--
-- PostgreSQL database dump
--

-- Dumped from database version 9.6.3
-- Dumped by pg_dump version 9.6.3

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

DROP DATABASE demo;
--
-- Name: demo; Type: DATABASE; Schema: -; Owner: -
--

CREATE DATABASE demo;


\connect demo

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: bookings; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA bookings;


--
-- Name: SCHEMA bookings; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON SCHEMA bookings IS 'Airlines demo database schema';


--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = bookings, pg_catalog;

--
-- Name: lang(); Type: FUNCTION; Schema: bookings; Owner: -
--

CREATE FUNCTION lang() RETURNS text
    LANGUAGE plpgsql STABLE
    AS $$
BEGIN
  RETURN current_setting('bookings.lang');
EXCEPTION
  WHEN undefined_object THEN
    RETURN NULL;
END;
$$;


--
-- Name: now(); Type: FUNCTION; Schema: bookings; Owner: -
--

CREATE FUNCTION now() RETURNS timestamp with time zone
    LANGUAGE sql IMMUTABLE
    AS $$SELECT '2017-08-15 18:00:00'::TIMESTAMP AT TIME ZONE 'Europe/Moscow';$$;


--
-- Name: FUNCTION now(); Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON FUNCTION now() IS 'Point in time according to which the data are generated';


SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: aircrafts_data; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE aircrafts_data (
    aircraft_code character(3) NOT NULL,
    model jsonb NOT NULL,
    range integer NOT NULL,
    CONSTRAINT aircrafts_range_check CHECK ((range > 0))
);


--
-- Name: TABLE aircrafts_data; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE aircrafts_data IS 'Aircrafts (internal data)';


--
-- Name: COLUMN aircrafts_data.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts_data.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN aircrafts_data.model; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts_data.model IS 'Aircraft model';


--
-- Name: COLUMN aircrafts_data.range; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts_data.range IS 'Maximal flying distance, km';


--
-- Name: aircrafts; Type: VIEW; Schema: bookings; Owner: -
--

CREATE VIEW aircrafts AS
 SELECT ml.aircraft_code,
    (ml.model ->> lang()) AS model,
    ml.range
   FROM aircrafts_data ml;


--
-- Name: VIEW aircrafts; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON VIEW aircrafts IS 'Aircrafts';


--
-- Name: COLUMN aircrafts.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN aircrafts.model; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts.model IS 'Aircraft model';


--
-- Name: COLUMN aircrafts.range; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN aircrafts.range IS 'Maximal flying distance, km';


--
-- Name: airports_data; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE airports_data (
    airport_code character(3) NOT NULL,
    airport_name jsonb NOT NULL,
    city jsonb NOT NULL,
    coordinates point NOT NULL,
    timezone text NOT NULL
);


--
-- Name: TABLE airports_data; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE airports_data IS 'Airports (internal data)';


--
-- Name: COLUMN airports_data.airport_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports_data.airport_code IS 'Airport code';


--
-- Name: COLUMN airports_data.airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports_data.airport_name IS 'Airport name';


--
-- Name: COLUMN airports_data.city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports_data.city IS 'City';


--
-- Name: COLUMN airports_data.coordinates; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports_data.coordinates IS 'Airport coordinates (longitude and latitude)';


--
-- Name: COLUMN airports_data.timezone; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports_data.timezone IS 'Airport time zone';


--
-- Name: airports; Type: VIEW; Schema: bookings; Owner: -
--

CREATE VIEW airports AS
 SELECT ml.airport_code,
    (ml.airport_name ->> lang()) AS airport_name,
    (ml.city ->> lang()) AS city,
    ml.coordinates,
    ml.timezone
   FROM airports_data ml;


--
-- Name: VIEW airports; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON VIEW airports IS 'Airports';


--
-- Name: COLUMN airports.airport_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports.airport_code IS 'Airport code';


--
-- Name: COLUMN airports.airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports.airport_name IS 'Airport name';


--
-- Name: COLUMN airports.city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports.city IS 'City';


--
-- Name: COLUMN airports.coordinates; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports.coordinates IS 'Airport coordinates (longitude and latitude)';


--
-- Name: COLUMN airports.timezone; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN airports.timezone IS 'Airport time zone';


--
-- Name: boarding_passes; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE boarding_passes (
    ticket_no character(13) NOT NULL,
    flight_id integer NOT NULL,
    boarding_no integer NOT NULL,
    seat_no character varying(4) NOT NULL
);


--
-- Name: TABLE boarding_passes; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE boarding_passes IS 'Boarding passes';


--
-- Name: COLUMN boarding_passes.ticket_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN boarding_passes.ticket_no IS 'Ticket number';


--
-- Name: COLUMN boarding_passes.flight_id; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN boarding_passes.flight_id IS 'Flight ID';


--
-- Name: COLUMN boarding_passes.boarding_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN boarding_passes.boarding_no IS 'Boarding pass number';


--
-- Name: COLUMN boarding_passes.seat_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN boarding_passes.seat_no IS 'Seat number';


--
-- Name: bookings; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE bookings (
    book_ref character(6) NOT NULL,
    book_date timestamp with time zone NOT NULL,
    total_amount numeric(10,2) NOT NULL
);


--
-- Name: TABLE bookings; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE bookings IS 'Bookings';


--
-- Name: COLUMN bookings.book_ref; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN bookings.book_ref IS 'Booking number';


--
-- Name: COLUMN bookings.book_date; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN bookings.book_date IS 'Booking date';


--
-- Name: COLUMN bookings.total_amount; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN bookings.total_amount IS 'Total booking cost';


--
-- Name: flights; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE flights (
    flight_id integer NOT NULL,
    flight_no character(6) NOT NULL,
    scheduled_departure timestamp with time zone NOT NULL,
    scheduled_arrival timestamp with time zone NOT NULL,
    departure_airport character(3) NOT NULL,
    arrival_airport character(3) NOT NULL,
    status character varying(20) NOT NULL,
    aircraft_code character(3) NOT NULL,
    actual_departure timestamp with time zone,
    actual_arrival timestamp with time zone,
    CONSTRAINT flights_check CHECK ((scheduled_arrival > scheduled_departure)),
    CONSTRAINT flights_check1 CHECK (((actual_arrival IS NULL) OR ((actual_departure IS NOT NULL) AND (actual_arrival IS NOT NULL) AND (actual_arrival > actual_departure)))),
    CONSTRAINT flights_status_check CHECK (((status)::text = ANY (ARRAY[('On Time'::character varying)::text, ('Delayed'::character varying)::text, ('Departed'::character varying)::text, ('Arrived'::character varying)::text, ('Scheduled'::character varying)::text, ('Cancelled'::character varying)::text])))
);


--
-- Name: TABLE flights; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE flights IS 'Flights';


--
-- Name: COLUMN flights.flight_id; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.flight_id IS 'Flight ID';


--
-- Name: COLUMN flights.flight_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.flight_no IS 'Flight number';


--
-- Name: COLUMN flights.scheduled_departure; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.scheduled_departure IS 'Scheduled departure time';


--
-- Name: COLUMN flights.scheduled_arrival; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.scheduled_arrival IS 'Scheduled arrival time';


--
-- Name: COLUMN flights.departure_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.departure_airport IS 'Airport of departure';


--
-- Name: COLUMN flights.arrival_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.arrival_airport IS 'Airport of arrival';


--
-- Name: COLUMN flights.status; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.status IS 'Flight status';


--
-- Name: COLUMN flights.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN flights.actual_departure; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.actual_departure IS 'Actual departure time';


--
-- Name: COLUMN flights.actual_arrival; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights.actual_arrival IS 'Actual arrival time';


--
-- Name: flights_flight_id_seq; Type: SEQUENCE; Schema: bookings; Owner: -
--

CREATE SEQUENCE flights_flight_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: flights_flight_id_seq; Type: SEQUENCE OWNED BY; Schema: bookings; Owner: -
--

ALTER SEQUENCE flights_flight_id_seq OWNED BY flights.flight_id;


--
-- Name: flights_v; Type: VIEW; Schema: bookings; Owner: -
--

CREATE VIEW flights_v AS
 SELECT f.flight_id,
    f.flight_no,
    f.scheduled_departure,
    timezone(dep.timezone, f.scheduled_departure) AS scheduled_departure_local,
    f.scheduled_arrival,
    timezone(arr.timezone, f.scheduled_arrival) AS scheduled_arrival_local,
    (f.scheduled_arrival - f.scheduled_departure) AS scheduled_duration,
    f.departure_airport,
    dep.airport_name AS departure_airport_name,
    dep.city AS departure_city,
    f.arrival_airport,
    arr.airport_name AS arrival_airport_name,
    arr.city AS arrival_city,
    f.status,
    f.aircraft_code,
    f.actual_departure,
    timezone(dep.timezone, f.actual_departure) AS actual_departure_local,
    f.actual_arrival,
    timezone(arr.timezone, f.actual_arrival) AS actual_arrival_local,
    (f.actual_arrival - f.actual_departure) AS actual_duration
   FROM flights f,
    airports dep,
    airports arr
  WHERE ((f.departure_airport = dep.airport_code) AND (f.arrival_airport = arr.airport_code));


--
-- Name: VIEW flights_v; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON VIEW flights_v IS 'Flights (extended)';


--
-- Name: COLUMN flights_v.flight_id; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.flight_id IS 'Flight ID';


--
-- Name: COLUMN flights_v.flight_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.flight_no IS 'Flight number';


--
-- Name: COLUMN flights_v.scheduled_departure; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.scheduled_departure IS 'Scheduled departure time';


--
-- Name: COLUMN flights_v.scheduled_departure_local; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.scheduled_departure_local IS 'Scheduled departure time, local time at the point of departure';


--
-- Name: COLUMN flights_v.scheduled_arrival; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.scheduled_arrival IS 'Scheduled arrival time';


--
-- Name: COLUMN flights_v.scheduled_arrival_local; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.scheduled_arrival_local IS 'Scheduled arrival time, local time at the point of destination';


--
-- Name: COLUMN flights_v.scheduled_duration; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.scheduled_duration IS 'Scheduled flight duration';


--
-- Name: COLUMN flights_v.departure_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.departure_airport IS 'Deprature airport code';


--
-- Name: COLUMN flights_v.departure_airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.departure_airport_name IS 'Departure airport name';


--
-- Name: COLUMN flights_v.departure_city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.departure_city IS 'City of departure';


--
-- Name: COLUMN flights_v.arrival_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.arrival_airport IS 'Arrival airport code';


--
-- Name: COLUMN flights_v.arrival_airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.arrival_airport_name IS 'Arrival airport name';


--
-- Name: COLUMN flights_v.arrival_city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.arrival_city IS 'City of arrival';


--
-- Name: COLUMN flights_v.status; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.status IS 'Flight status';


--
-- Name: COLUMN flights_v.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN flights_v.actual_departure; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.actual_departure IS 'Actual departure time';


--
-- Name: COLUMN flights_v.actual_departure_local; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.actual_departure_local IS 'Actual departure time, local time at the point of departure';


--
-- Name: COLUMN flights_v.actual_arrival; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.actual_arrival IS 'Actual arrival time';


--
-- Name: COLUMN flights_v.actual_arrival_local; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.actual_arrival_local IS 'Actual arrival time, local time at the point of destination';


--
-- Name: COLUMN flights_v.actual_duration; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN flights_v.actual_duration IS 'Actual flight duration';


--
-- Name: routes; Type: VIEW; Schema: bookings; Owner: -
--

CREATE VIEW routes AS
 WITH f3 AS (
         SELECT f2.flight_no,
            f2.departure_airport,
            f2.arrival_airport,
            f2.aircraft_code,
            f2.duration,
            array_agg(f2.days_of_week) AS days_of_week
           FROM ( SELECT f1.flight_no,
                    f1.departure_airport,
                    f1.arrival_airport,
                    f1.aircraft_code,
                    f1.duration,
                    f1.days_of_week
                   FROM ( SELECT flights.flight_no,
                            flights.departure_airport,
                            flights.arrival_airport,
                            flights.aircraft_code,
                            (flights.scheduled_arrival - flights.scheduled_departure) AS duration,
                            (to_char(flights.scheduled_departure, 'ID'::text))::integer AS days_of_week
                           FROM flights) f1
                  GROUP BY f1.flight_no, f1.departure_airport, f1.arrival_airport, f1.aircraft_code, f1.duration, f1.days_of_week
                  ORDER BY f1.flight_no, f1.departure_airport, f1.arrival_airport, f1.aircraft_code, f1.duration, f1.days_of_week) f2
          GROUP BY f2.flight_no, f2.departure_airport, f2.arrival_airport, f2.aircraft_code, f2.duration
        )
 SELECT f3.flight_no,
    f3.departure_airport,
    dep.airport_name AS departure_airport_name,
    dep.city AS departure_city,
    f3.arrival_airport,
    arr.airport_name AS arrival_airport_name,
    arr.city AS arrival_city,
    f3.aircraft_code,
    f3.duration,
    f3.days_of_week
   FROM f3,
    airports dep,
    airports arr
  WHERE ((f3.departure_airport = dep.airport_code) AND (f3.arrival_airport = arr.airport_code));


--
-- Name: VIEW routes; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON VIEW routes IS 'Routes';


--
-- Name: COLUMN routes.flight_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.flight_no IS 'Flight number';


--
-- Name: COLUMN routes.departure_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.departure_airport IS 'Code of airport of departure';


--
-- Name: COLUMN routes.departure_airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.departure_airport_name IS 'Name of airport of departure';


--
-- Name: COLUMN routes.departure_city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.departure_city IS 'City of departure';


--
-- Name: COLUMN routes.arrival_airport; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.arrival_airport IS 'Code of airport of arrival';


--
-- Name: COLUMN routes.arrival_airport_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.arrival_airport_name IS 'Name of airport of arrival';


--
-- Name: COLUMN routes.arrival_city; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.arrival_city IS 'City of arrival';


--
-- Name: COLUMN routes.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN routes.duration; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.duration IS 'Scheduled duration of flight';


--
-- Name: COLUMN routes.days_of_week; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN routes.days_of_week IS 'Days of week on which flights are scheduled';


--
-- Name: seats; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE seats (
    aircraft_code character(3) NOT NULL,
    seat_no character varying(4) NOT NULL,
    fare_conditions character varying(10) NOT NULL,
    CONSTRAINT seats_fare_conditions_check CHECK (((fare_conditions)::text = ANY (ARRAY[('Economy'::character varying)::text, ('Comfort'::character varying)::text, ('Business'::character varying)::text])))
);


--
-- Name: TABLE seats; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE seats IS 'Seats';


--
-- Name: COLUMN seats.aircraft_code; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN seats.aircraft_code IS 'Aircraft code, IATA';


--
-- Name: COLUMN seats.seat_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN seats.seat_no IS 'Seat number';


--
-- Name: COLUMN seats.fare_conditions; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN seats.fare_conditions IS 'Travel class';


--
-- Name: ticket_flights; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE ticket_flights (
    ticket_no character(13) NOT NULL,
    flight_id integer NOT NULL,
    fare_conditions character varying(10) NOT NULL,
    amount numeric(10,2) NOT NULL,
    CONSTRAINT ticket_flights_amount_check CHECK ((amount >= (0)::numeric)),
    CONSTRAINT ticket_flights_fare_conditions_check CHECK (((fare_conditions)::text = ANY (ARRAY[('Economy'::character varying)::text, ('Comfort'::character varying)::text, ('Business'::character varying)::text])))
);


--
-- Name: TABLE ticket_flights; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE ticket_flights IS 'Flight segment';


--
-- Name: COLUMN ticket_flights.ticket_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN ticket_flights.ticket_no IS 'Ticket number';


--
-- Name: COLUMN ticket_flights.flight_id; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN ticket_flights.flight_id IS 'Flight ID';


--
-- Name: COLUMN ticket_flights.fare_conditions; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN ticket_flights.fare_conditions IS 'Travel class';


--
-- Name: COLUMN ticket_flights.amount; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN ticket_flights.amount IS 'Travel cost';


--
-- Name: tickets; Type: TABLE; Schema: bookings; Owner: -
--

CREATE TABLE tickets (
    ticket_no character(13) NOT NULL,
    book_ref character(6) NOT NULL,
    passenger_id character varying(20) NOT NULL,
    passenger_name text NOT NULL,
    contact_data jsonb
);


--
-- Name: TABLE tickets; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON TABLE tickets IS 'Tickets';


--
-- Name: COLUMN tickets.ticket_no; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN tickets.ticket_no IS 'Ticket number';


--
-- Name: COLUMN tickets.book_ref; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN tickets.book_ref IS 'Booking number';


--
-- Name: COLUMN tickets.passenger_id; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN tickets.passenger_id IS 'Passenger ID';


--
-- Name: COLUMN tickets.passenger_name; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN tickets.passenger_name IS 'Passenger name';


--
-- Name: COLUMN tickets.contact_data; Type: COMMENT; Schema: bookings; Owner: -
--

COMMENT ON COLUMN tickets.contact_data IS 'Passenger contact information';


--
-- Name: flights flight_id; Type: DEFAULT; Schema: bookings; Owner: -
--

ALTER TABLE ONLY flights ALTER COLUMN flight_id SET DEFAULT nextval('flights_flight_id_seq'::regclass);


--
-- Data for Name: aircrafts_data; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY aircrafts_data (aircraft_code, model, range) FROM stdin;
773	{"en": "Boeing 777-300", "ru": "Боинг 777-300"}	11100
763	{"en": "Boeing 767-300", "ru": "Боинг 767-300"}	7900
SU9	{"en": "Sukhoi Superjet-100", "ru": "Сухой Суперджет-100"}	3000
320	{"en": "Airbus A320-200", "ru": "Аэробус A320-200"}	5700
321	{"en": "Airbus A321-200", "ru": "Аэробус A321-200"}	5600
319	{"en": "Airbus A319-100", "ru": "Аэробус A319-100"}	6700
733	{"en": "Boeing 737-300", "ru": "Боинг 737-300"}	4200
CN1	{"en": "Cessna 208 Caravan", "ru": "Сессна 208 Караван"}	1200
CR2	{"en": "Bombardier CRJ-200", "ru": "Бомбардье CRJ-200"}	2700
\.


--
-- Data for Name: airports_data; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY airports_data (airport_code, airport_name, city, coordinates, timezone) FROM stdin;
YKS	{"en": "Yakutsk Airport", "ru": "Якутск"}	{"en": "Yakutsk", "ru": "Якутск"}	(129.77099609375,62.0932998657226562)	Asia/Yakutsk
MJZ	{"en": "Mirny Airport", "ru": "Мирный"}	{"en": "Mirnyj", "ru": "Мирный"}	(114.03900146484375,62.534698486328125)	Asia/Yakutsk
KHV	{"en": "Khabarovsk-Novy Airport", "ru": "Хабаровск-Новый"}	{"en": "Khabarovsk", "ru": "Хабаровск"}	(135.18800354004,48.5279998779300001)	Asia/Vladivostok
PKC	{"en": "Yelizovo Airport", "ru": "Елизово"}	{"en": "Petropavlovsk", "ru": "Петропавловск-Камчатский"}	(158.453994750976562,53.1679000854492188)	Asia/Kamchatka
UUS	{"en": "Yuzhno-Sakhalinsk Airport", "ru": "Хомутово"}	{"en": "Yuzhno-Sakhalinsk", "ru": "Южно-Сахалинск"}	(142.718002319335938,46.8886985778808594)	Asia/Sakhalin
VVO	{"en": "Vladivostok International Airport", "ru": "Владивосток"}	{"en": "Vladivostok", "ru": "Владивосток"}	(132.147994995117188,43.3989982604980469)	Asia/Vladivostok
LED	{"en": "Pulkovo Airport", "ru": "Пулково"}	{"en": "St. Petersburg", "ru": "Санкт-Петербург"}	(30.2625007629394531,59.8003005981445312)	Europe/Moscow
KGD	{"en": "Khrabrovo Airport", "ru": "Храброво"}	{"en": "Kaliningrad", "ru": "Калининград"}	(20.5925998687744141,54.8899993896484375)	Europe/Kaliningrad
KEJ	{"en": "Kemerovo Airport", "ru": "Кемерово"}	{"en": "Kemorovo", "ru": "Кемерово"}	(86.1072006225585938,55.2700996398925781)	Asia/Novokuznetsk
CEK	{"en": "Chelyabinsk Balandino Airport", "ru": "Челябинск"}	{"en": "Chelyabinsk", "ru": "Челябинск"}	(61.503300000000003,55.3058010000000024)	Asia/Yekaterinburg
MQF	{"en": "Magnitogorsk International Airport", "ru": "Магнитогорск"}	{"en": "Magnetiogorsk", "ru": "Магнитогорск"}	(58.7556991577148438,53.3931007385253906)	Asia/Yekaterinburg
PEE	{"en": "Bolshoye Savino Airport", "ru": "Пермь"}	{"en": "Perm", "ru": "Пермь"}	(56.021198272705,57.9145011901860016)	Asia/Yekaterinburg
SGC	{"en": "Surgut Airport", "ru": "Сургут"}	{"en": "Surgut", "ru": "Сургут"}	(73.4018020629882812,61.3437004089355469)	Asia/Yekaterinburg
BZK	{"en": "Bryansk Airport", "ru": "Брянск"}	{"en": "Bryansk", "ru": "Брянск"}	(34.1763992309999978,53.2141990661999955)	Europe/Moscow
MRV	{"en": "Mineralnyye Vody Airport", "ru": "Минеральные Воды"}	{"en": "Mineralnye Vody", "ru": "Минеральные Воды"}	(43.0819015502929688,44.2251014709472656)	Europe/Moscow
STW	{"en": "Stavropol Shpakovskoye Airport", "ru": "Ставрополь"}	{"en": "Stavropol", "ru": "Ставрополь"}	(42.1128005981445312,45.1091995239257812)	Europe/Moscow
ASF	{"en": "Astrakhan Airport", "ru": "Астрахань"}	{"en": "Astrakhan", "ru": "Астрахань"}	(48.0063018799000005,46.2832984924000002)	Europe/Samara
NJC	{"en": "Nizhnevartovsk Airport", "ru": "Нижневартовск"}	{"en": "Nizhnevartovsk", "ru": "Нижневартовск"}	(76.4835968017578125,60.9492988586425781)	Asia/Yekaterinburg
SVX	{"en": "Koltsovo Airport", "ru": "Кольцово"}	{"en": "Yekaterinburg", "ru": "Екатеринбург"}	(60.8027000427250002,56.7430992126460012)	Asia/Yekaterinburg
SVO	{"en": "Sheremetyevo International Airport", "ru": "Шереметьево"}	{"en": "Moscow", "ru": "Москва"}	(37.4146000000000001,55.9725990000000024)	Europe/Moscow
VOZ	{"en": "Voronezh International Airport", "ru": "Воронеж"}	{"en": "Voronezh", "ru": "Воронеж"}	(39.2295989990234375,51.8142013549804688)	Europe/Moscow
VKO	{"en": "Vnukovo International Airport", "ru": "Внуково"}	{"en": "Moscow", "ru": "Москва"}	(37.2615013122999983,55.5914993286000012)	Europe/Moscow
SCW	{"en": "Syktyvkar Airport", "ru": "Сыктывкар"}	{"en": "Syktyvkar", "ru": "Сыктывкар"}	(50.8451004028320312,61.6469993591308594)	Europe/Moscow
KUF	{"en": "Kurumoch International Airport", "ru": "Курумоч"}	{"en": "Samara", "ru": "Самара"}	(50.1642990112299998,53.5049018859860013)	Europe/Samara
DME	{"en": "Domodedovo International Airport", "ru": "Домодедово"}	{"en": "Moscow", "ru": "Москва"}	(37.9062995910644531,55.4087982177734375)	Europe/Moscow
TJM	{"en": "Roshchino International Airport", "ru": "Рощино"}	{"en": "Tyumen", "ru": "Тюмень"}	(65.3243026732999965,57.1896018981999958)	Asia/Yekaterinburg
GOJ	{"en": "Nizhny Novgorod Strigino International Airport", "ru": "Стригино"}	{"en": "Nizhniy Novgorod", "ru": "Нижний Новгород"}	(43.7840003967289988,56.2300987243649999)	Europe/Moscow
TOF	{"en": "Bogashevo Airport", "ru": "Богашёво"}	{"en": "Tomsk", "ru": "Томск"}	(85.2082977294920028,56.3802986145020029)	Asia/Krasnoyarsk
UIK	{"en": "Ust-Ilimsk Airport", "ru": "Усть-Илимск"}	{"en": "Ust Ilimsk", "ru": "Усть-Илимск"}	(102.56500244140625,58.1361007690429688)	Asia/Irkutsk
NSK	{"en": "Norilsk-Alykel Airport", "ru": "Норильск"}	{"en": "Norilsk", "ru": "Норильск"}	(87.3321990966796875,69.31109619140625)	Asia/Krasnoyarsk
ARH	{"en": "Talagi Airport", "ru": "Талаги"}	{"en": "Arkhangelsk", "ru": "Архангельск"}	(40.7167015075683594,64.6003036499023438)	Europe/Moscow
RTW	{"en": "Saratov Central Airport", "ru": "Саратов-Центральный"}	{"en": "Saratov", "ru": "Саратов"}	(46.0466995239257812,51.5649986267089844)	Europe/Volgograd
NUX	{"en": "Novy Urengoy Airport", "ru": "Новый Уренгой"}	{"en": "Novy Urengoy", "ru": "Новый Уренгой"}	(76.5203018188476562,66.06939697265625)	Asia/Yekaterinburg
NOJ	{"en": "Noyabrsk Airport", "ru": "Ноябрьск"}	{"en": "Noyabrsk", "ru": "Ноябрьск"}	(75.2699966430664062,63.1833000183105469)	Asia/Yekaterinburg
UCT	{"en": "Ukhta Airport", "ru": "Ухта"}	{"en": "Ukhta", "ru": "Ухта"}	(53.8046989440917969,63.5668983459472656)	Europe/Moscow
USK	{"en": "Usinsk Airport", "ru": "Усинск"}	{"en": "Usinsk", "ru": "Усинск"}	(57.3671989440917969,66.00469970703125)	Europe/Moscow
NNM	{"en": "Naryan Mar Airport", "ru": "Нарьян-Мар"}	{"en": "Naryan-Mar", "ru": "Нарьян-Мар"}	(53.1218986511230469,67.6399993896484375)	Europe/Moscow
PKV	{"en": "Pskov Airport", "ru": "Псков"}	{"en": "Pskov", "ru": "Псков"}	(28.395599365234375,57.7839012145996094)	Europe/Moscow
KGP	{"en": "Kogalym International Airport", "ru": "Когалым"}	{"en": "Kogalym", "ru": "Когалым"}	(74.5337982177734375,62.190399169921875)	Asia/Yekaterinburg
KJA	{"en": "Yemelyanovo Airport", "ru": "Емельяново"}	{"en": "Krasnoyarsk", "ru": "Красноярск"}	(92.493301391602003,56.1729011535639984)	Asia/Krasnoyarsk
URJ	{"en": "Uray Airport", "ru": "Петрозаводск"}	{"en": "Uraj", "ru": "Урай"}	(64.8266983032226562,60.1032981872558594)	Asia/Yekaterinburg
IWA	{"en": "Ivanovo South Airport", "ru": "Иваново-Южный"}	{"en": "Ivanovo", "ru": "Иваново"}	(40.9407997131347656,56.9393997192382812)	Europe/Moscow
PYJ	{"en": "Polyarny Airport", "ru": "Полярный"}	{"en": "Yakutia", "ru": "Удачный"}	(112.029998778999996,66.4003982544000024)	Asia/Yakutsk
KXK	{"en": "Komsomolsk-on-Amur Airport", "ru": "Хурба"}	{"en": "Komsomolsk-on-Amur", "ru": "Комсомольск-на-Амуре"}	(136.934005737304688,50.4090003967285156)	Asia/Vladivostok
DYR	{"en": "Ugolny Airport", "ru": "Анадырь"}	{"en": "Anadyr", "ru": "Анадырь"}	(177.740997314453125,64.7349014282226562)	Asia/Anadyr
PES	{"en": "Petrozavodsk Airport", "ru": "Бесовец"}	{"en": "Petrozavodsk", "ru": "Петрозаводск"}	(34.1547012329101562,61.8852005004882812)	Europe/Moscow
KYZ	{"en": "Kyzyl Airport", "ru": "Кызыл"}	{"en": "Kyzyl", "ru": "Кызыл"}	(94.4005966186523438,51.6693992614746094)	Asia/Krasnoyarsk
NOZ	{"en": "Spichenkovo Airport", "ru": "Спиченково"}	{"en": "Novokuznetsk", "ru": "Новокузнецк"}	(86.877197265625,53.8114013671875)	Asia/Novokuznetsk
GRV	{"en": "Khankala Air Base", "ru": "Грозный"}	{"en": "Grozny", "ru": "Грозный"}	(45.7840995788574219,43.2980995178222656)	Europe/Moscow
NAL	{"en": "Nalchik Airport", "ru": "Нальчик"}	{"en": "Nalchik", "ru": "Нальчик"}	(43.6366004943847656,43.5129013061523438)	Europe/Moscow
OGZ	{"en": "Beslan Airport", "ru": "Беслан"}	{"en": "Beslan", "ru": "Владикавказ"}	(44.6066017150999983,43.2051010132000002)	Europe/Moscow
ESL	{"en": "Elista Airport", "ru": "Элиста"}	{"en": "Elista", "ru": "Элиста"}	(44.3308982849121094,46.3739013671875)	Europe/Moscow
SLY	{"en": "Salekhard Airport", "ru": "Салехард"}	{"en": "Salekhard", "ru": "Салехард"}	(66.6110000610351562,66.5907974243164062)	Asia/Yekaterinburg
HMA	{"en": "Khanty Mansiysk Airport", "ru": "Ханты-Мансийск"}	{"en": "Khanty-Mansiysk", "ru": "Ханты-Мансийск"}	(69.0860977172851562,61.0284996032714844)	Asia/Yekaterinburg
NYA	{"en": "Nyagan Airport", "ru": "Нягань"}	{"en": "Nyagan", "ru": "Нягань"}	(65.6149978637695312,62.1100006103515625)	Asia/Yekaterinburg
OVS	{"en": "Sovetskiy Airport", "ru": "Советский"}	{"en": "Sovetskiy", "ru": "Советский"}	(63.6019134521484375,61.3266220092773438)	Asia/Yekaterinburg
IJK	{"en": "Izhevsk Airport", "ru": "Ижевск"}	{"en": "Izhevsk", "ru": "Ижевск"}	(53.4575004577636719,56.8280982971191406)	Europe/Samara
KVX	{"en": "Pobedilovo Airport", "ru": "Победилово"}	{"en": "Kirov", "ru": "Киров"}	(49.3483009338379972,58.5032997131350001)	Europe/Moscow
NYM	{"en": "Nadym Airport", "ru": "Надым"}	{"en": "Nadym", "ru": "Надым"}	(72.6988983154296875,65.4809036254882812)	Asia/Yekaterinburg
NFG	{"en": "Nefteyugansk Airport", "ru": "Нефтеюганск"}	{"en": "Nefteyugansk", "ru": "Нефтеюганск"}	(72.6500015258789062,61.1082992553710938)	Asia/Yekaterinburg
KRO	{"en": "Kurgan Airport", "ru": "Курган"}	{"en": "Kurgan", "ru": "Курган"}	(65.4156036376953125,55.4752998352050781)	Asia/Yekaterinburg
EGO	{"en": "Belgorod International Airport", "ru": "Белгород"}	{"en": "Belgorod", "ru": "Белгород"}	(36.5900993347167969,50.643798828125)	Europe/Moscow
URS	{"en": "Kursk East Airport", "ru": "Курск-Восточный"}	{"en": "Kursk", "ru": "Курск"}	(36.2956008911132812,51.7505989074707031)	Europe/Moscow
LPK	{"en": "Lipetsk Airport", "ru": "Липецк"}	{"en": "Lipetsk", "ru": "Липецк"}	(39.5377998352050781,52.7028007507324219)	Europe/Moscow
VKT	{"en": "Vorkuta Airport", "ru": "Воркута"}	{"en": "Vorkuta", "ru": "Воркута"}	(63.9930992126464844,67.4886016845703125)	Europe/Moscow
UUA	{"en": "Bugulma Airport", "ru": "Бугульма"}	{"en": "Bugulma", "ru": "Бугульма"}	(52.8017005920410156,54.6399993896484375)	Europe/Moscow
JOK	{"en": "Yoshkar-Ola Airport", "ru": "Йошкар-Ола"}	{"en": "Yoshkar-Ola", "ru": "Йошкар-Ола"}	(47.9047012329101562,56.7005996704101562)	Europe/Moscow
CSY	{"en": "Cheboksary Airport", "ru": "Чебоксары"}	{"en": "Cheboksary", "ru": "Чебоксары"}	(47.3473014831542969,56.090301513671875)	Europe/Moscow
ULY	{"en": "Ulyanovsk East Airport", "ru": "Ульяновск-Восточный"}	{"en": "Ulyanovsk", "ru": "Ульяновск"}	(48.8027000427246094,54.4010009765625)	Europe/Samara
OSW	{"en": "Orsk Airport", "ru": "Орск"}	{"en": "Orsk", "ru": "Орск"}	(58.5956001281738281,51.0724983215332031)	Asia/Yekaterinburg
PEZ	{"en": "Penza Airport", "ru": "Пенза"}	{"en": "Penza", "ru": "Пенза"}	(45.0210990905761719,53.1105995178222656)	Europe/Moscow
SKX	{"en": "Saransk Airport", "ru": "Саранск"}	{"en": "Saransk", "ru": "Саранск"}	(45.2122573852539062,54.1251296997070312)	Europe/Moscow
TBW	{"en": "Donskoye Airport", "ru": "Донское"}	{"en": "Tambow", "ru": "Тамбов"}	(41.4827995300289984,52.806098937987997)	Europe/Moscow
UKX	{"en": "Ust-Kut Airport", "ru": "Усть-Кут"}	{"en": "Ust-Kut", "ru": "Усть-Кут"}	(105.730003356933594,56.8567008972167969)	Asia/Irkutsk
GDZ	{"en": "Gelendzhik Airport", "ru": "Геленджик"}	{"en": "Gelendzhik", "ru": "Геленджик"}	(38.012480735799997,44.5820926295000035)	Europe/Moscow
IAR	{"en": "Tunoshna Airport", "ru": "Туношна"}	{"en": "Yaroslavl", "ru": "Ярославль"}	(40.1573982238769531,57.560699462890625)	Europe/Moscow
NBC	{"en": "Begishevo Airport", "ru": "Бегишево"}	{"en": "Nizhnekamsk", "ru": "Нижнекамск"}	(52.092498779296875,55.5647010803222656)	Europe/Moscow
ULV	{"en": "Ulyanovsk Baratayevka Airport", "ru": "Баратаевка"}	{"en": "Ulyanovsk", "ru": "Ульяновск"}	(48.2266998291000064,54.2682991027999932)	Europe/Samara
SWT	{"en": "Strezhevoy Airport", "ru": "Стрежевой"}	{"en": "Strezhevoy", "ru": "Стрежевой"}	(77.66000366210001,60.7094001769999991)	Asia/Krasnoyarsk
EYK	{"en": "Beloyarskiy Airport", "ru": "Белоярский"}	{"en": "Beloyarsky", "ru": "Белоярский"}	(66.6986007689999951,63.6869010924999941)	Asia/Yekaterinburg
KLF	{"en": "Grabtsevo Airport", "ru": "Калуга"}	{"en": "Kaluga", "ru": "Калуга"}	(36.3666687011999983,54.5499992371000033)	Europe/Moscow
RGK	{"en": "Gorno-Altaysk Airport", "ru": "Горно-Алтайск"}	{"en": "Gorno-Altaysk", "ru": "Горно-Алтайск"}	(85.8332977295000035,51.9667015075999998)	Asia/Krasnoyarsk
KRR	{"en": "Krasnodar Pashkovsky International Airport", "ru": "Краснодар"}	{"en": "Krasnodar", "ru": "Краснодар"}	(39.1705017089839984,45.0346984863279971)	Europe/Moscow
MCX	{"en": "Uytash Airport", "ru": "Уйташ"}	{"en": "Makhachkala", "ru": "Махачкала"}	(47.6523017883300781,42.8167991638183594)	Europe/Moscow
KZN	{"en": "Kazan International Airport", "ru": "Казань"}	{"en": "Kazan", "ru": "Казань"}	(49.278701782227003,55.606201171875)	Europe/Moscow
REN	{"en": "Orenburg Central Airport", "ru": "Оренбург-Центральный"}	{"en": "Orenburg", "ru": "Оренбург"}	(55.4566993713378906,51.7957992553710938)	Asia/Yekaterinburg
UFA	{"en": "Ufa International Airport", "ru": "Уфа"}	{"en": "Ufa", "ru": "Уфа"}	(55.8744010925289984,54.5574989318850001)	Asia/Yekaterinburg
OVB	{"en": "Tolmachevo Airport", "ru": "Толмачёво"}	{"en": "Novosibirsk", "ru": "Новосибирск"}	(82.6507034301759944,55.012599945067997)	Asia/Novosibirsk
CEE	{"en": "Cherepovets Airport", "ru": "Череповец"}	{"en": "Cherepovets", "ru": "Череповец"}	(38.0158004761000043,59.2736015320000007)	Europe/Moscow
OMS	{"en": "Omsk Central Airport", "ru": "Омск-Центральный"}	{"en": "Omsk", "ru": "Омск"}	(73.3105010986328125,54.9669990539550781)	Asia/Omsk
ROV	{"en": "Rostov-on-Don Airport", "ru": "Ростов-на-Дону"}	{"en": "Rostov", "ru": "Ростов-на-Дону"}	(39.8180999755999991,47.2582015990999977)	Europe/Moscow
AER	{"en": "Sochi International Airport", "ru": "Сочи"}	{"en": "Sochi", "ru": "Сочи"}	(39.9566001892089986,43.4499015808110016)	Europe/Moscow
VOG	{"en": "Volgograd International Airport", "ru": "Гумрак"}	{"en": "Volgograd", "ru": "Волгоград"}	(44.3455009460449219,48.782501220703125)	Europe/Volgograd
BQS	{"en": "Ignatyevo Airport", "ru": "Игнатьево"}	{"en": "Blagoveschensk", "ru": "Благовещенск"}	(127.412002563476562,50.4253997802734375)	Asia/Yakutsk
GDX	{"en": "Sokol Airport", "ru": "Магадан"}	{"en": "Magadan", "ru": "Магадан"}	(150.720001220703125,59.9109992980957031)	Asia/Magadan
HTA	{"en": "Chita-Kadala Airport", "ru": "Чита"}	{"en": "Chita", "ru": "Чита"}	(113.305999999999997,52.0262990000000016)	Asia/Chita
BTK	{"en": "Bratsk Airport", "ru": "Братск"}	{"en": "Bratsk", "ru": "Братск"}	(101.697998046875,56.3706016540527344)	Asia/Irkutsk
IKT	{"en": "Irkutsk Airport", "ru": "Иркутск"}	{"en": "Irkutsk", "ru": "Иркутск"}	(104.388999938959998,52.2680015563960012)	Asia/Irkutsk
UUD	{"en": "Ulan-Ude Airport (Mukhino)", "ru": "Байкал"}	{"en": "Ulan-ude", "ru": "Улан-Удэ"}	(107.438003540039062,51.80780029296875)	Asia/Irkutsk
MMK	{"en": "Murmansk Airport", "ru": "Мурманск"}	{"en": "Murmansk", "ru": "Мурманск"}	(32.7508010864257812,68.7817001342773438)	Europe/Moscow
ABA	{"en": "Abakan Airport", "ru": "Абакан"}	{"en": "Abakan", "ru": "Абакан"}	(91.3850021362304688,53.7400016784667969)	Asia/Krasnoyarsk
BAX	{"en": "Barnaul Airport", "ru": "Барнаул"}	{"en": "Barnaul", "ru": "Барнаул"}	(83.5384979248046875,53.363800048828125)	Asia/Krasnoyarsk
AAQ	{"en": "Anapa Vityazevo Airport", "ru": "Витязево"}	{"en": "Anapa", "ru": "Анапа"}	(37.3473014831539984,45.002101898192997)	Europe/Moscow
CNN	{"en": "Chulman Airport", "ru": "Чульман"}	{"en": "Neryungri", "ru": "Нерюнгри"}	(124.914001464839998,56.9138984680179973)	Asia/Yakutsk
\.


--
-- Data for Name: boarding_passes; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY boarding_passes (ticket_no, flight_id, boarding_no, seat_no) FROM stdin;
0005435212351	30625	1	2D
0005435212386	30625	2	3G
0005435212381	30625	3	4H
0005432211370	30625	4	5D
0005435212357	30625	5	11A
0005435212360	30625	6	11E
0005435212393	30625	7	11H
0005435212374	30625	8	12E
0005435212365	30625	9	13D
0005435212378	30625	10	14H
0005435212362	30625	11	15E
0005435212334	30625	12	15F
0005435212370	30625	13	15K
0005435212329	30625	14	15H
0005435725513	30625	15	16D
0005435212328	30625	16	16C
0005435630915	30625	17	16E
0005435212388	30625	18	17E
0005432159775	30625	19	17D
0005435212382	30625	20	17H
0005432211367	30625	21	19K
0005435212354	30625	22	20B
0005432211372	30625	23	20F
0005432159776	30625	24	2A
0005435212344	30625	25	20K
0005435212372	30625	26	22B
0005435212355	30625	27	22H
0005435212376	30625	28	23F
0005435725512	30625	29	25D
0005435212385	30625	30	25C
0005435212336	30625	31	26D
0005435212367	30625	32	26J
0005435212359	30625	33	27B
0005435212364	30625	34	27H
0005435725514	30625	35	27K
0005435212338	30625	36	28C
0005435212391	30625	37	28B
0005435212366	30625	38	28G
0005435212347	30625	39	28J
0005432211366	30625	40	28K
0005433656614	30625	41	29D
0005435212383	30625	42	29C
0005435212373	30625	43	29B
0005435212395	30625	44	29J
0005435212343	30625	45	30E
0005435212371	30625	46	30J
0005435212377	30625	47	31J
0005435212358	30625	48	32C
0005435212330	30625	49	32B
0005432211371	30625	50	32F
0005435212368	30625	51	32K
0005435212340	30625	52	33D
0005435212335	30625	53	33C
0005435212363	30625	54	33H
0005435212380	30625	55	35A
0005435212345	30625	56	35C
0005435212375	30625	57	35B
0005432211365	30625	58	35F
0005435212350	30625	59	35E
0005435212331	30625	60	35G
0005435212353	30625	61	36G
0005435630916	30625	62	36J
0005435212337	30625	63	37B
0005432211368	30625	64	37E
0005432211369	30625	65	37F
0005435212356	30625	66	37H
0005435212332	30625	67	38A
0005435212348	30625	68	38K
0005435212352	30625	69	39E
0005435212394	30625	70	40G
0005435212389	30625	71	40J
0005435212369	30625	72	42A
0005435212392	30625	73	41K
0005435212379	30625	74	42C
0005435725516	30625	75	42E
0005435212396	30625	76	42K
0005432159777	30625	77	43A
0005433656613	30625	78	43G
0005435725515	30625	79	43H
0005435212346	30625	80	43K
0005435212390	30625	81	45D
0005435212361	30625	82	45E
0005435212341	30625	83	45K
0005435725511	30625	84	46C
0005435212349	30625	85	46B
0005432159778	30625	86	46K
0005435212384	30625	87	47E
0005435630914	30625	88	49E
0005435212339	30625	89	49G
0005435212333	30625	90	50C
0005435212387	30625	91	50H
0005435212342	30625	92	51D
0005433367244	24836	1	1D
0005433367229	24836	2	1F
0005433367230	24836	3	2C
0005433367245	24836	4	2D
0005433367256	24836	5	3D
0005433367225	24836	6	3F
0005433367228	24836	7	4A
0005433367236	24836	8	4C
0005433367252	24836	9	4E
0005433367243	24836	10	5A
0005433367222	24836	11	5C
0005433367234	24836	12	5D
0005433367231	24836	13	5F
0005433367218	24836	14	6C
0005433367224	24836	15	6E
0005433367237	24836	16	7A
0005433367255	24836	17	7D
0005433367246	24836	18	7E
0005433367227	24836	19	8A
0005433367233	24836	20	8F
0005433367242	24836	21	9A
0005433367248	24836	22	9F
0005433367223	24836	23	10C
0005433367241	24836	24	10E
0005433367221	24836	25	10F
0005433367258	24836	26	11A
0005433367240	24836	27	13E
0005433367226	24836	28	13F
0005433367247	24836	29	14A
0005433367235	24836	30	14F
0005433367257	24836	31	15F
0005433367251	24836	32	16A
0005433367239	24836	33	16C
0005433367220	24836	34	16D
0005433367250	24836	35	16E
0005433367219	24836	36	17C
0005433367253	24836	37	17D
0005433367232	24836	38	18A
0005433367249	24836	39	18E
0005433367238	24836	40	19D
0005433367254	24836	41	19E
0005434979262	2055	1	1C
0005434979271	2055	2	1D
0005434979277	2055	3	2B
0005434979252	2055	4	2C
0005434979282	2055	5	2D
0005434979273	2055	6	3B
0005434979280	2055	7	3C
0005434979255	2055	8	4A
0005434979269	2055	9	4B
0005434979275	2055	10	4C
0005435801642	2055	11	4D
0005434979279	2055	12	5A
0005434979267	2055	13	5B
0005434979254	2055	14	5D
0005434979264	2055	15	6A
0005434979263	2055	16	6C
0005434979276	2055	17	7B
0005434979270	2055	18	18A
0005434979258	2055	19	18B
0005434979256	2055	20	18C
0005434979265	2055	21	18D
0005434979261	2055	22	19A
0005434979253	2055	23	19B
0005434979259	2055	24	19D
0005435801643	2055	25	20A
0005434979272	2055	26	20B
0005434979260	2055	27	20C
0005434979274	2055	28	20D
0005434979268	2055	29	21C
0005434979257	2055	30	21D
0005434979278	2055	31	22A
0005434979266	2055	32	22B
0005435801644	2055	33	22D
0005434979281	2055	34	23B
0005434952466	2575	1	1B
0005434952464	2575	2	4A
0005434952467	2575	3	5A
0005434952465	2575	4	4B
0005433256382	28205	1	1B
0005433256381	28205	2	5A
0005433111467	19732	1	1A
0005433111468	19732	2	3B
0005433112350	19732	3	4B
0005433111469	19732	4	6A
0005434190367	19092	1	1C
0005434190368	19092	2	7A
0005433534460	6786	1	1B
0005433534461	6786	2	2A
0005433534463	6786	3	2D
0005433538721	6786	4	3A
0005433538717	6786	5	4B
0005433538718	6786	6	4C
0005433534462	6786	7	5C
0005433538720	6786	8	21A
0005433538719	6786	9	21B
0005433538722	6786	10	21D
0005433538723	6786	11	22A
0005433538724	6786	12	23B
0005435259680	25029	1	3D
0005435259678	25029	2	4C
0005435259681	25029	3	18A
0005435259679	25029	4	19D
0005433511804	823	1	1D
0005433511803	823	2	4B
0005433511809	823	3	5D
0005433511807	823	4	6A
0005433511802	823	5	7B
0005433511801	823	6	19B
0005433511808	823	7	20B
0005433511806	823	8	21B
0005433511805	823	9	22B
0005432922454	16157	1	1C
0005432922455	16157	2	2D
0005432922453	16157	3	5A
0005433475633	4021	1	1D
0005433475632	4021	2	2D
0005433475631	4021	3	18D
0005433475630	4021	4	21A
0005435696849	3660	1	1B
0005435696846	3660	2	1D
0005434950451	3660	3	2A
0005435696864	3660	4	2B
0005435696862	3660	5	2D
0005435696847	3660	6	3A
0005435696850	3660	7	3D
0005435696866	3660	8	4A
0005435696843	3660	9	4C
0005435696863	3660	10	5A
0005435696851	3660	11	5B
0005434950450	3660	12	5D
0005435696870	3660	13	6B
0005434950452	3660	14	6D
0005435696859	3660	15	7A
0005435696871	3660	16	7B
0005435696855	3660	17	7D
0005435696869	3660	18	18A
0005435696852	3660	19	18C
0005435696857	3660	20	18D
0005435696853	3660	21	19A
0005435696845	3660	22	19B
0005435696844	3660	23	19C
0005435696856	3660	24	20B
0005435696858	3660	25	20C
0005435696865	3660	26	20D
0005435696848	3660	27	21C
0005435696861	3660	28	22A
0005435696860	3660	29	22B
0005435696854	3660	30	22D
0005435696868	3660	31	23B
0005435696867	3660	32	23A
0005435916119	16272	1	6A
0005435916118	16272	2	7B
0005432609659	3993	1	1A
0005432609661	3993	2	1B
0005432607495	3993	3	1C
0005434606760	3993	4	1D
0005432609658	3993	5	2D
0005434606759	3993	6	4A
0005434606763	3993	7	4D
0005433519378	3993	8	5B
0005432607494	3993	9	6B
0005433519379	3993	10	6D
0005434604838	3993	11	7A
0005434606761	3993	12	18B
0005433519377	3993	13	19B
0005432609660	3993	14	19C
0005434604839	3993	15	19D
0005434606762	3993	16	20B
0005433519380	3993	17	20C
0005432607496	3993	18	21B
0005434604837	3993	19	21C
0005435853578	22080	1	1D
0005435853580	22080	2	18C
0005435853579	22080	3	22C
0005435628670	728	1	1A
0005435628672	728	2	2A
0005435628669	728	3	4B
0005435628671	728	4	6A
0005433348889	15900	1	1A
0005433348891	15900	2	2A
0005433348887	15900	3	3B
0005433348888	15900	4	5B
0005433348890	15900	5	6B
0005433159275	17677	1	4A
0005433159274	17677	2	6A
0005433159276	17677	3	6B
0005435132700	7862	1	2B
0005435132696	7862	2	2D
0005435132694	7862	3	3D
0005435132695	7862	4	4B
0005435132698	7862	5	5A
0005435132697	7862	6	6A
0005435132699	7862	7	7D
0005435132703	7862	8	19B
0005435132704	7862	9	20A
0005435132702	7862	10	21C
0005435132701	7862	11	23A
0005435383058	33092	1	1A
0005435383057	33092	2	5C
0005435383056	33092	3	6B
0005435383059	33092	4	18B
0005435383055	33092	5	22B
0005435160112	7477	1	4C
0005435160111	7477	2	6A
0005435160104	7477	3	7C
0005435160106	7477	4	7B
0005435160109	7477	5	18B
0005435160103	7477	6	18D
0005435160105	7477	7	20A
0005435160110	7477	8	21B
0005435160113	7477	9	21C
0005435160107	7477	10	21D
0005435160108	7477	11	23B
0005435390116	29573	1	1A
0005435390120	29573	2	4A
0005435390121	29573	3	4B
0005435390122	29573	4	5C
0005435390118	29573	5	7C
0005435390117	29573	6	21A
0005435390119	29573	7	21D
0005434503467	6547	1	2C
0005434503492	6547	2	2F
0005434503487	6547	3	4A
0005434503465	6547	4	4C
0005434503495	6547	5	4F
0005434503472	6547	6	5A
0005434503463	6547	7	5D
0005434503469	6547	8	5E
0005434503460	6547	9	5F
0005434503488	6547	10	6C
0005434503484	6547	11	6D
0005434503490	6547	12	6E
0005434503468	6547	13	6F
0005434503482	6547	14	7A
0005435103797	6547	15	7D
0005435103796	6547	16	7E
0005434503479	6547	17	8A
0005435103802	6547	18	8C
0005434503471	6547	19	8D
0005434503494	6547	20	8E
0005434503483	6547	21	8F
0005434503474	6547	22	9C
0005434503464	6547	23	9D
0005434503476	6547	24	9E
0005435103803	6547	25	10A
0005434503462	6547	26	10C
0005434503459	6547	27	10E
0005435103799	6547	28	10F
0005434503458	6547	29	11C
0005434503466	6547	30	11F
0005434503478	6547	31	12A
0005434503470	6547	32	12C
0005434503486	6547	33	13C
0005434503489	6547	34	13F
0005434503491	6547	35	14A
0005435103793	6547	36	14D
0005435103795	6547	37	14E
0005434503485	6547	38	14F
0005434503477	6547	39	15C
0005434503461	6547	40	15E
0005434503473	6547	41	15F
0005434503496	6547	42	16D
0005435103794	6547	43	16E
0005434503475	6547	44	17E
0005434503493	6547	45	17F
0005435103801	6547	46	18D
0005435103798	6547	47	19A
0005435103800	6547	48	20A
0005434503481	6547	49	20C
0005434503480	6547	50	20E
0005435652274	1654	1	1A
0005435652282	1654	2	1D
0005435652261	1654	3	2C
0005435652269	1654	4	2F
0005435652292	1654	5	3C
0005435652275	1654	6	4A
0005435652281	1654	7	4C
0005435652283	1654	8	5D
0005435652263	1654	9	5E
0005435652260	1654	10	6D
0005435652264	1654	11	6F
0005435652278	1654	12	7A
0005435652266	1654	13	7D
0005435652272	1654	14	7F
0005435652250	1654	15	8A
0005435652254	1654	16	8C
0005435652268	1654	17	8E
0005435652253	1654	18	9C
0005435652279	1654	19	9D
0005435652276	1654	20	9E
0005435652251	1654	21	10A
0005435652273	1654	22	10C
0005435652252	1654	23	11A
0005435652295	1654	24	11C
0005435652284	1654	25	11D
0005435652259	1654	26	11E
0005435652265	1654	27	12C
0005435652262	1654	28	12D
0005435652267	1654	29	12E
0005435652280	1654	30	13A
0005435652294	1654	31	13C
0005435652296	1654	32	13D
0005435652257	1654	33	13E
0005435652288	1654	34	14C
0005435652271	1654	35	14D
0005435652285	1654	36	15D
0005435652258	1654	37	15E
0005435652286	1654	38	15F
0005435652291	1654	39	16A
0005435652293	1654	40	16E
0005435652256	1654	41	16D
0005435652270	1654	42	17C
0005435652289	1654	43	18C
0005435652287	1654	44	18D
0005435652290	1654	45	19E
0005435652277	1654	46	19F
0005435652255	1654	47	20D
0005433367257	21707	1	1C
0005433367244	21707	2	1D
0005433367258	21707	3	1F
0005433367221	21707	4	2F
0005433367224	21707	5	4A
0005433367218	21707	6	4D
0005433367240	21707	7	4E
0005433367222	21707	8	6D
0005433367227	21707	9	6E
0005433367252	21707	10	6F
0005433367256	21707	11	7C
0005433367245	21707	12	7F
0005433367247	21707	13	8A
0005433367248	21707	14	8D
0005433367251	21707	15	8E
0005433367235	21707	16	9E
0005433367246	21707	17	10A
0005433367237	21707	18	10C
0005433367242	21707	19	10D
0005433367241	21707	20	10E
0005433367234	21707	21	10F
0005433367253	21707	22	11D
0005433367250	21707	23	11F
0005433367255	21707	24	13D
0005433367231	21707	25	13E
0005433367228	21707	26	14D
0005433367220	21707	27	14E
0005433367238	21707	28	15A
0005433367219	21707	29	15D
0005433367225	21707	30	16A
0005433367226	21707	31	16C
0005433367236	21707	32	16D
0005433367230	21707	33	17A
0005433367254	21707	34	17C
0005433367239	21707	35	18F
0005433367229	21707	36	19A
0005433367232	21707	37	19C
0005433367233	21707	38	19D
0005433367249	21707	39	19E
0005433367243	21707	40	20A
0005433367223	21707	41	20D
0005433985127	4135	1	1D
0005433985129	4135	2	1F
0005433985123	4135	3	2A
0005433985126	4135	4	2C
0005433985160	4135	5	2F
0005435788725	4135	6	3A
0005433985140	4135	7	3D
0005433985155	4135	8	3F
0005433985137	4135	9	4A
0005433985159	4135	10	4E
0005433985125	4135	11	5A
0005433985154	4135	12	5D
0005433985161	4135	13	5E
0005433985122	4135	14	5F
0005433985136	4135	15	7D
0005433985148	4135	16	8A
0005433985143	4135	17	8E
0005433985131	4135	18	9A
0005433985133	4135	19	9C
0005433985158	4135	20	9D
0005433985141	4135	21	10A
0005433985134	4135	22	10D
0005433985139	4135	23	10F
0005435788726	4135	24	11A
0005433985145	4135	25	11E
0005433985152	4135	26	12A
0005433985144	4135	27	12C
0005433985147	4135	28	12F
0005433985146	4135	29	13A
0005435788727	4135	30	13C
0005433985124	4135	31	13D
0005435788728	4135	32	13E
0005433985153	4135	33	14A
0005433985156	4135	34	14D
0005433985130	4135	35	14E
0005433985150	4135	36	17A
0005433985132	4135	37	17D
0005433985151	4135	38	17E
0005433985157	4135	39	18F
0005433985135	4135	40	19A
0005433985142	4135	41	19E
0005433985128	4135	42	19F
0005433985149	4135	43	20D
0005433985138	4135	44	20E
0005433168301	21332	1	3B
0005433168299	21332	2	3D
0005433168302	21332	3	6C
0005433168300	21332	4	20A
0005432869415	17856	1	3F
0005432869416	17856	2	8F
0005432869413	17856	3	9A
0005434151654	17856	4	12D
0005434151656	17856	5	18E
0005432869412	17856	6	19D
0005434151655	17856	7	20C
0005432869414	17856	8	20F
0005432327913	3108	1	1D
0005432327892	3108	2	2D
0005432327911	3108	3	2F
0005432327914	3108	4	3F
0005432287105	3108	5	4D
0005432287101	3108	6	4F
0005432287104	3108	7	4E
0005432327915	3108	8	5C
0005432327904	3108	9	5E
0005432327907	3108	10	5F
0005432327925	3108	11	6A
0005432327930	3108	12	6C
0005432327894	3108	13	6D
0005432287100	3108	14	6E
0005433438767	3108	15	6F
0005432327931	3108	16	7A
0005432327923	3108	17	7C
0005432327898	3108	18	7D
0005432327920	3108	19	7E
0005432327928	3108	20	8A
0005432327893	3108	21	8C
0005432327921	3108	22	8E
0005432327934	3108	23	8F
0005432327912	3108	24	9A
0005432327901	3108	25	9C
0005432327929	3108	26	9F
0005432327932	3108	27	10A
0005432287099	3108	28	10C
0005432327924	3108	29	10D
0005432327903	3108	30	10F
0005433438765	3108	31	11C
0005432327890	3108	32	11E
0005432327896	3108	33	11F
0005433438764	3108	34	12A
0005433438763	3108	35	12C
0005432327917	3108	36	12D
0005432327906	3108	37	13A
0005432327910	3108	38	13C
0005432287103	3108	39	13D
0005432327919	3108	40	13E
0005432327895	3108	41	13F
0005432327926	3108	42	14C
0005432327899	3108	43	14D
0005432327902	3108	44	14E
0005432327897	3108	45	15A
0005432327909	3108	46	15C
0005432287102	3108	47	16D
0005433438766	3108	48	17A
0005432327937	3108	49	17C
0005432327891	3108	50	17E
0005432327922	3108	51	17F
0005432327905	3108	52	18C
0005432327935	3108	53	18D
0005432327900	3108	54	18F
0005432327927	3108	55	19A
0005432327936	3108	56	19C
0005432327918	3108	57	19D
0005432327908	3108	58	20A
0005432327916	3108	59	20D
0005432327933	3108	60	20F
0005432905025	31103	1	3F
0005432054254	31103	2	4C
0005432905022	31103	3	7E
0005432905024	31103	4	11E
0005432905023	31103	5	12E
0005432054252	31103	6	13C
0005432905019	31103	7	13F
0005432905020	31103	8	14D
0005432905021	31103	9	15C
0005432054253	31103	10	19C
0005434309500	6223	1	1A
0005434309510	6223	2	1D
0005432146164	6223	3	2D
0005434309502	6223	4	3F
0005435998953	6223	5	5C
0005435998957	6223	6	5E
0005434309511	6223	7	6C
0005435998963	6223	8	6E
0005434309508	6223	9	7A
0005434309506	6223	10	7C
0005435998956	6223	11	8C
0005435998965	6223	12	9E
0005434309509	6223	13	10B
0005435998964	6223	14	11E
0005435998952	6223	15	11F
0005435998959	6223	16	12F
0005434309501	6223	17	13E
0005435998962	6223	18	14A
0005434309513	6223	19	14C
0005434309512	6223	20	14D
0005435998958	6223	21	16A
0005435998954	6223	22	17C
0005432146163	6223	23	18A
0005435998966	6223	24	18C
0005435998961	6223	25	18E
0005434309505	6223	26	18F
0005435998960	6223	27	19A
0005434309507	6223	28	19E
0005434309503	6223	29	19F
0005435998967	6223	30	20A
0005434309504	6223	31	20E
0005432146165	6223	32	21B
0005435998955	6223	33	23A
0005435998951	6223	34	23E
0005435296942	19528	1	1D
0005435296939	19528	2	2F
0005435296941	19528	3	7A
0005435296938	19528	4	7D
0005435296943	19528	5	7F
0005435296940	19528	6	16E
0005433158094	17534	1	21B
0005433158093	17534	2	22B
0005435501945	1567	1	1A
0005435508176	1567	2	1C
0005435501931	1567	3	1F
0005434565681	1567	4	2C
0005435501933	1567	5	2D
0005434565690	1567	6	3C
0005435517599	1567	7	3D
0005435508167	1567	8	3F
0005435501932	1567	9	4A
0005435501936	1567	10	4C
0005435501950	1567	11	4D
0005434565688	1567	12	5A
0005435517590	1567	13	5D
0005435517605	1567	14	5F
0005435508174	1567	15	6C
0005435501947	1567	16	6D
0005432291890	1567	17	6E
0005435508166	1567	18	6F
0005435501941	1567	19	7A
0005434565686	1567	20	7C
0005435517602	1567	21	7D
0005435517591	1567	22	7E
0005434565678	1567	23	7F
0005435517595	1567	24	8A
0005435501937	1567	25	8D
0005435508164	1567	26	8E
0005434565684	1567	27	8F
0005435501943	1567	28	9A
0005434565687	1567	29	9E
0005435517604	1567	30	9F
0005435501948	1567	31	10A
0005435517596	1567	32	10D
0005435501946	1567	33	10E
0005435517603	1567	34	11A
0005432291889	1567	35	11C
0005435517594	1567	36	11D
0005435508173	1567	37	11E
0005435501944	1567	38	11F
0005434565679	1567	39	12A
0005435508171	1567	40	12C
0005435517600	1567	41	12D
0005434565682	1567	42	12E
0005435508170	1567	43	13A
0005435501952	1567	44	13C
0005435501935	1567	45	13D
0005435508165	1567	46	13E
0005435501938	1567	47	13F
0005435508175	1567	48	14A
0005434565689	1567	49	14C
0005435517585	1567	50	14D
0005435517601	1567	51	14E
0005435517587	1567	52	15A
0005435501949	1567	53	14F
0005435517598	1567	54	15C
0005434565691	1567	55	15D
0005435517589	1567	56	15E
0005435508168	1567	57	15F
0005435517588	1567	58	16C
0005435501940	1567	59	16F
0005435501951	1567	60	17A
0005434565677	1567	61	17C
0005434565685	1567	62	17E
0005435517592	1567	63	18A
0005435501942	1567	64	18C
0005434565683	1567	65	18D
0005435517597	1567	66	18E
0005435501934	1567	67	18F
0005435508169	1567	68	19C
0005435517593	1567	69	19D
0005435517586	1567	70	19F
0005435501939	1567	71	20A
0005435517606	1567	72	20D
0005434565680	1567	73	20E
0005435508172	1567	74	20F
0005433185971	20846	1	2A
0005433185974	20846	2	3A
0005433185975	20846	3	4D
0005433185970	20846	4	5C
0005433185968	20846	5	6F
0005433185969	20846	6	7E
0005433185973	20846	7	18C
0005433185972	20846	8	20F
0005435153627	3925	1	1B
0005435153628	3925	2	2D
0005435153626	3925	3	3B
0005435153631	3925	4	7C
0005435153629	3925	5	18D
0005435153630	3925	6	20D
0005435931536	21848	1	6C
0005435931538	21848	2	18C
0005435931537	21848	3	22D
0005432628586	7226	1	1A
0005432628591	7226	2	2D
0005432628592	7226	3	3D
0005432628588	7226	4	4B
0005432628593	7226	5	4D
0005432628595	7226	6	5C
0005432628596	7226	7	5D
0005432628597	7226	8	6A
0005432628599	7226	9	18A
0005432628594	7226	10	19A
0005432628589	7226	11	20A
0005432628590	7226	12	20C
0005432628585	7226	13	21A
0005432628598	7226	14	21B
0005432628587	7226	15	22C
0005435225447	28100	1	2A
0005435225445	28100	2	18D
0005435225446	28100	3	19A
0005435225449	28100	4	20D
0005435225444	28100	5	21A
0005435225443	28100	6	22A
0005435225448	28100	7	22B
0005435959984	8719	1	6C
0005435959983	8719	2	7C
0005435959985	8719	3	18A
0005435959982	8719	4	20A
0005434267884	15264	1	2A
0005434267885	15264	2	3B
0005434267886	15264	3	5A
0005432674869	1214	1	2A
0005432674874	1214	2	2F
0005432674868	1214	3	3C
0005432674866	1214	4	3F
0005432674876	1214	5	4C
0005432674865	1214	6	5A
0005432674875	1214	7	7D
0005432674873	1214	8	8C
0005432674872	1214	9	10A
0005432674867	1214	10	14F
0005432674871	1214	11	17E
0005432674863	1214	12	18F
0005432674870	1214	13	19B
0005432674877	1214	14	19F
0005432674864	1214	15	20B
0005432873167	17509	1	3D
0005432873168	17509	2	3C
0005432873172	17509	3	5A
0005432873165	17509	4	7A
0005432873171	17509	5	7F
0005432873166	17509	6	10D
0005432873173	17509	7	14C
0005432873169	17509	8	17C
0005432873170	17509	9	20D
0005434434912	1127	1	2A
0005434434913	1127	2	2B
0005434434915	1127	3	3C
0005434434918	1127	4	3D
0005434434919	1127	5	4C
0005434434922	1127	6	5B
0005434434924	1127	7	5C
0005434434910	1127	8	7B
0005434434914	1127	9	18B
0005434434909	1127	10	19C
0005434434921	1127	11	19D
0005434434911	1127	12	20D
0005434434920	1127	13	21B
0005434434916	1127	14	21C
0005434434917	1127	15	22A
0005434434923	1127	16	22D
0005433156598	17301	1	1C
0005433156599	17301	2	2B
0005433156605	17301	3	3D
0005433156604	17301	4	4A
0005433156597	17301	5	4C
0005433156603	17301	6	20A
0005433156600	17301	7	21D
0005433156602	17301	8	22C
0005433156601	17301	9	22D
0005435086706	4103	1	2D
0005435086702	4103	2	3A
0005435086704	4103	3	5A
0005435086703	4103	4	19D
0005435086701	4103	5	21C
0005435086705	4103	6	22B
0005435086700	4103	7	22D
0005435928060	24384	1	1B
0005435928061	24384	2	2D
0005435928057	24384	3	3A
0005435928059	24384	4	7B
0005435928058	24384	5	19A
0005435551493	17003	1	3F
0005435551492	17003	2	4A
0005435551491	17003	3	4G
0005435098522	17003	4	13F
0005435098521	17003	5	14H
0005435551490	17003	6	20F
0005434625797	4822	1	4D
0005434625796	4822	2	6D
0005434625798	4822	3	8A
0005434625793	4822	4	10E
0005434625802	4822	5	11D
0005434625799	4822	6	12F
0005434625794	4822	7	14F
0005434625801	4822	8	19A
0005434625795	4822	9	19F
0005434625800	4822	10	20C
0005435907416	32920	1	1D
0005435907418	32920	2	5F
0005433194818	32920	3	9E
0005435907417	32920	4	11A
0005433194819	32920	5	11F
0005435907419	32920	6	13E
0005435907420	32920	7	15F
0005433194817	32920	8	19F
0005432195657	13777	1	2D
0005432195655	13777	2	3C
0005435937312	13777	3	5A
0005435937307	13777	4	5D
0005435937313	13777	5	18B
0005435937310	13777	6	18D
0005435937306	13777	7	19A
0005432195656	13777	8	19B
0005435937308	13777	9	19D
0005435937309	13777	10	20A
0005435937305	13777	11	21A
0005435937311	13777	12	22A
0005435310836	20272	1	1F
0005435310855	20272	2	2A
0005435310841	20272	3	2C
0005435310846	20272	4	3C
0005435310848	20272	5	3D
0005435310840	20272	6	4F
0005435310854	20272	7	6D
0005432058315	20272	8	7E
0005435310851	20272	9	8D
0005435310849	20272	10	9A
0005435310847	20272	11	9C
0005432058313	20272	12	11F
0005435310844	20272	13	12E
0005435310842	20272	14	14D
0005435310839	20272	15	14F
0005435310845	20272	16	15E
0005435310852	20272	17	15F
0005435310838	20272	18	16D
0005435310837	20272	19	16F
0005435310853	20272	20	17E
0005435310843	20272	21	17F
0005435310850	20272	22	18F
0005432058314	20272	23	19A
0005432058312	20272	24	20F
0005434406641	26958	1	1A
0005432153814	26958	2	1C
0005434406650	26958	3	1D
0005434406669	26958	4	2C
0005434406689	26958	5	2D
0005434406685	26958	6	2F
0005434406643	26958	7	3A
0005434406668	26958	8	3C
0005434406665	26958	9	3D
0005434406695	26958	10	3F
0005432153813	26958	11	4C
0005434406651	26958	12	4E
0005434406654	26958	13	4F
0005434406642	26958	14	5A
0005434406683	26958	15	5C
0005432153815	26958	16	5D
0005434406649	26958	17	5E
0005434406646	26958	18	6A
0005434406701	26958	19	6C
0005432153817	26958	20	6F
0005434406678	26958	21	7A
0005434406690	26958	22	7D
0005434406667	26958	23	7E
0005434406658	26958	24	7F
0005434406679	26958	25	8A
0005434406674	26958	26	8C
0005434406639	26958	27	8F
0005434406673	26958	28	9A
0005434406691	26958	29	9C
0005434406700	26958	30	9E
0005434406656	26958	31	10A
0005434406692	26958	32	10F
0005434406681	26958	33	11A
0005434406666	26958	34	11C
0005434406640	26958	35	11D
0005434406682	26958	36	11E
0005434406670	26958	37	11F
0005434406661	26958	38	12C
0005434406698	26958	39	12D
0005434406662	26958	40	12E
0005434406676	26958	41	12F
0005434406696	26958	42	13A
0005434406653	26958	43	13D
0005434406652	26958	44	13E
0005434406687	26958	45	14D
0005434406677	26958	46	14F
0005434406645	26958	47	15C
0005434406680	26958	48	15D
0005434406693	26958	49	15E
0005434406644	26958	50	15F
0005432153819	26958	51	16A
0005434406659	26958	52	16C
0005434406664	26958	53	16D
0005434406660	26958	54	16E
0005434406655	26958	55	16F
0005434406657	26958	56	17A
0005434406699	26958	57	17C
0005434406671	26958	58	17D
0005434406675	26958	59	17F
0005434406647	26958	60	18C
0005434406686	26958	61	18D
0005434406684	26958	62	18E
0005434406663	26958	63	18F
0005434406697	26958	64	19A
0005434406648	26958	65	19C
0005432153818	26958	66	19D
0005434406672	26958	67	20C
0005432153816	26958	68	20D
0005434406694	26958	69	20E
0005434406688	26958	70	20F
0005434319150	5671	1	2D
0005434319142	5671	2	4F
0005434319149	5671	3	6F
0005434311182	5671	4	7F
0005432109655	5671	5	8D
0005432109656	5671	6	10E
0005434319144	5671	7	10F
0005434319148	5671	8	11F
0005434319143	5671	9	12C
0005434319141	5671	10	13E
0005434319147	5671	11	14F
0005434319145	5671	12	16D
0005434311181	5671	13	16E
0005434319146	5671	14	18E
0005433123577	15695	1	2C
0005433123582	15695	2	2F
0005433123571	15695	3	4A
0005433123580	15695	4	4C
0005433123578	15695	5	6C
0005433123566	15695	6	7C
0005433123573	15695	7	8C
0005433123574	15695	8	11C
0005433123586	15695	9	11D
0005433123587	15695	10	11E
0005433123569	15695	11	12C
0005433123568	15695	12	12D
0005433123575	15695	13	13A
0005433123584	15695	14	13F
0005433123567	15695	15	14A
0005433123565	15695	16	15A
0005433123570	15695	17	15C
0005433123585	15695	18	15E
0005433123583	15695	19	16A
0005433123579	15695	20	17F
0005433123572	15695	21	18F
0005433123581	15695	22	20E
0005433123576	15695	23	20F
0005435219165	31748	1	3C
0005435220283	31748	2	21D
0005435220284	31748	3	22D
0005434484235	9001	1	2B
0005434484231	9001	2	4B
0005434484237	9001	3	4D
0005434484234	9001	4	6B
0005434484236	9001	5	6C
0005434484232	9001	6	18B
0005434484233	9001	7	21B
0005434189075	16620	1	4B
0005434189079	16620	2	6A
0005434189076	16620	3	20C
0005434189077	16620	4	20D
0005434189078	16620	5	21A
0005434189080	16620	6	22B
0005433123582	7571	1	1C
0005433123572	7571	2	2F
0005433123565	7571	3	3C
0005433123574	7571	4	4A
0005433123570	7571	5	4C
0005433123583	7571	6	4F
0005433123581	7571	7	5F
0005433123573	7571	8	7F
0005433123580	7571	9	8D
0005433123566	7571	10	10C
0005433123576	7571	11	11E
0005433123567	7571	12	13D
0005433123584	7571	13	14D
0005433123586	7571	14	15D
0005433123587	7571	15	16A
0005433123579	7571	16	17A
0005433123585	7571	17	17D
0005433123578	7571	18	17F
0005433123577	7571	19	19C
0005433123575	7571	20	19E
0005433123569	7571	21	19F
0005433123568	7571	22	20A
0005433123571	7571	23	20D
0005432720450	7572	1	1C
0005432692555	7572	2	1D
0005432692532	7572	3	1F
0005432720453	7572	4	2A
0005432720446	7572	5	2C
0005432692535	7572	6	2F
0005432720452	7572	7	3D
0005433449584	7572	8	3F
0005432720442	7572	9	4A
0005432720448	7572	10	4C
0005432720447	7572	11	4D
0005432720455	7572	12	4E
0005433449583	7572	13	4F
0005432720435	7572	14	5A
0005432692528	7572	15	5C
0005432692539	7572	16	5D
0005432720433	7572	17	5E
0005432692547	7572	18	5F
0005432720444	7572	19	6A
0005432692527	7572	20	6C
0005433449590	7572	21	6D
0005432692536	7572	22	6E
0005433449604	7572	23	6F
0005432720445	7572	24	7A
0005432692552	7572	25	7C
0005432692542	7572	26	7D
0005432692545	7572	27	7E
0005432720440	7572	28	7F
0005433449595	7572	29	8A
0005432720429	7572	30	8C
0005432720454	7572	31	8D
0005432692534	7572	32	8E
0005432692529	7572	33	8F
0005432692541	7572	34	9A
0005432071520	7572	35	9C
0005432720451	7572	36	9D
0005433449588	7572	37	9E
0005433449601	7572	38	9F
0005432720430	7572	39	10A
0005432720437	7572	40	10C
0005432720439	7572	41	10D
0005432071522	7572	42	10F
0005433449593	7572	43	11A
0005433449586	7572	44	11C
0005432692543	7572	45	11D
0005432720436	7572	46	11E
0005432720449	7572	47	11F
0005432720434	7572	48	12A
0005433449592	7572	49	12C
0005432692549	7572	50	12D
0005432692557	7572	51	12E
0005433449599	7572	52	13A
0005433449591	7572	53	13C
0005432692553	7572	54	13D
0005432720443	7572	55	13E
0005432071521	7572	56	13F
0005432720428	7572	57	14A
0005432692537	7572	58	14C
0005432720438	7572	59	14E
0005432692551	7572	60	15D
0005432692540	7572	61	15C
0005433449597	7572	62	15E
0005432692546	7572	63	15F
0005432692530	7572	64	16A
0005432692554	7572	65	16C
0005432692550	7572	66	16D
0005433449598	7572	67	16E
0005432720432	7572	68	16F
0005432692533	7572	69	17A
0005432692548	7572	70	17C
0005432692531	7572	71	17D
0005433449603	7572	72	17E
0005432692556	7572	73	17F
0005433449600	7572	74	18A
0005433449587	7572	75	18C
0005432692558	7572	76	18D
0005433449602	7572	77	18F
0005433449596	7572	78	18E
0005433449589	7572	79	19A
0005433449605	7572	80	19C
0005433449594	7572	81	19D
0005432692544	7572	82	19E
0005432720441	7572	83	20A
0005432720431	7572	84	20C
0005433449585	7572	85	20E
0005432692538	7572	86	20F
0005433722106	30450	1	2C
0005433722105	30450	2	4E
0005433722104	30450	3	9D
0005433722102	30450	4	12E
0005433722103	30450	5	15F
0005434586172	1368	1	1A
0005434513533	1368	2	1C
0005434586169	1368	3	2A
0005434586179	1368	4	2D
0005434586161	1368	5	2F
0005433524846	1368	6	3A
0005434514921	1368	7	3C
0005433524850	1368	8	3F
0005432270954	1368	9	4C
0005434586160	1368	10	4D
0005433524855	1368	11	4E
0005434586164	1368	12	5A
0005434586171	1368	13	5E
0005432270955	1368	14	6A
0005434586165	1368	15	6F
0005434586162	1368	16	7A
0005434586158	1368	17	7C
0005433524853	1368	18	7D
0005434586177	1368	19	7E
0005434586176	1368	20	7F
0005434586163	1368	21	8D
0005433524851	1368	22	9F
0005432270956	1368	23	10D
0005433524852	1368	24	10E
0005434586181	1368	25	11A
0005434586159	1368	26	11E
0005433524854	1368	27	11F
0005433724726	1368	28	12A
0005433524849	1368	29	12C
0005434586173	1368	30	12E
0005433724727	1368	31	13A
0005434586174	1368	32	13D
0005434513534	1368	33	14C
0005434586182	1368	34	14F
0005434586180	1368	35	15A
0005433724724	1368	36	15D
0005434586157	1368	37	16C
0005434514922	1368	38	16D
0005434586170	1368	39	16E
0005434586167	1368	40	16F
0005434586166	1368	41	17C
0005434586168	1368	42	17D
0005433724725	1368	43	17E
0005434513535	1368	44	18C
0005434586178	1368	45	19C
0005433524848	1368	46	19F
0005434586175	1368	47	20C
0005433524847	1368	48	20D
0005434514923	1368	49	20E
0005433192815	18514	1	4A
0005433192818	18514	2	7D
0005433192812	18514	3	9E
0005433192814	18514	4	9F
0005433192813	18514	5	10A
0005433192816	18514	6	10C
0005433192817	18514	7	11C
0005433192809	18514	8	12E
0005433192810	18514	9	18D
0005433192821	18514	10	19A
0005433192811	18514	11	19D
0005433192820	18514	12	20C
0005433192819	18514	13	20E
0005434142542	11429	1	5A
0005434142541	11429	2	7D
0005434142540	11429	3	20D
0005434142543	11429	4	21B
0005435304095	29766	1	7C
0005435304096	29766	2	7D
0005435304092	29766	3	18D
0005435304094	29766	4	19C
0005435304093	29766	5	20A
0005435304989	29766	6	23A
0005435824155	1287	1	1F
0005435824160	1287	2	2C
0005435824158	1287	3	4A
0005435824164	1287	4	5C
0005435824154	1287	5	6E
0005435824172	1287	6	7B
0005435824173	1287	7	6F
0005435824151	1287	8	8B
0005435824161	1287	9	8A
0005435824169	1287	10	8E
0005435824177	1287	11	9F
0005435824178	1287	12	9E
0005435824156	1287	13	10B
0005435824175	1287	14	10D
0005432284506	1287	15	11A
0005435824170	1287	16	11B
0005435824167	1287	17	12C
0005435824171	1287	18	12E
0005435824162	1287	19	13A
0005435824174	1287	20	13F
0005435824163	1287	21	14C
0005432284505	1287	22	16A
0005435824157	1287	23	16C
0005435824153	1287	24	16D
0005435824165	1287	25	16E
0005432284508	1287	26	17B
0005435824168	1287	27	18D
0005432284507	1287	28	19B
0005435824166	1287	29	19D
0005435824176	1287	30	20A
0005435824159	1287	31	19E
0005435824152	1287	32	20B
0005433415388	17980	1	4A
0005433415381	17980	2	5C
0005433415385	17980	3	6F
0005433415389	17980	4	7B
0005433415384	17980	5	9D
0005433415391	17980	6	9C
0005433415380	17980	7	12E
0005433415383	17980	8	13A
0005433415390	17980	9	14E
0005433415378	17980	10	15B
0005433415379	17980	11	16D
0005433415386	17980	12	17A
0005433415392	17980	13	18A
0005433415382	17980	14	18C
0005433415393	17980	15	20E
0005433415387	17980	16	21A
0005432143931	5615	1	1A
0005432782863	5615	2	1D
0005432782838	5615	3	1F
0005432782841	5615	4	2A
0005432782840	5615	5	2F
0005432782847	5615	6	3A
0005432782887	5615	7	3C
0005432782888	5615	8	4C
0005432782870	5615	9	4D
0005432782872	5615	10	4E
0005432143932	5615	11	5A
0005432782850	5615	12	5C
0005432782849	5615	13	5F
0005432782889	5615	14	6A
0005432782871	5615	15	6C
0005432782857	5615	16	6D
0005432782873	5615	17	7A
0005432782877	5615	18	7C
0005432782858	5615	19	7D
0005432782854	5615	20	7F
0005432782892	5615	21	8D
0005432782864	5615	22	8F
0005432782851	5615	23	9A
0005432782848	5615	24	9D
0005432782891	5615	25	9E
0005432782860	5615	26	9F
0005432782861	5615	27	10A
0005432782880	5615	28	10C
0005432782882	5615	29	10E
0005432782853	5615	30	10F
0005432782839	5615	31	11E
0005432782881	5615	32	11F
0005432782883	5615	33	12A
0005432782842	5615	34	12C
0005432782879	5615	35	12D
0005432782876	5615	36	12E
0005432782869	5615	37	13A
0005432782859	5615	38	13C
0005432782867	5615	39	13D
0005432782855	5615	40	14A
0005432782845	5615	41	14E
0005432782884	5615	42	15C
0005432782886	5615	43	16A
0005432782874	5615	44	16E
0005432782846	5615	45	17C
0005432143930	5615	46	17F
0005432782878	5615	47	18A
0005432782843	5615	48	18C
0005432143929	5615	49	18F
0005432782865	5615	50	19A
0005432782890	5615	51	19C
0005432782856	5615	52	19D
0005432782875	5615	53	19E
0005432782862	5615	54	19F
0005432782868	5615	55	20A
0005432782885	5615	56	20C
0005432782852	5615	57	20D
0005432782844	5615	58	20E
0005432782866	5615	59	20F
0005435476637	15345	1	1C
0005435476646	15345	2	4C
0005435476647	15345	3	4D
0005435476640	15345	4	5A
0005435476634	15345	5	5D
0005435476636	15345	6	6F
0005435476643	15345	7	8A
0005435476645	15345	8	12F
0005435476635	15345	9	14A
0005435476641	15345	10	14E
0005435476639	15345	11	15C
0005435476642	15345	12	16F
0005435476638	15345	13	18D
0005435476648	15345	14	20A
0005435476644	15345	15	20F
0005432848055	4384	1	1B
0005432848056	4384	2	2C
0005434462753	4384	3	2D
0005432848057	4384	4	3C
0005432848064	4384	5	3D
0005432848059	4384	6	4B
0005432848066	4384	7	5A
0005432848062	4384	8	5D
0005432848067	4384	9	7C
0005434463892	4384	10	7D
0005434463891	4384	11	18D
0005432848060	4384	12	19C
0005432848061	4384	13	20C
0005432848070	4384	14	21A
0005432848068	4384	15	21C
0005432848058	4384	16	22A
0005432848065	4384	17	22B
0005434462752	4384	18	22C
0005432848069	4384	19	23A
0005432848063	4384	20	23B
0005435850752	28883	1	1B
0005435850751	28883	2	2C
0005435850756	28883	3	4D
0005435850750	28883	4	5B
0005435850754	28883	5	18C
0005435850755	28883	6	19A
0005435850753	28883	7	21C
0005435850757	28883	8	22B
0005433496438	6253	1	1A
0005433496444	6253	2	1D
0005433496449	6253	3	1F
0005434443432	6253	4	2A
0005434925249	6253	5	2C
0005433496435	6253	6	2F
0005433496432	6253	7	3C
0005434443436	6253	8	3F
0005433496431	6253	9	4A
0005434925247	6253	10	4C
0005434925256	6253	11	4E
0005434925264	6253	12	4D
0005434443433	6253	13	5C
0005434925254	6253	14	5D
0005434443427	6253	15	5E
0005434925265	6253	16	5F
0005434443424	6253	17	6D
0005433496436	6253	18	6E
0005434925250	6253	19	6F
0005434925263	6253	20	7C
0005434925269	6253	21	7D
0005434925255	6253	22	7F
0005433496430	6253	23	7E
0005434925266	6253	24	8D
0005433496418	6253	25	8E
0005434443434	6253	26	8F
0005432075169	6253	27	9A
0005433496447	6253	28	9C
0005434443438	6253	29	9D
0005433496433	6253	30	9F
0005434925270	6253	31	10C
0005433496420	6253	32	10E
0005434925258	6253	33	10F
0005433496445	6253	34	11A
0005434925248	6253	35	11C
0005433496422	6253	36	11D
0005434443439	6253	37	11F
0005434925268	6253	38	12A
0005433496421	6253	39	12C
0005434925251	6253	40	12D
0005434925271	6253	41	12E
0005433496428	6253	42	12F
0005433496425	6253	43	13A
0005433496434	6253	44	13C
0005434925253	6253	45	13D
0005434925260	6253	46	13E
0005433496429	6253	47	13F
0005433496427	6253	48	14A
0005432075170	6253	49	14C
0005434443425	6253	50	14D
0005433496424	6253	51	14E
0005434443435	6253	52	14F
0005434925259	6253	53	15A
0005433496423	6253	54	15C
0005434443429	6253	55	15D
0005434443428	6253	56	16D
0005434443426	6253	57	16E
0005433496442	6253	58	16F
0005433496441	6253	59	17A
0005434443431	6253	60	17C
0005434925261	6253	61	17D
0005434925257	6253	62	17E
0005433496440	6253	63	17F
0005433496446	6253	64	18A
0005433496426	6253	65	18D
0005432075171	6253	66	18E
0005433496437	6253	67	18F
0005434925272	6253	68	19A
0005434925252	6253	69	19C
0005433496439	6253	70	19D
0005433496419	6253	71	19E
0005434925262	6253	72	19F
0005434443437	6253	73	20A
0005433496443	6253	74	20C
0005434925267	6253	75	20D
0005433496448	6253	76	20E
0005434443430	6253	77	20F
0005435242399	12211	1	1A
0005435242390	12211	2	3C
0005435242389	12211	3	3D
0005435242409	12211	4	3F
0005435242393	12211	5	5C
0005435242400	12211	6	5D
0005435242403	12211	7	7C
0005435242404	12211	8	7F
0005435242394	12211	9	9C
0005435242401	12211	10	9D
0005435242414	12211	11	9E
0005435242413	12211	12	9F
0005435242396	12211	13	11C
0005435242410	12211	14	11E
0005435242411	12211	15	11F
0005435242398	12211	16	12A
0005435242407	12211	17	13A
0005435242391	12211	18	13C
0005435242395	12211	19	14F
0005435242388	12211	20	15A
0005435242408	12211	21	15C
0005435242392	12211	22	15E
0005435242405	12211	23	16C
0005435242402	12211	24	16D
0005435242412	12211	25	16E
0005435242406	12211	26	17A
0005435242387	12211	27	17C
0005435242415	12211	28	19C
0005435242397	12211	29	20C
0005435913849	10095	1	5D
0005434910069	10095	2	6E
0005434910068	10095	3	15C
0005434910070	10095	4	16D
0005435913850	10095	5	18D
0005434876590	14602	1	1C
0005434876598	14602	2	1A
0005434876624	14602	3	1D
0005434876582	14602	4	2C
0005434876616	14602	5	2A
0005434876615	14602	6	2D
0005434876569	14602	7	3A
0005434876638	14602	8	3D
0005434876620	14602	9	3C
0005434876608	14602	10	4A
0005434876636	14602	11	3F
0005434876555	14602	12	4D
0005434876601	14602	13	4C
0005434876617	14602	14	4F
0005434876593	14602	15	5C
0005434876610	14602	16	5F
0005434876564	14602	17	5D
0005434876629	14602	18	6A
0005434876650	14602	19	6C
0005434876648	14602	20	6F
0005434876621	14602	21	6E
0005434876574	14602	22	6D
0005434876618	14602	23	7A
0005434876641	14602	24	7C
0005434876579	14602	25	7B
0005434876565	14602	26	7D
0005434876635	14602	27	7F
0005434758853	14602	28	7E
0005434876557	14602	29	8B
0005434876600	14602	30	8D
0005434876558	14602	31	8C
0005434876611	14602	32	8F
0005434876563	14602	33	9B
0005434876570	14602	34	9A
0005434876637	14602	35	9C
0005434876583	14602	36	9E
0005434876639	14602	37	9D
0005434876573	14602	38	10B
0005434876612	14602	39	10A
0005434876595	14602	40	9F
0005434876626	14602	41	10C
0005434876592	14602	42	10E
0005434876580	14602	43	10D
0005434876560	14602	44	11A
0005434876586	14602	45	10F
0005434876568	14602	46	11C
0005434876581	14602	47	11B
0005434876619	14602	48	11F
0005434876607	14602	49	11E
0005434876609	14602	50	12B
0005434876559	14602	51	12A
0005434876614	14602	52	12D
0005434876603	14602	53	12C
0005434876651	14602	54	12E
0005434758854	14602	55	13A
0005434876649	14602	56	12F
0005434876633	14602	57	13C
0005434758852	14602	58	13B
0005434876606	14602	59	13E
0005434876562	14602	60	13D
0005434876646	14602	61	13F
0005434876596	14602	62	14B
0005434876561	14602	63	14D
0005434876556	14602	64	14C
0005434876634	14602	65	14F
0005434876631	14602	66	15B
0005434876640	14602	67	15A
0005434876625	14602	68	15C
0005434876623	14602	69	15F
0005434876627	14602	70	15E
0005434876575	14602	71	16A
0005434876597	14602	72	16C
0005434876588	14602	73	16B
0005434876642	14602	74	16F
0005434876572	14602	75	16E
0005434876587	14602	76	17C
0005434876585	14602	77	17B
0005434876605	14602	78	17F
0005434876602	14602	79	17E
0005434876628	14602	80	18B
0005434876589	14602	81	18A
0005434876567	14602	82	18C
0005434876599	14602	83	18D
0005434876647	14602	84	19A
0005434876645	14602	85	18F
0005434876644	14602	86	19B
0005434876591	14602	87	19E
0005434876576	14602	88	19D
0005434876632	14602	89	20B
0005434876604	14602	90	20A
0005434876566	14602	91	20D
0005434876578	14602	92	20C
0005434876594	14602	93	20F
0005434876622	14602	94	20E
0005434876584	14602	95	21A
0005434876571	14602	96	21C
0005434876643	14602	97	21B
0005434876577	14602	98	21E
0005434876630	14602	99	21D
0005434876613	14602	100	21F
0005435659943	9262	1	1A
0005435659937	9262	2	1B
0005435659948	9262	3	1C
0005435659946	9262	4	3A
0005435659939	9262	5	4C
0005435659941	9262	6	4D
0005435659940	9262	7	5A
0005435659944	9262	8	5D
0005435659938	9262	9	20A
0005435659945	9262	10	21C
0005435659947	9262	11	21D
0005435659942	9262	12	22A
0005434251798	24676	1	1D
0005434251800	24676	2	2A
0005434251802	24676	3	2B
0005434251795	24676	4	4C
0005434251801	24676	5	5B
0005434251797	24676	6	5C
0005434251804	24676	7	6B
0005434251803	24676	8	6C
0005434251796	24676	9	7A
0005434251799	24676	10	18B
0005433679726	2796	1	1A
0005433679724	2796	2	1C
0005433679740	2796	3	1D
0005433679728	2796	4	1F
0005433679715	2796	5	2A
0005432222688	2796	6	2D
0005433679754	2796	7	3C
0005432222690	2796	8	4A
0005433679717	2796	9	4C
0005433679752	2796	10	4D
0005433679718	2796	11	4E
0005433679716	2796	12	5C
0005433679745	2796	13	5D
0005433679731	2796	14	5E
0005433679727	2796	15	6A
0005433679747	2796	16	6C
0005433679719	2796	17	6D
0005433679755	2796	18	6E
0005433679734	2796	19	7A
0005433679710	2796	20	7E
0005433679733	2796	21	7F
0005433679722	2796	22	8C
0005433679744	2796	23	8E
0005433679739	2796	24	8F
0005433679732	2796	25	10A
0005433679729	2796	26	10C
0005433679713	2796	27	10E
0005433679711	2796	28	11A
0005433679720	2796	29	12C
0005433679736	2796	30	12D
0005433679750	2796	31	12E
0005433679748	2796	32	12F
0005432222691	2796	33	13A
0005433679741	2796	34	13D
0005433679742	2796	35	13E
0005433679749	2796	36	13F
0005432222689	2796	37	14A
0005433679709	2796	38	14C
0005433679725	2796	39	14D
0005433679721	2796	40	14F
0005433679756	2796	41	15A
0005433679751	2796	42	15D
0005433679723	2796	43	16C
0005433679737	2796	44	16F
0005433679746	2796	45	17A
0005433679743	2796	46	17C
0005433679730	2796	47	17F
0005433679735	2796	48	18A
0005433679738	2796	49	18C
0005433679753	2796	50	18F
0005433679712	2796	51	19C
0005433679714	2796	52	19D
0005432222692	2796	53	20C
0005432966502	29150	1	2C
0005432966499	29150	2	3A
0005432966486	29150	3	3C
0005432966482	29150	4	3F
0005432966494	29150	5	4A
0005432966495	29150	6	4C
0005432966489	29150	7	4D
0005432966504	29150	8	5C
0005432966492	29150	9	6C
0005432966480	29150	10	6D
0005432966497	29150	11	7F
0005432005165	29150	12	8A
0005432966483	29150	13	8F
0005432005164	29150	14	9A
0005432966503	29150	15	10C
0005432966498	29150	16	11A
0005432966491	29150	17	13C
0005432966493	29150	18	13E
0005432966479	29150	19	13F
0005432966481	29150	20	14E
0005432966496	29150	21	14F
0005432966488	29150	22	15C
0005432966500	29150	23	16A
0005432966484	29150	24	16C
0005432966501	29150	25	16E
0005432005163	29150	26	17C
0005432966487	29150	27	17E
0005432966485	29150	28	18A
0005432966490	29150	29	18D
0005433577568	9307	1	3A
0005433577564	9307	2	4C
0005433577563	9307	3	6A
0005433577565	9307	4	6F
0005432755016	9307	5	7F
0005432756789	9307	6	8A
0005433577567	9307	7	8C
0005433577572	9307	8	10B
0005433577566	9307	9	10E
0005432755017	9307	10	12B
0005433577571	9307	11	14B
0005432756787	9307	12	14F
0005433577562	9307	13	19B
0005432755015	9307	14	20B
0005433577573	9307	15	20C
0005433577570	9307	16	25B
0005433577569	9307	17	26A
0005432756788	9307	18	27A
0005433577561	9307	19	30C
0005432184902	4199	1	2C
0005435986654	4199	2	13B
0005435986650	4199	3	13G
0005435986652	4199	4	15H
0005435986649	4199	5	21E
0005432184901	4199	6	24B
0005435986653	4199	7	28A
0005432184900	4199	8	33B
0005435986651	4199	9	38E
0005435947005	26588	1	1A
0005432571260	26588	2	1H
0005432571259	26588	3	3B
0005435947001	26588	4	4A
0005435947010	26588	5	5C
0005435947004	26588	6	11G
0005435856131	26588	7	13A
0005435947003	26588	8	14A
0005435946996	26588	9	18E
0005435947000	26588	10	18D
0005435787321	26588	11	19F
0005432571257	26588	12	20E
0005435946997	26588	13	23H
0005435947009	26588	14	30F
0005432571258	26588	15	30G
0005435946998	26588	16	31G
0005435947006	26588	17	32E
0005435946999	26588	18	33F
0005435856133	26588	19	33G
0005435947008	26588	20	36B
0005435856130	26588	21	36D
0005435947002	26588	22	37H
0005435787320	26588	23	38D
0005435947011	26588	24	38F
0005435947007	26588	25	38G
0005435856132	26588	26	38H
0005433568041	331	1	2A
0005433568033	331	2	2D
0005433568034	331	3	3F
0005433568043	331	4	5A
0005433568065	331	5	4F
0005433568018	331	6	5F
0005433568045	331	7	5D
0005433568061	331	8	6A
0005433568019	331	9	7A
0005433568029	331	10	8A
0005433568037	331	11	8B
0005433568057	331	12	9B
0005433568036	331	13	9C
0005433568022	331	14	9D
0005433568038	331	15	9F
0005433568053	331	16	10B
0005432238832	331	17	10F
0005433568060	331	18	11A
0005433568040	331	19	11D
0005433568054	331	20	11C
0005432238829	331	21	11F
0005433568066	331	22	12D
0005433568067	331	23	13B
0005433568042	331	24	14C
0005433568027	331	25	15A
0005433568028	331	26	15D
0005432238831	331	27	15F
0005433568063	331	28	15E
0005432238828	331	29	17A
0005432238830	331	30	17D
0005433568032	331	31	17E
0005433568044	331	32	18A
0005433568023	331	33	18B
0005433568049	331	34	18D
0005433568046	331	35	18C
0005433568047	331	36	19E
0005433568052	331	37	20D
0005433568020	331	38	21B
0005433568039	331	39	21D
0005433568048	331	40	21F
0005433568050	331	41	22B
0005433568056	331	42	22C
0005433568030	331	43	22E
0005433568031	331	44	22D
0005433568035	331	45	23C
0005433568058	331	46	24D
0005433568059	331	47	24F
0005432238827	331	48	25B
0005433568015	331	49	25D
0005433568062	331	50	25C
0005433568025	331	51	27A
0005433568016	331	52	27C
0005433568068	331	53	27E
0005433568064	331	54	28C
0005433568055	331	55	28D
0005433568017	331	56	29A
0005433568051	331	57	29D
0005433568026	331	58	30F
0005433568024	331	59	31B
0005433568021	331	60	31F
0005433074208	11606	1	1D
0005432192264	11606	2	1C
0005433134056	11606	3	2D
0005433074209	11606	4	4D
0005433074203	11606	5	6C
0005433074216	11606	6	6F
0005433074217	11606	7	6D
0005433074213	11606	8	7A
0005433074204	11606	9	8A
0005433074219	11606	10	10B
0005432192265	11606	11	11E
0005433074214	11606	12	12E
0005433074225	11606	13	12D
0005433074199	11606	14	13A
0005433074197	11606	15	13D
0005433074207	11606	16	13F
0005433074196	11606	17	14D
0005433074211	11606	18	15A
0005433134059	11606	19	15E
0005433131627	11606	20	15D
0005433134058	11606	21	15F
0005433131629	11606	22	16A
0005433074222	11606	23	17A
0005433074218	11606	24	17F
0005433074205	11606	25	17E
0005433074210	11606	26	18C
0005433074201	11606	27	18E
0005432192263	11606	28	19E
0005433074223	11606	29	20B
0005433131626	11606	30	20F
0005433074212	11606	31	24A
0005433074200	11606	32	25A
0005433074221	11606	33	27D
0005433131628	11606	34	27F
0005433134057	11606	35	28C
0005433074206	11606	36	28F
0005433074198	11606	37	29D
0005433074224	11606	38	29F
0005433074220	11606	39	29E
0005433074215	11606	40	30A
0005433074202	11606	41	31B
0005433817405	10005	1	1A
0005433817407	10005	2	1B
0005433817406	10005	3	3B
0005433817404	10005	4	6B
0005434732921	13968	1	3B
0005434732918	13968	2	4A
0005434732920	13968	3	4B
0005434732919	13968	4	5A
0005433753223	2323	1	1A
0005432655337	2323	2	1C
0005433753243	2323	3	1B
0005432655327	2323	4	1F
0005433753278	2323	5	1G
0005433753262	2323	6	2A
0005435981535	2323	7	1H
0005435981511	2323	8	2F
0005433753275	2323	9	2C
0005433753244	2323	10	3B
0005433753246	2323	11	3F
0005433753273	2323	12	3C
0005432225946	2323	13	4A
0005435981527	2323	14	4B
0005435981514	2323	15	4F
0005435981510	2323	16	5A
0005432655334	2323	17	5F
0005433753267	2323	18	5C
0005435981519	2323	19	9B
0005433753268	2323	20	11B
0005435981537	2323	21	11F
0005432655335	2323	22	11G
0005433753249	2323	23	12A
0005435981513	2323	24	12F
0005433753269	2323	25	13D
0005435981534	2323	26	13B
0005433753258	2323	27	13E
0005435981533	2323	28	13F
0005435981509	2323	29	13H
0005433753228	2323	30	13G
0005433753227	2323	31	14A
0005435981515	2323	32	14E
0005433753240	2323	33	14D
0005433753251	2323	34	14F
0005433753241	2323	35	14H
0005433753221	2323	36	14G
0005433753271	2323	37	15D
0005432300163	2323	38	15F
0005433753250	2323	39	15H
0005433753239	2323	40	15G
0005435981528	2323	41	16E
0005435981545	2323	42	16G
0005432225947	2323	43	16F
0005433753266	2323	44	17B
0005433753253	2323	45	17A
0005435981518	2323	46	17D
0005433753224	2323	47	17E
0005433753242	2323	48	17G
0005432655331	2323	49	17H
0005433753254	2323	50	18B
0005432300165	2323	51	18D
0005433753232	2323	52	18F
0005435981540	2323	53	18H
0005433753237	2323	54	19B
0005433753259	2323	55	19A
0005433764644	2323	56	19D
0005433753233	2323	57	19F
0005435981546	2323	58	19H
0005433764643	2323	59	19G
0005435981523	2323	60	20A
0005433766573	2323	61	20E
0005435981543	2323	62	20D
0005433753261	2323	63	20G
0005435981531	2323	64	20F
0005435981542	2323	65	21A
0005432300161	2323	66	21F
0005433753255	2323	67	22A
0005432655332	2323	68	21G
0005432655333	2323	69	22B
0005435981530	2323	70	22E
0005433753235	2323	71	22F
0005433753263	2323	72	22H
0005435981517	2323	73	23F
0005435981547	2323	74	23E
0005435981516	2323	75	24B
0005433753245	2323	76	24D
0005433753230	2323	77	24H
0005433753272	2323	78	24G
0005435981539	2323	79	25D
0005433753225	2323	80	25E
0005432655336	2323	81	27B
0005433766575	2323	82	27E
0005432225952	2323	83	27D
0005433753277	2323	84	27G
0005433753231	2323	85	27F
0005432655328	2323	86	27H
0005432225950	2323	87	28B
0005432300162	2323	88	28H
0005433753238	2323	89	28G
0005433753229	2323	90	29A
0005435981522	2323	91	29G
0005432225949	2323	92	30B
0005433753260	2323	93	30A
0005435981521	2323	94	30D
0005433753265	2323	95	30F
0005435981532	2323	96	30E
0005433753274	2323	97	30G
0005433753247	2323	98	30H
0005435981536	2323	99	31B
0005432225951	2323	100	31A
0005435981526	2323	101	31G
0005432655326	2323	102	32A
0005435981538	2323	103	32B
0005435981529	2323	104	32E
0005433753256	2323	105	32H
0005433766572	2323	106	33A
0005433753226	2323	107	33B
0005435981508	2323	108	34A
0005433753248	2323	109	34D
0005432300164	2323	110	34E
0005435981520	2323	111	34G
0005433753222	2323	112	34F
0005435981512	2323	113	35A
0005433753234	2323	114	34H
0005433753270	2323	115	35B
0005433753236	2323	116	35D
0005435981544	2323	117	35E
0005433753264	2323	118	35H
0005433753257	2323	119	35G
0005432655330	2323	120	36F
0005433753252	2323	121	37D
0005435981541	2323	122	37A
0005432655329	2323	123	37G
0005435981524	2323	124	38A
0005433766574	2323	125	38G
0005432225948	2323	126	39E
0005433753276	2323	127	39D
0005435981525	2323	128	39F
0005432984529	26185	1	1A
0005432051075	26185	2	1B
0005433434188	26185	3	1F
0005433434192	26185	4	1G
0005432984518	26185	5	2A
0005432984503	26185	6	2B
0005433434184	26185	7	3F
0005432984526	26185	8	4B
0005433434195	26185	9	4F
0005432984506	26185	10	5A
0005432984530	26185	11	5F
0005433434186	26185	12	9G
0005432984514	26185	13	11E
0005433434203	26185	14	12B
0005433434181	26185	15	12F
0005432984510	26185	16	12G
0005432984501	26185	17	13H
0005432984524	26185	18	14A
0005433434187	26185	19	14F
0005432984507	26185	20	15E
0005432984527	26185	21	16D
0005433434189	26185	22	16E
0005432984511	26185	23	17A
0005432984505	26185	24	18A
0005432984516	26185	25	18G
0005434731099	26185	26	19B
0005433434185	26185	27	19F
0005433434204	26185	28	19G
0005433434193	26185	29	20D
0005433434182	26185	30	20H
0005432984504	26185	31	21B
0005433434202	26185	32	22D
0005433434197	26185	33	22F
0005432984502	26185	34	22E
0005433434198	26185	35	23B
0005432984515	26185	36	23E
0005433434199	26185	37	24A
0005432984520	26185	38	24D
0005434731097	26185	39	24E
0005434731096	26185	40	24G
0005433434201	26185	41	27H
0005433434207	26185	42	29E
0005433434208	26185	43	29G
0005433434180	26185	44	29H
0005432984512	26185	45	30E
0005434731098	26185	46	31D
0005432049402	26185	47	31F
0005432051076	26185	48	31E
0005432984508	26185	49	31H
0005433434190	26185	50	32D
0005432984509	26185	51	32B
0005433434194	26185	52	32F
0005432051074	26185	53	33A
0005432049400	26185	54	33B
0005432984513	26185	55	33D
0005433434196	26185	56	33G
0005432984521	26185	57	33F
0005432984519	26185	58	34A
0005432984531	26185	59	34D
0005433434191	26185	60	35E
0005432984532	26185	61	35D
0005432984523	26185	62	36A
0005432984522	26185	63	36B
0005433434200	26185	64	36D
0005433434183	26185	65	36E
0005432984517	26185	66	37D
0005432984500	26185	67	38A
0005432049401	26185	68	38D
0005432984525	26185	69	38E
0005433434206	26185	70	38F
0005433434205	26185	71	39D
0005432984528	26185	72	39F
0005434373852	1521	1	1A
0005434373860	1521	2	1D
0005434373851	1521	3	2C
0005434373859	1521	4	2D
0005433460399	1521	5	3A
0005434373870	1521	6	2F
0005434373884	1521	7	3C
0005434373856	1521	8	4B
0005434373887	1521	9	4D
0005434373897	1521	10	5D
0005432267782	1521	11	5F
0005434373854	1521	12	6B
0005434373874	1521	13	6A
0005434373857	1521	14	6C
0005433461550	1521	15	6D
0005434373846	1521	16	6E
0005434373872	1521	17	7B
0005434373855	1521	18	7C
0005434373879	1521	19	7D
0005434373890	1521	20	9B
0005434373876	1521	21	9C
0005432267778	1521	22	9E
0005434373867	1521	23	9F
0005434373869	1521	24	10B
0005434373861	1521	25	10E
0005434373847	1521	26	10D
0005434373878	1521	27	11A
0005434373881	1521	28	11D
0005434373894	1521	29	11C
0005434373891	1521	30	11E
0005434373873	1521	31	11F
0005434373888	1521	32	12B
0005434373895	1521	33	12D
0005434373877	1521	34	12E
0005433460398	1521	35	13B
0005434373853	1521	36	13D
0005434373864	1521	37	13C
0005434373893	1521	38	13F
0005434373885	1521	39	14C
0005434373849	1521	40	14B
0005432267780	1521	41	15B
0005434373880	1521	42	16E
0005434373848	1521	43	17B
0005434373883	1521	44	17C
0005434373875	1521	45	17F
0005434373862	1521	46	17E
0005432267779	1521	47	18B
0005434373863	1521	48	18C
0005433461551	1521	49	18D
0005434373882	1521	50	19A
0005432267777	1521	51	19B
0005434373865	1521	52	19D
0005434373868	1521	53	20B
0005434373889	1521	54	20D
0005432267781	1521	55	20E
0005434373886	1521	56	21A
0005434373866	1521	57	21C
0005434373850	1521	58	22C
0005434373871	1521	59	22D
0005434373892	1521	60	23A
0005434373858	1521	61	23B
0005434373896	1521	62	23D
0005433150802	20159	1	1D
0005433150806	20159	2	1F
0005433150801	20159	3	2A
0005433150825	20159	4	3D
0005433931415	20159	5	3F
0005433150796	20159	6	4B
0005433931414	20159	7	4F
0005433150820	20159	8	5B
0005432056231	20159	9	5A
0005432056232	20159	10	5F
0005433150817	20159	11	6D
0005432056233	20159	12	7B
0005433150808	20159	13	7D
0005433150809	20159	14	7E
0005433931413	20159	15	8C
0005433150819	20159	16	8F
0005433150804	20159	17	9D
0005434029615	20159	18	10C
0005433764643	20159	19	11C
0005433150795	20159	20	11B
0005433150812	20159	21	11E
0005433150816	20159	22	11D
0005433150799	20159	23	12D
0005432056234	20159	24	13A
0005433931416	20159	25	13C
0005433150818	20159	26	13B
0005433150803	20159	27	13E
0005433150826	20159	28	13F
0005433150821	20159	29	14D
0005434029613	20159	30	14F
0005433150797	20159	31	15B
0005433150807	20159	32	15C
0005433150824	20159	33	15D
0005433150794	20159	34	15E
0005433150822	20159	35	16B
0005433150813	20159	36	16C
0005433150811	20159	37	17B
0005433150815	20159	38	17C
0005434029614	20159	39	17F
0005433150810	20159	40	18E
0005433150805	20159	41	18F
0005433150800	20159	42	19A
0005433150814	20159	43	21C
0005433150798	20159	44	22C
0005433150823	20159	45	22E
0005433764644	20159	46	23B
0005433150827	20159	47	23A
0005432423614	533	1	1D
0005432423631	533	2	2C
0005432282742	533	3	4C
0005432282744	533	4	7A
0005432423633	533	5	8B
0005432423621	533	6	8C
0005432423607	533	7	10B
0005432423644	533	8	10D
0005432423626	533	9	10E
0005432423612	533	10	11F
0005432423605	533	11	11E
0005432282745	533	12	12B
0005432282740	533	13	12D
0005432423618	533	14	12C
0005432423634	533	15	12E
0005432423623	533	16	13D
0005432423642	533	17	13F
0005432423637	533	18	14D
0005432423632	533	19	15A
0005432423645	533	20	15B
0005432423630	533	21	15E
0005432423604	533	22	15D
0005432423617	533	23	16C
0005432423616	533	24	17F
0005432423643	533	25	18B
0005432282746	533	26	18E
0005432423609	533	27	18F
0005432423610	533	28	19C
0005432423635	533	29	19D
0005432423639	533	30	20D
0005432423646	533	31	20E
0005432423638	533	32	21A
0005432423606	533	33	21F
0005432423628	533	34	22C
0005432423627	533	35	23A
0005432423622	533	36	23B
0005432282739	533	37	23C
0005432423611	533	38	23F
0005432423641	533	39	24C
0005432423640	533	40	24D
0005432423636	533	41	25E
0005432423613	533	42	25F
0005432423625	533	43	26B
0005432423620	533	44	26E
0005432423608	533	45	26F
0005432282743	533	46	27A
0005432423619	533	47	28B
0005432423624	533	48	28F
0005432423629	533	49	29A
0005432282741	533	50	29D
0005432423647	533	51	30A
0005432423615	533	52	31E
0005432302265	12840	1	7C
0005432302266	12840	2	9F
0005433158094	12840	3	24C
0005433158093	12840	4	24F
0005434022558	478	1	1G
0005434022550	478	2	2B
0005432235505	478	3	2G
0005434022515	478	4	2H
0005434022561	478	5	3G
0005434022537	478	6	4A
0005434022536	478	7	3H
0005434022507	478	8	4F
0005434022534	478	9	5B
0005432235507	478	10	5G
0005434022547	478	11	11A
0005434022528	478	12	11E
0005434022520	478	13	11G
0005434022502	478	14	12D
0005434022553	478	15	12E
0005434022525	478	16	12H
0005434022506	478	17	13F
0005434022503	478	18	14B
0005434022562	478	19	14G
0005434022541	478	20	15E
0005434022565	478	21	15F
0005432235508	478	22	15H
0005434022521	478	23	15G
0005434022527	478	24	16A
0005434022542	478	25	16F
0005432235512	478	26	16D
0005434022512	478	27	17D
0005434022524	478	28	17F
0005434022519	478	29	17G
0005434022508	478	30	18E
0005432235506	478	31	18G
0005434022556	478	32	19E
0005434022510	478	33	20D
0005434022538	478	34	20F
0005434022567	478	35	21D
0005434022539	478	36	21H
0005434022530	478	37	21G
0005434022533	478	38	22D
0005434022516	478	39	22G
0005434022531	478	40	23A
0005434022505	478	41	23D
0005434022523	478	42	23H
0005434022535	478	43	24B
0005434022568	478	44	24D
0005434022548	478	45	24F
0005434022540	478	46	27A
0005434022549	478	47	27E
0005434022564	478	48	28F
0005434022513	478	49	28H
0005434022552	478	50	29D
0005432235509	478	51	29G
0005434022529	478	52	29F
0005434022517	478	53	30A
0005434022557	478	54	31A
0005434022545	478	55	30H
0005434022546	478	56	31B
0005434022518	478	57	31F
0005432235510	478	58	31G
0005434022560	478	59	32D
0005434022544	478	60	33A
0005434022563	478	61	33E
0005434022543	478	62	33F
0005432235504	478	63	33H
0005434022509	478	64	33G
0005434022522	478	65	34E
0005434022555	478	66	34G
0005434022566	478	67	35B
0005434022511	478	68	35E
0005434022551	478	69	35G
0005434022504	478	70	36A
0005432235511	478	71	35H
0005434022532	478	72	37B
0005434022559	478	73	37E
0005434022514	478	74	37H
0005434022501	478	75	38D
0005434022526	478	76	38H
0005434022569	478	77	39F
0005434022554	478	78	39E
0005432156288	12679	1	1B
0005434735601	12679	2	1F
0005433057203	12679	3	2F
0005433057204	12679	4	2G
0005433929541	12679	5	4A
0005433057198	12679	6	4C
0005433057179	12679	7	4F
0005433057182	12679	8	5F
0005433057190	12679	9	9A
0005433057194	12679	10	11A
0005433929539	12679	11	11E
0005433057206	12679	12	11H
0005433057196	12679	13	12H
0005433929540	12679	14	13F
0005433057168	12679	15	13H
0005433057187	12679	16	14D
0005433057181	12679	17	15F
0005433057191	12679	18	16A
0005433057176	12679	19	16D
0005433057174	12679	20	17B
0005433057169	12679	21	17F
0005433057170	12679	22	18A
0005433057197	12679	23	18E
0005432156289	12679	24	19B
0005433057178	12679	25	19G
0005433057183	12679	26	20E
0005433057172	12679	27	20F
0005432156290	12679	28	21A
0005433057193	12679	29	20H
0005433057188	12679	30	21B
0005433057180	12679	31	22B
0005432156286	12679	32	22D
0005432157457	12679	33	22E
0005433057202	12679	34	22F
0005433057189	12679	35	23E
0005433057200	12679	36	23F
0005433057173	12679	37	24A
0005433057205	12679	38	24H
0005433057184	12679	39	27G
0005433057175	12679	40	28A
0005433057186	12679	41	29G
0005433057195	12679	42	29F
0005433057199	12679	43	30A
0005432156287	12679	44	30G
0005433057201	12679	45	31G
0005433057208	12679	46	32A
0005434735600	12679	47	32F
0005433057192	12679	48	32G
0005433929542	12679	49	33A
0005434735599	12679	50	33G
0005433684385	12679	51	34D
0005433057185	12679	52	34B
0005432157458	12679	53	36D
0005434735597	12679	54	36F
0005433684384	12679	55	36G
0005433057171	12679	56	37A
0005433057207	12679	57	36H
0005434735598	12679	58	37H
0005433057177	12679	59	38E
0005433921597	2140	1	1A
0005432231380	2140	2	1C
0005433921601	2140	3	1B
0005433921643	2140	4	1F
0005433929540	2140	5	1G
0005433921659	2140	6	2C
0005433921667	2140	7	2H
0005433931415	2140	8	2G
0005433921590	2140	9	4B
0005433921655	2140	10	4H
0005433921623	2140	11	4F
0005433921665	2140	12	5A
0005433921605	2140	13	5B
0005433921624	2140	14	5C
0005432231376	2140	15	5G
0005433921621	2140	16	5H
0005433921673	2140	17	9B
0005432231384	2140	18	9G
0005433921661	2140	19	9H
0005433921650	2140	20	11B
0005432044477	2140	21	11D
0005433929539	2140	22	11G
0005433921632	2140	23	12A
0005433921594	2140	24	12B
0005433921660	2140	25	12H
0005433921642	2140	26	13B
0005433921639	2140	27	13A
0005433921684	2140	28	13F
0005433921668	2140	29	13E
0005433921680	2140	30	13H
0005433921603	2140	31	14F
0005433921615	2140	32	14E
0005432231377	2140	33	15A
0005433921600	2140	34	15B
0005433921629	2140	35	15E
0005433931416	2140	36	15F
0005433921619	2140	37	16B
0005433921611	2140	38	16A
0005433921675	2140	39	15H
0005433921656	2140	40	16D
0005433921618	2140	41	16H
0005433921654	2140	42	16G
0005433921666	2140	43	17A
0005433921634	2140	44	17B
0005433921644	2140	45	17G
0005433921630	2140	46	17F
0005433921636	2140	47	17H
0005433921671	2140	48	18E
0005433921648	2140	49	18F
0005433931414	2140	50	19A
0005433921587	2140	51	19D
0005433921649	2140	52	19F
0005433921682	2140	53	19H
0005433921622	2140	54	19G
0005433921638	2140	55	20D
0005433921664	2140	56	20B
0005433921683	2140	57	20E
0005432231379	2140	58	20H
0005432044476	2140	59	21E
0005433921606	2140	60	21H
0005433921633	2140	61	22B
0005433921598	2140	62	22G
0005433921646	2140	63	22F
0005433921672	2140	64	23A
0005433921610	2140	65	22H
0005432231378	2140	66	23D
0005433921626	2140	67	23E
0005433921658	2140	68	23G
0005433921663	2140	69	24D
0005433921676	2140	70	24F
0005433921631	2140	71	24G
0005433921662	2140	72	25E
0005433921670	2140	73	27A
0005433921678	2140	74	27E
0005433921645	2140	75	27D
0005432044475	2140	76	27F
0005433921608	2140	77	27H
0005433921681	2140	78	28H
0005432231375	2140	79	29D
0005433921669	2140	80	29B
0005433921637	2140	81	29F
0005433921652	2140	82	30A
0005433921604	2140	83	30B
0005433921635	2140	84	30E
0005433931413	2140	85	30D
0005433921641	2140	86	30F
0005433921651	2140	87	30G
0005432231383	2140	88	31A
0005433921627	2140	89	31E
0005433921628	2140	90	31G
0005433921588	2140	91	32A
0005433921647	2140	92	31H
0005433929542	2140	93	32E
0005433921620	2140	94	33A
0005433921674	2140	95	33B
0005433921614	2140	96	33D
0005433921679	2140	97	33G
0005433921653	2140	98	33F
0005433921613	2140	99	33H
0005433921616	2140	100	34B
0005433921595	2140	101	34A
0005433921677	2140	102	34D
0005433921612	2140	103	34F
0005432231382	2140	104	34E
0005432231381	2140	105	34H
0005433921589	2140	106	35B
0005433921609	2140	107	35F
0005433921640	2140	108	35H
0005433921602	2140	109	35G
0005433921593	2140	110	36B
0005433921657	2140	111	36A
0005433929541	2140	112	36E
0005433921617	2140	113	36F
0005433921592	2140	114	36H
0005433921599	2140	115	37A
0005433921625	2140	116	37F
0005433921596	2140	117	37H
0005432231374	2140	118	38A
0005433921591	2140	119	38E
0005433921607	2140	120	38F
0005433035392	24118	1	1B
0005433035386	24118	2	1F
0005433035391	24118	3	1G
0005433035374	24118	4	2H
0005433035377	24118	5	3G
0005433035396	24118	6	4C
0005433035388	24118	7	5B
0005433035390	24118	8	9A
0005433035364	24118	9	11E
0005433035369	24118	10	11F
0005433035378	24118	11	12A
0005433035398	24118	12	11H
0005432206096	24118	13	12G
0005432207616	24118	14	13E
0005433035381	24118	15	13H
0005433035393	24118	16	14G
0005433035379	24118	17	14F
0005433035384	24118	18	15A
0005433035383	24118	19	15F
0005433035356	24118	20	16D
0005433035370	24118	21	16G
0005432207617	24118	22	17B
0005433035409	24118	23	18B
0005433035380	24118	24	18G
0005433035358	24118	25	18F
0005433035397	24118	26	18H
0005433035373	24118	27	19D
0005432206094	24118	28	19H
0005433035403	24118	29	19G
0005433035366	24118	30	20E
0005433035368	24118	31	20G
0005432206091	24118	32	21F
0005433035404	24118	33	22A
0005433035406	24118	34	22D
0005433035365	24118	35	22F
0005433035371	24118	36	22E
0005433035407	24118	37	23E
0005434028249	24118	38	23G
0005433035375	24118	39	23F
0005433035372	24118	40	24B
0005433035405	24118	41	24E
0005433035385	24118	42	24D
0005433035387	24118	43	24H
0005432207618	24118	44	25D
0005432206093	24118	45	27A
0005433035394	24118	46	27D
0005433035367	24118	47	27E
0005433035363	24118	48	30F
0005433035376	24118	49	30H
0005433035399	24118	50	31D
0005432206095	24118	51	32H
0005434028247	24118	52	32G
0005433035360	24118	53	33A
0005433035410	24118	54	33E
0005433035361	24118	55	34B
0005433035357	24118	56	34A
0005433035389	24118	57	35B
0005433035359	24118	58	35E
0005433035395	24118	59	35D
0005433035400	24118	60	35G
0005434028246	24118	61	36D
0005433035362	24118	62	36E
0005432206092	24118	63	37B
0005433035408	24118	64	37E
0005432749747	24118	65	37D
0005433035401	24118	66	37G
0005433035402	24118	67	37F
0005433035382	24118	68	37H
0005434028248	24118	69	38D
0005432749748	24118	70	38G
0005434550284	277	1	1C
0005434723419	277	2	1A
0005434723381	277	3	1H
0005434723410	277	4	1G
0005434550305	277	5	2A
0005434723388	277	6	1K
0005434550256	277	7	2C
0005434550307	277	8	2G
0005434723407	277	9	2K
0005434550275	277	10	3H
0005434723327	277	11	3K
0005435142344	277	12	4D
0005434723399	277	13	5A
0005434723343	277	14	4H
0005434723346	277	15	5H
0005434723421	277	16	5G
0005434550303	277	17	5K
0005434723394	277	18	11C
0005434723349	277	19	11F
0005434550294	277	20	11G
0005434302381	277	21	12C
0005432277569	277	22	11K
0005434550293	277	23	12G
0005434723359	277	24	13A
0005434723352	277	25	12H
0005432277572	277	26	13C
0005434550288	277	27	13G
0005434723325	277	28	13F
0005434723391	277	29	13E
0005434550270	277	30	13H
0005435142348	277	31	14C
0005434723402	277	32	14A
0005434550276	277	33	14G
0005434550281	277	34	14F
0005432277575	277	35	14E
0005434550263	277	36	15C
0005434723373	277	37	15K
0005434723337	277	38	16D
0005434723378	277	39	16E
0005434723329	277	40	17C
0005434550286	277	41	17E
0005434723431	277	42	17D
0005434550260	277	43	18A
0005434550299	277	44	18B
0005432277580	277	45	18E
0005434723334	277	46	18D
0005434550267	277	47	18C
0005434723355	277	48	18G
0005434550291	277	49	18J
0005434723396	277	50	19B
0005432277574	277	51	19A
0005434550258	277	52	19H
0005434723395	277	53	19G
0005435142337	277	54	19K
0005434550279	277	55	20C
0005434723312	277	56	20B
0005434550277	277	57	20A
0005434723351	277	58	20E
0005434723379	277	59	20D
0005434723314	277	60	20G
0005434723424	277	61	20J
0005434723360	277	62	20H
0005434550283	277	63	21A
0005434723414	277	64	21D
0005434723389	277	65	21C
0005434550306	277	66	21G
0005434550287	277	67	22C
0005435142347	277	68	22G
0005434723433	277	69	22J
0005434723423	277	70	23B
0005434550309	277	71	23A
0005434723345	277	72	23D
0005434723365	277	73	23F
0005434723320	277	74	23E
0005435142341	277	75	23J
0005432277577	277	76	24D
0005434302382	277	77	23K
0005435142342	277	78	24E
0005434723393	277	79	25A
0005434550269	277	80	25D
0005434723366	277	81	25B
0005434723356	277	82	25E
0005434723335	277	83	25G
0005434550265	277	84	26A
0005434723357	277	85	25J
0005435142343	277	86	26C
0005435142346	277	87	26B
0005434723374	277	88	26E
0005434550259	277	89	26H
0005434550268	277	90	26F
0005434723417	277	91	26J
0005434723316	277	92	27D
0005434723406	277	93	27B
0005434723418	277	94	27E
0005434723368	277	95	27J
0005432277581	277	96	28B
0005434550262	277	97	28E
0005434723386	277	98	28D
0005434723403	277	99	28G
0005434550264	277	100	28F
0005434723430	277	101	28H
0005434723333	277	102	29A
0005434723390	277	103	29D
0005434723341	277	104	29C
0005434723321	277	105	29F
0005434550310	277	106	29E
0005434723432	277	107	29J
0005432277571	277	108	29H
0005434723408	277	109	30C
0005434550280	277	110	30B
0005434723319	277	111	30D
0005434723330	277	112	30G
0005434723411	277	113	30J
0005434723369	277	114	31A
0005434550257	277	115	31C
0005434723323	277	116	31E
0005434723380	277	117	31G
0005434723354	277	118	31K
0005434723370	277	119	31J
0005434550300	277	120	32E
0005434723363	277	121	32D
0005435142340	277	122	32F
0005434723383	277	123	32K
0005434550301	277	124	33D
0005434302853	277	125	33C
0005434723364	277	126	33H
0005434723331	277	127	34A
0005434723413	277	128	33K
0005434723313	277	129	33J
0005434723342	277	130	34B
0005434723398	277	131	34E
0005435142335	277	132	34C
0005434723427	277	133	34K
0005434723404	277	134	34J
0005434723362	277	135	35B
0005434723416	277	136	35D
0005434723361	277	137	35C
0005434723382	277	138	35E
0005432277579	277	139	35H
0005434550272	277	140	36A
0005434723353	277	141	36C
0005435142339	277	142	36D
0005434723412	277	143	36K
0005435142338	277	144	36J
0005434723318	277	145	37D
0005434723387	277	146	37C
0005434302383	277	147	37F
0005434550278	277	148	37E
0005434550298	277	149	37J
0005434723348	277	150	38A
0005434723409	277	151	37K
0005434302384	277	152	38C
0005434723385	277	153	38H
0005434723311	277	154	39B
0005434550261	277	155	39A
0005434723336	277	156	39D
0005435142336	277	157	39H
0005434723338	277	158	39K
0005434723344	277	159	39J
0005434723367	277	160	40B
0005432277576	277	161	40D
0005434723392	277	162	40K
0005434723384	277	163	41B
0005434550297	277	164	41D
0005432277573	277	165	41C
0005434550285	277	166	41G
0005434550266	277	167	41E
0005434550302	277	168	41K
0005432277578	277	169	41J
0005434723347	277	170	42C
0005434723428	277	171	42B
0005434723332	277	172	42D
0005434723426	277	173	42G
0005434723375	277	174	43D
0005434723339	277	175	43E
0005434723415	277	176	43H
0005434723425	277	177	43G
0005434723317	277	178	43K
0005434723324	277	179	43J
0005434723315	277	180	44A
0005434550290	277	181	44D
0005434723372	277	182	44C
0005434723326	277	183	45B
0005434723340	277	184	45J
0005434723350	277	185	45G
0005434550308	277	186	45K
0005434550274	277	187	46B
0005434723310	277	188	46A
0005434723422	277	189	46D
0005434723401	277	190	46F
0005434550282	277	191	46K
0005434723376	277	192	47C
0005434723377	277	193	47E
0005434550289	277	194	47D
0005434302385	277	195	47F
0005434723429	277	196	48A
0005434723400	277	197	48F
0005434550296	277	198	48E
0005434550273	277	199	48D
0005434723397	277	200	48H
0005434723322	277	201	48G
0005434550271	277	202	49C
0005434550295	277	203	49A
0005434723420	277	204	49F
0005434550304	277	205	49E
0005434723358	277	206	49H
0005434723405	277	207	50A
0005434723371	277	208	50H
0005434550311	277	209	50F
0005435142345	277	210	51D
0005432277570	277	211	50K
0005434723328	277	212	51E
0005434550292	277	213	51G
0005433233127	9829	1	1A
0005434031947	9829	2	1G
0005433233121	9829	3	1K
0005433180671	9829	4	2C
0005432199129	9829	5	2G
0005433180649	9829	6	3G
0005432199128	9829	7	4G
0005433180661	9829	8	4D
0005433180665	9829	9	4H
0005433233138	9829	10	5D
0005433233096	9829	11	5H
0005432199126	9829	12	11A
0005433233093	9829	13	11D
0005433233111	9829	14	11G
0005433180667	9829	15	11F
0005433233097	9829	16	11H
0005433233110	9829	17	12C
0005433233112	9829	18	13A
0005433180672	9829	19	12H
0005433180664	9829	20	13C
0005433180657	9829	21	13K
0005433233103	9829	22	13G
0005433233091	9829	23	14G
0005433233102	9829	24	15H
0005433233107	9829	25	15G
0005433233118	9829	26	15F
0005433233089	9829	27	18C
0005433233124	9829	28	18A
0005433180653	9829	29	18E
0005433233090	9829	30	18F
0005433233114	9829	31	19A
0005433233143	9829	32	19D
0005433233133	9829	33	19C
0005433233108	9829	34	20F
0005433180673	9829	35	21C
0005433233117	9829	36	21J
0005433113496	9829	37	21H
0005434031946	9829	38	23B
0005433180670	9829	39	23E
0005433233092	9829	40	23H
0005432199123	9829	41	23K
0005433233085	9829	42	25E
0005433233134	9829	43	25H
0005433180668	9829	44	26E
0005433233131	9829	45	26D
0005433766574	9829	46	26F
0005433233080	9829	47	26J
0005433180660	9829	48	27A
0005433233116	9829	49	27C
0005432199124	9829	50	28A
0005433180654	9829	51	28C
0005433180669	9829	52	28B
0005433766573	9829	53	28E
0005433180651	9829	54	28G
0005433233125	9829	55	28J
0005433233115	9829	56	29B
0005432199127	9829	57	29G
0005433233141	9829	58	30B
0005433233086	9829	59	30E
0005433233139	9829	60	30C
0005432199125	9829	61	30J
0005433766575	9829	62	30K
0005433233101	9829	63	31D
0005433233105	9829	64	31F
0005433113495	9829	65	31E
0005433233135	9829	66	31K
0005433180659	9829	67	32H
0005433233123	9829	68	33B
0005433233119	9829	69	32K
0005433233082	9829	70	33K
0005433233120	9829	71	34E
0005433233100	9829	72	35K
0005433233136	9829	73	36F
0005433233099	9829	74	36H
0005433233113	9829	75	36G
0005433233130	9829	76	37F
0005433233126	9829	77	37E
0005433233083	9829	78	37G
0005434031945	9829	79	38A
0005433180655	9829	80	37K
0005433233140	9829	81	39C
0005433233137	9829	82	39B
0005434031944	9829	83	39D
0005433766572	9829	84	40D
0005433180652	9829	85	40F
0005433233129	9829	86	41A
0005433180666	9829	87	41D
0005433233142	9829	88	42A
0005433180648	9829	89	41J
0005433233109	9829	90	42G
0005433180663	9829	91	43D
0005433233088	9829	92	43K
0005433233122	9829	93	44B
0005433233104	9829	94	44H
0005433233095	9829	95	44G
0005433180662	9829	96	45A
0005433233106	9829	97	45E
0005433233094	9829	98	45G
0005433180656	9829	99	46D
0005433233098	9829	100	46J
0005433233128	9829	101	47F
0005433233084	9829	102	48G
0005433233081	9829	103	48K
0005433233132	9829	104	49C
0005433180658	9829	105	49H
0005433180650	9829	106	50E
0005433233087	9829	107	50H
0005432525678	7768	1	1C
0005432525723	7768	2	1A
0005432525761	7768	3	2A
0005434066299	7768	4	1K
0005432525677	7768	5	1H
0005432525642	7768	6	2D
0005432525709	7768	7	2C
0005434066325	7768	8	2G
0005432150061	7768	9	3C
0005434066354	7768	10	3K
0005434066360	7768	11	3H
0005434066313	7768	12	3G
0005432525732	7768	13	4A
0005434066306	7768	14	4G
0005432533242	7768	15	5C
0005432525674	7768	16	5A
0005432525694	7768	17	5D
0005432069406	7768	18	11A
0005432525731	7768	19	5K
0005432525648	7768	20	11D
0005432525634	7768	21	11C
0005432525645	7768	22	11F
0005434066327	7768	23	11E
0005432525727	7768	24	11H
0005434066321	7768	25	11G
0005434066332	7768	26	12C
0005432525744	7768	27	12A
0005432525666	7768	28	12D
0005434066351	7768	29	12F
0005432525733	7768	30	12K
0005432525655	7768	31	13C
0005432525686	7768	32	13F
0005432150057	7768	33	13E
0005434066343	7768	34	13G
0005432535748	7768	35	14A
0005434066322	7768	36	13K
0005432525735	7768	37	14E
0005434066305	7768	38	14H
0005432525730	7768	39	14G
0005434066317	7768	40	15C
0005432525710	7768	41	15A
0005432525667	7768	42	15D
0005432150055	7768	43	15G
0005432525701	7768	44	15K
0005432525669	7768	45	16D
0005432525639	7768	46	16C
0005434066334	7768	47	16E
0005432525765	7768	48	16K
0005434066352	7768	49	17E
0005432525647	7768	50	17G
0005432525739	7768	51	17F
0005434066315	7768	52	18A
0005432525767	7768	53	17K
0005434066355	7768	54	18C
0005432525654	7768	55	18B
0005432525658	7768	56	18E
0005432525644	7768	57	18D
0005434066335	7768	58	18G
0005434066342	7768	59	18F
0005432525736	7768	60	18H
0005434066346	7768	61	19B
0005432150060	7768	62	18K
0005432525662	7768	63	19D
0005434066341	7768	64	19C
0005432525729	7768	65	19H
0005432150054	7768	66	19G
0005432525696	7768	67	19J
0005432525691	7768	68	20B
0005432525697	7768	69	20E
0005432525718	7768	70	20C
0005432525703	7768	71	20F
0005434066362	7768	72	20K
0005432525646	7768	73	21B
0005434066324	7768	74	21A
0005432525685	7768	75	21D
0005434066353	7768	76	21C
0005432525747	7768	77	21H
0005434066340	7768	78	21G
0005434066345	7768	79	22A
0005434066303	7768	80	22D
0005432525716	7768	81	22C
0005432533241	7768	82	22B
0005434066304	7768	83	22E
0005432525668	7768	84	22H
0005432069400	7768	85	22G
0005432069397	7768	86	22J
0005434066333	7768	87	23B
0005432150059	7768	88	23A
0005432535746	7768	89	23D
0005434066326	7768	90	23G
0005432525742	7768	91	23F
0005434066361	7768	92	23J
0005434066295	7768	93	23H
0005434066323	7768	94	24D
0005432428867	7768	95	24F
0005434066318	7768	96	25B
0005432525649	7768	97	25A
0005432150058	7768	98	24G
0005434066319	7768	99	25D
0005434066328	7768	100	25C
0005432525670	7768	101	25F
0005432069404	7768	102	25H
0005432525741	7768	103	25K
0005432069394	7768	104	25J
0005432525754	7768	105	26A
0005434066364	7768	106	26E
0005432525746	7768	107	26G
0005434066316	7768	108	26F
0005432525687	7768	109	26K
0005432525758	7768	110	26J
0005432535745	7768	111	27A
0005434066312	7768	112	27B
0005432525692	7768	113	27E
0005432525635	7768	114	27H
0005432525664	7768	115	27G
0005434066349	7768	116	27J
0005432525714	7768	117	28C
0005432525659	7768	118	28B
0005432525683	7768	119	28G
0005434066366	7768	120	28J
0005432525725	7768	121	28H
0005432525745	7768	122	29B
0005432525766	7768	123	29A
0005434066358	7768	124	28K
0005432525759	7768	125	29C
0005434066300	7768	126	29G
0005432525652	7768	127	30A
0005432525715	7768	128	29J
0005434066314	7768	129	30B
0005432525719	7768	130	30F
0005432069401	7768	131	30K
0005432525717	7768	132	30J
0005432525763	7768	133	31D
0005432525762	7768	134	31G
0005434066302	7768	135	31K
0005434066365	7768	136	31J
0005432069407	7768	137	32C
0005432525748	7768	138	32E
0005434066344	7768	139	32D
0005432525698	7768	140	32G
0005432069403	7768	141	32J
0005432525637	7768	142	32H
0005432525653	7768	143	33B
0005432525651	7768	144	33D
0005432525713	7768	145	33F
0005432525671	7768	146	33J
0005432525700	7768	147	33G
0005434066330	7768	148	34A
0005432525663	7768	149	33K
0005434066297	7768	150	34C
0005434066298	7768	151	34B
0005434066348	7768	152	34D
0005432525721	7768	153	34G
0005434066307	7768	154	34F
0005432535747	7768	155	34J
0005432069399	7768	156	35A
0005432525724	7768	157	35C
0005432525753	7768	158	35J
0005434066331	7768	159	35H
0005432150062	7768	160	36A
0005432069408	7768	161	35K
0005432525752	7768	162	36C
0005434066311	7768	163	36B
0005434066329	7768	164	36F
0005432150056	7768	165	36E
0005432525720	7768	166	36D
0005432525638	7768	167	36K
0005432525665	7768	168	36J
0005432428869	7768	169	37B
0005432525656	7768	170	37E
0005432525705	7768	171	37J
0005432525690	7768	172	38A
0005434066339	7768	173	37K
0005434066350	7768	174	38C
0005432525737	7768	175	38J
0005432525707	7768	176	39B
0005432428868	7768	177	39G
0005432525755	7768	178	39F
0005434066320	7768	179	39D
0005432525702	7768	180	39K
0005432525641	7768	181	39J
0005432525751	7768	182	40C
0005432069395	7768	183	40B
0005434066310	7768	184	40F
0005434066296	7768	185	40D
0005432525726	7768	186	40K
0005432525689	7768	187	40J
0005432525693	7768	188	41A
0005432525643	7768	189	41D
0005432525673	7768	190	41C
0005432535749	7768	191	41F
0005432525681	7768	192	41E
0005432525704	7768	193	41H
0005432525738	7768	194	41G
0005434066338	7768	195	42A
0005432525688	7768	196	41K
0005432525650	7768	197	42B
0005432525708	7768	198	42E
0005432525743	7768	199	42K
0005432525657	7768	200	42J
0005432525660	7768	201	43C
0005432525695	7768	202	43F
0005432525640	7768	203	43G
0005432525672	7768	204	43K
0005432069396	7768	205	43J
0005432525712	7768	206	44B
0005434066337	7768	207	44E
0005434066356	7768	208	44G
0005432525757	7768	209	44F
0005432069402	7768	210	44K
0005432533240	7768	211	44H
0005432069398	7768	212	45B
0005432525760	7768	213	45F
0005434066336	7768	214	45H
0005432525756	7768	215	45G
0005432525675	7768	216	46E
0005432525699	7768	217	46D
0005432525722	7768	218	46G
0005434066359	7768	219	46F
0005432525636	7768	220	46H
0005432525740	7768	221	46K
0005432525734	7768	222	47D
0005434066357	7768	223	47C
0005432525728	7768	224	48A
0005432525676	7768	225	47K
0005432525711	7768	226	48C
0005432069405	7768	227	48E
0005434066309	7768	228	48H
0005432525749	7768	229	49A
0005434066363	7768	230	49D
0005432525706	7768	231	49C
0005432525679	7768	232	49G
0005432525684	7768	233	49F
0005432525682	7768	234	49K
0005432525680	7768	235	49H
0005432525750	7768	236	50C
0005432525764	7768	237	50A
0005434066301	7768	238	50E
0005434066308	7768	239	50D
0005434066347	7768	240	50F
0005432525661	7768	241	51E
0005435611762	5354	1	1A
0005434343587	5354	2	1H
0005432132951	5354	3	1G
0005434343593	5354	4	1K
0005435611739	5354	5	2H
0005435611766	5354	6	3A
0005435611757	5354	7	4H
0005434573103	5354	8	5C
0005435097048	5354	9	5A
0005435611769	5354	10	5G
0005434343591	5354	11	11C
0005435611727	5354	12	11G
0005434343600	5354	13	11F
0005435097051	5354	14	12C
0005432132947	5354	15	12F
0005435611699	5354	16	13D
0005435611731	5354	17	13C
0005435097047	5354	18	13A
0005432132954	5354	19	14A
0005432132942	5354	20	14E
0005435611713	5354	21	14C
0005434573110	5354	22	15C
0005435611722	5354	23	15E
0005434343611	5354	24	16A
0005434573104	5354	25	15K
0005435611700	5354	26	16C
0005435611743	5354	27	16F
0005435611754	5354	28	17D
0005434573106	5354	29	17K
0005432132955	5354	30	18C
0005435611701	5354	31	18B
0005434343609	5354	32	18D
0005435611746	5354	33	19F
0005435611737	5354	34	20E
0005435611755	5354	35	20D
0005435611748	5354	36	20F
0005435611715	5354	37	21H
0005435611733	5354	38	22B
0005432047485	5354	39	22F
0005434573101	5354	40	22J
0005435097044	5354	41	23F
0005435611740	5354	42	23H
0005432132941	5354	43	23K
0005434343605	5354	44	24G
0005434343608	5354	45	25E
0005435611738	5354	46	25G
0005435611698	5354	47	26A
0005435097043	5354	48	26D
0005435611717	5354	49	26H
0005434343610	5354	50	27A
0005432132953	5354	51	27C
0005435611750	5354	52	27B
0005434343599	5354	53	27F
0005435611742	5354	54	27J
0005434573102	5354	55	27G
0005432132944	5354	56	27K
0005434343603	5354	57	28E
0005435611734	5354	58	28G
0005435611714	5354	59	28F
0005435611712	5354	60	29B
0005435611702	5354	61	29C
0005432047484	5354	62	29G
0005435611741	5354	63	29F
0005435611751	5354	64	29H
0005432132952	5354	65	30E
0005435611708	5354	66	30D
0005435611719	5354	67	30G
0005434343589	5354	68	30J
0005435611756	5354	69	31E
0005434573107	5354	70	31H
0005435611764	5354	71	32C
0005434343613	5354	72	32B
0005434343597	5354	73	32D
0005434573115	5354	74	32G
0005435611753	5354	75	32F
0005432047486	5354	76	32J
0005435611707	5354	77	32K
0005434343586	5354	78	33C
0005435097049	5354	79	33H
0005435097050	5354	80	33G
0005434343615	5354	81	34A
0005435611763	5354	82	33K
0005434343595	5354	83	33J
0005435611730	5354	84	34G
0005434573114	5354	85	34K
0005435611725	5354	86	35B
0005435611723	5354	87	35F
0005435611710	5354	88	35E
0005435611726	5354	89	36A
0005434343585	5354	90	36B
0005434343602	5354	91	36E
0005435611771	5354	92	36G
0005432132945	5354	93	36K
0005435611718	5354	94	36J
0005434343604	5354	95	37A
0005434343590	5354	96	37D
0005434343582	5354	97	37C
0005434343592	5354	98	37G
0005434343601	5354	99	37J
0005434573108	5354	100	38A
0005434343594	5354	101	38H
0005435611765	5354	102	38C
0005435097046	5354	103	38B
0005435611761	5354	104	38J
0005432132948	5354	105	39B
0005435611706	5354	106	39E
0005434343584	5354	107	39J
0005435611760	5354	108	39H
0005432132943	5354	109	40A
0005432132949	5354	110	40B
0005435611745	5354	111	40D
0005435611705	5354	112	40H
0005435611728	5354	113	41B
0005434343606	5354	114	41D
0005435611759	5354	115	41C
0005434573111	5354	116	41G
0005435611711	5354	117	41F
0005435611709	5354	118	41K
0005434343588	5354	119	42C
0005435611724	5354	120	42B
0005434573105	5354	121	42E
0005435611767	5354	122	42G
0005435611752	5354	123	42H
0005435611758	5354	124	42K
0005434343607	5354	125	43C
0005434343596	5354	126	43J
0005435611772	5354	127	44C
0005434343583	5354	128	44A
0005434343598	5354	129	44E
0005432132946	5354	130	44H
0005435611768	5354	131	44G
0005435611720	5354	132	44J
0005435611747	5354	133	44K
0005435611721	5354	134	45F
0005434573113	5354	135	45J
0005435611732	5354	136	45H
0005434343612	5354	137	45K
0005435611703	5354	138	46C
0005434343614	5354	139	46B
0005435611729	5354	140	47C
0005435611716	5354	141	46K
0005435611770	5354	142	47F
0005435611749	5354	143	47K
0005434573109	5354	144	48D
0005435097045	5354	145	48F
0005432132950	5354	146	48G
0005434343616	5354	147	49C
0005435611736	5354	148	49A
0005434573112	5354	149	48K
0005435611704	5354	150	49G
0005435611744	5354	151	50H
0005435611735	5354	152	51G
0005434244460	10895	1	1A
0005432840976	10895	2	2H
0005435423601	10895	3	3H
0005435423610	10895	4	4D
0005434656521	10895	5	4K
0005432166845	10895	6	11A
0005432164904	10895	7	11F
0005434244482	10895	8	11H
0005434244467	10895	9	12C
0005435423600	10895	10	12E
0005435423613	10895	11	12H
0005435423615	10895	12	12G
0005434244474	10895	13	13C
0005434656520	10895	14	13F
0005435423623	10895	15	14D
0005434244476	10895	16	14G
0005435423591	10895	17	15D
0005432164906	10895	18	15A
0005434244471	10895	19	15E
0005433719080	10895	20	15G
0005435423637	10895	21	16C
0005435423626	10895	22	17C
0005435423594	10895	23	17A
0005435423616	10895	24	17D
0005435423639	10895	25	18B
0005435423642	10895	26	18D
0005435423640	10895	27	18J
0005434244480	10895	28	19A
0005434244455	10895	29	19D
0005434244477	10895	30	19G
0005435423619	10895	31	20E
0005435423627	10895	32	20F
0005434244473	10895	33	20H
0005435423644	10895	34	21B
0005435423598	10895	35	21A
0005435423587	10895	36	21D
0005434244461	10895	37	21G
0005435423631	10895	38	21K
0005435423643	10895	39	22E
0005435042820	10895	40	22K
0005435423614	10895	41	23B
0005434244464	10895	42	23A
0005434244463	10895	43	23K
0005435423582	10895	44	24F
0005435423595	10895	45	25F
0005433719082	10895	46	25J
0005435423592	10895	47	25H
0005434244459	10895	48	26C
0005434244458	10895	49	26B
0005435423636	10895	50	26D
0005432166844	10895	51	26G
0005435423584	10895	52	26K
0005435423612	10895	53	27D
0005435423576	10895	54	27C
0005435042822	10895	55	28C
0005434244472	10895	56	28B
0005435423632	10895	57	28A
0005435423588	10895	58	28G
0005435423617	10895	59	28J
0005434244457	10895	60	29H
0005432164902	10895	61	29K
0005435423645	10895	62	30E
0005435423604	10895	63	31B
0005435423628	10895	64	31D
0005435423597	10895	65	31F
0005435423599	10895	66	31H
0005432363359	10895	67	32C
0005435423622	10895	68	32K
0005432164903	10895	69	33B
0005434244456	10895	70	33D
0005435423634	10895	71	33C
0005432164901	10895	72	33F
0005434244475	10895	73	33H
0005434244470	10895	74	33K
0005435423583	10895	75	34E
0005435423578	10895	76	34F
0005434244479	10895	77	35C
0005434244481	10895	78	35F
0005435423586	10895	79	35H
0005435423620	10895	80	35G
0005432166843	10895	81	36A
0005435423638	10895	82	36C
0005434244483	10895	83	36F
0005433719081	10895	84	36H
0005435423635	10895	85	36G
0005435423589	10895	86	37E
0005435423608	10895	87	37D
0005435042821	10895	88	37C
0005435423577	10895	89	37G
0005435423603	10895	90	37H
0005435423580	10895	91	37J
0005432363360	10895	92	38J
0005434244466	10895	93	39A
0005435423633	10895	94	39G
0005434244469	10895	95	39K
0005435423593	10895	96	40E
0005435423611	10895	97	40G
0005435042823	10895	98	40K
0005434244465	10895	99	41F
0005433719083	10895	100	41E
0005435423596	10895	101	41K
0005435423579	10895	102	42B
0005435423605	10895	103	43C
0005435423609	10895	104	43B
0005435423629	10895	105	43G
0005434244453	10895	106	43J
0005432164907	10895	107	44H
0005435423624	10895	108	45B
0005435423621	10895	109	45D
0005435423641	10895	110	45H
0005435423602	10895	111	45G
0005434244468	10895	112	45K
0005435423625	10895	113	46D
0005435423618	10895	114	46K
0005435423585	10895	115	46H
0005435423607	10895	116	47C
0005435423581	10895	117	47G
0005434244454	10895	118	48F
0005432164905	10895	119	48H
0005435423590	10895	120	49C
0005434244478	10895	121	48K
0005432164908	10895	122	49D
0005435423606	10895	123	51D
0005435423630	10895	124	50K
0005435423575	10895	125	51F
0005434244462	10895	126	51G
0005433804786	3316	1	1F
0005433804791	3316	2	1D
0005433804793	3316	3	2D
0005433633228	3316	4	2C
0005433506853	3316	5	2F
0005433633225	3316	6	3A
0005433633239	3316	7	3F
0005433633226	3316	8	4A
0005433633227	3316	9	4D
0005432181320	3316	10	5C
0005433633217	3316	11	5F
0005433633231	3316	12	5D
0005433633222	3316	13	7A
0005433506856	3316	14	7C
0005433506855	3316	15	7F
0005433633214	3316	16	7D
0005433633221	3316	17	8C
0005433804780	3316	18	8B
0005432181330	3316	19	8D
0005433804788	3316	20	8F
0005433633213	3316	21	9A
0005432181331	3316	22	9C
0005433633220	3316	23	9E
0005433633245	3316	24	9D
0005433506857	3316	25	10A
0005433506861	3316	26	10C
0005432181325	3316	27	10B
0005432181339	3316	28	10D
0005433633247	3316	29	11B
0005433633241	3316	30	11C
0005433804782	3316	31	11D
0005432181329	3316	32	11F
0005432181327	3316	33	12B
0005432181332	3316	34	12E
0005433506866	3316	35	13A
0005433804790	3316	36	13D
0005432181323	3316	37	13E
0005433633244	3316	38	14A
0005433804787	3316	39	14D
0005433506867	3316	40	14C
0005433633229	3316	41	14F
0005433506870	3316	42	15B
0005432181322	3316	43	15A
0005433804781	3316	44	15E
0005432181324	3316	45	16A
0005433633219	3316	46	15F
0005433804778	3316	47	16C
0005433804783	3316	48	16E
0005433633224	3316	49	17B
0005433804784	3316	50	17C
0005433506862	3316	51	18A
0005432181321	3316	52	17F
0005432181333	3316	53	18C
0005433506868	3316	54	18E
0005433633230	3316	55	18F
0005432181334	3316	56	19C
0005433633235	3316	57	20B
0005432181337	3316	58	20A
0005433633215	3316	59	20E
0005433633233	3316	60	21B
0005433633242	3316	61	21D
0005433506860	3316	62	22B
0005433506869	3316	63	22A
0005433633234	3316	64	22D
0005433633216	3316	65	22C
0005433633223	3316	66	22F
0005433506859	3316	67	23A
0005433506858	3316	68	23B
0005433633237	3316	69	23D
0005432181335	3316	70	23C
0005433506854	3316	71	23F
0005432181340	3316	72	24B
0005433804777	3316	73	24E
0005432181319	3316	74	24F
0005433506863	3316	75	25A
0005432181326	3316	76	26A
0005433804789	3316	77	26C
0005433506871	3316	78	26E
0005432181336	3316	79	27A
0005432181338	3316	80	27D
0005433633232	3316	81	27F
0005433633236	3316	82	28A
0005433804785	3316	83	28D
0005433804792	3316	84	28C
0005433633243	3316	85	29B
0005433633246	3316	86	29A
0005433506864	3316	87	29C
0005432181328	3316	88	29E
0005433804779	3316	89	29F
0005433633218	3316	90	30B
0005433633238	3316	91	30A
0005433633240	3316	92	30F
0005433506865	3316	93	31C
0005435884382	8323	1	1C
0005432458972	8323	2	1A
0005432458984	8323	3	1F
0005435884409	8323	4	2A
0005432458964	8323	5	2C
0005432458973	8323	6	2D
0005435884393	8323	7	2F
0005432458992	8323	8	3D
0005432459008	8323	9	3C
0005435884385	8323	10	3F
0005435884375	8323	11	4D
0005435884414	8323	12	4F
0005432458980	8323	13	5D
0005432042479	8323	14	6A
0005432042473	8323	15	6C
0005432458965	8323	16	6D
0005432458991	8323	17	7C
0005432459003	8323	18	7F
0005432458999	8323	19	8D
0005435884405	8323	20	8C
0005435884410	8323	21	9A
0005432042478	8323	22	8F
0005435884408	8323	23	9B
0005432458978	8323	24	9C
0005432458956	8323	25	9D
0005432459005	8323	26	10A
0005435884411	8323	27	10B
0005432042469	8323	28	10D
0005435884384	8323	29	10C
0005435884377	8323	30	10E
0005432458979	8323	31	11C
0005432458967	8323	32	11B
0005432458993	8323	33	11D
0005435884417	8323	34	11E
0005435884378	8323	35	12A
0005435884418	8323	36	11F
0005435884415	8323	37	12C
0005432458990	8323	38	12E
0005432458995	8323	39	12D
0005432458963	8323	40	13A
0005432042471	8323	41	12F
0005432458962	8323	42	13B
0005432459001	8323	43	13C
0005435884420	8323	44	13F
0005435884425	8323	45	13E
0005432458971	8323	46	14A
0005432458996	8323	47	14C
0005435884381	8323	48	14D
0005435884372	8323	49	14E
0005435884424	8323	50	14F
0005435884373	8323	51	15B
0005432458960	8323	52	15F
0005435884374	8323	53	15E
0005435884422	8323	54	16A
0005435884391	8323	55	16C
0005432458985	8323	56	16F
0005435884401	8323	57	17B
0005432458970	8323	58	17C
0005435884407	8323	59	17D
0005432458968	8323	60	17E
0005432459006	8323	61	18B
0005434312283	8323	62	18D
0005435884386	8323	63	18C
0005432458974	8323	64	18E
0005434312284	8323	65	19C
0005435884412	8323	66	19B
0005432458977	8323	67	19E
0005435884389	8323	68	20B
0005435884404	8323	69	20A
0005432459000	8323	70	20D
0005435884397	8323	71	20C
0005432042475	8323	72	20E
0005432458966	8323	73	20F
0005435884383	8323	74	21A
0005435884371	8323	75	21C
0005432458988	8323	76	21E
0005435884426	8323	77	21D
0005432458975	8323	78	22B
0005435884402	8323	79	22A
0005435884398	8323	80	22D
0005435884396	8323	81	22C
0005435884416	8323	82	22E
0005432458997	8323	83	23A
0005435884390	8323	84	23C
0005435884370	8323	85	23B
0005432458983	8323	86	23D
0005435884394	8323	87	23E
0005432042472	8323	88	24A
0005435884400	8323	89	23F
0005432042476	8323	90	24D
0005435884421	8323	91	24C
0005435884419	8323	92	24E
0005435884395	8323	93	25B
0005432459004	8323	94	25A
0005432458976	8323	95	25D
0005432458961	8323	96	25C
0005432459009	8323	97	25E
0005435884413	8323	98	25F
0005435884423	8323	99	26B
0005432458989	8323	100	26A
0005432042474	8323	101	26C
0005432458987	8323	102	26E
0005435884387	8323	103	26F
0005432458969	8323	104	27C
0005435884376	8323	105	27D
0005432459002	8323	106	27F
0005432458957	8323	107	27E
0005435884406	8323	108	28C
0005435884399	8323	109	28B
0005432459007	8323	110	28A
0005432042480	8323	111	28E
0005432458998	8323	112	29A
0005432458981	8323	113	29C
0005432458958	8323	114	29B
0005432458959	8323	115	29D
0005432458982	8323	116	29F
0005432042470	8323	117	29E
0005435884379	8323	118	30A
0005432042468	8323	119	30B
0005435884392	8323	120	30C
0005435884380	8323	121	30E
0005432042477	8323	122	30D
0005432458986	8323	123	31C
0005432458994	8323	124	31D
0005435884403	8323	125	31F
0005435884388	8323	126	31E
0005432382506	4522	1	1A
0005432382517	4522	2	1F
0005432727721	4522	3	3A
0005432382485	4522	4	3C
0005432382509	4522	5	3D
0005432382488	4522	6	3F
0005432727716	4522	7	4A
0005432727720	4522	8	5A
0005433722105	4522	9	5D
0005432382501	4522	10	5E
0005432382505	4522	11	5F
0005432382511	4522	12	6C
0005432382500	4522	13	6E
0005432727722	4522	14	7A
0005432382495	4522	15	7F
0005432382508	4522	16	8A
0005432727727	4522	17	8C
0005432382492	4522	18	8D
0005432727725	4522	19	9C
0005432382497	4522	20	9D
0005432382486	4522	21	9F
0005432382512	4522	22	10C
0005432382507	4522	23	10D
0005432382493	4522	24	10F
0005433722106	4522	25	11A
0005432382514	4522	26	11C
0005433722103	4522	27	11D
0005432382484	4522	28	11F
0005432382502	4522	29	12A
0005432382499	4522	30	12C
0005432382519	4522	31	12F
0005432382503	4522	32	13C
0005432382504	4522	33	13D
0005433722104	4522	34	13F
0005433453727	4522	35	14A
0005432382510	4522	36	14C
0005432727719	4522	37	14E
0005432727718	4522	38	14F
0005432382498	4522	39	15A
0005433722102	4522	40	15C
0005432382496	4522	41	15D
0005432382487	4522	42	15E
0005432382516	4522	43	15F
0005432727717	4522	44	16A
0005432727723	4522	45	16C
0005432382518	4522	46	16F
0005432382490	4522	47	17A
0005433454838	4522	48	17C
0005432382489	4522	49	17F
0005432727724	4522	50	18A
0005433453726	4522	51	18C
0005432727726	4522	52	19C
0005432382494	4522	53	19D
0005432382515	4522	54	19E
0005433454837	4522	55	19F
0005432382513	4522	56	20A
0005432382491	4522	57	20D
0005432382520	4522	58	20E
0005435528884	1764	1	1C
0005433516726	1764	2	1D
0005432294445	1764	3	1F
0005435540628	1764	4	2C
0005435528879	1764	5	2F
0005435528885	1764	6	3A
0005435528896	1764	7	3C
0005435540640	1764	8	4E
0005435540625	1764	9	5C
0005435540639	1764	10	5D
0005435540638	1764	11	5E
0005435540630	1764	12	5F
0005435528894	1764	13	6D
0005435540627	1764	14	6E
0005435528893	1764	15	6F
0005435540633	1764	16	7A
0005435528898	1764	17	7D
0005435540635	1764	18	7E
0005435528891	1764	19	7F
0005433516727	1764	20	8C
0005435540643	1764	21	8F
0005435540641	1764	22	9A
0005435540634	1764	23	9C
0005435540632	1764	24	9E
0005435528880	1764	25	9F
0005433516722	1764	26	10A
0005435528887	1764	27	10C
0005435540629	1764	28	10E
0005435528883	1764	29	10F
0005435528881	1764	30	11A
0005435528882	1764	31	11C
0005435540631	1764	32	11E
0005435540623	1764	33	12C
0005433516729	1764	34	13A
0005435540637	1764	35	13D
0005435528895	1764	36	13E
0005433516721	1764	37	14A
0005435528899	1764	38	14C
0005435540642	1764	39	14D
0005435528892	1764	40	14E
0005435528900	1764	41	15A
0005435540636	1764	42	15C
0005432294446	1764	43	15D
0005435528886	1764	44	15E
0005435540626	1764	45	15F
0005433516723	1764	46	16E
0005435540622	1764	47	16F
0005435528890	1764	48	17E
0005435540624	1764	49	17F
0005433516725	1764	50	18A
0005433516724	1764	51	18C
0005435528888	1764	52	20A
0005435528889	1764	53	20C
0005435528897	1764	54	20D
0005433516728	1764	55	20F
0005432924953	21969	1	6A
0005432924951	21969	2	9E
0005432924955	21969	3	12D
0005432924952	21969	4	14D
0005432924954	21969	5	15E
0005434458440	7364	1	1A
0005432838490	7364	2	1C
0005432838492	7364	3	1F
0005434458439	7364	4	2A
0005432838507	7364	5	2C
0005432838495	7364	6	4C
0005434458449	7364	7	4D
0005434458437	7364	8	4E
0005434458448	7364	9	5E
0005432838510	7364	10	5F
0005432838488	7364	11	6A
0005432073330	7364	12	6E
0005434458433	7364	13	6F
0005434458436	7364	14	7A
0005432838505	7364	15	7E
0005434458450	7364	16	7F
0005432838498	7364	17	8A
0005434458452	7364	18	8C
0005434458434	7364	19	8D
0005432838509	7364	20	8E
0005432838497	7364	21	9D
0005432073331	7364	22	9E
0005434458443	7364	23	10A
0005432838496	7364	24	10C
0005432838484	7364	25	10E
0005434458453	7364	26	11D
0005432838489	7364	27	11E
0005432838487	7364	28	12C
0005432838480	7364	29	12E
0005434458435	7364	30	12F
0005434458438	7364	31	13A
0005434458442	7364	32	13D
0005434458451	7364	33	13F
0005432838499	7364	34	14A
0005432073329	7364	35	14C
0005432838481	7364	36	14D
0005432838483	7364	37	14E
0005432838503	7364	38	14F
0005432838511	7364	39	15C
0005432838485	7364	40	15D
0005434458441	7364	41	15E
0005432838501	7364	42	15F
0005434458447	7364	43	17A
0005432838482	7364	44	17D
0005434458444	7364	45	17C
0005432838502	7364	46	17E
0005432838486	7364	47	18C
0005434458445	7364	48	18D
0005432838508	7364	49	18E
0005432838500	7364	50	19C
0005434458446	7364	51	19D
0005432838493	7364	52	19E
0005432838491	7364	53	20C
0005432838506	7364	54	20D
0005432838494	7364	55	20E
0005432838504	7364	56	20F
0005435252378	28935	1	1A
0005435252382	28935	2	1D
0005435252385	28935	3	2C
0005435252379	28935	4	2D
0005435252390	28935	5	3A
0005435252381	28935	6	4E
0005435252396	28935	7	5C
0005435491407	28935	8	6A
0005435252383	28935	9	6D
0005432000987	28935	10	7A
0005435252393	28935	11	8A
0005435252392	28935	12	9F
0005435252388	28935	13	10A
0005432000988	28935	14	10E
0005434664920	28935	15	11D
0005435252380	28935	16	11F
0005434664919	28935	17	14F
0005435252384	28935	18	15C
0005435252389	28935	19	16A
0005435252395	28935	20	18A
0005435491405	28935	21	18D
0005435491406	28935	22	18E
0005435252391	28935	23	19E
0005435252387	28935	24	19F
0005435252394	28935	25	20E
0005435252386	28935	26	20F
0005435990502	8817	1	3A
0005435990497	8817	2	6B
0005435990498	8817	3	6D
0005435990503	8817	4	7E
0005435990501	8817	5	13B
0005435990499	8817	6	14C
0005435990500	8817	7	20B
0005434275928	15750	1	1F
0005434275925	15750	2	11C
0005434275926	15750	3	11D
0005434275924	15750	4	18A
0005434275927	15750	5	20D
0005433468183	2079	1	1D
0005433468182	2079	2	3B
0005433468185	2079	3	5D
0005433468184	2079	4	7C
0005433468181	2079	5	20C
0005433468186	2079	6	21C
0005433468180	2079	7	22D
0005433468187	2079	8	23A
0005433468188	2079	9	23B
0005432359506	6411	1	1A
0005432062135	6411	2	1F
0005432359555	6411	3	2C
0005432359536	6411	4	2D
0005432335821	6411	5	3C
0005432335824	6411	6	3A
0005432359533	6411	7	3F
0005432359552	6411	8	4B
0005432359525	6411	9	4E
0005432335829	6411	10	4D
0005432359537	6411	11	5B
0005432359513	6411	12	5C
0005432359521	6411	13	6C
0005432062136	6411	14	6B
0005432359527	6411	15	6D
0005432335825	6411	16	7D
0005432359540	6411	17	7E
0005432335822	6411	18	8A
0005432359544	6411	19	8C
0005432363360	6411	20	8E
0005432359507	6411	21	8F
0005432359550	6411	22	9B
0005432335823	6411	23	9C
0005432359529	6411	24	9F
0005432359543	6411	25	10B
0005432359511	6411	26	10E
0005432359528	6411	27	11D
0005432359551	6411	28	11F
0005432359522	6411	29	12B
0005432359547	6411	30	12D
0005432359510	6411	31	12C
0005432359532	6411	32	12E
0005432359524	6411	33	12F
0005432359508	6411	34	13A
0005432359541	6411	35	13B
0005432359542	6411	36	13D
0005432335827	6411	37	13E
0005432359512	6411	38	13F
0005432359518	6411	39	14A
0005432359517	6411	40	14C
0005432359548	6411	41	14F
0005432062134	6411	42	15B
0005432062137	6411	43	15D
0005432363359	6411	44	15E
0005432335820	6411	45	16A
0005432359519	6411	46	15F
0005432359539	6411	47	16B
0005432359554	6411	48	16E
0005432359534	6411	49	16F
0005432062139	6411	50	17A
0005432335826	6411	51	17E
0005432335830	6411	52	18A
0005432359530	6411	53	17F
0005432335831	6411	54	18B
0005432335828	6411	55	18D
0005432062138	6411	56	18C
0005432359526	6411	57	18F
0005432359520	6411	58	19C
0005432359545	6411	59	20B
0005432359531	6411	60	20C
0005432359515	6411	61	20E
0005432359514	6411	62	21B
0005432359523	6411	63	21F
0005432359538	6411	64	22A
0005432359546	6411	65	22B
0005432359535	6411	66	22E
0005432359553	6411	67	23A
0005432359549	6411	68	22F
0005432359516	6411	69	23B
0005432359509	6411	70	23C
0005435176585	20993	1	1C
0005435723010	20993	2	2A
0005434149526	20993	3	3C
0005435176587	20993	4	4B
0005435176608	20993	5	4E
0005434149522	20993	6	4F
0005435176610	20993	7	5C
0005435176594	20993	8	5F
0005435176612	20993	9	5E
0005435723009	20993	10	6D
0005435176601	20993	11	7B
0005435176603	20993	12	8A
0005435176596	20993	13	7F
0005432052694	20993	14	8C
0005435176602	20993	15	8F
0005434149529	20993	16	9A
0005432052692	20993	17	9B
0005435176590	20993	18	9C
0005435176600	20993	19	9E
0005434149521	20993	20	9D
0005435176588	20993	21	9F
0005435176599	20993	22	10B
0005434149528	20993	23	10C
0005435490169	20993	24	10E
0005432052693	20993	25	11A
0005434149530	20993	26	11E
0005435176592	20993	27	11F
0005435176593	20993	28	12B
0005432052691	20993	29	12C
0005435176609	20993	30	13D
0005435176597	20993	31	13E
0005435490172	20993	32	14D
0005435176604	20993	33	14E
0005434149531	20993	34	14F
0005435176591	20993	35	15C
0005435176589	20993	36	15B
0005434149527	20993	37	16A
0005435176586	20993	38	15F
0005435176611	20993	39	17A
0005435176598	20993	40	17B
0005435176607	20993	41	18A
0005434149525	20993	42	18B
0005435176605	20993	43	18E
0005435176595	20993	44	19A
0005435490173	20993	45	19B
0005435176606	20993	46	19E
0005434149523	20993	47	22D
0005435490170	20993	48	22F
0005434149520	20993	49	23A
0005435490171	20993	50	23B
0005434149524	20993	51	23E
0005434186148	17732	1	4D
0005434186147	17732	2	7D
0005434186149	17732	3	20A
0005434458435	29107	1	1A
0005434458448	29107	2	2A
0005434458445	29107	3	2C
0005434458442	29107	4	3A
0005434458446	29107	5	3C
0005434458449	29107	6	4A
0005434458452	29107	7	4C
0005434458437	29107	8	5C
0005434458450	29107	9	5D
0005434458440	29107	10	6A
0005434458453	29107	11	6B
0005434458447	29107	12	7C
0005434458444	29107	13	7D
0005434458451	29107	14	18B
0005434458433	29107	15	19B
0005434458439	29107	16	20D
0005434458434	29107	17	21B
0005434458441	29107	18	22A
0005434458438	29107	19	22B
0005434458436	29107	20	22C
0005434458443	29107	21	22D
0005435221036	31696	1	1B
0005435221035	31696	2	1C
0005435221497	31696	3	2A
0005433293144	29590	1	2D
0005433293143	29590	2	7A
0005433293145	29590	3	18A
0005433293142	29590	4	18D
0005433293146	29590	5	20C
0005433293147	29590	6	21C
0005433473104	6691	1	2A
0005433473108	6691	2	3B
0005433473101	6691	3	4A
0005433473107	6691	4	6A
0005433473103	6691	5	6B
0005433473106	6691	6	18A
0005433473105	6691	7	21B
0005433473102	6691	8	22C
0005433473100	6691	9	23A
0005432746899	370	1	1A
0005432746871	370	2	1D
0005432746901	370	3	1F
0005432746867	370	4	2C
0005432746878	370	5	3C
0005432746869	370	6	4A
0005432746898	370	7	4C
0005432746876	370	8	4D
0005432746886	370	9	4F
0005432746872	370	10	5A
0005432746880	370	11	5C
0005432746896	370	12	5E
0005432746893	370	13	5F
0005432219928	370	14	6E
0005432746883	370	15	7A
0005432219929	370	16	7D
0005432746891	370	17	7E
0005432746902	370	18	8C
0005432746875	370	19	8D
0005432746887	370	20	9C
0005432746900	370	21	10E
0005432746895	370	22	10F
0005432746865	370	23	11A
0005432746866	370	24	11E
0005432746884	370	25	11F
0005432746889	370	26	12C
0005432746888	370	27	12D
0005432746873	370	28	12F
0005432746890	370	29	13F
0005432746877	370	30	14C
0005432746879	370	31	14E
0005432746868	370	32	14F
0005432746874	370	33	16D
0005432746892	370	34	16E
0005432219926	370	35	17C
0005432746881	370	36	17E
0005432746864	370	37	17F
0005432746897	370	38	18C
0005432746870	370	39	19C
0005432746882	370	40	19D
0005432219927	370	41	19E
0005432746885	370	42	20C
0005432746894	370	43	20F
0005432890687	12076	1	1A
0005432890680	12076	2	1C
0005432890679	12076	3	2A
0005432214765	12076	4	2D
0005432890686	12076	5	3D
0005432890688	12076	6	4F
0005432214766	12076	7	5F
0005432214764	12076	8	6C
0005432890670	12076	9	8C
0005433875352	12076	10	8F
0005432890675	12076	11	10F
0005432890671	12076	12	11E
0005432890689	12076	13	12E
0005432890672	12076	14	13C
0005432890677	12076	15	13D
0005432890678	12076	16	14D
0005432890674	12076	17	15D
0005432890683	12076	18	16C
0005432890669	12076	19	17C
0005432890673	12076	20	17E
0005432890682	12076	21	17F
0005432890684	12076	22	18D
0005432890681	12076	23	18E
0005432890676	12076	24	19D
0005432890685	12076	25	20F
0005432927886	32474	1	6A
0005432927885	32474	2	6B
0005432927888	32474	3	20C
0005432927889	32474	4	22A
0005432927887	32474	5	22B
0005434821383	5254	1	1C
0005434821405	5254	2	1G
0005432396171	5254	3	2A
0005434821341	5254	4	2H
0005434821329	5254	5	3G
0005434821353	5254	6	3C
0005434821372	5254	7	4C
0005434821375	5254	8	4A
0005434821347	5254	9	4G
0005435149796	5254	10	4H
0005432394035	5254	11	5C
0005434821390	5254	12	5A
0005432121094	5254	13	5H
0005434821349	5254	14	11A
0005434821389	5254	15	11F
0005434821357	5254	16	11K
0005434821364	5254	17	11H
0005434821323	5254	18	12G
0005434821419	5254	19	12F
0005434821348	5254	20	13H
0005434821345	5254	21	13G
0005434821358	5254	22	14A
0005434821346	5254	23	13K
0005432394033	5254	24	14C
0005434821438	5254	25	14G
0005434821382	5254	26	14F
0005434821338	5254	27	15A
0005434821437	5254	28	14K
0005434821377	5254	29	15F
0005432121085	5254	30	16A
0005434821325	5254	31	15K
0005434821340	5254	32	15H
0005434821411	5254	33	16D
0005434821367	5254	34	16C
0005432121090	5254	35	16F
0005432121087	5254	36	16H
0005434821426	5254	37	16G
0005434821337	5254	38	17D
0005434821397	5254	39	17G
0005434821417	5254	40	17F
0005434821392	5254	41	17H
0005434821363	5254	42	18E
0005434821343	5254	43	18C
0005434821321	5254	44	18J
0005434821332	5254	45	19C
0005434821386	5254	46	19E
0005434821312	5254	47	20C
0005434821422	5254	48	21B
0005434821391	5254	49	21A
0005434821316	5254	50	21D
0005434821339	5254	51	21F
0005434821378	5254	52	21E
0005434821376	5254	53	21J
0005434821314	5254	54	21H
0005432396173	5254	55	21K
0005434821430	5254	56	22D
0005434821388	5254	57	22E
0005434821423	5254	58	22K
0005434821407	5254	59	23A
0005434821395	5254	60	23F
0005434821311	5254	61	23E
0005432121088	5254	62	25B
0005434821355	5254	63	25A
0005434821393	5254	64	25D
0005434821374	5254	65	25C
0005434821327	5254	66	25F
0005434821399	5254	67	25G
0005435149793	5254	68	25K
0005434821334	5254	69	26E
0005434821400	5254	70	26G
0005432396170	5254	71	27B
0005435149788	5254	72	27F
0005434821403	5254	73	27J
0005434821387	5254	74	28B
0005434821354	5254	75	28E
0005434821416	5254	76	28D
0005434821342	5254	77	28F
0005434821320	5254	78	29B
0005434821352	5254	79	29E
0005434821414	5254	80	29H
0005434821396	5254	81	29K
0005434821381	5254	82	29J
0005434821429	5254	83	30A
0005434821409	5254	84	30E
0005435149792	5254	85	30H
0005434821428	5254	86	30G
0005434821319	5254	87	31A
0005434821362	5254	88	31D
0005432121092	5254	89	31C
0005435149785	5254	90	31E
0005432394034	5254	91	31H
0005434821356	5254	92	32A
0005434821333	5254	93	32H
0005434821315	5254	94	33D
0005434821326	5254	95	33C
0005434821368	5254	96	33J
0005432121084	5254	97	33H
0005435149797	5254	98	33K
0005435149789	5254	99	34C
0005434821394	5254	100	34E
0005434821418	5254	101	34D
0005434821318	5254	102	34K
0005434821384	5254	103	35A
0005434821415	5254	104	35E
0005434821361	5254	105	35J
0005434821317	5254	106	35G
0005434821370	5254	107	36F
0005432394032	5254	108	36D
0005434821408	5254	109	37D
0005434821335	5254	110	37F
0005434821425	5254	111	37H
0005434821406	5254	112	37K
0005435149786	5254	113	38C
0005434821410	5254	114	38A
0005434821421	5254	115	38J
0005435149795	5254	116	39F
0005434821371	5254	117	40A
0005434821366	5254	118	39K
0005434821433	5254	119	40D
0005432121091	5254	120	40F
0005434821435	5254	121	40J
0005432121083	5254	122	40K
0005434821336	5254	123	41D
0005435149794	5254	124	41C
0005434821344	5254	125	41G
0005434821385	5254	126	41E
0005434821432	5254	127	41H
0005432121095	5254	128	42C
0005434821412	5254	129	42B
0005434821398	5254	130	42A
0005434821427	5254	131	42D
0005434821420	5254	132	43F
0005432396174	5254	133	43H
0005435149790	5254	134	43G
0005434821413	5254	135	43K
0005434821328	5254	136	44A
0005432121089	5254	137	44E
0005434821330	5254	138	44F
0005434821369	5254	139	44J
0005434821434	5254	140	44H
0005434821436	5254	141	45B
0005432396172	5254	142	45A
0005434821404	5254	143	45C
0005434821380	5254	144	45D
0005434821401	5254	145	45G
0005432121086	5254	146	45K
0005434821379	5254	147	45J
0005434821313	5254	148	46B
0005434821351	5254	149	46G
0005434821365	5254	150	46F
0005434821439	5254	151	46H
0005435149787	5254	152	47E
0005432121093	5254	153	47F
0005434821373	5254	154	47K
0005434821331	5254	155	47H
0005434821424	5254	156	48D
0005434821359	5254	157	48C
0005434821431	5254	158	48K
0005434821322	5254	159	49D
0005435149791	5254	160	49C
0005434821402	5254	161	50D
0005434821350	5254	162	50F
0005434821324	5254	163	51D
0005434821360	5254	164	50H
0005435372151	9891	1	2C
0005435372158	9891	2	2G
0005435735057	9891	3	2K
0005435372150	9891	4	3K
0005435372145	9891	5	5H
0005435372110	9891	6	11D
0005435372100	9891	7	11G
0005435372147	9891	8	12C
0005435372157	9891	9	12D
0005435372149	9891	10	13C
0005435372125	9891	11	13H
0005435372107	9891	12	14E
0005435372097	9891	13	14D
0005432202939	9891	14	14G
0005435386455	9891	15	14K
0005435661881	9891	16	15F
0005435372132	9891	17	15K
0005435372140	9891	18	16D
0005435372103	9891	19	16C
0005435372154	9891	20	16G
0005432202933	9891	21	17E
0005435372104	9891	22	17F
0005435372102	9891	23	18B
0005432202936	9891	24	18H
0005435372094	9891	25	19C
0005435372142	9891	26	19E
0005435372136	9891	27	19J
0005435661880	9891	28	21B
0005435735055	9891	29	21G
0005435386456	9891	30	22C
0005435372115	9891	31	22E
0005432823415	9891	32	22G
0005435372105	9891	33	22K
0005435372121	9891	34	24F
0005435372144	9891	35	25A
0005435372114	9891	36	25C
0005435372153	9891	37	25B
0005435372137	9891	38	25E
0005432202940	9891	39	27D
0005435372106	9891	40	27E
0005435372113	9891	41	27G
0005435372143	9891	42	28D
0005435372129	9891	43	29C
0005435661879	9891	44	30C
0005435372099	9891	45	31K
0005435372133	9891	46	32C
0005435372123	9891	47	32B
0005435372126	9891	48	32G
0005435372118	9891	49	33D
0005435372127	9891	50	33C
0005435372130	9891	51	33E
0005432202938	9891	52	34D
0005435372098	9891	53	34G
0005435372096	9891	54	34F
0005435735059	9891	55	35B
0005435372122	9891	56	35A
0005435735056	9891	57	35D
0005432202937	9891	58	36D
0005435372138	9891	59	36B
0005435372124	9891	60	36H
0005435372156	9891	61	37A
0005435372109	9891	62	37G
0005435735058	9891	63	37F
0005435372152	9891	64	39C
0005435372141	9891	65	39G
0005435372095	9891	66	41E
0005432202935	9891	67	42D
0005435372131	9891	68	42F
0005435372146	9891	69	42K
0005435372134	9891	70	43A
0005435372117	9891	71	43D
0005435372128	9891	72	44E
0005435372112	9891	73	45A
0005435372116	9891	74	45C
0005435372101	9891	75	46C
0005435372155	9891	76	46D
0005435372135	9891	77	47A
0005432202934	9891	78	47G
0005435386457	9891	79	47E
0005435372139	9891	80	47H
0005435386454	9891	81	48G
0005435372119	9891	82	49C
0005435372120	9891	83	49G
0005435372148	9891	84	50A
0005435372111	9891	85	50G
0005435372108	9891	86	50K
0005435082647	6978	1	1B
0005435082645	6978	2	2C
0005435082646	6978	3	5A
0005435790256	6978	4	6A
0005435790255	6978	5	18B
0005435082644	6978	6	19C
0005435082643	6978	7	21A
0005435082649	6978	8	22B
0005435082648	6978	9	22C
0005434755729	9528	1	1C
0005434755725	9528	2	1F
0005434755717	9528	3	2A
0005434755712	9528	4	2F
0005434755709	9528	5	3F
0005434755720	9528	6	4A
0005434755719	9528	7	4E
0005434755710	9528	8	5A
0005434755721	9528	9	5C
0005434755724	9528	10	5F
0005434755728	9528	11	6A
0005434755708	9528	12	6F
0005434755735	9528	13	7A
0005434755705	9528	14	7D
0005434755704	9528	15	8D
0005434755711	9528	16	9E
0005434755718	9528	17	9D
0005434755715	9528	18	9F
0005434755727	9528	19	10D
0005434755706	9528	20	11D
0005434755716	9528	21	12D
0005434755732	9528	22	12E
0005434755713	9528	23	13D
0005434755734	9528	24	14A
0005434755730	9528	25	15C
0005434755723	9528	26	16E
0005434755707	9528	27	16F
0005434755703	9528	28	17D
0005434755714	9528	29	17E
0005434755731	9528	30	18E
0005434755726	9528	31	18F
0005434755733	9528	32	19E
0005434755722	9528	33	20E
0005435100070	10806	1	7B
0005435100071	10806	2	18A
0005435100069	10806	3	21B
0005434760153	31815	1	6C
0005434760155	31815	2	19D
0005434760154	31815	3	20D
0005434638861	1994	1	1A
0005434638852	1994	2	1B
0005434638867	1994	3	1C
0005434638851	1994	4	2A
0005432290582	1994	5	2C
0005434638858	1994	6	2D
0005434638875	1994	7	3A
0005434638868	1994	8	3B
0005434638846	1994	9	3C
0005434638849	1994	10	3D
0005434638865	1994	11	4C
0005434638869	1994	12	4D
0005434638873	1994	13	5B
0005434638855	1994	14	5C
0005432290579	1994	15	6A
0005435948304	1994	16	6B
0005432290581	1994	17	6C
0005434638853	1994	18	6D
0005434638866	1994	19	7B
0005434638872	1994	20	7D
0005434638862	1994	21	18A
0005434638863	1994	22	18B
0005434638854	1994	23	19A
0005434638871	1994	24	19B
0005434638850	1994	25	19D
0005435948306	1994	26	20B
0005434638860	1994	27	20C
0005432290580	1994	28	20D
0005434638856	1994	29	21A
0005434638848	1994	30	21B
0005434638857	1994	31	21C
0005434638847	1994	32	21D
0005434638864	1994	33	22B
0005435948305	1994	34	22A
0005434638859	1994	35	22C
0005434638870	1994	36	22D
0005434638874	1994	37	23B
0005434600341	6050	1	1A
0005434600351	6050	2	1C
0005434600342	6050	3	1F
0005433531228	6050	4	2A
0005434600333	6050	5	2C
0005433531225	6050	6	2F
0005433533242	6050	7	3A
0005434600346	6050	8	3D
0005434600336	6050	9	3F
0005434600338	6050	10	4A
0005434600349	6050	11	4E
0005434600331	6050	12	5F
0005434600340	6050	13	6F
0005432111226	6050	14	7D
0005434600332	6050	15	7F
0005433533241	6050	16	8F
0005433531226	6050	17	9E
0005434600337	6050	18	10C
0005434600343	6050	19	11C
0005434600329	6050	20	11F
0005433533240	6050	21	12C
0005434600353	6050	22	12D
0005434600334	6050	23	13D
0005434600328	6050	24	13E
0005433533243	6050	25	15A
0005432111227	6050	26	15D
0005434600330	6050	27	15E
0005434600339	6050	28	15F
0005433531227	6050	29	16C
0005434600350	6050	30	17A
0005434600345	6050	31	17E
0005434600344	6050	32	18A
0005434600352	6050	33	18D
0005434600347	6050	34	18F
0005434600348	6050	35	18E
0005434600335	6050	36	19C
0005432111225	6050	37	19D
0005434600327	6050	38	20D
0005435326511	18571	1	2C
0005435326498	18571	2	4D
0005435326500	18571	3	4F
0005435326507	18571	4	6E
0005435326510	18571	5	9C
0005435326497	18571	6	11A
0005435326506	18571	7	13C
0005435326501	18571	8	14D
0005435326509	18571	9	15F
0005435326499	18571	10	16A
0005435326504	18571	11	16C
0005435326505	18571	12	18E
0005435326502	18571	13	19C
0005435326503	18571	14	19F
0005435326508	18571	15	20D
0005434554024	10653	1	15C
0005433180671	27692	1	1A
0005433180663	27692	2	2D
0005433180665	27692	3	2F
0005433180648	27692	4	3A
0005433180649	27692	5	3D
0005433180661	27692	6	3F
0005433180650	27692	7	4E
0005433180667	27692	8	5D
0005433180662	27692	9	6E
0005433180659	27692	10	7A
0005433180672	27692	11	6F
0005433180670	27692	12	7C
0005433180657	27692	13	7F
0005433180652	27692	14	8A
0005433180656	27692	15	10D
0005433180673	27692	16	10F
0005433180655	27692	17	11C
0005433180654	27692	18	11E
0005433180658	27692	19	12A
0005433180666	27692	20	12C
0005433180660	27692	21	13D
0005433180664	27692	22	13E
0005433180653	27692	23	14C
0005433180651	27692	24	14E
0005433180668	27692	25	16F
0005433180669	27692	26	20C
0005433459143	6148	1	1B
0005433459145	6148	2	2B
0005433459146	6148	3	5A
0005433459144	6148	4	6B
0005435254429	19301	1	2B
0005435254430	19301	2	6A
0005435681419	6733	1	1A
0005435681402	6733	2	1F
0005432136082	6733	3	2A
0005435681386	6733	4	2C
0005432136083	6733	5	2F
0005435681404	6733	6	3A
0005435681421	6733	7	4A
0005435681423	6733	8	4E
0005435681425	6733	9	5A
0005435681403	6733	10	5D
0005435681390	6733	11	6A
0005435681408	6733	12	6C
0005435720118	6733	13	6D
0005435681384	6733	14	6E
0005435681422	6733	15	6F
0005432136081	6733	16	7A
0005435681411	6733	17	7C
0005435681392	6733	18	7E
0005435681389	6733	19	8A
0005435681401	6733	20	8D
0005435681385	6733	21	8E
0005435681415	6733	22	8F
0005435681395	6733	23	9A
0005435681396	6733	24	9C
0005435681399	6733	25	9F
0005435681410	6733	26	10C
0005435681391	6733	27	10E
0005435681414	6733	28	11A
0005435681420	6733	29	11E
0005432136079	6733	30	12C
0005435681417	6733	31	12D
0005435720119	6733	32	13A
0005432136084	6733	33	13D
0005435681407	6733	34	13E
0005435681427	6733	35	14D
0005435681393	6733	36	14E
0005435681405	6733	37	14F
0005432136080	6733	38	15A
0005435681394	6733	39	15D
0005435681397	6733	40	16A
0005435681426	6733	41	16C
0005435681387	6733	42	17C
0005435681424	6733	43	17D
0005435681388	6733	44	18C
0005435681413	6733	45	18D
0005435681409	6733	46	18E
0005435681412	6733	47	18F
0005435681400	6733	48	19F
0005435681398	6733	49	20A
0005435681418	6733	50	20C
0005435681406	6733	51	20D
0005435681416	6733	52	20F
0005435437570	24574	1	1C
0005435437562	24574	2	2C
0005435437557	24574	3	2D
0005435437568	24574	4	3C
0005435437573	24574	5	3D
0005432533240	24574	6	4C
0005435437566	24574	7	4D
0005435437574	24574	8	5D
0005432305706	24574	9	6A
0005434828649	24574	10	6C
0005435437563	24574	11	6E
0005435437567	24574	12	6F
0005435437569	24574	13	7E
0005435437572	24574	14	7F
0005435437559	24574	15	8A
0005435437551	24574	16	8C
0005435437553	24574	17	9C
0005434828650	24574	18	9E
0005435437560	24574	19	9F
0005434828648	24574	20	10A
0005435437554	24574	21	11A
0005432305705	24574	22	11D
0005435437564	24574	23	12E
0005435437571	24574	24	15D
0005432533241	24574	25	16D
0005435437555	24574	26	17C
0005435437565	24574	27	18D
0005435437558	24574	28	18F
0005432533242	24574	29	19F
0005435437556	24574	30	20C
0005435437561	24574	31	20E
0005435437552	24574	32	20F
0005435105923	11521	1	14E
0005435105925	11521	2	18E
0005435105924	11521	3	20A
0005435558039	31901	1	4C
0005435558040	31901	2	7D
0005435558041	31901	3	18F
0005433397181	13537	1	1F
0005433397182	13537	2	2A
0005433397222	13537	3	3C
0005433397212	13537	4	3D
0005433397220	13537	5	3F
0005433397200	13537	6	4A
0005433397203	13537	7	4C
0005433397184	13537	8	4E
0005433397179	13537	9	6D
0005433397188	13537	10	6E
0005433397202	13537	11	6F
0005433397196	13537	12	7D
0005433397213	13537	13	7E
0005433397201	13537	14	8C
0005433397224	13537	15	8D
0005433397207	13537	16	8E
0005433397197	13537	17	9A
0005433397208	13537	18	9E
0005433397183	13537	19	9F
0005433397205	13537	20	10C
0005433397187	13537	21	10D
0005433397211	13537	22	10F
0005433397228	13537	23	11C
0005433397217	13537	24	11D
0005433397194	13537	25	11F
0005433397214	13537	26	12E
0005433397189	13537	27	12F
0005433397215	13537	28	13D
0005433397226	13537	29	13F
0005433397225	13537	30	14A
0005433397216	13537	31	14D
0005433397227	13537	32	14F
0005433397223	13537	33	15C
0005433397185	13537	34	15D
0005433397198	13537	35	15E
0005433397192	13537	36	15F
0005433397219	13537	37	16A
0005433397210	13537	38	16C
0005433397178	13537	39	16D
0005433397206	13537	40	16F
0005433397180	13537	41	17A
0005433397193	13537	42	17D
0005433397218	13537	43	17E
0005433397191	13537	44	18A
0005433397221	13537	45	18C
0005433397199	13537	46	18E
0005433397186	13537	47	19D
0005433397209	13537	48	20A
0005433397190	13537	49	20C
0005433397195	13537	50	20D
0005433397204	13537	51	20F
0005435732116	19417	1	1C
0005435732122	19417	2	2A
0005435732117	19417	3	3A
0005435732114	19417	4	3C
0005435732121	19417	5	4E
0005432297231	19417	6	5A
0005435732119	19417	7	5F
0005435732112	19417	8	8A
0005435732115	19417	9	10F
0005435732123	19417	10	11D
0005432297232	19417	11	13C
0005435732120	19417	12	13E
0005432297230	19417	13	16C
0005435732113	19417	14	16D
0005435732124	19417	15	17D
0005435732118	19417	16	20E
0005435925055	13148	1	2D
0005435925051	13148	2	2F
0005435925047	13148	3	3C
0005435925054	13148	4	5D
0005435925060	13148	5	6F
0005435925049	13148	6	7A
0005435925057	13148	7	7E
0005435925048	13148	8	8A
0005435925052	13148	9	10F
0005435925050	13148	10	12C
0005435925046	13148	11	14F
0005435925058	13148	12	15D
0005435925059	13148	13	15E
0005435925053	13148	14	18F
0005435925056	13148	15	20D
0005433407477	29499	1	1C
0005433407479	29499	2	4D
0005433407478	29499	3	6A
0005433407480	29499	4	20A
0005433407481	29499	5	21B
0005434213729	10699	1	1A
0005434213726	10699	2	1D
0005434213707	10699	3	2A
0005434213720	10699	4	2C
0005434213731	10699	5	3D
0005434213728	10699	6	4A
0005434213740	10699	7	4D
0005434213705	10699	8	4F
0005434213704	10699	9	5C
0005434213702	10699	10	6A
0005434213737	10699	11	6F
0005434213708	10699	12	7A
0005434213732	10699	13	7C
0005434213712	10699	14	7F
0005434213724	10699	15	8A
0005434213743	10699	16	8D
0005434213742	10699	17	8E
0005434213701	10699	18	9A
0005434213709	10699	19	10A
0005434213698	10699	20	10C
0005434213714	10699	21	10D
0005434213717	10699	22	10F
0005434213733	10699	23	11C
0005434213703	10699	24	11D
0005434213734	10699	25	11E
0005434213721	10699	26	11F
0005434213715	10699	27	12C
0005434213713	10699	28	13D
0005434213718	10699	29	13F
0005434213723	10699	30	14D
0005434213711	10699	31	15A
0005434213735	10699	32	15D
0005434213716	10699	33	15E
0005434213744	10699	34	16C
0005434213727	10699	35	16E
0005434213700	10699	36	16F
0005434213719	10699	37	17D
0005434213738	10699	38	17E
0005434213706	10699	39	18A
0005434213736	10699	40	18C
0005434213730	10699	41	18D
0005434213710	10699	42	18E
0005434213741	10699	43	19D
0005434213739	10699	44	19E
0005434213745	10699	45	19F
0005434213725	10699	46	20D
0005434213699	10699	47	20E
0005434213722	10699	48	20F
0005435006602	5474	1	1A
0005432125319	5474	2	1C
0005435038610	5474	3	1D
0005435006618	5474	4	1F
0005435006616	5474	5	2A
0005432125321	5474	6	2D
0005435038645	5474	7	2F
0005435006611	5474	8	3D
0005435038638	5474	9	3F
0005432125324	5474	10	4A
0005435038661	5474	11	4D
0005435038618	5474	12	4C
0005435006606	5474	13	4E
0005435038631	5474	14	4F
0005435006610	5474	15	5B
0005435038643	5474	16	5A
0005435038627	5474	17	5C
0005432125322	5474	18	5D
0005435038656	5474	19	5F
0005435006607	5474	20	6B
0005435038668	5474	21	6F
0005435038619	5474	22	6E
0005435038648	5474	23	7A
0005435038611	5474	24	7C
0005435038642	5474	25	7B
0005435038652	5474	26	7E
0005435038665	5474	27	8A
0005435038626	5474	28	7F
0005435038666	5474	29	8B
0005435006603	5474	30	8C
0005435038672	5474	31	8D
0005435038675	5474	32	8F
0005435038662	5474	33	8E
0005435038659	5474	34	9A
0005435038657	5474	35	9B
0005435006613	5474	36	9C
0005435038663	5474	37	9F
0005435038616	5474	38	9E
0005435038640	5474	39	10B
0005432125325	5474	40	10C
0005435038622	5474	41	10E
0005435038651	5474	42	11A
0005435038654	5474	43	11B
0005435038625	5474	44	11C
0005435038647	5474	45	11D
0005435038637	5474	46	11F
0005432125318	5474	47	12A
0005435038650	5474	48	12D
0005435038639	5474	49	12E
0005435038653	5474	50	13B
0005435038641	5474	51	13A
0005435038628	5474	52	13F
0005435038646	5474	53	14B
0005435006615	5474	54	14D
0005435038671	5474	55	14E
0005435038621	5474	56	14F
0005435006609	5474	57	15C
0005435038649	5474	58	15B
0005435038620	5474	59	15D
0005435038670	5474	60	15F
0005435038615	5474	61	16A
0005435006614	5474	62	16B
0005435042820	5474	63	16C
0005435038614	5474	64	16D
0005435006617	5474	65	16F
0005435006605	5474	66	17B
0005435038612	5474	67	17A
0005435042822	5474	68	17C
0005435038624	5474	69	17E
0005435038658	5474	70	17D
0005435038633	5474	71	17F
0005435038613	5474	72	18B
0005435006604	5474	73	18C
0005435038617	5474	74	18E
0005435038664	5474	75	18D
0005435006601	5474	76	19A
0005432125323	5474	77	19C
0005432125320	5474	78	19E
0005435038644	5474	79	19D
0005435038655	5474	80	19F
0005435042823	5474	81	20A
0005435038634	5474	82	20E
0005435006608	5474	83	20F
0005435042821	5474	84	21B
0005435006619	5474	85	21A
0005435006612	5474	86	21C
0005435038673	5474	87	21E
0005435038629	5474	88	22B
0005435038623	5474	89	22A
0005435038632	5474	90	22C
0005435006620	5474	91	22D
0005435038674	5474	92	22F
0005435038669	5474	93	23B
0005435038660	5474	94	23A
0005435038630	5474	95	23C
0005435038667	5474	96	23E
0005435038635	5474	97	23D
0005435038636	5474	98	23F
0005432304331	12973	1	1F
0005434228978	12973	2	2D
0005434228981	12973	3	5F
0005434228980	12973	4	7B
0005434228970	12973	5	8A
0005434228986	12973	6	8C
0005432304330	12973	7	8E
0005434228988	12973	8	11C
0005434228975	12973	9	11B
0005434228967	12973	10	12C
0005434228968	12973	11	13D
0005434228977	12973	12	14C
0005434228985	12973	13	15C
0005434228971	12973	14	16A
0005432304329	12973	15	17C
0005434228982	12973	16	18D
0005434228979	12973	17	18C
0005434228973	12973	18	19A
0005434228983	12973	19	19C
0005434228987	12973	20	19E
0005434228984	12973	21	20A
0005434228972	12973	22	20D
0005434228974	12973	23	21B
0005434228966	12973	24	22D
0005434228969	12973	25	23B
0005434228976	12973	26	23E
0005432059471	20234	1	1F
0005435554107	20234	2	2A
0005432059469	20234	3	2C
0005435902395	20234	4	2F
0005435902389	20234	5	4C
0005435902393	20234	6	5E
0005435902398	20234	7	6A
0005435902387	20234	8	6F
0005435554103	20234	9	7F
0005435902385	20234	10	9C
0005435902390	20234	11	11D
0005432059470	20234	12	11E
0005435902388	20234	13	11F
0005435554106	20234	14	13C
0005435902397	20234	15	13D
0005435902391	20234	16	13E
0005435902400	20234	17	14A
0005435554104	20234	18	15F
0005435902392	20234	19	16C
0005435902399	20234	20	16F
0005435902401	20234	21	17C
0005435902396	20234	22	18D
0005435902384	20234	23	18F
0005435902386	20234	24	19A
0005435554105	20234	25	19C
0005435902394	20234	26	20F
0005434269067	26680	1	1C
0005433434207	26680	2	2A
0005433434206	26680	3	2C
0005433434187	26680	4	3C
0005433434186	26680	5	4D
0005433434196	26680	6	5C
0005433434181	26680	7	5E
0005433434194	26680	8	6A
0005434269068	26680	9	6C
0005433434195	26680	10	7D
0005433434182	26680	11	7F
0005433434201	26680	12	8A
0005433434198	26680	13	8C
0005433434197	26680	14	8E
0005433434205	26680	15	9C
0005433434202	26680	16	10C
0005433434191	26680	17	10D
0005433434203	26680	18	10E
0005433434208	26680	19	10F
0005433434180	26680	20	11A
0005433434188	26680	21	11C
0005433434192	26680	22	11D
0005434270171	26680	23	12C
0005432051074	26680	24	12D
0005433434183	26680	25	12F
0005434269069	26680	26	13C
0005433434204	26680	27	13E
0005433434184	26680	28	14E
0005433434199	26680	29	15A
0005432051076	26680	30	15D
0005434271275	26680	31	16A
0005433434200	26680	32	16E
0005433434185	26680	33	17C
0005432051075	26680	34	18C
0005433434193	26680	35	19C
0005434270170	26680	36	19D
0005433434190	26680	37	19F
0005433434189	26680	38	20E
0005434271276	26680	39	20F
0005432583598	3180	1	1B
0005432583604	3180	2	1C
0005432583594	3180	3	1D
0005432583591	3180	4	2A
0005432583589	3180	5	2B
0005432583586	3180	6	3C
0005432583606	3180	7	3D
0005432583588	3180	8	4A
0005432583592	3180	9	4B
0005432583600	3180	10	4C
0005432583590	3180	11	4D
0005432583582	3180	12	5B
0005432583585	3180	13	5D
0005432583596	3180	14	6B
0005432583599	3180	15	6C
0005432583583	3180	16	7A
0005432583605	3180	17	7D
0005432583597	3180	18	18A
0005432583584	3180	19	18B
0005432583593	3180	20	19B
0005432583603	3180	21	19C
0005432216222	3180	22	20A
0005432583601	3180	23	20B
0005432216223	3180	24	21B
0005432583602	3180	25	21C
0005432583595	3180	26	22B
0005432583587	3180	27	22D
0005432216224	3180	28	23B
0005432857855	31520	1	2B
0005432857858	31520	2	2C
0005432857852	31520	3	3D
0005432857856	31520	4	4C
0005432857854	31520	5	5B
0005432857860	31520	6	5D
0005432857857	31520	7	6A
0005432857861	31520	8	18D
0005432857859	31520	9	20B
0005432857853	31520	10	21A
0005432857863	31520	11	21D
0005432857862	31520	12	22A
0005434943193	912	1	1D
0005434943187	912	2	3B
0005434943184	912	3	4A
0005434943186	912	4	4C
0005434943191	912	5	5B
0005434943194	912	6	6C
0005434943190	912	7	6D
0005434943185	912	8	7C
0005434943189	912	9	20A
0005434943192	912	10	21C
0005434943188	912	11	23B
0005433255025	16199	1	1A
0005433255023	16199	2	2B
0005433255021	16199	3	5A
0005433255024	16199	4	6B
0005433255022	16199	5	18A
0005433654647	4322	1	3D
0005433654653	4322	2	8E
0005433654648	4322	3	9E
0005433654652	4322	4	9F
0005433654651	4322	5	15C
0005433654650	4322	6	16F
0005433654654	4322	7	17F
0005433654649	4322	8	21D
0005433804791	9336	1	1C
0005433784317	9336	2	1G
0005433762954	9336	3	2H
0005433784328	9336	4	2G
0005432666352	9336	5	3B
0005433804783	9336	6	3G
0005433784321	9336	7	4C
0005433804779	9336	8	4B
0005433804784	9336	9	4F
0005433762944	9336	10	5B
0005433804788	9336	11	5C
0005433784297	9336	12	5G
0005433784312	9336	13	5H
0005433784306	9336	14	12A
0005432665238	9336	15	12E
0005433784316	9336	16	12F
0005433784327	9336	17	13A
0005433784305	9336	18	13B
0005432657393	9336	19	13D
0005433784294	9336	20	13G
0005433762942	9336	21	13F
0005433762949	9336	22	14A
0005433762953	9336	23	15D
0005433784299	9336	24	15F
0005433784326	9336	25	15H
0005433784302	9336	26	16A
0005433784292	9336	27	16H
0005433784313	9336	28	16G
0005433762955	9336	29	17A
0005433784322	9336	30	17D
0005433804780	9336	31	17B
0005433784324	9336	32	17H
0005432666353	9336	33	18F
0005433804785	9336	34	18H
0005433784320	9336	35	19B
0005433784318	9336	36	20H
0005433784295	9336	37	21B
0005432665237	9336	38	21E
0005433804790	9336	39	22D
0005433762943	9336	40	22G
0005433784301	9336	41	23B
0005433804792	9336	42	23A
0005433784319	9336	43	23H
0005433762948	9336	44	24E
0005432657395	9336	45	24H
0005433762950	9336	46	27A
0005433804787	9336	47	27D
0005433762951	9336	48	27H
0005433762956	9336	49	27G
0005433762946	9336	50	28B
0005433784296	9336	51	28F
0005433762947	9336	52	30H
0005433804781	9336	53	31F
0005433784311	9336	54	31H
0005433804778	9336	55	32D
0005433804782	9336	56	32B
0005433784315	9336	57	32G
0005433804777	9336	58	33H
0005433784293	9336	59	34A
0005433784304	9336	60	34D
0005432657394	9336	61	34B
0005433804789	9336	62	34G
0005433784325	9336	63	35G
0005433784309	9336	64	36B
0005433784300	9336	65	36A
0005433804793	9336	66	36E
0005433784298	9336	67	36D
0005433784307	9336	68	36F
0005432666351	9336	69	36H
0005433784310	9336	70	37E
0005433784314	9336	71	38A
0005433804786	9336	72	38B
0005433784303	9336	73	38H
0005433762952	9336	74	38G
0005433784323	9336	75	39E
0005433762945	9336	76	39D
0005433784308	9336	77	39F
0005434170798	26277	1	2G
0005435269632	26277	2	4C
0005435269631	26277	3	9G
0005434170806	26277	4	11B
0005434170804	26277	5	12E
0005435269628	26277	6	12H
0005435269633	26277	7	14B
0005435269625	26277	8	15E
0005434170807	26277	9	15F
0005435269634	26277	10	15H
0005435269622	26277	11	16A
0005434170801	26277	12	16G
0005435269641	26277	13	17B
0005434170797	26277	14	18E
0005434170810	26277	15	19G
0005435269621	26277	16	19H
0005435269624	26277	17	22D
0005435269635	26277	18	23D
0005435269639	26277	19	24A
0005434170809	26277	20	25F
0005434170805	26277	21	27D
0005435269642	26277	22	30E
0005434170800	26277	23	31F
0005435269623	26277	24	31G
0005435269640	26277	25	32B
0005435269627	26277	26	32D
0005435269636	26277	27	32H
0005434170803	26277	28	33B
0005434170802	26277	29	34A
0005435269626	26277	30	34E
0005434170808	26277	31	36A
0005434170799	26277	32	35H
0005435269638	26277	33	37F
0005435269630	26277	34	39E
0005435269629	26277	35	39D
0005435269637	26277	36	39F
0005435135585	4920	1	2D
0005435135582	4920	2	7C
0005435135583	4920	3	21B
0005435135584	4920	4	23A
0005435929595	33055	1	2A
0005435929597	33055	2	7B
0005435929596	33055	3	18D
0005434983194	9467	1	2D
0005434983198	9467	2	4A
0005434983195	9467	3	6B
0005434983197	9467	4	7A
0005434983196	9467	5	21B
0005434983193	9467	6	22C
0005434217896	27368	1	5A
0005434217894	27368	2	6B
0005434217897	27368	3	18B
0005434217895	27368	4	22B
0005434217898	27368	5	22D
0005434479880	923	1	1B
0005434479885	923	2	1C
0005434479896	923	3	2A
0005432269447	923	4	2B
0005434479888	923	5	2C
0005434479903	923	6	2D
0005432269445	923	7	4A
0005434479893	923	8	4B
0005434479894	923	9	4C
0005434479895	923	10	5B
0005434479879	923	11	5C
0005434479900	923	12	5D
0005434479897	923	13	6A
0005434479886	923	14	6C
0005434479890	923	15	7C
0005434479901	923	16	18A
0005434479878	923	17	18B
0005432269446	923	18	18C
0005434479881	923	19	19A
0005434479898	923	20	19C
0005434479902	923	21	20A
0005434479892	923	22	20B
0005434479883	923	23	20C
0005434479887	923	24	20D
0005434479882	923	25	21A
0005434479884	923	26	21C
0005434479889	923	27	21D
0005434479899	923	28	22A
0005434479891	923	29	23A
0005433165675	16590	1	1C
0005433165683	16590	2	2B
0005433165682	16590	3	2C
0005433165676	16590	4	4C
0005433165680	16590	5	4D
0005433165670	16590	6	6A
0005433165674	16590	7	6B
0005433165677	16590	8	6C
0005433165678	16590	9	6D
0005433165673	16590	10	18B
0005433165681	16590	11	19A
0005433165672	16590	12	20A
0005433165671	16590	13	20D
0005433165679	16590	14	22D
0005433872427	3194	1	2A
0005433872426	3194	2	19D
0005433872428	3194	3	23A
0005435386455	21926	1	1B
0005435386456	21926	2	1D
0005433289725	21926	3	5B
0005435386454	21926	4	6B
0005433289727	21926	5	21A
0005433289726	21926	6	21B
0005433289728	21926	7	22A
0005435386457	21926	8	22B
0005433289730	21926	9	22C
0005433289729	21926	10	22D
0005435319423	20931	1	2C
0005435319424	20931	2	3D
0005435319429	20931	3	5E
0005435319431	20931	4	6C
0005435319426	20931	5	10F
0005435319427	20931	6	11C
0005435319425	20931	7	12C
0005435319428	20931	8	14E
0005435319430	20931	9	17C
0005433683291	24306	1	3D
0005433683290	24306	2	4C
0005433683293	24306	3	19B
0005433683292	24306	4	19C
0005433927397	29277	1	3A
0005433927396	29277	2	3D
0005433927395	29277	3	5A
0005432706316	2926	1	1A
0005432706311	2926	2	1D
0005432706307	2926	3	2A
0005432217726	2926	4	2D
0005432706324	2926	5	4C
0005432706313	2926	6	4D
0005432706329	2926	7	6A
0005432706318	2926	8	6C
0005432706312	2926	9	6D
0005432706326	2926	10	7A
0005432706331	2926	11	7C
0005432706330	2926	12	8C
0005432706309	2926	13	8D
0005432706321	2926	14	9C
0005432706310	2926	15	9D
0005432706308	2926	16	9E
0005432706323	2926	17	10E
0005432706322	2926	18	10F
0005432706328	2926	19	11C
0005432217725	2926	20	12A
0005432706332	2926	21	12E
0005432706319	2926	22	13A
0005432706325	2926	23	13F
0005432706315	2926	24	14C
0005432706320	2926	25	17A
0005432706317	2926	26	17C
0005432706327	2926	27	18A
0005432706314	2926	28	18E
0005432217724	2926	29	18F
0005432692531	30019	1	1C
0005432692533	30019	2	1F
0005432692527	30019	3	3C
0005432692534	30019	4	3F
0005432880563	30019	5	4A
0005432880561	30019	6	4D
0005432692552	30019	7	5A
0005432692547	30019	8	5E
0005432880555	30019	9	5F
0005432692541	30019	10	6A
0005432692556	30019	11	6D
0005432692553	30019	12	6E
0005432692545	30019	13	6F
0005432692529	30019	14	7C
0005432692528	30019	15	7E
0005432692549	30019	16	7D
0005432880557	30019	17	8C
0005432880562	30019	18	8F
0005432692554	30019	19	9C
0005432692550	30019	20	9E
0005432692557	30019	21	10D
0005432692543	30019	22	11A
0005432692539	30019	23	11C
0005432880551	30019	24	11F
0005432692536	30019	25	12C
0005432692540	30019	26	13A
0005432880553	30019	27	13C
0005432880554	30019	28	14C
0005432692555	30019	29	14D
0005432692546	30019	30	14E
0005432880558	30019	31	15A
0005432692548	30019	32	15D
0005432692551	30019	33	15E
0005432880552	30019	34	16A
0005432880565	30019	35	16D
0005432880564	30019	36	17A
0005432692530	30019	37	17D
0005432880560	30019	38	17F
0005432692538	30019	39	18A
0005432692532	30019	40	18D
0005432692558	30019	41	18E
0005432692544	30019	42	18F
0005432692535	30019	43	19C
0005432880556	30019	44	19D
0005432692542	30019	45	19F
0005432692537	30019	46	20D
0005432880559	30019	47	20F
0005433113495	19632	1	2A
0005433113496	19632	2	19A
0005435068172	3533	1	1A
0005435068190	3533	2	1C
0005435068181	3533	3	1D
0005435068175	3533	4	2D
0005435718830	3533	5	2F
0005435068200	3533	6	3A
0005435068194	3533	7	3C
0005435068180	3533	8	4C
0005435068210	3533	9	4E
0005435068207	3533	10	4D
0005435068163	3533	11	5C
0005435718828	3533	12	5D
0005435718827	3533	13	5F
0005435068160	3533	14	6A
0005435068161	3533	15	6C
0005435068176	3533	16	6D
0005435068170	3533	17	7A
0005435068168	3533	18	7D
0005435068199	3533	19	7E
0005435068162	3533	20	7F
0005435068169	3533	21	8D
0005435718831	3533	22	8E
0005435068184	3533	23	8F
0005435068195	3533	24	9D
0005435068208	3533	25	9E
0005435068178	3533	26	9F
0005435068192	3533	27	10A
0005435068174	3533	28	10C
0005435068183	3533	29	10D
0005435068198	3533	30	11A
0005435068166	3533	31	11C
0005435068191	3533	32	11E
0005435068187	3533	33	12D
0005435718829	3533	34	12E
0005435068173	3533	35	12F
0005435068158	3533	36	13C
0005435068171	3533	37	13E
0005435068202	3533	38	13F
0005435068209	3533	39	14D
0005435068164	3533	40	14E
0005435068159	3533	41	15E
0005435068197	3533	42	15F
0005435068204	3533	43	16A
0005435068179	3533	44	16D
0005435068205	3533	45	16F
0005435068185	3533	46	17A
0005435068193	3533	47	17E
0005435068201	3533	48	17F
0005435068188	3533	49	18A
0005435068206	3533	50	18C
0005435068186	3533	51	18D
0005435068189	3533	52	18F
0005435068196	3533	53	19A
0005435068203	3533	54	19C
0005435068177	3533	55	19D
0005435068182	3533	56	19F
0005435068167	3533	57	20A
0005435068165	3533	58	20E
0005435925060	15302	1	4A
0005435925056	15302	2	4E
0005435925051	15302	3	5C
0005435925049	15302	4	6D
0005435925048	15302	5	8E
0005435925057	15302	6	9A
0005435925052	15302	7	9C
0005435925046	15302	8	9D
0005435939856	15302	9	11D
0005435925053	15302	10	15E
0005435925058	15302	11	16C
0005435925047	15302	12	17A
0005435925059	15302	13	17E
0005435925055	15302	14	19C
0005435925050	15302	15	20A
0005435925054	15302	16	20D
0005432157458	62	1	5F
0005432157457	62	2	25C
0005432816945	1	1	2C
0005432261133	1	2	2F
0005432261100	1	3	2D
0005432261098	1	4	4A
0005432261099	1	5	4F
0005432816962	1	6	5C
0005432261101	1	7	5F
0005432816959	1	8	6D
0005432261122	1	9	6C
0005432261110	1	10	6F
0005432261129	1	11	7C
0005432261096	1	12	7F
0005432816955	1	13	8A
0005432261119	1	14	8D
0005432816943	1	15	8C
0005432816947	1	16	9A
0005432816938	1	17	8F
0005432261090	1	18	9C
0005432816951	1	19	9D
0005432816960	1	20	9F
0005432261115	1	21	10B
0005432816954	1	22	10D
0005432816961	1	23	10E
0005432261097	1	24	10F
0005432261092	1	25	11B
0005432816963	1	26	11C
0005432261103	1	27	11D
0005432261116	1	28	11E
0005432816939	1	29	12A
0005432261109	1	30	11F
0005432261126	1	31	12E
0005432261121	1	32	12D
0005432816940	1	33	12F
0005432261120	1	34	13D
0005432261087	1	35	14B
0005432816965	1	36	14D
0005432288927	1	37	14E
0005432261112	1	38	14F
0005432261127	1	39	15B
0005432816958	1	40	15D
0005432816946	1	41	16E
0005432261114	1	42	16D
0005432816964	1	43	16F
0005432261132	1	44	17A
0005432261113	1	45	17F
0005432816952	1	46	18A
0005432261125	1	47	18B
0005432261118	1	48	18D
0005432261102	1	49	18C
0005432261128	1	50	19E
0005432816966	1	51	19D
0005432288929	1	52	20A
0005432261091	1	53	20C
0005432261123	1	54	20E
0005432261107	1	55	20F
0005432261094	1	56	21F
0005432816957	1	57	22A
0005432261111	1	58	22B
0005432261124	1	59	22D
0005432261108	1	60	23B
0005432816948	1	61	24A
0005432261093	1	62	25B
0005432816949	1	63	25D
0005432816953	1	64	25C
0005432816950	1	65	26A
0005432261130	1	66	26E
0005432261095	1	67	27A
0005432261089	1	68	27B
0005432261117	1	69	27E
0005432816942	1	70	27D
0005432816956	1	71	28E
0005432261131	1	72	28F
0005432261105	1	73	29D
0005432261106	1	74	29F
0005432288928	1	75	30B
0005432261104	1	76	30D
0005432816944	1	77	30E
0005432261088	1	78	31A
0005432816941	1	79	31E
0005433101217	8078	1	1D
0005433101189	8078	2	2A
0005432391945	8078	3	1F
0005433101183	8078	4	2C
0005433101197	8078	5	2F
0005432019787	8078	6	3C
0005432019786	8078	7	3D
0005433101173	8078	8	4A
0005433101216	8078	9	3F
0005433101157	8078	10	4C
0005433101155	8078	11	4D
0005432391946	8078	12	5A
0005433101200	8078	13	5C
0005433101194	8078	14	5F
0005433101168	8078	15	6D
0005433101148	8078	16	7A
0005433101161	8078	17	6F
0005432753243	8078	18	7F
0005433101176	8078	19	7D
0005433101172	8078	20	8A
0005433101196	8078	21	8C
0005432751469	8078	22	9A
0005433101160	8078	23	9B
0005433101150	8078	24	9C
0005432019796	8078	25	9D
0005433101190	8078	26	9E
0005432045579	8078	27	10A
0005433101210	8078	28	10C
0005433101171	8078	29	10B
0005432019794	8078	30	10D
0005433101204	8078	31	10E
0005432019779	8078	32	10F
0005433101154	8078	33	11A
0005433101184	8078	34	11B
0005432753242	8078	35	11D
0005433101220	8078	36	11E
0005432019780	8078	37	12A
0005433101162	8078	38	12B
0005433101178	8078	39	12C
0005433101170	8078	40	12D
0005432019797	8078	41	12E
0005433101207	8078	42	13B
0005433101212	8078	43	13C
0005432019784	8078	44	13D
0005433101164	8078	45	13F
0005433101202	8078	46	13E
0005432019793	8078	47	14A
0005432677503	8078	48	14B
0005433101169	8078	49	14C
0005433101187	8078	50	14E
0005433101182	8078	51	14F
0005432019792	8078	52	15A
0005432044475	8078	53	15C
0005432044477	8078	54	15B
0005433101219	8078	55	15F
0005432019801	8078	56	15E
0005433101209	8078	57	16B
0005432045580	8078	58	16D
0005433101213	8078	59	16F
0005432019800	8078	60	17F
0005433101205	8078	61	17E
0005433101208	8078	62	18A
0005433101179	8078	63	18C
0005433101159	8078	64	18B
0005433101203	8078	65	18D
0005433101195	8078	66	19B
0005432019789	8078	67	18F
0005433101193	8078	68	20A
0005432019790	8078	69	19E
0005433101152	8078	70	20C
0005433101206	8078	71	20D
0005433101192	8078	72	20F
0005432019783	8078	73	21A
0005433101199	8078	74	21C
0005433101177	8078	75	21B
0005433101167	8078	76	22B
0005433101163	8078	77	22A
0005432019804	8078	78	22E
0005433101211	8078	79	22D
0005432019781	8078	80	22F
0005433101201	8078	81	23A
0005433101165	8078	82	23D
0005432751468	8078	83	23C
0005432045581	8078	84	23E
0005433101149	8078	85	24A
0005433101185	8078	86	24D
0005433101214	8078	87	24C
0005433101198	8078	88	24F
0005432019799	8078	89	25A
0005433101151	8078	90	25C
0005433101175	8078	91	25B
0005433101188	8078	92	25D
0005432019802	8078	93	25E
0005433101166	8078	94	26A
0005432019785	8078	95	25F
0005432677506	8078	96	26B
0005432391947	8078	97	26C
0005432019795	8078	98	26E
0005432019803	8078	99	26F
0005433101186	8078	100	27B
0005432677504	8078	101	27E
0005433101218	8078	102	27D
0005432019782	8078	103	28B
0005433101180	8078	104	28D
0005432019788	8078	105	28F
0005433101158	8078	106	29A
0005432019791	8078	107	29C
0005432677505	8078	108	29E
0005432044476	8078	109	30A
0005432753244	8078	110	30B
0005433101156	8078	111	30D
0005433101153	8078	112	31A
0005433101181	8078	113	30F
0005432019798	8078	114	31B
0005433101215	8078	115	31C
0005433101191	8078	116	31F
0005433101174	8078	117	31E
0005432901293	8076	1	1C
0005432901302	8076	2	1F
0005432901304	8076	3	5C
0005432901295	8076	4	6D
0005432901310	8076	5	8D
0005432901298	8076	6	8C
0005432901307	8076	7	8F
0005432901309	8076	8	9C
0005432901308	8076	9	10B
0005432901297	8076	10	10D
0005432901300	8076	11	15B
0005432002040	8076	12	15F
0005432002041	8076	13	17D
0005432901299	8076	14	18C
0005432901303	8076	15	19E
0005432901296	8076	16	20C
0005432901306	8076	17	23A
0005432901294	8076	18	25B
0005432901311	8076	19	28D
0005432901301	8076	20	30B
0005432901305	8076	21	30D
0005433870692	9671	1	3B
0005433870691	9671	2	5B
0005434175681	32374	1	1A
0005434175678	32374	2	2B
0005434175680	32374	3	4A
0005434175679	32374	4	5A
0005434175682	32374	5	6B
0005434876559	3490	1	1A
0005435625879	3490	2	1G
0005432798964	3490	3	1D
0005434876557	3490	4	1K
0005435625862	3490	5	1H
0005432798955	3490	6	2D
0005434876620	3490	7	2C
0005435125675	3490	8	2A
0005434876651	3490	9	2H
0005434876564	3490	10	2G
0005434876581	3490	11	3A
0005432613790	3490	12	2K
0005435125669	3490	13	3D
0005435125656	3490	14	3C
0005434876585	3490	15	3H
0005432798962	3490	16	4A
0005432798966	3490	17	4G
0005434426109	3490	18	4K
0005435625868	3490	19	4H
0005434426101	3490	20	5C
0005435625876	3490	21	5A
0005434876593	3490	22	5H
0005434876614	3490	23	11A
0005434876575	3490	24	5K
0005434876617	3490	25	11E
0005434876565	3490	26	11D
0005435625858	3490	27	11C
0005435125677	3490	28	11F
0005432798969	3490	29	11G
0005434876583	3490	30	12A
0005435125661	3490	31	12E
0005432798961	3490	32	12G
0005435625877	3490	33	12F
0005434876621	3490	34	12K
0005434876636	3490	35	13F
0005434937796	3490	36	13E
0005434876558	3490	37	13H
0005435625873	3490	38	13G
0005435125665	3490	39	14A
0005434876650	3490	40	14G
0005435125651	3490	41	14F
0005434876580	3490	42	14K
0005434876578	3490	43	15C
0005435125663	3490	44	15E
0005432613789	3490	45	15G
0005434426085	3490	46	15H
0005434426092	3490	47	16C
0005434876633	3490	48	16A
0005435125688	3490	49	16E
0005434426091	3490	50	16H
0005434937810	3490	51	16G
0005434876569	3490	52	17A
0005434876600	3490	53	17E
0005432798977	3490	54	17D
0005435125678	3490	55	17C
0005434876582	3490	56	17F
0005434876608	3490	57	17K
0005434876609	3490	58	18C
0005432798956	3490	59	18E
0005434876574	3490	60	18D
0005434426093	3490	61	18F
0005434876591	3490	62	18K
0005435625867	3490	63	18J
0005434937805	3490	64	18H
0005435125682	3490	65	19B
0005435625857	3490	66	19A
0005434876640	3490	67	19D
0005435125687	3490	68	19C
0005435625869	3490	69	19E
0005435625863	3490	70	19J
0005434937808	3490	71	19H
0005435125666	3490	72	20A
0005434876584	3490	73	19K
0005435125652	3490	74	20B
0005435125653	3490	75	20E
0005434876599	3490	76	20C
0005435125657	3490	77	20K
0005434937802	3490	78	20J
0005435125655	3490	79	20H
0005435125674	3490	80	21A
0005432798972	3490	81	21D
0005434876598	3490	82	21F
0005434426096	3490	83	22A
0005434876646	3490	84	21K
0005435625875	3490	85	22C
0005434426102	3490	86	22B
0005434426099	3490	87	22E
0005435625861	3490	88	22D
0005434876639	3490	89	22G
0005434426098	3490	90	22F
0005434426105	3490	91	22K
0005434937792	3490	92	22H
0005434876619	3490	93	23B
0005434426088	3490	94	23A
0005434937809	3490	95	23D
0005434426089	3490	96	23C
0005432798968	3490	97	23G
0005434937797	3490	98	23F
0005434876642	3490	99	23E
0005432188550	3490	100	23J
0005435125671	3490	101	23H
0005434426104	3490	102	23K
0005434937793	3490	103	25A
0005434876615	3490	104	24G
0005432188551	3490	105	25C
0005434876616	3490	106	25B
0005434426095	3490	107	25F
0005434937806	3490	108	25E
0005434876618	3490	109	25G
0005432188553	3490	110	26A
0005435625865	3490	111	25J
0005434426113	3490	112	26D
0005434876610	3490	113	26C
0005432798979	3490	114	26H
0005434876597	3490	115	26F
0005434876626	3490	116	27B
0005434876606	3490	117	27A
0005434937804	3490	118	26K
0005434876622	3490	119	27D
0005432798976	3490	120	27C
0005434426110	3490	121	27F
0005435125659	3490	122	27H
0005434876568	3490	123	27K
0005434876647	3490	124	27J
0005434876560	3490	125	28C
0005435625874	3490	126	28B
0005432798954	3490	127	28D
0005435625878	3490	128	28G
0005432183428	3490	129	28H
0005434876624	3490	130	29B
0005432798965	3490	131	29A
0005434876571	3490	132	29D
0005432798975	3490	133	29C
0005435125660	3490	134	29F
0005434876627	3490	135	29E
0005432798971	3490	136	29H
0005435125672	3490	137	29K
0005434426112	3490	138	30C
0005434937799	3490	139	30B
0005434876570	3490	140	30D
0005434876630	3490	141	30G
0005434937800	3490	142	30E
0005434876629	3490	143	30K
0005434426108	3490	144	31D
0005434876645	3490	145	31C
0005435125647	3490	146	31F
0005434426094	3490	147	31J
0005432798970	3490	148	31G
0005434876587	3490	149	31K
0005435625871	3490	150	32C
0005434937795	3490	151	32B
0005432613792	3490	152	32A
0005435125686	3490	153	32E
0005434876590	3490	154	32G
0005434426107	3490	155	32J
0005432188552	3490	156	32H
0005432613791	3490	157	33B
0005434426097	3490	158	33A
0005434876556	3490	159	33F
0005435125670	3490	160	33E
0005434876572	3490	161	33G
0005434876635	3490	162	33K
0005434876576	3490	163	34B
0005435125676	3490	164	34A
0005434876623	3490	165	34E
0005435125667	3490	166	34H
0005434937807	3490	167	34G
0005434876612	3490	168	34J
0005432798981	3490	169	35B
0005434876596	3490	170	35A
0005434876605	3490	171	34K
0005434876631	3490	172	35C
0005434876602	3490	173	35F
0005434876603	3490	174	35E
0005435625864	3490	175	35H
0005434426100	3490	176	35G
0005434876563	3490	177	35J
0005434876632	3490	178	36C
0005434876634	3490	179	36E
0005434937798	3490	180	36D
0005434876577	3490	181	36F
0005434876604	3490	182	36K
0005435125685	3490	183	36J
0005434876628	3490	184	37B
0005435125648	3490	185	37A
0005435625872	3490	186	37E
0005432798960	3490	187	37D
0005434426090	3490	188	37F
0005434876566	3490	189	37J
0005434876637	3490	190	38B
0005435625860	3490	191	39A
0005434937803	3490	192	39D
0005434876595	3490	193	39B
0005435125650	3490	194	39G
0005434876625	3490	195	39J
0005432798980	3490	196	40C
0005432798958	3490	197	40E
0005434937794	3490	198	40D
0005432183429	3490	199	40H
0005434426084	3490	200	40F
0005435625859	3490	201	40J
0005435125668	3490	202	41B
0005434876638	3490	203	40K
0005434876588	3490	204	41D
0005435125683	3490	205	41C
0005434426086	3490	206	41F
0005434426106	3490	207	41G
0005434426087	3490	208	42A
0005432188549	3490	209	41J
0005435125664	3490	210	42E
0005435125658	3490	211	42F
0005432798974	3490	212	42J
0005434876648	3490	213	43A
0005434426111	3490	214	42K
0005434876644	3490	215	43C
0005434876567	3490	216	43B
0005434876611	3490	217	43E
0005434426103	3490	218	43H
0005432798957	3490	219	43J
0005432798978	3490	220	44C
0005435625870	3490	221	44A
0005434876613	3490	222	44D
0005435125681	3490	223	44G
0005434937801	3490	224	44F
0005434876594	3490	225	44J
0005435125673	3490	226	45B
0005432798967	3490	227	45A
0005432798963	3490	228	45H
0005434876561	3490	229	46B
0005432798953	3490	230	46A
0005434876562	3490	231	46F
0005434876641	3490	232	46H
0005434876643	3490	233	47E
0005432798973	3490	234	47D
0005432798982	3490	235	47C
0005434876601	3490	236	48A
0005434876586	3490	237	47K
0005434876592	3490	238	47H
0005434876589	3490	239	48C
0005435125684	3490	240	48F
0005435125649	3490	241	48H
0005434876573	3490	242	49A
0005435125654	3490	243	49E
0005435125680	3490	244	49G
0005434876555	3490	245	49F
0005435625866	3490	246	49K
0005434876579	3490	247	49H
0005435125679	3490	248	50C
0005434937811	3490	249	50A
0005435125662	3490	250	50E
0005434876649	3490	251	50H
0005432798959	3490	252	50F
0005434876607	3490	253	50K
0005435902395	14551	1	2A
0005435902390	14551	2	2H
0005435902388	14551	3	4G
0005432059471	14551	4	5A
0005435902400	14551	5	5H
0005435913849	14551	6	11D
0005432059469	14551	7	12C
0005435902384	14551	8	13F
0005435902389	14551	9	25B
0005435902386	14551	10	26D
0005435902385	14551	11	27F
0005435902401	14551	12	28G
0005435902398	14551	13	30A
0005435902396	14551	14	30K
0005435902387	14551	15	33D
0005435902397	14551	16	33G
0005432059470	14551	17	35K
0005435902399	14551	18	36D
0005435902394	14551	19	39B
0005435902393	14551	20	45J
0005435902391	14551	21	46J
0005435913850	14551	22	48F
0005435902392	14551	23	48D
0005434325452	3625	1	1A
0005434325451	3625	2	1C
0005434325445	3625	3	1D
0005434325450	3625	4	2C
0005434325446	3625	5	3A
0005434325453	3625	6	3D
0005434325448	3625	7	5A
0005434325447	3625	8	6C
0005434325444	3625	9	7C
0005434325443	3625	10	19B
0005434325449	3625	11	19C
0005434325454	3625	12	20C
0005434325455	3625	13	21B
0005435889790	15639	1	4C
0005435889793	15639	2	5C
0005435889791	15639	3	7C
0005435889789	15639	4	7D
0005435889788	15639	5	21A
0005435889792	15639	6	22A
0005435957441	669	1	1B
0005435957438	669	2	4B
0005435957450	669	3	4C
0005435957447	669	4	5B
0005435957453	669	5	5D
0005435957445	669	6	6A
0005435957449	669	7	7A
0005435957448	669	8	7C
0005435957440	669	9	18A
0005435957439	669	10	18D
0005435957444	669	11	19A
0005435957451	669	12	19B
0005435957443	669	13	19D
0005435957452	669	14	21C
0005435957442	669	15	22D
0005435957446	669	16	23B
0005433420253	15177	1	1B
0005433420249	15177	2	2B
0005433420252	15177	3	3A
0005433420256	15177	4	3B
0005433420251	15177	5	4C
0005433420254	15177	6	20B
0005433420255	15177	7	20D
0005433420257	15177	8	21D
0005433420250	15177	9	22A
0005435217676	31773	1	1A
0005435218099	31773	2	5B
0005435216554	31773	3	6A
0005435217677	31773	4	21C
0005435217678	31773	5	22A
0005435216553	31773	6	22D
0005435629383	8849	1	1B
0005434247102	16118	1	1A
0005434247100	16118	2	2B
0005434247101	16118	3	3B
0005434467723	4016	1	4B
0005434467724	4016	2	5A
0005435163143	4432	1	3A
0005435163141	4432	2	5A
0005435163142	4432	3	5C
0005435163144	4432	4	5D
0005435163140	4432	5	18D
0005435163139	4432	6	22A
0005435933395	29506	1	1C
0005435933394	29506	2	6D
0005432645761	6840	1	1A
0005432645768	6840	2	2D
0005432645773	6840	3	3D
0005432645767	6840	4	4E
0005432645764	6840	5	7C
0005432645765	6840	6	10D
0005432645763	6840	7	12F
0005432645766	6840	8	14F
0005432645762	6840	9	15D
0005432645772	6840	10	15E
0005432645769	6840	11	15F
0005432645771	6840	12	17A
0005432645770	6840	13	19F
0005435797234	2837	1	2C
0005435797224	2837	2	4A
0005435797223	2837	3	4D
0005435797226	2837	4	6A
0005435797227	2837	5	8E
0005435797222	2837	6	9D
0005435797230	2837	7	10C
0005435797233	2837	8	11C
0005435797225	2837	9	12A
0005435797231	2837	10	13F
0005435797236	2837	11	14C
0005435797232	2837	12	16C
0005435797235	2837	13	19D
0005435797229	2837	14	20A
0005435797228	2837	15	20F
0005433404679	29309	1	1C
0005433404677	29309	2	3A
0005433404683	29309	3	5C
0005433404681	29309	4	14D
0005433404678	29309	5	15A
0005433404680	29309	6	17C
0005433404682	29309	7	19E
0005434947871	5814	1	1A
0005434947870	5814	2	3A
0005434947868	5814	3	3B
0005434947869	5814	4	4A
0005434947874	5814	5	4B
0005434947872	5814	6	5B
0005434947873	5814	7	6A
0005435376312	16432	1	4A
0005435376313	16432	2	6A
0005435376314	16432	3	6B
0005433959869	6863	1	1A
0005433959896	6863	2	1D
0005433959866	6863	3	2C
0005433959860	6863	4	2D
0005433959895	6863	5	3A
0005433959903	6863	6	3D
0005433959865	6863	7	3F
0005433959883	6863	8	4C
0005433959864	6863	9	4D
0005433959879	6863	10	4E
0005433959891	6863	11	5A
0005433959882	6863	12	5C
0005433959871	6863	13	5F
0005433959872	6863	14	6F
0005433959888	6863	15	7A
0005433959889	6863	16	8A
0005433959900	6863	17	8C
0005433959857	6863	18	8E
0005433959881	6863	19	9D
0005433959893	6863	20	10C
0005433959867	6863	21	10E
0005433959898	6863	22	11A
0005433959870	6863	23	11C
0005433959885	6863	24	11E
0005433959863	6863	25	11F
0005433959887	6863	26	12A
0005433959858	6863	27	12F
0005433959877	6863	28	13E
0005433959902	6863	29	13D
0005433959894	6863	30	14A
0005433959897	6863	31	14C
0005433959876	6863	32	14F
0005433959874	6863	33	15A
0005433959892	6863	34	15E
0005433959862	6863	35	16C
0005433959899	6863	36	16E
0005433959868	6863	37	17C
0005433959859	6863	38	17D
0005433959873	6863	39	17E
0005433959861	6863	40	17F
0005433959875	6863	41	18E
0005433959856	6863	42	18F
0005433959878	6863	43	19E
0005433959901	6863	44	20A
0005433959884	6863	45	20C
0005433959880	6863	46	20D
0005433959886	6863	47	20E
0005433959890	6863	48	20F
0005434244467	5200	1	2D
0005434244473	5200	2	5A
0005434244459	5200	3	4F
0005434244463	5200	4	6A
0005434244453	5200	5	8A
0005434244466	5200	6	9C
0005434244469	5200	7	10A
0005434244470	5200	8	9F
0005434244479	5200	9	12A
0005434244457	5200	10	12E
0005434244462	5200	11	14A
0005434244456	5200	12	15D
0005434244480	5200	13	15E
0005434244477	5200	14	15F
0005434244458	5200	15	17D
0005434244455	5200	16	20A
0005434244478	5200	17	20C
0005434244481	5200	18	20F
0005432166843	5200	19	21C
0005434244476	5200	20	21B
0005432166845	5200	21	22C
0005434244468	5200	22	22E
0005434244464	5200	23	24B
0005434244474	5200	24	25C
0005434244475	5200	25	26A
0005434244471	5200	26	25F
0005434244461	5200	27	26D
0005434244454	5200	28	28A
0005434244482	5200	29	28D
0005434244483	5200	30	29B
0005434244472	5200	31	29E
0005432166844	5200	32	30A
0005434244465	5200	33	30F
0005434244460	5200	34	31B
0005432104729	5204	1	1A
0005433613444	5204	2	1C
0005432104738	5204	3	1F
0005433784315	5204	4	1D
0005433784293	5204	5	2A
0005433613453	5204	6	2C
0005432104714	5204	7	2F
0005433784299	5204	8	2D
0005432104734	5204	9	3A
0005433784312	5204	10	3C
0005432104711	5204	11	3D
0005433613386	5204	12	4A
0005432104749	5204	13	3F
0005433784324	5204	14	4C
0005432104740	5204	15	4F
0005433613433	5204	16	4D
0005433613388	5204	17	5C
0005433784313	5204	18	5A
0005433613452	5204	19	5D
0005433613418	5204	20	6A
0005433784304	5204	21	5F
0005432104735	5204	22	6C
0005433613429	5204	23	6F
0005432104736	5204	24	6D
0005432104742	5204	25	7A
0005432666351	5204	26	7C
0005433613421	5204	27	7D
0005432104728	5204	28	8A
0005433784308	5204	29	7F
0005433784309	5204	30	8B
0005432104759	5204	31	8D
0005432104755	5204	32	8C
0005432104732	5204	33	8E
0005433784311	5204	34	8F
0005433784328	5204	35	9B
0005433613460	5204	36	9A
0005433784301	5204	37	9C
0005432104751	5204	38	9E
0005433613407	5204	39	9D
0005433784292	5204	40	9F
0005432145075	5204	41	10A
0005432104747	5204	42	10C
0005433784317	5204	43	10B
0005433613393	5204	44	10D
0005433784297	5204	45	10E
0005433613435	5204	46	10F
0005433613409	5204	47	11A
0005433613455	5204	48	11C
0005432104725	5204	49	11B
0005432104723	5204	50	11D
0005432104717	5204	51	11E
0005432104744	5204	52	12A
0005433613431	5204	53	11F
0005433784314	5204	54	12C
0005433613408	5204	55	12B
0005433613395	5204	56	12D
0005433613448	5204	57	12E
0005432665237	5204	58	12F
0005432104758	5204	59	13A
0005432104713	5204	60	13C
0005433784305	5204	61	13B
0005433613458	5204	62	13D
0005432104712	5204	63	13F
0005433613419	5204	64	13E
0005433613441	5204	65	14A
0005433613415	5204	66	14C
0005433613423	5204	67	14B
0005433784295	5204	68	14D
0005433613437	5204	69	14F
0005432666352	5204	70	15B
0005432104752	5204	71	15A
0005433613445	5204	72	15C
0005433613397	5204	73	15D
0005433784323	5204	74	15F
0005433613414	5204	75	15E
0005432104715	5204	76	16A
0005432104731	5204	77	16B
0005433613404	5204	78	16D
0005433613424	5204	79	16C
0005432104718	5204	80	16E
0005433613411	5204	81	17A
0005433784316	5204	82	16F
0005433613412	5204	83	17C
0005433613401	5204	84	17B
0005433613420	5204	85	17E
0005433784296	5204	86	17D
0005433613425	5204	87	18A
0005432104748	5204	88	17F
0005433613400	5204	89	18B
0005433613457	5204	90	18C
0005433784318	5204	91	18E
0005432666353	5204	92	18D
0005433784300	5204	93	18F
0005433613396	5204	94	19C
0005432104753	5204	95	19B
0005432104757	5204	96	19D
0005433613416	5204	97	19E
0005433613417	5204	98	20B
0005433613440	5204	99	20A
0005433784322	5204	100	20C
0005433613426	5204	101	20D
0005433613443	5204	102	20F
0005432104727	5204	103	20E
0005433613459	5204	104	21A
0005433613394	5204	105	21C
0005432104722	5204	106	21B
0005433613451	5204	107	21D
0005433613405	5204	108	21E
0005432145077	5204	109	22A
0005432104741	5204	110	21F
0005433613392	5204	111	22B
0005433613454	5204	112	22D
0005433613427	5204	113	22C
0005432104750	5204	114	22E
0005432104726	5204	115	22F
0005433613436	5204	116	23B
0005432665238	5204	117	23A
0005433613430	5204	118	23C
0005433784325	5204	119	23D
0005433613391	5204	120	23F
0005433613446	5204	121	23E
0005432104733	5204	122	24A
0005433784321	5204	123	24B
0005433613410	5204	124	24C
0005433784294	5204	125	24E
0005433784326	5204	126	24D
0005433784298	5204	127	24F
0005433613442	5204	128	25A
0005433613406	5204	129	25C
0005433613439	5204	130	25B
0005433784320	5204	131	25D
0005433613450	5204	132	25F
0005432104737	5204	133	25E
0005433613390	5204	134	26A
0005433784302	5204	135	26B
0005433613413	5204	136	26D
0005433613434	5204	137	26C
0005433784319	5204	138	26E
0005432104716	5204	139	27A
0005432145076	5204	140	26F
0005433784306	5204	141	27C
0005432104720	5204	142	27B
0005433613389	5204	143	27D
0005432104745	5204	144	27F
0005432104719	5204	145	27E
0005433613456	5204	146	28A
0005433784307	5204	147	28B
0005432104743	5204	148	28C
0005433613402	5204	149	28E
0005433613438	5204	150	28D
0005432104724	5204	151	28F
0005433613403	5204	152	29B
0005432104739	5204	153	29A
0005433784303	5204	154	29D
0005433613447	5204	155	29C
0005433613422	5204	156	29E
0005433784310	5204	157	30A
0005432104746	5204	158	29F
0005433613387	5204	159	30B
0005433784327	5204	160	30D
0005432104754	5204	161	30C
0005433613432	5204	162	30E
0005433613449	5204	163	31A
0005432104756	5204	164	30F
0005432104730	5204	165	31B
0005433613399	5204	166	31C
0005433613428	5204	167	31D
0005433613398	5204	168	31E
0005432104721	5204	169	31F
0005434228981	5220	1	2A
0005434149531	5220	2	2D
0005434264695	5220	3	3A
0005434228967	5220	4	2F
0005434264681	5220	5	3F
0005434149528	5220	6	3D
0005434149523	5220	7	4C
0005434149527	5220	8	4D
0005434264679	5220	9	5A
0005434228969	5220	10	4F
0005434264685	5220	11	5C
0005434264686	5220	12	6A
0005434264683	5220	13	6D
0005434228979	5220	14	7A
0005434228975	5220	15	7D
0005434228977	5220	16	7C
0005434149522	5220	17	8A
0005434264693	5220	18	8C
0005434264688	5220	19	9D
0005434264680	5220	20	9F
0005434264682	5220	21	10A
0005434228984	5220	22	10C
0005434264696	5220	23	11B
0005434264694	5220	24	11E
0005434228966	5220	25	12C
0005434149526	5220	26	12E
0005434149525	5220	27	13B
0005434228973	5220	28	14C
0005434264676	5220	29	15D
0005434149524	5220	30	16B
0005434264691	5220	31	16C
0005434264690	5220	32	16F
0005434228983	5220	33	17A
0005434228987	5220	34	17C
0005434228970	5220	35	17E
0005434149530	5220	36	19B
0005434264687	5220	37	19C
0005434149521	5220	38	19E
0005434264689	5220	39	20A
0005434228985	5220	40	20C
0005434149529	5220	41	20D
0005434264692	5220	42	21D
0005434228982	5220	43	21F
0005434264678	5220	44	22A
0005434228976	5220	45	22D
0005434264697	5220	46	22C
0005434264701	5220	47	23A
0005434228974	5220	48	23B
0005434173450	5220	49	23E
0005434228986	5220	50	24B
0005434173451	5220	51	25D
0005434149520	5220	52	26C
0005434264684	5220	53	27C
0005434228968	5220	54	27F
0005434228988	5220	55	28A
0005434228980	5220	56	28E
0005434264700	5220	57	29E
0005434264699	5220	58	29D
0005434264677	5220	59	30A
0005434228978	5220	60	30C
0005434228972	5220	61	30E
0005434228971	5220	62	30D
0005434264698	5220	63	31B
0005434264675	5220	64	31C
0005435269621	8632	1	2D
0005435269636	8632	2	5F
0005435269642	8632	3	8B
0005435269637	8632	4	11C
0005435269628	8632	5	12B
0005435269629	8632	6	12E
0005435269625	8632	7	12F
0005435269624	8632	8	13F
0005435269634	8632	9	14D
0005435269622	8632	10	15D
0005435269639	8632	11	17B
0005435269631	8632	12	17A
0005435269633	8632	13	21B
0005435269627	8632	14	23B
0005435269626	8632	15	25C
0005435269638	8632	16	25B
0005435269623	8632	17	26D
0005435269632	8632	18	27D
0005435269630	8632	19	27F
0005435269635	8632	20	28D
0005435269641	8632	21	29F
0005435269640	8632	22	30A
0005435006615	8630	1	1A
0005432034450	8630	2	1C
0005432034469	8630	3	1D
0005435006619	8630	4	2A
0005432034463	8630	5	3D
0005432047484	8630	6	3C
0005435006608	8630	7	3A
0005432335826	8630	8	4D
0005435006610	8630	9	4C
0005432034456	8630	10	4F
0005435006609	8630	11	5A
0005432034459	8630	12	5F
0005433688773	8630	13	6A
0005432335828	8630	14	6D
0005432034468	8630	15	7A
0005435006612	8630	16	7C
0005435006602	8630	17	8A
0005435006607	8630	18	8C
0005432034451	8630	19	8E
0005435006618	8630	20	9C
0005435006601	8630	21	9D
0005432335827	8630	22	9E
0005433688774	8630	23	10A
0005433815302	8630	24	10B
0005433534460	8630	25	10C
0005432034460	8630	26	10D
0005433534462	8630	27	11A
0005432047486	8630	28	10E
0005433689875	8630	29	11C
0005432034452	8630	30	12A
0005433815300	8630	31	12B
0005432034471	8630	32	12D
0005435006616	8630	33	12C
0005432335821	8630	34	13B
0005432034462	8630	35	13F
0005435006620	8630	36	14C
0005434311182	8630	37	14D
0005432034466	8630	38	15A
0005432034473	8630	39	14F
0005435006617	8630	40	15C
0005432034467	8630	41	16B
0005435006611	8630	42	17A
0005435006605	8630	43	18D
0005433815303	8630	44	19C
0005435006613	8630	45	19D
0005432034470	8630	46	19E
0005432335831	8630	47	20B
0005432034465	8630	48	21A
0005435006614	8630	49	21D
0005433815305	8630	50	21C
0005432034477	8630	51	22A
0005432335830	8630	52	22B
0005432034464	8630	53	22D
0005432034461	8630	54	22F
0005432034449	8630	55	23B
0005432034453	8630	56	23C
0005432335829	8630	57	23E
0005432034474	8630	58	24A
0005432034457	8630	59	23F
0005435006606	8630	60	24E
0005432034476	8630	61	24F
0005433689874	8630	62	25A
0005433534461	8630	63	25D
0005432047485	8630	64	25C
0005433815301	8630	65	25F
0005432034458	8630	66	26B
0005433815304	8630	67	27A
0005432335822	8630	68	27D
0005432335820	8630	69	27F
0005433690890	8630	70	27E
0005433534463	8630	71	28A
0005433690891	8630	72	28B
0005432034475	8630	73	28C
0005432335823	8630	74	28E
0005433690892	8630	75	29B
0005432034455	8630	76	29A
0005435006603	8630	77	29C
0005434311181	8630	78	29D
0005432335825	8630	79	29F
0005433688775	8630	80	30B
0005432034472	8630	81	30D
0005432335824	8630	82	31A
0005435006604	8630	83	30F
0005432034454	8630	84	31B
0005433202114	12615	1	1C
0005433202104	12615	2	1D
0005433202103	12615	3	2A
0005433202110	12615	4	2C
0005433202106	12615	5	3A
0005433202113	12615	6	3D
0005433202109	12615	7	5A
0005433202111	12615	8	5B
0005433202115	12615	9	5C
0005433202105	12615	10	6A
0005433202102	12615	11	7B
0005433202107	12615	12	7D
0005433202108	12615	13	19B
0005433202116	12615	14	22B
0005433202112	12615	15	22D
0005432054252	21103	1	9D
0005432054253	21103	2	18F
0005432054254	21103	3	20C
0005433642080	2485	1	2C
0005433642085	2485	2	2D
0005433642073	2485	3	5E
0005433642078	2485	4	6F
0005433642075	2485	5	9C
0005433642086	2485	6	9D
0005433642087	2485	7	9F
0005433642081	2485	8	10D
0005433642082	2485	9	13A
0005433642084	2485	10	14A
0005433642079	2485	11	16C
0005433642083	2485	12	18C
0005433642077	2485	13	19C
0005433642074	2485	14	19F
0005433642076	2485	15	20F
0005432822072	9614	1	1C
0005432816942	9614	2	1D
0005432816945	9614	3	1F
0005432288929	9614	4	2D
0005432816966	9614	5	4A
0005432822064	9614	6	4E
0005432816950	9614	7	5D
0005432816965	9614	8	5F
0005432816956	9614	9	6C
0005434448256	9614	10	6E
0005432816954	9614	11	6F
0005432816953	9614	12	7C
0005432816960	9614	13	8D
0005432816949	9614	14	8F
0005434448253	9614	15	9A
0005432816952	9614	16	9C
0005432816957	9614	17	9E
0005432822068	9614	18	10A
0005432816943	9614	19	10C
0005432822070	9614	20	10D
0005432816938	9614	21	11E
0005432816961	9614	22	12E
0005432822067	9614	23	14A
0005432816964	9614	24	14C
0005432288927	9614	25	14D
0005432816939	9614	26	14E
0005434448255	9614	27	15C
0005432822071	9614	28	15D
0005432816948	9614	29	15F
0005434448254	9614	30	16C
0005432816962	9614	31	16E
0005432816951	9614	32	16F
0005432816963	9614	33	17A
0005432816946	9614	34	17C
0005432816947	9614	35	17E
0005432822069	9614	36	17F
0005432816958	9614	37	18C
0005432288928	9614	38	18D
0005432816944	9614	39	19A
0005432816941	9614	40	19D
0005432816959	9614	41	19E
0005432816955	9614	42	19F
0005432822066	9614	43	20A
0005432822065	9614	44	20C
0005432816940	9614	45	20E
0005434157344	29001	1	1C
0005432901298	29001	2	1F
0005432901294	29001	3	2A
0005434157341	29001	4	2F
0005432901306	29001	5	3D
0005432901300	29001	6	4D
0005432901303	29001	7	5C
0005432901304	29001	8	5F
0005432002041	29001	9	7F
0005432901302	29001	10	9C
0005432901309	29001	11	9E
0005432901307	29001	12	10C
0005432901293	29001	13	10E
0005434157342	29001	14	11A
0005434157345	29001	15	11D
0005432901310	29001	16	12A
0005432901301	29001	17	12C
0005432901308	29001	18	12D
0005432901296	29001	19	14D
0005432901311	29001	20	14E
0005432002040	29001	21	16A
0005432901299	29001	22	16C
0005432901295	29001	23	17C
0005432901305	29001	24	18E
0005434157343	29001	25	19F
0005432901297	29001	26	20A
0005434157346	29001	27	20F
0005432613789	15145	1	1A
0005432613792	15145	2	1B
0005432613790	15145	3	2B
0005432613791	15145	4	5A
0005432947780	25270	1	2C
0005432947782	25270	2	2A
0005432947789	25270	3	4D
0005432947768	25270	4	5D
0005432947764	25270	5	6B
0005432947798	25270	6	6E
0005432947796	25270	7	7C
0005432947800	25270	8	7E
0005432947787	25270	9	8E
0005432947779	25270	10	9B
0005432947778	25270	11	9A
0005432947784	25270	12	9F
0005432947767	25270	13	10B
0005432947793	25270	14	10E
0005432947795	25270	15	10F
0005432947781	25270	16	11B
0005432947775	25270	17	11A
0005432947783	25270	18	11F
0005432947801	25270	19	11E
0005432947772	25270	20	12A
0005432947771	25270	21	13A
0005432947773	25270	22	13C
0005432947790	25270	23	13B
0005432947804	25270	24	14C
0005432947769	25270	25	14E
0005432947797	25270	26	15D
0005432947765	25270	27	15C
0005432947791	25270	28	15F
0005432947774	25270	29	16A
0005432947794	25270	30	17B
0005432947802	25270	31	17C
0005432947786	25270	32	17F
0005432947777	25270	33	17E
0005432947788	25270	34	18A
0005432947799	25270	35	18E
0005432947770	25270	36	19C
0005432947785	25270	37	20A
0005432947766	25270	38	20D
0005432947776	25270	39	20F
0005432947792	25270	40	20E
0005432947803	25270	41	21E
0005432430803	14467	1	6E
0005432430800	14467	2	9C
0005434026671	14467	3	11C
0005432430802	14467	4	12E
0005434026669	14467	5	19A
0005434026670	14467	6	21C
0005432430801	14467	7	21E
0005433808308	30832	1	1A
0005433808307	30832	2	9A
0005433808309	30832	3	10B
0005433808304	30832	4	11F
0005433808305	30832	5	14D
0005433808306	30832	6	19A
0005434654168	5381	1	1A
0005434654179	5381	2	2D
0005434654182	5381	3	3A
0005434654172	5381	4	3C
0005434654178	5381	5	3D
0005434654163	5381	6	3F
0005434654170	5381	7	4C
0005434654166	5381	8	4D
0005434654167	5381	9	5A
0005434654174	5381	10	5C
0005434654186	5381	11	5D
0005434656521	5381	12	5F
0005434654187	5381	13	6A
0005434654162	5381	14	6F
0005434654169	5381	15	7A
0005434654181	5381	16	7F
0005434654184	5381	17	8E
0005434656520	5381	18	8F
0005434654176	5381	19	9C
0005434654173	5381	20	9F
0005434654175	5381	21	10E
0005434654164	5381	22	11C
0005432114146	5381	23	11E
0005434654161	5381	24	12C
0005432114145	5381	25	12D
0005432114147	5381	26	12F
0005434654183	5381	27	13E
0005434654165	5381	28	13F
0005434654188	5381	29	14C
0005434654177	5381	30	16F
0005432114148	5381	31	17A
0005434654185	5381	32	17C
0005434654160	5381	33	19C
0005434654171	5381	34	20E
0005434654180	5381	35	20F
0005435555335	12554	1	1D
0005435339991	12554	2	3C
0005435339989	12554	3	4F
0005435339996	12554	4	6D
0005435339998	12554	5	6F
0005435339992	12554	6	8C
0005435340001	12554	7	8D
0005435555334	12554	8	10D
0005435340002	12554	9	11D
0005435340000	12554	10	13A
0005435339999	12554	11	15D
0005435339993	12554	12	15F
0005435339990	12554	13	17F
0005435339995	12554	14	18F
0005435340003	12554	15	19C
0005435339997	12554	16	19D
0005435339994	12554	17	20A
0005433715070	7456	1	1C
0005433715087	7456	2	1F
0005433715100	7456	3	2D
0005432078011	7456	4	2F
0005433715080	7456	5	3C
0005433715114	7456	6	4B
0005433715068	7456	7	5B
0005433715093	7456	8	5A
0005432078008	7456	9	5D
0005433715075	7456	10	5E
0005433715097	7456	11	6A
0005433715091	7456	12	7D
0005433715083	7456	13	7C
0005433715109	7456	14	7E
0005433715094	7456	15	7F
0005432078012	7456	16	8B
0005433715105	7456	17	8C
0005433715112	7456	18	8D
0005433715076	7456	19	8E
0005433715108	7456	20	9B
0005433715104	7456	21	9C
0005432078013	7456	22	9E
0005433715107	7456	23	9D
0005433715081	7456	24	10D
0005432078009	7456	25	10E
0005433715090	7456	26	11A
0005433715099	7456	27	11F
0005433715086	7456	28	12B
0005433715077	7456	29	12A
0005433715074	7456	30	12E
0005433715115	7456	31	12D
0005433715098	7456	32	13C
0005433715089	7456	33	13F
0005433715110	7456	34	14B
0005433715095	7456	35	14C
0005433715071	7456	36	15A
0005433715069	7456	37	15F
0005433715096	7456	38	16D
0005433715101	7456	39	16C
0005433715072	7456	40	17A
0005433715082	7456	41	17D
0005433715103	7456	42	17F
0005432078014	7456	43	18A
0005433715106	7456	44	18E
0005433715067	7456	45	18D
0005433715102	7456	46	18F
0005433715111	7456	47	19B
0005433715084	7456	48	20B
0005433715088	7456	49	21E
0005433715073	7456	50	22B
0005433715085	7456	51	22D
0005433715078	7456	52	22E
0005433715092	7456	53	22F
0005432078010	7456	54	23B
0005432078015	7456	55	23A
0005433715113	7456	56	23D
0005433715079	7456	57	23F
0005432428867	29197	1	6D
0005432006710	29197	2	12E
0005432006708	29197	3	12F
0005432428868	29197	4	15B
0005432006709	29197	5	16E
0005432428869	29197	6	18D
0005435266074	29197	7	20F
0005434095016	8676	1	3A
0005434095020	8676	2	4F
0005434095022	8676	3	5C
0005434095024	8676	4	5D
0005434095028	8676	5	6A
0005434095021	8676	6	6F
0005434095029	8676	7	7F
0005434095018	8676	8	10A
0005434095015	8676	9	10E
0005434095017	8676	10	17A
0005434095025	8676	11	17C
0005434095026	8676	12	17E
0005434095019	8676	13	19A
0005434095023	8676	14	19C
0005434095027	8676	15	19F
0005434181965	11646	1	1C
0005434181957	11646	2	4C
0005434181959	11646	3	5E
0005434181964	11646	4	6F
0005434181963	11646	5	8A
0005434181962	11646	6	11F
0005434181966	11646	7	12C
0005434181961	11646	8	13D
0005434181967	11646	9	13E
0005434181968	11646	10	17F
0005434181960	11646	11	18A
0005434181958	11646	12	20F
0005433456897	1452	1	6D
0005435732120	1452	2	6E
0005435732116	1452	3	7A
0005435732115	1452	4	7C
0005433456898	1452	5	8E
0005435732117	1452	6	9F
0005435732124	1452	7	11D
0005435732122	1452	8	12C
0005432297231	1452	9	12D
0005432297232	1452	10	13C
0005433456900	1452	11	14D
0005433456899	1452	12	14F
0005432297230	1452	13	15D
0005435732119	1452	14	16A
0005435732118	1452	15	16E
0005435732114	1452	16	17A
0005435732123	1452	17	17E
0005435732113	1452	18	19A
0005435732121	1452	19	19E
0005435732112	1452	20	20F
0005433397213	19231	1	1A
0005433397186	19231	2	1C
0005433397228	19231	3	2C
0005433397225	19231	4	2D
0005433397222	19231	5	3A
0005433397217	19231	6	3D
0005433397187	19231	7	3F
0005433397218	19231	8	4A
0005433397185	19231	9	4D
0005433397211	19231	10	4E
0005433397199	19231	11	4F
0005433397219	19231	12	5A
0005433397194	19231	13	5C
0005433397184	19231	14	5D
0005433397189	19231	15	5E
0005433397223	19231	16	6A
0005433397212	19231	17	6E
0005433397196	19231	18	7A
0005432906492	19231	19	7C
0005433397210	19231	20	7D
0005433397178	19231	21	7E
0005433397221	19231	22	8D
0005433397216	19231	23	8F
0005433397190	19231	24	9C
0005433397183	19231	25	9F
0005433397182	19231	26	10D
0005433397209	19231	27	10E
0005433397198	19231	28	10F
0005433397197	19231	29	11C
0005433397191	19231	30	11D
0005433397215	19231	31	12C
0005433397226	19231	32	12D
0005433397195	19231	33	12E
0005432906491	19231	34	12F
0005433397192	19231	35	13A
0005433397180	19231	36	13D
0005433397214	19231	37	13F
0005433397200	19231	38	14A
0005433397181	19231	39	14C
0005433397220	19231	40	14D
0005433397204	19231	41	14E
0005433397193	19231	42	15A
0005433397179	19231	43	15F
0005433397227	19231	44	17E
0005433397208	19231	45	17F
0005433397202	19231	46	18C
0005433397206	19231	47	18D
0005433397205	19231	48	19A
0005433397207	19231	49	19C
0005433397201	19231	50	19F
0005433397188	19231	51	20C
0005433397203	19231	52	20D
0005433397224	19231	53	20E
0005434954540	7267	1	1A
0005434954538	7267	2	4A
0005434954539	7267	3	6A
0005434954537	7267	4	5B
0005435377538	28327	1	1B
0005435377537	28327	2	5A
0005434351476	4490	1	1C
0005434351466	4490	2	2B
0005434351464	4490	3	2C
0005434351472	4490	4	5C
0005434351471	4490	5	5D
0005434351475	4490	6	6B
0005434351469	4490	7	6D
0005434351468	4490	8	18B
0005434351473	4490	9	18D
0005434351463	4490	10	19A
0005434351470	4490	11	21B
0005434351474	4490	12	21C
0005434351465	4490	13	22A
0005434351467	4490	14	22C
0005435893507	29663	1	3C
0005435893505	29663	2	4B
0005435893509	29663	3	7D
0005435893506	29663	4	18C
0005435893503	29663	5	19C
0005435893508	29663	6	21D
0005435893504	29663	7	22A
0005435091899	1090	1	4F
0005435091897	1090	2	11F
0005435091895	1090	3	11H
0005433462709	1090	4	12A
0005435091894	1090	5	12F
0005432293165	1090	6	14A
0005433463863	1090	7	16D
0005435091896	1090	8	18B
0005435091892	1090	9	18E
0005433463862	1090	10	20F
0005435091898	1090	11	21F
0005434445207	1090	12	22A
0005435091893	1090	13	23E
0005435091900	1090	14	24D
0005434446476	1090	15	24E
0005434445210	1090	16	28F
0005434445208	1090	17	29G
0005433463861	1090	18	30D
0005434445209	1090	19	31A
0005433462708	1090	20	34G
0005432293164	1090	21	35G
0005435091901	1090	22	37G
0005433269620	17024	1	16H
0005433269619	17024	2	19G
0005433269624	17024	3	27E
0005433269622	17024	4	27H
0005433269623	17024	5	31H
0005433269621	17024	6	32D
0005432851815	18263	1	7E
0005432851816	18263	2	7F
0005432851819	18263	3	10B
0005432851817	18263	4	11D
0005432851820	18263	5	17D
0005432851818	18263	6	20E
0005432159776	12797	1	4B
0005432433582	12797	2	4C
0005432433585	12797	3	5B
0005433812858	12797	4	6F
0005433812857	12797	5	7A
0005432433586	12797	6	9B
0005432161111	12797	7	9C
0005432161110	12797	8	12D
0005432433583	12797	9	19C
0005432159777	12797	10	19D
0005432159778	12797	11	20A
0005432433584	12797	12	20E
0005433812859	12797	13	21C
0005432159775	12797	14	23A
0005433989684	30696	1	5E
0005433989681	30696	2	16A
0005433989682	30696	3	20A
0005433989683	30696	4	20F
0005435765119	5493	1	1C
0005435765148	5493	2	1H
0005435765122	5493	3	2B
0005432140305	5493	4	3A
0005435765106	5493	5	3F
0005435722013	5493	6	3H
0005435765169	5493	7	4B
0005435765146	5493	8	4G
0005435765136	5493	9	4H
0005435765134	5493	10	5G
0005435765116	5493	11	5F
0005433529211	5493	12	9B
0005432140301	5493	13	9G
0005435765107	5493	14	9H
0005435765127	5493	15	11B
0005435765139	5493	16	11D
0005432140300	5493	17	11H
0005435765168	5493	18	12G
0005435765130	5493	19	12H
0005435765159	5493	20	13B
0005435765144	5493	21	13A
0005435765115	5493	22	13G
0005435765125	5493	23	14B
0005435765126	5493	24	14F
0005435765164	5493	25	15A
0005435765128	5493	26	15F
0005435765140	5493	27	15H
0005435765121	5493	28	16A
0005435720800	5493	29	16D
0005432140298	5493	30	16E
0005433529212	5493	31	16F
0005435765154	5493	32	16H
0005435765166	5493	33	16G
0005435765141	5493	34	17E
0005432140306	5493	35	17G
0005435765111	5493	36	17H
0005433529210	5493	37	18A
0005435765110	5493	38	18E
0005435765171	5493	39	18D
0005435765124	5493	40	18G
0005435765162	5493	41	19D
0005435765138	5493	42	19B
0005435765102	5493	43	19E
0005435765132	5493	44	20A
0005435765152	5493	45	19H
0005435765133	5493	46	20B
0005435765167	5493	47	20F
0005432140303	5493	48	21A
0005432140304	5493	49	21B
0005435765129	5493	50	21E
0005435765165	5493	51	22B
0005435765135	5493	52	22A
0005435765158	5493	53	22F
0005435765147	5493	54	23A
0005435765109	5493	55	22H
0005435765155	5493	56	23B
0005435765105	5493	57	23E
0005435765160	5493	58	23H
0005435765149	5493	59	24A
0005435765157	5493	60	24D
0005433527199	5493	61	24E
0005435765123	5493	62	25D
0005433527202	5493	63	24H
0005435765145	5493	64	25F
0005432140299	5493	65	27B
0005435765103	5493	66	28A
0005435765161	5493	67	27H
0005435722012	5493	68	28B
0005435765150	5493	69	28F
0005435765131	5493	70	29A
0005435765120	5493	71	29F
0005435765143	5493	72	30D
0005435765163	5493	73	30G
0005433529213	5493	74	31B
0005435765156	5493	75	31A
0005435765151	5493	76	31D
0005435765114	5493	77	32A
0005432140307	5493	78	33A
0005435765112	5493	79	33E
0005435765104	5493	80	34A
0005435765142	5493	81	34E
0005435765108	5493	82	34H
0005435765137	5493	83	35E
0005435720798	5493	84	35D
0005435765118	5493	85	36D
0005432140302	5493	86	36H
0005435720799	5493	87	37B
0005435765170	5493	88	37G
0005433527200	5493	89	38A
0005435765153	5493	90	38D
0005435765113	5493	91	38H
0005433527201	5493	92	39D
0005435765117	5493	93	39F
0005432535746	13470	1	1C
0005434264686	13470	2	1B
0005432535749	13470	3	1G
0005434264678	13470	4	2C
0005435461788	13470	5	2G
0005434831066	13470	6	3A
0005435461769	13470	7	2H
0005435461777	13470	8	3F
0005435461773	13470	9	4A
0005435461756	13470	10	3H
0005435461763	13470	11	4B
0005434264696	13470	12	4G
0005435461784	13470	13	5B
0005435461768	13470	14	5C
0005434264683	13470	15	11A
0005432535747	13470	16	11E
0005434264685	13470	17	12A
0005435461787	13470	18	12F
0005434264691	13470	19	13F
0005434264681	13470	20	13G
0005434264677	13470	21	14B
0005435461774	13470	22	14A
0005435461780	13470	23	14E
0005432194435	13470	24	15A
0005434264690	13470	25	15D
0005435461776	13470	26	15H
0005434264700	13470	27	16G
0005435461786	13470	28	16F
0005435461762	13470	29	17D
0005435461781	13470	30	17E
0005432194438	13470	31	17G
0005435461791	13470	32	18B
0005435461779	13470	33	18D
0005434264699	13470	34	18G
0005435461772	13470	35	19F
0005434264695	13470	36	20A
0005432535745	13470	37	20E
0005434264701	13470	38	20G
0005434264687	13470	39	21B
0005434831068	13470	40	21H
0005435461790	13470	41	22A
0005434264697	13470	42	22G
0005435461760	13470	43	23E
0005435461789	13470	44	23F
0005435461794	13470	45	24B
0005434264684	13470	46	24E
0005432194436	13470	47	24G
0005434264676	13470	48	25E
0005434264692	13470	49	27A
0005434264698	13470	50	27D
0005435461792	13470	51	27F
0005434264682	13470	52	27H
0005435461766	13470	53	28D
0005435461765	13470	54	28H
0005434264689	13470	55	29A
0005434264688	13470	56	29B
0005435461770	13470	57	29H
0005434831067	13470	58	29G
0005432194437	13470	59	30A
0005434831070	13470	60	31B
0005434264693	13470	61	31G
0005432194439	13470	62	32D
0005435461764	13470	63	32B
0005435461758	13470	64	33F
0005434831069	13470	65	34B
0005435461759	13470	66	34F
0005435461771	13470	67	34H
0005432535748	13470	68	35B
0005435461757	13470	69	35G
0005435461778	13470	70	35F
0005435461785	13470	71	36A
0005435461793	13470	72	35H
0005435461767	13470	73	36B
0005434264694	13470	74	36E
0005434264680	13470	75	37A
0005435461775	13470	76	37D
0005434264679	13470	77	38B
0005434264675	13470	78	38E
0005435461761	13470	79	38F
0005435461783	13470	80	39D
0005435461782	13470	81	39F
0005435846191	25096	1	10A
0005435846188	25096	2	10D
0005435846190	25096	3	12D
0005435846189	25096	4	15E
0005433810491	1819	1	2D
0005432295834	1819	2	8D
0005432295833	1819	3	14D
0005433810488	1819	4	15C
0005433810489	1819	5	17E
0005433810490	1819	6	19E
0005432295832	1819	7	19F
0005433845696	5588	1	1C
0005433845710	5588	2	1D
0005432081398	5588	3	2D
0005433845663	5588	4	2F
0005433845704	5588	5	3D
0005433845679	5588	6	4A
0005433845678	5588	7	4C
0005433845720	5588	8	4F
0005433845712	5588	9	4D
0005433845673	5588	10	5A
0005433845684	5588	11	5F
0005433845691	5588	12	6A
0005433845690	5588	13	6C
0005433845716	5588	14	6B
0005433845689	5588	15	6F
0005433845714	5588	16	6E
0005433845681	5588	17	7C
0005433845692	5588	18	7D
0005433845705	5588	19	7F
0005433845701	5588	20	8A
0005433845676	5588	21	8D
0005433845715	5588	22	8F
0005433845708	5588	23	8E
0005433845668	5588	24	9A
0005433845695	5588	25	9C
0005433845719	5588	26	9E
0005433845665	5588	27	10A
0005433845697	5588	28	9F
0005433845667	5588	29	10B
0005432081394	5588	30	11B
0005433845713	5588	31	11A
0005433845683	5588	32	11D
0005433845682	5588	33	11E
0005432081396	5588	34	12B
0005433845721	5588	35	12D
0005432081393	5588	36	13B
0005433845706	5588	37	13A
0005433845688	5588	38	13D
0005433845687	5588	39	14A
0005432081400	5588	40	13F
0005433845711	5588	41	13E
0005433845722	5588	42	14B
0005433845685	5588	43	14D
0005433845680	5588	44	14C
0005433845702	5588	45	14F
0005433845666	5588	46	15B
0005433845703	5588	47	15F
0005432081397	5588	48	15E
0005433845693	5588	49	16E
0005433845672	5588	50	16D
0005433845677	5588	51	16C
0005433845671	5588	52	17A
0005433845699	5588	53	16F
0005432081399	5588	54	17C
0005432081395	5588	55	17D
0005433845670	5588	56	18B
0005433845717	5588	57	17F
0005433845674	5588	58	18C
0005433845686	5588	59	18F
0005433845707	5588	60	18E
0005433845669	5588	61	18D
0005433845664	5588	62	19C
0005433845709	5588	63	19F
0005433845718	5588	64	20C
0005433845675	5588	65	20A
0005433845700	5588	66	20F
0005433845698	5588	67	21E
0005433845694	5588	68	21D
0005435282067	13884	1	2A
0005435282064	13884	2	3F
0005434173451	13884	3	4C
0005435282058	13884	4	4A
0005432003645	13884	5	5A
0005435282055	13884	6	4F
0005435282069	13884	7	6C
0005435282059	13884	8	8D
0005435282057	13884	9	8F
0005435282054	13884	10	9A
0005435282062	13884	11	10C
0005435282053	13884	12	10B
0005435282061	13884	13	10E
0005435282050	13884	14	11B
0005435282063	13884	15	11A
0005435282049	13884	16	12B
0005432003647	13884	17	12E
0005435282052	13884	18	13F
0005435282051	13884	19	14C
0005435282060	13884	20	14D
0005435282068	13884	21	16A
0005434173450	13884	22	16E
0005435282065	13884	23	17C
0005435282056	13884	24	17F
0005432003646	13884	25	20E
0005435282066	13884	26	21C
0005434620228	7843	1	1C
0005434620230	7843	2	1D
0005434620232	7843	3	2A
0005432112476	7843	4	2D
0005434620233	7843	5	3A
0005434620240	7843	6	3D
0005434620226	7843	7	4D
0005434620242	7843	8	5B
0005434620223	7843	9	5C
0005434620222	7843	10	6A
0005434620238	7843	11	7A
0005434620227	7843	12	7B
0005434620241	7843	13	18A
0005434620239	7843	14	18C
0005434620229	7843	15	19B
0005434620231	7843	16	20A
0005434620234	7843	17	20C
0005434620235	7843	18	21A
0005434620236	7843	19	21B
0005434620224	7843	20	21C
0005434620237	7843	21	21D
0005434620225	7843	22	22D
0005432112475	7843	23	23A
0005435332153	32948	1	2B
0005435332154	32948	2	3A
0005435332149	32948	3	3B
0005435332156	32948	4	4A
0005435332150	32948	5	6B
0005435332152	32948	6	18B
0005435332155	32948	7	19A
0005435332146	32948	8	20B
0005435332148	32948	9	21B
0005435332147	32948	10	21D
0005435332151	32948	11	23A
0005435784754	4260	1	1A
0005435784742	4260	2	2C
0005432190562	4260	3	2F
0005432190561	4260	4	3C
0005435784758	4260	5	3D
0005432190564	4260	6	4A
0005435784748	4260	7	4D
0005435784736	4260	8	4E
0005435784760	4260	9	5D
0005435784757	4260	10	5E
0005434993846	4260	11	5F
0005435784762	4260	12	6A
0005435784755	4260	13	6C
0005435784737	4260	14	6D
0005435784731	4260	15	7A
0005435784738	4260	16	8C
0005435784729	4260	17	8D
0005435784734	4260	18	9A
0005435784739	4260	19	9E
0005435784756	4260	20	9F
0005432190563	4260	21	10C
0005435784740	4260	22	10D
0005435784732	4260	23	10E
0005434993854	4260	24	11A
0005434993851	4260	25	12C
0005435784749	4260	26	12D
0005435784752	4260	27	12F
0005434993848	4260	28	13A
0005435784746	4260	29	13D
0005435784747	4260	30	13E
0005435784735	4260	31	14C
0005434993853	4260	32	14E
0005434993852	4260	33	15C
0005435784759	4260	34	15D
0005435784733	4260	35	16D
0005435784727	4260	36	16E
0005435784728	4260	37	17C
0005435784751	4260	38	17D
0005435784750	4260	39	17F
0005435784763	4260	40	18A
0005435784730	4260	41	18C
0005435784753	4260	42	18E
0005434993850	4260	43	18F
0005434993847	4260	44	19A
0005435784744	4260	45	19C
0005435784745	4260	46	19D
0005434993849	4260	47	19E
0005435784743	4260	48	20A
0005435784761	4260	49	20E
0005435784741	4260	50	20F
0005435918570	27318	1	1F
0005435918572	27318	2	11D
0005435918571	27318	3	14E
0005435918569	27318	4	18F
0005432566574	4695	1	1A
0005434081472	4695	2	2C
0005434081483	4695	3	2F
0005432170270	4695	4	2G
0005432566543	4695	5	3A
0005432566539	4695	6	3C
0005432566569	4695	7	3H
0005432566545	4695	8	3G
0005434081485	4695	9	4G
0005434081479	4695	10	5A
0005432566541	4695	11	5F
0005432566535	4695	12	5G
0005434081473	4695	13	9A
0005432566575	4695	14	5H
0005432566577	4695	15	9B
0005432566584	4695	16	11A
0005432566555	4695	17	9H
0005432566557	4695	18	11E
0005432566581	4695	19	11G
0005432566565	4695	20	12A
0005432566586	4695	21	11H
0005434081484	4695	22	12D
0005432566530	4695	23	12E
0005432566566	4695	24	12F
0005432566538	4695	25	13D
0005432566542	4695	26	13B
0005432566558	4695	27	13G
0005432566580	4695	28	13H
0005432566572	4695	29	14B
0005432566551	4695	30	14D
0005434081480	4695	31	14F
0005432566548	4695	32	14H
0005432566570	4695	33	15B
0005432566540	4695	34	15E
0005432566547	4695	35	15D
0005432566533	4695	36	16D
0005432566553	4695	37	18A
0005432566588	4695	38	18F
0005432566534	4695	39	18E
0005432566544	4695	40	18H
0005434081476	4695	41	19D
0005432566550	4695	42	19H
0005432566563	4695	43	19G
0005432566582	4695	44	20A
0005432566525	4695	45	20B
0005434081477	4695	46	20E
0005434081471	4695	47	20D
0005432566583	4695	48	20H
0005433726063	4695	49	21A
0005432566568	4695	50	22B
0005432566562	4695	51	22E
0005433451582	4695	52	22G
0005432566578	4695	53	23B
0005432566546	4695	54	23G
0005432566528	4695	55	24B
0005433451583	4695	56	24E
0005434081475	4695	57	24G
0005432186804	4695	58	25E
0005432566571	4695	59	27A
0005432566556	4695	60	25F
0005434081486	4695	61	27B
0005432566564	4695	62	27F
0005432566579	4695	63	27G
0005432186803	4695	64	28A
0005432566526	4695	65	28D
0005432566549	4695	66	29B
0005432566585	4695	67	29E
0005434081470	4695	68	29F
0005432566573	4695	69	30B
0005432566532	4695	70	30A
0005432186806	4695	71	30E
0005433452702	4695	72	30F
0005432566576	4695	73	30H
0005432566554	4695	74	31B
0005432170267	4695	75	31A
0005434081474	4695	76	32E
0005432566529	4695	77	32F
0005434081482	4695	78	33H
0005432566559	4695	79	34A
0005434081481	4695	80	34F
0005432170269	4695	81	34E
0005432566536	4695	82	34G
0005432566560	4695	83	35A
0005432566527	4695	84	35D
0005432186805	4695	85	35G
0005434081478	4695	86	35F
0005432566561	4695	87	35H
0005432566531	4695	88	36B
0005432170266	4695	89	36A
0005432566537	4695	90	36E
0005432566567	4695	91	36G
0005433452701	4695	92	37A
0005433452703	4695	93	37E
0005432170268	4695	94	37D
0005432566552	4695	95	37H
0005432566587	4695	96	38A
0005432161110	30531	1	3G
0005432213541	30531	2	15G
0005432213539	30531	3	29B
0005432161111	30531	4	32F
0005432213542	30531	5	33E
0005432213540	30531	6	37A
0005435720798	13619	1	1A
0005435720800	13619	2	4A
0005435722013	13619	3	4B
0005435720799	13619	4	5A
0005435722012	13619	5	6A
0005432295833	22773	1	4A
0005432295832	22773	2	22A
0005432295834	22773	3	22C
0005433341410	11112	1	1C
0005433341457	11112	2	1F
0005433341429	11112	3	1D
0005433341416	11112	4	2A
0005433341395	11112	5	2C
0005433341381	11112	6	3A
0005433341468	11112	7	2F
0005433341402	11112	8	3D
0005433341463	11112	9	3C
0005433341409	11112	10	3F
0005433341464	11112	11	4A
0005433341456	11112	12	4B
0005433341379	11112	13	4D
0005433341417	11112	14	4C
0005433341452	11112	15	4E
0005433341389	11112	16	4F
0005433341446	11112	17	5B
0005433341467	11112	18	5D
0005433341408	11112	19	5C
0005433341436	11112	20	5E
0005433341448	11112	21	6A
0005433341398	11112	22	5F
0005433341420	11112	23	6B
0005433341478	11112	24	6D
0005433341378	11112	25	6F
0005433341425	11112	26	6E
0005433341462	11112	27	7C
0005433341384	11112	28	7B
0005433341434	11112	29	7E
0005433341422	11112	30	7D
0005433341455	11112	31	8B
0005433341471	11112	32	8D
0005433341405	11112	33	8C
0005433341470	11112	34	8E
0005433341401	11112	35	8F
0005433341458	11112	36	9C
0005433341387	11112	37	9E
0005433341419	11112	38	9D
0005433341406	11112	39	9F
0005433341394	11112	40	10C
0005433341443	11112	41	10E
0005433341423	11112	42	10D
0005433341465	11112	43	11B
0005433341426	11112	44	11D
0005433341445	11112	45	12B
0005433341380	11112	46	12A
0005433341459	11112	47	12C
0005433341450	11112	48	12D
0005433341449	11112	49	12E
0005433341454	11112	50	12F
0005433341411	11112	51	13B
0005433341382	11112	52	13A
0005433341430	11112	53	13D
0005433341412	11112	54	13E
0005433341439	11112	55	14A
0005433341391	11112	56	13F
0005433341451	11112	57	14B
0005433341393	11112	58	14D
0005433341400	11112	59	14C
0005433341385	11112	60	14E
0005433341447	11112	61	15B
0005433341461	11112	62	15A
0005433341396	11112	63	15C
0005433341390	11112	64	15D
0005433341432	11112	65	15E
0005433341414	11112	66	15F
0005433341444	11112	67	16B
0005433341472	11112	68	16A
0005433341437	11112	69	16C
0005433341440	11112	70	16D
0005433341476	11112	71	16F
0005433341418	11112	72	16E
0005433341383	11112	73	17B
0005433341424	11112	74	17E
0005433341386	11112	75	17D
0005433341407	11112	76	17F
0005433341399	11112	77	18A
0005433341431	11112	78	18C
0005433341428	11112	79	18B
0005433341392	11112	80	18D
0005433341466	11112	81	18F
0005433341433	11112	82	19B
0005433341404	11112	83	19A
0005433341415	11112	84	19C
0005433341435	11112	85	19E
0005433341441	11112	86	19D
0005433341479	11112	87	19F
0005433341469	11112	88	20C
0005433341477	11112	89	20D
0005433341427	11112	90	21A
0005433341473	11112	91	21C
0005433341460	11112	92	21B
0005433341474	11112	93	21D
0005433341421	11112	94	21E
0005433341438	11112	95	21F
0005433341475	11112	96	22B
0005433341453	11112	97	22E
0005433341413	11112	98	22F
0005433341403	11112	99	23B
0005433341397	11112	100	23A
0005433341442	11112	101	23C
0005433341388	11112	102	23D
0005432293165	17112	1	15D
0005432293164	17112	2	20B
0005433506861	9116	1	1C
0005433506866	9116	2	2C
0005433506857	9116	3	2D
0005433506863	9116	4	3C
0005433481032	9116	5	3D
0005433506870	9116	6	3F
0005433481029	9116	7	4C
0005433506859	9116	8	5A
0005433506860	9116	9	5F
0005433481031	9116	10	6C
0005433506856	9116	11	6D
0005433506862	9116	12	8D
0005433481030	9116	13	9A
0005433481027	9116	14	9F
0005433506864	9116	15	11D
0005433506871	9116	16	11F
0005433481034	9116	17	12D
0005433481033	9116	18	13A
0005433506869	9116	19	13D
0005433506855	9116	20	14A
0005433506865	9116	21	15A
0005433506854	9116	22	15D
0005433506867	9116	23	17D
0005433481028	9116	24	19D
0005433506868	9116	25	20A
0005433506853	9116	26	20D
0005433506858	9116	27	20F
0005432919520	20490	1	2D
0005432919523	20490	2	2F
0005432919514	20490	3	3D
0005432919504	20490	4	3F
0005434158945	20490	5	4A
0005432919511	20490	6	4C
0005432919506	20490	7	5C
0005432919517	20490	8	6C
0005432919521	20490	9	6E
0005432919524	20490	10	7C
0005432919513	20490	11	9E
0005432919518	20490	12	10D
0005434158946	20490	13	10E
0005432919508	20490	14	11E
0005432919516	20490	15	12A
0005434158943	20490	16	12C
0005432919505	20490	17	13C
0005432919522	20490	18	13F
0005432919509	20490	19	15D
0005432919515	20490	20	17A
0005432919507	20490	21	17C
0005432919510	20490	22	17E
0005434158944	20490	23	18A
0005432919519	20490	24	18F
0005432919512	20490	25	19F
0005432919503	20490	26	20F
0005434411702	11042	1	8C
0005434928248	11042	2	10A
0005434411704	11042	3	12A
0005434928249	11042	4	13F
0005434928251	11042	5	15D
0005434411703	11042	6	18F
0005434411701	11042	7	19D
0005434928250	11042	8	20A
0005435125688	14685	1	1A
0005435125651	14685	2	1D
0005435556647	14685	3	1F
0005435625861	14685	4	2A
0005435625875	14685	5	2C
0005435125680	14685	6	2D
0005435125675	14685	7	3A
0005435125655	14685	8	3C
0005435125673	14685	9	3D
0005435625859	14685	10	3F
0005435125659	14685	11	4C
0005435125663	14685	12	4D
0005435625878	14685	13	4E
0005435625870	14685	14	4F
0005435125678	14685	15	5A
0005435125662	14685	16	5C
0005435125666	14685	17	5D
0005435125672	14685	18	5E
0005435556646	14685	19	5F
0005435125665	14685	20	6A
0005435125654	14685	21	6E
0005435125647	14685	22	7A
0005435625879	14685	23	7D
0005435625864	14685	24	7F
0005435125670	14685	25	8E
0005435125653	14685	26	8F
0005435556648	14685	27	9A
0005435125649	14685	28	9C
0005435556649	14685	29	10A
0005435625874	14685	30	9F
0005435625871	14685	31	10C
0005435125664	14685	32	10D
0005435625860	14685	33	11A
0005435125685	14685	34	11C
0005435625876	14685	35	11D
0005435125656	14685	36	11F
0005435125681	14685	37	12C
0005435625872	14685	38	12D
0005435625857	14685	39	12E
0005435625873	14685	40	12F
0005435125648	14685	41	13A
0005435625862	14685	42	13C
0005435625865	14685	43	13D
0005435125657	14685	44	13E
0005435125660	14685	45	13F
0005435625868	14685	46	14A
0005435125650	14685	47	14C
0005435625858	14685	48	14D
0005435625866	14685	49	14E
0005435125687	14685	50	14F
0005435125658	14685	51	15C
0005435125667	14685	52	15D
0005435125661	14685	53	15E
0005435625877	14685	54	15F
0005435125683	14685	55	16A
0005435125679	14685	56	16C
0005435625867	14685	57	16E
0005435125676	14685	58	16F
0005435125674	14685	59	17C
0005435125686	14685	60	17D
0005435125669	14685	61	17F
0005435125677	14685	62	18A
0005435625863	14685	63	18E
0005435125652	14685	64	19D
0005435625869	14685	65	19E
0005435125671	14685	66	19F
0005435125684	14685	67	20A
0005435125682	14685	68	20D
0005435125668	14685	69	20F
0005432400059	7130	1	2F
0005435715162	7130	2	3F
0005435715170	7130	3	4A
0005432400056	7130	4	4C
0005432398131	7130	5	4D
0005432400060	7130	6	5F
0005432400057	7130	7	6C
0005435715169	7130	8	6D
0005435715174	7130	9	7A
0005435715161	7130	10	7D
0005435715173	7130	11	8A
0005432398129	7130	12	8C
0005435715175	7130	13	10C
0005435715171	7130	14	11C
0005435715163	7130	15	11F
0005435715168	7130	16	13A
0005435715165	7130	17	15E
0005435715172	7130	18	15F
0005435715176	7130	19	16A
0005435715167	7130	20	16E
0005432398130	7130	21	16F
0005432400058	7130	22	17D
0005435715166	7130	23	18D
0005435715164	7130	24	18F
0005435715160	7130	25	19C
0005435443144	27055	1	2D
0005435443151	27055	2	3A
0005435443148	27055	3	5F
0005435443149	27055	4	13D
0005435443145	27055	5	18D
0005435443150	27055	6	19A
0005435443147	27055	7	19C
0005435443146	27055	8	19D
0005435443152	27055	9	19E
0005434084849	2725	1	2A
0005434084848	2725	2	3B
0005434084851	2725	3	4A
0005434084850	2725	4	6A
0005434084852	2725	5	6B
0005433060366	28497	1	2B
0005433060367	28497	2	5B
0005434906370	2294	1	1C
0005434906375	2294	2	1F
0005434906367	2294	3	2F
0005434906395	2294	4	3D
0005434906366	2294	5	4C
0005434906397	2294	6	5E
0005434906402	2294	7	5F
0005434906372	2294	8	6A
0005434906359	2294	9	6C
0005434906365	2294	10	7A
0005434906361	2294	11	7C
0005434906391	2294	12	7D
0005434906374	2294	13	7E
0005434906387	2294	14	7F
0005434906380	2294	15	8A
0005434906362	2294	16	8C
0005434906379	2294	17	8D
0005434906392	2294	18	9C
0005434906400	2294	19	9D
0005434906364	2294	20	9F
0005434906386	2294	21	10D
0005434906376	2294	22	10F
0005434906378	2294	23	11D
0005434906393	2294	24	11E
0005434906373	2294	25	12D
0005434906371	2294	26	12F
0005434906396	2294	27	13E
0005434906382	2294	28	14A
0005434906406	2294	29	14C
0005434906377	2294	30	14E
0005434906388	2294	31	15A
0005434906405	2294	32	16A
0005434906401	2294	33	16C
0005434906369	2294	34	16D
0005434906404	2294	35	16E
0005434906363	2294	36	16F
0005434906398	2294	37	17C
0005434906385	2294	38	17D
0005434906399	2294	39	17E
0005434906390	2294	40	17F
0005434906383	2294	41	18A
0005434906394	2294	42	18D
0005434906360	2294	43	19A
0005434906381	2294	44	19D
0005434906384	2294	45	19F
0005434906368	2294	46	20D
0005434906403	2294	47	20E
0005434906389	2294	48	20F
0005433250950	25591	1	1A
0005433250955	25591	2	3A
0005433250929	25591	3	3D
0005433250945	25591	4	4A
0005433250938	25591	5	4C
0005433250940	25591	6	6A
0005433250931	25591	7	6D
0005433400929	25591	8	6F
0005433250928	25591	9	7A
0005433250949	25591	10	7E
0005433250935	25591	11	8A
0005433400930	25591	12	8E
0005433250944	25591	13	10E
0005433250933	25591	14	11A
0005433250934	25591	15	11C
0005433250954	25591	16	11D
0005433250937	25591	17	11F
0005433250943	25591	18	12A
0005433250957	25591	19	12C
0005433250947	25591	20	12E
0005433250941	25591	21	13C
0005433250930	25591	22	13E
0005433250948	25591	23	13F
0005433250956	25591	24	14A
0005433250932	25591	25	14C
0005433250936	25591	26	14D
0005433250942	25591	27	15A
0005433250951	25591	28	15D
0005433250927	25591	29	16A
0005433250952	25591	30	16D
0005433250946	25591	31	17E
0005433400931	25591	32	18E
0005433250958	25591	33	18F
0005433400932	25591	34	19E
0005433250939	25591	35	19F
0005433250953	25591	36	20E
0005432620788	2525	1	1A
0005432620793	2525	2	1C
0005432620792	2525	3	2B
0005432620796	2525	4	3B
0005432620790	2525	5	3D
0005432620799	2525	6	4B
0005432620789	2525	7	4C
0005432620795	2525	8	5D
0005432620794	2525	9	6B
0005432620798	2525	10	6C
0005432620787	2525	11	7D
0005432620786	2525	12	18D
0005432620797	2525	13	19C
0005432620791	2525	14	20A
0005432620800	2525	15	20C
0005432862166	28066	1	2A
0005432862167	28066	2	4C
0005432862165	28066	3	4D
0005432862169	28066	4	7A
0005432862168	28066	5	19B
0005432862162	28066	6	20D
0005432862163	28066	7	22C
0005432862164	28066	8	23B
0005434097449	13030	1	1B
0005433452703	31031	1	1A
0005433452702	31031	2	1B
0005433451583	31031	3	5A
0005433452701	31031	4	6A
0005433451582	31031	5	6B
0005433131627	29863	1	1B
0005433131626	29863	2	2C
0005434183543	29863	3	5A
0005434183545	29863	4	5D
0005433134059	29863	5	6D
0005434184630	29863	6	7B
0005433131628	29863	7	18B
0005433134056	29863	8	19B
0005434184629	29863	9	19D
0005433134057	29863	10	20A
0005433131629	29863	11	20B
0005434183544	29863	12	21B
0005434183546	29863	13	22C
0005433134058	29863	14	22D
0005435798915	1611	1	1A
0005435934992	24740	1	2A
0005435934993	24740	2	6C
0005435934994	24740	3	21D
0005435934995	24740	4	22A
0005432968802	21642	1	2A
0005432968801	21642	2	3B
0005432968803	21642	3	4A
0005434136717	7350	1	1A
0005434136743	7350	2	1C
0005434136697	7350	3	1D
0005434136694	7350	4	1F
0005434136685	7350	5	2A
0005434136752	7350	6	2C
0005434136755	7350	7	2D
0005434136701	7350	8	3A
0005434136733	7350	9	3C
0005434136702	7350	10	3D
0005434136732	7350	11	3F
0005434136704	7350	12	4A
0005434136678	7350	13	4C
0005434136683	7350	14	4F
0005434136734	7350	15	5A
0005434136742	7350	16	5C
0005434136713	7350	17	5D
0005434136750	7350	18	5E
0005434136758	7350	19	5F
0005434087429	7350	20	6A
0005434136709	7350	21	6C
0005434136710	7350	22	6E
0005434136721	7350	23	6F
0005434136692	7350	24	7A
0005434136757	7350	25	7C
0005434136698	7350	26	7D
0005434136716	7350	27	7E
0005434136675	7350	28	7F
0005434136748	7350	29	8A
0005434136753	7350	30	8C
0005434136691	7350	31	8E
0005434136686	7350	32	8F
0005434136723	7350	33	9A
0005434136722	7350	34	9C
0005434136736	7350	35	9D
0005434136741	7350	36	9E
0005434087428	7350	37	9F
0005434136726	7350	38	10A
0005434136688	7350	39	10C
0005434136676	7350	40	10D
0005434136693	7350	41	10F
0005434136700	7350	42	11A
0005434136744	7350	43	11C
0005434136679	7350	44	11D
0005434136759	7350	45	11E
0005434136687	7350	46	11F
0005434136728	7350	47	12A
0005434136705	7350	48	12C
0005434136756	7350	49	12D
0005434136695	7350	50	12E
0005434136719	7350	51	12F
0005434136681	7350	52	13A
0005434136684	7350	53	13C
0005434087427	7350	54	13D
0005434136751	7350	55	13E
0005434136746	7350	56	13F
0005434136731	7350	57	14A
0005434136738	7350	58	14C
0005434136745	7350	59	14D
0005434136718	7350	60	14E
0005434136714	7350	61	14F
0005434136740	7350	62	15A
0005434136725	7350	63	15C
0005434136707	7350	64	15D
0005434136737	7350	65	15E
0005434136720	7350	66	15F
0005434136708	7350	67	16A
0005434136727	7350	68	16C
0005434136729	7350	69	16D
0005434136703	7350	70	16F
0005434136730	7350	71	17A
0005434087430	7350	72	17C
0005434136690	7350	73	17D
0005434136711	7350	74	17E
0005434136682	7350	75	17F
0005434136689	7350	76	18A
0005434136739	7350	77	18C
0005434136706	7350	78	18D
0005434136680	7350	79	18E
0005434136712	7350	80	19A
0005434136677	7350	81	19C
0005434136754	7350	82	19D
0005434136696	7350	83	19E
0005434136749	7350	84	19F
0005434136699	7350	85	20A
0005434136747	7350	86	20C
0005434136735	7350	87	20D
0005434136715	7350	88	20E
0005434136724	7350	89	20F
0005435808052	1943	1	2B
0005435808054	1943	2	4B
0005435808055	1943	3	4C
0005435808058	1943	4	6B
0005434610167	1943	5	7A
0005435808049	1943	6	7B
0005435808051	1943	7	7C
0005434610166	1943	8	18C
0005435808050	1943	9	18D
0005435808059	1943	10	20B
0005435808057	1943	11	20C
0005435808053	1943	12	21A
0005435808056	1943	13	22B
0005434608276	6496	1	3D
0005434608277	6496	2	20A
0005435078071	2231	1	1C
0005435078075	2231	2	3A
0005435078079	2231	3	4A
0005435078069	2231	4	4B
0005435078070	2231	5	4C
0005435078063	2231	6	5C
0005435078072	2231	7	6A
0005435078068	2231	8	6B
0005435078064	2231	9	7C
0005435078065	2231	10	7D
0005435078076	2231	11	20B
0005435078078	2231	12	20C
0005435078077	2231	13	21A
0005435078067	2231	14	21B
0005435078074	2231	15	22B
0005435078073	2231	16	22C
0005435078066	2231	17	22D
0005433266564	24372	1	1A
0005433266562	24372	2	1B
0005433266563	24372	3	3D
0005433266565	24372	4	4C
0005433266559	24372	5	4D
0005433266561	24372	6	5A
0005433266560	24372	7	18D
0005433266557	24372	8	20A
0005433266558	24372	9	22C
0005433266566	24372	10	22D
0005433266556	24372	11	23A
0005434988556	6650	1	1C
0005435803211	6650	2	1D
0005435803210	6650	3	2A
0005434988555	6650	4	3D
0005434988559	6650	5	4A
0005434988563	6650	6	4C
0005434988561	6650	7	5B
0005434988558	6650	8	5C
0005434988557	6650	9	7D
0005435803212	6650	10	20B
0005434988564	6650	11	21A
0005434988562	6650	12	21B
0005435803213	6650	13	21D
0005434988560	6650	14	22A
0005435464473	23602	1	6B
0005435464472	23602	2	18D
0005432382491	30471	1	1C
0005433449593	30471	2	1D
0005432382518	30471	3	1F
0005433449595	30471	4	2A
0005433449599	30471	5	2C
0005433449600	30471	6	2D
0005432382487	30471	7	3A
0005432382485	30471	8	3C
0005432382519	30471	9	3F
0005432382495	30471	10	4D
0005433454838	30471	11	4E
0005433449586	30471	12	4F
0005432382505	30471	13	5A
0005432382493	30471	14	5D
0005433449589	30471	15	5E
0005433454837	30471	16	5F
0005432382501	30471	17	6A
0005433449588	30471	18	6C
0005432382499	30471	19	6D
0005432382514	30471	20	6F
0005432382510	30471	21	7A
0005432382484	30471	22	7C
0005433449596	30471	23	7E
0005433449594	30471	24	8A
0005432382490	30471	25	8C
0005432382492	30471	26	8D
0005433449590	30471	27	8E
0005432382496	30471	28	9A
0005432382506	30471	29	9C
0005433449605	30471	30	9E
0005433449584	30471	31	10C
0005432382515	30471	32	10D
0005433449592	30471	33	10E
0005433449604	30471	34	10F
0005432382500	30471	35	11A
0005433449603	30471	36	11C
0005433449591	30471	37	11F
0005432382520	30471	38	12A
0005432382498	30471	39	12C
0005433449583	30471	40	12D
0005432382504	30471	41	12E
0005432382508	30471	42	12F
0005432382513	30471	43	13A
0005432382489	30471	44	13D
0005433449587	30471	45	14A
0005433453727	30471	46	14C
0005433449597	30471	47	14D
0005432382488	30471	48	14E
0005432382486	30471	49	14F
0005432382517	30471	50	15A
0005433449602	30471	51	15C
0005432382516	30471	52	15E
0005432382497	30471	53	15F
0005432382502	30471	54	16A
0005433449598	30471	55	16E
0005432382511	30471	56	16F
0005432382509	30471	57	17C
0005432382507	30471	58	17F
0005432382503	30471	59	18C
0005432382494	30471	60	18E
0005433449585	30471	61	19E
0005433453726	30471	62	20A
0005433449601	30471	63	20C
0005432382512	30471	64	20F
0005435299698	29743	1	1A
0005435302120	29743	2	1B
0005433126769	29743	3	1D
0005435302119	29743	4	4A
0005433129199	29743	5	4C
0005435299697	29743	6	5A
0005433126768	29743	7	5B
0005435299696	29743	8	6B
0005433126771	29743	9	7B
0005435299699	29743	10	7C
0005435302123	29743	11	18C
0005433129198	29743	12	18D
0005433129201	29743	13	19C
0005433129200	29743	14	20A
0005435302122	29743	15	20D
0005433126770	29743	16	22A
0005435302121	29743	17	22D
0005434286911	2412	1	1B
0005434286899	2412	2	1D
0005434286894	2412	3	2C
0005434286895	2412	4	2D
0005434286905	2412	5	3A
0005434286912	2412	6	3D
0005434286900	2412	7	4C
0005434286914	2412	8	4D
0005434286892	2412	9	5A
0005434286893	2412	10	5C
0005434286909	2412	11	6B
0005432264431	2412	12	6C
0005432264432	2412	13	7B
0005434286910	2412	14	7A
0005434286901	2412	15	7C
0005434286896	2412	16	18A
0005434286903	2412	17	18D
0005432264433	2412	18	19B
0005434286898	2412	19	19C
0005434286897	2412	20	20A
0005434286906	2412	21	20B
0005434286902	2412	22	20D
0005434286913	2412	23	21C
0005434286904	2412	24	22B
0005434286907	2412	25	23A
0005434286908	2412	26	23B
0005433109843	26879	1	3A
0005433109846	26879	2	3B
0005433109845	26879	3	4C
0005433109847	26879	4	6A
0005433109837	26879	5	18B
0005433109848	26879	6	19A
0005433109841	26879	7	19C
0005433109844	26879	8	21B
0005433109842	26879	9	21C
0005433109840	26879	10	21D
0005433109839	26879	11	23A
0005433109838	26879	12	23B
0005435856133	25496	1	2A
0005435856130	25496	2	7A
0005435856131	25496	3	20C
0005435856132	25496	4	20D
0005434273046	26658	1	2B
0005434272161	26658	2	3A
0005434273047	26658	3	18D
0005434272162	26658	4	22C
0005435314767	19070	1	3B
0005435314769	19070	2	3D
0005435314770	19070	3	4B
0005435314768	19070	4	22C
0005435314771	19070	5	23B
0005433874293	7786	1	19A
0005433874292	7786	2	20B
0005433874291	7786	3	21C
0005433867752	4809	1	1A
0005433867734	4809	2	1B
0005433867757	4809	3	1C
0005433867751	4809	4	1D
0005433867740	4809	5	2A
0005433867755	4809	6	2B
0005433867732	4809	7	2C
0005433867731	4809	8	3A
0005433867739	4809	9	3B
0005433867762	4809	10	3C
0005433867754	4809	11	3D
0005433867748	4809	12	4A
0005433867749	4809	13	4B
0005433867766	4809	14	4C
0005433867728	4809	15	4D
0005433867746	4809	16	5A
0005433867733	4809	17	5B
0005433867730	4809	18	5C
0005433867735	4809	19	6A
0005433867753	4809	20	6C
0005433867767	4809	21	6D
0005433867741	4809	22	7A
0005433867737	4809	23	7C
0005433867729	4809	24	7D
0005433867761	4809	25	18A
0005433867747	4809	26	18B
0005433867756	4809	27	18C
0005433867763	4809	28	18D
0005433867768	4809	29	19A
0005433867727	4809	30	19C
0005433867760	4809	31	19D
0005433867736	4809	32	20A
0005433867742	4809	33	20B
0005433867743	4809	34	20C
0005433867745	4809	35	20D
0005433867764	4809	36	21A
0005433867750	4809	37	21B
0005433867738	4809	38	21D
0005433867769	4809	39	22A
0005433867765	4809	40	22B
0005433867758	4809	41	22C
0005433867744	4809	42	22D
0005433867759	4809	43	23A
0005434663174	3415	1	1B
0005434663168	3415	2	2B
0005434461608	3415	3	3A
0005434663172	3415	4	4B
0005434460466	3415	5	4C
0005434663169	3415	6	4D
0005434663166	3415	7	5C
0005434663176	3415	8	6B
0005434461609	3415	9	6D
0005434663165	3415	10	7A
0005434663173	3415	11	18C
0005434461610	3415	12	18D
0005434460467	3415	13	19B
0005434663175	3415	14	19C
0005434663178	3415	15	19D
0005434663167	3415	16	20B
0005434663171	3415	17	20C
0005434663170	3415	18	22A
0005434663177	3415	19	22C
0005434460468	3415	20	23A
0005435911321	12445	1	2B
0005435911315	12445	2	5D
0005435911316	12445	3	18D
0005435911322	12445	4	19C
0005435911319	12445	5	20A
0005435911317	12445	6	21B
0005435911320	12445	7	22B
0005435911318	12445	8	23A
0005432153818	7072	1	1A
0005434406677	7072	2	1D
0005434299162	7072	3	2A
0005434406659	7072	4	2D
0005434299151	7072	5	2C
0005434406691	7072	6	2F
0005434406673	7072	7	3C
0005434406658	7072	8	3D
0005434299154	7072	9	4A
0005434406676	7072	10	4B
0005434299152	7072	11	4C
0005434406696	7072	12	4E
0005434406681	7072	13	4F
0005434406657	7072	14	5C
0005434299160	7072	15	5F
0005434406660	7072	16	5E
0005434406678	7072	17	6B
0005434406668	7072	18	6A
0005434299147	7072	19	6D
0005432153815	7072	20	6C
0005434406669	7072	21	7A
0005434299150	7072	22	6F
0005434406701	7072	23	7B
0005434406682	7072	24	7C
0005434406644	7072	25	7D
0005432153819	7072	26	8A
0005432153817	7072	27	7F
0005434406646	7072	28	8B
0005434406684	7072	29	8D
0005434299155	7072	30	8C
0005434406698	7072	31	8F
0005434406653	7072	32	8E
0005432153814	7072	33	9D
0005434406656	7072	34	9F
0005434406665	7072	35	10B
0005434406639	7072	36	10D
0005434406687	7072	37	11B
0005434406672	7072	38	11D
0005434406670	7072	39	11C
0005434406690	7072	40	11E
0005434406699	7072	41	11F
0005434406645	7072	42	12A
0005434406695	7072	43	12B
0005434406664	7072	44	12D
0005434406685	7072	45	12C
0005434406640	7072	46	12F
0005434406679	7072	47	13B
0005434299158	7072	48	13C
0005434406680	7072	49	13D
0005434406649	7072	50	13E
0005434299163	7072	51	13F
0005434406697	7072	52	14A
0005434406655	7072	53	14C
0005432153813	7072	54	14B
0005434299166	7072	55	14D
0005432153816	7072	56	14E
0005434406675	7072	57	14F
0005434406650	7072	58	15C
0005434299168	7072	59	15D
0005434406663	7072	60	15E
0005434406700	7072	61	16A
0005434406642	7072	62	16B
0005434406661	7072	63	16C
0005434299164	7072	64	16D
0005432108205	7072	65	16F
0005434406688	7072	66	17A
0005434406643	7072	67	17B
0005434299165	7072	68	17C
0005434406667	7072	69	17F
0005434299167	7072	70	17E
0005434406652	7072	71	18A
0005434406654	7072	72	18B
0005434299161	7072	73	18D
0005432108206	7072	74	18E
0005434299159	7072	75	18F
0005434406647	7072	76	19A
0005434406648	7072	77	19B
0005434299169	7072	78	19C
0005434406666	7072	79	19E
0005434299157	7072	80	19F
0005432108204	7072	81	20A
0005434299156	7072	82	20C
0005434406686	7072	83	20B
0005434406692	7072	84	20E
0005434406671	7072	85	20F
0005434299149	7072	86	21C
0005434406689	7072	87	21B
0005434406651	7072	88	21E
0005434406641	7072	89	22A
0005434406693	7072	90	21F
0005434299148	7072	91	22B
0005434299153	7072	92	22C
0005434406674	7072	93	22F
0005434406683	7072	94	23B
0005434406694	7072	95	23F
0005434406662	7072	96	23E
0005435293048	26885	1	1F
0005435293050	26885	2	3C
0005435293054	26885	3	5A
0005435293049	26885	4	5E
0005435293055	26885	5	6E
0005435293051	26885	6	9C
0005435293053	26885	7	16F
0005435293046	26885	8	18E
0005435293052	26885	9	18F
0005435293047	26885	10	19C
0005435293056	26885	11	20E
0005435293045	26885	12	23F
0005432603662	6446	1	1A
0005432603673	6446	2	1B
0005432603668	6446	3	1C
0005432603657	6446	4	1D
0005432603681	6446	5	2A
0005432603672	6446	6	2B
0005432603674	6446	7	2C
0005432603669	6446	8	2D
0005432603642	6446	9	3A
0005432603648	6446	10	3B
0005432603679	6446	11	3C
0005432603647	6446	12	4A
0005434512019	6446	13	4B
0005434512017	6446	14	4C
0005432603654	6446	15	4D
0005432603664	6446	16	5A
0005432603680	6446	17	5B
0005432603677	6446	18	5C
0005432603656	6446	19	5D
0005432603675	6446	20	6A
0005432603660	6446	21	6B
0005432603651	6446	22	6C
0005432603667	6446	23	6D
0005432603665	6446	24	7A
0005432603661	6446	25	7B
0005434512016	6446	26	7C
0005432603646	6446	27	7D
0005432603666	6446	28	18A
0005434512021	6446	29	18B
0005434512015	6446	30	18C
0005434512018	6446	31	19A
0005432603643	6446	32	19B
0005434512020	6446	33	19C
0005432603655	6446	34	20A
0005432603670	6446	35	20B
0005432603678	6446	36	20C
0005432603658	6446	37	20D
0005432603645	6446	38	21A
0005432603671	6446	39	21C
0005432603644	6446	40	21B
0005432603650	6446	41	21D
0005432603663	6446	42	22B
0005432603676	6446	43	22A
0005432603653	6446	44	22C
0005432603649	6446	45	22D
0005432603652	6446	46	23A
0005432603659	6446	47	23B
0005435221035	21383	1	7B
0005435221497	21383	2	19D
0005435221036	21383	3	20D
0005433250932	15025	1	1A
0005433250946	15025	2	1C
0005433250928	15025	3	2C
0005433250937	15025	4	2D
0005433250938	15025	5	2F
0005433250956	15025	6	3A
0005433250949	15025	7	4E
0005433250954	15025	8	5C
0005433250934	15025	9	6D
0005433250947	15025	10	7C
0005433250931	15025	11	7E
0005433250943	15025	12	8C
0005433250942	15025	13	8F
0005433250948	15025	14	9A
0005433250957	15025	15	9E
0005433250929	15025	16	10C
0005433250935	15025	17	10F
0005433250944	15025	18	11C
0005433250952	15025	19	12C
0005433250951	15025	20	12D
0005433250950	15025	21	13A
0005433250933	15025	22	13E
0005433250945	15025	23	13F
0005433250955	15025	24	14C
0005433250927	15025	25	16C
0005433250940	15025	26	16F
0005433250936	15025	27	17F
0005433250941	15025	28	18C
0005433250958	15025	29	18D
0005433250939	15025	30	20C
0005433250953	15025	31	20D
0005433250930	15025	32	20F
0005433007840	14158	1	1C
0005433007824	14158	2	1D
0005433007835	14158	3	2A
0005433007825	14158	4	2C
0005433007860	14158	5	2D
0005433007845	14158	6	2F
0005433007864	14158	7	3D
0005433007832	14158	8	4A
0005433007855	14158	9	4C
0005433007829	14158	10	4D
0005433007827	14158	11	4E
0005433007830	14158	12	5E
0005433007863	14158	13	6A
0005433007848	14158	14	6E
0005433007822	14158	15	7D
0005433007843	14158	16	7F
0005433007851	14158	17	8A
0005433007847	14158	18	8C
0005433007852	14158	19	8E
0005433007867	14158	20	9A
0005433007865	14158	21	9C
0005433007841	14158	22	9E
0005433007859	14158	23	10D
0005433007842	14158	24	11D
0005433007853	14158	25	12A
0005433007833	14158	26	12C
0005433007861	14158	27	13A
0005433007850	14158	28	13D
0005433007826	14158	29	14A
0005433007831	14158	30	14D
0005433007838	14158	31	14E
0005433007862	14158	32	15A
0005433007837	14158	33	15C
0005433007839	14158	34	15D
0005433007858	14158	35	16A
0005433007857	14158	36	17E
0005433007836	14158	37	18A
0005433007828	14158	38	18C
0005433007856	14158	39	18F
0005433007854	14158	40	19A
0005433007849	14158	41	19C
0005433007866	14158	42	20A
0005433007844	14158	43	20C
0005433007823	14158	44	20E
0005433007834	14158	45	20D
0005433007846	14158	46	20F
0005435487465	15791	1	1B
0005435487470	15791	2	1C
0005435487462	15791	3	2B
0005435487458	15791	4	2D
0005435487454	15791	5	3A
0005435487471	15791	6	3B
0005435487461	15791	7	4D
0005435487468	15791	8	5B
0005435487464	15791	9	6A
0005435487456	15791	10	7A
0005435487469	15791	11	7B
0005435487459	15791	12	18C
0005435487460	15791	13	19C
0005435487463	15791	14	19D
0005435487453	15791	15	20B
0005435487467	15791	16	20C
0005435487457	15791	17	20D
0005435487455	15791	18	21A
0005435487473	15791	19	21D
0005435487472	15791	20	22A
0005435487466	15791	21	22C
0005435487474	15791	22	23A
0005435838963	5995	1	2A
0005435838980	5995	2	4A
0005435838962	5995	3	4C
0005432659671	5995	4	4F
0005435838958	5995	5	5F
0005432142198	5995	6	5D
0005432142199	5995	7	6B
0005432658556	5995	8	6C
0005435838969	5995	9	7C
0005432142201	5995	10	8B
0005435838978	5995	11	8D
0005435838973	5995	12	9B
0005432142197	5995	13	9E
0005435838964	5995	14	9F
0005435838975	5995	15	10E
0005432659672	5995	16	11D
0005435838961	5995	17	12E
0005435838984	5995	18	13C
0005435838979	5995	19	13D
0005435838960	5995	20	14B
0005435838971	5995	21	14D
0005435838966	5995	22	14F
0005435838983	5995	23	15C
0005435838985	5995	24	15D
0005435838982	5995	25	15F
0005435838972	5995	26	16E
0005435838965	5995	27	17D
0005435838959	5995	28	17F
0005435838981	5995	29	17E
0005432142200	5995	30	18F
0005435838970	5995	31	19B
0005435838974	5995	32	19E
0005435838968	5995	33	19C
0005435838976	5995	34	19F
0005435838977	5995	35	20C
0005432658555	5995	36	20D
0005432658557	5995	37	20E
0005435838967	5995	38	21B
0005435472521	18069	1	2C
0005435472516	18069	2	1F
0005435472513	18069	3	3F
0005432537022	18069	4	4C
0005435472525	18069	5	6F
0005435472512	18069	6	7D
0005435472515	18069	7	8B
0005435472523	18069	8	10F
0005435472511	18069	9	11A
0005435472522	18069	10	11D
0005435472526	18069	11	12A
0005435472519	18069	12	12E
0005435472524	18069	13	13C
0005435472520	18069	14	13B
0005435472517	18069	15	13F
0005435472528	18069	16	15C
0005435472527	18069	17	15B
0005435472518	18069	18	18A
0005435472514	18069	19	19E
0005433463862	17263	1	4B
0005433462709	17263	2	19F
0005433462708	17263	3	22G
0005433463863	17263	4	30G
0005433463861	17263	5	33B
0005433284791	32042	1	1D
0005433284772	32042	2	1F
0005433284792	32042	3	3D
0005433284777	32042	4	4A
0005433284774	32042	5	4B
0005433284783	32042	6	4F
0005433284778	32042	7	5E
0005433284794	32042	8	5F
0005433284787	32042	9	6B
0005433284770	32042	10	6F
0005433284776	32042	11	7E
0005433284785	32042	12	7D
0005433284782	32042	13	8A
0005433284773	32042	14	7F
0005433284788	32042	15	12F
0005433284779	32042	16	13E
0005433284771	32042	17	14F
0005433284784	32042	18	15A
0005433284790	32042	19	16A
0005433284786	32042	20	16D
0005433284769	32042	21	17B
0005433284793	32042	22	18D
0005433284789	32042	23	18E
0005433284781	32042	24	19C
0005433284780	32042	25	21B
0005433284775	32042	26	23E
0005433656615	30589	1	1D
0005432159779	30589	2	2A
0005435212416	30589	3	2G
0005432211378	30589	4	2K
0005435212420	30589	5	3C
0005432159781	30589	6	4C
0005435212426	30589	7	4A
0005435630917	30589	8	4G
0005435212438	30589	9	5C
0005435212405	30589	10	5A
0005435212452	30589	11	5G
0005435212400	30589	12	12G
0005435212422	30589	13	13D
0005435212454	30589	14	14G
0005435212419	30589	15	14F
0005435212459	30589	16	15D
0005435212403	30589	17	15G
0005435212404	30589	18	16D
0005435212429	30589	19	16E
0005435212428	30589	20	17C
0005432211379	30589	21	16K
0005435212445	30589	22	18B
0005432211377	30589	23	18E
0005435212406	30589	24	19B
0005435212451	30589	25	19D
0005435212464	30589	26	19C
0005435212447	30589	27	19F
0005435212424	30589	28	19G
0005435212441	30589	29	19K
0005432211375	30589	30	20B
0005435212463	30589	31	21D
0005432211376	30589	32	21B
0005435212461	30589	33	21F
0005435212397	30589	34	21J
0005435212433	30589	35	21K
0005435212413	30589	36	22J
0005433656616	30589	37	23B
0005435212423	30589	38	23E
0005435212409	30589	39	23H
0005435725520	30589	40	24G
0005435212458	30589	41	25B
0005435630918	30589	42	25E
0005435212443	30589	43	25D
0005435212462	30589	44	25J
0005433656617	30589	45	26D
0005432159780	30589	46	26F
0005432211373	30589	47	27C
0005435212457	30589	48	27G
0005432211374	30589	49	27K
0005435212418	30589	50	28C
0005435212448	30589	51	28B
0005435212407	30589	52	29C
0005435212430	30589	53	29F
0005435212434	30589	54	30B
0005435212450	30589	55	30H
0005435212408	30589	56	31B
0005435212437	30589	57	31A
0005435725517	30589	58	31F
0005435212444	30589	59	32A
0005435212411	30589	60	32C
0005435212466	30589	61	32D
0005435212432	30589	62	32G
0005435212412	30589	63	33H
0005435212427	30589	64	34E
0005435212440	30589	65	35H
0005435212442	30589	66	35K
0005435212446	30589	67	36D
0005435212439	30589	68	36K
0005435212410	30589	69	37C
0005435212401	30589	70	37G
0005435212431	30589	71	37F
0005432159783	30589	72	39C
0005435212421	30589	73	39H
0005432159782	30589	74	40A
0005435212460	30589	75	40D
0005435212455	30589	76	41C
0005435725519	30589	77	43B
0005435212415	30589	78	43A
0005435212398	30589	79	43D
0005435212436	30589	80	45A
0005435725518	30589	81	45J
0005435212414	30589	82	46G
0005435212425	30589	83	47A
0005435212399	30589	84	46K
0005435212435	30589	85	47E
0005435212402	30589	86	47D
0005432211380	30589	87	47G
0005435212453	30589	88	47H
0005435212456	30589	89	48G
0005435212417	30589	90	48K
0005435212465	30589	91	50G
0005435212449	30589	92	51E
0005433367281	24833	1	1A
0005433367289	24833	2	2A
0005433367277	24833	3	2F
0005433367275	24833	4	3A
0005433367271	24833	5	3C
0005433367278	24833	6	4E
0005433367288	24833	7	4F
0005433367284	24833	8	5D
0005433367272	24833	9	5E
0005433367268	24833	10	6C
0005433367290	24833	11	6D
0005433367292	24833	12	6E
0005433367293	24833	13	7D
0005433367270	24833	14	7F
0005433367266	24833	15	8C
0005433367273	24833	16	8E
0005433367285	24833	17	9A
0005433367261	24833	18	9C
0005433367263	24833	19	10D
0005433367291	24833	20	12C
0005433367267	24833	21	13C
0005433367264	24833	22	13D
0005433367262	24833	23	13E
0005433367274	24833	24	14A
0005433367294	24833	25	14E
0005433367279	24833	26	15A
0005433367260	24833	27	15F
0005433367286	24833	28	16C
0005433367280	24833	29	16D
0005433367287	24833	30	16E
0005433367265	24833	31	18D
0005433367282	24833	32	18F
0005433367276	24833	33	19C
0005433367269	24833	34	19D
0005433367283	24833	35	20C
0005433367259	24833	36	20E
0005434979294	2032	1	1B
0005434979286	2032	2	1D
0005434979288	2032	3	2A
0005434979313	2032	4	2B
0005434979299	2032	5	2C
0005434979312	2032	6	2D
0005434979308	2032	7	3A
0005434979309	2032	8	3B
0005435801647	2032	9	3C
0005434979300	2032	10	3D
0005434979296	2032	11	4C
0005434979284	2032	12	5A
0005434979306	2032	13	5C
0005434979287	2032	14	5D
0005435801645	2032	15	6A
0005434979297	2032	16	6B
0005434979301	2032	17	6D
0005434979289	2032	18	7B
0005434979290	2032	19	7C
0005434979292	2032	20	18A
0005434979303	2032	21	18C
0005434979295	2032	22	18D
0005434979283	2032	23	19A
0005434979310	2032	24	19C
0005434979298	2032	25	19D
0005434979305	2032	26	20A
0005434979293	2032	27	20B
0005434979285	2032	28	20C
0005434979302	2032	29	20D
0005434979291	2032	30	21B
0005434979311	2032	31	21C
0005434979304	2032	32	22B
0005434979307	2032	33	22D
0005435801646	2032	34	23B
0005434952468	2569	1	1B
0005434952470	2569	2	3B
0005434952469	2569	3	6B
0005433256384	28267	1	1B
0005433256385	28267	2	3A
0005433256383	28267	3	4B
0005433111470	19841	1	3A
0005433111471	19841	2	5B
0005434136687	28737	1	1A
0005434136723	28737	2	1C
0005434136742	28737	3	1D
0005434136727	28737	4	1F
0005434136751	28737	5	2A
0005434136721	28737	6	2C
0005434136733	28737	7	2D
0005434136696	28737	8	2F
0005434136729	28737	9	3A
0005434136736	28737	10	3C
0005434136722	28737	11	3D
0005434136699	28737	12	3F
0005434136689	28737	13	4A
0005434136693	28737	14	4C
0005434136678	28737	15	4E
0005434136704	28737	16	5A
0005434136745	28737	17	4F
0005434136757	28737	18	5C
0005434136717	28737	19	5E
0005434136713	28737	20	5D
0005434136739	28737	21	6A
0005434136706	28737	22	6C
0005434136724	28737	23	6D
0005434136691	28737	24	6E
0005434136683	28737	25	6F
0005434136680	28737	26	7C
0005434136754	28737	27	7D
0005434136701	28737	28	7E
0005434136707	28737	29	7F
0005434136716	28737	30	8C
0005434136730	28737	31	8D
0005434136702	28737	32	8F
0005434136677	28737	33	9A
0005434136731	28737	34	9C
0005434136746	28737	35	9D
0005434136737	28737	36	9E
0005434136676	28737	37	10A
0005434136688	28737	38	10C
0005434136714	28737	39	10D
0005434136741	28737	40	10E
0005434136734	28737	41	10F
0005434136720	28737	42	11A
0005434136675	28737	43	11C
0005434136740	28737	44	11D
0005434136719	28737	45	11E
0005434136705	28737	46	11F
0005434136708	28737	47	12A
0005434136752	28737	48	12C
0005434136692	28737	49	12D
0005434136759	28737	50	12E
0005434136728	28737	51	12F
0005434136756	28737	52	13A
0005434136700	28737	53	13C
0005434136718	28737	54	13D
0005434136712	28737	55	13F
0005434136725	28737	56	14C
0005434136679	28737	57	14D
0005434136735	28737	58	14E
0005434136681	28737	59	14F
0005434136747	28737	60	15A
0005434136694	28737	61	15C
0005434136686	28737	62	15D
0005434136744	28737	63	15E
0005434136748	28737	64	15F
0005434136750	28737	65	16A
0005434136743	28737	66	16C
0005434136715	28737	67	16D
0005434136684	28737	68	16E
0005434136732	28737	69	16F
0005434136758	28737	70	17A
0005434136703	28737	71	17C
0005434136697	28737	72	17D
0005434136709	28737	73	17E
0005434136698	28737	74	17F
0005434136755	28737	75	18A
0005434136749	28737	76	18C
0005434136726	28737	77	18D
0005434136711	28737	78	18E
0005434136682	28737	79	18F
0005434136695	28737	80	19C
0005434136753	28737	81	19F
0005434136738	28737	82	20A
0005434136690	28737	83	20C
0005434136710	28737	84	20D
0005434136685	28737	85	20F
0005433538729	6814	1	3B
0005433538730	6814	2	3D
0005433538733	6814	3	5B
0005433538726	6814	4	6A
0005433538732	6814	5	7B
0005433538725	6814	6	19C
0005433538728	6814	7	20A
0005433538731	6814	8	21A
0005433538727	6814	9	21D
0005435259685	25016	1	1C
0005435259683	25016	2	1D
0005435259682	25016	3	7D
0005435259684	25016	4	19D
0005435259686	25016	5	20C
0005435259687	25016	6	21D
0005433511815	806	1	2C
0005433511813	806	2	2D
0005433511810	806	3	4C
0005433511812	806	4	5D
0005433511811	806	5	6B
0005433511814	806	6	18B
0005433511816	806	7	19A
0005433511817	806	8	22A
0005432922456	16133	1	5C
0005432922459	16133	2	19C
0005432922458	16133	3	20D
0005432922457	16133	4	22B
0005434950458	3667	1	1A
0005434950455	3667	2	1B
0005435696899	3667	3	1C
0005435696880	3667	4	1D
0005435696887	3667	5	2A
0005435696900	3667	6	2C
0005434950453	3667	7	2D
0005435696879	3667	8	3A
0005435696878	3667	9	3B
0005435696876	3667	10	3D
0005435696893	3667	11	3C
0005434950454	3667	12	5B
0005435696883	3667	13	5C
0005434950456	3667	14	5D
0005435696872	3667	15	6C
0005435696895	3667	16	7B
0005435696884	3667	17	7C
0005434950457	3667	18	7D
0005435696888	3667	19	18A
0005435696890	3667	20	18D
0005435696898	3667	21	19B
0005435696889	3667	22	19D
0005435696886	3667	23	19C
0005435696892	3667	24	20A
0005435696891	3667	25	20B
0005435696896	3667	26	20C
0005435696894	3667	27	21A
0005435696897	3667	28	21B
0005435696874	3667	29	21C
0005435696885	3667	30	21D
0005435696873	3667	31	22A
0005435696877	3667	32	22C
0005435696882	3667	33	22D
0005435696881	3667	34	23A
0005435696875	3667	35	23B
0005435916121	16305	1	1B
0005435916120	16305	2	6C
0005435934992	16305	3	18C
0005435934995	16305	4	18D
0005435934993	16305	5	19A
0005435934994	16305	6	19D
0005435916122	16305	7	21B
0005433519381	3957	1	1A
0005432609666	3957	2	1D
0005434604843	3957	3	2A
0005434606767	3957	4	2C
0005433519383	3957	5	3D
0005434604842	3957	6	4A
0005433519384	3957	7	4D
0005432607498	3957	8	5A
0005434606765	3957	9	5B
0005432609662	3957	10	5C
0005432607499	3957	11	6D
0005433519382	3957	12	7A
0005434606766	3957	13	7D
0005434604841	3957	14	18B
0005433519385	3957	15	19B
0005432607500	3957	16	20A
0005434604844	3957	17	20C
0005434604840	3957	18	20D
0005432609665	3957	19	21B
0005434606764	3957	20	21C
0005432607497	3957	21	22C
0005432607501	3957	22	22D
0005432609663	3957	23	23A
0005432609664	3957	24	23B
0005433348892	15973	1	1A
0005433348896	15973	2	1B
0005433348893	15973	3	2A
0005433348895	15973	4	2B
0005433348894	15973	5	5B
0005433348897	15973	6	6A
0005434445208	17189	1	1B
0005434445209	17189	2	3B
0005434445207	17189	3	4B
0005434445210	17189	4	5A
0005434446476	17189	5	6A
0005433159277	17585	1	4B
0005433159278	17585	2	5B
0005435132711	7908	1	2B
0005435132709	7908	2	2D
0005435132712	7908	3	3A
0005435132710	7908	4	5D
0005435132707	7908	5	6A
0005435132708	7908	6	7B
0005435132706	7908	7	19D
0005435132714	7908	8	20D
0005435132705	7908	9	21D
0005435132713	7908	10	22A
0005435383066	33114	1	3C
0005435383060	33114	2	4A
0005435383065	33114	3	7B
0005435383061	33114	4	18D
0005435383062	33114	5	19B
0005435383063	33114	6	22A
0005435383064	33114	7	23A
0005435810985	4405	1	6E
0005435810993	4405	2	7F
0005435810988	4405	3	8A
0005435810995	4405	4	8F
0005435810989	4405	5	9F
0005435810992	4405	6	14C
0005435810991	4405	7	15D
0005435810994	4405	8	15B
0005435810987	4405	9	15F
0005435810990	4405	10	16B
0005435810986	4405	11	20C
0005435938844	29457	1	6A
0005435938845	29457	2	8F
0005435938843	29457	3	12B
0005435160125	7507	1	2A
0005435160123	7507	2	2C
0005435160124	7507	3	6A
0005435160114	7507	4	6C
0005435160116	7507	5	7B
0005435160119	7507	6	7C
0005435160121	7507	7	18A
0005435160118	7507	8	18B
0005435160117	7507	9	18D
0005435160115	7507	10	20B
0005435160120	7507	11	21C
0005435160122	7507	12	22A
0005435390125	29541	1	2A
0005435390124	29541	2	3A
0005435390126	29541	3	7A
0005435390129	29541	4	18A
0005435390127	29541	5	18B
0005435390128	29541	6	20B
0005435390123	29541	7	22B
0005435390130	29541	8	22C
0005435178469	18462	1	2B
0005435178977	18462	2	3B
0005435178470	18462	3	5A
0005432400060	27182	1	1A
0005432400058	27182	2	2A
0005432400059	27182	3	3A
0005432400056	27182	4	4A
0005432398129	27182	5	4B
0005432398131	27182	6	5A
0005432398130	27182	7	5B
0005432400057	27182	8	6B
0005435103816	6565	1	1F
0005434503534	6565	2	2C
0005434503498	6565	3	2D
0005434503502	6565	4	2F
0005434503513	6565	5	3A
0005435103809	6565	6	3C
0005434503507	6565	7	3D
0005434503520	6565	8	3F
0005435103804	6565	9	4A
0005435103814	6565	10	4C
0005435103810	6565	11	4E
0005434503497	6565	12	4F
0005434503526	6565	13	5A
0005434503532	6565	14	5C
0005434503517	6565	15	5D
0005434503529	6565	16	5E
0005434503536	6565	17	6E
0005434503527	6565	18	7C
0005434503530	6565	19	7D
0005435103817	6565	20	7E
0005434503528	6565	21	7F
0005434503516	6565	22	8C
0005434503505	6565	23	8D
0005434503500	6565	24	8E
0005435103808	6565	25	9C
0005435103812	6565	26	9F
0005434503499	6565	27	10C
0005434503514	6565	28	10D
0005434503503	6565	29	10E
0005434503535	6565	30	11A
0005434503524	6565	31	11C
0005435103811	6565	32	11D
0005434503511	6565	33	12A
0005435103818	6565	34	12C
0005435103805	6565	35	12F
0005434503515	6565	36	13A
0005434503501	6565	37	13D
0005434503508	6565	38	13E
0005434503512	6565	39	15F
0005434503506	6565	40	16A
0005434503509	6565	41	16C
0005434503521	6565	42	16D
0005434503519	6565	43	16E
0005435103815	6565	44	16F
0005434503518	6565	45	17A
0005434503523	6565	46	17C
0005434503522	6565	47	17D
0005434503531	6565	48	17E
0005434503533	6565	49	17F
0005434503525	6565	50	18F
0005434503510	6565	51	19A
0005435103807	6565	52	19C
0005435103813	6565	53	19E
0005434503504	6565	54	20C
0005435103806	6565	55	20E
0005435652303	1664	1	1A
0005435652309	1664	2	1F
0005435652300	1664	3	2A
0005435652317	1664	4	2D
0005435652302	1664	5	3C
0005435652325	1664	6	4C
0005435652318	1664	7	6C
0005435652320	1664	8	6D
0005435652298	1664	9	6E
0005435652304	1664	10	7D
0005435652326	1664	11	7F
0005435652299	1664	12	8E
0005435652307	1664	13	9A
0005435652324	1664	14	9D
0005435652316	1664	15	9E
0005435652312	1664	16	9F
0005435652338	1664	17	10C
0005435652330	1664	18	10E
0005435652323	1664	19	11A
0005435652308	1664	20	12C
0005435652334	1664	21	12E
0005435652329	1664	22	13C
0005435652306	1664	23	13E
0005435652328	1664	24	14D
0005435652319	1664	25	14F
0005435652339	1664	26	15A
0005435652332	1664	27	15C
0005435652297	1664	28	15D
0005435652322	1664	29	15F
0005435652313	1664	30	16C
0005435652301	1664	31	16F
0005435652337	1664	32	17A
0005435652327	1664	33	17C
0005435652315	1664	34	17D
0005435652321	1664	35	17E
0005435652310	1664	36	18A
0005435652305	1664	37	18C
0005435652331	1664	38	18D
0005435652314	1664	39	18E
0005435652335	1664	40	19A
0005435652333	1664	41	19C
0005435652311	1664	42	19D
0005435652336	1664	43	20C
0005433367275	21714	1	1C
0005433367270	21714	2	1D
0005433367268	21714	3	3A
0005433367264	21714	4	3C
0005433367290	21714	5	3F
0005433367278	21714	6	4D
0005433367289	21714	7	4F
0005433367280	21714	8	5C
0005433367274	21714	9	5E
0005433367265	21714	10	6C
0005433367288	21714	11	6D
0005433367273	21714	12	7A
0005433367279	21714	13	7C
0005433367269	21714	14	7F
0005433367291	21714	15	8A
0005433367282	21714	16	8C
0005433367262	21714	17	8D
0005433367272	21714	18	8E
0005433367287	21714	19	9C
0005433367283	21714	20	9D
0005433367276	21714	21	10C
0005433367286	21714	22	10E
0005433367284	21714	23	10F
0005433367293	21714	24	11D
0005433367263	21714	25	11E
0005433367277	21714	26	12A
0005433367267	21714	27	14D
0005433367271	21714	28	14F
0005433367294	21714	29	15E
0005433367292	21714	30	16C
0005433367285	21714	31	16F
0005433367266	21714	32	17C
0005433367281	21714	33	18C
0005433367260	21714	34	18E
0005433367259	21714	35	19A
0005433367261	21714	36	20C
0005433985170	4188	1	1F
0005433985169	4188	2	2C
0005433985210	4188	3	2D
0005433985180	4188	4	2F
0005433985182	4188	5	3A
0005433985171	4188	6	4A
0005433985176	4188	7	4C
0005433985186	4188	8	4D
0005433985201	4188	9	5A
0005433985191	4188	10	5D
0005433985172	4188	11	6A
0005433985200	4188	12	6C
0005433985167	4188	13	6D
0005433985184	4188	14	6E
0005433985195	4188	15	7A
0005433985197	4188	16	7C
0005433985175	4188	17	7E
0005433985190	4188	18	7F
0005435788730	4188	19	8C
0005433985211	4188	20	8D
0005433985173	4188	21	8F
0005433985193	4188	22	9C
0005433985199	4188	23	9D
0005433985165	4188	24	9E
0005433985174	4188	25	10D
0005433985166	4188	26	10F
0005433985181	4188	27	11A
0005433985203	4188	28	11E
0005433985179	4188	29	12A
0005433985178	4188	30	12C
0005433985209	4188	31	12D
0005433985194	4188	32	12E
0005433985185	4188	33	13C
0005433985183	4188	34	13D
0005433985204	4188	35	13E
0005433985163	4188	36	14A
0005435788729	4188	37	14D
0005433985187	4188	38	14E
0005433985198	4188	39	14F
0005433985208	4188	40	15D
0005433985192	4188	41	15F
0005433985188	4188	42	16A
0005433985205	4188	43	16C
0005433985164	4188	44	16D
0005433985202	4188	45	16E
0005433985207	4188	46	16F
0005433985206	4188	47	17C
0005433985162	4188	48	17D
0005433985189	4188	49	18A
0005433985196	4188	50	18E
0005433985168	4188	51	19F
0005433985177	4188	52	20A
0005435720119	24782	1	19B
0005435720118	24782	2	20B
0005434509023	1614	1	3A
0005434509016	1614	2	4B
0005434509025	1614	3	5A
0005434509015	1614	4	5B
0005434509022	1614	5	6A
0005434509024	1614	6	6D
0005434509028	1614	7	7A
0005434509027	1614	8	7C
0005434509018	1614	9	18A
0005434509014	1614	10	18C
0005434509021	1614	11	18D
0005434509026	1614	12	20B
0005434509019	1614	13	20D
0005434509017	1614	14	21A
0005434509030	1614	15	22D
0005434509029	1614	16	23A
0005434509020	1614	17	23B
0005432869418	17829	1	1C
0005432869422	17829	2	3F
0005432869419	17829	3	4C
0005434151657	17829	4	8D
0005434151658	17829	5	8E
0005432869423	17829	6	11A
0005432869417	17829	7	13A
0005432869420	17829	8	16A
0005432869421	17829	9	17C
0005434151659	17829	10	20E
0005432666353	26292	1	2C
0005432665238	26292	2	2D
0005432657395	26292	3	3F
0005432657394	26292	4	4D
0005432657393	26292	5	10A
0005432666351	26292	6	11D
0005432666352	26292	7	12E
0005432665237	26292	8	18E
0005432865895	25073	1	1A
0005432865897	25073	2	2D
0005432865903	25073	3	3A
0005432865899	25073	4	4A
0005432865902	25073	5	6D
0005432865901	25073	6	7D
0005432865908	25073	7	9C
0005432865907	25073	8	13C
0005432865905	25073	9	14A
0005432865906	25073	10	16C
0005432865898	25073	11	16D
0005432865904	25073	12	16E
0005432865896	25073	13	19A
0005432865900	25073	14	19E
0005432865894	25073	15	19F
0005432327939	3086	1	1A
0005433438776	3086	2	1D
0005432287106	3086	3	1F
0005432327938	3086	4	2A
0005433438771	3086	5	2C
0005432327941	3086	6	2D
0005432327960	3086	7	2F
0005432327980	3086	8	3A
0005432327957	3086	9	3C
0005432327973	3086	10	3D
0005432327951	3086	11	3F
0005432327967	3086	12	4A
0005432327982	3086	13	4C
0005432327970	3086	14	4D
0005432327984	3086	15	4E
0005433438772	3086	16	4F
0005432287107	3086	17	5A
0005433438775	3086	18	5D
0005432327958	3086	19	5E
0005433438769	3086	20	6E
0005432327975	3086	21	6F
0005432327942	3086	22	7A
0005432327963	3086	23	7D
0005432327954	3086	24	7E
0005432327953	3086	25	8D
0005432327955	3086	26	8F
0005432327943	3086	27	9D
0005432327979	3086	28	9F
0005432327949	3086	29	10A
0005432327981	3086	30	10C
0005432327947	3086	31	10F
0005432327946	3086	32	11A
0005432287108	3086	33	12A
0005432327945	3086	34	12D
0005432327952	3086	35	13C
0005432287109	3086	36	13E
0005432327956	3086	37	14A
0005432327969	3086	38	14F
0005432327971	3086	39	15A
0005432327944	3086	40	15C
0005432327977	3086	41	15E
0005432327972	3086	42	15D
0005433438774	3086	43	15F
0005433438770	3086	44	16A
0005432327965	3086	45	16C
0005432327962	3086	46	17A
0005432327976	3086	47	17E
0005432327964	3086	48	18A
0005432327966	3086	49	18C
0005432327978	3086	50	18D
0005432327961	3086	51	18E
0005432327974	3086	52	18F
0005432327948	3086	53	19C
0005432327940	3086	54	19D
0005432327950	3086	55	19E
0005433438773	3086	56	20A
0005433438768	3086	57	20C
0005432327983	3086	58	20D
0005432327968	3086	59	20E
0005432327959	3086	60	20F
0005432054255	31120	1	1A
0005432905028	31120	2	1F
0005432905027	31120	3	6F
0005432054256	31120	4	12C
0005432905026	31120	5	13C
0005432054257	31120	6	14F
0005435998981	6201	1	2C
0005435998969	6201	2	2F
0005434309523	6201	3	4F
0005435998977	6201	4	5C
0005434309517	6201	5	5E
0005435998974	6201	6	6A
0005434309527	6201	7	6D
0005434309519	6201	8	8A
0005435998983	6201	9	8C
0005435998984	6201	10	8F
0005435998968	6201	11	9D
0005435998975	6201	12	10E
0005435998970	6201	13	11C
0005434309518	6201	14	11B
0005435998979	6201	15	12C
0005435998976	6201	16	12E
0005434309515	6201	17	12F
0005434309529	6201	18	13E
0005434309525	6201	19	15A
0005434309514	6201	20	16B
0005434309528	6201	21	16A
0005434309521	6201	22	16F
0005434309522	6201	23	17B
0005434309520	6201	24	19E
0005435998978	6201	25	19F
0005435998971	6201	26	20A
0005435998982	6201	27	20D
0005435998972	6201	28	21D
0005434309526	6201	29	21F
0005432146166	6201	30	22B
0005434309524	6201	31	22D
0005435998973	6201	32	23B
0005434309516	6201	33	23D
0005435998980	6201	34	23C
0005435487456	19552	1	1C
0005435487465	19552	2	1F
0005435487464	19552	3	2C
0005435487471	19552	4	4D
0005435296949	19552	5	5D
0005435296950	19552	6	5F
0005435296947	19552	7	6F
0005435487470	19552	8	7B
0005435487466	19552	9	7E
0005435487472	19552	10	8C
0005435296944	19552	11	10E
0005435487453	19552	12	11D
0005435487457	19552	13	11E
0005435487474	19552	14	12A
0005435487461	19552	15	13A
0005435487463	19552	16	12F
0005435296946	19552	17	14B
0005435487455	19552	18	17E
0005435487467	19552	19	18E
0005435296948	19552	20	19A
0005435487473	19552	21	19D
0005435487454	19552	22	19C
0005435487459	19552	23	20B
0005435487469	19552	24	20D
0005435296945	19552	25	20C
0005435487460	19552	26	20F
0005435487468	19552	27	23A
0005435487458	19552	28	23E
0005435487462	19552	29	23F
0005432291892	1599	1	1C
0005435501954	1599	2	1F
0005434565699	1599	3	2C
0005435501960	1599	4	2D
0005435501964	1599	5	2F
0005434565693	1599	6	3A
0005435501965	1599	7	3C
0005435517612	1599	8	3D
0005435508178	1599	9	3F
0005434565696	1599	10	4A
0005435517607	1599	11	4C
0005434565701	1599	12	4D
0005434565702	1599	13	4E
0005435508182	1599	14	4F
0005435517624	1599	15	5A
0005435501957	1599	16	5C
0005435501953	1599	17	5D
0005435517619	1599	18	5E
0005434565700	1599	19	5F
0005435517628	1599	20	6A
0005435517608	1599	21	6C
0005435508181	1599	22	6D
0005435501956	1599	23	6E
0005435501958	1599	24	6F
0005435517622	1599	25	7C
0005434565703	1599	26	7D
0005435517611	1599	27	7E
0005434565698	1599	28	7F
0005435501955	1599	29	8A
0005435501974	1599	30	8D
0005435508183	1599	31	8F
0005435501970	1599	32	9A
0005434565692	1599	33	9E
0005435501959	1599	34	10C
0005435517613	1599	35	10E
0005435517614	1599	36	10F
0005435501971	1599	37	11C
0005435501962	1599	38	12D
0005435501963	1599	39	13A
0005435517626	1599	40	13D
0005435517625	1599	41	13E
0005434565694	1599	42	14A
0005435517615	1599	43	14C
0005435501967	1599	44	14D
0005434565704	1599	45	14F
0005435508179	1599	46	15A
0005435517616	1599	47	15D
0005435501961	1599	48	15E
0005434565695	1599	49	15F
0005435501973	1599	50	16A
0005435517620	1599	51	16D
0005432291891	1599	52	16E
0005434565705	1599	53	16F
0005435517609	1599	54	17A
0005435508184	1599	55	17C
0005435517617	1599	56	17D
0005435508180	1599	57	17E
0005435517610	1599	58	18A
0005434565697	1599	59	18C
0005435501972	1599	60	18E
0005435517618	1599	61	18F
0005435508177	1599	62	19A
0005435517621	1599	63	19D
0005435501969	1599	64	19E
0005435501966	1599	65	20A
0005435517623	1599	66	20C
0005435517627	1599	67	20D
0005435501968	1599	68	20E
0005433185981	20861	1	5E
0005433185984	20861	2	6D
0005433185979	20861	3	9D
0005433185982	20861	4	10C
0005433185977	20861	5	11D
0005433185978	20861	6	13D
0005433185980	20861	7	14E
0005433185983	20861	8	16D
0005433185976	20861	9	18E
0005435153639	3879	1	1C
0005435153637	3879	2	2B
0005435153632	3879	3	3C
0005435153638	3879	4	4B
0005435153633	3879	5	6B
0005435153635	3879	6	7B
0005435153636	3879	7	18C
0005435153634	3879	8	22A
0005435931540	21849	1	1D
0005435931539	21849	2	3A
0005435931542	21849	3	6B
0005435931541	21849	4	18A
0005432628616	7179	1	1B
0005432628609	7179	2	2B
0005432628612	7179	3	3D
0005432628600	7179	4	4A
0005432628607	7179	5	4D
0005432628606	7179	6	7C
0005432628605	7179	7	7D
0005432628613	7179	8	19A
0005432628603	7179	9	20A
0005432628602	7179	10	20C
0005432628601	7179	11	20D
0005432628611	7179	12	21B
0005432628608	7179	13	21C
0005432628610	7179	14	21D
0005432628615	7179	15	22B
0005432628614	7179	16	22C
0005432628604	7179	17	23A
0005435225455	28148	1	2C
0005435225454	28148	2	3B
0005435225452	28148	3	4A
0005435225456	28148	4	5D
0005435225453	28148	5	6C
0005435225457	28148	6	7C
0005435225458	28148	7	19B
0005435225451	28148	8	21B
0005435225450	28148	9	22B
0005435959989	8762	1	2D
0005435959988	8762	2	18B
0005435959986	8762	3	20A
0005435959987	8762	4	21C
0005434267889	15218	1	4D
0005434267890	15218	2	18A
0005434267888	15218	3	18D
0005434267887	15218	4	20C
0005432677506	1172	1	1F
0005432692551	1172	2	2A
0005432677505	1172	3	2D
0005432692536	1172	4	3C
0005432692554	1172	5	4D
0005432692540	1172	6	4C
0005432692531	1172	7	4F
0005432674886	1172	8	5C
0005432674888	1172	9	5A
0005432692558	1172	10	6B
0005432692547	1172	11	6A
0005432692557	1172	12	6E
0005432692549	1172	13	6D
0005432692548	1172	14	7B
0005432692552	1172	15	7E
0005432692535	1172	16	7D
0005432674881	1172	17	8A
0005432674880	1172	18	8B
0005432674889	1172	19	8C
0005432692530	1172	20	9C
0005432692529	1172	21	9B
0005432674883	1172	22	9E
0005432674885	1172	23	10C
0005432692541	1172	24	10F
0005432692537	1172	25	11C
0005432677504	1172	26	12A
0005432692532	1172	27	12D
0005432692528	1172	28	13D
0005432692543	1172	29	14B
0005432692546	1172	30	14A
0005432674878	1172	31	14D
0005432692544	1172	32	15C
0005432692534	1172	33	15E
0005432692533	1172	34	15D
0005432674892	1172	35	16B
0005432674882	1172	36	16A
0005432674887	1172	37	16D
0005432674891	1172	38	17B
0005432674884	1172	39	17D
0005432692545	1172	40	18B
0005432674879	1172	41	18A
0005432692550	1172	42	18C
0005432677503	1172	43	19A
0005432692538	1172	44	19B
0005432692539	1172	45	19F
0005432692555	1172	46	20A
0005432692556	1172	47	21B
0005432692542	1172	48	21A
0005432674890	1172	49	20F
0005432692527	1172	50	21E
0005432692553	1172	51	21F
0005432873174	17471	1	8C
0005432873179	17471	2	12D
0005432873178	17471	3	13A
0005432873176	17471	4	15C
0005432873177	17471	5	17F
0005432873175	17471	6	21C
0005434434940	1101	1	1A
0005434434930	1101	2	2B
0005434434939	1101	3	4D
0005434434926	1101	4	5A
0005434434933	1101	5	6B
0005434434931	1101	6	7C
0005434434938	1101	7	7D
0005434434929	1101	8	18C
0005434434937	1101	9	18D
0005434434925	1101	10	19C
0005434434934	1101	11	21B
0005434434935	1101	12	21D
0005434434927	1101	13	22A
0005434434928	1101	14	22C
0005434434936	1101	15	23A
0005434434932	1101	16	23B
0005433156610	17310	1	1B
0005433156606	17310	2	5C
0005433156609	17310	3	6B
0005433156612	17310	4	6D
0005433156608	17310	5	18B
0005433156607	17310	6	18C
0005433156611	17310	7	20B
0005435086709	4086	1	1D
0005435086713	4086	2	2B
0005435086707	4086	3	3B
0005435086710	4086	4	4C
0005435086711	4086	5	5C
0005435086715	4086	6	5D
0005435086714	4086	7	6B
0005435086708	4086	8	18C
0005435086712	4086	9	23B
0005435928067	24440	1	1B
0005435928065	24440	2	1C
0005435928063	24440	3	2C
0005435928064	24440	4	4C
0005435928062	24440	5	5A
0005435928066	24440	6	19B
0005434963930	1315	1	1F
0005434963898	1315	2	1C
0005434963932	1315	3	1H
0005434963910	1315	4	3A
0005434963927	1315	5	4G
0005434963921	1315	6	5B
0005434963917	1315	7	5C
0005434963902	1315	8	5F
0005434963911	1315	9	11H
0005434963901	1315	10	12F
0005432279238	1315	11	13E
0005434963903	1315	12	14A
0005434963904	1315	13	14D
0005434963906	1315	14	15E
0005434963923	1315	15	16A
0005432279236	1315	16	17A
0005434963928	1315	17	17B
0005434963925	1315	18	17G
0005432279237	1315	19	18A
0005434963895	1315	20	19B
0005434963909	1315	21	19A
0005434963912	1315	22	21A
0005434963920	1315	23	21D
0005434963918	1315	24	22D
0005434963922	1315	25	22H
0005434963929	1315	26	23B
0005434963896	1315	27	23D
0005434963924	1315	28	23F
0005434963919	1315	29	23H
0005432279235	1315	30	29B
0005434963926	1315	31	29F
0005434963915	1315	32	29H
0005434963900	1315	33	32F
0005434963905	1315	34	33E
0005434963916	1315	35	33F
0005434963913	1315	36	34G
0005434963931	1315	37	35A
0005434963933	1315	38	36H
0005434963908	1315	39	37B
0005434963907	1315	40	37H
0005434963914	1315	41	38F
0005434963899	1315	42	38H
0005434963897	1315	43	39F
0005433261393	18258	1	11B
0005433261388	18258	2	13A
0005433261396	18258	3	15A
0005433261395	18258	4	15B
0005433261402	18258	5	15D
0005433261404	18258	6	15H
0005433261389	18258	7	16H
0005433261406	18258	8	19F
0005433261392	18258	9	20A
0005433261399	18258	10	22G
0005433261401	18258	11	23G
0005433261397	18258	12	24A
0005433261407	18258	13	24E
0005433261405	18258	14	27E
0005433261390	18258	15	29D
0005433261408	18258	16	31A
0005433261391	18258	17	31B
0005433261394	18258	18	33A
0005433261398	18258	19	34A
0005433261400	18258	20	35H
0005433261403	18258	21	38D
0005434625803	4821	1	2A
0005434625809	4821	2	5A
0005434625807	4821	3	6A
0005434625812	4821	4	10F
0005434625810	4821	5	17A
0005434625806	4821	6	18E
0005434625808	4821	7	19A
0005434625811	4821	8	19C
0005434625805	4821	9	19D
0005434625804	4821	10	20E
0005433194823	32913	1	5C
0005435907421	32913	2	6A
0005433194820	32913	3	8C
0005433194822	32913	4	9F
0005435907425	32913	5	13F
0005435907423	32913	6	16A
0005435907422	32913	7	17D
0005433194821	32913	8	18F
0005435907424	32913	9	20C
0005432195658	13778	1	2C
0005435937315	13778	2	5D
0005432195659	13778	3	19A
0005435937318	13778	4	20A
0005435937314	13778	5	22A
0005435937316	13778	6	22C
0005435937317	13778	7	23A
0005435784732	27409	1	1A
0005432190563	27409	2	1B
0005435784756	27409	3	1C
0005435784730	27409	4	1D
0005435784752	27409	5	2B
0005435784738	27409	6	2C
0005435784739	27409	7	2D
0005435784737	27409	8	3A
0005435784759	27409	9	3C
0005435784742	27409	10	3D
0005435784736	27409	11	4A
0005435784748	27409	12	4B
0005435784735	27409	13	4C
0005435784733	27409	14	4D
0005435784750	27409	15	5A
0005435784761	27409	16	5C
0005435784758	27409	17	6A
0005435784757	27409	18	6B
0005435784763	27409	19	6C
0005432190564	27409	20	7A
0005435784749	27409	21	6D
0005432190561	27409	22	7B
0005435784762	27409	23	7C
0005435784729	27409	24	7D
0005432190562	27409	25	18A
0005435784731	27409	26	18C
0005435784755	27409	27	19A
0005435784744	27409	28	18D
0005435784740	27409	29	19B
0005435784747	27409	30	19C
0005435784754	27409	31	19D
0005435784728	27409	32	20A
0005435784745	27409	33	20B
0005435784751	27409	34	20C
0005435784746	27409	35	20D
0005435784741	27409	36	21C
0005435784743	27409	37	22A
0005435784753	27409	38	22B
0005435784727	27409	39	22D
0005435784734	27409	40	23A
0005435784760	27409	41	23B
0005432058316	20278	1	1A
0005435310873	20278	2	2A
0005435310859	20278	3	2C
0005435310861	20278	4	4D
0005435310869	20278	5	5C
0005432058317	20278	6	5D
0005435310858	20278	7	5F
0005435310863	20278	8	6E
0005435310867	20278	9	6F
0005435310875	20278	10	7D
0005435310860	20278	11	7E
0005435310856	20278	12	8A
0005435310857	20278	13	8F
0005435310870	20278	14	10C
0005432058319	20278	15	10F
0005435310866	20278	16	11E
0005435310872	20278	17	12A
0005435310862	20278	18	13C
0005435310865	20278	19	15A
0005435310871	20278	20	15C
0005435310868	20278	21	16A
0005435310874	20278	22	18D
0005432058318	20278	23	19D
0005435310864	20278	24	19F
0005434406750	26977	1	1A
0005434406732	26977	2	1C
0005434406744	26977	3	1D
0005434406737	26977	4	2C
0005434406755	26977	5	2D
0005434406753	26977	6	2F
0005434406747	26977	7	3A
0005434406721	26977	8	3C
0005434406713	26977	9	3D
0005434406751	26977	10	3F
0005434406726	26977	11	4A
0005434406763	26977	12	4C
0005434406722	26977	13	4E
0005434406709	26977	14	4F
0005434406703	26977	15	5C
0005432153826	26977	16	5D
0005434406716	26977	17	5F
0005434406707	26977	18	6C
0005434406715	26977	19	6D
0005434406759	26977	20	6E
0005432153822	26977	21	6F
0005432153821	26977	22	7A
0005434406740	26977	23	7C
0005432153827	26977	24	7D
0005432153824	26977	25	7E
0005434406735	26977	26	8D
0005434406719	26977	27	9A
0005434406734	26977	28	9C
0005434406741	26977	29	9E
0005434406764	26977	30	10A
0005432153820	26977	31	10C
0005434406748	26977	32	10E
0005434406757	26977	33	10F
0005434406723	26977	34	11A
0005434406731	26977	35	11D
0005434406702	26977	36	11E
0005434406728	26977	37	11F
0005434406704	26977	38	12A
0005434406718	26977	39	12C
0005434406742	26977	40	12D
0005434406761	26977	41	12E
0005434406733	26977	42	12F
0005434406711	26977	43	13A
0005434406749	26977	44	13C
0005434406708	26977	45	13D
0005434406724	26977	46	13E
0005434406727	26977	47	13F
0005434406738	26977	48	14A
0005434406739	26977	49	14C
0005434406714	26977	50	14D
0005434406760	26977	51	14F
0005434406712	26977	52	15A
0005434406752	26977	53	15D
0005434406745	26977	54	15E
0005434406730	26977	55	15F
0005434406758	26977	56	16C
0005434406729	26977	57	16E
0005434406705	26977	58	16F
0005434406743	26977	59	17D
0005432153825	26977	60	17E
0005432153823	26977	61	17F
0005434406720	26977	62	18C
0005434406736	26977	63	18D
0005434406746	26977	64	18E
0005434406717	26977	65	19A
0005434406754	26977	66	19D
0005434406762	26977	67	19E
0005434406725	26977	68	19F
0005434406756	26977	69	20D
0005434406710	26977	70	20E
0005434406706	26977	71	20F
0005434319151	5673	1	1D
0005432109658	5673	2	2C
0005434319160	5673	3	2D
0005434319156	5673	4	3A
0005434319162	5673	5	3D
0005434319163	5673	6	4A
0005434319158	5673	7	5D
0005434319152	5673	8	5E
0005432109657	5673	9	6D
0005434319155	5673	10	9C
0005432109659	5673	11	10E
0005434319161	5673	12	12C
0005434311184	5673	13	13A
0005434319157	5673	14	14F
0005434319154	5673	15	15A
0005434319153	5673	16	15C
0005434311183	5673	17	17D
0005434319159	5673	18	19D
0005433123598	15683	1	1C
0005433123606	15683	2	1F
0005433123605	15683	3	3A
0005433123589	15683	4	3C
0005433123602	15683	5	3D
0005433123600	15683	6	4A
0005433123597	15683	7	5E
0005433123608	15683	8	6A
0005433123609	15683	9	9A
0005433123595	15683	10	10D
0005433123601	15683	11	11A
0005433123599	15683	12	11E
0005433123607	15683	13	11F
0005433123596	15683	14	12A
0005433123610	15683	15	13C
0005433123603	15683	16	13E
0005433123594	15683	17	15D
0005433123604	15683	18	15E
0005433123590	15683	19	16A
0005433123588	15683	20	16C
0005433123591	15683	21	17C
0005433123592	15683	22	17E
0005433123593	15683	23	18A
0005434484241	8978	1	2C
0005434484243	8978	2	3B
0005434484238	8978	3	4A
0005434484239	8978	4	4D
0005434484242	8978	5	21A
0005434484240	8978	6	21C
0005434484244	8978	7	23A
0005434189084	16643	1	1A
0005434189083	16643	2	3D
0005434189086	16643	3	5A
0005434189085	16643	4	6B
0005434189081	16643	5	19C
0005434189082	16643	6	23A
0005433123598	7659	1	1C
0005433123606	7659	2	2C
0005433123601	7659	3	4A
0005433123593	7659	4	5E
0005433123610	7659	5	5F
0005433123602	7659	6	6C
0005433123599	7659	7	7A
0005433123604	7659	8	7F
0005433123589	7659	9	8C
0005433123596	7659	10	8E
0005433123590	7659	11	11F
0005433123608	7659	12	12F
0005433123605	7659	13	13D
0005433123603	7659	14	14E
0005433123588	7659	15	15D
0005433123594	7659	16	17C
0005433123607	7659	17	17F
0005433123592	7659	18	18A
0005433123600	7659	19	18D
0005433123591	7659	20	18F
0005433123609	7659	21	19A
0005433123597	7659	22	19C
0005433123595	7659	23	19D
0005432720474	7660	1	1A
0005432692588	7660	2	1C
0005432692575	7660	3	1D
0005432720471	7660	4	1F
0005433449624	7660	5	2A
0005432720478	7660	6	2C
0005433449627	7660	7	2D
0005432720465	7660	8	2F
0005432692565	7660	9	3A
0005432692566	7660	10	3D
0005432692578	7660	11	3F
0005433449607	7660	12	4A
0005432692573	7660	13	4C
0005432692569	7660	14	4D
0005432720463	7660	15	4E
0005432720459	7660	16	4F
0005432720456	7660	17	5A
0005432692581	7660	18	5C
0005432720475	7660	19	5D
0005432692571	7660	20	5E
0005432692576	7660	21	5F
0005432692567	7660	22	6A
0005432720482	7660	23	6C
0005433449618	7660	24	6D
0005432720473	7660	25	6E
0005432720470	7660	26	6F
0005433449612	7660	27	7C
0005432692562	7660	28	7D
0005432720458	7660	29	7E
0005432692572	7660	30	7F
0005432720462	7660	31	8A
0005432071523	7660	32	8C
0005432720457	7660	33	8E
0005432720460	7660	34	8F
0005432692585	7660	35	9A
0005433449609	7660	36	9C
0005432692564	7660	37	9D
0005432720480	7660	38	9E
0005433449611	7660	39	9F
0005433449626	7660	40	10A
0005432692582	7660	41	10C
0005433449608	7660	42	10E
0005432692587	7660	43	10F
0005433449625	7660	44	11A
0005432071525	7660	45	11C
0005432071526	7660	46	11D
0005433449610	7660	47	11E
0005432720466	7660	48	11F
0005432692560	7660	49	12A
0005432692583	7660	50	12C
0005432692563	7660	51	12D
0005432692559	7660	52	12E
0005432720467	7660	53	12F
0005433449614	7660	54	13A
0005433449613	7660	55	13C
0005432692570	7660	56	13D
0005432692586	7660	57	13F
0005432071524	7660	58	14A
0005432692579	7660	59	14C
0005433449615	7660	60	14D
0005433449616	7660	61	14E
0005432692589	7660	62	14F
0005432692580	7660	63	15A
0005433449606	7660	64	15D
0005432720464	7660	65	15E
0005432720481	7660	66	15F
0005432692577	7660	67	16A
0005433449623	7660	68	16D
0005432720461	7660	69	17A
0005432720468	7660	70	17D
0005432692584	7660	71	17E
0005432720479	7660	72	18A
0005432692568	7660	73	18C
0005432720476	7660	74	18D
0005432692574	7660	75	18E
0005432692561	7660	76	18F
0005432720477	7660	77	19A
0005433449622	7660	78	19C
0005433449621	7660	79	19D
0005433449619	7660	80	19F
0005433449620	7660	81	20A
0005432720469	7660	82	20D
0005432720472	7660	83	20E
0005433449617	7660	84	20F
0005433722107	30444	1	2F
0005433722114	30444	2	6D
0005433722117	30444	3	7F
0005433722111	30444	4	8E
0005433722112	30444	5	9C
0005433722108	30444	6	9D
0005433722116	30444	7	11E
0005433722115	30444	8	13E
0005433722109	30444	9	16E
0005433722113	30444	10	18C
0005433722110	30444	11	20A
0005434514925	1393	1	1C
0005434586198	1393	2	1D
0005433524866	1393	3	1F
0005433724731	1393	4	2A
0005434586203	1393	5	3F
0005433524865	1393	6	4A
0005433524863	1393	7	4C
0005434586192	1393	8	4E
0005433524861	1393	9	4F
0005434586194	1393	10	5A
0005434514924	1393	11	5C
0005434586204	1393	12	5D
0005434586189	1393	13	5F
0005434586206	1393	14	6A
0005434586190	1393	15	6C
0005434586186	1393	16	6D
0005434513536	1393	17	6E
0005434586205	1393	18	6F
0005434586195	1393	19	7C
0005434586191	1393	20	7F
0005433524859	1393	21	8A
0005434586184	1393	22	8D
0005433524867	1393	23	9C
0005433524860	1393	24	9E
0005434586187	1393	25	10A
0005433524868	1393	26	10C
0005432270957	1393	27	10E
0005433724729	1393	28	10F
0005434586196	1393	29	11A
0005433524864	1393	30	11C
0005434586185	1393	31	11D
0005434586202	1393	32	12C
0005434586183	1393	33	12D
0005434586207	1393	34	12E
0005434586200	1393	35	12F
0005433724728	1393	36	13A
0005433524857	1393	37	13F
0005433524862	1393	38	14A
0005432270958	1393	39	14C
0005433524856	1393	40	14E
0005433724732	1393	41	14F
0005434586193	1393	42	15C
0005433524869	1393	43	16C
0005434586197	1393	44	16D
0005434586199	1393	45	16F
0005434586201	1393	46	17A
0005434586188	1393	47	18A
0005433524858	1393	48	18F
0005432270959	1393	49	19A
0005433724730	1393	50	19F
0005434586208	1393	51	20A
0005434513537	1393	52	20F
0005433192835	18549	1	1F
0005432968802	18549	2	2A
0005432927889	18549	3	2F
0005433192837	18549	4	3C
0005433192836	18549	5	4E
0005433192825	18549	6	5C
0005433192823	18549	7	5D
0005433192827	18549	8	6F
0005432927886	18549	9	8E
0005433192831	18549	10	9C
0005433192832	18549	11	11A
0005433192822	18549	12	11F
0005433192834	18549	13	12E
0005432968803	18549	14	14A
0005433192830	18549	15	14D
0005432968801	18549	16	15A
0005433192826	18549	17	15E
0005432927885	18549	18	16F
0005433192833	18549	19	18A
0005432927887	18549	20	19C
0005432927888	18549	21	20C
0005433192829	18549	22	20D
0005433192828	18549	23	20E
0005433192824	18549	24	20F
0005434343582	11432	1	1A
0005434142545	11432	2	1B
0005434343592	11432	3	1C
0005434142546	11432	4	1D
0005434343608	11432	5	2B
0005434343597	11432	6	2D
0005434343590	11432	7	3A
0005434343607	11432	8	3B
0005434343603	11432	9	3C
0005434142544	11432	10	3D
0005434343587	11432	11	4A
0005434343611	11432	12	4B
0005434343584	11432	13	4C
0005434343615	11432	14	5A
0005434142547	11432	15	5B
0005434343606	11432	16	5C
0005434343602	11432	17	5D
0005434343599	11432	18	6A
0005434343600	11432	19	6B
0005434343589	11432	20	7A
0005434343596	11432	21	7B
0005434343614	11432	22	7C
0005434343609	11432	23	7D
0005434343585	11432	24	18B
0005434343610	11432	25	18C
0005434343605	11432	26	18D
0005434343616	11432	27	19A
0005434343586	11432	28	19B
0005434343591	11432	29	19C
0005434343595	11432	30	20B
0005434343598	11432	31	20D
0005434343588	11432	32	21A
0005434343593	11432	33	21C
0005434343583	11432	34	21D
0005434343594	11432	35	22A
0005434343613	11432	36	22B
0005434343612	11432	37	22C
0005434343604	11432	38	22D
0005434343601	11432	39	23B
0005435304097	29770	1	4A
0005435304098	29770	2	19C
0005435824187	1252	1	1C
0005435824203	1252	2	2A
0005435824181	1252	3	3D
0005435824192	1252	4	4C
0005435824204	1252	5	5A
0005435824202	1252	6	6A
0005435824199	1252	7	8B
0005435824186	1252	8	8E
0005435824200	1252	9	9F
0005435824196	1252	10	9E
0005432284510	1252	11	10A
0005432284512	1252	12	10C
0005432284511	1252	13	10D
0005435824184	1252	14	10F
0005435824195	1252	15	10E
0005435824193	1252	16	11B
0005435824205	1252	17	11D
0005435824180	1252	18	12C
0005435824191	1252	19	13B
0005435824189	1252	20	13D
0005435824183	1252	21	13F
0005432284509	1252	22	15C
0005435824190	1252	23	16B
0005435824185	1252	24	16E
0005435824194	1252	25	17B
0005435824197	1252	26	17A
0005435824198	1252	27	18F
0005435824201	1252	28	18E
0005435824188	1252	29	19A
0005435824182	1252	30	20B
0005435824179	1252	31	21F
0005433415401	18029	1	2C
0005433415403	18029	2	3A
0005433415394	18029	3	2F
0005433415398	18029	4	5F
0005433415400	18029	5	6A
0005433415404	18029	6	8F
0005433415407	18029	7	11A
0005433415395	18029	8	14B
0005433415408	18029	9	16F
0005433415410	18029	10	16E
0005433415402	18029	11	17A
0005433415406	18029	12	19B
0005433415397	18029	13	19E
0005433415396	18029	14	19D
0005433415399	18029	15	20C
0005433415405	18029	16	21B
0005433415409	18029	17	21E
0005434461608	12579	1	1B
0005434461609	12579	2	6A
0005434460467	12579	3	6B
0005434461610	12579	4	19B
0005434460466	12579	5	22A
0005434460468	12579	6	23B
0005432782922	5636	1	1D
0005432782915	5636	2	1F
0005432782930	5636	3	2C
0005432782912	5636	4	2D
0005432782936	5636	5	2F
0005432143933	5636	6	3A
0005432782940	5636	7	3F
0005432782927	5636	8	4A
0005432782918	5636	9	4C
0005432782941	5636	10	4D
0005432782934	5636	11	4F
0005432782933	5636	12	5A
0005432782928	5636	13	5C
0005432143934	5636	14	5D
0005432782945	5636	15	5F
0005432782946	5636	16	6A
0005432782903	5636	17	6F
0005432782929	5636	18	7C
0005432782947	5636	19	7D
0005432782908	5636	20	7E
0005432782893	5636	21	8A
0005432782907	5636	22	8C
0005432782938	5636	23	8D
0005432782899	5636	24	9C
0005432782932	5636	25	9D
0005432782913	5636	26	9F
0005432782911	5636	27	10A
0005432782904	5636	28	10C
0005432782914	5636	29	10D
0005432782905	5636	30	10E
0005432782923	5636	31	10F
0005432782944	5636	32	11D
0005432782895	5636	33	11E
0005432782916	5636	34	11F
0005432782921	5636	35	12A
0005432782917	5636	36	12D
0005432782937	5636	37	12E
0005432782906	5636	38	13A
0005432782943	5636	39	13D
0005432782910	5636	40	13E
0005432782924	5636	41	14A
0005432782920	5636	42	14E
0005432782919	5636	43	14F
0005432782898	5636	44	15A
0005432782931	5636	45	15C
0005432782909	5636	46	15E
0005432782942	5636	47	15F
0005432782896	5636	48	16A
0005432782900	5636	49	17C
0005432782902	5636	50	17D
0005432782939	5636	51	17F
0005432782901	5636	52	18A
0005432782926	5636	53	18C
0005432782897	5636	54	18D
0005432143935	5636	55	18F
0005432782925	5636	56	19A
0005432782935	5636	57	19F
0005432782894	5636	58	20C
0005432782948	5636	59	20E
0005435242390	15349	1	1A
0005435242391	15349	2	2F
0005435242406	15349	3	3A
0005435242412	15349	4	3D
0005435242403	15349	5	4A
0005435242387	15349	6	4D
0005435242396	15349	7	5A
0005435242409	15349	8	5E
0005435242402	15349	9	6E
0005435242405	15349	10	7A
0005435242393	15349	11	7C
0005435242413	15349	12	7D
0005435242389	15349	13	8A
0005435242415	15349	14	8D
0005435476651	15349	15	9A
0005435242395	15349	16	9D
0005435242388	15349	17	9F
0005435242414	15349	18	10A
0005435242410	15349	19	10C
0005435242401	15349	20	10E
0005435242394	15349	21	12C
0005435242400	15349	22	13A
0005435242408	15349	23	13C
0005435242398	15349	24	13D
0005435476650	15349	25	15E
0005435476649	15349	26	16F
0005435242407	15349	27	18D
0005435242392	15349	28	19C
0005435242411	15349	29	19E
0005435242397	15349	30	19F
0005435242404	15349	31	20A
0005435242399	15349	32	20C
0005432848083	4387	1	1D
0005432848082	4387	2	3B
0005432848075	4387	3	4A
0005432848080	4387	4	4D
0005434463895	4387	5	5B
0005432848084	4387	6	5C
0005432848079	4387	7	5D
0005432848081	4387	8	6B
0005432848078	4387	9	6D
0005432848077	4387	10	7C
0005432848076	4387	11	7D
0005434462755	4387	12	18C
0005432848074	4387	13	19A
0005434462754	4387	14	20B
0005434463894	4387	15	20C
0005432848073	4387	16	20D
0005432848072	4387	17	21C
0005432848071	4387	18	22A
0005434463893	4387	19	23A
0005435850759	28861	1	3A
0005435850760	28861	2	3B
0005435850764	28861	3	3D
0005435850765	28861	4	4A
0005435850762	28861	5	6B
0005435850766	28861	6	18D
0005435850758	28861	7	19B
0005435850763	28861	8	21D
0005435850761	28861	9	22D
0005433496460	6314	1	1A
0005434443452	6314	2	1C
0005434443453	6314	3	1D
0005434925293	6314	4	2A
0005433496452	6314	5	2C
0005433496472	6314	6	2D
0005433496459	6314	7	2F
0005434443448	6314	8	3A
0005433496479	6314	9	3C
0005434443450	6314	10	3D
0005434443441	6314	11	3F
0005432075173	6314	12	4A
0005433496464	6314	13	4E
0005433496473	6314	14	4F
0005434925303	6314	15	5A
0005433496482	6314	16	5C
0005433496469	6314	17	5D
0005434925288	6314	18	5E
0005433496451	6314	19	5F
0005432075175	6314	20	6A
0005434925275	6314	21	6C
0005434443454	6314	22	6D
0005434925287	6314	23	6E
0005434443451	6314	24	6F
0005434925297	6314	25	7A
0005434925300	6314	26	7C
0005434443455	6314	27	7D
0005433496450	6314	28	7E
0005433496456	6314	29	7F
0005434925294	6314	30	8A
0005434443443	6314	31	8C
0005434443446	6314	32	8D
0005434925299	6314	33	8E
0005433496481	6314	34	8F
0005434925305	6314	35	9A
0005434925274	6314	36	9C
0005434443444	6314	37	9D
0005432075174	6314	38	9F
0005434443449	6314	39	10A
0005434925280	6314	40	10C
0005432075172	6314	41	10E
0005434925304	6314	42	10F
0005433496480	6314	43	11A
0005434925273	6314	44	11C
0005433496465	6314	45	11D
0005434925292	6314	46	11E
0005434925282	6314	47	11F
0005433496475	6314	48	12A
0005434925298	6314	49	12D
0005433496477	6314	50	12E
0005433496467	6314	51	12F
0005434925301	6314	52	13A
0005434443447	6314	53	13C
0005434925302	6314	54	13D
0005433496462	6314	55	13E
0005433496454	6314	56	13F
0005433496458	6314	57	14A
0005434925290	6314	58	14C
0005434443440	6314	59	14E
0005433496474	6314	60	14D
0005433496476	6314	61	14F
0005433496471	6314	62	15A
0005434925277	6314	63	15C
0005434925286	6314	64	15D
0005433496463	6314	65	15F
0005433496466	6314	66	16A
0005434925283	6314	67	16C
0005433496455	6314	68	16D
0005433496470	6314	69	16E
0005433496468	6314	70	16F
0005434925284	6314	71	17A
0005434925285	6314	72	17C
0005434925281	6314	73	17D
0005434925278	6314	74	17E
0005433496453	6314	75	17F
0005433496461	6314	76	18C
0005433496478	6314	77	18D
0005433496457	6314	78	18E
0005434925295	6314	79	19A
0005434925291	6314	80	19D
0005434925279	6314	81	19E
0005434443442	6314	82	20A
0005434925296	6314	83	20C
0005434443445	6314	84	20D
0005434925276	6314	85	20E
0005434925289	6314	86	20F
0005435242431	12197	1	1A
0005435242418	12197	2	1D
0005435242430	12197	3	3A
0005435242419	12197	4	4C
0005435242427	12197	5	4F
0005435242429	12197	6	6A
0005435242442	12197	7	6E
0005435242426	12197	8	6F
0005435242424	12197	9	7D
0005435242433	12197	10	8A
0005435242441	12197	11	8C
0005435242416	12197	12	8D
0005435242438	12197	13	10A
0005435242432	12197	14	10C
0005435242436	12197	15	11E
0005435242420	12197	16	12D
0005435242425	12197	17	15D
0005435242423	12197	18	15E
0005435242428	12197	19	15F
0005435242437	12197	20	16C
0005435242439	12197	21	16D
0005435242435	12197	22	17A
0005435242421	12197	23	17C
0005435242417	12197	24	17E
0005435242422	12197	25	18C
0005435242440	12197	26	18D
0005435242434	12197	27	20C
0005432782857	15398	1	1D
0005432782842	15398	2	2A
0005432782890	15398	3	3A
0005432782856	15398	4	3C
0005432782847	15398	5	3D
0005432782855	15398	6	4C
0005432782859	15398	7	4D
0005432782873	15398	8	4F
0005432782880	15398	9	5A
0005432782891	15398	10	5E
0005432782879	15398	11	5F
0005432782850	15398	12	6A
0005432782862	15398	13	6E
0005432782884	15398	14	7A
0005432782846	15398	15	7C
0005432782848	15398	16	7D
0005432782877	15398	17	7E
0005432782887	15398	18	8A
0005432782868	15398	19	8E
0005432782858	15398	20	9C
0005432782875	15398	21	9D
0005432782864	15398	22	9F
0005432782881	15398	23	10A
0005432782882	15398	24	10D
0005432782865	15398	25	11A
0005432782843	15398	26	11C
0005432782866	15398	27	11F
0005432782876	15398	28	12A
0005432782870	15398	29	12D
0005432782885	15398	30	12E
0005432782841	15398	31	13A
0005432782839	15398	32	13E
0005432782883	15398	33	13D
0005432782851	15398	34	14A
0005432782869	15398	35	14C
0005432782888	15398	36	14E
0005432782844	15398	37	15A
0005432782849	15398	38	15C
0005432782860	15398	39	15F
0005432782863	15398	40	16A
0005432782874	15398	41	16C
0005432782840	15398	42	16D
0005432782854	15398	43	17C
0005432782838	15398	44	17E
0005432782872	15398	45	17F
0005432782886	15398	46	18A
0005432782853	15398	47	18C
0005432782852	15398	48	18D
0005432782867	15398	49	18F
0005432782871	15398	50	19A
0005432782845	15398	51	19C
0005432782861	15398	52	19E
0005432782889	15398	53	20A
0005432782892	15398	54	20C
0005432782878	15398	55	20F
0005435913855	10111	1	1F
0005434910071	10111	2	6F
0005435913852	10111	3	9E
0005435913853	10111	4	11A
0005434910072	10111	5	12F
0005435913851	10111	6	15E
0005435913854	10111	7	17E
0005435913856	10111	8	19F
0005435913857	10111	9	20F
0005434876746	14650	1	1A
0005434876668	14650	2	1D
0005434876726	14650	3	2C
0005434876654	14650	4	2A
0005434876652	14650	5	2F
0005434876666	14650	6	2D
0005434876740	14650	7	3A
0005434876742	14650	8	3D
0005434876737	14650	9	3C
0005434876657	14650	10	4A
0005434876743	14650	11	3F
0005434876732	14650	12	4D
0005434876658	14650	13	4C
0005434876679	14650	14	5A
0005434876681	14650	15	4F
0005434876717	14650	16	5D
0005434876725	14650	17	5C
0005434876703	14650	18	5F
0005434876669	14650	19	6A
0005434876684	14650	20	6D
0005434876706	14650	21	6C
0005434876739	14650	22	6B
0005434876691	14650	23	6F
0005434876688	14650	24	6E
0005434876724	14650	25	7A
0005434876672	14650	26	7C
0005434876653	14650	27	7B
0005434876690	14650	28	7E
0005434876727	14650	29	7D
0005434876713	14650	30	7F
0005434876719	14650	31	8B
0005434876707	14650	32	8A
0005434876718	14650	33	8E
0005434876710	14650	34	9B
0005434876695	14650	35	9A
0005434876697	14650	36	9C
0005434876736	14650	37	9F
0005434876685	14650	38	9E
0005434876744	14650	39	9D
0005434876662	14650	40	10B
0005434876696	14650	41	10A
0005434876694	14650	42	10C
0005434876716	14650	43	10D
0005434876711	14650	44	10F
0005434876700	14650	45	11C
0005434876683	14650	46	11B
0005434876665	14650	47	11D
0005434876704	14650	48	11F
0005434876692	14650	49	12B
0005434876670	14650	50	12A
0005434876682	14650	51	12D
0005434876741	14650	52	12C
0005434876733	14650	53	12F
0005434876734	14650	54	12E
0005434876735	14650	55	13C
0005434758855	14650	56	13B
0005434876659	14650	57	13E
0005434876712	14650	58	13D
0005434876676	14650	59	14A
0005434876667	14650	60	13F
0005434876747	14650	61	14B
0005434758856	14650	62	14C
0005434876728	14650	63	14F
0005434876738	14650	64	14E
0005434876745	14650	65	15B
0005434876701	14650	66	15D
0005434876689	14650	67	15C
0005434876680	14650	68	15F
0005434876686	14650	69	15E
0005434876673	14650	70	16A
0005434876729	14650	71	16C
0005434876721	14650	72	16B
0005434876748	14650	73	16D
0005434876663	14650	74	16F
0005434876675	14650	75	16E
0005434876664	14650	76	17C
0005434876715	14650	77	17B
0005434876702	14650	78	17A
0005434876661	14650	79	17D
0005434876687	14650	80	18B
0005434876723	14650	81	18A
0005434876677	14650	82	17F
0005434876693	14650	83	18C
0005434876699	14650	84	18D
0005434876709	14650	85	19A
0005434876720	14650	86	18F
0005434876698	14650	87	19E
0005434876671	14650	88	19D
0005434876722	14650	89	19C
0005434876731	14650	90	19F
0005434876660	14650	91	20B
0005434876674	14650	92	20A
0005434876705	14650	93	20C
0005434876656	14650	94	20F
0005434876730	14650	95	20D
0005434876678	14650	96	21A
0005434876714	14650	97	21C
0005434876708	14650	98	21E
0005434876655	14650	99	21F
0005435659953	9246	1	1A
0005435659954	9246	2	2A
0005435659949	9246	3	4A
0005435659950	9246	4	4D
0005435659959	9246	5	5C
0005435659958	9246	6	5D
0005435659951	9246	7	7A
0005435659955	9246	8	19B
0005435659956	9246	9	19D
0005435659952	9246	10	21C
0005435659957	9246	11	22C
0005434251809	24625	1	1C
0005434251810	24625	2	3D
0005434251808	24625	3	4D
0005434251812	24625	4	5A
0005434251813	24625	5	5C
0005434251811	24625	6	19B
0005434251805	24625	7	20C
0005434251807	24625	8	20D
0005434251806	24625	9	21D
0005434251814	24625	10	23B
0005433679787	2803	1	1C
0005433679788	2803	2	2C
0005433679790	2803	3	3A
0005433679759	2803	4	3C
0005433679772	2803	5	4A
0005433684385	2803	6	4D
0005433679767	2803	7	4E
0005433679758	2803	8	5A
0005433679771	2803	9	5C
0005433679791	2803	10	5E
0005433679769	2803	11	5F
0005433679768	2803	12	6A
0005433679770	2803	13	6C
0005433679793	2803	14	6D
0005433679805	2803	15	6E
0005433679774	2803	16	6F
0005433679799	2803	17	7A
0005433679765	2803	18	7C
0005433679783	2803	19	7D
0005433679761	2803	20	7F
0005433679785	2803	21	8A
0005433679776	2803	22	8C
0005432222695	2803	23	8D
0005433679797	2803	24	8E
0005433679784	2803	25	9D
0005433679779	2803	26	9E
0005433679804	2803	27	9F
0005433679763	2803	28	10C
0005433679789	2803	29	10E
0005433679792	2803	30	11A
0005433679762	2803	31	11C
0005433679778	2803	32	11D
0005433679775	2803	33	11E
0005433679801	2803	34	11F
0005433679780	2803	35	12A
0005433679798	2803	36	12C
0005432222693	2803	37	12D
0005433684384	2803	38	12F
0005433679781	2803	39	12E
0005433679764	2803	40	13C
0005433679806	2803	41	13E
0005433679773	2803	42	14D
0005433679796	2803	43	15A
0005432222694	2803	44	15C
0005433679794	2803	45	15D
0005432222697	2803	46	16A
0005433679757	2803	47	16C
0005433679795	2803	48	16D
0005433679803	2803	49	17A
0005432222696	2803	50	17C
0005433679782	2803	51	17D
0005433679760	2803	52	18A
0005433679802	2803	53	19A
0005433679786	2803	54	19F
0005433679777	2803	55	20D
0005433679766	2803	56	20E
0005433679800	2803	57	20F
0005432966515	29157	1	3D
0005432966513	29157	2	4E
0005432966526	29157	3	5D
0005432966530	29157	4	5E
0005432966512	29157	5	6A
0005432966508	29157	6	6E
0005432005166	29157	7	7A
0005432966507	29157	8	7C
0005432966516	29157	9	7D
0005432966525	29157	10	8D
0005432966514	29157	11	8F
0005432966518	29157	12	9E
0005432966522	29157	13	10D
0005432966505	29157	14	10F
0005432966528	29157	15	11C
0005432005167	29157	16	12A
0005432966520	29157	17	13A
0005432966510	29157	18	13F
0005432966521	29157	19	14A
0005432005168	29157	20	14D
0005432966531	29157	21	14E
0005432966527	29157	22	15C
0005432966511	29157	23	17E
0005432966523	29157	24	18C
0005432966519	29157	25	18E
0005432966529	29157	26	18F
0005432966506	29157	27	19C
0005432966524	29157	28	19E
0005432966509	29157	29	20A
0005432966517	29157	30	20C
0005433613391	9319	1	1C
0005433613431	9319	2	1A
0005433613388	9319	3	1D
0005433613438	9319	4	2A
0005433613440	9319	5	2C
0005433633240	9319	6	2F
0005433613450	9319	7	2D
0005433613422	9319	8	3A
0005433613433	9319	9	3C
0005432756792	9319	10	3D
0005433613460	9319	11	3F
0005433613427	9319	12	4C
0005433613413	9319	13	5A
0005433613447	9319	14	4F
0005433613429	9319	15	5C
0005433613399	9319	16	5D
0005433633217	9319	17	6A
0005433633230	9319	18	6C
0005433613400	9319	19	6F
0005433633214	9319	20	6D
0005433633219	9319	21	7A
0005433613446	9319	22	7C
0005433613432	9319	23	8B
0005433633246	9319	24	8D
0005433613415	9319	25	8C
0005433613416	9319	26	8E
0005433633224	9319	27	9A
0005433613412	9319	28	8F
0005433613390	9319	29	9D
0005433633213	9319	30	9E
0005433613458	9319	31	10A
0005433577583	9319	32	9F
0005432145076	9319	33	10D
0005433577576	9319	34	10C
0005433613402	9319	35	10E
0005433613418	9319	36	10F
0005433613417	9319	37	11B
0005433613452	9319	38	11A
0005433633236	9319	39	11C
0005433613404	9319	40	11D
0005432756790	9319	41	12A
0005433613437	9319	42	11F
0005433577577	9319	43	12C
0005433613421	9319	44	12B
0005433613445	9319	45	12D
0005433633245	9319	46	12E
0005433633218	9319	47	12F
0005433613459	9319	48	13C
0005433613397	9319	49	13B
0005433613407	9319	50	13D
0005433633226	9319	51	13F
0005433613453	9319	52	13E
0005433577574	9319	53	14A
0005433613443	9319	54	14E
0005433613456	9319	55	14D
0005433613425	9319	56	14F
0005433613444	9319	57	15C
0005433613454	9319	58	15B
0005433633241	9319	59	15E
0005433613409	9319	60	15D
0005433613401	9319	61	16A
0005433633235	9319	62	15F
0005433633227	9319	63	16C
0005433613436	9319	64	16B
0005433633225	9319	65	16D
0005433577579	9319	66	16F
0005433613386	9319	67	17C
0005433633232	9319	68	17B
0005433613434	9319	69	17D
0005433613393	9319	70	17F
0005433613441	9319	71	17E
0005433633231	9319	72	18B
0005433613387	9319	73	18D
0005433577580	9319	74	18C
0005433613396	9319	75	18E
0005433633244	9319	76	18F
0005433613395	9319	77	19C
0005433633221	9319	78	19B
0005433633239	9319	79	20A
0005433613403	9319	80	19E
0005433613408	9319	81	20B
0005433633223	9319	82	20C
0005433613392	9319	83	20F
0005433633247	9319	84	21B
0005433613424	9319	85	21D
0005433613414	9319	86	21E
0005433613398	9319	87	21F
0005433633242	9319	88	22B
0005433613423	9319	89	22A
0005433613389	9319	90	22D
0005433633237	9319	91	22C
0005432145077	9319	92	22F
0005433577584	9319	93	22E
0005433633228	9319	94	23B
0005433613448	9319	95	23D
0005433633243	9319	96	24A
0005432755018	9319	97	23F
0005433613420	9319	98	24B
0005433613449	9319	99	24D
0005433577581	9319	100	24C
0005432145075	9319	101	24E
0005433633229	9319	102	24F
0005433613406	9319	103	25B
0005433577586	9319	104	25A
0005433613435	9319	105	25C
0005433633234	9319	106	25D
0005433613419	9319	107	25E
0005432755020	9319	108	25F
0005432756793	9319	109	26B
0005433633220	9319	110	26A
0005433613430	9319	111	26D
0005433633215	9319	112	26C
0005433613442	9319	113	26E
0005433577587	9319	114	26F
0005432755019	9319	115	27A
0005433577578	9319	116	27C
0005433613405	9319	117	27D
0005433613451	9319	118	27E
0005433577582	9319	119	27F
0005433633233	9319	120	28D
0005433577585	9319	121	28F
0005433633222	9319	122	29A
0005433613394	9319	123	29C
0005433633216	9319	124	29B
0005433613439	9319	125	29D
0005433613455	9319	126	29E
0005433613457	9319	127	29F
0005433633238	9319	128	30D
0005433613426	9319	129	30C
0005432756791	9319	130	30E
0005433577575	9319	131	31A
0005433613411	9319	132	31C
0005433613410	9319	133	31D
0005433613428	9319	134	31F
0005434163466	25219	1	3F
0005434163467	25219	2	5C
0005434273047	25219	3	5D
0005434163464	25219	4	9E
0005434163469	25219	5	10D
0005434163463	25219	6	12F
0005434272162	25219	7	13B
0005434163461	25219	8	14B
0005434163458	25219	9	20C
0005434163460	25219	10	22F
0005434163459	25219	11	23E
0005434272161	25219	12	25A
0005434163468	25219	13	26F
0005434163462	25219	14	27D
0005434163465	25219	15	30F
0005434273046	25219	16	31C
0005435986656	4255	1	15A
0005432184903	4255	2	21B
0005432184904	4255	3	31G
0005435986655	4255	4	32A
0005432184905	4255	5	33G
0005435787323	26569	1	1B
0005435787322	26569	2	1G
0005435947021	26569	3	5B
0005435947017	26569	4	5H
0005435947023	26569	5	11F
0005435947024	26569	6	11H
0005432571263	26569	7	14B
0005435947025	26569	8	14A
0005435947019	26569	9	16E
0005435856137	26569	10	17G
0005432571262	26569	11	20E
0005435947020	26569	12	20H
0005435947014	26569	13	21A
0005435947012	26569	14	23A
0005435947022	26569	15	24B
0005435947016	26569	16	28A
0005435947015	26569	17	32D
0005435947013	26569	18	34G
0005432571261	26569	19	35B
0005435856134	26569	20	35E
0005435947018	26569	21	35G
0005435856136	26569	22	37B
0005435856135	26569	23	39E
0005432238837	363	1	1C
0005433568112	363	2	1D
0005433568086	363	3	2A
0005433568103	363	4	2D
0005433568083	363	5	4A
0005433568072	363	6	3F
0005433568120	363	7	4C
0005433568096	363	8	5D
0005433568102	363	9	7A
0005433568113	363	10	7F
0005433568088	363	11	8B
0005433568092	363	12	9C
0005433568093	363	13	9F
0005433568100	363	14	9E
0005433568122	363	15	10A
0005433568111	363	16	10C
0005433568099	363	17	10F
0005433568115	363	18	11C
0005432238839	363	19	11D
0005433568073	363	20	12B
0005433568121	363	21	12D
0005433568089	363	22	12F
0005433568123	363	23	12E
0005433568109	363	24	13C
0005433568107	363	25	13D
0005433568097	363	26	14A
0005433568094	363	27	14E
0005433568104	363	28	14F
0005433568085	363	29	15A
0005433568078	363	30	15D
0005433568076	363	31	15E
0005433568090	363	32	16B
0005433568071	363	33	17A
0005433568108	363	34	17B
0005432238836	363	35	19B
0005433568117	363	36	19E
0005432238834	363	37	20B
0005433568084	363	38	20A
0005433568118	363	39	20D
0005433568077	363	40	21B
0005433568116	363	41	22C
0005433568101	363	42	22E
0005433568091	363	43	23B
0005433568110	363	44	24B
0005432238835	363	45	24D
0005433568082	363	46	24F
0005433568105	363	47	25B
0005432238833	363	48	25C
0005433568098	363	49	25E
0005433568114	363	50	26D
0005433568070	363	51	26C
0005433568080	363	52	26E
0005433568095	363	53	27B
0005433568081	363	54	27D
0005433568087	363	55	27F
0005433568119	363	56	28B
0005433568074	363	57	28E
0005433568079	363	58	29A
0005432238838	363	59	29C
0005433568069	363	60	29D
0005433568106	363	61	30D
0005433568075	363	62	31C
0005433074234	11605	1	1D
0005432947798	11605	2	2A
0005432947802	11605	3	2D
0005432947785	11605	4	4D
0005432947767	11605	5	4C
0005433074242	11605	6	4F
0005433074232	11605	7	5A
0005432947775	11605	8	6A
0005432947766	11605	9	6C
0005433074238	11605	10	6D
0005433074254	11605	11	7A
0005432192268	11605	12	7C
0005433074231	11605	13	8A
0005432947777	11605	14	8B
0005432947770	11605	15	8E
0005432947768	11605	16	9B
0005433074244	11605	17	9A
0005433074246	11605	18	9E
0005433134064	11605	19	10A
0005432192269	11605	20	10B
0005432947797	11605	21	10D
0005432947776	11605	22	10F
0005432947779	11605	23	11A
0005433074252	11605	24	11C
0005433074248	11605	25	11E
0005433131634	11605	26	11F
0005432947793	11605	27	12A
0005432947791	11605	28	12B
0005432947769	11605	29	12D
0005433074236	11605	30	13A
0005432947800	11605	31	13D
0005433074241	11605	32	13F
0005432947784	11605	33	14C
0005433074226	11605	34	14E
0005432947787	11605	35	15C
0005432947786	11605	36	15D
0005432192266	11605	37	15F
0005432947796	11605	38	16B
0005432947764	11605	39	16E
0005432947771	11605	40	17A
0005433074227	11605	41	17C
0005433074233	11605	42	17E
0005432947803	11605	43	18A
0005432192267	11605	44	18C
0005433074247	11605	45	18D
0005432947789	11605	46	18E
0005432947794	11605	47	19B
0005432947780	11605	48	18F
0005433134062	11605	49	19D
0005432947788	11605	50	20C
0005433074240	11605	51	20D
0005433131632	11605	52	20E
0005433074229	11605	53	21B
0005433134063	11605	54	21E
0005433074237	11605	55	22A
0005432947778	11605	56	21F
0005432947799	11605	57	22D
0005432947765	11605	58	22E
0005432947772	11605	59	23A
0005432947795	11605	60	23B
0005433074230	11605	61	23E
0005433074253	11605	62	23F
0005433131631	11605	63	24B
0005433074245	11605	64	24D
0005432947804	11605	65	24C
0005432947783	11605	66	24E
0005433074243	11605	67	25C
0005432947792	11605	68	26A
0005432947782	11605	69	25F
0005433074239	11605	70	26B
0005432947774	11605	71	26D
0005432947790	11605	72	26C
0005433131630	11605	73	26E
0005433134060	11605	74	27C
0005433074250	11605	75	27B
0005433074228	11605	76	27D
0005433074249	11605	77	27F
0005433134061	11605	78	28A
0005432947781	11605	79	28E
0005433074251	11605	80	29B
0005432947801	11605	81	30F
0005433131633	11605	82	31A
0005433074235	11605	83	31B
0005432947773	11605	84	31E
0005433817409	10037	1	4A
0005433817411	10037	2	3B
0005433817408	10037	3	5A
0005433817410	10037	4	6A
0005434732924	13972	1	1B
0005434732922	13972	2	4B
0005434732925	13972	3	5A
0005434732923	13972	4	6B
0005433753307	2370	1	1A
0005435981586	2370	2	1C
0005433753299	2370	3	1F
0005435981560	2370	4	2B
0005435981576	2370	5	2F
0005435981565	2370	6	2C
0005432655339	2370	7	2G
0005435981559	2370	8	3B
0005433753329	2370	9	3C
0005435981567	2370	10	3G
0005433753323	2370	11	3H
0005433753300	2370	12	4C
0005435981561	2370	13	4G
0005433753288	2370	14	4H
0005433753309	2370	15	5B
0005435981558	2370	16	5C
0005435981564	2370	17	5G
0005433753333	2370	18	5F
0005433753331	2370	19	5H
0005432655347	2370	20	9B
0005433766579	2370	21	9A
0005433753281	2370	22	9G
0005433753335	2370	23	11B
0005435981589	2370	24	11F
0005432300169	2370	25	11H
0005432225956	2370	26	12B
0005433753330	2370	27	12A
0005435981571	2370	28	12D
0005432300170	2370	29	12E
0005435981588	2370	30	12F
0005432225954	2370	31	12H
0005433753321	2370	32	12G
0005435981574	2370	33	13B
0005433753308	2370	34	13A
0005433753314	2370	35	13D
0005433753327	2370	36	13G
0005433753294	2370	37	13H
0005433766576	2370	38	14B
0005433753291	2370	39	14D
0005433753310	2370	40	14G
0005433753334	2370	41	15B
0005433753284	2370	42	15D
0005432300168	2370	43	15F
0005433753304	2370	44	15H
0005435981583	2370	45	16A
0005433753326	2370	46	16B
0005435981590	2370	47	17A
0005435981581	2370	48	17D
0005433766578	2370	49	17E
0005433753282	2370	50	17F
0005433764645	2370	51	18A
0005432300167	2370	52	18D
0005435981569	2370	53	18B
0005435981572	2370	54	18E
0005433753320	2370	55	18G
0005433753280	2370	56	19A
0005432655338	2370	57	18H
0005432225958	2370	58	19D
0005435981568	2370	59	19F
0005435981584	2370	60	19G
0005435981552	2370	61	20D
0005432655340	2370	62	20F
0005433753328	2370	63	20H
0005435981551	2370	64	21A
0005433753317	2370	65	21B
0005433764646	2370	66	21E
0005435981573	2370	67	22A
0005433753319	2370	68	22F
0005435981548	2370	69	22E
0005435981577	2370	70	22G
0005433753311	2370	71	23A
0005433753293	2370	72	23B
0005433753295	2370	73	23D
0005432655346	2370	74	23F
0005433766580	2370	75	23H
0005433753298	2370	76	23G
0005432655342	2370	77	24A
0005435981570	2370	78	24B
0005433753302	2370	79	24H
0005432225953	2370	80	25D
0005435981587	2370	81	25F
0005433766577	2370	82	27D
0005433753296	2370	83	27F
0005433753312	2370	84	27E
0005435981592	2370	85	27H
0005435981591	2370	86	28A
0005432300171	2370	87	28D
0005432655344	2370	88	28E
0005435981555	2370	89	28F
0005435981585	2370	90	29A
0005433753332	2370	91	28H
0005435981575	2370	92	29D
0005433753322	2370	93	29B
0005435981553	2370	94	29E
0005433753287	2370	95	29F
0005432655348	2370	96	30B
0005433753289	2370	97	30D
0005435981562	2370	98	30F
0005435981549	2370	99	30H
0005433753283	2370	100	31A
0005433753286	2370	101	31E
0005433753290	2370	102	31G
0005433753279	2370	103	31H
0005433753285	2370	104	32D
0005435981550	2370	105	32G
0005435981566	2370	106	33A
0005433753318	2370	107	33B
0005433753297	2370	108	33F
0005433753306	2370	109	33H
0005433753292	2370	110	34A
0005432655343	2370	111	34D
0005433753324	2370	112	34E
0005435981580	2370	113	34H
0005432225959	2370	114	35A
0005432655345	2370	115	35D
0005435981593	2370	116	35E
0005435981563	2370	117	35G
0005433753316	2370	118	36A
0005435981557	2370	119	36D
0005432655349	2370	120	36E
0005435981556	2370	121	36G
0005432655341	2370	122	37A
0005432225957	2370	123	36H
0005435981554	2370	124	37B
0005433753301	2370	125	37E
0005433753303	2370	126	37D
0005435981579	2370	127	37F
0005432225955	2370	128	38A
0005435981582	2370	129	38B
0005432300166	2370	130	38E
0005433753313	2370	131	38D
0005435981578	2370	132	38H
0005433753325	2370	133	38G
0005433753315	2370	134	39F
0005433753305	2370	135	39E
0005432984559	26174	1	1C
0005433434217	26174	2	1B
0005433434210	26174	3	2C
0005432984541	26174	4	2H
0005433434225	26174	5	2G
0005433434212	26174	6	3F
0005432984550	26174	7	3C
0005432984551	26174	8	4A
0005432869413	26174	9	4G
0005433434211	26174	10	4H
0005433434236	26174	11	5C
0005432984552	26174	12	5G
0005432984540	26174	13	11E
0005433434220	26174	14	11D
0005433434228	26174	15	11F
0005432984536	26174	16	11G
0005433434209	26174	17	12B
0005432869414	26174	18	12E
0005432984555	26174	19	12D
0005434731102	26174	20	12F
0005432984543	26174	21	13G
0005433434218	26174	22	14A
0005433434234	26174	23	14F
0005432984546	26174	24	14G
0005433434226	26174	25	15A
0005432984544	26174	26	15F
0005432984564	26174	27	16B
0005433434221	26174	28	16D
0005433434231	26174	29	16F
0005432869416	26174	30	16H
0005433434213	26174	31	17B
0005432984542	26174	32	17E
0005433434229	26174	33	17H
0005433434232	26174	34	18D
0005432984534	26174	35	19A
0005432984557	26174	36	19E
0005432869415	26174	37	20A
0005432984554	26174	38	20H
0005432984556	26174	39	21A
0005432051078	26174	40	21B
0005433434233	26174	41	22A
0005432049405	26174	42	22D
0005434731101	26174	43	22G
0005434731100	26174	44	22H
0005432984561	26174	45	23G
0005432984545	26174	46	23H
0005432984537	26174	47	24B
0005433434223	26174	48	24D
0005432984535	26174	49	24H
0005432049406	26174	50	28E
0005433434227	26174	51	28D
0005434731103	26174	52	28H
0005433434230	26174	53	28G
0005432984560	26174	54	29B
0005432984549	26174	55	29E
0005432984538	26174	56	30E
0005432049404	26174	57	31A
0005433434222	26174	58	32A
0005433434224	26174	59	32F
0005432984558	26174	60	32H
0005432984566	26174	61	33B
0005433434216	26174	62	33D
0005433434235	26174	63	33H
0005432984553	26174	64	34A
0005433434219	26174	65	34G
0005432984547	26174	66	35A
0005432984562	26174	67	35D
0005432869412	26174	68	35G
0005432984533	26174	69	36B
0005432051077	26174	70	36H
0005432984539	26174	71	36G
0005432984563	26174	72	37A
0005433434214	26174	73	37D
0005432984565	26174	74	37F
0005432049403	26174	75	38B
0005432984548	26174	76	38D
0005433434215	26174	77	38H
0005434373922	1502	1	1A
0005434373934	1502	2	1C
0005432267783	1502	3	1D
0005434373944	1502	4	1F
0005434373928	1502	5	2F
0005434373920	1502	6	3F
0005434373931	1502	7	4D
0005434373900	1502	8	4C
0005434373905	1502	9	4E
0005434373919	1502	10	5A
0005432267787	1502	11	4F
0005434373915	1502	12	5C
0005434373910	1502	13	5E
0005434373914	1502	14	6A
0005434373936	1502	15	6C
0005432267786	1502	16	6D
0005434373902	1502	17	7C
0005432267784	1502	18	7B
0005434373935	1502	19	7E
0005434373940	1502	20	7F
0005434373933	1502	21	9A
0005434373937	1502	22	9C
0005433461553	1502	23	10B
0005434373912	1502	24	11B
0005434373907	1502	25	11F
0005432267789	1502	26	11E
0005434373899	1502	27	12F
0005434373926	1502	28	13A
0005434373908	1502	29	13B
0005434373932	1502	30	13D
0005434373942	1502	31	13C
0005434373941	1502	32	13F
0005434373901	1502	33	14A
0005434373930	1502	34	14D
0005434373925	1502	35	14F
0005434373903	1502	36	14E
0005434373916	1502	37	15A
0005434373939	1502	38	15C
0005434373924	1502	39	16B
0005434373929	1502	40	16F
0005434373906	1502	41	16E
0005433461552	1502	42	17B
0005434373917	1502	43	17A
0005434373911	1502	44	17C
0005434373943	1502	45	17D
0005434373918	1502	46	18A
0005434373927	1502	47	19D
0005434373913	1502	48	20B
0005434373898	1502	49	20C
0005433460400	1502	50	20F
0005434373938	1502	51	21B
0005434373909	1502	52	21C
0005432267785	1502	53	21D
0005434373904	1502	54	22C
0005432267788	1502	55	22D
0005434373923	1502	56	22E
0005434373921	1502	57	22F
0005433460401	1502	58	23F
0005433150840	20115	1	1A
0005433150847	20115	2	1D
0005433150861	20115	3	2A
0005433150850	20115	4	3A
0005434029617	20115	5	3D
0005434029616	20115	6	4A
0005433150833	20115	7	3F
0005433150837	20115	8	4B
0005433150856	20115	9	5D
0005432056235	20115	10	6F
0005433150836	20115	11	6E
0005433150849	20115	12	7C
0005433150842	20115	13	7D
0005433931417	20115	14	8A
0005433931419	20115	15	9D
0005433150843	20115	16	9F
0005433150832	20115	17	10E
0005433150852	20115	18	11E
0005433150853	20115	19	11F
0005433150851	20115	20	12C
0005433150848	20115	21	12D
0005433150829	20115	22	13B
0005433150863	20115	23	13C
0005433150860	20115	24	13F
0005433150831	20115	25	14A
0005432056238	20115	26	14D
0005433764645	20115	27	14E
0005433150845	20115	28	14F
0005433764646	20115	29	15C
0005433931418	20115	30	15E
0005432056236	20115	31	16A
0005433150854	20115	32	16C
0005433150834	20115	33	16E
0005433150839	20115	34	17A
0005433150830	20115	35	16F
0005432056237	20115	36	17B
0005433150846	20115	37	17D
0005433150838	20115	38	18A
0005433150858	20115	39	17F
0005433150841	20115	40	18E
0005433150857	20115	41	19A
0005434029618	20115	42	20A
0005433150859	20115	43	20E
0005433150855	20115	44	21F
0005433150862	20115	45	22B
0005433150828	20115	46	22D
0005433150835	20115	47	22F
0005433150844	20115	48	23A
0005432423653	585	1	1F
0005432423678	585	2	2C
0005432423665	585	3	2F
0005432423662	585	4	3C
0005432423692	585	5	3F
0005432423675	585	6	4C
0005432423686	585	7	4F
0005432423684	585	8	5D
0005432423682	585	9	6A
0005432423691	585	10	6D
0005432423685	585	11	6C
0005432423671	585	12	7C
0005432423661	585	13	8A
0005432423690	585	14	8D
0005432282749	585	15	9F
0005432282752	585	16	11A
0005432423680	585	17	11B
0005432282751	585	18	11D
0005432423683	585	19	11F
0005432423673	585	20	12A
0005432423679	585	21	13D
0005432282750	585	22	13F
0005432282748	585	23	14B
0005432423660	585	24	15A
0005432423676	585	25	15F
0005432423669	585	26	16B
0005432282754	585	27	16E
0005432423658	585	28	17A
0005432282747	585	29	17F
0005432423693	585	30	18D
0005432282753	585	31	18E
0005432423668	585	32	19B
0005432423664	585	33	20B
0005432423681	585	34	20E
0005432423674	585	35	21A
0005432423663	585	36	21B
0005432423688	585	37	21E
0005432423667	585	38	22E
0005432423649	585	39	22F
0005432423657	585	40	23C
0005432423672	585	41	23E
0005432423689	585	42	24B
0005432423659	585	43	24F
0005432423652	585	44	25B
0005432423677	585	45	25C
0005432423687	585	46	26C
0005432423648	585	47	27B
0005432423650	585	48	27D
0005432423654	585	49	27F
0005432423670	585	50	28C
0005432423655	585	51	28B
0005432423656	585	52	28D
0005432423651	585	53	30C
0005432423666	585	54	31D
0005432302267	12907	1	10C
0005432302271	12907	2	19C
0005432302270	12907	3	26F
0005432302268	12907	4	29B
0005432302269	12907	5	30C
0005434022601	487	1	1C
0005434022621	487	2	1B
0005434022611	487	3	1G
0005434022594	487	4	1H
0005434022605	487	5	3B
0005434031946	487	6	3C
0005434022618	487	7	3G
0005434022579	487	8	4C
0005434022613	487	9	4G
0005434022631	487	10	4H
0005434022622	487	11	5G
0005434022625	487	12	9H
0005434022610	487	13	11B
0005434022630	487	14	11E
0005434022602	487	15	11G
0005432235515	487	16	12E
0005434022638	487	17	12F
0005434022629	487	18	13B
0005434022587	487	19	13G
0005432235516	487	20	14A
0005434029615	487	21	14D
0005434022606	487	22	14E
0005432235517	487	23	14H
0005432045579	487	24	15D
0005434022597	487	25	15G
0005434022620	487	26	16D
0005434022578	487	27	16H
0005434022571	487	28	17B
0005434022590	487	29	17G
0005434022582	487	30	18D
0005434022584	487	31	18G
0005434022633	487	32	19B
0005434022577	487	33	20H
0005434022615	487	34	20G
0005434028246	487	35	21G
0005434022627	487	36	21F
0005432235513	487	37	21H
0005434022592	487	38	23A
0005434022637	487	39	22H
0005432235518	487	40	23B
0005434022608	487	41	23D
0005434022583	487	42	23E
0005434022570	487	43	23G
0005434022635	487	44	23H
0005434022616	487	45	24E
0005434022609	487	46	24F
0005434022595	487	47	24G
0005434022624	487	48	25D
0005434022572	487	49	25F
0005434022585	487	50	27A
0005434029614	487	51	27E
0005434022576	487	52	27D
0005434022619	487	53	27F
0005434022628	487	54	27H
0005434022588	487	55	28F
0005434022580	487	56	28H
0005434022607	487	57	28G
0005434022623	487	58	29D
0005432045581	487	59	29B
0005434022636	487	60	29F
0005434022573	487	61	30A
0005434029613	487	62	30G
0005434022589	487	63	31A
0005434022586	487	64	30H
0005434022634	487	65	31B
0005432045580	487	66	31D
0005434022581	487	67	31F
0005434022574	487	68	31G
0005434031947	487	69	32B
0005434022598	487	70	32F
0005434022593	487	71	32G
0005434031944	487	72	33E
0005434028249	487	73	33F
0005434022632	487	74	34B
0005434022612	487	75	34A
0005434022599	487	76	34G
0005434031945	487	77	34F
0005434022603	487	78	35A
0005434028247	487	79	35G
0005434022596	487	80	36A
0005434022575	487	81	36F
0005432235514	487	82	36E
0005434022614	487	83	36H
0005434022600	487	84	38A
0005434022591	487	85	38B
0005434022617	487	86	38E
0005434028248	487	87	38H
0005434022626	487	88	39D
0005434022604	487	89	39F
0005433057209	12658	1	2C
0005433057223	12658	2	3G
0005433057225	12658	3	4A
0005433057237	12658	4	4B
0005433057248	12658	5	5A
0005433057247	12658	6	9B
0005433057238	12658	7	11A
0005433057227	12658	8	11D
0005434735603	12658	9	11B
0005432157459	12658	10	11E
0005433057231	12658	11	11F
0005433057242	12658	12	11H
0005433057224	12658	13	12D
0005433057212	12658	14	12G
0005433057236	12658	15	13B
0005433057217	12658	16	13F
0005433057240	12658	17	13H
0005433057219	12658	18	14B
0005433057211	12658	19	14E
0005433929546	12658	20	15D
0005433684388	12658	21	16B
0005432156293	12658	22	16F
0005433057246	12658	23	17B
0005433057214	12658	24	18A
0005433684387	12658	25	19A
0005433929543	12658	26	19D
0005433057229	12658	27	19G
0005433057213	12658	28	21B
0005433057239	12658	29	21G
0005433057249	12658	30	22E
0005433057226	12658	31	22G
0005433057220	12658	32	22H
0005433057216	12658	33	23B
0005433057232	12658	34	23A
0005434735604	12658	35	23E
0005433057228	12658	36	23G
0005432156292	12658	37	24H
0005432156291	12658	38	24G
0005433057234	12658	39	27G
0005433057222	12658	40	27H
0005433057243	12658	41	28G
0005433057210	12658	42	29A
0005433929545	12658	43	28H
0005433057218	12658	44	29F
0005432156294	12658	45	29G
0005433057244	12658	46	30B
0005434735606	12658	47	31B
0005433057241	12658	48	31D
0005433057215	12658	49	31G
0005433057233	12658	50	32B
0005433057230	12658	51	32D
0005432157460	12658	52	34B
0005433684386	12658	53	35B
0005434735602	12658	54	36B
0005433057221	12658	55	37E
0005433057245	12658	56	37H
0005433929544	12658	57	37G
0005433057235	12658	58	38D
0005434735605	12658	59	39F
0005433921738	2153	1	1A
0005433921753	2153	2	1C
0005433921767	2153	3	1F
0005433921770	2153	4	2A
0005433921771	2153	5	1H
0005433921692	2153	6	2B
0005432044478	2153	7	2H
0005433921776	2153	8	2G
0005433921775	2153	9	3A
0005433921711	2153	10	3B
0005433921742	2153	11	3C
0005433929545	2153	12	3G
0005433921710	2153	13	4A
0005433921705	2153	14	4G
0005433921780	2153	15	5A
0005433921694	2153	16	5B
0005433921724	2153	17	5C
0005433921723	2153	18	9G
0005432044480	2153	19	11A
0005433921726	2153	20	11B
0005433921708	2153	21	11E
0005433921699	2153	22	12A
0005433921766	2153	23	12D
0005433921762	2153	24	12E
0005433921768	2153	25	12F
0005432231392	2153	26	13A
0005433921712	2153	27	13D
0005432231385	2153	28	13G
0005432231390	2153	29	13F
0005433921741	2153	30	13H
0005433921747	2153	31	14F
0005433921758	2153	32	14G
0005433921769	2153	33	14H
0005433921717	2153	34	15B
0005433929546	2153	35	15G
0005433921764	2153	36	16A
0005433921736	2153	37	16E
0005432231394	2153	38	16F
0005433921707	2153	39	17A
0005433921749	2153	40	17E
0005433921713	2153	41	17G
0005433921743	2153	42	17H
0005433921687	2153	43	18A
0005432231389	2153	44	18D
0005433921730	2153	45	18E
0005432231391	2153	46	18G
0005433921688	2153	47	19A
0005433921746	2153	48	18H
0005433921728	2153	49	19F
0005432231395	2153	50	19H
0005433921695	2153	51	19G
0005433921754	2153	52	20E
0005433921716	2153	53	20D
0005433921706	2153	54	20F
0005433921781	2153	55	21A
0005432231396	2153	56	20H
0005433921773	2153	57	21E
0005433921685	2153	58	21F
0005433921757	2153	59	21G
0005433875352	2153	60	22B
0005432044479	2153	61	22E
0005433921709	2153	62	22G
0005433921714	2153	63	22F
0005433921745	2153	64	23A
0005433921691	2153	65	23B
0005433921732	2153	66	23F
0005433921689	2153	67	23G
0005433921719	2153	68	23H
0005433921697	2153	69	24B
0005433921759	2153	70	24E
0005433921761	2153	71	24F
0005433921721	2153	72	25E
0005433921720	2153	73	25D
0005433921750	2153	74	25F
0005433921735	2153	75	27F
0005433921715	2153	76	27H
0005433931417	2153	77	27G
0005433921698	2153	78	28A
0005433921703	2153	79	28B
0005433921777	2153	80	28F
0005433921700	2153	81	28H
0005433921774	2153	82	29B
0005433921772	2153	83	29G
0005433921778	2153	84	29F
0005433921718	2153	85	29H
0005433931418	2153	86	30B
0005433921727	2153	87	30E
0005433921729	2153	88	30D
0005433921740	2153	89	30G
0005433931419	2153	90	31A
0005433921686	2153	91	30H
0005433921690	2153	92	31B
0005433921702	2153	93	31E
0005433921765	2153	94	32A
0005433921782	2153	95	31H
0005433921748	2153	96	32B
0005432231388	2153	97	32E
0005433921737	2153	98	32F
0005433921751	2153	99	32G
0005433921696	2153	100	33A
0005433929543	2153	101	33D
0005433921701	2153	102	34D
0005433921752	2153	103	35A
0005433921733	2153	104	34H
0005433921693	2153	105	35B
0005433921755	2153	106	35F
0005433921734	2153	107	35E
0005433921756	2153	108	35H
0005433921739	2153	109	36A
0005433921725	2153	110	36E
0005433921744	2153	111	36F
0005433921779	2153	112	36H
0005432231393	2153	113	36G
0005432231386	2153	114	37A
0005433921760	2153	115	37F
0005433929544	2153	116	37H
0005433921722	2153	117	37G
0005432231387	2153	118	38A
0005433921731	2153	119	38D
0005433921763	2153	120	38F
0005433921704	2153	121	39F
0005432749750	24129	1	1B
0005433035446	24129	2	1A
0005433035440	24129	3	1C
0005433035444	24129	4	1F
0005433035449	24129	5	2B
0005433035425	24129	6	2F
0005434028252	24129	7	3B
0005433035430	24129	8	3F
0005432207620	24129	9	4A
0005434028251	24129	10	4G
0005433035426	24129	11	4H
0005433035431	24129	12	5B
0005433035445	24129	13	5F
0005433035442	24129	14	9A
0005433035457	24129	15	9G
0005433035415	24129	16	11G
0005432206102	24129	17	12A
0005433035439	24129	18	14E
0005433035419	24129	19	15G
0005433035421	24129	20	16A
0005433035463	24129	21	16G
0005433035452	24129	22	16F
0005433035450	24129	23	16H
0005432207621	24129	24	17A
0005433035437	24129	25	17E
0005434028250	24129	26	18A
0005433035462	24129	27	18D
0005433035422	24129	28	18E
0005433035428	24129	29	18G
0005433035424	24129	30	19E
0005433035448	24129	31	20D
0005433035435	24129	32	20F
0005433035458	24129	33	21B
0005433035427	24129	34	21H
0005433035456	24129	35	22H
0005433035454	24129	36	23B
0005432206100	24129	37	23A
0005432749749	24129	38	23D
0005432206101	24129	39	23E
0005433035412	24129	40	24D
0005433035411	24129	41	24F
0005432207619	24129	42	24E
0005433035461	24129	43	24G
0005433035429	24129	44	24H
0005433035420	24129	45	27E
0005433035416	24129	46	28A
0005433035418	24129	47	28E
0005433035432	24129	48	29D
0005433035433	24129	49	29G
0005433035453	24129	50	29H
0005433035459	24129	51	30B
0005432206098	24129	52	30D
0005434028253	24129	53	31A
0005433035413	24129	54	30H
0005432206097	24129	55	31F
0005433035455	24129	56	31H
0005433035443	24129	57	32E
0005433035438	24129	58	32F
0005433035451	24129	59	32H
0005432206099	24129	60	33F
0005433035436	24129	61	34H
0005433035414	24129	62	35D
0005433035423	24129	63	35E
0005433035447	24129	64	35H
0005433035417	24129	65	36E
0005433035460	24129	66	36H
0005433035441	24129	67	38A
0005433035434	24129	68	39F
0005434723483	288	1	1C
0005435142360	288	2	1G
0005434550314	288	3	1K
0005432277589	288	4	2A
0005434723489	288	5	2G
0005432277585	288	6	3C
0005434723440	288	7	3G
0005434550368	288	8	4A
0005434550335	288	9	3K
0005435142349	288	10	4G
0005434550325	288	11	4H
0005434723537	288	12	5D
0005434735598	288	13	5C
0005434723556	288	14	5H
0005434723504	288	15	5G
0005434723435	288	16	11C
0005434723540	288	17	5K
0005434723441	288	18	11E
0005434550364	288	19	11D
0005434723548	288	20	11F
0005434723502	288	21	11K
0005434550351	288	22	11H
0005434550330	288	23	12A
0005434550316	288	24	12E
0005432277584	288	25	12H
0005434731096	288	26	12G
0005432277591	288	27	12K
0005434723505	288	28	13F
0005434723511	288	29	13E
0005435142358	288	30	13H
0005434723453	288	31	14D
0005434723498	288	32	14C
0005432277582	288	33	15E
0005434723475	288	34	15D
0005434550365	288	35	15H
0005434723536	288	36	15G
0005434723452	288	37	15F
0005432277587	288	38	16D
0005434723543	288	39	16F
0005435142353	288	40	16K
0005432277594	288	41	16G
0005432277592	288	42	17C
0005434723469	288	43	17A
0005434723487	288	44	17E
0005434550354	288	45	17G
0005434550357	288	46	17F
0005434723527	288	47	18A
0005434723507	288	48	17K
0005434735599	288	49	17H
0005434723519	288	50	18C
0005434731098	288	51	18B
0005434550362	288	52	18D
0005434723438	288	53	18F
0005434723459	288	54	18H
0005434550312	288	55	19D
0005434550341	288	56	19F
0005434550336	288	57	19E
0005435142357	288	58	20A
0005434723521	288	59	19K
0005434735601	288	60	19J
0005434723555	288	61	20G
0005434723526	288	62	20F
0005434550337	288	63	20K
0005434723530	288	64	21B
0005434723468	288	65	21D
0005434723456	288	66	21C
0005434550355	288	67	21G
0005435142352	288	68	21F
0005434550349	288	69	21H
0005435142356	288	70	21K
0005434723466	288	71	22B
0005434723494	288	72	22E
0005434723508	288	73	22D
0005434723454	288	74	22G
0005432277583	288	75	22F
0005435142361	288	76	23B
0005434723518	288	77	23A
0005432277595	288	78	23D
0005434723500	288	79	23C
0005434723471	288	80	23F
0005434723478	288	81	23J
0005434723465	288	82	23G
0005434550350	288	83	23K
0005434723464	288	84	25C
0005435142355	288	85	25B
0005434723506	288	86	25F
0005434550360	288	87	25E
0005434302388	288	88	25G
0005434550353	288	89	25K
0005434550317	288	90	26E
0005434550333	288	91	26D
0005434550334	288	92	26F
0005434723541	288	93	26H
0005434550318	288	94	27B
0005434723534	288	95	27A
0005434550363	288	96	26K
0005434723538	288	97	27D
0005434550359	288	98	27H
0005434723503	288	99	27G
0005434723446	288	100	28B
0005434723515	288	101	28C
0005434723514	288	102	28J
0005434302387	288	103	28H
0005434723522	288	104	29A
0005434550323	288	105	29E
0005434723532	288	106	29D
0005434723473	288	107	30A
0005434723474	288	108	30E
0005434723513	288	109	30F
0005434723450	288	110	30J
0005435142351	288	111	31B
0005434723510	288	112	31A
0005434550358	288	113	31D
0005434723444	288	114	31F
0005434723463	288	115	31E
0005434723445	288	116	31H
0005435142350	288	117	31J
0005434723470	288	118	32E
0005434735597	288	119	32D
0005432277593	288	120	32C
0005434723436	288	121	32G
0005434723523	288	122	32F
0005434550345	288	123	33A
0005434723476	288	124	33C
0005434723492	288	125	33F
0005434550332	288	126	33E
0005434723488	288	127	33H
0005435142359	288	128	33K
0005434723525	288	129	34A
0005434723486	288	130	34G
0005434723437	288	131	35A
0005434550339	288	132	35D
0005434550367	288	133	35B
0005432277596	288	134	35F
0005434723451	288	135	35J
0005434550343	288	136	35H
0005434550352	288	137	35G
0005434723449	288	138	36A
0005434550348	288	139	35K
0005434723458	288	140	36C
0005434723533	288	141	36B
0005434723493	288	142	36D
0005434550324	288	143	36G
0005434723439	288	144	36F
0005434723460	288	145	37B
0005434723484	288	146	37A
0005434723529	288	147	37F
0005434723472	288	148	37E
0005434723550	288	149	37H
0005434723481	288	150	38A
0005434302390	288	151	37K
0005434723545	288	152	38C
0005434723447	288	153	39C
0005434723479	288	154	39F
0005434723495	288	155	39E
0005434723448	288	156	39G
0005434550331	288	157	40A
0005434550347	288	158	39K
0005432277586	288	159	40K
0005435142362	288	160	40H
0005434550327	288	161	41A
0005434723553	288	162	41D
0005434723551	288	163	41C
0005434550328	288	164	41G
0005434550356	288	165	41F
0005434723554	288	166	41E
0005434550340	288	167	41H
0005434550346	288	168	42A
0005434723501	288	169	41K
0005434723482	288	170	41J
0005434723485	288	171	42C
0005435142354	288	172	42E
0005434723462	288	173	42D
0005434723546	288	174	42H
0005434723509	288	175	43B
0005434550338	288	176	43A
0005434723467	288	177	42K
0005434723528	288	178	43D
0005434723461	288	179	43C
0005434550322	288	180	43F
0005434723496	288	181	43E
0005434723517	288	182	43G
0005434723544	288	183	43K
0005434723443	288	184	43J
0005434731099	288	185	44B
0005434550366	288	186	44A
0005434302389	288	187	44E
0005434723457	288	188	44C
0005434723434	288	189	44G
0005432277588	288	190	44K
0005434723535	288	191	44J
0005434550321	288	192	45B
0005434723455	288	193	45D
0005434550326	288	194	45C
0005434723520	288	195	45F
0005434723531	288	196	45E
0005434723512	288	197	45G
0005434302386	288	198	45K
0005434735600	288	199	45J
0005434550313	288	200	46C
0005432277590	288	201	46E
0005434723516	288	202	47C
0005434550315	288	203	46K
0005434723524	288	204	47E
0005434723542	288	205	47G
0005434550320	288	206	47F
0005434723547	288	207	48A
0005434723497	288	208	47K
0005434550342	288	209	48C
0005434723442	288	210	48F
0005434723499	288	211	48E
0005434550344	288	212	48D
0005434723549	288	213	49A
0005434550361	288	214	49D
0005434550319	288	215	49C
0005434723552	288	216	49K
0005434550329	288	217	49H
0005434723491	288	218	49G
0005434723480	288	219	50D
0005434723477	288	220	50F
0005434723539	288	221	51D
0005434723490	288	222	51F
0005434731097	288	223	51G
0005433233166	9841	1	2C
0005433233186	9841	2	2H
0005433233195	9841	3	2D
0005433233170	9841	4	2K
0005433233153	9841	5	3D
0005433180691	9841	6	4D
0005433180699	9841	7	5C
0005433233204	9841	8	5A
0005433180697	9841	9	5G
0005433180693	9841	10	5D
0005433289725	9841	11	11D
0005433180696	9841	12	11C
0005433233188	9841	13	11E
0005433289728	9841	14	12F
0005433289730	9841	15	13A
0005433126768	9841	16	15C
0005433233208	9841	17	15D
0005433180679	9841	18	15G
0005433180694	9841	19	15F
0005433233205	9841	20	15K
0005433233206	9841	21	16E
0005432199131	9841	22	16K
0005433233152	9841	23	16G
0005433766578	9841	24	17H
0005433180680	9841	25	18C
0005433233158	9841	26	18B
0005432199136	9841	27	18G
0005433233198	9841	28	18J
0005433289727	9841	29	19A
0005433126770	9841	30	19D
0005433233184	9841	31	19C
0005433129201	9841	32	19E
0005433180688	9841	33	19K
0005432199135	9841	34	19J
0005433180686	9841	35	20C
0005433180689	9841	36	20B
0005433233151	9841	37	20H
0005433233161	9841	38	20G
0005433233150	9841	39	21A
0005433180684	9841	40	20K
0005433766580	9841	41	21G
0005433233187	9841	42	21H
0005433233155	9841	43	22E
0005432199130	9841	44	23B
0005433233154	9841	45	23D
0005433766579	9841	46	23J
0005433233159	9841	47	24D
0005433233197	9841	48	23K
0005433233190	9841	49	24F
0005433233189	9841	50	24E
0005433233173	9841	51	25A
0005433766576	9841	52	24G
0005433233168	9841	53	25C
0005433233196	9841	54	25G
0005433180675	9841	55	26A
0005433180681	9841	56	26K
0005433129198	9841	57	27D
0005433233180	9841	58	28A
0005434031949	9841	59	28E
0005433233147	9841	60	28J
0005434031952	9841	61	28H
0005433233160	9841	62	28K
0005433113498	9841	63	29C
0005433233172	9841	64	29E
0005433233164	9841	65	29H
0005433180678	9841	66	30C
0005433180676	9841	67	30G
0005433180700	9841	68	30J
0005433233177	9841	69	30H
0005433766577	9841	70	31D
0005433233181	9841	71	31H
0005433129200	9841	72	31G
0005433129199	9841	73	32C
0005433233163	9841	74	33F
0005433233194	9841	75	33E
0005433233199	9841	76	33H
0005433126769	9841	77	34E
0005433233185	9841	78	35C
0005433126771	9841	79	35E
0005433233176	9841	80	35G
0005433180690	9841	81	35K
0005433233192	9841	82	36G
0005433180683	9841	83	36F
0005432199133	9841	84	36H
0005433233169	9841	85	37B
0005433233148	9841	86	37A
0005434031951	9841	87	37D
0005433180685	9841	88	37E
0005433180674	9841	89	37J
0005433233156	9841	90	37H
0005433180692	9841	91	39B
0005434031950	9841	92	39A
0005433233157	9841	93	39F
0005433233203	9841	94	40A
0005433233167	9841	95	40C
0005433233165	9841	96	40F
0005433233145	9841	97	40K
0005433233182	9841	98	41D
0005433113497	9841	99	41F
0005433233183	9841	100	41H
0005433113499	9841	101	41G
0005433233201	9841	102	42C
0005433180682	9841	103	42F
0005433233146	9841	104	42K
0005433180695	9841	105	43B
0005433233162	9841	106	44B
0005433180687	9841	107	44E
0005433233171	9841	108	45A
0005432199134	9841	109	44K
0005433233179	9841	110	45J
0005433233175	9841	111	45G
0005433289729	9841	112	46A
0005433233207	9841	113	45K
0005433289726	9841	114	46C
0005433233149	9841	115	46B
0005433233191	9841	116	46G
0005433233200	9841	117	46J
0005433180677	9841	118	48F
0005433233144	9841	119	48D
0005432199132	9841	120	48H
0005433180698	9841	121	49D
0005433233174	9841	122	49F
0005433233178	9841	123	49K
0005433233193	9841	124	49H
0005434031948	9841	125	50H
0005433233202	9841	126	51E
0005434066410	7717	1	1C
0005434066399	7717	2	1A
0005434066426	7717	3	1H
0005432525771	7717	4	1G
0005432525803	7717	5	2A
0005432069413	7717	6	1K
0005434066400	7717	7	2C
0005432525798	7717	8	2G
0005432525854	7717	9	3A
0005434066388	7717	10	2K
0005432525812	7717	11	2H
0005434066417	7717	12	3D
0005434066367	7717	13	3G
0005432069420	7717	14	4G
0005434066371	7717	15	4D
0005434066396	7717	16	4K
0005432525897	7717	17	4H
0005432525855	7717	18	5C
0005432150063	7717	19	5H
0005432525786	7717	20	5G
0005432525810	7717	21	11A
0005432525881	7717	22	5K
0005432525783	7717	23	11D
0005432525789	7717	24	11C
0005432069416	7717	25	11K
0005432525895	7717	26	11H
0005432525840	7717	27	12C
0005432525872	7717	28	12A
0005434066404	7717	29	12G
0005432525831	7717	30	12F
0005434066393	7717	31	12H
0005432525900	7717	32	13D
0005434066439	7717	33	13C
0005432525861	7717	34	13F
0005432525795	7717	35	13K
0005434066395	7717	36	13H
0005434066368	7717	37	14A
0005432069423	7717	38	14D
0005434066435	7717	39	14C
0005432525793	7717	40	14F
0005434066427	7717	41	15C
0005432525860	7717	42	15E
0005432525869	7717	43	15G
0005434066406	7717	44	15F
0005432525805	7717	45	16A
0005432525837	7717	46	15K
0005432525828	7717	47	15H
0005432525856	7717	48	16F
0005432525898	7717	49	16K
0005432525780	7717	50	16H
0005432525850	7717	51	17C
0005432525870	7717	52	17H
0005432525791	7717	53	18B
0005432525838	7717	54	18A
0005432150065	7717	55	18D
0005432525825	7717	56	18C
0005432525883	7717	57	18F
0005432525817	7717	58	18K
0005432525848	7717	59	18J
0005434066416	7717	60	18H
0005432525839	7717	61	19B
0005432525773	7717	62	19A
0005432525847	7717	63	19F
0005432525772	7717	64	19E
0005432525899	7717	65	20A
0005432150066	7717	66	19K
0005434066413	7717	67	19J
0005434066389	7717	68	20B
0005432525901	7717	69	20D
0005434066418	7717	70	20G
0005432069411	7717	71	20F
0005432525887	7717	72	20H
0005432525846	7717	73	21B
0005432525845	7717	74	21A
0005432150070	7717	75	21D
0005434066429	7717	76	21K
0005434066414	7717	77	21J
0005432535751	7717	78	22D
0005434066415	7717	79	22B
0005432069422	7717	80	22F
0005434066422	7717	81	22E
0005432525862	7717	82	22G
0005434066379	7717	83	22K
0005434066377	7717	84	23A
0005432525842	7717	85	23C
0005432150068	7717	86	23J
0005432069418	7717	87	23G
0005432150069	7717	88	23K
0005434066370	7717	89	24F
0005434066405	7717	90	25A
0005432525886	7717	91	24G
0005434066382	7717	92	25D
0005432525826	7717	93	25C
0005432069419	7717	94	25B
0005432525890	7717	95	25E
0005432069409	7717	96	25J
0005432525871	7717	97	26E
0005434066372	7717	98	26F
0005434066385	7717	99	26K
0005432525792	7717	100	26J
0005432525833	7717	101	26H
0005432525822	7717	102	27D
0005432150064	7717	103	27C
0005434066387	7717	104	27B
0005432150067	7717	105	27F
0005434066381	7717	106	27E
0005434066431	7717	107	27H
0005432525866	7717	108	27G
0005432525777	7717	109	28A
0005432525781	7717	110	28C
0005432525818	7717	111	28B
0005432525844	7717	112	28E
0005432525801	7717	113	28G
0005434066420	7717	114	28J
0005432525841	7717	115	29A
0005434066375	7717	116	29D
0005432525823	7717	117	29F
0005434066421	7717	118	29E
0005432525808	7717	119	29G
0005434066408	7717	120	30A
0005432525849	7717	121	29J
0005434066432	7717	122	30C
0005432525873	7717	123	30E
0005432525836	7717	124	30D
0005434066394	7717	125	30G
0005432535750	7717	126	30F
0005432525799	7717	127	30J
0005432428871	7717	128	30K
0005432535753	7717	129	31C
0005432525769	7717	130	31E
0005432525797	7717	131	31J
0005432069421	7717	132	31G
0005432525891	7717	133	31K
0005432525820	7717	134	32C
0005434066380	7717	135	32B
0005434066433	7717	136	32E
0005432525892	7717	137	32G
0005434066398	7717	138	32J
0005432525867	7717	139	32H
0005432525782	7717	140	32K
0005432525851	7717	141	33C
0005434066383	7717	142	33F
0005432525888	7717	143	33E
0005432525882	7717	144	34A
0005432525800	7717	145	33K
0005432525864	7717	146	33J
0005432525821	7717	147	34E
0005434066425	7717	148	34D
0005434066423	7717	149	34C
0005432069415	7717	150	34K
0005434066409	7717	151	35B
0005432525843	7717	152	35A
0005432525809	7717	153	35D
0005434066407	7717	154	35C
0005432525830	7717	155	35F
0005432525877	7717	156	35E
0005432525857	7717	157	35J
0005432525859	7717	158	35H
0005432525868	7717	159	35G
0005432525816	7717	160	36A
0005432533243	7717	161	36C
0005432525879	7717	162	36B
0005432525824	7717	163	36E
0005432525775	7717	164	36H
0005434066386	7717	165	36F
0005434066402	7717	166	36J
0005432428873	7717	167	37B
0005432525896	7717	168	37A
0005432525814	7717	169	36K
0005432537022	7717	170	37F
0005434066430	7717	171	37E
0005434066411	7717	172	37J
0005432069412	7717	173	38K
0005432533245	7717	174	38J
0005432525875	7717	175	39B
0005434066424	7717	176	39A
0005432525834	7717	177	39D
0005432535752	7717	178	39C
0005434066397	7717	179	39E
0005432525788	7717	180	39H
0005434066428	7717	181	39G
0005434066437	7717	182	39K
0005432069417	7717	183	40A
0005432525811	7717	184	40G
0005432535755	7717	185	40F
0005432525819	7717	186	40K
0005434066391	7717	187	40J
0005432525880	7717	188	40H
0005432525853	7717	189	41A
0005432525784	7717	190	41D
0005432525806	7717	191	41B
0005432533246	7717	192	41F
0005432525858	7717	193	41E
0005432525813	7717	194	41J
0005432525893	7717	195	41H
0005432525804	7717	196	42A
0005432525794	7717	197	42C
0005432525852	7717	198	42E
0005432525894	7717	199	42F
0005434066434	7717	200	42J
0005432525774	7717	201	42H
0005432525796	7717	202	43B
0005434066390	7717	203	43C
0005432525790	7717	204	43F
0005434066401	7717	205	43E
0005432069410	7717	206	43G
0005434066384	7717	207	43K
0005434066438	7717	208	44E
0005434066419	7717	209	44G
0005434066392	7717	210	44F
0005432525865	7717	211	44J
0005432525768	7717	212	44H
0005432525815	7717	213	45B
0005432525778	7717	214	45A
0005432525835	7717	215	44K
0005432533244	7717	216	45D
0005432525827	7717	217	45C
0005434066436	7717	218	45E
0005432535754	7717	219	45H
0005432525770	7717	220	45K
0005432525903	7717	221	45J
0005432069414	7717	222	46A
0005432525787	7717	223	46D
0005434066369	7717	224	46G
0005432525878	7717	225	46F
0005434066378	7717	226	46K
0005434066412	7717	227	46J
0005432525876	7717	228	47A
0005432525902	7717	229	47E
0005432525832	7717	230	47D
0005432525863	7717	231	47C
0005432525779	7717	232	47K
0005432428870	7717	233	48C
0005432525807	7717	234	48F
0005432525829	7717	235	48H
0005432525802	7717	236	48K
0005434066376	7717	237	49D
0005434066373	7717	238	49C
0005432525889	7717	239	49G
0005432525785	7717	240	49E
0005434066403	7717	241	49K
0005432525885	7717	242	49H
0005432525776	7717	243	50C
0005432525874	7717	244	50A
0005434066374	7717	245	50F
0005432525884	7717	246	50K
0005432428872	7717	247	51F
0005434343650	5304	1	1H
0005435611802	5304	2	1G
0005434573123	5304	3	1D
0005435611828	5304	4	2A
0005435611825	5304	5	2D
0005435611816	5304	6	2H
0005434343621	5304	7	2G
0005435611788	5304	8	3A
0005435611789	5304	9	3G
0005435611870	5304	10	4C
0005435611813	5304	11	4D
0005435611776	5304	12	5C
0005435611866	5304	13	5H
0005434343645	5304	14	11A
0005434343630	5304	15	11D
0005435611822	5304	16	11F
0005435611841	5304	17	11H
0005435611798	5304	18	11G
0005435611796	5304	19	12C
0005435490173	5304	20	12D
0005434343646	5304	21	12K
0005432132956	5304	22	12H
0005435611799	5304	23	13C
0005434343635	5304	24	13F
0005434343620	5304	25	13H
0005434343643	5304	26	14G
0005435611781	5304	27	15C
0005434343624	5304	28	15E
0005432132965	5304	29	15D
0005435611773	5304	30	15H
0005435611868	5304	31	16A
0005435097056	5304	32	15K
0005435611793	5304	33	16C
0005435611811	5304	34	16G
0005434343634	5304	35	16E
0005435611804	5304	36	16H
0005434343642	5304	37	17C
0005435611824	5304	38	17E
0005435611815	5304	39	17D
0005435097058	5304	40	17G
0005435611854	5304	41	17F
0005435611777	5304	42	18A
0005435611827	5304	43	17K
0005434573119	5304	44	18C
0005435611839	5304	45	18B
0005432132963	5304	46	18E
0005435611838	5304	47	18D
0005435611832	5304	48	18J
0005434343636	5304	49	19B
0005435611830	5304	50	19A
0005435611821	5304	51	19C
0005435097053	5304	52	19G
0005434343617	5304	53	20A
0005435611782	5304	54	19K
0005435611847	5304	55	19J
0005434573129	5304	56	20D
0005434573121	5304	57	20G
0005435491407	5304	58	20F
0005434343625	5304	59	20J
0005435611865	5304	60	20H
0005435611872	5304	61	21A
0005434573127	5304	62	21F
0005435611867	5304	63	21E
0005435097059	5304	64	21J
0005435611790	5304	65	21K
0005434343622	5304	66	22B
0005435611806	5304	67	22H
0005434343619	5304	68	22J
0005435611837	5304	69	23E
0005435611851	5304	70	23G
0005434573126	5304	71	23F
0005432132960	5304	72	23J
0005432132967	5304	73	23K
0005435611842	5304	74	24E
0005435611856	5304	75	24D
0005435611791	5304	76	25F
0005434343641	5304	77	25H
0005434343647	5304	78	26E
0005432132962	5304	79	26D
0005434343648	5304	80	26C
0005434343631	5304	81	26F
0005435097054	5304	82	26J
0005435611819	5304	83	27B
0005434343649	5304	84	27D
0005435611848	5304	85	27F
0005435611852	5304	86	27E
0005435611874	5304	87	27K
0005432132969	5304	88	27J
0005435611810	5304	89	28H
0005435555335	5304	90	29B
0005434343640	5304	91	29A
0005435097057	5304	92	29D
0005435611800	5304	93	29E
0005432047489	5304	94	29K
0005435611801	5304	95	30D
0005435611826	5304	96	30E
0005435611803	5304	97	30H
0005435611820	5304	98	31B
0005435611778	5304	99	31A
0005435611860	5304	100	31C
0005435611864	5304	101	31E
0005435490171	5304	102	31K
0005435611807	5304	103	32A
0005435611859	5304	104	32E
0005435611855	5304	105	32D
0005434573117	5304	106	33A
0005435611875	5304	107	33C
0005435611786	5304	108	33G
0005435611785	5304	109	33E
0005432047491	5304	110	33H
0005435611845	5304	111	33K
0005435611844	5304	112	34E
0005435611871	5304	113	34G
0005432132961	5304	114	34K
0005434573124	5304	115	34H
0005435490170	5304	116	35B
0005435611794	5304	117	35D
0005434343627	5304	118	35C
0005435611833	5304	119	35F
0005435611836	5304	120	35H
0005434343638	5304	121	36A
0005432132966	5304	122	35K
0005435611829	5304	123	36C
0005434573118	5304	124	36B
0005435490172	5304	125	36E
0005435611795	5304	126	36H
0005435611869	5304	127	36G
0005434573128	5304	128	36F
0005434573116	5304	129	36K
0005435611853	5304	130	37E
0005432047490	5304	131	37D
0005435611843	5304	132	37H
0005435611817	5304	133	37G
0005435611835	5304	134	38B
0005435611823	5304	135	39D
0005435611831	5304	136	39C
0005434343628	5304	137	39F
0005435611783	5304	138	39H
0005435611858	5304	139	40B
0005435097055	5304	140	40D
0005435611814	5304	141	40K
0005434343633	5304	142	40J
0005432132957	5304	143	40H
0005434343632	5304	144	41A
0005435611809	5304	145	41D
0005435611846	5304	146	41C
0005435611861	5304	147	41F
0005434343623	5304	148	41E
0005434343618	5304	149	41H
0005435611834	5304	150	41G
0005435611840	5304	151	42C
0005434573125	5304	152	42B
0005435611849	5304	153	42F
0005432132970	5304	154	42H
0005435611787	5304	155	43B
0005435611808	5304	156	42K
0005435555334	5304	157	43D
0005435611779	5304	158	43H
0005435611784	5304	159	43G
0005435611862	5304	160	43K
0005435611792	5304	161	44B
0005434573120	5304	162	44E
0005432132971	5304	163	44J
0005432047488	5304	164	45A
0005435097052	5304	165	45D
0005434343639	5304	166	45C
0005435611775	5304	167	45B
0005432047487	5304	168	45J
0005435611774	5304	169	46B
0005432132964	5304	170	46A
0005435611818	5304	171	46G
0005435490169	5304	172	46F
0005432132959	5304	173	46K
0005432132968	5304	174	46H
0005432132958	5304	175	47E
0005435611797	5304	176	47C
0005434343637	5304	177	47K
0005435611863	5304	178	48C
0005435611857	5304	179	48A
0005434343626	5304	180	48F
0005434343644	5304	181	48D
0005435611805	5304	182	49A
0005434343629	5304	183	49E
0005435491406	5304	184	49H
0005435611873	5304	185	50A
0005435611812	5304	186	50E
0005434573122	5304	187	51D
0005435491405	5304	188	51F
0005435611780	5304	189	51E
0005435611850	5304	190	51G
0005434244499	10928	1	1D
0005435423694	10928	2	1G
0005434244489	10928	3	1K
0005435423669	10928	4	2D
0005432164915	10928	5	3A
0005435319424	10928	6	2K
0005435423704	10928	7	3K
0005434244488	10928	8	3H
0005432164916	10928	9	3G
0005435423681	10928	10	4C
0005435423703	10928	11	4D
0005435423696	10928	12	5C
0005435423675	10928	13	11A
0005435423660	10928	14	11F
0005432164911	10928	15	12A
0005435423690	10928	16	11K
0005435423673	10928	17	12G
0005435423652	10928	18	13D
0005435423648	10928	19	13C
0005435423654	10928	20	13A
0005435423664	10928	21	13E
0005435423715	10928	22	14E
0005435319427	10928	23	15A
0005435423672	10928	24	15D
0005432363363	10928	25	15F
0005435423674	10928	26	15K
0005434244509	10928	27	16K
0005434244512	10928	28	17G
0005433719084	10928	29	18F
0005432164912	10928	30	19D
0005435319429	10928	31	19G
0005434244514	10928	32	19J
0005435319430	10928	33	20B
0005435423708	10928	34	20A
0005435423665	10928	35	20D
0005434244508	10928	36	20H
0005435423714	10928	37	21A
0005435423666	10928	38	21D
0005434244511	10928	39	21C
0005435304092	10928	40	21J
0005435423677	10928	41	22E
0005432164910	10928	42	22D
0005434244494	10928	43	22G
0005432840978	10928	44	22F
0005435423680	10928	45	23A
0005434244513	10928	46	23F
0005434244485	10928	47	23K
0005434244493	10928	48	25F
0005434656523	10928	49	25H
0005435319426	10928	50	25K
0005435423692	10928	51	26C
0005435423668	10928	52	26B
0005435423653	10928	53	26E
0005435423646	10928	54	26F
0005434244498	10928	55	27A
0005435423709	10928	56	26K
0005435423706	10928	57	27D
0005435423701	10928	58	27C
0005432363362	10928	59	27H
0005435319428	10928	60	28B
0005432166847	10928	61	28C
0005433719085	10928	62	28F
0005435423647	10928	63	28H
0005434244484	10928	64	29A
0005434244505	10928	65	29C
0005435423658	10928	66	29F
0005435423693	10928	67	29H
0005435319425	10928	68	29K
0005432166846	10928	69	30B
0005434244491	10928	70	30G
0005432840977	10928	71	30J
0005434244500	10928	72	31B
0005435423655	10928	73	31F
0005434244501	10928	74	31E
0005435423686	10928	75	31H
0005434244492	10928	76	32B
0005435304095	10928	77	32D
0005435423702	10928	78	32G
0005435304093	10928	79	33D
0005434656522	10928	80	33C
0005434244503	10928	81	33G
0005435319423	10928	82	33E
0005432840979	10928	83	33K
0005432363364	10928	84	33J
0005435423656	10928	85	34D
0005435423659	10928	86	34F
0005435423667	10928	87	34K
0005435423679	10928	88	35A
0005435423700	10928	89	35E
0005435423678	10928	90	35G
0005434244490	10928	91	36F
0005435423711	10928	92	36J
0005434244496	10928	93	37D
0005435423684	10928	94	37C
0005435423691	10928	95	37G
0005435423707	10928	96	38K
0005435423712	10928	97	39D
0005432164913	10928	98	39E
0005434244495	10928	99	39H
0005435423663	10928	100	39G
0005434244510	10928	101	40A
0005432166849	10928	102	40B
0005435423650	10928	103	40D
0005434244507	10928	104	40H
0005435423687	10928	105	40J
0005432164914	10928	106	41F
0005434244486	10928	107	41G
0005432164909	10928	108	42A
0005435423689	10928	109	41K
0005435423651	10928	110	42C
0005435304094	10928	111	42H
0005434244487	10928	112	42F
0005434244502	10928	113	43A
0005435423698	10928	114	43H
0005435423695	10928	115	44A
0005435423682	10928	116	43J
0005435423683	10928	117	44C
0005434244504	10928	118	44E
0005435423705	10928	119	44G
0005435423657	10928	120	44J
0005435423710	10928	121	45B
0005435304096	10928	122	45D
0005432166848	10928	123	45E
0005433719086	10928	124	46A
0005435423661	10928	125	46B
0005435319431	10928	126	46C
0005433719087	10928	127	47C
0005434244506	10928	128	47E
0005435304989	10928	129	47D
0005435423649	10928	130	47F
0005435423697	10928	131	47H
0005435423713	10928	132	48D
0005434244497	10928	133	48F
0005435423685	10928	134	48E
0005435423676	10928	135	48H
0005435423662	10928	136	49A
0005435423688	10928	137	49C
0005435423699	10928	138	50D
0005432363361	10928	139	50F
0005435423670	10928	140	50K
0005435423671	10928	141	50H
0005432181354	3229	1	1A
0005433804814	3229	2	1F
0005432181352	3229	3	2A
0005433804809	3229	4	2C
0005433804825	3229	5	3A
0005433633250	3229	6	2F
0005432181345	3229	7	3C
0005433804826	3229	8	3F
0005433804818	3229	9	4C
0005432181362	3229	10	4D
0005433804804	3229	11	4F
0005432181348	3229	12	5D
0005433633248	3229	13	5C
0005433633257	3229	14	6C
0005433506887	3229	15	6D
0005433506882	3229	16	7A
0005433506876	3229	17	7D
0005433506874	3229	18	8A
0005433633260	3229	19	8D
0005432181361	3229	20	9B
0005432181357	3229	21	9A
0005432181341	3229	22	9C
0005433804799	3229	23	9D
0005433633258	3229	24	9E
0005433633253	3229	25	10A
0005433633271	3229	26	10B
0005432181363	3229	27	10C
0005433804820	3229	28	10E
0005433633279	3229	29	10F
0005433804808	3229	30	11B
0005433506883	3229	31	11D
0005433633268	3229	32	11F
0005433804812	3229	33	12A
0005433804803	3229	34	12B
0005433804801	3229	35	12D
0005432181347	3229	36	12F
0005433804824	3229	37	13D
0005433633272	3229	38	14B
0005433633259	3229	39	14A
0005433506890	3229	40	14C
0005433633256	3229	41	14E
0005433633261	3229	42	15A
0005432181350	3229	43	15B
0005433804798	3229	44	15D
0005433804810	3229	45	15E
0005433633265	3229	46	16A
0005433804805	3229	47	16C
0005432181351	3229	48	16D
0005433633264	3229	49	16E
0005433804816	3229	50	16F
0005432181346	3229	51	17B
0005432181360	3229	52	17A
0005433804806	3229	53	17D
0005433633274	3229	54	18A
0005433804800	3229	55	17F
0005433633249	3229	56	18B
0005433633280	3229	57	18C
0005433804811	3229	58	18D
0005433506884	3229	59	18F
0005433804794	3229	60	19D
0005433506875	3229	61	20A
0005433506877	3229	62	19E
0005433633254	3229	63	20C
0005433506881	3229	64	20E
0005433633267	3229	65	20D
0005432181353	3229	66	21A
0005433506878	3229	67	20F
0005433633276	3229	68	21B
0005433506886	3229	69	21E
0005433804827	3229	70	21F
0005433804795	3229	71	22B
0005433804807	3229	72	22A
0005433633282	3229	73	22C
0005433804815	3229	74	22E
0005433633266	3229	75	22D
0005433506888	3229	76	23A
0005433633273	3229	77	23C
0005433633269	3229	78	23D
0005433506885	3229	79	23E
0005433804802	3229	80	23F
0005433633262	3229	81	24B
0005433633277	3229	82	24C
0005433804819	3229	83	24F
0005433506873	3229	84	24E
0005433804822	3229	85	25A
0005433506879	3229	86	25C
0005432181344	3229	87	25D
0005433633251	3229	88	26A
0005433804821	3229	89	26C
0005433804828	3229	90	26E
0005432181356	3229	91	26D
0005433633270	3229	92	26F
0005433804813	3229	93	27A
0005432181359	3229	94	27C
0005432181349	3229	95	27D
0005433804796	3229	96	28A
0005433633281	3229	97	28C
0005433804817	3229	98	28B
0005433506889	3229	99	28D
0005433804823	3229	100	28E
0005432181355	3229	101	28F
0005433633252	3229	102	29F
0005433506880	3229	103	30B
0005433633275	3229	104	30A
0005433804797	3229	105	30D
0005433633255	3229	106	30E
0005432181358	3229	107	31B
0005433633278	3229	108	31A
0005432181342	3229	109	31C
0005433633263	3229	110	31E
0005433506872	3229	111	31D
0005432181343	3229	112	31F
0005432459023	8205	1	1C
0005435884470	8205	2	1D
0005432459038	8205	3	2A
0005432459061	8205	4	1F
0005432459015	8205	5	2D
0005435884452	8205	6	2C
0005432042493	8205	7	2F
0005435884438	8205	8	3A
0005432459012	8205	9	3F
0005435884460	8205	10	4D
0005432459017	8205	11	4F
0005432459051	8205	12	5C
0005432459058	8205	13	5F
0005435884449	8205	14	5D
0005435884480	8205	15	6A
0005435884444	8205	16	6C
0005435884448	8205	17	6F
0005435884429	8205	18	6D
0005432459043	8205	19	7C
0005432459054	8205	20	7F
0005432459035	8205	21	7D
0005435884465	8205	22	8A
0005432459046	8205	23	8B
0005435884454	8205	24	8D
0005435884467	8205	25	8C
0005434312286	8205	26	8F
0005435884469	8205	27	9A
0005435884477	8205	28	9C
0005435884433	8205	29	9D
0005435884446	8205	30	9E
0005432042481	8205	31	10A
0005432459029	8205	32	10B
0005435884443	8205	33	10E
0005432459060	8205	34	10D
0005435884451	8205	35	10F
0005432459014	8205	36	11B
0005432459037	8205	37	11D
0005432042488	8205	38	11F
0005432459059	8205	39	12A
0005432042487	8205	40	12B
0005432459039	8205	41	12C
0005432459022	8205	42	12E
0005435884435	8205	43	12D
0005432459018	8205	44	12F
0005432459041	8205	45	13C
0005435884476	8205	46	13D
0005432459025	8205	47	14A
0005432459036	8205	48	14B
0005435884447	8205	49	14C
0005435884457	8205	50	14E
0005432459024	8205	51	14D
0005432459050	8205	52	15C
0005435884481	8205	53	15B
0005432459055	8205	54	15E
0005432459049	8205	55	15D
0005435884440	8205	56	15F
0005432042482	8205	57	16B
0005432459047	8205	58	16D
0005432459057	8205	59	16C
0005432459062	8205	60	16E
0005435884428	8205	61	16F
0005432042492	8205	62	17B
0005432459053	8205	63	17A
0005432459052	8205	64	17D
0005435884439	8205	65	17E
0005432459056	8205	66	18A
0005432042489	8205	67	17F
0005432459044	8205	68	18B
0005432042490	8205	69	18C
0005432459026	8205	70	19B
0005435884431	8205	71	19D
0005435884459	8205	72	20B
0005435884466	8205	73	20A
0005435884461	8205	74	20C
0005432459019	8205	75	20D
0005435884442	8205	76	20F
0005435884456	8205	77	20E
0005435884437	8205	78	21A
0005435884471	8205	79	21B
0005432459010	8205	80	21D
0005432459013	8205	81	21E
0005432042485	8205	82	21F
0005435884463	8205	83	22B
0005435884468	8205	84	22C
0005432459033	8205	85	22E
0005432459011	8205	86	22F
0005435884478	8205	87	23D
0005432459028	8205	88	23C
0005432042484	8205	89	23F
0005435884430	8205	90	24B
0005435884455	8205	91	24A
0005432459031	8205	92	24D
0005432459034	8205	93	24F
0005432459016	8205	94	25A
0005435884445	8205	95	25C
0005435884475	8205	96	25B
0005435884441	8205	97	25E
0005432459027	8205	98	26A
0005432459030	8205	99	26B
0005432459020	8205	100	26E
0005432459042	8205	101	26D
0005435884436	8205	102	27A
0005435884462	8205	103	26F
0005432042483	8205	104	27C
0005432042491	8205	105	27F
0005432459048	8205	106	27E
0005435884479	8205	107	28A
0005435884458	8205	108	28C
0005432459021	8205	109	28B
0005435884434	8205	110	28D
0005435884427	8205	111	28F
0005432042494	8205	112	29B
0005434312285	8205	113	29A
0005435884464	8205	114	29C
0005435884432	8205	115	29D
0005435884450	8205	116	30A
0005432459045	8205	117	29F
0005432459032	8205	118	30B
0005435884453	8205	119	30C
0005432459040	8205	120	30D
0005435884474	8205	121	30F
0005435884472	8205	122	31B
0005435884473	8205	123	31A
0005432042486	8205	124	31C
0005432382539	4576	1	1A
0005432382531	4576	2	1C
0005432382536	4576	3	1D
0005432382542	4576	4	1F
0005432382524	4576	5	2A
0005433454840	4576	6	2D
0005432382543	4576	7	3A
0005432382535	4576	8	3C
0005432382532	4576	9	3D
0005433722114	4576	10	3F
0005432382546	4576	11	4A
0005432382560	4576	12	4F
0005433722107	4576	13	5D
0005432727729	4576	14	5E
0005433453728	4576	15	5F
0005433453729	4576	16	6A
0005432382558	4576	17	6C
0005433194819	4576	18	6D
0005432382527	4576	19	6E
0005433722115	4576	20	6F
0005432727738	4576	21	7A
0005432382526	4576	22	7E
0005432382523	4576	23	7F
0005432727728	4576	24	8A
0005432382530	4576	25	8D
0005433722108	4576	26	8E
0005432382561	4576	27	8F
0005432727730	4576	28	9C
0005432382547	4576	29	9D
0005433454839	4576	30	9E
0005433722109	4576	31	9F
0005433722110	4576	32	10C
0005432382538	4576	33	10D
0005432727732	4576	34	10E
0005432727734	4576	35	10F
0005432382551	4576	36	11D
0005433194817	4576	37	11E
0005432727735	4576	38	11F
0005432382553	4576	39	12A
0005432382550	4576	40	12C
0005432382540	4576	41	12D
0005432382545	4576	42	12E
0005432382555	4576	43	13C
0005432727739	4576	44	13D
0005432382544	4576	45	13E
0005432382522	4576	46	13F
0005432382552	4576	47	14A
0005432382559	4576	48	14C
0005432382528	4576	49	14D
0005432727736	4576	50	14F
0005432382529	4576	51	15E
0005432382556	4576	52	15F
0005432382534	4576	53	16C
0005432727733	4576	54	16D
0005433722117	4576	55	16E
0005432382554	4576	56	16F
0005432727737	4576	57	17A
0005432382525	4576	58	17C
0005433194818	4576	59	17D
0005432382533	4576	60	17E
0005432727731	4576	61	17F
0005432382557	4576	62	18A
0005433722113	4576	63	18C
0005432382537	4576	64	18D
0005433722116	4576	65	18E
0005432382563	4576	66	18F
0005432382549	4576	67	19A
0005432382541	4576	68	19C
0005432382521	4576	69	19E
0005432382548	4576	70	19F
0005432382562	4576	71	20C
0005433722111	4576	72	20D
0005433722112	4576	73	20E
0005432727740	4576	74	20F
0005435528904	1715	1	1A
0005435528915	1715	2	1C
0005435528917	1715	3	1D
0005435528908	1715	4	1F
0005433516738	1715	5	2C
0005435540664	1715	6	3A
0005435540660	1715	7	3C
0005435540651	1715	8	3D
0005435540646	1715	9	3F
0005435540656	1715	10	4E
0005435528919	1715	11	4F
0005432294449	1715	12	5A
0005432294447	1715	13	5C
0005435528902	1715	14	5D
0005435528912	1715	15	5E
0005435528901	1715	16	6A
0005435528913	1715	17	6C
0005433516736	1715	18	6D
0005435528911	1715	19	7F
0005433516737	1715	20	8A
0005435540665	1715	21	8C
0005433516732	1715	22	8D
0005433516730	1715	23	9A
0005433516739	1715	24	9D
0005435528906	1715	25	9E
0005435540655	1715	26	9F
0005435540648	1715	27	10C
0005435528903	1715	28	10D
0005435540654	1715	29	10E
0005433516733	1715	30	10F
0005435540661	1715	31	11A
0005433516731	1715	32	11C
0005433516735	1715	33	11F
0005435540650	1715	34	12C
0005435540659	1715	35	12E
0005435528907	1715	36	13C
0005435540652	1715	37	13D
0005435528909	1715	38	13E
0005435540662	1715	39	13F
0005435528910	1715	40	14A
0005435528905	1715	41	14D
0005435528921	1715	42	14E
0005435528920	1715	43	14F
0005435540663	1715	44	15C
0005433516734	1715	45	15D
0005435528916	1715	46	16C
0005435528914	1715	47	16D
0005435540657	1715	48	16E
0005432294448	1715	49	16F
0005435528918	1715	50	17A
0005435540644	1715	51	17C
0005435540649	1715	52	17D
0005435540647	1715	53	17F
0005435540666	1715	54	18E
0005435540645	1715	55	19C
0005435540658	1715	56	20E
0005435540653	1715	57	20F
0005432924958	22014	1	4D
0005432924956	22014	2	4F
0005432924959	22014	3	5D
0005432924957	22014	4	13E
0005432924960	22014	5	16F
0005432838514	7371	1	1C
0005432838524	7371	2	1F
0005432838520	7371	3	2A
0005434458458	7371	4	2D
0005432838540	7371	5	2F
0005432840976	7371	6	3A
0005432838535	7371	7	4A
0005432838536	7371	8	4D
0005432838537	7371	9	4E
0005432838529	7371	10	4F
0005432838527	7371	11	5C
0005432838515	7371	12	5D
0005434458471	7371	13	6A
0005432838531	7371	14	6C
0005432073335	7371	15	6D
0005432838542	7371	16	6F
0005432838544	7371	17	7E
0005432073334	7371	18	7F
0005432838541	7371	19	8A
0005432073332	7371	20	8C
0005432838522	7371	21	8D
0005434458454	7371	22	8E
0005434458455	7371	23	8F
0005434458464	7371	24	9C
0005434458465	7371	25	9D
0005432823415	7371	26	9E
0005432838516	7371	27	10A
0005434458470	7371	28	10C
0005434458469	7371	29	10D
0005432838533	7371	30	10E
0005432838543	7371	31	11A
0005432838512	7371	32	11C
0005434458457	7371	33	11D
0005432838521	7371	34	11F
0005432838539	7371	35	12A
0005432838513	7371	36	12E
0005434458467	7371	37	12F
0005432838519	7371	38	13A
0005434458462	7371	39	13C
0005432838538	7371	40	13D
0005432838517	7371	41	14E
0005432838532	7371	42	14F
0005432073333	7371	43	15C
0005434458459	7371	44	15D
0005434458474	7371	45	15E
0005432838528	7371	46	15F
0005434458460	7371	47	16A
0005432838518	7371	48	16D
0005434458456	7371	49	16E
0005432838534	7371	50	16F
0005432838525	7371	51	17A
0005432838530	7371	52	17D
0005434458466	7371	53	17E
0005434458472	7371	54	17F
0005432838523	7371	55	18C
0005434458468	7371	56	18D
0005434458461	7371	57	18E
0005434458473	7371	58	18F
0005434458475	7371	59	19E
0005434458463	7371	60	20E
0005432838526	7371	61	20F
0005434664923	28939	1	1F
0005432000990	28939	2	3F
0005435252398	28939	3	4F
0005435491408	28939	4	5F
0005435252407	28939	5	6D
0005435252417	28939	6	6E
0005435252408	28939	7	6F
0005435252397	28939	8	7E
0005435252406	28939	9	9A
0005435252401	28939	10	9F
0005435252404	28939	11	10F
0005435252405	28939	12	11D
0005435252399	28939	13	12A
0005435252409	28939	14	12C
0005435252403	28939	15	13C
0005435252410	28939	16	14A
0005435252414	28939	17	14C
0005435252400	28939	18	14E
0005435252413	28939	19	14F
0005434664924	28939	20	15A
0005435252402	28939	21	15D
0005435252416	28939	22	16A
0005435252412	28939	23	16F
0005435252411	28939	24	17D
0005435252415	28939	25	17E
0005434664922	28939	26	18C
0005432000989	28939	27	18E
0005435491409	28939	28	19A
0005434664921	28939	29	20E
0005435990506	8796	1	8B
0005435990511	8796	2	10B
0005435990512	8796	3	14C
0005435990510	8796	4	18A
0005435990505	8796	5	18D
0005435990508	8796	6	18E
0005435990504	8796	7	19A
0005435990507	8796	8	20A
0005435990509	8796	9	21B
0005434275929	15753	1	6B
0005434275930	15753	2	7B
0005434275931	15753	3	11E
0005434275937	15753	4	12F
0005434275936	15753	5	13D
0005434275933	15753	6	13F
0005434275932	15753	7	15D
0005434275934	15753	8	19E
0005434275935	15753	9	20F
0005432427109	20619	1	1D
0005432427106	20619	2	6A
0005432427107	20619	3	19C
0005432427108	20619	4	23B
0005433476856	30855	1	3B
0005433476858	30855	2	7C
0005433476857	30855	3	18B
0005433476855	30855	4	19A
0005432359599	6364	1	1D
0005432359591	6364	2	2C
0005432359598	6364	3	2D
0005432359602	6364	4	2F
0005432335838	6364	5	3A
0005432335833	6364	6	3F
0005432363363	6364	7	4C
0005432359559	6364	8	4E
0005432359567	6364	9	4F
0005432359603	6364	10	5C
0005432359586	6364	11	5D
0005432359563	6364	12	6B
0005432359581	6364	13	6C
0005432335835	6364	14	7A
0005432359577	6364	15	6F
0005432359572	6364	16	7C
0005432062141	6364	17	7E
0005432335839	6364	18	7F
0005432335844	6364	19	8B
0005432335842	6364	20	8C
0005432359560	6364	21	8F
0005432359589	6364	22	9C
0005432359585	6364	23	9D
0005432335832	6364	24	10B
0005432359594	6364	25	10C
0005432359574	6364	26	10D
0005432335841	6364	27	10E
0005432359584	6364	28	11D
0005432359605	6364	29	11F
0005432335834	6364	30	12B
0005432335840	6364	31	12E
0005432359592	6364	32	12F
0005432359597	6364	33	13A
0005432359573	6364	34	13C
0005432062143	6364	35	13B
0005432359568	6364	36	13D
0005432359569	6364	37	13E
0005432359564	6364	38	13F
0005432359588	6364	39	14B
0005432359562	6364	40	14A
0005432335837	6364	41	14D
0005432359576	6364	42	15A
0005432359601	6364	43	15C
0005432359587	6364	44	15D
0005432359561	6364	45	15F
0005432359558	6364	46	16B
0005432359595	6364	47	16D
0005432363364	6364	48	16E
0005432359575	6364	49	16F
0005432359570	6364	50	17D
0005432359582	6364	51	17C
0005432359590	6364	52	17E
0005432062142	6364	53	18A
0005432359593	6364	54	17F
0005432363362	6364	55	18B
0005432359596	6364	56	18C
0005432359565	6364	57	19C
0005432359600	6364	58	19B
0005432359566	6364	59	19D
0005432062140	6364	60	20B
0005432359579	6364	61	21A
0005432359556	6364	62	20F
0005432335843	6364	63	21C
0005432359580	6364	64	21D
0005432359604	6364	65	21F
0005432363361	6364	66	22B
0005432359557	6364	67	22A
0005432335836	6364	68	22E
0005432359571	6364	69	23A
0005432359578	6364	70	23E
0005432359583	6364	71	23F
0005435176637	20982	1	1A
0005432052697	20982	2	1C
0005434149533	20982	3	1D
0005435176628	20982	4	2A
0005435176635	20982	5	2C
0005432052695	20982	6	2F
0005435723012	20982	7	3C
0005435176640	20982	8	3A
0005434149541	20982	9	5A
0005435490174	20982	10	5D
0005435176617	20982	11	6C
0005435176619	20982	12	6E
0005435490176	20982	13	7B
0005435176624	20982	14	7C
0005434149532	20982	15	7F
0005435176627	20982	16	8A
0005435176618	20982	17	8D
0005435176636	20982	18	8E
0005435176629	20982	19	8F
0005434149539	20982	20	9A
0005435176641	20982	21	10D
0005434149536	20982	22	10E
0005435176631	20982	23	11B
0005434149542	20982	24	11C
0005435176625	20982	25	12A
0005434149535	20982	26	12E
0005434149537	20982	27	13C
0005435176634	20982	28	14D
0005435176626	20982	29	15B
0005435176630	20982	30	15C
0005435176621	20982	31	15E
0005435490175	20982	32	15D
0005435723011	20982	33	16A
0005435176622	20982	34	15F
0005435176613	20982	35	16C
0005435176623	20982	36	17A
0005434149540	20982	37	17B
0005434149543	20982	38	17F
0005432052696	20982	39	18B
0005434149538	20982	40	18F
0005435176614	20982	41	19B
0005435176633	20982	42	19C
0005435176620	20982	43	19F
0005435176615	20982	44	20B
0005435176632	20982	45	20F
0005435176616	20982	46	21D
0005434149534	20982	47	21E
0005435176638	20982	48	22A
0005435176639	20982	49	22E
0005432052698	20982	50	23F
0005434186150	17693	1	1D
0005434186152	17693	2	3A
0005434186151	17693	3	6B
0005434458458	29125	1	1A
0005434458464	29125	2	1B
0005434458461	29125	3	1C
0005434463892	29125	4	2A
0005434458474	29125	5	2B
0005434458463	29125	6	2C
0005434458454	29125	7	2D
0005434462752	29125	8	3A
0005434458462	29125	9	3B
0005434458475	29125	10	4A
0005434458467	29125	11	4B
0005434458466	29125	12	4C
0005434458456	29125	13	5B
0005434458471	29125	14	6A
0005434458470	29125	15	6B
0005434458465	29125	16	7B
0005434448255	29125	17	7C
0005434458469	29125	18	7D
0005434458455	29125	19	18C
0005434458460	29125	20	18D
0005434458473	29125	21	19A
0005434463891	29125	22	19B
0005434462753	29125	23	19C
0005434458468	29125	24	20A
0005434448253	29125	25	20B
0005434458472	29125	26	20C
0005434448254	29125	27	20D
0005434458457	29125	28	21A
0005434448256	29125	29	21C
0005434458459	29125	30	23A
0005432603673	21411	1	1A
0005432603680	21411	2	1B
0005432603674	21411	3	1C
0005432603667	21411	4	1D
0005432603657	21411	5	2A
0005432603662	21411	6	2B
0005432603660	21411	7	2D
0005432603656	21411	8	3A
0005432603652	21411	9	3B
0005432603644	21411	10	3D
0005432603661	21411	11	4B
0005432603675	21411	12	4C
0005432603664	21411	13	4D
0005432603648	21411	14	5A
0005432603646	21411	15	5B
0005432603645	21411	16	5D
0005432603653	21411	17	6A
0005432603666	21411	18	6C
0005432603659	21411	19	6B
0005432603669	21411	20	6D
0005432603676	21411	21	7A
0005432603651	21411	22	7B
0005432603679	21411	23	7C
0005432603672	21411	24	18B
0005432603677	21411	25	18C
0005432603671	21411	26	18D
0005432603681	21411	27	19A
0005432603643	21411	28	19C
0005432603655	21411	29	20A
0005432603654	21411	30	20B
0005432603663	21411	31	20C
0005432603649	21411	32	20D
0005432603642	21411	33	21A
0005432603650	21411	34	21B
0005432603647	21411	35	21C
0005432603670	21411	36	21D
0005432603668	21411	37	22B
0005432603665	21411	38	22C
0005432603678	21411	39	22D
0005432603658	21411	40	23A
0005434606760	22352	1	1A
0005434606759	22352	2	2B
0005434606762	22352	3	3A
0005434606763	22352	4	3B
0005434606761	22352	5	4A
0005434604838	22352	6	5A
0005434604839	22352	7	6A
0005434604837	22352	8	6B
0005432746912	376	1	2D
0005432746925	376	2	2F
0005432746923	376	3	3A
0005432746943	376	4	3C
0005432746935	376	5	4D
0005432746910	376	6	4F
0005432746921	376	7	6A
0005432753244	376	8	6D
0005432753243	376	9	7A
0005432746924	376	10	7E
0005432219933	376	11	8A
0005435154581	376	12	8D
0005432746940	376	13	8E
0005432219930	376	14	9A
0005432746915	376	15	9D
0005432746922	376	16	9E
0005432746942	376	17	9F
0005432746909	376	18	10A
0005432746908	376	19	10D
0005432746931	376	20	11A
0005432746911	376	21	11C
0005432751468	376	22	11D
0005432746944	376	23	11F
0005432746913	376	24	12A
0005432746929	376	25	12C
0005432746928	376	26	12D
0005432746903	376	27	12F
0005432746916	376	28	13A
0005432746933	376	29	13D
0005432746941	376	30	13E
0005432746927	376	31	13F
0005432751469	376	32	14C
0005432746907	376	33	14D
0005435154580	376	34	14F
0005432746917	376	35	15A
0005432749748	376	36	15C
0005435154582	376	37	15D
0005432746937	376	38	15E
0005432746914	376	39	16A
0005432746930	376	40	16D
0005432746905	376	41	16E
0005432753242	376	42	17A
0005432746920	376	43	17C
0005432746936	376	44	17D
0005432746932	376	45	17E
0005432219932	376	46	18A
0005432746904	376	47	18C
0005432219931	376	48	18D
0005432746934	376	49	19A
0005432746938	376	50	19C
0005432746939	376	51	19D
0005432746926	376	52	19E
0005432746919	376	53	19F
0005432746918	376	54	20D
0005432749747	376	55	20E
0005432746906	376	56	20F
0005432890709	12064	1	1C
0005432890693	12064	2	1D
0005432890706	12064	3	1F
0005432890702	12064	4	2D
0005432890707	12064	5	3F
0005433875354	12064	6	4A
0005432214767	12064	7	4E
0005432214768	12064	8	5C
0005433293146	12064	9	6A
0005432890699	12064	10	7A
0005432890701	12064	11	7E
0005433875353	12064	12	7F
0005433293144	12064	13	8D
0005433293147	12064	14	9C
0005433293143	12064	15	10C
0005432890692	12064	16	10E
0005432890698	12064	17	10F
0005432890703	12064	18	11C
0005433293145	12064	19	12A
0005432890704	12064	20	14A
0005432890708	12064	21	15F
0005432890694	12064	22	16C
0005432890700	12064	23	16F
0005432890697	12064	24	17C
0005433293142	12064	25	18C
0005432890691	12064	26	18D
0005432890695	12064	27	19A
0005432890705	12064	28	19D
0005432890690	12064	29	19F
0005432890696	12064	30	20F
0005433524855	18989	1	1A
0005433531227	18989	2	1B
0005433524854	18989	3	2C
0005433531228	18989	4	3A
0005433533243	18989	5	3C
0005433533240	18989	6	4D
0005433531226	18989	7	5B
0005433524849	18989	8	6A
0005433524853	18989	9	6C
0005433524847	18989	10	6D
0005433533242	18989	11	7A
0005433524846	18989	12	7B
0005433524852	18989	13	18A
0005433531225	18989	14	18C
0005433524850	18989	15	19A
0005433524851	18989	16	19D
0005433524848	18989	17	21B
0005433533241	18989	18	21C
0005432927892	32512	1	2D
0005432927891	32512	2	5B
0005432927894	32512	3	7B
0005432927893	32512	4	18A
0005432927890	32512	5	18C
0005432927895	32512	6	20C
0005432927896	32512	7	23B
0005434821524	5278	1	1D
0005434558146	5278	2	1K
0005434821526	5278	3	1H
0005434821536	5278	4	2G
0005434558143	5278	5	3C
0005434821511	5278	6	4K
0005434821470	5278	7	4H
0005434821447	5278	8	5G
0005432121103	5278	9	11C
0005434821498	5278	10	11K
0005434821478	5278	11	11H
0005435149801	5278	12	11G
0005432121102	5278	13	12A
0005434821519	5278	14	12G
0005434821501	5278	15	12F
0005434821454	5278	16	13A
0005434831070	5278	17	12H
0005434821458	5278	18	13D
0005434821441	5278	19	13C
0005432396178	5278	20	13G
0005434821518	5278	21	14D
0005434821445	5278	22	14C
0005434821527	5278	23	14K
0005434821505	5278	24	14G
0005434821516	5278	25	15C
0005435149806	5278	26	15E
0005435149811	5278	27	15H
0005434821547	5278	28	15G
0005434821538	5278	29	15F
0005434821506	5278	30	16D
0005434821467	5278	31	16C
0005434821532	5278	32	16E
0005434821549	5278	33	17D
0005434821540	5278	34	17H
0005432121107	5278	35	17G
0005432394038	5278	36	17K
0005434821488	5278	37	18C
0005434821533	5278	38	18B
0005434821512	5278	39	18E
0005434821514	5278	40	18D
0005432121101	5278	41	18G
0005434821554	5278	42	18K
0005434821503	5278	43	18H
0005432396177	5278	44	19B
0005434558140	5278	45	19A
0005435149800	5278	46	19C
0005435149805	5278	47	19F
0005434821449	5278	48	20C
0005432394039	5278	49	20G
0005434821555	5278	50	20F
0005434821440	5278	51	20K
0005434821551	5278	52	20J
0005434831067	5278	53	21A
0005434821491	5278	54	21D
0005434558145	5278	55	21C
0005434821492	5278	56	21F
0005434821556	5278	57	21H
0005434821530	5278	58	22A
0005434821565	5278	59	22B
0005434821496	5278	60	22E
0005434821563	5278	61	23B
0005434664920	5278	62	22K
0005434821558	5278	63	23E
0005434821539	5278	64	23D
0005434821463	5278	65	23C
0005434821567	5278	66	23F
0005434821568	5278	67	23J
0005434821515	5278	68	23H
0005434821466	5278	69	23G
0005434821468	5278	70	24F
0005434821490	5278	71	25D
0005432121097	5278	72	25F
0005435149804	5278	73	25E
0005432394036	5278	74	25H
0005434821507	5278	75	25G
0005434821508	5278	76	25J
0005434821500	5278	77	26E
0005434821570	5278	78	26D
0005434821509	5278	79	26K
0005434558141	5278	80	26J
0005434821461	5278	81	27B
0005434821452	5278	82	27A
0005434821480	5278	83	27D
0005434821513	5278	84	27F
0005434558148	5278	85	27J
0005434821531	5278	86	27G
0005434821525	5278	87	28B
0005434821485	5278	88	28E
0005434558144	5278	89	28D
0005435149807	5278	90	28C
0005434821450	5278	91	29E
0005434821469	5278	92	29J
0005434821543	5278	93	30A
0005434821502	5278	94	29K
0005434821517	5278	95	30B
0005434558142	5278	96	30D
0005434821564	5278	97	30G
0005434821444	5278	98	30F
0005434821520	5278	99	31B
0005434821475	5278	100	31D
0005434821484	5278	101	32A
0005432396175	5278	102	32C
0005434821442	5278	103	32E
0005434821541	5278	104	32F
0005434821456	5278	105	32H
0005434821542	5278	106	33B
0005434821521	5278	107	33A
0005434821471	5278	108	33D
0005434821473	5278	109	33C
0005434821497	5278	110	33E
0005432121098	5278	111	33G
0005432121110	5278	112	33K
0005434821557	5278	113	34C
0005434821481	5278	114	34B
0005434821569	5278	115	34G
0005434821464	5278	116	34K
0005434828648	5278	117	35B
0005434821460	5278	118	35A
0005432394037	5278	119	35D
0005434821529	5278	120	35H
0005434821453	5278	121	35G
0005434821495	5278	122	36A
0005435149809	5278	123	35K
0005434821535	5278	124	36C
0005434821476	5278	125	36E
0005434821523	5278	126	36D
0005434821499	5278	127	36G
0005434821493	5278	128	36F
0005434821446	5278	129	36K
0005434821472	5278	130	36J
0005434821482	5278	131	37A
0005434821552	5278	132	37D
0005434831066	5278	133	37F
0005434831069	5278	134	37H
0005432121099	5278	135	37K
0005434821489	5278	136	38K
0005435149812	5278	137	38J
0005434821479	5278	138	39A
0005434828649	5278	139	39D
0005434821544	5278	140	39G
0005435149808	5278	141	40D
0005434821494	5278	142	40J
0005434821443	5278	143	41J
0005434821528	5278	144	41G
0005434821561	5278	145	42C
0005435149799	5278	146	42B
0005435149803	5278	147	42G
0005434821455	5278	148	42F
0005434821546	5278	149	42J
0005434821483	5278	150	42H
0005434821486	5278	151	43B
0005434821477	5278	152	43A
0005434821451	5278	153	42K
0005432121109	5278	154	43D
0005434821548	5278	155	43H
0005434821553	5278	156	43G
0005432121096	5278	157	43J
0005434821566	5278	158	44B
0005432121108	5278	159	44A
0005434821550	5278	160	44E
0005432121100	5278	161	44D
0005434828650	5278	162	44C
0005434821559	5278	163	45A
0005435149802	5278	164	45C
0005434821487	5278	165	45D
0005434821465	5278	166	45G
0005434664919	5278	167	45K
0005434821459	5278	168	46A
0005434821504	5278	169	46D
0005434821510	5278	170	46G
0005435149798	5278	171	46F
0005434821560	5278	172	46K
0005432121106	5278	173	46H
0005432121105	5278	174	47C
0005432121104	5278	175	47G
0005434821474	5278	176	47K
0005434558147	5278	177	47H
0005434821448	5278	178	48D
0005432396176	5278	179	48C
0005434821534	5278	180	48A
0005434831068	5278	181	48F
0005434821562	5278	182	48K
0005434821537	5278	183	49E
0005435149810	5278	184	49H
0005434821457	5278	185	50C
0005434821522	5278	186	50A
0005434821545	5278	187	50F
0005434821462	5278	188	50E
0005434558139	5278	189	50D
0005435372211	9883	1	1C
0005435372202	9883	2	1A
0005435372222	9883	3	1D
0005435372218	9883	4	2C
0005435372213	9883	5	3G
0005432202946	9883	6	4A
0005435372204	9883	7	4K
0005435386463	9883	8	5C
0005435372201	9883	9	5H
0005435386459	9883	10	5G
0005435372197	9883	11	11A
0005435735061	9883	12	5K
0005435372193	9883	13	11D
0005432202942	9883	14	11G
0005435735064	9883	15	13D
0005435735062	9883	16	14E
0005435372166	9883	17	14D
0005432823416	9883	18	14G
0005435179687	9883	19	14F
0005435372210	9883	20	15D
0005435372198	9883	21	15C
0005435372160	9883	22	16A
0005435372187	9883	23	16F
0005435372174	9883	24	16E
0005432823417	9883	25	17A
0005435735060	9883	26	18A
0005435386464	9883	27	18H
0005435372186	9883	28	19C
0005435302122	9883	29	19E
0005435386461	9883	30	20E
0005435372184	9883	31	20H
0005435372165	9883	32	20G
0005435372219	9883	33	21A
0005435386462	9883	34	21E
0005435372215	9883	35	21J
0005435372161	9883	36	22F
0005435372169	9883	37	22K
0005432202948	9883	38	22J
0005432823418	9883	39	23B
0005435372216	9883	40	23D
0005435372212	9883	41	23C
0005435179686	9883	42	25A
0005435372200	9883	43	25C
0005435302119	9883	44	25H
0005435372163	9883	45	25K
0005435299696	9883	46	25J
0005435302123	9883	47	26G
0005435372178	9883	48	27A
0005435386460	9883	49	26K
0005435372179	9883	50	27D
0005435372171	9883	51	27E
0005435299699	9883	52	27H
0005435372203	9883	53	29C
0005435372191	9883	54	29E
0005435372162	9883	55	30B
0005435661884	9883	56	30F
0005435372176	9883	57	30H
0005435372192	9883	58	31A
0005435372205	9883	59	31E
0005435372214	9883	60	31J
0005435372190	9883	61	32C
0005435372221	9883	62	32B
0005435372173	9883	63	32A
0005435386458	9883	64	32F
0005435372164	9883	65	32K
0005435372209	9883	66	33C
0005435661882	9883	67	33F
0005435372195	9883	68	33H
0005435735063	9883	69	33G
0005435372194	9883	70	34F
0005432202947	9883	71	34J
0005435372206	9883	72	35D
0005435372189	9883	73	35C
0005435372181	9883	74	35F
0005435372159	9883	75	35G
0005435372217	9883	76	36A
0005435372223	9883	77	36G
0005435372167	9883	78	36F
0005435372175	9883	79	37F
0005432202941	9883	80	38J
0005432202943	9883	81	38H
0005435372208	9883	82	39C
0005435372207	9883	83	39G
0005435372177	9883	84	39H
0005435372224	9883	85	41A
0005435372183	9883	86	41J
0005435372225	9883	87	42E
0005435372172	9883	88	42D
0005435661883	9883	89	43D
0005435302120	9883	90	43F
0005435372182	9883	91	44A
0005435372185	9883	92	44G
0005435372168	9883	93	45B
0005432202945	9883	94	45F
0005435372180	9883	95	45H
0005435372199	9883	96	45J
0005435372170	9883	97	46F
0005435302121	9883	98	46J
0005435372188	9883	99	47E
0005435372196	9883	100	48E
0005432202944	9883	101	49G
0005435299698	9883	102	49K
0005435299697	9883	103	50F
0005435372220	9883	104	51E
0005435082657	6983	1	1D
0005435790259	6983	2	2B
0005435790257	6983	3	2C
0005435082653	6983	4	4C
0005435082658	6983	5	6A
0005435082652	6983	6	6C
0005435082654	6983	7	7D
0005435790258	6983	8	18C
0005435082656	6983	9	19B
0005435082660	6983	10	19C
0005435082650	6983	11	20B
0005435082661	6983	12	20C
0005435082651	6983	13	21A
0005435082655	6983	14	21C
0005435082659	6983	15	22C
0005434755781	9557	1	1C
0005434755756	9557	2	2C
0005434755771	9557	3	2D
0005434755737	9557	4	3A
0005434755765	9557	5	3D
0005434755759	9557	6	4A
0005434755766	9557	7	4D
0005434755757	9557	8	4F
0005434755746	9557	9	5A
0005434755773	9557	10	5C
0005434755747	9557	11	6D
0005434755774	9557	12	6E
0005434755739	9557	13	7C
0005434755763	9557	14	7E
0005434755743	9557	15	8C
0005434755738	9557	16	9D
0005434755758	9557	17	10C
0005434755772	9557	18	10D
0005434755762	9557	19	11A
0005434755760	9557	20	11C
0005434755776	9557	21	12A
0005434755778	9557	22	12C
0005434755767	9557	23	13C
0005434755764	9557	24	13D
0005434755745	9557	25	13E
0005434755755	9557	26	13F
0005434755742	9557	27	14A
0005434755749	9557	28	14C
0005434755752	9557	29	14D
0005434755780	9557	30	15A
0005434755769	9557	31	15C
0005434755748	9557	32	15D
0005434755761	9557	33	16C
0005434755736	9557	34	16D
0005434755750	9557	35	17C
0005434755754	9557	36	17D
0005434755740	9557	37	17E
0005434755744	9557	38	17F
0005434755777	9557	39	18A
0005434755779	9557	40	18D
0005434755741	9557	41	19A
0005434755753	9557	42	19C
0005434755775	9557	43	19E
0005434755751	9557	44	20A
0005434755768	9557	45	20E
0005434755770	9557	46	20F
0005434213722	28631	1	1A
0005434213723	28631	2	1D
0005434213728	28631	3	1F
0005434213734	28631	4	2F
0005434213731	28631	5	3A
0005434213730	28631	6	3C
0005434213715	28631	7	3D
0005434213699	28631	8	3F
0005434213732	28631	9	4A
0005434213714	28631	10	4C
0005434213743	28631	11	4D
0005434213738	28631	12	4E
0005434213704	28631	13	4F
0005434213720	28631	14	5A
0005434213719	28631	15	6C
0005434213703	28631	16	6D
0005434213739	28631	17	7A
0005434213737	28631	18	7D
0005434213718	28631	19	7E
0005434213706	28631	20	8A
0005434213726	28631	21	8C
0005434213700	28631	22	9C
0005434213712	28631	23	9D
0005434213725	28631	24	9F
0005434213729	28631	25	10C
0005434213740	28631	26	10D
0005434213745	28631	27	10E
0005434213717	28631	28	11C
0005434213711	28631	29	11E
0005434213701	28631	30	12A
0005434213744	28631	31	12C
0005434213710	28631	32	12D
0005434213716	28631	33	12E
0005434213735	28631	34	12F
0005434213705	28631	35	13C
0005434213713	28631	36	13E
0005434213708	28631	37	15C
0005434213724	28631	38	15F
0005434213702	28631	39	16A
0005434213736	28631	40	16D
0005434213742	28631	41	16F
0005434213709	28631	42	17F
0005434213733	28631	43	18A
0005434213721	28631	44	18F
0005434213727	28631	45	19C
0005434213707	28631	46	19F
0005434213741	28631	47	20A
0005434213698	28631	48	20C
0005435100072	10823	1	6A
0005435100074	10823	2	21C
0005435100073	10823	3	22C
0005434760157	31806	1	5A
0005434760156	31806	2	7B
0005434638882	1982	1	1A
0005434638898	1982	2	1C
0005434638880	1982	3	1D
0005434638883	1982	4	2A
0005434638887	1982	5	2B
0005434638891	1982	6	2C
0005434638901	1982	7	2D
0005434638894	1982	8	3B
0005434638896	1982	9	4A
0005434638879	1982	10	4C
0005432290583	1982	11	4D
0005435948307	1982	12	5A
0005434638902	1982	13	5B
0005434638884	1982	14	5C
0005434638895	1982	15	6A
0005434638888	1982	16	6D
0005434638899	1982	17	7A
0005432290584	1982	18	7B
0005434638900	1982	19	7C
0005434638892	1982	20	18C
0005434638885	1982	21	19A
0005434638877	1982	22	19D
0005434638897	1982	23	20A
0005434638889	1982	24	20B
0005434638890	1982	25	20C
0005434638886	1982	26	21D
0005434638876	1982	27	22C
0005434638893	1982	28	22D
0005434638881	1982	29	23A
0005434638878	1982	30	23B
0005433202105	23271	1	1B
0005433202116	23271	2	2A
0005433202113	23271	3	2D
0005433202110	23271	4	3C
0005433202115	23271	5	5D
0005433202111	23271	6	6B
0005433202106	23271	7	6C
0005433202107	23271	8	7B
0005433202108	23271	9	7C
0005433202112	23271	10	7D
0005433202103	23271	11	18A
0005433202104	23271	12	18B
0005433202102	23271	13	19A
0005433202109	23271	14	20C
0005433202114	23271	15	21C
0005434600380	6036	1	1A
0005434600372	6036	2	1C
0005432111229	6036	3	1F
0005434600370	6036	4	2A
0005433533245	6036	5	3D
0005434600368	6036	6	4A
0005434600366	6036	7	4C
0005434600365	6036	8	4E
0005433531231	6036	9	5D
0005434600357	6036	10	5E
0005434600359	6036	11	6E
0005433531230	6036	12	7C
0005434600358	6036	13	8D
0005433533247	6036	14	8C
0005434600381	6036	15	8E
0005434600354	6036	16	9C
0005434600362	6036	17	9A
0005432111230	6036	18	9D
0005434600373	6036	19	9F
0005434600356	6036	20	10E
0005433531232	6036	21	11D
0005434600364	6036	22	11E
0005434600374	6036	23	12D
0005434600379	6036	24	12E
0005434600377	6036	25	13A
0005434600376	6036	26	13D
0005433531229	6036	27	13F
0005433531233	6036	28	14E
0005434600375	6036	29	14F
0005434600371	6036	30	15A
0005434600361	6036	31	15C
0005434600367	6036	32	15D
0005433533244	6036	33	17A
0005433533246	6036	34	17D
0005434600369	6036	35	18C
0005434600355	6036	36	18D
0005434600360	6036	37	18E
0005434600363	6036	38	19D
0005434600378	6036	39	20C
0005432111228	6036	40	20E
0005435326512	18565	1	2A
0005435326516	18565	2	4A
0005435326523	18565	3	5F
0005435326521	18565	4	6D
0005435326514	18565	5	7A
0005435326515	18565	6	9E
0005435326518	18565	7	9F
0005435326519	18565	8	12A
0005435326513	18565	9	12D
0005435326517	18565	10	13A
0005435326522	18565	11	14E
0005435326520	18565	12	18E
0005435326524	18565	13	20F
0005434550311	10599	1	1A
0005434550267	10599	2	1F
0005434550299	10599	3	2C
0005434550310	10599	4	2D
0005434550288	10599	5	2F
0005434550266	10599	6	3A
0005434550305	10599	7	3D
0005434550292	10599	8	4A
0005434550263	10599	9	4C
0005434550289	10599	10	4D
0005434550271	10599	11	4E
0005434550306	10599	12	5C
0005434550279	10599	13	5D
0005434550309	10599	14	5E
0005434550259	10599	15	6D
0005434550297	10599	16	6F
0005434550293	10599	17	7D
0005434550274	10599	18	7E
0005434550277	10599	19	7F
0005434550287	10599	20	8A
0005434550281	10599	21	8D
0005434550276	10599	22	8E
0005434550283	10599	23	9A
0005434550272	10599	24	9C
0005434550260	10599	25	9E
0005434554025	10599	26	9F
0005434550286	10599	27	10A
0005434550257	10599	28	10C
0005434550265	10599	29	10D
0005434550262	10599	30	10F
0005434550303	10599	31	11C
0005434550256	10599	32	11D
0005434550268	10599	33	11E
0005434550269	10599	34	12A
0005434554026	10599	35	12E
0005434550300	10599	36	13A
0005434550296	10599	37	13C
0005434550261	10599	38	13E
0005434554027	10599	39	13F
0005434550308	10599	40	14A
0005434550298	10599	41	14D
0005434550264	10599	42	14E
0005434550291	10599	43	14F
0005434550280	10599	44	15A
0005434550284	10599	45	15C
0005434550285	10599	46	15D
0005434550275	10599	47	15F
0005434550290	10599	48	16C
0005434550301	10599	49	16D
0005434550295	10599	50	16F
0005434550282	10599	51	17A
0005434550294	10599	52	17C
0005434550273	10599	53	18A
0005434550302	10599	54	18D
0005434550270	10599	55	18E
0005434550304	10599	56	19C
0005434550307	10599	57	19E
0005434550278	10599	58	20C
0005434550258	10599	59	20D
0005433180686	27760	1	1F
0005433180693	27760	2	3A
0005433180683	27760	3	3C
0005433180688	27760	4	3F
0005433180679	27760	5	4C
0005433180697	27760	6	4E
0005433180692	27760	7	5E
0005433180678	27760	8	6A
0005433180677	27760	9	7A
0005433180700	27760	10	7C
0005433180675	27760	11	7D
0005433180684	27760	12	7E
0005433180685	27760	13	10D
0005433180691	27760	14	10F
0005433180680	27760	15	11C
0005433180682	27760	16	11E
0005433180699	27760	17	12F
0005433180695	27760	18	13D
0005433180690	27760	19	14C
0005433180687	27760	20	14E
0005433180698	27760	21	15A
0005433180676	27760	22	15C
0005433180674	27760	23	16C
0005433180694	27760	24	18A
0005433180681	27760	25	19A
0005433180689	27760	26	19C
0005433180696	27760	27	20A
0005433459150	6138	1	1A
0005433459151	6138	2	1B
0005433459148	6138	3	4A
0005433459147	6138	4	4B
0005433459149	6138	5	6B
0005435254433	19333	1	2A
0005435254431	19333	2	3B
0005435254432	19333	3	5A
0005435681466	6731	1	1A
0005435681436	6731	2	1D
0005435681433	6731	3	1F
0005435681463	6731	4	2A
0005435681442	6731	5	2C
0005435681438	6731	6	2D
0005435681443	6731	7	3C
0005435681429	6731	8	3F
0005432136085	6731	9	4A
0005435681437	6731	10	4E
0005435681444	6731	11	4F
0005435681446	6731	12	5F
0005435681432	6731	13	6A
0005435681456	6731	14	6C
0005435681454	6731	15	6D
0005435681450	6731	16	6E
0005435630915	6731	17	6F
0005432136089	6731	18	7A
0005435681428	6731	19	7C
0005435681464	6731	20	7D
0005432136087	6731	21	7E
0005435681452	6731	22	8C
0005432136088	6731	23	8D
0005435681445	6731	24	8F
0005435681462	6731	25	9A
0005435681458	6731	26	9C
0005435681431	6731	27	9D
0005435681455	6731	28	10F
0005435681430	6731	29	11E
0005432136086	6731	30	12D
0005435681457	6731	31	12E
0005435681439	6731	32	13C
0005435681440	6731	33	13D
0005435630914	6731	34	13E
0005435661879	6731	35	13F
0005435681460	6731	36	14A
0005435681465	6731	37	14C
0005435661881	6731	38	14E
0005435681447	6731	39	15A
0005435661880	6731	40	15F
0005435681451	6731	41	16C
0005435681453	6731	42	17F
0005435681449	6731	43	18C
0005435681448	6731	44	18F
0005435681459	6731	45	19A
0005435681441	6731	46	19C
0005435681434	6731	47	19D
0005435681435	6731	48	19F
0005435681461	6731	49	20A
0005435630916	6731	50	20C
0005435437587	24572	1	1C
0005435437588	24572	2	2C
0005435437590	24572	3	3C
0005435220284	24572	4	3F
0005432533246	24572	5	4A
0005435437580	24572	6	4C
0005432305708	24572	7	4F
0005435437592	24572	8	5A
0005434828651	24572	9	5D
0005435437595	24572	10	7A
0005435219165	24572	11	7C
0005435437593	24572	12	8C
0005435437586	24572	13	8D
0005432533245	24572	14	8E
0005435437581	24572	15	8F
0005435437582	24572	16	9D
0005434828652	24572	17	12A
0005435437577	24572	18	12D
0005435437575	24572	19	12F
0005432533244	24572	20	13A
0005435437596	24572	21	14A
0005435437583	24572	22	14D
0005435437579	24572	23	14E
0005435437591	24572	24	15D
0005435220283	24572	25	15F
0005435437585	24572	26	16E
0005434828653	24572	27	17A
0005435437589	24572	28	17E
0005435437576	24572	29	18A
0005435437578	24572	30	18E
0005432305707	24572	31	19D
0005435437594	24572	32	19E
0005435437584	24572	33	20D
0005432533243	24572	34	20E
0005435125672	11533	1	1C
0005435125667	11533	2	1D
0005435098522	11533	3	1F
0005435125670	11533	4	2C
0005435125676	11533	5	2D
0005435105926	11533	6	2F
0005435105929	11533	7	3A
0005435105928	11533	8	3C
0005435125685	11533	9	4A
0005435125658	11533	10	4D
0005435125675	11533	11	5A
0005435125686	11533	12	5D
0005435125678	11533	13	5F
0005435125679	11533	14	6F
0005435125662	11533	15	7D
0005435125659	11533	16	8D
0005435125666	11533	17	9C
0005435125665	11533	18	9D
0005435125669	11533	19	9E
0005435125652	11533	20	9F
0005435098521	11533	21	10E
0005435125682	11533	22	11E
0005435125674	11533	23	11F
0005435125687	11533	24	12A
0005435125671	11533	25	12D
0005435125673	11533	26	12E
0005435125657	11533	27	12F
0005435105927	11533	28	13A
0005435125664	11533	29	13C
0005435125684	11533	30	14A
0005435125680	11533	31	14D
0005435125649	11533	32	14E
0005435125648	11533	33	14F
0005435125663	11533	34	15D
0005435125647	11533	35	15E
0005435125681	11533	36	16A
0005435125668	11533	37	16D
0005435125660	11533	38	16E
0005435125655	11533	39	16F
0005435125654	11533	40	17D
0005435125677	11533	41	17E
0005435125688	11533	42	17F
0005435125650	11533	43	18C
0005435125651	11533	44	18E
0005435125683	11533	45	19C
0005435125653	11533	46	19E
0005435125656	11533	47	20A
0005435125661	11533	48	20C
0005435558044	31872	1	4F
0005435558045	31872	2	5A
0005435558043	31872	3	6E
0005435558042	31872	4	7E
0005435558046	31872	5	14F
0005433397267	13533	1	1D
0005433397234	13533	2	1F
0005433397246	13533	3	2C
0005433397245	13533	4	2D
0005433397233	13533	5	2F
0005433397229	13533	6	3D
0005433397253	13533	7	3F
0005433397257	13533	8	4E
0005433397252	13533	9	5C
0005433397270	13533	10	5E
0005433397240	13533	11	6A
0005433397248	13533	12	6D
0005433397269	13533	13	6E
0005433397243	13533	14	7A
0005433397256	13533	15	7E
0005433397239	13533	16	7F
0005433397275	13533	17	8A
0005433397235	13533	18	8D
0005433397232	13533	19	9A
0005433397277	13533	20	9D
0005433397259	13533	21	9E
0005433397272	13533	22	10C
0005433397273	13533	23	10D
0005433397254	13533	24	10E
0005433397274	13533	25	10F
0005433397271	13533	26	11A
0005433397250	13533	27	11E
0005433397258	13533	28	12D
0005433397236	13533	29	12E
0005433397230	13533	30	12F
0005433397263	13533	31	13E
0005433397260	13533	32	14E
0005433397261	13533	33	14F
0005433397251	13533	34	15C
0005433397262	13533	35	15E
0005433397231	13533	36	16D
0005433397276	13533	37	16F
0005433397268	13533	38	17D
0005433397247	13533	39	17E
0005433397241	13533	40	17F
0005433397265	13533	41	18A
0005433397266	13533	42	18C
0005433397238	13533	43	18D
0005433397249	13533	44	19A
0005433397237	13533	45	19C
0005433397244	13533	46	19D
0005433397264	13533	47	19E
0005433397255	13533	48	20E
0005433397242	13533	49	20F
0005435732126	19378	1	1A
0005435732128	19378	2	1C
0005435732127	19378	3	1F
0005432297233	19378	4	5C
0005435732125	19378	5	7A
0005432297234	19378	6	20C
0005435925072	13149	1	1D
0005435925062	13149	2	3A
0005435925070	13149	3	4D
0005435925063	13149	4	7C
0005435925061	13149	5	8D
0005435925073	13149	6	9C
0005435925074	13149	7	10C
0005435925067	13149	8	12D
0005435925076	13149	9	14C
0005435925065	13149	10	15E
0005435925068	13149	11	15F
0005435925075	13149	12	17A
0005435925066	13149	13	17F
0005435925064	13149	14	18F
0005435925077	13149	15	20C
0005435925071	13149	16	20D
0005435925069	13149	17	20E
0005435068201	15478	1	1A
0005435068162	15478	2	1C
0005435068161	15478	3	2C
0005435068181	15478	4	2D
0005435068189	15478	5	2F
0005435068165	15478	6	3D
0005435068203	15478	7	4A
0005435068188	15478	8	4D
0005435068190	15478	9	4E
0005435068171	15478	10	4F
0005435068183	15478	11	5D
0005435068207	15478	12	5F
0005435068186	15478	13	7A
0005435068163	15478	14	7C
0005435068167	15478	15	7D
0005435068166	15478	16	7E
0005435068184	15478	17	8A
0005435068168	15478	18	8D
0005435068208	15478	19	9C
0005435068196	15478	20	9D
0005435068160	15478	21	9F
0005435068200	15478	22	10A
0005435068193	15478	23	10C
0005435068169	15478	24	10E
0005435068209	15478	25	11A
0005435068187	15478	26	11C
0005435068158	15478	27	11D
0005435068180	15478	28	11F
0005435068174	15478	29	12C
0005435068185	15478	30	12E
0005435068204	15478	31	12F
0005435068159	15478	32	13A
0005435068175	15478	33	14A
0005435068176	15478	34	14C
0005435068198	15478	35	14D
0005435068197	15478	36	14E
0005435068178	15478	37	14F
0005435068192	15478	38	15A
0005435068194	15478	39	15C
0005435068199	15478	40	15E
0005435068177	15478	41	15F
0005435068202	15478	42	16A
0005435068191	15478	43	16C
0005435068164	15478	44	16E
0005435068210	15478	45	16F
0005435068206	15478	46	17E
0005435068170	15478	47	18C
0005435068179	15478	48	18D
0005435068172	15478	49	19C
0005435068173	15478	50	19D
0005435068182	15478	51	19F
0005435068195	15478	52	20A
0005435068205	15478	53	20E
0005435808058	23194	1	2A
0005435808049	23194	2	2D
0005435808057	23194	3	4D
0005435808055	23194	4	5C
0005435808051	23194	5	6C
0005435808056	23194	6	7A
0005435808053	23194	7	7B
0005435808054	23194	8	19C
0005435808050	23194	9	20A
0005435808059	23194	10	21B
0005435808052	23194	11	22A
0005434213772	10689	1	1D
0005434213755	10689	2	1F
0005434213767	10689	3	2F
0005434213784	10689	4	3A
0005434213782	10689	5	3C
0005434213793	10689	6	4C
0005434213763	10689	7	4D
0005434213789	10689	8	4F
0005434213781	10689	9	5A
0005434213758	10689	10	5D
0005434213786	10689	11	5F
0005434213757	10689	12	6D
0005434213753	10689	13	6E
0005434213777	10689	14	7A
0005434213787	10689	15	7C
0005434213766	10689	16	7E
0005434213746	10689	17	7F
0005434213774	10689	18	8A
0005434213747	10689	19	8C
0005434213778	10689	20	8D
0005434213783	10689	21	8F
0005434213792	10689	22	9D
0005434213750	10689	23	9E
0005434213760	10689	24	10A
0005434213752	10689	25	10C
0005434213751	10689	26	10D
0005434213749	10689	27	11C
0005434213779	10689	28	11D
0005434213780	10689	29	11E
0005434213768	10689	30	11F
0005434213762	10689	31	12D
0005434213790	10689	32	13D
0005434213754	10689	33	13F
0005434213765	10689	34	14D
0005434213761	10689	35	14E
0005434213791	10689	36	15D
0005434213756	10689	37	16A
0005434213759	10689	38	16C
0005434213771	10689	39	16D
0005434213769	10689	40	17C
0005434213770	10689	41	17D
0005434213764	10689	42	18C
0005434213785	10689	43	18D
0005434213776	10689	44	19A
0005434213788	10689	45	19D
0005434213773	10689	46	20C
0005434213748	10689	47	20D
0005434213775	10689	48	20F
0005434755729	28649	1	1F
0005434755707	28649	2	2A
0005434755731	28649	3	2F
0005434755722	28649	4	3F
0005434755733	28649	5	4A
0005434755732	28649	6	4E
0005434755714	28649	7	4F
0005434755730	28649	8	5A
0005434755726	28649	9	5C
0005434755715	28649	10	5F
0005434755725	28649	11	6A
0005434755728	28649	12	6C
0005434755706	28649	13	8A
0005434755717	28649	14	8C
0005434755703	28649	15	9E
0005434755718	28649	16	10D
0005434755712	28649	17	12C
0005434755727	28649	18	12D
0005434755704	28649	19	13D
0005434755724	28649	20	13E
0005434755719	28649	21	14E
0005434755711	28649	22	14F
0005434755709	28649	23	15E
0005434755710	28649	24	16D
0005434755723	28649	25	16F
0005434755721	28649	26	17E
0005434755705	28649	27	17F
0005434755735	28649	28	18A
0005434755713	28649	29	18C
0005434755720	28649	30	18E
0005434755734	28649	31	18F
0005434755708	28649	32	20C
0005434755716	28649	33	20D
0005435038681	5456	1	1A
0005435006633	5456	2	1C
0005435038715	5456	3	1F
0005435038709	5456	4	1D
0005435038678	5456	5	2A
0005435006629	5456	6	2C
0005435038734	5456	7	2F
0005435038708	5456	8	2D
0005435038721	5456	9	3C
0005432125329	5456	10	3A
0005435038732	5456	11	3D
0005435038718	5456	12	3F
0005435038738	5456	13	4A
0005432125327	5456	14	4D
0005435038704	5456	15	4E
0005435038719	5456	16	4F
0005435038737	5456	17	5A
0005435038703	5456	18	5C
0005435038726	5456	19	5D
0005435038727	5456	20	5F
0005435006630	5456	21	6A
0005435006621	5456	22	6C
0005435006636	5456	23	6D
0005435038682	5456	24	6F
0005435038698	5456	25	7D
0005435038725	5456	26	7E
0005435006625	5456	27	8A
0005435006623	5456	28	7F
0005435038710	5456	29	8B
0005435038731	5456	30	8D
0005435038680	5456	31	8C
0005435038707	5456	32	8F
0005432125328	5456	33	9A
0005435038716	5456	34	9D
0005435006644	5456	35	9C
0005435038705	5456	36	9F
0005432125330	5456	37	9E
0005435038735	5456	38	10B
0005435038728	5456	39	10E
0005435038676	5456	40	10D
0005435038679	5456	41	11A
0005435038730	5456	42	11C
0005432125331	5456	43	11B
0005435006622	5456	44	11D
0005435006634	5456	45	11F
0005435038687	5456	46	11E
0005435038696	5456	47	12B
0005435038702	5456	48	12A
0005435038684	5456	49	12D
0005435038724	5456	50	12E
0005435038713	5456	51	12F
0005435006628	5456	52	13C
0005435038699	5456	53	13E
0005435006643	5456	54	13F
0005435038688	5456	55	14C
0005435038686	5456	56	14B
0005435006626	5456	57	14D
0005435038711	5456	58	14E
0005435038685	5456	59	15A
0005435006645	5456	60	14F
0005435006641	5456	61	15B
0005435038693	5456	62	15C
0005435006640	5456	63	15D
0005435006642	5456	64	15E
0005435038695	5456	65	15F
0005435038677	5456	66	16A
0005435006631	5456	67	16C
0005432125333	5456	68	16D
0005435038689	5456	69	16F
0005435038690	5456	70	16E
0005435038729	5456	71	17A
0005435038722	5456	72	17E
0005435006646	5456	73	17D
0005435038717	5456	74	18A
0005432125332	5456	75	17F
0005435006638	5456	76	18B
0005435006639	5456	77	18E
0005435006637	5456	78	18F
0005435038733	5456	79	19A
0005435006632	5456	80	19D
0005435038714	5456	81	19E
0005435038701	5456	82	20A
0005435038683	5456	83	20B
0005435038694	5456	84	20D
0005435038723	5456	85	20C
0005435038697	5456	86	20F
0005435006635	5456	87	21A
0005435038692	5456	88	21D
0005435038691	5456	89	22A
0005435006624	5456	90	21F
0005435038700	5456	91	22B
0005435038736	5456	92	22D
0005435038720	5456	93	22E
0005432125326	5456	94	22F
0005435006627	5456	95	23B
0005435038712	5456	96	23C
0005435038706	5456	97	23E
0005434228995	12969	1	2A
0005434228996	12969	2	2D
0005434228990	12969	3	3A
0005432304334	12969	4	3D
0005434229009	12969	5	4B
0005434229006	12969	6	6B
0005432304335	12969	7	7F
0005434229007	12969	8	8B
0005434228989	12969	9	9C
0005434228997	12969	10	9E
0005434228993	12969	11	9F
0005434229010	12969	12	10C
0005432304332	12969	13	11E
0005432304333	12969	14	12C
0005434229001	12969	15	12B
0005434229002	12969	16	13A
0005434228998	12969	17	14F
0005434229005	12969	18	16B
0005434229011	12969	19	16C
0005432304336	12969	20	17D
0005434228992	12969	21	17F
0005434229003	12969	22	19A
0005434229008	12969	23	20B
0005432304337	12969	24	20A
0005434229004	12969	25	20C
0005434228994	12969	26	21A
0005434228999	12969	27	22C
0005434228991	12969	28	23A
0005434229000	12969	29	23F
0005432188549	14856	1	1A
0005434411704	14856	2	2C
0005434426101	14856	3	2D
0005434426112	14856	4	2F
0005434426084	14856	5	3F
0005434426093	14856	6	4C
0005434411703	14856	7	4D
0005432188550	14856	8	4E
0005434426094	14856	9	5A
0005434411701	14856	10	5C
0005434426100	14856	11	6A
0005434426095	14856	12	6E
0005434426098	14856	13	7C
0005434426089	14856	14	7E
0005434426088	14856	15	7F
0005434426087	14856	16	8C
0005434426108	14856	17	8F
0005434426103	14856	18	9A
0005434411702	14856	19	10D
0005432188553	14856	20	10F
0005434426105	14856	21	11C
0005434426104	14856	22	11E
0005434426106	14856	23	11F
0005434426109	14856	24	12F
0005432188552	14856	25	13A
0005434426091	14856	26	14E
0005434426113	14856	27	15D
0005432188551	14856	28	15E
0005434426110	14856	29	15F
0005434426085	14856	30	16E
0005434426092	14856	31	17F
0005434426090	14856	32	18A
0005434426099	14856	33	18C
0005434426107	14856	34	18D
0005434426096	14856	35	18F
0005434426111	14856	36	19D
0005434426086	14856	37	19F
0005434426097	14856	38	20C
0005434426102	14856	39	20F
0005435902410	20208	1	2D
0005435902405	20208	2	4A
0005435902413	20208	3	5C
0005435902418	20208	4	5E
0005435902415	20208	5	6A
0005435902420	20208	6	6C
0005435902409	20208	7	8C
0005435554111	20208	8	8F
0005435902419	20208	9	10C
0005435902417	20208	10	10E
0005435902408	20208	11	12E
0005435902412	20208	12	13A
0005435902414	20208	13	13D
0005435554109	20208	14	13E
0005435902402	20208	15	13F
0005435902411	20208	16	14E
0005435902404	20208	17	14F
0005435902406	20208	18	15D
0005435554108	20208	19	15E
0005435902407	20208	20	16A
0005435554110	20208	21	17A
0005432059472	20208	22	17D
0005435902416	20208	23	17F
0005435554112	20208	24	19F
0005435902403	20208	25	20A
0005435981545	26528	1	1C
0005435981511	26528	2	1D
0005435981540	26528	3	1F
0005432300163	26528	4	2A
0005435981526	26528	5	2F
0005435981539	26528	6	3A
0005435981525	26528	7	3C
0005435981513	26528	8	4A
0005435981533	26528	9	4E
0005435981543	26528	10	5C
0005435981530	26528	11	5D
0005435981529	26528	12	5E
0005435981520	26528	13	5F
0005435981509	26528	14	6A
0005435981510	26528	15	6C
0005432300161	26528	16	6D
0005435981523	26528	17	6E
0005435981538	26528	18	7A
0005435981516	26528	19	7F
0005435981517	26528	20	8E
0005435981518	26528	21	8F
0005435981512	26528	22	9A
0005435981542	26528	23	9F
0005435981528	26528	24	10A
0005435981536	26528	25	11C
0005435981524	26528	26	11E
0005435981535	26528	27	12C
0005435981508	26528	28	12D
0005432300162	26528	29	12E
0005435981514	26528	30	13A
0005435981522	26528	31	13C
0005435981519	26528	32	14A
0005435981541	26528	33	14E
0005435981515	26528	34	15C
0005435981532	26528	35	15D
0005435981546	26528	36	16A
0005435981531	26528	37	16C
0005435981527	26528	38	16F
0005432300164	26528	39	17D
0005435981534	26528	40	18E
0005435981544	26528	41	19D
0005432300165	26528	42	19E
0005435981537	26528	43	20A
0005435981521	26528	44	20E
0005435981547	26528	45	20F
0005434270173	26697	1	1D
0005433434218	26697	2	1F
0005433434228	26697	3	2D
0005433434233	26697	4	2F
0005433434231	26697	5	3A
0005433434234	26697	6	4D
0005433434210	26697	7	5A
0005432051078	26697	8	5C
0005433434213	26697	9	5E
0005433434216	26697	10	6D
0005433434235	26697	11	6E
0005433434226	26697	12	6F
0005432051077	26697	13	7C
0005433434232	26697	14	8A
0005433434221	26697	15	8D
0005433434230	26697	16	8F
0005434271279	26697	17	9C
0005433434212	26697	18	10E
0005433434215	26697	19	11A
0005434270172	26697	20	11D
0005433434223	26697	21	11F
0005433434220	26697	22	12D
0005433434222	26697	23	12E
0005434271277	26697	24	13C
0005433434211	26697	25	13E
0005433434227	26697	26	14D
0005433434225	26697	27	14E
0005433434217	26697	28	15E
0005434271280	26697	29	16A
0005434271278	26697	30	17E
0005433434209	26697	31	17F
0005433434236	26697	32	19C
0005433434224	26697	33	19D
0005433434219	26697	34	19E
0005433434214	26697	35	20E
0005433434229	26697	36	20F
0005432583609	3165	1	1A
0005432583629	3165	2	1B
0005432216226	3165	3	1C
0005432583633	3165	4	2A
0005432583617	3165	5	2C
0005432583622	3165	6	3A
0005432216225	3165	7	3B
0005432583615	3165	8	3C
0005432583625	3165	9	3D
0005432583628	3165	10	4B
0005432583616	3165	11	4C
0005432583619	3165	12	4D
0005432216227	3165	13	5A
0005432583614	3165	14	5C
0005432583610	3165	15	5D
0005432583611	3165	16	6A
0005432583620	3165	17	7B
0005432583608	3165	18	7D
0005432583627	3165	19	18B
0005432583626	3165	20	18D
0005432583634	3165	21	19C
0005432583618	3165	22	20A
0005432583607	3165	23	20B
0005432583624	3165	24	20C
0005432583630	3165	25	20D
0005432583621	3165	26	21A
0005432583623	3165	27	21B
0005432583612	3165	28	21C
0005432583632	3165	29	22A
0005432583613	3165	30	22D
0005432583631	3165	31	23A
0005432857873	31474	1	2A
0005432857871	31474	2	3B
0005432857867	31474	3	3D
0005432857869	31474	4	4A
0005432857868	31474	5	7B
0005432857866	31474	6	7C
0005432857865	31474	7	18A
0005432857870	31474	8	18D
0005432857872	31474	9	19D
0005432857864	31474	10	20A
0005434943200	862	1	2A
0005434943203	862	2	2D
0005434943202	862	3	3C
0005434943199	862	4	6A
0005434943195	862	5	7A
0005434943196	862	6	18A
0005434943201	862	7	18B
0005434943198	862	8	19D
0005434943197	862	9	21D
0005433255030	16231	1	1B
0005433255028	16231	2	1C
0005433255027	16231	3	2C
0005433255026	16231	4	7D
0005433255029	16231	5	23A
0005433255031	16231	6	23B
0005435652273	21749	1	1A
0005435652250	21749	2	2A
0005435652277	21749	3	2C
0005435652292	21749	4	2F
0005435652252	21749	5	3A
0005435652284	21749	6	3F
0005435652258	21749	7	4D
0005435652254	21749	8	4F
0005435652260	21749	9	5D
0005435652262	21749	10	5F
0005435652279	21749	11	6F
0005435652269	21749	12	7A
0005435652257	21749	13	8A
0005435652287	21749	14	8E
0005435652281	21749	15	9C
0005435652288	21749	16	9D
0005435652296	21749	17	9E
0005435652295	21749	18	9F
0005435652264	21749	19	10C
0005435652286	21749	20	10D
0005435652263	21749	21	10F
0005435652270	21749	22	11C
0005435652268	21749	23	12C
0005435652293	21749	24	12D
0005435652271	21749	25	12E
0005435652272	21749	26	12F
0005435652255	21749	27	13C
0005435652291	21749	28	14D
0005435652290	21749	29	14E
0005435652267	21749	30	14F
0005435652274	21749	31	15A
0005435652261	21749	32	15D
0005435652275	21749	33	15E
0005435652266	21749	34	16C
0005435652294	21749	35	16D
0005435652276	21749	36	16E
0005435652282	21749	37	17D
0005435652251	21749	38	17E
0005435652256	21749	39	18A
0005435652265	21749	40	18D
0005435652253	21749	41	19C
0005435652289	21749	42	19E
0005435652280	21749	43	20A
0005435652278	21749	44	20C
0005435652283	21749	45	20D
0005435652285	21749	46	20E
0005435652259	21749	47	20F
0005433804816	9379	1	1A
0005433804799	9379	2	1C
0005433784351	9379	3	1G
0005432657397	9379	4	2A
0005433762963	9379	5	2F
0005433804813	9379	6	3A
0005433784356	9379	7	3F
0005433784365	9379	8	3C
0005433804805	9379	9	3G
0005433762970	9379	10	4B
0005433762957	9379	11	4F
0005433784336	9379	12	5F
0005432665239	9379	13	5C
0005433804806	9379	14	5G
0005433784331	9379	15	5H
0005433762965	9379	16	9G
0005433804824	9379	17	11D
0005433804804	9379	18	11B
0005433784335	9379	19	11E
0005433804814	9379	20	12A
0005433762960	9379	21	12D
0005433804811	9379	22	12B
0005433784343	9379	23	12F
0005433804820	9379	24	13D
0005433784342	9379	25	13E
0005433784345	9379	26	14F
0005433784347	9379	27	15A
0005433804826	9379	28	15G
0005432657399	9379	29	15F
0005433784337	9379	30	16B
0005433784329	9379	31	16F
0005433784364	9379	32	17D
0005433784350	9379	33	17H
0005433804815	9379	34	18D
0005433784341	9379	35	18F
0005433762972	9379	36	19B
0005433784348	9379	37	19E
0005432667420	9379	38	19H
0005433762962	9379	39	19G
0005433804818	9379	40	20A
0005433784355	9379	41	20E
0005433762971	9379	42	20D
0005433804796	9379	43	20H
0005433784333	9379	44	20G
0005433784353	9379	45	21D
0005432667418	9379	46	21E
0005433762964	9379	47	21F
0005433804797	9379	48	22D
0005433804823	9379	49	23A
0005433804801	9379	50	23E
0005433784349	9379	51	23D
0005433804800	9379	52	23B
0005433784359	9379	53	23G
0005433804825	9379	54	24A
0005433762968	9379	55	23H
0005433784332	9379	56	24E
0005433784346	9379	57	24D
0005432666354	9379	58	24H
0005433804803	9379	59	24G
0005433784340	9379	60	25D
0005433784360	9379	61	27A
0005433804808	9379	62	27B
0005433804809	9379	63	27E
0005433804821	9379	64	27D
0005433804795	9379	65	28A
0005432667419	9379	66	27H
0005433804822	9379	67	28B
0005433804819	9379	68	28E
0005433784357	9379	69	29B
0005433804802	9379	70	29G
0005433784338	9379	71	29H
0005433784352	9379	72	30A
0005433804817	9379	73	30F
0005433784339	9379	74	30E
0005433762967	9379	75	30G
0005433784334	9379	76	31F
0005433804794	9379	77	32D
0005433804807	9379	78	32E
0005433762959	9379	79	32F
0005432665240	9379	80	32G
0005432657396	9379	81	32H
0005433804798	9379	82	33B
0005432657398	9379	83	33E
0005433804812	9379	84	33D
0005433762966	9379	85	34B
0005433784366	9379	86	34F
0005433784358	9379	87	34E
0005433784354	9379	88	34H
0005433762961	9379	89	35E
0005433784330	9379	90	36D
0005433784362	9379	91	36F
0005433784361	9379	92	36G
0005433762969	9379	93	37B
0005433784344	9379	94	37E
0005433762958	9379	95	37D
0005433804828	9379	96	38D
0005433784363	9379	97	38H
0005433804810	9379	98	38G
0005433804827	9379	99	39F
0005434170812	26245	1	1B
0005434269069	26245	2	1F
0005434170824	26245	3	4F
0005434170815	26245	4	4C
0005435269643	26245	5	5B
0005434170825	26245	6	5A
0005434170822	26245	7	13E
0005435269644	26245	8	13H
0005434151654	26245	9	14A
0005434170814	26245	10	14H
0005434269068	26245	11	15F
0005434170813	26245	12	16F
0005435269646	26245	13	16H
0005434170811	26245	14	17D
0005434170820	26245	15	17E
0005434269067	26245	16	18H
0005434170817	26245	17	21E
0005434170823	26245	18	21G
0005434170821	26245	19	24F
0005435269645	26245	20	24G
0005434170819	26245	21	25E
0005434170818	26245	22	28H
0005434270170	26245	23	29D
0005435269647	26245	24	30B
0005434270171	26245	25	30G
0005434151656	26245	26	31H
0005434151655	26245	27	33H
0005434271276	26245	28	34B
0005434271275	26245	29	35E
0005434170816	26245	30	36B
0005435135588	4918	1	2C
0005435135589	4918	2	3C
0005435135586	4918	3	4C
0005435135587	4918	4	5A
0005435135590	4918	5	18C
0005435929599	33053	1	4C
0005435929598	33053	2	7A
0005434983202	9492	1	4C
0005434983199	9492	2	4D
0005434983201	9492	3	5A
0005434983200	9492	4	5D
0005434983203	9492	5	7C
0005434217901	27351	1	18C
0005434217900	27351	2	18D
0005434217899	27351	3	20C
0005433959860	25957	1	1C
0005433985134	25957	2	2B
0005433959872	25957	3	2H
0005433959896	25957	4	3A
0005433959894	25957	5	3C
0005433985124	25957	6	3F
0005433959879	25957	7	3G
0005433959878	25957	8	4B
0005433959901	25957	9	4F
0005433959875	25957	10	4H
0005433959888	25957	11	5B
0005433959903	25957	12	5F
0005433985133	25957	13	9B
0005433959882	25957	14	9G
0005433985144	25957	15	11A
0005433985140	25957	16	11E
0005433985125	25957	17	11D
0005433985149	25957	18	11F
0005433959876	25957	19	11G
0005433959898	25957	20	12H
0005433959889	25957	21	13F
0005433985147	25957	22	13G
0005433959861	25957	23	14F
0005433959883	25957	24	14G
0005433959893	25957	25	15A
0005433985146	25957	26	15B
0005433985128	25957	27	15F
0005433959902	25957	28	15G
0005433985160	25957	29	15H
0005433959865	25957	30	16D
0005433985135	25957	31	16E
0005433985151	25957	32	16G
0005433985157	25957	33	17B
0005433959870	25957	34	17D
0005433985158	25957	35	17G
0005433985123	25957	36	18A
0005433959859	25957	37	19H
0005433959873	25957	38	20A
0005433959856	25957	39	20B
0005433959884	25957	40	20H
0005433985141	25957	41	21E
0005433985132	25957	42	21D
0005433985127	25957	43	21H
0005433959895	25957	44	22A
0005433985148	25957	45	23F
0005433985156	25957	46	24A
0005433959866	25957	47	24E
0005433959877	25957	48	27D
0005433985131	25957	49	27G
0005433959881	25957	50	28E
0005433959863	25957	51	28F
0005433985130	25957	52	28H
0005433985152	25957	53	29B
0005433959899	25957	54	29D
0005433985138	25957	55	29H
0005433959869	25957	56	30D
0005433985129	25957	57	30B
0005433985143	25957	58	30E
0005433959867	25957	59	30G
0005433959864	25957	60	30H
0005433959897	25957	61	31D
0005433959891	25957	62	31G
0005433985137	25957	63	32E
0005433985126	25957	64	32H
0005433985122	25957	65	32G
0005433959886	25957	66	33A
0005433959900	25957	67	33B
0005433959885	25957	68	33E
0005433959858	25957	69	33D
0005433959887	25957	70	33F
0005433959857	25957	71	34A
0005433959871	25957	72	34D
0005433985153	25957	73	34B
0005433959862	25957	74	35A
0005433959890	25957	75	35G
0005433985142	25957	76	35H
0005433959892	25957	77	36A
0005433985154	25957	78	36E
0005433959868	25957	79	36H
0005433985159	25957	80	36G
0005433959880	25957	81	37B
0005433985139	25957	82	37E
0005433959874	25957	83	38B
0005433985136	25957	84	38E
0005433985155	25957	85	38G
0005433985145	25957	86	38H
0005433985161	25957	87	39E
0005433985150	25957	88	39F
0005434479917	948	1	1C
0005432269448	948	2	1D
0005434479923	948	3	2A
0005434479907	948	4	2B
0005434479904	948	5	2D
0005434479913	948	6	3B
0005434479924	948	7	3C
0005434479915	948	8	4D
0005434479910	948	9	5D
0005434479919	948	10	6A
0005434479906	948	11	7B
0005434479912	948	12	7C
0005434479925	948	13	7D
0005434479911	948	14	18B
0005432269449	948	15	18D
0005434479914	948	16	19C
0005432269450	948	17	19D
0005434479920	948	18	20B
0005434479905	948	19	20C
0005434479922	948	20	20D
0005434479909	948	21	21B
0005434479908	948	22	22A
0005434479921	948	23	22B
0005434479918	948	24	22C
0005434479916	948	25	22D
0005433165693	16566	1	1C
0005433165694	16566	2	2C
0005433165689	16566	3	4B
0005433165692	16566	4	18A
0005433165688	16566	5	19B
0005433165686	16566	6	19D
0005433165684	16566	7	20A
0005433165687	16566	8	20B
0005433165691	16566	9	20D
0005433165690	16566	10	21A
0005433165685	16566	11	22A
0005435149796	10341	1	1B
0005435142340	10341	2	1C
0005435149797	10341	3	1D
0005435149788	10341	4	2A
0005435142342	10341	5	2C
0005435149792	10341	6	3A
0005435149790	10341	7	3B
0005435142345	10341	8	3D
0005435142343	10341	9	5A
0005435149789	10341	10	5D
0005435149795	10341	11	6A
0005435149787	10341	12	6B
0005435149791	10341	13	6C
0005435142337	10341	14	6D
0005435142341	10341	15	7C
0005435142348	10341	16	7D
0005435142339	10341	17	18C
0005435149785	10341	18	19A
0005435142338	10341	19	19B
0005435142346	10341	20	19C
0005435149794	10341	21	20B
0005435142347	10341	22	20C
0005435142335	10341	23	20D
0005435142344	10341	24	21B
0005435149786	10341	25	21C
0005435149793	10341	26	22A
0005435142336	10341	27	22C
0005435386463	21929	1	2C
0005433289733	21929	2	2D
0005435386461	21929	3	3A
0005433289731	21929	4	5C
0005435386464	21929	5	5D
0005433289738	21929	6	6B
0005433289734	21929	7	6D
0005433289735	21929	8	7A
0005433289736	21929	9	7B
0005433289737	21929	10	18D
0005435386460	21929	11	19A
0005435386462	21929	12	19C
0005433289732	21929	13	20D
0005435386459	21929	14	21B
0005435386458	21929	15	22B
0005434573108	11232	1	2F
0005434573104	11232	2	6A
0005434573109	11232	3	8E
0005434573111	11232	4	10E
0005434573113	11232	5	10F
0005434573105	11232	6	12C
0005434573107	11232	7	14F
0005434573112	11232	8	17A
0005434573110	11232	9	17C
0005434573115	11232	10	18A
0005434573102	11232	11	18C
0005434573106	11232	12	18D
0005434573101	11232	13	18F
0005434573114	11232	14	19A
0005434573103	11232	15	19D
0005435319436	20961	1	1A
0005435501940	20961	2	1C
0005435517588	20961	3	1D
0005435517599	20961	4	2A
0005435501944	20961	5	2C
0005435501933	20961	6	2F
0005435508176	20961	7	3A
0005435501936	20961	8	3C
0005435501934	20961	9	3D
0005435501952	20961	10	4A
0005435501939	20961	11	4E
0005435319438	20961	12	4F
0005435508175	20961	13	5A
0005435508170	20961	14	5C
0005435501951	20961	15	5D
0005435517606	20961	16	5E
0005435517585	20961	17	6C
0005435517596	20961	18	6D
0005435501931	20961	19	6E
0005435517592	20961	20	6F
0005435319439	20961	21	7C
0005435319432	20961	22	7D
0005435517605	20961	23	8A
0005435517603	20961	24	7F
0005435501938	20961	25	8C
0005435517594	20961	26	8E
0005435508164	20961	27	8F
0005435508168	20961	28	9A
0005435517591	20961	29	9C
0005435517587	20961	30	9E
0005435501949	20961	31	9F
0005435517604	20961	32	10C
0005432291890	20961	33	10D
0005435319434	20961	34	10E
0005435508172	20961	35	11A
0005435501942	20961	36	11C
0005435319435	20961	37	11D
0005435319440	20961	38	11E
0005435517602	20961	39	11F
0005435508169	20961	40	12C
0005435501937	20961	41	12D
0005435517598	20961	42	12E
0005435508174	20961	43	12F
0005435508165	20961	44	13A
0005435508173	20961	45	13D
0005435501941	20961	46	13E
0005435517590	20961	47	14D
0005435508171	20961	48	14E
0005432291889	20961	49	15A
0005435517597	20961	50	15E
0005435501945	20961	51	15F
0005435508166	20961	52	16A
0005435517595	20961	53	16C
0005435319433	20961	54	16D
0005435501943	20961	55	16E
0005435319437	20961	56	16F
0005435508167	20961	57	17A
0005435501935	20961	58	17C
0005435501932	20961	59	17D
0005435501948	20961	60	18A
0005435517593	20961	61	18E
0005435501946	20961	62	19C
0005435501950	20961	63	19E
0005435501947	20961	64	19F
0005435517589	20961	65	20A
0005435517586	20961	66	20C
0005435517600	20961	67	20D
0005435517601	20961	68	20E
0005432706358	2911	1	1A
0005432706350	2911	2	1C
0005432217727	2911	3	1F
0005432706354	2911	4	2D
0005432706348	2911	5	2F
0005432706345	2911	6	3A
0005432706335	2911	7	4A
0005432706352	2911	8	4E
0005432706351	2911	9	4F
0005432706349	2911	10	6D
0005432706333	2911	11	6E
0005432706357	2911	12	7E
0005432706346	2911	13	8A
0005432217729	2911	14	8C
0005432706339	2911	15	8D
0005432706338	2911	16	9C
0005432706355	2911	17	9D
0005432706359	2911	18	9F
0005432706353	2911	19	10C
0005432706337	2911	20	10D
0005432217728	2911	21	11F
0005432706334	2911	22	12C
0005432706342	2911	23	13C
0005432706340	2911	24	13E
0005432706343	2911	25	13F
0005432217730	2911	26	15C
0005432706347	2911	27	16D
0005432706336	2911	28	17E
0005432706356	2911	29	17F
0005432706344	2911	30	18F
0005432706341	2911	31	20E
0005432692577	29980	1	1A
0005432692573	29980	2	1C
0005432692588	29980	3	1D
0005432880573	29980	4	1F
0005433123575	29980	5	2A
0005433123573	29980	6	2C
0005433123567	29980	7	2D
0005433123586	29980	8	2F
0005433123584	29980	9	3A
0005432880576	29980	10	3C
0005433123572	29980	11	3D
0005433194819	29980	12	3F
0005432692565	29980	13	4A
0005433123583	29980	14	4D
0005432692589	29980	15	4E
0005432880569	29980	16	4F
0005432692581	29980	17	5A
0005432692587	29980	18	5C
0005433123581	29980	19	5D
0005432880577	29980	20	5E
0005432692568	29980	21	5F
0005432692585	29980	22	6A
0005433123582	29980	23	6C
0005432692582	29980	24	6D
0005433123569	29980	25	6F
0005432692562	29980	26	7C
0005432692576	29980	27	7D
0005432692574	29980	28	7E
0005433123565	29980	29	8A
0005432880578	29980	30	8C
0005432692563	29980	31	8E
0005433123574	29980	32	8F
0005433123585	29980	33	9C
0005432880579	29980	34	9D
0005432692578	29980	35	9E
0005432880572	29980	36	10C
0005433123566	29980	37	10D
0005432880567	29980	38	10E
0005432692561	29980	39	10F
0005432692569	29980	40	11A
0005432692566	29980	41	11C
0005432880580	29980	42	11E
0005432692571	29980	43	11F
0005432692579	29980	44	12A
0005432692567	29980	45	12D
0005433123587	29980	46	12E
0005432692580	29980	47	12F
0005432692572	29980	48	13C
0005433123568	29980	49	14A
0005432692570	29980	50	14E
0005432692559	29980	51	14F
0005432692560	29980	52	15A
0005432880568	29980	53	15D
0005432880570	29980	54	15E
0005433194817	29980	55	15F
0005432692584	29980	56	16A
0005433123571	29980	57	16C
0005432692564	29980	58	16E
0005432880574	29980	59	16F
0005432692586	29980	60	17C
0005433123579	29980	61	17D
0005433123570	29980	62	17E
0005433123578	29980	63	17F
0005432880571	29980	64	18C
0005433123577	29980	65	18D
0005432880566	29980	66	18F
0005433123576	29980	67	19C
0005433194818	29980	68	19D
0005433123580	29980	69	19E
0005432692575	29980	70	20C
0005432880575	29980	71	20D
0005432692583	29980	72	20F
0005434979265	23701	1	1A
0005434979258	23701	2	1B
0005434979278	23701	3	1C
0005434979272	23701	4	1D
0005434979254	23701	5	2A
0005434988557	23701	6	2B
0005434988561	23701	7	2C
0005434979269	23701	8	2D
0005434979275	23701	9	3A
0005434979260	23701	10	3B
0005434979276	23701	11	3D
0005434979263	23701	12	4A
0005434979252	23701	13	4B
0005434979271	23701	14	4D
0005434988562	23701	15	5B
0005434979273	23701	16	5C
0005434979277	23701	17	6A
0005434979255	23701	18	6B
0005434979262	23701	19	6C
0005434979268	23701	20	6D
0005434979267	23701	21	7A
0005434979261	23701	22	7B
0005434979259	23701	23	7C
0005434979264	23701	24	7D
0005434979281	23701	25	18B
0005434979266	23701	26	18C
0005434988558	23701	27	18D
0005434988560	23701	28	19A
0005434979279	23701	29	19C
0005434988559	23701	30	19D
0005434979282	23701	31	20A
0005434979253	23701	32	20B
0005434979280	23701	33	20C
0005434988555	23701	34	21A
0005434988564	23701	35	21B
0005434979270	23701	36	21D
0005434979257	23701	37	22A
0005434988563	23701	38	22B
0005434979256	23701	39	22C
0005434979274	23701	40	23A
0005434988556	23701	41	23B
0005434302383	10258	1	2A
0005434302385	10258	2	3B
0005434302382	10258	3	18D
0005434302381	10258	4	20D
0005434302384	10258	5	21A
0005434302853	10258	6	21D
0005433113499	19645	1	5D
0005433113497	19645	2	7C
0005433113498	19645	3	22A
0005435068246	3553	1	1C
0005435718834	3553	2	1A
0005435068211	3553	3	1D
0005435068238	3553	4	1F
0005435068230	3553	5	2A
0005435068257	3553	6	2C
0005435068237	3553	7	3A
0005435068227	3553	8	4A
0005435068243	3553	9	4D
0005435068217	3553	10	4E
0005435068254	3553	11	4F
0005435068260	3553	12	5A
0005435068253	3553	13	5C
0005435068213	3553	14	5D
0005435068256	3553	15	5E
0005435068241	3553	16	6A
0005435068255	3553	17	6D
0005435068226	3553	18	6E
0005435068249	3553	19	6F
0005435068236	3553	20	7A
0005435068247	3553	21	7C
0005435068263	3553	22	7E
0005435068261	3553	23	8A
0005435068242	3553	24	8C
0005435068239	3553	25	8E
0005435718836	3553	26	9D
0005435068234	3553	27	10A
0005435068225	3553	28	10D
0005435068233	3553	29	10E
0005435068248	3553	30	10F
0005435068252	3553	31	11A
0005435068212	3553	32	11D
0005435718832	3553	33	12A
0005435068258	3553	34	12D
0005435068216	3553	35	12F
0005435068222	3553	36	13E
0005435068259	3553	37	14A
0005435068229	3553	38	14E
0005435068240	3553	39	14F
0005435068262	3553	40	15A
0005435068232	3553	41	15C
0005435718835	3553	42	15E
0005435718837	3553	43	16A
0005435068220	3553	44	16E
0005435068219	3553	45	17C
0005435068218	3553	46	17E
0005435718833	3553	47	17F
0005435068231	3553	48	18A
0005435068221	3553	49	18D
0005435068250	3553	50	18F
0005435068224	3553	51	18E
0005435068223	3553	52	19A
0005435068244	3553	53	19D
0005435068245	3553	54	19E
0005435068251	3553	55	20A
0005435068235	3553	56	20C
0005435068215	3553	57	20D
0005435068214	3553	58	20E
0005435068228	3553	59	20F
0005435925063	15276	1	1A
0005435925071	15276	2	1F
0005435939858	15276	3	2C
0005435925072	15276	4	3A
0005435925074	15276	5	4A
0005435925068	15276	6	5D
0005435925067	15276	7	5F
0005435925066	15276	8	6F
0005435925065	15276	9	8A
0005435925061	15276	10	8C
0005435925077	15276	11	9A
0005435925073	15276	12	10F
0005435939857	15276	13	11E
0005435925069	15276	14	12F
0005435925076	15276	15	14D
0005435925075	15276	16	14E
0005435925064	15276	17	15D
0005435925062	15276	18	18C
0005435925070	15276	19	20E
0005432658556	18221	1	2A
0005432659671	18221	2	4B
0005432658555	18221	3	5B
0005432659672	18221	4	6B
0005432658557	18221	5	6A
0005432157459	88	1	4D
0005432157460	88	2	29B
0005432261160	87	1	1F
0005432261145	87	2	2D
0005432261155	87	3	3A
0005432816986	87	4	2F
0005432816977	87	5	3C
0005432261149	87	6	3D
0005432261159	87	7	4D
0005432816983	87	8	7A
0005432816973	87	9	6F
0005432261171	87	10	8A
0005432261152	87	11	8E
0005432816994	87	12	8F
0005432816967	87	13	9A
0005432261144	87	14	9F
0005432261139	87	15	10B
0005432816995	87	16	10C
0005432261174	87	17	10E
0005432816992	87	18	10F
0005432261161	87	19	11B
0005432261150	87	20	11A
0005432261156	87	21	11C
0005432261169	87	22	11D
0005432816978	87	23	11E
0005432261140	87	24	12B
0005432261180	87	25	12C
0005432816970	87	26	13C
0005432816981	87	27	13D
0005432261142	87	28	13F
0005432261162	87	29	13E
0005432207618	87	30	14A
0005432816969	87	31	14B
0005432261172	87	32	14C
0005432261138	87	33	15B
0005432261143	87	34	15F
0005432261148	87	35	16B
0005432261158	87	36	16C
0005432816979	87	37	16F
0005432288932	87	38	17C
0005432261165	87	39	18A
0005432261136	87	40	18D
0005432261146	87	41	18C
0005432816980	87	42	19B
0005432288933	87	43	18F
0005432261173	87	44	19C
0005432288930	87	45	19D
0005432261137	87	46	20E
0005432816974	87	47	20D
0005432261178	87	48	21A
0005432261151	87	49	21C
0005432207616	87	50	21B
0005432261176	87	51	21F
0005432261170	87	52	22E
0005432261166	87	53	22F
0005432261179	87	54	23A
0005432261153	87	55	23C
0005432816984	87	56	23D
0005432816993	87	57	23F
0005432816997	87	58	24B
0005432288931	87	59	24A
0005432816985	87	60	24D
0005432816989	87	61	24E
0005432816990	87	62	24F
0005432261163	87	63	25B
0005432261147	87	64	25A
0005432816988	87	65	25E
0005432816975	87	66	25D
0005432816976	87	67	25C
0005432261177	87	68	25F
0005432261134	87	69	26C
0005432261141	87	70	27B
0005432261164	87	71	27D
0005432261154	87	72	27E
0005432261167	87	73	27F
0005432816968	87	74	28B
0005432816971	87	75	28D
0005432816991	87	76	29A
0005432261168	87	77	28F
0005432816982	87	78	29C
0005432261157	87	79	29D
0005432261175	87	80	29E
0005432816972	87	81	30A
0005432816987	87	82	30B
0005432207617	87	83	31B
0005432816996	87	84	31D
0005432261135	87	85	31E
0005433101258	7947	1	1A
0005432019812	7947	2	1C
0005432919516	7947	3	1F
0005433101272	7947	4	1D
0005432019817	7947	5	2A
0005432019818	7947	6	2C
0005432045583	7947	7	3A
0005432019805	7947	8	2F
0005432677510	7947	9	3D
0005432391951	7947	10	4A
0005433101270	7947	11	3F
0005433101269	7947	12	4C
0005432019823	7947	13	4D
0005432019813	7947	14	5A
0005432919506	7947	15	4F
0005433101271	7947	16	5D
0005432019814	7947	17	6A
0005433101231	7947	18	6C
0005432919512	7947	19	7A
0005432019832	7947	20	6F
0005432919503	7947	21	7D
0005432751473	7947	22	8A
0005432919517	7947	23	8C
0005432919515	7947	24	8B
0005432019821	7947	25	8D
0005432019808	7947	26	8E
0005432919521	7947	27	9A
0005433101266	7947	28	8F
0005433101226	7947	29	9B
0005433101267	7947	30	9C
0005432019816	7947	31	9F
0005433101263	7947	32	10A
0005432919504	7947	33	10D
0005432019820	7947	34	10C
0005432019815	7947	35	10E
0005433101251	7947	36	11A
0005432753245	7947	37	11C
0005432751472	7947	38	11B
0005433101223	7947	39	11D
0005432391948	7947	40	11E
0005432919510	7947	41	12A
0005432677507	7947	42	11F
0005432919511	7947	43	12B
0005433101224	7947	44	12D
0005433101248	7947	45	12E
0005433101250	7947	46	13B
0005432019826	7947	47	13A
0005433101221	7947	48	13D
0005433101232	7947	49	13E
0005433101245	7947	50	14A
0005432019809	7947	51	13F
0005432753246	7947	52	14B
0005432019830	7947	53	14C
0005433101261	7947	54	14D
0005432919524	7947	55	15B
0005433101275	7947	56	15A
0005432044479	7947	57	15C
0005433101257	7947	58	15D
0005433101288	7947	59	15F
0005433101241	7947	60	16B
0005433101289	7947	61	16D
0005432019831	7947	62	16C
0005433101228	7947	63	16E
0005432919522	7947	64	17A
0005432919519	7947	65	16F
0005433101265	7947	66	17C
0005433101239	7947	67	17B
0005432019810	7947	68	17E
0005432919507	7947	69	17D
0005433101235	7947	70	17F
0005433101276	7947	71	18A
0005433101290	7947	72	18C
0005433101278	7947	73	18D
0005433101246	7947	74	19B
0005433101268	7947	75	18F
0005432019828	7947	76	19C
0005432919505	7947	77	20A
0005433101233	7947	78	19E
0005432019829	7947	79	20B
0005433101252	7947	80	20C
0005432019825	7947	81	20E
0005432919520	7947	82	20D
0005432019827	7947	83	20F
0005433101264	7947	84	21C
0005433101225	7947	85	21B
0005433101259	7947	86	21D
0005433101236	7947	87	21F
0005433101277	7947	88	21E
0005433101255	7947	89	22A
0005433101243	7947	90	22B
0005433101229	7947	91	22C
0005432919508	7947	92	22E
0005433101234	7947	93	22D
0005433101279	7947	94	22F
0005433101247	7947	95	23A
0005433101254	7947	96	23C
0005432919514	7947	97	23B
0005433101283	7947	98	23E
0005433101262	7947	99	23F
0005432391950	7947	100	24B
0005433101286	7947	101	24A
0005433101230	7947	102	24C
0005432044480	7947	103	24F
0005432919513	7947	104	24E
0005432019807	7947	105	25A
0005432019819	7947	106	25C
0005433101260	7947	107	25F
0005433101237	7947	108	25E
0005432751470	7947	109	26A
0005432019806	7947	110	26B
0005432919523	7947	111	26D
0005433101242	7947	112	26C
0005433101273	7947	113	26F
0005432019822	7947	114	26E
0005433101284	7947	115	27B
0005432677508	7947	116	27A
0005433101240	7947	117	27C
0005432045582	7947	118	27D
0005433101249	7947	119	27F
0005432019824	7947	120	27E
0005433101281	7947	121	28A
0005433101222	7947	122	28B
0005433101282	7947	123	28D
0005432919518	7947	124	28C
0005433101227	7947	125	28E
0005433101256	7947	126	28F
0005433101285	7947	127	29B
0005432677509	7947	128	29D
0005433101274	7947	129	29E
0005433101253	7947	130	30A
0005432751471	7947	131	30B
0005433101244	7947	132	30D
0005433101280	7947	133	30C
0005433101238	7947	134	30E
0005432044478	7947	135	31A
0005432753247	7947	136	31B
0005432019811	7947	137	31D
0005432919509	7947	138	31C
0005433101287	7947	139	31E
0005432391949	7947	140	31F
0005432901316	7945	1	4A
0005432901313	7945	2	4D
0005432901315	7945	3	6C
0005432901327	7945	4	7D
0005432901322	7945	5	10C
0005432901318	7945	6	10E
0005432901325	7945	7	14D
0005432901324	7945	8	15D
0005432901319	7945	9	16C
0005432002043	7945	10	17E
0005432901326	7945	11	21B
0005432901323	7945	12	21F
0005432901320	7945	13	24E
0005432901317	7945	14	28A
0005432901328	7945	15	28C
0005432901314	7945	16	29C
0005432901312	7945	17	29E
0005432002042	7945	18	30F
0005432901321	7945	19	31B
0005433870693	9651	1	2A
0005433870695	9651	2	4B
0005433870694	9651	3	5B
0005434175685	32328	1	1B
0005434175686	32328	2	3A
0005434175684	32328	3	4A
0005434175683	32328	4	6A
0005434876740	3475	1	1C
0005434876652	3475	2	1G
0005432799001	3475	3	1K
0005434876748	3475	4	2C
0005434876653	3475	5	2A
0005432188554	3475	6	2H
0005432798997	3475	7	2G
0005435625882	3475	8	3A
0005435625896	3475	9	2K
0005435125726	3475	10	3G
0005434876703	3475	11	3C
0005434876718	3475	12	3H
0005434876694	3475	13	4C
0005434876689	3475	14	4G
0005432188555	3475	15	4D
0005435625883	3475	16	4K
0005434876717	3475	17	4H
0005434426138	3475	18	5C
0005434876700	3475	19	5D
0005435125699	3475	20	11A
0005434876677	3475	21	5K
0005434876709	3475	22	11D
0005434876666	3475	23	11H
0005435625888	3475	24	12C
0005434876707	3475	25	12E
0005434876656	3475	26	12D
0005435125708	3475	27	12F
0005434876672	3475	28	12K
0005435125719	3475	29	13C
0005432798994	3475	30	13E
0005435125725	3475	31	13G
0005434426118	3475	32	14A
0005434876714	3475	33	14D
0005435125722	3475	34	14G
0005434876669	3475	35	14K
0005435125712	3475	36	14H
0005432798996	3475	37	15C
0005434937812	3475	38	15E
0005434876711	3475	39	15D
0005434937831	3475	40	15H
0005434876723	3475	41	15G
0005434876741	3475	42	15F
0005435125695	3475	43	16A
0005434426131	3475	44	15K
0005435125717	3475	45	16D
0005434426125	3475	46	16F
0005434876729	3475	47	16H
0005435625889	3475	48	17C
0005435125704	3475	49	17A
0005432798992	3475	50	16K
0005432799006	3475	51	17E
0005432798987	3475	52	17D
0005435625884	3475	53	17G
0005434937816	3475	54	17F
0005435125689	3475	55	17K
0005435125718	3475	56	18C
0005435125705	3475	57	18B
0005434876708	3475	58	18A
0005434937820	3475	59	18H
0005434876678	3475	60	18K
0005435625897	3475	61	18J
0005432611644	3475	62	19F
0005434876673	3475	63	19E
0005434876692	3475	64	19D
0005434937823	3475	65	19H
0005435125706	3475	66	20A
0005434937832	3475	67	20C
0005435125690	3475	68	20E
0005434937814	3475	69	20F
0005434426119	3475	70	20K
0005435125693	3475	71	20H
0005432611642	3475	72	21A
0005435125697	3475	73	21D
0005432798983	3475	74	21C
0005434876697	3475	75	22C
0005432798998	3475	76	22B
0005434937827	3475	77	22F
0005434426139	3475	78	22E
0005432611645	3475	79	22D
0005434876663	3475	80	22G
0005435625899	3475	81	22K
0005434876695	3475	82	23B
0005434426134	3475	83	23A
0005434876690	3475	84	23D
0005434876747	3475	85	23F
0005434426116	3475	86	23E
0005432799008	3475	87	24D
0005434876712	3475	88	23K
0005434876686	3475	89	23J
0005434876710	3475	90	24E
0005434876661	3475	91	25B
0005434876684	3475	92	25D
0005434876664	3475	93	25F
0005435125721	3475	94	25E
0005434937819	3475	95	25H
0005435125720	3475	96	25G
0005434426145	3475	97	25K
0005434876683	3475	98	26C
0005434876745	3475	99	26B
0005434876667	3475	100	26A
0005432799009	3475	101	26E
0005434426126	3475	102	26D
0005434876670	3475	103	26G
0005434876706	3475	104	26K
0005432798984	3475	105	26J
0005434876682	3475	106	26H
0005435125716	3475	107	27A
0005435125698	3475	108	27D
0005434876738	3475	109	27C
0005434876658	3475	110	27B
0005434937821	3475	111	27E
0005434426114	3475	112	27H
0005435625891	3475	113	27G
0005434876662	3475	114	27F
0005432798989	3475	115	27K
0005432799000	3475	116	27J
0005435125700	3475	117	28B
0005432798995	3475	118	28E
0005434876659	3475	119	28D
0005434426136	3475	120	28G
0005434876715	3475	121	28J
0005432799004	3475	122	29B
0005435625880	3475	123	29A
0005434876732	3475	124	29D
0005435125701	3475	125	29J
0005432799003	3475	126	29G
0005434426127	3475	127	30A
0005434876726	3475	128	29K
0005434876674	3475	129	30B
0005435125727	3475	130	30D
0005434937830	3475	131	30G
0005432613795	3475	132	30H
0005434426142	3475	133	31C
0005432613796	3475	134	31B
0005432799005	3475	135	31F
0005435625892	3475	136	31H
0005434876693	3475	137	31J
0005434876687	3475	138	32A
0005434876701	3475	139	32E
0005434426122	3475	140	32D
0005435625887	3475	141	32C
0005434876688	3475	142	32G
0005434876722	3475	143	33B
0005432798993	3475	144	33A
0005434876660	3475	145	33C
0005435125715	3475	146	33F
0005434876736	3475	147	33E
0005434876728	3475	148	33J
0005435625894	3475	149	33H
0005434426143	3475	150	33K
0005435125714	3475	151	34C
0005434876685	3475	152	34B
0005432798988	3475	153	34D
0005435125728	3475	154	34G
0005434426123	3475	155	34J
0005435125692	3475	156	34H
0005435625895	3475	157	35B
0005432613793	3475	158	35A
0005434876655	3475	159	34K
0005434937825	3475	160	35C
0005434426144	3475	161	35F
0005435625885	3475	162	35E
0005435125694	3475	163	35H
0005434876716	3475	164	35K
0005435125729	3475	165	36C
0005434876665	3475	166	36B
0005434876705	3475	167	36E
0005432183431	3475	168	36G
0005435125691	3475	169	36K
0005435125707	3475	170	37A
0005434876691	3475	171	37C
0005432798990	3475	172	37E
0005434937826	3475	173	37J
0005432798999	3475	174	37H
0005434937813	3475	175	37G
0005434426132	3475	176	38A
0005434876679	3475	177	38K
0005434426137	3475	178	38J
0005432798991	3475	179	38H
0005434876676	3475	180	39A
0005434876731	3475	181	39C
0005435625890	3475	182	39F
0005434876720	3475	183	39E
0005434426130	3475	184	39J
0005434426128	3475	185	40B
0005435625886	3475	186	40E
0005434876698	3475	187	40D
0005434426129	3475	188	40G
0005434876742	3475	189	40K
0005432799002	3475	190	40J
0005435125702	3475	191	41A
0005434876733	3475	192	41D
0005434426120	3475	193	41C
0005434876735	3475	194	41F
0005434937828	3475	195	41E
0005434426117	3475	196	41H
0005432183430	3475	197	41G
0005435125711	3475	198	42A
0005435125709	3475	199	41J
0005432188556	3475	200	42C
0005434876739	3475	201	42B
0005434426124	3475	202	42J
0005434876724	3475	203	42H
0005434876737	3475	204	42K
0005434876671	3475	205	43D
0005434876746	3475	206	43C
0005434937822	3475	207	43B
0005432799010	3475	208	43F
0005432799007	3475	209	43E
0005434876734	3475	210	43J
0005434876727	3475	211	43H
0005434937824	3475	212	43G
0005435125723	3475	213	44A
0005435125710	3475	214	44C
0005434937817	3475	215	44B
0005434937829	3475	216	44F
0005434426121	3475	217	44J
0005434876675	3475	218	45B
0005434876680	3475	219	45D
0005434876713	3475	220	45G
0005434426115	3475	221	45F
0005434876744	3475	222	45E
0005434876719	3475	223	45H
0005434937818	3475	224	45K
0005432611643	3475	225	45J
0005435125713	3475	226	46C
0005432611646	3475	227	46B
0005434876704	3475	228	46A
0005434876721	3475	229	46F
0005434876730	3475	230	46K
0005432798985	3475	231	46H
0005434426140	3475	232	47A
0005434876699	3475	233	47D
0005434876696	3475	234	47F
0005434426133	3475	235	48A
0005435625898	3475	236	47K
0005434876681	3475	237	47H
0005432613794	3475	238	48C
0005434937815	3475	239	48H
0005434876743	3475	240	48G
0005434876668	3475	241	49A
0005434876657	3475	242	48K
0005435125703	3475	243	49D
0005435625893	3475	244	49F
0005435625881	3475	245	49K
0005432798986	3475	246	49H
0005435125724	3475	247	50A
0005434876702	3475	248	50E
0005434426141	3475	249	50D
0005434876725	3475	250	50G
0005435125696	3475	251	50F
0005434426135	3475	252	50K
0005434876654	3475	253	51F
0005435902405	14534	1	13F
0005435913855	14534	2	14E
0005435902404	14534	3	15A
0005435902416	14534	4	17H
0005435913851	14534	5	19B
0005435902402	14534	6	19F
0005435842313	14534	7	19K
0005435902418	14534	8	21J
0005432059472	14534	9	23B
0005435902408	14534	10	23C
0005435902419	14534	11	23H
0005435902415	14534	12	27B
0005435913852	14534	13	29G
0005435914681	14534	14	30H
0005435902420	14534	15	32F
0005435902413	14534	16	32K
0005435902417	14534	17	33D
0005435913856	14534	18	33G
0005435842311	14534	19	37K
0005435902406	14534	20	39F
0005435902403	14534	21	40J
0005435914682	14534	22	41D
0005435902412	14534	23	42C
0005435902414	14534	24	42F
0005435913853	14534	25	43A
0005435902411	14534	26	44B
0005435913857	14534	27	44A
0005435913854	14534	28	44K
0005435902409	14534	29	46G
0005435902407	14534	30	47D
0005435902410	14534	31	48C
0005435842312	14534	32	48H
0005434325461	3638	1	1A
0005434325462	3638	2	2D
0005434312283	3638	3	4C
0005434325457	3638	4	5D
0005434325456	3638	5	6B
0005434325463	3638	6	6C
0005434325459	3638	7	7D
0005434325460	3638	8	19D
0005434325464	3638	9	20B
0005434325458	3638	10	20D
0005434312284	3638	11	21A
0005434325465	3638	12	22C
0005435889798	15599	1	2C
0005435889800	15599	2	3D
0005435889796	15599	3	4C
0005435889795	15599	4	5A
0005435889794	15599	5	6A
0005435889799	15599	6	20C
0005435889797	15599	7	20D
0005435957455	616	1	1D
0005435957465	616	2	2C
0005435957454	616	3	2D
0005435957463	616	4	4D
0005435957466	616	5	6B
0005435957461	616	6	6C
0005435957468	616	7	18A
0005435957462	616	8	19B
0005435957457	616	9	19D
0005435957456	616	10	20B
0005435957464	616	11	21B
0005435957458	616	12	21D
0005435957459	616	13	22A
0005435957467	616	14	22B
0005435957460	616	15	23B
0005433420261	15158	1	2D
0005433420263	15158	2	5C
0005433420258	15158	3	7C
0005433420260	15158	4	18C
0005433420259	15158	5	19C
0005433420264	15158	6	20C
0005433420262	15158	7	21C
0005433420265	15158	8	23B
0005435629384	8875	1	3A
0005434247104	16101	1	4A
0005434247103	16101	2	6B
0005435797249	2872	1	3A
0005435797247	2872	2	4C
0005435797238	2872	3	4D
0005435797240	2872	4	6D
0005435797250	2872	5	6F
0005435797242	2872	6	8F
0005435797237	2872	7	10A
0005435797246	2872	8	11D
0005435797248	2872	9	13A
0005435797241	2872	10	14E
0005435797251	2872	11	15D
0005435797244	2872	12	16E
0005435797239	2872	13	17A
0005435797243	2872	14	18C
0005435797245	2872	15	20F
0005433404687	29307	1	6D
0005433404688	29307	2	8C
0005433404689	29307	3	10D
0005433404686	29307	4	16A
0005433404690	29307	5	16C
0005433404685	29307	6	19D
0005433404684	29307	7	19F
0005434947879	5830	1	1A
0005434947884	5830	2	1B
0005434947881	5830	3	2A
0005434947876	5830	4	2B
0005434947882	5830	5	3B
0005434947875	5830	6	4A
0005434947878	5830	7	5A
0005434947877	5830	8	6A
0005434947883	5830	9	5B
0005434947880	5830	10	6B
0005433959919	6890	1	1A
0005433959944	6890	2	1F
0005433959942	6890	3	2C
0005433959954	6890	4	2F
0005433959957	6890	5	3A
0005433959927	6890	6	3C
0005433959908	6890	7	3F
0005433959962	6890	8	4A
0005433959959	6890	9	4C
0005433959947	6890	10	4D
0005433959934	6890	11	4E
0005433959905	6890	12	4F
0005433959906	6890	13	5C
0005433959931	6890	14	5D
0005433959915	6890	15	5E
0005433959949	6890	16	5F
0005433959943	6890	17	6A
0005433959909	6890	18	6D
0005433959913	6890	19	6E
0005433959918	6890	20	7C
0005433959940	6890	21	8A
0005433959951	6890	22	9A
0005433959928	6890	23	9C
0005433959956	6890	24	9D
0005433959933	6890	25	9E
0005433959937	6890	26	9F
0005433959904	6890	27	10A
0005433959914	6890	28	10D
0005433959912	6890	29	10E
0005433959955	6890	30	11A
0005433959924	6890	31	11C
0005433959945	6890	32	11D
0005433959960	6890	33	11E
0005433959936	6890	34	12D
0005433959907	6890	35	12F
0005433959946	6890	36	13A
0005433959926	6890	37	13D
0005433959941	6890	38	13E
0005433959953	6890	39	14C
0005433959932	6890	40	14D
0005433959930	6890	41	14E
0005433959952	6890	42	15A
0005433959948	6890	43	15C
0005433959916	6890	44	15D
0005433959961	6890	45	15E
0005433959963	6890	46	15F
0005433959935	6890	47	16A
0005433959917	6890	48	16D
0005433959929	6890	49	16F
0005433959950	6890	50	17A
0005433959910	6890	51	17D
0005433959922	6890	52	17E
0005433959920	6890	53	18C
0005433959923	6890	54	18F
0005433959958	6890	55	19A
0005433959911	6890	56	19D
0005433959925	6890	57	19F
0005433959921	6890	58	20A
0005433959938	6890	59	20C
0005433959939	6890	60	20D
0005435082646	26091	1	1A
0005435082647	26091	2	2A
0005435082648	26091	3	2B
0005435082643	26091	4	3B
0005435082644	26091	5	5B
0005435082649	26091	6	6A
0005435082645	26091	7	6B
0005434244507	5142	1	3A
0005434244484	5142	2	5C
0005434244503	5142	3	7D
0005434244492	5142	4	7F
0005434244494	5142	5	8A
0005432166848	5142	6	8E
0005434244511	5142	7	8F
0005434244488	5142	8	9F
0005434244505	5142	9	10B
0005434244501	5142	10	11B
0005434244514	5142	11	11E
0005434244489	5142	12	13E
0005432166849	5142	13	14C
0005434244508	5142	14	15D
0005434244502	5142	15	17A
0005434244495	5142	16	18A
0005434244493	5142	17	20A
0005432166846	5142	18	20E
0005434244509	5142	19	21C
0005434244491	5142	20	21D
0005434244486	5142	21	21F
0005434244504	5142	22	22D
0005434244499	5142	23	23A
0005434244490	5142	24	23D
0005434244512	5142	25	24E
0005434244513	5142	26	24F
0005434244497	5142	27	25B
0005434244498	5142	28	25F
0005434244510	5142	29	27B
0005434244500	5142	30	27C
0005434244487	5142	31	27F
0005434244496	5142	32	29A
0005432166847	5142	33	29C
0005434244485	5142	34	29E
0005434244506	5142	35	30B
0005432104764	5141	1	1C
0005432104777	5141	2	1A
0005432104804	5141	3	1D
0005433613535	5141	4	2A
0005433613502	5141	5	1F
0005433613468	5141	6	2C
0005433613517	5141	7	2D
0005432104772	5141	8	3A
0005433613509	5141	9	2F
0005432104775	5141	10	3C
0005433613513	5141	11	3F
0005432104781	5141	12	3D
0005433784347	5141	13	4A
0005432104798	5141	14	4C
0005433613495	5141	15	4F
0005433613463	5141	16	4D
0005433784340	5141	17	5A
0005432104784	5141	18	5C
0005433613528	5141	19	5D
0005433613519	5141	20	6A
0005433613533	5141	21	5F
0005433613488	5141	22	6C
0005433613491	5141	23	6F
0005433613486	5141	24	6D
0005432104779	5141	25	7A
0005433613525	5141	26	7C
0005433613477	5141	27	7F
0005433784329	5141	28	7D
0005433784362	5141	29	8A
0005433613480	5141	30	8B
0005433613510	5141	31	8D
0005432666354	5141	32	8C
0005433613467	5141	33	8E
0005433613485	5141	34	8F
0005433613529	5141	35	9B
0005432104799	5141	36	9A
0005432104761	5141	37	9C
0005433784349	5141	38	9D
0005432667420	5141	39	9F
0005433784332	5141	40	9E
0005432667418	5141	41	10A
0005432104770	5141	42	10B
0005433784357	5141	43	10D
0005433784345	5141	44	10C
0005433613505	5141	45	10E
0005433784353	5141	46	10F
0005433613479	5141	47	11A
0005433613516	5141	48	11C
0005432104803	5141	49	11B
0005433784358	5141	50	11D
0005432104763	5141	51	11E
0005433613490	5141	52	11F
0005433784365	5141	53	12B
0005433613527	5141	54	12A
0005432104802	5141	55	12D
0005432104805	5141	56	12C
0005433613464	5141	57	12E
0005433613487	5141	58	12F
0005433784336	5141	59	13B
0005433613489	5141	60	13A
0005433613508	5141	61	13C
0005433784330	5141	62	13D
0005432104806	5141	63	13F
0005433613469	5141	64	13E
0005433613492	5141	65	14A
0005433613493	5141	66	14D
0005433613523	5141	67	14C
0005432104762	5141	68	14E
0005433613532	5141	69	14F
0005432104786	5141	70	15B
0005433784351	5141	71	15A
0005432104787	5141	72	15C
0005433784334	5141	73	15E
0005433613507	5141	74	15D
0005432104789	5141	75	16A
0005432104785	5141	76	15F
0005433613476	5141	77	16C
0005433784342	5141	78	16B
0005433784337	5141	79	16D
0005432145078	5141	80	16E
0005432104801	5141	81	16F
0005433613471	5141	82	17A
0005433613515	5141	83	17C
0005433613499	5141	84	17B
0005433613461	5141	85	17E
0005432104771	5141	86	17D
0005433613494	5141	87	17F
0005433784363	5141	88	18A
0005433784344	5141	89	18C
0005433613526	5141	90	18B
0005433784366	5141	91	18E
0005432104800	5141	92	18D
0005433784350	5141	93	19B
0005433613498	5141	94	18F
0005433784354	5141	95	19D
0005433613506	5141	96	19C
0005432104807	5141	97	20A
0005432104793	5141	98	19E
0005432104766	5141	99	20B
0005432104778	5141	100	20C
0005433784331	5141	101	20E
0005432104767	5141	102	20D
0005432104765	5141	103	20F
0005433613465	5141	104	21B
0005432104783	5141	105	21A
0005433613462	5141	106	21D
0005433613521	5141	107	21C
0005432104760	5141	108	21E
0005432104791	5141	109	21F
0005433613482	5141	110	22A
0005433613512	5141	111	22C
0005433784360	5141	112	22B
0005433613474	5141	113	22D
0005433613497	5141	114	22F
0005432104776	5141	115	22E
0005432104795	5141	116	23A
0005433613520	5141	117	23C
0005433784343	5141	118	23B
0005433613500	5141	119	23D
0005433784335	5141	120	23F
0005432104774	5141	121	23E
0005432104796	5141	122	24A
0005432104782	5141	123	24B
0005433613501	5141	124	24D
0005433784348	5141	125	24C
0005433613466	5141	126	24F
0005433613524	5141	127	24E
0005433613496	5141	128	25B
0005432104769	5141	129	25A
0005433613470	5141	130	25C
0005432104797	5141	131	25E
0005433784352	5141	132	25D
0005433613478	5141	133	25F
0005432104780	5141	134	26A
0005433613518	5141	135	26B
0005433613514	5141	136	26C
0005433784364	5141	137	26E
0005433784361	5141	138	26D
0005432665240	5141	139	26F
0005433784333	5141	140	27B
0005433784356	5141	141	27A
0005433613472	5141	142	27C
0005433784341	5141	143	27D
0005432104808	5141	144	27E
0005432104768	5141	145	28A
0005433613530	5141	146	27F
0005432104788	5141	147	28C
0005433613484	5141	148	28B
0005433613511	5141	149	28E
0005432104792	5141	150	28D
0005433784359	5141	151	28F
0005433613473	5141	152	29B
0005433613531	5141	153	29A
0005433613534	5141	154	29C
0005433613504	5141	155	29D
0005433784338	5141	156	29F
0005433613483	5141	157	29E
0005432104790	5141	158	30A
0005433784339	5141	159	30B
0005432104773	5141	160	30C
0005433613522	5141	161	30E
0005433613481	5141	162	30D
0005433613475	5141	163	30F
0005432667419	5141	164	31A
0005433784346	5141	165	31C
0005432104794	5141	166	31B
0005433613503	5141	167	31D
0005432665239	5141	168	31F
0005433784355	5141	169	31E
0005434229008	5137	1	1C
0005434149543	5137	2	1F
0005434264708	5137	3	2C
0005434149535	5137	4	2F
0005434228990	5137	5	4A
0005434149532	5137	6	4C
0005434229005	5137	7	5D
0005434264727	5137	8	5C
0005434229006	5137	9	5F
0005434173452	5137	10	6F
0005434264726	5137	11	7D
0005434228992	5137	12	8D
0005434264712	5137	13	8F
0005434149534	5137	14	9B
0005434229011	5137	15	9A
0005434264719	5137	16	9D
0005434264703	5137	17	10B
0005434229002	5137	18	10D
0005434264711	5137	19	11A
0005434228995	5137	20	11C
0005434264723	5137	21	11D
0005434264710	5137	22	11F
0005434264705	5137	23	12B
0005434264715	5137	24	12C
0005434228997	5137	25	12E
0005434173454	5137	26	12F
0005434229000	5137	27	13D
0005434264707	5137	28	13E
0005434264718	5137	29	14A
0005434229004	5137	30	14D
0005434228996	5137	31	14E
0005434264724	5137	32	15A
0005434229009	5137	33	15B
0005434149542	5137	34	15D
0005434149541	5137	35	15F
0005434228989	5137	36	16D
0005434264706	5137	37	17E
0005434264713	5137	38	17F
0005434149540	5137	39	18C
0005434149537	5137	40	18F
0005434149538	5137	41	19C
0005434228998	5137	42	20E
0005434264720	5137	43	21F
0005434173455	5137	44	22A
0005434264717	5137	45	22C
0005434229010	5137	46	22D
0005434264709	5137	47	23B
0005434264714	5137	48	23A
0005434228994	5137	49	24A
0005434264725	5137	50	25D
0005434264722	5137	51	26C
0005434229001	5137	52	26B
0005434149539	5137	53	27B
0005434229003	5137	54	27C
0005434173453	5137	55	28C
0005434264702	5137	56	29B
0005434228999	5137	57	29D
0005434229007	5137	58	29E
0005434264716	5137	59	29F
0005434264721	5137	60	30C
0005434264704	5137	61	30E
0005434149533	5137	62	30D
0005434228993	5137	63	30F
0005434228991	5137	64	31C
0005434149536	5137	65	31D
0005435269643	8602	1	4F
0005435269647	8602	2	8F
0005435269645	8602	3	10D
0005435269646	8602	4	12C
0005435269644	8602	5	15F
0005432034495	8600	1	1F
0005433815308	8600	2	2C
0005432034481	8600	3	2F
0005432335835	8600	4	2D
0005432034485	8600	5	3A
0005432034492	8600	6	3D
0005433689877	8600	7	3C
0005435286544	8600	8	4F
0005432335843	8600	9	5A
0005432034479	8600	10	5C
0005435006635	8600	11	6C
0005433690893	8600	12	6F
0005435006634	8600	13	6D
0005432335841	8600	14	7A
0005432034503	8600	15	7C
0005433688776	8600	16	7F
0005435286548	8600	17	8A
0005432047488	8600	18	8C
0005435006645	8600	19	8B
0005432047491	8600	20	8D
0005435286547	8600	21	8F
0005435006623	8600	22	9B
0005432034490	8600	23	10A
0005435006639	8600	24	10B
0005435006644	8600	25	10D
0005432335833	8600	26	10E
0005432034505	8600	27	11A
0005435006642	8600	28	10F
0005432034482	8600	29	11B
0005432335837	8600	30	11C
0005432335834	8600	31	11F
0005432335836	8600	32	11E
0005432034496	8600	33	12B
0005435006621	8600	34	12E
0005435006628	8600	35	12F
0005432034488	8600	36	13A
0005433815306	8600	37	13D
0005435286545	8600	38	14A
0005435286539	8600	39	13F
0005435006631	8600	40	14B
0005432034497	8600	41	14E
0005435006641	8600	42	15A
0005433815309	8600	43	14F
0005432034484	8600	44	16B
0005435006629	8600	45	16E
0005432034491	8600	46	17A
0005432034504	8600	47	16F
0005432034486	8600	48	17C
0005435006636	8600	49	17E
0005435286542	8600	50	18B
0005435286541	8600	51	18D
0005435006625	8600	52	18E
0005435006630	8600	53	18F
0005432335832	8600	54	19C
0005435006632	8600	55	19D
0005432047489	8600	56	20A
0005432034502	8600	57	20E
0005434311184	8600	58	21A
0005435286538	8600	59	20F
0005435286540	8600	60	21C
0005432335839	8600	61	22B
0005432034498	8600	62	22D
0005435006640	8600	63	22F
0005435006633	8600	64	23D
0005432034500	8600	65	23C
0005432034501	8600	66	23E
0005432335844	8600	67	23F
0005432034478	8600	68	24B
0005432335838	8600	69	24E
0005435006626	8600	70	24F
0005435286546	8600	71	25B
0005433815307	8600	72	25C
0005432034489	8600	73	25F
0005435006622	8600	74	25E
0005432034499	8600	75	26A
0005433689876	8600	76	26C
0005435006637	8600	77	26E
0005432047490	8600	78	27B
0005432034480	8600	79	27D
0005432047487	8600	80	28A
0005432335842	8600	81	28D
0005432034483	8600	82	28E
0005432335840	8600	83	28F
0005432034493	8600	84	29B
0005435006638	8600	85	29A
0005435006646	8600	86	29E
0005435006627	8600	87	29D
0005435006643	8600	88	29C
0005435006624	8600	89	30A
0005432034494	8600	90	30C
0005434311183	8600	91	30E
0005432034487	8600	92	30D
0005435286543	8600	93	31E
0005433202129	12625	1	1C
0005433202125	12625	2	2D
0005433202123	12625	3	3D
0005433202126	12625	4	4A
0005433202130	12625	5	4D
0005433202127	12625	6	5A
0005433202122	12625	7	5B
0005433202120	12625	8	5D
0005433202131	12625	9	6B
0005433202124	12625	10	7A
0005433202132	12625	11	19C
0005433202128	12625	12	21B
0005433202118	12625	13	21D
0005433202117	12625	14	22B
0005433202121	12625	15	23A
0005433202119	12625	16	23B
0005434638853	23345	1	1A
0005434638874	23345	2	1B
0005434638854	23345	3	1C
0005434638850	23345	4	1D
0005432290582	23345	5	2A
0005434638848	23345	6	2B
0005434638852	23345	7	2C
0005432290579	23345	8	3D
0005432290580	23345	9	4B
0005434638862	23345	10	4C
0005434638869	23345	11	5A
0005434638851	23345	12	4D
0005434638875	23345	13	5B
0005434638871	23345	14	5C
0005434638855	23345	15	5D
0005434638865	23345	16	6A
0005434638873	23345	17	6B
0005432290581	23345	18	6C
0005434638868	23345	19	6D
0005434638870	23345	20	7A
0005434638861	23345	21	7B
0005434638858	23345	22	18B
0005434638856	23345	23	18C
0005434638846	23345	24	19A
0005434638867	23345	25	19B
0005434638860	23345	26	19C
0005434638859	23345	27	20C
0005434638866	23345	28	20D
0005434638872	23345	29	21B
0005434638863	23345	30	21C
0005434638857	23345	31	22A
0005434638849	23345	32	22B
0005434638864	23345	33	22C
0005434638847	23345	34	23B
0005432054255	21096	1	9D
0005432054256	21096	2	12C
0005432054257	21096	3	14F
0005432327901	31264	1	1A
0005432287101	31264	2	1C
0005432327922	31264	3	1D
0005432382510	31264	4	1F
0005432327910	31264	5	2C
0005432327936	31264	6	2D
0005432382504	31264	7	2F
0005432327931	31264	8	3C
0005432327897	31264	9	3D
0005432382505	31264	10	3F
0005432327892	31264	11	4A
0005432327914	31264	12	4C
0005432382496	31264	13	4D
0005432382511	31264	14	4E
0005432382516	31264	15	4F
0005432382512	31264	16	5A
0005432327915	31264	17	5C
0005432327900	31264	18	5D
0005432382488	31264	19	5E
0005432382500	31264	20	5F
0005432327890	31264	21	6A
0005432382492	31264	22	6C
0005432382495	31264	23	6D
0005432327891	31264	24	6E
0005432382509	31264	25	6F
0005432327920	31264	26	7A
0005432382493	31264	27	7C
0005432327935	31264	28	7D
0005432382485	31264	29	7E
0005432327909	31264	30	7F
0005432327893	31264	31	8A
0005432327932	31264	32	8C
0005432327906	31264	33	8D
0005432327929	31264	34	8E
0005432382513	31264	35	8F
0005432327913	31264	36	9A
0005432327908	31264	37	9C
0005432327923	31264	38	9D
0005432327926	31264	39	9F
0005432382497	31264	40	10A
0005432327896	31264	41	10C
0005432287099	31264	42	10D
0005432327924	31264	43	10E
0005432382520	31264	44	10F
0005432327912	31264	45	11A
0005432382514	31264	46	11C
0005432287102	31264	47	11D
0005432382518	31264	48	11E
0005432382517	31264	49	11F
0005432327937	31264	50	12A
0005432287104	31264	51	12C
0005432327930	31264	52	12D
0005432382508	31264	53	12E
0005432382501	31264	54	12F
0005432287103	31264	55	13A
0005432382484	31264	56	13C
0005432382502	31264	57	13D
0005432382491	31264	58	13E
0005432382494	31264	59	13F
0005432327916	31264	60	14A
0005432327927	31264	61	14C
0005432327928	31264	62	14D
0005432382486	31264	63	14E
0005432382507	31264	64	14F
0005432327905	31264	65	15A
0005432287105	31264	66	15C
0005432382506	31264	67	15D
0005432382487	31264	68	15E
0005432327898	31264	69	15F
0005432382503	31264	70	16A
0005432327933	31264	71	16C
0005432327904	31264	72	16D
0005432382519	31264	73	16E
0005432327903	31264	74	16F
0005432327902	31264	75	17A
0005432327934	31264	76	17D
0005432327919	31264	77	17E
0005432327918	31264	78	17F
0005432382490	31264	79	18A
0005432327895	31264	80	18C
0005432382489	31264	81	18D
0005432382515	31264	82	18E
0005432327907	31264	83	18F
0005432327911	31264	84	19A
0005432327921	31264	85	19C
0005432287100	31264	86	19D
0005432327899	31264	87	19E
0005432382499	31264	88	19F
0005432327917	31264	89	20A
0005432327894	31264	90	20C
0005432382498	31264	91	20E
0005432327925	31264	92	20F
0005432423644	13305	1	1A
0005432423643	13305	2	1F
0005432423636	13305	3	2A
0005432423645	13305	4	3A
0005432423647	13305	5	3C
0005432423614	13305	6	4A
0005432423605	13305	7	4F
0005432423613	13305	8	5E
0005432423639	13305	9	5F
0005432423616	13305	10	6C
0005432423615	13305	11	6F
0005432423604	13305	12	7C
0005432423631	13305	13	7F
0005432423621	13305	14	8E
0005432423629	13305	15	8F
0005432423626	13305	16	9C
0005432423612	13305	17	9D
0005432423607	13305	18	9E
0005432423627	13305	19	10A
0005432423618	13305	20	10E
0005432423609	13305	21	11D
0005432423640	13305	22	12D
0005432423622	13305	23	13D
0005432423617	13305	24	13F
0005432423606	13305	25	14D
0005432423637	13305	26	15A
0005432423632	13305	27	15C
0005432423630	13305	28	15D
0005432423608	13305	29	16C
0005432423624	13305	30	16D
0005432423628	13305	31	16E
0005432423638	13305	32	16F
0005432423633	13305	33	17A
0005432423623	13305	34	17E
0005432423642	13305	35	17F
0005432423611	13305	36	18A
0005432423620	13305	37	18C
0005432423635	13305	38	18D
0005432423625	13305	39	18F
0005432423610	13305	40	19A
0005432423619	13305	41	19E
0005432423641	13305	42	20A
0005432423634	13305	43	20C
0005432423646	13305	44	20D
0005432816992	9586	1	1A
0005432822074	9586	2	1F
0005434448259	9586	3	2A
0005432816968	9586	4	2C
0005432816972	9586	5	2F
0005432822077	9586	6	3A
0005434448257	9586	7	4C
0005432816971	9586	8	5F
0005432816994	9586	9	6A
0005432816985	9586	10	6C
0005434448260	9586	11	6D
0005432816978	9586	12	7C
0005432288930	9586	13	7D
0005432816967	9586	14	7F
0005432816976	9586	15	8A
0005432816983	9586	16	8D
0005432816970	9586	17	9E
0005432288933	9586	18	9F
0005432822079	9586	19	10C
0005432822075	9586	20	10D
0005432816997	9586	21	11A
0005432816969	9586	22	10F
0005432816982	9586	23	11C
0005432816991	9586	24	12E
0005432816996	9586	25	12F
0005432816973	9586	26	13C
0005432816975	9586	27	13F
0005432816974	9586	28	14A
0005432816977	9586	29	14C
0005434448258	9586	30	14D
0005432816990	9586	31	14E
0005432816988	9586	32	15D
0005432822076	9586	33	15E
0005432816995	9586	34	15F
0005432816979	9586	35	16C
0005432816987	9586	36	16E
0005432822078	9586	37	17D
0005432288932	9586	38	18A
0005432816984	9586	39	18C
0005432822073	9586	40	18E
0005432816993	9586	41	18F
0005432816986	9586	42	19A
0005432288931	9586	43	20A
0005432816989	9586	44	20C
0005432816980	9586	45	20D
0005432816981	9586	46	20F
0005434157350	28956	1	1D
0005432901312	28956	2	2C
0005432901322	28956	3	2D
0005432901321	28956	4	2F
0005432901317	28956	5	3A
0005432901328	28956	6	3F
0005434186147	28956	7	4C
0005432901325	28956	8	4F
0005434157349	28956	9	5D
0005434157352	28956	10	6A
0005432002042	28956	11	6C
0005434157347	28956	12	6E
0005432002043	28956	13	7C
0005432901318	28956	14	7D
0005432901327	28956	15	8C
0005434157353	28956	16	9E
0005432901315	28956	17	9F
0005434157355	28956	18	10E
0005432901324	28956	19	12E
0005432901316	28956	20	13C
0005432901326	28956	21	13F
0005432901323	28956	22	14D
0005434157354	28956	23	14F
0005434186149	28956	24	15F
0005432901313	28956	25	17D
0005434186148	28956	26	17E
0005432901320	28956	27	17F
0005432901314	28956	28	19A
0005434157351	28956	29	20A
0005434157348	28956	30	20C
0005432901319	28956	31	20E
0005432613795	15046	1	1A
0005432611642	15046	2	2B
0005432613794	15046	3	2A
0005432613796	15046	4	3A
0005432611644	15046	5	3B
0005432611646	15046	6	4A
0005432611643	15046	7	5A
0005432611645	15046	8	5B
0005432613793	15046	9	6A
0005435842311	31614	1	1B
0005435842312	31614	2	3A
0005435842313	31614	3	3B
0005433568046	11845	1	1C
0005433568047	11845	2	2A
0005433568026	11845	3	3C
0005433568015	11845	4	4A
0005433568049	11845	5	3F
0005433568055	11845	6	4C
0005433568025	11845	7	5F
0005433568033	11845	8	6A
0005433568051	11845	9	6C
0005433568028	11845	10	6B
0005433568044	11845	11	6E
0005433568065	11845	12	7C
0005433568036	11845	13	7D
0005433568067	11845	14	8B
0005433568042	11845	15	8C
0005433568043	11845	16	8F
0005433568062	11845	17	9A
0005433568021	11845	18	9D
0005433568041	11845	19	9C
0005433568016	11845	20	9B
0005433568048	11845	21	9F
0005433568050	11845	22	10B
0005433568023	11845	23	10E
0005433568068	11845	24	10D
0005433568061	11845	25	10F
0005433568064	11845	26	11C
0005433568038	11845	27	11D
0005433568035	11845	28	12B
0005433568024	11845	29	12C
0005433568052	11845	30	12E
0005433568037	11845	31	13D
0005433568032	11845	32	13F
0005433568058	11845	33	14B
0005433568040	11845	34	14A
0005433568053	11845	35	14C
0005433568059	11845	36	15B
0005433568031	11845	37	15A
0005433568039	11845	38	15F
0005433568063	11845	39	16E
0005433568030	11845	40	16D
0005433568027	11845	41	17B
0005433568017	11845	42	17D
0005433568022	11845	43	17C
0005433568066	11845	44	17F
0005433568060	11845	45	18C
0005433568054	11845	46	19A
0005433568019	11845	47	19C
0005433568018	11845	48	19B
0005433568056	11845	49	19D
0005433568029	11845	50	19F
0005433568057	11845	51	20D
0005433568020	11845	52	20E
0005433568034	11845	53	21F
0005433568045	11845	54	21D
0005432947818	25291	1	2F
0005432947821	25291	2	3A
0005432947822	25291	3	3D
0005432947829	25291	4	3C
0005432947842	25291	5	3F
0005432947845	25291	6	5C
0005432947833	25291	7	5A
0005432947837	25291	8	6C
0005432947831	25291	9	6D
0005432947816	25291	10	7E
0005432947828	25291	11	8C
0005432947835	25291	12	8E
0005432947826	25291	13	9A
0005432947809	25291	14	9E
0005432947810	25291	15	10C
0005432947836	25291	16	10E
0005432947807	25291	17	10F
0005432947840	25291	18	11C
0005432947844	25291	19	11F
0005432947815	25291	20	11E
0005432947839	25291	21	12C
0005432947843	25291	22	12B
0005432947814	25291	23	13D
0005432947832	25291	24	13F
0005432947841	25291	25	14B
0005432947820	25291	26	14A
0005432947819	25291	27	14D
0005432947830	25291	28	14F
0005432947823	25291	29	15D
0005432947834	25291	30	16A
0005432947838	25291	31	16F
0005432947806	25291	32	17B
0005432947817	25291	33	17F
0005432947825	25291	34	18B
0005432947805	25291	35	18D
0005432947813	25291	36	19A
0005432947808	25291	37	19D
0005432947824	25291	38	20A
0005432947811	25291	39	20E
0005432947827	25291	40	21D
0005432947812	25291	41	21C
0005434654217	5367	1	1A
0005434654214	5367	2	1D
0005434654190	5367	3	1F
0005434654199	5367	4	2A
0005434654205	5367	5	2F
0005434654215	5367	6	4C
0005434654204	5367	7	4D
0005432114150	5367	8	4E
0005434654202	5367	9	4F
0005432114149	5367	10	5C
0005434654200	5367	11	5E
0005434656523	5367	12	6A
0005434654201	5367	13	6D
0005434654213	5367	14	6F
0005434654198	5367	15	7F
0005434656522	5367	16	9A
0005434654207	5367	17	9C
0005434654216	5367	18	9D
0005434654193	5367	19	9F
0005434654194	5367	20	10C
0005434654212	5367	21	10D
0005434654218	5367	22	10F
0005434654196	5367	23	11E
0005434654195	5367	24	12A
0005434654208	5367	25	14C
0005434654189	5367	26	14E
0005434654209	5367	27	14F
0005434654197	5367	28	15A
0005434654192	5367	29	16D
0005434654203	5367	30	16E
0005434654211	5367	31	19A
0005434654206	5367	32	19C
0005434654210	5367	33	20A
0005434654191	5367	34	20E
0005435340013	12534	1	2C
0005435340016	12534	2	3D
0005435340015	12534	3	4A
0005435340008	12534	4	4D
0005435340010	12534	5	5C
0005435340018	12534	6	9E
0005435340006	12534	7	10C
0005435555337	12534	8	11C
0005435340014	12534	9	13C
0005435340017	12534	10	14F
0005435340011	12534	11	15A
0005435340007	12534	12	15F
0005435340004	12534	13	16E
0005435340012	12534	14	18E
0005435340009	12534	15	19C
0005435340005	12534	16	19D
0005435555336	12534	17	19F
0005433689875	7431	1	1A
0005433715123	7431	2	1D
0005433715121	7431	3	2A
0005433715137	7431	4	2D
0005433715159	7431	5	2F
0005433715120	7431	6	3C
0005433722102	7431	7	4B
0005433715126	7431	8	4A
0005433715146	7431	9	4E
0005433715129	7431	10	4F
0005433715125	7431	11	5A
0005433715147	7431	12	5C
0005433715151	7431	13	5D
0005433715157	7431	14	5E
0005433715118	7431	15	5F
0005433722104	7431	16	6B
0005433688773	7431	17	6F
0005433722103	7431	18	7B
0005433715158	7431	19	7D
0005433715134	7431	20	7F
0005433715116	7431	21	8A
0005433656613	7431	22	8B
0005433715135	7431	23	8D
0005433715132	7431	24	8C
0005433715155	7431	25	8E
0005433715150	7431	26	8F
0005433715124	7431	27	9A
0005433690892	7431	28	9C
0005433715128	7431	29	9D
0005433715139	7431	30	9F
0005433715145	7431	31	10B
0005433715131	7431	32	10C
0005433715133	7431	33	10E
0005433688775	7431	34	11B
0005433715153	7431	35	11F
0005433715122	7431	36	12B
0005433715152	7431	37	12D
0005433715156	7431	38	12E
0005433715130	7431	39	12F
0005433715136	7431	40	13B
0005433715164	7431	41	13C
0005433715154	7431	42	13F
0005433715162	7431	43	14B
0005433715119	7431	44	14D
0005433715148	7431	45	14E
0005433656614	7431	46	14F
0005433688774	7431	47	15D
0005433715140	7431	48	15E
0005433715163	7431	49	15F
0005432078016	7431	50	16B
0005433715160	7431	51	16A
0005433719081	7431	52	16C
0005433719082	7431	53	16F
0005433715143	7431	54	17A
0005433722106	7431	55	17C
0005433715144	7431	56	17D
0005433719083	7431	57	17F
0005433715127	7431	58	18B
0005433715149	7431	59	18A
0005432078018	7431	60	18D
0005433689874	7431	61	18C
0005433715138	7431	62	18E
0005433715161	7431	63	18F
0005433715166	7431	64	19C
0005433690891	7431	65	19D
0005433690890	7431	66	19F
0005433715167	7431	67	20C
0005433715165	7431	68	20E
0005433722105	7431	69	21A
0005433715141	7431	70	21C
0005433715142	7431	71	21E
0005433715117	7431	72	21F
0005433719080	7431	73	22F
0005432078017	7431	74	23C
0005432006711	29207	1	1C
0005432428871	29207	2	7E
0005432428872	29207	3	12E
0005432006713	29207	4	19B
0005432428870	29207	5	19D
0005432006712	29207	6	19F
0005432428873	29207	7	20A
0005434095031	8697	1	1A
0005434095030	8697	2	3A
0005434095038	8697	3	6D
0005434095036	8697	4	7D
0005434095035	8697	5	8F
0005434095041	8697	6	9E
0005434095033	8697	7	10A
0005434095040	8697	8	11E
0005434095042	8697	9	12D
0005434095043	8697	10	14F
0005434095039	8697	11	15A
0005434095037	8697	12	16D
0005434095032	8697	13	20A
0005434095034	8697	14	20E
0005434181978	11638	1	1C
0005434181981	11638	2	3F
0005434183544	11638	3	4E
0005434181974	11638	4	4F
0005434181969	11638	5	6E
0005434183543	11638	6	6F
0005434181976	11638	7	7A
0005434184629	11638	8	8F
0005434181977	11638	9	9D
0005434184630	11638	10	10D
0005434181973	11638	11	12E
0005434181970	11638	12	13D
0005434183546	11638	13	13F
0005434181972	11638	14	14E
0005434181980	11638	15	16A
0005434181975	11638	16	17F
0005434181979	11638	17	18A
0005434183545	11638	18	19D
0005434181971	11638	19	20E
0005435732127	1430	1	7A
0005432297233	1430	2	8E
0005435732126	1430	3	10A
0005433456901	1430	4	10D
0005433456903	1430	5	10F
0005435732128	1430	6	15F
0005432297234	1430	7	16F
0005435732125	1430	8	17D
0005433456904	1430	9	17E
0005433456902	1430	10	20D
0005433397260	19277	1	1A
0005433397259	19277	2	1D
0005433397254	19277	3	1F
0005433397266	19277	4	2C
0005433397268	19277	5	2F
0005433397233	19277	6	3D
0005433397269	19277	7	4C
0005433397235	19277	8	4E
0005432906495	19277	9	4F
0005433397261	19277	10	6A
0005433397256	19277	11	6C
0005433397253	19277	12	6D
0005433397243	19277	13	6F
0005433397272	19277	14	7A
0005433397234	19277	15	7D
0005433397277	19277	16	7E
0005433397231	19277	17	7F
0005432906493	19277	18	8C
0005433397267	19277	19	8D
0005433397247	19277	20	8F
0005433397237	19277	21	9C
0005433397271	19277	22	9D
0005433397262	19277	23	9F
0005433397230	19277	24	10A
0005433397276	19277	25	10D
0005433397264	19277	26	10E
0005433397245	19277	27	10F
0005433397275	19277	28	11A
0005433397274	19277	29	11D
0005433397241	19277	30	11E
0005433397229	19277	31	11F
0005433397250	19277	32	12E
0005433397255	19277	33	12F
0005433397232	19277	34	13A
0005433397246	19277	35	13D
0005433397240	19277	36	14C
0005433397251	19277	37	14F
0005433397258	19277	38	15A
0005433397257	19277	39	15C
0005432906494	19277	40	15E
0005433397249	19277	41	16A
0005433397239	19277	42	16E
0005433397270	19277	43	16F
0005433397252	19277	44	17A
0005433397273	19277	45	17F
0005433397244	19277	46	18C
0005433397238	19277	47	18E
0005433397263	19277	48	19A
0005433397242	19277	49	19C
0005433397248	19277	50	19F
0005433397236	19277	51	20A
0005433397265	19277	52	20E
0005434443425	20554	1	2A
0005434443434	20554	2	2C
0005434443432	20554	3	3B
0005434443439	20554	4	3D
0005434443433	20554	5	4A
0005434443435	20554	6	5A
0005434443430	20554	7	5B
0005434443424	20554	8	5D
0005434443426	20554	9	6A
0005434443436	20554	10	7B
0005434443429	20554	11	18C
0005434443438	20554	12	20C
0005434443437	20554	13	21A
0005434443427	20554	14	21C
0005434443431	20554	15	22C
0005434443428	20554	16	22D
0005434954542	7285	1	1A
0005434954541	7285	2	2B
0005434954543	7285	3	3B
0005434954545	7285	4	4A
0005434954544	7285	5	6B
0005435377540	28343	1	2A
0005435377539	28343	2	6B
0005434351483	4494	1	2B
0005434351481	4494	2	2C
0005434351480	4494	3	2D
0005434351488	4494	4	4C
0005434351478	4494	5	5C
0005434351489	4494	6	6D
0005434351486	4494	7	18B
0005434351487	4494	8	18A
0005434351484	4494	9	19B
0005434351485	4494	10	20B
0005434351477	4494	11	21C
0005434351479	4494	12	21D
0005434351482	4494	13	22C
0005435893516	29644	1	1B
0005435893512	29644	2	2C
0005435893510	29644	3	5A
0005435893515	29644	4	5C
0005435893513	29644	5	7B
0005435893511	29644	6	7D
0005435893514	29644	7	22A
0005435893517	29644	8	22D
0005432293166	1076	1	1F
0005434446481	1076	2	2B
0005433463864	1076	3	5H
0005435091904	1076	4	11H
0005435091909	1076	5	12F
0005435091908	1076	6	13D
0005435091903	1076	7	13F
0005433463865	1076	8	14D
0005435091910	1076	9	15D
0005434446477	1076	10	15G
0005434445211	1076	11	17D
0005433462712	1076	12	17G
0005435091907	1076	13	17H
0005433462710	1076	14	18B
0005432293167	1076	15	18G
0005434446480	1076	16	20A
0005434446479	1076	17	20D
0005435091912	1076	18	27A
0005433462711	1076	19	27B
0005434446478	1076	20	28B
0005432293168	1076	21	30H
0005435091905	1076	22	33A
0005435091911	1076	23	33D
0005435091906	1076	24	34F
0005435091902	1076	25	35G
0005433341411	17071	1	1A
0005433341383	17071	2	2A
0005433341394	17071	3	2F
0005433341452	17071	4	2G
0005433341446	17071	5	2H
0005433341437	17071	6	3F
0005433341413	17071	7	3H
0005433341443	17071	8	4B
0005433341467	17071	9	4A
0005433159275	17071	10	4F
0005433341392	17071	11	4G
0005433341439	17071	12	5B
0005433341387	17071	13	5A
0005433341472	17071	14	5F
0005433341400	17071	15	5G
0005433341415	17071	16	9A
0005433341427	17071	17	5H
0005433341436	17071	18	9B
0005433341465	17071	19	11A
0005433341421	17071	20	11H
0005433341408	17071	21	12A
0005433341440	17071	22	12E
0005433341459	17071	23	12D
0005433341466	17071	24	12F
0005433341473	17071	25	13D
0005433269630	17071	26	13G
0005433341423	17071	27	13F
0005433341395	17071	28	14B
0005433341462	17071	29	14F
0005433341435	17071	30	14G
0005433341438	17071	31	15D
0005433341461	17071	32	15H
0005433341401	17071	33	16B
0005433159274	17071	34	16E
0005433269627	17071	35	16G
0005433341451	17071	36	16F
0005433341444	17071	37	16H
0005433341420	17071	38	17A
0005433341454	17071	39	17G
0005433341479	17071	40	18B
0005433341425	17071	41	18E
0005433159276	17071	42	18D
0005433269626	17071	43	19A
0005433341419	17071	44	19B
0005433341379	17071	45	19F
0005433341393	17071	46	19H
0005433341434	17071	47	19G
0005433341402	17071	48	20A
0005433341406	17071	49	20E
0005433341409	17071	50	20D
0005433341453	17071	51	20F
0005433341417	17071	52	20H
0005433341458	17071	53	21A
0005433341475	17071	54	21D
0005433341460	17071	55	21E
0005433341450	17071	56	21G
0005433341388	17071	57	21F
0005433341469	17071	58	22A
0005433341391	17071	59	22D
0005433341405	17071	60	22E
0005433341441	17071	61	22G
0005433341416	17071	62	22F
0005433341432	17071	63	22H
0005433341455	17071	64	24D
0005433341447	17071	65	24H
0005433341418	17071	66	25E
0005433341457	17071	67	27B
0005433341381	17071	68	27A
0005433341385	17071	69	27D
0005433341463	17071	70	27F
0005433341397	17071	71	28A
0005433269628	17071	72	28B
0005433341471	17071	73	28G
0005433341474	17071	74	29A
0005433341378	17071	75	28H
0005433341430	17071	76	29H
0005433341384	17071	77	30B
0005433341396	17071	78	30A
0005433341399	17071	79	30D
0005433341431	17071	80	30G
0005433341449	17071	81	30H
0005433341470	17071	82	31B
0005433341382	17071	83	31D
0005433341478	17071	84	31G
0005433341403	17071	85	31H
0005433341422	17071	86	32D
0005433341390	17071	87	32H
0005433341426	17071	88	32G
0005433341445	17071	89	33D
0005433341404	17071	90	33E
0005433341414	17071	91	33F
0005433341429	17071	92	33G
0005433341448	17071	93	34A
0005433341442	17071	94	34D
0005433341468	17071	95	34F
0005433341476	17071	96	35A
0005433269629	17071	97	35B
0005433269625	17071	98	35F
0005433341380	17071	99	35H
0005433341412	17071	100	36A
0005433341410	17071	101	36E
0005433341433	17071	102	36G
0005433341407	17071	103	37A
0005433341424	17071	104	37E
0005433341389	17071	105	37D
0005433341386	17071	106	37F
0005433341456	17071	107	37H
0005433341428	17071	108	38D
0005433341464	17071	109	38F
0005433341398	17071	110	38H
0005433341477	17071	111	39E
0005432433591	12791	1	4E
0005432433588	12791	2	6A
0005432433590	12791	3	6F
0005432159779	12791	4	7B
0005433812860	12791	5	7D
0005432161113	12791	6	8B
0005432161112	12791	7	10E
0005432159783	12791	8	11E
0005432159780	12791	9	12A
0005432159782	12791	10	15B
0005432433589	12791	11	16A
0005432433592	12791	12	18C
0005432159781	12791	13	19F
0005432433587	12791	14	21B
0005433812861	12791	15	23F
0005434066301	30652	1	1A
0005434066347	30652	2	1C
0005434066361	30652	3	1D
0005434081482	30652	4	1F
0005434081477	30652	5	2C
0005434066322	30652	6	2D
0005434066310	30652	7	2F
0005434066319	30652	8	3D
0005434066331	30652	9	3C
0005434066340	30652	10	3F
0005434066308	30652	11	4A
0005434066334	30652	12	4C
0005434081472	30652	13	4B
0005434066363	30652	14	4D
0005434066323	30652	15	4E
0005434066318	30652	16	5A
0005434066351	30652	17	4F
0005434066330	30652	18	5B
0005434066325	30652	19	5C
0005434026670	30652	20	5E
0005434066314	30652	21	5F
0005434066350	30652	22	6B
0005434066303	30652	23	6A
0005432186806	30652	24	6C
0005433989688	30652	25	6D
0005434066364	30652	26	6E
0005434066336	30652	27	6F
0005434081474	30652	28	7A
0005434066317	30652	29	7C
0005432150059	30652	30	7D
0005434066362	30652	31	7E
0005434066313	30652	32	8A
0005434066311	30652	33	7F
0005434066304	30652	34	8C
0005434066333	30652	35	8B
0005434066338	30652	36	8D
0005432150054	30652	37	8F
0005432150056	30652	38	9A
0005434066306	30652	39	9B
0005434066342	30652	40	9C
0005434081473	30652	41	9D
0005434066352	30652	42	9F
0005434066335	30652	43	10C
0005433989689	30652	44	10B
0005434066296	30652	45	10D
0005434066343	30652	46	11A
0005434066316	30652	47	11C
0005433989686	30652	48	11B
0005432150055	30652	49	11F
0005432150061	30652	50	11E
0005434066341	30652	51	12A
0005434066346	30652	52	12D
0005434081476	30652	53	12C
0005434026669	30652	54	12E
0005434066345	30652	55	12F
0005434081484	30652	56	13A
0005434066307	30652	57	13C
0005434066356	30652	58	13B
0005432186805	30652	59	13D
0005434066332	30652	60	13E
0005434066344	30652	61	14A
0005434066300	30652	62	13F
0005434066329	30652	63	14C
0005434066348	30652	64	14E
0005434066297	30652	65	14F
0005434066360	30652	66	15B
0005434066365	30652	67	15A
0005434026671	30652	68	15D
0005433989687	30652	69	15F
0005434066309	30652	70	15E
0005434081470	30652	71	16B
0005434066299	30652	72	16C
0005434081478	30652	73	16D
0005434081483	30652	74	16F
0005434081485	30652	75	16E
0005434066337	30652	76	17A
0005434066324	30652	77	17B
0005434066302	30652	78	17C
0005434066366	30652	79	17E
0005434066315	30652	80	17D
0005434066321	30652	81	18A
0005434081471	30652	82	17F
0005434066328	30652	83	18B
0005432150062	30652	84	18C
0005434066355	30652	85	18E
0005434066295	30652	86	18D
0005434066305	30652	87	19A
0005434066349	30652	88	19B
0005433989685	30652	89	19E
0005434066320	30652	90	19F
0005434066359	30652	91	20B
0005434066339	30652	92	20A
0005434066354	30652	93	20D
0005434066298	30652	94	20C
0005434066357	30652	95	20E
0005432186803	30652	96	20F
0005434066312	30652	97	21A
0005432150057	30652	98	21C
0005434066358	30652	99	21D
0005434081481	30652	100	21F
0005432150058	30652	101	22B
0005434081475	30652	102	22C
0005434081480	30652	103	22D
0005432186804	30652	104	22E
0005434081486	30652	105	23A
0005434066353	30652	106	23B
0005434066326	30652	107	23C
0005434081479	30652	108	23D
0005432150060	30652	109	23F
0005434066327	30652	110	23E
0005435765207	5500	1	1B
0005435723010	5500	2	1G
0005435735056	5500	3	2A
0005435765204	5500	4	3A
0005433527205	5500	5	3B
0005433529217	5500	6	3F
0005435765187	5500	7	3H
0005435765188	5500	8	3G
0005435765182	5500	9	4G
0005435765185	5500	10	5C
0005435765178	5500	11	5H
0005435765194	5500	12	9B
0005435765214	5500	13	9G
0005435735059	5500	14	9H
0005435765192	5500	15	11F
0005435722014	5500	16	11G
0005435765203	5500	17	12F
0005435765195	5500	18	13B
0005435765198	5500	19	13F
0005435725511	5500	20	14B
0005435765202	5500	21	14A
0005432140312	5500	22	14E
0005435725515	5500	23	15F
0005435725514	5500	24	15H
0005435765200	5500	25	16G
0005435765176	5500	26	17B
0005433529214	5500	27	17G
0005435765181	5500	28	17F
0005435765212	5500	29	17H
0005435765172	5500	30	18E
0005435765184	5500	31	18G
0005435725513	5500	32	19B
0005435765189	5500	33	19D
0005435765190	5500	34	19F
0005435765196	5500	35	21A
0005435765191	5500	36	21D
0005435765180	5500	37	21G
0005433527203	5500	38	22E
0005435765197	5500	39	22G
0005435725512	5500	40	23B
0005435765208	5500	41	23E
0005433529218	5500	42	23G
0005435765186	5500	43	24D
0005435765193	5500	44	24G
0005432140308	5500	45	24H
0005435722015	5500	46	25F
0005432140309	5500	47	25D
0005435765213	5500	48	27A
0005432140314	5500	49	27F
0005433527206	5500	50	28H
0005433529216	5500	51	29D
0005435765210	5500	52	29B
0005435765209	5500	53	29E
0005435723009	5500	54	29F
0005435735057	5500	55	30A
0005435765205	5500	56	31E
0005435765183	5500	57	32B
0005435765174	5500	58	32A
0005432140310	5500	59	32E
0005432140311	5500	60	32D
0005435765211	5500	61	32G
0005435765173	5500	62	33G
0005433529215	5500	63	34A
0005435720802	5500	64	35E
0005435765179	5500	65	36A
0005432140313	5500	66	35H
0005435765199	5500	67	36G
0005435735055	5500	68	37A
0005435765177	5500	69	36H
0005435765201	5500	70	37D
0005435735058	5500	71	37F
0005433527204	5500	72	38A
0005435720801	5500	73	38D
0005435725516	5500	74	38B
0005435765175	5500	75	38E
0005435722016	5500	76	38F
0005435765206	5500	77	39E
0005434831073	13477	1	1A
0005432194443	13477	2	1C
0005432535750	13477	3	1B
0005435461819	13477	4	1G
0005435461806	13477	5	3C
0005434264727	13477	6	4F
0005434264725	13477	7	4C
0005435461817	13477	8	4G
0005432535754	13477	9	9H
0005435461818	13477	10	9G
0005435461830	13477	11	11E
0005434264709	13477	12	11H
0005435461828	13477	13	11G
0005434264705	13477	14	12D
0005435461823	13477	15	12H
0005434264718	13477	16	13B
0005435461804	13477	17	13F
0005434264711	13477	18	13E
0005435461814	13477	19	15G
0005435461826	13477	20	15F
0005434831075	13477	21	15H
0005435461802	13477	22	16A
0005434264708	13477	23	16D
0005434264717	13477	24	16B
0005434264719	13477	25	16E
0005434264703	13477	26	16F
0005432535751	13477	27	16H
0005435461807	13477	28	17B
0005434264712	13477	29	17D
0005435461813	13477	30	17G
0005435461805	13477	31	17H
0005435461803	13477	32	18D
0005435461821	13477	33	18E
0005434264726	13477	34	18H
0005435461831	13477	35	19A
0005435461809	13477	36	19G
0005432194442	13477	37	20E
0005435461825	13477	38	20G
0005434264713	13477	39	22B
0005435461832	13477	40	22E
0005434264715	13477	41	22F
0005435461800	13477	42	23E
0005435461796	13477	43	23D
0005434264714	13477	44	23G
0005434264720	13477	45	25D
0005435461799	13477	46	27A
0005432194441	13477	47	27D
0005434264706	13477	48	27G
0005435461795	13477	49	28A
0005434264704	13477	50	28B
0005434831071	13477	51	28H
0005434264723	13477	52	29A
0005434264702	13477	53	29D
0005432535755	13477	54	30A
0005434264724	13477	55	29H
0005435461797	13477	56	30D
0005434831074	13477	57	30E
0005435461816	13477	58	30G
0005432535753	13477	59	31D
0005435461810	13477	60	31G
0005435461811	13477	61	31H
0005432535752	13477	62	32F
0005435461820	13477	63	32E
0005434264721	13477	64	32H
0005434264722	13477	65	32G
0005435461827	13477	66	33F
0005435461815	13477	67	34A
0005435461824	13477	68	34D
0005434264707	13477	69	34G
0005432194440	13477	70	35D
0005434831072	13477	71	35B
0005434264710	13477	72	36B
0005435461822	13477	73	36F
0005435461829	13477	74	36E
0005435461808	13477	75	37B
0005435461812	13477	76	37D
0005435461801	13477	77	37G
0005435461798	13477	78	38E
0005434264716	13477	79	39E
0005434514921	18702	1	2A
0005434513535	18702	2	2B
0005434514923	18702	3	3A
0005434513534	18702	4	3B
0005434514922	18702	5	5A
0005434513533	18702	6	5B
0005432632623	4108	1	1A
0005432632620	4108	2	1D
0005432632624	4108	3	1F
0005432649304	4108	4	2A
0005432632632	4108	5	2C
0005432632627	4108	6	2F
0005432632630	4108	7	3A
0005432649297	4108	8	3D
0005432632622	4108	9	3F
0005432649296	4108	10	5C
0005432632626	4108	11	6D
0005432649299	4108	12	8C
0005432632631	4108	13	9E
0005432649306	4108	14	10C
0005432632625	4108	15	10F
0005432632629	4108	16	11C
0005432632628	4108	17	11E
0005432649303	4108	18	13A
0005432632634	4108	19	13E
0005432649300	4108	20	13F
0005432649302	4108	21	14A
0005432632621	4108	22	15F
0005432649298	4108	23	17D
0005432649307	4108	24	18A
0005432649305	4108	25	18F
0005432649301	4108	26	19A
0005432632633	4108	27	20F
0005432295837	1798	1	2D
0005432295836	1798	2	3A
0005433810492	1798	3	3D
0005432295835	1798	4	5C
0005433007859	22549	1	1C
0005433007850	22549	2	1D
0005433007841	22549	3	1F
0005433284788	22549	4	2A
0005433007854	22549	5	2C
0005433284786	22549	6	2D
0005433284773	22549	7	2F
0005433007853	22549	8	3A
0005433007866	22549	9	3D
0005433007825	22549	10	4C
0005433284791	22549	11	4D
0005433007849	22549	12	4F
0005433007835	22549	13	5A
0005433284780	22549	14	5C
0005433007865	22549	15	5D
0005433284790	22549	16	5E
0005433007834	22549	17	5F
0005433007838	22549	18	6A
0005433007831	22549	19	6C
0005433007867	22549	20	6D
0005433007832	22549	21	6F
0005433284779	22549	22	7D
0005433284782	22549	23	7E
0005433284783	22549	24	8D
0005433007827	22549	25	8E
0005433007828	22549	26	8F
0005433284770	22549	27	9A
0005433284769	22549	28	9C
0005433007857	22549	29	9E
0005433007845	22549	30	9F
0005433007829	22549	31	10A
0005433007836	22549	32	10C
0005433284775	22549	33	10D
0005433007833	22549	34	10E
0005433284793	22549	35	10F
0005433284784	22549	36	11C
0005433284792	22549	37	11D
0005433007846	22549	38	11E
0005433284774	22549	39	11F
0005433007843	22549	40	12A
0005433007847	22549	41	12D
0005433007861	22549	42	12E
0005433007840	22549	43	12F
0005433284781	22549	44	13C
0005433007851	22549	45	13D
0005433007823	22549	46	13E
0005433007855	22549	47	13F
0005433007826	22549	48	14A
0005433007824	22549	49	14E
0005433007858	22549	50	14F
0005433284776	22549	51	15E
0005433007830	22549	52	15F
0005433007822	22549	53	16A
0005433284794	22549	54	16C
0005433284789	22549	55	16E
0005433284787	22549	56	16F
0005433284772	22549	57	17A
0005433007844	22549	58	17E
0005433007848	22549	59	17F
0005433284777	22549	60	18A
0005433284785	22549	61	18C
0005433007862	22549	62	18D
0005433007852	22549	63	18E
0005433007856	22549	64	18F
0005433007864	22549	65	19A
0005433007863	22549	66	19C
0005433284771	22549	67	19D
0005433007837	22549	68	19E
0005433007839	22549	69	19F
0005433007842	22549	70	20A
0005433007860	22549	71	20D
0005433284778	22549	72	20F
0005433845780	5568	1	1C
0005433845724	5568	2	1A
0005432081404	5568	3	2A
0005433845736	5568	4	1F
0005433845769	5568	5	2C
0005433845744	5568	6	3A
0005433845725	5568	7	2F
0005433845778	5568	8	3D
0005433845767	5568	9	4A
0005433815304	5568	10	3F
0005433845737	5568	11	4C
0005433845754	5568	12	5A
0005433845729	5568	13	4F
0005433845760	5568	14	5C
0005433845747	5568	15	5F
0005433815300	5568	16	5D
0005433845723	5568	17	7C
0005432081401	5568	18	7B
0005433845750	5568	19	7E
0005433845749	5568	20	7D
0005433845757	5568	21	8A
0005433845751	5568	22	8C
0005433845766	5568	23	8B
0005432081406	5568	24	8D
0005433845735	5568	25	8F
0005433845770	5568	26	8E
0005433845742	5568	27	9A
0005433845731	5568	28	9C
0005432081405	5568	29	9B
0005433845728	5568	30	9E
0005433845776	5568	31	9D
0005433845753	5568	32	10B
0005433845759	5568	33	10A
0005433845763	5568	34	10E
0005433845782	5568	35	10D
0005433845781	5568	36	11C
0005433845771	5568	37	11F
0005433845741	5568	38	11E
0005433845773	5568	39	12D
0005433845745	5568	40	12C
0005433845764	5568	41	12E
0005433845743	5568	42	13A
0005433845774	5568	43	13B
0005433845768	5568	44	13E
0005433845733	5568	45	14A
0005433845772	5568	46	14D
0005433845765	5568	47	14F
0005433845756	5568	48	15B
0005433845755	5568	49	15C
0005433845758	5568	50	15F
0005433815302	5568	51	15E
0005432081403	5568	52	15D
0005433815301	5568	53	16A
0005433845734	5568	54	16B
0005433815305	5568	55	17A
0005433815303	5568	56	16F
0005433845732	5568	57	17B
0005433845777	5568	58	17D
0005433845775	5568	59	17C
0005433845746	5568	60	17F
0005433845748	5568	61	17E
0005433845726	5568	62	18A
0005433845762	5568	63	18C
0005433845730	5568	64	19B
0005433845738	5568	65	19A
0005433845740	5568	66	19D
0005433845752	5568	67	20B
0005433845727	5568	68	20A
0005433845761	5568	69	20D
0005433845779	5568	70	21B
0005432081402	5568	71	21A
0005433845739	5568	72	21C
0005432003649	13885	1	1F
0005435282071	13885	2	2A
0005435282092	13885	3	2F
0005435282082	13885	4	3C
0005435282078	13885	5	3A
0005432003648	13885	6	4A
0005435282095	13885	7	5C
0005435282079	13885	8	5D
0005434173453	13885	9	6E
0005435282090	13885	10	7A
0005435282076	13885	11	6F
0005434173455	13885	12	7B
0005434173452	13885	13	7F
0005435282087	13885	14	8B
0005435282086	13885	15	8D
0005435282085	13885	16	9B
0005435282070	13885	17	9A
0005435282081	13885	18	11D
0005434173454	13885	19	11F
0005435282077	13885	20	12E
0005435282091	13885	21	13A
0005435282088	13885	22	13C
0005435282073	13885	23	13B
0005432003650	13885	24	16A
0005435282084	13885	25	16B
0005435282094	13885	26	17B
0005435282093	13885	27	17D
0005435282074	13885	28	17C
0005435282080	13885	29	17E
0005435282089	13885	30	18D
0005435282075	13885	31	18F
0005435282072	13885	32	19C
0005435282083	13885	33	20F
0005434620247	7828	1	1C
0005434620245	7828	2	2C
0005432112477	7828	3	2D
0005432112478	7828	4	3B
0005434620243	7828	5	3C
0005434620259	7828	6	4B
0005434620253	7828	7	4C
0005432112479	7828	8	5B
0005434620252	7828	9	5C
0005434620255	7828	10	5D
0005434620260	7828	11	7A
0005434620251	7828	12	7B
0005434620254	7828	13	7D
0005434620248	7828	14	18A
0005434620250	7828	15	19A
0005434620258	7828	16	19C
0005434620257	7828	17	20C
0005434620263	7828	18	21A
0005434620261	7828	19	21B
0005434620262	7828	20	21C
0005434620244	7828	21	22B
0005434620249	7828	22	22C
0005434620246	7828	23	23A
0005434620256	7828	24	23B
0005435332165	32999	1	1B
0005435332157	32999	2	2A
0005435332161	32999	3	2B
0005435332162	32999	4	4B
0005435332164	32999	5	6A
0005435332167	32999	6	6C
0005435332163	32999	7	7B
0005435332159	32999	8	18A
0005435332158	32999	9	18D
0005435332166	32999	10	20B
0005435332160	32999	11	23B
0005435784767	4273	1	1A
0005435784792	4273	2	1F
0005435784765	4273	3	2A
0005435784789	4273	4	2D
0005434993862	4273	5	2F
0005435784768	4273	6	3C
0005435787320	4273	7	3F
0005434993855	4273	8	5C
0005435787321	4273	9	5D
0005435784781	4273	10	5E
0005434993863	4273	11	5F
0005435784786	4273	12	6E
0005432190565	4273	13	7C
0005434993860	4273	14	7F
0005435784787	4273	15	8A
0005432190566	4273	16	8C
0005435784776	4273	17	8E
0005435784775	4273	18	9F
0005435784780	4273	19	10A
0005435784770	4273	20	10C
0005435784798	4273	21	10D
0005435784778	4273	22	11D
0005434993857	4273	23	11E
0005434993858	4273	24	11F
0005435784794	4273	25	12A
0005435784782	4273	26	12E
0005435784790	4273	27	13D
0005435784797	4273	28	13E
0005435784779	4273	29	14A
0005435784793	4273	30	14C
0005435784784	4273	31	14E
0005434993864	4273	32	14F
0005435784774	4273	33	15C
0005435784788	4273	34	16A
0005435784766	4273	35	16D
0005435784772	4273	36	16E
0005435784796	4273	37	17C
0005435784795	4273	38	17E
0005432190567	4273	39	17F
0005435784764	4273	40	18C
0005435784777	4273	41	18D
0005435784783	4273	42	18E
0005434993859	4273	43	18F
0005435784769	4273	44	19A
0005435784785	4273	45	19C
0005435784771	4273	46	19D
0005435784791	4273	47	19E
0005435784773	4273	48	20A
0005434993861	4273	49	20C
0005434993856	4273	50	20E
0005435937307	27288	1	1A
0005435918578	27288	2	3F
0005435937305	27288	3	6C
0005432195655	27288	4	8A
0005435918573	27288	5	8D
0005435937313	27288	6	8F
0005435918574	27288	7	9A
0005435937308	27288	8	9C
0005435937312	27288	9	9D
0005435937309	27288	10	10A
0005435918575	27288	11	12D
0005435918577	27288	12	14A
0005432195656	27288	13	14C
0005435937306	27288	14	15F
0005435918576	27288	15	16C
0005435937311	27288	16	16F
0005432195657	27288	17	18D
0005435937310	27288	18	19E
0005432146165	19872	1	3D
0005432146164	19872	2	4A
0005432146163	19872	3	21B
0005432566599	4693	1	1A
0005432458989	4693	2	1C
0005432566607	4693	3	1B
0005432458975	4693	4	1F
0005432566648	4693	5	1G
0005432566605	4693	6	2A
0005432566609	4693	7	1H
0005432566612	4693	8	2C
0005432566613	4693	9	2B
0005432458996	4693	10	2G
0005432571258	4693	11	2F
0005432566629	4693	12	3A
0005432459009	4693	13	3B
0005432566592	4693	14	3C
0005432459003	4693	15	3G
0005432458959	4693	16	3F
0005434081489	4693	17	3H
0005432458999	4693	18	4B
0005432186810	4693	19	4A
0005432566606	4693	20	4C
0005434081505	4693	21	4G
0005432186808	4693	22	4F
0005432458994	4693	23	5A
0005432566642	4693	24	5B
0005434081492	4693	25	5C
0005434081487	4693	26	5H
0005432566601	4693	27	9B
0005432458961	4693	28	9A
0005432458979	4693	29	9H
0005432458986	4693	30	11B
0005432566641	4693	31	11A
0005432566646	4693	32	11D
0005432566645	4693	33	11F
0005433726066	4693	34	11H
0005432566647	4693	35	12A
0005434081491	4693	36	12B
0005434081509	4693	37	12E
0005432459006	4693	38	12D
0005432566649	4693	39	12F
0005432458956	4693	40	12H
0005434081507	4693	41	13A
0005432566611	4693	42	13D
0005432566625	4693	43	13E
0005433451584	4693	44	13G
0005432170276	4693	45	13F
0005432566591	4693	46	13H
0005434081503	4693	47	14B
0005432566644	4693	48	14D
0005433452705	4693	49	14F
0005432566622	4693	50	14H
0005432458981	4693	51	15E
0005432458982	4693	52	15D
0005432458972	4693	53	15F
0005432458983	4693	54	15H
0005434081488	4693	55	15G
0005434081513	4693	56	16A
0005432170274	4693	57	16B
0005434081497	4693	58	16E
0005434081499	4693	59	16F
0005434081493	4693	60	16H
0005434081495	4693	61	17D
0005432458964	4693	62	17B
0005432566639	4693	63	17F
0005432566650	4693	64	17E
0005432566636	4693	65	17G
0005432566621	4693	66	17H
0005432566603	4693	67	18B
0005432566620	4693	68	18A
0005432458984	4693	69	18F
0005432458985	4693	70	18E
0005432458987	4693	71	18G
0005432566634	4693	72	19B
0005432458969	4693	73	19A
0005434081517	4693	74	19E
0005432458957	4693	75	19D
0005432186809	4693	76	19F
0005434081498	4693	77	19G
0005433726065	4693	78	20A
0005434081500	4693	79	19H
0005432571257	4693	80	20E
0005434081496	4693	81	20D
0005432566616	4693	82	20G
0005432566627	4693	83	20F
0005432458990	4693	84	20H
0005434081512	4693	85	21B
0005432459001	4693	86	21A
0005432458977	4693	87	21E
0005432459008	4693	88	21F
0005432566624	4693	89	22B
0005432566640	4693	90	22A
0005432566637	4693	91	22D
0005432458991	4693	92	22G
0005432458978	4693	93	22F
0005432566600	4693	94	23B
0005434081506	4693	95	23A
0005434081501	4693	96	23H
0005432566643	4693	97	23G
0005432566617	4693	98	24A
0005432458998	4693	99	24B
0005432458974	4693	100	24E
0005432566590	4693	101	24D
0005432571259	4693	102	24F
0005432458970	4693	103	24G
0005432458960	4693	104	25E
0005432170275	4693	105	25D
0005432458993	4693	106	25F
0005434081514	4693	107	27A
0005432566638	4693	108	27D
0005432458965	4693	109	27F
0005432458968	4693	110	27E
0005434081490	4693	111	28A
0005432170272	4693	112	27H
0005432566597	4693	113	28D
0005432566594	4693	114	28F
0005432170271	4693	115	28E
0005432458958	4693	116	28G
0005433726064	4693	117	29F
0005432458963	4693	118	29E
0005434081504	4693	119	29G
0005432566615	4693	120	29H
0005434081510	4693	121	30B
0005434081520	4693	122	30F
0005432458962	4693	123	30G
0005432458992	4693	124	31B
0005432566610	4693	125	31A
0005432458997	4693	126	31D
0005432566604	4693	127	31F
0005432566602	4693	128	31E
0005432566628	4693	129	31G
0005432566589	4693	130	32A
0005432459005	4693	131	32B
0005432566595	4693	132	32D
0005432566631	4693	133	32G
0005432458967	4693	134	32H
0005432170273	4693	135	33A
0005434081494	4693	136	33B
0005432571260	4693	137	33E
0005432566593	4693	138	33D
0005433451585	4693	139	33G
0005432566632	4693	140	33F
0005432458988	4693	141	33H
0005434081502	4693	142	34A
0005432566608	4693	143	34D
0005432566633	4693	144	34B
0005433452704	4693	145	34F
0005432566618	4693	146	34E
0005432459007	4693	147	35B
0005432458976	4693	148	35A
0005433451586	4693	149	35D
0005432566630	4693	150	35F
0005432459004	4693	151	35E
0005434081508	4693	152	35G
0005432566623	4693	153	35H
0005434081515	4693	154	36B
0005432458971	4693	155	36A
0005432566614	4693	156	36E
0005432566619	4693	157	36D
0005434081519	4693	158	36G
0005432458973	4693	159	37A
0005432458966	4693	160	36H
0005432566626	4693	161	37B
0005432186807	4693	162	37E
0005432459000	4693	163	37G
0005432566635	4693	164	37F
0005432566598	4693	165	37H
0005432458995	4693	166	38B
0005434081518	4693	167	38A
0005432170277	4693	168	38D
0005432566596	4693	169	38E
0005432458980	4693	170	38F
0005434081516	4693	171	38H
0005432459002	4693	172	38G
0005434081511	4693	173	39F
0005432213545	30541	1	9H
0005432161112	30541	2	18B
0005432161113	30541	3	20D
0005432213544	30541	4	22G
0005432213543	30541	5	27H
0005435720802	13628	1	1B
0005435722014	13628	2	2A
0005435722015	13628	3	3B
0005435722016	13628	4	5A
0005435720801	13628	5	5B
0005432295836	22802	1	7B
0005432295835	22802	2	19C
0005432295837	22802	3	19D
0005433341548	11081	1	1C
0005433341495	11081	2	1A
0005433341525	11081	3	1F
0005433341574	11081	4	1D
0005433341533	11081	5	2C
0005433341517	11081	6	2A
0005433341581	11081	7	2F
0005433341572	11081	8	3A
0005433341531	11081	9	3D
0005433341513	11081	10	3C
0005433341481	11081	11	4A
0005433341577	11081	12	4B
0005433341567	11081	13	4D
0005433341563	11081	14	4C
0005433341491	11081	15	4E
0005435097048	11081	16	4F
0005433341524	11081	17	5A
0005433341504	11081	18	5B
0005433341506	11081	19	5D
0005433341550	11081	20	5E
0005433341562	11081	21	5F
0005433341579	11081	22	6B
0005433341514	11081	23	6A
0005433341509	11081	24	6C
0005433341560	11081	25	6D
0005433341536	11081	26	6E
0005433341553	11081	27	6F
0005433341489	11081	28	7B
0005433341490	11081	29	7A
0005433341571	11081	30	7C
0005433341498	11081	31	7E
0005433341512	11081	32	8A
0005433341527	11081	33	7F
0005433341578	11081	34	8B
0005433341557	11081	35	8C
0005433341558	11081	36	8D
0005433341552	11081	37	8F
0005433341486	11081	38	9A
0005433341484	11081	39	9B
0005433341582	11081	40	9C
0005433341519	11081	41	9E
0005433341541	11081	42	9D
0005433341521	11081	43	9F
0005433341493	11081	44	10C
0005433341522	11081	45	10D
0005433341544	11081	46	11A
0005433341503	11081	47	11B
0005435097047	11081	48	11D
0005433341573	11081	49	11C
0005433341576	11081	50	11E
0005433341540	11081	51	11F
0005433341494	11081	52	12A
0005433341580	11081	53	12C
0005433341500	11081	54	12B
0005433341492	11081	55	13B
0005433341520	11081	56	13A
0005433341559	11081	57	13D
0005433341499	11081	58	13E
0005433341561	11081	59	14A
0005433341508	11081	60	13F
0005433341488	11081	61	14B
0005433341556	11081	62	14D
0005433341555	11081	63	14E
0005433341543	11081	64	15A
0005433341538	11081	65	15B
0005435097050	11081	66	15D
0005433341542	11081	67	15E
0005433341554	11081	68	16A
0005433341507	11081	69	16B
0005435097046	11081	70	16C
0005435097045	11081	71	16D
0005433341529	11081	72	16E
0005433341568	11081	73	17A
0005433341569	11081	74	16F
0005433341565	11081	75	17C
0005433341570	11081	76	17E
0005435097044	11081	77	17D
0005433341482	11081	78	18A
0005433341487	11081	79	17F
0005433341547	11081	80	18B
0005435097051	11081	81	18D
0005433341535	11081	82	18C
0005433341511	11081	83	18F
0005433341505	11081	84	18E
0005433341501	11081	85	19B
0005433341480	11081	86	19A
0005433341516	11081	87	19D
0005433341549	11081	88	19C
0005433341539	11081	89	19F
0005433341532	11081	90	19E
0005433341545	11081	91	20C
0005433341510	11081	92	20B
0005433341534	11081	93	20D
0005433341564	11081	94	20E
0005433341485	11081	95	21A
0005433341537	11081	96	20F
0005433341546	11081	97	21B
0005433341551	11081	98	21C
0005433341502	11081	99	21D
0005433341530	11081	100	21E
0005433341526	11081	101	22B
0005433341496	11081	102	22A
0005433341497	11081	103	22C
0005433341518	11081	104	22D
0005435097049	11081	105	22E
0005433341515	11081	106	23A
0005433341523	11081	107	22F
0005435097043	11081	108	23B
0005433341483	11081	109	23C
0005433341528	11081	110	23E
0005433341566	11081	111	23D
0005433341575	11081	112	23F
0005432293168	17128	1	7F
0005432293166	17128	2	12C
0005432293167	17128	3	21B
0005433481037	9088	1	1C
0005433506872	9088	2	2A
0005433506888	9088	3	2D
0005433481041	9088	4	4A
0005433506883	9088	5	4D
0005433506877	9088	6	5E
0005433506889	9088	7	6E
0005433506880	9088	8	7F
0005433506879	9088	9	8C
0005433506881	9088	10	8E
0005433506887	9088	11	9A
0005433481042	9088	12	9E
0005433506885	9088	13	10F
0005433481043	9088	14	11C
0005433506874	9088	15	12C
0005433506884	9088	16	14D
0005433506882	9088	17	14F
0005433481038	9088	18	15C
0005433481039	9088	19	15E
0005433481035	9088	20	16D
0005433481036	9088	21	16F
0005433506875	9088	22	17C
0005433481040	9088	23	17E
0005433506890	9088	24	17F
0005433506886	9088	25	18C
0005433506876	9088	26	18D
0005433506878	9088	27	18E
0005433506873	9088	28	20F
0005432919527	20483	1	2C
0005432919528	20483	2	2D
0005432919537	20483	3	4C
0005432919529	20483	4	5C
0005432919534	20483	5	6A
0005432919530	20483	6	6F
0005432919525	20483	7	7E
0005432919539	20483	8	9A
0005432919531	20483	9	9C
0005432919536	20483	10	10C
0005432919542	20483	11	11D
0005432919544	20483	12	12C
0005432919543	20483	13	14E
0005432919535	20483	14	15A
0005432919533	20483	15	16C
0005432919540	20483	16	17A
0005432919541	20483	17	17F
0005432919532	20483	18	18A
0005432919526	20483	19	18C
0005432919545	20483	20	19A
0005432919538	20483	21	19D
0005432396173	10149	1	1A
0005432394034	10149	2	1B
0005432396172	10149	3	2A
0005432394032	10149	4	2B
0005432394033	10149	5	4B
0005432396174	10149	6	4A
0005432394035	10149	7	5A
0005432396171	10149	8	5B
0005432396170	10149	9	6A
0005435179687	18337	1	3A
0005435179686	18337	2	4B
0005434928253	10991	1	1A
0005434411708	10991	2	2D
0005434928252	10991	3	11E
0005434411707	10991	4	12A
0005434411705	10991	5	12E
0005434411706	10991	6	15F
0005434411709	10991	7	19C
0005435125694	14692	1	1A
0005435125716	14692	2	1D
0005435125697	14692	3	1F
0005435125706	14692	4	2A
0005435625880	14692	5	2C
0005435125714	14692	6	2D
0005435554106	14692	7	3D
0005435625887	14692	8	3F
0005435554103	14692	9	4C
0005435125712	14692	10	4D
0005435125707	14692	11	4E
0005435125727	14692	12	5A
0005435625898	14692	13	5C
0005435125726	14692	14	5D
0005435625894	14692	15	5E
0005435625883	14692	16	5F
0005435625892	14692	17	6A
0005435625896	14692	18	6C
0005435554104	14692	19	6E
0005435125724	14692	20	6F
0005435125723	14692	21	7A
0005435125703	14692	22	7C
0005435125713	14692	23	7D
0005435125690	14692	24	7F
0005435125728	14692	25	8A
0005435625882	14692	26	8D
0005435125709	14692	27	8E
0005435125704	14692	28	8F
0005435556650	14692	29	9A
0005435554107	14692	30	9C
0005435125725	14692	31	9D
0005435125692	14692	32	9E
0005435125711	14692	33	9F
0005435125699	14692	34	10A
0005435125715	14692	35	10C
0005435125721	14692	36	10E
0005435125718	14692	37	11A
0005435125702	14692	38	11C
0005435125691	14692	39	11D
0005435125705	14692	40	12C
0005435625888	14692	41	12D
0005435625899	14692	42	12E
0005435625881	14692	43	12F
0005435125729	14692	44	13C
0005435625890	14692	45	13D
0005435625886	14692	46	13F
0005435625889	14692	47	14C
0005435625891	14692	48	14E
0005435125689	14692	49	14F
0005435125695	14692	50	15A
0005435125710	14692	51	15C
0005435125696	14692	52	16A
0005435125700	14692	53	16C
0005435125698	14692	54	17A
0005435625897	14692	55	17F
0005435125701	14692	56	18C
0005435125717	14692	57	18D
0005435125693	14692	58	18E
0005435625895	14692	59	18F
0005435554105	14692	60	19A
0005435125722	14692	61	19C
0005435125720	14692	62	19D
0005435625885	14692	63	19E
0005435625884	14692	64	20C
0005435125719	14692	65	20D
0005435625893	14692	66	20E
0005435125708	14692	67	20F
0005435715178	7144	1	2D
0005435715177	7144	2	2F
0005435715182	7144	3	4D
0005432400063	7144	4	5E
0005435715193	7144	5	7A
0005435715181	7144	6	8A
0005435715192	7144	7	8C
0005435715185	7144	8	8E
0005432400061	7144	9	9A
0005435715187	7144	10	9F
0005435715189	7144	11	10D
0005432400064	7144	12	13A
0005432398132	7144	13	13D
0005432400062	7144	14	15A
0005432398134	7144	15	16E
0005435715183	7144	16	17A
0005432398133	7144	17	17C
0005435715191	7144	18	17F
0005435715179	7144	19	18D
0005435715180	7144	20	18F
0005435715190	7144	21	19C
0005432398135	7144	22	19D
0005435715186	7144	23	19E
0005435715188	7144	24	19F
0005435715184	7144	25	20E
0005435443154	27074	1	3C
0005435443158	27074	2	5D
0005435216553	27074	3	6E
0005435217676	27074	4	7A
0005435443153	27074	5	7E
0005435443161	27074	6	7F
0005435217678	27074	7	10A
0005435218099	27074	8	10D
0005435216554	27074	9	10E
0005435443160	27074	10	12D
0005435443157	27074	11	13D
0005435443156	27074	12	14D
0005435443159	27074	13	15E
0005435217677	27074	14	16E
0005435443155	27074	15	18A
0005435443162	27074	16	18F
0005434084856	2758	1	3A
0005434084854	2758	2	3B
0005434084855	2758	3	4A
0005434084853	2758	4	5A
0005434084857	2758	5	5B
0005433060369	28478	1	1A
0005433060368	28478	2	2B
0005433788147	11165	1	4D
0005433788141	11165	2	6C
0005433788140	11165	3	7D
0005433788144	11165	4	18C
0005433788145	11165	5	19C
0005433788143	11165	6	20B
0005433788148	11165	7	22C
0005433788142	11165	8	23A
0005433788146	11165	9	23B
0005435528891	22263	1	1A
0005435528885	22263	2	2A
0005435540631	22263	3	2D
0005432294445	22263	4	3C
0005435528892	22263	5	3F
0005435540626	22263	6	4E
0005435528879	22263	7	5C
0005435528886	22263	8	5D
0005435540639	22263	9	5F
0005435540627	22263	10	6C
0005435540643	22263	11	6F
0005435528893	22263	12	7A
0005435540632	22263	13	7C
0005435528887	22263	14	7D
0005435528889	22263	15	7E
0005435528895	22263	16	8F
0005435540642	22263	17	9D
0005435540634	22263	18	9F
0005432294446	22263	19	10A
0005435540630	22263	20	10D
0005435540623	22263	21	11E
0005435528898	22263	22	12C
0005435540635	22263	23	12D
0005435540641	22263	24	12E
0005435528896	22263	25	12F
0005435528888	22263	26	13A
0005435528899	22263	27	13C
0005435540633	22263	28	13D
0005435540624	22263	29	13F
0005435528900	22263	30	14E
0005435528897	22263	31	15A
0005435528894	22263	32	15D
0005435528880	22263	33	16C
0005435540637	22263	34	16D
0005435540640	22263	35	16E
0005435540628	22263	36	17A
0005435528890	22263	37	17F
0005435540622	22263	38	18A
0005435528884	22263	39	18C
0005435540625	22263	40	18D
0005435528882	22263	41	19A
0005435528883	22263	42	19C
0005435540636	22263	43	20A
0005435540638	22263	44	20C
0005435528881	22263	45	20D
0005435540629	22263	46	20E
0005434906415	2299	1	1D
0005434906442	2299	2	1F
0005434906444	2299	3	2A
0005434906435	2299	4	3D
0005434906441	2299	5	4D
0005434906452	2299	6	4F
0005434906426	2299	7	5A
0005434906422	2299	8	5C
0005434906407	2299	9	6A
0005434906419	2299	10	7A
0005434906418	2299	11	7C
0005434906421	2299	12	8D
0005434906433	2299	13	8E
0005434906453	2299	14	10A
0005434906454	2299	15	10D
0005434906431	2299	16	10F
0005434906438	2299	17	11C
0005434906416	2299	18	11D
0005434906429	2299	19	11E
0005434906430	2299	20	12A
0005434906448	2299	21	12E
0005434906436	2299	22	13A
0005434906434	2299	23	13C
0005434906449	2299	24	13D
0005434906425	2299	25	13F
0005434906451	2299	26	14C
0005434906412	2299	27	14D
0005434906445	2299	28	14E
0005434906450	2299	29	14F
0005434906409	2299	30	15C
0005434906408	2299	31	15D
0005434906440	2299	32	15E
0005434906428	2299	33	16A
0005434906423	2299	34	16D
0005434906420	2299	35	17A
0005434906437	2299	36	17D
0005434906410	2299	37	17F
0005434906411	2299	38	18A
0005434906413	2299	39	18C
0005434906443	2299	40	18E
0005434906439	2299	41	18F
0005434906446	2299	42	19A
0005434906432	2299	43	19C
0005434906447	2299	44	19D
0005434906427	2299	45	19E
0005434906424	2299	46	19F
0005434906455	2299	47	20A
0005434906414	2299	48	20E
0005434906417	2299	49	20F
0005433250959	25619	1	1A
0005433250984	25619	2	1D
0005433400933	25619	3	3C
0005433250981	25619	4	3D
0005433400934	25619	5	4A
0005433250965	25619	6	4C
0005433250983	25619	7	4F
0005433250979	25619	8	6C
0005433250985	25619	9	6D
0005433250988	25619	10	6F
0005433250972	25619	11	7F
0005433250962	25619	12	10C
0005433250982	25619	13	11C
0005433250976	25619	14	11E
0005433250966	25619	15	12C
0005433250973	25619	16	12E
0005433250967	25619	17	12F
0005433250975	25619	18	14A
0005433250971	25619	19	14C
0005433250986	25619	20	14E
0005433250968	25619	21	14F
0005433250961	25619	22	15A
0005433250970	25619	23	15D
0005433250964	25619	24	16C
0005433250969	25619	25	17A
0005433250977	25619	26	17F
0005433250963	25619	27	18C
0005433250960	25619	28	18E
0005433250974	25619	29	18F
0005433250987	25619	30	19E
0005433250978	25619	31	19F
0005433250989	25619	32	20A
0005433250980	25619	33	20D
0005432620809	2540	1	1A
0005432620801	2540	2	2A
0005432620807	2540	3	5C
0005432620808	2540	4	5D
0005432620804	2540	5	6A
0005432620812	2540	6	6C
0005432620802	2540	7	7B
0005432620805	2540	8	18B
0005432620803	2540	9	18D
0005432620806	2540	10	21C
0005432620810	2540	11	21D
0005432620811	2540	12	22B
0005432620814	2540	13	22C
0005432620813	2540	14	23A
0005432862170	28089	1	2B
0005432862172	28089	2	3C
0005432862177	28089	3	4A
0005432862178	28089	4	4C
0005432862176	28089	5	21B
0005432862173	28089	6	21C
0005432862171	28089	7	21D
0005432862174	28089	8	22C
0005432862175	28089	9	23B
0005434097451	13104	1	1A
0005434097450	13104	2	1B
0005433452704	31011	1	1A
0005433451584	31011	2	1B
0005433451585	31011	3	4B
0005433452705	31011	4	5A
0005433451586	31011	5	6A
0005434183547	29840	1	1B
0005433131633	29840	2	3D
0005433134060	29840	3	4B
0005433131630	29840	4	4D
0005434184632	29840	5	5A
0005433131634	29840	6	5B
0005433134064	29840	7	5D
0005433134062	29840	8	6A
0005433134063	29840	9	6B
0005434142542	29840	10	6D
0005433134061	29840	11	7A
0005434142543	29840	12	19C
0005434142540	29840	13	19D
0005434184631	29840	14	21B
0005433131631	29840	15	21C
0005433131632	29840	16	22C
0005434142541	29840	17	22D
0005435696869	16466	1	1A
0005435696849	16466	2	1C
0005435696843	16466	3	1D
0005435696863	16466	4	2B
0005435696871	16466	5	2D
0005435696848	16466	6	3A
0005435696853	16466	7	3B
0005435696852	16466	8	3D
0005435696857	16466	9	5B
0005435696844	16466	10	6A
0005435696854	16466	11	6B
0005435696861	16466	12	6D
0005435696860	16466	13	7D
0005435696862	16466	14	18A
0005435696851	16466	15	18D
0005435696845	16466	16	19B
0005435696847	16466	17	19C
0005435696866	16466	18	19D
0005435696850	16466	19	20A
0005435696867	16466	20	20B
0005435696868	16466	21	20D
0005435696859	16466	22	21A
0005435696846	16466	23	21B
0005435696858	16466	24	21D
0005435696870	16466	25	22A
0005435696855	16466	26	22B
0005435696865	16466	27	22C
0005435696864	16466	28	23A
0005435696856	16466	29	23B
0005435934996	24731	1	2A
0005435934997	24731	2	2C
0005435934998	24731	3	6D
0005433724725	18809	1	1A
0005433724724	18809	2	3A
0005433724726	18809	3	4A
0005433724727	18809	4	5B
0005432968804	21605	1	4A
0005432968805	21605	2	6A
0005434136785	7295	1	1A
0005434136810	7295	2	1C
0005434136774	7295	3	1D
0005434087435	7295	4	1F
0005434136775	7295	5	2A
0005434136811	7295	6	2C
0005434136790	7295	7	2D
0005434136820	7295	8	2F
0005434136788	7295	9	3C
0005434136791	7295	10	3D
0005434136762	7295	11	3F
0005434136822	7295	12	4A
0005434136841	7295	13	4C
0005434136805	7295	14	4D
0005434136839	7295	15	4E
0005434136800	7295	16	4F
0005434087432	7295	17	5A
0005434136836	7295	18	5C
0005434136797	7295	19	5D
0005434136783	7295	20	5E
0005434136803	7295	21	5F
0005434136781	7295	22	6A
0005434136763	7295	23	6C
0005434136840	7295	24	6D
0005434136779	7295	25	6E
0005434136782	7295	26	7A
0005434136838	7295	27	6F
0005434136802	7295	28	7C
0005434136787	7295	29	7D
0005434136776	7295	30	7E
0005434136829	7295	31	7F
0005434136826	7295	32	8A
0005434136834	7295	33	8C
0005434136817	7295	34	8D
0005434136765	7295	35	8E
0005434136798	7295	36	8F
0005434136830	7295	37	9A
0005434136770	7295	38	9D
0005434087431	7295	39	9E
0005434136784	7295	40	9F
0005434087433	7295	41	10A
0005434136760	7295	42	10C
0005434136804	7295	43	10D
0005434136833	7295	44	10E
0005434136799	7295	45	10F
0005434136825	7295	46	11A
0005434136835	7295	47	11C
0005434136761	7295	48	11E
0005434087434	7295	49	11F
0005434136843	7295	50	12A
0005434136831	7295	51	12C
0005434136771	7295	52	12D
0005434136778	7295	53	12E
0005434136777	7295	54	12F
0005434136844	7295	55	13A
0005434136789	7295	56	13C
0005434136786	7295	57	13D
0005434136809	7295	58	13E
0005434136837	7295	59	13F
0005434136842	7295	60	14A
0005434136769	7295	61	14C
0005434136808	7295	62	14D
0005434136773	7295	63	14E
0005434136792	7295	64	14F
0005434136795	7295	65	15C
0005434136821	7295	66	15D
0005434136806	7295	67	15E
0005434136796	7295	68	15F
0005434136814	7295	69	16A
0005434136812	7295	70	16C
0005434136780	7295	71	16E
0005434136815	7295	72	17A
0005434136764	7295	73	17C
0005434136772	7295	74	17D
0005434136807	7295	75	17E
0005434136824	7295	76	17F
0005434136827	7295	77	18A
0005434136768	7295	78	18C
0005434136828	7295	79	18D
0005434136823	7295	80	18E
0005434136793	7295	81	18F
0005434136818	7295	82	19A
0005434136813	7295	83	19C
0005434136816	7295	84	19D
0005434136819	7295	85	19E
0005434136832	7295	86	20A
0005434136766	7295	87	20C
0005434136767	7295	88	20D
0005434136801	7295	89	20E
0005434136794	7295	90	20F
0005435808070	1904	1	1B
0005435808065	1904	2	1D
0005435808061	1904	3	2D
0005434610169	1904	4	3B
0005434610170	1904	5	4B
0005435808067	1904	6	5B
0005435808062	1904	7	6A
0005435808068	1904	8	6B
0005435808060	1904	9	6C
0005435808064	1904	10	7D
0005435808063	1904	11	18A
0005435808066	1904	12	19C
0005434610168	1904	13	21A
0005435808069	1904	14	22C
0005433407480	23062	1	1A
0005433407481	23062	2	3B
0005433407478	23062	3	3D
0005433407479	23062	4	4C
0005433407477	23062	5	4D
0005434503460	22907	1	1A
0005434503461	22907	2	1B
0005434503463	22907	3	2A
0005434503476	22907	4	2C
0005434503475	22907	5	2D
0005434503485	22907	6	3A
0005434503491	22907	7	3D
0005434503473	22907	8	4A
0005434503458	22907	9	4B
0005434503474	22907	10	4C
0005434503492	22907	11	4D
0005434503471	22907	12	5A
0005434503465	22907	13	5B
0005434503469	22907	14	5C
0005434503490	22907	15	5D
0005434503489	22907	16	6B
0005434503466	22907	17	6D
0005434503470	22907	18	7A
0005434503487	22907	19	7B
0005434503494	22907	20	7C
0005434503477	22907	21	7D
0005434503480	22907	22	18A
0005434503488	22907	23	18B
0005434503495	22907	24	18D
0005434503464	22907	25	19B
0005434503459	22907	26	19C
0005434503478	22907	27	20A
0005434503482	22907	28	20B
0005434503493	22907	29	20D
0005434503462	22907	30	21A
0005434503479	22907	31	21B
0005434503484	22907	32	21C
0005434503481	22907	33	21D
0005434503496	22907	34	22A
0005434503486	22907	35	22B
0005434503468	22907	36	22C
0005434503483	22907	37	22D
0005434503467	22907	38	23A
0005434503472	22907	39	23B
0005435078080	2196	1	1B
0005435078090	2196	2	1C
0005435078095	2196	3	2A
0005435078093	2196	4	2B
0005435078091	2196	5	2C
0005435078085	2196	6	3D
0005435078082	2196	7	5B
0005435078087	2196	8	5D
0005435078089	2196	9	7D
0005435078094	2196	10	20B
0005435078081	2196	11	20D
0005435078088	2196	12	21A
0005435078084	2196	13	21D
0005435078086	2196	14	22A
0005435078092	2196	15	22D
0005435078083	2196	16	23A
0005433266571	24332	1	2C
0005433266569	24332	2	3B
0005433266568	24332	3	6A
0005433266573	24332	4	7B
0005433266570	24332	5	18A
0005433266574	24332	6	19A
0005433266567	24332	7	19D
0005433266572	24332	8	21C
0005435803215	6651	1	1A
0005434988567	6651	2	1B
0005434988569	6651	3	2C
0005434988570	6651	4	4D
0005435803216	6651	5	6C
0005435803217	6651	6	19B
0005434988565	6651	7	19C
0005434988566	6651	8	19D
0005435803214	6651	9	21C
0005434988568	6651	10	22C
0005435464474	23613	1	2D
0005435464475	23613	2	4B
0005435464476	23613	3	6D
0005432382530	30510	1	1C
0005433449620	30510	2	1D
0005432382553	30510	3	1F
0005432382555	30510	4	2A
0005432382538	30510	5	2C
0005432382533	30510	6	2F
0005432382546	30510	7	3A
0005432382524	30510	8	3C
0005433449609	30510	9	3D
0005432382540	30510	10	3F
0005433449616	30510	11	4C
0005432382549	30510	12	4D
0005433449624	30510	13	4E
0005432382531	30510	14	4F
0005433454840	30510	15	5A
0005432382536	30510	16	5E
0005433449618	30510	17	6A
0005433449623	30510	18	6E
0005432382537	30510	19	6F
0005432382529	30510	20	7C
0005433449606	30510	21	7D
0005432382528	30510	22	7E
0005433449627	30510	23	7F
0005433449619	30510	24	8A
0005432382556	30510	25	8C
0005432382522	30510	26	8D
0005432382559	30510	27	8F
0005432382558	30510	28	9A
0005432382535	30510	29	9C
0005432382547	30510	30	9D
0005432382552	30510	31	9E
0005433453728	30510	32	9F
0005433449617	30510	33	10C
0005433449615	30510	34	10D
0005432382548	30510	35	10F
0005433449611	30510	36	11A
0005432382544	30510	37	11C
0005432382563	30510	38	11E
0005433449607	30510	39	11F
0005432382554	30510	40	12C
0005432382562	30510	41	12D
0005432382532	30510	42	12E
0005433449614	30510	43	12F
0005432382526	30510	44	13D
0005432382521	30510	45	13E
0005432382545	30510	46	13F
0005432382542	30510	47	14A
0005432382525	30510	48	14C
0005432382539	30510	49	14E
0005432382551	30510	50	15A
0005433449622	30510	51	15C
0005433449612	30510	52	15D
0005432382541	30510	53	15E
0005432382543	30510	54	15F
0005432382561	30510	55	16C
0005433454839	30510	56	16F
0005433449621	30510	57	17A
0005433449626	30510	58	17C
0005433449610	30510	59	17D
0005432382560	30510	60	17E
0005432382534	30510	61	17F
0005432382523	30510	62	18A
0005433453729	30510	63	18C
0005433449613	30510	64	18F
0005433449625	30510	65	19A
0005432382550	30510	66	19C
0005432382527	30510	67	19D
0005432382557	30510	68	20C
0005433449608	30510	69	20F
0005435302129	29702	1	1B
0005435302125	29702	2	1D
0005433129205	29702	3	2C
0005435302128	29702	4	3B
0005435299701	29702	5	3C
0005435302124	29702	6	4A
0005433126775	29702	7	4C
0005433129203	29702	8	5C
0005433126774	29702	9	5D
0005433126772	29702	10	6A
0005435299702	29702	11	6C
0005433126776	29702	12	6D
0005433126773	29702	13	7A
0005433129204	29702	14	7D
0005433129206	29702	15	18D
0005435302126	29702	16	19B
0005435299700	29702	17	20A
0005433129202	29702	18	21A
0005435302127	29702	19	21D
0005435299704	29702	20	22B
0005435299703	29702	21	22D
0005434286931	2406	1	1A
0005434286932	2406	2	1D
0005434286916	2406	3	2A
0005434286930	2406	4	2B
0005434286919	2406	5	2C
0005434286923	2406	6	2D
0005434286926	2406	7	3A
0005434286928	2406	8	4B
0005434286934	2406	9	5C
0005434286922	2406	10	5D
0005434286929	2406	11	6B
0005434286937	2406	12	6D
0005434286927	2406	13	7C
0005434286924	2406	14	18A
0005434286917	2406	15	18B
0005434286920	2406	16	18D
0005434286935	2406	17	19B
0005434286915	2406	18	19D
0005434286933	2406	19	20B
0005434286918	2406	20	20C
0005432264435	2406	21	20D
0005432264434	2406	22	21C
0005434286925	2406	23	22A
0005434286921	2406	24	22B
0005434286936	2406	25	23A
0005433109858	26820	1	1C
0005433109859	26820	2	1D
0005433109857	26820	3	3A
0005433109861	26820	4	4B
0005433109849	26820	5	4D
0005433109854	26820	6	5B
0005433109860	26820	7	5C
0005433109855	26820	8	7A
0005433109852	26820	9	18A
0005433109856	26820	10	19B
0005433109851	26820	11	19C
0005433109850	26820	12	21D
0005433109853	26820	13	22B
0005435856135	25466	1	7B
0005435856136	25466	2	18A
0005435856134	25466	3	19D
0005435856137	25466	4	20C
0005434273049	26634	1	1B
0005434272163	26634	2	3C
0005434272164	26634	3	5D
0005434273048	26634	4	22A
0005433867779	4766	1	1A
0005433867789	4766	2	1B
0005433867770	4766	3	1C
0005433867803	4766	4	2B
0005433867798	4766	5	2C
0005433867780	4766	6	2D
0005433867792	4766	7	3A
0005433867786	4766	8	3B
0005433867802	4766	9	3C
0005433867791	4766	10	3D
0005433867777	4766	11	4A
0005433867805	4766	12	4B
0005433867771	4766	13	4C
0005433867776	4766	14	4D
0005433867782	4766	15	5A
0005433867794	4766	16	5B
0005433867808	4766	17	5D
0005433867804	4766	18	6B
0005433867797	4766	19	6C
0005433867774	4766	20	7A
0005433867795	4766	21	7C
0005433867809	4766	22	7D
0005433867801	4766	23	18B
0005433867775	4766	24	18C
0005433867788	4766	25	18D
0005433867781	4766	26	19A
0005433867800	4766	27	19B
0005433867787	4766	28	19C
0005433867773	4766	29	19D
0005433867810	4766	30	20A
0005433867793	4766	31	20C
0005433867799	4766	32	20D
0005433867806	4766	33	21A
0005433867785	4766	34	21B
0005433867807	4766	35	21C
0005433867790	4766	36	21D
0005433867772	4766	37	22A
0005433867784	4766	38	22B
0005433867796	4766	39	22C
0005433867778	4766	40	23A
0005433867783	4766	41	23B
0005435860432	32564	1	21C
0005435860433	32564	2	22A
0005434663181	3447	1	1B
0005434460470	3447	2	2A
0005434663191	3447	3	3A
0005434663192	3447	4	3B
0005434460469	3447	5	3C
0005434461612	3447	6	3D
0005434663189	3447	7	4D
0005434663182	3447	8	7B
0005434663179	3447	9	7C
0005434663190	3447	10	18C
0005434663188	3447	11	18D
0005434461611	3447	12	20B
0005434663184	3447	13	20D
0005434663185	3447	14	21A
0005434663186	3447	15	21D
0005434663183	3447	16	22C
0005434663180	3447	17	22D
0005434663187	3447	18	23A
0005435911330	12464	1	2B
0005435911323	12464	2	4A
0005435911327	12464	3	4B
0005435911324	12464	4	6A
0005435911325	12464	5	6B
0005435911328	12464	6	6D
0005435911326	12464	7	7C
0005435911329	12464	8	19C
0005435860432	14525	1	1C
0005435860433	14525	2	6A
0005433867738	32643	1	1A
0005433867768	32643	2	1B
0005433867743	32643	3	1D
0005433867746	32643	4	2A
0005433867766	32643	5	2B
0005433867736	32643	6	2C
0005433867728	32643	7	2D
0005433867752	32643	8	3A
0005433867734	32643	9	3B
0005433867735	32643	10	3C
0005433867762	32643	11	4A
0005433867732	32643	12	4B
0005433867730	32643	13	4C
0005433867755	32643	14	4D
0005433867764	32643	15	5A
0005433867729	32643	16	5B
0005433867760	32643	17	5C
0005433867741	32643	18	6A
0005433867745	32643	19	6B
0005433867767	32643	20	6C
0005433867757	32643	21	6D
0005433867759	32643	22	7A
0005433867727	32643	23	7B
0005433867740	32643	24	7C
0005433867750	32643	25	7D
0005433867733	32643	26	18A
0005433867758	32643	27	18B
0005433867747	32643	28	18C
0005433867731	32643	29	19A
0005433867742	32643	30	19B
0005433867753	32643	31	19D
0005433867761	32643	32	20A
0005433867744	32643	33	20B
0005433867739	32643	34	20C
0005433867749	32643	35	21A
0005433867765	32643	36	21B
0005433867763	32643	37	21C
0005433867748	32643	38	21D
0005433867756	32643	39	22B
0005433867737	32643	40	22C
0005433867754	32643	41	22D
0005433867751	32643	42	23A
0005433867769	32643	43	23B
0005432798965	14823	1	1A
0005432798978	14823	2	1B
0005432798976	14823	3	1D
0005432798962	14823	4	3A
0005432798953	14823	5	3B
0005432798955	14823	6	3C
0005432798961	14823	7	4C
0005432798966	14823	8	5B
0005432798977	14823	9	5C
0005432798979	14823	10	6A
0005432798974	14823	11	6B
0005432798981	14823	12	6C
0005432798963	14823	13	7C
0005432798957	14823	14	7D
0005432798956	14823	15	18A
0005432798954	14823	16	19B
0005432798959	14823	17	19C
0005432798967	14823	18	19D
0005432798958	14823	19	20A
0005432798970	14823	20	20B
0005432798980	14823	21	20C
0005432798964	14823	22	20D
0005432798969	14823	23	21A
0005432798972	14823	24	21B
0005432798975	14823	25	21C
0005432798973	14823	26	22A
0005432798968	14823	27	22B
0005432798982	14823	28	22C
0005432798960	14823	29	22D
0005432798971	14823	30	23B
0005434406728	7054	1	1A
0005434299189	7054	2	1C
0005434299186	7054	3	1D
0005434406722	7054	4	2C
0005434299173	7054	5	2D
0005434406711	7054	6	2F
0005434406746	7054	7	3A
0005434406704	7054	8	3C
0005434406705	7054	9	3F
0005434299180	7054	10	4A
0005434299174	7054	11	4C
0005434406712	7054	12	4B
0005434299191	7054	13	4D
0005434406714	7054	14	4E
0005434406732	7054	15	4F
0005434406718	7054	16	5B
0005434406747	7054	17	5A
0005434299182	7054	18	5C
0005434406723	7054	19	5D
0005434406717	7054	20	5E
0005434406743	7054	21	6B
0005434406757	7054	22	6A
0005434406725	7054	23	6E
0005434406708	7054	24	6D
0005434299193	7054	25	7A
0005434406751	7054	26	6F
0005434406734	7054	27	7B
0005434406730	7054	28	7C
0005432153823	7054	29	7D
0005434299188	7054	30	7E
0005434406706	7054	31	8A
0005434299183	7054	32	8B
0005434406764	7054	33	8D
0005434299181	7054	34	8C
0005432153825	7054	35	8E
0005434406748	7054	36	9A
0005432153820	7054	37	9C
0005432153821	7054	38	9E
0005434406758	7054	39	9F
0005434406719	7054	40	10B
0005434406727	7054	41	10D
0005434406749	7054	42	10E
0005434406709	7054	43	11A
0005434406702	7054	44	11B
0005434406760	7054	45	11C
0005432153827	7054	46	11E
0005434406753	7054	47	11F
0005434406741	7054	48	12D
0005434406745	7054	49	12E
0005434299176	7054	50	12F
0005434406716	7054	51	13B
0005434406713	7054	52	13A
0005434406715	7054	53	13C
0005434406763	7054	54	13E
0005434406703	7054	55	14A
0005434406724	7054	56	14C
0005434299190	7054	57	14B
0005432153826	7054	58	14D
0005434299187	7054	59	14E
0005434406729	7054	60	15A
0005434406710	7054	61	15B
0005434406736	7054	62	15D
0005434406721	7054	63	15F
0005434299179	7054	64	15E
0005434406752	7054	65	16A
0005434406742	7054	66	16B
0005434406759	7054	67	16D
0005434406726	7054	68	17B
0005434406755	7054	69	17A
0005434299185	7054	70	17E
0005434406735	7054	71	18A
0005432153822	7054	72	18B
0005434406740	7054	73	18C
0005432108208	7054	74	18E
0005434406750	7054	75	18D
0005432108207	7054	76	18F
0005434406761	7054	77	19A
0005434406733	7054	78	19B
0005434406707	7054	79	19D
0005434406744	7054	80	19C
0005434299172	7054	81	19E
0005434299175	7054	82	19F
0005434299177	7054	83	20A
0005434406762	7054	84	20B
0005434406737	7054	85	20D
0005434299184	7054	86	21A
0005434299170	7054	87	21D
0005434299192	7054	88	21E
0005434406720	7054	89	22A
0005434406739	7054	90	21F
0005434406756	7054	91	22B
0005434406738	7054	92	22C
0005434299178	7054	93	22F
0005434299171	7054	94	23C
0005434406754	7054	95	23D
0005432153824	7054	96	23F
0005434406731	7054	97	23E
0005435310843	26926	1	1A
0005435310839	26926	2	1D
0005435310841	26926	3	4B
0005435293064	26926	4	5C
0005435310836	26926	5	6B
0005435310851	26926	6	6C
0005435310855	26926	7	7C
0005435293067	26926	8	7E
0005435293065	26926	9	8A
0005435310842	26926	10	8B
0005435293069	26926	11	8C
0005435310844	26926	12	8E
0005435293061	26926	13	9A
0005435310849	26926	14	10D
0005435310845	26926	15	10E
0005432058312	26926	16	11E
0005435293068	26926	17	12B
0005432058315	26926	18	13D
0005435310838	26926	19	13F
0005435293058	26926	20	14F
0005435293063	26926	21	15F
0005432058314	26926	22	16B
0005435310840	26926	23	16E
0005435310850	26926	24	17A
0005435310847	26926	25	17C
0005435310854	26926	26	17D
0005435293066	26926	27	17F
0005435293060	26926	28	18D
0005435293059	26926	29	18E
0005435310848	26926	30	19D
0005435310846	26926	31	19E
0005432058313	26926	32	19F
0005435293057	26926	33	20D
0005435293070	26926	34	22A
0005435310853	26926	35	21F
0005435310837	26926	36	22D
0005435310852	26926	37	23B
0005435293062	26926	38	23C
0005432603722	6465	1	1A
0005432603700	6465	2	1B
0005432603705	6465	3	1C
0005432603707	6465	4	1D
0005432603683	6465	5	2A
0005432603711	6465	6	2B
0005432603718	6465	7	2C
0005432603690	6465	8	2D
0005432603701	6465	9	3A
0005432603704	6465	10	3B
0005432603708	6465	11	3C
0005432603697	6465	12	4A
0005432603685	6465	13	4B
0005432603682	6465	14	4C
0005432603703	6465	15	4D
0005432603713	6465	16	5A
0005434512026	6465	17	5B
0005432603696	6465	18	5D
0005434512023	6465	19	6A
0005432603714	6465	20	6B
0005432603687	6465	21	6C
0005434512022	6465	22	6D
0005432603695	6465	23	7A
0005432603684	6465	24	7B
0005434512027	6465	25	7C
0005432603709	6465	26	7D
0005432603719	6465	27	18A
0005434512024	6465	28	18B
0005432603694	6465	29	18C
0005432603689	6465	30	18D
0005432603699	6465	31	19A
0005432603698	6465	32	19B
0005432603712	6465	33	19C
0005432603702	6465	34	19D
0005434512025	6465	35	20B
0005432603716	6465	36	20C
0005432603691	6465	37	20D
0005432603693	6465	38	21A
0005432603706	6465	39	21B
0005432603686	6465	40	21C
0005432603721	6465	41	21D
0005432603688	6465	42	22A
0005432603715	6465	43	22B
0005432603717	6465	44	22C
0005432603710	6465	45	22D
0005432603692	6465	46	23A
0005432603720	6465	47	23B
0005433250989	15002	1	1A
0005433250985	15002	2	2C
0005433250988	15002	3	3D
0005433250968	15002	4	4D
0005433250979	15002	5	5D
0005433250972	15002	6	5F
0005433250959	15002	7	6A
0005433250961	15002	8	6C
0005433250962	15002	9	6E
0005433250981	15002	10	7D
0005433250974	15002	11	7F
0005433250965	15002	12	8D
0005433250983	15002	13	8E
0005433250987	15002	14	9C
0005433250971	15002	15	9D
0005433250967	15002	16	11A
0005433250966	15002	17	11C
0005433250980	15002	18	12D
0005433250970	15002	19	12F
0005433250963	15002	20	13E
0005433250978	15002	21	14D
0005433250975	15002	22	15D
0005433250984	15002	23	15F
0005433250977	15002	24	16E
0005433250969	15002	25	17E
0005433250964	15002	26	17F
0005433250982	15002	27	19A
0005433250986	15002	28	20A
0005433250973	15002	29	20C
0005433250960	15002	30	20D
0005433250976	15002	31	20E
0005434906406	25859	1	1C
0005434906388	25859	2	1D
0005434906405	25859	3	2D
0005434906368	25859	4	3F
0005434906400	25859	5	4A
0005434906379	25859	6	4C
0005434906404	25859	7	4D
0005434906364	25859	8	4E
0005434906362	25859	9	5A
0005434906371	25859	10	5D
0005434906375	25859	11	5F
0005434906384	25859	12	6D
0005434906395	25859	13	6F
0005434906365	25859	14	7A
0005434906396	25859	15	7C
0005434906392	25859	16	8A
0005434906398	25859	17	8D
0005434906391	25859	18	8E
0005434906370	25859	19	9A
0005434906360	25859	20	9E
0005434906381	25859	21	10A
0005434906377	25859	22	10D
0005434906374	25859	23	10F
0005434906401	25859	24	11C
0005434906389	25859	25	11D
0005434906403	25859	26	11F
0005434906393	25859	27	12A
0005434906394	25859	28	12C
0005434906359	25859	29	13D
0005434906397	25859	30	13E
0005434906361	25859	31	13F
0005434906367	25859	32	14A
0005434906383	25859	33	14C
0005434906373	25859	34	14E
0005434906385	25859	35	15C
0005434906402	25859	36	15E
0005434906376	25859	37	15F
0005434906366	25859	38	16F
0005434906380	25859	39	17A
0005434906378	25859	40	17D
0005434906390	25859	41	17F
0005434906387	25859	42	18A
0005434906363	25859	43	18C
0005434906369	25859	44	18D
0005434906382	25859	45	18F
0005434906386	25859	46	19A
0005434906399	25859	47	19E
0005434906372	25859	48	20A
0005433007874	14193	1	1D
0005433007882	14193	2	2A
0005433007890	14193	3	3A
0005433007898	14193	4	4C
0005433007868	14193	5	5C
0005433007907	14193	6	5D
0005433007908	14193	7	5E
0005433007900	14193	8	5F
0005433007881	14193	9	6A
0005433007871	14193	10	6F
0005433007897	14193	11	7A
0005433007885	14193	12	7E
0005433007893	14193	13	8A
0005433007892	14193	14	8D
0005433007910	14193	15	8F
0005433007878	14193	16	9C
0005433007894	14193	17	10C
0005433007903	14193	18	10E
0005433007872	14193	19	11A
0005433007895	14193	20	12C
0005433007880	14193	21	12D
0005433007886	14193	22	12F
0005433007914	14193	23	13C
0005433007887	14193	24	13D
0005433007902	14193	25	13E
0005433007905	14193	26	13F
0005433007901	14193	27	14C
0005433007889	14193	28	14D
0005433007873	14193	29	14F
0005433007883	14193	30	15C
0005433007870	14193	31	15D
0005433007884	14193	32	15E
0005433007869	14193	33	16A
0005433007913	14193	34	16D
0005433007904	14193	35	16E
0005433007906	14193	36	16F
0005433007879	14193	37	17A
0005433007912	14193	38	17C
0005433007877	14193	39	17D
0005433007875	14193	40	17E
0005433007909	14193	41	17F
0005433007896	14193	42	18A
0005433007876	14193	43	18F
0005433007888	14193	44	19D
0005433007891	14193	45	19F
0005433007899	14193	46	20A
0005433007911	14193	47	20C
0005433810489	22824	1	2D
0005433810491	22824	2	6A
0005433810490	22824	3	7A
0005433810488	22824	4	16C
0005435718828	15523	1	1D
0005435718829	15523	2	3A
0005435718830	15523	3	11A
0005435718827	15523	4	12A
0005435718831	15523	5	16D
0005434925265	20535	1	1C
0005434925247	20535	2	3A
0005434925272	20535	3	3C
0005434925269	20535	4	3D
0005434925259	20535	5	4C
0005434925270	20535	6	4E
0005434925261	20535	7	5C
0005434925256	20535	8	5F
0005434925268	20535	9	6C
0005434925258	20535	10	6F
0005434925267	20535	11	7F
0005434925264	20535	12	8D
0005434925266	20535	13	8E
0005434925253	20535	14	8F
0005434925262	20535	15	10C
0005434925257	20535	16	10D
0005434925251	20535	17	12E
0005434925263	20535	18	13E
0005434925260	20535	19	14A
0005434925254	20535	20	14D
0005434925252	20535	21	15C
0005434925249	20535	22	16A
0005434925248	20535	23	17E
0005434925255	20535	24	18C
0005434925250	20535	25	20A
0005434925271	20535	26	20D
0005435487479	15793	1	1A
0005435487494	15793	2	2B
0005435487478	15793	3	2C
0005435487482	15793	4	2D
0005435487484	15793	5	3A
0005435487485	15793	6	3C
0005435487481	15793	7	4B
0005435487480	15793	8	4C
0005435487486	15793	9	5D
0005435487477	15793	10	7B
0005435487475	15793	11	7C
0005435487489	15793	12	7D
0005435487491	15793	13	18A
0005435487496	15793	14	18C
0005435487490	15793	15	18D
0005435487476	15793	16	19A
0005435487492	15793	17	19B
0005435487497	15793	18	20A
0005435487487	15793	19	20D
0005435487495	15793	20	21D
0005435487483	15793	21	22A
0005435487493	15793	22	22B
0005435487488	15793	23	23A
0005435998959	19673	1	1B
0005435998954	19673	2	1D
0005435998955	19673	3	2B
0005435998965	19673	4	2C
0005435998963	19673	5	2D
0005435998961	19673	6	3B
0005435998960	19673	7	4B
0005435998962	19673	8	5D
0005435998964	19673	9	6B
0005435998957	19673	10	18B
0005435998952	19673	11	18C
0005435998951	19673	12	19A
0005435998958	19673	13	19B
0005435998967	19673	14	19C
0005435998953	19673	15	20B
0005435998956	19673	16	22D
0005435998966	19673	17	23B
0005435838991	5984	1	1A
0005435839013	5984	2	1C
0005432660785	5984	3	2A
0005432660786	5984	4	1F
0005435838989	5984	5	3D
0005435838993	5984	6	3C
0005435838988	5984	7	3F
0005435839011	5984	8	4C
0005435838995	5984	9	6C
0005435839004	5984	10	6D
0005435838996	5984	11	7E
0005435839008	5984	12	7D
0005435838987	5984	13	9D
0005435839000	5984	14	9E
0005432658559	5984	15	10E
0005435839001	5984	16	12B
0005432659674	5984	17	12C
0005432660784	5984	18	12E
0005435838990	5984	19	13A
0005435839007	5984	20	13C
0005432658558	5984	21	13E
0005435838998	5984	22	13F
0005435838994	5984	23	14C
0005435838986	5984	24	15B
0005435839002	5984	25	15A
0005435839010	5984	26	16D
0005435839014	5984	27	16C
0005435839003	5984	28	16F
0005432660787	5984	29	16E
0005435839009	5984	30	17B
0005435838997	5984	31	17D
0005435838999	5984	32	17C
0005435839006	5984	33	18B
0005435838992	5984	34	20B
0005432659673	5984	35	20D
0005435839012	5984	36	20C
0005435839005	5984	37	21B
0005432142202	5984	38	21A
0005435472543	18086	1	1C
0005435472536	18086	2	1D
0005435472539	18086	3	8D
0005435472531	18086	4	8E
0005435472535	18086	5	9B
0005435472532	18086	6	10C
0005435472530	18086	7	10D
0005435472541	18086	8	11A
0005435472529	18086	9	11C
0005435472537	18086	10	11E
0005435472544	18086	11	12D
0005432537023	18086	12	12F
0005432537024	18086	13	15B
0005435472534	18086	14	15C
0005435472540	18086	15	17E
0005435472538	18086	16	19C
0005435472542	18086	17	20B
0005435472533	18086	18	21F
0005435103796	23047	1	1D
0005435103798	23047	2	1F
0005435103801	23047	3	2F
0005435103799	23047	4	4A
0005435103797	23047	5	4C
0005435103793	23047	6	12C
0005435103803	23047	7	13B
0005435103802	23047	8	18A
0005435103794	23047	9	18F
0005435103795	23047	10	20D
0005435103800	23047	11	23F
0005433284805	32049	1	1A
0005433284811	32049	2	2D
0005433284800	32049	3	3F
0005433284795	32049	4	4B
0005433284817	32049	5	4A
0005433284814	32049	6	5A
0005433284801	32049	7	5D
0005433284816	32049	8	5F
0005433284806	32049	9	6C
0005433284802	32049	10	6F
0005433284812	32049	11	7B
0005433284813	32049	12	8F
0005433284807	32049	13	9A
0005433284820	32049	14	9B
0005433284798	32049	15	10D
0005433284796	32049	16	11D
0005433284804	32049	17	12B
0005433284797	32049	18	13C
0005433284803	32049	19	13F
0005433284810	32049	20	15E
0005433284819	32049	21	16C
0005433284808	32049	22	17C
0005433284799	32049	23	18F
0005433284815	32049	24	21B
0005433284809	32049	25	22D
0005433284818	32049	26	23F
0005432802433	1478	1	4F
0005432802430	1478	2	13B
0005432802432	1478	3	15C
0005432802429	1478	4	16F
0005432802434	1478	5	17C
0005432802431	1478	6	18B
0005432802435	1478	7	20D
0005435852529	23856	1	3A
0005435852528	23856	2	3D
0005435852530	23856	3	4B
0005435852532	23856	4	18A
0005435852533	23856	5	20D
0005435852526	23856	6	21B
0005435852525	23856	7	21C
0005435852527	23856	8	22A
0005435852531	23856	9	22B
0005435212498	30585	1	1H
0005432211384	30585	2	2A
0005435212476	30585	3	2G
0005435212468	30585	4	2H
0005435212519	30585	5	3G
0005435212501	30585	6	3C
0005435212482	30585	7	5D
0005432159785	30585	8	11E
0005435212473	30585	9	11F
0005435212485	30585	10	11G
0005435725525	30585	11	12F
0005435725523	30585	12	12D
0005435212520	30585	13	12G
0005435212495	30585	14	13A
0005435212504	30585	15	13F
0005435212507	30585	16	13K
0005432211383	30585	17	14D
0005432211385	30585	18	14F
0005435212516	30585	19	14H
0005435212523	30585	20	15F
0005435212472	30585	21	15E
0005435725524	30585	22	16F
0005435212503	30585	23	17C
0005435212496	30585	24	17G
0005435212497	30585	25	17H
0005435212502	30585	26	18C
0005435212494	30585	27	18K
0005435212470	30585	28	19H
0005435212530	30585	29	19J
0005435212489	30585	30	20K
0005435212514	30585	31	21A
0005435212499	30585	32	21H
0005435212500	30585	33	22C
0005435212481	30585	34	22G
0005435212521	30585	35	22K
0005433656618	30585	36	23H
0005435212491	30585	37	25B
0005435725522	30585	38	25F
0005435212510	30585	39	25J
0005435212526	30585	40	25H
0005435212512	30585	41	26E
0005432211388	30585	42	27B
0005435212487	30585	43	28B
0005435212480	30585	44	28G
0005432211382	30585	45	29F
0005433656619	30585	46	29G
0005432159786	30585	47	29K
0005435212492	30585	48	29J
0005435212467	30585	49	30B
0005435212531	30585	50	30C
0005435212532	30585	51	30G
0005435630920	30585	52	31H
0005435212505	30585	53	32G
0005435212478	30585	54	33A
0005435212483	30585	55	33D
0005435725526	30585	56	33B
0005435212477	30585	57	33K
0005435212534	30585	58	34D
0005435212479	30585	59	34F
0005435212513	30585	60	36A
0005435212490	30585	61	36D
0005435212471	30585	62	36C
0005435212469	30585	63	36F
0005432211386	30585	64	37B
0005432159784	30585	65	37C
0005435212509	30585	66	37E
0005435212533	30585	67	38B
0005435212508	30585	68	38A
0005435212528	30585	69	38K
0005435212524	30585	70	39F
0005435630919	30585	71	39H
0005435725521	30585	72	40C
0005435212511	30585	73	40H
0005432211381	30585	74	40K
0005435212522	30585	75	40J
0005435212517	30585	76	41E
0005435212493	30585	77	42C
0005432159787	30585	78	42F
0005435212474	30585	79	42H
0005435212488	30585	80	43B
0005435212486	30585	81	43F
0005435212515	30585	82	43E
0005435630922	30585	83	44B
0005433656620	30585	84	44E
0005432211387	30585	85	45B
0005435212475	30585	86	44K
0005435212525	30585	87	45K
0005435212484	30585	88	45J
0005435212506	30585	89	47A
0005435212527	30585	90	46K
0005435212535	30585	91	50A
0005435212529	30585	92	51D
0005435630921	30585	93	50K
0005435212518	30585	94	51F
0005433367304	24816	1	2A
0005433367329	24816	2	2D
0005433367328	24816	3	3D
0005433367312	24816	4	4A
0005433367315	24816	5	4D
0005433367300	24816	6	4E
0005433367317	24816	7	4F
0005433367314	24816	8	5A
0005433367301	24816	9	5C
0005433367326	24816	10	5F
0005433367320	24816	11	6A
0005433367309	24816	12	6C
0005433367324	24816	13	7C
0005433367299	24816	14	7D
0005433367321	24816	15	7E
0005433367316	24816	16	8A
0005433367305	24816	17	8F
0005433367331	24816	18	9D
0005433367330	24816	19	11A
0005433367307	24816	20	12D
0005433367313	24816	21	12F
0005433367297	24816	22	13F
0005433367303	24816	23	14A
0005433367295	24816	24	14C
0005433367318	24816	25	14D
0005433367308	24816	26	14F
0005433367319	24816	27	15D
0005433367323	24816	28	16A
0005433367332	24816	29	16F
0005433367310	24816	30	17C
0005433367306	24816	31	18A
0005433367296	24816	32	18C
0005433367325	24816	33	19C
0005433367298	24816	34	19D
0005433367322	24816	35	19E
0005433367311	24816	36	19F
0005433367302	24816	37	20A
0005433367327	24816	38	20E
0005434979340	2019	1	1B
0005434979325	2019	2	2B
0005434979330	2019	3	2C
0005434979317	2019	4	2D
0005434979342	2019	5	3A
0005434979315	2019	6	3C
0005434979334	2019	7	3D
0005434979319	2019	8	4C
0005435801650	2019	9	4D
0005434979320	2019	10	5A
0005434979314	2019	11	5B
0005434979339	2019	12	5D
0005434979322	2019	13	6A
0005434979318	2019	14	6D
0005434979338	2019	15	7A
0005434979326	2019	16	7B
0005434979324	2019	17	18A
0005434979333	2019	18	18B
0005434979323	2019	19	18C
0005434979336	2019	20	18D
0005435801649	2019	21	19A
0005434979321	2019	22	19B
0005434979329	2019	23	19D
0005434979328	2019	24	20A
0005434979341	2019	25	20B
0005434979316	2019	26	20C
0005434979332	2019	27	20D
0005434979327	2019	28	21A
0005434979337	2019	29	21B
0005434979335	2019	30	21D
0005434979343	2019	31	22A
0005435801648	2019	32	22C
0005434979344	2019	33	22D
0005434979331	2019	34	23B
0005434952471	2662	1	3A
0005434952474	2662	2	3B
0005434952472	2662	3	5B
0005434952473	2662	4	6B
0005433256387	28207	1	3A
0005433256386	28207	2	5A
0005433112351	19839	1	4A
0005433112352	19839	2	5A
0005433111472	19839	3	5B
0005433111473	19839	4	6B
0005434136781	28755	1	1A
0005434136822	28755	2	1D
0005434136785	28755	3	1F
0005434136775	28755	4	2A
0005434136799	28755	5	2C
0005434136800	28755	6	2D
0005434136844	28755	7	2F
0005434136811	28755	8	3A
0005434136810	28755	9	3C
0005434136786	28755	10	3D
0005434136790	28755	11	3F
0005434136766	28755	12	4A
0005434136813	28755	13	4C
0005434136784	28755	14	4D
0005434136824	28755	15	4F
0005434136778	28755	16	4E
0005434136830	28755	17	5C
0005434136821	28755	18	5D
0005434136795	28755	19	5E
0005434136793	28755	20	5F
0005434136823	28755	21	6A
0005434136768	28755	22	6C
0005434136843	28755	23	6D
0005434136839	28755	24	6E
0005434136802	28755	25	6F
0005434136794	28755	26	7A
0005434136774	28755	27	7C
0005434136776	28755	28	7D
0005434136796	28755	29	7E
0005434136838	28755	30	7F
0005434136819	28755	31	8A
0005434136764	28755	32	8C
0005434136835	28755	33	8D
0005434136825	28755	34	8E
0005434136797	28755	35	8F
0005434136771	28755	36	9A
0005434136767	28755	37	9C
0005434136832	28755	38	9D
0005434136801	28755	39	9E
0005434136831	28755	40	9F
0005434136782	28755	41	10A
0005434136816	28755	42	10C
0005434136803	28755	43	10D
0005434136836	28755	44	10E
0005434136792	28755	45	10F
0005434136834	28755	46	11A
0005434136762	28755	47	11C
0005434136814	28755	48	11D
0005434136828	28755	49	11F
0005434136808	28755	50	12A
0005434136773	28755	51	12C
0005434136770	28755	52	12D
0005434136837	28755	53	12E
0005434136765	28755	54	12F
0005434136761	28755	55	13A
0005434136818	28755	56	13C
0005434136809	28755	57	13D
0005434136783	28755	58	13F
0005434136807	28755	59	14A
0005434136842	28755	60	14C
0005434136841	28755	61	14D
0005434136760	28755	62	14E
0005434136780	28755	63	14F
0005434136805	28755	64	15A
0005434136791	28755	65	15C
0005434136815	28755	66	15D
0005434136806	28755	67	15F
0005434136829	28755	68	16A
0005434136779	28755	69	16D
0005434136820	28755	70	16E
0005434136840	28755	71	16F
0005434136812	28755	72	17E
0005434136827	28755	73	17F
0005434136769	28755	74	18A
0005434136798	28755	75	18C
0005434136788	28755	76	18E
0005434136826	28755	77	18F
0005434136777	28755	78	19A
0005434136787	28755	79	19C
0005434136789	28755	80	19D
0005434136817	28755	81	20A
0005434136772	28755	82	20C
0005434136804	28755	83	20D
0005434136833	28755	84	20E
0005434136763	28755	85	20F
0005434466385	6571	1	4C
0005434466384	6571	2	4D
0005434466380	6571	3	5A
0005434466383	6571	4	6A
0005434466373	6571	5	6B
0005434466375	6571	6	7B
0005434466387	6571	7	7D
0005434466386	6571	8	18C
0005434466376	6571	9	19A
0005434466379	6571	10	19C
0005434466382	6571	11	20A
0005434466378	6571	12	21D
0005434466381	6571	13	22B
0005434466377	6571	14	22C
0005434466372	6571	15	22D
0005434466374	6571	16	23B
0005433534466	6781	1	3B
0005433538738	6781	2	4B
0005433538740	6781	3	4D
0005433538734	6781	4	5A
0005433534465	6781	5	5C
0005433538741	6781	6	6A
0005433534464	6781	7	7B
0005433538739	6781	8	18B
0005433538736	6781	9	20A
0005433538737	6781	10	21A
0005433538735	6781	11	22A
0005435259690	25036	1	4B
0005435259688	25036	2	20B
0005435259689	25036	3	23B
0005433511818	852	1	3C
0005433511824	852	2	3D
0005433511823	852	3	4A
0005433511825	852	4	4C
0005433511819	852	5	6D
0005433511820	852	6	7A
0005433511822	852	7	21D
0005433511821	852	8	23B
0005432922460	16155	1	2A
0005432922462	16155	2	2D
0005432922463	16155	3	18A
0005432922461	16155	4	21D
0005432922464	16155	5	23A
0005433475638	4026	1	1D
0005433475635	4026	2	2C
0005433475634	4026	3	4D
0005433475640	4026	4	6A
0005433475641	4026	5	18A
0005433475642	4026	6	20D
0005433475636	4026	7	22C
0005433475639	4026	8	22D
0005433475637	4026	9	23A
0005435696918	3686	1	1A
0005435696924	3686	2	1B
0005435696912	3686	3	2A
0005435696902	3686	4	2B
0005435696917	3686	5	2C
0005435696904	3686	6	3D
0005435696927	3686	7	4A
0005435696919	3686	8	4B
0005435696901	3686	9	4C
0005435696905	3686	10	4D
0005434950460	3686	11	5A
0005435696928	3686	12	5B
0005435696925	3686	13	5C
0005435696915	3686	14	6A
0005435696926	3686	15	6B
0005435696914	3686	16	6C
0005435696910	3686	17	7C
0005434950462	3686	18	7D
0005435696911	3686	19	18A
0005435696923	3686	20	18B
0005435696916	3686	21	19A
0005435696909	3686	22	19B
0005435696913	3686	23	19C
0005435696920	3686	24	19D
0005435696921	3686	25	20B
0005434950459	3686	26	20D
0005435696907	3686	27	21A
0005435696922	3686	28	21C
0005434950461	3686	29	22A
0005435696908	3686	30	22C
0005435696903	3686	31	22D
0005435696906	3686	32	23B
0005435934997	16282	1	3C
0005435916125	16282	2	5D
0005435916126	16282	3	18C
0005435934998	16282	4	21A
0005435916123	16282	5	21C
0005435916124	16282	6	23A
0005435934996	16282	7	23B
0005433519386	3948	1	1A
0005432607504	3948	2	1B
0005432609671	3948	3	1C
0005432607502	3948	4	3A
0005434606770	3948	5	3B
0005433519389	3948	6	4D
0005434606769	3948	7	5A
0005433519388	3948	8	5B
0005432609670	3948	9	6A
0005432607505	3948	10	6D
0005434606771	3948	11	18B
0005434604845	3948	12	18D
0005434606768	3948	13	19C
0005432609669	3948	14	20B
0005433519387	3948	15	21C
0005432609667	3948	16	22A
0005432609668	3948	17	22D
0005432607503	3948	18	23B
0005435853581	22043	1	1B
0005435853584	22043	2	6C
0005435853582	22043	3	7C
0005435853583	22043	4	18B
0005435628673	767	1	1A
0005435628674	767	2	2A
0005435628675	767	3	1B
0005435628676	767	4	3B
0005433348901	15913	1	1B
0005433348903	15913	2	2B
0005433348899	15913	3	3A
0005433348900	15913	4	3B
0005433348902	15913	5	5A
0005433348898	15913	6	6B
0005434446480	17216	1	1A
0005434446479	17216	2	3A
0005434446477	17216	3	3B
0005434446481	17216	4	4A
0005434445211	17216	5	5A
0005434446478	17216	6	5B
0005433159279	17681	1	4A
0005433159280	17681	2	4B
0005435132716	7894	1	1C
0005435132723	7894	2	3C
0005435132717	7894	3	6A
0005435132725	7894	4	7B
0005435132721	7894	5	19A
0005435132719	7894	6	19B
0005435132718	7894	7	21A
0005435132715	7894	8	21D
0005435132722	7894	9	22A
0005435132724	7894	10	22B
0005435132720	7894	11	22D
0005435383069	33110	1	1A
0005435383068	33110	2	4A
0005435383070	33110	3	18C
0005435383067	33110	4	22C
0005435160131	7530	1	1C
0005435160134	7530	2	1D
0005435160136	7530	3	2C
0005435160132	7530	4	2D
0005435160127	7530	5	4B
0005435160129	7530	6	4C
0005435160128	7530	7	5B
0005435160135	7530	8	6D
0005435160126	7530	9	19C
0005435160133	7530	10	21D
0005435160130	7530	11	23A
0005435390137	29568	1	2D
0005435390131	29568	2	5A
0005435390138	29568	3	6C
0005435390133	29568	4	18C
0005435390132	29568	5	19D
0005435390134	29568	6	20D
0005435390136	29568	7	21A
0005435390135	29568	8	22C
0005435178473	18443	1	1B
0005435178471	18443	2	2A
0005435178978	18443	3	3B
0005435178472	18443	4	5A
0005432400062	27181	1	1A
0005432398135	27181	2	1B
0005432400061	27181	3	3A
0005432400063	27181	4	3B
0005432398133	27181	5	4A
0005432400064	27181	6	4B
0005432398132	27181	7	5A
0005432398134	27181	8	6A
0005432638939	2243	1	2A
0005432638937	2243	2	2D
0005432638932	2243	3	3D
0005432638929	2243	4	4A
0005432638923	2243	5	5E
0005432638922	2243	6	6E
0005432638943	2243	7	6F
0005432638936	2243	8	7A
0005432638917	2243	9	7C
0005432638948	2243	10	8A
0005432638934	2243	11	8C
0005432638925	2243	12	8D
0005432638924	2243	13	8F
0005432638947	2243	14	9D
0005432638926	2243	15	9E
0005432638919	2243	16	10C
0005432638928	2243	17	10E
0005432638951	2243	18	10F
0005432638949	2243	19	11D
0005432638935	2243	20	11F
0005432638933	2243	21	12E
0005432638941	2243	22	13A
0005432638945	2243	23	13C
0005432638942	2243	24	14C
0005432638944	2243	25	14F
0005432638920	2243	26	14E
0005432638938	2243	27	15A
0005432638915	2243	28	15D
0005432638930	2243	29	15E
0005432638921	2243	30	16C
0005432638927	2243	31	16E
0005432638918	2243	32	16F
0005432638950	2243	33	17A
0005432638952	2243	34	17D
0005432638916	2243	35	17F
0005432638931	2243	36	18C
0005432638940	2243	37	19C
0005432638946	2243	38	20E
0005434503566	6528	1	1A
0005434503547	6528	2	1F
0005434503553	6528	3	2D
0005435103819	6528	4	3A
0005434503560	6528	5	3D
0005434503544	6528	6	3F
0005434503540	6528	7	4A
0005434503549	6528	8	4D
0005434503557	6528	9	5D
0005434503568	6528	10	5E
0005434503565	6528	11	6D
0005434503552	6528	12	6E
0005434503548	6528	13	6F
0005434503563	6528	14	7C
0005434503550	6528	15	7E
0005434503562	6528	16	7F
0005434503554	6528	17	8C
0005434503564	6528	18	9A
0005434503556	6528	19	9C
0005434503573	6528	20	9D
0005434503569	6528	21	9F
0005434503541	6528	22	10C
0005434503555	6528	23	10E
0005434503574	6528	24	10F
0005434503542	6528	25	11A
0005434503559	6528	26	11D
0005435103820	6528	27	11E
0005434503571	6528	28	12F
0005434503558	6528	29	13A
0005434503567	6528	30	13C
0005434503570	6528	31	13D
0005434503546	6528	32	14A
0005434503537	6528	33	14D
0005434503572	6528	34	14F
0005434503545	6528	35	15D
0005434503576	6528	36	15F
0005434503575	6528	37	16D
0005434503551	6528	38	16E
0005435103822	6528	39	17A
0005434503539	6528	40	17C
0005435103823	6528	41	17F
0005434503543	6528	42	18A
0005435103821	6528	43	18C
0005434503577	6528	44	18E
0005435103824	6528	45	19D
0005434503538	6528	46	20A
0005434503561	6528	47	20C
0005435800080	6423	1	1B
0005435800079	6423	2	18C
0005435800077	6423	3	20D
0005435800081	6423	4	21C
0005435800078	6423	5	22D
0005435652367	1644	1	1D
0005435652382	1644	2	2D
0005435652351	1644	3	2F
0005435652365	1644	4	3A
0005435652357	1644	5	3F
0005435652340	1644	6	4A
0005435652354	1644	7	4C
0005435652377	1644	8	4D
0005435652374	1644	9	5E
0005435652348	1644	10	6C
0005435652373	1644	11	6D
0005435652376	1644	12	6E
0005435652350	1644	13	7A
0005435652343	1644	14	7C
0005435652379	1644	15	8C
0005435652341	1644	16	8E
0005435652349	1644	17	9A
0005435652383	1644	18	9E
0005435652352	1644	19	10D
0005435652355	1644	20	10E
0005435652346	1644	21	10F
0005435652381	1644	22	11A
0005435652364	1644	23	11D
0005435652370	1644	24	11E
0005435652358	1644	25	12A
0005435652366	1644	26	12C
0005435652344	1644	27	12E
0005435652372	1644	28	13A
0005435652380	1644	29	13D
0005435652368	1644	30	14C
0005435652342	1644	31	14E
0005435652359	1644	32	14F
0005435652345	1644	33	15D
0005435652361	1644	34	15F
0005435652375	1644	35	16C
0005435652353	1644	36	16F
0005435652362	1644	37	17C
0005435652356	1644	38	17D
0005435652347	1644	39	17F
0005435652360	1644	40	18D
0005435652378	1644	41	18F
0005435652369	1644	42	19D
0005435652371	1644	43	19F
0005435652363	1644	44	20C
0005433367308	21718	1	1C
0005433367332	21718	2	2A
0005433367295	21718	3	2C
0005433367299	21718	4	4C
0005433367315	21718	5	4E
0005433367311	21718	6	5A
0005433367314	21718	7	5C
0005433367306	21718	8	5E
0005433367302	21718	9	5F
0005433367319	21718	10	6A
0005433367317	21718	11	6C
0005433367310	21718	12	6F
0005433367307	21718	13	7F
0005433367331	21718	14	8C
0005433367312	21718	15	8E
0005433367304	21718	16	9A
0005433367326	21718	17	9C
0005433367330	21718	18	9D
0005433367329	21718	19	11E
0005433367300	21718	20	11F
0005433367320	21718	21	13C
0005433367327	21718	22	13D
0005433367305	21718	23	13F
0005433367322	21718	24	15A
0005433367297	21718	25	15D
0005433367321	21718	26	15E
0005433367298	21718	27	16E
0005433367313	21718	28	17C
0005433367323	21718	29	17E
0005433367324	21718	30	18A
0005433367296	21718	31	18D
0005433367316	21718	32	18F
0005433367303	21718	33	19A
0005433367309	21718	34	19C
0005433367301	21718	35	19D
0005433367318	21718	36	19E
0005433367325	21718	37	19F
0005433367328	21718	38	20A
0005435312764	23227	1	1A
0005435312766	23227	2	3B
0005435312765	23227	3	4B
0005435312767	23227	4	19D
0005435312769	23227	5	20B
0005435312768	23227	6	23A
0005433985218	4172	1	3C
0005433985216	4172	2	3D
0005433985250	4172	3	4A
0005433985231	4172	4	4E
0005433985255	4172	5	5C
0005433985247	4172	6	5D
0005433985215	4172	7	5E
0005433985259	4172	8	5F
0005433985234	4172	9	6A
0005433985230	4172	10	6C
0005433985239	4172	11	6D
0005433985222	4172	12	7A
0005433985219	4172	13	7C
0005433985225	4172	14	7E
0005433985252	4172	15	7F
0005433985256	4172	16	8A
0005433985238	4172	17	8C
0005433985236	4172	18	8E
0005433985243	4172	19	8F
0005433985242	4172	20	9A
0005433985257	4172	21	9C
0005433985213	4172	22	9D
0005433985253	4172	23	9E
0005433985224	4172	24	10A
0005433985229	4172	25	10D
0005433985246	4172	26	11A
0005433985260	4172	27	11C
0005433985248	4172	28	11E
0005433985227	4172	29	11F
0005433985232	4172	30	12A
0005433985228	4172	31	12D
0005433985240	4172	32	12E
0005433985244	4172	33	12F
0005435788731	4172	34	13C
0005433985249	4172	35	13D
0005433985235	4172	36	13E
0005433985233	4172	37	14E
0005433985237	4172	38	14F
0005433985254	4172	39	15E
0005433985223	4172	40	15F
0005433985220	4172	41	16A
0005433985217	4172	42	16D
0005433985226	4172	43	16E
0005433985245	4172	44	17F
0005433985221	4172	45	18D
0005433985251	4172	46	18E
0005433985241	4172	47	19D
0005433985214	4172	48	19F
0005435788732	4172	49	20A
0005433985212	4172	50	20D
0005433985258	4172	51	20E
0005433168309	21336	1	3A
0005433168303	21336	2	3C
0005433168306	21336	3	4A
0005433168305	21336	4	7A
0005433168308	21336	5	18B
0005433168311	21336	6	20D
0005433168304	21336	7	21A
0005433168307	21336	8	22D
0005433168310	21336	9	23B
0005434151662	17837	1	1F
0005432869429	17837	2	2D
0005432869426	17837	3	3A
0005432869425	17837	4	8D
0005434151660	17837	5	11E
0005432869428	17837	6	12F
0005432869424	17837	7	13A
0005434151661	17837	8	13C
0005432869427	17837	9	13F
0005432869430	17837	10	17E
0005432665240	26337	1	1C
0005432657399	26337	2	2A
0005432655336	26337	3	2F
0005432655337	26337	4	3C
0005432655330	26337	5	4A
0005432655326	26337	6	4E
0005432655335	26337	7	5D
0005432658556	26337	8	7A
0005432665239	26337	9	7F
0005432657396	26337	10	10E
0005432667419	26337	11	10F
0005432657397	26337	12	11D
0005432655328	26337	13	12C
0005432655331	26337	14	12F
0005432659672	26337	15	13F
0005432667418	26337	16	14A
0005432655332	26337	17	14C
0005432658555	26337	18	15A
0005432658557	26337	19	15C
0005432655333	26337	20	16C
0005432655334	26337	21	16E
0005432655327	26337	22	17E
0005432667420	26337	23	18D
0005432657398	26337	24	18E
0005432655329	26337	25	19C
0005432659671	26337	26	20E
0005432666354	26337	27	20F
0005432328001	3075	1	1A
0005432328023	3075	2	1C
0005432328006	3075	3	1D
0005433438780	3075	4	1F
0005432328017	3075	5	2C
0005432328009	3075	6	2D
0005432327987	3075	7	3A
0005432328004	3075	8	3C
0005432328024	3075	9	3D
0005432328027	3075	10	3F
0005432328005	3075	11	4D
0005432328000	3075	12	4E
0005432327993	3075	13	5A
0005432327995	3075	14	5C
0005432328030	3075	15	5D
0005432328016	3075	16	5F
0005433438784	3075	17	6A
0005432327988	3075	18	6D
0005432328011	3075	19	6F
0005432328014	3075	20	7A
0005432328008	3075	21	7C
0005432328002	3075	22	7D
0005432327986	3075	23	7F
0005432328029	3075	24	8A
0005432287112	3075	25	8C
0005432328022	3075	26	8D
0005432327989	3075	27	8E
0005432328013	3075	28	9A
0005432327991	3075	29	9C
0005432287115	3075	30	9D
0005433438781	3075	31	9F
0005433438779	3075	32	10A
0005433438783	3075	33	10E
0005432328028	3075	34	10F
0005433438777	3075	35	11C
0005432327998	3075	36	11E
0005432287110	3075	37	11F
0005432327985	3075	38	12D
0005432287113	3075	39	12E
0005432287114	3075	40	13A
0005432328025	3075	41	13F
0005432328021	3075	42	14A
0005432328020	3075	43	14C
0005432327997	3075	44	14E
0005432328031	3075	45	14F
0005432328010	3075	46	15E
0005432287111	3075	47	15F
0005432328003	3075	48	16D
0005433438782	3075	49	16E
0005432328015	3075	50	16F
0005432328019	3075	51	17E
0005432327994	3075	52	17F
0005432328018	3075	53	18A
0005432328012	3075	54	18D
0005432328007	3075	55	18E
0005432327996	3075	56	18F
0005432327990	3075	57	19C
0005432328026	3075	58	19D
0005432327992	3075	59	19F
0005433438778	3075	60	20E
0005432327999	3075	61	20F
0005432905034	31102	1	3C
0005432054261	31102	2	9C
0005432905029	31102	3	9F
0005432054258	31102	4	10C
0005432905035	31102	5	13F
0005432054259	31102	6	14C
0005432905030	31102	7	16A
0005432905033	31102	8	16D
0005432054260	31102	9	16F
0005432905032	31102	10	17C
0005432905031	31102	11	18D
0005432848836	31102	12	20E
0005434309530	6232	1	1A
0005434309531	6232	2	3A
0005434309538	6232	3	3D
0005435998992	6232	4	3F
0005434309537	6232	5	4E
0005434309534	6232	6	6A
0005435998993	6232	7	6C
0005434309539	6232	8	7A
0005434309540	6232	9	7B
0005434309541	6232	10	7C
0005432146168	6232	11	7D
0005434309532	6232	12	8E
0005435998986	6232	13	9B
0005435998998	6232	14	9E
0005435998994	6232	15	9F
0005435998991	6232	16	10B
0005435998997	6232	17	11B
0005435998987	6232	18	12A
0005432146169	6232	19	12D
0005434309533	6232	20	14E
0005435998990	6232	21	15A
0005434309542	6232	22	14F
0005434309535	6232	23	16E
0005435998988	6232	24	16F
0005435998996	6232	25	18A
0005432146167	6232	26	18B
0005434309536	6232	27	19C
0005432146170	6232	28	19B
0005435998995	6232	29	20F
0005435998985	6232	30	22C
0005435998989	6232	31	23B
0005435487480	19534	1	1D
0005435487495	19534	2	3A
0005435487491	19534	3	3D
0005435487476	19534	4	4F
0005435487478	19534	5	5A
0005435487489	19534	6	6A
0005435487493	19534	7	6E
0005435296953	19534	8	7A
0005435487484	19534	9	7F
0005435487488	19534	10	10B
0005435487479	19534	11	11D
0005435487486	19534	12	11F
0005435487483	19534	13	13A
0005435296952	19534	14	13C
0005435487490	19534	15	14E
0005435487496	19534	16	14F
0005435487494	19534	17	15C
0005435296955	19534	18	15B
0005435487487	19534	19	15D
0005435296951	19534	20	15E
0005435296957	19534	21	16E
0005435487482	19534	22	17A
0005435487485	19534	23	17F
0005435487481	19534	24	18D
0005435296954	19534	25	19C
0005435487497	19534	26	19D
0005435487475	19534	27	20B
0005435487492	19534	28	20D
0005435487477	19534	29	21B
0005435296956	19534	30	22E
0005433158098	17533	1	2A
0005433158095	17533	2	21B
0005433158097	17533	3	21C
0005433158096	17533	4	23A
0005435501986	1548	1	1A
0005435501989	1548	2	1F
0005434565708	1548	3	2C
0005435501997	1548	4	2D
0005434565715	1548	5	3D
0005435517637	1548	6	3F
0005435501988	1548	7	4A
0005435517647	1548	8	4C
0005435508189	1548	9	4E
0005434565713	1548	10	4F
0005435517630	1548	11	5A
0005434565716	1548	12	5C
0005434565711	1548	13	5D
0005435501983	1548	14	5E
0005435517640	1548	15	5F
0005435501993	1548	16	6A
0005435508190	1548	17	6C
0005435517646	1548	18	6D
0005435501982	1548	19	6E
0005434565709	1548	20	6F
0005435517644	1548	21	7E
0005435501991	1548	22	7F
0005435501984	1548	23	8A
0005434565710	1548	24	8C
0005435501992	1548	25	8D
0005435501980	1548	26	8F
0005435517634	1548	27	9A
0005435501978	1548	28	9C
0005434565717	1548	29	9D
0005435508195	1548	30	10C
0005435501985	1548	31	10D
0005435517635	1548	32	10E
0005435508196	1548	33	11A
0005435517645	1548	34	11C
0005435517636	1548	35	11D
0005435501979	1548	36	11E
0005435508197	1548	37	11F
0005435517641	1548	38	12A
0005435501995	1548	39	12C
0005435517629	1548	40	12E
0005435508198	1548	41	12F
0005435508194	1548	42	13C
0005435508188	1548	43	13D
0005435501994	1548	44	13E
0005435508185	1548	45	13F
0005432291893	1548	46	14E
0005435517631	1548	47	14F
0005434565707	1548	48	15A
0005435517633	1548	49	15F
0005435508186	1548	50	16A
0005434565714	1548	51	16D
0005435517638	1548	52	16E
0005435501990	1548	53	17A
0005435508191	1548	54	17C
0005435508187	1548	55	17D
0005435501996	1548	56	17E
0005435508193	1548	57	17F
0005435517632	1548	58	18C
0005434565706	1548	59	18D
0005435517642	1548	60	18E
0005435501977	1548	61	19A
0005435517639	1548	62	19C
0005435517643	1548	63	19D
0005435501976	1548	64	19E
0005434565712	1548	65	19F
0005435508192	1548	66	20A
0005435501987	1548	67	20C
0005432291894	1548	68	20D
0005435501975	1548	69	20E
0005435501981	1548	70	20F
0005433185989	20867	1	1A
0005433185987	20867	2	2C
0005433185988	20867	3	4E
0005433185985	20867	4	4F
0005433185993	20867	5	5F
0005433185994	20867	6	7C
0005433185992	20867	7	10F
0005433185986	20867	8	12A
0005433185990	20867	9	13E
0005433185991	20867	10	14E
0005435153643	3901	1	3A
0005435153645	3901	2	4D
0005435153644	3901	3	5A
0005435153640	3901	4	6A
0005435153641	3901	5	7C
0005435153642	3901	6	21C
0005435931544	21850	1	6B
0005435931545	21850	2	6C
0005435931543	21850	3	21C
0005432628622	7186	1	2A
0005432628619	7186	2	2C
0005432628617	7186	3	3C
0005432628624	7186	4	3D
0005432628628	7186	5	5A
0005432628620	7186	6	5D
0005432628625	7186	7	7A
0005432628621	7186	8	18A
0005432628623	7186	9	18B
0005432628630	7186	10	20B
0005432628626	7186	11	20D
0005432628618	7186	12	21A
0005432628629	7186	13	22D
0005432628627	7186	14	23B
0005435225466	28099	1	1C
0005435225465	28099	2	1B
0005435225460	28099	3	3C
0005435225464	28099	4	3D
0005435225462	28099	5	5A
0005435225463	28099	6	5D
0005435225459	28099	7	20D
0005435225461	28099	8	23A
0005435959992	8746	1	4A
0005435959991	8746	2	4B
0005435959993	8746	3	4D
0005435959990	8746	4	5A
0005434267891	15265	1	1C
0005434267892	15265	2	4C
0005434267893	15265	3	6D
0005432692589	1194	1	1C
0005432674897	1194	2	1D
0005432692567	1194	3	3A
0005432674899	1194	4	3D
0005432692570	1194	5	3C
0005432692566	1194	6	4D
0005432674895	1194	7	4C
0005432677508	1194	8	4F
0005432692575	1194	9	5A
0005432674901	1194	10	6D
0005432692584	1194	11	6B
0005432692586	1194	12	6E
0005432692559	1194	13	7C
0005432692563	1194	14	7B
0005432692569	1194	15	7D
0005432692574	1194	16	8C
0005432692581	1194	17	8F
0005432692585	1194	18	9B
0005432692576	1194	19	9A
0005432677507	1194	20	9D
0005432677510	1194	21	10C
0005432692587	1194	22	10E
0005432692571	1194	23	10D
0005432692577	1194	24	11A
0005432674908	1194	25	11C
0005432677509	1194	26	11F
0005432692578	1194	27	12A
0005432674894	1194	28	12D
0005432674906	1194	29	12C
0005432692561	1194	30	12F
0005432692560	1194	31	13A
0005432674902	1194	32	13C
0005432692588	1194	33	14B
0005432674893	1194	34	14E
0005432674898	1194	35	14C
0005432692568	1194	36	15B
0005432674903	1194	37	15A
0005432674905	1194	38	15C
0005432692582	1194	39	15E
0005432674907	1194	40	15F
0005432692579	1194	41	16C
0005432692564	1194	42	16E
0005432674900	1194	43	16D
0005432692562	1194	44	17A
0005432692573	1194	45	16F
0005432692565	1194	46	19A
0005432674904	1194	47	19C
0005432692572	1194	48	19D
0005432692583	1194	49	21C
0005432692580	1194	50	21E
0005432674896	1194	51	21F
0005432873186	17508	1	1C
0005432873183	17508	2	1A
0005432873184	17508	3	4D
0005432873181	17508	4	11C
0005432873182	17508	5	12E
0005432873185	17508	6	13C
0005432873180	17508	7	15C
0005434434954	1140	1	2C
0005434434951	1140	2	3B
0005434434942	1140	3	3C
0005434434943	1140	4	4C
0005434434945	1140	5	5A
0005434434944	1140	6	5B
0005434434949	1140	7	5C
0005434434953	1140	8	7A
0005434434950	1140	9	7D
0005434434952	1140	10	18C
0005434434955	1140	11	18D
0005434434948	1140	12	19D
0005434434946	1140	13	21A
0005434434947	1140	14	21B
0005434434941	1140	15	21D
0005433156621	17317	1	1B
0005433156618	17317	2	4D
0005433156613	17317	3	6D
0005433156620	17317	4	7C
0005433156614	17317	5	18B
0005433156617	17317	6	19A
0005433156616	17317	7	20A
0005433156619	17317	8	20D
0005433156615	17317	9	21D
0005435086719	4079	1	5B
0005435086717	4079	2	5C
0005435086720	4079	3	6A
0005435086721	4079	4	7B
0005435086716	4079	5	20B
0005435086718	4079	6	20C
0005435086722	4079	7	22B
0005435928071	24401	1	3B
0005435928068	24401	2	5A
0005435928069	24401	3	21B
0005435928070	24401	4	23A
0005435706133	2450	1	1D
0005435706113	2450	2	1F
0005435706132	2450	3	2C
0005435706100	2450	4	3C
0005435706135	2450	5	4A
0005435706114	2450	6	4C
0005435706122	2450	7	4E
0005435706112	2450	8	5A
0005435706127	2450	9	5C
0005435706108	2450	10	5F
0005435706105	2450	11	6A
0005435706118	2450	12	6D
0005435706134	2450	13	6F
0005435706125	2450	14	7A
0005435706110	2450	15	7C
0005435706121	2450	16	7D
0005435706144	2450	17	7E
0005435706129	2450	18	7F
0005435706119	2450	19	8A
0005435706103	2450	20	8D
0005435706120	2450	21	8F
0005435706101	2450	22	9C
0005435706141	2450	23	9D
0005435706130	2450	24	10A
0005435706097	2450	25	10C
0005435706139	2450	26	10D
0005435706143	2450	27	10E
0005435706138	2450	28	10F
0005435706106	2450	29	11A
0005435706126	2450	30	11D
0005435706136	2450	31	11E
0005435706109	2450	32	11F
0005435706142	2450	33	12A
0005435706131	2450	34	12F
0005435706140	2450	35	13A
0005435706123	2450	36	13E
0005435706124	2450	37	13F
0005435706107	2450	38	14E
0005435706096	2450	39	15C
0005435706128	2450	40	15D
0005435706115	2450	41	16C
0005435706099	2450	42	16F
0005435706117	2450	43	17C
0005435706116	2450	44	17D
0005435706098	2450	45	18A
0005435706095	2450	46	18C
0005435706111	2450	47	19E
0005435706102	2450	48	20A
0005435706104	2450	49	20D
0005435706137	2450	50	20E
0005433373382	27019	1	1C
0005433373397	27019	2	2C
0005433373395	27019	3	2D
0005433373392	27019	4	3A
0005433373375	27019	5	4C
0005433373391	27019	6	4F
0005433373378	27019	7	5C
0005433373377	27019	8	5F
0005433373389	27019	9	6C
0005433373374	27019	10	6F
0005433373379	27019	11	7C
0005433373399	27019	12	7E
0005433373402	27019	13	9A
0005433373400	27019	14	9E
0005433373381	27019	15	10A
0005433373380	27019	16	11C
0005433373387	27019	17	11D
0005433373376	27019	18	11F
0005433373394	27019	19	12C
0005433373388	27019	20	12E
0005433373385	27019	21	13A
0005433373398	27019	22	14A
0005433373386	27019	23	17C
0005433373393	27019	24	17D
0005433373384	27019	25	17F
0005433373401	27019	26	18F
0005433373383	27019	27	19F
0005433373396	27019	28	20D
0005433373390	27019	29	20E
0005434625813	4843	1	1A
0005434625821	4843	2	4C
0005434625815	4843	3	5D
0005434625818	4843	4	6D
0005434625819	4843	5	9A
0005434625814	4843	6	10A
0005434625822	4843	7	17C
0005434625817	4843	8	18E
0005434625820	4843	9	19C
0005434625816	4843	10	20D
0005435907430	32899	1	4C
0005435907429	32899	2	11E
0005435907431	32899	3	15E
0005435907428	32899	4	15F
0005435907426	32899	5	16A
0005435907427	32899	6	17D
0005432195660	13756	1	2D
0005432195661	13756	2	3B
0005435937326	13756	3	4D
0005435937323	13756	4	5C
0005435937325	13756	5	6C
0005435937319	13756	6	18B
0005435937322	13756	7	19B
0005435937321	13756	8	20C
0005435937320	13756	9	21B
0005435937324	13756	10	22A
0005435784780	27426	1	1A
0005435784789	27426	2	1B
0005432190566	27426	3	1C
0005435784776	27426	4	1D
0005435784792	27426	5	2A
0005435787320	27426	6	2B
0005435784794	27426	7	2C
0005435784796	27426	8	2D
0005435784790	27426	9	3C
0005435784768	27426	10	4A
0005435784765	27426	11	4B
0005435784774	27426	12	4C
0005435784797	27426	13	4D
0005435784766	27426	14	5B
0005435784775	27426	15	5C
0005435784798	27426	16	5D
0005432190567	27426	17	6A
0005435784767	27426	18	6B
0005435784793	27426	19	6C
0005435784784	27426	20	7A
0005432190565	27426	21	18A
0005435784779	27426	22	18B
0005435784785	27426	23	18C
0005435787321	27426	24	18D
0005435784783	27426	25	19B
0005435784791	27426	26	19C
0005435784772	27426	27	19D
0005435784769	27426	28	20B
0005435784788	27426	29	20C
0005435784764	27426	30	20D
0005435784786	27426	31	21A
0005435784787	27426	32	21B
0005435784777	27426	33	21C
0005435784781	27426	34	21D
0005435784795	27426	35	22A
0005435784773	27426	36	22B
0005435784782	27426	37	22C
0005435784778	27426	38	22D
0005435784771	27426	39	23A
0005435784770	27426	40	23B
0005432058323	20258	1	1F
0005435310876	20258	2	3F
0005435310890	20258	3	5A
0005432058322	20258	4	5D
0005435310883	20258	5	5E
0005435310893	20258	6	6A
0005435310882	20258	7	6D
0005435310879	20258	8	6F
0005432058320	20258	9	9C
0005435310888	20258	10	9F
0005435310881	20258	11	10C
0005435310880	20258	12	12C
0005432058321	20258	13	12D
0005435310894	20258	14	12E
0005435310878	20258	15	13C
0005435310885	20258	16	13F
0005435310877	20258	17	14C
0005435310884	20258	18	14D
0005432058324	20258	19	14F
0005435310887	20258	20	17A
0005435310891	20258	21	19C
0005435310892	20258	22	20D
0005435310886	20258	23	20E
0005435310889	20258	24	20F
0005434406774	26961	1	1A
0005434406769	26961	2	1C
0005434406770	26961	3	1D
0005434406790	26961	4	2A
0005432153832	26961	5	2F
0005434406829	26961	6	3A
0005434406809	26961	7	3C
0005434406824	26961	8	3F
0005434406784	26961	9	4A
0005434406817	26961	10	4C
0005434406772	26961	11	4D
0005434406810	26961	12	4E
0005434406822	26961	13	4F
0005434406777	26961	14	5C
0005432153831	26961	15	5D
0005434406799	26961	16	5E
0005434406807	26961	17	5F
0005434406825	26961	18	6A
0005434406785	26961	19	6C
0005434406818	26961	20	6D
0005434406828	26961	21	6E
0005434406773	26961	22	6F
0005434406795	26961	23	7A
0005434406797	26961	24	7C
0005434406826	26961	25	7E
0005434406811	26961	26	7F
0005434406793	26961	27	8A
0005434406796	26961	28	8C
0005434406791	26961	29	8F
0005434406804	26961	30	9C
0005434406806	26961	31	9D
0005434406765	26961	32	9E
0005434406812	26961	33	10A
0005434406801	26961	34	10C
0005434406768	26961	35	10D
0005434406767	26961	36	10E
0005434406814	26961	37	10F
0005434406775	26961	38	11A
0005434406823	26961	39	11C
0005434406808	26961	40	11D
0005432153833	26961	41	11E
0005434406815	26961	42	12A
0005434406800	26961	43	12E
0005434406802	26961	44	12F
0005434406782	26961	45	13A
0005434406794	26961	46	13D
0005434406827	26961	47	13E
0005434406787	26961	48	14A
0005434406778	26961	49	14C
0005434406803	26961	50	14E
0005434406821	26961	51	14F
0005434406789	26961	52	15A
0005434406816	26961	53	15E
0005434406780	26961	54	15F
0005434406820	26961	55	16F
0005434406792	26961	56	17A
0005432153828	26961	57	17C
0005434406781	26961	58	17D
0005434406771	26961	59	17F
0005434406813	26961	60	18A
0005434406805	26961	61	18C
0005434406819	26961	62	18D
0005434406788	26961	63	18F
0005434406786	26961	64	19A
0005434406783	26961	65	19C
0005432153829	26961	66	19D
0005434406766	26961	67	19E
0005432153830	26961	68	20A
0005434406779	26961	69	20D
0005434406776	26961	70	20E
0005434406798	26961	71	20F
0005434319179	5674	1	1D
0005434319177	5674	2	2C
0005434319171	5674	3	4A
0005434319173	5674	4	4D
0005434319169	5674	5	5A
0005434319183	5674	6	5F
0005434311187	5674	7	6D
0005432109661	5674	8	8C
0005434319172	5674	9	9C
0005434319170	5674	10	9D
0005434319182	5674	11	9E
0005434319180	5674	12	10A
0005434319178	5674	13	11A
0005434319167	5674	14	11D
0005434311185	5674	15	12E
0005434319166	5674	16	13E
0005434319164	5674	17	14C
0005434311186	5674	18	14D
0005434319176	5674	19	14F
0005432109660	5674	20	15C
0005434319168	5674	21	16F
0005434319185	5674	22	17D
0005434319165	5674	23	17E
0005434319181	5674	24	18A
0005434319175	5674	25	18E
0005434319174	5674	26	19C
0005434319184	5674	27	19E
0005433123623	15701	1	1D
0005433123624	15701	2	2A
0005433123613	15701	3	3C
0005433123629	15701	4	4A
0005433123619	15701	5	5E
0005433123626	15701	6	6A
0005433123611	15701	7	6D
0005433123614	15701	8	6F
0005433123616	15701	9	7D
0005433123618	15701	10	9D
0005433123627	15701	11	9E
0005433123617	15701	12	10F
0005433123633	15701	13	11D
0005433123622	15701	14	11E
0005433123620	15701	15	13C
0005433123615	15701	16	14E
0005433123632	15701	17	15D
0005433123631	15701	18	18A
0005433123625	15701	19	17F
0005433123612	15701	20	18D
0005433123621	15701	21	19D
0005433123628	15701	22	20D
0005433123630	15701	23	20F
0005435220289	31757	1	1A
0005435219167	31757	2	2B
0005435220288	31757	3	3C
0005435219169	31757	4	5A
0005435219170	31757	5	5B
0005435220287	31757	6	5D
0005435220488	31757	7	18A
0005435219166	31757	8	18B
0005435220290	31757	9	20B
0005435220286	31757	10	20C
0005435219168	31757	11	20D
0005435220285	31757	12	22B
0005434484250	8994	1	2A
0005434484246	8994	2	3C
0005434484247	8994	3	4A
0005434484248	8994	4	19C
0005434484245	8994	5	20D
0005434484249	8994	6	22A
0005434484251	8994	7	22D
0005434189088	16641	1	5C
0005434189091	16641	2	7A
0005434189092	16641	3	7C
0005434189087	16641	4	18A
0005434189089	16641	5	19A
0005434189090	16641	6	21B
0005433123624	7706	1	1A
0005433123617	7706	2	1F
0005433123611	7706	3	2A
0005433123632	7706	4	2F
0005433123620	7706	5	3C
0005433123623	7706	6	4C
0005433123627	7706	7	6A
0005433123625	7706	8	7A
0005433123612	7706	9	8F
0005433123622	7706	10	12D
0005433123618	7706	11	13C
0005433123629	7706	12	13E
0005433123615	7706	13	14E
0005433123630	7706	14	15C
0005433123621	7706	15	15E
0005433123619	7706	16	17C
0005433123633	7706	17	18C
0005433123614	7706	18	18D
0005433123631	7706	19	18E
0005433123616	7706	20	19A
0005433123628	7706	21	19C
0005433123626	7706	22	19D
0005433123613	7706	23	20F
0005432692613	7705	1	1A
0005432692616	7705	2	1C
0005433449641	7705	3	1D
0005432692599	7705	4	1F
0005433449646	7705	5	2A
0005432692592	7705	6	2C
0005433449628	7705	7	2D
0005432720502	7705	8	3A
0005432071528	7705	9	3C
0005432692602	7705	10	3D
0005432071530	7705	11	3F
0005433449636	7705	12	4A
0005432692620	7705	13	4C
0005432692617	7705	14	4D
0005432720491	7705	15	4F
0005432720497	7705	16	5A
0005432720500	7705	17	5D
0005432720492	7705	18	5E
0005432692612	7705	19	5F
0005432720485	7705	20	6A
0005433449645	7705	21	6C
0005433449640	7705	22	6E
0005432692615	7705	23	6F
0005432720493	7705	24	7A
0005432720508	7705	25	7C
0005432720496	7705	26	7D
0005432720509	7705	27	7E
0005432720489	7705	28	7F
0005432720486	7705	29	8C
0005432720488	7705	30	8F
0005432720498	7705	31	9C
0005432720494	7705	32	9D
0005432720504	7705	33	9E
0005432692605	7705	34	9F
0005432692609	7705	35	10A
0005432720501	7705	36	10C
0005433449633	7705	37	10D
0005432692595	7705	38	10E
0005433449644	7705	39	11C
0005433449631	7705	40	11D
0005432692600	7705	41	11E
0005432692598	7705	42	11F
0005432720487	7705	43	12A
0005432692596	7705	44	12C
0005432692606	7705	45	12D
0005433449635	7705	46	12E
0005432692594	7705	47	12F
0005432692590	7705	48	13A
0005433449629	7705	49	13C
0005433449639	7705	50	13E
0005432692610	7705	51	13F
0005433449637	7705	52	14A
0005433449632	7705	53	14C
0005433449643	7705	54	14D
0005432692593	7705	55	14E
0005433449642	7705	56	14F
0005432692597	7705	57	15A
0005432720506	7705	58	15C
0005432692608	7705	59	15D
0005433449647	7705	60	15E
0005433449634	7705	61	15F
0005432692601	7705	62	16A
0005432720495	7705	63	16C
0005433449638	7705	64	16D
0005432071529	7705	65	16E
0005432720483	7705	66	16F
0005433449648	7705	67	17A
0005432720499	7705	68	17C
0005432720507	7705	69	17D
0005432692604	7705	70	17E
0005432692619	7705	71	17F
0005432692607	7705	72	18A
0005432692621	7705	73	18C
0005432692591	7705	74	18D
0005433449649	7705	75	18F
0005432692611	7705	76	18E
0005432071527	7705	77	19A
0005432720490	7705	78	19C
0005432720484	7705	79	19E
0005432692614	7705	80	19F
0005433449630	7705	81	20A
0005432692618	7705	82	20C
0005432720503	7705	83	20D
0005432692603	7705	84	20E
0005432720505	7705	85	20F
0005433722118	30434	1	5D
0005433722120	30434	2	9F
0005433722119	30434	3	11A
0005434586218	1365	1	1D
0005434586233	1365	2	2A
0005434586222	1365	3	2F
0005434514927	1365	4	3A
0005434586228	1365	5	3C
0005434513539	1365	6	3D
0005434586234	1365	7	3F
0005433524874	1365	8	4A
0005434586211	1365	9	4C
0005434514926	1365	10	4D
0005433524870	1365	11	4F
0005433724736	1365	12	5C
0005434586223	1365	13	5D
0005433524876	1365	14	5E
0005434586225	1365	15	5F
0005434586217	1365	16	6C
0005434586216	1365	17	6D
0005433524878	1365	18	6E
0005434586229	1365	19	7A
0005434586232	1365	20	7D
0005433524879	1365	21	7F
0005433724734	1365	22	8A
0005434586210	1365	23	8C
0005434514928	1365	24	8E
0005434586209	1365	25	9D
0005433724735	1365	26	9E
0005434586213	1365	27	9F
0005433524875	1365	28	10C
0005433524880	1365	29	10D
0005434586221	1365	30	10F
0005434586230	1365	31	11D
0005433524877	1365	32	11E
0005433724738	1365	33	12E
0005434586219	1365	34	12F
0005434586231	1365	35	13E
0005434586215	1365	36	14C
0005434586227	1365	37	14E
0005432270960	1365	38	14F
0005433724733	1365	39	15C
0005433724737	1365	40	15E
0005434586226	1365	41	16A
0005433524873	1365	42	16C
0005434586212	1365	43	17C
0005433524872	1365	44	17E
0005434513538	1365	45	17F
0005434586224	1365	46	18A
0005432270961	1365	47	18E
0005434586214	1365	48	19C
0005434513540	1365	49	19D
0005434586235	1365	50	19E
0005433524871	1365	51	20A
0005434586220	1365	52	20C
0005433192844	18521	1	1A
0005433192848	18521	2	2C
0005433192847	18521	3	3C
0005433192842	18521	4	4C
0005432927890	18521	5	4F
0005432927892	18521	6	5F
0005432927893	18521	7	6F
0005433192845	18521	8	8F
0005432968804	18521	9	9C
0005433192846	18521	10	10A
0005432968805	18521	11	12A
0005433192840	18521	12	13D
0005432927891	18521	13	13F
0005433192839	18521	14	15A
0005432927896	18521	15	16E
0005433192843	18521	16	17C
0005433192841	18521	17	17D
0005432927895	18521	18	18E
0005433192838	18521	19	19C
0005432927894	18521	20	19E
0005433192849	18521	21	20A
0005434142549	11424	1	1A
0005434343626	11424	2	1B
0005434343628	11424	3	1C
0005434343624	11424	4	1D
0005434142551	11424	5	2A
0005434343640	11424	6	2B
0005434343647	11424	7	2C
0005434343648	11424	8	3A
0005434343632	11424	9	3B
0005434343625	11424	10	3D
0005434343631	11424	11	4A
0005434343636	11424	12	4C
0005434343637	11424	13	4D
0005434343634	11424	14	5B
0005434343650	11424	15	5C
0005434142550	11424	16	5D
0005434343629	11424	17	6B
0005434343646	11424	18	6D
0005434343649	11424	19	7A
0005434142553	11424	20	7B
0005434343633	11424	21	7C
0005434343645	11424	22	18A
0005434142548	11424	23	18B
0005434343642	11424	24	18C
0005434343630	11424	25	18D
0005434343641	11424	26	19A
0005434343618	11424	27	19C
0005434343620	11424	28	19D
0005434343619	11424	29	20A
0005434343643	11424	30	20B
0005434343622	11424	31	20C
0005434343638	11424	32	20D
0005434343617	11424	33	21A
0005434343635	11424	34	21C
0005434343639	11424	35	21D
0005434142552	11424	36	22A
0005434343627	11424	37	22B
0005434343623	11424	38	22C
0005434343621	11424	39	22D
0005434343644	11424	40	23A
0005435304102	29759	1	2B
0005435304990	29759	2	3B
0005435304101	29759	3	6A
0005435304099	29759	4	6C
0005435304991	29759	5	7A
0005435304994	29759	6	18B
0005435304103	29759	7	19B
0005435304992	29759	8	20B
0005435304100	29759	9	20D
0005435304993	29759	10	21C
0005435824221	1253	1	2C
0005435824212	1253	2	4F
0005435824209	1253	3	5D
0005435824216	1253	4	5A
0005435824219	1253	5	6B
0005435824211	1253	6	6D
0005435824217	1253	7	7B
0005435824207	1253	8	7D
0005435824228	1253	9	8B
0005435824206	1253	10	10D
0005435824220	1253	11	11B
0005432284514	1253	12	11D
0005435824231	1253	13	11F
0005435824224	1253	14	12D
0005435824227	1253	15	14C
0005435824225	1253	16	14A
0005435824223	1253	17	14E
0005435824229	1253	18	16A
0005435824214	1253	19	16B
0005435824230	1253	20	17E
0005432284513	1253	21	17F
0005435824222	1253	22	18C
0005435824215	1253	23	18D
0005435824210	1253	24	19A
0005435824226	1253	25	19E
0005435824208	1253	26	20B
0005435824213	1253	27	20E
0005435824218	1253	28	21B
0005435824232	1253	29	21E
0005433415426	17975	1	1D
0005433415420	17975	2	5A
0005433415423	17975	3	6B
0005433415419	17975	4	6E
0005433415412	17975	5	8C
0005433415415	17975	6	9B
0005433415418	17975	7	10C
0005433415411	17975	8	10D
0005433415422	17975	9	12A
0005433415414	17975	10	14D
0005433415413	17975	11	15B
0005433415416	17975	12	16A
0005433415424	17975	13	18B
0005433415421	17975	14	19A
0005433415425	17975	15	19D
0005433415417	17975	16	21A
0005432782957	5660	1	1A
0005432782958	5660	2	1C
0005432782953	5660	3	2D
0005432782984	5660	4	2F
0005432782987	5660	5	3A
0005432782962	5660	6	3C
0005432782955	5660	7	4A
0005432782968	5660	8	4E
0005432783000	5660	9	4F
0005432783002	5660	10	5A
0005432143936	5660	11	5C
0005432782981	5660	12	5E
0005432782982	5660	13	5F
0005432782977	5660	14	6A
0005432782994	5660	15	6C
0005432782961	5660	16	6E
0005432782989	5660	17	6F
0005432782965	5660	18	7D
0005432782949	5660	19	8A
0005432782990	5660	20	8C
0005432782998	5660	21	8D
0005432782979	5660	22	8E
0005432782975	5660	23	8F
0005432782997	5660	24	9A
0005432782950	5660	25	9C
0005432782964	5660	26	9D
0005432782996	5660	27	9E
0005432143937	5660	28	9F
0005432782983	5660	29	10A
0005432782978	5660	30	10E
0005432782985	5660	31	10F
0005432782952	5660	32	11C
0005432782993	5660	33	11D
0005432782992	5660	34	12E
0005432782972	5660	35	12F
0005432782956	5660	36	13A
0005432782969	5660	37	13C
0005432782970	5660	38	13E
0005432782967	5660	39	14D
0005432782986	5660	40	14F
0005432782991	5660	41	15D
0005432782951	5660	42	16D
0005432782976	5660	43	16E
0005432782973	5660	44	16F
0005432782959	5660	45	17A
0005432782995	5660	46	17C
0005432782974	5660	47	17D
0005432782960	5660	48	17E
0005432782966	5660	49	18A
0005432782963	5660	50	18E
0005432782954	5660	51	19A
0005432143938	5660	52	19C
0005432782999	5660	53	19D
0005432782980	5660	54	19E
0005432782988	5660	55	19F
0005432783001	5660	56	20A
0005432782971	5660	57	20D
0005435242429	15358	1	1D
0005435476654	15358	2	1F
0005435242421	15358	3	2A
0005435242424	15358	4	2F
0005435242426	15358	5	3A
0005435242419	15358	6	3F
0005435242417	15358	7	4C
0005435242438	15358	8	4E
0005435242420	15358	9	4F
0005435242442	15358	10	5C
0005435242436	15358	11	6F
0005435242425	15358	12	7A
0005435242435	15358	13	7F
0005435242432	15358	14	8A
0005435242430	15358	15	8C
0005435242439	15358	16	8D
0005435476653	15358	17	8E
0005435242416	15358	18	9F
0005435476652	15358	19	10D
0005435242440	15358	20	11A
0005435242434	15358	21	12A
0005435242431	15358	22	12E
0005435242427	15358	23	13D
0005435242441	15358	24	13E
0005435242422	15358	25	14C
0005435242437	15358	26	14E
0005435242423	15358	27	15D
0005435242428	15358	28	17D
0005435242418	15358	29	18F
0005435242433	15358	30	19C
0005432848089	4372	1	1C
0005432848094	4372	2	2D
0005432848086	4372	3	4A
0005432848099	4372	4	4D
0005432848092	4372	5	5A
0005434462756	4372	6	5C
0005432848098	4372	7	6B
0005434462757	4372	8	7A
0005434463897	4372	9	18A
0005432848097	4372	10	18C
0005432848093	4372	11	19B
0005432848091	4372	12	20A
0005434463896	4372	13	20C
0005434462758	4372	14	20D
0005432848090	4372	15	21A
0005432848087	4372	16	21B
0005432848095	4372	17	21D
0005432848096	4372	18	22A
0005432848085	4372	19	23A
0005432848088	4372	20	23B
0005435850773	28836	1	1B
0005435850774	28836	2	3A
0005435850775	28836	3	4B
0005435850768	28836	4	5A
0005435850772	28836	5	5D
0005435850771	28836	6	6D
0005435850770	28836	7	7B
0005435850769	28836	8	19A
0005435850767	28836	9	21C
0005434925336	6349	1	1A
0005434925321	6349	2	1C
0005433496502	6349	3	1D
0005432075178	6349	4	2A
0005434925337	6349	5	2D
0005433496504	6349	6	2F
0005433496507	6349	7	3A
0005433496490	6349	8	3C
0005434925327	6349	9	3F
0005434443467	6349	10	4A
0005434925332	6349	11	4C
0005434925307	6349	12	4D
0005434443459	6349	13	4E
0005434443456	6349	14	4F
0005433496508	6349	15	5A
0005434925308	6349	16	5C
0005434443465	6349	17	5D
0005434443464	6349	18	5E
0005434925339	6349	19	5F
0005433496510	6349	20	6A
0005434925326	6349	21	6C
0005433496499	6349	22	6D
0005433496513	6349	23	6E
0005432075177	6349	24	6F
0005433496511	6349	25	7A
0005434925323	6349	26	7C
0005433496494	6349	27	7D
0005434925329	6349	28	7E
0005434925311	6349	29	7F
0005434925318	6349	30	8C
0005434925306	6349	31	8D
0005434925333	6349	32	8E
0005434925317	6349	33	8F
0005433496483	6349	34	9A
0005434443458	6349	35	9C
0005434443466	6349	36	9D
0005433496500	6349	37	9E
0005434443470	6349	38	9F
0005434925319	6349	39	10A
0005433496489	6349	40	10D
0005433496496	6349	41	10E
0005433496512	6349	42	10F
0005434925310	6349	43	11A
0005433496492	6349	44	11C
0005434443472	6349	45	11D
0005434925320	6349	46	11E
0005432075176	6349	47	11F
0005434925325	6349	48	12A
0005433496488	6349	49	12C
0005434443463	6349	50	12D
0005434925342	6349	51	12E
0005434443460	6349	52	12F
0005433496486	6349	53	13A
0005432075179	6349	54	13E
0005433496506	6349	55	13F
0005434443471	6349	56	14A
0005434925314	6349	57	14C
0005434443462	6349	58	14D
0005433496509	6349	59	14E
0005433496485	6349	60	14F
0005433496498	6349	61	15A
0005434925312	6349	62	15C
0005434925341	6349	63	15D
0005434925338	6349	64	15E
0005434925315	6349	65	15F
0005434925340	6349	66	16A
0005434925330	6349	67	16C
0005434925313	6349	68	16D
0005434925334	6349	69	16E
0005433496487	6349	70	16F
0005433496505	6349	71	17A
0005434925335	6349	72	17C
0005433496484	6349	73	17D
0005433496493	6349	74	17E
0005433496495	6349	75	17F
0005434925309	6349	76	18A
0005434925324	6349	77	18C
0005433496491	6349	78	18D
0005434925328	6349	79	18E
0005434925316	6349	80	18F
0005433496501	6349	81	19A
0005434443461	6349	82	19C
0005434925322	6349	83	19D
0005433496497	6349	84	19E
0005434443468	6349	85	19F
0005433496503	6349	86	20A
0005434443457	6349	87	20C
0005434925331	6349	88	20D
0005434443469	6349	89	20E
0005433496443	20394	1	12D
0005433496444	20394	2	18F
0005435242445	12174	1	1A
0005435242453	12174	2	1F
0005435242459	12174	3	2D
0005435242467	12174	4	4A
0005435242456	12174	5	6C
0005435242469	12174	6	7C
0005435242461	12174	7	8A
0005435242451	12174	8	8C
0005435242444	12174	9	8D
0005435242460	12174	10	8E
0005435242455	12174	11	9F
0005435242454	12174	12	10E
0005435242466	12174	13	11C
0005435242463	12174	14	12E
0005435242443	12174	15	13F
0005435242449	12174	16	14D
0005435242470	12174	17	14F
0005435242465	12174	18	15C
0005435242446	12174	19	15D
0005435242457	12174	20	16C
0005435242448	12174	21	17A
0005435242452	12174	22	17C
0005435242447	12174	23	18F
0005435242464	12174	24	19A
0005435242450	12174	25	19E
0005435242462	12174	26	20A
0005435242468	12174	27	20C
0005435242458	12174	28	20D
0005432782926	15400	1	2D
0005432782903	15400	2	2F
0005432782915	15400	3	3A
0005432782897	15400	4	3C
0005432782895	15400	5	3F
0005432782904	15400	6	4A
0005432782913	15400	7	4C
0005432782916	15400	8	4D
0005432782932	15400	9	5A
0005432782896	15400	10	5C
0005432782914	15400	11	5F
0005432782930	15400	12	6A
0005432782921	15400	13	6D
0005432782948	15400	14	6E
0005432782901	15400	15	6F
0005432782900	15400	16	7A
0005432782927	15400	17	7C
0005432782905	15400	18	7F
0005432782909	15400	19	8E
0005432782893	15400	20	8F
0005432782943	15400	21	9C
0005432782935	15400	22	9D
0005432782923	15400	23	9E
0005432782941	15400	24	9F
0005432782939	15400	25	10D
0005432782931	15400	26	10E
0005432782918	15400	27	10F
0005432782912	15400	28	11A
0005432782908	15400	29	11D
0005432782947	15400	30	11E
0005432782911	15400	31	12A
0005432782942	15400	32	12C
0005432782899	15400	33	12E
0005432782928	15400	34	13A
0005432782938	15400	35	13C
0005432782945	15400	36	13D
0005432782940	15400	37	14A
0005432782898	15400	38	14F
0005432782946	15400	39	15A
0005432782920	15400	40	15C
0005432782907	15400	41	15D
0005432782933	15400	42	15E
0005432782906	15400	43	15F
0005432782919	15400	44	16A
0005432782894	15400	45	16F
0005432782937	15400	46	17A
0005432782917	15400	47	17D
0005432782929	15400	48	18C
0005432782922	15400	49	18F
0005432782925	15400	50	19A
0005432782910	15400	51	19E
0005432782936	15400	52	19F
0005432782944	15400	53	20C
0005432782924	15400	54	20D
0005432782934	15400	55	20E
0005432782902	15400	56	20F
0005434876770	14596	1	1A
0005434876824	14596	2	1F
0005434876800	14596	3	1D
0005434876807	14596	4	2A
0005434876777	14596	5	2F
0005434876830	14596	6	2D
0005434876789	14596	7	3A
0005434876813	14596	8	3D
0005434876811	14596	9	3C
0005434876835	14596	10	4A
0005434876787	14596	11	3F
0005434876804	14596	12	4D
0005434876771	14596	13	4C
0005434876797	14596	14	5A
0005434876844	14596	15	4F
0005434876776	14596	16	5C
0005434876815	14596	17	5D
0005434876798	14596	18	6B
0005434876758	14596	19	6A
0005434876793	14596	20	5F
0005434876790	14596	21	6D
0005434876832	14596	22	6F
0005434876806	14596	23	6E
0005434876827	14596	24	7A
0005434876750	14596	25	7C
0005434876751	14596	26	7B
0005434876765	14596	27	7E
0005434876836	14596	28	7D
0005434876839	14596	29	7F
0005434876753	14596	30	8B
0005434876846	14596	31	8E
0005434876773	14596	32	8C
0005434876814	14596	33	9A
0005434876761	14596	34	9C
0005434876796	14596	35	9B
0005434876818	14596	36	9E
0005434876780	14596	37	9D
0005434876762	14596	38	10A
0005434876756	14596	39	10C
0005434876799	14596	40	10B
0005434876759	14596	41	10E
0005434876826	14596	42	10D
0005434876794	14596	43	11A
0005434876841	14596	44	10F
0005434876840	14596	45	11D
0005434876825	14596	46	11C
0005434876833	14596	47	11F
0005434876779	14596	48	11E
0005434876769	14596	49	12A
0005434876831	14596	50	12D
0005434876795	14596	51	12C
0005434876767	14596	52	12F
0005434876782	14596	53	12E
0005434876752	14596	54	13A
0005434876809	14596	55	13C
0005434876791	14596	56	13D
0005434876828	14596	57	14A
0005434876805	14596	58	13F
0005434758858	14596	59	14B
0005434876816	14596	60	14D
0005434876786	14596	61	14C
0005434876763	14596	62	14F
0005434876819	14596	63	14E
0005434876801	14596	64	15B
0005434876781	14596	65	15A
0005434876803	14596	66	15D
0005434876838	14596	67	15C
0005434876785	14596	68	15F
0005434876842	14596	69	15E
0005434876757	14596	70	16A
0005434876802	14596	71	16C
0005434876768	14596	72	16D
0005434876764	14596	73	16F
0005434876837	14596	74	17B
0005434876792	14596	75	17A
0005434876775	14596	76	17D
0005434876820	14596	77	17C
0005434876843	14596	78	17F
0005434876783	14596	79	17E
0005434876778	14596	80	18A
0005434876754	14596	81	18C
0005434876784	14596	82	18E
0005434876810	14596	83	18D
0005434876749	14596	84	19A
0005434876766	14596	85	18F
0005434758857	14596	86	19C
0005434876755	14596	87	19B
0005434876774	14596	88	19E
0005434876808	14596	89	19D
0005434876822	14596	90	19F
0005434876829	14596	91	20B
0005434876772	14596	92	20D
0005434876788	14596	93	20C
0005434876812	14596	94	20F
0005434876821	14596	95	20E
0005434876760	14596	96	21B
0005434876834	14596	97	21D
0005434876823	14596	98	21C
0005434876845	14596	99	21E
0005434876817	14596	100	21F
0005435659962	9233	1	1A
0005435659965	9233	2	4A
0005435659964	9233	3	4C
0005435659968	9233	4	6C
0005435659970	9233	5	6D
0005435659963	9233	6	7D
0005435659960	9233	7	18B
0005435659966	9233	8	20A
0005435659961	9233	9	20C
0005435659967	9233	10	21B
0005435659969	9233	11	21C
0005434251824	24661	1	1B
0005434251822	24661	2	1C
0005434251817	24661	3	1D
0005434251815	24661	4	3B
0005434251823	24661	5	3D
0005434251821	24661	6	18C
0005434251820	24661	7	19C
0005434251818	24661	8	20C
0005434251819	24661	9	21D
0005434251816	24661	10	23B
0005433679820	2767	1	1A
0005433679841	2767	2	1C
0005433679812	2767	3	1D
0005433679853	2767	4	2A
0005433679813	2767	5	2C
0005433679834	2767	6	3A
0005433679835	2767	7	2F
0005433679815	2767	8	3D
0005433679842	2767	9	4C
0005432222701	2767	10	4E
0005432222699	2767	11	4F
0005433679816	2767	12	5A
0005433679849	2767	13	5C
0005433679819	2767	14	5D
0005432222700	2767	15	5E
0005433679817	2767	16	6C
0005433679822	2767	17	8A
0005433679850	2767	18	8D
0005433679847	2767	19	8F
0005433679809	2767	20	9C
0005433679827	2767	21	9D
0005433679839	2767	22	9E
0005432222702	2767	23	10A
0005433679845	2767	24	10C
0005433679848	2767	25	10E
0005433679823	2767	26	10F
0005433679808	2767	27	11C
0005433679844	2767	28	11E
0005433679825	2767	29	11F
0005433679821	2767	30	12C
0005433684387	2767	31	12D
0005433679826	2767	32	12E
0005433679829	2767	33	12F
0005433679838	2767	34	13A
0005433679852	2767	35	13C
0005433679830	2767	36	13D
0005433679811	2767	37	13E
0005433679807	2767	38	14A
0005433679843	2767	39	14C
0005432222698	2767	40	14D
0005433679828	2767	41	15C
0005433684386	2767	42	15E
0005433679818	2767	43	15F
0005433679854	2767	44	17A
0005433679851	2767	45	17D
0005433679837	2767	46	17E
0005433684388	2767	47	17F
0005433679833	2767	48	18A
0005433679840	2767	49	18E
0005433679832	2767	50	19A
0005433679824	2767	51	19C
0005433679846	2767	52	19D
0005433679814	2767	53	19E
0005433679831	2767	54	19F
0005433679810	2767	55	20E
0005433679836	2767	56	20F
0005432966533	29178	1	2D
0005432966534	29178	2	3D
0005432966536	29178	3	3F
0005432966547	29178	4	4C
0005432966538	29178	5	4E
0005432966537	29178	6	5C
0005432966535	29178	7	5D
0005432005171	29178	8	5E
0005432966553	29178	9	6C
0005432966546	29178	10	6E
0005432966539	29178	11	6F
0005432966541	29178	12	7A
0005432966542	29178	13	8F
0005432005172	29178	14	10C
0005432966554	29178	15	10E
0005432966540	29178	16	10F
0005432005170	29178	17	11C
0005432005169	29178	18	12C
0005432966555	29178	19	12D
0005432966549	29178	20	12F
0005432966545	29178	21	13C
0005432966552	29178	22	13D
0005432966557	29178	23	14D
0005432966544	29178	24	14F
0005432966550	29178	25	15D
0005432966551	29178	26	16E
0005432966556	29178	27	17C
0005432966548	29178	28	19C
0005432966543	29178	29	19D
0005432966532	29178	30	19E
0005433633268	9276	1	1A
0005433613521	9276	2	1F
0005433577590	9276	3	2A
0005433613486	9276	4	2D
0005433613477	9276	5	2C
0005433633250	9276	6	2F
0005433613475	9276	7	3C
0005433577589	9276	8	3F
0005433633280	9276	9	3D
0005433613495	9276	10	4A
0005433613516	9276	11	4C
0005433613481	9276	12	5A
0005433613530	9276	13	5F
0005433633272	9276	14	5D
0005433633256	9276	15	6A
0005433577591	9276	16	6D
0005433633270	9276	17	6F
0005433613527	9276	18	7F
0005433613507	9276	19	8B
0005433613469	9276	20	8D
0005433613534	9276	21	8C
0005433633276	9276	22	8E
0005433577595	9276	23	8F
0005433633271	9276	24	9A
0005433613498	9276	25	9C
0005433613482	9276	26	9D
0005433613470	9276	27	9E
0005433633265	9276	28	10A
0005433633277	9276	29	10B
0005433613518	9276	30	10D
0005433613526	9276	31	10C
0005433613480	9276	32	10F
0005433633259	9276	33	10E
0005433613461	9276	34	11B
0005433633279	9276	35	11C
0005433613522	9276	36	11D
0005433613512	9276	37	11F
0005433633253	9276	38	11E
0005433613485	9276	39	12A
0005433613483	9276	40	12B
0005433577597	9276	41	12C
0005433613532	9276	42	12D
0005433633258	9276	43	12F
0005433633261	9276	44	12E
0005433613519	9276	45	13A
0005433577588	9276	46	13C
0005433613506	9276	47	13D
0005433633278	9276	48	13E
0005432756795	9276	49	14A
0005433633266	9276	50	13F
0005432756796	9276	51	14D
0005433633251	9276	52	14C
0005432755025	9276	53	14E
0005433633262	9276	54	14F
0005433633273	9276	55	15A
0005433633252	9276	56	15C
0005433633263	9276	57	15B
0005433613523	9276	58	15E
0005433633281	9276	59	16A
0005433577593	9276	60	15F
0005433633267	9276	61	16C
0005433613478	9276	62	16D
0005433613465	9276	63	17B
0005433613490	9276	64	17A
0005433613535	9276	65	17D
0005433577601	9276	66	17F
0005433613515	9276	67	17E
0005433633257	9276	68	18A
0005433613476	9276	69	18B
0005433613517	9276	70	18D
0005433633249	9276	71	18C
0005433613505	9276	72	18E
0005433613468	9276	73	19B
0005433613502	9276	74	19C
0005433613493	9276	75	19E
0005433613508	9276	76	20B
0005433613471	9276	77	20A
0005432145078	9276	78	20C
0005433613467	9276	79	20D
0005433613513	9276	80	20F
0005433613510	9276	81	21D
0005433613474	9276	82	21C
0005433633248	9276	83	21E
0005433613499	9276	84	21F
0005433613511	9276	85	22B
0005432756794	9276	86	22D
0005433613533	9276	87	22C
0005433613472	9276	88	22E
0005433633254	9276	89	23B
0005433633255	9276	90	23D
0005433613524	9276	91	23E
0005433613491	9276	92	24B
0005433577598	9276	93	24A
0005433613466	9276	94	24D
0005433633260	9276	95	24C
0005433577592	9276	96	24F
0005433613463	9276	97	24E
0005433613525	9276	98	25B
0005433577594	9276	99	25A
0005433613509	9276	100	25C
0005433613462	9276	101	25D
0005433613504	9276	102	25E
0005433613464	9276	103	26A
0005433577599	9276	104	25F
0005433613492	9276	105	26C
0005433613479	9276	106	26B
0005433633275	9276	107	26E
0005433613487	9276	108	26D
0005433633274	9276	109	27B
0005433613528	9276	110	27A
0005433613494	9276	111	27C
0005433613529	9276	112	27D
0005433613520	9276	113	27E
0005433577596	9276	114	28A
0005433633269	9276	115	27F
0005433633282	9276	116	28B
0005433613496	9276	117	28C
0005433613500	9276	118	28E
0005432755023	9276	119	28D
0005433577600	9276	120	28F
0005433613489	9276	121	29A
0005432755021	9276	122	29E
0005432755022	9276	123	29D
0005433633264	9276	124	30A
0005433613514	9276	125	30B
0005433613488	9276	126	30C
0005433613501	9276	127	30E
0005432755024	9276	128	30D
0005433613473	9276	129	30F
0005433613531	9276	130	31B
0005433577602	9276	131	31A
0005433613497	9276	132	31E
0005433613503	9276	133	31D
0005433613484	9276	134	31F
0005434163474	25237	1	3C
0005434163477	25237	2	5D
0005434273049	25237	3	8D
0005434163471	25237	4	9F
0005434163472	25237	5	10A
0005434273048	25237	6	12F
0005434163480	25237	7	13C
0005434163473	25237	8	13B
0005434272163	25237	9	16D
0005434163470	25237	10	17D
0005434163479	25237	11	21C
0005434272164	25237	12	25C
0005434163475	25237	13	27D
0005434163476	25237	14	30A
0005434163478	25237	15	31D
0005435986658	4205	1	1F
0005432184906	4205	2	1H
0005435986657	4205	3	3H
0005435986663	4205	4	9B
0005435986660	4205	5	18G
0005435986667	4205	6	23B
0005432184907	4205	7	23F
0005435986665	4205	8	24A
0005435986662	4205	9	24F
0005435986668	4205	10	25F
0005435986669	4205	11	28A
0005435986664	4205	12	29H
0005435986659	4205	13	33D
0005432184908	4205	14	36D
0005435986666	4205	15	36H
0005435986661	4205	16	38E
0005435947032	26564	1	1H
0005435947029	26564	2	4A
0005435947040	26564	3	4B
0005435947038	26564	4	12H
0005435947034	26564	5	15D
0005435947033	26564	6	17A
0005435856138	26564	7	19H
0005435947030	26564	8	23A
0005435947035	26564	9	22H
0005432571265	26564	10	28G
0005435856139	26564	11	28F
0005435947028	26564	12	29D
0005435947026	26564	13	30F
0005435947039	26564	14	30H
0005435947027	26564	15	31G
0005432571264	26564	16	33B
0005435947031	26564	17	33E
0005432571266	26564	18	35B
0005435856141	26564	19	35A
0005435947036	26564	20	36A
0005435947041	26564	21	37B
0005432571267	26564	22	37H
0005435856140	26564	23	39E
0005435947037	26564	24	39F
0005433568188	358	1	1A
0005433568187	358	2	1D
0005433568134	358	3	3F
0005433568126	358	4	4A
0005432238840	358	5	4F
0005433568165	358	6	4D
0005433568190	358	7	5A
0005433568173	358	8	5C
0005433568147	358	9	5D
0005433568135	358	10	6C
0005433568136	358	11	6F
0005433568144	358	12	6D
0005433568183	358	13	7D
0005433568129	358	14	8A
0005433568167	358	15	8B
0005433568162	358	16	8E
0005433568164	358	17	9D
0005433568139	358	18	9E
0005433568184	358	19	10A
0005433568149	358	20	10D
0005433568142	358	21	10C
0005433568163	358	22	10E
0005433568185	358	23	11B
0005433568157	358	24	11C
0005433568156	358	25	12D
0005433568125	358	26	13C
0005433568160	358	27	13D
0005433568170	358	28	13E
0005433568153	358	29	14C
0005433568189	358	30	14E
0005433568152	358	31	15A
0005433568151	358	32	15D
0005433568180	358	33	15E
0005433568186	358	34	16A
0005433568182	358	35	16D
0005433568140	358	36	16C
0005433568141	358	37	16E
0005433568169	358	38	16F
0005433568158	358	39	17A
0005433568178	358	40	17B
0005433568159	358	41	17D
0005433568150	358	42	18A
0005433568138	358	43	19B
0005433568176	358	44	20A
0005433568128	358	45	20C
0005433568191	358	46	21B
0005432238843	358	47	21C
0005433568168	358	48	21F
0005433568175	358	49	22E
0005433568143	358	50	22D
0005433568132	358	51	23B
0005433568181	358	52	23D
0005433568161	358	53	23F
0005433568145	358	54	24C
0005433568172	358	55	24E
0005433568127	358	56	25C
0005433568137	358	57	25F
0005433568179	358	58	25E
0005433568130	358	59	26A
0005433568154	358	60	26B
0005433568177	358	61	26D
0005432238845	358	62	27A
0005432238842	358	63	27D
0005433568166	358	64	27F
0005433568171	358	65	28B
0005433568131	358	66	29A
0005432238844	358	67	29E
0005433568146	358	68	29F
0005432238841	358	69	30B
0005433568155	358	70	30C
0005433568148	358	71	30E
0005433568124	358	72	30F
0005433568174	358	73	31B
0005433568133	358	74	31E
0005433074278	11570	1	1D
0005433074283	11570	2	2C
0005432947812	11570	3	3A
0005432947834	11570	4	2F
0005432947842	11570	5	4A
0005432947839	11570	6	4C
0005432192270	11570	7	5A
0005433074267	11570	8	4F
0005433074264	11570	9	5C
0005432947811	11570	10	6F
0005432947829	11570	11	7A
0005432947840	11570	12	7F
0005432947809	11570	13	7D
0005432947832	11570	14	8A
0005433131635	11570	15	8B
0005432192272	11570	16	8F
0005433074280	11570	17	9A
0005432947820	11570	18	9E
0005433134065	11570	19	10A
0005433134069	11570	20	10B
0005432947805	11570	21	10C
0005432947830	11570	22	10E
0005432947831	11570	23	10F
0005432947838	11570	24	11A
0005433074260	11570	25	11F
0005433074276	11570	26	12A
0005433074269	11570	27	12D
0005433074263	11570	28	13A
0005432947836	11570	29	12F
0005432947843	11570	30	13C
0005433074282	11570	31	13F
0005432947833	11570	32	13E
0005432947841	11570	33	14A
0005432947845	11570	34	14B
0005433074274	11570	35	14D
0005433131637	11570	36	14C
0005433074262	11570	37	14E
0005433074271	11570	38	14F
0005433074272	11570	39	15E
0005433131638	11570	40	16D
0005432947837	11570	41	16F
0005432947814	11570	42	17B
0005433131636	11570	43	19B
0005433074268	11570	44	19D
0005433074266	11570	45	20A
0005432947835	11570	46	20C
0005433134068	11570	47	20D
0005432947808	11570	48	21A
0005432947823	11570	49	20F
0005432947844	11570	50	21B
0005432947806	11570	51	21D
0005432947815	11570	52	21C
0005433074256	11570	53	22A
0005432947826	11570	54	21F
0005433134066	11570	55	22D
0005432947828	11570	56	22F
0005433074275	11570	57	23B
0005432947816	11570	58	23D
0005433074270	11570	59	23E
0005432947827	11570	60	24A
0005432192271	11570	61	24B
0005432947822	11570	62	24D
0005433074281	11570	63	24C
0005432947824	11570	64	25A
0005433074279	11570	65	25C
0005432947817	11570	66	25D
0005432947807	11570	67	26F
0005432947813	11570	68	26E
0005433074258	11570	69	27B
0005433074261	11570	70	27D
0005433074277	11570	71	28B
0005433131639	11570	72	28C
0005433134067	11570	73	28E
0005432947818	11570	74	28F
0005432947819	11570	75	29B
0005433074273	11570	76	29C
0005432947825	11570	77	29D
0005432947821	11570	78	29E
0005433074259	11570	79	30C
0005432947810	11570	80	30E
0005433074257	11570	81	30D
0005433074265	11570	82	30F
0005433074255	11570	83	31F
0005433817414	10009	1	1B
0005433817413	10009	2	5A
0005433817412	10009	3	5B
0005434732928	13932	1	2B
0005434732927	13932	2	4A
0005434732926	13932	3	5A
0005435981616	2324	1	1A
0005435981603	2324	2	1C
0005433753383	2324	3	1F
0005435981630	2324	4	1H
0005433753337	2324	5	1G
0005435981600	2324	6	2A
0005433753389	2324	7	2B
0005433753358	2324	8	2F
0005435981622	2324	9	2C
0005433753354	2324	10	2G
0005432300177	2324	11	3B
0005433753342	2324	12	3A
0005435981629	2324	13	3C
0005432655362	2324	14	3G
0005433753361	2324	15	3F
0005433753364	2324	16	3H
0005432225962	2324	17	4B
0005433753385	2324	18	4F
0005435981626	2324	19	4H
0005433753351	2324	20	5A
0005433753391	2324	21	5F
0005433753371	2324	22	5C
0005435981628	2324	23	5G
0005433753360	2324	24	5H
0005433753349	2324	25	9B
0005433753375	2324	26	9G
0005433753379	2324	27	9H
0005432655361	2324	28	11B
0005433764647	2324	29	11E
0005435981632	2324	30	11F
0005435981633	2324	31	11H
0005435981606	2324	32	12A
0005433753359	2324	33	12D
0005435981624	2324	34	12B
0005435981607	2324	35	12F
0005435981638	2324	36	13B
0005433753390	2324	37	13A
0005433753382	2324	38	13D
0005433753363	2324	39	13E
0005432300173	2324	40	13H
0005433753357	2324	41	14A
0005433753388	2324	42	14D
0005433753347	2324	43	14F
0005432225963	2324	44	14G
0005433753340	2324	45	15A
0005433766583	2324	46	15B
0005435981612	2324	47	15E
0005433753352	2324	48	15D
0005433753374	2324	49	15H
0005433753386	2324	50	15G
0005432225961	2324	51	16A
0005435981604	2324	52	16B
0005435981631	2324	53	16F
0005435981597	2324	54	16H
0005435981625	2324	55	16G
0005435981635	2324	56	17B
0005435981641	2324	57	17D
0005435981618	2324	58	17F
0005432300176	2324	59	18A
0005433764648	2324	60	18D
0005432225965	2324	61	18F
0005433753392	2324	62	18E
0005435981608	2324	63	18G
0005435981594	2324	64	19A
0005435981615	2324	65	19E
0005435981627	2324	66	19F
0005433753365	2324	67	20A
0005433753373	2324	68	19H
0005433753338	2324	69	20B
0005432655353	2324	70	20E
0005432655360	2324	71	20D
0005433753355	2324	72	20F
0005433753344	2324	73	21A
0005433753387	2324	74	21B
0005433753377	2324	75	21E
0005435981598	2324	76	21D
0005433766581	2324	77	21H
0005433753378	2324	78	22E
0005433753393	2324	79	22F
0005433753339	2324	80	23A
0005433753366	2324	81	22H
0005433753350	2324	82	23B
0005433753384	2324	83	23D
0005435981642	2324	84	23F
0005433753345	2324	85	23E
0005433753369	2324	86	23G
0005432300175	2324	87	23H
0005435981636	2324	88	24E
0005435981610	2324	89	24F
0005433753381	2324	90	24G
0005435981596	2324	91	25D
0005432655357	2324	92	25F
0005435981617	2324	93	27D
0005435981613	2324	94	27B
0005432300172	2324	95	27A
0005433753336	2324	96	27E
0005432655351	2324	97	28A
0005435981639	2324	98	28D
0005435981634	2324	99	28G
0005432655355	2324	100	29B
0005435981609	2324	101	29E
0005435981619	2324	102	29G
0005433766584	2324	103	29F
0005435981601	2324	104	29H
0005433753362	2324	105	30F
0005433753346	2324	106	31B
0005433764649	2324	107	31D
0005433766582	2324	108	31E
0005433753372	2324	109	31H
0005435981614	2324	110	31G
0005433753343	2324	111	32A
0005435981623	2324	112	33A
0005433753353	2324	113	32H
0005435981640	2324	114	33E
0005432300174	2324	115	33F
0005433753367	2324	116	33H
0005435981602	2324	117	34D
0005432655358	2324	118	34B
0005432655350	2324	119	34E
0005435981621	2324	120	34G
0005433753380	2324	121	34H
0005435981620	2324	122	35B
0005435981644	2324	123	35D
0005433753376	2324	124	35F
0005433753356	2324	125	35E
0005432225960	2324	126	35H
0005435981595	2324	127	36B
0005432655356	2324	128	36A
0005433753348	2324	129	36E
0005433753370	2324	130	36F
0005432655354	2324	131	36H
0005432225964	2324	132	37D
0005435981643	2324	133	37E
0005435981637	2324	134	37F
0005435981605	2324	135	38A
0005432655359	2324	136	38D
0005435981599	2324	137	38E
0005433753368	2324	138	38G
0005433753341	2324	139	38F
0005432655352	2324	140	39D
0005435981611	2324	141	39E
0005432984567	26195	1	1F
0005433434250	26195	2	1G
0005433434265	26195	3	2A
0005433434252	26195	4	2B
0005432869419	26195	5	3G
0005433434253	26195	6	4B
0005432984573	26195	7	4C
0005432984596	26195	8	4H
0005432984591	26195	9	4F
0005432984578	26195	10	9A
0005432984569	26195	11	5H
0005432984572	26195	12	9G
0005432984590	26195	13	11E
0005432984597	26195	14	11D
0005432869418	26195	15	11F
0005432984571	26195	16	12E
0005433434257	26195	17	12H
0005432984595	26195	18	13B
0005432984576	26195	19	13D
0005432984592	26195	20	13E
0005432869421	26195	21	13G
0005434731108	26195	22	14B
0005432984574	26195	23	14D
0005433434254	26195	24	15A
0005433434239	26195	25	15G
0005432984581	26195	26	15H
0005432984568	26195	27	16G
0005434731105	26195	28	17A
0005432984599	26195	29	17D
0005433434237	26195	30	17E
0005433434262	26195	31	18B
0005432984588	26195	32	18H
0005434731107	26195	33	19B
0005433434249	26195	34	19E
0005433434246	26195	35	19D
0005434731106	26195	36	20A
0005433434258	26195	37	20E
0005433434251	26195	38	20G
0005432984570	26195	39	21E
0005432984589	26195	40	22D
0005432869422	26195	41	22E
0005433434263	26195	42	22G
0005432984598	26195	43	23A
0005433434238	26195	44	24A
0005432984575	26195	45	24D
0005432984579	26195	46	24F
0005432984594	26195	47	24H
0005432049407	26195	48	27B
0005432984584	26195	49	27E
0005433434244	26195	50	27G
0005432984593	26195	51	28D
0005433434256	26195	52	28B
0005433434242	26195	53	28H
0005432049410	26195	54	29A
0005432984583	26195	55	29B
0005432984577	26195	56	29E
0005432869420	26195	57	29H
0005432049409	26195	58	30A
0005433434259	26195	59	30D
0005432051079	26195	60	30G
0005433434261	26195	61	31D
0005432984586	26195	62	31F
0005432869417	26195	63	32E
0005432984580	26195	64	32H
0005432051080	26195	65	33G
0005434731104	26195	66	33F
0005433434248	26195	67	33H
0005433434240	26195	68	34A
0005433434243	26195	69	34D
0005433434247	26195	70	34H
0005432984585	26195	71	35D
0005433434241	26195	72	35F
0005433434260	26195	73	36A
0005433434264	26195	74	35H
0005432051081	26195	75	36B
0005432984582	26195	76	36E
0005432984587	26195	77	38A
0005432049408	26195	78	38D
0005432051082	26195	79	38E
0005433434255	26195	80	38F
0005433434245	26195	81	38H
0005432869423	26195	82	39F
0005434373955	1494	1	1C
0005434373948	1494	2	2C
0005434373984	1494	3	2A
0005434373988	1494	4	4E
0005434373987	1494	5	4F
0005432267795	1494	6	5A
0005432267792	1494	7	5C
0005434373994	1494	8	5E
0005434373974	1494	9	5F
0005434373973	1494	10	6C
0005432267791	1494	11	6B
0005434373968	1494	12	6F
0005434373977	1494	13	7C
0005434373978	1494	14	7D
0005434373966	1494	15	8A
0005434373956	1494	16	8C
0005434373991	1494	17	8E
0005434373964	1494	18	8D
0005434373975	1494	19	9A
0005432267790	1494	20	9B
0005434373957	1494	21	9E
0005434373971	1494	22	9D
0005433150827	1494	23	11A
0005434373952	1494	24	11D
0005434373963	1494	25	11E
0005434373979	1494	26	12A
0005434373993	1494	27	12B
0005434373945	1494	28	12F
0005434373960	1494	29	13C
0005434373958	1494	30	13B
0005434373982	1494	31	13E
0005434373970	1494	32	13F
0005434373967	1494	33	14A
0005433461554	1494	34	14C
0005434373983	1494	35	14B
0005434373959	1494	36	14D
0005434373986	1494	37	14E
0005434373950	1494	38	15A
0005434373962	1494	39	14F
0005434373980	1494	40	15B
0005433460403	1494	41	15E
0005433460404	1494	42	15F
0005434373961	1494	43	16B
0005432267793	1494	44	16C
0005432267796	1494	45	16E
0005434373969	1494	46	16F
0005434373965	1494	47	17B
0005434373976	1494	48	17C
0005434373990	1494	49	17D
0005433461555	1494	50	18C
0005434373989	1494	51	19A
0005434373953	1494	52	18F
0005432267794	1494	53	19C
0005433460402	1494	54	20A
0005434373954	1494	55	20D
0005434373985	1494	56	20E
0005434373981	1494	57	21B
0005434373949	1494	58	21D
0005434373946	1494	59	21E
0005434373992	1494	60	22B
0005434373951	1494	61	22F
0005434373947	1494	62	23C
0005434373972	1494	63	23F
0005433764648	20123	1	1C
0005433150874	20123	2	1F
0005433150884	20123	3	2F
0005433150877	20123	4	3F
0005433150893	20123	5	4E
0005433150896	20123	6	5A
0005433150885	20123	7	5C
0005433150873	20123	8	5D
0005433150864	20123	9	5E
0005433150897	20123	10	7A
0005434029619	20123	11	7F
0005433150871	20123	12	8D
0005432056239	20123	13	9B
0005434029620	20123	14	9C
0005433150889	20123	15	9E
0005433150882	20123	16	10C
0005433150891	20123	17	10D
0005433931421	20123	18	11A
0005433764649	20123	19	11D
0005433150892	20123	20	12A
0005433150883	20123	21	12C
0005433150868	20123	22	12B
0005433150869	20123	23	12F
0005433931420	20123	24	13D
0005433150895	20123	25	13E
0005433150887	20123	26	14A
0005432056240	20123	27	14D
0005433150867	20123	28	14F
0005433150890	20123	29	15F
0005433150886	20123	30	16B
0005433150894	20123	31	16E
0005433150875	20123	32	17A
0005433150898	20123	33	17B
0005433150865	20123	34	17F
0005433150866	20123	35	18D
0005433150879	20123	36	19B
0005433150881	20123	37	19E
0005432056241	20123	38	20A
0005433931422	20123	39	21A
0005432056242	20123	40	21D
0005433150876	20123	41	21E
0005433150878	20123	42	22B
0005433150872	20123	43	22C
0005433150880	20123	44	22D
0005433764647	20123	45	23B
0005433150888	20123	46	23C
0005433150870	20123	47	23F
0005432423717	508	1	1C
0005432423737	508	2	1D
0005432282759	508	3	2C
0005432423720	508	4	2F
0005432423730	508	5	3C
0005432282756	508	6	4D
0005432423713	508	7	5A
0005432423695	508	8	5F
0005432423716	508	9	6C
0005432423755	508	10	7A
0005432423761	508	11	7C
0005432423709	508	12	8B
0005432282757	508	13	8D
0005432423714	508	14	8E
0005432423728	508	15	9B
0005432423722	508	16	9D
0005432423757	508	17	9E
0005432423754	508	18	10A
0005432423742	508	19	9F
0005432282755	508	20	10E
0005432423707	508	21	10D
0005432423701	508	22	11D
0005432423702	508	23	12A
0005432423705	508	24	12B
0005432423731	508	25	12C
0005432423747	508	26	12F
0005432423724	508	27	13B
0005432423740	508	28	13A
0005432423725	508	29	13D
0005432423734	508	30	14A
0005432423718	508	31	14B
0005432423756	508	32	14D
0005432423715	508	33	15C
0005432423745	508	34	16C
0005432423752	508	35	16F
0005432423760	508	36	17B
0005432423694	508	37	17A
0005432423719	508	38	17D
0005432423711	508	39	17F
0005432423736	508	40	18A
0005432423741	508	41	18D
0005432423710	508	42	19E
0005432423753	508	43	20F
0005432423762	508	44	20E
0005432423697	508	45	21C
0005432423735	508	46	21B
0005432423723	508	47	21D
0005432423704	508	48	21E
0005432423706	508	49	22D
0005432423738	508	50	23A
0005432282758	508	51	23C
0005432423739	508	52	23B
0005432423744	508	53	23D
0005432423733	508	54	23E
0005432423703	508	55	23F
0005432423708	508	56	24C
0005432423743	508	57	24D
0005432423751	508	58	24F
0005432423712	508	59	25B
0005432423759	508	60	25C
0005432423749	508	61	26A
0005432423700	508	62	25F
0005432423727	508	63	26B
0005432423726	508	64	26F
0005432423729	508	65	27D
0005432423696	508	66	27E
0005432423746	508	67	27F
0005432423732	508	68	28B
0005432423748	508	69	28F
0005432423758	508	70	29E
0005432423699	508	71	29D
0005432423721	508	72	30A
0005432423750	508	73	29F
0005432423698	508	74	31E
0005432302273	12905	1	10A
0005432302274	12905	2	19C
0005432302272	12905	3	21F
0005433158096	12905	4	22F
0005433158098	12905	5	26C
0005433158095	12905	6	30E
0005433158097	12905	7	31E
0005434022696	440	1	1A
0005434022694	440	2	1B
0005434022671	440	3	1G
0005434022664	440	4	2F
0005434029616	440	5	2H
0005434022684	440	6	2G
0005434022695	440	7	3B
0005434022652	440	8	3F
0005434022673	440	9	3H
0005434022643	440	10	4A
0005434022707	440	11	4G
0005432235520	440	12	4F
0005434022700	440	13	4H
0005432235522	440	14	5F
0005434022670	440	15	9A
0005432235525	440	16	9G
0005434022649	440	17	11A
0005432235526	440	18	9H
0005432045582	440	19	11D
0005434022647	440	20	11H
0005434022686	440	21	12B
0005434022682	440	22	12E
0005434022685	440	23	13B
0005434022693	440	24	13A
0005434022698	440	25	13D
0005434022680	440	26	14B
0005434022672	440	27	14A
0005434022669	440	28	14D
0005434031951	440	29	14G
0005434022656	440	30	15B
0005434028252	440	31	15A
0005434022704	440	32	16A
0005434022676	440	33	16B
0005434022645	440	34	16G
0005434022642	440	35	16H
0005434022678	440	36	17D
0005432235519	440	37	17G
0005434022651	440	38	17F
0005434022702	440	39	18D
0005434022697	440	40	18F
0005434028251	440	41	18G
0005434022701	440	42	19B
0005434022644	440	43	19A
0005434022691	440	44	19D
0005434022662	440	45	20A
0005434022667	440	46	20D
0005434022692	440	47	20F
0005432045583	440	48	20G
0005432235523	440	49	21A
0005434022677	440	50	21B
0005434022654	440	51	21F
0005434022703	440	52	22A
0005434022668	440	53	22D
0005434031950	440	54	22E
0005434022659	440	55	23B
0005434022679	440	56	23D
0005434022705	440	57	23F
0005434022706	440	58	23G
0005434022699	440	59	24E
0005434029617	440	60	24D
0005434022674	440	61	24F
0005434022640	440	62	25F
0005434028250	440	63	27A
0005434022648	440	64	27E
0005434022688	440	65	27G
0005434029618	440	66	28B
0005434022660	440	67	28D
0005434022708	440	68	29D
0005434022663	440	69	29G
0005434022683	440	70	30F
0005434022687	440	71	30E
0005434022681	440	72	30G
0005434031949	440	73	31E
0005434022653	440	74	31G
0005434028253	440	75	32E
0005434022661	440	76	32G
0005434022690	440	77	33A
0005434022658	440	78	33G
0005434022666	440	79	33F
0005434022641	440	80	33H
0005434031948	440	81	34E
0005434022657	440	82	34G
0005434022655	440	83	35E
0005434022646	440	84	35F
0005434022650	440	85	36A
0005432235521	440	86	37A
0005434022689	440	87	37E
0005434022639	440	88	38B
0005432235524	440	89	38A
0005434031952	440	90	37H
0005434022675	440	91	38F
0005434022665	440	92	39D
0005433057258	12671	1	1F
0005432156298	12671	2	2A
0005433057263	12671	3	2B
0005433929550	12671	4	4G
0005433057262	12671	5	4F
0005433057252	12671	6	5B
0005433057280	12671	7	5F
0005433057277	12671	8	5H
0005433684389	12671	9	11A
0005433057251	12671	10	11E
0005433057284	12671	11	12D
0005432156299	12671	12	12F
0005433057267	12671	13	13F
0005432157462	12671	14	14B
0005433057274	12671	15	14F
0005433057264	12671	16	14G
0005433929547	12671	17	14H
0005433057270	12671	18	16E
0005432157461	12671	19	17B
0005433057285	12671	20	17A
0005432157463	12671	21	17E
0005433057281	12671	22	17G
0005433057287	12671	23	18A
0005433057256	12671	24	19A
0005433057289	12671	25	20A
0005433057288	12671	26	20B
0005433929552	12671	27	21B
0005434735612	12671	28	21F
0005432156297	12671	29	21H
0005432156295	12671	30	22A
0005433057255	12671	31	23E
0005433057266	12671	32	23F
0005433057259	12671	33	24A
0005433057282	12671	34	24G
0005433057290	12671	35	27B
0005433057278	12671	36	28A
0005433057250	12671	37	28H
0005433057268	12671	38	28G
0005433929548	12671	39	29E
0005433057276	12671	40	30A
0005434735611	12671	41	29H
0005433057260	12671	42	30B
0005433057265	12671	43	30G
0005433057283	12671	44	31A
0005434735608	12671	45	31D
0005433057271	12671	46	32B
0005433057261	12671	47	33B
0005433057257	12671	48	33E
0005433929551	12671	49	33G
0005432156296	12671	50	33H
0005433057269	12671	51	34E
0005433057253	12671	52	34F
0005434735609	12671	53	35A
0005433057272	12671	54	34H
0005433929549	12671	55	35D
0005434735610	12671	56	35H
0005433057279	12671	57	36A
0005433057254	12671	58	36F
0005433057286	12671	59	37D
0005433057273	12671	60	37E
0005433057275	12671	61	38D
0005434735607	12671	62	39E
0005433921847	2113	1	1A
0005433921824	2113	2	1C
0005433921826	2113	3	1B
0005433921836	2113	4	1G
0005433921830	2113	5	2A
0005433921842	2113	6	3A
0005433921827	2113	7	2H
0005433921865	2113	8	3C
0005433921875	2113	9	3F
0005432231401	2113	10	3G
0005433921816	2113	11	3H
0005433921880	2113	12	4B
0005432044482	2113	13	4A
0005432231403	2113	14	4F
0005433921796	2113	15	4H
0005433921807	2113	16	5B
0005433921799	2113	17	5F
0005433921806	2113	18	5C
0005433921848	2113	19	5G
0005433921783	2113	20	5H
0005433929550	2113	21	9A
0005433921860	2113	22	9G
0005433921797	2113	23	11A
0005433921789	2113	24	11B
0005433921868	2113	25	11E
0005433921873	2113	26	11F
0005432231397	2113	27	11H
0005433921863	2113	28	11G
0005432231399	2113	29	12A
0005433921820	2113	30	13D
0005433921801	2113	31	13G
0005433921853	2113	32	14B
0005433921794	2113	33	14D
0005433921791	2113	34	14F
0005433921817	2113	35	14H
0005433921792	2113	36	15E
0005433875353	2113	37	15H
0005433921855	2113	38	16B
0005433921843	2113	39	16E
0005433921822	2113	40	16H
0005433921864	2113	41	17A
0005433921858	2113	42	17D
0005433921874	2113	43	17B
0005433921869	2113	44	17F
0005433921844	2113	45	17G
0005432231405	2113	46	18A
0005433921784	2113	47	18E
0005433921814	2113	48	18D
0005433921845	2113	49	18B
0005433921840	2113	50	18F
0005433921835	2113	51	18H
0005433921839	2113	52	19E
0005433921857	2113	53	19G
0005433929548	2113	54	20A
0005433921825	2113	55	20D
0005433929551	2113	56	20G
0005433921804	2113	57	21B
0005432231404	2113	58	21E
0005433921861	2113	59	21G
0005433921819	2113	60	22D
0005433931420	2113	61	22E
0005433921795	2113	62	22G
0005433921832	2113	63	22H
0005433921810	2113	64	23B
0005433921859	2113	65	23F
0005433921877	2113	66	23H
0005433921821	2113	67	24A
0005433921808	2113	68	24B
0005433929552	2113	69	24D
0005433921829	2113	70	24F
0005433921879	2113	71	24G
0005433921809	2113	72	25E
0005433921818	2113	73	25F
0005433921793	2113	74	27B
0005433921841	2113	75	27E
0005433921790	2113	76	27F
0005433931422	2113	77	28B
0005433921785	2113	78	28F
0005432231400	2113	79	28H
0005433921872	2113	80	28G
0005433921870	2113	81	29B
0005433921823	2113	82	29A
0005433921856	2113	83	29D
0005433921838	2113	84	29F
0005433875354	2113	85	29H
0005432231406	2113	86	29G
0005433921837	2113	87	30E
0005432044481	2113	88	30D
0005433929547	2113	89	30F
0005433921862	2113	90	31B
0005433921786	2113	91	31D
0005433921802	2113	92	31G
0005433921787	2113	93	32D
0005433921867	2113	94	32B
0005433921878	2113	95	32E
0005433921812	2113	96	32F
0005432231402	2113	97	33D
0005433921876	2113	98	33E
0005433921833	2113	99	33F
0005433921803	2113	100	33H
0005433921871	2113	101	34A
0005433921846	2113	102	34F
0005433921834	2113	103	34H
0005433921851	2113	104	35D
0005433921815	2113	105	35H
0005433921854	2113	106	35G
0005433921850	2113	107	36A
0005432231398	2113	108	36E
0005433921798	2113	109	36D
0005433921813	2113	110	36F
0005433921788	2113	111	36G
0005433929549	2113	112	37A
0005433931421	2113	113	36H
0005433921866	2113	114	37F
0005433921831	2113	115	37G
0005433921800	2113	116	38E
0005433921805	2113	117	38G
0005433921828	2113	118	38F
0005433921849	2113	119	39D
0005433921852	2113	120	39F
0005433921811	2113	121	39E
0005433035507	24135	1	1C
0005433035511	24135	2	1B
0005433035515	24135	3	1F
0005433035466	24135	4	1H
0005433035476	24135	5	1G
0005433035494	24135	6	2A
0005433035469	24135	7	2F
0005432749752	24135	8	5B
0005433035484	24135	9	9H
0005433035514	24135	10	11G
0005433035468	24135	11	11F
0005433035495	24135	12	12A
0005433035490	24135	13	12B
0005433035474	24135	14	12E
0005433035516	24135	15	13G
0005433035491	24135	16	14G
0005433035488	24135	17	15D
0005433035475	24135	18	15G
0005433035506	24135	19	16E
0005433035499	24135	20	17A
0005432206103	24135	21	17D
0005433035512	24135	22	17E
0005433035497	24135	23	17H
0005433035485	24135	24	18B
0005433035510	24135	25	18A
0005433035472	24135	26	18E
0005433035489	24135	27	18G
0005433035513	24135	28	18F
0005433035501	24135	29	18H
0005432749751	24135	30	19B
0005433035465	24135	31	19G
0005433035500	24135	32	20A
0005433035478	24135	33	20D
0005432206108	24135	34	20H
0005433035481	24135	35	21F
0005433035493	24135	36	21G
0005434028254	24135	37	22B
0005432207623	24135	38	22H
0005434028256	24135	39	22G
0005432206109	24135	40	23G
0005432207622	24135	41	24A
0005433035477	24135	42	25D
0005433035464	24135	43	27B
0005433035487	24135	44	27D
0005433035473	24135	45	27F
0005433035509	24135	46	27G
0005433035480	24135	47	28D
0005433035498	24135	48	28H
0005433035518	24135	49	28G
0005433035503	24135	50	29F
0005433035496	24135	51	29H
0005433035517	24135	52	29G
0005433035504	24135	53	30G
0005433035471	24135	54	31B
0005433035505	24135	55	31H
0005433035482	24135	56	31G
0005432206105	24135	57	32B
0005433035470	24135	58	33A
0005433035479	24135	59	33H
0005432206104	24135	60	33G
0005433035467	24135	61	34B
0005434028255	24135	62	36A
0005433035492	24135	63	36B
0005433035483	24135	64	36E
0005432206106	24135	65	37A
0005433035502	24135	66	37H
0005433035486	24135	67	38B
0005433035508	24135	68	38G
0005432206107	24135	69	38H
0005432277598	245	1	1D
0005434550379	245	2	1K
0005434723600	245	3	2A
0005434550397	245	4	2H
0005434550391	245	5	2G
0005435142369	245	6	3A
0005434550377	245	7	2K
0005434550416	245	8	3D
0005434723570	245	9	3H
0005434723625	245	10	4C
0005434723680	245	11	4A
0005434723633	245	12	4D
0005434550392	245	13	4K
0005434550409	245	14	5C
0005434723663	245	15	5G
0005434550407	245	16	11C
0005435142367	245	17	11F
0005434723589	245	18	11E
0005434723656	245	19	11K
0005434723669	245	20	11H
0005434723575	245	21	12C
0005432277600	245	22	12A
0005434550412	245	23	12H
0005434550393	245	24	13A
0005434550373	245	25	12K
0005435142374	245	26	13F
0005434723594	245	27	13E
0005432277609	245	28	13G
0005434723557	245	29	14A
0005434723559	245	30	13K
0005434723562	245	31	14E
0005434723657	245	32	14D
0005432277608	245	33	14C
0005434550371	245	34	14G
0005435142373	245	35	14F
0005434723627	245	36	14K
0005434723558	245	37	15A
0005434723621	245	38	15D
0005434723564	245	39	15G
0005434735606	245	40	15K
0005434723672	245	41	15H
0005434735605	245	42	16C
0005434723666	245	43	16E
0005434723642	245	44	16H
0005434550411	245	45	17C
0005434723606	245	46	16K
0005434723643	245	47	17D
0005434723580	245	48	17G
0005434723639	245	49	18C
0005434723602	245	50	18B
0005434723645	245	51	18A
0005434550374	245	52	18D
0005434723662	245	53	18G
0005434723665	245	54	18J
0005434723597	245	55	19B
0005434723628	245	56	19A
0005434550389	245	57	18K
0005434723572	245	58	19D
0005434550406	245	59	19C
0005434723566	245	60	19F
0005434723631	245	61	19J
0005432277606	245	62	19K
0005434550417	245	63	20C
0005434550418	245	64	20D
0005434723664	245	65	20F
0005434723649	245	66	20K
0005434723567	245	67	21D
0005434723578	245	68	21C
0005434550420	245	69	21F
0005434550399	245	70	21E
0005434723626	245	71	21H
0005434723682	245	72	21G
0005434723622	245	73	21J
0005434723652	245	74	22E
0005434723583	245	75	22H
0005434302391	245	76	22G
0005434723667	245	77	22K
0005435142371	245	78	22J
0005434723620	245	79	23B
0005434723614	245	80	23A
0005434550376	245	81	23D
0005434723582	245	82	23C
0005434550403	245	83	23G
0005435142372	245	84	23F
0005434723584	245	85	23E
0005435142366	245	86	23H
0005434550402	245	87	23K
0005434723660	245	88	24E
0005434731101	245	89	24G
0005432277607	245	90	25D
0005434723679	245	91	25H
0005435142370	245	92	26A
0005432277597	245	93	25K
0005434550380	245	94	25J
0005434723637	245	95	26D
0005434550424	245	96	26H
0005432277602	245	97	26G
0005434723595	245	98	26J
0005434723560	245	99	27B
0005434723644	245	100	27A
0005434723613	245	101	26K
0005434723585	245	102	27C
0005434723617	245	103	27E
0005434550370	245	104	28A
0005432277601	245	105	28E
0005434723571	245	106	28J
0005434550404	245	107	28H
0005434550369	245	108	29B
0005434723648	245	109	29A
0005434723563	245	110	28K
0005432277599	245	111	29D
0005432277605	245	112	29F
0005434731102	245	113	29E
0005434723615	245	114	29K
0005434723681	245	115	30G
0005432277604	245	116	30F
0005434735604	245	117	30J
0005434723587	245	118	31A
0005434723610	245	119	30K
0005434723673	245	120	31F
0005434550408	245	121	31H
0005434723588	245	122	31G
0005434550394	245	123	32A
0005434550372	245	124	31K
0005434723674	245	125	32C
0005434723640	245	126	32B
0005434723561	245	127	32D
0005434735603	245	128	32G
0005434723647	245	129	33C
0005434550375	245	130	33G
0005434723675	245	131	33K
0005434550423	245	132	34C
0005434723601	245	133	34B
0005434550405	245	134	34F
0005435142364	245	135	34J
0005435142363	245	136	34H
0005434723629	245	137	35A
0005434550396	245	138	34K
0005434550395	245	139	35D
0005434735602	245	140	35C
0005434550378	245	141	35F
0005434723579	245	142	35E
0005434723659	245	143	36C
0005434723586	245	144	36B
0005434723607	245	145	36E
0005434723670	245	146	36D
0005434723611	245	147	36G
0005435142365	245	148	36F
0005434731100	245	149	36K
0005434723612	245	150	36J
0005435142375	245	151	37C
0005434723576	245	152	37D
0005434723641	245	153	37F
0005434550410	245	154	37E
0005434723646	245	155	37J
0005434723609	245	156	37G
0005434723593	245	157	37K
0005434550413	245	158	38C
0005434723636	245	159	38B
0005434723632	245	160	38K
0005434550383	245	161	39B
0005434723604	245	162	39A
0005434723568	245	163	39C
0005434723658	245	164	39F
0005434550401	245	165	39E
0005434723653	245	166	39J
0005434723596	245	167	40B
0005434723661	245	168	40E
0005434550381	245	169	40H
0005434723603	245	170	40F
0005434723565	245	171	41A
0005434723573	245	172	41C
0005434723592	245	173	41F
0005434723650	245	174	41H
0005434550415	245	175	41K
0005434723676	245	176	41J
0005434723671	245	177	42E
0005434550386	245	178	42D
0005434302394	245	179	42H
0005432277603	245	180	42G
0005434723634	245	181	42K
0005434723608	245	182	43B
0005434723655	245	183	43D
0005434723654	245	184	43F
0005434723623	245	185	43E
0005434723581	245	186	43H
0005434550422	245	187	43J
0005434723678	245	188	44B
0005434550419	245	189	44A
0005434550421	245	190	44G
0005434723616	245	191	44F
0005434302392	245	192	44H
0005434723651	245	193	45B
0005434723569	245	194	45D
0005434723677	245	195	45C
0005434731103	245	196	45F
0005434723638	245	197	45H
0005434550387	245	198	45K
0005434723590	245	199	46B
0005434550398	245	200	46A
0005434723619	245	201	46E
0005434723624	245	202	46D
0005434550384	245	203	46G
0005434723630	245	204	46J
0005434723605	245	205	47D
0005434723635	245	206	47F
0005435142376	245	207	47E
0005434550414	245	208	48C
0005435142368	245	209	48A
0005434723598	245	210	48F
0005434302393	245	211	48E
0005434723618	245	212	48H
0005434550382	245	213	48G
0005434723668	245	214	49E
0005434550400	245	215	49G
0005434723577	245	216	49K
0005434723574	245	217	50E
0005434550388	245	218	50D
0005434550390	245	219	51D
0005434723591	245	220	50K
0005434550385	245	221	51F
0005434723599	245	222	51E
0005433233261	9858	1	1D
0005433233254	9858	2	1K
0005433180706	9858	3	2C
0005433233263	9858	4	3A
0005433233238	9858	5	3D
0005433766582	9858	6	3C
0005433233211	9858	7	4C
0005433180707	9858	8	11A
0005433233236	9858	9	11D
0005433233244	9858	10	11C
0005432199139	9858	11	11H
0005433233270	9858	12	12E
0005433180704	9858	13	12D
0005433233231	9858	14	13E
0005433289732	9858	15	14D
0005433180702	9858	16	15C
0005433113500	9858	17	15D
0005433129203	9858	18	15F
0005433233262	9858	19	16K
0005433233233	9858	20	17C
0005432199142	9858	21	18D
0005433113501	9858	22	18G
0005433233256	9858	23	19B
0005433180705	9858	24	19A
0005433129204	9858	25	19F
0005433180725	9858	26	20C
0005433126772	9858	27	20B
0005433289735	9858	28	20F
0005433129202	9858	29	21B
0005433129206	9858	30	21C
0005433289734	9858	31	22B
0005433233218	9858	32	22F
0005433233227	9858	33	23B
0005433233248	9858	34	23E
0005432199143	9858	35	23G
0005432199137	9858	36	24D
0005432199138	9858	37	24F
0005433233217	9858	38	24G
0005433180703	9858	39	25C
0005433233221	9858	40	25B
0005433233249	9858	41	25E
0005433233222	9858	42	25J
0005433180722	9858	43	26A
0005433180709	9858	44	26E
0005433180712	9858	45	26D
0005433233228	9858	46	26J
0005433233271	9858	47	27A
0005433233268	9858	48	27B
0005433180719	9858	49	27E
0005433289738	9858	50	27G
0005433233247	9858	51	27K
0005433233266	9858	52	27J
0005433233232	9858	53	28E
0005433233219	9858	54	28K
0005433233209	9858	55	29D
0005432199144	9858	56	29C
0005434031954	9858	57	29F
0005433233259	9858	58	30C
0005432199141	9858	59	30B
0005433233251	9858	60	30A
0005433289733	9858	61	30E
0005433289731	9858	62	30H
0005433233267	9858	63	31B
0005433233210	9858	64	31E
0005433233250	9858	65	32G
0005433180708	9858	66	33B
0005433233214	9858	67	32K
0005433233264	9858	68	33G
0005433180710	9858	69	33J
0005433180724	9858	70	33H
0005433233272	9858	71	34E
0005433233229	9858	72	34D
0005433233260	9858	73	35D
0005434031956	9858	74	35H
0005433180718	9858	75	36C
0005433129205	9858	76	36F
0005433233213	9858	77	36E
0005433233226	9858	78	36H
0005433233241	9858	79	36J
0005434031953	9858	80	37D
0005433233253	9858	81	37G
0005433126774	9858	82	37H
0005433180717	9858	83	38B
0005433180721	9858	84	39A
0005433233257	9858	85	39D
0005433233220	9858	86	40A
0005433180720	9858	87	39K
0005433766581	9858	88	40E
0005433233212	9858	89	40D
0005433766583	9858	90	40K
0005433233239	9858	91	41B
0005433233243	9858	92	41F
0005433233269	9858	93	41G
0005433180713	9858	94	42C
0005433180715	9858	95	42B
0005433126773	9858	96	42E
0005433233255	9858	97	42D
0005433180716	9858	98	42H
0005433180711	9858	99	42J
0005433233242	9858	100	43D
0005433233223	9858	101	44A
0005433233265	9858	102	43J
0005432199140	9858	103	44E
0005433233246	9858	104	44G
0005433233258	9858	105	44F
0005433233235	9858	106	45C
0005433233224	9858	107	45G
0005433126775	9858	108	45K
0005433180723	9858	109	45J
0005433233237	9858	110	46H
0005433766584	9858	111	46G
0005433233234	9858	112	46J
0005433180714	9858	113	46K
0005433126776	9858	114	47E
0005433233240	9858	115	47G
0005433289737	9858	116	47K
0005433233216	9858	117	49A
0005433233230	9858	118	49D
0005433180701	9858	119	50E
0005433289736	9858	120	50D
0005434031955	9858	121	50G
0005433233215	9858	122	50H
0005433233252	9858	123	51F
0005433233245	9858	124	51E
0005433233225	9858	125	51D
0005432428876	7723	1	1C
0005432069438	7723	2	1H
0005432526024	7723	3	1G
0005432069432	7723	4	2A
0005434066476	7723	5	1K
0005434066486	7723	6	2C
0005432526012	7723	7	2G
0005434066468	7723	8	3A
0005432526004	7723	9	2K
0005432525982	7723	10	3C
0005432526032	7723	11	4A
0005434066496	7723	12	4G
0005432069431	7723	13	4D
0005432525938	7723	14	4K
0005432525989	7723	15	5C
0005432069427	7723	16	5A
0005434066458	7723	17	5H
0005432526027	7723	18	5G
0005432428878	7723	19	11A
0005432069437	7723	20	5K
0005432525929	7723	21	11C
0005432526015	7723	22	11F
0005432525948	7723	23	11E
0005432526025	7723	24	11K
0005432525915	7723	25	11H
0005432535757	7723	26	12A
0005432526028	7723	27	12E
0005432526019	7723	28	12D
0005432525957	7723	29	12G
0005434066492	7723	30	12F
0005432428874	7723	31	12K
0005432069426	7723	32	12H
0005432525980	7723	33	13C
0005432525987	7723	34	13F
0005432525928	7723	35	13E
0005432150077	7723	36	13G
0005434066490	7723	37	13K
0005434066470	7723	38	14D
0005434066453	7723	39	14C
0005432525942	7723	40	14F
0005432525947	7723	41	14H
0005432525995	7723	42	14G
0005432526006	7723	43	15A
0005434066450	7723	44	15D
0005432526003	7723	45	15G
0005432525936	7723	46	15F
0005434066471	7723	47	15K
0005432526001	7723	48	16D
0005432525984	7723	49	16A
0005432525976	7723	50	16F
0005432533247	7723	51	16E
0005432525933	7723	52	17A
0005434066488	7723	53	16K
0005434066443	7723	54	17E
0005432069435	7723	55	17D
0005432525966	7723	56	17C
0005432525959	7723	57	17G
0005432525972	7723	58	17F
0005434066440	7723	59	17K
0005432525998	7723	60	17H
0005432525992	7723	61	18E
0005432525926	7723	62	18G
0005432526005	7723	63	18F
0005434066457	7723	64	18J
0005432526011	7723	65	18H
0005432525999	7723	66	19B
0005432525918	7723	67	19A
0005434066465	7723	68	19C
0005432526033	7723	69	19G
0005432525967	7723	70	19F
0005432525950	7723	71	19E
0005432525975	7723	72	19K
0005432069433	7723	73	20A
0005432525968	7723	74	20D
0005432525943	7723	75	20G
0005432525907	7723	76	21B
0005432526030	7723	77	20K
0005432525997	7723	78	21D
0005434066491	7723	79	21G
0005434066462	7723	80	21J
0005434066483	7723	81	21H
0005432069429	7723	82	22A
0005434066454	7723	83	21K
0005434066466	7723	84	22C
0005432150076	7723	85	22F
0005434066493	7723	86	22G
0005432525964	7723	87	22J
0005432526026	7723	88	22H
0005434066469	7723	89	23B
0005432069436	7723	90	23D
0005432525979	7723	91	23C
0005434066442	7723	92	23F
0005432525912	7723	93	23E
0005434066459	7723	94	23J
0005434066464	7723	95	24D
0005432525914	7723	96	23K
0005432525911	7723	97	24F
0005434066489	7723	98	24G
0005432525974	7723	99	25C
0005434066475	7723	100	25B
0005434066460	7723	101	25K
0005432069434	7723	102	26C
0005434066495	7723	103	26B
0005432069425	7723	104	26E
0005432428875	7723	105	26D
0005432525986	7723	106	26G
0005432526000	7723	107	26F
0005432525958	7723	108	26H
0005434066447	7723	109	26K
0005432526031	7723	110	27C
0005432526034	7723	111	27F
0005432525937	7723	112	27H
0005434066499	7723	113	27G
0005432526035	7723	114	27K
0005432525973	7723	115	27J
0005432525906	7723	116	28C
0005434066480	7723	117	28B
0005434066485	7723	118	28A
0005434066478	7723	119	28E
0005432526023	7723	120	28D
0005434066507	7723	121	28F
0005432525965	7723	122	28J
0005432525935	7723	123	29D
0005434066445	7723	124	29F
0005432525905	7723	125	29G
0005432525949	7723	126	30B
0005434066503	7723	127	30A
0005432526018	7723	128	30E
0005432525922	7723	129	30D
0005432535758	7723	130	30K
0005434066473	7723	131	31D
0005432525994	7723	132	31C
0005434066448	7723	133	31E
0005434066509	7723	134	31H
0005432526022	7723	135	31K
0005432525910	7723	136	32C
0005432526020	7723	137	32A
0005434066487	7723	138	32E
0005434066479	7723	139	32G
0005432525962	7723	140	33B
0005432150074	7723	141	33A
0005434066501	7723	142	32K
0005432525945	7723	143	33D
0005432525940	7723	144	33H
0005432525963	7723	145	33G
0005432525913	7723	146	33K
0005432525944	7723	147	34C
0005432525955	7723	148	34D
0005432525925	7723	149	34G
0005434066508	7723	150	34F
0005432525981	7723	151	34K
0005434066441	7723	152	34J
0005434066451	7723	153	34H
0005432525941	7723	154	35B
0005432526014	7723	155	35D
0005434066467	7723	156	35C
0005432069424	7723	157	35J
0005432525924	7723	158	35G
0005434066444	7723	159	35K
0005434066506	7723	160	36B
0005434066463	7723	161	36E
0005434066484	7723	162	36D
0005432525988	7723	163	36K
0005432150071	7723	164	37B
0005432526002	7723	165	37D
0005432526007	7723	166	37G
0005434066482	7723	167	37F
0005434066472	7723	168	37J
0005434066474	7723	169	38A
0005432525952	7723	170	37K
0005432525971	7723	171	38H
0005434066502	7723	172	38J
0005432525991	7723	173	39B
0005432525921	7723	174	39A
0005434066477	7723	175	38K
0005432150073	7723	176	39D
0005432525993	7723	177	39C
0005432525977	7723	178	39G
0005432526013	7723	179	39E
0005432526029	7723	180	39J
0005432537024	7723	181	40D
0005434066498	7723	182	40G
0005434066456	7723	183	40J
0005432533248	7723	184	41B
0005432526010	7723	185	41D
0005432525916	7723	186	41C
0005432069430	7723	187	41F
0005432525927	7723	188	41E
0005432525919	7723	189	41H
0005432525917	7723	190	41K
0005434066494	7723	191	41J
0005432525983	7723	192	42C
0005432525920	7723	193	42B
0005432525996	7723	194	42E
0005432525961	7723	195	42H
0005432525932	7723	196	42F
0005434066455	7723	197	42J
0005432428877	7723	198	43B
0005432525985	7723	199	43C
0005434066481	7723	200	43E
0005432535756	7723	201	43J
0005432525954	7723	202	43H
0005432526008	7723	203	43K
0005432150072	7723	204	44B
0005432525956	7723	205	44D
0005432526009	7723	206	44H
0005432525990	7723	207	44G
0005432525970	7723	208	44K
0005434066511	7723	209	45B
0005434066497	7723	210	45F
0005432525969	7723	211	45E
0005432525930	7723	212	45G
0005434066449	7723	213	46A
0005432526017	7723	214	46F
0005432525960	7723	215	46J
0005432525934	7723	216	46H
0005432525923	7723	217	47A
0005432535759	7723	218	46K
0005432526021	7723	219	47E
0005432525951	7723	220	47D
0005434066500	7723	221	47G
0005432525978	7723	222	47F
0005434066505	7723	223	48F
0005432150075	7723	224	48K
0005434066510	7723	225	49E
0005434066504	7723	226	49D
0005432525908	7723	227	49C
0005432525904	7723	228	49G
0005434066446	7723	229	49F
0005434066452	7723	230	49H
0005432525946	7723	231	50C
0005432525939	7723	232	49K
0005432525909	7723	233	50E
0005432526016	7723	234	50D
0005432537023	7723	235	50G
0005432525953	7723	236	51F
0005434066461	7723	237	51E
0005432525931	7723	238	51D
0005432069428	7723	239	51G
0005432132982	5305	1	1G
0005434573143	5305	2	1H
0005435611891	5305	3	2H
0005435611946	5305	4	2G
0005435611964	5305	5	2D
0005434343654	5305	6	3C
0005435611919	5305	7	3A
0005435611978	5305	8	2K
0005434343666	5305	9	3G
0005435611917	5305	10	3K
0005434343672	5305	11	4D
0005435611971	5305	12	5C
0005435097062	5305	13	5H
0005435611924	5305	14	5G
0005434343677	5305	15	11D
0005435611983	5305	16	11E
0005434343679	5305	17	11K
0005434573141	5305	18	11H
0005435611961	5305	19	12C
0005435097061	5305	20	12F
0005435611896	5305	21	12E
0005435611948	5305	22	12D
0005435490176	5305	23	13A
0005435611906	5305	24	13F
0005434343678	5305	25	13E
0005432047493	5305	26	13D
0005435611951	5305	27	13G
0005434573135	5305	28	14A
0005434573140	5305	29	14E
0005435611879	5305	30	14D
0005435611979	5305	31	14G
0005434573136	5305	32	14H
0005435611895	5305	33	15A
0005434343670	5305	34	15D
0005435611936	5305	35	16A
0005435611888	5305	36	15K
0005435423603	5305	37	15H
0005432132974	5305	38	16D
0005434343684	5305	39	16E
0005435555337	5305	40	16K
0005432132976	5305	41	17E
0005435611928	5305	42	17D
0005435555336	5305	43	17G
0005435611959	5305	44	18D
0005434343673	5305	45	18C
0005434343664	5305	46	18F
0005435611882	5305	47	18J
0005434343658	5305	48	18H
0005435611965	5305	49	19B
0005434343653	5305	50	18K
0005435611933	5305	51	19E
0005435611981	5305	52	19H
0005432132972	5305	53	19K
0005435097065	5305	54	20C
0005435611954	5305	55	20E
0005434343685	5305	56	20D
0005432132980	5305	57	20H
0005435611908	5305	58	20G
0005435423636	5305	59	21A
0005434343665	5305	60	21C
0005434343675	5305	61	21F
0005435611957	5305	62	21E
0005435611911	5305	63	21J
0005435611922	5305	64	22A
0005432132981	5305	65	21K
0005432047492	5305	66	22B
0005434573142	5305	67	22D
0005435611913	5305	68	22H
0005435611877	5305	69	22G
0005435611909	5305	70	22K
0005435611966	5305	71	22J
0005435611907	5305	72	23B
0005435611943	5305	73	23A
0005435611956	5305	74	23D
0005435611982	5305	75	23F
0005435611898	5305	76	23H
0005435611883	5305	77	23G
0005434343651	5305	78	23K
0005435611925	5305	79	24F
0005435611926	5305	80	24E
0005434573133	5305	81	24G
0005435611880	5305	82	25D
0005435611955	5305	83	25G
0005435611890	5305	84	26E
0005435611885	5305	85	26D
0005435611973	5305	86	26H
0005435097066	5305	87	26G
0005434343663	5305	88	26F
0005434343674	5305	89	26J
0005434573130	5305	90	27B
0005435491409	5305	91	26K
0005435611984	5305	92	27D
0005435611901	5305	93	27H
0005435611927	5305	94	27G
0005435611900	5305	95	28A
0005435611967	5305	96	27K
0005434573138	5305	97	28C
0005435611914	5305	98	28B
0005434343681	5305	99	28F
0005435611892	5305	100	28K
0005435490175	5305	101	28J
0005434343680	5305	102	30A
0005435611970	5305	103	30C
0005435611953	5305	104	30B
0005435611889	5305	105	30E
0005435611975	5305	106	30K
0005434573132	5305	107	30J
0005432132978	5305	108	31B
0005435611938	5305	109	31A
0005435611941	5305	110	31C
0005434573137	5305	111	31E
0005435611949	5305	112	31D
0005435611920	5305	113	31K
0005435611931	5305	114	32C
0005434343668	5305	115	32D
0005435611963	5305	116	32G
0005435611899	5305	117	32F
0005435611972	5305	118	32J
0005432132977	5305	119	32H
0005434573139	5305	120	32K
0005432132983	5305	121	33E
0005435611916	5305	122	33H
0005435611939	5305	123	33G
0005435611934	5305	124	33J
0005435611912	5305	125	34A
0005435611893	5305	126	34F
0005434343662	5305	127	35D
0005432047494	5305	128	35F
0005435097068	5305	129	35H
0005435097063	5305	130	35G
0005434343657	5305	131	36C
0005435423635	5305	132	36B
0005435097064	5305	133	36K
0005435611897	5305	134	37D
0005435611980	5305	135	37F
0005432132975	5305	136	38A
0005434343661	5305	137	37K
0005435611947	5305	138	37J
0005435611944	5305	139	38C
0005435611950	5305	140	39E
0005435611969	5305	141	39H
0005435611968	5305	142	40A
0005435611905	5305	143	39K
0005435611942	5305	144	40C
0005434343656	5305	145	40D
0005434343671	5305	146	40F
0005435611958	5305	147	41B
0005435611881	5305	148	41D
0005435611902	5305	149	41E
0005434573131	5305	150	41H
0005434343652	5305	151	42C
0005435611929	5305	152	42B
0005432132973	5305	153	42A
0005435611918	5305	154	42E
0005432132985	5305	155	42K
0005435611930	5305	156	42H
0005435491408	5305	157	43A
0005435611923	5305	158	43D
0005435611940	5305	159	43E
0005435097067	5305	160	44H
0005435490174	5305	161	44G
0005435611977	5305	162	44F
0005434343676	5305	163	44K
0005435423602	5305	164	44J
0005435611962	5305	165	45A
0005435611960	5305	166	45C
0005432132986	5305	167	45H
0005434343683	5305	168	45J
0005432132984	5305	169	46C
0005435611945	5305	170	46B
0005435611935	5305	171	46E
0005435611884	5305	172	46J
0005435611878	5305	173	46H
0005435611921	5305	174	47C
0005435097060	5305	175	47A
0005434343667	5305	176	46K
0005435611932	5305	177	47D
0005435611903	5305	178	47E
0005432132979	5305	179	47K
0005435611894	5305	180	48C
0005435611910	5305	181	48A
0005435611976	5305	182	48E
0005435611974	5305	183	48G
0005434343660	5305	184	49A
0005435611887	5305	185	49C
0005434343659	5305	186	49F
0005435611904	5305	187	49E
0005435611886	5305	188	49K
0005434343669	5305	189	49H
0005435611876	5305	190	50C
0005435611937	5305	191	50A
0005434343655	5305	192	50E
0005435611915	5305	193	50D
0005434573134	5305	194	50G
0005435611952	5305	195	50K
0005434343682	5305	196	50H
0005435423746	10910	1	1K
0005435042825	10910	2	3D
0005435423763	10910	3	4G
0005434244527	10910	4	4H
0005435423780	10910	5	5D
0005432164920	10910	6	11A
0005435423724	10910	7	11H
0005433719089	10910	8	12C
0005432164919	10910	9	12A
0005435423778	10910	10	12K
0005435423733	10910	11	13E
0005432166852	10910	12	13G
0005434244529	10910	13	14D
0005435423742	10910	14	14F
0005435423757	10910	15	15C
0005435423764	10910	16	15A
0005435423772	10910	17	15E
0005434244519	10910	18	16G
0005434244532	10910	19	17A
0005435304097	10910	20	16K
0005435423768	10910	21	17E
0005435423717	10910	22	18A
0005435319437	10910	23	17H
0005435423752	10910	24	18B
0005435423785	10910	25	18J
0005433719091	10910	26	18K
0005435423781	10910	27	19G
0005435423759	10910	28	20C
0005434244540	10910	29	20D
0005435042824	10910	30	20G
0005435423767	10910	31	21D
0005435423761	10910	32	21F
0005435423730	10910	33	21E
0005432166851	10910	34	22B
0005435423750	10910	35	22D
0005434244517	10910	36	22H
0005435423734	10910	37	22G
0005432164917	10910	38	23C
0005434244521	10910	39	23H
0005435423744	10910	40	24D
0005434244524	10910	41	23K
0005435423740	10910	42	24E
0005435423783	10910	43	24G
0005434244531	10910	44	25D
0005435423762	10910	45	25F
0005434244536	10910	46	25G
0005435423729	10910	47	26B
0005432166850	10910	48	26G
0005432164918	10910	49	26K
0005435423749	10910	50	26J
0005434244542	10910	51	26H
0005434244541	10910	52	27B
0005435423718	10910	53	27A
0005435423758	10910	54	27C
0005435319440	10910	55	27F
0005434244530	10910	56	27H
0005435423784	10910	57	28B
0005434244526	10910	58	28D
0005435319433	10910	59	28C
0005434244533	10910	60	28G
0005435423723	10910	61	28F
0005435423735	10910	62	28H
0005435423766	10910	63	29B
0005435423777	10910	64	28K
0005435423716	10910	65	29F
0005435423751	10910	66	30F
0005434244538	10910	67	30K
0005432363365	10910	68	31D
0005435423760	10910	69	31F
0005435423722	10910	70	31G
0005434244543	10910	71	32E
0005435319436	10910	72	32H
0005435423721	10910	73	33B
0005435423786	10910	74	33A
0005435423756	10910	75	33F
0005434244539	10910	76	33E
0005434244523	10910	77	34C
0005432363366	10910	78	34A
0005435423726	10910	79	34J
0005435423753	10910	80	34H
0005435423743	10910	81	35D
0005432840980	10910	82	35G
0005433719088	10910	83	35F
0005434244515	10910	84	35K
0005435423745	10910	85	36C
0005435423776	10910	86	36B
0005435319432	10910	87	36D
0005433719090	10910	88	36H
0005432164923	10910	89	37D
0005435423770	10910	90	37C
0005435423748	10910	91	37G
0005434244534	10910	92	38A
0005432164921	10910	93	38J
0005435423737	10910	94	38H
0005435423732	10910	95	39C
0005434244522	10910	96	39J
0005435423774	10910	97	39G
0005435319438	10910	98	40A
0005435423773	10910	99	39K
0005435423739	10910	100	40B
0005435423782	10910	101	40E
0005435423754	10910	102	40D
0005435423736	10910	103	40H
0005435423779	10910	104	41B
0005435423765	10910	105	40K
0005435423775	10910	106	41C
0005432164922	10910	107	41F
0005435304098	10910	108	41J
0005432840981	10910	109	42C
0005434244516	10910	110	42E
0005434244518	10910	111	42D
0005435423727	10910	112	42G
0005435423741	10910	113	42J
0005435319435	10910	114	44A
0005434244528	10910	115	44C
0005434656525	10910	116	44K
0005435423747	10910	117	44H
0005432840982	10910	118	45C
0005435423755	10910	119	46E
0005435319434	10910	120	46H
0005434244535	10910	121	47A
0005435423725	10910	122	47D
0005434244537	10910	123	47G
0005435423769	10910	124	47F
0005435423731	10910	125	47E
0005435423720	10910	126	48C
0005434244525	10910	127	48E
0005435423738	10910	128	49D
0005435319439	10910	129	49C
0005435423728	10910	130	49H
0005434244520	10910	131	50C
0005434656524	10910	132	50E
0005435423719	10910	133	50D
0005435423771	10910	134	50G
0005432181366	3246	1	1A
0005432181374	3246	2	1C
0005433506902	3246	3	1D
0005433633287	3246	4	2A
0005432181370	3246	5	2C
0005433804838	3246	6	2F
0005433804852	3246	7	3D
0005432181377	3246	8	4A
0005433804849	3246	9	3F
0005432181373	3246	10	4C
0005433633313	3246	11	4D
0005433804840	3246	12	5A
0005433506898	3246	13	5C
0005433506903	3246	14	5F
0005433506910	3246	15	6A
0005433633301	3246	16	6F
0005433633316	3246	17	6D
0005432181384	3246	18	7D
0005432181379	3246	19	8A
0005433804853	3246	20	8B
0005432181386	3246	21	8D
0005433633310	3246	22	8C
0005433506911	3246	23	8E
0005433804846	3246	24	9B
0005433633288	3246	25	9A
0005433804847	3246	26	9C
0005433506908	3246	27	9D
0005433633308	3246	28	9E
0005432181383	3246	29	10A
0005433633302	3246	30	9F
0005433804851	3246	31	10B
0005433804834	3246	32	10C
0005433804850	3246	33	10D
0005433804857	3246	34	10F
0005433633291	3246	35	11B
0005432181381	3246	36	11A
0005433804854	3246	37	11C
0005433633290	3246	38	12A
0005433804856	3246	39	12B
0005432181367	3246	40	12D
0005433506909	3246	41	12F
0005433633303	3246	42	12E
0005433633294	3246	43	13A
0005433633297	3246	44	13D
0005433633311	3246	45	13E
0005433506900	3246	46	14A
0005433506904	3246	47	14B
0005432181368	3246	48	14D
0005432181372	3246	49	14E
0005433633283	3246	50	15C
0005433633317	3246	51	15F
0005433804858	3246	52	15E
0005433633292	3246	53	16A
0005433633286	3246	54	16B
0005433804836	3246	55	16F
0005433506905	3246	56	17B
0005433633300	3246	57	17C
0005433506907	3246	58	17E
0005433633309	3246	59	18A
0005433506892	3246	60	18D
0005433633295	3246	61	18C
0005433804835	3246	62	18F
0005433804832	3246	63	19C
0005432181382	3246	64	19E
0005432181385	3246	65	20F
0005433804842	3246	66	21B
0005433633306	3246	67	21C
0005433506906	3246	68	21E
0005433506896	3246	69	22A
0005433506893	3246	70	21F
0005433633299	3246	71	22B
0005433804848	3246	72	23A
0005433804830	3246	73	23C
0005432181364	3246	74	23D
0005433633296	3246	75	23F
0005433633304	3246	76	24C
0005432181376	3246	77	24D
0005432181375	3246	78	24F
0005433804839	3246	79	24E
0005433804855	3246	80	25D
0005433633315	3246	81	25C
0005433804845	3246	82	26A
0005433633289	3246	83	25F
0005433804841	3246	84	26B
0005433506891	3246	85	26D
0005433633314	3246	86	26F
0005433804837	3246	87	27A
0005433633285	3246	88	27C
0005433633312	3246	89	27B
0005432181371	3246	90	27F
0005433633293	3246	91	27E
0005433633305	3246	92	28D
0005433633298	3246	93	28C
0005433804843	3246	94	28E
0005433804831	3246	95	28F
0005433804833	3246	96	29B
0005433506901	3246	97	29A
0005432181378	3246	98	29C
0005433506899	3246	99	29E
0005433804844	3246	100	29D
0005433506897	3246	101	30C
0005432181380	3246	102	30B
0005433804829	3246	103	30D
0005432181365	3246	104	30F
0005433633307	3246	105	31B
0005433633284	3246	106	31A
0005433506895	3246	107	31C
0005433506894	3246	108	31D
0005432181369	3246	109	31E
0005435884392	3247	1	7C
0005435884408	3247	2	14F
0005435884393	3247	3	19E
0005435884409	3247	4	25D
0005435884391	3247	5	29B
0005432459106	8287	1	1C
0005432459110	8287	2	1D
0005432459086	8287	3	1F
0005435884524	8287	4	2A
0005432459078	8287	5	2D
0005435884523	8287	6	3A
0005435884521	8287	7	2F
0005435884494	8287	8	3C
0005432042507	8287	9	3D
0005432459088	8287	10	4A
0005432459063	8287	11	4C
0005432459070	8287	12	5A
0005435884506	8287	13	5C
0005435884501	8287	14	5D
0005432459112	8287	15	6C
0005435884497	8287	16	6D
0005432459075	8287	17	7C
0005432042509	8287	18	8E
0005435884505	8287	19	8F
0005432459101	8287	20	9A
0005432459073	8287	21	9C
0005435884509	8287	22	9B
0005432459100	8287	23	9F
0005432459077	8287	24	9E
0005435884484	8287	25	10A
0005435884498	8287	26	10B
0005435884525	8287	27	10C
0005435884516	8287	28	10E
0005432459091	8287	29	11B
0005435884504	8287	30	11C
0005435884486	8287	31	11E
0005435884485	8287	32	11D
0005432042503	8287	33	11F
0005435884496	8287	34	12C
0005432459065	8287	35	12D
0005432459089	8287	36	12E
0005432459092	8287	37	12F
0005435884507	8287	38	13A
0005432042504	8287	39	13F
0005435884488	8287	40	13E
0005435884499	8287	41	14A
0005435884510	8287	42	14B
0005432042502	8287	43	14D
0005435884500	8287	44	14F
0005432459109	8287	45	15A
0005432459071	8287	46	15C
0005432459102	8287	47	15B
0005434312287	8287	48	15E
0005432042495	8287	49	15D
0005432459098	8287	50	15F
0005435884491	8287	51	16C
0005432459081	8287	52	16B
0005432459080	8287	53	16D
0005432042506	8287	54	16E
0005432042505	8287	55	16F
0005432459067	8287	56	17A
0005432459115	8287	57	17C
0005434312288	8287	58	17F
0005432042501	8287	59	18A
0005432459076	8287	60	18C
0005432459095	8287	61	18E
0005432042496	8287	62	18F
0005435884514	8287	63	19C
0005432042508	8287	64	20A
0005432459093	8287	65	19E
0005432042497	8287	66	20B
0005432042500	8287	67	20D
0005432459084	8287	68	20C
0005435884518	8287	69	20E
0005435884503	8287	70	20F
0005432459087	8287	71	21A
0005435884511	8287	72	21D
0005432459111	8287	73	21C
0005435884495	8287	74	22A
0005432459094	8287	75	21F
0005432459105	8287	76	22B
0005432459104	8287	77	22C
0005435884502	8287	78	22D
0005435884489	8287	79	22E
0005432459103	8287	80	23B
0005432459108	8287	81	23C
0005435884493	8287	82	23D
0005435884517	8287	83	24A
0005432459107	8287	84	24B
0005432459099	8287	85	24C
0005432459090	8287	86	24E
0005432459066	8287	87	24D
0005435884519	8287	88	24F
0005435884492	8287	89	25A
0005432459083	8287	90	25C
0005432459074	8287	91	25B
0005435884483	8287	92	25D
0005432459079	8287	93	25E
0005432459097	8287	94	26A
0005435884520	8287	95	26D
0005435884487	8287	96	26F
0005432459068	8287	97	27A
0005432459085	8287	98	27D
0005432459113	8287	99	27F
0005432459064	8287	100	27E
0005432459069	8287	101	28B
0005435884522	8287	102	28D
0005435884513	8287	103	29A
0005435884512	8287	104	28F
0005432459114	8287	105	29C
0005435884490	8287	106	29D
0005435884508	8287	107	29E
0005432042498	8287	108	30A
0005432042499	8287	109	30B
0005432459082	8287	110	30E
0005435884482	8287	111	30F
0005435884515	8287	112	31C
0005432459072	8287	113	31B
0005432459096	8287	114	31E
0005432727752	4603	1	1C
0005433194822	4603	2	1D
0005432382598	4603	3	2A
0005432382581	4603	4	2C
0005432382570	4603	5	2D
0005432382576	4603	6	2F
0005432382588	4603	7	3A
0005432382601	4603	8	4A
0005433453731	4603	9	4D
0005432382604	4603	10	4E
0005432727745	4603	11	4F
0005432727741	4603	12	5A
0005432382591	4603	13	5C
0005433194821	4603	14	5E
0005432727743	4603	15	5F
0005432382571	4603	16	6A
0005432382575	4603	17	6C
0005432382577	4603	18	6D
0005432382589	4603	19	6E
0005433194823	4603	20	7C
0005432382578	4603	21	7D
0005432382599	4603	22	7F
0005432382580	4603	23	8A
0005432727750	4603	24	8C
0005432727753	4603	25	8D
0005432382565	4603	26	9A
0005432382596	4603	27	9C
0005432382600	4603	28	9E
0005433453732	4603	29	10E
0005432382568	4603	30	10F
0005432382592	4603	31	11A
0005432382566	4603	32	11C
0005432382595	4603	33	11D
0005432727742	4603	34	11F
0005433453730	4603	35	12A
0005432727751	4603	36	12D
0005433722119	4603	37	12E
0005432382586	4603	38	12F
0005432382572	4603	39	13A
0005432382585	4603	40	13C
0005432382587	4603	41	13D
0005433722118	4603	42	13E
0005432382567	4603	43	14A
0005433454841	4603	44	14C
0005432382579	4603	45	14D
0005432382574	4603	46	14E
0005432727748	4603	47	14F
0005432382597	4603	48	15A
0005432382573	4603	49	15D
0005432382590	4603	50	16A
0005432382582	4603	51	16D
0005432382594	4603	52	16E
0005432382593	4603	53	16F
0005433722120	4603	54	17A
0005432382602	4603	55	17C
0005432382583	4603	56	17D
0005432382605	4603	57	17F
0005432727744	4603	58	18C
0005432382584	4603	59	18D
0005432727747	4603	60	18F
0005432382564	4603	61	19C
0005432727746	4603	62	19D
0005433454842	4603	63	19E
0005433194820	4603	64	19F
0005432382569	4603	65	20C
0005432727749	4603	66	20D
0005432382603	4603	67	20E
0005432727754	4603	68	20F
0005433516748	1729	1	1C
0005435528926	1729	2	1D
0005435540684	1729	3	2A
0005433516743	1729	4	2C
0005435540689	1729	5	2D
0005435528923	1729	6	3A
0005435540678	1729	7	3D
0005432294452	1729	8	4D
0005435528935	1729	9	4F
0005435540669	1729	10	5C
0005435528924	1729	11	5D
0005435528941	1729	12	5E
0005433516744	1729	13	5F
0005435540674	1729	14	6A
0005435540682	1729	15	6C
0005435528929	1729	16	6D
0005435540668	1729	17	6E
0005435540672	1729	18	6F
0005435528945	1729	19	7C
0005435540679	1729	20	7D
0005435540685	1729	21	7E
0005433516746	1729	22	7F
0005435540683	1729	23	8C
0005435540670	1729	24	8D
0005435540673	1729	25	9A
0005435528940	1729	26	9D
0005435528928	1729	27	10A
0005433516747	1729	28	10C
0005435540667	1729	29	10E
0005435528927	1729	30	11C
0005435528936	1729	31	11D
0005435528937	1729	32	11E
0005435540688	1729	33	11F
0005435528944	1729	34	12A
0005435528938	1729	35	12D
0005435528922	1729	36	13A
0005435540676	1729	37	13C
0005432294451	1729	38	13D
0005435528939	1729	39	13E
0005435528942	1729	40	14F
0005432294450	1729	41	15C
0005435540671	1729	42	15D
0005433516742	1729	43	15E
0005435540675	1729	44	15F
0005435528932	1729	45	16C
0005433516740	1729	46	16D
0005435528925	1729	47	16E
0005433516745	1729	48	16F
0005435540686	1729	49	17A
0005435540687	1729	50	17C
0005435540681	1729	51	17E
0005435528946	1729	52	17F
0005435528943	1729	53	18C
0005435540680	1729	54	18D
0005435540677	1729	55	18E
0005435528931	1729	56	19A
0005433516741	1729	57	19C
0005435528933	1729	58	19D
0005435528930	1729	59	19F
0005435528934	1729	60	20A
0005432924963	22011	1	1F
0005432924965	22011	2	8D
0005432924961	22011	3	10A
0005432924964	22011	4	12A
0005432924966	22011	5	16C
0005432924962	22011	6	16D
0005434458486	7377	1	1A
0005434458495	7377	2	1C
0005432838547	7377	3	1F
0005432823417	7377	4	2F
0005432838575	7377	5	3A
0005432823418	7377	6	3C
0005432838566	7377	7	4A
0005432840979	7377	8	4C
0005434458479	7377	9	5A
0005434458488	7377	10	5F
0005434458485	7377	11	6A
0005432838572	7377	12	6C
0005432838552	7377	13	6E
0005432073338	7377	14	7D
0005432838555	7377	15	7E
0005434458494	7377	16	7F
0005432838546	7377	17	8A
0005432838554	7377	18	8C
0005432838549	7377	19	8E
0005432838563	7377	20	9C
0005434458478	7377	21	9E
0005432838553	7377	22	9F
0005434458482	7377	23	10A
0005432838571	7377	24	10E
0005432838573	7377	25	10F
0005434458489	7377	26	11D
0005432073336	7377	27	11E
0005434458491	7377	28	11F
0005432838561	7377	29	12A
0005432838560	7377	30	12C
0005432838574	7377	31	12D
0005434458487	7377	32	12E
0005432838562	7377	33	12F
0005432838556	7377	34	13A
0005432838568	7377	35	13C
0005434458477	7377	36	13D
0005434458492	7377	37	13E
0005432840977	7377	38	14A
0005434458483	7377	39	14C
0005432838569	7377	40	14D
0005432838557	7377	41	14E
0005432073337	7377	42	15A
0005432823416	7377	43	15C
0005432838545	7377	44	15E
0005434458493	7377	45	16C
0005434458480	7377	46	16E
0005432838558	7377	47	16F
0005432838565	7377	48	17C
0005432838564	7377	49	17E
0005434458484	7377	50	17F
0005432838559	7377	51	18C
0005434458490	7377	52	18D
0005432840978	7377	53	18E
0005434458476	7377	54	19A
0005434458496	7377	55	19C
0005432838570	7377	56	19D
0005432838550	7377	57	19E
0005432838548	7377	58	19F
0005432838567	7377	59	20A
0005434458481	7377	60	20D
0005432838551	7377	61	20E
0005432000991	28913	1	1D
0005435252431	28913	2	3C
0005435252422	28913	3	3F
0005435252424	28913	4	4D
0005435252418	28913	5	4E
0005432000992	28913	6	5F
0005435252429	28913	7	6D
0005435252420	28913	8	7D
0005435252432	28913	9	8A
0005435252419	28913	10	8C
0005435252427	28913	11	8D
0005435491411	28913	12	9C
0005435252423	28913	13	11D
0005435252421	28913	14	13E
0005435252430	28913	15	15D
0005435491410	28913	16	15E
0005435252433	28913	17	15F
0005435252426	28913	18	16C
0005435252425	28913	19	16E
0005435252434	28913	20	17F
0005434664925	28913	21	18C
0005435491412	28913	22	18D
0005435252428	28913	23	19C
0005432000993	28913	24	19E
0005435990514	8810	1	4C
0005435990518	8810	2	7A
0005435990515	8810	3	8B
0005435990516	8810	4	9E
0005435990513	8810	5	18C
0005435990517	8810	6	18E
0005434275939	15733	1	9B
0005434275938	15733	2	13E
0005434275941	15733	3	17E
0005434275940	15733	4	19F
0005433468194	2083	1	1C
0005433468195	2083	2	2A
0005433468198	2083	3	2C
0005433468203	2083	4	3B
0005433468200	2083	5	3D
0005433468206	2083	6	4A
0005433468190	2083	7	4C
0005433468197	2083	8	6A
0005433468202	2083	9	6D
0005433468201	2083	10	7B
0005433468193	2083	11	7C
0005433468205	2083	12	18C
0005433468196	2083	13	19A
0005433468204	2083	14	19C
0005433468192	2083	15	20C
0005433468189	2083	16	20D
0005433468191	2083	17	21A
0005433468199	2083	18	23A
0005432909206	23838	1	1C
0005432909200	23838	2	1D
0005432909204	23838	3	2B
0005432909197	23838	4	3D
0005432909196	23838	5	5A
0005432909191	23838	6	6A
0005432909194	23838	7	7A
0005432909195	23838	8	7D
0005432909198	23838	9	18B
0005432909193	23838	10	18C
0005432909189	23838	11	18D
0005432909205	23838	12	20A
0005432909190	23838	13	20B
0005432909202	23838	14	20C
0005432909201	23838	15	20D
0005432909199	23838	16	21D
0005432909203	23838	17	23A
0005432909192	23838	18	22D
0005432359622	6363	1	1A
0005432359621	6363	2	1D
0005432359636	6363	3	1F
0005432359637	6363	4	2C
0005432359611	6363	5	3C
0005432359642	6363	6	4B
0005432363366	6363	7	4D
0005432359630	6363	8	4E
0005432335850	6363	9	5A
0005432359643	6363	10	5D
0005432359645	6363	11	5E
0005432359639	6363	12	5F
0005432062144	6363	13	6A
0005432359632	6363	14	6C
0005432359648	6363	15	6E
0005432359614	6363	16	6D
0005432359617	6363	17	6F
0005432363365	6363	18	7C
0005432359608	6363	19	7D
0005432359627	6363	20	7F
0005432359635	6363	21	7E
0005432359629	6363	22	8A
0005432359631	6363	23	8F
0005432359626	6363	24	9C
0005432359610	6363	25	9E
0005432359623	6363	26	10C
0005432335849	6363	27	10E
0005432359628	6363	28	11C
0005432359607	6363	29	11B
0005432359606	6363	30	11D
0005432359634	6363	31	11F
0005432359640	6363	32	11E
0005432335857	6363	33	12A
0005432359612	6363	34	12C
0005432359644	6363	35	13D
0005432335856	6363	36	13C
0005432335846	6363	37	14A
0005432062146	6363	38	14D
0005432359649	6363	39	15C
0005432359641	6363	40	16B
0005432062147	6363	41	16A
0005432335848	6363	42	16C
0005432359625	6363	43	16E
0005432335855	6363	44	16D
0005432062150	6363	45	17A
0005432335845	6363	46	16F
0005432359647	6363	47	17B
0005432359615	6363	48	17E
0005432062149	6363	49	18D
0005432359618	6363	50	18C
0005432359613	6363	51	18F
0005432359638	6363	52	19A
0005432359619	6363	53	19B
0005432359651	6363	54	19D
0005432359652	6363	55	19F
0005432359609	6363	56	20A
0005432335851	6363	57	20C
0005432359624	6363	58	20E
0005432335854	6363	59	20D
0005432062145	6363	60	21B
0005432335847	6363	61	21A
0005432359633	6363	62	21D
0005432359653	6363	63	21E
0005432335853	6363	64	21F
0005432359616	6363	65	22E
0005432359620	6363	66	23A
0005432359646	6363	67	23D
0005432359650	6363	68	23C
0005432335852	6363	69	23E
0005432062148	6363	70	23F
0005435176662	21041	1	1D
0005435176664	21041	2	1C
0005435176643	21041	3	1F
0005435176653	21041	4	3D
0005435176649	21041	5	4B
0005434149546	21041	6	4A
0005434149549	21041	7	4C
0005435176656	21041	8	4D
0005435176642	21041	9	4E
0005435176644	21041	10	5A
0005435176668	21041	11	5C
0005434149550	21041	12	5D
0005434149545	21041	13	5E
0005435176647	21041	14	6A
0005435490179	21041	15	6F
0005435490178	21041	16	7B
0005435176648	21041	17	7A
0005435176659	21041	18	7E
0005432052699	21041	19	8A
0005435723015	21041	20	8B
0005435176665	21041	21	8D
0005435176663	21041	22	8E
0005434149547	21041	23	9B
0005434149551	21041	24	9F
0005435176657	21041	25	10C
0005434149556	21041	26	10E
0005435176667	21041	27	11A
0005435176655	21041	28	11D
0005434149555	21041	29	11E
0005432052700	21041	30	11F
0005435723013	21041	31	12A
0005435176652	21041	32	12E
0005434149548	21041	33	12F
0005435176646	21041	34	13E
0005435176645	21041	35	14A
0005435176661	21041	36	14C
0005435723014	21041	37	15D
0005435490180	21041	38	16F
0005435176669	21041	39	18F
0005435176666	21041	40	18E
0005435490177	21041	41	19F
0005435176660	21041	42	20B
0005434149553	21041	43	20C
0005434149544	21041	44	21C
0005434149552	21041	45	21D
0005435176658	21041	46	22A
0005434149554	21041	47	21F
0005435176654	21041	48	22E
0005435176651	21041	49	23C
0005435176650	21041	50	23D
0005434186154	17694	1	6A
0005434186153	17694	2	6C
0005434186155	17694	3	6D
0005434186156	17694	4	19A
0005434458476	29115	1	1A
0005434448259	29115	2	1B
0005434458494	29115	3	1C
0005434458484	29115	4	2C
0005434458486	29115	5	2D
0005434458487	29115	6	3B
0005434463894	29115	7	3D
0005434448257	29115	8	4A
0005434458477	29115	9	4C
0005434458496	29115	10	4D
0005434458485	29115	11	5A
0005434458495	29115	12	5B
0005434463893	29115	13	5C
0005434462754	29115	14	6D
0005434463895	29115	15	7A
0005434458482	29115	16	7D
0005434458480	29115	17	18B
0005434458483	29115	18	18C
0005434458478	29115	19	18D
0005434458488	29115	20	19A
0005434458492	29115	21	19B
0005434448260	29115	22	19D
0005434458479	29115	23	20A
0005434448258	29115	24	20B
0005434458491	29115	25	20C
0005434458490	29115	26	20D
0005434462755	29115	27	22A
0005434458481	29115	28	22C
0005434458489	29115	29	22D
0005434458493	29115	30	23B
0005432603717	21469	1	1B
0005432603716	21469	2	1C
0005432603699	21469	3	1D
0005432603704	21469	4	2A
0005432603720	21469	5	2B
0005432603683	21469	6	2C
0005432603695	21469	7	2D
0005432603706	21469	8	3A
0005432603703	21469	9	3B
0005432603697	21469	10	3C
0005432603718	21469	11	3D
0005432603709	21469	12	4A
0005432603719	21469	13	4B
0005432603686	21469	14	4C
0005432603708	21469	15	5B
0005432603701	21469	16	5C
0005432603693	21469	17	6A
0005432603711	21469	18	6B
0005432603712	21469	19	6C
0005432603684	21469	20	6D
0005432603700	21469	21	7A
0005432603713	21469	22	7B
0005432603691	21469	23	7D
0005432603715	21469	24	18A
0005432603714	21469	25	18D
0005432603682	21469	26	19A
0005432603696	21469	27	19B
0005432603692	21469	28	20A
0005432603687	21469	29	20B
0005432603722	21469	30	20C
0005432603698	21469	31	20D
0005432603705	21469	32	21A
0005432603721	21469	33	21B
0005432603702	21469	34	21C
0005432603710	21469	35	21D
0005432603707	21469	36	22A
0005432603685	21469	37	22B
0005432603690	21469	38	22C
0005432603694	21469	39	23A
0005432603689	21469	40	22D
0005432603688	21469	41	23B
0005435221498	31659	1	2B
0005435221500	31659	2	2C
0005435221037	31659	3	20B
0005435221499	31659	4	22A
0005433293148	29611	1	1A
0005433293155	29611	2	2C
0005433293150	29611	3	2D
0005433293149	29611	4	3A
0005433293158	29611	5	3D
0005433293152	29611	6	4B
0005433293154	29611	7	5B
0005433293161	29611	8	5C
0005433293157	29611	9	6B
0005433293159	29611	10	6C
0005433293162	29611	11	6D
0005433293151	29611	12	7D
0005433293153	29611	13	20B
0005433293156	29611	14	21B
0005433293160	29611	15	22A
0005433293163	29611	16	22D
0005433473113	6678	1	1A
0005433473111	6678	2	2A
0005433473109	6678	3	2B
0005433473110	6678	4	2D
0005433473118	6678	5	3B
0005433473119	6678	6	3C
0005433473121	6678	7	4A
0005433473114	6678	8	6B
0005433473122	6678	9	6C
0005433473126	6678	10	6D
0005433473112	6678	11	7B
0005433473117	6678	12	7D
0005433473125	6678	13	19C
0005433473127	6678	14	19D
0005433473116	6678	15	20A
0005433473120	6678	16	20C
0005433473123	6678	17	21B
0005433473115	6678	18	22A
0005433473124	6678	19	22C
0005435257149	23897	1	1A
0005435257151	23897	2	1B
0005435257153	23897	3	4B
0005435257145	23897	4	4D
0005435257148	23897	5	5D
0005435257147	23897	6	6D
0005435257154	23897	7	7A
0005435257157	23897	8	19A
0005435257144	23897	9	19D
0005435257155	23897	10	20A
0005435257150	23897	11	20B
0005435257143	23897	12	21A
0005435257146	23897	13	21C
0005435257152	23897	14	22C
0005435257156	23897	15	23A
0005434604843	22401	1	1A
0005434606764	22401	2	3A
0005434604844	22401	3	3B
0005434606767	22401	4	4B
0005434604840	22401	5	4A
0005434604842	22401	6	5A
0005434606765	22401	7	5B
0005434606766	22401	8	6A
0005434604841	22401	9	6B
0005434602867	3837	1	1A
0005434602864	3837	2	1D
0005434522380	3837	3	2B
0005434602865	3837	4	2D
0005434602863	3837	5	3C
0005434602862	3837	6	4B
0005434602860	3837	7	4C
0005434602858	3837	8	4D
0005434522381	3837	9	5A
0005434602861	3837	10	5C
0005434522379	3837	11	5D
0005434522383	3837	12	6B
0005434522377	3837	13	7B
0005434602859	3837	14	18A
0005434522386	3837	15	18C
0005434522382	3837	16	19B
0005434522378	3837	17	19C
0005434522385	3837	18	19D
0005434522387	3837	19	20A
0005434522376	3837	20	21D
0005434602866	3837	21	22B
0005434522384	3837	22	23A
0005435904370	19059	1	1D
0005435904369	19059	2	4A
0005435904368	19059	3	4D
0005435904371	19059	4	18A
0005435904366	19059	5	20C
0005435904367	19059	6	21B
0005435904365	19059	7	21C
0005435904372	19059	8	23B
0005432746953	382	1	1A
0005432746962	382	2	1F
0005432746945	382	3	2C
0005432746973	382	4	3A
0005435154583	382	5	3F
0005432753245	382	6	4A
0005432746959	382	7	4D
0005432746968	382	8	4E
0005432219934	382	9	5D
0005435154584	382	10	5E
0005432746972	382	11	5F
0005432746963	382	12	6A
0005432746948	382	13	6F
0005432746969	382	14	7A
0005432746955	382	15	7D
0005432749749	382	16	7F
0005432746954	382	17	8D
0005432746975	382	18	8F
0005432219938	382	19	9A
0005432751473	382	20	9E
0005432219937	382	21	9F
0005432746952	382	22	10C
0005432746956	382	23	10F
0005432746949	382	24	11A
0005432751470	382	25	11C
0005432746971	382	26	11D
0005432746981	382	27	12A
0005432749750	382	28	12C
0005432753246	382	29	13A
0005432746965	382	30	13C
0005432746946	382	31	13F
0005432746979	382	32	14A
0005432746964	382	33	14E
0005435154585	382	34	14F
0005432746970	382	35	15A
0005432746978	382	36	15C
0005432219936	382	37	15D
0005432746967	382	38	15F
0005432746961	382	39	16A
0005432746960	382	40	16C
0005432219935	382	41	16E
0005432746950	382	42	16F
0005432746957	382	43	17A
0005432746977	382	44	17C
0005432746966	382	45	17E
0005432746976	382	46	17F
0005432753247	382	47	18A
0005432746958	382	48	18E
0005432746974	382	49	19A
0005432746980	382	50	19D
0005432751472	382	51	19E
0005432746947	382	52	19F
0005432751471	382	53	20C
0005432746951	382	54	20F
0005432890723	12085	1	1C
0005432890727	12085	2	2C
0005432890728	12085	3	4C
0005433875356	12085	4	5A
0005432890717	12085	5	5C
0005432890711	12085	6	5F
0005434153515	12085	7	6A
0005432890718	12085	8	6F
0005432890721	12085	9	7C
0005432890720	12085	10	10A
0005432890714	12085	11	11A
0005432890712	12085	12	11F
0005432890719	12085	13	12C
0005432890713	12085	14	12F
0005432214769	12085	15	13E
0005432890726	12085	16	14A
0005433875355	12085	17	14E
0005432890715	12085	18	14F
0005432890724	12085	19	15C
0005432890716	12085	20	17E
0005432890722	12085	21	19D
0005432890725	12085	22	19F
0005432890710	12085	23	20A
0005432214770	12085	24	20F
0005433524858	18960	1	1B
0005433533244	18960	2	2C
0005433524865	18960	3	2D
0005433531233	18960	4	3A
0005433524860	18960	5	4A
0005433524867	18960	6	4B
0005433524866	18960	7	5A
0005433524861	18960	8	5B
0005433524869	18960	9	5C
0005433533247	18960	10	6B
0005433524857	18960	11	6D
0005433524868	18960	12	7A
0005433524856	18960	13	7D
0005433524859	18960	14	18A
0005433533246	18960	15	18B
0005433531230	18960	16	18D
0005433524863	18960	17	19C
0005433531232	18960	18	20A
0005433533245	18960	19	20C
0005433524864	18960	20	21A
0005433524862	18960	21	21B
0005433531231	18960	22	22A
0005433531229	18960	23	22B
0005432927897	32484	1	2D
0005432927898	32484	2	3D
0005432927902	32484	3	5B
0005432927899	32484	4	6C
0005432927901	32484	5	7C
0005432927900	32484	6	21B
0005434821646	5302	1	1C
0005434821614	5302	2	1D
0005434558150	5302	3	2D
0005434821661	5302	4	2H
0005434831073	5302	5	2G
0005432396181	5302	6	2K
0005434821579	5302	7	3C
0005432121121	5302	8	3H
0005434831075	5302	9	3G
0005434821580	5302	10	4G
0005432121118	5302	11	4K
0005434821583	5302	12	5D
0005434821635	5302	13	5C
0005434821677	5302	14	5A
0005434821654	5302	15	5G
0005435149825	5302	16	11E
0005434821637	5302	17	12C
0005434821679	5302	18	12A
0005434821698	5302	19	12D
0005434821616	5302	20	12G
0005434821607	5302	21	13A
0005434821652	5302	22	12K
0005434821599	5302	23	12H
0005434821680	5302	24	13D
0005434821629	5302	25	13F
0005434821572	5302	26	13G
0005434821595	5302	27	13K
0005434821673	5302	28	14D
0005434821587	5302	29	14C
0005434821645	5302	30	14F
0005434821669	5302	31	14K
0005434664923	5302	32	15A
0005435149813	5302	33	15F
0005434821641	5302	34	15D
0005434821697	5302	35	16A
0005434821684	5302	36	15K
0005434821648	5302	37	16H
0005434664924	5302	38	17C
0005434821597	5302	39	17A
0005434821658	5302	40	17G
0005434821601	5302	41	17F
0005434821626	5302	42	18A
0005432394040	5302	43	18E
0005435149824	5302	44	18J
0005434821582	5302	45	19A
0005432121117	5302	46	19C
0005434821590	5302	47	19F
0005434821577	5302	48	19H
0005434558153	5302	49	19G
0005434821603	5302	50	19K
0005434821682	5302	51	20C
0005435149817	5302	52	20B
0005434821651	5302	53	20A
0005434821574	5302	54	20E
0005434821624	5302	55	20G
0005434821620	5302	56	20K
0005434821585	5302	57	21A
0005434558149	5302	58	21D
0005434821586	5302	59	21F
0005434821691	5302	60	21G
0005434821605	5302	61	22A
0005432121116	5302	62	22B
0005435149815	5302	63	22E
0005434821578	5302	64	22D
0005434821699	5302	65	22G
0005434821647	5302	66	22K
0005434821666	5302	67	22J
0005434821685	5302	68	23F
0005434828651	5302	69	23H
0005434821619	5302	70	23G
0005434821628	5302	71	23K
0005434821689	5302	72	24G
0005434821664	5302	73	25E
0005434558151	5302	74	25H
0005432121112	5302	75	25G
0005434821692	5302	76	26A
0005434821631	5302	77	25K
0005432121114	5302	78	26C
0005434821694	5302	79	26E
0005435149822	5302	80	26G
0005432121119	5302	81	26F
0005434821676	5302	82	26H
0005432394042	5302	83	27C
0005434821672	5302	84	27F
0005434821592	5302	85	27E
0005434821695	5302	86	27H
0005432121115	5302	87	28C
0005434821611	5302	88	28A
0005434831071	5302	89	28E
0005434558154	5302	90	28F
0005434821674	5302	91	28K
0005434821632	5302	92	28J
0005432396182	5302	93	29A
0005434821623	5302	94	29D
0005434821589	5302	95	29F
0005434821596	5302	96	29E
0005434821653	5302	97	29K
0005435149816	5302	98	29J
0005434821622	5302	99	30B
0005434821591	5302	100	30A
0005434821642	5302	101	30H
0005434821667	5302	102	30G
0005435149820	5302	103	30K
0005434821604	5302	104	31A
0005434821576	5302	105	31G
0005432396180	5302	106	31K
0005434821696	5302	107	32B
0005434821606	5302	108	32A
0005434821675	5302	109	33A
0005434821665	5302	110	33J
0005434821593	5302	111	34B
0005432396179	5302	112	34E
0005434831072	5302	113	35D
0005434821655	5302	114	35J
0005434821687	5302	115	36A
0005434821598	5302	116	36E
0005434664922	5302	117	36H
0005434821693	5302	118	36G
0005434821615	5302	119	36F
0005434821594	5302	120	36K
0005432121122	5302	121	37B
0005434828652	5302	122	37A
0005434821659	5302	123	37F
0005432121120	5302	124	37E
0005434821639	5302	125	37J
0005434821636	5302	126	37G
0005434821613	5302	127	38C
0005434831074	5302	128	38K
0005432394041	5302	129	38J
0005434821668	5302	130	39A
0005435149818	5302	131	39C
0005434821625	5302	132	39F
0005434821571	5302	133	39H
0005434821671	5302	134	39J
0005432394043	5302	135	40A
0005435149826	5302	136	40D
0005434821644	5302	137	40G
0005434821683	5302	138	41A
0005432121113	5302	139	40K
0005434821600	5302	140	41D
0005432121123	5302	141	41C
0005434664921	5302	142	41H
0005434821575	5302	143	42B
0005434821588	5302	144	42A
0005432121124	5302	145	42E
0005434821630	5302	146	42D
0005434821610	5302	147	42H
0005434821612	5302	148	42F
0005434821618	5302	149	42K
0005434821617	5302	150	43A
0005434821662	5302	151	43C
0005434821573	5302	152	43F
0005434821656	5302	153	43E
0005434828653	5302	154	43J
0005434821643	5302	155	44C
0005434821584	5302	156	44B
0005434821690	5302	157	44A
0005434821688	5302	158	44E
0005434821649	5302	159	44G
0005434821633	5302	160	44K
0005434821640	5302	161	44J
0005435149821	5302	162	44H
0005434821657	5302	163	45B
0005435149819	5302	164	45C
0005434821650	5302	165	45H
0005434821670	5302	166	45G
0005434558152	5302	167	46D
0005434821663	5302	168	46C
0005434821678	5302	169	46H
0005434821608	5302	170	46F
0005434821681	5302	171	47A
0005435149814	5302	172	47E
0005434821660	5302	173	47G
0005434821627	5302	174	48H
0005434821609	5302	175	48G
0005434821686	5302	176	48F
0005432121111	5302	177	49E
0005435386455	5302	178	49F
0005434821581	5302	179	50C
0005435149823	5302	180	50A
0005434821638	5302	181	50E
0005434821634	5302	182	50F
0005434821621	5302	183	50K
0005434821602	5302	184	51G
0005435372265	9879	1	1C
0005435372280	9879	2	1A
0005435179688	9879	3	1H
0005435299704	9879	4	2C
0005435372270	9879	5	2A
0005432202953	9879	6	2G
0005435372256	9879	7	3D
0005435372244	9879	8	3K
0005432202955	9879	9	4G
0005435372248	9879	10	5C
0005432202952	9879	11	5A
0005435661885	9879	12	5H
0005435372260	9879	13	11A
0005432823421	9879	14	5K
0005435372236	9879	15	11D
0005435661887	9879	16	11C
0005435372227	9879	17	11F
0005435372232	9879	18	11E
0005435372233	9879	19	12A
0005432202950	9879	20	12E
0005435372259	9879	21	12K
0005435372257	9879	22	12H
0005435372250	9879	23	14A
0005435735069	9879	24	14E
0005435372253	9879	25	14C
0005435372282	9879	26	15C
0005435372243	9879	27	14K
0005435372246	9879	28	15D
0005435372271	9879	29	16A
0005435661889	9879	30	16H
0005435372230	9879	31	17C
0005435735067	9879	32	16K
0005435386472	9879	33	17D
0005435372237	9879	34	18C
0005435372272	9879	35	19H
0005435372228	9879	36	20G
0005435372291	9879	37	21F
0005435299700	9879	38	21J
0005435302124	9879	39	23D
0005435372267	9879	40	24D
0005435372273	9879	41	25C
0005435372290	9879	42	25B
0005435386471	9879	43	26D
0005435299702	9879	44	26F
0005435372266	9879	45	26K
0005435372255	9879	46	26H
0005435386468	9879	47	27B
0005435372264	9879	48	27D
0005432202956	9879	49	28G
0005435372226	9879	50	28F
0005435386467	9879	51	28H
0005435372241	9879	52	29A
0005435299703	9879	53	29D
0005435179383	9879	54	29E
0005435299701	9879	55	29H
0005435302128	9879	56	29G
0005435372276	9879	57	30A
0005435372292	9879	58	29K
0005435735066	9879	59	30D
0005435661888	9879	60	31C
0005435372240	9879	61	31H
0005435302129	9879	62	32A
0005435735065	9879	63	31K
0005435372247	9879	64	32H
0005435372269	9879	65	32G
0005435386470	9879	66	32F
0005435372289	9879	67	33E
0005435179384	9879	68	34G
0005435302125	9879	69	35H
0005435302126	9879	70	35G
0005435372277	9879	71	35K
0005435372284	9879	72	36F
0005435372268	9879	73	37B
0005435372231	9879	74	37D
0005435372252	9879	75	37G
0005435372286	9879	76	38A
0005435372274	9879	77	38H
0005435735068	9879	78	39C
0005435386466	9879	79	39E
0005435372251	9879	80	39D
0005435372238	9879	81	39K
0005435372254	9879	82	40H
0005435372258	9879	83	40K
0005435372235	9879	84	41D
0005435372263	9879	85	41C
0005435372287	9879	86	41J
0005435372279	9879	87	41G
0005432823420	9879	88	41K
0005432823419	9879	89	42G
0005435372275	9879	90	42J
0005435372262	9879	91	42H
0005435372245	9879	92	43J
0005435372242	9879	93	44C
0005435372288	9879	94	44G
0005435372249	9879	95	44J
0005435372239	9879	96	44H
0005435372285	9879	97	44K
0005435372234	9879	98	45D
0005435372283	9879	99	45C
0005435386465	9879	100	45F
0005432202954	9879	101	45J
0005435372261	9879	102	46C
0005432202951	9879	103	46E
0005435372281	9879	104	46H
0005435372278	9879	105	47G
0005432202949	9879	106	48D
0005435661886	9879	107	49A
0005435372229	9879	108	49F
0005435386469	9879	109	49E
0005435302127	9879	110	51E
0005435082662	7020	1	1A
0005435790262	7020	2	1B
0005435082663	7020	3	1C
0005435790263	7020	4	4B
0005435082667	7020	5	6A
0005435082666	7020	6	6B
0005435082669	7020	7	19B
0005435082664	7020	8	20A
0005435790260	7020	9	20B
0005435082665	7020	10	20D
0005435082668	7020	11	22A
0005435790261	7020	12	22C
0005434755807	9553	1	1A
0005434755822	9553	2	1F
0005434755806	9553	3	2D
0005434755793	9553	4	3C
0005434755814	9553	5	4A
0005434755809	9553	6	4D
0005434755785	9553	7	5A
0005434755820	9553	8	5C
0005434755801	9553	9	5D
0005434755796	9553	10	6F
0005434755798	9553	11	7A
0005434755788	9553	12	7D
0005434755783	9553	13	7E
0005434755790	9553	14	8A
0005434755808	9553	15	8E
0005434755819	9553	16	9A
0005434755802	9553	17	9D
0005434755810	9553	18	9E
0005434755792	9553	19	10A
0005434755812	9553	20	10D
0005434755797	9553	21	10F
0005434755804	9553	22	12D
0005434755782	9553	23	12E
0005434755818	9553	24	13C
0005434755800	9553	25	13D
0005434755795	9553	26	13F
0005434755815	9553	27	14C
0005434755786	9553	28	14D
0005434755823	9553	29	14F
0005434755803	9553	30	15A
0005434755787	9553	31	15C
0005434755794	9553	32	15F
0005434755811	9553	33	16C
0005434755805	9553	34	16E
0005434755813	9553	35	16F
0005434755791	9553	36	17A
0005434755789	9553	37	18C
0005434755817	9553	38	19C
0005434755784	9553	39	19D
0005434755816	9553	40	20A
0005434755821	9553	41	20D
0005434755799	9553	42	20F
0005434213748	28608	1	1A
0005434213766	28608	2	1D
0005434213771	28608	3	2A
0005434213770	28608	4	2C
0005434213764	28608	5	2D
0005434213793	28608	6	2F
0005434213760	28608	7	3A
0005434213779	28608	8	4A
0005434213787	28608	9	4E
0005434213789	28608	10	5C
0005434213746	28608	11	5E
0005434213780	28608	12	5F
0005434213752	28608	13	6A
0005434213749	28608	14	6E
0005434213753	28608	15	6F
0005434213761	28608	16	7C
0005434213782	28608	17	7D
0005434213758	28608	18	7E
0005434213776	28608	19	7F
0005434213788	28608	20	8A
0005434213763	28608	21	8C
0005434213768	28608	22	8D
0005434213755	28608	23	9D
0005434213769	28608	24	10A
0005434213765	28608	25	10D
0005434213754	28608	26	10F
0005434213792	28608	27	11A
0005434213791	28608	28	11C
0005434213756	28608	29	12F
0005434213762	28608	30	13A
0005434213775	28608	31	13C
0005434213790	28608	32	13F
0005434213747	28608	33	14A
0005434213785	28608	34	14D
0005434213777	28608	35	14E
0005434213773	28608	36	14F
0005434213759	28608	37	16A
0005434213784	28608	38	16D
0005434213767	28608	39	17D
0005434213750	28608	40	18C
0005434213772	28608	41	18D
0005434213783	28608	42	18E
0005434213781	28608	43	18F
0005434213786	28608	44	19A
0005434213774	28608	45	19C
0005434213751	28608	46	19F
0005434213757	28608	47	20D
0005434213778	28608	48	20E
0005435100076	10805	1	5B
0005435100077	10805	2	6C
0005435100075	10805	3	20B
0005434760160	31808	1	3C
0005434760158	31808	2	20C
0005434760159	31808	3	21D
0005434638906	2010	1	1C
0005434638914	2010	2	2A
0005434638920	2010	3	2C
0005434638921	2010	4	3A
0005434638911	2010	5	3B
0005434638903	2010	6	4A
0005434638918	2010	7	5A
0005434638905	2010	8	5B
0005434638904	2010	9	5C
0005434638919	2010	10	5D
0005432290587	2010	11	6A
0005434638915	2010	12	6B
0005434638908	2010	13	6C
0005434638913	2010	14	6D
0005434638925	2010	15	7B
0005434638916	2010	16	7D
0005434638924	2010	17	18A
0005432290585	2010	18	18C
0005434638907	2010	19	18D
0005434638926	2010	20	19A
0005434638927	2010	21	19B
0005434638923	2010	22	19C
0005434638917	2010	23	20A
0005434638909	2010	24	20B
0005434638910	2010	25	20C
0005434638912	2010	26	22A
0005432290586	2010	27	22B
0005434638922	2010	28	22C
0005433202131	23246	1	1A
0005433202127	23246	2	2D
0005433202118	23246	3	3B
0005433202120	23246	4	4A
0005433202125	23246	5	5B
0005433202117	23246	6	6A
0005433202119	23246	7	6C
0005433202132	23246	8	6D
0005433202130	23246	9	7C
0005433202129	23246	10	7D
0005433202123	23246	11	18A
0005433202128	23246	12	20A
0005433202121	23246	13	20B
0005433202126	23246	14	20D
0005433202124	23246	15	21A
0005433202122	23246	16	22B
0005434600404	6093	1	1C
0005433531235	6093	2	1D
0005434600384	6093	3	2A
0005432111232	6093	4	1F
0005434600388	6093	5	3A
0005433533250	6093	6	3C
0005434600382	6093	7	4C
0005434600405	6093	8	5A
0005434600395	6093	9	5C
0005432111231	6093	10	5D
0005434600406	6093	11	6A
0005434600389	6093	12	6D
0005434600402	6093	13	6E
0005434600400	6093	14	7C
0005434600407	6093	15	7D
0005434600385	6093	16	8A
0005434600394	6093	17	8C
0005433531234	6093	18	8D
0005433531236	6093	19	8E
0005434600408	6093	20	9C
0005434600409	6093	21	9D
0005434600397	6093	22	9F
0005434600403	6093	23	10A
0005434600386	6093	24	10E
0005434600392	6093	25	10F
0005434600390	6093	26	13C
0005434600391	6093	27	13D
0005434600401	6093	28	13F
0005434600387	6093	29	14E
0005433533251	6093	30	14F
0005434600399	6093	31	15C
0005432111233	6093	32	16E
0005434600398	6093	33	17E
0005434600383	6093	34	17F
0005433533249	6093	35	18C
0005434600396	6093	36	18F
0005434600393	6093	37	19C
0005433533248	6093	38	19D
0005433533252	6093	39	19E
0005435326533	18572	1	1C
0005435326535	18572	2	3D
0005435326536	18572	3	5A
0005435326532	18572	4	5E
0005435326525	18572	5	6D
0005435326529	18572	6	10A
0005435326527	18572	7	10D
0005435326531	18572	8	10F
0005435326538	18572	9	11D
0005435326530	18572	10	14F
0005435326537	18572	11	16C
0005435326534	18572	12	17D
0005435326528	18572	13	18D
0005435326526	18572	14	19D
0005434550356	10571	1	1A
0005434550347	10571	2	1C
0005434550327	10571	3	1D
0005434550335	10571	4	1F
0005434550343	10571	5	2A
0005434558145	10571	6	2C
0005434558142	10571	7	2F
0005434550338	10571	8	3A
0005434550340	10571	9	3C
0005434550329	10571	10	3D
0005434550362	10571	11	3F
0005434550367	10571	12	4C
0005434550366	10571	13	4D
0005434550360	10571	14	4E
0005434550316	10571	15	5A
0005434550336	10571	16	5C
0005434550326	10571	17	5D
0005434550318	10571	18	5F
0005434550322	10571	19	6A
0005434550337	10571	20	6D
0005434550333	10571	21	6F
0005434550353	10571	22	7C
0005434550321	10571	23	7E
0005434558141	10571	24	7F
0005434550361	10571	25	8A
0005434550345	10571	26	8C
0005434550352	10571	27	8D
0005434554028	10571	28	8E
0005434550325	10571	29	8F
0005434550349	10571	30	9A
0005434550359	10571	31	9D
0005434550357	10571	32	9E
0005434550315	10571	33	10A
0005434550323	10571	34	10C
0005434550313	10571	35	10E
0005434550351	10571	36	10F
0005434550320	10571	37	11A
0005434550339	10571	38	11C
0005434550328	10571	39	11D
0005434550324	10571	40	11F
0005434550358	10571	41	12A
0005434558139	10571	42	12C
0005434550312	10571	43	12D
0005434550341	10571	44	12E
0005434550348	10571	45	13A
0005434550334	10571	46	13C
0005434550368	10571	47	13D
0005434550344	10571	48	13E
0005434550355	10571	49	13F
0005434558147	10571	50	14A
0005434550330	10571	51	14C
0005434550317	10571	52	14E
0005434558146	10571	53	14F
0005434558143	10571	54	15A
0005434550331	10571	55	15C
0005434550354	10571	56	15D
0005434550319	10571	57	15E
0005434550346	10571	58	16E
0005434550342	10571	59	17A
0005434558148	10571	60	17C
0005434558144	10571	61	17F
0005434550314	10571	62	18A
0005434550365	10571	63	18E
0005434550363	10571	64	18F
0005434550364	10571	65	19D
0005434554029	10571	66	19E
0005434550350	10571	67	20A
0005434550332	10571	68	20E
0005434558140	10571	69	20F
0005433180710	27775	1	1A
0005433180703	27775	2	2F
0005433180719	27775	3	4A
0005433180723	27775	4	7A
0005433180701	27775	5	7F
0005433180720	27775	6	8A
0005433180709	27775	7	8D
0005433180705	27775	8	9D
0005433180716	27775	9	9E
0005433180702	27775	10	10D
0005433180718	27775	11	10F
0005433180724	27775	12	11C
0005433180712	27775	13	12A
0005433180714	27775	14	12D
0005433180722	27775	15	12E
0005433180708	27775	16	12F
0005433180707	27775	17	15F
0005433180704	27775	18	17C
0005433180713	27775	19	17F
0005433180711	27775	20	18A
0005433180706	27775	21	18D
0005433180715	27775	22	18E
0005433180721	27775	23	19D
0005433180725	27775	24	19E
0005433180717	27775	25	20D
0005433459152	6161	1	1A
0005433459155	6161	2	2B
0005433459153	6161	3	5A
0005433459154	6161	4	6A
0005435254434	19290	1	4A
0005435254435	19290	2	5A
0005435254436	19290	3	6B
0005435661883	6723	1	1C
0005435681477	6723	2	1D
0005435719551	6723	3	1F
0005435661884	6723	4	2A
0005435681487	6723	5	2F
0005435681475	6723	6	3A
0005435681498	6723	7	3C
0005435681489	6723	8	4D
0005435681491	6723	9	5A
0005435681476	6723	10	5C
0005435681474	6723	11	5D
0005435681501	6723	12	5E
0005435681492	6723	13	6A
0005435681507	6723	14	6C
0005435681468	6723	15	6D
0005435681480	6723	16	6E
0005435681481	6723	17	6F
0005435681470	6723	18	7C
0005435681467	6723	19	7E
0005435681473	6723	20	8F
0005435681485	6723	21	9A
0005432136093	6723	22	10A
0005435681482	6723	23	10D
0005435630918	6723	24	10E
0005435681504	6723	25	10F
0005435217677	6723	26	11A
0005435681494	6723	27	11C
0005435681506	6723	28	11D
0005435719550	6723	29	11E
0005435681493	6723	30	11F
0005435681497	6723	31	12C
0005435681479	6723	32	12D
0005435681505	6723	33	12F
0005435681486	6723	34	13E
0005435681469	6723	35	13F
0005435681484	6723	36	14A
0005435681483	6723	37	14F
0005435681471	6723	38	15A
0005432136091	6723	39	15C
0005435681503	6723	40	15D
0005432136092	6723	41	15F
0005435681488	6723	42	16A
0005435681500	6723	43	16D
0005435681502	6723	44	16E
0005435661882	6723	45	16F
0005435681496	6723	46	17E
0005435630917	6723	47	18D
0005435681472	6723	48	18F
0005435681478	6723	49	19A
0005435681490	6723	50	19C
0005432136090	6723	51	19E
0005435681495	6723	52	20D
0005435681499	6723	53	20F
0005435437599	24618	1	2D
0005435437613	24618	2	3F
0005435437601	24618	3	5A
0005432305711	24618	4	5C
0005435437605	24618	5	5E
0005435437615	24618	6	6E
0005432533247	24618	7	6F
0005434828654	24618	8	8E
0005435437617	24618	9	9F
0005435437616	24618	10	10D
0005435437619	24618	11	11C
0005435437603	24618	12	12E
0005435437600	24618	13	13D
0005435437606	24618	14	13E
0005432533248	24618	15	13F
0005432305709	24618	16	14A
0005435437604	24618	17	14D
0005435437602	24618	18	15A
0005435437609	24618	19	15C
0005435437610	24618	20	15D
0005435437612	24618	21	15E
0005435437618	24618	22	16A
0005435437597	24618	23	17A
0005435437614	24618	24	17C
0005435437607	24618	25	17E
0005435437598	24618	26	17F
0005434828655	24618	27	18C
0005435437608	24618	28	18D
0005435437611	24618	29	18F
0005432305710	24618	30	20C
0005435125693	11538	1	1C
0005435125725	11538	2	1D
0005435125691	11538	3	1F
0005435125727	11538	4	2A
0005435125719	11538	5	2D
0005435125701	11538	6	3D
0005435125709	11538	7	3F
0005435125712	11538	8	4E
0005435125716	11538	9	5A
0005435125695	11538	10	6E
0005435125707	11538	11	6F
0005435125706	11538	12	7D
0005435125696	11538	13	7F
0005435125692	11538	14	8A
0005435125705	11538	15	8C
0005435105930	11538	16	8E
0005435125721	11538	17	9F
0005435125689	11538	18	10A
0005435125704	11538	19	10E
0005435125711	11538	20	11A
0005435125723	11538	21	11D
0005435125714	11538	22	11E
0005435125697	11538	23	12E
0005435125690	11538	24	13C
0005435125698	11538	25	13D
0005435125700	11538	26	13E
0005435125726	11538	27	13F
0005435125718	11538	28	14C
0005435125713	11538	29	14D
0005435125729	11538	30	14E
0005435105931	11538	31	15C
0005435125724	11538	32	15D
0005435125694	11538	33	15F
0005435125710	11538	34	17F
0005435125715	11538	35	18A
0005435125708	11538	36	18D
0005435125703	11538	37	18E
0005435125717	11538	38	19A
0005435125702	11538	39	19D
0005435125699	11538	40	19F
0005435125728	11538	41	20A
0005435125720	11538	42	20C
0005435125722	11538	43	20D
0005435558047	31848	1	6D
0005433397283	13558	1	1A
0005433397286	13558	2	1C
0005433397321	13558	3	2A
0005433397295	13558	4	2C
0005433397318	13558	5	2F
0005433397311	13558	6	3D
0005433397327	13558	7	3F
0005433397307	13558	8	4C
0005433397282	13558	9	5C
0005433397290	13558	10	5E
0005433397287	13558	11	6A
0005433397314	13558	12	6E
0005433397291	13558	13	6F
0005433397324	13558	14	7D
0005433397278	13558	15	7E
0005433397296	13558	16	7F
0005433397297	13558	17	8C
0005433397293	13558	18	9A
0005433397294	13558	19	9C
0005433397306	13558	20	9D
0005433397325	13558	21	10A
0005433397320	13558	22	10C
0005433397284	13558	23	10E
0005433397281	13558	24	10F
0005433397292	13558	25	11F
0005433397298	13558	26	12A
0005433397315	13558	27	12C
0005433397289	13558	28	12D
0005433397317	13558	29	12E
0005433397288	13558	30	12F
0005433397305	13558	31	13A
0005433397303	13558	32	13F
0005433397299	13558	33	14D
0005433397323	13558	34	14E
0005433397300	13558	35	15C
0005433397304	13558	36	15F
0005433397302	13558	37	16A
0005433397308	13558	38	16D
0005433397285	13558	39	17A
0005433397326	13558	40	17D
0005433397313	13558	41	17E
0005433397319	13558	42	17F
0005433397316	13558	43	18C
0005433397312	13558	44	18E
0005433397309	13558	45	19A
0005433397322	13558	46	19C
0005433397279	13558	47	19D
0005433397301	13558	48	20C
0005433397280	13558	49	20D
0005433397310	13558	50	20F
0005435732132	19385	1	1D
0005435732147	19385	2	1F
0005432297237	19385	3	2D
0005435732148	19385	4	3C
0005435732135	19385	5	4A
0005432297236	19385	6	4C
0005435732131	19385	7	5E
0005435732138	19385	8	6A
0005433397219	19385	9	6C
0005435732149	19385	10	6D
0005435732142	19385	11	6F
0005435732134	19385	12	7D
0005432297235	19385	13	7E
0005435732151	19385	14	7F
0005435732139	19385	15	8A
0005435732144	19385	16	9A
0005435732141	19385	17	10A
0005435732129	19385	18	10F
0005435732136	19385	19	11A
0005435732133	19385	20	13D
0005435732140	19385	21	15C
0005435732146	19385	22	15D
0005435732145	19385	23	17A
0005435732137	19385	24	19A
0005435732130	19385	25	19C
0005435732150	19385	26	20A
0005435732143	19385	27	20E
0005435925084	13144	1	1D
0005435925094	13144	2	2C
0005435925093	13144	3	2D
0005435925087	13144	4	4A
0005435925095	13144	5	5A
0005435925090	13144	6	5F
0005435925092	13144	7	6A
0005435925085	13144	8	6C
0005435925081	13144	9	8C
0005435925079	13144	10	9E
0005435925080	13144	11	10C
0005435925089	13144	12	13F
0005435925088	13144	13	15E
0005435925091	13144	14	16C
0005435925078	13144	15	16D
0005435925082	13144	16	17D
0005435925086	13144	17	17F
0005435925083	13144	18	20E
0005435068254	15500	1	1A
0005435068256	15500	2	1C
0005435068219	15500	3	1F
0005435068248	15500	4	2C
0005435068262	15500	5	2F
0005435068250	15500	6	3A
0005435068252	15500	7	3C
0005435068236	15500	8	3F
0005435068243	15500	9	4E
0005435068230	15500	10	5A
0005435068238	15500	11	5D
0005435068220	15500	12	5E
0005435068213	15500	13	6A
0005435068215	15500	14	6C
0005435068235	15500	15	6D
0005435068218	15500	16	6E
0005435068263	15500	17	7A
0005435068245	15500	18	7C
0005435068260	15500	19	7F
0005435068224	15500	20	8A
0005435068253	15500	21	8F
0005435068211	15500	22	9A
0005435068223	15500	23	9C
0005435068229	15500	24	9E
0005435068258	15500	25	9F
0005435068232	15500	26	10A
0005435068246	15500	27	10D
0005435068234	15500	28	10C
0005435068216	15500	29	10E
0005435068261	15500	30	10F
0005435068217	15500	31	11A
0005435068242	15500	32	11C
0005435068228	15500	33	11D
0005435068237	15500	34	12A
0005435068247	15500	35	12E
0005435068226	15500	36	13A
0005435068249	15500	37	13C
0005435068212	15500	38	13D
0005435068222	15500	39	13E
0005435068221	15500	40	14A
0005435068241	15500	41	14D
0005435068255	15500	42	15F
0005435068233	15500	43	16E
0005435068251	15500	44	16F
0005435068227	15500	45	17A
0005435068244	15500	46	17C
0005435068225	15500	47	17E
0005435068257	15500	48	18A
0005435068239	15500	49	18D
0005435068214	15500	50	18E
0005435068240	15500	51	18F
0005435068231	15500	52	19E
0005435068259	15500	53	19F
0005433407490	29484	1	2C
0005433407485	29484	2	2D
0005433407487	29484	3	4C
0005433407489	29484	4	6B
0005433407488	29484	5	7B
0005433407482	29484	6	19C
0005433407483	29484	7	19D
0005433407484	29484	8	20C
0005433407486	29484	9	22B
0005433407491	29484	10	22C
0005434213794	10710	1	1A
0005434213800	10710	2	1C
0005434213823	10710	3	2D
0005434213818	10710	4	2F
0005434213810	10710	5	3D
0005434213837	10710	6	3F
0005434213832	10710	7	4A
0005434213820	10710	8	4C
0005434213807	10710	9	4D
0005434213827	10710	10	4E
0005434213808	10710	11	4F
0005434213840	10710	12	5D
0005434213824	10710	13	6E
0005434213825	10710	14	6F
0005434213809	10710	15	7E
0005434213828	10710	16	8A
0005434213816	10710	17	8F
0005434213799	10710	18	9D
0005434213813	10710	19	9E
0005434213797	10710	20	10C
0005434213836	10710	21	11A
0005434213796	10710	22	11F
0005434213798	10710	23	12C
0005434213826	10710	24	13A
0005434213805	10710	25	13C
0005434213822	10710	26	13E
0005434213804	10710	27	13F
0005434213801	10710	28	14A
0005434213819	10710	29	14C
0005434213806	10710	30	14F
0005434213835	10710	31	15A
0005434213795	10710	32	15C
0005434213803	10710	33	15E
0005434213812	10710	34	16C
0005434213821	10710	35	16D
0005434213830	10710	36	16F
0005434213833	10710	37	17F
0005434213834	10710	38	18A
0005434213811	10710	39	18C
0005434213802	10710	40	18D
0005434213829	10710	41	18E
0005434213831	10710	42	18F
0005434213838	10710	43	19A
0005434213817	10710	44	19D
0005434213814	10710	45	19E
0005434213815	10710	46	20C
0005434213839	10710	47	20E
0005434755739	28655	1	1A
0005434755754	28655	2	1C
0005434755737	28655	3	2A
0005434755738	28655	4	2D
0005434755760	28655	5	2F
0005434755742	28655	6	3A
0005434755746	28655	7	3D
0005434755743	28655	8	3F
0005434755774	28655	9	4A
0005434755756	28655	10	4C
0005434755773	28655	11	4D
0005434755775	28655	12	4F
0005434755740	28655	13	5C
0005434755762	28655	14	6D
0005434755748	28655	15	6E
0005434755781	28655	16	7A
0005434755736	28655	17	7C
0005434755758	28655	18	7E
0005434755749	28655	19	8A
0005434755770	28655	20	8D
0005434755751	28655	21	8E
0005434755772	28655	22	9A
0005434755764	28655	23	9C
0005434755778	28655	24	9E
0005434755769	28655	25	9F
0005434755761	28655	26	10D
0005434755767	28655	27	10F
0005434755757	28655	28	11A
0005434755763	28655	29	11E
0005434755755	28655	30	12E
0005434755777	28655	31	12F
0005434755753	28655	32	13E
0005434755765	28655	33	14E
0005434755780	28655	34	16E
0005434755750	28655	35	17A
0005434755759	28655	36	17D
0005434755752	28655	37	17E
0005434755747	28655	38	17F
0005434755741	28655	39	18E
0005434755771	28655	40	19A
0005434755779	28655	41	19D
0005434755745	28655	42	19F
0005434755766	28655	43	20C
0005434755744	28655	44	20D
0005434755768	28655	45	20E
0005434755776	28655	46	20F
0005435038748	5431	1	1A
0005435038781	5431	2	1C
0005435038762	5431	3	1F
0005435038774	5431	4	2C
0005435038753	5431	5	2D
0005435038742	5431	6	3A
0005435038780	5431	7	2F
0005435038761	5431	8	3C
0005435038771	5431	9	3F
0005435038797	5431	10	4B
0005435006659	5431	11	4C
0005435038741	5431	12	4E
0005435038788	5431	13	5A
0005435006669	5431	14	4F
0005435006655	5431	15	5B
0005435038783	5431	16	5D
0005435038765	5431	17	5E
0005435038752	5431	18	6A
0005435042825	5431	19	5F
0005435038793	5431	20	6C
0005435006667	5431	21	6B
0005435038764	5431	22	6D
0005435038801	5431	23	6E
0005435038767	5431	24	6F
0005435038776	5431	25	7B
0005435038800	5431	26	7D
0005435006656	5431	27	8A
0005435038751	5431	28	7F
0005435006649	5431	29	8B
0005435038747	5431	30	8D
0005435006650	5431	31	8E
0005435038766	5431	32	9A
0005435038775	5431	33	8F
0005435038778	5431	34	9B
0005432125339	5431	35	9D
0005435038740	5431	36	9C
0005435038779	5431	37	9E
0005435038744	5431	38	9F
0005435038789	5431	39	10B
0005435038757	5431	40	10E
0005435038784	5431	41	11A
0005435038773	5431	42	11C
0005435006648	5431	43	11B
0005435038777	5431	44	11D
0005435038770	5431	45	11F
0005435038772	5431	46	11E
0005435038768	5431	47	12A
0005435038749	5431	48	12B
0005432125334	5431	49	12E
0005435038760	5431	50	13A
0005435006663	5431	51	12F
0005435038791	5431	52	13D
0005435038787	5431	53	13C
0005435006654	5431	54	13E
0005435038759	5431	55	13F
0005435038750	5431	56	14B
0005435006671	5431	57	14A
0005435006657	5431	58	14C
0005435038799	5431	59	14D
0005435006660	5431	60	14E
0005435038796	5431	61	14F
0005435038794	5431	62	15B
0005432125340	5431	63	15A
0005435038755	5431	64	15D
0005432125335	5431	65	15C
0005435006666	5431	66	15E
0005435006665	5431	67	16A
0005435038745	5431	68	15F
0005435038769	5431	69	16E
0005435038756	5431	70	16F
0005435006658	5431	71	17A
0005435038754	5431	72	17B
0005435043273	5431	73	17C
0005432125338	5431	74	17E
0005435038803	5431	75	18A
0005435006662	5431	76	18E
0005435006647	5431	77	18D
0005435006668	5431	78	18F
0005435038739	5431	79	19A
0005435006664	5431	80	19B
0005435043275	5431	81	19C
0005435038790	5431	82	19D
0005435006652	5431	83	19F
0005435006653	5431	84	20A
0005435006670	5431	85	20C
0005432125337	5431	86	20D
0005435006661	5431	87	21A
0005432125336	5431	88	21B
0005435038785	5431	89	21D
0005435038798	5431	90	21C
0005435043274	5431	91	21E
0005435038786	5431	92	21F
0005435038792	5431	93	22B
0005435038743	5431	94	22D
0005435038782	5431	95	22C
0005435038795	5431	96	22E
0005435038758	5431	97	22F
0005435038763	5431	98	23B
0005435038804	5431	99	23A
0005435038746	5431	100	23C
0005435006651	5431	101	23D
0005435038802	5431	102	23E
0005435042824	5431	103	23F
0005432304338	12991	1	2D
0005434229028	12991	2	3A
0005434229034	12991	3	5B
0005434229029	12991	4	5A
0005434229021	12991	5	6C
0005434229027	12991	6	10B
0005434229014	12991	7	10E
0005434229026	12991	8	11D
0005434229012	12991	9	12A
0005434229020	12991	10	12B
0005434229022	12991	11	12C
0005434229016	12991	12	12E
0005434229023	12991	13	14A
0005434229017	12991	14	14C
0005434229031	12991	15	16A
0005434229013	12991	16	16C
0005434229024	12991	17	17B
0005434229018	12991	18	17C
0005434229030	12991	19	18B
0005434229025	12991	20	19C
0005434229033	12991	21	21D
0005434229015	12991	22	22B
0005434229032	12991	23	22A
0005434229019	12991	24	22E
0005432304339	12991	25	23A
0005434426129	14871	1	1A
0005434426114	14871	2	1C
0005434411705	14871	3	2C
0005434426117	14871	4	3F
0005434426140	14871	5	4E
0005434411706	14871	6	5C
0005432188556	14871	7	5E
0005434426128	14871	8	6C
0005434426144	14871	9	6D
0005434426134	14871	10	6E
0005434426142	14871	11	6F
0005434426136	14871	12	7C
0005434426139	14871	13	7D
0005434411707	14871	14	7E
0005432188555	14871	15	8A
0005434426141	14871	16	8C
0005434426132	14871	17	8E
0005434426131	14871	18	9D
0005434426137	14871	19	9E
0005434426135	14871	20	10C
0005434426145	14871	21	10D
0005434426115	14871	22	10E
0005434426120	14871	23	11C
0005434426122	14871	24	12C
0005434426121	14871	25	12D
0005434426124	14871	26	12E
0005434426123	14871	27	12F
0005434426143	14871	28	13A
0005434426116	14871	29	14A
0005434411708	14871	30	14C
0005434426130	14871	31	15D
0005434411709	14871	32	16A
0005434426133	14871	33	16D
0005434426127	14871	34	18A
0005434426118	14871	35	18F
0005434426126	14871	36	19A
0005434426119	14871	37	19C
0005434426125	14871	38	19D
0005432188554	14871	39	19F
0005434426138	14871	40	20C
0005432059474	20205	1	2D
0005435902432	20205	2	3C
0005435902422	20205	3	4D
0005435902431	20205	4	4F
0005432059475	20205	5	6A
0005435902436	20205	6	6F
0005435902425	20205	7	7C
0005435902435	20205	8	8C
0005435902421	20205	9	8D
0005435554115	20205	10	11A
0005435902430	20205	11	11E
0005435902427	20205	12	12C
0005435554114	20205	13	13C
0005432059473	20205	14	13E
0005435902428	20205	15	13F
0005435902433	20205	16	15A
0005435902424	20205	17	15C
0005435902434	20205	18	15E
0005435554113	20205	19	17A
0005435554117	20205	20	17F
0005435902437	20205	21	18C
0005435902426	20205	22	19F
0005435554116	20205	23	20A
0005435902429	20205	24	20D
0005435902423	20205	25	20E
0005432462483	28016	1	5D
0005432462480	28016	2	12F
0005432462484	28016	3	16D
0005432462478	28016	4	19A
0005432462479	28016	5	19B
0005432462481	28016	6	21A
0005432462482	28016	7	22D
0005435981551	26526	1	1A
0005435981592	26526	2	1C
0005435981589	26526	3	1F
0005432300170	26526	4	2A
0005435981549	26526	5	2C
0005432300169	26526	6	2D
0005435981557	26526	7	3C
0005435981565	26526	8	3D
0005435981574	26526	9	3F
0005435981566	26526	10	4A
0005432300166	26526	11	4C
0005435981573	26526	12	5D
0005435981579	26526	13	5E
0005435981561	26526	14	5F
0005435981555	26526	15	6C
0005435981569	26526	16	6D
0005435981582	26526	17	6E
0005435981577	26526	18	8D
0005435981567	26526	19	8F
0005435981560	26526	20	8E
0005435981585	26526	21	9E
0005435981559	26526	22	10A
0005432300171	26526	23	10C
0005435981571	26526	24	11A
0005435981548	26526	25	11C
0005435981562	26526	26	12A
0005432300168	26526	27	12D
0005435981576	26526	28	12E
0005435981553	26526	29	13C
0005432300167	26526	30	14A
0005435981581	26526	31	14C
0005435981563	26526	32	14D
0005435981568	26526	33	14E
0005435981554	26526	34	14F
0005435981580	26526	35	15C
0005435981552	26526	36	15D
0005435981591	26526	37	15F
0005435981587	26526	38	16A
0005435981550	26526	39	16D
0005435981572	26526	40	16F
0005435981584	26526	41	17A
0005435981558	26526	42	17C
0005435981590	26526	43	17E
0005435981556	26526	44	17F
0005435981583	26526	45	18C
0005435981575	26526	46	18A
0005435981564	26526	47	18D
0005435981593	26526	48	19A
0005435981588	26526	49	19C
0005435981586	26526	50	19E
0005435981578	26526	51	20C
0005435981570	26526	52	20D
0005433434265	26681	1	2A
0005434269070	26681	2	2C
0005434269073	26681	3	2F
0005433434248	26681	4	3D
0005433434258	26681	5	3C
0005433434244	26681	6	4A
0005433434246	26681	7	4C
0005433434240	26681	8	4D
0005433434238	26681	9	4F
0005432051080	26681	10	5A
0005433434243	26681	11	5C
0005433434239	26681	12	5F
0005434269072	26681	13	6A
0005433434254	26681	14	6E
0005433434260	26681	15	7A
0005432051079	26681	16	9A
0005433434237	26681	17	9E
0005433434247	26681	18	10C
0005433434252	26681	19	12A
0005433434241	26681	20	12D
0005433434242	26681	21	12E
0005433434256	26681	22	12F
0005433434262	26681	23	13E
0005434270176	26681	24	14E
0005433434263	26681	25	15C
0005433434251	26681	26	15E
0005433434264	26681	27	15F
0005433434245	26681	28	16A
0005433434259	26681	29	16C
0005434270175	26681	30	16E
0005433434257	26681	31	16F
0005432051082	26681	32	17A
0005433434249	26681	33	17D
0005434269071	26681	34	18E
0005433434261	26681	35	19E
0005432051081	26681	36	20A
0005433434255	26681	37	20C
0005433434250	26681	38	20D
0005434270174	26681	39	20E
0005433434253	26681	40	20F
0005432583656	3190	1	1B
0005432583646	3190	2	1D
0005432583651	3190	3	2B
0005432583657	3190	4	2D
0005432583645	3190	5	3D
0005432583635	3190	6	4A
0005432583654	3190	7	4B
0005432583641	3190	8	4C
0005432583659	3190	9	4D
0005432583649	3190	10	5B
0005432583655	3190	11	5C
0005432583644	3190	12	6A
0005432216229	3190	13	6B
0005432216228	3190	14	6C
0005432583636	3190	15	7A
0005432583653	3190	16	7B
0005432583638	3190	17	7D
0005432216230	3190	18	18A
0005432583642	3190	19	18B
0005432583643	3190	20	19A
0005432583640	3190	21	19B
0005432583648	3190	22	19C
0005432583639	3190	23	20B
0005432583658	3190	24	20C
0005432583660	3190	25	20D
0005432583652	3190	26	21A
0005432583647	3190	27	22A
0005432583650	3190	28	22B
0005432583637	3190	29	22D
0005432857880	31491	1	1B
0005432857881	31491	2	3C
0005432857875	31491	3	4B
0005432857878	31491	4	4D
0005432857883	31491	5	5B
0005432857882	31491	6	6A
0005432857884	31491	7	6C
0005432857877	31491	8	7C
0005432857874	31491	9	20B
0005432857885	31491	10	21C
0005432857876	31491	11	22A
0005432857886	31491	12	22C
0005432857879	31491	13	23B
0005434943210	899	1	1A
0005434943207	899	2	1D
0005434943211	899	3	1C
0005434943212	899	4	2A
0005434943206	899	5	3A
0005434943209	899	6	5A
0005434943205	899	7	7C
0005434943208	899	8	18C
0005434943204	899	9	23A
0005433255032	16212	1	1B
0005433255034	16212	2	5D
0005433255035	16212	3	6B
0005433255036	16212	4	6C
0005433255033	16212	5	7C
0005435652322	21757	1	1C
0005435652323	21757	2	1F
0005435652319	21757	3	3A
0005435652338	21757	4	3F
0005435652315	21757	5	4A
0005435652330	21757	6	4C
0005435652324	21757	7	4D
0005435652318	21757	8	4F
0005435652320	21757	9	6C
0005435652306	21757	10	6D
0005435652297	21757	11	7C
0005435652316	21757	12	7E
0005435652314	21757	13	8A
0005435652312	21757	14	8D
0005435652317	21757	15	9A
0005435652321	21757	16	9C
0005435652304	21757	17	9D
0005435652336	21757	18	9F
0005435652326	21757	19	10C
0005435652311	21757	20	11A
0005435652325	21757	21	11D
0005435652313	21757	22	11E
0005435652327	21757	23	11F
0005435652299	21757	24	12A
0005435652302	21757	25	12C
0005435652328	21757	26	12D
0005435652305	21757	27	12E
0005435652329	21757	28	13A
0005435652303	21757	29	13C
0005435652310	21757	30	13E
0005435652300	21757	31	14E
0005435652339	21757	32	14F
0005435652334	21757	33	15C
0005435652332	21757	34	15F
0005435652308	21757	35	16A
0005435652331	21757	36	16D
0005435652335	21757	37	17F
0005435652301	21757	38	19A
0005435652307	21757	39	19C
0005435652298	21757	40	19D
0005435652337	21757	41	20C
0005435652333	21757	42	20D
0005435652309	21757	43	20F
0005433784393	9359	1	1H
0005433784400	9359	2	2H
0005433762980	9359	3	3A
0005433804856	9359	4	3G
0005433784396	9359	5	3H
0005433762974	9359	6	4B
0005432665243	9359	7	4F
0005433784372	9359	8	4C
0005433804849	9359	9	5B
0005433804836	9359	10	5H
0005433762979	9359	11	9B
0005432657401	9359	12	9H
0005433762982	9359	13	11A
0005433784379	9359	14	11F
0005433804835	9359	15	11H
0005433784373	9359	16	12B
0005433804854	9359	17	12F
0005433784368	9359	18	12D
0005433762985	9359	19	12G
0005432667422	9359	20	13B
0005433784392	9359	21	13G
0005433804850	9359	22	14A
0005432657400	9359	23	14E
0005433804841	9359	24	14D
0005432666355	9359	25	15A
0005433804832	9359	26	15D
0005433804851	9359	27	15B
0005433804845	9359	28	15G
0005433784369	9359	29	16A
0005433784399	9359	30	16D
0005433804840	9359	31	17A
0005433804837	9359	32	17F
0005433784387	9359	33	17D
0005433784384	9359	34	17G
0005433804831	9359	35	18D
0005433804847	9359	36	18B
0005433804842	9359	37	18E
0005433804855	9359	38	19A
0005433784391	9359	39	19F
0005432665242	9359	40	20A
0005433762983	9359	41	20B
0005433804829	9359	42	20F
0005433762984	9359	43	20H
0005433784367	9359	44	20G
0005433784378	9359	45	21F
0005432666357	9359	46	22D
0005433784377	9359	47	23B
0005433762977	9359	48	23E
0005433784389	9359	49	23G
0005433804846	9359	50	23F
0005433804834	9359	51	24B
0005433784374	9359	52	24E
0005433804857	9359	53	25D
0005433804848	9359	54	25F
0005433784380	9359	55	27A
0005433784397	9359	56	27F
0005433784394	9359	57	28B
0005433762976	9359	58	28D
0005433804833	9359	59	28H
0005433784375	9359	60	28G
0005433784390	9359	61	29A
0005433784370	9359	62	29F
0005433804852	9359	63	29E
0005433784398	9359	64	29G
0005433784382	9359	65	30B
0005433804844	9359	66	30F
0005433784386	9359	67	30E
0005433804838	9359	68	30G
0005432665241	9359	69	31D
0005433762981	9359	70	31F
0005433784376	9359	71	32A
0005433804830	9359	72	31H
0005433762975	9359	73	32D
0005433804843	9359	74	32G
0005433762978	9359	75	33D
0005433784371	9359	76	34E
0005433784381	9359	77	34H
0005432666356	9359	78	35A
0005433804853	9359	79	35F
0005433762973	9359	80	35H
0005433762986	9359	81	36B
0005433784383	9359	82	36G
0005433784385	9359	83	37A
0005433804839	9359	84	37G
0005433784388	9359	85	38D
0005433804858	9359	86	38G
0005433784395	9359	87	38H
0005432667421	9359	88	39E
0005434170838	26218	1	4H
0005434170828	26218	2	5B
0005434170837	26218	3	11G
0005434170831	26218	4	12E
0005434170839	26218	5	12G
0005434270172	26218	6	13F
0005434270173	26218	7	13G
0005434170830	26218	8	14B
0005434170836	26218	9	15F
0005434170832	26218	10	17D
0005434170826	26218	11	17G
0005434170835	26218	12	17H
0005434271278	26218	13	18E
0005434170840	26218	14	20B
0005434170827	26218	15	20E
0005434170829	26218	16	20H
0005434151658	26218	17	22D
0005434151657	26218	18	23F
0005434271279	26218	19	24D
0005434271277	26218	20	27F
0005434170834	26218	21	29D
0005434271280	26218	22	32B
0005434170833	26218	23	33B
0005434151659	26218	24	37A
0005435135592	4934	1	2A
0005435135594	4934	2	4B
0005435135591	4934	3	4C
0005435135593	4934	4	6D
0005435135595	4934	5	19D
0005435929601	33042	1	4B
0005435929600	33042	2	6B
0005435929602	33042	3	21C
0005434983205	9503	1	3A
0005434983207	9503	2	7A
0005434983204	9503	3	18C
0005434983208	9503	4	20A
0005434983206	9503	5	22C
0005434217907	27374	1	1B
0005434217903	27374	2	2D
0005434217906	27374	3	4C
0005434217905	27374	4	5D
0005434217904	27374	5	18A
0005434217902	27374	6	18B
0005433959920	25910	1	1A
0005433959908	25910	2	1C
0005433959940	25910	3	1H
0005433985169	25910	4	1G
0005433959944	25910	5	2B
0005433959925	25910	6	2G
0005433959926	25910	7	2H
0005433985173	25910	8	3A
0005433959904	25910	9	3G
0005433985184	25910	10	4A
0005433985201	25910	11	4G
0005433959922	25910	12	4F
0005433985202	25910	13	5A
0005433985178	25910	14	5F
0005433985171	25910	15	9A
0005433959918	25910	16	11A
0005433985179	25910	17	11D
0005433985209	25910	18	11E
0005433985206	25910	19	11G
0005433959912	25910	20	12A
0005433985183	25910	21	12E
0005433985194	25910	22	13A
0005433959931	25910	23	13D
0005433985207	25910	24	13B
0005433959955	25910	25	13E
0005433985199	25910	26	13F
0005433959935	25910	27	13H
0005433959951	25910	28	14B
0005433959942	25910	29	14A
0005433959919	25910	30	14D
0005433985167	25910	31	14E
0005433959939	25910	32	14G
0005433959927	25910	33	14H
0005433985208	25910	34	16A
0005433959960	25910	35	16D
0005433985211	25910	36	16B
0005433959929	25910	37	16E
0005433959910	25910	38	17D
0005433959946	25910	39	17E
0005433959907	25910	40	17G
0005433959924	25910	41	17H
0005433985168	25910	42	18B
0005433985174	25910	43	18A
0005433985188	25910	44	18D
0005433985192	25910	45	18F
0005433985197	25910	46	18G
0005433985162	25910	47	19E
0005433985166	25910	48	19F
0005433985195	25910	49	19G
0005433985163	25910	50	20A
0005433985190	25910	51	20B
0005433959914	25910	52	20D
0005433985196	25910	53	21G
0005433959913	25910	54	21F
0005433959916	25910	55	22G
0005433985172	25910	56	22F
0005433985177	25910	57	23A
0005433985189	25910	58	22H
0005433959915	25910	59	23B
0005433985182	25910	60	23H
0005433959963	25910	61	24D
0005433985165	25910	62	24F
0005433959906	25910	63	25E
0005433959950	25910	64	27A
0005433959928	25910	65	27D
0005433959936	25910	66	27F
0005433985187	25910	67	27H
0005433959923	25910	68	27G
0005433959945	25910	69	28A
0005433985181	25910	70	28D
0005433985204	25910	71	28B
0005433985205	25910	72	28E
0005433985185	25910	73	28H
0005433959943	25910	74	29B
0005433959957	25910	75	29G
0005433985175	25910	76	29F
0005433985180	25910	77	29H
0005433959962	25910	78	30A
0005433959953	25910	79	30D
0005433985170	25910	80	30G
0005433959917	25910	81	30F
0005433985203	25910	82	32A
0005433985210	25910	83	31H
0005433959905	25910	84	32E
0005433985164	25910	85	32D
0005433959949	25910	86	33A
0005433959958	25910	87	33B
0005433959934	25910	88	33E
0005433959932	25910	89	33G
0005433985198	25910	90	34A
0005433985193	25910	91	34B
0005433959921	25910	92	34F
0005433959948	25910	93	34G
0005433959930	25910	94	34H
0005433959941	25910	95	35G
0005433985186	25910	96	36B
0005433959909	25910	97	36D
0005433959938	25910	98	36F
0005433959911	25910	99	36G
0005433959952	25910	100	37A
0005433959959	25910	101	37E
0005433985200	25910	102	37D
0005433959937	25910	103	37F
0005433959956	25910	104	37H
0005433959954	25910	105	37G
0005433985191	25910	106	38D
0005433985176	25910	107	38B
0005433959933	25910	108	38E
0005433959947	25910	109	39E
0005433959961	25910	110	39F
0005434479942	941	1	1B
0005434479937	941	2	1C
0005434479948	941	3	1D
0005434479936	941	4	2C
0005434479938	941	5	2D
0005434479934	941	6	3B
0005434479926	941	7	3C
0005432269452	941	8	3D
0005434479931	941	9	4D
0005434479946	941	10	5A
0005432269451	941	11	5C
0005432269454	941	12	5D
0005434479949	941	13	6B
0005434479945	941	14	7A
0005434479935	941	15	7B
0005434479939	941	16	7C
0005434479928	941	17	7D
0005434479944	941	18	18A
0005434479932	941	19	18C
0005434479951	941	20	19A
0005434479943	941	21	19C
0005434479947	941	22	20A
0005432269453	941	23	19D
0005434479930	941	24	20B
0005434479929	941	25	20C
0005434479933	941	26	21B
0005434479950	941	27	21D
0005434479927	941	28	22A
0005434479940	941	29	22C
0005434479941	941	30	22D
0005433165701	16576	1	1D
0005433165702	16576	2	2D
0005433165696	16576	3	4B
0005433165697	16576	4	4D
0005433165703	16576	5	5C
0005433165705	16576	6	6A
0005433165708	16576	7	6B
0005433165695	16576	8	7A
0005433165698	16576	9	7D
0005433165706	16576	10	19D
0005433165700	16576	11	20D
0005433165704	16576	12	21B
0005433165699	16576	13	21D
0005433165707	16576	14	23A
0005433872432	3213	1	1C
0005433872435	3213	2	5B
0005433872430	3213	3	7B
0005433872434	3213	4	19C
0005433872431	3213	5	21B
0005433872429	3213	6	22A
0005433872433	3213	7	23A
0005435149801	10349	1	1B
0005435149806	10349	2	1C
0005435142361	10349	3	2B
0005435142357	10349	4	2C
0005435149800	10349	5	2D
0005435142360	10349	6	3C
0005435142350	10349	7	3D
0005435149812	10349	8	4B
0005435149807	10349	9	4C
0005435142356	10349	10	4D
0005435142354	10349	11	5A
0005435142352	10349	12	5B
0005435142359	10349	13	5C
0005435142355	10349	14	5D
0005435149810	10349	15	6A
0005435149803	10349	16	6B
0005435149808	10349	17	18A
0005435142362	10349	18	7D
0005435142351	10349	19	18B
0005435149798	10349	20	18C
0005435149799	10349	21	18D
0005435149809	10349	22	19C
0005435142349	10349	23	20A
0005435149804	10349	24	21B
0005435142358	10349	25	21C
0005435149811	10349	26	21D
0005435142353	10349	27	22B
0005435149805	10349	28	22C
0005435149802	10349	29	22D
0005433289745	21947	1	1B
0005435386472	21947	2	2A
0005435386466	21947	3	2B
0005433289743	21947	4	2D
0005433289744	21947	5	3B
0005433289740	21947	6	3D
0005433289741	21947	7	5C
0005435386471	21947	8	7D
0005435386467	21947	9	18A
0005435386469	21947	10	19A
0005435386468	21947	11	19B
0005433289742	21947	12	21A
0005433289739	21947	13	21D
0005435386465	21947	14	23A
0005435386470	21947	15	23B
0005434573128	11214	1	3C
0005434573121	11214	2	3F
0005434573129	11214	3	4A
0005434573117	11214	4	4C
0005434573125	11214	5	4E
0005434573127	11214	6	5D
0005434573126	11214	7	5F
0005434573116	11214	8	7C
0005434573122	11214	9	7F
0005434573118	11214	10	9A
0005434573124	11214	11	12E
0005434573119	11214	12	14A
0005434573120	11214	13	15E
0005434573123	11214	14	16E
0005432291891	20939	1	1C
0005435501958	20939	2	1D
0005435517625	20939	3	1F
0005435319446	20939	4	2A
0005435501966	20939	5	2D
0005435501955	20939	6	2F
0005435517612	20939	7	3A
0005435319441	20939	8	3D
0005435517608	20939	9	3F
0005435517622	20939	10	4D
0005435501957	20939	11	4E
0005435501964	20939	12	4F
0005435319444	20939	13	5A
0005435501968	20939	14	5C
0005435517624	20939	15	5D
0005435517611	20939	16	5E
0005435501974	20939	17	6A
0005435517617	20939	18	6C
0005435319449	20939	19	6E
0005435517618	20939	20	6F
0005435501962	20939	21	7A
0005435501973	20939	22	7C
0005435501963	20939	23	7D
0005435508178	20939	24	7E
0005435517615	20939	25	8C
0005435508177	20939	26	8D
0005435501972	20939	27	9A
0005435319448	20939	28	9C
0005435501970	20939	29	9D
0005432291892	20939	30	9E
0005435517616	20939	31	10C
0005435501969	20939	32	10D
0005435319445	20939	33	10E
0005435501961	20939	34	10F
0005435517619	20939	35	11A
0005435508182	20939	36	11C
0005435508183	20939	37	11D
0005435517610	20939	38	11E
0005435517626	20939	39	12A
0005435508180	20939	40	12D
0005435508181	20939	41	12E
0005435517627	20939	42	12F
0005435319447	20939	43	13A
0005435508184	20939	44	13C
0005435501953	20939	45	13E
0005435501971	20939	46	14C
0005435508179	20939	47	14D
0005435501956	20939	48	14E
0005435501960	20939	49	15D
0005435501967	20939	50	15F
0005435501959	20939	51	16A
0005435501965	20939	52	16D
0005435517614	20939	53	16E
0005435517609	20939	54	17E
0005435319443	20939	55	17F
0005435517621	20939	56	18A
0005435319442	20939	57	18E
0005435517607	20939	58	18F
0005435517620	20939	59	19A
0005435517623	20939	60	19E
0005435501954	20939	61	20D
0005435517628	20939	62	20E
0005435517613	20939	63	20F
0005432706385	2968	1	1A
0005432706370	2968	2	1D
0005432706383	2968	3	2C
0005432706364	2968	4	2F
0005432706381	2968	5	3D
0005432706369	2968	6	4C
0005432706377	2968	7	4E
0005432706380	2968	8	5C
0005432706367	2968	9	5D
0005432706373	2968	10	6A
0005432706360	2968	11	6D
0005432706368	2968	12	7F
0005432706372	2968	13	8D
0005432706362	2968	14	8E
0005432706366	2968	15	9C
0005432217731	2968	16	10A
0005432706363	2968	17	10D
0005432706365	2968	18	11A
0005432706378	2968	19	11C
0005432706379	2968	20	12C
0005432706374	2968	21	13F
0005432706361	2968	22	14C
0005432706375	2968	23	14F
0005432217732	2968	24	16A
0005432706382	2968	25	18C
0005432706376	2968	26	19A
0005432706384	2968	27	20A
0005432706371	2968	28	20E
0005432692604	30081	1	1A
0005432692613	30081	2	1C
0005432880581	30081	3	1F
0005432692607	30081	4	2A
0005432692614	30081	5	2C
0005432692621	30081	6	2F
0005432880591	30081	7	3A
0005433123588	30081	8	3C
0005432880593	30081	9	3D
0005432692612	30081	10	3F
0005432692608	30081	11	4C
0005433123593	30081	12	4D
0005432880584	30081	13	4E
0005432692598	30081	14	5A
0005433123598	30081	15	5C
0005432692597	30081	16	5E
0005432692616	30081	17	5F
0005432692609	30081	18	6A
0005433123599	30081	19	6D
0005432880594	30081	20	6E
0005433123597	30081	21	6F
0005432880582	30081	22	7A
0005433123603	30081	23	7C
0005433123606	30081	24	7D
0005433123604	30081	25	7E
0005432692602	30081	26	7F
0005433123591	30081	27	8A
0005433123596	30081	28	8D
0005432692615	30081	29	8E
0005432880586	30081	30	8F
0005432692596	30081	31	9A
0005432706344	30081	32	9C
0005432692617	30081	33	9D
0005432692620	30081	34	9F
0005432880587	30081	35	10C
0005433194820	30081	36	10D
0005432692601	30081	37	10E
0005433123592	30081	38	10F
0005433123594	30081	39	11E
0005432692593	30081	40	11F
0005433194823	30081	41	12A
0005432692591	30081	42	12C
0005433123605	30081	43	12D
0005433123602	30081	44	12E
0005432692590	30081	45	12F
0005433123590	30081	46	13D
0005432692605	30081	47	13E
0005432880589	30081	48	13F
0005432692595	30081	49	14A
0005432880595	30081	50	14C
0005432692606	30081	51	14E
0005432692618	30081	52	14F
0005432692592	30081	53	15C
0005432880583	30081	54	15A
0005433123589	30081	55	15D
0005433123608	30081	56	15F
0005432880592	30081	57	16A
0005432692600	30081	58	16C
0005432692603	30081	59	16E
0005433194821	30081	60	16F
0005432692619	30081	61	17A
0005433123595	30081	62	17C
0005433194822	30081	63	17E
0005432880588	30081	64	17F
0005432692594	30081	65	18A
0005433123609	30081	66	18E
0005433123600	30081	67	18F
0005433123601	30081	68	19A
0005433123607	30081	69	19C
0005432692599	30081	70	19D
0005432880585	30081	71	19E
0005432880590	30081	72	19F
0005432692611	30081	73	20A
0005432692610	30081	74	20E
0005433123610	30081	75	20F
0005434979296	23647	1	1B
0005434979283	23647	2	1C
0005434979292	23647	3	2A
0005434979290	23647	4	2B
0005434979308	23647	5	2C
0005434988565	23647	6	2D
0005434979313	23647	7	3A
0005434979297	23647	8	3B
0005434979312	23647	9	3C
0005434979299	23647	10	3D
0005434979311	23647	11	4A
0005434979310	23647	12	4B
0005434979284	23647	13	4C
0005434979295	23647	14	4D
0005434979303	23647	15	5A
0005434988567	23647	16	5B
0005434979286	23647	17	5C
0005434979288	23647	18	5D
0005434979309	23647	19	6A
0005434979285	23647	20	6D
0005434988566	23647	21	7A
0005434988568	23647	22	7C
0005434979287	23647	23	7D
0005434979294	23647	24	18A
0005434979304	23647	25	18B
0005434988570	23647	26	18C
0005434979305	23647	27	18D
0005434979289	23647	28	19B
0005434979307	23647	29	19D
0005434979301	23647	30	20A
0005434979291	23647	31	20B
0005434979306	23647	32	20D
0005434979298	23647	33	21B
0005434979293	23647	34	21D
0005434988569	23647	35	22A
0005434979300	23647	36	22C
0005434979302	23647	37	22D
0005434302388	10280	1	4D
0005434302387	10280	2	6B
0005434302390	10280	3	18A
0005434302386	10280	4	20A
0005434302389	10280	5	22C
0005433113500	19598	1	2D
0005433113501	19598	2	7B
0005435068273	3523	1	1C
0005435068294	3523	2	1F
0005435068309	3523	3	2D
0005435068306	3523	4	2F
0005435068311	3523	5	3C
0005435068299	3523	6	3F
0005435068275	3523	7	4A
0005435068285	3523	8	4C
0005435068292	3523	9	4D
0005435068282	3523	10	4E
0005435068288	3523	11	4F
0005435068307	3523	12	5A
0005435068297	3523	13	5C
0005435068277	3523	14	5D
0005435068316	3523	15	6C
0005435068286	3523	16	6D
0005435718842	3523	17	7D
0005435718838	3523	18	7E
0005435068312	3523	19	7F
0005435068315	3523	20	8A
0005435068317	3523	21	8C
0005435068308	3523	22	8D
0005435068313	3523	23	8E
0005435068272	3523	24	9A
0005435068265	3523	25	9C
0005435068267	3523	26	9D
0005435068290	3523	27	9F
0005435068314	3523	28	10A
0005435068264	3523	29	10C
0005435068291	3523	30	10D
0005435068301	3523	31	10E
0005435068271	3523	32	10F
0005435718839	3523	33	11A
0005435068298	3523	34	12A
0005435068304	3523	35	12C
0005435718844	3523	36	12D
0005435068302	3523	37	12E
0005435068280	3523	38	13A
0005435068279	3523	39	13C
0005435718847	3523	40	13E
0005435718845	3523	41	13F
0005435068287	3523	42	14A
0005435718843	3523	43	14D
0005435068276	3523	44	14F
0005435068274	3523	45	15C
0005435068268	3523	46	15D
0005435068270	3523	47	16A
0005435068296	3523	48	16C
0005435718841	3523	49	16D
0005435068305	3523	50	16E
0005435068293	3523	51	17A
0005435068283	3523	52	17C
0005435068281	3523	53	17D
0005435068278	3523	54	17E
0005435068269	3523	55	18A
0005435068300	3523	56	18C
0005435068284	3523	57	18D
0005435068289	3523	58	18E
0005435718840	3523	59	19D
0005435068295	3523	60	19E
0005435068303	3523	61	19F
0005435718846	3523	62	20C
0005435068266	3523	63	20E
0005435068310	3523	64	20F
0005435925089	15298	1	1A
0005435925079	15298	2	2A
0005435925081	15298	3	2D
0005435925090	15298	4	3A
0005435925085	15298	5	4D
0005435925080	15298	6	4F
0005435925086	15298	7	6D
0005435925082	15298	8	7D
0005435925095	15298	9	8C
0005435939861	15298	10	9C
0005435925088	15298	11	9F
0005435939860	15298	12	11A
0005435939859	15298	13	11D
0005435925094	15298	14	13E
0005435925078	15298	15	14A
0005435925093	15298	16	15C
0005435925083	15298	17	17F
0005435925092	15298	18	18E
0005435925084	15298	19	19C
0005435925091	15298	20	19D
0005435925087	15298	21	20C
0005432660784	18167	1	2A
0005432658558	18167	2	2B
0005432660785	18167	3	4B
0005432660787	18167	4	4A
0005432659673	18167	5	5A
0005432658559	18167	6	5B
0005432659674	18167	7	6A
0005432660786	18167	8	6B
0005432157461	55	1	15E
0005432157463	55	2	24A
0005432157462	55	3	28F
0005432817007	54	1	1D
0005432261189	54	2	1A
0005432817010	54	3	2C
0005432261208	54	4	2A
0005432261219	54	5	3A
0005432261185	54	6	3F
0005432207621	54	7	5C
0005432261217	54	8	5F
0005432817008	54	9	5D
0005432817017	54	10	7F
0005432261193	54	11	8A
0005432817020	54	12	8C
0005432261206	54	13	8B
0005432817022	54	14	8E
0005432817027	54	15	9E
0005432261184	54	16	10B
0005432261209	54	17	10D
0005432261197	54	18	10E
0005432261204	54	19	10F
0005432817014	54	20	11B
0005432817000	54	21	11A
0005432261226	54	22	12C
0005432261214	54	23	12E
0005432817005	54	24	12D
0005432261200	54	25	13A
0005432817016	54	26	12F
0005432261188	54	27	13B
0005432261225	54	28	13F
0005432261205	54	29	14C
0005432261216	54	30	14F
0005432261203	54	31	15B
0005432261194	54	32	15F
0005432817021	54	33	15E
0005432261207	54	34	16C
0005432261202	54	35	16E
0005432817018	54	36	16D
0005432817012	54	37	17A
0005432817013	54	38	17E
0005432207620	54	39	17D
0005432261223	54	40	17F
0005432817024	54	41	18A
0005432261192	54	42	18B
0005432261221	54	43	18C
0005432817011	54	44	18E
0005432261213	54	45	18D
0005432261198	54	46	20B
0005432817015	54	47	20F
0005432817001	54	48	21B
0005432261183	54	49	21A
0005432817025	54	50	21C
0005432207619	54	51	21E
0005432261201	54	52	22A
0005432261220	54	53	22B
0005432261186	54	54	22E
0005432816999	54	55	22D
0005432288934	54	56	23D
0005432817009	54	57	23C
0005432261212	54	58	23E
0005432261190	54	59	24B
0005432288935	54	60	25A
0005432261182	54	61	25B
0005432817002	54	62	25D
0005432817019	54	63	25C
0005432261187	54	64	25F
0005432261211	54	65	26A
0005432261191	54	66	26E
0005432817006	54	67	26D
0005432816998	54	68	27A
0005432261196	54	69	27C
0005432261227	54	70	27D
0005432261199	54	71	28A
0005432261215	54	72	27F
0005432261222	54	73	28C
0005432261218	54	74	28E
0005432817026	54	75	29B
0005432817003	54	76	29E
0005432817004	54	77	30B
0005432288936	54	78	30C
0005432817023	54	79	30D
0005432261181	54	80	30F
0005432261195	54	81	30E
0005432261210	54	82	31D
0005432261224	54	83	31E
0005433101340	7988	1	1A
0005433101302	7988	2	1F
0005432391952	7988	3	1D
0005433101295	7988	4	2A
0005432919536	7988	5	2F
0005433101328	7988	6	3D
0005433101316	7988	7	3F
0005432019858	7988	8	4A
0005433101293	7988	9	4D
0005432919545	7988	10	4C
0005433101345	7988	11	5A
0005432019842	7988	12	5C
0005432019835	7988	13	5D
0005432019844	7988	14	6D
0005433101341	7988	15	7A
0005432019839	7988	16	6F
0005433101317	7988	17	7C
0005432019840	7988	18	7F
0005433101298	7988	19	7D
0005432019846	7988	20	8B
0005432019852	7988	21	8D
0005433101336	7988	22	8C
0005432019834	7988	23	9B
0005432753251	7988	24	9A
0005433101327	7988	25	9C
0005432019855	7988	26	9D
0005432753250	7988	27	9F
0005433101306	7988	28	9E
0005432019847	7988	29	10A
0005433101326	7988	30	10D
0005432019850	7988	31	10C
0005432919538	7988	32	10E
0005433101323	7988	33	10F
0005433101303	7988	34	11C
0005433101335	7988	35	11E
0005432919535	7988	36	12B
0005433101301	7988	37	12C
0005433101333	7988	38	12E
0005432753249	7988	39	13C
0005432019849	7988	40	13B
0005433101325	7988	41	13D
0005433101299	7988	42	13E
0005432019845	7988	43	14A
0005433101300	7988	44	14B
0005432919543	7988	45	14C
0005433101343	7988	46	14E
0005433101292	7988	47	14D
0005432019833	7988	48	15A
0005432019848	7988	49	14F
0005432019856	7988	50	15B
0005432919527	7988	51	15C
0005433101337	7988	52	15D
0005432919528	7988	53	15E
0005433101339	7988	54	16A
0005432677511	7988	55	15F
0005433101321	7988	56	16B
0005433101310	7988	57	16D
0005432019836	7988	58	16E
0005432019843	7988	59	17A
0005433101322	7988	60	17B
0005433101319	7988	61	17E
0005432919534	7988	62	17D
0005433101330	7988	63	17F
0005433101318	7988	64	18B
0005432677514	7988	65	18C
0005432919542	7988	66	18F
0005433101304	7988	67	19C
0005432919541	7988	68	19B
0005432751474	7988	69	19D
0005432919533	7988	70	19E
0005433101338	7988	71	20B
0005433101344	7988	72	20C
0005432019838	7988	73	20D
0005432919531	7988	74	21C
0005433101297	7988	75	21B
0005433101294	7988	76	21D
0005433101320	7988	77	21E
0005432044481	7988	78	22B
0005433101291	7988	79	22C
0005432391953	7988	80	22E
0005433101329	7988	81	22D
0005433101331	7988	82	23A
0005432919544	7988	83	23C
0005432919537	7988	84	23E
0005432753248	7988	85	23F
0005433101315	7988	86	24C
0005432677513	7988	87	24E
0005433101324	7988	88	24D
0005432019859	7988	89	25B
0005433101296	7988	90	25E
0005433101334	7988	91	25F
0005432677512	7988	92	26B
0005432919526	7988	93	26A
0005433101311	7988	94	26C
0005433101332	7988	95	26D
0005433101312	7988	96	26F
0005432919532	7988	97	26E
0005432751475	7988	98	27A
0005432919539	7988	99	27C
0005432751476	7988	100	27F
0005433101305	7988	101	27E
0005432044482	7988	102	28A
0005432019854	7988	103	28B
0005433101307	7988	104	28D
0005432919530	7988	105	28C
0005432019857	7988	106	28E
0005432919540	7988	107	28F
0005433101313	7988	108	29B
0005432019853	7988	109	29C
0005432919525	7988	110	29D
0005433101342	7988	111	29F
0005432019841	7988	112	30B
0005432391954	7988	113	30C
0005433101314	7988	114	30D
0005432045584	7988	115	30F
0005432919529	7988	116	30E
0005433101309	7988	117	31B
0005433101308	7988	118	31C
0005432019851	7988	119	31D
0005432019837	7988	120	31F
0005432901330	7989	1	2C
0005432901336	7989	2	6F
0005432901340	7989	3	8C
0005432901342	7989	4	8B
0005432901343	7989	5	8F
0005432002045	7989	6	10B
0005432901339	7989	7	10C
0005432901333	7989	8	11E
0005432901329	7989	9	14F
0005432901332	7989	10	15C
0005432901338	7989	11	21A
0005432901344	7989	12	22B
0005432901341	7989	13	23C
0005432901331	7989	14	23D
0005432901345	7989	15	24B
0005432901337	7989	16	24F
0005432901335	7989	17	25F
0005432002044	7989	18	27B
0005432901346	7989	19	27F
0005432901334	7989	20	30F
0005433870698	9656	1	1A
0005433870696	9656	2	1B
0005433870697	9656	3	5B
0005434175690	32343	1	2A
0005434175688	32343	2	4A
0005434175687	32343	3	5A
0005434175689	32343	4	6A
0005434426152	3512	1	1C
0005434876775	3512	2	1H
0005434876819	3512	3	1D
0005434426162	3512	4	2D
0005432799016	3512	5	2C
0005434426169	3512	6	2A
0005435625911	3512	7	2G
0005435125733	3512	8	3A
0005432799036	3512	9	3H
0005434876776	3512	10	4A
0005435125739	3512	11	4G
0005435125766	3512	12	4K
0005432799024	3512	13	5A
0005434876785	3512	14	5H
0005434937835	3512	15	11A
0005434426172	3512	16	5K
0005434426156	3512	17	11C
0005434876780	3512	18	11F
0005434876808	3512	19	11K
0005434876760	3512	20	11H
0005434876834	3512	21	12C
0005434426157	3512	22	12E
0005434937847	3512	23	12G
0005434876809	3512	24	12F
0005434937851	3512	25	12K
0005432613800	3512	26	13A
0005434876797	3512	27	13F
0005432799018	3512	28	13E
0005434876822	3512	29	13H
0005434876778	3512	30	13G
0005434876829	3512	31	14A
0005434876801	3512	32	13K
0005434876828	3512	33	14C
0005434876799	3512	34	14G
0005432611649	3512	35	14F
0005434876761	3512	36	14K
0005434426146	3512	37	14H
0005434876831	3512	38	15C
0005434876750	3512	39	15E
0005434876759	3512	40	15D
0005434876754	3512	41	15H
0005435125731	3512	42	15F
0005432799017	3512	43	15K
0005432799022	3512	44	16C
0005434876764	3512	45	16H
0005432183435	3512	46	16G
0005434876820	3512	47	17C
0005432188560	3512	48	16K
0005432799031	3512	49	17D
0005434876836	3512	50	17H
0005432799028	3512	51	17G
0005434876786	3512	52	17F
0005434876752	3512	53	17K
0005434876788	3512	54	18E
0005435125751	3512	55	18C
0005434876832	3512	56	18J
0005434937844	3512	57	18H
0005434426155	3512	58	19A
0005435125730	3512	59	19D
0005434876777	3512	60	19C
0005432799023	3512	61	19E
0005435125764	3512	62	19H
0005434426171	3512	63	19G
0005434876804	3512	64	19K
0005435125736	3512	65	19J
0005434876802	3512	66	20C
0005434426165	3512	67	20B
0005435625909	3512	68	20E
0005435125757	3512	69	20D
0005432799034	3512	70	20G
0005435625910	3512	71	20F
0005434876782	3512	72	20J
0005434426167	3512	73	21B
0005432183433	3512	74	20K
0005434876755	3512	75	21D
0005434426161	3512	76	21C
0005434876846	3512	77	21F
0005435625902	3512	78	21E
0005432188559	3512	79	21J
0005432799030	3512	80	21H
0005432799039	3512	81	22B
0005432611647	3512	82	22E
0005434876805	3512	83	22D
0005432799019	3512	84	22H
0005434876787	3512	85	22K
0005434426147	3512	86	23B
0005432799011	3512	87	23G
0005434426148	3512	88	23J
0005434876781	3512	89	23H
0005435625912	3512	90	24D
0005434426170	3512	91	25C
0005435125768	3512	92	25G
0005434876806	3512	93	25K
0005434426166	3512	94	25J
0005435125732	3512	95	26B
0005434876763	3512	96	26D
0005432799037	3512	97	26F
0005435625901	3512	98	26J
0005432188557	3512	99	27A
0005434876774	3512	100	27C
0005435125760	3512	101	27F
0005432183434	3512	102	27H
0005434876792	3512	103	27G
0005434876771	3512	104	28A
0005434876758	3512	105	27J
0005432799020	3512	106	28B
0005435125737	3512	107	28E
0005434426153	3512	108	28D
0005435125742	3512	109	28F
0005434876751	3512	110	28J
0005435625900	3512	111	28H
0005435125752	3512	112	29B
0005432613797	3512	113	29A
0005434876770	3512	114	29C
0005434937840	3512	115	29F
0005435125767	3512	116	29E
0005434876837	3512	117	29H
0005435625905	3512	118	29K
0005435125734	3512	119	30B
0005432611648	3512	120	30A
0005432188558	3512	121	30E
0005432799015	3512	122	30F
0005434876793	3512	123	31A
0005432799021	3512	124	30K
0005435125753	3512	125	31F
0005434426159	3512	126	31E
0005434876757	3512	127	31H
0005432799013	3512	128	31G
0005434876823	3512	129	32A
0005434426149	3512	130	32E
0005435625907	3512	131	32D
0005435125754	3512	132	32J
0005435125770	3512	133	33A
0005434876844	3512	134	33D
0005434876773	3512	135	33E
0005434876821	3512	136	33G
0005434426164	3512	137	34A
0005435125738	3512	138	33J
0005434876803	3512	139	34C
0005432799035	3512	140	34B
0005435125749	3512	141	34E
0005434876817	3512	142	34F
0005434426158	3512	143	34J
0005434876825	3512	144	35G
0005435125740	3512	145	35F
0005434937846	3512	146	35E
0005434876824	3512	147	35H
0005434876810	3512	148	35K
0005434876766	3512	149	35J
0005432799025	3512	150	36D
0005434937839	3512	151	36C
0005434426151	3512	152	36F
0005432799027	3512	153	36H
0005434876753	3512	154	36K
0005435125759	3512	155	37B
0005434876800	3512	156	37E
0005432799014	3512	157	37D
0005434876768	3512	158	37C
0005435625906	3512	159	37G
0005432799033	3512	160	37F
0005434876827	3512	161	37J
0005434876769	3512	162	38A
0005434426160	3512	163	37K
0005435125765	3512	164	38C
0005432613798	3512	165	38J
0005434426150	3512	166	38H
0005434876765	3512	167	39B
0005435125741	3512	168	38K
0005434876813	3512	169	39E
0005435625903	3512	170	39H
0005434876833	3512	171	39G
0005434937849	3512	172	39J
0005435125747	3512	173	40C
0005434876767	3512	174	40B
0005435125769	3512	175	40G
0005434937841	3512	176	40F
0005434876789	3512	177	40J
0005434937842	3512	178	40H
0005434937833	3512	179	41A
0005434937838	3512	180	41D
0005434876784	3512	181	41C
0005435125748	3512	182	41F
0005432799038	3512	183	41H
0005435125756	3512	184	42A
0005434937834	3512	185	41K
0005435125758	3512	186	42C
0005434876762	3512	187	42B
0005434937850	3512	188	42E
0005434876826	3512	189	42D
0005434876749	3512	190	42G
0005434876796	3512	191	42F
0005434876790	3512	192	42J
0005435125744	3512	193	42H
0005435125746	3512	194	43B
0005435125755	3512	195	42K
0005432611650	3512	196	43C
0005434876794	3512	197	43E
0005432799029	3512	198	43J
0005435125761	3512	199	44C
0005434876795	3512	200	44A
0005435125735	3512	201	44E
0005434876815	3512	202	44D
0005435125762	3512	203	44H
0005434876798	3512	204	44G
0005435125771	3512	205	44F
0005434937848	3512	206	44K
0005434876842	3512	207	44J
0005432613799	3512	208	45A
0005434876835	3512	209	45C
0005435625904	3512	210	45B
0005434876756	3512	211	45D
0005434937837	3512	212	45H
0005434426173	3512	213	45G
0005435625908	3512	214	45K
0005435125750	3512	215	45J
0005434937845	3512	216	46A
0005434876816	3512	217	46E
0005434876812	3512	218	46D
0005435125743	3512	219	46F
0005434937836	3512	220	47A
0005434876818	3512	221	46K
0005434876838	3512	222	47E
0005434876814	3512	223	47D
0005434876840	3512	224	47H
0005434876772	3512	225	48D
0005434426168	3512	226	48A
0005432799032	3512	227	48F
0005434426163	3512	228	48E
0005434876779	3512	229	48H
0005434937843	3512	230	48G
0005434876843	3512	231	49A
0005434876811	3512	232	48K
0005435125745	3512	233	49D
0005434876783	3512	234	49C
0005434876830	3512	235	49F
0005432799012	3512	236	49E
0005434876807	3512	237	49H
0005432183432	3512	238	50A
0005434426154	3512	239	50D
0005435125763	3512	240	50G
0005434876791	3512	241	50F
0005434876841	3512	242	50H
0005434876839	3512	243	51E
0005432799026	3512	244	51D
0005434876845	3512	245	51G
0005435902434	14543	1	2A
0005435902429	14543	2	14K
0005435902437	14543	3	18H
0005435902431	14543	4	20G
0005435902426	14543	5	21E
0005435902427	14543	6	21K
0005435902433	14543	7	23C
0005435902430	14543	8	23F
0005435902436	14543	9	26E
0005432059475	14543	10	27B
0005432059473	14543	11	28E
0005435842314	14543	12	28H
0005435902435	14543	13	29B
0005435902425	14543	14	33C
0005432059474	14543	15	36C
0005435902428	14543	16	36F
0005435902424	14543	17	37E
0005435902422	14543	18	39C
0005435841810	14543	19	42E
0005435902421	14543	20	43F
0005435902432	14543	21	44G
0005435902423	14543	22	48K
0005434325469	3589	1	2C
0005434312286	3589	2	4B
0005434312285	3589	3	4D
0005434325477	3589	4	5A
0005434325473	3589	5	5C
0005434325467	3589	6	5D
0005434325471	3589	7	6B
0005434325468	3589	8	7A
0005434325476	3589	9	18A
0005434325474	3589	10	19C
0005434325470	3589	11	19D
0005434325472	3589	12	20B
0005434325466	3589	13	22A
0005434325475	3589	14	22D
0005435889804	15604	1	2B
0005435889805	15604	2	2C
0005435889802	15604	3	3C
0005435889803	15604	4	5A
0005435889806	15604	5	21B
0005435889801	15604	6	23A
0005435957471	666	1	1C
0005435957470	666	2	1D
0005435957474	666	3	2B
0005435957483	666	4	2C
0005435957477	666	5	3C
0005435957476	666	6	3D
0005435957473	666	7	6A
0005435957472	666	8	7A
0005435957469	666	9	18D
0005435957480	666	10	19A
0005435957475	666	11	19D
0005435957482	666	12	20C
0005435957481	666	13	20D
0005435957478	666	14	21D
0005435957479	666	15	22D
0005433420270	15173	1	1C
0005433420268	15173	2	1D
0005433420274	15173	3	2B
0005433420267	15173	4	2D
0005433420273	15173	5	4A
0005433420272	15173	6	4D
0005433420269	15173	7	7B
0005433420266	15173	8	7C
0005433420271	15173	9	21C
0005433420275	15173	10	22C
0005435629386	8905	1	1A
0005435629387	8905	2	3A
0005435629385	8905	3	3B
0005434247110	16087	1	1A
0005434247106	16087	2	3B
0005434247108	16087	3	4A
0005434247109	16087	4	5B
0005434247107	16087	5	6A
0005434247105	16087	6	6B
0005435163148	4446	1	1C
0005435163145	4446	2	2C
0005435163147	4446	3	3A
0005435163149	4446	4	3C
0005435163154	4446	5	3D
0005435163151	4446	6	4B
0005435163150	4446	7	5B
0005435163146	4446	8	18C
0005435163153	4446	9	19A
0005435163152	4446	10	20A
0005435163155	4446	11	23A
0005435933396	29518	1	1B
0005435933403	29518	2	3A
0005435933400	29518	3	3C
0005435933402	29518	4	7C
0005435933397	29518	5	20C
0005435933399	29518	6	22A
0005435933398	29518	7	22B
0005435933401	29518	8	22D
0005435797262	2862	1	1F
0005435797257	2862	2	2C
0005435797252	2862	3	7C
0005435797263	2862	4	7E
0005435797261	2862	5	8A
0005435797260	2862	6	8D
0005435797256	2862	7	9D
0005435797253	2862	8	9E
0005435797255	2862	9	11C
0005435797254	2862	10	12F
0005435797259	2862	11	13A
0005435797258	2862	12	14E
0005435797264	2862	13	19F
0005433404691	29310	1	2D
0005433404695	29310	2	4C
0005433404698	29310	3	5D
0005433404692	29310	4	9C
0005433404697	29310	5	10D
0005433404696	29310	6	11E
0005433404693	29310	7	12A
0005433404694	29310	8	20D
0005434947892	5762	1	1A
0005434947888	5762	2	1B
0005434947885	5762	3	2A
0005434947890	5762	4	2B
0005434947887	5762	5	4A
0005434947893	5762	6	4B
0005434947889	5762	7	6A
0005434947891	5762	8	5B
0005434947886	5762	9	6B
0005435376316	16423	1	2B
0005435376315	16423	2	5A
0005435376317	16423	3	5B
0005433960020	6919	1	1A
0005433959993	6919	2	1C
0005433959970	6919	3	1D
0005433959981	6919	4	2A
0005433959992	6919	5	2C
0005433960017	6919	6	2D
0005433960003	6919	7	2F
0005433960001	6919	8	3C
0005433960024	6919	9	3D
0005433959978	6919	10	3F
0005433959998	6919	11	4A
0005433959994	6919	12	4C
0005433959972	6919	13	4D
0005433959973	6919	14	4E
0005433960022	6919	15	5A
0005433959974	6919	16	5C
0005433959983	6919	17	5F
0005433959990	6919	18	6A
0005433960013	6919	19	6C
0005433960014	6919	20	6E
0005433959967	6919	21	7A
0005433960007	6919	22	7C
0005433959997	6919	23	7D
0005433959995	6919	24	7E
0005433959985	6919	25	7F
0005433960010	6919	26	8C
0005433960027	6919	27	8D
0005433959996	6919	28	8E
0005433959982	6919	29	9A
0005433959968	6919	30	9C
0005433960016	6919	31	9D
0005433960000	6919	32	9E
0005433960023	6919	33	10C
0005433959976	6919	34	10D
0005433960002	6919	35	10F
0005433959980	6919	36	11A
0005433959966	6919	37	11C
0005433960019	6919	38	11E
0005433959969	6919	39	11F
0005433960026	6919	40	12A
0005433959988	6919	41	12D
0005433960012	6919	42	12E
0005433960025	6919	43	13A
0005433960006	6919	44	13C
0005433959965	6919	45	13F
0005433959987	6919	46	14D
0005433959991	6919	47	15A
0005433959984	6919	48	15C
0005433960021	6919	49	15E
0005433959975	6919	50	16A
0005433960009	6919	51	16C
0005433960011	6919	52	16E
0005433959989	6919	53	16F
0005433959964	6919	54	17A
0005433959971	6919	55	17C
0005433959999	6919	56	17E
0005433960004	6919	57	17F
0005433960008	6919	58	18A
0005433960005	6919	59	18C
0005433959986	6919	60	18E
0005433959979	6919	61	19E
0005433959977	6919	62	19F
0005433960018	6919	63	20A
0005433960015	6919	64	20C
0005435082652	26095	1	1A
0005435082656	26095	2	1B
0005435082655	26095	3	2A
0005435082661	26095	4	2B
0005435082653	26095	5	3B
0005435082654	26095	6	3A
0005435082651	26095	7	4A
0005435082659	26095	8	5A
0005435082650	26095	9	4B
0005435082658	26095	10	5B
0005435082657	26095	11	6A
0005435082660	26095	12	6B
0005434244534	5036	1	2D
0005434244524	5036	2	5A
0005434244520	5036	3	6A
0005434244527	5036	4	6F
0005434244533	5036	5	9C
0005434244516	5036	6	10E
0005434244526	5036	7	12D
0005434244525	5036	8	14A
0005432166850	5036	9	13F
0005434244519	5036	10	14D
0005434244515	5036	11	15F
0005434244532	5036	12	16B
0005434244522	5036	13	17C
0005434244538	5036	14	17F
0005434244521	5036	15	17E
0005434244523	5036	16	18C
0005434244530	5036	17	18F
0005434244539	5036	18	21A
0005432166851	5036	19	21E
0005434244542	5036	20	22E
0005434244535	5036	21	23B
0005434244537	5036	22	24A
0005432166852	5036	23	24F
0005434244531	5036	24	25E
0005434244518	5036	25	26B
0005434244517	5036	26	26F
0005434244529	5036	27	26E
0005434244541	5036	28	27B
0005434244528	5036	29	28D
0005434244543	5036	30	28F
0005434244536	5036	31	30C
0005434244540	5036	32	31E
0005433613582	5035	1	1A
0005433613543	5035	2	1C
0005433784383	5035	3	1D
0005432667421	5035	4	2A
0005433613546	5035	5	1F
0005433784384	5035	6	2C
0005433613554	5035	7	2F
0005433613557	5035	8	2D
0005433613544	5035	9	3A
0005433613552	5035	10	3C
0005433784397	5035	11	3D
0005432104821	5035	12	4A
0005433784368	5035	13	3F
0005433613606	5035	14	4C
0005433613571	5035	15	4D
0005433784393	5035	16	5A
0005433613547	5035	17	4F
0005433613570	5035	18	5C
0005432104840	5035	19	5F
0005433613592	5035	20	5D
0005433613541	5035	21	6A
0005432104855	5035	22	6D
0005433613590	5035	23	6C
0005432145081	5035	24	6F
0005432104844	5035	25	7A
0005433784385	5035	26	7C
0005432104842	5035	27	7D
0005432104822	5035	28	8A
0005433784388	5035	29	7F
0005433613558	5035	30	8B
0005433784391	5035	31	8C
0005432104857	5035	32	8E
0005433613561	5035	33	8D
0005433784370	5035	34	8F
0005433784386	5035	35	9B
0005433613566	5035	36	9A
0005433613560	5035	37	9C
0005432104814	5035	38	9D
0005432666357	5035	39	9F
0005432665241	5035	40	9E
0005432145079	5035	41	10A
0005433784396	5035	42	10C
0005433613593	5035	43	10B
0005433613605	5035	44	10D
0005432104832	5035	45	10E
0005433784387	5035	46	10F
0005433613537	5035	47	11B
0005433613550	5035	48	11A
0005432104853	5035	49	11C
0005433613584	5035	50	11D
0005433784374	5035	51	11F
0005433784376	5035	52	11E
0005433784400	5035	53	12A
0005432104816	5035	54	12B
0005432104847	5035	55	12D
0005432104830	5035	56	12C
0005433613598	5035	57	12E
0005432666355	5035	58	12F
0005433784379	5035	59	13A
0005432666356	5035	60	13C
0005433784395	5035	61	13B
0005432104825	5035	62	13D
0005433613538	5035	63	13F
0005433613572	5035	64	13E
0005433784390	5035	65	14A
0005433613607	5035	66	14B
0005433784372	5035	67	14C
0005433613540	5035	68	14E
0005433613587	5035	69	14D
0005432104851	5035	70	14F
0005432104812	5035	71	15B
0005433613604	5035	72	15A
0005432104829	5035	73	15C
0005432104838	5035	74	15D
0005433613549	5035	75	15E
0005432104811	5035	76	16A
0005432104839	5035	77	15F
0005433613563	5035	78	16B
0005433784389	5035	79	16D
0005433613562	5035	80	16C
0005433613602	5035	81	16E
0005433613595	5035	82	17A
0005432667422	5035	83	16F
0005433613565	5035	84	17B
0005433784392	5035	85	17C
0005432104831	5035	86	17D
0005433613548	5035	87	17E
0005433784371	5035	88	18A
0005432104837	5035	89	17F
0005432104843	5035	90	18B
0005433613559	5035	91	18D
0005433784398	5035	92	18C
0005433784399	5035	93	18E
0005432145080	5035	94	18F
0005432104856	5035	95	19C
0005433613545	5035	96	19B
0005433613555	5035	97	19D
0005433784381	5035	98	19E
0005433613574	5035	99	20B
0005433613601	5035	100	20A
0005432104841	5035	101	20C
0005432104834	5035	102	20D
0005433784378	5035	103	20E
0005432104850	5035	104	21B
0005433613576	5035	105	21A
0005433613539	5035	106	20F
0005432104836	5035	107	21D
0005432104826	5035	108	21C
0005433613600	5035	109	21E
0005432104833	5035	110	21F
0005433784375	5035	111	22B
0005433613583	5035	112	22A
0005433613588	5035	113	22C
0005432104849	5035	114	22E
0005433613597	5035	115	22D
0005433613577	5035	116	22F
0005432104846	5035	117	23B
0005433613564	5035	118	23A
0005432104827	5035	119	23C
0005433613585	5035	120	23D
0005433784373	5035	121	23F
0005433613603	5035	122	23E
0005432104818	5035	123	24A
0005433613610	5035	124	24B
0005433613556	5035	125	24D
0005433784377	5035	126	24C
0005433613591	5035	127	24F
0005432104809	5035	128	24E
0005433613579	5035	129	25A
0005432104820	5035	130	25C
0005432104835	5035	131	25B
0005432104858	5035	132	25D
0005432104815	5035	133	25F
0005433784369	5035	134	25E
0005433784394	5035	135	26A
0005433613575	5035	136	26B
0005433784367	5035	137	26C
0005433613608	5035	138	26E
0005433613567	5035	139	26D
0005432104810	5035	140	26F
0005433613568	5035	141	27A
0005432104823	5035	142	27C
0005433613581	5035	143	27B
0005432665242	5035	144	27D
0005432104813	5035	145	27F
0005433613609	5035	146	27E
0005432665243	5035	147	28A
0005433613553	5035	148	28B
0005433613594	5035	149	28C
0005433613569	5035	150	28E
0005433613596	5035	151	28D
0005433613580	5035	152	28F
0005432104828	5035	153	29B
0005432104845	5035	154	29A
0005433613536	5035	155	29C
0005433613573	5035	156	29E
0005433784382	5035	157	29D
0005432104848	5035	158	29F
0005432104824	5035	159	30A
0005433613542	5035	160	30B
0005432104852	5035	161	30C
0005432104819	5035	162	30E
0005433613586	5035	163	30D
0005433613578	5035	164	30F
0005432104854	5035	165	31A
0005433613599	5035	166	31C
0005433784380	5035	167	31B
0005433613589	5035	168	31D
0005433613551	5035	169	31E
0005432104817	5035	170	31F
0005434173456	5033	1	1A
0005434229015	5033	2	1F
0005434229017	5033	3	2F
0005434229028	5033	4	3C
0005434264752	5033	5	3D
0005434149555	5033	6	5C
0005434149545	5033	7	5D
0005434264740	5033	8	6C
0005434264745	5033	9	7A
0005434229031	5033	10	7D
0005434173458	5033	11	8A
0005434173457	5033	12	8F
0005434264731	5033	13	9C
0005434229016	5033	14	9F
0005434229018	5033	15	10B
0005434229021	5033	16	10D
0005434149550	5033	17	10E
0005434264736	5033	18	10F
0005434264753	5033	19	11B
0005434264743	5033	20	11A
0005434149547	5033	21	11D
0005434149556	5033	22	12C
0005434264747	5033	23	12B
0005434229032	5033	24	12E
0005434229030	5033	25	12D
0005434264749	5033	26	13B
0005434264733	5033	27	13D
0005434264748	5033	28	14A
0005434149552	5033	29	14E
0005434264730	5033	30	15B
0005434264737	5033	31	15C
0005434229026	5033	32	15E
0005434149549	5033	33	16D
0005434229033	5033	34	16E
0005434149553	5033	35	17B
0005434229029	5033	36	17A
0005434264741	5033	37	17E
0005434229013	5033	38	17D
0005434264732	5033	39	17F
0005434229034	5033	40	18D
0005434264729	5033	41	19C
0005434229019	5033	42	20A
0005434229014	5033	43	20D
0005434149544	5033	44	20C
0005434264750	5033	45	20E
0005434229020	5033	46	21B
0005434229027	5033	47	22B
0005434229022	5033	48	22A
0005434149551	5033	49	22F
0005434149554	5033	50	23C
0005434229025	5033	51	24D
0005434264742	5033	52	24C
0005434229012	5033	53	25D
0005434264735	5033	54	25F
0005434264728	5033	55	26A
0005434264746	5033	56	26C
0005434149548	5033	57	27B
0005434264744	5033	58	29A
0005434149546	5033	59	29E
0005434264734	5033	60	30A
0005434229023	5033	61	30C
0005434264739	5033	62	30D
0005434264751	5033	63	31B
0005434229024	5033	64	31C
0005434264738	5033	65	31E
0005434173459	5033	66	31D
0005432034525	8570	1	1A
0005432034517	8570	2	1C
0005432335854	8570	3	1D
0005432034509	8570	4	2A
0005432034533	8570	5	2F
0005432034521	8570	6	3C
0005433534464	8570	7	3F
0005435006668	8570	8	3D
0005433534465	8570	9	4A
0005432335857	8570	10	4C
0005433815310	8570	11	4F
0005432034514	8570	12	5C
0005432034523	8570	13	5D
0005433690896	8570	14	5F
0005435006648	8570	15	6A
0005432034508	8570	16	6F
0005432335849	8570	17	7A
0005432034510	8570	18	7D
0005433689878	8570	19	8A
0005432034515	8570	20	7F
0005435006662	8570	21	8D
0005432034527	8570	22	8F
0005435006652	8570	23	9C
0005433815313	8570	24	9E
0005432034528	8570	25	10A
0005433815314	8570	26	10C
0005432047492	8570	27	10E
0005434311187	8570	28	10D
0005435006653	8570	29	10F
0005435286552	8570	30	11C
0005435006666	8570	31	11B
0005432034529	8570	32	11D
0005435006664	8570	33	12A
0005432335845	8570	34	12B
0005432335853	8570	35	12D
0005432047493	8570	36	12C
0005432335852	8570	37	13A
0005435006649	8570	38	13D
0005435006656	8570	39	13E
0005434311186	8570	40	14C
0005432034531	8570	41	14B
0005432034522	8570	42	14A
0005435006665	8570	43	14E
0005432034507	8570	44	14D
0005433689881	8570	45	15A
0005432034532	8570	46	15B
0005433690894	8570	47	15F
0005433690895	8570	48	16A
0005432335847	8570	49	16E
0005432335855	8570	50	17A
0005435006650	8570	51	17D
0005432034516	8570	52	17F
0005435006651	8570	53	17E
0005435006659	8570	54	18B
0005433689879	8570	55	18C
0005432034520	8570	56	18D
0005435286551	8570	57	19D
0005435006669	8570	58	19E
0005435006654	8570	59	20A
0005434311185	8570	60	20C
0005432335851	8570	61	21A
0005432034518	8570	62	21B
0005432034526	8570	63	21D
0005432335848	8570	64	21F
0005432034511	8570	65	22A
0005435286553	8570	66	22B
0005433815311	8570	67	22D
0005435006670	8570	68	22F
0005432047494	8570	69	22E
0005432034513	8570	70	23B
0005435006663	8570	71	24D
0005435286549	8570	72	24E
0005435006667	8570	73	24F
0005435006658	8570	74	25A
0005432034506	8570	75	26A
0005433688778	8570	76	25F
0005433815312	8570	77	26F
0005433534466	8570	78	27C
0005432335850	8570	79	27E
0005435006671	8570	80	28B
0005433688777	8570	81	29A
0005435006647	8570	82	28F
0005432335846	8570	83	29C
0005435006661	8570	84	29D
0005433689880	8570	85	29E
0005435286550	8570	86	30A
0005435006655	8570	87	30B
0005435006657	8570	88	30D
0005432034530	8570	89	30C
0005432034512	8570	90	30E
0005432034519	8570	91	30F
0005432034524	8570	92	31A
0005435006660	8570	93	31C
0005432335856	8570	94	31D
0005433202137	12637	1	1C
0005433202141	12637	2	4C
0005433202142	12637	3	5A
0005433202145	12637	4	5B
0005433202140	12637	5	5D
0005433202139	12637	6	6B
0005433202133	12637	7	7A
0005433202144	12637	8	7D
0005433202136	12637	9	18B
0005433202135	12637	10	18C
0005433202143	12637	11	19A
0005433202134	12637	12	20C
0005433202138	12637	13	22A
0005433202146	12637	14	22C
0005434638899	23344	1	1A
0005432290583	23344	2	1B
0005434638888	23344	3	1C
0005434638890	23344	4	1D
0005434638893	23344	5	2B
0005434638883	23344	6	2C
0005434638882	23344	7	3A
0005434638894	23344	8	3B
0005434638897	23344	9	3D
0005434638898	23344	10	4A
0005434638878	23344	11	4C
0005434638885	23344	12	5D
0005434638879	23344	13	6A
0005432290584	23344	14	6C
0005434638881	23344	15	7A
0005434638901	23344	16	7B
0005434638876	23344	17	7D
0005434638877	23344	18	18B
0005434638887	23344	19	19A
0005434638892	23344	20	19B
0005434638895	23344	21	19C
0005434638886	23344	22	20A
0005434638896	23344	23	20C
0005434638902	23344	24	20D
0005434638880	23344	25	21A
0005434638900	23344	26	21D
0005434638891	23344	27	22C
0005434638884	23344	28	22D
0005434638889	23344	29	23B
0005432054258	21084	1	2A
0005432848836	21084	2	4F
0005432054260	21084	3	8D
0005432054259	21084	4	14D
0005432054261	21084	5	17F
0005432327978	31230	1	1A
0005432287109	31230	2	1C
0005432327981	31230	3	1D
0005432382526	31230	4	1F
0005432382543	31230	5	2A
0005432382521	31230	6	2C
0005432327973	31230	7	2D
0005432382561	31230	8	2F
0005432327940	31230	9	3A
0005432382531	31230	10	3C
0005432327969	31230	11	3D
0005432382541	31230	12	3F
0005432327959	31230	13	4A
0005432327948	31230	14	4C
0005432327938	31230	15	4E
0005432382529	31230	16	4F
0005432327960	31230	17	5A
0005432382551	31230	18	5C
0005432382528	31230	19	5D
0005432382540	31230	20	5E
0005432382562	31230	21	5F
0005432327968	31230	22	6A
0005432382549	31230	23	6D
0005432327957	31230	24	6E
0005432382558	31230	25	6F
0005432382544	31230	26	7A
0005432382524	31230	27	7C
0005432327945	31230	28	7D
0005432327963	31230	29	7E
0005432382535	31230	30	7F
0005432327976	31230	31	8A
0005432382527	31230	32	8C
0005432327971	31230	33	8D
0005432327982	31230	34	8E
0005432327949	31230	35	8F
0005432327983	31230	36	9A
0005432382559	31230	37	9C
0005432382539	31230	38	9D
0005432327979	31230	39	9E
0005432382522	31230	40	9F
0005432327953	31230	41	10A
0005432327967	31230	42	10C
0005432327952	31230	43	10D
0005432382532	31230	44	10E
0005432382557	31230	45	10F
0005432327943	31230	46	11A
0005432327975	31230	47	11C
0005432382552	31230	48	11D
0005432382523	31230	49	11E
0005432327939	31230	50	11F
0005432382563	31230	51	12A
0005432382553	31230	52	12C
0005432382545	31230	53	12D
0005432327956	31230	54	12E
0005432327942	31230	55	12F
0005432327964	31230	56	13A
0005432382547	31230	57	13C
0005432287108	31230	58	13D
0005432327941	31230	59	13E
0005432327961	31230	60	13F
0005432382546	31230	61	14A
0005432382525	31230	62	14C
0005432382548	31230	63	14D
0005432327965	31230	64	14E
0005432327954	31230	65	14F
0005432382536	31230	66	15A
0005432327946	31230	67	15C
0005432327950	31230	68	15D
0005432382554	31230	69	15E
0005432382550	31230	70	15F
0005432382556	31230	71	16A
0005432287106	31230	72	16C
0005432327980	31230	73	16D
0005432382555	31230	74	16E
0005432382537	31230	75	16F
0005432382534	31230	76	17A
0005432327955	31230	77	17C
0005432327944	31230	78	17D
0005432327962	31230	79	17E
0005432327970	31230	80	17F
0005432327977	31230	81	18A
0005432327951	31230	82	18C
0005432382538	31230	83	18D
0005432287107	31230	84	18F
0005432382560	31230	85	19A
0005432327966	31230	86	19C
0005432327984	31230	87	19D
0005432382530	31230	88	19E
0005432327972	31230	89	20A
0005432327958	31230	90	19F
0005432382533	31230	91	20C
0005432327947	31230	92	20D
0005432382542	31230	93	20E
0005432327974	31230	94	20F
0005433642091	2491	1	1A
0005433642100	2491	2	2D
0005433642109	2491	3	2F
0005433642114	2491	4	3A
0005433642117	2491	5	3F
0005433642108	2491	6	4E
0005433642119	2491	7	5D
0005433642090	2491	8	6C
0005433642088	2491	9	7A
0005433642112	2491	10	7C
0005433642102	2491	11	7D
0005433642106	2491	12	8D
0005433642095	2491	13	9A
0005433642103	2491	14	9C
0005433642092	2491	15	10C
0005433642118	2491	16	11E
0005433642115	2491	17	12F
0005433642101	2491	18	13C
0005433642110	2491	19	13F
0005433642097	2491	20	14A
0005433642094	2491	21	14C
0005433642098	2491	22	14E
0005433642104	2491	23	14F
0005433642113	2491	24	15A
0005433642116	2491	25	15E
0005433642111	2491	26	16D
0005433642105	2491	27	16E
0005433642093	2491	28	16F
0005433642089	2491	29	18A
0005433642099	2491	30	20A
0005433642096	2491	31	20C
0005433642107	2491	32	20E
0005432953791	27596	1	1C
0005432953802	27596	2	1D
0005432953798	27596	3	1F
0005432953808	27596	4	2A
0005432953811	27596	5	2D
0005432953809	27596	6	3D
0005432953807	27596	7	3F
0005432953806	27596	8	4C
0005432953796	27596	9	4D
0005432953793	27596	10	5F
0005432953799	27596	11	7F
0005432953785	27596	12	8C
0005432953801	27596	13	8D
0005432953797	27596	14	9C
0005432953803	27596	15	10D
0005432953795	27596	16	11C
0005432953788	27596	17	11E
0005432953810	27596	18	12E
0005432953805	27596	19	15A
0005432953790	27596	20	14F
0005432953789	27596	21	15C
0005432953794	27596	22	15D
0005432953786	27596	23	16E
0005432953804	27596	24	17E
0005432953787	27596	25	18E
0005432953800	27596	26	19A
0005432953792	27596	27	19D
0005432423649	13331	1	1C
0005432423656	13331	2	1D
0005432423682	13331	3	2A
0005432423671	13331	4	2C
0005432423652	13331	5	2D
0005432423658	13331	6	2F
0005432423690	13331	7	3D
0005432423677	13331	8	4C
0005432423657	13331	9	4D
0005432423660	13331	10	4E
0005432423664	13331	11	4F
0005432423665	13331	12	5C
0005432423670	13331	13	5D
0005432423663	13331	14	5E
0005432423667	13331	15	5F
0005432423668	13331	16	6A
0005432423693	13331	17	6E
0005432423674	13331	18	6F
0005432423653	13331	19	7A
0005432423662	13331	20	7F
0005432423650	13331	21	9A
0005432423679	13331	22	9C
0005432423681	13331	23	9D
0005432423684	13331	24	9E
0005432423687	13331	25	9F
0005432423661	13331	26	10C
0005432423675	13331	27	10D
0005432423685	13331	28	10F
0005432423666	13331	29	11A
0005432423659	13331	30	11C
0005432423654	13331	31	13A
0005432423651	13331	32	13C
0005432423655	13331	33	13E
0005432423678	13331	34	13F
0005432423672	13331	35	14C
0005432423673	13331	36	14E
0005432423648	13331	37	15D
0005432423683	13331	38	16D
0005432423676	13331	39	16E
0005432423691	13331	40	17D
0005432423688	13331	41	17E
0005432423692	13331	42	18E
0005432423669	13331	43	19C
0005432423680	13331	44	19D
0005432423689	13331	45	20C
0005432423686	13331	46	20E
0005434448261	9596	1	1F
0005432822084	9596	2	2A
0005432817020	9596	3	2D
0005432817013	9596	4	3A
0005432817004	9596	5	3C
0005432816998	9596	6	3D
0005434448264	9596	7	4F
0005434448263	9596	8	5A
0005432817018	9596	9	5D
0005432817011	9596	10	5F
0005432288936	9596	11	6A
0005432288935	9596	12	6C
0005432817003	9596	13	6D
0005432822087	9596	14	6E
0005432817000	9596	15	6F
0005432817016	9596	16	7A
0005432817024	9596	17	7C
0005432817007	9596	18	7E
0005432817025	9596	19	8C
0005432822085	9596	20	8D
0005432817010	9596	21	9A
0005432817019	9596	22	9C
0005434448262	9596	23	10A
0005432817006	9596	24	10D
0005432817026	9596	25	10F
0005432817017	9596	26	11C
0005432817015	9596	27	11F
0005432816999	9596	28	12D
0005432822082	9596	29	12E
0005432822086	9596	30	13D
0005432817009	9596	31	14A
0005432817027	9596	32	14D
0005432288934	9596	33	14F
0005432822080	9596	34	16C
0005432817005	9596	35	16D
0005432822081	9596	36	16E
0005432817002	9596	37	17C
0005432817023	9596	38	18A
0005432817014	9596	39	18C
0005432817022	9596	40	18D
0005432817001	9596	41	18E
0005432817021	9596	42	19C
0005432817012	9596	43	19E
0005432822083	9596	44	19F
0005432817008	9596	45	20C
0005432901346	28993	1	1A
0005434157356	28993	2	1F
0005432002045	28993	3	2A
0005432901345	28993	4	2C
0005432901335	28993	5	3C
0005434157360	28993	6	3D
0005432901331	28993	7	3F
0005434157358	28993	8	4E
0005434157361	28993	9	6F
0005432901342	28993	10	7A
0005432901336	28993	11	8F
0005434157362	28993	12	9C
0005432901330	28993	13	9D
0005434186152	28993	14	9E
0005432901344	28993	15	10E
0005432901339	28993	16	11F
0005432901341	28993	17	12A
0005432901333	28993	18	12C
0005432901338	28993	19	13F
0005432901332	28993	20	14A
0005434186150	28993	21	14D
0005432901337	28993	22	16C
0005432901329	28993	23	16E
0005434157359	28993	24	16F
0005432901340	28993	25	17A
0005432901334	28993	26	18E
0005432002044	28993	27	18F
0005434186151	28993	28	19A
0005434157357	28993	29	19E
0005432901343	28993	30	20E
0005432613797	15058	1	1B
0005432611647	15058	2	2A
0005432611650	15058	3	2B
0005432611649	15058	4	3B
0005432613799	15058	5	4A
0005432613800	15058	6	5A
0005432611648	15058	7	4B
0005432613798	15058	8	6A
0005435842314	31644	1	1B
0005435841810	31644	2	4B
0005433568088	11866	1	1A
0005433568084	11866	2	2A
0005433568117	11866	3	2D
0005433568079	11866	4	3C
0005433568102	11866	5	4A
0005433568122	11866	6	4D
0005433568076	11866	7	5F
0005433568087	11866	8	5D
0005433568069	11866	9	6D
0005433568072	11866	10	7C
0005433568090	11866	11	7D
0005433568121	11866	12	7F
0005433568113	11866	13	8B
0005433568112	11866	14	8F
0005433568114	11866	15	9B
0005433568110	11866	16	9A
0005433568104	11866	17	9D
0005433568095	11866	18	9C
0005433568101	11866	19	9F
0005433568085	11866	20	10B
0005433568119	11866	21	10E
0005433568073	11866	22	10D
0005433568107	11866	23	11A
0005433568094	11866	24	11B
0005433568070	11866	25	11D
0005433568118	11866	26	12B
0005433568091	11866	27	12A
0005433568081	11866	28	12C
0005433568086	11866	29	12E
0005433568115	11866	30	13A
0005433568108	11866	31	13C
0005433568093	11866	32	13F
0005433568120	11866	33	14C
0005433568123	11866	34	14E
0005433568099	11866	35	14D
0005433568083	11866	36	15B
0005433568097	11866	37	15E
0005433568071	11866	38	15D
0005433568075	11866	39	16A
0005433568080	11866	40	15F
0005433568089	11866	41	16E
0005433568106	11866	42	16D
0005433568078	11866	43	17A
0005433568100	11866	44	17B
0005433568082	11866	45	17C
0005433568096	11866	46	18A
0005433568109	11866	47	18B
0005433568105	11866	48	18D
0005433568074	11866	49	18F
0005433568111	11866	50	19B
0005433568103	11866	51	19E
0005433568098	11866	52	19C
0005433568092	11866	53	20C
0005433568077	11866	54	21B
0005433568116	11866	55	21F
0005432947850	25328	1	1A
0005432947868	25328	2	1F
0005432947885	25328	3	1C
0005432947873	25328	4	2C
0005432947877	25328	5	2F
0005432947874	25328	6	3D
0005432947855	25328	7	4C
0005432947852	25328	8	6B
0005432947861	25328	9	6A
0005432947860	25328	10	6D
0005432947875	25328	11	6C
0005432947853	25328	12	7C
0005432947872	25328	13	7E
0005432947849	25328	14	7D
0005432947876	25328	15	7F
0005432947883	25328	16	8B
0005432947888	25328	17	8C
0005432947863	25328	18	8E
0005432947882	25328	19	9A
0005432947862	25328	20	9E
0005432947857	25328	21	9D
0005432947856	25328	22	10D
0005432947879	25328	23	10F
0005432947869	25328	24	11B
0005432947866	25328	25	11D
0005432947880	25328	26	11E
0005432947871	25328	27	12B
0005432947847	25328	28	12C
0005432947851	25328	29	12F
0005432947878	25328	30	13C
0005432947864	25328	31	13B
0005432947887	25328	32	13E
0005432947865	25328	33	15D
0005432947858	25328	34	17D
0005432947846	25328	35	18B
0005432947884	25328	36	18D
0005432947867	25328	37	18F
0005432947870	25328	38	19C
0005432947881	25328	39	19B
0005432947848	25328	40	20C
0005432947886	25328	41	20F
0005432947854	25328	42	21B
0005432947859	25328	43	21F
0005434654244	5387	1	1C
0005434654239	5387	2	1F
0005434654225	5387	3	2F
0005434654221	5387	4	3D
0005434654236	5387	5	4F
0005434654228	5387	6	5E
0005434654241	5387	7	7A
0005434654223	5387	8	7F
0005434654230	5387	9	8E
0005434654248	5387	10	8F
0005434654232	5387	11	9F
0005434654240	5387	12	10A
0005434656525	5387	13	10C
0005434654224	5387	14	10D
0005434654243	5387	15	10F
0005432114151	5387	16	11C
0005434654234	5387	17	11E
0005434654235	5387	18	12A
0005434654245	5387	19	12C
0005434654229	5387	20	12D
0005434654231	5387	21	12F
0005434654227	5387	22	13D
0005434654246	5387	23	13F
0005434654226	5387	24	14E
0005432114154	5387	25	14F
0005432114153	5387	26	15C
0005434654222	5387	27	15D
0005434654242	5387	28	16E
0005432114152	5387	29	18A
0005434656524	5387	30	18C
0005434654220	5387	31	18D
0005434654233	5387	32	19A
0005434654238	5387	33	19C
0005434654237	5387	34	19E
0005434654247	5387	35	19F
0005434654219	5387	36	20C
0005435340019	12533	1	3F
0005435555340	12533	2	5F
0005435340024	12533	3	6A
0005435340028	12533	4	6C
0005435340032	12533	5	6D
0005435340029	12533	6	8D
0005435340034	12533	7	9E
0005435340021	12533	8	10A
0005435340023	12533	9	11A
0005435555339	12533	10	11C
0005435555338	12533	11	11D
0005435340026	12533	12	11E
0005435340027	12533	13	12D
0005435340022	12533	14	12E
0005435340025	12533	15	16D
0005435340030	12533	16	17D
0005435340031	12533	17	18A
0005435340020	12533	18	18D
0005435340033	12533	19	19F
0005433715170	7422	1	1A
0005433722113	7422	2	1C
0005433715197	7422	3	1D
0005433722107	7422	4	1F
0005433722109	7422	5	2F
0005433715216	7422	6	3F
0005433715202	7422	7	4A
0005433715179	7422	8	4C
0005433715201	7422	9	4D
0005433715188	7422	10	4E
0005432078019	7422	11	5B
0005433715219	7422	12	5A
0005433715213	7422	13	5D
0005433715194	7422	14	6B
0005432078024	7422	15	6D
0005433715184	7422	16	6F
0005433715168	7422	17	6E
0005433715178	7422	18	7B
0005433722110	7422	19	7E
0005433715186	7422	20	8B
0005433722115	7422	21	8E
0005433722111	7422	22	8D
0005433715173	7422	23	9A
0005433715205	7422	24	9C
0005433715189	7422	25	9B
0005432078023	7422	26	9E
0005433719085	7422	27	10B
0005433715212	7422	28	10D
0005433715176	7422	29	10C
0005433715171	7422	30	10E
0005433715182	7422	31	11B
0005433715180	7422	32	11C
0005433722108	7422	33	11F
0005433715215	7422	34	12A
0005433719084	7422	35	12B
0005433715199	7422	36	12C
0005433715187	7422	37	12E
0005433715191	7422	38	13B
0005433715209	7422	39	13D
0005433715198	7422	40	13F
0005433722112	7422	41	14D
0005433715183	7422	42	14C
0005433690893	7422	43	14E
0005433715172	7422	44	15A
0005433715169	7422	45	15B
0005433719086	7422	46	15C
0005433689877	7422	47	15D
0005433689876	7422	48	15E
0005433715196	7422	49	16E
0005432078021	7422	50	16D
0005433715211	7422	51	17A
0005433715190	7422	52	16F
0005433715203	7422	53	17F
0005433656615	7422	54	18A
0005433656616	7422	55	18C
0005433715217	7422	56	18E
0005433715192	7422	57	18F
0005433715204	7422	58	19C
0005433715218	7422	59	19E
0005433715195	7422	60	19F
0005433715185	7422	61	20A
0005433722117	7422	62	20C
0005433719087	7422	63	20B
0005433688776	7422	64	20D
0005433715177	7422	65	20E
0005433715181	7422	66	21A
0005433715208	7422	67	21C
0005432078022	7422	68	21B
0005433715210	7422	69	21E
0005433715193	7422	70	21F
0005433715200	7422	71	22C
0005433722114	7422	72	22B
0005433715175	7422	73	22D
0005433656617	7422	74	22E
0005432078020	7422	75	23A
0005433715214	7422	76	23B
0005433722116	7422	77	23C
0005433715207	7422	78	23D
0005433715206	7422	79	23F
0005433715174	7422	80	23E
0005432006714	29231	1	3A
0005432006718	29231	2	5A
0005432428874	29231	3	5E
0005432006717	29231	4	7A
0005432428876	29231	5	6F
0005432006715	29231	6	8B
0005432006716	29231	7	14A
0005432428878	29231	8	14C
0005432428877	29231	9	22B
0005432428875	29231	10	22E
0005434095051	8672	1	2D
0005434095054	8672	2	5F
0005434095049	8672	3	7D
0005434095057	8672	4	8A
0005434095048	8672	5	9F
0005434095045	8672	6	10C
0005434095046	8672	7	10D
0005434095052	8672	8	12A
0005434095058	8672	9	12F
0005434095047	8672	10	13C
0005434181964	8672	11	13F
0005434181963	8672	12	14E
0005434095050	8672	13	16A
0005434095053	8672	14	17C
0005434095055	8672	15	18A
0005434095044	8672	16	18E
0005434095056	8672	17	20E
0005434181986	11683	1	1A
0005434181984	11683	2	3C
0005434181993	11683	3	3D
0005434181983	11683	4	5D
0005434181987	11683	5	6D
0005434184632	11683	6	8F
0005434181988	11683	7	9F
0005434181994	11683	8	10F
0005434181990	11683	9	12C
0005434181982	11683	10	14F
0005434181989	11683	11	15A
0005434181992	11683	12	16C
0005434181985	11683	13	16F
0005434183547	11683	14	17A
0005434181991	11683	15	18D
0005434184631	11683	16	19F
0005433456906	1449	1	1C
0005435732145	1449	2	1D
0005433456908	1449	3	1F
0005435732148	1449	4	2A
0005435732137	1449	5	2F
0005433456907	1449	6	3D
0005435732149	1449	7	4A
0005435732140	1449	8	4C
0005435732151	1449	9	4D
0005435732138	1449	10	4E
0005435732135	1449	11	5C
0005435732141	1449	12	6A
0005433456905	1449	13	6D
0005435732131	1449	14	8D
0005435732134	1449	15	8E
0005435732133	1449	16	9D
0005435732129	1449	17	10A
0005435732142	1449	18	10E
0005433397219	1449	19	11A
0005432297235	1449	20	12A
0005435732132	1449	21	12E
0005432297237	1449	22	13D
0005435732144	1449	23	14A
0005435732130	1449	24	14D
0005435732147	1449	25	14F
0005435732146	1449	26	17E
0005435732143	1449	27	18E
0005435732139	1449	28	18F
0005432297236	1449	29	19C
0005435732136	1449	30	19E
0005435732150	1449	31	20A
0005433397327	19260	1	1A
0005433397310	19260	2	1C
0005433397312	19260	3	1D
0005433397324	19260	4	2A
0005433397304	19260	5	2D
0005433397311	19260	6	2F
0005433397296	19260	7	3A
0005433397282	19260	8	3C
0005433397285	19260	9	4C
0005433397306	19260	10	4E
0005433397317	19260	11	4F
0005433397295	19260	12	6A
0005433397318	19260	13	6D
0005433397281	19260	14	6E
0005433397278	19260	15	6F
0005433397279	19260	16	7F
0005433397292	19260	17	8A
0005433397319	19260	18	8C
0005433397287	19260	19	8D
0005433397322	19260	20	8E
0005433397305	19260	21	8F
0005433397299	19260	22	9C
0005433397298	19260	23	9E
0005433397288	19260	24	9F
0005433397316	19260	25	10A
0005433397314	19260	26	10C
0005433397280	19260	27	10F
0005433397326	19260	28	11C
0005433397286	19260	29	11D
0005433397313	19260	30	11F
0005433397315	19260	31	12C
0005433397291	19260	32	12F
0005433397320	19260	33	13A
0005433397321	19260	34	13C
0005433397323	19260	35	13D
0005433397303	19260	36	13F
0005432906496	19260	37	16A
0005433397309	19260	38	16C
0005433397301	19260	39	16E
0005432906497	19260	40	16F
0005433397307	19260	41	17A
0005433397300	19260	42	17C
0005433397302	19260	43	17D
0005433397283	19260	44	17E
0005433397284	19260	45	18C
0005433397308	19260	46	18D
0005433397297	19260	47	19A
0005433397294	19260	48	19C
0005433397293	19260	49	19F
0005433397325	19260	50	20A
0005433397290	19260	51	20D
0005433397289	19260	52	20E
0005434443455	20576	1	1A
0005434443452	20576	2	1C
0005434443454	20576	3	2A
0005434443446	20576	4	3A
0005434443453	20576	5	3B
0005434443451	20576	6	3D
0005434443449	20576	7	4B
0005434443443	20576	8	4D
0005434443447	20576	9	5D
0005434443448	20576	10	6B
0005434443444	20576	11	19B
0005434443440	20576	12	20D
0005434443450	20576	13	21C
0005434443445	20576	14	21D
0005434443442	20576	15	22D
0005434443441	20576	16	23A
0005435377537	7246	1	1B
0005434954546	7246	2	3A
0005434954549	7246	3	4A
0005434954548	7246	4	4B
0005434954547	7246	5	5A
0005434954550	7246	6	6B
0005435377543	28360	1	3B
0005435377542	28360	2	4B
0005435377541	28360	3	6B
0005434351501	4486	1	2B
0005434351493	4486	2	2C
0005434351502	4486	3	2D
0005434351497	4486	4	3B
0005434351499	4486	5	3C
0005434351492	4486	6	4A
0005434351498	4486	7	4B
0005434351491	4486	8	7C
0005434351494	4486	9	19A
0005434351496	4486	10	19B
0005434351490	4486	11	21A
0005434351495	4486	12	21D
0005434351500	4486	13	23A
0005435893521	29685	1	3C
0005435893519	29685	2	4B
0005435893523	29685	3	5B
0005435893522	29685	4	6A
0005435893520	29685	5	7C
0005435893518	29685	6	21B
0005432293170	1050	1	2F
0005435545615	1050	2	12A
0005434445212	1050	3	15G
0005435091922	1050	4	16F
0005435091917	1050	5	17A
0005434446485	1050	6	17D
0005433463867	1050	7	17E
0005435545614	1050	8	17F
0005433462713	1050	9	18B
0005435091921	1050	10	20H
0005435091918	1050	11	20G
0005434445213	1050	12	22B
0005435091914	1050	13	22H
0005435091915	1050	14	23B
0005433463866	1050	15	23A
0005435091920	1050	16	24A
0005435091919	1050	17	27A
0005432293169	1050	18	25F
0005435545613	1050	19	28E
0005435091923	1050	20	31H
0005434446486	1050	21	32A
0005435545616	1050	22	34F
0005434446483	1050	23	37A
0005435091916	1050	24	37E
0005435091913	1050	25	38B
0005434446484	1050	26	38E
0005434446482	1050	27	39E
0005433269633	17031	1	1C
0005433341526	17031	2	1G
0005433341517	17031	3	1H
0005433341497	17031	4	2C
0005433341571	17031	5	2B
0005433341550	17031	6	2F
0005433341480	17031	7	3A
0005433341507	17031	8	3F
0005433341546	17031	9	3C
0005433341523	17031	10	3G
0005433341555	17031	11	4F
0005433341541	17031	12	5C
0005433341529	17031	13	5H
0005433341561	17031	14	9G
0005433159277	17031	15	11B
0005433341494	17031	16	11A
0005433341558	17031	17	11E
0005433269632	17031	18	11G
0005433341481	17031	19	11F
0005433341499	17031	20	11H
0005433341506	17031	21	12D
0005433341537	17031	22	12G
0005433341553	17031	23	12F
0005433341493	17031	24	14H
0005433269631	17031	25	14G
0005433341578	17031	26	15B
0005433341524	17031	27	15F
0005433341569	17031	28	15H
0005433341581	17031	29	16B
0005433341536	17031	30	16F
0005433341522	17031	31	16E
0005433341579	17031	32	17B
0005433341498	17031	33	17D
0005433341514	17031	34	17E
0005433341518	17031	35	17G
0005433341551	17031	36	17H
0005433341580	17031	37	18D
0005433341534	17031	38	18B
0005433341531	17031	39	18E
0005433341491	17031	40	19D
0005433341508	17031	41	19F
0005433341548	17031	42	19H
0005433341503	17031	43	19G
0005433341510	17031	44	20A
0005433341484	17031	45	20D
0005433341485	17031	46	20H
0005433341504	17031	47	20G
0005433269634	17031	48	21E
0005433341511	17031	49	22B
0005433341512	17031	50	22A
0005433341542	17031	51	22D
0005433341502	17031	52	22E
0005433341528	17031	53	22G
0005433341574	17031	54	22H
0005433341545	17031	55	23E
0005433341519	17031	56	23G
0005433341577	17031	57	24E
0005433341554	17031	58	24D
0005433341505	17031	59	24F
0005433341544	17031	60	24H
0005433341488	17031	61	24G
0005433341525	17031	62	25D
0005433341582	17031	63	25F
0005433341532	17031	64	27D
0005433341564	17031	65	27F
0005433341500	17031	66	28A
0005433341576	17031	67	27H
0005433341516	17031	68	28E
0005433341568	17031	69	29B
0005433341549	17031	70	28H
0005433341501	17031	71	29G
0005433341560	17031	72	29H
0005433341492	17031	73	30D
0005433269635	17031	74	30B
0005433341572	17031	75	30F
0005433341557	17031	76	30E
0005433341483	17031	77	31B
0005433341486	17031	78	31D
0005433341515	17031	79	32A
0005433341565	17031	80	32F
0005433159278	17031	81	32G
0005433341575	17031	82	33A
0005433341513	17031	83	33E
0005433341547	17031	84	33D
0005433341482	17031	85	33H
0005433341521	17031	86	33G
0005433341527	17031	87	34B
0005433341496	17031	88	34A
0005433341562	17031	89	34D
0005433341559	17031	90	34F
0005433341563	17031	91	34E
0005433341556	17031	92	34G
0005433341530	17031	93	35A
0005433341540	17031	94	34H
0005433341538	17031	95	35B
0005433341533	17031	96	35E
0005433341495	17031	97	35G
0005433341490	17031	98	35H
0005433341543	17031	99	36G
0005433341566	17031	100	37A
0005433341487	17031	101	37B
0005433341573	17031	102	37D
0005433341539	17031	103	38B
0005433341520	17031	104	38A
0005433341567	17031	105	38E
0005433341552	17031	106	38D
0005433341489	17031	107	38F
0005433341535	17031	108	38G
0005433341570	17031	109	39E
0005433341509	17031	110	39F
0005432389938	1341	1	1C
0005432389958	1341	2	2A
0005432389962	1341	3	2C
0005432391951	1341	4	3A
0005432389935	1341	5	4A
0005432389963	1341	6	3F
0005432389966	1341	7	5F
0005432389942	1341	8	6B
0005432389954	1341	9	6D
0005432389933	1341	10	7B
0005432389936	1341	11	8C
0005432389961	1341	12	8E
0005432389967	1341	13	9C
0005432389956	1341	14	9B
0005432389941	1341	15	10E
0005432389943	1341	16	10D
0005432389934	1341	17	11A
0005432389946	1341	18	11B
0005432391946	1341	19	11C
0005432389944	1341	20	11E
0005432389952	1341	21	12E
0005432389949	1341	22	13B
0005432389939	1341	23	13D
0005432389955	1341	24	15A
0005432389957	1341	25	15E
0005432389945	1341	26	15F
0005432389964	1341	27	16B
0005432391945	1341	28	17A
0005432389959	1341	29	17D
0005432389960	1341	30	17C
0005432389950	1341	31	17E
0005432389951	1341	32	18A
0005432391947	1341	33	18D
0005432389953	1341	34	19C
0005432389948	1341	35	19D
0005432389937	1341	36	19F
0005432389947	1341	37	20B
0005432389965	1341	38	20D
0005432389940	1341	39	20E
0005432391950	1341	40	21C
0005432391949	1341	41	21E
0005432391948	1341	42	21F
0005432159784	12786	1	1C
0005432159786	12786	2	1F
0005432433597	12786	3	2D
0005432159785	12786	4	3A
0005432433593	12786	5	4B
0005432159787	12786	6	5B
0005432161116	12786	7	7B
0005432433594	12786	8	9F
0005433812863	12786	9	16C
0005433812862	12786	10	18D
0005432433595	12786	11	20F
0005432433596	12786	12	21A
0005432161115	12786	13	22B
0005432161114	12786	14	23E
0005432150064	30689	1	1D
0005434066407	30689	2	1C
0005432150066	30689	3	1A
0005434081509	30689	4	1F
0005434066410	30689	5	2C
0005434081498	30689	6	2A
0005434081504	30689	7	2D
0005434066417	30689	8	2F
0005434081487	30689	9	3C
0005434081520	30689	10	3A
0005432150070	30689	11	3F
0005433989690	30689	12	4B
0005434081495	30689	13	4C
0005434066427	30689	14	4D
0005432150067	30689	15	4F
0005434081505	30689	16	4E
0005434081511	30689	17	5A
0005434066383	30689	18	5B
0005434066411	30689	19	5D
0005434066423	30689	20	5C
0005434066430	30689	21	5F
0005434081496	30689	22	5E
0005434081512	30689	23	6A
0005432186808	30689	24	6B
0005434081490	30689	25	6C
0005434066387	30689	26	6D
0005434066436	30689	27	6E
0005434066385	30689	28	6F
0005434066439	30689	29	7B
0005434081507	30689	30	7A
0005434066429	30689	31	7C
0005434066416	30689	32	7D
0005434081497	30689	33	7F
0005434066425	30689	34	7E
0005434066406	30689	35	8A
0005434066400	30689	36	8B
0005434066379	30689	37	8C
0005434066396	30689	38	8D
0005433989694	30689	39	8F
0005434066434	30689	40	8E
0005434066402	30689	41	9A
0005434066403	30689	42	9B
0005434066369	30689	43	9C
0005434066432	30689	44	9D
0005434081513	30689	45	9F
0005434081493	30689	46	10B
0005434066422	30689	47	10D
0005434066404	30689	48	10C
0005434066386	30689	49	10E
0005434081508	30689	50	11A
0005434066375	30689	51	11B
0005433989692	30689	52	11C
0005434081499	30689	53	11D
0005434066437	30689	54	11F
0005434066392	30689	55	11E
0005434066367	30689	56	12A
0005434066426	30689	57	12B
0005434066412	30689	58	12C
0005434081500	30689	59	12E
0005434066389	30689	60	12F
0005434081510	30689	61	13B
0005434066397	30689	62	13A
0005434066408	30689	63	13C
0005434066413	30689	64	13D
0005434066368	30689	65	13E
0005434081515	30689	66	13F
0005434066409	30689	67	14A
0005434066380	30689	68	14C
0005434066390	30689	69	14B
0005434066415	30689	70	14D
0005434066435	30689	71	14E
0005434066421	30689	72	14F
0005434066393	30689	73	15A
0005433989693	30689	74	15C
0005434081503	30689	75	15B
0005434066428	30689	76	15E
0005432150065	30689	77	15D
0005434066395	30689	78	15F
0005434066414	30689	79	16B
0005432150063	30689	80	16C
0005434066424	30689	81	16D
0005434066370	30689	82	16F
0005434081514	30689	83	16E
0005434066377	30689	84	17A
0005434066431	30689	85	17B
0005434081491	30689	86	17C
0005434066391	30689	87	17E
0005434066378	30689	88	17D
0005432150069	30689	89	17F
0005434066381	30689	90	18A
0005434066388	30689	91	18B
0005432150068	30689	92	18C
0005434081488	30689	93	18D
0005434066405	30689	94	18F
0005434081506	30689	95	18E
0005434081489	30689	96	19A
0005434066371	30689	97	19B
0005434081519	30689	98	19D
0005434081494	30689	99	19C
0005434066394	30689	100	19E
0005434066419	30689	101	19F
0005434066418	30689	102	20B
0005434081492	30689	103	20A
0005434081501	30689	104	20C
0005434066384	30689	105	20E
0005434066438	30689	106	20D
0005434066373	30689	107	20F
0005434081517	30689	108	21B
0005434066399	30689	109	21A
0005434066374	30689	110	21C
0005434066420	30689	111	21D
0005433989691	30689	112	21E
0005434066398	30689	113	21F
0005434066382	30689	114	22A
0005432186810	30689	115	22B
0005434081516	30689	116	22E
0005434066433	30689	117	22D
0005434066376	30689	118	23A
0005434066401	30689	119	22F
0005434081502	30689	120	23B
0005432186807	30689	121	23C
0005434081518	30689	122	23E
0005434066372	30689	123	23D
0005432186809	30689	124	23F
0005435765234	5507	1	1A
0005435765237	5507	2	1C
0005435765287	5507	3	2A
0005435765222	5507	4	1H
0005435765221	5507	5	2G
0005435765267	5507	6	3A
0005435765220	5507	7	3B
0005435765275	5507	8	3F
0005435735060	5507	9	3C
0005435720806	5507	10	3G
0005435765230	5507	11	3H
0005432140315	5507	12	4B
0005435765266	5507	13	4C
0005435765274	5507	14	4H
0005435765257	5507	15	5C
0005435722019	5507	16	5G
0005435765235	5507	17	5F
0005435765270	5507	18	9G
0005432140317	5507	19	11E
0005435720804	5507	20	12A
0005435720805	5507	21	12B
0005435765240	5507	22	12E
0005433527209	5507	23	13B
0005435765223	5507	24	13A
0005435765271	5507	25	13D
0005433529219	5507	26	13E
0005433529220	5507	27	13F
0005435765286	5507	28	13H
0005432140322	5507	29	14B
0005435765268	5507	30	14E
0005435765279	5507	31	14G
0005435765219	5507	32	15D
0005435765254	5507	33	15F
0005432140319	5507	34	15H
0005435765278	5507	35	16B
0005435765285	5507	36	16F
0005435720803	5507	37	16G
0005435765248	5507	38	17B
0005435765226	5507	39	17D
0005435765233	5507	40	17E
0005435735062	5507	41	17G
0005435765288	5507	42	18A
0005435765249	5507	43	18G
0005435765250	5507	44	19F
0005435765283	5507	45	19E
0005435725517	5507	46	19G
0005435765215	5507	47	20A
0005435765277	5507	48	20B
0005435765264	5507	49	20D
0005435765261	5507	50	20H
0005435765252	5507	51	21E
0005435765262	5507	52	21F
0005435765258	5507	53	21H
0005435765218	5507	54	22A
0005435735064	5507	55	22D
0005435765280	5507	56	22E
0005433529221	5507	57	22G
0005435765253	5507	58	23A
0005432140318	5507	59	23E
0005435765229	5507	60	23D
0005435723012	5507	61	23H
0005435765260	5507	62	24A
0005435723011	5507	63	24D
0005435722017	5507	64	24F
0005435725519	5507	65	25D
0005435765265	5507	66	24H
0005435725518	5507	67	25F
0005435765225	5507	68	25E
0005435722018	5507	69	27G
0005435765269	5507	70	28D
0005433527208	5507	71	28E
0005435765259	5507	72	28H
0005435765236	5507	73	29A
0005435765256	5507	74	29D
0005432140321	5507	75	29B
0005435765255	5507	76	30B
0005435765241	5507	77	30A
0005435765244	5507	78	30D
0005435765243	5507	79	30E
0005433527207	5507	80	30G
0005435735061	5507	81	30F
0005435765284	5507	82	31A
0005432140316	5507	83	31B
0005435765232	5507	84	31E
0005435765239	5507	85	31D
0005435765238	5507	86	31F
0005435765245	5507	87	31G
0005435765231	5507	88	31H
0005435765276	5507	89	32B
0005435765251	5507	90	32F
0005435765272	5507	91	32E
0005433527210	5507	92	32G
0005435765228	5507	93	32H
0005435765227	5507	94	33E
0005435765282	5507	95	33D
0005435765273	5507	96	33F
0005435765246	5507	97	33H
0005435765247	5507	98	34D
0005435765242	5507	99	34G
0005435765263	5507	100	34F
0005435765281	5507	101	34H
0005435765216	5507	102	36B
0005435725520	5507	103	36G
0005432140320	5507	104	37E
0005435735063	5507	105	38B
0005435765224	5507	106	38E
0005435765217	5507	107	39F
0005432535756	13451	1	1B
0005434264733	13451	2	1H
0005432194445	13451	3	1G
0005434264731	13451	4	2F
0005435461847	13451	5	3A
0005434264728	13451	6	3G
0005435461835	13451	7	3F
0005434264750	13451	8	4A
0005435461855	13451	9	5G
0005435461857	13451	10	5F
0005434264742	13451	11	9B
0005434264748	13451	12	9G
0005435461858	13451	13	11A
0005435461865	13451	14	11D
0005435461843	13451	15	11G
0005435461868	13451	16	12B
0005435461862	13451	17	12E
0005434264744	13451	18	12H
0005435461844	13451	19	12G
0005434264738	13451	20	13A
0005435461852	13451	21	13B
0005435461853	13451	22	13E
0005434264743	13451	23	14D
0005435461860	13451	24	14F
0005434264734	13451	25	14E
0005434264753	13451	26	14G
0005435043274	13451	27	15B
0005435461842	13451	28	15E
0005435461845	13451	29	15D
0005435043273	13451	30	16E
0005434264739	13451	31	18F
0005435461833	13451	32	18G
0005435461854	13451	33	18H
0005434831079	13451	34	19E
0005434831078	13451	35	20D
0005434831081	13451	36	20E
0005434264740	13451	37	20G
0005435461872	13451	38	21D
0005434264735	13451	39	21E
0005434264732	13451	40	21G
0005432535758	13451	41	22E
0005434264729	13451	42	22G
0005435043275	13451	43	23E
0005435461859	13451	44	23G
0005434264746	13451	45	24A
0005435461863	13451	46	24D
0005434264749	13451	47	24G
0005435461838	13451	48	25D
0005435461848	13451	49	27B
0005435461870	13451	50	27D
0005434264752	13451	51	28B
0005432535759	13451	52	28F
0005435461839	13451	53	29D
0005435461849	13451	54	29B
0005432535757	13451	55	29G
0005434831077	13451	56	29H
0005435461840	13451	57	30D
0005432194446	13451	58	31B
0005432194444	13451	59	31A
0005435461867	13451	60	31H
0005435461834	13451	61	32B
0005435461837	13451	62	32E
0005434264747	13451	63	32G
0005434264751	13451	64	32H
0005435461866	13451	65	33A
0005434264737	13451	66	33G
0005435461856	13451	67	34B
0005435461836	13451	68	34A
0005435461846	13451	69	34D
0005434264730	13451	70	34G
0005432194447	13451	71	35B
0005435461871	13451	72	35A
0005434831076	13451	73	35H
0005435461841	13451	74	36B
0005434264736	13451	75	36E
0005435461861	13451	76	36D
0005434264741	13451	77	36F
0005435461869	13451	78	36G
0005434264745	13451	79	37A
0005435461850	13451	80	37E
0005434831080	13451	81	37H
0005435461851	13451	82	38D
0005435461864	13451	83	38G
0005434513537	18735	1	1A
0005434514925	18735	2	2B
0005434513536	18735	3	3A
0005434514924	18735	4	5B
0005435846195	25092	1	5F
0005435846194	25092	2	6C
0005435846197	25092	3	8D
0005435846199	25092	4	9F
0005435846192	25092	5	10D
0005435846196	25092	6	12A
0005435846198	25092	7	15E
0005435846193	25092	8	18A
0005432295838	1846	1	3C
0005433810494	1846	2	11D
0005433810493	1846	3	14A
0005433810495	1846	4	15E
0005432295839	1846	5	16F
0005433007907	22565	1	1A
0005433007888	22565	2	1D
0005433284803	22565	3	1F
0005433284806	22565	4	2A
0005433007910	22565	5	2D
0005433284810	22565	6	3A
0005433007909	22565	7	3C
0005433007900	22565	8	3F
0005433284813	22565	9	4D
0005433007897	22565	10	4F
0005433007878	22565	11	5A
0005433007872	22565	12	5C
0005433007871	22565	13	5D
0005433284808	22565	14	5E
0005433007882	22565	15	5F
0005433007895	22565	16	6C
0005433007911	22565	17	6D
0005433284818	22565	18	6E
0005433007874	22565	19	6F
0005433007912	22565	20	7C
0005433007913	22565	21	7D
0005433007903	22565	22	7E
0005433007886	22565	23	7F
0005433284812	22565	24	8A
0005433284804	22565	25	8C
0005433284798	22565	26	8D
0005433007902	22565	27	9A
0005433007870	22565	28	9C
0005433284815	22565	29	9E
0005433284795	22565	30	10A
0005433007914	22565	31	10C
0005433284802	22565	32	10D
0005433007875	22565	33	10E
0005433007883	22565	34	10F
0005433007908	22565	35	11A
0005433007879	22565	36	11D
0005433007898	22565	37	11E
0005433007881	22565	38	11F
0005433007904	22565	39	12A
0005433284797	22565	40	12D
0005433284801	22565	41	12E
0005433284807	22565	42	12F
0005433284800	22565	43	13A
0005433007891	22565	44	13C
0005433007901	22565	45	13D
0005433284817	22565	46	13E
0005433007896	22565	47	13F
0005433007884	22565	48	14A
0005433284811	22565	49	14C
0005433007905	22565	50	14D
0005433284805	22565	51	14E
0005433007869	22565	52	15A
0005433007876	22565	53	15D
0005433284819	22565	54	15E
0005433007880	22565	55	15F
0005433007906	22565	56	16A
0005433007877	22565	57	16C
0005433007894	22565	58	16F
0005433007873	22565	59	17A
0005433284816	22565	60	17C
0005433007885	22565	61	17E
0005433007887	22565	62	17F
0005433007889	22565	63	18A
0005433284814	22565	64	18D
0005433007893	22565	65	18F
0005433007892	22565	66	19A
0005433007890	22565	67	19C
0005433284809	22565	68	19E
0005433284796	22565	69	19F
0005433007899	22565	70	20A
0005433284799	22565	71	20D
0005433007868	22565	72	20E
0005433284820	22565	73	20F
0005434152757	12285	1	3A
0005434152751	12285	2	5A
0005434152754	12285	3	6A
0005434152752	12285	4	10A
0005434152756	12285	5	10C
0005434152753	12285	6	11A
0005434152759	12285	7	12C
0005434152755	12285	8	19F
0005434152758	12285	9	20F
0005433845820	5596	1	1C
0005433845814	5596	2	1A
0005432081410	5596	3	1F
0005433845819	5596	4	2C
0005433845836	5596	5	2A
0005433845796	5596	6	2F
0005433845823	5596	7	3D
0005433845826	5596	8	3F
0005433815307	5596	9	4D
0005433845808	5596	10	4C
0005433845797	5596	11	4F
0005433845831	5596	12	5A
0005432081407	5596	13	5F
0005432081413	5596	14	5D
0005433845807	5596	15	6D
0005433845839	5596	16	6E
0005433845815	5596	17	7C
0005433845813	5596	18	7E
0005433845828	5596	19	7D
0005433845818	5596	20	8A
0005433845821	5596	21	8F
0005433845789	5596	22	9D
0005433845783	5596	23	9C
0005433845834	5596	24	9F
0005433845794	5596	25	9E
0005433845799	5596	26	10A
0005433845829	5596	27	10C
0005433845842	5596	28	10B
0005433845812	5596	29	10E
0005433845809	5596	30	10D
0005433845803	5596	31	11A
0005433845801	5596	32	10F
0005433845805	5596	33	11D
0005433845840	5596	34	11F
0005433845788	5596	35	12A
0005433845835	5596	36	12E
0005433845784	5596	37	12D
0005433845804	5596	38	13B
0005433845827	5596	39	12F
0005433845837	5596	40	13C
0005433845790	5596	41	13D
0005432081412	5596	42	13F
0005433845822	5596	43	14D
0005433845833	5596	44	14C
0005433845798	5596	45	14F
0005433845786	5596	46	15B
0005433815309	5596	47	15A
0005432081409	5596	48	15C
0005433845841	5596	49	15E
0005433845810	5596	50	15D
0005433845793	5596	51	16C
0005433845830	5596	52	16B
0005433845787	5596	53	16D
0005433845817	5596	54	17A
0005433845824	5596	55	16E
0005432081408	5596	56	17C
0005433845806	5596	57	17E
0005433845816	5596	58	18B
0005433845838	5596	59	18C
0005433845792	5596	60	18F
0005433845802	5596	61	18E
0005433815306	5596	62	19C
0005433845800	5596	63	19B
0005433845795	5596	64	19E
0005433815308	5596	65	19F
0005433845785	5596	66	20D
0005433845791	5596	67	20E
0005433845825	5596	68	21C
0005432081411	5596	69	21B
0005433845811	5596	70	21E
0005433845832	5596	71	21F
0005435282119	13836	1	3D
0005435282100	13836	2	4C
0005435282105	13836	3	6A
0005432003653	13836	4	6F
0005435282103	13836	5	6E
0005435282108	13836	6	7C
0005435282113	13836	7	8A
0005435282114	13836	8	9E
0005435282121	13836	9	10A
0005435282102	13836	10	10C
0005435282111	13836	11	11A
0005434173459	13836	12	11B
0005435282120	13836	13	11E
0005434173458	13836	14	12B
0005435282099	13836	15	12E
0005432003652	13836	16	13A
0005435282118	13836	17	13B
0005434173456	13836	18	14A
0005435282112	13836	19	14E
0005435282096	13836	20	15C
0005435282101	13836	21	15B
0005435282110	13836	22	15E
0005435282115	13836	23	16A
0005432003654	13836	24	15F
0005435282097	13836	25	16E
0005435282117	13836	26	16D
0005435282116	13836	27	17A
0005435282106	13836	28	16F
0005435282098	13836	29	17B
0005435282123	13836	30	17D
0005432003651	13836	31	18B
0005435282122	13836	32	18C
0005435282107	13836	33	19C
0005435282104	13836	34	20F
0005434173457	13836	35	21C
0005432003655	13836	36	21D
0005435282109	13836	37	21F
0005434620274	7815	1	1B
0005434620282	7815	2	3A
0005434620272	7815	3	3C
0005434620270	7815	4	3D
0005434620268	7815	5	4A
0005434620276	7815	6	4D
0005434620275	7815	7	5A
0005434620265	7815	8	5C
0005434620281	7815	9	5D
0005434620269	7815	10	6A
0005434620273	7815	11	6B
0005434620284	7815	12	6D
0005432112481	7815	13	18C
0005434620271	7815	14	18D
0005434620266	7815	15	19A
0005434620279	7815	16	20D
0005434620283	7815	17	21D
0005434620277	7815	18	22A
0005434620267	7815	19	22B
0005434620264	7815	20	22C
0005432112480	7815	21	22D
0005434620278	7815	22	23A
0005434620280	7815	23	23B
0005435332170	32978	1	2B
0005435332168	32978	2	3B
0005435332173	32978	3	5C
0005435332172	32978	4	6D
0005435332169	32978	5	18C
0005435332175	32978	6	19A
0005435332171	32978	7	21A
0005435332174	32978	8	21B
0005435332176	32978	9	21C
0005435332177	32978	10	22C
0005435784808	4285	1	1D
0005435784804	4285	2	2C
0005435784821	4285	3	2D
0005435784827	4285	4	3D
0005435784807	4285	5	3F
0005435784799	4285	6	4C
0005434993872	4285	7	4E
0005435784805	4285	8	5C
0005435784829	4285	9	5E
0005435784809	4285	10	6C
0005435784819	4285	11	6D
0005435784824	4285	12	7A
0005435784820	4285	13	7E
0005435784831	4285	14	8A
0005435784811	4285	15	8D
0005435784816	4285	16	9A
0005435784814	4285	17	9C
0005435784832	4285	18	9E
0005434993865	4285	19	10A
0005434993874	4285	20	10C
0005434993869	4285	21	10D
0005435784815	4285	22	10E
0005432190570	4285	23	11C
0005435784801	4285	24	12A
0005435784806	4285	25	12C
0005434993870	4285	26	12D
0005435784800	4285	27	12F
0005435784818	4285	28	13C
0005435784825	4285	29	13F
0005434993867	4285	30	14C
0005435784830	4285	31	15C
0005434993875	4285	32	15D
0005435784817	4285	33	15E
0005435784812	4285	34	15F
0005435787323	4285	35	16A
0005435784810	4285	36	16C
0005435787322	4285	37	16D
0005435784822	4285	38	16E
0005435784823	4285	39	17D
0005432190568	4285	40	17F
0005435784828	4285	41	18A
0005434993871	4285	42	18D
0005434993873	4285	43	18E
0005432190569	4285	44	19A
0005435784826	4285	45	19C
0005435784813	4285	46	19D
0005434993866	4285	47	19E
0005435784802	4285	48	19F
0005434993868	4285	49	20A
0005435784833	4285	50	20D
0005435784803	4285	51	20F
0005435918581	27290	1	2A
0005435918580	27290	2	2C
0005432195659	27290	3	3F
0005432195658	27290	4	4F
0005435937316	27290	5	6C
0005435937315	27290	6	7A
0005435918582	27290	7	9A
0005435937318	27290	8	11E
0005435918579	27290	9	12A
0005435937317	27290	10	13F
0005435918583	27290	11	14A
0005435937314	27290	12	14C
0005432146166	19858	1	20B
0005432459054	4705	1	1A
0005434081531	4705	2	1C
0005432170279	4705	3	1H
0005432170281	4705	4	2B
0005432170278	4705	5	2F
0005434081538	4705	6	2G
0005432170283	4705	7	3A
0005432566708	4705	8	2H
0005432571261	4705	9	3B
0005432566661	4705	10	3C
0005432459032	4705	11	3G
0005432459038	4705	12	4A
0005432566681	4705	13	3H
0005434081539	4705	14	4B
0005432566687	4705	15	4G
0005432186811	4705	16	4H
0005434081549	4705	17	5B
0005432459015	4705	18	5A
0005434081526	4705	19	5F
0005432566690	4705	20	5C
0005432566682	4705	21	5G
0005432566684	4705	22	5H
0005432566657	4705	23	9B
0005433452707	4705	24	9A
0005432459016	4705	25	9G
0005432566664	4705	26	9H
0005432566702	4705	27	11G
0005432459010	4705	28	11F
0005432459027	4705	29	11E
0005432459035	4705	30	11H
0005432566700	4705	31	12A
0005432459050	4705	32	12D
0005432459037	4705	33	12B
0005432566653	4705	34	12E
0005434081525	4705	35	12H
0005432566674	4705	36	13A
0005432566656	4705	37	13D
0005432459033	4705	38	13E
0005432459030	4705	39	13G
0005434081544	4705	40	13H
0005432459029	4705	41	14B
0005434081536	4705	42	14E
0005433451588	4705	43	14D
0005432459055	4705	44	14G
0005434081541	4705	45	15A
0005432566695	4705	46	15B
0005432459043	4705	47	15D
0005432186812	4705	48	15F
0005432566678	4705	49	15E
0005432459062	4705	50	15H
0005432566703	4705	51	16B
0005432459013	4705	52	16A
0005434081546	4705	53	16D
0005432566677	4705	54	16F
0005432459040	4705	55	16G
0005434081540	4705	56	17B
0005432566706	4705	57	17A
0005432566676	4705	58	17D
0005432459057	4705	59	17E
0005432459046	4705	60	17G
0005434081521	4705	61	17F
0005432566671	4705	62	17H
0005432566683	4705	63	18B
0005432566693	4705	64	18A
0005432459023	4705	65	18E
0005434081534	4705	66	18D
0005434081543	4705	67	18G
0005434081547	4705	68	19A
0005432566712	4705	69	19B
0005432170280	4705	70	19E
0005432566651	4705	71	19F
0005432566663	4705	72	19G
0005432566705	4705	73	20A
0005432566699	4705	74	20B
0005432459017	4705	75	20D
0005433726067	4705	76	20G
0005432566679	4705	77	20F
0005432459028	4705	78	21A
0005432459025	4705	79	20H
0005432566692	4705	80	21D
0005432459060	4705	81	21B
0005432459044	4705	82	21G
0005432566696	4705	83	21F
0005432459022	4705	84	21H
0005432566710	4705	85	22A
0005432459056	4705	86	22E
0005432566697	4705	87	22H
0005432459026	4705	88	23B
0005434081528	4705	89	23A
0005432566673	4705	90	23D
0005432566652	4705	91	23F
0005432459048	4705	92	23E
0005432566701	4705	93	23G
0005434081523	4705	94	24B
0005432566670	4705	95	24A
0005434081542	4705	96	24E
0005432571263	4705	97	24D
0005432459014	4705	98	24F
0005433452706	4705	99	24G
0005432459020	4705	100	25D
0005433451587	4705	101	25E
0005432459011	4705	102	27A
0005432459012	4705	103	27D
0005432459051	4705	104	27B
0005432566658	4705	105	27F
0005432170282	4705	106	27E
0005432459047	4705	107	27H
0005432566711	4705	108	27G
0005432566689	4705	109	28A
0005432566659	4705	110	28B
0005434081529	4705	111	28E
0005432566655	4705	112	28D
0005432459031	4705	113	28F
0005432459036	4705	114	28H
0005434081535	4705	115	28G
0005432566704	4705	116	29A
0005432459053	4705	117	29D
0005432566707	4705	118	29B
0005432459019	4705	119	29E
0005432459058	4705	120	29G
0005432566669	4705	121	29F
0005432459021	4705	122	29H
0005432459041	4705	123	30B
0005432459024	4705	124	30D
0005432459059	4705	125	30E
0005434081530	4705	126	30G
0005432459039	4705	127	30F
0005432566672	4705	128	31A
0005432459042	4705	129	30H
0005432566665	4705	130	31B
0005432170284	4705	131	31E
0005432186813	4705	132	31D
0005434081545	4705	133	31F
0005432459018	4705	134	31H
0005434081550	4705	135	31G
0005432566688	4705	136	32E
0005432566666	4705	137	32D
0005432186814	4705	138	32H
0005434081527	4705	139	33A
0005432566698	4705	140	33D
0005432566660	4705	141	33F
0005434081524	4705	142	34A
0005434081537	4705	143	34D
0005432566709	4705	144	34B
0005432459052	4705	145	34E
0005432571262	4705	146	34G
0005432566686	4705	147	35B
0005432566694	4705	148	35D
0005434081533	4705	149	35F
0005434081548	4705	150	35G
0005432459049	4705	151	36A
0005434081532	4705	152	35H
0005432459045	4705	153	36B
0005432566691	4705	154	36F
0005434081522	4705	155	36E
0005432566680	4705	156	36G
0005432566668	4705	157	36H
0005432566685	4705	158	37B
0005432566654	4705	159	37D
0005433726069	4705	160	37F
0005432459034	4705	161	38A
0005432566675	4705	162	38B
0005432566667	4705	163	38E
0005432566662	4705	164	38G
0005432459061	4705	165	38F
0005433726068	4705	166	39E
0005432213546	30559	1	1C
0005432213547	30559	2	4F
0005432213549	30559	3	23H
0005432161114	30559	4	29G
0005432213548	30559	5	30A
0005432161115	30559	6	33D
0005432161116	30559	7	38F
0005435720805	13618	1	1B
0005435722018	13618	2	2B
0005435720803	13618	3	3B
0005435720804	13618	4	4A
0005435722019	13618	5	5A
0005435722017	13618	6	6A
0005435720806	13618	7	6B
0005432295838	22779	1	7D
0005432295839	22779	2	18A
0005433341645	11079	1	1C
0005433341680	11079	2	1D
0005433341601	11079	3	1F
0005433341661	11079	4	2A
0005435097058	11079	5	2D
0005433341666	11079	6	3A
0005433341646	11079	7	2F
0005433341608	11079	8	3C
0005433341596	11079	9	3F
0005433341595	11079	10	3D
0005433341616	11079	11	4C
0005433341617	11079	12	4B
0005433341642	11079	13	4E
0005433341648	11079	14	4F
0005433341650	11079	15	5B
0005433341638	11079	16	5A
0005433341583	11079	17	5C
0005433341618	11079	18	5D
0005433341677	11079	19	5E
0005433341673	11079	20	6A
0005433341678	11079	21	5F
0005433341637	11079	22	6B
0005433341656	11079	23	6D
0005433341681	11079	24	6E
0005433341667	11079	25	7A
0005433341647	11079	26	6F
0005433341672	11079	27	7B
0005433341633	11079	28	7C
0005433341652	11079	29	7D
0005433341599	11079	30	7F
0005433341655	11079	31	7E
0005433341603	11079	32	8C
0005433341622	11079	33	8D
0005435097059	11079	34	8F
0005433341620	11079	35	8E
0005433341636	11079	36	9A
0005433341671	11079	37	9B
0005433341676	11079	38	9D
0005433341659	11079	39	9C
0005433341590	11079	40	9E
0005433341589	11079	41	10C
0005435097053	11079	42	10B
0005433341682	11079	43	10D
0005433341651	11079	44	10E
0005433341594	11079	45	11A
0005433341598	11079	46	11B
0005433341630	11079	47	11D
0005433341613	11079	48	11C
0005433341624	11079	49	11E
0005433341629	11079	50	11F
0005433341649	11079	51	12A
0005435097052	11079	52	12B
0005433341597	11079	53	12C
0005433341610	11079	54	12E
0005435097056	11079	55	12F
0005433341658	11079	56	13A
0005433341611	11079	57	13B
0005433341607	11079	58	13D
0005433341631	11079	59	13C
0005433341587	11079	60	13E
0005433341621	11079	61	13F
0005433341604	11079	62	14B
0005433341668	11079	63	14A
0005433341593	11079	64	14C
0005433341606	11079	65	14D
0005433341644	11079	66	14F
0005433341632	11079	67	15A
0005433341614	11079	68	15C
0005433341635	11079	69	15B
0005435097057	11079	70	15D
0005433341584	11079	71	15E
0005433341665	11079	72	15F
0005433341628	11079	73	16B
0005433341634	11079	74	16A
0005433341679	11079	75	16E
0005433341663	11079	76	16D
0005433341605	11079	77	16F
0005433341653	11079	78	17B
0005433341627	11079	79	17C
0005433341625	11079	80	17D
0005433341641	11079	81	17E
0005433341600	11079	82	18A
0005435097055	11079	83	17F
0005433341602	11079	84	18B
0005433341623	11079	85	18D
0005433341615	11079	86	18E
0005433341669	11079	87	19B
0005433341683	11079	88	19A
0005433341674	11079	89	19C
0005433341662	11079	90	19D
0005433341643	11079	91	20A
0005433341640	11079	92	20B
0005433341619	11079	93	20D
0005433341639	11079	94	20C
0005435097054	11079	95	20E
0005433341592	11079	96	21A
0005433341660	11079	97	21C
0005433341586	11079	98	21F
0005433341670	11079	99	21E
0005433341654	11079	100	22A
0005433341591	11079	101	22C
0005433341609	11079	102	22B
0005433341664	11079	103	23A
0005433341657	11079	104	22F
0005433341626	11079	105	23B
0005433341612	11079	106	23D
0005433341588	11079	107	23C
0005433341675	11079	108	23E
0005433341585	11079	109	23F
0005432293170	17107	1	5A
0005432293169	17107	2	7A
0005435545614	17107	3	8E
0005435545613	17107	4	10C
0005435380227	17107	5	14A
0005435545616	17107	6	15B
0005435380226	17107	7	16D
0005435380224	17107	8	17E
0005435380225	17107	9	20B
0005435545615	17107	10	21C
0005433481047	9085	1	1C
0005433506909	9085	2	1D
0005433506911	9085	3	1F
0005433506908	9085	4	3A
0005433506897	9085	5	3D
0005433481048	9085	6	4A
0005433506898	9085	7	5F
0005433481045	9085	8	6E
0005433506893	9085	9	9A
0005433506910	9085	10	9C
0005433506896	9085	11	10F
0005433506903	9085	12	11D
0005433506891	9085	13	11E
0005433506895	9085	14	11F
0005433506904	9085	15	12A
0005433506892	9085	16	13C
0005433506906	9085	17	13D
0005433481049	9085	18	13E
0005433506902	9085	19	14A
0005433481044	9085	20	14F
0005433506901	9085	21	15C
0005433506905	9085	22	15E
0005433481046	9085	23	16C
0005433506894	9085	24	18C
0005433481050	9085	25	18D
0005433506899	9085	26	18E
0005433506900	9085	27	19E
0005433506907	9085	28	20D
0005432919558	20475	1	1F
0005432919550	20475	2	2A
0005432919565	20475	3	3F
0005432919548	20475	4	4E
0005434158950	20475	5	4F
0005432919555	20475	6	5D
0005432919564	20475	7	6A
0005434158949	20475	8	6C
0005432919566	20475	9	7E
0005432919551	20475	10	8A
0005432919562	20475	11	8D
0005432919559	20475	12	8E
0005432919557	20475	13	9A
0005432919561	20475	14	9F
0005432919553	20475	15	10C
0005434158947	20475	16	12D
0005432919560	20475	17	13C
0005434158948	20475	18	13F
0005432919549	20475	19	14A
0005432919547	20475	20	14E
0005432919554	20475	21	15D
0005432919552	20475	22	16A
0005432919546	20475	23	18D
0005432919563	20475	24	19A
0005432919556	20475	25	20C
0005432394036	10164	1	1A
0005432394037	10164	2	1B
0005432396178	10164	3	2B
0005432396175	10164	4	3A
0005432394038	10164	5	3B
0005432396176	10164	6	4B
0005432396177	10164	7	5B
0005432394039	10164	8	6B
0005435179384	18304	1	1B
0005435179688	18304	2	3B
0005435179383	18304	3	6B
0005434928257	10935	1	3C
0005434411713	10935	2	4E
0005434928255	10935	3	4F
0005434411714	10935	4	5A
0005434411712	10935	5	10F
0005434411711	10935	6	15F
0005434928256	10935	7	16A
0005434411710	10935	8	17E
0005434928254	10935	9	19A
0005435125740	14726	1	1C
0005435554112	14726	2	1D
0005435125732	14726	3	2C
0005435125765	14726	4	2D
0005435125735	14726	5	2F
0005435125739	14726	6	3A
0005435125748	14726	7	3C
0005435125753	14726	8	3F
0005435125771	14726	9	4D
0005435125733	14726	10	4E
0005435125744	14726	11	4F
0005435625909	14726	12	5A
0005435125760	14726	13	5C
0005435125734	14726	14	5F
0005435125743	14726	15	6A
0005435625911	14726	16	6C
0005435554109	14726	17	6D
0005435125756	14726	18	7A
0005435625906	14726	19	7C
0005435556653	14726	20	7D
0005435625908	14726	21	8C
0005435125761	14726	22	8D
0005435554110	14726	23	9A
0005435625904	14726	24	9C
0005435625902	14726	25	9E
0005435125736	14726	26	10A
0005435125755	14726	27	10C
0005435125730	14726	28	10D
0005435625905	14726	29	10E
0005435125768	14726	30	11A
0005435125737	14726	31	11C
0005435625900	14726	32	11F
0005435125759	14726	33	12C
0005435125751	14726	34	12D
0005435554111	14726	35	13D
0005435556651	14726	36	13E
0005435125754	14726	37	13F
0005435625912	14726	38	14E
0005435556652	14726	39	14F
0005435625903	14726	40	15A
0005435125747	14726	41	15C
0005435554108	14726	42	15D
0005435125752	14726	43	15E
0005435125749	14726	44	16A
0005435125763	14726	45	16C
0005435125764	14726	46	16E
0005435125766	14726	47	16F
0005435125769	14726	48	17A
0005435125746	14726	49	17C
0005435125767	14726	50	17D
0005435125745	14726	51	17E
0005435125731	14726	52	17F
0005435125741	14726	53	18A
0005435125770	14726	54	18D
0005435125742	14726	55	18E
0005435125762	14726	56	19A
0005435125738	14726	57	19C
0005435625901	14726	58	19D
0005435625910	14726	59	19E
0005435625907	14726	60	19F
0005435125750	14726	61	20A
0005435125758	14726	62	20D
0005435125757	14726	63	20F
0005435715199	7107	1	1C
0005435715201	7107	2	1D
0005432398138	7107	3	2A
0005432398136	7107	4	2D
0005432400067	7107	5	3C
0005432400065	7107	6	3D
0005432400066	7107	7	4C
0005432398141	7107	8	4D
0005435715203	7107	9	4E
0005435715206	7107	10	5A
0005435715197	7107	11	5D
0005435715204	7107	12	6A
0005435715209	7107	13	6E
0005435715210	7107	14	7E
0005432398137	7107	15	8F
0005435715198	7107	16	9D
0005435715196	7107	17	10A
0005435715194	7107	18	10D
0005432398139	7107	19	12D
0005435715195	7107	20	13F
0005435715208	7107	21	14D
0005435715205	7107	22	16F
0005435715211	7107	23	18A
0005432400068	7107	24	18E
0005432398140	7107	25	19D
0005435715202	7107	26	20C
0005435715207	7107	27	20E
0005435715200	7107	28	20F
0005435178470	27100	1	1C
0005435443164	27100	2	2A
0005435443165	27100	3	7C
0005435178977	27100	4	7E
0005435443168	27100	5	10C
0005435443171	27100	6	12F
0005435443163	27100	7	13F
0005435443169	27100	8	16C
0005435178469	27100	9	17C
0005435443170	27100	10	18A
0005435443172	27100	11	18C
0005435443166	27100	12	18F
0005435443167	27100	13	20A
0005434084859	2734	1	1A
0005434084860	2734	2	4B
0005434084858	2734	3	6B
0005433060371	28467	1	2B
0005433060370	28467	2	3A
0005433060372	28467	3	5A
0005435528913	22230	1	1D
0005435528920	22230	2	1F
0005435528912	22230	3	2A
0005435540649	22230	4	2C
0005435540646	22230	5	2D
0005435540644	22230	6	3A
0005435540653	22230	7	3D
0005435540664	22230	8	4E
0005435528905	22230	9	4F
0005435540647	22230	10	5A
0005435528917	22230	11	5F
0005435540645	22230	12	6D
0005435540659	22230	13	6F
0005435528907	22230	14	7A
0005435540657	22230	15	7F
0005432294448	22230	16	8C
0005435528921	22230	17	8F
0005432294449	22230	18	9D
0005435540656	22230	19	10A
0005435528919	22230	20	10F
0005435540663	22230	21	11C
0005435540648	22230	22	11D
0005435528908	22230	23	11E
0005435540661	22230	24	11F
0005435540658	22230	25	12A
0005435528901	22230	26	12D
0005435540650	22230	27	12E
0005435528915	22230	28	12F
0005435528902	22230	29	13C
0005435540666	22230	30	13D
0005435540665	22230	31	14D
0005435540651	22230	32	15A
0005435528906	22230	33	15C
0005435528909	22230	34	15D
0005435540655	22230	35	15E
0005435540662	22230	36	17A
0005435528914	22230	37	17C
0005435528910	22230	38	17D
0005435528918	22230	39	17E
0005435528916	22230	40	18A
0005435528911	22230	41	18C
0005435540654	22230	42	18D
0005432294447	22230	43	19D
0005435528904	22230	44	19E
0005435540652	22230	45	19F
0005435528903	22230	46	20A
0005435540660	22230	47	20E
0005434906472	2261	1	1A
0005434906460	2261	2	1C
0005434906480	2261	3	1D
0005434906471	2261	4	1F
0005434906511	2261	5	2C
0005434906470	2261	6	2D
0005434906494	2261	7	2F
0005434906500	2261	8	3A
0005434906482	2261	9	4A
0005434906490	2261	10	4D
0005434906496	2261	11	4F
0005434906499	2261	12	5D
0005434906501	2261	13	5E
0005434906465	2261	14	6C
0005434906486	2261	15	6F
0005434906469	2261	16	7C
0005434906468	2261	17	7D
0005434906492	2261	18	8A
0005434906458	2261	19	8D
0005434906485	2261	20	8F
0005434906457	2261	21	9D
0005434906515	2261	22	9E
0005434906479	2261	23	10C
0005434906497	2261	24	10E
0005434906476	2261	25	11A
0005434906493	2261	26	11C
0005434906504	2261	27	11D
0005434906508	2261	28	11E
0005434906513	2261	29	12C
0005434906489	2261	30	12E
0005434906506	2261	31	12F
0005434906510	2261	32	13A
0005434906466	2261	33	13C
0005434906507	2261	34	14A
0005434906491	2261	35	14D
0005434906478	2261	36	14E
0005434906459	2261	37	14F
0005434906484	2261	38	15A
0005434906473	2261	39	15C
0005434906474	2261	40	15E
0005434906498	2261	41	15F
0005433400929	2261	42	16A
0005434906505	2261	43	16C
0005434906488	2261	44	16D
0005434906509	2261	45	16F
0005434906456	2261	46	17A
0005434906503	2261	47	17C
0005434906481	2261	48	17D
0005434906512	2261	49	17E
0005434906463	2261	50	17F
0005434906461	2261	51	18A
0005434906483	2261	52	18E
0005434906477	2261	53	18F
0005434906487	2261	54	19A
0005434906502	2261	55	19C
0005434906475	2261	56	19E
0005434906464	2261	57	19F
0005434906495	2261	58	20C
0005434906514	2261	59	20D
0005434906467	2261	60	20E
0005434906462	2261	61	20F
0005433250991	25615	1	1A
0005433400939	25615	2	1D
0005433250990	25615	3	4A
0005433251004	25615	4	4C
0005433250994	25615	5	4D
0005433251018	25615	6	5E
0005433400938	25615	7	6A
0005433250995	25615	8	6E
0005433251007	25615	9	6F
0005433251012	25615	10	7E
0005433251019	25615	11	8A
0005433251000	25615	12	8C
0005433251002	25615	13	9C
0005433251014	25615	14	9F
0005433400935	25615	15	10C
0005433251008	25615	16	10E
0005433251020	25615	17	11C
0005433400936	25615	18	12A
0005433250997	25615	19	12C
0005433251001	25615	20	12D
0005433251003	25615	21	12E
0005433251010	25615	22	12F
0005433251006	25615	23	13A
0005433251015	25615	24	13D
0005433251011	25615	25	13E
0005433250998	25615	26	14E
0005433251013	25615	27	14F
0005433250993	25615	28	16A
0005433400937	25615	29	16E
0005433250992	25615	30	17D
0005433251021	25615	31	18A
0005433250996	25615	32	18E
0005433251017	25615	33	19C
0005433251016	25615	34	19D
0005433251009	25615	35	20A
0005433250999	25615	36	20C
0005433251005	25615	37	20F
0005432620817	2520	1	1A
0005432620818	2520	2	1D
0005432620825	2520	3	3D
0005432620819	2520	4	4C
0005432620826	2520	5	4D
0005432620821	2520	6	5A
0005432620822	2520	7	5D
0005432620827	2520	8	6B
0005432620824	2520	9	6C
0005432620816	2520	10	6D
0005432620828	2520	11	18C
0005432620820	2520	12	19D
0005432620815	2520	13	20C
0005432620823	2520	14	21B
0005432862184	28051	1	5A
0005432862185	28051	2	7D
0005432862183	28051	3	18B
0005432862181	28051	4	20C
0005432862179	28051	5	21C
0005432862182	28051	6	22C
0005432862180	28051	7	22D
0005434097452	13122	1	5A
0005434097453	13122	2	6B
0005433452706	31090	1	4B
0005433451588	31090	2	5A
0005433451587	31090	3	6A
0005433452707	31090	4	6B
0005434142547	29837	1	1B
0005433134067	29837	2	2D
0005434142546	29837	3	3C
0005433134066	29837	4	3D
0005433131637	29837	5	4A
0005434142544	29837	6	4B
0005433134065	29837	7	5B
0005434183548	29837	8	5D
0005434184634	29837	9	6A
0005433134069	29837	10	7C
0005433134068	29837	11	7D
0005434183549	29837	12	18B
0005433131638	29837	13	18C
0005433131635	29837	14	20C
0005433131636	29837	15	20D
0005434142545	29837	16	21B
0005434184633	29837	17	22A
0005434184635	29837	18	22B
0005433131639	29837	19	22D
0005435696892	16463	1	1B
0005435696878	16463	2	1C
0005435696899	16463	3	2A
0005435696874	16463	4	2C
0005435696890	16463	5	2D
0005435696894	16463	6	3A
0005435696889	16463	7	3C
0005435696893	16463	8	4B
0005435696884	16463	9	5D
0005435696886	16463	10	6A
0005435696900	16463	11	6B
0005435696898	16463	12	6C
0005435696876	16463	13	6D
0005435696885	16463	14	7C
0005435696888	16463	15	7D
0005435696879	16463	16	18A
0005435696873	16463	17	18B
0005435696881	16463	18	18D
0005435696887	16463	19	19B
0005435696882	16463	20	19D
0005435696897	16463	21	20A
0005435696896	16463	22	20B
0005435696891	16463	23	20C
0005435696883	16463	24	21A
0005435696872	16463	25	21B
0005435696895	16463	26	21C
0005435696880	16463	27	22A
0005435696877	16463	28	22B
0005435696875	16463	29	22C
0005435934999	24720	1	5B
0005435935002	24720	2	19B
0005435935001	24720	3	21C
0005435935000	24720	4	22C
0005433724728	18772	1	1A
0005433724731	18772	2	2B
0005433724730	18772	3	3B
0005433724732	18772	4	6A
0005433724729	18772	5	6B
0005432968806	21600	1	3B
0005432968807	21600	2	5B
0005434087437	7309	1	1A
0005434136884	7309	2	1C
0005434136876	7309	3	1D
0005434136859	7309	4	1F
0005434136865	7309	5	2A
0005434136908	7309	6	2D
0005434136888	7309	7	2C
0005434136889	7309	8	2F
0005434136855	7309	9	3A
0005434136848	7309	10	3C
0005434136854	7309	11	3D
0005434136926	7309	12	3F
0005434136914	7309	13	4A
0005434136882	7309	14	4C
0005434136858	7309	15	4D
0005434136863	7309	16	4E
0005434136900	7309	17	4F
0005434136890	7309	18	5A
0005434136849	7309	19	5C
0005434136852	7309	20	5D
0005434136929	7309	21	5E
0005434136886	7309	22	5F
0005434136877	7309	23	6A
0005434087436	7309	24	6C
0005434136857	7309	25	6D
0005434136924	7309	26	6E
0005434136898	7309	27	6F
0005434136879	7309	28	7A
0005434136846	7309	29	7C
0005434136916	7309	30	7D
0005434087440	7309	31	7E
0005434136918	7309	32	8A
0005434136861	7309	33	8C
0005434136921	7309	34	8D
0005434136903	7309	35	8E
0005434136869	7309	36	8F
0005434136845	7309	37	9A
0005434136860	7309	38	9C
0005434087439	7309	39	9D
0005434136868	7309	40	9E
0005434136907	7309	41	9F
0005434136925	7309	42	10A
0005434136883	7309	43	10C
0005434136913	7309	44	10E
0005434136931	7309	45	10F
0005434136894	7309	46	11A
0005434136871	7309	47	11C
0005434136901	7309	48	11D
0005434136878	7309	49	11E
0005434136875	7309	50	11F
0005434136862	7309	51	12A
0005434136870	7309	52	12C
0005434136934	7309	53	12D
0005434136895	7309	54	12E
0005434136912	7309	55	12F
0005434136927	7309	56	13A
0005434136897	7309	57	13C
0005434136919	7309	58	13D
0005434136885	7309	59	13E
0005434136891	7309	60	13F
0005434136853	7309	61	14A
0005434136881	7309	62	14C
0005434136917	7309	63	14D
0005434136872	7309	64	14E
0005434136899	7309	65	14F
0005434136873	7309	66	15A
0005434136911	7309	67	15C
0005434136851	7309	68	15D
0005434136906	7309	69	15E
0005434136864	7309	70	15F
0005434136887	7309	71	16A
0005434136893	7309	72	16C
0005434136915	7309	73	16D
0005434136930	7309	74	16E
0005434136905	7309	75	16F
0005434136932	7309	76	17A
0005434136847	7309	77	17C
0005434136922	7309	78	17D
0005434136904	7309	79	17E
0005434136902	7309	80	17F
0005434136910	7309	81	18A
0005434136920	7309	82	18C
0005434087438	7309	83	18D
0005434136933	7309	84	18E
0005434136880	7309	85	18F
0005434136850	7309	86	19A
0005434136909	7309	87	19C
0005434136928	7309	88	19D
0005434136896	7309	89	19E
0005434136856	7309	90	19F
0005434136923	7309	91	20A
0005434136874	7309	92	20C
0005434136866	7309	93	20D
0005434136867	7309	94	20E
0005434136892	7309	95	20F
0005435808077	1923	1	1A
0005434610172	1923	2	1C
0005435808072	1923	3	1D
0005435808074	1923	4	3A
0005435808075	1923	5	6C
0005435808071	1923	6	7C
0005434610171	1923	7	7D
0005434610174	1923	8	18B
0005435808079	1923	9	18C
0005435808073	1923	10	18D
0005434610173	1923	11	19A
0005434610175	1923	12	19B
0005435808076	1923	13	19C
0005435808078	1923	14	20D
0005435808080	1923	15	21C
0005434503528	22906	1	1A
0005434503497	22906	2	1B
0005434503519	22906	3	1C
0005434503505	22906	4	1D
0005434503525	22906	5	2A
0005434503527	22906	6	2C
0005434503499	22906	7	2D
0005434503535	22906	8	3A
0005434503530	22906	9	3B
0005434503518	22906	10	3D
0005434503520	22906	11	4A
0005434503515	22906	12	4B
0005434503508	22906	13	4C
0005434503506	22906	14	5A
0005434503524	22906	15	5B
0005434503532	22906	16	5C
0005434503513	22906	17	6C
0005434503512	22906	18	6D
0005434503534	22906	19	7A
0005434503507	22906	20	7B
0005434503517	22906	21	7C
0005434503521	22906	22	18A
0005434503536	22906	23	18B
0005434503502	22906	24	18C
0005434503498	22906	25	19A
0005434503522	22906	26	19B
0005434503504	22906	27	19C
0005434503500	22906	28	19D
0005434503526	22906	29	20A
0005434503516	22906	30	20B
0005434503531	22906	31	20C
0005434503529	22906	32	20D
0005434503501	22906	33	21B
0005434503523	22906	34	21C
0005434503510	22906	35	21D
0005434503533	22906	36	22A
0005434503509	22906	37	22B
0005434503511	22906	38	22C
0005434503503	22906	39	22D
0005434503514	22906	40	23B
0005435078101	2171	1	1B
0005435078105	2171	2	1C
0005435078096	2171	3	2B
0005435078110	2171	4	3A
0005435078109	2171	5	3B
0005435078108	2171	6	4B
0005435078098	2171	7	4C
0005435078097	2171	8	4D
0005435078100	2171	9	6C
0005435078111	2171	10	6D
0005435078102	2171	11	18D
0005435078107	2171	12	19C
0005435078103	2171	13	19D
0005435078106	2171	14	20B
0005435078112	2171	15	21B
0005435078104	2171	16	22C
0005435078099	2171	17	22D
0005433266583	24373	1	2A
0005433266584	24373	2	3C
0005433266580	24373	3	4A
0005433266575	24373	4	5C
0005433266578	24373	5	7B
0005433266579	24373	6	18B
0005433266577	24373	7	19B
0005433266582	24373	8	20A
0005433266581	24373	9	22B
0005433266576	24373	10	23A
0005434988576	6641	1	1D
0005434988579	6641	2	4A
0005435803218	6641	3	4C
0005434988578	6641	4	5A
0005434988572	6641	5	5B
0005434988573	6641	6	6C
0005434988575	6641	7	7B
0005435803219	6641	8	7D
0005434988577	6641	9	20A
0005434988571	6641	10	22C
0005434988574	6641	11	22D
0005435464477	23624	1	2B
0005432382585	30473	1	1D
0005433449647	30473	2	1F
0005433454842	30473	3	2C
0005432382584	30473	4	2D
0005432382570	30473	5	2F
0005433449645	30473	6	3D
0005432382598	30473	7	3F
0005432382603	30473	8	4A
0005432382590	30473	9	4E
0005432382594	30473	10	4D
0005432382592	30473	11	5C
0005433449640	30473	12	5D
0005433449637	30473	13	5F
0005433449646	30473	14	6C
0005433449638	30473	15	6D
0005432382605	30473	16	6E
0005432382569	30473	17	6F
0005433449634	30473	18	7C
0005433449649	30473	19	7E
0005432382574	30473	20	7F
0005433449639	30473	21	8A
0005432382572	30473	22	8D
0005432382599	30473	23	8E
0005433454841	30473	24	8F
0005432382566	30473	25	9A
0005432382595	30473	26	9D
0005432382601	30473	27	9E
0005432382576	30473	28	10A
0005433449632	30473	29	10E
0005432382593	30473	30	11C
0005433449631	30473	31	11D
0005432382575	30473	32	11F
0005433449643	30473	33	12A
0005432382583	30473	34	12C
0005432382588	30473	35	12D
0005433449635	30473	36	12F
0005433453731	30473	37	13C
0005433449628	30473	38	13E
0005432382581	30473	39	13F
0005432382589	30473	40	14A
0005433449630	30473	41	14C
0005432382567	30473	42	14E
0005432382568	30473	43	15C
0005433453730	30473	44	15E
0005432382586	30473	45	15F
0005433449642	30473	46	16A
0005432382564	30473	47	16C
0005433449641	30473	48	16D
0005432382604	30473	49	16E
0005433453732	30473	50	16F
0005432382577	30473	51	17A
0005432382571	30473	52	17C
0005432382602	30473	53	17D
0005433449633	30473	54	17E
0005433449644	30473	55	17F
0005433449629	30473	56	18A
0005432382573	30473	57	18C
0005432382597	30473	58	18D
0005432382600	30473	59	18E
0005433449636	30473	60	18F
0005432382591	30473	61	19A
0005432382579	30473	62	19C
0005433449648	30473	63	19D
0005432382596	30473	64	19E
0005432382565	30473	65	19F
0005432382580	30473	66	20A
0005432382587	30473	67	20C
0005432382578	30473	68	20D
0005432382582	30473	69	20F
0005433788147	20813	1	1B
0005433788145	20813	2	2C
0005433788148	20813	3	4C
0005433788146	20813	4	7A
0005433788144	20813	5	7D
0005433788142	20813	6	19A
0005433788140	20813	7	21A
0005433788143	20813	8	21D
0005433788141	20813	9	23A
0005435548427	26479	1	2B
0005435548418	26479	2	3A
0005435548431	26479	3	4D
0005435548428	26479	4	5A
0005435548429	26479	5	5D
0005435548424	26479	6	6A
0005435548421	26479	7	6C
0005435548430	26479	8	6D
0005435548420	26479	9	7A
0005435548423	26479	10	7D
0005435548432	26479	11	19C
0005435548425	26479	12	19D
0005435548426	26479	13	20C
0005435548417	26479	14	21B
0005435548422	26479	15	22A
0005435548419	26479	16	22D
0005433126778	29722	1	1A
0005433129209	29722	2	1D
0005435299705	29722	3	3A
0005435299707	29722	4	3D
0005433126780	29722	5	4B
0005433129207	29722	6	4C
0005435302132	29722	7	5A
0005433129208	29722	8	5B
0005435302131	29722	9	5D
0005435299706	29722	10	6A
0005433129211	29722	11	7B
0005433126777	29722	12	18C
0005435299709	29722	13	19B
0005433126779	29722	14	19C
0005435299708	29722	15	20D
0005435302133	29722	16	21D
0005435302130	29722	17	22C
0005433129210	29722	18	23A
0005434286955	2431	1	1B
0005434286942	2431	2	1C
0005434286947	2431	3	2A
0005434286956	2431	4	2C
0005434286941	2431	5	2D
0005434286943	2431	6	3C
0005432264436	2431	7	3D
0005432264437	2431	8	4A
0005434286944	2431	9	4C
0005434286959	2431	10	5A
0005434286953	2431	11	5B
0005434286939	2431	12	5C
0005432264438	2431	13	5D
0005434286951	2431	14	6C
0005434286946	2431	15	7C
0005434286948	2431	16	7D
0005434286952	2431	17	18A
0005434286957	2431	18	18C
0005434286954	2431	19	19C
0005434286958	2431	20	20C
0005434286938	2431	21	21A
0005434286940	2431	22	21B
0005434286949	2431	23	22B
0005434286945	2431	24	23A
0005434286950	2431	25	23B
0005433109872	26854	1	1B
0005433109870	26854	2	2D
0005433109871	26854	3	4B
0005433109868	26854	4	4D
0005433109862	26854	5	6A
0005433109865	26854	6	7B
0005433109864	26854	7	7C
0005433109873	26854	8	18A
0005433109867	26854	9	19D
0005433109869	26854	10	20D
0005433109863	26854	11	21D
0005433109866	26854	12	22D
0005435856140	25456	1	2B
0005435856138	25456	2	2C
0005435856141	25456	3	4C
0005435856139	25456	4	7B
0005434273050	26623	1	1D
0005434273051	26623	2	3B
0005434272165	26623	3	4D
0005434272166	26623	4	22C
0005434520144	6099	1	1B
0005434520128	6099	2	1C
0005434520134	6099	3	1D
0005434520138	6099	4	2A
0005434520149	6099	5	2B
0005434520147	6099	6	2C
0005434520131	6099	7	2D
0005434520127	6099	8	3C
0005434520139	6099	9	4A
0005434520129	6099	10	5A
0005434520150	6099	11	6A
0005434520136	6099	12	6D
0005434520151	6099	13	7B
0005434520146	6099	14	7C
0005434520130	6099	15	18A
0005434520148	6099	16	18C
0005434520145	6099	17	18D
0005434520143	6099	18	19A
0005434520137	6099	19	19B
0005434520132	6099	20	19C
0005434520140	6099	21	19D
0005434520135	6099	22	20A
0005434520126	6099	23	20C
0005434520133	6099	24	21D
0005434520141	6099	25	22D
0005434520142	6099	26	23B
0005433650389	7160	1	1A
0005433650379	7160	2	1C
0005433650365	7160	3	1D
0005433650373	7160	4	1F
0005433650371	7160	5	2A
0005433650393	7160	6	3A
0005433650381	7160	7	3C
0005433650406	7160	8	3D
0005433650408	7160	9	3F
0005433650387	7160	10	4F
0005433650376	7160	11	5C
0005433650411	7160	12	5F
0005433650404	7160	13	6A
0005433650390	7160	14	6C
0005433650401	7160	15	7C
0005433650410	7160	16	7D
0005433650412	7160	17	7E
0005433650375	7160	18	8A
0005433650367	7160	19	8E
0005433650409	7160	20	9E
0005433650380	7160	21	9F
0005433650400	7160	22	10A
0005433650403	7160	23	10D
0005433650398	7160	24	10E
0005433650402	7160	25	11C
0005433650377	7160	26	11F
0005433650384	7160	27	12A
0005433650407	7160	28	12F
0005433650391	7160	29	13C
0005433650392	7160	30	13D
0005433650369	7160	31	13E
0005433650370	7160	32	13F
0005433650374	7160	33	14E
0005433650372	7160	34	15C
0005433650368	7160	35	15F
0005433650399	7160	36	16D
0005433650386	7160	37	16E
0005433650405	7160	38	17A
0005433650366	7160	39	17C
0005433650388	7160	40	18A
0005433650378	7160	41	18D
0005433650382	7160	42	18E
0005433650394	7160	43	18F
0005433650397	7160	44	19A
0005433650385	7160	45	19D
0005433650396	7160	46	19F
0005433650395	7160	47	20C
0005433650383	7160	48	20E
0005435263502	27622	1	1C
0005435263492	27622	2	1D
0005435263494	27622	3	2F
0005435263484	27622	4	3C
0005435263483	27622	5	4E
0005435263495	27622	6	5C
0005435263488	27622	7	5D
0005435263490	27622	8	5F
0005435263501	27622	9	10C
0005435263485	27622	10	10D
0005435263491	27622	11	10E
0005435263487	27622	12	11A
0005435263497	27622	13	11C
0005435263479	27622	14	12D
0005435263481	27622	15	12F
0005435263489	27622	16	13C
0005435263482	27622	17	13D
0005435263480	27622	18	13E
0005435263486	27622	19	17A
0005435263493	27622	20	18C
0005435263496	27622	21	19E
0005435263499	27622	22	19F
0005435263500	27622	23	20D
0005435263498	27622	24	20F
0005433867823	4782	1	1A
0005433867845	4782	2	1B
0005433867824	4782	3	1C
0005433867821	4782	4	1D
0005433867837	4782	5	2A
0005433867829	4782	6	2B
0005433867847	4782	7	2C
0005433867838	4782	8	2D
0005433867818	4782	9	3A
0005433867835	4782	10	3B
0005433867830	4782	11	4A
0005433867826	4782	12	4B
0005433867833	4782	13	4D
0005433867850	4782	14	5A
0005433867844	4782	15	5B
0005433867842	4782	16	5C
0005433867836	4782	17	5D
0005433867828	4782	18	6A
0005433867834	4782	19	6B
0005433867831	4782	20	7A
0005433867849	4782	21	7B
0005433867841	4782	22	7C
0005433867811	4782	23	7D
0005433867817	4782	24	18B
0005433867839	4782	25	18C
0005433867832	4782	26	18D
0005433867820	4782	27	19B
0005433867812	4782	28	19C
0005433867827	4782	29	20A
0005433867819	4782	30	20B
0005433867822	4782	31	20C
0005433867843	4782	32	21A
0005433867840	4782	33	21C
0005433867813	4782	34	21B
0005433867825	4782	35	21D
0005433867814	4782	36	22A
0005433867816	4782	37	22B
0005433867846	4782	38	22C
0005433867815	4782	39	22D
0005433867848	4782	40	23A
0005435860436	32574	1	3B
0005435860435	32574	2	6B
0005435860434	32574	3	7A
0005435860437	32574	4	20D
0005434663205	3417	1	2B
0005434663200	3417	2	2D
0005434663201	3417	3	3C
0005434461613	3417	4	3D
0005434663203	3417	5	5C
0005434663206	3417	6	5D
0005434663196	3417	7	6D
0005434460472	3417	8	7D
0005434663194	3417	9	18A
0005434460471	3417	10	18C
0005434663202	3417	11	20A
0005434663199	3417	12	20B
0005434461614	3417	13	21A
0005434663193	3417	14	21C
0005434663195	3417	15	22A
0005434663197	3417	16	21D
0005434663204	3417	17	22B
0005434663198	3417	18	23B
0005435911334	12500	1	1B
0005435911336	12500	2	2A
0005435911332	12500	3	4C
0005435911339	12500	4	4D
0005435911333	12500	5	7C
0005435911337	12500	6	7D
0005435911338	12500	7	19C
0005435911331	12500	8	19D
0005435911335	12500	9	22B
0005435860437	14488	1	2B
0005435860434	14488	2	19A
0005435860436	14488	3	19D
0005435860435	14488	4	23A
0005433867810	32675	1	1A
0005433867781	32675	2	1D
0005433867783	32675	3	2B
0005433867772	32675	4	2C
0005433867793	32675	5	2D
0005433867804	32675	6	3A
0005433867808	32675	7	3B
0005433867774	32675	8	3C
0005433867806	32675	9	3D
0005433867777	32675	10	4A
0005433867807	32675	11	4B
0005433867802	32675	12	4D
0005433867787	32675	13	4C
0005433867773	32675	14	5A
0005433867800	32675	15	5B
0005433867797	32675	16	5C
0005433867792	32675	17	5D
0005433867791	32675	18	6C
0005433867798	32675	19	6D
0005433867801	32675	20	7A
0005433867775	32675	21	7C
0005433867786	32675	22	7D
0005433867795	32675	23	18A
0005433867794	32675	24	18B
0005433867778	32675	25	19A
0005433867782	32675	26	19C
0005433867771	32675	27	19B
0005433867805	32675	28	19D
0005433867784	32675	29	20A
0005433867770	32675	30	20B
0005433867788	32675	31	20C
0005433867779	32675	32	20D
0005433867796	32675	33	21A
0005433867785	32675	34	21B
0005433867790	32675	35	21C
0005433867776	32675	36	21D
0005433867789	32675	37	22A
0005433867799	32675	38	22B
0005433867809	32675	39	22C
0005433867780	32675	40	22D
0005433867803	32675	41	23A
0005432798984	14837	1	1A
0005432798985	14837	2	1B
0005432798992	14837	3	1C
0005432799004	14837	4	1D
0005432798990	14837	5	2A
0005432798996	14837	6	2B
0005432799000	14837	7	2C
0005432798991	14837	8	4A
0005432798983	14837	9	4B
0005432799009	14837	10	4C
0005432798986	14837	11	5A
0005432798999	14837	12	5B
0005432799007	14837	13	5C
0005432798997	14837	14	5D
0005432799005	14837	15	6D
0005432798987	14837	16	7B
0005432799002	14837	17	7C
0005432798993	14837	18	18B
0005432799006	14837	19	18C
0005432798995	14837	20	19C
0005432799003	14837	21	19D
0005432799010	14837	22	20A
0005432799008	14837	23	20B
0005432799001	14837	24	20C
0005432798989	14837	25	21A
0005432798994	14837	26	21C
0005432798998	14837	27	22B
0005432798988	14837	28	23B
0005434406788	7036	1	1A
0005434406822	7036	2	1C
0005434406816	7036	3	1D
0005434406767	7036	4	1F
0005434406813	7036	5	2C
0005434406817	7036	6	2D
0005434406821	7036	7	2F
0005432108210	7036	8	3C
0005432153832	7036	9	3A
0005434299198	7036	10	3D
0005434406773	7036	11	3F
0005434406827	7036	12	4C
0005434299199	7036	13	4B
0005434299214	7036	14	4D
0005434406776	7036	15	4F
0005434406787	7036	16	4E
0005434299216	7036	17	5A
0005434299208	7036	18	5B
0005434406815	7036	19	5D
0005434406793	7036	20	5C
0005434299202	7036	21	5F
0005434406774	7036	22	5E
0005434406779	7036	23	6A
0005434406792	7036	24	6E
0005434406794	7036	25	6D
0005434299215	7036	26	7A
0005434406771	7036	27	6F
0005434406795	7036	28	7E
0005434406809	7036	29	7D
0005434299200	7036	30	8B
0005432153833	7036	31	8C
0005434299205	7036	32	8E
0005434299210	7036	33	8D
0005434406790	7036	34	8F
0005434299204	7036	35	9A
0005434406812	7036	36	9C
0005434406819	7036	37	9B
0005434406825	7036	38	9E
0005434406811	7036	39	9D
0005434299206	7036	40	9F
0005432108211	7036	41	10B
0005432108212	7036	42	10C
0005434406828	7036	43	11A
0005432153831	7036	44	10E
0005434299201	7036	45	11B
0005434406775	7036	46	11C
0005434406778	7036	47	11E
0005432153828	7036	48	11F
0005434406784	7036	49	12B
0005434406814	7036	50	12A
0005434299209	7036	51	12D
0005434406768	7036	52	12E
0005434299196	7036	53	12F
0005434406783	7036	54	13A
0005434406786	7036	55	13C
0005432108209	7036	56	13E
0005434406781	7036	57	13D
0005434406777	7036	58	14A
0005432153830	7036	59	13F
0005434406796	7036	60	14B
0005434406801	7036	61	14D
0005434406797	7036	62	14C
0005434406810	7036	63	14F
0005434406789	7036	64	15E
0005434406804	7036	65	15C
0005434406791	7036	66	15F
0005434406766	7036	67	16B
0005434406803	7036	68	16A
0005434299213	7036	69	16F
0005434406772	7036	70	16E
0005434299197	7036	71	17A
0005434406808	7036	72	17B
0005434299207	7036	73	17C
0005434406780	7036	74	17D
0005434406765	7036	75	17E
0005434406770	7036	76	18A
0005434406826	7036	77	18C
0005434299212	7036	78	19A
0005434406802	7036	79	19D
0005434406782	7036	80	19C
0005434406818	7036	81	19E
0005434406823	7036	82	19F
0005434406785	7036	83	20A
0005434299211	7036	84	20C
0005434406799	7036	85	20D
0005432153829	7036	86	21A
0005434406805	7036	87	21C
0005434406820	7036	88	21B
0005434299194	7036	89	21E
0005434406807	7036	90	21D
0005434406798	7036	91	22A
0005434406806	7036	92	21F
0005434299203	7036	93	22B
0005434406829	7036	94	22C
0005434406800	7036	95	22E
0005434299195	7036	96	23B
0005434406824	7036	97	23A
0005434406769	7036	98	23E
0005435293075	26880	1	1A
0005432058318	26880	2	2F
0005435310874	26880	3	3D
0005435310873	26880	4	4B
0005435293073	26880	5	4C
0005435310865	26880	6	5B
0005435293078	26880	7	5E
0005435310868	26880	8	6C
0005435310860	26880	9	6D
0005435310861	26880	10	7F
0005435310869	26880	11	7E
0005435310859	26880	12	8B
0005435310863	26880	13	8E
0005435293077	26880	14	10D
0005435293080	26880	15	12D
0005435310862	26880	16	13B
0005432058319	26880	17	13D
0005432058316	26880	18	13C
0005435293072	26880	19	13E
0005435310856	26880	20	13F
0005435310872	26880	21	14B
0005435310858	26880	22	16C
0005435310871	26880	23	16E
0005435310867	26880	24	17C
0005435293071	26880	25	17F
0005435310864	26880	26	18C
0005432058317	26880	27	18D
0005435310866	26880	28	18E
0005435293076	26880	29	18F
0005435293081	26880	30	19A
0005435293082	26880	31	19D
0005435310875	26880	32	19C
0005435310857	26880	33	20B
0005435310870	26880	34	20D
0005435293079	26880	35	22E
0005435293074	26880	36	23E
0005434512033	6483	1	1A
0005432603754	6483	2	1B
0005432603752	6483	3	1C
0005432603740	6483	4	1D
0005432603738	6483	5	2A
0005432603728	6483	6	2B
0005432603749	6483	7	2C
0005432603758	6483	8	2D
0005434512034	6483	9	3A
0005432603762	6483	10	3B
0005432603745	6483	11	3C
0005434512030	6483	12	3D
0005432603731	6483	13	4A
0005432603746	6483	14	4B
0005432603747	6483	15	4C
0005432603761	6483	16	4D
0005432603757	6483	17	5A
0005432603736	6483	18	5C
0005432603750	6483	19	5D
0005432603730	6483	20	6A
0005432603723	6483	21	6B
0005432603753	6483	22	6C
0005432603725	6483	23	6D
0005432603759	6483	24	7A
0005434512029	6483	25	7B
0005432603742	6483	26	7C
0005432603727	6483	27	7D
0005432603732	6483	28	18A
0005432603737	6483	29	18B
0005432603751	6483	30	18C
0005432603756	6483	31	18D
0005432603748	6483	32	19A
0005432603733	6483	33	19B
0005432603741	6483	34	19C
0005434512028	6483	35	19D
0005432603734	6483	36	20A
0005432603743	6483	37	20B
0005432603729	6483	38	20C
0005432603755	6483	39	21A
0005432603735	6483	40	21B
0005432603724	6483	41	21C
0005432603760	6483	42	22A
0005434512031	6483	43	22B
0005432603744	6483	44	22C
0005434512032	6483	45	22D
0005432603726	6483	46	23A
0005432603739	6483	47	23B
0005435221037	21346	1	1D
0005435221500	21346	2	7C
0005435221499	21346	3	20B
0005435221498	21346	4	22C
0005433251014	15007	1	1A
0005433250990	15007	2	2A
0005433251018	15007	3	2F
0005433251016	15007	4	3A
0005433251011	15007	5	4A
0005433251003	15007	6	4C
0005433251001	15007	7	4E
0005433250998	15007	8	5E
0005433251006	15007	9	5F
0005433251013	15007	10	6E
0005433251005	15007	11	6F
0005433251004	15007	12	7A
0005433250997	15007	13	8D
0005433250996	15007	14	8E
0005433251012	15007	15	9A
0005433251015	15007	16	9C
0005433250999	15007	17	9E
0005433250992	15007	18	12A
0005433251008	15007	19	12C
0005433250994	15007	20	13A
0005433251002	15007	21	13E
0005433251000	15007	22	13F
0005433251019	15007	23	14C
0005433251020	15007	24	14F
0005433250993	15007	25	16D
0005433251009	15007	26	17A
0005433250995	15007	27	17C
0005433251007	15007	28	17E
0005433251017	15007	29	18D
0005433251021	15007	30	20A
0005433250991	15007	31	20E
0005433251010	15007	32	20F
0005434906447	25822	1	1D
0005434906418	25822	2	2A
0005434906443	25822	3	2C
0005434906412	25822	4	2D
0005434906428	25822	5	3A
0005434906423	25822	6	3F
0005434906411	25822	7	4C
0005434906432	25822	8	4F
0005434906427	25822	9	5D
0005434906453	25822	10	5E
0005434906407	25822	11	6C
0005434906417	25822	12	7C
0005434906449	25822	13	8A
0005434906420	25822	14	8C
0005434906425	25822	15	8E
0005434906441	25822	16	9D
0005434906429	25822	17	10D
0005434906437	25822	18	10E
0005434906448	25822	19	10F
0005434906408	25822	20	11A
0005434906414	25822	21	11C
0005434906450	25822	22	11D
0005434906416	25822	23	12A
0005434906446	25822	24	12C
0005434906436	25822	25	12D
0005434906421	25822	26	12E
0005434906431	25822	27	13D
0005434906434	25822	28	13E
0005434906442	25822	29	13F
0005434906433	25822	30	14A
0005434906438	25822	31	14C
0005434906439	25822	32	14F
0005434906454	25822	33	15D
0005434906413	25822	34	16A
0005434906455	25822	35	16C
0005434906440	25822	36	16D
0005434906419	25822	37	16F
0005434906426	25822	38	17A
0005434906445	25822	39	17C
0005434906452	25822	40	18C
0005434906410	25822	41	18D
0005434906415	25822	42	18E
0005434906451	25822	43	18F
0005434906409	25822	44	19A
0005434906444	25822	45	19C
0005434906435	25822	46	19D
0005434906424	25822	47	19E
0005434906430	25822	48	20D
0005434906422	25822	49	20E
0005433007939	14152	1	2D
0005433007958	14152	2	2F
0005433007959	14152	3	3A
0005433007923	14152	4	3F
0005433007953	14152	5	4C
0005433007938	14152	6	4D
0005433007933	14152	7	4E
0005433007934	14152	8	4F
0005433007952	14152	9	5A
0005433007922	14152	10	5C
0005433007928	14152	11	5D
0005433007948	14152	12	5E
0005433007929	14152	13	5F
0005433007955	14152	14	6C
0005433007951	14152	15	6F
0005433007930	14152	16	7A
0005433007926	14152	17	7C
0005433007919	14152	18	7D
0005433007946	14152	19	8A
0005433007915	14152	20	8D
0005433007935	14152	21	9E
0005433007918	14152	22	10A
0005433007945	14152	23	10C
0005433007925	14152	24	10F
0005433007943	14152	25	12C
0005433007937	14152	26	13D
0005433007942	14152	27	13E
0005433007944	14152	28	14A
0005433007932	14152	29	14C
0005433007954	14152	30	14E
0005433007960	14152	31	15D
0005433007936	14152	32	15E
0005433007949	14152	33	16C
0005433007917	14152	34	16D
0005433007921	14152	35	16F
0005433007924	14152	36	17C
0005433007950	14152	37	17E
0005433007931	14152	38	18A
0005433007920	14152	39	18C
0005433007916	14152	40	18D
0005433007957	14152	41	18E
0005433007927	14152	42	19D
0005433007947	14152	43	19E
0005433007941	14152	44	20A
0005433007940	14152	45	20C
0005433007956	14152	46	20D
0005433810492	22853	1	15A
0005434925302	20549	1	1C
0005434925286	20549	2	1F
0005434925274	20549	3	2A
0005434925295	20549	4	2C
0005434925275	20549	5	2D
0005434925282	20549	6	2F
0005434925290	20549	7	3F
0005434925303	20549	8	5C
0005434925294	20549	9	5D
0005434925289	20549	10	6A
0005434925281	20549	11	6E
0005434925284	20549	12	7D
0005434925304	20549	13	7E
0005434925296	20549	14	8D
0005434925297	20549	15	9A
0005434925279	20549	16	9C
0005434925278	20549	17	9D
0005434925283	20549	18	9E
0005434925277	20549	19	10D
0005434925285	20549	20	11A
0005434925300	20549	21	11C
0005434925288	20549	22	12A
0005434925298	20549	23	13E
0005434925273	20549	24	14D
0005434925293	20549	25	15D
0005434925301	20549	26	15F
0005434925291	20549	27	16E
0005434925305	20549	28	16F
0005434925276	20549	29	18D
0005434925280	20549	30	18E
0005434925292	20549	31	18F
0005434925287	20549	32	19C
0005434925299	20549	33	20A
0005435487515	15798	1	1B
0005435487503	15798	2	1C
0005435487499	15798	3	2A
0005435487500	15798	4	2C
0005435487511	15798	5	3A
0005435487508	15798	6	3B
0005435487514	15798	7	4A
0005435487516	15798	8	4B
0005435487506	15798	9	4C
0005435487513	15798	10	4D
0005435487519	15798	11	6A
0005435487501	15798	12	6D
0005435487502	15798	13	7A
0005435487507	15798	14	7B
0005435487509	15798	15	7C
0005435487518	15798	16	18B
0005435487510	15798	17	18D
0005435487504	15798	18	19A
0005435487505	15798	19	19C
0005435487512	15798	20	20B
0005435487498	15798	21	22B
0005435487517	15798	22	23B
0005435998970	19680	1	1B
0005435998969	19680	2	1C
0005435998975	19680	3	1D
0005435998981	19680	4	3A
0005435998979	19680	5	3C
0005435998972	19680	6	3D
0005435998984	19680	7	4A
0005435998971	19680	8	4C
0005435998978	19680	9	5A
0005435998976	19680	10	5B
0005435998974	19680	11	5D
0005435998968	19680	12	18A
0005435998977	19680	13	18C
0005435998980	19680	14	18D
0005435998973	19680	15	21A
0005435998983	19680	16	21D
0005435998982	19680	17	23A
0005435839044	5993	1	1F
0005435839028	5993	2	3C
0005435839043	5993	3	4F
0005435839027	5993	4	6A
0005435839026	5993	5	6D
0005435839040	5993	6	6F
0005432659676	5993	7	7C
0005432658561	5993	8	7B
0005435839042	5993	9	7D
0005432142204	5993	10	8A
0005435839039	5993	11	7F
0005435839030	5993	12	8B
0005432658560	5993	13	9E
0005432660788	5993	14	9F
0005435839031	5993	15	10C
0005435839029	5993	16	10F
0005432142203	5993	17	11C
0005435839023	5993	18	12B
0005435839032	5993	19	12C
0005432142205	5993	20	12E
0005432659675	5993	21	12F
0005435839017	5993	22	13C
0005435839020	5993	23	13F
0005435839034	5993	24	14B
0005435839015	5993	25	14D
0005435839019	5993	26	14E
0005435839035	5993	27	15B
0005435839021	5993	28	15A
0005435839038	5993	29	15F
0005435839018	5993	30	17D
0005435839033	5993	31	18A
0005435839041	5993	32	18E
0005435839036	5993	33	18F
0005435839016	5993	34	19C
0005435839024	5993	35	19E
0005435839037	5993	36	21B
0005435839025	5993	37	21E
0005435839022	5993	38	21D
0005432660789	5993	39	21F
0005432537026	18044	1	1D
0005435472547	18044	2	7F
0005435472556	18044	3	8F
0005435472558	18044	4	9D
0005435472559	18044	5	11D
0005435472545	18044	6	11F
0005432537025	18044	7	12A
0005435472560	18044	8	14E
0005435472548	18044	9	15B
0005435472557	18044	10	15E
0005435472550	18044	11	16C
0005435472549	18044	12	16B
0005435472552	18044	13	16D
0005435472546	18044	14	17A
0005435472555	18044	15	19A
0005435472554	18044	16	18F
0005435472553	18044	17	19B
0005432537027	18044	18	19E
0005435472551	18044	19	20F
0005435472561	18044	20	21F
0005435103811	23007	1	5D
0005435103814	23007	2	6B
0005435103816	23007	3	8C
0005435103817	23007	4	9A
0005435103806	23007	5	9C
0005435103815	23007	6	11B
0005435103808	23007	7	13F
0005435103813	23007	8	15A
0005435103809	23007	9	16F
0005435103804	23007	10	16E
0005435103818	23007	11	17E
0005435103807	23007	12	20B
0005435103810	23007	13	20C
0005435103805	23007	14	22E
0005435103812	23007	15	23F
0005433284831	32052	1	1C
0005433284838	32052	2	2F
0005433284847	32052	3	4C
0005433284839	32052	4	5D
0005433284844	32052	5	5F
0005433284833	32052	6	6B
0005433284836	32052	7	6F
0005433284834	32052	8	7D
0005433284837	32052	9	8A
0005433284824	32052	10	8F
0005433284821	32052	11	9F
0005433284832	32052	12	10B
0005433284848	32052	13	11A
0005433284846	32052	14	11C
0005433284830	32052	15	11D
0005433284835	32052	16	11E
0005433284841	32052	17	12A
0005433284825	32052	18	12C
0005433284823	32052	19	14C
0005433284826	32052	20	15C
0005433284827	32052	21	16B
0005433284822	32052	22	16F
0005433284828	32052	23	17F
0005433284840	32052	24	18B
0005433284842	32052	25	19D
0005433284845	32052	26	20C
0005433284829	32052	27	20D
0005433284843	32052	28	23A
0005433111468	19951	1	1A
0005432892721	19951	2	2F
0005433111470	19951	3	5F
0005432892724	19951	4	10E
0005433112350	19951	5	14D
0005432892722	19951	6	15B
0005432892720	19951	7	16B
0005432892719	19951	8	17E
0005432892723	19951	9	18B
0005433111471	19951	10	18E
0005432892725	19951	11	18F
0005433111469	19951	12	20B
0005433111467	19951	13	20E
0005435630923	30595	1	1A
0005435212545	30595	2	1H
0005433656624	30595	3	2D
0005435212587	30595	4	2C
0005432159792	30595	5	3G
0005435212539	30595	6	3D
0005435212561	30595	7	4A
0005435212552	30595	8	4C
0005435630924	30595	9	5C
0005435212600	30595	10	5D
0005435212603	30595	11	11D
0005435725530	30595	12	12E
0005432159789	30595	13	12D
0005435212536	30595	14	13D
0005435212560	30595	15	13H
0005435212583	30595	16	14D
0005435212572	30595	17	15A
0005435212566	30595	18	17E
0005435212537	30595	19	18E
0005435212590	30595	20	18G
0005435212593	30595	21	18H
0005435212565	30595	22	19F
0005432159790	30595	23	20D
0005435212549	30595	24	20J
0005435212555	30595	25	21B
0005432211396	30595	26	20K
0005435212540	30595	27	21D
0005435212597	30595	28	22D
0005435725529	30595	29	22B
0005435212550	30595	30	22J
0005435212547	30595	31	24G
0005435725527	30595	32	25D
0005435212576	30595	33	25B
0005435212541	30595	34	25E
0005432211389	30595	35	26C
0005435212592	30595	36	26B
0005435212581	30595	37	26A
0005435212596	30595	38	26E
0005435212562	30595	39	27A
0005435212553	30595	40	26K
0005435212554	30595	41	27B
0005435212582	30595	42	27H
0005432211394	30595	43	28A
0005435212579	30595	44	28G
0005435212605	30595	45	29A
0005435212595	30595	46	28K
0005435212570	30595	47	29K
0005435212580	30595	48	30G
0005435212602	30595	49	30J
0005435212575	30595	50	31A
0005435212544	30595	51	32D
0005435212543	30595	52	32K
0005432159788	30595	53	33E
0005433656623	30595	54	34J
0005435212591	30595	55	35F
0005435212568	30595	56	36A
0005435212604	30595	57	36H
0005435212563	30595	58	37B
0005435212585	30595	59	37A
0005435212571	30595	60	37D
0005435212567	30595	61	37G
0005435212556	30595	62	37H
0005435630925	30595	63	38C
0005435212601	30595	64	38B
0005435212578	30595	65	39D
0005432211391	30595	66	39B
0005435212584	30595	67	40C
0005435212557	30595	68	40D
0005435725528	30595	69	40J
0005432211392	30595	70	40K
0005435212559	30595	71	42A
0005435212589	30595	72	42F
0005435212577	30595	73	43F
0005435212588	30595	74	43E
0005435212594	30595	75	43H
0005432159791	30595	76	44C
0005432211395	30595	77	44H
0005435212574	30595	78	44K
0005435212569	30595	79	44J
0005435212551	30595	80	45D
0005435212586	30595	81	45G
0005432211390	30595	82	45K
0005435212542	30595	83	46C
0005432211393	30595	84	46B
0005435212546	30595	85	46A
0005435212598	30595	86	46G
0005435212599	30595	87	46H
0005435212538	30595	88	47A
0005435212558	30595	89	48A
0005433656622	30595	90	49D
0005433656621	30595	91	49K
0005435725531	30595	92	49H
0005435212548	30595	93	50E
0005435212564	30595	94	50D
0005435212573	30595	95	50G
0005433367355	24854	1	1D
0005433367334	24854	2	2C
0005433367361	24854	3	2F
0005433367367	24854	4	3A
0005433367333	24854	5	3D
0005433367341	24854	6	3F
0005433367336	24854	7	4D
0005433367362	24854	8	5C
0005433367353	24854	9	5F
0005433367358	24854	10	6D
0005433367350	24854	11	6E
0005433367337	24854	12	6F
0005433367368	24854	13	7A
0005433367338	24854	14	7C
0005433367371	24854	15	7F
0005433367342	24854	16	8A
0005433367339	24854	17	8D
0005433367359	24854	18	8E
0005433367349	24854	19	9D
0005433367348	24854	20	10A
0005433367363	24854	21	10D
0005433367369	24854	22	10E
0005433367344	24854	23	11C
0005433367357	24854	24	12D
0005433367356	24854	25	13C
0005433367370	24854	26	13D
0005433367364	24854	27	13E
0005433367354	24854	28	13F
0005433367346	24854	29	14D
0005433367343	24854	30	15F
0005433367360	24854	31	16A
0005433367347	24854	32	16C
0005433367365	24854	33	16D
0005433367340	24854	34	17E
0005433367352	24854	35	18D
0005433367351	24854	36	18F
0005433367366	24854	37	19A
0005433367345	24854	38	20C
0005433367335	24854	39	20E
0005435949736	6594	1	1C
0005435949735	6594	2	4B
0005435949739	6594	3	4D
0005435949742	6594	4	5A
0005435949740	6594	5	6A
0005435949734	6594	6	6D
0005435949733	6594	7	7D
0005435949738	6594	8	19D
0005435949741	6594	9	20D
0005435949732	6594	10	21C
0005435949737	6594	11	22B
0005434979362	2031	1	1A
0005434979371	2031	2	1B
0005434979363	2031	3	1D
0005434979352	2031	4	2A
0005434979359	2031	5	2B
0005434979357	2031	6	2C
0005434979350	2031	7	2D
0005434979368	2031	8	3A
0005434979349	2031	9	3D
0005434979358	2031	10	4D
0005434979353	2031	11	5A
0005434979346	2031	12	5C
0005434979360	2031	13	6A
0005434979356	2031	14	6C
0005434979364	2031	15	7A
0005434979367	2031	16	6D
0005435801654	2031	17	7C
0005434979373	2031	18	7D
0005434979354	2031	19	18B
0005434979351	2031	20	18D
0005434979348	2031	21	19A
0005434979361	2031	22	19B
0005434979372	2031	23	19C
0005434979365	2031	24	19D
0005434979355	2031	25	20A
0005434979345	2031	26	20B
0005435801651	2031	27	20D
0005435801653	2031	28	21A
0005434979366	2031	29	21B
0005434979369	2031	30	21D
0005434979370	2031	31	22B
0005434979374	2031	32	22C
0005435801652	2031	33	23A
0005434979347	2031	34	23B
0005434952479	2561	1	1A
0005434952478	2561	2	3A
0005434952475	2561	3	3B
0005434952477	2561	4	5B
0005434952476	2561	5	6B
0005433256388	28264	1	1A
0005433256389	28264	2	2A
0005433256390	28264	3	4B
0005433112355	19830	1	2A
0005433111474	19830	2	3A
0005433111475	19830	3	4A
0005433112354	19830	4	5A
0005433112353	19830	5	6B
0005434136853	28769	1	1A
0005434136869	28769	2	1C
0005434136933	28769	3	1D
0005434136916	28769	4	1F
0005434136856	28769	5	2A
0005434136898	28769	6	2C
0005434136881	28769	7	2F
0005434136885	28769	8	3A
0005434136863	28769	9	3C
0005434136896	28769	10	3D
0005434136934	28769	11	3F
0005434136901	28769	12	4A
0005434136922	28769	13	4C
0005434136919	28769	14	4D
0005434136884	28769	15	4E
0005434136889	28769	16	4F
0005434136907	28769	17	5A
0005434136923	28769	18	5C
0005434136908	28769	19	5D
0005434136877	28769	20	5E
0005434136859	28769	21	5F
0005434136893	28769	22	6A
0005434136850	28769	23	6C
0005434136880	28769	24	6E
0005434136906	28769	25	6F
0005434136852	28769	26	7A
0005434136847	28769	27	7C
0005434136854	28769	28	7D
0005434136861	28769	29	7E
0005434136900	28769	30	7F
0005434136855	28769	31	8C
0005434136888	28769	32	8D
0005434136873	28769	33	8F
0005434136883	28769	34	9A
0005434136845	28769	35	9C
0005434136904	28769	36	9D
0005434136913	28769	37	9E
0005434136930	28769	38	9F
0005434136912	28769	39	10A
0005434136932	28769	40	10C
0005434136886	28769	41	10D
0005434136862	28769	42	10E
0005434136903	28769	43	10F
0005434136914	28769	44	11A
0005434136909	28769	45	11C
0005434136925	28769	46	11D
0005434136890	28769	47	11E
0005434136915	28769	48	11F
0005434136874	28769	49	12A
0005434136848	28769	50	12C
0005434136860	28769	51	12D
0005434136899	28769	52	12E
0005434136910	28769	53	12F
0005434136858	28769	54	13C
0005434136917	28769	55	13D
0005434136868	28769	56	13E
0005434136870	28769	57	13F
0005434136921	28769	58	14A
0005434136851	28769	59	14D
0005434136864	28769	60	14C
0005434136882	28769	61	14E
0005434136887	28769	62	14F
0005434136902	28769	63	15A
0005434136927	28769	64	15C
0005434136875	28769	65	15D
0005434136878	28769	66	15E
0005434136867	28769	67	15F
0005434136924	28769	68	16A
0005434136931	28769	69	16C
0005434136879	28769	70	16D
0005434136894	28769	71	16E
0005434136846	28769	72	16F
0005434136895	28769	73	17A
0005434136876	28769	74	17C
0005434136926	28769	75	17D
0005434136891	28769	76	17E
0005434136849	28769	77	17F
0005434136897	28769	78	18C
0005434136866	28769	79	18D
0005434136911	28769	80	18E
0005434136918	28769	81	19A
0005434136929	28769	82	19C
0005434136928	28769	83	19D
0005434136872	28769	84	19E
0005434136857	28769	85	19F
0005434136920	28769	86	20A
0005434136905	28769	87	20C
0005434136892	28769	88	20D
0005434136865	28769	89	20E
0005434136871	28769	90	20F
0005433538750	6785	1	1A
0005433538746	6785	2	1B
0005433534468	6785	3	2B
0005433538749	6785	4	4B
0005433538743	6785	5	4D
0005433534467	6785	6	5B
0005433538744	6785	7	5D
0005433538747	6785	8	6B
0005433538745	6785	9	18B
0005433538742	6785	10	19D
0005433538748	6785	11	21B
0005435259695	25027	1	4D
0005435259694	25027	2	6A
0005435259692	25027	3	18D
0005435259691	25027	4	21C
0005435259693	25027	5	22C
0005433511834	800	1	3C
0005433511830	800	2	3D
0005433511831	800	3	5A
0005433511828	800	4	7B
0005433511835	800	5	18C
0005433511833	800	6	19D
0005433511829	800	7	20B
0005433511826	800	8	21C
0005433511827	800	9	22B
0005433511832	800	10	22C
0005432922467	16130	1	6B
0005432922468	16130	2	6D
0005432922466	16130	3	7A
0005432922465	16130	4	22D
0005435696931	3664	1	1A
0005435696952	3664	2	1B
0005434950467	3664	3	1C
0005434950465	3664	4	2A
0005435696940	3664	5	2D
0005435696943	3664	6	3B
0005435696944	3664	7	3C
0005435696937	3664	8	3D
0005435696954	3664	9	5A
0005435696955	3664	10	5B
0005435696953	3664	11	5C
0005435696938	3664	12	5D
0005435696947	3664	13	6A
0005435696930	3664	14	6B
0005435696929	3664	15	6C
0005434950466	3664	16	6D
0005435696949	3664	17	7A
0005435696956	3664	18	7B
0005435696932	3664	19	7D
0005435696939	3664	20	18A
0005435696933	3664	21	18B
0005435696948	3664	22	18C
0005435696951	3664	23	18D
0005435696934	3664	24	19C
0005434950464	3664	25	20A
0005435696936	3664	26	20C
0005435696941	3664	27	21A
0005435696935	3664	28	21B
0005435696957	3664	29	21C
0005434950463	3664	30	21D
0005435696942	3664	31	22A
0005435696950	3664	32	22B
0005435696946	3664	33	22C
0005435696945	3664	34	22D
0005435916128	16270	1	3A
0005435916127	16270	2	7D
0005435935001	16270	3	18A
0005435935000	16270	4	18C
0005435935002	16270	5	19D
0005435934999	16270	6	20A
0005434606772	3980	1	1A
0005432609675	3980	2	2C
0005433519391	3980	3	2D
0005435842312	3980	4	3A
0005432609674	3980	5	3D
0005432609673	3980	6	4D
0005432609672	3980	7	5A
0005432607507	3980	8	6C
0005434606775	3980	9	7B
0005432607506	3980	10	18A
0005433519393	3980	11	18C
0005433519390	3980	12	18D
0005433519394	3980	13	19A
0005434604846	3980	14	19B
0005433519392	3980	15	19C
0005434604847	3980	16	20A
0005435842313	3980	17	20B
0005432607509	3980	18	20C
0005434604848	3980	19	20D
0005434606773	3980	20	21D
0005432607508	3980	21	22A
0005434606774	3980	22	23B
0005435853586	22041	1	4A
0005435853585	22041	2	21C
0005435628678	680	1	3A
0005435628677	680	2	3B
0005433348906	15963	1	1A
0005433348907	15963	2	1B
0005433348905	15963	3	2A
0005433348908	15963	4	3B
0005433348909	15963	5	4B
0005433348904	15963	6	5B
0005434446482	17243	1	1A
0005434446485	17243	2	1B
0005434446483	17243	3	2A
0005434446484	17243	4	3A
0005434445213	17243	5	3B
0005434446486	17243	6	4B
0005434445212	17243	7	5B
0005433159281	17640	1	5B
0005433159282	17640	2	6B
0005435132728	7871	1	2B
0005435132732	7871	2	3B
0005435132734	7871	3	3D
0005435132733	7871	4	5B
0005435132737	7871	5	6A
0005435132727	7871	6	6B
0005435132736	7871	7	6D
0005435132726	7871	8	18B
0005435132730	7871	9	18C
0005435132735	7871	10	20C
0005435132729	7871	11	21C
0005435132731	7871	12	22C
0005435383073	33105	1	2D
0005435132702	33105	2	4B
0005435383075	33105	3	6C
0005435132704	33105	4	6D
0005435132699	33105	5	7A
0005435383072	33105	6	18B
0005435132703	33105	7	20B
0005435383074	33105	8	21A
0005435132700	33105	9	22B
0005435383071	33105	10	23B
0005435160145	7478	1	3C
0005435160149	7478	2	3D
0005435160144	7478	3	5B
0005435160146	7478	4	5D
0005435160142	7478	5	6C
0005435160138	7478	6	7A
0005435160139	7478	7	18B
0005435160148	7478	8	19B
0005435160140	7478	9	19A
0005435160141	7478	10	20A
0005435160137	7478	11	20C
0005435160143	7478	12	21A
0005435160147	7478	13	22D
0005435390144	29543	1	1B
0005435390143	29543	2	1C
0005435390141	29543	3	2A
0005435390142	29543	4	2C
0005435390140	29543	5	6B
0005435390139	29543	6	22C
0005435178475	18437	1	1A
0005435178474	18437	2	4A
0005432398138	27180	1	1B
0005432398139	27180	2	2A
0005432398140	27180	3	2B
0005432398141	27180	4	3A
0005432398136	27180	5	3B
0005432400066	27180	6	4A
0005432400067	27180	7	5A
0005432398137	27180	8	5B
0005432400065	27180	9	6A
0005432400068	27180	10	6B
0005434503607	6520	1	1F
0005434503612	6520	2	2A
0005434503600	6520	3	2C
0005434503584	6520	4	3A
0005434503592	6520	5	4C
0005434503595	6520	6	4D
0005435103826	6520	7	4F
0005434503591	6520	8	5D
0005434503613	6520	9	6C
0005434503601	6520	10	6D
0005434503589	6520	11	7A
0005434503581	6520	12	7C
0005434503585	6520	13	8D
0005434503582	6520	14	8F
0005434503611	6520	15	9E
0005434503596	6520	16	10C
0005434503616	6520	17	10D
0005434503579	6520	18	10E
0005434503608	6520	19	11C
0005434503602	6520	20	11F
0005434503618	6520	21	12F
0005435103827	6520	22	13D
0005434503609	6520	23	13E
0005434503605	6520	24	14A
0005434503606	6520	25	14E
0005434503604	6520	26	14F
0005434503598	6520	27	15A
0005434503597	6520	28	15C
0005435103825	6520	29	15D
0005434503587	6520	30	16A
0005434503617	6520	31	16C
0005434503599	6520	32	17A
0005434503586	6520	33	17C
0005434503593	6520	34	17D
0005434503614	6520	35	17E
0005434503603	6520	36	18A
0005434503580	6520	37	18C
0005434503615	6520	38	18D
0005434503588	6520	39	18F
0005434503590	6520	40	19A
0005434503583	6520	41	19C
0005434503578	6520	42	19E
0005434503594	6520	43	20A
0005434503610	6520	44	20C
0005435652390	1683	1	1A
0005435652385	1683	2	1D
0005435652388	1683	3	2D
0005435652400	1683	4	3C
0005435652427	1683	5	3D
0005435652397	1683	6	3F
0005435652406	1683	7	4A
0005435652408	1683	8	4C
0005435652414	1683	9	4E
0005435652415	1683	10	4F
0005435652420	1683	11	5A
0005435652425	1683	12	5E
0005435652434	1683	13	6A
0005435652391	1683	14	6D
0005435652392	1683	15	6E
0005435652410	1683	16	7D
0005435652401	1683	17	7F
0005435652430	1683	18	8E
0005435652384	1683	19	8F
0005435652403	1683	20	9A
0005435652432	1683	21	9D
0005435652404	1683	22	9F
0005435652429	1683	23	10A
0005435652407	1683	24	10C
0005435652435	1683	25	11C
0005435652409	1683	26	12C
0005435652398	1683	27	12D
0005435652424	1683	28	12E
0005435652389	1683	29	13C
0005435652393	1683	30	13F
0005435652402	1683	31	14A
0005435652418	1683	32	14C
0005435652399	1683	33	14D
0005435652428	1683	34	14E
0005435652416	1683	35	14F
0005435652387	1683	36	15A
0005435652413	1683	37	15D
0005435652422	1683	38	15E
0005435652396	1683	39	16C
0005435652433	1683	40	16E
0005435652417	1683	41	16F
0005435652421	1683	42	17C
0005435652431	1683	43	17E
0005435652386	1683	44	17F
0005435652426	1683	45	18A
0005435652411	1683	46	18D
0005435652405	1683	47	18E
0005435652412	1683	48	19C
0005435652395	1683	49	19D
0005435652394	1683	50	20A
0005435652419	1683	51	20D
0005435652423	1683	52	20F
0005433367363	21689	1	1C
0005433367343	21689	2	2C
0005433367345	21689	3	2F
0005433367371	21689	4	3C
0005433367357	21689	5	3F
0005433367370	21689	6	4C
0005433367347	21689	7	4E
0005433367349	21689	8	5D
0005433367341	21689	9	5E
0005433367353	21689	10	6A
0005433367342	21689	11	7E
0005433367358	21689	12	8A
0005433367362	21689	13	8E
0005433367336	21689	14	8F
0005433367350	21689	15	9A
0005433367368	21689	16	9E
0005433367352	21689	17	10F
0005433367335	21689	18	11C
0005433367355	21689	19	11F
0005433367367	21689	20	12A
0005433367348	21689	21	12D
0005433367365	21689	22	12E
0005433367351	21689	23	12F
0005433367366	21689	24	14E
0005433367369	21689	25	15A
0005433367360	21689	26	15E
0005433367344	21689	27	15F
0005433367361	21689	28	16E
0005433367356	21689	29	17C
0005433367337	21689	30	17D
0005433367338	21689	31	17E
0005433367359	21689	32	18A
0005433367364	21689	33	18E
0005433367346	21689	34	18F
0005433367354	21689	35	19C
0005433367340	21689	36	19E
0005433367334	21689	37	20C
0005433367333	21689	38	20D
0005433367339	21689	39	20F
0005433985263	4159	1	1D
0005435788735	4159	2	1F
0005433985287	4159	3	2A
0005433985301	4159	4	2F
0005433985288	4159	5	3A
0005433985275	4159	6	3D
0005433985267	4159	7	4C
0005433985268	4159	8	4D
0005433985262	4159	9	4F
0005433985272	4159	10	5D
0005433985299	4159	11	5F
0005433985279	4159	12	6C
0005433985266	4159	13	6F
0005433985261	4159	14	7C
0005435788733	4159	15	7E
0005433985273	4159	16	7F
0005433985265	4159	17	8A
0005433985264	4159	18	8D
0005433985282	4159	19	8E
0005433985297	4159	20	9A
0005433985294	4159	21	9C
0005433985280	4159	22	9E
0005433985269	4159	23	10C
0005433985302	4159	24	10D
0005433985270	4159	25	10E
0005433985281	4159	26	10F
0005433985303	4159	27	11A
0005433985289	4159	28	11C
0005433985293	4159	29	11D
0005433985286	4159	30	11E
0005433985290	4159	31	12A
0005433985296	4159	32	12D
0005433985271	4159	33	13A
0005433985278	4159	34	13C
0005433985298	4159	35	13F
0005433985284	4159	36	14D
0005433985291	4159	37	14F
0005433985274	4159	38	15A
0005433985277	4159	39	15D
0005433985276	4159	40	15F
0005435788734	4159	41	16D
0005433985295	4159	42	17A
0005433985285	4159	43	17D
0005433985306	4159	44	17E
0005433985292	4159	45	17F
0005433985305	4159	46	18A
0005433985300	4159	47	18E
0005433985283	4159	48	19C
0005433985304	4159	49	20C
0005433985307	4159	50	20D
0005435719551	24767	1	7A
0005435719550	24767	2	21D
0005434516045	9024	1	2D
0005434516043	9024	2	3C
0005434516049	9024	3	3D
0005434516051	9024	4	4C
0005434516047	9024	5	4D
0005434516048	9024	6	5A
0005434516050	9024	7	5B
0005434516052	9024	8	5D
0005434516046	9024	9	6B
0005434516044	9024	10	23A
0005434151664	17850	1	1F
0005432869433	17850	2	2C
0005432869434	17850	3	5F
0005432869432	17850	4	6C
0005432869431	17850	5	7C
0005432869435	17850	6	8A
0005434151663	17850	7	8C
0005432869436	17850	8	8D
0005432869437	17850	9	11F
0005434151665	17850	10	14E
0005432657400	26329	1	1C
0005432659673	26329	2	1F
0005432666356	26329	3	2A
0005432655345	26329	4	2C
0005432665241	26329	5	3A
0005432660787	26329	6	4C
0005432659674	26329	7	4D
0005432660785	26329	8	4E
0005432655342	26329	9	5A
0005432655341	26329	10	5C
0005432660784	26329	11	6A
0005432655347	26329	12	6C
0005432657401	26329	13	6F
0005432658558	26329	14	7F
0005432655343	26329	15	8E
0005432655340	26329	16	8F
0005432665243	26329	17	9C
0005432655344	26329	18	9E
0005432655338	26329	19	10E
0005432658559	26329	20	10F
0005432667421	26329	21	11A
0005432655348	26329	22	13C
0005432666357	26329	23	13D
0005432655346	26329	24	15C
0005432655339	26329	25	15E
0005432655349	26329	26	16A
0005432667422	26329	27	17A
0005432660786	26329	28	17C
0005432666355	26329	29	19D
0005432665242	26329	30	20C
0005432328052	3129	1	1A
0005432287116	3129	2	1D
0005432328060	3129	3	1F
0005432328070	3129	4	2A
0005432328073	3129	5	3A
0005432328058	3129	6	3C
0005432328039	3129	7	3D
0005432328047	3129	8	3F
0005432328059	3129	9	4A
0005432328043	3129	10	4D
0005432328076	3129	11	4E
0005432328042	3129	12	5C
0005432328044	3129	13	5D
0005432328038	3129	14	6C
0005432328066	3129	15	6D
0005432328048	3129	16	6F
0005432328041	3129	17	7F
0005432328051	3129	18	8D
0005432328033	3129	19	8E
0005432328067	3129	20	9C
0005432328056	3129	21	9D
0005432328050	3129	22	9F
0005432328036	3129	23	10A
0005432328032	3129	24	10F
0005432328037	3129	25	11E
0005432328054	3129	26	11F
0005432287118	3129	27	12A
0005432328046	3129	28	12F
0005432328065	3129	29	13C
0005432328061	3129	30	13D
0005432328069	3129	31	13E
0005432328063	3129	32	14D
0005432328077	3129	33	15C
0005432328057	3129	34	15D
0005432328055	3129	35	15E
0005432328071	3129	36	16A
0005432328072	3129	37	16C
0005432328075	3129	38	16D
0005432287119	3129	39	17A
0005432328062	3129	40	17D
0005432328053	3129	41	17E
0005432328068	3129	42	18A
0005432328064	3129	43	18C
0005432328035	3129	44	18F
0005432328045	3129	45	19A
0005432287117	3129	46	19D
0005432328049	3129	47	19E
0005432328040	3129	48	20D
0005432328034	3129	49	20E
0005432328074	3129	50	20F
0005432905037	31154	1	1D
0005432054262	31154	2	2A
0005432905041	31154	3	2F
0005432905040	31154	4	5D
0005432905036	31154	5	6E
0005432327965	31154	6	10C
0005432905038	31154	7	13A
0005432905039	31154	8	19E
0005432054263	31154	9	20A
0005434309554	6196	1	1D
0005434309548	6196	2	2C
0005434309543	6196	3	3A
0005434309553	6196	4	3F
0005434309547	6196	5	4B
0005435999008	6196	6	4E
0005435998999	6196	7	7D
0005435999002	6196	8	8C
0005435999003	6196	9	8F
0005435999011	6196	10	9A
0005435999007	6196	11	9E
0005435999000	6196	12	9F
0005434309544	6196	13	12B
0005434309555	6196	14	12F
0005434309545	6196	15	13B
0005435999005	6196	16	13E
0005434309546	6196	17	14A
0005435999010	6196	18	14D
0005435999006	6196	19	14C
0005435999001	6196	20	16B
0005434309550	6196	21	17A
0005434309551	6196	22	17F
0005435999004	6196	23	18F
0005435999009	6196	24	19B
0005434309552	6196	25	20D
0005434309549	6196	26	20F
0005435999012	6196	27	22E
0005435296958	19581	1	2C
0005435487507	19581	2	5D
0005435487517	19581	3	5F
0005435487519	19581	4	6F
0005435487500	19581	5	8C
0005435296960	19581	6	8E
0005435487512	19581	7	9C
0005435296959	19581	8	10B
0005435487511	19581	9	10E
0005435487514	19581	10	12F
0005435296963	19581	11	13F
0005435487499	19581	12	14B
0005435296964	19581	13	15E
0005435487510	19581	14	16C
0005435487501	19581	15	16F
0005435487518	19581	16	16E
0005435487515	19581	17	17B
0005435296961	19581	18	17E
0005435487504	19581	19	18E
0005435487505	19581	20	18F
0005435296962	19581	21	19A
0005435487509	19581	22	20B
0005435487506	19581	23	20C
0005435487508	19581	24	21E
0005435487513	19581	25	21F
0005435487498	19581	26	22C
0005435487503	19581	27	22E
0005435487516	19581	28	23A
0005435487502	19581	29	23D
0005435517661	1563	1	1C
0005434565728	1563	2	1A
0005434565724	1563	3	1D
0005435502012	1563	4	1F
0005435517650	1563	5	2A
0005434565725	1563	6	2D
0005435517666	1563	7	2F
0005432291896	1563	8	3A
0005435501998	1563	9	3C
0005435502019	1563	10	3D
0005435517656	1563	11	4A
0005434565729	1563	12	4C
0005434565720	1563	13	4F
0005435517657	1563	14	5A
0005434565726	1563	15	5C
0005435502000	1563	16	5D
0005435502004	1563	17	5E
0005435517648	1563	18	5F
0005435517649	1563	19	6A
0005435502011	1563	20	6D
0005435502005	1563	21	6E
0005435508205	1563	22	6F
0005435502015	1563	23	7A
0005434565722	1563	24	7D
0005435502017	1563	25	7E
0005435508206	1563	26	8A
0005435508200	1563	27	8D
0005435517665	1563	28	8F
0005435517654	1563	29	8E
0005435517662	1563	30	9A
0005435502020	1563	31	9C
0005435502008	1563	32	9D
0005435517655	1563	33	9F
0005435517660	1563	34	10A
0005435502009	1563	35	10D
0005435502010	1563	36	10E
0005435508204	1563	37	10F
0005434565721	1563	38	11A
0005432291895	1563	39	11C
0005435508203	1563	40	11D
0005434565730	1563	41	11E
0005434565733	1563	42	12A
0005435517663	1563	43	12C
0005434565723	1563	44	12D
0005435502001	1563	45	13A
0005435502016	1563	46	13C
0005435508208	1563	47	13D
0005435502014	1563	48	13E
0005435508209	1563	49	14A
0005435508199	1563	50	14C
0005435517667	1563	51	14D
0005435517664	1563	52	14F
0005435517658	1563	53	15A
0005432291897	1563	54	15C
0005435517653	1563	55	15E
0005435502006	1563	56	15F
0005435508202	1563	57	16A
0005435517652	1563	58	16C
0005435502013	1563	59	16D
0005434565727	1563	60	16F
0005435502003	1563	61	17A
0005435502018	1563	62	17C
0005434565731	1563	63	17E
0005435502007	1563	64	18A
0005434565719	1563	65	18C
0005434565732	1563	66	18D
0005434565718	1563	67	18F
0005435501999	1563	68	19A
0005435502002	1563	69	19D
0005435517651	1563	70	19F
0005435508201	1563	71	20A
0005435517659	1563	72	20D
0005435508207	1563	73	20F
0005433186000	20894	1	4F
0005433185999	20894	2	5F
0005433185996	20894	3	6F
0005433185998	20894	4	10D
0005433186002	20894	5	12A
0005433186001	20894	6	12C
0005433185995	20894	7	18E
0005433185997	20894	8	19A
0005433186003	20894	9	19D
0005435153652	3926	1	1B
0005435153646	3926	2	2B
0005435153648	3926	3	4D
0005435153651	3926	4	5C
0005435153647	3926	5	7A
0005435153649	3926	6	20A
0005435153650	3926	7	21A
0005435931548	21851	1	7C
0005435931550	21851	2	19B
0005435931549	21851	3	20B
0005435931551	21851	4	21B
0005435931547	21851	5	21D
0005435931546	21851	6	22B
0005432628635	7193	1	1A
0005432628642	7193	2	1B
0005432628646	7193	3	2B
0005432628643	7193	4	2D
0005432628639	7193	5	3A
0005432628640	7193	6	3D
0005432628644	7193	7	4A
0005432628634	7193	8	5A
0005432628632	7193	9	5B
0005432628645	7193	10	6A
0005432628633	7193	11	6D
0005432628638	7193	12	18B
0005432628631	7193	13	19B
0005432628641	7193	14	20A
0005432628636	7193	15	21A
0005432628637	7193	16	21B
0005435225468	28110	1	2A
0005435225469	28110	2	3D
0005435225470	28110	3	4D
0005435225474	28110	4	7A
0005435225467	28110	5	7B
0005435225471	28110	6	20B
0005435225473	28110	7	22D
0005435225472	28110	8	23B
0005435959995	8724	1	1C
0005435959994	8724	2	1D
0005435959996	8724	3	4D
0005435959997	8724	4	20D
0005434267894	15270	1	1D
0005434267895	15270	2	3D
0005434267897	15270	3	4C
0005434267898	15270	4	22B
0005434267896	15270	5	22D
0005432692598	1162	1	1D
0005432692619	1162	2	1F
0005432692605	1162	3	2C
0005432692614	1162	4	2F
0005432674911	1162	5	4C
0005432692611	1162	6	4F
0005432674919	1162	7	5D
0005432674923	1162	8	6B
0005432674909	1162	9	6A
0005432692613	1162	10	6C
0005432692591	1162	11	6E
0005432692608	1162	12	7D
0005432692615	1162	13	8B
0005432692621	1162	14	8D
0005432674913	1162	15	8C
0005432677514	1162	16	9B
0005432674914	1162	17	9A
0005432677511	1162	18	9D
0005432692606	1162	19	10A
0005432692600	1162	20	10C
0005432674920	1162	21	11A
0005432692609	1162	22	11F
0005432692601	1162	23	12B
0005432692602	1162	24	12A
0005432692610	1162	25	12D
0005432692612	1162	26	12C
0005432677512	1162	27	12E
0005432692599	1162	28	13C
0005432692595	1162	29	13B
0005432692618	1162	30	13D
0005432692620	1162	31	13E
0005432674917	1162	32	14A
0005432692617	1162	33	14F
0005432674910	1162	34	14E
0005432692616	1162	35	15A
0005432692597	1162	36	15D
0005432674916	1162	37	15E
0005432692594	1162	38	15F
0005432674922	1162	39	16C
0005432692590	1162	40	16B
0005432674921	1162	41	16E
0005432674912	1162	42	17A
0005432692603	1162	43	17F
0005432692596	1162	44	18D
0005432692592	1162	45	19A
0005432692607	1162	46	19D
0005432674918	1162	47	20F
0005432692604	1162	48	21A
0005432692593	1162	49	21C
0005432674915	1162	50	21B
0005432677513	1162	51	21F
0005432873187	17463	1	3C
0005432873195	17463	2	5D
0005432873190	17463	3	12D
0005432873188	17463	4	14A
0005432674872	17463	5	14E
0005432873189	17463	6	18F
0005432873192	17463	7	19B
0005432873191	17463	8	19F
0005432873193	17463	9	20C
0005432873194	17463	10	20E
0005434434963	1132	1	2D
0005434434959	1132	2	4D
0005434434956	1132	3	5B
0005434434958	1132	4	6C
0005434434970	1132	5	6D
0005434434965	1132	6	7A
0005434434960	1132	7	7B
0005434434967	1132	8	19A
0005434434969	1132	9	19C
0005434434968	1132	10	20B
0005434434961	1132	11	20D
0005434434964	1132	12	21D
0005434434957	1132	13	22A
0005434434962	1132	14	22B
0005434434966	1132	15	23B
0005433156623	17312	1	2A
0005433156629	17312	2	2D
0005433156625	17312	3	3A
0005433156627	17312	4	5B
0005433156626	17312	5	5C
0005433156628	17312	6	6A
0005433156630	17312	7	20B
0005433156622	17312	8	21A
0005433156624	17312	9	22D
0005435086724	4063	1	1D
0005435086727	4063	2	2A
0005435086725	4063	3	2C
0005435086726	4063	4	3D
0005435086730	4063	5	4D
0005435086728	4063	6	20A
0005435086723	4063	7	20B
0005435086729	4063	8	20C
0005435928077	24402	1	2D
0005435928076	24402	2	3C
0005435928075	24402	3	5B
0005435928072	24402	4	20D
0005435928073	24402	5	22C
0005435928074	24402	6	22D
0005435551509	17011	1	1A
0005435098524	17011	2	1G
0005435551495	17011	3	3F
0005435551500	17011	4	3H
0005435098525	17011	5	4G
0005435551511	17011	6	5B
0005435098526	17011	7	9A
0005435551498	17011	8	9G
0005435551499	17011	9	13D
0005435098527	17011	10	14A
0005435551504	17011	11	15D
0005435098528	17011	12	18D
0005435551497	17011	13	22F
0005435551506	17011	14	23A
0005435098523	17011	15	24A
0005435551505	17011	16	25D
0005435551496	17011	17	25E
0005435551512	17011	18	25F
0005435551507	17011	19	29H
0005435551501	17011	20	30A
0005435551494	17011	21	32E
0005435551510	17011	22	33E
0005435551503	17011	23	36G
0005435551502	17011	24	37D
0005435551508	17011	25	39E
0005433261414	18242	1	2C
0005433261427	18242	2	11E
0005433261423	18242	3	11G
0005433261410	18242	4	12F
0005433261425	18242	5	13F
0005433261417	18242	6	13E
0005433261419	18242	7	14D
0005433261428	18242	8	15E
0005433261411	18242	9	16H
0005433261422	18242	10	18B
0005433261420	18242	11	19A
0005433261424	18242	12	19E
0005433261413	18242	13	20A
0005433261426	18242	14	21H
0005433261415	18242	15	27B
0005433261412	18242	16	27E
0005433261409	18242	17	29D
0005433261421	18242	18	29G
0005433261416	18242	19	30B
0005434963906	18242	20	34E
0005433261418	18242	21	35F
0005433261429	18242	22	36D
0005434625824	4849	1	3F
0005434625830	4849	2	7C
0005434625825	4849	3	7F
0005434625831	4849	4	10E
0005434625823	4849	5	15E
0005434625827	4849	6	15F
0005434625828	4849	7	16A
0005434625829	4849	8	16D
0005434625832	4849	9	18D
0005434625826	4849	10	19D
0005435907436	32884	1	1F
0005435907437	32884	2	8E
0005435907433	32884	3	10A
0005435907435	32884	4	15D
0005433194824	32884	5	16A
0005435907434	32884	6	16D
0005433194825	32884	7	16F
0005435907432	32884	8	20E
0005432195662	13752	1	2C
0005435937328	13752	2	4C
0005435937327	13752	3	5C
0005432195663	13752	4	21A
0005435784803	27423	1	1A
0005435784817	27423	2	1B
0005435784809	27423	3	1C
0005435784815	27423	4	1D
0005432190570	27423	5	2A
0005435784804	27423	6	2B
0005435784818	27423	7	2C
0005435784828	27423	8	2D
0005435784824	27423	9	3A
0005435784801	27423	10	3B
0005435784810	27423	11	3C
0005435784805	27423	12	4A
0005435787322	27423	13	4B
0005435784832	27423	14	4C
0005432190568	27423	15	4D
0005435784808	27423	16	5A
0005435784831	27423	17	5B
0005435784812	27423	18	5C
0005435784813	27423	19	5D
0005435784820	27423	20	6B
0005435784829	27423	21	6C
0005435784825	27423	22	6D
0005435784800	27423	23	7A
0005435787323	27423	24	7B
0005435784802	27423	25	7C
0005435784814	27423	26	7D
0005435784821	27423	27	18A
0005435784816	27423	28	18B
0005435784833	27423	29	18C
0005435784823	27423	30	19C
0005435784830	27423	31	19D
0005435784826	27423	32	20A
0005435784819	27423	33	20D
0005435784807	27423	34	21B
0005435784822	27423	35	21C
0005435784806	27423	36	21D
0005432190569	27423	37	22C
0005435784827	27423	38	22D
0005435784811	27423	39	23A
0005435784799	27423	40	23B
0005435310903	20251	1	3C
0005435310900	20251	2	4F
0005435310901	20251	3	5C
0005435310904	20251	4	10C
0005435310896	20251	5	11D
0005435310895	20251	6	11E
0005432058326	20251	7	12C
0005435310897	20251	8	14D
0005435310899	20251	9	15C
0005432058327	20251	10	15F
0005435310905	20251	11	17A
0005435310902	20251	12	17D
0005435310898	20251	13	18A
0005432058325	20251	14	18C
0005434406850	26959	1	1A
0005434406877	26959	2	1C
0005432153838	26959	3	1F
0005434406856	26959	4	2A
0005434406830	26959	5	2C
0005434406858	26959	6	3A
0005432153834	26959	7	3C
0005434406865	26959	8	4A
0005434406894	26959	9	4C
0005434406870	26959	10	4D
0005434406881	26959	11	5C
0005434406886	26959	12	5D
0005434406879	26959	13	5E
0005432153840	26959	14	5F
0005434406889	26959	15	6A
0005434406866	26959	16	6C
0005434406857	26959	17	6D
0005434406864	26959	18	6E
0005434406837	26959	19	6F
0005434406835	26959	20	7A
0005434406892	26959	21	7C
0005434406884	26959	22	7D
0005434406832	26959	23	7E
0005432153842	26959	24	8C
0005434406855	26959	25	8D
0005434406851	26959	26	8E
0005434406867	26959	27	8F
0005434406842	26959	28	9A
0005434406847	26959	29	9D
0005434406831	26959	30	9E
0005434406836	26959	31	10D
0005434406844	26959	32	10E
0005434406846	26959	33	11C
0005434406868	26959	34	11D
0005432153837	26959	35	11E
0005434406882	26959	36	11F
0005434406839	26959	37	12A
0005434406880	26959	38	12C
0005434406853	26959	39	12D
0005434406890	26959	40	12E
0005434406888	26959	41	12F
0005434406860	26959	42	13A
0005434406862	26959	43	13C
0005432153836	26959	44	13D
0005434406852	26959	45	13E
0005434406887	26959	46	13F
0005434406873	26959	47	14A
0005434406875	26959	48	14E
0005432153835	26959	49	14F
0005434406840	26959	50	15C
0005434406878	26959	51	15D
0005434406833	26959	52	15E
0005434406863	26959	53	15F
0005434406859	26959	54	16C
0005434406883	26959	55	16D
0005434406885	26959	56	16E
0005434406874	26959	57	16F
0005434406854	26959	58	17A
0005434406838	26959	59	17D
0005434406845	26959	60	17E
0005434406861	26959	61	17F
0005434406841	26959	62	18A
0005434406893	26959	63	18C
0005434406849	26959	64	18D
0005432153839	26959	65	18E
0005434406876	26959	66	18F
0005434406848	26959	67	19A
0005432153841	26959	68	19D
0005434406834	26959	69	19E
0005434406871	26959	70	19F
0005434406843	26959	71	20C
0005434406869	26959	72	20D
0005434406872	26959	73	20E
0005434406891	26959	74	20F
0005432109664	5676	1	2F
0005434319190	5676	2	3C
0005432109662	5676	3	6F
0005434319191	5676	4	7E
0005432109666	5676	5	8D
0005434319187	5676	6	9E
0005434319192	5676	7	11F
0005434319189	5676	8	12C
0005432109663	5676	9	12D
0005432109665	5676	10	14E
0005432109667	5676	11	16C
0005434319186	5676	12	17D
0005434319188	5676	13	17E
0005434311188	5676	14	19D
0005433123640	15679	1	1A
0005433123648	15679	2	1C
0005433123638	15679	3	2C
0005433123634	15679	4	4C
0005433123645	15679	5	5C
0005433123642	15679	6	5E
0005433123646	15679	7	6A
0005433123650	15679	8	7D
0005433123641	15679	9	7F
0005433123636	15679	10	9A
0005433123635	15679	11	11D
0005433123644	15679	12	12E
0005433123643	15679	13	13F
0005433123651	15679	14	14E
0005433123655	15679	15	15E
0005433123653	15679	16	18A
0005433123649	15679	17	18D
0005433123652	15679	18	18E
0005433123637	15679	19	18F
0005433123647	15679	20	19A
0005433123654	15679	21	19D
0005433123639	15679	22	19E
0005435217677	24965	1	21D
0005434484253	8997	1	1A
0005434484252	8997	2	2C
0005434484257	8997	3	2D
0005434484256	8997	4	3C
0005434484254	8997	5	4C
0005434484255	8997	6	5C
0005434189097	16669	1	3A
0005434189094	16669	2	6A
0005434189096	16669	3	6C
0005434189095	16669	4	7A
0005434189098	16669	5	19C
0005434189093	16669	6	21B
0005433123649	7599	1	1A
0005433123651	7599	2	1C
0005433123638	7599	3	1F
0005433123636	7599	4	2D
0005433123654	7599	5	2F
0005433123640	7599	6	4D
0005433123639	7599	7	5A
0005433123647	7599	8	6D
0005433123646	7599	9	7A
0005433123645	7599	10	8A
0005433123643	7599	11	10F
0005433123641	7599	12	11D
0005433123642	7599	13	12A
0005433123653	7599	14	13D
0005433123634	7599	15	13F
0005433123655	7599	16	14F
0005433123648	7599	17	15A
0005433123644	7599	18	15D
0005433123637	7599	19	17A
0005433123635	7599	20	19A
0005433123652	7599	21	20A
0005433123650	7599	22	20C
0005432692630	7598	1	1A
0005432720518	7598	2	1D
0005433449656	7598	3	1F
0005433449666	7598	4	2A
0005432720515	7598	5	2C
0005433449667	7598	6	2D
0005432692627	7598	7	2F
0005433449650	7598	8	3A
0005433449652	7598	9	3C
0005433449657	7598	10	3D
0005432071531	7598	11	3F
0005432692652	7598	12	4A
0005432720514	7598	13	4D
0005433449659	7598	14	4E
0005432692622	7598	15	5A
0005432720534	7598	16	5C
0005432720510	7598	17	5D
0005432720521	7598	18	5E
0005432692635	7598	19	5F
0005433449662	7598	20	6A
0005433449658	7598	21	6C
0005432720511	7598	22	6E
0005433449669	7598	23	6F
0005432692648	7598	24	7A
0005432692637	7598	25	7C
0005432720532	7598	26	7D
0005432720523	7598	27	7E
0005432071532	7598	28	7F
0005433449661	7598	29	8A
0005432720527	7598	30	8C
0005432692642	7598	31	8D
0005432692625	7598	32	8F
0005432720530	7598	33	9A
0005432720535	7598	34	9C
0005432692650	7598	35	9D
0005432692641	7598	36	9E
0005432720516	7598	37	10A
0005432720519	7598	38	10C
0005432692651	7598	39	10D
0005432720520	7598	40	10E
0005432692643	7598	41	10F
0005432692645	7598	42	11A
0005432692631	7598	43	11C
0005432720522	7598	44	11D
0005432720513	7598	45	11E
0005432692640	7598	46	12C
0005432692636	7598	47	12D
0005432720533	7598	48	12F
0005432720528	7598	49	13A
0005432692632	7598	50	13C
0005432692633	7598	51	13D
0005432692639	7598	52	13E
0005432720524	7598	53	13F
0005432692638	7598	54	14C
0005433449651	7598	55	14D
0005432720526	7598	56	14E
0005432692629	7598	57	14F
0005432692623	7598	58	15A
0005432692634	7598	59	15C
0005432720517	7598	60	15D
0005433449663	7598	61	15E
0005432720537	7598	62	15F
0005432720536	7598	63	16A
0005432692626	7598	64	16C
0005432692647	7598	65	16D
0005433449660	7598	66	16F
0005432692628	7598	67	17A
0005432720512	7598	68	17C
0005433449671	7598	69	17D
0005433449668	7598	70	17F
0005432720525	7598	71	18A
0005432692624	7598	72	18D
0005433449665	7598	73	18E
0005432720531	7598	74	18F
0005433449655	7598	75	19A
0005432692644	7598	76	19C
0005433449670	7598	77	19D
0005433449654	7598	78	19E
0005433449664	7598	79	19F
0005432720529	7598	80	20A
0005432692649	7598	81	20D
0005433449653	7598	82	20E
0005432692646	7598	83	20F
0005433722127	30428	1	2F
0005433722125	30428	2	4A
0005432720477	30428	3	4C
0005433722124	30428	4	6A
0005433722121	30428	5	9A
0005433722126	30428	6	11F
0005433722123	30428	7	12A
0005433722122	30428	8	13E
0005434586238	1357	1	1A
0005434586239	1357	2	1D
0005434586251	1357	3	1F
0005433524881	1357	4	2A
0005434586260	1357	5	2F
0005434586261	1357	6	3A
0005433524888	1357	7	3C
0005433524885	1357	8	3D
0005434586259	1357	9	4A
0005433524886	1357	10	4C
0005433524889	1357	11	4D
0005434586252	1357	12	4F
0005432270965	1357	13	5A
0005432270962	1357	14	5C
0005433724741	1357	15	5D
0005434586243	1357	16	6A
0005434586244	1357	17	6D
0005434586242	1357	18	7A
0005434513541	1357	19	8F
0005434586247	1357	20	9A
0005434586250	1357	21	9F
0005434586249	1357	22	10E
0005434586253	1357	23	11A
0005434586256	1357	24	11C
0005433724739	1357	25	11E
0005434514930	1357	26	12C
0005434586257	1357	27	13A
0005433524887	1357	28	13C
0005434514929	1357	29	13D
0005434586241	1357	30	14A
0005434586258	1357	31	14D
0005433524882	1357	32	14F
0005434586236	1357	33	15C
0005433724740	1357	34	15D
0005433524883	1357	35	15E
0005434513542	1357	36	16A
0005434586245	1357	37	16F
0005434586240	1357	38	17A
0005433524884	1357	39	17F
0005432270963	1357	40	18A
0005434586248	1357	41	18D
0005432270964	1357	42	18F
0005434586246	1357	43	19C
0005433724742	1357	44	19E
0005434586237	1357	45	19F
0005434586255	1357	46	20A
0005434514931	1357	47	20E
0005434586254	1357	48	20F
0005434586165	18548	1	1D
0005432927901	18548	2	1F
0005432968807	18548	3	3D
0005433192857	18548	4	3F
0005433192854	18548	5	4C
0005432927898	18548	6	5A
0005433192855	18548	7	6A
0005434586164	18548	8	6F
0005433192863	18548	9	7A
0005433192851	18548	10	7E
0005433192852	18548	11	8D
0005433192856	18548	12	10D
0005432927902	18548	13	10F
0005433192861	18548	14	12C
0005433192853	18548	15	12D
0005433192850	18548	16	13D
0005433192858	18548	17	13E
0005433192860	18548	18	14E
0005432968806	18548	19	15C
0005432927900	18548	20	15E
0005434586177	18548	21	15F
0005432927897	18548	22	16A
0005433192862	18548	23	17D
0005432927899	18548	24	17F
0005433192859	18548	25	18E
0005434343680	11444	1	1A
0005434343671	11444	2	1D
0005434343677	11444	3	2A
0005434343681	11444	4	2B
0005434343659	11444	5	2C
0005434142554	11444	6	2D
0005434343668	11444	7	3A
0005434343670	11444	8	3B
0005434343683	11444	9	3C
0005434343678	11444	10	3D
0005434343682	11444	11	4C
0005434343665	11444	12	4D
0005434343667	11444	13	5A
0005434343654	11444	14	5B
0005434343679	11444	15	5C
0005434343660	11444	16	6A
0005434343662	11444	17	6C
0005434343669	11444	18	6D
0005434343664	11444	19	7A
0005434343676	11444	20	7C
0005434343674	11444	21	7D
0005434343661	11444	22	18B
0005434343685	11444	23	18D
0005434343652	11444	24	19A
0005434343675	11444	25	19C
0005434343651	11444	26	19D
0005434343656	11444	27	20A
0005434343684	11444	28	20B
0005434343663	11444	29	20C
0005434343653	11444	30	20D
0005434142555	11444	31	21B
0005434343672	11444	32	21C
0005434343673	11444	33	21D
0005434343655	11444	34	22A
0005434343657	11444	35	22B
0005434343658	11444	36	22D
0005434343666	11444	37	23B
0005435304995	29782	1	1B
0005435304107	29782	2	5D
0005435304105	29782	3	6A
0005435304996	29782	4	6D
0005435304106	29782	5	7B
0005435304104	29782	6	19A
0005435304108	29782	7	22C
0005435304997	29782	8	22D
0005435824253	1302	1	2F
0005435824259	1302	2	4F
0005435824243	1302	3	5F
0005435824242	1302	4	5D
0005435824248	1302	5	6A
0005435824236	1302	6	7C
0005435824235	1302	7	7B
0005435824257	1302	8	7D
0005435824247	1302	9	8A
0005435824254	1302	10	8C
0005435824233	1302	11	8F
0005432284516	1302	12	9A
0005432284515	1302	13	9D
0005435824255	1302	14	9F
0005435824244	1302	15	10B
0005435824239	1302	16	11A
0005435824246	1302	17	12A
0005435824234	1302	18	12B
0005435824249	1302	19	13A
0005435824237	1302	20	12F
0005435824258	1302	21	13E
0005435824241	1302	22	13D
0005435824245	1302	23	17B
0005435824260	1302	24	18B
0005435824240	1302	25	18E
0005435824250	1302	26	18D
0005435824251	1302	27	19A
0005435824252	1302	28	19C
0005435824261	1302	29	20A
0005435824256	1302	30	20D
0005435824238	1302	31	21B
0005432284517	1302	32	21F
0005433415429	17995	1	3D
0005433415433	17995	2	6D
0005433415427	17995	3	6C
0005433415435	17995	4	6E
0005433415442	17995	5	7A
0005433415441	17995	6	7E
0005433415431	17995	7	9C
0005433415434	17995	8	9B
0005433415438	17995	9	9F
0005433415430	17995	10	14C
0005433415428	17995	11	14E
0005433415444	17995	12	15F
0005433415437	17995	13	17B
0005433415439	17995	14	17C
0005433415443	17995	15	18E
0005433415436	17995	16	18F
0005433415440	17995	17	20B
0005433415432	17995	18	21C
0005432783047	5634	1	1C
0005432143942	5634	2	1D
0005432783043	5634	3	2A
0005432783017	5634	4	2D
0005432783024	5634	5	2F
0005432783003	5634	6	3A
0005432783051	5634	7	3C
0005432783029	5634	8	3D
0005432783005	5634	9	3F
0005432143941	5634	10	4A
0005432783028	5634	11	4D
0005432783048	5634	12	4E
0005432783046	5634	13	4F
0005432783031	5634	14	5D
0005432783035	5634	15	5F
0005432783006	5634	16	6D
0005432783033	5634	17	6E
0005432783007	5634	18	7C
0005432783011	5634	19	7D
0005432783056	5634	20	7E
0005432783038	5634	21	7F
0005432783041	5634	22	8A
0005432783012	5634	23	8D
0005432783004	5634	24	9A
0005432783015	5634	25	9E
0005432783053	5634	26	9F
0005432783016	5634	27	10A
0005432783008	5634	28	10C
0005432783057	5634	29	10D
0005432783019	5634	30	10E
0005432783049	5634	31	10F
0005432783025	5634	32	11A
0005432783023	5634	33	11E
0005432783037	5634	34	12A
0005432783014	5634	35	12C
0005432783018	5634	36	12D
0005432783040	5634	37	12F
0005432783009	5634	38	13D
0005432783020	5634	39	14E
0005432783034	5634	40	14F
0005432783027	5634	41	15A
0005432783022	5634	42	15C
0005432783026	5634	43	15D
0005432783030	5634	44	15F
0005432783055	5634	45	16C
0005432783013	5634	46	16D
0005432143939	5634	47	16F
0005432783042	5634	48	17D
0005432783039	5634	49	17E
0005432783010	5634	50	17F
0005432783050	5634	51	18A
0005432783021	5634	52	18D
0005432783054	5634	53	18E
0005432143940	5634	54	19A
0005432783032	5634	55	19D
0005432783036	5634	56	19E
0005432783044	5634	57	20A
0005432783052	5634	58	20C
0005432783045	5634	59	20D
0005435242453	15392	1	1A
0005435242455	15392	2	1D
0005435242460	15392	3	2D
0005435242463	15392	4	2F
0005435242449	15392	5	4A
0005435242456	15392	6	4D
0005435242464	15392	7	4E
0005435242448	15392	8	6D
0005435476655	15392	9	7C
0005435242443	15392	10	7E
0005435242451	15392	11	7D
0005435242458	15392	12	9F
0005435242445	15392	13	10C
0005435242469	15392	14	10F
0005435242452	15392	15	11F
0005435242446	15392	16	12A
0005435242462	15392	17	13D
0005435476656	15392	18	13E
0005435242459	15392	19	13F
0005435242465	15392	20	14C
0005435242468	15392	21	14D
0005435242447	15392	22	14E
0005435242450	15392	23	15A
0005435242467	15392	24	14F
0005435242461	15392	25	15E
0005435242457	15392	26	16C
0005435242470	15392	27	17A
0005435242444	15392	28	17F
0005435476657	15392	29	18C
0005435476658	15392	30	19E
0005435242454	15392	31	19F
0005435242466	15392	32	20F
0005432848105	4364	1	1C
0005432848111	4364	2	1D
0005434463899	4364	3	2A
0005432848103	4364	4	2D
0005432848112	4364	5	3C
0005432848101	4364	6	3D
0005432848107	4364	7	4A
0005432848106	4364	8	4B
0005432848113	4364	9	4D
0005432848109	4364	10	5A
0005434463898	4364	11	5B
0005434462760	4364	12	6D
0005434462759	4364	13	18A
0005432848108	4364	14	18B
0005432848100	4364	15	18D
0005432848104	4364	16	19C
0005432848102	4364	17	20D
0005432848110	4364	18	22A
0005435850784	28859	1	1D
0005435850779	28859	2	2B
0005435850781	28859	3	2D
0005435850783	28859	4	4C
0005435850780	28859	5	6A
0005435850785	28859	6	6B
0005435850786	28859	7	7C
0005435850776	28859	8	19C
0005435850778	28859	9	20A
0005435850777	28859	10	20C
0005435850782	28859	11	23A
0005433496528	6244	1	1A
0005433496517	6244	2	1C
0005434443484	6244	3	2A
0005434925357	6244	4	3C
0005433496535	6244	5	3F
0005433496529	6244	6	4A
0005433496532	6244	7	4C
0005433496521	6244	8	4E
0005433496543	6244	9	5A
0005434925347	6244	10	5C
0005434443478	6244	11	5D
0005434925358	6244	12	5E
0005433496514	6244	13	5F
0005433496519	6244	14	6A
0005434925353	6244	15	6C
0005433496526	6244	16	6D
0005434925345	6244	17	6E
0005433496536	6244	18	6F
0005434925343	6244	19	7D
0005433496544	6244	20	7E
0005433496522	6244	21	7F
0005433496525	6244	22	8A
0005434925359	6244	23	8D
0005433496530	6244	24	8F
0005434443479	6244	25	9A
0005434925348	6244	26	9C
0005433496516	6244	27	9D
0005434925351	6244	28	9F
0005433496533	6244	29	10A
0005434443485	6244	30	10C
0005433496545	6244	31	10D
0005433496542	6244	32	10E
0005433496540	6244	33	10F
0005433496524	6244	34	11D
0005434925363	6244	35	11E
0005433496527	6244	36	11F
0005434925352	6244	37	12A
0005434443473	6244	38	12C
0005434925362	6244	39	12D
0005433496531	6244	40	12E
0005434925355	6244	41	12F
0005434925361	6244	42	13A
0005432075181	6244	43	13D
0005433496541	6244	44	13F
0005434925346	6244	45	14A
0005434925349	6244	46	14C
0005434443476	6244	47	14D
0005434925354	6244	48	15C
0005434443480	6244	49	15D
0005434443488	6244	50	15E
0005434443477	6244	51	15F
0005434443487	6244	52	16A
0005434443481	6244	53	16C
0005434925356	6244	54	16D
0005434925344	6244	55	16E
0005434443474	6244	56	16F
0005434925350	6244	57	17A
0005433496537	6244	58	17C
0005433496534	6244	59	17D
0005433496523	6244	60	17E
0005433496538	6244	61	17F
0005433496515	6244	62	18C
0005434443483	6244	63	18D
0005432075180	6244	64	18E
0005432075182	6244	65	18F
0005433496539	6244	66	19A
0005434443486	6244	67	19C
0005434925360	6244	68	19D
0005433496520	6244	69	19E
0005434925364	6244	70	19F
0005433496546	6244	71	20A
0005434443482	6244	72	20C
0005434443475	6244	73	20E
0005433496518	6244	74	20F
0005433496476	20371	1	11C
0005433496477	20371	2	20D
0005435242495	12168	1	1A
0005435242483	12168	2	1C
0005435242491	12168	3	2A
0005435242474	12168	4	2C
0005435242484	12168	5	3A
0005435242496	12168	6	3C
0005435242497	12168	7	4A
0005435242490	12168	8	4E
0005435242477	12168	9	5F
0005435242475	12168	10	6D
0005435242488	12168	11	7C
0005435242471	12168	12	9A
0005435242481	12168	13	10C
0005435242493	12168	14	11A
0005435242478	12168	15	11F
0005435242473	12168	16	12C
0005435242485	12168	17	12E
0005432782839	12168	18	13A
0005435242479	12168	19	13C
0005435242492	12168	20	14A
0005435242489	12168	21	15A
0005435242472	12168	22	15C
0005435242487	12168	23	15E
0005435242476	12168	24	16C
0005435242480	12168	25	16D
0005435242486	12168	26	16F
0005435242494	12168	27	17A
0005435242482	12168	28	18E
0005432783000	15401	1	2A
0005432782970	15401	2	2D
0005432782958	15401	3	3C
0005432782993	15401	4	3F
0005432782965	15401	5	4A
0005432782961	15401	6	4D
0005432782975	15401	7	4E
0005432782978	15401	8	5C
0005432782988	15401	9	5E
0005432782998	15401	10	6A
0005432782986	15401	11	6C
0005432782972	15401	12	6D
0005432783002	15401	13	6F
0005432783001	15401	14	7C
0005432782983	15401	15	7E
0005432782992	15401	16	7F
0005432782999	15401	17	8A
0005432782959	15401	18	8C
0005432782966	15401	19	8D
0005432782982	15401	20	8E
0005432782962	15401	21	8F
0005432782980	15401	22	9A
0005432782956	15401	23	9E
0005432782976	15401	24	10A
0005432782981	15401	25	10C
0005432782950	15401	26	10D
0005432782964	15401	27	10E
0005432782951	15401	28	11A
0005432782996	15401	29	11C
0005432782974	15401	30	11D
0005432782985	15401	31	11F
0005432782995	15401	32	12D
0005432782969	15401	33	12E
0005432782977	15401	34	12F
0005432782953	15401	35	13C
0005432782997	15401	36	13F
0005432782967	15401	37	14A
0005432782979	15401	38	14C
0005432782960	15401	39	15C
0005432782954	15401	40	15D
0005432782971	15401	41	15E
0005432782989	15401	42	15F
0005432782957	15401	43	16A
0005432782990	15401	44	16D
0005432782991	15401	45	16E
0005432782987	15401	46	16F
0005432782984	15401	47	17D
0005432782968	15401	48	17F
0005432782963	15401	49	18C
0005432782949	15401	50	19C
0005432782994	15401	51	19D
0005432782955	15401	52	19F
0005432782973	15401	53	20E
0005432782952	15401	54	20F
0005434910075	10122	1	2D
0005435913865	10122	2	4F
0005435913862	10122	3	6F
0005435913859	10122	4	7E
0005435913864	10122	5	7D
0005434876642	10122	6	9C
0005435913858	10122	7	9E
0005435913861	10122	8	11E
0005434910073	10122	9	13C
0005435913863	10122	10	14D
0005435913860	10122	11	20A
0005434910074	10122	12	20E
0005434876917	14624	1	1C
0005434876859	14624	2	1A
0005434876877	14624	3	1D
0005434876874	14624	4	2A
0005434876924	14624	5	1F
0005434876925	14624	6	2F
0005434876868	14624	7	2D
0005434876921	14624	8	3C
0005434876910	14624	9	4A
0005434876848	14624	10	3F
0005434876928	14624	11	3D
0005434876909	14624	12	4D
0005434876931	14624	13	4C
0005434876914	14624	14	5D
0005434876911	14624	15	5C
0005434876922	14624	16	5A
0005434758860	14624	17	5F
0005434876847	14624	18	6B
0005434876915	14624	19	6A
0005434876861	14624	20	6C
0005434876857	14624	21	6F
0005434876938	14624	22	6E
0005434876900	14624	23	6D
0005434876934	14624	24	7A
0005434876899	14624	25	7C
0005434876869	14624	26	7B
0005434876932	14624	27	7E
0005434876881	14624	28	8A
0005434876865	14624	29	8C
0005434876940	14624	30	8B
0005434876903	14624	31	8D
0005434876892	14624	32	8F
0005434758861	14624	33	8E
0005434876871	14624	34	9B
0005434876916	14624	35	9A
0005434876885	14624	36	9D
0005434876860	14624	37	9C
0005434876893	14624	38	10A
0005434876858	14624	39	9F
0005434876930	14624	40	10B
0005434876912	14624	41	10E
0005434876913	14624	42	10D
0005434876895	14624	43	11A
0005434876849	14624	44	10F
0005434876937	14624	45	11B
0005434876887	14624	46	11C
0005434876862	14624	47	11F
0005434876908	14624	48	11E
0005434758859	14624	49	12B
0005434876918	14624	50	12A
0005434876853	14624	51	12C
0005434876920	14624	52	12F
0005434876904	14624	53	12E
0005434876866	14624	54	13B
0005434876883	14624	55	13A
0005434876856	14624	56	13C
0005434876876	14624	57	13E
0005434876863	14624	58	13D
0005434876870	14624	59	13F
0005434876850	14624	60	14C
0005434876878	14624	61	14B
0005434876927	14624	62	14A
0005434876867	14624	63	14D
0005434876901	14624	64	14E
0005434876851	14624	65	15B
0005434876855	14624	66	15A
0005434876854	14624	67	15D
0005434876872	14624	68	15C
0005434876902	14624	69	15E
0005434876942	14624	70	15F
0005434876879	14624	71	16C
0005434876923	14624	72	16B
0005434876935	14624	73	16D
0005434876939	14624	74	16F
0005434876882	14624	75	16E
0005434876891	14624	76	17B
0005434876896	14624	77	17A
0005434876941	14624	78	17D
0005434876919	14624	79	17C
0005434876886	14624	80	18B
0005434876889	14624	81	18A
0005434876852	14624	82	18C
0005434876894	14624	83	18F
0005434876907	14624	84	18E
0005434876933	14624	85	18D
0005434876898	14624	86	19A
0005434876906	14624	87	19C
0005434876936	14624	88	19B
0005434876897	14624	89	19D
0005434876873	14624	90	19F
0005434876864	14624	91	19E
0005434876905	14624	92	20C
0005434876890	14624	93	20B
0005434876926	14624	94	20D
0005434876884	14624	95	21B
0005434876875	14624	96	21A
0005434876880	14624	97	20F
0005434876929	14624	98	21C
0005434876888	14624	99	21E
0005435659972	9217	1	1D
0005435659976	9217	2	2D
0005435659974	9217	3	3A
0005435659979	9217	4	4C
0005435659975	9217	5	4D
0005435659971	9217	6	6B
0005435659981	9217	7	6C
0005435659980	9217	8	19D
0005435659978	9217	9	20A
0005435659973	9217	10	21A
0005435659977	9217	11	21D
0005435659982	9217	12	22A
0005434251831	24640	1	2C
0005434251830	24640	2	2D
0005434251825	24640	3	3D
0005434251828	24640	4	4B
0005434251827	24640	5	5B
0005434251834	24640	6	6D
0005434251829	24640	7	18C
0005434251826	24640	8	20A
0005434251832	24640	9	20C
0005434251833	24640	10	23B
0005433679887	2821	1	1A
0005432222704	2821	2	1C
0005433679863	2821	3	1F
0005433679870	2821	4	2D
0005433679861	2821	5	2F
0005433679881	2821	6	3A
0005433679859	2821	7	3C
0005433679896	2821	8	4A
0005433679874	2821	9	4D
0005433679892	2821	10	4E
0005432222706	2821	11	4F
0005432222705	2821	12	5A
0005433679880	2821	13	5C
0005433684389	2821	14	5D
0005433679860	2821	15	5F
0005433679904	2821	16	6A
0005433679897	2821	17	6C
0005432222707	2821	18	7C
0005433679894	2821	19	7D
0005433679871	2821	20	7E
0005433679875	2821	21	8A
0005433679873	2821	22	8C
0005433679867	2821	23	8D
0005433679868	2821	24	8F
0005433679878	2821	25	9A
0005433679857	2821	26	10C
0005433679900	2821	27	10E
0005432222703	2821	28	10F
0005432222708	2821	29	11C
0005433679855	2821	30	11E
0005433679899	2821	31	12C
0005433679877	2821	32	12E
0005433679869	2821	33	13A
0005433679866	2821	34	13C
0005433679864	2821	35	13D
0005433679883	2821	36	13E
0005433679879	2821	37	14A
0005433679898	2821	38	14E
0005433679890	2821	39	14F
0005433679888	2821	40	15A
0005433679872	2821	41	15D
0005433679889	2821	42	15E
0005433679865	2821	43	15F
0005433679862	2821	44	16C
0005433679884	2821	45	16E
0005433679886	2821	46	17E
0005433679902	2821	47	17F
0005433679891	2821	48	18A
0005433679856	2821	49	18D
0005433679876	2821	50	18E
0005433679858	2821	51	18F
0005433679895	2821	52	19A
0005433679893	2821	53	19C
0005433679901	2821	54	19E
0005433679903	2821	55	20A
0005433679885	2821	56	20C
0005433679882	2821	57	20F
0005432966579	29142	1	1C
0005432966566	29142	2	1F
0005432966565	29142	3	2A
0005432966562	29142	4	2D
0005432966573	29142	5	3A
0005433679729	29142	6	3F
0005432966577	29142	7	4E
0005432966581	29142	8	6F
0005432966563	29142	9	7A
0005432005173	29142	10	7E
0005432966560	29142	11	8D
0005432966582	29142	12	8E
0005432966572	29142	13	9F
0005432966559	29142	14	10A
0005432966564	29142	15	11D
0005432966561	29142	16	11F
0005432966575	29142	17	12A
0005432966578	29142	18	12F
0005432966568	29142	19	13C
0005432966571	29142	20	13D
0005432966569	29142	21	13F
0005432966576	29142	22	14D
0005432966567	29142	23	14F
0005432966574	29142	24	15C
0005432966570	29142	25	18C
0005432966580	29142	26	20A
0005432966558	29142	27	20C
0005432966583	29142	28	20E
0005433613594	9290	1	1A
0005433613542	9290	2	1C
0005433613593	9290	3	1F
0005433613552	9290	4	1D
0005433613564	9290	5	2A
0005433613558	9290	6	2C
0005433613545	9290	7	2D
0005433577611	9290	8	3A
0005433577604	9290	9	3C
0005433613568	9290	10	3D
0005433633304	9290	11	4A
0005433633301	9290	12	4C
0005433633292	9290	13	4F
0005433613576	9290	14	4D
0005433613547	9290	15	5A
0005433613539	9290	16	5C
0005433633310	9290	17	5D
0005433613598	9290	18	6F
0005433613575	9290	19	6D
0005433613587	9290	20	7A
0005433633300	9290	21	7D
0005433613573	9290	22	7C
0005433613604	9290	23	7F
0005433633295	9290	24	8A
0005433613560	9290	25	8B
0005433613557	9290	26	8D
0005433613544	9290	27	8C
0005433633313	9290	28	8E
0005433613580	9290	29	8F
0005433633288	9290	30	9B
0005433633285	9290	31	9A
0005433633289	9290	32	9C
0005433577608	9290	33	9E
0005433613596	9290	34	9D
0005433613599	9290	35	9F
0005433613574	9290	36	10A
0005432756799	9290	37	10E
0005433633296	9290	38	10F
0005433633303	9290	39	11B
0005433633293	9290	40	11A
0005433613554	9290	41	11E
0005433613548	9290	42	12A
0005433613543	9290	43	11F
0005433577603	9290	44	12B
0005433633283	9290	45	12C
0005433613572	9290	46	13A
0005433577607	9290	47	12E
0005433613588	9290	48	13C
0005433633308	9290	49	13B
0005433613536	9290	50	13D
0005432755028	9290	51	13E
0005433613608	9290	52	14B
0005433613582	9290	53	14A
0005433577610	9290	54	14C
0005433613553	9290	55	14E
0005433633306	9290	56	14D
0005433613592	9290	57	14F
0005433613559	9290	58	15A
0005433577605	9290	59	15C
0005433633307	9290	60	16B
0005433613566	9290	61	16C
0005433633314	9290	62	16F
0005433633316	9290	63	17B
0005433613595	9290	64	17A
0005433613567	9290	65	17C
0005432756798	9290	66	17D
0005432145081	9290	67	17F
0005433613562	9290	68	17E
0005433613538	9290	69	18B
0005433613597	9290	70	18D
0005433613603	9290	71	18F
0005433613609	9290	72	19B
0005433577613	9290	73	19D
0005433613563	9290	74	19C
0005433633284	9290	75	20B
0005433613607	9290	76	20C
0005433613585	9290	77	20E
0005433633286	9290	78	20D
0005433613555	9290	79	20F
0005433577609	9290	80	21A
0005433633315	9290	81	21D
0005433613577	9290	82	21C
0005433577614	9290	83	21E
0005433613586	9290	84	22B
0005433613584	9290	85	22D
0005433633297	9290	86	22C
0005433613583	9290	87	22E
0005433613537	9290	88	23A
0005433633290	9290	89	23C
0005433613579	9290	90	23B
0005432755027	9290	91	23E
0005433613590	9290	92	23D
0005433613589	9290	93	23F
0005433613540	9290	94	24B
0005432145080	9290	95	24D
0005433613550	9290	96	24E
0005432756800	9290	97	25A
0005433613610	9290	98	25C
0005433613569	9290	99	25D
0005433633294	9290	100	25E
0005433613570	9290	101	26A
0005433613602	9290	102	25F
0005433633311	9290	103	26B
0005433613546	9290	104	26C
0005433633302	9290	105	26D
0005432755026	9290	106	26F
0005433633291	9290	107	26E
0005433613565	9290	108	27B
0005433577606	9290	109	27A
0005433613591	9290	110	27C
0005433633298	9290	111	27D
0005433613541	9290	112	27E
0005433613606	9290	113	28A
0005433633287	9290	114	27F
0005433613581	9290	115	28B
0005433613600	9290	116	28D
0005433577612	9290	117	28C
0005433613561	9290	118	28E
0005433633305	9290	119	28F
0005432145079	9290	120	29B
0005433613551	9290	121	29C
0005433633299	9290	122	29E
0005433613571	9290	123	30A
0005433613556	9290	124	29F
0005433613601	9290	125	30D
0005433613578	9290	126	30C
0005433633317	9290	127	30F
0005432756797	9290	128	31B
0005433633312	9290	129	31A
0005433613549	9290	130	31C
0005433633309	9290	131	31D
0005433613605	9290	132	31F
0005434152751	25223	1	1C
0005434152757	25223	2	1D
0005434163488	25223	3	1F
0005434273050	25223	4	2C
0005434152758	25223	5	3A
0005434163484	25223	6	3D
0005434163486	25223	7	5A
0005434163490	25223	8	8D
0005434163487	25223	9	9E
0005434152752	25223	10	10C
0005434163489	25223	11	12C
0005434163491	25223	12	12D
0005434273051	25223	13	13B
0005434163482	25223	14	14D
0005434152759	25223	15	14C
0005434152756	25223	16	17E
0005434152755	25223	17	18A
0005434272165	25223	18	21A
0005434163481	25223	19	26B
0005434152753	25223	20	26D
0005434163485	25223	21	27B
0005434152754	25223	22	28C
0005434163483	25223	23	28F
0005434272166	25223	24	29F
0005432184909	4241	1	16F
0005432184910	4241	2	22E
0005432184911	4241	3	37D
0005435856143	26598	1	2F
0005435856145	26598	2	11E
0005435856146	26598	3	11D
0005435947045	26598	4	12D
0005435947053	26598	5	13F
0005435856144	26598	6	16D
0005432571268	26598	7	17B
0005435947052	26598	8	19E
0005435947054	26598	9	19F
0005435947056	26598	10	24D
0005435947044	26598	11	24E
0005435947046	26598	12	27A
0005435947049	26598	13	27D
0005435856142	26598	14	27F
0005435947042	26598	15	31H
0005435787324	26598	16	32E
0005435947055	26598	17	32D
0005435947047	26598	18	33E
0005432571269	26598	19	33G
0005432571271	26598	20	33F
0005435947043	26598	21	34E
0005435947051	26598	22	34G
0005432571270	26598	23	35B
0005435787325	26598	24	35G
0005435947050	26598	25	36G
0005435947048	26598	26	39D
0005433568195	352	1	1A
0005433568219	352	2	2A
0005433568224	352	3	2F
0005433568202	352	4	2D
0005433568194	352	5	3D
0005433568201	352	6	3C
0005433568244	352	7	3F
0005432238847	352	8	5A
0005433568208	352	9	4F
0005432238850	352	10	5C
0005433568197	352	11	5F
0005433568234	352	12	6A
0005433568207	352	13	7C
0005433568227	352	14	7D
0005433568214	352	15	8E
0005433568230	352	16	8D
0005433568210	352	17	9B
0005433568206	352	18	9F
0005433568239	352	19	10E
0005433568249	352	20	11B
0005433568228	352	21	11C
0005433568245	352	22	11D
0005433568225	352	23	11E
0005433568218	352	24	12A
0005433568257	352	25	12C
0005432238849	352	26	12E
0005433568192	352	27	13B
0005433568196	352	28	13C
0005433568251	352	29	13E
0005433568233	352	30	13D
0005433568220	352	31	13F
0005433568212	352	32	14A
0005433568209	352	33	15A
0005433568236	352	34	15E
0005433568252	352	35	15D
0005433568247	352	36	15F
0005433568231	352	37	17F
0005432238848	352	38	17E
0005433568204	352	39	18A
0005433568222	352	40	18B
0005433568248	352	41	18C
0005433568226	352	42	18E
0005433568203	352	43	18D
0005433568229	352	44	18F
0005432238851	352	45	20C
0005433568215	352	46	20E
0005433568193	352	47	20F
0005433568200	352	48	22C
0005433568237	352	49	22E
0005433568213	352	50	22D
0005433568243	352	51	23B
0005433568246	352	52	23E
0005433568221	352	53	24B
0005433568235	352	54	24C
0005433568253	352	55	24E
0005433568199	352	56	24D
0005433568258	352	57	25A
0005433568205	352	58	26B
0005433568211	352	59	26C
0005433568241	352	60	26D
0005433568198	352	61	27A
0005433568254	352	62	27C
0005433568216	352	63	27D
0005433568223	352	64	28D
0005432238846	352	65	28E
0005433568255	352	66	29C
0005433568238	352	67	29D
0005433568242	352	68	30A
0005433568232	352	69	30C
0005433568250	352	70	30D
0005433568240	352	71	30F
0005433568217	352	72	31A
0005433568256	352	73	31C
0005433074301	11603	1	1D
0005433074291	11603	2	2D
0005433074300	11603	3	2F
0005432947881	11603	4	3C
0005433074313	11603	5	4A
0005432947884	11603	6	3F
0005433074296	11603	7	4C
0005432947859	11603	8	4D
0005432947861	11603	9	4F
0005432947876	11603	10	5D
0005433074307	11603	11	5F
0005433134071	11603	12	6C
0005432947849	11603	13	6A
0005432947879	11603	14	7A
0005432947854	11603	15	7C
0005432947863	11603	16	7F
0005432947868	11603	17	8A
0005432947867	11603	18	8B
0005432947886	11603	19	8C
0005432947864	11603	20	9A
0005432947860	11603	21	9B
0005433134075	11603	22	10B
0005433074284	11603	23	10D
0005432947870	11603	24	10C
0005433074308	11603	25	10F
0005432947858	11603	26	11C
0005432947888	11603	27	12A
0005433074304	11603	28	11F
0005432947877	11603	29	12C
0005433074303	11603	30	12E
0005432947855	11603	31	12F
0005432947885	11603	32	13E
0005432947865	11603	33	14A
0005432947874	11603	34	13F
0005433074289	11603	35	14D
0005432947852	11603	36	15A
0005433074302	11603	37	15B
0005433074294	11603	38	15E
0005433131643	11603	39	15F
0005433074287	11603	40	16A
0005433074292	11603	41	16B
0005432192274	11603	42	16D
0005432947862	11603	43	16E
0005432947887	11603	44	16F
0005433131642	11603	45	17A
0005433074286	11603	46	17F
0005432192276	11603	47	18A
0005432947872	11603	48	18E
0005433134070	11603	49	19C
0005433134072	11603	50	20A
0005432947856	11603	51	20B
0005432192275	11603	52	20C
0005433131640	11603	53	20D
0005433074290	11603	54	21D
0005433074305	11603	55	21E
0005433131641	11603	56	21F
0005433074295	11603	57	22D
0005432947866	11603	58	22F
0005432947869	11603	59	23A
0005432947853	11603	60	23B
0005433074293	11603	61	23D
0005433074312	11603	62	23E
0005432947857	11603	63	24A
0005433074306	11603	64	23F
0005433134073	11603	65	24B
0005433074285	11603	66	24D
0005432947875	11603	67	24C
0005432947848	11603	68	24E
0005432947882	11603	69	25A
0005433074309	11603	70	25E
0005433074310	11603	71	26D
0005432947851	11603	72	27A
0005432947846	11603	73	26F
0005432947878	11603	74	27C
0005433074297	11603	75	27D
0005433074288	11603	76	27F
0005432947883	11603	77	28A
0005432947873	11603	78	28D
0005432947850	11603	79	29A
0005432192273	11603	80	29C
0005432947847	11603	81	29D
0005433131644	11603	82	29F
0005432947871	11603	83	30B
0005433074314	11603	84	30D
0005432947880	11603	85	30E
0005433074298	11603	86	31A
0005433074311	11603	87	31C
0005433074299	11603	88	31D
0005433134074	11603	89	31F
0005433817418	9940	1	4B
0005433817416	9940	2	5A
0005433817417	9940	3	6A
0005433817415	9940	4	5B
0005434732929	13948	1	3A
0005434732932	13948	2	3B
0005434732930	13948	3	4A
0005434732931	13948	4	6A
0005435981656	2342	1	1F
0005435981658	2342	2	1G
0005432984502	2342	3	1H
0005432225966	2342	4	2C
0005433753423	2342	5	2F
0005435981673	2342	6	3A
0005432300180	2342	7	3B
0005435981653	2342	8	3C
0005433753435	2342	9	3F
0005435981681	2342	10	4B
0005433753430	2342	11	4F
0005435981678	2342	12	5A
0005435981659	2342	13	4H
0005433766587	2342	14	5B
0005435981687	2342	15	5G
0005435981654	2342	16	5H
0005432655364	2342	17	9A
0005435981667	2342	18	9H
0005435981677	2342	19	9G
0005435981671	2342	20	11A
0005433753420	2342	21	11D
0005433753412	2342	22	11F
0005433753403	2342	23	11G
0005435981686	2342	24	11H
0005432655370	2342	25	12D
0005433753395	2342	26	12B
0005435981646	2342	27	12E
0005435981664	2342	28	12G
0005433753436	2342	29	13A
0005432300184	2342	30	13D
0005432655363	2342	31	13B
0005433753397	2342	32	13H
0005432655371	2342	33	14D
0005432655373	2342	34	14F
0005435981660	2342	35	15A
0005435981668	2342	36	14H
0005435981652	2342	37	15E
0005433753399	2342	38	15D
0005433753410	2342	39	15H
0005433753434	2342	40	16B
0005433753406	2342	41	16E
0005433753401	2342	42	16G
0005432225970	2342	43	16F
0005433753402	2342	44	17A
0005433766586	2342	45	17D
0005435981674	2342	46	17F
0005433764650	2342	47	17G
0005432984501	2342	48	18B
0005433753400	2342	49	18D
0005433753426	2342	50	18E
0005432225967	2342	51	18G
0005433753415	2342	52	19A
0005433753424	2342	53	19D
0005433753432	2342	54	19G
0005435981684	2342	55	20A
0005433753408	2342	56	19H
0005433753443	2342	57	20D
0005433753409	2342	58	20B
0005435981651	2342	59	20H
0005433753447	2342	60	21B
0005433753438	2342	61	21A
0005432655369	2342	62	21E
0005432300181	2342	63	21F
0005435981665	2342	64	21H
0005433753414	2342	65	21G
0005433753418	2342	66	22A
0005435981661	2342	67	22D
0005433753416	2342	68	22F
0005432225969	2342	69	22E
0005433753425	2342	70	22G
0005435981675	2342	71	23A
0005435981685	2342	72	23E
0005432300179	2342	73	23G
0005433753445	2342	74	24A
0005435981647	2342	75	24E
0005435981683	2342	76	24D
0005433753427	2342	77	24F
0005433753450	2342	78	25E
0005433753411	2342	79	27A
0005433753404	2342	80	25F
0005433753437	2342	81	27D
0005435981645	2342	82	27F
0005435981672	2342	83	27E
0005435981676	2342	84	27H
0005435981682	2342	85	28D
0005433753413	2342	86	28E
0005432655367	2342	87	28G
0005433753444	2342	88	28H
0005433753449	2342	89	29A
0005435981648	2342	90	29D
0005433753394	2342	91	29E
0005433766585	2342	92	29G
0005435981689	2342	93	30A
0005433753428	2342	94	30D
0005435981669	2342	95	30E
0005432655372	2342	96	30G
0005432300183	2342	97	31A
0005433753429	2342	98	31D
0005432300178	2342	99	31F
0005433753419	2342	100	31G
0005435981680	2342	101	32D
0005433753407	2342	102	32G
0005435981662	2342	103	32F
0005432300182	2342	104	32E
0005433753405	2342	105	32H
0005433753417	2342	106	33D
0005433753398	2342	107	33H
0005433753421	2342	108	33G
0005435981688	2342	109	34A
0005433753448	2342	110	34E
0005433753422	2342	111	34G
0005435981657	2342	112	34H
0005435981655	2342	113	35B
0005432655365	2342	114	35A
0005433753431	2342	115	35D
0005432655366	2342	116	35F
0005433753396	2342	117	36A
0005432225968	2342	118	35H
0005435981670	2342	119	36D
0005435981649	2342	120	36E
0005435981666	2342	121	37D
0005433753446	2342	122	37B
0005432655368	2342	123	37F
0005433753442	2342	124	37H
0005433753441	2342	125	38A
0005435981679	2342	126	38B
0005433753433	2342	127	38D
0005433753440	2342	128	38F
0005432655374	2342	129	38H
0005435981663	2342	130	38G
0005435981650	2342	131	39D
0005433753439	2342	132	39F
0005432051085	26206	1	1F
0005433434290	26206	2	2G
0005432984615	26206	3	3C
0005433434277	26206	4	3B
0005432984618	26206	5	3G
0005433434284	26206	6	3F
0005432984609	26206	7	4F
0005433434275	26206	8	4C
0005432984621	26206	9	5A
0005432984612	26206	10	5F
0005432984631	26206	11	5C
0005432984600	26206	12	9A
0005433434292	26206	13	5H
0005433434267	26206	14	11A
0005432984617	26206	15	9H
0005432049413	26206	16	11E
0005433434273	26206	17	11D
0005433434272	26206	18	11F
0005432984619	26206	19	11H
0005432984616	26206	20	12B
0005433434266	26206	21	12H
0005432984604	26206	22	13D
0005433434286	26206	23	13E
0005432049412	26206	24	14G
0005432984613	26206	25	15D
0005433434285	26206	26	15F
0005432984606	26206	27	16A
0005433434276	26206	28	16B
0005432869429	26206	29	16E
0005432869426	26206	30	16F
0005433434279	26206	31	16H
0005432984602	26206	32	17D
0005433434278	26206	33	17E
0005433434287	26206	34	18H
0005434731112	26206	35	19B
0005432869430	26206	36	19A
0005432984627	26206	37	19F
0005433753280	26206	38	20A
0005432049411	26206	39	20E
0005433434288	26206	40	20G
0005432984630	26206	41	21A
0005432984622	26206	42	21B
0005432984607	26206	43	21H
0005432984611	26206	44	22E
0005433434281	26206	45	23B
0005432984601	26206	46	23E
0005433434282	26206	47	23D
0005432051083	26206	48	23F
0005432869425	26206	49	24A
0005433434274	26206	50	24D
0005433434270	26206	51	25D
0005434731111	26206	52	27A
0005433434269	26206	53	27F
0005433434289	26206	54	28B
0005433434294	26206	55	28G
0005433434283	26206	56	29A
0005432984614	26206	57	29F
0005432984623	26206	58	30A
0005434731110	26206	59	30E
0005432984608	26206	60	31B
0005432984610	26206	61	31F
0005432984629	26206	62	31G
0005433434280	26206	63	32D
0005432984620	26206	64	33A
0005433753227	26206	65	33E
0005433434271	26206	66	33D
0005432869424	26206	67	33F
0005433434293	26206	68	33H
0005432984632	26206	69	34B
0005432984605	26206	70	34A
0005432984625	26206	71	34D
0005432984603	26206	72	35B
0005432869427	26206	73	35H
0005432984624	26206	74	36D
0005432869428	26206	75	37A
0005432984628	26206	76	37G
0005433434268	26206	77	38D
0005432984626	26206	78	38E
0005433434291	26206	79	38H
0005432051084	26206	80	39F
0005434731109	26206	81	39E
0005434374028	1486	1	1A
0005434374016	1486	2	1C
0005433460405	1486	3	2A
0005434374015	1486	4	1F
0005434374010	1486	5	2C
0005434374011	1486	6	2F
0005434374005	1486	7	4B
0005434374041	1486	8	4D
0005434374043	1486	9	4F
0005432267797	1486	10	5C
0005434374006	1486	11	5F
0005434374034	1486	12	6B
0005432267803	1486	13	6D
0005433460407	1486	14	7C
0005434374036	1486	15	7E
0005434374019	1486	16	7D
0005434374021	1486	17	8A
0005434374032	1486	18	7F
0005434373997	1486	19	8B
0005434374050	1486	20	8D
0005434374004	1486	21	8C
0005434374025	1486	22	8E
0005434374024	1486	23	9A
0005434374030	1486	24	9C
0005433460406	1486	25	9F
0005434374031	1486	26	10B
0005433461556	1486	27	10D
0005434374040	1486	28	11A
0005434374049	1486	29	11E
0005434374017	1486	30	11F
0005434374046	1486	31	12A
0005434374035	1486	32	12C
0005434374047	1486	33	12D
0005433461558	1486	34	12F
0005432267802	1486	35	13B
0005434374013	1486	36	13C
0005432267801	1486	37	13D
0005433150857	1486	38	13E
0005434373998	1486	39	14A
0005434374045	1486	40	14B
0005434373996	1486	41	14C
0005434374020	1486	42	14F
0005434374037	1486	43	14E
0005434374002	1486	44	15F
0005434374003	1486	45	16D
0005434374027	1486	46	17B
0005434374012	1486	47	17A
0005433461557	1486	48	17C
0005434374007	1486	49	17D
0005434374029	1486	50	18A
0005434374026	1486	51	18B
0005434374038	1486	52	18D
0005434374023	1486	53	18F
0005433150826	1486	54	19A
0005434374022	1486	55	19C
0005434373999	1486	56	19E
0005434374044	1486	57	20B
0005432267800	1486	58	20A
0005434374009	1486	59	20D
0005434374042	1486	60	20C
0005434374001	1486	61	21D
0005432267799	1486	62	22A
0005434374008	1486	63	21F
0005433150825	1486	64	22C
0005434374018	1486	65	22D
0005434374048	1486	66	22E
0005434374039	1486	67	22F
0005434374033	1486	68	23B
0005434374000	1486	69	23C
0005434373995	1486	70	23E
0005434374014	1486	71	23D
0005432267798	1486	72	23F
0005433150923	20131	1	1A
0005433150904	20131	2	1F
0005433150920	20131	3	2C
0005433150916	20131	4	2F
0005433150922	20131	5	3C
0005433150927	20131	6	4B
0005433150899	20131	7	4D
0005433150907	20131	8	4E
0005434029623	20131	9	4F
0005433150933	20131	10	5D
0005433150925	20131	11	5C
0005433150917	20131	12	6C
0005433150912	20131	13	7A
0005432056245	20131	14	7E
0005433150926	20131	15	7D
0005433764650	20131	16	8B
0005432056246	20131	17	8C
0005433150928	20131	18	8D
0005433150905	20131	19	8F
0005433150924	20131	20	9B
0005434029621	20131	21	9C
0005433150902	20131	22	12B
0005433150903	20131	23	12D
0005433150915	20131	24	12C
0005433150930	20131	25	12E
0005433150929	20131	26	13B
0005433150919	20131	27	13E
0005433931424	20131	28	13F
0005433150921	20131	29	14A
0005433150932	20131	30	14E
0005432056247	20131	31	15A
0005433150913	20131	32	15D
0005433150908	20131	33	15F
0005434029622	20131	34	16B
0005433150906	20131	35	16C
0005433150910	20131	36	16F
0005433931423	20131	37	19B
0005433150900	20131	38	19C
0005433150918	20131	39	20C
0005433150909	20131	40	20F
0005433150901	20131	41	21B
0005432056244	20131	42	22B
0005433150911	20131	43	22A
0005433150914	20131	44	22D
0005433150931	20131	45	22F
0005433931425	20131	46	23B
0005432056243	20131	47	23E
0005432282764	536	1	1D
0005432423776	536	2	2F
0005432423778	536	3	3A
0005432423767	536	4	3C
0005432423784	536	5	3D
0005432423796	536	6	4C
0005432423806	536	7	5A
0005432423774	536	8	5F
0005432423807	536	9	7A
0005432423789	536	10	8A
0005432423809	536	11	8D
0005432423793	536	12	8E
0005432423764	536	13	8F
0005432423794	536	14	9C
0005432423766	536	15	10A
0005432423797	536	16	10D
0005432423763	536	17	10F
0005432423800	536	18	11A
0005432423770	536	19	11E
0005432423781	536	20	12F
0005432423773	536	21	13C
0005432423765	536	22	13D
0005432423780	536	23	14F
0005432423790	536	24	15B
0005432423803	536	25	15A
0005432423768	536	26	15C
0005432423779	536	27	15F
0005432423775	536	28	15E
0005432423769	536	29	17C
0005432423795	536	30	18C
0005432423802	536	31	20A
0005432423798	536	32	19E
0005432423792	536	33	21A
0005432282767	536	34	21D
0005432282760	536	35	22A
0005432423788	536	36	22D
0005432423777	536	37	22F
0005432423782	536	38	22E
0005432282762	536	39	23D
0005432423799	536	40	24D
0005432282761	536	41	24E
0005432423808	536	42	24F
0005432423783	536	43	25A
0005432423786	536	44	25F
0005432423804	536	45	26A
0005432423772	536	46	26B
0005432423787	536	47	27C
0005432423805	536	48	28E
0005432423785	536	49	28D
0005432282765	536	50	29A
0005432423801	536	51	30E
0005432282763	536	52	31A
0005432282766	536	53	31B
0005432423791	536	54	31F
0005432423771	536	55	31E
0005432302277	12877	1	1A
0005432302275	12877	2	2F
0005432302276	12877	3	9C
0005432302278	12877	4	17A
0005434022725	465	1	1C
0005434022724	465	2	1H
0005434031953	465	3	1G
0005434022713	465	4	2B
0005434022736	465	5	2F
0005434022721	465	6	2G
0005432235532	465	7	3C
0005434029620	465	8	3G
0005434022774	465	9	4B
0005434022734	465	10	4H
0005434022729	465	11	5B
0005434022714	465	12	5G
0005434029619	465	13	9B
0005434028255	465	14	11D
0005434022718	465	15	11G
0005434022711	465	16	12A
0005434022762	465	17	12E
0005434022709	465	18	12F
0005434022763	465	19	12H
0005434022732	465	20	12G
0005434022756	465	21	13B
0005434031955	465	22	13E
0005434022772	465	23	13F
0005434022722	465	24	13H
0005434022717	465	25	14F
0005434022752	465	26	14E
0005434022712	465	27	14H
0005434022768	465	28	15D
0005434028254	465	29	15E
0005434022715	465	30	16D
0005434022748	465	31	16E
0005434022746	465	32	16F
0005434022735	465	33	17D
0005434022723	465	34	17H
0005434022726	465	35	18E
0005434022710	465	36	19F
0005432235533	465	37	19E
0005434022720	465	38	19H
0005434022753	465	39	20B
0005434022730	465	40	20F
0005434022731	465	41	20G
0005434022773	465	42	21B
0005434022737	465	43	21H
0005434028256	465	44	22D
0005434022716	465	45	22B
0005434022751	465	46	23A
0005434022767	465	47	23D
0005433057197	465	48	23B
0005434022754	465	49	23F
0005434022760	465	50	23G
0005434022750	465	51	24A
0005434022719	465	52	24D
0005434031956	465	53	24F
0005434022742	465	54	25D
0005434022757	465	55	27B
0005434022777	465	56	27D
0005434022741	465	57	27F
0005434022740	465	58	27E
0005432235530	465	59	27H
0005434022758	465	60	28G
0005434022744	465	61	28H
0005434022743	465	62	29D
0005434031954	465	63	29B
0005434022761	465	64	29F
0005434022739	465	65	29H
0005432235527	465	66	30A
0005434022764	465	67	31G
0005432235531	465	68	32B
0005434022759	465	69	32E
0005432045584	465	70	32F
0005434022766	465	71	32H
0005432235528	465	72	33B
0005434022738	465	73	33D
0005432235534	465	74	33H
0005434022775	465	75	34A
0005434022733	465	76	34D
0005432235529	465	77	34B
0005433057196	465	78	34F
0005434022755	465	79	34G
0005434022769	465	80	34H
0005434022771	465	81	35B
0005434022728	465	82	35E
0005434022749	465	83	36B
0005434022747	465	84	37D
0005433057195	465	85	37F
0005434022776	465	86	37E
0005434022745	465	87	37H
0005434022765	465	88	38H
0005434022770	465	89	38G
0005434022727	465	90	39E
0005433684392	12677	1	1F
0005434735614	12677	2	1H
0005433057293	12677	3	1G
0005434022545	12677	4	3H
0005432156303	12677	5	4B
0005433057291	12677	6	4C
0005432156302	12677	7	4G
0005434735613	12677	8	9A
0005433057299	12677	9	9H
0005433684390	12677	10	11F
0005433929553	12677	11	13D
0005433057320	12677	12	15G
0005433057316	12677	13	16F
0005433057303	12677	14	16G
0005433057305	12677	15	17G
0005433057323	12677	16	18A
0005433057296	12677	17	18D
0005433057332	12677	18	18H
0005434735616	12677	19	20F
0005433057322	12677	20	20G
0005433057327	12677	21	21D
0005432157464	12677	22	21E
0005434735617	12677	23	21G
0005433057317	12677	24	22B
0005434735615	12677	25	22D
0005433057306	12677	26	22H
0005433057326	12677	27	24B
0005433057297	12677	28	24E
0005433057294	12677	29	24G
0005433057328	12677	30	25D
0005433057324	12677	31	25F
0005433057292	12677	32	27D
0005433057311	12677	33	27H
0005433057308	12677	34	29G
0005433929554	12677	35	29H
0005433684391	12677	36	30E
0005433057330	12677	37	31A
0005432156300	12677	38	31E
0005433057321	12677	39	32A
0005433057309	12677	40	32F
0005433057314	12677	41	33A
0005433057310	12677	42	33E
0005433057307	12677	43	33G
0005433057304	12677	44	34A
0005433057300	12677	45	34B
0005433057319	12677	46	34E
0005433057295	12677	47	34F
0005433057325	12677	48	35A
0005433929555	12677	49	34H
0005433057315	12677	50	35D
0005433057329	12677	51	35G
0005433057331	12677	52	36A
0005433057301	12677	53	36E
0005433057298	12677	54	36H
0005432156301	12677	55	38A
0005433057302	12677	56	38D
0005433057318	12677	57	38E
0005433057313	12677	58	38F
0005433057312	12677	59	39E
0005433529216	13824	1	1A
0005433527207	13824	2	1F
0005433527200	13824	3	2A
0005433529211	13824	4	4C
0005433527203	13824	5	5C
0005433527205	13824	6	7A
0005433529219	13824	7	7D
0005433527202	13824	8	7F
0005433529214	13824	9	8B
0005433529218	13824	10	8F
0005433527199	13824	11	10B
0005433527210	13824	12	10E
0005433529213	13824	13	11C
0005433529215	13824	14	12B
0005433529210	13824	15	12D
0005433529220	13824	16	12C
0005433527201	13824	17	12F
0005433529221	13824	18	13E
0005433529212	13824	19	15C
0005433527206	13824	20	15F
0005433527208	13824	21	17B
0005433527209	13824	22	18F
0005433529217	13824	23	21C
0005433527204	13824	24	21D
0005433921964	2142	1	1A
0005433921888	2142	2	1C
0005433921899	2142	3	1H
0005433921950	2142	4	2A
0005433921893	2142	5	2B
0005433921926	2142	6	2F
0005433929555	2142	7	3B
0005433921937	2142	8	3A
0005432231410	2142	9	3G
0005432231415	2142	10	3H
0005433921975	2142	11	4C
0005433921890	2142	12	4A
0005433921883	2142	13	4G
0005433921898	2142	14	5C
0005433931423	2142	15	5F
0005433921911	2142	16	5H
0005433921885	2142	17	9B
0005433921927	2142	18	11A
0005433921948	2142	19	11D
0005432044485	2142	20	11F
0005433921921	2142	21	11G
0005433921925	2142	22	12A
0005433921979	2142	23	12E
0005433921952	2142	24	12F
0005433921961	2142	25	12H
0005433921908	2142	26	13A
0005432231414	2142	27	13E
0005433921906	2142	28	13G
0005433921959	2142	29	13H
0005433921946	2142	30	14B
0005433921918	2142	31	14H
0005433921960	2142	32	15B
0005433875355	2142	33	15E
0005433921936	2142	34	15D
0005433921943	2142	35	16B
0005433921882	2142	36	16A
0005433921969	2142	37	16F
0005433921938	2142	38	16E
0005433921892	2142	39	16D
0005433921903	2142	40	16H
0005433931424	2142	41	16G
0005433921919	2142	42	17B
0005432044484	2142	43	17A
0005433929554	2142	44	17D
0005433921970	2142	45	17F
0005433921913	2142	46	17E
0005433921958	2142	47	18A
0005433921945	2142	48	18E
0005433921956	2142	49	18F
0005433921957	2142	50	18G
0005433921884	2142	51	19A
0005433921891	2142	52	19D
0005433921909	2142	53	19G
0005433921972	2142	54	20A
0005433921933	2142	55	20D
0005433921977	2142	56	20B
0005433921910	2142	57	20F
0005433921942	2142	58	20E
0005433921915	2142	59	20G
0005433921973	2142	60	21A
0005433921955	2142	61	21D
0005433931425	2142	62	21E
0005433921914	2142	63	21F
0005433921967	2142	64	21H
0005433921889	2142	65	21G
0005433921941	2142	66	22A
0005432231412	2142	67	22D
0005433921904	2142	68	22B
0005433921887	2142	69	22E
0005432231409	2142	70	22G
0005433921917	2142	71	22H
0005433921901	2142	72	23B
0005433921968	2142	73	23A
0005433921895	2142	74	23E
0005433921894	2142	75	24D
0005433921932	2142	76	24F
0005433921929	2142	77	24G
0005432231408	2142	78	25D
0005433921940	2142	79	24H
0005432231413	2142	80	27B
0005433921939	2142	81	27A
0005433921920	2142	82	27F
0005433921971	2142	83	28A
0005433921949	2142	84	28B
0005433921922	2142	85	28D
0005432231407	2142	86	29A
0005433921897	2142	87	29D
0005433921907	2142	88	30B
0005433921928	2142	89	30A
0005433921976	2142	90	30F
0005433921935	2142	91	31B
0005433921962	2142	92	31G
0005433921931	2142	93	31F
0005433921963	2142	94	31H
0005433921912	2142	95	32B
0005433921923	2142	96	32E
0005433921881	2142	97	32H
0005433921947	2142	98	32G
0005432044483	2142	99	33A
0005433921924	2142	100	33D
0005433921896	2142	101	33F
0005433921934	2142	102	33H
0005433921953	2142	103	34A
0005432231416	2142	104	34D
0005433921965	2142	105	34E
0005433921905	2142	106	35B
0005433921954	2142	107	35D
0005433921900	2142	108	35F
0005433921966	2142	109	35E
0005433921978	2142	110	35G
0005433921886	2142	111	36B
0005432231411	2142	112	36A
0005433929553	2142	113	36D
0005433921916	2142	114	36F
0005433875356	2142	115	36G
0005433921974	2142	116	37D
0005433921930	2142	117	37F
0005433921944	2142	118	37E
0005433921951	2142	119	37H
0005433921902	2142	120	39D
0005433035558	24117	1	1A
0005432206114	24117	2	1F
0005433035552	24117	3	1H
0005433035521	24117	4	2B
0005433035547	24117	5	2C
0005433035524	24117	6	2H
0005434028258	24117	7	2F
0005433035565	24117	8	3B
0005433035548	24117	9	3C
0005432749753	24117	10	3G
0005433035569	24117	11	3H
0005433035536	24117	12	4G
0005433035527	24117	13	4H
0005433035543	24117	14	5B
0005433035523	24117	15	5C
0005433035519	24117	16	9B
0005432206111	24117	17	11A
0005433035531	24117	18	12F
0005433035540	24117	19	13A
0005433035563	24117	20	13G
0005433035526	24117	21	14H
0005432206110	24117	22	15B
0005433035532	24117	23	15G
0005433035553	24117	24	15F
0005432207626	24117	25	16B
0005433035525	24117	26	16E
0005433035562	24117	27	16G
0005433035535	24117	28	17B
0005433035530	24117	29	17D
0005434028260	24117	30	17H
0005433035557	24117	31	18B
0005432749754	24117	32	21H
0005433035554	24117	33	22E
0005433035546	24117	34	23B
0005433035537	24117	35	23A
0005433035522	24117	36	23D
0005433035566	24117	37	23H
0005434028259	24117	38	24G
0005433035550	24117	39	27D
0005432206112	24117	40	28A
0005433035551	24117	41	28B
0005433035533	24117	42	28D
0005433035549	24117	43	28F
0005433035568	24117	44	28E
0005433035528	24117	45	29A
0005432206113	24117	46	30B
0005433035567	24117	47	30F
0005433035571	24117	48	31D
0005433035545	24117	49	32A
0005433035520	24117	50	33A
0005433035534	24117	51	33B
0005434028257	24117	52	33F
0005433035561	24117	53	33H
0005433035539	24117	54	34A
0005433035560	24117	55	34D
0005433035570	24117	56	34F
0005432207625	24117	57	34H
0005432207624	24117	58	36A
0005433035564	24117	59	36B
0005433035541	24117	60	36D
0005433035542	24117	61	36H
0005433035555	24117	62	37D
0005433035559	24117	63	37F
0005433035538	24117	64	37G
0005433035556	24117	65	38A
0005433035544	24117	66	38G
0005433035529	24117	67	39E
0005434723801	251	1	1C
0005434723687	251	2	1A
0005434723791	251	3	1H
0005434723695	251	4	1G
0005434550440	251	5	1D
0005434723782	251	6	2C
0005435142380	251	7	2A
0005434723768	251	8	2D
0005434723796	251	9	3A
0005434723795	251	10	2K
0005434550470	251	11	2H
0005432277616	251	12	3C
0005434723743	251	13	3H
0005432277611	251	14	4C
0005434735610	251	15	4A
0005434723731	251	16	4K
0005434723765	251	17	5C
0005435142384	251	18	5A
0005434550432	251	19	11A
0005434723778	251	20	11D
0005434723720	251	21	11K
0005434723751	251	22	12C
0005435142387	251	23	12F
0005434723771	251	24	12E
0005434550436	251	25	12G
0005434723692	251	26	12H
0005434723774	251	27	13C
0005434723735	251	28	13F
0005434550425	251	29	13E
0005434723757	251	30	13D
0005434723721	251	31	14A
0005434550449	251	32	13K
0005434550434	251	33	14C
0005432277618	251	34	14F
0005434550448	251	35	14H
0005434723775	251	36	15C
0005434723736	251	37	15A
0005434723754	251	38	15F
0005434550469	251	39	15E
0005434723724	251	40	16A
0005434550451	251	41	15K
0005434550444	251	42	16D
0005434723730	251	43	16K
0005434723688	251	44	17F
0005432277610	251	45	17H
0005434723714	251	46	18C
0005434723694	251	47	18F
0005434550426	251	48	18K
0005434723710	251	49	19A
0005434723733	251	50	19E
0005434550471	251	51	19G
0005434550464	251	52	20A
0005434723793	251	53	19K
0005434723685	251	54	20C
0005434550476	251	55	20D
0005434550473	251	56	20G
0005434550437	251	57	20F
0005434302397	251	58	20K
0005434731108	251	59	20J
0005434550455	251	60	21B
0005434550465	251	61	21A
0005434731106	251	62	21D
0005434550458	251	63	21C
0005434723698	251	64	21J
0005434550481	251	65	21G
0005434723707	251	66	22A
0005434723752	251	67	21K
0005434723763	251	68	22B
0005434302396	251	69	22E
0005434723725	251	70	22H
0005434550463	251	71	23A
0005434723717	251	72	23D
0005435142379	251	73	23C
0005434550438	251	74	24D
0005435142389	251	75	23J
0005434723729	251	76	24F
0005434550478	251	77	24E
0005434723781	251	78	25A
0005434550453	251	79	25C
0005434550456	251	80	25F
0005434550452	251	81	25E
0005434550475	251	82	25H
0005432277620	251	83	25K
0005434731104	251	84	26G
0005434731107	251	85	26F
0005434723705	251	86	26J
0005434723804	251	87	26H
0005432277612	251	88	27A
0005434723691	251	89	27C
0005434723715	251	90	27D
0005434735609	251	91	27H
0005434550468	251	92	27G
0005434550435	251	93	27K
0005434723683	251	94	27J
0005434723789	251	95	28B
0005434731105	251	96	28C
0005434723776	251	97	28J
0005434723699	251	98	29D
0005434723784	251	99	29C
0005434550442	251	100	29E
0005434723690	251	101	29J
0005434723734	251	102	30C
0005432277614	251	103	30B
0005434723684	251	104	30D
0005434550461	251	105	30H
0005434723709	251	106	30G
0005434723756	251	107	30J
0005434550460	251	108	31B
0005434723758	251	109	31A
0005434723788	251	110	30K
0005434723786	251	111	31D
0005434723693	251	112	31E
0005434723708	251	113	31H
0005434550427	251	114	31K
0005434723728	251	115	32C
0005434723779	251	116	32E
0005434550447	251	117	32G
0005434723719	251	118	32F
0005434723700	251	119	32K
0005434723803	251	120	33C
0005434723802	251	121	33B
0005434723746	251	122	33E
0005434302398	251	123	33H
0005434550459	251	124	33K
0005434723732	251	125	33J
0005434723742	251	126	34B
0005434723761	251	127	34E
0005434550429	251	128	34F
0005434723738	251	129	35B
0005434550477	251	130	35A
0005434723773	251	131	34K
0005434723718	251	132	35D
0005434723777	251	133	35C
0005432277622	251	134	35G
0005434723759	251	135	35F
0005434723712	251	136	35H
0005434735611	251	137	35J
0005434550431	251	138	36C
0005434723740	251	139	36F
0005434723722	251	140	36D
0005434723794	251	141	36H
0005434723696	251	142	36G
0005434550467	251	143	36K
0005434723797	251	144	36J
0005434550428	251	145	37A
0005434723780	251	146	37C
0005434723769	251	147	37F
0005434550479	251	148	37K
0005434723744	251	149	38J
0005434550443	251	150	38K
0005434723783	251	151	39D
0005432277615	251	152	39C
0005432277621	251	153	39B
0005435142377	251	154	39G
0005434550433	251	155	39F
0005434723739	251	156	39H
0005434723745	251	157	39J
0005434735612	251	158	40C
0005434723689	251	159	40B
0005434550462	251	160	40G
0005434723747	251	161	40F
0005434723755	251	162	40J
0005434550445	251	163	41C
0005434723716	251	164	41G
0005434723711	251	165	41F
0005434550439	251	166	41E
0005435142383	251	167	41H
0005434550466	251	168	42A
0005434723702	251	169	41J
0005434723767	251	170	42C
0005434302395	251	171	42E
0005434723753	251	172	42D
0005434723785	251	173	42F
0005435142385	251	174	42J
0005434723737	251	175	42H
0005435142378	251	176	43B
0005434723766	251	177	43A
0005434723741	251	178	42K
0005434723790	251	179	43D
0005434550457	251	180	43E
0005434723706	251	181	43H
0005434550454	251	182	44C
0005434723760	251	183	44B
0005434723727	251	184	44E
0005434723772	251	185	44D
0005434723750	251	186	44G
0005434550446	251	187	45A
0005434723764	251	188	45C
0005434735607	251	189	45F
0005434723799	251	190	45E
0005432277613	251	191	45H
0005434550450	251	192	46A
0005434550480	251	193	45K
0005435142381	251	194	46C
0005434550472	251	195	46B
0005434550430	251	196	46G
0005434723713	251	197	46F
0005434723787	251	198	46K
0005435142382	251	199	47A
0005435142386	251	200	47E
0005434723762	251	201	47F
0005433233099	251	202	47H
0005434723726	251	203	48C
0005434723800	251	204	48E
0005434723770	251	205	48G
0005434735608	251	206	48F
0005434723703	251	207	48K
0005434723748	251	208	49C
0005434723686	251	209	49F
0005434550474	251	210	49E
0005434723798	251	211	49K
0005434723723	251	212	49H
0005434723701	251	213	50A
0005434723697	251	214	50F
0005434723749	251	215	50D
0005432277619	251	216	50H
0005435142388	251	217	50G
0005434723792	251	218	50K
0005432277617	251	219	51F
0005434550441	251	220	51E
0005433233100	251	221	51D
0005434723704	251	222	51G
0005433233332	9861	1	2D
0005433766586	9861	2	2C
0005433233310	9861	3	3D
0005433233304	9861	4	4A
0005433233328	9861	5	4G
0005433289742	9861	6	5D
0005433180745	9861	7	11D
0005434031958	9861	8	11C
0005433180735	9861	9	12A
0005433233294	9861	10	13D
0005433129208	9861	11	13F
0005433233333	9861	12	13E
0005434723311	9861	13	13H
0005433233287	9861	14	13G
0005433233290	9861	15	13K
0005433233288	9861	16	14C
0005433233300	9861	17	14K
0005432199145	9861	18	14G
0005433180727	9861	19	15E
0005432199146	9861	20	15D
0005433233281	9861	21	15G
0005433129211	9861	22	15K
0005432199148	9861	23	18C
0005433113504	9861	24	18B
0005433289743	9861	25	18A
0005433233320	9861	26	18G
0005433233318	9861	27	18K
0005433233327	9861	28	19H
0005433129210	9861	29	20A
0005433233283	9861	30	19K
0005433180733	9861	31	20C
0005433126777	9861	32	20D
0005433233286	9861	33	20F
0005433233311	9861	34	22C
0005433233282	9861	35	22B
0005433233317	9861	36	22H
0005433233331	9861	37	22K
0005434031960	9861	38	22J
0005433180730	9861	39	23A
0005433233303	9861	40	23C
0005433126779	9861	41	23G
0005433233334	9861	42	24D
0005433233316	9861	43	24E
0005433233284	9861	44	25A
0005433180747	9861	45	25B
0005433233309	9861	46	25D
0005433766587	9861	47	25H
0005433233321	9861	48	25G
0005433180732	9861	49	26A
0005433233336	9861	50	26C
0005433233277	9861	51	26G
0005433233280	9861	52	26H
0005433233326	9861	53	27D
0005432199147	9861	54	27E
0005433233308	9861	55	27H
0005433126778	9861	56	27K
0005433233323	9861	57	27J
0005433289745	9861	58	28C
0005432199149	9861	59	28G
0005433180744	9861	60	29D
0005434031961	9861	61	29F
0005433233324	9861	62	30B
0005433113503	9861	63	30K
0005433233301	9861	64	31B
0005433233298	9861	65	31C
0005433233291	9861	66	31G
0005433180736	9861	67	31K
0005433180729	9861	68	32B
0005433233293	9861	69	32G
0005433233306	9861	70	32F
0005433180741	9861	71	33A
0005433233289	9861	72	33D
0005433233299	9861	73	33E
0005433233302	9861	74	33G
0005432199152	9861	75	34C
0005433233278	9861	76	34E
0005433289740	9861	77	34D
0005433180726	9861	78	34G
0005433180743	9861	79	35J
0005433180738	9861	80	36F
0005433233296	9861	81	36E
0005433233285	9861	82	36H
0005433180739	9861	83	36J
0005433233275	9861	84	37G
0005433180737	9861	85	37F
0005433233297	9861	86	37E
0005433180728	9861	87	37K
0005432199150	9861	88	39D
0005433233307	9861	89	39J
0005433233292	9861	90	40A
0005433129209	9861	91	40E
0005434031959	9861	92	40J
0005433766585	9861	93	41A
0005433289739	9861	94	41E
0005433233335	9861	95	41H
0005433233313	9861	96	42D
0005433233312	9861	97	42F
0005433180746	9861	98	42K
0005433129207	9861	99	42J
0005433180742	9861	100	43A
0005434031957	9861	101	43E
0005433233274	9861	102	44E
0005433289744	9861	103	44F
0005433233279	9861	104	44J
0005433180749	9861	105	45D
0005433233276	9861	106	45C
0005433233295	9861	107	46A
0005433289741	9861	108	46G
0005433233319	9861	109	46F
0005433126780	9861	110	47A
0005433233329	9861	111	47F
0005433233330	9861	112	47H
0005433233315	9861	113	48A
0005433233325	9861	114	48K
0005433180731	9861	115	49C
0005433233322	9861	116	49G
0005433233273	9861	117	49F
0005433233305	9861	118	49K
0005434723312	9861	119	50C
0005433113502	9861	120	50A
0005432199151	9861	121	50E
0005433180748	9861	122	50D
0005433233314	9861	123	50F
0005433180740	9861	124	50K
0005433180750	9861	125	50H
0005433180734	9861	126	51G
0005435212331	7763	1	1A
0005432069440	7763	2	1H
0005434066551	7763	3	1G
0005432069444	7763	4	1D
0005434066531	7763	5	2C
0005434066564	7763	6	2A
0005432526090	7763	7	2G
0005434066524	7763	8	2D
0005432526135	7763	9	2K
0005432150085	7763	10	2H
0005432526110	7763	11	3D
0005432526136	7763	12	3C
0005432535761	7763	13	3H
0005432535764	7763	14	4H
0005434066575	7763	15	4G
0005432526126	7763	16	4D
0005434066579	7763	17	5C
0005432526077	7763	18	5A
0005432526042	7763	19	11C
0005432526153	7763	20	11F
0005432526082	7763	21	11E
0005432526078	7763	22	11H
0005434066553	7763	23	12A
0005432526115	7763	24	12E
0005434066565	7763	25	12G
0005432150082	7763	26	12F
0005434066567	7763	27	12K
0005432069446	7763	28	12H
0005432526166	7763	29	13A
0005432069445	7763	30	13K
0005432526137	7763	31	14E
0005432526105	7763	32	14C
0005434066583	7763	33	14F
0005432533249	7763	34	14K
0005432069447	7763	35	14H
0005432526049	7763	36	15C
0005432150083	7763	37	15A
0005434066532	7763	38	15K
0005434066577	7763	39	15H
0005434066528	7763	40	16C
0005434066554	7763	41	16A
0005432526104	7763	42	16F
0005432526051	7763	43	16E
0005434066574	7763	44	16H
0005434066530	7763	45	17A
0005432526121	7763	46	17E
0005432526095	7763	47	17D
0005432535762	7763	48	17H
0005432526168	7763	49	17G
0005432533250	7763	50	18C
0005432069439	7763	51	18B
0005432526036	7763	52	18D
0005432526160	7763	53	18E
0005432526107	7763	54	18H
0005434066563	7763	55	19B
0005432526145	7763	56	18K
0005432526099	7763	57	19C
0005434066544	7763	58	19H
0005432526098	7763	59	19G
0005432526119	7763	60	20A
0005432526056	7763	61	19K
0005432526144	7763	62	19J
0005434066578	7763	63	20C
0005432526059	7763	64	20B
0005432526112	7763	65	20E
0005432526162	7763	66	20D
0005432526155	7763	67	20H
0005432069451	7763	68	20G
0005434066519	7763	69	20K
0005432526054	7763	70	20J
0005432526152	7763	71	21B
0005432428880	7763	72	21E
0005432526109	7763	73	21C
0005434066522	7763	74	22C
0005432526062	7763	75	22F
0005432526118	7763	76	22K
0005432526103	7763	77	23C
0005432526123	7763	78	23F
0005432535763	7763	79	23E
0005432526061	7763	80	23H
0005432526128	7763	81	23K
0005432526066	7763	82	25A
0005432526125	7763	83	24G
0005432526124	7763	84	25C
0005432535760	7763	85	25E
0005432526106	7763	86	25D
0005432150080	7763	87	25G
0005432526080	7763	88	25J
0005432526130	7763	89	26C
0005432069443	7763	90	26A
0005432526132	7763	91	26E
0005432526169	7763	92	26G
0005432428879	7763	93	26F
0005432526093	7763	94	26K
0005432526113	7763	95	26J
0005432526140	7763	96	26H
0005432526040	7763	97	27F
0005434066537	7763	98	27E
0005434066570	7763	99	27D
0005434066549	7763	100	27H
0005432526122	7763	101	27K
0005432150079	7763	102	28B
0005434066560	7763	103	28D
0005434066536	7763	104	28H
0005434066539	7763	105	28G
0005432526094	7763	106	28F
0005434066566	7763	107	28E
0005432526111	7763	108	28K
0005432526089	7763	109	28J
0005434066558	7763	110	29E
0005432526075	7763	111	29D
0005434066526	7763	112	29H
0005432526043	7763	113	29K
0005434066547	7763	114	29J
0005432150084	7763	115	30C
0005432526092	7763	116	30B
0005434066516	7763	117	30A
0005432526100	7763	118	30E
0005432526148	7763	119	30H
0005432526046	7763	120	30G
0005432526055	7763	121	30F
0005432069448	7763	122	30K
0005432526101	7763	123	31D
0005432537025	7763	124	31C
0005432526045	7763	125	31B
0005434066556	7763	126	31E
0005432526142	7763	127	31J
0005432526053	7763	128	31H
0005432526087	7763	129	31G
0005434066512	7763	130	32A
0005432526131	7763	131	31K
0005432150078	7763	132	32C
0005434066535	7763	133	32B
0005432526167	7763	134	32E
0005434066562	7763	135	32H
0005432526079	7763	136	32G
0005434066582	7763	137	32F
0005434066517	7763	138	33B
0005432526057	7763	139	33C
0005434066542	7763	140	33F
0005432526129	7763	141	33E
0005434066545	7763	142	33J
0005432526037	7763	143	34C
0005432526097	7763	144	34A
0005432526070	7763	145	34E
0005434066559	7763	146	35B
0005432069449	7763	147	35A
0005432069450	7763	148	34K
0005432526146	7763	149	35D
0005434066523	7763	150	35E
0005432526091	7763	151	35J
0005432526143	7763	152	35H
0005432526084	7763	153	35K
0005434066576	7763	154	36A
0005432526151	7763	155	36F
0005432526074	7763	156	36E
0005434066534	7763	157	36D
0005432526139	7763	158	36G
0005432526076	7763	159	36H
0005434066569	7763	160	37B
0005432526047	7763	161	37A
0005434066572	7763	162	36K
0005432526065	7763	163	37D
0005434066521	7763	164	37C
0005432526083	7763	165	37G
0005432526058	7763	166	37F
0005432526086	7763	167	37E
0005434066552	7763	168	37H
0005432526158	7763	169	38A
0005432537027	7763	170	37J
0005432526088	7763	171	38C
0005432526044	7763	172	38J
0005434066541	7763	173	38H
0005434066525	7763	174	38K
0005432537026	7763	175	39B
0005432526165	7763	176	39F
0005432526060	7763	177	39G
0005434066527	7763	178	40A
0005434066513	7763	179	39J
0005434066561	7763	180	40C
0005434066580	7763	181	40D
0005432526141	7763	182	40H
0005432526068	7763	183	40G
0005434066520	7763	184	40J
0005434066548	7763	185	41B
0005432526048	7763	186	41A
0005434066514	7763	187	41C
0005434066518	7763	188	41F
0005432526069	7763	189	41E
0005432526164	7763	190	41H
0005434066546	7763	191	42E
0005432069441	7763	192	42G
0005432526163	7763	193	42F
0005434066581	7763	194	42H
0005432526052	7763	195	43B
0005434066573	7763	196	43A
0005434066550	7763	197	42K
0005432535765	7763	198	43D
0005432526138	7763	199	43C
0005432526081	7763	200	43E
0005432526127	7763	201	43G
0005434066533	7763	202	44A
0005432526096	7763	203	44E
0005432526117	7763	204	44F
0005434066515	7763	205	44K
0005432526039	7763	206	44J
0005432150081	7763	207	45B
0005434066543	7763	208	45F
0005432526108	7763	209	45E
0005432526073	7763	210	46C
0005432526041	7763	211	46B
0005432526102	7763	212	46A
0005432526156	7763	213	46D
0005432526085	7763	214	46G
0005432526120	7763	215	46J
0005434066540	7763	216	46H
0005432526072	7763	217	46K
0005432526134	7763	218	47E
0005432526149	7763	219	47D
0005432526038	7763	220	47C
0005432526116	7763	221	47F
0005432526159	7763	222	48A
0005432526154	7763	223	47H
0005432069452	7763	224	48D
0005434066529	7763	225	48C
0005434066568	7763	226	48E
0005432069453	7763	227	48H
0005432526147	7763	228	49C
0005432526063	7763	229	49A
0005432526157	7763	230	49E
0005432069442	7763	231	49D
0005434066555	7763	232	49F
0005432526133	7763	233	49K
0005434066571	7763	234	49H
0005432526150	7763	235	49G
0005432526067	7763	236	50C
0005432526050	7763	237	50A
0005432526114	7763	238	50G
0005432526071	7763	239	50F
0005432526064	7763	240	51D
0005434066538	7763	241	50K
0005434066584	7763	242	50H
0005432526161	7763	243	51F
0005432533251	7763	244	51E
0005434066557	7763	245	51G
0005435612094	5352	1	1D
0005435612060	5352	2	1C
0005435612075	5352	3	1G
0005435612026	5352	4	1K
0005435612013	5352	5	1H
0005435611988	5352	6	2H
0005432132996	5352	7	2D
0005435097077	5352	8	3A
0005434343716	5352	9	3G
0005434343701	5352	10	3D
0005435490179	5352	11	3C
0005435612022	5352	12	3H
0005434343715	5352	13	4C
0005434343686	5352	14	4A
0005435611997	5352	15	4D
0005434343724	5352	16	4K
0005435611995	5352	17	4H
0005435612027	5352	18	5D
0005435612098	5352	19	11A
0005435612076	5352	20	5K
0005435612007	5352	21	11E
0005432047495	5352	22	11K
0005434573153	5352	23	11H
0005435097069	5352	24	12A
0005435612067	5352	25	12G
0005435491411	5352	26	13A
0005435423580	5352	27	12K
0005435611994	5352	28	13D
0005435612082	5352	29	13F
0005435612001	5352	30	13E
0005434343705	5352	31	13G
0005435612086	5352	32	13K
0005435611991	5352	33	14C
0005435097078	5352	34	14F
0005435612059	5352	35	14E
0005434343717	5352	36	15C
0005435612025	5352	37	15A
0005435611992	5352	38	15E
0005432132987	5352	39	15D
0005435612079	5352	40	16A
0005435612011	5352	41	16D
0005435612044	5352	42	16C
0005435612045	5352	43	16G
0005434343703	5352	44	16F
0005435612042	5352	45	16E
0005435612019	5352	46	16H
0005434343694	5352	47	17A
0005435555338	5352	48	17E
0005435612017	5352	49	17G
0005434573149	5352	50	17F
0005435612012	5352	51	17K
0005435612064	5352	52	17H
0005435612088	5352	53	18C
0005434343698	5352	54	18B
0005435097076	5352	55	18A
0005434343687	5352	56	18E
0005434343714	5352	57	18G
0005435612084	5352	58	19B
0005435555340	5352	59	19A
0005435490180	5352	60	19C
0005435612029	5352	61	19E
0005432133002	5352	62	19H
0005432132994	5352	63	19G
0005435612093	5352	64	20A
0005432133003	5352	65	19K
0005435612078	5352	66	20C
0005434343723	5352	67	20B
0005435612052	5352	68	20E
0005432132995	5352	69	20D
0005435612072	5352	70	20F
0005435612102	5352	71	20K
0005435423585	5352	72	20H
0005435612038	5352	73	21B
0005435612100	5352	74	21D
0005435612080	5352	75	21C
0005434343722	5352	76	21G
0005435612090	5352	77	21F
0005434343692	5352	78	22B
0005434343695	5352	79	22D
0005434343691	5352	80	22G
0005434573157	5352	81	22K
0005434343713	5352	82	22H
0005435423579	5352	83	23B
0005435612023	5352	84	23A
0005435612018	5352	85	23D
0005434343709	5352	86	23F
0005435612062	5352	87	23H
0005434573154	5352	88	23K
0005435612085	5352	89	24F
0005435612014	5352	90	24E
0005435612041	5352	91	25A
0005435612005	5352	92	25C
0005435612083	5352	93	25H
0005434573150	5352	94	25G
0005435612034	5352	95	25K
0005435612058	5352	96	25J
0005435612077	5352	97	26A
0005435612000	5352	98	26G
0005435612089	5352	99	26F
0005435612016	5352	100	27D
0005432132999	5352	101	27C
0005432132998	5352	102	27B
0005432132993	5352	103	27K
0005435612095	5352	104	27J
0005435612040	5352	105	28C
0005435612092	5352	106	28B
0005435097073	5352	107	28A
0005435612036	5352	108	28G
0005432133000	5352	109	28J
0005435611989	5352	110	28H
0005434573156	5352	111	29A
0005435612104	5352	112	28K
0005434343718	5352	113	29E
0005435612028	5352	114	29J
0005435612065	5352	115	30G
0005434343719	5352	116	31B
0005432132991	5352	117	31C
0005435612054	5352	118	31E
0005435612037	5352	119	31H
0005435612020	5352	120	31G
0005434343688	5352	121	31K
0005435612099	5352	122	31J
0005434343721	5352	123	32C
0005435097074	5352	124	32B
0005434573146	5352	125	32E
0005435612069	5352	126	32H
0005435612033	5352	127	32G
0005435612043	5352	128	32F
0005435612003	5352	129	32K
0005435612103	5352	130	33A
0005434343704	5352	131	34A
0005435611999	5352	132	34B
0005434343711	5352	133	34C
0005432132992	5352	134	34G
0005435612051	5352	135	34J
0005434343707	5352	136	35B
0005435612050	5352	137	35A
0005434573158	5352	138	34K
0005435612032	5352	139	35F
0005435097070	5352	140	35J
0005434343712	5352	141	35H
0005434343706	5352	142	35G
0005435612068	5352	143	36C
0005435612024	5352	144	36B
0005435612105	5352	145	36A
0005435490177	5352	146	36E
0005434573148	5352	147	36D
0005435612091	5352	148	36G
0005435612008	5352	149	36F
0005435555339	5352	150	36J
0005435612047	5352	151	37B
0005435612056	5352	152	36K
0005435611990	5352	153	37D
0005435612073	5352	154	37C
0005432132990	5352	155	37F
0005435490178	5352	156	37J
0005435423578	5352	157	37H
0005435612004	5352	158	37G
0005435611996	5352	159	39B
0005435612039	5352	160	38K
0005435612101	5352	161	39F
0005434343697	5352	162	39E
0005435612048	5352	163	39D
0005435612015	5352	164	39H
0005434343689	5352	165	39G
0005435612002	5352	166	40A
0005435612061	5352	167	39J
0005435097071	5352	168	40C
0005432132988	5352	169	40H
0005435612010	5352	170	40G
0005434343696	5352	171	40K
0005434343699	5352	172	40J
0005435612074	5352	173	41B
0005435611987	5352	174	41D
0005434343700	5352	175	41G
0005435612063	5352	176	41K
0005435612066	5352	177	42E
0005434573151	5352	178	42F
0005434573145	5352	179	42K
0005434573152	5352	180	42J
0005432047497	5352	181	42H
0005435612070	5352	182	43J
0005434343720	5352	183	43H
0005435612035	5352	184	43G
0005435611993	5352	185	44B
0005434573155	5352	186	44E
0005435612031	5352	187	44D
0005435611986	5352	188	44H
0005435491412	5352	189	45D
0005435611985	5352	190	45C
0005435612049	5352	191	45H
0005434343710	5352	192	45K
0005434573144	5352	193	46B
0005435612053	5352	194	46E
0005435612081	5352	195	46G
0005435612097	5352	196	46F
0005435423584	5352	197	46K
0005432047496	5352	198	46J
0005435097075	5352	199	47C
0005432133001	5352	200	47D
0005432132989	5352	201	47G
0005435612096	5352	202	47F
0005435612030	5352	203	47K
0005435612006	5352	204	47H
0005435612021	5352	205	48C
0005435612046	5352	206	48A
0005434343690	5352	207	48E
0005434343702	5352	208	48D
0005435612071	5352	209	48G
0005435611998	5352	210	48K
0005434343693	5352	211	49D
0005434573147	5352	212	49C
0005435491410	5352	213	49H
0005435612009	5352	214	50A
0005435612055	5352	215	49K
0005435612087	5352	216	50F
0005435097072	5352	217	50E
0005435612057	5352	218	50D
0005432132997	5352	219	50G
0005434343708	5352	220	51G
0005435423857	10920	1	1C
0005435423798	10920	2	2C
0005433719092	10920	3	2G
0005435423832	10920	4	2D
0005435380227	10920	5	3A
0005434244558	10920	6	3D
0005435423853	10920	7	3K
0005435423816	10920	8	11A
0005435423794	10920	9	5K
0005432166854	10920	10	11C
0005435423829	10920	11	11G
0005435423850	10920	12	12C
0005435423789	10920	13	12F
0005434656526	10920	14	14C
0005435304102	10920	15	14E
0005432164931	10920	16	14K
0005432164928	10920	17	15C
0005435423806	10920	18	15A
0005435423822	10920	19	15E
0005435319443	10920	20	15K
0005435423793	10920	21	17E
0005434244555	10920	22	17D
0005434244569	10920	23	17G
0005435423819	10920	24	17K
0005434244564	10920	25	18B
0005435319446	10920	26	18D
0005434244561	10920	27	18F
0005432164925	10920	28	18E
0005435423800	10920	29	18J
0005432840983	10920	30	19C
0005435423796	10920	31	19B
0005435319441	10920	32	19K
0005435423826	10920	33	19J
0005434656527	10920	34	20C
0005435319442	10920	35	20D
0005434244559	10920	36	20K
0005435423847	10920	37	21B
0005435380225	10920	38	21D
0005435423795	10920	39	21C
0005435319448	10920	40	21F
0005435423841	10920	41	21H
0005435304101	10920	42	22A
0005435423790	10920	43	21K
0005435423839	10920	44	22C
0005435319445	10920	45	22D
0005432164927	10920	46	22F
0005435423818	10920	47	22H
0005435423835	10920	48	23B
0005435304099	10920	49	23A
0005435423814	10920	50	23F
0005435304992	10920	51	23E
0005435423856	10920	52	24D
0005435423807	10920	53	23K
0005434244565	10920	54	24F
0005435423824	10920	55	24E
0005435423845	10920	56	25B
0005434244568	10920	57	25C
0005432164930	10920	58	25K
0005434244554	10920	59	26C
0005435319444	10920	60	26A
0005435423849	10920	61	26D
0005432363368	10920	62	26J
0005432840984	10920	63	26H
0005435423788	10920	64	27D
0005435423804	10920	65	27F
0005435304993	10920	66	27E
0005435423791	10920	67	28A
0005435423808	10920	68	28F
0005435423810	10920	69	28J
0005435423787	10920	70	29B
0005435423851	10920	71	29H
0005434244550	10920	72	29K
0005435423805	10920	73	30B
0005434244548	10920	74	30H
0005434244553	10920	75	31E
0005435423797	10920	76	31J
0005435423809	10920	77	31K
0005435423801	10920	78	32E
0005434244549	10920	79	32D
0005434244560	10920	80	32C
0005434244571	10920	81	32K
0005434244566	10920	82	33C
0005435423817	10920	83	33F
0005434244552	10920	84	34G
0005434244545	10920	85	34K
0005435423848	10920	86	34J
0005435423840	10920	87	35B
0005434244557	10920	88	35A
0005435423823	10920	89	35D
0005434244547	10920	90	35F
0005435423844	10920	91	35H
0005434244544	10920	92	35G
0005435423843	10920	93	35J
0005432166853	10920	94	36C
0005435423828	10920	95	36F
0005435423838	10920	96	36G
0005435423799	10920	97	36J
0005435423827	10920	98	37B
0005435319447	10920	99	38B
0005435423831	10920	100	39B
0005435304994	10920	101	39D
0005435423846	10920	102	39G
0005435423803	10920	103	40A
0005434244567	10920	104	39K
0005435423836	10920	105	39J
0005435319449	10920	106	40C
0005434244546	10920	107	40B
0005435423834	10920	108	40H
0005432363370	10920	109	41A
0005434244563	10920	110	41F
0005435423820	10920	111	41G
0005435423837	10920	112	42A
0005435423842	10920	113	42B
0005435423833	10920	114	42E
0005435304100	10920	115	42K
0005434244572	10920	116	43D
0005435423852	10920	117	43E
0005435423802	10920	118	43G
0005432164929	10920	119	44A
0005435304990	10920	120	43J
0005432164924	10920	121	44B
0005435423815	10920	122	44E
0005435423825	10920	123	44D
0005432164926	10920	124	44G
0005433719093	10920	125	44F
0005434244556	10920	126	44K
0005435423811	10920	127	45A
0005435423813	10920	128	45C
0005432363371	10920	129	45F
0005432363367	10920	130	46C
0005435423854	10920	131	46B
0005434244551	10920	132	46D
0005435423830	10920	133	46F
0005435423812	10920	134	47C
0005435423821	10920	135	47A
0005435304103	10920	136	47K
0005435423792	10920	137	47H
0005434244570	10920	138	48E
0005435423855	10920	139	49C
0005432363369	10920	140	49A
0005435380224	10920	141	48K
0005434244562	10920	142	49D
0005435380226	10920	143	49G
0005432166855	10920	144	50D
0005435304991	10920	145	51F
0005433633331	3264	1	1A
0005433633334	3264	2	1D
0005433633339	3264	3	1F
0005432181393	3264	4	2A
0005433506928	3264	5	2C
0005433506923	3264	6	2F
0005433804865	3264	7	2D
0005433633348	3264	8	3C
0005433633332	3264	9	3F
0005433804881	3264	10	3D
0005433506924	3264	11	4C
0005433633333	3264	12	4F
0005433804886	3264	13	4D
0005433633342	3264	14	5A
0005433633350	3264	15	5C
0005433633351	3264	16	5F
0005433804887	3264	17	5D
0005432181388	3264	18	6A
0005433633354	3264	19	6C
0005432181409	3264	20	6D
0005433804885	3264	21	6F
0005432181394	3264	22	7C
0005433633340	3264	23	7D
0005432181404	3264	24	8B
0005433633324	3264	25	8C
0005433804890	3264	26	8E
0005433804873	3264	27	8F
0005433804877	3264	28	9B
0005433506922	3264	29	9C
0005433633318	3264	30	9E
0005433633321	3264	31	9D
0005433633322	3264	32	9F
0005433804891	3264	33	10A
0005432181401	3264	34	10D
0005433804868	3264	35	10C
0005433804883	3264	36	10E
0005433804878	3264	37	11B
0005433633353	3264	38	11C
0005433804871	3264	39	11D
0005433633341	3264	40	11F
0005433804884	3264	41	11E
0005433804861	3264	42	12B
0005432181402	3264	43	12D
0005433804874	3264	44	12C
0005433506914	3264	45	13A
0005433506926	3264	46	13B
0005433804869	3264	47	13D
0005433633346	3264	48	13E
0005432181398	3264	49	14B
0005433804888	3264	50	14D
0005433633326	3264	51	14E
0005433804875	3264	52	14F
0005433633328	3264	53	15C
0005433804872	3264	54	15D
0005433804864	3264	55	15F
0005432181389	3264	56	16A
0005433633352	3264	57	16B
0005432181396	3264	58	16D
0005433633327	3264	59	16F
0005432181403	3264	60	17B
0005433506921	3264	61	17D
0005433506929	3264	62	17F
0005433804892	3264	63	18A
0005433633338	3264	64	18B
0005433506920	3264	65	18C
0005433633343	3264	66	18E
0005432181390	3264	67	19B
0005433506925	3264	68	19C
0005432181387	3264	69	20A
0005433804862	3264	70	20C
0005433506915	3264	71	20F
0005433804860	3264	72	21A
0005433804866	3264	73	21C
0005433506913	3264	74	21B
0005432181406	3264	75	22A
0005433633319	3264	76	22C
0005433633337	3264	77	22F
0005433804870	3264	78	23B
0005433506919	3264	79	23A
0005432181408	3264	80	23C
0005433804879	3264	81	23D
0005432181392	3264	82	23E
0005432181400	3264	83	24B
0005433804876	3264	84	24C
0005433804863	3264	85	24E
0005433506927	3264	86	24F
0005433633330	3264	87	25A
0005433804882	3264	88	25C
0005432181399	3264	89	25B
0005432181407	3264	90	25E
0005433633336	3264	91	26B
0005433506917	3264	92	26A
0005433633349	3264	93	26C
0005433633344	3264	94	26F
0005433804867	3264	95	28A
0005432181391	3264	96	27F
0005433633329	3264	97	28D
0005433633345	3264	98	28C
0005433506916	3264	99	28F
0005432181397	3264	100	29B
0005433633323	3264	101	29C
0005433506918	3264	102	29E
0005433633347	3264	103	29D
0005433633320	3264	104	30C
0005433804859	3264	105	30D
0005433804889	3264	106	30F
0005433633325	3264	107	31A
0005432181405	3264	108	31C
0005433804880	3264	109	31B
0005433506912	3264	110	31D
0005433633335	3264	111	31F
0005432181395	3264	112	31E
0005432459154	8226	1	1C
0005432459136	8226	2	1D
0005432459119	8226	3	2A
0005435884558	8226	4	1F
0005435884555	8226	5	2C
0005432459169	8226	6	2F
0005435884563	8226	7	2D
0005432042522	8226	8	3A
0005435884528	8226	9	3F
0005432459155	8226	10	3D
0005435884532	8226	11	4A
0005435884572	8226	12	4F
0005432042511	8226	13	4D
0005432042517	8226	14	5A
0005432042520	8226	15	5D
0005432459116	8226	16	5C
0005435884540	8226	17	6C
0005432459132	8226	18	6F
0005432459156	8226	19	6D
0005432459143	8226	20	7A
0005432459164	8226	21	7C
0005435884543	8226	22	8A
0005432459158	8226	23	8B
0005435884560	8226	24	8C
0005432459127	8226	25	8E
0005435884571	8226	26	8F
0005435884545	8226	27	9A
0005434312289	8226	28	9C
0005435884547	8226	29	9F
0005432042510	8226	30	9E
0005432459134	8226	31	10C
0005435884565	8226	32	10E
0005432459152	8226	33	10D
0005432459117	8226	34	11A
0005432042523	8226	35	10F
0005435884541	8226	36	11B
0005435884534	8226	37	11C
0005435884574	8226	38	11D
0005432459140	8226	39	11E
0005435884575	8226	40	12A
0005432459129	8226	41	11F
0005434312291	8226	42	12C
0005435884548	8226	43	12B
0005432459120	8226	44	12D
0005432459142	8226	45	12E
0005432459148	8226	46	13B
0005434326260	8226	47	13A
0005435884542	8226	48	13C
0005432459126	8226	49	13E
0005432459157	8226	50	13D
0005435884553	8226	51	13F
0005435884527	8226	52	14A
0005432042524	8226	53	14C
0005435884561	8226	54	14E
0005435884533	8226	55	14F
0005435884577	8226	56	15E
0005432042521	8226	57	15D
0005432459130	8226	58	16A
0005432459160	8226	59	16E
0005435884530	8226	60	16D
0005432459163	8226	61	16F
0005435884566	8226	62	17A
0005432042513	8226	63	17C
0005432459121	8226	64	17E
0005432459146	8226	65	18A
0005435884556	8226	66	17F
0005435884544	8226	67	18B
0005432459144	8226	68	18C
0005435884539	8226	69	18E
0005435884529	8226	70	18D
0005435884537	8226	71	18F
0005432042515	8226	72	19C
0005432459170	8226	73	19D
0005435884570	8226	74	20B
0005435884538	8226	75	20C
0005432459123	8226	76	20F
0005435884576	8226	77	21B
0005432042514	8226	78	21A
0005432459124	8226	79	21C
0005435884526	8226	80	21D
0005435884573	8226	81	21E
0005435884567	8226	82	21F
0005432459159	8226	83	22B
0005435884569	8226	84	22A
0005432459141	8226	85	22E
0005435884568	8226	86	22F
0005432459131	8226	87	23A
0005434312290	8226	88	23C
0005432459135	8226	89	23B
0005435884552	8226	90	23D
0005435884551	8226	91	23E
0005432459125	8226	92	23F
0005435884554	8226	93	24B
0005432042519	8226	94	24E
0005432459122	8226	95	24D
0005432459167	8226	96	25B
0005434326259	8226	97	25C
0005432042512	8226	98	25D
0005435884557	8226	99	25E
0005432459153	8226	100	26A
0005432459166	8226	101	26B
0005435884536	8226	102	26C
0005432459162	8226	103	26E
0005432459139	8226	104	26F
0005432459151	8226	105	27A
0005432459137	8226	106	27C
0005435884562	8226	107	27B
0005432459150	8226	108	27D
0005435884578	8226	109	27E
0005435884549	8226	110	28A
0005432459128	8226	111	27F
0005435884546	8226	112	28B
0005432042518	8226	113	28D
0005432459118	8226	114	28C
0005435884559	8226	115	28E
0005435884531	8226	116	29A
0005432042516	8226	117	29B
0005432459138	8226	118	29D
0005435884535	8226	119	29E
0005435884564	8226	120	30A
0005435884550	8226	121	29F
0005432459161	8226	122	30B
0005432459145	8226	123	30C
0005432459165	8226	124	30E
0005432459147	8226	125	30D
0005432459133	8226	126	30F
0005432459149	8226	127	31D
0005432459168	8226	128	31E
0005432382623	4515	1	1C
0005432382637	4515	2	1D
0005432382607	4515	3	2D
0005432727762	4515	4	2F
0005432727755	4515	5	3A
0005432727759	4515	6	3C
0005432382639	4515	7	3D
0005433453733	4515	8	3F
0005432382606	4515	9	4A
0005432382636	4515	10	4D
0005432382629	4515	11	4E
0005432382608	4515	12	4F
0005432382630	4515	13	5C
0005432382619	4515	14	5E
0005432382628	4515	15	5F
0005432727766	4515	16	6A
0005433453734	4515	17	6C
0005432382634	4515	18	6D
0005432382620	4515	19	6F
0005432382611	4515	20	7A
0005432727765	4515	21	7C
0005432382644	4515	22	7D
0005433454846	4515	23	8A
0005433722122	4515	24	8E
0005432382631	4515	25	9C
0005432382643	4515	26	9E
0005432727763	4515	27	10A
0005432727760	4515	28	10C
0005432382618	4515	29	10D
0005432382613	4515	30	10E
0005433722126	4515	31	10F
0005432382627	4515	32	11A
0005432382622	4515	33	11C
0005432382641	4515	34	11D
0005432382610	4515	35	11E
0005432727757	4515	36	11F
0005432382624	4515	37	12A
0005433722121	4515	38	12D
0005432382646	4515	39	12E
0005432382617	4515	40	12F
0005433454843	4515	41	13A
0005432382640	4515	42	13C
0005432382621	4515	43	13D
0005432727761	4515	44	13E
0005432382635	4515	45	13F
0005432727764	4515	46	14C
0005433454844	4515	47	14D
0005433722124	4515	48	14F
0005432382615	4515	49	15C
0005433722127	4515	50	15E
0005432382633	4515	51	16A
0005432382648	4515	52	16D
0005432382642	4515	53	16E
0005432382647	4515	54	17D
0005432382626	4515	55	17E
0005432382612	4515	56	18A
0005433722125	4515	57	18C
0005432382632	4515	58	18D
0005432727756	4515	59	18E
0005432382614	4515	60	18F
0005433454845	4515	61	19A
0005432382616	4515	62	19C
0005432382645	4515	63	19D
0005432382609	4515	64	19F
0005432727758	4515	65	20A
0005433722123	4515	66	20D
0005432382625	4515	67	20E
0005432382638	4515	68	20F
0005435540691	1738	1	1A
0005435540704	1738	2	1C
0005435528958	1738	3	1D
0005435540697	1738	4	2C
0005435528949	1738	5	3A
0005435528964	1738	6	3D
0005435540709	1738	7	3F
0005435540705	1738	8	4F
0005435540708	1738	9	5C
0005435540695	1738	10	5D
0005433516750	1738	11	5E
0005432294453	1738	12	5F
0005435540710	1738	13	6C
0005433516751	1738	14	6D
0005435528960	1738	15	6F
0005435528952	1738	16	7E
0005435528961	1738	17	7F
0005435540696	1738	18	8A
0005435528955	1738	19	8D
0005435540706	1738	20	8F
0005435540692	1738	21	9C
0005435528950	1738	22	9F
0005435528959	1738	23	10D
0005435540690	1738	24	10E
0005435528947	1738	25	10F
0005435528957	1738	26	11A
0005433516755	1738	27	11E
0005433516749	1738	28	12A
0005435528953	1738	29	12D
0005435528965	1738	30	12F
0005433516757	1738	31	13D
0005433516754	1738	32	13F
0005435540693	1738	33	14C
0005435540698	1738	34	14D
0005435540700	1738	35	14E
0005435528956	1738	36	14F
0005435540694	1738	37	15A
0005435528948	1738	38	15C
0005435540699	1738	39	15E
0005435540701	1738	40	15F
0005435540702	1738	41	16C
0005432294454	1738	42	17E
0005435540707	1738	43	17F
0005435528966	1738	44	18A
0005435528951	1738	45	18D
0005435540703	1738	46	18F
0005433516752	1738	47	19A
0005435528962	1738	48	19D
0005435528963	1738	49	19E
0005435528954	1738	50	19F
0005433516753	1738	51	20E
0005433516756	1738	52	20F
0005432924968	21993	1	7C
0005432924967	21993	2	14F
0005432924969	21993	3	19E
0005432924970	21993	4	20D
0005432838583	7354	1	1A
0005434458499	7354	2	1C
0005432838593	7354	3	1D
0005432838581	7354	4	2C
0005434458518	7354	5	3A
0005432838598	7354	6	3C
0005432823419	7354	7	4A
0005432838597	7354	8	4C
0005432838588	7354	9	4F
0005432073339	7354	10	5A
0005432838596	7354	11	5C
0005432838578	7354	12	5D
0005434458505	7354	13	5E
0005432838582	7354	14	5F
0005434458510	7354	15	6A
0005434458500	7354	16	6C
0005434458501	7354	17	6D
0005432838604	7354	18	6E
0005432838585	7354	19	7A
0005434458511	7354	20	7D
0005434458509	7354	21	7F
0005432838592	7354	22	8D
0005432838580	7354	23	8E
0005432073340	7354	24	9A
0005432838594	7354	25	9D
0005434458506	7354	26	9E
0005434458513	7354	27	9F
0005434458516	7354	28	10A
0005434458512	7354	29	10F
0005434458508	7354	30	11D
0005432840982	7354	31	11F
0005434458515	7354	32	11E
0005432838576	7354	33	12A
0005432838586	7354	34	12D
0005432073341	7354	35	12E
0005432838601	7354	36	12F
0005432838602	7354	37	13A
0005434458504	7354	38	13D
0005432823421	7354	39	13E
0005432840981	7354	40	13F
0005432838579	7354	41	14C
0005432073342	7354	42	14D
0005434458498	7354	43	14E
0005432838577	7354	44	14F
0005432838589	7354	45	15C
0005432823420	7354	46	15D
0005432840980	7354	47	15E
0005434458503	7354	48	15F
0005432838587	7354	49	16A
0005432838591	7354	50	16C
0005432838599	7354	51	16E
0005434458502	7354	52	16F
0005432838605	7354	53	17D
0005432838606	7354	54	17F
0005432838600	7354	55	18A
0005432838590	7354	56	18C
0005434458507	7354	57	19A
0005432838595	7354	58	19C
0005434458514	7354	59	19D
0005432838603	7354	60	19E
0005434458497	7354	61	19F
0005432838584	7354	62	20C
0005434458517	7354	63	20D
0005435252443	28912	1	1C
0005435252445	28912	2	2C
0005435252439	28912	3	4E
0005435491414	28912	4	5D
0005434664927	28912	5	5C
0005435252441	28912	6	5F
0005435252448	28912	7	6D
0005432000994	28912	8	6F
0005434664929	28912	9	8D
0005432838505	28912	10	9F
0005435252437	28912	11	10A
0005435252440	28912	12	10C
0005435252449	28912	13	10E
0005435252451	28912	14	11C
0005435252444	28912	15	11D
0005435252435	28912	16	11E
0005435252436	28912	17	12D
0005434664928	28912	18	12E
0005435252442	28912	19	13A
0005435252447	28912	20	13D
0005435252446	28912	21	13F
0005435252438	28912	22	14A
0005435252452	28912	23	14C
0005435252450	28912	24	15C
0005432838480	28912	25	15E
0005432000995	28912	26	17A
0005432838504	28912	27	18D
0005434664926	28912	28	19D
0005435491413	28912	29	19E
0005435990523	8786	1	1A
0005435990519	8786	2	4C
0005435990521	8786	3	4A
0005435990520	8786	4	6C
0005435990522	8786	5	9C
0005435990524	8786	6	12D
0005435990525	8786	7	14C
0005435990526	8786	8	18A
0005434275944	15722	1	4D
0005434275943	15722	2	6E
0005434275942	15722	3	8F
0005434275945	15722	4	17A
0005434275946	15722	5	21B
0005432427113	20635	1	1B
0005432427112	20635	2	3D
0005432427111	20635	3	4C
0005432427110	20635	4	5A
0005432427114	20635	5	5B
0005432359667	6381	1	1C
0005432359690	6381	2	1A
0005432335860	6381	3	2D
0005432363371	6381	4	3A
0005432359688	6381	5	3F
0005432359664	6381	6	4C
0005432335865	6381	7	4E
0005432363367	6381	8	5B
0005432359702	6381	9	5C
0005432359679	6381	10	5E
0005432359683	6381	11	6A
0005432359682	6381	12	6C
0005432359676	6381	13	6D
0005432062152	6381	14	6E
0005432359658	6381	15	6F
0005432359654	6381	16	7D
0005432363368	6381	17	7B
0005432359668	6381	18	7F
0005432359670	6381	19	8A
0005432359672	6381	20	8B
0005432359693	6381	21	8D
0005432359656	6381	22	9A
0005432359663	6381	23	9F
0005432359681	6381	24	10E
0005432359700	6381	25	11B
0005432359685	6381	26	11C
0005432359671	6381	27	11E
0005432359695	6381	28	11D
0005432359699	6381	29	11F
0005432335863	6381	30	12A
0005432359657	6381	31	12D
0005432335861	6381	32	12E
0005432359674	6381	33	12F
0005432359665	6381	34	13A
0005432359660	6381	35	13C
0005432359662	6381	36	13B
0005432359689	6381	37	13D
0005432359703	6381	38	13E
0005432359698	6381	39	13F
0005432359684	6381	40	14B
0005435176604	6381	41	14C
0005432335867	6381	42	14D
0005432335864	6381	43	15A
0005432363370	6381	44	15C
0005432359692	6381	45	16B
0005432359678	6381	46	16E
0005432359680	6381	47	17D
0005432335862	6381	48	17C
0005432359675	6381	49	17E
0005432335859	6381	50	17F
0005432359659	6381	51	18B
0005432359694	6381	52	18D
0005432359677	6381	53	18C
0005432359661	6381	54	18F
0005432062151	6381	55	19A
0005432335858	6381	56	19F
0005432359655	6381	57	19E
0005435176603	6381	58	20B
0005432363369	6381	59	20A
0005432359691	6381	60	20C
0005432359669	6381	61	20D
0005432359696	6381	62	20E
0005432359701	6381	63	21B
0005432335868	6381	64	21D
0005432062153	6381	65	21E
0005432359687	6381	66	21F
0005432359666	6381	67	22B
0005432335866	6381	68	22A
0005432359697	6381	69	22D
0005432359686	6381	70	22F
0005432062154	6381	71	23C
0005432359673	6381	72	23E
0005435176689	21014	1	1D
0005435490183	21014	2	4B
0005435176688	21014	3	4E
0005435176692	21014	4	4F
0005434149561	21014	5	5E
0005435176675	21014	6	5F
0005435176677	21014	7	6F
0005434149560	21014	8	7C
0005434149566	21014	9	7E
0005434149563	21014	10	8D
0005435176674	21014	11	9F
0005435176683	21014	12	9E
0005434149557	21014	13	10C
0005435176691	21014	14	10B
0005435490181	21014	15	10E
0005435176693	21014	16	11B
0005432052702	21014	17	12C
0005435490182	21014	18	12F
0005435723017	21014	19	13A
0005435176680	21014	20	13E
0005435176684	21014	21	14C
0005435176673	21014	22	14E
0005432052701	21014	23	15A
0005434149567	21014	24	15C
0005432052703	21014	25	15D
0005435176671	21014	26	16B
0005435723018	21014	27	16C
0005435176685	21014	28	16D
0005435176695	21014	29	16F
0005435176694	21014	30	16E
0005435723019	21014	31	18A
0005434149562	21014	32	18B
0005435176682	21014	33	18C
0005435176676	21014	34	18D
0005434149558	21014	35	18F
0005435176686	21014	36	18E
0005435176679	21014	37	19E
0005434149564	21014	38	20B
0005435176678	21014	39	20A
0005435723016	21014	40	20D
0005435176672	21014	41	20F
0005434149565	21014	42	21A
0005435176687	21014	43	21D
0005435176681	21014	44	22A
0005435176697	21014	45	23A
0005435176670	21014	46	22F
0005434149559	21014	47	23B
0005435176696	21014	48	23E
0005435176690	21014	49	23F
0005434186158	17720	1	3B
0005434186157	17720	2	6A
0005434186159	17720	3	6C
0005434458499	29085	1	1A
0005434458505	29085	2	1B
0005434458513	29085	3	1C
0005434458512	29085	4	1D
0005434448262	29085	5	2A
0005434458500	29085	6	2B
0005434458514	29085	7	2C
0005434458507	29085	8	2D
0005434458508	29085	9	3A
0005434448263	29085	10	3C
0005434458502	29085	11	3D
0005434458503	29085	12	5A
0005434448261	29085	13	5B
0005434458515	29085	14	5C
0005434463897	29085	15	6A
0005434448264	29085	16	6D
0005434458517	29085	17	7A
0005434458511	29085	18	7B
0005434458498	29085	19	7D
0005434458510	29085	20	18A
0005434458509	29085	21	18C
0005434462757	29085	22	19C
0005434462758	29085	23	20B
0005434463896	29085	24	20C
0005434458504	29085	25	20D
0005434458516	29085	26	21A
0005434458518	29085	27	21B
0005434458497	29085	28	21C
0005434462756	29085	29	21D
0005434458506	29085	30	22C
0005434458501	29085	31	22D
0005432603737	21458	1	1A
0005432603760	21458	2	1C
0005432603751	21458	3	1D
0005432603734	21458	4	2A
0005432603724	21458	5	2C
0005432603745	21458	6	2D
0005432603750	21458	7	3A
0005432603744	21458	8	3B
0005432603743	21458	9	3C
0005432603742	21458	10	3D
0005432603740	21458	11	4B
0005432603727	21458	12	4C
0005432603736	21458	13	4D
0005432603733	21458	14	5A
0005432603728	21458	15	5B
0005432603753	21458	16	5C
0005432603747	21458	17	5D
0005432603738	21458	18	6A
0005432603735	21458	19	6C
0005432603758	21458	20	6D
0005432603752	21458	21	7B
0005432603739	21458	22	7C
0005432603757	21458	23	7D
0005432603726	21458	24	18A
0005432603725	21458	25	18B
0005432603732	21458	26	18C
0005432603746	21458	27	18D
0005432603748	21458	28	19A
0005432603729	21458	29	19D
0005432603749	21458	30	20B
0005432603723	21458	31	20C
0005432603731	21458	32	20D
0005432603754	21458	33	21A
0005432603761	21458	34	21B
0005432603759	21458	35	21C
0005432603762	21458	36	21D
0005432603730	21458	37	22B
0005432603741	21458	38	22C
0005432603755	21458	39	23A
0005432603756	21458	40	23B
0005435221501	31665	1	2B
0005435221502	31665	2	2D
0005435221040	31665	3	3B
0005435221038	31665	4	6B
0005435221039	31665	5	18B
0005435154580	12304	1	1D
0005435154583	12304	2	2D
0005435154581	12304	3	3B
0005435154582	12304	4	4A
0005435154584	12304	5	5C
0005435154585	12304	6	18B
0005434606769	22389	1	2B
0005434604845	22389	2	3B
0005434606768	22389	3	4A
0005434606770	22389	4	4B
0005434606771	22389	5	5B
0005432747005	387	1	1C
0005432751476	387	2	1F
0005432747013	387	3	2D
0005432747016	387	4	2F
0005432219942	387	5	3A
0005432751474	387	6	3C
0005432747006	387	7	3D
0005432747008	387	8	3F
0005432746995	387	9	4C
0005432747019	387	10	4E
0005432746990	387	11	4F
0005432746985	387	12	5D
0005432746994	387	13	5F
0005432753248	387	14	6A
0005435154587	387	15	6D
0005432749752	387	16	6E
0005432746997	387	17	6F
0005432746999	387	18	7C
0005432747002	387	19	7E
0005432219941	387	20	8A
0005432219940	387	21	8E
0005432747012	387	22	8F
0005432747010	387	23	9C
0005432746984	387	24	9D
0005432753250	387	25	9E
0005432747001	387	26	11A
0005432747020	387	27	11D
0005432746988	387	28	11E
0005432751475	387	29	12A
0005432747021	387	30	12D
0005432747011	387	31	13A
0005432749751	387	32	13D
0005432746986	387	33	13F
0005432746998	387	34	14A
0005432746982	387	35	14C
0005432746993	387	36	14D
0005432747017	387	37	14E
0005435154588	387	38	15F
0005432746992	387	39	16A
0005435154586	387	40	16C
0005432746996	387	41	16D
0005432747018	387	42	16F
0005432747004	387	43	17A
0005432753249	387	44	17C
0005432746989	387	45	17D
0005432746991	387	46	17F
0005432747015	387	47	18A
0005432746987	387	48	18D
0005432747003	387	49	18E
0005432219939	387	50	19A
0005432753251	387	51	19C
0005432747007	387	52	19E
0005432746983	387	53	19F
0005432747009	387	54	20A
0005432747014	387	55	20C
0005432747000	387	56	20D
0005433293157	12074	1	1C
0005432890743	12074	2	1F
0005432890748	12074	3	2A
0005432890731	12074	4	2F
0005432890735	12074	5	3D
0005432890739	12074	6	3F
0005433293156	12074	7	4A
0005433293152	12074	8	4C
0005432890745	12074	9	4D
0005433293148	12074	10	4F
0005432890730	12074	11	5A
0005432890741	12074	12	5C
0005433293149	12074	13	5E
0005433293150	12074	14	6F
0005433293158	12074	15	7C
0005432214771	12074	16	7F
0005432890747	12074	17	8A
0005432890736	12074	18	8D
0005432890737	12074	19	8F
0005434153517	12074	20	9C
0005432214772	12074	21	9E
0005432890733	12074	22	9F
0005432890746	12074	23	10D
0005432746864	12074	24	10E
0005434153516	12074	25	11A
0005432890734	12074	26	11C
0005433293153	12074	27	11D
0005432890742	12074	28	12A
0005433293163	12074	29	12E
0005432890744	12074	30	12F
0005433293159	12074	31	14F
0005433293155	12074	32	14E
0005432890732	12074	33	15A
0005433875357	12074	34	15E
0005432890738	12074	35	16F
0005433293154	12074	36	17A
0005433293162	12074	37	18A
0005433293161	12074	38	18C
0005432890729	12074	39	18E
0005433293151	12074	40	19A
0005432890740	12074	41	19E
0005433293160	12074	42	20A
0005433524879	18940	1	1B
0005433524880	18940	2	1D
0005433533249	18940	3	2D
0005433533248	18940	4	4B
0005433533250	18940	5	4C
0005433524876	18940	6	4D
0005433524873	18940	7	5A
0005433524877	18940	8	5D
0005433524874	18940	9	6A
0005433533251	18940	10	6C
0005433524871	18940	11	7B
0005433524875	18940	12	7D
0005433531235	18940	13	18B
0005433533252	18940	14	19C
0005433524870	18940	15	20A
0005433531236	18940	16	20C
0005433524872	18940	17	20D
0005433524878	18940	18	21B
0005433531234	18940	19	22A
0005432927906	32458	1	1B
0005432927903	32458	2	5D
0005432927904	32458	3	6D
0005432927907	32458	4	7B
0005432927908	32458	5	18D
0005432927905	32458	6	23A
0005434821732	5286	1	1G
0005434821742	5286	2	2A
0005434821726	5286	3	1K
0005434821706	5286	4	2H
0005434821757	5286	5	2G
0005434821777	5286	6	3A
0005434821767	5286	7	3D
0005434821704	5286	8	4C
0005434821790	5286	9	4A
0005435149840	5286	10	4G
0005434821703	5286	11	5A
0005434821756	5286	12	11A
0005434821785	5286	13	5K
0005434821824	5286	14	11E
0005434821759	5286	15	11F
0005434821774	5286	16	11H
0005434821710	5286	17	12C
0005434821723	5286	18	12F
0005434821739	5286	19	12E
0005432396185	5286	20	13A
0005434821713	5286	21	13D
0005434821709	5286	22	13G
0005434828654	5286	23	14A
0005434558158	5286	24	14D
0005432396183	5286	25	14F
0005434821809	5286	26	14E
0005434821735	5286	27	14K
0005434821720	5286	28	14G
0005432121126	5286	29	15C
0005434821789	5286	30	15A
0005434821778	5286	31	15K
0005434821734	5286	32	16C
0005435372139	5286	33	16F
0005434821718	5286	34	16E
0005434821754	5286	35	16H
0005434821803	5286	36	16K
0005434821702	5286	37	17E
0005432121136	5286	38	17C
0005434821729	5286	39	17G
0005434821725	5286	40	17K
0005434821769	5286	41	18A
0005434821764	5286	42	18E
0005434821822	5286	43	18D
0005435149832	5286	44	18H
0005435149831	5286	45	19J
0005434821804	5286	46	19H
0005434821708	5286	47	20A
0005434821793	5286	48	20B
0005434821786	5286	49	20J
0005434821750	5286	50	21A
0005434821808	5286	51	21D
0005432394046	5286	52	21B
0005432121125	5286	53	21F
0005434821755	5286	54	21J
0005434821727	5286	55	22A
0005434821773	5286	56	22G
0005434821768	5286	57	22K
0005435149833	5286	58	23B
0005434821807	5286	59	23A
0005434821795	5286	60	23D
0005435149837	5286	61	23C
0005434821766	5286	62	23J
0005434821744	5286	63	25C
0005434821771	5286	64	25E
0005434821775	5286	65	25H
0005434821783	5286	66	25G
0005434821797	5286	67	25J
0005434831079	5286	68	26E
0005434821811	5286	69	26D
0005435149836	5286	70	26C
0005434821707	5286	71	26G
0005432121132	5286	72	26F
0005432121134	5286	73	26H
0005434821736	5286	74	27A
0005434821737	5286	75	26K
0005434821782	5286	76	27C
0005432121135	5286	77	27B
0005432121128	5286	78	27F
0005434821792	5286	79	27E
0005434821753	5286	80	27H
0005434821788	5286	81	27G
0005434821776	5286	82	28E
0005434821714	5286	83	28C
0005434821794	5286	84	28H
0005432121138	5286	85	28G
0005432121130	5286	86	29A
0005434558159	5286	87	29D
0005432121139	5286	88	29E
0005432394045	5286	89	29H
0005435149827	5286	90	30B
0005434828655	5286	91	30E
0005434821801	5286	92	30C
0005434821825	5286	93	31E
0005434821791	5286	94	31G
0005434821760	5286	95	31K
0005434831076	5286	96	31J
0005432394044	5286	97	32A
0005434821712	5286	98	32G
0005434821780	5286	99	32F
0005435149830	5286	100	32K
0005432396184	5286	101	33D
0005434821762	5286	102	33J
0005434821823	5286	103	34A
0005434821813	5286	104	34B
0005434821716	5286	105	34D
0005434558157	5286	106	34C
0005434821814	5286	107	34H
0005434831080	5286	108	34G
0005434821829	5286	109	34F
0005434821711	5286	110	35B
0005434821733	5286	111	34K
0005435149828	5286	112	35C
0005434821802	5286	113	35F
0005434821724	5286	114	35E
0005434821799	5286	115	35G
0005434821806	5286	116	36A
0005434821815	5286	117	35J
0005434821743	5286	118	36B
0005434821800	5286	119	36H
0005432121127	5286	120	36K
0005435149838	5286	121	37B
0005434821701	5286	122	37G
0005434821748	5286	123	37F
0005434831077	5286	124	37J
0005434821763	5286	125	37H
0005434821700	5286	126	38A
0005434821705	5286	127	38C
0005434821821	5286	128	38K
0005432394047	5286	129	39B
0005434558155	5286	130	39A
0005434821761	5286	131	39G
0005434821745	5286	132	39H
0005434821818	5286	133	39J
0005432396186	5286	134	40C
0005434821749	5286	135	40E
0005434821798	5286	136	40H
0005434821731	5286	137	41B
0005434821751	5286	138	41A
0005432121129	5286	139	41C
0005434821784	5286	140	41G
0005435149829	5286	141	42B
0005434821741	5286	142	42E
0005434821819	5286	143	42D
0005434821826	5286	144	42H
0005434821738	5286	145	42K
0005434821820	5286	146	42J
0005434821715	5286	147	43B
0005434821817	5286	148	43F
0005434821728	5286	149	43K
0005432121137	5286	150	44B
0005434821721	5286	151	44E
0005434821779	5286	152	44D
0005434821747	5286	153	44G
0005434821812	5286	154	44J
0005434558156	5286	155	45A
0005434821746	5286	156	45D
0005434821781	5286	157	45C
0005434831081	5286	158	45B
0005434821772	5286	159	45E
0005434821758	5286	160	45H
0005434821787	5286	161	45K
0005434821717	5286	162	46A
0005432121133	5286	163	46E
0005435149834	5286	164	46F
0005432121131	5286	165	46H
0005434821828	5286	166	47C
0005434831078	5286	167	47A
0005434821719	5286	168	46K
0005434821827	5286	169	47G
0005434821740	5286	170	47F
0005434821730	5286	171	48A
0005434821796	5286	172	47H
0005434821722	5286	173	48H
0005434821816	5286	174	48G
0005435149835	5286	175	49A
0005434821765	5286	176	49D
0005434664925	5286	177	49C
0005434821752	5286	178	49G
0005434821805	5286	179	49F
0005434821810	5286	180	50F
0005435149839	5286	181	51E
0005434821770	5286	182	51G
0005435735074	9929	1	1C
0005435372344	9929	2	1G
0005435735070	9929	3	1D
0005435386476	9929	4	2D
0005435372298	9929	5	2C
0005435735073	9929	6	2K
0005435372354	9929	7	4H
0005435372345	9929	8	11E
0005435386479	9929	9	12F
0005435386475	9929	10	13A
0005435372300	9929	11	13G
0005435372333	9929	12	14A
0005435372324	9929	13	14E
0005435372327	9929	14	14G
0005435372330	9929	15	14K
0005435386480	9929	16	17C
0005435372309	9929	17	18A
0005435372336	9929	18	17K
0005435372359	9929	19	18C
0005435372355	9929	20	18D
0005435372341	9929	21	18K
0005435372329	9929	22	19A
0005435372358	9929	23	19E
0005435372337	9929	24	19H
0005435372296	9929	25	20D
0005435302130	9929	26	20G
0005435372319	9929	27	22E
0005435302131	9929	28	22G
0005435372304	9929	29	23C
0005435372360	9929	30	25A
0005435386477	9929	31	24G
0005435372356	9929	32	25D
0005435372348	9929	33	25F
0005432823423	9929	34	26A
0005435372328	9929	35	26G
0005432202958	9929	36	26F
0005435372299	9929	37	26H
0005435372318	9929	38	27A
0005435372347	9929	39	27F
0005432202962	9929	40	27H
0005435372294	9929	41	27K
0005435372315	9929	42	29A
0005435372308	9929	43	29F
0005435372340	9929	44	29H
0005435372331	9929	45	29K
0005435372310	9929	46	29J
0005435372313	9929	47	30H
0005435372334	9929	48	31F
0005435386473	9929	49	31E
0005432202959	9929	50	31H
0005435299709	9929	51	32D
0005435372349	9929	52	32H
0005435299707	9929	53	32G
0005435372312	9929	54	33C
0005435735071	9929	55	33B
0005435372295	9929	56	33E
0005435372338	9929	57	34A
0005435372352	9929	58	34K
0005432202960	9929	59	34J
0005432202961	9929	60	35G
0005435372332	9929	61	36C
0005435372316	9929	62	36G
0005435372323	9929	63	37D
0005435372305	9929	64	37F
0005435372335	9929	65	38A
0005435372346	9929	66	37J
0005432202957	9929	67	38B
0005435372351	9929	68	39A
0005435372357	9929	69	40A
0005435302133	9929	70	40F
0005435386478	9929	71	40E
0005435372322	9929	72	40H
0005434821415	9929	73	40K
0005435302132	9929	74	41F
0005435372297	9929	75	41G
0005435372314	9929	76	41K
0005435372303	9929	77	41J
0005435372311	9929	78	42J
0005435372307	9929	79	43D
0005435372302	9929	80	43F
0005435372321	9929	81	43G
0005435372293	9929	82	44A
0005435372353	9929	83	44C
0005435372326	9929	84	44K
0005435372343	9929	85	45H
0005435299708	9929	86	46A
0005435372317	9929	87	46E
0005435372342	9929	88	46F
0005435372301	9929	89	46K
0005435299706	9929	90	47D
0005432823422	9929	91	47G
0005435372350	9929	92	48C
0005435735072	9929	93	48A
0005435372320	9929	94	48H
0005435661890	9929	95	49D
0005435299705	9929	96	49C
0005435386474	9929	97	49G
0005435372325	9929	98	50E
0005435372339	9929	99	50H
0005435372306	9929	100	51F
0005435082674	7014	1	1A
0005435082671	7014	2	4C
0005435082673	7014	3	7B
0005435082672	7014	4	7C
0005435790265	7014	5	18B
0005435082670	7014	6	19B
0005435082676	7014	7	19C
0005435082675	7014	8	20B
0005435790264	7014	9	22B
0005435082677	7014	10	22C
0005434755845	9563	1	1C
0005434755824	9563	2	2A
0005434755865	9563	3	2C
0005434755844	9563	4	2D
0005434755830	9563	5	3A
0005434755855	9563	6	3F
0005434755857	9563	7	4D
0005434755869	9563	8	4E
0005434755851	9563	9	4F
0005434755862	9563	10	5A
0005434755849	9563	11	5E
0005434755836	9563	12	5F
0005434755864	9563	13	6A
0005434755868	9563	14	6D
0005434755867	9563	15	7C
0005434755861	9563	16	7D
0005434755853	9563	17	7F
0005434755856	9563	18	8C
0005434755841	9563	19	8F
0005434755852	9563	20	9F
0005434755854	9563	21	10A
0005434755827	9563	22	10E
0005434755834	9563	23	10F
0005434755831	9563	24	11C
0005434755866	9563	25	12A
0005434755835	9563	26	12E
0005434755850	9563	27	12F
0005434755826	9563	28	13D
0005434755837	9563	29	13E
0005434755825	9563	30	13F
0005434755860	9563	31	14A
0005434755828	9563	32	14D
0005434755838	9563	33	14E
0005434755843	9563	34	15E
0005434755832	9563	35	15F
0005434755840	9563	36	16C
0005434755847	9563	37	16E
0005434755863	9563	38	17A
0005434755858	9563	39	17C
0005434755846	9563	40	17D
0005434755870	9563	41	17E
0005434755859	9563	42	18F
0005434755829	9563	43	19A
0005434755842	9563	44	19D
0005434755839	9563	45	19E
0005434755833	9563	46	20D
0005434755848	9563	47	20E
0005434213798	28612	1	1C
0005434213805	28612	2	1F
0005434213801	28612	3	2A
0005434213809	28612	4	2C
0005434213833	28612	5	2D
0005434213835	28612	6	2F
0005434213810	28612	7	3D
0005434213807	28612	8	4A
0005434213797	28612	9	4C
0005434213832	28612	10	4E
0005434213837	28612	11	4F
0005434213795	28612	12	5A
0005434213840	28612	13	5C
0005434213827	28612	14	5D
0005434213802	28612	15	5E
0005434213816	28612	16	6A
0005434213824	28612	17	6E
0005434213817	28612	18	7A
0005434213829	28612	19	7E
0005434213839	28612	20	7F
0005434213823	28612	21	8C
0005434213808	28612	22	8D
0005434213815	28612	23	9A
0005434213831	28612	24	9D
0005434213814	28612	25	10A
0005434213803	28612	26	10F
0005434213820	28612	27	11D
0005434213819	28612	28	11E
0005434213821	28612	29	12C
0005434213800	28612	30	13C
0005434213818	28612	31	13D
0005434213830	28612	32	13F
0005434213828	28612	33	14C
0005434213838	28612	34	14D
0005434213806	28612	35	14E
0005434213796	28612	36	15E
0005434213804	28612	37	15F
0005434213836	28612	38	16D
0005434213834	28612	39	17A
0005434213822	28612	40	17E
0005434213813	28612	41	17F
0005434213811	28612	42	18D
0005434213825	28612	43	18E
0005434213794	28612	44	18F
0005434213799	28612	45	19A
0005434213812	28612	46	19C
0005434213826	28612	47	19D
0005435100079	10828	1	7C
0005435100080	10828	2	19D
0005435100078	10828	3	21D
0005434760161	31809	1	1A
0005434760162	31809	2	2B
0005434638938	1965	1	1B
0005434638944	1965	2	1C
0005434638933	1965	3	1D
0005434638939	1965	4	2A
0005434638942	1965	5	2B
0005435948308	1965	6	3A
0005434638941	1965	7	3B
0005435948310	1965	8	3C
0005434638929	1965	9	3D
0005434638952	1965	10	4B
0005434638935	1965	11	4C
0005434638936	1965	12	4D
0005432290589	1965	13	5A
0005435948309	1965	14	5B
0005434638937	1965	15	5D
0005434638953	1965	16	6A
0005434638947	1965	17	6B
0005434638943	1965	18	6D
0005434638934	1965	19	7B
0005434638945	1965	20	7D
0005434638954	1965	21	18C
0005434638931	1965	22	18D
0005434638928	1965	23	19A
0005432290590	1965	24	19D
0005434638949	1965	25	20C
0005434638948	1965	26	20D
0005434638946	1965	27	21A
0005432290588	1965	28	21B
0005434638950	1965	29	21C
0005434638951	1965	30	21D
0005434638940	1965	31	22C
0005434638932	1965	32	22D
0005434638955	1965	33	23A
0005434638930	1965	34	23B
0005433202134	23256	1	1B
0005433202135	23256	2	1D
0005433202133	23256	3	2B
0005433202145	23256	4	3C
0005433202143	23256	5	4D
0005433202142	23256	6	5D
0005433202140	23256	7	6A
0005433202141	23256	8	6D
0005433202139	23256	9	18A
0005433202144	23256	10	18B
0005433202138	23256	11	19A
0005433202146	23256	12	20D
0005433202136	23256	13	23A
0005433202137	23256	14	23B
0005434600411	6040	1	1C
0005434600410	6040	2	1D
0005432111234	6040	3	1F
0005434600424	6040	4	2A
0005434600428	6040	5	3A
0005432111236	6040	6	5C
0005434600429	6040	7	5D
0005434600433	6040	8	6C
0005433531238	6040	9	6D
0005434600430	6040	10	6F
0005434600423	6040	11	7A
0005434600427	6040	12	8A
0005433533253	6040	13	8C
0005433531237	6040	14	8D
0005434600425	6040	15	9F
0005434600418	6040	16	10E
0005433531240	6040	17	11D
0005434600422	6040	18	11E
0005434600415	6040	19	11F
0005432111235	6040	20	12C
0005434600414	6040	21	12F
0005433533254	6040	22	13A
0005434600417	6040	23	13D
0005434600412	6040	24	13F
0005433533255	6040	25	14D
0005433533256	6040	26	14E
0005434600420	6040	27	14F
0005434600419	6040	28	16A
0005434600426	6040	29	16C
0005434600413	6040	30	17D
0005433531239	6040	31	17F
0005434600432	6040	32	18A
0005434600421	6040	33	18F
0005434600434	6040	34	19A
0005434600416	6040	35	19D
0005434600436	6040	36	20C
0005434600431	6040	37	20A
0005434600435	6040	38	20F
0005435326553	18579	1	2D
0005435326547	18579	2	3C
0005435326551	18579	3	4C
0005435326549	18579	4	5A
0005435326543	18579	5	5D
0005435326548	18579	6	5E
0005435326539	18579	7	7E
0005435326542	18579	8	8D
0005435326544	18579	9	10C
0005435326540	18579	10	11A
0005435326552	18579	11	12A
0005435326546	18579	12	14C
0005435326541	18579	13	17C
0005435326550	18579	14	18C
0005435326545	18579	15	20A
0005434550388	10640	1	1C
0005434550394	10640	2	1F
0005434550415	10640	3	2A
0005434550400	10640	4	2C
0005434550404	10640	5	2D
0005434550420	10640	6	3A
0005434550407	10640	7	3D
0005434554030	10640	8	3F
0005434550372	10640	9	4A
0005434554031	10640	10	4C
0005434550381	10640	11	4D
0005434550369	10640	12	4E
0005434550393	10640	13	4F
0005434550376	10640	14	5A
0005434550380	10640	15	5C
0005434550386	10640	16	5D
0005434550373	10640	17	5E
0005434550375	10640	18	5F
0005434550423	10640	19	6A
0005434550398	10640	20	6D
0005434550387	10640	21	6E
0005434550410	10640	22	6F
0005434550418	10640	23	7C
0005434550411	10640	24	7D
0005434550370	10640	25	8C
0005434550396	10640	26	9A
0005434550378	10640	27	9D
0005434550374	10640	28	9E
0005434550402	10640	29	9F
0005434550403	10640	30	10A
0005434550408	10640	31	10F
0005434550379	10640	32	11A
0005434550382	10640	33	11C
0005434550424	10640	34	11E
0005434558154	10640	35	11F
0005434550377	10640	36	12A
0005434550417	10640	37	12C
0005434558151	10640	38	12D
0005434558150	10640	39	13A
0005434550416	10640	40	13C
0005434550392	10640	41	14A
0005434550390	10640	42	14C
0005434558152	10640	43	14D
0005434550422	10640	44	14F
0005434558153	10640	45	15D
0005434550385	10640	46	15F
0005434550389	10640	47	16C
0005434550397	10640	48	16D
0005434550405	10640	49	16E
0005434550406	10640	50	16F
0005434550384	10640	51	17A
0005434558149	10640	52	17E
0005434550414	10640	53	17F
0005434550409	10640	54	18C
0005434550399	10640	55	18D
0005434550383	10640	56	19A
0005434550421	10640	57	19C
0005434550395	10640	58	19D
0005434550412	10640	59	19E
0005434550413	10640	60	19F
0005434550371	10640	61	20A
0005434550401	10640	62	20C
0005434550391	10640	63	20D
0005434550419	10640	64	20E
0005433180734	27727	1	2C
0005433180736	27727	2	3F
0005433180730	27727	3	5A
0005433180749	27727	4	5C
0005433180738	27727	5	5D
0005433180726	27727	6	5F
0005433180739	27727	7	8A
0005433180735	27727	8	8E
0005433180744	27727	9	9D
0005433180727	27727	10	10A
0005433180745	27727	11	10C
0005433180728	27727	12	11A
0005433180750	27727	13	11E
0005433180737	27727	14	13D
0005433180729	27727	15	14A
0005433180743	27727	16	14C
0005433180748	27727	17	14F
0005433180740	27727	18	15C
0005433180742	27727	19	15D
0005433180733	27727	20	17A
0005433180746	27727	21	19C
0005433180731	27727	22	19D
0005433180732	27727	23	19F
0005433180741	27727	24	20A
0005433180747	27727	25	20E
0005434550291	27726	1	8C
0005434550290	27726	2	10E
0005433459157	6133	1	1B
0005433459158	6133	2	3A
0005433459156	6133	3	5A
0005433459159	6133	4	5B
0005435254437	19297	1	2A
0005435254439	19297	2	3B
0005435254438	19297	3	4A
0005435661887	6750	1	1C
0005435681542	6750	2	1D
0005435681513	6750	3	1F
0005435681526	6750	4	2A
0005432136095	6750	5	2F
0005435661888	6750	6	3A
0005435681548	6750	7	3F
0005435681533	6750	8	4A
0005435661885	6750	9	4C
0005435681518	6750	10	4D
0005435681547	6750	11	4E
0005435681525	6750	12	5A
0005435720120	6750	13	5D
0005435681535	6750	14	6A
0005435681541	6750	15	6E
0005435630922	6750	16	7A
0005435681540	6750	17	7C
0005435681508	6750	18	7D
0005435681522	6750	19	7E
0005435681523	6750	20	8E
0005435681543	6750	21	8F
0005435681517	6750	22	9A
0005435681524	6750	23	9E
0005435681544	6750	24	9F
0005435681530	6750	25	10D
0005432136094	6750	26	10E
0005435681531	6750	27	11A
0005435681515	6750	28	11E
0005435681537	6750	29	12A
0005435681534	6750	30	12C
0005435681546	6750	31	12D
0005435630921	6750	32	12E
0005432136096	6750	33	13A
0005435681511	6750	34	13C
0005435681520	6750	35	13D
0005432136097	6750	36	14A
0005435681545	6750	37	14C
0005432136099	6750	38	14D
0005435681529	6750	39	14F
0005435681528	6750	40	15A
0005435681536	6750	41	15C
0005435681532	6750	42	15D
0005435681514	6750	43	15E
0005435681538	6750	44	16A
0005435661886	6750	45	16C
0005435681509	6750	46	16F
0005435681521	6750	47	17A
0005435681519	6750	48	17C
0005435681527	6750	49	17D
0005435720121	6750	50	18C
0005435661889	6750	51	18D
0005435681516	6750	52	18E
0005432136098	6750	53	19A
0005435681510	6750	54	19D
0005432136100	6750	55	19E
0005435630919	6750	56	19F
0005435681512	6750	57	20A
0005435681539	6750	58	20C
0005435719552	6750	59	20D
0005435630920	6750	60	20E
0005435219169	24609	1	1A
0005435437621	24609	2	1C
0005435437620	24609	3	1D
0005435437639	24609	4	2A
0005435220286	24609	5	3A
0005435437623	24609	6	4A
0005435437630	24609	7	4E
0005432533250	24609	8	5D
0005432305713	24609	9	5E
0005434828656	24609	10	5F
0005435220289	24609	11	6A
0005435219166	24609	12	6E
0005435219167	24609	13	6F
0005434828657	24609	14	7A
0005435437638	24609	15	7D
0005435437629	24609	16	8D
0005435437640	24609	17	9F
0005435437634	24609	18	10A
0005435437636	24609	19	10C
0005435437632	24609	20	10D
0005435220288	24609	21	11F
0005435437633	24609	22	12C
0005435220488	24609	23	13A
0005435437625	24609	24	13D
0005435220287	24609	25	13E
0005435220285	24609	26	13F
0005432533249	24609	27	14D
0005435437622	24609	28	14E
0005435437631	24609	29	14F
0005434828658	24609	30	15A
0005432305712	24609	31	15E
0005435219168	24609	32	16A
0005435437637	24609	33	16D
0005432533251	24609	34	16E
0005435437628	24609	35	17D
0005435437641	24609	36	17E
0005435437642	24609	37	18C
0005435437624	24609	38	18D
0005435220290	24609	39	18F
0005435437626	24609	40	19E
0005435219170	24609	41	19F
0005435437635	24609	42	20C
0005435437627	24609	43	20D
0005435125733	11543	1	1A
0005435125759	11543	2	1D
0005435125758	11543	3	1F
0005435125750	11543	4	2D
0005435125731	11543	5	3C
0005435125756	11543	6	3D
0005435125769	11543	7	5A
0005435125765	11543	8	5C
0005435125734	11543	9	5D
0005435105933	11543	10	6A
0005435125745	11543	11	6C
0005435125738	11543	12	6D
0005435125749	11543	13	6E
0005435125763	11543	14	7A
0005435125743	11543	15	7E
0005435125762	11543	16	7F
0005435125737	11543	17	8C
0005435125736	11543	18	8E
0005435125768	11543	19	9C
0005435105932	11543	20	9D
0005435125732	11543	21	9E
0005435125764	11543	22	9F
0005435125767	11543	23	10A
0005435125730	11543	24	10C
0005435125746	11543	25	10E
0005435125748	11543	26	10F
0005435125747	11543	27	11E
0005435125766	11543	28	11F
0005435105934	11543	29	12D
0005435125751	11543	30	12E
0005435125760	11543	31	12F
0005435125741	11543	32	13C
0005435125753	11543	33	13D
0005435125742	11543	34	14A
0005435125739	11543	35	15A
0005435125771	11543	36	15C
0005435125770	11543	37	15F
0005435125754	11543	38	16D
0005435125757	11543	39	16E
0005435105935	11543	40	17C
0005435105936	11543	41	17D
0005435125761	11543	42	18A
0005435125744	11543	43	18C
0005435125735	11543	44	18E
0005435125755	11543	45	18F
0005435125752	11543	46	19F
0005435125740	11543	47	20F
0005435558049	31880	1	1C
0005435105929	31880	2	4D
0005435558048	31880	3	7D
0005435558050	31880	4	15F
0005435105928	31880	5	18E
0005433397344	13505	1	1A
0005433397338	13505	2	1D
0005433397365	13505	3	1F
0005433397369	13505	4	2C
0005433397328	13505	5	2D
0005433397342	13505	6	2F
0005433397345	13505	7	3A
0005433397331	13505	8	3F
0005433397378	13505	9	4C
0005433397355	13505	10	4E
0005433397332	13505	11	6A
0005433397362	13505	12	6D
0005433397353	13505	13	6E
0005433397366	13505	14	7C
0005433397347	13505	15	7E
0005433397370	13505	16	8D
0005433397364	13505	17	8F
0005433397343	13505	18	9A
0005433397358	13505	19	9C
0005433397357	13505	20	9E
0005433397333	13505	21	9F
0005433397363	13505	22	10C
0005433397371	13505	23	10D
0005433397341	13505	24	10E
0005433397354	13505	25	10F
0005433397352	13505	26	11D
0005433397336	13505	27	11F
0005433397340	13505	28	12D
0005433397376	13505	29	12F
0005433397367	13505	30	13D
0005433397330	13505	31	13E
0005433397346	13505	32	14A
0005433397348	13505	33	14C
0005433397368	13505	34	14D
0005433397375	13505	35	14E
0005433397349	13505	36	14F
0005433397360	13505	37	15A
0005433397377	13505	38	15C
0005433397373	13505	39	16C
0005433397356	13505	40	16D
0005433397337	13505	41	16E
0005433397350	13505	42	17F
0005433397359	13505	43	18A
0005433397372	13505	44	18C
0005433397339	13505	45	18D
0005433397334	13505	46	18E
0005433397374	13505	47	18F
0005433397335	13505	48	19A
0005433397361	13505	49	19C
0005433397351	13505	50	19D
0005433397329	13505	51	20D
0005432297240	19393	1	1A
0005432297238	19393	2	5D
0005435732156	19393	3	6D
0005435732152	19393	4	6E
0005435732154	19393	5	8A
0005435732159	19393	6	8E
0005435732155	19393	7	10F
0005435732158	19393	8	12C
0005435732157	19393	9	13C
0005435732161	19393	10	13E
0005435732160	19393	11	14D
0005432297239	19393	12	15D
0005435732153	19393	13	18C
0005435068283	15515	1	1A
0005435068282	15515	2	1C
0005435068296	15515	3	2A
0005435068288	15515	4	2D
0005435068280	15515	5	3C
0005435068317	15515	6	4A
0005435068308	15515	7	4C
0005435068309	15515	8	4F
0005435068311	15515	9	5E
0005435068273	15515	10	6E
0005435068284	15515	11	6F
0005435068276	15515	12	7A
0005435068285	15515	13	7C
0005435068305	15515	14	8A
0005435068270	15515	15	8E
0005435068295	15515	16	8F
0005435068268	15515	17	9E
0005435068287	15515	18	9F
0005435068293	15515	19	10A
0005435068315	15515	20	10C
0005435068290	15515	21	10D
0005435068306	15515	22	10F
0005435068297	15515	23	11E
0005435068286	15515	24	11F
0005435068264	15515	25	12D
0005435068300	15515	26	12E
0005435068304	15515	27	13A
0005435068310	15515	28	13C
0005435068279	15515	29	13D
0005435068275	15515	30	13E
0005435068294	15515	31	13F
0005435068274	15515	32	14A
0005435068272	15515	33	14C
0005435068316	15515	34	14F
0005435068298	15515	35	15A
0005435068271	15515	36	15C
0005435068269	15515	37	15F
0005435068313	15515	38	16A
0005435068314	15515	39	16C
0005435068312	15515	40	16D
0005435068281	15515	41	17A
0005435068266	15515	42	17C
0005435068303	15515	43	17D
0005435068265	15515	44	17E
0005435068277	15515	45	17F
0005435068289	15515	46	18A
0005435068292	15515	47	18C
0005435068299	15515	48	18D
0005435068301	15515	49	18F
0005435068307	15515	50	19C
0005435068291	15515	51	19D
0005435068267	15515	52	19E
0005435068278	15515	53	20A
0005435068302	15515	54	20F
0005435808068	23192	1	1B
0005435808067	23192	2	1D
0005435808078	23192	3	2A
0005435808076	23192	4	2C
0005435808073	23192	5	3A
0005435808074	23192	6	3C
0005435808077	23192	7	5A
0005435808080	23192	8	6A
0005435808063	23192	9	6B
0005435808066	23192	10	7A
0005435808075	23192	11	7C
0005435808071	23192	12	18D
0005435808060	23192	13	19C
0005435808065	23192	14	19D
0005435808062	23192	15	20B
0005435808072	23192	16	20C
0005435808061	23192	17	20D
0005435808069	23192	18	21B
0005435808064	23192	19	22A
0005435808079	23192	20	22C
0005435808070	23192	21	22D
0005434213851	10735	1	2A
0005434213852	10735	2	2C
0005434213866	10735	3	3C
0005434213876	10735	4	3F
0005434213870	10735	5	4A
0005434213874	10735	6	4C
0005434213862	10735	7	4D
0005434213863	10735	8	4F
0005434213883	10735	9	5A
0005434213855	10735	10	5D
0005434213871	10735	11	6C
0005434213861	10735	12	6D
0005434213882	10735	13	6F
0005434213850	10735	14	7C
0005434213860	10735	15	8A
0005434213864	10735	16	8C
0005434213867	10735	17	9C
0005434213842	10735	18	9D
0005434213848	10735	19	9E
0005434213859	10735	20	10A
0005434213875	10735	21	10C
0005434213880	10735	22	10D
0005434213879	10735	23	11C
0005434213878	10735	24	11D
0005434213853	10735	25	11E
0005434213877	10735	26	11F
0005434213888	10735	27	12A
0005434213843	10735	28	12C
0005434213854	10735	29	12D
0005434213856	10735	30	12E
0005434213869	10735	31	12F
0005434213886	10735	32	13C
0005434213885	10735	33	13D
0005434213841	10735	34	13F
0005434213857	10735	35	14A
0005434213845	10735	36	14C
0005434213846	10735	37	14E
0005434213858	10735	38	15A
0005434213849	10735	39	15C
0005434213881	10735	40	15F
0005434213868	10735	41	16E
0005434213873	10735	42	17D
0005434213847	10735	43	17E
0005434213844	10735	44	18C
0005434213872	10735	45	19A
0005434213865	10735	46	19F
0005434213887	10735	47	20A
0005434213884	10735	48	20D
0005434755803	28690	1	2C
0005434755798	28690	2	3A
0005434755813	28690	3	4D
0005434755801	28690	4	4F
0005434755800	28690	5	5A
0005434755820	28690	6	5F
0005434755784	28690	7	6A
0005434755793	28690	8	6C
0005434755789	28690	9	6D
0005434755786	28690	10	6E
0005434755817	28690	11	8A
0005434755805	28690	12	8D
0005434755808	28690	13	8F
0005434755802	28690	14	9D
0005434755791	28690	15	9E
0005434755806	28690	16	10C
0005434755818	28690	17	10E
0005434755823	28690	18	10F
0005434755812	28690	19	11E
0005434755794	28690	20	11F
0005434755796	28690	21	12C
0005434755821	28690	22	13A
0005434755816	28690	23	13D
0005434755782	28690	24	13F
0005434755822	28690	25	14E
0005434755785	28690	26	14F
0005434755783	28690	27	15A
0005434755795	28690	28	15E
0005434755815	28690	29	15F
0005434755819	28690	30	16A
0005434755804	28690	31	16D
0005434755792	28690	32	17A
0005434755814	28690	33	17C
0005434755811	28690	34	17D
0005434755797	28690	35	17F
0005434755809	28690	36	18E
0005434755807	28690	37	18F
0005434755790	28690	38	19D
0005434755788	28690	39	19E
0005434755799	28690	40	19F
0005434755810	28690	41	20D
0005434755787	28690	42	20F
0005432125345	5435	1	1A
0005435038811	5435	2	1C
0005435038824	5435	3	1D
0005435038839	5435	4	2C
0005432125342	5435	5	2D
0005435006673	5435	6	2F
0005435038859	5435	7	3C
0005435038849	5435	8	3D
0005435038829	5435	9	3F
0005435038867	5435	10	4A
0005435038808	5435	11	4C
0005435006697	5435	12	4D
0005435006685	5435	13	4E
0005435038825	5435	14	5A
0005435038843	5435	15	4F
0005435038818	5435	16	5B
0005435006684	5435	17	5C
0005435006682	5435	18	5D
0005435038863	5435	19	5F
0005435038846	5435	20	5E
0005435038827	5435	21	6A
0005435038865	5435	22	6C
0005435006674	5435	23	6B
0005435006691	5435	24	6E
0005435006676	5435	25	7A
0005435038837	5435	26	6F
0005435038822	5435	27	7C
0005435006677	5435	28	7E
0005435038864	5435	29	7D
0005435006690	5435	30	7F
0005435038813	5435	31	8B
0005435038830	5435	32	8A
0005435038853	5435	33	8D
0005435038840	5435	34	8C
0005435038852	5435	35	8F
0005435006696	5435	36	9A
0005435006681	5435	37	9B
0005435038857	5435	38	9D
0005435038845	5435	39	9F
0005435038854	5435	40	9E
0005435038870	5435	41	10B
0005435038847	5435	42	10C
0005435006692	5435	43	10E
0005435006679	5435	44	10D
0005435006672	5435	45	11A
0005435006687	5435	46	11B
0005435038817	5435	47	11C
0005435038819	5435	48	11E
0005435038821	5435	49	11D
0005435038834	5435	50	11F
0005435038815	5435	51	12A
0005435038823	5435	52	12C
0005435038835	5435	53	12D
0005432125348	5435	54	12E
0005435038812	5435	55	12F
0005435006688	5435	56	13A
0005432125347	5435	57	13C
0005435038861	5435	58	13E
0005435038805	5435	59	14B
0005435006680	5435	60	14A
0005432125344	5435	61	14C
0005435038869	5435	62	15A
0005435038832	5435	63	14F
0005435006689	5435	64	15B
0005435038855	5435	65	15D
0005435006683	5435	66	15F
0005435038868	5435	67	16A
0005435038842	5435	68	16C
0005435038814	5435	69	16B
0005435006693	5435	70	16D
0005435038828	5435	71	16F
0005435038838	5435	72	17B
0005435038858	5435	73	17A
0005435038831	5435	74	17D
0005435038810	5435	75	17F
0005435038856	5435	76	17E
0005435006695	5435	77	18A
0005435006694	5435	78	18B
0005435038826	5435	79	18D
0005435038850	5435	80	18C
0005435038866	5435	81	18E
0005435006686	5435	82	19A
0005432125343	5435	83	19B
0005435038844	5435	84	19C
0005432125341	5435	85	19E
0005435038809	5435	86	19F
0005432125346	5435	87	20C
0005435038807	5435	88	20E
0005435038833	5435	89	21A
0005435038806	5435	90	20F
0005435038841	5435	91	21B
0005435038816	5435	92	21E
0005435038836	5435	93	21F
0005435038848	5435	94	22A
0005435038851	5435	95	22C
0005435038862	5435	96	22D
0005435038860	5435	97	22F
0005435006678	5435	98	23B
0005435038820	5435	99	23C
0005435006675	5435	100	23E
0005434229056	12985	1	2C
0005434229058	12985	2	3A
0005434229054	12985	3	4A
0005434229041	12985	4	4C
0005434229055	12985	5	5A
0005434229049	12985	6	6D
0005432304343	12985	7	7B
0005434229038	12985	8	7A
0005434229052	12985	9	7C
0005434229040	12985	10	8C
0005434229036	12985	11	9C
0005434229050	12985	12	12E
0005434229044	12985	13	13A
0005434229051	12985	14	13F
0005434229048	12985	15	14C
0005434229047	12985	16	14F
0005434229039	12985	17	15C
0005434229057	12985	18	15D
0005434229053	12985	19	15F
0005432304340	12985	20	16A
0005432304342	12985	21	16D
0005434229043	12985	22	16E
0005432304341	12985	23	17D
0005434229046	12985	24	18B
0005434229035	12985	25	19F
0005434229037	12985	26	21D
0005435377900	12985	27	21E
0005434229045	12985	28	22A
0005434229042	12985	29	22D
0005434426172	14901	1	1C
0005434411711	14901	2	1F
0005434426173	14901	3	2C
0005434426159	14901	4	3D
0005434426163	14901	5	4D
0005434426157	14901	6	5D
0005434426154	14901	7	6A
0005434426161	14901	8	6C
0005434426169	14901	9	7A
0005434426167	14901	10	7C
0005434426156	14901	11	7D
0005434426158	14901	12	8C
0005434426170	14901	13	8D
0005434426146	14901	14	8E
0005434426151	14901	15	8F
0005434426148	14901	16	10A
0005434411712	14901	17	10E
0005434411710	14901	18	10F
0005434426147	14901	19	11A
0005434426160	14901	20	11C
0005434426150	14901	21	11E
0005434426155	14901	22	12D
0005432188557	14901	23	13A
0005434426165	14901	24	13F
0005434426149	14901	25	14C
0005434426153	14901	26	14F
0005432188558	14901	27	15A
0005434426171	14901	28	15C
0005434426162	14901	29	15E
0005434426152	14901	30	15F
0005434426164	14901	31	17D
0005434411713	14901	32	18A
0005434411714	14901	33	19A
0005432188559	14901	34	19E
0005432188560	14901	35	20A
0005434426166	14901	36	20D
0005434426168	14901	37	20E
0005435902448	20188	1	1F
0005435902455	20188	2	2A
0005435902454	20188	3	2C
0005435902452	20188	4	4C
0005435902447	20188	5	6C
0005435902456	20188	6	6F
0005435554119	20188	7	7D
0005435902451	20188	8	7E
0005435902446	20188	9	8C
0005435902453	20188	10	8E
0005435902440	20188	11	8F
0005435902438	20188	12	9D
0005435902443	20188	13	9E
0005435902449	20188	14	11A
0005435902445	20188	15	11D
0005435902442	20188	16	12F
0005435554118	20188	17	13C
0005435902444	20188	18	13F
0005435554122	20188	19	15A
0005435554121	20188	20	15C
0005432059476	20188	21	15E
0005435902441	20188	22	15F
0005435902439	20188	23	16D
0005435554120	20188	24	17C
0005435902450	20188	25	18E
0005434523738	30883	1	2C
0005434523739	30883	2	5E
0005434523732	30883	3	6C
0005434523740	30883	4	9B
0005434523736	30883	5	9C
0005434523734	30883	6	11B
0005434523735	30883	7	14A
0005434523731	30883	8	21C
0005434523733	30883	9	22A
0005434523737	30883	10	22C
0005435981625	26540	1	1A
0005435981634	26540	2	1D
0005435981623	26540	3	1F
0005432300176	26540	4	2A
0005435981619	26540	5	2D
0005435981644	26540	6	2F
0005435981607	26540	7	3C
0005435981631	26540	8	4E
0005435981617	26540	9	4F
0005435981614	26540	10	5A
0005435981594	26540	11	5F
0005432300172	26540	12	6C
0005435981643	26540	13	6D
0005435981635	26540	14	7C
0005435981604	26540	15	7D
0005435981626	26540	16	8A
0005435981605	26540	17	8C
0005435981640	26540	18	8D
0005435981642	26540	19	8F
0005435981621	26540	20	9A
0005435981633	26540	21	9C
0005435981595	26540	22	9D
0005435981636	26540	23	9E
0005435981602	26540	24	9F
0005435981637	26540	25	10A
0005435981630	26540	26	10C
0005435981624	26540	27	10D
0005432300177	26540	28	10E
0005435981613	26540	29	11A
0005435981622	26540	30	11C
0005435981628	26540	31	11E
0005435981618	26540	32	12C
0005435981612	26540	33	12E
0005435981639	26540	34	12F
0005432300173	26540	35	13A
0005435981641	26540	36	13D
0005435981608	26540	37	14A
0005435981599	26540	38	14C
0005432300174	26540	39	14D
0005435981620	26540	40	14F
0005435981600	26540	41	15A
0005435981615	26540	42	15C
0005435981606	26540	43	15F
0005435981638	26540	44	16A
0005435981603	26540	45	16D
0005435981627	26540	46	16E
0005435981610	26540	47	17A
0005435981611	26540	48	17D
0005435981596	26540	49	18A
0005435981601	26540	50	18C
0005435981629	26540	51	18D
0005435981632	26540	52	18F
0005432300175	26540	53	19A
0005435981616	26540	54	19E
0005435981597	26540	55	20C
0005435981598	26540	56	20D
0005435981609	26540	57	20E
0005433434270	26696	1	1D
0005433434281	26696	2	2A
0005433434286	26696	3	2F
0005433434287	26696	4	3A
0005433434284	26696	5	3C
0005433434282	26696	6	4C
0005433434288	26696	7	4E
0005433434293	26696	8	5A
0005433434272	26696	9	5D
0005434269075	26696	10	5E
0005433434294	26696	11	6A
0005433434268	26696	12	6D
0005433434275	26696	13	7C
0005433434280	26696	14	9A
0005433434289	26696	15	9C
0005433434278	26696	16	9D
0005433434276	26696	17	9E
0005433434267	26696	18	9F
0005433434266	26696	19	10F
0005433434279	26696	20	11A
0005433434285	26696	21	11E
0005433434290	26696	22	12D
0005433434271	26696	23	12E
0005432051083	26696	24	12F
0005433434269	26696	25	13D
0005433434291	26696	26	14A
0005433434283	26696	27	14D
0005433434274	26696	28	15A
0005432051085	26696	29	15C
0005434271281	26696	30	15D
0005434271283	26696	31	15F
0005433434292	26696	32	16C
0005432051084	26696	33	17F
0005433434273	26696	34	18C
0005434269074	26696	35	19C
0005434271282	26696	36	19F
0005434270177	26696	37	20A
0005433434277	26696	38	20C
0005432583676	3137	1	1A
0005432583667	3137	2	1B
0005432583680	3137	3	3B
0005432583662	3137	4	3C
0005432583673	3137	5	4A
0005432583681	3137	6	3D
0005432583665	3137	7	4B
0005432216232	3137	8	4D
0005432583670	3137	9	5A
0005432583679	3137	10	5D
0005432583666	3137	11	6B
0005432583669	3137	12	6C
0005432583661	3137	13	6D
0005432216231	3137	14	7A
0005432583668	3137	15	7B
0005432583685	3137	16	7C
0005432583675	3137	17	18A
0005432583672	3137	18	19B
0005432583683	3137	19	19C
0005432583677	3137	20	19D
0005432583682	3137	21	20A
0005432216233	3137	22	20D
0005432583674	3137	23	21A
0005432583671	3137	24	21D
0005432583663	3137	25	22A
0005432583678	3137	26	22C
0005432583664	3137	27	23A
0005432583684	3137	28	23B
0005432857887	31479	1	2A
0005432857893	31479	2	2B
0005432857892	31479	3	4D
0005432857891	31479	4	5C
0005432857896	31479	5	5D
0005432857889	31479	6	6D
0005432857897	31479	7	7B
0005432857895	31479	8	18D
0005432857894	31479	9	20D
0005432857898	31479	10	21B
0005432857890	31479	11	21D
0005432857888	31479	12	23B
0005434943218	870	1	2D
0005434943217	870	2	3C
0005434943219	870	3	4D
0005434943213	870	4	6B
0005434943220	870	5	7A
0005433255024	870	6	18B
0005433255025	870	7	19C
0005434943215	870	8	20A
0005434943214	870	9	21A
0005434943216	870	10	22D
0005434943221	870	11	23B
0005433255038	16196	1	4B
0005433255041	16196	2	5B
0005433255042	16196	3	18D
0005433255039	16196	4	19A
0005433255037	16196	5	22A
0005433255040	16196	6	23B
0005435858495	27608	1	4A
0005435858487	27608	2	5F
0005435858497	27608	3	6B
0005435858491	27608	4	6F
0005435858484	27608	5	8C
0005435858493	27608	6	9D
0005435858485	27608	7	10A
0005435858483	27608	8	10C
0005435858496	27608	9	11E
0005435858498	27608	10	12A
0005435858492	27608	11	12C
0005435858489	27608	12	13D
0005435858488	27608	13	14E
0005435858494	27608	14	15A
0005435858482	27608	15	17A
0005435858486	27608	16	16F
0005435858490	27608	17	20C
0005435858499	27608	18	21C
0005435652380	21758	1	2A
0005435652366	21758	2	2C
0005435652376	21758	3	3A
0005435652342	21758	4	3F
0005435652345	21758	5	4A
0005435652347	21758	6	4C
0005435652368	21758	7	4E
0005435652360	21758	8	5C
0005435652381	21758	9	5E
0005435652378	21758	10	6A
0005435652371	21758	11	6E
0005435652365	21758	12	7C
0005435652340	21758	13	7E
0005435652370	21758	14	8D
0005435652359	21758	15	8E
0005435652355	21758	16	9E
0005435652361	21758	17	9F
0005435652341	21758	18	10A
0005435652356	21758	19	10D
0005435652377	21758	20	10F
0005435652373	21758	21	11C
0005435652362	21758	22	11F
0005435652354	21758	23	12A
0005435652346	21758	24	12C
0005435652349	21758	25	13E
0005435652352	21758	26	13F
0005435652350	21758	27	14A
0005435652379	21758	28	14E
0005435652375	21758	29	15D
0005435652369	21758	30	16A
0005435652348	21758	31	16C
0005435652374	21758	32	16D
0005435652372	21758	33	17A
0005435652364	21758	34	17C
0005435652357	21758	35	17D
0005435652383	21758	36	17E
0005435652367	21758	37	17F
0005435652363	21758	38	18C
0005435652353	21758	39	18D
0005435652358	21758	40	18E
0005435652343	21758	41	19D
0005435652382	21758	42	19F
0005435652344	21758	43	20E
0005435652351	21758	44	20F
0005433804868	9374	1	1B
0005432657404	9374	2	1A
0005433804860	9374	3	1C
0005433784435	9374	4	1H
0005432657406	9374	5	2B
0005433804889	9374	6	2F
0005432657403	9374	7	2H
0005433763000	9374	8	3B
0005433762993	9374	9	3C
0005433804887	9374	10	3G
0005433762990	9374	11	3H
0005432665245	9374	12	4A
0005433762996	9374	13	4F
0005433784409	9374	14	5B
0005433763001	9374	15	5C
0005433784438	9374	16	5G
0005433784437	9374	17	9H
0005432657405	9374	18	11B
0005433784424	9374	19	11D
0005433784418	9374	20	11F
0005434170803	9374	21	12B
0005433804863	9374	22	12E
0005433784408	9374	23	12F
0005433784419	9374	24	13B
0005433784439	9374	25	13D
0005433804867	9374	26	13F
0005433762991	9374	27	14G
0005433804888	9374	28	15F
0005433804862	9374	29	16B
0005432665244	9374	30	16E
0005433784414	9374	31	16D
0005433804882	9374	32	16G
0005433804861	9374	33	17D
0005433784428	9374	34	17H
0005433804869	9374	35	18B
0005433784427	9374	36	18A
0005433784421	9374	37	18E
0005433804877	9374	38	19A
0005433804884	9374	39	18H
0005433784430	9374	40	19E
0005433762995	9374	41	19G
0005433804865	9374	42	20B
0005432667424	9374	43	20E
0005433804892	9374	44	20G
0005433804872	9374	45	21B
0005433784423	9374	46	21D
0005433784407	9374	47	21F
0005433784434	9374	48	21G
0005433784436	9374	49	22A
0005433804881	9374	50	22E
0005432667425	9374	51	23B
0005433804876	9374	52	23A
0005433804890	9374	53	23D
0005433762999	9374	54	24B
0005433784420	9374	55	24D
0005433784402	9374	56	24E
0005433804870	9374	57	24H
0005433784412	9374	58	27B
0005433784404	9374	59	27E
0005432667423	9374	60	27D
0005433804875	9374	61	27F
0005433804878	9374	62	27H
0005433784413	9374	63	27G
0005432657402	9374	64	28A
0005433762998	9374	65	28B
0005433784417	9374	66	28E
0005434170797	9374	67	28H
0005433784416	9374	68	28G
0005433784422	9374	69	29A
0005433784405	9374	70	29B
0005433784429	9374	71	29D
0005433804886	9374	72	29G
0005433804873	9374	73	29H
0005433784432	9374	74	30A
0005433784411	9374	75	30E
0005432666358	9374	76	30D
0005433804874	9374	77	30F
0005433804880	9374	78	31H
0005433784426	9374	79	32B
0005433762987	9374	80	32D
0005433784403	9374	81	32E
0005433762992	9374	82	32G
0005433784410	9374	83	33A
0005433804871	9374	84	33G
0005433762994	9374	85	33F
0005433804879	9374	86	33H
0005433784433	9374	87	34A
0005433784406	9374	88	34D
0005433762988	9374	89	34F
0005433784431	9374	90	34H
0005433804859	9374	91	35E
0005433784425	9374	92	36B
0005433784415	9374	93	36F
0005433804891	9374	94	36H
0005433804885	9374	95	36G
0005433784401	9374	96	37D
0005433804866	9374	97	37B
0005433804864	9374	98	37G
0005434170802	9374	99	38A
0005433804883	9374	100	37H
0005433762989	9374	101	38B
0005433762997	9374	102	39F
0005434151662	26229	1	2G
0005434170843	26229	2	4H
0005435269652	26229	3	12E
0005434170845	26229	4	14E
0005434151661	26229	5	16B
0005434269073	26229	6	17A
0005434270176	26229	7	17F
0005435269648	26229	8	18E
0005434170850	26229	9	20A
0005434170849	26229	10	21A
0005434170853	26229	11	20H
0005434170844	26229	12	21E
0005434170841	26229	13	23E
0005433784296	26229	14	24G
0005434269072	26229	15	25E
0005435269650	26229	16	25D
0005434170851	26229	17	28B
0005434170847	26229	18	28H
0005434170852	26229	19	30G
0005434269071	26229	20	31G
0005434269070	26229	21	32A
0005435269651	26229	22	31H
0005434170846	26229	23	32F
0005435269649	26229	24	32H
0005434170854	26229	25	33D
0005434151660	26229	26	34D
0005434170848	26229	27	36F
0005434270175	26229	28	38G
0005434270174	26229	29	39D
0005434170842	26229	30	39E
0005435135600	4906	1	2D
0005435135597	4906	2	7D
0005435135596	4906	3	19C
0005435135599	4906	4	21A
0005435135601	4906	5	21B
0005435135598	4906	6	23B
0005435929603	33047	1	1A
0005435929605	33047	2	2A
0005435929604	33047	3	4A
0005434983209	9473	1	3A
0005434983211	9473	2	6C
0005434983213	9473	3	6D
0005434983210	9473	4	7A
0005434983212	9473	5	19A
0005434983214	9473	6	20A
0005434217910	27378	1	5D
0005434217908	27378	2	20B
0005434217911	27378	3	21B
0005434217909	27378	4	21D
0005433960020	25934	1	1A
0005433985224	25934	2	1B
0005433985229	25934	3	1F
0005433959980	25934	4	1G
0005433985253	25934	5	2F
0005433960005	25934	6	2C
0005433959974	25934	7	2G
0005433960027	25934	8	2H
0005433960003	25934	9	3C
0005433985219	25934	10	3G
0005433960025	25934	11	4B
0005433959989	25934	12	4F
0005433959997	25934	13	4G
0005433985249	25934	14	5C
0005433960023	25934	15	9B
0005433959981	25934	16	9G
0005433959971	25934	17	11A
0005433985220	25934	18	9H
0005433985240	25934	19	11E
0005433959964	25934	20	11G
0005433959970	25934	21	12E
0005433985227	25934	22	12D
0005433960021	25934	23	12H
0005433960024	25934	24	12G
0005433960000	25934	25	13D
0005433959976	25934	26	13F
0005433985244	25934	27	13E
0005433959988	25934	28	13G
0005433985233	25934	29	14B
0005433960026	25934	30	14D
0005433985235	25934	31	14F
0005433959979	25934	32	14G
0005433985225	25934	33	14H
0005433959991	25934	34	15D
0005433959993	25934	35	15B
0005433959999	25934	36	15A
0005433959984	25934	37	15F
0005433985231	25934	38	15H
0005433985255	25934	39	16B
0005433985247	25934	40	16D
0005433959973	25934	41	16H
0005433960014	25934	42	17A
0005433960009	25934	43	17D
0005433985221	25934	44	17B
0005433985256	25934	45	17E
0005433985215	25934	46	17G
0005433985216	25934	47	17H
0005433985258	25934	48	18B
0005433959987	25934	49	18A
0005433985250	25934	50	18E
0005433985213	25934	51	18D
0005433960017	25934	52	18G
0005433959990	25934	53	18H
0005433985248	25934	54	19A
0005433985214	25934	55	19E
0005433959985	25934	56	19D
0005433959994	25934	57	19H
0005433959977	25934	58	20D
0005433960011	25934	59	20H
0005433959975	25934	60	21G
0005433985241	25934	61	22A
0005433985242	25934	62	22D
0005433959995	25934	63	22G
0005433960012	25934	64	23A
0005433985223	25934	65	22H
0005433985237	25934	66	23G
0005433959992	25934	67	23F
0005433959966	25934	68	24G
0005433985228	25934	69	25E
0005433959965	25934	70	27A
0005433985243	25934	71	27H
0005433960004	25934	72	28A
0005433960008	25934	73	28E
0005433959967	25934	74	28H
0005433959983	25934	75	29B
0005433985232	25934	76	29H
0005433985230	25934	77	30D
0005433960016	25934	78	30F
0005433959978	25934	79	30G
0005433960013	25934	80	30H
0005433985260	25934	81	31A
0005433985217	25934	82	31F
0005433959982	25934	83	32D
0005433960022	25934	84	32G
0005433985246	25934	85	33A
0005433985245	25934	86	33D
0005433985259	25934	87	33G
0005433985257	25934	88	33F
0005433985212	25934	89	33H
0005433960019	25934	90	34E
0005433959998	25934	91	34G
0005433985218	25934	92	34H
0005433985238	25934	93	35B
0005433959968	25934	94	35D
0005433960018	25934	95	35F
0005433960007	25934	96	35E
0005433985254	25934	97	35G
0005433960002	25934	98	35H
0005433985251	25934	99	37A
0005433960015	25934	100	36H
0005433959972	25934	101	37D
0005433959986	25934	102	37B
0005433985236	25934	103	37F
0005433960001	25934	104	37E
0005433985252	25934	105	37H
0005433985239	25934	106	38A
0005433959996	25934	107	38D
0005433959969	25934	108	38B
0005433985226	25934	109	38E
0005433960006	25934	110	38H
0005433985234	25934	111	38G
0005433960010	25934	112	39E
0005433985222	25934	113	39F
0005434479956	931	1	1B
0005434479954	931	2	1C
0005434479970	931	3	1D
0005434479976	931	4	2B
0005434479965	931	5	2C
0005434479952	931	6	2D
0005432269456	931	7	4B
0005434479977	931	8	4C
0005434479962	931	9	4D
0005434479973	931	10	5A
0005434479969	931	11	5B
0005434479960	931	12	5C
0005434479953	931	13	5D
0005434479975	931	14	6C
0005434479961	931	15	7A
0005434479967	931	16	7D
0005434479971	931	17	18A
0005434479966	931	18	18C
0005434479964	931	19	18D
0005434479959	931	20	20A
0005434479974	931	21	20B
0005434479955	931	22	20C
0005434479963	931	23	20D
0005432269455	931	24	21A
0005434479958	931	25	21C
0005434479972	931	26	22A
0005434479968	931	27	22B
0005434479957	931	28	22D
0005433165719	16549	1	1A
0005433165710	16549	2	3A
0005433165712	16549	3	4B
0005433165715	16549	4	4D
0005433165721	16549	5	6C
0005433165713	16549	6	18A
0005433165720	16549	7	20A
0005433165714	16549	8	20B
0005433165717	16549	9	20C
0005433165711	16549	10	20D
0005433165716	16549	11	21A
0005433165718	16549	12	21C
0005433165709	16549	13	22C
0005435386455	10342	1	1C
0005435142369	10342	2	1D
0005435142370	10342	3	2C
0005435149821	10342	4	2D
0005435149826	10342	5	3B
0005435142364	10342	6	3C
0005435142372	10342	7	3D
0005435142376	10342	8	4C
0005435142363	10342	9	4D
0005435149814	10342	10	5B
0005435142371	10342	11	5C
0005435149820	10342	12	6A
0005435149819	10342	13	7A
0005435142367	10342	14	7B
0005435142365	10342	15	7C
0005435149817	10342	16	18B
0005435149818	10342	17	19A
0005435142375	10342	18	19B
0005435149825	10342	19	19D
0005435142366	10342	20	20A
0005435142374	10342	21	20B
0005435149813	10342	22	20D
0005435149822	10342	23	21A
0005435149816	10342	24	21C
0005435142373	10342	25	22B
0005435142368	10342	26	22C
0005435149823	10342	27	22D
0005435149824	10342	28	23A
0005435149815	10342	29	23B
0005435386478	21949	1	1B
0005435386475	21949	2	1C
0005435386476	21949	3	3C
0005433289753	21949	4	4B
0005433289752	21949	5	4D
0005433289750	21949	6	6B
0005435386479	21949	7	18A
0005433289749	21949	8	18D
0005433289751	21949	9	19C
0005433289747	21949	10	19D
0005435386473	21949	11	20A
0005435386474	21949	12	20D
0005433289746	21949	13	21C
0005435386477	21949	14	22A
0005435386480	21949	15	21D
0005433289748	21949	16	22B
0005434573130	11186	1	5C
0005434573134	11186	2	5F
0005434573140	11186	3	7A
0005434573136	11186	4	8A
0005434573141	11186	5	9A
0005434573131	11186	6	10A
0005434573138	11186	7	15C
0005434573137	11186	8	16E
0005434573132	11186	9	16F
0005434573133	11186	10	17D
0005434573135	11186	11	18E
0005434573142	11186	12	20C
0005434573143	11186	13	20D
0005434573139	11186	14	20E
0005435517644	20921	1	1A
0005435517638	20921	2	1D
0005435501982	20921	3	1F
0005435517637	20921	4	2A
0005435501990	20921	5	2D
0005435501988	20921	6	3A
0005432291894	20921	7	3C
0005435319455	20921	8	3F
0005435501986	20921	9	4A
0005435501994	20921	10	4C
0005435508195	20921	11	5A
0005435508191	20921	12	5D
0005435517633	20921	13	5E
0005435517642	20921	14	5F
0005435501975	20921	15	6E
0005435501992	20921	16	7A
0005435517631	20921	17	7C
0005435517640	20921	18	7D
0005435501989	20921	19	7E
0005435517635	20921	20	7F
0005435508192	20921	21	8A
0005435508190	20921	22	8C
0005435508198	20921	23	8D
0005435508194	20921	24	8F
0005435517641	20921	25	9A
0005435501976	20921	26	9D
0005435501991	20921	27	9E
0005435319456	20921	28	10A
0005435517646	20921	29	10D
0005435517630	20921	30	10F
0005435319452	20921	31	11D
0005435319459	20921	32	11E
0005435517639	20921	33	11F
0005435508197	20921	34	12A
0005435517647	20921	35	12C
0005435508189	20921	36	12E
0005435517645	20921	37	12F
0005435517634	20921	38	13A
0005435501983	20921	39	13E
0005435501979	20921	40	13D
0005435501996	20921	41	13F
0005435517632	20921	42	14A
0005435508196	20921	43	14C
0005435319458	20921	44	14F
0005435508187	20921	45	15A
0005435319457	20921	46	15C
0005435508185	20921	47	15D
0005435501985	20921	48	15E
0005435508188	20921	49	15F
0005435501981	20921	50	16A
0005435501997	20921	51	16E
0005435508193	20921	52	16F
0005435508186	20921	53	17D
0005435501987	20921	54	17E
0005435319453	20921	55	17F
0005435517636	20921	56	18A
0005432291893	20921	57	18C
0005435501984	20921	58	18D
0005435319454	20921	59	18F
0005435517643	20921	60	19A
0005435319450	20921	61	19C
0005435501978	20921	62	19D
0005435501995	20921	63	19E
0005435501993	20921	64	19F
0005435319451	20921	65	20A
0005435517629	20921	66	20C
0005435501977	20921	67	20D
0005435501980	20921	68	20F
0005433683295	24303	1	1C
0005433683299	24303	2	3B
0005433683298	24303	3	6C
0005433683294	24303	4	6D
0005433683297	24303	5	18A
0005433683296	24303	6	18D
0005433683300	24303	7	19C
0005433927404	29287	1	2B
0005433927405	29287	2	3B
0005433927400	29287	3	6D
0005433927399	29287	4	7A
0005433927402	29287	5	7C
0005433927398	29287	6	20A
0005433927401	29287	7	21D
0005433927403	29287	8	22D
0005432217733	2918	1	1A
0005432706408	2918	2	2C
0005432706405	2918	3	4C
0005432706392	2918	4	4E
0005432706390	2918	5	4D
0005432706400	2918	6	5D
0005432706389	2918	7	6A
0005432217735	2918	8	6E
0005432706397	2918	9	7A
0005432217734	2918	10	8F
0005432706404	2918	11	9A
0005432706401	2918	12	10F
0005432706403	2918	13	11A
0005432706411	2918	14	11E
0005432706393	2918	15	13E
0005432706391	2918	16	13F
0005432706410	2918	17	14C
0005432706388	2918	18	14E
0005432706399	2918	19	15E
0005432706386	2918	20	16F
0005432706407	2918	21	17C
0005432706402	2918	22	17D
0005432706395	2918	23	17E
0005432706396	2918	24	17F
0005432706387	2918	25	18A
0005432706398	2918	26	18D
0005432706409	2918	27	18E
0005432706406	2918	28	19D
0005432706394	2918	29	20C
0005432692639	30010	1	1A
0005432692625	30010	2	1C
0005432692627	30010	3	1D
0005432692637	30010	4	2A
0005432880600	30010	5	2C
0005432880606	30010	6	2D
0005432880609	30010	7	3A
0005432880601	30010	8	4A
0005432692645	30010	9	4C
0005433123616	30010	10	4D
0005433123621	30010	11	4E
0005432692643	30010	12	5C
0005432692650	30010	13	5A
0005432692652	30010	14	5D
0005433123619	30010	15	5E
0005433123632	30010	16	5F
0005433123620	30010	17	6A
0005432692632	30010	18	6E
0005432692641	30010	19	6F
0005432880596	30010	20	7A
0005432692642	30010	21	7C
0005433123624	30010	22	7D
0005432692640	30010	23	7E
0005433123618	30010	24	7F
0005433123614	30010	25	8C
0005432692628	30010	26	8D
0005433123611	30010	27	8E
0005432692634	30010	28	8F
0005433123626	30010	29	9A
0005433123629	30010	30	9F
0005432692626	30010	31	10A
0005433123625	30010	32	10F
0005432880597	30010	33	11D
0005432880608	30010	34	11E
0005432692636	30010	35	11F
0005432880607	30010	36	12D
0005432692623	30010	37	12E
0005433123613	30010	38	12F
0005432692649	30010	39	13A
0005432880605	30010	40	13C
0005432692633	30010	41	13D
0005432692622	30010	42	14A
0005433123612	30010	43	14C
0005432880603	30010	44	14D
0005432692629	30010	45	14E
0005432692647	30010	46	14F
0005432880602	30010	47	15A
0005433123622	30010	48	15C
0005433123617	30010	49	15D
0005432692638	30010	50	15E
0005432880598	30010	51	15F
0005432692648	30010	52	16A
0005432692646	30010	53	16C
0005432692651	30010	54	16D
0005433123630	30010	55	16F
0005433123627	30010	56	17A
0005432880604	30010	57	17C
0005432692631	30010	58	17F
0005432692630	30010	59	18A
0005432880599	30010	60	18C
0005432692635	30010	61	18E
0005433123633	30010	62	18F
0005432692644	30010	63	19C
0005433123623	30010	64	19D
0005433123628	30010	65	19E
0005432692624	30010	66	20A
0005433123615	30010	67	20D
0005432880610	30010	68	20E
0005433123631	30010	69	20F
0005434979331	23689	1	1A
0005434979316	23689	2	1B
0005434979317	23689	3	1D
0005434979342	23689	4	2A
0005434979344	23689	5	2B
0005434979340	23689	6	2D
0005434979341	23689	7	3A
0005434988571	23689	8	3B
0005434979334	23689	9	3C
0005434979326	23689	10	3D
0005434979323	23689	11	4C
0005434979329	23689	12	4D
0005434988574	23689	13	5A
0005434988576	23689	14	5C
0005434979339	23689	15	5D
0005434979324	23689	16	6A
0005434979336	23689	17	6B
0005434979335	23689	18	6D
0005434979318	23689	19	7A
0005434988572	23689	20	7C
0005434988579	23689	21	7D
0005434979333	23689	22	18A
0005434988578	23689	23	18B
0005434979332	23689	24	18C
0005434979322	23689	25	18D
0005434988573	23689	26	19A
0005434979321	23689	27	19B
0005434979337	23689	28	19C
0005434979319	23689	29	19D
0005434979325	23689	30	20A
0005434979338	23689	31	20C
0005434988577	23689	32	20D
0005434979314	23689	33	21A
0005434979330	23689	34	21C
0005434979343	23689	35	21D
0005434979315	23689	36	22A
0005434988575	23689	37	22B
0005434979327	23689	38	22C
0005434979328	23689	39	23A
0005434979320	23689	40	23B
0005434302394	10305	1	2D
0005434302393	10305	2	7A
0005434302391	10305	3	19B
0005434302392	10305	4	19C
0005433113502	19626	1	4C
0005433113504	19626	2	5C
0005433113503	19626	3	21B
0005435068369	3540	1	1A
0005435068336	3540	2	1F
0005435068365	3540	3	2A
0005435068355	3540	4	2C
0005435068354	3540	5	3A
0005435068370	3540	6	3D
0005435068356	3540	7	3F
0005435068366	3540	8	4C
0005435068359	3540	9	4D
0005435068343	3540	10	4E
0005435068322	3540	11	5A
0005435068331	3540	12	5D
0005435068340	3540	13	5E
0005435068348	3540	14	6C
0005435068362	3540	15	6F
0005435068367	3540	16	7A
0005435068339	3540	17	7C
0005435718849	3540	18	7D
0005435068329	3540	19	7F
0005435068350	3540	20	8A
0005435068326	3540	21	8D
0005435068334	3540	22	9C
0005435068338	3540	23	9F
0005435718850	3540	24	10A
0005435068358	3540	25	10E
0005435068344	3540	26	10F
0005435068349	3540	27	11C
0005435718855	3540	28	11E
0005435068318	3540	29	11F
0005435068364	3540	30	12D
0005435068352	3540	31	12E
0005435068324	3540	32	12F
0005435068333	3540	33	13D
0005435718848	3540	34	13E
0005435068320	3540	35	13F
0005435068347	3540	36	14A
0005435068353	3540	37	15C
0005435068351	3540	38	15F
0005435068360	3540	39	16A
0005435068357	3540	40	16C
0005435068332	3540	41	16D
0005435068361	3540	42	16E
0005435068328	3540	43	16F
0005435068346	3540	44	17A
0005435068327	3540	45	17C
0005435068323	3540	46	17D
0005435068368	3540	47	17E
0005435718851	3540	48	17F
0005435068363	3540	49	18A
0005435718854	3540	50	18D
0005435068335	3540	51	19A
0005435068337	3540	52	18F
0005435068321	3540	53	19C
0005435068341	3540	54	19D
0005435068345	3540	55	19E
0005435718852	3540	56	19F
0005435068319	3540	57	20A
0005435068330	3540	58	20C
0005435068342	3540	59	20D
0005435718853	3540	60	20E
0005435068325	3540	61	20F
0005432659676	18207	1	2A
0005432660789	18207	2	2B
0005432658561	18207	3	3B
0005432659675	18207	4	4A
0005432658560	18207	5	6A
0005432660788	18207	6	6B
0005432157464	22	1	9F
0005432261249	21	1	1C
0005432817044	21	2	2A
0005432817033	21	3	1F
0005432817039	21	4	2D
0005432261254	21	5	2F
0005432261257	21	6	3D
0005432288937	21	7	4F
0005432261242	21	8	5A
0005432817043	21	9	5C
0005432261255	21	10	5D
0005432261239	21	11	7C
0005432261234	21	12	7F
0005432817050	21	13	8D
0005432261251	21	14	8C
0005432261238	21	15	9A
0005432817048	21	16	8F
0005432261265	21	17	9D
0005432261229	21	18	9E
0005432261273	21	19	9F
0005432261240	21	20	10C
0005432261245	21	21	10D
0005432817049	21	22	11B
0005432261232	21	23	11D
0005432261258	21	24	12A
0005432261233	21	25	12B
0005432261250	21	26	12D
0005432261244	21	27	12E
0005432261247	21	28	13A
0005432261264	21	29	13C
0005432817028	21	30	14C
0005432207623	21	31	14F
0005432817031	21	32	14E
0005432261246	21	33	15B
0005432261270	21	34	15A
0005432261261	21	35	15D
0005432817036	21	36	15F
0005432817037	21	37	16B
0005432261262	21	38	16C
0005432261235	21	39	16E
0005432817045	21	40	16F
0005432261243	21	41	17B
0005432817055	21	42	17C
0005432261260	21	43	17D
0005432261253	21	44	18B
0005432261274	21	45	18D
0005432817051	21	46	18E
0005432261271	21	47	18F
0005432261269	21	48	19C
0005432817054	21	49	20C
0005432261267	21	50	21A
0005432817058	21	51	21E
0005432261259	21	52	21F
0005432261266	21	53	22B
0005432261252	21	54	22D
0005432817052	21	55	22C
0005432207622	21	56	23A
0005432261272	21	57	23C
0005432261228	21	58	23B
0005432261268	21	59	23D
0005432288938	21	60	23E
0005432817038	21	61	24B
0005432817032	21	62	24D
0005432817056	21	63	24F
0005432261241	21	64	24E
0005432261263	21	65	25C
0005432817042	21	66	25B
0005432261231	21	67	25E
0005432261256	21	68	26A
0005432817040	21	69	26B
0005432261236	21	70	26C
0005432261230	21	71	26D
0005432817046	21	72	27A
0005432261248	21	73	27C
0005432817057	21	74	27B
0005432261275	21	75	27F
0005432288939	21	76	28B
0005432817047	21	77	28F
0005432817041	21	78	29B
0005432817053	21	79	29F
0005434153515	21	80	30C
0005432817029	21	81	30A
0005432817030	21	82	31A
0005432817034	21	83	31C
0005432817035	21	84	31D
0005432261237	21	85	31E
0005432753253	8122	1	1A
0005433101351	8122	2	1C
0005433101366	8122	3	1F
0005433101371	8122	4	1D
0005432019884	8122	5	2A
0005432919552	8122	6	2D
0005432019870	8122	7	2F
0005432019880	8122	8	3D
0005432919559	8122	9	3C
0005432019860	8122	10	3F
0005432019872	8122	11	4A
0005432919555	8122	12	4D
0005432019874	8122	13	4C
0005432919557	8122	14	4F
0005432019876	8122	15	5A
0005433101355	8122	16	5C
0005433101370	8122	17	5D
0005433101376	8122	18	6A
0005432391957	8122	19	7A
0005432019867	8122	20	7C
0005432019871	8122	21	7F
0005432045586	8122	22	7D
0005432045585	8122	23	8A
0005433101367	8122	24	8C
0005433101365	8122	25	8B
0005433101369	8122	26	8E
0005433101347	8122	27	9A
0005432391956	8122	28	9C
0005432019873	8122	29	9B
0005433101364	8122	30	9E
0005433101368	8122	31	10A
0005432751480	8122	32	10D
0005432019865	8122	33	10C
0005433101348	8122	34	10E
0005432019866	8122	35	10F
0005433101346	8122	36	11C
0005433101387	8122	37	11B
0005433101372	8122	38	11D
0005433101352	8122	39	11F
0005433101357	8122	40	12B
0005432677515	8122	41	12C
0005432919558	8122	42	12E
0005432919546	8122	43	12D
0005432044485	8122	44	13A
0005432019864	8122	45	12F
0005433101353	8122	46	13B
0005433101380	8122	47	13C
0005432753254	8122	48	13D
0005432677519	8122	49	14A
0005432677517	8122	50	14C
0005432019881	8122	51	14B
0005432751477	8122	52	14D
0005432919550	8122	53	14F
0005432044484	8122	54	15A
0005432019887	8122	55	15E
0005433101349	8122	56	16A
0005432019886	8122	57	16B
0005433101356	8122	58	16C
0005433101381	8122	59	16F
0005432751478	8122	60	16E
0005432919561	8122	61	17B
0005432019878	8122	62	17A
0005432919549	8122	63	17C
0005433101382	8122	64	18B
0005433101386	8122	65	18D
0005432919565	8122	66	18E
0005433101359	8122	67	19C
0005432919556	8122	68	19D
0005432919547	8122	69	19E
0005433101361	8122	70	20B
0005432919563	8122	71	20A
0005432019877	8122	72	20C
0005432391955	8122	73	20E
0005432677516	8122	74	21A
0005432753252	8122	75	21C
0005432919554	8122	76	21D
0005433101358	8122	77	21F
0005432019875	8122	78	21E
0005433101354	8122	79	22F
0005433101385	8122	80	22E
0005433101389	8122	81	23A
0005433101390	8122	82	23D
0005432044483	8122	83	23E
0005432677518	8122	84	24A
0005432019883	8122	85	23F
0005433101373	8122	86	24D
0005432019861	8122	87	24C
0005432919553	8122	88	25A
0005433101388	8122	89	25B
0005432019863	8122	90	25D
0005433101377	8122	91	25E
0005432919562	8122	92	26A
0005432019869	8122	93	25F
0005432019882	8122	94	26B
0005433101350	8122	95	26C
0005433101374	8122	96	26D
0005432919560	8122	97	26F
0005433101378	8122	98	27B
0005433101383	8122	99	27F
0005432019868	8122	100	27E
0005433101362	8122	101	28A
0005433101360	8122	102	28C
0005432919566	8122	103	28D
0005432919564	8122	104	29A
0005432391958	8122	105	29C
0005433101384	8122	106	29F
0005432019879	8122	107	29E
0005433101363	8122	108	30B
0005432019862	8122	109	30D
0005432751479	8122	110	30E
0005432919548	8122	111	30F
0005433101375	8122	112	31A
0005433101379	8122	113	31C
0005432019885	8122	114	31E
0005432919551	8122	115	31D
0005432901355	8123	1	1A
0005432901364	8123	2	1F
0005432002046	8123	3	9D
0005432901357	8123	4	11C
0005432901349	8123	5	11B
0005432901353	8123	6	15E
0005432901350	8123	7	16D
0005432901361	8123	8	17F
0005432901363	8123	9	19B
0005432901347	8123	10	21F
0005432901354	8123	11	22D
0005432901358	8123	12	22F
0005432901362	8123	13	23A
0005432901360	8123	14	24E
0005432901359	8123	15	25C
0005432901348	8123	16	26B
0005432901352	8123	17	27D
0005432901356	8123	18	27F
0005432901351	8123	19	28C
0005432002047	8123	20	30D
0005433870699	9684	1	2B
0005434175693	32368	1	1B
0005434175691	32368	2	3B
0005434175692	32368	3	4B
0005435125806	3473	1	1D
0005434426198	3473	2	1A
0005435125795	3473	3	1G
0005434876933	3473	4	1K
0005434876872	3473	5	2C
0005435125808	3473	6	2A
0005434876923	3473	7	2H
0005434876847	3473	8	2G
0005434876926	3473	9	2K
0005432799050	3473	10	3C
0005435125779	3473	11	3K
0005435125811	3473	12	3H
0005435125788	3473	13	4D
0005432611653	3473	14	5D
0005434937852	3473	15	5C
0005435625921	3473	16	11A
0005434876857	3473	17	5K
0005434876873	3473	18	11C
0005432799041	3473	19	11F
0005434937868	3473	20	11E
0005434426177	3473	21	11H
0005434876910	3473	22	11G
0005432611652	3473	23	12A
0005432613801	3473	24	11K
0005434426188	3473	25	12E
0005435125772	3473	26	12H
0005435125784	3473	27	12G
0005434876925	3473	28	12K
0005434426180	3473	29	13F
0005434876882	3473	30	13E
0005434426178	3473	31	13G
0005435125786	3473	32	14C
0005434876907	3473	33	13K
0005434876876	3473	34	14D
0005435125798	3473	35	14F
0005434876874	3473	36	14E
0005435125800	3473	37	14K
0005434876887	3473	38	14H
0005432799063	3473	39	15E
0005434937870	3473	40	15H
0005434876918	3473	41	15G
0005434937853	3473	42	15F
0005432799064	3473	43	15K
0005434876866	3473	44	16C
0005434426199	3473	45	16F
0005432799048	3473	46	16E
0005434876929	3473	47	16K
0005434876854	3473	48	16G
0005434876861	3473	49	17C
0005432799066	3473	50	17A
0005432799054	3473	51	17E
0005432613802	3473	52	17D
0005434876877	3473	53	17G
0005434876941	3473	54	17H
0005434876902	3473	55	18C
0005434876905	3473	56	18B
0005434426174	3473	57	18A
0005434876919	3473	58	18D
0005434876924	3473	59	18F
0005434876850	3473	60	18J
0005434937865	3473	61	18H
0005434876859	3473	62	19B
0005434876906	3473	63	18K
0005434876894	3473	64	19F
0005432799045	3473	65	19E
0005434426204	3473	66	19D
0005434876885	3473	67	19J
0005435125790	3473	68	20A
0005434876930	3473	69	19K
0005435125803	3473	70	20C
0005435625923	3473	71	20E
0005435125783	3473	72	20D
0005432188562	3473	73	20G
0005432613803	3473	74	20F
0005434876858	3473	75	20J
0005435125794	3473	76	20H
0005435125782	3473	77	21A
0005434937867	3473	78	21J
0005434426185	3473	79	21G
0005435125804	3473	80	22A
0005434426184	3473	81	22D
0005432799065	3473	82	22B
0005434876899	3473	83	22F
0005432799044	3473	84	22E
0005432613804	3473	85	22H
0005434876935	3473	86	22K
0005434876851	3473	87	23D
0005432799067	3473	88	23F
0005434876903	3473	89	23E
0005434426181	3473	90	23H
0005434426191	3473	91	23K
0005435125785	3473	92	24F
0005435125774	3473	93	24E
0005434876865	3473	94	25B
0005435125796	3473	95	24G
0005435125787	3473	96	25C
0005434876892	3473	97	25F
0005434426183	3473	98	25E
0005432799049	3473	99	25H
0005434876888	3473	100	25G
0005434426182	3473	101	25J
0005434876890	3473	102	26C
0005434876912	3473	103	26A
0005434937869	3473	104	26E
0005434937856	3473	105	26D
0005434937864	3473	106	26G
0005435625918	3473	107	26K
0005432611654	3473	108	26H
0005434876860	3473	109	27B
0005434876939	3473	110	27D
0005434876921	3473	111	27F
0005434876863	3473	112	27E
0005435125777	3473	113	27H
0005434876869	3473	114	27G
0005434937858	3473	115	27K
0005434876901	3473	116	28B
0005435625913	3473	117	28E
0005434426200	3473	118	28D
0005434876886	3473	119	28C
0005434937862	3473	120	28G
0005434876849	3473	121	28H
0005434876883	3473	122	29A
0005434876914	3473	123	28K
0005432799052	3473	124	29D
0005435125797	3473	125	29C
0005434876898	3473	126	29F
0005435625916	3473	127	29E
0005434426189	3473	128	29J
0005432799060	3473	129	29H
0005435625919	3473	130	30A
0005434876891	3473	131	30C
0005435125805	3473	132	30E
0005432799055	3473	133	30D
0005434876884	3473	134	30J
0005435125809	3473	135	30H
0005434426187	3473	136	31A
0005434876893	3473	137	31D
0005435125773	3473	138	31C
0005435625926	3473	139	31E
0005432799058	3473	140	32A
0005435125778	3473	141	32E
0005435125780	3473	142	33B
0005434426176	3473	143	33A
0005434876942	3473	144	32K
0005432188561	3473	145	33D
0005435125793	3473	146	33C
0005435125807	3473	147	33G
0005432611651	3473	148	34C
0005432799051	3473	149	34B
0005432799040	3473	150	34A
0005434876881	3473	151	34E
0005432799047	3473	152	34D
0005434426190	3473	153	34G
0005434937854	3473	154	35B
0005432799043	3473	155	35D
0005434876870	3473	156	35C
0005434876936	3473	157	35F
0005434937855	3473	158	35E
0005434426179	3473	159	35J
0005434426194	3473	160	35G
0005434876920	3473	161	35K
0005434876852	3473	162	36B
0005434876889	3473	163	36E
0005435625914	3473	164	36D
0005435125802	3473	165	36H
0005434876853	3473	166	36K
0005434426192	3473	167	37C
0005434937859	3473	168	37B
0005435125799	3473	169	37E
0005434426196	3473	170	37H
0005434876928	3473	171	37G
0005434876864	3473	172	37K
0005434876934	3473	173	37J
0005435125781	3473	174	38C
0005434876909	3473	175	38A
0005434937863	3473	176	38K
0005434426203	3473	177	38H
0005432799062	3473	178	39C
0005432799046	3473	179	39B
0005434876908	3473	180	39F
0005434876916	3473	181	39E
0005432613805	3473	182	39J
0005434426195	3473	183	39H
0005435625925	3473	184	39G
0005434937860	3473	185	40C
0005434876917	3473	186	40E
0005434876913	3473	187	40D
0005435125776	3473	188	40G
0005435125792	3473	189	40H
0005434426186	3473	190	41D
0005435625924	3473	191	41C
0005434426201	3473	192	41G
0005435125789	3473	193	41E
0005434876904	3473	194	42A
0005434876896	3473	195	41K
0005434876900	3473	196	42C
0005434876848	3473	197	42G
0005434426202	3473	198	42K
0005435625915	3473	199	42H
0005432799053	3473	200	43C
0005435625917	3473	201	43F
0005435125791	3473	202	43E
0005435625920	3473	203	43H
0005432799056	3473	204	44A
0005434876867	3473	205	43K
0005434876895	3473	206	44B
0005434937871	3473	207	44E
0005432799059	3473	208	44F
0005432799042	3473	209	44J
0005434876868	3473	210	44H
0005435125775	3473	211	45B
0005435125812	3473	212	45D
0005434876938	3473	213	45C
0005434876878	3473	214	45E
0005434937866	3473	215	45H
0005434876927	3473	216	45G
0005434876880	3473	217	45J
0005434876911	3473	218	46B
0005432799057	3473	219	46G
0005434876856	3473	220	46F
0005434937857	3473	221	46J
0005435625922	3473	222	47A
0005435125813	3473	223	46K
0005434876897	3473	224	47C
0005434876915	3473	225	47E
0005434876855	3473	226	47K
0005434426197	3473	227	48E
0005434876862	3473	228	48D
0005434876937	3473	229	48H
0005434876871	3473	230	48G
0005432799061	3473	231	48F
0005434426193	3473	232	48K
0005435625927	3473	233	49G
0005435125810	3473	234	49F
0005434876922	3473	235	49E
0005435125801	3473	236	49K
0005434937861	3473	237	49H
0005434876932	3473	238	50D
0005434876875	3473	239	50C
0005434876879	3473	240	50E
0005434876940	3473	241	50G
0005434876931	3473	242	50K
0005432799068	3473	243	51D
0005434426175	3473	244	51G
0005435913865	14563	1	1A
0005435913858	14563	2	2K
0005435902449	14563	3	3K
0005435902455	14563	4	4C
0005432059476	14563	5	4A
0005435913861	14563	6	5G
0005435902450	14563	7	11A
0005435902438	14563	8	11D
0005435902439	14563	9	11F
0005435902454	14563	10	11K
0005435913859	14563	11	13D
0005435902448	14563	12	15K
0005434876642	14563	13	18H
0005435841811	14563	14	19K
0005435902456	14563	15	20H
0005435902446	14563	16	23C
0005435902441	14563	17	25A
0005435902440	14563	18	25K
0005435902452	14563	19	28D
0005435902443	14563	20	30F
0005435902445	14563	21	34A
0005435842315	14563	22	36J
0005435902451	14563	23	37D
0005435913860	14563	24	37H
0005435913864	14563	25	39G
0005435902442	14563	26	42A
0005435842316	14563	27	42C
0005435902444	14563	28	43G
0005435913862	14563	29	44C
0005435902453	14563	30	45A
0005435914683	14563	31	45C
0005435902447	14563	32	48H
0005435913863	14563	33	49D
0005434312288	3636	1	2C
0005434312287	3636	2	2D
0005434325484	3636	3	3D
0005434325487	3636	4	4D
0005434325478	3636	5	6B
0005434325479	3636	6	6D
0005434325489	3636	7	7D
0005434325483	3636	8	18C
0005434325481	3636	9	19A
0005434325482	3636	10	19C
0005434325485	3636	11	20A
0005434325486	3636	12	21B
0005434325480	3636	13	22B
0005434325488	3636	14	22D
0005434325490	3636	15	23A
0005435889807	15610	1	4D
0005435889810	15610	2	18B
0005435889809	15610	3	19D
0005435889808	15610	4	20D
0005435889812	15610	5	21D
0005435889811	15610	6	22B
0005435889813	15610	7	22D
0005435957497	648	1	1D
0005435957494	648	2	4B
0005435957492	648	3	5C
0005435957489	648	4	6A
0005435957487	648	5	6C
0005435957491	648	6	7B
0005435957498	648	7	7D
0005435957485	648	8	19C
0005435957484	648	9	19D
0005435957486	648	10	20A
0005435957490	648	11	20B
0005435957495	648	12	21A
0005435957496	648	13	21B
0005435957488	648	14	22C
0005435957493	648	15	23B
0005433420279	15181	1	2C
0005433420276	15181	2	3B
0005433420278	15181	3	4A
0005433420282	15181	4	5B
0005433420280	15181	5	6A
0005433420283	15181	6	6C
0005433420284	15181	7	18A
0005433420281	15181	8	19A
0005433420277	15181	9	23A
0005435217683	31784	1	2B
0005435217681	31784	2	3B
0005435218100	31784	3	3C
0005435216557	31784	4	5A
0005435216555	31784	5	4D
0005435218104	31784	6	5B
0005435217680	31784	7	5D
0005435216560	31784	8	6D
0005435217679	31784	9	7C
0005435218103	31784	10	18A
0005435216558	31784	11	20A
0005435218102	31784	12	20B
0005435216559	31784	13	21A
0005435217684	31784	14	21B
0005435216556	31784	15	21C
0005435218101	31784	16	22A
0005435217682	31784	17	22B
0005434995277	6697	1	1C
0005434995276	6697	2	3F
0005434995275	6697	3	6B
0005434995278	6697	4	10E
0005434995280	6697	5	11F
0005434995281	6697	6	14D
0005434995282	6697	7	15C
0005434995279	6697	8	16A
0005434467725	4010	1	3B
0005434467726	4010	2	3D
0005434467728	4010	3	19A
0005434467730	4010	4	19C
0005434467729	4010	5	20C
0005434467727	4010	6	20D
0005434467731	4010	7	21C
0005434096711	20178	1	1D
0005434096708	20178	2	3B
0005434096709	20178	3	3C
0005434096710	20178	4	6C
0005434096713	20178	5	7A
0005434096712	20178	6	20B
0005434096707	20178	7	22A
0005432645797	6837	1	1A
0005432645781	6837	2	1D
0005432645783	6837	3	1F
0005432645804	6837	4	2D
0005432645799	6837	5	2F
0005432645801	6837	6	3C
0005432645777	6837	7	3F
0005432645803	6837	8	5A
0005432645774	6837	9	5C
0005432645806	6837	10	6D
0005432645807	6837	11	6E
0005432645805	6837	12	7D
0005432645786	6837	13	8A
0005432645779	6837	14	8C
0005432645800	6837	15	9A
0005432645796	6837	16	10C
0005432645785	6837	17	10D
0005432645794	6837	18	10F
0005432645793	6837	19	11D
0005432645787	6837	20	11F
0005432645789	6837	21	12A
0005432645782	6837	22	12C
0005432645811	6837	23	12F
0005432645795	6837	24	13E
0005432645788	6837	25	14E
0005432645784	6837	26	14F
0005432645812	6837	27	15A
0005432645776	6837	28	15E
0005432645778	6837	29	15F
0005432645802	6837	30	16A
0005432645798	6837	31	16C
0005432645792	6837	32	16D
0005432645791	6837	33	16F
0005432645775	6837	34	19A
0005432645780	6837	35	19E
0005432645808	6837	36	19F
0005432645809	6837	37	20C
0005432645810	6837	38	20D
0005432645790	6837	39	20F
0005435229314	25108	1	1A
0005435229323	25108	2	1C
0005435229317	25108	3	2C
0005435229318	25108	4	3C
0005435229319	25108	5	3D
0005435229301	25108	6	4D
0005435229326	25108	7	5F
0005435229303	25108	8	7A
0005435229330	25108	9	7D
0005435229315	25108	10	8D
0005435229308	25108	11	8E
0005435229307	25108	12	10A
0005435229313	25108	13	11C
0005435229324	25108	14	12C
0005435229320	25108	15	12D
0005435229327	25108	16	13C
0005435229311	25108	17	14D
0005435229305	25108	18	14E
0005435229312	25108	19	15A
0005435229322	25108	20	15C
0005435229316	25108	21	16D
0005435229321	25108	22	16F
0005435229309	25108	23	18C
0005435229304	25108	24	19C
0005435229302	25108	25	19D
0005435229329	25108	26	19E
0005435229310	25108	27	19F
0005435229328	25108	28	20C
0005435229325	25108	29	20E
0005435229306	25108	30	20F
0005435797273	2838	1	2F
0005435797272	2838	2	3A
0005435797276	2838	3	3F
0005435797274	2838	4	6F
0005435797269	2838	5	9D
0005435797266	2838	6	9F
0005435797277	2838	7	10F
0005435797275	2838	8	11A
0005435797267	2838	9	11F
0005435797278	2838	10	13E
0005435797279	2838	11	15E
0005435797268	2838	12	18A
0005435797271	2838	13	18C
0005435797265	2838	14	19A
0005435797270	2838	15	20A
0005433404699	29319	1	3F
0005433404700	29319	2	4C
0005433404703	29319	3	7C
0005433404701	29319	4	12E
0005433404705	29319	5	12F
0005433404704	29319	6	17F
0005433404702	29319	7	20F
0005434947900	5750	1	1A
0005434947896	5750	2	1B
0005434947894	5750	3	2A
0005434947902	5750	4	2B
0005434947899	5750	5	3A
0005434947898	5750	6	4A
0005434947903	5750	7	3B
0005434947897	5750	8	4B
0005434947895	5750	9	5A
0005434947901	5750	10	6B
0005434947875	16419	1	3A
0005435376318	16419	2	4B
0005433960054	6963	1	1A
0005433960057	6963	2	1C
0005433960032	6963	3	2C
0005433960070	6963	4	2F
0005433960056	6963	5	3A
0005433960068	6963	6	3C
0005433960074	6963	7	3D
0005433960051	6963	8	3F
0005433960065	6963	9	4A
0005433960042	6963	10	4C
0005433960058	6963	11	4E
0005433960079	6963	12	4F
0005433960081	6963	13	5A
0005433960063	6963	14	5F
0005433960071	6963	15	6C
0005433960075	6963	16	6D
0005433960030	6963	17	6F
0005433960036	6963	18	7A
0005433960048	6963	19	7D
0005433960080	6963	20	8A
0005433960077	6963	21	8F
0005433960069	6963	22	9A
0005433960035	6963	23	9C
0005433960059	6963	24	9F
0005433960043	6963	25	10A
0005433960038	6963	26	10D
0005433960060	6963	27	10E
0005433960041	6963	28	11C
0005433960078	6963	29	11E
0005433960064	6963	30	11F
0005433960050	6963	31	12D
0005433960076	6963	32	13A
0005433960040	6963	33	13C
0005433960067	6963	34	13E
0005433960061	6963	35	13F
0005433960037	6963	36	14A
0005433960055	6963	37	14C
0005433960073	6963	38	14F
0005433960062	6963	39	15C
0005433960047	6963	40	15E
0005433960033	6963	41	15F
0005433960031	6963	42	16A
0005433960072	6963	43	16E
0005433960029	6963	44	17D
0005433960045	6963	45	17E
0005433960053	6963	46	17F
0005433960066	6963	47	18C
0005433960046	6963	48	18E
0005433960039	6963	49	19A
0005433960044	6963	50	20A
0005433960034	6963	51	20C
0005433960028	6963	52	20D
0005433960049	6963	53	20E
0005433960052	6963	54	20F
0005435082669	26076	1	1B
0005435082663	26076	2	2B
0005435082662	26076	3	2A
0005435082668	26076	4	4A
0005435082667	26076	5	4B
0005435082666	26076	6	5A
0005435082664	26076	7	6A
0005435082665	26076	8	6B
0005434244560	4956	1	1D
0005434244547	4956	2	3A
0005434244562	4956	3	5A
0005432166854	4956	4	7F
0005434244558	4956	5	7D
0005434244572	4956	6	8B
0005434244556	4956	7	9C
0005434244548	4956	8	10D
0005434244549	4956	9	11C
0005434244552	4956	10	13C
0005434244561	4956	11	13E
0005434244569	4956	12	14A
0005434244559	4956	13	14E
0005434244568	4956	14	15E
0005434244545	4956	15	16C
0005432166855	4956	16	16E
0005434244551	4956	17	17B
0005434244550	4956	18	18D
0005434244553	4956	19	18F
0005432166853	4956	20	19D
0005434244555	4956	21	20A
0005434244570	4956	22	21F
0005434244571	4956	23	22F
0005434244565	4956	24	23A
0005434244554	4956	25	23F
0005434244546	4956	26	24A
0005434244544	4956	27	24C
0005434244566	4956	28	25B
0005434244563	4956	29	26C
0005434244564	4956	30	28E
0005434244557	4956	31	30C
0005434244567	4956	32	31F
0005433784423	4957	1	1A
0005433613678	4957	2	1C
0005433784436	4957	3	1F
0005433613681	4957	4	1D
0005433613612	4957	5	2C
0005432104871	4957	6	2A
0005432104903	4957	7	2F
0005433613657	4957	8	2D
0005432667423	4957	9	3A
0005433613637	4957	10	3C
0005433784427	4957	11	3D
0005433613672	4957	12	4A
0005432104889	4957	13	3F
0005432104879	4957	14	4C
0005433613643	4957	15	4F
0005433613614	4957	16	4D
0005432104865	4957	17	5A
0005433784408	4957	18	5D
0005432104880	4957	19	5C
0005433784420	4957	20	6A
0005432667424	4957	21	5F
0005433613676	4957	22	6D
0005433613669	4957	23	6C
0005433784435	4957	24	6F
0005433613618	4957	25	7A
0005433613673	4957	26	7C
0005432104867	4957	27	7D
0005432667425	4957	28	8A
0005432665245	4957	29	7F
0005433613624	4957	30	8B
0005433613634	4957	31	8D
0005433784415	4957	32	8C
0005433784402	4957	33	8E
0005433784438	4957	34	8F
0005433784426	4957	35	9B
0005433784418	4957	36	9A
0005432104892	4957	37	9C
0005432104875	4957	38	9D
0005433613659	4957	39	9F
0005433613646	4957	40	9E
0005433613623	4957	41	10A
0005433613619	4957	42	10B
0005433784413	4957	43	10D
0005432104868	4957	44	10C
0005433613654	4957	45	10E
0005432104862	4957	46	10F
0005433784405	4957	47	11B
0005433784417	4957	48	11A
0005432104895	4957	49	11C
0005433613650	4957	50	11D
0005432104887	4957	51	11F
0005433613629	4957	52	11E
0005433613655	4957	53	12A
0005432104902	4957	54	12B
0005432104869	4957	55	12D
0005433613625	4957	56	12C
0005433613636	4957	57	12E
0005433613644	4957	58	12F
0005432104888	4957	59	13B
0005433613671	4957	60	13A
0005432104878	4957	61	13C
0005433613667	4957	62	13D
0005433613641	4957	63	13F
0005433613638	4957	64	13E
0005432104893	4957	65	14A
0005432104859	4957	66	14B
0005433784434	4957	67	14D
0005433613668	4957	68	14C
0005433784430	4957	69	14E
0005433613651	4957	70	14F
0005433784437	4957	71	15B
0005433613653	4957	72	15A
0005433613630	4957	73	15C
0005432104874	4957	74	15D
0005433613686	4957	75	15E
0005432104897	4957	76	16A
0005432104860	4957	77	15F
0005432104873	4957	78	16C
0005432104901	4957	79	16B
0005432104900	4957	80	16D
0005433613661	4957	81	16E
0005432104870	4957	82	16F
0005433613685	4957	83	17A
0005432104899	4957	84	17C
0005432104876	4957	85	17B
0005433784414	4957	86	17E
0005432104891	4957	87	17D
0005433613658	4957	88	17F
0005433784428	4957	89	18A
0005433613670	4957	90	18C
0005432104881	4957	91	18B
0005432104884	4957	92	18D
0005432104883	4957	93	18E
0005433613613	4957	94	19B
0005433784421	4957	95	18F
0005433784429	4957	96	19C
0005433613662	4957	97	19D
0005433613679	4957	98	19E
0005433784412	4957	99	20B
0005433613665	4957	100	20A
0005433784431	4957	101	20C
0005433613682	4957	102	20E
0005433613621	4957	103	20D
0005433613640	4957	104	21A
0005433784404	4957	105	20F
0005433613617	4957	106	21B
0005432104877	4957	107	21D
0005433613616	4957	108	21C
0005432104894	4957	109	21E
0005432104885	4957	110	22A
0005433613684	4957	111	21F
0005433613660	4957	112	22B
0005433613622	4957	113	22C
0005432104872	4957	114	22E
0005433613649	4957	115	22D
0005433784424	4957	116	22F
0005433784411	4957	117	23B
0005432104866	4957	118	23A
0005433613663	4957	119	23C
0005433613666	4957	120	23D
0005433613615	4957	121	23E
0005432665244	4957	122	24A
0005432104906	4957	123	23F
0005433613628	4957	124	24B
0005432104904	4957	125	24D
0005432104863	4957	126	24C
0005432666358	4957	127	24E
0005432104898	4957	128	24F
0005433784416	4957	129	25A
0005433784410	4957	130	25C
0005433613664	4957	131	25B
0005433613674	4957	132	25D
0005433784419	4957	133	25F
0005433613648	4957	134	25E
0005433613611	4957	135	26A
0005433613642	4957	136	26B
0005433784406	4957	137	26D
0005433784401	4957	138	26C
0005433613680	4957	139	26F
0005433613631	4957	140	26E
0005433613635	4957	141	27B
0005433613620	4957	142	27A
0005433784407	4957	143	27C
0005432104890	4957	144	27D
0005433784422	4957	145	27E
0005433613633	4957	146	28A
0005433613683	4957	147	27F
0005433784439	4957	148	28B
0005432104905	4957	149	28C
0005433613675	4957	150	28E
0005433784432	4957	151	28D
0005433784425	4957	152	29A
0005433613626	4957	153	28F
0005432104861	4957	154	29B
0005433613645	4957	155	29C
0005433613647	4957	156	29D
0005433613656	4957	157	29E
0005433784403	4957	158	29F
0005433613627	4957	159	30B
0005433784433	4957	160	30A
0005433613652	4957	161	30C
0005433613677	4957	162	30E
0005433613632	4957	163	30D
0005432104882	4957	164	30F
0005432104896	4957	165	31B
0005432145082	4957	166	31A
0005433613639	4957	167	31D
0005433784409	4957	168	31C
0005432104886	4957	169	31E
0005432104864	4957	170	31F
0005434229036	4959	1	1A
0005434149564	4959	2	1D
0005434264761	4959	3	3A
0005434229042	4959	4	2F
0005434173461	4959	5	3C
0005434229056	4959	6	4F
0005434264776	4959	7	5C
0005434264771	4959	8	5D
0005434229037	4959	9	6A
0005434264759	4959	10	6C
0005434173464	4959	11	7A
0005434264777	4959	12	6F
0005434264764	4959	13	7F
0005434264757	4959	14	8B
0005434229050	4959	15	8D
0005434173460	4959	16	9B
0005434264773	4959	17	9D
0005434149565	4959	18	11A
0005434264769	4959	19	11C
0005434264765	4959	20	12B
0005434264780	4959	21	12D
0005434264768	4959	22	13A
0005434264763	4959	23	12F
0005434264762	4959	24	13F
0005434229038	4959	25	14D
0005434264756	4959	26	15B
0005434229044	4959	27	15E
0005434229052	4959	28	16C
0005434229035	4959	29	16D
0005434173462	4959	30	16F
0005434229058	4959	31	17C
0005434229041	4959	32	17E
0005434149562	4959	33	18B
0005434264766	4959	34	18D
0005434229045	4959	35	18C
0005434229049	4959	36	19E
0005434264779	4959	37	19C
0005434149559	4959	38	20A
0005434264760	4959	39	20D
0005434229047	4959	40	20F
0005434173463	4959	41	21E
0005434149557	4959	42	22B
0005434229053	4959	43	22C
0005434229057	4959	44	22E
0005434264770	4959	45	22F
0005434229039	4959	46	23C
0005434149560	4959	47	23D
0005434264755	4959	48	23F
0005434229054	4959	49	23E
0005434229055	4959	50	24F
0005434229043	4959	51	25C
0005434149561	4959	52	25B
0005434264775	4959	53	25E
0005434264772	4959	54	25F
0005434229048	4959	55	26B
0005434149567	4959	56	26D
0005434264774	4959	57	27D
0005434229040	4959	58	28A
0005434229051	4959	59	28F
0005434264778	4959	60	29A
0005434149563	4959	61	29D
0005434264758	4959	62	30A
0005434264767	4959	63	30B
0005434149558	4959	64	30D
0005434229046	4959	65	30C
0005434149566	4959	66	30F
0005434264754	4959	67	31F
0005435269652	8542	1	7A
0005434244457	8542	2	7D
0005435269648	8542	3	13F
0005434244460	8542	4	15C
0005435269651	8542	5	16A
0005434244458	8542	6	17B
0005435269650	8542	7	18F
0005435269649	8542	8	21B
0005434244461	8542	9	28A
0005433784296	8542	10	28F
0005433815316	8540	1	1A
0005433688781	8540	2	2A
0005433534468	8540	3	2C
0005433689883	8540	4	2F
0005432034560	8540	5	3A
0005432034545	8540	6	3D
0005432034553	8540	7	4C
0005432047496	8540	8	4F
0005435006691	8540	9	4D
0005435006692	8540	10	6D
0005433815317	8540	11	7C
0005432034535	8540	12	7D
0005432034546	8540	13	8C
0005435006683	8540	14	8B
0005435006695	8540	15	8D
0005432034543	8540	16	9B
0005432335863	8540	17	9A
0005432034555	8540	18	9D
0005432335862	8540	19	10B
0005435006676	8540	20	10E
0005432034556	8540	21	10F
0005432034541	8540	22	11B
0005435006673	8540	23	11F
0005432034539	8540	24	12B
0005432034552	8540	25	12C
0005435006697	8540	26	12E
0005432034536	8540	27	12F
0005435006688	8540	28	13B
0005432034558	8540	29	13C
0005432034550	8540	30	13E
0005434264681	8540	31	13F
0005432034544	8540	32	14F
0005432335861	8540	33	15A
0005433815315	8540	34	15C
0005432034542	8540	35	15D
0005434311188	8540	36	15F
0005435006694	8540	37	16A
0005435006687	8540	38	16B
0005432034538	8540	39	16C
0005435006675	8540	40	16E
0005432335868	8540	41	17B
0005435006686	8540	42	17A
0005435006684	8540	43	17C
0005433688780	8540	44	17F
0005432335865	8540	45	18B
0005432034562	8540	46	18D
0005432034537	8540	47	18E
0005432034549	8540	48	19B
0005432034559	8540	49	19E
0005432335866	8540	50	21D
0005435006678	8540	51	21E
0005435006696	8540	52	22B
0005432034534	8540	53	22D
0005435006681	8540	54	23A
0005432047495	8540	55	23D
0005433534467	8540	56	23C
0005435006685	8540	57	23E
0005432034551	8540	58	24F
0005432034540	8540	59	25A
0005435006689	8540	60	25B
0005435006677	8540	61	25D
0005435006679	8540	62	25C
0005433815319	8540	63	25E
0005433815318	8540	64	26A
0005432047497	8540	65	25F
0005435006690	8540	66	26B
0005432034557	8540	67	26E
0005435006682	8540	68	26D
0005433690897	8540	69	26F
0005432335864	8540	70	27B
0005433689882	8540	71	27A
0005432034547	8540	72	27E
0005432034554	8540	73	28A
0005433688779	8540	74	27F
0005432335858	8540	75	28B
0005435006693	8540	76	28C
0005432335867	8540	77	28E
0005435006672	8540	78	29A
0005435006680	8540	79	29C
0005432034561	8540	80	29D
0005435286554	8540	81	29E
0005433690898	8540	82	30A
0005434264680	8540	83	29F
0005435006674	8540	84	30D
0005435286555	8540	85	30E
0005432034548	8540	86	30F
0005432335860	8540	87	31B
0005432335859	8540	88	31E
0005433202153	12640	1	2B
0005433202158	12640	2	4B
0005433202162	12640	3	6B
0005433202155	12640	4	7A
0005433202151	12640	5	7D
0005433202157	12640	6	18A
0005433202150	12640	7	19B
0005433202147	12640	8	19D
0005433202149	12640	9	20D
0005433202160	12640	10	21A
0005433202154	12640	11	21B
0005433202148	12640	12	21C
0005433202159	12640	13	21D
0005433202152	12640	14	22C
0005433202161	12640	15	22D
0005433202156	12640	16	23B
0005434638917	23348	1	2A
0005434638919	23348	2	2C
0005434638914	23348	3	2D
0005434638924	23348	4	3A
0005434638915	23348	5	3B
0005434638908	23348	6	3C
0005434638916	23348	7	3D
0005434638913	23348	8	4B
0005432290585	23348	9	4D
0005434638911	23348	10	5A
0005434638920	23348	11	5B
0005434638918	23348	12	5C
0005434638926	23348	13	5D
0005434638923	23348	14	6C
0005434638912	23348	15	7A
0005434638909	23348	16	7B
0005434638906	23348	17	7D
0005434638921	23348	18	18B
0005434638910	23348	19	19B
0005434638907	23348	20	19C
0005432290587	23348	21	19D
0005432290586	23348	22	20A
0005434638927	23348	23	20B
0005434638925	23348	24	20D
0005434638905	23348	25	21B
0005434638903	23348	26	21D
0005434638922	23348	27	22D
0005434638904	23348	28	23B
0005432054262	21073	1	7E
0005432327965	21073	2	13F
0005432054263	21073	3	20C
0005432382569	31254	1	1A
0005432328027	31254	2	1C
0005432382570	31254	3	1D
0005432328011	31254	4	1F
0005432328020	31254	5	2A
0005432382592	31254	6	2C
0005432382566	31254	7	2D
0005432382568	31254	8	2F
0005432327999	31254	9	3A
0005432328013	31254	10	3C
0005432328030	31254	11	3D
0005432382575	31254	12	3F
0005432382588	31254	13	4A
0005432328023	31254	14	4C
0005432328004	31254	15	4D
0005432328002	31254	16	4E
0005432382584	31254	17	4F
0005432382565	31254	18	5A
0005432382594	31254	19	5C
0005432382571	31254	20	5D
0005432382599	31254	21	5E
0005432327996	31254	22	5F
0005432328007	31254	23	6A
0005432382598	31254	24	6C
0005432382572	31254	25	6D
0005432328019	31254	26	6E
0005432382595	31254	27	6F
0005432382579	31254	28	7A
0005432328016	31254	29	7C
0005432382573	31254	30	7D
0005432382603	31254	31	7E
0005432328008	31254	32	7F
0005432287114	31254	33	8A
0005432328001	31254	34	8C
0005432327995	31254	35	8D
0005432328000	31254	36	8E
0005432328003	31254	37	8F
0005432327986	31254	38	9C
0005432327994	31254	39	9D
0005432328021	31254	40	9E
0005432382574	31254	41	9F
0005432327985	31254	42	10A
0005432287112	31254	43	10C
0005432382583	31254	44	10D
0005432382601	31254	45	10E
0005432327998	31254	46	10F
0005432327993	31254	47	11A
0005432328005	31254	48	11C
0005432327988	31254	49	11D
0005432382597	31254	50	11E
0005432382589	31254	51	11F
0005432328014	31254	52	12A
0005432382580	31254	53	12C
0005432287113	31254	54	12D
0005432328006	31254	55	12E
0005432382587	31254	56	12F
0005432382600	31254	57	13A
0005432382585	31254	58	13C
0005432327991	31254	59	13D
0005432287110	31254	60	13E
0005432328025	31254	61	13F
0005432328026	31254	62	14A
0005432382564	31254	63	14C
0005432328012	31254	64	14D
0005432382602	31254	65	14E
0005432327987	31254	66	14F
0005432328015	31254	67	15A
0005432328024	31254	68	15C
0005432327990	31254	69	15D
0005432382586	31254	70	15E
0005432382605	31254	71	15F
0005432382590	31254	72	16A
0005432327989	31254	73	16C
0005432287111	31254	74	16D
0005432328009	31254	75	16E
0005432382591	31254	76	16F
0005432287115	31254	77	17A
0005432328010	31254	78	17C
0005432328018	31254	79	17D
0005432382582	31254	80	17E
0005432382578	31254	81	17F
0005432382577	31254	82	18A
0005432382593	31254	83	18C
0005432328022	31254	84	18D
0005432328017	31254	85	18E
0005432382581	31254	86	18F
0005432327992	31254	87	19A
0005432382576	31254	88	19C
0005432382567	31254	89	19D
0005432328031	31254	90	19F
0005432328029	31254	91	20A
0005432327997	31254	92	20C
0005432328028	31254	93	20D
0005432382604	31254	94	20E
0005432382596	31254	95	20F
0005432423698	13273	1	1A
0005432423718	13273	2	1C
0005432423712	13273	3	1D
0005432423734	13273	4	1F
0005432423758	13273	5	2C
0005432423725	13273	6	2D
0005432423701	13273	7	2F
0005432423759	13273	8	3A
0005432423754	13273	9	3C
0005432423751	13273	10	3F
0005432423735	13273	11	4A
0005432423731	13273	12	4C
0005432423748	13273	13	4D
0005432423723	13273	14	4F
0005432423696	13273	15	5A
0005432423757	13273	16	5C
0005432423707	13273	17	5D
0005432423704	13273	18	5F
0005432423747	13273	19	6C
0005432423741	13273	20	6D
0005432423742	13273	21	6E
0005432423755	13273	22	6F
0005432423730	13273	23	7A
0005432423753	13273	24	7D
0005432423716	13273	25	7F
0005432423697	13273	26	7E
0005432423738	13273	27	8A
0005432423729	13273	28	8D
0005432423695	13273	29	8F
0005432423745	13273	30	9A
0005432423709	13273	31	9D
0005432423714	13273	32	10A
0005432423708	13273	33	10C
0005432423703	13273	34	10D
0005432423719	13273	35	10E
0005432423740	13273	36	10F
0005432423721	13273	37	11A
0005432423733	13273	38	11C
0005432423727	13273	39	11E
0005432423699	13273	40	11F
0005432423710	13273	41	12E
0005432423711	13273	42	12F
0005432423715	13273	43	13E
0005432423717	13273	44	14A
0005432423694	13273	45	14C
0005432423750	13273	46	14D
0005432423706	13273	47	14E
0005432423739	13273	48	14F
0005432423744	13273	49	15A
0005432423726	13273	50	15C
0005432423762	13273	51	15E
0005432423746	13273	52	15F
0005432423749	13273	53	16A
0005432423736	13273	54	16C
0005432423720	13273	55	16D
0005432423760	13273	56	17A
0005432423700	13273	57	17C
0005432423732	13273	58	17D
0005432423743	13273	59	18A
0005432423722	13273	60	18D
0005432423761	13273	61	18C
0005432423713	13273	62	18E
0005432423724	13273	63	18F
0005432423728	13273	64	19A
0005432423752	13273	65	19C
0005432423705	13273	66	19D
0005432423756	13273	67	20D
0005432423737	13273	68	20E
0005432423702	13273	69	20F
0005432822096	9587	1	1A
0005434448267	9587	2	2A
0005432822092	9587	3	2C
0005432817057	9587	4	2D
0005432822095	9587	5	2F
0005432817039	9587	6	3D
0005432817040	9587	7	4A
0005432817042	9587	8	4C
0005432817041	9587	9	4D
0005432817037	9587	10	4E
0005432817032	9587	11	5A
0005432817044	9587	12	5C
0005432817038	9587	13	6D
0005432817055	9587	14	8D
0005432817029	9587	15	8F
0005432817045	9587	16	9A
0005432822091	9587	17	9C
0005432822090	9587	18	9E
0005432817035	9587	19	9F
0005432817036	9587	20	10D
0005432817046	9587	21	10F
0005432817028	9587	22	11D
0005432288937	9587	23	12C
0005432817049	9587	24	13A
0005434448265	9587	25	13C
0005432817048	9587	26	13E
0005432817034	9587	27	14C
0005432822089	9587	28	14D
0005432817058	9587	29	14F
0005432817050	9587	30	15D
0005432817043	9587	31	15E
0005432822093	9587	32	15F
0005432817033	9587	33	16A
0005432817056	9587	34	16D
0005432817051	9587	35	16E
0005432817031	9587	36	17C
0005432822094	9587	37	17E
0005432817054	9587	38	17F
0005432288938	9587	39	18A
0005432822088	9587	40	18C
0005432822097	9587	41	18D
0005432817047	9587	42	18E
0005432288939	9587	43	19D
0005432817053	9587	44	19E
0005432817052	9587	45	19F
0005432817030	9587	46	20C
0005434448266	9587	47	20D
0005432901363	28995	1	2C
0005434186156	28995	2	3D
0005432901354	28995	3	5D
0005434157364	28995	4	5F
0005432901356	28995	5	6D
0005434157369	28995	6	8A
0005432901359	28995	7	8C
0005432901357	28995	8	9A
0005432901364	28995	9	9D
0005434157367	28995	10	9E
0005434157366	28995	11	10A
0005432002047	28995	12	10D
0005432901360	28995	13	10E
0005432002046	28995	14	11A
0005434157363	28995	15	11C
0005432901351	28995	16	11E
0005434186155	28995	17	11F
0005432901352	28995	18	12C
0005432901348	28995	19	12D
0005434157365	28995	20	13D
0005432901355	28995	21	13E
0005432901349	28995	22	13F
0005434157368	28995	23	14A
0005432901353	28995	24	14F
0005432901350	28995	25	15E
0005432901358	28995	26	16E
0005432901347	28995	27	17A
0005432901361	28995	28	17D
0005434157370	28995	29	18A
0005434186154	28995	30	18E
0005434186153	28995	31	18F
0005432901362	28995	32	20E
0005432613804	15115	1	1A
0005432613803	15115	2	1B
0005432611654	15115	3	2A
0005432611652	15115	4	3A
0005432613801	15115	5	3B
0005432613805	15115	6	4B
0005432611653	15115	7	5A
0005432613802	15115	8	6A
0005432611651	15115	9	6B
0005435842316	31551	1	3A
0005435842315	31551	2	2B
0005435841811	31551	3	6B
0005433568148	11846	1	1C
0005433568189	11846	2	1A
0005433568150	11846	3	1F
0005433568160	11846	4	1D
0005433568124	11846	5	2D
0005433568136	11846	6	3A
0005433568183	11846	7	2F
0005433568157	11846	8	3C
0005433568159	11846	9	4A
0005433568169	11846	10	4F
0005433568141	11846	11	5A
0005433568142	11846	12	5F
0005433568125	11846	13	5D
0005433568163	11846	14	6A
0005433568127	11846	15	7A
0005433568151	11846	16	6F
0005433568152	11846	17	7B
0005433568134	11846	18	7E
0005433568177	11846	19	8A
0005433568188	11846	20	7F
0005433568133	11846	21	8B
0005433568184	11846	22	8C
0005433568191	11846	23	8E
0005433568174	11846	24	9B
0005433568153	11846	25	9A
0005433568145	11846	26	9C
0005433568126	11846	27	9E
0005433568171	11846	28	10B
0005433568166	11846	29	10E
0005433568128	11846	30	10D
0005433568144	11846	31	11A
0005433568149	11846	32	11C
0005433568138	11846	33	11B
0005433568179	11846	34	11D
0005433568175	11846	35	12B
0005433568158	11846	36	12A
0005433568180	11846	37	12C
0005433568187	11846	38	13A
0005433568176	11846	39	12F
0005433568155	11846	40	13C
0005433568181	11846	41	13E
0005433568182	11846	42	13F
0005433568154	11846	43	14C
0005433568190	11846	44	14E
0005433568168	11846	45	14D
0005433568130	11846	46	15A
0005433568156	11846	47	15D
0005433568161	11846	48	16D
0005433568170	11846	49	16C
0005433568164	11846	50	16F
0005433568172	11846	51	16E
0005433568129	11846	52	17B
0005433568185	11846	53	17D
0005433568146	11846	54	17C
0005433568132	11846	55	17F
0005433568186	11846	56	18E
0005433568137	11846	57	18D
0005433568140	11846	58	19B
0005433568143	11846	59	19F
0005433568165	11846	60	19E
0005433568131	11846	61	20A
0005433568178	11846	62	20D
0005433568135	11846	63	20C
0005433568162	11846	64	20F
0005433568167	11846	65	21B
0005433568147	11846	66	21A
0005433568173	11846	67	21D
0005433568139	11846	68	21C
0005432947920	25281	1	1C
0005432947897	25281	2	2A
0005432947926	25281	3	1F
0005432947889	25281	4	2D
0005432947929	25281	5	2C
0005432947922	25281	6	2F
0005432947916	25281	7	3F
0005432947894	25281	8	4C
0005432947919	25281	9	5C
0005432947903	25281	10	5D
0005432947891	25281	11	6B
0005432947912	25281	12	6D
0005432947904	25281	13	6E
0005432947917	25281	14	7B
0005432947921	25281	15	6F
0005432947896	25281	16	7C
0005432947901	25281	17	7E
0005432947899	25281	18	8A
0005432947905	25281	19	7F
0005432947893	25281	20	9B
0005432947927	25281	21	9E
0005432947911	25281	22	9F
0005432947918	25281	23	10F
0005432947924	25281	24	11C
0005432947925	25281	25	12B
0005432947902	25281	26	13D
0005432947907	25281	27	14B
0005432947909	25281	28	14C
0005432947898	25281	29	15B
0005432947892	25281	30	16A
0005432947906	25281	31	16F
0005432947908	25281	32	17B
0005432947914	25281	33	18D
0005432947915	25281	34	20B
0005432947913	25281	35	20D
0005432947890	25281	36	20C
0005432947895	25281	37	20F
0005432947923	25281	38	20E
0005432947900	25281	39	21A
0005432947928	25281	40	21D
0005432947910	25281	41	21F
0005433808317	30824	1	1D
0005433808313	30824	2	3F
0005433808310	30824	3	5F
0005433812862	30824	4	7B
0005433812860	30824	5	9A
0005433808314	30824	6	11E
0005433812857	30824	7	12B
0005433808316	30824	8	12D
0005433812858	30824	9	13A
0005433808311	30824	10	13C
0005433812859	30824	11	15C
0005433808312	30824	12	15D
0005433808318	30824	13	16E
0005433808319	30824	14	17E
0005433812861	30824	15	18A
0005433808315	30824	16	18E
0005433812863	30824	17	19F
0005434654270	5384	1	1A
0005432114157	5384	2	1C
0005434654253	5384	3	1D
0005434654272	5384	4	3A
0005434654268	5384	5	4A
0005434654266	5384	6	4F
0005434654251	5384	7	5D
0005434654267	5384	8	5E
0005434654264	5384	9	5F
0005434654250	5384	10	6D
0005434654260	5384	11	6F
0005434654255	5384	12	7A
0005434654276	5384	13	7C
0005434654262	5384	14	8C
0005434656526	5384	15	8D
0005434654271	5384	16	8F
0005434654278	5384	17	9A
0005434654252	5384	18	9E
0005434654280	5384	19	11D
0005434654277	5384	20	11F
0005434654257	5384	21	12C
0005434654279	5384	22	13F
0005434654274	5384	23	14A
0005432114156	5384	24	15C
0005434654254	5384	25	15D
0005434656527	5384	26	15E
0005434654269	5384	27	16A
0005434654259	5384	28	16D
0005434654249	5384	29	16E
0005434654258	5384	30	17A
0005434654275	5384	31	17F
0005434654263	5384	32	18D
0005434654256	5384	33	18F
0005432114155	5384	34	19E
0005434654265	5384	35	20A
0005434654261	5384	36	20C
0005434654273	5384	37	20E
0005435340045	12510	1	1F
0005435555341	12510	2	2F
0005435340044	12510	3	3F
0005435340047	12510	4	5A
0005435340038	12510	5	7D
0005435340041	12510	6	10C
0005435340049	12510	7	10D
0005435340039	12510	8	11D
0005435340043	12510	9	14F
0005435340037	12510	10	15C
0005435340046	12510	11	15D
0005435340050	12510	12	15E
0005435340035	12510	13	17A
0005435340048	12510	14	18A
0005435340036	12510	15	19A
0005435340042	12510	16	19E
0005435340040	12510	17	19F
0005433715221	7465	1	2A
0005433715267	7465	2	2C
0005433722120	7465	3	3A
0005433715243	7465	4	3F
0005433715254	7465	5	4A
0005433690895	7465	6	4B
0005433656619	7465	7	4D
0005433715235	7465	8	4E
0005433715223	7465	9	5B
0005432078031	7465	10	5D
0005433715256	7465	11	5C
0005433715236	7465	12	5F
0005433715251	7465	13	6B
0005433715268	7465	14	6F
0005433715237	7465	15	7A
0005433715242	7465	16	7E
0005433688778	7465	17	7D
0005433722118	7465	18	7F
0005433689881	7465	19	8A
0005433715247	7465	20	8B
0005433689878	7465	21	8D
0005432078028	7465	22	8F
0005433715241	7465	23	9D
0005433715264	7465	24	9F
0005433715230	7465	25	10C
0005433715261	7465	26	10B
0005433715238	7465	27	10E
0005433715233	7465	28	11A
0005433715226	7465	29	11C
0005433715270	7465	30	11E
0005432078029	7465	31	11D
0005433715240	7465	32	11F
0005433715269	7465	33	12C
0005433715266	7465	34	12F
0005433690896	7465	35	13A
0005433715259	7465	36	13C
0005433689879	7465	37	13E
0005432078025	7465	38	14A
0005433715265	7465	39	13F
0005433715262	7465	40	14D
0005433715228	7465	41	14E
0005432078027	7465	42	14F
0005432078026	7465	43	15A
0005433690894	7465	44	15B
0005432078030	7465	45	15E
0005433688777	7465	46	15D
0005433715244	7465	47	15F
0005433689880	7465	48	16D
0005433715232	7465	49	16B
0005433719089	7465	50	16E
0005433715253	7465	51	17A
0005433715245	7465	52	17B
0005433715220	7465	53	17C
0005433715249	7465	54	17D
0005433715263	7465	55	17F
0005433719090	7465	56	17E
0005433719088	7465	57	18C
0005433715227	7465	58	18B
0005433715252	7465	59	18F
0005433715222	7465	60	18E
0005433715255	7465	61	19A
0005433715257	7465	62	19B
0005433715234	7465	63	19C
0005433656618	7465	64	20B
0005433722119	7465	65	20D
0005433715248	7465	66	20C
0005433715239	7465	67	20F
0005433715224	7465	68	21B
0005433715260	7465	69	21A
0005433715231	7465	70	21D
0005433715246	7465	71	22B
0005433719091	7465	72	22C
0005433656620	7465	73	23A
0005433715258	7465	74	23B
0005433715225	7465	75	23C
0005433715250	7465	76	23D
0005433715229	7465	77	23F
0005432428879	29250	1	1F
0005435266078	29250	2	4E
0005435266075	29250	3	5E
0005435266076	29250	4	6B
0005435266079	29250	5	9A
0005432428880	29250	6	13E
0005432006719	29250	7	14C
0005435266077	29250	8	20D
0005434095069	8677	1	3C
0005434095071	8677	2	4A
0005434095062	8677	3	7C
0005434095065	8677	4	7F
0005434095066	8677	5	8C
0005434095060	8677	6	9A
0005434095063	8677	7	9C
0005434095072	8677	8	9F
0005434095067	8677	9	10D
0005434095070	8677	10	10E
0005434095064	8677	11	12C
0005434095061	8677	12	15A
0005434095068	8677	13	16D
0005434095059	8677	14	17C
0005434095073	8677	15	20A
0005434181997	11642	1	3C
0005434182001	11642	2	3D
0005434182003	11642	3	5C
0005434182005	11642	4	5E
0005434182007	11642	5	6A
0005434184633	11642	6	6D
0005434183548	11642	7	7E
0005434181998	11642	8	9A
0005434183549	11642	9	10A
0005434181999	11642	10	10C
0005434181995	11642	11	11C
0005434182002	11642	12	12E
0005434184634	11642	13	13A
0005434182004	11642	14	13F
0005434181996	11642	15	16A
0005434184635	11642	16	16C
0005434182000	11642	17	18A
0005434182006	11642	18	18E
0005435732154	1443	1	1A
0005432297239	1443	2	1C
0005433456909	1443	3	1D
0005432297240	1443	4	2A
0005433456911	1443	5	4E
0005432297238	1443	6	4F
0005435732156	1443	7	5D
0005435732157	1443	8	6C
0005435732152	1443	9	11A
0005433456910	1443	10	11D
0005435732153	1443	11	14A
0005435732155	1443	12	14E
0005435732160	1443	13	15E
0005435732161	1443	14	16C
0005435732158	1443	15	17E
0005435732159	1443	16	19A
0005432906500	19230	1	1A
0005433397376	19230	2	1C
0005433397352	19230	3	1F
0005433397368	19230	4	2C
0005433397332	19230	5	2D
0005432906498	19230	6	2F
0005433397344	19230	7	3A
0005433397328	19230	8	3C
0005433397360	19230	9	3F
0005433397341	19230	10	4A
0005433397346	19230	11	4F
0005433397342	19230	12	5C
0005433397338	19230	13	5D
0005433397358	19230	14	5F
0005432906499	19230	15	6A
0005433397337	19230	16	6C
0005433397365	19230	17	6D
0005433397356	19230	18	7A
0005433397340	19230	19	7D
0005433397335	19230	20	7F
0005433397362	19230	21	8C
0005433397347	19230	22	8D
0005433397349	19230	23	8E
0005433397377	19230	24	9C
0005433397345	19230	25	10A
0005433397353	19230	26	10C
0005433397339	19230	27	10D
0005433397367	19230	28	10E
0005433397370	19230	29	10F
0005433397348	19230	30	11D
0005433397354	19230	31	11F
0005433397361	19230	32	12A
0005433397333	19230	33	12C
0005433397366	19230	34	12F
0005433397363	19230	35	13A
0005433397355	19230	36	13D
0005433397375	19230	37	13E
0005433397359	19230	38	14A
0005433397351	19230	39	14D
0005433397374	19230	40	14F
0005433397329	19230	41	15C
0005433397378	19230	42	15E
0005433397371	19230	43	16D
0005433397350	19230	44	17C
0005433397336	19230	45	17D
0005433397369	19230	46	17F
0005433397373	19230	47	18C
0005433397357	19230	48	18F
0005433397372	19230	49	18E
0005433397364	19230	50	19A
0005433397330	19230	51	19C
0005433397343	19230	52	19D
0005433397334	19230	53	19E
0005433397331	19230	54	20C
0005434443465	20575	1	1C
0005434443462	20575	2	1D
0005434443471	20575	3	2C
0005434443467	20575	4	3C
0005434443461	20575	5	4B
0005434443460	20575	6	5B
0005434443472	20575	7	5C
0005434443458	20575	8	6D
0005434443456	20575	9	7B
0005434443470	20575	10	18C
0005434443463	20575	11	18D
0005434443468	20575	12	19C
0005434443464	20575	13	20C
0005434443457	20575	14	21A
0005434443459	20575	15	21B
0005434443466	20575	16	23A
0005434443469	20575	17	23B
0005434954553	7232	1	3B
0005434954551	7232	2	4A
0005434954552	7232	3	4B
0005435377545	28344	1	2A
0005435377544	28344	2	5B
0005434351512	4473	1	2B
0005434351504	4473	2	2D
0005434351508	4473	3	3A
0005434351515	4473	4	4B
0005434351514	4473	5	5A
0005434351506	4473	6	5C
0005434351507	4473	7	6D
0005434351510	4473	8	7C
0005434326260	4473	9	18C
0005434351511	4473	10	18D
0005434351503	4473	11	19B
0005434351509	4473	12	20C
0005434351513	4473	13	21A
0005434351505	4473	14	21C
0005434326259	4473	15	22D
0005435893526	29640	1	3B
0005435893531	29640	2	3C
0005435893528	29640	3	5B
0005435893527	29640	4	6C
0005435893532	29640	5	19B
0005435893529	29640	6	19D
0005435893530	29640	7	20A
0005435893525	29640	8	21A
0005435893524	29640	9	22C
0005433463869	1077	1	2B
0005434445214	1077	2	3F
0005435545630	1077	3	3H
0005432293173	1077	4	11A
0005435545633	1077	5	13B
0005435091930	1077	6	13D
0005435545619	1077	7	14A
0005432293172	1077	8	13H
0005435545620	1077	9	14E
0005435091924	1077	10	14D
0005435091929	1077	11	14G
0005435545618	1077	12	14H
0005435545623	1077	13	15E
0005435091927	1077	14	16E
0005435545627	1077	15	21E
0005435545631	1077	16	22H
0005435091926	1077	17	23D
0005435545621	1077	18	23H
0005435545625	1077	19	23G
0005433462716	1077	20	24A
0005435545617	1077	21	25D
0005433462715	1077	22	27E
0005435091931	1077	23	28B
0005435545629	1077	24	28F
0005435545632	1077	25	29E
0005435091928	1077	26	29G
0005435091925	1077	27	30B
0005435545628	1077	28	31A
0005435545635	1077	29	31H
0005435545622	1077	30	32B
0005435545634	1077	31	32A
0005435091932	1077	32	32H
0005435545624	1077	33	36F
0005433463868	1077	34	37F
0005433462714	1077	35	38E
0005432293171	1077	36	38G
0005435545626	1077	37	39E
0005433341614	17040	1	1A
0005433341623	17040	2	1B
0005433341622	17040	3	2B
0005433341588	17040	4	2G
0005433341650	17040	5	3B
0005433341630	17040	6	3F
0005433341592	17040	7	3G
0005433341633	17040	8	3H
0005433341590	17040	9	4B
0005433341615	17040	10	4F
0005433341670	17040	11	5B
0005433341671	17040	12	5C
0005433159279	17040	13	5F
0005433341663	17040	14	5G
0005433341591	17040	15	9A
0005433341583	17040	16	9G
0005433341644	17040	17	9H
0005433341603	17040	18	11D
0005433269639	17040	19	11G
0005433341638	17040	20	11H
0005433341596	17040	21	12B
0005433341674	17040	22	12E
0005433341627	17040	23	12D
0005433341604	17040	24	12G
0005433341647	17040	25	12F
0005435091894	17040	26	12H
0005433341660	17040	27	13H
0005433341665	17040	28	14B
0005433341678	17040	29	14A
0005433341677	17040	30	14D
0005433341675	17040	31	14F
0005433341662	17040	32	14E
0005433341676	17040	33	14G
0005433341680	17040	34	15A
0005433341599	17040	35	15D
0005433341683	17040	36	15H
0005433341639	17040	37	16B
0005433269638	17040	38	16F
0005433341666	17040	39	16H
0005433341617	17040	40	17A
0005433341606	17040	41	17D
0005433341624	17040	42	18B
0005433341612	17040	43	18D
0005433341618	17040	44	19A
0005433269637	17040	45	19E
0005433341625	17040	46	19D
0005433341611	17040	47	19G
0005433341629	17040	48	20A
0005433341651	17040	49	19H
0005433341664	17040	50	20D
0005433341679	17040	51	20F
0005433341602	17040	52	20H
0005433341605	17040	53	21B
0005433341667	17040	54	21G
0005433341657	17040	55	21F
0005433269642	17040	56	21H
0005433341619	17040	57	22D
0005433269636	17040	58	22B
0005433341608	17040	59	22F
0005433341673	17040	60	22E
0005433341672	17040	61	22G
0005433341634	17040	62	23A
0005433341653	17040	63	22H
0005433269641	17040	64	23B
0005433341600	17040	65	23E
0005433341681	17040	66	23F
0005433341682	17040	67	24B
0005433341585	17040	68	24F
0005433341621	17040	69	24H
0005433341594	17040	70	27A
0005433341669	17040	71	25F
0005433341642	17040	72	27B
0005433341643	17040	73	27G
0005433341584	17040	74	28A
0005433341620	17040	75	28D
0005433341589	17040	76	28B
0005433341656	17040	77	28F
0005433341613	17040	78	28H
0005433341646	17040	79	28G
0005433341640	17040	80	29G
0005433341668	17040	81	29F
0005433341607	17040	82	30A
0005433159280	17040	83	30D
0005433341637	17040	84	30G
0005433341641	17040	85	30H
0005433341658	17040	86	31A
0005433341628	17040	87	31G
0005433341635	17040	88	32A
0005433341661	17040	89	32B
0005433341652	17040	90	32D
0005433341595	17040	91	33H
0005433341632	17040	92	34A
0005433341587	17040	93	34B
0005433341597	17040	94	35A
0005433341655	17040	95	35B
0005433341645	17040	96	35D
0005433341586	17040	97	35H
0005433341659	17040	98	36B
0005433341609	17040	99	36D
0005433341636	17040	100	36G
0005433269640	17040	101	37A
0005433341598	17040	102	36H
0005433341631	17040	103	37D
0005433341626	17040	104	37B
0005433341593	17040	105	37F
0005433341601	17040	106	37G
0005433341616	17040	107	38B
0005433341649	17040	108	38E
0005433341654	17040	109	38D
0005433341648	17040	110	39D
0005433341610	17040	111	39F
0005432851832	18274	1	1F
0005432851837	18274	2	3A
0005432851826	18274	3	2F
0005432851839	18274	4	4A
0005432851829	18274	5	6A
0005432851823	18274	6	6F
0005432851825	18274	7	9D
0005432851830	18274	8	10D
0005432851827	18274	9	12A
0005432851824	18274	10	13E
0005432851836	18274	11	14F
0005432851840	18274	12	15B
0005432851828	18274	13	16C
0005432851838	18274	14	17B
0005432851821	18274	15	17A
0005432851833	18274	16	18A
0005432851834	18274	17	18D
0005432851831	18274	18	19F
0005432851822	18274	19	20B
0005432851835	18274	20	20F
0005433812864	12798	1	3F
0005432161117	12798	2	5E
0005433812866	12798	3	6C
0005432161118	12798	4	7F
0005432433604	12798	5	11A
0005432433600	12798	6	12E
0005432159788	12798	7	13E
0005432159792	12798	8	14D
0005432159790	12798	9	14E
0005433812865	12798	10	16D
0005432159789	12798	11	17E
0005432159791	12798	12	18C
0005432433602	12798	13	18B
0005432433598	12798	14	19C
0005432433599	12798	15	21A
0005432433603	12798	16	23E
0005432433601	12798	17	23F
0005434066467	30684	1	1A
0005434081531	30684	2	1D
0005434066447	30684	3	1C
0005434066444	30684	4	1F
0005434066465	30684	5	2A
0005434066480	30684	6	2D
0005434066461	30684	7	2C
0005434066449	30684	8	2F
0005434066495	30684	9	3C
0005434066471	30684	10	3A
0005434066484	30684	11	3D
0005432150075	30684	12	3F
0005434081538	30684	13	4B
0005434081541	30684	14	4A
0005434081533	30684	15	4C
0005434081530	30684	16	4D
0005434066440	30684	17	4E
0005434066493	30684	18	4F
0005432150077	30684	19	5C
0005434066479	30684	20	5B
0005432186811	30684	21	5F
0005434081534	30684	22	6B
0005434066442	30684	23	6A
0005434066457	30684	24	6D
0005434066501	30684	25	6C
0005434066487	30684	26	6F
0005434081543	30684	27	6E
0005434081535	30684	28	7A
0005433989698	30684	29	7B
0005434066474	30684	30	7E
0005434066475	30684	31	7D
0005434066441	30684	32	8B
0005433989699	30684	33	8D
0005434066505	30684	34	8C
0005434066507	30684	35	8F
0005434066443	30684	36	8E
0005434066497	30684	37	9B
0005434081529	30684	38	9A
0005434066469	30684	39	9C
0005434066454	30684	40	9E
0005434066448	30684	41	9F
0005434066482	30684	42	10B
0005434066498	30684	43	10C
0005432150071	30684	44	10E
0005434066470	30684	45	10D
0005434066504	30684	46	11A
0005434066476	30684	47	11C
0005434066462	30684	48	11E
0005434081539	30684	49	11D
0005434081540	30684	50	11F
0005434066453	30684	51	12A
0005434066446	30684	52	12C
0005434066481	30684	53	12B
0005434066491	30684	54	12E
0005434081542	30684	55	12D
0005434066509	30684	56	12F
0005434081545	30684	57	13B
0005434066500	30684	58	13A
0005434066472	30684	59	13D
0005434081537	30684	60	13C
0005434066463	30684	61	13E
0005434066473	30684	62	13F
0005434066477	30684	63	14A
0005434066464	30684	64	14C
0005432150073	30684	65	14B
0005434066489	30684	66	14D
0005434081528	30684	67	14F
0005432150076	30684	68	14E
0005434066456	30684	69	15A
0005434081522	30684	70	15C
0005434066466	30684	71	15B
0005434081549	30684	72	15D
0005434066451	30684	73	15E
0005434066496	30684	74	16A
0005434066508	30684	75	15F
0005434081548	30684	76	16B
0005434066510	30684	77	16C
0005434066503	30684	78	16D
0005432186812	30684	79	16E
0005432150072	30684	80	16F
0005434066502	30684	81	17B
0005434066452	30684	82	17C
0005432186813	30684	83	17D
0005434066499	30684	84	17F
0005434066445	30684	85	17E
0005434066494	30684	86	18A
0005434066483	30684	87	18B
0005434066460	30684	88	18D
0005434081524	30684	89	18C
0005434066478	30684	90	18E
0005434081547	30684	91	19A
0005433989695	30684	92	18F
0005434066511	30684	93	19B
0005433989696	30684	94	19D
0005434066486	30684	95	19C
0005434066488	30684	96	19F
0005434066468	30684	97	20B
0005434081536	30684	98	20D
0005434081525	30684	99	20C
0005434081521	30684	100	20F
0005434081526	30684	101	21A
0005434081544	30684	102	21B
0005434066450	30684	103	21D
0005434066490	30684	104	21C
0005432150074	30684	105	21E
0005434081523	30684	106	21F
0005434066485	30684	107	22B
0005433989697	30684	108	22A
0005434066492	30684	109	22C
0005434081550	30684	110	22E
0005434081527	30684	111	22D
0005434066458	30684	112	22F
0005434066459	30684	113	23B
0005432186814	30684	114	23A
0005434081546	30684	115	23C
0005434066506	30684	116	23E
0005434081532	30684	117	23D
0005434066455	30684	118	23F
0005433685498	9048	1	1A
0005433686609	9048	2	2A
0005433685497	9048	3	2D
0005433685494	9048	4	3A
0005433687679	9048	5	3B
0005433685491	9048	6	3D
0005433686607	9048	7	4A
0005433685492	9048	8	4D
0005433686602	9048	9	5C
0005433687675	9048	10	5D
0005433686603	9048	11	6A
0005433687678	9048	12	6B
0005433686606	9048	13	7D
0005433686605	9048	14	18A
0005433687677	9048	15	18B
0005433687680	9048	16	18C
0005433687681	9048	17	19B
0005433685499	9048	18	19D
0005433687676	9048	19	20A
0005433685493	9048	20	21A
0005433685496	9048	21	21C
0005433686608	9048	22	21D
0005433686604	9048	23	22C
0005433685495	9048	24	22D
0005435765308	5505	1	1A
0005433529222	5505	2	1B
0005435723015	5505	3	1H
0005435765291	5505	4	2F
0005435765344	5505	5	2H
0005435765294	5505	6	3F
0005435765323	5505	7	3H
0005432140331	5505	8	3G
0005435765296	5505	9	4B
0005435765324	5505	10	5A
0005433527213	5505	11	5C
0005433529225	5505	12	5H
0005435765289	5505	13	9B
0005435765334	5505	14	12A
0005435725522	5505	15	12D
0005435765295	5505	16	13A
0005435765339	5505	17	13D
0005435725526	5505	18	13E
0005435765311	5505	19	13F
0005435735067	5505	20	13H
0005432140326	5505	21	13G
0005435735065	5505	22	14E
0005435765331	5505	23	14H
0005435765340	5505	24	15A
0005435765299	5505	25	15B
0005435765301	5505	26	15E
0005435725525	5505	27	15G
0005435765307	5505	28	15F
0005432140328	5505	29	16B
0005435765302	5505	30	16A
0005433529223	5505	31	16D
0005435765293	5505	32	18B
0005435765346	5505	33	18D
0005435765303	5505	34	18E
0005435765305	5505	35	18H
0005435765325	5505	36	19B
0005435765345	5505	37	19E
0005435765300	5505	38	20A
0005435765326	5505	39	19H
0005432140324	5505	40	20B
0005435765314	5505	41	20D
0005435765309	5505	42	20G
0005433527214	5505	43	21D
0005435725521	5505	44	21B
0005435765341	5505	45	21E
0005435765312	5505	46	22A
0005435765338	5505	47	22D
0005435765298	5505	48	23A
0005435723013	5505	49	23B
0005435765304	5505	50	23E
0005435725524	5505	51	23F
0005435765327	5505	52	23H
0005435765320	5505	53	24B
0005435765316	5505	54	24E
0005435765336	5505	55	24F
0005435722020	5505	56	25F
0005435765319	5505	57	25E
0005435722021	5505	58	27B
0005435765306	5505	59	27E
0005432140323	5505	60	27H
0005435765310	5505	61	28A
0005435725523	5505	62	28D
0005435765342	5505	63	29B
0005435765317	5505	64	29A
0005433527212	5505	65	29E
0005435765333	5505	66	29F
0005435723014	5505	67	30F
0005435720807	5505	68	31E
0005433527211	5505	69	31D
0005435765313	5505	70	31F
0005435765322	5505	71	32A
0005435765343	5505	72	32E
0005435765321	5505	73	32D
0005435765337	5505	74	32F
0005432140325	5505	75	33A
0005435765292	5505	76	32H
0005435765335	5505	77	33B
0005435765328	5505	78	33H
0005435735068	5505	79	34D
0005432140330	5505	80	34G
0005435765330	5505	81	35A
0005435765318	5505	82	35E
0005435735069	5505	83	36B
0005432140327	5505	84	36F
0005435765315	5505	85	36H
0005435765290	5505	86	37B
0005435735066	5505	87	37F
0005432140329	5505	88	38A
0005435765297	5505	89	38E
0005435765329	5505	90	38D
0005433529224	5505	91	38G
0005435765332	5505	92	39F
0005435461900	13486	1	2A
0005435461902	13486	2	3A
0005434264773	13486	3	3G
0005434264768	13486	4	4F
0005432194451	13486	5	5B
0005435461880	13486	6	5F
0005434264755	13486	7	9A
0005434264766	13486	8	11B
0005434831082	13486	9	11E
0005434264757	13486	10	11D
0005434264776	13486	11	11F
0005435617167	13486	12	11G
0005434264758	13486	13	12B
0005434264769	13486	14	12D
0005434264765	13486	15	12G
0005435461878	13486	16	13F
0005435461881	13486	17	13E
0005435461882	13486	18	14B
0005435461883	13486	19	14F
0005435461905	13486	20	14E
0005435461886	13486	21	14G
0005434264772	13486	22	15D
0005434264764	13486	23	15G
0005434264780	13486	24	16D
0005435461904	13486	25	16H
0005435461894	13486	26	17D
0005434264767	13486	27	17F
0005432535762	13486	28	17H
0005435461892	13486	29	18D
0005434831084	13486	30	18E
0005434264759	13486	31	18H
0005435461873	13486	32	18G
0005435617168	13486	33	19B
0005434264771	13486	34	19F
0005434264760	13486	35	19E
0005435461909	13486	36	19H
0005432194448	13486	37	19G
0005435461897	13486	38	20A
0005435461907	13486	39	20D
0005434264756	13486	40	20E
0005435461874	13486	41	21F
0005434831085	13486	42	21D
0005434264774	13486	43	21G
0005434264763	13486	44	22D
0005435617166	13486	45	24D
0005434264754	13486	46	24G
0005435461896	13486	47	25F
0005435461889	13486	48	27B
0005432194449	13486	49	27D
0005434831083	13486	50	27F
0005434264777	13486	51	27G
0005435461906	13486	52	28A
0005435461888	13486	53	28B
0005432535763	13486	54	28E
0005435461893	13486	55	28H
0005435461891	13486	56	29G
0005434264778	13486	57	30F
0005435461890	13486	58	30H
0005434264779	13486	59	31E
0005435461901	13486	60	31D
0005432535761	13486	61	31F
0005434264761	13486	62	31G
0005434264775	13486	63	32A
0005434264770	13486	64	31H
0005435461885	13486	65	32E
0005435461875	13486	66	32G
0005435461895	13486	67	33A
0005435461884	13486	68	33G
0005435461876	13486	69	34D
0005435461908	13486	70	34H
0005432535765	13486	71	35E
0005435461903	13486	72	36A
0005434264762	13486	73	36B
0005432194450	13486	74	36D
0005432535764	13486	75	36F
0005435461877	13486	76	37A
0005435461887	13486	77	37G
0005435461899	13486	78	37F
0005432535760	13486	79	38B
0005435461879	13486	80	38G
0005435461910	13486	81	38F
0005435461898	13486	82	38H
0005434513539	18673	1	1A
0005434514927	18673	2	1B
0005434513540	18673	3	2B
0005434513538	18673	4	3B
0005434514928	18673	5	4A
0005434514926	18673	6	4B
0005434602864	19147	1	1A
0005434602858	19147	2	1B
0005434602862	19147	3	2B
0005434602867	19147	4	3A
0005434602865	19147	5	4A
0005434602859	19147	6	4B
0005434602863	19147	7	5A
0005434602860	19147	8	5B
0005434602866	19147	9	6A
0005434602861	19147	10	6B
0005433810498	1800	1	3A
0005433810502	1800	2	3C
0005432295841	1800	3	4D
0005432295843	1800	4	6D
0005433810497	1800	5	8D
0005433810496	1800	6	10A
0005433810500	1800	7	11C
0005433810503	1800	8	11D
0005433810499	1800	9	13A
0005433810501	1800	10	13F
0005433810504	1800	11	14A
0005432295840	1800	12	18D
0005432295842	1800	13	20E
0005433810505	1800	14	20F
0005433284825	22589	1	1A
0005433007919	22589	2	1C
0005433284838	22589	3	1D
0005433007924	22589	4	1F
0005433284842	22589	5	2C
0005433007926	22589	6	2F
0005433284836	22589	7	3A
0005433007953	22589	8	3C
0005433284832	22589	9	3D
0005433007934	22589	10	3F
0005433007932	22589	11	4A
0005433007943	22589	12	4C
0005433007946	22589	13	4D
0005433007937	22589	14	4F
0005433284831	22589	15	5A
0005433007958	22589	16	5C
0005433007948	22589	17	5D
0005433007915	22589	18	5E
0005433007933	22589	19	5F
0005433007931	22589	20	6A
0005433007935	22589	21	6C
0005433007951	22589	22	6D
0005433007921	22589	23	6E
0005433007941	22589	24	6F
0005433284844	22589	25	7C
0005433284822	22589	26	7E
0005433007916	22589	27	7F
0005433284826	22589	28	8A
0005433007956	22589	29	8C
0005433007955	22589	30	8D
0005433007936	22589	31	8E
0005433284827	22589	32	8F
0005433007952	22589	33	9C
0005433007949	22589	34	9D
0005433284841	22589	35	9F
0005433007917	22589	36	10D
0005433284821	22589	37	10E
0005433284829	22589	38	11A
0005433284828	22589	39	11C
0005433007960	22589	40	11E
0005433007938	22589	41	12A
0005433284830	22589	42	12C
0005433007945	22589	43	12D
0005433284839	22589	44	12E
0005433284845	22589	45	12F
0005433007939	22589	46	13C
0005433007950	22589	47	13E
0005433007920	22589	48	14A
0005433007957	22589	49	14C
0005433284823	22589	50	14E
0005433007954	22589	51	14F
0005433007944	22589	52	15A
0005433007959	22589	53	15E
0005433284840	22589	54	15F
0005433284834	22589	55	16A
0005433007947	22589	56	16C
0005433284835	22589	57	16D
0005433007925	22589	58	16F
0005433284824	22589	59	17D
0005433007922	22589	60	17E
0005433007942	22589	61	17F
0005433284833	22589	62	18A
0005433284846	22589	63	18C
0005433284837	22589	64	18D
0005433007929	22589	65	18E
0005433007940	22589	66	18F
0005433007927	22589	67	19C
0005433284843	22589	68	19D
0005433007918	22589	69	19E
0005433007930	22589	70	19F
0005433284847	22589	71	20A
0005433007923	22589	72	20C
0005433007928	22589	73	20D
0005433284848	22589	74	20E
0005432756788	25334	1	3F
0005432756789	25334	2	6D
0005432756790	25334	3	6E
0005432755018	25334	4	9C
0005432756795	25334	5	12C
0005432756792	25334	6	13D
0005432755016	25334	7	15C
0005432755020	25334	8	15D
0005432755025	25334	9	15E
0005432755023	25334	10	16C
0005432755017	25334	11	16E
0005432755021	25334	12	16F
0005432755024	25334	13	17A
0005432756794	25334	14	17C
0005432755019	25334	15	17E
0005432755015	25334	16	19E
0005432756793	25334	17	19F
0005432756796	25334	18	20C
0005432756787	25334	19	20D
0005432755022	25334	20	20E
0005432756791	25334	21	20F
0005433845856	5556	1	1C
0005433845900	5556	2	2F
0005433845871	5556	3	2D
0005433845901	5556	4	2C
0005433845872	5556	5	3A
0005433845854	5556	6	3F
0005432081419	5556	7	4A
0005432081416	5556	8	5A
0005433845902	5556	9	4F
0005433845892	5556	10	5D
0005433845877	5556	11	6B
0005433845894	5556	12	6A
0005433845847	5556	13	6F
0005433845866	5556	14	7B
0005432081417	5556	15	7E
0005433815313	5556	16	7D
0005433845851	5556	17	8A
0005432081420	5556	18	8C
0005433845858	5556	19	8F
0005433845862	5556	20	9B
0005433845896	5556	21	9C
0005433845889	5556	22	9E
0005433845876	5556	23	10A
0005433845849	5556	24	9F
0005433815312	5556	25	10C
0005433845875	5556	26	10E
0005433845873	5556	27	10D
0005433815311	5556	28	10F
0005433845870	5556	29	11C
0005433845879	5556	30	11A
0005433845853	5556	31	11D
0005433845887	5556	32	11F
0005433845864	5556	33	12B
0005433845860	5556	34	12A
0005433845857	5556	35	12C
0005433845852	5556	36	12D
0005433845846	5556	37	13A
0005433845888	5556	38	12F
0005433845845	5556	39	13B
0005433845869	5556	40	13E
0005433845881	5556	41	14A
0005433845899	5556	42	13F
0005432081418	5556	43	14D
0005433845865	5556	44	14C
0005433845878	5556	45	14F
0005432081415	5556	46	15A
0005433845895	5556	47	15D
0005433845885	5556	48	15C
0005433845890	5556	49	15E
0005432081422	5556	50	16A
0005433845863	5556	51	15F
0005433845859	5556	52	16C
0005433845880	5556	53	16B
0005433815314	5556	54	16D
0005433845893	5556	55	17C
0005433845850	5556	56	17F
0005433845861	5556	57	17E
0005433845898	5556	58	18B
0005433845886	5556	59	18A
0005433845843	5556	60	18C
0005432081414	5556	61	18E
0005432081421	5556	62	18D
0005433845897	5556	63	19C
0005433845891	5556	64	19D
0005433845874	5556	65	19F
0005433845882	5556	66	19E
0005433845868	5556	67	20B
0005433845844	5556	68	20A
0005433845855	5556	69	20C
0005433815310	5556	70	21A
0005433845883	5556	71	21D
0005433845867	5556	72	21C
0005433845848	5556	73	21E
0005433845884	5556	74	21F
0005432003656	13874	1	1A
0005435282146	13874	2	1F
0005435282152	13874	3	2F
0005435282140	13874	4	3C
0005435282139	13874	5	4A
0005435282130	13874	6	4D
0005435282144	13874	7	5C
0005432003657	13874	8	5A
0005434173462	13874	9	5F
0005434173463	13874	10	5D
0005435282126	13874	11	6E
0005434173464	13874	12	7A
0005435282133	13874	13	7F
0005435282127	13874	14	8F
0005434173460	13874	15	9A
0005435282136	13874	16	10C
0005435282150	13874	17	10E
0005435282124	13874	18	10F
0005435282137	13874	19	11D
0005435282129	13874	20	11C
0005435282148	13874	21	13E
0005435282141	13874	22	13F
0005435282125	13874	23	14A
0005435282135	13874	24	14E
0005433845698	13874	25	15D
0005435282134	13874	26	16C
0005435282128	13874	27	16F
0005435282147	13874	28	18E
0005435282143	13874	29	19A
0005435282145	13874	30	19E
0005434173461	13874	31	19D
0005435282149	13874	32	19F
0005435282151	13874	33	20C
0005435282132	13874	34	20B
0005435282131	13874	35	20D
0005435282142	13874	36	21B
0005435282138	13874	37	20F
0005434620295	7800	1	1A
0005434620290	7800	2	1B
0005434620303	7800	3	1C
0005434620285	7800	4	2B
0005434620287	7800	5	2C
0005434620288	7800	6	3C
0005434620286	7800	7	4B
0005434620299	7800	8	4C
0005434620300	7800	9	4D
0005434620291	7800	10	5D
0005434620297	7800	11	6A
0005434620302	7800	12	7A
0005434620301	7800	13	7B
0005434620294	7800	14	7C
0005432112482	7800	15	7D
0005434620292	7800	16	19A
0005432112483	7800	17	19C
0005434620298	7800	18	20A
0005435332149	7800	19	20B
0005434620293	7800	20	20C
0005434620296	7800	21	20D
0005434620305	7800	22	21C
0005434620289	7800	23	22B
0005434620304	7800	24	22C
0005435332180	32975	1	3A
0005435332185	32975	2	4B
0005435332184	32975	3	4D
0005435332181	32975	4	6A
0005435332186	32975	5	6B
0005435332182	32975	6	7C
0005435332178	32975	7	20B
0005435332183	32975	8	20C
0005435332188	32975	9	20D
0005435332179	32975	10	21B
0005435332187	32975	11	22C
0005435784850	4300	1	1C
0005435784865	4300	2	1A
0005435784864	4300	3	2A
0005435784855	4300	4	2C
0005435784861	4300	5	2F
0005435784852	4300	6	3A
0005435784847	4300	7	3C
0005434993876	4300	8	4A
0005432190572	4300	9	4D
0005435784857	4300	10	4F
0005435784836	4300	11	5A
0005435784853	4300	12	6C
0005435784841	4300	13	6D
0005435784862	4300	14	6E
0005435784837	4300	15	7A
0005434993880	4300	16	7C
0005434993883	4300	17	7D
0005434993878	4300	18	7F
0005434993886	4300	19	8C
0005435784840	4300	20	8E
0005435784845	4300	21	8F
0005434993879	4300	22	9A
0005435784866	4300	23	9E
0005435784842	4300	24	9F
0005435784854	4300	25	10C
0005435784834	4300	26	10D
0005435784868	4300	27	10E
0005435784858	4300	28	10F
0005435784849	4300	29	11A
0005434993877	4300	30	11C
0005435784843	4300	31	11E
0005435784844	4300	32	12C
0005432190573	4300	33	12D
0005434993885	4300	34	12E
0005435784856	4300	35	13E
0005434993881	4300	36	14A
0005435784867	4300	37	14C
0005432190571	4300	38	15A
0005435784860	4300	39	16A
0005434993884	4300	40	16C
0005435784851	4300	41	16E
0005435784863	4300	42	16F
0005435784835	4300	43	17E
0005432190574	4300	44	17F
0005435784839	4300	45	18E
0005435784846	4300	46	18F
0005434993882	4300	47	19C
0005435784859	4300	48	19E
0005435784848	4300	49	19F
0005435784838	4300	50	20D
0005435918585	27292	1	3C
0005435937320	27292	2	4C
0005432195661	27292	3	6A
0005435918586	27292	4	7E
0005435937322	27292	5	8A
0005435937325	27292	6	10F
0005435937326	27292	7	12D
0005435937323	27292	8	13D
0005435937321	27292	9	14A
0005435937324	27292	10	14E
0005435937319	27292	11	16A
0005432195660	27292	12	18C
0005435918584	27292	13	19E
0005435918587	27292	14	20A
0005432146168	19873	1	2A
0005432146167	19873	2	5B
0005432146169	19873	3	18A
0005432146170	19873	4	19D
0005432566761	4718	1	1A
0005432459072	4718	2	1B
0005434081567	4718	3	1F
0005432459097	4718	4	1C
0005432459073	4718	5	1G
0005433726072	4718	6	1H
0005432459096	4718	7	2B
0005432459085	4718	8	2F
0005432459098	4718	9	2C
0005432566740	4718	10	2H
0005434081555	4718	11	3C
0005432170290	4718	12	3B
0005432459112	4718	13	3F
0005432566741	4718	14	3G
0005434081556	4718	15	3H
0005432566767	4718	16	4B
0005432459093	4718	17	4G
0005432459087	4718	18	4F
0005432459067	4718	19	5B
0005434081558	4718	20	5F
0005432566726	4718	21	5C
0005432459063	4718	22	5G
0005432566736	4718	23	9A
0005432566770	4718	24	5H
0005432566738	4718	25	9B
0005432566749	4718	26	9H
0005432459104	4718	27	11A
0005432566751	4718	28	11D
0005432566754	4718	29	11B
0005433451590	4718	30	11E
0005433452708	4718	31	11H
0005434081559	4718	32	12A
0005432566724	4718	33	12D
0005434081573	4718	34	12B
0005432459092	4718	35	12E
0005432566729	4718	36	12G
0005432566755	4718	37	12F
0005432170288	4718	38	12H
0005432459079	4718	39	13B
0005432566721	4718	40	13A
0005432459065	4718	41	13D
0005432566713	4718	42	13E
0005432459066	4718	43	13F
0005432459105	4718	44	14A
0005434081562	4718	45	13H
0005432566728	4718	46	13G
0005432566743	4718	47	14D
0005432566752	4718	48	14E
0005432459108	4718	49	14F
0005432459070	4718	50	15A
0005432566725	4718	51	14H
0005432459088	4718	52	16A
0005433451589	4718	53	16D
0005432186817	4718	54	16E
0005434081574	4718	55	16G
0005432566715	4718	56	16F
0005432566750	4718	57	16H
0005432566731	4718	58	17B
0005432186815	4718	59	17F
0005432566771	4718	60	17G
0005434081560	4718	61	17H
0005432459089	4718	62	18B
0005432459078	4718	63	18A
0005432170285	4718	64	18D
0005432566763	4718	65	18F
0005432459090	4718	66	18E
0005432459109	4718	67	18G
0005432566732	4718	68	19A
0005432566775	4718	69	18H
0005432459110	4718	70	19B
0005432566773	4718	71	19E
0005434081571	4718	72	19D
0005432459095	4718	73	19G
0005434081563	4718	74	19F
0005432566764	4718	75	20A
0005432459083	4718	76	19H
0005432459114	4718	77	20B
0005432459107	4718	78	20E
0005432459106	4718	79	20D
0005432566734	4718	80	20H
0005432571265	4718	81	20G
0005432566757	4718	82	21B
0005432459076	4718	83	21D
0005434081575	4718	84	21E
0005432566727	4718	85	21G
0005432459111	4718	86	21H
0005432459102	4718	87	22B
0005433726070	4718	88	22A
0005432459094	4718	89	22D
0005432566769	4718	90	23A
0005432459081	4718	91	22H
0005434081561	4718	92	23B
0005432566722	4718	93	23D
0005433452709	4718	94	23F
0005432459113	4718	95	23H
0005432566746	4718	96	24D
0005432459064	4718	97	24F
0005434081553	4718	98	24E
0005432170289	4718	99	24G
0005432459069	4718	100	25D
0005432566742	4718	101	25E
0005434081566	4718	102	25F
0005432566756	4718	103	27E
0005432186816	4718	104	27F
0005432566733	4718	105	27H
0005434081554	4718	106	27G
0005432566730	4718	107	28D
0005432566719	4718	108	28B
0005432186818	4718	109	28G
0005434081572	4718	110	29A
0005432566760	4718	111	29D
0005432170287	4718	112	29E
0005432566723	4718	113	29G
0005434081565	4718	114	29F
0005432459103	4718	115	29H
0005432566745	4718	116	30B
0005432566718	4718	117	30A
0005434081551	4718	118	30E
0005434081568	4718	119	30H
0005434081564	4718	120	31B
0005432566714	4718	121	31A
0005434081552	4718	122	31E
0005432566720	4718	123	31D
0005432459082	4718	124	31F
0005432566774	4718	125	31G
0005432566748	4718	126	32A
0005432571266	4718	127	31H
0005434081569	4718	128	32E
0005432566737	4718	129	32D
0005432459084	4718	130	32F
0005432566753	4718	131	32H
0005434081557	4718	132	32G
0005432566716	4718	133	33B
0005432459115	4718	134	33E
0005432566739	4718	135	33G
0005432459075	4718	136	33F
0005432459086	4718	137	33H
0005432459071	4718	138	34D
0005432566759	4718	139	34F
0005432459099	4718	140	34E
0005434081576	4718	141	34H
0005432571264	4718	142	35B
0005432566766	4718	143	35A
0005432459068	4718	144	35E
0005433726071	4718	145	35D
0005432566772	4718	146	35F
0005434081570	4718	147	36A
0005432566765	4718	148	36B
0005432459100	4718	149	36E
0005432566717	4718	150	36D
0005432566758	4718	151	36F
0005432459074	4718	152	36G
0005432459101	4718	153	36H
0005432571267	4718	154	37D
0005432566762	4718	155	37H
0005432566768	4718	156	37G
0005432566744	4718	157	38A
0005432459077	4718	158	38E
0005432459080	4718	159	38G
0005432566735	4718	160	38F
0005432566747	4718	161	38H
0005432459091	4718	162	39D
0005432170286	4718	163	39F
0005432170291	4718	164	39E
0005432213552	30514	1	3F
0005432161117	30514	2	5H
0005432566687	30514	3	19B
0005432161118	30514	4	21B
0005432566688	30514	5	25E
0005432213551	30514	6	29A
0005432566623	30514	7	29E
0005432213550	30514	8	30F
0005432566590	30514	9	31D
0005432213553	30514	10	35F
0005432566589	30514	11	36E
0005435720807	13602	1	2A
0005435722021	13602	2	3A
0005435722020	13602	3	5A
0005432295840	22801	1	4A
0005432295843	22801	2	4B
0005432295842	22801	3	5D
0005432295841	22801	4	20C
0005433341745	11115	1	1A
0005433341764	11115	2	1F
0005433341741	11115	3	1D
0005433341758	11115	4	2A
0005433341717	11115	5	2C
0005433341733	11115	6	2D
0005433341720	11115	7	3A
0005433341771	11115	8	2F
0005433341691	11115	9	3C
0005433341773	11115	10	3D
0005433341744	11115	11	3F
0005433341684	11115	12	4A
0005433341721	11115	13	4B
0005435097064	11115	14	4D
0005433341782	11115	15	4C
0005433341706	11115	16	4E
0005433341697	11115	17	4F
0005433341784	11115	18	5A
0005433341767	11115	19	5C
0005433341757	11115	20	5B
0005433341752	11115	21	5E
0005433341689	11115	22	6A
0005433341692	11115	23	5F
0005433341778	11115	24	6B
0005433341735	11115	25	6C
0005433341722	11115	26	6D
0005433341687	11115	27	6E
0005433341755	11115	28	7A
0005433341785	11115	29	7D
0005433341723	11115	30	7C
0005433341761	11115	31	7E
0005433341726	11115	32	7F
0005433341769	11115	33	8B
0005433341749	11115	34	8A
0005435097061	11115	35	8E
0005433341760	11115	36	8D
0005433341705	11115	37	8F
0005433341685	11115	38	9A
0005433341728	11115	39	9B
0005433341738	11115	40	9C
0005433341779	11115	41	9D
0005433341777	11115	42	9F
0005433341710	11115	43	9E
0005433341759	11115	44	10B
0005433341742	11115	45	10D
0005433341772	11115	46	10E
0005433341736	11115	47	11A
0005433341699	11115	48	11B
0005433341698	11115	49	11C
0005433341774	11115	50	11E
0005435097067	11115	51	11F
0005433341729	11115	52	12B
0005433341702	11115	53	12A
0005433341727	11115	54	12C
0005433341730	11115	55	12D
0005433341686	11115	56	12E
0005433341688	11115	57	13B
0005433341765	11115	58	13C
0005433341756	11115	59	13E
0005433341737	11115	60	13F
0005433341775	11115	61	14B
0005433341715	11115	62	14A
0005433341711	11115	63	14C
0005435097063	11115	64	14D
0005433341770	11115	65	14E
0005433341700	11115	66	15A
0005433341768	11115	67	15C
0005433341712	11115	68	15E
0005433341739	11115	69	16A
0005433341724	11115	70	15F
0005433341743	11115	71	16C
0005433341734	11115	72	16B
0005433341695	11115	73	16E
0005433341731	11115	74	16D
0005433341690	11115	75	16F
0005433341754	11115	76	17A
0005433341746	11115	77	17B
0005433341763	11115	78	17C
0005435097060	11115	79	17E
0005433341783	11115	80	17D
0005433341732	11115	81	18A
0005435097065	11115	82	17F
0005435097062	11115	83	18C
0005433341716	11115	84	18E
0005435097068	11115	85	18F
0005433341751	11115	86	19B
0005433341780	11115	87	19A
0005433341740	11115	88	19C
0005433341703	11115	89	19E
0005433341747	11115	90	19D
0005435097066	11115	91	19F
0005433341766	11115	92	20C
0005433341781	11115	93	20B
0005433341708	11115	94	20E
0005433341725	11115	95	21A
0005433341719	11115	96	20F
0005433341709	11115	97	21B
0005433341714	11115	98	21C
0005433341786	11115	99	21D
0005433341694	11115	100	21E
0005433341762	11115	101	22B
0005433341707	11115	102	22A
0005433341701	11115	103	22C
0005433341718	11115	104	22D
0005433341704	11115	105	22E
0005433341696	11115	106	23A
0005433341753	11115	107	22F
0005433341750	11115	108	23B
0005433341693	11115	109	23C
0005433341748	11115	110	23D
0005433341713	11115	111	23F
0005433341776	11115	112	23E
0005435545628	17111	1	1F
0005435545617	17111	2	4A
0005435545626	17111	3	5A
0005435545624	17111	4	5F
0005432293171	17111	5	6D
0005435545632	17111	6	6E
0005435545630	17111	7	7B
0005432293173	17111	8	7F
0005435380229	17111	9	9C
0005435545627	17111	10	9B
0005435380234	17111	11	9E
0005435545618	17111	12	10B
0005435380233	17111	13	10E
0005435545622	17111	14	12B
0005435380232	17111	15	12F
0005435545633	17111	16	13C
0005435545634	17111	17	15D
0005435545620	17111	18	15E
0005435380230	17111	19	16A
0005435545629	17111	20	16C
0005435380231	17111	21	17A
0005435545623	17111	22	17D
0005432293172	17111	23	18D
0005435545619	17111	24	19B
0005435380228	17111	25	19C
0005435545635	17111	26	20E
0005435545625	17111	27	22E
0005435545631	17111	28	23A
0005435545621	17111	29	23F
0005433506915	9115	1	1D
0005433506921	9115	2	3D
0005433506928	9115	3	3F
0005433506924	9115	4	4D
0005433506917	9115	5	4F
0005433506922	9115	6	5F
0005433506912	9115	7	6E
0005433481056	9115	8	7C
0005433506919	9115	9	8D
0005433506923	9115	10	9A
0005433506916	9115	11	9C
0005433506927	9115	12	9F
0005433506913	9115	13	11D
0005433506925	9115	14	11E
0005433506918	9115	15	11F
0005433506920	9115	16	13F
0005433481053	9115	17	14A
0005433506914	9115	18	14D
0005433506926	9115	19	15A
0005433481058	9115	20	16C
0005433481054	9115	21	17E
0005433481051	9115	22	17F
0005433506929	9115	23	18A
0005433481057	9115	24	18F
0005433481052	9115	25	20A
0005433481059	9115	26	20C
0005433481055	9115	27	20F
0005432919572	20467	1	1D
0005432919568	20467	2	2A
0005432919581	20467	3	2D
0005432919585	20467	4	3C
0005432919567	20467	5	5E
0005432919576	20467	6	7C
0005432919582	20467	7	8A
0005432919579	20467	8	7F
0005432919586	20467	9	9A
0005432919580	20467	10	10D
0005432919587	20467	11	11C
0005432919573	20467	12	12A
0005432919569	20467	13	14E
0005432919574	20467	14	15A
0005432919570	20467	15	17C
0005432919571	20467	16	17E
0005432919577	20467	17	19E
0005432919575	20467	18	19F
0005432919584	20467	19	20D
0005432919578	20467	20	20E
0005432919583	20467	21	20F
0005432396181	10125	1	1A
0005432394041	10125	2	1B
0005432394042	10125	3	2A
0005432396180	10125	4	2B
0005432396179	10125	5	3A
0005432396182	10125	6	3B
0005432394040	10125	7	4B
0005432394043	10125	8	6A
0005434928258	11025	1	2D
0005434928259	11025	2	5D
0005434928260	11025	3	6C
0005434411716	11025	4	8D
0005434411715	11025	5	10E
0005434411717	11025	6	12D
0005434411718	11025	7	19E
0005435125797	14764	1	1A
0005435625913	14764	2	1F
0005435125812	14764	3	2C
0005435125800	14764	4	2D
0005435625923	14764	5	2F
0005435556656	14764	6	3A
0005435125806	14764	7	3C
0005435625922	14764	8	3D
0005435125793	14764	9	3F
0005435125775	14764	10	4A
0005435125799	14764	11	4D
0005435125794	14764	12	4F
0005435625925	14764	13	5A
0005435625917	14764	14	5D
0005435625926	14764	15	5E
0005435125798	14764	16	5F
0005435125790	14764	17	6A
0005435554117	14764	18	6D
0005435125805	14764	19	6E
0005435125809	14764	20	6F
0005435625924	14764	21	7A
0005435125781	14764	22	7D
0005435125780	14764	23	7E
0005435554115	14764	24	7F
0005435125803	14764	25	8A
0005435125804	14764	26	8C
0005435125785	14764	27	8D
0005435125789	14764	28	8E
0005435125807	14764	29	8F
0005435625927	14764	30	9D
0005435125808	14764	31	10A
0005435125788	14764	32	10D
0005435125801	14764	33	10F
0005435625921	14764	34	11A
0005435125786	14764	35	11D
0005435125811	14764	36	11E
0005435625920	14764	37	12A
0005435125782	14764	38	12D
0005435554114	14764	39	12F
0005435125777	14764	40	13A
0005435625914	14764	41	13C
0005435125783	14764	42	13D
0005435125784	14764	43	13E
0005435125779	14764	44	13F
0005435125810	14764	45	14A
0005435556657	14764	46	14D
0005435625915	14764	47	14E
0005435554116	14764	48	15A
0005435125796	14764	49	15C
0005435125792	14764	50	15D
0005435554113	14764	51	15E
0005435125787	14764	52	16A
0005435625919	14764	53	16C
0005435556655	14764	54	16D
0005435125795	14764	55	17A
0005435125813	14764	56	17D
0005435125774	14764	57	17E
0005435125802	14764	58	17F
0005435125791	14764	59	18A
0005435625918	14764	60	18D
0005435625916	14764	61	18E
0005435556654	14764	62	19C
0005435125776	14764	63	19D
0005435125778	14764	64	19F
0005435125772	14764	65	20D
0005435125773	14764	66	20F
0005435715219	7131	1	1A
0005432400070	7131	2	1F
0005435715215	7131	3	2F
0005435715227	7131	4	3A
0005435715224	7131	5	4D
0005432398145	7131	6	4E
0005435715214	7131	7	5E
0005435715216	7131	8	5F
0005435715212	7131	9	7C
0005435715218	7131	10	7D
0005435715223	7131	11	8E
0005432400071	7131	12	9D
0005435715217	7131	13	9F
0005432400069	7131	14	10F
0005435715226	7131	15	13D
0005432400072	7131	16	13E
0005432398143	7131	17	14A
0005435715222	7131	18	14E
0005435715213	7131	19	16C
0005435715220	7131	20	16F
0005435715225	7131	21	18E
0005435715221	7131	22	18F
0005432398142	7131	23	19A
0005432398144	7131	24	20D
0005435715228	7131	25	20E
0005435443180	27078	1	1A
0005435178473	27078	2	2F
0005435443176	27078	3	4A
0005435443179	27078	4	4C
0005435443173	27078	5	4D
0005435178978	27078	6	6F
0005435443181	27078	7	7F
0005435178472	27078	8	8C
0005435178471	27078	9	9F
0005435443178	27078	10	13E
0005435443174	27078	11	14C
0005435443175	27078	12	17F
0005435443177	27078	13	19F
0005434084865	2745	1	3B
0005434084863	2745	2	3A
0005434084861	2745	3	4A
0005434084862	2745	4	5B
0005434084864	2745	5	6B
0005433060375	28483	1	1A
0005433060376	28483	2	2B
0005433060374	28483	3	2A
0005433060373	28483	4	4B
0005432632632	25192	1	2C
0005432632634	25192	2	3A
0005432632629	25192	3	3B
0005432632631	25192	4	3D
0005432632628	25192	5	4A
0005432632626	25192	6	4B
0005432632624	25192	7	5D
0005432632622	25192	8	6A
0005432632625	25192	9	6C
0005432632627	25192	10	6D
0005432632630	25192	11	7A
0005432632633	25192	12	18A
0005432632620	25192	13	19A
0005432632623	25192	14	20D
0005432632621	25192	15	21C
0005435844270	28177	1	2B
0005435844267	28177	2	3B
0005435844261	28177	3	4D
0005435844260	28177	4	5C
0005435844266	28177	5	6D
0005435844265	28177	6	7B
0005435844269	28177	7	19C
0005435844264	28177	8	21C
0005435844268	28177	9	22A
0005435844262	28177	10	22D
0005435844263	28177	11	23A
0005432294451	22222	1	1A
0005435528930	22222	2	1D
0005435528944	22222	3	2C
0005435540676	22222	4	3C
0005435540681	22222	5	3F
0005435528923	22222	6	4C
0005432294450	22222	7	4D
0005435540689	22222	8	4F
0005435528934	22222	9	5C
0005435528926	22222	10	5D
0005435528929	22222	11	5E
0005435528931	22222	12	5F
0005435540671	22222	13	6C
0005435540667	22222	14	6D
0005435540677	22222	15	6E
0005435540670	22222	16	7A
0005435528924	22222	17	7D
0005435528935	22222	18	7F
0005435540682	22222	19	8C
0005432294452	22222	20	8D
0005435540686	22222	21	8E
0005435540683	22222	22	8F
0005435528936	22222	23	9A
0005435540680	22222	24	10D
0005435540672	22222	25	11A
0005435528943	22222	26	11C
0005435528922	22222	27	11F
0005435528928	22222	28	12A
0005435540684	22222	29	12C
0005435540679	22222	30	12D
0005435528927	22222	31	12E
0005435540674	22222	32	12F
0005435528925	22222	33	13A
0005435528941	22222	34	13E
0005435528940	22222	35	13F
0005435540669	22222	36	14A
0005435528939	22222	37	14D
0005435528942	22222	38	15A
0005435540687	22222	39	15E
0005435540678	22222	40	16A
0005435528933	22222	41	16C
0005435540673	22222	42	16F
0005435528945	22222	43	18A
0005435540685	22222	44	18C
0005435528946	22222	45	18E
0005435540668	22222	46	18F
0005435540688	22222	47	19A
0005435540675	22222	48	19E
0005435528932	22222	49	20A
0005435528937	22222	50	20D
0005435528938	22222	51	20E
0005434906523	2298	1	1A
0005434906519	2298	2	1C
0005434906563	2298	3	2A
0005434906567	2298	4	2D
0005434906565	2298	5	3C
0005434906518	2298	6	3F
0005434906522	2298	7	4C
0005434906566	2298	8	4D
0005434906531	2298	9	4E
0005434906554	2298	10	5A
0005434906539	2298	11	5C
0005434906520	2298	12	5D
0005434906545	2298	13	5F
0005434906557	2298	14	6A
0005434906550	2298	15	6C
0005434906537	2298	16	6D
0005434906526	2298	17	7A
0005434906532	2298	18	7C
0005434906564	2298	19	7F
0005434906559	2298	20	8C
0005434906534	2298	21	9A
0005434906553	2298	22	9F
0005434906525	2298	23	10F
0005434906535	2298	24	11C
0005434906570	2298	25	11D
0005434906527	2298	26	11E
0005434906561	2298	27	12A
0005434906547	2298	28	12C
0005434906536	2298	29	12D
0005434906541	2298	30	12E
0005434906556	2298	31	12F
0005434906533	2298	32	13A
0005434906529	2298	33	13C
0005434906551	2298	34	13D
0005434906528	2298	35	13E
0005434906544	2298	36	13F
0005434906524	2298	37	14C
0005434906552	2298	38	14D
0005434906543	2298	39	14E
0005434906555	2298	40	14F
0005434906546	2298	41	15E
0005434906568	2298	42	15F
0005434906549	2298	43	16A
0005434906538	2298	44	16D
0005434906542	2298	45	16E
0005434906517	2298	46	17C
0005434906521	2298	47	18C
0005434906560	2298	48	18D
0005434906540	2298	49	18E
0005434906558	2298	50	18F
0005434906569	2298	51	19A
0005434906530	2298	52	19E
0005434906562	2298	53	20A
0005434906516	2298	54	20C
0005434906548	2298	55	20E
0005434906571	2298	56	20F
0005433251046	25610	1	1A
0005433251038	25610	2	2A
0005433400943	25610	3	2D
0005433251036	25610	4	3F
0005433251025	25610	5	4A
0005433251048	25610	6	4D
0005433251042	25610	7	4E
0005433251022	25610	8	4F
0005433251047	25610	9	5F
0005433251029	25610	10	6D
0005433251023	25610	11	6F
0005433400941	25610	12	7C
0005433251026	25610	13	7D
0005433251035	25610	14	8F
0005433251039	25610	15	9D
0005433251049	25610	16	9F
0005433251027	25610	17	10F
0005433251041	25610	18	11D
0005433251024	25610	19	11E
0005433251033	25610	20	12D
0005433251040	25610	21	12E
0005433400940	25610	22	13D
0005433251051	25610	23	14F
0005433251043	25610	24	15A
0005433251030	25610	25	15D
0005433251052	25610	26	16D
0005433251045	25610	27	16E
0005433251037	25610	28	17A
0005433251053	25610	29	17C
0005433400942	25610	30	17E
0005433251050	25610	31	18A
0005433251031	25610	32	18E
0005433251028	25610	33	19A
0005433251032	25610	34	19C
0005433251044	25610	35	20E
0005433251034	25610	36	20F
0005432620831	2546	1	1C
0005432620835	2546	2	3A
0005432620837	2546	3	4A
0005432620841	2546	4	5C
0005432620834	2546	5	5D
0005432620836	2546	6	6C
0005432620829	2546	7	6D
0005432620843	2546	8	7C
0005432620830	2546	9	18A
0005432620840	2546	10	18B
0005432620832	2546	11	19A
0005432620839	2546	12	19D
0005432620838	2546	13	21B
0005432620842	2546	14	22D
0005432620833	2546	15	23A
0005432862193	28084	1	1B
0005432862192	28084	2	2A
0005432862190	28084	3	2B
0005432862187	28084	4	2C
0005432862189	28084	5	4A
0005432862191	28084	6	4B
0005432862186	28084	7	5D
0005432862194	28084	8	6C
0005432862188	28084	9	22B
0005434097454	13059	1	2A
0005434097455	13059	2	5A
0005433451589	31064	1	1A
0005433451590	31064	2	1B
0005433452709	31064	3	5A
0005433452708	31064	4	6B
0005433131644	29844	1	2C
0005434142548	29844	2	3A
0005434142552	29844	3	3C
0005433134070	29844	4	4B
0005433131642	29844	5	5B
0005433131643	29844	6	6D
0005433134073	29844	7	7A
0005434142553	29844	8	7C
0005433131640	29844	9	7D
0005433131641	29844	10	18C
0005434184636	29844	11	18D
0005434183551	29844	12	19B
0005434142551	29844	13	19C
0005434183550	29844	14	20A
0005434142549	29844	15	20B
0005433134075	29844	16	21A
0005433134074	29844	17	21C
0005434142550	29844	18	22C
0005433134072	29844	19	22D
0005433134071	29844	20	23A
0005435696921	16446	1	1A
0005435696903	16446	2	1C
0005435696914	16446	3	2B
0005435696919	16446	4	2C
0005435696912	16446	5	3B
0005435696917	16446	6	3C
0005435696926	16446	7	3D
0005435696920	16446	8	4C
0005435696904	16446	9	4D
0005435696924	16446	10	5C
0005435696927	16446	11	6A
0005435696916	16446	12	6C
0005435696918	16446	13	6D
0005435696906	16446	14	7A
0005435696913	16446	15	7B
0005435696902	16446	16	7C
0005435696909	16446	17	18B
0005435696910	16446	18	18C
0005435696907	16446	19	18D
0005435696905	16446	20	19C
0005435696915	16446	21	19D
0005435696911	16446	22	20A
0005435696922	16446	23	20B
0005435696925	16446	24	21D
0005435696908	16446	25	22A
0005435696901	16446	26	22D
0005435696923	16446	27	23A
0005435696928	16446	28	23B
0005435935003	24686	1	19D
0005433724736	18810	1	1A
0005433724735	18810	2	3B
0005433724738	18810	3	4A
0005433724733	18810	4	5A
0005433724737	18810	5	6A
0005433724734	18810	6	6B
0005432968810	21627	1	2A
0005432968808	21627	2	4A
0005432968809	21627	3	6B
0005434136970	7316	1	1A
0005434136957	7316	2	1C
0005434136946	7316	3	1D
0005434136949	7316	4	1F
0005434136950	7316	5	2A
0005434136983	7316	6	2C
0005434136997	7316	7	2D
0005434137009	7316	8	3A
0005434136985	7316	9	3C
0005434136937	7316	10	3D
0005434136988	7316	11	3F
0005434136991	7316	12	4A
0005434136947	7316	13	4C
0005434137001	7316	14	4D
0005434136977	7316	15	4F
0005434087444	7316	16	5A
0005434137006	7316	17	5D
0005434136982	7316	18	5E
0005434136973	7316	19	5F
0005434087442	7316	20	6A
0005434137004	7316	21	6C
0005434136960	7316	22	6D
0005434137008	7316	23	6E
0005434136966	7316	24	6F
0005434136968	7316	25	7A
0005434136979	7316	26	7C
0005434136943	7316	27	7D
0005434136995	7316	28	7F
0005434136971	7316	29	8A
0005434136959	7316	30	8D
0005434136975	7316	31	8E
0005434137012	7316	32	9A
0005434136944	7316	33	9C
0005434087443	7316	34	9D
0005434137000	7316	35	9E
0005434136958	7316	36	9F
0005434136987	7316	37	10A
0005434136956	7316	38	10C
0005434136998	7316	39	10D
0005434136965	7316	40	10E
0005434136938	7316	41	10F
0005434087446	7316	42	11A
0005434136990	7316	43	11C
0005434136992	7316	44	11D
0005434136939	7316	45	11E
0005434137011	7316	46	12A
0005434136993	7316	47	12C
0005434137013	7316	48	12D
0005434136967	7316	49	12F
0005434136986	7316	50	13A
0005434137005	7316	51	13C
0005434136976	7316	52	13D
0005434137010	7316	53	13F
0005434136984	7316	54	14A
0005434136935	7316	55	14C
0005434136969	7316	56	14D
0005434136994	7316	57	14E
0005434136972	7316	58	14F
0005434136953	7316	59	15A
0005434137003	7316	60	15C
0005434136955	7316	61	15D
0005434136962	7316	62	15F
0005434136963	7316	63	16A
0005434136961	7316	64	16C
0005434136980	7316	65	16E
0005434136951	7316	66	16F
0005434136936	7316	67	17A
0005434087441	7316	68	17C
0005434136945	7316	69	17D
0005434136954	7316	70	17E
0005434136942	7316	71	17F
0005434136974	7316	72	18A
0005434136948	7316	73	18C
0005434137007	7316	74	18E
0005434136989	7316	75	18F
0005434136952	7316	76	19A
0005434136964	7316	77	19C
0005434136978	7316	78	19D
0005434136940	7316	79	19E
0005434137002	7316	80	19F
0005434087445	7316	81	20A
0005434136999	7316	82	20C
0005434136981	7316	83	20D
0005434136941	7316	84	20E
0005434136996	7316	85	20F
0005434610177	1898	1	2C
0005435808081	1898	2	3A
0005435808092	1898	3	3B
0005435808082	1898	4	3C
0005435808086	1898	5	3D
0005435808091	1898	6	4A
0005435808085	1898	7	4B
0005435808090	1898	8	4C
0005435808084	1898	9	5D
0005434610178	1898	10	6C
0005435808087	1898	11	7B
0005434610176	1898	12	20A
0005435808083	1898	13	20D
0005434610179	1898	14	21A
0005435808089	1898	15	21D
0005435808088	1898	16	23A
0005433407484	23119	1	1C
0005433407487	23119	2	2C
0005433407489	23119	3	3A
0005433407482	23119	4	3C
0005433407485	23119	5	4B
0005433407488	23119	6	5C
0005433407490	23119	7	6D
0005433407491	23119	8	7D
0005433407483	23119	9	20C
0005433407486	23119	10	22A
0005434503568	22878	1	1A
0005434503564	22878	2	1B
0005434503575	22878	3	1C
0005434503544	22878	4	1D
0005434503573	22878	5	2B
0005434503562	22878	6	2C
0005434503551	22878	7	2D
0005434503539	22878	8	3A
0005434503547	22878	9	3B
0005434503541	22878	10	3C
0005434503558	22878	11	4A
0005434503576	22878	12	4B
0005434503571	22878	13	4D
0005434503550	22878	14	5B
0005434503540	22878	15	5C
0005434503543	22878	16	5D
0005434503559	22878	17	6B
0005434503548	22878	18	6C
0005434503565	22878	19	7A
0005434503545	22878	20	7B
0005434503577	22878	21	7C
0005434503552	22878	22	7D
0005434503556	22878	23	18A
0005434503538	22878	24	18B
0005434503567	22878	25	18C
0005434503554	22878	26	19A
0005434503563	22878	27	19B
0005434503566	22878	28	19C
0005434503572	22878	29	19D
0005434503570	22878	30	20A
0005434503560	22878	31	20B
0005434503574	22878	32	20C
0005434503542	22878	33	20D
0005434503549	22878	34	21A
0005434503557	22878	35	21B
0005434503561	22878	36	21D
0005434503537	22878	37	22B
0005434503555	22878	38	22C
0005434503553	22878	39	22D
0005434503569	22878	40	23A
0005434503546	22878	41	23B
0005435078122	2199	1	1D
0005435078113	2199	2	2A
0005435078117	2199	3	2B
0005435078121	2199	4	4B
0005435078119	2199	5	4D
0005435078126	2199	6	5D
0005435078114	2199	7	6B
0005435078127	2199	8	6D
0005435078116	2199	9	18C
0005435078125	2199	10	21A
0005435078123	2199	11	21B
0005435078124	2199	12	21C
0005435078115	2199	13	21D
0005435078118	2199	14	22C
0005435078120	2199	15	22D
0005433266589	24355	1	1A
0005433266592	24355	2	2A
0005433266587	24355	3	2B
0005433266585	24355	4	3A
0005433266588	24355	5	3C
0005433266590	24355	6	4C
0005433266591	24355	7	5A
0005433266593	24355	8	6D
0005435078064	24355	9	20C
0005433266586	24355	10	23B
0005435803220	6626	1	1B
0005434988587	6626	2	1C
0005435803222	6626	3	3D
0005434988585	6626	4	4B
0005434988584	6626	5	6A
0005435803221	6626	6	7A
0005434988582	6626	7	7B
0005434988580	6626	8	7D
0005434988583	6626	9	18C
0005434988586	6626	10	19C
0005435803223	6626	11	19D
0005434988581	6626	12	22D
0005435464478	23625	1	1B
0005435464479	23625	2	21D
0005432382610	30462	1	1A
0005433449669	30462	2	1C
0005432382623	30462	3	1D
0005432382634	30462	4	1F
0005432382609	30462	5	2A
0005432382628	30462	6	2C
0005433449667	30462	7	2D
0005432382622	30462	8	2F
0005433449654	30462	9	3A
0005432382615	30462	10	3C
0005433449668	30462	11	3D
0005432382637	30462	12	3F
0005432382640	30462	13	4D
0005432382643	30462	14	5C
0005432382635	30462	15	5E
0005432382645	30462	16	5F
0005433449670	30462	17	6C
0005433449660	30462	18	6E
0005432382641	30462	19	6F
0005432382606	30462	20	7A
0005433454843	30462	21	7C
0005432382618	30462	22	7D
0005432382632	30462	23	7E
0005433449661	30462	24	7F
0005432382633	30462	25	8A
0005432382648	30462	26	8C
0005432382613	30462	27	8E
0005432382617	30462	28	9A
0005432382639	30462	29	9C
0005432382619	30462	30	9D
0005432382627	30462	31	9E
0005432382608	30462	32	9F
0005433449651	30462	33	10A
0005432382616	30462	34	10C
0005432382647	30462	35	10D
0005432382630	30462	36	10F
0005433454845	30462	37	11A
0005432382624	30462	38	11D
0005433449665	30462	39	11F
0005432382621	30462	40	12D
0005433449666	30462	41	12E
0005433449650	30462	42	13A
0005432382626	30462	43	13C
0005432382636	30462	44	13D
0005433449662	30462	45	14A
0005432382611	30462	46	14C
0005433449656	30462	47	14E
0005433449657	30462	48	15A
0005433453733	30462	49	15D
0005432382607	30462	50	15E
0005433449652	30462	51	15F
0005432382642	30462	52	16A
0005433449658	30462	53	16D
0005432382620	30462	54	16E
0005432382629	30462	55	16F
0005433449659	30462	56	17A
0005433449655	30462	57	17D
0005432382638	30462	58	17E
0005433449653	30462	59	17F
0005432382625	30462	60	18A
0005432382631	30462	61	18C
0005433453734	30462	62	18E
0005432382614	30462	63	18F
0005433454844	30462	64	19A
0005433454846	30462	65	19C
0005433449671	30462	66	19E
0005433449664	30462	67	19F
0005432382644	30462	68	20C
0005433449663	30462	69	20D
0005432382646	30462	70	20E
0005432382612	30462	71	20F
0005435302136	29714	1	1A
0005433129216	29714	2	2A
0005435299711	29714	3	4D
0005433126781	29714	4	5A
0005433129215	29714	5	6B
0005433129213	29714	6	6C
0005435299710	29714	7	7A
0005433126785	29714	8	7B
0005435302135	29714	9	7D
0005435302134	29714	10	18B
0005433126784	29714	11	18C
0005435302137	29714	12	19C
0005433129212	29714	13	20A
0005435302138	29714	14	20B
0005435299714	29714	15	21A
0005435299712	29714	16	21B
0005433129214	29714	17	21D
0005433129217	29714	18	22B
0005433126782	29714	19	22C
0005435299713	29714	20	22D
0005433126783	29714	21	23A
0005434286960	2402	1	1A
0005434286974	2402	2	1C
0005434286964	2402	3	2A
0005434286966	2402	4	2D
0005434286979	2402	5	3A
0005434286976	2402	6	4A
0005432264439	2402	7	4B
0005434286977	2402	8	4C
0005434286961	2402	9	4D
0005434286975	2402	10	5A
0005434286972	2402	11	5B
0005434286970	2402	12	5D
0005434286967	2402	13	6B
0005434286962	2402	14	6C
0005434286981	2402	15	18B
0005434286965	2402	16	18C
0005434286980	2402	17	18D
0005432264440	2402	18	19B
0005434286971	2402	19	19D
0005434286963	2402	20	20B
0005434286969	2402	21	21A
0005434286968	2402	22	21C
0005434286978	2402	23	22A
0005434286973	2402	24	22C
0005434286982	2402	25	23B
0005433109875	26865	1	3C
0005433109886	26865	2	3D
0005433109881	26865	3	4D
0005433109882	26865	4	5A
0005433109879	26865	5	6B
0005433109878	26865	6	7D
0005433109888	26865	7	18A
0005433109877	26865	8	19A
0005433109885	26865	9	19C
0005433109883	26865	10	19D
0005433109876	26865	11	20C
0005433109887	26865	12	21B
0005433109884	26865	13	21D
0005433109880	26865	14	22C
0005433109874	26865	15	23A
0005435856143	25446	1	1A
0005435856146	25446	2	1B
0005435856142	25446	3	2C
0005435856145	25446	4	7C
0005435856144	25446	5	22C
0005434273053	26641	1	2B
0005434272168	26641	2	4D
0005434272167	26641	3	5C
0005434273054	26641	4	7B
0005434273052	26641	5	21D
0005433867852	4781	1	1B
0005433867873	4781	2	2A
0005433867887	4781	3	2B
0005433867869	4781	4	2C
0005433867875	4781	5	2D
0005433867851	4781	6	3C
0005433867865	4781	7	4A
0005433867872	4781	8	4B
0005433867889	4781	9	4C
0005433867882	4781	10	4D
0005433867879	4781	11	5A
0005433867886	4781	12	5B
0005433867874	4781	13	5D
0005433867855	4781	14	6A
0005433867878	4781	15	6B
0005433867871	4781	16	6D
0005433867859	4781	17	7A
0005433867867	4781	18	7B
0005433867876	4781	19	7C
0005433867853	4781	20	7D
0005433867884	4781	21	18A
0005433867885	4781	22	18B
0005433867860	4781	23	18C
0005433867862	4781	24	19A
0005433867857	4781	25	19B
0005433867877	4781	26	19D
0005433867868	4781	27	19C
0005433867881	4781	28	20A
0005433867861	4781	29	20C
0005433867863	4781	30	21A
0005433867854	4781	31	21B
0005433867870	4781	32	21C
0005433867866	4781	33	21D
0005433867888	4781	34	22B
0005433867883	4781	35	22A
0005433867880	4781	36	22C
0005433867858	4781	37	22D
0005433867864	4781	38	23A
0005433867856	4781	39	23B
0005435860441	32612	1	6B
0005435860439	32612	2	18A
0005435860440	32612	3	18B
0005435860438	32612	4	21C
0005434461617	3437	1	1C
0005434663219	3437	2	2A
0005434663218	3437	3	2C
0005434663220	3437	4	2D
0005434663221	3437	5	3C
0005434461615	3437	6	4A
0005434663212	3437	7	4B
0005434663208	3437	8	4C
0005434663207	3437	9	4D
0005434663209	3437	10	5A
0005434663216	3437	11	6D
0005434461616	3437	12	7A
0005434663213	3437	13	18B
0005434460474	3437	14	18C
0005434663217	3437	15	20A
0005434663210	3437	16	21A
0005434663214	3437	17	21B
0005434663215	3437	18	21C
0005434460473	3437	19	22A
0005434663211	3437	20	23A
0005435911341	12446	1	2C
0005435911343	12446	2	3B
0005435911340	12446	3	6C
0005435911345	12446	4	7D
0005435911344	12446	5	18D
0005435911346	12446	6	19C
0005435911342	12446	7	23A
0005435860440	14508	1	1A
0005435860441	14508	2	5A
0005435860438	14508	3	5C
0005435860439	14508	4	19B
0005433867821	32656	1	1A
0005433867814	32656	2	1B
0005433867827	32656	3	1D
0005433867832	32656	4	1C
0005433867831	32656	5	2A
0005433867846	32656	6	2B
0005433867839	32656	7	2C
0005433867833	32656	8	2D
0005433867823	32656	9	3A
0005433867822	32656	10	3B
0005433867834	32656	11	3D
0005433867813	32656	12	4A
0005433867812	32656	13	4D
0005433867836	32656	14	4C
0005433867841	32656	15	5C
0005433867845	32656	16	5D
0005433867818	32656	17	6A
0005433867847	32656	18	6B
0005433867816	32656	19	6C
0005433867844	32656	20	6D
0005433867825	32656	21	7A
0005433867849	32656	22	7B
0005433867842	32656	23	7D
0005433867815	32656	24	18B
0005433867850	32656	25	18C
0005433867837	32656	26	18D
0005433867817	32656	27	19C
0005433867840	32656	28	20A
0005433867830	32656	29	20C
0005433867824	32656	30	20B
0005433867828	32656	31	20D
0005433867820	32656	32	21A
0005433867819	32656	33	21B
0005433867835	32656	34	21C
0005433867843	32656	35	21D
0005433867811	32656	36	22A
0005433867848	32656	37	22B
0005433867838	32656	38	22D
0005433867829	32656	39	23A
0005433867826	32656	40	23B
0005432799030	14786	1	1A
0005432799022	14786	2	1B
0005432799023	14786	3	1C
0005432799028	14786	4	2A
0005432799038	14786	5	2B
0005432799016	14786	6	2C
0005432799018	14786	7	2D
0005432799019	14786	8	3A
0005432799027	14786	9	3C
0005432799013	14786	10	4A
0005432799012	14786	11	4C
0005432799017	14786	12	5B
0005432799039	14786	13	5C
0005432799015	14786	14	5D
0005432799036	14786	15	6B
0005432799031	14786	16	6C
0005432799035	14786	17	7B
0005432799029	14786	18	7D
0005432799026	14786	19	18A
0005432799014	14786	20	18B
0005432799025	14786	21	19D
0005432799032	14786	22	20B
0005432799034	14786	23	20D
0005432799033	14786	24	21A
0005432799021	14786	25	21B
0005432799011	14786	26	22A
0005432799024	14786	27	22C
0005432799037	14786	28	22D
0005432799020	14786	29	23B
0005434406893	7031	1	1C
0005434299217	7031	2	1D
0005434299236	7031	3	2A
0005434299221	7031	4	1F
0005434406849	7031	5	2C
0005434406844	7031	6	2D
0005434406847	7031	7	2F
0005432153840	7031	8	3C
0005432153839	7031	9	3A
0005432108214	7031	10	3F
0005434406861	7031	11	4A
0005434406851	7031	12	4B
0005434406892	7031	13	4D
0005434406855	7031	14	4C
0005434406856	7031	15	5A
0005434299240	7031	16	5C
0005434299233	7031	17	5D
0005434299224	7031	18	5E
0005434406879	7031	19	6B
0005434406833	7031	20	6A
0005434406841	7031	21	6D
0005434299231	7031	22	6C
0005434406846	7031	23	6F
0005434406871	7031	24	7B
0005434406859	7031	25	7A
0005434406887	7031	26	7C
0005434299223	7031	27	7D
0005434406882	7031	28	7E
0005434406832	7031	29	8A
0005434406831	7031	30	7F
0005434406830	7031	31	8B
0005434406888	7031	32	8C
0005434406872	7031	33	9A
0005434406835	7031	34	9C
0005434299226	7031	35	9B
0005432153838	7031	36	9D
0005434406868	7031	37	9F
0005434406848	7031	38	9E
0005434406860	7031	39	10D
0005434406858	7031	40	10C
0005434406836	7031	41	10E
0005434406880	7031	42	11A
0005432153835	7031	43	11B
0005434406864	7031	44	11C
0005434406876	7031	45	11E
0005434299237	7031	46	12A
0005432108213	7031	47	11F
0005434406845	7031	48	12B
0005434406843	7031	49	12C
0005432153842	7031	50	12E
0005434406873	7031	51	13A
0005434406862	7031	52	12F
0005434406854	7031	53	13B
0005434406884	7031	54	13C
0005434406870	7031	55	13D
0005434406866	7031	56	13E
0005434406834	7031	57	14A
0005432153836	7031	58	13F
0005434406875	7031	59	14B
0005432153834	7031	60	14D
0005434406838	7031	61	14F
0005434406878	7031	62	15A
0005434406867	7031	63	15F
0005434299230	7031	64	15E
0005434406869	7031	65	16A
0005434299218	7031	66	16B
0005434299225	7031	67	16C
0005434299232	7031	68	16E
0005434406883	7031	69	16D
0005434406853	7031	70	16F
0005434406857	7031	71	17A
0005434406874	7031	72	17C
0005434406881	7031	73	17D
0005434406886	7031	74	17F
0005432153837	7031	75	18A
0005432153841	7031	76	18B
0005434299234	7031	77	18D
0005434406850	7031	78	18C
0005434406877	7031	79	18F
0005434406840	7031	80	19A
0005434406852	7031	81	19C
0005434406837	7031	82	19D
0005434299229	7031	83	19E
0005434406885	7031	84	20B
0005434299228	7031	85	20C
0005434406865	7031	86	20D
0005434406891	7031	87	20F
0005434406890	7031	88	21A
0005434299220	7031	89	21B
0005434406839	7031	90	21E
0005434299239	7031	91	22A
0005434406894	7031	92	21F
0005434299227	7031	93	22B
0005434406889	7031	94	22C
0005434299238	7031	95	22E
0005434299235	7031	96	23A
0005434406863	7031	97	22F
0005434406842	7031	98	23C
0005434299222	7031	99	23D
0005434299219	7031	100	23E
0005435310880	26889	1	1C
0005435293090	26889	2	1F
0005435293087	26889	3	2A
0005435293092	26889	4	2D
0005435293084	26889	5	3D
0005432058321	26889	6	4E
0005432058324	26889	7	4F
0005435310885	26889	8	5D
0005435310881	26889	9	5E
0005435310890	26889	10	6E
0005435310884	26889	11	6F
0005435310877	26889	12	7B
0005435293083	26889	13	7E
0005435293091	26889	14	8B
0005435310891	26889	15	9A
0005435310886	26889	16	11D
0005432058322	26889	17	11C
0005432058323	26889	18	12C
0005435310879	26889	19	13A
0005435310894	26889	20	13D
0005435293089	26889	21	14B
0005435293093	26889	22	14F
0005435310893	26889	23	15D
0005435310876	26889	24	16B
0005432058320	26889	25	16A
0005435310883	26889	26	16F
0005435310889	26889	27	18C
0005435310892	26889	28	18B
0005435310887	26889	29	19D
0005435293085	26889	30	19E
0005435310882	26889	31	20D
0005435293095	26889	32	20F
0005435293088	26889	33	21A
0005435293086	26889	34	21E
0005435293094	26889	35	21F
0005435310878	26889	36	22F
0005435310888	26889	37	23F
0005434512037	6462	1	1A
0005432603787	6462	2	1B
0005432603803	6462	3	1C
0005432603786	6462	4	2A
0005432603774	6462	5	2B
0005432603780	6462	6	2C
0005432603783	6462	7	2D
0005432603784	6462	8	3A
0005432603773	6462	9	3B
0005432603768	6462	10	3C
0005432603778	6462	11	3D
0005432603770	6462	12	4A
0005432603767	6462	13	4D
0005432603791	6462	14	5B
0005432603775	6462	15	5C
0005432603797	6462	16	5D
0005432603792	6462	17	6A
0005432603795	6462	18	6B
0005432603802	6462	19	6C
0005432603799	6462	20	6D
0005434512036	6462	21	7A
0005432603777	6462	22	7B
0005432603766	6462	23	7C
0005432603781	6462	24	7D
0005432603764	6462	25	18A
0005432603772	6462	26	18B
0005432603800	6462	27	18C
0005432603785	6462	28	19A
0005432603776	6462	29	18D
0005432603789	6462	30	19B
0005432603794	6462	31	19C
0005432603790	6462	32	19D
0005432603771	6462	33	20A
0005432603782	6462	34	20B
0005434512035	6462	35	20C
0005432603798	6462	36	20D
0005432603793	6462	37	21A
0005432603796	6462	38	21B
0005432603763	6462	39	21C
0005432603801	6462	40	22A
0005432603769	6462	41	22B
0005432603779	6462	42	22C
0005432603788	6462	43	22D
0005432603765	6462	44	23B
0005435221038	21339	1	3C
0005435221040	21339	2	6C
0005435221039	21339	3	7D
0005435221502	21339	4	21C
0005435221501	21339	5	22C
0005433251028	15022	1	1F
0005433251050	15022	2	2A
0005433251036	15022	3	2C
0005433251048	15022	4	2D
0005433251030	15022	5	3D
0005433251047	15022	6	4A
0005433251033	15022	7	4F
0005433251039	15022	8	5E
0005433251023	15022	9	5F
0005433251045	15022	10	6A
0005433251038	15022	11	6C
0005433251022	15022	12	7A
0005433251025	15022	13	7E
0005433251049	15022	14	7F
0005433251046	15022	15	8E
0005433251029	15022	16	10A
0005433251041	15022	17	11A
0005433251027	15022	18	12A
0005433251026	15022	19	12D
0005433251051	15022	20	12F
0005433251037	15022	21	13C
0005433251043	15022	22	14F
0005433251034	15022	23	15C
0005433251044	15022	24	16C
0005433251035	15022	25	16D
0005433251024	15022	26	16F
0005433251042	15022	27	17F
0005433251053	15022	28	18C
0005433251031	15022	29	19A
0005433251032	15022	30	19D
0005433251040	15022	31	20A
0005433251052	15022	32	20D
0005434906506	25821	1	1A
0005434906468	25821	2	2D
0005434906483	25821	3	3C
0005434906490	25821	4	3D
0005434906482	25821	5	3F
0005434906498	25821	6	4A
0005434906463	25821	7	4C
0005434906508	25821	8	4D
0005434906515	25821	9	4E
0005434906500	25821	10	4F
0005434906509	25821	11	5A
0005434906469	25821	12	5E
0005434906510	25821	13	5F
0005434906471	25821	14	6A
0005434906476	25821	15	6C
0005434906503	25821	16	6F
0005434906460	25821	17	7C
0005434906487	25821	18	7F
0005434906512	25821	19	8C
0005434906496	25821	20	8D
0005434906505	25821	21	8F
0005434906458	25821	22	9C
0005434906489	25821	23	9D
0005434906462	25821	24	10A
0005434906470	25821	25	9F
0005434906504	25821	26	10C
0005434906465	25821	27	10D
0005434906466	25821	28	10F
0005434906461	25821	29	11D
0005434906457	25821	30	11F
0005434906497	25821	31	12C
0005434906464	25821	32	12F
0005434906474	25821	33	13A
0005434906486	25821	34	13D
0005434906488	25821	35	13F
0005434906481	25821	36	14A
0005434906475	25821	37	14C
0005434906507	25821	38	14D
0005434906511	25821	39	14E
0005434906480	25821	40	14F
0005434906492	25821	41	15A
0005434906479	25821	42	15D
0005434906493	25821	43	15F
0005434906477	25821	44	16D
0005434906485	25821	45	16F
0005434906514	25821	46	17A
0005434906499	25821	47	17C
0005434906473	25821	48	17D
0005434906491	25821	49	17E
0005434906478	25821	50	18A
0005434906467	25821	51	18D
0005434906495	25821	52	18E
0005434906494	25821	53	18F
0005434906501	25821	54	19C
0005434906472	25821	55	19D
0005434906513	25821	56	19E
0005434906502	25821	57	20C
0005434906456	25821	58	20D
0005434906484	25821	59	20E
0005434906459	25821	60	20F
0005432607497	22468	1	1C
0005432609664	22468	2	2B
0005432607500	22468	3	2C
0005432609665	22468	4	3C
0005432607501	22468	5	3D
0005432607495	22468	6	4D
0005432609669	22468	7	5A
0005432609658	22468	8	5B
0005432609663	22468	9	5C
0005432609668	22468	10	6C
0005432607504	22468	11	6D
0005432607505	22468	12	7B
0005432609659	22468	13	7C
0005432607498	22468	14	18A
0005432607502	22468	15	18D
0005432609670	22468	16	19C
0005432609671	22468	17	20A
0005432609667	22468	18	20C
0005432609661	22468	19	20D
0005432607496	22468	20	21A
0005432609662	22468	21	21B
0005432607499	22468	22	21D
0005432607494	22468	23	22B
0005432609660	22468	24	22C
0005432607503	22468	25	22D
0005432609666	22468	26	23B
0005435841461	31727	1	3D
0005435841462	31727	2	4D
0005435841085	31727	3	6D
0005435841463	31727	4	7B
0005435841086	31727	5	7D
0005435841082	31727	6	20D
0005435841464	31727	7	21B
0005435841081	31727	8	21D
0005435841084	31727	9	22C
0005435841083	31727	10	22D
0005433007997	14196	1	1A
0005433007994	14196	2	1C
0005433007990	14196	3	1D
0005433007975	14196	4	2D
0005433007985	14196	5	2F
0005433007988	14196	6	3C
0005433007965	14196	7	3D
0005433007962	14196	8	3F
0005433007974	14196	9	5A
0005433007992	14196	10	5C
0005433007966	14196	11	5D
0005433007995	14196	12	5F
0005433007963	14196	13	6E
0005433007969	14196	14	7C
0005433008004	14196	15	8C
0005433007961	14196	16	8E
0005433007964	14196	17	9A
0005433007968	14196	18	9C
0005433007972	14196	19	9F
0005433007989	14196	20	10C
0005433008000	14196	21	10D
0005433007977	14196	22	10F
0005433007986	14196	23	11A
0005433007993	14196	24	11D
0005433008005	14196	25	11E
0005433007981	14196	26	12A
0005433008003	14196	27	12C
0005433007971	14196	28	12F
0005433007999	14196	29	13C
0005433007984	14196	30	13E
0005433007970	14196	31	14C
0005433007967	14196	32	14E
0005433007987	14196	33	15C
0005433007980	14196	34	16A
0005433007996	14196	35	16C
0005433008006	14196	36	16E
0005433007978	14196	37	16F
0005433007998	14196	38	17A
0005433007979	14196	39	17C
0005433008007	14196	40	17E
0005433007982	14196	41	17F
0005433007976	14196	42	18A
0005433007983	14196	43	18E
0005433008001	14196	44	18F
0005433008002	14196	45	19C
0005433007991	14196	46	20E
0005433007973	14196	47	20F
0005433810493	22856	1	9A
0005433810495	22856	2	9D
0005433810494	22856	3	10F
0005434925322	20516	1	1A
0005434925319	20516	2	1C
0005434925310	20516	3	1F
0005434925315	20516	4	2A
0005434925318	20516	5	2D
0005434925326	20516	6	3A
0005434925325	20516	7	3F
0005434925314	20516	8	5F
0005434925335	20516	9	6A
0005434925307	20516	10	6F
0005434925312	20516	11	7E
0005434925342	20516	12	7F
0005434925339	20516	13	8A
0005434925317	20516	14	8D
0005434925337	20516	15	8C
0005434925334	20516	16	9A
0005434925309	20516	17	9E
0005434925308	20516	18	9F
0005434925338	20516	19	11A
0005434925327	20516	20	11E
0005434925328	20516	21	12C
0005434925341	20516	22	12D
0005434925306	20516	23	13A
0005434925323	20516	24	13C
0005434925311	20516	25	14C
0005434925313	20516	26	14D
0005434925331	20516	27	14F
0005434925321	20516	28	15D
0005434925320	20516	29	15E
0005434925316	20516	30	16A
0005434925336	20516	31	16F
0005434925330	20516	32	17D
0005434925332	20516	33	17E
0005434925329	20516	34	18D
0005434925340	20516	35	19E
0005434925333	20516	36	20C
0005434925324	20516	37	20F
0005435487542	15799	1	1A
0005435487526	15799	2	2C
0005435487531	15799	3	2D
0005435487522	15799	4	3B
0005435487538	15799	5	3A
0005435487525	15799	6	3C
0005435487533	15799	7	3D
0005435487528	15799	8	4A
0005435487535	15799	9	4C
0005435487541	15799	10	5B
0005435487540	15799	11	5C
0005435487530	15799	12	5D
0005435487529	15799	13	6C
0005435487520	15799	14	6D
0005435487534	15799	15	7B
0005435487536	15799	16	18A
0005435487539	15799	17	18D
0005435487532	15799	18	20C
0005435487537	15799	19	20B
0005435487527	15799	20	21A
0005435487521	15799	21	21C
0005435487523	15799	22	21D
0005435487524	15799	23	23A
0005435998992	19721	1	1A
0005435998988	19721	2	1B
0005435998996	19721	3	1C
0005435998991	19721	4	3C
0005435998987	19721	5	6A
0005435998994	19721	6	6B
0005435998990	19721	7	19A
0005435998993	19721	8	20B
0005435998995	19721	9	20C
0005435998998	19721	10	21D
0005435998985	19721	11	22A
0005435998997	19721	12	22B
0005435998986	19721	13	22C
0005435998989	19721	14	23B
0005435839068	5988	1	1F
0005432142210	5988	2	1C
0005435839056	5988	3	2C
0005432659677	5988	4	2A
0005435839047	5988	5	3A
0005435839050	5988	6	4A
0005435472516	5988	7	4C
0005435839065	5988	8	5A
0005435839053	5988	9	4D
0005435839063	5988	10	5F
0005435839055	5988	11	6B
0005432658562	5988	12	6F
0005435839067	5988	13	6E
0005435839062	5988	14	6D
0005435839059	5988	15	8C
0005435839066	5988	16	8B
0005435839069	5988	17	8F
0005435839052	5988	18	9D
0005435839058	5988	19	9F
0005432658563	5988	20	10C
0005435839061	5988	21	10B
0005435839054	5988	22	10E
0005432142206	5988	23	11C
0005432142209	5988	24	11B
0005435839071	5988	25	11A
0005435839060	5988	26	11F
0005435472515	5988	27	13B
0005435839048	5988	28	14C
0005435839064	5988	29	15D
0005435839051	5988	30	16C
0005435839049	5988	31	17A
0005435839057	5988	32	17C
0005435839045	5988	33	17F
0005435839070	5988	34	17E
0005432659678	5988	35	18B
0005435839046	5988	36	18D
0005432142208	5988	37	19C
0005435839072	5988	38	19B
0005432142207	5988	39	19E
0005432660790	5988	40	21D
0005435472573	18048	1	2F
0005435472568	18048	2	3C
0005435472570	18048	3	4C
0005432537028	18048	4	5F
0005435472575	18048	5	6B
0005432537029	18048	6	6C
0005435472578	18048	7	7A
0005435472564	18048	8	8D
0005435472579	18048	9	9A
0005435472562	18048	10	10B
0005435472571	18048	11	11E
0005435472569	18048	12	12B
0005435472574	18048	13	12C
0005435472566	18048	14	12F
0005435472577	18048	15	12E
0005435472567	18048	16	17F
0005435472572	18048	17	18E
0005435472565	18048	18	20D
0005435472563	18048	19	20C
0005435472576	18048	20	21D
0005435103822	23022	1	2D
0005435103821	23022	2	5A
0005435103820	23022	3	8B
0005435103823	23022	4	8E
0005435103819	23022	5	11C
0005435103824	23022	6	14D
0005433284875	32056	1	1D
0005433284855	32056	2	3C
0005433284877	32056	3	4F
0005433284863	32056	4	6D
0005433284873	32056	5	7A
0005433284874	32056	6	7B
0005433284853	32056	7	7F
0005433284865	32056	8	8F
0005433284876	32056	9	9B
0005433284860	32056	10	9E
0005433284861	32056	11	10B
0005433284871	32056	12	11E
0005433284864	32056	13	11F
0005433284850	32056	14	12B
0005433284862	32056	15	13C
0005433284856	32056	16	14B
0005433284849	32056	17	14F
0005433284870	32056	18	15A
0005433284872	32056	19	17B
0005433284878	32056	20	17A
0005433284852	32056	21	17F
0005433284854	32056	22	18D
0005433284851	32056	23	18C
0005433284859	32056	24	18F
0005433284867	32056	25	20A
0005433284858	32056	26	20D
0005433284866	32056	27	21E
0005433284868	32056	28	22A
0005433284869	32056	29	22C
0005433284857	32056	30	22F
0005435852537	23863	1	5B
0005435852536	23863	2	5C
0005435852535	23863	3	7B
0005435852539	23863	4	18A
0005435852534	23863	5	18D
0005435852538	23863	6	20D
0005432211402	30594	1	2A
0005435212656	30594	2	3D
0005435212674	30594	3	3H
0005435212612	30594	4	4D
0005435212664	30594	5	5D
0005432211401	30594	6	11A
0005435212647	30594	7	12C
0005435212644	30594	8	13C
0005435212643	30594	9	13E
0005435212657	30594	10	13K
0005432211400	30594	11	14K
0005435630926	30594	12	14G
0005435725535	30594	13	15C
0005435725534	30594	14	15D
0005435212635	30594	15	15G
0005432211398	30594	16	15K
0005435212648	30594	17	16D
0005435212672	30594	18	16F
0005435212669	30594	19	16H
0005435212621	30594	20	17K
0005435212614	30594	21	18D
0005432159796	30594	22	18K
0005435212624	30594	23	19B
0005435725536	30594	24	19F
0005435212622	30594	25	19J
0005432525896	30594	26	19K
0005434066361	30594	27	20B
0005435212629	30594	28	20D
0005435212630	30594	29	22B
0005435212645	30594	30	22H
0005435212667	30594	31	23E
0005435212671	30594	32	24E
0005435212633	30594	33	24G
0005435212641	30594	34	25H
0005432159797	30594	35	25G
0005435212668	30594	36	26C
0005435212663	30594	37	26G
0005435212628	30594	38	27C
0005435630928	30594	39	28D
0005435212670	30594	40	29A
0005432159793	30594	41	29H
0005433656625	30594	42	29J
0005435212642	30594	43	30D
0005435212655	30594	44	30H
0005435630927	30594	45	31A
0005435212638	30594	46	31D
0005435725532	30594	47	31C
0005435212640	30594	48	31E
0005435212661	30594	49	32B
0005435212660	30594	50	32A
0005435212636	30594	51	32E
0005433656627	30594	52	33H
0005435212631	30594	53	34A
0005435212659	30594	54	33K
0005432159794	30594	55	34B
0005435212616	30594	56	34D
0005435212626	30594	57	34G
0005432159795	30594	58	34F
0005432211399	30594	59	34J
0005435212618	30594	60	35A
0005433656626	30594	61	34K
0005435212650	30594	62	35F
0005432525895	30594	63	35E
0005435212632	30594	64	35G
0005435212619	30594	65	36C
0005435212652	30594	66	36D
0005435212666	30594	67	37G
0005432525694	30594	68	37F
0005435212637	30594	69	37H
0005435212620	30594	70	38B
0005435212608	30594	71	38K
0005435212625	30594	72	39A
0005435725533	30594	73	39D
0005435212673	30594	74	39G
0005435212613	30594	75	40E
0005435212639	30594	76	41A
0005435212665	30594	77	41J
0005435212662	30594	78	41H
0005435212627	30594	79	42D
0005435212615	30594	80	42F
0005435212623	30594	81	43F
0005435212653	30594	82	44F
0005435212611	30594	83	45A
0005435212651	30594	84	44K
0005435212634	30594	85	45E
0005432211403	30594	86	45H
0005432525637	30594	87	46A
0005435212649	30594	88	46J
0005435212607	30594	89	47E
0005435212606	30594	90	47K
0005432525636	30594	91	48G
0005435212617	30594	92	49C
0005435212658	30594	93	48K
0005435212654	30594	94	49E
0005435212610	30594	95	49H
0005432211397	30594	96	50E
0005435212609	30594	97	50D
0005435212646	30594	98	50H
0005433367384	24841	1	1D
0005433367396	24841	2	2D
0005433367374	24841	3	3D
0005433367398	24841	4	3F
0005433367379	24841	5	4F
0005433367377	24841	6	5C
0005433367382	24841	7	5F
0005433367402	24841	8	6A
0005433367381	24841	9	6C
0005433367392	24841	10	6E
0005433367385	24841	11	6F
0005433367394	24841	12	7C
0005433367380	24841	13	9F
0005433367387	24841	14	10A
0005433367373	24841	15	10E
0005433367372	24841	16	11A
0005433367399	24841	17	11F
0005433367401	24841	18	12A
0005433367406	24841	19	12E
0005433367389	24841	20	12F
0005433367395	24841	21	13A
0005433367407	24841	22	13D
0005433367376	24841	23	13E
0005433367393	24841	24	14C
0005433367378	24841	25	14E
0005433367386	24841	26	15C
0005433367388	24841	27	16C
0005433367397	24841	28	16D
0005433367400	24841	29	16F
0005433367408	24841	30	17D
0005433367403	24841	31	18A
0005433367391	24841	32	18C
0005433367383	24841	33	18E
0005433367405	24841	34	18F
0005433367404	24841	35	19D
0005433367409	24841	36	20C
0005433367375	24841	37	20D
0005433367390	24841	38	20F
0005434979404	2057	1	1A
0005434979400	2057	2	1B
0005434979394	2057	3	1C
0005434979389	2057	4	1D
0005434979403	2057	5	2B
0005434979380	2057	6	2C
0005435801657	2057	7	2D
0005434979393	2057	8	3A
0005434979385	2057	9	3B
0005434979399	2057	10	3D
0005434979384	2057	11	4A
0005434979405	2057	12	4C
0005434979401	2057	13	4D
0005434979383	2057	14	5B
0005434979388	2057	15	5C
0005434979375	2057	16	5D
0005434979382	2057	17	6A
0005434979392	2057	18	6D
0005434979387	2057	19	7A
0005434979381	2057	20	7B
0005434979398	2057	21	7D
0005434979386	2057	22	18A
0005434979376	2057	23	18B
0005434979378	2057	24	19A
0005434979395	2057	25	18D
0005434979391	2057	26	19C
0005435801656	2057	27	19D
0005434979406	2057	28	20C
0005434979397	2057	29	21A
0005434979390	2057	30	21B
0005435801655	2057	31	21D
0005434979396	2057	32	22A
0005434979402	2057	33	22B
0005434979379	2057	34	23A
0005434979377	2057	35	23B
0005434952480	2591	1	1B
0005434952481	2591	2	3B
0005434952482	2591	3	5A
0005434952483	2591	4	6B
0005433256391	28225	1	3B
0005433256392	28225	2	5B
0005433111477	19828	1	1A
0005433112356	19828	2	2A
0005433112357	19828	3	2B
0005433111478	19828	4	4A
0005433111476	19828	5	5B
0005434136675	11964	1	3D
0005434136822	11964	2	6F
0005434136723	11964	3	7A
0005434136836	11964	4	12C
0005434136676	11964	5	18D
0005434136821	11964	6	20D
0005434136997	28736	1	1A
0005434137008	28736	2	1C
0005434136978	28736	3	1F
0005434136965	28736	4	2A
0005434136940	28736	5	2C
0005434137004	28736	6	2D
0005434136983	28736	7	2F
0005434136971	28736	8	3A
0005434137007	28736	9	3C
0005434137003	28736	10	3D
0005434136954	28736	11	3F
0005434136947	28736	12	4A
0005434136948	28736	13	4C
0005434136992	28736	14	4D
0005434136964	28736	15	4F
0005434136968	28736	16	5A
0005434136977	28736	17	5C
0005434137011	28736	18	5D
0005434136993	28736	19	5E
0005434136958	28736	20	6A
0005434136946	28736	21	6C
0005434137009	28736	22	6D
0005434136961	28736	23	6E
0005434136974	28736	24	6F
0005434136969	28736	25	7A
0005434136970	28736	26	7C
0005434136975	28736	27	7D
0005434136987	28736	28	7F
0005434137002	28736	29	8A
0005434136986	28736	30	8D
0005434137010	28736	31	8E
0005434137000	28736	32	9A
0005434136943	28736	33	9C
0005434136984	28736	34	9D
0005434137005	28736	35	9E
0005434136963	28736	36	10A
0005434136998	28736	37	10C
0005434136942	28736	38	10D
0005434136960	28736	39	10E
0005434136995	28736	40	11A
0005434136937	28736	41	11C
0005434137012	28736	42	11D
0005434136976	28736	43	11E
0005434136994	28736	44	12A
0005434136991	28736	45	12C
0005434136935	28736	46	12D
0005434136949	28736	47	12E
0005434136955	28736	48	12F
0005434136988	28736	49	13A
0005434136952	28736	50	13F
0005434136999	28736	51	14A
0005434136945	28736	52	14C
0005434136962	28736	53	14D
0005434136973	28736	54	14E
0005434136980	28736	55	14F
0005434136996	28736	56	15A
0005434136951	28736	57	15D
0005434136990	28736	58	16A
0005434136944	28736	59	16C
0005434137013	28736	60	16D
0005434136941	28736	61	16F
0005434136956	28736	62	17A
0005434136989	28736	63	17C
0005434136972	28736	64	17E
0005434136936	28736	65	17F
0005434136950	28736	66	18A
0005434136938	28736	67	18C
0005434137006	28736	68	18D
0005434136959	28736	69	18E
0005434136966	28736	70	18F
0005434136982	28736	71	19A
0005434136957	28736	72	19C
0005434136953	28736	73	19D
0005434136985	28736	74	19E
0005434136979	28736	75	20A
0005434136939	28736	76	20C
0005434137001	28736	77	20D
0005434136981	28736	78	20E
0005434136967	28736	79	20F
0005434466389	6580	1	1B
0005434466395	6580	2	2B
0005434466391	6580	3	3C
0005434466393	6580	4	4A
0005434466396	6580	5	4C
0005434466392	6580	6	5A
0005434466390	6580	7	5B
0005434466394	6580	8	7B
0005434466388	6580	9	18A
0005434466397	6580	10	19D
0005434190369	19090	1	4D
0005434190370	19090	2	5A
0005434190375	19090	3	5B
0005434190373	19090	4	7A
0005434190376	19090	5	7C
0005434190378	19090	6	19B
0005434190372	19090	7	20A
0005434190374	19090	8	20C
0005434190371	19090	9	22C
0005434190377	19090	10	22D
0005433538753	6773	1	1B
0005433534470	6773	2	2D
0005433538755	6773	3	3B
0005433538751	6773	4	4B
0005433538756	6773	5	6A
0005433538752	6773	6	6C
0005433534471	6773	7	7A
0005435259683	6773	8	7D
0005433538757	6773	9	19A
0005433538758	6773	10	20A
0005433538759	6773	11	21A
0005433538754	6773	12	22A
0005433534469	6773	13	23B
0005435259697	24990	1	1C
0005435259696	24990	2	2A
0005435259700	24990	3	2B
0005435259699	24990	4	19A
0005435259698	24990	5	20C
0005433511838	842	1	3A
0005433511841	842	2	4A
0005433511837	842	3	4D
0005433511842	842	4	7A
0005433511836	842	5	7D
0005433511839	842	6	19B
0005433511840	842	7	20B
0005433511843	842	8	21C
0005432922471	16153	1	7C
0005432922472	16153	2	18A
0005432922469	16153	3	20A
0005432922470	16153	4	22A
0005435696973	3698	1	1C
0005435696960	3698	2	2A
0005435696963	3698	3	2B
0005435696966	3698	4	2C
0005435696985	3698	5	2D
0005435696967	3698	6	3A
0005435696961	3698	7	3B
0005435696972	3698	8	3C
0005434950471	3698	9	3D
0005435696965	3698	10	4C
0005435696969	3698	11	5A
0005435696964	3698	12	5C
0005434950470	3698	13	6A
0005434950468	3698	14	6D
0005435696984	3698	15	7A
0005435696958	3698	16	7B
0005435696978	3698	17	7D
0005435696974	3698	18	18A
0005435696971	3698	19	18C
0005435696968	3698	20	18D
0005435696962	3698	21	19B
0005434950469	3698	22	19D
0005435696976	3698	23	20A
0005435696979	3698	24	20B
0005435696983	3698	25	20D
0005435696975	3698	26	21C
0005435696959	3698	27	21D
0005435696980	3698	28	22A
0005435696981	3698	29	22C
0005435696977	3698	30	22D
0005435696970	3698	31	23A
0005435696982	3698	32	23B
0005435916129	16254	1	3B
0005435916131	16254	2	4B
0005435935003	16254	3	20D
0005435916130	16254	4	21B
0005434604851	3950	1	1A
0005433519397	3950	2	1D
0005432607511	3950	3	1C
0005434606780	3950	4	2B
0005434606777	3950	5	2C
0005432607513	3950	6	3A
0005432609676	3950	7	3C
0005434606776	3950	8	4C
0005432609678	3950	9	4D
0005432609679	3950	10	5A
0005432607512	3950	11	5B
0005434604850	3950	12	6B
0005432609680	3950	13	6C
0005434604849	3950	14	6D
0005434606779	3950	15	7C
0005433519398	3950	16	18C
0005433519399	3950	17	19B
0005432607514	3950	18	19D
0005433519395	3950	19	20D
0005434606778	3950	20	21B
0005432607510	3950	21	21D
0005433519396	3950	22	21C
0005432609677	3950	23	22A
0005434606781	3950	24	22B
0005434604853	3950	25	23A
0005434604852	3950	26	23B
0005435841462	22052	1	1A
0005435841461	22052	2	1B
0005435841082	22052	3	1C
0005435841086	22052	4	1D
0005435841085	22052	5	3A
0005435841084	22052	6	5B
0005435841081	22052	7	6B
0005435841464	22052	8	7B
0005435841463	22052	9	21B
0005435841083	22052	10	21C
0005435628680	780	1	1A
0005435628685	780	2	2A
0005435628684	780	3	3A
0005435628681	780	4	4A
0005435628682	780	5	4B
0005435628679	780	6	5B
0005435628683	780	7	6A
0005435628686	780	8	6B
0005433348912	15989	1	1B
0005433348914	15989	2	2B
0005433348911	15989	3	3A
0005433348913	15989	4	4B
0005433348915	15989	5	5A
0005433348910	15989	6	5B
0005434445214	17234	1	3B
0005433159283	17615	1	2B
0005433159284	17615	2	4A
0005433159285	17615	3	6B
0005435132744	7904	1	1B
0005435132738	7904	2	2D
0005435132747	7904	3	4A
0005435132742	7904	4	5B
0005435132741	7904	5	6C
0005435132745	7904	6	7A
0005435132739	7904	7	19B
0005435132746	7904	8	22A
0005435132743	7904	9	22D
0005435132740	7904	10	23B
0005435383078	33101	1	1B
0005435383076	33101	2	2C
0005435383080	33101	3	4B
0005435383081	33101	4	5A
0005435383079	33101	5	5C
0005435383077	33101	6	22D
0005435810996	4416	1	1A
0005435811010	4416	2	4F
0005435811001	4416	3	5D
0005435810999	4416	4	8F
0005435811000	4416	5	9E
0005435811002	4416	6	10E
0005435811009	4416	7	12B
0005435810998	4416	8	14F
0005435810997	4416	9	15A
0005435811004	4416	10	15F
0005435811008	4416	11	16A
0005435811003	4416	12	17F
0005435811007	4416	13	18B
0005435811005	4416	14	19B
0005435811006	4416	15	21E
0005435938852	29446	1	4D
0005435938848	29446	2	4C
0005435938853	29446	3	5F
0005435938849	29446	4	7D
0005435938846	29446	5	8A
0005435938847	29446	6	12C
0005435938851	29446	7	13F
0005435938850	29446	8	18E
0005435160158	7523	1	1A
0005435160157	7523	2	2A
0005435160150	7523	3	2D
0005435160152	7523	4	3C
0005435160159	7523	5	4B
0005435160153	7523	6	7B
0005435160154	7523	7	18B
0005435160156	7523	8	20B
0005435160151	7523	9	22A
0005435160155	7523	10	23A
0005435390146	29550	1	1A
0005435390152	29550	2	1D
0005435390151	29550	3	2C
0005435390148	29550	4	2D
0005435390147	29550	5	6A
0005435390149	29550	6	6B
0005435390145	29550	7	22B
0005435390150	29550	8	23A
0005435178980	18478	1	6A
0005435178979	18478	2	6B
0005432400070	27178	1	1A
0005432398145	27178	2	1B
0005432398142	27178	3	2A
0005432400071	27178	4	2B
0005432398144	27178	5	3A
0005432400072	27178	6	3B
0005432398143	27178	7	6A
0005432400069	27178	8	6B
0005432638961	2240	1	1F
0005432638956	2240	2	2D
0005432638971	2240	3	3F
0005432638969	2240	4	4A
0005432638960	2240	5	4C
0005432638954	2240	6	4E
0005432638968	2240	7	8A
0005432638966	2240	8	8E
0005432638974	2240	9	9D
0005432638970	2240	10	9E
0005432638962	2240	11	10A
0005432638976	2240	12	10D
0005432638958	2240	13	10F
0005432638977	2240	14	11A
0005432638959	2240	15	11D
0005432638953	2240	16	11F
0005432638965	2240	17	12D
0005432638957	2240	18	12C
0005432638975	2240	19	13A
0005432638978	2240	20	14E
0005432638973	2240	21	15C
0005432638964	2240	22	15E
0005432638972	2240	23	16E
0005432638967	2240	24	16F
0005432638955	2240	25	17F
0005432638963	2240	26	18A
0005435103836	6563	1	1F
0005434503633	6563	2	2A
0005434503641	6563	3	2C
0005434503654	6563	4	4E
0005435103828	6563	5	4F
0005435103835	6563	6	5A
0005435103832	6563	7	5C
0005434503644	6563	8	5D
0005434503623	6563	9	6A
0005434503631	6563	10	6D
0005434503643	6563	11	6E
0005434503659	6563	12	6F
0005434503649	6563	13	7A
0005435103834	6563	14	7C
0005434503652	6563	15	7D
0005434503622	6563	16	7E
0005434503634	6563	17	7F
0005434503653	6563	18	8A
0005434503637	6563	19	8E
0005434503638	6563	20	9C
0005434503656	6563	21	9D
0005434503630	6563	22	9E
0005434503645	6563	23	9F
0005434503619	6563	24	10A
0005434503635	6563	25	10C
0005434503651	6563	26	10D
0005434503628	6563	27	10E
0005434503640	6563	28	11E
0005434503620	6563	29	11F
0005434503636	6563	30	12A
0005434503627	6563	31	13A
0005435103829	6563	32	13C
0005434503642	6563	33	13E
0005434503624	6563	34	14A
0005435103837	6563	35	14C
0005435103831	6563	36	14E
0005434503655	6563	37	14F
0005434503646	6563	38	15A
0005434503657	6563	39	15E
0005434503629	6563	40	15F
0005434503647	6563	41	16C
0005434503626	6563	42	16E
0005434503621	6563	43	17A
0005434503658	6563	44	17F
0005434503625	6563	45	18E
0005434503639	6563	46	18F
0005434503632	6563	47	19C
0005434503648	6563	48	19D
0005434503650	6563	49	20A
0005435103833	6563	50	20D
0005435103830	6563	51	20E
0005435652477	1669	1	1C
0005435652451	1669	2	1D
0005435652480	1669	3	2C
0005435652455	1669	4	3A
0005435652473	1669	5	3C
0005435652436	1669	6	3F
0005435652444	1669	7	4C
0005435652456	1669	8	4E
0005435652463	1669	9	5A
0005435652474	1669	10	5C
0005435652476	1669	11	5D
0005435652461	1669	12	5F
0005435652452	1669	13	6D
0005435652454	1669	14	6F
0005435652468	1669	15	7A
0005435652439	1669	16	7D
0005435652458	1669	17	8A
0005435652482	1669	18	8C
0005435652488	1669	19	8D
0005435652450	1669	20	8F
0005435652486	1669	21	9A
0005435652481	1669	22	9C
0005435652443	1669	23	9D
0005435652475	1669	24	9E
0005435652487	1669	25	10A
0005435652478	1669	26	10D
0005435652448	1669	27	10E
0005435652469	1669	28	11D
0005435652471	1669	29	12A
0005435652446	1669	30	12D
0005435652466	1669	31	13A
0005435652438	1669	32	13D
0005435652447	1669	33	14A
0005435652484	1669	34	14D
0005435652457	1669	35	14E
0005435652470	1669	36	14F
0005435652453	1669	37	15E
0005435652441	1669	38	16A
0005435652442	1669	39	16C
0005435652459	1669	40	16D
0005435652449	1669	41	17A
0005435652485	1669	42	17C
0005435652460	1669	43	17E
0005435652462	1669	44	17F
0005435652464	1669	45	18A
0005435652467	1669	46	18F
0005435652440	1669	47	19C
0005435652483	1669	48	19E
0005435652465	1669	49	19F
0005435652479	1669	50	20A
0005435652445	1669	51	20D
0005435652437	1669	52	20E
0005435652472	1669	53	20F
0005433367378	21681	1	1D
0005433367404	21681	2	2A
0005433367388	21681	3	2C
0005433367379	21681	4	3A
0005433367400	21681	5	3C
0005433367408	21681	6	3D
0005433367380	21681	7	4A
0005433367373	21681	8	4C
0005433367398	21681	9	5C
0005433367396	21681	10	5E
0005433367407	21681	11	6C
0005433367389	21681	12	6D
0005433367375	21681	13	6F
0005433367409	21681	14	7D
0005433367381	21681	15	8A
0005433367386	21681	16	8E
0005433367406	21681	17	8F
0005433367399	21681	18	9A
0005433367395	21681	19	9F
0005433367402	21681	20	10D
0005433367377	21681	21	10E
0005433367405	21681	22	10F
0005433367383	21681	23	11C
0005433367382	21681	24	11F
0005433367376	21681	25	12F
0005433367394	21681	26	13D
0005433367391	21681	27	14D
0005433367401	21681	28	14F
0005433367397	21681	29	15C
0005433367387	21681	30	15E
0005433367384	21681	31	16A
0005433367390	21681	32	17A
0005433367372	21681	33	17E
0005433367385	21681	34	18E
0005433367393	21681	35	19A
0005433367374	21681	36	19D
0005433367403	21681	37	19F
0005433367392	21681	38	20D
0005435312774	23228	1	1A
0005435312773	23228	2	1B
0005435312771	23228	3	2A
0005435312772	23228	4	18A
0005435312770	23228	5	20B
0005433985351	4161	1	1C
0005433985320	4161	2	1D
0005433985324	4161	3	2A
0005433985357	4161	4	2C
0005433985334	4161	5	2D
0005433985313	4161	6	3A
0005433985344	4161	7	4A
0005433985311	4161	8	4D
0005433985352	4161	9	4E
0005433985325	4161	10	5A
0005433985328	4161	11	5E
0005433985340	4161	12	5F
0005433985335	4161	13	6D
0005433985345	4161	14	6E
0005433985337	4161	15	7A
0005433985354	4161	16	7C
0005435788736	4161	17	7D
0005433985349	4161	18	7E
0005433985329	4161	19	8A
0005433985339	4161	20	8E
0005433985338	4161	21	9A
0005433985314	4161	22	9C
0005433985331	4161	23	9D
0005433985317	4161	24	10D
0005433985341	4161	25	10F
0005433985348	4161	26	11A
0005433985327	4161	27	11C
0005433985308	4161	28	11D
0005433985326	4161	29	11E
0005433985342	4161	30	11F
0005433985323	4161	31	12E
0005433985336	4161	32	13A
0005433985353	4161	33	13D
0005433985356	4161	34	13E
0005433985318	4161	35	14A
0005433985309	4161	36	14D
0005433985343	4161	37	14E
0005433985316	4161	38	15A
0005433985332	4161	39	15D
0005433985330	4161	40	15F
0005433985333	4161	41	16C
0005433985315	4161	42	16D
0005433985319	4161	43	16E
0005433985346	4161	44	16F
0005433985355	4161	45	17C
0005433985310	4161	46	17F
0005433985312	4161	47	18A
0005433985322	4161	48	18F
0005435788737	4161	49	19A
0005433985350	4161	50	19C
0005433985321	4161	51	19D
0005433985347	4161	52	20A
0005435720120	24774	1	18B
0005435720121	24774	2	20B
0005435719552	24774	3	22C
0005434509033	1622	1	1A
0005434509035	1622	2	1C
0005434509044	1622	3	1D
0005434509038	1622	4	2A
0005434509036	1622	5	2C
0005434509051	1622	6	2D
0005434509043	1622	7	3C
0005434509041	1622	8	3D
0005434509039	1622	9	4C
0005434509032	1622	10	6A
0005434509042	1622	11	7A
0005434509040	1622	12	7B
0005434509045	1622	13	18A
0005434509034	1622	14	19C
0005434509047	1622	15	20A
0005434509037	1622	16	20C
0005434509049	1622	17	20D
0005434509046	1622	18	21A
0005434509050	1622	19	21B
0005434509048	1622	20	21D
0005434509052	1622	21	22C
0005434509031	1622	22	22D
0005432869443	17863	1	6A
0005432869445	17863	2	8E
0005432869444	17863	3	8F
0005432869442	17863	4	9C
0005432869440	17863	5	9D
0005432869439	17863	6	11F
0005432869438	17863	7	12A
0005432869441	17863	8	14E
0005434151668	17863	9	15A
0005434151669	17863	10	17C
0005434151667	17863	11	19A
0005434151666	17863	12	20D
0005432665244	26317	1	1A
0005432657406	26317	2	1C
0005432658561	26317	3	2A
0005432655356	26317	4	3A
0005432655358	26317	5	5D
0005432657404	26317	6	5E
0005432660788	26317	7	6C
0005432667423	26317	8	6D
0005432655359	26317	9	6F
0005432659676	26317	10	7C
0005432655352	26317	11	8F
0005432655361	26317	12	9A
0005432657402	26317	13	10A
0005432667425	26317	14	11E
0005432655350	26317	15	12E
0005432655362	26317	16	12F
0005432655355	26317	17	13E
0005432655357	26317	18	16A
0005432665245	26317	19	15F
0005432655360	26317	20	16C
0005432657403	26317	21	16D
0005432667424	26317	22	16F
0005432659675	26317	23	17A
0005432666358	26317	24	17E
0005432660789	26317	25	17F
0005432658560	26317	26	18E
0005432655351	26317	27	18F
0005432655353	26317	28	19A
0005432657405	26317	29	19E
0005432655354	26317	30	20E
0005432865909	25075	1	3C
0005432865926	25075	2	4C
0005432865927	25075	3	5D
0005432865924	25075	4	5F
0005432865916	25075	5	6C
0005432865918	25075	6	7A
0005432865923	25075	7	8A
0005432865920	25075	8	8D
0005432865914	25075	9	10C
0005432865917	25075	10	10D
0005432865910	25075	11	11D
0005432865925	25075	12	12E
0005432865928	25075	13	12F
0005432865919	25075	14	13C
0005432865912	25075	15	15C
0005432865921	25075	16	15E
0005432865911	25075	17	16F
0005432865915	25075	18	17C
0005432865922	25075	19	19A
0005432865913	25075	20	20F
0005432328092	3091	1	1A
0005432328109	3091	2	1C
0005432328106	3091	3	2C
0005432328094	3091	4	2D
0005432328105	3091	5	2F
0005432328085	3091	6	3C
0005432328091	3091	7	3D
0005432328098	3091	8	3F
0005432328122	3091	9	4C
0005432328124	3091	10	4E
0005432328096	3091	11	5C
0005432328123	3091	12	5F
0005432328116	3091	13	6A
0005432328097	3091	14	6C
0005432905023	3091	15	6D
0005432328078	3091	16	6E
0005432287121	3091	17	7E
0005432328110	3091	18	8A
0005432328115	3091	19	8C
0005432328083	3091	20	8D
0005433438787	3091	21	8E
0005432328121	3091	22	8F
0005433438795	3091	23	9A
0005432287122	3091	24	9C
0005432328087	3091	25	9E
0005432287123	3091	26	10C
0005432328080	3091	27	10D
0005432328103	3091	28	10E
0005432328090	3091	29	10F
0005433438789	3091	30	11C
0005432328084	3091	31	11D
0005432328100	3091	32	11E
0005432287124	3091	33	11F
0005432328099	3091	34	12C
0005432328102	3091	35	12D
0005432328104	3091	36	12E
0005433438793	3091	37	13A
0005433438792	3091	38	13C
0005432328095	3091	39	13D
0005432328086	3091	40	13E
0005432328088	3091	41	13F
0005433438786	3091	42	14A
0005433438791	3091	43	14D
0005432328120	3091	44	14E
0005432328119	3091	45	15A
0005433438788	3091	46	15C
0005432328113	3091	47	15D
0005432328089	3091	48	15E
0005432328114	3091	49	16C
0005433438785	3091	50	16D
0005432328112	3091	51	16E
0005432287120	3091	52	17D
0005432328093	3091	53	17E
0005432328111	3091	54	18C
0005432328082	3091	55	18D
0005432328079	3091	56	18E
0005433438790	3091	57	19A
0005432328117	3091	58	19C
0005432328108	3091	59	19D
0005432328118	3091	60	19E
0005432328081	3091	61	19F
0005432328107	3091	62	20C
0005433438794	3091	63	20E
0005432328101	3091	64	20F
0005432327914	31118	1	1C
0005432905046	31118	2	2D
0005432905044	31118	3	3A
0005432905047	31118	4	5E
0005432054266	31118	5	6A
0005432054264	31118	6	6C
0005432905042	31118	7	7A
0005432054265	31118	8	10A
0005432905043	31118	9	10C
0005432905048	31118	10	11A
0005432905045	31118	11	20D
0005435999019	6205	1	1F
0005434309567	6205	2	1D
0005435999021	6205	3	2C
0005435999034	6205	4	4A
0005434309564	6205	5	4D
0005435999023	6205	6	5A
0005435999020	6205	7	5F
0005435999025	6205	8	6E
0005435999027	6205	9	6D
0005434309558	6205	10	6F
0005432146172	6205	11	8D
0005432146174	6205	12	9B
0005435999022	6205	13	9C
0005434309562	6205	14	9E
0005434309569	6205	15	11D
0005432146171	6205	16	11F
0005435999014	6205	17	11E
0005435999018	6205	18	12C
0005434309556	6205	19	12F
0005435999026	6205	20	13C
0005434309560	6205	21	13B
0005435999017	6205	22	13F
0005434309566	6205	23	14C
0005435999029	6205	24	15A
0005434309557	6205	25	15D
0005435999028	6205	26	15E
0005432146173	6205	27	16A
0005435999016	6205	28	15F
0005435999033	6205	29	16B
0005434309559	6205	30	17E
0005435999030	6205	31	19A
0005435999015	6205	32	19C
0005434309565	6205	33	19D
0005435999032	6205	34	20C
0005435999031	6205	35	20F
0005435999013	6205	36	21C
0005434309568	6205	37	21E
0005435999024	6205	38	22F
0005434309561	6205	39	23B
0005434309563	6205	40	23E
0005435487536	19546	1	1D
0005435487527	19546	2	1F
0005435487530	19546	3	2D
0005435296968	19546	4	6B
0005435487540	19546	5	7C
0005435296971	19546	6	7E
0005435487528	19546	7	8C
0005435487537	19546	8	9B
0005435296970	19546	9	9E
0005435296969	19546	10	10B
0005435296967	19546	11	10E
0005435487521	19546	12	11B
0005435487538	19546	13	11E
0005435487531	19546	14	13D
0005435487535	19546	15	15B
0005435487524	19546	16	15D
0005435296965	19546	17	15E
0005435487532	19546	18	16F
0005435487542	19546	19	18A
0005435487523	19546	20	18D
0005435487533	19546	21	18E
0005435296966	19546	22	20B
0005435487534	19546	23	20D
0005435487541	19546	24	21A
0005435487529	19546	25	21E
0005435487525	19546	26	21F
0005435487539	19546	27	22E
0005435487522	19546	28	23B
0005435487526	19546	29	23D
0005435487520	19546	30	23E
0005433158102	17539	1	1A
0005433158101	17539	2	6D
0005433158100	17539	3	19A
0005433158103	17539	4	21D
0005433158099	17539	5	23B
0005434565736	1552	1	1C
0005434565744	1552	2	1F
0005435502039	1552	3	2A
0005435517675	1552	4	2C
0005432291899	1552	5	2F
0005435502034	1552	6	3C
0005435502024	1552	7	3F
0005435502028	1552	8	4A
0005435517670	1552	9	4C
0005435502031	1552	10	4D
0005435517687	1552	11	4F
0005435517684	1552	12	5D
0005434565739	1552	13	5E
0005435502036	1552	14	5F
0005435517677	1552	15	6A
0005435517683	1552	16	6C
0005435508210	1552	17	6E
0005435502026	1552	18	6F
0005435517679	1552	19	7A
0005435502023	1552	20	7C
0005435508212	1552	21	7D
0005435502021	1552	22	7E
0005435508215	1552	23	7F
0005435517676	1552	24	8C
0005435517673	1552	25	8D
0005435517674	1552	26	8E
0005435517672	1552	27	8F
0005435508213	1552	28	9C
0005432291898	1552	29	9E
0005434565734	1552	30	9F
0005435508217	1552	31	10D
0005435517671	1552	32	10E
0005435502027	1552	33	11A
0005435517681	1552	34	11E
0005435508214	1552	35	11F
0005435502025	1552	36	12A
0005434565742	1552	37	12C
0005435502032	1552	38	12E
0005435502041	1552	39	12F
0005435508211	1552	40	13A
0005435517678	1552	41	13C
0005435517685	1552	42	13D
0005435508219	1552	43	13E
0005435502035	1552	44	13F
0005435508218	1552	45	14A
0005435502038	1552	46	14C
0005434565743	1552	47	14D
0005434565745	1552	48	14E
0005435508220	1552	49	14F
0005435502029	1552	50	15A
0005435517686	1552	51	15D
0005435502037	1552	52	15E
0005435517682	1552	53	15F
0005435517669	1552	54	16A
0005435517668	1552	55	16C
0005435502030	1552	56	16D
0005435517680	1552	57	17A
0005435508221	1552	58	17C
0005434565740	1552	59	17D
0005434565737	1552	60	17E
0005435508216	1552	61	17F
0005434565741	1552	62	18A
0005435502033	1552	63	18D
0005435517688	1552	64	18F
0005433185968	1552	65	19D
0005434565735	1552	66	19E
0005435502040	1552	67	19F
0005434565738	1552	68	20A
0005435502022	1552	69	20F
0005433186007	20856	1	4E
0005433186008	20856	2	5E
0005433186010	20856	3	7C
0005433186009	20856	4	10E
0005433186005	20856	5	11A
0005433186004	20856	6	11E
0005433186006	20856	7	18F
0005435153656	3918	1	2D
0005435153657	3918	2	3C
0005435153655	3918	3	5C
0005435153658	3918	4	6A
0005435153653	3918	5	19C
0005435153654	3918	6	21A
0005435931553	21852	1	18B
0005435931552	21852	2	23B
0005432628660	7202	1	1A
0005432628653	7202	2	2A
0005432628650	7202	3	2C
0005432628655	7202	4	2D
0005432628657	7202	5	3A
0005432628648	7202	6	3D
0005432628654	7202	7	5D
0005432628656	7202	8	18D
0005432628647	7202	9	20A
0005432628649	7202	10	20B
0005432628651	7202	11	20C
0005432628658	7202	12	20D
0005432628652	7202	13	21B
0005432628659	7202	14	23B
0005435225482	28131	1	1C
0005435225480	28131	2	2D
0005435225477	28131	3	3A
0005435225476	28131	4	3C
0005435225478	28131	5	6B
0005435225481	28131	6	18D
0005432628585	28131	7	20A
0005435225479	28131	8	22B
0005435225475	28131	9	22D
0005435960000	8744	1	7B
0005435960001	8744	2	20B
0005435959998	8744	3	21A
0005435959999	8744	4	23B
0005434267901	15259	1	1C
0005434267899	15259	2	7A
0005434267900	15259	3	21B
0005432674936	1198	1	1A
0005432692645	1198	2	2A
0005432692623	1198	3	1F
0005432674938	1198	4	2D
0005432692639	1198	5	3D
0005432692648	1198	6	3C
0005432674930	1198	7	3F
0005432674937	1198	8	5D
0005432692651	1198	9	5C
0005432677516	1198	10	5A
0005432692642	1198	11	6B
0005432677515	1198	12	6E
0005432692636	1198	13	6F
0005432692634	1198	14	7C
0005432692630	1198	15	7B
0005432674926	1198	16	7F
0005432692622	1198	17	8D
0005432692647	1198	18	9B
0005432692635	1198	19	9E
0005432692649	1198	20	10B
0005432674924	1198	21	9F
0005432692628	1198	22	10E
0005432674933	1198	23	10F
0005432674925	1198	24	11B
0005432692643	1198	25	11A
0005432692640	1198	26	11F
0005432692646	1198	27	11E
0005432692631	1198	28	12A
0005432692650	1198	29	12F
0005432677517	1198	30	13A
0005432677519	1198	31	13D
0005432674931	1198	32	15A
0005432674932	1198	33	14F
0005432692629	1198	34	15B
0005432692625	1198	35	15D
0005432692652	1198	36	16A
0005432692633	1198	37	15F
0005432692632	1198	38	16C
0005432674927	1198	39	16B
0005432674929	1198	40	16D
0005432692624	1198	41	16F
0005432692644	1198	42	17B
0005432677518	1198	43	17D
0005432674928	1198	44	17F
0005432674935	1198	45	18E
0005432692626	1198	46	19A
0005432692641	1198	47	19F
0005432692627	1198	48	20F
0005432692637	1198	49	20E
0005432674934	1198	50	21D
0005432692638	1198	51	21C
0005432873197	17482	1	5D
0005432873201	17482	2	9E
0005432873196	17482	3	15B
0005432873199	17482	4	16E
0005432873200	17482	5	17A
0005432873198	17482	6	19A
0005434434983	1143	1	1D
0005434434972	1143	2	2C
0005434434980	1143	3	2D
0005434434982	1143	4	5A
0005434434976	1143	5	5C
0005434434974	1143	6	6C
0005434434977	1143	7	7C
0005434434978	1143	8	7D
0005434434975	1143	9	18A
0005434434984	1143	10	18D
0005434434971	1143	11	19A
0005434434986	1143	12	19B
0005434434979	1143	13	19C
0005434434981	1143	14	20A
0005434434985	1143	15	21A
0005434434973	1143	16	21D
0005433156638	17300	1	2C
0005433156637	17300	2	4C
0005433156631	17300	3	5A
0005433156639	17300	4	7A
0005433156634	17300	5	7D
0005433156632	17300	6	18B
0005433156635	17300	7	19B
0005433156633	17300	8	20C
0005433156636	17300	9	20D
0005435086737	4057	1	1A
0005435086735	4057	2	2B
0005435086734	4057	3	3B
0005435086733	4057	4	3D
0005435086738	4057	5	4C
0005435086732	4057	6	20A
0005435928061	4057	7	20B
0005435086731	4057	8	22A
0005435086736	4057	9	22D
0005435928081	24426	1	1D
0005435928080	24426	2	4B
0005435928079	24426	3	6D
0005435928078	24426	4	7A
0005435706171	2442	1	3C
0005435706153	2442	2	4C
0005435706168	2442	3	5A
0005435706147	2442	4	5C
0005435706149	2442	5	6E
0005435706145	2442	6	6F
0005435706164	2442	7	8A
0005435706172	2442	8	8C
0005435706157	2442	9	9C
0005435706165	2442	10	9D
0005435706146	2442	11	9E
0005435706158	2442	12	10A
0005435706148	2442	13	10C
0005435706170	2442	14	10E
0005435706152	2442	15	10F
0005435706167	2442	16	11A
0005435706174	2442	17	12C
0005435706166	2442	18	13C
0005435706156	2442	19	13E
0005435706177	2442	20	14A
0005435706175	2442	21	14D
0005435706151	2442	22	15D
0005435706169	2442	23	16C
0005435706154	2442	24	16D
0005435706176	2442	25	16F
0005435706163	2442	26	17A
0005435706150	2442	27	17D
0005435706180	2442	28	17E
0005435706161	2442	29	17F
0005435706179	2442	30	18A
0005435706159	2442	31	18E
0005435706155	2442	32	18F
0005435706178	2442	33	19C
0005435706173	2442	34	19D
0005435706160	2442	35	20A
0005435706162	2442	36	20C
0005433373417	27025	1	2F
0005433373408	27025	2	3F
0005433373410	27025	3	6D
0005433373413	27025	4	8A
0005433373409	27025	5	10E
0005433373414	27025	6	10F
0005433373419	27025	7	11D
0005433373406	27025	8	12D
0005433373404	27025	9	13E
0005433373405	27025	10	14E
0005433373412	27025	11	15C
0005433373415	27025	12	15E
0005433373407	27025	13	16A
0005433373416	27025	14	17A
0005433373403	27025	15	17E
0005433373418	27025	16	19E
0005433373411	27025	17	20E
0005434963989	1322	1	1A
0005434963948	1322	2	1F
0005434963965	1322	3	1G
0005434963952	1322	4	2B
0005434963953	1322	5	2H
0005434963958	1322	6	3A
0005434963959	1322	7	3C
0005434963957	1322	8	3B
0005434963937	1322	9	3F
0005434963943	1322	10	3G
0005434963980	1322	11	4A
0005434963988	1322	12	4C
0005434963935	1322	13	4H
0005434963971	1322	14	5A
0005434963968	1322	15	5G
0005434963940	1322	16	5F
0005434963941	1322	17	9A
0005433261392	1322	18	9G
0005434963950	1322	19	11B
0005434963939	1322	20	11D
0005434963949	1322	21	11E
0005434963990	1322	22	11H
0005434963983	1322	23	12B
0005434963961	1322	24	12F
0005434963967	1322	25	13D
0005434963966	1322	26	13G
0005434963991	1322	27	13F
0005434963981	1322	28	14A
0005434963987	1322	29	14E
0005434963955	1322	30	15F
0005434963947	1322	31	15H
0005434963954	1322	32	16A
0005434963969	1322	33	16B
0005432279240	1322	34	17D
0005434963936	1322	35	17E
0005434963973	1322	36	18B
0005434963938	1322	37	18A
0005434963972	1322	38	18E
0005433261393	1322	39	18H
0005434963986	1322	40	19D
0005432279244	1322	41	20E
0005434963978	1322	42	21B
0005432279242	1322	43	22B
0005434963985	1322	44	22H
0005434963979	1322	45	24E
0005434963946	1322	46	24G
0005434963944	1322	47	25D
0005434963984	1322	48	25F
0005434963960	1322	49	28G
0005434963982	1322	50	28F
0005434963942	1322	51	29E
0005434963934	1322	52	29G
0005434963977	1322	53	29H
0005434963945	1322	54	30B
0005434963951	1322	55	31E
0005434963974	1322	56	31G
0005434963963	1322	57	32D
0005432279239	1322	58	32B
0005434963975	1322	59	32G
0005434963976	1322	60	33A
0005434963962	1322	61	33D
0005434963956	1322	62	34A
0005434963964	1322	63	35A
0005432279241	1322	64	35G
0005432279243	1322	65	36A
0005434963970	1322	66	38H
0005434625838	4871	1	2A
0005434625834	4871	2	2F
0005434625836	4871	3	4A
0005434625833	4871	4	6D
0005434625841	4871	5	6E
0005434625840	4871	6	9A
0005434625835	4871	7	12A
0005434625839	4871	8	17A
0005434625837	4871	9	18A
0005435907440	32883	1	1C
0005435907443	32883	2	2C
0005435907438	32883	3	5C
0005435907439	32883	4	7F
0005435907441	32883	5	8C
0005433194827	32883	6	12C
0005433194826	32883	7	15A
0005435907442	32883	8	16F
0005434625811	32883	9	19D
0005432195666	13772	1	1D
0005432195665	13772	2	20A
0005432195664	13772	3	20D
0005435784847	27398	1	1A
0005435784867	27398	2	1B
0005435784862	27398	3	1C
0005435784834	27398	4	1D
0005435784856	27398	5	2A
0005435784860	27398	6	2C
0005435784843	27398	7	2D
0005435784844	27398	8	3B
0005435784837	27398	9	3C
0005435784852	27398	10	3D
0005435784838	27398	11	4A
0005435784849	27398	12	4B
0005435784853	27398	13	4C
0005435784848	27398	14	4D
0005432190571	27398	15	5A
0005435784836	27398	16	5B
0005432190574	27398	17	5C
0005432190572	27398	18	5D
0005435784855	27398	19	6A
0005435784864	27398	20	6C
0005435784866	27398	21	6B
0005435784840	27398	22	7A
0005435784854	27398	23	7B
0005435784835	27398	24	7D
0005435784841	27398	25	18A
0005435784857	27398	26	18B
0005435784845	27398	27	18C
0005435784851	27398	28	18D
0005432190573	27398	29	19B
0005435784863	27398	30	20C
0005435784846	27398	31	20D
0005435784858	27398	32	21A
0005435784859	27398	33	21B
0005435784865	27398	34	21C
0005435784850	27398	35	21D
0005435784868	27398	36	22A
0005435784839	27398	37	22C
0005435784861	27398	38	22D
0005435784842	27398	39	23A
0005435310924	20280	1	1C
0005435310925	20280	2	1F
0005435310923	20280	3	2A
0005435310917	20280	4	4A
0005435310928	20280	5	4D
0005434406691	20280	6	5A
0005434406690	20280	7	6D
0005435310908	20280	8	6E
0005435310921	20280	9	7F
0005435310914	20280	10	8C
0005434406673	20280	11	8D
0005435310909	20280	12	9C
0005435310926	20280	13	9F
0005435310912	20280	14	10C
0005435310920	20280	15	10E
0005435310929	20280	16	11E
0005435310927	20280	17	12F
0005435310911	20280	18	13A
0005435310918	20280	19	13C
0005435310915	20280	20	13D
0005435310913	20280	21	13E
0005432058328	20280	22	14C
0005435310919	20280	23	14E
0005435310906	20280	24	14F
0005432058330	20280	25	15F
0005435310916	20280	26	16C
0005432058329	20280	27	16E
0005435310910	20280	28	16F
0005435310922	20280	29	18A
0005435310907	20280	30	18D
0005434406799	20280	31	19A
0005432058331	20280	32	19C
0005432153847	26988	1	1A
0005434406945	26988	2	1D
0005432153849	26988	3	1F
0005434406906	26988	4	2A
0005434406957	26988	5	2D
0005434406938	26988	6	2F
0005434406902	26988	7	3C
0005434406949	26988	8	3D
0005434406922	26988	9	4C
0005434406921	26988	10	4D
0005434406948	26988	11	4E
0005434406934	26988	12	4F
0005434406933	26988	13	5A
0005434406897	26988	14	5C
0005434406907	26988	15	5D
0005434406905	26988	16	5E
0005434406932	26988	17	5F
0005434406952	26988	18	6A
0005434406939	26988	19	6C
0005434406940	26988	20	6D
0005432153848	26988	21	6F
0005434406942	26988	22	7C
0005432153843	26988	23	7D
0005434406911	26988	24	7E
0005434406899	26988	25	7F
0005434406908	26988	26	8C
0005432153844	26988	27	8D
0005434406924	26988	28	8E
0005434406951	26988	29	8F
0005434406943	26988	30	9A
0005434406955	26988	31	9C
0005434406904	26988	32	9D
0005434406916	26988	33	9E
0005434406910	26988	34	9F
0005432153845	26988	35	10A
0005434406898	26988	36	10C
0005434406944	26988	37	10D
0005434406920	26988	38	10E
0005434406918	26988	39	10F
0005434406913	26988	40	11C
0005434406930	26988	41	11E
0005434406926	26988	42	11F
0005434406954	26988	43	12A
0005434406936	26988	44	12D
0005434406917	26988	45	12E
0005434406901	26988	46	12F
0005434406958	26988	47	13A
0005434406941	26988	48	13C
0005434406928	26988	49	13D
0005434406896	26988	50	13E
0005434406929	26988	51	14A
0005434406903	26988	52	14E
0005434406909	26988	53	14F
0005434406956	26988	54	15D
0005434406953	26988	55	16A
0005434406950	26988	56	16C
0005434406900	26988	57	16D
0005434406923	26988	58	16F
0005434406895	26988	59	17A
0005432153846	26988	60	17C
0005434406937	26988	61	17D
0005434406915	26988	62	17E
0005434406927	26988	63	17F
0005434406925	26988	64	18A
0005434406946	26988	65	18D
0005434406947	26988	66	18E
0005434406935	26988	67	19E
0005434406914	26988	68	19F
0005434406919	26988	69	20C
0005434406912	26988	70	20D
0005434406931	26988	71	20E
0005434319198	5679	1	1D
0005434319201	5679	2	2A
0005434319195	5679	3	2D
0005434319197	5679	4	5D
0005434319202	5679	5	5F
0005434319206	5679	6	7C
0005434319203	5679	7	7F
0005434311189	5679	8	9A
0005434319200	5679	9	9F
0005434319193	5679	10	10A
0005434319194	5679	11	11A
0005434319205	5679	12	11D
0005434319199	5679	13	12C
0005434319209	5679	14	12D
0005434319208	5679	15	13F
0005434319207	5679	16	15D
0005434319204	5679	17	17A
0005434311190	5679	18	19A
0005434319196	5679	19	20A
0005433123672	15697	1	1C
0005433123661	15697	2	4C
0005433123675	15697	3	5F
0005433123671	15697	4	6A
0005433123658	15697	5	6F
0005433123670	15697	6	8A
0005433123667	15697	7	8C
0005433123677	15697	8	8D
0005433123660	15697	9	8F
0005433123674	15697	10	9E
0005433123676	15697	11	9F
0005433123668	15697	12	10E
0005433123663	15697	13	11D
0005433123664	15697	14	11E
0005433123666	15697	15	13E
0005433123678	15697	16	13F
0005433123673	15697	17	14C
0005433123669	15697	18	14D
0005433123657	15697	19	15F
0005433123659	15697	20	18D
0005433123662	15697	21	18F
0005433123656	15697	22	19C
0005433123665	15697	23	19D
0005435219171	31742	1	3A
0005435220293	31742	2	5C
0005435219174	31742	3	6D
0005435219173	31742	4	7C
0005435220294	31742	5	19B
0005435220291	31742	6	19C
0005435219172	31742	7	20A
0005435220292	31742	8	21B
0005434484263	8976	1	1C
0005434484262	8976	2	2B
0005434484260	8976	3	3C
0005434484258	8976	4	4C
0005434484259	8976	5	18C
0005434484264	8976	6	18D
0005434484261	8976	7	19C
0005434189099	16625	1	4C
0005434189100	16625	2	4D
0005434189104	16625	3	7C
0005434189101	16625	4	18D
0005434189103	16625	5	20C
0005434189102	16625	6	22B
0005433123666	7633	1	1C
0005433123661	7633	2	2A
0005433123674	7633	3	3D
0005433123657	7633	4	3F
0005433123673	7633	5	4E
0005433123672	7633	6	4F
0005433123671	7633	7	6D
0005433123662	7633	8	6E
0005433123659	7633	9	8A
0005433123678	7633	10	10A
0005433123677	7633	11	10C
0005433123658	7633	12	10D
0005433123665	7633	13	12A
0005433123660	7633	14	13C
0005433123669	7633	15	13E
0005433123670	7633	16	14D
0005433123667	7633	17	14E
0005433123656	7633	18	16F
0005433123675	7633	19	17A
0005433123663	7633	20	17D
0005433123668	7633	21	19A
0005433123676	7633	22	19E
0005433123664	7633	23	20A
0005432692656	7640	1	1A
0005433449678	7640	2	1C
0005432692664	7640	3	1D
0005433449672	7640	4	1F
0005432720545	7640	5	2A
0005432720547	7640	6	2C
0005432692666	7640	7	2D
0005432692679	7640	8	2F
0005432692684	7640	9	3A
0005432692682	7640	10	3C
0005433449694	7640	11	3D
0005432692657	7640	12	3F
0005432720554	7640	13	4A
0005432071534	7640	14	4C
0005432692676	7640	15	4D
0005432720542	7640	16	4E
0005432692675	7640	17	4F
0005432692655	7640	18	5A
0005432720541	7640	19	5C
0005432692677	7640	20	5D
0005433449679	7640	21	5E
0005432720556	7640	22	5F
0005432720552	7640	23	6A
0005432071533	7640	24	6C
0005432692683	7640	25	6E
0005432720546	7640	26	6F
0005432720561	7640	27	7A
0005432692658	7640	28	7C
0005432692678	7640	29	7D
0005432720543	7640	30	7E
0005432692673	7640	31	7F
0005433449693	7640	32	8A
0005433449674	7640	33	8C
0005432692667	7640	34	8D
0005433449690	7640	35	9A
0005432692661	7640	36	9C
0005432720549	7640	37	9D
0005432692668	7640	38	9E
0005432720563	7640	39	9F
0005432720560	7640	40	10A
0005432692659	7640	41	10C
0005432720553	7640	42	10D
0005432692685	7640	43	10E
0005432720558	7640	44	10F
0005432692663	7640	45	11A
0005432071535	7640	46	11C
0005432720557	7640	47	11D
0005432692654	7640	48	11E
0005433449687	7640	49	11F
0005432720550	7640	50	12A
0005432692671	7640	51	12C
0005433449685	7640	52	12D
0005432692672	7640	53	12E
0005432720564	7640	54	12F
0005432692660	7640	55	13A
0005432720548	7640	56	13D
0005433449684	7640	57	14A
0005432720539	7640	58	14E
0005432720544	7640	59	14F
0005432720551	7640	60	15A
0005433449673	7640	61	15C
0005432692681	7640	62	15D
0005433449683	7640	63	15E
0005433449677	7640	64	15F
0005433449686	7640	65	16A
0005433449692	7640	66	16D
0005433449676	7640	67	16E
0005432720559	7640	68	16F
0005433449688	7640	69	17A
0005432720555	7640	70	17C
0005432692662	7640	71	17D
0005432692665	7640	72	17E
0005432692653	7640	73	17F
0005433449682	7640	74	18C
0005433449691	7640	75	18D
0005433449681	7640	76	18E
0005433449689	7640	77	18F
0005433449680	7640	78	19A
0005432692674	7640	79	19C
0005432692670	7640	80	19D
0005432692669	7640	81	19E
0005432692680	7640	82	19F
0005432720562	7640	83	20A
0005432720540	7640	84	20C
0005432071536	7640	85	20D
0005432720538	7640	86	20E
0005433449675	7640	87	20F
0005432720467	30415	1	1F
0005433722131	30415	2	11F
0005433722130	30415	3	13F
0005433722128	30415	4	14C
0005433722129	30415	5	16A
0005434586277	1395	1	1A
0005434586269	1395	2	1F
0005434586275	1395	3	2C
0005434586284	1395	4	2D
0005434586265	1395	5	2F
0005434586273	1395	6	3C
0005434586271	1395	7	3D
0005433192825	1395	8	3F
0005433524894	1395	9	4A
0005433524899	1395	10	4E
0005434586266	1395	11	4F
0005433524891	1395	12	5F
0005433724747	1395	13	6C
0005434513544	1395	14	6E
0005434586263	1395	15	7A
0005433524898	1395	16	7C
0005434586270	1395	17	8A
0005434586281	1395	18	8F
0005433524896	1395	19	9A
0005434513545	1395	20	9D
0005434586278	1395	21	9F
0005434586264	1395	22	10A
0005434586280	1395	23	10C
0005434586268	1395	24	10E
0005434586282	1395	25	10F
0005434586274	1395	26	11A
0005433524893	1395	27	12C
0005434586285	1395	28	12D
0005434586262	1395	29	13C
0005433524895	1395	30	13D
0005433524900	1395	31	13F
0005434586267	1395	32	14A
0005434513543	1395	33	14C
0005434586286	1395	34	14D
0005434586276	1395	35	14E
0005432270967	1395	36	14F
0005434586283	1395	37	15C
0005433192815	1395	38	15D
0005434513546	1395	39	15E
0005433724745	1395	40	15F
0005433724744	1395	41	16A
0005434586287	1395	42	16C
0005433524890	1395	43	16D
0005434586272	1395	44	17C
0005434586279	1395	45	17D
0005434514932	1395	46	18D
0005433524892	1395	47	18E
0005433524897	1395	48	19C
0005434514933	1395	49	19D
0005433724743	1395	50	19E
0005432270966	1395	51	20A
0005433724746	1395	52	20D
0005433192873	18530	1	2D
0005432927903	18530	2	3D
0005432927908	18530	3	5D
0005433192871	18530	4	6C
0005433192874	18530	5	7D
0005434586208	18530	6	7E
0005433192875	18530	7	8C
0005433192866	18530	8	8D
0005433192869	18530	9	8E
0005432927905	18530	10	9F
0005433192865	18530	11	10D
0005433192870	18530	12	10F
0005432927904	18530	13	11F
0005432927907	18530	14	13D
0005433192867	18530	15	14F
0005432968809	18530	16	15C
0005433192872	18530	17	16E
0005433192876	18530	18	16F
0005432968808	18530	19	17D
0005432927906	18530	20	17F
0005433192864	18530	21	18F
0005434586168	18530	22	19E
0005432968810	18530	23	20A
0005433192868	18530	24	20E
0005434343698	11458	1	1A
0005434343687	11458	2	1B
0005434343701	11458	3	1C
0005434343700	11458	4	1D
0005434343705	11458	5	2A
0005434343689	11458	6	2B
0005434343691	11458	7	2C
0005434142559	11458	8	2D
0005434343697	11458	9	3B
0005434343696	11458	10	3D
0005434343713	11458	11	4A
0005434343686	11458	12	4B
0005434343716	11458	13	4C
0005434343721	11458	14	5A
0005434343718	11458	15	5C
0005434343724	11458	16	5D
0005434343710	11458	17	6A
0005434343704	11458	18	6B
0005434343690	11458	19	6D
0005434343723	11458	20	7A
0005434343715	11458	21	7B
0005434142560	11458	22	7C
0005434343714	11458	23	7D
0005434343717	11458	24	18A
0005434142556	11458	25	18B
0005434343703	11458	26	18C
0005434343708	11458	27	19A
0005434343720	11458	28	19B
0005434343709	11458	29	19C
0005434343719	11458	30	19D
0005434343702	11458	31	20A
0005434142557	11458	32	20B
0005434343692	11458	33	20C
0005434343722	11458	34	20D
0005434343694	11458	35	21A
0005434142558	11458	36	21B
0005434343695	11458	37	21C
0005434343693	11458	38	21D
0005434343699	11458	39	22A
0005434343706	11458	40	22B
0005434343711	11458	41	22C
0005434343688	11458	42	22D
0005434343712	11458	43	23A
0005434343707	11458	44	23B
0005435304113	29808	1	1A
0005435304112	29808	2	3A
0005435304114	29808	3	6A
0005435304109	29808	4	6B
0005435304999	29808	5	20A
0005435304110	29808	6	21A
0005435304111	29808	7	21C
0005435304998	29808	8	21D
0005435824265	1266	1	1C
0005435824277	1266	2	2A
0005435824267	1266	3	3F
0005432284519	1266	4	4D
0005435824279	1266	5	7C
0005435824273	1266	6	7D
0005435824271	1266	7	8A
0005435824282	1266	8	7F
0005435824272	1266	9	8C
0005435824278	1266	10	9D
0005435824280	1266	11	11B
0005435824268	1266	12	11D
0005435824284	1266	13	11F
0005435824264	1266	14	13B
0005435824275	1266	15	14F
0005435824263	1266	16	15B
0005435824274	1266	17	15A
0005435824283	1266	18	16B
0005435824287	1266	19	16E
0005435824270	1266	20	17B
0005432284521	1266	21	17A
0005435824269	1266	22	18A
0005432284520	1266	23	19A
0005435824286	1266	24	19D
0005435824266	1266	25	19F
0005435824285	1266	26	20D
0005435824281	1266	27	20C
0005435824262	1266	28	21A
0005432284518	1266	29	21B
0005435824276	1266	30	21E
0005433415447	17990	1	1D
0005433415449	17990	2	2A
0005433415453	17990	3	4A
0005433415450	17990	4	6D
0005433415458	17990	5	7B
0005433415446	17990	6	7F
0005433415455	17990	7	11C
0005433415457	17990	8	11F
0005433415459	17990	9	12B
0005433415452	17990	10	13C
0005433415445	17990	11	15A
0005433415456	17990	12	18A
0005433415451	17990	13	20D
0005433415448	17990	14	21E
0005433415454	17990	15	21F
0005432783064	5647	1	1A
0005432783077	5647	2	1C
0005432783061	5647	3	1F
0005432783067	5647	4	2A
0005432783086	5647	5	2C
0005432783112	5647	6	2D
0005432783110	5647	7	2F
0005432783095	5647	8	3C
0005432783089	5647	9	3D
0005432783066	5647	10	3F
0005432783099	5647	11	4A
0005432783094	5647	12	4D
0005432783079	5647	13	5A
0005432783090	5647	14	5E
0005432783105	5647	15	6D
0005432783065	5647	16	6E
0005432783078	5647	17	7A
0005432783074	5647	18	7D
0005432783098	5647	19	8A
0005432783071	5647	20	8C
0005432783072	5647	21	8E
0005432783073	5647	22	9C
0005432783063	5647	23	9D
0005432783101	5647	24	9E
0005432783080	5647	25	9F
0005432143944	5647	26	10A
0005432783060	5647	27	10C
0005432783062	5647	28	10D
0005432783104	5647	29	10E
0005432783084	5647	30	10F
0005432783108	5647	31	11E
0005432143945	5647	32	11F
0005432783081	5647	33	12C
0005432783107	5647	34	12E
0005432783096	5647	35	13A
0005432783100	5647	36	13C
0005432783076	5647	37	13D
0005432783091	5647	38	13F
0005432783058	5647	39	14C
0005432783092	5647	40	14D
0005432783087	5647	41	14E
0005432783103	5647	42	14F
0005432783102	5647	43	15A
0005432783111	5647	44	15C
0005432783068	5647	45	15D
0005432783082	5647	46	15E
0005432783088	5647	47	15F
0005432783097	5647	48	16C
0005432143943	5647	49	16E
0005432783069	5647	50	17C
0005432783083	5647	51	17F
0005432783093	5647	52	18D
0005432783106	5647	53	18E
0005432783109	5647	54	18F
0005432783070	5647	55	19A
0005432783085	5647	56	19C
0005432783075	5647	57	19F
0005432783059	5647	58	20E
0005435242489	15368	1	1C
0005435476661	15368	2	1D
0005435242490	15368	3	2A
0005435242480	15368	4	2C
0005435242488	15368	5	4A
0005435242487	15368	6	4E
0005435242485	15368	7	5F
0005435476659	15368	8	6F
0005435242478	15368	9	7A
0005435476663	15368	10	7C
0005435242492	15368	11	7D
0005435242472	15368	12	8D
0005432782839	15368	13	8E
0005435242477	15368	14	8F
0005435476668	15368	15	9C
0005435242491	15368	16	10E
0005435242484	15368	17	10F
0005435242497	15368	18	11F
0005435242481	15368	19	12A
0005435476664	15368	20	12D
0005435242471	15368	21	12F
0005435242479	15368	22	13E
0005435476660	15368	23	13F
0005435476662	15368	24	14A
0005435242495	15368	25	14D
0005435242476	15368	26	15A
0005435476667	15368	27	16F
0005435476666	15368	28	17A
0005435242483	15368	29	17C
0005435242475	15368	30	17F
0005435242473	15368	31	18D
0005435476665	15368	32	18F
0005435242482	15368	33	19E
0005435242493	15368	34	19F
0005435242474	15368	35	20A
0005435242486	15368	36	20C
0005435242494	15368	37	20D
0005435242496	15368	38	20E
0005432848121	4355	1	1A
0005432848125	4355	2	1B
0005434462763	4355	3	1D
0005432848124	4355	4	2C
0005435850755	4355	5	2D
0005432848119	4355	6	3A
0005432848128	4355	7	3B
0005432848118	4355	8	3C
0005434463901	4355	9	3D
0005435850754	4355	10	4B
0005432848114	4355	11	4C
0005432848123	4355	12	4D
0005434463900	4355	13	6D
0005432848117	4355	14	18A
0005432848127	4355	15	18B
0005432848122	4355	16	18C
0005432848120	4355	17	19C
0005434462761	4355	18	19D
0005432848126	4355	19	20A
0005432848116	4355	20	20D
0005434463902	4355	21	22A
0005434462762	4355	22	22B
0005432848115	4355	23	22C
0005435850788	28884	1	1B
0005435850793	28884	2	3A
0005435850792	28884	3	5D
0005435850789	28884	4	6B
0005435850791	28884	5	7C
0005435850787	28884	6	21A
0005435850790	28884	7	22B
0005435850794	28884	8	22C
0005434925382	6260	1	1A
0005433496548	6260	2	1C
0005434925376	6260	3	1D
0005433496549	6260	4	1F
0005434925385	6260	5	2A
0005434443489	6260	6	2C
0005434925365	6260	7	2D
0005434443505	6260	8	3A
0005434925381	6260	9	3C
0005434925395	6260	10	3F
0005434443496	6260	11	4A
0005434925369	6260	12	4C
0005434443491	6260	13	4D
0005433496567	6260	14	4E
0005433496565	6260	15	5A
0005434443494	6260	16	5C
0005434925375	6260	17	5D
0005433496547	6260	18	5E
0005432075184	6260	19	5F
0005434925384	6260	20	6A
0005434925377	6260	21	6C
0005434925368	6260	22	6D
0005434443500	6260	23	6E
0005434925371	6260	24	6F
0005433496557	6260	25	7A
0005434443499	6260	26	7C
0005434443492	6260	27	7D
0005434925379	6260	28	7E
0005434443498	6260	29	7F
0005434443502	6260	30	8A
0005434925390	6260	31	8C
0005434925378	6260	32	8D
0005434925367	6260	33	8F
0005433496561	6260	34	9A
0005433496575	6260	35	9C
0005434925370	6260	36	9D
0005434925380	6260	37	9E
0005433496572	6260	38	9F
0005434443501	6260	39	10A
0005433496570	6260	40	10C
0005433496553	6260	41	10E
0005434925394	6260	42	10F
0005433496562	6260	43	11A
0005434443506	6260	44	11C
0005433496556	6260	45	11D
0005432075186	6260	46	11E
0005432075185	6260	47	11F
0005434443504	6260	48	12D
0005434443493	6260	49	12E
0005434925388	6260	50	12F
0005434925387	6260	51	13A
0005433496569	6260	52	13C
0005433496574	6260	53	13D
0005433496552	6260	54	13E
0005434925366	6260	55	13F
0005434925373	6260	56	14A
0005434925383	6260	57	14C
0005433496577	6260	58	14D
0005434925374	6260	59	14E
0005433496558	6260	60	14F
0005433496560	6260	61	15C
0005433496568	6260	62	15D
0005434925392	6260	63	15E
0005434443495	6260	64	15F
0005433496566	6260	65	16C
0005433496555	6260	66	16D
0005434443497	6260	67	16E
0005433496573	6260	68	16F
0005433496554	6260	69	17A
0005434443490	6260	70	17C
0005433496576	6260	71	17D
0005432075183	6260	72	17E
0005434925391	6260	73	17F
0005434925396	6260	74	18A
0005433496564	6260	75	18C
0005433496563	6260	76	19A
0005434925389	6260	77	19C
0005433496559	6260	78	19D
0005434925372	6260	79	19E
0005433496571	6260	80	19F
0005433496550	6260	81	20A
0005433496551	6260	82	20C
0005434925393	6260	83	20D
0005434443503	6260	84	20E
0005434925386	6260	85	20F
0005433496436	20423	1	7E
0005435242510	12167	1	1C
0005435242515	12167	2	2D
0005435242506	12167	3	2F
0005435242505	12167	4	3A
0005435242503	12167	5	3C
0005435242520	12167	6	3F
0005435242524	12167	7	4F
0005435242499	12167	8	5C
0005435242514	12167	9	5F
0005435242500	12167	10	6F
0005435242517	12167	11	8F
0005435242509	12167	12	9A
0005435242516	12167	13	9D
0005435242498	12167	14	10D
0005435242525	12167	15	11C
0005435242502	12167	16	11E
0005435242513	12167	17	11F
0005435242521	12167	18	13D
0005435242507	12167	19	14A
0005435242522	12167	20	15D
0005435242511	12167	21	16A
0005435242501	12167	22	16D
0005435242523	12167	23	16F
0005435242504	12167	24	17C
0005435242512	12167	25	17F
0005435242519	12167	26	19E
0005435242526	12167	27	19F
0005435242518	12167	28	20C
0005432782863	12167	29	20E
0005435242508	12167	30	20F
0005432783018	15403	1	1A
0005432783009	15403	2	1C
0005432783055	15403	3	1D
0005432783049	15403	4	1F
0005432783046	15403	5	2A
0005432783027	15403	6	2C
0005432783010	15403	7	3D
0005432783033	15403	8	3F
0005432783029	15403	9	4D
0005432783024	15403	10	4E
0005432783053	15403	11	4F
0005432783019	15403	12	5A
0005432783006	15403	13	5D
0005432783017	15403	14	5F
0005432783028	15403	15	6E
0005432783020	15403	16	7C
0005432783037	15403	17	7E
0005432783048	15403	18	7F
0005432783047	15403	19	8A
0005432783052	15403	20	8C
0005432783036	15403	21	8E
0005432783035	15403	22	8F
0005432783012	15403	23	9A
0005432783044	15403	24	9D
0005432783031	15403	25	9E
0005432783013	15403	26	9F
0005432783054	15403	27	10C
0005432783041	15403	28	11A
0005432783007	15403	29	11C
0005432783016	15403	30	11D
0005432783005	15403	31	11F
0005432783057	15403	32	12E
0005432783008	15403	33	13C
0005432783034	15403	34	13D
0005432783030	15403	35	13E
0005432783043	15403	36	13F
0005432783015	15403	37	14A
0005432783056	15403	38	14F
0005432783026	15403	39	15C
0005432783011	15403	40	15D
0005432783042	15403	41	15E
0005432783003	15403	42	15F
0005432783051	15403	43	16D
0005432783021	15403	44	17A
0005432783050	15403	45	17D
0005432783023	15403	46	17E
0005432783025	15403	47	18C
0005432783045	15403	48	18D
0005432783039	15403	49	18E
0005432783014	15403	50	19C
0005432783004	15403	51	19D
0005432783032	15403	52	20A
0005432783038	15403	53	20D
0005432783022	15403	54	20E
0005432783040	15403	55	20F
0005435913870	10112	1	2F
0005435913873	10112	2	4F
0005434910076	10112	3	6D
0005435913874	10112	4	7D
0005434910078	10112	5	7F
0005435913868	10112	6	9B
0005435913872	10112	7	11B
0005435913871	10112	8	12F
0005435913867	10112	9	13A
0005435913866	10112	10	15F
0005434910077	10112	11	16D
0005434876696	10112	12	19F
0005435913869	10112	13	20A
0005434877007	14612	1	1F
0005434876995	14612	2	1D
0005434758863	14612	3	1C
0005434877020	14612	4	2A
0005434877035	14612	5	2D
0005434876962	14612	6	2C
0005434877003	14612	7	3C
0005434876988	14612	8	3A
0005434876963	14612	9	2F
0005434877039	14612	10	3D
0005434877005	14612	11	4A
0005434876953	14612	12	3F
0005434876969	14612	13	4D
0005434877026	14612	14	4C
0005434877022	14612	15	5A
0005434876968	14612	16	4F
0005434876974	14612	17	5C
0005434877016	14612	18	6A
0005434876950	14612	19	5F
0005434877013	14612	20	6D
0005434876966	14612	21	6E
0005434877000	14612	22	7B
0005434877028	14612	23	7A
0005434877034	14612	24	6F
0005434876959	14612	25	7E
0005434876970	14612	26	7D
0005434877032	14612	27	8B
0005434876956	14612	28	8E
0005434876989	14612	29	8D
0005434876948	14612	30	8C
0005434877029	14612	31	8F
0005434877004	14612	32	9B
0005434876991	14612	33	9A
0005434876993	14612	34	10B
0005434877014	14612	35	10A
0005434758862	14612	36	9F
0005434877030	14612	37	10C
0005434876973	14612	38	10E
0005434877011	14612	39	10D
0005434876967	14612	40	10F
0005434877006	14612	41	11B
0005434876981	14612	42	11A
0005434877033	14612	43	11D
0005434876945	14612	44	11C
0005434876985	14612	45	11F
0005434877037	14612	46	11E
0005434876994	14612	47	12B
0005434876954	14612	48	12A
0005434876947	14612	49	12C
0005434876975	14612	50	12F
0005434876979	14612	51	12E
0005434876998	14612	52	13B
0005434877036	14612	53	13A
0005434877012	14612	54	13C
0005434877025	14612	55	13E
0005434876982	14612	56	13D
0005434877024	14612	57	14A
0005434876943	14612	58	13F
0005434876949	14612	59	14B
0005434876999	14612	60	14D
0005434876984	14612	61	14C
0005434877015	14612	62	14F
0005434877018	14612	63	14E
0005434876957	14612	64	15B
0005434877023	14612	65	15A
0005434876996	14612	66	15C
0005434910068	14612	67	15E
0005434876972	14612	68	15D
0005434877008	14612	69	16A
0005434876955	14612	70	15F
0005434876971	14612	71	16C
0005434876978	14612	72	16B
0005434877009	14612	73	16E
0005434877001	14612	74	17A
0005434876987	14612	75	16F
0005434876992	14612	76	17B
0005434876965	14612	77	17D
0005434876997	14612	78	17C
0005434877031	14612	79	17E
0005434876980	14612	80	18B
0005434876983	14612	81	18D
0005434877002	14612	82	18C
0005434876990	14612	83	18E
0005434876944	14612	84	19A
0005434877027	14612	85	18F
0005434876946	14612	86	19C
0005434877019	14612	87	19B
0005434876964	14612	88	19E
0005434876977	14612	89	19D
0005434876960	14612	90	19F
0005434877017	14612	91	20B
0005434876986	14612	92	20A
0005434877021	14612	93	20D
0005434876958	14612	94	20C
0005434876952	14612	95	20E
0005434876951	14612	96	21B
0005434876961	14612	97	21A
0005434877038	14612	98	21C
0005434876976	14612	99	21E
0005434877010	14612	100	21F
0005435659990	9265	1	1A
0005435659985	9265	2	3A
0005435659984	9265	3	4A
0005435659983	9265	4	7A
0005435659993	9265	5	7C
0005435659988	9265	6	18C
0005435659991	9265	7	19D
0005435659986	9265	8	20C
0005435659987	9265	9	21B
0005435659989	9265	10	22D
0005435659992	9265	11	23B
0005434251841	24665	1	2D
0005434251836	24665	2	3D
0005434251837	24665	3	5D
0005434251835	24665	4	6A
0005434251839	24665	5	6B
0005434251838	24665	6	19A
0005434251842	24665	7	21B
0005434251840	24665	8	22D
0005434251843	24665	9	23A
0005433679912	2771	1	1A
0005433679924	2771	2	1D
0005432222711	2771	3	2A
0005432222710	2771	4	3A
0005433679931	2771	5	3C
0005433679907	2771	6	3D
0005432222709	2771	7	4D
0005433679905	2771	8	4E
0005433679935	2771	9	4F
0005433679920	2771	10	5A
0005433679937	2771	11	5D
0005433679933	2771	12	5E
0005433679910	2771	13	5F
0005433679945	2771	14	6D
0005433679906	2771	15	6E
0005433679952	2771	16	7C
0005432222712	2771	17	7E
0005433679919	2771	18	7F
0005433679916	2771	19	8C
0005433679950	2771	20	8D
0005433679908	2771	21	8E
0005433679942	2771	22	9A
0005433684391	2771	23	9C
0005433679951	2771	24	9D
0005433679934	2771	25	9E
0005433679923	2771	26	9F
0005433679944	2771	27	10C
0005433679918	2771	28	10E
0005433679913	2771	29	11F
0005433679921	2771	30	12C
0005433679947	2771	31	12D
0005433679948	2771	32	12E
0005433679953	2771	33	12F
0005433679938	2771	34	13A
0005433679929	2771	35	13C
0005432222713	2771	36	13D
0005433679914	2771	37	14A
0005433679941	2771	38	14C
0005433679943	2771	39	15A
0005433679936	2771	40	15C
0005433679930	2771	41	15D
0005433679926	2771	42	15E
0005433679949	2771	43	15F
0005433679911	2771	44	16C
0005433684390	2771	45	16E
0005433679915	2771	46	16F
0005433679946	2771	47	17C
0005433679922	2771	48	17D
0005433679909	2771	49	17E
0005433679932	2771	50	18A
0005433684392	2771	51	18C
0005433679927	2771	52	18D
0005433679939	2771	53	19A
0005433679925	2771	54	19D
0005433679917	2771	55	19E
0005433679928	2771	56	19F
0005433679940	2771	57	20A
0005432966585	29140	1	1D
0005432966588	29140	2	2C
0005432966607	29140	3	3D
0005432966589	29140	4	4C
0005432966596	29140	5	4D
0005433679767	29140	6	5D
0005433679768	29140	7	5E
0005432966598	29140	8	6D
0005432966593	29140	9	7C
0005433679710	29140	10	7E
0005433679838	29140	11	8A
0005432005177	29140	12	9A
0005432966594	29140	13	9C
0005432966602	29140	14	9F
0005432966587	29140	15	10C
0005432966599	29140	16	10E
0005433679764	29140	17	10F
0005432966601	29140	18	11A
0005433679799	29140	19	11E
0005432966595	29140	20	12D
0005433679749	29140	21	12F
0005432966590	29140	22	13A
0005432966604	29140	23	13E
0005432005174	29140	24	14D
0005432005176	29140	25	14F
0005432966606	29140	26	15A
0005432966609	29140	27	15C
0005432966584	29140	28	15D
0005432966608	29140	29	15E
0005432966600	29140	30	16C
0005432966603	29140	31	16D
0005432966591	29140	32	17E
0005433679772	29140	33	18A
0005432966592	29140	34	18F
0005432966605	29140	35	19D
0005432966586	29140	36	19F
0005432966597	29140	37	20C
0005432005175	29140	38	20E
0005433679797	29140	39	20F
0005433613676	9272	1	1C
0005432755029	9272	2	1F
0005433633327	9272	3	1D
0005433613668	9272	4	2A
0005433613649	9272	5	2C
0005433613639	9272	6	2D
0005433633322	9272	7	3A
0005432756803	9272	8	2F
0005433633326	9272	9	3F
0005433613636	9272	10	4A
0005433613667	9272	11	4C
0005433633324	9272	12	4F
0005433613671	9272	13	4D
0005433613655	9272	14	5A
0005433633337	9272	15	5C
0005433613651	9272	16	5F
0005433633331	9272	17	5D
0005433613633	9272	18	6A
0005433613616	9272	19	6C
0005433613686	9272	20	7A
0005433613629	9272	21	6F
0005433633347	9272	22	7C
0005433613679	9272	23	7D
0005433613632	9272	24	8A
0005433633325	9272	25	7F
0005433633330	9272	26	8C
0005433633341	9272	27	8D
0005433613624	9272	28	8E
0005433613643	9272	29	9A
0005433613615	9272	30	9B
0005433633321	9272	31	9C
0005433613672	9272	32	9D
0005433613630	9272	33	9E
0005433633318	9272	34	10A
0005432756801	9272	35	10B
0005433613621	9272	36	10D
0005433613664	9272	37	10E
0005433613637	9272	38	11A
0005433633349	9272	39	11C
0005433633345	9272	40	11B
0005433577619	9272	41	11D
0005433577624	9272	42	11E
0005433577627	9272	43	12D
0005433613642	9272	44	12C
0005433613685	9272	45	12E
0005433577622	9272	46	13C
0005433613631	9272	47	13B
0005433613670	9272	48	13D
0005433613661	9272	49	13E
0005433613659	9272	50	14B
0005433633332	9272	51	15A
0005433613622	9272	52	14F
0005433577623	9272	53	15C
0005433577616	9272	54	15B
0005433633340	9272	55	15D
0005433633348	9272	56	15E
0005433613653	9272	57	16A
0005433613626	9272	58	16C
0005433613623	9272	59	16D
0005433577621	9272	60	16E
0005432756802	9272	61	17A
0005433613640	9272	62	16F
0005433633319	9272	63	17C
0005433613683	9272	64	17B
0005433633351	9272	65	17E
0005433613618	9272	66	17F
0005433577617	9272	67	18A
0005433633333	9272	68	18B
0005433613662	9272	69	18C
0005433633354	9272	70	18D
0005433613647	9272	71	18F
0005433633346	9272	72	19C
0005433633344	9272	73	19B
0005433577615	9272	74	20B
0005433613645	9272	75	20A
0005433613665	9272	76	20C
0005433577620	9272	77	20E
0005433613635	9272	78	20D
0005433633338	9272	79	20F
0005433613681	9272	80	21B
0005433613627	9272	81	21A
0005433613625	9272	82	21D
0005433613673	9272	83	21E
0005433613614	9272	84	21F
0005433633339	9272	85	22B
0005433613675	9272	86	22D
0005433633334	9272	87	22C
0005433613654	9272	88	22F
0005432145082	9272	89	23A
0005433613657	9272	90	23C
0005433613658	9272	91	23B
0005433613663	9272	92	23D
0005433613617	9272	93	23F
0005433633352	9272	94	23E
0005433613646	9272	95	24A
0005433613611	9272	96	24B
0005433633343	9272	97	24C
0005433633329	9272	98	24D
0005433577628	9272	99	24F
0005433613684	9272	100	24E
0005433613644	9272	101	25A
0005433613666	9272	102	25C
0005433633328	9272	103	25B
0005433613638	9272	104	25D
0005433633336	9272	105	25F
0005433613648	9272	106	26A
0005433633320	9272	107	26B
0005432755031	9272	108	26C
0005433613677	9272	109	26E
0005433613613	9272	110	26F
0005433613641	9272	111	27A
0005433633353	9272	112	27C
0005433613656	9272	113	27B
0005433613612	9272	114	27D
0005433577618	9272	115	27E
0005433633350	9272	116	28A
0005433633335	9272	117	27F
0005433613620	9272	118	28D
0005433633323	9272	119	28E
0005433613650	9272	120	29A
0005433613669	9272	121	28F
0005433613674	9272	122	29B
0005433577626	9272	123	29E
0005433613652	9272	124	30A
0005433613619	9272	125	30B
0005433613634	9272	126	30C
0005433577625	9272	127	30E
0005432755030	9272	128	30D
0005433613660	9272	129	30F
0005433613680	9272	130	31B
0005433633342	9272	131	31A
0005433613682	9272	132	31C
0005433613628	9272	133	31D
0005433613678	9272	134	31E
0005434273053	25207	1	1F
0005434163492	25207	2	3C
0005434273052	25207	3	4C
0005434163494	25207	4	5A
0005435854044	25207	5	6A
0005434163497	25207	6	9B
0005435854043	25207	7	11B
0005434163496	25207	8	12B
0005434272168	25207	9	14A
0005434163502	25207	10	21F
0005434163498	25207	11	22C
0005434273054	25207	12	25D
0005435854042	25207	13	26F
0005434163499	25207	14	28E
0005434272167	25207	15	29D
0005434163493	25207	16	29E
0005434163501	25207	17	30B
0005434163500	25207	18	30F
0005435854041	25207	19	31B
0005434163495	25207	20	31F
0005435986675	4204	1	2B
0005435986670	4204	2	2H
0005435986677	4204	3	3G
0005435986673	4204	4	4C
0005432184912	4204	5	5F
0005435986679	4204	6	11B
0005435986678	4204	7	15H
0005435986674	4204	8	17E
0005432184913	4204	9	18A
0005435986671	4204	10	19G
0005435986672	4204	11	38B
0005435986676	4204	12	39D
0005435856147	26597	1	1A
0005435947063	26597	2	2A
0005435856149	26597	3	2B
0005435856150	26597	4	9G
0005435947061	26597	5	11D
0005435947068	26597	6	11E
0005432571275	26597	7	12B
0005435947070	26597	8	12E
0005435947067	26597	9	16D
0005435947065	26597	10	16F
0005435947059	26597	11	17F
0005432571273	26597	12	18F
0005435947058	26597	13	19E
0005435947057	26597	14	20A
0005435787327	26597	15	22D
0005432571274	26597	16	23D
0005435947064	26597	17	23H
0005435856148	26597	18	24B
0005432571272	26597	19	24G
0005435947069	26597	20	33D
0005435947062	26597	21	33F
0005435947066	26597	22	35B
0005435787326	26597	23	35D
0005435947060	26597	24	38H
0005433568282	344	1	1D
0005433568307	344	2	1F
0005433568278	344	3	2D
0005433134060	344	4	4D
0005433568283	344	5	5A
0005433568272	344	6	5C
0005432238852	344	7	6A
0005433568267	344	8	8F
0005433568296	344	9	9D
0005433568260	344	10	9F
0005433568262	344	11	9E
0005433568270	344	12	10A
0005433568271	344	13	10F
0005433568269	344	14	11B
0005432238857	344	15	11A
0005433568261	344	16	11D
0005433568298	344	17	13C
0005432238853	344	18	13D
0005433568259	344	19	13E
0005433568268	344	20	14A
0005433568305	344	21	14C
0005433568292	344	22	14B
0005433074237	344	23	14E
0005433074236	344	24	15A
0005433568276	344	25	14F
0005433568299	344	26	15B
0005433074196	344	27	15C
0005433568279	344	28	15F
0005433568304	344	29	16C
0005433568275	344	30	17B
0005433568277	344	31	17C
0005433568281	344	32	17E
0005433568288	344	33	18D
0005432238856	344	34	18F
0005433568301	344	35	19E
0005433568285	344	36	20C
0005433568266	344	37	20D
0005433568295	344	38	21E
0005433568287	344	39	21F
0005432238855	344	40	22E
0005433568265	344	41	23C
0005433568294	344	42	23D
0005433568264	344	43	23E
0005433568306	344	44	24B
0005433568280	344	45	24C
0005432238854	344	46	24E
0005433568303	344	47	26B
0005433568293	344	48	26D
0005433568274	344	49	27C
0005433568297	344	50	27F
0005433568290	344	51	28B
0005433568263	344	52	28E
0005433568291	344	53	29A
0005433568273	344	54	29B
0005433568286	344	55	29D
0005433568284	344	56	30B
0005433568289	344	57	30F
0005433568300	344	58	31D
0005433568302	344	59	31E
0005432947914	11598	1	1C
0005433074338	11598	2	1F
0005433074333	11598	3	2C
0005432947928	11598	4	2A
0005432947916	11598	5	3A
0005432947902	11598	6	3D
0005432947911	11598	7	5A
0005432947894	11598	8	5C
0005433074335	11598	9	5F
0005433074318	11598	10	5D
0005433074320	11598	11	6A
0005432947926	11598	12	6C
0005432947904	11598	13	6F
0005433074327	11598	14	7D
0005432947897	11598	15	8A
0005432192278	11598	16	8D
0005433074325	11598	17	8C
0005432947912	11598	18	8F
0005432947922	11598	19	9C
0005433131647	11598	20	9B
0005432192279	11598	21	9D
0005433074319	11598	22	10A
0005432947924	11598	23	10E
0005433074322	11598	24	10F
0005432947913	11598	25	11B
0005432947898	11598	26	11D
0005433074332	11598	27	12B
0005432947895	11598	28	12D
0005432947925	11598	29	12F
0005433074334	11598	30	13D
0005432947908	11598	31	14B
0005432947917	11598	32	14E
0005433131645	11598	33	15E
0005432947910	11598	34	15D
0005433134078	11598	35	16D
0005432192277	11598	36	16E
0005433074321	11598	37	17D
0005433074331	11598	38	17F
0005432947909	11598	39	18A
0005432947929	11598	40	18B
0005432947893	11598	41	18E
0005433074323	11598	42	18F
0005433074337	11598	43	19C
0005433074341	11598	44	19E
0005433134076	11598	45	20B
0005432947896	11598	46	20D
0005433074339	11598	47	20F
0005432947899	11598	48	21C
0005433074328	11598	49	21B
0005432947919	11598	50	21E
0005432947906	11598	51	21F
0005433074336	11598	52	22D
0005433074340	11598	53	22F
0005433074329	11598	54	22E
0005432947907	11598	55	23B
0005433074326	11598	56	23D
0005432947923	11598	57	23F
0005433074324	11598	58	24B
0005433131648	11598	59	24C
0005432947920	11598	60	25C
0005432947901	11598	61	25D
0005433074315	11598	62	25F
0005432947900	11598	63	25E
0005433074330	11598	64	26F
0005432947903	11598	65	26E
0005433074317	11598	66	27A
0005432947892	11598	67	27C
0005432947889	11598	68	27B
0005432947891	11598	69	27D
0005432947921	11598	70	28A
0005433074316	11598	71	28D
0005432947890	11598	72	28C
0005432947918	11598	73	29C
0005432947927	11598	74	29D
0005432947905	11598	75	29E
0005432947915	11598	76	30B
0005433131646	11598	77	30A
0005433134077	11598	78	31C
0005433817421	9998	1	1B
0005433817422	9998	2	3A
0005433817419	9998	3	4B
0005433817420	9998	4	6B
0005434732933	13966	1	2B
0005434732934	13966	2	4A
0005434732935	13966	3	6B
0005435981696	2361	1	1A
0005433753497	2361	2	1C
0005433753458	2361	3	1G
0005435981697	2361	4	2A
0005435981691	2361	5	2C
0005435981727	2361	6	2H
0005433753479	2361	7	3A
0005432655384	2361	8	3B
0005435981709	2361	9	3F
0005432655386	2361	10	3G
0005435981724	2361	11	4C
0005433766590	2361	12	4G
0005433753502	2361	13	4F
0005433753464	2361	14	5B
0005432300191	2361	15	5C
0005432655381	2361	16	5G
0005435981712	2361	17	5F
0005433753494	2361	18	5H
0005433764652	2361	19	9B
0005435981695	2361	20	11A
0005435981729	2361	21	9H
0005433753487	2361	22	11D
0005433753454	2361	23	11E
0005435981702	2361	24	11G
0005432225977	2361	25	12A
0005435981716	2361	26	12B
0005432655376	2361	27	12D
0005433764653	2361	28	12G
0005435981698	2361	29	12H
0005433753491	2361	30	13A
0005432655380	2361	31	13D
0005435981723	2361	32	13E
0005433753495	2361	33	13H
0005432300190	2361	34	14A
0005433753488	2361	35	14D
0005435981721	2361	36	14F
0005433753490	2361	37	15D
0005435981730	2361	38	15B
0005435981707	2361	39	15A
0005433766589	2361	40	15F
0005435981694	2361	41	15E
0005432984597	2361	42	15H
0005433753503	2361	43	15G
0005432300189	2361	44	16D
0005435981733	2361	45	16F
0005435981718	2361	46	16E
0005433753508	2361	47	17B
0005433753472	2361	48	17D
0005433753507	2361	49	17E
0005435981734	2361	50	17G
0005435981708	2361	51	17F
0005433753470	2361	52	18B
0005433753475	2361	53	18A
0005432984596	2361	54	18D
0005432225976	2361	55	18F
0005433753509	2361	56	18E
0005433753459	2361	57	18H
0005433753501	2361	58	19A
0005433766592	2361	59	19D
0005432655379	2361	60	19G
0005435981728	2361	61	20A
0005433753456	2361	62	19H
0005433753493	2361	63	20E
0005435981722	2361	64	20F
0005435981710	2361	65	20G
0005435981725	2361	66	20H
0005432225972	2361	67	21D
0005432655385	2361	68	21B
0005432300187	2361	69	21E
0005433753473	2361	70	21G
0005435981705	2361	71	21F
0005433753474	2361	72	21H
0005435981713	2361	73	22A
0005433766591	2361	74	22B
0005432655375	2361	75	22E
0005432300188	2361	76	22F
0005435981700	2361	77	22G
0005435981693	2361	78	23B
0005435981717	2361	79	23A
0005433753452	2361	80	23G
0005433753483	2361	81	24E
0005433753485	2361	82	24D
0005433753466	2361	83	24F
0005433753506	2361	84	25E
0005435981701	2361	85	25F
0005435981720	2361	86	27D
0005432225973	2361	87	27B
0005435981714	2361	88	27A
0005433753498	2361	89	27H
0005432655378	2361	90	27G
0005433753468	2361	91	28B
0005432655383	2361	92	28G
0005435981732	2361	93	28F
0005433753477	2361	94	28H
0005433766588	2361	95	29A
0005433753453	2361	96	29B
0005432655377	2361	97	29D
0005433753465	2361	98	29G
0005435981731	2361	99	29H
0005432225971	2361	100	30B
0005433753478	2361	101	30A
0005432984598	2361	102	30D
0005433753504	2361	103	30F
0005433753451	2361	104	30G
0005433753476	2361	105	31A
0005433753500	2361	106	31E
0005435981726	2361	107	31G
0005433753481	2361	108	32A
0005433753489	2361	109	32B
0005433753460	2361	110	32E
0005433753482	2361	111	32D
0005435981703	2361	112	32F
0005435981692	2361	113	32H
0005435981690	2361	114	33A
0005433753480	2361	115	33B
0005433753486	2361	116	33D
0005433753492	2361	117	33G
0005435981699	2361	118	33F
0005435981719	2361	119	33H
0005435981711	2361	120	34B
0005433753471	2361	121	34A
0005433753469	2361	122	34D
0005433764651	2361	123	34E
0005433753463	2361	124	34G
0005433753467	2361	125	34H
0005432655382	2361	126	35B
0005432300186	2361	127	35A
0005432225975	2361	128	35D
0005433753461	2361	129	35G
0005433753499	2361	130	36F
0005433753462	2361	131	36E
0005435981706	2361	132	36G
0005433753484	2361	133	37A
0005435981715	2361	134	36H
0005435981704	2361	135	37B
0005432225974	2361	136	37F
0005433753496	2361	137	37E
0005433753505	2361	138	38A
0005433753455	2361	139	38E
0005432300185	2361	140	39D
0005433753457	2361	141	39F
0005432984664	26197	1	1B
0005432984637	26197	2	1H
0005433434295	26197	3	1F
0005432051088	26197	4	2F
0005432984656	26197	5	2H
0005433434320	26197	6	3H
0005432984643	26197	7	4G
0005433434314	26197	8	5A
0005432984638	26197	9	5G
0005433434298	26197	10	5H
0005432984642	26197	11	9B
0005432984657	26197	12	9G
0005433434297	26197	13	11A
0005432869437	26197	14	9H
0005434731113	26197	15	11E
0005433434309	26197	16	11F
0005433434305	26197	17	11G
0005434731115	26197	18	11H
0005433434317	26197	19	13B
0005433434306	26197	20	13A
0005432984653	26197	21	13H
0005432984641	26197	22	14D
0005433434322	26197	23	14F
0005433753258	26197	24	14E
0005432984635	26197	25	14H
0005433434296	26197	26	15A
0005434731114	26197	27	15D
0005432984644	26197	28	15F
0005432869431	26197	29	15H
0005433434310	26197	30	16B
0005433434307	26197	31	17E
0005433434319	26197	32	17H
0005433434316	26197	33	18G
0005432049414	26197	34	19B
0005432051086	26197	35	19A
0005432984652	26197	36	19H
0005432984654	26197	37	20B
0005434731116	26197	38	20H
0005432984639	26197	39	20G
0005433434301	26197	40	21B
0005433434302	26197	41	21E
0005432984660	26197	42	22B
0005432869432	26197	43	22D
0005433434311	26197	44	23B
0005433434315	26197	45	23D
0005433434313	26197	46	24A
0005432984640	26197	47	23H
0005433434318	26197	48	24B
0005433434323	26197	49	24F
0005433434300	26197	50	27A
0005433753257	26197	51	27B
0005432984663	26197	52	27D
0005433434303	26197	53	27F
0005432984634	26197	54	28E
0005432869435	26197	55	28F
0005432051087	26197	56	28H
0005432984662	26197	57	29A
0005432984658	26197	58	29D
0005432984661	26197	59	29H
0005432984655	26197	60	30D
0005432984666	26197	61	30G
0005433434324	26197	62	31B
0005432049417	26197	63	31A
0005432869434	26197	64	31F
0005432869433	26197	65	32B
0005433434304	26197	66	32E
0005432984645	26197	67	32F
0005432984647	26197	68	32H
0005432984659	26197	69	33B
0005432984651	26197	70	33H
0005432984648	26197	71	34A
0005433766572	26197	72	34D
0005433434321	26197	73	34G
0005432984636	26197	74	34F
0005432984650	26197	75	35D
0005432049415	26197	76	35H
0005432869436	26197	77	36F
0005432984665	26197	78	37E
0005433434312	26197	79	37G
0005433434308	26197	80	38B
0005432984646	26197	81	38A
0005433434299	26197	82	38F
0005432049416	26197	83	38H
0005432984633	26197	84	39D
0005432984649	26197	85	39F
0005432267805	1508	1	1D
0005434374065	1508	2	2F
0005432267807	1508	3	3F
0005434374053	1508	4	4A
0005434374067	1508	5	4B
0005434374079	1508	6	4C
0005434374070	1508	7	5B
0005433460408	1508	8	5D
0005434374076	1508	9	6A
0005433150855	1508	10	6B
0005434374072	1508	11	6F
0005434374055	1508	12	7A
0005434374081	1508	13	7E
0005434374068	1508	14	8E
0005434374066	1508	15	8F
0005434374075	1508	16	9C
0005434374051	1508	17	9D
0005434374080	1508	18	11E
0005434374078	1508	19	11D
0005434374064	1508	20	12A
0005434374077	1508	21	12C
0005433150928	1508	22	12D
0005433461560	1508	23	12E
0005434374062	1508	24	13C
0005434374060	1508	25	13B
0005434374057	1508	26	13D
0005432267808	1508	27	14E
0005434374063	1508	28	15B
0005434374061	1508	29	16A
0005434374073	1508	30	16C
0005434374058	1508	31	16D
0005432267809	1508	32	16E
0005433150926	1508	33	17C
0005433150927	1508	34	18F
0005434374074	1508	35	19C
0005434374071	1508	36	19D
0005434374052	1508	37	19E
0005432267804	1508	38	19F
0005433461559	1508	39	20A
0005434374069	1508	40	20C
0005434374054	1508	41	20E
0005432267806	1508	42	22A
0005434374056	1508	43	23A
0005434374059	1508	44	23C
0005433150961	20147	1	1A
0005432056248	20147	2	1D
0005433150958	20147	3	2C
0005433764651	20147	4	2D
0005433764653	20147	5	2F
0005433150950	20147	6	3C
0005433150946	20147	7	4D
0005433150960	20147	8	4C
0005434373867	20147	9	4E
0005433150939	20147	10	5B
0005433150949	20147	11	5C
0005433150959	20147	12	5E
0005433150968	20147	13	6A
0005432056250	20147	14	6B
0005433150941	20147	15	6E
0005433150934	20147	16	7A
0005433150942	20147	17	7E
0005433150937	20147	18	9B
0005433150944	20147	19	9D
0005432056249	20147	20	9F
0005433150969	20147	21	10B
0005433764652	20147	22	11A
0005433150954	20147	23	12A
0005433150965	20147	24	12C
0005433150967	20147	25	12F
0005433150943	20147	26	13B
0005433150935	20147	27	14B
0005433150956	20147	28	14E
0005433150955	20147	29	14F
0005433150953	20147	30	15A
0005433150936	20147	31	15E
0005433150945	20147	32	16C
0005433150952	20147	33	17F
0005434029625	20147	34	18C
0005433150966	20147	35	18E
0005433150962	20147	36	19B
0005433150964	20147	37	19C
0005433150951	20147	38	19E
0005433150947	20147	39	20D
0005434029624	20147	40	20F
0005433150948	20147	41	21D
0005433150938	20147	42	22A
0005433931426	20147	43	22B
0005433150940	20147	44	22C
0005433150963	20147	45	22D
0005433150957	20147	46	23B
0005432282773	544	1	1A
0005432423853	544	2	2C
0005432423837	544	3	2A
0005432282771	544	4	3D
0005432423840	544	5	3F
0005432423836	544	6	4C
0005432423845	544	7	5D
0005432423816	544	8	7C
0005432423832	544	9	7D
0005432282772	544	10	7F
0005432423824	544	11	8B
0005432423826	544	12	8D
0005432423819	544	13	8F
0005432423813	544	14	9C
0005432423844	544	15	11E
0005432423856	544	16	11D
0005432423834	544	17	11F
0005432423846	544	18	12D
0005432423828	544	19	12C
0005432423829	544	20	14A
0005432423858	544	21	13F
0005432423831	544	22	14B
0005432423849	544	23	14F
0005432282769	544	24	15C
0005432423835	544	25	16A
0005432423850	544	26	16C
0005432423830	544	27	16F
0005432282770	544	28	17C
0005432423841	544	29	18C
0005432423827	544	30	18F
0005432423843	544	31	19E
0005432423823	544	32	20E
0005432423838	544	33	21A
0005432423859	544	34	21F
0005432423818	544	35	22C
0005432423855	544	36	22D
0005432423839	544	37	22F
0005432423820	544	38	23A
0005432423842	544	39	23C
0005432423822	544	40	23D
0005432423833	544	41	23E
0005432423854	544	42	24E
0005432423817	544	43	25B
0005432423821	544	44	25F
0005432282768	544	45	26C
0005432423815	544	46	26F
0005432423848	544	47	27E
0005432423811	544	48	28A
0005432423825	544	49	28B
0005432423852	544	50	28F
0005432423810	544	51	29F
0005432423851	544	52	30D
0005432423814	544	53	30F
0005432423812	544	54	31C
0005432423857	544	55	31D
0005432423847	544	56	31E
0005432302279	12938	1	10C
0005433158099	12938	2	11C
0005432302281	12938	3	21C
0005433158103	12938	4	22E
0005433158102	12938	5	25E
0005433158101	12938	6	26E
0005433158100	12938	7	28C
0005432302282	12938	8	29C
0005432302280	12938	9	30E
0005433057169	475	1	1F
0005434022785	475	2	1H
0005434022830	475	3	3C
0005434022843	475	4	3F
0005433057259	475	5	4A
0005432045585	475	6	4C
0005434022789	475	7	4F
0005434022790	475	8	5B
0005434022840	475	9	5A
0005434022844	475	10	5F
0005434022811	475	11	5G
0005434022812	475	12	9B
0005434022804	475	13	9A
0005434022783	475	14	9G
0005434022803	475	15	9H
0005434031957	475	16	11B
0005434022809	475	17	11E
0005434022837	475	18	11D
0005434029621	475	19	11G
0005434022801	475	20	12A
0005434022792	475	21	12D
0005432045586	475	22	12B
0005434022824	475	23	12F
0005434022816	475	24	13A
0005434022825	475	25	13G
0005434022826	475	26	13H
0005434022784	475	27	14D
0005434022821	475	28	14E
0005434022817	475	29	15D
0005434022794	475	30	15F
0005434022795	475	31	16A
0005434022788	475	32	16F
0005434022779	475	33	17A
0005434022787	475	34	16G
0005434022818	475	35	17B
0005434022805	475	36	17H
0005434022797	475	37	18B
0005434022791	475	38	18D
0005432235535	475	39	18F
0005434031961	475	40	18H
0005434022829	475	41	19B
0005434022802	475	42	19G
0005433057211	475	43	20D
0005434022819	475	44	20H
0005434022834	475	45	20G
0005434022831	475	46	21D
0005432235538	475	47	21E
0005434028257	475	48	21G
0005434022839	475	49	21F
0005434022836	475	50	21H
0005434028259	475	51	22A
0005434031959	475	52	22F
0005434022845	475	53	22E
0005433057168	475	54	22H
0005434022806	475	55	23B
0005433057260	475	56	23E
0005434022820	475	57	23D
0005434022781	475	58	23G
0005434022815	475	59	24A
0005434022823	475	60	23H
0005434022827	475	61	24H
0005433057170	475	62	25E
0005434022786	475	63	27B
0005432235539	475	64	27D
0005434022814	475	65	27H
0005434022796	475	66	27G
0005434022832	475	67	28E
0005434022835	475	68	28H
0005434031960	475	69	28G
0005434022833	475	70	29F
0005434022798	475	71	30E
0005434022808	475	72	31A
0005434022778	475	73	30H
0005434022780	475	74	31F
0005434022822	475	75	31G
0005432235540	475	76	32E
0005434022841	475	77	32D
0005434022813	475	78	32F
0005432235541	475	79	33B
0005434022838	475	80	33F
0005434029623	475	81	33G
0005434022846	475	82	34A
0005434022782	475	83	34D
0005433057247	475	84	35F
0005434029622	475	85	36D
0005434028260	475	86	36F
0005434022799	475	87	36E
0005434022800	475	88	37A
0005434022828	475	89	36H
0005434028258	475	90	37F
0005434022810	475	91	37G
0005432235536	475	92	38B
0005434031958	475	93	37H
0005434022793	475	94	38D
0005434022842	475	95	38F
0005432235537	475	96	39D
0005434022807	475	97	38G
0005432156304	12666	1	1C
0005433057357	12666	2	1G
0005432156308	12666	3	1H
0005433057370	12666	4	3A
0005432157465	12666	5	2H
0005433057367	12666	6	4C
0005433057337	12666	7	5B
0005433929558	12666	8	5G
0005433057360	12666	9	11H
0005433057339	12666	10	11G
0005433057373	12666	11	12E
0005433057336	12666	12	12F
0005433057372	12666	13	13A
0005434735621	12666	14	13D
0005433057368	12666	15	13B
0005433057346	12666	16	13E
0005433057344	12666	17	13G
0005433057362	12666	18	13F
0005433684393	12666	19	14A
0005433057353	12666	20	14E
0005433057366	12666	21	15D
0005433057363	12666	22	15B
0005433057351	12666	23	15E
0005433057334	12666	24	15G
0005433929556	12666	25	16B
0005434735620	12666	26	18G
0005433057356	12666	27	19D
0005433057348	12666	28	19H
0005433057364	12666	29	19G
0005433057358	12666	30	20B
0005432156307	12666	31	20D
0005433057347	12666	32	21A
0005433057345	12666	33	21G
0005433057354	12666	34	21H
0005433057349	12666	35	22B
0005433057342	12666	36	23B
0005434735622	12666	37	24A
0005433684394	12666	38	24D
0005434735619	12666	39	25D
0005432156306	12666	40	25E
0005433057350	12666	41	27A
0005433057369	12666	42	29D
0005432156305	12666	43	30A
0005434022539	12666	44	30G
0005433057352	12666	45	31E
0005433057343	12666	46	31F
0005434735623	12666	47	32G
0005433057338	12666	48	33D
0005433057361	12666	49	33G
0005433057340	12666	50	34D
0005433929559	12666	51	34F
0005433057341	12666	52	35D
0005433057335	12666	53	35F
0005433057365	12666	54	35E
0005433057355	12666	55	36D
0005432157466	12666	56	36F
0005434735618	12666	57	36E
0005433929557	12666	58	37A
0005433057359	12666	59	38D
0005433057371	12666	60	38G
0005433057333	12666	61	39E
0005433922017	2157	1	1A
0005433922030	2157	2	1C
0005433922005	2157	3	1F
0005433921982	2157	4	1G
0005433922070	2157	5	2A
0005433922062	2157	6	1H
0005433035364	2157	7	2C
0005432044486	2157	8	2H
0005433922029	2157	9	2G
0005433922045	2157	10	3B
0005433922025	2157	11	3F
0005433922011	2157	12	3G
0005432231423	2157	13	3H
0005433921987	2157	14	4F
0005433922023	2157	15	9A
0005433922013	2157	16	5H
0005433929556	2157	17	9B
0005433922063	2157	18	9H
0005433921984	2157	19	9G
0005433922056	2157	20	11A
0005433922024	2157	21	11H
0005433922071	2157	22	12A
0005433922001	2157	23	12E
0005433922007	2157	24	12F
0005433922069	2157	25	12G
0005432231420	2157	26	13A
0005433922020	2157	27	13G
0005433922068	2157	28	13H
0005432231427	2157	29	14A
0005433921995	2157	30	14F
0005433921981	2157	31	14E
0005433922052	2157	32	15A
0005433922004	2157	33	14H
0005433922027	2157	34	15D
0005433922009	2157	35	15B
0005433922076	2157	36	15E
0005433922047	2157	37	15H
0005433922008	2157	38	15G
0005432231417	2157	39	16B
0005433922066	2157	40	16A
0005433035399	2157	41	16E
0005433922065	2157	42	16G
0005433922033	2157	43	17B
0005433922072	2157	44	17A
0005433922015	2157	45	18A
0005432231421	2157	46	17H
0005433929557	2157	47	18F
0005433922022	2157	48	19B
0005433921986	2157	49	19A
0005433922059	2157	50	19E
0005433921999	2157	51	19H
0005432231424	2157	52	19G
0005433922000	2157	53	20D
0005433035450	2157	54	20B
0005433922055	2157	55	20F
0005433929559	2157	56	21A
0005433922036	2157	57	20H
0005433922057	2157	58	21D
0005433921985	2157	59	21B
0005433922048	2157	60	21F
0005433922018	2157	61	21H
0005433922039	2157	62	21G
0005433922028	2157	63	22B
0005433921980	2157	64	22A
0005433922050	2157	65	22D
0005432231426	2157	66	22E
0005433921983	2157	67	22G
0005433922073	2157	68	23B
0005433922006	2157	69	23E
0005433921996	2157	70	23D
0005433921997	2157	71	24A
0005433875357	2157	72	24B
0005432231425	2157	73	24D
0005433922061	2157	74	24F
0005433922051	2157	75	24E
0005433922038	2157	76	25E
0005432231419	2157	77	25D
0005433922012	2157	78	27B
0005433922074	2157	79	27A
0005433922041	2157	80	27G
0005433922040	2157	81	27F
0005433921993	2157	82	27H
0005433921990	2157	83	28A
0005433922010	2157	84	28E
0005433922003	2157	85	28H
0005433922032	2157	86	28G
0005433922067	2157	87	29A
0005433922049	2157	88	29B
0005433922064	2157	89	29G
0005433921989	2157	90	30D
0005433922042	2157	91	30F
0005433922002	2157	92	31B
0005433921998	2157	93	31A
0005433921991	2157	94	31D
0005432044487	2157	95	31F
0005433922060	2157	96	31G
0005433921988	2157	97	32A
0005433921992	2157	98	32E
0005433922026	2157	99	32D
0005432231418	2157	100	32H
0005433922037	2157	101	33A
0005433922021	2157	102	33D
0005433922019	2157	103	33H
0005433922058	2157	104	34E
0005433922075	2157	105	34F
0005433931426	2157	106	35A
0005433922016	2157	107	34H
0005432044488	2157	108	35D
0005433922034	2157	109	35F
0005433922053	2157	110	35E
0005433922035	2157	111	35H
0005432231422	2157	112	36B
0005433921994	2157	113	36A
0005433922077	2157	114	36D
0005433922031	2157	115	36H
0005433922044	2157	116	37G
0005433922014	2157	117	38A
0005433922054	2157	118	38D
0005433929558	2157	119	38E
0005433922043	2157	120	38H
0005433922046	2157	121	39D
0005433035613	24142	1	1A
0005433921780	24142	2	1F
0005433035604	24142	3	2A
0005433035602	24142	4	1H
0005433035576	24142	5	2B
0005433035608	24142	6	2G
0005433035620	24142	7	3G
0005433035590	24142	8	3H
0005433035612	24142	9	4C
0005433035607	24142	10	4G
0005432206121	24142	11	5A
0005433035588	24142	12	5C
0005433035614	24142	13	5G
0005433035585	24142	14	11D
0005433035596	24142	15	11F
0005433035586	24142	16	12E
0005433035575	24142	17	12D
0005433035616	24142	18	12F
0005432207627	24142	19	13F
0005433035601	24142	20	13H
0005433035606	24142	21	14G
0005433035621	24142	22	15B
0005433035577	24142	23	15A
0005433035619	24142	24	15F
0005433035582	24142	25	16G
0005433035603	24142	26	16F
0005433035622	24142	27	16H
0005433035609	24142	28	17A
0005433035595	24142	29	17H
0005432207628	24142	30	18D
0005433035597	24142	31	19B
0005433035581	24142	32	19F
0005433035574	24142	33	20D
0005433035599	24142	34	20H
0005433035583	24142	35	21F
0005433035592	24142	36	23B
0005433035605	24142	37	23A
0005433035584	24142	38	23D
0005432749756	24142	39	23E
0005432206118	24142	40	23G
0005433035615	24142	41	23F
0005432206116	24142	42	24A
0005433035598	24142	43	24H
0005433921781	24142	44	24G
0005433035594	24142	45	27B
0005432206117	24142	46	28D
0005432206119	24142	47	28H
0005433035623	24142	48	29D
0005433035578	24142	49	29B
0005433035579	24142	50	29E
0005433035591	24142	51	29H
0005433035600	24142	52	30B
0005433035611	24142	53	30E
0005433035572	24142	54	31B
0005433035593	24142	55	32F
0005432749755	24142	56	33D
0005433035618	24142	57	34B
0005433035589	24142	58	35A
0005433035617	24142	59	34H
0005433035573	24142	60	35G
0005433035624	24142	61	36A
0005432206115	24142	62	36B
0005433035580	24142	63	36F
0005433035587	24142	64	37A
0005433035610	24142	65	37E
0005432206120	24142	66	37D
0005433035625	24142	67	37G
0005434723809	255	1	1C
0005434723878	255	2	1H
0005434550484	255	3	1K
0005433233132	255	4	2D
0005434723820	255	5	3A
0005434550502	255	6	3D
0005434723843	255	7	3C
0005434550491	255	8	3K
0005434723811	255	9	3H
0005434550534	255	10	4G
0005435142393	255	11	4C
0005434723865	255	12	4H
0005433233134	255	13	5C
0005434550507	255	14	5H
0005433233133	255	15	11A
0005434302403	255	16	11D
0005434723916	255	17	11F
0005432277636	255	18	11K
0005434723896	255	19	11H
0005434550521	255	20	11G
0005434723830	255	21	12C
0005434723840	255	22	12D
0005434723892	255	23	12F
0005435142401	255	24	13A
0005433233119	255	25	12K
0005435142403	255	26	13D
0005434550532	255	27	13E
0005434550488	255	28	13H
0005434550508	255	29	13G
0005434723837	255	30	14A
0005432277631	255	31	14E
0005434723835	255	32	14C
0005434723890	255	33	14K
0005434550487	255	34	14H
0005434723819	255	35	14G
0005434550536	255	36	15D
0005434550504	255	37	16E
0005434723870	255	38	16H
0005434723887	255	39	16G
0005434723832	255	40	17C
0005432277626	255	41	17E
0005434735616	255	42	17G
0005434550519	255	43	17K
0005434550514	255	44	18D
0005432277632	255	45	18G
0005434723881	255	46	18J
0005434723929	255	47	18H
0005434723924	255	48	19B
0005434723918	255	49	19D
0005434550510	255	50	19C
0005434723874	255	51	19F
0005434550518	255	52	19E
0005434723861	255	53	19H
0005434550489	255	54	20C
0005434723893	255	55	20B
0005434302401	255	56	20F
0005434723836	255	57	20H
0005432277628	255	58	21B
0005434723907	255	59	21A
0005432277635	255	60	20K
0005432277627	255	61	21D
0005434550511	255	62	21E
0005434723884	255	63	21J
0005435142391	255	64	21G
0005434550524	255	65	21K
0005434723901	255	66	22G
0005434302402	255	67	22J
0005434302399	255	68	23B
0005432277629	255	69	23A
0005434731111	255	70	23C
0005434723812	255	71	23F
0005434723806	255	72	23E
0005434550496	255	73	23H
0005434731109	255	74	24D
0005435142402	255	75	24E
0005434735615	255	76	24G
0005434550497	255	77	25C
0005434723823	255	78	25F
0005434735613	255	79	25E
0005434550533	255	80	25G
0005434550523	255	81	26A
0005434723849	255	82	26E
0005434723828	255	83	26D
0005434550495	255	84	26G
0005434723846	255	85	26J
0005434723808	255	86	26H
0005434723919	255	87	27C
0005434723877	255	88	27E
0005434723927	255	89	27D
0005434550516	255	90	27H
0005434723860	255	91	27G
0005434723814	255	92	28A
0005434723895	255	93	28E
0005434723851	255	94	28C
0005432277625	255	95	28G
0005434723921	255	96	28J
0005434723875	255	97	28H
0005434723889	255	98	29F
0005434723852	255	99	29E
0005434723913	255	100	29H
0005434723926	255	101	29G
0005434735614	255	102	30A
0005434723868	255	103	29J
0005434723842	255	104	30C
0005434723886	255	105	30E
0005434723908	255	106	30D
0005434723805	255	107	30F
0005434723824	255	108	30J
0005435142400	255	109	31A
0005434723910	255	110	31C
0005434723914	255	111	31F
0005435142399	255	112	31E
0005434550522	255	113	31J
0005434550509	255	114	31H
0005434550513	255	115	32B
0005434550499	255	116	32E
0005434550493	255	117	32D
0005434723904	255	118	32C
0005435142404	255	119	32F
0005434723911	255	120	32K
0005432277623	255	121	33B
0005434723822	255	122	33A
0005434723825	255	123	33D
0005434723891	255	124	33F
0005434723853	255	125	33E
0005434723839	255	126	33J
0005434550520	255	127	33H
0005434550531	255	128	34A
0005434723900	255	129	33K
0005434723848	255	130	34C
0005434550500	255	131	34H
0005434723909	255	132	34F
0005434723818	255	133	34K
0005434550505	255	134	35C
0005432277624	255	135	35F
0005434723879	255	136	35E
0005434550501	255	137	35H
0005434723810	255	138	36A
0005434723826	255	139	35J
0005434723854	255	140	36B
0005434723922	255	141	36D
0005435142396	255	142	36G
0005432277634	255	143	36K
0005434723880	255	144	36J
0005434723902	255	145	37D
0005435142390	255	146	37C
0005434723855	255	147	37G
0005434550512	255	148	37E
0005434723831	255	149	37J
0005434550525	255	150	37H
0005434550528	255	151	38A
0005434723833	255	152	38C
0005434723905	255	153	38J
0005434723882	255	154	38H
0005435142394	255	155	39A
0005433233118	255	156	38K
0005434723838	255	157	39D
0005432277633	255	158	39J
0005434550506	255	159	39H
0005435142395	255	160	40B
0005434723898	255	161	40A
0005434550486	255	162	40E
0005434723815	255	163	40D
0005434723873	255	164	41B
0005434550494	255	165	41A
0005434723894	255	166	40K
0005434723847	255	167	41D
0005434723883	255	168	41C
0005434723858	255	169	41F
0005434550492	255	170	41E
0005434723869	255	171	41J
0005434723857	255	172	41H
0005434723925	255	173	41G
0005434723888	255	174	42A
0005434723813	255	175	42B
0005434723817	255	176	42E
0005434723903	255	177	42D
0005434723866	255	178	42G
0005434723920	255	179	42H
0005434550527	255	180	43B
0005434723845	255	181	42K
0005434723915	255	182	43D
0005434731112	255	183	43C
0005434723923	255	184	43E
0005434550482	255	185	43J
0005434723885	255	186	44B
0005432277630	255	187	44E
0005434723912	255	188	44F
0005434723917	255	189	44H
0005434550529	255	190	45B
0005434550530	255	191	45A
0005435142392	255	192	44K
0005434550526	255	193	45D
0005434723864	255	194	45C
0005434723816	255	195	45G
0005434550498	255	196	45E
0005434302400	255	197	45H
0005434723876	255	198	45K
0005434723821	255	199	45J
0005434731110	255	200	46E
0005434550517	255	201	46D
0005434550515	255	202	46C
0005435142398	255	203	46G
0005434723844	255	204	46K
0005434723863	255	205	46H
0005434550485	255	206	47C
0005434723862	255	207	47A
0005434723872	255	208	47E
0005434723841	255	209	47G
0005434723829	255	210	47K
0005434723867	255	211	47H
0005433233139	255	212	48A
0005434723897	255	213	48D
0005434723871	255	214	48G
0005434723856	255	215	49A
0005435142397	255	216	48K
0005434550535	255	217	49G
0005434723834	255	218	49F
0005434723859	255	219	49K
0005434723928	255	220	49H
0005434723827	255	221	50C
0005434723899	255	222	50A
0005434550483	255	223	50F
0005434550490	255	224	50E
0005434550503	255	225	50D
0005434723850	255	226	50K
0005434735617	255	227	50H
0005434723807	255	228	51E
0005434723906	255	229	51G
0005433233362	9834	1	1C
0005433233341	9834	2	1K
0005432199153	9834	3	1H
0005433233399	9834	4	2K
0005433180775	9834	5	3G
0005432199154	9834	6	3K
0005433180763	9834	7	4G
0005433766591	9834	8	5C
0005433233363	9834	9	5G
0005433289749	9834	10	11E
0005433233387	9834	11	11D
0005433180757	9834	12	11G
0005433233351	9834	13	12E
0005433180774	9834	14	12H
0005433180771	9834	15	13D
0005433233358	9834	16	13E
0005433180754	9834	17	13K
0005433180758	9834	18	13G
0005433233379	9834	19	14A
0005433289750	9834	20	14D
0005433233385	9834	21	14C
0005433180761	9834	22	14K
0005434031964	9834	23	15C
0005433233376	9834	24	15A
0005433233348	9834	25	15G
0005434723346	9834	26	16C
0005433180767	9834	27	16A
0005433233400	9834	28	16F
0005433233354	9834	29	17C
0005433180752	9834	30	17A
0005433233394	9834	31	17E
0005433233368	9834	32	17G
0005433126785	9834	33	18B
0005433233366	9834	34	18A
0005433233390	9834	35	19B
0005433233386	9834	36	20A
0005433180766	9834	37	20D
0005433233389	9834	38	21D
0005433233380	9834	39	21C
0005433233339	9834	40	22A
0005433233364	9834	41	21K
0005434550290	9834	42	22G
0005433233401	9834	43	23C
0005433233372	9834	44	23H
0005433180772	9834	45	24D
0005433129212	9834	46	24E
0005433126782	9834	47	25D
0005433766592	9834	48	25F
0005433180765	9834	49	25H
0005433129216	9834	50	26A
0005433233347	9834	51	25K
0005433233365	9834	52	25J
0005433129215	9834	53	26E
0005433233350	9834	54	26K
0005433233360	9834	55	27C
0005433233392	9834	56	27J
0005433233359	9834	57	28K
0005433180751	9834	58	28J
0005433233356	9834	59	29K
0005433233377	9834	60	30A
0005433233381	9834	61	30H
0005433233340	9834	62	30G
0005433233382	9834	63	30J
0005433233388	9834	64	31B
0005433233383	9834	65	31A
0005433180768	9834	66	31H
0005433126783	9834	67	31G
0005433129214	9834	68	32A
0005433766588	9834	69	32K
0005433233374	9834	70	32H
0005434031963	9834	71	33J
0005433233343	9834	72	34C
0005433180762	9834	73	34F
0005432199157	9834	74	34H
0005433233375	9834	75	35B
0005433129213	9834	76	35D
0005433233397	9834	77	35C
0005433233396	9834	78	35E
0005434031965	9834	79	35J
0005433233391	9834	80	35G
0005433180760	9834	81	36C
0005433233342	9834	82	36G
0005433289746	9834	83	36K
0005434031966	9834	84	36J
0005433233378	9834	85	37D
0005433233353	9834	86	37C
0005433289747	9834	87	38A
0005433180759	9834	88	37K
0005434723679	9834	89	38C
0005433766590	9834	90	38B
0005433233346	9834	91	38J
0005433233367	9834	92	38H
0005433233369	9834	93	39B
0005433233384	9834	94	39D
0005433233393	9834	95	40A
0005433233371	9834	96	39K
0005433233398	9834	97	40E
0005433233344	9834	98	40J
0005433233349	9834	99	40H
0005433180764	9834	100	41B
0005433180770	9834	101	41A
0005433233361	9834	102	41D
0005433180776	9834	103	41C
0005433289752	9834	104	41J
0005433233370	9834	105	41K
0005433766589	9834	106	42A
0005433233345	9834	107	42G
0005433233337	9834	108	42J
0005433289753	9834	109	42H
0005432199156	9834	110	44D
0005433233357	9834	111	44G
0005434550291	9834	112	44J
0005433180773	9834	113	45A
0005433180769	9834	114	45F
0005433289751	9834	115	45E
0005433180753	9834	116	45G
0005433180755	9834	117	46A
0005433233395	9834	118	45J
0005433233338	9834	119	46B
0005432199158	9834	120	46D
0005433289748	9834	121	46K
0005433233352	9834	122	46H
0005433129217	9834	123	47E
0005434031962	9834	124	47K
0005432199155	9834	125	47H
0005433126784	9834	126	48E
0005434723316	9834	127	48H
0005433180756	9834	128	48G
0005433233373	9834	129	49A
0005433126781	9834	130	50K
0005433233355	9834	131	50H
0005433113505	9834	132	51E
0005432069468	7719	1	1C
0005432150092	7719	2	1A
0005432526290	7719	3	1G
0005434066610	7719	4	1D
0005432526202	7719	5	1K
0005432526277	7719	6	3A
0005434066620	7719	7	2K
0005432526275	7719	8	3D
0005432526291	7719	9	3G
0005432526196	7719	10	4G
0005432526257	7719	11	4K
0005432069466	7719	12	4H
0005432069464	7719	13	5C
0005434066590	7719	14	5H
0005432526236	7719	15	5G
0005434066609	7719	16	5D
0005434066654	7719	17	11A
0005434066586	7719	18	11G
0005432526281	7719	19	11F
0005434066613	7719	20	12C
0005432526183	7719	21	12A
0005434066623	7719	22	12E
0005432526211	7719	23	12G
0005432526249	7719	24	12F
0005432526223	7719	25	13A
0005432526174	7719	26	12K
0005432526267	7719	27	12H
0005432428884	7719	28	13C
0005434066634	7719	29	13F
0005432526283	7719	30	13E
0005432526177	7719	31	14C
0005432150086	7719	32	14A
0005434066646	7719	33	14E
0005432526232	7719	34	14G
0005432526190	7719	35	14K
0005432069463	7719	36	14H
0005432526214	7719	37	15A
0005434066632	7719	38	15E
0005432526241	7719	39	15H
0005434066637	7719	40	16A
0005434066628	7719	41	15K
0005434066647	7719	42	16F
0005434066655	7719	43	16G
0005432526198	7719	44	17C
0005434066603	7719	45	17D
0005432526296	7719	46	17G
0005434066625	7719	47	17F
0005432428883	7719	48	18D
0005432526271	7719	49	18C
0005434066636	7719	50	18G
0005434066635	7719	51	18F
0005432526293	7719	52	18J
0005432526259	7719	53	18H
0005432526215	7719	54	19B
0005432526303	7719	55	18K
0005432526282	7719	56	19F
0005434066622	7719	57	19E
0005432428881	7719	58	19D
0005432526204	7719	59	19H
0005432526297	7719	60	19G
0005432526298	7719	61	20A
0005432533254	7719	62	19K
0005432526213	7719	63	20D
0005434066599	7719	64	20H
0005432526184	7719	65	20F
0005432526205	7719	66	20K
0005432526253	7719	67	21D
0005432526234	7719	68	21C
0005432526170	7719	69	21E
0005432526258	7719	70	21J
0005432526302	7719	71	22C
0005434066596	7719	72	22F
0005434066649	7719	73	22E
0005432526188	7719	74	22G
0005432526212	7719	75	22K
0005434066600	7719	76	22H
0005432526262	7719	77	23B
0005432526270	7719	78	23A
0005432526178	7719	79	23E
0005432526284	7719	80	23D
0005432526264	7719	81	23C
0005432526235	7719	82	23H
0005434066587	7719	83	24D
0005432526220	7719	84	24F
0005432526248	7719	85	24E
0005434066629	7719	86	25A
0005432069461	7719	87	24G
0005434066657	7719	88	25C
0005432526288	7719	89	25H
0005434066591	7719	90	25G
0005432526192	7719	91	26A
0005432526286	7719	92	25K
0005432150088	7719	93	26C
0005432526247	7719	94	26B
0005432526254	7719	95	26G
0005432526217	7719	96	26F
0005432535766	7719	97	26J
0005432526219	7719	98	26H
0005432526289	7719	99	27B
0005432526292	7719	100	26K
0005434066619	7719	101	27C
0005432526278	7719	102	27F
0005432069454	7719	103	27D
0005432526221	7719	104	27H
0005434066650	7719	105	27J
0005432428882	7719	106	28B
0005434066611	7719	107	28E
0005432526244	7719	108	28C
0005432526300	7719	109	28K
0005434066615	7719	110	28J
0005434066585	7719	111	28H
0005434066644	7719	112	29D
0005432526251	7719	113	29C
0005432069455	7719	114	29F
0005432526268	7719	115	29H
0005432069460	7719	116	29G
0005432069467	7719	117	29K
0005434066608	7719	118	29J
0005432526179	7719	119	30C
0005434066614	7719	120	30A
0005432069457	7719	121	30E
0005432526252	7719	122	30G
0005434066612	7719	123	30J
0005432526208	7719	124	31B
0005432069456	7719	125	31A
0005434066642	7719	126	31D
0005432150090	7719	127	31C
0005432533253	7719	128	31F
0005434066601	7719	129	31E
0005432526237	7719	130	31H
0005432526180	7719	131	31G
0005432526238	7719	132	32A
0005435212365	7719	133	32B
0005434066598	7719	134	32E
0005432069459	7719	135	32D
0005434066604	7719	136	32G
0005434066617	7719	137	32J
0005432526239	7719	138	32H
0005432526266	7719	139	33B
0005432150093	7719	140	33A
0005432526229	7719	141	33D
0005432526227	7719	142	33C
0005432526181	7719	143	33F
0005434066595	7719	144	33H
0005432537028	7719	145	34A
0005434066588	7719	146	33J
0005432526285	7719	147	34C
0005432526191	7719	148	34B
0005432526256	7719	149	34G
0005432526228	7719	150	34F
0005432526276	7719	151	34K
0005434066648	7719	152	34J
0005434066626	7719	153	34H
0005434066631	7719	154	35D
0005432526299	7719	155	35C
0005434066593	7719	156	35F
0005432526250	7719	157	35H
0005432069465	7719	158	35G
0005432526230	7719	159	36A
0005432526304	7719	160	35K
0005432526272	7719	161	36D
0005434066592	7719	162	36F
0005434066597	7719	163	36G
0005432526295	7719	164	36K
0005434066638	7719	165	36J
0005432526189	7719	166	37B
0005434066589	7719	167	37A
0005432526193	7719	168	37D
0005432526246	7719	169	37E
0005434066616	7719	170	37J
0005432526255	7719	171	37H
0005432526242	7719	172	38A
0005432526185	7719	173	37K
0005432526222	7719	174	38J
0005432526226	7719	175	38H
0005432069462	7719	176	39B
0005434066618	7719	177	39A
0005434066624	7719	178	38K
0005432526263	7719	179	39D
0005432526216	7719	180	39C
0005432526218	7719	181	39F
0005432535769	7719	182	39E
0005432526186	7719	183	39J
0005432526279	7719	184	40C
0005432537029	7719	185	40B
0005432526201	7719	186	40E
0005432535768	7719	187	40D
0005432526194	7719	188	40F
0005432526224	7719	189	40K
0005432526195	7719	190	40J
0005432526273	7719	191	41B
0005432526245	7719	192	41A
0005434066641	7719	193	41C
0005432526203	7719	194	41J
0005432526187	7719	195	41K
0005434066627	7719	196	42C
0005432069458	7719	197	42F
0005434066605	7719	198	42E
0005432526200	7719	199	42D
0005434066621	7719	200	42G
0005432533252	7719	201	42K
0005432526265	7719	202	42J
0005432526176	7719	203	42H
0005432526182	7719	204	43A
0005434066653	7719	205	43D
0005434066652	7719	206	43C
0005432526243	7719	207	43F
0005434066639	7719	208	43E
0005432526210	7719	209	43G
0005432526280	7719	210	44C
0005432526197	7719	211	44F
0005434066630	7719	212	44J
0005432526301	7719	213	45A
0005435725512	7719	214	44K
0005432150091	7719	215	45D
0005432535767	7719	216	45B
0005434066633	7719	217	45F
0005432526172	7719	218	45E
0005432526240	7719	219	45K
0005432526175	7719	220	45J
0005432526173	7719	221	46D
0005434066656	7719	222	46G
0005434066640	7719	223	46F
0005432150089	7719	224	46J
0005432526287	7719	225	47A
0005432526199	7719	226	46K
0005432526261	7719	227	47E
0005432526231	7719	228	47C
0005434066607	7719	229	47G
0005432526171	7719	230	48A
0005432526260	7719	231	47K
0005432526209	7719	232	48E
0005434066602	7719	233	48G
0005432526207	7719	234	49D
0005432526274	7719	235	49G
0005434066645	7719	236	49F
0005432526225	7719	237	49E
0005432526233	7719	238	49H
0005432526206	7719	239	50A
0005434066651	7719	240	50E
0005434066594	7719	241	50G
0005432526294	7719	242	50K
0005434066643	7719	243	50H
0005432526269	7719	244	51F
0005432150087	7719	245	51D
0005434066606	7719	246	51G
0005434244458	5309	1	1A
0005434343746	5309	2	1H
0005434573162	5309	3	1D
0005434343753	5309	4	1K
0005435612234	5309	5	2C
0005435490182	5309	6	2A
0005435612162	5309	7	2D
0005435612236	5309	8	2K
0005434573160	5309	9	2H
0005435612106	5309	10	3D
0005434343737	5309	11	3K
0005435612230	5309	12	3G
0005434343742	5309	13	4C
0005435612195	5309	14	4A
0005432133007	5309	15	4G
0005435423616	5309	16	4D
0005435612130	5309	17	4H
0005435612123	5309	18	5D
0005435612214	5309	19	5H
0005435612210	5309	20	11A
0005435612204	5309	21	11D
0005435612142	5309	22	11F
0005435612175	5309	23	11E
0005435612136	5309	24	11H
0005435612129	5309	25	12F
0005434343726	5309	26	12H
0005435612177	5309	27	13A
0005435612182	5309	28	13F
0005432047500	5309	29	13E
0005435617167	5309	30	13D
0005435490181	5309	31	13H
0005435491413	5309	32	13G
0005435612189	5309	33	14C
0005435612187	5309	34	14F
0005432133008	5309	35	14G
0005435612224	5309	36	15C
0005435612235	5309	37	15A
0005435612232	5309	38	14K
0005434343750	5309	39	15D
0005434343739	5309	40	15G
0005435612178	5309	41	15F
0005435612205	5309	42	15H
0005434343755	5309	43	16D
0005435612228	5309	44	16C
0005435612180	5309	45	16F
0005435612110	5309	46	16G
0005434343744	5309	47	17E
0005435612223	5309	48	17D
0005434343757	5309	49	17F
0005432133015	5309	50	18C
0005434573165	5309	51	18E
0005435612146	5309	52	18D
0005435612220	5309	53	18G
0005435612183	5309	54	18F
0005435612186	5309	55	18J
0005435612115	5309	56	18H
0005435612151	5309	57	19B
0005432133009	5309	58	19C
0005435612233	5309	59	19F
0005435612179	5309	60	19H
0005435097079	5309	61	19G
0005432133011	5309	62	20B
0005435612145	5309	63	20E
0005434343738	5309	64	20G
0005435612169	5309	65	20F
0005434343734	5309	66	20J
0005435612199	5309	67	21B
0005432133012	5309	68	21A
0005435423630	5309	69	21D
0005435612172	5309	70	21G
0005435612113	5309	71	21F
0005432133006	5309	72	21E
0005432133013	5309	73	21H
0005435612133	5309	74	22H
0005434343756	5309	75	22G
0005435612212	5309	76	23B
0005435612121	5309	77	23A
0005434343727	5309	78	23D
0005435612139	5309	79	23C
0005434343735	5309	80	23H
0005435612198	5309	81	24D
0005435612174	5309	82	24F
0005435612203	5309	83	24E
0005435612143	5309	84	25B
0005435612227	5309	85	25A
0005435612171	5309	86	24G
0005434244460	5309	87	25D
0005435612201	5309	88	25C
0005435612240	5309	89	25F
0005435612152	5309	90	25E
0005435612148	5309	91	25J
0005435612200	5309	92	26C
0005435612197	5309	93	26E
0005435612188	5309	94	26H
0005435612166	5309	95	26F
0005435612208	5309	96	26K
0005432133005	5309	97	27D
0005435612190	5309	98	27C
0005435612202	5309	99	27F
0005434343758	5309	100	27E
0005434573168	5309	101	27G
0005434343760	5309	102	27J
0005435612173	5309	103	28C
0005435612138	5309	104	28B
0005434343745	5309	105	28A
0005435612160	5309	106	28E
0005435612137	5309	107	28D
0005435423593	5309	108	28F
0005432047501	5309	109	28J
0005435612191	5309	110	29A
0005435612108	5309	111	28K
0005434573170	5309	112	29F
0005435612226	5309	113	29J
0005434343729	5309	114	29H
0005435612196	5309	115	30A
0005434343740	5309	116	29K
0005434343730	5309	117	30C
0005434244461	5309	118	30B
0005432133016	5309	119	30D
0005435612217	5309	120	30J
0005435612147	5309	121	31B
0005435612163	5309	122	31A
0005435097083	5309	123	30K
0005435097081	5309	124	31C
0005435612225	5309	125	31G
0005435612209	5309	126	31K
0005435490183	5309	127	31J
0005434343732	5309	128	32B
0005435612132	5309	129	32D
0005434343752	5309	130	32H
0005435612111	5309	131	33D
0005435612117	5309	132	33C
0005432133017	5309	133	33B
0005435612213	5309	134	33H
0005435612193	5309	135	33G
0005435612161	5309	136	33K
0005435612150	5309	137	33J
0005435612194	5309	138	34C
0005435612144	5309	139	34A
0005432133014	5309	140	34E
0005434573159	5309	141	34D
0005435612149	5309	142	34F
0005435612239	5309	143	34J
0005435612134	5309	144	35B
0005435612181	5309	145	34K
0005435097087	5309	146	35D
0005435612109	5309	147	35C
0005435612218	5309	148	35F
0005435617168	5309	149	35E
0005435612125	5309	150	35J
0005435612131	5309	151	35G
0005435612124	5309	152	36A
0005434343743	5309	153	36E
0005435612135	5309	154	36D
0005435612221	5309	155	36F
0005435612211	5309	156	37B
0005434343749	5309	157	37A
0005435612126	5309	158	36K
0005435491414	5309	159	38A
0005434343751	5309	160	38C
0005434343741	5309	161	38B
0005435097085	5309	162	38K
0005434343733	5309	163	38J
0005435612119	5309	164	38H
0005435612231	5309	165	39B
0005435612141	5309	166	39A
0005435097084	5309	167	39C
0005435612159	5309	168	39E
0005435612241	5309	169	39G
0005435612168	5309	170	40B
0005435612176	5309	171	40G
0005434573161	5309	172	40J
0005435612237	5309	173	40H
0005435612238	5309	174	41A
0005434573163	5309	175	41C
0005432133004	5309	176	41G
0005434343748	5309	177	42C
0005434343747	5309	178	42B
0005435612167	5309	179	42D
0005434343725	5309	180	42H
0005435612222	5309	181	42G
0005435097082	5309	182	42F
0005435612112	5309	183	42J
0005435612107	5309	184	42K
0005435612128	5309	185	43D
0005435612164	5309	186	43C
0005434573167	5309	187	43B
0005435612114	5309	188	43G
0005434343759	5309	189	43F
0005435612154	5309	190	44A
0005435612127	5309	191	43K
0005435612156	5309	192	43J
0005435612140	5309	193	44D
0005435097086	5309	194	44G
0005435612155	5309	195	44K
0005435612118	5309	196	44J
0005434573171	5309	197	45A
0005434343728	5309	198	45D
0005435612157	5309	199	45F
0005434573166	5309	200	45E
0005434573172	5309	201	45J
0005435612229	5309	202	45K
0005434573164	5309	203	46C
0005432047498	5309	204	46B
0005435612120	5309	205	46D
0005434343736	5309	206	46H
0005435612165	5309	207	46F
0005432047499	5309	208	46J
0005432133010	5309	209	47C
0005434343754	5309	210	46K
0005435617166	5309	211	47E
0005434573169	5309	212	47K
0005435612170	5309	213	47H
0005435612158	5309	214	48A
0005435612207	5309	215	48E
0005435612185	5309	216	48D
0005435612219	5309	217	48H
0005435612116	5309	218	49A
0005434244457	5309	219	48K
0005435612184	5309	220	49D
0005435097080	5309	221	49C
0005435612192	5309	222	49E
0005435612215	5309	223	50C
0005435612216	5309	224	49K
0005435612122	5309	225	50E
0005434343731	5309	226	51D
0005435555341	5309	227	50K
0005435612153	5309	228	50H
0005435612206	5309	229	51G
0005434244578	10901	1	1D
0005435423907	10901	2	1K
0005435380232	10901	3	2C
0005435319457	10901	4	2A
0005435042830	10901	5	2H
0005435319454	10901	6	2G
0005434244575	10901	7	3K
0005435423887	10901	8	4C
0005435423867	10901	9	4G
0005435423916	10901	10	4H
0005435319458	10901	11	5D
0005435423895	10901	12	5K
0005435423927	10901	13	11E
0005434244583	10901	14	11K
0005434244602	10901	15	12C
0005434244576	10901	16	12A
0005435423901	10901	17	12D
0005435423921	10901	18	12K
0005435423894	10901	19	12H
0005435042827	10901	20	13C
0005435423892	10901	21	13G
0005435423922	10901	22	14D
0005435423924	10901	23	14C
0005435304106	10901	24	14K
0005435423879	10901	25	15E
0005434244579	10901	26	16D
0005435423886	10901	27	16E
0005433719094	10901	28	17A
0005435423913	10901	29	17E
0005435423889	10901	30	17G
0005435423917	10901	31	18B
0005434244574	10901	32	18A
0005435423888	10901	33	18H
0005435304108	10901	34	18J
0005432164935	10901	35	19A
0005435423869	10901	36	18K
0005434244597	10901	37	19F
0005435319453	10901	38	19E
0005435304995	10901	39	19H
0005434656528	10901	40	20A
0005435380230	10901	41	19K
0005435319452	10901	42	19J
0005435380234	10901	43	20K
0005434244582	10901	44	20J
0005435423926	10901	45	20H
0005435423905	10901	46	21C
0005435423909	10901	47	21G
0005435423893	10901	48	22A
0005435423859	10901	49	22B
0005435423873	10901	50	22K
0005432164938	10901	51	22J
0005435423896	10901	52	23E
0005435423919	10901	53	23C
0005435423885	10901	54	23F
0005435319459	10901	55	23J
0005435042829	10901	56	23H
0005434244598	10901	57	23G
0005435423881	10901	58	24G
0005435423866	10901	59	25F
0005435423925	10901	60	25D
0005435380231	10901	61	25K
0005432164939	10901	62	26A
0005434244595	10901	63	26D
0005435423862	10901	64	26K
0005434244596	10901	65	26H
0005435423878	10901	66	27B
0005434244600	10901	67	27A
0005435423906	10901	68	27H
0005435423883	10901	69	28A
0005435423899	10901	70	28E
0005434244573	10901	71	29D
0005435319456	10901	72	29G
0005434244594	10901	73	29J
0005434244591	10901	74	30C
0005435423863	10901	75	30F
0005435042826	10901	76	30J
0005432363373	10901	77	30H
0005432164932	10901	78	31A
0005435423897	10901	79	31D
0005435423882	10901	80	31G
0005435423911	10901	81	32B
0005435423898	10901	82	32A
0005434244603	10901	83	32E
0005435423865	10901	84	32D
0005432166857	10901	85	32F
0005435380233	10901	86	32J
0005432840986	10901	87	33B
0005434244581	10901	88	33A
0005433719095	10901	89	33H
0005434244587	10901	90	34C
0005435423891	10901	91	34B
0005435423910	10901	92	34A
0005435380229	10901	93	34E
0005434244585	10901	94	34G
0005435042828	10901	95	34J
0005432166856	10901	96	35A
0005435423875	10901	97	35H
0005434244601	10901	98	35G
0005435319451	10901	99	36A
0005435423903	10901	100	35J
0005432840985	10901	101	36C
0005435423868	10901	102	36K
0005434244590	10901	103	37F
0005432164934	10901	104	38A
0005432164933	10901	105	38C
0005432166859	10901	106	38B
0005434656529	10901	107	39B
0005432164936	10901	108	39A
0005435423884	10901	109	39G
0005435304997	10901	110	39H
0005435319450	10901	111	40A
0005435423860	10901	112	40B
0005435423902	10901	113	40G
0005434244577	10901	114	40F
0005435423912	10901	115	40K
0005432363372	10901	116	41C
0005435423914	10901	117	41B
0005434244593	10901	118	41E
0005435380228	10901	119	41H
0005435423874	10901	120	42G
0005434244589	10901	121	42J
0005435423861	10901	122	42K
0005434244588	10901	123	43D
0005435423918	10901	124	43C
0005434244592	10901	125	43F
0005434244599	10901	126	43G
0005435423880	10901	127	44B
0005433719097	10901	128	44G
0005435304104	10901	129	44F
0005435304107	10901	130	44J
0005435319455	10901	131	45A
0005435423871	10901	132	45B
0005435423858	10901	133	46A
0005435423900	10901	134	46D
0005435423864	10901	135	46J
0005434244584	10901	136	46H
0005432166858	10901	137	47C
0005435304105	10901	138	47A
0005435423890	10901	139	46K
0005432164937	10901	140	48D
0005435423876	10901	141	48F
0005435423908	10901	142	48G
0005433719096	10901	143	48K
0005434244580	10901	144	49C
0005435423923	10901	145	49E
0005434244586	10901	146	49H
0005435423870	10901	147	49G
0005435423877	10901	148	50A
0005435423904	10901	149	50E
0005435423915	10901	150	50G
0005435304996	10901	151	50K
0005435423920	10901	152	51F
0005435423872	10901	153	51E
0005433506936	3282	1	1C
0005432181426	3282	2	1D
0005432181423	3282	3	1F
0005433506941	3282	4	2C
0005432181425	3282	5	2D
0005433804909	3282	6	3A
0005433804926	3282	7	2F
0005433804902	3282	8	3F
0005433633369	3282	9	4A
0005432181413	3282	10	4F
0005433804916	3282	11	4D
0005433633364	3282	12	5A
0005434143703	3282	13	5C
0005433804919	3282	14	5D
0005433804910	3282	15	6A
0005432181415	3282	16	6C
0005432181430	3282	17	7A
0005433633378	3282	18	6F
0005433804895	3282	19	7C
0005433804925	3282	20	7D
0005432181412	3282	21	7F
0005433633384	3282	22	8C
0005433804924	3282	23	8D
0005432181414	3282	24	8E
0005433506935	3282	25	9A
0005434143701	3282	26	8F
0005433633383	3282	27	9B
0005434143705	3282	28	9D
0005433506939	3282	29	9F
0005433506940	3282	30	9E
0005433804893	3282	31	10A
0005434143698	3282	32	10B
0005433633361	3282	33	10D
0005433506938	3282	34	10C
0005434143699	3282	35	10E
0005433804912	3282	36	11A
0005432181421	3282	37	10F
0005433804908	3282	38	11C
0005432181416	3282	39	11E
0005433804921	3282	40	12A
0005433506932	3282	41	12B
0005432181417	3282	42	12C
0005433506943	3282	43	13B
0005433804901	3282	44	13C
0005433804913	3282	45	13D
0005433804927	3282	46	13E
0005433804907	3282	47	14A
0005433804922	3282	48	13F
0005432181429	3282	49	14C
0005434143700	3282	50	14B
0005433633385	3282	51	14D
0005433804906	3282	52	14E
0005433804923	3282	53	14F
0005432181428	3282	54	15B
0005433804930	3282	55	15A
0005433633367	3282	56	15C
0005433633366	3282	57	15E
0005433506931	3282	58	15F
0005433804898	3282	59	16B
0005433804900	3282	60	16D
0005433804911	3282	61	16F
0005433506933	3282	62	17B
0005433633363	3282	63	17A
0005433633355	3282	64	17C
0005433633375	3282	65	17D
0005433804929	3282	66	17E
0005433633379	3282	67	18A
0005432181411	3282	68	18C
0005433804914	3282	69	18F
0005433804899	3282	70	19C
0005433804903	3282	71	19D
0005433633374	3282	72	19E
0005432181424	3282	73	20B
0005433633372	3282	74	20A
0005433633370	3282	75	20E
0005433804894	3282	76	20D
0005433804920	3282	77	20F
0005433804896	3282	78	21A
0005433804897	3282	79	21D
0005433633360	3282	80	21E
0005433804904	3282	81	22A
0005433506942	3282	82	22D
0005433633376	3282	83	22C
0005433633362	3282	84	22E
0005433633356	3282	85	22F
0005432181419	3282	86	23C
0005433633380	3282	87	23B
0005433506934	3282	88	23D
0005433633387	3282	89	23E
0005433633358	3282	90	23F
0005434143702	3282	91	24B
0005432181427	3282	92	24A
0005433804932	3282	93	24E
0005433633386	3282	94	24D
0005433506930	3282	95	24F
0005433804917	3282	96	25A
0005433804933	3282	97	25C
0005432181422	3282	98	25D
0005433633371	3282	99	26C
0005433633368	3282	100	26D
0005432181420	3282	101	26F
0005433804928	3282	102	27A
0005433506937	3282	103	27C
0005433804905	3282	104	27B
0005433633382	3282	105	27D
0005432181418	3282	106	27F
0005432181410	3282	107	27E
0005433804931	3282	108	28C
0005433633381	3282	109	28E
0005433633359	3282	110	28F
0005433804918	3282	111	29B
0005432181431	3282	112	29A
0005433633373	3282	113	29F
0005433633377	3282	114	30A
0005433804915	3282	115	30B
0005433633365	3282	116	30C
0005434143704	3282	117	30D
0005433633357	3282	118	31B
0005435884507	3283	1	8F
0005435884427	3283	2	12C
0005435884506	3283	3	17B
0005435884505	3283	4	17E
0005432042531	8184	1	1F
0005435884583	8184	2	1D
0005435884605	8184	3	2C
0005432459177	8184	4	2A
0005432042532	8184	5	2D
0005432042534	8184	6	3A
0005435884611	8184	7	3F
0005432459218	8184	8	4A
0005435884601	8184	9	4C
0005435884613	8184	10	5C
0005432459186	8184	11	5D
0005432459222	8184	12	6A
0005432042526	8184	13	5F
0005435884618	8184	14	6C
0005435884615	8184	15	6F
0005434326261	8184	16	7A
0005432459187	8184	17	7C
0005435884599	8184	18	7F
0005432459211	8184	19	8C
0005432459188	8184	20	8E
0005432459212	8184	21	8F
0005432459178	8184	22	9A
0005432042527	8184	23	9C
0005432459195	8184	24	9F
0005435884606	8184	25	10A
0005432042528	8184	26	10B
0005432459217	8184	27	10D
0005435884602	8184	28	10C
0005432459221	8184	29	10F
0005435884621	8184	30	11A
0005432459200	8184	31	11C
0005432459219	8184	32	11D
0005435884579	8184	33	11E
0005435884582	8184	34	12B
0005432459171	8184	35	12F
0005432042529	8184	36	13B
0005435884600	8184	37	13A
0005432459174	8184	38	13C
0005435884586	8184	39	13F
0005432459204	8184	40	14B
0005432459216	8184	41	14A
0005432459210	8184	42	14D
0005432459214	8184	43	15A
0005435884589	8184	44	14F
0005432459172	8184	45	15C
0005435884584	8184	46	15B
0005435884581	8184	47	15D
0005432459199	8184	48	16A
0005432459213	8184	49	16B
0005435884608	8184	50	16F
0005435884619	8184	51	16E
0005432042530	8184	52	17C
0005432042525	8184	53	17D
0005432042537	8184	54	17E
0005432459197	8184	55	18A
0005432459183	8184	56	18B
0005432042533	8184	57	18C
0005435884620	8184	58	18E
0005435884595	8184	59	19B
0005432459184	8184	60	19D
0005432459203	8184	61	19E
0005432459198	8184	62	20B
0005435884603	8184	63	20A
0005432459196	8184	64	20C
0005432459220	8184	65	20E
0005432042536	8184	66	20D
0005432459193	8184	67	21B
0005434312292	8184	68	21D
0005432459189	8184	69	21F
0005432459205	8184	70	21E
0005432459215	8184	71	22B
0005432459208	8184	72	22D
0005432459175	8184	73	22C
0005432459179	8184	74	22F
0005435884612	8184	75	23A
0005432459191	8184	76	23C
0005435884614	8184	77	23B
0005435884593	8184	78	24A
0005435884596	8184	79	23F
0005432459185	8184	80	24B
0005435884592	8184	81	24C
0005432459202	8184	82	24E
0005435884607	8184	83	25B
0005435884580	8184	84	25A
0005432459201	8184	85	25E
0005432042535	8184	86	25D
0005435884617	8184	87	25F
0005435884591	8184	88	26B
0005435884610	8184	89	26C
0005432459194	8184	90	26D
0005432459176	8184	91	27D
0005435884609	8184	92	27C
0005435884594	8184	93	28A
0005432459173	8184	94	27F
0005435884604	8184	95	28C
0005435884616	8184	96	28D
0005435884585	8184	97	28F
0005432459190	8184	98	29A
0005435884587	8184	99	29C
0005432459209	8184	100	29B
0005432459206	8184	101	29D
0005432459207	8184	102	29E
0005434312293	8184	103	29F
0005432459182	8184	104	30A
0005435884597	8184	105	30C
0005435884598	8184	106	30E
0005432459180	8184	107	31C
0005435884588	8184	108	31B
0005432459192	8184	109	31D
0005435884590	8184	110	31F
0005432459181	8184	111	31E
0005435854042	8183	1	8E
0005435854041	8183	2	9E
0005435854043	8183	3	23C
0005435854044	8183	4	24E
0005434183544	8338	1	11F
0005432382662	4565	1	1C
0005432382663	4565	2	1F
0005432382661	4565	3	2A
0005432382676	4565	4	2D
0005432727772	4565	5	2F
0005432382668	4565	6	3A
0005432382664	4565	7	3F
0005432727778	4565	8	4A
0005432382683	4565	9	4E
0005432382651	4565	10	5A
0005432382652	4565	11	5D
0005432727777	4565	12	6A
0005432727773	4565	13	6C
0005432382660	4565	14	6E
0005433453735	4565	15	6F
0005432382684	4565	16	7A
0005432382656	4565	17	7C
0005432382679	4565	18	7D
0005432382674	4565	19	7E
0005432382655	4565	20	7F
0005432382659	4565	21	8A
0005432382665	4565	22	8C
0005432727776	4565	23	8E
0005432382681	4565	24	9A
0005432382667	4565	25	9C
0005432727770	4565	26	9D
0005432382649	4565	27	10A
0005432727769	4565	28	10C
0005432382682	4565	29	10D
0005432382672	4565	30	10F
0005432727768	4565	31	11A
0005433722129	4565	32	11D
0005432382658	4565	33	11E
0005432727771	4565	34	12A
0005432382669	4565	35	12C
0005433454847	4565	36	12D
0005432727775	4565	37	12E
0005432382677	4565	38	13A
0005432382678	4565	39	14A
0005433453736	4565	40	14D
0005433722131	4565	41	14C
0005432382687	4565	42	14F
0005433194825	4565	43	15A
0005432382657	4565	44	15C
0005433722130	4565	45	15D
0005433194824	4565	46	15E
0005432382685	4565	47	15F
0005432727767	4565	48	16C
0005432382673	4565	49	16D
0005432382653	4565	50	16E
0005432382675	4565	51	17A
0005432382690	4565	52	17C
0005432727774	4565	53	17E
0005432382650	4565	54	17F
0005432727779	4565	55	18A
0005433722128	4565	56	18C
0005432382671	4565	57	18D
0005432382654	4565	58	18E
0005432382686	4565	59	19A
0005432382689	4565	60	19C
0005432382666	4565	61	19E
0005432382670	4565	62	19F
0005432382688	4565	63	20C
0005432382680	4565	64	20F
0005432727718	30262	1	1A
0005432727738	30262	2	7E
0005433516763	1750	1	1A
0005433516767	1750	2	1C
0005435540726	1750	3	1D
0005435528977	1750	4	1F
0005435528970	1750	5	2A
0005435528973	1750	6	2D
0005435528987	1750	7	2F
0005432924951	1750	8	3C
0005433516762	1750	9	3D
0005433516761	1750	10	3F
0005435540730	1750	11	4C
0005435540723	1750	12	4D
0005435528978	1750	13	5C
0005435540725	1750	14	5D
0005435540728	1750	15	6C
0005435540711	1750	16	6D
0005435528974	1750	17	6E
0005435528988	1750	18	6F
0005435540717	1750	19	7E
0005432924952	1750	20	7F
0005435528981	1750	21	8A
0005435528982	1750	22	8C
0005435528975	1750	23	8D
0005435528968	1750	24	8E
0005435528972	1750	25	8F
0005433516765	1750	26	9A
0005435528985	1750	27	9C
0005435528967	1750	28	10C
0005435528986	1750	29	10D
0005435540714	1750	30	10F
0005435528979	1750	31	11C
0005435540715	1750	32	11E
0005435540724	1750	33	12A
0005435540720	1750	34	12D
0005435540719	1750	35	12F
0005435540727	1750	36	13D
0005433516760	1750	37	13E
0005435528976	1750	38	13F
0005435540732	1750	39	14A
0005435528983	1750	40	14D
0005435540716	1750	41	15C
0005432294456	1750	42	15E
0005435540718	1750	43	15F
0005433516766	1750	44	16C
0005435528984	1750	45	16D
0005435540721	1750	46	16E
0005435540713	1750	47	16F
0005435540733	1750	48	17A
0005435540729	1750	49	17C
0005433516759	1750	50	17D
0005435528971	1750	51	17F
0005435528980	1750	52	18A
0005435540731	1750	53	18F
0005435540722	1750	54	19D
0005432294455	1750	55	19E
0005435528969	1750	56	20C
0005435540712	1750	57	20D
0005433516758	1750	58	20E
0005433516764	1750	59	20F
0005432924974	22008	1	2D
0005432924971	22008	2	4C
0005432924975	22008	3	8F
0005432924973	22008	4	11E
0005432924972	22008	5	15E
0005432924976	22008	6	20C
0005432838627	7388	1	1A
0005432838640	7388	2	1C
0005432838629	7388	3	1D
0005432838612	7388	4	2A
0005434458537	7388	5	2F
0005434458535	7388	6	3A
0005432838637	7388	7	3D
0005432838636	7388	8	3F
0005432838626	7388	9	4C
0005432823422	7388	10	4D
0005432838633	7388	11	4E
0005434458522	7388	12	4F
0005434458529	7388	13	5A
0005434458539	7388	14	5C
0005432838631	7388	15	5D
0005432073345	7388	16	5E
0005432838609	7388	17	5F
0005432838618	7388	18	6D
0005434458531	7388	19	6F
0005434458519	7388	20	7A
0005434458527	7388	21	7C
0005434458520	7388	22	7E
0005432838619	7388	23	7F
0005432838624	7388	24	8A
0005432838610	7388	25	8C
0005432838632	7388	26	8D
0005432838623	7388	27	8E
0005434458534	7388	28	8F
0005432823423	7388	29	9A
0005432838639	7388	30	9C
0005434458525	7388	31	9F
0005434458521	7388	32	10D
0005432838608	7388	33	10F
0005432073344	7388	34	11A
0005432838621	7388	35	11E
0005432838615	7388	36	11F
0005434458536	7388	37	12C
0005434458524	7388	38	12D
0005432838635	7388	39	12F
0005432073343	7388	40	13A
0005434458528	7388	41	13E
0005434458530	7388	42	13F
0005432838630	7388	43	14A
0005432838622	7388	44	14D
0005432838634	7388	45	14E
0005432838613	7388	46	15E
0005432838625	7388	47	15F
0005432838638	7388	48	16A
0005432838607	7388	49	16F
0005434458533	7388	50	17A
0005432838614	7388	51	17C
0005432838628	7388	52	17E
0005432838620	7388	53	17F
0005432838611	7388	54	18A
0005432840983	7388	55	18E
0005432838617	7388	56	18F
0005434458526	7388	57	19C
0005434458523	7388	58	19D
0005434458532	7388	59	20A
0005432838616	7388	60	19F
0005434458538	7388	61	20D
0005432840984	7388	62	20F
0005435252467	28929	1	1C
0005435252458	28929	2	5A
0005435252455	28929	3	6C
0005435252453	28929	4	6E
0005434664931	28929	5	7E
0005435252470	28929	6	9C
0005435252464	28929	7	10F
0005435252471	28929	8	11E
0005435252469	28929	9	11F
0005435252460	28929	10	12C
0005435252466	28929	11	13A
0005435252457	28929	12	13D
0005432000996	28929	13	14A
0005434664930	28929	14	14E
0005435252456	28929	15	15C
0005435252459	28929	16	15D
0005435252462	28929	17	16D
0005435252463	28929	18	16E
0005435252465	28929	19	16F
0005435252461	28929	20	19A
0005435252468	28929	21	19D
0005435252454	28929	22	20F
0005435990527	8779	1	4A
0005435990529	8779	2	5D
0005435990530	8779	3	8F
0005435990532	8779	4	13F
0005435990531	8779	5	15C
0005435990528	8779	6	21B
0005434275950	15759	1	3C
0005434275949	15759	2	5F
0005434275948	15759	3	8B
0005434275947	15759	4	10F
0005434275952	15759	5	16A
0005434275951	15759	6	18C
0005433476861	30857	1	3A
0005433476860	30857	2	3B
0005433476865	30857	3	3C
0005433476863	30857	4	5C
0005433476859	30857	5	7B
0005433476862	30857	6	7C
0005433476864	30857	7	20D
0005432909207	23832	1	1C
0005432909210	23832	2	2A
0005432909208	23832	3	3A
0005432909214	23832	4	4B
0005432909215	23832	5	4C
0005432909209	23832	6	5B
0005432909211	23832	7	6C
0005432909212	23832	8	7B
0005432909216	23832	9	7C
0005432909213	23832	10	21A
0005432335879	6365	1	1D
0005432359736	6365	2	3A
0005432359735	6365	3	3C
0005432359704	6365	4	3F
0005432359708	6365	5	4A
0005432359733	6365	6	4D
0005432359731	6365	7	4C
0005432335871	6365	8	4F
0005432359719	6365	9	5B
0005432359751	6365	10	5A
0005432359740	6365	11	5C
0005432359732	6365	12	5D
0005432359726	6365	13	5E
0005432359718	6365	14	6A
0005432359734	6365	15	6C
0005432359748	6365	16	6D
0005432335870	6365	17	6E
0005432363373	6365	18	7A
0005432062156	6365	19	6F
0005432335876	6365	20	7B
0005432359717	6365	21	7C
0005432363372	6365	22	8A
0005432359738	6365	23	7F
0005432359721	6365	24	8B
0005432359713	6365	25	9A
0005432359711	6365	26	8F
0005432359743	6365	27	9B
0005432359709	6365	28	9E
0005432359707	6365	29	9D
0005432359729	6365	30	9F
0005432359741	6365	31	10B
0005432335874	6365	32	10D
0005432062159	6365	33	11A
0005432062160	6365	34	10E
0005432359706	6365	35	11C
0005432359730	6365	36	11D
0005432062158	6365	37	11F
0005432335872	6365	38	12A
0005432335880	6365	39	12E
0005432359746	6365	40	12F
0005432359728	6365	41	13C
0005432359752	6365	42	13E
0005432335877	6365	43	14B
0005432359720	6365	44	14E
0005432359747	6365	45	15B
0005432335873	6365	46	15F
0005432335875	6365	47	16B
0005432359739	6365	48	16A
0005432359745	6365	49	16C
0005432359727	6365	50	16D
0005432359724	6365	51	17A
0005432359725	6365	52	17C
0005432359744	6365	53	17E
0005432359710	6365	54	17D
0005432359714	6365	55	18B
0005432359750	6365	56	18D
0005432359712	6365	57	18E
0005432359723	6365	58	18F
0005432359737	6365	59	19B
0005432359749	6365	60	19E
0005435176637	6365	61	19D
0005432335878	6365	62	20A
0005432062155	6365	63	20E
0005432359742	6365	64	21A
0005432359705	6365	65	21C
0005432062157	6365	66	21F
0005432359715	6365	67	22D
0005432335869	6365	68	23A
0005432359722	6365	69	22F
0005432359716	6365	70	23B
0005434149578	21002	1	1A
0005435490184	21002	2	1C
0005435176713	21002	3	1F
0005435176708	21002	4	2D
0005432052704	21002	5	2F
0005435176719	21002	6	3C
0005435176710	21002	7	3D
0005435176715	21002	8	3F
0005435176702	21002	9	4B
0005435176707	21002	10	4C
0005434149574	21002	11	4D
0005434149577	21002	12	4E
0005432359547	21002	13	5D
0005434149569	21002	14	5F
0005435176700	21002	15	6B
0005432359557	21002	16	6A
0005435176725	21002	17	6D
0005432052707	21002	18	7D
0005435176704	21002	19	7E
0005432052708	21002	20	9A
0005432052705	21002	21	10B
0005435176724	21002	22	11B
0005435176703	21002	23	11D
0005434149571	21002	24	11C
0005435176716	21002	25	11E
0005435176723	21002	26	12E
0005435176712	21002	27	13B
0005432052706	21002	28	13E
0005435176699	21002	29	14B
0005434149573	21002	30	15D
0005434149579	21002	31	16A
0005434149572	21002	32	15F
0005435176717	21002	33	16B
0005435176705	21002	34	16D
0005435176714	21002	35	17B
0005435176718	21002	36	17D
0005435176720	21002	37	18B
0005435176722	21002	38	18A
0005435176711	21002	39	18E
0005435176709	21002	40	18D
0005435176698	21002	41	19A
0005434149576	21002	42	19D
0005435176706	21002	43	19F
0005432359546	21002	44	20D
0005435176701	21002	45	20E
0005432359558	21002	46	20F
0005434149570	21002	47	22C
0005434149568	21002	48	23A
0005435176721	21002	49	22F
0005434149575	21002	50	23F
0005434458464	17698	1	1D
0005434186162	17698	2	2A
0005434186161	17698	3	3D
0005434458465	17698	4	4A
0005434461608	17698	5	5D
0005434186160	17698	6	22A
0005434448267	29127	1	1A
0005434458527	29127	2	1B
0005434458525	29127	3	1D
0005434458539	29127	4	2A
0005434458523	29127	5	2B
0005434462760	29127	6	2D
0005434458519	29127	7	3A
0005434458531	29127	8	3B
0005434458529	29127	9	3D
0005434458535	29127	10	4B
0005434458532	29127	11	5B
0005434458520	29127	12	5D
0005434458522	29127	13	5C
0005434448266	29127	14	6D
0005434458521	29127	15	7A
0005434458537	29127	16	7C
0005434458524	29127	17	7D
0005434458528	29127	18	18B
0005434458530	29127	19	18D
0005434458534	29127	20	19A
0005434458538	29127	21	19C
0005434458536	29127	22	20B
0005434448265	29127	23	21A
0005434463899	29127	24	21C
0005434463898	29127	25	21D
0005434462759	29127	26	22A
0005434458533	29127	27	22C
0005434458526	29127	28	23B
0005432603774	21422	1	1A
0005432603778	21422	2	1B
0005432603767	21422	3	1C
0005432603784	21422	4	1D
0005432603790	21422	5	2B
0005432603801	21422	6	2C
0005432603803	21422	7	2D
0005432603797	21422	8	3A
0005432603780	21422	9	3B
0005432603789	21422	10	3D
0005432603764	21422	11	4A
0005432603783	21422	12	4B
0005432603763	21422	13	4C
0005432603773	21422	14	4D
0005432603796	21422	15	5A
0005432603779	21422	16	5B
0005432603795	21422	17	5C
0005432603786	21422	18	5D
0005432603800	21422	19	6A
0005432603791	21422	20	6B
0005432603768	21422	21	6D
0005432603785	21422	22	7A
0005432603799	21422	23	7B
0005432603766	21422	24	7D
0005432603775	21422	25	18A
0005432603802	21422	26	18C
0005432603776	21422	27	19B
0005432603771	21422	28	19C
0005432603792	21422	29	20A
0005432603777	21422	30	20B
0005432603770	21422	31	20C
0005432603793	21422	32	21A
0005432603769	21422	33	21B
0005432603787	21422	34	21C
0005432603781	21422	35	21D
0005432603765	21422	36	22A
0005432603782	21422	37	22B
0005432603772	21422	38	22C
0005432603794	21422	39	22D
0005432603788	21422	40	23A
0005432603798	21422	41	23B
0005433293170	29616	1	1A
0005433293175	29616	2	1C
0005433293164	29616	3	3A
0005433293173	29616	4	3C
0005433293165	29616	5	5A
0005433293167	29616	6	6A
0005433293169	29616	7	6D
0005433293177	29616	8	7A
0005433293171	29616	9	19B
0005433293176	29616	10	19D
0005433293172	29616	11	20A
0005433293166	29616	12	21A
0005433293174	29616	13	22C
0005433293168	29616	14	23A
0005433473146	6679	1	2A
0005433473143	6679	2	3D
0005433473142	6679	3	4A
0005433473131	6679	4	4B
0005433473138	6679	5	4D
0005433473136	6679	6	5A
0005433473145	6679	7	6A
0005433473134	6679	8	6D
0005433473129	6679	9	7B
0005433473130	6679	10	7C
0005433473132	6679	11	19A
0005433473147	6679	12	18D
0005433473133	6679	13	19B
0005433473135	6679	14	19C
0005433473140	6679	15	20A
0005433473137	6679	16	21B
0005433473141	6679	17	21D
0005433473144	6679	18	22A
0005433473139	6679	19	22D
0005433473128	6679	20	23B
0005435257163	23888	1	1B
0005435257160	23888	2	1C
0005435257169	23888	3	3A
0005435257167	23888	4	3C
0005435257164	23888	5	4A
0005435257168	23888	6	4C
0005435257162	23888	7	5B
0005435257166	23888	8	7D
0005435257159	23888	9	18B
0005435257161	23888	10	20D
0005435257170	23888	11	21B
0005435257158	23888	12	22A
0005435257165	23888	13	23B
0005434606772	22347	1	2B
0005434606775	22347	2	3A
0005434606774	22347	3	3B
0005434604846	22347	4	4A
0005434604848	22347	5	4B
0005434604847	22347	6	5B
0005434606773	22347	7	5A
0005434602872	3844	1	1B
0005434522395	3844	2	2B
0005434522388	3844	3	3B
0005434522390	3844	4	3C
0005434522392	3844	5	4A
0005434602873	3844	6	5A
0005434522394	3844	7	6A
0005434602874	3844	8	6B
0005434602868	3844	9	19A
0005434602870	3844	10	19B
0005434522389	3844	11	19C
0005434522393	3844	12	19D
0005434602871	3844	13	21A
0005434602869	3844	14	21B
0005434522391	3844	15	22C
0005435904374	19051	1	7B
0005435904376	19051	2	7C
0005435904375	19051	3	19A
0005435904377	19051	4	22B
0005435904373	19051	5	22C
0005432747058	392	1	1A
0005432747052	392	2	1C
0005432747046	392	3	1D
0005432747053	392	4	1F
0005432747055	392	5	2A
0005432747032	392	6	2C
0005432751477	392	7	2D
0005432747022	392	8	3A
0005432747040	392	9	4A
0005432747027	392	10	4C
0005432747029	392	11	4D
0005432747060	392	12	4F
0005432749754	392	13	5A
0005432747023	392	14	5F
0005432747041	392	15	6D
0005432747056	392	16	7A
0005432751480	392	17	7D
0005432747042	392	18	7E
0005432747033	392	19	7F
0005432747044	392	20	8C
0005432747048	392	21	8D
0005432747031	392	22	9A
0005432219943	392	23	9C
0005432219946	392	24	9D
0005432747057	392	25	9E
0005432747051	392	26	10D
0005432747035	392	27	10F
0005432747043	392	28	11E
0005432749753	392	29	11F
0005432747026	392	30	12A
0005432747047	392	31	12D
0005432753254	392	32	12E
0005432747034	392	33	13A
0005432747059	392	34	13C
0005432751479	392	35	13D
0005432753253	392	36	13F
0005432747024	392	37	14C
0005432747054	392	38	14D
0005432747050	392	39	14F
0005432751478	392	40	15A
0005432747038	392	41	15C
0005432747036	392	42	15D
0005432747049	392	43	15F
0005432747045	392	44	16A
0005432747039	392	45	16F
0005432219944	392	46	17D
0005435154589	392	47	17F
0005432747037	392	48	18A
0005435154590	392	49	18C
0005432747030	392	50	18D
0005432747025	392	51	18F
0005432753252	392	52	19A
0005432219945	392	53	19F
0005432747028	392	54	20C
0005432747061	392	55	20E
0005432214775	12063	1	1C
0005432890754	12063	2	1D
0005432890757	12063	3	1F
0005432890750	12063	4	3A
0005432890752	12063	5	4C
0005432214776	12063	6	4E
0005432214774	12063	7	5C
0005434153518	12063	8	5E
0005432890759	12063	9	6E
0005432890751	12063	10	6F
0005432890760	12063	11	7D
0005432890768	12063	12	8E
0005432746899	12063	13	9F
0005432890765	12063	14	10A
0005432890763	12063	15	11C
0005432890755	12063	16	12A
0005432890749	12063	17	12E
0005432890766	12063	18	13A
0005432746934	12063	19	13F
0005432746875	12063	20	15E
0005433875359	12063	21	16C
0005432890761	12063	22	17D
0005432214773	12063	23	17E
0005433875358	12063	24	18A
0005432890753	12063	25	18C
0005432890767	12063	26	18D
0005432890764	12063	27	18E
0005432890756	12063	28	19C
0005432890758	12063	29	19D
0005432746876	12063	30	19F
0005432890762	12063	31	20D
0005433531240	18985	1	1A
0005433524886	18985	2	2B
0005433533256	18985	3	2C
0005433531239	18985	4	3B
0005433531237	18985	5	3C
0005433524885	18985	6	3D
0005433524888	18985	7	4C
0005433524889	18985	8	4D
0005433533255	18985	9	7C
0005433524887	18985	10	18B
0005433524883	18985	11	19B
0005433533253	18985	12	20B
0005433524881	18985	13	20D
0005433524882	18985	14	22B
0005433524884	18985	15	22D
0005433531238	18985	16	23A
0005433533254	18985	17	23B
0005432927913	32492	1	1C
0005433531228	32492	2	3A
0005433531227	32492	3	5D
0005432927910	32492	4	19B
0005432927912	32492	5	20B
0005432927911	32492	6	20C
0005432927909	32492	7	22B
0005435304095	5274	1	1H
0005434821914	5274	2	1D
0005434821841	5274	3	2A
0005434821961	5274	4	2C
0005434821929	5274	5	2H
0005434821879	5274	6	2G
0005434821953	5274	7	2K
0005434664927	5274	8	3K
0005434821895	5274	9	5G
0005434821894	5274	10	11A
0005434821919	5274	11	5K
0005432121140	5274	12	11K
0005435149847	5274	13	11G
0005432121143	5274	14	12D
0005432396190	5274	15	12K
0005434831084	5274	16	14A
0005435149855	5274	17	14E
0005434821926	5274	18	14C
0005434821899	5274	19	14K
0005434821932	5274	20	14H
0005434821872	5274	21	15C
0005434821836	5274	22	15A
0005432121144	5274	23	15H
0005432394051	5274	24	15G
0005435149854	5274	25	15F
0005434821867	5274	26	15K
0005434821896	5274	27	16F
0005434821934	5274	28	16E
0005434821903	5274	29	16H
0005434821859	5274	30	16G
0005434821912	5274	31	17C
0005434821908	5274	32	16K
0005434821846	5274	33	17D
0005434821944	5274	34	17G
0005434821897	5274	35	17H
0005434821881	5274	36	18C
0005434821863	5274	37	18B
0005435149849	5274	38	19C
0005434821940	5274	39	19F
0005432394049	5274	40	19J
0005434821869	5274	41	19G
0005435149850	5274	42	20A
0005434821957	5274	43	20C
0005434821840	5274	44	20D
0005434821956	5274	45	20G
0005434828658	5274	46	20F
0005434821854	5274	47	20J
0005435149844	5274	48	21C
0005434821909	5274	49	21G
0005434821922	5274	50	22A
0005434558162	5274	51	21K
0005434821835	5274	52	22C
0005434821838	5274	53	22B
0005434821941	5274	54	22E
0005434821865	5274	55	22D
0005434821842	5274	56	22H
0005434821937	5274	57	22G
0005434558161	5274	58	23C
0005434664929	5274	59	23G
0005434821890	5274	60	23F
0005434821866	5274	61	23J
0005434821893	5274	62	23K
0005432121150	5274	63	25A
0005434821883	5274	64	24G
0005432396188	5274	65	25D
0005434821839	5274	66	25B
0005434558167	5274	67	25J
0005432121153	5274	68	25G
0005434821935	5274	69	25K
0005434821936	5274	70	26B
0005434821959	5274	71	26E
0005434821945	5274	72	26D
0005434821939	5274	73	27B
0005434821855	5274	74	27A
0005434821916	5274	75	27D
0005434558169	5274	76	27C
0005434821845	5274	77	27F
0005434821904	5274	78	27H
0005434821847	5274	79	28A
0005434821853	5274	80	28C
0005434821892	5274	81	28B
0005432394048	5274	82	28J
0005434558168	5274	83	28H
0005434558166	5274	84	29B
0005434821886	5274	85	29A
0005434821943	5274	86	28K
0005435149848	5274	87	29E
0005434821902	5274	88	29H
0005434821834	5274	89	29G
0005434828657	5274	90	30A
0005435304096	5274	91	29K
0005434821875	5274	92	30B
0005434821927	5274	93	30E
0005434558163	5274	94	30D
0005432121149	5274	95	30F
0005435149841	5274	96	30K
0005432396187	5274	97	31B
0005434821862	5274	98	31G
0005434831085	5274	99	32C
0005434821888	5274	100	32D
0005434821887	5274	101	32G
0005434821948	5274	102	32J
0005432121152	5274	103	32K
0005434821889	5274	104	33D
0005432121145	5274	105	33G
0005434821931	5274	106	33K
0005434821877	5274	107	33J
0005432121142	5274	108	34C
0005434821849	5274	109	34B
0005434821925	5274	110	34E
0005434821852	5274	111	34D
0005434831083	5274	112	34F
0005434821856	5274	113	35A
0005434821844	5274	114	35D
0005435149843	5274	115	35C
0005434821910	5274	116	35F
0005434821891	5274	117	35H
0005434821884	5274	118	36E
0005434828656	5274	119	36D
0005434821898	5274	120	36J
0005434821947	5274	121	37B
0005434821831	5274	122	37D
0005434821873	5274	123	37J
0005432396191	5274	124	37H
0005434821882	5274	125	37G
0005434821950	5274	126	38A
0005434821880	5274	127	37K
0005432121147	5274	128	38B
0005434821960	5274	129	38J
0005434821901	5274	130	38H
0005432394050	5274	131	39A
0005434821843	5274	132	38K
0005434821857	5274	133	39F
0005434821952	5274	134	39E
0005434821871	5274	135	39H
0005434821858	5274	136	39G
0005434821832	5274	137	39J
0005434821850	5274	138	40E
0005434821946	5274	139	40G
0005434821874	5274	140	40F
0005434821915	5274	141	40J
0005434821928	5274	142	41B
0005432121148	5274	143	41A
0005434821949	5274	144	41F
0005434831082	5274	145	41J
0005434664926	5274	146	42A
0005434821924	5274	147	41K
0005432121154	5274	148	42C
0005434821876	5274	149	42E
0005434821920	5274	150	42K
0005435149851	5274	151	42J
0005434821900	5274	152	42H
0005434821868	5274	153	43A
0005434821954	5274	154	43D
0005434821851	5274	155	43E
0005434821878	5274	156	43J
0005432121151	5274	157	43H
0005434558160	5274	158	44B
0005432396189	5274	159	44E
0005434821923	5274	160	44K
0005434821830	5274	161	44J
0005434821951	5274	162	44H
0005435149842	5274	163	45C
0005434821933	5274	164	45F
0005434821930	5274	165	45H
0005434821917	5274	166	45G
0005432121141	5274	167	46A
0005435149846	5274	168	45K
0005434821833	5274	169	46E
0005434821938	5274	170	46C
0005434821955	5274	171	46F
0005434821958	5274	172	46J
0005435149853	5274	173	46H
0005434558170	5274	174	47A
0005432121146	5274	175	47E
0005434821921	5274	176	47D
0005434821905	5274	177	47F
0005434821942	5274	178	47K
0005434558164	5274	179	47H
0005435149852	5274	180	48D
0005434821870	5274	181	48H
0005434821864	5274	182	48F
0005434821885	5274	183	49A
0005434821911	5274	184	48K
0005434821837	5274	185	49D
0005434821907	5274	186	49C
0005434821913	5274	187	49G
0005434821848	5274	188	49K
0005434821918	5274	189	49H
0005435149845	5274	190	50A
0005434821906	5274	191	50F
0005434821861	5274	192	50E
0005434821860	5274	193	50H
0005434558165	5274	194	50G
0005434664928	5274	195	51E
0005435179386	9936	1	1H
0005435372406	9936	2	1G
0005432202969	9936	3	1K
0005435372425	9936	4	2D
0005435372409	9936	5	3C
0005435372365	9936	6	4D
0005435735075	9936	7	4H
0005435661892	9936	8	5A
0005435372400	9936	9	5H
0005435735079	9936	10	5G
0005435372369	9936	11	11G
0005435735076	9936	12	11E
0005435735080	9936	13	13D
0005435372370	9936	14	13G
0005435372403	9936	15	14A
0005435386486	9936	16	14F
0005435372423	9936	17	14K
0005435372376	9936	18	15K
0005432202968	9936	19	16F
0005435302136	9936	20	16H
0005432202966	9936	21	18B
0005435372411	9936	22	18E
0005435372418	9936	23	18G
0005435372363	9936	24	19G
0005435372421	9936	25	19F
0005435372387	9936	26	20A
0005435372395	9936	27	20C
0005435372401	9936	28	20J
0005435372396	9936	29	21D
0005435372388	9936	30	21J
0005435386482	9936	31	22B
0005435299713	9936	32	22G
0005435372407	9936	33	22K
0005435302138	9936	34	23D
0005435299711	9936	35	23F
0005435372404	9936	36	23H
0005435372378	9936	37	23K
0005435372386	9936	38	24E
0005435372372	9936	39	25B
0005435372361	9936	40	25E
0005435372393	9936	41	25H
0005435372362	9936	42	25J
0005435372380	9936	43	26C
0005435372368	9936	44	26B
0005435372379	9936	45	26D
0005435386484	9936	46	26K
0005435372424	9936	47	26H
0005435372366	9936	48	27K
0005435661893	9936	49	28B
0005435302134	9936	50	28E
0005435386485	9936	51	28H
0005435372399	9936	52	29E
0005435372389	9936	53	30A
0005435386481	9936	54	30J
0005435661891	9936	55	31D
0005435372383	9936	56	31F
0005435372364	9936	57	31E
0005432202964	9936	58	31H
0005435372371	9936	59	31J
0005435372367	9936	60	32B
0005435372394	9936	61	32A
0005435299710	9936	62	33C
0005435372390	9936	63	33F
0005435372375	9936	64	33E
0005435372417	9936	65	33J
0005435179385	9936	66	34A
0005435372398	9936	67	34F
0005435372392	9936	68	34J
0005435302137	9936	69	35B
0005435372410	9936	70	35G
0005435372414	9936	71	35K
0005435372377	9936	72	36C
0005435299714	9936	73	36G
0005435372374	9936	74	36K
0005435372397	9936	75	37A
0005435372413	9936	76	37E
0005435302135	9936	77	37D
0005434821357	9936	78	37F
0005435372384	9936	79	38K
0005435372391	9936	80	39D
0005435372381	9936	81	39G
0005432202963	9936	82	39K
0005435372402	9936	83	39J
0005435372419	9936	84	40E
0005435372416	9936	85	40J
0005435372422	9936	86	41B
0005435386488	9936	87	41C
0005435299712	9936	88	41H
0005434821426	9936	89	42B
0005434821392	9936	90	42J
0005435372408	9936	91	42K
0005435372415	9936	92	43G
0005432202967	9936	93	44B
0005432202965	9936	94	44E
0005432823424	9936	95	44D
0005435372373	9936	96	44J
0005435386483	9936	97	44H
0005435735077	9936	98	45G
0005435386487	9936	99	47F
0005435372412	9936	100	48D
0005434821342	9936	101	48K
0005435372385	9936	102	49D
0005435735078	9936	103	49E
0005435372382	9936	104	49H
0005435372420	9936	105	50G
0005435372405	9936	106	51E
0005435082681	6991	1	1C
0005435790266	6991	2	2A
0005435790268	6991	3	2B
0005435790269	6991	4	4C
0005435082680	6991	5	6A
0005435082678	6991	6	18D
0005435082683	6991	7	19A
0005435790267	6991	8	21D
0005435082682	6991	9	23A
0005435082679	6991	10	23B
0005434755916	9560	1	1C
0005434755902	9560	2	2A
0005434755876	9560	3	2C
0005434755896	9560	4	2D
0005434755903	9560	5	3A
0005434755888	9560	6	3D
0005434755919	9560	7	3F
0005434755918	9560	8	4C
0005434755908	9560	9	4D
0005434755911	9560	10	4E
0005434755898	9560	11	4F
0005434755879	9560	12	5C
0005434755891	9560	13	5D
0005434755889	9560	14	5F
0005434755914	9560	15	6D
0005434755872	9560	16	7A
0005434755899	9560	17	7D
0005434755907	9560	18	8F
0005434755877	9560	19	9C
0005434755880	9560	20	9D
0005434755882	9560	21	9E
0005434755912	9560	22	10C
0005434755886	9560	23	10D
0005434755910	9560	24	10E
0005434755892	9560	25	10F
0005434755901	9560	26	11D
0005434755921	9560	27	12C
0005434755895	9560	28	12D
0005434755875	9560	29	12F
0005434755897	9560	30	13A
0005434755884	9560	31	13C
0005434755904	9560	32	13D
0005434755883	9560	33	13F
0005434755871	9560	34	14D
0005434755887	9560	35	14F
0005434755913	9560	36	15D
0005434755873	9560	37	15E
0005434755900	9560	38	15F
0005434755885	9560	39	16C
0005434755917	9560	40	16D
0005434755906	9560	41	16F
0005434755905	9560	42	17A
0005434755881	9560	43	17C
0005434755915	9560	44	18A
0005434755874	9560	45	18D
0005434755909	9560	46	18E
0005434755890	9560	47	19C
0005434755878	9560	48	19D
0005434755920	9560	49	19F
0005434755894	9560	50	20A
0005434755893	9560	51	20C
0005434213853	28609	1	1C
0005434213878	28609	2	1D
0005434213858	28609	3	2C
0005434213884	28609	4	2D
0005434213864	28609	5	2F
0005434213886	28609	6	3A
0005434213862	28609	7	3C
0005434213885	28609	8	3D
0005434213883	28609	9	3F
0005434213873	28609	10	4A
0005434213846	28609	11	4E
0005434213866	28609	12	5C
0005434213871	28609	13	5D
0005434213877	28609	14	5E
0005434213874	28609	15	6D
0005434213841	28609	16	6F
0005434213888	28609	17	7A
0005434213870	28609	18	7E
0005434213887	28609	19	8F
0005434213872	28609	20	9A
0005434213857	28609	21	9C
0005434213867	28609	22	9E
0005434213845	28609	23	10A
0005434213852	28609	24	10C
0005434213851	28609	25	10D
0005434213882	28609	26	10E
0005434213844	28609	27	11C
0005434213865	28609	28	11F
0005434213843	28609	29	12A
0005434213849	28609	30	12D
0005434213880	28609	31	12E
0005434213856	28609	32	12F
0005434213854	28609	33	13E
0005434213861	28609	34	14A
0005434213850	28609	35	15A
0005434213879	28609	36	15D
0005434213881	28609	37	15E
0005434213875	28609	38	16A
0005434213847	28609	39	16C
0005434213869	28609	40	16F
0005434213855	28609	41	17A
0005434213842	28609	42	18A
0005434213860	28609	43	18E
0005434213868	28609	44	18F
0005434213876	28609	45	19D
0005434213859	28609	46	19F
0005434213848	28609	47	20E
0005434213863	28609	48	20F
0005435100083	10829	1	1A
0005434760154	10829	2	2C
0005435100081	10829	3	2D
0005435100082	10829	4	3A
0005434760155	10829	5	6A
0005435100084	10829	6	22A
0005434760164	31816	1	4C
0005434760165	31816	2	7B
0005434760163	31816	3	23B
0005434638957	1999	1	1A
0005434638973	1999	2	1C
0005432290591	1999	3	1D
0005434638972	1999	4	2A
0005434638963	1999	5	2C
0005434638981	1999	6	2D
0005435948311	1999	7	3A
0005434638961	1999	8	3B
0005434638984	1999	9	3C
0005434638964	1999	10	3D
0005434638983	1999	11	4A
0005434638974	1999	12	4B
0005434638969	1999	13	4D
0005432290592	1999	14	5A
0005434638968	1999	15	5B
0005432290593	1999	16	5D
0005434638978	1999	17	6A
0005434638976	1999	18	6C
0005434638979	1999	19	6D
0005434638960	1999	20	7B
0005434638967	1999	21	18B
0005434638956	1999	22	18D
0005434638958	1999	23	20A
0005434638971	1999	24	20B
0005434638966	1999	25	20C
0005434638975	1999	26	20D
0005434638962	1999	27	21A
0005434638980	1999	28	21B
0005434638970	1999	29	22A
0005434638965	1999	30	22B
0005434638959	1999	31	22D
0005434638977	1999	32	23A
0005434638982	1999	33	23B
0005433202150	23275	1	2B
0005433202162	23275	2	3D
0005433202155	23275	3	4B
0005433202159	23275	4	4D
0005433202161	23275	5	6A
0005433202160	23275	6	6C
0005433202158	23275	7	7A
0005433202151	23275	8	7B
0005433202156	23275	9	18C
0005433202148	23275	10	18D
0005433202154	23275	11	19D
0005433202153	23275	12	20A
0005433202157	23275	13	20D
0005433202152	23275	14	21C
0005433202147	23275	15	22C
0005433202149	23275	16	23B
0005434600440	6048	1	1A
0005434600439	6048	2	1C
0005434600456	6048	3	2C
0005432111239	6048	4	3A
0005434600461	6048	5	3C
0005434600442	6048	6	3D
0005434600446	6048	7	3F
0005434600459	6048	8	4C
0005434600444	6048	9	4E
0005434600441	6048	10	4F
0005434600447	6048	11	5D
0005434600450	6048	12	5E
0005434600449	6048	13	6A
0005433531241	6048	14	7C
0005434600457	6048	15	7E
0005434600443	6048	16	8C
0005434600448	6048	17	8F
0005433531243	6048	18	9A
0005433533258	6048	19	9F
0005434600463	6048	20	10F
0005434600462	6048	21	11A
0005434600451	6048	22	11C
0005434600438	6048	23	11E
0005432111240	6048	24	12D
0005433533257	6048	25	12E
0005434600437	6048	26	12F
0005434600445	6048	27	13F
0005434600453	6048	28	14A
0005433533259	6048	29	14F
0005433531244	6048	30	15A
0005434600460	6048	31	15C
0005434600452	6048	32	16D
0005433531242	6048	33	17D
0005434600464	6048	34	17F
0005434600458	6048	35	18C
0005434600455	6048	36	18E
0005434600454	6048	37	18F
0005432111238	6048	38	20E
0005432111237	6048	39	20F
0005435326558	18586	1	2C
0005435326554	18586	2	4F
0005435326560	18586	3	7E
0005435326555	18586	4	7F
0005435326563	18586	5	8D
0005435326567	18586	6	11C
0005435326559	18586	7	12D
0005435326565	18586	8	12E
0005435326564	18586	9	13C
0005435326566	18586	10	14C
0005435326561	18586	11	14D
0005435326557	18586	12	14F
0005435326556	18586	13	19A
0005435326562	18586	14	20E
0005434550451	10637	1	1C
0005434554032	10637	2	1D
0005434550450	10637	3	2A
0005434550429	10637	4	2C
0005434550453	10637	5	2D
0005434550464	10637	6	3A
0005434550444	10637	7	3D
0005434550455	10637	8	3F
0005434550468	10637	9	4A
0005434550448	10637	10	4C
0005434550447	10637	11	4E
0005434550446	10637	12	6A
0005434550480	10637	13	6C
0005434554034	10637	14	6D
0005434550440	10637	15	6E
0005434550452	10637	16	6F
0005434550473	10637	17	7A
0005434550479	10637	18	7D
0005434550443	10637	19	7E
0005434550456	10637	20	7F
0005434550465	10637	21	8A
0005434558155	10637	22	8E
0005434550426	10637	23	9A
0005434558159	10637	24	9C
0005434558156	10637	25	9D
0005434550454	10637	26	9E
0005434550478	10637	27	10A
0005434550428	10637	28	10C
0005434550477	10637	29	10D
0005434550445	10637	30	10E
0005434550425	10637	31	10F
0005434550461	10637	32	11A
0005434550430	10637	33	11E
0005434550471	10637	34	11F
0005434550475	10637	35	12A
0005434550472	10637	36	12C
0005434550459	10637	37	12D
0005434558158	10637	38	12F
0005434550460	10637	39	13C
0005434550435	10637	40	13D
0005434550474	10637	41	13E
0005434550458	10637	42	13F
0005434550457	10637	43	14D
0005434554033	10637	44	14E
0005434550434	10637	45	15C
0005434550438	10637	46	15D
0005434550437	10637	47	15E
0005434550462	10637	48	15F
0005434558157	10637	49	16C
0005434550463	10637	50	16D
0005434550469	10637	51	16E
0005434550476	10637	52	16F
0005434550449	10637	53	17A
0005434550481	10637	54	17D
0005434550432	10637	55	17E
0005434550470	10637	56	17F
0005434550427	10637	57	18A
0005434550442	10637	58	18C
0005434550436	10637	59	18D
0005434550441	10637	60	19D
0005434550439	10637	61	19E
0005434550467	10637	62	19F
0005434550433	10637	63	20A
0005434550431	10637	64	20C
0005434550466	10637	65	20F
0005433180757	27689	1	1F
0005433180769	27689	2	3C
0005433180763	27689	3	4A
0005433180771	27689	4	4C
0005433180770	27689	5	4F
0005433180751	27689	6	5A
0005433180768	27689	7	6D
0005433180758	27689	8	6F
0005433180767	27689	9	7E
0005433180755	27689	10	8A
0005433180765	27689	11	8D
0005433180776	27689	12	9E
0005433180766	27689	13	10E
0005433180752	27689	14	12A
0005433180761	27689	15	12F
0005433180762	27689	16	14D
0005433180772	27689	17	15C
0005433180775	27689	18	15F
0005433180773	27689	19	16C
0005433180760	27689	20	16E
0005433180774	27689	21	16F
0005433180764	27689	22	17E
0005433180756	27689	23	18C
0005433180754	27689	24	19C
0005433180759	27689	25	20A
0005433180753	27689	26	20F
0005434550256	27697	1	4A
0005434550258	27697	2	6C
0005434550257	27697	3	10F
0005433459160	6135	1	1A
0005433459164	6135	2	3B
0005433459162	6135	3	4B
0005433459163	6135	4	5A
0005433459161	6135	5	6A
0005435254440	19343	1	4A
0005435254441	19343	2	6A
0005435681580	6747	1	1A
0005435681584	6747	2	1C
0005435681582	6747	3	1D
0005435681566	6747	4	2A
0005435681591	6747	5	2C
0005435681571	6747	6	3A
0005435681579	6747	7	3F
0005435681574	6747	8	4A
0005435681552	6747	9	4E
0005435681593	6747	10	5A
0005435681572	6747	11	5C
0005435630923	6747	12	5D
0005435681556	6747	13	5F
0005435681561	6747	14	6E
0005432136102	6747	15	7A
0005435437574	6747	16	7C
0005435681567	6747	17	7D
0005435630924	6747	18	7E
0005435630925	6747	19	7F
0005435681573	6747	20	8C
0005435681581	6747	21	8D
0005435681587	6747	22	9C
0005435681592	6747	23	9D
0005435681585	6747	24	9E
0005435681559	6747	25	10A
0005435681595	6747	26	10C
0005435681568	6747	27	10D
0005435681554	6747	28	11C
0005435681558	6747	29	11E
0005435681586	6747	30	11F
0005435681578	6747	31	12A
0005435437573	6747	32	12C
0005435681551	6747	33	12D
0005435681557	6747	34	12E
0005435681570	6747	35	13A
0005435681560	6747	36	13E
0005435681590	6747	37	13F
0005435681589	6747	38	14C
0005435681549	6747	39	14D
0005435681555	6747	40	14F
0005435681550	6747	41	15A
0005435681565	6747	42	15C
0005435661890	6747	43	15E
0005435681588	6747	44	15F
0005435681564	6747	45	16A
0005435681576	6747	46	16F
0005435681575	6747	47	17C
0005432136103	6747	48	17E
0005432136101	6747	49	17F
0005435681562	6747	50	18A
0005435681569	6747	51	18E
0005435681563	6747	52	19A
0005435681594	6747	53	19C
0005435719553	6747	54	19E
0005435681553	6747	55	20A
0005435681583	6747	56	20C
0005435681577	6747	57	20F
0005435681413	24595	1	2D
0005432305716	24595	2	3A
0005435437664	24595	3	3F
0005435437643	24595	4	4C
0005434828659	24595	5	4F
0005435437661	24595	6	5D
0005435437656	24595	7	5E
0005435437651	24595	8	5F
0005435437645	24595	9	6E
0005434828660	24595	10	7C
0005435437646	24595	11	8A
0005435437647	24595	12	8F
0005432533253	24595	13	9F
0005435437660	24595	14	10D
0005435437650	24595	15	10E
0005432305714	24595	16	11A
0005435437657	24595	17	11C
0005435437649	24595	18	11D
0005435437644	24595	19	13A
0005435437648	24595	20	13D
0005435437663	24595	21	14A
0005435681414	24595	22	14E
0005435437658	24595	23	15E
0005432533254	24595	24	15F
0005435437655	24595	25	16E
0005435437659	24595	26	17E
0005435437665	24595	27	17F
0005434828661	24595	28	18A
0005432533252	24595	29	18C
0005435437662	24595	30	18D
0005435437653	24595	31	18E
0005432305715	24595	32	18F
0005435437652	24595	33	19F
0005435437654	24595	34	20F
0005435125772	11519	1	1A
0005435125784	11519	2	1D
0005435105937	11519	3	1F
0005435125779	11519	4	2A
0005435125788	11519	5	3A
0005435125802	11519	6	3C
0005435125773	11519	7	4A
0005435125787	11519	8	4C
0005435125796	11519	9	4F
0005435125776	11519	10	5C
0005435125792	11519	11	5E
0005435125783	11519	12	6E
0005435125785	11519	13	7A
0005435125806	11519	14	7C
0005435125810	11519	15	7F
0005435098523	11519	16	8A
0005435098527	11519	17	8D
0005435125801	11519	18	8E
0005435125793	11519	19	8F
0005435125809	11519	20	9A
0005435125800	11519	21	9D
0005435125807	11519	22	9F
0005435125812	11519	23	10C
0005435125808	11519	24	10D
0005435098526	11519	25	10E
0005435125775	11519	26	11A
0005435098524	11519	27	11D
0005435125794	11519	28	11E
0005435125803	11519	29	11F
0005435125798	11519	30	12C
0005435125805	11519	31	13F
0005435125782	11519	32	14A
0005435098525	11519	33	14C
0005435125780	11519	34	14E
0005435125797	11519	35	14F
0005435098528	11519	36	15C
0005435125789	11519	37	15E
0005435125791	11519	38	16C
0005435105938	11519	39	16E
0005435125778	11519	40	16F
0005435125795	11519	41	17E
0005435125777	11519	42	17F
0005435125813	11519	43	18D
0005435125811	11519	44	18F
0005435125804	11519	45	19A
0005435125781	11519	46	19C
0005435125786	11519	47	19E
0005435125799	11519	48	20C
0005435125790	11519	49	20D
0005435125774	11519	50	20E
0005435558052	31903	1	2C
0005435558051	31903	2	13C
0005435558053	31903	3	15A
0005433397392	13503	1	1C
0005433397405	13503	2	1D
0005433397382	13503	3	2C
0005433397423	13503	4	2D
0005433397416	13503	5	3A
0005433397391	13503	6	3D
0005433397427	13503	7	3F
0005433397388	13503	8	4A
0005433397401	13503	9	4C
0005433397407	13503	10	4D
0005433397397	13503	11	4E
0005433397421	13503	12	4F
0005433397399	13503	13	5D
0005433397409	13503	14	6A
0005433397413	13503	15	5F
0005433397385	13503	16	7C
0005433397394	13503	17	7E
0005433397403	13503	18	7F
0005433397390	13503	19	8A
0005433397379	13503	20	9A
0005433397422	13503	21	9C
0005433397411	13503	22	9D
0005433397380	13503	23	9E
0005433397419	13503	24	9F
0005433397420	13503	25	10A
0005433397389	13503	26	10D
0005433397402	13503	27	10E
0005433397414	13503	28	11C
0005433397383	13503	29	11D
0005433397410	13503	30	12A
0005433397425	13503	31	12C
0005433397415	13503	32	12D
0005433397398	13503	33	12E
0005433397396	13503	34	13A
0005433397418	13503	35	13F
0005433397395	13503	36	14A
0005433397387	13503	37	14C
0005433397400	13503	38	14F
0005433397384	13503	39	16D
0005433397406	13503	40	17A
0005433397408	13503	41	17C
0005433397393	13503	42	18C
0005433397386	13503	43	18E
0005433397412	13503	44	18F
0005433397424	13503	45	19A
0005433397404	13503	46	19E
0005433397426	13503	47	20C
0005433397381	13503	48	20E
0005433397417	13503	49	20F
0005433397197	19418	1	1D
0005435732165	19418	2	5C
0005432297241	19418	3	7A
0005435732162	19418	4	8A
0005432297242	19418	5	8E
0005433397224	19418	6	9C
0005433397178	19418	7	11F
0005433397182	19418	8	12A
0005435732164	19418	9	12E
0005433397181	19418	10	13F
0005435732163	19418	11	15C
0005433397321	19418	12	17C
0005433397195	19418	13	19C
0005433397322	19418	14	20F
0005435925098	13173	1	1A
0005435925117	13173	2	1C
0005435925106	13173	3	2A
0005435925097	13173	4	3A
0005435925100	13173	5	5D
0005435925105	13173	6	5F
0005435925114	13173	7	9F
0005435925111	13173	8	10A
0005435925102	13173	9	10C
0005435925096	13173	10	10E
0005435925107	13173	11	11D
0005435925099	13173	12	12A
0005435925101	13173	13	12F
0005435925109	13173	14	13C
0005435925119	13173	15	13E
0005435925112	13173	16	14F
0005435925116	13173	17	15A
0005435925120	13173	18	15D
0005435925104	13173	19	15E
0005435925113	13173	20	16A
0005435925103	13173	21	16D
0005435925110	13173	22	17E
0005435925108	13173	23	18D
0005435925118	13173	24	19E
0005435925115	13173	25	19F
0005435068370	15468	1	1C
0005435068358	15468	2	1F
0005435068342	15468	3	2A
0005435068355	15468	4	2C
0005435068329	15468	5	2D
0005435068350	15468	6	2F
0005435068332	15468	7	3A
0005435068363	15468	8	3D
0005435068354	15468	9	3F
0005435068349	15468	10	4A
0005435068366	15468	11	5A
0005435068335	15468	12	5D
0005435068331	15468	13	5E
0005435068333	15468	14	6C
0005435068341	15468	15	6F
0005435068336	15468	16	7A
0005435068327	15468	17	7D
0005435068338	15468	18	7E
0005435068357	15468	19	7F
0005435068321	15468	20	8A
0005435068367	15468	21	8D
0005435068348	15468	22	8F
0005435068322	15468	23	9C
0005435068368	15468	24	9D
0005435068340	15468	25	10A
0005435068319	15468	26	10E
0005435068345	15468	27	10F
0005435068326	15468	28	11E
0005435068359	15468	29	12D
0005435068361	15468	30	12F
0005435068356	15468	31	13A
0005435068325	15468	32	13D
0005435068343	15468	33	13E
0005435068365	15468	34	14A
0005435068337	15468	35	14C
0005435068324	15468	36	14D
0005435068353	15468	37	14E
0005435068328	15468	38	15A
0005435068347	15468	39	15D
0005435068362	15468	40	15F
0005435068369	15468	41	16D
0005435068346	15468	42	16C
0005435068318	15468	43	16E
0005435068330	15468	44	17A
0005435068344	15468	45	17C
0005435068360	15468	46	18C
0005435068320	15468	47	18E
0005435068334	15468	48	19A
0005435068339	15468	49	19C
0005435068364	15468	50	19D
0005435068352	15468	51	20C
0005435068323	15468	52	20D
0005435068351	15468	53	20F
0005433407499	29477	1	2C
0005433407495	29477	2	3B
0005433407500	29477	3	3C
0005433407492	29477	4	3D
0005433407494	29477	5	4B
0005433407502	29477	6	5A
0005433407497	29477	7	19C
0005433407496	29477	8	19D
0005433407498	29477	9	21A
0005433407501	29477	10	21C
0005433407493	29477	11	22D
0005434213907	10713	1	1A
0005434213926	10713	2	2A
0005434213897	10713	3	2C
0005434213895	10713	4	2D
0005434213933	10713	5	2F
0005434213929	10713	6	3C
0005434213891	10713	7	3F
0005434213908	10713	8	4D
0005434213889	10713	9	4E
0005434213914	10713	10	5A
0005434213912	10713	11	5D
0005434213901	10713	12	6A
0005434213922	10713	13	6E
0005434213920	10713	14	7A
0005434213909	10713	15	7C
0005434213917	10713	16	7E
0005434213927	10713	17	7F
0005434213932	10713	18	8A
0005434213918	10713	19	8D
0005434213900	10713	20	8F
0005434213925	10713	21	10A
0005434213921	10713	22	10C
0005434213916	10713	23	10D
0005434213893	10713	24	10F
0005434213915	10713	25	11E
0005434213923	10713	26	12C
0005434213903	10713	27	13D
0005434213906	10713	28	13F
0005434213896	10713	29	14C
0005434213894	10713	30	14D
0005434213913	10713	31	15C
0005434213919	10713	32	15E
0005434213902	10713	33	15F
0005434213930	10713	34	16E
0005434213911	10713	35	17A
0005434213935	10713	36	17F
0005434213934	10713	37	18A
0005434213910	10713	38	18C
0005434213890	10713	39	18E
0005434213905	10713	40	19C
0005434213928	10713	41	19D
0005434213931	10713	42	19E
0005434213904	10713	43	19F
0005434213892	10713	44	20A
0005434213899	10713	45	20D
0005434213898	10713	46	20E
0005434213924	10713	47	20F
0005434755824	28670	1	1C
0005434755830	28670	2	1F
0005434755870	28670	3	2A
0005434755858	28670	4	2C
0005434755852	28670	5	4A
0005434755843	28670	6	4E
0005434755827	28670	7	5A
0005434755846	28670	8	5D
0005434755837	28670	9	5F
0005434755826	28670	10	6A
0005434755862	28670	11	6E
0005434755845	28670	12	6F
0005434755868	28670	13	7A
0005434755836	28670	14	7E
0005434755831	28670	15	8D
0005434755829	28670	16	8E
0005434755863	28670	17	8F
0005434755849	28670	18	9A
0005434755835	28670	19	9C
0005434755834	28670	20	9D
0005434755861	28670	21	9E
0005434755854	28670	22	10C
0005434755839	28670	23	11A
0005434755856	28670	24	11C
0005434755869	28670	25	11D
0005434755855	28670	26	12C
0005434755840	28670	27	12D
0005434755841	28670	28	12F
0005434755857	28670	29	13E
0005434755859	28670	30	14A
0005434755842	28670	31	14D
0005434755847	28670	32	14F
0005434755864	28670	33	15A
0005434755832	28670	34	15F
0005434755828	28670	35	16A
0005434755851	28670	36	16C
0005434755850	28670	37	16D
0005434755853	28670	38	17A
0005434755833	28670	39	17C
0005434755825	28670	40	17D
0005434755865	28670	41	17E
0005434755844	28670	42	17F
0005434755860	28670	43	18A
0005434755866	28670	44	18F
0005434755838	28670	45	19E
0005434755867	28670	46	20D
0005434755848	28670	47	20E
0005435038917	5462	1	1A
0005435042830	5462	2	1C
0005432125351	5462	3	1F
0005435038893	5462	4	1D
0005435006720	5462	5	2A
0005435038910	5462	6	2D
0005435038875	5462	7	3A
0005435038922	5462	8	3C
0005435006701	5462	9	3D
0005435006713	5462	10	3F
0005435038924	5462	11	4A
0005435006704	5462	12	4B
0005435038896	5462	13	4D
0005435038913	5462	14	4C
0005432125352	5462	15	4E
0005435038912	5462	16	5A
0005435006722	5462	17	5C
0005435042829	5462	18	5D
0005435006721	5462	19	5F
0005435006703	5462	20	5E
0005435006705	5462	21	6A
0005435006708	5462	22	6C
0005435006702	5462	23	6E
0005435006698	5462	24	7A
0005432125349	5462	25	7B
0005435038887	5462	26	7C
0005435038888	5462	27	7D
0005435006714	5462	28	7E
0005435006712	5462	29	8A
0005435038925	5462	30	7F
0005435042827	5462	31	8B
0005435038891	5462	32	8C
0005435038911	5462	33	8E
0005432125355	5462	34	8D
0005435038928	5462	35	8F
0005435006707	5462	36	9A
0005435006717	5462	37	9B
0005435006719	5462	38	9C
0005435038876	5462	39	9D
0005435006716	5462	40	9F
0005435038905	5462	41	10C
0005435038894	5462	42	11A
0005435038907	5462	43	10E
0005435038918	5462	44	11B
0005435038909	5462	45	11D
0005435038927	5462	46	11F
0005435038873	5462	47	12A
0005435038921	5462	48	12B
0005435038901	5462	49	12C
0005432125350	5462	50	12D
0005435038906	5462	51	12F
0005435006715	5462	52	13B
0005435038885	5462	53	13A
0005435038877	5462	54	13C
0005435038920	5462	55	13D
0005435038884	5462	56	13E
0005435038881	5462	57	13F
0005435038878	5462	58	14A
0005435042828	5462	59	14B
0005435006710	5462	60	14D
0005435038890	5462	61	14F
0005435038892	5462	62	15B
0005435038882	5462	63	15A
0005435038903	5462	64	15D
0005435038900	5462	65	15E
0005435038919	5462	66	16B
0005435038898	5462	67	16D
0005435038872	5462	68	16E
0005435042826	5462	69	16F
0005435006700	5462	70	17E
0005435038874	5462	71	17D
0005435038871	5462	72	17F
0005435006711	5462	73	18B
0005435038923	5462	74	18C
0005435038879	5462	75	18E
0005435038899	5462	76	18D
0005435006709	5462	77	19B
0005435038926	5462	78	19C
0005435038889	5462	79	19D
0005435038914	5462	80	19F
0005435038929	5462	81	20A
0005435038916	5462	82	20B
0005435038931	5462	83	20D
0005432125354	5462	84	20E
0005435006706	5462	85	21A
0005435038908	5462	86	21C
0005435038915	5462	87	21D
0005435006718	5462	88	22A
0005435038883	5462	89	22B
0005435038897	5462	90	22C
0005435038895	5462	91	22D
0005435006699	5462	92	22E
0005435038886	5462	93	23A
0005435038902	5462	94	23D
0005432125353	5462	95	23C
0005435038880	5462	96	23B
0005435038904	5462	97	23F
0005435038930	5462	98	23E
0005434229073	12949	1	1D
0005435038652	12949	2	2C
0005435006641	12949	3	2A
0005434229062	12949	4	2F
0005435006639	12949	5	3C
0005434229063	12949	6	4D
0005434229067	12949	7	5D
0005434229061	12949	8	8A
0005432304346	12949	9	8B
0005434229074	12949	10	9D
0005432304344	12949	11	9C
0005432304347	12949	12	10B
0005434229069	12949	13	11B
0005434229079	12949	14	12D
0005435006613	12949	15	12C
0005435038653	12949	16	12E
0005432304345	12949	17	12F
0005435006640	12949	18	13D
0005434229060	12949	19	13E
0005434229070	12949	20	14F
0005435038624	12949	21	15B
0005434229075	12949	22	15C
0005434229066	12949	23	16A
0005434229071	12949	24	16D
0005434229068	12949	25	16E
0005434229072	12949	26	18D
0005434229064	12949	27	18F
0005434229076	12949	28	19A
0005435038623	12949	29	20A
0005434229065	12949	30	20E
0005434229078	12949	31	20F
0005435038631	12949	32	21B
0005434229080	12949	33	21D
0005434229059	12949	34	21F
0005434229077	12949	35	23B
0005434411715	14862	1	1C
0005434426176	14862	2	1D
0005432188561	14862	3	1F
0005434426180	14862	4	2C
0005434426203	14862	5	3C
0005434426188	14862	6	3F
0005432188562	14862	7	4F
0005434426177	14862	8	5E
0005434426182	14862	9	5F
0005434426195	14862	10	7A
0005434426184	14862	11	9A
0005434411717	14862	12	9C
0005434426191	14862	13	10C
0005434426201	14862	14	11A
0005434426194	14862	15	11C
0005434426179	14862	16	11E
0005434426186	14862	17	11F
0005434426202	14862	18	12C
0005434426187	14862	19	12E
0005434426190	14862	20	13A
0005434411718	14862	21	13C
0005434426193	14862	22	13D
0005434426183	14862	23	14C
0005434426204	14862	24	14D
0005434426198	14862	25	15C
0005434426174	14862	26	15D
0005434426200	14862	27	15E
0005434426185	14862	28	16A
0005434426197	14862	29	16E
0005434426192	14862	30	16F
0005434426189	14862	31	17E
0005434411716	14862	32	18A
0005434426178	14862	33	18D
0005434426196	14862	34	19C
0005434426181	14862	35	19E
0005434426199	14862	36	19F
0005434426175	14862	37	20F
0005435902474	20203	1	1C
0005435902458	20203	2	3D
0005435902462	20203	3	4C
0005435902460	20203	4	5E
0005435554124	20203	5	5F
0005435902466	20203	6	6D
0005432059477	20203	7	7A
0005434426096	20203	8	8A
0005435554126	20203	9	8D
0005435902461	20203	10	9E
0005435902459	20203	11	10C
0005435554127	20203	12	10D
0005435902468	20203	13	10F
0005434426098	20203	14	11A
0005434426097	20203	15	11C
0005435902465	20203	16	14A
0005435902469	20203	17	14F
0005435554123	20203	18	15E
0005435554125	20203	19	17A
0005435902464	20203	20	17C
0005435902473	20203	21	17F
0005435902467	20203	22	18A
0005435902471	20203	23	18C
0005434426092	20203	24	18E
0005435902457	20203	25	18F
0005435902472	20203	26	19D
0005432059478	20203	27	19F
0005435902463	20203	28	20C
0005435554128	20203	29	20D
0005435902470	20203	30	20E
0005435981654	26545	1	1C
0005435981677	26545	2	1D
0005435981688	26545	3	3C
0005432300179	26545	4	3D
0005435981655	26545	5	4C
0005432300184	26545	6	4D
0005435981670	26545	7	4E
0005432300178	26545	8	4F
0005435981672	26545	9	5C
0005435981666	26545	10	5D
0005435981647	26545	11	5E
0005435981684	26545	12	5F
0005435981681	26545	13	7A
0005435981660	26545	14	7C
0005435981664	26545	15	7D
0005432300181	26545	16	7E
0005435981659	26545	17	7F
0005435981673	26545	18	8D
0005435981665	26545	19	8F
0005435981663	26545	20	9A
0005435981668	26545	21	9C
0005435981656	26545	22	9D
0005435981661	26545	23	10A
0005435981648	26545	24	10F
0005432300182	26545	25	11C
0005435981687	26545	26	11D
0005435981676	26545	27	11E
0005435981653	26545	28	12E
0005435981652	26545	29	12F
0005435981657	26545	30	13C
0005435981667	26545	31	13D
0005435981685	26545	32	13E
0005435981662	26545	33	13F
0005435981669	26545	34	14A
0005435981674	26545	35	14F
0005435981675	26545	36	15C
0005435981671	26545	37	15F
0005435981650	26545	38	16F
0005435981678	26545	39	17A
0005435981680	26545	40	17D
0005435981686	26545	41	17E
0005432300180	26545	42	18A
0005435981689	26545	43	18C
0005435981646	26545	44	18D
0005435981679	26545	45	18E
0005435981682	26545	46	18F
0005435981651	26545	47	19D
0005432300183	26545	48	19E
0005435981683	26545	49	20A
0005435981649	26545	50	20C
0005435981645	26545	51	20D
0005435981658	26545	52	20F
0005433434304	26710	1	1A
0005433434296	26710	2	1F
0005433434314	26710	3	2A
0005433434303	26710	4	2C
0005433434299	26710	5	2F
0005432051086	26710	6	3A
0005433434316	26710	7	3C
0005433434310	26710	8	4A
0005433434305	26710	9	4D
0005433434306	26710	10	5C
0005433434321	26710	11	5F
0005433434322	26710	12	6C
0005433434315	26710	13	7D
0005433434300	26710	14	7E
0005433434324	26710	15	7F
0005433434318	26710	16	8C
0005432051088	26710	17	8D
0005433434311	26710	18	8E
0005433434309	26710	19	8F
0005434271284	26710	20	9D
0005433434323	26710	21	9F
0005433434308	26710	22	10D
0005434270179	26710	23	10F
0005433434317	26710	24	13D
0005433434307	26710	25	13E
0005433434297	26710	26	14C
0005433434302	26710	27	14F
0005433434298	26710	28	15D
0005433434320	26710	29	15E
0005433434319	26710	30	15F
0005433434301	26710	31	16C
0005434270178	26710	32	17E
0005434271285	26710	33	17F
0005432051087	26710	34	18C
0005433434313	26710	35	18D
0005433434312	26710	36	18E
0005433434295	26710	37	19D
0005434269076	26710	38	19E
0005432583696	3178	1	1A
0005432216236	3178	2	1C
0005432583692	3178	3	2A
0005432583690	3178	4	2B
0005432583697	3178	5	2D
0005432583693	3178	6	3A
0005432583705	3178	7	4A
0005432583694	3178	8	4B
0005432583695	3178	9	4C
0005432583708	3178	10	4D
0005432583687	3178	11	5A
0005432583698	3178	12	5B
0005432216235	3178	13	5C
0005432216234	3178	14	6B
0005432583689	3178	15	6D
0005432583709	3178	16	7A
0005432583691	3178	17	7B
0005432583702	3178	18	18D
0005432583707	3178	19	19A
0005432583706	3178	20	19C
0005432583688	3178	21	19D
0005432583699	3178	22	20A
0005432583704	3178	23	20D
0005432583703	3178	24	21A
0005432583701	3178	25	21B
0005432583710	3178	26	21D
0005432583686	3178	27	22A
0005432583700	3178	28	22B
0005432857907	31510	1	1B
0005432857899	31510	2	1D
0005432583593	31510	3	3B
0005432857908	31510	4	4A
0005432857903	31510	5	4B
0005432857910	31510	6	6A
0005432857909	31510	7	7D
0005432583592	31510	8	18B
0005432857901	31510	9	18C
0005432857904	31510	10	18D
0005432857905	31510	11	19B
0005432857906	31510	12	21B
0005432857902	31510	13	21C
0005432857900	31510	14	23B
0005434943225	897	1	4D
0005434943229	897	2	5A
0005434943230	897	3	7A
0005434943222	897	4	18A
0005434943226	897	5	18B
0005434943231	897	6	19B
0005434943228	897	7	21A
0005434943224	897	8	22D
0005434943227	897	9	23A
0005434943223	897	10	23B
0005433255048	16237	1	1C
0005434943191	16237	2	2B
0005433255047	16237	3	3B
0005433255043	16237	4	4D
0005433255045	16237	5	19B
0005433255046	16237	6	21A
0005433255044	16237	7	21C
0005434943192	16237	8	23A
0005433654676	4328	1	2F
0005433654662	4328	2	4D
0005433654677	4328	3	6B
0005433654678	4328	4	6A
0005433654656	4328	5	6E
0005433654659	4328	6	8B
0005433654673	4328	7	9A
0005433654667	4328	8	9F
0005433654663	4328	9	10E
0005433654664	4328	10	10F
0005433654681	4328	11	11A
0005433654683	4328	12	11D
0005433654666	4328	13	12A
0005433654674	4328	14	12C
0005433654658	4328	15	14A
0005433654655	4328	16	14B
0005433654671	4328	17	14C
0005433654670	4328	18	16C
0005433654669	4328	19	16B
0005433654679	4328	20	16F
0005433654675	4328	21	17E
0005433654657	4328	22	18E
0005433654684	4328	23	19B
0005433654665	4328	24	19D
0005433654661	4328	25	19F
0005433654672	4328	26	20D
0005433654682	4328	27	20F
0005433654680	4328	28	20E
0005433654668	4328	29	21D
0005433654660	4328	30	21B
0005435652390	21778	1	1A
0005435652433	21778	2	1D
0005435652396	21778	3	1F
0005435652384	21778	4	2C
0005435652424	21778	5	2F
0005435652406	21778	6	3D
0005435652413	21778	7	3F
0005435652400	21778	8	4A
0005435652405	21778	9	4C
0005435652386	21778	10	4D
0005435652432	21778	11	4F
0005435652420	21778	12	5C
0005435652418	21778	13	5D
0005435652429	21778	14	5E
0005435652404	21778	15	6E
0005435652419	21778	16	6F
0005435652407	21778	17	7A
0005435652415	21778	18	7C
0005435652434	21778	19	7D
0005435652402	21778	20	7E
0005435652422	21778	21	7F
0005435652411	21778	22	8A
0005435652427	21778	23	8E
0005435652403	21778	24	8F
0005435652408	21778	25	9A
0005435652389	21778	26	9C
0005435652398	21778	27	11A
0005435652401	21778	28	11C
0005435652392	21778	29	11E
0005435652428	21778	30	11F
0005435652425	21778	31	12F
0005435652388	21778	32	13A
0005435652410	21778	33	13C
0005435652430	21778	34	13F
0005435652385	21778	35	14A
0005435652395	21778	36	14D
0005435652423	21778	37	14F
0005435652435	21778	38	15C
0005435652431	21778	39	15E
0005435652414	21778	40	15F
0005435652412	21778	41	16E
0005435652416	21778	42	16F
0005435652397	21778	43	17D
0005435652394	21778	44	17E
0005435652417	21778	45	18A
0005435652426	21778	46	18C
0005435652387	21778	47	18E
0005435652391	21778	48	19D
0005435652409	21778	49	19E
0005435652399	21778	50	19F
0005435652421	21778	51	20D
0005435652393	21778	52	20F
0005432665248	9356	1	1A
0005433784446	9356	2	1C
0005433804897	9356	3	1G
0005433763016	9356	4	2A
0005433784442	9356	5	1H
0005433763005	9356	6	2B
0005433763008	9356	7	3A
0005432667426	9356	8	3B
0005433804926	9356	9	3H
0005432665247	9356	10	5A
0005433804899	9356	11	4H
0005433804904	9356	12	5C
0005433804906	9356	13	5F
0005433804908	9356	14	9B
0005433804902	9356	15	11F
0005432666359	9356	16	11H
0005433784466	9356	17	12D
0005433784449	9356	18	12E
0005433763015	9356	19	12G
0005433804905	9356	20	13A
0005432665246	9356	21	13B
0005433784463	9356	22	13E
0005432666360	9356	23	13G
0005433804930	9356	24	14B
0005433804909	9356	25	14A
0005433784462	9356	26	14E
0005433804895	9356	27	14F
0005433804910	9356	28	14G
0005433763007	9356	29	15G
0005432667427	9356	30	16A
0005433804901	9356	31	15H
0005433763004	9356	32	16D
0005433784474	9356	33	16E
0005433804919	9356	34	16F
0005433804922	9356	35	16H
0005433784454	9356	36	17B
0005433804896	9356	37	17E
0005433784458	9356	38	17G
0005432657407	9356	39	18D
0005433763003	9356	40	18H
0005433804907	9356	41	18G
0005433804913	9356	42	19E
0005433804912	9356	43	20D
0005433784451	9356	44	20B
0005433784450	9356	45	20H
0005433804925	9356	46	21A
0005433784469	9356	47	21D
0005433804923	9356	48	21B
0005433763010	9356	49	21G
0005433784467	9356	50	22B
0005433784457	9356	51	22E
0005433804911	9356	52	22H
0005433784453	9356	53	23B
0005433784470	9356	54	23A
0005433784476	9356	55	23E
0005433804900	9356	56	23G
0005433804898	9356	57	23H
0005433804917	9356	58	24B
0005433804928	9356	59	24F
0005433804893	9356	60	24H
0005433784445	9356	61	25E
0005433784448	9356	62	25F
0005433784461	9356	63	27E
0005433784444	9356	64	27D
0005433784473	9356	65	27F
0005433784472	9356	66	27G
0005433763006	9356	67	27H
0005433784456	9356	68	28D
0005433804933	9356	69	28F
0005433804924	9356	70	28H
0005433763002	9356	71	29E
0005433784452	9356	72	30D
0005433804921	9356	73	30E
0005433763013	9356	74	30H
0005433784455	9356	75	31B
0005433784468	9356	76	31D
0005433784460	9356	77	31F
0005433804927	9356	78	31H
0005433784471	9356	79	32G
0005433804931	9356	80	32H
0005433804903	9356	81	33E
0005433804920	9356	82	33H
0005433804918	9356	83	34B
0005432657408	9356	84	34A
0005434170800	9356	85	34D
0005433804916	9356	86	34F
0005433804929	9356	87	34E
0005433804915	9356	88	34G
0005433784443	9356	89	35A
0005434170832	9356	90	35D
0005433784447	9356	91	35B
0005433784440	9356	92	35G
0005433804894	9356	93	35H
0005433804914	9356	94	36A
0005433784475	9356	95	36E
0005433784441	9356	96	36D
0005433763014	9356	97	36G
0005433784459	9356	98	36H
0005433763012	9356	99	37D
0005433784464	9356	100	37F
0005433763009	9356	101	37E
0005433763011	9356	102	37G
0005433804932	9356	103	38G
0005433784465	9356	104	38F
0005435269658	26241	1	2F
0005435269661	26241	2	5B
0005434170856	26241	3	9G
0005435269663	26241	4	11A
0005434151663	26241	5	11B
0005434170861	26241	6	11G
0005434151664	26241	7	12H
0005434170855	26241	8	13G
0005434170869	26241	9	14F
0005434269075	26241	10	16A
0005435269664	26241	11	16B
0005434271282	26241	12	16H
0005434170866	26241	13	17B
0005434170863	26241	14	17G
0005434170857	26241	15	18D
0005434151665	26241	16	18F
0005434170862	26241	17	18E
0005434170865	26241	18	20F
0005435269659	26241	19	21G
0005435269662	26241	20	29A
0005434170864	26241	21	29H
0005435269655	26241	22	30D
0005434170860	26241	23	30G
0005434269074	26241	24	31B
0005434170867	26241	25	31G
0005435269660	26241	26	31H
0005434270177	26241	27	32E
0005434271281	26241	28	32F
0005435269657	26241	29	33B
0005435269656	26241	30	33F
0005435269654	26241	31	35B
0005434170858	26241	32	35F
0005435269653	26241	33	35E
0005434170859	26241	34	36E
0005434170868	26241	35	37G
0005434271283	26241	36	39F
0005435135604	4914	1	1C
0005435135605	4914	2	2A
0005435135603	4914	3	6C
0005435135602	4914	4	7D
0005435929606	33050	1	3B
0005435929608	33050	2	7B
0005435929607	33050	3	20C
0005434983217	9498	1	1D
0005434983216	9498	2	6B
0005434983220	9498	3	6C
0005434983219	9498	4	20A
0005434983215	9498	5	21C
0005434983218	9498	6	22D
0005434217914	27390	1	2C
0005434217915	27390	2	4B
0005434217913	27390	3	18D
0005434217912	27390	4	20D
0005433985267	25927	1	1A
0005433960037	25927	2	1B
0005433960047	25927	3	1F
0005433985295	25927	4	1H
0005433960074	25927	5	1G
0005433985289	25927	6	2C
0005433960044	25927	7	2H
0005433960035	25927	8	3C
0005433985273	25927	9	4B
0005433985283	25927	10	4A
0005433985306	25927	11	4F
0005433985264	25927	12	4C
0005433960073	25927	13	4G
0005433985285	25927	14	5F
0005433985291	25927	15	9G
0005433985280	25927	16	11B
0005433960040	25927	17	11D
0005433960031	25927	18	12G
0005433985268	25927	19	13A
0005433960066	25927	20	13B
0005433985297	25927	21	13E
0005433985305	25927	22	13F
0005433960059	25927	23	14D
0005433960041	25927	24	14E
0005433960081	25927	25	14H
0005433960053	25927	26	15D
0005433960032	25927	27	15B
0005433985266	25927	28	15E
0005433985262	25927	29	15G
0005433960029	25927	30	16F
0005433960028	25927	31	16E
0005433985263	25927	32	16D
0005433985301	25927	33	16G
0005433960077	25927	34	16H
0005433985287	25927	35	17B
0005433960070	25927	36	17A
0005433985307	25927	37	17E
0005433985272	25927	38	17G
0005433960057	25927	39	17H
0005433960076	25927	40	18B
0005433985293	25927	41	19A
0005433960065	25927	42	19E
0005433960061	25927	43	19F
0005433985288	25927	44	19H
0005433960036	25927	45	20A
0005433985278	25927	46	20B
0005433960033	25927	47	20G
0005433960039	25927	48	21A
0005433960056	25927	49	20H
0005433985277	25927	50	21B
0005433960050	25927	51	21F
0005433960045	25927	52	22A
0005433985299	25927	53	22F
0005433960063	25927	54	22E
0005433985269	25927	55	23A
0005433985290	25927	56	24D
0005433960049	25927	57	24F
0005433960052	25927	58	24H
0005433985304	25927	59	25E
0005433985292	25927	60	27B
0005433985279	25927	61	27F
0005433960042	25927	62	27G
0005433960075	25927	63	28A
0005433985276	25927	64	28B
0005433960055	25927	65	28H
0005433985271	25927	66	28G
0005433960069	25927	67	29A
0005433960046	25927	68	29F
0005433960054	25927	69	29H
0005433960071	25927	70	29G
0005433985303	25927	71	30A
0005433985282	25927	72	30E
0005433985274	25927	73	30H
0005433985298	25927	74	31B
0005433960048	25927	75	31G
0005433960038	25927	76	32A
0005433960034	25927	77	32D
0005433985286	25927	78	32H
0005433960058	25927	79	32G
0005433985275	25927	80	33B
0005433960078	25927	81	33E
0005433985296	25927	82	33F
0005433985281	25927	83	33H
0005433960051	25927	84	34D
0005433985284	25927	85	34E
0005433960060	25927	86	34H
0005433985265	25927	87	35A
0005433960079	25927	88	35E
0005433985270	25927	89	35D
0005433960043	25927	90	35G
0005433960080	25927	91	36B
0005433960068	25927	92	36A
0005433985261	25927	93	36D
0005433985300	25927	94	36E
0005433960072	25927	95	36G
0005433960064	25927	96	37A
0005433960030	25927	97	37E
0005433985294	25927	98	37G
0005433960062	25927	99	38G
0005433960067	25927	100	39F
0005433985302	25927	101	39E
0005432269458	970	1	1B
0005434479984	970	2	2B
0005434479978	970	3	2C
0005434479990	970	4	2D
0005434479993	970	5	3B
0005434479988	970	6	3C
0005434479989	970	7	4A
0005434479979	970	8	4B
0005434479981	970	9	4C
0005434479991	970	10	4D
0005434479999	970	11	5D
0005433165674	970	12	6C
0005434480001	970	13	6D
0005434479992	970	14	7B
0005434479980	970	15	7C
0005434480003	970	16	18A
0005434480002	970	17	18B
0005434479985	970	18	18C
0005434479997	970	19	18D
0005434479987	970	20	19B
0005434479982	970	21	19C
0005434480000	970	22	20B
0005434479994	970	23	20C
0005434479998	970	24	20D
0005434479995	970	25	21A
0005434479983	970	26	21D
0005434479986	970	27	22C
0005432269457	970	28	22D
0005434479996	970	29	23A
0005433165732	16560	1	1A
0005433165733	16560	2	3B
0005433165728	16560	3	3C
0005433165723	16560	4	5B
0005433165734	16560	5	5C
0005434479923	16560	6	6C
0005433165730	16560	7	7B
0005433165724	16560	8	7C
0005433165727	16560	9	19A
0005433165731	16560	10	19B
0005433165726	16560	11	19C
0005433165729	16560	12	21A
0005433165722	16560	13	21B
0005433165725	16560	14	21C
0005433872439	3193	1	2C
0005433872440	3193	2	4A
0005433872441	3193	3	4B
0005433872438	3193	4	4D
0005433872442	3193	5	20D
0005433872436	3193	6	22A
0005433872437	3193	7	23A
0005435149832	10340	1	1D
0005435149828	10340	2	2D
0005435142382	10340	3	3C
0005435149837	10340	4	4A
0005435142380	10340	5	4B
0005435142384	10340	6	4D
0005435142389	10340	7	5A
0005435149829	10340	8	5C
0005435149833	10340	9	5D
0005435142381	10340	10	6A
0005435149830	10340	11	6B
0005435142383	10340	12	6D
0005435149835	10340	13	7A
0005435149838	10340	14	7B
0005435142388	10340	15	7C
0005435149834	10340	16	18A
0005435142378	10340	17	18C
0005435142387	10340	18	19C
0005435149836	10340	19	19D
0005435149839	10340	20	20A
0005435142379	10340	21	20C
0005435149827	10340	22	20D
0005435149840	10340	23	21C
0005435142386	10340	24	21D
0005435142377	10340	25	22A
0005435149831	10340	26	22C
0005435142385	10340	27	22D
0005435386481	21956	1	1D
0005435386487	21956	2	2A
0005433289754	21956	3	4C
0005435386485	21956	4	5B
0005433289761	21956	5	5D
0005433289758	21956	6	6C
0005433289755	21956	7	7A
0005435386482	21956	8	18A
0005433289760	21956	9	18C
0005435386484	21956	10	18D
0005435386483	21956	11	19D
0005435386488	21956	12	20C
0005433289757	21956	13	21A
0005433289759	21956	14	21B
0005435386486	21956	15	21D
0005433289756	21956	16	22A
0005434573155	11189	1	3F
0005434573144	11189	2	4A
0005434573146	11189	3	5F
0005434573147	11189	4	9D
0005434573156	11189	5	11F
0005434573149	11189	6	12C
0005434573153	11189	7	13D
0005434573158	11189	8	13E
0005434573154	11189	9	16C
0005434573148	11189	10	16E
0005434573152	11189	11	16F
0005434573151	11189	12	17C
0005434573145	11189	13	18A
0005434573150	11189	14	18C
0005434573157	11189	15	18D
0005435508209	20962	1	1A
0005435508208	20962	2	1C
0005435508203	20962	3	1D
0005435502006	20962	4	1F
0005435508207	20962	5	2C
0005435502008	20962	6	2D
0005435502001	20962	7	2F
0005435319461	20962	8	3D
0005435517660	20962	9	3F
0005435319464	20962	10	4A
0005432291895	20962	11	4C
0005435502015	20962	12	4D
0005435319462	20962	13	4E
0005435517657	20962	14	4F
0005435319465	20962	15	5A
0005435502018	20962	16	5C
0005435319463	20962	17	5D
0005435508205	20962	18	5E
0005435502003	20962	19	6A
0005435517652	20962	20	6D
0005435517649	20962	21	6E
0005435508199	20962	22	6F
0005435508200	20962	23	7A
0005435517659	20962	24	7E
0005435502000	20962	25	7F
0005435502012	20962	26	8A
0005435502019	20962	27	8C
0005435502010	20962	28	8D
0005435502013	20962	29	8E
0005435517662	20962	30	8F
0005435517656	20962	31	9A
0005435508206	20962	32	9C
0005435517653	20962	33	9E
0005435502005	20962	34	10A
0005435501998	20962	35	10C
0005432291896	20962	36	10D
0005435502020	20962	37	10E
0005435502014	20962	38	10F
0005435517650	20962	39	11C
0005435517664	20962	40	11D
0005435502011	20962	41	12D
0005435517655	20962	42	12E
0005435502016	20962	43	12F
0005435502002	20962	44	13D
0005435517666	20962	45	13E
0005435502007	20962	46	13F
0005435517663	20962	47	14A
0005434573122	20962	48	14C
0005435508202	20962	49	14F
0005435517654	20962	50	15A
0005432291897	20962	51	15C
0005435517651	20962	52	15D
0005435517658	20962	53	15F
0005435501999	20962	54	16A
0005435517667	20962	55	16C
0005435508201	20962	56	16D
0005435508204	20962	57	16E
0005435517648	20962	58	16F
0005435502017	20962	59	17C
0005435517665	20962	60	17F
0005435319466	20962	61	18A
0005435319467	20962	62	18C
0005435319460	20962	63	18D
0005435517661	20962	64	18F
0005435502004	20962	65	20E
0005435502009	20962	66	20F
0005432706431	2971	1	1F
0005432706435	2971	2	3C
0005432706422	2971	3	4D
0005432706414	2971	4	4F
0005432706437	2971	5	5C
0005432706430	2971	6	5E
0005432706419	2971	7	5D
0005432706412	2971	8	5F
0005432706421	2971	9	6C
0005432706436	2971	10	6F
0005432706432	2971	11	7C
0005432217737	2971	12	8D
0005432706427	2971	13	9A
0005432706428	2971	14	10F
0005432706418	2971	15	11D
0005432217738	2971	16	12C
0005432706429	2971	17	12E
0005432706433	2971	18	12F
0005432217739	2971	19	13F
0005432706417	2971	20	14E
0005432706415	2971	21	15D
0005432706420	2971	22	15F
0005432706424	2971	23	16A
0005432706413	2971	24	16C
0005432706426	2971	25	17A
0005432706423	2971	26	17D
0005432706416	2971	27	18E
0005432217736	2971	28	19F
0005432706434	2971	29	20C
0005432706425	2971	30	20D
0005432692660	30069	1	1A
0005433123647	30069	2	1C
0005432880612	30069	3	1D
0005432706330	30069	4	1F
0005432692681	30069	5	2A
0005432692655	30069	6	2D
0005432692662	30069	7	2F
0005432880614	30069	8	3A
0005433123641	30069	9	3C
0005433123643	30069	10	3D
0005432880623	30069	11	3F
0005433123645	30069	12	5A
0005432692684	30069	13	5C
0005432880624	30069	14	5D
0005432880621	30069	15	5F
0005432692653	30069	16	6A
0005432880619	30069	17	6C
0005432880611	30069	18	6D
0005432880617	30069	19	6E
0005432692679	30069	20	6F
0005432692665	30069	21	7A
0005432692685	30069	22	7C
0005433123653	30069	23	7E
0005433123642	30069	24	7F
0005432692671	30069	25	8A
0005433123650	30069	26	8C
0005433123639	30069	27	8E
0005432706316	30069	28	8F
0005432880620	30069	29	9A
0005433194825	30069	30	9C
0005432706329	30069	31	9D
0005432692673	30069	32	9E
0005432692656	30069	33	9F
0005432692675	30069	34	10C
0005432880613	30069	35	10E
0005433123635	30069	36	10F
0005432692678	30069	37	11C
0005432880615	30069	38	11D
0005432692677	30069	39	11E
0005433123654	30069	40	11F
0005433123640	30069	41	12A
0005432692664	30069	42	12C
0005432880625	30069	43	12E
0005432692659	30069	44	12F
0005432880622	30069	45	13C
0005432692668	30069	46	13D
0005433123646	30069	47	13E
0005432692683	30069	48	13F
0005432880618	30069	49	14D
0005433123636	30069	50	14E
0005432692661	30069	51	14F
0005432692657	30069	52	15A
0005432692654	30069	53	15C
0005432692680	30069	54	15D
0005433123649	30069	55	15E
0005432692658	30069	56	16A
0005433194824	30069	57	16C
0005433123637	30069	58	16D
0005433123648	30069	59	16E
0005432692670	30069	60	16F
0005432692672	30069	61	17A
0005433123638	30069	62	17D
0005432706315	30069	63	17E
0005433123652	30069	64	17F
0005433123644	30069	65	18A
0005432692667	30069	66	18C
0005432692666	30069	67	18D
0005432706307	30069	68	18E
0005432692682	30069	69	19A
0005432706314	30069	70	19C
0005432692674	30069	71	19D
0005432692663	30069	72	19E
0005432692676	30069	73	19F
0005432880616	30069	74	20A
0005432692669	30069	75	20C
0005433123634	30069	76	20D
0005433123651	30069	77	20E
0005433123655	30069	78	20F
0005434988583	23648	1	1A
0005434979348	23648	2	1B
0005434979367	23648	3	1C
0005434979358	23648	4	2B
0005434979360	23648	5	2C
0005434979355	23648	6	2D
0005434988587	23648	7	3A
0005434979366	23648	8	3B
0005434979371	23648	9	3C
0005434979345	23648	10	3D
0005434979369	23648	11	4A
0005434988582	23648	12	4B
0005434988584	23648	13	4D
0005434979373	23648	14	5A
0005434979362	23648	15	5D
0005434979372	23648	16	6A
0005434979359	23648	17	6C
0005434979364	23648	18	6D
0005434979349	23648	19	7A
0005434988585	23648	20	7B
0005434979346	23648	21	7C
0005434979363	23648	22	7D
0005434979352	23648	23	18A
0005434979354	23648	24	18B
0005434979374	23648	25	18C
0005434979351	23648	26	18D
0005434979350	23648	27	19A
0005434979365	23648	28	19B
0005434979370	23648	29	19C
0005434979357	23648	30	20A
0005434988586	23648	31	21A
0005434979368	23648	32	21D
0005434979347	23648	33	22A
0005434979353	23648	34	22B
0005434988581	23648	35	22C
0005434979361	23648	36	22D
0005434988580	23648	37	23A
0005434979356	23648	38	23B
0005434302397	10276	1	2B
0005434302396	10276	2	2C
0005434302395	10276	3	5C
0005434302398	10276	4	18C
0005433113505	19593	1	18C
0005435068399	3559	1	1D
0005435068400	3559	2	2C
0005435068378	3559	3	3A
0005435068418	3559	4	3D
0005435068398	3559	5	4C
0005435068388	3559	6	4D
0005435068382	3559	7	4E
0005435068371	3559	8	4F
0005435068376	3559	9	5A
0005435068374	3559	10	5C
0005435068402	3559	11	5D
0005435068372	3559	12	6A
0005435718856	3559	13	6C
0005435068395	3559	14	6D
0005435068419	3559	15	6E
0005435068403	3559	16	7C
0005435068373	3559	17	7D
0005435068396	3559	18	7E
0005435068413	3559	19	7F
0005435068407	3559	20	8A
0005435718857	3559	21	8E
0005435068410	3559	22	8F
0005435068392	3559	23	9E
0005435068412	3559	24	10C
0005435068417	3559	25	10D
0005435068381	3559	26	10E
0005435068408	3559	27	10F
0005435068397	3559	28	11C
0005435068420	3559	29	11E
0005435068389	3559	30	11F
0005435068377	3559	31	12A
0005435068391	3559	32	12C
0005435068415	3559	33	12D
0005435068386	3559	34	12E
0005435718860	3559	35	13D
0005435068375	3559	36	13E
0005435718861	3559	37	14A
0005435068379	3559	38	14C
0005435068414	3559	39	14D
0005435068383	3559	40	14E
0005435068390	3559	41	15D
0005435718862	3559	42	15F
0005435068406	3559	43	16A
0005435068393	3559	44	16D
0005435068387	3559	45	16E
0005435068401	3559	46	16F
0005435068411	3559	47	17A
0005435068409	3559	48	17D
0005435068416	3559	49	17E
0005435068384	3559	50	17F
0005435718858	3559	51	18A
0005435068394	3559	52	18D
0005435068421	3559	53	18E
0005435068405	3559	54	18F
0005435068385	3559	55	19C
0005435068404	3559	56	19D
0005435068422	3559	57	20A
0005435068380	3559	58	20E
0005435718859	3559	59	20F
0005435925120	15305	1	1C
0005435925099	15305	2	3A
0005435925117	15305	3	4A
0005435925114	15305	4	5F
0005435925101	15305	5	6E
0005435925102	15305	6	7C
0005435925107	15305	7	9A
0005435925103	15305	8	9D
0005435925098	15305	9	9E
0005435925111	15305	10	9F
0005435925115	15305	11	10A
0005435925113	15305	12	10E
0005435925118	15305	13	12A
0005435925108	15305	14	12C
0005435925116	15305	15	12F
0005435925112	15305	16	13C
0005435925097	15305	17	14D
0005435925109	15305	18	16A
0005435939862	15305	19	16C
0005435925106	15305	20	16E
0005435925110	15305	21	17A
0005435925096	15305	22	17C
0005435925105	15305	23	17E
0005435925119	15305	24	18E
0005435925104	15305	25	20A
0005435925100	15305	26	20C
0005432658563	18200	1	2A
0005432659678	18200	2	3A
0005432658562	18200	3	3B
0005432660790	18200	4	5A
0005432659677	18200	5	6B
0005432901308	240	1	6D
0005432157466	240	2	9C
0005432157465	240	3	14F
0005432901309	240	4	26A
0005432207624	239	1	1A
0005432288941	239	2	1C
0005432261314	239	3	2A
0005432817082	239	4	2F
0005432261299	239	5	4D
0005432261301	239	6	5A
0005432261279	239	7	5F
0005432817073	239	8	6A
0005432261303	239	9	6F
0005432261294	239	10	6D
0005432261276	239	11	7A
0005432261297	239	12	8A
0005432817074	239	13	8B
0005432261307	239	14	8D
0005432207625	239	15	9B
0005432261317	239	16	10D
0005434153517	239	17	10F
0005432261286	239	18	11A
0005432261285	239	19	11E
0005432817063	239	20	12A
0005432817088	239	21	11F
0005432261305	239	22	12D
0005432261291	239	23	12F
0005432261310	239	24	13A
0005432817079	239	25	13C
0005432817077	239	26	13B
0005432261306	239	27	13D
0005432817081	239	28	13E
0005432207626	239	29	14B
0005432817087	239	30	14A
0005432261309	239	31	14C
0005432817084	239	32	15B
0005432261277	239	33	15A
0005432261300	239	34	15C
0005432288943	239	35	15D
0005432817078	239	36	15F
0005432261281	239	37	15E
0005432817067	239	38	16F
0005432261296	239	39	17B
0005432817070	239	40	17A
0005432261319	239	41	17C
0005432261293	239	42	17E
0005432261290	239	43	18A
0005432261280	239	44	18B
0005432817080	239	45	18D
0005432261316	239	46	18C
0005432817085	239	47	19C
0005432817072	239	48	19E
0005432288942	239	49	20C
0005432261292	239	50	20D
0005432261315	239	51	20F
0005432817061	239	52	21A
0005432261311	239	53	21C
0005432817069	239	54	21B
0005432817076	239	55	21D
0005432261320	239	56	22A
0005432261283	239	57	22B
0005432261304	239	58	22D
0005432817068	239	59	22E
0005432817059	239	60	23D
0005432817066	239	61	23C
0005432261287	239	62	23F
0005432817062	239	63	23E
0005432261288	239	64	24B
0005432817060	239	65	24C
0005432261321	239	66	24E
0005432817071	239	67	24D
0005432817064	239	68	24F
0005432261298	239	69	25B
0005432817086	239	70	26D
0005432261318	239	71	27C
0005432261313	239	72	27F
0005432261308	239	73	28A
0005432261278	239	74	28B
0005432261284	239	75	28F
0005432261312	239	76	29C
0005432288940	239	77	30A
0005432261282	239	78	29F
0005432817065	239	79	30C
0005434153516	239	80	30E
0005432261302	239	81	30F
0005432261289	239	82	31B
0005432261295	239	83	31C
0005432817083	239	84	31E
0005432817075	239	85	31F
0005432019910	8069	1	1A
0005433101404	8069	2	1D
0005432019913	8069	3	1C
0005432919568	8069	4	2A
0005432919572	8069	5	2C
0005433101426	8069	6	2F
0005432751481	8069	7	3A
0005432019898	8069	8	3D
0005432919582	8069	9	3C
0005432919579	8069	10	3F
0005432919569	8069	11	4D
0005433101411	8069	12	4C
0005432019892	8069	13	5A
0005432677521	8069	14	4F
0005433101444	8069	15	5C
0005432919571	8069	16	5D
0005432044487	8069	17	6C
0005433101407	8069	18	7A
0005433101425	8069	19	6F
0005433101417	8069	20	7D
0005433101402	8069	21	7C
0005432019893	8069	22	7F
0005432919586	8069	23	8A
0005433101398	8069	24	8C
0005433101394	8069	25	8B
0005432391960	8069	26	8D
0005433101415	8069	27	8F
0005433101431	8069	28	9B
0005432919570	8069	29	9C
0005432753258	8069	30	9D
0005433101439	8069	31	9F
0005432919575	8069	32	9E
0005432019912	8069	33	10A
0005433101450	8069	34	10B
0005432044488	8069	35	10D
0005433101416	8069	36	10C
0005432919574	8069	37	10E
0005433101446	8069	38	11B
0005433101451	8069	39	11E
0005433101391	8069	40	12C
0005432919576	8069	41	12B
0005432019900	8069	42	12D
0005432677523	8069	43	12F
0005433101423	8069	44	12E
0005432919580	8069	45	13B
0005432044486	8069	46	13C
0005433101453	8069	47	13E
0005433101418	8069	48	13D
0005432019889	8069	49	14A
0005433101410	8069	50	14C
0005432919567	8069	51	14E
0005433101401	8069	52	14D
0005433101409	8069	53	14F
0005433101438	8069	54	15B
0005432019902	8069	55	15F
0005433101406	8069	56	15E
0005432019891	8069	57	16B
0005432045587	8069	58	16D
0005432753256	8069	59	16E
0005433101424	8069	60	16F
0005433101435	8069	61	17B
0005433101422	8069	62	17A
0005433101427	8069	63	17C
0005432019899	8069	64	17D
0005432019894	8069	65	17F
0005432751482	8069	66	17E
0005432019888	8069	67	18A
0005433101433	8069	68	18B
0005432677520	8069	69	18D
0005433101420	8069	70	18F
0005433101436	8069	71	19B
0005433101396	8069	72	19D
0005433101432	8069	73	20A
0005432019904	8069	74	19E
0005433101437	8069	75	20B
0005432677522	8069	76	20C
0005432019903	8069	77	20E
0005432753255	8069	78	20D
0005432919578	8069	79	20F
0005433101440	8069	80	21A
0005432919573	8069	81	21B
0005433101448	8069	82	21D
0005432919581	8069	83	21C
0005433101454	8069	84	21F
0005433101441	8069	85	21E
0005433101413	8069	86	22A
0005433101414	8069	87	22B
0005433101419	8069	88	22C
0005433101455	8069	89	22E
0005432919584	8069	90	22D
0005433101408	8069	91	22F
0005433101421	8069	92	23C
0005433101405	8069	93	23B
0005433101456	8069	94	23D
0005432019905	8069	95	23F
0005432019901	8069	96	24A
0005433101430	8069	97	24C
0005433101403	8069	98	24E
0005432019909	8069	99	24D
0005433101443	8069	100	24F
0005432391959	8069	101	25A
0005433101434	8069	102	25C
0005432019908	8069	103	25F
0005432019897	8069	104	25E
0005432751483	8069	105	26A
0005432019895	8069	106	26B
0005433101447	8069	107	26C
0005433101442	8069	108	26E
0005433101393	8069	109	26D
0005432919583	8069	110	26F
0005432019896	8069	111	27B
0005432919587	8069	112	27A
0005433101399	8069	113	27C
0005432019906	8069	114	27D
0005432753257	8069	115	27F
0005433101400	8069	116	27E
0005433101449	8069	117	28A
0005433101395	8069	118	28D
0005433101445	8069	119	28C
0005432919585	8069	120	28F
0005433101458	8069	121	29C
0005432019907	8069	122	29B
0005433101397	8069	123	29D
0005432019911	8069	124	29E
0005433101457	8069	125	29F
0005432019890	8069	126	30C
0005432045588	8069	127	30B
0005432019914	8069	128	30A
0005433101429	8069	129	30D
0005433101452	8069	130	30E
0005433101428	8069	131	30F
0005432919577	8069	132	31A
0005433101392	8069	133	31C
0005433101412	8069	134	31D
0005432019915	8069	135	31E
0005432901378	8068	1	1A
0005432901370	8068	2	4C
0005432901382	8068	3	5A
0005432901374	8068	4	6F
0005432002049	8068	5	7C
0005432901381	8068	6	7F
0005432901375	8068	7	10C
0005432901372	8068	8	11A
0005432901380	8068	9	11B
0005432901377	8068	10	13D
0005432901368	8068	11	13F
0005432901383	8068	12	13E
0005432901366	8068	13	16B
0005432901373	8068	14	16D
0005432901367	8068	15	17A
0005432816958	8068	16	17F
0005432901376	8068	17	19B
0005432816959	8068	18	20D
0005432901379	8068	19	24E
0005432002048	8068	20	25B
0005432901365	8068	21	25F
0005432901371	8068	22	26A
0005432901369	8068	23	31D
0005433870701	9640	1	5A
0005433870700	9640	2	5B
0005433870702	9640	3	6A
0005434175696	32365	1	2B
0005434175695	32365	2	3A
0005434175694	32365	3	4A
0005434175697	32365	4	6A
0005434937882	3495	1	1C
0005434426229	3495	2	1A
0005434877021	3495	3	1H
0005435125840	3495	4	1G
0005435625929	3495	5	1D
0005434876979	3495	6	1K
0005434876981	3495	7	2D
0005434877036	3495	8	2C
0005434876982	3495	9	2G
0005434876992	3495	10	2K
0005434877020	3495	11	3C
0005435125850	3495	12	3H
0005435625944	3495	13	3G
0005434876969	3495	14	4A
0005434876946	3495	15	4K
0005435125834	3495	16	4H
0005434876988	3495	17	5D
0005434877002	3495	18	5C
0005435125816	3495	19	5A
0005432799091	3495	20	5H
0005434426215	3495	21	5G
0005434876960	3495	22	11A
0005434877005	3495	23	11C
0005434877033	3495	24	11F
0005434937878	3495	25	11E
0005434877008	3495	26	11H
0005434876966	3495	27	11G
0005434877009	3495	28	12A
0005434877031	3495	29	12E
0005434426217	3495	30	12D
0005432799070	3495	31	12H
0005432613808	3495	32	13C
0005435125851	3495	33	13E
0005432611658	3495	34	13H
0005434877018	3495	35	14A
0005434426214	3495	36	13K
0005435625939	3495	37	14E
0005434877030	3495	38	14D
0005432799081	3495	39	14F
0005435625934	3495	40	14K
0005434426208	3495	41	14H
0005432799084	3495	42	14G
0005432611656	3495	43	15E
0005434877006	3495	44	15D
0005434876991	3495	45	15H
0005434876955	3495	46	15K
0005434876967	3495	47	16D
0005435125843	3495	48	16C
0005434426216	3495	49	16A
0005435125817	3495	50	16K
0005434876949	3495	51	16G
0005434426220	3495	52	17C
0005432799079	3495	53	17D
0005434877027	3495	54	17G
0005435125818	3495	55	17F
0005432799075	3495	56	17H
0005434937873	3495	57	18B
0005435125846	3495	58	18A
0005434877035	3495	59	18F
0005434426227	3495	60	18K
0005434877003	3495	61	18J
0005435625933	3495	62	19B
0005434876994	3495	63	19A
0005435625942	3495	64	19D
0005432799089	3495	65	19C
0005432799073	3495	66	19F
0005435125832	3495	67	19H
0005434937875	3495	68	19G
0005434877039	3495	69	19K
0005434937874	3495	70	19J
0005435625937	3495	71	20C
0005434876944	3495	72	20B
0005434877037	3495	73	20A
0005434877012	3495	74	20D
0005435625948	3495	75	20H
0005435125819	3495	76	20F
0005434937876	3495	77	20J
0005434877016	3495	78	21B
0005435625941	3495	79	21A
0005434426213	3495	80	20K
0005435625936	3495	81	21D
0005432188563	3495	82	21C
0005435625945	3495	83	21E
0005432611655	3495	84	21J
0005435625938	3495	85	21H
0005434876974	3495	86	21G
0005435125844	3495	87	22A
0005435125839	3495	88	21K
0005434877038	3495	89	22E
0005434877014	3495	90	22D
0005435125815	3495	91	22G
0005434876963	3495	92	23D
0005434876952	3495	93	23C
0005434877011	3495	94	23E
0005435125847	3495	95	23J
0005435125833	3495	96	23H
0005435125849	3495	97	24D
0005432613806	3495	98	24E
0005432613807	3495	99	25B
0005435125836	3495	100	25A
0005435125821	3495	101	24G
0005435625943	3495	102	25E
0005434426218	3495	103	25H
0005434426212	3495	104	25G
0005435125820	3495	105	25K
0005434876996	3495	106	25J
0005432188565	3495	107	26C
0005434937890	3495	108	26B
0005435125830	3495	109	26G
0005434876987	3495	110	26H
0005434876954	3495	111	27B
0005432799071	3495	112	27C
0005434426206	3495	113	27E
0005434937884	3495	114	27H
0005435125837	3495	115	27K
0005434876953	3495	116	28B
0005434877032	3495	117	28E
0005434877013	3495	118	28C
0005435125835	3495	119	28G
0005435125822	3495	120	28K
0005434426232	3495	121	29A
0005434937872	3495	122	29C
0005434876956	3495	123	29F
0005434937885	3495	124	29J
0005434426234	3495	125	29H
0005434876997	3495	126	30A
0005434876968	3495	127	29K
0005432799069	3495	128	30E
0005434876984	3495	129	30D
0005434876962	3495	130	30G
0005435125848	3495	131	30H
0005435125841	3495	132	31D
0005435625946	3495	133	31C
0005432799095	3495	134	31B
0005434876973	3495	135	31F
0005434876978	3495	136	31E
0005434876945	3495	137	31H
0005432611657	3495	138	32A
0005432799077	3495	139	31J
0005434876950	3495	140	32E
0005435125845	3495	141	32D
0005435625932	3495	142	32H
0005434937889	3495	143	32G
0005432799086	3495	144	32F
0005434877000	3495	145	33C
0005435125827	3495	146	33B
0005434877010	3495	147	33F
0005435125823	3495	148	33H
0005434876957	3495	149	33G
0005435625930	3495	150	33K
0005434937880	3495	151	33J
0005434877024	3495	152	34B
0005434876976	3495	153	34D
0005434426225	3495	154	34F
0005432799074	3495	155	34J
0005434877029	3495	156	34H
0005434426209	3495	157	35B
0005432799087	3495	158	35A
0005432799080	3495	159	34K
0005432188564	3495	160	35D
0005434877034	3495	161	35E
0005432183437	3495	162	35G
0005434876977	3495	163	35K
0005434426207	3495	164	36C
0005434426235	3495	165	36D
0005434876983	3495	166	36K
0005435125831	3495	167	36J
0005434937891	3495	168	36H
0005434876971	3495	169	37B
0005434937886	3495	170	37A
0005434426223	3495	171	37E
0005434876985	3495	172	37D
0005434426221	3495	173	37J
0005435625935	3495	174	37K
0005432799078	3495	175	38C
0005434876964	3495	176	38A
0005432799076	3495	177	38K
0005434876943	3495	178	38J
0005434876970	3495	179	39A
0005435125829	3495	180	39D
0005434426233	3495	181	39B
0005435125838	3495	182	39E
0005435125814	3495	183	39K
0005434876993	3495	184	40C
0005435625947	3495	185	40A
0005435125826	3495	186	40F
0005434876986	3495	187	40E
0005432799088	3495	188	40D
0005434426205	3495	189	40H
0005434876948	3495	190	40J
0005434937881	3495	191	41B
0005434426230	3495	192	41C
0005434876975	3495	193	41G
0005434937877	3495	194	41E
0005435125824	3495	195	41H
0005432799090	3495	196	41K
0005434426224	3495	197	42G
0005435625928	3495	198	42F
0005434877025	3495	199	42J
0005434876965	3495	200	42H
0005434876980	3495	201	43D
0005434937879	3495	202	43C
0005434876961	3495	203	43B
0005434426231	3495	204	43F
0005434877022	3495	205	43E
0005435125855	3495	206	43J
0005434937883	3495	207	43H
0005432799082	3495	208	43G
0005434876999	3495	209	43K
0005434877017	3495	210	44C
0005432799097	3495	211	44B
0005434876990	3495	212	44E
0005432799093	3495	213	44D
0005435625940	3495	214	44G
0005434876972	3495	215	44F
0005434877026	3495	216	44K
0005434876995	3495	217	45B
0005432183438	3495	218	45F
0005434876959	3495	219	45H
0005435125828	3495	220	45K
0005434877019	3495	221	45J
0005432799096	3495	222	46C
0005434426211	3495	223	46B
0005434426219	3495	224	46A
0005435914681	3495	225	46D
0005434426222	3495	226	46G
0005434877015	3495	227	46J
0005432799083	3495	228	46H
0005434877001	3495	229	47A
0005434876947	3495	230	46K
0005434876998	3495	231	47E
0005434877004	3495	232	47D
0005434876958	3495	233	47K
0005434937888	3495	234	47H
0005432799094	3495	235	48C
0005434877023	3495	236	48A
0005434426226	3495	237	48E
0005435125842	3495	238	48D
0005435125852	3495	239	48H
0005435125825	3495	240	48G
0005432799072	3495	241	48F
0005434877007	3495	242	49A
0005432183436	3495	243	48K
0005434877028	3495	244	49G
0005432799092	3495	245	49K
0005434426228	3495	246	50C
0005434426210	3495	247	50A
0005434937887	3495	248	50E
0005435625931	3495	249	50D
0005435125854	3495	250	50H
0005434876951	3495	251	51D
0005435125853	3495	252	50K
0005434876989	3495	253	51F
0005432799085	3495	254	51E
0005435902467	14557	1	1G
0005432059478	14557	2	1H
0005435902457	14557	3	2D
0005434876696	14557	4	3G
0005435902459	14557	5	4C
0005435913866	14557	6	4G
0005434426097	14557	7	5H
0005432799047	14557	8	11K
0005435902464	14557	9	13H
0005432799046	14557	10	14F
0005435902460	14557	11	17A
0005435913869	14557	12	18D
0005435913867	14557	13	20F
0005435902470	14557	14	20G
0005434937815	14557	15	21B
0005432059477	14557	16	22D
0005435902474	14557	17	22J
0005434426098	14557	18	26F
0005435902465	14557	19	27E
0005435902466	14557	20	27D
0005435902469	14557	21	29F
0005435902468	14557	22	31A
0005435902472	14557	23	31F
0005435913873	14557	24	32B
0005432798989	14557	25	33E
0005435913868	14557	26	35A
0005432798988	14557	27	35J
0005434937814	14557	28	37D
0005435902458	14557	29	37F
0005435913872	14557	30	42C
0005435902473	14557	31	42G
0005435902463	14557	32	42J
0005435902471	14557	33	42K
0005435902461	14557	34	43J
0005434426096	14557	35	44A
0005434426092	14557	36	47K
0005435913874	14557	37	48F
0005435913871	14557	38	48G
0005435902462	14557	39	50D
0005435913870	14557	40	51F
0005434325496	3604	1	1D
0005434325491	3604	2	2D
0005434325495	3604	3	5C
0005434325498	3604	4	6B
0005434325492	3604	5	7B
0005434312291	3604	6	7C
0005434312290	3604	7	7D
0005434325503	3604	8	18D
0005434325493	3604	9	19B
0005434325494	3604	10	19C
0005434325502	3604	11	20B
0005434312289	3604	12	20D
0005434325500	3604	13	21D
0005434325497	3604	14	21C
0005434325499	3604	15	22C
0005434325501	3604	16	22D
0005435889814	15616	1	3A
0005435889816	15616	2	4B
0005435889815	15616	3	18A
0005435889818	15616	4	19B
0005435889817	15616	5	21B
0005435957511	665	1	1D
0005435957501	665	2	2C
0005435957510	665	3	3D
0005435957513	665	4	4B
0005435957505	665	5	4D
0005435957509	665	6	6A
0005435957512	665	7	6D
0005435957504	665	8	7A
0005435957508	665	9	7B
0005435957499	665	10	7C
0005435957500	665	11	19B
0005435957503	665	12	19D
0005435957506	665	13	20D
0005435957502	665	14	22B
0005435957507	665	15	23B
0005433420290	15170	1	2A
0005433420287	15170	2	5B
0005433420286	15170	3	5D
0005433420291	15170	4	6D
0005433420288	15170	5	7C
0005433420285	15170	6	20A
0005433420292	15170	7	20D
0005433420289	15170	8	21D
0005435629388	8940	1	2A
0005434247111	16060	1	1B
0005434247112	16060	2	4A
0005434247113	16060	3	4B
0005435163165	4423	1	1A
0005435163159	4423	2	2C
0005435163164	4423	3	4A
0005435163158	4423	4	4C
0005435163160	4423	5	5D
0005435163156	4423	6	7B
0005435163162	4423	7	18A
0005435163157	4423	8	18C
0005435163163	4423	9	19D
0005435163161	4423	10	20A
0005435797283	2844	1	1C
0005435797293	2844	2	2C
0005435797282	2844	3	4C
0005435797288	2844	4	4D
0005435797291	2844	5	4F
0005435797289	2844	6	5E
0005435797287	2844	7	6D
0005435797285	2844	8	9A
0005435797284	2844	9	9C
0005435797290	2844	10	10C
0005435797281	2844	11	13A
0005435797292	2844	12	16A
0005435797280	2844	13	19D
0005435797286	2844	14	20E
0005433404712	29295	1	5A
0005433404708	29295	2	5F
0005433404714	29295	3	6C
0005433404709	29295	4	8A
0005433404711	29295	5	10E
0005433404713	29295	6	12C
0005433404710	29295	7	13C
0005433404707	29295	8	13E
0005433404706	29295	9	15C
0005435376313	5759	1	6A
0005434947909	5732	1	1A
0005434947910	5732	2	1B
0005434947906	5732	3	2B
0005434947907	5732	4	3A
0005434947908	5732	5	4A
0005434947905	5732	6	3B
0005434947912	5732	7	4B
0005434947913	5732	8	5B
0005434947904	5732	9	6A
0005434947911	5732	10	6B
0005435376321	16415	1	1B
0005435376319	16415	2	2B
0005435376320	16415	3	3A
0005433960088	6940	1	1F
0005433960139	6940	2	2A
0005433960097	6940	3	2F
0005433960090	6940	4	3C
0005433960085	6940	5	4C
0005433960126	6940	6	4D
0005433960098	6940	7	5A
0005433960112	6940	8	5D
0005433960140	6940	9	5E
0005433960138	6940	10	5F
0005433960095	6940	11	6A
0005433960094	6940	12	6D
0005433960102	6940	13	6E
0005433960125	6940	14	6F
0005433960089	6940	15	7A
0005433960083	6940	16	7D
0005433960091	6940	17	8A
0005433960111	6940	18	8C
0005433960137	6940	19	8D
0005433960116	6940	20	8E
0005433960119	6940	21	8F
0005433960100	6940	22	9A
0005433960130	6940	23	9D
0005433960092	6940	24	9E
0005433960135	6940	25	9F
0005433960104	6940	26	10A
0005433960141	6940	27	10C
0005433960110	6940	28	10E
0005433960134	6940	29	10F
0005433960136	6940	30	11A
0005433960131	6940	31	11C
0005433960121	6940	32	11D
0005433960132	6940	33	11E
0005433960118	6940	34	12A
0005433960133	6940	35	12C
0005433960108	6940	36	12E
0005433960087	6940	37	13A
0005433960096	6940	38	13D
0005433960115	6940	39	13F
0005433960084	6940	40	14C
0005433960109	6940	41	14D
0005433960082	6940	42	14E
0005433960107	6940	43	14F
0005433960114	6940	44	15D
0005433960093	6940	45	15F
0005433960086	6940	46	16A
0005433960105	6940	47	16C
0005433960120	6940	48	16D
0005433960122	6940	49	16E
0005433960099	6940	50	17D
0005433960113	6940	51	17E
0005433960129	6940	52	18A
0005433960123	6940	53	18E
0005433960103	6940	54	18F
0005433960106	6940	55	19A
0005433960127	6940	56	19E
0005433960128	6940	57	20A
0005433960101	6940	58	20C
0005433960117	6940	59	20D
0005433960124	6940	60	20F
0005435082671	26137	1	3A
0005435082673	26137	2	2B
0005435082670	26137	3	4A
0005435082676	26137	4	4B
0005435082674	26137	5	5A
0005435082677	26137	6	5B
0005435082675	26137	7	6A
0005435082672	26137	8	6B
0005434244577	5073	1	2A
0005434244595	5073	2	2D
0005434244579	5073	3	4C
0005434244588	5073	4	4D
0005434244591	5073	5	6D
0005434244601	5073	6	7A
0005434244581	5073	7	7F
0005434244590	5073	8	8B
0005434244573	5073	9	8D
0005434244598	5073	10	9B
0005434244594	5073	11	9A
0005434244589	5073	12	10C
0005434244584	5073	13	10D
0005434244603	5073	14	10E
0005434244575	5073	15	11F
0005434244596	5073	16	13D
0005434244585	5073	17	13E
0005434244600	5073	18	14B
0005432166858	5073	19	15A
0005434244592	5073	20	15B
0005432166857	5073	21	15F
0005434244574	5073	22	16D
0005434244580	5073	23	19D
0005434244602	5073	24	20D
0005434244576	5073	25	20E
0005434244578	5073	26	21A
0005434244586	5073	27	21B
0005434244583	5073	28	22D
0005434244597	5073	29	23C
0005432166856	5073	30	23D
0005434244593	5073	31	25C
0005432166859	5073	32	25D
0005434244587	5073	33	27B
0005434244582	5073	34	29E
0005434244599	5073	35	31F
0005433784470	5074	1	1C
0005433784467	5074	2	1A
0005433784445	5074	3	1F
0005433613727	5074	4	1D
0005433613758	5074	5	2A
0005433613704	5074	6	2D
0005432145085	5074	7	2C
0005433784453	5074	8	2F
0005432104927	5074	9	3A
0005433613739	5074	10	3C
0005432104939	5074	11	3D
0005433613751	5074	12	4A
0005433613731	5074	13	3F
0005433613732	5074	14	4C
0005433613734	5074	15	4D
0005433784450	5074	16	5A
0005433613720	5074	17	4F
0005432104918	5074	18	5C
0005433613689	5074	19	5F
0005433784463	5074	20	5D
0005433613710	5074	21	6A
0005433613749	5074	22	6C
0005433613717	5074	23	6D
0005432666359	5074	24	7A
0005433613752	5074	25	6F
0005433613721	5074	26	7D
0005432665248	5074	27	7C
0005432665247	5074	28	7F
0005433613737	5074	29	8A
0005433613707	5074	30	8B
0005432104913	5074	31	8D
0005433613742	5074	32	8C
0005433784471	5074	33	8E
0005433784459	5074	34	9A
0005432104923	5074	35	8F
0005433613696	5074	36	9C
0005433613733	5074	37	9B
0005432667426	5074	38	9E
0005433784449	5074	39	9D
0005432104910	5074	40	10A
0005433784457	5074	41	9F
0005432104914	5074	42	10B
0005432104915	5074	43	10C
0005433613702	5074	44	10E
0005433784442	5074	45	10D
0005432104950	5074	46	10F
0005432104922	5074	47	11A
0005432667427	5074	48	11C
0005432104934	5074	49	11B
0005433613698	5074	50	11D
0005433613690	5074	51	11F
0005432104932	5074	52	11E
0005433784440	5074	53	12A
0005433784474	5074	54	12B
0005433613713	5074	55	12D
0005432104942	5074	56	12C
0005432104908	5074	57	12E
0005433613746	5074	58	12F
0005432104912	5074	59	13B
0005433613715	5074	60	13A
0005433613687	5074	61	13C
0005433613747	5074	62	13D
0005433613740	5074	63	13E
0005433613691	5074	64	14A
0005433613711	5074	65	13F
0005433613705	5074	66	14B
0005432104948	5074	67	14D
0005432104931	5074	68	14C
0005433784455	5074	69	14E
0005432104955	5074	70	14F
0005433613692	5074	71	15A
0005433613693	5074	72	15C
0005433784476	5074	73	15B
0005433613694	5074	74	15E
0005432104919	5074	75	15D
0005432104928	5074	76	16A
0005433613741	5074	77	15F
0005433613688	5074	78	16B
0005432104907	5074	79	16D
0005433784468	5074	80	16C
0005433784475	5074	81	16E
0005433784464	5074	82	16F
0005432104936	5074	83	17A
0005433613738	5074	84	17D
0005433613714	5074	85	17C
0005432665246	5074	86	17B
0005433613750	5074	87	17F
0005433613718	5074	88	17E
0005432104925	5074	89	18A
0005432666360	5074	90	18B
0005433613754	5074	91	18D
0005433784458	5074	92	18C
0005433613719	5074	93	18E
0005433613748	5074	94	18F
0005432104943	5074	95	19C
0005432104941	5074	96	19B
0005433784456	5074	97	19E
0005433784473	5074	98	19D
0005432104951	5074	99	20B
0005433784462	5074	100	20A
0005433613736	5074	101	20C
0005433784441	5074	102	20E
0005433613708	5074	103	20D
0005433613703	5074	104	20F
0005433784469	5074	105	21A
0005433784466	5074	106	21C
0005433784446	5074	107	21B
0005433613709	5074	108	21D
0005432104954	5074	109	21F
0005433613760	5074	110	21E
0005433613728	5074	111	22B
0005433613724	5074	112	22A
0005433613723	5074	113	22C
0005432104945	5074	114	22D
0005432104917	5074	115	22F
0005433613699	5074	116	22E
0005433613735	5074	117	23A
0005433784444	5074	118	23C
0005433613730	5074	119	23B
0005433613706	5074	120	23D
0005433613744	5074	121	23E
0005432104926	5074	122	24A
0005432104946	5074	123	23F
0005433613701	5074	124	24B
0005433613695	5074	125	24D
0005432104921	5074	126	24C
0005433613753	5074	127	24F
0005433613716	5074	128	24E
0005432145084	5074	129	25A
0005433613759	5074	130	25C
0005433613697	5074	131	25B
0005432104933	5074	132	25D
0005433784472	5074	133	25E
0005432104929	5074	134	26A
0005433613745	5074	135	25F
0005432104937	5074	136	26B
0005432104930	5074	137	26C
0005433784454	5074	138	26E
0005433784460	5074	139	26D
0005432104938	5074	140	26F
0005432104940	5074	141	27B
0005432104909	5074	142	27A
0005433613757	5074	143	27C
0005433784461	5074	144	27D
0005433784443	5074	145	27E
0005433613743	5074	146	28A
0005432104911	5074	147	27F
0005433784448	5074	148	28C
0005432145083	5074	149	28B
0005433613755	5074	150	28D
0005432104944	5074	151	28E
0005432104920	5074	152	29A
0005433613725	5074	153	28F
0005433613726	5074	154	29B
0005432104947	5074	155	29C
0005433613729	5074	156	29D
0005432104935	5074	157	29F
0005433784447	5074	158	29E
0005433784465	5074	159	30A
0005432104916	5074	160	30B
0005433613712	5074	161	30D
0005432104949	5074	162	30C
0005433784452	5074	163	30F
0005433784451	5074	164	30E
0005432104953	5074	165	31A
0005432104924	5074	166	31C
0005433613700	5074	167	31B
0005433613756	5074	168	31D
0005432104952	5074	169	31F
0005433613722	5074	170	31E
0005434229066	5076	1	1A
0005434229071	5076	2	2D
0005434264784	5076	3	3F
0005434173465	5076	4	4C
0005434264806	5076	5	4F
0005434229069	5076	6	5A
0005434229080	5076	7	5C
0005434149579	5076	8	5F
0005434229061	5076	9	6F
0005434229077	5076	10	7A
0005434173466	5076	11	7D
0005434264789	5076	12	7C
0005434264799	5076	13	8D
0005434149578	5076	14	8E
0005434149575	5076	15	9B
0005434229078	5076	16	9C
0005434149574	5076	17	9E
0005435006639	5076	18	9D
0005434229062	5076	19	10A
0005434264805	5076	20	9F
0005434264783	5076	21	10C
0005434149568	5076	22	10D
0005434264792	5076	23	11A
0005434149577	5076	24	10F
0005434264790	5076	25	11D
0005434229060	5076	26	13A
0005434149571	5076	27	13D
0005434264788	5076	28	13F
0005435006640	5076	29	14B
0005434229064	5076	30	14C
0005434229068	5076	31	15A
0005434264791	5076	32	15D
0005435006613	5076	33	15F
0005434264785	5076	34	16B
0005434229065	5076	35	17C
0005434264800	5076	36	17E
0005434229075	5076	37	18A
0005434264807	5076	38	20A
0005434229063	5076	39	20B
0005434264781	5076	40	21E
0005434264787	5076	41	22A
0005434264801	5076	42	22B
0005434264803	5076	43	22F
0005434229059	5076	44	23A
0005434264782	5076	45	23C
0005434229073	5076	46	23B
0005434264802	5076	47	23D
0005434229067	5076	48	24D
0005434264794	5076	49	25A
0005434229072	5076	50	25C
0005435006641	5076	51	25F
0005434264797	5076	52	26C
0005434229079	5076	53	26B
0005434149569	5076	54	26D
0005434264786	5076	55	26E
0005434264795	5076	56	27A
0005434229076	5076	57	27B
0005434229074	5076	58	27D
0005434149570	5076	59	27E
0005434264804	5076	60	27F
0005434173467	5076	61	28C
0005434149573	5076	62	28B
0005434264793	5076	63	29A
0005434149572	5076	64	29E
0005434229070	5076	65	30A
0005434264798	5076	66	30C
0005434264796	5076	67	30E
0005434149576	5076	68	31D
0005435269661	8517	1	3F
0005435269657	8517	2	5D
0005435269659	8517	3	6C
0005435269662	8517	4	8A
0005435269654	8517	5	8E
0005435269653	8517	6	10A
0005435269656	8517	7	13C
0005435269660	8517	8	13D
0005435269664	8517	9	18D
0005435269658	8517	10	19B
0005435269663	8517	11	26F
0005435269655	8517	12	31C
0005432034568	8515	1	2A
0005432034574	8515	2	1F
0005432034587	8515	3	2D
0005433534471	8515	4	3F
0005432335878	8515	5	3D
0005435006704	8515	6	4C
0005432335875	8515	7	4F
0005432034567	8515	8	5F
0005433688782	8515	9	5D
0005432335876	8515	10	6A
0005432047501	8515	11	6D
0005432034564	8515	12	6C
0005435006708	8515	13	6F
0005435006698	8515	14	7D
0005435006713	8515	15	7C
0005432335874	8515	16	7F
0005432034569	8515	17	8A
0005432335871	8515	18	8B
0005435006722	8515	19	9B
0005435006699	8515	20	9A
0005432034590	8515	21	9D
0005432034578	8515	22	10A
0005432335877	8515	23	9F
0005432034586	8515	24	10B
0005434311190	8515	25	10C
0005435286561	8515	26	10E
0005432034572	8515	27	11F
0005433815323	8515	28	12A
0005432034581	8515	29	12B
0005435006707	8515	30	12C
0005433534469	8515	31	12D
0005432034566	8515	32	12F
0005435006720	8515	33	13D
0005435006718	8515	34	13E
0005435286558	8515	35	14B
0005432047499	8515	36	14D
0005435006703	8515	37	14C
0005435006705	8515	38	14E
0005433534470	8515	39	15B
0005433815321	8515	40	15D
0005435006709	8515	41	15F
0005432034582	8515	42	15E
0005435286560	8515	43	16C
0005432034573	8515	44	16E
0005433815324	8515	45	16D
0005432034588	8515	46	17B
0005432034580	8515	47	17A
0005432034584	8515	48	17C
0005432034571	8515	49	17D
0005432335873	8515	50	18B
0005435006716	8515	51	18F
0005433689884	8515	52	19D
0005433815320	8515	53	20C
0005435006717	8515	54	20E
0005432335880	8515	55	20F
0005432034589	8515	56	22A
0005433688783	8515	57	21F
0005435006719	8515	58	22B
0005432034570	8515	59	22D
0005435006710	8515	60	22C
0005435006714	8515	61	22F
0005432034565	8515	62	23A
0005433690899	8515	63	23B
0005432335870	8515	64	23F
0005432034583	8515	65	24B
0005432034563	8515	66	24D
0005435286559	8515	67	24C
0005435006711	8515	68	24E
0005432335872	8515	69	25A
0005435006721	8515	70	25B
0005434264725	8515	71	26A
0005435006715	8515	72	25F
0005432034585	8515	73	26B
0005435006702	8515	74	26D
0005435006701	8515	75	26E
0005433815322	8515	76	27A
0005432034575	8515	77	27C
0005432335869	8515	78	27F
0005435006712	8515	79	28F
0005432047500	8515	80	29B
0005435006700	8515	81	29D
0005432034579	8515	82	29E
0005434311189	8515	83	30A
0005432335879	8515	84	29F
0005432047498	8515	85	30B
0005435006706	8515	86	30E
0005432034576	8515	87	30F
0005435286557	8515	88	31A
0005435286556	8515	89	31D
0005435286562	8515	90	31F
0005432034577	8515	91	31E
0005433202168	12589	1	2B
0005433202175	12589	2	2C
0005433202174	12589	3	3A
0005433202167	12589	4	3D
0005433202166	12589	5	4A
0005433202169	12589	6	5A
0005433202163	12589	7	5C
0005433202164	12589	8	6B
0005433202176	12589	9	7C
0005433202171	12589	10	19C
0005433202173	12589	11	21C
0005433202165	12589	12	21D
0005433202170	12589	13	22C
0005433202172	12589	14	23A
0005434638932	23389	1	1A
0005434638948	23389	2	1B
0005434638928	23389	3	1C
0005434638937	23389	4	2A
0005432290590	23389	5	2C
0005434638946	23389	6	2D
0005434638953	23389	7	3A
0005434638939	23389	8	3B
0005434638950	23389	9	3C
0005434638935	23389	10	3D
0005434638931	23389	11	4A
0005434638940	23389	12	4C
0005434638955	23389	13	5D
0005434638943	23389	14	6B
0005434638952	23389	15	6C
0005432290588	23389	16	6D
0005434638936	23389	17	7D
0005434638951	23389	18	18B
0005434638949	23389	19	18A
0005434638942	23389	20	18C
0005432290589	23389	21	18D
0005434638944	23389	22	19B
0005434638941	23389	23	19C
0005434638947	23389	24	19D
0005434638934	23389	25	20B
0005434638954	23389	26	21B
0005434638929	23389	27	21C
0005434638938	23389	28	21D
0005434638930	23389	29	22A
0005434638945	23389	30	22B
0005434638933	23389	31	23B
0005432054266	21065	1	3A
0005432054264	21065	2	5A
0005432054265	21065	3	15E
0005432327914	21065	4	16F
0005432328057	31265	1	1A
0005432382641	31265	2	1C
0005432382639	31265	3	1D
0005432382643	31265	4	1F
0005432382624	31265	5	2A
0005432328055	31265	6	2C
0005432382614	31265	7	2D
0005432328053	31265	8	2F
0005432382606	31265	9	3A
0005432328054	31265	10	3C
0005432382627	31265	11	3D
0005432328064	31265	12	3F
0005432382646	31265	13	4A
0005432382636	31265	14	4C
0005432328070	31265	15	4D
0005432328072	31265	16	4E
0005432328076	31265	17	4F
0005432328074	31265	18	5A
0005432382634	31265	19	5C
0005432382609	31265	20	5D
0005432328032	31265	21	5E
0005432328067	31265	22	5F
0005432328063	31265	23	6C
0005432382622	31265	24	6D
0005432328038	31265	25	6E
0005432328077	31265	26	6F
0005432382628	31265	27	7A
0005432328034	31265	28	7C
0005432382618	31265	29	7D
0005432382637	31265	30	7E
0005432287117	31265	31	7F
0005432382648	31265	32	8A
0005432328069	31265	33	8C
0005432382645	31265	34	8D
0005432382612	31265	35	8E
0005432328043	31265	36	8F
0005432287119	31265	37	9A
0005432328061	31265	38	9C
0005432382611	31265	39	9D
0005432382630	31265	40	9E
0005432382632	31265	41	9F
0005432382613	31265	42	10A
0005432328065	31265	43	10C
0005432382647	31265	44	10D
0005432382642	31265	45	10E
0005432382608	31265	46	10F
0005432328048	31265	47	11A
0005432382619	31265	48	11C
0005432328046	31265	49	11D
0005432328073	31265	50	11F
0005432382616	31265	51	12A
0005432328050	31265	52	12C
0005432328042	31265	53	12D
0005432328066	31265	54	12E
0005432382633	31265	55	12F
0005432382617	31265	56	13A
0005432328047	31265	57	13D
0005432382615	31265	58	13E
0005432328075	31265	59	13F
0005432382629	31265	60	14A
0005432328033	31265	61	14C
0005432328071	31265	62	14D
0005432382620	31265	63	14E
0005432328035	31265	64	14F
0005432328049	31265	65	15A
0005432328068	31265	66	15D
0005432382638	31265	67	15E
0005432328052	31265	68	15F
0005432382621	31265	69	16A
0005432328040	31265	70	16D
0005432328041	31265	71	16C
0005432328036	31265	72	16E
0005432382644	31265	73	16F
0005432382625	31265	74	17A
0005432287118	31265	75	17C
0005432328062	31265	76	17D
0005432328039	31265	77	17E
0005432328037	31265	78	17F
0005432382635	31265	79	18A
0005432382640	31265	80	18C
0005432382626	31265	81	18D
0005432328056	31265	82	18E
0005432382623	31265	83	18F
0005432382607	31265	84	19A
0005432287116	31265	85	19C
0005432328058	31265	86	19D
0005432382631	31265	87	19E
0005432328044	31265	88	19F
0005432382610	31265	89	20A
0005432328045	31265	90	20C
0005432328060	31265	91	20D
0005432328059	31265	92	20E
0005432328051	31265	93	20F
0005433642141	2486	1	1C
0005433642123	2486	2	2A
0005433642135	2486	3	2D
0005433642120	2486	4	3A
0005433642146	2486	5	3F
0005433642126	2486	6	5A
0005433642136	2486	7	5C
0005433642130	2486	8	5D
0005433642142	2486	9	5E
0005433642125	2486	10	8E
0005433642137	2486	11	9F
0005433642132	2486	12	10F
0005433642133	2486	13	11D
0005433642134	2486	14	11E
0005433642144	2486	15	12F
0005433642128	2486	16	13D
0005433642143	2486	17	13E
0005433642131	2486	18	13F
0005433642148	2486	19	14D
0005433642122	2486	20	14F
0005433642139	2486	21	15E
0005433642147	2486	22	15F
0005433642140	2486	23	16A
0005433642127	2486	24	16F
0005433642149	2486	25	17C
0005433642138	2486	26	17E
0005433642124	2486	27	17F
0005433642121	2486	28	18C
0005433642145	2486	29	19F
0005433642129	2486	30	20A
0005432953812	27603	1	1C
0005432953813	27603	2	2D
0005432953826	27603	3	4D
0005432953827	27603	4	5D
0005433642082	27603	5	7C
0005432953819	27603	6	9D
0005432953824	27603	7	9F
0005432953828	27603	8	11A
0005432953823	27603	9	11E
0005433642083	27603	10	12A
0005432953817	27603	11	13A
0005432953818	27603	12	14C
0005432953816	27603	13	14D
0005432953820	27603	14	15A
0005432953825	27603	15	17A
0005432953821	27603	16	17D
0005432953815	27603	17	17E
0005432953822	27603	18	18A
0005432953829	27603	19	18C
0005432953814	27603	20	20D
0005432423791	13281	1	1C
0005432423804	13281	2	2C
0005432423768	13281	3	2D
0005432423799	13281	4	3D
0005432423770	13281	5	3F
0005432423789	13281	6	4A
0005432423785	13281	7	4C
0005432423803	13281	8	4D
0005432423792	13281	9	5A
0005432423793	13281	10	5E
0005432423778	13281	11	6A
0005432423788	13281	12	6C
0005432423790	13281	13	6D
0005432423796	13281	14	7C
0005432423777	13281	15	8A
0005432423773	13281	16	8D
0005432423784	13281	17	8E
0005432423764	13281	18	8F
0005432423800	13281	19	9C
0005432423809	13281	20	9D
0005432423774	13281	21	10C
0005432423781	13281	22	10D
0005432423797	13281	23	10F
0005432423780	13281	24	11F
0005432423769	13281	25	12A
0005432423806	13281	26	12F
0005432423783	13281	27	13A
0005432423779	13281	28	13C
0005432423765	13281	29	13D
0005432423807	13281	30	13E
0005432423805	13281	31	13F
0005432423795	13281	32	14C
0005432423808	13281	33	14D
0005432423776	13281	34	15E
0005432423787	13281	35	16A
0005432423782	13281	36	16D
0005432423786	13281	37	16F
0005432423763	13281	38	17A
0005432423798	13281	39	17C
0005432423794	13281	40	18A
0005432423772	13281	41	18E
0005432423766	13281	42	19A
0005432423801	13281	43	19E
0005432423771	13281	44	19F
0005432423775	13281	45	20A
0005432423802	13281	46	20D
0005432423767	13281	47	20F
0005432817072	9629	1	1D
0005432817063	9629	2	2D
0005432817062	9629	3	3D
0005432817068	9629	4	4C
0005432817081	9629	5	4E
0005434448268	9629	6	4F
0005432817083	9629	7	5A
0005432817076	9629	8	5C
0005432817066	9629	9	5D
0005432817065	9629	10	6D
0005434448269	9629	11	6F
0005432817073	9629	12	7A
0005432817069	9629	13	8A
0005432822101	9629	14	8C
0005432817067	9629	15	8D
0005432817088	9629	16	8F
0005432288940	9629	17	9C
0005432817070	9629	18	9D
0005432817080	9629	19	10D
0005434448270	9629	20	11A
0005432288942	9629	21	11C
0005432817059	9629	22	11F
0005432817064	9629	23	12A
0005432288943	9629	24	12C
0005432817082	9629	25	12D
0005432817060	9629	26	12E
0005432817061	9629	27	13D
0005432817085	9629	28	14C
0005432817075	9629	29	14D
0005432822099	9629	30	14F
0005432822098	9629	31	15C
0005432817078	9629	32	15E
0005432822100	9629	33	15F
0005432822102	9629	34	16A
0005432822103	9629	35	16D
0005432822105	9629	36	17A
0005432817079	9629	37	17D
0005432288941	9629	38	17E
0005432817084	9629	39	18D
0005432822104	9629	40	18E
0005432817086	9629	41	18F
0005432817087	9629	42	19D
0005432817071	9629	43	19E
0005432817074	9629	44	19F
0005432817077	9629	45	20A
0005432901368	28968	1	1A
0005434157375	28968	2	1C
0005434157374	28968	3	1D
0005432901373	28968	4	1F
0005432901382	28968	5	2D
0005432002048	28968	6	5C
0005434157376	28968	7	5D
0005432901378	28968	8	6F
0005434157378	28968	9	7A
0005432901372	28968	10	7F
0005432901381	28968	11	9E
0005432901365	28968	12	9F
0005434157372	28968	13	10A
0005432901369	28968	14	10D
0005432901371	28968	15	10F
0005432816958	28968	16	12A
0005432901379	28968	17	12F
0005432901383	28968	18	13C
0005434186158	28968	19	13F
0005432901377	28968	20	14C
0005432002049	28968	21	15C
0005434186159	28968	22	15E
0005434157377	28968	23	15D
0005434186157	28968	24	15F
0005432901367	28968	25	16D
0005434157373	28968	26	16E
0005432901370	28968	27	17C
0005432901366	28968	28	17F
0005432901375	28968	29	18A
0005432816959	28968	30	18D
0005432901374	28968	31	19D
0005432901380	28968	32	20A
0005434157371	28968	33	20D
0005432901376	28968	34	20F
0005432611658	15119	1	1A
0005432611657	15119	2	1B
0005432613808	15119	3	2B
0005432611656	15119	4	3A
0005432611655	15119	5	5A
0005432613807	15119	6	6A
0005432613806	15119	7	6B
0005433568217	11850	1	1A
0005433568212	11850	2	1F
0005433568209	11850	3	1D
0005433568204	11850	4	2D
0005433568233	11850	5	3A
0005433568214	11850	6	3C
0005433568238	11850	7	4D
0005433568234	11850	8	4F
0005433568216	11850	9	5C
0005433568218	11850	10	5D
0005433568207	11850	11	6A
0005433568242	11850	12	6D
0005433568220	11850	13	6B
0005433568226	11850	14	6E
0005433568250	11850	15	6F
0005433568232	11850	16	7E
0005433568239	11850	17	7D
0005433568229	11850	18	8A
0005433568231	11850	19	7F
0005433568228	11850	20	8B
0005433568199	11850	21	8E
0005433568241	11850	22	8D
0005433568253	11850	23	9A
0005433568197	11850	24	9D
0005433568223	11850	25	9F
0005433568211	11850	26	11A
0005433568201	11850	27	10F
0005433568256	11850	28	10E
0005433568243	11850	29	11C
0005433568257	11850	30	11F
0005433568206	11850	31	12B
0005433568224	11850	32	12A
0005433568195	11850	33	12D
0005433568193	11850	34	12C
0005433568237	11850	35	12F
0005433568258	11850	36	12E
0005433568245	11850	37	13A
0005433568240	11850	38	13D
0005433568219	11850	39	14A
0005433568202	11850	40	14D
0005433568225	11850	41	14C
0005433568208	11850	42	14E
0005433568196	11850	43	15B
0005433568247	11850	44	15A
0005433568210	11850	45	15F
0005433568236	11850	46	15D
0005433568198	11850	47	16A
0005433568213	11850	48	16B
0005433568244	11850	49	16F
0005433568215	11850	50	17D
0005433568230	11850	51	17C
0005433568235	11850	52	17E
0005433568221	11850	53	18B
0005433568205	11850	54	18C
0005433568227	11850	55	18D
0005433568192	11850	56	18F
0005433568203	11850	57	19B
0005433568222	11850	58	19D
0005433568246	11850	59	19F
0005433568249	11850	60	20B
0005433568252	11850	61	20F
0005433568248	11850	62	20E
0005433568255	11850	63	21A
0005433568254	11850	64	21D
0005433568251	11850	65	21B
0005433568200	11850	66	21E
0005433568194	11850	67	21F
0005432947931	25312	1	1A
0005432947948	25312	2	1F
0005432947953	25312	3	3C
0005432947965	25312	4	4D
0005432947932	25312	5	6B
0005432947967	25312	6	6D
0005432947959	25312	7	6C
0005432947949	25312	8	6E
0005432947963	25312	9	7A
0005432947947	25312	10	6F
0005432947956	25312	11	7B
0005432947941	25312	12	8A
0005432947945	25312	13	8E
0005432947950	25312	14	9E
0005432947970	25312	15	10D
0005432947964	25312	16	10C
0005432947934	25312	17	10B
0005432947954	25312	18	11B
0005432947944	25312	19	11A
0005432947940	25312	20	11F
0005432947943	25312	21	12B
0005432947961	25312	22	12C
0005432947952	25312	23	12E
0005432947942	25312	24	13A
0005432947933	25312	25	13B
0005432947962	25312	26	14A
0005432947955	25312	27	14C
0005432947937	25312	28	14D
0005432947960	25312	29	14E
0005432947968	25312	30	15B
0005432947966	25312	31	16E
0005432947969	25312	32	16F
0005432947930	25312	33	17A
0005432947936	25312	34	17C
0005432947935	25312	35	17E
0005432947946	25312	36	18A
0005432947938	25312	37	18D
0005432947971	25312	38	18C
0005432947939	25312	39	20B
0005432947957	25312	40	20A
0005432947951	25312	41	21B
0005432947958	25312	42	21D
0005432430816	14459	1	2C
0005434026680	14459	2	3A
0005432430810	14459	3	3C
0005432430813	14459	4	5A
0005432430815	14459	5	4D
0005432430814	14459	6	7F
0005432430806	14459	7	8F
0005434026677	14459	8	9D
0005432430807	14459	9	9C
0005432430804	14459	10	9E
0005434026672	14459	11	10D
0005432430811	14459	12	11A
0005432430808	14459	13	10F
0005434026676	14459	14	11B
0005434026675	14459	15	11E
0005434026678	14459	16	13F
0005434026674	14459	17	14D
0005432430818	14459	18	14C
0005434026673	14459	19	18A
0005432430817	14459	20	18D
0005434026679	14459	21	18C
0005432430805	14459	22	19C
0005432430812	14459	23	21B
0005432430809	14459	24	21E
0005434654292	5413	1	2C
0005434656529	5413	2	4C
0005434654291	5413	3	5C
0005434654305	5413	4	6A
0005434654294	5413	5	6F
0005434654290	5413	6	7E
0005434654283	5413	7	7F
0005434654282	5413	8	8C
0005434654284	5413	9	9F
0005434654289	5413	10	10D
0005434654296	5413	11	10E
0005434654303	5413	12	10F
0005434654288	5413	13	11A
0005432114160	5413	14	11D
0005434654286	5413	15	11E
0005434654287	5413	16	12A
0005434654298	5413	17	12F
0005435340000	5413	18	13A
0005434654300	5413	19	13C
0005432114159	5413	20	13F
0005434654307	5413	21	14A
0005434654306	5413	22	14E
0005434656528	5413	23	15E
0005434654297	5413	24	16C
0005434654301	5413	25	16D
0005432114161	5413	26	16E
0005434654295	5413	27	16F
0005434654308	5413	28	17A
0005434654304	5413	29	17D
0005434654302	5413	30	17E
0005434654285	5413	31	18E
0005434654293	5413	32	18F
0005434654281	5413	33	19D
0005432114158	5413	34	19F
0005434654299	5413	35	20E
0005435555343	12523	1	1D
0005435340055	12523	2	4D
0005435340059	12523	3	5C
0005435340051	12523	4	6A
0005435340056	12523	5	6E
0005435340065	12523	6	7A
0005435340063	12523	7	9A
0005435340061	12523	8	9E
0005435340060	12523	9	12E
0005435340053	12523	10	13C
0005435340062	12523	11	13D
0005435340057	12523	12	13E
0005435340052	12523	13	14F
0005435340058	12523	14	16F
0005435555342	12523	15	17C
0005435340054	12523	16	18F
0005435340064	12523	17	20A
0005433715285	7461	1	1A
0005433715302	7461	2	1C
0005433715304	7461	3	1D
0005433719092	7461	4	2A
0005433715272	7461	5	1F
0005433715319	7461	6	2C
0005433715290	7461	7	2F
0005433715288	7461	8	3F
0005433715273	7461	9	4C
0005433715297	7461	10	4E
0005433715315	7461	11	5A
0005433715295	7461	12	5C
0005432078036	7461	13	5D
0005433715280	7461	14	6A
0005433715303	7461	15	6B
0005433656621	7461	16	6D
0005433715300	7461	17	6F
0005433715278	7461	18	7A
0005433715289	7461	19	7B
0005433715292	7461	20	7C
0005433715308	7461	21	7F
0005432078034	7461	22	8B
0005433689883	7461	23	8C
0005433722127	7461	24	8E
0005433715275	7461	25	9A
0005432078033	7461	26	9B
0005433690898	7461	27	9E
0005433688781	7461	28	9D
0005433715305	7461	29	10D
0005433715294	7461	30	10C
0005433722124	7461	31	11C
0005433722123	7461	32	12A
0005432078032	7461	33	12B
0005433715311	7461	34	12E
0005433715298	7461	35	13A
0005433715284	7461	36	13B
0005433715281	7461	37	13D
0005433722122	7461	38	13E
0005433715271	7461	39	14A
0005433715293	7461	40	14C
0005433715318	7461	41	14B
0005433715316	7461	42	14F
0005433715317	7461	43	14E
0005433715296	7461	44	15B
0005433715286	7461	45	15C
0005433722121	7461	46	15F
0005433722126	7461	47	15E
0005433715321	7461	48	16A
0005433715276	7461	49	16B
0005433719093	7461	50	16E
0005433722125	7461	51	16F
0005433715299	7461	52	17B
0005433715277	7461	53	17C
0005433688779	7461	54	17D
0005433688780	7461	55	17F
0005433715312	7461	56	18A
0005433715314	7461	57	18B
0005433715306	7461	58	18C
0005433715279	7461	59	18D
0005433715320	7461	60	18F
0005433656622	7461	61	18E
0005433715310	7461	62	19E
0005433689882	7461	63	19D
0005433656623	7461	64	19F
0005433656624	7461	65	20B
0005433715309	7461	66	20C
0005433715307	7461	67	21A
0005433715301	7461	68	21E
0005433715282	7461	69	22B
0005433715274	7461	70	22A
0005433715287	7461	71	22D
0005433690897	7461	72	22E
0005433715283	7461	73	23A
0005433715291	7461	74	23B
0005433715313	7461	75	23E
0005432078035	7461	76	23F
0005432428881	29257	1	12A
0005432428882	29257	2	13F
0005432006721	29257	3	14B
0005432428884	29257	4	14C
0005432006723	29257	5	16A
0005432428883	29257	6	18A
0005432006722	29257	7	18F
0005432006724	29257	8	19D
0005432006720	29257	9	22A
0005434095085	8680	1	3A
0005434095076	8680	2	3D
0005434326084	8680	3	4C
0005434143701	8680	4	5D
0005434095078	8680	5	6D
0005434143698	8680	6	6E
0005434095074	8680	7	7D
0005434143705	8680	8	8C
0005434095081	8680	9	8F
0005434095083	8680	10	9E
0005434095088	8680	11	10A
0005434143704	8680	12	10E
0005434095077	8680	13	12A
0005434143700	8680	14	12C
0005434095079	8680	15	12D
0005434095075	8680	16	13E
0005434095080	8680	17	14A
0005434095084	8680	18	14C
0005434095086	8680	19	15C
0005434143699	8680	20	17E
0005434143703	8680	21	18A
0005434095087	8680	22	18C
0005434143702	8680	23	19C
0005434095082	8680	24	20C
0005434182020	11670	1	2C
0005434182021	11670	2	2D
0005434182009	11670	3	5D
0005434182016	11670	4	8A
0005434182010	11670	5	8E
0005434182012	11670	6	9E
0005434182015	11670	7	11E
0005434182008	11670	8	12F
0005434095032	11670	9	13C
0005434182018	11670	10	13E
0005434182013	11670	11	16D
0005434182011	11670	12	17C
0005434182014	11670	13	18A
0005434183551	11670	14	18C
0005434182019	11670	15	18D
0005434095031	11670	16	18E
0005434183550	11670	17	19D
0005434184636	11670	18	19F
0005434182017	11670	19	20D
0005433397322	1429	1	1C
0005433397197	1429	2	4D
0005435732163	1429	3	6D
0005433456914	1429	4	6E
0005433397181	1429	5	7C
0005433456915	1429	6	7E
0005432297241	1429	7	8C
0005433397178	1429	8	9E
0005435732165	1429	9	11F
0005433456913	1429	10	12A
0005435732162	1429	11	12F
0005435732164	1429	12	13C
0005433397321	1429	13	15D
0005433397195	1429	14	15F
0005433397182	1429	15	16F
0005433456912	1429	16	17C
0005433456916	1429	17	19A
0005433397224	1429	18	19F
0005432297242	1429	19	20A
0005433397426	19281	1	1A
0005433397424	19281	2	1C
0005433397384	19281	3	1D
0005433397411	19281	4	1F
0005433397389	19281	5	2A
0005433397407	19281	6	2C
0005433397390	19281	7	2D
0005433397417	19281	8	3A
0005433397423	19281	9	3C
0005433397427	19281	10	4A
0005433397383	19281	11	4C
0005433397397	19281	12	4D
0005433397381	19281	13	5D
0005433397400	19281	14	5E
0005433397401	19281	15	6A
0005433397399	19281	16	6E
0005433397415	19281	17	7C
0005433397413	19281	18	7D
0005433397422	19281	19	7E
0005433397388	19281	20	7F
0005433397409	19281	21	8A
0005433397380	19281	22	8C
0005433397420	19281	23	8E
0005433397425	19281	24	9E
0005433397416	19281	25	9F
0005433397392	19281	26	10A
0005433397394	19281	27	10D
0005433397403	19281	28	11C
0005433397398	19281	29	11E
0005433397406	19281	30	12E
0005433397404	19281	31	13C
0005433397385	19281	32	13D
0005433397386	19281	33	13E
0005433397421	19281	34	14A
0005433397419	19281	35	14D
0005432906502	19281	36	14F
0005433397396	19281	37	15D
0005433397402	19281	38	15E
0005432906501	19281	39	16A
0005433397387	19281	40	16C
0005433397410	19281	41	17C
0005433397418	19281	42	17E
0005432906503	19281	43	17F
0005433397408	19281	44	18C
0005433397391	19281	45	18D
0005433397382	19281	46	18E
0005433397412	19281	47	18F
0005433397395	19281	48	19A
0005433397379	19281	49	19C
0005433397414	19281	50	19D
0005433397393	19281	51	19F
0005433397405	19281	52	20A
0005434443482	20558	1	1D
0005434443478	20558	2	2A
0005434443479	20558	3	3B
0005434443475	20558	4	3D
0005434443488	20558	5	4C
0005434443485	20558	6	7D
0005434443481	20558	7	18A
0005434443474	20558	8	19C
0005434443477	20558	9	19B
0005434443486	20558	10	19D
0005434443487	20558	11	20C
0005434443473	20558	12	21B
0005434443483	20558	13	21C
0005434443476	20558	14	21D
0005434443484	20558	15	22A
0005434443480	20558	16	22B
0005434954556	7278	1	1A
0005434954555	7278	2	2B
0005434954557	7278	3	4B
0005434954558	7278	4	5B
0005434954554	7278	5	6A
0005435377549	28348	1	1A
0005435377548	28348	2	4B
0005435377547	28348	3	5A
0005435377546	28348	4	6A
0005434351524	4462	1	2A
0005434351528	4462	2	2D
0005434351521	4462	3	4D
0005434351525	4462	4	5C
0005434351520	4462	5	5D
0005434351519	4462	6	7A
0005434326261	4462	7	7B
0005434351522	4462	8	7D
0005434351516	4462	9	18B
0005434351517	4462	10	19A
0005434351518	4462	11	19C
0005434351527	4462	12	20A
0005434351526	4462	13	21C
0005434351523	4462	14	23A
0005435893534	29639	1	1B
0005435893536	29639	2	3B
0005435893538	29639	3	4A
0005435893535	29639	4	5B
0005435893533	29639	5	5C
0005435893537	29639	6	7B
0005435893539	29639	7	22D
0005433463871	1081	1	2G
0005435091938	1081	2	3G
0005435545639	1081	3	3H
0005433341476	1081	4	5C
0005434446489	1081	5	12B
0005435091934	1081	6	12E
0005433463872	1081	7	12F
0005435091937	1081	8	13A
0005432293174	1081	9	13F
0005434446488	1081	10	14H
0005435091941	1081	11	15F
0005435545637	1081	12	15H
0005435091940	1081	13	17F
0005433341580	1081	14	17H
0005434446487	1081	15	18F
0005434445215	1081	16	20B
0005435091935	1081	17	21F
0005435545636	1081	18	22F
0005435091933	1081	19	22H
0005433462717	1081	20	23H
0005435545638	1081	21	24H
0005433463870	1081	22	28B
0005435091936	1081	23	29D
0005435091942	1081	24	34G
0005434445216	1081	25	35B
0005435545640	1081	26	35E
0005433462718	1081	27	36F
0005434446490	1081	28	36E
0005435091939	1081	29	37A
0005432293175	1081	30	39E
0005433341716	17067	1	1A
0005433341785	17067	2	1C
0005433341707	17067	3	1B
0005433341709	17067	4	1F
0005433341762	17067	5	1H
0005433341732	17067	6	2A
0005433341758	17067	7	2C
0005433341779	17067	8	2G
0005433341717	17067	9	3C
0005433341777	17067	10	3H
0005433341774	17067	11	4B
0005433341734	17067	12	4A
0005433341719	17067	13	5A
0005433341771	17067	14	4H
0005433341722	17067	15	5B
0005433341727	17067	16	5C
0005433341691	17067	17	5F
0005433341692	17067	18	5H
0005433341755	17067	19	9A
0005433341750	17067	20	11A
0005433341746	17067	21	11B
0005433341739	17067	22	11H
0005433341740	17067	23	12G
0005433341743	17067	24	12F
0005433341782	17067	25	13B
0005433341748	17067	26	13D
0005433341704	17067	27	13E
0005433341749	17067	28	13F
0005433269644	17067	29	13H
0005433341690	17067	30	14F
0005433341687	17067	31	15A
0005433341765	17067	32	14H
0005433341761	17067	33	15D
0005433341731	17067	34	15G
0005433341741	17067	35	15F
0005433341753	17067	36	15H
0005433341759	17067	37	16D
0005433341711	17067	38	16B
0005433341720	17067	39	17E
0005433341712	17067	40	17H
0005433341710	17067	41	18B
0005433341784	17067	42	18A
0005433341751	17067	43	18D
0005433341780	17067	44	18F
0005433341786	17067	45	19B
0005433341760	17067	46	19A
0005433341745	17067	47	19D
0005433341686	17067	48	19G
0005433341697	17067	49	20B
0005433341726	17067	50	20E
0005433341730	17067	51	20H
0005433341714	17067	52	21A
0005433269645	17067	53	21B
0005433341718	17067	54	21G
0005433341733	17067	55	21F
0005433159282	17067	56	21H
0005433341685	17067	57	22B
0005433341752	17067	58	22A
0005433341773	17067	59	22F
0005433341757	17067	60	23A
0005433341768	17067	61	23D
0005433341738	17067	62	23G
0005433341754	17067	63	24E
0005433341725	17067	64	24H
0005433341737	17067	65	25E
0005433341693	17067	66	25F
0005433341735	17067	67	27B
0005433341699	17067	68	27A
0005433341705	17067	69	27D
0005433341713	17067	70	27F
0005433341769	17067	71	27H
0005433341695	17067	72	28A
0005433341767	17067	73	28D
0005433341706	17067	74	28B
0005433341694	17067	75	28F
0005433341775	17067	76	29A
0005433341783	17067	77	29G
0005433341702	17067	78	30A
0005433341778	17067	79	30D
0005433341742	17067	80	30F
0005433341764	17067	81	31A
0005433341696	17067	82	30H
0005433341729	17067	83	31B
0005433341763	17067	84	31G
0005433341723	17067	85	32A
0005433159281	17067	86	31H
0005433341698	17067	87	32D
0005433341715	17067	88	32F
0005433269643	17067	89	33B
0005433341781	17067	90	33E
0005433341724	17067	91	33G
0005433341744	17067	92	34A
0005433341684	17067	93	34D
0005435091893	17067	94	34G
0005433341700	17067	95	34H
0005433341747	17067	96	35D
0005433341776	17067	97	35G
0005433341701	17067	98	36B
0005433341708	17067	99	36A
0005433341728	17067	100	36E
0005433341766	17067	101	36D
0005433341703	17067	102	36F
0005433341772	17067	103	36G
0005433341756	17067	104	37B
0005433341689	17067	105	37D
0005433341770	17067	106	37F
0005433269646	17067	107	37H
0005433341721	17067	108	38A
0005433341688	17067	109	38D
0005433341736	17067	110	38H
0005432159796	12790	1	2C
0005432433607	12790	2	2D
0005433812867	12790	3	4F
0005432159795	12790	4	5F
0005432161122	12790	5	7A
0005432433606	12790	6	9D
0005432433608	12790	7	10C
0005433812868	12790	8	11D
0005432161121	12790	9	14B
0005432433605	12790	10	14C
0005432161119	12790	11	14D
0005432161123	12790	12	14E
0005432159797	12790	13	14F
0005432159793	12790	14	16C
0005434066361	12790	15	17A
0005432159794	12790	16	17B
0005432161120	12790	17	20C
0005434081553	30673	1	1A
0005434066529	30673	2	1C
0005434081567	30673	3	1D
0005434066532	30673	4	1F
0005432150080	30673	5	2C
0005434066564	30673	6	2F
0005434066566	30673	7	3D
0005434066521	30673	8	3C
0005434081554	30673	9	3F
0005434066557	30673	10	4B
0005434081551	30673	11	4A
0005434066525	30673	12	4C
0005433989701	30673	13	4E
0005434066574	30673	14	4F
0005432150079	30673	15	5B
0005434066514	30673	16	5A
0005434066570	30673	17	5C
0005434066520	30673	18	5D
0005434066526	30673	19	5E
0005434066581	30673	20	6A
0005434066584	30673	21	5F
0005434081575	30673	22	6C
0005434081563	30673	23	6B
0005434066576	30673	24	6D
0005434066544	30673	25	6F
0005434081557	30673	26	6E
0005434066518	30673	27	7A
0005433989700	30673	28	7B
0005433989704	30673	29	7C
0005434066538	30673	30	7E
0005434066527	30673	31	7D
0005434066553	30673	32	8A
0005434066578	30673	33	7F
0005434066537	30673	34	8B
0005434081569	30673	35	8C
0005432150085	30673	36	8D
0005433989703	30673	37	8F
0005434066519	30673	38	8E
0005434066565	30673	39	9A
0005434081565	30673	40	9B
0005434081564	30673	41	9D
0005434081572	30673	42	9F
0005434066561	30673	43	9E
0005434081559	30673	44	10B
0005434066540	30673	45	10C
0005434066516	30673	46	10D
0005432150082	30673	47	11A
0005434081573	30673	48	11B
0005432150081	30673	49	11D
0005434066517	30673	50	11C
0005432186818	30673	51	11F
0005434066583	30673	52	11E
0005434066580	30673	53	12A
0005434066558	30673	54	12B
0005434066541	30673	55	12C
0005432186816	30673	56	12D
0005434066542	30673	57	13A
0005434066556	30673	58	12F
0005434081558	30673	59	13B
0005434066551	30673	60	13C
0005434066573	30673	61	13D
0005434066534	30673	62	13E
0005434081560	30673	63	13F
0005434066523	30673	64	14C
0005434066562	30673	65	14B
0005434066513	30673	66	14D
0005432150084	30673	67	14F
0005434066549	30673	68	14E
0005434081555	30673	69	15A
0005434081571	30673	70	15C
0005434066545	30673	71	15E
0005434081556	30673	72	15F
0005434066554	30673	73	16B
0005434066560	30673	74	16A
0005434081561	30673	75	16C
0005434066539	30673	76	16E
0005434066522	30673	77	16D
0005432186815	30673	78	16F
0005434066535	30673	79	17A
0005434066531	30673	80	17B
0005434081574	30673	81	17C
0005434066567	30673	82	17E
0005434066548	30673	83	18A
0005434066552	30673	84	17F
0005434066555	30673	85	18B
0005434066572	30673	86	18D
0005434066543	30673	87	18C
0005434066515	30673	88	18F
0005434081568	30673	89	18E
0005434081576	30673	90	19A
0005434066563	30673	91	19B
0005434066577	30673	92	19D
0005434066546	30673	93	19C
0005434066569	30673	94	19E
0005434081552	30673	95	20A
0005434066530	30673	96	20B
0005433989702	30673	97	20D
0005434066550	30673	98	20C
0005434066568	30673	99	20E
0005434066575	30673	100	20F
0005432150083	30673	101	21A
0005434066559	30673	102	21C
0005434066512	30673	103	21B
0005434066582	30673	104	21D
0005432150078	30673	105	21E
0005434066528	30673	106	22A
0005434066547	30673	107	22C
0005434081562	30673	108	22D
0005434081566	30673	109	22F
0005434066571	30673	110	22E
0005434066536	30673	111	23A
0005434081570	30673	112	23B
0005434066533	30673	113	23C
0005432186817	30673	114	23D
0005434066579	30673	115	23F
0005434066524	30673	116	23E
0005432140338	5531	1	1F
0005435765358	5531	2	1C
0005435722022	5531	3	1G
0005435720810	5531	4	2F
0005435765367	5531	5	3B
0005432140341	5531	6	3A
0005432140332	5531	7	4B
0005435765351	5531	8	4F
0005432140337	5531	9	4G
0005433529227	5531	10	5A
0005435765399	5531	11	4H
0005435765356	5531	12	5B
0005435765385	5531	13	5C
0005435720809	5531	14	9A
0005432140336	5531	15	9B
0005435765395	5531	16	9G
0005435765387	5531	17	11A
0005435765374	5531	18	9H
0005435765363	5531	19	11B
0005435765401	5531	20	11D
0005435720808	5531	21	11F
0005435765359	5531	22	11E
0005432140334	5531	23	12A
0005435765365	5531	24	12D
0005435765347	5531	25	12B
0005435765369	5531	26	12E
0005435765350	5531	27	12H
0005432140333	5531	28	13D
0005435765381	5531	29	13F
0005435765362	5531	30	13E
0005435765404	5531	31	13G
0005433527216	5531	32	13H
0005435765360	5531	33	14A
0005435765383	5531	34	14D
0005435725528	5531	35	14F
0005432140339	5531	36	15A
0005435765397	5531	37	15B
0005435735072	5531	38	15H
0005435765371	5531	39	15G
0005435765394	5531	40	16F
0005435765405	5531	41	16D
0005435765398	5531	42	17B
0005435765366	5531	43	17D
0005433529228	5531	44	18A
0005435725531	5531	45	18B
0005434264680	5531	46	18D
0005432140340	5531	47	18E
0005432140335	5531	48	18G
0005435461759	5531	49	18F
0005435461761	5531	50	18H
0005435725529	5531	51	19D
0005435723018	5531	52	19B
0005435765375	5531	53	19E
0005435765400	5531	54	19H
0005435723016	5531	55	20B
0005435765389	5531	56	21A
0005435765388	5531	57	21D
0005435735073	5531	58	21G
0005434264681	5531	59	21H
0005435735074	5531	60	22D
0005435765378	5531	61	22E
0005435765354	5531	62	22G
0005435765402	5531	63	23B
0005433527215	5531	64	23H
0005435725530	5531	65	24B
0005435765382	5531	66	24D
0005435765391	5531	67	24F
0005435765379	5531	68	27A
0005435765364	5531	69	27D
0005433527217	5531	70	27G
0005435765355	5531	71	28A
0005435723019	5531	72	28E
0005435765348	5531	73	28D
0005433529229	5531	74	28H
0005435765357	5531	75	29D
0005433529226	5531	76	29E
0005435765396	5531	77	29G
0005435765403	5531	78	30B
0005433527218	5531	79	30G
0005435765386	5531	80	31D
0005435735071	5531	81	31H
0005435765352	5531	82	31F
0005435765377	5531	83	32E
0005435765349	5531	84	32D
0005435765376	5531	85	32F
0005435725527	5531	86	32H
0005435765370	5531	87	32G
0005435765373	5531	88	33B
0005435765372	5531	89	33E
0005435765384	5531	90	33D
0005435722023	5531	91	33H
0005435723017	5531	92	34H
0005435765353	5531	93	35G
0005435765361	5531	94	36F
0005435735070	5531	95	36G
0005435765393	5531	96	37B
0005435765380	5531	97	37D
0005435765390	5531	98	37F
0005435765392	5531	99	37G
0005435765368	5531	100	38F
0005434264785	13465	1	1G
0005435725512	13465	2	2A
0005434831088	13465	3	1H
0005434264782	13465	4	2H
0005434264798	13465	5	3B
0005434264786	13465	6	3F
0005435461924	13465	7	4A
0005435461942	13465	8	4C
0005432535769	13465	9	5H
0005435461936	13465	10	9H
0005435461925	13465	11	11F
0005434264781	13465	12	12B
0005434264800	13465	13	12G
0005432194454	13465	14	12F
0005432535767	13465	15	12H
0005435461939	13465	16	13D
0005435461914	13465	17	13B
0005435461946	13465	18	13E
0005435461921	13465	19	14D
0005434264797	13465	20	14E
0005435461931	13465	21	14H
0005435461912	13465	22	15D
0005435461935	13465	23	15H
0005434264802	13465	24	15G
0005434264807	13465	25	16B
0005435461920	13465	26	16E
0005435461932	13465	27	16F
0005432194453	13465	28	16H
0005435461944	13465	29	17A
0005435461941	13465	30	17B
0005435461934	13465	31	17E
0005432194456	13465	32	17G
0005435461940	13465	33	18D
0005435461928	13465	34	18E
0005435461930	13465	35	19A
0005435461947	13465	36	19G
0005434264789	13465	37	20A
0005435461943	13465	38	21A
0005434264793	13465	39	21B
0005435461929	13465	40	21H
0005434264794	13465	41	21G
0005435461915	13465	42	22B
0005435461948	13465	43	22F
0005434264806	13465	44	23G
0005435461911	13465	45	23H
0005432194452	13465	46	24B
0005432194455	13465	47	24D
0005434264788	13465	48	24F
0005434264804	13465	49	27E
0005435461927	13465	50	27F
0005435461926	13465	51	27H
0005434264805	13465	52	28G
0005434831087	13465	53	29A
0005435461913	13465	54	29E
0005434264801	13465	55	29H
0005435461938	13465	56	30B
0005434264790	13465	57	30A
0005434831086	13465	58	30G
0005435461918	13465	59	30F
0005435461933	13465	60	31A
0005434264783	13465	61	31G
0005435461919	13465	62	32A
0005435461923	13465	63	32B
0005435461916	13465	64	32H
0005434264796	13465	65	32G
0005434264795	13465	66	33A
0005434264787	13465	67	33B
0005435461922	13465	68	33F
0005432535766	13465	69	34A
0005434264791	13465	70	35B
0005432535768	13465	71	35D
0005434831089	13465	72	35E
0005434264784	13465	73	36B
0005435461945	13465	74	36E
0005434264792	13465	75	36D
0005434264803	13465	76	36G
0005435461937	13465	77	36H
0005435461917	13465	78	38G
0005434264799	13465	79	39E
0005434514929	18703	1	1A
0005434514931	18703	2	1B
0005434513542	18703	3	2A
0005434514930	18703	4	2B
0005434513541	18703	5	4A
0005432649310	4115	1	1F
0005432632638	4115	2	2A
0005432632637	4115	3	2C
0005432632635	4115	4	3C
0005432632643	4115	5	3D
0005432649324	4115	6	4A
0005432649312	4115	7	4C
0005432632647	4115	8	5A
0005432649314	4115	9	6A
0005432649326	4115	10	6E
0005432632650	4115	11	6F
0005432632640	4115	12	7A
0005432649318	4115	13	7E
0005432649319	4115	14	8F
0005432632654	4115	15	9A
0005432632649	4115	16	9F
0005432649315	4115	17	10A
0005432632641	4115	18	10C
0005432649308	4115	19	10E
0005432632639	4115	20	10F
0005432649321	4115	21	11A
0005432649309	4115	22	11E
0005432649313	4115	23	11F
0005432632642	4115	24	12D
0005432649325	4115	25	13E
0005432649317	4115	26	13F
0005432632648	4115	27	14C
0005432632653	4115	28	16A
0005432649322	4115	29	16D
0005432632644	4115	30	16E
0005432649316	4115	31	17A
0005432649320	4115	32	17D
0005432632646	4115	33	18C
0005432632636	4115	34	18D
0005432649311	4115	35	18E
0005432632651	4115	36	19A
0005432632652	4115	37	19E
0005432649323	4115	38	20A
0005432632645	4115	39	20F
0005433007854	1803	1	1A
0005432295845	1803	2	3C
0005433284794	1803	3	5F
0005433284793	1803	4	7C
0005433284770	1803	5	9E
0005432295844	1803	6	15F
0005433007852	1803	7	16E
0005433007965	22607	1	1A
0005433007961	22607	2	1C
0005433007988	22607	3	1D
0005433007981	22607	4	2A
0005433007979	22607	5	2C
0005433284872	22607	6	2D
0005433007998	22607	7	2F
0005433007982	22607	8	3A
0005433284853	22607	9	3D
0005433008002	22607	10	4C
0005433284860	22607	11	4E
0005433284874	22607	12	4F
0005433008007	22607	13	5A
0005433008001	22607	14	5C
0005433284861	22607	15	5D
0005433284866	22607	16	5E
0005433008003	22607	17	5F
0005433007970	22607	18	6A
0005433284856	22607	19	6C
0005433008006	22607	20	6D
0005433007968	22607	21	6F
0005433284854	22607	22	7C
0005433284862	22607	23	7D
0005433008005	22607	24	7E
0005433284852	22607	25	7F
0005433007993	22607	26	8C
0005433284873	22607	27	8E
0005433284858	22607	28	9A
0005433007983	22607	29	9D
0005433007997	22607	30	9E
0005433284855	22607	31	9F
0005433284857	22607	32	10C
0005433007962	22607	33	10D
0005433007989	22607	34	10E
0005433284865	22607	35	10F
0005433007969	22607	36	11A
0005433284877	22607	37	11C
0005433007996	22607	38	11E
0005433284871	22607	39	11F
0005433007994	22607	40	12A
0005433284869	22607	41	12C
0005433284849	22607	42	12D
0005433007964	22607	43	12E
0005433007992	22607	44	12F
0005433007986	22607	45	13A
0005433008000	22607	46	13C
0005433284851	22607	47	13D
0005433007977	22607	48	13E
0005433007995	22607	49	13F
0005433007991	22607	50	14A
0005433007966	22607	51	14C
0005433284864	22607	52	14D
0005433284859	22607	53	14E
0005433007971	22607	54	14F
0005433007974	22607	55	15A
0005433284850	22607	56	15C
0005433007972	22607	57	15D
0005433284876	22607	58	15F
0005433284863	22607	59	16A
0005433007985	22607	60	16C
0005433284867	22607	61	16D
0005433007975	22607	62	16E
0005433007987	22607	63	16F
0005433007978	22607	64	17C
0005433007984	22607	65	17D
0005433007999	22607	66	17E
0005433007990	22607	67	17F
0005433284868	22607	68	18A
0005433007967	22607	69	18C
0005433007963	22607	70	18E
0005433007976	22607	71	18F
0005433007980	22607	72	19A
0005433284870	22607	73	19C
0005433008004	22607	74	19D
0005433284878	22607	75	20A
0005433007973	22607	76	20C
0005433284875	22607	77	20F
0005433845907	5573	1	1A
0005433845934	5573	2	2C
0005433845924	5573	3	2A
0005433845923	5573	4	3D
0005433845957	5573	5	4A
0005433845913	5573	6	4D
0005433845955	5573	7	4C
0005433845928	5573	8	4F
0005433845903	5573	9	5C
0005433845910	5573	10	5A
0005433845961	5573	11	5D
0005433845954	5573	12	6B
0005433845947	5573	13	7C
0005433845929	5573	14	7D
0005433845916	5573	15	8A
0005433845935	5573	16	8B
0005433815318	5573	17	8D
0005433845940	5573	18	8F
0005435282082	5573	19	8E
0005432081425	5573	20	9B
0005433845936	5573	21	9A
0005433845939	5573	22	9C
0005433845951	5573	23	9E
0005433845906	5573	24	9D
0005433845956	5573	25	10B
0005433845937	5573	26	10A
0005433815319	5573	27	10C
0005433845938	5573	28	10E
0005433845904	5573	29	10D
0005433845912	5573	30	11A
0005433845918	5573	31	11E
0005433845921	5573	32	12A
0005433845915	5573	33	12D
0005433845943	5573	34	12C
0005433845958	5573	35	12E
0005433845945	5573	36	13A
0005433845919	5573	37	12F
0005433845927	5573	38	13B
0005433845905	5573	39	13E
0005433845922	5573	40	13D
0005433845942	5573	41	14A
0005433845931	5573	42	14D
0005433845911	5573	43	14F
0005433845960	5573	44	14E
0005433845909	5573	45	15D
0005433845914	5573	46	15C
0005433845946	5573	47	15F
0005432081424	5573	48	15E
0005433845926	5573	49	17B
0005433815315	5573	50	17A
0005433845925	5573	51	17D
0005433845950	5573	52	17C
0005433815317	5573	53	17E
0005433845917	5573	54	18B
0005433845944	5573	55	18A
0005433815316	5573	56	17F
0005433845933	5573	57	19A
0005433845908	5573	58	18F
0005433845953	5573	59	19C
0005433845920	5573	60	19D
0005432081423	5573	61	19F
0005433845941	5573	62	19E
0005433845959	5573	63	20D
0005433845952	5573	64	20C
0005433845949	5573	65	20F
0005433845932	5573	66	21D
0005433845948	5573	67	21B
0005433845930	5573	68	21E
0005435282162	13877	1	2F
0005435282158	13877	2	2D
0005433845673	13877	3	3A
0005435282168	13877	4	3D
0005432003659	13877	5	3F
0005433845670	13877	6	4D
0005435282180	13877	7	6A
0005433845757	13877	8	6C
0005435282172	13877	9	6B
0005434173465	13877	10	6E
0005435282174	13877	11	7A
0005435282170	13877	12	7D
0005435282153	13877	13	7F
0005435282178	13877	14	8B
0005435282171	13877	15	8F
0005434173467	13877	16	9D
0005435282156	13877	17	10B
0005435282177	13877	18	10A
0005433845758	13877	19	10D
0005435282159	13877	20	10F
0005435282167	13877	21	11D
0005433845671	13877	22	13A
0005435282166	13877	23	12F
0005433845672	13877	24	13E
0005435282179	13877	25	14A
0005435282164	13877	26	14B
0005435282176	13877	27	15C
0005432003658	13877	28	16A
0005435282169	13877	29	16D
0005435282161	13877	30	17A
0005435282165	13877	31	17D
0005432003660	13877	32	17E
0005434173466	13877	33	18B
0005435282154	13877	34	18E
0005435282160	13877	35	19A
0005435282163	13877	36	19C
0005433845814	13877	37	19D
0005435282155	13877	38	20A
0005435282175	13877	39	20E
0005435282173	13877	40	21A
0005435282157	13877	41	21D
0005435332147	7811	1	1C
0005434620316	7811	2	2A
0005434620318	7811	3	2C
0005434620319	7811	4	3A
0005434620307	7811	5	3B
0005434620326	7811	6	3D
0005434620323	7811	7	4A
0005432112484	7811	8	4B
0005434620317	7811	9	5A
0005434620312	7811	10	5B
0005435332148	7811	11	5C
0005434620320	7811	12	6C
0005434620306	7811	13	7A
0005434620315	7811	14	7B
0005434620325	7811	15	7D
0005434620308	7811	16	18A
0005434620314	7811	17	18C
0005434620322	7811	18	18D
0005434620311	7811	19	19B
0005434620309	7811	20	19C
0005434620310	7811	21	20C
0005434620313	7811	22	20D
0005434620321	7811	23	21A
0005432112485	7811	24	21C
0005434620324	7811	25	22A
0005435332193	32983	1	1C
0005435332198	32983	2	3C
0005435332190	32983	3	4C
0005435332191	32983	4	19A
0005435332196	32983	5	19B
0005435332192	32983	6	21B
0005435332195	32983	7	21C
0005435332189	32983	8	22C
0005435332194	32983	9	23A
0005435332197	32983	10	23B
0005435784893	4313	1	1D
0005432190575	4313	2	2C
0005435784888	4313	3	2D
0005432190578	4313	4	2F
0005435787324	4313	5	3C
0005435784901	4313	6	3D
0005434993891	4313	7	3F
0005432190576	4313	8	4A
0005435784889	4313	9	4C
0005435787325	4313	10	4D
0005435784896	4313	11	5A
0005435784902	4313	12	5C
0005434993890	4313	13	5D
0005435784894	4313	14	6A
0005435784871	4313	15	6C
0005435784895	4313	16	6D
0005435784872	4313	17	7F
0005435784869	4313	18	8A
0005434993892	4313	19	8C
0005435784881	4313	20	8E
0005435784899	4313	21	9D
0005435784885	4313	22	10A
0005435784884	4313	23	10C
0005434993887	4313	24	11C
0005435784879	4313	25	11E
0005435784890	4313	26	11F
0005435784891	4313	27	12A
0005432190577	4313	28	12C
0005435784870	4313	29	12F
0005435784898	4313	30	13A
0005435784883	4313	31	13D
0005434993893	4313	32	13E
0005435784892	4313	33	14A
0005435784880	4313	34	14C
0005435784903	4313	35	14D
0005434993888	4313	36	15A
0005435784875	4313	37	15F
0005435784887	4313	38	16A
0005435784878	4313	39	16C
0005435784882	4313	40	16D
0005435784876	4313	41	16E
0005435784877	4313	42	16F
0005435784904	4313	43	17D
0005435784873	4313	44	18C
0005435784900	4313	45	19A
0005435784874	4313	46	19C
0005435784886	4313	47	19E
0005435784897	4313	48	20C
0005434993889	4313	49	20D
0005434993894	4313	50	20E
0005435937328	27282	1	1D
0005435937327	27282	2	2C
0005432195663	27282	3	2D
0005435918590	27282	4	3F
0005435918589	27282	5	5D
0005432195662	27282	6	6C
0005435918592	27282	7	6D
0005435918588	27282	8	16F
0005435918591	27282	9	17C
0005432459121	4703	1	1A
0005432566796	4703	2	1C
0005432459140	4703	3	1F
0005432566785	4703	4	1H
0005432571270	4703	5	2C
0005432566818	4703	6	2G
0005432566779	4703	7	3A
0005434081591	4703	8	2H
0005432566813	4703	9	3B
0005432459165	4703	10	3G
0005432459158	4703	11	3H
0005432566797	4703	12	4B
0005432566803	4703	13	4A
0005432459153	4703	14	4F
0005433726075	4703	15	4G
0005432459144	4703	16	5A
0005432459146	4703	17	4H
0005432459135	4703	18	5B
0005432566784	4703	19	5C
0005432566804	4703	20	5G
0005432566830	4703	21	5H
0005434081588	4703	22	9B
0005434081583	4703	23	9A
0005432566807	4703	24	9G
0005432459157	4703	25	11A
0005434081584	4703	26	11B
0005432566829	4703	27	11E
0005432566808	4703	28	11D
0005432459141	4703	29	11G
0005434081587	4703	30	11F
0005432566792	4703	31	11H
0005432459168	4703	32	12B
0005432566822	4703	33	12A
0005434559082	4703	34	12D
0005432459148	4703	35	12E
0005432566832	4703	36	12H
0005432459133	4703	37	12G
0005432459152	4703	38	13D
0005432459129	4703	39	13B
0005432459138	4703	40	13F
0005432566805	4703	41	13E
0005432186819	4703	42	14A
0005432459150	4703	43	13H
0005432566833	4703	44	14B
0005432566800	4703	45	14E
0005432170295	4703	46	14F
0005432566812	4703	47	14H
0005434081596	4703	48	15D
0005432566776	4703	49	15A
0005432571269	4703	50	15E
0005432186820	4703	51	15G
0005432566831	4703	52	16A
0005432566821	4703	53	15H
0005434081581	4703	54	16B
0005434081589	4703	55	16E
0005434081577	4703	56	16G
0005433452710	4703	57	16F
0005432459127	4703	58	17B
0005432566817	4703	59	17A
0005432459156	4703	60	17G
0005432566825	4703	61	17F
0005434081580	4703	62	17H
0005432459132	4703	63	18A
0005433451591	4703	64	18D
0005432459160	4703	65	18B
0005432566815	4703	66	18F
0005432566835	4703	67	18G
0005432566794	4703	68	19D
0005432566816	4703	69	19A
0005432566809	4703	70	19F
0005432459162	4703	71	19H
0005432186821	4703	72	19G
0005432566836	4703	73	20B
0005432571271	4703	74	20G
0005432170298	4703	75	20H
0005434081578	4703	76	21B
0005432566786	4703	77	21A
0005432566795	4703	78	21E
0005432459124	4703	79	21G
0005432566798	4703	80	21F
0005433452711	4703	81	21H
0005432566824	4703	82	22B
0005432566827	4703	83	22D
0005432566788	4703	84	22E
0005432566826	4703	85	23B
0005432459125	4703	86	23E
0005432459164	4703	87	23D
0005432459128	4703	88	23F
0005432566793	4703	89	23G
0005432459154	4703	90	23H
0005432459161	4703	91	24B
0005432459134	4703	92	24E
0005432459126	4703	93	25D
0005432566834	4703	94	25F
0005432566790	4703	95	27B
0005432566789	4703	96	27A
0005434081582	4703	97	27E
0005434081593	4703	98	27D
0005432459118	4703	99	27F
0005432566828	4703	100	27H
0005432459136	4703	101	27G
0005432186822	4703	102	28A
0005432459155	4703	103	28E
0005432459145	4703	104	28D
0005434081595	4703	105	28H
0005432459151	4703	106	28G
0005432170292	4703	107	29B
0005432566820	4703	108	29A
0005432566810	4703	109	29D
0005432459142	4703	110	29E
0005432459147	4703	111	29F
0005432566837	4703	112	29H
0005432566811	4703	113	30B
0005432459169	4703	114	30A
0005432459166	4703	115	30E
0005432566791	4703	116	30G
0005432566780	4703	117	31A
0005432170296	4703	118	30H
0005432566777	4703	119	31D
0005432566799	4703	120	31H
0005433451592	4703	121	31G
0005432571268	4703	122	32A
0005433726073	4703	123	32F
0005432459131	4703	124	32G
0005432459137	4703	125	33A
0005434081590	4703	126	32H
0005432566781	4703	127	33D
0005434081585	4703	128	33E
0005432459130	4703	129	33G
0005432459123	4703	130	33F
0005432566802	4703	131	33H
0005432459120	4703	132	34B
0005432566823	4703	133	34A
0005432459117	4703	134	34D
0005432459116	4703	135	34E
0005432170294	4703	136	34G
0005434081592	4703	137	34F
0005432459149	4703	138	34H
0005434081579	4703	139	35B
0005434081597	4703	140	35E
0005432566806	4703	141	35D
0005433726074	4703	142	35H
0005432459167	4703	143	35G
0005432170297	4703	144	35F
0005432459170	4703	145	36B
0005432566782	4703	146	36A
0005432566783	4703	147	36E
0005432459159	4703	148	36G
0005432459143	4703	149	37A
0005432566787	4703	150	37E
0005432459122	4703	151	37D
0005432459139	4703	152	37F
0005432566778	4703	153	37G
0005434081594	4703	154	38A
0005432170293	4703	155	38D
0005432566819	4703	156	38E
0005432566814	4703	157	38G
0005434081586	4703	158	38F
0005432459119	4703	159	38H
0005432459163	4703	160	39F
0005432566801	4703	161	39E
0005432213556	30521	1	5C
0005432161119	30521	2	9A
0005432213555	30521	3	13B
0005432161121	30521	4	14G
0005432213554	30521	5	16A
0005432161120	30521	6	20B
0005432566705	30521	7	20E
0005432161123	30521	8	23B
0005432566537	30521	9	28F
0005432161122	30521	10	34H
0005432566562	30521	11	37G
0005435722022	13631	1	1B
0005435720808	13631	2	2A
0005435720810	13631	3	3B
0005435720809	13631	4	4A
0005435722023	13631	5	5A
0005432295845	22796	1	5A
0005432295844	22796	2	6C
0005433341839	11117	1	1C
0005433341876	11117	2	1D
0005433341846	11117	3	2C
0005433341868	11117	4	2A
0005433341818	11117	5	2D
0005433341838	11117	6	2F
0005433341822	11117	7	3C
0005433341792	11117	8	3A
0005433341821	11117	9	3D
0005433341858	11117	10	3F
0005433341810	11117	11	4A
0005435097071	11117	12	4C
0005433341854	11117	13	4B
0005433341871	11117	14	4E
0005433341845	11117	15	4F
0005435097073	11117	16	5B
0005433341865	11117	17	5A
0005433341859	11117	18	5D
0005435097076	11117	19	5F
0005433341867	11117	20	5E
0005435097072	11117	21	6B
0005433341799	11117	22	6A
0005435097070	11117	23	6D
0005433341805	11117	24	6F
0005433341793	11117	25	7B
0005433341878	11117	26	7C
0005433341848	11117	27	7D
0005433341790	11117	28	7E
0005433341788	11117	29	8A
0005433341820	11117	30	7F
0005433341835	11117	31	8B
0005433341812	11117	32	8D
0005433341807	11117	33	8C
0005435097077	11117	34	8E
0005433341841	11117	35	8F
0005433341877	11117	36	9A
0005433341842	11117	37	9B
0005433341817	11117	38	9C
0005433341851	11117	39	9E
0005433341870	11117	40	9D
0005433341833	11117	41	9F
0005433341806	11117	42	10B
0005433341827	11117	43	10C
0005435097075	11117	44	10D
0005433341884	11117	45	11A
0005433341855	11117	46	10E
0005433341843	11117	47	11D
0005433341857	11117	48	11C
0005433341828	11117	49	11F
0005433341885	11117	50	11E
0005433341824	11117	51	12C
0005433341882	11117	52	12B
0005433341830	11117	53	12D
0005433341811	11117	54	12E
0005433341863	11117	55	12F
0005433341880	11117	56	13B
0005433341798	11117	57	13A
0005433341832	11117	58	13D
0005433341862	11117	59	13E
0005433341879	11117	60	13F
0005433341795	11117	61	14A
0005433341844	11117	62	14B
0005433341881	11117	63	14D
0005433341860	11117	64	14C
0005435097069	11117	65	14E
0005433341875	11117	66	15B
0005433341819	11117	67	15A
0005433341802	11117	68	15C
0005433341814	11117	69	15D
0005433341866	11117	70	15E
0005433341801	11117	71	16B
0005433341815	11117	72	16E
0005433341864	11117	73	17A
0005433341787	11117	74	16F
0005433341850	11117	75	17D
0005433341847	11117	76	17E
0005433341826	11117	77	18A
0005433341836	11117	78	17F
0005433341840	11117	79	18B
0005433341834	11117	80	18C
0005433341837	11117	81	18E
0005433341829	11117	82	18D
0005433341872	11117	83	18F
0005433341804	11117	84	19B
0005435097074	11117	85	19D
0005433341887	11117	86	19C
0005433341813	11117	87	19E
0005433341825	11117	88	19F
0005433341809	11117	89	20B
0005433341853	11117	90	20A
0005433341856	11117	91	20C
0005433341791	11117	92	20E
0005433341849	11117	93	20D
0005433341886	11117	94	20F
0005433341789	11117	95	21A
0005433341794	11117	96	21C
0005433341816	11117	97	21B
0005433341869	11117	98	21D
0005433341874	11117	99	21E
0005435097078	11117	100	22A
0005433341803	11117	101	21F
0005433341883	11117	102	22B
0005433341823	11117	103	22C
0005433341852	11117	104	22D
0005433341861	11117	105	22F
0005433341797	11117	106	23A
0005433341873	11117	107	23B
0005433341831	11117	108	23D
0005433341796	11117	109	23C
0005433341800	11117	110	23F
0005433341808	11117	111	23E
0005432293175	17125	1	3A
0005432293174	17125	2	5E
0005435545638	17125	3	6A
0005435380239	17125	4	6F
0005433341476	17125	5	8E
0005435545636	17125	6	10D
0005435380237	17125	7	15E
0005435380235	17125	8	16E
0005435380236	17125	9	17C
0005435545640	17125	10	20E
0005435545637	17125	11	20F
0005433341580	17125	12	22E
0005435380238	17125	13	23A
0005435545639	17125	14	23E
0005433481063	9079	1	2F
0005433506936	9079	2	3F
0005433506935	9079	3	4D
0005433506938	9079	4	5C
0005433506941	9079	5	5E
0005433506937	9079	6	6A
0005433506933	9079	7	6F
0005433506930	9079	8	10E
0005433481065	9079	9	10F
0005433506942	9079	10	12C
0005433506931	9079	11	14C
0005433481062	9079	12	15D
0005433481066	9079	13	15F
0005433506934	9079	14	16D
0005433506940	9079	15	17C
0005433481061	9079	16	17D
0005433506939	9079	17	17E
0005433506943	9079	18	17F
0005433481064	9079	19	19A
0005433481060	9079	20	19F
0005433506932	9079	21	20A
0005432919600	20459	1	2A
0005432919606	20459	2	3F
0005432919589	20459	3	4A
0005432919605	20459	4	4D
0005432919603	20459	5	5C
0005432919596	20459	6	7A
0005432919594	20459	7	7D
0005432919604	20459	8	7E
0005432919597	20459	9	9D
0005432919609	20459	10	10C
0005432919602	20459	11	10D
0005432919607	20459	12	12A
0005432919592	20459	13	12F
0005432919590	20459	14	13A
0005432919598	20459	15	13C
0005432919591	20459	16	14C
0005432919599	20459	17	16E
0005432919601	20459	18	16F
0005432919593	20459	19	17C
0005432919595	20459	20	17D
0005433506884	20459	21	17E
0005433506867	20459	22	18C
0005432919608	20459	23	18F
0005433506883	20459	24	19E
0005432919588	20459	25	20F
0005432394047	10224	1	1A
0005432396186	10224	2	1B
0005432394045	10224	3	2B
0005432394044	10224	4	3B
0005432396183	10224	5	4A
0005432396184	10224	6	4B
0005432394046	10224	7	5B
0005432396185	10224	8	6B
0005435179385	18347	1	1A
0005435179386	18347	2	2A
0005434928262	10975	1	1C
0005434411719	10975	2	2C
0005434411722	10975	3	9D
0005434411723	10975	4	12D
0005434411721	10975	5	13A
0005434928261	10975	6	16C
0005434411720	10975	7	20F
0005435625937	14748	1	1A
0005435125823	14748	2	1C
0005435556658	14748	3	1F
0005435125849	14748	4	2A
0005435125821	14748	5	2C
0005435125850	14748	6	2D
0005435125817	14748	7	2F
0005435125818	14748	8	3A
0005435625935	14748	9	3C
0005435125815	14748	10	3D
0005435625933	14748	11	3F
0005435625934	14748	12	4A
0005435125828	14748	13	4C
0005435125842	14748	14	4E
0005435125832	14748	15	5A
0005435554122	14748	16	5C
0005435625940	14748	17	5D
0005435625945	14748	18	5F
0005435625946	14748	19	6A
0005435125851	14748	20	6E
0005435125825	14748	21	6F
0005435625930	14748	22	7A
0005435625944	14748	23	7C
0005435625928	14748	24	7D
0005435125841	14748	25	7E
0005435125838	14748	26	8A
0005435125837	14748	27	8C
0005435625948	14748	28	8D
0005435125840	14748	29	9C
0005435125834	14748	30	9A
0005435125831	14748	31	9E
0005435125854	14748	32	10A
0005435625932	14748	33	10D
0005435125826	14748	34	10F
0005435125827	14748	35	11A
0005435625929	14748	36	11C
0005435125830	14748	37	11D
0005435125846	14748	38	11E
0005435625938	14748	39	11F
0005435125836	14748	40	12A
0005435125855	14748	41	12C
0005435625947	14748	42	12D
0005435554121	14748	43	12E
0005435125824	14748	44	13D
0005435125835	14748	45	13E
0005435625939	14748	46	13F
0005435125845	14748	47	14C
0005435125843	14748	48	14D
0005435125814	14748	49	14E
0005435554120	14748	50	15A
0005435554119	14748	51	15C
0005435625931	14748	52	15D
0005435125822	14748	53	15E
0005435125853	14748	54	15F
0005435125829	14748	55	16A
0005435125820	14748	56	16D
0005435125852	14748	57	16E
0005435625936	14748	58	16F
0005435625941	14748	59	17A
0005435554118	14748	60	17D
0005435625943	14748	61	17E
0005435125833	14748	62	17F
0005435625942	14748	63	18C
0005435125847	14748	64	18D
0005435125839	14748	65	18E
0005435125819	14748	66	18F
0005435125848	14748	67	19D
0005435125816	14748	68	19E
0005435125844	14748	69	20F
0005432398148	7092	1	3A
0005435715244	7092	2	3C
0005435715247	7092	3	4A
0005435715240	7092	4	4C
0005435715239	7092	5	4E
0005435715232	7092	6	5E
0005432400076	7092	7	6C
0005435715235	7092	8	7A
0005435715242	7092	9	8A
0005432398147	7092	10	8C
0005432400074	7092	11	9C
0005435715246	7092	12	9D
0005435715237	7092	13	10D
0005435715241	7092	14	12D
0005435715233	7092	15	13D
0005435715236	7092	16	13E
0005435715238	7092	17	15C
0005435715231	7092	18	15F
0005435715229	7092	19	16D
0005435715234	7092	20	16F
0005432400073	7092	21	17C
0005432398146	7092	22	18A
0005435715230	7092	23	18C
0005435715245	7092	24	18D
0005432400075	7092	25	18E
0005435715243	7092	26	19F
0005435715248	7092	27	20D
0005435715162	27056	1	5F
0005435216558	27056	2	6A
0005435216559	27056	3	6D
0005435443186	27056	4	6F
0005435218101	27056	5	7C
0005435715160	27056	6	7F
0005435443182	27056	7	8A
0005435443188	27056	8	8C
0005435216556	27056	9	8E
0005435218104	27056	10	8F
0005435217679	27056	11	9A
0005435217684	27056	12	9C
0005435218102	27056	13	9D
0005435443191	27056	14	9E
0005435443185	27056	15	9F
0005435443184	27056	16	10A
0005435715161	27056	17	11A
0005435178474	27056	18	11C
0005435217682	27056	19	12D
0005435178475	27056	20	12F
0005435218100	27056	21	13A
0005435443187	27056	22	13C
0005435715171	27056	23	14A
0005435715163	27056	24	14C
0005435715172	27056	25	14F
0005435443189	27056	26	16A
0005435443190	27056	27	16C
0005435216557	27056	28	16D
0005435443183	27056	29	17E
0005435218103	27056	30	18A
0005435217680	27056	31	18D
0005435217683	27056	32	18F
0005435216560	27056	33	19A
0005435216555	27056	34	20C
0005435217681	27056	35	20F
0005434084866	2718	1	1A
0005434084868	2718	2	1B
0005434084869	2718	3	2B
0005434084867	2718	4	3B
0005433060379	28512	1	2B
0005433060377	28512	2	3A
0005433060378	28512	3	3B
0005433788156	11163	1	1D
0005433788154	11163	2	2B
0005433788160	11163	3	2D
0005433788159	11163	4	4B
0005433788158	11163	5	4D
0005433788157	11163	6	5A
0005433788153	11163	7	18C
0005433788152	11163	8	18D
0005433788151	11163	9	20B
0005433788149	11163	10	20D
0005433788155	11163	11	21B
0005433788150	11163	12	23A
0005435548422	20677	1	1C
0005435548427	20677	2	1D
0005435548430	20677	3	2A
0005435548432	20677	4	2B
0005435548426	20677	5	2C
0005435548435	20677	6	3B
0005435548420	20677	7	3C
0005435548436	20677	8	4A
0005435548421	20677	9	5C
0005435548439	20677	10	5D
0005435548437	20677	11	6A
0005435548438	20677	12	6B
0005435548428	20677	13	6C
0005435548419	20677	14	7A
0005435548425	20677	15	7D
0005435548424	20677	16	18B
0005435548417	20677	17	18D
0005435548433	20677	18	19A
0005435548423	20677	19	19D
0005435548429	20677	20	20A
0005435548431	20677	21	20D
0005435548434	20677	22	21C
0005435548418	20677	23	23A
0005435540700	22269	1	1C
0005435528950	22269	2	1D
0005435540697	22269	3	2A
0005435528961	22269	4	2D
0005435528952	22269	5	2F
0005435528957	22269	6	3A
0005435540710	22269	7	3C
0005435540693	22269	8	3D
0005435528947	22269	9	3F
0005435528954	22269	10	4A
0005435540694	22269	11	4C
0005435540702	22269	12	4F
0005435528955	22269	13	5C
0005435528948	22269	14	5E
0005435528958	22269	15	5F
0005435540692	22269	16	6A
0005435540707	22269	17	6E
0005435528962	22269	18	7A
0005432294454	22269	19	7D
0005435540691	22269	20	9A
0005435528965	22269	21	9C
0005435540708	22269	22	9F
0005435540705	22269	23	10E
0005435528959	22269	24	10F
0005432294453	22269	25	11C
0005435528953	22269	26	11D
0005435540709	22269	27	12C
0005435540703	22269	28	12F
0005435528964	22269	29	13A
0005435540696	22269	30	14A
0005435528960	22269	31	14E
0005435540701	22269	32	16C
0005435540699	22269	33	16D
0005435528966	22269	34	17C
0005435528951	22269	35	17D
0005435528963	22269	36	17E
0005435540690	22269	37	18A
0005435540698	22269	38	18C
0005435540706	22269	39	18E
0005435528956	22269	40	19F
0005435528949	22269	41	20C
0005435540695	22269	42	20D
0005435540704	22269	43	20E
0005434906610	2287	1	1A
0005434906615	2287	2	1C
0005434906631	2287	3	1D
0005434906593	2287	4	1F
0005434906630	2287	5	2C
0005434906575	2287	6	2D
0005434906621	2287	7	3C
0005434906600	2287	8	4A
0005434906619	2287	9	4C
0005434906622	2287	10	4D
0005434906618	2287	11	5A
0005434906632	2287	12	5C
0005434906576	2287	13	5D
0005434906573	2287	14	5E
0005434906616	2287	15	5F
0005434906578	2287	16	6A
0005434906601	2287	17	6E
0005434906572	2287	18	7A
0005434906624	2287	19	7C
0005434906582	2287	20	7D
0005434906606	2287	21	7E
0005434906611	2287	22	8A
0005434906583	2287	23	8E
0005434906604	2287	24	8F
0005434906633	2287	25	9D
0005434906627	2287	26	9F
0005434906602	2287	27	10A
0005434906599	2287	28	10E
0005434906587	2287	29	10F
0005434906588	2287	30	11C
0005434906592	2287	31	11D
0005434906589	2287	32	12A
0005434906623	2287	33	12C
0005434906579	2287	34	12D
0005434906629	2287	35	12E
0005434906605	2287	36	12F
0005434906617	2287	37	13A
0005434906625	2287	38	13C
0005434906580	2287	39	13E
0005434906594	2287	40	13F
0005434906609	2287	41	14A
0005434906584	2287	42	14E
0005434906581	2287	43	14F
0005434906591	2287	44	15A
0005434906626	2287	45	15C
0005434906608	2287	46	15D
0005434906597	2287	47	15F
0005434906598	2287	48	16A
0005433250982	2287	49	16C
0005434906628	2287	50	16D
0005434906577	2287	51	16E
0005434906595	2287	52	16F
0005434906620	2287	53	17C
0005434906596	2287	54	17D
0005434906590	2287	55	17E
0005434906603	2287	56	18C
0005434906612	2287	57	18D
0005434906585	2287	58	18E
0005434906574	2287	59	19A
0005434906613	2287	60	19C
0005434906614	2287	61	19F
0005434906607	2287	62	20A
0005434906586	2287	63	20F
0005433251084	25612	1	1A
0005433400945	25612	2	1D
0005433251059	25612	3	1F
0005433251069	25612	4	3D
0005433251061	25612	5	3F
0005433251054	25612	6	5C
0005433251064	25612	7	5D
0005433251081	25612	8	5E
0005433251071	25612	9	6F
0005433251058	25612	10	7D
0005433400944	25612	11	7F
0005433251072	25612	12	8D
0005433251083	25612	13	9A
0005433251055	25612	14	9F
0005433251070	25612	15	10A
0005433251068	25612	16	10C
0005433251066	25612	17	10F
0005433251073	25612	18	11D
0005433251074	25612	19	11E
0005433251080	25612	20	12C
0005433251076	25612	21	12D
0005433251060	25612	22	13A
0005433251067	25612	23	13E
0005433251079	25612	24	14D
0005433251057	25612	25	14F
0005433251065	25612	26	15D
0005433251056	25612	27	15E
0005433251082	25612	28	16A
0005433251075	25612	29	16C
0005433251078	25612	30	17C
0005433251077	25612	31	18A
0005433251063	25612	32	18C
0005433251062	25612	33	18D
0005432620852	2517	1	1A
0005432620853	2517	2	2C
0005432620855	2517	3	2D
0005432620851	2517	4	4C
0005432620856	2517	5	5A
0005432620847	2517	6	6C
0005432620854	2517	7	7C
0005432620848	2517	8	7D
0005432620850	2517	9	20A
0005432620849	2517	10	20B
0005432620857	2517	11	20C
0005432620845	2517	12	21D
0005432620844	2517	13	22C
0005432620846	2517	14	23A
0005432862197	28075	1	1A
0005432862201	28075	2	1D
0005432862196	28075	3	3A
0005432862195	28075	4	4D
0005432862200	28075	5	20A
0005432862198	28075	6	20C
0005432862199	28075	7	22A
0005433451591	31026	1	2A
0005433452711	31026	2	4B
0005433451592	31026	3	5A
0005433452710	31026	4	6B
0005433134060	11990	1	18A
0005434142554	29816	1	1A
0005433131647	29816	2	3A
0005434184638	29816	3	3B
0005434184637	29816	4	4A
0005433131645	29816	5	4B
0005434184639	29816	6	5D
0005433134078	29816	7	6B
0005434183553	29816	8	6C
0005434183554	29816	9	18A
0005433134077	29816	10	18B
0005434183552	29816	11	18D
0005433134076	29816	12	19A
0005433131648	29816	13	21A
0005434142555	29816	14	22A
0005433131646	29816	15	23A
0005435696930	16456	1	1A
0005435696950	16456	2	1B
0005435696943	16456	3	1C
0005435696949	16456	4	1D
0005435696945	16456	5	2B
0005435696934	16456	6	3A
0005435696953	16456	7	3D
0005435696955	16456	8	4B
0005435696944	16456	9	4C
0005435696954	16456	10	5B
0005435696948	16456	11	5C
0005435696939	16456	12	6B
0005435696956	16456	13	6C
0005435696937	16456	14	7B
0005435696952	16456	15	7C
0005435696947	16456	16	7D
0005435696938	16456	17	18B
0005435696935	16456	18	18D
0005435696957	16456	19	19A
0005435696929	16456	20	19B
0005435696951	16456	21	19C
0005435696931	16456	22	19D
0005435696942	16456	23	20A
0005435696936	16456	24	20C
0005435696940	16456	25	21B
0005435696932	16456	26	22A
0005435696946	16456	27	22B
0005435696933	16456	28	22C
0005435696941	16456	29	23B
0005435935006	24685	1	3B
0005435696886	24685	2	18C
0005435696887	24685	3	20C
0005435935005	24685	4	21D
0005435935007	24685	5	22C
0005435935004	24685	6	23B
0005433724741	18770	1	1B
0005433724742	18770	2	2B
0005433724740	18770	3	5B
0005433724739	18770	4	6B
0005432968811	21628	1	3A
0005432968812	21628	2	4B
0005434137096	7308	1	1A
0005434137082	7308	2	1C
0005434137038	7308	3	1D
0005434137055	7308	4	1F
0005434137083	7308	5	2A
0005434137045	7308	6	2C
0005434137034	7308	7	2D
0005434137070	7308	8	2F
0005434137023	7308	9	3C
0005434137071	7308	10	3D
0005434087449	7308	11	3F
0005434137099	7308	12	4A
0005434137100	7308	13	4C
0005434137048	7308	14	4D
0005434137094	7308	15	4F
0005434137042	7308	16	5A
0005434137063	7308	17	5C
0005434137078	7308	18	5D
0005434137026	7308	19	5E
0005434137037	7308	20	5F
0005434137031	7308	21	6A
0005434137097	7308	22	6C
0005434137061	7308	23	6D
0005434137059	7308	24	6E
0005434137049	7308	25	6F
0005434137076	7308	26	7C
0005434137033	7308	27	7D
0005434137072	7308	28	7F
0005434087450	7308	29	7E
0005434137015	7308	30	8A
0005434137058	7308	31	8C
0005434137039	7308	32	8D
0005434137067	7308	33	8E
0005434137064	7308	34	8F
0005434137021	7308	35	9A
0005434137054	7308	36	9C
0005434137081	7308	37	9D
0005434137066	7308	38	9E
0005434137088	7308	39	9F
0005434137069	7308	40	10A
0005434137051	7308	41	10C
0005434137046	7308	42	10D
0005434137028	7308	43	10E
0005434137019	7308	44	10F
0005434137035	7308	45	11A
0005434137014	7308	46	11C
0005434137068	7308	47	11D
0005434137092	7308	48	11E
0005434087447	7308	49	11F
0005434137016	7308	50	12A
0005434137077	7308	51	12C
0005434137024	7308	52	12D
0005434137053	7308	53	12E
0005434137065	7308	54	12F
0005434137040	7308	55	13A
0005434137029	7308	56	13C
0005434137050	7308	57	13D
0005434137060	7308	58	13E
0005434137017	7308	59	13F
0005434137079	7308	60	14A
0005434137062	7308	61	14C
0005434137084	7308	62	14D
0005434137044	7308	63	14E
0005434137036	7308	64	14F
0005434137056	7308	65	15A
0005434137032	7308	66	15C
0005434137018	7308	67	15D
0005434087448	7308	68	15E
0005434137074	7308	69	15F
0005434137089	7308	70	16A
0005434137030	7308	71	16C
0005434137075	7308	72	16D
0005434137043	7308	73	16E
0005434137090	7308	74	16F
0005434137080	7308	75	17A
0005434137087	7308	76	17C
0005434137095	7308	77	17D
0005434137098	7308	78	17F
0005434137086	7308	79	18A
0005434137022	7308	80	18C
0005434137020	7308	81	18D
0005434137025	7308	82	18E
0005434137057	7308	83	18F
0005434137052	7308	84	19A
0005434137091	7308	85	19C
0005434137085	7308	86	19D
0005434137047	7308	87	19E
0005434137027	7308	88	19F
0005434137073	7308	89	20A
0005434137041	7308	90	20C
0005434137093	7308	91	20E
0005434087451	7308	92	20F
0005434087436	28560	1	9E
0005435808095	1892	1	5B
0005434610182	1892	2	6B
0005435808096	1892	3	6D
0005435808101	1892	4	7A
0005435808099	1892	5	7C
0005435808098	1892	6	19A
0005434610181	1892	7	20A
0005435808100	1892	8	21B
0005435808093	1892	9	21C
0005435808094	1892	10	21D
0005435808102	1892	11	22B
0005434610180	1892	12	22C
0005434610183	1892	13	23A
0005435808097	1892	14	23B
0005434503486	16719	1	1D
0005434503612	22930	1	1A
0005434503608	22930	2	1B
0005434503603	22930	3	1C
0005434503578	22930	4	2A
0005434503616	22930	5	2B
0005434503592	22930	6	2C
0005434503588	22930	7	2D
0005434503587	22930	8	3A
0005434503591	22930	9	3D
0005434503606	22930	10	4B
0005434503618	22930	11	4A
0005434503610	22930	12	4C
0005434503598	22930	13	4D
0005434503601	22930	14	5A
0005434503604	22930	15	5B
0005434503596	22930	16	5C
0005434503613	22930	17	5D
0005434503579	22930	18	6A
0005434503597	22930	19	6B
0005434503611	22930	20	6C
0005434503605	22930	21	7A
0005434503590	22930	22	7C
0005434503595	22930	23	7D
0005434503583	22930	24	18A
0005434503602	22930	25	18B
0005434503593	22930	26	18C
0005434503581	22930	27	19A
0005434503582	22930	28	19C
0005434503584	22930	29	19D
0005434503585	22930	30	20A
0005434503615	22930	31	20B
0005434503580	22930	32	20C
0005434503609	22930	33	20D
0005434503617	22930	34	21B
0005434503614	22930	35	21C
0005434503594	22930	36	22A
0005434503600	22930	37	22B
0005434503599	22930	38	22C
0005434503607	22930	39	22D
0005434503586	22930	40	23A
0005434503589	22930	41	23B
0005435078129	2175	1	3C
0005435078133	2175	2	3D
0005435078140	2175	3	5A
0005435078141	2175	4	5C
0005435078132	2175	5	5D
0005435078136	2175	6	7A
0005435078137	2175	7	7D
0005435078135	2175	8	18D
0005435078139	2175	9	19A
0005435078134	2175	10	19B
0005435078138	2175	11	20A
0005435078131	2175	12	20B
0005435078130	2175	13	21B
0005435078142	2175	14	22C
0005435078128	2175	15	23A
0005433266594	24365	1	1D
0005433266597	24365	2	2C
0005433266599	24365	3	3D
0005433266603	24365	4	4A
0005433266600	24365	5	4D
0005433266598	24365	6	7B
0005433266596	24365	7	18A
0005433266595	24365	8	18C
0005433266601	24365	9	20C
0005433266602	24365	10	21A
0005434988598	6635	1	1A
0005434988592	6635	2	1D
0005434988594	6635	3	2A
0005435803224	6635	4	3D
0005434988589	6635	5	4C
0005434988595	6635	6	5C
0005434988588	6635	7	7A
0005434988593	6635	8	19D
0005434988597	6635	9	20B
0005434988596	6635	10	20D
0005435803225	6635	11	21C
0005434988591	6635	12	21D
0005434988590	6635	13	23A
0005435464481	23599	1	5D
0005435464480	23599	2	19A
0005432382660	30504	1	1D
0005432382686	30504	2	1F
0005432382652	30504	3	2C
0005432382687	30504	4	2D
0005433449683	30504	5	2F
0005432382668	30504	6	3A
0005432382679	30504	7	3C
0005432382674	30504	8	3D
0005432382658	30504	9	3F
0005433453736	30504	10	4A
0005432382670	30504	11	4D
0005433449685	30504	12	4E
0005432382661	30504	13	4F
0005433449684	30504	14	5A
0005432382653	30504	15	5D
0005432382682	30504	16	5F
0005432382685	30504	17	6A
0005433449681	30504	18	6C
0005432382657	30504	19	6D
0005432382683	30504	20	6E
0005433449693	30504	21	6F
0005432382669	30504	22	7D
0005432382673	30504	23	7F
0005432382650	30504	24	8A
0005432382664	30504	25	8C
0005432382678	30504	26	8F
0005432382667	30504	27	9D
0005432382671	30504	28	9E
0005432382681	30504	29	9F
0005433449679	30504	30	10A
0005432382680	30504	31	10D
0005433449687	30504	32	10E
0005433449682	30504	33	11A
0005433453735	30504	34	11D
0005432382655	30504	35	11E
0005432382663	30504	36	11F
0005433449690	30504	37	12C
0005433449692	30504	38	12D
0005432382676	30504	39	12E
0005432382666	30504	40	12F
0005432382662	30504	41	13A
0005433449694	30504	42	13C
0005432382688	30504	43	13E
0005432382651	30504	44	14A
0005433449678	30504	45	14C
0005433449691	30504	46	14D
0005433449672	30504	47	14F
0005433449677	30504	48	15A
0005432382675	30504	49	15C
0005432382665	30504	50	15D
0005432382677	30504	51	15E
0005433449689	30504	52	16A
0005433449686	30504	53	16C
0005433449676	30504	54	16D
0005432382656	30504	55	16E
0005433449688	30504	56	17A
0005433449675	30504	57	17D
0005433449674	30504	58	17E
0005433449673	30504	59	17F
0005432382659	30504	60	18A
0005433454847	30504	61	18C
0005432382654	30504	62	18D
0005432382684	30504	63	18E
0005432382689	30504	64	19C
0005432382672	30504	65	19E
0005432382690	30504	66	19F
0005433449680	30504	67	20D
0005432382649	30504	68	20E
0005435548439	26472	1	2A
0005435548436	26472	2	2B
0005435548433	26472	3	2C
0005435548438	26472	4	3A
0005435548435	26472	5	4A
0005435548437	26472	6	5D
0005435548434	26472	7	18C
0005435299715	29745	1	1A
0005435302141	29745	2	1B
0005433126789	29745	3	1D
0005435302142	29745	4	2A
0005433129219	29745	5	2D
0005433129220	29745	6	3C
0005435302140	29745	7	3D
0005433126790	29745	8	5A
0005433126788	29745	9	5B
0005435299718	29745	10	6C
0005433126787	29745	11	6D
0005433126786	29745	12	7C
0005435299716	29745	13	18B
0005435299719	29745	14	18C
0005435302139	29745	15	19D
0005435299717	29745	16	22B
0005435302143	29745	17	23A
0005433129218	29745	18	23B
0005434287003	2436	1	1B
0005434287002	2436	2	1C
0005434286998	2436	3	2A
0005434286987	2436	4	2B
0005433109861	2436	5	2C
0005434286999	2436	6	2D
0005434286995	2436	7	3A
0005434286997	2436	8	3B
0005434286992	2436	9	3D
0005434286989	2436	10	4A
0005434287004	2436	11	4B
0005432264441	2436	12	5A
0005434287001	2436	13	5B
0005434286984	2436	14	5C
0005434286991	2436	15	5D
0005434286994	2436	16	6B
0005432264443	2436	17	6C
0005434287005	2436	18	6D
0005434286990	2436	19	7B
0005432264442	2436	20	18B
0005434286996	2436	21	19C
0005434286983	2436	22	20A
0005433109860	2436	23	20C
0005434286986	2436	24	21A
0005434286993	2436	25	22C
0005434286985	2436	26	22D
0005434287000	2436	27	23A
0005434286988	2436	28	23B
0005433109891	26856	1	1C
0005433109892	26856	2	1D
0005433109889	26856	3	3B
0005433109895	26856	4	4A
0005433109897	26856	5	6C
0005433109896	26856	6	6D
0005434286913	26856	7	18B
0005433109894	26856	8	20C
0005434286900	26856	9	21A
0005433109898	26856	10	22B
0005433109893	26856	11	22D
0005433109890	26856	12	23A
0005435856150	25450	1	1B
0005435856149	25450	2	2D
0005435856148	25450	3	4B
0005435856147	25450	4	21C
0005434272169	26659	1	1C
0005434272170	26659	2	4D
0005434272171	26659	3	6A
0005434273055	26659	4	7A
0005434273056	26659	5	23B
0005435314782	19077	1	3C
0005435314784	19077	2	4D
0005435314772	19077	3	5A
0005435314774	19077	4	5D
0005435314781	19077	5	6A
0005435314780	19077	6	6C
0005435314776	19077	7	7C
0005435314778	19077	8	18A
0005435314787	19077	9	18C
0005435314783	19077	10	18D
0005435314773	19077	11	19A
0005435314777	19077	12	19B
0005435314786	19077	13	19C
0005435314785	19077	14	19D
0005435314779	19077	15	21A
0005435314775	19077	16	21D
0005433874297	7785	1	2D
0005433874307	7785	2	3A
0005433874298	7785	3	3B
0005433874303	7785	4	4B
0005433874300	7785	5	4C
0005433874296	7785	6	5D
0005433874301	7785	7	6A
0005433874295	7785	8	6C
0005433874302	7785	9	21B
0005433874305	7785	10	22A
0005433874294	7785	11	22B
0005433874304	7785	12	22C
0005433874299	7785	13	22D
0005433874306	7785	14	23B
0005433867890	4762	1	1B
0005433867923	4762	2	1C
0005433867928	4762	3	1D
0005433867905	4762	4	2B
0005433867922	4762	5	2C
0005433867930	4762	6	2D
0005433867902	4762	7	3A
0005433867915	4762	8	3B
0005433867925	4762	9	3C
0005433867909	4762	10	3D
0005433867910	4762	11	4A
0005433867894	4762	12	4B
0005433867921	4762	13	4C
0005433867895	4762	14	5A
0005433867908	4762	15	5B
0005433867891	4762	16	5C
0005433867911	4762	17	6A
0005433867903	4762	18	6B
0005433867912	4762	19	6C
0005433867906	4762	20	6D
0005433867919	4762	21	7B
0005433867892	4762	22	7A
0005433867916	4762	23	7C
0005433867907	4762	24	7D
0005433867897	4762	25	18A
0005433867914	4762	26	18C
0005433867899	4762	27	18D
0005433867927	4762	28	19A
0005433867898	4762	29	19C
0005433867929	4762	30	19D
0005433867893	4762	31	20B
0005433867904	4762	32	20C
0005433867926	4762	33	20D
0005433867900	4762	34	21B
0005433867917	4762	35	21C
0005433867920	4762	36	21D
0005433867918	4762	37	22A
0005433867924	4762	38	22B
0005433867901	4762	39	22C
0005433867896	4762	40	22D
0005433867913	4762	41	23A
0005435860442	32610	1	1D
0005434461620	3420	1	1A
0005434663228	3420	2	1B
0005434663229	3420	3	3C
0005434460475	3420	4	4A
0005434461618	3420	5	6C
0005434663231	3420	6	7A
0005434663230	3420	7	18A
0005434663225	3420	8	18B
0005434663224	3420	9	18C
0005434663222	3420	10	19A
0005434460476	3420	11	20A
0005434663226	3420	12	20C
0005434663234	3420	13	21A
0005434663233	3420	14	22A
0005434461619	3420	15	22C
0005434663227	3420	16	22D
0005434663232	3420	17	23A
0005434663223	3420	18	23B
0005435911349	12460	1	1C
0005435911351	12460	2	2A
0005435911348	12460	3	7B
0005435911347	12460	4	19C
0005435911353	12460	5	20B
0005435911350	12460	6	22D
0005435911352	12460	7	23B
0005435860442	14532	1	5C
0005433867876	32698	1	1A
0005433867859	32698	2	1B
0005433867862	32698	3	1C
0005433867868	32698	4	1D
0005433867867	32698	5	2A
0005433867866	32698	6	2B
0005433867873	32698	7	2C
0005433867864	32698	8	2D
0005433867888	32698	9	3D
0005433867887	32698	10	4A
0005433867865	32698	11	4B
0005433867881	32698	12	4C
0005433867860	32698	13	4D
0005433867853	32698	14	5A
0005433867879	32698	15	5B
0005433867884	32698	16	5C
0005433867877	32698	17	5D
0005433867856	32698	18	6B
0005433867882	32698	19	6C
0005433867863	32698	20	6D
0005433867872	32698	21	7B
0005433867885	32698	22	7C
0005433867886	32698	23	7D
0005433867874	32698	24	18A
0005433867875	32698	25	18C
0005433867869	32698	26	19A
0005433867854	32698	27	19B
0005433867857	32698	28	19C
0005433867880	32698	29	19D
0005433867852	32698	30	20A
0005433867883	32698	31	20C
0005433867851	32698	32	20B
0005433867858	32698	33	20D
0005433867871	32698	34	21B
0005433867878	32698	35	22A
0005433867870	32698	36	22C
0005433867861	32698	37	22D
0005433867855	32698	38	23A
0005433867889	32698	39	23B
0005432798988	12136	1	2A
0005432799046	12136	2	2B
0005432798989	12136	3	5B
0005432799047	12136	4	19B
0005432799058	14816	1	1A
0005432799041	14816	2	1B
0005432799047	14816	3	2C
0005432799056	14816	4	2D
0005432799060	14816	5	3A
0005432799062	14816	6	3D
0005432799051	14816	7	4A
0005432799059	14816	8	4C
0005432799055	14816	9	5C
0005432799061	14816	10	6A
0005432799063	14816	11	6B
0005432799043	14816	12	6C
0005432799066	14816	13	6D
0005432799057	14816	14	7A
0005432799048	14816	15	7D
0005432799052	14816	16	18A
0005432799054	14816	17	18B
0005432799064	14816	18	18C
0005432799067	14816	19	19A
0005432799068	14816	20	19B
0005432799065	14816	21	19C
0005432799050	14816	22	19D
0005432799044	14816	23	20A
0005432799045	14816	24	20B
0005432799053	14816	25	21A
0005432799042	14816	26	21B
0005432799049	14816	27	21C
0005432799040	14816	28	22C
0005432799046	14816	29	22D
0005434406930	7038	1	1C
0005434299247	7038	2	1D
0005434299260	7038	3	1F
0005434406936	7038	4	2C
0005434299254	7038	5	3A
0005432108215	7038	6	3D
0005434406958	7038	7	3F
0005432153845	7038	8	4A
0005434406895	7038	9	4B
0005434406952	7038	10	4D
0005434406925	7038	11	4E
0005434406946	7038	12	5A
0005434406941	7038	13	4F
0005434406944	7038	14	5B
0005434406934	7038	15	5C
0005434406953	7038	16	5E
0005434406922	7038	17	6C
0005434299259	7038	18	6D
0005434299264	7038	19	6E
0005434406914	7038	20	6F
0005432153847	7038	21	7C
0005434406900	7038	22	7D
0005434406923	7038	23	7F
0005434299243	7038	24	8A
0005434406955	7038	25	8C
0005434406945	7038	26	8D
0005434406954	7038	27	8F
0005434299242	7038	28	8E
0005432153844	7038	29	9A
0005432153848	7038	30	9C
0005434406940	7038	31	9B
0005434406938	7038	32	9D
0005434299245	7038	33	9E
0005432153849	7038	34	10C
0005434406902	7038	35	10B
0005432153843	7038	36	10D
0005434406943	7038	37	11A
0005434406927	7038	38	11B
0005432108217	7038	39	11E
0005434406916	7038	40	11D
0005434406928	7038	41	11F
0005434299256	7038	42	12A
0005434406899	7038	43	12D
0005434406906	7038	44	13A
0005434406896	7038	45	12F
0005434406915	7038	46	13C
0005434406908	7038	47	13B
0005432153846	7038	48	13D
0005434406929	7038	49	13E
0005434299249	7038	50	14A
0005434299241	7038	51	14B
0005434406910	7038	52	14D
0005434406951	7038	53	14C
0005434406957	7038	54	14E
0005434299257	7038	55	14F
0005434299248	7038	56	15A
0005432108216	7038	57	15B
0005434406918	7038	58	15C
0005434299261	7038	59	15F
0005434406949	7038	60	16A
0005434406909	7038	61	16B
0005434406920	7038	62	16C
0005434406926	7038	63	16E
0005434406917	7038	64	16D
0005434406939	7038	65	16F
0005434406919	7038	66	17B
0005434406950	7038	67	17A
0005434406924	7038	68	17C
0005434299252	7038	69	17D
0005434299263	7038	70	18A
0005434406897	7038	71	18B
0005434406932	7038	72	18D
0005434406933	7038	73	18E
0005434406903	7038	74	19A
0005434406912	7038	75	18F
0005434406905	7038	76	19B
0005434406948	7038	77	19D
0005434406898	7038	78	19F
0005434299262	7038	79	20B
0005434406956	7038	80	20A
0005434406947	7038	81	20C
0005434299250	7038	82	20F
0005434299258	7038	83	21A
0005434406937	7038	84	21C
0005434299246	7038	85	21B
0005434406911	7038	86	21D
0005434406921	7038	87	21E
0005434299255	7038	88	21F
0005434406901	7038	89	22A
0005434299244	7038	90	22C
0005434406907	7038	91	22D
0005434406942	7038	92	22E
0005434406935	7038	93	23A
0005434406931	7038	94	22F
0005434406913	7038	95	23B
0005434299251	7038	96	23C
0005434299253	7038	97	23D
0005434406904	7038	98	23F
0005435310901	26925	1	1C
0005435310903	26925	2	3D
0005435310896	26925	3	4B
0005432058325	26925	4	4E
0005435310899	26925	5	6B
0005435293104	26925	6	8B
0005435310898	26925	7	9A
0005435293097	26925	8	8F
0005435310902	26925	9	9F
0005435293101	26925	10	12F
0005435293108	26925	11	14F
0005435310900	26925	12	15C
0005435293099	26925	13	15E
0005435310897	26925	14	16B
0005435293103	26925	15	16E
0005435293100	26925	16	16F
0005435293096	26925	17	18A
0005435310895	26925	18	18B
0005435293107	26925	19	18D
0005432058327	26925	20	18C
0005432058326	26925	21	18E
0005435293106	26925	22	19C
0005435293098	26925	23	20D
0005435293102	26925	24	20E
0005435310905	26925	25	20F
0005435293105	26925	26	22D
0005435310904	26925	27	23E
0005434512040	6482	1	1B
0005432603811	6482	2	1C
0005432603838	6482	3	1D
0005432603813	6482	4	2A
0005432603822	6482	5	2B
0005432603828	6482	6	2C
0005432603839	6482	7	2D
0005434512042	6482	8	3A
0005432603829	6482	9	3B
0005432603825	6482	10	3C
0005432603805	6482	11	3D
0005432603842	6482	12	4A
0005432603807	6482	13	4B
0005434512043	6482	14	4C
0005432603815	6482	15	5A
0005432603827	6482	16	5B
0005432603808	6482	17	5C
0005432603830	6482	18	5D
0005432603821	6482	19	6A
0005432603806	6482	20	6B
0005432603819	6482	21	6C
0005432603812	6482	22	6D
0005432603818	6482	23	7A
0005432603834	6482	24	7B
0005432603832	6482	25	7C
0005432603816	6482	26	7D
0005432603810	6482	27	18B
0005432603823	6482	28	18C
0005432603833	6482	29	18D
0005432603820	6482	30	19A
0005432603826	6482	31	19B
0005432603836	6482	32	19C
0005432603824	6482	33	19D
0005432603841	6482	34	20A
0005434512038	6482	35	20B
0005432603835	6482	36	20C
0005432603814	6482	37	20D
0005434512039	6482	38	21A
0005432603809	6482	39	21B
0005432603837	6482	40	21C
0005434512041	6482	41	21D
0005432603831	6482	42	22A
0005432603843	6482	43	22B
0005432603840	6482	44	22C
0005432603804	6482	45	22D
0005432603817	6482	46	23B
0005433251058	14997	1	1C
0005433251079	14997	2	1F
0005433251082	14997	3	2D
0005433251065	14997	4	3D
0005433251059	14997	5	4A
0005433251074	14997	6	4C
0005433251063	14997	7	5C
0005433251072	14997	8	5D
0005433251066	14997	9	6A
0005433251061	14997	10	6C
0005433251077	14997	11	6D
0005433251054	14997	12	7E
0005433251056	14997	13	9D
0005433251081	14997	14	10A
0005433251084	14997	15	10C
0005433251078	14997	16	10D
0005433251068	14997	17	10F
0005433251070	14997	18	11A
0005433251060	14997	19	11C
0005433251075	14997	20	11D
0005433251073	14997	21	11E
0005433251071	14997	22	12E
0005433251069	14997	23	13D
0005433251083	14997	24	13E
0005433251062	14997	25	14D
0005433251067	14997	26	15D
0005433251057	14997	27	15F
0005433251064	14997	28	16A
0005433251080	14997	29	17E
0005433251055	14997	30	18A
0005433251076	14997	31	19D
0005434906551	25824	1	1C
0005434906520	25824	2	1D
0005434906547	25824	3	1F
0005434906544	25824	4	3A
0005434906550	25824	5	3C
0005434906535	25824	6	3D
0005434906524	25824	7	3F
0005434906552	25824	8	4C
0005434906540	25824	9	4D
0005434906516	25824	10	4E
0005434906569	25824	11	4F
0005434906525	25824	12	5C
0005434906554	25824	13	5D
0005434906549	25824	14	5E
0005434906517	25824	15	6E
0005434906563	25824	16	7C
0005434906570	25824	17	7D
0005434906528	25824	18	7E
0005434906542	25824	19	7F
0005434906553	25824	20	8D
0005434906566	25824	21	8E
0005434906559	25824	22	8F
0005434906521	25824	23	10A
0005434906548	25824	24	10C
0005434906534	25824	25	10E
0005434906567	25824	26	10F
0005434906519	25824	27	11D
0005434906537	25824	28	11E
0005434906532	25824	29	12D
0005434906541	25824	30	12E
0005434906561	25824	31	13A
0005434906557	25824	32	13C
0005434906545	25824	33	13E
0005434906523	25824	34	13F
0005434906533	25824	35	14A
0005434906539	25824	36	14C
0005434906558	25824	37	14E
0005434906571	25824	38	15A
0005434906529	25824	39	15C
0005434906538	25824	40	15D
0005434906536	25824	41	15E
0005434906526	25824	42	15F
0005434906562	25824	43	16E
0005434906531	25824	44	17A
0005434906556	25824	45	17F
0005434906518	25824	46	18A
0005434906546	25824	47	18C
0005434906530	25824	48	18D
0005434906560	25824	49	18E
0005434906568	25824	50	19C
0005434906522	25824	51	19D
0005434906564	25824	52	19F
0005434906565	25824	53	20A
0005434906555	25824	54	20C
0005434906527	25824	55	20E
0005434906543	25824	56	20F
0005433008027	14181	1	1D
0005433008046	14181	2	1F
0005433008012	14181	3	2D
0005433008019	14181	4	2F
0005433008024	14181	5	4C
0005433008021	14181	6	4E
0005433008051	14181	7	5E
0005433008013	14181	8	5F
0005433008030	14181	9	6A
0005433008033	14181	10	6E
0005433008020	14181	11	6F
0005433008028	14181	12	7A
0005433008044	14181	13	7C
0005433008016	14181	14	7D
0005433008040	14181	15	7E
0005433008029	14181	16	7F
0005433008017	14181	17	8E
0005433008039	14181	18	8F
0005433008023	14181	19	9C
0005433008037	14181	20	9E
0005433008010	14181	21	10A
0005433008034	14181	22	10C
0005433008045	14181	23	10E
0005433008031	14181	24	10F
0005433008050	14181	25	11A
0005433008026	14181	26	13A
0005433008052	14181	27	13C
0005433008043	14181	28	13D
0005433008038	14181	29	13F
0005433008015	14181	30	14C
0005433008036	14181	31	14D
0005433008025	14181	32	14F
0005433008054	14181	33	15D
0005433008047	14181	34	15C
0005433008011	14181	35	15E
0005433008041	14181	36	16A
0005433008014	14181	37	16E
0005433008032	14181	38	17C
0005433008049	14181	39	17E
0005433008035	14181	40	17F
0005433008018	14181	41	18C
0005433008009	14181	42	18D
0005433008048	14181	43	18E
0005433008008	14181	44	19A
0005433008022	14181	45	19E
0005433008053	14181	46	19F
0005433008042	14181	47	20D
0005433810502	22828	1	1C
0005433810500	22828	2	3F
0005433810504	22828	3	7E
0005433810501	22828	4	7F
0005433810499	22828	5	9A
0005433810503	22828	6	10D
0005433810505	22828	7	13E
0005433810497	22828	8	13F
0005433810496	22828	9	16F
0005433810498	22828	10	17E
0005434925344	20498	1	1D
0005434925358	20498	2	2A
0005434925363	20498	3	2F
0005434925357	20498	4	4A
0005434925360	20498	5	6D
0005434925364	20498	6	6E
0005434925343	20498	7	8A
0005434925361	20498	8	8D
0005434925348	20498	9	9F
0005434925349	20498	10	11D
0005434925345	20498	11	12C
0005434925356	20498	12	14C
0005434925355	20498	13	14D
0005434925353	20498	14	14E
0005434925354	20498	15	15C
0005434925346	20498	16	16A
0005434925351	20498	17	16E
0005434925352	20498	18	17C
0005434925362	20498	19	18D
0005434925359	20498	20	20C
0005434925347	20498	21	20D
0005434925350	20498	22	20F
0005435487550	15801	1	1A
0005435487559	15801	2	1B
0005435487562	15801	3	1D
0005435487547	15801	4	2A
0005435487549	15801	5	2B
0005435487552	15801	6	3A
0005435487558	15801	7	3B
0005435487544	15801	8	3C
0005435487561	15801	9	3D
0005435487560	15801	10	4A
0005435487551	15801	11	5A
0005435487545	15801	12	5B
0005435487543	15801	13	5C
0005435487557	15801	14	5D
0005435487553	15801	15	6A
0005435487556	15801	16	6D
0005435487546	15801	17	7B
0005435487563	15801	18	20D
0005435487555	15801	19	21A
0005435487548	15801	20	22A
0005435487554	15801	21	23A
0005435999012	19715	1	1A
0005435999008	19715	2	1D
0005435999006	19715	3	2C
0005435999004	19715	4	3A
0005435998999	19715	5	3C
0005435999002	19715	6	4D
0005435999003	19715	7	5A
0005435999007	19715	8	5B
0005435999010	19715	9	6B
0005435999000	19715	10	18A
0005435999001	19715	11	18D
0005435999009	19715	12	20B
0005435999011	19715	13	21B
0005435999005	19715	14	21D
0005435839091	6030	1	1A
0005435839089	6030	2	1D
0005435839096	6030	3	2A
0005435839083	6030	4	2D
0005435839077	6030	5	2C
0005435839097	6030	6	3C
0005435839088	6030	7	4A
0005435839087	6030	8	3F
0005432658565	6030	9	4C
0005432660791	6030	10	4D
0005435839079	6030	11	6B
0005435839073	6030	12	6E
0005435839080	6030	13	7B
0005435839082	6030	14	7E
0005435839092	6030	15	8A
0005435839085	6030	16	8B
0005435839081	6030	17	8E
0005432658566	6030	18	9B
0005435839093	6030	19	9D
0005435839084	6030	20	10A
0005432658564	6030	21	10B
0005435839074	6030	22	11D
0005435839099	6030	23	11C
0005432142212	6030	24	12D
0005435839100	6030	25	13A
0005432659680	6030	26	12F
0005435839076	6030	27	14C
0005435839101	6030	28	14A
0005435839094	6030	29	15C
0005432142211	6030	30	16A
0005435839098	6030	31	17E
0005435839086	6030	32	18B
0005435839078	6030	33	18D
0005435839095	6030	34	19F
0005432660792	6030	35	19E
0005435839075	6030	36	20B
0005432659681	6030	37	20D
0005435839090	6030	38	20C
0005432659679	6030	39	21F
0005435472591	18080	1	1A
0005435472582	18080	2	3D
0005435472581	18080	3	5A
0005435472583	18080	4	6D
0005432537030	18080	5	7E
0005435472594	18080	6	9A
0005435472585	18080	7	10B
0005435472593	18080	8	11E
0005435472595	18080	9	14B
0005435472587	18080	10	15C
0005435472589	18080	11	15D
0005435472588	18080	12	16C
0005435472580	18080	13	16F
0005435472584	18080	14	17D
0005435472590	18080	15	18A
0005435472592	18080	16	19C
0005435472586	18080	17	19B
0005432537031	18080	18	20D
0005435103827	23038	1	5C
0005433284793	23038	2	9D
0005433284794	23038	3	17C
0005435103825	23038	4	19C
0005435103826	23038	5	20E
0005433284770	23038	6	22D
0005433284898	32100	1	1C
0005433284886	32100	2	1D
0005433284897	32100	3	2D
0005433284889	32100	4	3A
0005433284879	32100	5	4D
0005433284905	32100	6	5E
0005433284880	32100	7	6A
0005433284881	32100	8	6D
0005433284903	32100	9	6E
0005433284890	32100	10	6F
0005433284893	32100	11	7B
0005433284885	32100	12	9C
0005433284887	32100	13	10B
0005433284902	32100	14	10C
0005433284884	32100	15	11A
0005433284882	32100	16	11D
0005433284900	32100	17	12A
0005433284888	32100	18	13E
0005433284907	32100	19	14A
0005433284895	32100	20	13F
0005433284896	32100	21	14B
0005433284904	32100	22	14E
0005433284908	32100	23	14F
0005433284892	32100	24	15B
0005433284891	32100	25	17B
0005433284910	32100	26	17A
0005433284894	32100	27	18B
0005433284883	32100	28	19B
0005433284906	32100	29	19F
0005433284899	32100	30	20C
0005433284909	32100	31	20E
0005433284901	32100	32	21B
0005435212724	30603	1	1A
0005433656628	30603	2	1K
0005435212692	30603	3	3C
0005434066349	30603	4	3K
0005435212709	30603	5	4G
0005434066421	30603	6	4K
0005435212729	30603	7	5G
0005433656629	30603	8	5D
0005435212686	30603	9	5K
0005435212676	30603	10	11C
0005435212710	30603	11	11G
0005435212736	30603	12	11H
0005435212704	30603	13	12E
0005435212681	30603	14	12D
0005435212675	30603	15	12H
0005435212697	30603	16	13D
0005432211406	30603	17	13C
0005435212740	30603	18	13E
0005435212732	30603	19	13H
0005435212717	30603	20	14D
0005435212687	30603	21	14C
0005432525942	30603	22	14H
0005435212684	30603	23	15E
0005435212698	30603	24	15D
0005435212743	30603	25	15G
0005435212739	30603	26	15F
0005432525697	30603	27	16D
0005435212716	30603	28	16F
0005435212713	30603	29	16E
0005432211408	30603	30	16H
0005435212718	30603	31	17A
0005434066330	30603	32	17E
0005435212722	30603	33	17H
0005435212737	30603	34	18E
0005435212677	30603	35	18G
0005435212715	30603	36	18F
0005435212693	30603	37	19B
0005435212683	30603	38	20E
0005433656632	30603	39	20K
0005435630932	30603	40	21B
0005435212706	30603	41	21C
0005435725541	30603	42	21E
0005435212711	30603	43	21J
0005433656631	30603	44	21G
0005435212705	30603	45	22D
0005435212731	30603	46	22B
0005435725540	30603	47	22K
0005435212688	30603	48	23B
0005435212703	30603	49	23D
0005435725537	30603	50	23H
0005432525801	30603	51	24D
0005435212725	30603	52	25C
0005435630929	30603	53	25H
0005432525664	30603	54	26A
0005432211410	30603	55	26H
0005435212741	30603	56	27A
0005435212695	30603	57	27C
0005435212733	30603	58	28C
0005435630931	30603	59	28B
0005432525722	30603	60	28A
0005435212707	30603	61	28D
0005435212714	30603	62	28G
0005435212727	30603	63	28K
0005435212689	30603	64	29E
0005432525696	30603	65	30K
0005435212721	30603	66	31A
0005432525740	30603	67	31G
0005432211409	30603	68	31K
0005435212742	30603	69	32C
0005435212734	30603	70	33B
0005432211404	30603	71	32K
0005432159799	30603	72	33D
0005432211411	30603	73	33E
0005434066505	30603	74	34E
0005432159800	30603	75	35A
0005435212679	30603	76	35C
0005432159802	30603	77	35F
0005435630930	30603	78	36G
0005432526138	30603	79	36K
0005435212685	30603	80	37A
0005432159798	30603	81	37E
0005435212702	30603	82	37F
0005434066390	30603	83	37G
0005435212730	30603	84	38A
0005432211405	30603	85	38H
0005434066307	30603	86	39A
0005435212696	30603	87	39E
0005432525849	30603	88	40A
0005435725539	30603	89	39J
0005433656630	30603	90	40J
0005432525754	30603	91	41A
0005432159801	30603	92	41D
0005435212690	30603	93	41F
0005435212699	30603	94	43B
0005435212691	30603	95	43A
0005435212726	30603	96	43C
0005435212678	30603	97	44C
0005435725538	30603	98	44E
0005435212728	30603	99	44D
0005435212708	30603	100	44G
0005435212694	30603	101	44F
0005432211407	30603	102	45B
0005435212719	30603	103	46A
0005435212680	30603	104	46E
0005435212720	30603	105	47G
0005432525665	30603	106	48D
0005435212700	30603	107	48F
0005435212735	30603	108	49C
0005435212723	30603	109	48K
0005435212738	30603	110	49D
0005435212682	30603	111	49F
0005435212712	30603	112	50D
0005432525875	30603	113	50F
0005435212701	30603	114	51E
0005433367451	24861	1	1A
0005433367445	24861	2	1F
0005433367437	24861	3	2A
0005433367450	24861	4	2D
0005433367433	24861	5	3C
0005433367422	24861	6	4A
0005433367439	24861	7	4C
0005433367432	24861	8	4D
0005433367427	24861	9	4E
0005433367428	24861	10	5A
0005433367421	24861	11	5D
0005433367449	24861	12	5E
0005433367418	24861	13	6A
0005433367441	24861	14	6C
0005433367424	24861	15	6D
0005433367417	24861	16	6F
0005433367452	24861	17	7A
0005433367420	24861	18	7E
0005433367435	24861	19	8D
0005433367415	24861	20	9C
0005433367426	24861	21	9D
0005433367412	24861	22	10D
0005433367434	24861	23	11A
0005433367414	24861	24	11C
0005433367430	24861	25	11F
0005433367447	24861	26	12C
0005433367446	24861	27	12E
0005433367429	24861	28	12F
0005433367440	24861	29	13F
0005433367411	24861	30	14D
0005433367425	24861	31	14F
0005433367444	24861	32	15C
0005433367438	24861	33	16A
0005433367442	24861	34	16E
0005433367410	24861	35	16F
0005433367419	24861	36	17E
0005433367413	24861	37	17F
0005433367431	24861	38	18D
0005433367436	24861	39	18E
0005433367443	24861	40	18F
0005433367448	24861	41	19A
0005433367416	24861	42	20C
0005433367423	24861	43	20F
0005434979415	2053	1	1A
0005435801659	2053	2	1C
0005434979409	2053	3	1D
0005434979436	2053	4	2A
0005434979421	2053	5	2B
0005434979410	2053	6	2C
0005435801658	2053	7	3B
0005434979423	2053	8	3C
0005434979426	2053	9	3D
0005434979413	2053	10	4B
0005434979407	2053	11	5D
0005434979414	2053	12	6A
0005434979432	2053	13	6B
0005434979418	2053	14	6C
0005434979422	2053	15	6D
0005434979428	2053	16	7A
0005434979416	2053	17	7B
0005435801660	2053	18	7C
0005434979425	2053	19	7D
0005434979420	2053	20	18A
0005434979417	2053	21	18B
0005434979424	2053	22	18C
0005434979419	2053	23	18D
0005434979431	2053	24	19A
0005434979429	2053	25	19B
0005434979430	2053	26	19C
0005434979427	2053	27	19D
0005434979412	2053	28	20A
0005434979434	2053	29	21A
0005434979435	2053	30	21B
0005434979433	2053	31	22D
0005434979411	2053	32	23A
0005434979408	2053	33	23B
0005434952486	2622	1	1A
0005434952484	2622	2	2A
0005434952485	2622	3	2B
0005433256387	2623	1	3B
0005433256393	28218	1	1A
0005433256394	28218	2	3A
0005433111479	19824	1	3B
0005433111480	19824	2	5A
0005433112358	19824	3	6A
0005433112359	19824	4	6B
0005434137029	28743	1	1A
0005434137076	28743	2	1C
0005434137084	28743	3	1D
0005434137051	28743	4	1F
0005434137019	28743	5	2A
0005434137038	28743	6	2C
0005434137078	28743	7	2D
0005434137046	28743	8	2F
0005434137088	28743	9	3A
0005434137079	28743	10	3C
0005434137085	28743	11	3D
0005434137067	28743	12	3F
0005434137036	28743	13	4A
0005434137054	28743	14	4C
0005434137093	28743	15	4D
0005434137032	28743	16	4E
0005434137073	28743	17	5A
0005434137061	28743	18	5C
0005434137081	28743	19	5E
0005434137020	28743	20	5F
0005434137057	28743	21	6A
0005434137027	28743	22	6C
0005434137071	28743	23	6D
0005434137090	28743	24	6E
0005434137096	28743	25	6F
0005434137053	28743	26	7A
0005434137026	28743	27	7C
0005434137100	28743	28	7D
0005434137070	28743	29	7E
0005434137066	28743	30	7F
0005434137050	28743	31	8A
0005434137014	28743	32	8C
0005434137063	28743	33	8D
0005434137077	28743	34	8E
0005434137018	28743	35	8F
0005434137047	28743	36	9A
0005434137048	28743	37	9C
0005434137039	28743	38	9D
0005434137045	28743	39	9E
0005434137028	28743	40	9F
0005434137034	28743	41	10A
0005434137042	28743	42	10C
0005434137060	28743	43	10D
0005434137062	28743	44	10E
0005434137055	28743	45	10F
0005434137083	28743	46	11A
0005434137068	28743	47	11C
0005434137075	28743	48	11D
0005434137086	28743	49	11E
0005434137044	28743	50	11F
0005434137041	28743	51	12C
0005434137059	28743	52	12D
0005434137033	28743	53	12E
0005434137095	28743	54	12F
0005434137092	28743	55	13A
0005434137030	28743	56	13D
0005434137091	28743	57	13F
0005434137040	28743	58	14A
0005434137016	28743	59	14C
0005434137065	28743	60	14D
0005434137052	28743	61	14E
0005434137097	28743	62	14F
0005434137080	28743	63	15A
0005434137064	28743	64	15D
0005434137023	28743	65	15E
0005434137024	28743	66	16A
0005434137043	28743	67	16C
0005434137069	28743	68	16D
0005434137058	28743	69	16E
0005434137087	28743	70	17A
0005434137035	28743	71	17C
0005434137094	28743	72	17D
0005434137022	28743	73	17E
0005434137037	28743	74	17F
0005434137082	28743	75	18A
0005434137089	28743	76	18C
0005434137015	28743	77	18D
0005434137098	28743	78	18E
0005434137021	28743	79	18F
0005434137072	28743	80	19C
0005434137049	28743	81	19D
0005434137099	28743	82	19E
0005434137017	28743	83	20A
0005434137025	28743	84	20C
0005434137031	28743	85	20D
0005434137056	28743	86	20E
0005434137074	28743	87	20F
0005433538764	6774	1	1C
0005433538762	6774	2	2D
0005433534472	6774	3	3A
0005433538760	6774	4	4C
0005433538763	6774	5	5B
0005433538766	6774	6	7C
0005433538761	6774	7	20C
0005433538768	6774	8	21A
0005433538767	6774	9	21C
0005435259681	6774	10	23A
0005433538765	6774	11	23B
0005433538730	24993	1	1C
0005435259703	24993	2	2B
0005435259702	24993	3	2C
0005435259701	24993	4	2D
0005433538719	24993	5	3C
0005435259704	24993	6	5B
0005435259705	24993	7	5D
0005433538731	24993	8	7B
0005433538729	24993	9	19A
0005433511849	824	1	2B
0005433511848	824	2	3C
0005433511844	824	3	3D
0005433511850	824	4	7A
0005433511846	824	5	21A
0005433511845	824	6	22B
0005433511851	824	7	22C
0005433511847	824	8	23B
0005433511812	16121	1	1A
0005433511811	16121	2	4B
0005433511810	16121	3	4D
0005432922474	16121	4	5D
0005432922473	16121	5	7A
0005432922476	16121	6	18C
0005432922475	16121	7	23A
0005433475645	4039	1	1B
0005433475647	4039	2	1D
0005433475655	4039	3	3A
0005433475649	4039	4	3B
0005433475650	4039	5	3C
0005433475656	4039	6	3D
0005433475646	4039	7	4B
0005433475652	4039	8	4C
0005433475648	4039	9	18A
0005433475653	4039	10	19C
0005433475654	4039	11	19D
0005433475644	4039	12	20A
0005433475643	4039	13	20B
0005433475651	4039	14	21C
0005435696990	3679	1	1B
0005434950473	3679	2	2B
0005435697011	3679	3	2C
0005434950474	3679	4	2D
0005434950476	3679	5	3A
0005435696996	3679	6	3B
0005435697010	3679	7	3C
0005435696992	3679	8	3D
0005435696986	3679	9	4A
0005434950472	3679	10	4B
0005435696989	3679	11	5B
0005435697005	3679	12	5D
0005435696999	3679	13	6A
0005435697014	3679	14	6B
0005435696988	3679	15	6C
0005435697007	3679	16	6D
0005435697001	3679	17	7A
0005435696995	3679	18	7B
0005435697013	3679	19	7C
0005435696997	3679	20	7D
0005434950475	3679	21	18C
0005435697006	3679	22	18D
0005435696994	3679	23	19B
0005435697004	3679	24	19C
0005435697008	3679	25	20A
0005435935002	3679	26	20B
0005435696998	3679	27	21A
0005435696993	3679	28	21B
0005435697003	3679	29	21C
0005435697009	3679	30	21D
0005435697002	3679	31	22A
0005435697012	3679	32	22B
0005435935001	3679	33	22C
0005435696991	3679	34	22D
0005435697000	3679	35	23A
0005435696987	3679	36	23B
0005435696887	16256	1	2D
0005435696886	16256	2	3A
0005435935004	16256	3	3B
0005435916132	16256	4	4A
0005435935005	16256	5	5A
0005434950450	16256	6	6B
0005435916133	16256	7	7D
0005435935006	16256	8	18B
0005435916135	16256	9	19A
0005435916134	16256	10	19B
0005435935007	16256	11	19C
0005434950451	16256	12	22B
0005433519403	3961	1	1B
0005434606784	3961	2	1D
0005434604858	3961	3	3B
0005433519400	3961	4	3A
0005432609681	3961	5	4B
0005435853578	3961	6	4D
0005432609683	3961	7	5C
0005434604857	3961	8	6A
0005434606782	3961	9	6C
0005434606783	3961	10	7A
0005434604854	3961	11	7B
0005433519401	3961	12	19A
0005432609682	3961	13	19C
0005434604855	3961	14	20C
0005433519402	3961	15	20D
0005432607517	3961	16	22C
0005432607516	3961	17	22D
0005434604856	3961	18	23A
0005432607515	3961	19	23B
0005433519381	22063	1	3C
0005435853587	22063	2	20A
0005435628688	682	1	1A
0005435628687	682	2	3B
0005435628689	682	3	5A
0005433348917	15886	1	3A
0005433348921	15886	2	4A
0005433348918	15886	3	5A
0005433348920	15886	4	5B
0005433348916	15886	5	6A
0005433348919	15886	6	6B
0005434446487	17177	1	1B
0005434446489	17177	2	2A
0005434446488	17177	3	2B
0005434445215	17177	4	5A
0005434445216	17177	5	5B
0005434446490	17177	6	6B
0005433159287	17608	1	5A
0005433159288	17608	2	4B
0005433159286	17608	3	5B
0005435132750	7899	1	2B
0005435132752	7899	2	3B
0005435132757	7899	3	3C
0005435132755	7899	4	4B
0005435132751	7899	5	5A
0005435132758	7899	6	5C
0005435132748	7899	7	6A
0005435132756	7899	8	6D
0005435132749	7899	9	18B
0005435132754	7899	10	19D
0005435132753	7899	11	20B
0005435383086	33073	1	3B
0005435383085	33073	2	5C
0005435383082	33073	3	6C
0005435383087	33073	4	7D
0005435383084	33073	5	18A
0005435383083	33073	6	20B
0005435132714	33073	7	23B
0005435160168	7521	1	3C
0005435160166	7521	2	3D
0005435160170	7521	3	4B
0005435160167	7521	4	5B
0005435160164	7521	5	5D
0005435160169	7521	6	6B
0005435160163	7521	7	6C
0005435160165	7521	8	7B
0005435390129	7521	9	19D
0005435160171	7521	10	20B
0005435160162	7521	11	21C
0005435160160	7521	12	21D
0005435160161	7521	13	22B
0005435390130	7521	14	22C
0005435390153	29558	1	2B
0005435390158	29558	2	5B
0005435160113	29558	3	6B
0005435390156	29558	4	7D
0005435390157	29558	5	18A
0005435390154	29558	6	18C
0005435390155	29558	7	19B
0005435160103	29558	8	19D
0005435160104	29558	9	20D
0005435390159	29558	10	21C
0005435178476	18450	1	2A
0005435178982	18450	2	3A
0005435178477	18450	3	5A
0005435178981	18450	4	5B
0005432398148	27177	1	1A
0005432400076	27177	2	2A
0005432398146	27177	3	2B
0005432398147	27177	4	3A
0005432400074	27177	5	4A
0005432400075	27177	6	4B
0005432400073	27177	7	6A
0005434503690	6509	1	1C
0005434503680	6509	2	1D
0005434503691	6509	3	1F
0005434503670	6509	4	2A
0005434503666	6509	5	2D
0005435103847	6509	6	3A
0005434503674	6509	7	3D
0005434503673	6509	8	4A
0005434503677	6509	9	4F
0005434503692	6509	10	5F
0005434503669	6509	11	6A
0005434503699	6509	12	6D
0005434503696	6509	13	7E
0005434503681	6509	14	7F
0005434503676	6509	15	8A
0005435103844	6509	16	8D
0005435103845	6509	17	8E
0005434503687	6509	18	8F
0005434503688	6509	19	9A
0005434503694	6509	20	9C
0005434503678	6509	21	9F
0005435103841	6509	22	10A
0005434503689	6509	23	10C
0005434503695	6509	24	10D
0005435103839	6509	25	10E
0005434503661	6509	26	10F
0005434503698	6509	27	11C
0005434503683	6509	28	11E
0005434503682	6509	29	11F
0005434503668	6509	30	12D
0005434503663	6509	31	12E
0005434503660	6509	32	13C
0005434503667	6509	33	13E
0005434503697	6509	34	14A
0005434503665	6509	35	14C
0005434503679	6509	36	15A
0005434503684	6509	37	15E
0005435103843	6509	38	15F
0005434503662	6509	39	16A
0005435103846	6509	40	16C
0005434503686	6509	41	16E
0005434503671	6509	42	16F
0005435103848	6509	43	17A
0005434503685	6509	44	17C
0005435103849	6509	45	18A
0005434503664	6509	46	18D
0005435103838	6509	47	18F
0005434503675	6509	48	19E
0005435103840	6509	49	19F
0005434503693	6509	50	20C
0005434503672	6509	51	20E
0005435103842	6509	52	20F
0005434503486	22667	1	20A
0005435652506	1695	1	1A
0005435652513	1695	2	1D
0005435652522	1695	3	3A
0005435652519	1695	4	3D
0005435652496	1695	5	4D
0005435652517	1695	6	4F
0005435652508	1695	7	5C
0005435652494	1695	8	5D
0005433367241	1695	9	6A
0005435652514	1695	10	6C
0005435652503	1695	11	6E
0005435652524	1695	12	7D
0005435652523	1695	13	7E
0005435652510	1695	14	7F
0005435652489	1695	15	8C
0005435652515	1695	16	9F
0005435652490	1695	17	10A
0005435652507	1695	18	10D
0005435652499	1695	19	11A
0005435652505	1695	20	11D
0005435652512	1695	21	11F
0005435652498	1695	22	12E
0005435652495	1695	23	12F
0005435652491	1695	24	13A
0005435652525	1695	25	13C
0005435652504	1695	26	13F
0005435652520	1695	27	14A
0005435652493	1695	28	14D
0005435652511	1695	29	14E
0005435652521	1695	30	15D
0005435652518	1695	31	16A
0005433367223	1695	32	16C
0005435652502	1695	33	16D
0005435652516	1695	34	17C
0005435652509	1695	35	17D
0005435652492	1695	36	18A
0005435652526	1695	37	19E
0005435652500	1695	38	20A
0005433367234	1695	39	20C
0005435652501	1695	40	20E
0005435652497	1695	41	20F
0005433367441	21673	1	2A
0005433367428	21673	2	2C
0005433367442	21673	3	2D
0005433367439	21673	4	2F
0005433367431	21673	5	3F
0005433367411	21673	6	4A
0005433367433	21673	7	4E
0005433367417	21673	8	4F
0005433367446	21673	9	5C
0005433367432	21673	10	5D
0005433367414	21673	11	6A
0005433367410	21673	12	6F
0005433367430	21673	13	7C
0005433367413	21673	14	7D
0005433367445	21673	15	8A
0005433367425	21673	16	8D
0005433367427	21673	17	9A
0005433367412	21673	18	9C
0005433367447	21673	19	9F
0005433367420	21673	20	10C
0005433367448	21673	21	10E
0005433367422	21673	22	11D
0005433367429	21673	23	11E
0005433367415	21673	24	12A
0005433367424	21673	25	12F
0005433367437	21673	26	13A
0005433367418	21673	27	13C
0005433367421	21673	28	13F
0005433367426	21673	29	14D
0005433367440	21673	30	14E
0005433367443	21673	31	15A
0005433367423	21673	32	15D
0005433367435	21673	33	16A
0005433367449	21673	34	16C
0005433367452	21673	35	17E
0005433367436	21673	36	17F
0005433367438	21673	37	18C
0005433367434	21673	38	18E
0005433367416	21673	39	19D
0005433367451	21673	40	19F
0005433367450	21673	41	20C
0005433367419	21673	42	20E
0005433367444	21673	43	20F
0005433985404	4154	1	1C
0005433985378	4154	2	1D
0005435788740	4154	3	2A
0005433985392	4154	4	2C
0005433985361	4154	5	2F
0005433985389	4154	6	3A
0005433985380	4154	7	3F
0005433985367	4154	8	4A
0005433985390	4154	9	4C
0005433985369	4154	10	4D
0005433985385	4154	11	4E
0005433985368	4154	12	5C
0005433985372	4154	13	6C
0005433985371	4154	14	6D
0005433985381	4154	15	6F
0005433985384	4154	16	7A
0005433985377	4154	17	7C
0005433985399	4154	18	7F
0005433985387	4154	19	8C
0005433985366	4154	20	8D
0005433985375	4154	21	8E
0005433985391	4154	22	9A
0005433985401	4154	23	9C
0005433985359	4154	24	9D
0005433985407	4154	25	9E
0005433985363	4154	26	10A
0005433985394	4154	27	10D
0005433985370	4154	28	10F
0005433985360	4154	29	11A
0005433985383	4154	30	11C
0005433985397	4154	31	11F
0005433985358	4154	32	12A
0005433985400	4154	33	12C
0005433985364	4154	34	13A
0005433985396	4154	35	13C
0005433985388	4154	36	13E
0005433985398	4154	37	13F
0005433985376	4154	38	14E
0005433985362	4154	39	14F
0005433985406	4154	40	15C
0005433985365	4154	41	15E
0005433985403	4154	42	15F
0005433985395	4154	43	16A
0005433985379	4154	44	16C
0005435788739	4154	45	16D
0005433985393	4154	46	18A
0005433985382	4154	47	18C
0005433985405	4154	48	18E
0005433985402	4154	49	18F
0005433985374	4154	50	19D
0005435788738	4154	51	20C
0005433985373	4154	52	20D
0005433985386	4154	53	20F
0005435788730	25647	1	10D
0005433985159	25647	2	10F
0005433985153	25647	3	12A
0005433985183	25647	4	19E
0005435720798	21259	1	7C
0005435720799	21259	2	19B
0005435720800	21259	3	20A
0005435719553	24800	1	5A
0005433168313	21320	1	4A
0005433168321	21320	2	4C
0005433168320	21320	3	5A
0005433168317	21320	4	5B
0005434509019	21320	5	5D
0005433168316	21320	6	6A
0005433168318	21320	7	6C
0005433168322	21320	8	7A
0005433168324	21320	9	18A
0005433168314	21320	10	18B
0005433168312	21320	11	18C
0005433168315	21320	12	19C
0005434509024	21320	13	20C
0005433168323	21320	14	21B
0005433168319	21320	15	22A
0005432869446	17870	1	3D
0005432869450	17870	2	5D
0005434151670	17870	3	6A
0005432869449	17870	4	7C
0005432869447	17870	5	10A
0005432869448	17870	6	13D
0005434151671	17870	7	13E
0005432657394	17870	8	16E
0005432657407	26285	1	1F
0005432655371	26285	2	5E
0005432665246	26285	3	6A
0005432655366	26285	4	7A
0005432657408	26285	5	9F
0005432667427	26285	6	10C
0005432667426	26285	7	10F
0005432655368	26285	8	11C
0005432655374	26285	9	11E
0005432655365	26285	10	11F
0005432655370	26285	11	13C
0005432666360	26285	12	13E
0005432666359	26285	13	14D
0005432655367	26285	14	15D
0005432655369	26285	15	16C
0005432655363	26285	16	16F
0005432655372	26285	17	17A
0005432655373	26285	18	17C
0005432660790	26285	19	18E
0005432665247	26285	20	19A
0005432658563	26285	21	19C
0005432659677	26285	22	19D
0005432655364	26285	23	19F
0005432659678	26285	24	20A
0005432665248	26285	25	20D
0005432658562	26285	26	20E
0005433438796	3125	1	1C
0005432287128	3125	2	2A
0005432328161	3125	3	2C
0005432328149	3125	4	2D
0005432328160	3125	5	3A
0005433438799	3125	6	3C
0005432328148	3125	7	3F
0005432328156	3125	8	4A
0005433438801	3125	9	4D
0005432328142	3125	10	4E
0005432328167	3125	11	4F
0005432287127	3125	12	5A
0005432328150	3125	13	5C
0005432328145	3125	14	5D
0005432328139	3125	15	5F
0005432287126	3125	16	6A
0005432328164	3125	17	6C
0005432328131	3125	18	6D
0005432328137	3125	19	7A
0005432328159	3125	20	7E
0005432328151	3125	21	7F
0005432328169	3125	22	8A
0005432328143	3125	23	8D
0005433438797	3125	24	8E
0005432328132	3125	25	8F
0005433438803	3125	26	9A
0005432328168	3125	27	9C
0005432328172	3125	28	9E
0005433438802	3125	29	9F
0005432328155	3125	30	10C
0005432287129	3125	31	10D
0005432328144	3125	32	10F
0005432328171	3125	33	11E
0005432328162	3125	34	12A
0005432328153	3125	35	12C
0005432328166	3125	36	12E
0005432328157	3125	37	13C
0005432328163	3125	38	13D
0005432328130	3125	39	13F
0005432328152	3125	40	14A
0005432328154	3125	41	14C
0005432287125	3125	42	14D
0005432328138	3125	43	14E
0005432328141	3125	44	15A
0005432328135	3125	45	15D
0005432328146	3125	46	15E
0005432287131	3125	47	16A
0005433438800	3125	48	16C
0005432328158	3125	49	16D
0005432328133	3125	50	16F
0005433438798	3125	51	17A
0005432328129	3125	52	17C
0005432328165	3125	53	17D
0005432328136	3125	54	17F
0005432328128	3125	55	18A
0005432328126	3125	56	18E
0005432328127	3125	57	19A
0005432328134	3125	58	19C
0005432287130	3125	59	19D
0005432328147	3125	60	19F
0005432328125	3125	61	20A
0005432328170	3125	62	20C
0005432328140	3125	63	20D
0005432327962	31144	1	2D
0005432905050	31144	2	6E
0005432905051	31144	3	9C
0005432054268	31144	4	10D
0005432905052	31144	5	11E
0005432905054	31144	6	12C
0005432905049	31144	7	13D
0005432054267	31144	8	14D
0005432054269	31144	9	14E
0005433438764	31144	10	15D
0005432328009	31144	11	16C
0005432905053	31144	12	16E
0005432328012	31144	13	19A
0005432905055	31144	14	19C
0005435999038	6233	1	1A
0005434309574	6233	2	3C
0005434309573	6233	3	3F
0005435999046	6233	4	4B
0005434309580	6233	5	5C
0005435999040	6233	6	5D
0005434309583	6233	7	6B
0005435999037	6233	8	6A
0005434309582	6233	9	6F
0005435999042	6233	10	9A
0005434309579	6233	11	14F
0005434309575	6233	12	15B
0005434309577	6233	13	15E
0005435999044	6233	14	17E
0005435999043	6233	15	18B
0005434309570	6233	16	18D
0005435999039	6233	17	18C
0005435999036	6233	18	18E
0005434309571	6233	19	19B
0005434309572	6233	20	19D
0005432146175	6233	21	19C
0005434309578	6233	22	20A
0005434309581	6233	23	20B
0005435999041	6233	24	21C
0005434309576	6233	25	22A
0005435999035	6233	26	22B
0005435999045	6233	27	22D
0005435487560	19567	1	1A
0005435487563	19567	2	2C
0005435487557	19567	3	4A
0005435296978	19567	4	4E
0005435296973	19567	5	5B
0005435296977	19567	6	5D
0005435487550	19567	7	6B
0005435487546	19567	8	6C
0005435487554	19567	9	6D
0005435296972	19567	10	10B
0005435296975	19567	11	11B
0005435487552	19567	12	11F
0005435487543	19567	13	12B
0005435487556	19567	14	12A
0005435487561	19567	15	12E
0005435487551	19567	16	12D
0005435487547	19567	17	14A
0005435487555	19567	18	16B
0005435296974	19567	19	16C
0005435487548	19567	20	16D
0005435296976	19567	21	17A
0005435487544	19567	22	17B
0005435487553	19567	23	17C
0005435487558	19567	24	18F
0005435487549	19567	25	21B
0005435487559	19567	26	23A
0005435487562	19567	27	23D
0005435487545	19567	28	23E
0005435502059	1558	1	1A
0005435517689	1558	2	1C
0005434565754	1558	3	1D
0005435508225	1558	4	1F
0005434565757	1558	5	2A
0005434565748	1558	6	2C
0005435517709	1558	7	2D
0005435517692	1558	8	2F
0005435508224	1558	9	3A
0005435517699	1558	10	3C
0005434565752	1558	11	3D
0005435502054	1558	12	4A
0005432291902	1558	13	4C
0005435517696	1558	14	4E
0005435517702	1558	15	4F
0005435517710	1558	16	5A
0005435502048	1558	17	5C
0005435502058	1558	18	5D
0005435517708	1558	19	6A
0005434565755	1558	20	6C
0005435517695	1558	21	6D
0005435508222	1558	22	7D
0005434565746	1558	23	7F
0005435502052	1558	24	8A
0005435502051	1558	25	8C
0005432291900	1558	26	8D
0005435517698	1558	27	8E
0005435508228	1558	28	9D
0005435502055	1558	29	9E
0005434565749	1558	30	9F
0005435502045	1558	31	10C
0005435517700	1558	32	10D
0005435508223	1558	33	10E
0005435502044	1558	34	10F
0005435517701	1558	35	11A
0005435508226	1558	36	11D
0005434565751	1558	37	11E
0005435502056	1558	38	12A
0005432291901	1558	39	12D
0005435502047	1558	40	12E
0005435502057	1558	41	12F
0005434565753	1558	42	13C
0005435517690	1558	43	13D
0005435517707	1558	44	13F
0005434565747	1558	45	14A
0005435502060	1558	46	14D
0005435517693	1558	47	14F
0005435517703	1558	48	15C
0005435502061	1558	49	15D
0005435517694	1558	50	15E
0005435517704	1558	51	16A
0005434565750	1558	52	16C
0005435502043	1558	53	16D
0005435517697	1558	54	16E
0005435502049	1558	55	17A
0005435502062	1558	56	17C
0005435517705	1558	57	17D
0005434565756	1558	58	17E
0005435517706	1558	59	17F
0005435517691	1558	60	18A
0005435508227	1558	61	18E
0005435502046	1558	62	18F
0005435502063	1558	63	19D
0005435502042	1558	64	19F
0005434565759	1558	65	20A
0005435502053	1558	66	20D
0005434565758	1558	67	20E
0005435502050	1558	68	20F
0005433186020	20847	1	2D
0005434565686	20847	2	2F
0005433186019	20847	3	7C
0005433186015	20847	4	8C
0005433186014	20847	5	9F
0005433186012	20847	6	10D
0005433186018	20847	7	10E
0005433186013	20847	8	11F
0005433186011	20847	9	12A
0005433186016	20847	10	16A
0005433186017	20847	11	16E
0005435153664	3891	1	1B
0005435153662	3891	2	2A
0005435153663	3891	3	6D
0005435153660	3891	4	7D
0005435153661	3891	5	19A
0005435153665	3891	6	21B
0005435153659	3891	7	21C
0005435931558	21853	1	3D
0005435931557	21853	2	18A
0005435931555	21853	3	19C
0005435931556	21853	4	21C
0005435931554	21853	5	22C
0005432628665	7209	1	1D
0005432628674	7209	2	2C
0005432628666	7209	3	2D
0005432628670	7209	4	3B
0005432628663	7209	5	3C
0005432628671	7209	6	3D
0005435225447	7209	7	4A
0005432628662	7209	8	4C
0005432628661	7209	9	5C
0005432628668	7209	10	6B
0005435225456	7209	11	6D
0005432628673	7209	12	7B
0005432628669	7209	13	18C
0005432628675	7209	14	18D
0005435225454	7209	15	20D
0005435225455	7209	16	21C
0005432628664	7209	17	21D
0005432628667	7209	18	22C
0005432628672	7209	19	22D
0005435225485	28146	1	1B
0005432628587	28146	2	3A
0005435225491	28146	3	3B
0005435225484	28146	4	3D
0005435225486	28146	5	6C
0005432628588	28146	6	6D
0005435225488	28146	7	7D
0005435225483	28146	8	18A
0005435225490	28146	9	19D
0005435225489	28146	10	20D
0005435225487	28146	11	21B
0005435960004	8728	1	5B
0005435960003	8728	2	7A
0005435960002	8728	3	19A
0005435960005	8728	4	22D
0005434267905	15244	1	2D
0005434267904	15244	2	19B
0005434267902	15244	3	19C
0005434267903	15244	4	22B
0005432674946	1177	1	1C
0005432692667	1177	2	1A
0005432692668	1177	3	1F
0005432692674	1177	4	2F
0005432692661	1177	5	2C
0005432674954	1177	6	3A
0005432692671	1177	7	3C
0005432674939	1177	8	3F
0005432692654	1177	9	4D
0005432677520	1177	10	4C
0005432674949	1177	11	4F
0005432692662	1177	12	5D
0005432677523	1177	13	5C
0005432674947	1177	14	6A
0005432692677	1177	15	6D
0005432692685	1177	16	6B
0005432692659	1177	17	6F
0005432873171	1177	18	7B
0005432692680	1177	19	7D
0005432692664	1177	20	8A
0005432692666	1177	21	8F
0005432692663	1177	22	9A
0005432692665	1177	23	9D
0005432692670	1177	24	11C
0005432692678	1177	25	11D
0005432692655	1177	26	11F
0005432692656	1177	27	11E
0005432692658	1177	28	13A
0005432674948	1177	29	13E
0005432692683	1177	30	13D
0005432677521	1177	31	14B
0005432674941	1177	32	14E
0005432692681	1177	33	14C
0005432692676	1177	34	15B
0005432692669	1177	35	15C
0005432674942	1177	36	16B
0005432674944	1177	37	16A
0005432692675	1177	38	15F
0005432674951	1177	39	16C
0005432692684	1177	40	17A
0005432692673	1177	41	16E
0005432674953	1177	42	17B
0005432692672	1177	43	17D
0005432674952	1177	44	17F
0005432692657	1177	45	17E
0005432674950	1177	46	18C
0005432692660	1177	47	18E
0005432692679	1177	48	18D
0005432674945	1177	49	19C
0005432692653	1177	50	19D
0005432674955	1177	51	20B
0005432692682	1177	52	20D
0005432674940	1177	53	20E
0005432677522	1177	54	20F
0005432674943	1177	55	21D
0005432873202	17478	1	1C
0005432674885	17478	2	6B
0005432873204	17478	3	7A
0005432873205	17478	4	10F
0005432873208	17478	5	13D
0005432692565	17478	6	13F
0005432873207	17478	7	15C
0005432873206	17478	8	16C
0005432873203	17478	9	16B
0005432674886	17478	10	20E
0005434434992	1134	1	1C
0005434435000	1134	2	2A
0005434434995	1134	3	2B
0005434434998	1134	4	3B
0005433156599	1134	5	3C
0005434434988	1134	6	5B
0005434434999	1134	7	5D
0005434434997	1134	8	6B
0005433156610	1134	9	6D
0005433156597	1134	10	7A
0005434434993	1134	11	7D
0005434434994	1134	12	19A
0005433156598	1134	13	19D
0005434434991	1134	14	20B
0005434434989	1134	15	21B
0005434434996	1134	16	21D
0005434434990	1134	17	22A
0005434435001	1134	18	22B
0005434434987	1134	19	22C
0005434435002	1134	20	23B
0005434434924	17295	1	1A
0005433156644	17295	2	2A
0005433156641	17295	3	2D
0005433156642	17295	4	4D
0005433156648	17295	5	6B
0005433156640	17295	6	7A
0005433156645	17295	7	7D
0005434434923	17295	8	20A
0005433156646	17295	9	20C
0005433156647	17295	10	21A
0005433156643	17295	11	21B
0005435086740	4078	1	1D
0005435086744	4078	2	2D
0005435086742	4078	3	5A
0005435086743	4078	4	5D
0005435086741	4078	5	21B
0005435086739	4078	6	22A
0005435086745	4078	7	22D
0005435928083	24414	1	3C
0005435928085	24414	2	5A
0005435086713	24414	3	6A
0005435928084	24414	4	18C
0005435928086	24414	5	18D
0005435086712	24414	6	21D
0005435928082	24414	7	22D
0005434625845	4851	1	1D
0005434625847	4851	2	1F
0005434625846	4851	3	3D
0005434625852	4851	4	4D
0005434625848	4851	5	7D
0005434625842	4851	6	8F
0005434625844	4851	7	16C
0005434625851	4851	8	17D
0005434625850	4851	9	17F
0005434625843	4851	10	19A
0005434625849	4851	11	19F
0005435907446	32885	1	1C
0005435907447	32885	2	14F
0005435907445	32885	3	17E
0005435907444	32885	4	19E
0005432195667	13774	1	7D
0005435784781	13774	2	21D
0005435784904	27451	1	1A
0005435784898	27451	2	1B
0005432190575	27451	3	1C
0005435784894	27451	4	2A
0005435784892	27451	5	2B
0005435784891	27451	6	2C
0005435784885	27451	7	2D
0005435784900	27451	8	3B
0005435784884	27451	9	3C
0005435784883	27451	10	4A
0005435784873	27451	11	3D
0005435784869	27451	12	4B
0005435784899	27451	13	4D
0005435784881	27451	14	5A
0005435784901	27451	15	5B
0005435784896	27451	16	5C
0005435784902	27451	17	6A
0005435784874	27451	18	6B
0005432190578	27451	19	6C
0005435787324	27451	20	7A
0005435784871	27451	21	7B
0005435784888	27451	22	7C
0005435784875	27451	23	7D
0005435784886	27451	24	18A
0005432190576	27451	25	18C
0005435784893	27451	26	18D
0005435784872	27451	27	19A
0005435784889	27451	28	19B
0005435784878	27451	29	19C
0005432190577	27451	30	19D
0005435784882	27451	31	20A
0005435784895	27451	32	20C
0005435784870	27451	33	20D
0005435784877	27451	34	21A
0005435784890	27451	35	21B
0005435784876	27451	36	21C
0005435784903	27451	37	22A
0005435784887	27451	38	22B
0005435787325	27451	39	22C
0005435784879	27451	40	22D
0005435784897	27451	41	23A
0005435784880	27451	42	23B
0005432058333	20298	1	4E
0005432058336	20298	2	11A
0005432058334	20298	3	15F
0005432058332	20298	4	16F
0005432058335	20298	5	18F
0005434406969	26976	1	1C
0005434406984	26976	2	1D
0005434406961	26976	3	1F
0005434406973	26976	4	2A
0005434407005	26976	5	2C
0005434406991	26976	6	2D
0005434407023	26976	7	2F
0005434406996	26976	8	3A
0005434407000	26976	9	3D
0005434406988	26976	10	3F
0005434406981	26976	11	4A
0005434406992	26976	12	4C
0005434406995	26976	13	4D
0005434407010	26976	14	4E
0005434406980	26976	15	5A
0005432153850	26976	16	5C
0005434406983	26976	17	5E
0005434406982	26976	18	5F
0005434407004	26976	19	6A
0005434406999	26976	20	6E
0005434406979	26976	21	6D
0005434407017	26976	22	6F
0005434407003	26976	23	7C
0005434406970	26976	24	7D
0005434406967	26976	25	7F
0005434406978	26976	26	8D
0005434407009	26976	27	8E
0005434406964	26976	28	8F
0005434406959	26976	29	9A
0005434406993	26976	30	9C
0005432153855	26976	31	9D
0005434407022	26976	32	9E
0005434407015	26976	33	9F
0005434407016	26976	34	10C
0005434406985	26976	35	10E
0005434406971	26976	36	10F
0005434407012	26976	37	11C
0005434406997	26976	38	11D
0005434406990	26976	39	11E
0005434407013	26976	40	11F
0005434407002	26976	41	12C
0005434406974	26976	42	12D
0005434406960	26976	43	12F
0005434406977	26976	44	13E
0005434406968	26976	45	14A
0005434407019	26976	46	14C
0005434406987	26976	47	14D
0005434406998	26976	48	14E
0005432153854	26976	49	14F
0005434406975	26976	50	15A
0005432153852	26976	51	15C
0005434406966	26976	52	15F
0005434407008	26976	53	16A
0005434407014	26976	54	16C
0005434406965	26976	55	16D
0005434407011	26976	56	16F
0005432153851	26976	57	17C
0005434406972	26976	58	17E
0005434407001	26976	59	17F
0005434407020	26976	60	18A
0005434406976	26976	61	18C
0005432153853	26976	62	18D
0005434407006	26976	63	18E
0005434407018	26976	64	18F
0005434406963	26976	65	19E
0005434406962	26976	66	19F
0005434406986	26976	67	20A
0005434407007	26976	68	20C
0005434406989	26976	69	20D
0005434406994	26976	70	20E
0005434407021	26976	71	20F
0005434319221	5681	1	1A
0005434319213	5681	2	1C
0005434319218	5681	3	1D
0005434319225	5681	4	2A
0005432109669	5681	5	2F
0005434319212	5681	6	4C
0005434311192	5681	7	4D
0005434319210	5681	8	5C
0005434319217	5681	9	5D
0005434311191	5681	10	5F
0005432109668	5681	11	6E
0005434319219	5681	12	6F
0005434319216	5681	13	7F
0005434319224	5681	14	8A
0005432109670	5681	15	8D
0005434319223	5681	16	8F
0005434319215	5681	17	9A
0005434319222	5681	18	10F
0005433123575	5681	19	12A
0005434319228	5681	20	14D
0005434319214	5681	21	16D
0005434319220	5681	22	18A
0005434319211	5681	23	19A
0005434319226	5681	24	19F
0005434311193	5681	25	20A
0005434319227	5681	26	20E
0005433123693	15672	1	1C
0005433123681	15672	2	2A
0005433123695	15672	3	3A
0005433123696	15672	4	3C
0005433123689	15672	5	4A
0005433123691	15672	6	4D
0005433123686	15672	7	4F
0005433123688	15672	8	10A
0005433123680	15672	9	10C
0005433123698	15672	10	10E
0005433123697	15672	11	11E
0005433123690	15672	12	12F
0005433123684	15672	13	14A
0005433123679	15672	14	16E
0005433123687	15672	15	18C
0005433123682	15672	16	18E
0005433123692	15672	17	18F
0005433123683	15672	18	19C
0005433123694	15672	19	19D
0005433123685	15672	20	19E
0005434484268	8963	1	2D
0005434484266	8963	2	3B
0005434484270	8963	3	5B
0005434484269	8963	4	6A
0005434484265	8963	5	7D
0005434484267	8963	6	20C
0005434189106	16627	1	4A
0005434189108	16627	2	4D
0005434189110	16627	3	7A
0005434189109	16627	4	19A
0005434189105	16627	5	20B
0005434189107	16627	6	21C
0005433123690	7646	1	1F
0005433123679	7646	2	2A
0005433123692	7646	3	2C
0005433123687	7646	4	3A
0005433123681	7646	5	3D
0005433123698	7646	6	4A
0005433123684	7646	7	4E
0005433123682	7646	8	5E
0005433123697	7646	9	6A
0005433123686	7646	10	6E
0005433123680	7646	11	7A
0005433123696	7646	12	7C
0005433123694	7646	13	7E
0005433123689	7646	14	10D
0005433123693	7646	15	14A
0005433123695	7646	16	14D
0005433123688	7646	17	16C
0005433123691	7646	18	16D
0005433123685	7646	19	17E
0005433123683	7646	20	19D
0005432720584	7647	1	1A
0005432692702	7647	2	1C
0005432692698	7647	3	1D
0005432720576	7647	4	1F
0005432720575	7647	5	2A
0005432692715	7647	6	2C
0005433449707	7647	7	2D
0005432720591	7647	8	2F
0005432692700	7647	9	3A
0005432692689	7647	10	3C
0005433449699	7647	11	3F
0005432692701	7647	12	4A
0005432692691	7647	13	4C
0005432692697	7647	14	4D
0005432692703	7647	15	4E
0005432720583	7647	16	4F
0005432692690	7647	17	5A
0005432692708	7647	18	5C
0005433449708	7647	19	5D
0005432692692	7647	20	5E
0005432720568	7647	21	5F
0005432692711	7647	22	6A
0005432692695	7647	23	6C
0005432720573	7647	24	6D
0005432720565	7647	25	6F
0005433449715	7647	26	7A
0005432720572	7647	27	7C
0005433449709	7647	28	7D
0005432692705	7647	29	7E
0005432720566	7647	30	7F
0005432720569	7647	31	8A
0005432692686	7647	32	8D
0005432692714	7647	33	8E
0005432071538	7647	34	8F
0005433449712	7647	35	9D
0005433449703	7647	36	9E
0005433449706	7647	37	10A
0005432720587	7647	38	10C
0005433449713	7647	39	10D
0005432692694	7647	40	10E
0005433449716	7647	41	10F
0005433449705	7647	42	11A
0005432720578	7647	43	11C
0005432692709	7647	44	11D
0005433449700	7647	45	11E
0005433449714	7647	46	11F
0005432692693	7647	47	12A
0005433449704	7647	48	12C
0005432720582	7647	49	12D
0005432720590	7647	50	12E
0005432720580	7647	51	13A
0005432720567	7647	52	13E
0005432720589	7647	53	13F
0005432720579	7647	54	14A
0005432720581	7647	55	14D
0005433449695	7647	56	14E
0005432071537	7647	57	14F
0005432692696	7647	58	15A
0005433449697	7647	59	15C
0005432720586	7647	60	15D
0005432692712	7647	61	15E
0005432692688	7647	62	15F
0005433449711	7647	63	16A
0005433449710	7647	64	16C
0005432720570	7647	65	16D
0005433449696	7647	66	16E
0005432720588	7647	67	16F
0005432692706	7647	68	17C
0005432692716	7647	69	17D
0005432692699	7647	70	17F
0005432720574	7647	71	18A
0005432720577	7647	72	18C
0005433449702	7647	73	18D
0005432692704	7647	74	18F
0005432692710	7647	75	19A
0005432720585	7647	76	19C
0005433449701	7647	77	19D
0005433449698	7647	78	19E
0005432692707	7647	79	19F
0005432692713	7647	80	20A
0005432720592	7647	81	20C
0005432720571	7647	82	20D
0005432692687	7647	83	20E
0005433449588	30410	1	5E
0005432692565	30410	2	12D
0005433449604	30410	3	14E
0005433449605	30410	4	15F
0005432720470	30409	1	1A
0005432720451	30409	2	1F
0005433123575	30409	3	5D
0005433722138	30409	4	5E
0005433722133	30409	5	6F
0005432720452	30409	6	9D
0005432720461	30409	7	11F
0005433722135	30409	8	12A
0005433722140	30409	9	13E
0005433722139	30409	10	15A
0005432720460	30409	11	16A
0005433722136	30409	12	16D
0005433722137	30409	13	17F
0005433722132	30409	14	18F
0005433722134	30409	15	20C
0005432720462	30409	16	20F
0005434586289	1353	1	1D
0005433524903	1353	2	1F
0005434586297	1353	3	2C
0005434586313	1353	4	2F
0005433192841	1353	5	3C
0005433524907	1353	6	4A
0005434586312	1353	7	4D
0005434513547	1353	8	4E
0005432270968	1353	9	5C
0005434586294	1353	10	5E
0005433724749	1353	11	6E
0005434586292	1353	12	6D
0005434586298	1353	13	6F
0005434586290	1353	14	7C
0005434586305	1353	15	7E
0005433524901	1353	16	7F
0005434586302	1353	17	8A
0005433524904	1353	18	8C
0005434514935	1353	19	8E
0005433724750	1353	20	9C
0005434586306	1353	21	9D
0005434586309	1353	22	9E
0005434513548	1353	23	9F
0005433192826	1353	24	10A
0005434586310	1353	25	10D
0005434586288	1353	26	10E
0005434586307	1353	27	11A
0005433524905	1353	28	11C
0005433524902	1353	29	11E
0005434586308	1353	30	12A
0005434586293	1353	31	11F
0005433724748	1353	32	12C
0005434586303	1353	33	12D
0005434586300	1353	34	12E
0005434586295	1353	35	12F
0005434586296	1353	36	13E
0005433524911	1353	37	13F
0005434586291	1353	38	14A
0005434586301	1353	39	14E
0005433524906	1353	40	15A
0005433524909	1353	41	15D
0005433724751	1353	42	15E
0005432270970	1353	43	16F
0005432270969	1353	44	17A
0005434586311	1353	45	17C
0005434514934	1353	46	17E
0005433524908	1353	47	18D
0005434586304	1353	48	19A
0005434514936	1353	49	19F
0005433724752	1353	50	20A
0005434586299	1353	51	20C
0005433524910	1353	52	20F
0005432927913	18501	1	1F
0005433192889	18501	2	3C
0005432927911	18501	3	3F
0005432968811	18501	4	4D
0005433192888	18501	5	4E
0005434586160	18501	6	6D
0005433192886	18501	7	7A
0005433192880	18501	8	7D
0005433192887	18501	9	8E
0005433192878	18501	10	9D
0005432968812	18501	11	9E
0005433192884	18501	12	10E
0005433192883	18501	13	11C
0005433192879	18501	14	12D
0005433192881	18501	15	12F
0005433192885	18501	16	13A
0005433192890	18501	17	14E
0005433192877	18501	18	15A
0005432927909	18501	19	15E
0005433192882	18501	20	16A
0005432927910	18501	21	16F
0005432927912	18501	22	18F
0005434343738	11452	1	1A
0005434343745	11452	2	1B
0005434343736	11452	3	1C
0005434343744	11452	4	1D
0005434343729	11452	5	2A
0005434343730	11452	6	2C
0005434343754	11452	7	2D
0005434343750	11452	8	3A
0005434343757	11452	9	3C
0005434343734	11452	10	3D
0005434343758	11452	11	4A
0005434142562	11452	12	4B
0005434343751	11452	13	4C
0005434343726	11452	14	4D
0005434343748	11452	15	5A
0005434142564	11452	16	5B
0005434343735	11452	17	5C
0005434142561	11452	18	5D
0005434343727	11452	19	6A
0005434343741	11452	20	6B
0005434343760	11452	21	6C
0005434343759	11452	22	6D
0005434343728	11452	23	7A
0005434343740	11452	24	7B
0005434343731	11452	25	7C
0005434343746	11452	26	7D
0005434343739	11452	27	18A
0005434142563	11452	28	18B
0005434343725	11452	29	18C
0005434343732	11452	30	18D
0005434343743	11452	31	19A
0005434343755	11452	32	19B
0005434343737	11452	33	20A
0005434343749	11452	34	20D
0005434343756	11452	35	21A
0005434343752	11452	36	21C
0005434343747	11452	37	22A
0005434343753	11452	38	22B
0005434343742	11452	39	22C
0005434343733	11452	40	23A
0005435824302	1274	1	1C
0005435824300	1274	2	1A
0005435824299	1274	3	2F
0005435824295	1274	4	3D
0005435824297	1274	5	4A
0005435824316	1274	6	4F
0005435824288	1274	7	6B
0005435824293	1274	8	7A
0005433415385	1274	9	7D
0005435824315	1274	10	7F
0005435824305	1274	11	8D
0005432284523	1274	12	8C
0005435824304	1274	13	9A
0005435824301	1274	14	10C
0005435824306	1274	15	10B
0005433415426	1274	16	10E
0005435824312	1274	17	10F
0005435824290	1274	18	11A
0005435824291	1274	19	11F
0005433415383	1274	20	12C
0005435824298	1274	21	13A
0005435824307	1274	22	12F
0005435824310	1274	23	13E
0005435824308	1274	24	14C
0005435824289	1274	25	16C
0005435824292	1274	26	16D
0005435824294	1274	27	17B
0005435824309	1274	28	18C
0005435824296	1274	29	18D
0005435824313	1274	30	18F
0005433415384	1274	31	19E
0005435824303	1274	32	19F
0005435824314	1274	33	20E
0005432284522	1274	34	20F
0005435824311	1274	35	21D
0005433415472	18000	1	1F
0005433415461	18000	2	3A
0005433415468	18000	3	3D
0005433415473	18000	4	4C
0005433415464	18000	5	6E
0005433415474	18000	6	7D
0005435824200	18000	7	8D
0005435824161	18000	8	8C
0005433415470	18000	9	8E
0005433415466	18000	10	9A
0005433415465	18000	11	9E
0005433415463	18000	12	9D
0005435824191	18000	13	11A
0005435824160	18000	14	11B
0005435824202	18000	15	12E
0005433415467	18000	16	13A
0005435824204	18000	17	13B
0005435824203	18000	18	13E
0005433415471	18000	19	13F
0005433415460	18000	20	16A
0005435824205	18000	21	16B
0005435824201	18000	22	18A
0005433415475	18000	23	19F
0005433415469	18000	24	21C
0005433415462	18000	25	21E
0005434460470	12578	1	1B
0005434461615	12578	2	2A
0005434461617	12578	3	2C
0005434461619	12578	4	3A
0005434461612	12578	5	5B
0005434461614	12578	6	5D
0005434461618	12578	7	6B
0005434460472	12578	8	7A
0005434461611	12578	9	7B
0005434461613	12578	10	18D
0005434461620	12578	11	19C
0005434460469	12578	12	19D
0005434460474	12578	13	20A
0005434460473	12578	14	20B
0005434460471	12578	15	20C
0005434460475	12578	16	21A
0005434461616	12578	17	22D
0005434460476	12578	18	23B
0005432783113	5652	1	1A
0005432783167	5652	2	1C
0005432783147	5652	3	2A
0005432783138	5652	4	2D
0005432783136	5652	5	2F
0005432783158	5652	6	3A
0005432783141	5652	7	3C
0005432783120	5652	8	3D
0005432783140	5652	9	3F
0005432783160	5652	10	4E
0005432783163	5652	11	4F
0005432783117	5652	12	5A
0005432783162	5652	13	5D
0005432783155	5652	14	5E
0005432783159	5652	15	6A
0005432783121	5652	16	6C
0005432783125	5652	17	6E
0005432783161	5652	18	7A
0005432783124	5652	19	7D
0005432783127	5652	20	7E
0005432783154	5652	21	8A
0005435242400	5652	22	8C
0005432783144	5652	23	8D
0005432783143	5652	24	9A
0005432783118	5652	25	10A
0005432783151	5652	26	10C
0005432783139	5652	27	10D
0005432783115	5652	28	10F
0005432783164	5652	29	11A
0005432783145	5652	30	11C
0005432783157	5652	31	11F
0005432783122	5652	32	12A
0005432783165	5652	33	12E
0005432783148	5652	34	12F
0005432783119	5652	35	13A
0005435242401	5652	36	13D
0005432783142	5652	37	13E
0005432783133	5652	38	13F
0005432783130	5652	39	14C
0005432783132	5652	40	14D
0005432783149	5652	41	14E
0005432783128	5652	42	15A
0005432783114	5652	43	15C
0005432783146	5652	44	16A
0005432783123	5652	45	16D
0005432783131	5652	46	16F
0005432783135	5652	47	17A
0005432783152	5652	48	17C
0005432143946	5652	49	17D
0005432783150	5652	50	17E
0005432783134	5652	51	18A
0005432783168	5652	52	18C
0005432783166	5652	53	18E
0005432783116	5652	54	19D
0005432783129	5652	55	19E
0005432783153	5652	56	19F
0005432783126	5652	57	20A
0005432143947	5652	58	20C
0005432783156	5652	59	20D
0005432783137	5652	60	20E
0005432143948	5652	61	20F
0005435242498	15360	1	1A
0005435242520	15360	2	1D
0005435242514	15360	3	2A
0005435476672	15360	4	2C
0005435242500	15360	5	2D
0005435242502	15360	6	2F
0005435242508	15360	7	3F
0005435476676	15360	8	4C
0005435476677	15360	9	4D
0005435242513	15360	10	5E
0005435476670	15360	11	6F
0005435242523	15360	12	7A
0005432782863	15360	13	7C
0005435242511	15360	14	7D
0005435242519	15360	15	7E
0005435242504	15360	16	8A
0005435242510	15360	17	8E
0005435242512	15360	18	8F
0005435242521	15360	19	9C
0005435242499	15360	20	9D
0005435242522	15360	21	10A
0005435242526	15360	22	10C
0005435242505	15360	23	10D
0005435242503	15360	24	10F
0005435242517	15360	25	11D
0005435476669	15360	26	12E
0005435242509	15360	27	13A
0005435242524	15360	28	13D
0005435476679	15360	29	13F
0005435242516	15360	30	14D
0005435476675	15360	31	14E
0005435476674	15360	32	16A
0005435242515	15360	33	16F
0005435242525	15360	34	17A
0005435476678	15360	35	17D
0005435242518	15360	36	18A
0005435242501	15360	37	19A
0005435242506	15360	38	19C
0005435242507	15360	39	19D
0005435476671	15360	40	19E
0005435476673	15360	41	20C
0005435476680	15360	42	20F
0005432848138	4367	1	1C
0005434463903	4367	2	2B
0005432848137	4367	3	2C
0005432848133	4367	4	3A
0005432848141	4367	5	3C
0005432848135	4367	6	3D
0005435850772	4367	7	4A
0005435850775	4367	8	4B
0005432848136	4367	9	4D
0005432848140	4367	10	5C
0005432848132	4367	11	7B
0005432848134	4367	12	7C
0005434462764	4367	13	18A
0005432848143	4367	14	18B
0005432848142	4367	15	18C
0005432848131	4367	16	19D
0005435850750	4367	17	20B
0005432848139	4367	18	21C
0005435850751	4367	19	22B
0005432848129	4367	20	22D
0005432848130	4367	21	23A
0005432848058	28843	1	1D
0005435850800	28843	2	2C
0005435850798	28843	3	3A
0005435850804	28843	4	4C
0005435850796	28843	5	7A
0005434461608	28843	6	7C
0005435850801	28843	7	18C
0005435850797	28843	8	20A
0005435850799	28843	9	20C
0005435850802	28843	10	22A
0005435850803	28843	11	22D
0005435850795	28843	12	23B
0005433496604	6281	1	1A
0005434925431	6281	2	1C
0005433496588	6281	3	1D
0005433496591	6281	4	1F
0005434443509	6281	5	2C
0005433496600	6281	6	2D
0005434925430	6281	7	2F
0005433496612	6281	8	3A
0005433496586	6281	9	3C
0005434925422	6281	10	3D
0005434443519	6281	11	3F
0005434925432	6281	12	4A
0005433496599	6281	13	4C
0005434443508	6281	14	4D
0005434925421	6281	15	4E
0005434443518	6281	16	4F
0005434925420	6281	17	5A
0005434925424	6281	18	5D
0005434443517	6281	19	5E
0005434925403	6281	20	5F
0005434925427	6281	21	6A
0005434925398	6281	22	6C
0005433496594	6281	23	6D
0005434443521	6281	24	6E
0005433496598	6281	25	6F
0005433496608	6281	26	7A
0005434443520	6281	27	7C
0005433496596	6281	28	7D
0005434925415	6281	29	7E
0005434443511	6281	30	7F
0005433496581	6281	31	8A
0005434925423	6281	32	8C
0005434925404	6281	33	8D
0005433496609	6281	34	8E
0005434925408	6281	35	8F
0005434443507	6281	36	9A
0005434925407	6281	37	9E
0005434925402	6281	38	9F
0005433496587	6281	39	10A
0005434925401	6281	40	10C
0005434925410	6281	41	10E
0005434925426	6281	42	10F
0005434925417	6281	43	11A
0005434925400	6281	44	11C
0005433496607	6281	45	11D
0005433496578	6281	46	11E
0005433496582	6281	47	11F
0005432075187	6281	48	12A
0005433496603	6281	49	12C
0005434443513	6281	50	12D
0005433496590	6281	51	12E
0005434925412	6281	52	12F
0005434925399	6281	53	13A
0005433496589	6281	54	13C
0005433496605	6281	55	13E
0005434925419	6281	56	13D
0005433496584	6281	57	14A
0005434443510	6281	58	14C
0005432075189	6281	59	14D
0005433496579	6281	60	14E
0005434925409	6281	61	15A
0005433496597	6281	62	15C
0005434925406	6281	63	15D
0005432075188	6281	64	15F
0005434443516	6281	65	16A
0005434925418	6281	66	16C
0005434443514	6281	67	16D
0005433496593	6281	68	16E
0005433496606	6281	69	16F
0005433496602	6281	70	17A
0005434925414	6281	71	17C
0005434925413	6281	72	17D
0005434925397	6281	73	17E
0005433496585	6281	74	17F
0005433496610	6281	75	18A
0005433496583	6281	76	18C
0005434925429	6281	77	18D
0005434443512	6281	78	18E
0005434925428	6281	79	18F
0005433496580	6281	80	19A
0005433496592	6281	81	19C
0005433496601	6281	82	19D
0005434925416	6281	83	19E
0005434925425	6281	84	19F
0005433496595	6281	85	20A
0005434443515	6281	86	20C
0005434925405	6281	87	20D
0005434925411	6281	88	20E
0005433496611	6281	89	20F
0005433496423	20367	1	1A
0005434443430	20367	2	2C
0005433496422	20367	3	3F
0005433496497	20367	4	4E
0005433496472	20367	5	6C
0005433496471	20367	6	9F
0005434443432	20367	7	11C
0005434443429	20367	8	12A
0005434443431	20367	9	18A
0005433496440	20367	10	20C
0005435242534	12206	1	1D
0005435242539	12206	2	2C
0005435242546	12206	3	2D
0005435242547	12206	4	3D
0005435242540	12206	5	4E
0005435242536	12206	6	4F
0005432782869	12206	7	5D
0005435242549	12206	8	5F
0005435242537	12206	9	6A
0005435242538	12206	10	6D
0005435242550	12206	11	7F
0005435242530	12206	12	8D
0005432782847	12206	13	8E
0005435242535	12206	14	8F
0005432783022	12206	15	9A
0005435242541	12206	16	9D
0005435242553	12206	17	9F
0005432782890	12206	18	10A
0005435242529	12206	19	10C
0005435242527	12206	20	11F
0005435242531	12206	21	13E
0005435242533	12206	22	13F
0005435242552	12206	23	14A
0005435242532	12206	24	14E
0005435242542	12206	25	15A
0005432782844	12206	26	16A
0005435242544	12206	27	16F
0005435242543	12206	28	17A
0005435242551	12206	29	19D
0005435242548	12206	30	19E
0005432782870	12206	31	20C
0005435242528	12206	32	20D
0005435242545	12206	33	20E
0005432783069	15404	1	1A
0005432783068	15404	2	1D
0005432783097	15404	3	1F
0005432783076	15404	4	2D
0005432783070	15404	5	2F
0005432783107	15404	6	3A
0005432783080	15404	7	3D
0005432783071	15404	8	4A
0005432783082	15404	9	4C
0005432783095	15404	10	4E
0005432783067	15404	11	5A
0005432783063	15404	12	5C
0005432783084	15404	13	5F
0005432783096	15404	14	6F
0005432783112	15404	15	7A
0005432783091	15404	16	7C
0005432783086	15404	17	7D
0005432783106	15404	18	7E
0005432783074	15404	19	7F
0005432783099	15404	20	8D
0005432783103	15404	21	8E
0005432783101	15404	22	9D
0005432783090	15404	23	10D
0005432783089	15404	24	10F
0005432783058	15404	25	11A
0005432783094	15404	26	11C
0005432783087	15404	27	11E
0005432783092	15404	28	11F
0005432783109	15404	29	12C
0005432783060	15404	30	12F
0005432783075	15404	31	13C
0005432783093	15404	32	13E
0005432783108	15404	33	13F
0005432783100	15404	34	14A
0005432783072	15404	35	14C
0005432783062	15404	36	14D
0005432783066	15404	37	14F
0005432783098	15404	38	15A
0005432783088	15404	39	15C
0005432783102	15404	40	16C
0005432783105	15404	41	16D
0005432783085	15404	42	16E
0005432783104	15404	43	17C
0005432783083	15404	44	17D
0005432783059	15404	45	17F
0005432783111	15404	46	18A
0005432783081	15404	47	18D
0005432783061	15404	48	18E
0005432783064	15404	49	18F
0005432783078	15404	50	19A
0005432783110	15404	51	19D
0005432783073	15404	52	19F
0005432783065	15404	53	20C
0005432783077	15404	54	20D
0005432783079	15404	55	20E
0005434876788	10074	1	2C
0005434910081	10074	2	2F
0005435913880	10074	3	3D
0005434758853	10074	4	6B
0005435913885	10074	5	6A
0005435913875	10074	6	7B
0005435913883	10074	7	7E
0005434876789	10074	8	7F
0005434876622	10074	9	8B
0005434876655	10074	10	8D
0005434876608	10074	11	9B
0005434910080	10074	12	9D
0005434910079	10074	13	10E
0005435913877	10074	14	11C
0005435913884	10074	15	12E
0005434876568	10074	16	13A
0005434758854	10074	17	13B
0005435913887	10074	18	14E
0005435913876	10074	19	15F
0005435913878	10074	20	16C
0005435913886	10074	21	16F
0005435913881	10074	22	17B
0005435913888	10074	23	17D
0005435913879	10074	24	17E
0005435913882	10074	25	19A
0005434876654	10074	26	20D
0005434877123	14631	1	1A
0005434877042	14631	2	1F
0005434877067	14631	3	1D
0005434877053	14631	4	1C
0005434877069	14631	5	2A
0005434877068	14631	6	2D
0005434877085	14631	7	2C
0005434877105	14631	8	3A
0005434877077	14631	9	2F
0005434877065	14631	10	3D
0005434877104	14631	11	3C
0005434877113	14631	12	4A
0005434877098	14631	13	3F
0005434877082	14631	14	4D
0005434877091	14631	15	4C
0005434877109	14631	16	4F
0005434877136	14631	17	5D
0005434877103	14631	18	5C
0005434877086	14631	19	5A
0005434877064	14631	20	5F
0005434877124	14631	21	6B
0005434877102	14631	22	6A
0005434877059	14631	23	6D
0005434877051	14631	24	6C
0005434877044	14631	25	6E
0005434877093	14631	26	7A
0005434877047	14631	27	6F
0005434877056	14631	28	7C
0005434877099	14631	29	7B
0005434877050	14631	30	7D
0005434877122	14631	31	8A
0005434758864	14631	32	7F
0005434877052	14631	33	8C
0005434877070	14631	34	8D
0005434877089	14631	35	8F
0005434877097	14631	36	9A
0005434877108	14631	37	9D
0005434877084	14631	38	9C
0005434877080	14631	39	9E
0005434877125	14631	40	10A
0005434877071	14631	41	9F
0005434877126	14631	42	10C
0005434877110	14631	43	10E
0005434877049	14631	44	10D
0005434877112	14631	45	10F
0005434877114	14631	46	11C
0005434877062	14631	47	11B
0005434877048	14631	48	11D
0005434877088	14631	49	11F
0005434877079	14631	50	11E
0005434877043	14631	51	12C
0005434877045	14631	52	12D
0005434877111	14631	53	13C
0005434877072	14631	54	13B
0005434877118	14631	55	13E
0005434877120	14631	56	13D
0005434877135	14631	57	14A
0005434877132	14631	58	13F
0005434877119	14631	59	14C
0005434877087	14631	60	14B
0005434877092	14631	61	14D
0005434877095	14631	62	14F
0005434877117	14631	63	14E
0005434877040	14631	64	15B
0005434877116	14631	65	15A
0005434877115	14631	66	15C
0005434877054	14631	67	15F
0005434877081	14631	68	15E
0005434877060	14631	69	15D
0005434877101	14631	70	16A
0005434877074	14631	71	16C
0005434877078	14631	72	16B
0005434877083	14631	73	16D
0005434877100	14631	74	16F
0005434877128	14631	75	16E
0005434877046	14631	76	17A
0005434877134	14631	77	17D
0005434877061	14631	78	17C
0005434877055	14631	79	17F
0005434877073	14631	80	17E
0005434877137	14631	81	18A
0005434758865	14631	82	18C
0005434877075	14631	83	18B
0005434877066	14631	84	18E
0005434877058	14631	85	18D
0005434877094	14631	86	19A
0005434877130	14631	87	19C
0005434877063	14631	88	19B
0005434877041	14631	89	19E
0005434877076	14631	90	19D
0005434877121	14631	91	20A
0005434877129	14631	92	19F
0005434877131	14631	93	20C
0005434877133	14631	94	20B
0005434877057	14631	95	20D
0005434877107	14631	96	20F
0005434877106	14631	97	21B
0005434877096	14631	98	21A
0005434877127	14631	99	21E
0005434877090	14631	100	21F
0005435659996	9237	1	1A
0005435660000	9237	2	2A
0005435659998	9237	3	3A
0005435660002	9237	4	3C
0005435659995	9237	5	3D
0005435660003	9237	6	4A
0005435659997	9237	7	5B
0005435660005	9237	8	5C
0005435659994	9237	9	18B
0005435659999	9237	10	18C
0005435660004	9237	11	19C
0005435660001	9237	12	22A
0005434251844	24674	1	2B
0005434251850	24674	2	3B
0005434251845	24674	3	4C
0005434251851	24674	4	5A
0005434251847	24674	5	5C
0005434251853	24674	6	6A
0005434251846	24674	7	18D
0005434251854	24674	8	20B
0005434251852	24674	9	21A
0005434251848	24674	10	22A
0005434251849	24674	11	22C
0005433679994	2797	1	1F
0005433679962	2797	2	2A
0005433679993	2797	3	2C
0005432222718	2797	4	3A
0005433679968	2797	5	3C
0005433679978	2797	6	3D
0005432966503	2797	7	3F
0005433679990	2797	8	4C
0005433679973	2797	9	4D
0005433680001	2797	10	4F
0005433679985	2797	11	5D
0005433684393	2797	12	5F
0005432222716	2797	13	6C
0005433679971	2797	14	6F
0005433679963	2797	15	7A
0005433679981	2797	16	7C
0005433679970	2797	17	7D
0005433679988	2797	18	7E
0005433679977	2797	19	7F
0005433679967	2797	20	8C
0005432966504	2797	21	8F
0005433679983	2797	22	9A
0005433679965	2797	23	9C
0005433679995	2797	24	9D
0005433679991	2797	25	9F
0005432222719	2797	26	10C
0005433679986	2797	27	10D
0005433679996	2797	28	10E
0005433679982	2797	29	10F
0005433679956	2797	30	11D
0005433679955	2797	31	11E
0005433679961	2797	32	12A
0005433679999	2797	33	12E
0005433679984	2797	34	13A
0005433679979	2797	35	13C
0005432222715	2797	36	13F
0005433679992	2797	37	14C
0005433679998	2797	38	14D
0005432222714	2797	39	14E
0005432966494	2797	40	14F
0005433679980	2797	41	15A
0005433680002	2797	42	15C
0005433679957	2797	43	15F
0005433679958	2797	44	16C
0005432222717	2797	45	16E
0005433679997	2797	46	16F
0005433679972	2797	47	17A
0005433679960	2797	48	17C
0005433679976	2797	49	17D
0005433679987	2797	50	17E
0005433679975	2797	51	18A
0005433679959	2797	52	18D
0005433679966	2797	53	18F
0005433684394	2797	54	19A
0005433679964	2797	55	19D
0005433679989	2797	56	19E
0005433680000	2797	57	20A
0005433679969	2797	58	20C
0005433679954	2797	59	20D
0005433679974	2797	60	20F
0005432966610	29158	1	1A
0005433679753	29158	2	1D
0005432966618	29158	3	3C
0005433679780	29158	4	3F
0005432966628	29158	5	4A
0005432966617	29158	6	4D
0005432966621	29158	7	4F
0005432966627	29158	8	5C
0005432966615	29158	9	5D
0005432966613	29158	10	7A
0005432966635	29158	11	8F
0005432966634	29158	12	9C
0005433690890	29158	13	9D
0005432966616	29158	14	9E
0005432966624	29158	15	10C
0005432966620	29158	16	10D
0005433679828	29158	17	11A
0005432966611	29158	18	11F
0005432966612	29158	19	12F
0005432966625	29158	20	13A
0005432966622	29158	21	13C
0005433679748	29158	22	13F
0005432966623	29158	23	14A
0005432966629	29158	24	14C
0005433679725	29158	25	14E
0005432966626	29158	26	15C
0005432966619	29158	27	15E
0005432966631	29158	28	15F
0005432005178	29158	29	16A
0005432005179	29158	30	16D
0005432966633	29158	31	16E
0005432966632	29158	32	17A
0005432966630	29158	33	18D
0005433690893	29158	34	19C
0005433679781	29158	35	19E
0005433679752	29158	36	20A
0005432966614	29158	37	20D
0005433613745	9284	1	1A
0005433577640	9284	2	1C
0005433633385	9284	3	1F
0005433633381	9284	4	1D
0005433613739	9284	5	2A
0005433613754	9284	6	2D
0005433613729	9284	7	2F
0005432756807	9284	8	3A
0005433613720	9284	9	4A
0005433613738	9284	10	3F
0005433577641	9284	11	4D
0005433613712	9284	12	4C
0005432145083	9284	13	5A
0005433613719	9284	14	4F
0005433613707	9284	15	5C
0005433577632	9284	16	5F
0005433577629	9284	17	5D
0005433613752	9284	18	6A
0005432756804	9284	19	6C
0005433633384	9284	20	7C
0005433633376	9284	21	7D
0005433613744	9284	22	8A
0005433613742	9284	23	7F
0005433613733	9284	24	8D
0005433577636	9284	25	8C
0005433613698	9284	26	8E
0005433613690	9284	27	8F
0005433633364	9284	28	9A
0005433633373	9284	29	9B
0005433577630	9284	30	9E
0005433613697	9284	31	9D
0005433613711	9284	32	10A
0005432755033	9284	33	9F
0005433613700	9284	34	10B
0005433613726	9284	35	10E
0005433613737	9284	36	10D
0005433633369	9284	37	11A
0005433633370	9284	38	10F
0005433613691	9284	39	11C
0005433633355	9284	40	11D
0005433613709	9284	41	12A
0005433613702	9284	42	11F
0005433577637	9284	43	12B
0005433633378	9284	44	12C
0005433633366	9284	45	12D
0005433613757	9284	46	12F
0005433613708	9284	47	12E
0005433613688	9284	48	13A
0005433613693	9284	49	13B
0005433577638	9284	50	13D
0005433613689	9284	51	14A
0005433613740	9284	52	13F
0005433633368	9284	53	14D
0005433613750	9284	54	14E
0005433633379	9284	55	14F
0005433633359	9284	56	15A
0005433613714	9284	57	15C
0005433577642	9284	58	15D
0005433613704	9284	59	15E
0005433577635	9284	60	16A
0005433577639	9284	61	16B
0005433613713	9284	62	16D
0005432755032	9284	63	16E
0005433633367	9284	64	16F
0005433613760	9284	65	17A
0005433633362	9284	66	17C
0005433633374	9284	67	17E
0005433613694	9284	68	18A
0005433613736	9284	69	18B
0005433577631	9284	70	18C
0005433633358	9284	71	18E
0005433613721	9284	72	18F
0005433613743	9284	73	19B
0005433633371	9284	74	19D
0005433613749	9284	75	19C
0005433577634	9284	76	19E
0005433613718	9284	77	20B
0005433613723	9284	78	20E
0005433613756	9284	79	20D
0005432756806	9284	80	20F
0005433633383	9284	81	21C
0005433613725	9284	82	21B
0005433613717	9284	83	21D
0005433613710	9284	84	21E
0005432145085	9284	85	21F
0005433613695	9284	86	22A
0005433633363	9284	87	22D
0005433613755	9284	88	22C
0005433613727	9284	89	22E
0005432756805	9284	90	22F
0005433613747	9284	91	23A
0005433613759	9284	92	23B
0005432145084	9284	93	23E
0005433613741	9284	94	24A
0005433613751	9284	95	24B
0005433613703	9284	96	24E
0005433577633	9284	97	24D
0005433613746	9284	98	25A
0005433613748	9284	99	25C
0005433633372	9284	100	25B
0005433613735	9284	101	25D
0005433613722	9284	102	25E
0005433633365	9284	103	26A
0005433613732	9284	104	25F
0005433613706	9284	105	26B
0005433613730	9284	106	26C
0005433613699	9284	107	26E
0005433633361	9284	108	26F
0005433633356	9284	109	27B
0005433613734	9284	110	27A
0005433613728	9284	111	27C
0005433633375	9284	112	27E
0005433633387	9284	113	28A
0005433613687	9284	114	28B
0005433613701	9284	115	28D
0005433633386	9284	116	28C
0005433613705	9284	117	28F
0005433613716	9284	118	29A
0005433633357	9284	119	29C
0005433613724	9284	120	29B
0005433613696	9284	121	29D
0005433613731	9284	122	29E
0005433613753	9284	123	30A
0005433633382	9284	124	29F
0005433633377	9284	125	30E
0005433613692	9284	126	31A
0005432755034	9284	127	30F
0005433613758	9284	128	31B
0005433633360	9284	129	31D
0005433633380	9284	130	31E
0005433613715	9284	131	31F
0005434163504	25265	1	2D
0005434273055	25265	2	4F
0005434163510	25265	3	10A
0005434163509	25265	4	10F
0005433613471	25265	5	11F
0005434163511	25265	6	12B
0005434163508	25265	7	13D
0005433613610	25265	8	14F
0005434272169	25265	9	16E
0005434163512	25265	10	16F
0005434163505	25265	11	18C
0005434273056	25265	12	18E
0005434163507	25265	13	19E
0005433633216	25265	14	22C
0005434272171	25265	15	25C
0005433633217	25265	16	27B
0005434272170	25265	17	27D
0005434163513	25265	18	28A
0005433577610	25265	19	29B
0005434163503	25265	20	31A
0005434163506	25265	21	31F
0005432184915	4201	1	3C
0005435986680	4201	2	4B
0005432184914	4201	3	4G
0005435986682	4201	4	21E
0005435986681	4201	5	29G
0005432184916	4201	6	35F
0005435856152	26613	1	2B
0005435947071	26613	2	3C
0005435947083	26613	3	4A
0005435947074	26613	4	4G
0005435947076	26613	5	9B
0005435947072	26613	6	13B
0005435787329	26613	7	13G
0005432571279	26613	8	14D
0005435787328	26613	9	15D
0005435947079	26613	10	15F
0005435947077	26613	11	17E
0005432571278	26613	12	22H
0005435947078	26613	13	23B
0005435856151	26613	14	23F
0005435947075	26613	15	24B
0005435947084	26613	16	24G
0005435947080	26613	17	27D
0005435947085	26613	18	28F
0005435856154	26613	19	30F
0005435947073	26613	20	32E
0005435947082	26613	21	33E
0005435856153	26613	22	33H
0005432571277	26613	23	35G
0005432571276	26613	24	36B
0005435947081	26613	25	37D
0005432238861	340	1	2D
0005432947787	340	2	2F
0005432238860	340	3	3A
0005433568338	340	4	3C
0005433568336	340	5	4A
0005433568343	340	6	5A
0005433568325	340	7	6A
0005432947772	340	8	5F
0005433568322	340	9	6D
0005433568313	340	10	7A
0005433568346	340	11	7C
0005433568314	340	12	7F
0005433568359	340	13	8E
0005433568323	340	14	8F
0005432238858	340	15	9C
0005433568329	340	16	10A
0005433568320	340	17	9F
0005433568363	340	18	10D
0005433074206	340	19	10E
0005433568315	340	20	11A
0005433568341	340	21	11F
0005433568321	340	22	11E
0005433568332	340	23	12A
0005433568352	340	24	12B
0005433568365	340	25	12D
0005433568347	340	26	13B
0005433568344	340	27	13D
0005433568364	340	28	13F
0005433568372	340	29	14C
0005433568311	340	30	14B
0005433568349	340	31	14F
0005433568351	340	32	15B
0005433568345	340	33	15A
0005433568317	340	34	15E
0005433568335	340	35	16B
0005433568361	340	36	16E
0005433568367	340	37	17B
0005433568355	340	38	17A
0005433568368	340	39	17C
0005433568339	340	40	17F
0005433568369	340	41	17E
0005433568370	340	42	18B
0005433568327	340	43	18F
0005432238859	340	44	20A
0005433568326	340	45	19E
0005433568316	340	46	20D
0005433568371	340	47	20E
0005433568357	340	48	21A
0005433568310	340	49	21B
0005433568312	340	50	21E
0005433568362	340	51	21F
0005432947786	340	52	22B
0005433568353	340	53	22A
0005433568319	340	54	22E
0005433568358	340	55	22F
0005433568354	340	56	23B
0005433568366	340	57	23D
0005433568308	340	58	23C
0005433568337	340	59	24A
0005433568333	340	60	24B
0005433074207	340	61	24C
0005433568350	340	62	24E
0005433568328	340	63	25C
0005433568330	340	64	25D
0005433568360	340	65	25E
0005433568356	340	66	25F
0005433568324	340	67	26C
0005433568348	340	68	27A
0005433568373	340	69	27D
0005433568318	340	70	28C
0005433568342	340	71	28E
0005433568309	340	72	28F
0005433568334	340	73	29E
0005433568331	340	74	30A
0005432238863	340	75	30D
0005433568340	340	76	31D
0005432238862	340	77	31F
0005433074354	11594	1	1C
0005433134081	11594	2	1A
0005433074364	11594	3	1F
0005432947938	11594	4	1D
0005432947955	11594	5	3A
0005433134079	11594	6	2F
0005433131653	11594	7	4A
0005432947965	11594	8	3F
0005432947936	11594	9	4F
0005433074356	11594	10	4D
0005432947963	11594	11	5A
0005433074349	11594	12	5D
0005433134080	11594	13	6F
0005432192282	11594	14	7A
0005433074362	11594	15	7C
0005433074361	11594	16	7D
0005432947931	11594	17	8A
0005433074369	11594	18	8C
0005432947940	11594	19	8B
0005432947966	11594	20	8D
0005432947962	11594	21	8F
0005432947951	11594	22	9C
0005432947953	11594	23	10B
0005432947970	11594	24	10A
0005432947948	11594	25	10D
0005432947967	11594	26	12A
0005432947954	11594	27	11F
0005432192280	11594	28	12C
0005432947971	11594	29	12B
0005433074360	11594	30	12F
0005432947957	11594	31	13C
0005433074365	11594	32	13D
0005433074343	11594	33	14A
0005433074363	11594	34	13F
0005433074367	11594	35	14B
0005432947945	11594	36	14C
0005432947949	11594	37	14E
0005432947964	11594	38	14D
0005433074342	11594	39	15A
0005432947937	11594	40	15C
0005433074357	11594	41	15B
0005432947950	11594	42	15E
0005432947944	11594	43	16A
0005432947960	11594	44	16E
0005432947946	11594	45	17B
0005432947935	11594	46	17C
0005432947932	11594	47	17E
0005433074358	11594	48	18A
0005432947956	11594	49	18D
0005433134083	11594	50	19D
0005433074350	11594	51	19E
0005432947939	11594	52	20E
0005433131651	11594	53	21D
0005432947959	11594	54	21E
0005433074344	11594	55	21F
0005433074352	11594	56	22B
0005433131650	11594	57	22C
0005433074366	11594	58	23C
0005432947930	11594	59	24A
0005432947933	11594	60	24B
0005433131652	11594	61	24C
0005432947961	11594	62	24E
0005432947958	11594	63	25A
0005432947952	11594	64	25B
0005433074347	11594	65	26A
0005432947968	11594	66	26D
0005432947934	11594	67	26C
0005432947969	11594	68	26E
0005433074353	11594	69	26F
0005433074370	11594	70	27E
0005432947947	11594	71	28A
0005432947943	11594	72	28C
0005432947941	11594	73	28B
0005432192281	11594	74	29B
0005433074345	11594	75	29D
0005433074346	11594	76	29C
0005433074351	11594	77	29E
0005433074348	11594	78	30B
0005432947942	11594	79	30D
0005433134082	11594	80	30E
0005433074368	11594	81	31B
0005433074355	11594	82	31A
0005433074359	11594	83	31D
0005433131649	11594	84	31F
0005433817426	10011	1	2A
0005433817423	10011	2	2B
0005433817425	10011	3	5B
0005433817424	10011	4	6A
0005434732937	13911	1	1A
0005434732938	13911	2	2A
0005434732939	13911	3	4B
0005434732936	13911	4	5B
0005435981785	2335	1	1A
0005433753525	2335	2	1B
0005435981764	2335	3	1G
0005433753510	2335	4	2B
0005435981766	2335	5	2G
0005435981763	2335	6	2H
0005433753535	2335	7	3C
0005435981753	2335	8	3G
0005435981745	2335	9	3F
0005432655394	2335	10	4A
0005435981737	2335	11	3H
0005432300192	2335	12	4B
0005432300195	2335	13	4F
0005435981768	2335	14	5A
0005435981776	2335	15	4H
0005433753563	2335	16	5B
0005435981742	2335	17	5G
0005435981772	2335	18	5H
0005435981771	2335	19	9B
0005432225979	2335	20	9H
0005435981748	2335	21	9G
0005435981773	2335	22	11B
0005432655398	2335	23	11A
0005433753514	2335	24	11D
0005432655391	2335	25	11E
0005433753554	2335	26	12A
0005435981746	2335	27	11H
0005435981765	2335	28	12E
0005435981750	2335	29	12H
0005433753537	2335	30	13D
0005432225980	2335	31	13B
0005435981781	2335	32	13G
0005435981777	2335	33	13F
0005433753530	2335	34	13H
0005433764654	2335	35	14E
0005433753567	2335	36	14D
0005433753558	2335	37	14F
0005435981759	2335	38	15A
0005433766594	2335	39	15E
0005433753522	2335	40	15D
0005435981761	2335	41	15F
0005433753513	2335	42	16B
0005432655388	2335	43	15H
0005433753550	2335	44	16E
0005433753560	2335	45	16F
0005432225982	2335	46	16H
0005435981769	2335	47	16G
0005432655389	2335	48	17A
0005435981738	2335	49	17B
0005433753526	2335	50	17E
0005435981767	2335	51	17H
0005433753545	2335	52	18B
0005433753520	2335	53	18A
0005432655397	2335	54	18D
0005433753528	2335	55	18F
0005433753561	2335	56	18E
0005433753515	2335	57	18G
0005432655399	2335	58	19A
0005433766593	2335	59	18H
0005433753556	2335	60	19B
0005432655395	2335	61	19D
0005435981751	2335	62	19H
0005432300194	2335	63	19G
0005435981735	2335	64	20A
0005435981749	2335	65	20E
0005433434182	2335	66	20F
0005433753534	2335	67	21A
0005433753541	2335	68	21D
0005433753519	2335	69	21G
0005432655393	2335	70	21F
0005433753524	2335	71	22A
0005433753548	2335	72	22G
0005435981754	2335	73	22F
0005435981743	2335	74	22H
0005435981756	2335	75	23F
0005433434221	2335	76	23E
0005435981787	2335	77	23H
0005433753565	2335	78	23G
0005433753518	2335	79	24B
0005433753549	2335	80	24E
0005433753529	2335	81	24G
0005432655387	2335	82	25D
0005433753539	2335	83	24H
0005435981788	2335	84	25E
0005435981755	2335	85	25F
0005433753511	2335	86	27B
0005433753553	2335	87	27E
0005435981760	2335	88	27D
0005433753516	2335	89	27G
0005432225978	2335	90	27F
0005433434197	2335	91	28A
0005435981736	2335	92	28B
0005435981786	2335	93	28E
0005435981762	2335	94	28G
0005433753562	2335	95	29B
0005433753533	2335	96	29E
0005433753536	2335	97	29D
0005433753521	2335	98	29G
0005433753543	2335	99	30B
0005433753542	2335	100	30F
0005433753540	2335	101	30G
0005435981782	2335	102	31A
0005435981757	2335	103	30H
0005432225981	2335	104	31B
0005433753551	2335	105	31E
0005433434183	2335	106	31F
0005433753566	2335	107	31H
0005435981783	2335	108	31G
0005433753559	2335	109	32A
0005432984545	2335	110	32B
0005432655396	2335	111	32E
0005433753517	2335	112	32D
0005433753544	2335	113	32F
0005432300193	2335	114	32G
0005433753555	2335	115	33A
0005435981752	2335	116	32H
0005435981778	2335	117	33B
0005435981774	2335	118	33E
0005435981758	2335	119	33F
0005433753564	2335	120	33H
0005433753523	2335	121	33G
0005435981740	2335	122	34A
0005435981780	2335	123	34D
0005432984546	2335	124	34B
0005433753552	2335	125	34F
0005435981784	2335	126	35F
0005432225983	2335	127	35E
0005432655390	2335	128	35G
0005433753531	2335	129	36A
0005435981739	2335	130	35H
0005433434198	2335	131	36D
0005433753538	2335	132	36F
0005435981747	2335	133	37A
0005435981744	2335	134	36H
0005433753527	2335	135	37B
0005432655392	2335	136	37D
0005435981779	2335	137	37G
0005433753547	2335	138	37F
0005433753532	2335	139	37H
0005435981775	2335	140	38A
0005433753546	2335	141	38E
0005433753512	2335	142	38H
0005435981741	2335	143	38G
0005435981770	2335	144	39D
0005433753557	2335	145	39E
0005434731120	26203	1	1A
0005432984698	26203	2	1C
0005433434348	26203	3	2A
0005433434337	26203	4	2F
0005434731118	26203	5	3A
0005432984679	26203	6	3F
0005432984691	26203	7	3H
0005432984674	26203	8	4F
0005432984670	26203	9	5A
0005433434341	26203	10	5F
0005432984695	26203	11	9B
0005433434332	26203	12	9G
0005432984668	26203	13	11D
0005432869445	26203	14	12D
0005432049420	26203	15	12E
0005432869442	26203	16	13B
0005432984676	26203	17	13A
0005434731117	26203	18	13D
0005433434325	26203	19	13E
0005432984678	26203	20	13F
0005432869444	26203	21	14D
0005433434327	26203	22	14E
0005434731119	26203	23	15D
0005432984692	26203	24	15F
0005432051089	26203	25	16F
0005433434335	26203	26	17B
0005432984673	26203	27	17A
0005433434351	26203	28	17E
0005433434343	26203	29	17F
0005432049419	26203	30	18B
0005432984688	26203	31	18F
0005432869438	26203	32	18E
0005432984696	26203	33	18H
0005433434347	26203	34	19G
0005432984677	26203	35	20F
0005434731121	26203	36	20G
0005433434350	26203	37	21A
0005433434345	26203	38	21H
0005433434328	26203	39	22B
0005433434340	26203	40	22E
0005433434326	26203	41	22G
0005432984694	26203	42	23D
0005432984690	26203	43	23F
0005432984675	26203	44	23G
0005433434331	26203	45	24A
0005432984686	26203	46	24E
0005432984693	26203	47	24H
0005433434330	26203	48	25E
0005432869439	26203	49	25F
0005432984672	26203	50	27D
0005432984669	26203	51	27G
0005432984671	26203	52	28A
0005432051090	26203	53	28B
0005432051091	26203	54	28D
0005433434338	26203	55	30B
0005432049421	26203	56	31B
0005432984680	26203	57	31E
0005432984697	26203	58	31D
0005432984681	26203	59	31H
0005433434346	26203	60	32B
0005433434352	26203	61	32D
0005432984667	26203	62	32H
0005432049418	26203	63	33G
0005433434344	26203	64	33F
0005432869443	26203	65	34D
0005433434342	26203	66	34B
0005433434349	26203	67	34E
0005433434334	26203	68	34G
0005432984683	26203	69	35B
0005433764644	26203	70	35F
0005432984682	26203	71	35G
0005433434353	26203	72	35H
0005433753238	26203	73	36B
0005433434339	26203	74	36F
0005433434336	26203	75	37A
0005432869440	26203	76	37B
0005432984687	26203	77	37E
0005432984685	26203	78	37F
0005432984684	26203	79	37G
0005433434329	26203	80	38D
0005432984689	26203	81	38G
0005433434333	26203	82	39D
0005432869441	26203	83	39E
0005434374118	1499	1	1A
0005432267811	1499	2	1D
0005433150831	1499	3	2A
0005434374095	1499	4	1F
0005434374123	1499	5	2D
0005434374086	1499	6	2F
0005434374106	1499	7	3A
0005434374117	1499	8	3C
0005433460410	1499	9	4A
0005434374085	1499	10	4D
0005434374122	1499	11	5A
0005434374102	1499	12	4F
0005434374111	1499	13	5B
0005433460409	1499	14	5D
0005433150795	1499	15	6B
0005432267816	1499	16	6F
0005434374107	1499	17	6E
0005434374092	1499	18	7B
0005434374098	1499	19	7A
0005434374082	1499	20	8B
0005434374099	1499	21	8E
0005434374110	1499	22	9C
0005434374112	1499	23	9E
0005434374093	1499	24	10E
0005432267813	1499	25	11A
0005434374121	1499	26	11B
0005434374088	1499	27	11C
0005432267815	1499	28	12A
0005432267812	1499	29	12D
0005434374105	1499	30	12F
0005434374091	1499	31	13C
0005434374104	1499	32	13B
0005434374115	1499	33	13D
0005434374097	1499	34	13E
0005434374109	1499	35	14B
0005434374108	1499	36	14F
0005434374103	1499	37	15B
0005433150796	1499	38	15D
0005433461562	1499	39	15E
0005434374083	1499	40	15F
0005434374094	1499	41	16C
0005434374084	1499	42	16D
0005434374114	1499	43	17E
0005434374119	1499	44	17F
0005433150939	1499	45	18D
0005433150936	1499	46	19A
0005434374089	1499	47	18F
0005434374100	1499	48	19F
0005434374120	1499	49	20D
0005434374116	1499	50	20E
0005433150937	1499	51	21B
0005433150938	1499	52	21D
0005432267814	1499	53	22B
0005434374113	1499	54	22A
0005434374096	1499	55	22C
0005433461561	1499	56	22D
0005434374090	1499	57	23A
0005434374087	1499	58	22F
0005432267810	1499	59	23D
0005434374101	1499	60	23F
0005433151002	20153	1	1F
0005433151004	20153	2	2A
0005433150985	20153	3	2D
0005433150973	20153	4	3D
0005434029626	20153	5	3C
0005433150992	20153	6	4B
0005433150994	20153	7	5D
0005433150996	20153	8	6B
0005433150987	20153	9	6C
0005433150975	20153	10	6E
0005433151001	20153	11	7A
0005433150978	20153	12	7F
0005433151000	20153	13	8E
0005433150989	20153	14	8D
0005433150972	20153	15	8F
0005433150981	20153	16	9A
0005433150990	20153	17	9B
0005433931427	20153	18	9C
0005433931429	20153	19	9D
0005433151003	20153	20	10D
0005433150997	20153	21	11C
0005433150970	20153	22	11D
0005433150971	20153	23	12C
0005433150976	20153	24	13D
0005433150986	20153	25	14E
0005433150999	20153	26	15B
0005433150982	20153	27	15A
0005433150980	20153	28	15F
0005433764654	20153	29	16B
0005433150979	20153	30	16F
0005433150993	20153	31	17A
0005432056253	20153	32	18D
0005433931428	20153	33	18E
0005432056251	20153	34	19A
0005433150995	20153	35	19D
0005433150977	20153	36	19F
0005433150974	20153	37	20B
0005433150991	20153	38	20E
0005433150998	20153	39	20F
0005433150984	20153	40	21C
0005432056252	20153	41	21F
0005433150988	20153	42	22E
0005433150983	20153	43	23C
0005432423874	588	1	1F
0005432282780	588	2	1D
0005432423899	588	3	2A
0005432282781	588	4	3D
0005432423868	588	5	5A
0005432423901	588	6	4F
0005432423867	588	7	5C
0005432423862	588	8	5D
0005432423907	588	9	6C
0005432423891	588	10	7A
0005432423893	588	11	6F
0005432423895	588	12	7F
0005432423896	588	13	7D
0005432423872	588	14	8B
0005432282776	588	15	8C
0005432282775	588	16	8E
0005432423883	588	17	9C
0005432423860	588	18	9E
0005432282774	588	19	9F
0005432423894	588	20	11B
0005432423870	588	21	11A
0005432282779	588	22	12A
0005432423881	588	23	12E
0005432282777	588	24	12F
0005432423869	588	25	13C
0005432423904	588	26	13F
0005432423871	588	27	14E
0005432423873	588	28	14D
0005432423884	588	29	15C
0005432423902	588	30	15D
0005432423876	588	31	16A
0005432423890	588	32	16B
0005432423889	588	33	16F
0005432423900	588	34	16D
0005432423861	588	35	17D
0005432423879	588	36	17E
0005432423882	588	37	18B
0005432423880	588	38	18D
0005432423903	588	39	18F
0005432423877	588	40	20D
0005432423875	588	41	21A
0005432423898	588	42	21E
0005432282778	588	43	22A
0005432423909	588	44	22B
0005432423878	588	45	22D
0005432423863	588	46	22F
0005432423908	588	47	23B
0005432423885	588	48	23C
0005432423866	588	49	24E
0005432423886	588	50	25E
0005432423892	588	51	27A
0005432423905	588	52	27C
0005432423865	588	53	28B
0005432423887	588	54	28D
0005432423897	588	55	28E
0005432423864	588	56	29A
0005432423906	588	57	29F
0005432423888	588	58	30B
0005432302283	12898	1	11D
0005432302285	12898	2	18D
0005432302284	12898	3	26B
0005432302286	12898	4	28D
0005434022916	443	1	1C
0005433057240	443	2	1B
0005433057272	443	3	1F
0005434022906	443	4	1H
0005434022861	443	5	1G
0005432045587	443	6	2C
0005434022903	443	7	2H
0005434022889	443	8	3F
0005434022914	443	9	3H
0005434022856	443	10	4B
0005434022878	443	11	4F
0005434022865	443	12	4C
0005432235545	443	13	4H
0005434022862	443	14	5C
0005434022851	443	15	5H
0005434022874	443	16	9B
0005434022894	443	17	9H
0005434022888	443	18	11B
0005434022895	443	19	11F
0005434022850	443	20	11E
0005434022909	443	21	12A
0005433057189	443	22	11H
0005434022907	443	23	12D
0005434022910	443	24	12F
0005434022893	443	25	13A
0005434029624	443	26	13D
0005434022882	443	27	14B
0005433057274	443	28	14F
0005434031966	443	29	14E
0005434022905	443	30	14G
0005433057193	443	31	15D
0005432235543	443	32	15E
0005434022867	443	33	15G
0005433057172	443	34	16E
0005434022871	443	35	16D
0005434022908	443	36	16F
0005434022847	443	37	17B
0005434022852	443	38	17A
0005434022900	443	39	17E
0005434022891	443	40	18A
0005434031962	443	41	18B
0005433057239	443	42	19A
0005434022877	443	43	18H
0005434022896	443	44	19B
0005434022858	443	45	19D
0005434022915	443	46	19H
0005434022866	443	47	20A
0005434031965	443	48	20D
0005434022884	443	49	20B
0005432235546	443	50	21A
0005434022868	443	51	21B
0005432235548	443	52	21E
0005432235542	443	53	22G
0005432235544	443	54	23F
0005432235547	443	55	23E
0005434022887	443	56	24A
0005434022854	443	57	23H
0005434022886	443	58	24B
0005434022864	443	59	24E
0005434022879	443	60	24D
0005434022904	443	61	24F
0005434029625	443	62	24H
0005434022860	443	63	25D
0005434022883	443	64	25E
0005434022892	443	65	27A
0005432235549	443	66	27B
0005434022872	443	67	27D
0005434022912	443	68	27E
0005434022902	443	69	27G
0005434022859	443	70	28A
0005434022885	443	71	28D
0005434022911	443	72	28B
0005434022855	443	73	28H
0005434022849	443	74	29D
0005434022876	443	75	30B
0005434022869	443	76	30D
0005432045588	443	77	30G
0005434022901	443	78	30H
0005434022897	443	79	31D
0005434022873	443	80	31F
0005434022853	443	81	31H
0005434031963	443	82	32A
0005434022899	443	83	32B
0005434022890	443	84	34A
0005433057311	443	85	34G
0005434022863	443	86	35A
0005434022913	443	87	35D
0005434022898	443	88	36E
0005434022857	443	89	36F
0005434031964	443	90	36G
0005434022881	443	91	37E
0005434022875	443	92	37G
0005434022848	443	93	38B
0005434022870	443	94	38A
0005433057273	443	95	38G
0005434022880	443	96	38F
0005433057228	443	97	39D
0005433057390	12674	1	1G
0005433057378	12674	2	2A
0005434022599	12674	3	3A
0005434022541	12674	4	3C
0005433057407	12674	5	3G
0005433057389	12674	6	5C
0005434022557	12674	7	5G
0005433057380	12674	8	5H
0005433057411	12674	9	9B
0005433057409	12674	10	9G
0005433057393	12674	11	11A
0005433929562	12674	12	11E
0005433057385	12674	13	11F
0005434022543	12674	14	12E
0005433057391	12674	15	12F
0005432156312	12674	16	12G
0005433057396	12674	17	13D
0005433057377	12674	18	14B
0005434022512	12674	19	14E
0005433057414	12674	20	15B
0005433057392	12674	21	16A
0005433057386	12674	22	17G
0005434735624	12674	23	18F
0005433929561	12674	24	18E
0005433929564	12674	25	18H
0005433057408	12674	26	19H
0005434735627	12674	27	20H
0005433057376	12674	28	21A
0005433057401	12674	29	21E
0005433057402	12674	30	22G
0005433684396	12674	31	23B
0005432156310	12674	32	23G
0005433057412	12674	33	23H
0005433057405	12674	34	24G
0005434022562	12674	35	25E
0005433057399	12674	36	25F
0005433057388	12674	37	27F
0005433057400	12674	38	27G
0005433057404	12674	39	28B
0005433057383	12674	40	28E
0005433057406	12674	41	28G
0005434735626	12674	42	28F
0005433057398	12674	43	29D
0005432157467	12674	44	30A
0005433057387	12674	45	30D
0005433057382	12674	46	31B
0005433057374	12674	47	31D
0005434735625	12674	48	31E
0005433057410	12674	49	31F
0005433057381	12674	50	32F
0005433929563	12674	51	33B
0005434735628	12674	52	33E
0005432156309	12674	53	33D
0005433057413	12674	54	33H
0005433929560	12674	55	34F
0005432156311	12674	56	34E
0005434022542	12674	57	34H
0005433057384	12674	58	36B
0005433057379	12674	59	36E
0005433057394	12674	60	36F
0005433057375	12674	61	37A
0005433684395	12674	62	36H
0005433057397	12674	63	37B
0005433057395	12674	64	37E
0005432157468	12674	65	38A
0005433057403	12674	66	38D
0005433931427	2152	1	1A
0005433922122	2152	2	1B
0005433922131	2152	3	1F
0005432044490	2152	4	1C
0005433922089	2152	5	1G
0005432231432	2152	6	2A
0005433931429	2152	7	2F
0005433922128	2152	8	3A
0005433922139	2152	9	3C
0005433922090	2152	10	3B
0005433922123	2152	11	3F
0005433922161	2152	12	3G
0005433929560	2152	13	4A
0005433922100	2152	14	3H
0005433922173	2152	15	4B
0005433922103	2152	16	4C
0005433922127	2152	17	4G
0005433929563	2152	18	4F
0005432231428	2152	19	5A
0005432231429	2152	20	5F
0005433922106	2152	21	9B
0005433922104	2152	22	9G
0005433922094	2152	23	9H
0005433922109	2152	24	11B
0005432231433	2152	25	11E
0005433922078	2152	26	11G
0005433922165	2152	27	12E
0005432231438	2152	28	12D
0005433922087	2152	29	12F
0005433922137	2152	30	13B
0005433922156	2152	31	13E
0005433922149	2152	32	13D
0005433922143	2152	33	14D
0005433922124	2152	34	14G
0005433922119	2152	35	15A
0005433922092	2152	36	14H
0005433922151	2152	37	15D
0005433922133	2152	38	15G
0005433922157	2152	39	15H
0005433922110	2152	40	16A
0005433922112	2152	41	16D
0005433922146	2152	42	16F
0005433922099	2152	43	16H
0005433929564	2152	44	17B
0005433922121	2152	45	17A
0005432231436	2152	46	17D
0005433922107	2152	47	17F
0005433922115	2152	48	18A
0005433922120	2152	49	18B
0005433922111	2152	50	18F
0005433922091	2152	51	18E
0005433922079	2152	52	18H
0005433922152	2152	53	19B
0005432231431	2152	54	19D
0005433922175	2152	55	19F
0005433922145	2152	56	20A
0005433922093	2152	57	20E
0005433922166	2152	58	20G
0005433922132	2152	59	20H
0005433922118	2152	60	21B
0005433931428	2152	61	21E
0005433922114	2152	62	21F
0005433922171	2152	63	21H
0005433922097	2152	64	21G
0005433875358	2152	65	22A
0005433922155	2152	66	22D
0005433922154	2152	67	22B
0005433922105	2152	68	22E
0005432044489	2152	69	22G
0005433922096	2152	70	22H
0005433922102	2152	71	23A
0005432231437	2152	72	23B
0005433922113	2152	73	23H
0005433922081	2152	74	24B
0005433922136	2152	75	24F
0005433922125	2152	76	24E
0005433875359	2152	77	24G
0005433035360	2152	78	25D
0005433922084	2152	79	25E
0005433922141	2152	80	27A
0005433922162	2152	81	27B
0005433922169	2152	82	27D
0005433922142	2152	83	27F
0005433922129	2152	84	27H
0005433922086	2152	85	27G
0005432231430	2152	86	28A
0005433922164	2152	87	28B
0005433922135	2152	88	28E
0005433922150	2152	89	29B
0005433922160	2152	90	29E
0005432231434	2152	91	29D
0005433922082	2152	92	29H
0005433922098	2152	93	29G
0005433922174	2152	94	30A
0005433922167	2152	95	30D
0005433922163	2152	96	30F
0005433922140	2152	97	30E
0005433922159	2152	98	30G
0005433922138	2152	99	31E
0005433922126	2152	100	31G
0005433922148	2152	101	31H
0005433922170	2152	102	32B
0005433922134	2152	103	32H
0005433922108	2152	104	32G
0005432231439	2152	105	33A
0005433922088	2152	106	33F
0005433922083	2152	107	33G
0005433922168	2152	108	34E
0005433922085	2152	109	34G
0005433035359	2152	110	35A
0005433922117	2152	111	34H
0005433922172	2152	112	35B
0005433922080	2152	113	35D
0005433922147	2152	114	35E
0005433922116	2152	115	35H
0005433929561	2152	116	36B
0005433929562	2152	117	36D
0005433922095	2152	118	37A
0005433922130	2152	119	36H
0005432231435	2152	120	37E
0005433922153	2152	121	37G
0005433922144	2152	122	38D
0005433922101	2152	123	38F
0005432044491	2152	124	39D
0005433922158	2152	125	39F
0005433035676	24087	1	1F
0005434028262	24087	2	1C
0005433035653	24087	3	1H
0005432206124	24087	4	1G
0005433035662	24087	5	2A
0005433035672	24087	6	3G
0005433035655	24087	7	4B
0005433035627	24087	8	4F
0005433035650	24087	9	5B
0005433035664	24087	10	5F
0005433035674	24087	11	5C
0005433035647	24087	12	5G
0005434028261	24087	13	5H
0005433035677	24087	14	9B
0005433035657	24087	15	9H
0005433921725	24087	16	11F
0005433035648	24087	17	12E
0005433035636	24087	18	12F
0005433921693	24087	19	12H
0005433921660	24087	20	13G
0005433035669	24087	21	13H
0005433035652	24087	22	14A
0005433035644	24087	23	14E
0005433035659	24087	24	14G
0005432749758	24087	25	15A
0005432207631	24087	26	14H
0005433921659	24087	27	15B
0005433921742	24087	28	15E
0005433035678	24087	29	17B
0005433035632	24087	30	17D
0005433035646	24087	31	17F
0005433921694	24087	32	17E
0005433035628	24087	33	17G
0005433035658	24087	34	18B
0005433035637	24087	35	18D
0005433035651	24087	36	19A
0005433035670	24087	37	20G
0005433035679	24087	38	21D
0005433921612	24087	39	21F
0005433035642	24087	40	22E
0005433035635	24087	41	23D
0005432206127	24087	42	23E
0005433035663	24087	43	24E
0005433035660	24087	44	24F
0005432749759	24087	45	24G
0005433035661	24087	46	27A
0005433035667	24087	47	27B
0005433921677	24087	48	27E
0005433921741	24087	49	27F
0005433035629	24087	50	27G
0005433035666	24087	51	28A
0005433035639	24087	52	27H
0005433035630	24087	53	28B
0005432206123	24087	54	28E
0005432207630	24087	55	28D
0005433035633	24087	56	29D
0005432206125	24087	57	30B
0005433035640	24087	58	30F
0005433035675	24087	59	30H
0005433035643	24087	60	31A
0005433035649	24087	61	31E
0005433921665	24087	62	32B
0005432206122	24087	63	32D
0005433035673	24087	64	32F
0005432207629	24087	65	33B
0005433035641	24087	66	33E
0005433035631	24087	67	33G
0005433035626	24087	68	34A
0005433035634	24087	69	34E
0005433921740	24087	70	34G
0005433035645	24087	71	34F
0005433035665	24087	72	35F
0005433035671	24087	73	36A
0005433035656	24087	74	36B
0005433035668	24087	75	36E
0005433035638	24087	76	36D
0005432206126	24087	77	37B
0005432749757	24087	78	38H
0005433035654	24087	79	39F
0005434723943	278	1	1C
0005434550554	278	2	1G
0005434724022	278	3	1D
0005434723949	278	4	2G
0005434550556	278	5	3D
0005433766572	278	6	3C
0005434723956	278	7	3K
0005434550538	278	8	3H
0005432277638	278	9	3G
0005434724049	278	10	4C
0005433233086	278	11	4G
0005434550580	278	12	5A
0005435142410	278	13	4K
0005432277647	278	14	5D
0005434550592	278	15	11A
0005434723995	278	16	5K
0005434550558	278	17	11D
0005432277642	278	18	11C
0005434550588	278	19	11G
0005434724021	278	20	11F
0005434550537	278	21	11E
0005434550568	278	22	11H
0005434550569	278	23	12C
0005434550553	278	24	12E
0005434550573	278	25	12D
0005434723948	278	26	12H
0005434723932	278	27	13C
0005434731115	278	28	13F
0005434724023	278	29	13E
0005434723965	278	30	13K
0005434723967	278	31	13H
0005434550551	278	32	14A
0005434550559	278	33	14D
0005432277651	278	34	14F
0005434731116	278	35	14G
0005434550572	278	36	15C
0005434724011	278	37	15A
0005434550547	278	38	15H
0005434731114	278	39	15F
0005434724009	278	40	16A
0005434723992	278	41	16F
0005434724033	278	42	17C
0005434550578	278	43	17D
0005434550586	278	44	17G
0005434550560	278	45	17F
0005434724036	278	46	18C
0005434550565	278	47	18D
0005434724019	278	48	18G
0005434723998	278	49	18H
0005434723931	278	50	19B
0005432277640	278	51	19A
0005434550579	278	52	18K
0005434723952	278	53	19D
0005434723962	278	54	19F
0005434550555	278	55	20A
0005434723999	278	56	19K
0005434550587	278	57	20C
0005434550561	278	58	20K
0005434723972	278	59	21B
0005434723934	278	60	21A
0005434550576	278	61	21G
0005434723936	278	62	21F
0005434723939	278	63	21E
0005434723993	278	64	21J
0005434550543	278	65	21H
0005434724048	278	66	22C
0005434723964	278	67	22B
0005434724002	278	68	22E
0005434723971	278	69	22H
0005434724013	278	70	22G
0005434550552	278	71	22F
0005434724006	278	72	23B
0005434550548	278	73	23A
0005434731113	278	74	22K
0005435142408	278	75	23D
0005434723969	278	76	23C
0005434723980	278	77	23F
0005434724041	278	78	23E
0005434723989	278	79	23H
0005435142414	278	80	23G
0005434550540	278	81	24D
0005434724034	278	82	23K
0005432277649	278	83	24F
0005434724038	278	84	24E
0005434735618	278	85	25A
0005434723959	278	86	24G
0005434723954	278	87	25D
0005433233121	278	88	26A
0005434723996	278	89	26D
0005434735620	278	90	26G
0005434735619	278	91	26F
0005434723958	278	92	26K
0005435142405	278	93	26J
0005434723990	278	94	27B
0005434723938	278	95	27A
0005434723966	278	96	27D
0005435142411	278	97	27C
0005434724014	278	98	27E
0005434550549	278	99	27J
0005434550557	278	100	28B
0005432277639	278	101	28A
0005434550550	278	102	28D
0005434723981	278	103	28G
0005434550571	278	104	29A
0005432277641	278	105	29C
0005434723977	278	106	29F
0005434550539	278	107	29E
0005434550582	278	108	29J
0005434723978	278	109	29H
0005435142409	278	110	30B
0005435142407	278	111	30A
0005434723988	278	112	30E
0005434723935	278	113	30D
0005432277644	278	114	30F
0005434724043	278	115	30K
0005434550584	278	116	30J
0005434723955	278	117	30H
0005434724050	278	118	31D
0005435142406	278	119	31C
0005434724031	278	120	31B
0005434302406	278	121	31F
0005434724008	278	122	31J
0005434723957	278	123	31H
0005434723983	278	124	32A
0005434550585	278	125	32E
0005434723950	278	126	32C
0005434723937	278	127	32G
0005434724012	278	128	32F
0005434724004	278	129	32J
0005434724018	278	130	32H
0005434550564	278	131	33B
0005434550567	278	132	33A
0005432277645	278	133	33D
0005435142415	278	134	33F
0005434724015	278	135	33G
0005434723974	278	136	34A
0005434302407	278	137	34C
0005435142416	278	138	34B
0005434550563	278	139	34D
0005434723941	278	140	34G
0005434724029	278	141	34J
0005434724035	278	142	34K
0005434723994	278	143	35C
0005434550575	278	144	35G
0005434550591	278	145	36A
0005434724003	278	146	35K
0005434723979	278	147	36C
0005435142412	278	148	36B
0005432277648	278	149	36E
0005432277650	278	150	36F
0005434550581	278	151	36J
0005434724047	278	152	36H
0005434550566	278	153	37B
0005434723987	278	154	37E
0005434723975	278	155	37D
0005434723970	278	156	37C
0005434723944	278	157	37F
0005434550544	278	158	37J
0005434723963	278	159	37H
0005434723984	278	160	37G
0005433180660	278	161	38A
0005434723945	278	162	38C
0005434723985	278	163	38J
0005434724010	278	164	38H
0005434724044	278	165	39D
0005434550542	278	166	39C
0005434724046	278	167	39E
0005434723930	278	168	39H
0005434735623	278	169	39G
0005434550590	278	170	39K
0005434724016	278	171	40C
0005433233175	278	172	40E
0005434724007	278	173	40D
0005434723982	278	174	40H
0005434723942	278	175	40K
0005434723946	278	176	40J
0005432277643	278	177	41B
0005434550583	278	178	41A
0005434724028	278	179	41C
0005434724045	278	180	41F
0005435142413	278	181	41J
0005434724005	278	182	41H
0005434724051	278	183	42C
0005432277646	278	184	42B
0005434735622	278	185	42D
0005434723997	278	186	42F
0005434724017	278	187	42J
0005434724024	278	188	42H
0005434724039	278	189	43B
0005434550541	278	190	43A
0005434724032	278	191	43F
0005434723951	278	192	43E
0005434723961	278	193	43H
0005434723953	278	194	44B
0005434724000	278	195	44D
0005434302405	278	196	44C
0005434723940	278	197	44F
0005434550562	278	198	45D
0005434723947	278	199	45B
0005434550589	278	200	45E
0005434723968	278	201	45G
0005434550574	278	202	46A
0005434724040	278	203	45K
0005434724020	278	204	46B
0005434724053	278	205	46E
0005434724030	278	206	46D
0005434550570	278	207	46H
0005434724052	278	208	47A
0005434724027	278	209	47D
0005435142417	278	210	47G
0005434724025	278	211	47F
0005434724037	278	212	47E
0005434723933	278	213	48C
0005434724026	278	214	48E
0005434723976	278	215	48D
0005434550546	278	216	48H
0005434723986	278	217	48K
0005434724001	278	218	49D
0005434723973	278	219	49C
0005434735621	278	220	49F
0005434723991	278	221	49H
0005432277637	278	222	50C
0005434302404	278	223	50A
0005434724042	278	224	49K
0005434723960	278	225	50D
0005433233122	278	226	50G
0005434550545	278	227	50H
0005434550577	278	228	51F
0005433233463	9873	1	1C
0005433233453	9873	2	2A
0005434031969	9873	3	1K
0005433233428	9873	4	2D
0005433233438	9873	5	3A
0005433233441	9873	6	2K
0005433233414	9873	7	3G
0005433233406	9873	8	4G
0005432199164	9873	9	5A
0005433129220	9873	10	4H
0005433180796	9873	11	5D
0005433233445	9873	12	11D
0005433233417	9873	13	11E
0005434723521	9873	14	11G
0005432199163	9873	15	12H
0005433289755	9873	16	12K
0005433180788	9873	17	13F
0005433233436	9873	18	13E
0005433233432	9873	19	13D
0005433233423	9873	20	14C
0005433233402	9873	21	13K
0005433126789	9873	22	15D
0005433289761	9873	23	15G
0005434723365	9873	24	15K
0005433233447	9873	25	16D
0005433180778	9873	26	16F
0005434723393	9873	27	17C
0005433233415	9873	28	18D
0005434723341	9873	29	18G
0005433180785	9873	30	19G
0005433113506	9873	31	19H
0005433233448	9873	32	19K
0005433233440	9873	33	20G
0005434723402	9873	34	20F
0005434723359	9873	35	20H
0005433180789	9873	36	21B
0005433233458	9873	37	21A
0005433180792	9873	38	21J
0005433233421	9873	39	21K
0005433289757	9873	40	22E
0005433180797	9873	41	22G
0005433129218	9873	42	23D
0005434550256	9873	43	23C
0005433233416	9873	44	23G
0005433233430	9873	45	23J
0005433233408	9873	46	24D
0005433766593	9873	47	24F
0005434031970	9873	48	24E
0005433180787	9873	49	25A
0005433233444	9873	50	25D
0005433129219	9873	51	25F
0005433180780	9873	52	25J
0005433180798	9873	53	25K
0005433233456	9873	54	26A
0005433233407	9873	55	26F
0005433233460	9873	56	26H
0005433233439	9873	57	27B
0005433233452	9873	58	27D
0005433233410	9873	59	27C
0005433233454	9873	60	27E
0005433289754	9873	61	27H
0005433180790	9873	62	28B
0005433126790	9873	63	28D
0005433180784	9873	64	28G
0005433126787	9873	65	28F
0005433233434	9873	66	29A
0005433233433	9873	67	29H
0005432199161	9873	68	29G
0005433126788	9873	69	30A
0005433113507	9873	70	29K
0005433233409	9873	71	30C
0005433180786	9873	72	30B
0005433233462	9873	73	30E
0005434723415	9873	74	30D
0005433233457	9873	75	30F
0005433233404	9873	76	30K
0005434550257	9873	77	31D
0005432199159	9873	78	31F
0005433180777	9873	79	31E
0005433233461	9873	80	31H
0005434031971	9873	81	31G
0005433233412	9873	82	32B
0005433289760	9873	83	32G
0005433289756	9873	84	32H
0005433233422	9873	85	33A
0005433180783	9873	86	33E
0005433766594	9873	87	33H
0005433233435	9873	88	33G
0005433233451	9873	89	33K
0005433233419	9873	90	34B
0005434723403	9873	91	34F
0005433180800	9873	92	35B
0005433233405	9873	93	34K
0005432199160	9873	94	35G
0005432199165	9873	95	35F
0005434723390	9873	96	36A
0005433180781	9873	97	35K
0005433126786	9873	98	36C
0005434723366	9873	99	36J
0005433233420	9873	100	37C
0005433289758	9873	101	37G
0005433233443	9873	102	37F
0005433233426	9873	103	39B
0005433233442	9873	104	39K
0005433233465	9873	105	39J
0005433233431	9873	106	40C
0005433180802	9873	107	40B
0005433233464	9873	108	40E
0005433233450	9873	109	40H
0005433180791	9873	110	40G
0005433233413	9873	111	41B
0005433233429	9873	112	40K
0005433233459	9873	113	42A
0005434031968	9873	114	41K
0005433233446	9873	115	42F
0005433180794	9873	116	42J
0005434723430	9873	117	43E
0005433180799	9873	118	43D
0005433233427	9873	119	43H
0005433180779	9873	120	43G
0005433180801	9873	121	43K
0005434723536	9873	122	43J
0005434550258	9873	123	44D
0005434723392	9873	124	44F
0005433233424	9873	125	45A
0005433233418	9873	126	45C
0005432199162	9873	127	45H
0005433233455	9873	128	46C
0005433233403	9873	129	46B
0005434031967	9873	130	46D
0005434723520	9873	131	46H
0005433233411	9873	132	47C
0005433289759	9873	133	48C
0005433233425	9873	134	48H
0005433180793	9873	135	48G
0005433180795	9873	136	49D
0005433113508	9873	137	50G
0005433180782	9873	138	50F
0005433233437	9873	139	50K
0005433233449	9873	140	51E
0005434066662	7727	1	1A
0005432526333	7727	2	1D
0005432526428	7727	3	2A
0005432535773	7727	4	1H
0005434066682	7727	5	2H
0005432526363	7727	6	2G
0005432526394	7727	7	2D
0005432526340	7727	8	3A
0005432526364	7727	9	2K
0005434066677	7727	10	3G
0005432526410	7727	11	3D
0005432526362	7727	12	3C
0005432526368	7727	13	4A
0005432526414	7727	14	4G
0005434066681	7727	15	4D
0005432526416	7727	16	4H
0005434066723	7727	17	5D
0005432526334	7727	18	5C
0005432526338	7727	19	5K
0005432526395	7727	20	11D
0005434066712	7727	21	11F
0005432526349	7727	22	11E
0005435212343	7727	23	11K
0005432526345	7727	24	11H
0005432150095	7727	25	12C
0005432526378	7727	26	12A
0005432526424	7727	27	12E
0005432526422	7727	28	12D
0005434066694	7727	29	12G
0005432069473	7727	30	13A
0005432526353	7727	31	12K
0005432150099	7727	32	12H
0005434066667	7727	33	13D
0005432526335	7727	34	13C
0005434066725	7727	35	13F
0005434066719	7727	36	13H
0005434066659	7727	37	14A
0005434066690	7727	38	13K
0005434066666	7727	39	14E
0005432150097	7727	40	14F
0005432526326	7727	41	14K
0005434066720	7727	42	14H
0005434066703	7727	43	15C
0005432526322	7727	44	15A
0005432526385	7727	45	15D
0005432535770	7727	46	15G
0005432526377	7727	47	15F
0005434066661	7727	48	15K
0005432526398	7727	49	15H
0005432526325	7727	50	16D
0005432526383	7727	51	16A
0005432526307	7727	52	16F
0005434066728	7727	53	16E
0005434066688	7727	54	16H
0005432428887	7727	55	16G
0005432526316	7727	56	17A
0005432150100	7727	57	16K
0005434066658	7727	58	17E
0005432150096	7727	59	17F
0005432526425	7727	60	18A
0005432526373	7727	61	17H
0005434066683	7727	62	18C
0005432526437	7727	63	18E
0005432526356	7727	64	18D
0005432526342	7727	65	18J
0005434066715	7727	66	18H
0005434066680	7727	67	19A
0005432526386	7727	68	19C
0005432526370	7727	69	19D
0005432535774	7727	70	19H
0005432428886	7727	71	19G
0005432526360	7727	72	20B
0005432526418	7727	73	20D
0005432526397	7727	74	20C
0005432526402	7727	75	20F
0005434066676	7727	76	20K
0005434066717	7727	77	20J
0005432526430	7727	78	21B
0005432069472	7727	79	21F
0005432150094	7727	80	21E
0005432069482	7727	81	21G
0005432526415	7727	82	22A
0005432526317	7727	83	22C
0005432526308	7727	84	22B
0005432526351	7727	85	22F
0005434066696	7727	86	22E
0005432069469	7727	87	22D
0005432526311	7727	88	22H
0005434066705	7727	89	22J
0005432526409	7727	90	23A
0005432526330	7727	91	23E
0005432526421	7727	92	23C
0005432535771	7727	93	23G
0005432526361	7727	94	23F
0005434066684	7727	95	23J
0005434066687	7727	96	24D
0005432526320	7727	97	25A
0005432069479	7727	98	24G
0005432526350	7727	99	25D
0005434066704	7727	100	25B
0005432526438	7727	101	25F
0005434066695	7727	102	25E
0005432526329	7727	103	25H
0005434066729	7727	104	25G
0005432526336	7727	105	26A
0005434066713	7727	106	25K
0005432526339	7727	107	26C
0005432526359	7727	108	26F
0005434066691	7727	109	26J
0005432526399	7727	110	27A
0005434066693	7727	111	27C
0005432537031	7727	112	27B
0005432526426	7727	113	27E
0005434066679	7727	114	27D
0005434066686	7727	115	27H
0005432069476	7727	116	28A
0005432526436	7727	117	27K
0005432526331	7727	118	27J
0005434066707	7727	119	28B
0005432526434	7727	120	28G
0005434066698	7727	121	28F
0005434066670	7727	122	28H
0005432526306	7727	123	29B
0005432069481	7727	124	29A
0005434066671	7727	125	28K
0005432526346	7727	126	29D
0005432526369	7727	127	29C
0005434066699	7727	128	29E
0005432150102	7727	129	29G
0005432069470	7727	130	29K
0005432526406	7727	131	30B
0005432526328	7727	132	30E
0005432526403	7727	133	30D
0005432526332	7727	134	30C
0005432526417	7727	135	30K
0005432526341	7727	136	30H
0005432526420	7727	137	31D
0005432526337	7727	138	31C
0005432526407	7727	139	31G
0005432526324	7727	140	32B
0005434066675	7727	141	32E
0005432428885	7727	142	32D
0005432526413	7727	143	32J
0005434066724	7727	144	33D
0005434066709	7727	145	33F
0005432533255	7727	146	33G
0005432526391	7727	147	34A
0005432526310	7727	148	33K
0005432526365	7727	149	34D
0005434066706	7727	150	34C
0005432069474	7727	151	34F
0005432526375	7727	152	34H
0005432526440	7727	153	34K
0005432526314	7727	154	35G
0005432526381	7727	155	35F
0005432526400	7727	156	35E
0005432526344	7727	157	35J
0005434066711	7727	158	35H
0005432526390	7727	159	35K
0005434066678	7727	160	36B
0005432526309	7727	161	36F
0005432535772	7727	162	36G
0005432526315	7727	163	36J
0005434066697	7727	164	37B
0005432526354	7727	165	37A
0005432526408	7727	166	37D
0005432526367	7727	167	37C
0005432526372	7727	168	37F
0005432069477	7727	169	37J
0005432069471	7727	170	37H
0005432526396	7727	171	38A
0005434066726	7727	172	37K
0005432526321	7727	173	38C
0005432526327	7727	174	38B
0005434066664	7727	175	39A
0005434066689	7727	176	38K
0005434066672	7727	177	39C
0005432526348	7727	178	39F
0005432526357	7727	179	39E
0005432526412	7727	180	39D
0005432526393	7727	181	39G
0005432526312	7727	182	39K
0005432526419	7727	183	40C
0005432526358	7727	184	40B
0005432526371	7727	185	40E
0005432526404	7727	186	40D
0005434066663	7727	187	40G
0005432526387	7727	188	40K
0005432526429	7727	189	41A
0005432526405	7727	190	41B
0005432533257	7727	191	41E
0005432526366	7727	192	41J
0005432526379	7727	193	41G
0005432526352	7727	194	42B
0005432526384	7727	195	42D
0005432526392	7727	196	42G
0005434066727	7727	197	42F
0005432526376	7727	198	42J
0005432150101	7727	199	43A
0005432526423	7727	200	42K
0005432526427	7727	201	43D
0005432537030	7727	202	43C
0005432533256	7727	203	43B
0005432526305	7727	204	43F
0005432526319	7727	205	43E
0005434066669	7727	206	43H
0005432526389	7727	207	43G
0005432526439	7727	208	44C
0005434066702	7727	209	44B
0005434066685	7727	210	44E
0005432526323	7727	211	44D
0005432526411	7727	212	44K
0005434066674	7727	213	44J
0005432526388	7727	214	45A
0005434066721	7727	215	45F
0005434066714	7727	216	45E
0005432526355	7727	217	45K
0005434066692	7727	218	46C
0005432069475	7727	219	46B
0005432526347	7727	220	46E
0005434066710	7727	221	46G
0005434066722	7727	222	46F
0005432069478	7727	223	46H
0005434066718	7727	224	46K
0005432526431	7727	225	47E
0005434066668	7727	226	47G
0005432526433	7727	227	47K
0005434066660	7727	228	47H
0005432526382	7727	229	48D
0005432150098	7727	230	48C
0005432069480	7727	231	48A
0005434066665	7727	232	48H
0005432526343	7727	233	48G
0005434066701	7727	234	48F
0005434066708	7727	235	49A
0005432526435	7727	236	49D
0005434066716	7727	237	49G
0005432526401	7727	238	49K
0005434066673	7727	239	50C
0005434066700	7727	240	50D
0005432526313	7727	241	50G
0005432526374	7727	242	50F
0005432526432	7727	243	51D
0005435212428	7727	244	51F
0005432526318	7727	245	51E
0005432526380	7727	246	51G
0005435612263	5345	1	1A
0005434343780	5345	2	1H
0005435612353	5345	3	2A
0005435612258	5345	4	1K
0005432133021	5345	5	2C
0005435612272	5345	6	2H
0005435423650	5345	7	2G
0005435612344	5345	8	2K
0005434343773	5345	9	3C
0005435612244	5345	10	3G
0005435612276	5345	11	4C
0005432047504	5345	12	4D
0005435612305	5345	13	5D
0005435612311	5345	14	11A
0005435612343	5345	15	11K
0005435612349	5345	16	12C
0005435555342	5345	17	12E
0005435612283	5345	18	12D
0005435612291	5345	19	12F
0005435612307	5345	20	13F
0005435612318	5345	21	13H
0005435612362	5345	22	14A
0005434343765	5345	23	13K
0005432133020	5345	24	14F
0005434343789	5345	25	15C
0005434343792	5345	26	15A
0005435423730	5345	27	15F
0005435612280	5345	28	15E
0005434343767	5345	29	15D
0005435612331	5345	30	15H
0005434343761	5345	31	15G
0005435612259	5345	32	16A
0005434573185	5345	33	16D
0005435612269	5345	34	16F
0005434343777	5345	35	16K
0005435612297	5345	36	16H
0005435490184	5345	37	17F
0005435423596	5345	38	18A
0005435612314	5345	39	17K
0005432133031	5345	40	18C
0005435612359	5345	41	18G
0005435097091	5345	42	18F
0005435612321	5345	43	18K
0005434573176	5345	44	18H
0005434343796	5345	45	19D
0005435612300	5345	46	19B
0005434343762	5345	47	19E
0005435612267	5345	48	19H
0005435612287	5345	49	20A
0005435612293	5345	50	19K
0005434343770	5345	51	20E
0005434573178	5345	52	20F
0005434343788	5345	53	20H
0005435612285	5345	54	21A
0005434343764	5345	55	20K
0005435612340	5345	56	21E
0005435612320	5345	57	21J
0005434343774	5345	58	21H
0005435097096	5345	59	22A
0005435612250	5345	60	21K
0005432133019	5345	61	22C
0005435612332	5345	62	22B
0005435612335	5345	63	22E
0005432133030	5345	64	22G
0005435612333	5345	65	22K
0005434573182	5345	66	23E
0005435423592	5345	67	23D
0005435612346	5345	68	23C
0005434343769	5345	69	23J
0005435612326	5345	70	23H
0005432133024	5345	71	23G
0005435423699	5345	72	24D
0005432133023	5345	73	24E
0005435097093	5345	74	25A
0005435612299	5345	75	24G
0005435097094	5345	76	25C
0005434343776	5345	77	25G
0005435612282	5345	78	26A
0005432133029	5345	79	26C
0005435612292	5345	80	26B
0005435555343	5345	81	26E
0005435612319	5345	82	26G
0005435423628	5345	83	26J
0005434343771	5345	84	27A
0005435612345	5345	85	26K
0005435097098	5345	86	27D
0005434343790	5345	87	27C
0005435612356	5345	88	27H
0005434343782	5345	89	27G
0005435612242	5345	90	27K
0005434573183	5345	91	28C
0005434573177	5345	92	28B
0005435612334	5345	93	28E
0005432133034	5345	94	28D
0005435612261	5345	95	28G
0005435612281	5345	96	28J
0005434573173	5345	97	28K
0005435612302	5345	98	29F
0005435612288	5345	99	29H
0005434343793	5345	100	29G
0005435612350	5345	101	29K
0005434343768	5345	102	30A
0005435612361	5345	103	30E
0005432133026	5345	104	30D
0005435097095	5345	105	30G
0005432133033	5345	106	30F
0005435097088	5345	107	30J
0005435423613	5345	108	30H
0005435612325	5345	109	31B
0005434343775	5345	110	31A
0005434343784	5345	111	31F
0005435612347	5345	112	31E
0005435612290	5345	113	31H
0005435612296	5345	114	32A
0005435612339	5345	115	31K
0005435612338	5345	116	31J
0005435097089	5345	117	32C
0005435612279	5345	118	32B
0005435612328	5345	119	32D
0005435612357	5345	120	32G
0005435612317	5345	121	32F
0005435612327	5345	122	32J
0005435612358	5345	123	32H
0005435612248	5345	124	33B
0005435423698	5345	125	33A
0005435612323	5345	126	32K
0005435612265	5345	127	33D
0005435612251	5345	128	33C
0005435612354	5345	129	33F
0005434343797	5345	130	33E
0005434343779	5345	131	33K
0005435612246	5345	132	33J
0005435612268	5345	133	34A
0005435612355	5345	134	34E
0005434573186	5345	135	34D
0005435612351	5345	136	34G
0005435612360	5345	137	34F
0005435612342	5345	138	34K
0005435319424	5345	139	34H
0005435612255	5345	140	35B
0005435612249	5345	141	35C
0005435612304	5345	142	35F
0005435097090	5345	143	35E
0005434343783	5345	144	35J
0005434343772	5345	145	35H
0005434343795	5345	146	35G
0005435612247	5345	147	36A
0005435097092	5345	148	35K
0005434573180	5345	149	36C
0005434343786	5345	150	36F
0005435612253	5345	151	36E
0005435612266	5345	152	36D
0005435612306	5345	153	36K
0005435612309	5345	154	36H
0005435612273	5345	155	37A
0005435612295	5345	156	37D
0005435612313	5345	157	37G
0005435612286	5345	158	38A
0005435612348	5345	159	37K
0005435612294	5345	160	38C
0005435423693	5345	161	38B
0005434343778	5345	162	38J
0005435612277	5345	163	38H
0005434573184	5345	164	39A
0005434343785	5345	165	39C
0005435612243	5345	166	39F
0005432133032	5345	167	39K
0005432133025	5345	168	40B
0005435423761	5345	169	40E
0005435612329	5345	170	40D
0005432133018	5345	171	40F
0005435612257	5345	172	40J
0005435612316	5345	173	40H
0005435612252	5345	174	41B
0005435612256	5345	175	41D
0005435612245	5345	176	41F
0005435612324	5345	177	41J
0005435612315	5345	178	41H
0005434343763	5345	179	41G
0005435612274	5345	180	42A
0005435097097	5345	181	42C
0005434573175	5345	182	42B
0005434343791	5345	183	42D
0005435612270	5345	184	42J
0005435612310	5345	185	42H
0005434573181	5345	186	43A
0005435612260	5345	187	43D
0005434343794	5345	188	43B
0005432133022	5345	189	43E
0005435612337	5345	190	43G
0005435612284	5345	191	44A
0005434573174	5345	192	43J
0005435612352	5345	193	44D
0005435612298	5345	194	44F
0005432133027	5345	195	44K
0005432047502	5345	196	44J
0005434343787	5345	197	45A
0005435612330	5345	198	45D
0005432047503	5345	199	45C
0005435423645	5345	200	45F
0005435612312	5345	201	45H
0005435612264	5345	202	45J
0005435612301	5345	203	46E
0005435612308	5345	204	46D
0005435423620	5345	205	46G
0005435612262	5345	206	47A
0005434343798	5345	207	47G
0005435612341	5345	208	47F
0005435319425	5345	209	47K
0005434573179	5345	210	48D
0005434573187	5345	211	48C
0005434343766	5345	212	48F
0005434343781	5345	213	49A
0005435612271	5345	214	48K
0005435612275	5345	215	49D
0005432133028	5345	216	49K
0005435612303	5345	217	49H
0005432047505	5345	218	50A
0005435612336	5345	219	50F
0005435423644	5345	220	50E
0005435612254	5345	221	50G
0005435612289	5345	222	51D
0005435612278	5345	223	51F
0005435612322	5345	224	51G
0005435423945	10892	1	1C
0005432164944	10892	2	1G
0005432164940	10892	3	1D
0005435423982	10892	4	2H
0005435423928	10892	5	2D
0005435423964	10892	6	3A
0005435319467	10892	7	3D
0005435423934	10892	8	3K
0005435304113	10892	9	3H
0005435423969	10892	10	3G
0005434656530	10892	11	4C
0005434244628	10892	12	4A
0005432164947	10892	13	5C
0005435611717	10892	14	5H
0005434244606	10892	15	5G
0005435319462	10892	16	11H
0005435611867	10892	17	12C
0005434244604	10892	18	12D
0005435423929	10892	19	12G
0005435423932	10892	20	12F
0005435423991	10892	21	13D
0005435423972	10892	22	13F
0005435611774	10892	23	13E
0005433719099	10892	24	13H
0005434244612	10892	25	13G
0005434244607	10892	26	14A
0005435423942	10892	27	14D
0005435380237	10892	28	14C
0005434244608	10892	29	15H
0005435423941	10892	30	15F
0005434244623	10892	31	16D
0005435423973	10892	32	16K
0005435423951	10892	33	18A
0005435380235	10892	34	18B
0005435304111	10892	35	18G
0005435423943	10892	36	18K
0005435423979	10892	37	19D
0005433719098	10892	38	19C
0005435423938	10892	39	19B
0005435423997	10892	40	19G
0005432166860	10892	41	19F
0005435423977	10892	42	19H
0005434244625	10892	43	19J
0005435304109	10892	44	20B
0005435423953	10892	45	20A
0005435319460	10892	46	20G
0005435423931	10892	47	21B
0005432164943	10892	48	21D
0005435423962	10892	49	21C
0005435423980	10892	50	21F
0005435423961	10892	51	21G
0005435611719	10892	52	22C
0005435423966	10892	53	22E
0005435423993	10892	54	22D
0005435423975	10892	55	23B
0005432166862	10892	56	23A
0005435423948	10892	57	23D
0005432363374	10892	58	23F
0005435423935	10892	59	23H
0005435423974	10892	60	23K
0005435319464	10892	61	25A
0005434244613	10892	62	25D
0005434244611	10892	63	25G
0005434244605	10892	64	26B
0005435423995	10892	65	26G
0005435423988	10892	66	26K
0005434244617	10892	67	26J
0005435304999	10892	68	27B
0005435319465	10892	69	27A
0005435423955	10892	70	27D
0005435423956	10892	71	27C
0005435423944	10892	72	27G
0005435423957	10892	73	27K
0005435423984	10892	74	28A
0005435319461	10892	75	28K
0005434244626	10892	76	28H
0005435611764	10892	77	29F
0005435612046	10892	78	29D
0005435423952	10892	79	29H
0005435612045	10892	80	29G
0005435423976	10892	81	30G
0005435423981	10892	82	30H
0005435423978	10892	83	31B
0005435423946	10892	84	31A
0005434244633	10892	85	31C
0005432164942	10892	86	31F
0005432840988	10892	87	31E
0005434573122	10892	88	32A
0005435611763	10892	89	31K
0005435423949	10892	90	32C
0005432164946	10892	91	33B
0005435611715	10892	92	33G
0005434244629	10892	93	33F
0005434244620	10892	94	33E
0005435423958	10892	95	34C
0005435423989	10892	96	34B
0005435423967	10892	97	34A
0005435380238	10892	98	34E
0005435304110	10892	99	35B
0005435380236	10892	100	35C
0005434244631	10892	101	35F
0005433719100	10892	102	35E
0005435423983	10892	103	35H
0005435611716	10892	104	36A
0005435423950	10892	105	35J
0005435423960	10892	106	36E
0005434244632	10892	107	36H
0005435423933	10892	108	36K
0005435423930	10892	109	37G
0005434244610	10892	110	37H
0005435423971	10892	111	38C
0005434244614	10892	112	38J
0005435423965	10892	113	38H
0005434244627	10892	114	39D
0005435304112	10892	115	39F
0005435319463	10892	116	39H
0005435423968	10892	117	39K
0005435304998	10892	118	40C
0005434656531	10892	119	40B
0005434244616	10892	120	40D
0005435319466	10892	121	41A
0005435423959	10892	122	41C
0005435423987	10892	123	41E
0005435611720	10892	124	42A
0005434244622	10892	125	41K
0005435304114	10892	126	42E
0005434244624	10892	127	42G
0005432164945	10892	128	42K
0005434244619	10892	129	43A
0005434244630	10892	130	43D
0005434244615	10892	131	43C
0005435423985	10892	132	43F
0005435423992	10892	133	44A
0005432840987	10892	134	43K
0005434244618	10892	135	44D
0005435423970	10892	136	44G
0005435423986	10892	137	44F
0005435423937	10892	138	45A
0005435423994	10892	139	45C
0005435423996	10892	140	45F
0005435423947	10892	141	45E
0005432363375	10892	142	45H
0005432363376	10892	143	46C
0005435423954	10892	144	46B
0005435423990	10892	145	46D
0005432164948	10892	146	47A
0005434244609	10892	147	47D
0005435423940	10892	148	47G
0005435423939	10892	149	48A
0005432164941	10892	150	48E
0005435380239	10892	151	48G
0005435423936	10892	152	49F
0005435423963	10892	153	50K
0005434244621	10892	154	50H
0005432166861	10892	155	51G
0005432181441	3299	1	1D
0005433804959	3299	2	1F
0005433506952	3299	3	2D
0005433633417	3299	4	3A
0005432181449	3299	5	3D
0005433506954	3299	6	4A
0005433633394	3299	7	4C
0005433633398	3299	8	5C
0005432181433	3299	9	5F
0005433804958	3299	10	6A
0005433804947	3299	11	7A
0005433633402	3299	12	6F
0005433804961	3299	13	7D
0005433633391	3299	14	7C
0005433804936	3299	15	8A
0005433633411	3299	16	8C
0005433804949	3299	17	8E
0005432181438	3299	18	8D
0005433506944	3299	19	8F
0005433506947	3299	20	9C
0005433804941	3299	21	9D
0005433804956	3299	22	10A
0005433506953	3299	23	10C
0005433804963	3299	24	10D
0005433633390	3299	25	10F
0005433633416	3299	26	11A
0005433804948	3299	27	11C
0005433804967	3299	28	11B
0005432181439	3299	29	11D
0005433804942	3299	30	11F
0005433633393	3299	31	11E
0005433804966	3299	32	12B
0005433633412	3299	33	12E
0005433633397	3299	34	12D
0005432181435	3299	35	13C
0005433633389	3299	36	13B
0005433633399	3299	37	13D
0005433804944	3299	38	13E
0005432181453	3299	39	13F
0005433506950	3299	40	14B
0005432181447	3299	41	14C
0005432181434	3299	42	14E
0005433506958	3299	43	15A
0005433633414	3299	44	15C
0005433804952	3299	45	15E
0005433633419	3299	46	15D
0005432181443	3299	47	15F
0005432181437	3299	48	16A
0005432181445	3299	49	16C
0005433804943	3299	50	16B
0005433633418	3299	51	16D
0005433633395	3299	52	16F
0005433633396	3299	53	17C
0005433804935	3299	54	18C
0005433633406	3299	55	18B
0005433633404	3299	56	18E
0005433633388	3299	57	19B
0005432181446	3299	58	18F
0005432181452	3299	59	19E
0005433633401	3299	60	20E
0005433804950	3299	61	21A
0005433633392	3299	62	20F
0005433633409	3299	63	21C
0005433506948	3299	64	21B
0005433633415	3299	65	21D
0005433804953	3299	66	21E
0005432181450	3299	67	21F
0005433633410	3299	68	22D
0005433506955	3299	69	22F
0005432181432	3299	70	23A
0005433804946	3299	71	23C
0005433633413	3299	72	23D
0005433633405	3299	73	23E
0005433804940	3299	74	23F
0005432181436	3299	75	24D
0005432181440	3299	76	25B
0005432181448	3299	77	25A
0005432181444	3299	78	25C
0005433506945	3299	79	25E
0005433506957	3299	80	26A
0005432181451	3299	81	25F
0005433804955	3299	82	26B
0005433633421	3299	83	26D
0005433804934	3299	84	26C
0005433804937	3299	85	27A
0005433506946	3299	86	26F
0005433804960	3299	87	27C
0005433804945	3299	88	27D
0005432181442	3299	89	28B
0005433804938	3299	90	28E
0005432181454	3299	91	29A
0005433633408	3299	92	29C
0005433804954	3299	93	29B
0005433633400	3299	94	29D
0005433804951	3299	95	29E
0005433506956	3299	96	30A
0005433633420	3299	97	30D
0005433804965	3299	98	30C
0005433804957	3299	99	30E
0005433633403	3299	100	30F
0005433506949	3299	101	31A
0005433804964	3299	102	31C
0005433804962	3299	103	31B
0005433804939	3299	104	31D
0005433633407	3299	105	31F
0005433506951	3299	106	31E
0005435884372	3300	1	2D
0005435884463	3300	2	4F
0005435884476	3300	3	10C
0005435884465	3300	4	11E
0005435884373	3300	5	15A
0005435884464	3300	6	16C
0005435884462	3300	7	16E
0005435884477	3300	8	16D
0005435884375	3300	9	17A
0005435884399	3300	10	17C
0005435884387	3300	11	17E
0005435884417	3300	12	18E
0005435884374	3300	13	20F
0005435884478	3300	14	22F
0005435884473	3300	15	23D
0005435884577	3300	16	26B
0005432459257	8166	1	1A
0005435884642	8166	2	1C
0005432459238	8166	3	1D
0005432459256	8166	4	2A
0005432459269	8166	5	1F
0005435884664	8166	6	2C
0005435884631	8166	7	2F
0005435884659	8166	8	2D
0005432042538	8166	9	3A
0005435884635	8166	10	3C
0005432042548	8166	11	4A
0005435884671	8166	12	4D
0005435884653	8166	13	4C
0005432042546	8166	14	5A
0005432042540	8166	15	4F
0005435884657	8166	16	5C
0005435884623	8166	17	6A
0005432459229	8166	18	5F
0005432459224	8166	19	6C
0005432459240	8166	20	6D
0005435884637	8166	21	6F
0005435884626	8166	22	7F
0005432459270	8166	23	7D
0005435884656	8166	24	8A
0005432459276	8166	25	8C
0005432042552	8166	26	8B
0005432459262	8166	27	8D
0005435884674	8166	28	8E
0005432459268	8166	29	9B
0005435884628	8166	30	9A
0005435884640	8166	31	9C
0005432042541	8166	32	9E
0005432042551	8166	33	9D
0005434326262	8166	34	9F
0005435884672	8166	35	10A
0005435884636	8166	36	10C
0005435884662	8166	37	10B
0005435884639	8166	38	10D
0005432459228	8166	39	11A
0005433506867	8166	40	10F
0005435884673	8166	41	11B
0005432042539	8166	42	11E
0005432459227	8166	43	11D
0005432042547	8166	44	11C
0005432459265	8166	45	11F
0005435884675	8166	46	12A
0005432459245	8166	47	12D
0005432459241	8166	48	12C
0005432042545	8166	49	12F
0005433506884	8166	50	13B
0005432459243	8166	51	13F
0005432459233	8166	52	13E
0005435884625	8166	53	14A
0005432459251	8166	54	14C
0005432459267	8166	55	14B
0005435884630	8166	56	14D
0005432459263	8166	57	14E
0005432459258	8166	58	14F
0005435884638	8166	59	15C
0005432459244	8166	60	15B
0005432042544	8166	61	15E
0005435884648	8166	62	15D
0005432459255	8166	63	16A
0005432459271	8166	64	15F
0005435884665	8166	65	16C
0005435884670	8166	66	16B
0005432459272	8166	67	16E
0005435884669	8166	68	16D
0005435884651	8166	69	17A
0005433506883	8166	70	17B
0005432459260	8166	71	17E
0005435884654	8166	72	17D
0005435884652	8166	73	17F
0005435884663	8166	74	18A
0005432459254	8166	75	18D
0005432459264	8166	76	19B
0005432459232	8166	77	18E
0005432459253	8166	78	19E
0005432459274	8166	79	19D
0005432459236	8166	80	19C
0005432459234	8166	81	20B
0005432042550	8166	82	20A
0005435884624	8166	83	20C
0005432459230	8166	84	20F
0005432459266	8166	85	20E
0005435884667	8166	86	21A
0005435884634	8166	87	21D
0005432459223	8166	88	21C
0005435884644	8166	89	21E
0005435884643	8166	90	21F
0005432459246	8166	91	22B
0005432459249	8166	92	22C
0005435884641	8166	93	22D
0005432459235	8166	94	22F
0005432459225	8166	95	23B
0005435884646	8166	96	23A
0005435884629	8166	97	23C
0005432459231	8166	98	23D
0005435884632	8166	99	24A
0005435884666	8166	100	23F
0005435884645	8166	101	24B
0005435884660	8166	102	24D
0005432459248	8166	103	24C
0005435884661	8166	104	24F
0005435884622	8166	105	24E
0005435884627	8166	106	25A
0005432042543	8166	107	25E
0005432459242	8166	108	26B
0005432459252	8166	109	26C
0005432459237	8166	110	26E
0005432042549	8166	111	26D
0005432459239	8166	112	26F
0005435884658	8166	113	27B
0005435884650	8166	114	27A
0005432459250	8166	115	27D
0005432459273	8166	116	28A
0005432459226	8166	117	28F
0005434312295	8166	118	29B
0005435884668	8166	119	29C
0005434312294	8166	120	29D
0005435884633	8166	121	29E
0005434326263	8166	122	30A
0005432042542	8166	123	29F
0005432459261	8166	124	30C
0005435884655	8166	125	30B
0005435884647	8166	126	31B
0005432459259	8166	127	31A
0005432459247	8166	128	31C
0005432459275	8166	129	31D
0005435884649	8166	130	31E
0005433633216	8163	1	9B
0005433804780	8163	2	11C
0005433804792	8163	3	15B
0005433804879	8163	4	17D
0005433633217	8163	5	18D
0005433804779	8163	6	24A
0005432382710	4661	1	1A
0005432727781	4661	2	1C
0005432727786	4661	3	1D
0005432727790	4661	4	1F
0005433722138	4661	5	2A
0005432727782	4661	6	3A
0005432382722	4661	7	2F
0005432382713	4661	8	3C
0005432382706	4661	9	3F
0005432382692	4661	10	4A
0005433722132	4661	11	4C
0005432382717	4661	12	4D
0005433454850	4661	13	5A
0005432382724	4661	14	5D
0005433722133	4661	15	5E
0005432382714	4661	16	5F
0005432382702	4661	17	6C
0005432382726	4661	18	6D
0005433454848	4661	19	6F
0005433194826	4661	20	7A
0005432382719	4661	21	7C
0005432382720	4661	22	7D
0005433453739	4661	23	7E
0005432382711	4661	24	8A
0005433453737	4661	25	8C
0005432382695	4661	26	8D
0005432382716	4661	27	8E
0005432727784	4661	28	8F
0005432382703	4661	29	9C
0005432727789	4661	30	9D
0005432382693	4661	31	9E
0005432382696	4661	32	9F
0005432382707	4661	33	10D
0005432382718	4661	34	10F
0005432727788	4661	35	11A
0005433454849	4661	36	11F
0005432382721	4661	37	12C
0005432382698	4661	38	12D
0005432382712	4661	39	12E
0005433453738	4661	40	12F
0005433194827	4661	41	13F
0005433722139	4661	42	14C
0005433722134	4661	43	15A
0005432382699	4661	44	15D
0005433722136	4661	45	16A
0005432727791	4661	46	15F
0005432727780	4661	47	16C
0005432382694	4661	48	16D
0005432382704	4661	49	16E
0005432382708	4661	50	16F
0005432382701	4661	51	17A
0005432382691	4661	52	17C
0005432727783	4661	53	17D
0005432382697	4661	54	17E
0005433722135	4661	55	17F
0005433722140	4661	56	18A
0005432382700	4661	57	18C
0005432382709	4661	58	18D
0005432382725	4661	59	18E
0005433722137	4661	60	19A
0005432382723	4661	61	18F
0005432382715	4661	62	19D
0005432727787	4661	63	19F
0005432727785	4661	64	20A
0005432382705	4661	65	20F
0005432727759	30189	1	1D
0005432727732	30189	2	8E
0005432727723	30189	3	10F
0005432727733	30189	4	13C
0005432727741	30189	5	17E
0005435528999	1760	1	1A
0005435529000	1760	2	1C
0005433516775	1760	3	1D
0005435540734	1760	4	2A
0005435540752	1760	5	2D
0005435540748	1760	6	2F
0005435528989	1760	7	3A
0005435528991	1760	8	3C
0005435540739	1760	9	3D
0005435528996	1760	10	3F
0005435529002	1760	11	4C
0005435529009	1760	12	4D
0005435540736	1760	13	5A
0005435529006	1760	14	5D
0005435528993	1760	15	5F
0005435540743	1760	16	6A
0005435529003	1760	17	6E
0005433516772	1760	18	6F
0005435528992	1760	19	7C
0005435540741	1760	20	7E
0005432294459	1760	21	7F
0005435540750	1760	22	8C
0005433516774	1760	23	8D
0005435540745	1760	24	8F
0005433516768	1760	25	9C
0005433516776	1760	26	9D
0005435528998	1760	27	10D
0005433516777	1760	28	11C
0005433516771	1760	29	11D
0005435529010	1760	30	11F
0005435540737	1760	31	12A
0005435540754	1760	32	12C
0005435540740	1760	33	12D
0005432294457	1760	34	12F
0005435540735	1760	35	13A
0005435529001	1760	36	13D
0005435540744	1760	37	13E
0005435528997	1760	38	14A
0005435529005	1760	39	14C
0005435540753	1760	40	14E
0005433516770	1760	41	16C
0005435528995	1760	42	16E
0005433516769	1760	43	16F
0005435540746	1760	44	17A
0005435540738	1760	45	17C
0005435528990	1760	46	17F
0005432294458	1760	47	18A
0005435529007	1760	48	18C
0005435528994	1760	49	18D
0005435540747	1760	50	18E
0005435529004	1760	51	19A
0005435540755	1760	52	19D
0005433516773	1760	53	19E
0005435540751	1760	54	19F
0005435540749	1760	55	20C
0005435540742	1760	56	20D
0005435529008	1760	57	20F
0005433516721	22025	1	3C
0005432924981	22025	2	4A
0005432924977	22025	3	5A
0005432924978	22025	4	11F
0005432924979	22025	5	12D
0005432924980	22025	6	20E
0005432838654	7400	1	1A
0005432838656	7400	2	1D
0005432838645	7400	3	1F
0005432838650	7400	4	2C
0005432838665	7400	5	2D
0005434458555	7400	6	2F
0005432838667	7400	7	3C
0005432838658	7400	8	3D
0005432838652	7400	9	3F
0005432838666	7400	10	4A
0005434458548	7400	11	4C
0005432073348	7400	12	4D
0005434458546	7400	13	4F
0005434458550	7400	14	5A
0005434458549	7400	15	5E
0005432823424	7400	16	5F
0005432838664	7400	17	6A
0005432838660	7400	18	6C
0005432840986	7400	19	6D
0005434458560	7400	20	6E
0005432838644	7400	21	6F
0005432838663	7400	22	7A
0005432838646	7400	23	7F
0005432838647	7400	24	8A
0005432838669	7400	25	8C
0005432073349	7400	26	8D
0005434458541	7400	27	8F
0005434458558	7400	28	9A
0005434458544	7400	29	9C
0005432838670	7400	30	9D
0005432838649	7400	31	9F
0005434458547	7400	32	10A
0005434458552	7400	33	10E
0005434458540	7400	34	11A
0005434458554	7400	35	11C
0005432838668	7400	36	11D
0005434458556	7400	37	11F
0005432838642	7400	38	12A
0005432838651	7400	39	12F
0005434458551	7400	40	13C
0005432838659	7400	41	13F
0005434458557	7400	42	14A
0005432838643	7400	43	14F
0005432838661	7400	44	15A
0005432838662	7400	45	15D
0005432838671	7400	46	15E
0005434458545	7400	47	16C
0005432073347	7400	48	16D
0005435252378	7400	49	16E
0005432840985	7400	50	16F
0005432838648	7400	51	17F
0005432838655	7400	52	18A
0005434458543	7400	53	18D
0005434458553	7400	54	18E
0005432838641	7400	55	19A
0005432073346	7400	56	19C
0005432838653	7400	57	19D
0005434458542	7400	58	19E
0005434458559	7400	59	20C
0005432838657	7400	60	20D
0005432838516	28904	1	2A
0005432000998	28904	2	2C
0005435252484	28904	3	3C
0005435252476	28904	4	3D
0005435252472	28904	5	4A
0005435252475	28904	6	4E
0005435252479	28904	7	5C
0005432838536	28904	8	6F
0005432838512	28904	9	7A
0005435252482	28904	10	7C
0005434664932	28904	11	7F
0005435252474	28904	12	8A
0005435491415	28904	13	8C
0005435252490	28904	14	8D
0005435252483	28904	15	8E
0005432000999	28904	16	8F
0005432838489	28904	17	9A
0005435252478	28904	18	10F
0005432838571	28904	19	11C
0005432838517	28904	20	11F
0005432823415	28904	21	12C
0005435252488	28904	22	12D
0005435252477	28904	23	12E
0005435252480	28904	24	13A
0005435252489	28904	25	13D
0005432838490	28904	26	13E
0005432838572	28904	27	14C
0005435252485	28904	28	14D
0005434458465	28904	29	14E
0005432838482	28904	30	14F
0005435252473	28904	31	15A
0005434458464	28904	32	15C
0005435491416	28904	33	17C
0005435252481	28904	34	17F
0005432838570	28904	35	18E
0005435252486	28904	36	19A
0005435252487	28904	37	19E
0005432000997	28904	38	19F
0005434275925	8829	1	5C
0005435990538	8829	2	6E
0005434275924	8829	3	7A
0005435990535	8829	4	7D
0005435990533	8829	5	9F
0005435990536	8829	6	11C
0005435990537	8829	7	11F
0005435990534	8829	8	12A
0005435990539	8829	9	20C
0005435990507	15770	1	1C
0005434275957	15770	2	6A
0005434275953	15770	3	8A
0005434275956	15770	4	7F
0005434275958	15770	5	11B
0005434275954	15770	6	11D
0005434275955	15770	7	15E
0005435990498	15770	8	18D
0005433468227	2091	1	1B
0005433468213	2091	2	1C
0005433468209	2091	3	1D
0005433468210	2091	4	2A
0005433468211	2091	5	2C
0005433468226	2091	6	3B
0005433468216	2091	7	4A
0005433468228	2091	8	4B
0005433468215	2091	9	4C
0005433468230	2091	10	4D
0005433468225	2091	11	5D
0005433468222	2091	12	6B
0005433468232	2091	13	6D
0005433468220	2091	14	7A
0005433468214	2091	15	7B
0005433468212	2091	16	7C
0005433468231	2091	17	7D
0005433468207	2091	18	18B
0005433468224	2091	19	18D
0005433468219	2091	20	19C
0005433468233	2091	21	19D
0005433468221	2091	22	20B
0005433468223	2091	23	20C
0005433468229	2091	24	21A
0005433468217	2091	25	21B
0005433468218	2091	26	21D
0005433468208	2091	27	22B
0005432359765	6384	1	1C
0005432359756	6384	2	1D
0005432359758	6384	3	2C
0005432359796	6384	4	2D
0005432359771	6384	5	2F
0005434149525	6384	6	3C
0005432335891	6384	7	3D
0005432335888	6384	8	3F
0005432335881	6384	9	4B
0005432359768	6384	10	4D
0005432335883	6384	11	4E
0005432359788	6384	12	4F
0005432359790	6384	13	5A
0005432359792	6384	14	5D
0005432359772	6384	15	5C
0005432359773	6384	16	5E
0005432359763	6384	17	5F
0005435176606	6384	18	6D
0005432359795	6384	19	6F
0005432359799	6384	20	6E
0005432335894	6384	21	7A
0005432359779	6384	22	7B
0005432359786	6384	23	7C
0005432359787	6384	24	8A
0005432335892	6384	25	8C
0005432062163	6384	26	8D
0005432359757	6384	27	8F
0005432359780	6384	28	9C
0005432335885	6384	29	9D
0005432363375	6384	30	10C
0005432359783	6384	31	10E
0005432335887	6384	32	11A
0005432363374	6384	33	11C
0005432359769	6384	34	11D
0005432359791	6384	35	11E
0005432062165	6384	36	12A
0005432062162	6384	37	12B
0005432335886	6384	38	12D
0005432335890	6384	39	12E
0005432359760	6384	40	12F
0005432359781	6384	41	13D
0005435176598	6384	42	13E
0005432359762	6384	43	13F
0005432359754	6384	44	14A
0005432359789	6384	45	14B
0005432359794	6384	46	14D
0005432359784	6384	47	14E
0005432062164	6384	48	14F
0005432359798	6384	49	15B
0005432335882	6384	50	15D
0005432062161	6384	51	15F
0005435176630	6384	52	16B
0005432359797	6384	53	16C
0005432359778	6384	54	17C
0005432359785	6384	55	17E
0005435176629	6384	56	18A
0005432359793	6384	57	17F
0005432359774	6384	58	18B
0005432359782	6384	59	18D
0005432359767	6384	60	18F
0005432359777	6384	61	19A
0005432359753	6384	62	19D
0005432359800	6384	63	19C
0005432335889	6384	64	19E
0005432359761	6384	65	19F
0005432363376	6384	66	20A
0005432335893	6384	67	20B
0005432359766	6384	68	20E
0005432359759	6384	69	20F
0005432359776	6384	70	21C
0005432359755	6384	71	21F
0005432335884	6384	72	22A
0005432359775	6384	73	22C
0005432359770	6384	74	22B
0005432359764	6384	75	22E
0005435176607	6384	76	23C
0005435176730	20981	1	1D
0005435176726	20981	2	2A
0005435176754	20981	3	2C
0005435176736	20981	4	2D
0005435723022	20981	5	3A
0005435176740	20981	6	2F
0005435176731	20981	7	3C
0005435176739	20981	8	3D
0005435176729	20981	9	3F
0005434149591	20981	10	4C
0005434149590	20981	11	4B
0005434149588	20981	12	4E
0005435490187	20981	13	4F
0005434149592	20981	14	6B
0005435176741	20981	15	6A
0005435176732	20981	16	6C
0005435176727	20981	17	6D
0005435176744	20981	18	6E
0005435176750	20981	19	6F
0005435176749	20981	20	7C
0005435176735	20981	21	8D
0005434149587	20981	22	8C
0005434149586	20981	23	8E
0005435176752	20981	24	9A
0005435176734	20981	25	8F
0005432052709	20981	26	9F
0005435176748	20981	27	11C
0005432359583	20981	28	12A
0005435176755	20981	29	12C
0005435176753	20981	30	12E
0005434149582	20981	31	13A
0005434149580	20981	32	13C
0005435176738	20981	33	13B
0005435723021	20981	34	13E
0005435176737	20981	35	13F
0005432359582	20981	36	15A
0005434149589	20981	37	15C
0005435176742	20981	38	15F
0005435176728	20981	39	16B
0005435176743	20981	40	16C
0005432359529	20981	41	17D
0005434149584	20981	42	17F
0005434149585	20981	43	18A
0005435176733	20981	44	18B
0005435176751	20981	45	18C
0005434149583	20981	46	18E
0005432359588	20981	47	19C
0005435176745	20981	48	19B
0005435723020	20981	49	21A
0005435490186	20981	50	21B
0005435176747	20981	51	23A
0005435490185	20981	52	22F
0005435176746	20981	53	23B
0005434149581	20981	54	23F
0005434458471	17740	1	1A
0005434186163	17740	2	3D
0005434186164	17740	3	5A
0005434458490	17740	4	7C
0005434448259	17740	5	18A
0005434458439	17740	6	19B
0005434458453	17740	7	20C
0005434458438	17740	8	22A
0005434448260	17740	9	23B
0005434463902	29080	1	1A
0005434458555	29080	2	1C
0005434458559	29080	3	1D
0005434458557	29080	4	2A
0005434458545	29080	5	2B
0005434458550	29080	6	2D
0005434448270	29080	7	3C
0005434458552	29080	8	4B
0005434458554	29080	9	4C
0005434458548	29080	10	5A
0005434463900	29080	11	5B
0005434462762	29080	12	5D
0005434458553	29080	13	6B
0005434458556	29080	14	6C
0005434458549	29080	15	7A
0005434458546	29080	16	7C
0005434458541	29080	17	7D
0005434458543	29080	18	18A
0005434462761	29080	19	18C
0005434448269	29080	20	19A
0005434462763	29080	21	19C
0005434458540	29080	22	20A
0005434458558	29080	23	20B
0005434458542	29080	24	20C
0005434458547	29080	25	20D
0005434458551	29080	26	21A
0005434463901	29080	27	21C
0005434458544	29080	28	22A
0005434458560	29080	29	22B
0005434448268	29080	30	22D
0005432603815	21437	1	1A
0005432603822	21437	2	1B
0005432603826	21437	3	1C
0005432603810	21437	4	2B
0005432603807	21437	5	3A
0005432603827	21437	6	3C
0005432603811	21437	7	3D
0005432603805	21437	8	4A
0005432603838	21437	9	4B
0005432603834	21437	10	4C
0005432603843	21437	11	4D
0005432603804	21437	12	5A
0005432603806	21437	13	5B
0005432603823	21437	14	5C
0005432603830	21437	15	5D
0005432603812	21437	16	6A
0005432603820	21437	17	6B
0005432603824	21437	18	6C
0005432603837	21437	19	6D
0005432603841	21437	20	7B
0005432603819	21437	21	7C
0005432603818	21437	22	18A
0005432603816	21437	23	18B
0005432603833	21437	24	18C
0005432603839	21437	25	19B
0005432603842	21437	26	19C
0005432603831	21437	27	19D
0005432603829	21437	28	20A
0005432603817	21437	29	20C
0005432603840	21437	30	20D
0005432603821	21437	31	21A
0005432603814	21437	32	21B
0005432603836	21437	33	21C
0005432603809	21437	34	21D
0005432603835	21437	35	22A
0005432603828	21437	36	22B
0005432603813	21437	37	22C
0005432603808	21437	38	22D
0005432603825	21437	39	23A
0005432603832	21437	40	23B
0005435221043	31658	1	2D
0005432603657	31658	2	4A
0005432603675	31658	3	4C
0005435221042	31658	4	6D
0005435221041	31658	5	18B
0005432603676	31658	6	19C
0005435221503	31658	7	20C
0005435904889	18820	1	1A
0005434604850	22317	1	1A
0005434604852	22317	2	1B
0005434606780	22317	3	2A
0005434606778	22317	4	2B
0005434606776	22317	5	3A
0005434604849	22317	6	3B
0005434604853	22317	7	4A
0005434606781	22317	8	4B
0005434606779	22317	9	5A
0005434604851	22317	10	5B
0005434606777	22317	11	6B
0005432747070	399	1	1A
0005432747092	399	2	1D
0005432747096	399	3	1F
0005432747063	399	4	3C
0005432747100	399	5	3F
0005432747082	399	6	4A
0005432747088	399	7	4E
0005432751481	399	8	5C
0005432747079	399	9	5D
0005432749755	399	10	5E
0005432747068	399	11	5F
0005432747085	399	12	6A
0005432747074	399	13	6C
0005432747089	399	14	6F
0005432747078	399	15	7A
0005432753256	399	16	7C
0005432219951	399	17	7E
0005432747064	399	18	7F
0005432747080	399	19	8A
0005432747069	399	20	9A
0005432747087	399	21	9D
0005432747083	399	22	9F
0005432219947	399	23	10A
0005432747076	399	24	10C
0005432753258	399	25	10E
0005432747075	399	26	11A
0005432747062	399	27	11C
0005432747094	399	28	12A
0005432747077	399	29	12C
0005432747095	399	30	12E
0005432747084	399	31	12F
0005432747081	399	32	13A
0005432747071	399	33	13C
0005432219948	399	34	13D
0005432753257	399	35	13F
0005432747097	399	36	14A
0005432747086	399	37	14C
0005432753255	399	38	15A
0005432747066	399	39	15D
0005432749756	399	40	16C
0005432751483	399	41	16D
0005432747073	399	42	16E
0005432751482	399	43	17A
0005432219950	399	44	17D
0005432747098	399	45	17E
0005432747091	399	46	18D
0005432747067	399	47	18F
0005432747093	399	48	18E
0005432747065	399	49	19A
0005432219949	399	50	19C
0005432747090	399	51	19E
0005432747072	399	52	20C
0005432747099	399	53	20D
0005433293164	12079	1	1A
0005432890772	12079	2	1C
0005434153520	12079	3	1D
0005432890779	12079	4	2C
0005432890780	12079	5	2D
0005433293168	12079	6	2F
0005433293173	12079	7	3C
0005432890783	12079	8	4A
0005432890781	12079	9	4E
0005433293170	12079	10	4F
0005432890788	12079	11	5D
0005433293174	12079	12	6C
0005433875360	12079	13	6D
0005433293169	12079	14	6F
0005433293165	12079	15	7A
0005432890778	12079	16	7E
0005432746902	12079	17	8E
0005432890776	12079	18	9A
0005432890769	12079	19	9C
0005432214777	12079	20	10C
0005433293175	12079	21	10D
0005433875362	12079	22	10F
0005432890773	12079	23	11C
0005432890770	12079	24	11D
0005432746887	12079	25	12C
0005432746932	12079	26	12F
0005432890787	12079	27	13E
0005432746930	12079	28	14C
0005432890777	12079	29	14F
0005433293177	12079	30	15A
0005433293171	12079	31	15C
0005433293172	12079	32	15D
0005433293167	12079	33	16E
0005432746890	12079	34	16F
0005433293166	12079	35	17A
0005433293176	12079	36	17C
0005432890775	12079	37	17D
0005432890771	12079	38	17E
0005432890785	12079	39	17F
0005432890786	12079	40	18A
0005433875363	12079	41	18C
0005432890774	12079	42	19A
0005433875361	12079	43	19C
0005432890782	12079	44	19D
0005432890784	12079	45	19E
0005434153519	12079	46	19F
0005432746929	12079	47	20C
0005433524898	18982	1	1D
0005433524900	18982	2	3A
0005433531244	18982	3	3C
0005433533257	18982	4	3D
0005433524896	18982	5	4A
0005433531241	18982	6	4B
0005433524891	18982	7	4C
0005433524892	18982	8	5B
0005433533258	18982	9	6B
0005433531242	18982	10	7A
0005433524893	18982	11	18A
0005433524890	18982	12	19C
0005433524895	18982	13	20D
0005433524899	18982	14	21B
0005433524894	18982	15	22A
0005433533259	18982	16	22B
0005433531243	18982	17	22D
0005433524897	18982	18	23B
0005432927919	32514	1	2A
0005432927916	32514	2	3D
0005433524855	32514	3	4A
0005432927920	32514	4	20A
0005432927918	32514	5	20C
0005432927917	32514	6	21C
0005433524856	32514	7	22A
0005432927915	32514	8	22D
0005432927914	32514	9	23A
0005432121160	5260	1	1A
0005434821999	5260	2	1H
0005434821977	5260	3	1G
0005432121156	5260	4	2D
0005434822070	5260	5	2H
0005434821983	5260	6	2K
0005434822043	5260	7	3D
0005434821966	5260	8	3K
0005434822027	5260	9	3G
0005434822075	5260	10	4H
0005434822060	5260	11	5H
0005434822048	5260	12	5G
0005434822037	5260	13	11C
0005434822038	5260	14	11A
0005434822078	5260	15	5K
0005434822042	5260	16	11D
0005434822014	5260	17	11F
0005434822051	5260	18	11E
0005434558179	5260	19	11K
0005434821987	5260	20	12C
0005434822049	5260	21	12A
0005434822007	5260	22	12G
0005434822044	5260	23	12F
0005434822085	5260	24	13G
0005434822087	5260	25	13K
0005432396194	5260	26	14D
0005435149869	5260	27	14G
0005434822056	5260	28	14K
0005434558174	5260	29	15D
0005432121159	5260	30	15H
0005434822024	5260	31	15G
0005435372150	5260	32	15F
0005434822004	5260	33	16D
0005434822068	5260	34	16C
0005434821997	5260	35	16H
0005434822018	5260	36	17C
0005434821964	5260	37	17E
0005434821972	5260	38	17G
0005434822036	5260	39	17H
0005435149862	5260	40	18C
0005434821996	5260	41	18A
0005434821969	5260	42	18E
0005434822017	5260	43	18H
0005432121161	5260	44	19D
0005434831086	5260	45	19C
0005432121165	5260	46	19B
0005434822019	5260	47	19H
0005434664931	5260	48	19K
0005434822032	5260	49	20C
0005435372250	5260	50	20B
0005434822055	5260	51	20E
0005434822011	5260	52	20G
0005434558175	5260	53	21C
0005435149857	5260	54	21H
0005434822025	5260	55	21G
0005434821979	5260	56	21K
0005435372249	5260	57	22F
0005434821982	5260	58	22E
0005434822012	5260	59	23B
0005434822015	5260	60	23A
0005434822054	5260	61	22K
0005434828661	5260	62	23E
0005435149861	5260	63	23D
0005435149866	5260	64	23F
0005434822080	5260	65	24D
0005432121157	5260	66	24E
0005434821975	5260	67	24G
0005434822086	5260	68	25D
0005434822063	5260	69	25C
0005434822076	5260	70	25F
0005434822059	5260	71	25G
0005435149859	5260	72	26A
0005435149856	5260	73	26E
0005434821968	5260	74	26F
0005434831088	5260	75	26K
0005435372145	5260	76	27A
0005434821973	5260	77	27C
0005434821985	5260	78	27F
0005435149860	5260	79	27E
0005434822003	5260	80	27G
0005434822035	5260	81	28C
0005432121158	5260	82	28B
0005432121163	5260	83	28D
0005434822047	5260	84	28G
0005434822072	5260	85	29A
0005434822021	5260	86	28K
0005432396193	5260	87	29C
0005434822009	5260	88	29E
0005434822079	5260	89	29H
0005432394053	5260	90	29G
0005434822000	5260	91	29K
0005434822084	5260	92	30B
0005434822064	5260	93	30A
0005434822071	5260	94	30E
0005432121166	5260	95	30D
0005434822088	5260	96	30G
0005434822001	5260	97	30F
0005435149867	5260	98	30K
0005434558171	5260	99	30J
0005434822058	5260	100	30H
0005434822028	5260	101	31B
0005432394056	5260	102	31A
0005434822030	5260	103	31E
0005434831089	5260	104	31K
0005434822090	5260	105	31J
0005434821994	5260	106	32E
0005432121162	5260	107	32G
0005435149865	5260	108	32J
0005434822033	5260	109	32K
0005434822077	5260	110	33D
0005434822089	5260	111	33B
0005434821976	5260	112	33F
0005434558178	5260	113	33E
0005434822005	5260	114	33G
0005434822010	5260	115	33K
0005434821965	5260	116	34A
0005434821984	5260	117	34E
0005432121167	5260	118	34D
0005434822081	5260	119	34K
0005434821986	5260	120	35B
0005435304098	5260	121	35D
0005435149863	5260	122	35C
0005434558173	5260	123	35G
0005434821962	5260	124	35F
0005434822029	5260	125	35H
0005434822006	5260	126	36A
0005434822016	5260	127	36E
0005434822065	5260	128	36D
0005434828660	5260	129	36G
0005435372281	5260	130	36H
0005434821967	5260	131	37A
0005434822002	5260	132	37E
0005434822046	5260	133	37D
0005432121155	5260	134	37F
0005434822083	5260	135	37G
0005434822008	5260	136	38H
0005434822026	5260	137	39B
0005434822069	5260	138	39F
0005432394055	5260	139	39E
0005435149868	5260	140	39H
0005434822045	5260	141	40C
0005435372279	5260	142	40F
0005432121164	5260	143	40J
0005435149858	5260	144	41B
0005434822040	5260	145	41A
0005434822067	5260	146	41D
0005434821978	5260	147	41G
0005434822061	5260	148	41F
0005435372280	5260	149	41E
0005434822074	5260	150	41H
0005434821963	5260	151	42A
0005434822053	5260	152	41J
0005434822050	5260	153	42B
0005434821998	5260	154	42E
0005434558172	5260	155	42G
0005434822062	5260	156	42J
0005435372190	5260	157	43D
0005435372159	5260	158	43C
0005434831087	5260	159	43B
0005434821990	5260	160	43G
0005434822082	5260	161	44A
0005434821970	5260	162	43K
0005434828659	5260	163	43J
0005434821989	5260	164	44B
0005434821995	5260	165	44F
0005432121168	5260	166	44J
0005434821971	5260	167	44H
0005434821992	5260	168	45A
0005434822031	5260	169	45C
0005435149864	5260	170	45E
0005434822039	5260	171	45H
0005434822023	5260	172	45G
0005432396195	5260	173	45J
0005434822034	5260	174	46D
0005432394054	5260	175	46C
0005434821988	5260	176	46F
0005434558176	5260	177	47A
0005432394052	5260	178	47D
0005434558177	5260	179	47F
0005434664930	5260	180	47K
0005434821993	5260	181	48D
0005434822020	5260	182	48C
0005434822022	5260	183	48E
0005434822066	5260	184	49C
0005434822073	5260	185	49E
0005434822057	5260	186	49D
0005434821981	5260	187	49G
0005434821980	5260	188	49F
0005434821974	5260	189	50C
0005434821991	5260	190	50A
0005435372146	5260	191	50E
0005434822052	5260	192	50F
0005434822041	5260	193	51F
0005432396192	5260	194	51E
0005434822013	5260	195	51G
0005435372476	9935	1	1A
0005435302141	9935	2	1H
0005435372493	9935	3	1D
0005432396172	9935	4	2G
0005435372465	9935	5	3K
0005435302143	9935	6	5A
0005435372445	9935	7	5C
0005435386489	9935	8	5G
0005435302140	9935	9	5H
0005435299719	9935	10	11C
0005435372490	9935	11	11K
0005435299718	9935	12	12C
0005435372456	9935	13	12G
0005432823425	9935	14	13A
0005435372458	9935	15	13E
0005435661895	9935	16	13H
0005435372434	9935	17	14C
0005435372453	9935	18	14A
0005434821353	9935	19	15C
0005434821409	9935	20	15A
0005434821669	9935	21	16C
0005435302139	9935	22	16H
0005432202973	9935	23	16K
0005435372478	9935	24	17H
0005432823426	9935	25	18D
0005435302142	9935	26	19A
0005435386490	9935	27	18K
0005434821408	9935	28	19D
0005435735085	9935	29	19C
0005435299717	9935	30	19J
0005435372460	9935	31	19H
0005435372486	9935	32	20E
0005435372473	9935	33	20D
0005435372430	9935	34	20H
0005434821421	9935	35	20F
0005435386492	9935	36	20J
0005435372487	9935	37	21D
0005435372462	9935	38	21E
0005434821384	9935	39	21K
0005435735082	9935	40	22H
0005432202972	9935	41	23B
0005434821698	9935	42	23J
0005435372455	9935	43	24D
0005434821370	9935	44	24F
0005435735081	9935	45	24E
0005435386496	9935	46	24G
0005432202974	9935	47	25G
0005435372436	9935	48	25K
0005435372441	9935	49	26J
0005435372444	9935	50	27C
0005435372442	9935	51	27F
0005435661894	9935	52	27G
0005435299715	9935	53	28A
0005435372466	9935	54	28C
0005435372467	9935	55	28E
0005435386493	9935	56	28G
0005435372439	9935	57	28F
0005434821671	9935	58	28K
0005435372435	9935	59	28J
0005435386495	9935	60	29A
0005434821385	9935	61	29D
0005434821490	9935	62	29F
0005435372479	9935	63	29E
0005435372438	9935	64	30C
0005435372449	9935	65	30G
0005435372440	9935	66	31C
0005435372484	9935	67	32C
0005435372492	9935	68	32G
0005435372469	9935	69	32F
0005435372489	9935	70	33B
0005435372452	9935	71	33F
0005435372431	9935	72	33E
0005435372428	9935	73	33J
0005435372472	9935	74	33G
0005435372446	9935	75	34A
0005435372426	9935	76	34D
0005435372432	9935	77	34C
0005435372450	9935	78	34G
0005435735083	9935	79	34F
0005432202977	9935	80	35A
0005435386491	9935	81	34K
0005435372468	9935	82	35J
0005434821410	9935	83	35G
0005435372483	9935	84	36B
0005435372461	9935	85	36G
0005435372448	9935	86	37D
0005434821394	9935	87	37F
0005435372447	9935	88	37J
0005432202975	9935	89	37H
0005435372491	9935	90	38C
0005435372485	9935	91	39D
0005435661896	9935	92	39B
0005432202971	9935	93	39J
0005435372480	9935	94	40E
0005435372464	9935	95	40D
0005434821378	9935	96	40H
0005435372429	9935	97	40G
0005435372457	9935	98	40F
0005432202970	9935	99	41F
0005432396170	9935	100	42A
0005435372451	9935	101	41K
0005435372437	9935	102	42B
0005432396171	9935	103	42G
0005435372471	9935	104	42K
0005435386494	9935	105	43J
0005434821395	9935	106	44C
0005435372481	9935	107	44B
0005435372474	9935	108	46A
0005432202976	9935	109	45J
0005435372470	9935	110	46F
0005435735084	9935	111	47A
0005435372433	9935	112	47E
0005432202978	9935	113	47D
0005435372443	9935	114	47C
0005435372454	9935	115	47G
0005435372463	9935	116	47K
0005435299716	9935	117	48D
0005435372488	9935	118	48F
0005435372427	9935	119	48E
0005434821393	9935	120	48H
0005435372459	9935	121	49A
0005435372475	9935	122	49E
0005435386497	9935	123	49F
0005435372482	9935	124	50C
0005435372477	9935	125	50H
0005434821555	9935	126	51E
0005435082686	7016	1	1A
0005435082689	7016	2	3C
0005435082690	7016	3	3D
0005435082692	7016	4	4C
0005435790271	7016	5	4D
0005435082688	7016	6	6A
0005435082693	7016	7	7A
0005435082684	7016	8	7B
0005435082694	7016	9	19B
0005435082691	7016	10	19C
0005435082685	7016	11	19D
0005435790270	7016	12	20A
0005435082687	7016	13	21C
0005435082643	26017	1	1C
0005435082648	26017	2	19A
0005435082649	26017	3	22A
0005434755942	9526	1	1F
0005434755945	9526	2	2F
0005434755949	9526	3	3D
0005434755929	9526	4	4A
0005434755953	9526	5	4C
0005434755923	9526	6	4D
0005434755926	9526	7	6A
0005434755938	9526	8	6D
0005434755935	9526	9	6E
0005434755956	9526	10	6F
0005434755939	9526	11	8C
0005434755957	9526	12	8E
0005434755958	9526	13	9A
0005434755952	9526	14	9E
0005434755930	9526	15	10A
0005434755931	9526	16	10C
0005434755960	9526	17	11A
0005434755955	9526	18	11D
0005434755959	9526	19	11E
0005434755944	9526	20	12C
0005434755922	9526	21	12D
0005434755941	9526	22	12F
0005434755936	9526	23	13A
0005434755951	9526	24	13D
0005434755937	9526	25	13F
0005434755927	9526	26	14F
0005434755948	9526	27	15A
0005434213705	9526	28	15C
0005434213712	9526	29	15D
0005434755947	9526	30	15F
0005434755940	9526	31	16A
0005434755925	9526	32	16C
0005434213706	9526	33	16D
0005434755933	9526	34	16E
0005434755946	9526	35	17C
0005434755934	9526	36	17E
0005434755932	9526	37	17F
0005434755928	9526	38	19E
0005434755950	9526	39	19F
0005434755943	9526	40	20A
0005434755924	9526	41	20C
0005434755954	9526	42	20D
0005434213900	28620	1	1A
0005434213920	28620	2	1C
0005434213927	28620	3	2A
0005434213921	28620	4	2D
0005434213913	28620	5	3C
0005434213935	28620	6	3D
0005434213910	28620	7	4C
0005434213901	28620	8	4F
0005434213914	28620	9	5C
0005434213894	28620	10	5F
0005434213932	28620	11	6A
0005434213906	28620	12	6D
0005434213931	28620	13	6F
0005434213929	28620	14	7A
0005434213890	28620	15	7D
0005434213891	28620	16	7F
0005434213899	28620	17	8A
0005434213924	28620	18	8C
0005434213925	28620	19	9A
0005434213892	28620	20	9E
0005434213923	28620	21	9F
0005434213895	28620	22	10C
0005434213930	28620	23	10D
0005434213908	28620	24	10E
0005434213909	28620	25	11A
0005434213926	28620	26	11C
0005434213896	28620	27	12C
0005434213934	28620	28	12D
0005434213928	28620	29	12F
0005434213912	28620	30	12E
0005434213905	28620	31	13A
0005434213907	28620	32	13C
0005434213915	28620	33	13E
0005434213911	28620	34	14A
0005434213918	28620	35	14C
0005434213919	28620	36	14E
0005434213904	28620	37	14F
0005434213902	28620	38	15C
0005434213916	28620	39	15D
0005434213933	28620	40	15E
0005434213893	28620	41	15F
0005434213897	28620	42	16F
0005434213917	28620	43	17A
0005434213903	28620	44	17C
0005434213922	28620	45	18D
0005434213898	28620	46	19D
0005434213889	28620	47	20D
0005435100086	10851	1	4D
0005435100085	10851	2	22A
0005435100073	31839	1	1A
0005434760166	31839	2	2C
0005434760167	31839	3	18C
0005435100072	31839	4	22D
0005434639008	1970	1	1A
0005434639005	1970	2	1B
0005434639006	1970	3	2A
0005432290595	1970	4	2C
0005434638996	1970	5	2D
0005432290597	1970	6	3A
0005432290594	1970	7	3C
0005434639010	1970	8	3D
0005434639011	1970	9	4B
0005434639012	1970	10	4D
0005434638997	1970	11	5B
0005434639007	1970	12	5C
0005434638994	1970	13	6A
0005434638990	1970	14	6B
0005434638998	1970	15	7C
0005434638991	1970	16	18A
0005434638992	1970	17	18B
0005434638986	1970	18	18D
0005434639000	1970	19	19A
0005434638987	1970	20	19B
0005434639009	1970	21	19D
0005434638988	1970	22	20A
0005434638999	1970	23	20B
0005434639003	1970	24	20C
0005434638995	1970	25	20D
0005434639002	1970	26	21A
0005434639001	1970	27	21B
0005434638985	1970	28	21D
0005432290596	1970	29	22A
0005434639004	1970	30	22C
0005434638993	1970	31	22D
0005434638989	1970	32	23B
0005433202167	23289	1	1A
0005433202168	23289	2	2B
0005433202169	23289	3	3B
0005433202164	23289	4	3D
0005433202165	23289	5	4C
0005433202174	23289	6	5B
0005433202163	23289	7	6D
0005433202171	23289	8	7A
0005433202175	23289	9	7D
0005433202170	23289	10	19A
0005433202176	23289	11	20A
0005433202173	23289	12	20D
0005433202166	23289	13	22B
0005433202172	23289	14	23A
0005434600479	6091	1	1A
0005434600485	6091	2	1F
0005434600488	6091	3	4A
0005433533262	6091	4	4C
0005432111244	6091	5	4E
0005434600466	6091	6	5A
0005434600477	6091	7	5E
0005432111242	6091	8	6A
0005433533260	6091	9	6C
0005434600490	6091	10	7C
0005434600471	6091	11	7E
0005434600474	6091	12	7F
0005434600470	6091	13	8E
0005434600472	6091	14	9C
0005433531248	6091	15	10C
0005435326506	6091	16	10F
0005434600491	6091	17	11A
0005435326507	6091	18	11C
0005434600478	6091	19	12A
0005434600473	6091	20	12E
0005434600465	6091	21	13C
0005434600493	6091	22	13D
0005432111241	6091	23	13E
0005433533261	6091	24	13F
0005434600492	6091	25	14D
0005434600486	6091	26	14E
0005432111243	6091	27	15A
0005433531245	6091	28	15C
0005434600487	6091	29	15F
0005434600481	6091	30	16C
0005434600480	6091	31	16E
0005434600469	6091	32	17A
0005434600475	6091	33	17C
0005434600467	6091	34	17E
0005433531246	6091	35	18A
0005434600468	6091	36	18C
0005434600483	6091	37	18D
0005433531247	6091	38	18E
0005434600484	6091	39	19A
0005434600476	6091	40	19E
0005434600482	6091	41	20E
0005434600489	6091	42	20F
0005435326570	18591	1	4A
0005435326579	18591	2	4C
0005435326578	18591	3	4E
0005435326581	18591	4	6F
0005435326580	18591	5	7E
0005435326575	18591	6	9F
0005435326568	18591	7	10D
0005435326573	18591	8	10E
0005435326574	18591	9	13A
0005433531227	18591	10	14D
0005435326577	18591	11	15F
0005435326571	18591	12	16C
0005435326576	18591	13	16D
0005435326569	18591	14	16F
0005435326572	18591	15	18F
0005433531228	18591	16	20D
0005434600332	18591	17	20F
0005434550485	10609	1	1C
0005434550495	10609	2	2C
0005434558168	10609	3	2F
0005434550491	10609	4	3A
0005434550525	10609	5	3C
0005434550531	10609	6	3D
0005434550494	10609	7	3F
0005434550490	10609	8	4A
0005434550518	10609	9	4D
0005434550526	10609	10	4E
0005434550499	10609	11	4F
0005434550504	10609	12	5A
0005434550497	10609	13	5D
0005434550506	10609	14	5E
0005434550532	10609	15	6A
0005434550535	10609	16	5F
0005434550484	10609	17	6D
0005434550489	10609	18	6E
0005434550488	10609	19	6F
0005434550508	10609	20	7A
0005434550528	10609	21	7C
0005434558160	10609	22	7D
0005434550487	10609	23	7F
0005434558167	10609	24	8A
0005434550517	10609	25	8C
0005434558166	10609	26	8D
0005434558170	10609	27	8F
0005434558161	10609	28	9C
0005434550502	10609	29	9D
0005434550521	10609	30	9F
0005434558164	10609	31	10A
0005434554035	10609	32	10C
0005434550498	10609	33	10D
0005434550519	10609	34	10E
0005434558163	10609	35	10F
0005434550533	10609	36	11A
0005434550510	10609	37	11D
0005434550482	10609	38	11E
0005434550527	10609	39	11F
0005434550486	10609	40	12A
0005434550515	10609	41	12C
0005434550530	10609	42	12D
0005434550536	10609	43	12E
0005434554036	10609	44	12F
0005434550529	10609	45	13A
0005434550512	10609	46	13D
0005434550523	10609	47	13E
0005434558169	10609	48	14A
0005434550522	10609	49	14C
0005434550496	10609	50	14D
0005434550511	10609	51	15A
0005434550501	10609	52	15F
0005434550493	10609	53	16A
0005434550507	10609	54	16C
0005434550513	10609	55	16E
0005434550500	10609	56	17C
0005434550505	10609	57	17D
0005434550509	10609	58	17E
0005434558162	10609	59	18A
0005434550483	10609	60	18C
0005434550516	10609	61	18D
0005434550514	10609	62	19A
0005434558165	10609	63	19C
0005434550524	10609	64	19E
0005434550520	10609	65	20A
0005434550534	10609	66	20C
0005434550492	10609	67	20D
0005434550503	10609	68	20E
0005434554037	10609	69	20F
0005433180797	27732	1	1A
0005433180782	27732	2	2C
0005433180798	27732	3	2D
0005433180795	27732	4	3C
0005433180788	27732	5	4A
0005433180794	27732	6	5A
0005433180781	27732	7	5D
0005433180777	27732	8	6F
0005433180784	27732	9	7E
0005433180780	27732	10	7F
0005433180785	27732	11	8F
0005433180783	27732	12	9E
0005433180789	27732	13	10C
0005433180802	27732	14	10D
0005433180787	27732	15	10E
0005433180792	27732	16	11A
0005433180793	27732	17	12A
0005433180791	27732	18	12F
0005433180801	27732	19	13A
0005433180799	27732	20	14D
0005433180779	27732	21	15A
0005433180778	27732	22	18C
0005433180796	27732	23	18F
0005433180800	27732	24	19D
0005433180790	27732	25	19E
0005433180786	27732	26	20E
0005434550334	27733	1	16D
0005434550333	27733	2	19C
0005433459167	6168	1	2A
0005433459166	6168	2	3B
0005433459165	6168	3	4A
0005433459168	6168	4	6A
0005435254442	19319	1	1B
0005435254444	19319	2	4B
0005435254443	19319	3	6A
0005435681597	6732	1	1C
0005435681604	6732	2	1D
0005435681639	6732	3	1F
0005435681600	6732	4	2A
0005435681627	6732	5	2C
0005435630927	6732	6	2D
0005435681611	6732	7	3A
0005435681619	6732	8	3D
0005435681607	6732	9	3F
0005435681618	6732	10	4A
0005435681631	6732	11	4D
0005435681606	6732	12	4E
0005435681638	6732	13	4F
0005435681641	6732	14	5C
0005435681621	6732	15	5D
0005435681625	6732	16	5F
0005435437561	6732	17	6A
0005435681605	6732	18	6C
0005435661891	6732	19	6E
0005435720123	6732	20	6F
0005435720124	6732	21	7A
0005435630926	6732	22	7C
0005435681617	6732	23	7D
0005435681629	6732	24	7E
0005435437567	6732	25	7F
0005435681640	6732	26	8C
0005435437571	6732	27	8D
0005435681613	6732	28	8E
0005435681612	6732	29	9C
0005435719554	6732	30	9D
0005435681608	6732	31	9E
0005435681615	6732	32	9F
0005432136106	6732	33	10C
0005435681624	6732	34	10E
0005435681642	6732	35	10F
0005435681609	6732	36	11D
0005432136104	6732	37	11F
0005435681616	6732	38	12A
0005435681633	6732	39	12C
0005435720122	6732	40	12D
0005435681603	6732	41	12F
0005435681623	6732	42	13A
0005435630928	6732	43	13C
0005435681622	6732	44	13D
0005435681610	6732	45	13F
0005432136108	6732	46	14A
0005435681599	6732	47	14D
0005435681598	6732	48	15C
0005435661893	6732	49	15D
0005435437595	6732	50	15E
0005435681596	6732	51	16A
0005435719555	6732	52	16C
0005435437609	6732	53	16D
0005432136105	6732	54	16F
0005435681620	6732	55	17A
0005435681634	6732	56	17C
0005435437596	6732	57	17E
0005435681602	6732	58	17F
0005432136107	6732	59	18A
0005435681630	6732	60	18C
0005435681614	6732	61	18D
0005435661892	6732	62	18E
0005435681628	6732	63	18F
0005435681626	6732	64	19A
0005435437568	6732	65	19E
0005435681632	6732	66	19F
0005435681635	6732	67	20A
0005435681637	6732	68	20C
0005435681636	6732	69	20E
0005435681601	6732	70	20F
0005435437684	24566	1	1C
0005435681427	24566	2	2C
0005435437668	24566	3	3A
0005435437682	24566	4	3D
0005435437680	24566	5	3F
0005432305719	24566	6	4A
0005435220294	24566	7	4C
0005435437672	24566	8	4D
0005435437673	24566	9	4E
0005435219171	24566	10	5A
0005435220291	24566	11	5C
0005435219173	24566	12	5E
0005435437674	24566	13	6F
0005435437686	24566	14	7A
0005435437687	24566	15	7C
0005432533256	24566	16	7D
0005435437670	24566	17	7F
0005435437677	24566	18	8A
0005435437666	24566	19	8C
0005435437671	24566	20	8F
0005435681420	24566	21	9D
0005435681384	24566	22	9E
0005434828663	24566	23	9F
0005434828664	24566	24	10A
0005435437685	24566	25	10F
0005435437667	24566	26	11A
0005432533257	24566	27	11C
0005435437678	24566	28	11D
0005435681426	24566	29	12C
0005435437679	24566	30	12D
0005435437681	24566	31	12E
0005435681457	24566	32	12F
0005435681432	24566	33	13D
0005434828662	24566	34	13F
0005435220293	24566	35	14C
0005432533255	24566	36	14F
0005435437676	24566	37	15C
0005432305717	24566	38	17A
0005435219174	24566	39	17D
0005432305718	24566	40	17E
0005435681449	24566	41	17F
0005435437669	24566	42	18A
0005435437675	24566	43	18C
0005435437683	24566	44	19C
0005435681458	24566	45	19D
0005435220292	24566	46	20A
0005435219172	24566	47	20C
0005435681410	24566	48	20F
0005435105939	11510	1	1D
0005435125848	11510	2	2A
0005435125820	11510	3	2C
0005435125852	11510	4	2F
0005435125853	11510	5	3C
0005435125819	11510	6	3D
0005435125839	11510	7	3F
0005435125821	11510	8	4C
0005435125843	11510	9	4E
0005435125844	11510	10	4F
0005435125837	11510	11	5D
0005435125826	11510	12	5E
0005435125838	11510	13	5F
0005435125835	11510	14	6C
0005435125851	11510	15	6F
0005435125818	11510	16	7F
0005435125849	11510	17	8A
0005435125816	11510	18	8C
0005435125845	11510	19	8E
0005435125840	11510	20	9A
0005435125830	11510	21	9C
0005435125814	11510	22	9D
0005435125833	11510	23	9E
0005435125854	11510	24	9F
0005435125846	11510	25	10A
0005435125841	11510	26	10F
0005435125824	11510	27	11C
0005435105943	11510	28	11F
0005435125834	11510	29	12F
0005435125822	11510	30	13C
0005435125825	11510	31	13E
0005435125842	11510	32	13F
0005435125850	11510	33	14C
0005435125815	11510	34	14E
0005435125823	11510	35	14F
0005435105940	11510	36	15A
0005435125829	11510	37	15C
0005435125831	11510	38	15D
0005435125828	11510	39	16A
0005435105941	11510	40	16D
0005435125817	11510	41	17C
0005435125832	11510	42	17E
0005435105942	11510	43	17F
0005435125836	11510	44	19A
0005435125847	11510	45	19E
0005435125855	11510	46	19F
0005435125827	11510	47	20D
0005435125657	31904	1	1F
0005435125669	31904	2	4F
0005435125649	31904	3	11D
0005435125684	31904	4	12D
0005435125668	31904	5	17C
0005435558055	31904	6	17D
0005435558054	31904	7	18E
0005433397476	13541	1	1C
0005433397457	13541	2	2A
0005433397450	13541	3	2C
0005433397434	13541	4	2D
0005433397474	13541	5	2F
0005433397436	13541	6	3D
0005433397463	13541	7	3F
0005433397465	13541	8	4C
0005433397445	13541	9	4F
0005433397440	13541	10	5A
0005433397439	13541	11	5C
0005433397461	13541	12	5D
0005433397430	13541	13	6A
0005433397428	13541	14	6D
0005433397448	13541	15	6E
0005435732113	13541	16	7C
0005433397456	13541	17	7D
0005433397464	13541	18	8A
0005433397435	13541	19	8D
0005433397467	13541	20	8E
0005433397455	13541	21	8F
0005433397443	13541	22	9C
0005433397447	13541	23	9E
0005433397470	13541	24	9F
0005433397452	13541	25	10A
0005433397444	13541	26	10F
0005433397466	13541	27	11F
0005433397453	13541	28	12E
0005433397441	13541	29	13A
0005433397429	13541	30	13D
0005433397458	13541	31	13E
0005433397472	13541	32	13F
0005433397469	13541	33	14C
0005433397437	13541	34	14F
0005433397438	13541	35	15C
0005433397442	13541	36	15E
0005433397462	13541	37	15F
0005433397432	13541	38	16A
0005433397446	13541	39	16F
0005433397471	13541	40	17A
0005433397460	13541	41	17D
0005433397459	13541	42	17F
0005433397449	13541	43	18A
0005433397431	13541	44	19A
0005433397473	13541	45	19D
0005433397475	13541	46	19F
0005433397433	13541	47	20A
0005433397451	13541	48	20C
0005433397468	13541	49	20E
0005433397454	13541	50	20F
0005435732171	19398	1	1F
0005433397185	19398	2	2D
0005433397246	19398	3	4E
0005432297244	19398	4	5D
0005433397228	19398	5	6C
0005435732168	19398	6	7C
0005435732175	19398	7	7E
0005435732177	19398	8	8A
0005435732169	19398	9	8F
0005435732176	19398	10	9C
0005432297245	19398	11	10C
0005435732174	19398	12	12A
0005435732166	19398	13	12C
0005433397198	19398	14	12E
0005433397184	19398	15	13A
0005435732178	19398	16	13C
0005435732179	19398	17	14A
0005433397227	19398	18	14C
0005435732170	19398	19	17A
0005435732173	19398	20	17D
0005435732172	19398	21	18C
0005435732167	19398	22	19D
0005432297243	19398	23	20F
0005435068190	13145	1	1C
0005435925123	13145	2	6A
0005435925128	13145	3	6C
0005435925124	13145	4	6E
0005435925121	13145	5	8F
0005435925125	13145	6	13A
0005435925127	13145	7	13E
0005435925122	13145	8	14A
0005435068264	13145	9	15E
0005435068191	13145	10	15F
0005435925126	13145	11	19F
0005435068384	15458	1	1A
0005435068417	15458	2	1D
0005435068420	15458	3	1F
0005435068406	15458	4	2A
0005435068412	15458	5	2C
0005435068401	15458	6	3C
0005435068416	15458	7	3D
0005435068410	15458	8	4C
0005435068379	15458	9	4D
0005435068405	15458	10	4F
0005435068375	15458	11	5D
0005435068414	15458	12	5E
0005435068377	15458	13	7A
0005435068411	15458	14	7D
0005435068372	15458	15	7F
0005435068390	15458	16	8C
0005435068393	15458	17	8D
0005435068422	15458	18	8E
0005435068397	15458	19	8F
0005435068398	15458	20	9C
0005435068389	15458	21	9D
0005435068403	15458	22	10C
0005435068392	15458	23	10A
0005435068404	15458	24	10E
0005435068396	15458	25	10F
0005435068421	15458	26	11A
0005435068413	15458	27	11C
0005435068374	15458	28	11F
0005435068381	15458	29	12A
0005435068394	15458	30	12D
0005435068383	15458	31	13C
0005435068386	15458	32	13D
0005435068387	15458	33	13E
0005435068408	15458	34	13F
0005435068378	15458	35	14C
0005435068419	15458	36	14E
0005435068400	15458	37	14F
0005435068418	15458	38	15A
0005435068395	15458	39	15C
0005435068371	15458	40	15E
0005435068376	15458	41	15F
0005435068385	15458	42	16C
0005435068399	15458	43	16E
0005435068391	15458	44	16F
0005435068407	15458	45	17D
0005435068382	15458	46	18A
0005435068409	15458	47	18C
0005435068402	15458	48	18E
0005435068380	15458	49	18F
0005435068415	15458	50	19D
0005435068388	15458	51	19F
0005435068373	15458	52	20E
0005434213975	10696	1	1C
0005434213962	10696	2	2D
0005434213964	10696	3	2F
0005434213965	10696	4	3F
0005434213938	10696	5	4C
0005434213973	10696	6	4D
0005434213936	10696	7	4E
0005434213966	10696	8	5E
0005434213960	10696	9	6A
0005434213961	10696	10	6C
0005434213959	10696	11	7C
0005434213952	10696	12	7E
0005434213982	10696	13	8C
0005434213944	10696	14	8D
0005434213976	10696	15	8E
0005434213940	10696	16	9A
0005434213950	10696	17	9D
0005434213980	10696	18	9E
0005434213974	10696	19	10C
0005434213957	10696	20	10E
0005434213953	10696	21	11A
0005434213941	10696	22	11C
0005434213971	10696	23	11E
0005434213945	10696	24	11F
0005434213937	10696	25	12C
0005434213956	10696	26	12D
0005434213963	10696	27	12F
0005434213955	10696	28	13A
0005434213951	10696	29	14D
0005434213946	10696	30	14E
0005434213977	10696	31	14F
0005434213958	10696	32	15A
0005434213969	10696	33	15E
0005434213968	10696	34	15F
0005434213949	10696	35	16A
0005434213979	10696	36	16C
0005434213981	10696	37	16E
0005434213970	10696	38	17A
0005434213978	10696	39	17C
0005434213972	10696	40	17E
0005434213939	10696	41	18A
0005434213943	10696	42	18F
0005434213947	10696	43	19C
0005434213983	10696	44	19F
0005434213967	10696	45	20A
0005434213942	10696	46	20C
0005434213954	10696	47	20D
0005434213948	10696	48	20E
0005434755892	28678	1	1D
0005434755888	28678	2	1F
0005434755874	28678	3	2A
0005434755881	28678	4	2F
0005434755905	28678	5	4A
0005434755911	28678	6	4C
0005434755902	28678	7	4D
0005434755891	28678	8	4F
0005434755900	28678	9	5A
0005434755916	28678	10	5E
0005434755913	28678	11	6A
0005434755875	28678	12	6D
0005434755921	28678	13	6E
0005434755919	28678	14	7A
0005434755897	28678	15	7C
0005434755895	28678	16	7D
0005434755878	28678	17	7F
0005434755894	28678	18	8C
0005434755917	28678	19	8D
0005434755880	28678	20	9E
0005434755879	28678	21	9F
0005434755893	28678	22	10A
0005434755896	28678	23	10D
0005434755909	28678	24	10E
0005434755886	28678	25	11C
0005434755898	28678	26	11D
0005434755873	28678	27	11E
0005434755890	28678	28	11F
0005434755883	28678	29	12D
0005434755903	28678	30	13A
0005434755914	28678	31	13D
0005434755872	28678	32	13F
0005434755910	28678	33	14C
0005434755912	28678	34	14E
0005434755882	28678	35	14F
0005434755918	28678	36	15C
0005434755907	28678	37	15D
0005434755885	28678	38	16A
0005434755877	28678	39	16E
0005434755889	28678	40	17C
0005434755920	28678	41	17F
0005434755904	28678	42	18C
0005434755901	28678	43	18F
0005434755908	28678	44	19A
0005434755915	28678	45	19C
0005434755876	28678	46	19E
0005434755899	28678	47	19F
0005434755887	28678	48	20A
0005434755884	28678	49	20C
0005434755906	28678	50	20D
0005434755871	28678	51	20E
0005435006743	5425	1	1A
0005435038988	5425	2	1C
0005435038972	5425	3	1D
0005432125364	5425	4	2C
0005435038942	5425	5	3C
0005435038977	5425	6	3A
0005435038981	5425	7	3D
0005435038962	5425	8	4A
0005432125359	5425	9	4B
0005435038932	5425	10	4D
0005435006732	5425	11	4F
0005435006733	5425	12	5A
0005435038935	5425	13	5C
0005432125357	5425	14	5D
0005432125356	5425	15	5E
0005435038979	5425	16	6A
0005434228968	5425	17	5F
0005435038976	5425	18	6B
0005435038967	5425	19	6C
0005435038950	5425	20	6F
0005434228966	5425	21	6E
0005435038965	5425	22	7A
0005435038948	5425	23	7C
0005435006736	5425	24	7B
0005435006735	5425	25	7E
0005435038956	5425	26	7D
0005435038958	5425	27	8A
0005435038952	5425	28	8B
0005435038982	5425	29	8D
0005434228967	5425	30	8C
0005435038934	5425	31	8F
0005435038959	5425	32	8E
0005435038937	5425	33	9A
0005435006724	5425	34	9B
0005432125358	5425	35	9C
0005434228977	5425	36	9F
0005435038960	5425	37	10B
0005435038978	5425	38	10C
0005435038933	5425	39	10E
0005435006744	5425	40	11A
0005435006731	5425	41	11C
0005435006737	5425	42	11E
0005435038939	5425	43	12B
0005432125363	5425	44	12C
0005435038941	5425	45	12F
0005435006738	5425	46	13B
0005435006723	5425	47	13A
0005435038975	5425	48	13C
0005435006728	5425	49	13D
0005435038943	5425	50	13E
0005435038953	5425	51	13F
0005435038944	5425	52	14B
0005435038936	5425	53	14A
0005435038938	5425	54	14F
0005435038947	5425	55	14E
0005435038963	5425	56	15A
0005435038957	5425	57	15B
0005435006727	5425	58	15C
0005435006734	5425	59	15E
0005435038951	5425	60	15D
0005435006741	5425	61	16A
0005435038984	5425	62	15F
0005435006726	5425	63	16B
0005435006742	5425	64	16C
0005432125361	5425	65	16D
0005435038966	5425	66	16E
0005435038964	5425	67	16F
0005435038969	5425	68	17A
0005432125362	5425	69	17D
0005435038986	5425	70	17C
0005435006740	5425	71	17E
0005432125360	5425	72	18A
0005435006725	5425	73	17F
0005435038946	5425	74	18E
0005435038987	5425	75	18F
0005435038989	5425	76	19C
0005435038983	5425	77	19B
0005435038961	5425	78	19D
0005435038949	5425	79	19F
0005435038985	5425	80	19E
0005435038955	5425	81	20B
0005435038968	5425	82	20D
0005435038954	5425	83	20C
0005435006739	5425	84	20F
0005435038974	5425	85	21A
0005435006729	5425	86	21B
0005435038980	5425	87	21E
0005435038973	5425	88	21F
0005435006730	5425	89	22A
0005435038971	5425	90	22C
0005435038940	5425	91	22F
0005435006745	5425	92	22E
0005435038970	5425	93	23B
0005435038945	5425	94	23F
0005432304349	12972	1	1A
0005435006602	12972	2	2D
0005434229093	12972	3	2F
0005434229094	12972	4	3C
0005434229096	12972	5	3F
0005434229081	12972	6	4D
0005432304351	12972	7	4F
0005434229086	12972	8	5A
0005432304348	12972	9	5F
0005434229098	12972	10	6D
0005435006633	12972	11	7E
0005434229100	12972	12	8E
0005434229085	12972	13	9C
0005434229097	12972	14	9F
0005434229089	12972	15	10B
0005435006603	12972	16	11B
0005434229091	12972	17	11D
0005434229092	12972	18	11F
0005434229082	12972	19	13B
0005434229103	12972	20	13E
0005434229084	12972	21	14B
0005434229088	12972	22	16B
0005435006632	12972	23	16E
0005434229102	12972	24	18C
0005434229095	12972	25	18E
0005435006601	12972	26	19E
0005434229087	12972	27	20A
0005434229099	12972	28	20C
0005432304350	12972	29	20E
0005434229101	12972	30	21E
0005435006629	12972	31	22A
0005434229083	12972	32	23A
0005434229090	12972	33	23E
0005434426233	14890	1	1A
0005434426234	14890	2	1F
0005434426221	14890	3	2F
0005434426210	14890	4	3A
0005434426212	14890	5	3D
0005434426213	14890	6	4D
0005434426230	14890	7	4E
0005434426226	14890	8	5D
0005434411720	14890	9	5E
0005434411721	14890	10	5F
0005434426222	14890	11	6A
0005434426225	14890	12	7C
0005434426214	14890	13	8C
0005434411719	14890	14	8D
0005434426219	14890	15	9D
0005434426211	14890	16	9E
0005432188563	14890	17	10A
0005434426231	14890	18	10F
0005432188564	14890	19	11C
0005434426215	14890	20	12A
0005434426207	14890	21	12C
0005434411722	14890	22	12D
0005434411723	14890	23	13C
0005434426228	14890	24	14A
0005432188565	14890	25	15A
0005434426224	14890	26	16A
0005434426229	14890	27	16D
0005434426223	14890	28	16E
0005434426227	14890	29	17A
0005434426209	14890	30	17D
0005434426235	14890	31	18C
0005434426206	14890	32	18D
0005434426208	14890	33	18F
0005434426216	14890	34	19A
0005434426217	14890	35	19C
0005434426205	14890	36	19D
0005434426232	14890	37	19E
0005434426220	14890	38	19F
0005434426218	14890	39	20C
0005435902492	20198	1	1F
0005435902488	20198	2	2C
0005435902477	20198	3	2F
0005435902491	20198	4	4D
0005435902480	20198	5	4E
0005435902482	20198	6	5C
0005432059480	20198	7	5E
0005435902476	20198	8	7C
0005434426090	20198	9	7D
0005432059479	20198	10	8C
0005432059481	20198	11	9D
0005435554131	20198	12	10D
0005435902490	20198	13	10E
0005435554132	20198	14	11E
0005435902489	20198	15	12D
0005435902483	20198	16	13C
0005435902478	20198	17	13D
0005435554130	20198	18	13E
0005434426084	20198	19	14C
0005435902475	20198	20	15F
0005435902481	20198	21	16A
0005435902486	20198	22	16E
0005435902479	20198	23	17A
0005435902487	20198	24	18A
0005434426089	20198	25	18C
0005435902485	20198	26	19E
0005435902484	20198	27	20E
0005435554129	20198	28	20F
0005435981698	26523	1	1A
0005435981713	26523	2	1C
0005435981702	26523	3	1D
0005435981694	26523	4	2A
0005435981721	26523	5	2D
0005435981692	26523	6	3F
0005435981711	26523	7	4A
0005435981732	26523	8	4C
0005435981708	26523	9	5E
0005432300191	26523	10	5F
0005432300186	26523	11	6D
0005435981707	26523	12	7C
0005435981690	26523	13	7D
0005435981726	26523	14	7E
0005435981733	26523	15	7F
0005435981697	26523	16	8A
0005435981725	26523	17	8D
0005432300189	26523	18	8E
0005435981729	26523	19	9A
0005435981704	26523	20	10D
0005432300188	26523	21	10E
0005435981719	26523	22	10F
0005435981701	26523	23	11C
0005435981693	26523	24	11D
0005435981710	26523	25	11E
0005435981727	26523	26	12A
0005435981700	26523	27	12C
0005435981696	26523	28	12D
0005435981706	26523	29	13A
0005435981718	26523	30	13C
0005432300185	26523	31	13E
0005435981731	26523	32	14A
0005435981724	26523	33	14C
0005432300187	26523	34	14E
0005432300190	26523	35	14F
0005435981712	26523	36	15A
0005435981714	26523	37	15C
0005435981728	26523	38	15D
0005435981730	26523	39	15E
0005435981720	26523	40	16C
0005435981703	26523	41	17A
0005435981691	26523	42	17D
0005435981709	26523	43	17F
0005435981705	26523	44	18A
0005435981722	26523	45	18E
0005435981715	26523	46	18F
0005435981734	26523	47	19E
0005435981717	26523	48	19F
0005435981716	26523	49	20A
0005435981723	26523	50	20C
0005435981699	26523	51	20D
0005435981695	26523	52	20F
0005434270181	26736	1	1A
0005432051089	26736	2	1C
0005432051090	26736	3	1D
0005434269077	26736	4	3A
0005433434353	26736	5	3F
0005434270180	26736	6	4A
0005432051091	26736	7	4C
0005433434335	26736	8	4E
0005433434337	26736	9	4F
0005433434339	26736	10	5A
0005433434332	26736	11	5D
0005433434338	26736	12	6D
0005433434334	26736	13	7A
0005434271287	26736	14	7C
0005433434351	26736	15	7E
0005433434344	26736	16	8A
0005433434342	26736	17	8E
0005433434328	26736	18	9D
0005433434347	26736	19	9F
0005433434341	26736	20	10A
0005433434349	26736	21	11A
0005433434345	26736	22	12D
0005434271286	26736	23	12E
0005433434327	26736	24	13C
0005433434343	26736	25	13D
0005434269078	26736	26	14D
0005433434336	26736	27	14E
0005433434329	26736	28	15F
0005433434326	26736	29	16A
0005433434333	26736	30	16E
0005433434325	26736	31	17A
0005433434346	26736	32	18A
0005434269079	26736	33	18E
0005433434340	26736	34	19A
0005433434352	26736	35	19E
0005433434331	26736	36	20C
0005433434348	26736	37	20D
0005433434350	26736	38	20E
0005433434330	26736	39	20F
0005432583723	3153	1	1D
0005432583714	3153	2	2A
0005432583718	3153	3	2C
0005432583734	3153	4	3B
0005432583731	3153	5	3C
0005432583722	3153	6	3D
0005432583726	3153	7	4B
0005432583724	3153	8	4D
0005432583713	3153	9	5A
0005432583711	3153	10	5C
0005432583720	3153	11	5D
0005432216237	3153	12	6B
0005432583730	3153	13	6C
0005432583719	3153	14	7B
0005432583725	3153	15	18B
0005432216238	3153	16	18C
0005432583729	3153	17	18D
0005432583733	3153	18	19B
0005432583728	3153	19	19A
0005432583735	3153	20	19C
0005432583721	3153	21	19D
0005432857883	3153	22	20B
0005432583716	3153	23	21A
0005432583712	3153	24	21B
0005432583732	3153	25	21C
0005432583727	3153	26	22A
0005432583715	3153	27	22C
0005432583717	3153	28	23A
0005432857922	31468	1	1C
0005432857914	31468	2	2D
0005432857912	31468	3	4C
0005432857915	31468	4	5A
0005432857913	31468	5	5B
0005432857919	31468	6	5C
0005432857920	31468	7	5D
0005432583589	31468	8	6C
0005432583615	31468	9	7A
0005432583594	31468	10	7C
0005432583606	31468	11	18B
0005432583590	31468	12	18C
0005432857917	31468	13	18D
0005432857918	31468	14	19A
0005432857916	31468	15	19B
0005432583596	31468	16	19D
0005432583605	31468	17	20B
0005432857911	31468	18	20D
0005432857921	31468	19	22B
0005432857923	31468	20	23A
0005434943239	861	1	3B
0005434943238	861	2	3C
0005434943240	861	3	3D
0005434943236	861	4	5D
0005434943234	861	5	6B
0005434943237	861	6	19A
0005434943241	861	7	20A
0005434943233	861	8	20B
0005434943232	861	9	22C
0005434943235	861	10	22D
0005434943189	16236	1	2B
0005433255053	16236	2	3C
0005433255052	16236	3	4B
0005433255051	16236	4	5A
0005433255049	16236	5	18A
0005433255050	16236	6	22A
0005434943188	16236	7	22D
0005435652485	21729	1	1A
0005435652463	21729	2	1C
0005435652447	21729	3	1D
0005435652484	21729	4	1F
0005435652488	21729	5	2A
0005435652471	21729	6	2C
0005435652457	21729	7	2F
0005435652452	21729	8	3A
0005435652439	21729	9	4C
0005435652436	21729	10	4D
0005435652458	21729	11	5A
0005435652445	21729	12	5D
0005435652478	21729	13	5E
0005435652487	21729	14	6A
0005435652464	21729	15	6D
0005435652466	21729	16	6E
0005435652472	21729	17	6F
0005435652482	21729	18	7A
0005435652473	21729	19	7C
0005435652483	21729	20	7F
0005435652446	21729	21	8F
0005435652455	21729	22	9F
0005435652449	21729	23	10A
0005435652437	21729	24	10D
0005435652442	21729	25	10E
0005435652440	21729	26	10F
0005435652460	21729	27	11A
0005435652479	21729	28	11D
0005435652477	21729	29	12D
0005435652468	21729	30	12E
0005435652448	21729	31	13A
0005435652475	21729	32	13D
0005435652469	21729	33	13F
0005435652465	21729	34	14C
0005435652438	21729	35	14D
0005435652476	21729	36	15D
0005435652480	21729	37	15E
0005435652486	21729	38	15F
0005435652459	21729	39	16A
0005435652441	21729	40	16C
0005435652450	21729	41	16D
0005435652456	21729	42	16E
0005435652444	21729	43	16F
0005435652454	21729	44	17D
0005435652461	21729	45	17E
0005435652467	21729	46	18C
0005435652474	21729	47	18D
0005435652453	21729	48	18E
0005435652462	21729	49	18F
0005435652470	21729	50	19A
0005435652443	21729	51	19C
0005435652451	21729	52	20A
0005435652481	21729	53	20C
0005433763028	9332	1	1A
0005433804960	9332	2	1C
0005433784499	9332	3	1B
0005433763032	9332	4	2A
0005433804967	9332	5	1H
0005433804938	9332	6	2C
0005433763025	9332	7	2G
0005433804959	9332	8	3B
0005433784516	9332	9	3C
0005433804946	9332	10	4F
0005434170833	9332	11	4G
0005433763030	9332	12	4H
0005433763020	9332	13	9B
0005433784506	9332	14	11B
0005433784487	9332	15	11E
0005433784495	9332	16	11H
0005433804941	9332	17	12E
0005432666361	9332	18	12F
0005433784510	9332	19	13B
0005433763023	9332	20	13D
0005433804957	9332	21	13G
0005432665249	9332	22	13H
0005433784512	9332	23	14E
0005433804953	9332	24	14D
0005433784511	9332	25	15B
0005433763024	9332	26	15G
0005433784494	9332	27	15F
0005432657412	9332	28	15E
0005433784477	9332	29	16A
0005434170809	9332	30	16D
0005433763019	9332	31	16G
0005434170808	9332	32	16F
0005433804949	9332	33	16H
0005433784509	9332	34	17D
0005434170807	9332	35	17G
0005433784490	9332	36	17F
0005433804966	9332	37	18B
0005433804962	9332	38	18D
0005433763026	9332	39	18H
0005432657410	9332	40	19D
0005433784517	9332	41	19F
0005433784489	9332	42	19G
0005433804942	9332	43	20D
0005433784500	9332	44	20H
0005432657409	9332	45	21A
0005433784481	9332	46	21D
0005433784508	9332	47	21B
0005433784488	9332	48	21G
0005433804943	9332	49	22A
0005433784483	9332	50	22B
0005433804939	9332	51	22E
0005433804947	9332	52	22G
0005433784480	9332	53	22F
0005433784485	9332	54	23D
0005433804937	9332	55	23F
0005433804940	9332	56	23H
0005432657411	9332	57	24B
0005433784486	9332	58	24D
0005433804954	9332	59	24F
0005433804952	9332	60	25D
0005433784493	9332	61	25E
0005433804963	9332	62	27A
0005433804934	9332	63	27E
0005433784504	9332	64	27G
0005432657413	9332	65	28D
0005433784515	9332	66	28B
0005433784492	9332	67	29A
0005433804936	9332	68	29D
0005433784479	9332	69	29E
0005433804935	9332	70	29G
0005433763021	9332	71	29H
0005433784514	9332	72	30A
0005433804955	9332	73	30E
0005433784513	9332	74	30D
0005433804956	9332	75	30G
0005433763018	9332	76	31A
0005433804964	9332	77	31B
0005433784478	9332	78	32D
0005433763027	9332	79	32A
0005433804961	9332	80	33A
0005432666362	9332	81	33E
0005433784482	9332	82	33G
0005433804950	9332	83	34D
0005433784505	9332	84	34B
0005433804965	9332	85	34E
0005433804945	9332	86	35A
0005433784497	9332	87	34H
0005433784491	9332	88	35D
0005433804944	9332	89	35F
0005433784507	9332	90	36A
0005433784502	9332	91	36D
0005432667428	9332	92	36E
0005433763022	9332	93	36G
0005433763029	9332	94	36H
0005433784496	9332	95	37D
0005433804948	9332	96	37B
0005433763031	9332	97	37H
0005433784498	9332	98	38A
0005433804958	9332	99	38D
0005433804951	9332	100	38G
0005433763017	9332	101	38F
0005433784484	9332	102	38H
0005433784501	9332	103	39E
0005433784503	9332	104	39D
0005434151667	26256	1	1B
0005433784314	26256	2	2F
0005434170874	26256	3	3C
0005435269666	26256	4	4A
0005435269665	26256	5	4G
0005433804779	26256	6	5G
0005434170882	26256	7	9G
0005434270179	26256	8	11F
0005434170870	26256	9	12D
0005433784324	26256	10	12G
0005434170872	26256	11	15A
0005433762986	26256	12	15B
0005434170875	26256	13	15H
0005433784360	26256	14	16B
0005434271285	26256	15	17A
0005435269669	26256	16	19A
0005433804792	26256	17	20A
0005434170878	26256	18	20G
0005433784315	26256	19	22G
0005435269668	26256	20	23A
0005433784361	26256	21	23B
0005434170880	26256	22	23G
0005434270178	26256	23	24B
0005434170877	26256	24	24D
0005434151669	26256	25	24H
0005434170871	26256	26	25E
0005434170873	26256	27	27B
0005434269076	26256	28	27A
0005433784313	26256	29	28A
0005434170881	26256	30	28G
0005434170884	26256	31	30E
0005434271284	26256	32	30H
0005434170879	26256	33	31B
0005433804879	26256	34	32A
0005435269670	26256	35	33B
0005434170883	26256	36	34F
0005434151668	26256	37	35A
0005433784323	26256	38	35E
0005433804780	26256	39	35F
0005435269667	26256	40	36A
0005434170876	26256	41	37B
0005433784363	26256	42	37E
0005435269671	26256	43	38D
0005434151666	26256	44	38G
0005435135608	4912	1	4B
0005435135609	4912	2	6B
0005435135607	4912	3	19C
0005435135610	4912	4	20D
0005435135606	4912	5	22B
0005435929611	33002	1	1B
0005435929609	33002	2	1C
0005435929610	33002	3	4D
0005434983224	9475	1	1C
0005434983222	9475	2	6D
0005434983221	9475	3	21C
0005434983223	9475	4	22B
0005434217917	27336	1	1B
0005434983195	27336	2	2B
0005434983196	27336	3	2D
0005434983199	27336	4	18A
0005434217916	27336	5	20B
0005434217918	27336	6	22B
0005433985153	24257	1	29A
0005433985183	24257	2	30H
0005433985159	24257	3	31G
0005433960098	25948	1	1A
0005433960116	25948	2	1B
0005433985335	25948	3	1F
0005433985331	25948	4	1H
0005433985312	25948	5	2B
0005433960126	25948	6	2C
0005433960085	25948	7	2G
0005433960092	25948	8	3A
0005433960132	25948	9	3F
0005433960123	25948	10	4H
0005433985343	25948	11	5B
0005433960089	25948	12	5C
0005433960129	25948	13	9A
0005433985352	25948	14	5H
0005433960109	25948	15	11D
0005433985347	25948	16	11F
0005433985321	25948	17	12A
0005433985314	25948	18	12E
0005433960082	25948	19	12F
0005433960139	25948	20	12H
0005433985320	25948	21	13A
0005433960104	25948	22	13E
0005433960122	25948	23	14B
0005433985355	25948	24	14F
0005433985313	25948	25	14G
0005433960117	25948	26	14H
0005433985324	25948	27	15E
0005433960119	25948	28	15D
0005433960091	25948	29	15H
0005433960094	25948	30	15G
0005433985356	25948	31	16A
0005433985323	25948	32	16B
0005433985315	25948	33	16D
0005433960141	25948	34	16G
0005433985340	25948	35	16F
0005433985332	25948	36	17A
0005433985357	25948	37	17D
0005433960111	25948	38	18A
0005433985351	25948	39	18G
0005433960108	25948	40	19B
0005433985325	25948	41	19A
0005433985317	25948	42	19D
0005433985345	25948	43	19E
0005433960135	25948	44	19H
0005433960101	25948	45	20B
0005433985339	25948	46	21A
0005433985309	25948	47	21B
0005433960124	25948	48	21E
0005433960110	25948	49	21D
0005433960134	25948	50	21G
0005433985327	25948	51	22B
0005433960112	25948	52	22D
0005433960102	25948	53	22E
0005433960121	25948	54	22G
0005433960113	25948	55	22H
0005433960114	25948	56	23B
0005433960088	25948	57	23A
0005433960128	25948	58	23D
0005433985344	25948	59	23G
0005433985336	25948	60	23H
0005433960095	25948	61	24B
0005433985330	25948	62	24E
0005433960127	25948	63	24H
0005433985349	25948	64	27D
0005433960138	25948	65	27H
0005433985353	25948	66	28A
0005433960130	25948	67	28D
0005433985311	25948	68	29E
0005433985338	25948	69	29G
0005433985348	25948	70	30B
0005433960105	25948	71	30D
0005433960099	25948	72	30F
0005433960125	25948	73	30G
0005433960103	25948	74	31B
0005433985326	25948	75	31A
0005433960100	25948	76	31D
0005433985310	25948	77	31F
0005433985318	25948	78	31E
0005433985354	25948	79	32A
0005433960097	25948	80	31H
0005433985350	25948	81	32D
0005433985342	25948	82	32B
0005433960083	25948	83	32F
0005433985333	25948	84	32H
0005433960137	25948	85	33A
0005433960133	25948	86	33B
0005433960140	25948	87	33G
0005433960086	25948	88	34A
0005433985329	25948	89	34F
0005433960084	25948	90	34H
0005433960118	25948	91	35B
0005433985322	25948	92	35A
0005433960106	25948	93	35F
0005433985334	25948	94	35G
0005433960120	25948	95	36B
0005433960090	25948	96	36D
0005433985346	25948	97	36F
0005433985341	25948	98	36G
0005433960096	25948	99	37A
0005433985319	25948	100	37B
0005433985308	25948	101	37E
0005433985328	25948	102	37D
0005433960136	25948	103	37G
0005433960115	25948	104	37H
0005433960087	25948	105	38A
0005433985337	25948	106	38E
0005433985316	25948	107	38F
0005433960093	25948	108	39E
0005433960131	25948	109	39D
0005433960107	25948	110	39F
0005434480023	940	1	1A
0005434480014	940	2	1C
0005434480019	940	3	1D
0005434480025	940	4	2C
0005434480007	940	5	3C
0005432269461	940	6	3D
0005434480010	940	7	4A
0005434480030	940	8	4B
0005434480004	940	9	4C
0005434480005	940	10	4D
0005434480013	940	11	5B
0005434480016	940	12	5C
0005434480017	940	13	5D
0005434480026	940	14	6B
0005434480018	940	15	6C
0005434480020	940	16	6D
0005434480021	940	17	7A
0005432269462	940	18	18A
0005434480006	940	19	18B
0005434480011	940	20	18C
0005434480008	940	21	19A
0005434480022	940	22	19B
0005434480027	940	23	19C
0005434480024	940	24	19D
0005434480028	940	25	20A
0005432269460	940	26	21C
0005434480009	940	27	22A
0005432269459	940	28	22B
0005434480029	940	29	22D
0005434480012	940	30	23A
0005434480015	940	31	23B
0005433165744	16577	1	1A
0005433165741	16577	2	3B
0005433165747	16577	3	4A
0005433165743	16577	4	4D
0005433165738	16577	5	5B
0005433165748	16577	6	5D
0005433165735	16577	7	6B
0005434479915	16577	8	7C
0005433165736	16577	9	7D
0005433165746	16577	10	18C
0005434479898	16577	11	19A
0005433165737	16577	12	19D
0005433165749	16577	13	20B
0005433165739	16577	14	20C
0005434479916	16577	15	21C
0005433165742	16577	16	22B
0005433165740	16577	17	22C
0005433165745	16577	18	23A
0005435149854	10359	1	1A
0005435149844	10359	2	1B
0005435149848	10359	3	1C
0005435149845	10359	4	3A
0005435149847	10359	5	3B
0005435142392	10359	6	3C
0005435142401	10359	7	3D
0005435142402	10359	8	4B
0005435142404	10359	9	5A
0005435149850	10359	10	5B
0005435149853	10359	11	5C
0005435142391	10359	12	6B
0005435142396	10359	13	6D
0005435142400	10359	14	7B
0005435149841	10359	15	7D
0005435142390	10359	16	18A
0005435142394	10359	17	18D
0005435149855	10359	18	19C
0005435149846	10359	19	19D
0005435142393	10359	20	20A
0005435149842	10359	21	20B
0005435142399	10359	22	20C
0005435149849	10359	23	20D
0005435149852	10359	24	21B
0005435142397	10359	25	21C
0005435142403	10359	26	22A
0005435142398	10359	27	22B
0005435149851	10359	28	22D
0005435149843	10359	29	23A
0005435142395	10359	30	23B
0005433289765	21925	1	1A
0005435386493	21925	2	1C
0005435386497	21925	3	2A
0005435386496	21925	4	2B
0005435386492	21925	5	3B
0005433289764	21925	6	3D
0005435386495	21925	7	4D
0005433289762	21925	8	5A
0005435386490	21925	9	5C
0005435386491	21925	10	6A
0005433289766	21925	11	6C
0005433289767	21925	12	7B
0005433289763	21925	13	18C
0005435386489	21925	14	21A
0005435386494	21925	15	21C
0005434573165	11221	1	4A
0005434573170	11221	2	4D
0005435528883	11221	3	4E
0005434573163	11221	4	6C
0005434573166	11221	5	6F
0005434573164	11221	6	7E
0005434573159	11221	7	9C
0005434573172	11221	8	9E
0005435501938	11221	9	10A
0005434573160	11221	10	10C
0005434573168	11221	11	10D
0005435501980	11221	12	11A
0005434573162	11221	13	11D
0005434573171	11221	14	13D
0005434573161	11221	15	18F
0005435501981	11221	16	19C
0005434573169	11221	17	19F
0005434573167	11221	18	20E
0005435517677	20932	1	1A
0005435508219	20932	2	1C
0005435517683	20932	3	1D
0005435508216	20932	4	1F
0005435502033	20932	5	2D
0005435502023	20932	6	2F
0005435517688	20932	7	3A
0005435517685	20932	8	3F
0005435319470	20932	9	4A
0005435502027	20932	10	4D
0005435319474	20932	11	4F
0005432291898	20932	12	5C
0005435319477	20932	13	5D
0005435502037	20932	14	5E
0005435502026	20932	15	6C
0005435517669	20932	16	6D
0005435319472	20932	17	6F
0005435502024	20932	18	7C
0005435502035	20932	19	7D
0005432291899	20932	20	7E
0005435517681	20932	21	8A
0005435508218	20932	22	8D
0005435502039	20932	23	8E
0005435517668	20932	24	8F
0005435517674	20932	25	9A
0005435319473	20932	26	9C
0005435319468	20932	27	9E
0005435517673	20932	28	9F
0005435502031	20932	29	10D
0005435502040	20932	30	10E
0005435502038	20932	31	10F
0005435319471	20932	32	11C
0005435517676	20932	33	11D
0005435502022	20932	34	11E
0005435517682	20932	35	12A
0005435502041	20932	36	12C
0005435319475	20932	37	12E
0005435502030	20932	38	13A
0005435508221	20932	39	13C
0005435517679	20932	40	13E
0005435517671	20932	41	13F
0005435319469	20932	42	14A
0005435319476	20932	43	14C
0005435517670	20932	44	14D
0005435508211	20932	45	14E
0005435517687	20932	46	15A
0005435517672	20932	47	15C
0005435517680	20932	48	15D
0005435502032	20932	49	15E
0005435502028	20932	50	16A
0005435517686	20932	51	16C
0005435508210	20932	52	17A
0005435508217	20932	53	17D
0005435508213	20932	54	17E
0005435517678	20932	55	17F
0005435502021	20932	56	18A
0005435502034	20932	57	18C
0005435502025	20932	58	18D
0005435502029	20932	59	18E
0005435517684	20932	60	18F
0005435517675	20932	61	19A
0005435508214	20932	62	19C
0005435508212	20932	63	19D
0005435508215	20932	64	19E
0005435508220	20932	65	20D
0005435502036	20932	66	20E
0005432692565	2956	1	15D
0005432706451	2957	1	1A
0005432706456	2957	2	2F
0005432706461	2957	3	3A
0005432706439	2957	4	3D
0005432706442	2957	5	3F
0005432706462	2957	6	4A
0005432706443	2957	7	5E
0005433123575	2957	8	6D
0005432706440	2957	9	6E
0005432706459	2957	10	6F
0005432706463	2957	11	7D
0005432706449	2957	12	8D
0005432706448	2957	13	8C
0005432706452	2957	14	8F
0005432706438	2957	15	9D
0005432706453	2957	16	9F
0005432706458	2957	17	10E
0005432706455	2957	18	11A
0005432706450	2957	19	12A
0005432217741	2957	20	12E
0005432706457	2957	21	13C
0005432706441	2957	22	13E
0005432706447	2957	23	14A
0005432706454	2957	24	16D
0005432706446	2957	25	17E
0005432217740	2957	26	18A
0005432706444	2957	27	19D
0005432706460	2957	28	19F
0005432706445	2957	29	20E
0005432706464	2957	30	20F
0005432692688	29960	1	1A
0005433123661	29960	2	1D
0005433123656	29960	3	1F
0005432880627	29960	4	2A
0005432692708	29960	5	2C
0005433123674	29960	6	2D
0005432706349	29960	7	2F
0005432692686	29960	8	3A
0005433123675	29960	9	3C
0005432692709	29960	10	3D
0005433123676	29960	11	3F
0005433123670	29960	12	4A
0005432880640	29960	13	4C
0005433123665	29960	14	4D
0005432692712	29960	15	4E
0005432692716	29960	16	5A
0005433123667	29960	17	5C
0005432692711	29960	18	5D
0005433123677	29960	19	5E
0005432692703	29960	20	5F
0005432692702	29960	21	6A
0005432692704	29960	22	6C
0005432692706	29960	23	6E
0005432706348	29960	24	7C
0005432880637	29960	25	7D
0005433194826	29960	26	8A
0005432880633	29960	27	8C
0005433123657	29960	28	8D
0005432880634	29960	29	8E
0005432880639	29960	30	8F
0005432692705	29960	31	9A
0005432692710	29960	32	9C
0005432692693	29960	33	9E
0005432692687	29960	34	9F
0005433123668	29960	35	10D
0005433123664	29960	36	10F
0005432706327	29960	37	11A
0005432692695	29960	38	11C
0005432880635	29960	39	11D
0005433123666	29960	40	11E
0005432880638	29960	41	11F
0005432880628	29960	42	12A
0005432692692	29960	43	12C
0005432692700	29960	44	12D
0005433123672	29960	45	12E
0005432692714	29960	46	12F
0005433123658	29960	47	13A
0005432692699	29960	48	13D
0005433123673	29960	49	13E
0005433123671	29960	50	13F
0005432692694	29960	51	14A
0005432692691	29960	52	14C
0005432880626	29960	53	14D
0005433123662	29960	54	14E
0005433123669	29960	55	15A
0005432706328	29960	56	15D
0005432880630	29960	57	15E
0005433123659	29960	58	16A
0005432692707	29960	59	16C
0005432880632	29960	60	16D
0005432692689	29960	61	16E
0005432692697	29960	62	16F
0005432692701	29960	63	17A
0005432692713	29960	64	17C
0005432692696	29960	65	17E
0005432880631	29960	66	17F
0005432706323	29960	67	18A
0005433194827	29960	68	18C
0005433123660	29960	69	18D
0005432692715	29960	70	18F
0005432880629	29960	71	19C
0005432706350	29960	72	19F
0005432880636	29960	73	20A
0005433123663	29960	74	20C
0005432692690	29960	75	20D
0005433123678	29960	76	20E
0005432692698	29960	77	20F
0005434988596	23667	1	1C
0005434979385	23667	2	2A
0005434979389	23667	3	2B
0005434988597	23667	4	2C
0005434979393	23667	5	2D
0005434979406	23667	6	3A
0005434979398	23667	7	3B
0005434979400	23667	8	3D
0005434979388	23667	9	4A
0005434979378	23667	10	4B
0005434979403	23667	11	4C
0005434988598	23667	12	4D
0005434979394	23667	13	5A
0005434988592	23667	14	5B
0005434979379	23667	15	5C
0005434979401	23667	16	5D
0005434979375	23667	17	6B
0005434979404	23667	18	6C
0005434979383	23667	19	6D
0005434979390	23667	20	7A
0005434979377	23667	21	7C
0005434979382	23667	22	7D
0005434979402	23667	23	18A
0005434979376	23667	24	18B
0005434979380	23667	25	18C
0005434988588	23667	26	19A
0005434979384	23667	27	19B
0005434979391	23667	28	19C
0005434979395	23667	29	19D
0005434979405	23667	30	20A
0005434988594	23667	31	20B
0005434988591	23667	32	20C
0005434988595	23667	33	20D
0005434979396	23667	34	21A
0005434988593	23667	35	21B
0005434979397	23667	36	21C
0005434979381	23667	37	21D
0005434979392	23667	38	22A
0005434988590	23667	39	22B
0005434979399	23667	40	22C
0005434979387	23667	41	22D
0005434988589	23667	42	23A
0005434979386	23667	43	23B
0005434979285	27574	1	1A
0005434979273	27574	2	4D
0005434979272	27574	3	6B
0005434979286	27574	4	18D
0005434979259	27574	5	20A
0005434979258	27574	6	21B
0005434302400	10287	1	1D
0005434302403	10287	2	7D
0005434302401	10287	3	21C
0005434302399	10287	4	21D
0005434302402	10287	5	22A
0005433113508	19604	1	2B
0005433113507	19604	2	5C
0005433113506	19604	3	20B
0005435068431	3524	1	1C
0005435068459	3524	2	1D
0005435718867	3524	3	1F
0005435068475	3524	4	2A
0005435068456	3524	5	2C
0005435068437	3524	6	2D
0005435068424	3524	7	2F
0005435068474	3524	8	3A
0005435068458	3524	9	3D
0005435718864	3524	10	3C
0005435068441	3524	11	4A
0005435068448	3524	12	4C
0005435068444	3524	13	4D
0005435068451	3524	14	4E
0005435068462	3524	15	4F
0005435068433	3524	16	5E
0005435068432	3524	17	5F
0005435068423	3524	18	6C
0005435068469	3524	19	6D
0005435068435	3524	20	6F
0005435068455	3524	21	7A
0005435068460	3524	22	8A
0005435718869	3524	23	8F
0005435068439	3524	24	9A
0005435068436	3524	25	9C
0005435068466	3524	26	9F
0005435718863	3524	27	10A
0005435068445	3524	28	10C
0005435068426	3524	29	10E
0005435068440	3524	30	10F
0005435068463	3524	31	11A
0005435068473	3524	32	11D
0005435068468	3524	33	11E
0005435068449	3524	34	12E
0005435068446	3524	35	12F
0005435068471	3524	36	13C
0005435068427	3524	37	13E
0005435068429	3524	38	13F
0005435068467	3524	39	14C
0005435718870	3524	40	14F
0005435068470	3524	41	15A
0005435718868	3524	42	15C
0005435068454	3524	43	15D
0005435068472	3524	44	16A
0005435068442	3524	45	16C
0005435068434	3524	46	16D
0005435068465	3524	47	16F
0005435068452	3524	48	17A
0005435068464	3524	49	17E
0005435068443	3524	50	17F
0005435068453	3524	51	18A
0005435068438	3524	52	18C
0005435068430	3524	53	18D
0005435068457	3524	54	18F
0005435068450	3524	55	18E
0005435068425	3524	56	19D
0005435718866	3524	57	19F
0005435718865	3524	58	20A
0005435068447	3524	59	20C
0005435068428	3524	60	20D
0005435068461	3524	61	20F
0005435925125	15293	1	2F
0005435925127	15293	2	7E
0005435925124	15293	3	8C
0005435068190	15293	4	9E
0005435925123	15293	5	10D
0005435925121	15293	6	11D
0005435068191	15293	7	14C
0005435068264	15293	8	16E
0005435925122	15293	9	18D
0005435925126	15293	10	18E
0005435925128	15293	11	19F
0005432658565	18145	1	1B
0005432658566	18145	2	2A
0005432660791	18145	3	2B
0005432659680	18145	4	4A
0005432658564	18145	5	3B
0005432659679	18145	6	5A
0005432659681	18145	7	4B
0005432660792	18145	8	6A
0005432901300	211	1	6C
0005432157467	211	2	18C
0005432901312	211	3	24D
0005432157468	211	4	24E
0005432901335	211	5	27D
0005432261344	210	1	2C
0005432288945	210	2	2D
0005432261346	210	3	3A
0005432261359	210	4	3D
0005432261358	210	5	4A
0005432817117	210	6	3F
0005432817100	210	7	4C
0005432261338	210	8	5D
0005432261325	210	9	6A
0005432817112	210	10	5F
0005432817108	210	11	6C
0005432261361	210	12	6F
0005432261362	210	13	7A
0005432261323	210	14	8D
0005432817118	210	15	9A
0005432288944	210	16	9E
0005432817094	210	17	9F
0005432817095	210	18	10C
0005432261354	210	19	10E
0005432261331	210	20	10F
0005432261327	210	21	11B
0005432261350	210	22	11C
0005432817102	210	23	11E
0005432817106	210	24	12B
0005432207628	210	25	12D
0005432261328	210	26	13A
0005432261347	210	27	12F
0005432817114	210	28	13C
0005432261326	210	29	14A
0005432261333	210	30	14D
0005432261364	210	31	14C
0005432261345	210	32	14E
0005432261322	210	33	14F
0005434153518	210	34	15C
0005432261334	210	35	16D
0005432817104	210	36	17A
0005432207627	210	37	16F
0005432261330	210	38	17E
0005432817105	210	39	17F
0005432817097	210	40	18B
0005432817089	210	41	18D
0005432817113	210	42	18C
0005432817116	210	43	18E
0005432261365	210	44	19C
0005432261339	210	45	19D
0005432261337	210	46	19E
0005432261363	210	47	20A
0005432261353	210	48	20D
0005432261357	210	49	20C
0005432288946	210	50	21A
0005432817101	210	51	21D
0005432817091	210	52	22A
0005432261342	210	53	22C
0005432817092	210	54	22E
0005432261360	210	55	23B
0005432261355	210	56	23C
0005432261340	210	57	24A
0005432261356	210	58	24C
0005432261324	210	59	25B
0005432817099	210	60	25A
0005432261349	210	61	26B
0005432261351	210	62	26C
0005432817109	210	63	26E
0005432261367	210	64	27A
0005432817090	210	65	27C
0005432817110	210	66	27D
0005432261343	210	67	27E
0005432261341	210	68	27F
0005432817098	210	69	28C
0005432261352	210	70	28D
0005432817103	210	71	29C
0005432261336	210	72	29D
0005432261332	210	73	29E
0005432261348	210	74	30B
0005432817111	210	75	30A
0005432817096	210	76	30C
0005432817093	210	77	30E
0005432261329	210	78	31A
0005432261335	210	79	31C
0005432817115	210	80	31B
0005432817107	210	81	31E
0005432261366	210	82	31F
0005432751486	7942	1	1A
0005433101483	7942	2	1D
0005432753260	7942	3	1C
0005433101466	7942	4	1F
0005432019920	7942	5	2A
0005432045589	7942	6	2C
0005433101491	7942	7	2F
0005433101470	7942	8	2D
0005432045591	7942	9	3C
0005432019936	7942	10	3A
0005433101475	7942	11	3D
0005432677524	7942	12	4D
0005432919594	7942	13	4C
0005433101500	7942	14	4F
0005432919590	7942	15	5A
0005432919605	7942	16	5D
0005433101480	7942	17	5F
0005433101465	7942	18	6A
0005433101459	7942	19	6F
0005432391962	7942	20	6D
0005432044491	7942	21	7A
0005432019937	7942	22	7D
0005432919591	7942	23	7C
0005432019942	7942	24	8A
0005433101477	7942	25	8B
0005432677526	7942	26	8D
0005432753259	7942	27	8E
0005433101494	7942	28	9B
0005432019928	7942	29	9A
0005432019926	7942	30	9D
0005433101514	7942	31	10A
0005432019943	7942	32	9F
0005433101496	7942	33	10D
0005433101515	7942	34	10E
0005432019923	7942	35	11A
0005432919596	7942	36	11C
0005432677525	7942	37	11B
0005432019939	7942	38	11D
0005432751485	7942	39	12A
0005433101508	7942	40	12B
0005433101513	7942	41	12C
0005433101476	7942	42	12E
0005432677527	7942	43	12D
0005432919588	7942	44	12F
0005432019921	7942	45	13A
0005433101511	7942	46	13C
0005433101460	7942	47	13D
0005432919607	7942	48	13F
0005433101509	7942	49	13E
0005432919606	7942	50	14A
0005432391961	7942	51	14C
0005432019925	7942	52	14D
0005432019938	7942	53	14F
0005433101481	7942	54	15B
0005432019932	7942	55	15A
0005433101510	7942	56	15C
0005432019924	7942	57	15F
0005432019919	7942	58	15E
0005432751487	7942	59	16A
0005432919595	7942	60	16B
0005433101485	7942	61	16D
0005433101489	7942	62	16C
0005433101503	7942	63	16E
0005433101487	7942	64	17A
0005433101482	7942	65	17C
0005432019929	7942	66	17B
0005433101462	7942	67	17D
0005432919589	7942	68	17E
0005432019927	7942	69	17F
0005433101516	7942	70	18B
0005433101501	7942	71	18D
0005433101479	7942	72	18C
0005432919600	7942	73	18E
0005433101464	7942	74	18F
0005432019930	7942	75	19B
0005432753261	7942	76	19D
0005433101474	7942	77	20A
0005432044490	7942	78	19E
0005432919601	7942	79	20B
0005432391964	7942	80	20E
0005433101497	7942	81	20D
0005433101498	7942	82	20F
0005433101502	7942	83	21A
0005433101472	7942	84	21B
0005433101506	7942	85	21D
0005432019922	7942	86	21E
0005433101505	7942	87	21F
0005433101471	7942	88	22B
0005433101473	7942	89	22C
0005433101512	7942	90	22F
0005433101493	7942	91	22E
0005433101468	7942	92	23B
0005432019935	7942	93	23A
0005433101488	7942	94	23C
0005432919593	7942	95	23D
0005432919602	7942	96	23E
0005433101469	7942	97	24A
0005432919604	7942	98	23F
0005433101467	7942	99	24F
0005432019940	7942	100	24E
0005432919599	7942	101	25B
0005432919592	7942	102	25C
0005432045590	7942	103	25D
0005432919608	7942	104	26A
0005432391963	7942	105	25F
0005432019918	7942	106	26D
0005433101490	7942	107	26F
0005432019933	7942	108	26E
0005432019917	7942	109	27C
0005432019934	7942	110	27B
0005433101492	7942	111	27D
0005433101461	7942	112	28A
0005432044489	7942	113	27F
0005433101507	7942	114	28B
0005432019916	7942	115	28C
0005433101486	7942	116	28E
0005433101484	7942	117	29B
0005433101478	7942	118	29A
0005432919603	7942	119	29C
0005432919598	7942	120	29D
0005433101463	7942	121	29F
0005432019941	7942	122	29E
0005433101504	7942	123	30A
0005432751484	7942	124	30B
0005432019931	7942	125	31A
0005433101495	7942	126	30F
0005432919609	7942	127	31C
0005433101499	7942	128	31D
0005432919597	7942	129	31F
0005432901393	7938	1	5F
0005432901394	7938	2	7F
0005432901390	7938	3	9F
0005432901389	7938	4	10C
0005432901388	7938	5	11B
0005432901396	7938	6	13A
0005432901386	7938	7	13C
0005432901387	7938	8	13F
0005432901401	7938	9	16F
0005432901399	7938	10	17D
0005432816972	7938	11	17E
0005432901384	7938	12	18A
0005432816938	7938	13	18E
0005432002050	7938	14	19C
0005432901397	7938	15	23A
0005432901395	7938	16	23C
0005432901392	7938	17	23F
0005432901400	7938	18	28C
0005432901398	7938	19	30A
0005432002051	7938	20	31E
0005432901385	7938	21	31D
0005432901391	7938	22	31F
0005433870703	9659	1	5A
0005433870704	9659	2	6B
0005434175700	32372	1	1B
0005434175701	32372	2	2A
0005434175699	32372	3	3B
0005434175698	32372	4	5B
0005432188567	3518	1	1D
0005434877097	3518	2	1C
0005434877111	3518	3	1A
0005434877065	3518	4	1G
0005435125882	3518	5	1K
0005434877128	3518	6	1H
0005434877114	3518	7	2D
0005434877091	3518	8	2A
0005434877113	3518	9	2H
0005434877053	3518	10	2G
0005434426239	3518	11	3A
0005434877095	3518	12	2K
0005432799118	3518	13	3G
0005434877080	3518	14	3D
0005434426237	3518	15	3C
0005434877067	3518	16	3H
0005435125876	3518	17	4C
0005434937907	3518	18	4D
0005432613809	3518	19	4K
0005434877108	3518	20	4H
0005435625953	3518	21	5D
0005434877055	3518	22	5C
0005434426257	3518	23	5A
0005432188566	3518	24	5G
0005434877051	3518	25	5K
0005434426255	3518	26	11D
0005434937896	3518	27	11C
0005435625970	3518	28	11K
0005434877056	3518	29	11G
0005435625963	3518	30	12A
0005434937897	3518	31	12D
0005434877060	3518	32	12H
0005434877112	3518	33	12G
0005434877057	3518	34	13C
0005434877118	3518	35	13F
0005432183439	3518	36	13E
0005434877074	3518	37	13D
0005435125883	3518	38	13H
0005434426240	3518	39	14A
0005434937898	3518	40	13K
0005434937906	3518	41	14D
0005434877109	3518	42	14C
0005432799123	3518	43	14G
0005434877105	3518	44	14E
0005434877062	3518	45	14H
0005434877127	3518	46	15A
0005434426246	3518	47	14K
0005435125874	3518	48	15F
0005434877131	3518	49	15E
0005434937905	3518	50	15D
0005432613811	3518	51	15H
0005434937911	3518	52	16A
0005435125887	3518	53	15K
0005432799105	3518	54	16E
0005434877119	3518	55	16K
0005432799106	3518	56	17C
0005435125872	3518	57	17E
0005434877092	3518	58	17D
0005434426243	3518	59	17F
0005434877082	3518	60	18A
0005434426250	3518	61	17H
0005435125875	3518	62	18C
0005435125885	3518	63	18B
0005434877052	3518	64	18E
0005434877099	3518	65	18D
0005435125865	3518	66	18G
0005434877043	3518	67	18F
0005435125884	3518	68	18H
0005434877096	3518	69	19B
0005432183440	3518	70	19A
0005435125891	3518	71	19D
0005435625949	3518	72	19C
0005435125873	3518	73	19F
0005435125868	3518	74	19J
0005434877066	3518	75	19H
0005432611659	3518	76	20C
0005434877132	3518	77	20D
0005434426256	3518	78	20K
0005435125879	3518	79	20J
0005432799120	3518	80	20H
0005435125863	3518	81	21A
0005432799110	3518	82	21C
0005435625952	3518	83	21G
0005434937900	3518	84	21F
0005434426245	3518	85	21E
0005434877063	3518	86	21H
0005434426261	3518	87	21J
0005435125867	3518	88	22B
0005432799119	3518	89	22E
0005435125877	3518	90	22D
0005434877130	3518	91	22H
0005434877087	3518	92	22G
0005434877058	3518	93	22K
0005435625950	3518	94	22J
0005434877048	3518	95	23B
0005435625969	3518	96	23A
0005435125862	3518	97	23G
0005432799111	3518	98	23F
0005434877040	3518	99	23E
0005435125864	3518	100	23J
0005434877044	3518	101	24D
0005434426247	3518	102	23K
0005434877126	3518	103	25D
0005435125871	3518	104	25B
0005434877117	3518	105	25F
0005434426238	3518	106	25E
0005435625957	3518	107	25H
0005434877098	3518	108	25G
0005435125878	3518	109	25J
0005435625966	3518	110	26C
0005434877079	3518	111	26H
0005434426258	3518	112	26G
0005434877090	3518	113	27B
0005435625960	3518	114	27A
0005434877064	3518	115	27F
0005435125889	3518	116	27E
0005434877072	3518	117	27G
0005434877101	3518	118	28A
0005434877069	3518	119	27J
0005432799107	3518	120	28D
0005434426236	3518	121	28G
0005434426241	3518	122	28F
0005434877075	3518	123	28J
0005434426249	3518	124	29A
0005432799109	3518	125	29C
0005432799122	3518	126	29F
0005434877071	3518	127	29J
0005434877136	3518	128	30B
0005434877121	3518	129	30A
0005435625959	3518	130	30D
0005435125893	3518	131	30G
0005435125881	3518	132	30F
0005434877042	3518	133	30J
0005435125861	3518	134	30H
0005434426253	3518	135	31B
0005434877129	3518	136	31A
0005435125895	3518	137	31C
0005435625954	3518	138	31E
0005435125858	3518	139	31H
0005434426254	3518	140	31G
0005435125896	3518	141	31K
0005434877070	3518	142	31J
0005435125880	3518	143	32C
0005432799100	3518	144	32A
0005434426264	3518	145	32D
0005435125866	3518	146	32H
0005434426252	3518	147	32F
0005434877103	3518	148	32J
0005434877059	3518	149	32K
0005434937892	3518	150	33G
0005432799103	3518	151	33F
0005435125859	3518	152	33E
0005434877100	3518	153	33H
0005434877134	3518	154	34E
0005434877123	3518	155	34D
0005432613812	3518	156	34H
0005434877115	3518	157	34G
0005434877073	3518	158	34F
0005434426262	3518	159	34K
0005434877078	3518	160	35B
0005434426260	3518	161	35A
0005434877093	3518	162	35C
0005432611660	3518	163	35F
0005434877107	3518	164	35J
0005434937909	3518	165	35G
0005434877081	3518	166	36E
0005435125892	3518	167	36D
0005434877088	3518	168	36H
0005434877041	3518	169	36K
0005434937904	3518	170	36J
0005432799104	3518	171	37B
0005434937899	3518	172	37A
0005435625955	3518	173	37C
0005434877085	3518	174	37F
0005434877122	3518	175	37H
0005434877102	3518	176	37G
0005432799113	3518	177	38A
0005434877047	3518	178	37K
0005434877045	3518	179	38C
0005432613810	3518	180	38B
0005434877094	3518	181	38K
0005434426259	3518	182	39B
0005434937908	3518	183	39A
0005435625967	3518	184	39D
0005434877061	3518	185	39E
0005435625958	3518	186	39K
0005434937910	3518	187	39J
0005432799108	3518	188	40E
0005435625962	3518	189	40D
0005434877046	3518	190	40G
0005435625951	3518	191	40F
0005435902393	3518	192	40J
0005434877137	3518	193	40H
0005435125869	3518	194	41A
0005435625964	3518	195	41D
0005432799117	3518	196	41C
0005432611661	3518	197	41F
0005434426244	3518	198	41E
0005435125856	3518	199	41K
0005434937893	3518	200	42C
0005434877106	3518	201	42B
0005434426248	3518	202	42D
0005435625965	3518	203	42G
0005434877054	3518	204	42K
0005434877125	3518	205	42H
0005434877110	3518	206	43B
0005432188568	3518	207	43A
0005434877089	3518	208	43D
0005432799099	3518	209	43C
0005434877135	3518	210	43J
0005432799121	3518	211	43G
0005434877084	3518	212	43K
0005432799115	3518	213	44C
0005435625968	3518	214	44G
0005434877133	3518	215	44K
0005432799125	3518	216	44H
0005434426242	3518	217	45C
0005434937903	3518	218	45F
0005432799112	3518	219	45E
0005432799116	3518	220	45H
0005435125870	3518	221	45G
0005435125860	3518	222	45K
0005434937901	3518	223	45J
0005434426251	3518	224	46A
0005435125888	3518	225	46E
0005435125894	3518	226	46D
0005435125890	3518	227	46G
0005434877120	3518	228	46F
0005432799102	3518	229	46K
0005435125857	3518	230	46J
0005434877124	3518	231	46H
0005435625961	3518	232	47E
0005434877083	3518	233	47G
0005434877104	3518	234	47K
0005435125886	3518	235	47H
0005432799101	3518	236	48A
0005434877077	3518	237	48E
0005434937902	3518	238	48D
0005432799114	3518	239	48H
0005434877086	3518	240	49A
0005434877049	3518	241	49D
0005432611662	3518	242	49K
0005434877116	3518	243	49H
0005434877076	3518	244	49G
0005434877050	3518	245	50A
0005435625956	3518	246	50D
0005432799098	3518	247	50H
0005434937895	3518	248	50F
0005434877068	3518	249	50K
0005434426263	3518	250	51E
0005432799124	3518	251	51D
0005434937894	3518	252	51G
0005434937805	14540	1	2C
0005435913879	14540	2	2G
0005434876654	14540	3	3A
0005434937817	14540	4	2K
0005435913882	14540	5	3G
0005435902485	14540	6	4C
0005435913878	14540	7	4G
0005435902484	14540	8	5D
0005435902490	14540	9	11D
0005435913886	14540	10	12C
0005435902480	14540	11	12D
0005435913880	14540	12	13A
0005435913885	14540	13	13E
0005434876789	14540	14	14C
0005434426084	14540	15	13K
0005435902486	14540	16	14D
0005435913887	14540	17	14F
0005435902475	14540	18	14E
0005435842318	14540	19	14H
0005435913877	14540	20	15C
0005434876655	14540	21	15D
0005434937816	14540	22	16E
0005435902487	14540	23	17E
0005435913888	14540	24	18G
0005435913875	14540	25	18E
0005435902488	14540	26	20D
0005434937798	14540	27	20C
0005434876788	14540	28	20G
0005434876608	14540	29	20K
0005434426090	14540	30	22F
0005435902481	14540	31	22E
0005435914684	14540	32	22K
0005435913881	14540	33	23B
0005435902478	14540	34	23D
0005434876568	14540	35	23J
0005435902479	14540	36	25D
0005435902491	14540	37	29C
0005435914687	14540	38	30J
0005435902476	14540	39	31H
0005434937797	14540	40	33A
0005435902483	14540	41	33B
0005435913883	14540	42	33E
0005432059481	14540	43	33K
0005432059479	14540	44	35A
0005435902482	14540	45	38J
0005435902477	14540	46	39F
0005435902489	14540	47	41C
0005435842317	14540	48	41E
0005434937804	14540	49	42J
0005435902492	14540	50	43A
0005435914686	14540	51	43C
0005432059480	14540	52	43H
0005435914685	14540	53	44F
0005435841812	14540	54	45B
0005434876622	14540	55	45A
0005435913884	14540	56	45C
0005434426089	14540	57	48D
0005435913876	14540	58	50G
0005434325506	3621	1	1A
0005434312292	3621	2	3A
0005434325508	3621	3	5A
0005434325509	3621	4	6C
0005434325510	3621	5	7B
0005434312293	3621	6	18D
0005434325507	3621	7	19D
0005434325505	3621	8	20A
0005434325511	3621	9	20B
0005434325512	3621	10	22A
0005434325504	3621	11	22C
0005434325513	3621	12	23B
0005434325444	15623	1	1B
0005435889824	15623	2	2B
0005435889822	15623	3	2D
0005435889820	15623	4	5C
0005435889819	15623	5	6C
0005435889823	15623	6	19B
0005435889821	15623	7	21B
0005434325460	15623	8	22B
0005435957516	663	1	1B
0005435957524	663	2	1C
0005435957523	663	3	1D
0005435957520	663	4	2C
0005435957525	663	5	3C
0005435957522	663	6	3D
0005435957527	663	7	4B
0005433420253	663	8	4D
0005433420252	663	9	5A
0005435957517	663	10	6D
0005435957521	663	11	7B
0005435957528	663	12	7D
0005435957518	663	13	19C
0005435957515	663	14	19D
0005435957514	663	15	20A
0005435957526	663	16	20D
0005435957519	663	17	22B
0005433420300	15166	1	3D
0005433420295	15166	2	4C
0005433420297	15166	3	5C
0005433420293	15166	4	6D
0005433420296	15166	5	7D
0005433420294	15166	6	19A
0005433420299	15166	7	21A
0005433420298	15166	8	22A
0005435629390	8904	1	3A
0005435629389	8904	2	6A
0005434247115	16049	1	1B
0005434247114	16049	2	3A
0005434247116	16049	3	6A
0005435933405	29524	1	2B
0005435933413	29524	2	2D
0005435933407	29524	3	3C
0005435933409	29524	4	4D
0005435933408	29524	5	5D
0005435933406	29524	6	6C
0005435933410	29524	7	7D
0005435933411	29524	8	18B
0005435933404	29524	9	20D
0005435933412	29524	10	21A
0005435797299	2835	1	1A
0005435797296	2835	2	2A
0005435797306	2835	3	4A
0005435797297	2835	4	4D
0005435797303	2835	5	6A
0005435797300	2835	6	7F
0005435797308	2835	7	8D
0005435797301	2835	8	10F
0005435797307	2835	9	14A
0005435797294	2835	10	16F
0005435797302	2835	11	17A
0005435797304	2835	12	17C
0005435797298	2835	13	17E
0005435797295	2835	14	18D
0005435797305	2835	15	20E
0005435797227	29296	1	2D
0005435797244	29296	2	4D
0005433404720	29296	3	7E
0005433404719	29296	4	8A
0005435797224	29296	5	11A
0005435797225	29296	6	12C
0005433404718	29296	7	14C
0005433404721	29296	8	15D
0005433404716	29296	9	16C
0005433404717	29296	10	17C
0005433404715	29296	11	18C
0005435376314	5740	1	2B
0005434947920	5798	1	1B
0005434947921	5798	2	2A
0005434947916	5798	3	3A
0005434947915	5798	4	4A
0005434947919	5798	5	4B
0005434947914	5798	6	5A
0005434947918	5798	7	5B
0005434947917	5798	8	6A
0005435376325	16411	1	1B
0005435376322	16411	2	2B
0005435376323	16411	3	3A
0005434947868	16411	4	3B
0005435376324	16411	5	4A
0005433960159	6909	1	1C
0005433960149	6909	2	1D
0005433960200	6909	3	1F
0005433960198	6909	4	2A
0005433960152	6909	5	2C
0005433960196	6909	6	3C
0005433960175	6909	7	3D
0005433960189	6909	8	4A
0005433960193	6909	9	4C
0005433960168	6909	10	4D
0005433960206	6909	11	4E
0005433960195	6909	12	4F
0005433960204	6909	13	5A
0005433960160	6909	14	5C
0005433960197	6909	15	5D
0005433960182	6909	16	6A
0005433960184	6909	17	6F
0005433960199	6909	18	7C
0005433960173	6909	19	7E
0005433960144	6909	20	7F
0005433960179	6909	21	8A
0005433960164	6909	22	8C
0005433960181	6909	23	8D
0005433960188	6909	24	8F
0005433960157	6909	25	9C
0005433960142	6909	26	9D
0005433960162	6909	27	9E
0005433960201	6909	28	10D
0005433960171	6909	29	10E
0005433960191	6909	30	10F
0005433960170	6909	31	11A
0005433960174	6909	32	11D
0005433960172	6909	33	11E
0005433960169	6909	34	11F
0005433960185	6909	35	12A
0005433960167	6909	36	12F
0005433960145	6909	37	13A
0005433960151	6909	38	13D
0005433960194	6909	39	13F
0005433960153	6909	40	14A
0005433960176	6909	41	14C
0005433960178	6909	42	14D
0005433960177	6909	43	14E
0005433960187	6909	44	14F
0005433960190	6909	45	15A
0005433960165	6909	46	15D
0005433960205	6909	47	15F
0005433960203	6909	48	16A
0005433960143	6909	49	16C
0005433960146	6909	50	16D
0005433960150	6909	51	16E
0005433960183	6909	52	16F
0005433960192	6909	53	17A
0005433960155	6909	54	17C
0005433960208	6909	55	17D
0005433960161	6909	56	17E
0005433960148	6909	57	17F
0005433960163	6909	58	18C
0005433960147	6909	59	18D
0005433960158	6909	60	18E
0005433960166	6909	61	18F
0005433960186	6909	62	19C
0005433960156	6909	63	19F
0005433960207	6909	64	20C
0005433960180	6909	65	20D
0005433960202	6909	66	20E
0005433960154	6909	67	20F
0005435082648	24458	1	1A
0005435082643	24458	2	2B
0005435082649	24458	3	6B
0005435082680	26090	1	1A
0005435082679	26090	2	2A
0005435082681	26090	3	4A
0005435082678	26090	4	3B
0005435082682	26090	5	4B
0005435082683	26090	6	6B
0005434244610	5196	1	2A
0005434244614	5196	2	1F
0005434244623	5196	3	4D
0005434244611	5196	4	5A
0005434244609	5196	5	5C
0005434244618	5196	6	5F
0005434244620	5196	7	9A
0005434244630	5196	8	9E
0005434244631	5196	9	11E
0005434244629	5196	10	12C
0005432166862	5196	11	12D
0005434244628	5196	12	14D
0005434244605	5196	13	14E
0005434244621	5196	14	14F
0005434244633	5196	15	16B
0005434244615	5196	16	17D
0005434244608	5196	17	17F
0005432166860	5196	18	18D
0005434244624	5196	19	19D
0005434244604	5196	20	19E
0005434244616	5196	21	21A
0005434244625	5196	22	22F
0005434244612	5196	23	23F
0005434244613	5196	24	25B
0005432166861	5196	25	25D
0005434244607	5196	26	25E
0005434244606	5196	27	25F
0005434244617	5196	28	26E
0005434244632	5196	29	27F
0005434244626	5196	30	29B
0005434244627	5196	31	30B
0005434244619	5196	32	30A
0005434244622	5196	33	31D
0005433784517	5197	1	1A
0005433784500	5197	2	1C
0005433613830	5197	3	1D
0005433784483	5197	4	2A
0005433613798	5197	5	1F
0005432666361	5197	6	2C
0005433613797	5197	7	2D
0005433784513	5197	8	3A
0005432104972	5197	9	2F
0005433784498	5197	10	3C
0005433613811	5197	11	3F
0005432104995	5197	12	3D
0005433784481	5197	13	4A
0005432104970	5197	14	4D
0005432104977	5197	15	4C
0005432105000	5197	16	4F
0005433613810	5197	17	5C
0005433613813	5197	18	5A
0005432104958	5197	19	5F
0005433613778	5197	20	5D
0005432104967	5197	21	6A
0005433613819	5197	22	6D
0005433613823	5197	23	6C
0005433784478	5197	24	6F
0005433784506	5197	25	7A
0005433784488	5197	26	7C
0005433613834	5197	27	7D
0005432104987	5197	28	8A
0005433613776	5197	29	7F
0005432104981	5197	30	8B
0005432104986	5197	31	8D
0005433613792	5197	32	8C
0005433613820	5197	33	8E
0005433784516	5197	34	9A
0005433784477	5197	35	8F
0005432104956	5197	36	9B
0005432104962	5197	37	9C
0005433784507	5197	38	9D
0005433784493	5197	39	9E
0005432104960	5197	40	10A
0005432104989	5197	41	9F
0005433784491	5197	42	10C
0005433613793	5197	43	10B
0005433613773	5197	44	10D
0005433613775	5197	45	10E
0005432666362	5197	46	11A
0005432104996	5197	47	10F
0005432104965	5197	48	11B
0005433613777	5197	49	11C
0005433613807	5197	50	11D
0005432104983	5197	51	11F
0005432104957	5197	52	11E
0005433784508	5197	53	12A
0005433613800	5197	54	12C
0005432104976	5197	55	12B
0005433613786	5197	56	12D
0005433784485	5197	57	12E
0005432104968	5197	58	12F
0005433784480	5197	59	13A
0005433613781	5197	60	13C
0005432104961	5197	61	13B
0005433613815	5197	62	13E
0005432105004	5197	63	13D
0005433613818	5197	64	14A
0005433613806	5197	65	13F
0005433613832	5197	66	14B
0005433613791	5197	67	14C
0005433613804	5197	68	14E
0005433784501	5197	69	14D
0005433784504	5197	70	14F
0005433613790	5197	71	15B
0005433784495	5197	72	15A
0005433784502	5197	73	15C
0005432104963	5197	74	15D
0005432104988	5197	75	15E
0005432665249	5197	76	16A
0005433784487	5197	77	15F
0005432104994	5197	78	16B
0005432104993	5197	79	16C
0005433784509	5197	80	16F
0005432104966	5197	81	16E
0005432104974	5197	82	16D
0005433784482	5197	83	17A
0005433613816	5197	84	17C
0005433613826	5197	85	17B
0005433613827	5197	86	17E
0005433613769	5197	87	17D
0005433613765	5197	88	17F
0005433613808	5197	89	18A
0005433784505	5197	90	18B
0005433613774	5197	91	18C
0005433613814	5197	92	18D
0005433613768	5197	93	19B
0005432104980	5197	94	18F
0005433613821	5197	95	18E
0005433784503	5197	96	19D
0005433784479	5197	97	19C
0005432104997	5197	98	19E
0005433784497	5197	99	20B
0005433613767	5197	100	20A
0005433613766	5197	101	20C
0005433613779	5197	102	20D
0005433613833	5197	103	20F
0005433613805	5197	104	20E
0005433613824	5197	105	21A
0005432104998	5197	106	21C
0005433784512	5197	107	21B
0005432104992	5197	108	21D
0005432104969	5197	109	21E
0005433784490	5197	110	22A
0005433613772	5197	111	21F
0005433613771	5197	112	22B
0005433613764	5197	113	22C
0005432105001	5197	114	22D
0005432145086	5197	115	22F
0005433613794	5197	116	22E
0005432104973	5197	117	23A
0005433613787	5197	118	23B
0005433613788	5197	119	23D
0005432145087	5197	120	23C
0005433613801	5197	121	23E
0005432104979	5197	122	24A
0005433613822	5197	123	23F
0005433613817	5197	124	24B
0005432104964	5197	125	24C
0005433784510	5197	126	24D
0005432667428	5197	127	24F
0005433613782	5197	128	24E
0005433613763	5197	129	25A
0005433784496	5197	130	25C
0005433613828	5197	131	25B
0005433613831	5197	132	25D
0005433784489	5197	133	25E
0005433613803	5197	134	26A
0005433613789	5197	135	25F
0005433784499	5197	136	26B
0005432105002	5197	137	26C
0005433784484	5197	138	26E
0005433784511	5197	139	26D
0005433784486	5197	140	26F
0005432104959	5197	141	27A
0005433613762	5197	142	27C
0005433613785	5197	143	27B
0005432104985	5197	144	27D
0005433784492	5197	145	27E
0005433613796	5197	146	27F
0005433613795	5197	147	28B
0005433613761	5197	148	28A
0005433613809	5197	149	28C
0005433613825	5197	150	28E
0005432104991	5197	151	28D
0005433613802	5197	152	28F
0005433613780	5197	153	29A
0005432104984	5197	154	29C
0005432104982	5197	155	29B
0005433613812	5197	156	29E
0005433784515	5197	157	29D
0005432104971	5197	158	30A
0005433613829	5197	159	29F
0005433784514	5197	160	30B
0005432104975	5197	161	30C
0005432105003	5197	162	30D
0005433613799	5197	163	31A
0005432104978	5197	164	30F
0005432104990	5197	165	30E
0005433613784	5197	166	31B
0005432104999	5197	167	31C
0005433613783	5197	168	31D
0005433784494	5197	169	31E
0005433613770	5197	170	31F
0005434229100	5202	1	1C
0005435006602	5202	2	2D
0005434264815	5202	3	3D
0005434173471	5202	4	3C
0005434229096	5202	5	4D
0005434264814	5202	6	5C
0005434264825	5202	7	5D
0005434264833	5202	8	6D
0005434149580	5202	9	7A
0005434149591	5202	10	7D
0005434149592	5202	11	9B
0005434264821	5202	12	10E
0005434173472	5202	13	10F
0005434264829	5202	14	11C
0005434264823	5202	15	11D
0005434264828	5202	16	11E
0005434229082	5202	17	12A
0005434264809	5202	18	12C
0005434264817	5202	19	12B
0005434149587	5202	20	12F
0005434149584	5202	21	13B
0005435006601	5202	22	13C
0005435006629	5202	23	13D
0005434229097	5202	24	13F
0005434149583	5202	25	14C
0005434229092	5202	26	15B
0005434229084	5202	27	15A
0005434229095	5202	28	15C
0005434229094	5202	29	15E
0005434229090	5202	30	16A
0005434264819	5202	31	16B
0005434173468	5202	32	16E
0005434149585	5202	33	17A
0005435006603	5202	34	17F
0005434264818	5202	35	17E
0005434264830	5202	36	18C
0005434229089	5202	37	18B
0005434264832	5202	38	18E
0005434264834	5202	39	19D
0005434229103	5202	40	19E
0005434149581	5202	41	20E
0005434264822	5202	42	21A
0005434264812	5202	43	20F
0005434229086	5202	44	21D
0005434264831	5202	45	21F
0005434149589	5202	46	22C
0005434264820	5202	47	22E
0005434173469	5202	48	22D
0005434229098	5202	49	22F
0005434149582	5202	50	23C
0005434173470	5202	51	23F
0005434264811	5202	52	24F
0005434264810	5202	53	25A
0005434149586	5202	54	25B
0005434229083	5202	55	25D
0005434264824	5202	56	26B
0005434149588	5202	57	26A
0005434149590	5202	58	26C
0005435006633	5202	59	26D
0005435006632	5202	60	27A
0005434264813	5202	61	27F
0005434264827	5202	62	28B
0005434264808	5202	63	28C
0005434229102	5202	64	28E
0005434229088	5202	65	28D
0005434229101	5202	66	29B
0005434229087	5202	67	29D
0005434264826	5202	68	29E
0005434229093	5202	69	30B
0005434264816	5202	70	30C
0005434229081	5202	71	30D
0005434229085	5202	72	31B
0005434229091	5202	73	31D
0005434229099	5202	74	31E
0005435269668	8492	1	2D
0005433784323	8492	2	5A
0005433784363	8492	3	5D
0005435269665	8492	4	8D
0005433784324	8492	5	8E
0005435269669	8492	6	9D
0005433784315	8492	7	12C
0005434244484	8492	8	12D
0005435269670	8492	9	17A
0005433784314	8492	10	17B
0005435269671	8492	11	18E
0005435269666	8492	12	19B
0005433784361	8492	13	20F
0005434244473	8492	14	21F
0005433784313	8492	15	23E
0005434244456	8492	16	27C
0005433784360	8492	17	28A
0005435269667	8492	18	31E
0005433613610	8491	1	9A
0005433613471	8491	2	24E
0005432034619	8490	1	1A
0005432335890	8490	2	1D
0005435006727	8490	3	2A
0005432335891	8490	4	2C
0005432034599	8490	5	2F
0005432335889	8490	6	2D
0005432034596	8490	7	3D
0005432335894	8490	8	3F
0005435006733	8490	9	4A
0005435006732	8490	10	4D
0005433690902	8490	11	4C
0005433690901	8490	12	5C
0005433815329	8490	13	5F
0005435006742	8490	14	7C
0005432034609	8490	15	8A
0005432335884	8490	16	8C
0005432034603	8490	17	8B
0005432047503	8490	18	8D
0005435006736	8490	19	8E
0005434264696	8490	20	8F
0005432034613	8490	21	9A
0005434228967	8490	22	9C
0005435006745	8490	23	9D
0005432034601	8490	24	9E
0005433689886	8490	25	10B
0005435006744	8490	26	10D
0005434311191	8490	27	10E
0005432034595	8490	28	11E
0005433689885	8490	29	11D
0005435006728	8490	30	12B
0005432034605	8490	31	12C
0005432034602	8490	32	13B
0005434149525	8490	33	13D
0005432335893	8490	34	13E
0005432034591	8490	35	14A
0005432335882	8490	36	14C
0005433815328	8490	37	14E
0005435006738	8490	38	14D
0005432335881	8490	39	15C
0005432034600	8490	40	15D
0005433815325	8490	41	15E
0005432034606	8490	42	16B
0005432034615	8490	43	16C
0005434311193	8490	44	16D
0005432335886	8490	45	16F
0005435006731	8490	46	17E
0005435006741	8490	47	18C
0005432034592	8490	48	18E
0005435006735	8490	49	18F
0005432034593	8490	50	19E
0005433815327	8490	51	20B
0005434264697	8490	52	20A
0005432034610	8490	53	20C
0005433690900	8490	54	20D
0005432047502	8490	55	20F
0005435006729	8490	56	21A
0005434228977	8490	57	21C
0005435006734	8490	58	21B
0005434228966	8490	59	21D
0005434228968	8490	60	22B
0005433688784	8490	61	22D
0005432335887	8490	62	22E
0005432034604	8490	63	22F
0005435006725	8490	64	23A
0005432034608	8490	65	23C
0005432034607	8490	66	24A
0005432034594	8490	67	24B
0005435006739	8490	68	24D
0005432034614	8490	69	24E
0005435006723	8490	70	25B
0005432034612	8490	71	25E
0005432335888	8490	72	25F
0005432034616	8490	73	26E
0005432335885	8490	74	26F
0005432034618	8490	75	27B
0005435006730	8490	76	28A
0005435006740	8490	77	27F
0005432335892	8490	78	28B
0005434311192	8490	79	28D
0005432047504	8490	80	28C
0005432335883	8490	81	28E
0005432047505	8490	82	29B
0005435006737	8490	83	29D
0005433815326	8490	84	29F
0005435006743	8490	85	30B
0005433534472	8490	86	30C
0005435006726	8490	87	30F
0005432034611	8490	88	31B
0005432034617	8490	89	31A
0005432034598	8490	90	31C
0005435006724	8490	91	31E
0005432034597	8490	92	31F
0005433202183	12606	1	1B
0005434638878	12606	2	1C
0005433202189	12606	3	2C
0005433202184	12606	4	3C
0005433202178	12606	5	3D
0005434638905	12606	6	4A
0005433202179	12606	7	4B
0005433202180	12606	8	5C
0005433202182	12606	9	6C
0005433202185	12606	10	7B
0005434638846	12606	11	18C
0005433202181	12606	12	18D
0005433202188	12606	13	19B
0005434638847	12606	14	20D
0005433202186	12606	15	21B
0005433202190	12606	16	21D
0005433202191	12606	17	22B
0005433202187	12606	18	22D
0005433202177	12606	19	23A
0005434638976	23363	1	1A
0005432290591	23363	2	1B
0005434638982	23363	3	1C
0005434638973	23363	4	2B
0005434638969	23363	5	2C
0005434638964	23363	6	3B
0005434638974	23363	7	3C
0005434638957	23363	8	3D
0005434638984	23363	9	4A
0005432290592	23363	10	4B
0005434638983	23363	11	5A
0005434638967	23363	12	5B
0005434638966	23363	13	6C
0005434638972	23363	14	6D
0005434638965	23363	15	7A
0005434638961	23363	16	7B
0005434638981	23363	17	18A
0005434638956	23363	18	18B
0005434638977	23363	19	18C
0005434638960	23363	20	18D
0005432290593	23363	21	19A
0005434638962	23363	22	19B
0005434638979	23363	23	19C
0005434638975	23363	24	19D
0005434638970	23363	25	20A
0005434638959	23363	26	20B
0005434638958	23363	27	20C
0005434638980	23363	28	21B
0005434638978	23363	29	22A
0005434638968	23363	30	22C
0005434638971	23363	31	22D
0005434638963	23363	32	23A
0005432382491	21058	1	2A
0005432054267	21058	2	4C
0005432054269	21058	3	11A
0005432327962	21058	4	14A
0005432382492	21058	5	14E
0005432328012	21058	6	15F
0005432054268	21058	7	17E
0005432328009	21058	8	18A
0005432328095	31274	1	1A
0005432328090	31274	2	1C
0005432287121	31274	3	1D
0005432382669	31274	4	1F
0005432328117	31274	5	2A
0005432328101	31274	6	2C
0005432382662	31274	7	2D
0005432382687	31274	8	2F
0005432328088	31274	9	3A
0005432328082	31274	10	3C
0005432328112	31274	11	3D
0005432382679	31274	12	3F
0005432328120	31274	13	4A
0005432328080	31274	14	4C
0005432382678	31274	15	4D
0005432382655	31274	16	4E
0005432382686	31274	17	4F
0005432382681	31274	18	5A
0005432382650	31274	19	5C
0005432328105	31274	20	5E
0005432328103	31274	21	5D
0005432287123	31274	22	5F
0005432328115	31274	23	6A
0005432382661	31274	24	6C
0005432382665	31274	25	6D
0005432328106	31274	26	6E
0005432382666	31274	27	6F
0005432328122	31274	28	7A
0005432328118	31274	29	7C
0005432382663	31274	30	7D
0005432328084	31274	31	7E
0005432382685	31274	32	7F
0005432382670	31274	33	8A
0005432382660	31274	34	8D
0005432328089	31274	35	8E
0005432287124	31274	36	8F
0005432382668	31274	37	9A
0005432328110	31274	38	9C
0005432328091	31274	39	9D
0005432382653	31274	40	9E
0005432382688	31274	41	9F
0005432382664	31274	42	10A
0005432382658	31274	43	10C
0005432328097	31274	44	10D
0005432382667	31274	45	10E
0005432328121	31274	46	10F
0005432382672	31274	47	11A
0005432328108	31274	48	11C
0005432328098	31274	49	11D
0005432382683	31274	50	11E
0005432328093	31274	51	11F
0005432328104	31274	52	12A
0005432382690	31274	53	12C
0005432328092	31274	54	12D
0005432382651	31274	55	12E
0005432328119	31274	56	12F
0005432328086	31274	57	13A
0005432287120	31274	58	13C
0005432328124	31274	59	13D
0005432328085	31274	60	13E
0005432328094	31274	61	13F
0005432382676	31274	62	14A
0005432382677	31274	63	14C
0005432382682	31274	64	14D
0005432382652	31274	65	14E
0005432328123	31274	66	14F
0005432328102	31274	67	15A
0005432287122	31274	68	15C
0005432328083	31274	69	15D
0005432328099	31274	70	15E
0005432328116	31274	71	15F
0005432382649	31274	72	16A
0005432382671	31274	73	16C
0005432328109	31274	74	16D
0005432382654	31274	75	16E
0005432328100	31274	76	16F
0005432382656	31274	77	17C
0005432328087	31274	78	17A
0005432328113	31274	79	17D
0005432382659	31274	80	17E
0005432328081	31274	81	17F
0005432382680	31274	82	18A
0005432328079	31274	83	18C
0005432382657	31274	84	18E
0005432382673	31274	85	18F
0005432382689	31274	86	19A
0005432328096	31274	87	19C
0005432328107	31274	88	19E
0005432328114	31274	89	19F
0005432382674	31274	90	20A
0005432328111	31274	91	20C
0005432328078	31274	92	20D
0005432382684	31274	93	20E
0005432382675	31274	94	20F
0005432423835	13283	1	1D
0005432423828	13283	2	2A
0005432423824	13283	3	2D
0005432423852	13283	4	2F
0005432423837	13283	5	3A
0005432423815	13283	6	3C
0005432423827	13283	7	3D
0005432423838	13283	8	4A
0005432423812	13283	9	4E
0005432423810	13283	10	4F
0005432423834	13283	11	5D
0005432423811	13283	12	6C
0005432423848	13283	13	6D
0005432423820	13283	14	6F
0005432423839	13283	15	7F
0005432423818	13283	16	8A
0005432423859	13283	17	8C
0005432423841	13283	18	8E
0005432423833	13283	19	8F
0005432423836	13283	20	9A
0005432423821	13283	21	9C
0005432423814	13283	22	9E
0005432423846	13283	23	10A
0005432423850	13283	24	10C
0005432423851	13283	25	10E
0005432423853	13283	26	10F
0005432423832	13283	27	11A
0005432423843	13283	28	12A
0005432423813	13283	29	12D
0005432423845	13283	30	12F
0005432423830	13283	31	13A
0005432423856	13283	32	13E
0005432423854	13283	33	14A
0005432423857	13283	34	14C
0005432423842	13283	35	14D
0005432423844	13283	36	15F
0005432423825	13283	37	16C
0005432423822	13283	38	16D
0005432423840	13283	39	16E
0005432423831	13283	40	17A
0005432423823	13283	41	17C
0005432423847	13283	42	18A
0005432423816	13283	43	18D
0005432423849	13283	44	18E
0005432423826	13283	45	19A
0005432423858	13283	46	19C
0005432423855	13283	47	19D
0005432423817	13283	48	19F
0005432423819	13283	49	20A
0005432423829	13283	50	20D
0005432817108	9576	1	1C
0005432817100	9576	2	2A
0005434448271	9576	3	2C
0005432817109	9576	4	2F
0005432817111	9576	5	3A
0005432817089	9576	6	3C
0005432822111	9576	7	3F
0005432817097	9576	8	4A
0005432288945	9576	9	5A
0005432817092	9576	10	6D
0005432817102	9576	11	6F
0005432822106	9576	12	7A
0005432817117	9576	13	7E
0005432817118	9576	14	7F
0005432822112	9576	15	8A
0005432817113	9576	16	8D
0005432901309	9576	17	8F
0005434157346	9576	18	9C
0005432288944	9576	19	9D
0005432817107	9576	20	10A
0005432817115	9576	21	10D
0005432817091	9576	22	10E
0005432817099	9576	23	11D
0005432817094	9576	24	11E
0005432901308	9576	25	11F
0005432817101	9576	26	12A
0005432817106	9576	27	12C
0005432817098	9576	28	12D
0005432817110	9576	29	12F
0005432822109	9576	30	13E
0005434448272	9576	31	14C
0005432822108	9576	32	14E
0005434448274	9576	33	14F
0005432817103	9576	34	15F
0005432817090	9576	35	16C
0005432817114	9576	36	16D
0005432822107	9576	37	17C
0005432817104	9576	38	18C
0005432817093	9576	39	18D
0005432822110	9576	40	18F
0005434448273	9576	41	19A
0005432817105	9576	42	19E
0005432817116	9576	43	19F
0005432817095	9576	44	20C
0005432817112	9576	45	20D
0005432288946	9576	46	20E
0005432817096	9576	47	20F
0005434157384	28973	1	2D
0005432901384	28973	2	3C
0005434186161	28973	3	4A
0005432901391	28973	4	4C
0005432901387	28973	5	4D
0005432901396	28973	6	5A
0005432901390	28973	7	5D
0005434157385	28973	8	5E
0005434186162	28973	9	6C
0005432901394	28973	10	7C
0005432901397	28973	11	7D
0005434157380	28973	12	8A
0005434157381	28973	13	8C
0005432002050	28973	14	8D
0005434157379	28973	15	9C
0005432901389	28973	16	9D
0005434157382	28973	17	10C
0005432901400	28973	18	10E
0005432901386	28973	19	11D
0005434186160	28973	20	11E
0005432901401	28973	21	11F
0005432901393	28973	22	12F
0005432816938	28973	23	13C
0005432901399	28973	24	13E
0005434157383	28973	25	14C
0005432002051	28973	26	14F
0005432901398	28973	27	15A
0005432901395	28973	28	15E
0005432901388	28973	29	16A
0005432816972	28973	30	17F
0005434157386	28973	31	18C
0005432901392	28973	32	18D
0005432901385	28973	33	19C
0005432611660	15040	1	1A
0005432611661	15040	2	1B
0005432611662	15040	3	2A
0005432613810	15040	4	4A
0005432613811	15040	5	5A
0005432613812	15040	6	5B
0005432613809	15040	7	6A
0005432611659	15040	8	6B
0005435841812	31621	1	1B
0005435842317	31621	2	3A
0005435842318	31621	3	3B
0005433568298	11838	1	2D
0005433568296	11838	2	2F
0005433568272	11838	3	3F
0005433568301	11838	4	4C
0005433568307	11838	5	5C
0005433568306	11838	6	5F
0005433568285	11838	7	6B
0005433568281	11838	8	6D
0005433568269	11838	9	6C
0005433568293	11838	10	7C
0005433568305	11838	11	7B
0005433568274	11838	12	8A
0005433568279	11838	13	7F
0005433568261	11838	14	9B
0005433568263	11838	15	9D
0005433568276	11838	16	9F
0005433568294	11838	17	10B
0005433568302	11838	18	11A
0005433568295	11838	19	11D
0005433568290	11838	20	11F
0005433568283	11838	21	11E
0005433568264	11838	22	12A
0005433568288	11838	23	12D
0005433568299	11838	24	12B
0005433568297	11838	25	12F
0005433568271	11838	26	13C
0005433568265	11838	27	13F
0005433568286	11838	28	14B
0005433568268	11838	29	14F
0005433568287	11838	30	15B
0005433568273	11838	31	15C
0005433568291	11838	32	15E
0005433568270	11838	33	16C
0005433568262	11838	34	16B
0005433568303	11838	35	17B
0005433568267	11838	36	17D
0005433568278	11838	37	17C
0005433568284	11838	38	17F
0005433568289	11838	39	18C
0005433568282	11838	40	19A
0005433568259	11838	41	19C
0005433568304	11838	42	19D
0005433568260	11838	43	20B
0005433568280	11838	44	20A
0005433568277	11838	45	20D
0005433568266	11838	46	20C
0005433568300	11838	47	21A
0005433568292	11838	48	20F
0005433568275	11838	49	21D
0005432947985	25326	1	2A
0005432948012	25326	2	2C
0005432947978	25326	3	3A
0005432947994	25326	4	3C
0005432947980	25326	5	3F
0005432948005	25326	6	4C
0005432947987	25326	7	4F
0005432948007	25326	8	5F
0005432948010	25326	9	6D
0005432948004	25326	10	6C
0005432948000	25326	11	6B
0005432947995	25326	12	7E
0005432947996	25326	13	7F
0005432948003	25326	14	8B
0005432947988	25326	15	8A
0005432947989	25326	16	8D
0005432947990	25326	17	8F
0005432947999	25326	18	9A
0005432947986	25326	19	9B
0005432948009	25326	20	10B
0005432947981	25326	21	10D
0005432947993	25326	22	11C
0005432947977	25326	23	11B
0005432947991	25326	24	12A
0005432948002	25326	25	12D
0005432947974	25326	26	14F
0005432948006	25326	27	15B
0005432947979	25326	28	15E
0005432947992	25326	29	16A
0005432947984	25326	30	16C
0005432947973	25326	31	16B
0005432948011	25326	32	16E
0005432948001	25326	33	17A
0005432948008	25326	34	17C
0005432947997	25326	35	17F
0005432947972	25326	36	17E
0005432947976	25326	37	19C
0005432947998	25326	38	20A
0005432947982	25326	39	21B
0005432947983	25326	40	21A
0005432947975	25326	41	21E
0005434654327	5422	1	2A
0005434654314	5422	2	3A
0005434654325	5422	3	3C
0005434656530	5422	4	3D
0005434654309	5422	5	3F
0005434654315	5422	6	4E
0005434656531	5422	7	4F
0005434654338	5422	8	5F
0005434654316	5422	9	6A
0005434654324	5422	10	6D
0005434654334	5422	11	6F
0005434654331	5422	12	8A
0005432114164	5422	13	8D
0005434654337	5422	14	8F
0005432114163	5422	15	9D
0005434654326	5422	16	9F
0005434654312	5422	17	10C
0005434654317	5422	18	10F
0005432114162	5422	19	11F
0005434654313	5422	20	12C
0005434654318	5422	21	12D
0005434654333	5422	22	13A
0005434654319	5422	23	13D
0005434654336	5422	24	14A
0005434654329	5422	25	14E
0005434654328	5422	26	15C
0005434654321	5422	27	16D
0005434654330	5422	28	16F
0005434654311	5422	29	17A
0005434654320	5422	30	17C
0005434654323	5422	31	17E
0005434654335	5422	32	18D
0005434654332	5422	33	18E
0005434654322	5422	34	18F
0005434654310	5422	35	19E
0005435555345	12548	1	1C
0005435340069	12548	2	3D
0005435555347	12548	3	4A
0005435340066	12548	4	6C
0005435340080	12548	5	7A
0005435340070	12548	6	10C
0005435340073	12548	7	10E
0005435555344	12548	8	11A
0005435340068	12548	9	11C
0005435340079	12548	10	11E
0005435340081	12548	11	11F
0005435340072	12548	12	12C
0005435340074	12548	13	12F
0005435340075	12548	14	14A
0005435340078	12548	15	14D
0005435340067	12548	16	16F
0005435555346	12548	17	19C
0005435340077	12548	18	20A
0005435340071	12548	19	20E
0005435340076	12548	20	20F
0005433715331	7451	1	2C
0005433719094	7451	2	2A
0005433688782	7451	3	3A
0005433722128	7451	4	3C
0005433715346	7451	5	3F
0005433715322	7451	6	4A
0005433715344	7451	7	4C
0005433715335	7451	8	4D
0005433715336	7451	9	4F
0005433715328	7451	10	5B
0005433715350	7451	11	5C
0005433715371	7451	12	5E
0005433715345	7451	13	6A
0005433715343	7451	14	5F
0005433656626	7451	15	6B
0005433715326	7451	16	7B
0005433715372	7451	17	7C
0005433722129	7451	18	7E
0005433715364	7451	19	7D
0005433715337	7451	20	8C
0005433715349	7451	21	9B
0005433715333	7451	22	9C
0005433715342	7451	23	9E
0005432078038	7451	24	9D
0005433656625	7451	25	10D
0005433715353	7451	26	11A
0005433722130	7451	27	10E
0005433688783	7451	28	11C
0005433715357	7451	29	11E
0005433715348	7451	30	11F
0005433715324	7451	31	12A
0005433715338	7451	32	12C
0005433715370	7451	33	12B
0005433715358	7451	34	12F
0005433715355	7451	35	13C
0005433715363	7451	36	13D
0005433715367	7451	37	13E
0005433715352	7451	38	14A
0005433715334	7451	39	14B
0005433715351	7451	40	14D
0005433715325	7451	41	14E
0005433715329	7451	42	15C
0005433715361	7451	43	15D
0005433715365	7451	44	16F
0005432078037	7451	45	16E
0005433715354	7451	46	17D
0005433715340	7451	47	18A
0005433715356	7451	48	18C
0005433715369	7451	49	18D
0005433715360	7451	50	18F
0005433715366	7451	51	18E
0005433715341	7451	52	19B
0005433719095	7451	53	19D
0005433715368	7451	54	19F
0005433719097	7451	55	19E
0005433715359	7451	56	20A
0005433715327	7451	57	20D
0005433722131	7451	58	20E
0005433715323	7451	59	21A
0005433690899	7451	60	20F
0005433715362	7451	61	21D
0005433715332	7451	62	21F
0005433656627	7451	63	21E
0005433715339	7451	64	22B
0005433719096	7451	65	22A
0005433689884	7451	66	22E
0005433715330	7451	67	23B
0005433715347	7451	68	23A
0005432078039	7451	69	23D
0005432078041	7451	70	23C
0005432078040	7451	71	23F
0005435266085	29256	1	1A
0005433715076	29256	2	2C
0005435266083	29256	3	3A
0005435266088	29256	4	4C
0005435266080	29256	5	4E
0005432428887	29256	6	5A
0005432006725	29256	7	5F
0005435266089	29256	8	8F
0005435266090	29256	9	9D
0005435266084	29256	10	10B
0005432428885	29256	11	12B
0005435266091	29256	12	13D
0005433715184	29256	13	14B
0005435266081	29256	14	15D
0005435266087	29256	15	15F
0005433715074	29256	16	17B
0005435266082	29256	17	18F
0005435266086	29256	18	19E
0005433715075	29256	19	20D
0005432428886	29256	20	20E
0005434095100	8668	1	1C
0005434095093	8668	2	3C
0005434095101	8668	3	3F
0005434095091	8668	4	5C
0005434095103	8668	5	6C
0005434095097	8668	6	7A
0005434181966	8668	7	7C
0005434095090	8668	8	7D
0005434095099	8668	9	10D
0005434095096	8668	10	13C
0005434095102	8668	11	13E
0005434181962	8668	12	17A
0005434181965	8668	13	17C
0005434095095	8668	14	17E
0005434095092	8668	15	18F
0005434095089	8668	16	19A
0005434095098	8668	17	19D
0005434095094	8668	18	20E
0005434183554	11640	1	1C
0005434182034	11640	2	3C
0005434184639	11640	3	3F
0005434183553	11640	4	5A
0005434182033	11640	5	5D
0005434182025	11640	6	7C
0005434182028	11640	7	7D
0005434095027	11640	8	7E
0005434182031	11640	9	10A
0005434182024	11640	10	11C
0005434182022	11640	11	11D
0005434182027	11640	12	11E
0005434183552	11640	13	12C
0005434184637	11640	14	12D
0005434182026	11640	15	13A
0005434184638	11640	16	14C
0005434095026	11640	17	15A
0005434182023	11640	18	16F
0005434182029	11640	19	17F
0005434182032	11640	20	18A
0005434182030	11640	21	20E
0005433456918	1412	1	1D
0005435732169	1412	2	1F
0005435732175	1412	3	2A
0005432297245	1412	4	2D
0005433397246	1412	5	3F
0005435732177	1412	6	4E
0005432297244	1412	7	5F
0005433397228	1412	8	6F
0005433456920	1412	9	7A
0005432297243	1412	10	7E
0005433397184	1412	11	8D
0005435732170	1412	12	8F
0005433397198	1412	13	9C
0005435732166	1412	14	9E
0005433456919	1412	15	10F
0005435732174	1412	16	11E
0005435732176	1412	17	13A
0005435732178	1412	18	14C
0005433397185	1412	19	14E
0005433397227	1412	20	14F
0005435732167	1412	21	15A
0005433456917	1412	22	15E
0005435732179	1412	23	16A
0005435732173	1412	24	18A
0005435732172	1412	25	18C
0005435732168	1412	26	19D
0005435732171	1412	27	20A
0005433397448	19247	1	2C
0005433397440	19247	2	3A
0005433397432	19247	3	3C
0005433397451	19247	4	3F
0005433397460	19247	5	4D
0005433397473	19247	6	4F
0005433397461	19247	7	5A
0005433397434	19247	8	5C
0005433397436	19247	9	5D
0005433397428	19247	10	5E
0005433397459	19247	11	5F
0005433397439	19247	12	6D
0005433397458	19247	13	6E
0005433397443	19247	14	6F
0005433397457	19247	15	7A
0005433397464	19247	16	7C
0005433397455	19247	17	7D
0005433397465	19247	18	8C
0005433397462	19247	19	8D
0005435732113	19247	20	9A
0005433397433	19247	21	9C
0005433397476	19247	22	10A
0005433397441	19247	23	10E
0005433397472	19247	24	10F
0005433397474	19247	25	11A
0005433397471	19247	26	11C
0005432906505	19247	27	12A
0005433397467	19247	28	12C
0005433397447	19247	29	12D
0005433397431	19247	30	12E
0005433397446	19247	31	12F
0005432906504	19247	32	13A
0005433397444	19247	33	13C
0005433397475	19247	34	13E
0005433397430	19247	35	14C
0005432906506	19247	36	14D
0005433397442	19247	37	14E
0005433397454	19247	38	14F
0005433397453	19247	39	15C
0005433397445	19247	40	15F
0005433397463	19247	41	16A
0005433397429	19247	42	16C
0005433397449	19247	43	17A
0005433397452	19247	44	17C
0005433397470	19247	45	17D
0005433397437	19247	46	17E
0005433397466	19247	47	18C
0005433397438	19247	48	18E
0005433397469	19247	49	18F
0005433397435	19247	50	19A
0005433397456	19247	51	20C
0005433397468	19247	52	20E
0005433397450	19247	53	20F
0005434443432	17377	1	3A
0005434443430	17377	2	6C
0005434443431	17377	3	18B
0005434443429	17377	4	19D
0005434443501	20582	1	2D
0005434443493	20582	2	3A
0005434443494	20582	3	3D
0005434443492	20582	4	4C
0005434443490	20582	5	5C
0005434443496	20582	6	6A
0005434443503	20582	7	6B
0005434443498	20582	8	6D
0005434443506	20582	9	7D
0005434443499	20582	10	18D
0005434443504	20582	11	19B
0005434443495	20582	12	19D
0005434443497	20582	13	20A
0005434443491	20582	14	20B
0005434443502	20582	15	20D
0005434443489	20582	16	21A
0005434443505	20582	17	22A
0005434443500	20582	18	22B
0005434954559	7236	1	1B
0005434954560	7236	2	4A
0005434954561	7236	3	4B
0005435377550	28300	1	5B
0005434351529	4452	1	1D
0005434351538	4452	2	2C
0005434351535	4452	3	2D
0005434351532	4452	4	3A
0005434351530	4452	5	3C
0005434183544	4452	6	5D
0005434326263	4452	7	7C
0005434351534	4452	8	7D
0005434351537	4452	9	18A
0005434351539	4452	10	18B
0005434326262	4452	11	18D
0005434351533	4452	12	19C
0005434351531	4452	13	20C
0005434351536	4452	14	21B
0005434351541	4452	15	21D
0005434351540	4452	16	22C
0005435893545	29672	1	2B
0005435893541	29672	2	5B
0005435893540	29672	3	7B
0005435893543	29672	4	7D
0005435893544	29672	5	20B
0005435893542	29672	6	21A
0005435091951	1091	1	2H
0005433462721	1091	2	5F
0005433463874	1091	3	9H
0005433269628	1091	4	12F
0005434445217	1091	5	13F
0005435545641	1091	6	14F
0005435091953	1091	7	15A
0005434445219	1091	8	17B
0005435091943	1091	9	18A
0005432293178	1091	10	18H
0005434446491	1091	11	19E
0005435091944	1091	12	19F
0005432293177	1091	13	20F
0005435091950	1091	14	22A
0005435091952	1091	15	23D
0005435091945	1091	16	23F
0005434445220	1091	17	24F
0005435091949	1091	18	25D
0005433269623	1091	19	27B
0005433341432	1091	20	28H
0005435091947	1091	21	35A
0005435545642	1091	22	35D
0005433269646	1091	23	35E
0005433463873	1091	24	36F
0005433462719	1091	25	36E
0005434445218	1091	26	37H
0005435091946	1091	27	38B
0005433462720	1091	28	38E
0005432293176	1091	29	38H
0005435091948	1091	30	39E
0005433341841	17034	1	1B
0005433341796	17034	2	1F
0005433341862	17034	3	2G
0005433341813	17034	4	2H
0005433341789	17034	5	3C
0005433341877	17034	6	3A
0005433341816	17034	7	3F
0005433341846	17034	8	3G
0005433341810	17034	9	4F
0005433341824	17034	10	4C
0005435091895	17034	11	4G
0005433341854	17034	12	4H
0005433341803	17034	13	5A
0005433341887	17034	14	5C
0005433341864	17034	15	5H
0005433341883	17034	16	9B
0005433341787	17034	17	9A
0005433341821	17034	18	9G
0005433341878	17034	19	11A
0005433341849	17034	20	12H
0005433341855	17034	21	13B
0005433341836	17034	22	13A
0005433269650	17034	23	13E
0005433341881	17034	24	13G
0005433341839	17034	25	13H
0005433341801	17034	26	14B
0005433341856	17034	27	15A
0005433341860	17034	28	14H
0005433341848	17034	29	15E
0005433341814	17034	30	15H
0005433159285	17034	31	16B
0005433341882	17034	32	16E
0005433341798	17034	33	16F
0005433341838	17034	34	16H
0005433341808	17034	35	17B
0005433269652	17034	36	17D
0005433341859	17034	37	17E
0005433341852	17034	38	17G
0005433341818	17034	39	17H
0005433341843	17034	40	18D
0005433341823	17034	41	18E
0005433341806	17034	42	18G
0005433341809	17034	43	19A
0005433341867	17034	44	18H
0005433341866	17034	45	19E
0005433341835	17034	46	19F
0005433341875	17034	47	19G
0005433341851	17034	48	20D
0005433341794	17034	49	20F
0005433341827	17034	50	21A
0005433341840	17034	51	21B
0005433341791	17034	52	21D
0005433341799	17034	53	21G
0005433341872	17034	54	21F
0005433341832	17034	55	21H
0005433341788	17034	56	22B
0005433341830	17034	57	22A
0005433341822	17034	58	22D
0005433341834	17034	59	22E
0005433341792	17034	60	22G
0005433341847	17034	61	23A
0005433341815	17034	62	23B
0005433341842	17034	63	23E
0005433341802	17034	64	23D
0005433341819	17034	65	24A
0005433341861	17034	66	23H
0005433341807	17034	67	24B
0005433341865	17034	68	24F
0005433341817	17034	69	24G
0005433341790	17034	70	25D
0005433341879	17034	71	24H
0005433341800	17034	72	25F
0005433341853	17034	73	27B
0005433341873	17034	74	27A
0005433269649	17034	75	27E
0005433159284	17034	76	27D
0005433341812	17034	77	27F
0005433341869	17034	78	27G
0005433341880	17034	79	28A
0005433341885	17034	80	27H
0005435091896	17034	81	28D
0005433341831	17034	82	29B
0005433341825	17034	83	29A
0005433341793	17034	84	29D
0005433341884	17034	85	29G
0005433341811	17034	86	29F
0005433341871	17034	87	29H
0005433341863	17034	88	30A
0005433341858	17034	89	30D
0005433341845	17034	90	30G
0005433341826	17034	91	30H
0005435091919	17034	92	31B
0005433341886	17034	93	31F
0005433341828	17034	94	31G
0005433341829	17034	95	31H
0005433341870	17034	96	32B
0005433341857	17034	97	32A
0005433341844	17034	98	32D
0005433341868	17034	99	32F
0005433341795	17034	100	32G
0005433341797	17034	101	33A
0005433341876	17034	102	33G
0005433341850	17034	103	34E
0005433269648	17034	104	34G
0005433269651	17034	105	34F
0005433341804	17034	106	34H
0005433341833	17034	107	35E
0005433341820	17034	108	35D
0005433159283	17034	109	37F
0005433341874	17034	110	37G
0005433341805	17034	111	38D
0005433341837	17034	112	38G
0005433269647	17034	113	39E
0005433812869	12774	1	1D
0005433812870	12774	2	3A
0005432159798	12774	3	5B
0005432433611	12774	4	6E
0005432433612	12774	5	7C
0005432159800	12774	6	7E
0005433812871	12774	7	9A
0005432159802	12774	8	8F
0005434066307	12774	9	10D
0005434066330	12774	10	11B
0005432159801	12774	11	11C
0005434066505	12774	12	11E
0005432433613	12774	13	12D
0005434066349	12774	14	13A
0005432433614	12774	15	14C
0005432159799	12774	16	14F
0005434081516	12774	17	15F
0005434066421	12774	18	17B
0005434066390	12774	19	17D
0005432433610	12774	20	17C
0005432433609	12774	21	23D
0005434066585	30651	1	1A
0005434081580	30651	2	1D
0005434081587	30651	3	1F
0005433989707	30651	4	2A
0005434026676	30651	5	2D
0005434066624	30651	6	2C
0005434081581	30651	7	2F
0005433989708	30651	8	3A
0005434081579	30651	9	3D
0005434066612	30651	10	3C
0005434066632	30651	11	3F
0005434066622	30651	12	4B
0005432186820	30651	13	4A
0005434081578	30651	14	4C
0005434081584	30651	15	4E
0005434066650	30651	16	4D
0005434066645	30651	17	5A
0005434066655	30651	18	4F
0005434066648	30651	19	5C
0005434066597	30651	20	5D
0005434066636	30651	21	5E
0005434081577	30651	22	6A
0005434066592	30651	23	5F
0005434066652	30651	24	6B
0005434081589	30651	25	6C
0005434081593	30651	26	6D
0005434081588	30651	27	6E
0005434081591	30651	28	7A
0005434066627	30651	29	7C
0005434066621	30651	30	7B
0005434066629	30651	31	7D
0005434066600	30651	32	7F
0005432186819	30651	33	7E
0005434026678	30651	34	8A
0005432150091	30651	35	8B
0005434066654	30651	36	8C
0005434066626	30651	37	8E
0005434066623	30651	38	8D
0005434066620	30651	39	8F
0005434066603	30651	40	9C
0005434066605	30651	41	9B
0005434081595	30651	42	9E
0005434066594	30651	43	9D
0005432150086	30651	44	9F
0005434081583	30651	45	10C
0005434066599	30651	46	10B
0005434066588	30651	47	10D
0005434066607	30651	48	11A
0005434026675	30651	49	10E
0005434066606	30651	50	11B
0005434066656	30651	51	11C
0005434081590	30651	52	11E
0005434081586	30651	53	11D
0005434066602	30651	54	11F
0005434066618	30651	55	12B
0005434066589	30651	56	12D
0005432150092	30651	57	12C
0005433989706	30651	58	12E
0005434066595	30651	59	12F
0005434066598	30651	60	13B
0005434066591	30651	61	13A
0005432186821	30651	62	13D
0005434066635	30651	63	13C
0005432186822	30651	64	13E
0005434066586	30651	65	13F
0005434066653	30651	66	14B
0005432433592	30651	67	14A
0005434066590	30651	68	14C
0005434066651	30651	69	14D
0005434066596	30651	70	14E
0005434066604	30651	71	15A
0005433989709	30651	72	15C
0005434081597	30651	73	15B
0005434066647	30651	74	15D
0005434081582	30651	75	15F
0005434066638	30651	76	15E
0005434066637	30651	77	16A
0005432150087	30651	78	16B
0005434066644	30651	79	16C
0005434066613	30651	80	16E
0005434066616	30651	81	16D
0005434066610	30651	82	16F
0005434066630	30651	83	17A
0005434066641	30651	84	17B
0005434066649	30651	85	17D
0005434066601	30651	86	17C
0005433989705	30651	87	17F
0005434066619	30651	88	17E
0005434066609	30651	89	18A
0005434066639	30651	90	18B
0005434066642	30651	91	18D
0005434066634	30651	92	18C
0005434081585	30651	93	18F
0005434066625	30651	94	19A
0005434066640	30651	95	19B
0005434066611	30651	96	19D
0005434081596	30651	97	19C
0005434026674	30651	98	19E
0005434066628	30651	99	19F
0005432150088	30651	100	20A
0005434066643	30651	101	20C
0005434026679	30651	102	20B
0005434066631	30651	103	20D
0005432150093	30651	104	20F
0005434066646	30651	105	21A
0005434081594	30651	106	21C
0005434081592	30651	107	21B
0005434026677	30651	108	21D
0005434066614	30651	109	21E
0005434066633	30651	110	21F
0005434066615	30651	111	22B
0005434066587	30651	112	22C
0005434066617	30651	113	22D
0005434026680	30651	114	22F
0005434066593	30651	115	22E
0005434066608	30651	116	23A
0005434066657	30651	117	23B
0005432150089	30651	118	23C
0005432150090	30651	119	23E
0005434026673	30651	120	23D
0005434026672	30651	121	23F
0005435765448	5496	1	1A
0005435765445	5496	2	1F
0005433527220	5496	3	1G
0005435765408	5496	4	2B
0005435735079	5496	5	2H
0005433527219	5496	6	3F
0005433527221	5496	7	4B
0005435765450	5496	8	4C
0005435765455	5496	9	5C
0005435765420	5496	10	5G
0005435765422	5496	11	9H
0005433529232	5496	12	11F
0005435765446	5496	13	12A
0005435765428	5496	14	11H
0005435765459	5496	15	12E
0005435765412	5496	16	13D
0005435725535	5496	17	13B
0005432140342	5496	18	13F
0005435765463	5496	19	13E
0005435765426	5496	20	13G
0005435765452	5496	21	14B
0005435765456	5496	22	14A
0005435765469	5496	23	14E
0005435461847	5496	24	14D
0005435725532	5496	25	14G
0005435735077	5496	26	14H
0005435461829	5496	27	15D
0005435765458	5496	28	15F
0005435765462	5496	29	15G
0005435765427	5496	30	16D
0005432140348	5496	31	16B
0005435765434	5496	32	16E
0005435765440	5496	33	16F
0005435765454	5496	34	16H
0005435725536	5496	35	17B
0005435765466	5496	36	17D
0005435765471	5496	37	17F
0005435765460	5496	38	17E
0005435765465	5496	39	17G
0005433529230	5496	40	18B
0005435765431	5496	41	18A
0005435765413	5496	42	18F
0005432140343	5496	43	18E
0005434264725	5496	44	18G
0005435765475	5496	45	19A
0005435765472	5496	46	19B
0005435765430	5496	47	19G
0005435735080	5496	48	20E
0005435765423	5496	49	20D
0005435765444	5496	50	20H
0005435765410	5496	51	20G
0005435765414	5496	52	21A
0005435765461	5496	53	21E
0005435765421	5496	54	21G
0005435765435	5496	55	21F
0005435461830	5496	56	22D
0005435765474	5496	57	22H
0005435765406	5496	58	23B
0005435765447	5496	59	23E
0005435765457	5496	60	24A
0005435765442	5496	61	24E
0005435765416	5496	62	24F
0005435765439	5496	63	24G
0005435722025	5496	64	27A
0005435725533	5496	65	25F
0005435735076	5496	66	27B
0005435765476	5496	67	27G
0005432140346	5496	68	28A
0005435765443	5496	69	27H
0005435735078	5496	70	28B
0005435725534	5496	71	28H
0005435765432	5496	72	28G
0005435765436	5496	73	29B
0005435461845	5496	74	29D
0005435765415	5496	75	29G
0005435765441	5496	76	30E
0005435765473	5496	77	30H
0005435765453	5496	78	31B
0005435765438	5496	79	31D
0005435765417	5496	80	31F
0005435765449	5496	81	31G
0005435765467	5496	82	31H
0005432140345	5496	83	32B
0005435765424	5496	84	32E
0005432140344	5496	85	32D
0005435765418	5496	86	32G
0005435765470	5496	87	32H
0005435765411	5496	88	33A
0005433529231	5496	89	33D
0005435722024	5496	90	33B
0005435765451	5496	91	34B
0005433529233	5496	92	34H
0005435765464	5496	93	35D
0005435735075	5496	94	35E
0005435765409	5496	95	35G
0005435765468	5496	96	36A
0005433529234	5496	97	36B
0005432140347	5496	98	36E
0005435765429	5496	99	37A
0005435461780	5496	100	37F
0005435765425	5496	101	37G
0005435765407	5496	102	38D
0005435765419	5496	103	38E
0005435765433	5496	104	38F
0005435765437	5496	105	39F
0005435765147	13463	1	1A
0005435765259	13463	2	1C
0005434264809	13463	3	1B
0005432535774	13463	4	1F
0005434264813	13463	5	1H
0005432194458	13463	6	2F
0005434264833	13463	7	2H
0005435461964	13463	8	3F
0005435461952	13463	9	3C
0005435461958	13463	10	3G
0005435461971	13463	11	3H
0005432535773	13463	12	4F
0005434264812	13463	13	5A
0005434264829	13463	14	5C
0005435461965	13463	15	5H
0005434264828	13463	16	9G
0005435461978	13463	17	11E
0005435461968	13463	18	11F
0005435461976	13463	19	11H
0005432535771	13463	20	12B
0005434264810	13463	21	13F
0005434264831	13463	22	13G
0005432535770	13463	23	13H
0005434831094	13463	24	14F
0005434264819	13463	25	15A
0005434831093	13463	26	14H
0005435461973	13463	27	15B
0005432194460	13463	28	15D
0005435461966	13463	29	15G
0005434264827	13463	30	15H
0005434264830	13463	31	16E
0005432194459	13463	32	16D
0005435461986	13463	33	16H
0005434264814	13463	34	17B
0005435461977	13463	35	18D
0005435461975	13463	36	19E
0005435765144	13463	37	19D
0005434264815	13463	38	19F
0005434264808	13463	39	19H
0005434264824	13463	40	20B
0005435765169	13463	41	20D
0005435461950	13463	42	20G
0005434264823	13463	43	21A
0005435461951	13463	44	21E
0005434264834	13463	45	21H
0005435461983	13463	46	22A
0005435765239	13463	47	22D
0005435461985	13463	48	22F
0005435461960	13463	49	23B
0005435461967	13463	50	23E
0005435461969	13463	51	23F
0005435461970	13463	52	23H
0005435461953	13463	53	24E
0005435461987	13463	54	24D
0005434264825	13463	55	24F
0005434264817	13463	56	24H
0005435765238	13463	57	27A
0005435461959	13463	58	27B
0005434831091	13463	59	28D
0005435461961	13463	60	28B
0005434264820	13463	61	28F
0005434831092	13463	62	29A
0005435461979	13463	63	29D
0005435765274	13463	64	30E
0005435461963	13463	65	30G
0005435461949	13463	66	30F
0005434831090	13463	67	31A
0005435461954	13463	68	31D
0005435461957	13463	69	31G
0005435461980	13463	70	33A
0005432535772	13463	71	32H
0005435461981	13463	72	33F
0005432194457	13463	73	34B
0005435461984	13463	74	34F
0005435765132	13463	75	35D
0005434264811	13463	76	35B
0005435461962	13463	77	35F
0005435461956	13463	78	35E
0005434264816	13463	79	35H
0005434264822	13463	80	36F
0005434264826	13463	81	36G
0005434264832	13463	82	37E
0005435461972	13463	83	37D
0005435461974	13463	84	37F
0005434264818	13463	85	38D
0005435461982	13463	86	38F
0005435461955	13463	87	38H
0005434264821	13463	88	39F
0005434514932	18739	1	1A
0005434514933	18739	2	1B
0005434513546	18739	3	5B
0005434513543	18739	4	5A
0005434513545	18739	5	6A
0005434513544	18739	6	6B
0005434602874	19225	1	1A
0005434602871	19225	2	2A
0005434602872	19225	3	3A
0005434602869	19225	4	4A
0005434602868	19225	5	4B
0005434602870	19225	6	5B
0005434602873	19225	7	6A
0005435844267	25083	1	1C
0005435844263	25083	2	1F
0005435844268	25083	3	3C
0005435844261	25083	4	4E
0005435846206	25083	5	6D
0005435844265	25083	6	10C
0005435846208	25083	7	10F
0005435846204	25083	8	11E
0005435844266	25083	9	11F
0005435844260	25083	10	12F
0005435844264	25083	11	13A
0005435846209	25083	12	13C
0005435846207	25083	13	13D
0005435846200	25083	14	14E
0005435844270	25083	15	15A
0005435846201	25083	16	15E
0005435846203	25083	17	16D
0005435844269	25083	18	17A
0005435846202	25083	19	17C
0005435844262	25083	20	18D
0005435846205	25083	21	20E
0005433007840	1855	1	1C
0005432295847	1855	2	1F
0005433007842	1855	3	3C
0005433007909	1855	4	11A
0005433007851	1855	5	11E
0005433007885	1855	6	19C
0005433810506	1855	7	19E
0005433007857	1855	8	19F
0005432295846	1855	9	20D
0005433810507	1855	10	20F
0005433008016	22625	1	1A
0005433284902	22625	2	1C
0005433008030	22625	3	1D
0005433008021	22625	4	1F
0005433284886	22625	5	2D
0005433284905	22625	6	3A
0005433284906	22625	7	3D
0005433284883	22625	8	3F
0005433284896	22625	9	4A
0005433008029	22625	10	4C
0005433008010	22625	11	4D
0005433008014	22625	12	4E
0005433008009	22625	13	5C
0005433008026	22625	14	5D
0005433008051	22625	15	5E
0005433284893	22625	16	5F
0005433008035	22625	17	6A
0005433284888	22625	18	6C
0005433284898	22625	19	6E
0005433008049	22625	20	6F
0005433008045	22625	21	7A
0005433008032	22625	22	7C
0005433008036	22625	23	7D
0005433008054	22625	24	7E
0005433284890	22625	25	7F
0005433284897	22625	26	8A
0005433284907	22625	27	8C
0005433284880	22625	28	8D
0005433284909	22625	29	8E
0005433008020	22625	30	9A
0005433008023	22625	31	9C
0005433008031	22625	32	9E
0005433284885	22625	33	9F
0005433008025	22625	34	10A
0005433008037	22625	35	10D
0005433284884	22625	36	10E
0005433008041	22625	37	10F
0005433008011	22625	38	11A
0005433284887	22625	39	11D
0005433284881	22625	40	11F
0005433284882	22625	41	12A
0005433008033	22625	42	12C
0005433008038	22625	43	12D
0005433284903	22625	44	12E
0005433008022	22625	45	13C
0005433284879	22625	46	13E
0005433008008	22625	47	13F
0005433008013	22625	48	14A
0005433008046	22625	49	14C
0005433008019	22625	50	14D
0005433008034	22625	51	14E
0005433284908	22625	52	14F
0005433284894	22625	53	15A
0005433284891	22625	54	15C
0005433008044	22625	55	15D
0005433008012	22625	56	15E
0005433008040	22625	57	15F
0005433008042	22625	58	16A
0005433008015	22625	59	16D
0005433008053	22625	60	16E
0005433008050	22625	61	16F
0005433008028	22625	62	17A
0005433008047	22625	63	17C
0005433284910	22625	64	17E
0005433008018	22625	65	17F
0005433008017	22625	66	18A
0005433008024	22625	67	18C
0005433008039	22625	68	18D
0005433008052	22625	69	18E
0005433284889	22625	70	18F
0005433284900	22625	71	19A
0005433284899	22625	72	19C
0005433284901	22625	73	19D
0005433008048	22625	74	19E
0005433284892	22625	75	20A
0005433008027	22625	76	20C
0005433008043	22625	77	20D
0005433284904	22625	78	20E
0005433284895	22625	79	20F
0005433845983	5583	1	1C
0005433845974	5583	2	1D
0005433845971	5583	3	1F
0005433846011	5583	4	2C
0005435282121	5583	5	3A
0005432081426	5583	6	2F
0005433846005	5583	7	3D
0005433815324	5583	8	3F
0005433845987	5583	9	5A
0005433846015	5583	10	4F
0005433845965	5583	11	4D
0005433845975	5583	12	5D
0005433846016	5583	13	6A
0005433845964	5583	14	6D
0005433845992	5583	15	6C
0005433845962	5583	16	6F
0005432081427	5583	17	6E
0005433845994	5583	18	7B
0005433845977	5583	19	7E
0005433845973	5583	20	7D
0005433846017	5583	21	7F
0005433846014	5583	22	8C
0005433845998	5583	23	8B
0005433815322	5583	24	8A
0005433845986	5583	25	8D
0005433845997	5583	26	8E
0005432081430	5583	27	9A
0005433846002	5583	28	9C
0005433846010	5583	29	9B
0005433845979	5583	30	9E
0005433815320	5583	31	10A
0005433815323	5583	32	10D
0005433845976	5583	33	10E
0005433846006	5583	34	11A
0005433846018	5583	35	11D
0005433845999	5583	36	11C
0005433845996	5583	37	11F
0005433845963	5583	38	11E
0005433845982	5583	39	12B
0005433845970	5583	40	12D
0005433845980	5583	41	12C
0005433846000	5583	42	12F
0005433845985	5583	43	13B
0005433845990	5583	44	13E
0005433845972	5583	45	13D
0005433845991	5583	46	14A
0005433846008	5583	47	13F
0005433845981	5583	48	14B
0005432081429	5583	49	14E
0005433846004	5583	50	15A
0005433845989	5583	51	15C
0005433846003	5583	52	16B
0005432081432	5583	53	16E
0005433815321	5583	54	16D
0005433846009	5583	55	17A
0005433846001	5583	56	17D
0005433845966	5583	57	17C
0005432081431	5583	58	17E
0005433845993	5583	59	18A
0005433846020	5583	60	17F
0005433846021	5583	61	18C
0005433845967	5583	62	18E
0005433845969	5583	63	18F
0005433845995	5583	64	19C
0005433845968	5583	65	19D
0005433845988	5583	66	19F
0005432081428	5583	67	20B
0005433846012	5583	68	20A
0005433845984	5583	69	20E
0005433846013	5583	70	21A
0005433845978	5583	71	21D
0005433846019	5583	72	21C
0005433846007	5583	73	21F
0005435282192	13851	1	2A
0005435282196	13851	2	2D
0005435282185	13851	3	2F
0005435282195	13851	4	3D
0005435282181	13851	5	5A
0005435282202	13851	6	4F
0005435282187	13851	7	5C
0005434173469	13851	8	5F
0005432003662	13851	9	5D
0005433845754	13851	10	6E
0005435282182	13851	11	8F
0005432003663	13851	12	9A
0005435282190	13851	13	9B
0005435282205	13851	14	10E
0005432003661	13851	15	11B
0005434173471	13851	16	11C
0005435282189	13851	17	11E
0005433845667	13851	18	12F
0005434173472	13851	19	12E
0005435282186	13851	20	13E
0005435282200	13851	21	14A
0005435282194	13851	22	13F
0005435282199	13851	23	14C
0005435282184	13851	24	14F
0005435282193	13851	25	15B
0005434173468	13851	26	15D
0005435282201	13851	27	15C
0005435282197	13851	28	16A
0005433845704	13851	29	15F
0005435282191	13851	30	16B
0005435282198	13851	31	16D
0005433845718	13851	32	17D
0005435282206	13851	33	18A
0005434173470	13851	34	19B
0005435282188	13851	35	19E
0005435282204	13851	36	19D
0005435282207	13851	37	21B
0005435282203	13851	38	21E
0005435282183	13851	39	21F
0005434620328	7825	1	1A
0005432112487	7825	2	1D
0005434620343	7825	3	2B
0005434620342	7825	4	2C
0005434620332	7825	5	2D
0005434620334	7825	6	3A
0005434620338	7825	7	3B
0005435332160	7825	8	4A
0005434620329	7825	9	4B
0005434620333	7825	10	5D
0005434620339	7825	11	6B
0005434620327	7825	12	6C
0005434620344	7825	13	7A
0005434620335	7825	14	7B
0005434620346	7825	15	7D
0005434620340	7825	16	18B
0005432112488	7825	17	18D
0005434620345	7825	18	19A
0005434620341	7825	19	19B
0005434620337	7825	20	19C
0005434620347	7825	21	20A
0005434620330	7825	22	20C
0005432112486	7825	23	21B
0005434620331	7825	24	21D
0005434620336	7825	25	23A
0005435332201	32962	1	2C
0005435332208	32962	2	2D
0005435332209	32962	3	4C
0005435332200	32962	4	6A
0005435332206	32962	5	6B
0005435332205	32962	6	7A
0005435332207	32962	7	7B
0005435332199	32962	8	21B
0005435332203	32962	9	21D
0005435332202	32962	10	22A
0005435332204	32962	11	22D
0005434620284	32962	12	23A
0005435784917	4303	1	1D
0005435784937	4303	2	1F
0005435784908	4303	3	2A
0005435784916	4303	4	2C
0005435784921	4303	5	3D
0005435784910	4303	6	4C
0005435784912	4303	7	4D
0005435784928	4303	8	4F
0005435784922	4303	9	5A
0005434993899	4303	10	5C
0005435784915	4303	11	5D
0005435918573	4303	12	6A
0005434993901	4303	13	6D
0005435784913	4303	14	6E
0005435784933	4303	15	6F
0005435784924	4303	16	7A
0005435784919	4303	17	7C
0005435784906	4303	18	7E
0005435784920	4303	19	7F
0005435784911	4303	20	8D
0005435784932	4303	21	8E
0005434993898	4303	22	8F
0005434993902	4303	23	9C
0005435784938	4303	24	9E
0005432190582	4303	25	10D
0005435784914	4303	26	10E
0005435784929	4303	27	10F
0005434993897	4303	28	11A
0005435784926	4303	29	11E
0005434993896	4303	30	11F
0005435784905	4303	31	12C
0005435784934	4303	32	12D
0005435784918	4303	33	12F
0005435784927	4303	34	13C
0005434993900	4303	35	13E
0005435784923	4303	36	14A
0005435787326	4303	37	14D
0005434993903	4303	38	14F
0005435784907	4303	39	15E
0005435784936	4303	40	16C
0005432190579	4303	41	16F
0005435787327	4303	42	17A
0005435784935	4303	43	17D
0005435784930	4303	44	17F
0005432190581	4303	45	18A
0005434993905	4303	46	18D
0005432190580	4303	47	19A
0005434993895	4303	48	19D
0005435784931	4303	49	19E
0005435784925	4303	50	20C
0005435784909	4303	51	20D
0005434993904	4303	52	20F
0005435918596	27281	1	6D
0005432195666	27281	2	6F
0005432195664	27281	3	7E
0005434993864	27281	4	8D
0005435918594	27281	5	14A
0005432195665	27281	6	14F
0005435918595	27281	7	15E
0005435918597	27281	8	16C
0005435918593	27281	9	17C
0005432146173	19882	1	1D
0005432146171	19882	2	2C
0005432146172	19882	3	7C
0005432146174	19882	4	19A
0005432566877	4737	1	1A
0005432566839	4737	2	1B
0005432459173	4737	3	1F
0005432566848	4737	4	1G
0005432170300	4737	5	2A
0005434081611	4737	6	1H
0005434081621	4737	7	2C
0005432566884	4737	8	2H
0005432571275	4737	9	2G
0005432566899	4737	10	2F
0005432459190	4737	11	3C
0005432566879	4737	12	3B
0005432170304	4737	13	3A
0005432459200	4737	14	4A
0005432566838	4737	15	3H
0005432566856	4737	16	4B
0005432566880	4737	17	4C
0005432459183	4737	18	4H
0005434081615	4737	19	4F
0005432459194	4737	20	5B
0005432459222	4737	21	5A
0005432459204	4737	22	5F
0005432566858	4737	23	9A
0005432571274	4737	24	9H
0005434081616	4737	25	11A
0005434081602	4737	26	11B
0005432459186	4737	27	11E
0005432459195	4737	28	11F
0005432566850	4737	29	11G
0005433451593	4737	30	12A
0005432566892	4737	31	12E
0005432459185	4737	32	12D
0005432459191	4737	33	12F
0005432459213	4737	34	12G
0005432566855	4737	35	13A
0005432459184	4737	36	13D
0005432459176	4737	37	13E
0005432459198	4737	38	13G
0005432566898	4737	39	14B
0005434081607	4737	40	14A
0005432566896	4737	41	14D
0005432459209	4737	42	14E
0005433452713	4737	43	14G
0005434081608	4737	44	15A
0005432170301	4737	45	14H
0005434081601	4737	46	15E
0005432459215	4737	47	15D
0005432459179	4737	48	15F
0005432566883	4737	49	15G
0005432566857	4737	50	16B
0005434081625	4737	51	16A
0005432566859	4737	52	15H
0005432566852	4737	53	16D
0005432459187	4737	54	16E
0005434081617	4737	55	16F
0005432459219	4737	56	16H
0005432566845	4737	57	16G
0005434081606	4737	58	17B
0005432459192	4737	59	17D
0005432459174	4737	60	17E
0005432459188	4737	61	17G
0005434081618	4737	62	17F
0005434081604	4737	63	18D
0005432566870	4737	64	18F
0005432459172	4737	65	18E
0005432566885	4737	66	18G
0005432566851	4737	67	19A
0005434081623	4737	68	18H
0005434081612	4737	69	19D
0005434559087	4737	70	19G
0005433451595	4737	71	19F
0005432566864	4737	72	19H
0005432459218	4737	73	20B
0005432566897	4737	74	20E
0005432459203	4737	75	20D
0005432566874	4737	76	20F
0005432566894	4737	77	20G
0005432566889	4737	78	21A
0005432566887	4737	79	21E
0005432170305	4737	80	21D
0005432459206	4737	81	21G
0005432566846	4737	82	21H
0005432459189	4737	83	22B
0005434081620	4737	84	22A
0005432566891	4737	85	22D
0005432170299	4737	86	22F
0005434081613	4737	87	22G
0005434081614	4737	88	23A
0005434081605	4737	89	22H
0005432186826	4737	90	23B
0005432170302	4737	91	23D
0005432566863	4737	92	23F
0005432459205	4737	93	23E
0005432459208	4737	94	23G
0005432459197	4737	95	23H
0005432566866	4737	96	24B
0005432459175	4737	97	24A
0005434081598	4737	98	24D
0005432459212	4737	99	24F
0005432566860	4737	100	24E
0005432566843	4737	101	24H
0005432459221	4737	102	24G
0005434081609	4737	103	25D
0005432566842	4737	104	25F
0005432459216	4737	105	25E
0005432566895	4737	106	27B
0005432459207	4737	107	27F
0005432459211	4737	108	27H
0005434081599	4737	109	27G
0005432566840	4737	110	28A
0005432459196	4737	111	28B
0005432186825	4737	112	28D
0005432459199	4737	113	28E
0005432459193	4737	114	28H
0005432459201	4737	115	29A
0005434559086	4737	116	29B
0005432566875	4737	117	29E
0005432459180	4737	118	29D
0005432459220	4737	119	29F
0005432566886	4737	120	29H
0005432459171	4737	121	29G
0005432459217	4737	122	30A
0005433451594	4737	123	30D
0005432566893	4737	124	30B
0005432566878	4737	125	30F
0005432566869	4737	126	30E
0005432566881	4737	127	30H
0005432571273	4737	128	30G
0005432566890	4737	129	31A
0005434081622	4737	130	31D
0005432566867	4737	131	31F
0005432566871	4737	132	31H
0005432566882	4737	133	31G
0005433451596	4737	134	32B
0005434081603	4737	135	32A
0005432459202	4737	136	32E
0005432571272	4737	137	32D
0005432566888	4737	138	32G
0005432566862	4737	139	33A
0005432566853	4737	140	33B
0005432459178	4737	141	33E
0005432566872	4737	142	33G
0005432566849	4737	143	33H
0005432566847	4737	144	34B
0005432566841	4737	145	34A
0005432566900	4737	146	34D
0005432566873	4737	147	34G
0005432566876	4737	148	34F
0005434559083	4737	149	34H
0005432566861	4737	150	35B
0005434081619	4737	151	35E
0005432459177	4737	152	35D
0005432566854	4737	153	35F
0005433452712	4737	154	35G
0005432459210	4737	155	36E
0005432566865	4737	156	36H
0005432170303	4737	157	37A
0005432566844	4737	158	37B
0005432459181	4737	159	37D
0005434559085	4737	160	37E
0005434081610	4737	161	37H
0005434081624	4737	162	37G
0005432186823	4737	163	38B
0005432186824	4737	164	38D
0005434081600	4737	165	38E
0005432459214	4737	166	38G
0005432459182	4737	167	38F
0005434559084	4737	168	38H
0005432566868	4737	169	39D
0005432566530	30551	1	1F
0005432566616	30551	2	3A
0005432213557	30551	3	2H
0005432566586	30551	4	4C
0005432566615	30551	5	5G
0005432213558	30551	6	11A
0005432459031	30551	7	11F
0005432566548	30551	8	14A
0005432566588	30551	9	16H
0005432566614	30551	10	22D
0005432566557	30551	11	23F
0005432566560	30551	12	24A
0005434081516	30551	13	24E
0005432566567	30551	14	24F
0005432213560	30551	15	24H
0005432566617	30551	16	27G
0005432566618	30551	17	28D
0005432213559	30551	18	28H
0005432566559	30551	19	30G
0005432566553	30551	20	31D
0005432566587	30551	21	35F
0005432458956	30551	22	35H
0005432458980	30551	23	37F
0005432459008	30551	24	38D
0005432459007	30551	25	38B
0005435722024	13614	1	3B
0005435722025	13614	2	6A
0005432295846	22815	1	1C
0005432295847	22815	2	7A
0005435097086	11083	1	1C
0005433341987	11083	2	1D
0005433341905	11083	3	2A
0005433341899	11083	4	1F
0005433341967	11083	5	2F
0005433341934	11083	6	2D
0005433341893	11083	7	2C
0005435097083	11083	8	3A
0005433341918	11083	9	3C
0005433341958	11083	10	3D
0005433341945	11083	11	4A
0005435097087	11083	12	3F
0005433341915	11083	13	4C
0005433341916	11083	14	4B
0005433341975	11083	15	4D
0005433341946	11083	16	4F
0005433341911	11083	17	5C
0005433341978	11083	18	5B
0005433341964	11083	19	5D
0005433341900	11083	20	5F
0005433341888	11083	21	5E
0005433341917	11083	22	6B
0005433341942	11083	23	6A
0005435097081	11083	24	6C
0005433341980	11083	25	6D
0005433341935	11083	26	6E
0005433341938	11083	27	7A
0005433341970	11083	28	7B
0005433341972	11083	29	7C
0005433341923	11083	30	7E
0005433341986	11083	31	7F
0005433341952	11083	32	8B
0005433341933	11083	33	8A
0005433341947	11083	34	8D
0005433341949	11083	35	8E
0005433341896	11083	36	8F
0005433341895	11083	37	9A
0005433341944	11083	38	9B
0005433341983	11083	39	9C
0005433341950	11083	40	9E
0005433341953	11083	41	9F
0005433341955	11083	42	10B
0005433341943	11083	43	10E
0005433341913	11083	44	10D
0005433341904	11083	45	11A
0005433341981	11083	46	11C
0005433341903	11083	47	11B
0005435097079	11083	48	11E
0005433341920	11083	49	12A
0005433341931	11083	50	12B
0005433341906	11083	51	12D
0005433341977	11083	52	12C
0005433341979	11083	53	12F
0005433341937	11083	54	13A
0005433341924	11083	55	13C
0005433341936	11083	56	13E
0005433341930	11083	57	13D
0005433341897	11083	58	14A
0005433341894	11083	59	13F
0005433341941	11083	60	14C
0005433341982	11083	61	14E
0005433341907	11083	62	14F
0005433341976	11083	63	15C
0005433341971	11083	64	15B
0005433341956	11083	65	15D
0005433341951	11083	66	15E
0005433341901	11083	67	16A
0005435097084	11083	68	15F
0005433341939	11083	69	16B
0005433341984	11083	70	16C
0005433341914	11083	71	16E
0005433341959	11083	72	16F
0005433341968	11083	73	17C
0005433341908	11083	74	17B
0005433341891	11083	75	17A
0005433341927	11083	76	17E
0005435097082	11083	77	17D
0005433341889	11083	78	17F
0005433341925	11083	79	18A
0005433341922	11083	80	18B
0005433341966	11083	81	18C
0005433341909	11083	82	18E
0005433341910	11083	83	18F
0005433341919	11083	84	19B
0005435097085	11083	85	19A
0005433341974	11083	86	19C
0005433341929	11083	87	19E
0005433341965	11083	88	20A
0005433341921	11083	89	19F
0005435097080	11083	90	20B
0005433341940	11083	91	20C
0005433341962	11083	92	20E
0005433341985	11083	93	20D
0005433341954	11083	94	20F
0005433341928	11083	95	21B
0005433341912	11083	96	21A
0005433341948	11083	97	21C
0005433341969	11083	98	21D
0005433341957	11083	99	21E
0005433341892	11083	100	22C
0005433341973	11083	101	22B
0005433341960	11083	102	22D
0005433341890	11083	103	22F
0005433341963	11083	104	22E
0005433341961	11083	105	23B
0005433341898	11083	106	23A
0005433341902	11083	107	23C
0005433341926	11083	108	23D
0005433341932	11083	109	23F
0005435380245	17089	1	2A
0005432293178	17089	2	4B
0005432293177	17089	3	8D
0005435545641	17089	4	10D
0005435380246	17089	5	13E
0005435380240	17089	6	14B
0005435380242	17089	7	14C
0005432293176	17089	8	17A
0005435380241	17089	9	19D
0005433341432	17089	10	20A
0005435380243	17089	11	20E
0005435545642	17089	12	21D
0005435380244	17089	13	22F
0005433481071	9103	1	1C
0005433506949	9103	2	1F
0005433506954	9103	3	3F
0005433481067	9103	4	4D
0005433481069	9103	5	5A
0005433506953	9103	6	6D
0005433506944	9103	7	7E
0005433481075	9103	8	7F
0005433506957	9103	9	8D
0005433481074	9103	10	11E
0005433506952	9103	11	12F
0005433506956	9103	12	14A
0005433481070	9103	13	15A
0005433506955	9103	14	15D
0005433481072	9103	15	15E
0005433506945	9103	16	15F
0005433506948	9103	17	16C
0005433506951	9103	18	16D
0005433506950	9103	19	16F
0005433506947	9103	20	17A
0005433481073	9103	21	19A
0005433506946	9103	22	19E
0005433481068	9103	23	20A
0005433506958	9103	24	20F
0005433506886	20453	1	1A
0005433481030	20453	2	1F
0005432919619	20453	3	2C
0005432919610	20453	4	2D
0005433506869	20453	5	3C
0005432919618	20453	6	4A
0005432919612	20453	7	4F
0005432919630	20453	8	6C
0005432919624	20453	9	6E
0005432919614	20453	10	6F
0005432919628	20453	11	7A
0005434158952	20453	12	7C
0005432919611	20453	13	8A
0005432919620	20453	14	8E
0005432919616	20453	15	8F
0005432919622	20453	16	9A
0005432919621	20453	17	9D
0005432919617	20453	18	11E
0005432919615	20453	19	12E
0005433481029	20453	20	13E
0005434158951	20453	21	14C
0005432919623	20453	22	15C
0005432919613	20453	23	15E
0005433506863	20453	24	16C
0005432919626	20453	25	16E
0005432919629	20453	26	17D
0005432919625	20453	27	17E
0005434158953	20453	28	18D
0005432919627	20453	29	20A
0005432394051	10143	1	1A
0005432396190	10143	2	1B
0005432394049	10143	3	2A
0005432396188	10143	4	2B
0005432394050	10143	5	3A
0005432396191	10143	6	3B
0005432396187	10143	7	4A
0005432394048	10143	8	4B
0005432396189	10143	9	5A
0005432396170	18292	1	2A
0005432396171	18292	2	2B
0005432396172	18292	3	5B
0005434928265	10967	1	1D
0005434411724	10967	2	2F
0005434411726	10967	3	7D
0005434928263	10967	4	7F
0005434411725	10967	5	12D
0005434411727	10967	6	14E
0005434928264	10967	7	16D
0005435125878	14711	1	1A
0005435125863	14711	2	1C
0005435625965	14711	3	1D
0005435125873	14711	4	1F
0005435125880	14711	5	2A
0005435125868	14711	6	2C
0005435125882	14711	7	2F
0005435625967	14711	8	3A
0005435625957	14711	9	3C
0005435625954	14711	10	3D
0005435625959	14711	11	3F
0005435625953	14711	12	4C
0005435125862	14711	13	4D
0005435125883	14711	14	5C
0005435125860	14711	15	5D
0005435125871	14711	16	5E
0005435625951	14711	17	6C
0005435625962	14711	18	6D
0005435625958	14711	19	6F
0005435125866	14711	20	7C
0005435554123	14711	21	7D
0005435125884	14711	22	7E
0005435125896	14711	23	7F
0005435625961	14711	24	8A
0005435125870	14711	25	8D
0005435125857	14711	26	8F
0005435554128	14711	27	9A
0005435125881	14711	28	9C
0005435625949	14711	29	9D
0005435125858	14711	30	9E
0005435125859	14711	31	9F
0005435125864	14711	32	10A
0005435556660	14711	33	10C
0005435125861	14711	34	10D
0005434928252	14711	35	10F
0005435125891	14711	36	11A
0005435125890	14711	37	11C
0005435125877	14711	38	11E
0005435125893	14711	39	11F
0005435125869	14711	40	12A
0005435125856	14711	41	12C
0005435625955	14711	42	12E
0005435125892	14711	43	12F
0005435125872	14711	44	13A
0005435125888	14711	45	13C
0005435554127	14711	46	13E
0005435625968	14711	47	13F
0005435625950	14711	48	14A
0005435625966	14711	49	14C
0005435554125	14711	50	14D
0005435125874	14711	51	15A
0005435556659	14711	52	15C
0005435125886	14711	53	15D
0005435625960	14711	54	15E
0005435125894	14711	55	15F
0005435625964	14711	56	16A
0005435625963	14711	57	16D
0005435125879	14711	58	16E
0005435625952	14711	59	17C
0005435125889	14711	60	17E
0005435125887	14711	61	18A
0005435554124	14711	62	18C
0005435125895	14711	63	18D
0005435625956	14711	64	18E
0005435125875	14711	65	18F
0005435125885	14711	66	19A
0005435625969	14711	67	19C
0005435625970	14711	68	19D
0005435125865	14711	69	19E
0005435554126	14711	70	20C
0005435125876	14711	71	20E
0005435125867	14711	72	20F
0005435715249	7098	1	1C
0005435715263	7098	2	1D
0005432398150	7098	3	2F
0005435715252	7098	4	4D
0005432400080	7098	5	6D
0005435715258	7098	6	7A
0005435715259	7098	7	7C
0005435715261	7098	8	8A
0005432400081	7098	9	8D
0005435715262	7098	10	8F
0005435715254	7098	11	9E
0005432398149	7098	12	9F
0005432398151	7098	13	10A
0005435715250	7098	14	10E
0005432400079	7098	15	10F
0005432400077	7098	16	12F
0005435715260	7098	17	13C
0005435715253	7098	18	13F
0005432400078	7098	19	14A
0005435715251	7098	20	14E
0005435715257	7098	21	15F
0005435443156	7098	22	16D
0005435715256	7098	23	18F
0005435715255	7098	24	20C
0005435443157	7098	25	20D
0005435443195	27073	1	1C
0005435715178	27073	2	2F
0005435178980	27073	3	4D
0005435715179	27073	4	5A
0005435443197	27073	5	5C
0005435443200	27073	6	8C
0005435443193	27073	7	8D
0005435443199	27073	8	12F
0005435443201	27073	9	13D
0005435178979	27073	10	14E
0005435443198	27073	11	15F
0005435443194	27073	12	17E
0005435443196	27073	13	17F
0005435443192	27073	14	20D
0005434084874	2723	1	1B
0005433060375	2723	2	2A
0005433060376	2723	3	2B
0005434084871	2723	4	3B
0005434084872	2723	5	4A
0005433060369	2723	6	4B
0005434084870	2723	7	5B
0005434084873	2723	8	6A
0005433060380	28472	1	2B
0005435540665	11374	1	3C
0005435517606	11374	2	6D
0005435540666	11374	3	10A
0005435517605	11374	4	20D
0005435528987	22250	1	1C
0005435528969	22250	2	1D
0005435528983	22250	3	2A
0005435540727	22250	4	2C
0005435528968	22250	5	2D
0005432294455	22250	6	3A
0005435540718	22250	7	3C
0005435540711	22250	8	3F
0005435540714	22250	9	4D
0005435540725	22250	10	4F
0005432294456	22250	11	5A
0005435540724	22250	12	6A
0005435540721	22250	13	6E
0005435540732	22250	14	6F
0005435540712	22250	15	7A
0005435540729	22250	16	7F
0005435528982	22250	17	8A
0005435528976	22250	18	8C
0005435540722	22250	19	9D
0005435528979	22250	20	9F
0005435540726	22250	21	10C
0005435528988	22250	22	10D
0005435528970	22250	23	11A
0005435528971	22250	24	11C
0005435540723	22250	25	11D
0005435528975	22250	26	12E
0005435528974	22250	27	12F
0005435540731	22250	28	13D
0005435540713	22250	29	13E
0005435540719	22250	30	13F
0005435528980	22250	31	14D
0005435540716	22250	32	15C
0005435528986	22250	33	16A
0005435528972	22250	34	16C
0005435528977	22250	35	16D
0005435528981	22250	36	16E
0005435540717	22250	37	17A
0005435528967	22250	38	17C
0005435540733	22250	39	18C
0005435540715	22250	40	18D
0005435528984	22250	41	18E
0005435528978	22250	42	18F
0005435540728	22250	43	19C
0005435540730	22250	44	19D
0005435528985	22250	45	19F
0005435528973	22250	46	20E
0005435540720	22250	47	20F
0005434906660	2310	1	1A
0005433250966	2310	2	1C
0005434906638	2310	3	1D
0005433250942	2310	4	2A
0005434906679	2310	5	2D
0005434906657	2310	6	2F
0005434906667	2310	7	3A
0005434906685	2310	8	3C
0005434906656	2310	9	3D
0005434906687	2310	10	3F
0005434906645	2310	11	4A
0005434906680	2310	12	4D
0005434906644	2310	13	4F
0005434906659	2310	14	5A
0005434906684	2310	15	5D
0005434906652	2310	16	5E
0005434906634	2310	17	6A
0005434906663	2310	18	6C
0005434906661	2310	19	6E
0005434906678	2310	20	7A
0005433400934	2310	21	7C
0005434906653	2310	22	8A
0005434906639	2310	23	8C
0005434906692	2310	24	8E
0005434906651	2310	25	10A
0005434906674	2310	26	10D
0005434906646	2310	27	10F
0005434906636	2310	28	11A
0005434906640	2310	29	11C
0005434906658	2310	30	11E
0005434906635	2310	31	12A
0005434906637	2310	32	12C
0005434906689	2310	33	13A
0005434906682	2310	34	13C
0005433250951	2310	35	13D
0005433250933	2310	36	13E
0005434906686	2310	37	13F
0005434906688	2310	38	14C
0005434906690	2310	39	14D
0005434906681	2310	40	14F
0005434906673	2310	41	15A
0005434906669	2310	42	15C
0005434906665	2310	43	15D
0005434906655	2310	44	15E
0005434906672	2310	45	15F
0005434906648	2310	46	16A
0005434906650	2310	47	16D
0005434906642	2310	48	16E
0005434906666	2310	49	16F
0005434906683	2310	50	17A
0005434906641	2310	51	17C
0005434906670	2310	52	17D
0005434906691	2310	53	17E
0005434906643	2310	54	18A
0005433250937	2310	55	18D
0005434906649	2310	56	18E
0005434906677	2310	57	18F
0005434906671	2310	58	19A
0005434906647	2310	59	19C
0005434906676	2310	60	19D
0005434906675	2310	61	19F
0005434906664	2310	62	20A
0005434906668	2310	63	20C
0005433250934	2310	64	20D
0005434906662	2310	65	20E
0005434906654	2310	66	20F
0005433251098	25624	1	1D
0005433251110	25624	2	1F
0005433251106	25624	3	3F
0005433251099	25624	4	4F
0005433251107	25624	5	5D
0005433251100	25624	6	6D
0005433251102	25624	7	6E
0005433251111	25624	8	7E
0005433251108	25624	9	8D
0005433251116	25624	10	8F
0005433251115	25624	11	9C
0005433251117	25624	12	10A
0005433251109	25624	13	10D
0005433251092	25624	14	11A
0005433251104	25624	15	12E
0005433251095	25624	16	13C
0005433251085	25624	17	13D
0005433251097	25624	18	13E
0005433251088	25624	19	13F
0005433251113	25624	20	14A
0005433251090	25624	21	14C
0005433251103	25624	22	14F
0005433251093	25624	23	15A
0005433251101	25624	24	15F
0005433251114	25624	25	16C
0005433251112	25624	26	16F
0005433251094	25624	27	17D
0005433251086	25624	28	18C
0005433251087	25624	29	18F
0005433251089	25624	30	19A
0005433251096	25624	31	19C
0005433400946	25624	32	19F
0005433251105	25624	33	20A
0005433400947	25624	34	20E
0005433251091	25624	35	20F
0005432620864	2543	1	1D
0005432862176	2543	2	2A
0005432620871	2543	3	3C
0005432620859	2543	4	4C
0005432862175	2543	5	4D
0005432620868	2543	6	6A
0005432620862	2543	7	6D
0005432620866	2543	8	18D
0005432620870	2543	9	19B
0005432620861	2543	10	19C
0005432620867	2543	11	20C
0005432620865	2543	12	21A
0005432620860	2543	13	21B
0005432620872	2543	14	21C
0005432620863	2543	15	21D
0005432620858	2543	16	22A
0005432862173	2543	17	22D
0005432620869	2543	18	23B
0005432862209	28056	1	2B
0005432862204	28056	2	3A
0005432620787	28056	3	3C
0005432862208	28056	4	4A
0005432862203	28056	5	5B
0005432862206	28056	6	6B
0005432862207	28056	7	19D
0005432620789	28056	8	20A
0005432862205	28056	9	20D
0005432862202	28056	10	21A
0005432620786	28056	11	22C
0005434097456	13091	1	2B
0005434097458	13091	2	3A
0005434097457	13091	3	6A
0005433452713	30995	1	1A
0005433451593	30995	2	1B
0005433451596	30995	3	4A
0005433451594	30995	4	3B
0005433451595	30995	5	4B
0005433452712	30995	6	6A
0005434142542	11982	1	3C
0005434326084	11982	2	18A
0005434142541	11982	3	18C
0005433134079	29857	1	1A
0005434142560	29857	2	2B
0005433131652	29857	3	2D
0005433134083	29857	4	3A
0005433131650	29857	5	4A
0005433134080	29857	6	4B
0005434142559	29857	7	4D
0005434142557	29857	8	5A
0005433131651	29857	9	5D
0005433131653	29857	10	6D
0005433134082	29857	11	7D
0005434142558	29857	12	18B
0005434183555	29857	13	19D
0005434142556	29857	14	20A
0005433134081	29857	15	22A
0005434184640	29857	16	22B
0005433131649	29857	17	23A
0005435696964	16457	1	1B
0005435696976	16457	2	1C
0005435696985	16457	3	1D
0005435696975	16457	4	2A
0005435696967	16457	5	2B
0005435696972	16457	6	2C
0005435696984	16457	7	3B
0005435696962	16457	8	4B
0005435696970	16457	9	5B
0005435696958	16457	10	5D
0005435696971	16457	11	6B
0005435696974	16457	12	6C
0005435696968	16457	13	6D
0005435696981	16457	14	7A
0005435696980	16457	15	7B
0005435696982	16457	16	7C
0005435696979	16457	17	18C
0005435696963	16457	18	18D
0005435696969	16457	19	19A
0005435696977	16457	20	19D
0005435696965	16457	21	20B
0005435696966	16457	22	20D
0005435696960	16457	23	21A
0005435696983	16457	24	21B
0005435696978	16457	25	21C
0005435696961	16457	26	22B
0005435696959	16457	27	22D
0005435696973	16457	28	23A
0005435935010	24743	1	2A
0005435696847	24743	2	4A
0005435935011	24743	3	7C
0005435935009	24743	4	19B
0005435935008	24743	5	21A
0005435696866	24743	6	21B
0005433724746	18781	1	1A
0005433724743	18781	2	1B
0005433724745	18781	3	3A
0005433724747	18781	4	6A
0005433724744	18781	5	6B
0005432968813	21616	1	1B
0005432968814	21616	2	3A
0005434137136	7323	1	1A
0005434137109	7323	2	1C
0005434087453	7323	3	1D
0005434137139	7323	4	1F
0005434137148	7323	5	2A
0005434137114	7323	6	2C
0005434137152	7323	7	2D
0005434137168	7323	8	2F
0005434137161	7323	9	3A
0005434087452	7323	10	3C
0005434137150	7323	11	3D
0005434087456	7323	12	3F
0005434137106	7323	13	4A
0005434137151	7323	14	4C
0005434137115	7323	15	4D
0005434137156	7323	16	4E
0005434137144	7323	17	4F
0005434137146	7323	18	5A
0005434137125	7323	19	5C
0005434137137	7323	20	5D
0005434137103	7323	21	5E
0005434137101	7323	22	6A
0005434137116	7323	23	6D
0005434137165	7323	24	6E
0005434137120	7323	25	6F
0005434137140	7323	26	7A
0005434137105	7323	27	7C
0005434137108	7323	28	7D
0005434137117	7323	29	7E
0005434137149	7323	30	7F
0005434137154	7323	31	8A
0005434087457	7323	32	8C
0005434137126	7323	33	8E
0005434137132	7323	34	8F
0005434137160	7323	35	9A
0005434137121	7323	36	9D
0005434137119	7323	37	9E
0005434137102	7323	38	9F
0005434137118	7323	39	10A
0005434137129	7323	40	10C
0005434137164	7323	41	10F
0005434137175	7323	42	11A
0005434137143	7323	43	11C
0005434137135	7323	44	11D
0005434137104	7323	45	11F
0005434137110	7323	46	12A
0005434137169	7323	47	12C
0005434137174	7323	48	12D
0005434137157	7323	49	12E
0005434137163	7323	50	12F
0005434137159	7323	51	13C
0005434137134	7323	52	13D
0005434137130	7323	53	13F
0005434137122	7323	54	14A
0005434137133	7323	55	14C
0005434137173	7323	56	14D
0005434137112	7323	57	14E
0005434087455	7323	58	15A
0005434137123	7323	59	15C
0005434137153	7323	60	15E
0005434137147	7323	61	15F
0005434137107	7323	62	16A
0005434137141	7323	63	16D
0005434137155	7323	64	16F
0005434137172	7323	65	17C
0005434137113	7323	66	17D
0005434137138	7323	67	17E
0005434137170	7323	68	17F
0005434137124	7323	69	18A
0005434137171	7323	70	18D
0005434137158	7323	71	18E
0005434137166	7323	72	18F
0005434137111	7323	73	19A
0005434137131	7323	74	19C
0005434137128	7323	75	19D
0005434137142	7323	76	19E
0005434137127	7323	77	20A
0005434137145	7323	78	20C
0005434137167	7323	79	20D
0005434087454	7323	80	20E
0005434137162	7323	81	20F
0005434136676	28565	1	1D
0005434136822	28565	2	4E
0005434136675	28565	3	10D
0005434136821	28565	4	12C
0005434136836	28565	5	16F
0005434136723	28565	6	17E
0005435808111	1942	1	1A
0005435808103	1942	2	1B
0005434610186	1942	3	1D
0005435808108	1942	4	2B
0005434610187	1942	5	3C
0005435808105	1942	6	4B
0005435808104	1942	7	7A
0005434610184	1942	8	7B
0005435808109	1942	9	7D
0005435808112	1942	10	19D
0005435808106	1942	11	20D
0005435808107	1942	12	21B
0005434610185	1942	13	21C
0005435808110	1942	14	22C
0005433407493	23087	1	1A
0005433407500	23087	2	2B
0005433407499	23087	3	2C
0005433407496	23087	4	3D
0005433407502	23087	5	4A
0005433407498	23087	6	5A
0005433407497	23087	7	6A
0005433407492	23087	8	7C
0005433407495	23087	9	19A
0005433407501	23087	10	20B
0005433407494	23087	11	20C
0005434503623	22897	1	1A
0005434503649	22897	2	1B
0005434503651	22897	3	1C
0005434503624	22897	4	1D
0005434503621	22897	5	2A
0005434503627	22897	6	2B
0005434503629	22897	7	3B
0005434503640	22897	8	4B
0005434503656	22897	9	4A
0005434503641	22897	10	4C
0005434503620	22897	11	4D
0005434503659	22897	12	5A
0005434503637	22897	13	5C
0005434503626	22897	14	5D
0005434503647	22897	15	6A
0005434503643	22897	16	6C
0005434503642	22897	17	6D
0005434503625	22897	18	7A
0005434503636	22897	19	7B
0005434503628	22897	20	7C
0005434503630	22897	21	7D
0005434503634	22897	22	18A
0005434503648	22897	23	18B
0005434503638	22897	24	18D
0005434503653	22897	25	19A
0005434503650	22897	26	19B
0005434503654	22897	27	19C
0005434503632	22897	28	19D
0005434503622	22897	29	20A
0005434503658	22897	30	20B
0005434503619	22897	31	20C
0005434503639	22897	32	20D
0005434503652	22897	33	21B
0005434503657	22897	34	21C
0005434503635	22897	35	21D
0005434503644	22897	36	22A
0005434503633	22897	37	22B
0005434503646	22897	38	22C
0005434503631	22897	39	22D
0005434503655	22897	40	23A
0005434503645	22897	41	23B
0005435078151	2218	1	1B
0005435078147	2218	2	2A
0005435078156	2218	3	2D
0005435078155	2218	4	3B
0005435078145	2218	5	4B
0005435078152	2218	6	4D
0005435078144	2218	7	5C
0005435078146	2218	8	5D
0005435078157	2218	9	6A
0005435078148	2218	10	6C
0005435078149	2218	11	7D
0005435078154	2218	12	18C
0005435078153	2218	13	19A
0005435078143	2218	14	20B
0005435078150	2218	15	21B
0005435078158	2218	16	21D
0005433266611	24350	1	1B
0005433266612	24350	2	2B
0005433266604	24350	3	3D
0005433266607	24350	4	4A
0005433266608	24350	5	4B
0005433266609	24350	6	5B
0005433266610	24350	7	5D
0005433266606	24350	8	6C
0005433266605	24350	9	7A
0005433266613	24350	10	7B
0005434988600	6617	1	1D
0005434988602	6617	2	3C
0005435803226	6617	3	4A
0005434988606	6617	4	4B
0005434988599	6617	5	6A
0005434988601	6617	6	6B
0005434988605	6617	7	7C
0005434988603	6617	8	7D
0005434988607	6617	9	18A
0005434988604	6617	10	19A
0005435803227	6617	11	21C
0005435464482	23592	1	2B
0005435803210	23592	2	19B
0005435464483	23592	3	19C
0005435803211	23592	4	20B
0005432382694	30458	1	1A
0005432382710	30458	2	1C
0005432382724	30458	3	2A
0005432382714	30458	4	2C
0005432382700	30458	5	2D
0005433454850	30458	6	2F
0005432382697	30458	7	3A
0005433449709	30458	8	3F
0005432382703	30458	9	4A
0005433449701	30458	10	4E
0005432382713	30458	11	4F
0005433454848	30458	12	5A
0005432382720	30458	13	5C
0005432382708	30458	14	5D
0005432382707	30458	15	5E
0005433449710	30458	16	5F
0005433453738	30458	17	6C
0005432382691	30458	18	6D
0005433449711	30458	19	6E
0005433449712	30458	20	6F
0005433453739	30458	21	7A
0005433449715	30458	22	7D
0005433449700	30458	23	7E
0005433449697	30458	24	7F
0005433449704	30458	25	8F
0005432382706	30458	26	9A
0005433449699	30458	27	9C
0005433449705	30458	28	9D
0005432382696	30458	29	9E
0005433449703	30458	30	9F
0005433449714	30458	31	10A
0005432382726	30458	32	10C
0005432382698	30458	33	10D
0005432382716	30458	34	11A
0005432382725	30458	35	11D
0005432382718	30458	36	11F
0005432382722	30458	37	12C
0005433449695	30458	38	12D
0005433449707	30458	39	12E
0005432382702	30458	40	13A
0005433449702	30458	41	13D
0005433454849	30458	42	13E
0005432382723	30458	43	13F
0005432382719	30458	44	14E
0005433449716	30458	45	14F
0005432382717	30458	46	15A
0005433449698	30458	47	15D
0005432382693	30458	48	15E
0005432382695	30458	49	16E
0005433453737	30458	50	16F
0005432382711	30458	51	17A
0005433449706	30458	52	17C
0005432382721	30458	53	17D
0005432382705	30458	54	17E
0005432382699	30458	55	17F
0005433449708	30458	56	18A
0005433449696	30458	57	18C
0005432382715	30458	58	18E
0005432382712	30458	59	19A
0005432382709	30458	60	19D
0005432382701	30458	61	19F
0005433449713	30458	62	20C
0005432382704	30458	63	20D
0005432382692	30458	64	20F
0005433449604	31335	1	5E
0005433449605	31335	2	17D
0005433449588	31335	3	18F
0005435304096	10765	1	3A
0005435304095	10765	2	18D
0005435299721	29717	1	1C
0005433129222	29717	2	2A
0005435302147	29717	3	2B
0005435302146	29717	4	3D
0005435302145	29717	5	4D
0005433126793	29717	6	5A
0005433129225	29717	7	5B
0005435299720	29717	8	5D
0005433129224	29717	9	6A
0005433129223	29717	10	7C
0005433126792	29717	11	7D
0005435302144	29717	12	18A
0005433129221	29717	13	18B
0005435299722	29717	14	19B
0005435299723	29717	15	19C
0005433126794	29717	16	21A
0005435302148	29717	17	22A
0005433126791	29717	18	22D
0005435299724	29717	19	23A
0005434287022	2398	1	1A
0005434287017	2398	2	1B
0005434287009	2398	3	1C
0005434287019	2398	4	2B
0005434287026	2398	5	2C
0005434287014	2398	6	2D
0005434287010	2398	7	3B
0005434287025	2398	8	4A
0005434287011	2398	9	4B
0005434287028	2398	10	4C
0005434287016	2398	11	4D
0005432264444	2398	12	5B
0005434287015	2398	13	5D
0005434287013	2398	14	6A
0005433109844	2398	15	6D
0005434287021	2398	16	7A
0005434287024	2398	17	7B
0005434287008	2398	18	18D
0005434287006	2398	19	19B
0005434287018	2398	20	19D
0005434287007	2398	21	20B
0005432264445	2398	22	20C
0005434287020	2398	23	21B
0005434287012	2398	24	21D
0005434287023	2398	25	22A
0005434287027	2398	26	22C
0005433109906	26827	1	1A
0005433109899	26827	2	2B
0005433109900	26827	3	2C
0005434286892	26827	4	2D
0005433109903	26827	5	3B
0005433109902	26827	6	3C
0005433109904	26827	7	4A
0005433109909	26827	8	5A
0005433109907	26827	9	7B
0005433109908	26827	10	18D
0005433109911	26827	11	20A
0005433109901	26827	12	20B
0005433109910	26827	13	20C
0005433109905	26827	14	23A
0005435856152	25491	1	3A
0005435856154	25491	2	5D
0005435856153	25491	3	18C
0005435856151	25491	4	21D
0005434273057	26670	1	6A
0005434273058	26670	2	19A
0005434272172	26670	3	19C
0005434272173	26670	4	21B
0005433650442	7155	1	1A
0005433650450	7155	2	1F
0005433650457	7155	3	2A
0005433650461	7155	4	3A
0005433650449	7155	5	3C
0005433650453	7155	6	3D
0005433650441	7155	7	4A
0005433650436	7155	8	4D
0005433650420	7155	9	4E
0005433650413	7155	10	4F
0005433650448	7155	11	5C
0005433650445	7155	12	5D
0005433650418	7155	13	5E
0005433650438	7155	14	6D
0005433650456	7155	15	6E
0005433650439	7155	16	7C
0005433650423	7155	17	7E
0005433650415	7155	18	8A
0005433650422	7155	19	8C
0005433650462	7155	20	9A
0005433650429	7155	21	9D
0005433650427	7155	22	9E
0005433650444	7155	23	9F
0005433650435	7155	24	10A
0005433650440	7155	25	10C
0005433650443	7155	26	10F
0005433650414	7155	27	11C
0005433650451	7155	28	11D
0005433650452	7155	29	11E
0005433650428	7155	30	12A
0005433650426	7155	31	12D
0005433650437	7155	32	12E
0005433650458	7155	33	13A
0005433650421	7155	34	13C
0005433650433	7155	35	14E
0005433650455	7155	36	15A
0005433650432	7155	37	15D
0005433650434	7155	38	15F
0005433650447	7155	39	16C
0005433650416	7155	40	16D
0005433650431	7155	41	16F
0005433650430	7155	42	17A
0005433650419	7155	43	17C
0005433650446	7155	44	18A
0005433650454	7155	45	18E
0005433650460	7155	46	18F
0005433650425	7155	47	19D
0005433650417	7155	48	20A
0005433650424	7155	49	20C
0005433650459	7155	50	20F
0005433867967	4784	1	1A
0005433867957	4784	2	1C
0005433867955	4784	3	1D
0005433867944	4784	4	2A
0005433867950	4784	5	2B
0005433867937	4784	6	2C
0005433867931	4784	7	2D
0005433867932	4784	8	3A
0005433867963	4784	9	3C
0005433867933	4784	10	3D
0005433867945	4784	11	4A
0005433867952	4784	12	4C
0005433867951	4784	13	5A
0005433867934	4784	14	5B
0005433867969	4784	15	5C
0005433867961	4784	16	5D
0005433867941	4784	17	6B
0005433867958	4784	18	6C
0005433867935	4784	19	7A
0005433867936	4784	20	7B
0005433867962	4784	21	7C
0005433867942	4784	22	7D
0005433867943	4784	23	18A
0005433867960	4784	24	18B
0005433867964	4784	25	18C
0005433867949	4784	26	18D
0005433867954	4784	27	19C
0005433867959	4784	28	19D
0005433867953	4784	29	20A
0005433867947	4784	30	20B
0005433867940	4784	31	20D
0005433867939	4784	32	21B
0005433867938	4784	33	21C
0005433867946	4784	34	21D
0005433867948	4784	35	22A
0005433867968	4784	36	22B
0005433867965	4784	37	22C
0005433867956	4784	38	22D
0005433867966	4784	39	23A
0005433867760	32614	1	3B
0005435860445	32614	2	4A
0005433867759	32614	3	5C
0005433867758	32614	4	6B
0005435860444	32614	5	19C
0005435860443	32614	6	21C
0005435860446	32614	7	22A
0005435860447	32614	8	23A
0005434663241	3423	1	1A
0005435911323	3423	2	1D
0005434663240	3423	3	2B
0005434663239	3423	4	3A
0005434663238	3423	5	3C
0005434663236	3423	6	3D
0005434460478	3423	7	4C
0005434663237	3423	8	4D
0005434663247	3423	9	5A
0005434663244	3423	10	6A
0005434663246	3423	11	6B
0005434663248	3423	12	7A
0005434460479	3423	13	7D
0005434663235	3423	14	19B
0005434460477	3423	15	20A
0005434663242	3423	16	20C
0005434663243	3423	17	22B
0005434663245	3423	18	23A
0005435911359	12492	1	1D
0005435911354	12492	2	3A
0005435911361	12492	3	5B
0005435911358	12492	4	6C
0005435911362	12492	5	7B
0005435911357	12492	6	7D
0005435911356	12492	7	20C
0005435911355	12492	8	21C
0005435911363	12492	9	22A
0005435911360	12492	10	23A
0005435860443	14527	1	1A
0005435860445	14527	2	1B
0005435860444	14527	3	1D
0005433867759	14527	4	4D
0005435860447	14527	5	6A
0005433867758	14527	6	6D
0005433867760	14527	7	21C
0005435860446	14527	8	23B
0005433867902	32655	1	1A
0005433867920	32655	2	1B
0005433867890	32655	3	1C
0005433867927	32655	4	1D
0005433867910	32655	5	2A
0005433867918	32655	6	2B
0005433867896	32655	7	2C
0005433867891	32655	8	2D
0005433867903	32655	9	3B
0005433867892	32655	10	3C
0005433867919	32655	11	3D
0005433867923	32655	12	4A
0005433867925	32655	13	4D
0005433867916	32655	14	5A
0005433867913	32655	15	5B
0005433867905	32655	16	5C
0005433867895	32655	17	5D
0005433867904	32655	18	6A
0005433867915	32655	19	6B
0005433867894	32655	20	6C
0005433867911	32655	21	7B
0005433867921	32655	22	7C
0005433867893	32655	23	7D
0005433867907	32655	24	18A
0005433867897	32655	25	18B
0005433867914	32655	26	18C
0005433867924	32655	27	18D
0005433867900	32655	28	19A
0005433867929	32655	29	19B
0005433867930	32655	30	19D
0005433867912	32655	31	20A
0005433867909	32655	32	20B
0005433867917	32655	33	21A
0005433867898	32655	34	21B
0005433867928	32655	35	21C
0005433867926	32655	36	22A
0005433867906	32655	37	22B
0005433867922	32655	38	22C
0005433867899	32655	39	22D
0005433867901	32655	40	23A
0005433867908	32655	41	23B
0005432799094	14802	1	1A
0005432799087	14802	2	1B
0005432799090	14802	3	1C
0005432799097	14802	4	1D
0005432799089	14802	5	2A
0005432799077	14802	6	2B
0005432799079	14802	7	2C
0005432799084	14802	8	4A
0005432799070	14802	9	4B
0005432799093	14802	10	4C
0005432799080	14802	11	5A
0005432799086	14802	12	5B
0005432799075	14802	13	5C
0005432799081	14802	14	5D
0005432799071	14802	15	6A
0005432799091	14802	16	6C
0005432799074	14802	17	7C
0005432799078	14802	18	7D
0005432799092	14802	19	18B
0005432799069	14802	20	19A
0005432799076	14802	21	19D
0005432799095	14802	22	20A
0005432799072	14802	23	20D
0005432799083	14802	24	21A
0005432799096	14802	25	21B
0005432799088	14802	26	21C
0005432799082	14802	27	22A
0005432799085	14802	28	22D
0005432799073	14802	29	23A
0005434299288	7057	1	1A
0005434407000	7057	2	1C
0005434406981	7057	3	1D
0005434407022	7057	4	2C
0005434299280	7057	5	2D
0005434406999	7057	6	2F
0005434406967	7057	7	3A
0005434407006	7057	8	3C
0005434299281	7057	9	3F
0005432108219	7057	10	4A
0005434406975	7057	11	4B
0005434407020	7057	12	4D
0005434406963	7057	13	4E
0005434406984	7057	14	5B
0005434299274	7057	15	5C
0005434299278	7057	16	5D
0005434407008	7057	17	5E
0005432153854	7057	18	5F
0005434406968	7057	19	7A
0005434406992	7057	20	6F
0005434407021	7057	21	7B
0005434299284	7057	22	7D
0005434407018	7057	23	7F
0005434299276	7057	24	7E
0005434406966	7057	25	8A
0005434407004	7057	26	8C
0005434406970	7057	27	8D
0005434406982	7057	28	9C
0005434406978	7057	29	9B
0005432153853	7057	30	9D
0005434299287	7057	31	9F
0005434299286	7057	32	10B
0005434406971	7057	33	10C
0005434407012	7057	34	11A
0005434406988	7057	35	10E
0005434299279	7057	36	11B
0005434406997	7057	37	11C
0005434406974	7057	38	11D
0005434299268	7057	39	11F
0005434406961	7057	40	12A
0005434407010	7057	41	12C
0005434406977	7057	42	12B
0005434406990	7057	43	12D
0005432153851	7057	44	12E
0005434406979	7057	45	12F
0005434299267	7057	46	13B
0005434299266	7057	47	13A
0005434299272	7057	48	13C
0005434407015	7057	49	13E
0005434407007	7057	50	14A
0005434406962	7057	51	13F
0005434406995	7057	52	14B
0005434407003	7057	53	14D
0005432153855	7057	54	14E
0005434406989	7057	55	14F
0005434406969	7057	56	15C
0005434406991	7057	57	15D
0005434406959	7057	58	15E
0005434407005	7057	59	15F
0005432153852	7057	60	16B
0005434407019	7057	61	16A
0005434299273	7057	62	16D
0005434406986	7057	63	16C
0005434299270	7057	64	16F
0005434299283	7057	65	16E
0005434406998	7057	66	17A
0005434299277	7057	67	17B
0005434406993	7057	68	17C
0005434407001	7057	69	17D
0005434406976	7057	70	17F
0005434406996	7057	71	17E
0005434407013	7057	72	18A
0005434299275	7057	73	18B
0005434406972	7057	74	18C
0005434406960	7057	75	18E
0005434407023	7057	76	18F
0005434407017	7057	77	19A
0005432153850	7057	78	19C
0005434299282	7057	79	19E
0005434407002	7057	80	20B
0005434406985	7057	81	20C
0005434406987	7057	82	20E
0005432108218	7057	83	20F
0005434299265	7057	84	21A
0005434406964	7057	85	21C
0005434299285	7057	86	21B
0005434299271	7057	87	21D
0005434406994	7057	88	21E
0005434407014	7057	89	21F
0005434299269	7057	90	22C
0005434406973	7057	91	22B
0005434406965	7057	92	22D
0005434406983	7057	93	22F
0005434406980	7057	94	22E
0005434407016	7057	95	23B
0005434407011	7057	96	23C
0005434407009	7057	97	23D
0005432058329	26936	1	4A
0005435310928	26936	2	4C
0005435310908	26936	3	4D
0005434299154	26936	4	5D
0005435293113	26936	5	5E
0005434299151	26936	6	6A
0005432058331	26936	7	6C
0005435293116	26936	8	7A
0005435293112	26936	9	6F
0005435293111	26936	10	7B
0005435310922	26936	11	7C
0005435293120	26936	12	8B
0005435310907	26936	13	8F
0005435310919	26936	14	9A
0005434299175	26936	15	9C
0005435310921	26936	16	10D
0005435310918	26936	17	10C
0005435310926	26936	18	10E
0005435310927	26936	19	11B
0005435293109	26936	20	11D
0005435293115	26936	21	12E
0005435310910	26936	22	13F
0005435293117	26936	23	14A
0005435293114	26936	24	14B
0005435293118	26936	25	14D
0005435310917	26936	26	14E
0005435310911	26936	27	15A
0005435310929	26936	28	15D
0005432058328	26936	29	15E
0005435310912	26936	30	16A
0005434406691	26936	31	15F
0005434406673	26936	32	16B
0005434406690	26936	33	17A
0005435310925	26936	34	16F
0005435310906	26936	35	17B
0005435293110	26936	36	17C
0005435293119	26936	37	17E
0005435310914	26936	38	18B
0005435310913	26936	39	18F
0005432058330	26936	40	19E
0005434406799	26936	41	20A
0005435310924	26936	42	20B
0005435310915	26936	43	20E
0005435310916	26936	44	20F
0005434299186	26936	45	21D
0005435310909	26936	46	21C
0005434299169	26936	47	21F
0005434299155	26936	48	22B
0005435310920	26936	49	22A
0005434299168	26936	50	23B
0005435310923	26936	51	23F
0005434299185	26936	52	23E
0005434512044	6463	1	1A
0005434512050	6463	2	1B
0005434512048	6463	3	1C
0005432603847	6463	4	1D
0005432603867	6463	5	2A
0005432603880	6463	6	2B
0005432603862	6463	7	2C
0005432603854	6463	8	2D
0005432603865	6463	9	3A
0005434512045	6463	10	3B
0005432603848	6463	11	3C
0005432603856	6463	12	3D
0005432603860	6463	13	4A
0005432603863	6463	14	4B
0005432603846	6463	15	4D
0005432603877	6463	16	5A
0005432603881	6463	17	5B
0005432603875	6463	18	5C
0005432603844	6463	19	5D
0005434512051	6463	20	6A
0005432603858	6463	21	6B
0005432603878	6463	22	6C
0005432603845	6463	23	6D
0005432603850	6463	24	7A
0005432603853	6463	25	7B
0005432603849	6463	26	7C
0005432603876	6463	27	7D
0005432603861	6463	28	18A
0005432603882	6463	29	18B
0005432603879	6463	30	18C
0005432603884	6463	31	18D
0005432603874	6463	32	19A
0005432603852	6463	33	19B
0005434512049	6463	34	19C
0005432603872	6463	35	19D
0005432603883	6463	36	20A
0005432603870	6463	37	20B
0005434512046	6463	38	20C
0005432603869	6463	39	20D
0005432603864	6463	40	21A
0005432603851	6463	41	21B
0005432603866	6463	42	21C
0005432603873	6463	43	21D
0005432603855	6463	44	22A
0005432603859	6463	45	22B
0005432603871	6463	46	22C
0005432603868	6463	47	22D
0005432603857	6463	48	23A
0005434512047	6463	49	23B
0005435221041	21362	1	2A
0005435221043	21362	2	2D
0005432603657	21362	3	7C
0005432603676	21362	4	18D
0005435221503	21362	5	20D
0005435221042	21362	6	23A
0005432603675	21362	7	23B
0005433251108	14973	1	1A
0005433251098	14973	2	1D
0005433251095	14973	3	1F
0005433251115	14973	4	2A
0005433251109	14973	5	2D
0005433251116	14973	6	4D
0005433251099	14973	7	4E
0005433251093	14973	8	5E
0005433251111	14973	9	6D
0005433251088	14973	10	7C
0005433251090	14973	11	8C
0005433251086	14973	12	8D
0005433251091	14973	13	9C
0005433251110	14973	14	9F
0005433251106	14973	15	10C
0005433251089	14973	16	11D
0005433251087	14973	17	11E
0005433251101	14973	18	11F
0005433251112	14973	19	12D
0005433251085	14973	20	13D
0005433251103	14973	21	14D
0005433251107	14973	22	15C
0005433251104	14973	23	15D
0005433251117	14973	24	16A
0005433251097	14973	25	16C
0005433251096	14973	26	16D
0005433251105	14973	27	17C
0005433251113	14973	28	17D
0005433251102	14973	29	17E
0005433251094	14973	30	17F
0005433251092	14973	31	18C
0005433251114	14973	32	19D
0005433251100	14973	33	20E
0005434906574	25836	1	1A
0005434906596	25836	2	1D
0005434906588	25836	3	1F
0005434906579	25836	4	2A
0005434906624	25836	5	2C
0005434906595	25836	6	3A
0005434906631	25836	7	3C
0005434906615	25836	8	3D
0005434906572	25836	9	4A
0005434906616	25836	10	4C
0005434906609	25836	11	4D
0005434906590	25836	12	5F
0005434906617	25836	13	6D
0005434906580	25836	14	6F
0005434906612	25836	15	7A
0005434906600	25836	16	7D
0005434906584	25836	17	7E
0005434906608	25836	18	8C
0005434906598	25836	19	8D
0005434906605	25836	20	8E
0005434906587	25836	21	8F
0005434906628	25836	22	9A
0005433250982	25836	23	9C
0005434906592	25836	24	9D
0005434906630	25836	25	9E
0005434906575	25836	26	9F
0005434906618	25836	27	10A
0005434906576	25836	28	10C
0005434906594	25836	29	10F
0005434906627	25836	30	11A
0005434906573	25836	31	11C
0005434906581	25836	32	11D
0005434906593	25836	33	11E
0005434906614	25836	34	11F
0005434906613	25836	35	12A
0005434906632	25836	36	12F
0005434906606	25836	37	13A
0005434906607	25836	38	13C
0005434906633	25836	39	13D
0005434906629	25836	40	14D
0005434906583	25836	41	14E
0005434906601	25836	42	14F
0005434906622	25836	43	15C
0005434906599	25836	44	15E
0005434906582	25836	45	15F
0005434906585	25836	46	16A
0005434906602	25836	47	16C
0005434906578	25836	48	16D
0005434906619	25836	49	16E
0005434906610	25836	50	16F
0005434906621	25836	51	17A
0005434906604	25836	52	17C
0005434906577	25836	53	17D
0005434906586	25836	54	17E
0005434906620	25836	55	18A
0005434906589	25836	56	18E
0005434906626	25836	57	18F
0005434906597	25836	58	19C
0005434906603	25836	59	19D
0005434906591	25836	60	19E
0005434906611	25836	61	20A
0005434906625	25836	62	20D
0005434906623	25836	63	20F
0005433008060	14183	1	1A
0005433008073	14183	2	1D
0005433008067	14183	3	2A
0005433008088	14183	4	3F
0005433008092	14183	5	4F
0005433008059	14183	6	5A
0005433008065	14183	7	5D
0005433008080	14183	8	5E
0005433008086	14183	9	6A
0005433008093	14183	10	6C
0005433008089	14183	11	6D
0005433008099	14183	12	7D
0005433008085	14183	13	7F
0005433008087	14183	14	8A
0005433008084	14183	15	8C
0005433008063	14183	16	8D
0005433008095	14183	17	8F
0005433008066	14183	18	9C
0005433008069	14183	19	9D
0005433008064	14183	20	9E
0005433008090	14183	21	9F
0005433008076	14183	22	10A
0005433008097	14183	23	10C
0005433008071	14183	24	10E
0005433008075	14183	25	11C
0005433008094	14183	26	11F
0005433008078	14183	27	12C
0005433008057	14183	28	12F
0005433008083	14183	29	13A
0005433008091	14183	30	14A
0005433008096	14183	31	14C
0005433008056	14183	32	14D
0005433008072	14183	33	15D
0005433008058	14183	34	15F
0005433008098	14183	35	16A
0005433008055	14183	36	16C
0005433008079	14183	37	16D
0005433008081	14183	38	17A
0005433008070	14183	39	17E
0005433008068	14183	40	18A
0005433008082	14183	41	18D
0005433008077	14183	42	18F
0005433008062	14183	43	20C
0005433008061	14183	44	20E
0005433008074	14183	45	20F
0005433007854	22818	1	1C
0005433007852	22818	2	15D
0005434925367	20551	1	1F
0005434925368	20551	2	2D
0005434925370	20551	3	2F
0005434925396	20551	4	3A
0005434925369	20551	5	4A
0005434925385	20551	6	4C
0005434925383	20551	7	4E
0005434925391	20551	8	5E
0005434925371	20551	9	6A
0005434925376	20551	10	7A
0005434925386	20551	11	8A
0005434925375	20551	12	9C
0005434925365	20551	13	9E
0005434925387	20551	14	10D
0005434925382	20551	15	11C
0005434925389	20551	16	11E
0005434925381	20551	17	11F
0005434925378	20551	18	13E
0005434925392	20551	19	14C
0005434925380	20551	20	14E
0005434925390	20551	21	15A
0005434925379	20551	22	15D
0005434925374	20551	23	15E
0005434925388	20551	24	16A
0005434925373	20551	25	16C
0005434925377	20551	26	16D
0005434925372	20551	27	16F
0005434925395	20551	28	17C
0005434925384	20551	29	18E
0005434925366	20551	30	19C
0005434925393	20551	31	20A
0005434925394	20551	32	20D
0005435487577	15804	1	1A
0005435487576	15804	2	1D
0005435487572	15804	3	3A
0005435487584	15804	4	3C
0005435487583	15804	5	4B
0005435487565	15804	6	4C
0005435487579	15804	7	4D
0005435487566	15804	8	6A
0005435487567	15804	9	7A
0005435487573	15804	10	7B
0005435487578	15804	11	7C
0005435487582	15804	12	7D
0005435487574	15804	13	18B
0005435487568	15804	14	18C
0005435487585	15804	15	18D
0005435487569	15804	16	19C
0005435487575	15804	17	20A
0005435487581	15804	18	20B
0005435487571	15804	19	20D
0005435487570	15804	20	21C
0005435487564	15804	21	22B
0005435487580	15804	22	23B
0005435999020	19707	1	1A
0005435999024	19707	2	1D
0005435999031	19707	3	1C
0005435999032	19707	4	2A
0005435999029	19707	5	2B
0005435999016	19707	6	3B
0005435999026	19707	7	3D
0005435999033	19707	8	4A
0005435999025	19707	9	6B
0005435999028	19707	10	6C
0005435999027	19707	11	6D
0005435999019	19707	12	7A
0005435999014	19707	13	7D
0005435999017	19707	14	19A
0005435999013	19707	15	19B
0005435999034	19707	16	19D
0005435999021	19707	17	20A
0005435999015	19707	18	20B
0005435999022	19707	19	20C
0005435999030	19707	20	21B
0005435999018	19707	21	21C
0005435999023	19707	22	22C
0005435839124	6005	1	1F
0005435839105	6005	2	1D
0005432660794	6005	3	2A
0005435839111	6005	4	2D
0005435839128	6005	5	3A
0005435839118	6005	6	4F
0005435839103	6005	7	5C
0005435839129	6005	8	6D
0005432659682	6005	9	7C
0005435839116	6005	10	7B
0005435839125	6005	11	8A
0005432659683	6005	12	9B
0005435472518	6005	13	9C
0005432142215	6005	14	9F
0005435839104	6005	15	9D
0005435839107	6005	16	10B
0005432142213	6005	17	11B
0005435839119	6005	18	11E
0005435839120	6005	19	12B
0005435839130	6005	20	12A
0005432660793	6005	21	12D
0005435472517	6005	22	12F
0005435839122	6005	23	12E
0005435839106	6005	24	13E
0005432142214	6005	25	13D
0005435839123	6005	26	13F
0005435839127	6005	27	14A
0005435839109	6005	28	15A
0005435839113	6005	29	15C
0005435839110	6005	30	17B
0005435839108	6005	31	17D
0005435839112	6005	32	18E
0005435839115	6005	33	18D
0005435839102	6005	34	19A
0005432658567	6005	35	20C
0005435839114	6005	36	20E
0005435839121	6005	37	21B
0005435839126	6005	38	21D
0005435839117	6005	39	21E
0005435472609	18088	1	1A
0005432537033	18088	2	1F
0005432537034	18088	3	1C
0005432537032	18088	4	2A
0005435472603	18088	5	4F
0005435472606	18088	6	6B
0005435472604	18088	7	6E
0005435472607	18088	8	6D
0005432537035	18088	9	7D
0005435472602	18088	10	8D
0005435472611	18088	11	9D
0005435838981	18088	12	13A
0005435472598	18088	13	13D
0005435472601	18088	14	13F
0005435472605	18088	15	14B
0005435472600	18088	16	16A
0005435472610	18088	17	15F
0005435472597	18088	18	16C
0005435472612	18088	19	18A
0005435472599	18088	20	17F
0005435472596	18088	21	19A
0005435472608	18088	22	19C
0005435103830	23037	1	1D
0005435103829	23037	2	8B
0005435103834	23037	3	8C
0005435103837	23037	4	9C
0005435103831	23037	5	11D
0005435103833	23037	6	14D
0005435103828	23037	7	15E
0005435103835	23037	8	15D
0005435103836	23037	9	16D
0005435103832	23037	10	17B
0005433284921	32046	1	1D
0005433284935	32046	2	2C
0005433284939	32046	3	3F
0005433284923	32046	4	4A
0005433284930	32046	5	5A
0005433284924	32046	6	5B
0005433284934	32046	7	5D
0005433284942	32046	8	6F
0005433284936	32046	9	7F
0005433284919	32046	10	8C
0005433284933	32046	11	8D
0005433284928	32046	12	10B
0005433284931	32046	13	10C
0005433284938	32046	14	11D
0005433284932	32046	15	11F
0005433284922	32046	16	12F
0005433284918	32046	17	13C
0005433284927	32046	18	15A
0005433284940	32046	19	15F
0005433284913	32046	20	17B
0005433284929	32046	21	19D
0005433284912	32046	22	19F
0005433284937	32046	23	20A
0005433284915	32046	24	20D
0005433284916	32046	25	20F
0005433284917	32046	26	21A
0005433284925	32046	27	21B
0005433284911	32046	28	22A
0005433284941	32046	29	22D
0005433284920	32046	30	22F
0005433284926	32046	31	23D
0005433284914	32046	32	23F
0005435852542	23877	1	2D
0005435852540	23877	2	3C
0005435852541	23877	3	5A
0005433475640	23877	4	7C
0005435852543	23877	5	20D
0005432525730	30580	1	1G
0005432525767	30580	2	2A
0005435212766	30580	3	1H
0005432211413	30580	4	3C
0005435212747	30580	5	2K
0005432525865	30580	6	3G
0005435212759	30580	7	4A
0005435212788	30580	8	4H
0005432159805	30580	9	5H
0005434066305	30580	10	5K
0005432211415	30580	11	11D
0005435212793	30580	12	11C
0005432525993	30580	13	11H
0005432211418	30580	14	12F
0005432525748	30580	15	12K
0005435212776	30580	16	13C
0005432525747	30580	17	13G
0005435725542	30580	18	14C
0005432211416	30580	19	14D
0005432525795	30580	20	14F
0005435212790	30580	21	14H
0005435212801	30580	22	15H
0005435212748	30580	23	16A
0005432211417	30580	24	15K
0005435212813	30580	25	16D
0005433656634	30580	26	16F
0005435212746	30580	27	16G
0005432526270	30580	28	17E
0005435212789	30580	29	17G
0005432525678	30580	30	18A
0005434066510	30580	31	18C
0005435212782	30580	32	18G
0005435212785	30580	33	18E
0005435630933	30580	34	19C
0005432525817	30580	35	19J
0005435212770	30580	36	19H
0005432525644	30580	37	20A
0005435212750	30580	38	19K
0005435212805	30580	39	20D
0005433656633	30580	40	21B
0005435212806	30580	41	21F
0005435212799	30580	42	21E
0005434066351	30580	43	21J
0005435212795	30580	44	22B
0005435212775	30580	45	22F
0005435725545	30580	46	23A
0005435212798	30580	47	23F
0005435212768	30580	48	23E
0005435212763	30580	49	23H
0005435212808	30580	50	24F
0005432525687	30580	51	25C
0005435212794	30580	52	25B
0005435212797	30580	53	25D
0005432525732	30580	54	25H
0005435212769	30580	55	25K
0005432525723	30580	56	25J
0005435212762	30580	57	26C
0005432525893	30580	58	27E
0005432211412	30580	59	27G
0005435212786	30580	60	28C
0005432526136	30580	61	28B
0005434066350	30580	62	28A
0005434066331	30580	63	29A
0005435212783	30580	64	29D
0005435212754	30580	65	29H
0005435212753	30580	66	29G
0005435212804	30580	67	30A
0005435212796	30580	68	29K
0005435212767	30580	69	30B
0005435212779	30580	70	30D
0005435212764	30580	71	30C
0005435212760	30580	72	30G
0005435212802	30580	73	31H
0005435212780	30580	74	31J
0005435212800	30580	75	32B
0005435212784	30580	76	32E
0005432159803	30580	77	32D
0005435212771	30580	78	32G
0005432525645	30580	79	33D
0005432525939	30580	80	33E
0005435212773	30580	81	34A
0005435212777	30580	82	33K
0005435212757	30580	83	34B
0005435725544	30580	84	34D
0005432525757	30580	85	34K
0005435725546	30580	86	34J
0005435212765	30580	87	35D
0005432525724	30580	88	35F
0005435212756	30580	89	35H
0005435630934	30580	90	36B
0005434066304	30580	91	36K
0005435212749	30580	92	36J
0005432159806	30580	93	39A
0005435212745	30580	94	39C
0005435212755	30580	95	39B
0005435212807	30580	96	39E
0005432159804	30580	97	39H
0005432525634	30580	98	40A
0005435212803	30580	99	40C
0005435212791	30580	100	40B
0005435212812	30580	101	40H
0005432211414	30580	102	40F
0005435212809	30580	103	41G
0005432525679	30580	104	42C
0005435212761	30580	105	42G
0005434066384	30580	106	43A
0005435212772	30580	107	43E
0005435212774	30580	108	43G
0005435212810	30580	109	43J
0005435212758	30580	110	44G
0005435212781	30580	111	44F
0005432525649	30580	112	45H
0005435212752	30580	113	46C
0005435212778	30580	114	46K
0005435212787	30580	115	46J
0005432525894	30580	116	47K
0005432525933	30580	117	48C
0005435212811	30580	118	48F
0005435212744	30580	119	48E
0005432525759	30580	120	48H
0005432525731	30580	121	49A
0005432525766	30580	122	49F
0005435725543	30580	123	50D
0005435212751	30580	124	50K
0005435212792	30580	125	50H
0005433367463	24837	1	1F
0005433367462	24837	2	2A
0005433367465	24837	3	2C
0005433367483	24837	4	2D
0005433367470	24837	5	2F
0005433367459	24837	6	3A
0005433367474	24837	7	3D
0005433367453	24837	8	4A
0005433367469	24837	9	4C
0005433367479	24837	10	4D
0005433367481	24837	11	4E
0005433367480	24837	12	4F
0005433367486	24837	13	7C
0005433367477	24837	14	10D
0005433367461	24837	15	10E
0005433367467	24837	16	10F
0005433367455	24837	17	11A
0005433367482	24837	18	11D
0005433367478	24837	19	12C
0005433367473	24837	20	13A
0005433367460	24837	21	13D
0005433367476	24837	22	14D
0005433367485	24837	23	14F
0005433367475	24837	24	15F
0005433367471	24837	25	16A
0005433367468	24837	26	16C
0005433367484	24837	27	16E
0005433367454	24837	28	16F
0005433367456	24837	29	17C
0005433367464	24837	30	18E
0005433367472	24837	31	19A
0005433367458	24837	32	20A
0005433367466	24837	33	20C
0005433367457	24837	34	20D
0005435949748	6596	1	2A
0005435949745	6596	2	5A
0005435949749	6596	3	5C
0005435949744	6596	4	7A
0005435949750	6596	5	18C
0005435949751	6596	6	20A
0005435949747	6596	7	21A
0005435949746	6596	8	22C
0005435949743	6596	9	23B
0005434979439	2064	1	1A
0005434979443	2064	2	1B
0005434979463	2064	3	1D
0005434979446	2064	4	2D
0005434979462	2064	5	3D
0005434979466	2064	6	4A
0005434979447	2064	7	4B
0005434979445	2064	8	4D
0005434979437	2064	9	5A
0005434979452	2064	10	5B
0005435801663	2064	11	5D
0005434979457	2064	12	6A
0005434979440	2064	13	6B
0005434979451	2064	14	6C
0005435801662	2064	15	7A
0005434979464	2064	16	7C
0005434979460	2064	17	7D
0005434979459	2064	18	18B
0005434979455	2064	19	18C
0005435801661	2064	20	19A
0005434979456	2064	21	19B
0005434979449	2064	22	19C
0005434979461	2064	23	19D
0005434979442	2064	24	20A
0005434979458	2064	25	20B
0005434979453	2064	26	20D
0005434979465	2064	27	21B
0005434979438	2064	28	21C
0005434979448	2064	29	21D
0005434979454	2064	30	22A
0005434979444	2064	31	22B
0005434979450	2064	32	22C
0005434979441	2064	33	22D
0005434979259	23538	1	2A
0005434979285	23538	2	4C
0005434979273	23538	3	18B
0005434979272	23538	4	19A
0005434979258	23538	5	21B
0005434979286	23538	6	23B
0005434952487	2643	1	1A
0005434952489	2643	2	1B
0005434952488	2643	3	3B
0005434952490	2643	4	3A
0005434952491	2643	5	6A
0005434952469	28210	1	1A
0005433256398	28210	2	1B
0005433256397	28210	3	3A
0005434952468	28210	4	4A
0005433256395	28210	5	4B
0005433256396	28210	6	6B
0005433112360	19820	1	4B
0005433111482	19820	2	4A
0005433111481	19820	3	5A
0005433112361	19820	4	6B
0005434136722	11940	1	9A
0005434136738	11940	2	12F
0005434136739	11940	3	13F
0005434136680	11940	4	15D
0005434136719	11940	5	16F
0005434137108	28733	1	1D
0005434137169	28733	2	2C
0005434137126	28733	3	2D
0005434137137	28733	4	2F
0005434137148	28733	5	3C
0005434137170	28733	6	3D
0005434137171	28733	7	4D
0005434137132	28733	8	5A
0005434137158	28733	9	5D
0005434137142	28733	10	5E
0005434137127	28733	11	5F
0005434137113	28733	12	6A
0005434137164	28733	13	6C
0005434137143	28733	14	6D
0005434137149	28733	15	6E
0005434137119	28733	16	6F
0005434137163	28733	17	7A
0005434137123	28733	18	7C
0005434137141	28733	19	7D
0005434137168	28733	20	7E
0005434137146	28733	21	7F
0005434137125	28733	22	8A
0005434137122	28733	23	8C
0005434137175	28733	24	8D
0005434137130	28733	25	8E
0005434137161	28733	26	9C
0005434137138	28733	27	9D
0005434137131	28733	28	9E
0005434137155	28733	29	9F
0005434137165	28733	30	10A
0005434137139	28733	31	10C
0005434137157	28733	32	10D
0005434137128	28733	33	10E
0005434137134	28733	34	10F
0005434137172	28733	35	11A
0005434137106	28733	36	11D
0005434137116	28733	37	11F
0005434137154	28733	38	12A
0005434137152	28733	39	12D
0005434137117	28733	40	12E
0005434137136	28733	41	12F
0005434137103	28733	42	13A
0005434137133	28733	43	13C
0005434137115	28733	44	13D
0005434137109	28733	45	13E
0005434137160	28733	46	14A
0005434137120	28733	47	14C
0005434137144	28733	48	14D
0005434137162	28733	49	14E
0005434137173	28733	50	14F
0005434137112	28733	51	15A
0005434137111	28733	52	15C
0005434137102	28733	53	15D
0005434137110	28733	54	15E
0005434137105	28733	55	16A
0005434137150	28733	56	16C
0005434137151	28733	57	16D
0005434137159	28733	58	16E
0005434137156	28733	59	16F
0005434137174	28733	60	17A
0005434137153	28733	61	17D
0005434137147	28733	62	17E
0005434137118	28733	63	17F
0005434137140	28733	64	18A
0005434137121	28733	65	18C
0005434137167	28733	66	18D
0005434137145	28733	67	18E
0005434137124	28733	68	19A
0005434137114	28733	69	19D
0005434137104	28733	70	19E
0005434137107	28733	71	19F
0005434137135	28733	72	20A
0005434137129	28733	73	20C
0005434137101	28733	74	20D
0005434137166	28733	75	20E
0005434466402	6583	1	2C
0005434466398	6583	2	3B
0005434466403	6583	3	4A
0005434466408	6583	4	5A
0005434466407	6583	5	5B
0005434466401	6583	6	5C
0005434466404	6583	7	6B
0005434466400	6583	8	19B
0005434466399	6583	9	21C
0005434466406	6583	10	22C
0005434466405	6583	11	23B
0005433538770	6770	1	1B
0005433534473	6770	2	3A
0005433538772	6770	3	3D
0005433538774	6770	4	5B
0005433538776	6770	5	6A
0005433538769	6770	6	7D
0005433538777	6770	7	18A
0005433538773	6770	8	18B
0005433534474	6770	9	18D
0005433538775	6770	10	21C
0005433538771	6770	11	22D
0005435259708	25046	1	2C
0005435259707	25046	2	6A
0005435259706	25046	3	20C
0005433511857	798	1	3A
0005433511852	798	2	3D
0005433511858	798	3	4D
0005433511854	798	4	6A
0005433511853	798	5	6C
0005433511856	798	6	6D
0005433511855	798	7	7C
0005433511859	798	8	7D
0005433511860	798	9	21B
0005432922480	16145	1	2B
0005432922479	16145	2	2C
0005433511821	16145	3	3B
0005433511801	16145	4	6D
0005433511822	16145	5	7C
0005433511820	16145	6	18A
0005432922477	16145	7	19B
0005432922478	16145	8	20A
0005435916118	3673	1	1A
0005435697022	3673	2	1B
0005435697036	3673	3	1D
0005435697025	3673	4	2A
0005435697016	3673	5	2B
0005435697026	3673	6	2C
0005435697041	3673	7	2D
0005435697020	3673	8	3A
0005435697034	3673	9	3B
0005435697043	3673	10	3C
0005435697023	3673	11	3D
0005435697032	3673	12	4A
0005435697029	3673	13	4D
0005435916119	3673	14	5A
0005435697017	3673	15	5B
0005435697033	3673	16	5C
0005435697015	3673	17	5D
0005434950480	3673	18	6B
0005435697027	3673	19	7A
0005435697024	3673	20	7B
0005435697035	3673	21	7C
0005435697018	3673	22	18B
0005435697037	3673	23	18C
0005434950478	3673	24	18D
0005435697038	3673	25	19A
0005435697039	3673	26	19B
0005434950479	3673	27	19C
0005435697042	3673	28	20A
0005435697021	3673	29	20C
0005434950477	3673	30	20D
0005435934997	3673	31	21A
0005435697030	3673	32	21D
0005435697028	3673	33	22A
0005435697031	3673	34	22B
0005435697040	3673	35	23A
0005435697019	3673	36	23B
0005435696847	16291	1	2B
0005435935010	16291	2	2D
0005434950457	16291	3	7A
0005434950458	16291	4	7B
0005435935009	16291	5	7C
0005435916137	16291	6	7D
0005435916136	16291	7	18B
0005435696866	16291	8	18D
0005435935008	16291	9	20A
0005435935011	16291	10	23A
0005434606786	3947	1	1A
0005434604862	3947	2	1D
0005433519406	3947	3	2A
0005432609685	3947	4	2B
0005432607518	3947	5	2D
0005434604859	3947	6	3C
0005434604860	3947	7	4A
0005434606787	3947	8	4B
0005433519407	3947	9	4D
0005434606788	3947	10	5A
0005432609687	3947	11	5B
0005432609686	3947	12	5C
0005432609684	3947	13	6B
0005432607519	3947	14	6C
0005432607522	3947	15	7A
0005432609688	3947	16	7B
0005432607520	3947	17	7C
0005433519405	3947	18	7D
0005433519408	3947	19	18C
0005434606785	3947	20	19D
0005433519404	3947	21	20D
0005434604861	3947	22	22B
0005432607521	3947	23	22D
0005435853588	22062	1	2A
0005435853589	22062	2	7B
0005435853590	22062	3	19C
0005435904889	22062	4	20B
0005433348901	733	1	2B
0005435628691	733	2	3B
0005435628690	733	3	4A
0005433348926	15979	1	2A
0005433348927	15979	2	2B
0005433348924	15979	3	3B
0005433348922	15979	4	4B
0005433348923	15979	5	5B
0005433348925	15979	6	6B
0005434446491	17175	1	2B
0005434445218	17175	2	3B
0005434445219	17175	3	5A
0005434445217	17175	4	5B
0005434445220	17175	5	6B
0005433159289	17607	1	4A
0005434445210	17607	2	4B
0005435132762	7863	1	1D
0005435132769	7863	2	2D
0005435132765	7863	3	3D
0005435132768	7863	4	4A
0005435132767	7863	5	4B
0005435132764	7863	6	5D
0005435383060	7863	7	7A
0005435132759	7863	8	7B
0005435132761	7863	9	18A
0005435132766	7863	10	19A
0005435132760	7863	11	19D
0005435132763	7863	12	22D
0005435383092	33096	1	4A
0005435383090	33096	2	4B
0005435383089	33096	3	5C
0005435383091	33096	4	20B
0005435383088	33096	5	20D
0005435811014	4412	1	1F
0005435811017	4412	2	4D
0005435811018	4412	3	5C
0005435811011	4412	4	7C
0005435811015	4412	5	13E
0005435811013	4412	6	13D
0005435811019	4412	7	16D
0005435811020	4412	8	16E
0005435811021	4412	9	17C
0005435811012	4412	10	17E
0005435811016	4412	11	19E
0005435938854	29433	1	6A
0005435938856	29433	2	7F
0005435810990	29433	3	8C
0005435938855	29433	4	14A
0005435938859	29433	5	15B
0005435938858	29433	6	20C
0005435938857	29433	7	21D
0005435390126	7501	1	1A
0005435160174	7501	2	1B
0005435160181	7501	3	2B
0005435160175	7501	4	3A
0005435160179	7501	5	4C
0005435160182	7501	6	5B
0005435160176	7501	7	5D
0005435160177	7501	8	6A
0005435160180	7501	9	6B
0005435160172	7501	10	7A
0005435160178	7501	11	20A
0005435160173	7501	12	20C
0005435390127	7501	13	21D
0005435390162	29540	1	2C
0005435390160	29540	2	2D
0005435390164	29540	3	4D
0005435390166	29540	4	6A
0005435390161	29540	5	6B
0005435390163	29540	6	7D
0005435390165	29540	7	19C
0005432394035	18451	1	4A
0005432394036	18451	2	5B
0005432400078	27175	1	1A
0005432398149	27175	2	2A
0005432400077	27175	3	2B
0005432400080	27175	4	3A
0005432400079	27175	5	3B
0005432398150	27175	6	4A
0005432398151	27175	7	4B
0005432400081	27175	8	6B
0005432639003	2255	1	1C
0005432638991	2255	2	2D
0005432639000	2255	3	3A
0005432638998	2255	4	3C
0005432638999	2255	5	4E
0005432638989	2255	6	4F
0005432639001	2255	7	5A
0005432638983	2255	8	6C
0005432638993	2255	9	6D
0005432638981	2255	10	6E
0005432638982	2255	11	8A
0005432638988	2255	12	8F
0005432638987	2255	13	9A
0005432638990	2255	14	9E
0005432639002	2255	15	10F
0005432639004	2255	16	11A
0005432638984	2255	17	11F
0005432865900	2255	18	12E
0005432638996	2255	19	12F
0005432638980	2255	20	13A
0005432638994	2255	21	13F
0005432638985	2255	22	14F
0005432638992	2255	23	16A
0005432865899	2255	24	16C
0005432638995	2255	25	16E
0005432638997	2255	26	18E
0005432638986	2255	27	19F
0005432638979	2255	28	20D
0005433811618	24296	1	3F
0005433811615	24296	2	4C
0005433811614	24296	3	9A
0005433811613	24296	4	9D
0005433811620	24296	5	13C
0005433811617	24296	6	14B
0005433811610	24296	7	15E
0005433811611	24296	8	17A
0005433811619	24296	9	18A
0005433811612	24296	10	22D
0005433811616	24296	11	23D
0005434191257	32761	1	1A
0005434191261	32761	2	1B
0005434191251	32761	3	2A
0005434191258	32761	4	3A
0005434191253	32761	5	2B
0005434191259	32761	6	3B
0005434191255	32761	7	4A
0005434191260	32761	8	4B
0005434191252	32761	9	5A
0005434191256	32761	10	6A
0005434191254	32761	11	6B
0005434503713	6515	1	1C
0005434503702	6515	2	1F
0005434503725	6515	3	2C
0005434503739	6515	4	2F
0005434503734	6515	5	3C
0005434503731	6515	6	3D
0005434503715	6515	7	3F
0005434503722	6515	8	4A
0005434503737	6515	9	4D
0005434503707	6515	10	4E
0005434503727	6515	11	4F
0005435103852	6515	12	5D
0005434503723	6515	13	6A
0005434503728	6515	14	7A
0005434503729	6515	15	7E
0005434503719	6515	16	7F
0005435103850	6515	17	8E
0005434503721	6515	18	9A
0005434503732	6515	19	9C
0005434503705	6515	20	10D
0005434503718	6515	21	10F
0005434503706	6515	22	11A
0005434503716	6515	23	11C
0005434503703	6515	24	11F
0005434503710	6515	25	12A
0005434503711	6515	26	12E
0005435103851	6515	27	13A
0005434503730	6515	28	13C
0005434503700	6515	29	13D
0005434503724	6515	30	14A
0005434503704	6515	31	14D
0005434503733	6515	32	14E
0005434503708	6515	33	14F
0005434503740	6515	34	15C
0005434503738	6515	35	16F
0005434503709	6515	36	17A
0005434503714	6515	37	18C
0005434503701	6515	38	18D
0005434503712	6515	39	18E
0005434503720	6515	40	18F
0005434503726	6515	41	19C
0005434503717	6515	42	19D
0005434503736	6515	43	20C
0005434503735	6515	44	20F
0005435652558	1642	1	1A
0005433367282	1642	2	1C
0005433367236	1642	3	1F
0005435652543	1642	4	2F
0005435652537	1642	5	3A
0005435652534	1642	6	3C
0005433367247	1642	7	4A
0005435652555	1642	8	4C
0005435652539	1642	9	4E
0005435652529	1642	10	5E
0005435652542	1642	11	5F
0005435652547	1642	12	6C
0005435652554	1642	13	6D
0005435652548	1642	14	6E
0005433367291	1642	15	7A
0005435652553	1642	16	7C
0005433367220	1642	17	7F
0005435652557	1642	18	8C
0005433367235	1642	19	8E
0005435652527	1642	20	9C
0005435652536	1642	21	9E
0005435652551	1642	22	10A
0005435652531	1642	23	10E
0005435652549	1642	24	10F
0005435652560	1642	25	11C
0005435652528	1642	26	12D
0005433367248	1642	27	13A
0005435652544	1642	28	13C
0005435652556	1642	29	13D
0005435652530	1642	30	13E
0005435652559	1642	31	13F
0005435652538	1642	32	14A
0005435652535	1642	33	15C
0005435652550	1642	34	15E
0005435652541	1642	35	16C
0005435652546	1642	36	16F
0005435652552	1642	37	18D
0005435652533	1642	38	19A
0005435652532	1642	39	19E
0005435652545	1642	40	19F
0005435652540	1642	41	20E
0005433367313	1642	42	20F
0005433367479	21688	1	1A
0005433367468	21688	2	2A
0005433367471	21688	3	3F
0005433367476	21688	4	4D
0005433367484	21688	5	4F
0005433367482	21688	6	5A
0005433367469	21688	7	5C
0005433367486	21688	8	5E
0005433367460	21688	9	7C
0005433367453	21688	10	7E
0005433367467	21688	11	8A
0005433367478	21688	12	8D
0005433367474	21688	13	8F
0005433367473	21688	14	9F
0005433367458	21688	15	10D
0005433367457	21688	16	11A
0005433367455	21688	17	11C
0005433367472	21688	18	11D
0005433367477	21688	19	11F
0005433367483	21688	20	12A
0005433367485	21688	21	12E
0005433367480	21688	22	13F
0005433367475	21688	23	14D
0005433367466	21688	24	14F
0005433367456	21688	25	15A
0005433367459	21688	26	15D
0005433367464	21688	27	16A
0005433367454	21688	28	17D
0005433367470	21688	29	17E
0005433367463	21688	30	17F
0005433367465	21688	31	18D
0005433367481	21688	32	19A
0005433367462	21688	33	19E
0005433367461	21688	34	20C
0005435312776	23242	1	4A
0005435312779	23242	2	4B
0005435312775	23242	3	6B
0005435312777	23242	4	22B
0005435312778	23242	5	22D
0005433985420	4134	1	1A
0005433985455	4134	2	1C
0005433985453	4134	3	1D
0005433985418	4134	4	2A
0005433985413	4134	5	2C
0005433985440	4134	6	2D
0005433985415	4134	7	3C
0005433985454	4134	8	3F
0005433985409	4134	9	4C
0005433985425	4134	10	4F
0005433985432	4134	11	5A
0005433985444	4134	12	5D
0005433985412	4134	13	6A
0005433985414	4134	14	6C
0005433985458	4134	15	6E
0005433985439	4134	16	6F
0005433985428	4134	17	7C
0005433985460	4134	18	7E
0005433985445	4134	19	7F
0005433985422	4134	20	8C
0005433985463	4134	21	8D
0005433985433	4134	22	9C
0005435788742	4134	23	9D
0005433985457	4134	24	9E
0005433985459	4134	25	10A
0005433985424	4134	26	10C
0005433985443	4134	27	10E
0005433985416	4134	28	10F
0005433985431	4134	29	11A
0005433985441	4134	30	11C
0005433985452	4134	31	11F
0005433985427	4134	32	12C
0005433985446	4134	33	12D
0005433985430	4134	34	12F
0005433985423	4134	35	13C
0005433985411	4134	36	13E
0005433985451	4134	37	14C
0005433985449	4134	38	14D
0005433985410	4134	39	14E
0005433985462	4134	40	14F
0005433985442	4134	41	15A
0005435788743	4134	42	15C
0005433985437	4134	43	15E
0005433985408	4134	44	16A
0005433985447	4134	45	16D
0005433985434	4134	46	16E
0005433985435	4134	47	16F
0005433985426	4134	48	17D
0005433985438	4134	49	17E
0005433985456	4134	50	17F
0005435788741	4134	51	18A
0005433985461	4134	52	18C
0005433985448	4134	53	18D
0005433985450	4134	54	19A
0005433985436	4134	55	19D
0005433985419	4134	56	19E
0005433985421	4134	57	20A
0005433985417	4134	58	20C
0005433985429	4134	59	20E
0005433985150	25667	1	10F
0005433985134	25667	2	16A
0005433985126	25667	3	19F
0005435719555	24806	1	2A
0005435720123	24806	2	4A
0005435720122	24806	3	4B
0005435719554	24806	4	19C
0005435720124	24806	5	20B
0005434509059	1635	1	1B
0005434509067	1635	2	2A
0005434509055	1635	3	2B
0005434509056	1635	4	3A
0005433168303	1635	5	4A
0005434509064	1635	6	4B
0005434509058	1635	7	4C
0005434509065	1635	8	6C
0005434509061	1635	9	7A
0005434509062	1635	10	7B
0005433168300	1635	11	7C
0005434509066	1635	12	18A
0005433168301	1635	13	18C
0005434509054	1635	14	18D
0005434509068	1635	15	19A
0005434509060	1635	16	19D
0005434509057	1635	17	21B
0005434509063	1635	18	22A
0005434509053	1635	19	23A
0005434516054	9021	1	1D
0005434516056	9021	2	2B
0005434516053	9021	3	6D
0005434516057	9021	4	7A
0005434516055	9021	5	18C
0005432869455	17868	1	1C
0005434151673	17868	2	1D
0005432666351	17868	3	3F
0005434151674	17868	4	4D
0005432869458	17868	5	6A
0005432869454	17868	6	6F
0005432869451	17868	7	12E
0005432869452	17868	8	14A
0005432869456	17868	9	16D
0005432869453	17868	10	16E
0005434151672	17868	11	17C
0005432869457	17868	12	18A
0005432667428	26281	1	1C
0005432666361	26281	2	4D
0005432655377	26281	3	4E
0005432660791	26281	4	4F
0005432659681	26281	5	5E
0005432655385	26281	6	6D
0005432655379	26281	7	6E
0005432658565	26281	8	7A
0005432659679	26281	9	7D
0005432657413	26281	10	9C
0005432666362	26281	11	9D
0005432655378	26281	12	9E
0005432657410	26281	13	10C
0005432655376	26281	14	10F
0005432657409	26281	15	11A
0005432657412	26281	16	11C
0005432659680	26281	17	11F
0005432655383	26281	18	12C
0005432655386	26281	19	14D
0005432655380	26281	20	15C
0005432655384	26281	21	16A
0005432658564	26281	22	16F
0005432665249	26281	23	18A
0005432657411	26281	24	18C
0005432655375	26281	25	18E
0005432655382	26281	26	19A
0005432660792	26281	27	19F
0005432658566	26281	28	20C
0005432655381	26281	29	20E
0005432865935	25064	1	1F
0005432865936	25064	2	2A
0005432865932	25064	3	2C
0005432865940	25064	4	4A
0005432865929	25064	5	4E
0005432865943	25064	6	5C
0005432865939	25064	7	6A
0005432865941	25064	8	6D
0005432865931	25064	9	9E
0005432865933	25064	10	11C
0005432865942	25064	11	12A
0005432865930	25064	12	12C
0005432865934	25064	13	15E
0005432865938	25064	14	16F
0005432865937	25064	15	19F
0005432328217	3080	1	1C
0005432328213	3080	2	1D
0005432328204	3080	3	1F
0005432328181	3080	4	2D
0005432328205	3080	5	3A
0005432328189	3080	6	3D
0005432328185	3080	7	3F
0005432328188	3080	8	4A
0005432287135	3080	9	4E
0005432328202	3080	10	4F
0005433438810	3080	11	5A
0005433438806	3080	12	5C
0005433438811	3080	13	5D
0005432328199	3080	14	5E
0005432328190	3080	15	5F
0005432328214	3080	16	6A
0005432287132	3080	17	6C
0005432328216	3080	18	6F
0005432328207	3080	19	7A
0005432328177	3080	20	7C
0005432328203	3080	21	7E
0005433438804	3080	22	7F
0005432328179	3080	23	8A
0005432328197	3080	24	8C
0005432328194	3080	25	8F
0005432328212	3080	26	9A
0005432905032	3080	27	9C
0005432328208	3080	28	9D
0005432328195	3080	29	10C
0005432328210	3080	30	10D
0005433438805	3080	31	10F
0005432328175	3080	32	11C
0005432328191	3080	33	11D
0005432328176	3080	34	11F
0005432328201	3080	35	12F
0005432328209	3080	36	13A
0005432328198	3080	37	13C
0005432328180	3080	38	13E
0005432328193	3080	39	14A
0005432328182	3080	40	14D
0005433438807	3080	41	14E
0005432328196	3080	42	14F
0005432328192	3080	43	15D
0005432328215	3080	44	15E
0005432328174	3080	45	16A
0005433438809	3080	46	16C
0005432287133	3080	47	16D
0005432328178	3080	48	17A
0005432328183	3080	49	17D
0005432328211	3080	50	17E
0005432328187	3080	51	17F
0005432328173	3080	52	18C
0005432328218	3080	53	18D
0005432287134	3080	54	18F
0005433438808	3080	55	19D
0005432328206	3080	56	19F
0005432328184	3080	57	20A
0005432328200	3080	58	20D
0005432328186	3080	59	20E
0005432905056	31133	1	2C
0005432905061	31133	2	2D
0005432905060	31133	3	3C
0005432054271	31133	4	4C
0005432054270	31133	5	6D
0005432054272	31133	6	8D
0005432905057	31133	7	10A
0005432327945	31133	8	11F
0005432905059	31133	9	17D
0005432327989	31133	10	18F
0005432905058	31133	11	20E
0005432905062	31133	12	20F
0005434309595	6220	1	1C
0005435999066	6220	2	2C
0005432146177	6220	3	4C
0005435999058	6220	4	4E
0005435999060	6220	5	5A
0005435999055	6220	6	4F
0005435999061	6220	7	5B
0005435999064	6220	8	6A
0005435999063	6220	9	6E
0005434309584	6220	10	6F
0005434309594	6220	11	7B
0005432146176	6220	12	8C
0005435999054	6220	13	8F
0005435999049	6220	14	8E
0005434309590	6220	15	9A
0005435999050	6220	16	9B
0005434309589	6220	17	10D
0005434309585	6220	18	10C
0005435999048	6220	19	11D
0005435999059	6220	20	12A
0005435999065	6220	21	12B
0005434309596	6220	22	12F
0005435999052	6220	23	14C
0005434309587	6220	24	14E
0005434309586	6220	25	15D
0005435999067	6220	26	16A
0005434309588	6220	27	16B
0005434309592	6220	28	16E
0005435296938	6220	29	17A
0005435999056	6220	30	16F
0005435999051	6220	31	17E
0005435999053	6220	32	19B
0005435999062	6220	33	19E
0005435999057	6220	34	20B
0005435999047	6220	35	20D
0005435999068	6220	36	21A
0005434309597	6220	37	21E
0005434309591	6220	38	21F
0005434309593	6220	39	22F
0005434309539	19565	1	2C
0005435487569	19565	2	3C
0005435487577	19565	3	4C
0005435487582	19565	4	5E
0005435296979	19565	5	5F
0005435487564	19565	6	7B
0005435487583	19565	7	7D
0005435487571	19565	8	7E
0005435487575	19565	9	8C
0005435296986	19565	10	9C
0005435487576	19565	11	9B
0005435487567	19565	12	9D
0005435296981	19565	13	12A
0005435487584	19565	14	12D
0005435487568	19565	15	12F
0005435487580	19565	16	13B
0005435296980	19565	17	13A
0005435487581	19565	18	13C
0005435296982	19565	19	13D
0005435487572	19565	20	14C
0005435487579	19565	21	14F
0005435487578	19565	22	15C
0005435487570	19565	23	16E
0005435487566	19565	24	17B
0005435487573	19565	25	17A
0005435487565	19565	26	18C
0005434309540	19565	27	19C
0005435296985	19565	28	19F
0005435296983	19565	29	20A
0005435296984	19565	30	20D
0005435487585	19565	31	22E
0005435487574	19565	32	23E
0005435517721	1566	1	1D
0005435517727	1566	2	1F
0005435517720	1566	3	2A
0005435502068	1566	4	2C
0005435502071	1566	5	2D
0005435502079	1566	6	2F
0005434565760	1566	7	3C
0005434565767	1566	8	3D
0005434565766	1566	9	3F
0005435502073	1566	10	4A
0005435508234	1566	11	4C
0005435517723	1566	12	4E
0005435502084	1566	13	4F
0005435517713	1566	14	5A
0005435502072	1566	15	5D
0005435517729	1566	16	5F
0005435517730	1566	17	6A
0005435502080	1566	18	6C
0005435502067	1566	19	6D
0005435502082	1566	20	6E
0005434565761	1566	21	6F
0005432291904	1566	22	7A
0005435517717	1566	23	7C
0005435508232	1566	24	7D
0005435502081	1566	25	7E
0005434565768	1566	26	7F
0005435517725	1566	27	8E
0005435517712	1566	28	9A
0005435502065	1566	29	9D
0005435502070	1566	30	9E
0005435502066	1566	31	9F
0005434565770	1566	32	11A
0005435517714	1566	33	11C
0005434565764	1566	34	11D
0005435502074	1566	35	11F
0005435502078	1566	36	12A
0005435502064	1566	37	12C
0005435502075	1566	38	12E
0005435517711	1566	39	13A
0005435517726	1566	40	13C
0005434565762	1566	41	13D
0005434565769	1566	42	13E
0005435508233	1566	43	14A
0005434565774	1566	44	14C
0005435502077	1566	45	14F
0005434565773	1566	46	15A
0005435502076	1566	47	15C
0005435517724	1566	48	15D
0005435508230	1566	49	16A
0005435517716	1566	50	16D
0005435517731	1566	51	16E
0005435517715	1566	52	16F
0005435502069	1566	53	17A
0005435502083	1566	54	17D
0005435517722	1566	55	17F
0005435517728	1566	56	18A
0005432291903	1566	57	18C
0005434565771	1566	58	18E
0005434565763	1566	59	18F
0005435517718	1566	60	19A
0005435508229	1566	61	19D
0005435517719	1566	62	19E
0005434565772	1566	63	19F
0005435508231	1566	64	20C
0005435502085	1566	65	20D
0005434565765	1566	66	20E
0005435501980	20868	1	2D
0005433186026	20868	2	5A
0005433186027	20868	3	5D
0005435501981	20868	4	6C
0005433186029	20868	5	8D
0005433186022	20868	6	9D
0005433186028	20868	7	10F
0005433186025	20868	8	13D
0005435528883	20868	9	13F
0005433186021	20868	10	16A
0005435501938	20868	11	17D
0005433186024	20868	12	18C
0005433186023	20868	13	20E
0005435153667	3875	1	1D
0005435153673	3875	2	5A
0005435153672	3875	3	5B
0005435153669	3875	4	7C
0005435153671	3875	5	7D
0005435153670	3875	6	19A
0005435153666	3875	7	20D
0005435153668	3875	8	21A
0005435931560	21854	1	1C
0005435931562	21854	2	18A
0005435931561	21854	3	18D
0005435931559	21854	4	22B
0005432628686	7216	1	1B
0005432628690	7216	2	1D
0005432628684	7216	3	2D
0005432628677	7216	4	3A
0005432628688	7216	5	3D
0005432628682	7216	6	4C
0005432628687	7216	7	6B
0005432628679	7216	8	6D
0005432628689	7216	9	7B
0005432628676	7216	10	7D
0005435225465	7216	11	18C
0005432628680	7216	12	19B
0005432628685	7216	13	20A
0005432628678	7216	14	21D
0005432628683	7216	15	22D
0005432628681	7216	16	23B
0005435225492	28136	1	1C
0005432628613	28136	2	2A
0005432628594	28136	3	3A
0005432628601	28136	4	2D
0005435225494	28136	5	3B
0005435225498	28136	6	6A
0005435225495	28136	7	7A
0005435225497	28136	8	7C
0005435225499	28136	9	7D
0005435225496	28136	10	18B
0005432628596	28136	11	20B
0005435225493	28136	12	22B
0005435960009	8754	1	3C
0005435960007	8754	2	20C
0005435960008	8754	3	21D
0005435960006	8754	4	23B
0005434267906	15213	1	3B
0005434267910	15213	2	5B
0005434267907	15213	3	7D
0005434267908	15213	4	18A
0005434267909	15213	5	22A
0005432692704	1166	1	1A
0005432677525	1166	2	1D
0005432692712	1166	3	1F
0005432674970	1166	4	2D
0005432692710	1166	5	3D
0005432692687	1166	6	4D
0005432692707	1166	7	4F
0005432692696	1166	8	5A
0005432692702	1166	9	5F
0005432674963	1166	10	6A
0005432692686	1166	11	6D
0005432674968	1166	12	7C
0005432677524	1166	13	7E
0005432692699	1166	14	7D
0005432692695	1166	15	8A
0005432692715	1166	16	7F
0005432873172	1166	17	8C
0005432674962	1166	18	8E
0005432692706	1166	19	9C
0005432692688	1166	20	9F
0005432692694	1166	21	9E
0005432692716	1166	22	11A
0005432692691	1166	23	12A
0005432692700	1166	24	12D
0005432692709	1166	25	12C
0005432692701	1166	26	12E
0005432873173	1166	27	13A
0005432674965	1166	28	12F
0005432674957	1166	29	13E
0005432677526	1166	30	14A
0005432692705	1166	31	13F
0005432677527	1166	32	14B
0005432692692	1166	33	14E
0005432873175	1166	34	14F
0005432674960	1166	35	15D
0005432674966	1166	36	17C
0005432674964	1166	37	17B
0005432674956	1166	38	17A
0005432692708	1166	39	17F
0005432692703	1166	40	17E
0005432692693	1166	41	18C
0005432692714	1166	42	18B
0005432692711	1166	43	19A
0005432692698	1166	44	19C
0005432692697	1166	45	20A
0005432674967	1166	46	19F
0005432692690	1166	47	20C
0005432674958	1166	48	20D
0005432674969	1166	49	20F
0005432692689	1166	50	20E
0005432674961	1166	51	21A
0005432873176	1166	52	21E
0005432674959	1166	53	21D
0005432692713	1166	54	21F
0005432873211	17459	1	5C
0005432873210	17459	2	10D
0005432692552	17459	3	11C
0005432692551	17459	4	14E
0005432873214	17459	5	15B
0005432873213	17459	6	17B
0005432873212	17459	7	19A
0005432873216	17459	8	19F
0005432873215	17459	9	19E
0005432873209	17459	10	21D
0005434435004	1125	1	1A
0005434435013	1125	2	1D
0005434435007	1125	3	2A
0005434435019	1125	4	2B
0005434435008	1125	5	2C
0005434435011	1125	6	2D
0005433156605	1125	7	4B
0005434435009	1125	8	5A
0005434435006	1125	9	6D
0005433156609	1125	10	7B
0005434435017	1125	11	7C
0005434435003	1125	12	18A
0005434435014	1125	13	18D
0005434435010	1125	14	19C
0005434435012	1125	15	20A
0005434435016	1125	16	20B
0005434435005	1125	17	20D
0005433156604	1125	18	21A
0005434435015	1125	19	21D
0005433156618	1125	20	22B
0005434435018	1125	21	22D
0005433156619	1125	22	23B
0005433156652	17278	1	6C
0005433156656	17278	2	7B
0005433156655	17278	3	18C
0005433156651	17278	4	20A
0005433156657	17278	5	20C
0005433156650	17278	6	20D
0005433156653	17278	7	21C
0005434434936	17278	8	21D
0005433156654	17278	9	22D
0005433156649	17278	10	23B
0005435086752	4092	1	1A
0005435928062	4092	2	1B
0005435086750	4092	3	3A
0005435928063	4092	4	5A
0005435086751	4092	5	5B
0005435086747	4092	6	6B
0005435086754	4092	7	7D
0005435086749	4092	8	18D
0005435086753	4092	9	19A
0005435086748	4092	10	19D
0005435086746	4092	11	23A
0005435928087	24391	1	2A
0005435928088	24391	2	3B
0005435086710	24391	3	3C
0005435928091	24391	4	5C
0005435086711	24391	5	5D
0005435928090	24391	6	7A
0005435928089	24391	7	22A
0005435706199	2462	1	1A
0005435706182	2462	2	1C
0005435706207	2462	3	1F
0005435706197	2462	4	2A
0005435706209	2462	5	2D
0005435706206	2462	6	3A
0005435706195	2462	7	3C
0005435706196	2462	8	3D
0005435706210	2462	9	4A
0005435706189	2462	10	7E
0005433373382	2462	11	7F
0005435706192	2462	12	8D
0005435706194	2462	13	9A
0005435706212	2462	14	9D
0005435706185	2462	15	9E
0005435706187	2462	16	10E
0005435706201	2462	17	11A
0005435706204	2462	18	11D
0005435706205	2462	19	12A
0005435706190	2462	20	13A
0005435706203	2462	21	15A
0005435706186	2462	22	15D
0005435706188	2462	23	16A
0005435706181	2462	24	16E
0005435706198	2462	25	16F
0005435706211	2462	26	17A
0005435706193	2462	27	17C
0005435706183	2462	28	17F
0005435706208	2462	29	19D
0005435706184	2462	30	19C
0005435706191	2462	31	19F
0005435706202	2462	32	20D
0005435706200	2462	33	20E
0005433373423	27033	1	1A
0005433373437	27033	2	4D
0005435706139	27033	3	5D
0005433373428	27033	4	5E
0005433373429	27033	5	6E
0005433373425	27033	6	7A
0005433373420	27033	7	8C
0005433373434	27033	8	8D
0005433373427	27033	9	9F
0005435706126	27033	10	10C
0005435706125	27033	11	11D
0005435706140	27033	12	11F
0005433373435	27033	13	12A
0005435706127	27033	14	12C
0005433373431	27033	15	12D
0005433373426	27033	16	13A
0005433373424	27033	17	13E
0005433373436	27033	18	14A
0005433373421	27033	19	14C
0005433373422	27033	20	15D
0005433373430	27033	21	16D
0005433373438	27033	22	18D
0005433373432	27033	23	18E
0005433373433	27033	24	19D
0005434964012	1313	1	1B
0005434964000	1313	2	1F
0005434964025	1313	3	3C
0005434964009	1313	4	4B
0005434964026	1313	5	4G
0005434963995	1313	6	5B
0005434963996	1313	7	5H
0005434964029	1313	8	9B
0005434964008	1313	9	12F
0005434964015	1313	10	13A
0005434963992	1313	11	13G
0005434964022	1313	12	14A
0005434964002	1313	13	15F
0005434963994	1313	14	15G
0005434964030	1313	15	16B
0005434964010	1313	16	15H
0005432279245	1313	17	16E
0005434963998	1313	18	16H
0005434964027	1313	19	18A
0005434963999	1313	20	18D
0005434964013	1313	21	18G
0005432279249	1313	22	21B
0005432279248	1313	23	21D
0005434964001	1313	24	22D
0005432279246	1313	25	22B
0005432279247	1313	26	22F
0005434964004	1313	27	23A
0005434964018	1313	28	23H
0005434964014	1313	29	24E
0005434963997	1313	30	27A
0005434963993	1313	31	27D
0005434964028	1313	32	27F
0005434964003	1313	33	28B
0005434964005	1313	34	28G
0005434964011	1313	35	28H
0005434964020	1313	36	29E
0005434964024	1313	37	31E
0005434964007	1313	38	32F
0005434964016	1313	39	32H
0005434964017	1313	40	33D
0005434964023	1313	41	33B
0005434964006	1313	42	33G
0005434964019	1313	43	35G
0005434964021	1313	44	39F
0005433261446	18249	1	1C
0005433261454	18249	2	1B
0005433261443	18249	3	3A
0005433261456	18249	4	3B
0005433261460	18249	5	3F
0005433261459	18249	6	4H
0005434963930	18249	7	5C
0005433261431	18249	8	11E
0005434963909	18249	9	11G
0005433261455	18249	10	14E
0005433261433	18249	11	14D
0005433261461	18249	12	14B
0005433261438	18249	13	15B
0005433261450	18249	14	15G
0005434963917	18249	15	18F
0005433261442	18249	16	21B
0005433261439	18249	17	21H
0005433261432	18249	18	23B
0005433261448	18249	19	24A
0005433261444	18249	20	24D
0005433261452	18249	21	24H
0005434963910	18249	22	25E
0005433261449	18249	23	27E
0005433261434	18249	24	28F
0005433261430	18249	25	29B
0005433261445	18249	26	29F
0005433261457	18249	27	30B
0005433261437	18249	28	30A
0005433261435	18249	29	31B
0005433261453	18249	30	33A
0005433261440	18249	31	33D
0005434963908	18249	32	33H
0005433261441	18249	33	34G
0005433261451	18249	34	35G
0005433261436	18249	35	35F
0005433261458	18249	36	38E
0005433261447	18249	37	38H
0005434625855	4829	1	2F
0005434625854	4829	2	9A
0005434625860	4829	3	9D
0005434625858	4829	4	11D
0005434625862	4829	5	13C
0005434625863	4829	6	14C
0005434625861	4829	7	14E
0005434625856	4829	8	15A
0005434625857	4829	9	19C
0005434625853	4829	10	19E
0005434625859	4829	11	20F
0005434625817	32881	1	1F
0005434625825	32881	2	2A
0005435907450	32881	3	4F
0005434625801	32881	4	10D
0005434625795	32881	5	11D
0005435907448	32881	6	11E
0005435907451	32881	7	12E
0005435907449	32881	8	15F
0005435907452	32881	9	16F
0005434625802	32881	10	17E
0005432195670	13763	1	1B
0005435937329	13763	2	1C
0005435937330	13763	3	7D
0005435784735	13763	4	18A
0005435784790	13763	5	18C
0005432195668	13763	6	18D
0005435937332	13763	7	19B
0005432195669	13763	8	19C
0005435937331	13763	9	20C
0005435937333	13763	10	23A
0005435784817	13763	11	23B
0005435784909	27429	1	1B
0005435784919	27429	2	1D
0005435784912	27429	3	2A
0005435784938	27429	4	2B
0005435784931	27429	5	2C
0005435784908	27429	6	2D
0005435784913	27429	7	3A
0005435787327	27429	8	3B
0005435784923	27429	9	3C
0005435784924	27429	10	3D
0005435784916	27429	11	4A
0005435784935	27429	12	4B
0005435784928	27429	13	4D
0005435784905	27429	14	5A
0005435784922	27429	15	5B
0005435784911	27429	16	5C
0005435784937	27429	17	5D
0005435784910	27429	18	6A
0005435784926	27429	19	6B
0005435784934	27429	20	6C
0005435784933	27429	21	6D
0005435784927	27429	22	7A
0005435784921	27429	23	7B
0005435784915	27429	24	18A
0005432190582	27429	25	18B
0005435784907	27429	26	18D
0005435784917	27429	27	19A
0005435787326	27429	28	19B
0005435784929	27429	29	19C
0005435784920	27429	30	20A
0005435784914	27429	31	20C
0005432190580	27429	32	20D
0005435784906	27429	33	21A
0005435784918	27429	34	21B
0005435784932	27429	35	21C
0005435784925	27429	36	21D
0005435784930	27429	37	22A
0005432190579	27429	38	22B
0005435784936	27429	39	22C
0005432190581	27429	40	23B
0005435310938	20293	1	2C
0005435310932	20293	2	5F
0005432058338	20293	3	6A
0005434406733	20293	4	6E
0005434406747	20293	5	6F
0005435310931	20293	6	8A
0005435310933	20293	7	8C
0005435310936	20293	8	10C
0005435310935	20293	9	10D
0005434406722	20293	10	10F
0005435310934	20293	11	11D
0005435310939	20293	12	12C
0005434406693	20293	13	13C
0005434406661	20293	14	14C
0005435310941	20293	15	14E
0005432058339	20293	16	15A
0005435310940	20293	17	17D
0005432058337	20293	18	18A
0005434406716	20293	19	18C
0005434406675	20293	20	19D
0005435310930	20293	21	19E
0005435310937	20293	22	20A
0005434406666	20293	23	20C
0005434407059	26985	1	1A
0005434407049	26985	2	1C
0005434407062	26985	3	1F
0005434407066	26985	4	2C
0005434407067	26985	5	2D
0005434407024	26985	6	2F
0005434407044	26985	7	3A
0005434407063	26985	8	3C
0005434407080	26985	9	3D
0005434407027	26985	10	3F
0005434407040	26985	11	4A
0005432153861	26985	12	4D
0005434407033	26985	13	4F
0005434407056	26985	14	5A
0005434407069	26985	15	5C
0005432153858	26985	16	5F
0005434407028	26985	17	6A
0005434407036	26985	18	6C
0005434407087	26985	19	6D
0005434407031	26985	20	6E
0005434407030	26985	21	6F
0005434407086	26985	22	7A
0005434407048	26985	23	7E
0005434407035	26985	24	8A
0005432153860	26985	25	8C
0005434407046	26985	26	8D
0005434407029	26985	27	9C
0005434407081	26985	28	9D
0005434407026	26985	29	9E
0005432153862	26985	30	9F
0005434407065	26985	31	10A
0005434407072	26985	32	10C
0005434407074	26985	33	10D
0005434407045	26985	34	10F
0005434407083	26985	35	11C
0005434407068	26985	36	11D
0005434407055	26985	37	11E
0005434407061	26985	38	12A
0005434407034	26985	39	12C
0005434407054	26985	40	12D
0005434407032	26985	41	12F
0005434407064	26985	42	13A
0005432153863	26985	43	13C
0005434407037	26985	44	13D
0005434407050	26985	45	13E
0005434407038	26985	46	13F
0005434407060	26985	47	14A
0005434407078	26985	48	14D
0005434407042	26985	49	14F
0005434407047	26985	50	15A
0005434407053	26985	51	15C
0005434407070	26985	52	15D
0005434407077	26985	53	15E
0005434407082	26985	54	15F
0005434407025	26985	55	16A
0005434407075	26985	56	16D
0005434407052	26985	57	16E
0005434407051	26985	58	17A
0005434407043	26985	59	17C
0005434407073	26985	60	17E
0005432153859	26985	61	18A
0005434407076	26985	62	18D
0005434407058	26985	63	18E
0005434407084	26985	64	18F
0005434407057	26985	65	19A
0005434407071	26985	66	19C
0005434407085	26985	67	19D
0005434407079	26985	68	19F
0005434407041	26985	69	20A
0005432153857	26985	70	20C
0005432153856	26985	71	20D
0005434407039	26985	72	20F
0005434319230	5683	1	2A
0005432109673	5683	2	3C
0005434311194	5683	3	4A
0005432109671	5683	4	4D
0005434311195	5683	5	4F
0005434319233	5683	6	5D
0005433123581	5683	7	5F
0005433123586	5683	8	6C
0005434319229	5683	9	6D
0005434319234	5683	10	8A
0005432109672	5683	11	8D
0005433123587	5683	12	9C
0005434319238	5683	13	9E
0005432109674	5683	14	9F
0005434319240	5683	15	11F
0005434319232	5683	16	12A
0005433123609	5683	17	12C
0005434319239	5683	18	12F
0005434311196	5683	19	14C
0005434319237	5683	20	14D
0005433123580	5683	21	15D
0005433123571	5683	22	16D
0005434319235	5683	23	17A
0005433123593	5683	24	18F
0005434319231	5683	25	19D
0005434319236	5683	26	20D
0005433123702	15704	1	1A
0005433123712	15704	2	1C
0005433123700	15704	3	5E
0005433123707	15704	4	7C
0005433123706	15704	5	9D
0005434312285	15704	6	10A
0005433123703	15704	7	10C
0005433123711	15704	8	10D
0005433123708	15704	9	12F
0005433123701	15704	10	14C
0005433123705	15704	11	14E
0005433123713	15704	12	15F
0005433123699	15704	13	16D
0005433123709	15704	14	18C
0005433123710	15704	15	18D
0005433123704	15704	16	20A
0005434312286	15704	17	20D
0005434484271	8957	1	2D
0005434484276	8957	2	4A
0005434484273	8957	3	4B
0005434484272	8957	4	5D
0005434484274	8957	5	18A
0005434484277	8957	6	19A
0005434484275	8957	7	19C
0005434189112	16653	1	3C
0005434189116	16653	2	4D
0005434189114	16653	3	5D
0005434189111	16653	4	6D
0005434189115	16653	5	18C
0005434189113	16653	6	19B
0005433123700	7699	1	3A
0005433123707	7699	2	3C
0005433123699	7699	3	4F
0005433123709	7699	4	6F
0005433123704	7699	5	8D
0005433123706	7699	6	10A
0005433123705	7699	7	10E
0005433123708	7699	8	12A
0005433123712	7699	9	12F
0005433123703	7699	10	14E
0005433123711	7699	11	16C
0005433123702	7699	12	17A
0005433123710	7699	13	18A
0005433123701	7699	14	19A
0005433123713	7699	15	20E
0005432720610	7697	1	1C
0005432071541	7697	2	1D
0005432692737	7697	3	1F
0005432692719	7697	4	2C
0005432720614	7697	5	2D
0005433449724	7697	6	2F
0005432720599	7697	7	3A
0005432692742	7697	8	3C
0005432692743	7697	9	3D
0005432692735	7697	10	3F
0005432720611	7697	11	4A
0005433449734	7697	12	4D
0005432692747	7697	13	4E
0005432692730	7697	14	4F
0005432692740	7697	15	5A
0005432720596	7697	16	5C
0005432720601	7697	17	5D
0005432692726	7697	18	5E
0005432692723	7697	19	5F
0005432692722	7697	20	6A
0005433449723	7697	21	6C
0005432720612	7697	22	6D
0005432692720	7697	23	6E
0005433449727	7697	24	6F
0005433449717	7697	25	7A
0005432692739	7697	26	7C
0005432720602	7697	27	7D
0005432720607	7697	28	7F
0005432720605	7697	29	8A
0005432692717	7697	30	8C
0005432692736	7697	31	8D
0005432692738	7697	32	8E
0005432720608	7697	33	8F
0005433449719	7697	34	9D
0005433449730	7697	35	9E
0005432071540	7697	36	9F
0005432692732	7697	37	10A
0005432692727	7697	38	10C
0005433449731	7697	39	10D
0005432692721	7697	40	10E
0005432692741	7697	41	10F
0005432720616	7697	42	11A
0005433449738	7697	43	11C
0005432720618	7697	44	11D
0005432692744	7697	45	11E
0005432720619	7697	46	12C
0005432692746	7697	47	12D
0005432692718	7697	48	12E
0005433449726	7697	49	12F
0005432720593	7697	50	13A
0005432720617	7697	51	13D
0005432692728	7697	52	13F
0005433449720	7697	53	14A
0005433449722	7697	54	14C
0005433449718	7697	55	14D
0005433449733	7697	56	14E
0005433449729	7697	57	14F
0005432720600	7697	58	15A
0005432720606	7697	59	15C
0005432692729	7697	60	15D
0005432720595	7697	61	15E
0005432692731	7697	62	15F
0005433449736	7697	63	16A
0005432720615	7697	64	16C
0005432720594	7697	65	16D
0005433449728	7697	66	16E
0005433449732	7697	67	16F
0005433449725	7697	68	17A
0005432720597	7697	69	17C
0005432720598	7697	70	17D
0005432692724	7697	71	17E
0005432720613	7697	72	17F
0005432692725	7697	73	18C
0005433449737	7697	74	18E
0005432720603	7697	75	18F
0005432071539	7697	76	19A
0005432720604	7697	77	19C
0005433449735	7697	78	19D
0005432720609	7697	79	19F
0005433449721	7697	80	20A
0005432692734	7697	81	20D
0005432692745	7697	82	20E
0005432692733	7697	83	20F
0005432692552	30401	1	3F
0005433449648	30401	2	4A
0005432692551	30401	3	5C
0005433449603	30401	4	8F
0005433449591	30401	5	10C
0005433449664	30401	6	10E
0005433449602	30401	7	14D
0005433449649	30401	8	16F
0005433722145	30400	1	1D
0005433123571	30400	2	2D
0005433123586	30400	3	3C
0005433722146	30400	4	3D
0005432720501	30400	5	3F
0005433123609	30400	6	4E
0005433123580	30400	7	5F
0005432720455	30400	8	6A
0005433722152	30400	9	6D
0005433123593	30400	10	6F
0005432720429	30400	11	7C
0005433722141	30400	12	9C
0005432720572	30400	13	9D
0005433722149	30400	14	9E
0005433722142	30400	15	11C
0005432720500	30400	16	12C
0005432720453	30400	17	12F
0005433722144	30400	18	13D
0005433722151	30400	19	14F
0005433722150	30400	20	15A
0005433722153	30400	21	15D
0005432720450	30400	22	15E
0005432720571	30400	23	15F
0005433123581	30400	24	16A
0005432720475	30400	25	16E
0005433722148	30400	26	16F
0005433722143	30400	27	17A
0005432720446	30400	28	17F
0005433722154	30400	29	18D
0005432720454	30400	30	18F
0005433722147	30400	31	19E
0005433123587	30400	32	20D
0005432720464	30400	33	20F
0005433724758	1361	1	1A
0005434514939	1361	2	1C
0005434513549	1361	3	1D
0005433524913	1361	4	2A
0005434586315	1361	5	2C
0005433192810	1361	6	3A
0005433724756	1361	7	3C
0005433524918	1361	8	3F
0005434586316	1361	9	4C
0005434586339	1361	10	4F
0005433524912	1361	11	6D
0005434586328	1361	12	6E
0005432270973	1361	13	7A
0005434586319	1361	14	7C
0005434586329	1361	15	7F
0005434586317	1361	16	8C
0005433524919	1361	17	8E
0005434586333	1361	18	8F
0005434586335	1361	19	9A
0005434586331	1361	20	9C
0005434586340	1361	21	9E
0005434586324	1361	22	9F
0005433524916	1361	23	10D
0005434586318	1361	24	10E
0005434586320	1361	25	11C
0005432270972	1361	26	11E
0005434514937	1361	27	12A
0005434586332	1361	28	12D
0005434586334	1361	29	12E
0005434513550	1361	30	12F
0005433724754	1361	31	13A
0005433524920	1361	32	13C
0005434586338	1361	33	13D
0005433192809	1361	34	13F
0005434586337	1361	35	14A
0005433524921	1361	36	14D
0005434514938	1361	37	14E
0005434586326	1361	38	14F
0005434586336	1361	39	15D
0005433724757	1361	40	16C
0005433724753	1361	41	16D
0005434586323	1361	42	16F
0005433524914	1361	43	17C
0005434586322	1361	44	17D
0005434586321	1361	45	17F
0005433524917	1361	46	18A
0005434586330	1361	47	18C
0005433524922	1361	48	18D
0005434586325	1361	49	18F
0005434586314	1361	50	19C
0005433192814	1361	51	19D
0005433724755	1361	52	19E
0005434586327	1361	53	19F
0005433192813	1361	54	20A
0005434586341	1361	55	20C
0005432270971	1361	56	20E
0005433524915	1361	57	20F
0005433192891	18498	1	1F
0005433192896	18498	2	4A
0005433192901	18498	3	4D
0005432927917	18498	4	4F
0005434586170	18498	5	5E
0005433192898	18498	6	5F
0005433524855	18498	7	6E
0005433192892	18498	8	7E
0005433192903	18498	9	7F
0005433192893	18498	10	8C
0005433192897	18498	11	8E
0005433192900	18498	12	9A
0005433192902	18498	13	9C
0005432927914	18498	14	9F
0005432968814	18498	15	10F
0005432927919	18498	16	11A
0005434586169	18498	17	12C
0005433524856	18498	18	14A
0005432927915	18498	19	14C
0005433192899	18498	20	16A
0005433192894	18498	21	16D
0005432927920	18498	22	17E
0005432927916	18498	23	18E
0005432968813	18498	24	19F
0005434586157	18498	25	20A
0005433192895	18498	26	20D
0005432927918	18498	27	20E
0005434343782	11464	1	1A
0005434343773	11464	2	1C
0005434343795	11464	3	1D
0005434343772	11464	4	2A
0005434343776	11464	5	2C
0005434343765	11464	6	2D
0005434343775	11464	7	3A
0005434142567	11464	8	3B
0005434343768	11464	9	3C
0005434343787	11464	10	4A
0005434343793	11464	11	4B
0005434343763	11464	12	4C
0005434343783	11464	13	4D
0005434343771	11464	14	5B
0005434343777	11464	15	5C
0005434343791	11464	16	5D
0005434142565	11464	17	6A
0005434343779	11464	18	6B
0005434343790	11464	19	6C
0005434343798	11464	20	7A
0005434343794	11464	21	7B
0005434343792	11464	22	7C
0005434343774	11464	23	7D
0005434142568	11464	24	18A
0005434343784	11464	25	18C
0005434343789	11464	26	18D
0005434343761	11464	27	19A
0005434343785	11464	28	19B
0005434343786	11464	29	19C
0005434343778	11464	30	19D
0005434343780	11464	31	20A
0005434343769	11464	32	20B
0005434343764	11464	33	20C
0005434343767	11464	34	20D
0005434343788	11464	35	21A
0005434343781	11464	36	21B
0005434142566	11464	37	21C
0005434343762	11464	38	21D
0005434343796	11464	39	22B
0005434343766	11464	40	22C
0005434343797	11464	41	22D
0005434343770	11464	42	23B
0005434343654	29774	1	1B
0005435304115	29774	2	1D
0005434343653	29774	3	5C
0005435304116	29774	4	6B
0005434343676	29774	5	18C
0005434142542	29774	6	20A
0005435304117	29774	7	20C
0005434343594	29774	8	21C
0005434142541	29774	9	23B
0005435824321	1295	1	1C
0005433415397	1295	2	1F
0005435824319	1295	3	1D
0005433415381	1295	4	2A
0005433415452	1295	5	2F
0005435824336	1295	6	3D
0005435824340	1295	7	4C
0005435824339	1295	8	4D
0005433415405	1295	9	5C
0005433415451	1295	10	6B
0005435824323	1295	11	6C
0005435824332	1295	12	6E
0005433415387	1295	13	6D
0005435824318	1295	14	7C
0005435824334	1295	15	7B
0005433415380	1295	16	8D
0005435824322	1295	17	9C
0005435824317	1295	18	10A
0005435824320	1295	19	9F
0005435824328	1295	20	11A
0005435824330	1295	21	11E
0005435824341	1295	22	13A
0005432284525	1295	23	13B
0005435824331	1295	24	13F
0005435824333	1295	25	14B
0005435824325	1295	26	14D
0005435824326	1295	27	15B
0005435824338	1295	28	15A
0005433415403	1295	29	15E
0005433415382	1295	30	16C
0005432284526	1295	31	16B
0005435824324	1295	32	17D
0005435824342	1295	33	18B
0005435824335	1295	34	18E
0005435824337	1295	35	19C
0005433415404	1295	36	19B
0005435824329	1295	37	19E
0005432284524	1295	38	21A
0005435824327	1295	39	21F
0005435824179	17997	1	2D
0005435824162	17997	2	4C
0005433415482	17997	3	6A
0005435824213	17997	4	6C
0005435824206	17997	5	6F
0005433415486	17997	6	7D
0005433415476	17997	7	8C
0005435824178	17997	8	8B
0005435824163	17997	9	8F
0005433415490	17997	10	9C
0005433415488	17997	11	10E
0005433415477	17997	12	10F
0005433415483	17997	13	11D
0005433415491	17997	14	12F
0005433415489	17997	15	13D
0005435824181	17997	16	15E
0005433415478	17997	17	16A
0005433415485	17997	18	15F
0005435824164	17997	19	16E
0005433415484	17997	20	17B
0005433415481	17997	21	17A
0005433415480	17997	22	18E
0005433415487	17997	23	21B
0005435824176	17997	24	21A
0005433415479	17997	25	21E
0005435824177	17997	26	21D
0005434460467	17525	1	2C
0005432783194	5621	1	1A
0005432783185	5621	2	2A
0005432783200	5621	3	2D
0005432143953	5621	4	3C
0005432783218	5621	5	4A
0005432783181	5621	6	4D
0005432783213	5621	7	5A
0005432783187	5621	8	5D
0005432783212	5621	9	5E
0005432783208	5621	10	5F
0005432783197	5621	11	6A
0005432783209	5621	12	6C
0005432783178	5621	13	6D
0005432783174	5621	14	7A
0005432783220	5621	15	7C
0005432783211	5621	16	8A
0005432783217	5621	17	8D
0005432783214	5621	18	8E
0005432783222	5621	19	8F
0005432783182	5621	20	9C
0005432783221	5621	21	9D
0005432783183	5621	22	9E
0005432783201	5621	23	10A
0005432783198	5621	24	10C
0005432783170	5621	25	10D
0005432783219	5621	26	10F
0005432783184	5621	27	11C
0005432143951	5621	28	11D
0005432783192	5621	29	11E
0005432783224	5621	30	11F
0005432783172	5621	31	12A
0005432143949	5621	32	12D
0005432783175	5621	33	12E
0005432783207	5621	34	12F
0005432783216	5621	35	13A
0005432783171	5621	36	13C
0005432783210	5621	37	13D
0005432783195	5621	38	13E
0005432783223	5621	39	14A
0005432783189	5621	40	14C
0005432783204	5621	41	14D
0005432783180	5621	42	14F
0005432783203	5621	43	15A
0005432783191	5621	44	15D
0005432783199	5621	45	15E
0005432783193	5621	46	15F
0005432143952	5621	47	16A
0005432783176	5621	48	16C
0005432143950	5621	49	16E
0005432783202	5621	50	17A
0005432783190	5621	51	17E
0005432783188	5621	52	17F
0005432783186	5621	53	18A
0005432783196	5621	54	18D
0005432783169	5621	55	18F
0005432783205	5621	56	19A
0005432783179	5621	57	19C
0005432783177	5621	58	19D
0005432783215	5621	59	19E
0005432783206	5621	60	20C
0005432783173	5621	61	20E
0005432782870	15351	1	1A
0005435242529	15351	2	2D
0005435476687	15351	3	2F
0005435242542	15351	4	3C
0005435476681	15351	5	3F
0005435242538	15351	6	4F
0005435476688	15351	7	5A
0005432782890	15351	8	5C
0005435242534	15351	9	5D
0005435242532	15351	10	6A
0005435242547	15351	11	6D
0005435242527	15351	12	7A
0005435242548	15351	13	7D
0005435476684	15351	14	7E
0005435242543	15351	15	7F
0005435242544	15351	16	8C
0005432782844	15351	17	8E
0005435242540	15351	18	9A
0005435242533	15351	19	9C
0005435242546	15351	20	9E
0005435242550	15351	21	9F
0005435242552	15351	22	10A
0005435242535	15351	23	11A
0005435242553	15351	24	11C
0005435242539	15351	25	11D
0005432783022	15351	26	12A
0005432782847	15351	27	13E
0005435242531	15351	28	13F
0005435476686	15351	29	14A
0005435242537	15351	30	14D
0005435242536	15351	31	14E
0005435476685	15351	32	15F
0005435242545	15351	33	16A
0005435242541	15351	34	16E
0005435242551	15351	35	17D
0005435242530	15351	36	17E
0005435476682	15351	37	18C
0005435242528	15351	38	18E
0005435476683	15351	39	19D
0005435242549	15351	40	20C
0005432782869	15351	41	20F
0005432848149	4374	1	1C
0005434462765	4374	2	2D
0005432848145	4374	3	3A
0005432848148	4374	4	3C
0005432848153	4374	5	4A
0005432848144	4374	6	4C
0005434463904	4374	7	4D
0005432848158	4374	8	5D
0005432848150	4374	9	6C
0005432848156	4374	10	7B
0005435850767	4374	11	7D
0005432848151	4374	12	18A
0005432848154	4374	13	18D
0005435850774	4374	14	19A
0005432848152	4374	15	19B
0005432848157	4374	16	19D
0005435850757	4374	17	20A
0005432848155	4374	18	20D
0005432848146	4374	19	21A
0005434463905	4374	20	21B
0005432848147	4374	21	22B
0005434462766	4374	22	22C
0005435850807	28868	1	4C
0005435850808	28868	2	4D
0005435850809	28868	3	7A
0005435850805	28868	4	7C
0005435850813	28868	5	18D
0005435850812	28868	6	19D
0005435850811	28868	7	21B
0005435850810	28868	8	22D
0005435850806	28868	9	23B
0005434925468	6330	1	1A
0005434443533	6330	2	1C
0005434925451	6330	3	1D
0005434925469	6330	4	1F
0005434925433	6330	5	2A
0005433496638	6330	6	2C
0005434443532	6330	7	2D
0005434925439	6330	8	2F
0005433496639	6330	9	3A
0005434925448	6330	10	3C
0005434925456	6330	11	3D
0005434925457	6330	12	3F
0005434925473	6330	13	4A
0005433496616	6330	14	4C
0005434925446	6330	15	4D
0005433496622	6330	16	4E
0005434925441	6330	17	4F
0005434925444	6330	18	5A
0005434443536	6330	19	5C
0005434443535	6330	20	5D
0005433496640	6330	21	5E
0005434925452	6330	22	6A
0005432075190	6330	23	6D
0005433496614	6330	24	6E
0005433496615	6330	25	6F
0005434925437	6330	26	7A
0005433496630	6330	27	7C
0005434925466	6330	28	7D
0005433496618	6330	29	7E
0005434443524	6330	30	7F
0005432075192	6330	31	8A
0005434925471	6330	32	8C
0005433496613	6330	33	8D
0005434443534	6330	34	8E
0005434443525	6330	35	8F
0005434925435	6330	36	9A
0005434925447	6330	37	9C
0005434443523	6330	38	9D
0005434925450	6330	39	9E
0005434925434	6330	40	9F
0005433496625	6330	41	10A
0005434443538	6330	42	10C
0005433496619	6330	43	10D
0005434925463	6330	44	10E
0005434925462	6330	45	10F
0005434925472	6330	46	11A
0005434925461	6330	47	11C
0005433496633	6330	48	11D
0005434925458	6330	49	11E
0005432075193	6330	50	11F
0005434925459	6330	51	12A
0005434925436	6330	52	12D
0005433496636	6330	53	12E
0005434925453	6330	54	12F
0005433496621	6330	55	13A
0005433496620	6330	56	13C
0005434925443	6330	57	13D
0005433496635	6330	58	13E
0005433496632	6330	59	13F
0005434443526	6330	60	14A
0005434443537	6330	61	14C
0005434925470	6330	62	14D
0005434925438	6330	63	14E
0005433496624	6330	64	14F
0005433496641	6330	65	15A
0005434443529	6330	66	15D
0005432075191	6330	67	15E
0005433496626	6330	68	15F
0005434443522	6330	69	16A
0005433496628	6330	70	16C
0005434443530	6330	71	16E
0005433496617	6330	72	16F
0005433496627	6330	73	17A
0005434925464	6330	74	17C
0005434443527	6330	75	17D
0005433496637	6330	76	17E
0005434925460	6330	77	17F
0005434925455	6330	78	18A
0005434443531	6330	79	18C
0005434925442	6330	80	18D
0005433496629	6330	81	18E
0005434925440	6330	82	19A
0005434925467	6330	83	18F
0005434443528	6330	84	19C
0005434925465	6330	85	19D
0005434925449	6330	86	19E
0005434925445	6330	87	19F
0005434925454	6330	88	20A
0005433496634	6330	89	20C
0005433496623	6330	90	20D
0005433496631	6330	91	20E
0005433496494	20385	1	1D
0005433496434	20385	2	2C
0005433496418	20385	3	2D
0005433496490	20385	4	3F
0005433496451	20385	5	5F
0005433496448	20385	6	6D
0005433496433	20385	7	6E
0005433496491	20385	8	7E
0005433496492	20385	9	9A
0005433496449	20385	10	10A
0005433496419	20385	11	10C
0005433496432	20385	12	11A
0005433496450	20385	13	11C
0005433496452	20385	14	12E
0005433496464	20385	15	13D
0005433496445	20385	16	16D
0005433496453	20385	17	18A
0005433496503	20385	18	18E
0005433496495	20385	19	19A
0005433496486	20385	20	20E
0005435242571	12155	1	1A
0005435242576	12155	2	1D
0005435242561	12155	3	2C
0005432782848	12155	4	2D
0005435242574	12155	5	3F
0005432782904	12155	6	4D
0005435242558	12155	7	4E
0005435242577	12155	8	5A
0005435242555	12155	9	5C
0005435242570	12155	10	5F
0005435242567	12155	11	6D
0005432782879	12155	12	7E
0005435242557	12155	13	7F
0005435242573	12155	14	8C
0005432782911	12155	15	9A
0005435242568	12155	16	10A
0005435242565	12155	17	10C
0005435242580	12155	18	11E
0005435242572	12155	19	11F
0005435242569	12155	20	12C
0005432782868	12155	21	12D
0005435242563	12155	22	12F
0005432782899	12155	23	13D
0005435242559	12155	24	14A
0005432782902	12155	25	14C
0005435242578	12155	26	14E
0005435242556	12155	27	15A
0005435242562	12155	28	15C
0005435242581	12155	29	15E
0005432782885	12155	30	16A
0005432782849	12155	31	16D
0005435242564	12155	32	17A
0005435242554	12155	33	17D
0005435242579	12155	34	17F
0005432782955	12155	35	18A
0005435242575	12155	36	18D
0005432782880	12155	37	18E
0005435242566	12155	38	18F
0005435242560	12155	39	20D
0005432783132	15406	1	1A
0005432783168	15406	2	1C
0005432783156	15406	3	1D
0005432783127	15406	4	1F
0005432783163	15406	5	2F
0005432783126	15406	6	3A
0005432783116	15406	7	3C
0005432783129	15406	8	3D
0005432783136	15406	9	4A
0005432783150	15406	10	4D
0005432783166	15406	11	5A
0005432783134	15406	12	5C
0005432783161	15406	13	5E
0005435242401	15406	14	5F
0005432783151	15406	15	6A
0005432783148	15406	16	6C
0005432783133	15406	17	6D
0005432783131	15406	18	6E
0005432783121	15406	19	6F
0005435242400	15406	20	7C
0005432783160	15406	21	7D
0005432783113	15406	22	7E
0005432783155	15406	23	7F
0005432783157	15406	24	8A
0005432783141	15406	25	8C
0005432783165	15406	26	8D
0005432783119	15406	27	8E
0005432783123	15406	28	8F
0005432783114	15406	29	9A
0005432783144	15406	30	9C
0005432783138	15406	31	9E
0005432783159	15406	32	9F
0005432783146	15406	33	10D
0005432783143	15406	34	10E
0005432783135	15406	35	10F
0005432783162	15406	36	11A
0005432783130	15406	37	11C
0005432783149	15406	38	11D
0005432783154	15406	39	11E
0005432783140	15406	40	11F
0005432783128	15406	41	12C
0005432783153	15406	42	12D
0005432783117	15406	43	12E
0005432783158	15406	44	13E
0005432783147	15406	45	13F
0005432783122	15406	46	14C
0005432783164	15406	47	14D
0005432783137	15406	48	14E
0005432783145	15406	49	16D
0005432783125	15406	50	17D
0005432783124	15406	51	18C
0005432783139	15406	52	18E
0005432783142	15406	53	19A
0005432783120	15406	54	19C
0005432783167	15406	55	19D
0005432783118	15406	56	19E
0005432783115	15406	57	20C
0005432783152	15406	58	20D
0005434876574	10082	1	3A
0005434876784	10082	2	2F
0005434876611	10082	3	3C
0005434876581	10082	4	4D
0005434876626	10082	5	5F
0005434876625	10082	6	6D
0005434876630	10082	7	6E
0005434876588	10082	8	8C
0005434876571	10082	9	8B
0005435913889	10082	10	8E
0005434876575	10082	11	8F
0005434876586	10082	12	9D
0005434876606	10082	13	10A
0005434876686	10082	14	10B
0005434876576	10082	15	11C
0005434876582	10082	16	12B
0005434910083	10082	17	12E
0005435913891	10082	18	13A
0005435913890	10082	19	15A
0005434876632	10082	20	16F
0005434876782	10082	21	18C
0005434876617	10082	22	18B
0005434876556	10082	23	18E
0005434876717	10082	24	18D
0005434876650	10082	25	19A
0005434876555	10082	26	19D
0005435913892	10082	27	20B
0005434876783	10082	28	21A
0005434910082	10082	29	21D
0005434877177	14639	1	1A
0005434877156	14639	2	1F
0005434877218	14639	3	1D
0005434877153	14639	4	1C
0005434877179	14639	5	2A
0005434877186	14639	6	2D
0005434877164	14639	7	2C
0005434877165	14639	8	3A
0005434877233	14639	9	2F
0005434877170	14639	10	3D
0005434877228	14639	11	3C
0005434877152	14639	12	4A
0005434877195	14639	13	3F
0005434877173	14639	14	4C
0005434877220	14639	15	5A
0005434877219	14639	16	4F
0005434877140	14639	17	4D
0005434877151	14639	18	5D
0005434877146	14639	19	5C
0005434877138	14639	20	5F
0005434877141	14639	21	6B
0005434877182	14639	22	6A
0005434877192	14639	23	6C
0005434877193	14639	24	6F
0005434877162	14639	25	6E
0005434877174	14639	26	6D
0005434877163	14639	27	7A
0005434877148	14639	28	7C
0005434877178	14639	29	7B
0005434877230	14639	30	7E
0005434877227	14639	31	8A
0005434877185	14639	32	8C
0005434877181	14639	33	8B
0005434877229	14639	34	8D
0005434877231	14639	35	8F
0005434877159	14639	36	8E
0005434758867	14639	37	9B
0005434877171	14639	38	9A
0005434877143	14639	39	9D
0005434877224	14639	40	9C
0005434877226	14639	41	9E
0005434877225	14639	42	10A
0005434877212	14639	43	10B
0005434877150	14639	44	10D
0005434877202	14639	45	10F
0005434877184	14639	46	11B
0005434910070	14639	47	11A
0005434877155	14639	48	11D
0005434877203	14639	49	11C
0005434877208	14639	50	11F
0005434877169	14639	51	11E
0005434877216	14639	52	12B
0005434877175	14639	53	12A
0005434877172	14639	54	12C
0005434910069	14639	55	12F
0005434877222	14639	56	12E
0005434877161	14639	57	12D
0005434877194	14639	58	13A
0005434877196	14639	59	13C
0005434877139	14639	60	13B
0005434877210	14639	61	13E
0005434877215	14639	62	13D
0005434877149	14639	63	14A
0005434877168	14639	64	13F
0005434877223	14639	65	14C
0005434877166	14639	66	14D
0005434877189	14639	67	14F
0005434877200	14639	68	14E
0005434877157	14639	69	15B
0005434877232	14639	70	15A
0005434877158	14639	71	15C
0005434877217	14639	72	15E
0005434877199	14639	73	15D
0005434877213	14639	74	16A
0005434877206	14639	75	15F
0005434877221	14639	76	16C
0005434877147	14639	77	16B
0005434877142	14639	78	16E
0005434877187	14639	79	16D
0005434877160	14639	80	17A
0005434877167	14639	81	17B
0005434877183	14639	82	17C
0005434877145	14639	83	17F
0005434877211	14639	84	17E
0005434877205	14639	85	18B
0005434877207	14639	86	18D
0005434877154	14639	87	18C
0005434877176	14639	88	18E
0005434877197	14639	89	19B
0005434877201	14639	90	19E
0005434877188	14639	91	19D
0005434877191	14639	92	19F
0005434877198	14639	93	20B
0005434877144	14639	94	20A
0005434877204	14639	95	20D
0005434758866	14639	96	20C
0005434877180	14639	97	20F
0005434877234	14639	98	20E
0005434877214	14639	99	21D
0005434877209	14639	100	21B
0005434877190	14639	101	21E
0005435660008	9267	1	1A
0005435660014	9267	2	1B
0005435660013	9267	3	1C
0005434251797	9267	4	2B
0005435660011	9267	5	2D
0005435660006	9267	6	3A
0005434251811	9267	7	5A
0005435660012	9267	8	6C
0005435660009	9267	9	7C
0005435660010	9267	10	18B
0005435660015	9267	11	18C
0005435660007	9267	12	19C
0005435660016	9267	13	22C
0005434251858	24651	1	1D
0005434251857	24651	2	2C
0005434251862	24651	3	2D
0005434251859	24651	4	4C
0005434251855	24651	5	6C
0005434251856	24651	6	20B
0005434251860	24651	7	22B
0005434251861	24651	8	23A
0005433680016	2818	1	1A
0005433680032	2818	2	1C
0005433680019	2818	3	1D
0005433680028	2818	4	1F
0005432222720	2818	5	2A
0005433680033	2818	6	2C
0005433680009	2818	7	2D
0005433680037	2818	8	2F
0005432966525	2818	9	3A
0005433680047	2818	10	3C
0005433680039	2818	11	3D
0005433680003	2818	12	4C
0005433680051	2818	13	4D
0005433684396	2818	14	4E
0005432222721	2818	15	5C
0005433680036	2818	16	5D
0005433680035	2818	17	5E
0005433680024	2818	18	5F
0005433680011	2818	19	6C
0005433680029	2818	20	7C
0005433680030	2818	21	7D
0005432222722	2818	22	7E
0005433684395	2818	23	7F
0005432966536	2818	24	8A
0005433680040	2818	25	8C
0005433680045	2818	26	8E
0005433680048	2818	27	9A
0005433680026	2818	28	9D
0005433680012	2818	29	10F
0005432966526	2818	30	11A
0005433680023	2818	31	11C
0005433680020	2818	32	11D
0005433680046	2818	33	11F
0005433680027	2818	34	12C
0005433680021	2818	35	12D
0005433680043	2818	36	12E
0005433680031	2818	37	13A
0005432222723	2818	38	13E
0005432222724	2818	39	13F
0005433680008	2818	40	14A
0005433680044	2818	41	14F
0005433680007	2818	42	15A
0005433680005	2818	43	15D
0005433680034	2818	44	15E
0005433680013	2818	45	15F
0005433680018	2818	46	16A
0005433680050	2818	47	16C
0005433680042	2818	48	16D
0005433680014	2818	49	16E
0005432222725	2818	50	17C
0005433680006	2818	51	17F
0005433680041	2818	52	18A
0005433680038	2818	53	18C
0005433680022	2818	54	18D
0005432966486	2818	55	18E
0005433680010	2818	56	19C
0005433680049	2818	57	19E
0005433680025	2818	58	19F
0005433680004	2818	59	20A
0005433680017	2818	60	20C
0005433680015	2818	61	20D
0005433679711	29151	1	1C
0005432966644	29151	2	1D
0005432966661	29151	3	1F
0005432966660	29151	4	2A
0005433679746	29151	5	2D
0005432966653	29151	6	3A
0005432966643	29151	7	3C
0005433679723	29151	8	3D
0005432966639	29151	9	3F
0005432966652	29151	10	4C
0005432966655	29151	11	4E
0005433679734	29151	12	5C
0005432005183	29151	13	5D
0005433679791	29151	14	5F
0005432966640	29151	15	6A
0005433679762	29151	16	6C
0005433679745	29151	17	7D
0005432966659	29151	18	7E
0005432966636	29151	19	8A
0005432966642	29151	20	8C
0005432966641	29151	21	8E
0005432966646	29151	22	9A
0005433679735	29151	23	9C
0005432966662	29151	24	9D
0005433679755	29151	25	9F
0005432966657	29151	26	10C
0005433679744	29151	27	10E
0005432966638	29151	28	11A
0005433679736	29151	29	11D
0005432966648	29151	30	12C
0005432966650	29151	31	12F
0005432966645	29151	32	13C
0005432966651	29151	33	13F
0005433679826	29151	34	14C
0005433679756	29151	35	14D
0005433679757	29151	36	14E
0005432966654	29151	37	15C
0005433679844	29151	38	15D
0005433684389	29151	39	15F
0005433679716	29151	40	16A
0005432005180	29151	41	16C
0005432966658	29151	42	16E
0005433679843	29151	43	16F
0005432966647	29151	44	17A
0005433679722	29151	45	17D
0005433679852	29151	46	18A
0005433679754	29151	47	18F
0005432005181	29151	48	19D
0005433679803	29151	49	19E
0005432005182	29151	50	20A
0005432966637	29151	51	20C
0005432966649	29151	52	20D
0005432966656	29151	53	20E
0005433577657	9328	1	1C
0005433633389	9328	2	1A
0005433613824	9328	3	1F
0005433633412	9328	4	1D
0005433613794	9328	5	2C
0005433577644	9328	6	2F
0005433613809	9328	7	2D
0005433613781	9328	8	3A
0005433613802	9328	9	3D
0005433613828	9328	10	4A
0005433613821	9328	11	3F
0005433633402	9328	12	4F
0005433633411	9328	13	4D
0005433633398	9328	14	5A
0005433613810	9328	15	5C
0005432756809	9328	16	6A
0005433633401	9328	17	5F
0005432755036	9328	18	6C
0005433633397	9328	19	6F
0005433633406	9328	20	6D
0005433613769	9328	21	7D
0005433633419	9328	22	7C
0005433613811	9328	23	8A
0005433613831	9328	24	7F
0005432145086	9328	25	8C
0005433613779	9328	26	8B
0005433613806	9328	27	8E
0005433613804	9328	28	9B
0005433577653	9328	29	9D
0005433613774	9328	30	9E
0005433633414	9328	31	10B
0005433613782	9328	32	10C
0005433613787	9328	33	10D
0005433613826	9328	34	11B
0005433633400	9328	35	11A
0005433613788	9328	36	11C
0005433633399	9328	37	11D
0005433613815	9328	38	12A
0005433613796	9328	39	12C
0005433633421	9328	40	12B
0005433633407	9328	41	12D
0005433577656	9328	42	12E
0005433613833	9328	43	13A
0005433613814	9328	44	13C
0005433613797	9328	45	13B
0005432145087	9328	46	13D
0005433633420	9328	47	13F
0005433613784	9328	48	13E
0005433613813	9328	49	14A
0005434163473	9328	50	14B
0005432755035	9328	51	14C
0005433613827	9328	52	14E
0005433613798	9328	53	14F
0005433577650	9328	54	15A
0005433633388	9328	55	15C
0005433633405	9328	56	15D
0005433613834	9328	57	15F
0005434163472	9328	58	16A
0005433613808	9328	59	16C
0005433633403	9328	60	16B
0005433613770	9328	61	16D
0005433633404	9328	62	16E
0005433577652	9328	63	16F
0005433613767	9328	64	17B
0005433613762	9328	65	17D
0005433613818	9328	66	17F
0005433613792	9328	67	17E
0005433633418	9328	68	18B
0005433613790	9328	69	18C
0005433613807	9328	70	18E
0005433613822	9328	71	19B
0005433613800	9328	72	18F
0005432756808	9328	73	19C
0005433613799	9328	74	19D
0005433613832	9328	75	19E
0005433577658	9328	76	20A
0005433613829	9328	77	20C
0005433613778	9328	78	20E
0005434163459	9328	79	20D
0005433633417	9328	80	20F
0005433613819	9328	81	21A
0005433613771	9328	82	21C
0005433613791	9328	83	21B
0005433613820	9328	84	21D
0005432756810	9328	85	21E
0005433577647	9328	86	22A
0005433613823	9328	87	21F
0005433613805	9328	88	22B
0005433613775	9328	89	22C
0005433613765	9328	90	22E
0005433613766	9328	91	22D
0005433613761	9328	92	22F
0005433577645	9328	93	23A
0005433633396	9328	94	23B
0005433577651	9328	95	23D
0005432755037	9328	96	23C
0005433613803	9328	97	23E
0005433613776	9328	98	24B
0005433613764	9328	99	24A
0005433613785	9328	100	24C
0005433633390	9328	101	24E
0005433613789	9328	102	24D
0005433613763	9328	103	25A
0005433613825	9328	104	25C
0005433613772	9328	105	25B
0005433633408	9328	106	25D
0005433577654	9328	107	25E
0005432755038	9328	108	25F
0005433577646	9328	109	26D
0005433613816	9328	110	26C
0005433633416	9328	111	26E
0005433613812	9328	112	26F
0005433633410	9328	113	27B
0005433633395	9328	114	27C
0005433633413	9328	115	27D
0005433613773	9328	116	27E
0005433613801	9328	117	28A
0005433577649	9328	118	28B
0005433633415	9328	119	28C
0005433613777	9328	120	28E
0005433633391	9328	121	28F
0005433577648	9328	122	29B
0005433613830	9328	123	29A
0005433633392	9328	124	29C
0005433633393	9328	125	29D
0005433577655	9328	126	29E
0005433613783	9328	127	29F
0005433613793	9328	128	30A
0005433613786	9328	129	30E
0005433613795	9328	130	31A
0005433613817	9328	131	30F
0005433577643	9328	132	31C
0005433613768	9328	133	31B
0005433613780	9328	134	31D
0005433633394	9328	135	31F
0005433633409	9328	136	31E
0005434163524	25220	1	3C
0005434163521	25220	2	3D
0005433613398	25220	3	5C
0005433633246	25220	4	5F
0005434272173	25220	5	5D
0005433633213	25220	6	6D
0005433633233	25220	7	8A
0005434163516	25220	8	8B
0005433613424	25220	9	8C
0005434163517	25220	10	9E
0005433633215	25220	11	10F
0005434163519	25220	12	11A
0005433577565	25220	13	12B
0005433633214	25220	14	12F
0005433577571	25220	15	13A
0005433577572	25220	16	16A
0005433613439	25220	17	16C
0005434273058	25220	18	16E
0005434163523	25220	19	16F
0005433613452	25220	20	17D
0005433613520	25220	21	18F
0005433633232	25220	22	19D
0005434273057	25220	23	20B
0005433613451	25220	24	21B
0005434163515	25220	25	21A
0005434163522	25220	26	21C
0005434163520	25220	27	22D
0005434163518	25220	28	22E
0005434272172	25220	29	23A
0005433577579	25220	30	23B
0005433613490	25220	31	24B
0005433577566	25220	32	28C
0005434163514	25220	33	28F
0005433577573	25220	34	29E
0005433613397	25220	35	29D
0005433613459	25220	36	31D
0005435986683	4219	1	1F
0005435947012	4219	2	4C
0005435986691	4219	3	4F
0005432184919	4219	4	5A
0005435947007	4219	5	12G
0005435986692	4219	6	14E
0005435986689	4219	7	14G
0005435986693	4219	8	15H
0005432184917	4219	9	18D
0005435947021	4219	10	19F
0005435947022	4219	11	22B
0005435986690	4219	12	24F
0005432184918	4219	13	27B
0005435986685	4219	14	27D
0005435986688	4219	15	30A
0005435986686	4219	16	30E
0005435986684	4219	17	31E
0005435947020	4219	18	31G
0005432184920	4219	19	32D
0005435986687	4219	20	35B
0005435946996	4219	21	38B
0005435947095	26616	1	1A
0005432571280	26616	2	2B
0005435947099	26616	3	2H
0005435787331	26616	4	4C
0005435947092	26616	5	4F
0005435856157	26616	6	9B
0005435947093	26616	7	11D
0005432571283	26616	8	11B
0005435947090	26616	9	12G
0005435947101	26616	10	13D
0005435947089	26616	11	14F
0005435947098	26616	12	15F
0005435787330	26616	13	18F
0005435856155	26616	14	18E
0005435947094	26616	15	18G
0005435947086	26616	16	19A
0005435947096	26616	17	22E
0005435856156	26616	18	23B
0005435947088	26616	19	23A
0005432571281	26616	20	24A
0005435947097	26616	21	28H
0005435856158	26616	22	32E
0005435947091	26616	23	32H
0005435856159	26616	24	35D
0005435947087	26616	25	35G
0005432571282	26616	26	36D
0005435947100	26616	27	39F
0005433074199	333	1	1C
0005433568396	333	2	1F
0005432947774	333	3	2A
0005433568402	333	4	3C
0005433568414	333	5	3D
0005433568415	333	6	4C
0005433568411	333	7	5A
0005433568397	333	8	5F
0005432947773	333	9	6C
0005433568419	333	10	6D
0005432238870	333	11	6F
0005433568391	333	12	7C
0005433568385	333	13	8A
0005433568420	333	14	8C
0005433134057	333	15	8F
0005433568390	333	16	9C
0005433074201	333	17	9D
0005433568379	333	18	10B
0005433074234	333	19	10E
0005433568413	333	20	11C
0005433568410	333	21	12A
0005433568386	333	22	11F
0005433074210	333	23	12D
0005433568412	333	24	12E
0005433568406	333	25	13B
0005432947826	333	26	13D
0005432238868	333	27	13F
0005433568388	333	28	14A
0005433568375	333	29	14E
0005433568404	333	30	14F
0005433568374	333	31	15D
0005433568376	333	32	15F
0005432238867	333	33	15E
0005433568398	333	34	16C
0005433568381	333	35	16E
0005432238866	333	36	16D
0005433568399	333	37	16F
0005433568403	333	38	17C
0005433568382	333	39	17F
0005433568408	333	40	18D
0005433568416	333	41	18C
0005432238864	333	42	20C
0005433568394	333	43	20D
0005432947798	333	44	21A
0005433074200	333	45	21B
0005432238865	333	46	21E
0005433568383	333	47	22A
0005433568407	333	48	22D
0005433074205	333	49	22F
0005432238869	333	50	23B
0005433568417	333	51	23D
0005433568409	333	52	23C
0005433568378	333	53	23E
0005432947812	333	54	23F
0005433568387	333	55	24B
0005433568389	333	56	24D
0005433568422	333	57	24E
0005432947830	333	58	25A
0005433568421	333	59	25D
0005433568384	333	60	26C
0005433568377	333	61	26F
0005433074238	333	62	27B
0005433568392	333	63	27A
0005433568400	333	64	28C
0005433568405	333	65	29A
0005433568393	333	66	29C
0005433568401	333	67	29F
0005433568418	333	68	29E
0005433568380	333	69	31B
0005433568395	333	70	31C
0005432948005	11592	1	1D
0005433131658	11592	2	2A
0005432948010	11592	3	2F
0005433074379	11592	4	2D
0005433074381	11592	5	3D
0005433074377	11592	6	3C
0005432948012	11592	7	3F
0005432948000	11592	8	4A
0005433131657	11592	9	4D
0005433074380	11592	10	4F
0005432947972	11592	11	5A
0005432947997	11592	12	5D
0005433074397	11592	13	5C
0005433074395	11592	14	5F
0005433074387	11592	15	6A
0005433074376	11592	16	7A
0005432947976	11592	17	7C
0005433074386	11592	18	7D
0005433131655	11592	19	8D
0005433074378	11592	20	8C
0005433134086	11592	21	8E
0005432192283	11592	22	9B
0005433131656	11592	23	9A
0005433074382	11592	24	9C
0005433074385	11592	25	9D
0005432947992	11592	26	10D
0005433074383	11592	27	10C
0005433074372	11592	28	10F
0005433131659	11592	29	11A
0005432948004	11592	30	11E
0005432947981	11592	31	12A
0005432192285	11592	32	11F
0005433074394	11592	33	12C
0005432947988	11592	34	13E
0005432947998	11592	35	14A
0005432947983	11592	36	14C
0005432947973	11592	37	15A
0005432947996	11592	38	15F
0005432947993	11592	39	15E
0005433134088	11592	40	16A
0005433074393	11592	41	16B
0005432948001	11592	42	16D
0005433074389	11592	43	16C
0005433074388	11592	44	16E
0005433074371	11592	45	17B
0005433131654	11592	46	17D
0005432947989	11592	47	17E
0005433074400	11592	48	18A
0005432947975	11592	49	18C
0005432947974	11592	50	18B
0005433074391	11592	51	18F
0005432947987	11592	52	19B
0005433134085	11592	53	19D
0005433074392	11592	54	19E
0005432948003	11592	55	20B
0005432947982	11592	56	20D
0005432947991	11592	57	21C
0005433074398	11592	58	21D
0005432192284	11592	59	22C
0005432948006	11592	60	22F
0005432947990	11592	61	22E
0005433074374	11592	62	23B
0005433074384	11592	63	24A
0005432947985	11592	64	24D
0005433074399	11592	65	24C
0005432947986	11592	66	24E
0005433074375	11592	67	24F
0005433074390	11592	68	25B
0005432947977	11592	69	25D
0005432947984	11592	70	25C
0005433074373	11592	71	25E
0005432948007	11592	72	26A
0005432947980	11592	73	26E
0005432948008	11592	74	27A
0005433134087	11592	75	27E
0005432947978	11592	76	28A
0005432947995	11592	77	28D
0005432947979	11592	78	28E
0005433134084	11592	79	29C
0005432948002	11592	80	29F
0005432948011	11592	81	30A
0005432947994	11592	82	30B
0005432947999	11592	83	31C
0005432948009	11592	84	31D
0005433074396	11592	85	31E
0005433817428	10051	1	1A
0005433817427	10051	2	1B
0005433817429	10051	3	5A
0005433817430	10051	4	6A
0005434732942	14007	1	2A
0005434732940	14007	2	2B
0005433817404	14007	3	3B
0005434732943	14007	4	4A
0005434732944	14007	5	6A
0005434732941	14007	6	6B
0005432655408	2331	1	1F
0005432984529	2331	2	1C
0005432655407	2331	3	2A
0005432984541	2331	4	2F
0005435981821	2331	5	2C
0005433753580	2331	6	2H
0005432225990	2331	7	2G
0005433753573	2331	8	3A
0005432300196	2331	9	3C
0005433766598	2331	10	3G
0005433753577	2331	11	3F
0005432655405	2331	12	4A
0005433753604	2331	13	4C
0005435981810	2331	14	4F
0005433753582	2331	15	5B
0005432300198	2331	16	5A
0005433753598	2331	17	5G
0005433753591	2331	18	5F
0005435981794	2331	19	5H
0005433753578	2331	20	11A
0005432869431	2331	21	9H
0005433766596	2331	22	11B
0005433753583	2331	23	11D
0005435981827	2331	24	11F
0005435981825	2331	25	11G
0005433753612	2331	26	12B
0005433753587	2331	27	12A
0005433753599	2331	28	11H
0005435981803	2331	29	12D
0005435981824	2331	30	12E
0005435981800	2331	31	12H
0005433753568	2331	32	12G
0005435981840	2331	33	13D
0005432300197	2331	34	13B
0005435981809	2331	35	13F
0005435981811	2331	36	13E
0005435981828	2331	37	13H
0005432300201	2331	38	13G
0005433764655	2331	39	14B
0005432869416	2331	40	14D
0005432984528	2331	41	14F
0005435981830	2331	42	15B
0005433753608	2331	43	15A
0005435981795	2331	44	15E
0005432655400	2331	45	15G
0005433753605	2331	46	16A
0005433753588	2331	47	16D
0005433753581	2331	48	16B
0005433753593	2331	49	16E
0005435981813	2331	50	16F
0005432225988	2331	51	16H
0005435981820	2331	52	16G
0005435981798	2331	53	17A
0005435981806	2331	54	17B
0005435981831	2331	55	17F
0005435981797	2331	56	17E
0005435981823	2331	57	17G
0005433753601	2331	58	17H
0005433753619	2331	59	18B
0005433766595	2331	60	18A
0005432655406	2331	61	18D
0005433753618	2331	62	18F
0005432655404	2331	63	18E
0005433753590	2331	64	18G
0005432225984	2331	65	19D
0005435981822	2331	66	19F
0005432984563	2331	67	19E
0005433753607	2331	68	20A
0005433753584	2331	69	20E
0005435981829	2331	70	20D
0005435981832	2331	71	20F
0005433753616	2331	72	20G
0005435981838	2331	73	21A
0005435981812	2331	74	20H
0005435981804	2331	75	21D
0005433764656	2331	76	21B
0005435981817	2331	77	21E
0005435981818	2331	78	21G
0005433753585	2331	79	21F
0005432225989	2331	80	21H
0005433753571	2331	81	22A
0005433753606	2331	82	22D
0005433753602	2331	83	22F
0005435981799	2331	84	22E
0005435981837	2331	85	22G
0005435981819	2331	86	23A
0005435981815	2331	87	23D
0005433753574	2331	88	23F
0005433753579	2331	89	23E
0005435981814	2331	90	23H
0005433753570	2331	91	24B
0005435981836	2331	92	24D
0005432300199	2331	93	24F
0005435981826	2331	94	24G
0005433753576	2331	95	25D
0005435981796	2331	96	25F
0005435981789	2331	97	25E
0005433434193	2331	98	27D
0005432300202	2331	99	27B
0005432225985	2331	100	27E
0005433766597	2331	101	27G
0005433753617	2331	102	27F
0005433753613	2331	103	27H
0005433753609	2331	104	28A
0005433753621	2331	105	28D
0005435981833	2331	106	28B
0005435981816	2331	107	28F
0005433753592	2331	108	28G
0005433753611	2331	109	29A
0005432225986	2331	110	29B
0005433753603	2331	111	29E
0005432984523	2331	112	30A
0005435981793	2331	113	30D
0005435981808	2331	114	30B
0005435981841	2331	115	30F
0005435981802	2331	116	30G
0005432655403	2331	117	30H
0005432984531	2331	118	31A
0005435981790	2331	119	31D
0005435981805	2331	120	31E
0005433753597	2331	121	32A
0005433753595	2331	122	32D
0005435981807	2331	123	32F
0005433753615	2331	124	32G
0005432300200	2331	125	33B
0005432655410	2331	126	33A
0005432984589	2331	127	32H
0005433753622	2331	128	33E
0005432655402	2331	129	33G
0005433753572	2331	130	34B
0005433764657	2331	131	34D
0005433753589	2331	132	34E
0005433753586	2331	133	34F
0005433753596	2331	134	34H
0005435981801	2331	135	35B
0005435981835	2331	136	36A
0005435981839	2331	137	36D
0005432869415	2331	138	36F
0005433753575	2331	139	36G
0005435981791	2331	140	36H
0005433753614	2331	141	37D
0005435981834	2331	142	37E
0005433753620	2331	143	37F
0005433753600	2331	144	37H
0005433753594	2331	145	38A
0005433753610	2331	146	38D
0005432225987	2331	147	38E
0005433753569	2331	148	38F
0005432655401	2331	149	38H
0005432655409	2331	150	39E
0005435981792	2331	151	39D
0005433753623	2331	152	39F
0005432984707	26183	1	1B
0005433434368	26183	2	1F
0005433434355	26183	3	2C
0005433753446	26183	4	2F
0005432984724	26183	5	3C
0005433434354	26183	6	3F
0005432984721	26183	7	4A
0005432984715	26183	8	4C
0005433434359	26183	9	4F
0005433434377	26183	10	5A
0005432984706	26183	11	4H
0005434731124	26183	12	5C
0005432984711	26183	13	9A
0005433434371	26183	14	11A
0005432869450	26183	15	11E
0005432051094	26183	16	11D
0005433753264	26183	17	11F
0005432049425	26183	18	11H
0005433753390	26183	19	12A
0005432984703	26183	20	12D
0005433753275	26183	21	12E
0005433434370	26183	22	13B
0005432984709	26183	23	13A
0005432984728	26183	24	13E
0005433434378	26183	25	13F
0005433434379	26183	26	14A
0005433434366	26183	27	14B
0005432984725	26183	28	14E
0005432051093	26183	29	14G
0005432869446	26183	30	15A
0005432984705	26183	31	15B
0005433434357	26183	32	15G
0005432984729	26183	33	15F
0005432984708	26183	34	15E
0005435981565	26183	35	15H
0005433434362	26183	36	16F
0005433753274	26183	37	17B
0005432984714	26183	38	18A
0005433434374	26183	39	19A
0005433753265	26183	40	19D
0005432869449	26183	41	19E
0005433434373	26183	42	19H
0005432869448	26183	43	20A
0005432984731	26183	44	20E
0005432984730	26183	45	20D
0005432984719	26183	46	20F
0005433434361	26183	47	20G
0005432984701	26183	48	21D
0005433753288	26183	49	21F
0005432984713	26183	50	22E
0005433434376	26183	51	22G
0005432049422	26183	52	23E
0005433434369	26183	53	23F
0005432984723	26183	54	24A
0005433753276	26183	55	24H
0005432984704	26183	56	25D
0005432984726	26183	57	27B
0005433434375	26183	58	28A
0005433434364	26183	59	28D
0005432984710	26183	60	28E
0005432869447	26183	61	29B
0005432051092	26183	62	29F
0005432049423	26183	63	29H
0005433753230	26183	64	30B
0005432984716	26183	65	30F
0005433434358	26183	66	31A
0005432984722	26183	67	31D
0005432984717	26183	68	31E
0005432984699	26183	69	31G
0005433434360	26183	70	32D
0005433434380	26183	71	33B
0005433753391	26183	72	34F
0005433753393	26183	73	34G
0005432984720	26183	74	34H
0005432984702	26183	75	35B
0005432984700	26183	76	35F
0005432984718	26183	77	35H
0005432049424	26183	78	36B
0005432984712	26183	79	36E
0005433434372	26183	80	36F
0005433434365	26183	81	37F
0005433434356	26183	82	37H
0005434731122	26183	83	37G
0005433434363	26183	84	38E
0005433434367	26183	85	38D
0005434731125	26183	86	38F
0005434731123	26183	87	38H
0005432984727	26183	88	39D
0005435981533	26183	89	39F
0005433150819	1510	1	1D
0005432267819	1510	2	3A
0005434374124	1510	3	3D
0005434374150	1510	4	3F
0005432267817	1510	5	4E
0005434374132	1510	6	5B
0005433460411	1510	7	5C
0005432267822	1510	8	5E
0005433461564	1510	9	5F
0005434374146	1510	10	6B
0005434374154	1510	11	6E
0005434374138	1510	12	7B
0005433150896	1510	13	7C
0005433150812	1510	14	8A
0005432267824	1510	15	8D
0005433461563	1510	16	9C
0005434374131	1510	17	9E
0005434374139	1510	18	9F
0005434374130	1510	19	10E
0005433150813	1510	20	11D
0005434374126	1510	21	11C
0005433460412	1510	22	11F
0005434374143	1510	23	12A
0005433150814	1510	24	12E
0005434374151	1510	25	13A
0005433150811	1510	26	12F
0005434374133	1510	27	13B
0005434374141	1510	28	13D
0005432267818	1510	29	14A
0005434374144	1510	30	14C
0005434374152	1510	31	14E
0005434374135	1510	32	14F
0005434374149	1510	33	15C
0005434374153	1510	34	15D
0005434374134	1510	35	15F
0005434374157	1510	36	16B
0005434374140	1510	37	16A
0005433764644	1510	38	16C
0005434374156	1510	39	16D
0005432267821	1510	40	17B
0005434374136	1510	41	17C
0005432267823	1510	42	17F
0005434374142	1510	43	18A
0005434374145	1510	44	18F
0005434374137	1510	45	19A
0005434374148	1510	46	19C
0005434374128	1510	47	19F
0005434374125	1510	48	20B
0005433150799	1510	49	20D
0005433150853	1510	50	21B
0005433150798	1510	51	21F
0005433150820	1510	52	22C
0005434374155	1510	53	22D
0005434374147	1510	54	22E
0005432267820	1510	55	23A
0005434374129	1510	56	23B
0005434374127	1510	57	23E
0005433151019	20161	1	1A
0005432056254	20161	2	1C
0005433151028	20161	3	2C
0005433151006	20161	4	2F
0005433151025	20161	5	3C
0005433151016	20161	6	3A
0005433151034	20161	7	4B
0005434373890	20161	8	4F
0005433151027	20161	9	5A
0005433151026	20161	10	5B
0005433764656	20161	11	5D
0005433151024	20161	12	5C
0005433151038	20161	13	6A
0005434029628	20161	14	5F
0005433151007	20161	15	6C
0005434373968	20161	16	6E
0005433151031	20161	17	6F
0005434029627	20161	18	7B
0005433151023	20161	19	7D
0005433931432	20161	20	7F
0005434373876	20161	21	8A
0005434373914	20161	22	8B
0005433764655	20161	23	8C
0005433151021	20161	24	8E
0005433931431	20161	25	9A
0005434373859	20161	26	9C
0005433151030	20161	27	9B
0005434373878	20161	28	9D
0005432056255	20161	29	10D
0005434373854	20161	30	10E
0005433151020	20161	31	11D
0005434373881	20161	32	12B
0005434373877	20161	33	12F
0005433151014	20161	34	13A
0005433151035	20161	35	13C
0005434373882	20161	36	13E
0005434373864	20161	37	14B
0005433151009	20161	38	14A
0005433931430	20161	39	14C
0005434373872	20161	40	14D
0005434373865	20161	41	14E
0005434373915	20161	42	15A
0005433151015	20161	43	15D
0005432056256	20161	44	15C
0005433151037	20161	45	16A
0005433151013	20161	46	16C
0005433151018	20161	47	16D
0005433151032	20161	48	17D
0005433151022	20161	49	17F
0005433151008	20161	50	18A
0005433151029	20161	51	18F
0005432056257	20161	52	19A
0005434373860	20161	53	19C
0005433151011	20161	54	19D
0005434373871	20161	55	19F
0005433151012	20161	56	20B
0005433764657	20161	57	21B
0005433151005	20161	58	21A
0005433151010	20161	59	21C
0005434373852	20161	60	21D
0005434029629	20161	61	22B
0005433151033	20161	62	22D
0005433151036	20161	63	22E
0005433151017	20161	64	23F
0005432423935	595	1	1F
0005432423943	595	2	1D
0005432423936	595	3	2A
0005432423934	595	4	2C
0005432423951	595	5	2F
0005432423948	595	6	3A
0005432423946	595	7	3D
0005432423914	595	8	4F
0005432423932	595	9	5A
0005432423912	595	10	6F
0005432423922	595	11	7C
0005432423913	595	12	8D
0005432423945	595	13	8C
0005432282788	595	14	10C
0005432423954	595	15	11A
0005432423931	595	16	11B
0005432423942	595	17	11E
0005432423955	595	18	11D
0005432423926	595	19	12A
0005432423927	595	20	12B
0005432423938	595	21	12C
0005432423920	595	22	13B
0005432423925	595	23	13E
0005432282784	595	24	13D
0005432423953	595	25	14B
0005432282786	595	26	14E
0005432423947	595	27	14F
0005432423944	595	28	15C
0005432423916	595	29	15F
0005432423940	595	30	16A
0005432282783	595	31	16C
0005432423924	595	32	16E
0005432423919	595	33	17A
0005432423921	595	34	17D
0005432423939	595	35	18F
0005432423933	595	36	19C
0005432423950	595	37	19E
0005432282785	595	38	20D
0005432423917	595	39	21A
0005432423949	595	40	22F
0005432423930	595	41	23A
0005432423941	595	42	23E
0005432423918	595	43	24E
0005432423915	595	44	25C
0005432423952	595	45	26A
0005432423928	595	46	26B
0005432423910	595	47	27C
0005432423937	595	48	28A
0005432423929	595	49	28D
0005432423911	595	50	29C
0005432282787	595	51	29D
0005432282782	595	52	31E
0005432423923	595	53	31F
0005432302289	12943	1	6C
0005432302290	12943	2	10C
0005432302288	12943	3	20D
0005432302287	12943	4	27B
0005434022966	451	1	1A
0005434022983	451	2	1B
0005434022924	451	3	1F
0005432235555	451	4	2B
0005433057221	451	5	2F
0005433057177	451	6	2C
0005432235556	451	7	3B
0005434022925	451	8	3G
0005434022984	451	9	3F
0005434028261	451	10	4C
0005434022975	451	11	4H
0005433057202	451	12	5A
0005434022927	451	13	5G
0005434022954	451	14	5F
0005434022958	451	15	5H
0005434022940	451	16	11A
0005434022973	451	17	9H
0005434022937	451	18	11E
0005433057246	451	19	12D
0005434022957	451	20	12G
0005434022935	451	21	12F
0005434022959	451	22	13D
0005434022976	451	23	13B
0005434022938	451	24	13E
0005433057271	451	25	13G
0005433057314	451	26	14E
0005433057212	451	27	15A
0005434022930	451	28	15E
0005434022961	451	29	15H
0005434022956	451	30	15G
0005434022917	451	31	16D
0005434022943	451	32	16E
0005434022932	451	33	16G
0005434022955	451	34	16F
0005434022971	451	35	17A
0005433057188	451	36	17D
0005434022918	451	37	17E
0005434022941	451	38	18B
0005434022977	451	39	18F
0005434022962	451	40	18E
0005432235554	451	41	18G
0005434022974	451	42	18H
0005434022985	451	43	19B
0005432235552	451	44	19A
0005434031970	451	45	19E
0005433057295	451	46	19G
0005434022965	451	47	19H
0005434022947	451	48	20B
0005434022921	451	49	20D
0005434022942	451	50	20H
0005432235551	451	51	21B
0005433057179	451	52	21D
0005433057192	451	53	22B
0005433057232	451	54	22E
0005434022969	451	55	22G
0005434022939	451	56	22F
0005434022980	451	57	23E
0005433057222	451	58	23D
0005434022979	451	59	23F
0005432235553	451	60	23G
0005434022949	451	61	24E
0005434022934	451	62	24F
0005434022953	451	63	24G
0005434022952	451	64	24H
0005434029626	451	65	25E
0005432045589	451	66	25D
0005434022923	451	67	27A
0005434028262	451	68	27D
0005433057286	451	69	27B
0005434022936	451	70	27E
0005433057237	451	71	27F
0005434022968	451	72	28A
0005433057267	451	73	28F
0005434031968	451	74	28G
0005434022920	451	75	29D
0005434022928	451	76	29B
0005434022982	451	77	29G
0005434022926	451	78	29F
0005434022951	451	79	29H
0005434022970	451	80	30E
0005434022981	451	81	30G
0005434022946	451	82	31E
0005432045591	451	83	31F
0005434031969	451	84	31H
0005434022931	451	85	31G
0005434022964	451	86	32B
0005434022963	451	87	32E
0005434022945	451	88	32F
0005434022922	451	89	32H
0005434022944	451	90	33A
0005434022919	451	91	33B
0005434022948	451	92	33H
0005433057223	451	93	34B
0005432045590	451	94	34F
0005434022967	451	95	35A
0005434031967	451	96	35B
0005434022929	451	97	35H
0005432235557	451	98	37A
0005434022933	451	99	37B
0005432235550	451	100	37E
0005434022960	451	101	37D
0005434022978	451	102	38B
0005434031971	451	103	37H
0005434022972	451	104	38D
0005434022950	451	105	39E
0005433057421	12691	1	1C
0005433929568	12691	2	3A
0005433057439	12691	3	2H
0005433057431	12691	4	3B
0005433057433	12691	5	3F
0005434031944	12691	6	3G
0005434022604	12691	7	4A
0005433057417	12691	8	4C
0005433057435	12691	9	4H
0005433057437	12691	10	5B
0005433057441	12691	11	5F
0005434022531	12691	12	5G
0005433057428	12691	13	9H
0005434022746	12691	14	11B
0005433057453	12691	15	11F
0005433057430	12691	16	12A
0005433929566	12691	17	12E
0005434735633	12691	18	13F
0005432156316	12691	19	14F
0005433929565	12691	20	14G
0005433057427	12691	21	14H
0005433057422	12691	22	15H
0005433057452	12691	23	16B
0005433057434	12691	24	16E
0005433057448	12691	25	17A
0005434735630	12691	26	17D
0005433057455	12691	27	17H
0005434022640	12691	28	18A
0005433057444	12691	29	18G
0005433057429	12691	30	18H
0005434022602	12691	31	19E
0005433057436	12691	32	20B
0005433057425	12691	33	22B
0005433057416	12691	34	22D
0005434022603	12691	35	22G
0005432157470	12691	36	23A
0005434735629	12691	37	23E
0005434022593	12691	38	23G
0005433057423	12691	39	24D
0005432157469	12691	40	24B
0005434031952	12691	41	27D
0005432156315	12691	42	27G
0005433057443	12691	43	28B
0005433057451	12691	44	28H
0005433057415	12691	45	29B
0005433057432	12691	46	29E
0005433057419	12691	47	29H
0005433057424	12691	48	31F
0005434735634	12691	49	31G
0005433057454	12691	50	31H
0005433057426	12691	51	32B
0005432156317	12691	52	32F
0005432156313	12691	53	33A
0005433929567	12691	54	33D
0005433684398	12691	55	33F
0005433057420	12691	56	34A
0005434735631	12691	57	34D
0005433057445	12691	58	34F
0005433057446	12691	59	34E
0005433057418	12691	60	34G
0005433057447	12691	61	35B
0005432156314	12691	62	35G
0005433057440	12691	63	35F
0005433057450	12691	64	36A
0005434735632	12691	65	36D
0005434022639	12691	66	37A
0005434735635	12691	67	37F
0005433057442	12691	68	37H
0005433057449	12691	69	38D
0005434022517	12691	70	38E
0005434022532	12691	71	38F
0005433684397	12691	72	39E
0005433057438	12691	73	39D
0005433922209	2118	1	1A
0005433922177	2118	2	1B
0005433875360	2118	3	1F
0005433922189	2118	4	1H
0005433922255	2118	5	2A
0005433922225	2118	6	2C
0005433922227	2118	7	2B
0005432231447	2118	8	2F
0005433922206	2118	9	2G
0005433035373	2118	10	3A
0005433922181	2118	11	2H
0005433922268	2118	12	3F
0005433922196	2118	13	3C
0005432231441	2118	14	3G
0005432231440	2118	15	3H
0005433922242	2118	16	4B
0005432231446	2118	17	4F
0005433922186	2118	18	4H
0005433922234	2118	19	5A
0005433922230	2118	20	5B
0005433922223	2118	21	5F
0005433922203	2118	22	9A
0005433922237	2118	23	9H
0005433922263	2118	24	11E
0005433922179	2118	25	11H
0005433922262	2118	26	12A
0005433922210	2118	27	12D
0005433922198	2118	28	12B
0005433922271	2118	29	12E
0005433922253	2118	30	12F
0005433922194	2118	31	12H
0005433922180	2118	32	13B
0005433922249	2118	33	13D
0005433922272	2118	34	13G
0005433035453	2118	35	13F
0005433922260	2118	36	13H
0005433035443	2118	37	14A
0005433922184	2118	38	14D
0005433922188	2118	39	14H
0005432231442	2118	40	15B
0005433922265	2118	41	15A
0005433922214	2118	42	15D
0005433922226	2118	43	15F
0005433035407	2118	44	15H
0005433035382	2118	45	15G
0005433035398	2118	46	16A
0005433922212	2118	47	16D
0005433922183	2118	48	16B
0005433922266	2118	49	16F
0005433922235	2118	50	16H
0005432231445	2118	51	16G
0005433922217	2118	52	17B
0005433922259	2118	53	17A
0005433035381	2118	54	17D
0005433922207	2118	55	17F
0005433922201	2118	56	17E
0005432044493	2118	57	18A
0005433929566	2118	58	17H
0005433922236	2118	59	18B
0005433922251	2118	60	18D
0005433929567	2118	61	18G
0005432044494	2118	62	18F
0005433922213	2118	63	19B
0005433922247	2118	64	19G
0005433922219	2118	65	20A
0005433922243	2118	66	20D
0005433922239	2118	67	20B
0005433922202	2118	68	20E
0005433922205	2118	69	20H
0005433931431	2118	70	21A
0005433922261	2118	71	21E
0005432231443	2118	72	21D
0005433922218	2118	73	21G
0005433922193	2118	74	21F
0005433922250	2118	75	22A
0005433035412	2118	76	22E
0005433922254	2118	77	22H
0005433922252	2118	78	23A
0005433922244	2118	79	23E
0005433922246	2118	80	23F
0005433922238	2118	81	23H
0005433922197	2118	82	24B
0005433922216	2118	83	24F
0005433922248	2118	84	25D
0005433922208	2118	85	24H
0005433922200	2118	86	25E
0005433035384	2118	87	27A
0005433922264	2118	88	25F
0005433931430	2118	89	27F
0005433922222	2118	90	27E
0005433922245	2118	91	27H
0005433922229	2118	92	27G
0005433922228	2118	93	28A
0005433922190	2118	94	28B
0005433922221	2118	95	28D
0005433922215	2118	96	28E
0005433922233	2118	97	28G
0005433931432	2118	98	29B
0005433922176	2118	99	29F
0005432231449	2118	100	29H
0005433922256	2118	101	30A
0005433875361	2118	102	30D
0005433922269	2118	103	30B
0005433922199	2118	104	30E
0005432231444	2118	105	30G
0005433035374	2118	106	30F
0005433035397	2118	107	31A
0005433035361	2118	108	30H
0005432231448	2118	109	31B
0005433922257	2118	110	31D
0005433875362	2118	111	31E
0005433929565	2118	112	32B
0005433922195	2118	113	32E
0005433035396	2118	114	32D
0005433922258	2118	115	32F
0005433922273	2118	116	33A
0005433922274	2118	117	33E
0005433922185	2118	118	33D
0005433035411	2118	119	33H
0005433922204	2118	120	34B
0005433922211	2118	121	34E
0005433922231	2118	122	34F
0005433922178	2118	123	35B
0005433929568	2118	124	35A
0005433035406	2118	125	35G
0005433875363	2118	126	35H
0005433922267	2118	127	36B
0005433922220	2118	128	36D
0005433922270	2118	129	36E
0005433922224	2118	130	36G
0005432044492	2118	131	37B
0005433922241	2118	132	37F
0005433922240	2118	133	37E
0005433922187	2118	134	37H
0005433922191	2118	135	38A
0005433922232	2118	136	38D
0005433922182	2118	137	38B
0005433035388	2118	138	38F
0005433922192	2118	139	39D
0005433035444	2118	140	39F
0005433035686	24085	1	1B
0005433035724	24085	2	1H
0005433931417	24085	3	2B
0005433035707	24085	4	2C
0005433921627	24085	5	3C
0005433035703	24085	6	3B
0005433035708	24085	7	3F
0005433035705	24085	8	4B
0005433035683	24085	9	4A
0005432749761	24085	10	4C
0005433035680	24085	11	4G
0005433035693	24085	12	5B
0005433035706	24085	13	5A
0005433035692	24085	14	5F
0005433035716	24085	15	5C
0005433035727	24085	16	5G
0005433921597	24085	17	5H
0005434028265	24085	18	9B
0005433035702	24085	19	9H
0005434028266	24085	20	11A
0005433921675	24085	21	11B
0005433035699	24085	22	11F
0005433921641	24085	23	12D
0005433035690	24085	24	12B
0005433921800	24085	25	13B
0005433921664	24085	26	13D
0005433035711	24085	27	13F
0005432206129	24085	28	14B
0005432207633	24085	29	14A
0005433035725	24085	30	14E
0005433035691	24085	31	16A
0005433929546	24085	32	16B
0005432749760	24085	33	17A
0005433035715	24085	34	17B
0005433035688	24085	35	17D
0005432206128	24085	36	17F
0005433035696	24085	37	18D
0005433035701	24085	38	18G
0005433035734	24085	39	19A
0005433921663	24085	40	19E
0005433035689	24085	41	19F
0005433035732	24085	42	19H
0005433035684	24085	43	20A
0005433035697	24085	44	20E
0005433035730	24085	45	20G
0005433035710	24085	46	20F
0005433035722	24085	47	20H
0005432207632	24085	48	21A
0005433035698	24085	49	21D
0005432206132	24085	50	21G
0005433035700	24085	51	22B
0005433035729	24085	52	22A
0005433035709	24085	53	22F
0005433035685	24085	54	23B
0005433035731	24085	55	23A
0005432206131	24085	56	23D
0005433035694	24085	57	24D
0005433035723	24085	58	24G
0005433035682	24085	59	25D
0005433035720	24085	60	27A
0005433035712	24085	61	27D
0005433921686	24085	62	27G
0005433035687	24085	63	27F
0005433035726	24085	64	27E
0005434028264	24085	65	28E
0005433921775	24085	66	28D
0005432206130	24085	67	28H
0005433921620	24085	68	28G
0005433921596	24085	69	29A
0005433921674	24085	70	29D
0005433921726	24085	71	30A
0005433035695	24085	72	30G
0005433035721	24085	73	31B
0005434028263	24085	74	31D
0005433035714	24085	75	32E
0005433035718	24085	76	32H
0005433035704	24085	77	33B
0005433035681	24085	78	33E
0005433035717	24085	79	33G
0005433921787	24085	80	33F
0005433035713	24085	81	34A
0005433035719	24085	82	35F
0005433035728	24085	83	36A
0005433035733	24085	84	36H
0005433921701	24085	85	37E
0005433921727	24085	86	39D
0005434550621	266	1	1D
0005432277658	266	2	1A
0005434724074	266	3	1G
0005434724099	266	4	1H
0005434724106	266	5	2D
0005433180670	266	6	3A
0005434724093	266	7	2K
0005434550595	266	8	2H
0005434550600	266	9	3C
0005434724158	266	10	4A
0005434550608	266	11	3K
0005433233309	266	12	4G
0005434550598	266	13	4D
0005434724145	266	14	5A
0005434724104	266	15	4K
0005434550604	266	16	5C
0005434550599	266	17	5H
0005434724105	266	18	5G
0005434724159	266	19	5D
0005434724121	266	20	11A
0005434724065	266	21	5K
0005434550628	266	22	11E
0005432277655	266	23	11C
0005433233213	266	24	11F
0005433180720	266	25	11K
0005434724154	266	26	11H
0005434724155	266	27	11G
0005434724063	266	28	12C
0005434724160	266	29	12E
0005434724087	266	30	12G
0005434724083	266	31	12F
0005434550643	266	32	12K
0005433233189	266	33	12H
0005434550610	266	34	13K
0005434550623	266	35	13G
0005435142421	266	36	14C
0005432277653	266	37	14D
0005434550614	266	38	14G
0005434550613	266	39	14F
0005433233333	266	40	14K
0005434724144	266	41	15C
0005434724056	266	42	15A
0005434724089	266	43	15E
0005434550649	266	44	15H
0005434724090	266	45	15K
0005434724150	266	46	16D
0005434724151	266	47	16C
0005434550619	266	48	16A
0005434731120	266	49	16G
0005434724088	266	50	16F
0005434724077	266	51	16E
0005433233143	266	52	16H
0005434724176	266	53	17A
0005434724149	266	54	17G
0005434550616	266	55	17F
0005434550632	266	56	17K
0005434550645	266	57	18C
0005434724072	266	58	18A
0005434550607	266	59	18E
0005435142431	266	60	18D
0005434724068	266	61	18G
0005434724085	266	62	18F
0005435142418	266	63	18J
0005434724080	266	64	18H
0005434724097	266	65	18K
0005434724117	266	66	19D
0005434724153	266	67	19H
0005434550615	266	68	19K
0005434550639	266	69	19J
0005434724152	266	70	20A
0005434724082	266	71	20G
0005434724157	266	72	20F
0005434724069	266	73	20K
0005432277654	266	74	20J
0005432277661	266	75	20H
0005434302408	266	76	21D
0005434550602	266	77	21C
0005434724101	266	78	21F
0005434550618	266	79	21E
0005433233145	266	80	21J
0005434724118	266	81	21H
0005434724163	266	82	21G
0005434724071	266	83	22A
0005434724073	266	84	21K
0005434550611	266	85	22H
0005434550594	266	86	22F
0005434724136	266	87	22K
0005434550635	266	88	22J
0005434550597	266	89	23B
0005434724161	266	90	23D
0005434724169	266	91	23F
0005434735625	266	92	23E
0005434550612	266	93	23H
0005434724094	266	94	23G
0005435142420	266	95	23K
0005435142425	266	96	24E
0005434724130	266	97	25B
0005434550634	266	98	25A
0005434724129	266	99	24G
0005434550637	266	100	25F
0005434724061	266	101	25D
0005434550622	266	102	25J
0005434724135	266	103	26B
0005434724103	266	104	26D
0005434724067	266	105	26G
0005434550606	266	106	26F
0005433180669	266	107	26K
0005434724115	266	108	27D
0005434724114	266	109	27C
0005434550626	266	110	27B
0005432277663	266	111	27F
0005434550648	266	112	27E
0005433233168	266	113	27J
0005433233188	266	114	27G
0005434724125	266	115	28C
0005434724137	266	116	28D
0005434550640	266	117	28F
0005434550627	266	118	28K
0005434724084	266	119	28H
0005434724128	266	120	29B
0005434724086	266	121	29G
0005434724110	266	122	29H
0005434302409	266	123	29K
0005434724177	266	124	29J
0005432277662	266	125	30B
0005434724172	266	126	30E
0005434550625	266	127	30D
0005433233142	266	128	30G
0005434550631	266	129	30F
0005434724127	266	130	30J
0005434724167	266	131	30H
0005434731119	266	132	31C
0005434550647	266	133	31F
0005434735624	266	134	31E
0005434724100	266	135	31K
0005435142428	266	136	32E
0005432277660	266	137	32D
0005434724102	266	138	32G
0005434550593	266	139	32J
0005434731118	266	140	32H
0005434724111	266	141	33A
0005434724075	266	142	32K
0005434724081	266	143	33D
0005434724140	266	144	33C
0005434550641	266	145	33F
0005434724146	266	146	33E
0005434724076	266	147	33H
0005434724143	266	148	33G
0005435142419	266	149	33K
0005434724131	266	150	33J
0005434724079	266	151	34B
0005434724109	266	152	34E
0005434724055	266	153	34D
0005434724057	266	154	34G
0005433233334	266	155	34F
0005432277659	266	156	34J
0005435142422	266	157	35C
0005433180652	266	158	35B
0005434550642	266	159	35F
0005434724108	266	160	35E
0005434724060	266	161	35H
0005433233326	266	162	35G
0005433180648	266	163	36A
0005434550650	266	164	35J
0005434550629	266	165	36C
0005434724174	266	166	36B
0005434724098	266	167	36F
0005435142423	266	168	36J
0005434550646	266	169	37A
0005433233136	266	170	37C
0005434724092	266	171	37F
0005434550603	266	172	37E
0005434550624	266	173	37J
0005432277664	266	174	37K
0005434724148	266	175	38C
0005434724113	266	176	38B
0005432277656	266	177	38A
0005434724120	266	178	38K
0005434724168	266	179	39B
0005435142429	266	180	39E
0005434302411	266	181	39D
0005434724142	266	182	39H
0005434724070	266	183	39K
0005433180692	266	184	40C
0005434724124	266	185	40B
0005434735626	266	186	40A
0005434724123	266	187	41A
0005434724132	266	188	41D
0005434724054	266	189	41F
0005434724134	266	190	41E
0005434724156	266	191	41J
0005434724139	266	192	41G
0005434724126	266	193	42A
0005435142427	266	194	41K
0005435142430	266	195	42C
0005434724147	266	196	42E
0005434724095	266	197	42D
0005433233094	266	198	42G
0005435142426	266	199	42J
0005434550636	266	200	43B
0005434724175	266	201	43A
0005435142424	266	202	42K
0005434724059	266	203	43C
0005434724133	266	204	43E
0005433180649	266	205	43H
0005434731121	266	206	43G
0005434724112	266	207	44B
0005434724141	266	208	44A
0005434724173	266	209	44E
0005434550633	266	210	44D
0005434724162	266	211	44C
0005434302410	266	212	44J
0005434724096	266	213	44H
0005434724064	266	214	45B
0005434550638	266	215	45A
0005434724062	266	216	44K
0005434724170	266	217	45D
0005434724165	266	218	45K
0005434550620	266	219	45J
0005433180691	266	220	46B
0005434735627	266	221	46E
0005434550605	266	222	46C
0005434724119	266	223	46H
0005433131630	266	224	46K
0005434724091	266	225	47C
0005433233095	266	226	47G
0005434724164	266	227	47F
0005434550644	266	228	47K
0005434724078	266	229	47H
0005434724066	266	230	48E
0005434724166	266	231	48G
0005434724138	266	232	48F
0005434724107	266	233	49A
0005434724171	266	234	48K
0005434731117	266	235	49E
0005434735628	266	236	49C
0005432277652	266	237	49F
0005434724116	266	238	49K
0005434724122	266	239	49H
0005434550609	266	240	49G
0005434550617	266	241	50C
0005434302412	266	242	50A
0005433180721	266	243	50E
0005434550596	266	244	50F
0005434724058	266	245	50H
0005432277657	266	246	51F
0005434550601	266	247	51D
0005434550630	266	248	51G
0005433233491	9845	1	1C
0005433129224	9845	2	1K
0005433233511	9845	3	2G
0005433289767	9845	4	3A
0005433233488	9845	5	3K
0005432199168	9845	6	4C
0005433180827	9845	7	5A
0005433129223	9845	8	5G
0005433180809	9845	9	5K
0005433126794	9845	10	11D
0005433233518	9845	11	11E
0005433233506	9845	12	12E
0005433233528	9845	13	12D
0005433233469	9845	14	12G
0005433233495	9845	15	12F
0005434031973	9845	16	12H
0005433180813	9845	17	13H
0005434723523	9845	18	13G
0005433233483	9845	19	14A
0005433126793	9845	20	14F
0005434723660	9845	21	14K
0005433233505	9845	22	14H
0005433129222	9845	23	14G
0005433233510	9845	24	15A
0005433233473	9845	25	15F
0005434723661	9845	26	15E
0005434735601	9845	27	15H
0005433126792	9845	28	16D
0005433233531	9845	29	16A
0005433766597	9845	30	17C
0005433233494	9845	31	16K
0005433180814	9845	32	17H
0005433233504	9845	33	17E
0005433233485	9845	34	18B
0005434723492	9845	35	18A
0005434550333	9845	36	18J
0005433233529	9845	37	19F
0005433180817	9845	38	19J
0005433180818	9845	39	19G
0005434302382	9845	40	20A
0005433289766	9845	41	20B
0005433233516	9845	42	20E
0005433233475	9845	43	20D
0005433180812	9845	44	20H
0005433113510	9845	45	21A
0005433233512	9845	46	20K
0005433113509	9845	47	21D
0005433180811	9845	48	21H
0005433180806	9845	49	22C
0005433233471	9845	50	22J
0005433766598	9845	51	23B
0005433233482	9845	52	23A
0005433233496	9845	53	23E
0005433233489	9845	54	23C
0005433233497	9845	55	23G
0005434723399	9845	56	23J
0005433233524	9845	57	24D
0005433233522	9845	58	24F
0005432199169	9845	59	25A
0005434723460	9845	60	25C
0005432199166	9845	61	25K
0005433233525	9845	62	26F
0005433233474	9845	63	26J
0005432199172	9845	64	27D
0005433289765	9845	65	27C
0005434723400	9845	66	27H
0005433289762	9845	67	27G
0005433180824	9845	68	27J
0005433180821	9845	69	28J
0005433233484	9845	70	29B
0005433180823	9845	71	29F
0005433233527	9845	72	29G
0005433233530	9845	73	29J
0005433233487	9845	74	30C
0005433233478	9845	75	30H
0005433233520	9845	76	30K
0005433766595	9845	77	31D
0005433233479	9845	78	32A
0005433180805	9845	79	31J
0005433233468	9845	80	32D
0005434723382	9845	81	32F
0005432199170	9845	82	32H
0005433129225	9845	83	33B
0005433233467	9845	84	32K
0005433233493	9845	85	33D
0005433233500	9845	86	33C
0005433233476	9845	87	33G
0005433233519	9845	88	33K
0005433233499	9845	89	34D
0005433233466	9845	90	34F
0005433233507	9845	91	35B
0005433233526	9845	92	35A
0005433233508	9845	93	35C
0005433233498	9845	94	35H
0005433766596	9845	95	35G
0005433180808	9845	96	36A
0005433233486	9845	97	35K
0005434550334	9845	98	36B
0005433233513	9845	99	36E
0005433180825	9845	100	36D
0005433233490	9845	101	36G
0005433180810	9845	102	36J
0005433180803	9845	103	36H
0005434031972	9845	104	37C
0005433180804	9845	105	37G
0005434723482	9845	106	37H
0005434723381	9845	107	38B
0005432199167	9845	108	38J
0005433233481	9845	109	39H
0005433233480	9845	110	40A
0005433233470	9845	111	40H
0005433180807	9845	112	40K
0005433233502	9845	113	40J
0005433129221	9845	114	41H
0005433233523	9845	115	41G
0005433233472	9845	116	41K
0005433289763	9845	117	42C
0005434723449	9845	118	42B
0005434735606	9845	119	42A
0005433233501	9845	120	42E
0005433180826	9845	121	43C
0005434723567	9845	122	43F
0005433233515	9845	123	43E
0005433126791	9845	124	43H
0005433180820	9845	125	43K
0005433233477	9845	126	44C
0005434031975	9845	127	44J
0005433233492	9845	128	45C
0005433180822	9845	129	45F
0005433233514	9845	130	45H
0005434735600	9845	131	46E
0005433180819	9845	132	46D
0005434723543	9845	133	46G
0005433233509	9845	134	46J
0005433180828	9845	135	47C
0005434723544	9845	136	47A
0005434723459	9845	137	48A
0005433180815	9845	138	48K
0005434723638	9845	139	49K
0005432199171	9845	140	49H
0005433233521	9845	141	50C
0005433180816	9845	142	50A
0005433233503	9845	143	50E
0005433233517	9845	144	50K
0005434723335	9845	145	50H
0005434031974	9845	146	51F
0005433289764	9845	147	51D
0005432526573	7726	1	1C
0005432526567	7726	2	1A
0005432537035	7726	3	1G
0005432428891	7726	4	2A
0005432535776	7726	5	1K
0005432526538	7726	6	2C
0005432526549	7726	7	2H
0005432526492	7726	8	2G
0005434066765	7726	9	3A
0005432526522	7726	10	3C
0005432526530	7726	11	3K
0005432537033	7726	12	3G
0005434066736	7726	13	4A
0005432526451	7726	14	4G
0005432428890	7726	15	4K
0005434066763	7726	16	4H
0005434066793	7726	17	5C
0005432069497	7726	18	5H
0005432526480	7726	19	5G
0005434066745	7726	20	5D
0005434066780	7726	21	11A
0005432526477	7726	22	5K
0005432526541	7726	23	11C
0005432526468	7726	24	11G
0005432526461	7726	25	11H
0005432526523	7726	26	12A
0005434066753	7726	27	12G
0005432526532	7726	28	12K
0005432526470	7726	29	13D
0005432526537	7726	30	13C
0005432526478	7726	31	13A
0005432526499	7726	32	13F
0005434066752	7726	33	13E
0005432428889	7726	34	14A
0005434066731	7726	35	13K
0005432526502	7726	36	14D
0005432069493	7726	37	14C
0005432526572	7726	38	14F
0005432526486	7726	39	14E
0005434066787	7726	40	14K
0005434066802	7726	41	15C
0005434066766	7726	42	15A
0005432150109	7726	43	15F
0005432526481	7726	44	15H
0005432526517	7726	45	15K
0005432526473	7726	46	16D
0005432526574	7726	47	16C
0005432150106	7726	48	16F
0005432526509	7726	49	17C
0005432526508	7726	50	17A
0005432526554	7726	51	16K
0005432526561	7726	52	17E
0005432526511	7726	53	17D
0005432150103	7726	54	17G
0005432069492	7726	55	17K
0005432526527	7726	56	17H
0005432526484	7726	57	18B
0005434066771	7726	58	18A
0005432526545	7726	59	18D
0005434066738	7726	60	18C
0005432526465	7726	61	18G
0005434066791	7726	62	18J
0005434066772	7726	63	18H
0005434066774	7726	64	19A
0005434066803	7726	65	19D
0005432069491	7726	66	19E
0005432526565	7726	67	19H
0005434066748	7726	68	19G
0005434066760	7726	69	19K
0005432526495	7726	70	19J
0005434066762	7726	71	20C
0005432069488	7726	72	20B
0005432069490	7726	73	20A
0005432526489	7726	74	20E
0005435212356	7726	75	20D
0005434066730	7726	76	21B
0005434066781	7726	77	21A
0005432069495	7726	78	20K
0005434066732	7726	79	21D
0005432526449	7726	80	21C
0005434066768	7726	81	21F
0005432526442	7726	82	21H
0005432526459	7726	83	21K
0005432526550	7726	84	22B
0005432526516	7726	85	22E
0005432526506	7726	86	22H
0005432526524	7726	87	22G
0005432526564	7726	88	22F
0005432526474	7726	89	22K
0005434066797	7726	90	23A
0005434066743	7726	91	23D
0005432526462	7726	92	23G
0005432150104	7726	93	23F
0005432526444	7726	94	23E
0005432533260	7726	95	24D
0005434066742	7726	96	23K
0005434066755	7726	97	24F
0005434066734	7726	98	24E
0005432526456	7726	99	25A
0005434066795	7726	100	25F
0005432526548	7726	101	25H
0005432526455	7726	102	25G
0005432526475	7726	103	25K
0005434066782	7726	104	25J
0005432526445	7726	105	26E
0005434066733	7726	106	26D
0005432526528	7726	107	26G
0005432526490	7726	108	26J
0005435212418	7726	109	27C
0005434066754	7726	110	27F
0005435212355	7726	111	27H
0005432526535	7726	112	28C
0005434066779	7726	113	28A
0005432526544	7726	114	28D
0005434066784	7726	115	28F
0005432526571	7726	116	28H
0005432526557	7726	117	29A
0005432526546	7726	118	28K
0005434066757	7726	119	29D
0005432526539	7726	120	29F
0005432526488	7726	121	29G
0005432069486	7726	122	29K
0005434066792	7726	123	30B
0005432069487	7726	124	30D
0005434066741	7726	125	30C
0005432526487	7726	126	30G
0005432526514	7726	127	30E
0005432526471	7726	128	30J
0005432526496	7726	129	31A
0005434066777	7726	130	30K
0005434066796	7726	131	31D
0005432526447	7726	132	31C
0005434066790	7726	133	31B
0005432526542	7726	134	31F
0005432526498	7726	135	31E
0005432526507	7726	136	31H
0005432526566	7726	137	31G
0005432526460	7726	138	31K
0005434066799	7726	139	31J
0005432526485	7726	140	32C
0005432526483	7726	141	32B
0005432526526	7726	142	32A
0005432526458	7726	143	32F
0005434066737	7726	144	32K
0005432537034	7726	145	33B
0005432526533	7726	146	33A
0005432526529	7726	147	33D
0005432526512	7726	148	33F
0005432526466	7726	149	33E
0005432526543	7726	150	33J
0005435212383	7726	151	33H
0005432069494	7726	152	33K
0005434066747	7726	153	34B
0005432526547	7726	154	34E
0005435212382	7726	155	34C
0005432526452	7726	156	34G
0005432526560	7726	157	34F
0005432069489	7726	158	34J
0005432526570	7726	159	34H
0005432526493	7726	160	35A
0005434066801	7726	161	35D
0005432533259	7726	162	35C
0005434066750	7726	163	35F
0005434066773	7726	164	35E
0005434066735	7726	165	35H
0005432535778	7726	166	35G
0005432428888	7726	167	35J
0005432526556	7726	168	36C
0005434066756	7726	169	36E
0005432526464	7726	170	36D
0005434066776	7726	171	36H
0005432526450	7726	172	36G
0005432069496	7726	173	36F
0005432526510	7726	174	37B
0005432526559	7726	175	37A
0005435212419	7726	176	37E
0005432526536	7726	177	37D
0005432526555	7726	178	37C
0005432526534	7726	179	37G
0005434066749	7726	180	37K
0005432526482	7726	181	38K
0005432535780	7726	182	38H
0005432526520	7726	183	39A
0005432150108	7726	184	39C
0005432526518	7726	185	39F
0005434066778	7726	186	39E
0005434066767	7726	187	39H
0005432535777	7726	188	39K
0005432526515	7726	189	40B
0005432526504	7726	190	40E
0005432526463	7726	191	40D
0005432526479	7726	192	40G
0005432526454	7726	193	40F
0005434066783	7726	194	40K
0005432069484	7726	195	40J
0005432526467	7726	196	40H
0005434066744	7726	197	41A
0005432526569	7726	198	41D
0005434066764	7726	199	41C
0005432526521	7726	200	41B
0005432526491	7726	201	41G
0005432526453	7726	202	41F
0005432535775	7726	203	41E
0005432526494	7726	204	41J
0005434066761	7726	205	42A
0005432526448	7726	206	42C
0005432537032	7726	207	42B
0005432526513	7726	208	42E
0005432535779	7726	209	42D
0005434066751	7726	210	42H
0005432526503	7726	211	42G
0005432526472	7726	212	42K
0005435212376	7726	213	43D
0005432526441	7726	214	43E
0005432069485	7726	215	43J
0005432526500	7726	216	43H
0005432526476	7726	217	43G
0005435212420	7726	218	44A
0005434066739	7726	219	43K
0005434066759	7726	220	44B
0005434066786	7726	221	44E
0005434066775	7726	222	44D
0005432526568	7726	223	44C
0005432533258	7726	224	44G
0005434066788	7726	225	44F
0005435212348	7726	226	45B
0005432526497	7726	227	45A
0005432526505	7726	228	45D
0005434066785	7726	229	45C
0005434066770	7726	230	45F
0005434066740	7726	231	45H
0005434066794	7726	232	45K
0005432526552	7726	233	45J
0005432526501	7726	234	46B
0005434066746	7726	235	46E
0005434066798	7726	236	46G
0005432150105	7726	237	46K
0005432526563	7726	238	46J
0005435212386	7726	239	46H
0005434066769	7726	240	47A
0005432526540	7726	241	47C
0005434066789	7726	242	48A
0005432526443	7726	243	47H
0005432526553	7726	244	48E
0005432150107	7726	245	49A
0005432526446	7726	246	49D
0005432526562	7726	247	49C
0005432069483	7726	248	49G
0005432526457	7726	249	49F
0005432526525	7726	250	49E
0005432526531	7726	251	49K
0005434066758	7726	252	49H
0005432526519	7726	253	50A
0005432526558	7726	254	50E
0005434066800	7726	255	50G
0005432526469	7726	256	51D
0005432526551	7726	257	51E
0005434343829	5337	1	1C
0005435612466	5337	2	1G
0005435423589	5337	3	2C
0005435612427	5337	4	2A
0005435612393	5337	5	2D
0005435612439	5337	6	3C
0005434343833	5337	7	3K
0005435612479	5337	8	3H
0005432133039	5337	9	3G
0005435612469	5337	10	4G
0005435612443	5337	11	4K
0005435612407	5337	12	4H
0005434573197	5337	13	5C
0005435423599	5337	14	5H
0005435423640	5337	15	11A
0005435612386	5337	16	5K
0005435612412	5337	17	11D
0005435612402	5337	18	11F
0005435097103	5337	19	11E
0005435612434	5337	20	11K
0005432133047	5337	21	12E
0005435612389	5337	22	13C
0005432047506	5337	23	13A
0005434343824	5337	24	13E
0005435612392	5337	25	13K
0005435612476	5337	26	13H
0005432133036	5337	27	14C
0005435612391	5337	28	14A
0005435612461	5337	29	14G
0005435423898	5337	30	14F
0005435555344	5337	31	14E
0005434343837	5337	32	15C
0005435097100	5337	33	15A
0005435423641	5337	34	15E
0005434573188	5337	35	15D
0005434343823	5337	36	15H
0005435612441	5337	37	15G
0005435612374	5337	38	15F
0005434573196	5337	39	16D
0005434343810	5337	40	16F
0005434573200	5337	41	16K
0005435097107	5337	42	16H
0005432133037	5337	43	16G
0005434343822	5337	44	17C
0005435612444	5337	45	17A
0005435612475	5337	46	17E
0005435612463	5337	47	17F
0005434343835	5337	48	17H
0005435612377	5337	49	18D
0005435612426	5337	50	18C
0005435097101	5337	51	18H
0005435555345	5337	52	18G
0005435612387	5337	53	18F
0005435612445	5337	54	18K
0005435612450	5337	55	19A
0005434573194	5337	56	19D
0005432133042	5337	57	19C
0005435612406	5337	58	19B
0005435612471	5337	59	19F
0005435423587	5337	60	19G
0005435423676	5337	61	19J
0005435612373	5337	62	20B
0005434343804	5337	63	20A
0005432133043	5337	64	20F
0005434573195	5337	65	20K
0005435423707	5337	66	20J
0005435612474	5337	67	20H
0005435423595	5337	68	21B
0005435612384	5337	69	21A
0005435612447	5337	70	21F
0005432133045	5337	71	21E
0005435097108	5337	72	21J
0005435612395	5337	73	21H
0005435612423	5337	74	21K
0005435612416	5337	75	22C
0005435612372	5337	76	22E
0005434244456	5337	77	22H
0005432133038	5337	78	23B
0005435423836	5337	79	23A
0005435097109	5337	80	23D
0005435612435	5337	81	23C
0005435612473	5337	82	23F
0005435612418	5337	83	23J
0005435423716	5337	84	23G
0005435555347	5337	85	23K
0005432133044	5337	86	24E
0005435612428	5337	87	25D
0005435612388	5337	88	25C
0005432047508	5337	89	25E
0005435612480	5337	90	26C
0005435423692	5337	91	26D
0005435612456	5337	92	27B
0005435612419	5337	93	27A
0005435612379	5337	94	26K
0005434343834	5337	95	27F
0005435612399	5337	96	27E
0005435612478	5337	97	27D
0005434343802	5337	98	27H
0005435612438	5337	99	27K
0005435490187	5337	100	28A
0005435612378	5337	101	28E
0005435423639	5337	102	28D
0005435612431	5337	103	28G
0005434343807	5337	104	28F
0005435612446	5337	105	28J
0005435612483	5337	106	28H
0005435423843	5337	107	28K
0005434343832	5337	108	29C
0005435612369	5337	109	29B
0005434244484	5337	110	29F
0005434343799	5337	111	29H
0005435612396	5337	112	30A
0005432047507	5337	113	29K
0005435612436	5337	114	29J
0005435423835	5337	115	30C
0005435612432	5337	116	30E
0005435612464	5337	117	30G
0005435612468	5337	118	30K
0005435612459	5337	119	31B
0005435423796	5337	120	31A
0005435612413	5337	121	31C
0005435612437	5337	122	31F
0005435612451	5337	123	31E
0005434343805	5337	124	31H
0005435612403	5337	125	31J
0005435612364	5337	126	32C
0005434343800	5337	127	32E
0005435612465	5337	128	32H
0005435491415	5337	129	32G
0005435612458	5337	130	32F
0005434343820	5337	131	32K
0005435612383	5337	132	32J
0005435612424	5337	133	33B
0005435612400	5337	134	33H
0005434343828	5337	135	33G
0005434343827	5337	136	34A
0005435097105	5337	137	33K
0005434343831	5337	138	34C
0005435423588	5337	139	34B
0005435097104	5337	140	34E
0005435612460	5337	141	34D
0005435612380	5337	142	34G
0005434343801	5337	143	34F
0005435491416	5337	144	35D
0005435423622	5337	145	35C
0005435612452	5337	146	35F
0005435612382	5337	147	35E
0005435612414	5337	148	35J
0005435612454	5337	149	35H
0005435097106	5337	150	36A
0005435612477	5337	151	35K
0005435612370	5337	152	36E
0005435612453	5337	153	36H
0005435612398	5337	154	36K
0005434343808	5337	155	37C
0005434343830	5337	156	37A
0005435612482	5337	157	37F
0005435612401	5337	158	37E
0005434343825	5337	159	37H
0005434343803	5337	160	37G
0005434343818	5337	161	38A
0005435423601	5337	162	37J
0005434573198	5337	163	38C
0005435612420	5337	164	38B
0005434343809	5337	165	38J
0005435612433	5337	166	38H
0005435612410	5337	167	39A
0005435612365	5337	168	38K
0005435423598	5337	169	39C
0005435423631	5337	170	39E
0005435097099	5337	171	39H
0005435423685	5337	172	39G
0005435612404	5337	173	40A
0005434573199	5337	174	39K
0005435612411	5337	175	39J
0005435612472	5337	176	40C
0005435423788	5337	177	40B
0005435423691	5337	178	40E
0005434343836	5337	179	40D
0005435612368	5337	180	40F
0005435612405	5337	181	40H
0005432133041	5337	182	41B
0005435612470	5337	183	41A
0005435612449	5337	184	40K
0005434343813	5337	185	41D
0005435612421	5337	186	41C
0005435612390	5337	187	41F
0005432133046	5337	188	41E
0005435490185	5337	189	41H
0005434573201	5337	190	41G
0005432133040	5337	191	42A
0005435612381	5337	192	41K
0005435612367	5337	193	42C
0005434573191	5337	194	42B
0005434343819	5337	195	42E
0005434343816	5337	196	42H
0005435612408	5337	197	42F
0005435612429	5337	198	42J
0005435612448	5337	199	43A
0005435612481	5337	200	42K
0005434343811	5337	201	43D
0005434343806	5337	202	43C
0005435612366	5337	203	43B
0005435302119	5337	204	43H
0005434343826	5337	205	43K
0005435612455	5337	206	43J
0005435097102	5337	207	44C
0005435612376	5337	208	44F
0005435612430	5337	209	44K
0005435612375	5337	210	44J
0005435612415	5337	211	44H
0005434343814	5337	212	45A
0005435612422	5337	213	45E
0005435612467	5337	214	45D
0005434343821	5337	215	45G
0005435612440	5337	216	45K
0005435612462	5337	217	46B
0005432047509	5337	218	46E
0005435423844	5337	219	46D
0005435319423	5337	220	46G
0005435423576	5337	221	46F
0005434573202	5337	222	46K
0005434573190	5337	223	46J
0005435490186	5337	224	46H
0005435612417	5337	225	47E
0005435612363	5337	226	47D
0005434343812	5337	227	47K
0005434573193	5337	228	48C
0005435612397	5337	229	48A
0005435612442	5337	230	48F
0005435612394	5337	231	48D
0005434343815	5337	232	49A
0005434244473	5337	233	48K
0005435612457	5337	234	49D
0005435612409	5337	235	49C
0005434573192	5337	236	49F
0005435555346	5337	237	49K
0005434343817	5337	238	49H
0005432133048	5337	239	50C
0005435612371	5337	240	50D
0005435612385	5337	241	50H
0005432133035	5337	242	51F
0005434573189	5337	243	51E
0005435612425	5337	244	51G
0005432166864	10926	1	1A
0005435423998	10926	2	1D
0005434244647	10926	3	1K
0005435319476	10926	4	2C
0005434244644	10926	5	2A
0005435424003	10926	6	2G
0005435424034	10926	7	3D
0005435424028	10926	8	3C
0005432363382	10926	9	4C
0005434244655	10926	10	4D
0005432164954	10926	11	5C
0005435380241	10926	12	5D
0005433719102	10926	13	5K
0005435424014	10926	14	11D
0005435424067	10926	15	12E
0005434244649	10926	16	12D
0005435380244	10926	17	12F
0005434244640	10926	18	12H
0005435424016	10926	19	13D
0005435424002	10926	20	13F
0005434244646	10926	21	13E
0005435424051	10926	22	14E
0005434244663	10926	23	14C
0005434244662	10926	24	14K
0005432363377	10926	25	15D
0005434244661	10926	26	16A
0005435424058	10926	27	16C
0005435424022	10926	28	17D
0005435380246	10926	29	17H
0005433719103	10926	30	18B
0005434244660	10926	31	18G
0005435424033	10926	32	18K
0005435424032	10926	33	18H
0005435380240	10926	34	19D
0005432164955	10926	35	19C
0005435424062	10926	36	19F
0005435424063	10926	37	19J
0005435424001	10926	38	19G
0005435319473	10926	39	20A
0005434244656	10926	40	20C
0005435319475	10926	41	21F
0005432840989	10926	42	22E
0005435424040	10926	43	22D
0005434244664	10926	44	22G
0005432164951	10926	45	23E
0005435424054	10926	46	23C
0005435424068	10926	47	23J
0005434656533	10926	48	24D
0005432363380	10926	49	25A
0005435424049	10926	50	25C
0005432164953	10926	51	25F
0005435424048	10926	52	25K
0005435319469	10926	53	25J
0005435424044	10926	54	26D
0005435319471	10926	55	26G
0005434244659	10926	56	27B
0005433719101	10926	57	27A
0005435424007	10926	58	27D
0005435424064	10926	59	27E
0005434244658	10926	60	28B
0005435424018	10926	61	28D
0005432164950	10926	62	28G
0005435424020	10926	63	28F
0005435424008	10926	64	29B
0005435424023	10926	65	29D
0005434244635	10926	66	29J
0005434244651	10926	67	29G
0005434244654	10926	68	29K
0005434244645	10926	69	30B
0005435424065	10926	70	30E
0005435424061	10926	71	30G
0005432164949	10926	72	30F
0005435424017	10926	73	30J
0005434244634	10926	74	30K
0005432166863	10926	75	31E
0005435424042	10926	76	31G
0005435424006	10926	77	32C
0005435424000	10926	78	32D
0005435424005	10926	79	32G
0005435424012	10926	80	33A
0005432840990	10926	81	33C
0005435424015	10926	82	33F
0005435424013	10926	83	33E
0005435424030	10926	84	33H
0005435424025	10926	85	34C
0005435423999	10926	86	34A
0005434244652	10926	87	34G
0005435319468	10926	88	34K
0005435424043	10926	89	35A
0005435319474	10926	90	35E
0005435424024	10926	91	36B
0005435319477	10926	92	36F
0005434244639	10926	93	37B
0005435424036	10926	94	37A
0005435424050	10926	95	37C
0005435424004	10926	96	37J
0005434244642	10926	97	38C
0005435424047	10926	98	38K
0005435424052	10926	99	38J
0005434656532	10926	100	38H
0005435424031	10926	101	39D
0005435380245	10926	102	39C
0005434244637	10926	103	39B
0005432363379	10926	104	39K
0005435424019	10926	105	40C
0005435424037	10926	106	40F
0005435380242	10926	107	40J
0005435424057	10926	108	40K
0005435424041	10926	109	41D
0005432166865	10926	110	41C
0005435424046	10926	111	41G
0005432363378	10926	112	42C
0005432166866	10926	113	42G
0005435424026	10926	114	42F
0005435319470	10926	115	42J
0005434244636	10926	116	42K
0005435319472	10926	117	43C
0005434244653	10926	118	43F
0005435424011	10926	119	44A
0005433719104	10926	120	43K
0005435424029	10926	121	44E
0005434244648	10926	122	44D
0005432164952	10926	123	44J
0005435424066	10926	124	46A
0005435042831	10926	125	46D
0005434244650	10926	126	46G
0005434244657	10926	127	46F
0005435424055	10926	128	46K
0005435424059	10926	129	47D
0005434244641	10926	130	47C
0005435424045	10926	131	48D
0005435424010	10926	132	48C
0005434244638	10926	133	48F
0005435424056	10926	134	49A
0005435424060	10926	135	48K
0005435424021	10926	136	49C
0005435424053	10926	137	49F
0005435424035	10926	138	49H
0005434244643	10926	139	49G
0005435380243	10926	140	50C
0005435424009	10926	141	50E
0005435424038	10926	142	50F
0005432363381	10926	143	50H
0005435042832	10926	144	51F
0005435424027	10926	145	51E
0005435424039	10926	146	51G
0005433633427	3320	1	1A
0005433633455	3320	2	1C
0005432181475	3320	3	1F
0005432181456	3320	4	2A
0005433506963	3320	5	2C
0005432181463	3320	6	2D
0005432181464	3320	7	3A
0005432181466	3320	8	2F
0005433633446	3320	9	3F
0005433633445	3320	10	3D
0005433506980	3320	11	4A
0005432181461	3320	12	4C
0005433633433	3320	13	4D
0005433506978	3320	14	5A
0005433804993	3320	15	5D
0005432458956	3320	16	5C
0005433506969	3320	17	6A
0005433633449	3320	18	6C
0005433804988	3320	19	7A
0005433805001	3320	20	7D
0005433506973	3320	21	7F
0005433633429	3320	22	8B
0005433805000	3320	23	8C
0005433804985	3320	24	8F
0005433506977	3320	25	9B
0005432181470	3320	26	9A
0005433633443	3320	27	9C
0005433804969	3320	28	9D
0005433506961	3320	29	9F
0005433804970	3320	30	9E
0005433633431	3320	31	10B
0005433804973	3320	32	10C
0005433804986	3320	33	10E
0005433506965	3320	34	10D
0005432181471	3320	35	11A
0005433633452	3320	36	11D
0005433633450	3320	37	11C
0005433804978	3320	38	11F
0005433804975	3320	39	12A
0005433506960	3320	40	12B
0005432181468	3320	41	12E
0005433804968	3320	42	12D
0005433633448	3320	43	13A
0005433633425	3320	44	13D
0005433506976	3320	45	13C
0005433633437	3320	46	14A
0005433633423	3320	47	14B
0005433804981	3320	48	14D
0005433633447	3320	49	14C
0005432459007	3320	50	14E
0005433804992	3320	51	14F
0005433804972	3320	52	15B
0005433633426	3320	53	15A
0005432181477	3320	54	15C
0005433804989	3320	55	15D
0005433633434	3320	56	16A
0005432181459	3320	57	16B
0005433804979	3320	58	16E
0005433633428	3320	59	17A
0005433506967	3320	60	16F
0005433506981	3320	61	17B
0005433633430	3320	62	17C
0005433633436	3320	63	17F
0005433506975	3320	64	18A
0005432181476	3320	65	18B
0005433506966	3320	66	18D
0005433506974	3320	67	18E
0005433506959	3320	68	19B
0005433633453	3320	69	18F
0005432459031	3320	70	19D
0005433804996	3320	71	19C
0005433804999	3320	72	20B
0005432181458	3320	73	20C
0005433633441	3320	74	20D
0005433633454	3320	75	20F
0005432181462	3320	76	20E
0005433804991	3320	77	21B
0005433633451	3320	78	21C
0005432181455	3320	79	21E
0005433633442	3320	80	21F
0005433633439	3320	81	22B
0005433804977	3320	82	22C
0005433506962	3320	83	22D
0005433804998	3320	84	22F
0005433804982	3320	85	22E
0005432181472	3320	86	23B
0005433633422	3320	87	23A
0005433633440	3320	88	23D
0005433633438	3320	89	23E
0005432181478	3320	90	24A
0005432459008	3320	91	24B
0005433805002	3320	92	24C
0005433804984	3320	93	24F
0005433805003	3320	94	24E
0005433506971	3320	95	25B
0005433804980	3320	96	25A
0005432181457	3320	97	25D
0005433804994	3320	98	25F
0005432181473	3320	99	26B
0005433633424	3320	100	26D
0005433633456	3320	101	26F
0005433804976	3320	102	27A
0005433633435	3320	103	27C
0005433506968	3320	104	27D
0005433804997	3320	105	27E
0005433506979	3320	106	27F
0005433633444	3320	107	28B
0005433506964	3320	108	28C
0005432181474	3320	109	28E
0005433804995	3320	110	28D
0005433633432	3320	111	29A
0005433506972	3320	112	29C
0005432181467	3320	113	29E
0005433804990	3320	114	29F
0005433804983	3320	115	30B
0005432181469	3320	116	30A
0005433804974	3320	117	30E
0005433506970	3320	118	30D
0005433804987	3320	119	31A
0005432181465	3320	120	30F
0005432181460	3320	121	31C
0005433804971	3320	122	31D
0005432458980	3320	123	31E
0005435884403	3321	1	2F
0005435884377	3321	2	3F
0005435884426	3321	3	4D
0005435884444	3321	4	5F
0005435884384	3321	5	11C
0005435884376	3321	6	16A
0005435884394	3321	7	16B
0005435884574	3321	8	16D
0005435884519	3321	9	18E
0005435884554	3321	10	20B
0005435884518	3321	11	21F
0005435884423	3321	12	22A
0005435884378	3321	13	23B
0005435884566	3321	14	24A
0005435884520	3321	15	25C
0005435884457	3321	16	26A
0005435884395	3321	17	26C
0005435884565	3321	18	29F
0005435884559	3321	19	31F
0005432459325	8170	1	1C
0005435884710	8170	2	1A
0005435884684	8170	3	2A
0005435884676	8170	4	1F
0005432459329	8170	5	2F
0005432459309	8170	6	3C
0005432459326	8170	7	3F
0005432459323	8170	8	4A
0005432042560	8170	9	4D
0005435884706	8170	10	4C
0005435884681	8170	11	5A
0005432459290	8170	12	4F
0005435884704	8170	13	5D
0005432042555	8170	14	6A
0005435884720	8170	15	6C
0005435884713	8170	16	7A
0005433506863	8170	17	7D
0005432459287	8170	18	8A
0005432042553	8170	19	8C
0005435884702	8170	20	8B
0005435884678	8170	21	8E
0005435884715	8170	22	8D
0005435884701	8170	23	9A
0005432459300	8170	24	8F
0005432459296	8170	25	9D
0005435884699	8170	26	9F
0005432459327	8170	27	10B
0005432042556	8170	28	10C
0005432042558	8170	29	11A
0005432459319	8170	30	10F
0005435884682	8170	31	11B
0005432459292	8170	32	11C
0005435884721	8170	33	11E
0005435884695	8170	34	12B
0005432459285	8170	35	12E
0005432042563	8170	36	12F
0005432459310	8170	37	13B
0005435884716	8170	38	13C
0005432459317	8170	39	13D
0005432459298	8170	40	13F
0005435884693	8170	41	14B
0005432459320	8170	42	14D
0005435884677	8170	43	14C
0005432459289	8170	44	14F
0005435884700	8170	45	15B
0005432459308	8170	46	15A
0005432042562	8170	47	15C
0005435884705	8170	48	15D
0005432459291	8170	49	15F
0005432459306	8170	50	15E
0005435884696	8170	51	16A
0005435884714	8170	52	16D
0005432042559	8170	53	16C
0005435884685	8170	54	16F
0005435884712	8170	55	17B
0005432459297	8170	56	17A
0005432459278	8170	57	17E
0005434312296	8170	58	18A
0005432042554	8170	59	18B
0005432459328	8170	60	18D
0005434312297	8170	61	18C
0005432459324	8170	62	18E
0005432042564	8170	63	19B
0005432459315	8170	64	18F
0005432459284	8170	65	19D
0005435884718	8170	66	19E
0005435884711	8170	67	20A
0005432459303	8170	68	20C
0005435884687	8170	69	20E
0005432459288	8170	70	20D
0005435884708	8170	71	20F
0005435884692	8170	72	21B
0005435884683	8170	73	21A
0005435884680	8170	74	21D
0005432459318	8170	75	21C
0005435884709	8170	76	21F
0005435884689	8170	77	21E
0005432459295	8170	78	22A
0005435884679	8170	79	22D
0005435884697	8170	80	22E
0005432459281	8170	81	23A
0005432459307	8170	82	23B
0005435884694	8170	83	23D
0005435884686	8170	84	23E
0005432459302	8170	85	24A
0005435884719	8170	86	23F
0005432459283	8170	87	24B
0005435884703	8170	88	24E
0005432459301	8170	89	24D
0005432459294	8170	90	24F
0005432042565	8170	91	25B
0005432042557	8170	92	25A
0005432042561	8170	93	25D
0005432459313	8170	94	26A
0005433506886	8170	95	26B
0005432459314	8170	96	26E
0005432459322	8170	97	26D
0005435884707	8170	98	27B
0005435884717	8170	99	27A
0005435884688	8170	100	27C
0005432459316	8170	101	27E
0005432459279	8170	102	28A
0005433506869	8170	103	27F
0005435884690	8170	104	28C
0005432459304	8170	105	28E
0005432459305	8170	106	28D
0005432459312	8170	107	28F
0005435884691	8170	108	29A
0005435884698	8170	109	29B
0005432459299	8170	110	29E
0005432459280	8170	111	29F
0005432459293	8170	112	30D
0005432459286	8170	113	30C
0005432459321	8170	114	30E
0005432459282	8170	115	31B
0005432459311	8170	116	31C
0005432042566	8170	117	31D
0005432459277	8170	118	31F
0005433633215	8174	1	1D
0005433633233	8174	2	2D
0005433633246	8174	3	3C
0005433804806	8174	4	9C
0005433804841	8174	5	10B
0005433633214	8174	6	12A
0005433633213	8174	7	16A
0005433633232	8174	8	17C
0005433804790	8174	9	26D
0005433804842	8174	10	28E
0005434183543	8176	1	4C
0005433722145	4625	1	1A
0005433722147	4625	2	1C
0005432382735	4625	3	1D
0005432382763	4625	4	2A
0005432382766	4625	5	2C
0005432382733	4625	6	2D
0005432727797	4625	7	2F
0005432382739	4625	8	3A
0005433453742	4625	9	3F
0005432382753	4625	10	4A
0005432382747	4625	11	4D
0005432727799	4625	12	4F
0005432382765	4625	13	5A
0005433722144	4625	14	5C
0005433722143	4625	15	5E
0005432382738	4625	16	5F
0005432382743	4625	17	6C
0005432727792	4625	18	6D
0005433722142	4625	19	6F
0005432382751	4625	20	7A
0005432727795	4625	21	7C
0005432382727	4625	22	7D
0005432727793	4625	23	7E
0005433722146	4625	24	7F
0005432382730	4625	25	8A
0005432382758	4625	26	8C
0005433453741	4625	27	8D
0005432382731	4625	28	8E
0005432382760	4625	29	8F
0005432382761	4625	30	9D
0005432382752	4625	31	10A
0005433454851	4625	32	10D
0005432382749	4625	33	10E
0005432727803	4625	34	10F
0005433722148	4625	35	11A
0005433722150	4625	36	11C
0005432382764	4625	37	11D
0005432382734	4625	38	12A
0005432382748	4625	39	12D
0005432382742	4625	40	12E
0005433722141	4625	41	12F
0005432382762	4625	42	13A
0005432382757	4625	43	13C
0005433722154	4625	44	13D
0005432382754	4625	45	13E
0005432382755	4625	46	14C
0005432382756	4625	47	14D
0005432382736	4625	48	14E
0005433722151	4625	49	14F
0005432727801	4625	50	15A
0005432382750	4625	51	15C
0005432382741	4625	52	15D
0005433453740	4625	53	15E
0005432382728	4625	54	15F
0005432382740	4625	55	16D
0005432727798	4625	56	16E
0005433722152	4625	57	16F
0005432382744	4625	58	17C
0005432382759	4625	59	17D
0005432727804	4625	60	17F
0005432382746	4625	61	18A
0005433722149	4625	62	18C
0005433722153	4625	63	18D
0005432727796	4625	64	18E
0005432727802	4625	65	19A
0005432382737	4625	66	19C
0005432382745	4625	67	19E
0005432382729	4625	68	19F
0005432727794	4625	69	20A
0005432382732	4625	70	20D
0005432727800	4625	71	20F
0005432727751	30217	1	13C
0005432727724	30217	2	15C
0005435529011	1769	1	2A
0005435529020	1769	2	2D
0005433516782	1769	3	2F
0005435540762	1769	4	3A
0005435529018	1769	5	3C
0005435540765	1769	6	3D
0005435529014	1769	7	4A
0005435529012	1769	8	4D
0005435540769	1769	9	4F
0005432294461	1769	10	5F
0005435529019	1769	11	6A
0005435529022	1769	12	6C
0005435540764	1769	13	6F
0005435540768	1769	14	7A
0005435529030	1769	15	7E
0005435529029	1769	16	7F
0005435540771	1769	17	8D
0005435540763	1769	18	8E
0005435529024	1769	19	8F
0005433516781	1769	20	9A
0005435529025	1769	21	9D
0005435540760	1769	22	9E
0005435529023	1769	23	9F
0005433516785	1769	24	10A
0005435529016	1769	25	10C
0005435540773	1769	26	10D
0005435540774	1769	27	10E
0005435529032	1769	28	10F
0005435540776	1769	29	11C
0005435529017	1769	30	11D
0005435529031	1769	31	11E
0005435529028	1769	32	11F
0005435540767	1769	33	12C
0005435540777	1769	34	12D
0005435540758	1769	35	12E
0005433516779	1769	36	13D
0005432294460	1769	37	13F
0005435540775	1769	38	14D
0005435540757	1769	39	14F
0005435529021	1769	40	15C
0005435529033	1769	41	16C
0005435540761	1769	42	16D
0005435529027	1769	43	16F
0005433516783	1769	44	17A
0005435540759	1769	45	17D
0005433516784	1769	46	17F
0005433516780	1769	47	18C
0005433516786	1769	48	18D
0005435529026	1769	49	18E
0005433516778	1769	50	19A
0005435540756	1769	51	19C
0005435540770	1769	52	19D
0005435529013	1769	53	19F
0005435540766	1769	54	20A
0005435529015	1769	55	20C
0005435540772	1769	56	20F
0005433516747	21970	1	1A
0005432924985	21970	2	3D
0005433516724	21970	3	3F
0005433516722	21970	4	4D
0005432924982	21970	5	7E
0005435517606	21970	6	9C
0005432924984	21970	7	10E
0005433516723	21970	8	14E
0005435517605	21970	9	15A
0005432924983	21970	10	15C
0005435540666	21970	11	17F
0005435540665	21970	12	20C
0005432838687	7382	1	1A
0005432838672	7382	2	1C
0005432073350	7382	3	1D
0005434458563	7382	4	1F
0005435252413	7382	5	2A
0005432838700	7382	6	2C
0005432838674	7382	7	2D
0005434458570	7382	8	3A
0005434458580	7382	9	3C
0005434458575	7382	10	3D
0005432838701	7382	11	3F
0005434458578	7382	12	4A
0005432838692	7382	13	4C
0005435252390	7382	14	4D
0005432838686	7382	15	4E
0005432838696	7382	16	5A
0005432840988	7382	17	5E
0005432838699	7382	18	6C
0005432838678	7382	19	6E
0005434458574	7382	20	6F
0005432073351	7382	21	7A
0005432838683	7382	22	7C
0005434458581	7382	23	7D
0005432838691	7382	24	7E
0005432838702	7382	25	7F
0005432838689	7382	26	8C
0005432838679	7382	27	8D
0005435252414	7382	28	8E
0005432838693	7382	29	8F
0005435252403	7382	30	9C
0005432838685	7382	31	9A
0005434458569	7382	32	9E
0005434458571	7382	33	9F
0005432838688	7382	34	10A
0005432838681	7382	35	10C
0005434458573	7382	36	10D
0005434458564	7382	37	10E
0005434458562	7382	38	10F
0005434458579	7382	39	11A
0005432838695	7382	40	11C
0005432838675	7382	41	11F
0005432073353	7382	42	12C
0005432823426	7382	43	12D
0005432838690	7382	44	12E
0005432838680	7382	45	13C
0005432838673	7382	46	13D
0005432838697	7382	47	13E
0005434458561	7382	48	14A
0005432838677	7382	49	14C
0005432840987	7382	50	14D
0005432823425	7382	51	14F
0005434458577	7382	52	15A
0005432073352	7382	53	16D
0005435252399	7382	54	16F
0005434458572	7382	55	17F
0005434458568	7382	56	18C
0005434458565	7382	57	18D
0005432838694	7382	58	18E
0005432838676	7382	59	19A
0005432838698	7382	60	19C
0005434458576	7382	61	19D
0005432838682	7382	62	19E
0005434458582	7382	63	19F
0005435252389	7382	64	20A
0005434458566	7382	65	20C
0005434458567	7382	66	20D
0005432838684	7382	67	20E
0005435252391	7382	68	20F
0005435252499	28895	1	1A
0005435252507	28895	2	1C
0005435252506	28895	3	2A
0005435252502	28895	4	2C
0005435252492	28895	5	2D
0005435252504	28895	6	2F
0005435252495	28895	7	4A
0005435252505	28895	8	4C
0005432838526	28895	9	4E
0005435491417	28895	10	5A
0005435252503	28895	11	5E
0005435491418	28895	12	5F
0005435252508	28895	13	6A
0005435252497	28895	14	7C
0005435252491	28895	15	7E
0005434458438	28895	16	7F
0005432838507	28895	17	8D
0005432838520	28895	18	9F
0005434458439	28895	19	10A
0005432001001	28895	20	11A
0005432001000	28895	21	11D
0005434664934	28895	22	11F
0005432840976	28895	23	12A
0005432001002	28895	24	12C
0005434664935	28895	25	12E
0005435252501	28895	26	13A
0005432838528	28895	27	13F
0005435491419	28895	28	15F
0005435252493	28895	29	16A
0005434458490	28895	30	16E
0005434458471	28895	31	16F
0005435252498	28895	32	17A
0005435252494	28895	33	17E
0005432838627	28895	34	18C
0005435252496	28895	35	18D
0005432838527	28895	36	19A
0005434664933	28895	37	19C
0005434458453	28895	38	19D
0005435252500	28895	39	20A
0005432838481	28895	40	20C
0005435990543	8793	1	3A
0005434275949	8793	2	6F
0005435990546	8793	3	8B
0005435990547	8793	4	11D
0005435990541	8793	5	11C
0005435990545	8793	6	12E
0005435990544	8793	7	13F
0005435990540	8793	8	14D
0005435990542	8793	9	17B
0005434275939	8793	10	21A
0005434275948	8793	11	21C
0005434275963	15726	1	1D
0005435990508	15726	2	8A
0005434275959	15726	3	8F
0005434275960	15726	4	12A
0005434275964	15726	5	12E
0005434275961	15726	6	16F
0005434275962	15726	7	17B
0005433476855	20627	1	3B
0005432427118	20627	2	3D
0005433476858	20627	3	7B
0005432427117	20627	4	18A
0005432427115	20627	5	20D
0005432427116	20627	6	22A
0005432427119	20627	7	22B
0005433476869	30856	1	3B
0005432427109	30856	2	3D
0005433476867	30856	3	7C
0005433476866	30856	4	19C
0005433476868	30856	5	20A
0005432427108	30856	6	22C
0005432909224	23852	1	1C
0005432909218	23852	2	2A
0005432909221	23852	3	4C
0005432909222	23852	4	5B
0005432909226	23852	5	5C
0005432909220	23852	6	6C
0005432909227	23852	7	18C
0005432909217	23852	8	19A
0005433468186	23852	9	19C
0005432909225	23852	10	20B
0005432909219	23852	11	20D
0005432909223	23852	12	23A
0005432359823	6372	1	2A
0005432359843	6372	2	2C
0005432335902	6372	3	2D
0005432363382	6372	4	3C
0005435176638	6372	5	3D
0005432359806	6372	6	3F
0005432359842	6372	7	4B
0005432335895	6372	8	4C
0005432363380	6372	9	4E
0005432359848	6372	10	4D
0005432335900	6372	11	4F
0005432359815	6372	12	5A
0005435176642	6372	13	5C
0005432359824	6372	14	5B
0005432359829	6372	15	5D
0005432359808	6372	16	5E
0005432062167	6372	17	6A
0005432359850	6372	18	6C
0005435176594	6372	19	6B
0005432359839	6372	20	6D
0005432062169	6372	21	6F
0005432359818	6372	22	6E
0005432062166	6372	23	7A
0005432359803	6372	24	7B
0005432359819	6372	25	7D
0005432359845	6372	26	7F
0005432359822	6372	27	8C
0005432359821	6372	28	8F
0005432359840	6372	29	9D
0005435176688	6372	30	9C
0005432359836	6372	31	9F
0005432363379	6372	32	9E
0005432359837	6372	33	10B
0005432335903	6372	34	10C
0005432359831	6372	35	10D
0005432359833	6372	36	11B
0005432359849	6372	37	11C
0005432359832	6372	38	11E
0005432359807	6372	39	11D
0005432359835	6372	40	11F
0005432359801	6372	41	12C
0005432359802	6372	42	12B
0005432359827	6372	43	12D
0005434149529	6372	44	12F
0005435176654	6372	45	13A
0005432335905	6372	46	13D
0005432359813	6372	47	13E
0005435176602	6372	48	14A
0005432359820	6372	49	14C
0005435176593	6372	50	14E
0005432359811	6372	51	15A
0005432359812	6372	52	14F
0005432359826	6372	53	15B
0005432359828	6372	54	15C
0005432359825	6372	55	15E
0005432359830	6372	56	15F
0005432359809	6372	57	16A
0005432359847	6372	58	16C
0005435176633	6372	59	16B
0005432335904	6372	60	16F
0005432335896	6372	61	16E
0005432062171	6372	62	17B
0005432359805	6372	63	17A
0005432363381	6372	64	17E
0005432335899	6372	65	18A
0005432359844	6372	66	18C
0005432359817	6372	67	18E
0005432062168	6372	68	18D
0005435176610	6372	69	18F
0005432363377	6372	70	19A
0005432062170	6372	71	19D
0005432359834	6372	72	19C
0005432359810	6372	73	19E
0005432359814	6372	74	20B
0005432359846	6372	75	20C
0005432359838	6372	76	20E
0005432335901	6372	77	21A
0005432335906	6372	78	21D
0005432359816	6372	79	21E
0005432335897	6372	80	22C
0005432359841	6372	81	22E
0005432359804	6372	82	23B
0005432335898	6372	83	23D
0005432363378	6372	84	23E
0005435723023	20999	1	1A
0005434149603	20999	2	1C
0005435176756	20999	3	1D
0005432052710	20999	4	1F
0005435490190	20999	5	2D
0005435176770	20999	6	3A
0005435490188	20999	7	3C
0005435176773	20999	8	3F
0005432052711	20999	9	4C
0005432359645	20999	10	4B
0005435176772	20999	11	4D
0005435176777	20999	12	4F
0005435176776	20999	13	5D
0005435176757	20999	14	5C
0005435176764	20999	15	5F
0005434149596	20999	16	6B
0005432363362	20999	17	6C
0005434149598	20999	18	6F
0005434149601	20999	19	7A
0005435490189	20999	20	7E
0005434149593	20999	21	8B
0005434149594	20999	22	8E
0005435176768	20999	23	9E
0005435176769	20999	24	10C
0005435176759	20999	25	11A
0005434149599	20999	26	11B
0005435176771	20999	27	12C
0005435176782	20999	28	12D
0005435176775	20999	29	13A
0005435176766	20999	30	12F
0005434149600	20999	31	13B
0005432359542	20999	32	13C
0005432359644	20999	33	13F
0005435176780	20999	34	14A
0005432359510	20999	35	14C
0005435176760	20999	36	14D
0005434149595	20999	37	15A
0005435176781	20999	38	15F
0005434149597	20999	39	16C
0005435176761	20999	40	16D
0005435723024	20999	41	17B
0005435176779	20999	42	18B
0005432052712	20999	43	18C
0005435176765	20999	44	19B
0005435176767	20999	45	20A
0005435490191	20999	46	20C
0005435176774	20999	47	20F
0005435176763	20999	48	21A
0005432359630	20999	49	21D
0005434149602	20999	50	21F
0005435176758	20999	51	22B
0005435176778	20999	52	22F
0005435176762	20999	53	23D
0005432359522	20999	54	23C
0005434458463	17719	1	1A
0005434458476	17719	2	2B
0005434458517	17719	3	2D
0005434458518	17719	4	4A
0005434448253	17719	5	4D
0005434458475	17719	6	5A
0005434463892	17719	7	5B
0005434186167	17719	8	6C
0005434186165	17719	9	7A
0005434458449	17719	10	18A
0005434186166	17719	11	18C
0005434458448	17719	12	19B
0005434458462	17719	13	23A
0005434463891	17719	14	23B
0005434458581	29075	1	1B
0005434463903	29075	2	1C
0005434458576	29075	3	1D
0005434458570	29075	4	2D
0005434458569	29075	5	2C
0005434458568	29075	6	3D
0005434448272	29075	7	4C
0005434458575	29075	8	4D
0005434458567	29075	9	5A
0005434448274	29075	10	5B
0005434458565	29075	11	5D
0005434462764	29075	12	6A
0005434458571	29075	13	6B
0005434458579	29075	14	7A
0005434448273	29075	15	7B
0005434458566	29075	16	7C
0005434458577	29075	17	7D
0005434458582	29075	18	18B
0005434458578	29075	19	18D
0005434448271	29075	20	19A
0005434458574	29075	21	20A
0005434458580	29075	22	20C
0005434458561	29075	23	20D
0005434458563	29075	24	21A
0005434458572	29075	25	21C
0005434458564	29075	26	21D
0005434458562	29075	27	22A
0005434458573	29075	28	23A
0005432664127	6492	1	1F
0005432664117	6492	2	1C
0005432661912	6492	3	2A
0005432663018	6492	4	3A
0005432663014	6492	5	4A
0005432663019	6492	6	6B
0005432663022	6492	7	6F
0005432663024	6492	8	6E
0005432661911	6492	9	6D
0005432661902	6492	10	7A
0005432663017	6492	11	7B
0005432661904	6492	12	7E
0005432664119	6492	13	7F
0005432661901	6492	14	8C
0005432663013	6492	15	8D
0005432664121	6492	16	10A
0005432664125	6492	17	10C
0005432664123	6492	18	10E
0005432663023	6492	19	11D
0005432664126	6492	20	11E
0005432664120	6492	21	12B
0005432661905	6492	22	12A
0005432664116	6492	23	12F
0005432661898	6492	24	12E
0005432661903	6492	25	14A
0005432661908	6492	26	14D
0005432664114	6492	27	15B
0005432664122	6492	28	15A
0005432663025	6492	29	15F
0005432661906	6492	30	15D
0005432663012	6492	31	16A
0005432664115	6492	32	16D
0005432661909	6492	33	17B
0005432664124	6492	34	17E
0005432663020	6492	35	18B
0005432661910	6492	36	18D
0005432663015	6492	37	19A
0005432663016	6492	38	18F
0005432663021	6492	39	19E
0005432661899	6492	40	20F
0005432661900	6492	41	20E
0005432664113	6492	42	20D
0005432661907	6492	43	21B
0005432664118	6492	44	21D
0005432663026	6492	45	21C
0005432603858	21429	1	1A
0005432603874	21429	2	1B
0005432603845	21429	3	1C
0005432603860	21429	4	1D
0005432603844	21429	5	2A
0005432603851	21429	6	2B
0005432603867	21429	7	2C
0005432603875	21429	8	2D
0005432603857	21429	9	3A
0005432603866	21429	10	3C
0005432603846	21429	11	3D
0005432603881	21429	12	4A
0005432603847	21429	13	4D
0005432603865	21429	14	5A
0005432603869	21429	15	5B
0005432603853	21429	16	5D
0005432603854	21429	17	6A
0005432603882	21429	18	6B
0005432603856	21429	19	6D
0005432603876	21429	20	7A
0005432603868	21429	21	7B
0005432603862	21429	22	7C
0005432603880	21429	23	7D
0005432603870	21429	24	18B
0005432603879	21429	25	18C
0005432603877	21429	26	18D
0005432603863	21429	27	19B
0005432603850	21429	28	19C
0005432603855	21429	29	19D
0005432603852	21429	30	20A
0005432603873	21429	31	20B
0005432603859	21429	32	20C
0005432603849	21429	33	20D
0005432603848	21429	34	21A
0005432603864	21429	35	21B
0005432603883	21429	36	21C
0005432603884	21429	37	21D
0005432603871	21429	38	22A
0005432603861	21429	39	22B
0005432603872	21429	40	22D
0005432603878	21429	41	23A
0005432603715	31690	1	2A
0005435221045	31690	2	5B
0005435221044	31690	3	6C
0005435221505	31690	4	7D
0005435221504	31690	5	19A
0005432603668	31690	6	20C
0005435154589	12303	1	1B
0005435154590	12303	2	2D
0005435154587	12303	3	5D
0005435154588	12303	4	7A
0005435154586	12303	5	21B
0005433473107	23894	1	2A
0005433473108	23894	2	5A
0005435257176	23894	3	7B
0005435257172	23894	4	7C
0005435257179	23894	5	18A
0005435257173	23894	6	18D
0005435257180	23894	7	19C
0005435257178	23894	8	20A
0005435257171	23894	9	20C
0005435257174	23894	10	21B
0005435257177	23894	11	21C
0005435257181	23894	12	22B
0005435257175	23894	13	22C
0005434604855	22346	1	1A
0005434604854	22346	2	1B
0005434604856	22346	3	2B
0005434606782	22346	4	3B
0005434606784	22346	5	4A
0005434604857	22346	6	4B
0005434604858	22346	7	5A
0005434606783	22346	8	6A
0005434522400	3849	1	1A
0005434522401	3849	2	5B
0005434522399	3849	3	7D
0005434522396	3849	4	18B
0005434522403	3849	5	18D
0005434522397	3849	6	20D
0005434522398	3849	7	21B
0005434522402	3849	8	23A
0005435904379	19044	1	4C
0005435904381	19044	2	5D
0005434522383	19044	3	7C
0005434522384	19044	4	18B
0005435904380	19044	5	19B
0005435904382	19044	6	19C
0005434522380	19044	7	22B
0005435904378	19044	8	22C
0005432753259	404	1	1D
0005432747122	404	2	2A
0005432747103	404	3	2C
0005432219954	404	4	3A
0005432751487	404	5	3C
0005432747114	404	6	3D
0005432747112	404	7	4A
0005432747115	404	8	4C
0005432747113	404	9	4F
0005432890684	404	10	5D
0005432747127	404	11	5F
0005432747130	404	12	6C
0005432747118	404	13	6D
0005432747129	404	14	6E
0005432747121	404	15	7D
0005432747138	404	16	7E
0005432747117	404	17	7F
0005432747136	404	18	8A
0005432749757	404	19	8C
0005432747126	404	20	8D
0005432747131	404	21	8E
0005432751485	404	22	9C
0005432747134	404	23	9E
0005432747105	404	24	9F
0005432747101	404	25	10C
0005432753260	404	26	11A
0005432747102	404	27	11D
0005432747111	404	28	11E
0005432747116	404	29	12E
0005432747106	404	30	13A
0005432219955	404	31	13C
0005432747104	404	32	13E
0005432890697	404	33	13F
0005432749759	404	34	14C
0005432747109	404	35	14E
0005432753261	404	36	15A
0005432747123	404	37	15C
0005432219952	404	38	15E
0005432747133	404	39	15F
0005432747108	404	40	16A
0005432751484	404	41	16C
0005432747120	404	42	16D
0005432747107	404	43	16F
0005432747139	404	44	17A
0005432747110	404	45	17D
0005432747119	404	46	17E
0005432747132	404	47	18A
0005432747124	404	48	18E
0005432749758	404	49	18F
0005432751486	404	50	19C
0005432219953	404	51	19D
0005432747137	404	52	19E
0005432747125	404	53	20A
0005432747135	404	54	20E
0005432747128	404	55	20F
0005432890791	12072	1	1A
0005432746870	12072	2	2C
0005432746871	12072	3	2F
0005432890799	12072	4	3F
0005432746973	12072	5	3D
0005432890800	12072	6	4A
0005432214778	12072	7	4C
0005432890801	12072	8	4D
0005432746916	12072	9	4E
0005432746895	12072	10	5C
0005432890793	12072	11	5D
0005432890803	12072	12	6C
0005432890789	12072	13	7F
0005432890807	12072	14	8A
0005432890790	12072	15	8E
0005432746926	12072	16	9D
0005432746917	12072	17	9F
0005432746918	12072	18	10A
0005434153521	12072	19	10C
0005432890795	12072	20	11A
0005432890798	12072	21	11C
0005432890805	12072	22	11D
0005432890796	12072	23	11F
0005432890794	12072	24	14A
0005432890802	12072	25	14E
0005432890797	12072	26	15E
0005432890808	12072	27	16A
0005432746891	12072	28	16E
0005432747023	12072	29	17A
0005434153523	12072	30	17C
0005432746925	12072	31	17E
0005432890804	12072	32	18A
0005432214779	12072	33	18E
0005432746972	12072	34	18F
0005432746896	12072	35	19A
0005432890806	12072	36	19C
0005432890792	12072	37	19D
0005432746938	12072	38	19E
0005432747017	12072	39	19F
0005432746937	12072	40	20D
0005434153522	12072	41	20E
0005433524908	18973	1	1B
0005433524904	18973	2	3A
0005433524911	18973	3	3B
0005433524903	18973	4	3D
0005433533260	18973	5	4A
0005433533261	18973	6	5C
0005433524909	18973	7	5D
0005433524906	18973	8	6A
0005433533262	18973	9	18B
0005433524910	18973	10	19A
0005433531245	18973	11	19B
0005433524902	18973	12	19C
0005433524901	18973	13	19D
0005433531246	18973	14	20C
0005433531248	18973	15	20D
0005433531247	18973	16	21B
0005433524907	18973	17	22C
0005433524905	18973	18	23B
0005433527209	32511	1	1A
0005433527210	32511	2	1D
0005433524852	32511	3	3B
0005433527208	32511	4	4B
0005433531229	32511	5	5C
0005432927921	32511	6	18A
0005433527207	32511	7	18B
0005432927924	32511	8	18C
0005432927922	32511	9	21A
0005432927923	32511	10	21B
0005434558187	5297	1	1A
0005434822193	5297	2	1H
0005434822217	5297	3	1G
0005435372187	5297	4	1D
0005435372136	5297	5	1K
0005434822110	5297	6	2H
0005434822123	5297	7	2G
0005434831094	5297	8	3K
0005432396199	5297	9	3G
0005434822107	5297	10	4C
0005435372099	5297	11	4G
0005434822106	5297	12	4D
0005434822186	5297	13	4K
0005432121179	5297	14	4H
0005434822154	5297	15	5D
0005434822194	5297	16	5H
0005434822091	5297	17	11E
0005434822152	5297	18	11C
0005434822156	5297	19	11K
0005432121176	5297	20	11H
0005434822120	5297	21	12E
0005434822115	5297	22	12K
0005435372151	5297	23	12H
0005434822170	5297	24	13D
0005434558190	5297	25	13E
0005432396197	5297	26	13H
0005432121175	5297	27	13K
0005432121178	5297	28	14E
0005434822134	5297	29	14G
0005434822197	5297	30	14H
0005435149883	5297	31	15A
0005434822114	5297	32	15E
0005434822096	5297	33	15H
0005435386461	5297	34	16A
0005435372154	5297	35	15K
0005434822113	5297	36	17A
0005434822163	5297	37	17E
0005435372110	5297	38	17D
0005434822141	5297	39	17H
0005432121177	5297	40	18B
0005434822168	5297	41	18A
0005434822173	5297	42	18D
0005434822105	5297	43	18G
0005432121172	5297	44	18K
0005432394059	5297	45	18J
0005434822196	5297	46	18H
0005435372114	5297	47	19D
0005435372178	5297	48	19C
0005434664932	5297	49	19F
0005434822122	5297	50	19H
0005434822177	5297	51	19K
0005432121170	5297	52	19J
0005434822166	5297	53	20D
0005435149873	5297	54	20K
0005435299699	5297	55	20H
0005432121174	5297	56	21B
0005434822190	5297	57	21A
0005434822139	5297	58	21F
0005434831092	5297	59	21E
0005434822206	5297	60	21G
0005435372179	5297	61	21K
0005434822169	5297	62	21J
0005434822131	5297	63	22C
0005435372214	5297	64	22E
0005434822215	5297	65	22D
0005434822171	5297	66	22G
0005432121171	5297	67	22K
0005432394057	5297	68	22J
0005434822214	5297	69	22H
0005432823415	5297	70	23A
0005435149874	5297	71	23E
0005434822136	5297	72	24D
0005435149871	5297	73	24G
0005434558189	5297	74	25D
0005434822201	5297	75	25C
0005434822094	5297	76	25B
0005434822209	5297	77	25E
0005434822129	5297	78	25G
0005434558188	5297	79	26A
0005434822119	5297	80	25J
0005434822174	5297	81	26B
0005434822140	5297	82	26D
0005432396196	5297	83	26G
0005434822212	5297	84	26F
0005434822130	5297	85	26J
0005434822172	5297	86	27A
0005434822157	5297	87	27D
0005434822203	5297	88	27E
0005434822200	5297	89	27G
0005434822099	5297	90	28A
0005434822185	5297	91	27K
0005435386462	5297	92	27J
0005434822192	5297	93	28C
0005435372188	5297	94	28G
0005434831090	5297	95	28H
0005434822158	5297	96	29A
0005432396198	5297	97	29D
0005434822125	5297	98	29B
0005432394060	5297	99	29F
0005435149882	5297	100	29E
0005434822153	5297	101	29H
0005432121181	5297	102	29G
0005435149872	5297	103	30A
0005434822208	5297	104	29K
0005434822097	5297	105	29J
0005434822112	5297	106	30C
0005434822142	5297	107	30G
0005434822101	5297	108	30F
0005434822162	5297	109	30J
0005434822103	5297	110	30H
0005434822179	5297	111	31B
0005435149875	5297	112	31A
0005434822128	5297	113	31D
0005434558191	5297	114	31E
0005434822175	5297	115	31H
0005434822126	5297	116	31G
0005432121169	5297	117	31J
0005434828664	5297	118	32C
0005434822145	5297	119	32B
0005434558181	5297	120	32E
0005434822135	5297	121	32D
0005434822109	5297	122	32G
0005434558180	5297	123	32F
0005434558184	5297	124	32J
0005434558183	5297	125	33B
0005434822149	5297	126	32K
0005432396200	5297	127	33D
0005435149879	5297	128	33E
0005434822218	5297	129	33G
0005434822161	5297	130	33K
0005434822127	5297	131	33J
0005434822147	5297	132	34C
0005434558182	5297	133	34B
0005435372325	5297	134	34A
0005435149870	5297	135	34G
0005435372180	5297	136	34F
0005434822155	5297	137	34J
0005434822100	5297	138	34H
0005435149878	5297	139	35B
0005434822182	5297	140	35A
0005434831091	5297	141	34K
0005434822183	5297	142	35F
0005432394058	5297	143	35H
0005435372203	5297	144	35G
0005434822180	5297	145	36A
0005434822202	5297	146	35K
0005434828662	5297	147	36D
0005434822210	5297	148	36E
0005434822151	5297	149	36H
0005434822164	5297	150	36F
0005435372127	5297	151	37B
0005435372097	5297	152	37A
0005435372160	5297	153	37D
0005434831093	5297	154	37C
0005434822117	5297	155	37F
0005434822092	5297	156	37E
0005434822198	5297	157	37G
0005432121173	5297	158	37K
0005435149876	5297	159	38C
0005434822124	5297	160	39A
0005434822167	5297	161	38K
0005434822118	5297	162	39D
0005435149877	5297	163	39H
0005435372096	5297	164	39G
0005434822108	5297	165	40A
0005434822189	5297	166	39K
0005434822102	5297	167	40C
0005434822098	5297	168	40B
0005434822178	5297	169	40E
0005434822146	5297	170	41D
0005435372153	5297	171	41C
0005435372105	5297	172	41G
0005434822188	5297	173	42A
0005434822121	5297	174	41K
0005434822148	5297	175	41J
0005434822207	5297	176	42C
0005434822181	5297	177	42B
0005434822219	5297	178	42F
0005434822187	5297	179	42K
0005434822195	5297	180	42J
0005434822211	5297	181	43A
0005434822150	5297	182	43K
0005435372173	5297	183	43J
0005434822095	5297	184	44E
0005434822159	5297	185	44D
0005435372204	5297	186	44F
0005434822137	5297	187	44J
0005434822199	5297	188	44H
0005434822132	5297	189	45A
0005434822138	5297	190	45C
0005434828663	5297	191	45H
0005434822104	5297	192	45K
0005432121180	5297	193	45J
0005434822191	5297	194	46G
0005434558186	5297	195	46J
0005434822205	5297	196	47A
0005434822116	5297	197	47E
0005434822160	5297	198	47D
0005434822144	5297	199	47G
0005435149881	5297	200	47F
0005434822111	5297	201	47K
0005435149884	5297	202	47H
0005434822213	5297	203	48A
0005435372142	5297	204	48F
0005432121182	5297	205	48E
0005434822184	5297	206	48D
0005434822204	5297	207	48H
0005434822143	5297	208	48G
0005435149880	5297	209	49A
0005434558185	5297	210	49F
0005434558192	5297	211	49K
0005434822165	5297	212	49H
0005434822133	5297	213	50C
0005434822176	5297	214	50E
0005434822093	5297	215	50D
0005434822216	5297	216	50F
0005435372529	9880	1	1C
0005434821518	9880	2	1D
0005435299722	9880	3	3D
0005435372533	9880	4	3K
0005432202981	9880	5	4A
0005435372524	9880	6	4G
0005432823428	9880	7	4D
0005435372509	9880	8	11A
0005435372553	9880	9	11F
0005435372520	9880	10	11E
0005434821422	9880	11	11H
0005435372556	9880	12	11G
0005435735086	9880	13	12C
0005435302146	9880	14	12F
0005435372501	9880	15	12K
0005435735087	9880	16	12H
0005435661897	9880	17	13F
0005435372519	9880	18	13H
0005434821406	9880	19	14A
0005435302148	9880	20	14H
0005432202983	9880	21	15A
0005434821354	9880	22	15K
0005435735089	9880	23	16D
0005434821364	9880	24	16F
0005435372542	9880	25	16E
0005434821397	9880	26	16H
0005435372512	9880	27	17C
0005435372527	9880	28	18E
0005432202985	9880	29	19D
0005435372523	9880	30	19C
0005435149825	9880	31	19B
0005435372500	9880	32	19H
0005435372540	9880	33	19G
0005432823427	9880	34	20C
0005435179387	9880	35	20B
0005435299723	9880	36	20F
0005435372555	9880	37	20J
0005435372546	9880	38	21E
0005435372547	9880	39	21H
0005434821447	9880	40	22H
0005434821311	9880	41	23A
0005435372513	9880	42	23H
0005435302144	9880	43	23G
0005435372543	9880	44	24D
0005435372496	9880	45	25A
0005435386499	9880	46	25D
0005435299720	9880	47	25H
0005435372499	9880	48	25K
0005432202982	9880	49	25J
0005435372535	9880	50	26B
0005435372550	9880	51	26F
0005435735088	9880	52	26H
0005435179388	9880	53	27D
0005435372508	9880	54	27J
0005435372548	9880	55	28C
0005435386500	9880	56	28B
0005434821423	9880	57	28E
0005435661899	9880	58	28D
0005435302145	9880	59	28F
0005435299721	9880	60	28J
0005435372518	9880	61	29D
0005435372531	9880	62	29B
0005435372502	9880	63	29F
0005432202979	9880	64	29E
0005435372521	9880	65	30A
0005435372545	9880	66	30B
0005435386498	9880	67	30E
0005434821312	9880	68	30G
0005435386501	9880	69	31F
0005435372525	9880	70	31H
0005435372530	9880	71	31J
0005435372534	9880	72	32D
0005435302147	9880	73	33C
0005435372557	9880	74	33F
0005435372515	9880	75	33J
0005434821405	9880	76	33H
0005435299724	9880	77	34A
0005435372554	9880	78	33K
0005434821315	9880	79	34C
0005434821316	9880	80	34G
0005432202980	9880	81	35B
0005435372504	9880	82	35A
0005434821453	9880	83	34K
0005434821616	9880	84	35F
0005434821365	9880	85	35K
0005435372539	9880	86	36D
0005434821549	9880	87	36B
0005435372507	9880	88	36E
0005435372522	9880	89	36F
0005435661898	9880	90	36K
0005435372559	9880	91	37B
0005435372536	9880	92	37H
0005435372552	9880	93	38K
0005435372514	9880	94	39D
0005435372498	9880	95	39J
0005435372537	9880	96	39H
0005435372549	9880	97	40B
0005434821347	9880	98	40H
0005435386503	9880	99	40F
0005435372526	9880	100	40K
0005435372551	9880	101	40J
0005434821528	9880	102	41A
0005435372558	9880	103	41D
0005435372528	9880	104	41F
0005434821335	9880	105	42D
0005435372541	9880	106	43B
0005434821493	9880	107	43D
0005434821403	9880	108	43E
0005435372516	9880	109	43H
0005435372538	9880	110	44A
0005435372503	9880	111	44B
0005435372497	9880	112	44K
0005434821326	9880	113	44J
0005435372494	9880	114	45D
0005435372517	9880	115	45F
0005435372506	9880	116	45E
0005435372510	9880	117	45H
0005434821358	9880	118	46A
0005435372505	9880	119	46B
0005435386502	9880	120	46D
0005435372511	9880	121	46F
0005432202984	9880	122	47K
0005434821402	9880	123	49D
0005435372532	9880	124	49C
0005435372495	9880	125	49E
0005435372544	9880	126	50A
0005435790273	6968	1	1D
0005435082702	6968	2	2B
0005435082698	6968	3	2C
0005435082695	6968	4	3D
0005435082696	6968	5	5C
0005435790272	6968	6	5D
0005435082697	6968	7	6A
0005435790274	6968	8	6B
0005435082701	6968	9	7D
0005435082699	6968	10	18A
0005435082700	6968	11	18C
0005435790275	6968	12	21A
0005435082703	6968	13	21C
0005435790259	25987	1	2B
0005435790258	25987	2	19C
0005434213701	9556	1	1A
0005434755999	9556	2	1C
0005434755969	9556	3	1D
0005434755962	9556	4	1F
0005434213732	9556	5	2A
0005434755998	9556	6	2D
0005434755988	9556	7	3A
0005434213791	9556	8	3D
0005434755982	9556	9	3F
0005434755996	9556	10	4A
0005434755964	9556	11	4D
0005434755987	9556	12	5C
0005434755977	9556	13	5D
0005434755965	9556	14	6A
0005434755978	9556	15	6F
0005434213740	9556	16	7A
0005434756003	9556	17	7C
0005434755975	9556	18	7D
0005434755968	9556	19	7E
0005434756007	9556	20	8A
0005434755993	9556	21	8D
0005434755983	9556	22	8F
0005434756004	9556	23	9E
0005434755995	9556	24	10C
0005434213750	9556	25	10D
0005434755986	9556	26	10E
0005434755989	9556	27	11C
0005434755966	9556	28	11F
0005434755963	9556	29	12C
0005434755974	9556	30	12E
0005434755970	9556	31	12F
0005434755991	9556	32	13D
0005434755972	9556	33	13E
0005434756002	9556	34	13F
0005434755971	9556	35	14A
0005434755981	9556	36	14C
0005434755994	9556	37	14F
0005434756001	9556	38	15A
0005434755980	9556	39	15C
0005434755984	9556	40	15D
0005434213749	9556	41	16A
0005434755961	9556	42	16C
0005434756000	9556	43	16D
0005434755990	9556	44	16E
0005434755985	9556	45	17C
0005434755973	9556	46	17E
0005434755967	9556	47	17F
0005434755976	9556	48	18C
0005434756006	9556	49	18E
0005434755979	9556	50	19A
0005434755992	9556	51	19D
0005434756005	9556	52	19E
0005434755997	9556	53	19F
0005434213978	28591	1	1A
0005434213960	28591	2	1C
0005434213968	28591	3	1F
0005434213942	28591	4	2F
0005434213951	28591	5	3A
0005434213947	28591	6	3D
0005434213974	28591	7	3F
0005434213969	28591	8	4C
0005434213937	28591	9	4E
0005434213958	28591	10	4F
0005434213961	28591	11	5A
0005434213963	28591	12	5C
0005434213955	28591	13	6A
0005434213975	28591	14	6F
0005434213973	28591	15	7C
0005434213945	28591	16	7E
0005434213981	28591	17	8A
0005434213972	28591	18	8C
0005434213979	28591	19	8E
0005434213971	28591	20	8F
0005434213959	28591	21	9A
0005434213944	28591	22	9C
0005434213982	28591	23	9F
0005434213970	28591	24	10D
0005434213976	28591	25	11E
0005434213953	28591	26	11F
0005434213939	28591	27	12D
0005434213946	28591	28	12F
0005434213964	28591	29	13A
0005434213940	28591	30	13C
0005434213965	28591	31	13D
0005434213943	28591	32	13F
0005434213938	28591	33	14D
0005434213967	28591	34	14E
0005434213954	28591	35	14F
0005434213962	28591	36	15F
0005434213950	28591	37	16C
0005434213936	28591	38	16D
0005434213977	28591	39	16E
0005434213956	28591	40	17A
0005434213949	28591	41	18A
0005434213957	28591	42	18C
0005434213980	28591	43	18E
0005434213983	28591	44	19A
0005434213952	28591	45	19F
0005434213941	28591	46	20A
0005434213966	28591	47	20C
0005434213948	28591	48	20E
0005435100089	10837	1	2A
0005435100087	10837	2	18A
0005435100088	10837	3	22D
0005434760168	31807	1	2A
0005434760169	31807	2	3A
0005434760170	31807	3	7C
0005434639039	1957	1	1A
0005434639035	1957	2	1B
0005434639022	1957	3	1C
0005434639020	1957	4	2A
0005435948314	1957	5	2B
0005432290599	1957	6	2C
0005434639029	1957	7	2D
0005434639025	1957	8	3A
0005434639040	1957	9	3B
0005434639021	1957	10	3C
0005434639031	1957	11	3D
0005434639036	1957	12	4D
0005434639034	1957	13	5B
0005434639026	1957	14	5C
0005435948312	1957	15	5D
0005434639042	1957	16	6A
0005434639018	1957	17	6C
0005432290598	1957	18	6D
0005434639041	1957	19	7A
0005434639030	1957	20	7C
0005434639015	1957	21	18B
0005434639027	1957	22	18C
0005435948313	1957	23	18D
0005434639043	1957	24	19A
0005434639028	1957	25	19C
0005434639017	1957	26	19D
0005434639019	1957	27	20A
0005434639014	1957	28	20B
0005434639013	1957	29	20C
0005432290600	1957	30	21B
0005434639038	1957	31	21C
0005434639033	1957	32	21D
0005434639037	1957	33	22A
0005434639016	1957	34	22B
0005434639032	1957	35	22C
0005434639023	1957	36	22D
0005434639024	1957	37	23B
0005433202180	23264	1	1A
0005433202187	23264	2	1C
0005434638878	23264	3	2A
0005433202189	23264	4	2C
0005433202179	23264	5	2D
0005433202191	23264	6	3B
0005434638847	23264	7	3D
0005433202177	23264	8	4C
0005433202184	23264	9	4D
0005433202190	23264	10	7A
0005433202183	23264	11	7C
0005433202181	23264	12	7D
0005435948309	23264	13	18A
0005433202182	23264	14	18C
0005434638905	23264	15	18D
0005433202185	23264	16	21A
0005433202186	23264	17	21B
0005433202188	23264	18	22A
0005435948308	23264	19	22B
0005434638846	23264	20	23A
0005433202178	23264	21	22D
0005432111245	6085	1	1A
0005433533264	6085	2	1C
0005433533266	6085	3	1F
0005434600514	6085	4	2C
0005434600510	6085	5	2F
0005434600503	6085	6	3A
0005434600519	6085	7	4A
0005433533267	6085	8	4C
0005434600507	6085	9	4E
0005434600498	6085	10	5A
0005434600509	6085	11	5D
0005434600494	6085	12	6C
0005434600513	6085	13	6E
0005434600495	6085	14	7E
0005434600497	6085	15	8D
0005434600511	6085	16	9A
0005434600501	6085	17	9D
0005434600508	6085	18	9F
0005432111247	6085	19	10C
0005433533263	6085	20	10D
0005434600518	6085	21	10E
0005432111246	6085	22	11E
0005434600515	6085	23	13A
0005434600516	6085	24	13C
0005434600499	6085	25	13D
0005433531250	6085	26	13E
0005434600504	6085	27	13F
0005435326503	6085	28	14A
0005433531251	6085	29	14C
0005433533265	6085	30	15C
0005434600500	6085	31	15D
0005434600496	6085	32	15F
0005434600506	6085	33	16F
0005435326504	6085	34	17A
0005433531249	6085	35	17C
0005434600505	6085	36	18A
0005434600502	6085	37	18D
0005434600517	6085	38	18E
0005435326521	6085	39	19E
0005434600520	6085	40	20A
0005435326508	6085	41	20E
0005434600512	6085	42	20F
0005434600407	18599	1	1D
0005435326583	18599	2	3A
0005435326590	18599	3	6F
0005435326589	18599	4	7D
0005435326596	18599	5	7E
0005435326584	18599	6	9D
0005435326597	18599	7	9F
0005434600388	18599	8	10C
0005434600409	18599	9	11D
0005434600367	18599	10	12A
0005435326595	18599	11	12D
0005435326588	18599	12	13D
0005434600395	18599	13	13E
0005435326582	18599	14	14D
0005434600408	18599	15	15A
0005435326594	18599	16	15F
0005435326586	18599	17	16D
0005435326591	18599	18	17A
0005435326587	18599	19	18C
0005434600387	18599	20	18E
0005434600394	18599	21	19A
0005435326585	18599	22	19D
0005435326592	18599	23	19E
0005435326593	18599	24	20F
0005434550587	10592	1	1C
0005434558171	10592	2	1D
0005434550576	10592	3	1F
0005434550590	10592	4	2A
0005434550565	10592	5	2D
0005434550573	10592	6	2F
0005434550571	10592	7	3A
0005434550555	10592	8	3F
0005434550568	10592	9	4A
0005434550553	10592	10	4D
0005434550579	10592	11	4E
0005434550552	10592	12	5A
0005434550589	10592	13	5C
0005434550567	10592	14	5D
0005434550543	10592	15	5E
0005434550549	10592	16	5F
0005434550578	10592	17	6C
0005434550569	10592	18	6E
0005434550563	10592	19	7A
0005434550560	10592	20	7D
0005434550588	10592	21	7E
0005434550572	10592	22	8A
0005434550538	10592	23	8C
0005434550577	10592	24	8D
0005434550585	10592	25	8E
0005434558175	10592	26	8F
0005434550580	10592	27	9A
0005434550570	10592	28	9D
0005434550548	10592	29	9E
0005434550544	10592	30	9F
0005434550557	10592	31	10A
0005434558172	10592	32	10C
0005434550542	10592	33	10D
0005434550559	10592	34	10E
0005434550545	10592	35	10F
0005434550556	10592	36	11C
0005434550550	10592	37	11D
0005434550541	10592	38	11E
0005434558177	10592	39	12E
0005434550537	10592	40	13A
0005434550540	10592	41	13C
0005434550581	10592	42	13D
0005434550561	10592	43	13E
0005434550562	10592	44	13F
0005434550564	10592	45	14C
0005434550582	10592	46	14E
0005434550592	10592	47	14F
0005434550566	10592	48	15A
0005434550584	10592	49	15D
0005434558176	10592	50	15E
0005434550546	10592	51	15F
0005434550591	10592	52	16A
0005434558173	10592	53	16C
0005434550586	10592	54	16E
0005434550575	10592	55	17C
0005434550554	10592	56	17D
0005434554038	10592	57	17E
0005434558174	10592	58	17F
0005434550551	10592	59	18A
0005434558179	10592	60	18D
0005433180660	10592	61	18F
0005434550547	10592	62	19C
0005434550574	10592	63	19F
0005434550583	10592	64	20A
0005434558178	10592	65	20C
0005434550558	10592	66	20E
0005434550539	10592	67	20F
0005433180819	27770	1	1A
0005433180818	27770	2	1F
0005433180807	27770	3	3F
0005433180813	27770	4	5D
0005433180809	27770	5	5F
0005433180821	27770	6	6C
0005433180827	27770	7	8A
0005433180823	27770	8	8E
0005433180817	27770	9	8F
0005433180804	27770	10	9E
0005433180812	27770	11	10A
0005433180816	27770	12	10C
0005433180825	27770	13	10F
0005433180822	27770	14	11E
0005433180808	27770	15	12C
0005433180826	27770	16	14C
0005433180815	27770	17	15A
0005433180824	27770	18	16A
0005433180828	27770	19	16F
0005433180810	27770	20	16E
0005433180814	27770	21	18C
0005433180806	27770	22	19A
0005433180811	27770	23	19C
0005433180803	27770	24	20A
0005433180820	27770	25	20D
0005433180805	27770	26	20F
0005434554024	27771	1	4F
0005434550391	27771	2	6D
0005434550397	27771	3	7E
0005434550292	27771	4	15A
0005434550390	27771	5	16C
0005433459172	6127	1	3B
0005433459169	6127	2	4B
0005433459171	6127	3	5B
0005433459170	6127	4	6B
0005433459154	19347	1	1B
0005433459155	19347	2	3B
0005435254446	19347	3	5A
0005435254445	19347	4	6B
0005435437622	6711	1	1C
0005435437562	6711	2	2F
0005435661896	6711	3	3C
0005435681665	6711	4	3D
0005435681646	6711	5	3F
0005435681663	6711	6	4A
0005432136110	6711	7	4C
0005435681659	6711	8	4D
0005435681669	6711	9	4E
0005435681655	6711	10	4F
0005435681657	6711	11	5A
0005435681675	6711	12	5C
0005435681662	6711	13	5D
0005435681666	6711	14	5E
0005435630929	6711	15	6A
0005435681650	6711	16	6C
0005435681647	6711	17	6D
0005435681653	6711	18	6E
0005435661894	6711	19	7A
0005435681643	6711	20	7E
0005435437621	6711	21	8A
0005435681645	6711	22	8C
0005435681652	6711	23	8D
0005435681649	6711	24	8E
0005435681683	6711	25	8F
0005435720125	6711	26	9A
0005435681644	6711	27	9D
0005435681658	6711	28	9E
0005432136113	6711	29	10A
0005435681667	6711	30	10C
0005435681673	6711	31	10D
0005435681680	6711	32	11C
0005435681678	6711	33	11E
0005432136112	6711	34	11F
0005435437569	6711	35	12A
0005435681684	6711	36	12C
0005435437553	6711	37	12D
0005435681671	6711	38	12E
0005435681685	6711	39	13C
0005435437563	6711	40	13E
0005435630932	6711	41	14A
0005435437576	6711	42	14E
0005435681672	6711	43	14F
0005435681660	6711	44	15A
0005435630931	6711	45	15C
0005435661895	6711	46	15D
0005435681670	6711	47	15E
0005435681677	6711	48	15F
0005435437605	6711	49	16A
0005435681681	6711	50	16C
0005435681651	6711	51	16D
0005435681682	6711	52	17C
0005435681676	6711	53	17D
0005435681656	6711	54	17F
0005435681668	6711	55	18A
0005435681654	6711	56	18C
0005435719556	6711	57	18D
0005435681674	6711	58	18E
0005435681679	6711	59	18F
0005435630930	6711	60	19C
0005435720126	6711	61	19D
0005435681661	6711	62	19E
0005435681648	6711	63	20A
0005435719557	6711	64	20C
0005432136111	6711	65	20D
0005435681664	6711	66	20E
0005432136109	6711	67	20F
0005435720800	24615	1	1A
0005435437699	24615	2	1D
0005435720799	24615	3	1F
0005435681404	24615	4	2A
0005435437702	24615	5	2C
0005435681529	24615	6	2D
0005435437692	24615	7	2F
0005432533259	24615	8	4D
0005435437707	24615	9	4F
0005435437693	24615	10	5E
0005435437704	24615	11	7A
0005435437690	24615	12	7D
0005432533258	24615	13	8C
0005435437708	24615	14	8D
0005435437691	24615	15	9C
0005435437689	24615	16	9F
0005435437705	24615	17	10A
0005435437703	24615	18	10D
0005435437706	24615	19	11C
0005435437694	24615	20	11E
0005435437710	24615	21	12A
0005435681398	24615	22	12C
0005435681395	24615	23	12E
0005435437700	24615	24	13C
0005434828666	24615	25	13E
0005435681400	24615	26	13F
0005432305720	24615	27	14C
0005432305721	24615	28	14E
0005432533260	24615	29	14F
0005435437695	24615	30	15E
0005435437688	24615	31	15F
0005435681402	24615	32	16E
0005434828667	24615	33	17E
0005435720798	24615	34	18A
0005435437709	24615	35	18E
0005434828665	24615	36	19A
0005435437701	24615	37	18F
0005435437697	24615	38	19E
0005435437696	24615	39	20A
0005435437698	24615	40	20E
0005435125881	11551	1	1F
0005435125869	11551	2	2A
0005435125863	11551	3	3F
0005435125890	11551	4	4C
0005435125875	11551	5	4E
0005435125857	11551	6	5A
0005435125891	11551	7	5C
0005435125868	11551	8	5D
0005435125889	11551	9	5F
0005435125856	11551	10	6E
0005435125883	11551	11	7A
0005435125865	11551	12	7F
0005435125859	11551	13	8D
0005435125862	11551	14	8F
0005435125896	11551	15	9A
0005435125866	11551	16	9F
0005435125861	11551	17	10C
0005435125895	11551	18	10E
0005435125867	11551	19	10F
0005435125888	11551	20	11E
0005435125887	11551	21	11F
0005435125892	11551	22	12A
0005435125872	11551	23	12E
0005435125882	11551	24	13A
0005435125886	11551	25	13C
0005435125871	11551	26	13D
0005435125864	11551	27	13E
0005435125884	11551	28	14A
0005435125858	11551	29	15D
0005435125894	11551	30	15F
0005435125876	11551	31	16C
0005435125893	11551	32	16D
0005435125878	11551	33	16E
0005435105944	11551	34	16F
0005435125873	11551	35	17C
0005435125885	11551	36	17F
0005435125860	11551	37	18A
0005435125877	11551	38	18D
0005435125870	11551	39	18E
0005435125874	11551	40	19C
0005435125880	11551	41	19D
0005435125879	11551	42	19F
0005435125673	31900	1	1F
0005435125685	31900	2	2F
0005435125716	31900	3	5A
0005435558057	31900	4	7F
0005435125743	31900	5	8A
0005435125679	31900	6	9F
0005435125744	31900	7	10E
0005435558056	31900	8	12A
0005435105927	31900	9	12F
0005435558058	31900	10	13F
0005435125717	31900	11	16E
0005435125672	31900	12	19C
0005433397518	13546	1	1A
0005433397496	13546	2	1C
0005433397479	13546	3	1F
0005433397523	13546	4	2A
0005435732136	13546	5	2D
0005433397498	13546	6	3D
0005433397494	13546	7	3F
0005433397509	13546	8	4C
0005433397506	13546	9	4D
0005433397525	13546	10	4F
0005433397508	13546	11	5A
0005433397507	13546	12	5C
0005433397495	13546	13	5D
0005433397505	13546	14	5F
0005433397477	13546	15	6C
0005433397480	13546	16	6F
0005433397484	13546	17	7A
0005433397522	13546	18	7D
0005433397485	13546	19	7F
0005433397499	13546	20	8D
0005433397492	13546	21	8F
0005433397524	13546	22	9C
0005433397510	13546	23	9D
0005433397478	13546	24	9F
0005433397481	13546	25	10E
0005433397487	13546	26	10F
0005433397489	13546	27	11F
0005433397501	13546	28	12A
0005433397512	13546	29	12D
0005433397521	13546	30	12E
0005433397493	13546	31	12F
0005433397500	13546	32	13C
0005433397511	13546	33	13E
0005433397502	13546	34	14A
0005433397519	13546	35	14D
0005433397515	13546	36	15D
0005433397513	13546	37	15E
0005433397520	13546	38	15F
0005433397482	13546	39	16A
0005433397486	13546	40	16F
0005433397517	13546	41	17A
0005433397483	13546	42	17F
0005433397503	13546	43	18A
0005433397516	13546	44	19C
0005433397514	13546	45	19D
0005433397490	13546	46	19F
0005433397491	13546	47	20A
0005433397504	13546	48	20C
0005433397488	13546	49	20D
0005433397497	13546	50	20E
0005435732184	19416	1	4F
0005435732181	19416	2	5E
0005433397377	19416	3	6E
0005432297248	19416	4	7E
0005435732182	19416	5	7F
0005433397327	19416	6	9D
0005433397206	19416	7	9E
0005435732180	19416	8	9F
0005432297250	19416	9	10F
0005435732187	19416	10	11D
0005435732185	19416	11	13D
0005435732189	19416	12	13E
0005433397376	19416	13	13F
0005433397234	19416	14	14D
0005435732193	19416	15	14E
0005432297246	19416	16	14F
0005435732192	19416	17	15A
0005435732190	19416	18	15E
0005432297249	19416	19	15F
0005435732191	19416	20	16D
0005433397308	19416	21	17A
0005433397293	19416	22	17E
0005433397205	19416	23	18A
0005435732188	19416	24	19C
0005435732183	19416	25	19F
0005435732186	19416	26	20A
0005433397378	19416	27	20C
0005432297247	19416	28	20F
0005435925140	13175	1	1A
0005435068161	13175	2	1F
0005435925142	13175	3	2A
0005435925131	13175	4	2C
0005435925137	13175	5	2D
0005435068260	13175	6	3A
0005435925130	13175	7	3D
0005435925138	13175	8	4A
0005435925147	13175	9	4E
0005435925135	13175	10	6F
0005435925146	13175	11	8C
0005435925133	13175	12	8F
0005435925129	13175	13	9C
0005435068236	13175	14	12A
0005435925134	13175	15	12F
0005435925143	13175	16	13C
0005435925141	13175	17	13F
0005435925144	13175	18	15A
0005435925145	13175	19	15C
0005435925136	13175	20	16D
0005435068181	13175	21	17A
0005435925139	13175	22	17C
0005435068162	13175	23	17D
0005435068208	13175	24	18C
0005435068211	13175	25	18D
0005435925132	13175	26	19C
0005435068238	13175	27	20E
0005435068452	15506	1	1A
0005435068436	15506	2	1C
0005435068468	15506	3	2A
0005435068447	15506	4	2C
0005435068442	15506	5	2D
0005435068462	15506	6	2F
0005435068443	15506	7	3A
0005435068473	15506	8	3C
0005435068475	15506	9	3F
0005435068432	15506	10	4C
0005435068440	15506	11	4D
0005435068430	15506	12	4F
0005435068426	15506	13	5A
0005435068424	15506	14	5D
0005435068441	15506	15	6A
0005435068464	15506	16	6D
0005435068449	15506	17	6F
0005435068472	15506	18	7A
0005435068450	15506	19	8A
0005435068470	15506	20	8D
0005435068474	15506	21	9C
0005435068425	15506	22	9E
0005435068467	15506	23	9F
0005435068445	15506	24	10A
0005435068433	15506	25	10D
0005435068471	15506	26	10E
0005435068453	15506	27	11A
0005435068457	15506	28	11C
0005435068465	15506	29	11D
0005435068423	15506	30	11F
0005435068427	15506	31	12C
0005435068469	15506	32	12A
0005435068439	15506	33	12D
0005435068458	15506	34	13C
0005435068454	15506	35	13D
0005435068438	15506	36	13E
0005435068456	15506	37	14A
0005435068431	15506	38	14C
0005435068460	15506	39	14F
0005435068429	15506	40	15C
0005435068434	15506	41	15D
0005435068428	15506	42	15E
0005435068455	15506	43	15F
0005435068437	15506	44	16A
0005435068459	15506	45	16C
0005435068461	15506	46	16D
0005435068463	15506	47	16E
0005435068451	15506	48	17E
0005435068446	15506	49	18D
0005435068444	15506	50	18E
0005435068435	15506	51	19A
0005435068466	15506	52	19D
0005435068448	15506	53	20E
0005435808102	23178	1	1A
0005435808089	23178	2	1C
0005435808092	23178	3	1D
0005435808090	23178	4	2A
0005435808094	23178	5	3B
0005435808106	23178	6	3A
0005435808096	23178	7	3D
0005435808084	23178	8	4B
0005435808083	23178	9	4C
0005435808093	23178	10	5A
0005435808081	23178	11	5B
0005435808104	23178	12	5C
0005435808091	23178	13	5D
0005435808100	23178	14	6A
0005435808098	23178	15	6B
0005435808101	23178	16	6C
0005435808110	23178	17	7A
0005435808082	23178	18	18A
0005435808097	23178	19	18B
0005435808112	23178	20	18C
0005435808087	23178	21	19B
0005435808111	23178	22	19C
0005435808103	23178	23	19D
0005435808088	23178	24	20B
0005435808099	23178	25	20C
0005435808109	23178	26	20D
0005435808108	23178	27	21A
0005435808085	23178	28	21B
0005435808107	23178	29	22A
0005435808095	23178	30	22B
0005435808086	23178	31	22D
0005435808105	23178	32	23A
0005434755728	10739	1	1A
0005434214008	10739	2	1D
0005434214024	10739	3	2A
0005434214015	10739	4	2F
0005434214005	10739	5	3A
0005434214003	10739	6	3C
0005434213989	10739	7	4C
0005434214011	10739	8	5C
0005434214019	10739	9	5F
0005434214030	10739	10	6A
0005434214021	10739	11	6D
0005434213998	10739	12	6F
0005434213994	10739	13	7A
0005434213985	10739	14	7D
0005434213997	10739	15	7F
0005434214010	10739	16	8C
0005434214009	10739	17	8D
0005434214014	10739	18	8E
0005434214029	10739	19	8F
0005434213984	10739	20	10A
0005434214026	10739	21	10C
0005434214000	10739	22	10F
0005434213995	10739	23	11A
0005434214027	10739	24	11C
0005434214023	10739	25	11E
0005434214007	10739	26	11F
0005434213990	10739	27	12E
0005434213988	10739	28	13A
0005434214022	10739	29	13C
0005434213993	10739	30	13E
0005434213986	10739	31	14C
0005434214028	10739	32	14E
0005434213987	10739	33	14F
0005434214018	10739	34	15A
0005434213999	10739	35	15D
0005434214017	10739	36	15E
0005434214004	10739	37	16C
0005434214001	10739	38	16E
0005434214012	10739	39	17A
0005434214013	10739	40	17C
0005434214016	10739	41	17E
0005434213996	10739	42	17F
0005434214006	10739	43	18F
0005434213992	10739	44	19C
0005434214020	10739	45	19E
0005434214002	10739	46	19F
0005434213991	10739	47	20E
0005434214025	10739	48	20F
0005434755948	28703	1	1D
0005434755960	28703	2	1F
0005434755924	28703	3	2A
0005434755929	28703	4	2D
0005434755947	28703	5	3C
0005434755954	28703	6	3D
0005434213706	28703	7	4A
0005434755943	28703	8	4C
0005434755940	28703	9	4D
0005434755949	28703	10	4E
0005434755932	28703	11	5F
0005434755946	28703	12	6C
0005434755923	28703	13	7D
0005434755953	28703	14	8A
0005434755942	28703	15	8C
0005434755931	28703	16	8E
0005434755933	28703	17	8F
0005434213712	28703	18	9A
0005434755944	28703	19	9D
0005434755950	28703	20	9E
0005434213705	28703	21	10A
0005434755939	28703	22	10C
0005434755935	28703	23	10E
0005434755951	28703	24	11E
0005434755925	28703	25	12A
0005434755927	28703	26	12E
0005434755937	28703	27	12F
0005434755955	28703	28	13D
0005434755945	28703	29	13F
0005434755952	28703	30	14D
0005434755936	28703	31	14E
0005434755922	28703	32	15D
0005434755941	28703	33	15E
0005434755956	28703	34	15F
0005434755930	28703	35	16A
0005434755938	28703	36	16C
0005434755957	28703	37	16F
0005434755926	28703	38	17E
0005434755934	28703	39	18F
0005434755958	28703	40	19A
0005434755928	28703	41	19D
0005434755959	28703	42	20D
0005434229074	5436	1	1C
0005435038996	5436	2	1D
0005435006759	5436	3	2A
0005435039035	5436	4	1F
0005435006757	5436	5	2C
0005435039030	5436	6	2D
0005435039052	5436	7	3A
0005435039012	5436	8	2F
0005435039018	5436	9	3D
0005435039045	5436	10	3C
0005435042832	5436	11	4B
0005435039037	5436	12	4D
0005435039034	5436	13	4C
0005435006760	5436	14	4F
0005435006750	5436	15	4E
0005435042831	5436	16	5A
0005435039023	5436	17	5C
0005435039033	5436	18	5E
0005435039003	5436	19	6A
0005435039017	5436	20	6C
0005435038992	5436	21	6D
0005435039021	5436	22	7A
0005435039051	5436	23	6F
0005435039046	5436	24	7B
0005435039000	5436	25	7C
0005435039014	5436	26	7D
0005435039004	5436	27	7E
0005435039026	5436	28	7F
0005435039031	5436	29	8B
0005435006752	5436	30	8C
0005435006761	5436	31	8D
0005435039056	5436	32	8F
0005435039039	5436	33	9A
0005432125368	5436	34	9B
0005435006764	5436	35	9C
0005435039028	5436	36	9E
0005435039022	5436	37	9D
0005435006765	5436	38	10B
0005435039050	5436	39	10D
0005435039043	5436	40	11A
0005435038990	5436	41	10E
0005435039049	5436	42	11B
0005435039010	5436	43	11D
0005432125367	5436	44	11C
0005435006749	5436	45	11F
0005435039015	5436	46	11E
0005435039048	5436	47	12D
0005435039006	5436	48	12F
0005435006755	5436	49	13B
0005432125369	5436	50	13A
0005435039044	5436	51	13C
0005435039005	5436	52	13D
0005435039041	5436	53	13E
0005435039042	5436	54	14A
0005435006756	5436	55	13F
0005435006762	5436	56	14C
0005435039025	5436	57	14D
0005435039013	5436	58	14F
0005434228992	5436	59	15A
0005435006746	5436	60	15C
0005435006758	5436	61	15B
0005435039001	5436	62	15D
0005435006747	5436	63	16A
0005435039020	5436	64	15F
0005435038998	5436	65	16C
0005434229016	5436	66	16E
0005435006751	5436	67	16D
0005435039008	5436	68	17A
0005435038994	5436	69	17B
0005435039040	5436	70	17C
0005435006748	5436	71	17D
0005435039032	5436	72	17E
0005435038997	5436	73	18A
0005435039007	5436	74	18C
0005435039027	5436	75	18E
0005435039016	5436	76	19A
0005435006763	5436	77	19D
0005432125366	5436	78	19C
0005435039054	5436	79	19E
0005435039019	5436	80	19F
0005435039057	5436	81	20C
0005435039011	5436	82	20F
0005435039038	5436	83	20E
0005435039047	5436	84	20D
0005435038993	5436	85	21B
0005435039029	5436	86	21A
0005435038999	5436	87	21D
0005435039024	5436	88	21C
0005432125365	5436	89	21E
0005435006753	5436	90	21F
0005435038991	5436	91	22A
0005435039002	5436	92	22C
0005435039036	5436	93	22E
0005432125370	5436	94	23A
0005435006754	5436	95	23B
0005435039009	5436	96	23C
0005435038995	5436	97	23D
0005435039053	5436	98	23F
0005435039055	5436	99	23E
0005434229112	12989	1	1C
0005434229107	12989	2	2F
0005434229121	12989	3	3A
0005435038675	12989	4	3F
0005434229108	12989	5	4B
0005432304356	12989	6	4A
0005434229106	12989	7	4C
0005434229110	12989	8	5A
0005434229125	12989	9	4F
0005435038706	12989	10	5B
0005434229117	12989	11	5E
0005434229126	12989	12	6D
0005435006611	12989	13	6F
0005435038715	12989	14	7D
0005434229109	12989	15	7E
0005432304353	12989	16	8A
0005434229127	12989	17	8C
0005434229120	12989	18	8F
0005435038772	12989	19	8E
0005434229122	12989	20	9B
0005435038625	12989	21	10B
0005434229104	12989	22	11B
0005432304352	12989	23	11F
0005435038707	12989	24	12C
0005435038680	12989	25	13B
0005434229116	12989	26	13E
0005435038847	12989	27	13D
0005434229115	12989	28	14A
0005434229118	12989	29	14C
0005435038773	12989	30	14D
0005434229123	12989	31	14F
0005435038711	12989	32	15D
0005435038654	12989	33	15F
0005434229124	12989	34	16A
0005434229119	12989	35	16D
0005432304355	12989	36	17C
0005434229114	12989	37	18C
0005435006612	12989	38	18E
0005434229105	12989	39	19A
0005434229113	12989	40	19B
0005435038753	12989	41	19E
0005435006618	12989	42	19F
0005435038669	12989	43	20A
0005435006606	12989	44	20D
0005435006671	12989	45	20F
0005432304354	12989	46	22A
0005435038752	12989	47	22B
0005435006670	12989	48	22E
0005434229111	12989	49	23B
0005435038636	12989	50	23E
0005434426237	14866	1	1A
0005435902393	14866	2	1D
0005434426261	14866	3	1F
0005434426255	14866	4	2D
0005434426241	14866	5	3A
0005434426245	14866	6	3C
0005432188567	14866	7	4A
0005434426249	14866	8	4D
0005434426256	14866	9	5D
0005434411725	14866	10	7A
0005434426252	14866	11	7F
0005434426246	14866	12	8E
0005432188568	14866	13	9C
0005434426238	14866	14	9D
0005434426236	14866	15	9E
0005434426250	14866	16	10C
0005434426260	14866	17	11A
0005434426264	14866	18	11D
0005434426242	14866	19	12C
0005432188566	14866	20	12E
0005434411727	14866	21	13A
0005434426239	14866	22	14C
0005434426248	14866	23	15C
0005434426244	14866	24	15D
0005434426247	14866	25	15F
0005434426254	14866	26	16C
0005434426263	14866	27	16F
0005434426257	14866	28	17A
0005434426240	14866	29	17D
0005434426258	14866	30	18A
0005434426253	14866	31	18C
0005434411724	14866	32	18D
0005434426262	14866	33	18E
0005434426259	14866	34	18F
0005434411726	14866	35	19A
0005434426243	14866	36	19E
0005434426251	14866	37	20E
0005435902506	20186	1	1A
0005435902509	20186	2	1D
0005435554135	20186	3	1F
0005435902493	20186	4	3A
0005434426085	20186	5	4A
0005432059483	20186	6	5A
0005435554134	20186	7	5C
0005435902510	20186	8	5F
0005435902505	20186	9	6A
0005435902502	20186	10	6C
0005435902495	20186	11	6F
0005435554137	20186	12	8A
0005434426111	20186	13	8C
0005435902494	20186	14	8F
0005435554133	20186	15	9A
0005435902496	20186	16	9E
0005434426086	20186	17	9F
0005435554136	20186	18	10D
0005434426113	20186	19	10F
0005435902499	20186	20	11C
0005434426094	20186	21	12C
0005435902501	20186	22	12D
0005434426120	20186	23	13A
0005435902511	20186	24	14A
0005435902497	20186	25	14C
0005435902507	20186	26	14F
0005432059482	20186	27	15E
0005435902504	20186	28	16E
0005435902500	20186	29	17F
0005434426110	20186	30	18C
0005435902508	20186	31	18F
0005435902503	20186	32	19C
0005435902498	20186	33	19E
0005434426169	20186	34	19F
0005432462491	28013	1	5C
0005432462487	28013	2	12B
0005432462490	28013	3	14E
0005432462485	28013	4	15C
0005432462489	28013	5	16A
0005432462488	28013	6	17E
0005432462486	28013	7	22F
0005434559086	30886	1	2A
0005434559084	30886	2	2C
0005434559082	30886	3	5C
0005434559087	30886	4	5D
0005434559083	30886	5	6C
0005434523741	30886	6	11C
0005434523742	30886	7	15A
0005434523746	30886	8	15F
0005434523743	30886	9	18A
0005434523744	30886	10	20E
0005434523745	30886	11	21A
0005434559085	30886	12	22B
0005433726064	30867	1	1D
0005433726063	30867	2	1A
0005433726069	30867	3	2F
0005433726066	30867	4	4E
0005433726071	30867	5	6A
0005433726074	30867	6	10E
0005433726073	30867	7	12D
0005433726072	30867	8	14A
0005433726070	30867	9	14F
0005433726075	30867	10	15E
0005433726065	30867	11	17D
0005433726068	30867	12	18B
0005433726067	30867	13	20D
0005435981766	26500	1	1A
0005435981773	26500	2	1C
0005435981759	26500	3	1D
0005435981764	26500	4	2C
0005435981777	26500	5	2D
0005435981776	26500	6	2F
0005435981769	26500	7	3A
0005435981753	26500	8	3C
0005435981748	26500	9	3D
0005435981737	26500	10	3F
0005435981756	26500	11	4A
0005433434183	26500	12	5C
0005435981761	26500	13	5D
0005432300192	26500	14	5E
0005435981782	26500	15	6A
0005432300193	26500	16	6F
0005435981745	26500	17	7C
0005435981735	26500	18	7D
0005435981780	26500	19	7E
0005435981755	26500	20	7F
0005432300195	26500	21	8C
0005435981749	26500	22	8D
0005435981740	26500	23	9A
0005435981747	26500	24	9C
0005435981774	26500	25	9D
0005435981785	26500	26	9E
0005435981771	26500	27	9F
0005435981744	26500	28	10C
0005435981736	26500	29	10D
0005435981762	26500	30	10F
0005435981746	26500	31	11D
0005435981784	26500	32	11E
0005435981775	26500	33	12A
0005435981768	26500	34	12D
0005435981752	26500	35	12E
0005435981781	26500	36	13D
0005435981765	26500	37	14A
0005435981760	26500	38	14D
0005435981778	26500	39	14F
0005435981754	26500	40	15A
0005435981758	26500	41	15C
0005435981779	26500	42	16A
0005435981739	26500	43	16D
0005433434198	26500	44	16E
0005435981751	26500	45	17A
0005435981750	26500	46	17C
0005435981783	26500	47	17D
0005435981742	26500	48	17E
0005435981741	26500	49	17F
0005433434197	26500	50	18A
0005435981757	26500	51	18C
0005435981770	26500	52	18D
0005432300194	26500	53	18E
0005435981772	26500	54	18F
0005435981767	26500	55	19A
0005435981786	26500	56	19C
0005433434182	26500	57	19D
0005433434221	26500	58	19E
0005435981788	26500	59	20A
0005435981738	26500	60	20C
0005435981763	26500	61	20D
0005435981787	26500	62	20E
0005435981743	26500	63	20F
0005435981565	26737	1	1F
0005433434379	26737	2	2A
0005432051094	26737	3	2C
0005433434368	26737	4	2F
0005433434357	26737	5	3C
0005433434360	26737	6	4A
0005433434378	26737	7	4F
0005433434371	26737	8	5A
0005433434370	26737	9	5D
0005434270183	26737	10	5E
0005433434364	26737	11	5F
0005434271289	26737	12	6C
0005433434361	26737	13	6D
0005433434375	26737	14	8A
0005434270182	26737	15	9A
0005433434359	26737	16	10A
0005433434369	26737	17	10C
0005433434356	26737	18	10F
0005433434380	26737	19	11F
0005433434355	26737	20	13D
0005433434366	26737	21	13E
0005433434373	26737	22	14A
0005432051093	26737	23	14C
0005434271288	26737	24	14E
0005433434377	26737	25	14F
0005433434363	26737	26	15D
0005432051092	26737	27	15E
0005433434372	26737	28	16A
0005433434365	26737	29	16C
0005433434362	26737	30	16D
0005433434354	26737	31	16E
0005433434358	26737	32	18C
0005435981533	26737	33	18E
0005433434376	26737	34	19A
0005433434374	26737	35	19C
0005434269080	26737	36	19E
0005433434367	26737	37	20A
0005433689875	29258	1	19A
0005432583742	3144	1	1A
0005432583738	3144	2	1B
0005432583741	3144	3	1C
0005432583743	3144	4	2A
0005432583751	3144	5	2B
0005432583750	3144	6	3A
0005432583757	3144	7	4A
0005432583754	3144	8	4B
0005432583759	3144	9	4C
0005432583747	3144	10	4D
0005432583760	3144	11	5C
0005432583736	3144	12	6A
0005432583755	3144	13	6C
0005432583753	3144	14	6D
0005432583746	3144	15	7A
0005432216239	3144	16	7B
0005432216241	3144	17	7C
0005432583761	3144	18	18A
0005432583752	3144	19	18C
0005432583739	3144	20	18D
0005432216242	3144	21	19A
0005432857858	3144	22	19B
0005432583749	3144	23	19D
0005432583737	3144	24	20B
0005432583756	3144	25	21A
0005432583758	3144	26	21C
0005432583740	3144	27	21D
0005432583745	3144	28	22A
0005432216240	3144	29	22B
0005432583744	3144	30	22C
0005432583748	3144	31	23B
0005432857924	31472	1	1A
0005432857932	31472	2	1B
0005432857931	31472	3	1D
0005432857934	31472	4	2B
0005432857933	31472	5	2C
0005432583621	31472	6	3D
0005432857935	31472	7	5B
0005432857926	31472	8	5C
0005432857927	31472	9	6C
0005432583595	31472	10	7D
0005432583620	31472	11	18D
0005432857925	31472	12	19D
0005432583603	31472	13	20C
0005432857928	31472	14	21A
0005432583604	31472	15	21D
0005432857930	31472	16	22A
0005432857929	31472	17	22D
0005434943242	895	1	4C
0005433255028	895	2	4D
0005434943246	895	3	5C
0005434943247	895	4	6B
0005434943244	895	5	6C
0005434943245	895	6	18D
0005434943249	895	7	21A
0005434943243	895	8	22A
0005434943250	895	9	22B
0005434943248	895	10	22C
0005434943190	16197	1	1A
0005434943230	16197	2	3A
0005433255058	16197	3	3D
0005434943214	16197	4	4A
0005433255059	16197	5	4D
0005433255054	16197	6	5D
0005433255056	16197	7	19A
0005434943197	16197	8	19D
0005433255057	16197	9	20B
0005434943187	16197	10	21B
0005433255055	16197	11	22B
0005434943198	16197	12	23B
0005435858513	27611	1	4F
0005435858510	27611	2	6E
0005435858509	27611	3	7B
0005433654649	27611	4	7D
0005435858508	27611	5	11A
0005435858500	27611	6	12B
0005435858504	27611	7	12F
0005435858507	27611	8	13E
0005435858502	27611	9	14F
0005435858511	27611	10	15A
0005435858505	27611	11	16A
0005435858501	27611	12	18F
0005435858503	27611	13	19D
0005435858512	27611	14	20C
0005435858506	27611	15	21E
0005435652526	21774	1	2A
0005433367241	21774	2	2C
0005435652514	21774	3	3C
0005435652515	21774	4	4A
0005435652496	21774	5	4E
0005435652506	21774	6	5A
0005435652498	21774	7	5D
0005435652516	21774	8	6A
0005435652513	21774	9	6D
0005435652522	21774	10	6E
0005435652510	21774	11	7A
0005435652497	21774	12	7E
0005435652507	21774	13	7F
0005435652499	21774	14	8A
0005435652489	21774	15	8E
0005435652492	21774	16	9A
0005433367234	21774	17	9C
0005435652500	21774	18	9D
0005435652511	21774	19	9E
0005435652519	21774	20	10A
0005435652521	21774	21	10C
0005435652505	21774	22	11F
0005435652520	21774	23	12A
0005435652493	21774	24	12C
0005435652523	21774	25	12E
0005435652518	21774	26	13A
0005435652509	21774	27	13C
0005435652524	21774	28	13D
0005435652504	21774	29	13F
0005435652502	21774	30	14C
0005435652494	21774	31	15D
0005435652495	21774	32	15F
0005435652501	21774	33	16F
0005435652503	21774	34	17A
0005435652490	21774	35	17F
0005435652491	21774	36	17E
0005435652525	21774	37	18A
0005435652517	21774	38	18C
0005435652508	21774	39	18F
0005433367223	21774	40	19D
0005435652512	21774	41	20F
0005433763046	9364	1	1A
0005433763039	9364	2	1C
0005433784540	9364	3	1B
0005433804996	9364	4	2C
0005433763045	9364	5	2B
0005433804974	9364	6	2G
0005433784532	9364	7	3A
0005433763038	9364	8	2H
0005433763037	9364	9	3B
0005432665251	9364	10	3F
0005433784528	9364	11	3C
0005433804979	9364	12	3G
0005432666363	9364	13	4G
0005433804970	9364	14	5B
0005433784520	9364	15	5F
0005433784550	9364	16	5C
0005433763041	9364	17	5G
0005433804976	9364	18	5H
0005433804982	9364	19	9B
0005433784548	9364	20	9A
0005433804985	9364	21	9H
0005433804977	9364	22	11G
0005433784546	9364	23	12A
0005433784524	9364	24	12E
0005433804993	9364	25	12F
0005433784543	9364	26	12H
0005433804981	9364	27	13D
0005434170831	9364	28	14A
0005433784537	9364	29	14D
0005433804995	9364	30	14G
0005433804969	9364	31	14H
0005433763035	9364	32	15E
0005433784538	9364	33	15G
0005433784529	9364	34	16E
0005433804972	9364	35	16D
0005433805002	9364	36	16F
0005433784522	9364	37	16H
0005433784531	9364	38	17D
0005433804989	9364	39	18B
0005433804990	9364	40	18A
0005433784536	9364	41	18G
0005432667429	9364	42	19A
0005433804991	9364	43	19D
0005433804999	9364	44	19F
0005433784525	9364	45	19H
0005433804997	9364	46	19G
0005433763040	9364	47	20B
0005433763042	9364	48	20F
0005433784530	9364	49	21E
0005433784523	9364	50	21H
0005433784535	9364	51	22G
0005433784534	9364	52	23G
0005433805001	9364	53	23F
0005433784521	9364	54	24D
0005433804973	9364	55	24F
0005433804986	9364	56	25E
0005433784545	9364	57	25F
0005434170830	9364	58	27D
0005433804987	9364	59	27B
0005434170805	9364	60	27F
0005432667431	9364	61	27G
0005433784526	9364	62	28B
0005433784519	9364	63	28F
0005433804968	9364	64	28H
0005433804992	9364	65	29D
0005433784544	9364	66	29B
0005433784542	9364	67	29G
0005433784541	9364	68	29H
0005433804994	9364	69	30A
0005433804984	9364	70	30D
0005432667430	9364	71	31A
0005433804975	9364	72	30H
0005433805000	9364	73	31B
0005432666365	9364	74	31D
0005433763034	9364	75	31G
0005432665250	9364	76	32A
0005433805003	9364	77	32F
0005433804980	9364	78	33A
0005433763036	9364	79	33B
0005433804988	9364	80	33F
0005432657414	9364	81	34D
0005432666364	9364	82	35B
0005433784527	9364	83	35A
0005433784551	9364	84	35D
0005433784533	9364	85	35F
0005433763033	9364	86	35G
0005433784547	9364	87	36A
0005433763044	9364	88	35H
0005433784549	9364	89	36D
0005433804983	9364	90	36F
0005433784552	9364	91	36E
0005433784518	9364	92	37B
0005433804978	9364	93	37G
0005433804971	9364	94	37F
0005434170829	9364	95	38A
0005433804998	9364	96	38B
0005433763043	9364	97	38G
0005433784539	9364	98	38H
0005434170895	26278	1	1F
0005433784413	26278	2	1G
0005433804806	26278	3	3A
0005433804790	26278	4	3F
0005433784378	26278	5	4B
0005434269078	26278	6	4G
0005433784366	26278	7	4F
0005434170887	26278	8	5F
0005433784326	26278	9	9G
0005434269079	26278	10	11H
0005433762981	26278	11	12B
0005433784332	26278	12	12G
0005433784341	26278	13	13B
0005433784331	26278	14	13G
0005433804842	26278	15	14A
0005434269077	26278	16	14B
0005434170885	26278	17	14E
0005434270180	26278	18	15F
0005434151671	26278	19	16F
0005434170897	26278	20	16H
0005433784305	26278	21	17E
0005434271287	26278	22	17H
0005432657394	26278	23	18A
0005434170888	26278	24	18D
0005434170898	26278	25	19F
0005434270181	26278	26	19G
0005433784306	26278	27	20A
0005434271286	26278	28	20D
0005433804841	26278	29	20F
0005434151670	26278	30	21D
0005433784303	26278	31	22A
0005434170886	26278	32	22G
0005434170892	26278	33	23A
0005434170889	26278	34	25D
0005433784304	26278	35	27E
0005433762980	26278	36	28A
0005434170890	26278	37	28B
0005434170891	26278	38	28G
0005433784330	26278	39	32A
0005434170894	26278	40	33G
0005434170893	26278	41	33H
0005434170896	26278	42	34F
0005433762947	26278	43	35E
0005433762983	26278	44	35D
0005433784379	26278	45	37D
0005435135612	4882	1	1B
0005435135613	4882	2	2D
0005435135614	4882	3	5A
0005435135616	4882	4	18B
0005435135611	4882	5	18A
0005435135615	4882	6	20A
0005435135583	33025	1	1B
0005435929612	33025	2	4C
0005435929613	33025	3	21A
0005435135582	33025	4	22D
0005434983226	9511	1	1D
0005434983230	9511	2	20B
0005434983225	9511	3	22B
0005434983227	9511	4	22C
0005434983228	9511	5	22D
0005434983229	9511	6	23B
0005434217922	27387	1	1A
0005434217919	27387	2	4B
0005434217924	27387	3	5A
0005434217923	27387	4	5B
0005434217921	27387	5	18D
0005434217920	27387	6	22D
0005433985150	24291	1	17F
0005433985126	24291	2	22H
0005433985134	24291	3	38D
0005433985371	25925	1	1F
0005433960155	25925	2	3F
0005433985374	25925	3	3C
0005433985392	25925	4	3H
0005433960147	25925	5	4B
0005433960183	25925	6	4F
0005433985394	25925	7	4G
0005433985360	25925	8	5A
0005433960185	25925	9	5F
0005433960188	25925	10	11A
0005433985390	25925	11	9H
0005433960193	25925	12	11D
0005433960204	25925	13	11G
0005433960151	25925	14	12A
0005433960174	25925	15	11H
0005433960142	25925	16	12E
0005433985358	25925	17	12F
0005433960156	25925	18	12H
0005433985396	25925	19	13B
0005433960161	25925	20	13D
0005433960205	25925	21	13G
0005433960158	25925	22	13F
0005433985383	25925	23	13H
0005433985401	25925	24	14B
0005433960165	25925	25	14D
0005433985359	25925	26	14G
0005433985400	25925	27	15A
0005433960162	25925	28	14H
0005433985388	25925	29	15E
0005433985405	25925	30	15G
0005433960169	25925	31	15H
0005433960186	25925	32	16B
0005433960178	25925	33	16E
0005433960201	25925	34	16D
0005433985389	25925	35	16F
0005433960172	25925	36	16H
0005433960181	25925	37	17D
0005433985373	25925	38	17B
0005433960184	25925	39	17E
0005433960197	25925	40	17G
0005433985375	25925	41	17F
0005433985377	25925	42	17H
0005433960146	25925	43	18G
0005433960200	25925	44	19G
0005433960167	25925	45	19F
0005433985393	25925	46	19H
0005433960179	25925	47	20F
0005433985406	25925	48	20G
0005433985367	25925	49	21B
0005433960189	25925	50	21F
0005433960198	25925	51	21H
0005433985376	25925	52	22B
0005433960171	25925	53	22A
0005433960153	25925	54	22F
0005433985370	25925	55	22H
0005433985402	25925	56	23B
0005433985366	25925	57	23A
0005433960207	25925	58	23F
0005433985381	25925	59	23G
0005433960166	25925	60	23H
0005433960180	25925	61	24B
0005433960190	25925	62	24A
0005433985403	25925	63	24D
0005433985407	25925	64	24F
0005433985361	25925	65	24E
0005433960176	25925	66	24G
0005433985362	25925	67	25E
0005433985369	25925	68	27B
0005433960187	25925	69	27D
0005433960168	25925	70	27E
0005433960194	25925	71	27G
0005433960175	25925	72	28D
0005433985372	25925	73	28E
0005433985385	25925	74	28G
0005433960206	25925	75	28F
0005433985378	25925	76	28H
0005433960182	25925	77	29D
0005433960203	25925	78	29G
0005433985364	25925	79	31A
0005433960154	25925	80	30H
0005433960191	25925	81	31B
0005433960170	25925	82	31D
0005433960192	25925	83	31F
0005433985404	25925	84	32A
0005433985397	25925	85	32E
0005433985387	25925	86	32D
0005433960152	25925	87	32G
0005433985395	25925	88	33A
0005433985399	25925	89	32H
0005433960164	25925	90	33B
0005433960143	25925	91	33H
0005433960163	25925	92	34A
0005433985386	25925	93	34B
0005433985363	25925	94	34F
0005433960145	25925	95	35A
0005433960144	25925	96	34H
0005433985380	25925	97	35D
0005433985365	25925	98	35E
0005433985379	25925	99	35G
0005433960148	25925	100	35F
0005433960196	25925	101	36A
0005433960173	25925	102	35H
0005433960159	25925	103	36D
0005433960208	25925	104	36F
0005433960202	25925	105	36G
0005433960150	25925	106	37A
0005433960195	25925	107	37D
0005433985398	25925	108	37E
0005433985391	25925	109	37F
0005433985382	25925	110	37H
0005433960199	25925	111	38A
0005433985384	25925	112	38D
0005433960157	25925	113	38B
0005433960160	25925	114	38E
0005433960149	25925	115	38F
0005433985368	25925	116	39D
0005433960177	25925	117	39F
0005434480049	930	1	1A
0005434480042	930	2	1B
0005434480032	930	3	1C
0005434480039	930	4	1D
0005433165682	930	5	2A
0005434480043	930	6	3B
0005434480036	930	7	3D
0005433165681	930	8	3C
0005433165671	930	9	4A
0005434480034	930	10	4B
0005434480053	930	11	4D
0005434480046	930	12	5A
0005432269463	930	13	5C
0005433165672	930	14	5D
0005433165670	930	15	6A
0005434480044	930	16	6C
0005434480052	930	17	7A
0005434480054	930	18	7B
0005433165691	930	19	7C
0005434480037	930	20	7D
0005433165694	930	21	18C
0005434480055	930	22	18D
0005434480045	930	23	19C
0005434480033	930	24	19D
0005433165683	930	25	20B
0005434480041	930	26	20C
0005434480047	930	27	20D
0005432269464	930	28	21B
0005434480050	930	29	21C
0005434480048	930	30	21D
0005434480035	930	31	22A
0005434480040	930	32	22B
0005434480031	930	33	22D
0005434480038	930	34	23A
0005434480051	930	35	23B
0005434479889	16556	1	1A
0005433165752	16556	2	1C
0005433165759	16556	3	2B
0005434479888	16556	4	2C
0005433165757	16556	5	4A
0005433165761	16556	6	4B
0005433165754	16556	7	4D
0005433165753	16556	8	5A
0005433165750	16556	9	5C
0005434479897	16556	10	5D
0005434479894	16556	11	6C
0005433165755	16556	12	7A
0005434479902	16556	13	7D
0005433165751	16556	14	19C
0005433165758	16556	15	20A
0005433165756	16556	16	20D
0005433165760	16556	17	22A
0005434479895	16556	18	22C
0005433165762	16556	19	23B
0005435149866	10333	1	1D
0005435149864	10333	2	2C
0005435142412	10333	3	3A
0005435142410	10333	4	4A
0005435142409	10333	5	4B
0005435142416	10333	6	5A
0005435149863	10333	7	5B
0005435142408	10333	8	6B
0005435149856	10333	9	6C
0005435149868	10333	10	6D
0005435149861	10333	11	7A
0005435149857	10333	12	7B
0005435149860	10333	13	7D
0005435142413	10333	14	18C
0005435142406	10333	15	19A
0005435149859	10333	16	19C
0005435142417	10333	17	19D
0005435149867	10333	18	20A
0005435149858	10333	19	20B
0005435142405	10333	20	20C
0005435142415	10333	21	20D
0005435149865	10333	22	21B
0005435149862	10333	23	21C
0005435149869	10333	24	22A
0005435142411	10333	25	21D
0005435142414	10333	26	22D
0005435142407	10333	27	23A
0005433289774	21913	1	1A
0005433289769	21913	2	3C
0005433289772	21913	3	4A
0005435386503	21913	4	4C
0005435386500	21913	5	6D
0005435386501	21913	6	7A
0005435386502	21913	7	7B
0005435149825	21913	8	7C
0005433289768	21913	9	18A
0005435386498	21913	10	19A
0005433289770	21913	11	19D
0005433289775	21913	12	20B
0005433289773	21913	13	21D
0005433289771	21913	14	22B
0005435386499	21913	15	23A
0005434573173	11192	1	1A
0005434573183	11192	2	1F
0005434573187	11192	3	2D
0005435319425	11192	4	3F
0005434573179	11192	5	4A
0005435501941	11192	6	4F
0005435501943	11192	7	5D
0005434573174	11192	8	6E
0005435528921	11192	9	7C
0005434573181	11192	10	7F
0005435501949	11192	11	8D
0005434573178	11192	12	8E
0005434573186	11192	13	8F
0005435319424	11192	14	11A
0005434573184	11192	15	14C
0005435501942	11192	16	14D
0005434573177	11192	17	15C
0005434573185	11192	18	15E
0005434573175	11192	19	16C
0005434573176	11192	20	16E
0005434573182	11192	21	18D
0005434573180	11192	22	19C
0005435517698	20916	1	2D
0005435319486	20916	2	2F
0005435502043	20916	3	3A
0005435319479	20916	4	3C
0005435502062	20916	5	3F
0005435517690	20916	6	4D
0005435517697	20916	7	4E
0005435319481	20916	8	4F
0005432291901	20916	9	5A
0005435502052	20916	10	5D
0005435508222	20916	11	5E
0005435502042	20916	12	5F
0005435508225	20916	13	6A
0005435502045	20916	14	6D
0005435502051	20916	15	6E
0005435517694	20916	16	6F
0005435502049	20916	17	7C
0005435319482	20916	18	7D
0005435517701	20916	19	7E
0005435517707	20916	20	7F
0005435517689	20916	21	8A
0005435508224	20916	22	8C
0005435502053	20916	23	8D
0005435517700	20916	24	8E
0005435502054	20916	25	9A
0005435502059	20916	26	9C
0005435502055	20916	27	9D
0005435319483	20916	28	9E
0005435517708	20916	29	10A
0005435517692	20916	30	10D
0005435502056	20916	31	11C
0005435319478	20916	32	11D
0005435502047	20916	33	11E
0005435502046	20916	34	12D
0005435502050	20916	35	12F
0005435517705	20916	36	13C
0005435517699	20916	37	13D
0005435319480	20916	38	13E
0005435517709	20916	39	13F
0005435508226	20916	40	14D
0005432291900	20916	41	14E
0005435502058	20916	42	14F
0005435517703	20916	43	15A
0005435517704	20916	44	15C
0005435502060	20916	45	16C
0005435517706	20916	46	16E
0005435508223	20916	47	17A
0005435517710	20916	48	17C
0005435517695	20916	49	17D
0005435502044	20916	50	17E
0005432291902	20916	51	18A
0005435319485	20916	52	18C
0005435508227	20916	53	18E
0005435517693	20916	54	18F
0005435502048	20916	55	19A
0005435502063	20916	56	19C
0005435517696	20916	57	19D
0005435319484	20916	58	19E
0005435517691	20916	59	20A
0005435502057	20916	60	20C
0005435517702	20916	61	20D
0005435502061	20916	62	20E
0005435508228	20916	63	20F
0005432692552	2990	1	7F
0005432692551	2990	2	10C
0005432706466	2989	1	1F
0005432217742	2989	2	2A
0005432706470	2989	3	2D
0005432880572	2989	4	2F
0005433123580	2989	5	3C
0005432706485	2989	6	3F
0005432706469	2989	7	4A
0005432706473	2989	8	4F
0005432706483	2989	9	5A
0005432880557	2989	10	5D
0005433123586	2989	11	5E
0005432706489	2989	12	6C
0005432706468	2989	13	6D
0005432706472	2989	14	7C
0005432706465	2989	15	7D
0005432706476	2989	16	8A
0005432706475	2989	17	9A
0005432706488	2989	18	9F
0005432706479	2989	19	10E
0005433123571	2989	20	10F
0005432880554	2989	21	11F
0005432706477	2989	22	12A
0005432706482	2989	23	12F
0005432217743	2989	24	13F
0005432706486	2989	25	14C
0005432706480	2989	26	14E
0005432217744	2989	27	15A
0005433123581	2989	28	15D
0005432706471	2989	29	16A
0005432706467	2989	30	16C
0005432706484	2989	31	16F
0005433123587	2989	32	18A
0005433123593	2989	33	18D
0005432706487	2989	34	19A
0005432706474	2989	35	19E
0005432706478	2989	36	20A
0005433123609	2989	37	20E
0005432706481	2989	38	20F
0005432692734	29944	1	1A
0005432692719	29944	2	1C
0005432706317	29944	3	1F
0005433123679	29944	4	2A
0005432692725	29944	5	2C
0005432692743	29944	6	3A
0005432692747	29944	7	3C
0005432706374	29944	8	4A
0005433123697	29944	9	4D
0005432692720	29944	10	4E
0005432706400	29944	11	4F
0005432692729	29944	12	5A
0005433123686	29944	13	5C
0005433123685	29944	14	5D
0005433123682	29944	15	5E
0005432692730	29944	16	5F
0005432880647	29944	17	6A
0005432692737	29944	18	6C
0005432706401	29944	19	6D
0005432880649	29944	20	6F
0005433123692	29944	21	7A
0005432692733	29944	22	7C
0005433123681	29944	23	7D
0005432880648	29944	24	7F
0005433123680	29944	25	8C
0005432692741	29944	26	8D
0005433123691	29944	27	8E
0005432880651	29944	28	8F
0005433123688	29944	29	9A
0005432706311	29944	30	9D
0005432692731	29944	31	10C
0005433123689	29944	32	10E
0005432692726	29944	33	11A
0005432692724	29944	34	11C
0005432880644	29944	35	11D
0005432692732	29944	36	11E
0005432880643	29944	37	11F
0005432706312	29944	38	12A
0005432880645	29944	39	12D
0005432880650	29944	40	12E
0005432692742	29944	41	12F
0005432692740	29944	42	13C
0005432692727	29944	43	13D
0005432692736	29944	44	13E
0005432692721	29944	45	14A
0005432880653	29944	46	14C
0005433123695	29944	47	14D
0005432692722	29944	48	14E
0005433123683	29944	49	14F
0005432692739	29944	50	15C
0005433123687	29944	51	15D
0005432880646	29944	52	15E
0005433123694	29944	53	16C
0005432692745	29944	54	16D
0005432880655	29944	55	16E
0005432692718	29944	56	17A
0005432692746	29944	57	17C
0005432692728	29944	58	17D
0005433123698	29944	59	17E
0005432880642	29944	60	17F
0005432880654	29944	61	18A
0005432706373	29944	62	18C
0005433123693	29944	63	18D
0005432692735	29944	64	18E
0005432880641	29944	65	18F
0005432692744	29944	66	19A
0005432880652	29944	67	19C
0005432692738	29944	68	19D
0005432692723	29944	69	19F
0005432692717	29944	70	20C
0005433123696	29944	71	20D
0005433123690	29944	72	20E
0005433123684	29944	73	20F
0005434979430	23686	1	1A
0005434979409	23686	2	1B
0005434979435	23686	3	1C
0005434988607	23686	4	1D
0005434979436	23686	5	2C
0005434979434	23686	6	3B
0005434988604	23686	7	3C
0005434979425	23686	8	3D
0005434979428	23686	9	4B
0005434979433	23686	10	4C
0005434979419	23686	11	4D
0005434988602	23686	12	5A
0005434979416	23686	13	5B
0005434979424	23686	14	5C
0005434979418	23686	15	5D
0005434979415	23686	16	6A
0005434979407	23686	17	6B
0005434979432	23686	18	6D
0005434979431	23686	19	7B
0005434979421	23686	20	7C
0005434988600	23686	21	7D
0005434988603	23686	22	18A
0005434979410	23686	23	18D
0005434979411	23686	24	19A
0005434979414	23686	25	19C
0005434979426	23686	26	19D
0005434979429	23686	27	20A
0005434979412	23686	28	20B
0005434988606	23686	29	20C
0005434979417	23686	30	20D
0005434979413	23686	31	21A
0005434979422	23686	32	21B
0005434979423	23686	33	21D
0005434979420	23686	34	22A
0005434988599	23686	35	22B
0005434979427	23686	36	22C
0005434988605	23686	37	22D
0005434979408	23686	38	23A
0005434988601	23686	39	23B
0005434302405	10282	1	3C
0005434302407	10282	2	5B
0005434302404	10282	3	6C
0005434302406	10282	4	20A
0005434302382	19616	1	4A
0005433113509	19616	2	7C
0005433113510	19616	3	18C
0005435068514	3546	1	1C
0005435068526	3546	2	1D
0005435068515	3546	3	2C
0005435068513	3546	4	2D
0005435068479	3546	5	2F
0005435068511	3546	6	3A
0005435068505	3546	7	3C
0005435718876	3546	8	3D
0005435068486	3546	9	3F
0005435068487	3546	10	4A
0005435068528	3546	11	4C
0005435068521	3546	12	5C
0005435068506	3546	13	5E
0005435068482	3546	14	5F
0005435068523	3546	15	6C
0005435068488	3546	16	6D
0005435068490	3546	17	7C
0005435068519	3546	18	7D
0005435068499	3546	19	7E
0005435068495	3546	20	7F
0005435068525	3546	21	8A
0005435068517	3546	22	8C
0005435068507	3546	23	8D
0005435068492	3546	24	8E
0005435718877	3546	25	8F
0005435718878	3546	26	9A
0005435068501	3546	27	9C
0005435718875	3546	28	9D
0005435068498	3546	29	9E
0005435068481	3546	30	9F
0005435068520	3546	31	10A
0005435068518	3546	32	10C
0005435068496	3546	33	10D
0005435068478	3546	34	10E
0005435068491	3546	35	10F
0005435068509	3546	36	11F
0005435718872	3546	37	12C
0005435068512	3546	38	12D
0005435068508	3546	39	12F
0005435068502	3546	40	13A
0005435068480	3546	41	13C
0005435068527	3546	42	13D
0005435068489	3546	43	13F
0005435068503	3546	44	14A
0005435068493	3546	45	14C
0005435068477	3546	46	14D
0005435068484	3546	47	14E
0005435068494	3546	48	14F
0005435718871	3546	49	15A
0005435718874	3546	50	15C
0005435068500	3546	51	15E
0005435068522	3546	52	16C
0005435068524	3546	53	16D
0005435068497	3546	54	16F
0005435068476	3546	55	17A
0005435068483	3546	56	18C
0005435068504	3546	57	18D
0005435068516	3546	58	18F
0005435718873	3546	59	20A
0005435068510	3546	60	20C
0005435068485	3546	61	20F
0005435925142	15296	1	1D
0005435925135	15296	2	3C
0005435925133	15296	3	4C
0005435925134	15296	4	5A
0005435925143	15296	5	5E
0005435925137	15296	6	6E
0005435925138	15296	7	7E
0005435068238	15296	8	7F
0005435925130	15296	9	8A
0005435925144	15296	10	8D
0005435068181	15296	11	9A
0005435068208	15296	12	11A
0005435925146	15296	13	11D
0005435925145	15296	14	11F
0005435068161	15296	15	12F
0005435925139	15296	16	13A
0005435925136	15296	17	13F
0005435925129	15296	18	14C
0005435925132	15296	19	14D
0005435939863	15296	20	14F
0005435068236	15296	21	15A
0005435925147	15296	22	15C
0005435925131	15296	23	15F
0005435925141	15296	24	16E
0005435925140	15296	25	17A
0005435068162	15296	26	18C
0005435068211	15296	27	18F
0005435068260	15296	28	20D
0005432660793	18173	1	2A
0005432658567	18173	2	3A
0005432659683	18173	3	3B
0005432660794	18173	4	5A
0005432659682	18173	5	6A
0005432901324	184	1	2D
0005432901307	184	2	5D
0005432901320	184	3	8D
0005432919520	184	4	11B
0005432901299	184	5	12D
0005432901339	184	6	13F
0005432901310	184	7	17A
0005432901327	184	8	17F
0005432157469	184	9	19C
0005432157470	184	10	20D
0005432901294	184	11	21D
0005432919519	184	12	22A
0005432901321	184	13	23E
0005432919541	184	14	27E
0005432901311	184	15	29B
0005432901340	184	16	30C
0005432261401	182	1	2A
0005432817137	182	2	2D
0005432261381	182	3	2C
0005432261383	182	4	3F
0005432817146	182	5	5A
0005432817121	182	6	4F
0005432817135	182	7	5D
0005432261409	182	8	5F
0005432817128	182	9	6C
0005432817133	182	10	7A
0005432817119	182	11	7C
0005432261405	182	12	8D
0005432261389	182	13	9A
0005432288948	182	14	9B
0005432288949	182	15	9F
0005432261411	182	16	9E
0005432261384	182	17	10A
0005432817132	182	18	10D
0005432261395	182	19	10E
0005432817124	182	20	11C
0005432261375	182	21	11E
0005432261372	182	22	11D
0005432817148	182	23	12A
0005432207629	182	24	12C
0005432261374	182	25	12F
0005432261376	182	26	12E
0005432817145	182	27	13A
0005432817127	182	28	13C
0005432207630	182	29	13D
0005432261379	182	30	13E
0005432261388	182	31	13F
0005432261378	182	32	14B
0005433690893	182	33	14D
0005432261398	182	34	15C
0005432817122	182	35	15D
0005432261408	182	36	16A
0005432817142	182	37	15F
0005432261390	182	38	16D
0005432261400	182	39	16F
0005432817144	182	40	17C
0005432261410	182	41	17D
0005432817140	182	42	18A
0005432817134	182	43	18D
0005432817126	182	44	18F
0005432261406	182	45	19C
0005432261404	182	46	20A
0005432261382	182	47	19E
0005432261387	182	48	20C
0005432261396	182	49	20E
0005432207631	182	50	20F
0005432261391	182	51	21B
0005432261393	182	52	21D
0005432817141	182	53	22A
0005432261412	182	54	22B
0005432817131	182	55	22E
0005432817123	182	56	23A
0005432261394	182	57	23C
0005432261370	182	58	23B
0005432261402	182	59	23D
0005432261397	182	60	23E
0005432261386	182	61	24B
0005432261399	182	62	24C
0005432817130	182	63	24D
0005432261392	182	64	25A
0005432261403	182	65	26A
0005432288950	182	66	26B
0005432261407	182	67	26C
0005432288947	182	68	26E
0005432817147	182	69	26D
0005432261413	182	70	26F
0005432261414	182	71	27A
0005432817139	182	72	27B
0005432261385	182	73	27D
0005432261371	182	74	27F
0005432817149	182	75	27E
0005432817143	182	76	28A
0005432261368	182	77	28D
0005432817136	182	78	29A
0005432261380	182	79	28F
0005434153520	182	80	29B
0005432261373	182	81	29D
0005432817120	182	82	29F
0005432261377	182	83	30A
0005432817129	182	84	30C
0005434153519	182	85	30F
0005432817125	182	86	31A
0005432817138	182	87	31B
0005432261369	182	88	31F
0005433690890	182	89	31E
0005433101530	8018	1	1D
0005432019954	8018	2	1C
0005433101518	8018	3	2A
0005432019956	8018	4	1F
0005432919624	8018	5	2D
0005432677531	8018	6	2C
0005432919615	8018	7	2F
0005433101558	8018	8	3A
0005433101576	8018	9	4A
0005433101581	8018	10	3F
0005432019948	8018	11	4C
0005432019955	8018	12	4F
0005432019953	8018	13	5D
0005433101579	8018	14	5F
0005432019959	8018	15	6C
0005432019960	8018	16	6A
0005432919614	8018	17	6D
0005433101560	8018	18	7A
0005433101569	8018	19	7F
0005432677530	8018	20	7D
0005432753262	8018	21	8B
0005433101524	8018	22	8C
0005432045592	8018	23	8E
0005432019951	8018	24	8F
0005433101547	8018	25	9B
0005433101575	8018	26	9A
0005432019950	8018	27	9C
0005433101572	8018	28	9D
0005433101543	8018	29	10A
0005433101566	8018	30	9F
0005432919625	8018	31	10B
0005433101520	8018	32	10C
0005432019969	8018	33	10E
0005432044493	8018	34	10D
0005433101551	8018	35	10F
0005432677529	8018	36	11B
0005433101563	8018	37	11C
0005432019944	8018	38	11D
0005432919619	8018	39	11E
0005432919627	8018	40	11F
0005433101571	8018	41	12B
0005433101587	8018	42	12A
0005433101529	8018	43	12D
0005433101554	8018	44	12C
0005433101542	8018	45	12E
0005433101582	8018	46	12F
0005433101533	8018	47	13A
0005433101523	8018	48	13C
0005432919623	8018	49	13B
0005433101548	8018	50	13D
0005432919612	8018	51	13E
0005432751488	8018	52	13F
0005432019945	8018	53	14B
0005432019967	8018	54	14C
0005432019964	8018	55	14E
0005433101540	8018	56	14D
0005433101517	8018	57	14F
0005432019966	8018	58	15D
0005432019946	8018	59	15F
0005432919626	8018	60	15E
0005433101549	8018	61	16A
0005432391966	8018	62	16B
0005433101568	8018	63	16C
0005432919611	8018	64	16E
0005432753263	8018	65	17C
0005433101537	8018	66	17B
0005432019957	8018	67	17D
0005432391965	8018	68	18A
0005432919617	8018	69	17F
0005432019947	8018	70	18C
0005432919621	8018	71	18B
0005432751489	8018	72	18E
0005433101552	8018	73	18D
0005433101521	8018	74	18F
0005433101535	8018	75	19B
0005433101584	8018	76	19D
0005433101556	8018	77	20A
0005432919620	8018	78	19E
0005432044492	8018	79	20B
0005432019970	8018	80	20C
0005433101580	8018	81	20D
0005432919618	8018	82	20F
0005433101545	8018	83	20E
0005432019958	8018	84	21A
0005433101534	8018	85	21C
0005433101526	8018	86	21B
0005433101527	8018	87	21D
0005433101546	8018	88	21E
0005433101531	8018	89	22A
0005433101559	8018	90	21F
0005432753265	8018	91	22D
0005433101561	8018	92	22C
0005432677528	8018	93	22E
0005432019965	8018	94	22F
0005433101583	8018	95	23A
0005432677532	8018	96	23C
0005433101532	8018	97	23B
0005432019962	8018	98	23D
0005433101522	8018	99	23F
0005433101578	8018	100	24F
0005432919630	8018	101	25A
0005433101570	8018	102	25C
0005433101550	8018	103	25B
0005432044494	8018	104	25D
0005433101586	8018	105	25E
0005433101555	8018	106	26A
0005432919628	8018	107	26C
0005433101528	8018	108	26B
0005432919622	8018	109	26D
0005433101557	8018	110	26E
0005432019968	8018	111	26F
0005433101577	8018	112	27B
0005432751490	8018	113	27A
0005433101525	8018	114	27C
0005432919613	8018	115	27D
0005432019949	8018	116	27F
0005433101565	8018	117	27E
0005432919616	8018	118	28B
0005433101567	8018	119	28D
0005432753264	8018	120	28C
0005432919610	8018	121	28E
0005433101588	8018	122	28F
0005433101538	8018	123	29B
0005433101544	8018	124	29A
0005433101564	8018	125	29C
0005433101536	8018	126	29D
0005433101519	8018	127	29F
0005432751491	8018	128	29E
0005433101574	8018	129	30A
0005432019963	8018	130	30D
0005433101541	8018	131	30C
0005433101562	8018	132	30E
0005432919629	8018	133	30F
0005433101585	8018	134	31A
0005433101553	8018	135	31B
0005433101573	8018	136	31D
0005433101539	8018	137	31C
0005432019961	8018	138	31E
0005432019952	8018	139	31F
0005432816963	8019	1	6A
0005432901409	8019	2	8A
0005432002052	8019	3	8E
0005432901416	8019	4	9E
0005432901410	8019	5	10B
0005432901407	8019	6	10D
0005432901402	8019	7	10F
0005432002053	8019	8	11E
0005432901404	8019	9	13B
0005432901406	8019	10	16F
0005432901405	8019	11	18B
0005432901414	8019	12	20C
0005432901415	8019	13	21A
0005432901408	8019	14	22C
0005432002054	8019	15	24A
0005432901412	8019	16	23F
0005432901418	8019	17	24E
0005432901403	8019	18	25A
0005432901417	8019	19	26A
0005432901411	8019	20	26E
0005432901413	8019	21	28C
0005433870705	9658	1	4A
0005433870706	9658	2	5B
0005433870695	32342	1	1B
0005434175707	32342	2	2A
0005434175705	32342	3	3A
0005434175703	32342	4	4B
0005434175702	32342	5	5B
0005434175706	32342	6	6A
0005434175704	32342	7	6B
0005435125926	3511	1	1H
0005434426286	3511	2	1D
0005434937932	3511	3	2C
0005435125928	3511	4	2G
0005434877181	3511	5	3C
0005434426271	3511	6	3K
0005432611665	3511	7	4C
0005434937930	3511	8	4A
0005434877167	3511	9	4G
0005432799138	3511	10	4D
0005432611664	3511	11	5A
0005432799133	3511	12	4K
0005432799147	3511	13	5G
0005434877141	3511	14	11A
0005434877201	3511	15	5H
0005434877194	3511	16	11F
0005434877143	3511	17	11H
0005435125918	3511	18	11G
0005434877206	3511	19	12C
0005434426293	3511	20	12E
0005434877199	3511	21	12G
0005435125912	3511	22	12H
0005435625973	3511	23	13D
0005434877234	3511	24	13A
0005434877203	3511	25	13F
0005435125922	3511	26	13H
0005434877219	3511	27	13G
0005434877164	3511	28	14A
0005435125911	3511	29	13K
0005434877177	3511	30	14D
0005432611666	3511	31	14G
0005435125909	3511	32	14F
0005434426273	3511	33	14E
0005434877148	3511	34	14H
0005434937924	3511	35	15C
0005432613814	3511	36	15A
0005435125901	3511	37	15F
0005434877179	3511	38	15E
0005434426269	3511	39	15D
0005434877202	3511	40	15H
0005432799151	3511	41	16A
0005434877197	3511	42	16F
0005435625971	3511	43	16E
0005434877151	3511	44	16D
0005434877173	3511	45	16H
0005435625983	3511	46	17A
0005434877175	3511	47	17G
0005434877190	3511	48	17H
0005434877139	3511	49	18B
0005435125897	3511	50	18A
0005434937917	3511	51	18E
0005434877196	3511	52	18G
0005434426290	3511	53	18F
0005435902399	3511	54	18J
0005435625981	3511	55	18H
0005435625977	3511	56	19A
0005434426282	3511	57	19D
0005432799135	3511	58	19C
0005434426279	3511	59	19E
0005434877163	3511	60	19G
0005432799137	3511	61	19K
0005435625972	3511	62	19J
0005435125902	3511	63	20C
0005434877214	3511	64	20B
0005432613817	3511	65	20E
0005434877176	3511	66	20D
0005434877217	3511	67	20F
0005434877224	3511	68	21A
0005434426277	3511	69	20K
0005434426289	3511	70	21C
0005432799136	3511	71	21F
0005434937913	3511	72	21E
0005435125927	3511	73	21G
0005432799139	3511	74	22A
0005435125907	3511	75	21K
0005432799130	3511	76	22B
0005434877147	3511	77	22F
0005434877188	3511	78	22E
0005432188572	3511	79	22D
0005434877170	3511	80	22H
0005432799129	3511	81	22G
0005432799149	3511	82	22K
0005432188570	3511	83	23A
0005434877218	3511	84	23G
0005432613813	3511	85	23F
0005435125919	3511	86	23J
0005434877168	3511	87	24D
0005434877189	3511	88	23K
0005434937922	3511	89	24F
0005435125932	3511	90	25A
0005432799152	3511	91	25C
0005434877210	3511	92	25F
0005432799143	3511	93	25H
0005432799140	3511	94	26C
0005434426294	3511	95	26B
0005434937912	3511	96	26E
0005432611663	3511	97	26G
0005434937919	3511	98	26F
0005435125915	3511	99	26K
0005434877193	3511	100	26H
0005432183442	3511	101	27B
0005432613818	3511	102	27A
0005434426278	3511	103	27C
0005435125923	3511	104	27F
0005435625975	3511	105	27E
0005434877174	3511	106	27D
0005434426284	3511	107	28A
0005434877208	3511	108	28E
0005434937927	3511	109	28D
0005435125924	3511	110	28C
0005432799142	3511	111	28G
0005434877165	3511	112	28F
0005435125937	3511	113	28J
0005432799131	3511	114	28H
0005432799127	3511	115	29A
0005432188569	3511	116	29C
0005435625978	3511	117	29B
0005435125921	3511	118	29F
0005435125917	3511	119	29K
0005434877192	3511	120	29J
0005434877162	3511	121	30C
0005434877146	3511	122	30B
0005432799126	3511	123	30A
0005435125916	3511	124	30E
0005434937925	3511	125	30D
0005434877230	3511	126	30F
0005434877213	3511	127	30H
0005434877158	3511	128	31B
0005434877233	3511	129	31C
0005435125900	3511	130	31E
0005435625982	3511	131	31H
0005434877159	3511	132	31K
0005432799144	3511	133	32E
0005435125899	3511	134	32C
0005434877155	3511	135	32H
0005435125908	3511	136	32G
0005434877180	3511	137	33A
0005434877185	3511	138	32K
0005435902398	3511	139	33C
0005432799132	3511	140	33F
0005434877154	3511	141	33E
0005434937923	3511	142	33H
0005434877142	3511	143	34A
0005434877153	3511	144	33K
0005434426291	3511	145	33J
0005434426281	3511	146	34C
0005435125913	3511	147	34B
0005434877200	3511	148	34D
0005434877183	3511	149	34G
0005434426268	3511	150	34F
0005435125904	3511	151	34J
0005434877184	3511	152	34H
0005432799153	3511	153	35C
0005434937914	3511	154	35B
0005435125903	3511	155	35F
0005435125925	3511	156	35J
0005434426270	3511	157	35H
0005434877178	3511	158	36A
0005434937928	3511	159	36B
0005434426266	3511	160	36D
0005434877160	3511	161	36G
0005435625979	3511	162	36J
0005435125914	3511	163	36H
0005435125934	3511	164	37A
0005435125905	3511	165	37E
0005434877227	3511	166	37D
0005434877152	3511	167	37C
0005434877157	3511	168	37F
0005434877187	3511	169	37J
0005432799150	3511	170	37H
0005434937931	3511	171	38A
0005434877216	3511	172	37K
0005434877207	3511	173	38C
0005434877140	3511	174	38K
0005434877225	3511	175	38J
0005434877171	3511	176	38H
0005434877209	3511	177	39D
0005432183441	3511	178	39C
0005434426287	3511	179	39E
0005434877204	3511	180	39H
0005434937920	3511	181	39G
0005434937929	3511	182	39K
0005434937926	3511	183	40C
0005434877169	3511	184	40E
0005435625976	3511	185	40D
0005434426283	3511	186	40G
0005435125936	3511	187	40F
0005435125920	3511	188	40J
0005435125906	3511	189	40H
0005434877149	3511	190	40K
0005434877186	3511	191	41D
0005434426267	3511	192	41C
0005434937915	3511	193	41B
0005434426265	3511	194	41E
0005434877172	3511	195	42A
0005434877138	3511	196	41J
0005434426288	3511	197	42B
0005434877166	3511	198	42G
0005432799148	3511	199	42F
0005432188571	3511	200	42K
0005434877232	3511	201	42J
0005434877191	3511	202	42H
0005432799145	3511	203	43B
0005434877198	3511	204	43F
0005434877145	3511	205	43E
0005434877195	3511	206	43H
0005434937918	3511	207	43G
0005434426272	3511	208	44B
0005435125929	3511	209	44D
0005434877150	3511	210	44C
0005432611667	3511	211	44G
0005434937916	3511	212	44F
0005432613816	3511	213	44K
0005432799128	3511	214	44J
0005432613815	3511	215	44H
0005434877156	3511	216	45A
0005434877231	3511	217	45D
0005434877144	3511	218	45C
0005432799146	3511	219	45F
0005434426274	3511	220	45E
0005432799141	3511	221	45H
0005434877215	3511	222	45G
0005435125898	3511	223	46A
0005434426280	3511	224	46B
0005434877226	3511	225	46E
0005434426292	3511	226	46H
0005434877161	3511	227	46G
0005434426285	3511	228	46F
0005434426276	3511	229	47D
0005435625980	3511	230	47C
0005434877211	3511	231	47G
0005432799134	3511	232	47F
0005434877212	3511	233	47E
0005435125933	3511	234	47K
0005434877220	3511	235	48A
0005435125910	3511	236	48E
0005434877182	3511	237	48G
0005434877221	3511	238	49A
0005434426275	3511	239	48K
0005435125935	3511	240	49E
0005434877229	3511	241	49D
0005435125931	3511	242	49C
0005435125930	3511	243	49F
0005434877223	3511	244	49K
0005432799154	3511	245	50C
0005434877222	3511	246	50A
0005434877228	3511	247	50E
0005434937921	3511	248	50G
0005435625974	3511	249	50K
0005434877205	3511	250	51E
0005434426295	3511	251	51G
0005434876574	14576	1	1G
0005434876782	14576	2	2K
0005434426113	14576	3	4C
0005435125668	14576	4	4G
0005434426111	14576	5	4K
0005435902496	14576	6	11A
0005434876630	14576	7	5K
0005435902503	14576	8	11K
0005434876571	14576	9	13F
0005435902502	14576	10	14H
0005435902510	14576	11	15E
0005434876784	14576	12	15H
0005432798957	14576	13	16D
0005435913891	14576	14	16G
0005434876611	14576	15	17C
0005432059482	14576	16	17G
0005435125649	14576	17	18H
0005434937877	14576	18	18K
0005432799008	14576	19	19H
0005435125684	14576	20	20B
0005434937831	14576	21	20K
0005434876575	14576	22	21D
0005434426120	14576	23	21G
0005434426094	14576	24	21H
0005435842320	14576	25	22G
0005435902511	14576	26	23A
0005434426086	14576	27	24D
0005435902494	14576	28	23J
0005435902498	14576	29	24F
0005435842319	14576	30	25A
0005434937829	14576	31	24G
0005434937802	14576	32	25E
0005435842321	14576	33	25H
0005434937813	14576	34	26B
0005435902504	14576	35	26E
0005435842322	14576	36	26F
0005434876576	14576	37	26H
0005435902505	14576	38	27F
0005434876686	14576	39	28E
0005434876582	14576	40	28G
0005434937806	14576	41	29H
0005435125669	14576	42	30K
0005435902501	14576	43	31D
0005435913892	14576	44	31C
0005435902497	14576	45	32C
0005434876783	14576	46	32K
0005432059483	14576	47	33F
0005434937828	14576	48	33J
0005434876626	14576	49	34G
0005434876581	14576	50	35B
0005435902495	14576	51	35G
0005435902493	14576	52	35J
0005434876586	14576	53	36J
0005435902507	14576	54	37B
0005434876606	14576	55	38B
0005434876556	14576	56	39G
0005435841813	14576	57	40F
0005434876632	14576	58	40J
0005435902509	14576	59	40K
0005434876717	14576	60	41G
0005432611653	14576	61	42H
0005435902499	14576	62	43A
0005435913889	14576	63	43F
0005434876588	14576	64	43E
0005434937799	14576	65	44A
0005434876617	14576	66	44E
0005435902500	14576	67	44K
0005434876650	14576	68	45D
0005434876555	14576	69	45J
0005435913890	14576	70	46D
0005434426085	14576	71	46H
0005435902506	14576	72	46G
0005434937832	14576	73	46F
0005435125657	14576	74	46J
0005434937827	14576	75	47E
0005434876625	14576	76	48H
0005435902508	14576	77	48K
0005432798958	14576	78	49G
0005434937876	14576	79	49K
0005434426169	14576	80	49H
0005434426110	14576	81	51G
0005432799007	14576	82	51F
0005435889796	3614	1	1C
0005434312294	3614	2	2C
0005434325517	3614	3	2D
0005434325514	3614	4	3D
0005434325520	3614	5	5A
0005434325515	3614	6	5B
0005434325521	3614	7	6C
0005435889797	3614	8	7C
0005434325518	3614	9	18A
0005434325523	3614	10	18B
0005434325524	3614	11	19B
0005434312295	3614	12	20A
0005434325516	3614	13	20B
0005434325525	3614	14	20C
0005434325519	3614	15	21B
0005434325522	3614	16	21C
0005434325459	15630	1	1A
0005435889827	15630	2	1B
0005435889828	15630	3	1C
0005434325474	15630	4	2A
0005434325443	15630	5	3A
0005434325478	15630	6	3C
0005435889831	15630	7	4B
0005434325462	15630	8	5A
0005435889825	15630	9	5C
0005435889826	15630	10	6D
0005434325469	15630	11	18C
0005434325446	15630	12	19A
0005434325472	15630	13	20A
0005435889830	15630	14	20D
0005434325463	15630	15	21A
0005435889829	15630	16	21D
0005434325473	15630	17	22B
0005435957530	658	1	1D
0005435957540	658	2	2B
0005435957541	658	3	2D
0005433420266	658	4	3C
0005435957538	658	5	3D
0005435957537	658	6	5D
0005435957543	658	7	6A
0005435957536	658	8	6B
0005435957539	658	9	6C
0005435957533	658	10	7D
0005435957542	658	11	18A
0005435957532	658	12	18D
0005435957535	658	13	19C
0005435957534	658	14	20A
0005435957531	658	15	21C
0005435957529	658	16	22A
0005433420306	15176	1	1B
0005435957480	15176	2	1C
0005433420303	15176	3	2A
0005433420301	15176	4	3C
0005433420304	15176	5	3D
0005433420305	15176	6	5B
0005435957441	15176	7	5C
0005433420302	15176	8	18C
0005433420309	15176	9	19D
0005433420307	15176	10	20B
0005435957453	15176	11	21A
0005433420308	15176	12	23B
0005434247118	16034	1	1A
0005434247119	16034	2	2B
0005434247117	16034	3	4A
0005434096720	20174	1	3A
0005434096715	20174	2	7D
0005434096716	20174	3	18C
0005434096714	20174	4	19A
0005434096719	20174	5	20A
0005434096718	20174	6	21D
0005434096717	20174	7	22D
0005435229352	25115	1	1F
0005435229341	25115	2	3F
0005435229343	25115	3	5F
0005435229333	25115	4	6C
0005435229336	25115	5	6E
0005432645769	25115	6	7A
0005435229345	25115	7	7C
0005435229342	25115	8	7D
0005435229338	25115	9	8D
0005435229344	25115	10	8F
0005435229331	25115	11	9A
0005435229346	25115	12	9F
0005435229349	25115	13	10C
0005435229348	25115	14	10F
0005435229350	25115	15	11C
0005435229332	25115	16	11E
0005435229339	25115	17	12A
0005435229334	25115	18	12C
0005435229337	25115	19	14F
0005435229347	25115	20	15A
0005435229340	25115	21	18A
0005435229335	25115	22	18F
0005432645771	25115	23	19C
0005435229351	25115	24	20E
0005435797313	2834	1	2C
0005435797311	2834	2	3F
0005435797320	2834	3	7D
0005435797309	2834	4	8F
0005435797322	2834	5	9A
0005435797310	2834	6	9C
0005435797316	2834	7	13C
0005435797314	2834	8	14E
0005435797318	2834	9	15F
0005435797312	2834	10	16C
0005435797315	2834	11	17D
0005435797319	2834	12	18C
0005435797317	2834	13	20A
0005435797321	2834	14	20C
0005435797280	29301	1	5D
0005435797273	29301	2	5E
0005435797235	29301	3	7C
0005433404725	29301	4	8D
0005433404722	29301	5	8F
0005433404728	29301	6	9D
0005433404723	29301	7	10F
0005435797236	29301	8	11A
0005435797291	29301	9	11C
0005433404726	29301	10	13D
0005433404727	29301	11	14A
0005433404724	29301	12	19A
0005435797281	29301	13	20A
0005434947922	5837	1	1B
0005434947927	5837	2	2A
0005434947928	5837	3	2B
0005434947924	5837	4	3A
0005434947929	5837	5	3B
0005434947923	5837	6	4A
0005434947926	5837	7	4B
0005434947925	5837	8	5B
0005434947930	5837	9	6B
0005433960238	6868	1	1A
0005433960219	6868	2	1D
0005433960264	6868	3	2A
0005433960253	6868	4	2C
0005433960220	6868	5	2D
0005433960227	6868	6	3A
0005433960226	6868	7	3C
0005433960212	6868	8	3F
0005433960256	6868	9	4C
0005433960244	6868	10	4E
0005433960241	6868	11	4F
0005433960240	6868	12	5A
0005433960265	6868	13	5E
0005433960262	6868	14	6A
0005433960247	6868	15	6C
0005433960224	6868	16	6D
0005433960246	6868	17	6F
0005433960222	6868	18	7A
0005433960210	6868	19	7C
0005433960211	6868	20	7D
0005433960255	6868	21	7F
0005433960214	6868	22	8C
0005433960221	6868	23	8D
0005433960248	6868	24	8F
0005433960261	6868	25	9A
0005433960254	6868	26	9C
0005433960216	6868	27	9F
0005433960233	6868	28	10A
0005433960260	6868	29	10C
0005433960252	6868	30	11C
0005433960231	6868	31	11D
0005433960239	6868	32	11E
0005433960266	6868	33	12A
0005433960245	6868	34	12C
0005433960251	6868	35	12D
0005433960232	6868	36	13C
0005433960243	6868	37	13D
0005433960258	6868	38	13E
0005433960249	6868	39	13F
0005433960213	6868	40	14A
0005433960223	6868	41	14C
0005433960225	6868	42	14E
0005433960228	6868	43	14F
0005433960229	6868	44	15D
0005433960237	6868	45	15E
0005433960235	6868	46	15F
0005433960230	6868	47	16D
0005433960236	6868	48	16E
0005433960234	6868	49	16F
0005433960215	6868	50	17C
0005433960209	6868	51	17E
0005433960217	6868	52	18A
0005433960257	6868	53	18C
0005433960259	6868	54	18D
0005433960267	6868	55	18F
0005433960263	6868	56	19C
0005433960218	6868	57	19F
0005433960250	6868	58	20A
0005433960242	6868	59	20D
0005435082689	26127	1	1A
0005435082686	26127	2	1B
0005435082694	26127	3	2A
0005435082685	26127	4	2B
0005435082684	26127	5	3B
0005435082690	26127	6	4A
0005435082688	26127	7	4B
0005435082693	26127	8	5A
0005435082687	26127	9	5B
0005435082692	26127	10	6A
0005435082691	26127	11	6B
0005432166863	5180	1	2F
0005434244664	5180	2	2D
0005434244661	5180	3	3C
0005434244640	5180	4	4F
0005434244636	5180	5	5A
0005434244663	5180	6	7F
0005434244637	5180	7	7D
0005434244642	5180	8	8D
0005434244650	5180	9	9E
0005432166864	5180	10	10C
0005434244653	5180	11	11B
0005434244649	5180	12	12A
0005434244647	5180	13	13A
0005434244659	5180	14	14D
0005434244655	5180	15	14E
0005434244645	5180	16	14F
0005434244654	5180	17	15C
0005434244646	5180	18	16A
0005434244635	5180	19	18F
0005434244660	5180	20	20A
0005434244638	5180	21	20D
0005434244639	5180	22	20F
0005434244652	5180	23	22C
0005432166866	5180	24	22F
0005434244651	5180	25	23A
0005434244634	5180	26	24A
0005434244643	5180	27	24C
0005432166865	5180	28	26E
0005434244657	5180	29	26D
0005434244656	5180	30	27F
0005434244644	5180	31	28D
0005434244648	5180	32	29C
0005434244662	5180	33	31A
0005434244658	5180	34	31C
0005434244641	5180	35	31B
0005433784550	5177	1	1D
0005433784521	5177	2	1C
0005433613886	5177	3	1A
0005433784525	5177	4	2A
0005433613905	5177	5	1F
0005432105033	5177	6	2D
0005432105008	5177	7	2C
0005433784519	5177	8	2F
0005433613901	5177	9	3A
0005432105042	5177	10	3C
0005432666365	5177	11	3F
0005433613862	5177	12	3D
0005432105025	5177	13	4A
0005432105032	5177	14	4D
0005432667429	5177	15	4C
0005432105038	5177	16	4F
0005433613852	5177	17	5A
0005433613896	5177	18	5D
0005433784529	5177	19	5C
0005433784534	5177	20	5F
0005433613900	5177	21	6A
0005432665250	5177	22	6D
0005433784530	5177	23	6C
0005433613871	5177	24	6F
0005432105012	5177	25	7A
0005432105043	5177	26	7C
0005433613857	5177	27	7F
0005433613840	5177	28	7D
0005432667430	5177	29	8A
0005433613856	5177	30	8B
0005432105029	5177	31	8D
0005433613908	5177	32	8C
0005433613839	5177	33	8E
0005433784537	5177	34	8F
0005432105017	5177	35	9A
0005433784526	5177	36	9D
0005433613867	5177	37	9C
0005433613872	5177	38	9B
0005433613864	5177	39	9E
0005433784518	5177	40	10A
0005432105027	5177	41	9F
0005432105047	5177	42	10C
0005433613838	5177	43	10B
0005433784522	5177	44	10D
0005433613846	5177	45	10E
0005433613850	5177	46	10F
0005433613882	5177	47	11A
0005432105036	5177	48	11C
0005433613859	5177	49	11B
0005432105024	5177	50	11D
0005432105050	5177	51	11F
0005433613892	5177	52	11E
0005433613874	5177	53	12A
0005433613844	5177	54	12B
0005433613903	5177	55	12D
0005433613836	5177	56	12C
0005433613877	5177	57	12E
0005432105035	5177	58	12F
0005432105019	5177	59	13A
0005433784538	5177	60	13C
0005433613894	5177	61	13B
0005433784546	5177	62	13D
0005432105010	5177	63	13F
0005433613909	5177	64	13E
0005433784539	5177	65	14A
0005432105023	5177	66	14B
0005433613873	5177	67	14C
0005432105006	5177	68	14E
0005433613880	5177	69	14D
0005433613837	5177	70	15A
0005432105040	5177	71	14F
0005433613855	5177	72	15C
0005433784531	5177	73	15B
0005433784549	5177	74	15D
0005432666364	5177	75	15F
0005432105011	5177	76	15E
0005432105030	5177	77	16A
0005433784551	5177	78	16C
0005433613841	5177	79	16B
0005432666363	5177	80	16E
0005433613890	5177	81	16D
0005433784523	5177	82	16F
0005432145089	5177	83	17B
0005433613851	5177	84	17A
0005432105016	5177	85	17C
0005432105026	5177	86	17E
0005433613904	5177	87	17D
0005433784540	5177	88	18A
0005432105020	5177	89	17F
0005433613875	5177	90	18B
0005433613868	5177	91	18D
0005433613854	5177	92	18C
0005433613888	5177	93	18E
0005432105007	5177	94	19B
0005432105045	5177	95	18F
0005433613870	5177	96	19C
0005433613893	5177	97	19D
0005432105039	5177	98	19E
0005433784543	5177	99	20B
0005433784536	5177	100	20A
0005432105031	5177	101	20C
0005432105013	5177	102	20E
0005433613878	5177	103	20D
0005432105037	5177	104	20F
0005433784535	5177	105	21A
0005433613899	5177	106	21B
0005432105034	5177	107	21D
0005432105022	5177	108	21C
0005433784532	5177	109	21E
0005433613884	5177	110	22A
0005433613863	5177	111	21F
0005433613881	5177	112	22B
0005433784547	5177	113	22C
0005432105044	5177	114	22E
0005433613902	5177	115	22D
0005432105015	5177	116	22F
0005433613858	5177	117	23A
0005432145088	5177	118	23C
0005433613898	5177	119	23B
0005433613848	5177	120	23D
0005432105014	5177	121	23F
0005432145090	5177	122	23E
0005433784544	5177	123	24B
0005432665251	5177	124	24A
0005433613887	5177	125	24D
0005432105048	5177	126	24C
0005432105018	5177	127	24E
0005433613897	5177	128	25A
0005433784541	5177	129	24F
0005432105049	5177	130	25C
0005433613895	5177	131	25B
0005432105052	5177	132	25D
0005433784552	5177	133	25F
0005433613861	5177	134	25E
0005433613853	5177	135	26B
0005433613889	5177	136	26A
0005433613879	5177	137	26C
0005433613883	5177	138	26D
0005433613843	5177	139	27A
0005432105041	5177	140	26F
0005433613865	5177	141	26E
0005433784527	5177	142	27C
0005433613906	5177	143	27B
0005433613869	5177	144	27D
0005433613885	5177	145	27E
0005433784520	5177	146	27F
0005433784545	5177	147	28B
0005433613907	5177	148	28A
0005433613845	5177	149	28D
0005432105046	5177	150	28C
0005432105005	5177	151	28E
0005432105053	5177	152	28F
0005433613860	5177	153	29A
0005433613866	5177	154	29C
0005433784542	5177	155	29B
0005432667431	5177	156	29D
0005432105028	5177	157	29E
0005432105021	5177	158	30A
0005433784528	5177	159	29F
0005433784524	5177	160	30B
0005433613842	5177	161	30C
0005433613835	5177	162	30D
0005433613849	5177	163	30F
0005433613891	5177	164	30E
0005432105009	5177	165	31A
0005433613876	5177	166	31C
0005433613847	5177	167	31B
0005433784533	5177	168	31D
0005432105051	5177	169	31F
0005433784548	5177	170	31E
0005434229120	5175	1	1A
0005434264853	5175	2	1C
0005434229118	5175	3	3C
0005434229111	5175	4	3D
0005434312286	5175	5	4A
0005434264845	5175	6	4C
0005434264858	5175	7	5C
0005433815302	5175	8	5F
0005434149596	5175	9	6C
0005434264854	5175	10	7F
0005435006612	5175	11	7D
0005434149599	5175	12	8A
0005434264837	5175	13	8C
0005434229115	5175	14	9A
0005435006618	5175	15	9B
0005434264851	5175	16	9C
0005434229119	5175	17	9D
0005434264857	5175	18	9E
0005434264849	5175	19	10E
0005434312285	5175	20	10D
0005433815308	5175	21	11B
0005434229122	5175	22	11D
0005434149594	5175	23	12A
0005434264836	5175	24	12F
0005434264855	5175	25	12E
0005434229117	5175	26	13C
0005434264843	5175	27	13F
0005434149597	5175	28	14A
0005434229126	5175	29	14C
0005434229104	5175	30	14F
0005434149602	5175	31	15B
0005435006606	5175	32	15A
0005434264850	5175	33	15E
0005434264838	5175	34	16A
0005434229110	5175	35	16C
0005434229121	5175	36	16D
0005434229108	5175	37	17A
0005434264842	5175	38	16F
0005434229114	5175	39	17B
0005434264859	5175	40	17C
0005434173476	5175	41	17F
0005434149598	5175	42	19B
0005434229116	5175	43	18F
0005434229123	5175	44	19C
0005434149601	5175	45	20B
0005434264852	5175	46	20D
0005434264839	5175	47	20C
0005434229109	5175	48	20F
0005434149603	5175	49	21C
0005434229112	5175	50	21B
0005434173474	5175	51	21D
0005433815301	5175	52	22B
0005434173473	5175	53	22E
0005434149593	5175	54	22F
0005434264856	5175	55	23C
0005434149595	5175	56	23B
0005434264847	5175	57	23D
0005434229106	5175	58	23F
0005435006670	5175	59	24B
0005434264848	5175	60	24D
0005435006671	5175	61	24C
0005434264844	5175	62	24F
0005434264840	5175	63	25D
0005434229127	5175	64	26A
0005434229124	5175	65	26D
0005434264860	5175	66	27D
0005435006611	5175	67	27E
0005434229125	5175	68	28A
0005434264841	5175	69	27F
0005434229113	5175	70	28B
0005434173475	5175	71	28C
0005434229107	5175	72	28E
0005434264835	5175	73	28F
0005434149600	5175	74	29B
0005434264846	5175	75	29D
0005434229105	5175	76	29F
0005434173477	5175	77	30A
0005433784341	8457	1	7D
0005434244556	8457	2	8F
0005433784331	8457	3	9D
0005434244488	8457	4	10F
0005434244453	8457	5	11B
0005434244454	8457	6	11D
0005433784304	8457	7	14E
0005433784413	8457	8	14F
0005433784326	8457	9	16F
0005434244489	8457	10	20B
0005433784332	8457	11	20F
0005433784378	8457	12	21C
0005433784306	8457	13	23D
0005433784305	8457	14	24F
0005434244481	8457	15	25C
0005433784303	8457	16	25D
0005433784379	8457	17	25F
0005433784366	8457	18	27F
0005433784330	8457	19	29E
0005433613439	8456	1	5C
0005433613459	8456	2	5D
0005433613424	8456	3	14F
0005433613520	8456	4	21D
0005433613398	8456	5	25E
0005433613490	8456	6	27A
0005433613397	8456	7	29F
0005433613452	8456	8	30E
0005433613451	8456	9	31A
0005432034620	8455	1	1D
0005432335905	8455	2	1C
0005433688786	8455	3	2A
0005432047507	8455	4	3D
0005434264707	8455	5	4D
0005433534473	8455	6	5A
0005432034642	8455	7	4F
0005435006748	8455	8	5D
0005435006762	8455	9	5F
0005432034638	8455	10	6D
0005434149529	8455	11	6C
0005434311194	8455	12	7A
0005432034629	8455	13	7F
0005435006755	8455	14	7D
0005433689888	8455	15	8D
0005434311195	8455	16	8E
0005432034630	8455	17	9A
0005435006754	8455	18	9C
0005435006761	8455	19	9B
0005432047508	8455	20	9D
0005432335902	8455	21	9E
0005435006752	8455	22	10A
0005435006756	8455	23	9F
0005433815334	8455	24	10B
0005433690904	8455	25	10E
0005432034646	8455	26	12A
0005433688785	8455	27	11F
0005433534474	8455	28	12B
0005434264682	8455	29	12E
0005435006747	8455	30	12D
0005432034641	8455	31	13A
0005432034636	8455	32	13C
0005432034637	8455	33	13F
0005432034633	8455	34	14A
0005432034635	8455	35	14B
0005434264718	8455	36	14D
0005432034627	8455	37	14F
0005435006753	8455	38	15E
0005432034628	8455	39	16A
0005432034624	8455	40	16B
0005435006746	8455	41	16C
0005432034625	8455	42	16E
0005432335900	8455	43	16F
0005432034645	8455	44	17B
0005434228992	8455	45	17A
0005435006749	8455	46	17C
0005435006751	8455	47	18B
0005432034639	8455	48	18E
0005433815335	8455	49	18D
0005432335898	8455	50	19B
0005432335895	8455	51	19C
0005432034632	8455	52	19D
0005432034622	8455	53	19E
0005434264706	8455	54	20B
0005432335896	8455	55	20E
0005433815330	8455	56	21C
0005435006765	8455	57	21D
0005435006757	8455	58	22C
0005432047506	8455	59	22E
0005434264675	8455	60	22D
0005432335906	8455	61	22F
0005432034643	8455	62	23B
0005435006758	8455	63	23A
0005433689887	8455	64	23C
0005432335897	8455	65	23E
0005432047509	8455	66	24B
0005432034623	8455	67	24D
0005432034626	8455	68	24F
0005433815331	8455	69	24E
0005432034621	8455	70	25A
0005433815332	8455	71	25B
0005432335903	8455	72	25D
0005432335901	8455	73	25E
0005433690903	8455	74	26A
0005432034647	8455	75	26C
0005435006760	8455	76	26E
0005435006750	8455	77	27A
0005434264695	8455	78	27D
0005432034640	8455	79	27F
0005432335904	8455	80	28A
0005432335899	8455	81	28C
0005435006764	8455	82	28E
0005435006763	8455	83	28D
0005432034644	8455	84	29C
0005434229016	8455	85	29D
0005432034648	8455	86	30A
0005435006759	8455	87	30B
0005434311196	8455	88	30C
0005432034634	8455	89	31A
0005434229074	8455	90	31C
0005433815333	8455	91	31F
0005432034631	8455	92	31E
0005433202201	12584	1	1A
0005434638927	12584	2	1D
0005433202194	12584	3	2B
0005434638871	12584	4	2C
0005433202202	12584	5	3D
0005433202205	12584	6	4A
0005433202195	12584	7	4B
0005433202198	12584	8	4C
0005433202206	12584	9	4D
0005433202207	12584	10	5D
0005433202199	12584	11	7A
0005434638862	12584	12	7B
0005433202193	12584	13	18B
0005434638870	12584	14	18C
0005433202203	12584	15	20A
0005433202204	12584	16	20B
0005433202197	12584	17	20C
0005433202192	12584	18	20D
0005433202200	12584	19	21A
0005433202196	12584	20	21D
0005434638993	23362	1	1A
0005434639007	23362	2	1B
0005434638995	23362	3	1D
0005434638996	23362	4	2A
0005434639010	23362	5	2B
0005432290595	23362	6	2C
0005434638997	23362	7	2D
0005434639006	23362	8	3A
0005434638989	23362	9	4B
0005434638992	23362	10	4C
0005434639011	23362	11	5A
0005434638987	23362	12	5B
0005434639012	23362	13	5D
0005434638986	23362	14	6A
0005434639002	23362	15	6C
0005434639004	23362	16	6D
0005432290597	23362	17	7D
0005434639003	23362	18	18A
0005434638985	23362	19	18B
0005434638990	23362	20	18D
0005434639000	23362	21	19A
0005434638988	23362	22	19B
0005434638998	23362	23	19D
0005434639005	23362	24	20A
0005432290594	23362	25	20B
0005434638999	23362	26	20C
0005434639009	23362	27	20D
0005434638991	23362	28	21B
0005434638994	23362	29	21D
0005434639008	23362	30	22A
0005432290596	23362	31	22B
0005434639001	23362	32	22D
0005432054272	21061	1	1C
0005432054271	21061	2	8F
0005432054270	21061	3	9C
0005432327989	21061	4	10C
0005432327945	21061	5	17D
0005432382704	31253	1	1A
0005432328137	31253	2	1C
0005432328160	31253	3	1D
0005432328155	31253	4	2A
0005432382700	31253	5	2C
0005432287128	31253	6	2D
0005432382718	31253	7	2F
0005432328150	31253	8	3A
0005432328128	31253	9	3C
0005432382705	31253	10	3D
0005432328167	31253	11	3F
0005432328144	31253	12	4A
0005432328139	31253	13	4C
0005432328145	31253	14	4D
0005432328157	31253	15	4E
0005432382706	31253	16	4F
0005432382722	31253	17	5A
0005432328134	31253	18	5C
0005432328148	31253	19	5D
0005432382691	31253	20	5E
0005432328151	31253	21	5F
0005432287126	31253	22	6A
0005432328130	31253	23	6C
0005432382707	31253	24	6D
0005432382725	31253	25	6E
0005432382726	31253	26	6F
0005432382708	31253	27	7A
0005432328172	31253	28	7C
0005432382720	31253	29	7D
0005432382697	31253	30	7E
0005432328126	31253	31	7F
0005432328154	31253	32	8A
0005432382694	31253	33	8C
0005432382692	31253	34	8D
0005432382714	31253	35	8E
0005432382713	31253	36	8F
0005432328129	31253	37	9A
0005432328141	31253	38	9C
0005432328161	31253	39	9D
0005432328163	31253	40	9E
0005432382716	31253	41	9F
0005432382724	31253	42	10A
0005432382721	31253	43	10C
0005432287131	31253	44	10D
0005432328168	31253	45	10F
0005432382719	31253	46	11A
0005432328170	31253	47	11C
0005432328135	31253	48	11D
0005432328171	31253	49	11E
0005432287129	31253	50	11F
0005432328162	31253	51	12A
0005432382695	31253	52	12C
0005432328159	31253	53	12D
0005432328165	31253	54	12E
0005432382698	31253	55	12F
0005432328133	31253	56	13A
0005432328158	31253	57	13C
0005432328146	31253	58	13D
0005432328136	31253	59	13E
0005432382696	31253	60	13F
0005432287127	31253	61	14A
0005432328164	31253	62	14C
0005432382702	31253	63	14D
0005432328138	31253	64	14E
0005432382711	31253	65	15C
0005432382701	31253	66	15D
0005432382723	31253	67	15E
0005432328166	31253	68	15F
0005432382715	31253	69	16A
0005432382699	31253	70	16C
0005432382709	31253	71	16D
0005432328156	31253	72	16E
0005432328169	31253	73	16F
0005432328142	31253	74	17A
0005432328140	31253	75	17C
0005432328152	31253	76	17D
0005432287130	31253	77	17E
0005432328153	31253	78	17F
0005432328132	31253	79	18C
0005432328127	31253	80	18D
0005432382703	31253	81	18E
0005432328143	31253	82	18F
0005432382693	31253	83	19A
0005432382717	31253	84	19C
0005432328131	31253	85	19D
0005432328125	31253	86	19E
0005432382710	31253	87	20A
0005432382712	31253	88	20C
0005432328149	31253	89	20D
0005432287125	31253	90	20E
0005432328147	31253	91	20F
0005433642106	27597	1	2D
0005432953840	27597	2	2F
0005432953843	27597	3	3A
0005433642080	27597	4	5D
0005432953842	27597	5	6D
0005432953830	27597	6	8A
0005432953831	27597	7	8C
0005432953837	27597	8	8E
0005432953838	27597	9	10A
0005433642094	27597	10	10F
0005432953833	27597	11	13D
0005432953841	27597	12	13F
0005432953835	27597	13	14E
0005433642092	27597	14	15D
0005432953832	27597	15	16D
0005432953834	27597	16	17E
0005433642102	27597	17	17F
0005433642087	27597	18	18E
0005432953845	27597	19	18F
0005432953844	27597	20	20C
0005432953836	27597	21	20D
0005432953839	27597	22	20E
0005432423877	13320	1	1A
0005432423884	13320	2	1D
0005432423909	13320	3	2A
0005432423900	13320	4	2C
0005432423861	13320	5	2D
0005432423865	13320	6	2F
0005432423898	13320	7	3C
0005432423901	13320	8	3D
0005432423888	13320	9	4A
0005432423894	13320	10	4C
0005432423876	13320	11	4E
0005432423893	13320	12	5A
0005432423895	13320	13	5C
0005432423863	13320	14	5E
0005432423862	13320	15	7A
0005432423899	13320	16	7C
0005432423864	13320	17	7D
0005432423870	13320	18	8A
0005432423892	13320	19	8E
0005432423905	13320	20	9A
0005432423897	13320	21	9C
0005432423868	13320	22	9D
0005432423886	13320	23	9E
0005432423867	13320	24	10C
0005432423879	13320	25	10D
0005432423903	13320	26	10F
0005432423904	13320	27	11A
0005432423891	13320	28	11C
0005432423902	13320	29	11E
0005432423907	13320	30	12A
0005432423871	13320	31	12D
0005432423875	13320	32	12E
0005432423880	13320	33	12F
0005432423882	13320	34	13C
0005432423908	13320	35	13E
0005432423890	13320	36	13F
0005432423881	13320	37	14C
0005432423889	13320	38	14D
0005432423874	13320	39	14F
0005432423860	13320	40	15C
0005432423883	13320	41	15E
0005432423896	13320	42	15F
0005432423885	13320	43	16A
0005432423887	13320	44	16F
0005432423878	13320	45	17A
0005432423866	13320	46	17C
0005432423872	13320	47	17E
0005432423906	13320	48	18E
0005432423873	13320	49	19A
0005432423869	13320	50	19C
0005432822117	9601	1	1C
0005432817137	9601	2	1D
0005432901312	9601	3	2D
0005432817128	9601	4	3A
0005432817136	9601	5	3C
0005432817122	9601	6	3D
0005432817124	9601	7	3F
0005434157360	9601	8	4A
0005432817121	9601	9	4D
0005432901335	9601	10	5A
0005432822118	9601	11	5C
0005434448277	9601	12	5D
0005432817127	9601	13	5F
0005432817134	9601	14	6A
0005432822114	9601	15	6C
0005434448275	9601	16	7A
0005432817142	9601	17	7D
0005432817148	9601	18	7F
0005432817129	9601	19	8A
0005432817132	9601	20	8C
0005432288947	9601	21	8E
0005432817145	9601	22	9A
0005432817126	9601	23	9D
0005432817144	9601	24	9E
0005432901300	9601	25	10A
0005432817139	9601	26	10C
0005432817138	9601	27	10D
0005432817125	9601	28	10E
0005432817133	9601	29	10F
0005434157341	9601	30	11A
0005432822113	9601	31	11C
0005432817123	9601	32	11F
0005432822115	9601	33	12D
0005432288950	9601	34	13D
0005432817131	9601	35	13F
0005432817149	9601	36	14E
0005432288948	9601	37	15D
0005432817135	9601	38	15F
0005432817143	9601	39	16A
0005432817140	9601	40	16C
0005432817120	9601	41	16D
0005432817130	9601	42	17A
0005432817147	9601	43	17C
0005432817119	9601	44	18A
0005434157342	9601	45	18C
0005434448276	9601	46	19D
0005432817146	9601	47	19E
0005432817141	9601	48	19F
0005432288949	9601	49	20D
0005432822116	9601	50	20F
0005432901416	28984	1	2A
0005432901402	28984	2	2F
0005432901412	28984	3	5C
0005432901411	28984	4	5D
0005434157387	28984	5	6D
0005434186163	28984	6	6E
0005432002054	28984	7	6F
0005432901415	28984	8	7A
0005432901409	28984	9	7D
0005434157392	28984	10	8E
0005432901418	28984	11	10A
0005434448260	28984	12	10C
0005432002052	28984	13	10D
0005432901417	28984	14	10F
0005432901408	28984	15	11E
0005434157388	28984	16	11F
0005432901404	28984	17	12A
0005432901413	28984	18	12D
0005434157394	28984	19	13E
0005432901405	28984	20	14A
0005432822071	28984	21	15A
0005432901406	28984	22	15E
0005432901407	28984	23	15F
0005434157391	28984	24	16A
0005434157393	28984	25	16D
0005434448259	28984	26	17A
0005432901410	28984	27	17C
0005432816963	28984	28	17E
0005434186164	28984	29	18A
0005432822072	28984	30	18D
0005434157389	28984	31	19A
0005434157390	28984	32	19E
0005432002053	28984	33	19F
0005432901403	28984	34	20A
0005432901414	28984	35	20D
0005432613816	15131	1	1A
0005432611664	15131	2	1B
0005432611667	15131	3	2B
0005432613817	15131	4	3A
0005432611665	15131	5	3B
0005432611666	15131	6	4A
0005432611663	15131	7	4B
0005432613815	15131	8	5B
0005432613814	15131	9	5A
0005432613818	15131	10	6A
0005432613813	15131	11	6B
0005435842320	31583	1	1B
0005435842322	31583	2	2A
0005435841813	31583	3	4A
0005435842321	31583	4	5A
0005435842319	31583	5	5B
0005432611653	31583	6	6A
0005433568340	11836	1	1C
0005433568350	11836	2	2C
0005433568369	11836	3	3A
0005433568344	11836	4	2F
0005433568371	11836	5	5A
0005433568354	11836	6	5F
0005433568373	11836	7	5D
0005433568367	11836	8	6B
0005433568326	11836	9	6A
0005433568313	11836	10	6C
0005432947787	11836	11	6E
0005433568314	11836	12	6D
0005433568322	11836	13	7A
0005433568333	11836	14	6F
0005433568352	11836	15	7B
0005433568332	11836	16	7E
0005433568343	11836	17	7D
0005433568320	11836	18	8B
0005433568334	11836	19	8C
0005433568338	11836	20	9A
0005433568342	11836	21	8E
0005433568311	11836	22	9C
0005433568310	11836	23	9E
0005433568308	11836	24	10B
0005433568328	11836	25	10A
0005433568351	11836	26	10F
0005433568345	11836	27	11D
0005433568365	11836	28	11C
0005433568336	11836	29	11F
0005433568327	11836	30	11E
0005433568335	11836	31	12A
0005433568323	11836	32	12C
0005433568356	11836	33	12E
0005433568370	11836	34	12F
0005433568360	11836	35	13E
0005433568372	11836	36	13D
0005433568357	11836	37	14A
0005433568331	11836	38	13F
0005433568348	11836	39	14B
0005432947772	11836	40	14D
0005433568366	11836	41	14F
0005433568321	11836	42	14E
0005433568316	11836	43	15B
0005433568359	11836	44	15C
0005433568346	11836	45	15E
0005433568363	11836	46	15D
0005433568358	11836	47	16A
0005433568355	11836	48	16F
0005433568324	11836	49	16E
0005433568337	11836	50	17B
0005433568361	11836	51	17A
0005433568364	11836	52	17D
0005433568353	11836	53	17C
0005433568362	11836	54	17E
0005433568349	11836	55	18A
0005433568317	11836	56	18C
0005433568368	11836	57	18B
0005433568329	11836	58	18F
0005433568347	11836	59	18D
0005433568315	11836	60	19A
0005433568312	11836	61	19C
0005433568341	11836	62	19D
0005432947786	11836	63	19F
0005433568309	11836	64	20B
0005433568330	11836	65	20C
0005433568318	11836	66	20E
0005433568319	11836	67	21A
0005433568325	11836	68	21D
0005433568339	11836	69	21F
0005432948017	25285	1	1D
0005432948030	25285	2	2C
0005432948026	25285	3	4D
0005432948040	25285	4	4C
0005432948049	25285	5	5C
0005432948031	25285	6	5D
0005432948052	25285	7	6D
0005432948046	25285	8	6F
0005432948039	25285	9	7F
0005432948025	25285	10	7E
0005432948050	25285	11	8E
0005432948036	25285	12	9D
0005432948044	25285	13	9C
0005432948053	25285	14	9E
0005432948043	25285	15	10A
0005432948019	25285	16	10E
0005432948020	25285	17	11B
0005432948021	25285	18	11A
0005432948013	25285	19	11E
0005432948048	25285	20	12B
0005432948015	25285	21	13B
0005432948038	25285	22	13D
0005432948041	25285	23	13F
0005432948047	25285	24	14D
0005432948018	25285	25	14E
0005432948042	25285	26	16A
0005432948054	25285	27	16D
0005432948016	25285	28	16E
0005432948014	25285	29	17D
0005432948034	25285	30	17F
0005432948028	25285	31	18A
0005432948037	25285	32	18C
0005432948033	25285	33	18E
0005432948027	25285	34	18D
0005432948051	25285	35	19A
0005432948045	25285	36	20B
0005432948035	25285	37	20D
0005432948032	25285	38	20F
0005432948023	25285	39	20E
0005432948024	25285	40	21A
0005432948029	25285	41	21B
0005432948022	25285	42	21D
0005434654341	5388	1	1C
0005434656533	5388	2	2C
0005434654349	5388	3	2F
0005434654358	5388	4	3C
0005434654368	5388	5	4D
0005434654350	5388	6	4E
0005434654352	5388	7	5A
0005434654353	5388	8	5E
0005432114166	5388	9	6A
0005434654351	5388	10	6C
0005434654357	5388	11	7F
0005432114165	5388	12	8A
0005434654347	5388	13	8C
0005434654361	5388	14	9A
0005434654344	5388	15	10D
0005434654360	5388	16	11C
0005434654367	5388	17	11D
0005434654346	5388	18	11E
0005434654362	5388	19	12D
0005434654339	5388	20	12E
0005434654343	5388	21	13C
0005434654365	5388	22	13D
0005434654366	5388	23	13F
0005432114167	5388	24	14F
0005434654342	5388	25	15D
0005434654356	5388	26	15E
0005434654359	5388	27	16A
0005434654348	5388	28	16C
0005434656532	5388	29	16D
0005434654363	5388	30	16F
0005434654354	5388	31	17C
0005434654345	5388	32	17D
0005434654340	5388	33	18D
0005434654364	5388	34	18E
0005434654355	5388	35	20D
0005435340091	12504	1	1C
0005434654184	12504	2	1F
0005434654237	12504	3	2A
0005435340094	12504	4	2C
0005434654205	12504	5	2F
0005435340096	12504	6	4F
0005435340083	12504	7	5A
0005434654183	12504	8	5C
0005434654244	12504	9	5F
0005435340092	12504	10	6E
0005435340082	12504	11	7A
0005434654243	12504	12	7C
0005435340086	12504	13	8A
0005435340088	12504	14	8F
0005435340085	12504	15	9E
0005434654204	12504	16	10C
0005434654245	12504	17	10E
0005435340084	12504	18	12D
0005434654206	12504	19	12F
0005435340095	12504	20	13E
0005434654246	12504	21	13F
0005435340090	12504	22	15C
0005434654236	12504	23	15D
0005435340093	12504	24	17A
0005435340087	12504	25	18E
0005435340089	12504	26	18F
0005434654188	12504	27	20D
0005433656632	7464	1	1C
0005432078045	7464	2	2A
0005433715397	7464	3	2D
0005433722132	7464	4	3A
0005433656631	7464	5	3D
0005433722135	7464	6	3C
0005433690900	7464	7	3F
0005432078046	7464	8	4B
0005433715412	7464	9	4A
0005433715389	7464	10	4C
0005433715380	7464	11	4D
0005433715422	7464	12	4E
0005433715407	7464	13	5C
0005433715413	7464	14	5F
0005433715411	7464	15	6B
0005433715391	7464	16	6D
0005433722134	7464	17	6E
0005433715416	7464	18	7A
0005433715409	7464	19	6F
0005433715415	7464	20	7F
0005433715418	7464	21	7E
0005433715398	7464	22	8C
0005433722140	7464	23	8B
0005433715382	7464	24	8D
0005433715404	7464	25	8F
0005433715381	7464	26	8E
0005433690902	7464	27	9C
0005433715393	7464	28	9D
0005433656629	7464	29	10B
0005433715392	7464	30	10E
0005433715420	7464	31	11B
0005433715421	7464	32	11E
0005433722136	7464	33	11D
0005432078042	7464	34	12A
0005433690901	7464	35	12D
0005433719098	7464	36	12C
0005433715376	7464	37	12F
0005433715388	7464	38	13B
0005433656630	7464	39	13C
0005433715417	7464	40	13D
0005433722133	7464	41	13E
0005433722139	7464	42	13F
0005433689886	7464	43	14C
0005433715414	7464	44	14B
0005433715395	7464	45	14D
0005432078047	7464	46	15C
0005433715400	7464	47	15D
0005433715408	7464	48	15E
0005433722138	7464	49	16A
0005433715402	7464	50	16B
0005433688784	7464	51	16C
0005433715387	7464	52	16D
0005433715374	7464	53	16F
0005433715384	7464	54	17A
0005433719100	7464	55	17B
0005433715405	7464	56	17D
0005433715399	7464	57	17C
0005433715396	7464	58	17E
0005433715375	7464	59	18C
0005432078044	7464	60	18B
0005433715386	7464	61	18A
0005433715419	7464	62	18F
0005433715379	7464	63	19B
0005433715377	7464	64	19E
0005433715385	7464	65	19F
0005433715401	7464	66	20D
0005433656628	7464	67	20E
0005433715378	7464	68	21A
0005433715383	7464	69	20F
0005433715394	7464	70	21B
0005433689885	7464	71	21D
0005433715373	7464	72	21F
0005433715403	7464	73	22A
0005433722137	7464	74	22D
0005433715410	7464	75	22C
0005433715406	7464	76	22E
0005433715423	7464	77	23B
0005433715390	7464	78	23C
0005432078043	7464	79	23E
0005433719099	7464	80	23F
0005432006726	29246	1	1C
0005435266092	29246	2	2A
0005435266100	29246	3	4A
0005432428891	29246	4	4B
0005433715132	29246	5	5A
0005432006728	29246	6	5D
0005435266095	29246	7	6C
0005435266099	29246	8	6E
0005433715242	29246	9	7A
0005432006727	29246	10	6F
0005433715147	29246	11	10B
0005432428890	29246	12	11C
0005433715148	29246	13	12A
0005433715191	29246	14	13D
0005435266093	29246	15	13E
0005435266101	29246	16	14A
0005432428889	29246	17	14C
0005433715149	29246	18	14D
0005435266102	29246	19	14F
0005435266097	29246	20	15B
0005433715192	29246	21	17E
0005435266096	29246	22	19F
0005433715193	29246	23	20B
0005435266098	29246	24	22A
0005433715112	29246	25	22B
0005435266094	29246	26	22D
0005432428888	29246	27	22F
0005434181976	8688	1	3D
0005434182005	8688	2	4C
0005434181960	8688	3	4D
0005434095110	8688	4	6D
0005434095113	8688	5	7C
0005434095116	8688	6	8A
0005434095105	8688	7	8D
0005434095106	8688	8	8E
0005434095107	8688	9	9C
0005434095109	8688	10	9F
0005434095115	8688	11	11A
0005434095112	8688	12	12A
0005434181968	8688	13	12E
0005434095118	8688	14	13D
0005434181967	8688	15	14D
0005434181957	8688	16	15C
0005434095104	8688	17	17C
0005434095117	8688	18	17D
0005434095114	8688	19	18E
0005434181961	8688	20	19F
0005434095111	8688	21	20C
0005434095108	8688	22	20F
0005434095035	11660	1	1A
0005434183555	11660	2	1F
0005434095018	11660	3	3A
0005434095036	11660	4	4E
0005434182038	11660	5	6C
0005434182036	11660	6	6D
0005434182040	11660	7	7A
0005434182037	11660	8	7D
0005434182046	11660	9	8F
0005434184640	11660	10	10A
0005434182043	11660	11	11A
0005434182042	11660	12	11E
0005434182041	11660	13	11F
0005434095017	11660	14	16C
0005434182039	11660	15	16E
0005434182045	11660	16	17E
0005434182044	11660	17	19E
0005434095039	11660	18	20C
0005434182035	11660	19	20F
0005435732192	1454	1	1F
0005433397308	1454	2	3A
0005433456921	1454	3	4F
0005433397376	1454	4	5A
0005435732183	1454	5	5E
0005432297246	1454	6	5F
0005433397293	1454	7	6A
0005432297248	1454	8	6C
0005432297249	1454	9	6D
0005435732191	1454	10	6E
0005432297247	1454	11	6F
0005433397377	1454	12	7A
0005435732184	1454	13	7C
0005435732185	1454	14	7D
0005432297250	1454	15	7E
0005433456922	1454	16	9D
0005433397327	1454	17	10D
0005435732190	1454	18	11A
0005435732187	1454	19	11F
0005435732186	1454	20	12A
0005435732181	1454	21	14C
0005433397206	1454	22	14D
0005435732189	1454	23	15C
0005435732193	1454	24	15F
0005433456923	1454	25	16C
0005435732182	1454	26	16E
0005433397205	1454	27	17A
0005435732188	1454	28	17D
0005433397234	1454	29	18F
0005433397378	1454	30	19A
0005433456924	1454	31	19C
0005435732180	1454	32	19E
0005433456925	1454	33	20C
0005433397502	19283	1	1A
0005433397507	19283	2	1C
0005433397524	19283	3	1D
0005432906508	19283	4	1F
0005433397521	19283	5	2A
0005433397508	19283	6	2C
0005433397511	19283	7	2D
0005433397490	19283	8	2F
0005433397492	19283	9	3A
0005433397498	19283	10	3C
0005433397516	19283	11	3D
0005433397512	19283	12	4A
0005433397525	19283	13	4D
0005433397500	19283	14	4E
0005433397519	19283	15	6A
0005433397481	19283	16	6E
0005433397513	19283	17	6F
0005433397522	19283	18	7A
0005433397501	19283	19	7C
0005433397515	19283	20	7D
0005433397510	19283	21	8C
0005433397485	19283	22	8D
0005433397478	19283	23	8E
0005433397482	19283	24	9A
0005433397479	19283	25	9D
0005433397493	19283	26	9E
0005433397491	19283	27	10A
0005433397489	19283	28	10D
0005433397496	19283	29	10E
0005433397504	19283	30	11C
0005433397494	19283	31	11E
0005433397517	19283	32	12A
0005433397484	19283	33	12D
0005433397518	19283	34	12F
0005433397486	19283	35	13A
0005433397497	19283	36	13C
0005433397499	19283	37	14F
0005433397505	19283	38	15D
0005433397523	19283	39	15E
0005433397477	19283	40	16C
0005432906507	19283	41	16D
0005433397480	19283	42	16F
0005433397483	19283	43	17A
0005433397503	19283	44	17C
0005433397520	19283	45	18C
0005435732136	19283	46	18D
0005433397488	19283	47	18E
0005433397514	19283	48	18F
0005433397506	19283	49	19D
0005433397487	19283	50	20D
0005433397495	19283	51	20E
0005433397509	19283	52	20F
0005434443509	20563	1	1A
0005434443514	20563	2	1B
0005434443507	20563	3	1C
0005434443519	20563	4	1D
0005434443508	20563	5	2D
0005434443520	20563	6	4B
0005434443518	20563	7	4C
0005434443511	20563	8	5C
0005434443517	20563	9	6C
0005434443512	20563	10	7B
0005434443516	20563	11	18C
0005434443521	20563	12	19D
0005434443513	20563	13	20B
0005434443515	20563	14	20D
0005434443510	20563	15	21D
0005434954563	7272	1	1B
0005434954564	7272	2	3B
0005434954562	7272	3	4B
0005434954565	7272	4	6A
0005434954543	28330	1	1B
0005435377552	28330	2	2B
0005435377551	28330	3	5B
0005435893539	4456	1	1B
0005435893537	4456	2	2A
0005434351548	4456	3	2C
0005434351553	4456	4	3A
0005434351554	4456	5	3B
0005434351547	4456	6	3D
0005434351546	4456	7	4D
0005434351542	4456	8	5D
0005434351545	4456	9	7C
0005435893538	4456	10	7D
0005434351549	4456	11	18C
0005434351551	4456	12	19A
0005434351543	4456	13	19B
0005435893512	4456	14	19C
0005434351555	4456	15	20B
0005434351552	4456	16	20C
0005434351544	4456	17	21A
0005434351550	4456	18	22A
0005435893550	29656	1	1C
0005435893552	29656	2	1D
0005435893549	29656	3	2B
0005435893551	29656	4	2C
0005435893546	29656	5	3A
0005435893547	29656	6	4B
0005434351473	29656	7	6B
0005435893548	29656	8	18B
0005434351469	29656	9	18D
0005435893553	29656	10	20B
0005435091957	1046	1	1C
0005433341549	1046	2	2F
0005435091954	1046	3	2C
0005433341405	1046	4	2H
0005433341406	1046	5	11F
0005433269624	1046	6	11G
0005435091960	1046	7	12A
0005434445221	1046	8	18H
0005433463876	1046	9	19D
0005435091961	1046	10	19G
0005434446492	1046	11	20D
0005435091958	1046	12	21D
0005433341670	1046	13	21H
0005435091964	1046	14	21G
0005433341465	1046	15	23E
0005435091955	1046	16	23G
0005434446493	1046	17	24A
0005433463875	1046	18	30A
0005432293179	1046	19	30D
0005434446494	1046	20	30E
0005435091959	1046	21	32A
0005434445222	1046	22	32F
0005433341466	1046	23	33A
0005433462722	1046	24	33F
0005435091963	1046	25	34B
0005435091956	1046	26	36A
0005432293180	1046	27	37D
0005433341525	1046	28	38F
0005435091962	1046	29	38G
0005433269653	17047	1	1C
0005433159286	17047	2	1F
0005433341890	17047	3	1H
0005433341950	17047	4	2H
0005433341985	17047	5	2G
0005433341933	17047	6	3B
0005433341917	17047	7	3F
0005433341959	17047	8	3G
0005433341958	17047	9	4A
0005433341955	17047	10	4B
0005433341912	17047	11	4C
0005433341929	17047	12	4H
0005433341899	17047	13	5A
0005433341982	17047	14	5C
0005433341948	17047	15	5B
0005433341903	17047	16	5G
0005435091908	17047	17	5F
0005433269659	17047	18	9B
0005433341914	17047	19	9A
0005433341977	17047	20	9G
0005433341911	17047	21	11A
0005433341963	17047	22	9H
0005433341949	17047	23	11B
0005433341932	17047	24	12B
0005433341891	17047	25	12E
0005433341973	17047	26	12F
0005433341919	17047	27	12G
0005433269654	17047	28	13A
0005433341945	17047	29	13D
0005433341978	17047	30	13G
0005433341961	17047	31	14H
0005433341918	17047	32	15B
0005433341927	17047	33	15E
0005433341964	17047	34	15F
0005433341935	17047	35	15G
0005433341951	17047	36	16D
0005433341984	17047	37	16E
0005433341926	17047	38	16H
0005433341957	17047	39	16G
0005433341965	17047	40	17E
0005433341923	17047	41	17D
0005433269657	17047	42	17G
0005433341954	17047	43	18A
0005433341941	17047	44	17H
0005433341940	17047	45	18B
0005433341967	17047	46	18D
0005433341931	17047	47	18G
0005433341928	17047	48	19A
0005433341974	17047	49	19D
0005435091906	17047	50	19E
0005435091909	17047	51	19F
0005433269658	17047	52	19H
0005433341921	17047	53	20F
0005433341898	17047	54	20E
0005435091903	17047	55	21D
0005433341893	17047	56	21B
0005433341956	17047	57	21E
0005433341915	17047	58	21G
0005433341905	17047	59	21F
0005433341971	17047	60	22A
0005433341907	17047	61	22D
0005433341944	17047	62	22B
0005433341904	17047	63	22F
0005433341894	17047	64	22G
0005433341934	17047	65	23A
0005433341897	17047	66	22H
0005435091902	17047	67	23D
0005433341916	17047	68	23B
0005433159288	17047	69	23H
0005433341936	17047	70	24B
0005433341938	17047	71	24E
0005433341966	17047	72	24D
0005433341980	17047	73	24F
0005433341902	17047	74	24G
0005433341972	17047	75	25D
0005433341889	17047	76	24H
0005433341920	17047	77	25E
0005433341888	17047	78	27E
0005433341901	17047	79	27F
0005433341952	17047	80	28B
0005433269656	17047	81	28E
0005433341942	17047	82	28G
0005433341896	17047	83	29H
0005433341970	17047	84	30B
0005433341968	17047	85	30D
0005433341906	17047	86	30F
0005433341981	17047	87	30E
0005433341922	17047	88	30G
0005435091900	17047	89	30H
0005433341953	17047	90	31D
0005433341943	17047	91	31E
0005433341987	17047	92	32A
0005433341939	17047	93	31H
0005433341895	17047	94	32F
0005433341960	17047	95	33A
0005433341937	17047	96	33B
0005433341913	17047	97	33D
0005433341969	17047	98	33G
0005433341925	17047	99	34D
0005435091907	17047	100	34G
0005433341946	17047	101	35A
0005433159287	17047	102	35E
0005433341924	17047	103	35D
0005433341962	17047	104	35G
0005433341892	17047	105	35F
0005433341975	17047	106	36A
0005433341910	17047	107	36B
0005433341976	17047	108	36D
0005433341983	17047	109	36F
0005433341900	17047	110	36H
0005433269655	17047	111	36G
0005433341908	17047	112	37A
0005433269660	17047	113	37E
0005433341909	17047	114	37F
0005435091897	17047	115	37H
0005433341947	17047	116	37G
0005433341930	17047	117	38F
0005433341986	17047	118	39E
0005433341979	17047	119	39D
0005432389984	1345	1	1C
0005432391958	1345	2	1A
0005432389998	1345	3	1F
0005432391959	1345	4	1D
0005432389985	1345	5	2A
0005432390011	1345	6	2C
0005432391961	1345	7	3A
0005432389988	1345	8	3C
0005432390009	1345	9	3F
0005432390013	1345	10	4C
0005432389971	1345	11	4F
0005432389995	1345	12	5C
0005432389994	1345	13	6B
0005432389997	1345	14	5F
0005432389990	1345	15	6C
0005432389968	1345	16	6F
0005432389996	1345	17	6E
0005432389973	1345	18	6D
0005432389975	1345	19	7A
0005432389992	1345	20	7E
0005432389987	1345	21	7F
0005432851819	1345	22	8D
0005432391953	1345	23	8F
0005432389982	1345	24	9A
0005432389969	1345	25	9C
0005432390006	1345	26	9E
0005432390001	1345	27	9D
0005432389976	1345	28	10A
0005432391963	1345	29	10C
0005432391955	1345	30	10B
0005432390004	1345	31	10E
0005432389977	1345	32	11D
0005432390003	1345	33	11C
0005432391956	1345	34	12A
0005432389979	1345	35	12B
0005432389986	1345	36	13A
0005432391952	1345	37	13E
0005432390005	1345	38	13D
0005432389993	1345	39	14A
0005432389970	1345	40	14B
0005432391957	1345	41	14D
0005432390002	1345	42	14C
0005432389981	1345	43	14F
0005432391962	1345	44	15A
0005432389972	1345	45	15C
0005432390007	1345	46	15E
0005432389991	1345	47	15D
0005432389983	1345	48	16B
0005432389989	1345	49	16E
0005432390000	1345	50	17A
0005432389980	1345	51	18B
0005432389978	1345	52	18A
0005432391964	1345	53	18E
0005432391960	1345	54	19A
0005432390014	1345	55	19B
0005432389974	1345	56	19D
0005432390010	1345	57	20D
0005432390012	1345	58	20C
0005432389999	1345	59	20F
0005432390015	1345	60	21A
0005432390008	1345	61	21C
0005432391954	1345	62	21F
0005434066350	12805	1	1A
0005434066384	12805	2	1F
0005432433619	12805	3	3F
0005434066351	12805	4	4F
0005432161125	12805	5	6C
0005434066304	12805	6	7B
0005434066331	12805	7	7C
0005433812873	12805	8	8D
0005432433616	12805	9	8F
0005432161127	12805	10	10E
0005434066510	12805	11	12D
0005432433618	12805	12	13D
0005432161124	12805	13	15B
0005433812872	12805	14	16F
0005432159803	12805	15	17C
0005432161126	12805	16	18A
0005432159806	12805	17	19F
0005432159805	12805	18	21A
0005434066305	12805	19	21E
0005432433617	12805	20	22F
0005432433615	12805	21	23D
0005432159804	12805	22	23F
0005434081620	30669	1	1A
0005434066687	30669	2	1C
0005434081625	30669	3	1D
0005434066712	30669	4	2A
0005434066685	30669	5	1F
0005434066726	30669	6	2C
0005434066667	30669	7	2D
0005434066674	30669	8	2F
0005434066691	30669	9	3C
0005434081624	30669	10	3A
0005432186824	30669	11	3D
0005434066695	30669	12	3F
0005434066714	30669	13	4B
0005432186826	30669	14	4A
0005434081605	30669	15	4C
0005434066683	30669	16	4D
0005432150095	30669	17	4E
0005434081613	30669	18	5A
0005434066690	30669	19	4F
0005434066702	30669	20	5C
0005434066715	30669	21	5B
0005434066722	30669	22	5D
0005432150099	30669	23	5E
0005434066699	30669	24	6A
0005434081603	30669	25	5F
0005434081609	30669	26	6C
0005434066676	30669	27	6B
0005434066720	30669	28	6D
0005434081616	30669	29	6E
0005433989714	30669	30	6F
0005432433586	30669	31	7B
0005434081621	30669	32	7A
0005434066666	30669	33	7C
0005434066672	30669	34	7D
0005433989711	30669	35	7F
0005434066697	30669	36	7E
0005434066717	30669	37	8A
0005434066661	30669	38	8B
0005434081618	30669	39	8C
0005434081610	30669	40	8E
0005434066710	30669	41	8D
0005434066664	30669	42	8F
0005434081614	30669	43	9A
0005432150101	30669	44	9B
0005434081600	30669	45	9C
0005434066719	30669	46	9E
0005434066668	30669	47	9D
0005434066677	30669	48	9F
0005434066700	30669	49	10B
0005434066659	30669	50	10C
0005432150102	30669	51	10E
0005434066688	30669	52	11A
0005434081599	30669	53	11B
0005432150096	30669	54	11D
0005434066675	30669	55	11C
0005434081612	30669	56	11E
0005434066707	30669	57	12A
0005434066684	30669	58	12C
0005434066716	30669	59	12B
0005434081617	30669	60	12D
0005434066658	30669	61	12E
0005432433594	30669	62	13A
0005434081602	30669	63	12F
0005434066686	30669	64	13B
0005434066705	30669	65	13C
0005434081606	30669	66	13D
0005434081623	30669	67	13F
0005434081604	30669	68	14A
0005434066729	30669	69	14B
0005434081619	30669	70	14D
0005433989710	30669	71	14C
0005434066718	30669	72	14F
0005432433585	30669	73	14E
0005434066727	30669	74	15B
0005434066689	30669	75	15A
0005434066682	30669	76	15C
0005434066694	30669	77	15D
0005434066681	30669	78	15F
0005434081611	30669	79	15E
0005432433582	30669	80	16A
0005434066721	30669	81	16C
0005434066723	30669	82	16B
0005434081608	30669	83	16D
0005434066708	30669	84	16E
0005432150100	30669	85	16F
0005434066679	30669	86	17B
0005432150098	30669	87	17A
0005434066678	30669	88	17C
0005434066663	30669	89	17D
0005434066660	30669	90	18A
0005434066701	30669	91	17F
0005434081607	30669	92	18B
0005434081598	30669	93	18C
0005432150097	30669	94	18D
0005432186825	30669	95	18E
0005434066724	30669	96	19A
0005434066698	30669	97	18F
0005432186823	30669	98	19B
0005434081615	30669	99	19D
0005434081601	30669	100	19E
0005434066680	30669	101	20A
0005434066706	30669	102	20B
0005434066704	30669	103	20C
0005434066728	30669	104	20E
0005434066669	30669	105	20D
0005434066671	30669	106	20F
0005432433596	30669	107	21A
0005434066670	30669	108	21C
0005434066725	30669	109	21B
0005434081622	30669	110	21D
0005434066693	30669	111	21E
0005434066713	30669	112	21F
0005434066692	30669	113	22A
0005434066662	30669	114	22C
0005434066673	30669	115	22D
0005434066696	30669	116	22E
0005434066703	30669	117	23A
0005433989712	30669	118	22F
0005434066711	30669	119	23B
0005433989713	30669	120	23C
0005432150094	30669	121	23D
0005434066709	30669	122	23E
0005434066665	30669	123	23F
0005433687688	9037	1	2B
0005433686612	9037	2	3B
0005433685505	9037	3	3C
0005433685501	9037	4	3D
0005433686616	9037	5	4A
0005433687683	9037	6	4B
0005433687682	9037	7	4C
0005433686615	9037	8	5A
0005433687686	9037	9	5C
0005433685504	9037	10	5D
0005433686611	9037	11	6B
0005433687685	9037	12	7A
0005433685502	9037	13	18B
0005433685506	9037	14	19B
0005433685503	9037	15	19C
0005433686610	9037	16	19D
0005433686614	9037	17	20C
0005433687687	9037	18	21B
0005433685500	9037	19	21D
0005433686613	9037	20	22A
0005433687684	9037	21	22C
0005432140353	5517	1	1B
0005435765483	5517	2	1C
0005435765496	5517	3	1G
0005435765516	5517	4	1H
0005435765504	5517	5	2B
0005435765518	5517	6	3A
0005435765503	5517	7	3C
0005435722028	5517	8	3H
0005435765512	5517	9	4B
0005435765510	5517	10	4F
0005434264696	5517	11	4H
0005435723022	5517	12	5B
0005435765492	5517	13	5C
0005435461777	5517	14	5G
0005435765540	5517	15	5F
0005435765542	5517	16	9B
0005435765543	5517	17	9G
0005435735083	5517	18	11A
0005435765498	5517	19	9H
0005435765499	5517	20	11B
0005435725539	5517	21	11E
0005435765519	5517	22	11H
0005435765487	5517	23	11G
0005435765534	5517	24	12A
0005435765538	5517	25	12E
0005435765525	5517	26	12D
0005435723020	5517	27	13B
0005433529235	5517	28	13A
0005435765517	5517	29	13F
0005435765500	5517	30	14A
0005435765521	5517	31	14E
0005433527224	5517	32	14F
0005435765482	5517	33	15A
0005435765545	5517	34	14H
0005435725538	5517	35	15D
0005435723021	5517	36	16A
0005432140352	5517	37	16D
0005435765529	5517	38	16F
0005432140356	5517	39	16H
0005435461842	5517	40	17D
0005435765522	5517	41	17B
0005433527223	5517	42	17G
0005435765480	5517	43	17H
0005435725537	5517	44	18B
0005435765530	5517	45	18A
0005435765531	5517	46	18D
0005435765532	5517	47	18E
0005435461823	5517	48	18G
0005435765515	5517	49	19B
0005435765533	5517	50	19A
0005435765481	5517	51	19E
0005435765535	5517	52	19D
0005435765524	5517	53	19F
0005435722027	5517	54	19G
0005435765495	5517	55	20F
0005435765511	5517	56	21A
0005435765501	5517	57	21E
0005435765478	5517	58	21G
0005435765494	5517	59	21H
0005435765509	5517	60	22A
0005432140349	5517	61	22D
0005433527225	5517	62	22F
0005435720811	5517	63	22G
0005435725541	5517	64	23A
0005435765486	5517	65	22H
0005432140351	5517	66	23H
0005435722026	5517	67	24B
0005435765514	5517	68	24A
0005435765520	5517	69	24H
0005435765485	5517	70	25E
0005435461779	5517	71	27D
0005435765505	5517	72	27B
0005435735082	5517	73	27A
0005435765493	5517	74	27E
0005435765508	5517	75	27G
0005435461843	5517	76	27F
0005435765537	5517	77	27H
0005435765477	5517	78	28E
0005435765527	5517	79	28D
0005435725540	5517	80	28H
0005433529236	5517	81	29E
0005435765523	5517	82	29G
0005433527222	5517	83	30B
0005435735081	5517	84	30D
0005432140350	5517	85	30F
0005435765541	5517	86	30E
0005435765490	5517	87	30H
0005435765546	5517	88	31B
0005434264697	5517	89	31D
0005435765502	5517	90	31F
0005435765497	5517	91	31H
0005435735085	5517	92	32D
0005435765536	5517	93	33G
0005432140355	5517	94	34A
0005435765513	5517	95	34E
0005432140354	5517	96	35B
0005435765507	5517	97	35A
0005435735084	5517	98	35D
0005435765479	5517	99	35G
0005435765539	5517	100	35F
0005435720812	5517	101	36A
0005435765506	5517	102	35H
0005435765544	5517	103	36B
0005435765488	5517	104	36G
0005435765491	5517	105	37D
0005435765484	5517	106	37B
0005435765528	5517	107	37H
0005435461778	5517	108	38A
0005435765489	5517	109	38D
0005435765547	5517	110	38E
0005435765526	5517	111	38G
0005432535777	13482	1	1A
0005435461988	13482	2	1F
0005435461993	13482	3	3A
0005435765140	13482	4	3G
0005435461997	13482	5	4A
0005434264841	13482	6	4B
0005434264842	13482	7	5A
0005435765123	13482	8	4H
0005434831098	13482	9	5B
0005434264843	13482	10	9A
0005435461998	13482	11	9H
0005435462002	13482	12	9B
0005435765205	13482	13	11B
0005434264838	13482	14	11A
0005434264849	13482	15	11D
0005435765190	13482	16	11G
0005434831095	13482	17	13B
0005435765206	13482	18	13A
0005434264858	13482	19	13D
0005435462018	13482	20	13F
0005435462022	13482	21	14G
0005434264857	13482	22	15A
0005435765183	13482	23	15B
0005435461991	13482	24	15E
0005435765104	13482	25	15H
0005434264840	13482	26	15G
0005435462009	13482	27	16A
0005435462012	13482	28	16D
0005434264860	13482	29	16B
0005435461996	13482	30	16E
0005435462013	13482	31	16G
0005435461990	13482	32	16F
0005435462004	13482	33	17A
0005435462001	13482	34	17E
0005435462024	13482	35	17F
0005432535780	13482	36	17H
0005435462021	13482	37	18B
0005432194462	13482	38	18H
0005435462011	13482	39	20A
0005434264853	13482	40	20D
0005434264851	13482	41	20B
0005434264856	13482	42	20E
0005434264844	13482	43	20G
0005434264859	13482	44	21A
0005432194463	13482	45	21B
0005435765103	13482	46	21E
0005435461992	13482	47	21H
0005435462017	13482	48	21G
0005434264839	13482	49	22D
0005435461995	13482	50	22F
0005435462005	13482	51	22H
0005435462008	13482	52	23G
0005435765141	13482	53	23H
0005435461994	13482	54	24B
0005435735059	13482	55	24E
0005435462000	13482	56	24F
0005434264850	13482	57	24G
0005435462016	13482	58	24H
0005434264836	13482	59	25E
0005434264848	13482	60	27A
0005435765240	13482	61	27D
0005435462019	13482	62	27F
0005432194461	13482	63	27G
0005435462003	13482	64	28E
0005435462014	13482	65	28F
0005434831097	13482	66	29B
0005435462015	13482	67	29G
0005432535779	13482	68	29F
0005432535776	13482	69	29H
0005434264846	13482	70	30F
0005434831096	13482	71	31A
0005435765160	13482	72	30H
0005435462010	13482	73	31D
0005435462026	13482	74	32E
0005435461999	13482	75	32D
0005434264845	13482	76	32F
0005435462023	13482	77	33A
0005434831099	13482	78	34B
0005435765120	13482	79	34F
0005434264854	13482	80	34H
0005434264837	13482	81	35A
0005435461989	13482	82	35F
0005432535775	13482	83	35G
0005434264855	13482	84	36B
0005435765102	13482	85	36D
0005435462007	13482	86	36F
0005432535778	13482	87	37E
0005434264835	13482	88	37D
0005434264852	13482	89	37F
0005435462020	13482	90	37H
0005434264847	13482	91	37G
0005435462025	13482	92	38D
0005432194464	13482	93	38H
0005435462006	13482	94	39F
0005434602864	18705	1	4B
0005434514936	18704	1	1B
0005434513547	18704	2	2A
0005434514935	18704	3	3B
0005434513548	18704	4	5A
0005434514934	18704	5	6A
0005434514925	19144	1	3A
0005434514924	19144	2	6B
0005432632663	4125	1	3A
0005435846188	4125	2	3D
0005432632661	4125	3	4E
0005432649333	4125	4	5A
0005435846190	4125	5	5D
0005432632658	4125	6	5E
0005432649337	4125	7	6A
0005432649335	4125	8	6F
0005432632660	4125	9	8A
0005432632668	4125	10	8D
0005432632664	4125	11	9A
0005432632665	4125	12	9D
0005432632659	4125	13	10A
0005432632662	4125	14	10D
0005432632657	4125	15	11A
0005432649336	4125	16	12C
0005432632669	4125	17	13A
0005432649338	4125	18	13D
0005432649331	4125	19	13E
0005432649334	4125	20	13F
0005432632656	4125	21	14F
0005435846194	4125	22	15D
0005432649329	4125	23	15F
0005432649327	4125	24	16A
0005432632655	4125	25	17F
0005432632666	4125	26	18F
0005432649332	4125	27	19A
0005432649330	4125	28	19E
0005432649328	4125	29	19F
0005432632667	4125	30	20A
0005433007853	1804	1	1A
0005433810508	1804	2	1D
0005433007825	1804	3	2A
0005433007873	1804	4	2C
0005432295848	1804	5	4E
0005433284783	1804	6	5E
0005433007855	1804	7	5F
0005433007856	1804	8	6A
0005433007874	1804	9	6C
0005433284805	1804	10	7E
0005433007918	1804	11	8C
0005432295850	1804	12	10C
0005433007950	1804	13	13A
0005432295849	1804	14	14A
0005433007823	1804	15	15A
0005433284823	1804	16	17A
0005433007919	1804	17	18E
0005433284824	1804	18	18F
0005433284782	1804	19	19C
0005433810509	1804	20	19D
0005433008083	22512	1	1A
0005433284928	22512	2	1F
0005433284930	22512	3	2A
0005433284927	22512	4	2C
0005433008070	22512	5	2D
0005433284941	22512	6	3D
0005433008064	22512	7	3F
0005433284923	22512	8	4C
0005433284911	22512	9	4D
0005433284934	22512	10	4E
0005433284942	22512	11	4F
0005433284919	22512	12	5A
0005433008086	22512	13	5C
0005433008097	22512	14	5D
0005433284933	22512	15	5E
0005433008076	22512	16	5F
0005433284926	22512	17	6A
0005433008068	22512	18	6C
0005433284918	22512	19	6D
0005433284921	22512	20	6F
0005433008084	22512	21	7A
0005433284922	22512	22	7C
0005433008096	22512	23	7D
0005433284940	22512	24	7E
0005433008059	22512	25	7F
0005433008081	22512	26	8C
0005433284938	22512	27	8D
0005433008072	22512	28	8E
0005433008074	22512	29	9C
0005433008088	22512	30	9D
0005433008080	22512	31	9E
0005433284920	22512	32	9F
0005433008077	22512	33	10C
0005433008069	22512	34	10D
0005433008087	22512	35	10E
0005433284929	22512	36	10F
0005433284924	22512	37	11A
0005433008071	22512	38	11C
0005433008066	22512	39	11D
0005433284912	22512	40	11E
0005433284931	22512	41	11F
0005433008099	22512	42	12A
0005433284917	22512	43	12C
0005433008065	22512	44	12D
0005433008057	22512	45	12E
0005433008067	22512	46	12F
0005433008090	22512	47	13A
0005433008091	22512	48	13C
0005433008061	22512	49	13D
0005433284939	22512	50	13E
0005433008085	22512	51	13F
0005433008095	22512	52	14A
0005433008075	22512	53	14F
0005433008073	22512	54	15C
0005433284935	22512	55	15D
0005433008092	22512	56	15E
0005433284932	22512	57	16A
0005433008063	22512	58	16C
0005433008082	22512	59	16D
0005433008078	22512	60	16E
0005433008055	22512	61	16F
0005433284936	22512	62	17A
0005433008093	22512	63	17C
0005433008094	22512	64	17E
0005433008060	22512	65	17F
0005433008098	22512	66	18C
0005433284937	22512	67	18D
0005433284915	22512	68	18F
0005433284914	22512	69	19A
0005433284913	22512	70	19C
0005433284925	22512	71	19D
0005433008058	22512	72	19F
0005433008079	22512	73	20A
0005433008062	22512	74	20C
0005433008089	22512	75	20D
0005433008056	22512	76	20E
0005433284916	22512	77	20F
0005434152771	12293	1	1A
0005434152764	12293	2	1C
0005434152762	12293	3	1D
0005432755018	12293	4	1F
0005434152760	12293	5	6C
0005434152770	12293	6	7E
0005434152765	12293	7	10D
0005434152769	12293	8	11A
0005434152768	12293	9	11C
0005432755019	12293	10	11F
0005434152761	12293	11	12A
0005434152763	12293	12	12C
0005434152767	12293	13	13D
0005434152766	12293	14	20A
0005433815326	5559	1	1C
0005433846036	5559	2	1A
0005433815325	5559	3	2C
0005433846032	5559	4	2A
0005433846074	5559	5	1F
0005433846037	5559	6	2D
0005433815329	5559	7	3A
0005432081440	5559	8	3D
0005432081435	5559	9	3F
0005433815328	5559	10	4C
0005433846029	5559	11	4F
0005433846055	5559	12	4D
0005433846078	5559	13	5F
0005433846024	5559	14	5D
0005433846048	5559	15	6B
0005433846064	5559	16	6D
0005433846051	5559	17	6C
0005433846057	5559	18	6F
0005433846058	5559	19	7C
0005433846049	5559	20	7D
0005433846079	5559	21	8A
0005433846059	5559	22	7F
0005433846047	5559	23	8B
0005433846025	5559	24	8E
0005433846062	5559	25	8D
0005433846040	5559	26	8F
0005433846081	5559	27	9B
0005433846075	5559	28	9A
0005433846044	5559	29	9D
0005433846052	5559	30	9C
0005433815327	5559	31	9F
0005433846056	5559	32	10A
0005432081441	5559	33	10C
0005433846076	5559	34	10B
0005433846030	5559	35	10D
0005433846072	5559	36	11A
0005433846033	5559	37	10F
0005432081437	5559	38	11D
0005432081439	5559	39	12B
0005433846060	5559	40	12D
0005433846043	5559	41	12E
0005433846069	5559	42	13A
0005433846070	5559	43	13C
0005433846035	5559	44	13E
0005433846042	5559	45	13D
0005433846023	5559	46	14A
0005433846034	5559	47	13F
0005433846028	5559	48	14C
0005433846061	5559	49	14B
0005432081434	5559	50	14D
0005433846073	5559	51	14F
0005433846039	5559	52	15B
0005433846067	5559	53	15A
0005433846045	5559	54	15C
0005433846046	5559	55	15F
0005432081436	5559	56	16C
0005433846026	5559	57	16D
0005432081438	5559	58	17A
0005433846065	5559	59	16E
0005433846080	5559	60	17C
0005433846038	5559	61	17F
0005433846077	5559	62	17E
0005433846053	5559	63	18C
0005433846054	5559	64	18B
0005433846063	5559	65	18E
0005433846068	5559	66	19B
0005433846022	5559	67	19A
0005433846041	5559	68	19D
0005433846027	5559	69	19E
0005433846031	5559	70	20C
0005432081433	5559	71	20F
0005433846050	5559	72	20E
0005433846071	5559	73	21E
0005433846066	5559	74	21F
0005434173477	13863	1	1D
0005435282208	13863	2	2A
0005433845749	13863	3	2D
0005435282225	13863	4	2C
0005434173476	13863	5	2F
0005435282222	13863	6	3D
0005435282217	13863	7	3C
0005433845750	13863	8	4A
0005435282209	13863	9	4C
0005434173475	13863	10	6A
0005433845816	13863	11	6D
0005432003665	13863	12	7C
0005434173474	13863	13	7E
0005435282229	13863	14	8C
0005433845766	13863	15	8E
0005435282213	13863	16	8D
0005433815308	13863	17	8F
0005433845792	13863	18	9A
0005432003664	13863	19	9C
0005435282220	13863	20	9E
0005435282223	13863	21	9F
0005433845674	13863	22	10B
0005435282230	13863	23	10E
0005435282221	13863	24	10F
0005433845720	13863	25	11F
0005435282216	13863	26	11E
0005435282219	13863	27	12A
0005435282228	13863	28	12E
0005435282226	13863	29	12F
0005435282214	13863	30	14A
0005433845775	13863	31	13F
0005433815302	13863	32	13E
0005435282224	13863	33	14B
0005432003666	13863	34	14C
0005434173473	13863	35	14F
0005435282218	13863	36	15B
0005433845783	13863	37	15C
0005433845791	13863	38	15E
0005433845840	13863	39	15F
0005435282227	13863	40	16B
0005433815301	13863	41	16F
0005433845767	13863	42	17B
0005433845839	13863	43	17F
0005433845721	13863	44	18D
0005435282211	13863	45	18C
0005432003667	13863	46	19A
0005435282215	13863	47	19D
0005435282212	13863	48	20A
0005435282231	13863	49	21A
0005435282210	13863	50	21F
0005434620368	7844	1	1C
0005434620365	7844	2	2A
0005434620361	7844	3	2B
0005435332159	7844	4	3A
0005434620359	7844	5	4A
0005434620360	7844	6	4B
0005434620363	7844	7	5A
0005432112491	7844	8	5B
0005434620354	7844	9	5C
0005434620350	7844	10	6C
0005434620351	7844	11	6D
0005434620358	7844	12	7A
0005434620369	7844	13	7C
0005434620353	7844	14	18A
0005434620357	7844	15	18C
0005434620362	7844	16	18D
0005434620348	7844	17	19A
0005434620356	7844	18	19B
0005434620366	7844	19	19D
0005434620349	7844	20	20B
0005434620355	7844	21	20D
0005434620352	7844	22	21A
0005432112490	7844	23	21B
0005432112489	7844	24	22B
0005434620364	7844	25	22C
0005434620367	7844	26	22D
0005435332187	7844	27	23B
0005435332217	32994	1	2A
0005435332214	32994	2	3A
0005435332218	32994	3	3B
0005435332212	32994	4	3C
0005435332219	32994	5	3D
0005435332210	32994	6	4C
0005434620235	32994	7	4D
0005434620293	32994	8	6D
0005435332220	32994	9	18A
0005434620291	32994	10	18B
0005435332215	32994	11	19B
0005435332216	32994	12	19C
0005435332213	32994	13	20B
0005434620274	32994	14	20D
0005434620294	32994	15	21C
0005434620241	32994	16	22B
0005435332211	32994	17	23B
0005432190586	4287	1	1A
0005435784947	4287	2	1C
0005432190584	4287	3	1D
0005435784965	4287	4	2C
0005435784950	4287	5	2D
0005435784960	4287	6	2F
0005435784943	4287	7	3A
0005435784963	4287	8	4C
0005435784961	4287	9	4D
0005435784946	4287	10	4E
0005434993910	4287	11	5A
0005435784955	4287	12	5C
0005435784953	4287	13	5E
0005435784969	4287	14	5F
0005435784957	4287	15	6D
0005435784945	4287	16	6E
0005435784944	4287	17	6F
0005435784939	4287	18	7A
0005435784966	4287	19	7C
0005435784959	4287	20	7D
0005435784940	4287	21	8A
0005435784951	4287	22	8D
0005435784949	4287	23	9D
0005434993911	4287	24	9E
0005434993913	4287	25	9F
0005434993909	4287	26	10F
0005434993906	4287	27	11A
0005435784956	4287	28	11C
0005435784952	4287	29	11E
0005435784962	4287	30	11F
0005435787329	4287	31	12A
0005432190583	4287	32	12C
0005435784973	4287	33	13A
0005435784970	4287	34	13E
0005435784974	4287	35	13F
0005435784967	4287	36	14A
0005434993914	4287	37	14C
0005435784942	4287	38	14E
0005432190585	4287	39	15C
0005435784948	4287	40	15E
0005434993907	4287	41	15F
0005435784968	4287	42	16A
0005435787328	4287	43	16C
0005434993912	4287	44	16D
0005435784971	4287	45	17A
0005435784972	4287	46	17C
0005435918584	4287	47	17F
0005435784976	4287	48	18A
0005435784941	4287	49	18E
0005435784954	4287	50	18F
0005435784975	4287	51	19C
0005435784958	4287	52	19D
0005434993908	4287	53	19F
0005435784964	4287	54	20A
0005432195667	27303	1	5A
0005434993846	27303	2	5F
0005435918600	27303	3	7C
0005435918602	27303	4	8A
0005435918601	27303	5	9E
0005434993859	27303	6	15E
0005435918599	27303	7	15F
0005434993872	27303	8	16A
0005435918598	27303	9	18A
0005434993860	27303	10	18D
0005435784781	27303	11	20F
0005432146175	19901	1	23B
0005434081646	4720	1	1C
0005432459263	4720	2	1B
0005434081633	4720	3	1F
0005434081648	4720	4	1G
0005432459272	4720	5	2A
0005432170306	4720	6	1H
0005432566909	4720	7	2B
0005432566956	4720	8	2H
0005434081638	4720	9	2G
0005432566904	4720	10	2F
0005432459251	4720	11	3C
0005432459261	4720	12	3B
0005434081626	4720	13	3G
0005432566930	4720	14	3F
0005432459276	4720	15	3H
0005432566949	4720	16	4A
0005432459259	4720	17	4C
0005432459227	4720	18	4H
0005432459235	4720	19	4F
0005434081647	4720	20	5B
0005432566959	4720	21	5F
0005432459240	4720	22	5C
0005432566963	4720	23	5G
0005432566913	4720	24	5H
0005434081641	4720	25	9B
0005432459233	4720	26	9A
0005432459266	4720	27	9G
0005432459226	4720	28	11A
0005432566908	4720	29	9H
0005432566916	4720	30	11E
0005432459242	4720	31	11G
0005432459269	4720	32	11H
0005432170307	4720	33	12A
0005432566920	4720	34	12D
0005432566950	4720	35	12E
0005432566960	4720	36	12H
0005432459268	4720	37	13A
0005432459265	4720	38	13D
0005432566957	4720	39	13B
0005432566901	4720	40	13G
0005432566902	4720	41	13H
0005432459274	4720	42	14B
0005432566926	4720	43	14E
0005433452714	4720	44	14D
0005432459267	4720	45	14F
0005432571278	4720	46	14G
0005432566958	4720	47	14H
0005434081628	4720	48	15B
0005432566928	4720	49	15A
0005432566962	4720	50	15E
0005434081645	4720	51	15D
0005432170309	4720	52	15F
0005432459262	4720	53	15H
0005432459256	4720	54	16A
0005432459237	4720	55	16B
0005432566927	4720	56	16F
0005434081649	4720	57	16E
0005432566942	4720	58	16D
0005432186827	4720	59	17A
0005433726076	4720	60	17D
0005432459270	4720	61	17B
0005432566938	4720	62	17G
0005432566931	4720	63	17F
0005432459252	4720	64	17H
0005432170311	4720	65	18A
0005432566937	4720	66	18E
0005432459250	4720	67	18D
0005432459234	4720	68	18F
0005432566945	4720	69	18G
0005432566934	4720	70	19A
0005432571279	4720	71	18H
0005434081639	4720	72	19E
0005432566955	4720	73	19D
0005434081643	4720	74	19G
0005432566943	4720	75	20A
0005432459243	4720	76	20B
0005432571276	4720	77	20E
0005432566954	4720	78	20D
0005432459231	4720	79	20F
0005432186830	4720	80	20H
0005432566944	4720	81	21B
0005432566933	4720	82	21A
0005432566911	4720	83	21F
0005434081640	4720	84	21D
0005432566936	4720	85	21H
0005432459232	4720	86	21G
0005432459275	4720	87	22B
0005432459230	4720	88	22D
0005432459253	4720	89	22E
0005434081630	4720	90	22G
0005432566915	4720	91	23B
0005432459255	4720	92	23A
0005432459260	4720	93	23D
0005432566919	4720	94	23F
0005432566935	4720	95	23G
0005432459244	4720	96	24B
0005432566953	4720	97	24D
0005432566932	4720	98	24F
0005432571277	4720	99	25D
0005432170308	4720	100	24H
0005432459229	4720	101	27A
0005432459271	4720	102	25F
0005432566952	4720	103	27B
0005432459241	4720	104	27D
0005432459258	4720	105	27E
0005432566961	4720	106	27G
0005432459246	4720	107	28A
0005434081650	4720	108	27H
0005432566923	4720	109	28B
0005432566903	4720	110	28F
0005432459247	4720	111	28H
0005432566907	4720	112	29A
0005434081634	4720	113	29B
0005433452715	4720	114	29E
0005432459249	4720	115	29D
0005432566925	4720	116	29H
0005432170310	4720	117	29G
0005432566939	4720	118	30F
0005432566910	4720	119	30E
0005432459239	4720	120	30G
0005432186829	4720	121	30H
0005432566905	4720	122	31B
0005432170312	4720	123	31A
0005432566941	4720	124	31D
0005432566912	4720	125	31F
0005432566940	4720	126	32A
0005434081632	4720	127	31H
0005432459223	4720	128	32E
0005434081644	4720	129	32D
0005433726077	4720	130	32F
0005432566921	4720	131	32H
0005434081636	4720	132	32G
0005432186828	4720	133	33B
0005432459225	4720	134	33A
0005432566924	4720	135	33E
0005434081627	4720	136	33D
0005432459264	4720	137	33G
0005432459238	4720	138	33F
0005434081629	4720	139	33H
0005434081651	4720	140	34B
0005432566918	4720	141	34A
0005432566914	4720	142	34F
0005432566951	4720	143	34E
0005432566929	4720	144	35B
0005432459254	4720	145	35A
0005434081652	4720	146	35D
0005432566948	4720	147	35G
0005432566946	4720	148	36B
0005432459245	4720	149	36A
0005432566922	4720	150	36D
0005434081631	4720	151	36H
0005432459273	4720	152	36G
0005434081642	4720	153	37A
0005432566906	4720	154	37E
0005432566917	4720	155	37D
0005432459257	4720	156	37F
0005434081637	4720	157	37H
0005432566947	4720	158	38B
0005432459236	4720	159	38A
0005432459224	4720	160	38D
0005432459228	4720	161	38E
0005433726078	4720	162	38F
0005432459248	4720	163	39D
0005434081635	4720	164	39F
0005432566574	30519	1	1B
0005432458985	30519	2	2C
0005432566529	30519	3	2H
0005432161127	30519	4	3B
0005432459049	30519	5	3F
0005432458988	30519	6	5C
0005432458986	30519	7	9H
0005432458957	30519	8	11D
0005432459041	30519	9	12F
0005433454840	30519	10	12G
0005432566580	30519	11	13A
0005432566657	30519	12	13D
0005432161124	30519	13	13B
0005432458984	30519	14	13G
0005432566546	30519	15	14F
0005432213564	30519	16	14H
0005432566762	30519	17	18F
0005432566549	30519	18	19B
0005432459050	30519	19	20F
0005432458958	30519	20	21A
0005433454839	30519	21	21F
0005432458959	30519	22	23A
0005432213562	30519	23	24A
0005432566649	30519	24	25D
0005432213563	30519	25	25E
0005432161125	30519	26	27A
0005432459042	30519	27	30A
0005432566650	30519	28	30B
0005432566573	30519	29	31B
0005432566656	30519	30	32E
0005432566601	30519	31	32D
0005432213561	30519	32	35E
0005432566602	30519	33	37E
0005432566667	30519	34	37D
0005432161126	30519	35	38D
0005432566668	30519	36	38E
0005432566636	30519	37	38H
0005432213565	30519	38	39D
0005435722028	13612	1	1A
0005435722026	13612	2	2A
0005435720812	13612	3	3A
0005435720811	13612	4	3B
0005435722027	13612	5	4A
0005432295850	22781	1	4D
0005432295849	22781	2	20B
0005432295848	22781	3	20D
0005433342079	11108	1	1A
0005433342024	11108	2	1F
0005433341992	11108	3	1D
0005433341993	11108	4	2D
0005433342042	11108	5	2C
0005433342082	11108	6	3A
0005433342019	11108	7	3C
0005433342032	11108	8	3D
0005433342071	11108	9	3F
0005435097096	11108	10	4B
0005433342047	11108	11	4D
0005433342064	11108	12	4C
0005433342027	11108	13	4E
0005433342048	11108	14	4F
0005433341999	11108	15	5A
0005433342066	11108	16	5D
0005433342067	11108	17	5C
0005433342000	11108	18	5E
0005433342087	11108	19	5F
0005433342010	11108	20	6A
0005433342062	11108	21	6C
0005433341997	11108	22	6D
0005433342072	11108	23	6F
0005433342056	11108	24	6E
0005433342008	11108	25	7A
0005433342059	11108	26	7B
0005433342006	11108	27	7C
0005433342077	11108	28	7D
0005433342080	11108	29	7E
0005433342033	11108	30	7F
0005433342075	11108	31	8B
0005433342051	11108	32	8A
0005433342045	11108	33	8E
0005433342068	11108	34	8F
0005433341996	11108	35	9A
0005435097095	11108	36	9B
0005435097092	11108	37	9D
0005433342007	11108	38	9C
0005433342011	11108	39	9E
0005433342016	11108	40	9F
0005433342069	11108	41	10B
0005433342081	11108	42	10C
0005433342073	11108	43	10E
0005435097090	11108	44	10D
0005433342020	11108	45	11A
0005433342030	11108	46	11B
0005433342054	11108	47	11D
0005433342004	11108	48	11C
0005433342035	11108	49	11E
0005433342022	11108	50	11F
0005435097094	11108	51	12D
0005433342063	11108	52	12C
0005433342057	11108	53	12E
0005433341995	11108	54	12F
0005433342049	11108	55	13B
0005433342039	11108	56	13A
0005433342046	11108	57	13C
0005433342058	11108	58	13D
0005433341998	11108	59	13E
0005435097091	11108	60	13F
0005433342044	11108	61	14B
0005435097098	11108	62	14A
0005433342083	11108	63	14D
0005433342060	11108	64	14E
0005433342015	11108	65	14F
0005433342040	11108	66	15B
0005433342021	11108	67	15D
0005433342013	11108	68	15E
0005433342026	11108	69	16B
0005433342014	11108	70	16A
0005433342037	11108	71	16C
0005433341989	11108	72	16D
0005435097088	11108	73	16E
0005435097093	11108	74	17A
0005433342070	11108	75	16F
0005433342085	11108	76	17B
0005433342038	11108	77	17C
0005433342025	11108	78	17E
0005433342002	11108	79	17D
0005433342055	11108	80	17F
0005433342052	11108	81	18A
0005433342074	11108	82	18B
0005433342034	11108	83	18D
0005433342003	11108	84	18C
0005433342009	11108	85	18E
0005433342005	11108	86	18F
0005433342012	11108	87	19A
0005433342076	11108	88	19B
0005433342041	11108	89	19D
0005433342050	11108	90	19C
0005433342043	11108	91	19F
0005433342053	11108	92	20B
0005433342028	11108	93	20A
0005435097089	11108	94	20C
0005433342001	11108	95	20E
0005433342088	11108	96	21A
0005433342031	11108	97	21B
0005433342065	11108	98	21D
0005433342078	11108	99	21C
0005433342084	11108	100	21F
0005433342018	11108	101	21E
0005433342029	11108	102	22A
0005433341990	11108	103	22C
0005435097097	11108	104	22B
0005433342017	11108	105	22E
0005433342061	11108	106	22D
0005433341988	11108	107	23A
0005433341991	11108	108	22F
0005433342023	11108	109	23B
0005433342036	11108	110	23C
0005433341994	11108	111	23E
0005433342086	11108	112	23F
0005433341670	17136	1	1C
0005433341406	17136	2	4C
0005433341466	17136	3	7F
0005433341525	17136	4	11C
0005433341405	17136	5	14C
0005432293180	17136	6	17B
0005432293179	17136	7	18D
0005433341465	17136	8	19E
0005433341549	17136	9	21B
0005433506981	9066	1	1F
0005433506965	9066	2	4A
0005433506975	9066	3	4C
0005433506977	9066	4	5C
0005433506972	9066	5	5E
0005433506970	9066	6	6C
0005433506962	9066	7	7A
0005433506974	9066	8	7D
0005433506966	9066	9	7E
0005433506968	9066	10	8C
0005433506980	9066	11	8E
0005433481078	9066	12	9E
0005433506978	9066	13	10D
0005433506976	9066	14	11A
0005433481082	9066	15	11D
0005433506961	9066	16	11E
0005433481079	9066	17	12A
0005433506960	9066	18	12D
0005433481077	9066	19	12F
0005433481081	9066	20	14D
0005433481076	9066	21	14F
0005434158943	9066	22	15E
0005433506967	9066	23	16C
0005433506973	9066	24	16F
0005433506959	9066	25	17C
0005433481080	9066	26	18E
0005433506979	9066	27	18F
0005433506964	9066	28	19A
0005433506963	9066	29	19C
0005433506969	9066	30	19D
0005433506971	9066	31	20A
0005432919645	20445	1	1A
0005433506871	20445	2	2D
0005433506872	20445	3	2F
0005432919637	20445	4	3C
0005432919632	20445	5	4A
0005432919638	20445	6	4E
0005432919639	20445	7	5C
0005432919640	20445	8	5D
0005432919643	20445	9	7A
0005432919641	20445	10	7C
0005432919647	20445	11	8A
0005432919635	20445	12	8E
0005433506856	20445	13	8F
0005433481041	20445	14	9A
0005432919650	20445	15	10D
0005433481039	20445	16	11E
0005432919653	20445	17	11F
0005432919651	20445	18	12A
0005432919633	20445	19	12F
0005432919644	20445	20	13C
0005432919642	20445	21	14D
0005432919648	20445	22	14E
0005432919646	20445	23	15C
0005432919636	20445	24	15D
0005432919634	20445	25	16C
0005432919649	20445	26	16E
0005433506855	20445	27	16F
0005432919652	20445	28	17E
0005433481043	20445	29	17F
0005432919631	20445	30	18E
0005433506873	20445	31	19E
0005433481042	20445	32	20D
0005432396193	10139	1	1A
0005432394055	10139	2	1B
0005432396192	10139	3	2A
0005432396194	10139	4	2B
0005432394052	10139	5	3A
0005432394053	10139	6	3B
0005432394056	10139	7	5A
0005432394054	10139	8	5B
0005432396195	10139	9	6A
0005435179388	18284	1	3A
0005435179387	18284	2	4A
0005435125684	11055	1	1C
0005434928267	11055	2	1D
0005434411728	11055	3	3D
0005434411730	11055	4	6D
0005434928266	11055	5	6F
0005435125669	11055	6	8E
0005435125668	11055	7	12A
0005434411729	11055	8	14D
0005435125649	11055	9	15A
0005434411731	11055	10	16C
0005434928268	11055	11	16D
0005435554105	11055	12	18E
0005435125657	11055	13	19D
0005435125912	14705	1	1A
0005435125900	14705	2	1D
0005435625981	14705	3	1F
0005435125935	14705	4	2A
0005435556661	14705	5	2C
0005435125904	14705	6	2D
0005435125931	14705	7	2F
0005435125914	14705	8	3A
0005435556662	14705	9	3C
0005434928260	14705	10	3D
0005434928259	14705	11	3F
0005435625971	14705	12	4D
0005435125897	14705	13	4E
0005435625978	14705	14	4F
0005435125908	14705	15	5C
0005435125919	14705	16	5D
0005435125899	14705	17	5E
0005435125917	14705	18	5F
0005435125927	14705	19	6A
0005435125909	14705	20	6C
0005435125906	14705	21	6D
0005435625972	14705	22	7A
0005435125926	14705	23	7D
0005435125905	14705	24	7F
0005435625982	14705	25	8F
0005435125910	14705	26	9A
0005435625983	14705	27	9C
0005435125916	14705	28	9D
0005435556663	14705	29	9E
0005435125933	14705	30	9F
0005435625973	14705	31	10A
0005435125925	14705	32	10E
0005435625979	14705	33	10D
0005435125901	14705	34	10F
0005435125920	14705	35	11A
0005435125918	14705	36	11C
0005435125930	14705	37	11F
0005435125921	14705	38	12A
0005435554129	14705	39	12C
0005435554130	14705	40	12D
0005435125913	14705	41	12E
0005435125898	14705	42	13C
0005435625974	14705	43	14A
0005435625977	14705	44	15A
0005435125928	14705	45	15C
0005435556664	14705	46	15D
0005435554131	14705	47	15F
0005435125915	14705	48	16A
0005435625980	14705	49	16C
0005435125922	14705	50	16D
0005435556665	14705	51	16F
0005435125902	14705	52	17A
0005435554132	14705	53	17C
0005435625975	14705	54	17E
0005435625976	14705	55	17F
0005435125932	14705	56	18A
0005435125934	14705	57	18E
0005435125903	14705	58	18F
0005435125907	14705	59	19A
0005435125936	14705	60	19C
0005435125923	14705	61	19E
0005435125911	14705	62	19F
0005435125937	14705	63	20C
0005435125929	14705	64	20D
0005435125924	14705	65	20F
0005435443151	7104	1	1A
0005435715272	7104	2	1C
0005435715275	7104	3	1D
0005435715280	7104	4	1F
0005432400084	7104	5	2A
0005435715269	7104	6	2F
0005435715268	7104	7	3D
0005435715278	7104	8	4A
0005432400085	7104	9	5F
0005435715264	7104	10	6A
0005435715276	7104	11	8A
0005435715270	7104	12	8D
0005432398155	7104	13	10E
0005435715271	7104	14	11A
0005432400083	7104	15	11C
0005435715266	7104	16	11E
0005432398154	7104	17	12A
0005432398156	7104	18	12E
0005435221035	7104	19	13A
0005435715267	7104	20	13D
0005435715281	7104	21	13F
0005435715279	7104	22	14C
0005432400082	7104	23	14D
0005435715274	7104	24	15C
0005435715277	7104	25	16A
0005435715273	7104	26	18A
0005435715265	7104	27	18E
0005432398152	7104	28	18F
0005432398153	7104	29	19A
0005435178477	27088	1	2A
0005435178982	27088	2	5E
0005435178476	27088	3	6D
0005435443202	27088	4	7D
0005435443203	27088	5	8F
0005435443204	27088	6	12C
0005435715206	27088	7	14A
0005435443208	27088	8	14C
0005435443210	27088	9	14D
0005435178981	27088	10	16A
0005435443207	27088	11	17A
0005435443205	27088	12	17F
0005435443209	27088	13	19C
0005435443206	27088	14	20A
0005434084881	2754	1	1A
0005434084880	2754	2	2B
0005434084877	2754	3	3A
0005434084876	2754	4	3B
0005434084878	2754	5	4A
0005434084879	2754	6	4B
0005434084875	2754	7	5B
0005433060382	28502	1	1B
0005433060381	28502	2	3B
0005433060383	28502	3	5A
0005432632642	25190	1	1B
0005432632648	25190	2	1C
0005432632643	25190	3	2B
0005432632649	25190	4	2C
0005432632645	25190	5	3C
0005432632654	25190	6	3D
0005432632638	25190	7	4B
0005432632652	25190	8	4C
0005432632636	25190	9	5B
0005432632653	25190	10	5C
0005432632641	25190	11	7A
0005432632651	25190	12	7C
0005432632639	25190	13	7D
0005432632644	25190	14	18B
0005432632646	25190	15	18C
0005432632635	25190	16	18D
0005432632647	25190	17	19A
0005432632637	25190	18	19D
0005432632640	25190	19	21D
0005432632650	25190	20	22C
0005435844276	28176	1	1B
0005435844272	28176	2	1C
0005435844274	28176	3	2A
0005435844281	28176	4	2B
0005435844275	28176	5	2C
0005432632627	28176	6	2D
0005435844279	28176	7	3A
0005435844277	28176	8	5C
0005435844278	28176	9	7A
0005435844273	28176	10	19A
0005435844271	28176	11	19D
0005435844280	28176	12	21A
0005435844282	28176	13	22B
0005435517618	11363	1	2F
0005435540647	11363	2	6F
0005435517587	11363	3	9D
0005435517616	11363	4	10D
0005435517586	11363	5	11F
0005435517627	11363	6	12F
0005435540626	11363	7	13E
0005435540630	11363	8	14C
0005435540740	22242	1	1C
0005435529005	22242	2	1D
0005435528990	22242	3	1F
0005435540742	22242	4	2C
0005435540736	22242	5	2D
0005435528992	22242	6	2F
0005435528994	22242	7	3F
0005435540753	22242	8	4A
0005435540734	22242	9	4C
0005435528993	22242	10	4E
0005435528997	22242	11	4F
0005435540749	22242	12	5D
0005435529010	22242	13	5E
0005435540751	22242	14	5F
0005435529008	22242	15	6A
0005435540744	22242	16	6C
0005435540748	22242	17	6D
0005435529001	22242	18	6E
0005435528999	22242	19	7A
0005435528989	22242	20	7F
0005435528998	22242	21	8C
0005435529002	22242	22	8E
0005435540754	22242	23	8F
0005432294457	22242	24	9A
0005432294459	22242	25	10A
0005435529006	22242	26	10D
0005435540755	22242	27	11A
0005435540743	22242	28	11C
0005435529009	22242	29	11D
0005435528991	22242	30	11F
0005435540747	22242	31	12A
0005435540737	22242	32	13A
0005435540735	22242	33	14C
0005432294458	22242	34	14D
0005435540746	22242	35	14F
0005435529003	22242	36	15C
0005435529007	22242	37	15E
0005435540752	22242	38	16C
0005435528995	22242	39	16D
0005435540741	22242	40	16F
0005435529004	22242	41	17A
0005435540739	22242	42	17C
0005435540738	22242	43	17E
0005435540750	22242	44	18A
0005435528996	22242	45	19C
0005435540745	22242	46	19E
0005435529000	22242	47	19F
0005434906744	2306	1	1A
0005433250997	2306	2	1C
0005433250950	2306	3	1D
0005433250963	2306	4	1F
0005433250989	2306	5	2C
0005434906694	2306	6	2D
0005434906714	2306	7	3A
0005434906747	2306	8	3C
0005434906724	2306	9	3F
0005434906727	2306	10	4C
0005434906703	2306	11	4A
0005434906731	2306	12	4D
0005433250938	2306	13	4E
0005434906707	2306	14	4F
0005434906739	2306	15	5A
0005434906729	2306	16	5C
0005434906717	2306	17	5D
0005434906710	2306	18	6A
0005434906728	2306	19	6C
0005434906742	2306	20	7A
0005434906713	2306	21	7C
0005434906721	2306	22	7D
0005434906702	2306	23	7E
0005433251002	2306	24	8C
0005433251003	2306	25	8E
0005434906701	2306	26	8F
0005434906743	2306	27	9A
0005434906730	2306	28	9C
0005434906711	2306	29	9F
0005434906700	2306	30	10A
0005433250928	2306	31	10C
0005434906708	2306	32	10E
0005434906734	2306	33	10D
0005434906695	2306	34	10F
0005434906720	2306	35	11A
0005434906719	2306	36	11C
0005434906722	2306	37	11E
0005434906749	2306	38	11D
0005434906716	2306	39	11F
0005434906725	2306	40	12A
0005434906696	2306	41	12E
0005433250986	2306	42	12F
0005433250943	2306	43	13A
0005434906712	2306	44	13C
0005433250939	2306	45	13D
0005433250957	2306	46	13E
0005434906698	2306	47	14A
0005434906738	2306	48	14C
0005434906709	2306	49	14D
0005434906726	2306	50	14E
0005434906699	2306	51	15A
0005434906715	2306	52	15E
0005434906732	2306	53	15F
0005433250964	2306	54	16A
0005433250927	2306	55	16D
0005434906704	2306	56	16E
0005434906740	2306	57	17A
0005434906746	2306	58	17C
0005434906736	2306	59	17D
0005434906735	2306	60	17F
0005434906741	2306	61	18A
0005434906706	2306	62	18C
0005434906697	2306	63	18D
0005434906737	2306	64	18E
0005434906718	2306	65	18F
0005433250949	2306	66	19A
0005434906705	2306	67	19C
0005434906748	2306	68	19D
0005434906723	2306	69	19E
0005433251004	2306	70	19F
0005434906693	2306	71	20A
0005434906745	2306	72	20C
0005434906733	2306	73	20D
0005433251005	2306	74	20F
0005433251125	25581	1	1F
0005433251145	25581	2	2F
0005433251124	25581	3	3C
0005433251134	25581	4	3D
0005433251127	25581	5	3F
0005433251137	25581	6	4C
0005433251118	25581	7	5C
0005433251126	25581	8	6F
0005433251128	25581	9	7E
0005433251146	25581	10	7F
0005433251132	25581	11	8C
0005433400950	25581	12	8F
0005433251129	25581	13	9D
0005433251131	25581	14	10A
0005433251147	25581	15	10F
0005433251148	25581	16	11A
0005433251123	25581	17	11E
0005433251138	25581	18	12C
0005433251130	25581	19	12D
0005433251121	25581	20	13C
0005433251140	25581	21	13D
0005433251122	25581	22	14D
0005433251120	25581	23	15C
0005433251133	25581	24	16C
0005433400949	25581	25	16E
0005433251144	25581	26	17D
0005433400948	25581	27	17F
0005433251139	25581	28	18C
0005433251143	25581	29	18E
0005433251141	25581	30	19A
0005433251142	25581	31	19D
0005433251119	25581	32	19E
0005433251135	25581	33	20C
0005433251136	25581	34	20E
0005432620880	2509	1	2A
0005432620887	2509	2	3B
0005432620875	2509	3	5A
0005432620885	2509	4	5B
0005432620874	2509	5	7C
0005432620881	2509	6	18A
0005432620879	2509	7	18B
0005432862162	2509	8	18C
0005432620883	2509	9	19A
0005432620886	2509	10	19C
0005432620878	2509	11	20A
0005432620882	2509	12	20D
0005432620877	2509	13	21B
0005432620884	2509	14	21C
0005432620876	2509	15	22C
0005432620873	2509	16	23A
0005432862211	28088	1	1B
0005432862217	28088	2	3D
0005432862216	28088	3	4B
0005432862212	28088	4	4D
0005432620811	28088	5	5B
0005432620809	28088	6	7A
0005432862210	28088	7	20B
0005432862214	28088	8	20D
0005432862215	28088	9	22C
0005432862213	28088	10	23A
0005432620810	28088	11	23B
0005434097460	13096	1	5B
0005434097459	13096	2	6A
0005434191252	28028	1	4C
0005434191258	28028	2	4F
0005434191254	28028	3	7D
0005434191261	28028	4	7E
0005434191253	28028	5	8D
0005434191259	28028	6	16A
0005434191256	28028	7	17E
0005434191257	28028	8	18A
0005434191260	28028	9	18C
0005434191251	28028	10	19C
0005434191255	28028	11	20E
0005433452715	31076	1	3A
0005433452714	31076	2	4A
0005433454840	31428	1	2A
0005433454839	31428	2	5B
0005433134057	12007	1	21D
0005434142561	29869	1	1A
0005433134087	29869	2	1D
0005433134085	29869	3	4B
0005434142563	29869	4	5B
0005434184641	29869	5	5C
0005433134086	29869	6	5D
0005433131655	29869	7	6C
0005433134088	29869	8	7B
0005433131659	29869	9	18C
0005433131654	29869	10	19A
0005434142564	29869	11	19B
0005434183557	29869	12	19C
0005434183556	29869	13	19D
0005434142562	29869	14	20C
0005433131658	29869	15	21A
0005433131656	29869	16	21D
0005434184642	29869	17	22C
0005433131657	29869	18	22D
0005433134084	29869	19	23B
0005435697008	16468	1	1B
0005435696998	16468	2	1C
0005435696992	16468	3	1D
0005435696991	16468	4	2A
0005435697009	16468	5	2B
0005435696993	16468	6	3A
0005435697005	16468	7	4B
0005435697004	16468	8	4C
0005435697001	16468	9	4D
0005435696989	16468	10	5A
0005435697011	16468	11	5B
0005435935001	16468	12	5D
0005435696999	16468	13	6A
0005435696996	16468	14	6C
0005435697007	16468	15	6D
0005435696995	16468	16	7B
0005435696997	16468	17	7D
0005435696990	16468	18	18C
0005435697013	16468	19	18D
0005435935002	16468	20	19A
0005435697006	16468	21	19B
0005435696988	16468	22	19D
0005435697014	16468	23	20B
0005435696994	16468	24	20C
0005435697000	16468	25	21A
0005435697012	16468	26	21B
0005435696987	16468	27	21C
0005435697010	16468	28	21D
0005435697003	16468	29	22A
0005435696986	16468	30	22B
0005435697002	16468	31	23B
0005435696891	24710	1	1D
0005435935013	24710	2	4A
0005435696909	24710	3	4B
0005435696880	24710	4	5A
0005435696845	24710	5	6C
0005435696872	24710	6	18B
0005435696848	24710	7	19D
0005435696849	24710	8	20B
0005435935012	24710	9	22A
0005433724751	18812	1	2A
0005433724752	18812	2	2B
0005433724748	18812	3	4B
0005433724749	18812	4	5B
0005433724750	18812	5	6A
0005432968815	21601	1	1B
0005432968817	21601	2	3A
0005432968816	21601	3	6A
0005433724739	21601	4	6B
0005434137226	7346	1	1A
0005434137206	7346	2	1C
0005434137219	7346	3	1D
0005434137189	7346	4	1F
0005434137243	7346	5	2A
0005434137265	7346	6	2C
0005434087459	7346	7	2D
0005434137198	7346	8	2F
0005434137181	7346	9	3A
0005434137253	7346	10	3C
0005434137205	7346	11	3D
0005434137215	7346	12	3F
0005434137263	7346	13	4A
0005434137224	7346	14	4C
0005434137194	7346	15	4D
0005434137259	7346	16	4E
0005434137229	7346	17	4F
0005434137177	7346	18	5A
0005434137257	7346	19	5C
0005434137264	7346	20	5D
0005434137185	7346	21	5E
0005434137213	7346	22	5F
0005434137240	7346	23	6A
0005434137218	7346	24	6C
0005434137208	7346	25	6D
0005434137241	7346	26	6E
0005434137212	7346	27	6F
0005434137242	7346	28	7A
0005434137222	7346	29	7C
0005434137236	7346	30	7D
0005434137232	7346	31	7E
0005434137238	7346	32	7F
0005434137200	7346	33	8A
0005434137190	7346	34	8C
0005434137244	7346	35	8D
0005434137220	7346	36	8E
0005434137192	7346	37	8F
0005434137201	7346	38	9A
0005434137247	7346	39	9C
0005434137209	7346	40	9D
0005434137250	7346	41	9E
0005434137196	7346	42	9F
0005434137221	7346	43	10A
0005434137186	7346	44	10C
0005434137210	7346	45	10D
0005434137228	7346	46	10E
0005434137256	7346	47	10F
0005434137262	7346	48	11A
0005434137266	7346	49	11C
0005434137255	7346	50	11D
0005434137251	7346	51	11F
0005434087460	7346	52	12A
0005434137207	7346	53	12D
0005434137178	7346	54	12E
0005434137197	7346	55	12F
0005434137246	7346	56	13A
0005434137203	7346	57	13C
0005434137233	7346	58	13D
0005434087458	7346	59	13E
0005434137230	7346	60	13F
0005434137234	7346	61	14A
0005434137176	7346	62	14C
0005434137258	7346	63	14D
0005434137245	7346	64	14E
0005434137183	7346	65	14F
0005434137249	7346	66	15A
0005434137179	7346	67	15C
0005434137223	7346	68	15D
0005434137239	7346	69	15E
0005434137252	7346	70	15F
0005434137182	7346	71	16A
0005434137235	7346	72	16C
0005434137254	7346	73	16D
0005434137261	7346	74	16E
0005434137227	7346	75	16F
0005434137211	7346	76	17A
0005434137187	7346	77	17C
0005434137180	7346	78	17D
0005434137260	7346	79	17E
0005434137237	7346	80	17F
0005434137267	7346	81	18A
0005434137225	7346	82	18C
0005434137184	7346	83	18D
0005434137199	7346	84	18E
0005434137217	7346	85	18F
0005434137248	7346	86	19A
0005434137193	7346	87	19C
0005434137214	7346	88	19D
0005434137231	7346	89	19F
0005434137191	7346	90	19E
0005434137204	7346	91	20A
0005434137216	7346	92	20C
0005434137202	7346	93	20D
0005434137188	7346	94	20E
0005434137195	7346	95	20F
0005434087430	28572	1	12E
0005434087433	28572	2	20E
0005435808115	1903	1	1A
0005433407480	1903	2	1B
0005435808114	1903	3	1C
0005435808123	1903	4	3D
0005434610188	1903	5	5C
0005435808118	1903	6	6C
0005435808120	1903	7	6D
0005435808117	1903	8	7A
0005435808121	1903	9	7D
0005435808119	1903	10	18B
0005435808122	1903	11	19B
0005435808116	1903	12	19D
0005435808113	1903	13	21A
0005434610189	1903	14	22C
0005434503461	16676	1	3A
0005434503495	16676	2	6D
0005434503462	16676	3	18A
0005434503528	16676	4	22B
0005434503686	22914	1	1B
0005434503684	22914	2	1C
0005434503692	22914	3	2A
0005434503667	22914	4	2B
0005434503665	22914	5	2C
0005434503681	22914	6	2D
0005434503683	22914	7	3A
0005434503690	22914	8	3B
0005434503695	22914	9	3D
0005434503671	22914	10	4A
0005434503662	22914	11	4B
0005434503687	22914	12	4C
0005434503672	22914	13	5A
0005434503694	22914	14	5B
0005434503679	22914	15	5C
0005434503664	22914	16	6A
0005434503668	22914	17	6B
0005434503689	22914	18	6D
0005434503676	22914	19	7A
0005434503663	22914	20	7B
0005434503697	22914	21	7C
0005434503673	22914	22	7D
0005434503691	22914	23	18A
0005434503682	22914	24	18B
0005434503696	22914	25	19A
0005434503660	22914	26	19B
0005434503674	22914	27	19C
0005434503661	22914	28	19D
0005434503678	22914	29	20A
0005434503693	22914	30	20C
0005434503688	22914	31	20D
0005434503666	22914	32	21A
0005434503669	22914	33	21B
0005434503680	22914	34	21C
0005434503675	22914	35	21D
0005434503698	22914	36	22A
0005434503685	22914	37	22C
0005434503670	22914	38	22D
0005434503699	22914	39	23A
0005434503677	22914	40	23B
0005435078167	2186	1	1C
0005435078168	2186	2	2B
0005435078162	2186	3	3A
0005435078173	2186	4	3C
0005435078161	2186	5	3D
0005435078172	2186	6	4D
0005435078166	2186	7	7A
0005435078169	2186	8	7B
0005435078171	2186	9	18B
0005435078163	2186	10	19B
0005435078159	2186	11	20A
0005435078165	2186	12	21A
0005435078160	2186	13	22B
0005435078170	2186	14	22C
0005435078164	2186	15	22D
0005435078174	2186	16	23A
0005435078101	24347	1	1B
0005433266614	24347	2	2B
0005433266619	24347	3	2C
0005433266620	24347	4	3C
0005433266616	24347	5	4A
0005433266623	24347	6	4C
0005433266617	24347	7	5B
0005433266622	24347	8	5C
0005435078108	24347	9	18D
0005433266618	24347	10	19B
0005433266615	24347	11	19C
0005435078106	24347	12	20A
0005433266621	24347	13	21A
0005434988612	6629	1	1A
0005434988620	6629	2	1B
0005434988614	6629	3	2B
0005434988609	6629	4	3A
0005434988610	6629	5	3D
0005434988611	6629	6	4A
0005434988621	6629	7	4B
0005435803230	6629	8	5B
0005435464473	6629	9	5D
0005434988616	6629	10	6D
0005434988615	6629	11	7A
0005435803229	6629	12	7B
0005434988617	6629	13	7D
0005434988613	6629	14	18C
0005434988619	6629	15	18D
0005435464472	6629	16	19A
0005434988618	6629	17	21A
0005434988608	6629	18	21D
0005435803228	6629	19	22B
0005435464484	23612	1	7A
0005435464486	23612	2	18C
0005435464485	23612	3	20B
0005433449726	30466	1	1C
0005433449724	30466	2	1F
0005432382733	30466	3	2A
0005432382753	30466	4	2D
0005433449719	30466	5	3C
0005433449736	30466	6	3D
0005432382764	30466	7	3F
0005433449718	30466	8	4C
0005432382758	30466	9	4A
0005432382763	30466	10	4D
0005432382738	30466	11	4E
0005433453742	30466	12	4F
0005433453741	30466	13	5A
0005433453740	30466	14	5E
0005433449738	30466	15	5F
0005432382750	30466	16	6C
0005433449733	30466	17	6D
0005432382727	30466	18	6E
0005432382730	30466	19	7A
0005433449717	30466	20	7C
0005432382761	30466	21	7E
0005433449723	30466	22	7F
0005432382736	30466	23	8E
0005433454851	30466	24	9C
0005432382749	30466	25	9D
0005432382743	30466	26	9E
0005432382741	30466	27	9F
0005433449731	30466	28	10A
0005432382729	30466	29	10E
0005432382735	30466	30	10F
0005432382766	30466	31	11A
0005433449735	30466	32	11C
0005432382737	30466	33	11F
0005433449737	30466	34	12C
0005433449722	30466	35	12D
0005432382754	30466	36	12E
0005433449725	30466	37	12F
0005433449728	30466	38	13A
0005432382757	30466	39	13E
0005432382752	30466	40	13F
0005432382756	30466	41	14A
0005432382734	30466	42	14C
0005432382745	30466	43	14D
0005432382762	30466	44	14E
0005432382732	30466	45	15A
0005432382739	30466	46	15C
0005432382751	30466	47	15D
0005433449730	30466	48	15F
0005432382742	30466	49	16D
0005433449721	30466	50	16E
0005432382755	30466	51	17A
0005432382765	30466	52	17C
0005433449732	30466	53	17D
0005432382746	30466	54	17F
0005432382760	30466	55	18A
0005432382747	30466	56	18C
0005433449720	30466	57	18D
0005432382728	30466	58	18E
0005432382740	30466	59	18F
0005432382731	30466	60	19D
0005433449727	30466	61	19E
0005433449734	30466	62	19F
0005432382748	30466	63	20A
0005432382744	30466	64	20C
0005433449729	30466	65	20D
0005432382759	30466	66	20F
0005433449602	31308	1	6A
0005433449603	31308	2	6D
0005433449591	31308	3	9E
0005433449649	31308	4	13A
0005433449648	31308	5	14C
0005432382492	31308	6	14D
0005433449664	31308	7	16D
0005432382491	31308	8	18A
0005435548440	26466	1	3C
0005435548446	26466	2	4C
0005435548444	26466	3	7B
0005435548442	26466	4	18B
0005435548447	26466	5	18C
0005435548441	26466	6	19A
0005435548449	26466	7	19B
0005435548448	26466	8	20B
0005435548443	26466	9	20C
0005435548445	26466	10	22B
0005435304098	10796	1	2C
0005435302152	29707	1	1A
0005433126796	29707	2	1B
0005433129227	29707	3	2C
0005435302151	29707	4	3B
0005433126798	29707	5	3D
0005433129231	29707	6	5A
0005435302149	29707	7	5B
0005435299728	29707	8	5C
0005433126797	29707	9	7A
0005433129228	29707	10	7C
0005433126799	29707	11	7D
0005435299726	29707	12	18B
0005433126795	29707	13	18C
0005433129226	29707	14	19A
0005433129229	29707	15	19B
0005435299725	29707	16	19D
0005435302150	29707	17	20B
0005435299727	29707	18	20D
0005433129230	29707	19	21C
0005434287045	2382	1	1A
0005434287034	2382	2	1B
0005434287048	2382	3	1C
0005434287047	2382	4	1D
0005434287044	2382	5	2A
0005434287030	2382	6	2B
0005433109875	2382	7	2D
0005434287040	2382	8	3A
0005432264447	2382	9	3B
0005433109837	2382	10	3C
0005434287035	2382	11	3D
0005434287039	2382	12	4A
0005434287033	2382	13	4C
0005434287036	2382	14	4D
0005433109839	2382	15	5A
0005432264446	2382	16	5B
0005434287037	2382	17	5C
0005434287049	2382	18	5D
0005433109850	2382	19	6B
0005434287029	2382	20	6C
0005434287031	2382	21	6D
0005433109848	2382	22	7A
0005432264450	2382	23	7B
0005434287042	2382	24	7C
0005434287050	2382	25	7D
0005434287041	2382	26	18A
0005432264448	2382	27	18B
0005434287046	2382	28	18C
0005433109874	2382	29	18D
0005434287043	2382	30	19B
0005433109838	2382	31	19C
0005434287038	2382	32	20C
0005433109843	2382	33	21B
0005433109873	2382	34	21C
0005432264449	2382	35	21D
0005433109847	2382	36	22C
0005434287032	2382	37	22D
0005433109851	2382	38	23B
0005433109917	26824	1	2D
0005434286934	26824	2	3C
0005434286933	26824	3	3D
0005433109921	26824	4	4A
0005433109913	26824	5	4B
0005433109916	26824	6	4C
0005434286911	26824	7	5B
0005433109918	26824	8	5C
0005434286912	26824	9	6B
0005433109915	26824	10	7C
0005433109914	26824	11	18D
0005434286910	26824	12	19A
0005434286908	26824	13	19C
0005433109923	26824	14	20B
0005433109922	26824	15	20C
0005434286943	26824	16	21A
0005434286915	26824	17	21B
0005433109920	26824	18	21D
0005433109919	26824	19	22C
0005433109912	26824	20	22D
0005435856159	25468	1	3B
0005435856157	25468	2	6A
0005435856156	25468	3	19A
0005435856155	25468	4	19D
0005435856158	25468	5	20C
0005434520176	6098	1	1A
0005434520166	6098	2	1C
0005434520182	6098	3	1D
0005434520184	6098	4	2A
0005434520153	6098	5	2C
0005434520178	6098	6	2D
0005434520169	6098	7	3A
0005434520183	6098	8	3B
0005434520159	6098	9	3C
0005434520158	6098	10	3D
0005434520156	6098	11	4A
0005434520161	6098	12	4C
0005434520170	6098	13	5A
0005434520175	6098	14	5B
0005434520173	6098	15	5C
0005434520165	6098	16	5D
0005434520179	6098	17	6D
0005434520167	6098	18	7A
0005434520164	6098	19	7B
0005434520160	6098	20	7D
0005434520168	6098	21	18A
0005434520172	6098	22	18B
0005434520174	6098	23	19A
0005434520162	6098	24	19B
0005434520181	6098	25	20B
0005434520163	6098	26	20C
0005434520180	6098	27	20D
0005434520155	6098	28	21A
0005434520154	6098	29	21B
0005434520171	6098	30	22A
0005434520185	6098	31	22C
0005434520157	6098	32	22D
0005434520177	6098	33	23A
0005434520152	6098	34	23B
0005435263511	27629	1	1C
0005435263525	27629	2	2C
0005435263531	27629	3	3A
0005435263524	27629	4	3D
0005435263514	27629	5	3F
0005435263512	27629	6	4E
0005435263517	27629	7	5A
0005435263515	27629	8	5C
0005435263530	27629	9	5E
0005435263519	27629	10	6C
0005433650395	27629	11	6D
0005435263526	27629	12	6E
0005435263528	27629	13	6F
0005435263534	27629	14	7C
0005435263509	27629	15	8D
0005433650366	27629	16	8F
0005435263510	27629	17	9D
0005435263506	27629	18	10A
0005435263505	27629	19	10D
0005435263532	27629	20	10E
0005435263535	27629	21	11E
0005435263523	27629	22	12A
0005435263503	27629	23	12D
0005435263520	27629	24	13C
0005435263518	27629	25	13E
0005435263508	27629	26	14A
0005435263533	27629	27	14F
0005435263516	27629	28	15C
0005435263522	27629	29	15D
0005433650396	27629	30	16F
0005435263507	27629	31	17F
0005435263529	27629	32	18A
0005435263513	27629	33	18C
0005435263504	27629	34	18E
0005435263521	27629	35	19A
0005435263527	27629	36	19D
0005433868006	4759	1	1A
0005433867983	4759	2	1B
0005433867987	4759	3	1D
0005433867999	4759	4	2A
0005433868002	4759	5	2B
0005433868009	4759	6	2C
0005433867980	4759	7	2D
0005433867978	4759	8	3A
0005433868003	4759	9	3B
0005433867996	4759	10	3C
0005433867971	4759	11	3D
0005433867993	4759	12	4A
0005433867992	4759	13	4C
0005433867975	4759	14	4D
0005433867991	4759	15	5A
0005433867979	4759	16	5B
0005433867984	4759	17	5C
0005433868004	4759	18	5D
0005433867976	4759	19	6A
0005433868011	4759	20	6B
0005433868005	4759	21	6C
0005433868001	4759	22	6D
0005433867982	4759	23	7A
0005433867970	4759	24	7C
0005433868008	4759	25	7D
0005433867972	4759	26	18A
0005433867988	4759	27	18B
0005433867985	4759	28	18C
0005433867995	4759	29	18D
0005433867973	4759	30	19C
0005433867977	4759	31	19D
0005433867989	4759	32	20A
0005433867974	4759	33	20B
0005433868010	4759	34	20C
0005433867981	4759	35	20D
0005433867994	4759	36	21A
0005433868007	4759	37	21B
0005433867990	4759	38	21C
0005433867998	4759	39	22B
0005433868000	4759	40	22C
0005433867986	4759	41	23A
0005433867997	4759	42	23B
0005435860449	32582	1	2D
0005433867798	32582	2	4C
0005435860448	32582	3	18A
0005433867819	32582	4	19B
0005434663254	3403	1	1C
0005434663251	3403	2	2D
0005434663249	3403	3	3C
0005434460482	3403	4	4A
0005434663262	3403	5	5B
0005434460480	3403	6	5C
0005434663255	3403	7	5D
0005434461622	3403	8	6A
0005434663260	3403	9	6C
0005434663256	3403	10	7A
0005434663261	3403	11	7B
0005434663257	3403	12	18A
0005434460481	3403	13	18B
0005434663252	3403	14	18C
0005434460483	3403	15	19C
0005434461621	3403	16	19D
0005434663250	3403	17	20A
0005434663253	3403	18	21A
0005434461623	3403	19	22A
0005434663259	3403	20	22B
0005434663258	3403	21	22D
0005435911369	12498	1	3D
0005435911366	12498	2	4A
0005434663180	12498	3	6C
0005435911365	12498	4	6D
0005435911367	12498	5	18C
0005435911364	12498	6	18D
0005434663181	12498	7	19D
0005435911368	12498	8	22C
0005435860449	14486	1	1B
0005433867798	14486	2	3C
0005433867819	14486	3	5C
0005435860448	14486	4	6C
0005433867949	32700	1	1B
0005433867935	32700	2	1C
0005433867940	32700	3	1D
0005433867958	32700	4	2A
0005433867951	32700	5	2B
0005433867942	32700	6	2C
0005433867937	32700	7	2D
0005433867931	32700	8	3A
0005433867952	32700	9	3B
0005433867941	32700	10	3D
0005433867934	32700	11	4A
0005433867950	32700	12	4C
0005433867967	32700	13	4D
0005433867961	32700	14	5B
0005433867944	32700	15	5C
0005433867965	32700	16	6B
0005433867943	32700	17	6C
0005433867964	32700	18	6D
0005433867968	32700	19	7A
0005433867963	32700	20	7B
0005433867938	32700	21	7D
0005433867962	32700	22	18A
0005433867959	32700	23	18B
0005433867969	32700	24	18C
0005433867936	32700	25	18D
0005433867960	32700	26	19C
0005433867966	32700	27	20A
0005433867945	32700	28	20B
0005433867957	32700	29	20C
0005433867948	32700	30	20D
0005433867947	32700	31	21A
0005433867953	32700	32	21B
0005433867932	32700	33	21D
0005433867956	32700	34	22A
0005433867954	32700	35	22B
0005433867955	32700	36	22C
0005433867933	32700	37	22D
0005433867939	32700	38	23A
0005433867946	32700	39	23B
0005432798957	12098	1	3D
0005432799007	12098	2	7A
0005432799008	12098	3	7D
0005432798958	12098	4	19D
0005432799101	14778	1	1A
0005432799122	14778	2	1B
0005432799107	14778	3	1C
0005432799113	14778	4	1D
0005432799102	14778	5	2D
0005432799111	14778	6	3C
0005432799104	14778	7	4A
0005432799124	14778	8	4C
0005432799098	14778	9	5A
0005432799106	14778	10	5C
0005432799116	14778	11	6B
0005432799100	14778	12	6C
0005432799099	14778	13	7B
0005432799108	14778	14	7C
0005432799125	14778	15	7D
0005432799105	14778	16	18A
0005432799103	14778	17	18B
0005432799114	14778	18	18C
0005432799115	14778	19	18D
0005432799118	14778	20	19A
0005432799121	14778	21	19B
0005432799123	14778	22	19C
0005432799110	14778	23	19D
0005432799109	14778	24	20B
0005432799120	14778	25	20D
0005432799112	14778	26	21A
0005432799117	14778	27	22B
0005432799119	14778	28	22C
0005434407048	7029	1	1A
0005434407059	7029	2	1C
0005434407033	7029	3	1F
0005434299298	7029	4	1D
0005434407027	7029	5	2C
0005434407060	7029	6	2A
0005434299313	7029	7	3C
0005434299305	7029	8	3D
0005434407032	7029	9	4A
0005434407053	7029	10	4D
0005432153856	7029	11	4C
0005432153863	7029	12	4E
0005434407042	7029	13	4F
0005434299308	7029	14	5B
0005434407025	7029	15	5A
0005434407086	7029	16	5C
0005432153859	7029	17	5E
0005432108222	7029	18	6A
0005434407073	7029	19	5F
0005434299295	7029	20	6B
0005434407077	7029	21	6C
0005432153860	7029	22	6D
0005434407028	7029	23	6E
0005434299311	7029	24	7A
0005434407026	7029	25	6F
0005434299314	7029	26	7B
0005435293054	7029	27	7D
0005434407074	7029	28	7C
0005434407036	7029	29	7F
0005434407041	7029	30	8A
0005434407057	7029	31	8B
0005434407072	7029	32	8C
0005434407069	7029	33	8E
0005434299301	7029	34	8D
0005434299289	7029	35	9A
0005435293055	7029	36	8F
0005432153862	7029	37	9B
0005434407040	7029	38	9D
0005434407081	7029	39	9E
0005434407070	7029	40	10B
0005434407068	7029	41	10D
0005434407037	7029	42	10E
0005434407052	7029	43	11C
0005434407031	7029	44	11B
0005434407063	7029	45	11E
0005434299299	7029	46	11F
0005434299312	7029	47	12C
0005434299310	7029	48	12B
0005434299309	7029	49	12D
0005434299290	7029	50	12E
0005434299291	7029	51	12F
0005434407035	7029	52	13A
0005434299297	7029	53	13C
0005435293050	7029	54	13B
0005434407084	7029	55	13E
0005434299302	7029	56	13F
0005434407024	7029	57	14B
0005434407062	7029	58	14A
0005434407051	7029	59	14C
0005434407030	7029	60	14D
0005434407034	7029	61	14E
0005434407044	7029	62	15A
0005434299303	7029	63	14F
0005434407078	7029	64	15B
0005434407050	7029	65	15D
0005434299294	7029	66	15F
0005434299304	7029	67	15E
0005434407065	7029	68	16A
0005435293049	7029	69	16C
0005432108221	7029	70	16B
0005434299300	7029	71	16E
0005434299296	7029	72	16D
0005434407075	7029	73	16F
0005434407067	7029	74	17B
0005434407079	7029	75	17C
0005434407056	7029	76	17D
0005434407082	7029	77	17E
0005434407066	7029	78	18A
0005434407029	7029	79	17F
0005434407038	7029	80	18B
0005434299292	7029	81	18F
0005434407058	7029	82	19A
0005434299306	7029	83	19B
0005434407043	7029	84	19C
0005434407047	7029	85	19D
0005434407046	7029	86	19F
0005432108220	7029	87	19E
0005432153861	7029	88	20A
0005434407085	7029	89	20C
0005434407049	7029	90	20D
0005434407071	7029	91	20E
0005435293056	7029	92	21B
0005434407087	7029	93	21C
0005434299307	7029	94	21D
0005434407083	7029	95	21E
0005434407080	7029	96	21F
0005434407061	7029	97	22B
0005434407054	7029	98	22A
0005432153858	7029	99	22E
0005434407045	7029	100	22D
0005434407076	7029	101	23A
0005432153857	7029	102	22F
0005435293063	7029	103	23B
0005434407039	7029	104	23D
0005434407064	7029	105	23C
0005434407055	7029	106	23E
0005434299293	7029	107	23F
0005432058334	26927	1	2D
0005432058336	26927	2	2C
0005434299170	26927	3	3D
0005434299171	26927	4	4E
0005434299148	26927	5	5D
0005434299173	26927	6	6E
0005434299163	26927	7	6F
0005434299157	26927	8	11D
0005434299167	26927	9	14E
0005432058333	26927	10	17C
0005434299164	26927	11	17D
0005434299182	26927	12	19E
0005432058332	26927	13	20C
0005434299258	26927	14	20E
0005434299187	26927	15	20F
0005432058335	26927	16	22F
0005432603888	6433	1	1A
0005432603900	6433	2	1B
0005432603886	6433	3	1C
0005432603905	6433	4	1D
0005432603907	6433	5	2A
0005434512057	6433	6	2B
0005432603891	6433	7	2C
0005432603890	6433	8	2D
0005434512056	6433	9	3A
0005434512053	6433	10	3B
0005432603889	6433	11	3C
0005434512058	6433	12	3D
0005432603908	6433	13	4A
0005434512055	6433	14	4B
0005432603904	6433	15	4C
0005432603916	6433	16	4D
0005432603917	6433	17	5A
0005432603924	6433	18	5B
0005434512054	6433	19	5C
0005432603885	6433	20	5D
0005432603895	6433	21	6A
0005432603892	6433	22	6B
0005432603925	6433	23	6C
0005432603922	6433	24	6D
0005432603913	6433	25	7A
0005434512052	6433	26	7B
0005432603914	6433	27	7C
0005432603906	6433	28	7D
0005432603894	6433	29	18A
0005432603899	6433	30	18C
0005432603910	6433	31	18D
0005432603923	6433	32	19A
0005432603898	6433	33	19B
0005432603919	6433	34	19C
0005432603911	6433	35	19D
0005432603915	6433	36	20A
0005432603909	6433	37	20B
0005432603901	6433	38	20C
0005432603903	6433	39	20D
0005432603912	6433	40	21A
0005432603887	6433	41	21B
0005432603918	6433	42	21C
0005432603897	6433	43	21D
0005432603896	6433	44	22A
0005432603902	6433	45	22B
0005434512059	6433	46	22C
0005432603893	6433	47	22D
0005432603921	6433	48	23B
0005432603920	6433	49	23A
0005434512026	21364	1	1C
0005432603715	21364	2	2A
0005434512015	21364	3	3A
0005435221045	21364	4	4A
0005432603668	21364	5	4B
0005434512024	21364	6	6A
0005434512016	21364	7	6D
0005435221505	21364	8	18C
0005435221044	21364	9	18D
0005435221504	21364	10	22C
0005434512025	21364	11	22D
0005433251124	14989	1	3A
0005433251138	14989	2	3C
0005433251119	14989	3	4D
0005433251130	14989	4	4F
0005433251146	14989	5	5C
0005433251143	14989	6	5D
0005433251125	14989	7	5E
0005433251134	14989	8	5F
0005433251132	14989	9	8A
0005433251147	14989	10	8C
0005433251123	14989	11	8D
0005433251136	14989	12	8F
0005433251120	14989	13	9A
0005433251139	14989	14	9C
0005433251144	14989	15	10A
0005433251127	14989	16	10E
0005433251121	14989	17	11F
0005433251142	14989	18	12D
0005433251137	14989	19	12F
0005433251145	14989	20	13D
0005433251133	14989	21	14C
0005433251129	14989	22	14D
0005433251148	14989	23	15C
0005433251128	14989	24	15E
0005433251126	14989	25	17A
0005433251118	14989	26	18A
0005433251140	14989	27	18E
0005433251131	14989	28	19C
0005433251135	14989	29	19D
0005433251122	14989	30	20D
0005433251141	14989	31	20E
0005434906642	25841	1	1C
0005433250934	25841	2	1D
0005434906686	25841	3	1F
0005434906670	25841	4	2A
0005434906692	25841	5	2F
0005434906641	25841	6	3A
0005434906664	25841	7	3C
0005434906691	25841	8	3D
0005434906678	25841	9	3F
0005434906676	25841	10	4A
0005434906683	25841	11	4D
0005434906663	25841	12	4E
0005434906648	25841	13	4F
0005434906668	25841	14	5A
0005433250942	25841	15	5C
0005434906667	25841	16	5E
0005434906655	25841	17	5F
0005434906681	25841	18	6C
0005434906688	25841	19	6D
0005434906671	25841	20	6E
0005434906643	25841	21	7A
0005434906674	25841	22	7C
0005434906677	25841	23	7E
0005434906687	25841	24	7F
0005434906673	25841	25	8C
0005434906666	25841	26	8E
0005434906654	25841	27	8F
0005434906682	25841	28	9A
0005434906637	25841	29	9C
0005434906638	25841	30	9D
0005434906636	25841	31	9E
0005434906650	25841	32	10A
0005434906679	25841	33	10C
0005434906649	25841	34	10D
0005434906661	25841	35	10F
0005434906672	25841	36	11A
0005434906680	25841	37	11D
0005434906684	25841	38	11C
0005433250951	25841	39	12A
0005434906656	25841	40	12E
0005434906658	25841	41	12F
0005434906669	25841	42	13A
0005434906675	25841	43	13C
0005434906657	25841	44	13F
0005434906652	25841	45	14A
0005434906639	25841	46	14C
0005433250937	25841	47	14F
0005434906689	25841	48	15C
0005434906690	25841	49	15E
0005434906645	25841	50	15F
0005434906653	25841	51	16A
0005434906646	25841	52	16E
0005433250966	25841	53	17A
0005434906660	25841	54	17C
0005434906662	25841	55	17D
0005434906685	25841	56	17E
0005434906640	25841	57	17F
0005434906651	25841	58	18A
0005434906647	25841	59	18D
0005434906635	25841	60	18E
0005434906634	25841	61	19A
0005433250933	25841	62	19C
0005434906659	25841	63	19F
0005434906644	25841	64	20A
0005434906665	25841	65	20E
0005433008143	14185	1	1A
0005433008105	14185	2	1D
0005433008111	14185	3	1F
0005433008112	14185	4	2A
0005433008115	14185	5	2C
0005433008116	14185	6	2D
0005433008118	14185	7	4A
0005433008144	14185	8	4C
0005433008104	14185	9	5A
0005433008102	14185	10	5C
0005433008128	14185	11	6D
0005433008136	14185	12	7A
0005433008114	14185	13	7D
0005433008133	14185	14	7E
0005433008108	14185	15	7F
0005433008101	14185	16	8D
0005433008140	14185	17	9A
0005433008106	14185	18	10D
0005433008141	14185	19	10F
0005433008129	14185	20	11A
0005433008120	14185	21	11C
0005433008119	14185	22	11D
0005433008117	14185	23	11E
0005433008134	14185	24	12C
0005433008146	14185	25	12E
0005433008137	14185	26	13A
0005433008135	14185	27	13E
0005433008107	14185	28	13F
0005433008132	14185	29	14E
0005433008100	14185	30	15C
0005433008121	14185	31	15D
0005433008124	14185	32	15E
0005433008126	14185	33	16A
0005433008130	14185	34	16C
0005433008138	14185	35	16D
0005433008142	14185	36	17A
0005433008103	14185	37	17D
0005433008139	14185	38	17F
0005433008113	14185	39	18A
0005433008123	14185	40	18C
0005433008122	14185	41	18E
0005433008110	14185	42	19C
0005433008145	14185	43	20A
0005433008125	14185	44	19F
0005433008127	14185	45	20C
0005433008109	14185	46	20D
0005433008131	14185	47	20E
0005433007840	22819	1	2C
0005433007842	22819	2	4A
0005433007909	22819	3	5D
0005433810506	22819	4	6D
0005433007851	22819	5	8F
0005433810507	22819	6	12F
0005433007885	22819	7	20D
0005433007857	22819	8	20F
0005434925397	20510	1	1C
0005434925430	20510	2	1D
0005434925401	20510	3	1F
0005434925416	20510	4	2A
0005434925414	20510	5	2C
0005434925405	20510	6	2F
0005434925399	20510	7	3D
0005434925412	20510	8	3F
0005434925423	20510	9	4C
0005434925402	20510	10	5A
0005434925427	20510	11	5C
0005434925429	20510	12	5D
0005434925417	20510	13	5F
0005434925409	20510	14	7D
0005434925432	20510	15	8A
0005434925413	20510	16	8F
0005434925420	20510	17	9A
0005434925424	20510	18	9C
0005434925406	20510	19	9D
0005434925403	20510	20	10A
0005434925400	20510	21	10D
0005434925398	20510	22	11C
0005434925419	20510	23	11D
0005434925411	20510	24	12D
0005434925422	20510	25	12E
0005434925410	20510	26	12F
0005434925428	20510	27	14A
0005434925415	20510	28	15D
0005434925431	20510	29	15E
0005434925418	20510	30	16C
0005434925408	20510	31	16D
0005434925421	20510	32	16F
0005434925425	20510	33	17E
0005434925407	20510	34	18A
0005434925404	20510	35	19E
0005434925426	20510	36	20E
0005435487595	15806	1	1D
0005435487593	15806	2	2C
0005435487600	15806	3	3A
0005435487589	15806	4	3D
0005435487597	15806	5	4A
0005435487602	15806	6	4C
0005435487596	15806	7	5A
0005435487599	15806	8	5B
0005435487603	15806	9	5C
0005435487607	15806	10	6B
0005435487591	15806	11	7C
0005435487606	15806	12	7D
0005435487594	15806	13	18A
0005435487588	15806	14	18B
0005435487601	15806	15	19C
0005435487586	15806	16	19D
0005435487605	15806	17	21A
0005435487590	15806	18	21B
0005435487598	15806	19	21C
0005435487604	15806	20	21D
0005435487608	15806	21	22B
0005435487587	15806	22	23A
0005435487592	15806	23	23B
0005435999041	19696	1	1D
0005435999035	19696	2	2A
0005435999044	19696	3	2B
0005435999037	19696	4	3A
0005435999043	19696	5	4A
0005435999045	19696	6	7A
0005435999039	19696	7	18A
0005435999042	19696	8	19A
0005435999036	19696	9	20D
0005435999038	19696	10	21C
0005435999040	19696	11	21D
0005435999046	19696	12	23B
0005432658570	6004	1	1C
0005435839136	6004	2	1D
0005435839145	6004	3	2C
0005432658568	6004	4	3A
0005435839154	6004	5	3D
0005432142219	6004	6	4D
0005435839139	6004	7	5C
0005432658569	6004	8	5A
0005435839132	6004	9	6C
0005435839148	6004	10	7C
0005435839138	6004	11	7D
0005435839147	6004	12	8A
0005435839158	6004	13	8C
0005435839141	6004	14	9B
0005435839150	6004	15	10A
0005432142218	6004	16	10D
0005435839134	6004	17	11E
0005435839144	6004	18	13B
0005435839142	6004	19	13D
0005435839140	6004	20	13F
0005432660796	6004	21	14B
0005435839151	6004	22	14F
0005435839152	6004	23	15C
0005435839156	6004	24	15D
0005432658571	6004	25	16A
0005432659685	6004	26	16D
0005435839143	6004	27	16E
0005432660795	6004	28	17B
0005435839131	6004	29	17D
0005435839157	6004	30	17F
0005435839146	6004	31	18A
0005435839153	6004	32	18F
0005432659684	6004	33	19C
0005432142217	6004	34	20B
0005435839135	6004	35	20C
0005435839149	6004	36	21B
0005435839155	6004	37	21A
0005435839137	6004	38	21D
0005432142216	6004	39	21F
0005435839133	6004	40	21E
0005435472625	18053	1	1A
0005435838965	18053	2	2C
0005435472614	18053	3	3F
0005435472621	18053	4	5A
0005435472624	18053	5	6A
0005435839026	18053	6	6D
0005435472626	18053	7	7E
0005435839025	18053	8	8B
0005435472615	18053	9	9B
0005435838980	18053	10	9F
0005435472629	18053	11	10D
0005435472613	18053	12	12A
0005435472628	18053	13	12D
0005435838960	18053	14	13E
0005435838994	18053	15	14C
0005435472616	18053	16	16A
0005435472620	18053	17	17A
0005435472627	18053	18	17E
0005435472623	18053	19	18B
0005435838959	18053	20	18D
0005435472619	18053	21	19C
0005435472622	18053	22	20C
0005435472617	18053	23	21A
0005435472618	18053	24	21E
0005435838979	18053	25	21D
0005435839027	18053	26	21F
0005433284824	23013	1	2F
0005435103848	23013	2	4B
0005435103842	23013	3	4C
0005433284805	23013	4	5F
0005435103847	23013	5	6D
0005435103846	23013	6	9C
0005435103839	23013	7	11C
0005435103845	23013	8	12D
0005433284782	23013	9	15E
0005435103849	23013	10	16B
0005435103844	23013	11	17D
0005435103840	23013	12	17C
0005435103843	23013	13	18D
0005435103838	23013	14	19D
0005435103841	23013	15	20B
0005433284783	23013	16	21A
0005433284823	23013	17	21D
0005433284967	32093	1	1C
0005433284961	32093	2	4A
0005433284959	32093	3	7A
0005433284957	32093	4	8B
0005433284956	32093	5	8E
0005433284972	32093	6	9B
0005433284962	32093	7	9C
0005433284949	32093	8	9E
0005433284951	32093	9	10B
0005433284952	32093	10	11A
0005433284953	32093	11	12A
0005433284964	32093	12	12B
0005433284963	32093	13	12F
0005433284974	32093	14	13A
0005433284948	32093	15	13B
0005433284968	32093	16	13C
0005433284971	32093	17	13E
0005433284947	32093	18	16A
0005433284950	32093	19	16E
0005433284973	32093	20	17B
0005433284944	32093	21	17D
0005433284954	32093	22	17C
0005433284966	32093	23	18A
0005433284970	32093	24	18F
0005433284960	32093	25	19E
0005433284943	32093	26	20E
0005433284958	32093	27	22A
0005433284965	32093	28	22D
0005433284955	32093	29	23A
0005433284945	32093	30	23B
0005433284946	32093	31	23C
0005433284969	32093	32	23F
0005435212852	30602	1	1A
0005434066306	30602	2	1H
0005435212840	30602	3	1G
0005432525871	30602	4	1K
0005435212875	30602	5	2D
0005435212849	30602	6	2A
0005435212829	30602	7	2H
0005435212816	30602	8	3C
0005432525718	30602	9	3K
0005432211420	30602	10	3G
0005435212874	30602	11	4C
0005432526554	30602	12	4A
0005435630937	30602	13	4G
0005435212825	30602	14	4D
0005434066327	30602	15	4H
0005434066440	30602	16	5D
0005432525744	30602	17	11A
0005432525674	30602	18	11D
0005435212838	30602	19	11C
0005435725552	30602	20	11G
0005432159811	30602	21	12F
0005435212860	30602	22	12E
0005435212877	30602	23	12D
0005432526555	30602	24	12K
0005434066433	30602	25	13D
0005435212845	30602	26	13F
0005432525669	30602	27	13E
0005435212867	30602	28	13H
0005435212841	30602	29	14E
0005434066441	30602	30	14D
0005432535748	30602	31	14H
0005432525653	30602	32	15C
0005432525743	30602	33	15F
0005435212882	30602	34	15K
0005435725551	30602	35	16C
0005435212859	30602	36	16A
0005432159810	30602	37	16F
0005432535747	30602	38	16H
0005435212820	30602	39	17E
0005434066299	30602	40	17C
0005435630936	30602	41	17K
0005432525972	30602	42	17H
0005435212837	30602	43	18C
0005434066348	30602	44	18B
0005435212844	30602	45	18E
0005435212856	30602	46	18F
0005432526022	30602	47	18H
0005435212868	30602	48	19A
0005435212879	30602	49	19C
0005435212826	30602	50	19F
0005432526026	30602	51	19E
0005435212876	30602	52	19G
0005432525707	30602	53	20C
0005433656635	30602	54	20E
0005432525673	30602	55	20K
0005435630935	30602	56	21D
0005435212847	30602	57	21H
0005435212850	30602	58	21K
0005435212862	30602	59	22B
0005435212861	30602	60	22F
0005432428870	30602	61	22E
0005435725549	30602	62	23J
0005434066311	30602	63	23K
0005435212858	30602	64	24E
0005435212855	30602	65	25H
0005432211421	30602	66	26C
0005435725547	30602	67	26D
0005432211419	30602	68	27C
0005435212823	30602	69	28A
0005435212842	30602	70	28D
0005435725548	30602	71	28H
0005432526109	30602	72	28G
0005432525859	30602	73	29B
0005432525963	30602	74	29G
0005432211423	30602	75	29J
0005435212846	30602	76	29K
0005435212827	30602	77	30C
0005432525702	30602	78	30E
0005435212848	30602	79	30D
0005432525962	30602	80	30G
0005432525831	30602	81	31B
0005434066298	30602	82	30K
0005432525820	30602	83	31F
0005432525640	30602	84	31G
0005435212871	30602	85	31J
0005435212824	30602	86	32G
0005435212835	30602	87	32J
0005435212822	30602	88	32H
0005435212854	30602	89	33F
0005435212869	30602	90	33E
0005435212818	30602	91	33K
0005433656637	30602	92	33J
0005435212853	30602	93	34D
0005435212819	30602	94	34F
0005432211425	30602	95	34J
0005435212832	30602	96	35F
0005435725550	30602	97	36A
0005435212828	30602	98	35K
0005435212821	30602	99	37C
0005434066434	30602	100	37F
0005435212814	30602	101	37E
0005434066422	30602	102	37G
0005435212873	30602	103	37K
0005432525677	30602	104	38B
0005434066328	30602	105	38J
0005432525840	30602	106	38K
0005435212878	30602	107	39C
0005435212836	30602	108	39B
0005432211422	30602	109	39D
0005434066313	30602	110	39H
0005435212881	30602	111	39G
0005435212851	30602	112	40A
0005435212839	30602	113	39K
0005432525670	30602	114	40C
0005432526021	30602	115	40B
0005435212872	30602	116	40J
0005432525706	30602	117	40H
0005432525701	30602	118	41A
0005434066394	30602	119	41C
0005435212831	30602	120	41G
0005433656636	30602	121	42A
0005435212870	30602	122	41K
0005432211426	30602	123	42B
0005435212883	30602	124	42D
0005435212864	30602	125	42G
0005435212833	30602	126	42J
0005435212830	30602	127	42H
0005435212815	30602	128	43B
0005432525652	30602	129	43A
0005435212817	30602	130	43F
0005435212857	30602	131	43J
0005434066442	30602	132	43H
0005432525675	30602	133	44J
0005432525832	30602	134	44K
0005435212866	30602	135	45C
0005435212865	30602	136	46B
0005435212863	30602	137	46E
0005435212880	30602	138	46C
0005434066297	30602	139	46J
0005434066300	30602	140	46H
0005432525659	30602	141	46K
0005432159809	30602	142	47G
0005432525655	30602	143	48E
0005432525860	30602	144	48G
0005432525858	30602	145	49A
0005432525798	30602	146	49G
0005432159807	30602	147	49F
0005435212834	30602	148	49K
0005435212843	30602	149	49H
0005432525753	30602	150	50C
0005432428871	30602	151	50A
0005432211424	30602	152	50G
0005432525742	30602	153	50F
0005432525654	30602	154	50H
0005432159808	30602	155	51F
0005432525872	30602	156	51G
0005433367520	24835	1	1A
0005433367501	24835	2	1C
0005433367510	24835	3	1F
0005433367500	24835	4	2C
0005433367512	24835	5	2F
0005433367487	24835	6	3A
0005433367518	24835	7	3D
0005433367499	24835	8	3F
0005433367517	24835	9	4A
0005433367524	24835	10	4C
0005433367490	24835	11	5A
0005433367502	24835	12	5E
0005433367513	24835	13	5F
0005433367515	24835	14	6C
0005433367492	24835	15	6D
0005433367508	24835	16	7C
0005433367489	24835	17	8A
0005433367506	24835	18	8C
0005433367511	24835	19	9D
0005433367509	24835	20	10C
0005433367516	24835	21	10D
0005433367521	24835	22	10F
0005433367523	24835	23	11E
0005433367491	24835	24	11F
0005433367503	24835	25	12D
0005433367493	24835	26	13A
0005433367496	24835	27	14D
0005433367488	24835	28	15E
0005433367514	24835	29	15F
0005433367522	24835	30	16C
0005433367494	24835	31	17A
0005433367507	24835	32	17C
0005433367519	24835	33	18A
0005433367505	24835	34	18F
0005433367504	24835	35	19C
0005433367498	24835	36	19D
0005433367495	24835	37	19F
0005433367497	24835	38	20D
0005435801665	2062	1	1A
0005434979483	2062	2	1B
0005434979497	2062	3	1C
0005435801666	2062	4	2A
0005434979485	2062	5	2B
0005434979476	2062	6	2C
0005434979482	2062	7	3A
0005434979495	2062	8	3B
0005434979486	2062	9	3D
0005434979467	2062	10	4B
0005434979493	2062	11	4C
0005434979488	2062	12	4D
0005434979494	2062	13	5D
0005434979487	2062	14	6A
0005434979492	2062	15	6B
0005434979496	2062	16	6D
0005434979471	2062	17	7A
0005434979469	2062	18	7C
0005434979468	2062	19	7B
0005434979481	2062	20	7D
0005434979470	2062	21	18A
0005434979489	2062	22	18B
0005434979484	2062	23	18C
0005434979490	2062	24	19A
0005434979479	2062	25	19B
0005434979478	2062	26	20B
0005434979472	2062	27	21B
0005435801664	2062	28	21C
0005434979475	2062	29	21D
0005434979480	2062	30	22A
0005434979491	2062	31	22B
0005434979474	2062	32	22C
0005434979473	2062	33	22D
0005434979477	2062	34	23A
0005435801655	23534	1	1A
0005435801642	23534	2	6A
0005434952493	2656	1	1B
0005434952492	2656	2	2B
0005434952494	2656	3	3B
0005433256383	2655	1	1A
0005433256381	2655	2	2B
0005433256384	2655	3	4A
0005433256382	2655	4	4B
0005433256399	28241	1	1B
0005433256400	28241	2	3B
0005433111484	19814	1	4B
0005433111483	19814	2	5B
0005434136717	11967	1	1A
0005434136832	11967	2	1C
0005434136849	11967	3	2A
0005434136686	11967	4	2D
0005434136760	11967	5	3A
0005434136726	11967	6	4D
0005434136920	11967	7	4F
0005434136733	11967	8	5D
0005434136677	11967	9	5E
0005434136687	11967	10	7A
0005434136848	11967	11	8C
0005434136753	11967	12	9C
0005434136688	11967	13	9D
0005434136831	11967	14	10F
0005434136678	11967	15	11E
0005434136748	11967	16	12C
0005434136806	11967	17	12D
0005434136718	11967	18	16F
0005434136761	11967	19	17E
0005434136699	11967	20	18D
0005434137246	28721	1	1A
0005434137260	28721	2	1C
0005434137194	28721	3	1D
0005434137200	28721	4	1F
0005434137212	28721	5	2A
0005434137258	28721	6	2C
0005434137205	28721	7	2D
0005434137192	28721	8	2F
0005434137204	28721	9	3A
0005434137176	28721	10	3C
0005434137221	28721	11	3F
0005434137206	28721	12	4A
0005434137230	28721	13	4C
0005434137190	28721	14	4D
0005434137232	28721	15	4E
0005434137180	28721	16	4F
0005434137257	28721	17	5A
0005434137181	28721	18	5C
0005434137199	28721	19	5D
0005434137202	28721	20	5F
0005434137256	28721	21	6A
0005434137191	28721	22	6C
0005434137201	28721	23	6D
0005434137193	28721	24	6E
0005434137255	28721	25	6F
0005434137217	28721	26	7A
0005434137242	28721	27	7C
0005434137207	28721	28	7D
0005434137265	28721	29	7E
0005434137238	28721	30	7F
0005434137247	28721	31	8A
0005434137209	28721	32	8C
0005434137244	28721	33	8D
0005434137220	28721	34	8E
0005434137196	28721	35	8F
0005434137245	28721	36	9A
0005434137252	28721	37	9C
0005434137241	28721	38	9D
0005434137235	28721	39	9F
0005434137197	28721	40	10A
0005434137248	28721	41	10C
0005434137231	28721	42	10D
0005434137223	28721	43	10E
0005434137182	28721	44	10F
0005434137198	28721	45	11A
0005434137253	28721	46	11C
0005434137188	28721	47	11D
0005434137184	28721	48	11E
0005434137213	28721	49	11F
0005434137186	28721	50	12A
0005434137226	28721	51	12C
0005434137237	28721	52	12D
0005434137261	28721	53	12E
0005434137224	28721	54	12F
0005434137189	28721	55	13A
0005434137195	28721	56	13C
0005434137236	28721	57	13D
0005434137228	28721	58	13E
0005434137177	28721	59	13F
0005434137208	28721	60	14A
0005434137216	28721	61	14C
0005434137179	28721	62	14D
0005434137183	28721	63	14E
0005434137262	28721	64	14F
0005434137254	28721	65	15A
0005434137267	28721	66	15C
0005434137185	28721	67	15D
0005434137218	28721	68	15E
0005434137251	28721	69	15F
0005434137263	28721	70	16A
0005434137250	28721	71	16C
0005434137178	28721	72	16E
0005434137219	28721	73	16F
0005434137211	28721	74	17C
0005434137239	28721	75	17D
0005434137243	28721	76	17E
0005434137229	28721	77	17F
0005434137249	28721	78	18A
0005434137187	28721	79	18C
0005434137214	28721	80	18D
0005434137210	28721	81	18E
0005434137227	28721	82	18F
0005434137233	28721	83	19A
0005434137215	28721	84	19C
0005434137203	28721	85	19D
0005434137222	28721	86	19E
0005434137264	28721	87	19F
0005434137225	28721	88	20A
0005434137259	28721	89	20C
0005434137240	28721	90	20D
0005434137266	28721	91	20E
0005434137234	28721	92	20F
0005434513534	19101	1	1D
0005434513535	19101	2	2B
0005434190379	19101	3	4B
0005434190380	19101	4	6B
0005434190384	19101	5	6C
0005434190383	19101	6	7A
0005434190381	19101	7	18A
0005434513533	19101	8	18D
0005434190382	19101	9	19C
0005434513536	19101	10	20A
0005433534476	6769	1	1A
0005435259687	6769	2	1C
0005433538785	6769	3	1D
0005433538783	6769	4	2B
0005433538778	6769	5	6A
0005433538782	6769	6	7C
0005433538780	6769	7	18B
0005433534475	6769	8	18D
0005433538781	6769	9	19C
0005433538779	6769	10	19D
0005433538784	6769	11	21B
0005433534477	6769	12	21C
0005435259686	6769	13	22A
0005435259685	6769	14	23B
0005433534461	25003	1	1A
0005433538728	25003	2	2B
0005433538726	25003	3	2D
0005433538732	25003	4	3B
0005433538727	25003	5	3D
0005433538724	25003	6	6B
0005433538733	25003	7	6C
0005433538725	25003	8	7D
0005435259710	25003	9	18C
0005433534463	25003	10	20B
0005435259712	25003	11	21A
0005435259711	25003	12	21D
0005433534462	25003	13	22A
0005435259713	25003	14	23A
0005435259709	25003	15	23B
0005433511863	828	1	1A
0005433511861	828	2	1C
0005433511866	828	3	2D
0005433511862	828	4	4B
0005433511867	828	5	5C
0005433511869	828	6	6B
0005433511865	828	7	18A
0005433511868	828	8	19A
0005433511864	828	9	20D
0005432922455	828	10	21C
0005433511834	16168	1	1A
0005433511835	16168	2	2B
0005433511805	16168	3	3D
0005432922485	16168	4	4B
0005433511806	16168	5	4C
0005432922481	16168	6	6C
0005432922484	16168	7	6D
0005432922482	16168	8	7A
0005432922483	16168	9	19A
0005433511817	16168	10	20C
0005433511807	16168	11	22A
0005435852526	4024	1	1A
0005433475664	4024	2	1C
0005433475662	4024	3	3B
0005433475658	4024	4	3C
0005433475657	4024	5	6B
0005433475663	4024	6	7C
0005433475661	4024	7	18B
0005435852533	4024	8	19A
0005433475665	4024	9	19C
0005435852532	4024	10	20A
0005433475660	4024	11	20C
0005433475659	4024	12	22B
0005435697057	3704	1	1B
0005435697068	3704	2	1D
0005435697051	3704	3	2B
0005435697065	3704	4	2C
0005435697056	3704	5	2D
0005435697048	3704	6	3A
0005435697062	3704	7	3C
0005435697061	3704	8	3D
0005435697046	3704	9	4A
0005435697064	3704	10	4C
0005435697049	3704	11	4D
0005435697054	3704	12	5A
0005435697045	3704	13	5B
0005435697066	3704	14	5C
0005435697063	3704	15	6A
0005435697050	3704	16	6B
0005435697055	3704	17	6C
0005434950484	3704	18	6D
0005435697067	3704	19	7B
0005435697044	3704	20	7C
0005434950483	3704	21	7D
0005435697069	3704	22	18A
0005435697058	3704	23	18B
0005435697060	3704	24	18C
0005435697053	3704	25	18D
0005435697047	3704	26	19B
0005435697071	3704	27	19D
0005434950482	3704	28	20A
0005435697059	3704	29	20C
0005434950481	3704	30	21A
0005434950485	3704	31	22A
0005435697070	3704	32	22C
0005435697052	3704	33	23A
0005435697072	3704	34	22D
0005435696891	16283	1	2C
0005435916140	16283	2	2D
0005435696909	16283	3	3B
0005435696849	16283	4	3D
0005435696872	16283	5	4C
0005434950470	16283	6	5B
0005435935013	16283	7	6D
0005435696848	16283	8	7B
0005435696845	16283	9	7C
0005434950453	16283	10	7D
0005434950454	16283	11	19A
0005435935012	16283	12	20C
0005435916139	16283	13	20D
0005435696880	16283	14	21B
0005435916138	16283	15	22D
0005434604864	3982	1	1A
0005432607523	3982	2	1D
0005433519410	3982	3	1C
0005432607525	3982	4	2A
0005434606793	3982	5	2B
0005433519411	3982	6	3A
0005432609689	3982	7	3B
0005432607524	3982	8	4B
0005434606790	3982	9	4D
0005432607527	3982	10	5A
0005432607526	3982	11	5C
0005433519412	3982	12	6A
0005434604863	3982	13	6B
0005434606792	3982	14	6D
0005432609690	3982	15	7A
0005434606791	3982	16	7C
0005433519409	3982	17	18D
0005433519413	3982	18	19B
0005434606789	3982	19	20A
0005432609691	3982	20	20D
0005435853591	22033	1	1A
0005435853593	22033	2	5D
0005435853592	22033	3	6D
0005433519379	22033	4	22C
0005435628692	754	1	2A
0005433348888	754	2	2B
0005435628695	754	3	4A
0005433348902	754	4	5A
0005433348887	754	5	4B
0005435628694	754	6	5B
0005435628693	754	7	6B
0005433348929	15948	1	1A
0005435628674	15948	2	1B
0005433348930	15948	3	2B
0005433348931	15948	4	3A
0005433348928	15948	5	4A
0005433348932	15948	6	5A
0005433348933	15948	7	5B
0005434445221	17252	1	1A
0005434445222	17252	2	3A
0005434446493	17252	3	4A
0005434446492	17252	4	5A
0005434446494	17252	5	6B
0005434445209	17658	1	1A
0005434445208	17658	2	2A
0005433159291	17658	3	3A
0005433159290	17658	4	4A
0005435132777	7867	1	4A
0005435132780	7867	2	4C
0005435132775	7867	3	5B
0005435132770	7867	4	6D
0005435132773	7867	5	18A
0005435132772	7867	6	18B
0005435132776	7867	7	18C
0005435132774	7867	8	18D
0005435132779	7867	9	19A
0005435132771	7867	10	20C
0005435132778	7867	11	21A
0005435132706	33100	1	4A
0005435383094	33100	2	5D
0005435383097	33100	3	6A
0005435383098	33100	4	6B
0005435132719	33100	5	7B
0005435132715	33100	6	7C
0005435383096	33100	7	18C
0005435383093	33100	8	19C
0005435383095	33100	9	20D
0005435132701	33100	10	21C
0005435160184	7514	1	1B
0005435390119	7514	2	1C
0005435160185	7514	3	2C
0005435160186	7514	4	3A
0005435160183	7514	5	4C
0005435160187	7514	6	5A
0005435390121	7514	7	5D
0005435390117	7514	8	7B
0005435390120	7514	9	7C
0005435160190	7514	10	18B
0005435160188	7514	11	18D
0005435160191	7514	12	19A
0005435160192	7514	13	20C
0005435160193	7514	14	21A
0005435160189	7514	15	21B
0005435390123	7514	16	21D
0005435160194	7514	17	22B
0005435390171	29577	1	1A
0005435390167	29577	2	2A
0005435390170	29577	3	7B
0005435160137	29577	4	18A
0005435160123	29577	5	18C
0005435390172	29577	6	19D
0005435160121	29577	7	20D
0005435390169	29577	8	21B
0005435390168	29577	9	22B
0005435160122	29577	10	23B
0005435178479	18461	1	2B
0005435178478	18461	2	3B
0005435178984	18461	3	4A
0005435178983	18461	4	6A
0005432400084	27174	1	2A
0005432398154	27174	2	2B
0005432398153	27174	3	3A
0005432400085	27174	4	3B
0005432398155	27174	5	4A
0005432398152	27174	6	4B
0005432400083	27174	7	5B
0005432400082	27174	8	6A
0005432398156	27174	9	6B
0005434503772	6526	1	1A
0005434503754	6526	2	1C
0005434503778	6526	3	1F
0005434503779	6526	4	2A
0005434503743	6526	5	2D
0005434503747	6526	6	3A
0005434503782	6526	7	3C
0005434503774	6526	8	5C
0005435103856	6526	9	5D
0005434503777	6526	10	6C
0005434503759	6526	11	6D
0005434503741	6526	12	6E
0005434503745	6526	13	6F
0005434503748	6526	14	7E
0005434503780	6526	15	8A
0005434503781	6526	16	8C
0005434503753	6526	17	8E
0005434503765	6526	18	8F
0005434503761	6526	19	9A
0005435103854	6526	20	9D
0005435103857	6526	21	9E
0005434503757	6526	22	9F
0005434503771	6526	23	10C
0005434503760	6526	24	11C
0005434503755	6526	25	11F
0005434503768	6526	26	12D
0005435103855	6526	27	12E
0005434503758	6526	28	12F
0005434503742	6526	29	13A
0005435103861	6526	30	13C
0005434503749	6526	31	13E
0005435103859	6526	32	14C
0005434503770	6526	33	14F
0005434503766	6526	34	15D
0005434503773	6526	35	15E
0005435103853	6526	36	16D
0005434503751	6526	37	16E
0005434503750	6526	38	16F
0005434503762	6526	39	17A
0005435103860	6526	40	17C
0005434503763	6526	41	17E
0005434503776	6526	42	18A
0005434503775	6526	43	18D
0005434503744	6526	44	19A
0005434503764	6526	45	19C
0005434503752	6526	46	19D
0005434503769	6526	47	19F
0005434503746	6526	48	20A
0005434503767	6526	49	20C
0005435103858	6526	50	20D
0005434503756	6526	51	20F
0005434503528	22681	1	8D
0005434503461	22681	2	9F
0005434503462	22681	3	10F
0005434503495	22681	4	19A
0005433367232	1698	1	1C
0005435652566	1698	2	1D
0005435652608	1698	3	1F
0005435652614	1698	4	2A
0005435652599	1698	5	2C
0005435652596	1698	6	2D
0005433367397	1698	7	2F
0005435652611	1698	8	3A
0005435652581	1698	9	3C
0005435652578	1698	10	3D
0005435652607	1698	11	3F
0005433367251	1698	12	4A
0005435652580	1698	13	4C
0005435652564	1698	14	4E
0005435652571	1698	15	4F
0005433367258	1698	16	5A
0005435652610	1698	17	5E
0005435652589	1698	18	5F
0005435652601	1698	19	6A
0005435652583	1698	20	6C
0005435652582	1698	21	6D
0005433367233	1698	22	6E
0005433367256	1698	23	6F
0005433367277	1698	24	7A
0005435652576	1698	25	7C
0005435652587	1698	26	7D
0005433367242	1698	27	7E
0005435652572	1698	28	7F
0005433367280	1698	29	8A
0005435652579	1698	30	8C
0005435652613	1698	31	8F
0005435652562	1698	32	9A
0005435652616	1698	33	9F
0005435652597	1698	34	10A
0005435652568	1698	35	10C
0005435652567	1698	36	10D
0005435652603	1698	37	10E
0005435652615	1698	38	11C
0005435652604	1698	39	11D
0005435652593	1698	40	12A
0005435652609	1698	41	12D
0005435652591	1698	42	12E
0005433367257	1698	43	12F
0005435652569	1698	44	13A
0005435652563	1698	45	13C
0005435652577	1698	46	13D
0005433367284	1698	47	13E
0005435652584	1698	48	13F
0005435652605	1698	49	14A
0005435652598	1698	50	14C
0005435652561	1698	51	14E
0005435652586	1698	52	14F
0005435652574	1698	53	15A
0005435652585	1698	54	15C
0005435652618	1698	55	15D
0005435652617	1698	56	15E
0005435652602	1698	57	15F
0005435652575	1698	58	16A
0005435652590	1698	59	16C
0005435652619	1698	60	16E
0005433367229	1698	61	16F
0005435652588	1698	62	17D
0005435652592	1698	63	17E
0005435652620	1698	64	17F
0005435652565	1698	65	18A
0005435652595	1698	66	18C
0005435652612	1698	67	18D
0005435652573	1698	68	18E
0005435652600	1698	69	19D
0005435652570	1698	70	20C
0005435652594	1698	71	20D
0005435652606	1698	72	20F
0005433367503	21704	1	1D
0005433367497	21704	2	1F
0005433367523	21704	3	2D
0005433367520	21704	4	2F
0005433367514	21704	5	3C
0005433367488	21704	6	3D
0005433367498	21704	7	3F
0005433367521	21704	8	5D
0005433367496	21704	9	5F
0005433367506	21704	10	6A
0005433367492	21704	11	6D
0005433367489	21704	12	7D
0005433367499	21704	13	7F
0005433367517	21704	14	8D
0005433367490	21704	15	8F
0005433367502	21704	16	9A
0005433367487	21704	17	9C
0005433367513	21704	18	9D
0005433367522	21704	19	9E
0005433367500	21704	20	10A
0005433367501	21704	21	10E
0005433367494	21704	22	12D
0005433367518	21704	23	12E
0005433367519	21704	24	13D
0005433367505	21704	25	14C
0005433367515	21704	26	14E
0005433367507	21704	27	15A
0005433367495	21704	28	15D
0005433367510	21704	29	15F
0005433367491	21704	30	16A
0005433367512	21704	31	16D
0005433367516	21704	32	17A
0005433367508	21704	33	18A
0005433367524	21704	34	18F
0005433367493	21704	35	19A
0005433367504	21704	36	20A
0005433367511	21704	37	20E
0005433367509	21704	38	20F
0005433985516	4179	1	1A
0005435788745	4179	2	1C
0005433985506	4179	3	1F
0005433985485	4179	4	2A
0005433985500	4179	5	2C
0005433985508	4179	6	2D
0005433985465	4179	7	2F
0005433985464	4179	8	3D
0005433985493	4179	9	3F
0005433985501	4179	10	4D
0005433985477	4179	11	5C
0005433985514	4179	12	5D
0005433985471	4179	13	6A
0005433985494	4179	14	6C
0005433985483	4179	15	6D
0005433985470	4179	16	6E
0005433985507	4179	17	6F
0005433985497	4179	18	7C
0005433985486	4179	19	7E
0005433985472	4179	20	7F
0005433985515	4179	21	8A
0005433985513	4179	22	8D
0005433985502	4179	23	8E
0005433985504	4179	24	8F
0005433985466	4179	25	9C
0005433985473	4179	26	9E
0005433985509	4179	27	9F
0005433985505	4179	28	10A
0005433985491	4179	29	10D
0005433985487	4179	30	11A
0005433985478	4179	31	11C
0005433985484	4179	32	11D
0005433985469	4179	33	11E
0005433985468	4179	34	11F
0005433985510	4179	35	12D
0005435788746	4179	36	12E
0005433985503	4179	37	12F
0005433985479	4179	38	13A
0005433985492	4179	39	13C
0005433985511	4179	40	13D
0005433985512	4179	41	13E
0005433985476	4179	42	14A
0005433985480	4179	43	14F
0005433985499	4179	44	15A
0005433985498	4179	45	15D
0005433985489	4179	46	15F
0005433985481	4179	47	16E
0005433985496	4179	48	16F
0005433985495	4179	49	17E
0005435788747	4179	50	18A
0005433985488	4179	51	18E
0005433985474	4179	52	19A
0005435788744	4179	53	19C
0005433985490	4179	54	19D
0005433985475	4179	55	19E
0005433985467	4179	56	19F
0005433985482	4179	57	20D
0005433460400	20243	1	1A
0005433460411	20243	2	3A
0005433460403	20243	3	3G
0005433461560	20243	4	5A
0005433460401	20243	5	9H
0005433460409	20243	6	11B
0005433461562	20243	7	13A
0005433461564	20243	8	15A
0005433460407	20243	9	16A
0005433460406	20243	10	17A
0005433460405	20243	11	17D
0005433461559	20243	12	17G
0005433461554	20243	13	17H
0005433461558	20243	14	18G
0005433460412	20243	15	18H
0005433461550	20243	16	19A
0005433460408	20243	17	20A
0005433461561	20243	18	20E
0005433461557	20243	19	22B
0005433460398	20243	20	22A
0005433461556	20243	21	24E
0005433460410	20243	22	25F
0005433461553	20243	23	28A
0005433460399	20243	24	29H
0005433461563	20243	25	30H
0005433460404	20243	26	32D
0005433461552	20243	27	33A
0005433460402	20243	28	35E
0005433461551	20243	29	36B
0005433461555	20243	30	37F
0005435720125	24763	1	1B
0005435720126	24763	2	3C
0005435719556	24763	3	6B
0005435719557	24763	4	22D
0005433168331	21329	1	1A
0005433168330	21329	2	2A
0005434509029	21329	3	2B
0005433168328	21329	4	2D
0005433168329	21329	5	4B
0005434509015	21329	6	4D
0005433168327	21329	7	7A
0005433168332	21329	8	18C
0005433168325	21329	9	20C
0005434509016	21329	10	21A
0005433168326	21329	11	21C
0005434509030	21329	12	22A
0005432655340	17851	1	3C
0005432655341	17851	2	4C
0005434151675	17851	3	5C
0005432666360	17851	4	10D
0005432657393	17851	5	11E
0005432869463	17851	6	12E
0005432869464	17851	7	14E
0005432869462	17851	8	15C
0005432658555	17851	9	15F
0005432666359	17851	10	16D
0005434151677	17851	11	16E
0005432869461	17851	12	17D
0005434151676	17851	13	17E
0005432658556	17851	14	18A
0005432665237	17851	15	18E
0005432869460	17851	16	19A
0005432869459	17851	17	20F
0005432655390	26307	1	1D
0005432660794	26307	2	1F
0005432655395	26307	3	2A
0005432655392	26307	4	2C
0005432655397	26307	5	2D
0005432655398	26307	6	2F
0005432666363	26307	7	3A
0005432667431	26307	8	4D
0005432665250	26307	9	5C
0005432655389	26307	10	6A
0005432659682	26307	11	6F
0005432665251	26307	12	8C
0005432659683	26307	13	9D
0005432655399	26307	14	10A
0005432655387	26307	15	10F
0005432655396	26307	16	15A
0005432666365	26307	17	15D
0005432655388	26307	18	15E
0005432667430	26307	19	16A
0005432655391	26307	20	16D
0005432660793	26307	21	18A
0005432666364	26307	22	18D
0005432658567	26307	23	18E
0005432655394	26307	24	18F
0005432667429	26307	25	19A
0005432657414	26307	26	19F
0005432655393	26307	27	20F
0005432328265	3079	1	1A
0005432328232	3079	2	1C
0005432328243	3079	3	1D
0005432328262	3079	4	1F
0005432328249	3079	5	2A
0005432287139	3079	6	3D
0005432328234	3079	7	3C
0005432328252	3079	8	3F
0005432328239	3079	9	4C
0005432328240	3079	10	4D
0005432905041	3079	11	4E
0005432287137	3079	12	5E
0005432328242	3079	13	6C
0005432328229	3079	14	6D
0005432287140	3079	15	6E
0005432328228	3079	16	7C
0005432328251	3079	17	7F
0005432328258	3079	18	8A
0005432328221	3079	19	8D
0005432328220	3079	20	9E
0005432328255	3079	21	9F
0005432328245	3079	22	10A
0005432328259	3079	23	10C
0005432328260	3079	24	11A
0005432328223	3079	25	11C
0005432328236	3079	26	12A
0005432328235	3079	27	12D
0005432328238	3079	28	12E
0005432328233	3079	29	12F
0005432287136	3079	30	13A
0005432905028	3079	31	13C
0005432328222	3079	32	13D
0005432328263	3079	33	13E
0005432328225	3079	34	13F
0005432328261	3079	35	14A
0005432905031	3079	36	14C
0005432328226	3079	37	14D
0005432328237	3079	38	14E
0005432905027	3079	39	14F
0005432328256	3079	40	15A
0005432328254	3079	41	15C
0005432328257	3079	42	15D
0005432328247	3079	43	15F
0005432328231	3079	44	16C
0005432328219	3079	45	16D
0005432328253	3079	46	16E
0005433438813	3079	47	17C
0005432328224	3079	48	17E
0005432328244	3079	49	17F
0005432328241	3079	50	18A
0005432328248	3079	51	18C
0005433438812	3079	52	18D
0005432328246	3079	53	18E
0005432328230	3079	54	19A
0005432328227	3079	55	19C
0005432328264	3079	56	19E
0005432328250	3079	57	19F
0005432287138	3079	58	20C
0005432905064	31131	1	1A
0005432327930	31131	2	1C
0005432054273	31131	3	1F
0005432328033	31131	4	4C
0005432328034	31131	5	6C
0005432327905	31131	6	7E
0005432905066	31131	7	8C
0005432905069	31131	8	10C
0005432327931	31131	9	10E
0005432327901	31131	10	11A
0005432905067	31131	11	12C
0005432054275	31131	12	13C
0005432328004	31131	13	13D
0005432905065	31131	14	13E
0005432327919	31131	15	14A
0005432327902	31131	16	15F
0005432327906	31131	17	16A
0005432905068	31131	18	16F
0005432905063	31131	19	17A
0005432328006	31131	20	19C
0005432328005	31131	21	19D
0005432054274	31131	22	20A
0005435999090	6209	1	1C
0005435999087	6209	2	2A
0005435999086	6209	3	2D
0005435296957	6209	4	3A
0005434309602	6209	5	4C
0005435999083	6209	6	5B
0005435487468	6209	7	5C
0005435999069	6209	8	5F
0005435999080	6209	9	6B
0005434309607	6209	10	7F
0005435999078	6209	11	8A
0005434309600	6209	12	8D
0005435999081	6209	13	8C
0005435999073	6209	14	8F
0005435999085	6209	15	8E
0005432146179	6209	16	9B
0005435999079	6209	17	9C
0005435999075	6209	18	9E
0005435999074	6209	19	9F
0005434309606	6209	20	10E
0005435999076	6209	21	11A
0005434309604	6209	22	11D
0005434309599	6209	23	12A
0005435999093	6209	24	12C
0005435999088	6209	25	12E
0005435999077	6209	26	13B
0005435999071	6209	27	13D
0005434309603	6209	28	14C
0005435999072	6209	29	15B
0005434309601	6209	30	15A
0005435999084	6209	31	15C
0005435296953	6209	32	15E
0005434309608	6209	33	16A
0005435999091	6209	34	16C
0005435999089	6209	35	17E
0005432146178	6209	36	18A
0005435999070	6209	37	18C
0005435999092	6209	38	18D
0005434309611	6209	39	18F
0005434309598	6209	40	19C
0005435487461	6209	41	19E
0005434309609	6209	42	20E
0005434309605	6209	43	21B
0005435999082	6209	44	21A
0005434309610	6209	45	23A
0005434309531	19580	1	1F
0005435487596	19580	2	3A
0005435487594	19580	3	3F
0005435487589	19580	4	5C
0005435296991	19580	5	5B
0005435487587	19580	6	5D
0005435487592	19580	7	6B
0005435487603	19580	8	6A
0005434309505	19580	9	6D
0005434309521	19580	10	7A
0005435487607	19580	11	7D
0005434309532	19580	12	8E
0005435487586	19580	13	8F
0005434309533	19580	14	9B
0005435487601	19580	15	9E
0005435487608	19580	16	9D
0005435296992	19580	17	10D
0005434309509	19580	18	11A
0005435296990	19580	19	11F
0005435487595	19580	20	12A
0005435487590	19580	21	12E
0005435487604	19580	22	14D
0005434309542	19580	23	15D
0005435296987	19580	24	16A
0005435487598	19580	25	16C
0005434309508	19580	26	16D
0005435487605	19580	27	16F
0005434309541	19580	28	17D
0005435487602	19580	29	17F
0005435296988	19580	30	18C
0005435487600	19580	31	18D
0005435487588	19580	32	19A
0005435487599	19580	33	20C
0005435296989	19580	34	21E
0005435487597	19580	35	22F
0005435487606	19580	36	22E
0005435487593	19580	37	23B
0005435487591	19580	38	23C
0005433158104	17552	1	1D
0005433158111	17552	2	3D
0005433158106	17552	3	4D
0005433158105	17552	4	5D
0005433158109	17552	5	7B
0005433158110	17552	6	19D
0005433158107	17552	7	20C
0005433158108	17552	8	21B
0005435508240	1575	1	1C
0005435508244	1575	2	1D
0005435517741	1575	3	2A
0005435502105	1575	4	2C
0005435517742	1575	5	2F
0005435508248	1575	6	3C
0005434565784	1575	7	3A
0005435502100	1575	8	3D
0005432291906	1575	9	3F
0005435502101	1575	10	4A
0005435517739	1575	11	4E
0005435502106	1575	12	5D
0005435517747	1575	13	5E
0005435502102	1575	14	5F
0005435517738	1575	15	6C
0005434565780	1575	16	6D
0005434565775	1575	17	6E
0005434565783	1575	18	6F
0005434565781	1575	19	7A
0005435502107	1575	20	7D
0005435508239	1575	21	8A
0005432291907	1575	22	8C
0005435517737	1575	23	8D
0005432291905	1575	24	8E
0005435502086	1575	25	8F
0005435517735	1575	26	9A
0005433185981	1575	27	9C
0005435502093	1575	28	9D
0005435502099	1575	29	9F
0005434565786	1575	30	10A
0005435502087	1575	31	10C
0005434565779	1575	32	10D
0005435502090	1575	33	10E
0005435508246	1575	34	11D
0005435508241	1575	35	11E
0005435517736	1575	36	12A
0005434565777	1575	37	12C
0005435517748	1575	38	12D
0005435502089	1575	39	12E
0005435508249	1575	40	12F
0005435502095	1575	41	13A
0005435502088	1575	42	13C
0005435502098	1575	43	13D
0005435517743	1575	44	13E
0005435508242	1575	45	13F
0005434565778	1575	46	14C
0005433185980	1575	47	14D
0005435502104	1575	48	14E
0005433185971	1575	49	14F
0005435508235	1575	50	15A
0005435517745	1575	51	15C
0005434565787	1575	52	15E
0005435517740	1575	53	15F
0005435502103	1575	54	16A
0005435508236	1575	55	16C
0005435502094	1575	56	16D
0005435508238	1575	57	16E
0005434565785	1575	58	17A
0005435517746	1575	59	17C
0005435508237	1575	60	17F
0005435502091	1575	61	18A
0005435508245	1575	62	18C
0005435517744	1575	63	18D
0005435508247	1575	64	18E
0005435517733	1575	65	18F
0005435502092	1575	66	19C
0005434565782	1575	67	19D
0005434565776	1575	68	19F
0005435502096	1575	69	20A
0005435517732	1575	70	20C
0005435517734	1575	71	20D
0005435502097	1575	72	20E
0005435508243	1575	73	20F
0005433186030	20859	1	1A
0005434565691	20859	2	2D
0005434565689	20859	3	3C
0005433186035	20859	4	3D
0005433186033	20859	5	5E
0005433186038	20859	6	5F
0005435501942	20859	7	8C
0005434565699	20859	8	9A
0005434565706	20859	9	10A
0005433186034	20859	10	10E
0005433186031	20859	11	12C
0005434565693	20859	12	12E
0005435501949	20859	13	13D
0005434565690	20859	14	13F
0005433186037	20859	15	15C
0005433186036	20859	16	16A
0005435501943	20859	17	16F
0005433186032	20859	18	17A
0005435501941	20859	19	18A
0005435528921	20859	20	19C
0005435931537	3898	1	2A
0005435931542	3898	2	5A
0005435153676	3898	3	5C
0005435931538	3898	4	5D
0005435153674	3898	5	6D
0005435153678	3898	6	18D
0005435153675	3898	7	21A
0005435153679	3898	8	22B
0005435153677	3898	9	23B
0005435931564	21855	1	1A
0005435153629	21855	2	1B
0005435931565	21855	3	1D
0005435153630	21855	4	6B
0005435931563	21855	5	6D
0005432628693	7228	1	1B
0005432628699	7228	2	2D
0005432628700	7228	3	3A
0005432628705	7228	4	3B
0005432628697	7228	5	4A
0005432628691	7228	6	6C
0005432628692	7228	7	7B
0005432628704	7228	8	7C
0005432628702	7228	9	7D
0005432628701	7228	10	19A
0005432628694	7228	11	19D
0005432628696	7228	12	20C
0005432628698	7228	13	21B
0005432628703	7228	14	22A
0005435225443	7228	15	22D
0005432628695	7228	16	23A
0005432628610	28144	1	1A
0005432628617	28144	2	3C
0005435225506	28144	3	4B
0005432628614	28144	4	4C
0005435225503	28144	5	6A
0005435225501	28144	6	6B
0005435225508	28144	7	6D
0005432628605	28144	8	7B
0005435225510	28144	9	7D
0005432628616	28144	10	18D
0005435225504	28144	11	19A
0005432628615	28144	12	19B
0005432628609	28144	13	19C
0005435225509	28144	14	19D
0005435225507	28144	15	20A
0005435225505	28144	16	20B
0005435225502	28144	17	20C
0005432628618	28144	18	21A
0005432628604	28144	19	21B
0005435225500	28144	20	21D
0005432628602	28144	21	22B
0005432628603	28144	22	23A
0005435960012	8748	1	4C
0005435960013	8748	2	6C
0005435960011	8748	3	18B
0005434267890	8748	4	19C
0005435960010	8748	5	20B
0005435960014	8748	6	22A
0005435960015	8748	7	22B
0005434267912	15254	1	1D
0005434267911	15254	2	4C
0005435959986	15254	3	19D
0005434267913	15254	4	21C
0005432692725	1183	1	1A
0005432674975	1183	2	2A
0005432692729	1183	3	1F
0005432674977	1183	4	2D
0005432692741	1183	5	3A
0005432674981	1183	6	3D
0005432873166	1183	7	4F
0005432692728	1183	8	4D
0005432692727	1183	9	5C
0005432692747	1183	10	5A
0005432674974	1183	11	6B
0005432692744	1183	12	6A
0005432692739	1183	13	6C
0005432692738	1183	14	6F
0005432692742	1183	15	7C
0005432692723	1183	16	7E
0005432692730	1183	17	7F
0005432692724	1183	18	8B
0005432692732	1183	19	8E
0005432692737	1183	20	9A
0005432692720	1183	21	9D
0005432674985	1183	22	9C
0005432674984	1183	23	10C
0005432873179	1183	24	10E
0005432692745	1183	25	10D
0005432692731	1183	26	10F
0005432677529	1183	27	11B
0005432692735	1183	28	11D
0005432692736	1183	29	11C
0005432692722	1183	30	12A
0005432692717	1183	31	12B
0005432692721	1183	32	13A
0005432674978	1183	33	13B
0005432692718	1183	34	13F
0005432674972	1183	35	14B
0005432677531	1183	36	14C
0005432677530	1183	37	14E
0005432674980	1183	38	15B
0005432873189	1183	39	15A
0005432674973	1183	40	15E
0005432677528	1183	41	16A
0005432873165	1183	42	16E
0005432674979	1183	43	17A
0005432692740	1183	44	17C
0005432692733	1183	45	18D
0005432692719	1183	46	18E
0005432677532	1183	47	18F
0005432692746	1183	48	19B
0005432674983	1183	49	19E
0005432674971	1183	50	20A
0005432692734	1183	51	19F
0005432674986	1183	52	20B
0005432674982	1183	53	20F
0005432692726	1183	54	21D
0005432692743	1183	55	21E
0005432674976	1183	56	21F
0005432873222	17512	1	7D
0005432677508	17512	2	8C
0005432873217	17512	3	8E
0005432692536	17512	4	9A
0005432873223	17512	5	9F
0005432873219	17512	6	10F
0005432677509	17512	7	11F
0005432692563	17512	8	13D
0005432873220	17512	9	14C
0005432692581	17512	10	15E
0005432873221	17512	11	17A
0005432692541	17512	12	16F
0005432674889	17512	13	17D
0005432692542	17512	14	17C
0005432677510	17512	15	18B
0005432674868	17512	16	19A
0005432873218	17512	17	21F
0005434435033	1138	1	2C
0005434435020	1138	2	4A
0005434435023	1138	3	6A
0005434435030	1138	4	7D
0005434435026	1138	5	18A
0005433156614	1138	6	20B
0005434435027	1138	7	20C
0005434435032	1138	8	20D
0005434435029	1138	9	21B
0005434435024	1138	10	21C
0005434435025	1138	11	22A
0005434435028	1138	12	22C
0005434435022	1138	13	22D
0005434435021	1138	14	23A
0005434435031	1138	15	23B
0005434434921	17330	1	2B
0005433156661	17330	2	3C
0005433156662	17330	3	4A
0005433156665	17330	4	4B
0005434434948	17330	5	5C
0005434434911	17330	6	5D
0005433156658	17330	7	6B
0005433156666	17330	8	6C
0005434434959	17330	9	6D
0005434434910	17330	10	7A
0005434434922	17330	11	7B
0005433156663	17330	12	7C
0005433156659	17330	13	18B
0005434434929	17330	14	19B
0005433156660	17330	15	19C
0005434434947	17330	16	20D
0005433156664	17330	17	21A
0005434434967	17330	18	21C
0005434434968	17330	19	22B
0005435086761	4060	1	3C
0005435086760	4060	2	5B
0005435086759	4060	3	6C
0005435086755	4060	4	18A
0005435086757	4060	5	20B
0005435086756	4060	6	20C
0005435086758	4060	7	23A
0005435928093	24437	1	2C
0005435928096	24437	2	4B
0005435928095	24437	3	6D
0005435928094	24437	4	18B
0005435086716	24437	5	18C
0005435928097	24437	6	19A
0005435086702	24437	7	20B
0005435928092	24437	8	22B
0005435098533	17004	1	1A
0005435098534	17004	2	1G
0005435098537	17004	3	2A
0005435551524	17004	4	2G
0005435551528	17004	5	2H
0005435551516	17004	6	3B
0005435551523	17004	7	4B
0005435098529	17004	8	4H
0005435551531	17004	9	5C
0005435551526	17004	10	11B
0005435551532	17004	11	12B
0005435551522	17004	12	13A
0005435551535	17004	13	15F
0005435551527	17004	14	16D
0005435098530	17004	15	17B
0005435551514	17004	16	18B
0005435551533	17004	17	19H
0005435551519	17004	18	20E
0005435098535	17004	19	21B
0005435551525	17004	20	23F
0005435551536	17004	21	24E
0005435098532	17004	22	28B
0005435551534	17004	23	30A
0005435551529	17004	24	30G
0005435098531	17004	25	31D
0005435551518	17004	26	31H
0005435551517	17004	27	31G
0005435551520	17004	28	32B
0005435551513	17004	29	34H
0005435551515	17004	30	38F
0005435551530	17004	31	38D
0005435551521	17004	32	38H
0005435098536	17004	33	39D
0005434625866	4840	1	2A
0005434625867	4840	2	2C
0005434625865	4840	3	3F
0005434625870	4840	4	7C
0005434625869	4840	5	14D
0005434625868	4840	6	18E
0005435907418	4840	7	19A
0005434625864	4840	8	19C
0005435907419	4840	9	20A
0005435907457	32882	1	1D
0005433194828	32882	2	2D
0005435907454	32882	3	4A
0005434625798	32882	4	6E
0005435907453	32882	5	9A
0005433194833	32882	6	11D
0005433194831	32882	7	12D
0005433194832	32882	8	12E
0005435907455	32882	9	14D
0005434625797	32882	10	15E
0005434625821	32882	11	15F
0005434625822	32882	12	17E
0005435907456	32882	13	19A
0005433194829	32882	14	19C
0005433194830	32882	15	19D
0005432195671	13800	1	1B
0005435784727	13800	2	2C
0005435784811	13800	3	4B
0005435784740	13800	4	4D
0005435784782	13800	5	5B
0005435784743	13800	6	6A
0005435784733	13800	7	7D
0005432195672	13800	8	18C
0005435784728	13800	9	21C
0005435784734	13800	10	22B
0005435784950	27416	1	1A
0005435784961	27416	2	1B
0005435784965	27416	3	1C
0005435784946	27416	4	1D
0005432190586	27416	5	2A
0005432190584	27416	6	2C
0005435784960	27416	7	2D
0005435784945	27416	8	3A
0005435784968	27416	9	3B
0005435784976	27416	10	3C
0005435784955	27416	11	3D
0005435787329	27416	12	4A
0005432190583	27416	13	4B
0005435784975	27416	14	4C
0005435784956	27416	15	4D
0005435784969	27416	16	5A
0005435784963	27416	17	5B
0005435784940	27416	18	5C
0005435784964	27416	19	5D
0005435784967	27416	20	6A
0005432190585	27416	21	6C
0005435784972	27416	22	7A
0005435784958	27416	23	7C
0005435787328	27416	24	7D
0005435784954	27416	25	18A
0005435784949	27416	26	18B
0005435784953	27416	27	18D
0005435784970	27416	28	19A
0005435784948	27416	29	19B
0005435784973	27416	30	19C
0005435784942	27416	31	19D
0005435784952	27416	32	20A
0005435784939	27416	33	20B
0005435784944	27416	34	20C
0005435784962	27416	35	20D
0005435784951	27416	36	21A
0005435784947	27416	37	21B
0005435784941	27416	38	21C
0005435784971	27416	39	21D
0005435784943	27416	40	22A
0005435784959	27416	41	22B
0005435784974	27416	42	22C
0005435784966	27416	43	22D
0005435784957	27416	44	23B
0005434406663	20265	1	1D
0005434406751	20265	2	4E
0005432058343	20265	3	5C
0005434406810	20265	4	6C
0005434406834	20265	5	6D
0005434406821	20265	6	7C
0005434406800	20265	7	7E
0005434406743	20265	8	8D
0005434406784	20265	9	8F
0005435310946	20265	10	9C
0005432058341	20265	11	9D
0005432058340	20265	12	9E
0005435310945	20265	13	11A
0005434406729	20265	14	11D
0005434406770	20265	15	12C
0005434406783	20265	16	12F
0005434406662	20265	17	13C
0005435310942	20265	18	13F
0005434406730	20265	19	14A
0005434406674	20265	20	14D
0005434406917	20265	21	16A
0005435310948	20265	22	16C
0005434406742	20265	23	16F
0005435310943	20265	24	17A
0005435310947	20265	25	17C
0005435310944	20265	26	17F
0005434406660	20265	27	18C
0005432058342	20265	28	19A
0005434406713	20265	29	19E
0005434406862	20265	30	20E
0005434407109	27015	1	1A
0005434407089	27015	2	1C
0005434407121	27015	3	1D
0005434407147	27015	4	1F
0005434407090	27015	5	2A
0005434407103	27015	6	2D
0005434407149	27015	7	2F
0005434407129	27015	8	3A
0005434407130	27015	9	3C
0005434407092	27015	10	3F
0005434407088	27015	11	4C
0005434407119	27015	12	4D
0005434407117	27015	13	4F
0005434407123	27015	14	5A
0005434407133	27015	15	5C
0005434407143	27015	16	5D
0005434407136	27015	17	5E
0005434407138	27015	18	6C
0005434407126	27015	19	6D
0005434407106	27015	20	6E
0005432153866	27015	21	6F
0005432153864	27015	22	7A
0005434407120	27015	23	7C
0005434407097	27015	24	7D
0005434407099	27015	25	8A
0005434407116	27015	26	8C
0005434407111	27015	27	8D
0005434407095	27015	28	8E
0005432153868	27015	29	8F
0005434407101	27015	30	9A
0005434407114	27015	31	9C
0005434407094	27015	32	9D
0005434407107	27015	33	9E
0005434407100	27015	34	9F
0005434407140	27015	35	10A
0005434407137	27015	36	10D
0005434407152	27015	37	10E
0005434407093	27015	38	10F
0005434407144	27015	39	11A
0005434407142	27015	40	11C
0005434407113	27015	41	11E
0005434407091	27015	42	11F
0005434407146	27015	43	12A
0005434407145	27015	44	12C
0005434407105	27015	45	12D
0005434407128	27015	46	12F
0005434407102	27015	47	13A
0005434407115	27015	48	13D
0005434407153	27015	49	13E
0005434407118	27015	50	13F
0005434407150	27015	51	14C
0005434407104	27015	52	14E
0005434407148	27015	53	14F
0005434407134	27015	54	15A
0005434407096	27015	55	15C
0005434407124	27015	56	15D
0005432153865	27015	57	15E
0005434407098	27015	58	16A
0005434407127	27015	59	16D
0005434407131	27015	60	17A
0005434407139	27015	61	17C
0005432153867	27015	62	17D
0005432153869	27015	63	17E
0005434407135	27015	64	18A
0005434407112	27015	65	18C
0005434407108	27015	66	18D
0005434407110	27015	67	18E
0005434407132	27015	68	19A
0005434407125	27015	69	19C
0005434407151	27015	70	19E
0005434407141	27015	71	19F
0005434407154	27015	72	20C
0005434407122	27015	73	20F
0005434319243	5684	1	1F
0005433123584	5684	2	2A
0005433123572	5684	3	2D
0005434319248	5684	4	3D
0005433123578	5684	5	4F
0005434311197	5684	6	5E
0005433123579	5684	7	5F
0005433123569	5684	8	9C
0005433123583	5684	9	10E
0005434319241	5684	10	11D
0005434319246	5684	11	11E
0005434319247	5684	12	11F
0005434319244	5684	13	12C
0005434311200	5684	14	12E
0005433123585	5684	15	13C
0005434311198	5684	16	13E
0005434311199	5684	17	14A
0005432109676	5684	18	15A
0005433123568	5684	19	15C
0005434319242	5684	20	15F
0005432109675	5684	21	18C
0005434319245	5684	22	18D
0005433123610	5684	23	20D
0005433123714	15649	1	2D
0005433123719	15649	2	2F
0005433123732	15649	3	3F
0005434311182	15649	4	4C
0005433123723	15649	5	4D
0005433123730	15649	6	4E
0005433123735	15649	7	5A
0005433123716	15649	8	6D
0005433123727	15649	9	7A
0005433123734	15649	10	8C
0005434312287	15649	11	8E
0005433123725	15649	12	9A
0005434311185	15649	13	9D
0005433123720	15649	14	10C
0005433123721	15649	15	12A
0005433123722	15649	16	12E
0005433123729	15649	17	12F
0005433123715	15649	18	13A
0005434319142	15649	19	14A
0005433123736	15649	20	15A
0005434312283	15649	21	15F
0005433123724	15649	22	16A
0005433123718	15649	23	16C
0005433123726	15649	24	16E
0005433123728	15649	25	16F
0005433123717	15649	26	18F
0005434319141	15649	27	19A
0005433123733	15649	28	19C
0005433123731	15649	29	19E
0005434312288	15649	30	20E
0005435220295	31754	1	1A
0005435219179	31754	2	2C
0005435220299	31754	3	3A
0005435219175	31754	4	4A
0005435219178	31754	5	5C
0005435220296	31754	6	7B
0005435219176	31754	7	19C
0005435220298	31754	8	20B
0005435220297	31754	9	20D
0005435219180	31754	10	21B
0005435219177	31754	11	21C
0005434484281	9014	1	2B
0005434484283	9014	2	3C
0005434484278	9014	3	5A
0005434484280	9014	4	6B
0005434484279	9014	5	7B
0005434189076	9014	6	7D
0005434484282	9014	7	18C
0005434484284	9014	8	18D
0005434189120	16647	1	3B
0005434189119	16647	2	3C
0005434189117	16647	3	7A
0005434189122	16647	4	19B
0005434189121	16647	5	20D
0005434484247	16647	6	22C
0005434189118	16647	7	23B
0005433123720	7653	1	1C
0005433123717	7653	2	1F
0005433123736	7653	3	2C
0005433123714	7653	4	2F
0005433123733	7653	5	3C
0005433123719	7653	6	5C
0005433123730	7653	7	6E
0005433123718	7653	8	8F
0005433123726	7653	9	11A
0005433123722	7653	10	12A
0005433123729	7653	11	13C
0005433123727	7653	12	13E
0005433123723	7653	13	14D
0005433123734	7653	14	15A
0005433123735	7653	15	15E
0005433123731	7653	16	16A
0005433123728	7653	17	16C
0005433123732	7653	18	16D
0005433123724	7653	19	16F
0005433123716	7653	20	17A
0005433123715	7653	21	17C
0005433123721	7653	22	17E
0005433123725	7653	23	18D
0005433449757	7586	1	1C
0005432720642	7586	2	1D
0005433449756	7586	3	1F
0005432692779	7586	4	2A
0005433449741	7586	5	2C
0005432720648	7586	6	2D
0005432692770	7586	7	2F
0005432720627	7586	8	3A
0005433449754	7586	9	3C
0005432720630	7586	10	3D
0005432692755	7586	11	3F
0005433449740	7586	12	4A
0005432692769	7586	13	4C
0005432692758	7586	14	4D
0005432720632	7586	15	4E
0005432692752	7586	16	4F
0005433449752	7586	17	5A
0005432692765	7586	18	5C
0005433449743	7586	19	5D
0005432720643	7586	20	5E
0005432720637	7586	21	5F
0005432692768	7586	22	6A
0005432720623	7586	23	6C
0005432720634	7586	24	6D
0005433449744	7586	25	6E
0005432720645	7586	26	6F
0005433449759	7586	27	7A
0005432692756	7586	28	7C
0005432720620	7586	29	7E
0005432720628	7586	30	7F
0005432692773	7586	31	8A
0005432720631	7586	32	8C
0005432720629	7586	33	8D
0005433449758	7586	34	9C
0005433449760	7586	35	9D
0005432720646	7586	36	9F
0005433449755	7586	37	10A
0005432720622	7586	38	10C
0005432692777	7586	39	10D
0005432692767	7586	40	10E
0005432071544	7586	41	10F
0005433449747	7586	42	11A
0005432692772	7586	43	11C
0005432692764	7586	44	11D
0005432692748	7586	45	11E
0005432692763	7586	46	11F
0005432720624	7586	47	12C
0005432692761	7586	48	12D
0005432692762	7586	49	12E
0005433449748	7586	50	12F
0005432692766	7586	51	13A
0005432692750	7586	52	13C
0005432692751	7586	53	13D
0005432720640	7586	54	13E
0005432692771	7586	55	13F
0005432692778	7586	56	14A
0005432692757	7586	57	14C
0005432720621	7586	58	14D
0005432071545	7586	59	14E
0005432692754	7586	60	14F
0005433449746	7586	61	15A
0005432692776	7586	62	15C
0005432720635	7586	63	15D
0005433449750	7586	64	15E
0005433449749	7586	65	15F
0005433449745	7586	66	16C
0005432720644	7586	67	16D
0005432720626	7586	68	16E
0005432720641	7586	69	16F
0005432720647	7586	70	17A
0005432720639	7586	71	17C
0005432692760	7586	72	17D
0005432692759	7586	73	17E
0005433449753	7586	74	17F
0005432071543	7586	75	18A
0005432692753	7586	76	18C
0005432720636	7586	77	18D
0005433449751	7586	78	18E
0005432071542	7586	79	18F
0005433449761	7586	80	19A
0005432692749	7586	81	19C
0005432720633	7586	82	19D
0005432692775	7586	83	19E
0005432720638	7586	84	19F
0005433449739	7586	85	20A
0005432692774	7586	86	20C
0005433449742	7586	87	20D
0005432720625	7586	88	20F
0005433449661	30392	1	4F
0005432692536	30392	2	5A
0005432692542	30392	3	9C
0005432692581	30392	4	11F
0005432692563	30392	5	13C
0005432692541	30392	6	13E
0005433449623	30392	7	14F
0005433449646	30392	8	15F
0005433449622	30392	9	18E
0005433449610	30392	10	18F
0005433123585	30391	1	1D
0005433722155	30391	2	2D
0005432720434	30391	3	5D
0005433123579	30391	4	5E
0005432720476	30391	5	5F
0005433123578	30391	6	6A
0005432720432	30391	7	7C
0005433722156	30391	8	7E
0005433123572	30391	9	8A
0005432720433	30391	10	9C
0005433123610	30391	11	9D
0005433722157	30391	12	10A
0005433123583	30391	13	11A
0005433123568	30391	14	11C
0005432720481	30391	15	13A
0005432720505	30391	16	14C
0005432720440	30391	17	14F
0005433123569	30391	18	15D
0005433123584	30391	19	15E
0005432720441	30391	20	16D
0005432927895	1396	1	1A
0005434586348	1396	2	1C
0005434586362	1396	3	1D
0005433192838	1396	4	2A
0005434586345	1396	5	2C
0005433524929	1396	6	2D
0005433192839	1396	7	3A
0005433524933	1396	8	3C
0005434586366	1396	9	3D
0005433192843	1396	10	4A
0005433524930	1396	11	4C
0005433524934	1396	12	4D
0005434586367	1396	13	4E
0005434586346	1396	14	5E
0005433724761	1396	15	5F
0005434586349	1396	16	6C
0005434513552	1396	17	6E
0005433524932	1396	18	6F
0005434514941	1396	19	7A
0005433524935	1396	20	7C
0005432927892	1396	21	7E
0005432927896	1396	22	7F
0005433724759	1396	23	8A
0005433192818	1396	24	8C
0005433524931	1396	25	8D
0005434586354	1396	26	8E
0005433724760	1396	27	9C
0005434586352	1396	28	9E
0005432927891	1396	29	9F
0005434513551	1396	30	10C
0005434586344	1396	31	10D
0005434586357	1396	32	11C
0005434586350	1396	33	11D
0005433524927	1396	34	11F
0005433524923	1396	35	12F
0005434586353	1396	36	13A
0005434586363	1396	37	13C
0005434586365	1396	38	13F
0005434586347	1396	39	14A
0005434514940	1396	40	14E
0005434586358	1396	41	15A
0005434586359	1396	42	15C
0005434513553	1396	43	15D
0005433524926	1396	44	15F
0005432927887	1396	45	16A
0005434586356	1396	46	16D
0005434586361	1396	47	16E
0005434586364	1396	48	16F
0005434586360	1396	49	17A
0005434586342	1396	50	17C
0005432270975	1396	51	17F
0005434586351	1396	52	18A
0005433724762	1396	53	18C
0005433524928	1396	54	18D
0005433524924	1396	55	19A
0005432270974	1396	56	19C
0005432927897	1396	57	19E
0005432270976	1396	58	19F
0005433524925	1396	59	20C
0005434586343	1396	60	20D
0005434586355	1396	61	20E
0005433192914	18545	1	1A
0005434586162	18545	2	1F
0005432968815	18545	3	2C
0005433192904	18545	4	2D
0005433192909	18545	5	3A
0005433192919	18545	6	3C
0005434514924	18545	7	4F
0005433192913	18545	8	5D
0005432927922	18545	9	5E
0005434514925	18545	10	5F
0005433192915	18545	11	6A
0005434586223	18545	12	6C
0005433192912	18545	13	7F
0005433192917	18545	14	9A
0005433192906	18545	15	9D
0005433192908	18545	16	9E
0005433192911	18545	17	10C
0005433192910	18545	18	11E
0005432927921	18545	19	11F
0005434586237	18545	20	12A
0005433192905	18545	21	12C
0005432927923	18545	22	12D
0005432927924	18545	23	12E
0005434586180	18545	24	12F
0005433192916	18545	25	13C
0005433524852	18545	26	13E
0005434586236	18545	27	13F
0005434586190	18545	28	15D
0005433724739	18545	29	16C
0005434586222	18545	30	16D
0005434586161	18545	31	17C
0005433192918	18545	32	17D
0005432968816	18545	33	18A
0005432968817	18545	34	18D
0005433192907	18545	35	20A
0005434343816	11455	1	1A
0005434343799	11455	2	1B
0005434343808	11455	3	1C
0005434142572	11455	4	1D
0005435302119	11455	5	2A
0005434343817	11455	6	2B
0005434343836	11455	7	2D
0005434343802	11455	8	3A
0005434343834	11455	9	3B
0005434343835	11455	10	3C
0005434343837	11455	11	3D
0005434343809	11455	12	4A
0005434343821	11455	13	4C
0005434142570	11455	14	4D
0005434343806	11455	15	5A
0005434343825	11455	16	5B
0005434142573	11455	17	5C
0005434343800	11455	18	5D
0005434343818	11455	19	6A
0005434343820	11455	20	6B
0005434343832	11455	21	6C
0005434343827	11455	22	6D
0005434343804	11455	23	7A
0005434343826	11455	24	7D
0005434142569	11455	25	18A
0005434343801	11455	26	18B
0005434343831	11455	27	18C
0005434343805	11455	28	18D
0005434343833	11455	29	19A
0005434343823	11455	30	19C
0005434343812	11455	31	19D
0005434343803	11455	32	20A
0005434343830	11455	33	20B
0005434343815	11455	34	20C
0005434343811	11455	35	20D
0005434343814	11455	36	21A
0005434343822	11455	37	21B
0005434142571	11455	38	21D
0005434343829	11455	39	21C
0005434343828	11455	40	22A
0005434343824	11455	41	22B
0005434343807	11455	42	22C
0005434343810	11455	43	22D
0005434343819	11455	44	23A
0005434343813	11455	45	23B
0005434343584	29750	1	20D
0005435824351	1249	1	1C
0005435824349	1249	2	1A
0005433415407	1249	3	3A
0005435824343	1249	4	3D
0005435824358	1249	5	4F
0005435824344	1249	6	5A
0005435824362	1249	7	6B
0005432284530	1249	8	6E
0005433415429	1249	9	6D
0005432284527	1249	10	8A
0005435824356	1249	11	7F
0005435824355	1249	12	8B
0005435824352	1249	13	9B
0005435824348	1249	14	9A
0005435824365	1249	15	9D
0005433415430	1249	16	9F
0005435824370	1249	17	10B
0005433415389	1249	18	11A
0005432284528	1249	19	10E
0005433415420	1249	20	11F
0005435824367	1249	21	12A
0005435824366	1249	22	12D
0005435824354	1249	23	12C
0005435824363	1249	24	14C
0005433415419	1249	25	15B
0005435824345	1249	26	15A
0005435824347	1249	27	15E
0005435824359	1249	28	16A
0005435824360	1249	29	16C
0005435824368	1249	30	16D
0005435824369	1249	31	17B
0005435824350	1249	32	17A
0005433415390	1249	33	17D
0005432284529	1249	34	17E
0005435824346	1249	35	18B
0005435824357	1249	36	18E
0005433415400	1249	37	19B
0005435824364	1249	38	19D
0005435824361	1249	39	20B
0005435824353	1249	40	21A
0005433415391	1249	41	21E
0005433415418	1249	42	21F
0005435824185	17977	1	2D
0005435824170	17977	2	5A
0005433415493	17977	3	5D
0005433415499	17977	4	6C
0005435824171	17977	5	8B
0005433415495	17977	6	8D
0005435824183	17977	7	10A
0005433415492	17977	8	11B
0005433415497	17977	9	11E
0005433415496	17977	10	12C
0005435824259	17977	11	12E
0005433415502	17977	12	13C
0005433415494	17977	13	13E
0005433415503	17977	14	14C
0005433415507	17977	15	15D
0005435824168	17977	16	16A
0005433415504	17977	17	16C
0005435824169	17977	18	16E
0005435824184	17977	19	16D
0005433415506	17977	20	17B
0005435824167	17977	21	17A
0005433415498	17977	22	18B
0005433415505	17977	23	18D
0005433415501	17977	24	19F
0005433415508	17977	25	20C
0005433415500	17977	26	20F
0005432783246	5617	1	1A
0005432143954	5617	2	1C
0005432783230	5617	3	1D
0005435476646	5617	4	1F
0005432783244	5617	5	2D
0005432783238	5617	6	3A
0005432783234	5617	7	3F
0005432783250	5617	8	4A
0005432783248	5617	9	4C
0005435476648	5617	10	4D
0005432783271	5617	11	5A
0005432783232	5617	12	4F
0005432783249	5617	13	5C
0005435476645	5617	14	5E
0005432783226	5617	15	6C
0005432783273	5617	16	6D
0005432783243	5617	17	6E
0005432783275	5617	18	6F
0005432783263	5617	19	7A
0005432783276	5617	20	7C
0005432783237	5617	21	7D
0005435242441	5617	22	7E
0005432783269	5617	23	7F
0005432783252	5617	24	8A
0005432143955	5617	25	8C
0005432783265	5617	26	8D
0005435476636	5617	27	8F
0005432783239	5617	28	9A
0005432783259	5617	29	9C
0005432783264	5617	30	9E
0005432783231	5617	31	10A
0005432783236	5617	32	10C
0005432783268	5617	33	10D
0005432783258	5617	34	10F
0005435242387	5617	35	11C
0005432783267	5617	36	11F
0005432783240	5617	37	12A
0005432783254	5617	38	12C
0005435242414	5617	39	12D
0005432783257	5617	40	13A
0005432783229	5617	41	13C
0005432783227	5617	42	13D
0005432783241	5617	43	13F
0005432783235	5617	44	14A
0005432783274	5617	45	14C
0005432783251	5617	46	14D
0005432783233	5617	47	14F
0005432783266	5617	48	15A
0005435242415	5617	49	15C
0005432783277	5617	50	15D
0005432783255	5617	51	15E
0005435242442	5617	52	16C
0005432783272	5617	53	16D
0005432783245	5617	54	16E
0005432783261	5617	55	16F
0005432783260	5617	56	17C
0005432783262	5617	57	17D
0005432783225	5617	58	17E
0005432783278	5617	59	17F
0005432783256	5617	60	18C
0005432783253	5617	61	18E
0005432783228	5617	62	19C
0005435242413	5617	63	19D
0005432783270	5617	64	19E
0005432783242	5617	65	19F
0005432783247	5617	66	20E
0005435242557	15389	1	1A
0005435242565	15389	2	1F
0005435242562	15389	3	2A
0005435242579	15389	4	2D
0005435476694	15389	5	3A
0005435242572	15389	6	3C
0005435476693	15389	7	3D
0005435242558	15389	8	3F
0005435242575	15389	9	4C
0005432782879	15389	10	4E
0005432782904	15389	11	4F
0005435242559	15389	12	5C
0005435476697	15389	13	5D
0005435242566	15389	14	5E
0005435476690	15389	15	6C
0005432782955	15389	16	7A
0005435242573	15389	17	7C
0005435242568	15389	18	7E
0005435242580	15389	19	8C
0005435242563	15389	20	8F
0005435242578	15389	21	9D
0005432782848	15389	22	9E
0005435476692	15389	23	10A
0005435476689	15389	24	10E
0005435476696	15389	25	11A
0005435242564	15389	26	11D
0005435476698	15389	27	11E
0005435476695	15389	28	12A
0005432782880	15389	29	12C
0005435242577	15389	30	12D
0005435242574	15389	31	12E
0005435242570	15389	32	12F
0005432782902	15389	33	13A
0005435242581	15389	34	13C
0005435242554	15389	35	13D
0005435476691	15389	36	13E
0005432782849	15389	37	14C
0005435242556	15389	38	14D
0005435242555	15389	39	14F
0005435242561	15389	40	15A
0005435476699	15389	41	15E
0005432782885	15389	42	16A
0005432782868	15389	43	16E
0005432782911	15389	44	17A
0005432782899	15389	45	19A
0005435242569	15389	46	19C
0005435476700	15389	47	19D
0005435242576	15389	48	19E
0005435242560	15389	49	20C
0005435242567	15389	50	20E
0005435242571	15389	51	20F
0005435850761	4361	1	1C
0005434463906	4361	2	1D
0005432848168	4361	3	2C
0005432848172	4361	4	2D
0005432848160	4361	5	3D
0005435850802	4361	6	5A
0005432848173	4361	7	6A
0005432848164	4361	8	6C
0005432848163	4361	9	6D
0005432848167	4361	10	7B
0005432848162	4361	11	7C
0005432848161	4361	12	7D
0005432848174	4361	13	18A
0005432848159	4361	14	18B
0005432848171	4361	15	19B
0005432848170	4361	16	19C
0005432848166	4361	17	19D
0005432848165	4361	18	20D
0005435850770	4361	19	21A
0005434462769	4361	20	21C
0005434462767	4361	21	22B
0005434463907	4361	22	22C
0005434462768	4361	23	22D
0005432848169	4361	24	23A
0005434463908	4361	25	23B
0005435850817	28858	1	2A
0005435850822	28858	2	2C
0005435850823	28858	3	4D
0005435850820	28858	4	5D
0005435850818	28858	5	6B
0005432848055	28858	6	6C
0005434463891	28858	7	7B
0005435850815	28858	8	18C
0005432848057	28858	9	19D
0005435850816	28858	10	21B
0005435850819	28858	11	21C
0005434463892	28858	12	21D
0005432848056	28858	13	22A
0005435850814	28858	14	22B
0005435850821	28858	15	23A
0005433496667	6320	1	1A
0005434443551	6320	2	1C
0005433496665	6320	3	1D
0005434925491	6320	4	1F
0005434443553	6320	5	2A
0005434925478	6320	6	2C
0005433496674	6320	7	2D
0005434925476	6320	8	3C
0005433496655	6320	9	3D
0005433496661	6320	10	3F
0005434925487	6320	11	4A
0005434925501	6320	12	4C
0005434443544	6320	13	4D
0005434443555	6320	14	4E
0005434443539	6320	15	4F
0005434443548	6320	16	5A
0005434443554	6320	17	5C
0005433496653	6320	18	5E
0005434925483	6320	19	5F
0005434925490	6320	20	6A
0005433496658	6320	21	6C
0005433496673	6320	22	6D
0005434925495	6320	23	6F
0005434443550	6320	24	7A
0005434925474	6320	25	7C
0005434925481	6320	26	7D
0005433496671	6320	27	7E
0005432075196	6320	28	8A
0005434925488	6320	29	8D
0005434443540	6320	30	8E
0005434925500	6320	31	8F
0005433496657	6320	32	9A
0005433496650	6320	33	9C
0005434443541	6320	34	9D
0005434443547	6320	35	9E
0005433496649	6320	36	10D
0005434925475	6320	37	10E
0005433496672	6320	38	10F
0005433496648	6320	39	11A
0005434925486	6320	40	11C
0005433496644	6320	41	11D
0005434443546	6320	42	11E
0005434925480	6320	43	11F
0005433496659	6320	44	12A
0005434925489	6320	45	12D
0005433496642	6320	46	12E
0005433496662	6320	47	13A
0005432075195	6320	48	13C
0005433496651	6320	49	13D
0005433496652	6320	50	13E
0005433496654	6320	51	13F
0005434925482	6320	52	14C
0005434443549	6320	53	14D
0005433496669	6320	54	14E
0005434925494	6320	55	14F
0005433496660	6320	56	15A
0005434925498	6320	57	15C
0005433496664	6320	58	15D
0005434925479	6320	59	15E
0005433496666	6320	60	15F
0005434443552	6320	61	16A
0005433496645	6320	62	16D
0005433496643	6320	63	16E
0005433496656	6320	64	16F
0005433496668	6320	65	17C
0005432075194	6320	66	17E
0005434925493	6320	67	17F
0005433496646	6320	68	18A
0005434925485	6320	69	18C
0005434443542	6320	70	18D
0005434925492	6320	71	18E
0005434925496	6320	72	18F
0005434925477	6320	73	19A
0005433496670	6320	74	19C
0005433496663	6320	75	19D
0005433496647	6320	76	19E
0005434443545	6320	77	19F
0005434925497	6320	78	20A
0005434925484	6320	79	20C
0005434925502	6320	80	20D
0005434443543	6320	81	20E
0005434925499	6320	82	20F
0005434443447	20365	1	1D
0005433496456	20365	2	3D
0005433496461	20365	3	6A
0005433496526	20365	4	6D
0005433496428	20365	5	6E
0005433496567	20365	6	6F
0005433496427	20365	7	8F
0005433496513	20365	8	9A
0005433496502	20365	9	11D
0005433496435	20365	10	11F
0005433496430	20365	11	13A
0005433496462	20365	12	13F
0005433496431	20365	13	14F
0005433496460	20365	14	15F
0005433496459	20365	15	18A
0005435242601	12193	1	1C
0005432782992	12193	2	2A
0005432782843	12193	3	2D
0005435242609	12193	4	3A
0005435242600	12193	5	3D
0005432783044	12193	6	4C
0005435242603	12193	7	4D
0005432782942	12193	8	4E
0005432782871	12193	9	5C
0005435242604	12193	10	6A
0005435242586	12193	11	6D
0005435242592	12193	12	6E
0005432782901	12193	13	7C
0005435242582	12193	14	7D
0005432782883	12193	15	7E
0005432782919	12193	16	7F
0005435242589	12193	17	8A
0005432783090	12193	18	8D
0005432783011	12193	19	9C
0005435242584	12193	20	9D
0005435242605	12193	21	10A
0005435242594	12193	22	10C
0005435242596	12193	23	10D
0005432782900	12193	24	10E
0005432783091	12193	25	11A
0005432783010	12193	26	11C
0005435242590	12193	27	11D
0005432783009	12193	28	11E
0005435242610	12193	29	12A
0005432782938	12193	30	12C
0005435242607	12193	31	13A
0005435242593	12193	32	13C
0005432782898	12193	33	13D
0005435242585	12193	34	14A
0005435242598	12193	35	14D
0005432782990	12193	36	14E
0005435242606	12193	37	15E
0005435242588	12193	38	16A
0005435242599	12193	39	16C
0005435242583	12193	40	16E
0005432782991	12193	41	17A
0005432782968	12193	42	17C
0005435242595	12193	43	17D
0005435242602	12193	44	17E
0005432782905	12193	45	18A
0005435242608	12193	46	18C
0005435242597	12193	47	18D
0005432782845	12193	48	18F
0005432783045	12193	49	19C
0005432782874	12193	50	19D
0005435242591	12193	51	19E
0005432783092	12193	52	19F
0005432782840	12193	53	20A
0005432782967	12193	54	20D
0005435242587	12193	55	20E
0005432783201	15407	1	1A
0005432783212	15407	2	1F
0005432783189	15407	3	2A
0005432783172	15407	4	2C
0005432783176	15407	5	2D
0005432783199	15407	6	3A
0005432783182	15407	7	3D
0005432783180	15407	8	3F
0005432783179	15407	9	4A
0005432783222	15407	10	4C
0005432783183	15407	11	4E
0005432783211	15407	12	5A
0005432783181	15407	13	5C
0005432783213	15407	14	6C
0005432783208	15407	15	6D
0005432783198	15407	16	6E
0005432783173	15407	17	7D
0005432783174	15407	18	7E
0005432783217	15407	19	7F
0005432783197	15407	20	8A
0005432783223	15407	21	8D
0005432783178	15407	22	8E
0005432783203	15407	23	9C
0005432783186	15407	24	9D
0005432783188	15407	25	9E
0005432783206	15407	26	10A
0005432783196	15407	27	10C
0005432783200	15407	28	10D
0005432783218	15407	29	10E
0005432783210	15407	30	11C
0005432783219	15407	31	11E
0005432783216	15407	32	11F
0005432783177	15407	33	12A
0005432783184	15407	34	12C
0005432783214	15407	35	12E
0005432783224	15407	36	13A
0005432783195	15407	37	13C
0005432783175	15407	38	13E
0005432783194	15407	39	13F
0005432783193	15407	40	14D
0005432783204	15407	41	14F
0005432783215	15407	42	15C
0005432783190	15407	43	15E
0005432783170	15407	44	15F
0005432783169	15407	45	16A
0005432783187	15407	46	16C
0005432783192	15407	47	16D
0005432783221	15407	48	16F
0005432783191	15407	49	17A
0005432783207	15407	50	17C
0005432783209	15407	51	18C
0005432783171	15407	52	18E
0005432783205	15407	53	19E
0005432783220	15407	54	20A
0005432783202	15407	55	20C
0005432783185	15407	56	20F
0005435913899	10099	1	2D
0005434876616	10099	2	3A
0005434876936	10099	3	3D
0005434876667	10099	4	3F
0005434876612	10099	5	4C
0005435913894	10099	6	4F
0005434876759	10099	7	5C
0005434876825	10099	8	6B
0005434876817	10099	9	6D
0005434876826	10099	10	7C
0005434876668	10099	11	7B
0005434876761	10099	12	7E
0005434876669	10099	13	8D
0005434876760	10099	14	8C
0005435913895	10099	15	9A
0005434876722	10099	16	9B
0005434876563	10099	17	9E
0005434876564	10099	18	10A
0005434876670	10099	19	10B
0005435913896	10099	20	10E
0005434910086	10099	21	10D
0005435913900	10099	22	11B
0005434876614	10099	23	11F
0005434876572	10099	24	12B
0005434876688	10099	25	12A
0005434876621	10099	26	12C
0005434876675	10099	27	12F
0005434876615	10099	28	13A
0005434876645	10099	29	14D
0005434876671	10099	30	14C
0005434910084	10099	31	14E
0005434876820	10099	32	15C
0005435913898	10099	33	15F
0005434876674	10099	34	16C
0005434876583	10099	35	16D
0005434910085	10099	36	17A
0005434910087	10099	37	17F
0005434876704	10099	38	18C
0005434876607	10099	39	18E
0005434876672	10099	40	18D
0005434876656	10099	41	19A
0005434876646	10099	42	19C
0005434876703	10099	43	19B
0005434876752	10099	44	19E
0005434876673	10099	45	19D
0005435913897	10099	46	19F
0005435913893	10099	47	20A
0005434876620	10099	48	20F
0005434876819	10099	49	21A
0005434876909	10099	50	21C
0005434876585	10099	51	21F
0005434877323	14640	1	1C
0005434877301	14640	2	1A
0005434877305	14640	3	1D
0005434758868	14640	4	2A
0005434877256	14640	5	1F
0005434877282	14640	6	2D
0005434877279	14640	7	2C
0005434877239	14640	8	2F
0005434877311	14640	9	3C
0005434877250	14640	10	3F
0005434877308	14640	11	4D
0005434877288	14640	12	5A
0005434877278	14640	13	4F
0005434877266	14640	14	5D
0005434877307	14640	15	5C
0005434877254	14640	16	5F
0005434877289	14640	17	6B
0005434877300	14640	18	6A
0005434877303	14640	19	6D
0005434877317	14640	20	6C
0005434877294	14640	21	6F
0005434877235	14640	22	6E
0005434877242	14640	23	7A
0005434877314	14640	24	7C
0005434877281	14640	25	7B
0005434877260	14640	26	7E
0005434877268	14640	27	7D
0005434877269	14640	28	8A
0005434877290	14640	29	8B
0005434877247	14640	30	8D
0005434877262	14640	31	8F
0005434758870	14640	32	8E
0005434877241	14640	33	9B
0005434877284	14640	34	9A
0005434877275	14640	35	9D
0005434758871	14640	36	9C
0005434877330	14640	37	9E
0005434877291	14640	38	10A
0005434877295	14640	39	9F
0005434877309	14640	40	10C
0005434877306	14640	41	10E
0005434877249	14640	42	10D
0005434877302	14640	43	11A
0005434877313	14640	44	10F
0005434877299	14640	45	11D
0005434877245	14640	46	11C
0005434877236	14640	47	11F
0005434877324	14640	48	12A
0005434877312	14640	49	12D
0005434877271	14640	50	12C
0005434877321	14640	51	12B
0005434877327	14640	52	12F
0005434758869	14640	53	12E
0005434877258	14640	54	13A
0005434877320	14640	55	13C
0005434877246	14640	56	13B
0005434877255	14640	57	13E
0005434877259	14640	58	13D
0005434877257	14640	59	14A
0005434877273	14640	60	13F
0005434877276	14640	61	14B
0005434877310	14640	62	14D
0005434877293	14640	63	14C
0005434877316	14640	64	14F
0005434877243	14640	65	15B
0005434877244	14640	66	15A
0005434877270	14640	67	15D
0005434877252	14640	68	15C
0005434877265	14640	69	15E
0005434877277	14640	70	16A
0005434877315	14640	71	15F
0005434877274	14640	72	16C
0005434877283	14640	73	16B
0005434877292	14640	74	16D
0005434877263	14640	75	16F
0005434877264	14640	76	17B
0005434877272	14640	77	17A
0005434877326	14640	78	17D
0005434877318	14640	79	17F
0005434877286	14640	80	17E
0005434877237	14640	81	18A
0005434877238	14640	82	18C
0005434877253	14640	83	18B
0005434877285	14640	84	18E
0005434877248	14640	85	18D
0005434877328	14640	86	19A
0005434877329	14640	87	18F
0005434877298	14640	88	19C
0005434877261	14640	89	19B
0005434877280	14640	90	19E
0005434877296	14640	91	19D
0005434877251	14640	92	19F
0005434877287	14640	93	20B
0005434877267	14640	94	20A
0005434877322	14640	95	20D
0005434877297	14640	96	20F
0005434877304	14640	97	21A
0005434877325	14640	98	21C
0005434877319	14640	99	21E
0005434877240	14640	100	21F
0005435660026	9218	1	1B
0005435660022	9218	2	3A
0005434251803	9218	3	3C
0005434251802	9218	4	3D
0005435660023	9218	5	4A
0005435660021	9218	6	4C
0005435660027	9218	7	5D
0005435660019	9218	8	6C
0005435660028	9218	9	6D
0005435660020	9218	10	19B
0005435660025	9218	11	19C
0005435660024	9218	12	20B
0005435660017	9218	13	21C
0005435660018	9218	14	22B
0005435659947	24637	1	1C
0005435659938	24637	2	2A
0005434251864	24637	3	2B
0005434251866	24637	4	2D
0005434251865	24637	5	3C
0005434251872	24637	6	4A
0005435659939	24637	7	4D
0005435659940	24637	8	5D
0005435659952	24637	9	5C
0005434251868	24637	10	6A
0005435659955	24637	11	6D
0005435659937	24637	12	7A
0005435659953	24637	13	7D
0005434251870	24637	14	18D
0005434251863	24637	15	19A
0005434251871	24637	16	20A
0005434251869	24637	17	20D
0005435659948	24637	18	21B
0005435659956	24637	19	21C
0005434251867	24637	20	23B
0005433680081	2785	1	1D
0005432966502	2785	2	1F
0005433680075	2785	3	2A
0005433680079	2785	4	2D
0005433680062	2785	5	2F
0005433680072	2785	6	3A
0005432222727	2785	7	3D
0005432966479	2785	8	4A
0005433680068	2785	9	4C
0005433684397	2785	10	5A
0005432966522	2785	11	5E
0005432966523	2785	12	5F
0005433680069	2785	13	6A
0005433680067	2785	14	6E
0005432222726	2785	15	6F
0005433680093	2785	16	7A
0005433680089	2785	17	7C
0005433680092	2785	18	7D
0005432966514	2785	19	7E
0005432966576	2785	20	7F
0005433680096	2785	21	8A
0005432222728	2785	22	8F
0005433680074	2785	23	9A
0005433680078	2785	24	9C
0005433680087	2785	25	9D
0005432966621	2785	26	9E
0005433680086	2785	27	9F
0005433680099	2785	28	10A
0005433680073	2785	29	10C
0005433680080	2785	30	10D
0005432966551	2785	31	10F
0005433680088	2785	32	11A
0005433680053	2785	33	11D
0005433680071	2785	34	11E
0005433680083	2785	35	11F
0005432966491	2785	36	12A
0005433680061	2785	37	12E
0005433680064	2785	38	12F
0005433680055	2785	39	13A
0005433680070	2785	40	13C
0005432966499	2785	41	13D
0005433680082	2785	42	13E
0005433684398	2785	43	13F
0005433680084	2785	44	14C
0005433680077	2785	45	14D
0005433680052	2785	46	14E
0005433680066	2785	47	14F
0005432966620	2785	48	15A
0005433680097	2785	49	15C
0005433680054	2785	50	15D
0005432222730	2785	51	15E
0005433680060	2785	52	16A
0005433680085	2785	53	16C
0005433680091	2785	54	17A
0005432966515	2785	55	17C
0005433680095	2785	56	17E
0005433680076	2785	57	18A
0005433680056	2785	58	18C
0005432222729	2785	59	18D
0005433680065	2785	60	19A
0005433680057	2785	61	19C
0005433680059	2785	62	19D
0005433680098	2785	63	19F
0005433680058	2785	64	20A
0005433680063	2785	65	20C
0005433680090	2785	66	20E
0005433680094	2785	67	20F
0005433679883	29193	1	1C
0005432966677	29193	2	2C
0005432966685	29193	3	2F
0005433679912	29193	4	3C
0005432966672	29193	5	3D
0005432005184	29193	6	4A
0005432966681	29193	7	4C
0005433679717	29193	8	4F
0005432966665	29193	9	5C
0005433684384	29193	10	5E
0005432966663	29193	11	6A
0005432966686	29193	12	6D
0005432966675	29193	13	6F
0005433679727	29193	14	7C
0005433679932	29193	15	7F
0005433679891	29193	16	8A
0005433679808	29193	17	8C
0005433679807	29193	18	8E
0005432966668	29193	19	8F
0005432966680	29193	20	9D
0005432966682	29193	21	9F
0005432966684	29193	22	10A
0005433679830	29193	23	10D
0005432966664	29193	24	11D
0005432966667	29193	25	12C
0005433684385	29193	26	12F
0005432966683	29193	27	13C
0005433679743	29193	28	14E
0005432966673	29193	29	14D
0005432966676	29193	30	14F
0005432966666	29193	31	15F
0005432966669	29193	32	16A
0005432005185	29193	33	16C
0005432966671	29193	34	16D
0005433679742	29193	35	17C
0005432966679	29193	36	17E
0005432966687	29193	37	17F
0005432966678	29193	38	18C
0005432966670	29193	39	18F
0005432966674	29193	40	19A
0005433679906	29193	41	20A
0005433679913	29193	42	20D
0005433679739	29193	43	20F
0005433633456	9308	1	1A
0005433633448	9308	2	1C
0005433633428	9308	3	1D
0005433613857	9308	4	1F
0005433613881	9308	5	2C
0005433613891	9308	6	2F
0005433633450	9308	7	2D
0005433613887	9308	8	3A
0005433613842	9308	9	4A
0005433633454	9308	10	4C
0005433577666	9308	11	4F
0005433633436	9308	12	5A
0005433613856	9308	13	5D
0005433613885	9308	14	5C
0005433633440	9308	15	5F
0005433613906	9308	16	6A
0005433633444	9308	17	6F
0005433613876	9308	18	6D
0005433613848	9308	19	7A
0005433613902	9308	20	7C
0005433613908	9308	21	7D
0005433613864	9308	22	8A
0005433613869	9308	23	7F
0005433613866	9308	24	8B
0005432756811	9308	25	8C
0005433613843	9308	26	8E
0005433613845	9308	27	8D
0005433613898	9308	28	8F
0005433613840	9308	29	9C
0005433633449	9308	30	9B
0005433633441	9308	31	9D
0005433613903	9308	32	9E
0005433633445	9308	33	10A
0005433613850	9308	34	9F
0005433613836	9308	35	10C
0005433613880	9308	36	10B
0005433613846	9308	37	10D
0005433577661	9308	38	10F
0005433633434	9308	39	10E
0005433613872	9308	40	11B
0005432145089	9308	41	11A
0005433633427	9308	42	11C
0005433633452	9308	43	11D
0005433577662	9308	44	11E
0005433613847	9308	45	12A
0005433633435	9308	46	12C
0005433633430	9308	47	12E
0005433633424	9308	48	12D
0005434163485	9308	49	13A
0005433613901	9308	50	13C
0005433633455	9308	51	13B
0005433613841	9308	52	13D
0005433613894	9308	53	14A
0005432145090	9308	54	13F
0005432145088	9308	55	14B
0005433613882	9308	56	14D
0005433613888	9308	57	14C
0005433633425	9308	58	14E
0005433613859	9308	59	14F
0005433613904	9308	60	15B
0005432756812	9308	61	15A
0005433613851	9308	62	15C
0005433613895	9308	63	15E
0005433633433	9308	64	16A
0005433613889	9308	65	15F
0005433613907	9308	66	16B
0005432756813	9308	67	16D
0005433613844	9308	68	16C
0005433633453	9308	69	16E
0005433613837	9308	70	16F
0005433577659	9308	71	17B
0005434163492	9308	72	17D
0005433613868	9308	73	17E
0005433613905	9308	74	18A
0005433613865	9308	75	17F
0005432755041	9308	76	18D
0005433613899	9308	77	18C
0005433633443	9308	78	18E
0005433577660	9308	79	18F
0005433633429	9308	80	19C
0005434163493	9308	81	19D
0005433613863	9308	82	20B
0005433633437	9308	83	20A
0005433577667	9308	84	20C
0005433613854	9308	85	20D
0005432755042	9308	86	20F
0005433613884	9308	87	20E
0005433613893	9308	88	21A
0005433577665	9308	89	21C
0005433633432	9308	90	21D
0005433613849	9308	91	21F
0005433577670	9308	92	21E
0005433613870	9308	93	22A
0005433633422	9308	94	22C
0005433613838	9308	95	22D
0005433613877	9308	96	22F
0005433613897	9308	97	22E
0005433613860	9308	98	23B
0005433613875	9308	99	23A
0005433613900	9308	100	23D
0005433633442	9308	101	23C
0005433613874	9308	102	23E
0005433633439	9308	103	23F
0005433613852	9308	104	24B
0005433613883	9308	105	24A
0005432756814	9308	106	24C
0005433613858	9308	107	24D
0005433577663	9308	108	24F
0005433577668	9308	109	25B
0005433613890	9308	110	25A
0005432755039	9308	111	25C
0005433613892	9308	112	26A
0005433613861	9308	113	25F
0005433613853	9308	114	26C
0005433613855	9308	115	26B
0005433613886	9308	116	27A
0005434272167	9308	117	27D
0005433633447	9308	118	27E
0005433577669	9308	119	28A
0005433613896	9308	120	28C
0005432755040	9308	121	28B
0005433633426	9308	122	28D
0005433577664	9308	123	28E
0005433613878	9308	124	29A
0005433633431	9308	125	29E
0005433613879	9308	126	29D
0005433633423	9308	127	29F
0005433613867	9308	128	30A
0005433613871	9308	129	30B
0005433613835	9308	130	30C
0005433613862	9308	131	30D
0005433613839	9308	132	30F
0005433633438	9308	133	30E
0005433633451	9308	134	31C
0005433613873	9308	135	31B
0005433613909	9308	136	31D
0005433633446	9308	137	31F
0005433613477	25263	1	2A
0005433633289	25263	2	2F
0005434152767	25263	3	5C
0005433633272	25263	4	5D
0005434152770	25263	5	6F
0005433577630	25263	6	7C
0005433613418	25263	7	8B
0005434152762	25263	8	10B
0005434152761	25263	9	11C
0005433613703	25263	10	12A
0005432755018	25263	11	12C
0005433613423	25263	12	12E
0005433633296	25263	13	12F
0005433613426	25263	14	13F
0005433633314	25263	15	14D
0005434152768	25263	16	14C
0005433613427	25263	17	15C
0005433577574	25263	18	15B
0005434152769	25263	19	16D
0005434163525	25263	20	17A
0005433577632	25263	21	17E
0005434152771	25263	22	18A
0005433577631	25263	23	19C
0005433633315	25263	24	19E
0005433613386	25263	25	20A
0005434152764	25263	26	21B
0005433577561	25263	27	22A
0005434152760	25263	28	24D
0005432755019	25263	29	25D
0005433577576	25263	30	26C
0005433577575	25263	31	27A
0005433633295	25263	32	27C
0005434152765	25263	33	27D
0005434152763	25263	34	30C
0005434152766	25263	35	30E
0005433613387	25263	36	30F
0005432184921	4238	1	1G
0005435986694	4238	2	4A
0005435947010	4238	3	4G
0005435986703	4238	4	11A
0005435986701	4238	5	13B
0005435986700	4238	6	13D
0005435947033	4238	7	14F
0005435986702	4238	8	14G
0005435986699	4238	9	16D
0005435986696	4238	10	16G
0005435947041	4238	11	20F
0005435947039	4238	12	21E
0005435947040	4238	13	24G
0005435856143	4238	14	27H
0005435947015	4238	15	28E
0005435947042	4238	16	28F
0005435986695	4238	17	30B
0005435986698	4238	18	31E
0005432184922	4238	19	32B
0005435986697	4238	20	34G
0005435947011	4238	21	38E
0005435947109	26585	1	1A
0005435947108	26585	2	1B
0005435787332	26585	3	3H
0005435856162	26585	4	4G
0005435947104	26585	5	9G
0005435856161	26585	6	12G
0005435947114	26585	7	14H
0005435856165	26585	8	17F
0005435856160	26585	9	21G
0005435947102	26585	10	22A
0005435856163	26585	11	22G
0005432571287	26585	12	22H
0005435787333	26585	13	23A
0005432571285	26585	14	24A
0005435947112	26585	15	24H
0005435947110	26585	16	27B
0005435947103	26585	17	27A
0005435986651	26585	18	27E
0005435947106	26585	19	28E
0005435947113	26585	20	29D
0005435856164	26585	21	32A
0005435947107	26585	22	32F
0005435986652	26585	23	32E
0005432571284	26585	24	34G
0005435947105	26585	25	35H
0005435947111	26585	26	36D
0005432571286	26585	27	38D
0005435986658	26585	28	39E
0005433568426	326	1	1A
0005433568451	326	2	2D
0005433568442	326	3	3C
0005433074266	326	4	3F
0005433568463	326	5	4A
0005433568436	326	6	5A
0005433074229	326	7	5C
0005433568457	326	8	5D
0005433568469	326	9	6F
0005433568448	326	10	6D
0005433074250	326	11	7D
0005432238875	326	12	8A
0005433568435	326	13	8D
0005433568475	326	14	9B
0005433568445	326	15	9A
0005432238872	326	16	10A
0005433568473	326	17	10F
0005432238874	326	18	10E
0005433568471	326	19	11B
0005432947776	326	20	11A
0005433568459	326	21	11C
0005433568431	326	22	11D
0005432238871	326	23	12A
0005433568432	326	24	11F
0005432238873	326	25	12C
0005432947796	326	26	12E
0005432947775	326	27	12F
0005433568428	326	28	13C
0005433568441	326	29	15C
0005433568444	326	30	15B
0005433074267	326	31	15F
0005433568447	326	32	16A
0005433134065	326	33	16B
0005433568455	326	34	16C
0005432238876	326	35	16E
0005432947764	326	36	16F
0005433568437	326	37	17D
0005433568430	326	38	17F
0005433568450	326	39	18B
0005433568476	326	40	18D
0005433568440	326	41	18C
0005433568446	326	42	18F
0005433568467	326	43	19C
0005433568456	326	44	20B
0005433568461	326	45	20F
0005433568439	326	46	21B
0005433568462	326	47	21A
0005433568472	326	48	21C
0005433568449	326	49	21D
0005433568434	326	50	21E
0005433568424	326	51	22A
0005433568427	326	52	22E
0005433568468	326	53	22F
0005433568464	326	54	23B
0005433568477	326	55	23D
0005432947797	326	56	24B
0005433568443	326	57	24A
0005433568425	326	58	24D
0005433074249	326	59	24E
0005433568429	326	60	25B
0005433568433	326	61	25F
0005433568454	326	62	25E
0005433568465	326	63	26A
0005433568460	326	64	26F
0005433568470	326	65	27A
0005433568466	326	66	27F
0005433568452	326	67	28E
0005433074330	326	68	29B
0005433568423	326	69	29C
0005433568438	326	70	29F
0005433568458	326	71	30B
0005433074248	326	72	30A
0005433074263	326	73	30F
0005433568453	326	74	31C
0005433568474	326	75	31D
0005432948039	11581	1	1C
0005432192286	11581	2	1D
0005433074425	11581	3	2F
0005432948053	11581	4	3F
0005432948020	11581	5	3D
0005432948025	11581	6	4C
0005433134092	11581	7	4F
0005433131660	11581	8	4D
0005432948036	11581	9	5A
0005432948042	11581	10	5C
0005432948033	11581	11	5D
0005432948052	11581	12	6A
0005432192288	11581	13	6D
0005432948051	11581	14	6C
0005432948017	11581	15	6F
0005432948028	11581	16	7A
0005433074404	11581	17	7C
0005432948024	11581	18	7D
0005432948015	11581	19	8E
0005432948021	11581	20	9A
0005433134093	11581	21	9C
0005433134091	11581	22	9B
0005432948044	11581	23	9D
0005432948019	11581	24	10B
0005433134094	11581	25	10D
0005433074423	11581	26	10E
0005433074430	11581	27	11C
0005433074429	11581	28	11D
0005433134090	11581	29	11E
0005432948047	11581	30	11F
0005433074411	11581	31	12F
0005433074418	11581	32	14C
0005432948054	11581	33	15A
0005433074408	11581	34	14F
0005432948034	11581	35	15B
0005432948041	11581	36	15C
0005432948022	11581	37	15F
0005432948050	11581	38	16A
0005433074407	11581	39	17C
0005432948030	11581	40	17D
0005433074417	11581	41	18B
0005433074401	11581	42	18D
0005432948016	11581	43	18C
0005433074409	11581	44	18F
0005433074412	11581	45	19C
0005433131662	11581	46	20B
0005432948049	11581	47	20C
0005432948043	11581	48	21B
0005432948035	11581	49	21A
0005432948037	11581	50	21C
0005433074415	11581	51	21D
0005433074414	11581	52	22A
0005432948018	11581	53	21F
0005433074421	11581	54	22B
0005433074410	11581	55	22C
0005432192287	11581	56	22E
0005433074427	11581	57	22F
0005432948026	11581	58	23A
0005433074403	11581	59	23E
0005432192289	11581	60	24B
0005432948046	11581	61	24F
0005432948045	11581	62	25A
0005433131661	11581	63	25F
0005433134089	11581	64	26A
0005432948031	11581	65	26B
0005433074419	11581	66	26D
0005432948048	11581	67	26C
0005432948013	11581	68	26E
0005433074402	11581	69	26F
0005433074405	11581	70	27A
0005432948027	11581	71	27C
0005433074422	11581	72	27B
0005433074420	11581	73	28A
0005432948032	11581	74	27F
0005432948040	11581	75	28B
0005432948014	11581	76	29A
0005433074426	11581	77	28F
0005433074413	11581	78	29C
0005433074424	11581	79	29D
0005432948023	11581	80	29E
0005433074406	11581	81	29F
0005433074428	11581	82	30B
0005432948029	11581	83	30C
0005432948038	11581	84	31B
0005433074416	11581	85	31C
0005434732918	9949	1	1A
0005433817432	9949	2	3A
0005433817434	9949	3	4B
0005433817431	9949	4	5A
0005434732920	9949	5	6A
0005434732919	9949	6	5B
0005433817433	9949	7	6B
0005434732946	13995	1	4A
0005433817418	13995	2	5A
0005434732945	13995	3	4B
0005433753681	2362	1	1A
0005433434194	2362	2	1C
0005435981877	2362	3	1B
0005433434184	2362	4	1F
0005433753674	2362	5	1H
0005433766600	2362	6	1G
0005435981875	2362	7	2B
0005435981884	2362	8	2F
0005433753648	2362	9	2G
0005432300205	2362	10	3A
0005435981885	2362	11	3B
0005432655419	2362	12	3C
0005435981858	2362	13	3G
0005433434209	2362	14	3F
0005433753624	2362	15	3H
0005433753654	2362	16	4B
0005435981865	2362	17	4A
0005433753658	2362	18	4F
0005435981862	2362	19	4G
0005433434252	2362	20	4H
0005432225995	2362	21	5A
0005433434196	2362	22	5C
0005432655416	2362	23	5G
0005432225991	2362	24	5F
0005435981874	2362	25	9B
0005433753675	2362	26	9A
0005432984514	2362	27	9H
0005433766602	2362	28	11B
0005433753641	2362	29	11E
0005435981871	2362	30	11D
0005435981850	2362	31	11F
0005433753656	2362	32	11H
0005433764659	2362	33	11G
0005433434210	2362	34	12A
0005435981846	2362	35	12D
0005433434180	2362	36	12B
0005433753667	2362	37	12E
0005435981872	2362	38	12G
0005435981845	2362	39	12F
0005433753652	2362	40	13D
0005433753670	2362	41	13E
0005432655414	2362	42	13G
0005435981873	2362	43	14B
0005435981879	2362	44	14A
0005433434203	2362	45	14E
0005435981843	2362	46	14D
0005432984518	2362	47	14F
0005432984576	2362	48	14H
0005433434191	2362	49	14G
0005433434181	2362	50	15A
0005432655418	2362	51	15D
0005435981867	2362	52	15E
0005433753651	2362	53	15G
0005435981870	2362	54	15F
0005432984513	2362	55	16A
0005432300204	2362	56	15H
0005433753636	2362	57	16B
0005433753645	2362	58	16D
0005435981888	2362	59	16F
0005435981880	2362	60	16H
0005433753628	2362	61	17D
0005435981878	2362	62	17B
0005435981876	2362	63	17E
0005433434186	2362	64	17G
0005433753637	2362	65	17F
0005433753649	2362	66	17H
0005433753671	2362	67	18A
0005435981854	2362	68	18F
0005433753631	2362	69	18E
0005435981857	2362	70	18G
0005433753638	2362	71	19A
0005433753632	2362	72	18H
0005433753669	2362	73	19D
0005433753664	2362	74	19F
0005435981844	2362	75	19E
0005432655420	2362	76	19H
0005433753672	2362	77	19G
0005433753646	2362	78	20B
0005433434185	2362	79	20D
0005435981856	2362	80	20H
0005432984578	2362	81	20G
0005432655412	2362	82	21D
0005433753660	2362	83	21G
0005432984549	2362	84	21H
0005432984599	2362	85	22D
0005433753642	2362	86	22G
0005433753673	2362	87	22F
0005435981859	2362	88	23A
0005433434202	2362	89	23F
0005433753680	2362	90	23E
0005432225996	2362	91	23G
0005435981868	2362	92	23H
0005435981886	2362	93	24B
0005432300203	2362	94	24A
0005432225994	2362	95	24E
0005435981864	2362	96	24G
0005433753662	2362	97	24H
0005435981881	2362	98	25F
0005432655415	2362	99	25E
0005433753639	2362	100	25D
0005433434195	2362	101	27A
0005433753625	2362	102	27B
0005435981855	2362	103	27F
0005433753661	2362	104	27E
0005433434187	2362	105	28A
0005433753663	2362	106	28B
0005432655417	2362	107	28E
0005435981866	2362	108	28D
0005433753655	2362	109	28G
0005433753640	2362	110	28F
0005433766601	2362	111	28H
0005435981887	2362	112	29A
0005435981851	2362	113	29D
0005433753668	2362	114	29F
0005433753633	2362	115	29E
0005435981847	2362	116	29G
0005432225993	2362	117	29H
0005435981852	2362	118	30A
0005433753657	2362	119	30D
0005433753650	2362	120	30F
0005433764658	2362	121	30E
0005433753666	2362	122	30H
0005435981849	2362	123	31B
0005433753634	2362	124	31D
0005432984543	2362	125	31H
0005433434190	2362	126	31G
0005432984542	2362	127	32D
0005432655421	2362	128	32F
0005433753626	2362	129	32H
0005435981848	2362	130	32G
0005433753677	2362	131	33B
0005433753647	2362	132	33E
0005432655422	2362	133	33F
0005433753676	2362	134	33H
0005432984577	2362	135	33G
0005435981882	2362	136	34B
0005432655413	2362	137	34A
0005432300207	2362	138	34E
0005435981883	2362	139	34G
0005435981853	2362	140	35A
0005433753644	2362	141	34H
0005435981863	2362	142	35B
0005435981860	2362	143	35D
0005433753679	2362	144	35E
0005433753630	2362	145	35H
0005433753678	2362	146	35G
0005432655411	2362	147	36B
0005435981861	2362	148	36D
0005435981869	2362	149	36F
0005433753629	2362	150	37A
0005433753643	2362	151	36H
0005432225992	2362	152	37D
0005433753635	2362	153	37F
0005432300206	2362	154	37G
0005433753653	2362	155	38A
0005433753659	2362	156	38D
0005435981842	2362	157	38E
0005433753665	2362	158	38H
0005432984564	2362	159	39D
0005433753627	2362	160	39F
0005433766599	2362	161	39E
0005432984759	26207	1	1B
0005432984733	26207	2	1C
0005433753254	26207	3	2F
0005432984761	26207	4	2C
0005433434399	26207	5	3A
0005432869454	26207	6	2H
0005432984740	26207	7	3B
0005433434396	26207	8	3C
0005433753308	26207	9	3H
0005433434393	26207	10	4C
0005434731127	26207	11	4G
0005432984760	26207	12	5B
0005432984737	26207	13	5G
0005432869453	26207	14	5F
0005435981534	26207	15	5H
0005435981517	26207	16	9B
0005433753300	26207	17	9G
0005432984747	26207	18	11B
0005433753272	26207	19	11E
0005434731126	26207	20	11G
0005433434390	26207	21	11F
0005432984749	26207	22	11H
0005433434384	26207	23	12E
0005433753340	26207	24	12G
0005432984735	26207	25	13B
0005433753269	26207	26	13D
0005432984763	26207	27	14E
0005435981510	26207	28	14D
0005433753229	26207	29	14G
0005432984742	26207	30	15A
0005432984754	26207	31	15G
0005433753270	26207	32	15H
0005433434385	26207	33	16D
0005432984762	26207	34	16F
0005433434395	26207	35	16E
0005433434409	26207	36	16H
0005433434405	26207	37	16G
0005435981605	26207	38	17G
0005432869458	26207	39	17H
0005432984765	26207	40	18E
0005433434401	26207	41	18D
0005433753372	26207	42	18F
0005434731129	26207	43	19A
0005433434382	26207	44	18H
0005432869452	26207	45	19D
0005433434400	26207	46	19B
0005433434397	26207	47	19E
0005433434387	26207	48	19F
0005435981604	26207	49	19H
0005435981513	26207	50	20B
0005433434389	26207	51	20D
0005433753315	26207	52	20F
0005432984744	26207	53	20H
0005435981536	26207	54	20G
0005433764646	26207	55	21A
0005433434386	26207	56	21E
0005433753255	26207	57	22B
0005433434383	26207	58	22A
0005432984758	26207	59	22D
0005432984738	26207	60	22G
0005433434406	26207	61	22H
0005432984732	26207	62	23A
0005433434398	26207	63	23E
0005432984748	26207	64	23G
0005432984753	26207	65	24B
0005432984750	26207	66	24A
0005432984743	26207	67	24F
0005433434408	26207	68	24E
0005432049426	26207	69	25D
0005432984757	26207	70	24H
0005433753228	26207	71	27A
0005432051095	26207	72	25F
0005435981545	26207	73	27B
0005432984739	26207	74	27E
0005432984741	26207	75	27D
0005432984736	26207	76	27F
0005433434402	26207	77	27G
0005433753271	26207	78	27H
0005435981511	26207	79	28B
0005433434381	26207	80	28D
0005433434404	26207	81	28H
0005432051097	26207	82	28G
0005435981691	26207	83	29D
0005433753273	26207	84	29B
0005432984752	26207	85	29F
0005433753256	26207	86	30E
0005433434388	26207	87	30D
0005432984764	26207	88	30F
0005432984751	26207	89	31G
0005432051096	26207	90	32B
0005432869451	26207	91	32E
0005432984734	26207	92	32D
0005433753223	26207	93	32F
0005433764645	26207	94	32G
0005433753309	26207	95	33E
0005433753268	26207	96	33H
0005433753454	26207	97	34B
0005432869457	26207	98	34D
0005432049427	26207	99	34G
0005434731128	26207	100	34F
0005433434403	26207	101	35A
0005432049429	26207	102	35F
0005432049428	26207	103	36A
0005432984745	26207	104	35H
0005435981586	26207	105	36B
0005433434394	26207	106	36D
0005432869455	26207	107	36G
0005432984746	26207	108	37F
0005433434392	26207	109	37H
0005432984756	26207	110	38A
0005433753453	26207	111	38E
0005432984755	26207	112	38G
0005432869456	26207	113	38H
0005433434391	26207	114	39E
0005433434407	26207	115	39D
0005434374194	1518	1	1A
0005433150861	1518	2	1D
0005433461565	1518	3	1F
0005434374163	1518	4	2D
0005433150815	1518	5	3A
0005433150860	1518	6	2F
0005434374164	1518	7	4C
0005434374182	1518	8	4E
0005434374179	1518	9	4F
0005434374169	1518	10	5A
0005432267826	1518	11	5D
0005433150854	1518	12	5C
0005433150801	1518	13	5E
0005433150828	1518	14	6B
0005434374167	1518	15	6E
0005434374195	1518	16	6D
0005434374178	1518	17	6F
0005433150963	1518	18	7C
0005434374196	1518	19	7B
0005434374189	1518	20	7D
0005434374191	1518	21	7F
0005434374185	1518	22	8C
0005433150964	1518	23	8E
0005433150802	1518	24	8D
0005433461566	1518	25	8F
0005432267830	1518	26	9A
0005433150809	1518	27	9B
0005434374193	1518	28	9D
0005433150837	1518	29	10B
0005434374183	1518	30	10D
0005434374168	1518	31	11A
0005434374165	1518	32	11B
0005433150864	1518	33	11C
0005434374181	1518	34	12A
0005433150865	1518	35	12C
0005434374180	1518	36	12B
0005434374162	1518	37	12E
0005433150914	1518	38	12F
0005433150866	1518	39	13A
0005434374173	1518	40	13B
0005434374171	1518	41	13D
0005434374172	1518	42	14B
0005433150867	1518	43	14A
0005433150859	1518	44	14D
0005432267827	1518	45	14F
0005434374184	1518	46	14E
0005434374170	1518	47	15A
0005433460413	1518	48	15C
0005434374175	1518	49	15F
0005434374187	1518	50	16B
0005433150869	1518	51	16A
0005433460414	1518	52	16C
0005432267825	1518	53	16F
0005433150888	1518	54	16E
0005433150887	1518	55	17D
0005433461567	1518	56	18A
0005434374160	1518	57	18B
0005434374192	1518	58	18D
0005434374174	1518	59	18F
0005434374177	1518	60	19B
0005433150836	1518	61	19C
0005433931417	1518	62	19E
0005434374161	1518	63	19D
0005434374176	1518	64	20A
0005432267829	1518	65	20C
0005434374158	1518	66	20D
0005434374188	1518	67	21A
0005434374190	1518	68	21B
0005433150808	1518	69	21D
0005434374159	1518	70	22A
0005433150794	1518	71	22B
0005433150822	1518	72	22D
0005432267828	1518	73	22E
0005434374186	1518	74	23B
0005434374166	1518	75	23C
0005433150821	1518	76	23D
0005433151071	20135	1	1A
0005433151070	20135	2	1C
0005433151043	20135	3	1F
0005434373855	20135	4	1D
0005433931433	20135	5	3A
0005433151066	20135	6	3D
0005433931435	20135	7	5A
0005434373978	20135	8	5C
0005433151058	20135	9	6A
0005433151067	20135	10	5F
0005433151042	20135	11	6D
0005433151064	20135	12	6E
0005433151044	20135	13	7A
0005433151054	20135	14	6F
0005433764659	20135	15	7C
0005432056261	20135	16	8B
0005433151059	20135	17	8D
0005433151051	20135	18	8F
0005433151060	20135	19	9C
0005433151057	20135	20	9F
0005433151063	20135	21	10D
0005433151053	20135	22	11B
0005433151045	20135	23	11D
0005433151052	20135	24	11C
0005434029632	20135	25	12A
0005433151041	20135	26	12B
0005434373858	20135	27	12E
0005433151050	20135	28	13A
0005434029630	20135	29	12F
0005434029631	20135	30	14A
0005432056259	20135	31	13F
0005433151049	20135	32	14B
0005434373979	20135	33	14D
0005433151055	20135	34	14C
0005433151069	20135	35	14E
0005434373937	20135	36	15A
0005434373924	20135	37	15B
0005433151068	20135	38	15C
0005433151065	20135	39	15E
0005433151061	20135	40	16B
0005433151074	20135	41	16A
0005433151062	20135	42	16D
0005434373892	20135	43	17A
0005434373938	20135	44	17D
0005433151039	20135	45	18B
0005433151072	20135	46	18F
0005433151073	20135	47	19A
0005434373893	20135	48	19C
0005433151056	20135	49	19B
0005434373884	20135	50	19D
0005433151040	20135	51	19F
0005433931434	20135	52	20A
0005433151046	20135	53	20C
0005433151048	20135	54	21C
0005434373857	20135	55	21E
0005434373848	20135	56	22A
0005433764658	20135	57	22B
0005434373849	20135	58	22D
0005434373923	20135	59	22C
0005432056260	20135	60	22F
0005432056258	20135	61	23C
0005433151047	20135	62	23E
0005432423995	560	1	1A
0005432423983	560	2	2C
0005432423986	560	3	3A
0005432423956	560	4	3F
0005432423965	560	5	3D
0005432423978	560	6	4A
0005432423999	560	7	5D
0005432423961	560	8	6A
0005432282790	560	9	7C
0005432282792	560	10	7D
0005432423982	560	11	8B
0005432423994	560	12	8D
0005432282795	560	13	8F
0005432423990	560	14	9B
0005432282794	560	15	9A
0005432423977	560	16	9E
0005432423997	560	17	10A
0005432282793	560	18	10B
0005432423980	560	19	10C
0005432423963	560	20	11A
0005432423973	560	21	11C
0005432423970	560	22	11B
0005432423991	560	23	11F
0005432423957	560	24	14C
0005432423998	560	25	14E
0005432423975	560	26	14F
0005432423964	560	27	16C
0005432423987	560	28	16D
0005432423958	560	29	17D
0005432423976	560	30	18B
0005432423996	560	31	18F
0005432423972	560	32	19D
0005432423992	560	33	19E
0005432282791	560	34	20C
0005432423966	560	35	21D
0005432423959	560	36	22B
0005432423969	560	37	22C
0005432423979	560	38	23A
0005432423984	560	39	24E
0005432423967	560	40	26B
0005432423989	560	41	26C
0005432423981	560	42	26E
0005432423988	560	43	27A
0005432423968	560	44	27D
0005432423962	560	45	27E
0005432423993	560	46	29C
0005432423960	560	47	29D
0005432282789	560	48	29F
0005432423985	560	49	30A
0005432423974	560	50	30E
0005432423971	560	51	31E
0005433158108	12852	1	3C
0005432302295	12852	2	3D
0005433158109	12852	3	4D
0005432302291	12852	4	9D
0005433158105	12852	5	9E
0005432302294	12852	6	10A
0005433158107	12852	7	11B
0005433158106	12852	8	21D
0005433158111	12852	9	21F
0005432302292	12852	10	23E
0005433158110	12852	11	24E
0005432302293	12852	12	29D
0005433158104	12852	13	31C
0005434023040	471	1	1A
0005434023019	471	2	1B
0005433057257	471	3	1F
0005432235560	471	4	1H
0005434023054	471	5	2A
0005434023027	471	6	2B
0005434022989	471	7	2F
0005433057236	471	8	2C
0005434023013	471	9	2G
0005434031975	471	10	2H
0005434023012	471	11	3C
0005434735606	471	12	3G
0005433057234	471	13	3F
0005433057248	471	14	4A
0005433057276	471	15	4B
0005434735600	471	16	4G
0005434023046	471	17	4F
0005434023036	471	18	5A
0005434023034	471	19	5B
0005433057277	471	20	5G
0005432235566	471	21	5H
0005434023023	471	22	9H
0005434023020	471	23	9G
0005434023028	471	24	11B
0005434022993	471	25	11D
0005434028264	471	26	11E
0005434023018	471	27	11H
0005434023037	471	28	12B
0005434023029	471	29	12F
0005433684389	471	30	13B
0005433057289	471	31	13F
0005434022991	471	32	13E
0005434029628	471	33	14F
0005434031973	471	34	14G
0005433929546	471	35	15D
0005434023025	471	36	15B
0005434022994	471	37	15A
0005434023009	471	38	15E
0005434023033	471	39	15G
0005432045592	471	40	15F
0005433057219	471	41	16A
0005434023021	471	42	16D
0005434023038	471	43	16H
0005434023003	471	44	17D
0005434023014	471	45	17E
0005434023043	471	46	17G
0005432235563	471	47	17H
0005434022997	471	48	18B
0005434022995	471	49	18D
0005434023004	471	50	18G
0005434023050	471	51	19A
0005434023030	471	52	19D
0005433057183	471	53	19F
0005434028263	471	54	19G
0005434023041	471	55	20A
0005433057218	471	56	20E
0005434023010	471	57	20H
0005434023017	471	58	21D
0005434023051	471	59	21B
0005433057243	471	60	21E
0005433057203	471	61	21G
0005434023001	471	62	22A
0005434028266	471	63	23B
0005434023015	471	64	23A
0005432235565	471	65	23F
0005434023007	471	66	23E
0005434023052	471	67	24D
0005433057224	471	68	24F
0005434029627	471	69	24E
0005434023005	471	70	25D
0005434023011	471	71	24H
0005434023039	471	72	27A
0005433057233	471	73	27B
0005434023049	471	74	27G
0005433057231	471	75	28F
0005434022988	471	76	29A
0005432235561	471	77	30B
0005432235559	471	78	30A
0005434023016	471	79	30D
0005434029629	471	80	30F
0005432235564	471	81	30E
0005434022990	471	82	31A
0005434022999	471	83	31E
0005434023008	471	84	31G
0005434022992	471	85	32A
0005434023026	471	86	32D
0005434735601	471	87	32E
0005434023000	471	88	32F
0005434023024	471	89	32H
0005434023035	471	90	33A
0005434023053	471	91	33B
0005434031972	471	92	33E
0005434022987	471	93	33G
0005434031974	471	94	33H
0005434023006	471	95	34A
0005434023044	471	96	34D
0005434023031	471	97	34B
0005434023002	471	98	34F
0005434022996	471	99	34E
0005434023048	471	100	35A
0005433057313	471	101	35E
0005433057244	471	102	35B
0005434023022	471	103	35F
0005434022986	471	104	36D
0005434023042	471	105	36F
0005434023032	471	106	37B
0005434023047	471	107	37F
0005434022998	471	108	37H
0005433057245	471	109	37G
0005432235562	471	110	38D
0005432235558	471	111	38B
0005434028265	471	112	38G
0005434023045	471	113	39E
0005433057330	471	114	39F
0005433057492	12645	1	1A
0005434022612	12645	2	1F
0005433057483	12645	3	1C
0005434022569	12645	4	2A
0005433057474	12645	5	2G
0005433057461	12645	6	2H
0005433057496	12645	7	3B
0005433057456	12645	8	3C
0005433057468	12645	9	3G
0005433057493	12645	10	3H
0005433057486	12645	11	5B
0005433057467	12645	12	5C
0005433057471	12645	13	5H
0005433057494	12645	14	9B
0005434022516	12645	15	9A
0005433057473	12645	16	9G
0005433057458	12645	17	11F
0005434022732	12645	18	11H
0005432156322	12645	19	12A
0005433684399	12645	20	12E
0005433057482	12645	21	12G
0005433057478	12645	22	12H
0005433057487	12645	23	13H
0005433057470	12645	24	14B
0005434022558	12645	25	14G
0005434022613	12645	26	15A
0005432157471	12645	27	14H
0005433057460	12645	28	15B
0005432156318	12645	29	16B
0005434022515	12645	30	16A
0005433057457	12645	31	16F
0005433057469	12645	32	16G
0005434022507	12645	33	17A
0005434735640	12645	34	17D
0005433057490	12645	35	17B
0005433057491	12645	36	17F
0005433929571	12645	37	17H
0005434735639	12645	38	18H
0005433057489	12645	39	19E
0005434022579	12645	40	19H
0005434735637	12645	41	20B
0005432156320	12645	42	21B
0005433057459	12645	43	22B
0005434022632	12645	44	22G
0005432156321	12645	45	23A
0005432156323	12645	46	23D
0005433929569	12645	47	23G
0005434022527	12645	48	24B
0005433057462	12645	49	24D
0005433057480	12645	50	24F
0005433929570	12645	51	24E
0005434022670	12645	52	24H
0005432156319	12645	53	25F
0005434022580	12645	54	27B
0005434022525	12645	55	27F
0005434735638	12645	56	27G
0005434022554	12645	57	29D
0005433929572	12645	58	29G
0005433684400	12645	59	30G
0005433057476	12645	60	30H
0005434022690	12645	61	31B
0005434022526	12645	62	31A
0005433057485	12645	63	31D
0005433057495	12645	64	31G
0005434022551	12645	65	32B
0005433057484	12645	66	32E
0005433057481	12645	67	32G
0005433057466	12645	68	33A
0005433057463	12645	69	33F
0005432157472	12645	70	34B
0005433057464	12645	71	35A
0005434022547	12645	72	35B
0005433057477	12645	73	35G
0005433057475	12645	74	36A
0005434022553	12645	75	35H
0005433057479	12645	76	36D
0005434022713	12645	77	36E
0005433057472	12645	78	37A
0005434022552	12645	79	37E
0005434735636	12645	80	37D
0005433057488	12645	81	37F
0005433057465	12645	82	37G
0005434022508	12645	83	38D
0005434022631	12645	84	39F
0005433527225	13819	1	1F
0005433529234	13819	2	4A
0005433527215	13819	3	4D
0005433529226	13819	4	5A
0005433529224	13819	5	6A
0005433529229	13819	6	6B
0005433527213	13819	7	6E
0005433527216	13819	8	6D
0005433529227	13819	9	6F
0005433529228	13819	10	8A
0005433527217	13819	11	10A
0005433527212	13819	12	10E
0005433527221	13819	13	10D
0005433527222	13819	14	11C
0005433529225	13819	15	11D
0005433529222	13819	16	11F
0005433527218	13819	17	12B
0005433527223	13819	18	13D
0005433527224	13819	19	13F
0005433529236	13819	20	14B
0005433529233	13819	21	14D
0005433529232	13819	22	14C
0005433527214	13819	23	14F
0005433527219	13819	24	17C
0005433529231	13819	25	18E
0005433529230	13819	26	18F
0005433529223	13819	27	20A
0005433527211	13819	28	20C
0005433529235	13819	29	21A
0005433527220	13819	30	21B
0005433529210	32451	1	2A
0005432231454	2112	1	1A
0005433922338	2112	2	1B
0005433922345	2112	3	1F
0005433922290	2112	4	1C
0005433922339	2112	5	2C
0005433922301	2112	6	2B
0005433922359	2112	7	3A
0005433922296	2112	8	2H
0005433035390	2112	9	3C
0005433922292	2112	10	3H
0005433922276	2112	11	3G
0005433922324	2112	12	3F
0005433922293	2112	13	4A
0005433035454	2112	14	4F
0005433035378	2112	15	4C
0005433035400	2112	16	4H
0005433922308	2112	17	5B
0005433035393	2112	18	5A
0005433035437	2112	19	5C
0005433922370	2112	20	5G
0005433922313	2112	21	9B
0005433922285	2112	22	9A
0005432231453	2112	23	9G
0005433922341	2112	24	11A
0005433922307	2112	25	11D
0005433922321	2112	26	11E
0005433922363	2112	27	11F
0005433922294	2112	28	11H
0005433922289	2112	29	11G
0005433922284	2112	30	12A
0005433922320	2112	31	12D
0005433922286	2112	32	12F
0005433922365	2112	33	13D
0005433922331	2112	34	13E
0005433922291	2112	35	13G
0005433922357	2112	36	13F
0005433922299	2112	37	13H
0005433922319	2112	38	14A
0005433922349	2112	39	14F
0005433931435	2112	40	15A
0005433922335	2112	41	14H
0005433035389	2112	42	15E
0005432231456	2112	43	15F
0005432044497	2112	44	15H
0005433922300	2112	45	15G
0005433922325	2112	46	16A
0005433035426	2112	47	16B
0005433922371	2112	48	16F
0005432044496	2112	49	16H
0005433035442	2112	50	16G
0005433929571	2112	51	17B
0005433035478	2112	52	17A
0005433922368	2112	53	17D
0005433922280	2112	54	17G
0005433922305	2112	55	18D
0005433035405	2112	56	18G
0005433922330	2112	57	18F
0005433035391	2112	58	18H
0005432231452	2112	59	19B
0005433922302	2112	60	19D
0005433922275	2112	61	19F
0005433922369	2112	62	19E
0005433922288	2112	63	19H
0005433035451	2112	64	20A
0005432231461	2112	65	20E
0005433922323	2112	66	20F
0005433922352	2112	67	20G
0005432231459	2112	68	20H
0005433922344	2112	69	21E
0005433922333	2112	70	21G
0005433922322	2112	71	21F
0005433922343	2112	72	21H
0005433922334	2112	73	22D
0005433922287	2112	74	22G
0005433922342	2112	75	22F
0005433922328	2112	76	22H
0005433922312	2112	77	23D
0005433922337	2112	78	23G
0005433035441	2112	79	23H
0005432044495	2112	80	24B
0005433035427	2112	81	24E
0005433922283	2112	82	24D
0005433929570	2112	83	24F
0005433931434	2112	84	24G
0005433922361	2112	85	25D
0005433922314	2112	86	24H
0005433929569	2112	87	27E
0005433922353	2112	88	27D
0005433922317	2112	89	27F
0005433922310	2112	90	28B
0005432231450	2112	91	28E
0005433922298	2112	92	28F
0005433922303	2112	93	28H
0005433922362	2112	94	28G
0005433922348	2112	95	29A
0005433922316	2112	96	29D
0005433922295	2112	97	29B
0005433922336	2112	98	29E
0005433922326	2112	99	29H
0005433922332	2112	100	30B
0005433922350	2112	101	30A
0005433922360	2112	102	30D
0005433931433	2112	103	30E
0005433035401	2112	104	30H
0005433922329	2112	105	31B
0005432231460	2112	106	31A
0005433922372	2112	107	31D
0005433922327	2112	108	31F
0005433035394	2112	109	31G
0005433922311	2112	110	32A
0005433922367	2112	111	32B
0005433922277	2112	112	33A
0005433922279	2112	113	32H
0005433929572	2112	114	33B
0005432231458	2112	115	33E
0005433922306	2112	116	33D
0005433922347	2112	117	33H
0005433922297	2112	118	34B
0005433922366	2112	119	34F
0005433922318	2112	120	34G
0005433922340	2112	121	35B
0005433922358	2112	122	35A
0005433035438	2112	123	35D
0005433922304	2112	124	35G
0005433922351	2112	125	35H
0005433922315	2112	126	36E
0005433922354	2112	127	36D
0005433922355	2112	128	36F
0005433922356	2112	129	36G
0005433922373	2112	130	37A
0005432231451	2112	131	36H
0005433922278	2112	132	37B
0005433922281	2112	133	37E
0005432231457	2112	134	37H
0005433922364	2112	135	38A
0005433922346	2112	136	38D
0005433922282	2112	137	38E
0005432231455	2112	138	38G
0005433035531	2112	139	39D
0005433922309	2112	140	39F
0005433035771	24143	1	1C
0005434028267	24143	2	1B
0005433921753	24143	3	1F
0005433931422	24143	4	1G
0005433921610	24143	5	2A
0005433035770	24143	6	2F
0005433035763	24143	7	3G
0005434028270	24143	8	4B
0005433035743	24143	9	4A
0005434028269	24143	10	4G
0005433035773	24143	11	5F
0005432207636	24143	12	5G
0005433035769	24143	13	9B
0005434028268	24143	14	9A
0005433921752	24143	15	9G
0005433035755	24143	16	11A
0005433921609	24143	17	9H
0005433035787	24143	18	11D
0005433035752	24143	19	12B
0005433035739	24143	20	12D
0005433035761	24143	21	12F
0005433035750	24143	22	12H
0005433921645	24143	23	13D
0005433921595	24143	24	13G
0005433035748	24143	25	14D
0005432207635	24143	26	14E
0005433035762	24143	27	14H
0005433035756	24143	28	14G
0005432207634	24143	29	14F
0005433035767	24143	30	15F
0005433921647	24143	31	15H
0005433035742	24143	32	16A
0005433035746	24143	33	16B
0005433921818	24143	34	16D
0005433035754	24143	35	16H
0005433035781	24143	36	17A
0005433035778	24143	37	17D
0005433035776	24143	38	17F
0005432749762	24143	39	17G
0005433035784	24143	40	18D
0005433035783	24143	41	19A
0005432206137	24143	42	18H
0005433035745	24143	43	19B
0005432206133	24143	44	19D
0005433921611	24143	45	19F
0005433921670	24143	46	20D
0005432206136	24143	47	20B
0005433921661	24143	48	20H
0005433921589	24143	49	20G
0005433035785	24143	50	21A
0005433035764	24143	51	21E
0005433921615	24143	52	21G
0005433035777	24143	53	21F
0005433035757	24143	54	22B
0005433921616	24143	55	22A
0005433922048	24143	56	22E
0005433875356	24143	57	22F
0005433035775	24143	58	22H
0005433035766	24143	59	23A
0005433035765	24143	60	23D
0005433875355	24143	61	23B
0005432206134	24143	62	23F
0005432206138	24143	63	24B
0005433035749	24143	64	24D
0005433035747	24143	65	24F
0005433035744	24143	66	27A
0005433035768	24143	67	27B
0005433921866	24143	68	27E
0005433921588	24143	69	27D
0005433921807	24143	70	27G
0005433921671	24143	71	27H
0005433922050	24143	72	28D
0005433921587	24143	73	28G
0005433035774	24143	74	29A
0005433035779	24143	75	30B
0005433035740	24143	76	30A
0005432749763	24143	77	30D
0005432206139	24143	78	30H
0005433035738	24143	79	31D
0005433035751	24143	80	31E
0005433035782	24143	81	33A
0005433921646	24143	82	34D
0005433921859	24143	83	34B
0005433035735	24143	84	34E
0005433035759	24143	85	35F
0005433921662	24143	86	35E
0005432206135	24143	87	35H
0005433035786	24143	88	36A
0005433035780	24143	89	36D
0005433922049	24143	90	36F
0005433035772	24143	91	37A
0005433035753	24143	92	36H
0005433035760	24143	93	37B
0005433035741	24143	94	37F
0005433035758	24143	95	37E
0005433921617	24143	96	38A
0005433921836	24143	97	38E
0005433035736	24143	98	38D
0005433035737	24143	99	38G
0005433921599	24143	100	39D
0005433931421	24143	101	39F
0005434724205	258	1	1D
0005434550690	258	2	1C
0005434550668	258	3	1H
0005433233210	258	4	2A
0005433180658	258	5	1K
0005434724222	258	6	2C
0005433233158	258	7	2G
0005433233273	258	8	3A
0005433233199	258	9	2K
0005434550703	258	10	2H
0005434550688	258	11	3D
0005434724264	258	12	3C
0005434724263	258	13	3K
0005434724188	258	14	3H
0005435142433	258	15	3G
0005434550685	258	16	4D
0005435142445	258	17	5C
0005434724245	258	18	5G
0005434724219	258	19	11A
0005434724209	258	20	5K
0005435142435	258	21	11D
0005432277670	258	22	11C
0005433233092	258	23	11F
0005435142443	258	24	11E
0005434724273	258	25	11K
0005435142440	258	26	11H
0005434724185	258	27	11G
0005434724178	258	28	12C
0005434550657	258	29	12A
0005434724214	258	30	12E
0005434735633	258	31	12D
0005434724202	258	32	12H
0005434724271	258	33	12G
0005434724238	258	34	12F
0005434550679	258	35	12K
0005434724255	258	36	13D
0005433233155	258	37	13C
0005434724293	258	38	13A
0005433233230	258	39	13E
0005434724192	258	40	13H
0005434550654	258	41	13K
0005434724180	258	42	14E
0005435142442	258	43	14D
0005432277673	258	44	14C
0005433126770	258	45	14G
0005434724206	258	46	14K
0005434724277	258	47	14H
0005434724215	258	48	15C
0005434550655	258	49	15A
0005434550696	258	50	15D
0005434724201	258	51	15G
0005434724226	258	52	15H
0005434550683	258	53	16D
0005434724224	258	54	16C
0005434550676	258	55	16F
0005434550656	258	56	16E
0005434724294	258	57	16G
0005434724239	258	58	17C
0005433180679	258	59	17A
0005434550674	258	60	17G
0005434724248	258	61	18A
0005434724179	258	62	17K
0005434724266	258	63	18C
0005434550684	258	64	18E
0005434724250	258	65	18D
0005434724259	258	66	18F
0005434724246	258	67	18K
0005434724234	258	68	18J
0005434724300	258	69	18H
0005434550669	258	70	19A
0005434724272	258	71	19C
0005434724235	258	72	19B
0005434724299	258	73	19F
0005434735630	258	74	19E
0005434724213	258	75	19G
0005433180666	258	76	20C
0005434724290	258	77	20B
0005434724286	258	78	20A
0005432277677	258	79	20D
0005434724281	258	80	20G
0005434550680	258	81	20F
0005433131627	258	82	20K
0005434550673	258	83	20J
0005434724189	258	84	20H
0005434724267	258	85	21A
0005434724244	258	86	21D
0005434550662	258	87	21C
0005434724241	258	88	21H
0005434550681	258	89	21G
0005434724225	258	90	22A
0005434724233	258	91	21K
0005434724218	258	92	22D
0005434550660	258	93	22B
0005434550697	258	94	22E
0005434724278	258	95	22H
0005433233157	258	96	23A
0005435142446	258	97	23E
0005434724196	258	98	23D
0005434724197	258	99	23F
0005433180742	258	100	23J
0005434302417	258	101	23G
0005432277667	258	102	24D
0005434724203	258	103	24F
0005434724251	258	104	25A
0005434550682	258	105	25C
0005434724237	258	106	25E
0005434550665	258	107	25D
0005434724252	258	108	25H
0005434735629	258	109	25G
0005434724275	258	110	25K
0005433233147	258	111	25J
0005434724269	258	112	26C
0005434550667	258	113	26A
0005434550664	258	114	26E
0005434550702	258	115	26D
0005434550687	258	116	26G
0005434550651	258	117	26K
0005434724276	258	118	26H
0005434724186	258	119	27A
0005433233290	258	120	27C
0005435142439	258	121	27B
0005434724282	258	122	27E
0005434724221	258	123	27G
0005433180672	258	124	28A
0005434724231	258	125	27K
0005433111471	258	126	27J
0005434724184	258	127	28B
0005434550691	258	128	28C
0005434724268	258	129	28J
0005434724212	258	130	28H
0005433233108	258	131	29A
0005434724262	258	132	28K
0005434550666	258	133	29D
0005434724260	258	134	29F
0005433233160	258	135	29E
0005434550670	258	136	29H
0005434724297	258	137	29K
0005433180654	258	138	30F
0005434550677	258	139	30J
0005434735632	258	140	30H
0005434724254	258	141	31A
0005434724236	258	142	31B
0005434550699	258	143	31G
0005434550675	258	144	31H
0005433233138	258	145	31K
0005434724292	258	146	31J
0005435142436	258	147	32C
0005434724204	258	148	32B
0005434550671	258	149	32E
0005434724242	258	150	32D
0005434724198	258	151	32F
0005434724229	258	152	32H
0005433180675	258	153	33A
0005434724295	258	154	32K
0005432277669	258	155	33C
0005432277676	258	156	33B
0005434550704	258	157	33F
0005434550700	258	158	33E
0005434735635	258	159	33H
0005435142432	258	160	33G
0005432277672	258	161	33K
0005434550686	258	162	33J
0005434735631	258	163	34C
0005433233201	258	164	34B
0005434731122	258	165	34D
0005434724280	258	166	34G
0005434031944	258	167	34F
0005434724182	258	168	34K
0005434724265	258	169	34J
0005434724211	258	170	35A
0005433233090	258	171	35D
0005434724257	258	172	35C
0005433233231	258	173	35B
0005434724288	258	174	35G
0005435142437	258	175	35K
0005434724270	258	176	35J
0005434731124	258	177	36D
0005435142438	258	178	36C
0005434724183	258	179	36B
0005434724287	258	180	36G
0005434724261	258	181	36F
0005434724207	258	182	36J
0005434302415	258	183	37B
0005434550661	258	184	37A
0005434724210	258	185	37D
0005434724217	258	186	37C
0005433113496	258	187	37F
0005433233137	258	188	38A
0005434724296	258	189	37K
0005432277675	258	190	37J
0005434724181	258	191	38C
0005434724190	258	192	38K
0005433233315	258	193	39A
0005432277668	258	194	39D
0005434724191	258	195	39C
0005433180683	258	196	39F
0005434550693	258	197	39H
0005433180709	258	198	39G
0005434724187	258	199	39K
0005434724193	258	200	39J
0005434550652	258	201	40E
0005434724223	258	202	40D
0005434550694	258	203	40G
0005433233102	258	204	40F
0005433233101	258	205	40H
0005434724247	258	206	41D
0005432277666	258	207	41C
0005434724195	258	208	41B
0005434724256	258	209	41F
0005434302416	258	210	41H
0005434302413	258	211	41G
0005435142434	258	212	42A
0005433131626	258	213	41K
0005433111469	258	214	42C
0005434731125	258	215	42B
0005434731123	258	216	42E
0005434724253	258	217	42D
0005434550698	258	218	42G
0005434724298	258	219	42F
0005434550689	258	220	42J
0005433180711	258	221	43A
0005434031952	258	222	42K
0005433233146	258	223	43C
0005434550653	258	224	43F
0005434724289	258	225	43E
0005434724291	258	226	43H
0005434724258	258	227	43G
0005432277665	258	228	43J
0005433233177	258	229	44C
0005434302414	258	230	44B
0005434735634	258	231	44A
0005434724216	258	232	44E
0005434724227	258	233	44H
0005433180676	258	234	44F
0005433233154	258	235	44J
0005433180678	258	236	45B
0005432277671	258	237	45A
0005435142441	258	238	44K
0005434550701	258	239	45D
0005433233159	258	240	45C
0005434550658	258	241	45F
0005434724240	258	242	45E
0005434550692	258	243	45G
0005434724232	258	244	46A
0005434550678	258	245	45K
0005434550672	258	246	45J
0005434724279	258	247	46C
0005434724243	258	248	46B
0005433180653	258	249	46E
0005433111468	258	250	46K
0005434724208	258	251	46J
0005434724274	258	252	46H
0005434724230	258	253	47G
0005434724283	258	254	47F
0005433180671	258	255	47E
0005434724200	258	256	48A
0005432277678	258	257	48G
0005434550695	258	258	49A
0005433126771	258	259	49E
0005434550663	258	260	49D
0005434724220	258	261	49C
0005433233109	258	262	49K
0005434724285	258	263	49H
0005434724249	258	264	50D
0005434550705	258	265	50C
0005432277674	258	266	50A
0005434724228	258	267	50E
0005434724284	258	268	50H
0005434724199	258	269	50G
0005434724194	258	270	50F
0005435142444	258	271	50K
0005433131629	258	272	51F
0005434550659	258	273	51G
0005433180831	9846	1	1A
0005434723318	9846	2	1G
0005433233570	9846	3	1H
0005433233591	9846	4	2C
0005433126795	9846	5	2A
0005432199174	9846	6	2G
0005434723466	9846	7	2K
0005433233564	9846	8	3G
0005433233584	9846	9	4D
0005434723534	9846	10	5D
0005434031979	9846	11	5H
0005433180846	9846	12	11A
0005433233586	9846	13	5K
0005433180845	9846	14	11E
0005433233558	9846	15	11H
0005433233561	9846	16	12C
0005433233581	9846	17	12A
0005434723706	9846	18	12E
0005433233594	9846	19	12H
0005433233535	9846	20	13D
0005433233534	9846	21	13C
0005433180843	9846	22	13F
0005433233590	9846	23	13E
0005433126798	9846	24	14A
0005434723719	9846	25	14D
0005433180835	9846	26	14H
0005434724036	9846	27	15G
0005433289768	9846	28	15K
0005433129228	9846	29	16D
0005434723389	9846	30	16F
0005434723629	9846	31	17A
0005434302390	9846	32	16K
0005433233552	9846	33	17E
0005433233573	9846	34	17G
0005433233560	9846	35	17K
0005433233539	9846	36	17H
0005434550390	9846	37	18B
0005433180830	9846	38	18A
0005433233550	9846	39	18H
0005434723325	9846	40	18G
0005433126797	9846	41	18J
0005433113511	9846	42	19A
0005433180848	9846	43	19C
0005433233543	9846	44	19E
0005433233592	9846	45	20A
0005433129226	9846	46	20E
0005434723656	9846	47	20D
0005434723398	9846	48	20H
0005434723586	9846	49	20F
0005433180850	9846	50	20J
0005434031978	9846	51	21D
0005434302385	9846	52	21F
0005432199176	9846	53	21G
0005433233566	9846	54	22A
0005434723467	9846	55	22C
0005433233562	9846	56	22F
0005433289773	9846	57	22K
0005434723718	9846	58	22J
0005434723317	9846	59	23B
0005433129227	9846	60	23E
0005433180834	9846	61	23J
0005433233540	9846	62	23H
0005433233536	9846	63	23G
0005433233556	9846	64	24E
0005433233549	9846	65	24G
0005433180839	9846	66	25F
0005434302389	9846	67	25G
0005434550292	9846	68	26C
0005434723513	9846	69	26G
0005434723613	9846	70	26F
0005433233580	9846	71	26K
0005433180854	9846	72	26J
0005433233545	9846	73	27D
0005433180840	9846	74	27B
0005434723391	9846	75	27F
0005433289775	9846	76	27E
0005433180847	9846	77	27J
0005434723374	9846	78	27K
0005433289774	9846	79	28B
0005434031980	9846	80	28E
0005433233579	9846	81	28G
0005433233565	9846	82	28F
0005434723419	9846	83	29A
0005433766601	9846	84	28K
0005434735597	9846	85	29D
0005433233546	9846	86	29C
0005433233551	9846	87	29B
0005433233577	9846	88	29E
0005433233567	9846	89	29H
0005433233571	9846	90	29G
0005434031976	9846	91	30A
0005434723418	9846	92	30D
0005433180833	9846	93	30G
0005433126796	9846	94	30K
0005434723542	9846	95	30J
0005432199179	9846	96	31B
0005433233574	9846	97	31C
0005434550391	9846	98	31F
0005433233533	9846	99	31G
0005433289770	9846	100	32A
0005433129230	9846	101	31K
0005433233557	9846	102	31J
0005433180836	9846	103	32E
0005434723554	9846	104	32D
0005434723694	9846	105	32K
0005434724034	9846	106	32H
0005434723816	9846	107	33A
0005433180849	9846	108	33C
0005433126799	9846	109	33J
0005433233553	9846	110	33G
0005433233532	9846	111	34G
0005432199178	9846	112	34F
0005433233544	9846	113	34K
0005433233568	9846	114	35D
0005433233587	9846	115	35C
0005433233575	9846	116	35F
0005433233576	9846	117	35E
0005433233548	9846	118	35K
0005433233554	9846	119	36D
0005434723472	9846	120	36K
0005433180841	9846	121	37D
0005434723533	9846	122	37H
0005433766602	9846	123	37G
0005433180852	9846	124	38A
0005433289771	9846	125	37K
0005433233589	9846	126	38J
0005433766600	9846	127	39B
0005433233583	9846	128	39C
0005433233593	9846	129	39D
0005434723379	9846	130	39J
0005433233538	9846	131	39H
0005433233559	9846	132	40B
0005434723514	9846	133	40E
0005433766599	9846	134	40H
0005434723388	9846	135	40G
0005433180837	9846	136	40K
0005433180838	9846	137	41B
0005434724035	9846	138	41H
0005432199175	9846	139	42A
0005434723350	9846	140	41K
0005433233588	9846	141	42C
0005433180829	9846	142	42D
0005433180853	9846	143	42G
0005434723372	9846	144	43D
0005434031977	9846	145	43C
0005433289772	9846	146	43F
0005433180851	9846	147	43E
0005433129229	9846	148	43J
0005433233569	9846	149	43H
0005432199177	9846	150	43G
0005433233537	9846	151	43K
0005433233542	9846	152	44B
0005434723458	9846	153	44D
0005434723610	9846	154	45A
0005433113512	9846	155	45C
0005433233547	9846	156	45B
0005433233555	9846	157	45F
0005433233563	9846	158	45G
0005433180842	9846	159	45J
0005434723357	9846	160	46B
0005433180844	9846	161	46A
0005433289769	9846	162	47C
0005433233541	9846	163	47G
0005434723541	9846	164	47F
0005433233585	9846	165	47E
0005432199173	9846	166	48H
0005433233572	9846	167	48G
0005433129231	9846	168	48K
0005433233582	9846	169	49K
0005434723417	9846	170	50C
0005434550397	9846	171	50E
0005433180832	9846	172	50G
0005434723693	9846	173	50H
0005433233578	9846	174	51E
0005432428892	7732	1	1C
0005432150115	7732	2	1K
0005435212369	7732	3	1H
0005432526627	7732	4	2H
0005432526649	7732	5	2G
0005434066864	7732	6	3A
0005432526699	7732	7	2K
0005432526597	7732	8	3C
0005434066808	7732	9	3G
0005432069508	7732	10	4C
0005434066824	7732	11	4A
0005435212479	7732	12	4G
0005432526600	7732	13	4D
0005432526658	7732	14	4K
0005434066859	7732	15	4H
0005432526624	7732	16	5D
0005434066818	7732	17	5A
0005432526611	7732	18	5G
0005432526599	7732	19	11A
0005434066851	7732	20	5K
0005432526625	7732	21	11D
0005432526706	7732	22	11C
0005432526605	7732	23	11F
0005432526686	7732	24	11E
0005435212334	7732	25	11K
0005432526618	7732	26	11G
0005432526586	7732	27	12A
0005434066861	7732	28	12E
0005432526684	7732	29	12D
0005432526685	7732	30	12H
0005432526667	7732	31	12G
0005435212457	7732	32	12F
0005432526637	7732	33	13D
0005432069506	7732	34	13C
0005434066872	7732	35	13A
0005432526640	7732	36	13F
0005432526580	7732	37	13H
0005432150114	7732	38	13G
0005434066830	7732	39	14A
0005432526687	7732	40	13K
0005434066862	7732	41	14E
0005434066827	7732	42	14C
0005432526678	7732	43	14G
0005432526631	7732	44	14F
0005432069498	7732	45	14K
0005432526578	7732	46	15A
0005434066850	7732	47	15F
0005432526598	7732	48	15E
0005434066847	7732	49	15H
0005434066817	7732	50	16A
0005432526633	7732	51	15K
0005432526622	7732	52	16C
0005432526579	7732	53	16E
0005432535785	7732	54	16G
0005432526666	7732	55	17C
0005432526615	7732	56	17A
0005434066855	7732	57	16K
0005434066828	7732	58	17E
0005435212364	7732	59	17G
0005434066873	7732	60	17F
0005434066856	7732	61	17K
0005434066812	7732	62	17H
0005432535781	7732	63	18B
0005432533263	7732	64	18E
0005435212440	7732	65	18G
0005432526674	7732	66	18H
0005432526590	7732	67	19B
0005434066857	7732	68	19A
0005432535782	7732	69	18K
0005432526660	7732	70	19C
0005432526689	7732	71	19G
0005434066837	7732	72	20A
0005434066867	7732	73	19K
0005432526635	7732	74	20B
0005432526690	7732	75	20D
0005432526647	7732	76	20C
0005432526588	7732	77	20F
0005434066836	7732	78	20K
0005432150110	7732	79	20J
0005434066823	7732	80	20H
0005434066822	7732	81	21G
0005432533262	7732	82	21F
0005434066826	7732	83	21K
0005432533261	7732	84	22C
0005432526621	7732	85	22B
0005432526582	7732	86	22E
0005432526654	7732	87	22D
0005435212487	7732	88	22F
0005432526614	7732	89	22K
0005432526642	7732	90	22J
0005435212527	7732	91	23B
0005434066854	7732	92	23A
0005432526616	7732	93	23D
0005434066868	7732	94	23C
0005432526693	7732	95	23E
0005435212441	7732	96	23J
0005434066813	7732	97	23H
0005435212513	7732	98	23G
0005432526651	7732	99	23K
0005434066821	7732	100	24F
0005432526652	7732	101	24E
0005432428894	7732	102	24G
0005432150111	7732	103	25C
0005432526575	7732	104	25F
0005434066844	7732	105	25D
0005434066804	7732	106	25H
0005434066805	7732	107	25G
0005432526656	7732	108	26A
0005432535784	7732	109	25K
0005432526589	7732	110	25J
0005434066842	7732	111	26E
0005432526681	7732	112	26D
0005432526591	7732	113	26G
0005432526596	7732	114	26F
0005432526587	7732	115	27A
0005435212443	7732	116	27D
0005432526677	7732	117	27C
0005432069511	7732	118	27B
0005434066829	7732	119	27H
0005432526643	7732	120	27G
0005435212478	7732	121	28A
0005432526671	7732	122	27K
0005434066835	7732	123	28B
0005432526626	7732	124	28C
0005432526617	7732	125	28G
0005434066806	7732	126	28J
0005433656619	7732	127	29B
0005432150116	7732	128	29A
0005432069509	7732	129	29D
0005432069507	7732	130	29C
0005434066833	7732	131	29E
0005434066825	7732	132	29K
0005434066866	7732	133	29J
0005434066831	7732	134	30C
0005432526691	7732	135	30B
0005432069503	7732	136	30D
0005432526623	7732	137	30H
0005432526632	7732	138	30G
0005434066816	7732	139	30F
0005432150117	7732	140	30J
0005434066848	7732	141	31A
0005432526628	7732	142	31D
0005432526703	7732	143	31E
0005434066860	7732	144	31H
0005432526612	7732	145	31G
0005432526694	7732	146	31J
0005435212345	7732	147	32D
0005434066810	7732	148	32C
0005434066841	7732	149	32G
0005432526670	7732	150	32F
0005432526604	7732	151	32K
0005432526584	7732	152	32J
0005434066819	7732	153	33B
0005432069500	7732	154	33A
0005432150112	7732	155	33D
0005432526606	7732	156	33F
0005432526676	7732	157	33H
0005432526705	7732	158	34A
0005432526595	7732	159	33K
0005435212370	7732	160	33J
0005435212363	7732	161	34B
0005435212411	7732	162	34E
0005432526636	7732	163	34C
0005432526700	7732	164	34G
0005432526692	7732	165	34F
0005432069505	7732	166	34K
0005432526581	7732	167	34H
0005432526697	7732	168	35B
0005434066832	7732	169	35A
0005432526661	7732	170	35D
0005432535783	7732	171	35C
0005432526646	7732	172	35F
0005434066809	7732	173	35H
0005432526603	7732	174	36A
0005432526608	7732	175	36C
0005435212333	7732	176	36B
0005434066871	7732	177	36F
0005432526641	7732	178	36E
0005432526673	7732	179	36D
0005432526659	7732	180	36H
0005435212429	7732	181	36G
0005432526644	7732	182	37B
0005432526613	7732	183	37A
0005432526650	7732	184	37D
0005432069502	7732	185	37C
0005432069512	7732	186	37E
0005432526696	7732	187	37J
0005432526610	7732	188	37H
0005435212335	7732	189	37G
0005432526695	7732	190	38A
0005435212378	7732	191	37K
0005432150113	7732	192	38H
0005432526672	7732	193	38B
0005432526668	7732	194	38K
0005432526655	7732	195	38J
0005432526620	7732	196	39G
0005434066869	7732	197	39F
0005432526665	7732	198	39E
0005432526593	7732	199	39H
0005432069501	7732	200	39K
0005432526669	7732	201	39J
0005432526664	7732	202	40B
0005432526594	7732	203	40A
0005432526663	7732	204	40D
0005434066838	7732	205	40H
0005434066807	7732	206	40G
0005432526701	7732	207	40F
0005434066820	7732	208	41C
0005434066849	7732	209	41H
0005432069504	7732	210	41K
0005434066874	7732	211	41J
0005432526609	7732	212	42C
0005434066852	7732	213	42B
0005435212375	7732	214	42E
0005434066814	7732	215	42H
0005432526607	7732	216	42G
0005432526619	7732	217	42F
0005432526688	7732	218	42K
0005432428893	7732	219	42J
0005432526679	7732	220	43B
0005435212371	7732	221	43C
0005432526638	7732	222	43F
0005432526682	7732	223	43J
0005432526583	7732	224	43H
0005432526601	7732	225	44A
0005432526602	7732	226	43K
0005432526585	7732	227	44E
0005432069510	7732	228	44D
0005434066843	7732	229	44G
0005434066858	7732	230	44F
0005432526592	7732	231	44J
0005432069499	7732	232	44H
0005434066840	7732	233	45A
0005434066845	7732	234	44K
0005432526702	7732	235	45E
0005434066839	7732	236	45J
0005432526630	7732	237	45H
0005434066834	7732	238	45G
0005434066815	7732	239	45K
0005434066853	7732	240	46B
0005432526662	7732	241	46E
0005432526576	7732	242	46D
0005432526577	7732	243	46C
0005434066870	7732	244	46F
0005432526683	7732	245	46J
0005432526653	7732	246	47C
0005435212379	7732	247	47E
0005432526645	7732	248	47G
0005435212444	7732	249	47F
0005432526634	7732	250	47K
0005434066875	7732	251	47H
0005432526657	7732	252	48H
0005434066846	7732	253	48G
0005434066865	7732	254	48K
0005432526648	7732	255	49C
0005435212372	7732	256	49G
0005432526639	7732	257	49F
0005432526704	7732	258	49E
0005434066811	7732	259	49K
0005432526698	7732	260	50D
0005435212512	7732	261	50C
0005434066863	7732	262	50E
0005432526680	7732	263	50H
0005432526629	7732	264	51D
0005435212347	7732	265	50K
0005432526675	7732	266	51G
0005435423664	5316	1	1D
0005435423621	5316	2	1A
0005434573216	5316	3	1G
0005435423722	5316	4	1H
0005435612561	5316	5	2D
0005435423710	5316	6	2C
0005435612589	5316	7	2A
0005435612577	5316	8	3C
0005435612562	5316	9	3A
0005435423674	5316	10	2K
0005435423778	5316	11	3K
0005435491418	5316	12	3G
0005432133055	5316	13	4A
0005435612510	5316	14	4G
0005434573205	5316	15	4D
0005434343863	5316	16	5D
0005435319428	5316	17	5C
0005435423851	5316	18	5A
0005435097112	5316	19	5H
0005435612500	5316	20	5G
0005434343848	5316	21	11A
0005434573210	5316	22	5K
0005435423892	5316	23	11E
0005435612604	5316	24	11K
0005435097113	5316	25	11H
0005435612518	5316	26	11G
0005435612542	5316	27	12C
0005435423634	5316	28	12A
0005434343870	5316	29	12E
0005432047512	5316	30	12D
0005432133050	5316	31	12H
0005435491417	5316	32	12G
0005435490189	5316	33	12F
0005432133058	5316	34	13C
0005435612514	5316	35	13E
0005435612541	5316	36	13H
0005434343873	5316	37	13G
0005435612507	5316	38	14C
0005435423805	5316	39	14A
0005435612547	5316	40	14D
0005435612599	5316	41	14G
0005434343844	5316	42	14F
0005435612578	5316	43	14K
0005432133059	5316	44	14H
0005434573214	5316	45	15A
0005434343867	5316	46	15D
0005435612508	5316	47	15G
0005435423612	5316	48	15K
0005434343840	5316	49	15H
0005435423891	5316	50	16D
0005435423726	5316	51	16E
0005434573203	5316	52	16K
0005432840976	5316	53	16H
0005435097116	5316	54	16G
0005435612536	5316	55	17C
0005435423703	5316	56	17A
0005435612605	5316	57	17G
0005432047513	5316	58	17F
0005435612593	5316	59	17H
0005435612509	5316	60	18E
0005435612565	5316	61	18C
0005435612521	5316	62	18G
0005435612520	5316	63	18F
0005435612594	5316	64	18K
0005434343862	5316	65	18J
0005435612511	5316	66	18H
0005435612582	5316	67	19D
0005435423751	5316	68	19E
0005435612558	5316	69	19G
0005434343842	5316	70	19K
0005435423610	5316	71	20C
0005434343859	5316	72	20B
0005434343864	5316	73	20D
0005435612584	5316	74	20G
0005434573207	5316	75	20F
0005434343852	5316	76	20H
0005435423721	5316	77	20K
0005435612595	5316	78	21B
0005434343869	5316	79	21G
0005435612546	5316	80	21E
0005434573209	5316	81	21J
0005435612486	5316	82	21H
0005435612533	5316	83	22A
0005432047510	5316	84	21K
0005435423658	5316	85	22C
0005435612545	5316	86	22B
0005432133052	5316	87	22F
0005435612531	5316	88	22K
0005435612549	5316	89	22J
0005435423614	5316	90	23B
0005435097111	5316	91	23E
0005435612540	5316	92	23D
0005435612498	5316	93	23C
0005435612525	5316	94	23F
0005434343841	5316	95	23H
0005435612526	5316	96	23K
0005435612501	5316	97	24G
0005435612555	5316	98	24F
0005435612492	5316	99	25A
0005435612574	5316	100	25C
0005435612524	5316	101	25B
0005435491419	5316	102	25F
0005435612537	5316	103	25E
0005435423657	5316	104	25H
0005434343856	5316	105	25G
0005435097115	5316	106	26B
0005434244481	5316	107	26E
0005434343855	5316	108	26D
0005435612493	5316	109	26H
0005435612569	5316	110	26G
0005435612497	5316	111	26J
0005435423624	5316	112	27B
0005435612538	5316	113	27D
0005432133053	5316	114	27C
0005432133054	5316	115	27F
0005434244488	5316	116	27E
0005435097114	5316	117	27J
0005435612544	5316	118	27H
0005432133051	5316	119	27G
0005434343865	5316	120	28C
0005434343850	5316	121	28B
0005435612606	5316	122	28E
0005435423779	5316	123	28D
0005435612487	5316	124	28G
0005435612515	5316	125	28F
0005435612505	5316	126	28J
0005435423750	5316	127	28H
0005434573213	5316	128	29B
0005435612581	5316	129	29A
0005435423782	5316	130	29C
0005432133056	5316	131	29F
0005435612600	5316	132	29E
0005435612576	5316	133	30A
0005434244453	5316	134	29J
0005435612575	5316	135	30C
0005434244556	5316	136	30B
0005435423689	5316	137	30D
0005435612553	5316	138	30G
0005435612592	5316	139	30F
0005435097117	5316	140	30K
0005435612490	5316	141	30J
0005432133063	5316	142	31B
0005432363362	5316	143	31A
0005435423711	5316	144	31C
0005432133057	5316	145	31H
0005435612495	5316	146	31G
0005435304993	5316	147	32A
0005435612494	5316	148	31K
0005435612484	5316	149	31J
0005435423849	5316	150	32C
0005435423850	5316	151	32B
0005435612608	5316	152	32E
0005435423586	5316	153	32D
0005435612543	5316	154	32H
0005435097110	5316	155	32G
0005435612550	5316	156	32F
0005435612610	5316	157	32J
0005435612580	5316	158	33A
0005435612598	5316	159	33D
0005435612602	5316	160	33C
0005434343854	5316	161	33E
0005435612532	5316	162	33G
0005435612597	5316	163	33J
0005434343857	5316	164	34C
0005434573211	5316	165	34B
0005434343866	5316	166	34E
0005435612496	5316	167	34D
0005435612579	5316	168	34F
0005435612591	5316	169	34J
0005435423611	5316	170	34H
0005434573215	5316	171	35E
0005434573204	5316	172	35C
0005434343860	5316	173	35F
0005435612585	5316	174	35G
0005435304994	5316	175	36A
0005435612522	5316	176	35J
0005434343851	5316	177	36C
0005435612554	5316	178	36B
0005435612503	5316	179	36F
0005435612485	5316	180	36E
0005435612588	5316	181	36D
0005435612527	5316	182	36G
0005432133061	5316	183	36J
0005435490188	5316	184	37B
0005435612528	5316	185	37A
0005435612568	5316	186	37D
0005435423632	5316	187	37C
0005435612601	5316	188	37E
0005435612502	5316	189	37J
0005432047514	5316	190	37H
0005435423682	5316	191	37K
0005435612530	5316	192	38B
0005435612567	5316	193	38J
0005435612571	5316	194	38H
0005434343843	5316	195	38K
0005435612563	5316	196	39C
0005434573206	5316	197	39F
0005435612586	5316	198	39E
0005435612499	5316	199	39G
0005435423688	5316	200	40B
0005435612548	5316	201	40E
0005434573208	5316	202	40H
0005435612603	5316	203	40G
0005435612513	5316	204	40F
0005435612551	5316	205	40J
0005435423665	5316	206	41A
0005435423718	5316	207	41G
0005434244454	5316	208	41F
0005435612517	5316	209	41H
0005435423605	5316	210	42A
0005435612516	5316	211	41K
0005435612583	5316	212	42C
0005434343849	5316	213	42B
0005435612573	5316	214	42F
0005435612539	5316	215	42E
0005435612559	5316	216	42D
0005434244489	5316	217	42G
0005435612611	5316	218	42J
0005435612552	5316	219	42H
0005435612488	5316	220	43A
0005435612504	5316	221	42K
0005435612491	5316	222	43C
0005434343871	5316	223	43B
0005435097118	5316	224	43G
0005435612489	5316	225	43F
0005432047511	5316	226	43E
0005435423677	5316	227	43H
0005435612557	5316	228	44A
0005435423633	5316	229	43K
0005434343847	5316	230	44B
0005432133064	5316	231	44E
0005435612572	5316	232	44G
0005435612590	5316	233	45A
0005434573212	5316	234	44K
0005432133062	5316	235	45C
0005434343846	5316	236	45B
0005435612596	5316	237	45F
0005435423604	5316	238	45E
0005435612512	5316	239	45H
0005434343872	5316	240	45G
0005435423712	5316	241	45J
0005435612587	5316	242	46C
0005434343845	5316	243	46B
0005435612523	5316	244	46E
0005432133060	5316	245	46D
0005434343858	5316	246	46H
0005435612564	5316	247	47A
0005435612566	5316	248	47E
0005435423736	5316	249	47D
0005435612534	5316	250	47C
0005435612609	5316	251	47F
0005432133049	5316	252	47K
0005435612529	5316	253	47H
0005435612535	5316	254	48D
0005435612506	5316	255	48C
0005435612570	5316	256	48A
0005435612607	5316	257	48E
0005435423673	5316	258	48H
0005435490190	5316	259	48G
0005435612556	5316	260	48F
0005435423918	5316	261	48K
0005434343868	5316	262	49D
0005434343839	5316	263	49C
0005435612519	5316	264	49F
0005435423619	5316	265	49G
0005434343838	5316	266	50C
0005435490191	5316	267	49K
0005435319429	5316	268	50E
0005434343861	5316	269	50K
0005434343853	5316	270	51F
0005435612560	5316	271	51D
0005435611750	10911	1	1C
0005435424073	10911	2	1A
0005435612100	10911	3	1G
0005435424136	10911	4	1H
0005434244673	10911	5	2D
0005435319480	10911	6	2C
0005435424072	10911	7	2H
0005435611852	10911	8	3A
0005435424100	10911	9	3C
0005435304115	10911	10	3K
0005435424128	10911	11	3H
0005435424120	10911	12	3G
0005435424111	10911	13	4G
0005435424108	10911	14	4K
0005432164961	10911	15	5C
0005435304117	10911	16	5H
0005435319479	10911	17	5K
0005434244666	10911	18	11C
0005432164959	10911	19	11E
0005435424083	10911	20	12G
0005432164963	10911	21	12F
0005435424084	10911	22	13F
0005435424107	10911	23	13E
0005434656534	10911	24	13H
0005435611871	10911	25	14E
0005435424077	10911	26	14D
0005434244682	10911	27	14G
0005434244688	10911	28	14H
0005435611745	10911	29	15D
0005435424088	10911	30	15G
0005435042833	10911	31	16D
0005435424116	10911	32	16F
0005435319478	10911	33	16E
0005434343653	10911	34	17E
0005435424076	10911	35	17H
0005435612101	10911	36	18B
0005435611846	10911	37	18E
0005435612064	10911	38	18K
0005434656535	10911	39	18J
0005435424078	10911	40	19F
0005435424096	10911	41	19K
0005434244665	10911	42	20H
0005434244679	10911	43	20K
0005435424093	10911	44	20J
0005435424138	10911	45	21B
0005434244690	10911	46	21F
0005433719106	10911	47	21J
0005435424135	10911	48	22B
0005435424121	10911	49	22E
0005435424069	10911	50	22G
0005434244687	10911	51	22J
0005435611785	10911	52	23B
0005435424105	10911	53	23A
0005435611834	10911	54	23E
0005435424095	10911	55	23D
0005434244668	10911	56	23H
0005435424119	10911	57	24F
0005435611970	10911	58	24E
0005432166870	10911	59	25A
0005435319484	10911	60	25D
0005435424127	10911	61	25C
0005435424129	10911	62	25G
0005435042834	10911	63	25K
0005434656537	10911	64	25J
0005434244692	10911	65	26C
0005435424130	10911	66	26E
0005434244669	10911	67	26H
0005435611965	10911	68	26G
0005435611845	10911	69	26K
0005435612042	10911	70	27E
0005434656536	10911	71	27J
0005435424079	10911	72	28A
0005434244681	10911	73	27K
0005435424134	10911	74	28B
0005434244693	10911	75	28J
0005435424102	10911	76	28H
0005435319485	10911	77	29A
0005435611884	10911	78	29C
0005435424097	10911	79	29G
0005432363383	10911	80	30A
0005434244691	10911	81	30C
0005434244686	10911	82	30G
0005432164960	10911	83	30J
0005435319486	10911	84	30H
0005435424125	10911	85	31A
0005432164957	10911	86	31F
0005435424074	10911	87	31E
0005432840992	10911	88	31K
0005433719107	10911	89	32C
0005435424131	10911	90	32A
0005435304116	10911	91	32E
0005435424071	10911	92	32H
0005434244683	10911	93	32F
0005435424133	10911	94	33A
0005435424080	10911	95	33D
0005432166868	10911	96	33F
0005434244689	10911	97	33E
0005435611914	10911	98	33H
0005435424091	10911	99	34B
0005432164956	10911	100	34E
0005434244678	10911	101	34D
0005435424118	10911	102	34F
0005433719105	10911	103	34J
0005432166869	10911	104	35D
0005434244675	10911	105	35B
0005434244676	10911	106	35F
0005435424113	10911	107	35E
0005434244677	10911	108	35K
0005435424117	10911	109	36D
0005435424132	10911	110	36H
0005434244684	10911	111	36G
0005435424082	10911	112	36F
0005434244685	10911	113	36J
0005435611833	10911	114	37F
0005435424124	10911	115	37E
0005435424109	10911	116	37G
0005435611825	10911	117	38J
0005435424115	10911	118	39B
0005434244672	10911	119	39H
0005435424110	10911	120	39G
0005435611744	10911	121	40A
0005432166867	10911	122	40C
0005435424075	10911	123	40B
0005435611823	10911	124	40D
0005435611821	10911	125	40H
0005434244667	10911	126	41C
0005432164962	10911	127	41J
0005435424094	10911	128	41H
0005434343676	10911	129	41K
0005435424114	10911	130	42C
0005435424101	10911	131	42G
0005432164958	10911	132	42J
0005435424081	10911	133	42H
0005435424086	10911	134	43D
0005435424092	10911	135	43C
0005435424070	10911	136	43F
0005435424126	10911	137	43E
0005434244671	10911	138	43H
0005435424122	10911	139	43J
0005435424112	10911	140	44C
0005435611784	10911	141	44B
0005435424106	10911	142	44A
0005435424104	10911	143	44G
0005435611714	10911	144	44J
0005435424123	10911	145	45B
0005435611824	10911	146	45A
0005435319482	10911	147	45D
0005435424089	10911	148	45F
0005435319483	10911	149	45E
0005435424137	10911	150	45H
0005435491407	10911	151	46E
0005434244670	10911	152	46D
0005435319481	10911	153	46G
0005435424087	10911	154	47A
0005435611793	10911	155	46K
0005434244674	10911	156	47C
0005435611853	10911	157	47G
0005434244680	10911	158	47F
0005432840991	10911	159	47K
0005435424103	10911	160	48C
0005435424098	10911	161	48A
0005435424085	10911	162	48F
0005435424099	10911	163	49D
0005434343654	10911	164	49K
0005435611822	10911	165	49H
0005435611847	10911	166	49G
0005434343594	10911	167	50D
0005435424090	10911	168	50G
0005435611872	10911	169	51G
0005433805020	3341	1	1C
0005433633472	3341	2	1F
0005433633491	3341	3	2D
0005432181479	3341	4	2C
0005432459042	3341	5	2F
0005433633464	3341	6	3C
0005433805029	3341	7	3A
0005433633473	3341	8	3F
0005433805014	3341	9	4A
0005433506983	3341	10	4D
0005433805015	3341	11	4C
0005432181497	3341	12	4F
0005433633488	3341	13	5A
0005432181481	3341	14	5C
0005432181490	3341	15	5D
0005433633469	3341	16	6D
0005433633485	3341	17	6C
0005433633482	3341	18	6A
0005433633458	3341	19	7A
0005433805010	3341	20	6F
0005433805034	3341	21	7D
0005433506991	3341	22	7C
0005433805044	3341	23	8A
0005433633487	3341	24	8B
0005433805035	3341	25	8D
0005433805043	3341	26	8C
0005433633471	3341	27	8E
0005432181489	3341	28	9B
0005432181496	3341	29	9A
0005433805036	3341	30	9C
0005433633463	3341	31	9D
0005433805013	3341	32	9F
0005432181488	3341	33	10A
0005433805040	3341	34	10B
0005432181499	3341	35	10D
0005433805021	3341	36	10E
0005433805023	3341	37	10F
0005432459049	3341	38	11A
0005433507000	3341	39	11C
0005433805028	3341	40	11B
0005433633474	3341	41	11E
0005433633475	3341	42	11F
0005433506986	3341	43	12D
0005433633466	3341	44	12C
0005433633461	3341	45	12F
0005433805004	3341	46	13A
0005432181494	3341	47	13C
0005433633490	3341	48	13D
0005432181495	3341	49	13E
0005432181491	3341	50	13F
0005433805007	3341	51	14B
0005433805006	3341	52	14C
0005433633457	3341	53	14E
0005433633489	3341	54	15C
0005432458988	3341	55	15D
0005433506984	3341	56	15E
0005433805024	3341	57	15F
0005432458984	3341	58	16C
0005432459050	3341	59	16B
0005433506993	3341	60	16E
0005432181502	3341	61	16F
0005433633483	3341	62	17B
0005433805033	3341	63	17A
0005433805046	3341	64	17C
0005432458985	3341	65	17F
0005433633478	3341	66	17E
0005433633470	3341	67	18A
0005433633462	3341	68	18C
0005433805030	3341	69	18B
0005433506989	3341	70	18D
0005433506987	3341	71	18E
0005432458957	3341	72	19B
0005432458958	3341	73	18F
0005432181492	3341	74	19C
0005433805016	3341	75	20A
0005432181498	3341	76	19E
0005433633468	3341	77	20B
0005433805041	3341	78	20C
0005433633459	3341	79	20E
0005433506997	3341	80	20D
0005432181486	3341	81	20F
0005433805019	3341	82	21A
0005433805031	3341	83	21D
0005432181484	3341	84	21C
0005432181482	3341	85	21E
0005432181483	3341	86	22A
0005433805042	3341	87	21F
0005433506994	3341	88	22C
0005432181501	3341	89	22D
0005433506992	3341	90	22F
0005433805022	3341	91	22E
0005433805039	3341	92	23A
0005432181487	3341	93	23C
0005432181485	3341	94	23D
0005433805008	3341	95	23E
0005433633481	3341	96	24A
0005433805038	3341	97	24D
0005433805017	3341	98	24E
0005433506998	3341	99	24F
0005433805018	3341	100	25B
0005433506996	3341	101	25A
0005433506988	3341	102	25C
0005433633479	3341	103	25D
0005433507001	3341	104	25E
0005433805005	3341	105	25F
0005433805012	3341	106	26B
0005433805032	3341	107	26D
0005433506999	3341	108	26C
0005433805045	3341	109	26F
0005432458986	3341	110	27A
0005432459041	3341	111	27C
0005433506990	3341	112	27B
0005433633467	3341	113	27E
0005432181480	3341	114	28A
0005433506995	3341	115	27F
0005433805025	3341	116	28B
0005433805026	3341	117	28E
0005433805037	3341	118	28D
0005433805027	3341	119	28F
0005432181493	3341	120	29B
0005433633476	3341	121	29A
0005433633484	3341	122	29D
0005433805011	3341	123	29F
0005432458959	3341	124	30B
0005433506982	3341	125	30E
0005432181500	3341	126	30D
0005433633486	3341	127	30F
0005433633465	3341	128	31B
0005433506985	3341	129	31A
0005433633460	3341	130	31C
0005433633477	3341	131	31E
0005433805009	3341	132	31D
0005433633480	3341	133	31F
0005435884497	3342	1	1D
0005435884516	3342	2	2F
0005435884422	3342	3	3D
0005435884390	3342	4	4D
0005435884404	3342	5	10A
0005435884515	3342	6	13B
0005435884480	3342	7	13E
0005435884449	3342	8	14C
0005435884511	3342	9	14B
0005435884533	3342	10	15A
0005435884407	3342	11	18F
0005435884663	3342	12	20B
0005435884448	3342	13	20C
0005435884411	3342	14	20D
0005435884441	3342	15	21A
0005435884510	3342	16	21D
0005435884664	3342	17	22F
0005435884537	3342	18	23D
0005435884512	3342	19	23E
0005435884503	3342	20	24E
0005435884405	3342	21	25C
0005435884532	3342	22	26E
0005435884406	3342	23	27A
0005435884504	3342	24	27B
0005435884421	3342	25	30E
0005435884573	3342	26	31E
0005432042573	8210	1	1A
0005432042574	8210	2	1F
0005435884747	8210	3	1D
0005432459339	8210	4	2D
0005432459363	8210	5	2F
0005435884755	8210	6	4A
0005432042568	8210	7	3F
0005435884749	8210	8	4C
0005433506855	8210	9	4D
0005432459364	8210	10	5A
0005433506856	8210	11	5D
0005432042571	8210	12	5C
0005432459354	8210	13	5F
0005435884738	8210	14	6A
0005432459347	8210	15	6D
0005435884767	8210	16	6C
0005432459371	8210	17	7A
0005432459357	8210	18	7C
0005432042567	8210	19	7F
0005432459348	8210	20	7D
0005432459370	8210	21	8A
0005432042577	8210	22	8B
0005435884753	8210	23	8D
0005432459355	8210	24	8F
0005432459376	8210	25	8E
0005435884739	8210	26	9B
0005435884731	8210	27	9A
0005432042572	8210	28	9E
0005432459383	8210	29	10A
0005434312298	8210	30	10D
0005435884722	8210	31	10C
0005435884724	8210	32	10E
0005435884758	8210	33	10F
0005432459368	8210	34	11B
0005435884757	8210	35	11D
0005432459378	8210	36	11C
0005435884726	8210	37	11E
0005435884759	8210	38	12A
0005432459342	8210	39	12B
0005435884760	8210	40	12C
0005435884742	8210	41	12E
0005432459337	8210	42	12F
0005432042569	8210	43	13A
0005432459334	8210	44	13D
0005432459332	8210	45	13E
0005432459333	8210	46	14A
0005432459341	8210	47	14C
0005435884729	8210	48	14B
0005432459377	8210	49	14D
0005435884741	8210	50	14E
0005435884756	8210	51	14F
0005435884765	8210	52	15B
0005435884723	8210	53	15C
0005435884736	8210	54	15D
0005435884762	8210	55	15E
0005435884732	8210	56	16A
0005432459350	8210	57	15F
0005435884733	8210	58	16C
0005432459335	8210	59	16B
0005432459349	8210	60	16E
0005434312299	8210	61	16D
0005432459360	8210	62	16F
0005435884764	8210	63	17D
0005435884745	8210	64	17B
0005432459359	8210	65	17E
0005432459366	8210	66	18A
0005435884751	8210	67	17F
0005432459343	8210	68	18B
0005432459382	8210	69	18E
0005432459361	8210	70	18D
0005432459379	8210	71	18F
0005432459330	8210	72	19C
0005432042576	8210	73	19B
0005435884750	8210	74	19D
0005435884725	8210	75	19E
0005435884754	8210	76	20B
0005435884743	8210	77	20A
0005433506871	8210	78	20C
0005432459356	8210	79	20E
0005432042570	8210	80	20D
0005432459344	8210	81	20F
0005432459352	8210	82	21C
0005432042580	8210	83	21D
0005435884746	8210	84	21E
0005435884734	8210	85	22A
0005432459381	8210	86	22D
0005432459369	8210	87	22F
0005435884727	8210	88	23C
0005435884748	8210	89	23E
0005435884768	8210	90	24A
0005432459372	8210	91	24B
0005435884728	8210	92	24D
0005435884740	8210	93	24C
0005435884744	8210	94	24F
0005432459346	8210	95	24E
0005432459340	8210	96	25C
0005432459345	8210	97	25D
0005432459331	8210	98	25F
0005435884752	8210	99	25E
0005433506873	8210	100	26B
0005432459351	8210	101	26A
0005432042575	8210	102	26D
0005432042578	8210	103	26C
0005432459365	8210	104	26E
0005435884730	8210	105	26F
0005432459362	8210	106	27A
0005432459338	8210	107	27C
0005435884761	8210	108	27D
0005435884735	8210	109	27F
0005432042579	8210	110	27E
0005432459374	8210	111	28B
0005432459380	8210	112	28F
0005432459336	8210	113	29C
0005432459353	8210	114	29D
0005432459373	8210	115	29F
0005432459358	8210	116	30A
0005433506872	8210	117	30B
0005432459367	8210	118	30C
0005435884766	8210	119	30E
0005432459375	8210	120	30D
0005435884737	8210	121	30F
0005435884763	8210	122	31A
0005433804843	8223	1	4A
0005433804784	8223	2	7A
0005433633289	8223	3	8C
0005433804795	8223	4	9F
0005433804786	8223	5	10F
0005433633315	8223	6	11A
0005433633272	8223	7	11E
0005433804864	8223	8	12B
0005433804815	8223	9	13A
0005433804823	8223	10	14D
0005434271276	8223	11	17B
0005433804785	8223	12	20F
0005433804812	8223	13	21C
0005433804802	8223	14	21F
0005433633296	8223	15	25D
0005433804855	8223	16	25E
0005433633314	8223	17	26A
0005433804854	8223	18	26F
0005433633295	8223	19	30B
0005433804791	8223	20	30E
0005433804794	8223	21	31F
0005434183549	8247	1	14A
0005434183548	8247	2	14E
0005432727809	4510	1	1D
0005432382778	4510	2	2A
0005433722155	4510	3	2C
0005432382799	4510	4	2D
0005432382797	4510	5	2F
0005432382792	4510	6	3D
0005432382781	4510	7	3F
0005433722156	4510	8	4A
0005432382773	4510	9	4D
0005432382791	4510	10	5A
0005432382793	4510	11	5E
0005432382801	4510	12	6A
0005432727815	4510	13	6E
0005432382782	4510	14	6F
0005432382798	4510	15	8A
0005432382803	4510	16	8D
0005432382769	4510	17	8E
0005432382771	4510	18	9A
0005432727807	4510	19	8F
0005432382780	4510	20	9C
0005433454853	4510	21	10A
0005432382784	4510	22	10C
0005432382767	4510	23	10F
0005432382774	4510	24	11A
0005432382779	4510	25	11C
0005432727817	4510	26	11D
0005432727814	4510	27	11F
0005432382787	4510	28	12A
0005432382790	4510	29	12C
0005432727816	4510	30	12D
0005433722157	4510	31	12E
0005432382768	4510	32	12F
0005433454852	4510	33	13D
0005432382794	4510	34	13E
0005432727806	4510	35	13F
0005432727810	4510	36	14A
0005432382796	4510	37	14E
0005432382795	4510	38	15A
0005432382788	4510	39	15D
0005432727805	4510	40	15E
0005432382783	4510	41	16C
0005432382789	4510	42	16E
0005432727811	4510	43	16F
0005432382786	4510	44	17A
0005432382800	4510	45	17C
0005432382772	4510	46	17F
0005432382776	4510	47	18A
0005432727812	4510	48	18E
0005432382777	4510	49	18F
0005432727808	4510	50	19C
0005432382770	4510	51	19F
0005432382785	4510	52	20A
0005432382802	4510	53	20C
0005432727813	4510	54	20D
0005432382775	4510	55	20E
0005432382491	30261	1	1F
0005432382492	30261	2	7E
0005432727725	30261	3	11C
0005432727750	30261	4	14F
0005432727716	30261	5	19F
0005435540794	1709	1	1C
0005435540784	1709	2	1A
0005435529041	1709	3	2C
0005435540779	1709	4	2D
0005435540796	1709	5	2F
0005435540793	1709	6	3A
0005433516795	1709	7	3F
0005435529040	1709	8	4C
0005435529049	1709	9	5A
0005432924957	1709	10	5C
0005435529034	1709	11	5D
0005433516793	1709	12	5E
0005432294464	1709	13	5F
0005435540783	1709	14	6A
0005435540778	1709	15	6C
0005435540780	1709	16	6E
0005435540792	1709	17	6F
0005435529042	1709	18	7A
0005433516789	1709	19	7C
0005435540788	1709	20	7E
0005435529053	1709	21	8A
0005435540797	1709	22	8C
0005435529035	1709	23	8D
0005432294463	1709	24	8E
0005435529051	1709	25	9D
0005435540791	1709	26	9F
0005435529043	1709	27	10A
0005435540785	1709	28	10C
0005433516788	1709	29	10D
0005435540781	1709	30	11E
0005435529045	1709	31	11F
0005435529047	1709	32	13C
0005435529052	1709	33	13E
0005435540782	1709	34	14E
0005435540786	1709	35	14F
0005433516796	1709	36	15A
0005435540789	1709	37	15D
0005433516790	1709	38	15F
0005435529046	1709	39	16C
0005435540795	1709	40	16D
0005435540799	1709	41	16E
0005435529044	1709	42	17A
0005433516787	1709	43	17C
0005433516794	1709	44	17D
0005435540787	1709	45	17E
0005435529048	1709	46	17F
0005435540798	1709	47	18A
0005435529038	1709	48	18C
0005435529036	1709	49	18D
0005432294462	1709	50	19A
0005435529054	1709	51	19C
0005433516791	1709	52	19D
0005435529037	1709	53	19E
0005433516792	1709	54	20A
0005435529039	1709	55	20C
0005435529050	1709	56	20D
0005435540790	1709	57	20E
0005432924989	21995	1	2C
0005432924986	21995	2	3C
0005435540626	21995	3	5C
0005435540647	21995	4	6C
0005432924987	21995	5	6E
0005435517616	21995	6	8D
0005435517618	21995	7	13F
0005432924988	21995	8	14C
0005435517587	21995	9	14D
0005435517627	21995	10	14F
0005432924990	21995	11	15D
0005435517586	21995	12	15E
0005435540630	21995	13	16C
0005433516726	21995	14	16D
0005432073355	7398	1	1A
0005432838711	7398	2	1D
0005432838731	7398	3	2A
0005432838703	7398	4	2C
0005435252417	7398	5	2F
0005434458596	7398	6	3C
0005434458583	7398	7	3F
0005435252416	7398	8	4A
0005432838730	7398	9	4C
0005432838710	7398	10	4D
0005434458598	7398	11	4E
0005432838704	7398	12	5A
0005435252409	7398	13	5C
0005432838727	7398	14	5D
0005434458597	7398	15	5E
0005435252415	7398	16	5F
0005434458599	7398	17	6A
0005432840990	7398	18	6C
0005434458589	7398	19	6D
0005432838720	7398	20	6E
0005434458593	7398	21	6F
0005432838717	7398	22	7C
0005432838725	7398	23	7F
0005432838728	7398	24	8A
0005432838722	7398	25	8C
0005434458600	7398	26	8D
0005432823428	7398	27	8E
0005432073354	7398	28	8F
0005432838719	7398	29	9A
0005434458584	7398	30	9D
0005432838721	7398	31	9E
0005434458602	7398	32	10C
0005432838714	7398	33	10D
0005434458603	7398	34	10E
0005434458588	7398	35	11A
0005432838718	7398	36	11C
0005432838726	7398	37	11D
0005435252388	7398	38	11E
0005432838706	7398	39	11F
0005432840989	7398	40	12E
0005432838723	7398	41	12F
0005432838713	7398	42	13C
0005432838724	7398	43	13D
0005432838707	7398	44	13E
0005432838734	7398	45	13F
0005434458591	7398	46	14A
0005435252382	7398	47	14C
0005435252379	7398	48	14E
0005432838729	7398	49	14F
0005432838709	7398	50	15A
0005432838705	7398	51	15D
0005434458586	7398	52	16C
0005432838733	7398	53	16D
0005432838715	7398	54	16E
0005432838716	7398	55	16F
0005434458601	7398	56	17A
0005432838732	7398	57	17C
0005432838712	7398	58	17E
0005432838708	7398	59	17F
0005434458594	7398	60	18A
0005432073356	7398	61	18C
0005434458585	7398	62	18D
0005435252418	7398	63	18E
0005434458592	7398	64	18F
0005434458590	7398	65	19C
0005432823427	7398	66	19D
0005434458595	7398	67	19E
0005434458587	7398	68	20F
0005435252512	28948	1	1A
0005432838508	28948	2	2A
0005432001003	28948	3	2C
0005434458448	28948	4	3A
0005435491422	28948	5	2F
0005435252514	28948	6	3D
0005434664936	28948	7	3F
0005435252515	28948	8	4C
0005435252526	28948	9	4D
0005435252517	28948	10	4E
0005432838499	28948	11	5C
0005434458449	28948	12	5D
0005435252519	28948	13	5E
0005432838560	28948	14	6D
0005432001004	28948	15	6F
0005434458476	28948	16	7A
0005432838529	28948	17	7F
0005434664937	28948	18	8A
0005432838637	28948	19	8F
0005432823418	28948	20	9D
0005432838554	28948	21	9E
0005435252525	28948	22	9F
0005432838535	28948	23	10A
0005434458463	28948	24	10D
0005432838500	28948	25	10E
0005435252527	28948	26	10F
0005432838544	28948	27	11C
0005435252509	28948	28	11D
0005435252510	28948	29	11E
0005434458518	28948	30	11F
0005435252511	28948	31	12A
0005432840977	28948	32	12E
0005435252528	28948	33	13D
0005432838559	28948	34	13F
0005432838543	28948	35	14A
0005434458517	28948	36	14C
0005432838530	28948	37	14E
0005432838495	28948	38	15D
0005432838494	28948	39	15E
0005435252513	28948	40	15F
0005435491420	28948	41	16A
0005435252522	28948	42	16C
0005432838493	28948	43	16E
0005435491421	28948	44	16F
0005434458462	28948	45	17C
0005435252523	28948	46	17D
0005434458475	28948	47	18A
0005435252524	28948	48	18C
0005432840978	28948	49	18D
0005435252520	28948	50	18F
0005435252516	28948	51	19A
0005432838587	28948	52	20A
0005435252518	28948	53	20C
0005435252521	28948	54	20D
0005434664938	28948	55	20E
0005432838488	28948	56	20F
0005435990549	8784	1	4F
0005434275945	8784	2	6C
0005435990552	8784	3	9D
0005435990550	8784	4	10A
0005435990553	8784	5	11A
0005435990551	8784	6	12C
0005435990554	8784	7	15C
0005434275933	8784	8	16B
0005434275944	8784	9	19B
0005435990548	8784	10	21C
0005435990516	15741	1	3D
0005434275970	15741	2	8D
0005434275966	15741	3	13C
0005434275969	15741	4	15A
0005434275967	15741	5	17E
0005434275968	15741	6	18B
0005434275965	15741	7	18D
0005435990503	15741	8	21C
0005433468245	2075	1	1B
0005433468238	2075	2	1D
0005433468237	2075	3	2A
0005433468248	2075	4	2B
0005433468247	2075	5	2D
0005433468251	2075	6	3B
0005433468249	2075	7	3D
0005433468246	2075	8	4A
0005433468235	2075	9	4C
0005433468236	2075	10	5C
0005433468243	2075	11	7A
0005433468244	2075	12	7B
0005433468250	2075	13	19C
0005433468234	2075	14	19D
0005433468241	2075	15	20A
0005433468252	2075	16	20B
0005433468253	2075	17	21A
0005433468240	2075	18	22A
0005433468242	2075	19	22D
0005433468239	2075	20	23B
0005432359852	6378	1	1A
0005432359894	6378	2	1C
0005432335914	6378	3	1D
0005432359856	6378	4	2C
0005432359857	6378	5	2A
0005432359873	6378	6	2F
0005432359853	6378	7	3A
0005432359879	6378	8	3D
0005435176631	6378	9	3F
0005432359889	6378	10	4A
0005432359868	6378	11	4B
0005435176589	6378	12	4D
0005432359882	6378	13	4F
0005432359851	6378	14	5B
0005435176632	6378	15	5C
0005435176617	6378	16	5D
0005432335910	6378	17	5E
0005435176641	6378	18	6A
0005432359858	6378	19	6C
0005435176681	6378	20	6E
0005432359874	6378	21	7D
0005434149541	6378	22	8A
0005435176628	6378	23	8B
0005432335913	6378	24	8C
0005432359899	6378	25	8E
0005432359895	6378	26	8D
0005432359871	6378	27	9C
0005432359870	6378	28	9E
0005432335912	6378	29	9F
0005435176588	6378	30	10B
0005432335908	6378	31	11A
0005432359881	6378	32	10E
0005432335918	6378	33	11D
0005432359878	6378	34	11C
0005432359890	6378	35	11E
0005432359898	6378	36	11F
0005432359893	6378	37	12A
0005434149562	6378	38	12D
0005432359867	6378	39	12E
0005432359875	6378	40	13A
0005432359862	6378	41	12F
0005432359861	6378	42	13B
0005432062175	6378	43	13C
0005432359892	6378	44	13E
0005432359886	6378	45	14A
0005432359864	6378	46	13F
0005432062176	6378	47	14C
0005432335917	6378	48	14D
0005432359887	6378	49	14E
0005432359888	6378	50	15A
0005432359880	6378	51	14F
0005432359891	6378	52	15C
0005432335909	6378	53	15E
0005435176639	6378	54	15D
0005432359855	6378	55	15F
0005435176624	6378	56	16B
0005432062174	6378	57	16A
0005432359877	6378	58	16C
0005432359865	6378	59	16D
0005432359860	6378	60	16F
0005435176662	6378	61	16E
0005432359869	6378	62	17B
0005432062172	6378	63	18A
0005432335907	6378	64	18B
0005435176640	6378	65	18C
0005432335915	6378	66	18E
0005435176660	6378	67	19B
0005435176743	6378	68	19C
0005432359896	6378	69	20A
0005432062173	6378	70	20B
0005432359872	6378	71	20D
0005435176661	6378	72	20E
0005435176655	6378	73	21B
0005432335916	6378	74	21A
0005432359885	6378	75	21C
0005432359884	6378	76	21D
0005432359863	6378	77	21E
0005435176625	6378	78	21F
0005432359883	6378	79	22A
0005432359876	6378	80	22C
0005432359859	6378	81	22B
0005434149559	6378	82	22E
0005432359866	6378	83	22D
0005432335911	6378	84	22F
0005432359897	6378	85	23A
0005432363383	6378	86	23D
0005432359854	6378	87	23F
0005432052716	21039	1	2C
0005432335825	21039	2	2A
0005432359599	21039	3	2F
0005432359696	21039	4	3C
0005432359549	21039	5	4A
0005435176799	21039	6	4B
0005432335827	21039	7	4F
0005435176806	21039	8	5C
0005434149614	21039	9	5B
0005434149612	21039	10	5D
0005435176810	21039	11	5F
0005432359512	21039	12	6C
0005434149604	21039	13	6B
0005434149610	21039	14	6E
0005432359728	21039	15	7A
0005435176804	21039	16	7B
0005435176803	21039	17	7C
0005435176783	21039	18	7D
0005435176792	21039	19	7E
0005435176790	21039	20	8A
0005432359742	21039	21	8D
0005435176789	21039	22	8E
0005435176788	21039	23	9B
0005435490192	21039	24	9D
0005432359543	21039	25	9E
0005435176798	21039	26	11A
0005432363364	21039	27	11B
0005432335826	21039	28	11F
0005435176787	21039	29	12A
0005435176807	21039	30	12C
0005434149611	21039	31	12B
0005435176785	21039	32	12D
0005435176800	21039	33	13D
0005432359629	21039	34	13E
0005435176805	21039	35	13F
0005432359602	21039	36	14B
0005432359727	21039	37	14D
0005434149605	21039	38	14C
0005434149608	21039	39	14E
0005435176791	21039	40	15C
0005435176794	21039	41	15B
0005432359548	21039	42	15D
0005432359513	21039	43	15F
0005432052715	21039	44	15E
0005432052714	21039	45	16A
0005432335828	21039	46	16B
0005435176808	21039	47	16F
0005435176797	21039	48	17B
0005435490194	21039	49	17C
0005432359606	21039	50	17E
0005435490193	21039	51	17D
0005432359527	21039	52	17F
0005432359607	21039	53	18A
0005432052713	21039	54	18D
0005432363363	21039	55	18E
0005435176809	21039	56	18F
0005435723025	21039	57	19A
0005435176795	21039	58	19B
0005432335823	21039	59	19C
0005435176786	21039	60	19E
0005435176801	21039	61	19D
0005435176796	21039	62	19F
0005432359641	21039	63	20C
0005434149613	21039	64	20E
0005434149615	21039	65	20F
0005432359550	21039	66	21A
0005432335833	21039	67	21C
0005432359598	21039	68	21F
0005432359519	21039	69	21E
0005435723026	21039	70	22C
0005434149609	21039	71	22E
0005435176793	21039	72	23A
0005435176802	21039	73	23C
0005435176784	21039	74	23E
0005434149606	21039	75	23D
0005434149607	21039	76	23F
0005434458441	17721	1	2C
0005434458527	17721	2	2D
0005434458525	17721	3	3A
0005434458491	17721	4	3D
0005434458440	17721	5	4C
0005434458474	17721	6	4D
0005434186169	17721	7	5C
0005434186168	17721	8	6A
0005434458523	17721	9	19C
0005434186170	17721	10	19D
0005434458526	17721	11	20A
0005434458461	17721	12	20B
0005434458434	17721	13	21D
0005434186171	17721	14	23B
0005434458602	29087	1	1B
0005434458583	29087	2	2C
0005434458585	29087	3	3A
0005434462766	29087	4	3D
0005434458601	29087	5	4C
0005434458595	29087	6	4D
0005434458587	29087	7	5B
0005434458597	29087	8	5C
0005434458586	29087	9	5D
0005434458589	29087	10	6B
0005434448276	29087	11	6C
0005434458593	29087	12	6D
0005434458591	29087	13	18A
0005434458596	29087	14	18B
0005434462765	29087	15	18D
0005434458590	29087	16	19B
0005434448275	29087	17	19C
0005434458588	29087	18	20B
0005434458600	29087	19	20C
0005434448277	29087	20	20D
0005434458594	29087	21	21A
0005434463905	29087	22	21B
0005434458592	29087	23	21C
0005434463904	29087	24	22A
0005434458584	29087	25	22B
0005434458598	29087	26	22C
0005434458599	29087	27	22D
0005434458603	29087	28	23B
0005432603925	21459	1	1A
0005432603906	21459	2	1B
0005432603918	21459	3	1C
0005432603893	21459	4	1D
0005432603899	21459	5	2A
0005432603885	21459	6	2B
0005432603894	21459	7	2C
0005432603924	21459	8	2D
0005432603903	21459	9	3A
0005432603896	21459	10	3B
0005432603915	21459	11	4A
0005432603909	21459	12	3D
0005432603921	21459	13	4B
0005432603891	21459	14	4C
0005432603916	21459	15	4D
0005432603907	21459	16	5A
0005432603886	21459	17	5B
0005432603892	21459	18	5C
0005432603900	21459	19	5D
0005432603905	21459	20	6B
0005432603920	21459	21	6C
0005432603910	21459	22	7B
0005432603913	21459	23	7C
0005432603902	21459	24	7D
0005432603911	21459	25	18B
0005432603890	21459	26	18C
0005432603895	21459	27	18D
0005432603888	21459	28	19A
0005432603887	21459	29	19C
0005432603889	21459	30	20A
0005432603914	21459	31	20B
0005432603904	21459	32	20C
0005432603908	21459	33	21A
0005432603901	21459	34	21B
0005432603898	21459	35	21C
0005432603912	21459	36	21D
0005432603923	21459	37	22B
0005432603919	21459	38	22C
0005432603917	21459	39	22D
0005432603922	21459	40	23A
0005432603897	21459	41	23B
0005432603680	31688	1	1D
0005432603685	31688	2	2B
0005432603665	31688	3	2C
0005432603679	31688	4	4C
0005432603647	31688	5	6B
0005432603734	31688	6	7D
0005432603648	31688	7	20C
0005432603705	31688	8	21B
0005432603674	31688	9	22A
0005432603673	31688	10	22D
0005433293186	29612	1	1A
0005433293183	29612	2	2A
0005433293189	29612	3	3B
0005433293184	29612	4	4A
0005433293178	29612	5	4C
0005433293195	29612	6	5B
0005433293181	29612	7	5C
0005433293192	29612	8	6A
0005433293197	29612	9	6B
0005433293190	29612	10	7A
0005433293193	29612	11	7B
0005433293191	29612	12	7D
0005433293187	29612	13	19A
0005433293179	29612	14	20A
0005433293188	29612	15	21A
0005433293185	29612	16	21C
0005433293196	29612	17	21D
0005433293194	29612	18	22D
0005433293180	29612	19	23A
0005433293182	29612	20	23B
0005433473168	6675	1	1B
0005435257149	6675	2	1C
0005433473157	6675	3	1D
0005433473161	6675	4	2C
0005433473150	6675	5	2D
0005433473172	6675	6	3A
0005433473155	6675	7	3B
0005433473162	6675	8	3C
0005433473166	6675	9	4B
0005433473148	6675	10	4C
0005433473159	6675	11	5C
0005433473151	6675	12	5D
0005433473165	6675	13	6A
0005433473152	6675	14	6B
0005433473153	6675	15	6C
0005433473149	6675	16	6D
0005433473170	6675	17	7A
0005433473167	6675	18	7C
0005433473156	6675	19	18A
0005433473158	6675	20	18D
0005433473154	6675	21	19A
0005435257151	6675	22	19C
0005433473163	6675	23	19D
0005433473164	6675	24	20C
0005433473171	6675	25	21A
0005433473169	6675	26	21C
0005433473174	6675	27	21D
0005433473160	6675	28	22C
0005433473173	6675	29	23A
0005434606786	22284	1	1A
0005434606788	22284	2	1B
0005434606785	22284	3	2B
0005434604860	22284	4	3B
0005434604859	22284	5	4A
0005434604862	22284	6	5B
0005434604861	22284	7	6A
0005434606787	22284	8	6B
0005432747140	411	1	1A
0005432747149	411	2	1C
0005432747162	411	3	1D
0005432890688	411	4	1F
0005432747151	411	5	2A
0005432753263	411	6	2C
0005432747171	411	7	2D
0005432747157	411	8	3A
0005432747174	411	9	3C
0005432747180	411	10	3D
0005432890704	411	11	3F
0005432890747	411	12	4A
0005432747175	411	13	4C
0005432747160	411	14	4D
0005432749760	411	15	4E
0005432747150	411	16	5A
0005432751491	411	17	5C
0005432753265	411	18	5D
0005432747179	411	19	5E
0005432747146	411	20	6E
0005432751490	411	21	6F
0005432747167	411	22	7A
0005432747147	411	23	7E
0005432747163	411	24	7F
0005432747158	411	25	8D
0005432747144	411	26	8E
0005432753262	411	27	8F
0005432747176	411	28	9A
0005432747166	411	29	9C
0005432749761	411	30	9E
0005432747143	411	31	9F
0005432219959	411	32	10A
0005432890675	411	33	10C
0005432747168	411	34	11D
0005432890669	411	35	11E
0005432747164	411	36	12A
0005432219956	411	37	12C
0005432747145	411	38	12D
0005432747155	411	39	13A
0005432747172	411	40	13D
0005432747177	411	41	13F
0005432890701	411	42	14F
0005432747152	411	43	15A
0005432747141	411	44	15C
0005432747173	411	45	15D
0005432747159	411	46	15F
0005432747153	411	47	15E
0005432890689	411	48	16A
0005432219960	411	49	16C
0005432747170	411	50	16F
0005432747156	411	51	17A
0005432751489	411	52	17C
0005432747165	411	53	17D
0005432747148	411	54	17F
0005432890674	411	55	18C
0005432747142	411	56	18D
0005432747154	411	57	18E
0005432219958	411	58	19C
0005432747161	411	59	19D
0005432753264	411	60	19E
0005432747178	411	61	19F
0005432219957	411	62	20A
0005432751488	411	63	20D
0005432747169	411	64	20F
0005432890812	12061	1	1A
0005432749748	12061	2	1C
0005432890820	12061	3	1D
0005432890827	12061	4	1F
0005432746866	12061	5	2A
0005432890828	12061	6	2C
0005432746974	12061	7	3A
0005432890824	12061	8	3F
0005432890817	12061	9	3D
0005432890814	12061	10	4A
0005432746940	12061	11	4E
0005432746868	12061	12	5C
0005432746867	12061	13	6E
0005432746941	12061	14	6F
0005432214781	12061	15	7D
0005432749747	12061	16	7F
0005432746883	12061	17	8A
0005432747021	12061	18	8F
0005432746919	12061	19	9C
0005432746884	12061	20	9D
0005432890819	12061	21	9F
0005432747044	12061	22	10A
0005432746928	12061	23	10C
0005432890818	12061	24	10F
0005432747002	12061	25	11D
0005432890823	12061	26	12A
0005432890822	12061	27	12C
0005432746969	12061	28	12E
0005432756796	12061	29	13A
0005432747019	12061	30	14A
0005432747020	12061	31	14D
0005432214780	12061	32	14E
0005432890825	12061	33	15A
0005432747008	12061	34	15C
0005432890816	12061	35	15E
0005432890813	12061	36	15F
0005432746910	12061	37	16A
0005432890809	12061	38	16E
0005432747043	12061	39	17C
0005432746880	12061	40	18E
0005432890826	12061	41	18F
0005433875364	12061	42	19A
0005432746968	12061	43	19C
0005432746881	12061	44	19F
0005432890810	12061	45	20A
0005432890821	12061	46	20C
0005432890811	12061	47	20E
0005432890815	12061	48	20F
0005433533263	18987	1	1B
0005433524917	18987	2	1D
0005433524918	18987	3	3B
0005433531249	18987	4	3D
0005433533267	18987	5	5A
0005433524921	18987	6	5C
0005433524916	18987	7	7B
0005433533264	18987	8	18A
0005433524922	18987	9	18D
0005433524915	18987	10	19C
0005433531251	18987	11	19D
0005433524914	18987	12	20A
0005433524920	18987	13	20B
0005433533265	18987	14	20C
0005433524913	18987	15	20D
0005433524912	18987	16	22B
0005433524919	18987	17	22C
0005433533266	18987	18	22D
0005433531250	18987	19	23A
0005432927930	32494	1	2A
0005432927927	32494	2	3A
0005433524846	32494	3	3C
0005432927928	32494	4	3D
0005432927929	32494	5	4C
0005432927926	32494	6	7D
0005432927925	32494	7	18C
0005435372358	5247	1	1C
0005434822238	5247	2	1G
0005435304093	5247	3	1H
0005434822252	5247	4	2A
0005434822329	5247	5	3A
0005434558196	5247	6	2K
0005434822232	5247	7	3D
0005434822313	5247	8	3H
0005432121188	5247	9	3G
0005434558197	5247	10	4K
0005434831095	5247	11	4H
0005434822349	5247	12	5C
0005434822282	5247	13	5H
0005434822323	5247	14	5G
0005434822319	5247	15	11C
0005434822262	5247	16	11F
0005434822346	5247	17	12C
0005434822317	5247	18	12A
0005434822263	5247	19	11K
0005434822327	5247	20	12E
0005434822338	5247	21	12D
0005434822243	5247	22	12G
0005434822314	5247	23	12F
0005435149896	5247	24	12K
0005434822342	5247	25	12H
0005432396201	5247	26	13C
0005434822274	5247	27	13E
0005434822246	5247	28	13G
0005434822270	5247	29	14A
0005432396202	5247	30	13K
0005434822284	5247	31	14E
0005434664934	5247	32	14D
0005434822234	5247	33	14G
0005435149888	5247	34	14F
0005434822269	5247	35	15A
0005434822326	5247	36	15D
0005434822289	5247	37	15G
0005434822322	5247	38	15F
0005434822290	5247	39	16A
0005434822265	5247	40	15K
0005435372207	5247	41	16D
0005434822251	5247	42	16F
0005434822271	5247	43	16E
0005434822315	5247	44	16H
0005435372119	5247	45	17C
0005435372208	5247	46	17A
0005435372118	5247	47	16K
0005432121183	5247	48	17E
0005434822291	5247	49	17F
0005434822320	5247	50	17K
0005434822277	5247	51	18E
0005434822301	5247	52	18G
0005435372117	5247	53	18H
0005434822335	5247	54	19B
0005434822302	5247	55	18K
0005434822278	5247	56	19F
0005434822255	5247	57	19H
0005434822261	5247	58	19G
0005434822344	5247	59	19K
0005434822311	5247	60	19J
0005434822236	5247	61	20B
0005434822233	5247	62	20A
0005432121185	5247	63	20E
0005434822304	5247	64	20C
0005435149892	5247	65	20F
0005434822305	5247	66	21B
0005434822307	5247	67	21D
0005434822249	5247	68	21F
0005434664935	5247	69	21H
0005435149887	5247	70	21G
0005435149893	5247	71	21K
0005435299697	5247	72	22C
0005432394061	5247	73	22B
0005435372364	5247	74	22F
0005434822285	5247	75	22E
0005434822332	5247	76	22D
0005434822337	5247	77	22H
0005434822321	5247	78	23B
0005435149891	5247	79	23D
0005434828667	5247	80	23C
0005435372103	5247	81	23F
0005434822241	5247	82	23H
0005434822331	5247	83	23G
0005434822299	5247	84	24D
0005434822224	5247	85	23J
0005435372102	5247	86	24F
0005435149885	5247	87	24E
0005434822328	5247	88	25B
0005434822288	5247	89	25D
0005434822266	5247	90	25C
0005432121189	5247	91	25E
0005434822245	5247	92	25H
0005434822294	5247	93	25G
0005434822268	5247	94	26B
0005432396203	5247	95	26D
0005434822279	5247	96	26G
0005434822287	5247	97	26F
0005434822324	5247	98	27F
0005434822339	5247	99	28B
0005434822248	5247	100	28G
0005434822280	5247	101	28E
0005434822264	5247	102	28K
0005434822334	5247	103	28J
0005434822230	5247	104	28H
0005434822267	5247	105	29A
0005434822303	5247	106	29F
0005434822250	5247	107	29E
0005434822240	5247	108	29H
0005432121193	5247	109	30C
0005434822333	5247	110	30D
0005435372210	5247	111	30F
0005435149890	5247	112	30H
0005434822225	5247	113	31B
0005435149886	5247	114	31F
0005434822312	5247	115	31E
0005434822242	5247	116	31J
0005434822350	5247	117	31H
0005434822297	5247	118	31G
0005434822221	5247	119	31K
0005434822229	5247	120	32B
0005434822223	5247	121	32G
0005434822228	5247	122	33B
0005434822235	5247	123	33D
0005434822257	5247	124	33C
0005434822239	5247	125	33F
0005434664933	5247	126	33E
0005434822286	5247	127	33H
0005434822318	5247	128	33G
0005432394064	5247	129	33K
0005434558193	5247	130	34E
0005435372121	5247	131	34G
0005434558194	5247	132	34F
0005434822345	5247	133	34K
0005434822340	5247	134	35C
0005434822259	5247	135	35F
0005434831099	5247	136	35J
0005432394063	5247	137	35H
0005434822227	5247	138	36F
0005434822298	5247	139	36E
0005434822296	5247	140	36K
0005434822300	5247	141	36J
0005434822283	5247	142	37E
0005434831097	5247	143	38A
0005435372148	5247	144	37K
0005435304094	5247	145	38B
0005432121195	5247	146	39A
0005435372197	5247	147	38K
0005435372115	5247	148	39D
0005432121196	5247	149	39B
0005434822247	5247	150	39E
0005434822281	5247	151	39H
0005434822244	5247	152	40C
0005435372158	5247	153	40B
0005434822306	5247	154	40A
0005434822222	5247	155	40E
0005434822309	5247	156	40H
0005432121187	5247	157	40G
0005434822253	5247	158	41A
0005434822276	5247	159	41C
0005434828665	5247	160	41G
0005434822316	5247	161	42B
0005434822310	5247	162	42E
0005434822348	5247	163	42D
0005434822295	5247	164	42G
0005432121186	5247	165	42F
0005434822347	5247	166	42J
0005435372120	5247	167	43B
0005434822258	5247	168	42K
0005434822237	5247	169	43F
0005432121194	5247	170	43E
0005434822220	5247	171	44B
0005434831098	5247	172	44C
0005435149898	5247	173	44K
0005435149895	5247	174	45B
0005434822325	5247	175	45A
0005435372149	5247	176	45F
0005435149889	5247	177	45E
0005434822336	5247	178	45H
0005432121191	5247	179	45G
0005432394062	5247	180	45K
0005432121192	5247	181	46A
0005434558195	5247	182	46E
0005434828666	5247	183	46D
0005434822341	5247	184	46C
0005434822273	5247	185	46G
0005434822275	5247	186	46J
0005435735059	5247	187	46K
0005434831096	5247	188	47C
0005434822292	5247	189	47G
0005435372116	5247	190	47F
0005435149897	5247	191	47H
0005434822308	5247	192	48D
0005434822343	5247	193	48C
0005434822226	5247	194	48F
0005434822272	5247	195	48E
0005435372112	5247	196	48H
0005432121190	5247	197	49A
0005434822256	5247	198	48K
0005434822231	5247	199	49C
0005432121184	5247	200	50C
0005434822254	5247	201	50A
0005434822293	5247	202	50F
0005435372104	5247	203	50D
0005435149894	5247	204	50G
0005434822260	5247	205	51E
0005434822330	5247	206	51G
0005435661901	9906	1	1C
0005434821642	9906	2	1H
0005435372590	9906	3	1D
0005435386507	9906	4	1K
0005435386505	9906	5	2D
0005434821502	9906	6	2H
0005435372619	9906	7	3G
0005434821606	9906	8	4C
0005434821605	9906	9	4G
0005435661900	9906	10	12D
0005435735093	9906	11	13E
0005435299725	9906	12	13H
0005434821475	9906	13	13K
0005432202986	9906	14	14E
0005435372596	9906	15	15D
0005434821380	9906	16	15E
0005435372612	9906	17	15H
0005434821419	9906	18	16D
0005435299727	9906	19	16K
0005434821647	9906	20	17E
0005434821791	9906	21	17D
0005435302150	9906	22	17C
0005435372593	9906	23	17G
0005434821373	9906	24	17F
0005435372599	9906	25	18B
0005434821491	9906	26	18E
0005434821396	9906	27	18D
0005432202988	9906	28	18G
0005435372567	9906	29	18F
0005434831069	9906	30	19A
0005432400057	9906	31	19H
0005435372616	9906	32	19K
0005435302151	9906	33	19J
0005432202987	9906	34	20B
0005432400058	9906	35	20D
0005435372586	9906	36	20G
0005435372620	9906	37	20F
0005435372618	9906	38	20J
0005435372580	9906	39	20H
0005435372601	9906	40	21C
0005435372583	9906	41	21H
0005435372569	9906	42	22A
0005434821343	9906	43	22C
0005434821390	9906	44	23B
0005434821496	9906	45	22K
0005435372617	9906	46	23E
0005434821554	9906	47	23D
0005435372581	9906	48	23C
0005432202990	9906	49	23H
0005435386510	9906	50	23K
0005434821417	9906	51	24F
0005435372571	9906	52	25A
0005435372598	9906	53	25F
0005435372574	9906	54	25E
0005435372564	9906	55	25H
0005435372594	9906	56	25K
0005435372614	9906	57	26C
0005434821418	9906	58	26B
0005434821725	9906	59	26A
0005434821627	9906	60	26D
0005435372592	9906	61	26J
0005435372582	9906	62	27A
0005435372624	9906	63	27D
0005435372561	9906	64	27E
0005435372610	9906	65	27G
0005434821607	9906	66	27K
0005435372597	9906	67	28C
0005435735090	9906	68	28F
0005434821433	9906	69	28K
0005432400063	9906	70	29C
0005434821391	9906	71	30E
0005435372562	9906	72	30G
0005434821590	9906	73	30F
0005435372607	9906	74	30K
0005432202992	9906	75	30H
0005435372613	9906	76	31B
0005435372605	9906	77	31D
0005434821526	9906	78	31H
0005434821477	9906	79	31G
0005435372585	9906	80	32B
0005434821420	9906	81	32E
0005432823430	9906	82	32F
0005435386506	9906	83	32J
0005435372615	9906	84	33D
0005435372563	9906	85	33E
0005434821724	9906	86	33H
0005435372575	9906	87	34B
0005435372566	9906	88	34G
0005435735095	9906	89	34H
0005435372611	9906	90	35B
0005432823429	9906	91	35D
0005434821501	9906	92	35C
0005435386508	9906	93	35G
0005435372626	9906	94	35H
0005435372608	9906	95	36A
0005435372565	9906	96	35K
0005435299728	9906	97	36C
0005435372579	9906	98	36E
0005435386504	9906	99	36D
0005435372603	9906	100	36H
0005435302149	9906	101	37B
0005435372625	9906	102	37A
0005435735094	9906	103	37D
0005435372609	9906	104	37F
0005432202989	9906	105	37J
0005435372584	9906	106	37K
0005434821319	9906	107	38H
0005432400059	9906	108	39B
0005435372588	9906	109	39F
0005435372589	9906	110	39J
0005435386509	9906	111	40B
0005435372602	9906	112	40E
0005435372572	9906	113	41A
0005435372570	9906	114	41D
0005435372622	9906	115	41G
0005435372600	9906	116	41J
0005434821434	9906	117	41H
0005435302152	9906	118	42G
0005435372587	9906	119	42J
0005434821356	9906	120	43D
0005435372577	9906	121	43C
0005432202991	9906	122	43G
0005435372621	9906	123	44A
0005435372623	9906	124	43K
0005434821560	9906	125	44B
0005434821348	9906	126	44D
0005435372595	9906	127	44H
0005434821792	9906	128	44K
0005432400061	9906	129	44J
0005435372606	9906	130	45A
0005432400056	9906	131	45H
0005435372604	9906	132	45J
0005435372560	9906	133	46C
0005435661902	9906	134	46B
0005434821322	9906	135	46D
0005434821559	9906	136	46J
0005435735092	9906	137	46H
0005435372591	9906	138	47C
0005435735091	9906	139	46K
0005434821349	9906	140	47D
0005435299726	9906	141	47H
0005434821556	9906	142	48C
0005435372573	9906	143	48F
0005434664919	9906	144	48E
0005434821375	9906	145	48G
0005435372568	9906	146	49D
0005435372578	9906	147	49E
0005435372576	9906	148	50D
0005434821374	9906	149	51D
0005434821379	9906	150	51G
0005435790277	6986	1	1A
0005435790276	6986	2	18A
0005435082705	6986	3	18C
0005435082707	6986	4	18D
0005435082706	6986	5	20A
0005435082709	6986	6	20C
0005435082710	6986	7	21B
0005435082704	6986	8	21D
0005435082708	6986	9	22B
0005435790264	26025	1	1C
0005435790260	26025	2	5D
0005435790261	26025	3	6D
0005434756008	9522	1	1A
0005434213810	9522	2	1C
0005434756029	9522	3	2A
0005434756027	9522	4	2C
0005434756019	9522	5	2F
0005434756012	9522	6	3D
0005434756045	9522	7	4C
0005434756009	9522	8	4E
0005434756047	9522	9	4F
0005434756041	9522	10	6F
0005434756033	9522	11	7C
0005434756039	9522	12	7D
0005434213811	9522	13	8A
0005434756046	9522	14	8D
0005434756035	9522	15	9A
0005434756044	9522	16	9C
0005434756026	9522	17	9F
0005434756034	9522	18	10A
0005434213770	9522	19	10C
0005434756011	9522	20	11A
0005434756016	9522	21	11C
0005434756038	9522	22	11D
0005434756042	9522	23	12C
0005434756015	9522	24	12E
0005434756024	9522	25	13A
0005434756017	9522	26	13C
0005434756037	9522	27	13D
0005434756031	9522	28	13F
0005434756020	9522	29	14D
0005434756028	9522	30	16D
0005434756040	9522	31	16F
0005434756021	9522	32	17A
0005434213734	9522	33	17C
0005434756043	9522	34	17E
0005434756014	9522	35	17F
0005434756032	9522	36	18A
0005434756025	9522	37	18C
0005434756030	9522	38	18E
0005434756036	9522	39	19D
0005434756010	9522	40	19E
0005434756018	9522	41	20A
0005434756048	9522	42	19F
0005434756013	9522	43	20D
0005434756022	9522	44	20E
0005434756023	9522	45	20F
0005434214023	28594	1	1D
0005434214019	28594	2	1F
0005434213984	28594	3	2A
0005434213992	28594	4	2C
0005434214005	28594	5	3C
0005434213993	28594	6	3D
0005434214016	28594	7	4A
0005434213997	28594	8	5A
0005434214013	28594	9	5C
0005434214025	28594	10	5F
0005434214027	28594	11	6F
0005434214022	28594	12	7D
0005434214012	28594	13	7E
0005434214002	28594	14	7F
0005434214009	28594	15	8A
0005434214017	28594	16	8C
0005434213998	28594	17	8E
0005434214001	28594	18	8F
0005434213986	28594	19	9A
0005434214024	28594	20	9C
0005434214010	28594	21	9D
0005434213996	28594	22	10E
0005434755728	28594	23	10F
0005434214008	28594	24	11F
0005434214015	28594	25	12C
0005434214030	28594	26	14A
0005434214006	28594	27	14C
0005434214028	28594	28	14E
0005434213995	28594	29	14F
0005434213994	28594	30	15E
0005434214018	28594	31	15F
0005434213988	28594	32	16C
0005434214014	28594	33	16D
0005434213987	28594	34	16E
0005434214011	28594	35	16F
0005434214000	28594	36	17C
0005434213985	28594	37	17F
0005434213999	28594	38	18A
0005434214020	28594	39	18D
0005434214029	28594	40	18E
0005434214004	28594	41	18F
0005434213989	28594	42	19A
0005434214007	28594	43	19C
0005434214021	28594	44	19F
0005434213990	28594	45	20A
0005434214003	28594	46	20C
0005434214026	28594	47	20E
0005434213991	28594	48	20F
0005435100094	10836	1	1C
0005435100091	10836	2	1D
0005434760159	10836	3	4D
0005435100093	10836	4	5C
0005435100092	10836	5	18C
0005435100090	10836	6	20B
0005434760171	31818	1	6C
0005434760172	31818	2	7B
0005434639068	1996	1	1A
0005432290603	1996	2	1C
0005434639052	1996	3	2B
0005434639045	1996	4	2C
0005434639047	1996	5	2D
0005434639063	1996	6	3B
0005434639057	1996	7	3C
0005434639059	1996	8	3D
0005433202114	1996	9	4A
0005434639051	1996	10	4B
0005434639055	1996	11	4C
0005433202109	1996	12	4D
0005434639061	1996	13	5A
0005433202119	1996	14	5B
0005434639050	1996	15	5C
0005434639062	1996	16	6B
0005434639053	1996	17	6C
0005433202116	1996	18	6D
0005432290601	1996	19	7B
0005434639044	1996	20	7C
0005434639046	1996	21	7D
0005434639065	1996	22	18A
0005434639056	1996	23	18C
0005435948316	1996	24	18D
0005434639067	1996	25	19A
0005434639048	1996	26	19C
0005434639049	1996	27	19D
0005432290602	1996	28	20A
0005432290604	1996	29	20B
0005434639069	1996	30	20D
0005434639058	1996	31	21B
0005435948315	1996	32	21C
0005434639064	1996	33	21D
0005434639054	1996	34	22A
0005434639060	1996	35	22C
0005434639066	1996	36	22D
0005433202207	23302	1	1B
0005433202205	23302	2	1C
0005433202199	23302	3	1D
0005433202192	23302	4	2A
0005433202201	23302	5	3A
0005433202203	23302	6	3B
0005433202198	23302	7	4A
0005433202197	23302	8	4C
0005433202202	23302	9	6D
0005433202193	23302	10	7B
0005433202194	23302	11	18C
0005433202200	23302	12	19A
0005433202196	23302	13	19B
0005434638862	23302	14	20D
0005433202195	23302	15	21A
0005433202204	23302	16	21C
0005434638871	23302	17	22A
0005433202206	23302	18	22D
0005434638927	23302	19	23A
0005434638870	23302	20	23B
0005433533269	6055	1	1A
0005434600524	6055	2	1C
0005434600539	6055	3	1D
0005434600523	6055	4	2A
0005434600538	6055	5	1F
0005434600533	6055	6	3F
0005434600532	6055	7	4C
0005434600522	6055	8	5F
0005434600547	6055	9	6A
0005432111249	6055	10	6D
0005432111248	6055	11	6E
0005433531253	6055	12	7A
0005433531254	6055	13	7C
0005434600527	6055	14	7D
0005434600545	6055	15	7E
0005433533270	6055	16	7F
0005434600543	6055	17	8E
0005434600535	6055	18	8F
0005434600534	6055	19	9A
0005434600542	6055	20	10A
0005434600537	6055	21	10C
0005435326502	6055	22	10E
0005433531255	6055	23	11F
0005434600540	6055	24	12A
0005433531252	6055	25	12C
0005434600544	6055	26	12F
0005435326520	6055	27	13A
0005434600536	6055	28	13C
0005434600525	6055	29	13E
0005434600531	6055	30	13F
0005434600541	6055	31	14E
0005434600521	6055	32	15A
0005433533268	6055	33	15E
0005435326519	6055	34	15F
0005435326500	6055	35	16C
0005435326501	6055	36	16E
0005435326509	6055	37	17C
0005435326532	6055	38	18F
0005434600526	6055	39	19A
0005433531256	6055	40	19D
0005434600530	6055	41	19E
0005434600546	6055	42	20A
0005434600528	6055	43	19F
0005434600529	6055	44	20D
0005433531229	18606	1	1F
0005433527207	18606	2	2A
0005434600401	18606	3	4C
0005435326602	18606	4	5C
0005435326601	18606	5	5E
0005434600330	18606	6	6F
0005433527210	18606	7	8D
0005435326608	18606	8	8F
0005435326606	18606	9	9A
0005435326599	18606	10	10A
0005434600334	18606	11	11F
0005435326609	18606	12	12A
0005434600384	18606	13	12C
0005434600385	18606	14	13F
0005435326605	18606	15	14F
0005433527208	18606	16	15C
0005435326598	18606	17	15D
0005435326603	18606	18	15F
0005435326600	18606	19	17C
0005434600333	18606	20	17D
0005435326607	18606	21	17E
0005434600353	18606	22	18C
0005433527209	18606	23	20A
0005435326604	18606	24	20E
0005433180692	10560	1	1C
0005434554040	10560	2	1D
0005434550629	10560	3	2A
0005434550642	10560	4	2C
0005434550606	10560	5	2D
0005434558189	10560	6	2F
0005434558192	10560	7	3A
0005434558184	10560	8	3C
0005434550601	10560	9	3D
0005434558185	10560	10	3F
0005434558187	10560	11	4A
0005434550598	10560	12	4C
0005434550628	10560	13	4D
0005434550648	10560	14	4E
0005434558180	10560	15	4F
0005434550602	10560	16	5A
0005434550619	10560	17	5C
0005434550635	10560	18	5D
0005434550646	10560	19	5E
0005434550604	10560	20	5F
0005434550640	10560	21	6A
0005434558186	10560	22	6C
0005434550632	10560	23	6E
0005434550647	10560	24	6F
0005434550638	10560	25	7A
0005434550615	10560	26	7C
0005434550603	10560	27	7D
0005434550625	10560	28	7E
0005434550613	10560	29	7F
0005434550594	10560	30	8A
0005434558183	10560	31	8C
0005434558188	10560	32	8D
0005434550611	10560	33	8E
0005434550622	10560	34	8F
0005434550645	10560	35	9A
0005434550605	10560	36	9D
0005434550616	10560	37	9E
0005434550610	10560	38	9F
0005434550630	10560	39	10C
0005433180721	10560	40	10D
0005434550631	10560	41	10E
0005434550607	10560	42	10F
0005434550644	10560	43	11C
0005434550639	10560	44	11E
0005434550620	10560	45	12A
0005434550618	10560	46	12C
0005433180691	10560	47	12E
0005434550627	10560	48	12F
0005434550649	10560	49	13A
0005434550643	10560	50	13C
0005434550593	10560	51	13D
0005434558191	10560	52	13F
0005434550609	10560	53	14C
0005433180720	10560	54	14D
0005434558182	10560	55	14E
0005434550637	10560	56	15C
0005434550623	10560	57	15D
0005434550596	10560	58	15E
0005434550612	10560	59	15F
0005434558181	10560	60	16C
0005434550633	10560	61	16D
0005434554041	10560	62	16E
0005434550599	10560	63	16F
0005434550634	10560	64	17A
0005433180669	10560	65	17C
0005434550597	10560	66	17D
0005434554039	10560	67	17E
0005433180649	10560	68	17F
0005434550641	10560	69	18A
0005433180648	10560	70	18C
0005434550626	10560	71	18D
0005434550650	10560	72	18E
0005434550608	10560	73	18F
0005433180670	10560	74	19A
0005434550614	10560	75	19C
0005434550600	10560	76	19D
0005434558190	10560	77	19E
0005434550636	10560	78	19F
0005434550624	10560	79	20A
0005434550595	10560	80	20C
0005433180652	10560	81	20D
0005434550621	10560	82	20E
0005434550617	10560	83	20F
0005433180835	27780	1	1C
0005433180851	27780	2	2D
0005433180849	27780	3	3A
0005433180847	27780	4	3D
0005433180829	27780	5	4A
0005433180846	27780	6	4D
0005433180843	27780	7	5A
0005433180833	27780	8	5E
0005433180831	27780	9	6A
0005433180850	27780	10	7C
0005433180840	27780	11	7E
0005433180841	27780	12	8A
0005433180838	27780	13	8E
0005433180839	27780	14	10C
0005433180852	27780	15	12A
0005433180830	27780	16	12C
0005433180836	27780	17	13C
0005433180842	27780	18	13E
0005433180848	27780	19	14A
0005433180854	27780	20	15A
0005433180834	27780	21	16A
0005433180844	27780	22	16D
0005433180837	27780	23	16E
0005433180853	27780	24	18C
0005433180832	27780	25	18E
0005433180845	27780	26	20F
0005434550313	27779	1	1A
0005434550276	27779	2	1C
0005434550327	27779	3	1D
0005434550266	27779	4	2F
0005434550362	27779	5	3C
0005434550270	27779	6	4E
0005434550363	27779	7	5A
0005434550515	27779	8	5F
0005434550273	27779	9	6C
0005434550265	27779	10	8A
0005434550275	27779	11	8D
0005434550498	27779	12	9D
0005434550516	27779	13	9F
0005434550288	27779	14	11E
0005434550285	27779	15	11F
0005434550319	27779	16	12C
0005434550297	27779	17	13C
0005434550348	27779	18	13D
0005434550381	27779	19	14F
0005434550457	27779	20	17C
0005434550274	27779	21	18F
0005434550312	27779	22	20A
0005434550263	27779	23	20E
0005434550458	27779	24	20F
0005433459176	6166	1	1B
0005433459175	6166	2	4A
0005433459173	6166	3	5A
0005433459177	6166	4	5B
0005433459174	6166	5	6A
0005435254447	19307	1	2A
0005435254449	19307	2	1B
0005435254448	19307	3	6A
0005435681695	6707	1	1D
0005435681707	6707	2	2A
0005435681727	6707	3	2C
0005435681687	6707	4	2F
0005435681693	6707	5	3A
0005432136117	6707	6	3C
0005435437577	6707	7	3D
0005435681705	6707	8	3F
0005435681697	6707	9	4A
0005435437600	6707	10	4D
0005435681729	6707	11	4E
0005435681702	6707	12	4F
0005435681724	6707	13	5A
0005435681708	6707	14	5E
0005435681720	6707	15	6A
0005435681721	6707	16	6C
0005435437601	6707	17	6E
0005435681701	6707	18	6F
0005435681722	6707	19	7A
0005435681706	6707	20	7C
0005435437578	6707	21	7E
0005435681719	6707	22	7F
0005435681688	6707	23	8F
0005432136114	6707	24	9C
0005435437589	6707	25	9D
0005435681699	6707	26	9F
0005435681700	6707	27	10C
0005435681698	6707	28	10D
0005435681690	6707	29	10E
0005435437618	6707	30	11D
0005435661898	6707	31	11E
0005435681711	6707	32	11F
0005435681692	6707	33	12D
0005435681689	6707	34	12E
0005435681715	6707	35	12F
0005432136118	6707	36	13C
0005435681717	6707	37	13D
0005435681716	6707	38	13E
0005435681723	6707	39	14C
0005435681691	6707	40	14D
0005435630933	6707	41	14E
0005435661899	6707	42	14F
0005435681696	6707	43	15C
0005435437588	6707	44	15E
0005435681710	6707	45	15F
0005435437580	6707	46	16A
0005435681694	6707	47	16C
0005435437564	6707	48	16D
0005435681703	6707	49	17C
0005435681712	6707	50	17A
0005435681704	6707	51	17D
0005432136116	6707	52	17E
0005435437619	6707	53	17F
0005435661897	6707	54	18A
0005435681718	6707	55	18D
0005435681714	6707	56	18E
0005435681725	6707	57	18F
0005435681713	6707	58	19A
0005432136115	6707	59	19C
0005435630934	6707	60	19D
0005435681728	6707	61	19E
0005435681726	6707	62	19F
0005435681709	6707	63	20A
0005435681686	6707	64	20C
0005435220283	6707	65	20D
0005435437730	24583	1	3C
0005432533261	24583	2	4C
0005435437724	24583	3	4D
0005435681465	24583	4	4E
0005435437719	24583	5	5D
0005435681391	24583	6	5E
0005435437721	24583	7	5F
0005435437717	24583	8	6A
0005435437715	24583	9	6E
0005435437718	24583	10	7A
0005435681464	24583	11	7C
0005432305723	24583	12	7D
0005435437720	24583	13	8C
0005435437713	24583	14	8D
0005432533263	24583	15	8F
0005435681490	24583	16	9A
0005435681444	24583	17	9C
0005435437726	24583	18	9D
0005435681392	24583	19	9F
0005435437722	24583	20	10A
0005435681472	24583	21	10C
0005435437714	24583	22	10D
0005435437723	24583	23	10E
0005434828668	24583	24	10F
0005435681511	24583	25	11A
0005432305724	24583	26	11D
0005435681504	24583	27	12E
0005435681512	24583	28	12F
0005435681390	24583	29	13A
0005435681587	24583	30	13D
0005435681399	24583	31	14A
0005435681488	24583	32	14E
0005435437732	24583	33	14F
0005434828669	24583	34	15F
0005435437712	24583	35	16C
0005435437711	24583	36	16D
0005435437729	24583	37	16E
0005432305722	24583	38	16F
0005435681425	24583	39	17A
0005435681489	24583	40	17C
0005435437725	24583	41	17F
0005435681494	24583	42	18C
0005435437716	24583	43	18D
0005435437731	24583	44	18E
0005432533262	24583	45	18F
0005435437727	24583	46	19C
0005435681424	24583	47	19F
0005435681412	24583	48	20A
0005435437728	24583	49	20D
0005435681493	24583	50	20F
0005435125905	11508	1	1D
0005435125916	11508	2	1F
0005435125918	11508	3	2C
0005435125901	11508	4	3A
0005435125926	11508	5	3D
0005435125898	11508	6	4A
0005435125929	11508	7	4C
0005435125906	11508	8	4D
0005435125919	11508	9	5A
0005435125907	11508	10	5E
0005435125924	11508	11	5F
0005435125910	11508	12	6E
0005435125932	11508	13	6F
0005435125922	11508	14	7D
0005435125911	11508	15	7F
0005435125925	11508	16	8A
0005435125933	11508	17	8D
0005435125917	11508	18	8F
0005435125937	11508	19	9C
0005435125928	11508	20	9E
0005435125909	11508	21	9F
0005435125920	11508	22	10A
0005435125900	11508	23	10C
0005435125913	11508	24	12D
0005435125935	11508	25	13A
0005435125899	11508	26	13C
0005435125908	11508	27	13D
0005435125927	11508	28	13E
0005435125936	11508	29	14A
0005435105946	11508	30	14D
0005435105945	11508	31	14E
0005435125902	11508	32	14F
0005435105947	11508	33	15A
0005435125915	11508	34	16A
0005435125897	11508	35	16E
0005435125904	11508	36	17C
0005435125903	11508	37	18A
0005435125912	11508	38	18C
0005435125934	11508	39	18E
0005435105948	11508	40	19E
0005435125923	11508	41	19F
0005435125921	11508	42	20A
0005435125914	11508	43	20C
0005435125931	11508	44	20D
0005435125930	11508	45	20F
0005435558059	31881	1	1A
0005435558060	31881	2	7A
0005435125698	31881	3	7E
0005435125695	31881	4	12C
0005435125729	31881	5	12D
0005435125696	31881	6	12E
0005435125697	31881	7	14E
0005433397573	13523	1	1A
0005435732127	13523	2	1D
0005433397543	13523	3	2A
0005433397542	13523	4	2F
0005433397574	13523	5	3D
0005433397536	13523	6	3F
0005433397529	13523	7	4C
0005433397576	13523	8	4D
0005433397534	13523	9	4E
0005433397528	13523	10	4F
0005435732118	13523	11	5A
0005433397551	13523	12	5C
0005433397540	13523	13	6A
0005433397559	13523	14	6C
0005433397558	13523	15	6E
0005433397557	13523	16	6F
0005433397570	13523	17	7D
0005435732148	13523	18	7E
0005433397539	13523	19	7F
0005433397535	13523	20	8A
0005433397532	13523	21	8C
0005433397530	13523	22	8D
0005433397541	13523	23	8E
0005433397545	13523	24	9D
0005433397526	13523	25	9F
0005433397560	13523	26	10C
0005433397547	13523	27	10D
0005433397552	13523	28	10E
0005433397553	13523	29	10F
0005435732128	13523	30	11C
0005435732112	13523	31	11D
0005433397548	13523	32	11E
0005433397546	13523	33	12C
0005433397531	13523	34	12D
0005433397538	13523	35	12E
0005433397555	13523	36	13A
0005433397544	13523	37	13D
0005435732124	13523	38	14D
0005433397554	13523	39	14E
0005435732116	13523	40	14F
0005433397575	13523	41	15A
0005433397567	13523	42	15D
0005433397527	13523	43	15E
0005433397562	13523	44	15F
0005433397565	13523	45	16D
0005433397549	13523	46	16E
0005433397563	13523	47	17A
0005435732123	13523	48	17C
0005433397537	13523	49	17D
0005433397566	13523	50	17F
0005433397564	13523	51	18A
0005433397572	13523	52	18C
0005433397568	13523	53	18D
0005433397550	13523	54	18F
0005433397556	13523	55	19A
0005433397571	13523	56	19C
0005433397561	13523	57	19D
0005435732117	13523	58	19E
0005435732149	13523	59	20D
0005433397569	13523	60	20E
0005433397533	13523	61	20F
0005435732199	19408	1	1A
0005433397201	19408	2	1D
0005433397209	19408	3	2C
0005435732210	19408	4	3A
0005435732203	19408	5	3F
0005435732202	19408	6	4A
0005435732196	19408	7	5C
0005433397323	19408	8	5D
0005432297251	19408	9	6C
0005433397258	19408	10	7C
0005433397194	19408	11	7F
0005435732205	19408	12	8A
0005435732211	19408	13	8C
0005433397191	19408	14	9A
0005433397183	19408	15	10E
0005435732198	19408	16	11A
0005435732209	19408	17	11D
0005435732213	19408	18	12D
0005435732194	19408	19	12E
0005435732207	19408	20	14C
0005435732195	19408	21	15D
0005435732206	19408	22	16D
0005435732200	19408	23	16E
0005433397190	19408	24	16F
0005435732212	19408	25	17A
0005433397202	19408	26	17C
0005435732197	19408	27	17F
0005435732204	19408	28	18D
0005435732201	19408	29	19C
0005435732208	19408	30	19E
0005433397229	19408	31	20F
0005435925154	13163	1	1A
0005435925148	13163	2	2C
0005435068218	13163	3	4D
0005435925149	13163	4	4F
0005435068192	13163	5	8C
0005435068172	13163	6	9D
0005435068256	13163	7	10E
0005435068267	13163	8	11F
0005435925150	13163	9	14E
0005435068266	13163	10	15D
0005435068275	13163	11	16A
0005435925151	13163	12	16C
0005435925152	13163	13	17C
0005435068217	13163	14	17E
0005435068193	13163	15	17F
0005435925153	13163	16	18E
0005435068286	13163	17	19A
0005435068489	15486	1	1A
0005435068480	15486	2	1C
0005435068518	15486	3	3A
0005435068495	15486	4	4A
0005435068511	15486	5	4C
0005435068488	15486	6	4D
0005435068493	15486	7	4E
0005435068510	15486	8	5A
0005435068499	15486	9	5D
0005435068476	15486	10	5E
0005435068505	15486	11	5F
0005435068522	15486	12	6C
0005435068502	15486	13	6D
0005435068482	15486	14	6F
0005435068485	15486	15	7A
0005435068490	15486	16	7C
0005435068515	15486	17	7D
0005435068520	15486	18	7E
0005435068487	15486	19	8D
0005435068496	15486	20	8E
0005435068492	15486	21	8F
0005435068508	15486	22	9C
0005435068479	15486	23	9E
0005435068478	15486	24	9F
0005435068512	15486	25	10A
0005435068506	15486	26	10C
0005435068524	15486	27	11A
0005435068497	15486	28	11C
0005435068500	15486	29	11E
0005435068501	15486	30	12A
0005435068523	15486	31	13C
0005435068521	15486	32	13F
0005435068481	15486	33	14C
0005435068504	15486	34	14E
0005435068491	15486	35	14F
0005435068486	15486	36	15C
0005435068527	15486	37	15F
0005435068519	15486	38	16A
0005435068498	15486	39	16C
0005435068507	15486	40	16D
0005435068517	15486	41	17A
0005435068526	15486	42	17C
0005435068509	15486	43	17D
0005435068484	15486	44	17F
0005435068525	15486	45	18A
0005435068494	15486	46	18C
0005435068503	15486	47	18F
0005435068513	15486	48	19A
0005435068516	15486	49	19C
0005435068477	15486	50	19E
0005435068483	15486	51	19F
0005435068528	15486	52	20C
0005435068514	15486	53	20F
0005433407517	29490	1	1A
0005433407505	29490	2	2C
0005435808051	29490	3	3D
0005433407508	29490	4	4A
0005433407504	29490	5	4B
0005433407510	29490	6	4C
0005433407506	29490	7	4D
0005435808050	29490	8	5A
0005435808052	29490	9	6D
0005433407511	29490	10	7A
0005433407514	29490	11	7C
0005433407512	29490	12	7D
0005433407516	29490	13	18A
0005433407515	29490	14	18B
0005433407507	29490	15	18D
0005433407513	29490	16	19A
0005433407509	29490	17	19D
0005433407503	29490	18	22C
0005434214036	10741	1	1D
0005434214055	10741	2	1F
0005434214074	10741	3	2A
0005434214052	10741	4	2D
0005434214032	10741	5	2F
0005434214051	10741	6	4A
0005434214071	10741	7	4D
0005434214057	10741	8	4E
0005434214065	10741	9	4F
0005434214067	10741	10	5A
0005434214060	10741	11	5C
0005434214075	10741	12	5D
0005434214042	10741	13	5E
0005434214048	10741	14	6C
0005434214066	10741	15	6F
0005434214077	10741	16	7C
0005434214033	10741	17	7D
0005434214064	10741	18	8C
0005434214041	10741	19	8D
0005434214045	10741	20	8E
0005434214069	10741	21	8F
0005434214043	10741	22	9A
0005434214062	10741	23	9E
0005434214058	10741	24	10C
0005434214039	10741	25	10D
0005434214063	10741	26	10F
0005434214031	10741	27	11C
0005434214078	10741	28	11D
0005434214049	10741	29	11E
0005434214056	10741	30	11F
0005434214044	10741	31	12C
0005434214061	10741	32	12E
0005434214059	10741	33	13C
0005434214053	10741	34	13D
0005434214035	10741	35	13F
0005434214050	10741	36	14D
0005434214037	10741	37	15D
0005434214038	10741	38	16A
0005434214046	10741	39	17E
0005434214068	10741	40	17F
0005434214054	10741	41	18C
0005434214070	10741	42	18D
0005434214073	10741	43	18F
0005434214072	10741	44	19C
0005434214040	10741	45	19E
0005434214047	10741	46	20C
0005434214076	10741	47	20D
0005434214034	10741	48	20E
0005434756007	28685	1	1A
0005434755978	28685	2	1D
0005434755994	28685	3	2A
0005434755996	28685	4	2F
0005434755998	28685	5	3A
0005434756001	28685	6	3C
0005434755988	28685	7	3D
0005434213750	28685	8	4C
0005434755971	28685	9	4D
0005434755992	28685	10	4E
0005434755990	28685	11	5C
0005434755969	28685	12	5E
0005434755967	28685	13	6D
0005434755970	28685	14	7A
0005434755986	28685	15	7C
0005434213791	28685	16	7E
0005434756006	28685	17	8E
0005434213749	28685	18	9C
0005434755963	28685	19	9E
0005434755984	28685	20	9F
0005434756004	28685	21	10A
0005434755977	28685	22	10C
0005434755975	28685	23	10D
0005434755968	28685	24	10F
0005434755974	28685	25	11A
0005434755973	28685	26	11D
0005434755989	28685	27	11F
0005434756003	28685	28	12D
0005434755961	28685	29	12E
0005434755981	28685	30	13A
0005434755995	28685	31	13D
0005434213732	28685	32	14A
0005434755964	28685	33	14C
0005434755985	28685	34	14E
0005434755966	28685	35	14F
0005434755987	28685	36	15C
0005434755983	28685	37	15D
0005434755979	28685	38	15E
0005434755993	28685	39	15F
0005434755991	28685	40	16A
0005434755999	28685	41	16F
0005434756002	28685	42	17C
0005434755972	28685	43	17A
0005434755980	28685	44	17E
0005434756000	28685	45	17F
0005434755976	28685	46	18C
0005434755997	28685	47	18E
0005434755965	28685	48	19A
0005434213740	28685	49	19D
0005434755962	28685	50	19E
0005434213701	28685	51	20A
0005434755982	28685	52	20E
0005434756005	28685	53	20F
0005432125379	5483	1	1A
0005435039086	5483	2	1D
0005435006775	5483	3	1F
0005435042834	5483	4	2C
0005435039120	5483	5	2A
0005435039113	5483	6	2D
0005435006791	5483	7	3A
0005435039105	5483	8	2F
0005435039073	5483	9	3D
0005435006769	5483	10	3C
0005435006790	5483	11	3F
0005435039083	5483	12	4B
0005435039064	5483	13	4D
0005435039076	5483	14	4C
0005435039095	5483	15	4E
0005435039082	5483	16	4F
0005435006787	5483	17	5A
0005435006767	5483	18	5B
0005435039091	5483	19	5D
0005432125372	5483	20	5E
0005435006780	5483	21	5F
0005434229029	5483	22	6A
0005435039084	5483	23	6C
0005435039104	5483	24	6D
0005435006770	5483	25	6E
0005435006771	5483	26	7A
0005435039068	5483	27	6F
0005435006784	5483	28	7B
0005432125377	5483	29	7D
0005435006766	5483	30	7F
0005435039103	5483	31	7E
0005435039100	5483	32	8A
0005432125373	5483	33	8B
0005435039088	5483	34	8C
0005434229007	5483	35	8D
0005435039074	5483	36	8F
0005435039093	5483	37	8E
0005435006776	5483	38	9A
0005435006779	5483	39	9C
0005435039106	5483	40	9B
0005434228983	5483	41	9E
0005434229008	5483	42	10B
0005435006789	5483	43	10D
0005435039087	5483	44	10C
0005435039060	5483	45	11A
0005435039079	5483	46	10E
0005435039099	5483	47	11D
0005435039117	5483	48	11C
0005435039116	5483	49	11E
0005435039107	5483	50	11F
0005435039124	5483	51	12B
0005435006782	5483	52	12A
0005435039101	5483	53	12E
0005435039121	5483	54	12D
0005435006774	5483	55	12F
0005435039069	5483	56	13A
0005435039108	5483	57	13B
0005435039118	5483	58	13E
0005435006783	5483	59	14B
0005435039070	5483	60	14D
0005434229002	5483	61	14C
0005435006788	5483	62	14E
0005434228972	5483	63	14F
0005435039119	5483	64	15A
0005435039114	5483	65	15C
0005435039059	5483	66	15D
0005435039109	5483	67	16A
0005432125375	5483	68	15F
0005435039092	5483	69	16B
0005435006773	5483	70	16C
0005435039065	5483	71	16D
0005435039071	5483	72	16E
0005435039102	5483	73	17A
0005435039097	5483	74	16F
0005435039096	5483	75	17B
0005432125371	5483	76	17D
0005435039094	5483	77	17E
0005435039072	5483	78	17F
0005435039077	5483	79	18A
0005435006786	5483	80	18B
0005435039067	5483	81	18C
0005435039122	5483	82	18D
0005435006781	5483	83	18E
0005435039115	5483	84	19A
0005435039098	5483	85	18F
0005435039110	5483	86	19C
0005435039111	5483	87	19B
0005435039058	5483	88	19E
0005435006768	5483	89	19D
0005435039090	5483	90	19F
0005435039112	5483	91	20B
0005435039066	5483	92	20A
0005435039089	5483	93	20D
0005432125378	5483	94	20C
0005434228978	5483	95	20E
0005435039123	5483	96	20F
0005435039081	5483	97	21B
0005432125374	5483	98	21A
0005434229006	5483	99	21C
0005435039063	5483	100	21D
0005435006778	5483	101	21E
0005435039062	5483	102	22A
0005435006785	5483	103	21F
0005435039075	5483	104	22B
0005435042833	5483	105	22C
0005435039080	5483	106	22D
0005435039078	5483	107	22E
0005432125376	5483	108	23A
0005435039085	5483	109	23C
0005435006772	5483	110	23B
0005435006777	5483	111	23E
0005435039061	5483	112	23F
0005434229147	13003	1	1A
0005434229134	13003	2	1C
0005435038866	13003	3	1F
0005434229138	13003	4	1D
0005435006630	13003	5	2D
0005435006635	13003	6	3D
0005435038751	13003	7	3F
0005435006610	13003	8	4B
0005435006620	13003	9	4C
0005432304359	13003	10	4F
0005435038649	13003	11	5B
0005435038635	13003	12	5A
0005435038733	13003	13	5D
0005434229133	13003	14	5C
0005435038757	13003	15	5E
0005435038698	13003	16	5F
0005435038728	13003	17	6C
0005435038759	13003	18	7B
0005434229145	13003	19	7A
0005435006662	13003	20	7D
0005434229129	13003	21	7F
0005435038648	13003	22	8A
0005435006719	13003	23	8B
0005434229132	13003	24	8C
0005435038865	13003	25	8E
0005434229143	13003	26	8D
0005434229149	13003	27	9B
0005435006609	13003	28	9D
0005435006661	13003	29	9C
0005434229140	13003	30	9F
0005435038796	13003	31	10C
0005435038722	13003	32	10D
0005435038683	13003	33	10E
0005432304358	13003	34	12B
0005434229150	13003	35	12C
0005434229131	13003	36	12F
0005434229142	13003	37	13A
0005434229144	13003	38	13D
0005435006643	13003	39	13E
0005434229136	13003	40	14D
0005435038634	13003	41	14C
0005434229137	13003	42	15B
0005435038697	13003	43	15D
0005435038761	13003	44	15E
0005435038738	13003	45	16D
0005434229141	13003	46	16C
0005435038633	13003	47	16E
0005435006631	13003	48	17C
0005434229128	13003	49	18B
0005434229135	13003	50	18C
0005434229148	13003	51	18D
0005435006642	13003	52	18F
0005435038626	13003	53	18E
0005432304360	13003	54	20C
0005432304357	13003	55	20E
0005435006619	13003	56	20F
0005434229139	13003	57	21D
0005435038755	13003	58	22B
0005434229146	13003	59	22D
0005435006615	13003	60	23A
0005435006614	13003	61	23D
0005434229130	13003	62	23C
0005435038793	13003	63	23E
0005435038756	13003	64	23F
0005434426291	14888	1	1A
0005434426282	14888	2	1C
0005434426270	14888	3	1D
0005434426283	14888	4	2A
0005434426269	14888	5	2C
0005434426279	14888	6	2D
0005434411729	14888	7	2F
0005434426281	14888	8	3F
0005434426277	14888	9	4F
0005435902398	14888	10	5C
0005434426280	14888	11	5E
0005434411730	14888	12	5D
0005434426293	14888	13	6A
0005435902399	14888	14	6E
0005434426295	14888	15	7A
0005434411728	14888	16	7C
0005434426284	14888	17	7E
0005434426278	14888	18	7D
0005434426285	14888	19	8A
0005434426289	14888	20	8F
0005434426268	14888	21	9A
0005434426273	14888	22	9D
0005432188569	14888	23	10A
0005432188570	14888	24	11C
0005434426265	14888	25	11E
0005434426290	14888	26	13E
0005434426271	14888	27	13F
0005432188571	14888	28	14A
0005434426287	14888	29	14C
0005434411731	14888	30	15A
0005434426266	14888	31	15C
0005434426294	14888	32	15D
0005434426288	14888	33	15E
0005434426267	14888	34	16A
0005434426274	14888	35	16C
0005434426272	14888	36	16E
0005434426276	14888	37	16F
0005434426275	14888	38	17A
0005434426292	14888	39	17D
0005434426286	14888	40	17F
0005432188572	14888	41	19A
0005435554105	14888	42	19C
0005435902516	20223	1	1D
0005435554143	20223	2	2C
0005434426161	20223	3	2D
0005434426091	20223	4	3D
0005435902513	20223	5	4C
0005435554142	20223	6	6D
0005435554139	20223	7	6F
0005435902529	20223	8	7A
0005434426108	20223	9	7D
0005435554140	20223	10	7F
0005435902519	20223	11	8C
0005434411702	20223	12	9A
0005435902514	20223	13	9F
0005435902524	20223	14	10A
0005434426100	20223	15	10E
0005434426164	20223	16	10F
0005432059484	20223	17	11A
0005435902518	20223	18	11D
0005435554141	20223	19	12E
0005435902527	20223	20	12F
0005435902517	20223	21	13A
0005435902522	20223	22	13D
0005435902520	20223	23	14A
0005434426160	20223	24	14C
0005435902525	20223	25	15A
0005435554138	20223	26	16C
0005435902523	20223	27	16E
0005435902512	20223	28	16F
0005435902526	20223	29	17A
0005435902515	20223	30	17E
0005435902528	20223	31	18E
0005435902521	20223	32	20E
0005435981803	26542	1	1A
0005435981791	26542	2	1D
0005435981802	26542	3	1F
0005435981841	26542	4	2D
0005435981804	26542	5	3A
0005432300197	26542	6	3D
0005432300201	26542	7	3F
0005435981836	26542	8	4C
0005435981796	26542	9	4D
0005435981815	26542	10	4F
0005435981827	26542	11	5A
0005435981807	26542	12	5C
0005433434193	26542	13	5D
0005435981794	26542	14	5E
0005435981800	26542	15	6C
0005435981825	26542	16	6D
0005435981811	26542	17	6E
0005435981837	26542	18	6F
0005435981805	26542	19	7A
0005435981809	26542	20	8A
0005435981789	26542	21	8C
0005435981797	26542	22	8D
0005435981834	26542	23	8E
0005435981820	26542	24	8F
0005435981818	26542	25	9A
0005435981833	26542	26	9C
0005435981823	26542	27	9E
0005435981824	26542	28	10A
0005435981835	26542	29	10E
0005432300200	26542	30	10F
0005435981812	26542	31	11A
0005435981832	26542	32	11D
0005435981830	26542	33	11E
0005435981795	26542	34	12A
0005435981817	26542	35	12C
0005435981822	26542	36	12E
0005432300199	26542	37	12F
0005435981814	26542	38	13A
0005432300202	26542	39	14A
0005435981798	26542	40	14F
0005435981810	26542	41	15C
0005435981828	26542	42	15D
0005435981839	26542	43	15E
0005435981806	26542	44	16A
0005435981790	26542	45	16C
0005435981826	26542	46	16D
0005435981819	26542	47	16E
0005435981813	26542	48	16F
0005435981793	26542	49	17D
0005435981838	26542	50	17E
0005435981816	26542	51	17F
0005435981792	26542	52	18A
0005435981829	26542	53	18E
0005435981840	26542	54	18F
0005432300196	26542	55	19A
0005435981799	26542	56	19D
0005432300198	26542	57	19E
0005435981831	26542	58	19F
0005435981821	26542	59	20A
0005435981808	26542	60	20E
0005435981801	26542	61	20F
0005435981511	26732	1	1A
0005433434390	26732	2	2C
0005435981517	26732	3	2F
0005434271290	26732	4	3A
0005435981604	26732	5	3D
0005435981545	26732	6	3F
0005435981510	26732	7	4A
0005433434406	26732	8	4D
0005434269082	26732	9	4E
0005434270184	26732	10	5D
0005433434402	26732	11	5E
0005433434381	26732	12	6A
0005433434405	26732	13	6F
0005433434397	26732	14	7A
0005435981691	26732	15	7D
0005433434400	26732	16	8D
0005433434398	26732	17	8E
0005433434384	26732	18	9A
0005433434383	26732	19	9D
0005432051097	26732	20	9E
0005433434385	26732	21	9F
0005433434391	26732	22	10E
0005433434407	26732	23	10F
0005433434404	26732	24	11A
0005433434401	26732	25	11C
0005433434409	26732	26	11F
0005433434386	26732	27	12A
0005435981605	26732	28	12C
0005435981586	26732	29	12F
0005433434403	26732	30	13A
0005435981513	26732	31	13C
0005433434393	26732	32	14A
0005433434408	26732	33	14C
0005435981534	26732	34	14E
0005432051096	26732	35	15C
0005434271291	26732	36	15D
0005434269081	26732	37	15E
0005432051095	26732	38	15F
0005433434392	26732	39	16D
0005433434399	26732	40	17A
0005435981536	26732	41	17C
0005434270185	26732	42	18C
0005433434382	26732	43	18F
0005433434388	26732	44	19D
0005433434394	26732	45	19E
0005433434387	26732	46	19F
0005433434389	26732	47	20A
0005433434396	26732	48	20C
0005433434395	26732	49	20E
0005433687681	19522	1	1A
0005433686608	19522	2	1B
0005433685493	19522	3	1C
0005433686606	19522	4	1D
0005433686609	19522	5	2B
0005433685503	19522	6	2C
0005433686613	19522	7	2D
0005433685497	19522	8	3A
0005433686610	19522	9	3B
0005433687679	19522	10	3C
0005433686616	19522	11	3D
0005433685501	19522	12	4A
0005433685506	19522	13	4B
0005433685502	19522	14	4C
0005433686603	19522	15	4D
0005433686607	19522	16	5B
0005433685498	19522	17	5C
0005433685500	19522	18	5D
0005433687685	19522	19	6A
0005433687688	19522	20	6B
0005433687683	19522	21	6C
0005433685505	19522	22	6D
0005433686605	19522	23	7B
0005433687680	19522	24	7C
0005433687682	19522	25	7D
0005433686611	19522	26	18A
0005433685496	19522	27	18B
0005433687686	19522	28	18C
0005433686602	19522	29	18D
0005433686615	19522	30	19A
0005433687684	19522	31	19C
0005433687678	19522	32	19D
0005433685499	19522	33	20A
0005433685495	19522	34	20B
0005433686614	19522	35	20C
0005433687677	19522	36	20D
0005433685491	19522	37	21A
0005433685492	19522	38	21B
0005433687675	19522	39	21C
0005433687687	19522	40	21D
0005433686612	19522	41	22B
0005433685494	19522	42	22C
0005433687676	19522	43	23A
0005433686604	19522	44	22D
0005433685504	19522	45	23B
0005432583778	3183	1	1A
0005432583774	3183	2	1C
0005432583779	3183	3	2B
0005432583764	3183	4	2D
0005432583780	3183	5	3A
0005432857867	3183	6	3B
0005432583787	3183	7	3D
0005432583777	3183	8	4A
0005432583769	3183	9	4C
0005432583784	3183	10	5A
0005432583782	3183	11	5B
0005432583786	3183	12	5C
0005432216243	3183	13	6C
0005432583766	3183	14	6D
0005432583781	3183	15	7A
0005432583773	3183	16	7B
0005432583763	3183	17	7C
0005432857855	3183	18	7D
0005432583762	3183	19	18A
0005432857872	3183	20	18B
0005432857873	3183	21	18C
0005432583767	3183	22	19A
0005432216244	3183	23	19B
0005432583783	3183	24	19D
0005432583770	3183	25	20A
0005432583772	3183	26	20C
0005432583771	3183	27	20D
0005432583768	3183	28	21A
0005432857863	3183	29	21C
0005432583775	3183	30	21D
0005432857876	3183	31	22B
0005432583765	3183	32	22D
0005432583785	3183	33	23A
0005432583776	3183	34	23B
0005432857939	31469	1	1C
0005432583587	31469	2	1D
0005432583602	31469	3	2B
0005432583633	31469	4	2D
0005432857937	31469	5	3B
0005432583661	31469	6	3C
0005432583632	31469	7	3D
0005432583582	31469	8	4D
0005432857942	31469	9	5B
0005432857946	31469	10	5C
0005432857943	31469	11	5D
0005432857938	31469	12	6A
0005432857948	31469	13	6C
0005432857936	31469	14	7A
0005432583634	31469	15	7C
0005432857940	31469	16	7D
0005432857944	31469	17	18A
0005432857947	31469	18	18B
0005432583670	31469	19	18C
0005432857945	31469	20	18D
0005432583656	31469	21	19C
0005432583625	31469	22	19D
0005432583655	31469	23	20B
0005432583654	31469	24	20C
0005432857941	31469	25	20D
0005432583608	31469	26	21C
0005432583626	31469	27	21D
0005432583583	31469	28	22A
0005432583669	31469	29	22D
0005432583724	31469	30	23A
0005434943252	894	1	1D
0005434943258	894	2	2D
0005434943260	894	3	3C
0005434943255	894	4	4A
0005434943254	894	5	4C
0005434943259	894	6	5B
0005434943256	894	7	5D
0005434943257	894	8	6B
0005434943253	894	9	7C
0005433255035	894	10	18D
0005434943251	894	11	20A
0005433255064	16211	1	1B
0005433255065	16211	2	1C
0005434943212	16211	3	2C
0005433255062	16211	4	3A
0005433255063	16211	5	3D
0005433255061	16211	6	5B
0005433255060	16211	7	18D
0005433654700	4331	1	1D
0005433654690	4331	2	2A
0005433654685	4331	3	3D
0005433654705	4331	4	4C
0005433654697	4331	5	6F
0005433654691	4331	6	7B
0005433654695	4331	7	9B
0005433654693	4331	8	9C
0005433654702	4331	9	9E
0005433654701	4331	10	10D
0005433654687	4331	11	10E
0005433654688	4331	12	11A
0005433654692	4331	13	11F
0005433654689	4331	14	12E
0005433654696	4331	15	12D
0005433654686	4331	16	13F
0005433654706	4331	17	14E
0005433654703	4331	18	15C
0005433654704	4331	19	15F
0005433654699	4331	20	18B
0005433654698	4331	21	18E
0005433654707	4331	22	19C
0005433654694	4331	23	20C
0005433811612	27836	1	1A
0005433811611	27836	2	1B
0005433811616	27836	3	2A
0005433811617	27836	4	2B
0005433811610	27836	5	3A
0005433811613	27836	6	3B
0005433811619	27836	7	4A
0005433811618	27836	8	4B
0005433811614	27836	9	5B
0005433811615	27836	10	6A
0005433811620	27836	11	6B
0005435652538	21746	1	1A
0005435652548	21746	2	1D
0005433367220	21746	3	2C
0005435652527	21746	4	3A
0005435652535	21746	5	3F
0005435652546	21746	6	5D
0005435652533	21746	7	5E
0005433367248	21746	8	6A
0005435652556	21746	9	6C
0005435652553	21746	10	6D
0005435652544	21746	11	6F
0005435652542	21746	12	7A
0005435652529	21746	13	7C
0005435652537	21746	14	8A
0005435652540	21746	15	8F
0005435652558	21746	16	9D
0005435652543	21746	17	9E
0005435652547	21746	18	9F
0005435652534	21746	19	10C
0005435652559	21746	20	10D
0005435652532	21746	21	10E
0005435652550	21746	22	11A
0005433367235	21746	23	11D
0005435652531	21746	24	12A
0005433367282	21746	25	12E
0005435652551	21746	26	12F
0005435652530	21746	27	13C
0005435652539	21746	28	13D
0005433367247	21746	29	13E
0005435652528	21746	30	14A
0005435652554	21746	31	14E
0005435652555	21746	32	14D
0005433367291	21746	33	15F
0005433367313	21746	34	16C
0005435652536	21746	35	16E
0005435652545	21746	36	16F
0005435652541	21746	37	17F
0005435652560	21746	38	19E
0005435652549	21746	39	19F
0005435652552	21746	40	20A
0005433367236	21746	41	20C
0005435652557	21746	42	20D
0005433784559	9381	1	1A
0005434273052	9381	2	1B
0005433805045	9381	3	1F
0005433805011	9381	4	2C
0005433805004	9381	5	2B
0005433784555	9381	6	2G
0005433784570	9381	7	3B
0005432667432	9381	8	3F
0005433805030	9381	9	3C
0005432657416	9381	10	3G
0005433805016	9381	11	4B
0005433784564	9381	12	5G
0005433784584	9381	13	9B
0005433805026	9381	14	9G
0005433805013	9381	15	12B
0005433805005	9381	16	12E
0005433805031	9381	17	12F
0005433763052	9381	18	12G
0005433805007	9381	19	13A
0005433784562	9381	20	13E
0005432667433	9381	21	13F
0005433784583	9381	22	14A
0005433784576	9381	23	13H
0005433805021	9381	24	14D
0005433805041	9381	25	14E
0005433784573	9381	26	14G
0005433805010	9381	27	15A
0005433805008	9381	28	14H
0005433805009	9381	29	15E
0005433805020	9381	30	15H
0005433784565	9381	31	15G
0005434170838	9381	32	16A
0005433784567	9381	33	16B
0005433784571	9381	34	16H
0005433805028	9381	35	17B
0005433805018	9381	36	17F
0005433805039	9381	37	17G
0005433805014	9381	38	18A
0005434270170	9381	39	18D
0005433784582	9381	40	18F
0005433763051	9381	41	18G
0005433805029	9381	42	19A
0005433784553	9381	43	18H
0005433763050	9381	44	19E
0005433784569	9381	45	19F
0005434170817	9381	46	19G
0005433805040	9381	47	20A
0005433784563	9381	48	20E
0005432666367	9381	49	20D
0005433763055	9381	50	20F
0005433784575	9381	51	21H
0005433763060	9381	52	22A
0005434170834	9381	53	22D
0005433784581	9381	54	23A
0005433805034	9381	55	23E
0005433805023	9381	56	24D
0005433763056	9381	57	24B
0005432665252	9381	58	24G
0005433784554	9381	59	24F
0005434151657	9381	60	25E
0005432666366	9381	61	27A
0005433805017	9381	62	25F
0005433763054	9381	63	27B
0005433763058	9381	64	27D
0005433784577	9381	65	27G
0005433763049	9381	66	27E
0005432666368	9381	67	28A
0005434170826	9381	68	28B
0005433784586	9381	69	28F
0005433784557	9381	70	28E
0005433805012	9381	71	28G
0005434170837	9381	72	28H
0005433763057	9381	73	29D
0005433805024	9381	74	29G
0005433763062	9381	75	30B
0005433784580	9381	76	30A
0005432665253	9381	77	30E
0005433784578	9381	78	30G
0005433763047	9381	79	30H
0005433805046	9381	80	31B
0005433763061	9381	81	31A
0005433763053	9381	82	31H
0005432657415	9381	83	31G
0005433805044	9381	84	31F
0005433805019	9381	85	32B
0005433805036	9381	86	32E
0005433784560	9381	87	32G
0005433805033	9381	88	33A
0005433784556	9381	89	33H
0005433784558	9381	90	33G
0005433805015	9381	91	34B
0005433805006	9381	92	34A
0005433784561	9381	93	34F
0005433805027	9381	94	34E
0005433805043	9381	95	35A
0005433763059	9381	96	34H
0005433805032	9381	97	35F
0005434170847	9381	98	35E
0005434151654	9381	99	35G
0005432666369	9381	100	36F
0005433805025	9381	101	36G
0005433805022	9381	102	37A
0005433805042	9381	103	36H
0005433763048	9381	104	37B
0005433784579	9381	105	37E
0005433784572	9381	106	37F
0005433805035	9381	107	37H
0005433784566	9381	108	37G
0005433784574	9381	109	38B
0005433784568	9381	110	38F
0005433805038	9381	111	38H
0005432657417	9381	112	38G
0005433784585	9381	113	39E
0005433805037	9381	114	39F
0005433804785	26238	1	1H
0005434170907	26238	2	3B
0005433804795	26238	3	4A
0005434269080	26238	4	4G
0005434170913	26238	5	9B
0005434170912	26238	6	12D
0005433804864	26238	7	12G
0005432666351	26238	8	13F
0005434170910	26238	9	13E
0005433784433	26238	10	13H
0005433804812	26238	11	14A
0005433762971	26238	12	15D
0005433804855	26238	13	16D
0005434170914	26238	14	16E
0005433804802	26238	15	16H
0005433804784	26238	16	17F
0005433804786	26238	17	17G
0005433762972	26238	18	18H
0005434270183	26238	19	21A
0005434170902	26238	20	21D
0005433804843	26238	21	21E
0005434271288	26238	22	22A
0005434151674	26238	23	22D
0005435269673	26238	24	23A
0005433784298	26238	25	23D
0005433804815	26238	26	23G
0005434170911	26238	27	23H
0005433784432	26238	28	24A
0005434170908	26238	29	24D
0005433762949	26238	30	24F
0005433784297	26238	31	24G
0005434151673	26238	32	27F
0005434170899	26238	33	27G
0005434170906	26238	34	28B
0005433784301	26238	35	28E
0005434170904	26238	36	28F
0005434151672	26238	37	29G
0005435269672	26238	38	29F
0005433762979	26238	39	30G
0005434170900	26238	40	31B
0005434170905	26238	41	31E
0005433762956	26238	42	31F
0005433804854	26238	43	32B
0005433762950	26238	44	32E
0005433804823	26238	45	32F
0005434270182	26238	46	32H
0005433804791	26238	47	33B
0005433804794	26238	48	34F
0005433784354	26238	49	34G
0005435269674	26238	50	35D
0005434170909	26238	51	36A
0005433784356	26238	52	36G
0005434170901	26238	53	37G
0005434170903	26238	54	37F
0005434271289	26238	55	38H
0005435135617	4905	1	4D
0005435929602	4905	2	6A
0005435135618	4905	3	6C
0005435135619	4905	4	18A
0005435135620	4905	5	19B
0005435135621	4905	6	20C
0005435929601	4905	7	23A
0005435929616	33006	1	1C
0005435929615	33006	2	2A
0005435135595	33006	3	3B
0005435135588	33006	4	4C
0005435929614	33006	5	5B
0005435135587	33006	6	19B
0005434217907	9469	1	1C
0005434983235	9469	2	4D
0005434217897	9469	3	18A
0005434983234	9469	4	18D
0005434983232	9469	5	19A
0005434983233	9469	6	20C
0005434983231	9469	7	20D
0005434217898	9469	8	21D
0005434217905	9469	9	22B
0005434217906	9469	10	22A
0005434983207	27355	1	1D
0005434217925	27355	2	2B
0005434983206	27355	3	2D
0005434217926	27355	4	6A
0005434217927	27355	5	6D
0005434983202	27355	6	19B
0005434983203	27355	7	19C
0005433960218	25929	1	1A
0005433960267	25929	2	1F
0005433985447	25929	3	1H
0005433985418	25929	4	2A
0005433985459	25929	5	2F
0005433960230	25929	6	2C
0005433960219	25929	7	2G
0005433985428	25929	8	2H
0005433985438	25929	9	3B
0005433985442	25929	10	3C
0005433985446	25929	11	4A
0005433960248	25929	12	4C
0005433960226	25929	13	4G
0005433985417	25929	14	4F
0005433960255	25929	15	5B
0005433960225	25929	16	5G
0005433960220	25929	17	9A
0005433960247	25929	18	9B
0005433960234	25929	19	9H
0005433960261	25929	20	11B
0005433960214	25929	21	11E
0005433960253	25929	22	11G
0005433985458	25929	23	11F
0005433960244	25929	24	12A
0005433960240	25929	25	12D
0005433985461	25929	26	12B
0005433960243	25929	27	12E
0005433985454	25929	28	12F
0005433960242	25929	29	12H
0005433960233	25929	30	13G
0005433985415	25929	31	14B
0005433960212	25929	32	14A
0005433985411	25929	33	14E
0005433960213	25929	34	14G
0005433960251	25929	35	14F
0005433960231	25929	36	14H
0005433985410	25929	37	15E
0005433960236	25929	38	16A
0005433985433	25929	39	16B
0005433960209	25929	40	16G
0005433985427	25929	41	16F
0005433960235	25929	42	16H
0005433985413	25929	43	17A
0005433985432	25929	44	17G
0005433985420	25929	45	18B
0005433960263	25929	46	18E
0005433985441	25929	47	18D
0005433960215	25929	48	18F
0005433960227	25929	49	18G
0005433985416	25929	50	19B
0005433960250	25929	51	19D
0005433960254	25929	52	19F
0005433985414	25929	53	19E
0005433985436	25929	54	19H
0005433985457	25929	55	20D
0005433985445	25929	56	20F
0005433960249	25929	57	21A
0005433960260	25929	58	21D
0005433960262	25929	59	21B
0005433960258	25929	60	21E
0005433960265	25929	61	21H
0005433985453	25929	62	22F
0005433985409	25929	63	22E
0005433985440	25929	64	23E
0005433960221	25929	65	23G
0005433960223	25929	66	23F
0005433960217	25929	67	24A
0005433960257	25929	68	23H
0005433960241	25929	69	24B
0005433960239	25929	70	24D
0005433985422	25929	71	24F
0005433985439	25929	72	24G
0005433985462	25929	73	25F
0005433985448	25929	74	27E
0005433960256	25929	75	27F
0005433985426	25929	76	27G
0005433960224	25929	77	28B
0005433985443	25929	78	28E
0005433985451	25929	79	28D
0005433960222	25929	80	28F
0005433985435	25929	81	28H
0005433985429	25929	82	29D
0005433960238	25929	83	29H
0005433985419	25929	84	29G
0005433960264	25929	85	30A
0005433985412	25929	86	31B
0005433960259	25929	87	31A
0005433985425	25929	88	31E
0005433960211	25929	89	31G
0005433960245	25929	90	31H
0005433960216	25929	91	32F
0005433985449	25929	92	32G
0005433985444	25929	93	33A
0005433960229	25929	94	33E
0005433985408	25929	95	33F
0005433960246	25929	96	33H
0005433960210	25929	97	34D
0005433985423	25929	98	34B
0005433985431	25929	99	34G
0005433985430	25929	100	34H
0005433960237	25929	101	35A
0005433985463	25929	102	35E
0005433985424	25929	103	35G
0005433960232	25929	104	35H
0005433985456	25929	105	36A
0005433960266	25929	106	36G
0005433985434	25929	107	37B
0005433985460	25929	108	37E
0005433985437	25929	109	37F
0005433960252	25929	110	37G
0005433985421	25929	111	38A
0005433985450	25929	112	38B
0005433985452	25929	113	38E
0005433985455	25929	114	38H
0005433960228	25929	115	39E
0005434480077	938	1	1A
0005434480081	938	2	1B
0005434480062	938	3	1C
0005434480063	938	4	1D
0005434480061	938	5	2A
0005434480078	938	6	2C
0005434480070	938	7	3A
0005434480072	938	8	3B
0005434480069	938	9	3C
0005434480076	938	10	3D
0005434480075	938	11	4C
0005434480057	938	12	4D
0005432269465	938	13	5A
0005434480056	938	14	5B
0005434480060	938	15	5C
0005434480065	938	16	6B
0005434480064	938	17	7A
0005434480074	938	18	7B
0005433165676	938	19	7C
0005434480059	938	20	18A
0005434480058	938	21	18B
0005432269466	938	22	18C
0005432269467	938	23	19A
0005434480071	938	24	19B
0005433165700	938	25	19C
0005434480079	938	26	20A
0005434480067	938	27	20B
0005434480068	938	28	20D
0005433165686	938	29	21A
0005433165675	938	30	21B
0005433165680	938	31	21C
0005434480080	938	32	21D
0005433165679	938	33	22A
0005433165701	938	34	22B
0005433165687	938	35	22C
0005434480073	938	36	22D
0005434480066	938	37	23A
0005434479905	16553	1	1A
0005434479878	16553	2	1B
0005433165765	16553	3	2A
0005433165769	16553	4	3A
0005433165766	16553	5	3B
0005434479903	16553	6	4A
0005433165771	16553	7	4B
0005434479926	16553	8	4C
0005433165767	16553	9	4D
0005433165774	16553	10	6A
0005433165773	16553	11	6C
0005433165768	16553	12	7A
0005434479896	16553	13	7B
0005433165770	16553	14	18B
0005433165772	16553	15	18A
0005433165775	16553	16	18C
0005433165764	16553	17	19B
0005434479892	16553	18	19C
0005433165763	16553	19	19D
0005434479879	16553	20	20D
0005434479901	16553	21	22C
0005434479904	16553	22	22D
0005434479880	16553	23	23B
0005433872447	3198	1	2D
0005433872452	3198	2	3B
0005433872448	3198	3	4A
0005433872444	3198	4	5B
0005433872446	3198	5	5D
0005433872449	3198	6	7B
0005433872451	3198	7	18A
0005433872443	3198	8	18B
0005433872450	3198	9	19D
0005433872445	3198	10	21A
0005433872453	3198	11	22D
0005433872427	32536	1	2C
0005433872426	32536	2	20B
0005433872439	32536	3	23B
0005435142431	10374	1	1A
0005435149874	10374	2	1C
0005435149876	10374	3	2A
0005435149872	10374	4	2B
0005435386461	10374	5	2C
0005435142425	10374	6	2D
0005435149877	10374	7	3B
0005435142424	10374	8	3C
0005435149870	10374	9	3D
0005435149881	10374	10	4A
0005435149880	10374	11	4C
0005435142428	10374	12	5A
0005435149884	10374	13	5D
0005435386462	10374	14	6B
0005435149875	10374	15	6C
0005435149878	10374	16	6D
0005435142427	10374	17	7C
0005435142418	10374	18	7D
0005435142420	10374	19	18B
0005435149879	10374	20	18C
0005435142422	10374	21	19A
0005435142423	10374	22	20A
0005435149882	10374	23	21A
0005435149883	10374	24	21B
0005435142421	10374	25	21C
0005435149871	10374	26	21D
0005435142419	10374	27	22A
0005435149873	10374	28	22B
0005435142429	10374	29	22C
0005435142430	10374	30	22D
0005435142426	10374	31	23B
0005435142335	21910	1	1A
0005433289780	21910	2	2B
0005433289784	21910	3	2C
0005435386504	21910	4	3A
0005435386506	21910	5	3B
0005435386509	21910	6	4A
0005433289782	21910	7	4B
0005433289779	21910	8	5A
0005435386508	21910	9	5B
0005435386507	21910	10	5D
0005433289777	21910	11	7A
0005435142342	21910	12	7B
0005435386510	21910	13	7C
0005433289785	21910	14	18B
0005433289781	21910	15	19C
0005433289776	21910	16	20B
0005435386505	21910	17	21B
0005435142362	21910	18	22B
0005433289778	21910	19	22C
0005433289783	21910	20	23B
0005434573196	11224	1	2D
0005434573202	11224	2	4C
0005434573188	11224	3	5D
0005434573197	11224	4	5F
0005434573195	11224	5	6D
0005435501991	11224	6	7A
0005435501951	11224	7	7D
0005435319423	11224	8	8D
0005434573190	11224	9	9C
0005434573200	11224	10	9D
0005435528893	11224	11	10A
0005435501945	11224	12	10C
0005434573191	11224	13	10F
0005435501970	11224	14	11F
0005435528882	11224	15	12D
0005434573198	11224	16	13E
0005434573199	11224	17	13F
0005435528900	11224	18	15D
0005434573189	11224	19	15E
0005435528899	11224	20	16D
0005434573192	11224	21	16E
0005435501985	11224	22	17A
0005435501971	11224	23	18F
0005434573201	11224	24	19A
0005434573194	11224	25	19C
0005434573193	11224	26	20A
0005435528908	11224	27	20E
0005435502072	20913	1	1A
0005435517716	20913	2	1C
0005435517729	20913	3	2A
0005434573129	20913	4	2C
0005435502085	20913	5	2D
0005435502067	20913	6	2F
0005435502068	20913	7	3A
0005435517721	20913	8	3C
0005435319496	20913	9	3D
0005435517719	20913	10	4A
0005434573127	20913	11	4C
0005435517712	20913	12	4D
0005435517727	20913	13	4E
0005435319490	20913	14	4F
0005435517720	20913	15	5A
0005435508232	20913	16	5C
0005435508233	20913	17	5D
0005435517723	20913	18	5E
0005435517718	20913	19	5F
0005435502080	20913	20	6A
0005434573109	20913	21	6C
0005435502083	20913	22	6E
0005435502076	20913	23	6F
0005435508234	20913	24	7A
0005435517724	20913	25	7D
0005435508231	20913	26	7E
0005435319493	20913	27	7F
0005435502082	20913	28	8A
0005435502065	20913	29	8D
0005435502084	20913	30	8E
0005435502081	20913	31	8F
0005435508229	20913	32	9A
0005435508230	20913	33	9D
0005435502078	20913	34	10A
0005435517717	20913	35	10C
0005434573126	20913	36	10F
0005435517711	20913	37	11A
0005435319491	20913	38	11D
0005435319487	20913	39	11E
0005435502066	20913	40	11F
0005434573110	20913	41	12A
0005435502071	20913	42	12C
0005432291904	20913	43	12E
0005435502077	20913	44	12F
0005435517715	20913	45	13A
0005435502074	20913	46	13C
0005434573128	20913	47	13D
0005435319492	20913	48	14A
0005435517722	20913	49	14C
0005435502079	20913	50	14D
0005435502069	20913	51	15A
0005435502070	20913	52	15F
0005435517714	20913	53	16A
0005435319489	20913	54	16C
0005434573124	20913	55	16D
0005435517725	20913	56	16E
0005435517713	20913	57	17A
0005435502064	20913	58	17C
0005434573125	20913	59	17D
0005435502075	20913	60	18C
0005435319494	20913	61	18E
0005435319495	20913	62	18F
0005435517730	20913	63	19A
0005432291903	20913	64	19C
0005435517731	20913	65	19D
0005435517726	20913	66	19E
0005435517728	20913	67	20C
0005435502073	20913	68	20D
0005434573119	20913	69	20E
0005435319488	20913	70	20F
0005433927396	24308	1	1C
0005433683309	24308	2	3C
0005433683310	24308	3	3D
0005433683302	24308	4	4A
0005433683301	24308	5	4B
0005433927395	24308	6	5A
0005433683307	24308	7	5C
0005433683308	24308	8	6C
0005433683311	24308	9	7A
0005433683305	24308	10	18A
0005433927397	24308	11	19B
0005433683303	24308	12	19C
0005433683304	24308	13	20A
0005433683306	24308	14	21D
0005433927406	29283	1	2A
0005433927411	29283	2	2D
0005433927409	29283	3	3A
0005433927416	29283	4	5A
0005433683292	29283	5	6C
0005433927413	29283	6	7B
0005433683291	29283	7	7C
0005433927415	29283	8	7D
0005433927407	29283	9	18B
0005433683293	29283	10	18C
0005433927412	29283	11	20A
0005433927408	29283	12	20B
0005433683290	29283	13	22A
0005433927410	29283	14	22B
0005433927414	29283	15	22C
0005432692541	3003	1	3A
0005432692581	3003	2	4D
0005432692536	3003	3	6F
0005432692563	3003	4	14E
0005432692542	3003	5	20C
0005432706514	3004	1	1C
0005432706497	3004	2	2A
0005433123579	3004	3	2C
0005432706503	3004	4	2D
0005432706508	3004	5	4A
0005432217746	3004	6	4F
0005432706494	3004	7	5A
0005432706504	3004	8	5E
0005433123578	3004	9	6A
0005432706515	3004	10	6C
0005432706498	3004	11	6D
0005432217747	3004	12	7E
0005433123583	3004	13	7F
0005433123585	3004	14	8C
0005433194817	3004	15	8D
0005432217745	3004	16	8E
0005432706495	3004	17	8F
0005432706490	3004	18	9C
0005432706502	3004	19	9E
0005432706513	3004	20	10A
0005432706507	3004	21	11E
0005432706491	3004	22	11F
0005432706500	3004	23	12A
0005433123568	3004	24	12E
0005432706496	3004	25	13D
0005432706511	3004	26	14A
0005433123584	3004	27	14C
0005432706505	3004	28	15A
0005432706492	3004	29	15C
0005432706499	3004	30	15D
0005432706510	3004	31	16A
0005432706516	3004	32	16F
0005433123572	3004	33	17D
0005432706501	3004	34	18A
0005432706493	3004	35	18C
0005432706512	3004	36	18E
0005432706517	3004	37	19C
0005432706506	3004	38	19D
0005432706509	3004	39	19E
0005433123610	3004	40	20C
0005433123569	3004	41	20E
0005433123706	30013	1	1A
0005432880660	30013	2	1C
0005432706396	30013	3	1F
0005433123703	30013	4	2A
0005432692777	30013	5	2C
0005432706326	30013	6	2D
0005432880658	30013	7	2F
0005432692767	30013	8	3A
0005432706340	30013	9	3C
0005432692773	30013	10	3D
0005432706354	30013	11	4A
0005432706332	30013	12	4C
0005432692758	30013	13	4D
0005432880669	30013	14	4F
0005432880667	30013	15	5C
0005432692766	30013	16	5D
0005433123702	30013	17	5E
0005432692763	30013	18	5F
0005432692775	30013	19	6A
0005432880656	30013	20	6C
0005432692762	30013	21	6F
0005432692749	30013	22	7A
0005432706338	30013	23	7C
0005432692778	30013	24	7D
0005432706331	30013	25	7E
0005432692771	30013	26	7F
0005432692755	30013	27	8A
0005432692764	30013	28	8C
0005432706359	30013	29	8E
0005432692752	30013	30	8F
0005432880670	30013	31	9A
0005432692765	30013	32	9C
0005432706380	30013	33	9D
0005432692759	30013	34	9E
0005432880663	30013	35	10C
0005432880668	30013	36	10E
0005433123704	30013	37	11A
0005432880657	30013	38	11C
0005432706382	30013	39	11E
0005433123709	30013	40	11F
0005432706339	30013	41	12A
0005432692770	30013	42	12E
0005432692772	30013	43	12F
0005433123701	30013	44	13A
0005432692760	30013	45	13C
0005433123710	30013	46	13D
0005433123712	30013	47	13F
0005432692779	30013	48	14A
0005433123705	30013	49	14C
0005432880664	30013	50	14D
0005432692748	30013	51	14E
0005432880665	30013	52	14F
0005432692774	30013	53	15A
0005432692776	30013	54	15C
0005433123707	30013	55	15D
0005432880661	30013	56	15E
0005432880659	30013	57	15F
0005432692768	30013	58	16A
0005432880666	30013	59	16C
0005432692754	30013	60	16D
0005432692750	30013	61	16E
0005432706362	30013	62	16F
0005432692769	30013	63	17A
0005432706383	30013	64	17C
0005432692751	30013	65	17D
0005432692761	30013	66	17E
0005432706358	30013	67	18A
0005433123711	30013	68	18C
0005433123708	30013	69	18D
0005433123699	30013	70	18F
0005432692757	30013	71	19A
0005432706355	30013	72	19C
0005432692753	30013	73	19D
0005432880662	30013	74	19E
0005432706363	30013	75	19F
0005433123700	30013	76	20C
0005432692756	30013	77	20D
0005432706381	30013	78	20E
0005433123713	30013	79	20F
0005434988610	23655	1	1B
0005434988616	23655	2	1C
0005434979450	23655	3	1D
0005434979461	23655	4	2A
0005434979443	23655	5	2B
0005434988611	23655	6	2C
0005434979454	23655	7	2D
0005434979462	23655	8	3A
0005434979466	23655	9	3C
0005434988619	23655	10	3D
0005434979464	23655	11	4A
0005434979441	23655	12	4B
0005434988608	23655	13	4D
0005434988620	23655	14	5A
0005434979446	23655	15	5B
0005434979445	23655	16	5C
0005434979439	23655	17	5D
0005434979452	23655	18	6A
0005434979459	23655	19	6B
0005434988612	23655	20	6C
0005434979458	23655	21	6D
0005434979460	23655	22	7A
0005434979447	23655	23	7B
0005434979465	23655	24	7C
0005434988617	23655	25	7D
0005434988613	23655	26	18B
0005434979442	23655	27	18D
0005434988609	23655	28	18C
0005434979437	23655	29	19A
0005434979444	23655	30	19B
0005434979455	23655	31	19C
0005434979438	23655	32	20A
0005434979448	23655	33	20B
0005434988621	23655	34	20C
0005434979456	23655	35	20D
0005434979449	23655	36	21A
0005434979457	23655	37	21B
0005434988618	23655	38	21C
0005434979440	23655	39	21D
0005434988614	23655	40	22A
0005434979451	23655	41	22B
0005434988615	23655	42	22D
0005434979463	23655	43	23A
0005434979453	23655	44	23B
0005434979253	27558	1	2A
0005434979363	27558	2	3C
0005434979299	27558	3	5D
0005434979331	27558	4	6A
0005434979254	27558	5	7B
0005434979362	27558	6	20A
0005434979260	27558	7	21C
0005434979283	27558	8	23A
0005434979337	27558	9	23B
0005434302412	10246	1	6D
0005434302409	10246	2	7A
0005434302410	10246	3	7C
0005434302408	10246	4	21A
0005434302411	10246	5	21C
0005434302390	19635	1	2A
0005433113511	19635	2	2B
0005434302389	19635	3	3B
0005434302385	19635	4	5D
0005433113512	19635	5	20D
0005435068545	3579	1	1A
0005435068559	3579	2	1C
0005435068549	3579	3	2C
0005435068570	3579	4	2F
0005435068565	3579	5	3A
0005435718884	3579	6	3C
0005435718881	3579	7	3D
0005435068560	3579	8	4A
0005435068563	3579	9	4C
0005435068555	3579	10	4F
0005435068542	3579	11	5A
0005435068574	3579	12	5D
0005435068558	3579	13	6C
0005435068553	3579	14	6D
0005435068539	3579	15	6E
0005435068530	3579	16	6F
0005435068534	3579	17	7A
0005435718883	3579	18	7C
0005435068564	3579	19	7D
0005435068547	3579	20	8E
0005435718882	3579	21	8F
0005435068552	3579	22	9A
0005435718879	3579	23	9D
0005435068538	3579	24	9E
0005435068531	3579	25	9F
0005435068568	3579	26	10D
0005435068579	3579	27	10E
0005435068576	3579	28	10F
0005435068544	3579	29	11C
0005435068537	3579	30	11D
0005435068577	3579	31	11E
0005435068567	3579	32	11F
0005435068533	3579	33	12A
0005435068581	3579	34	12E
0005435068548	3579	35	13E
0005435718880	3579	36	14C
0005435068529	3579	37	14D
0005435068543	3579	38	14F
0005435068554	3579	39	15A
0005435068573	3579	40	15D
0005435068572	3579	41	15C
0005435068536	3579	42	16C
0005435068569	3579	43	16D
0005435068561	3579	44	16E
0005435068546	3579	45	16F
0005435068541	3579	46	17C
0005435068571	3579	47	17E
0005435068540	3579	48	17F
0005435068551	3579	49	18A
0005435068575	3579	50	18C
0005435068566	3579	51	18E
0005435068550	3579	52	18F
0005435068562	3579	53	19A
0005435068532	3579	54	19D
0005435068557	3579	55	19E
0005435068535	3579	56	20A
0005435068580	3579	57	20C
0005435068556	3579	58	20D
0005435068578	3579	59	20E
0005435068217	15289	1	2C
0005435068266	15289	2	2D
0005435068267	15289	3	2F
0005435925148	15289	4	5A
0005435068172	15289	5	6C
0005435925151	15289	6	7E
0005435925149	15289	7	9D
0005435939864	15289	8	12F
0005435068286	15289	9	13F
0005435925152	15289	10	14D
0005435925150	15289	11	14E
0005435068192	15289	12	15A
0005435068275	15289	13	15F
0005435068193	15289	14	17A
0005435068256	15289	15	17C
0005435925153	15289	16	17E
0005435925154	15289	17	19E
0005435068218	15289	18	20E
0005432660796	18149	1	1A
0005432660795	18149	2	2A
0005432658571	18149	3	3B
0005432658570	18149	4	4B
0005432659685	18149	5	4A
0005432658568	18149	6	5A
0005432659684	18149	7	6A
0005432658569	18149	8	6B
0005432157471	153	1	2A
0005432677509	153	2	4A
0005432901369	153	3	3F
0005433101170	153	4	4F
0005432157472	153	5	5D
0005432919535	153	6	5F
0005433101152	153	7	8E
0005432919528	153	8	9A
0005433101159	153	9	11E
0005432919527	153	10	12C
0005432901346	153	11	12F
0005432901295	153	12	13A
0005432901302	153	13	13C
0005432901317	153	14	14D
0005432901306	153	15	15C
0005433101158	153	16	15F
0005432901305	153	17	16B
0005432901381	153	18	16F
0005432391947	153	19	17A
0005432901361	153	20	17D
0005432901319	153	21	18E
0005432901301	153	22	19C
0005432677508	153	23	19D
0005432919529	153	24	22F
0005432901316	153	25	23F
0005432391946	153	26	24F
0005432919562	153	27	26D
0005433101160	153	28	26F
0005432901356	153	29	27C
0005432901370	153	30	28A
0005432901380	153	31	28C
0005433101153	153	32	29C
0005432901293	153	33	30E
0005432677510	153	34	31D
0005433101155	153	35	31F
0005432817169	152	1	1A
0005432817162	152	2	1C
0005432817168	152	3	1F
0005432817171	152	4	2D
0005432817165	152	5	3A
0005432817178	152	6	3F
0005432261428	152	7	3D
0005432261425	152	8	4A
0005432261421	152	9	5A
0005432261446	152	10	4F
0005432261437	152	11	5C
0005432817160	152	12	6C
0005432817175	152	13	7D
0005432261435	152	14	7F
0005432261441	152	15	8B
0005432261433	152	16	8D
0005432817177	152	17	8E
0005432261415	152	18	9D
0005432817176	152	19	10A
0005432261452	152	20	9F
0005432261416	152	21	10B
0005432261423	152	22	10D
0005432817151	152	23	10E
0005432817153	152	24	11B
0005432261454	152	25	11E
0005432817152	152	26	12A
0005432261432	152	27	12B
0005432261427	152	28	12C
0005432288953	152	29	12E
0005432261419	152	30	12D
0005432207633	152	31	12F
0005432261451	152	32	13D
0005432261429	152	33	13E
0005432261438	152	34	14C
0005432261447	152	35	14B
0005432261444	152	36	14D
0005432261443	152	37	15E
0005432817150	152	38	15D
0005432261453	152	39	15F
0005432261436	152	40	16B
0005432817170	152	41	16D
0005432261422	152	42	16E
0005432817155	152	43	17B
0005432261455	152	44	17A
0005434153522	152	45	17C
0005432817154	152	46	17F
0005432817161	152	47	18B
0005432261426	152	48	18D
0005432261439	152	49	18C
0005432288952	152	50	18F
0005432261440	152	51	19B
0005432261418	152	52	19D
0005432817164	152	53	19E
0005432261457	152	54	20E
0005432817156	152	55	21A
0005432261459	152	56	21C
0005434153521	152	57	21E
0005432817173	152	58	21F
0005432817167	152	59	22B
0005432261449	152	60	22C
0005432261460	152	61	22E
0005432207632	152	62	22F
0005432288951	152	63	23A
0005432261431	152	64	23B
0005432817163	152	65	23D
0005432261442	152	66	24E
0005434153523	152	67	24F
0005432261445	152	68	25B
0005432261434	152	69	25C
0005432261456	152	70	26E
0005432817172	152	71	26F
0005432261424	152	72	27C
0005432261450	152	73	28B
0005432261458	152	74	28C
0005432817159	152	75	28F
0005432261420	152	76	29B
0005432261448	152	77	29D
0005432817179	152	78	29C
0005432817158	152	79	29F
0005432817166	152	80	30B
0005432817157	152	81	31A
0005432817174	152	82	30F
0005432261430	152	83	31C
0005432261417	152	84	31E
0005432919643	7968	1	1A
0005433101615	7968	2	2A
0005432919645	7968	3	2C
0005432677534	7968	4	2F
0005432919647	7968	5	2D
0005432019989	7968	6	3C
0005432019985	7968	7	3F
0005432019977	7968	8	3D
0005432919652	7968	9	4F
0005432919648	7968	10	5A
0005433101602	7968	11	6A
0005433101598	7968	12	5F
0005433101592	7968	13	6D
0005433101614	7968	14	6C
0005432019976	7968	15	6F
0005432919636	7968	16	7C
0005432019988	7968	17	7F
0005432019987	7968	18	7D
0005432919650	7968	19	8A
0005432919631	7968	20	8D
0005432919641	7968	21	8C
0005432019974	7968	22	8F
0005433101616	7968	23	9A
0005433101600	7968	24	9B
0005432019998	7968	25	10A
0005432391969	7968	26	10C
0005432919653	7968	27	10D
0005432751493	7968	28	10E
0005432919635	7968	29	10F
0005432919646	7968	30	11D
0005433101594	7968	31	11E
0005432019993	7968	32	12A
0005432919634	7968	33	11F
0005432391968	7968	34	12B
0005433101610	7968	35	12D
0005432677533	7968	36	12E
0005432677535	7968	37	13A
0005433101596	7968	38	13C
0005432751492	7968	39	13E
0005432019990	7968	40	13F
0005433101608	7968	41	14E
0005432019994	7968	42	14F
0005433101590	7968	43	15A
0005432019973	7968	44	15D
0005432753266	7968	45	15F
0005433101595	7968	46	15E
0005432019992	7968	47	16A
0005432919638	7968	48	16F
0005432919640	7968	49	16E
0005432391967	7968	50	17A
0005432019978	7968	51	17C
0005433101589	7968	52	17D
0005432919633	7968	53	17F
0005432044497	7968	54	18A
0005432045595	7968	55	18B
0005432677536	7968	56	18C
0005432019972	7968	57	18E
0005432753268	7968	58	18D
0005433101606	7968	59	18F
0005432919642	7968	60	19E
0005433101593	7968	61	20A
0005433101604	7968	62	20C
0005432019995	7968	63	20B
0005432919649	7968	64	20E
0005433101601	7968	65	21A
0005432919639	7968	66	21B
0005433101591	7968	67	21E
0005432753267	7968	68	22A
0005432019984	7968	69	22B
0005432919644	7968	70	22F
0005433101609	7968	71	23A
0005432019983	7968	72	23D
0005432919632	7968	73	23F
0005433101603	7968	74	24C
0005433101617	7968	75	24D
0005433101611	7968	76	24F
0005432045593	7968	77	25B
0005432019980	7968	78	25A
0005433101618	7968	79	25C
0005433101613	7968	80	25D
0005432019975	7968	81	26C
0005433101605	7968	82	26E
0005433101619	7968	83	26F
0005432019971	7968	84	27A
0005433101597	7968	85	27C
0005432044496	7968	86	27F
0005432019986	7968	87	27E
0005433101607	7968	88	28A
0005433101599	7968	89	28B
0005432019982	7968	90	28C
0005432019997	7968	91	28F
0005432019991	7968	92	29B
0005432045594	7968	93	29A
0005432019996	7968	94	29D
0005433101612	7968	95	30C
0005432919651	7968	96	30B
0005432919637	7968	97	30D
0005432019981	7968	98	31A
0005432019979	7968	99	31B
0005432044495	7968	100	31E
0005432817061	8021	1	1F
0005432901425	8021	2	3A
0005432901423	8021	3	7A
0005434513536	8021	4	8B
0005432816964	8021	5	9C
0005432901434	8021	6	10A
0005434513533	8021	7	10E
0005432901429	8021	8	11C
0005432816944	8021	9	13B
0005432901435	8021	10	13D
0005432817042	8021	11	14C
0005432901427	8021	12	14F
0005432816954	8021	13	15C
0005432901433	8021	14	15E
0005432816952	8021	15	16A
0005432901424	8021	16	18A
0005434513534	8021	17	19D
0005432816953	8021	18	20C
0005432901422	8021	19	21B
0005432002055	8021	20	21E
0005432901420	8021	21	22B
0005432901430	8021	22	23D
0005432901426	8021	23	23C
0005432817041	8021	24	24D
0005432901421	8021	25	24C
0005432816955	8021	26	25E
0005434513535	8021	27	26D
0005432901431	8021	28	26F
0005432901419	8021	29	27A
0005432901432	8021	30	27D
0005432817000	8021	31	30C
0005432901436	8021	32	30F
0005432901428	8021	33	31B
0005432817067	8021	34	31A
0005432816943	8021	35	31F
0005434175686	9654	1	1A
0005433870708	9654	2	3B
0005433870707	9654	3	6B
0005434175708	32377	1	5A
0005434175710	32377	2	5B
0005434175709	32377	3	6A
0005434877245	3491	1	1A
0005434877248	3491	2	1H
0005435125949	3491	3	2A
0005434877314	3491	4	1K
0005434877297	3491	5	2D
0005434937937	3491	6	2C
0005434877310	3491	7	2H
0005434426315	3491	8	2K
0005434877239	3491	9	3D
0005435625998	3491	10	3C
0005435625987	3491	11	3K
0005434426319	3491	12	3G
0005434877318	3491	13	4C
0005434877267	3491	14	4G
0005435125942	3491	15	4D
0005435125973	3491	16	4K
0005434426300	3491	17	4H
0005435625999	3491	18	5D
0005435125968	3491	19	5C
0005434877320	3491	20	5G
0005434426323	3491	21	11A
0005435902414	3491	22	5K
0005432188574	3491	23	11E
0005435125939	3491	24	11H
0005434937947	3491	25	11G
0005434877253	3491	26	12C
0005435125969	3491	27	11K
0005434877294	3491	28	12E
0005434877317	3491	29	12K
0005434877324	3491	30	13D
0005434877246	3491	31	13A
0005434877325	3491	32	13H
0005432611669	3491	33	13G
0005432799180	3491	34	14C
0005435125966	3491	35	14A
0005432799159	3491	36	13K
0005435125944	3491	37	14K
0005434426316	3491	38	14H
0005434877256	3491	39	15E
0005434877254	3491	40	15H
0005434426303	3491	41	15G
0005434877309	3491	42	16A
0005434877281	3491	43	16C
0005434877315	3491	44	16F
0005435125976	3491	45	16E
0005432799158	3491	46	16K
0005434426307	3491	47	16H
0005434877306	3491	48	16G
0005434426311	3491	49	17C
0005434937935	3491	50	17E
0005434877262	3491	51	17H
0005434877286	3491	52	18A
0005434877258	3491	53	18G
0005432799164	3491	54	18F
0005432799171	3491	55	19B
0005434426304	3491	56	19C
0005434937945	3491	57	19F
0005434877264	3491	58	19E
0005434877295	3491	59	19D
0005435125943	3491	60	19G
0005432799161	3491	61	19K
0005434877271	3491	62	20C
0005432183445	3491	63	20B
0005434877304	3491	64	20E
0005434877251	3491	65	20F
0005434877269	3491	66	20J
0005434877243	3491	67	21A
0005434877311	3491	68	20K
0005434426312	3491	69	21D
0005432799157	3491	70	21C
0005435625997	3491	71	21F
0005432799170	3491	72	21E
0005435125958	3491	73	21J
0005434877321	3491	74	21H
0005435125962	3491	75	22A
0005434877293	3491	76	21K
0005434877301	3491	77	22B
0005434937942	3491	78	22E
0005435125938	3491	79	22G
0005432799163	3491	80	22J
0005434877240	3491	81	22H
0005434426314	3491	82	23B
0005434426299	3491	83	23A
0005432183444	3491	84	24D
0005435625990	3491	85	24G
0005432188575	3491	86	24F
0005435625984	3491	87	24E
0005434877302	3491	88	25D
0005435625996	3491	89	25C
0005435625988	3491	90	25E
0005435125979	3491	91	26B
0005434877323	3491	92	26E
0005435625993	3491	93	26G
0005434937943	3491	94	26F
0005434877257	3491	95	26H
0005435125954	3491	96	27B
0005434426322	3491	97	26K
0005434877326	3491	98	27D
0005435125974	3491	99	27C
0005435902413	3491	100	27F
0005434426313	3491	101	27E
0005435125948	3491	102	27J
0005432799169	3491	103	27H
0005432799172	3491	104	27K
0005434937938	3491	105	28C
0005435625994	3491	106	28B
0005435125940	3491	107	28E
0005434426321	3491	108	28D
0005434426301	3491	109	28F
0005434877278	3491	110	28K
0005434877276	3491	111	28J
0005434877283	3491	112	28H
0005434877303	3491	113	29C
0005435125955	3491	114	29F
0005434877329	3491	115	29D
0005434877249	3491	116	29H
0005434877236	3491	117	29G
0005434877238	3491	118	29K
0005434426320	3491	119	30C
0005434877255	3491	120	30B
0005434937941	3491	121	30D
0005435902412	3491	122	30G
0005435125978	3491	123	30F
0005434877327	3491	124	30J
0005434877272	3491	125	31B
0005432799168	3491	126	31C
0005432799165	3491	127	32A
0005432799179	3491	128	31J
0005435125965	3491	129	32C
0005435902394	3491	130	32E
0005434877237	3491	131	32D
0005432611671	3491	132	32G
0005432188573	3491	133	32F
0005434877279	3491	134	32J
0005434877277	3491	135	33B
0005435625992	3491	136	32K
0005434877285	3491	137	33C
0005434877312	3491	138	33H
0005435125956	3491	139	33G
0005434877296	3491	140	33J
0005434937940	3491	141	34B
0005434877250	3491	142	34C
0005434426302	3491	143	34G
0005434877260	3491	144	34F
0005434426309	3491	145	34H
0005432799178	3491	146	35A
0005435125961	3491	147	35G
0005434877259	3491	148	35E
0005434937949	3491	149	36A
0005434426306	3491	150	35J
0005434937950	3491	151	36C
0005434877290	3491	152	36B
0005435125972	3491	153	36E
0005432613819	3491	154	36D
0005432799166	3491	155	36G
0005434937939	3491	156	36F
0005432799173	3491	157	36K
0005435125971	3491	158	36H
0005435125970	3491	159	37B
0005434877288	3491	160	37E
0005434877299	3491	161	37D
0005435625985	3491	162	37F
0005432799174	3491	163	37H
0005434426310	3491	164	37G
0005432611670	3491	165	37J
0005434877307	3491	166	38C
0005435125960	3491	167	38H
0005434937934	3491	168	39B
0005434877308	3491	169	39C
0005434877284	3491	170	39F
0005434877287	3491	171	39E
0005434877291	3491	172	39H
0005434877265	3491	173	40A
0005434937944	3491	174	39J
0005435125951	3491	175	40C
0005435125941	3491	176	40E
0005434877289	3491	177	40D
0005435125959	3491	178	40H
0005434877270	3491	179	40K
0005432799181	3491	180	40J
0005434937948	3491	181	41D
0005435125957	3491	182	41J
0005432799183	3491	183	41H
0005434426324	3491	184	42A
0005432799156	3491	185	42E
0005435125946	3491	186	42D
0005434877266	3491	187	42G
0005434937936	3491	188	42F
0005435125967	3491	189	42J
0005434877292	3491	190	42H
0005432799177	3491	191	43A
0005434877328	3491	192	43C
0005434877305	3491	193	43B
0005432183443	3491	194	43F
0005432799160	3491	195	43E
0005434426318	3491	196	43H
0005434877316	3491	197	43G
0005435125950	3491	198	43K
0005435125964	3491	199	43J
0005435625986	3491	200	44B
0005432613820	3491	201	44E
0005432799182	3491	202	44D
0005434937933	3491	203	44C
0005434877280	3491	204	44G
0005434877275	3491	205	44F
0005434877235	3491	206	44K
0005435625991	3491	207	44J
0005435125963	3491	208	44H
0005432799167	3491	209	45B
0005434426305	3491	210	45E
0005434877273	3491	211	45K
0005435125977	3491	212	45J
0005434877268	3491	213	46C
0005432799162	3491	214	46E
0005432613821	3491	215	46D
0005434877261	3491	216	46F
0005434877319	3491	217	46J
0005434877244	3491	218	46H
0005434877313	3491	219	46K
0005435125947	3491	220	47D
0005435125953	3491	221	47C
0005434426296	3491	222	47G
0005435625989	3491	223	47F
0005435125975	3491	224	47E
0005434937951	3491	225	47H
0005434877263	3491	226	48C
0005432799175	3491	227	48A
0005435625995	3491	228	48E
0005434426308	3491	229	48D
0005434877274	3491	230	48H
0005434426317	3491	231	48G
0005432799176	3491	232	49A
0005434877298	3491	233	48K
0005434877241	3491	234	49D
0005434877282	3491	235	49C
0005434877330	3491	236	49F
0005434877322	3491	237	49E
0005434937946	3491	238	49H
0005434877242	3491	239	50C
0005434426325	3491	240	50A
0005435125945	3491	241	49K
0005435125952	3491	242	50F
0005432799155	3491	243	50D
0005432611668	3491	244	50G
0005434426298	3491	245	51D
0005434877252	3491	246	50K
0005434877300	3491	247	51F
0005434426297	3491	248	51E
0005434877247	3491	249	51G
0005435902519	14553	1	2A
0005435902527	14553	2	2H
0005435913898	14553	3	3D
0005434876621	14553	4	3H
0005434876645	14553	5	4G
0005434876620	14553	6	4D
0005434876703	14553	7	4K
0005434937837	14553	8	11G
0005434937810	14553	9	11H
0005435125679	14553	10	12E
0005435902528	14553	11	12D
0005434426108	14553	12	12H
0005434876671	14553	13	12F
0005434937818	14553	14	13G
0005435902521	14553	15	14G
0005434876670	14553	16	15A
0005435902516	14553	17	15F
0005434937809	14553	18	15D
0005435902525	14553	19	15K
0005434426161	14553	20	16G
0005434876674	14553	21	17D
0005435902526	14553	22	17K
0005434876669	14553	23	18C
0005434876572	14553	24	18D
0005434876909	14553	25	18H
0005432798991	14553	26	19A
0005432799043	14553	27	18K
0005435902517	14553	28	20A
0005435914688	14553	29	20H
0005434876760	14553	30	21B
0005434876612	14553	31	21A
0005434937851	14553	32	21C
0005434876563	14553	33	21K
0005432798966	14553	34	22E
0005435913893	14553	35	23E
0005435913899	14553	36	23G
0005435902518	14553	37	24D
0005434876820	14553	38	25B
0005435125672	14553	39	25A
0005432059484	14553	40	26B
0005434876583	14553	41	27J
0005434426100	14553	42	27H
0005434426160	14553	43	28F
0005434876668	14553	44	29A
0005435913894	14553	45	29C
0005434426091	14553	46	29D
0005435913897	14553	47	29J
0005435902529	14553	48	29H
0005434876759	14553	49	30D
0005434937890	14553	50	30J
0005434876825	14553	51	30K
0005434876585	14553	52	31J
0005432798993	14553	53	32E
0005434937830	14553	54	33B
0005435125743	14553	55	33D
0005434876826	14553	56	33F
0005435902515	14553	57	33H
0005434937808	14553	58	34A
0005434876673	14553	59	35D
0005435125685	14553	60	35C
0005435125717	14553	61	36H
0005435902513	14553	62	36G
0005434876752	14553	63	36F
0005435913896	14553	64	36K
0005434937836	14553	65	36J
0005434937891	14553	66	37C
0005434876614	14553	67	37H
0005432611648	14553	68	38A
0005434876616	14553	69	38H
0005432798992	14553	70	39B
0005434876607	14553	71	39E
0005432799000	14553	72	39G
0005434876672	14553	73	40A
0005435902512	14553	74	40J
0005434876675	14553	75	40K
0005434876722	14553	76	41F
0005432798964	14553	77	41E
0005434876819	14553	78	42A
0005434876761	14553	79	41K
0005434426164	14553	80	41J
0005434876615	14553	81	42B
0005435902524	14553	82	42F
0005434937803	14553	83	42H
0005434876688	14553	84	43A
0005435913895	14553	85	43D
0005435902514	14553	86	43J
0005434876564	14553	87	43K
0005435902520	14553	88	44B
0005435902523	14553	89	44C
0005434876646	14553	90	44J
0005435902522	14553	91	45A
0005434876936	14553	92	45D
0005434876817	14553	93	45G
0005434876704	14553	94	45H
0005435125744	14553	95	46A
0005434876656	14553	96	48A
0005435913900	14553	97	48H
0005432799044	14553	98	49D
0005432798970	14553	99	50C
0005435125673	14553	100	50A
0005435125716	14553	101	50E
0005434876667	14553	102	50D
0005432798965	14553	103	51F
0005432799010	14553	104	51E
0005434325530	3643	1	1B
0005434325529	3643	2	2A
0005434325536	3643	3	2C
0005434325526	3643	4	3B
0005435889812	3643	5	3C
0005435889813	3643	6	4A
0005434325532	3643	7	4B
0005434312297	3643	8	6C
0005435889811	3643	9	18D
0005434325527	3643	10	19C
0005434325531	3643	11	19D
0005434325533	3643	12	20A
0005434325528	3643	13	20B
0005434325534	3643	14	21A
0005434325535	3643	15	22A
0005435889792	3643	16	22B
0005434312296	3643	17	22D
0005435889837	15636	1	1C
0005434325450	15636	2	1D
0005434325458	15636	3	2B
0005434325461	15636	4	3A
0005434325449	15636	5	3D
0005434325454	15636	6	4D
0005434325447	15636	7	5C
0005434325457	15636	8	6A
0005434325455	15636	9	6C
0005435889838	15636	10	7A
0005434325451	15636	11	18B
0005435889836	15636	12	18D
0005435889832	15636	13	19B
0005434325448	15636	14	19C
0005435889833	15636	15	20A
0005434325453	15636	16	20C
0005435889834	15636	17	21C
0005435889835	15636	18	23A
0005435957558	630	1	1A
0005435957544	630	2	1B
0005435957552	630	3	1D
0005435957556	630	4	2C
0005435957551	630	5	3D
0005435957549	630	6	4A
0005435957547	630	7	4B
0005435957554	630	8	4D
0005433420273	630	9	5A
0005435957545	630	10	5B
0005433420275	630	11	6A
0005433420274	630	12	6D
0005433420268	630	13	7B
0005433420272	630	14	7C
0005433420249	630	15	7D
0005435957553	630	16	18C
0005435957557	630	17	19C
0005435957548	630	18	20A
0005435957546	630	19	21A
0005435957550	630	20	22C
0005435957555	630	21	22D
0005433420314	15157	1	2A
0005433420311	15157	2	2B
0005433420316	15157	3	4B
0005435957447	15157	4	4D
0005433420312	15157	5	5A
0005433420315	15157	6	7A
0005435957444	15157	7	19A
0005433420310	15157	8	19C
0005433420317	15157	9	20A
0005433420318	15157	10	21A
0005433420313	15157	11	21B
0005435957465	15157	12	22A
0005433420319	15157	13	22C
0005435221035	27265	1	21A
0005435218106	31775	1	1B
0005435217688	31775	2	2A
0005435218105	31775	3	2B
0005435216567	31775	4	2C
0005435217687	31775	5	3A
0005435216568	31775	6	3C
0005435216564	31775	7	4D
0005435217692	31775	8	5B
0005435216566	31775	9	5C
0005435216561	31775	10	6A
0005435217685	31775	11	6B
0005435217693	31775	12	6C
0005435217690	31775	13	6D
0005435216565	31775	14	7A
0005435216569	31775	15	7B
0005435217686	31775	16	18A
0005435217691	31775	17	19A
0005435217694	31775	18	19D
0005435217689	31775	19	20B
0005435218107	31775	20	20C
0005435216563	31775	21	21B
0005435216562	31775	22	22A
0005435218108	31775	23	22C
0005435629392	8836	1	1B
0005435629391	8836	2	4B
0005434247121	16026	1	3A
0005435629383	16026	2	4B
0005434247120	16026	3	5A
0005434247122	16026	4	6A
0005434467739	4008	1	2B
0005434467740	4008	2	3C
0005434467735	4008	3	4C
0005434467732	4008	4	5A
0005434467737	4008	5	5C
0005434467734	4008	6	7B
0005434467736	4008	7	7C
0005434467741	4008	8	19D
0005434467738	4008	9	21A
0005434467733	4008	10	22C
0005434467724	23209	1	6B
0005434467723	23209	2	18A
0005435163169	4433	1	1A
0005435163170	4433	2	1C
0005435163172	4433	3	2A
0005435163175	4433	4	2C
0005435163174	4433	5	2D
0005435163173	4433	6	3A
0005435163166	4433	7	4A
0005435163179	4433	8	4B
0005435163180	4433	9	4C
0005435933403	4433	10	6C
0005435163171	4433	11	7A
0005435933401	4433	12	18D
0005435933402	4433	13	19A
0005435163178	4433	14	20C
0005435163181	4433	15	21B
0005435163167	4433	16	22A
0005435163177	4433	17	22C
0005435163176	4433	18	23A
0005435163168	4433	19	23B
0005435933417	29507	1	1B
0005435163144	29507	2	4A
0005435933414	29507	3	4B
0005435163142	29507	4	6B
0005435933415	29507	5	7A
0005435163143	29507	6	21B
0005435933416	29507	7	22C
0005435933420	29507	8	22D
0005435933418	29507	9	23A
0005435933419	29507	10	23B
0005432645817	6828	1	1A
0005432645865	6828	2	1C
0005432645837	6828	3	1D
0005432645827	6828	4	1F
0005432645815	6828	5	2A
0005432645852	6828	6	3F
0005432645847	6828	7	4D
0005432645821	6828	8	4F
0005432645846	6828	9	5D
0005435229324	6828	10	5E
0005432645836	6828	11	5F
0005432645844	6828	12	6A
0005432645831	6828	13	6D
0005432645824	6828	14	6E
0005432645851	6828	15	7A
0005432645857	6828	16	8C
0005432645826	6828	17	8D
0005432645818	6828	18	8F
0005432645863	6828	19	9A
0005432645856	6828	20	9D
0005432645819	6828	21	10A
0005432645840	6828	22	10D
0005432645820	6828	23	11C
0005432645838	6828	24	11D
0005432645843	6828	25	11E
0005432645823	6828	26	11F
0005432645830	6828	27	12A
0005432645842	6828	28	12D
0005432645864	6828	29	12F
0005432645853	6828	30	13E
0005432645834	6828	31	13F
0005432645814	6828	32	14A
0005432645832	6828	33	15A
0005432645825	6828	34	15C
0005432645862	6828	35	15E
0005432645860	6828	36	15F
0005432645861	6828	37	16A
0005432645835	6828	38	16C
0005432645822	6828	39	16E
0005432645813	6828	40	16D
0005432645841	6828	41	16F
0005432645859	6828	42	17A
0005432645829	6828	43	17E
0005432645848	6828	44	17F
0005432645855	6828	45	18C
0005432645816	6828	46	18D
0005432645854	6828	47	18E
0005432645828	6828	48	19A
0005432645833	6828	49	19C
0005432645850	6828	50	19E
0005432645845	6828	51	19F
0005432645858	6828	52	20C
0005432645849	6828	53	20D
0005432645839	6828	54	20F
0005433404706	2846	1	2F
0005435797332	2846	2	3D
0005435797336	2846	3	4A
0005435797333	2846	4	5A
0005435797330	2846	5	5E
0005435797326	2846	6	7D
0005435797335	2846	7	7F
0005435797329	2846	8	11A
0005435797338	2846	9	11D
0005435797334	2846	10	12F
0005433404707	2846	11	13A
0005435797328	2846	12	13F
0005435797323	2846	13	14A
0005435797331	2846	14	14D
0005435797325	2846	15	15A
0005435797324	2846	16	16D
0005435797327	2846	17	17F
0005435797337	2846	18	20C
0005433404730	29293	1	1A
0005433404732	29293	2	3A
0005433404735	29293	3	5C
0005433404733	29293	4	5D
0005435797246	29293	5	5E
0005435797231	29293	6	7D
0005435797290	29293	7	10C
0005435797232	29293	8	10E
0005435797230	29293	9	11C
0005435797245	29293	10	14A
0005433404736	29293	11	14F
0005433404731	29293	12	15D
0005433404737	29293	13	18A
0005433404729	29293	14	18C
0005435797275	29293	15	19F
0005433404734	29293	16	20D
0005435376316	5795	1	2B
0005435376315	5795	2	4B
0005435376318	5795	3	5B
0005435376317	5795	4	6A
0005434947933	5833	1	1B
0005434947936	5833	2	2A
0005434947938	5833	3	2B
0005434947934	5833	4	3A
0005434947931	5833	5	3B
0005434947935	5833	6	5A
0005434947937	5833	7	5B
0005434947939	5833	8	6A
0005434947932	5833	9	6B
0005434947877	16401	1	1A
0005434947878	16401	2	1B
0005435376329	16401	3	2A
0005435376328	16401	4	2B
0005435376326	16401	5	4A
0005434947876	16401	6	4B
0005435376327	16401	7	5A
0005434947879	16401	8	6A
0005434947873	16401	9	6B
0005433960292	6849	1	1A
0005433960332	6849	2	1C
0005433960333	6849	3	1D
0005433960310	6849	4	1F
0005433960331	6849	5	2C
0005433960283	6849	6	2D
0005433960322	6849	7	2F
0005433960288	6849	8	3A
0005433960304	6849	9	3C
0005433960272	6849	10	3D
0005433960314	6849	11	4C
0005433960285	6849	12	4D
0005433960302	6849	13	4E
0005433960311	6849	14	6C
0005433960318	6849	15	6E
0005433960300	6849	16	6F
0005433960268	6849	17	7C
0005433960287	6849	18	7D
0005433960313	6849	19	7E
0005433960309	6849	20	7F
0005433960294	6849	21	8A
0005433960312	6849	22	8C
0005433960326	6849	23	8D
0005433960290	6849	24	8E
0005433960329	6849	25	9C
0005433960282	6849	26	9D
0005433960296	6849	27	9E
0005433960273	6849	28	9F
0005433960284	6849	29	10C
0005433960297	6849	30	10D
0005433960276	6849	31	10E
0005433960327	6849	32	10F
0005433960277	6849	33	11A
0005433960289	6849	34	11C
0005433960325	6849	35	11D
0005433960279	6849	36	11E
0005433960336	6849	37	11F
0005433960317	6849	38	12C
0005433960307	6849	39	12D
0005433960330	6849	40	12F
0005433960293	6849	41	13A
0005433960291	6849	42	13C
0005433960270	6849	43	13F
0005433960335	6849	44	14A
0005433960316	6849	45	14C
0005433960271	6849	46	14D
0005433960274	6849	47	14E
0005433960323	6849	48	14F
0005433960281	6849	49	15A
0005433960299	6849	50	15C
0005433960320	6849	51	15D
0005433960286	6849	52	15E
0005433960298	6849	53	16C
0005433960306	6849	54	16E
0005433960280	6849	55	16F
0005433960305	6849	56	17A
0005433960328	6849	57	17D
0005433960321	6849	58	17E
0005433960269	6849	59	18C
0005433960308	6849	60	18D
0005433960315	6849	61	18E
0005433960303	6849	62	19A
0005433960275	6849	63	19C
0005433960319	6849	64	19D
0005433960324	6849	65	19E
0005433960334	6849	66	19F
0005433960295	6849	67	20A
0005433960278	6849	68	20D
0005433960301	6849	69	20F
0005435082695	26071	1	2A
0005435082703	26071	2	3A
0005435082700	26071	3	2B
0005435082699	26071	4	4A
0005435082701	26071	5	3B
0005435082696	26071	6	4B
0005435082697	26071	7	5B
0005435082702	26071	8	6A
0005435082698	26071	9	6B
0005434244678	5017	1	1D
0005434244684	5017	2	2F
0005434244686	5017	3	5A
0005434244666	5017	4	5C
0005432166869	5017	5	7D
0005434244674	5017	6	9D
0005434244683	5017	7	10B
0005434244676	5017	8	11E
0005433534463	5017	9	12A
0005433534461	5017	10	12C
0005434244679	5017	11	13D
0005434244681	5017	12	14B
0005434244680	5017	13	14C
0005434244690	5017	14	16C
0005434244665	5017	15	17C
0005432166867	5017	16	18B
0005434244688	5017	17	18F
0005434244687	5017	18	19D
0005434244693	5017	19	20E
0005434244667	5017	20	20D
0005434244668	5017	21	20F
0005434244677	5017	22	21B
0005434244682	5017	23	21F
0005434244670	5017	24	22E
0005434244685	5017	25	23B
0005434244689	5017	26	23C
0005434244673	5017	27	25E
0005434244691	5017	28	26C
0005434244675	5017	29	26E
0005434244671	5017	30	26F
0005434244692	5017	31	27A
0005433534462	5017	32	27D
0005432166870	5017	33	27E
0005434244669	5017	34	29A
0005432166868	5017	35	29F
0005434244672	5017	36	30F
0005433784580	5016	1	1A
0005432666366	5016	2	1C
0005432105090	5016	3	1F
0005433613962	5016	4	1D
0005433784566	5016	5	2A
0005433784567	5016	6	2D
0005433613911	5016	7	2C
0005433784565	5016	8	3A
0005433613922	5016	9	2F
0005432105103	5016	10	3C
0005433613910	5016	11	3F
0005433784555	5016	12	3D
0005433613961	5016	13	4A
0005432667432	5016	14	4C
0005432105073	5016	15	4F
0005433613963	5016	16	4D
0005433613982	5016	17	5A
0005433784581	5016	18	5D
0005433613936	5016	19	5C
0005433613913	5016	20	5F
0005433613926	5016	21	6A
0005433613941	5016	22	6C
0005432105076	5016	23	6F
0005433613966	5016	24	6D
0005432105098	5016	25	7A
0005433613939	5016	26	7C
0005433613947	5016	27	7F
0005432665253	5016	28	7D
0005432105064	5016	29	8A
0005433784576	5016	30	8B
0005433613944	5016	31	8D
0005432667433	5016	32	8C
0005433784559	5016	33	8E
0005432105093	5016	34	8F
0005433613980	5016	35	9B
0005433613954	5016	36	9A
0005433613929	5016	37	9C
0005433613956	5016	38	9E
0005432105054	5016	39	9D
0005432145091	5016	40	10A
0005432105084	5016	41	9F
0005433613959	5016	42	10B
0005433613919	5016	43	10D
0005433613983	5016	44	10C
0005433613965	5016	45	10E
0005433784584	5016	46	10F
0005433784582	5016	47	11B
0005433613952	5016	48	11A
0005433784558	5016	49	11C
0005432105094	5016	50	11E
0005433613974	5016	51	11D
0005433613981	5016	52	12A
0005432666369	5016	53	11F
0005432105066	5016	54	12C
0005433613968	5016	55	12B
0005432105070	5016	56	12D
0005433613979	5016	57	12E
0005433784560	5016	58	12F
0005433613969	5016	59	13A
0005432105100	5016	60	13C
0005433784586	5016	61	13B
0005432105085	5016	62	13D
0005432105087	5016	63	13F
0005432105062	5016	64	13E
0005433784577	5016	65	14A
0005433613977	5016	66	14B
0005433784557	5016	67	14D
0005433613912	5016	68	14C
0005433613973	5016	69	14E
0005432105088	5016	70	14F
0005433784572	5016	71	15B
0005432105102	5016	72	15A
0005432666368	5016	73	15C
0005432105075	5016	74	15D
0005433784571	5016	75	15F
0005433613945	5016	76	15E
0005433613975	5016	77	16A
0005433784578	5016	78	16B
0005433784585	5016	79	16D
0005432105077	5016	80	16C
0005433613931	5016	81	16E
0005432105069	5016	82	16F
0005433784569	5016	83	17B
0005433784570	5016	84	17A
0005433613921	5016	85	17D
0005432105071	5016	86	17E
0005433784575	5016	87	18A
0005432105099	5016	88	17F
0005433613978	5016	89	18C
0005433784583	5016	90	18B
0005432105074	5016	91	18D
0005433784561	5016	92	18E
0005433613934	5016	93	18F
0005432105096	5016	94	19B
0005432105055	5016	95	19D
0005433784568	5016	96	19C
0005433613971	5016	97	20A
0005433613924	5016	98	19E
0005433613930	5016	99	20C
0005432105058	5016	100	20B
0005433613976	5016	101	20D
0005433784574	5016	102	20F
0005432105057	5016	103	20E
0005433613938	5016	104	21B
0005433784554	5016	105	21A
0005433613942	5016	106	21C
0005432105065	5016	107	21D
0005433784563	5016	108	21F
0005433613917	5016	109	21E
0005432105078	5016	110	22A
0005432105059	5016	111	22B
0005432105061	5016	112	22C
0005433613970	5016	113	22E
0005432105068	5016	114	22D
0005432105092	5016	115	22F
0005433613958	5016	116	23B
0005433613984	5016	117	23A
0005433613972	5016	118	23D
0005433784573	5016	119	23C
0005433613925	5016	120	23E
0005433613914	5016	121	24A
0005432105095	5016	122	23F
0005432105079	5016	123	24B
0005433613933	5016	124	24D
0005433613955	5016	125	24C
0005433613943	5016	126	24E
0005432105056	5016	127	24F
0005433784579	5016	128	25B
0005433613950	5016	129	25A
0005433613915	5016	130	25D
0005433613935	5016	131	25C
0005433613967	5016	132	25F
0005433784553	5016	133	25E
0005432105067	5016	134	26A
0005433613951	5016	135	26B
0005432105091	5016	136	26C
0005433784564	5016	137	26E
0005433613920	5016	138	26D
0005432105082	5016	139	26F
0005433613928	5016	140	27A
0005432665252	5016	141	27C
0005432105072	5016	142	27B
0005433784556	5016	143	27D
0005433613940	5016	144	27F
0005432105097	5016	145	27E
0005433784562	5016	146	28A
0005432105080	5016	147	28B
0005433613957	5016	148	28D
0005433613960	5016	149	28C
0005433613937	5016	150	28E
0005432105083	5016	151	29A
0005433613918	5016	152	28F
0005433613946	5016	153	29B
0005433613916	5016	154	29C
0005432105060	5016	155	29D
0005432105063	5016	156	29F
0005432666367	5016	157	29E
0005432105101	5016	158	30A
0005433613949	5016	159	30B
0005433613948	5016	160	30D
0005433613953	5016	161	30C
0005433613932	5016	162	30E
0005432105086	5016	163	30F
0005433613964	5016	164	31A
0005433613927	5016	165	31C
0005433613923	5016	166	31B
0005432105081	5016	167	31E
0005432105089	5016	168	31D
0005432145092	5016	169	31F
0005434264881	5014	1	1A
0005434229138	5014	2	1C
0005434264873	5014	3	1F
0005434264868	5014	4	2A
0005435006630	5014	5	2F
0005435006610	5014	6	3C
0005435006614	5014	7	3F
0005434229132	5014	8	4A
0005434229141	5014	9	4D
0005434229133	5014	10	4C
0005432335828	5014	11	5F
0005434229149	5014	12	6A
0005434264862	5014	13	6C
0005432335827	5014	14	6F
0005435006609	5014	15	6D
0005434229136	5014	16	7A
0005434311185	5014	17	7C
0005434229140	5014	18	7D
0005434264869	5014	19	8B
0005434229143	5014	20	8D
0005434173479	5014	21	8E
0005434264884	5014	22	9A
0005434149611	5014	23	9C
0005434264865	5014	24	9B
0005434229139	5014	25	9D
0005434149608	5014	26	9F
0005434264874	5014	27	9E
0005434264883	5014	28	11A
0005434149609	5014	29	11C
0005434149615	5014	30	11E
0005434173480	5014	31	11D
0005434264866	5014	32	12A
0005434229145	5014	33	12B
0005434229128	5014	34	12C
0005435006662	5014	35	13E
0005432335823	5014	36	13D
0005434264877	5014	37	14A
0005434173478	5014	38	14B
0005434312283	5014	39	14D
0005434264867	5014	40	14F
0005434149614	5014	41	15A
0005435006661	5014	42	15C
0005434264861	5014	43	15E
0005434264885	5014	44	16B
0005435006615	5014	45	16C
0005434149606	5014	46	16E
0005434264864	5014	47	16F
0005434229150	5014	48	17E
0005434311182	5014	49	17D
0005434229142	5014	50	17F
0005434149612	5014	51	18D
0005435006642	5014	52	18F
0005434229130	5014	53	19C
0005434149604	5014	54	19B
0005434312287	5014	55	19E
0005435006619	5014	56	20B
0005434229135	5014	57	20D
0005434264870	5014	58	20E
0005434229131	5014	59	21A
0005434264876	5014	60	21D
0005434229144	5014	61	21E
0005434264886	5014	62	22B
0005432335826	5014	63	22C
0005434264875	5014	64	23B
0005434229129	5014	65	23A
0005434264872	5014	66	23D
0005432335825	5014	67	24D
0005434312288	5014	68	24C
0005434229146	5014	69	24E
0005434149607	5014	70	25B
0005434229137	5014	71	25E
0005434264878	5014	72	25F
0005434264880	5014	73	26B
0005433815300	5014	74	26C
0005435006635	5014	75	27A
0005434229148	5014	76	27D
0005434229147	5014	77	27F
0005434149605	5014	78	28B
0005432335833	5014	79	28C
0005435006719	5014	80	28F
0005434264879	5014	81	29B
0005435006631	5014	82	29A
0005435006643	5014	83	29D
0005434229134	5014	84	29F
0005434149613	5014	85	30B
0005434264871	5014	86	30D
0005434264863	5014	87	30F
0005434149610	5014	88	31A
0005435006620	5014	89	31F
0005434264882	5014	90	31E
0005433784354	8422	1	2D
0005433784297	8422	2	3F
0005435269673	8422	3	5A
0005434244459	8422	4	6F
0005434244464	8422	5	8A
0005434244475	8422	6	8D
0005434244462	8422	7	8F
0005434244492	8422	8	9D
0005434244549	8422	9	10C
0005434244502	8422	10	11E
0005434244495	8422	11	12D
0005434244607	8422	12	14B
0005434244463	8422	13	16B
0005433784298	8422	14	16D
0005434244514	8422	15	18A
0005433784432	8422	16	19B
0005433784356	8422	17	19D
0005434244545	8422	18	19E
0005434244513	8422	19	20E
0005434244525	8422	20	20F
0005434244455	8422	21	22A
0005434244476	8422	22	22F
0005434244512	8422	23	23A
0005434244491	8422	24	25F
0005434244478	8422	25	26D
0005434244544	8422	26	27B
0005433784433	8422	27	27C
0005434244474	8422	28	27E
0005435269674	8422	29	28A
0005433784301	8422	30	28E
0005435269672	8422	31	28F
0005432666351	8422	32	29E
0005434244550	8422	33	30A
0005434244539	8422	34	29F
0005434244583	8422	35	31F
0005433613703	8421	1	4F
0005433613426	8421	2	10B
0005433613418	8421	3	10D
0005433613427	8421	4	11B
0005433613423	8421	5	18D
0005433613477	8421	6	19B
0005433613386	8421	7	23A
0005433613387	8421	8	31D
0005434264694	8420	1	1A
0005433534477	8420	2	1F
0005434228972	8420	3	2C
0005435006780	8420	4	2F
0005432034654	8420	5	3C
0005434264753	8420	6	3D
0005432034674	8420	7	4A
0005435006771	8420	8	3F
0005434264679	8420	9	4C
0005432034668	8420	10	4F
0005433690905	8420	11	4D
0005432335913	8420	12	5A
0005435006775	8420	13	5D
0005435006776	8420	14	5F
0005432034665	8420	15	6A
0005432335912	8420	16	6F
0005434264686	8420	17	6D
0005435006790	8420	18	7D
0005435006788	8420	19	7F
0005432034669	8420	20	8B
0005435006772	8420	21	8D
0005434229007	8420	22	8E
0005435006789	8420	23	8F
0005435006779	8420	24	9B
0005432034664	8420	25	9A
0005432034666	8420	26	9C
0005432335907	8420	27	9E
0005432034675	8420	28	9D
0005435006770	8420	29	9F
0005435006785	8420	30	10A
0005434311199	8420	31	10B
0005432034655	8420	32	10D
0005434264724	8420	33	10E
0005434311197	8420	34	11A
0005433815338	8420	35	10F
0005434173452	8420	36	11C
0005434311198	8420	37	11B
0005433534475	8420	38	11D
0005434264715	8420	39	12A
0005432034649	8420	40	12B
0005435006784	8420	41	12C
0005434264720	8420	42	12E
0005433815336	8420	43	13A
0005432034672	8420	44	12F
0005432034659	8420	45	13D
0005434149541	8420	46	13F
0005432034673	8420	47	14B
0005432034657	8420	48	14A
0005434264768	8420	49	14F
0005435006766	8420	50	15D
0005432047511	8420	51	15E
0005432034652	8420	52	15F
0005435006778	8420	53	16D
0005434173456	8420	54	16C
0005434229008	8420	55	16E
0005433689889	8420	56	16F
0005433689890	8420	57	17B
0005432335918	8420	58	17A
0005432335914	8420	59	17C
0005432034662	8420	60	17E
0005435006774	8420	61	18B
0005435006777	8420	62	18D
0005432335911	8420	63	18E
0005434149559	8420	64	19C
0005435006768	8420	65	19B
0005434311200	8420	66	19D
0005434264767	8420	67	20A
0005432047514	8420	68	20B
0005435006773	8420	69	20E
0005434264678	8420	70	20D
0005432335908	8420	71	21D
0005433690906	8420	72	21C
0005435286564	8420	73	22A
0005432034650	8420	74	22B
0005435006787	8420	75	22D
0005435286563	8420	76	22C
0005434228983	8420	77	22E
0005432034658	8420	78	23A
0005432034663	8420	79	23C
0005434173453	8420	80	23D
0005432034667	8420	81	23E
0005434264693	8420	82	24B
0005434229002	8420	83	24A
0005432335917	8420	84	24D
0005432034653	8420	85	24C
0005432034671	8420	86	24E
0005432034660	8420	87	24F
0005433688789	8420	88	25A
0005432047512	8420	89	25B
0005434149562	8420	90	25D
0005435006782	8420	91	26A
0005433688787	8420	92	26B
0005435006786	8420	93	26C
0005433534476	8420	94	26D
0005435006769	8420	95	27A
0005432047510	8420	96	26F
0005432335909	8420	97	27B
0005432335916	8420	98	27C
0005434229029	8420	99	27D
0005432047513	8420	100	28A
0005432034651	8420	101	27F
0005433815339	8420	102	28B
0005433688788	8420	103	28C
0005435006791	8420	104	28E
0005435006767	8420	105	28D
0005432335910	8420	106	28F
0005432335915	8420	107	29B
0005434264733	8420	108	29A
0005435286565	8420	109	29C
0005434173450	8420	110	29D
0005432034670	8420	111	29E
0005434264723	8420	112	30A
0005435006783	8420	113	29F
0005432034676	8420	114	30B
0005432034661	8420	115	30C
0005432034656	8420	116	30D
0005434229006	8420	117	30F
0005434228978	8420	118	31A
0005433815337	8420	119	31C
0005434264713	8420	120	31D
0005435006781	8420	121	31E
0005434638913	12599	1	1A
0005433202216	12599	2	1D
0005434638882	12599	3	2B
0005434638855	12599	4	2C
0005433202211	12599	5	3A
0005434638851	12599	6	3B
0005434638915	12599	7	3D
0005433202219	12599	8	4B
0005434638881	12599	9	5B
0005433202209	12599	10	5C
0005433202212	12599	11	6B
0005434638859	12599	12	6C
0005433202220	12599	13	7A
0005434638852	12599	14	7C
0005434638861	12599	15	18A
0005433202208	12599	16	18B
0005433202213	12599	17	18C
0005433202214	12599	18	19A
0005433202215	12599	19	19B
0005433202210	12599	20	19C
0005434638914	12599	21	19D
0005433202221	12599	22	20D
0005433202222	12599	23	22A
0005433202218	12599	24	22B
0005433202217	12599	25	22C
0005434638853	12599	26	23B
0005434639033	23369	1	1A
0005434639035	23369	2	1B
0005434639022	23369	3	1D
0005434639041	23369	4	2A
0005434639042	23369	5	2B
0005434639015	23369	6	2C
0005434639020	23369	7	3D
0005434639030	23369	8	4A
0005432290598	23369	9	4B
0005434639017	23369	10	4D
0005434639029	23369	11	5A
0005434639028	23369	12	5B
0005434639021	23369	13	6B
0005434639039	23369	14	6C
0005434639043	23369	15	6D
0005434639013	23369	16	7A
0005434639014	23369	17	7B
0005434639038	23369	18	7D
0005432290599	23369	19	18A
0005434639016	23369	20	18C
0005434639037	23369	21	19A
0005434639027	23369	22	19B
0005434639024	23369	23	19D
0005434639032	23369	24	20A
0005434639018	23369	25	20C
0005434639025	23369	26	21A
0005434639026	23369	27	21B
0005432290600	23369	28	21C
0005434639023	23369	29	21D
0005434639036	23369	30	22B
0005434639034	23369	31	22C
0005434639031	23369	32	22D
0005434639019	23369	33	23A
0005434639040	23369	34	23B
0005432328005	21081	1	1A
0005432327919	21081	2	2D
0005432054275	21081	3	4D
0005432327906	21081	4	5C
0005432328033	21081	5	6A
0005432328034	21081	6	7A
0005432327905	21081	7	7F
0005432382511	21081	8	9A
0005432382520	21081	9	9C
0005432054274	21081	10	9D
0005432382532	21081	11	9F
0005432327930	21081	12	10A
0005432382531	21081	13	10E
0005432327901	21081	14	12E
0005432382541	21081	15	13D
0005432382586	21081	16	15C
0005432382556	21081	17	16E
0005432054273	21081	18	16F
0005432328004	21081	19	17E
0005432328006	21081	20	18D
0005432327902	21081	21	18F
0005432382533	21081	22	19A
0005432382555	21081	23	19F
0005432327931	21081	24	20A
0005432382746	31248	1	1C
0005432382728	31248	2	1D
0005432328193	31248	3	1F
0005432287132	31248	4	2A
0005432382760	31248	5	2C
0005432328210	31248	6	2D
0005432328197	31248	7	3A
0005432328206	31248	8	2F
0005432328188	31248	9	3C
0005432328174	31248	10	3D
0005432328184	31248	11	3F
0005432382747	31248	12	4A
0005432328199	31248	13	4C
0005432328198	31248	14	4D
0005432328192	31248	15	4E
0005432328216	31248	16	4F
0005432382736	31248	17	5A
0005432328203	31248	18	5C
0005432382729	31248	19	5F
0005432382763	31248	20	6A
0005432328194	31248	21	6C
0005432328179	31248	22	6D
0005432382734	31248	23	6E
0005432328195	31248	24	6F
0005432328208	31248	25	7A
0005432382740	31248	26	7C
0005432382738	31248	27	7D
0005432328181	31248	28	7E
0005432328190	31248	29	7F
0005432382727	31248	30	8A
0005432382756	31248	31	8C
0005432328201	31248	32	8D
0005432382753	31248	33	8E
0005432328183	31248	34	8F
0005432382743	31248	35	9A
0005432382765	31248	36	9C
0005432328217	31248	37	9D
0005432382732	31248	38	9E
0005432382750	31248	39	9F
0005432382737	31248	40	10A
0005432382730	31248	41	10C
0005432328176	31248	42	10D
0005432382742	31248	43	10E
0005432328196	31248	44	10F
0005432382762	31248	45	11A
0005432382751	31248	46	11C
0005432328182	31248	47	11D
0005432382758	31248	48	11E
0005432382755	31248	49	11F
0005432328200	31248	50	12A
0005432382731	31248	51	12C
0005432328178	31248	52	12D
0005432382764	31248	53	12E
0005432382741	31248	54	13A
0005432287135	31248	55	13C
0005432382745	31248	56	13D
0005432328187	31248	57	13E
0005432382754	31248	58	13F
0005432328173	31248	59	14A
0005432328180	31248	60	14C
0005432328185	31248	61	14D
0005432328218	31248	62	14E
0005432382744	31248	63	14F
0005432328214	31248	64	15A
0005432382752	31248	65	15C
0005432328175	31248	66	15D
0005432382739	31248	67	15E
0005432328189	31248	68	15F
0005432328202	31248	69	16C
0005432328213	31248	70	16D
0005432382759	31248	71	16E
0005432328212	31248	72	16F
0005432328191	31248	73	17A
0005432328186	31248	74	17C
0005432382757	31248	75	17D
0005432382766	31248	76	17E
0005432382761	31248	77	17F
0005432382735	31248	78	18A
0005432328215	31248	79	18D
0005432328211	31248	80	18F
0005432382733	31248	81	18E
0005432287134	31248	82	19A
0005432382748	31248	83	19C
0005432382749	31248	84	19D
0005432328204	31248	85	19F
0005432287133	31248	86	20A
0005432328209	31248	87	20C
0005432328177	31248	88	20D
0005432328207	31248	89	20E
0005432328205	31248	90	20F
0005433642173	2478	1	1D
0005433642191	2478	2	1F
0005433642161	2478	3	2D
0005433642183	2478	4	2F
0005433642153	2478	5	3A
0005433642172	2478	6	3D
0005433642179	2478	7	4C
0005433642155	2478	8	4D
0005433642182	2478	9	4E
0005433642175	2478	10	4F
0005433642192	2478	11	5A
0005433642194	2478	12	5C
0005433642151	2478	13	5E
0005433642164	2478	14	6C
0005433642189	2478	15	6D
0005433642187	2478	16	6F
0005433642168	2478	17	7E
0005433642185	2478	18	7F
0005433642156	2478	19	8D
0005433642170	2478	20	9C
0005433642162	2478	21	9D
0005433642169	2478	22	10C
0005433642184	2478	23	10E
0005433642186	2478	24	11D
0005433642158	2478	25	11E
0005433642174	2478	26	12C
0005433642163	2478	27	12F
0005433642159	2478	28	13C
0005432953785	2478	29	13D
0005433642176	2478	30	13F
0005433642180	2478	31	14C
0005433642171	2478	32	14F
0005433642165	2478	33	15F
0005433642181	2478	34	16A
0005433642150	2478	35	16C
0005433642160	2478	36	17A
0005433642154	2478	37	17C
0005433642166	2478	38	17D
0005433642193	2478	39	17F
0005433642195	2478	40	18A
0005433642178	2478	41	18C
0005433642188	2478	42	18D
0005433642167	2478	43	18E
0005433642177	2478	44	18F
0005433642190	2478	45	19C
0005433642157	2478	46	19E
0005433642152	2478	47	20F
0005432423947	13353	1	1D
0005432423939	13353	2	2A
0005432423925	13353	3	2C
0005432423931	13353	4	3C
0005432423936	13353	5	4C
0005432423948	13353	6	4D
0005432423914	13353	7	4F
0005432423952	13353	8	5C
0005432423910	13353	9	5D
0005432423927	13353	10	5E
0005432423923	13353	11	6A
0005432423934	13353	12	6E
0005432423911	13353	13	6F
0005432423928	13353	14	7A
0005432423929	13353	15	7C
0005432423912	13353	16	7F
0005432423945	13353	17	8C
0005432423953	13353	18	8D
0005432423913	13353	19	9A
0005432423954	13353	20	9C
0005432423920	13353	21	9D
0005432423951	13353	22	9E
0005432423935	13353	23	10D
0005432423933	13353	24	11D
0005432423926	13353	25	12E
0005432423916	13353	26	12F
0005432423941	13353	27	13D
0005432423940	13353	28	13E
0005432423930	13353	29	14A
0005432423949	13353	30	14C
0005432423924	13353	31	14E
0005432423942	13353	32	15C
0005432423921	13353	33	15E
0005432423955	13353	34	15F
0005432423922	13353	35	16D
0005432423946	13353	36	16E
0005432423918	13353	37	17C
0005432423932	13353	38	17E
0005432423950	13353	39	18A
0005432423937	13353	40	18C
0005432423917	13353	41	18E
0005432423919	13353	42	19E
0005432423943	13353	43	19F
0005432423944	13353	44	20D
0005432423938	13353	45	20E
0005432423915	13353	46	20F
0005432817169	9626	1	1A
0005432901324	9626	2	1C
0005432817164	9626	3	1F
0005432288952	9626	4	2A
0005434448278	9626	5	2C
0005432901327	9626	6	2F
0005432822123	9626	7	3C
0005432817150	9626	8	3D
0005432822125	9626	9	4C
0005432822119	9626	10	4D
0005432817166	9626	11	4E
0005432817170	9626	12	5C
0005434157344	9626	13	5D
0005432901294	9626	14	5F
0005432817154	9626	15	6C
0005432817158	9626	16	6F
0005432822120	9626	17	7A
0005432901339	9626	18	7C
0005432817155	9626	19	7D
0005432817172	9626	20	7E
0005434186150	9626	21	7F
0005434186152	9626	22	8A
0005432817178	9626	23	8D
0005432817160	9626	24	9C
0005434186151	9626	25	9D
0005432901320	9626	26	9F
0005432822126	9626	27	10D
0005432817176	9626	28	10F
0005434157351	9626	29	11C
0005432817157	9626	30	11D
0005432817168	9626	31	11F
0005434448279	9626	32	11E
0005432817179	9626	33	12A
0005432901310	9626	34	12C
0005432817173	9626	35	12E
0005432817162	9626	36	13A
0005432288953	9626	37	13C
0005434157345	9626	38	13D
0005432817159	9626	39	13F
0005432817153	9626	40	14A
0005432817161	9626	41	14C
0005432822121	9626	42	14E
0005432817174	9626	43	14F
0005432817171	9626	44	15A
0005434448281	9626	45	15C
0005432817177	9626	46	15D
0005432817165	9626	47	15E
0005432822122	9626	48	15F
0005432901307	9626	49	16C
0005432817163	9626	50	16E
0005432901299	9626	51	17C
0005432901321	9626	52	17E
0005432817175	9626	53	17F
0005432901311	9626	54	18A
0005432822124	9626	55	18D
0005432817167	9626	56	18E
0005434448280	9626	57	18F
0005432817151	9626	58	19A
0005432901340	9626	59	19C
0005432817152	9626	60	19D
0005432288951	9626	61	19E
0005432817156	9626	62	20F
0005434157395	28982	1	1C
0005432901421	28982	2	1F
0005432002055	28982	3	2C
0005432901432	28982	4	2D
0005432901419	28982	5	2F
0005434448253	28982	6	4A
0005432901434	28982	7	4F
0005432816964	28982	8	5A
0005434157396	28982	9	5C
0005432901420	28982	10	5E
0005432901425	28982	11	5F
0005434186165	28982	12	6C
0005432901423	28982	13	7E
0005432817042	28982	14	8C
0005432816944	28982	15	8E
0005432901427	28982	16	9E
0005432901430	28982	17	10A
0005432816943	28982	18	10E
0005434157401	28982	19	11D
0005434157399	28982	20	11E
0005434157402	28982	21	11F
0005432901426	28982	22	12F
0005432817067	28982	23	13A
0005432817000	28982	24	13E
0005432816952	28982	25	13F
0005432816953	28982	26	14A
0005434186166	28982	27	14C
0005432817061	28982	28	14D
0005432901422	28982	29	14E
0005432816954	28982	30	14F
0005434157398	28982	31	15D
0005432901436	28982	32	15E
0005432901433	28982	33	15F
0005432901424	28982	34	16C
0005434157403	28982	35	16F
0005434157397	28982	36	17A
0005434186167	28982	37	17D
0005432816955	28982	38	17E
0005432901429	28982	39	18C
0005432901435	28982	40	18D
0005432817041	28982	41	18E
0005434157400	28982	42	19C
0005432901428	28982	43	19E
0005432901431	28982	44	20D
0005432611670	15071	1	1A
0005432613821	15071	2	2B
0005432611671	15071	3	3A
0005432613819	15071	4	3B
0005432613820	15071	5	4B
0005432611669	15071	6	5B
0005432611668	15071	7	5A
0005432611648	31544	1	4B
0005433568402	11855	1	1F
0005433568390	11855	2	1D
0005433568417	11855	3	2D
0005433568400	11855	4	3A
0005433568412	11855	5	2F
0005433568420	11855	6	3F
0005433568403	11855	7	4D
0005433568385	11855	8	4C
0005433568394	11855	9	5A
0005433568382	11855	10	5D
0005432947798	11855	11	6A
0005433568398	11855	12	5F
0005433568378	11855	13	6C
0005433568397	11855	14	6F
0005433568381	11855	15	6E
0005433568406	11855	16	7A
0005433568389	11855	17	7B
0005433568386	11855	18	8B
0005433568408	11855	19	9A
0005433568409	11855	20	9C
0005433568395	11855	21	9B
0005433568405	11855	22	10C
0005433568392	11855	23	10F
0005433568401	11855	24	11B
0005433568377	11855	25	11D
0005433568419	11855	26	11E
0005433568404	11855	27	12B
0005433568414	11855	28	12A
0005433568383	11855	29	12C
0005432947773	11855	30	12E
0005433568415	11855	31	12F
0005433568413	11855	32	13C
0005433568399	11855	33	14A
0005433568380	11855	34	13F
0005432947826	11855	35	14B
0005432947774	11855	36	14D
0005433568396	11855	37	14E
0005433568416	11855	38	15A
0005433568418	11855	39	15D
0005433568421	11855	40	15C
0005433568379	11855	41	15E
0005433568391	11855	42	16A
0005433568411	11855	43	16B
0005433568407	11855	44	16E
0005433568387	11855	45	17B
0005433568422	11855	46	17E
0005433568376	11855	47	18B
0005433568410	11855	48	18D
0005432947812	11855	49	19F
0005433568388	11855	50	19E
0005433568375	11855	51	20D
0005433568374	11855	52	20E
0005433568384	11855	53	21B
0005432947830	11855	54	21A
0005433568393	11855	55	21C
0005432948060	25272	1	1A
0005432948079	25272	2	1F
0005433568054	25272	3	3D
0005432948084	25272	4	4A
0005432948071	25272	5	4C
0005432948058	25272	6	5A
0005432948059	25272	7	5F
0005432948085	25272	8	6C
0005432948083	25272	9	6E
0005432948089	25272	10	7B
0005432948066	25272	11	7A
0005432948064	25272	12	7C
0005432948076	25272	13	7F
0005432948095	25272	14	8B
0005432948086	25272	15	8D
0005432948055	25272	16	8F
0005432948072	25272	17	9B
0005432948096	25272	18	9A
0005432948082	25272	19	9D
0005432948074	25272	20	10B
0005432948080	25272	21	10C
0005432948092	25272	22	10E
0005432948070	25272	23	10D
0005432948090	25272	24	11A
0005432948075	25272	25	11D
0005432948056	25272	26	12B
0005432948061	25272	27	12A
0005432948063	25272	28	13A
0005432948091	25272	29	14A
0005432948065	25272	30	14B
0005432948062	25272	31	14E
0005432948081	25272	32	14C
0005432948067	25272	33	14F
0005432948073	25272	34	15B
0005432948068	25272	35	15D
0005432948078	25272	36	15F
0005432948057	25272	37	16A
0005432948077	25272	38	16C
0005433568051	25272	39	16F
0005432948093	25272	40	17D
0005432948088	25272	41	17E
0005432948069	25272	42	18A
0005432948087	25272	43	18E
0005433568037	25272	44	20D
0005432948094	25272	45	21A
0005433568055	25272	46	21D
0005433808305	14466	1	3A
0005432430829	14466	2	4A
0005432430819	14466	3	3F
0005434026682	14466	4	4C
0005432430824	14466	5	5C
0005434026685	14466	6	7B
0005434026684	14466	7	7D
0005432430821	14466	8	11A
0005433808304	14466	9	13D
0005432430820	14466	10	14A
0005433812861	14466	11	14D
0005434026686	14466	12	14F
0005432430822	14466	13	15C
0005432430826	14466	14	15F
0005434026681	14466	15	16E
0005432430828	14466	16	16D
0005432430827	14466	17	18C
0005432430823	14466	18	18B
0005432430825	14466	19	18D
0005434026683	14466	20	21C
0005433812870	30828	1	1A
0005433808331	30828	2	1F
0005433808330	30828	3	2F
0005433808328	30828	4	2D
0005433808325	30828	5	3D
0005433808335	30828	6	4A
0005433812864	30828	7	4D
0005433808324	30828	8	6B
0005433812872	30828	9	6C
0005433808326	30828	10	6D
0005433812871	30828	11	7A
0005433812866	30828	12	7B
0005433812868	30828	13	10A
0005433808327	30828	14	10B
0005433808321	30828	15	10E
0005433812873	30828	16	10D
0005433808334	30828	17	13C
0005433808322	30828	18	14E
0005433808333	30828	19	16C
0005433808332	30828	20	17C
0005433812867	30828	21	17F
0005433812865	30828	22	18C
0005433808323	30828	23	19F
0005433808320	30828	24	20D
0005433812869	30828	25	21D
0005433808329	30828	26	21C
0005434654388	5393	1	1C
0005434654390	5393	2	2A
0005435340028	5393	3	1F
0005432114168	5393	4	2F
0005434654386	5393	5	3F
0005435340023	5393	6	4A
0005434654396	5393	7	4D
0005434656534	5393	8	5F
0005434654374	5393	9	6A
0005434654376	5393	10	7A
0005434654370	5393	11	7C
0005434654385	5393	12	8A
0005432114169	5393	13	8C
0005434654375	5393	14	8E
0005434654377	5393	15	8F
0005434654382	5393	16	10D
0005434654389	5393	17	10E
0005434654398	5393	18	11C
0005434654397	5393	19	12E
0005434654393	5393	20	12F
0005435339993	5393	21	13A
0005432114170	5393	22	13C
0005434654391	5393	23	14A
0005434654384	5393	24	14C
0005434654379	5393	25	14E
0005434654378	5393	26	14F
0005434654383	5393	27	15A
0005434654387	5393	28	15E
0005435339999	5393	29	15F
0005434656537	5393	30	16D
0005434654369	5393	31	16F
0005435339998	5393	32	17C
0005434654373	5393	33	17D
0005434656535	5393	34	17E
0005434654395	5393	35	18C
0005434654394	5393	36	18D
0005434654392	5393	37	18E
0005434654372	5393	38	18F
0005434654371	5393	39	19A
0005434654380	5393	40	19C
0005434654381	5393	41	19D
0005434656536	5393	42	20A
0005435339994	5393	43	20E
0005434654226	12528	1	1D
0005434656521	12528	2	2D
0005434654175	12528	3	3A
0005435340099	12528	4	3C
0005435340112	12528	5	3D
0005435340100	12528	6	4D
0005434654194	12528	7	4F
0005435340111	12528	8	6A
0005435340101	12528	9	6D
0005435340108	12528	10	6E
0005434654202	12528	11	6F
0005435555348	12528	12	7A
0005434654185	12528	13	7C
0005435340106	12528	14	7D
0005435340097	12528	15	7F
0005434654161	12528	16	8A
0005435340102	12528	17	8C
0005434656520	12528	18	8D
0005435340109	12528	19	8F
0005434654208	12528	20	11C
0005435340098	12528	21	11D
0005435340107	12528	22	13E
0005434654267	12528	23	15D
0005434654160	12528	24	17A
0005435555349	12528	25	18D
0005434654176	12528	26	19C
0005435340103	12528	27	19D
0005435555350	12528	28	19E
0005435340110	12528	29	19F
0005435340104	12528	30	20C
0005435340105	12528	31	20E
0005433715468	7436	1	1A
0005433715474	7436	2	1F
0005433715429	7436	3	1D
0005433722153	7436	4	2C
0005433715453	7436	5	2A
0005433715448	7436	6	2F
0005433715431	7436	7	3A
0005433722149	7436	8	3D
0005433715466	7436	9	3C
0005433715472	7436	10	4B
0005433722142	7436	11	4E
0005433715458	7436	12	5C
0005433715442	7436	13	5D
0005432078051	7436	14	5E
0005433719104	7436	15	5F
0005433715471	7436	16	6D
0005433715428	7436	17	6E
0005433715433	7436	18	6F
0005433715435	7436	19	7B
0005432078049	7436	20	7C
0005433715457	7436	21	7D
0005433715449	7436	22	7E
0005433715470	7436	23	8A
0005433688786	7436	24	8B
0005433715464	7436	25	8C
0005433715446	7436	26	8F
0005433715462	7436	27	9B
0005433715461	7436	28	9D
0005433656634	7436	29	9E
0005433719101	7436	30	9F
0005433715438	7436	31	10D
0005433722150	7436	32	11B
0005433715424	7436	33	11C
0005433715459	7436	34	11E
0005433715437	7436	35	11F
0005433689887	7436	36	12C
0005433722154	7436	37	12D
0005433715445	7436	38	12E
0005433715427	7436	39	13B
0005433722152	7436	40	13A
0005433715447	7436	41	13C
0005433715456	7436	42	13D
0005433715467	7436	43	13F
0005432078048	7436	44	14C
0005433715439	7436	45	14B
0005433715451	7436	46	14D
0005433715434	7436	47	14E
0005433715452	7436	48	15A
0005433715455	7436	49	15C
0005433722148	7436	50	15D
0005433715460	7436	51	15F
0005433715450	7436	52	15E
0005433715473	7436	53	16B
0005433722144	7436	54	16A
0005433715469	7436	55	16C
0005433715430	7436	56	16E
0005433715425	7436	57	16F
0005433722141	7436	58	17A
0005433715440	7436	59	17B
0005433722147	7436	60	17D
0005433689888	7436	61	18B
0005432078050	7436	62	18C
0005433719103	7436	63	18F
0005433722146	7436	64	19A
0005433690904	7436	65	19D
0005433715465	7436	66	19C
0005433715444	7436	67	19E
0005433688785	7436	68	19F
0005433715454	7436	69	20A
0005433690903	7436	70	20D
0005433722143	7436	71	20C
0005433656633	7436	72	20E
0005433715436	7436	73	20F
0005433715463	7436	74	21C
0005432078052	7436	75	22A
0005433722145	7436	76	21F
0005433715432	7436	77	22B
0005433715426	7436	78	22D
0005433715443	7436	79	22F
0005433719102	7436	80	23A
0005432078053	7436	81	23D
0005433715441	7436	82	23F
0005433722151	7436	83	23E
0005433715211	29232	1	1A
0005433715219	29232	2	1C
0005433715078	29232	3	3C
0005433715107	29232	4	3A
0005433719087	29232	5	3D
0005432006730	29232	6	4A
0005435266109	29232	7	4E
0005433715097	29232	8	5A
0005435266103	29232	9	4F
0005433715156	29232	10	5D
0005433715130	29232	11	5E
0005435266108	29232	12	5F
0005433715068	29232	13	6A
0005432006731	29232	14	6B
0005433715139	29232	15	6F
0005433715106	29232	16	7F
0005432428892	29232	17	8A
0005435266107	29232	18	9C
0005432428893	29232	19	9E
0005433715212	29232	20	10B
0005433715213	29232	21	11F
0005432428894	29232	22	12F
0005433715138	29232	23	13C
0005435266105	29232	24	14A
0005433715142	29232	25	14B
0005433715235	29232	26	14E
0005433656619	29232	27	17A
0005435266106	29232	28	16F
0005433719086	29232	29	18D
0005433715080	29232	30	19B
0005433715131	29232	31	19E
0005433715099	29232	32	19D
0005433715214	29232	33	20C
0005433715128	29232	34	20F
0005432006729	29232	35	21C
0005433715218	29232	36	21D
0005435266104	29232	37	23D
0005434095119	8709	1	1C
0005434184633	8709	2	1D
0005434181990	8709	3	3A
0005434095120	8709	4	2F
0005434181974	8709	5	4C
0005434181994	8709	6	5D
0005434095126	8709	7	6F
0005434181978	8709	8	9A
0005434095128	8709	9	9C
0005434181988	8709	10	10D
0005434095125	8709	11	10F
0005434095121	8709	12	11D
0005434095124	8709	13	11E
0005434095127	8709	14	12A
0005434095132	8709	15	13A
0005434095130	8709	16	15F
0005434095131	8709	17	16A
0005434181989	8709	18	16C
0005434095122	8709	19	16F
0005434095129	8709	20	17D
0005434095123	8709	21	17F
0005434181991	8709	22	18C
0005434181984	8709	23	18D
0005434184641	11625	1	1D
0005434182059	11625	2	1F
0005434095025	11625	3	2A
0005434182055	11625	4	3C
0005434182056	11625	5	4D
0005434182057	11625	6	5C
0005434182054	11625	7	5E
0005434182048	11625	8	6C
0005434184642	11625	9	10E
0005434095024	11625	10	13A
0005434095050	11625	11	13C
0005434182058	11625	12	13D
0005434182053	11625	13	13E
0005434095028	11625	14	14F
0005434095051	11625	15	15A
0005434182047	11625	16	15D
0005434182049	11625	17	15F
0005434183556	11625	18	16E
0005434183557	11625	19	17D
0005434095048	11625	20	19A
0005434182052	11625	21	19E
0005434182051	11625	22	20A
0005434095043	11625	23	20C
0005434182050	11625	24	20E
0005433397191	1420	1	1F
0005435732205	1420	2	2C
0005435732209	1420	3	2F
0005435732213	1420	4	3C
0005435732199	1420	5	5E
0005435732212	1420	6	6E
0005433397209	1420	7	6F
0005433397201	1420	8	7C
0005435732211	1420	9	7D
0005435732210	1420	10	7F
0005435732198	1420	11	8D
0005433397190	1420	12	9F
0005435732206	1420	13	10C
0005435732207	1420	14	10D
0005432906492	1420	15	10E
0005433397323	1420	16	11C
0005435732204	1420	17	11E
0005433456927	1420	18	11F
0005433397194	1420	19	12C
0005433397183	1420	20	12D
0005435732208	1420	21	12F
0005432297251	1420	22	13E
0005435732203	1420	23	14D
0005432906491	1420	24	14E
0005435732200	1420	25	15A
0005435732197	1420	26	15C
0005433456928	1420	27	15E
0005433456926	1420	28	16A
0005433397229	1420	29	17A
0005435732202	1420	30	17E
0005433397258	1420	31	18E
0005435732201	1420	32	18F
0005435732194	1420	33	19A
0005435732196	1420	34	19D
0005435732195	1420	35	20A
0005433397202	1420	36	20D
0005433397555	19278	1	1C
0005433397541	19278	2	1D
0005435732123	19278	3	1F
0005435732149	19278	4	2A
0005435732124	19278	5	2D
0005433397554	19278	6	3C
0005433397546	19278	7	3D
0005433397552	19278	8	3F
0005433397542	19278	9	4C
0005433397563	19278	10	4E
0005432906509	19278	11	5C
0005435732118	19278	12	5E
0005435732128	19278	13	5F
0005435732112	19278	14	6A
0005433397537	19278	15	6E
0005433397540	19278	16	6F
0005433397550	19278	17	7A
0005433397569	19278	18	7C
0005433397553	19278	19	7D
0005433397573	19278	20	7E
0005433397571	19278	21	8A
0005433397561	19278	22	8C
0005433397556	19278	23	8E
0005433397530	19278	24	8F
0005433397538	19278	25	9A
0005435732148	19278	26	9C
0005433456906	19278	27	9D
0005433397567	19278	28	9E
0005433397535	19278	29	9F
0005433397527	19278	30	10A
0005433397565	19278	31	10E
0005433397576	19278	32	10F
0005433397560	19278	33	11A
0005433397551	19278	34	11C
0005433397539	19278	35	11D
0005433397572	19278	36	12A
0005433397547	19278	37	12C
0005433397526	19278	38	12D
0005433397574	19278	39	12E
0005433397528	19278	40	13A
0005435732127	19278	41	13E
0005433397559	19278	42	14D
0005433397531	19278	43	14E
0005433397548	19278	44	15C
0005435732117	19278	45	15D
0005433397562	19278	46	15F
0005432906510	19278	47	16A
0005433397536	19278	48	16D
0005433397570	19278	49	17A
0005435732116	19278	50	17C
0005433397534	19278	51	17D
0005433397544	19278	52	17E
0005433397532	19278	53	18A
0005433397543	19278	54	18C
0005433397549	19278	55	18D
0005433397564	19278	56	18E
0005433397566	19278	57	19C
0005433397568	19278	58	19D
0005433397557	19278	59	19E
0005433397533	19278	60	19F
0005433397545	19278	61	20A
0005433397529	19278	62	20C
0005433397558	19278	63	20D
0005433397575	19278	64	20F
0005434443447	17391	1	2B
0005434443538	20573	1	1A
0005434443531	20573	2	1D
0005434443529	20573	3	2D
0005434443530	20573	4	3A
0005434443532	20573	5	3C
0005434443525	20573	6	4C
0005434443533	20573	7	5A
0005434443527	20573	8	5D
0005434443536	20573	9	6D
0005434443534	20573	10	7D
0005434443528	20573	11	19B
0005434443523	20573	12	19C
0005434443535	20573	13	20A
0005434443522	20573	14	21B
0005434443537	20573	15	21D
0005434443526	20573	16	22A
0005434443524	20573	17	22B
0005434954566	7233	1	2B
0005434954568	7233	2	3A
0005434954570	7233	3	4A
0005434954567	7233	4	3B
0005434954569	7233	5	6B
0005434954547	28301	1	1A
0005434954548	28301	2	2A
0005434954540	28301	3	3B
0005435377555	28301	4	4B
0005435377554	28301	5	5A
0005435377553	28301	6	6B
0005435893506	4470	1	2A
0005434351564	4470	2	2B
0005434351566	4470	3	2D
0005434183543	4470	4	3C
0005434351557	4470	5	4A
0005435893505	4470	6	4D
0005434351562	4470	7	5C
0005435893507	4470	8	5D
0005434351560	4470	9	6B
0005434351559	4470	10	7A
0005435893520	4470	11	7B
0005434351567	4470	12	18A
0005434351563	4470	13	18C
0005434351558	4470	14	19A
0005434351561	4470	15	19B
0005434351565	4470	16	20D
0005434351556	4470	17	23A
0005435893555	29669	1	2A
0005434351465	29669	2	3A
0005434351506	29669	3	4A
0005435893560	29669	4	5B
0005434351468	29669	5	7C
0005435893558	29669	6	19C
0005434351475	29669	7	20A
0005434351482	29669	8	20D
0005435893554	29669	9	21C
0005435893557	29669	10	22C
0005435893559	29669	11	23A
0005435893556	29669	12	23B
0005433341387	1047	1	1C
0005432293181	1047	2	1B
0005432293182	1047	3	2C
0005433462724	1047	4	2F
0005433341574	1047	5	3A
0005433462723	1047	6	3B
0005433341538	1047	7	3G
0005435091968	1047	8	4A
0005433463877	1047	9	4C
0005435091965	1047	10	5B
0005434446495	1047	11	9G
0005433341408	1047	12	11E
0005433269633	1047	13	11F
0005433341502	1047	14	11G
0005434446497	1047	15	12A
0005433341501	1047	16	12H
0005433463878	1047	17	13D
0005435091969	1047	18	14G
0005433341384	1047	19	16G
0005435545644	1047	20	17D
0005435091967	1047	21	17B
0005433341409	1047	22	18A
0005435545647	1047	23	18D
0005433269626	1047	24	19A
0005433341475	1047	25	19B
0005435545649	1047	26	19H
0005435545645	1047	27	19G
0005433269631	1047	28	20E
0005433341474	1047	29	20H
0005433341442	1047	30	21B
0005433269622	1047	31	21F
0005435545648	1047	32	22E
0005433341396	1047	33	23G
0005435091966	1047	34	24A
0005435091971	1047	35	24G
0005433341431	1047	36	27A
0005435091973	1047	37	27E
0005433269621	1047	38	28B
0005434445223	1047	39	28G
0005435545643	1047	40	29E
0005435091970	1047	41	31E
0005435545646	1047	42	31H
0005433341568	1047	43	32A
0005433269619	1047	44	32F
0005432293184	1047	45	33A
0005433341386	1047	46	34F
0005432293183	1047	47	34E
0005435091972	1047	48	35F
0005433341410	1047	49	37H
0005433269634	1047	50	38D
0005433341560	1047	51	38B
0005434446496	1047	52	38F
0005433341567	1047	53	39D
0005433342015	17019	1	1A
0005433342016	17019	2	1B
0005433342064	17019	3	1F
0005435091924	17019	4	2A
0005433342084	17019	5	2C
0005433342056	17019	6	2G
0005433342077	17019	7	3A
0005433342018	17019	8	3C
0005433269661	17019	9	3B
0005435091927	17019	10	3F
0005433341990	17019	11	4A
0005433342029	17019	12	4B
0005433342001	17019	13	4C
0005433342088	17019	14	4G
0005433342026	17019	15	4F
0005433341995	17019	16	5C
0005433342012	17019	17	9A
0005433342047	17019	18	5H
0005433342058	17019	19	9B
0005433269663	17019	20	9G
0005433342024	17019	21	11D
0005433342053	17019	22	11F
0005433342030	17019	23	11G
0005433342081	17019	24	12A
0005433342022	17019	25	12D
0005433342075	17019	26	12B
0005433342051	17019	27	12G
0005433159289	17019	28	12H
0005433342055	17019	29	13A
0005433342062	17019	30	13E
0005433342066	17019	31	13H
0005433342010	17019	32	14B
0005433342072	17019	33	14A
0005433341994	17019	34	14G
0005433342013	17019	35	15B
0005433342060	17019	36	15D
0005433342011	17019	37	16A
0005433341996	17019	38	16D
0005433342008	17019	39	16B
0005433342043	17019	40	16F
0005433342038	17019	41	16E
0005433341989	17019	42	16G
0005433342042	17019	43	16H
0005433342005	17019	44	17F
0005433342074	17019	45	17G
0005433341992	17019	46	17H
0005433342033	17019	47	18E
0005433342063	17019	48	19A
0005433341993	17019	49	19E
0005433342050	17019	50	19D
0005433342020	17019	51	19F
0005433342039	17019	52	20A
0005433342027	17019	53	19H
0005435091917	17019	54	20D
0005433342025	17019	55	21A
0005433342028	17019	56	21E
0005433341999	17019	57	21F
0005435091914	17019	58	21H
0005433342037	17019	59	22A
0005435091920	17019	60	22B
0005433342086	17019	61	22H
0005433342006	17019	62	22G
0005433342023	17019	63	23B
0005433342041	17019	64	23D
0005433342068	17019	65	23F
0005433342031	17019	66	23G
0005433342009	17019	67	24A
0005433342036	17019	68	23H
0005433342054	17019	69	24B
0005433342082	17019	70	24F
0005433342052	17019	71	24H
0005433342067	17019	72	25E
0005433342071	17019	73	27B
0005433342048	17019	74	27G
0005433342040	17019	75	28A
0005433342002	17019	76	28B
0005433342000	17019	77	28G
0005433342044	17019	78	29A
0005433342049	17019	79	28H
0005433342032	17019	80	29D
0005433342070	17019	81	29B
0005433342076	17019	82	29E
0005433342019	17019	83	29G
0005433342014	17019	84	30A
0005435091915	17019	85	31A
0005433342065	17019	86	30H
0005433342078	17019	87	31B
0005433342061	17019	88	31E
0005433342004	17019	89	31G
0005433342057	17019	90	31H
0005433342079	17019	91	32B
0005433341998	17019	92	32F
0005434445210	17019	93	32G
0005433342046	17019	94	33A
0005433341991	17019	95	32H
0005433342007	17019	96	33B
0005433341988	17019	97	33E
0005433342059	17019	98	33D
0005433342021	17019	99	33F
0005433342034	17019	100	34F
0005435091925	17019	101	34E
0005435091932	17019	102	34H
0005435091926	17019	103	35A
0005433342017	17019	104	35G
0005433341997	17019	105	36A
0005433342069	17019	106	36F
0005433342073	17019	107	36G
0005433342035	17019	108	36H
0005433342087	17019	109	37B
0005433342003	17019	110	37E
0005433269662	17019	111	37D
0005433342045	17019	112	37F
0005433342080	17019	113	38E
0005433342083	17019	114	38F
0005433342085	17019	115	39D
0005435091901	17019	116	39F
0005432851854	18272	1	1F
0005432851856	18272	2	2A
0005432851863	18272	3	4C
0005432851845	18272	4	5C
0005432851844	18272	5	5A
0005432851858	18272	6	7B
0005432851851	18272	7	7D
0005432851861	18272	8	8A
0005432851852	18272	9	9A
0005432851842	18272	10	10B
0005432851850	18272	11	10F
0005432391946	18272	12	11B
0005432851847	18272	13	12D
0005432389952	18272	14	13A
0005432389947	18272	15	12F
0005432851855	18272	16	14B
0005432851846	18272	17	14E
0005432389946	18272	18	14C
0005432851841	18272	19	15B
0005432391947	18272	20	15D
0005432851853	18272	21	15E
0005432851857	18272	22	17E
0005432851859	18272	23	18B
0005432851862	18272	24	18C
0005432851849	18272	25	18D
0005432851843	18272	26	19C
0005432851860	18272	27	19E
0005432851848	18272	28	20B
0005432389951	18272	29	20D
0005432433621	12812	1	1D
0005434066440	12812	2	2A
0005434066433	12812	3	3A
0005434066328	12812	4	3F
0005434066313	12812	5	3D
0005434066299	12812	6	4A
0005434066311	12812	7	6B
0005432159808	12812	8	8B
0005432433624	12812	9	8A
0005434081558	12812	10	9A
0005434066327	12812	11	10E
0005434066434	12812	12	11F
0005433812875	12812	13	12A
0005432159811	12812	14	12D
0005434066297	12812	15	13A
0005434066394	12812	16	12F
0005432161128	12812	17	13D
0005432433623	12812	18	13E
0005434081474	12812	19	13F
0005433812874	12812	20	14A
0005432159810	12812	21	14B
0005434066298	12812	22	14C
0005434081510	12812	23	15B
0005434066300	12812	24	15A
0005434066442	12812	25	15E
0005432433620	12812	26	16C
0005432159809	12812	27	17C
0005432159807	12812	28	18A
0005434066306	12812	29	18B
0005434066348	12812	30	19C
0005432433622	12812	31	19D
0005433989688	12812	32	20B
0005434081557	12812	33	20A
0005432433625	12812	34	20C
0005434081485	12812	35	21D
0005434066441	12812	36	22C
0005434066422	12812	37	22D
0005434081636	30691	1	1D
0005434066795	30691	2	1C
0005434066746	30691	3	1A
0005434066751	30691	4	1F
0005434066761	30691	5	2C
0005434081637	30691	6	2A
0005432186829	30691	7	2D
0005434066755	30691	8	3A
0005434066756	30691	9	2F
0005434066794	30691	10	3C
0005434066803	30691	11	3D
0005434066736	30691	12	3F
0005434066764	30691	13	4B
0005434081638	30691	14	4A
0005433989715	30691	15	4D
0005434081650	30691	16	4C
0005434066798	30691	17	4E
0005434066743	30691	18	5A
0005434081630	30691	19	4F
0005434066797	30691	20	5B
0005434081652	30691	21	5C
0005434066779	30691	22	5D
0005434066789	30691	23	5F
0005434066758	30691	24	5E
0005434066791	30691	25	6A
0005432186830	30691	26	6C
0005434081647	30691	27	6B
0005432150107	30691	28	6E
0005433989717	30691	29	7A
0005434066777	30691	30	6F
0005434066802	30691	31	7D
0005434066787	30691	32	7C
0005434081646	30691	33	7B
0005434081632	30691	34	7E
0005433989719	30691	35	7F
0005434066741	30691	36	8A
0005434066766	30691	37	8B
0005434066765	30691	38	8C
0005432186828	30691	39	8D
0005432150104	30691	40	8F
0005433989718	30691	41	8E
0005434066769	30691	42	9B
0005434066784	30691	43	9D
0005434081629	30691	44	9E
0005434066781	30691	45	9F
0005434066778	30691	46	10B
0005434066732	30691	47	10D
0005434066760	30691	48	10C
0005434066740	30691	49	10E
0005434066783	30691	50	11A
0005434081645	30691	51	11B
0005432150109	30691	52	11D
0005432150103	30691	53	11C
0005434066745	30691	54	11F
0005434081639	30691	55	12A
0005434066800	30691	56	12B
0005434066759	30691	57	12D
0005432150108	30691	58	12C
0005434066786	30691	59	12E
0005434066776	30691	60	12F
0005432186827	30691	61	13B
0005434066788	30691	62	13A
0005432433599	30691	63	13D
0005434081648	30691	64	13C
0005434066744	30691	65	13E
0005434066731	30691	66	13F
0005434066742	30691	67	14A
0005434066773	30691	68	14C
0005432150105	30691	69	14B
0005434081649	30691	70	14D
0005434066770	30691	71	14E
0005433989716	30691	72	14F
0005434066738	30691	73	15B
0005434066754	30691	74	15A
0005434081644	30691	75	15D
0005434066775	30691	76	15E
0005434066750	30691	77	16C
0005434066792	30691	78	16B
0005434066790	30691	79	16D
0005434066763	30691	80	16E
0005434066767	30691	81	16F
0005434066733	30691	82	17B
0005434066785	30691	83	17C
0005434081643	30691	84	17F
0005434066772	30691	85	17E
0005434066771	30691	86	18A
0005434081640	30691	87	18B
0005434066730	30691	88	18C
0005434066753	30691	89	18E
0005434081635	30691	90	18D
0005434066748	30691	91	18F
0005434081642	30691	92	19A
0005434066734	30691	93	19C
0005432150106	30691	94	19B
0005434066774	30691	95	19D
0005434066793	30691	96	19E
0005434066752	30691	97	19F
0005434081631	30691	98	20A
0005434066747	30691	99	20D
0005434066762	30691	100	20C
0005434081633	30691	101	20E
0005434081651	30691	102	20F
0005434081626	30691	103	21B
0005434066757	30691	104	21A
0005434066801	30691	105	21C
0005434066782	30691	106	21D
0005434081628	30691	107	21F
0005434066735	30691	108	21E
0005432433600	30691	109	22A
0005434066739	30691	110	22C
0005434066796	30691	111	22B
0005434066768	30691	112	22E
0005434081627	30691	113	23A
0005434066749	30691	114	22F
0005434066780	30691	115	23B
0005434066737	30691	116	23D
0005434081641	30691	117	23C
0005434066799	30691	118	23F
0005434081634	30691	119	23E
0005433689875	19355	1	2B
0005435461817	5545	1	1B
0005435725542	5545	2	1F
0005435735087	5545	3	1C
0005435461917	5545	4	2A
0005435765585	5545	5	2B
0005435725546	5545	6	2H
0005435765568	5545	7	3A
0005435735088	5545	8	3G
0005435461792	5545	9	4B
0005435722030	5545	10	4A
0005435765605	5545	11	4G
0005435461763	5545	12	4F
0005435765593	5545	13	5B
0005435765587	5545	14	5F
0005435765578	5545	15	5G
0005435765592	5545	16	5H
0005435765588	5545	17	9B
0005435765596	5545	18	9G
0005435765559	5545	19	9H
0005435765604	5545	20	11B
0005435765580	5545	21	11D
0005435765583	5545	22	11F
0005435765551	5545	23	11G
0005435765575	5545	24	12A
0005435765548	5545	25	11H
0005432140359	5545	26	12B
0005435765601	5545	27	12H
0005435765594	5545	28	13A
0005435765556	5545	29	13E
0005435765600	5545	30	13F
0005435765597	5545	31	14A
0005435765589	5545	32	14B
0005435765598	5545	33	14D
0005435725544	5545	34	14F
0005435765595	5545	35	15B
0005433527229	5545	36	15F
0005433529240	5545	37	16A
0005435765569	5545	38	16F
0005435765576	5545	39	16H
0005435765571	5545	40	17A
0005432140365	5545	41	17E
0005435765562	5545	42	17G
0005435461772	5545	43	17F
0005435765584	5545	44	17H
0005435765574	5545	45	18A
0005432140360	5545	46	18E
0005434264682	5545	47	18H
0005432140363	5545	48	19A
0005435765573	5545	49	19D
0005435765581	5545	50	19E
0005433527226	5545	51	19F
0005435461825	5545	52	19H
0005435765554	5545	53	20A
0005435765599	5545	54	20E
0005435461818	5545	55	20G
0005435720813	5545	56	20F
0005435735086	5545	57	20H
0005435765608	5545	58	21F
0005433527230	5545	59	21E
0005435765566	5545	60	21H
0005435735089	5545	61	22A
0005435765590	5545	62	22E
0005435765579	5545	63	22F
0005435722029	5545	64	23B
0005434264675	5545	65	23F
0005435765567	5545	66	23H
0005435461766	5545	67	24D
0005435765586	5545	68	24H
0005435765606	5545	69	25E
0005435765607	5545	70	25F
0005435725543	5545	71	27B
0005435765558	5545	72	27A
0005435765550	5545	73	27E
0005435765603	5545	74	27G
0005435765582	5545	75	27H
0005435765557	5545	76	28D
0005435765563	5545	77	28H
0005435461824	5545	78	29A
0005432140362	5545	79	29B
0005435765572	5545	80	29E
0005434264706	5545	81	29F
0005435461765	5545	82	29H
0005435765561	5545	83	29G
0005435461769	5545	84	30B
0005433529239	5545	85	30E
0005434264695	5545	86	30H
0005435720814	5545	87	31D
0005435765549	5545	88	31H
0005435723023	5545	89	31G
0005435765565	5545	90	32A
0005432140364	5545	91	32E
0005434264707	5545	92	32H
0005435461916	5545	93	32G
0005433527228	5545	94	33A
0005435725545	5545	95	33B
0005433529238	5545	96	33H
0005435765564	5545	97	34D
0005435765602	5545	98	34F
0005435765560	5545	99	34G
0005433529237	5545	100	35A
0005435765555	5545	101	34H
0005435765570	5545	102	35B
0005434264718	5545	103	35D
0005435461773	5545	104	35E
0005435461762	5545	105	35G
0005433529241	5545	106	36B
0005435765552	5545	107	36D
0005435723024	5545	108	36G
0005432140357	5545	109	37B
0005432140361	5545	110	37D
0005435765591	5545	111	37H
0005435765577	5545	112	37G
0005433527227	5545	113	38A
0005435461786	5545	114	38D
0005432140358	5545	115	39D
0005435765553	5545	116	39F
0005435462049	13461	1	1F
0005434264875	13461	2	1C
0005434831101	13461	3	2A
0005435462061	13461	4	2B
0005435765161	13461	5	2H
0005434264865	13461	6	3F
0005435462044	13461	7	3C
0005435462063	13461	8	3H
0005434264867	13461	9	4B
0005434264878	13461	10	4C
0005432194469	13461	11	5C
0005435462056	13461	12	5H
0005434264868	13461	13	9H
0005435462040	13461	14	11A
0005435462033	13461	15	11D
0005435462032	13461	16	11B
0005435765128	13461	17	11H
0005432535785	13461	18	12A
0005435765189	13461	19	12D
0005435462048	13461	20	12G
0005435765171	13461	21	12H
0005435765241	13461	22	13D
0005435462047	13461	23	13B
0005435462065	13461	24	13H
0005435462029	13461	25	14A
0005435765335	13461	26	14G
0005435462036	13461	27	14H
0005434264864	13461	28	15D
0005435462028	13461	29	15G
0005435765124	13461	30	15H
0005435462038	13461	31	16B
0005434264881	13461	32	16E
0005435765314	13461	33	16D
0005435765271	13461	34	16F
0005435765152	13461	35	17B
0005435765333	13461	36	17G
0005435462045	13461	37	17F
0005435462042	13461	38	18D
0005434264872	13461	39	18G
0005432535783	13461	40	18F
0005435765153	13461	41	19B
0005435462052	13461	42	19A
0005432194467	13461	43	19E
0005435765138	13461	44	19F
0005435765168	13461	45	19G
0005434264879	13461	46	20G
0005435462035	13461	47	21A
0005435462043	13461	48	21F
0005435462039	13461	49	21E
0005434264863	13461	50	22B
0005435765336	13461	51	22F
0005435765315	13461	52	22H
0005434264882	13461	53	23D
0005434264861	13461	54	23E
0005435765188	13461	55	23G
0005434831104	13461	56	23H
0005435462057	13461	57	24E
0005434264886	13461	58	24G
0005435462027	13461	59	25D
0005434264876	13461	60	25E
0005434264884	13461	61	27B
0005432535784	13461	62	27E
0005435765170	13461	63	27D
0005435462051	13461	64	27F
0005435462046	13461	65	28D
0005434831102	13461	66	28B
0005435462054	13461	67	28A
0005435462059	13461	68	28G
0005432535781	13461	69	28F
0005435765214	13461	70	29D
0005434264873	13461	71	29B
0005434264862	13461	72	29E
0005435462037	13461	73	29G
0005434264883	13461	74	30E
0005435462050	13461	75	30G
0005434831100	13461	76	30H
0005434264877	13461	77	31H
0005434264871	13461	78	31F
0005435462053	13461	79	32E
0005435765334	13461	80	32D
0005435462034	13461	81	32G
0005435462062	13461	82	32F
0005435765167	13461	83	32H
0005435462041	13461	84	33A
0005435462060	13461	85	33B
0005432194465	13461	86	33E
0005435462064	13461	87	33F
0005435462055	13461	88	33H
0005434264866	13461	89	34B
0005435462031	13461	90	34A
0005432535782	13461	91	34D
0005434831105	13461	92	34G
0005435765220	13461	93	35A
0005435462058	13461	94	35D
0005434831103	13461	95	35E
0005434264869	13461	96	35G
0005435462030	13461	97	35F
0005434264880	13461	98	36A
0005434264885	13461	99	36D
0005434264874	13461	100	36H
0005435765305	13461	101	37D
0005435765127	13461	102	37F
0005435765282	13461	103	37H
0005435765281	13461	104	38A
0005434264870	13461	105	38D
0005432194468	13461	106	38G
0005432194466	13461	107	39F
0005434514937	18746	1	1A
0005434513550	18746	2	2B
0005434514939	18746	3	3B
0005434514938	18746	4	4B
0005434513549	18746	5	5B
0005434514923	19184	1	2B
0005434514928	19184	2	5A
0005434514927	19184	3	5B
0005434514922	19184	4	6A
0005435844282	25089	1	2F
0005432632627	25089	2	3D
0005435844276	25089	3	4D
0005435844271	25089	4	5C
0005435846214	25089	5	6A
0005432649303	25089	6	6E
0005435844279	25089	7	7A
0005435846216	25089	8	7D
0005435846210	25089	9	7E
0005435844274	25089	10	8C
0005435844281	25089	11	8D
0005435844273	25089	12	9E
0005435844275	25089	13	10A
0005432649296	25089	14	10C
0005435844280	25089	15	10D
0005435846213	25089	16	11E
0005435846211	25089	17	11F
0005435846215	25089	18	12C
0005435844277	25089	19	13C
0005435846212	25089	20	13E
0005432649307	25089	21	13F
0005432649302	25089	22	14A
0005435844272	25089	23	18C
0005435844278	25089	24	18E
0005435846217	25089	25	19C
0005432649297	25089	26	20D
0005433007987	1852	1	1F
0005433007848	1852	2	4C
0005433007986	1852	3	4E
0005433007929	1852	4	6C
0005432295852	1852	5	6F
0005433008006	1852	6	7C
0005433007899	1852	7	9E
0005433007822	1852	8	10D
0005433284772	1852	9	10E
0005433007847	1852	10	11A
0005432295851	1852	11	11E
0005432295854	1852	12	12E
0005433284771	1852	13	12F
0005433007868	1852	14	13E
0005433007860	1852	15	14A
0005433007910	1852	16	14E
0005433007911	1852	17	14F
0005433007876	1852	18	15E
0005433007834	1852	19	17C
0005433007875	1852	20	17F
0005433284769	1852	21	18F
0005432295853	1852	22	19F
0005433007877	1852	23	20E
0005433007985	1852	24	20F
0005433008142	22628	1	1A
0005433284948	22628	2	1D
0005433008115	22628	3	1F
0005433284955	22628	4	2A
0005433284946	22628	5	2C
0005433008120	22628	6	2D
0005433284963	22628	7	2F
0005433284949	22628	8	3C
0005433008108	22628	9	3D
0005433008101	22628	10	3F
0005433284960	22628	11	4A
0005433008137	22628	12	4D
0005433008145	22628	13	4E
0005433008131	22628	14	4F
0005433284970	22628	15	5A
0005433008146	22628	16	5C
0005433008144	22628	17	5D
0005433008111	22628	18	5E
0005433008139	22628	19	5F
0005433284961	22628	20	6A
0005433008124	22628	21	6C
0005433008104	22628	22	6D
0005433008130	22628	23	6E
0005433284971	22628	24	6F
0005433008117	22628	25	7A
0005433284952	22628	26	7C
0005433284967	22628	27	7D
0005433008140	22628	28	7E
0005433284964	22628	29	7F
0005433008135	22628	30	8A
0005433284953	22628	31	8D
0005433008126	22628	32	9A
0005433284965	22628	33	9C
0005433284945	22628	34	9E
0005433008136	22628	35	9F
0005433008119	22628	36	10A
0005433008102	22628	37	10C
0005433008141	22628	38	10D
0005433008107	22628	39	11A
0005433008129	22628	40	11C
0005433284958	22628	41	11D
0005433284973	22628	42	11E
0005433284969	22628	43	12A
0005433284947	22628	44	12C
0005433284951	22628	45	12D
0005433008132	22628	46	12F
0005433008138	22628	47	13A
0005433284956	22628	48	13C
0005433008123	22628	49	13D
0005433008118	22628	50	13E
0005433284966	22628	51	14A
0005433284943	22628	52	14C
0005433284944	22628	53	14D
0005433008105	22628	54	14E
0005433008103	22628	55	14F
0005433284968	22628	56	15C
0005433008114	22628	57	15D
0005433008125	22628	58	15E
0005433008143	22628	59	15F
0005433008106	22628	60	16A
0005433008110	22628	61	16C
0005433284957	22628	62	16D
0005433008128	22628	63	16E
0005433008112	22628	64	16F
0005433008122	22628	65	17C
0005433284954	22628	66	17D
0005433284962	22628	67	17E
0005433008109	22628	68	17F
0005433008100	22628	69	18A
0005433008134	22628	70	18C
0005433284974	22628	71	18E
0005433284950	22628	72	18F
0005433008133	22628	73	19A
0005433008116	22628	74	19C
0005433008127	22628	75	19F
0005433008121	22628	76	20C
0005433284959	22628	77	20D
0005433284972	22628	78	20E
0005433008113	22628	79	20F
0005432755032	25331	1	1C
0005432756803	25331	2	1F
0005432755027	25331	3	2A
0005432755031	25331	4	3C
0005432755038	25331	5	3F
0005432756801	25331	6	5A
0005432756804	25331	7	5D
0005432756808	25331	8	5F
0005432755029	25331	9	6D
0005432755034	25331	10	6E
0005432755035	25331	11	7A
0005432756807	25331	12	9A
0005432755030	25331	13	10A
0005432756797	25331	14	10E
0005432755037	25331	15	10F
0005432756798	25331	16	11A
0005432755036	25331	17	11F
0005432756802	25331	18	12F
0005432756809	25331	19	13C
0005432756800	25331	20	13D
0005432755026	25331	21	15F
0005432756805	25331	22	16C
0005432755028	25331	23	17A
0005432756806	25331	24	17F
0005432756810	25331	25	18D
0005432755033	25331	26	19F
0005432756799	25331	27	20C
0005435282077	5555	1	1C
0005433846115	5555	2	1A
0005435282059	5555	3	1F
0005432081442	5555	4	2A
0005435282097	5555	5	2D
0005433846098	5555	6	2C
0005432081443	5555	7	3A
0005435282128	5555	8	3D
0005433846099	5555	9	4A
0005433846103	5555	10	3F
0005433846092	5555	11	4D
0005433846132	5555	12	4C
0005433846085	5555	13	5A
0005433846119	5555	14	4F
0005433846123	5555	15	5F
0005433846116	5555	16	5D
0005433846131	5555	17	6B
0005433846105	5555	18	6A
0005433846107	5555	19	6D
0005432081444	5555	20	6C
0005433815335	5555	21	6E
0005433846125	5555	22	7A
0005433846129	5555	23	7C
0005433846101	5555	24	7B
0005433846113	5555	25	7F
0005433846118	5555	26	8F
0005433846090	5555	27	9B
0005435282076	5555	28	9A
0005433846088	5555	29	9C
0005433846106	5555	30	9E
0005433846120	5555	31	9D
0005433846126	5555	32	10B
0005433846130	5555	33	10F
0005433846100	5555	34	11B
0005433846089	5555	35	11A
0005433846128	5555	36	11D
0005433846086	5555	37	11E
0005433815332	5555	38	12A
0005433846087	5555	39	12B
0005433846134	5555	40	12F
0005433846135	5555	41	13C
0005433846127	5555	42	13B
0005435282061	5555	43	13D
0005433846137	5555	44	14A
0005433815331	5555	45	13F
0005433846114	5555	46	14C
0005433815330	5555	47	14B
0005433846138	5555	48	14D
0005433846111	5555	49	14F
0005435282129	5555	50	14E
0005433846112	5555	51	15B
0005433846122	5555	52	15A
0005435282060	5555	53	15D
0005435282079	5555	54	15C
0005433846104	5555	55	15F
0005433846082	5555	56	15E
0005433846117	5555	57	16B
0005435282049	5555	58	16E
0005433846097	5555	59	17A
0005435282062	5555	60	16F
0005433846110	5555	61	17B
0005433846139	5555	62	17D
0005433846121	5555	63	17C
0005433846108	5555	64	18B
0005433846083	5555	65	18D
0005435282075	5555	66	18C
0005433846140	5555	67	18E
0005433846093	5555	68	19A
0005433846109	5555	69	19B
0005433846096	5555	70	19D
0005433846136	5555	71	19C
0005433846095	5555	72	19E
0005433846084	5555	73	20B
0005433815333	5555	74	20A
0005433846094	5555	75	20D
0005433846124	5555	76	20C
0005433815334	5555	77	20E
0005433846091	5555	78	21B
0005433846102	5555	79	21A
0005435282063	5555	80	20F
0005435282069	5555	81	21C
0005433846133	5555	82	21E
0005432081445	5555	83	21D
0005433845665	13882	1	1A
0005435282242	13882	2	2D
0005435282235	13882	3	2F
0005433845762	13882	4	3C
0005433845806	13882	5	4A
0005432003670	13882	6	3F
0005432003668	13882	7	4D
0005433845810	13882	8	4C
0005435282249	13882	9	5A
0005435282259	13882	10	5C
0005435282260	13882	11	7E
0005435282244	13882	12	7D
0005434173478	13882	13	8F
0005435282256	13882	14	9D
0005433845669	13882	15	10B
0005433845664	13882	16	10A
0005433845666	13882	17	10C
0005434173480	13882	18	10E
0005433845853	13882	19	10D
0005433845808	13882	20	11A
0005433845842	13882	21	11C
0005435282238	13882	22	11B
0005433845668	13882	23	11E
0005433845771	13882	24	12B
0005435282248	13882	25	12D
0005435282253	13882	26	12C
0005435282232	13882	27	12F
0005435282234	13882	28	13A
0005433845739	13882	29	13E
0005433845824	13882	30	14A
0005435282239	13882	31	13F
0005433845812	13882	32	14B
0005435282241	13882	33	14D
0005435282233	13882	34	14C
0005433845813	13882	35	15A
0005435282237	13882	36	15D
0005433845854	13882	37	15E
0005435282250	13882	38	16A
0005435282254	13882	39	16D
0005435282236	13882	40	16C
0005435282252	13882	41	16F
0005432003669	13882	42	17B
0005435282247	13882	43	17F
0005435282255	13882	44	18C
0005433815300	13882	45	18E
0005434173479	13882	46	18D
0005435282257	13882	47	18F
0005435282243	13882	48	19B
0005433845663	13882	49	19D
0005433845772	13882	50	19C
0005435282258	13882	51	20B
0005433845761	13882	52	20D
0005433845738	13882	53	20C
0005433845857	13882	54	20E
0005435282240	13882	55	21A
0005433845805	13882	56	20F
0005433845811	13882	57	21B
0005435282246	13882	58	21E
0005435282251	13882	59	21D
0005435282245	13882	60	21F
0005434620376	7846	1	1B
0005434620383	7846	2	1C
0005434620385	7846	3	2A
0005432112492	7846	4	3B
0005435332150	7846	5	4A
0005435332172	7846	6	4B
0005434620378	7846	7	4C
0005434620389	7846	8	5B
0005434620384	7846	9	5C
0005434620375	7846	10	5D
0005434620381	7846	11	6A
0005434620388	7846	12	6C
0005435332151	7846	13	6D
0005434620373	7846	14	7D
0005435332173	7846	15	18A
0005435332171	7846	16	18C
0005434620387	7846	17	19C
0005435332152	7846	18	20B
0005435332170	7846	19	20C
0005434620377	7846	20	20D
0005434620379	7846	21	21A
0005434620370	7846	22	21B
0005434620372	7846	23	21C
0005434620371	7846	24	22A
0005434620380	7846	25	22B
0005434620386	7846	26	22D
0005434620382	7846	27	23A
0005434620374	7846	28	23B
0005435332230	32947	1	1B
0005435332227	32947	2	1D
0005435332222	32947	3	2C
0005434620259	32947	4	3B
0005435332224	32947	5	3C
0005435332221	32947	6	4B
0005434620222	32947	7	4C
0005435332225	32947	8	4D
0005434620255	32947	9	5B
0005435332228	32947	10	7A
0005434620277	32947	11	7D
0005434620230	32947	12	18C
0005434620229	32947	13	18D
0005435332223	32947	14	19B
0005434620260	32947	15	20A
0005435332226	32947	16	20B
0005434620258	32947	17	20D
0005435332229	32947	18	22B
0005435784993	4293	1	1A
0005435784999	4293	2	1D
0005435784981	4293	3	2F
0005435784997	4293	4	3D
0005435784996	4293	5	3F
0005432190590	4293	6	4A
0005435785003	4293	7	4D
0005435785005	4293	8	5D
0005435784986	4293	9	5E
0005434993922	4293	10	5F
0005435785010	4293	11	6A
0005435785004	4293	12	6C
0005434993924	4293	13	6D
0005435784998	4293	14	6E
0005435785006	4293	15	6F
0005435785002	4293	16	7A
0005435784983	4293	17	7E
0005435785001	4293	18	7F
0005434993919	4293	19	8A
0005434993915	4293	20	8C
0005432190589	4293	21	8E
0005434993917	4293	22	9A
0005434993918	4293	23	9E
0005435784979	4293	24	9F
0005435785008	4293	25	10A
0005435918569	4293	26	10C
0005435784977	4293	27	10E
0005432190588	4293	28	10F
0005434993921	4293	29	11D
0005435918590	4293	30	11F
0005435784990	4293	31	12C
0005432190587	4293	32	12F
0005435785000	4293	33	13C
0005435784992	4293	34	13F
0005435785007	4293	35	14A
0005435784987	4293	36	14C
0005435787331	4293	37	14D
0005435918576	4293	38	14E
0005435784995	4293	39	15A
0005435784984	4293	40	15C
0005435784978	4293	41	16A
0005435784988	4293	42	16C
0005434993920	4293	43	16D
0005435784982	4293	44	16E
0005435787330	4293	45	16F
0005435784980	4293	46	17A
0005434993916	4293	47	17C
0005435784985	4293	48	17D
0005435785009	4293	49	17F
0005435918574	4293	50	18A
0005434993923	4293	51	18C
0005435918591	4293	52	18F
0005435784991	4293	53	19D
0005435784989	4293	54	19E
0005435918570	4293	55	19F
0005435784994	4293	56	20A
0005435918575	4293	57	20D
0005435918605	27280	1	2C
0005432195669	27280	2	3A
0005435918606	27280	3	3C
0005435918603	27280	4	4F
0005435937333	27280	5	7D
0005435784817	27280	6	7E
0005435937332	27280	7	9A
0005435937329	27280	8	10C
0005435918604	27280	9	11A
0005435937331	27280	10	12C
0005435784735	27280	11	12E
0005435784790	27280	12	14E
0005432195670	27280	13	17A
0005432195668	27280	14	17D
0005435937330	27280	15	18F
0005432146177	19849	1	18B
0005432146176	19849	2	22A
0005432566995	4717	1	1A
0005434081663	4717	2	1C
0005432459283	4717	3	1F
0005432459298	4717	4	1G
0005432566971	4717	5	1H
0005434081654	4717	6	2B
0005432170318	4717	7	2F
0005432571282	4717	8	2C
0005432566997	4717	9	2H
0005432459282	4717	10	2G
0005432571283	4717	11	3A
0005432566981	4717	12	3G
0005432170317	4717	13	4A
0005432459301	4717	14	3H
0005434081657	4717	15	4B
0005432566966	4717	16	4F
0005432566990	4717	17	4C
0005432459315	4717	18	4G
0005433726079	4717	19	5A
0005432459325	4717	20	4H
0005432567024	4717	21	5B
0005434081670	4717	22	5C
0005432566975	4717	23	5G
0005432566970	4717	24	5F
0005432567019	4717	25	5H
0005432459297	4717	26	9B
0005434081667	4717	27	11A
0005432459300	4717	28	9H
0005432459280	4717	29	11B
0005432459304	4717	30	11E
0005432566974	4717	31	11G
0005432566979	4717	32	11F
0005432567018	4717	33	11H
0005432459310	4717	34	12E
0005432567020	4717	35	12D
0005432459281	4717	36	12G
0005432170320	4717	37	12H
0005432567022	4717	38	13A
0005432567007	4717	39	13B
0005433452716	4717	40	13E
0005432566982	4717	41	13G
0005432567000	4717	42	14B
0005434081672	4717	43	14A
0005432567017	4717	44	14E
0005432566989	4717	45	14D
0005434081660	4717	46	14H
0005434081655	4717	47	14G
0005432459311	4717	48	15A
0005434081653	4717	49	15B
0005432459296	4717	50	15E
0005432459326	4717	51	15D
0005432566984	4717	52	15F
0005432170315	4717	53	16A
0005432459313	4717	54	15H
0005432566980	4717	55	16D
0005433726080	4717	56	16B
0005432459314	4717	57	16E
0005432566977	4717	58	16F
0005432567004	4717	59	17A
0005432567008	4717	60	17D
0005432566987	4717	61	17E
0005432459288	4717	62	17G
0005432571280	4717	63	17H
0005432459307	4717	64	18D
0005432459286	4717	65	18F
0005432566999	4717	66	18G
0005432567002	4717	67	18H
0005432566983	4717	68	19B
0005432567012	4717	69	19A
0005434081668	4717	70	19F
0005432459328	4717	71	19E
0005434081656	4717	72	19G
0005432459329	4717	73	20A
0005433452718	4717	74	20B
0005432567011	4717	75	20E
0005434081664	4717	76	20F
0005432170316	4717	77	20H
0005432459277	4717	78	21A
0005432567015	4717	79	21D
0005432459306	4717	80	21B
0005434081659	4717	81	21G
0005434081673	4717	82	21F
0005433451597	4717	83	22B
0005433451598	4717	84	22A
0005434081671	4717	85	22D
0005432459319	4717	86	22F
0005432567010	4717	87	22E
0005432566972	4717	88	23A
0005432566968	4717	89	22H
0005432566964	4717	90	23D
0005432566985	4717	91	23F
0005434081662	4717	92	23E
0005432459322	4717	93	24A
0005432567023	4717	94	23H
0005432459317	4717	95	24B
0005432566992	4717	96	24F
0005432567016	4717	97	24H
0005432566976	4717	98	24G
0005432459324	4717	99	25D
0005432459321	4717	100	25F
0005432567009	4717	101	25E
0005432459291	4717	102	27A
0005432459318	4717	103	27B
0005432566973	4717	104	27E
0005432459316	4717	105	27D
0005432459279	4717	106	27H
0005432566991	4717	107	28A
0005432186831	4717	108	28D
0005434081666	4717	109	28E
0005432566986	4717	110	28G
0005432459294	4717	111	28F
0005432459293	4717	112	28H
0005432571281	4717	113	29B
0005432566965	4717	114	29A
0005432459299	4717	115	29E
0005432459278	4717	116	29G
0005432459323	4717	117	29H
0005432566993	4717	118	30B
0005432459289	4717	119	30A
0005432459303	4717	120	30E
0005434081669	4717	121	30G
0005432459287	4717	122	30F
0005432459320	4717	123	30H
0005432567014	4717	124	31B
0005432459305	4717	125	31A
0005432170314	4717	126	31D
0005432170319	4717	127	31G
0005432567003	4717	128	32D
0005432459290	4717	129	32A
0005432567013	4717	130	32E
0005432170313	4717	131	32F
0005432566996	4717	132	32G
0005432186833	4717	133	33B
0005432566978	4717	134	33D
0005432459295	4717	135	33F
0005432186832	4717	136	33G
0005433451599	4717	137	34D
0005433726081	4717	138	34B
0005432566988	4717	139	34E
0005432567005	4717	140	34G
0005432567006	4717	141	35A
0005432459308	4717	142	35D
0005432566998	4717	143	35E
0005432459302	4717	144	35F
0005432459285	4717	145	36A
0005432459309	4717	146	36B
0005432459284	4717	147	36D
0005432567021	4717	148	36F
0005432566967	4717	149	36H
0005432459327	4717	150	37A
0005434081665	4717	151	37E
0005433452717	4717	152	37D
0005432566969	4717	153	37F
0005432567025	4717	154	38A
0005434081658	4717	155	38E
0005434081661	4717	156	38G
0005432459292	4717	157	38F
0005432459312	4717	158	38H
0005432566994	4717	159	39D
0005432567001	4717	160	39F
0005432566547	30530	1	1F
0005432566734	30530	2	2C
0005432459038	30530	3	2B
0005432566542	30530	4	2H
0005432459100	30530	5	3C
0005432566554	30530	6	4C
0005432566701	30530	7	4G
0005432459096	30530	8	5A
0005432571259	30530	9	5G
0005432566759	30530	10	11B
0005432566686	30530	11	12D
0005432459025	30530	12	12B
0005432459121	30530	13	12E
0005432566596	30530	14	12H
0005432459103	30530	15	13A
0005434081485	30530	16	13B
0005432566625	30530	17	15A
0005432161128	30530	18	14H
0005432566543	30530	19	15G
0005432566698	30530	20	16B
0005432458968	30530	21	16H
0005432459217	30530	22	16G
0005432213568	30530	23	17B
0005432566528	30530	24	17G
0005432566595	30530	25	19A
0005432213566	30530	26	19B
0005432213567	30530	27	19E
0005432566576	30530	28	19D
0005432459227	30530	29	20A
0005432566700	30530	30	20E
0005432459061	30530	31	21D
0005434081474	30530	32	21H
0005432459060	30530	33	22B
0005432458965	30530	34	23B
0005432566645	30530	35	23D
0005432566577	30530	36	23G
0005432459101	30530	37	23H
0005432566699	30530	38	24A
0005432459037	30530	39	24F
0005432458978	30530	40	25D
0005432566726	30530	41	27A
0005434081510	30530	42	27B
0005432458967	30530	43	28B
0005432566674	30530	44	29A
0005432459077	30530	45	28H
0005434081557	30530	46	29D
0005432458973	30530	47	29E
0005432566624	30530	48	29H
0005434081558	30530	49	30D
0005432458960	30530	50	30G
0005432459205	30530	51	31H
0005432566673	30530	52	32E
0005432459097	30530	53	33D
0005432459036	30530	54	33E
0005432566711	30530	55	34A
0005432566555	30530	56	35B
0005432566721	30530	57	35A
0005432566758	30530	58	36F
0005432566666	30530	59	36E
0005432459226	30530	60	36G
0005432566556	30530	61	37E
0005432566575	30530	62	38D
0005432566558	30530	63	38E
0005432566665	30530	64	39E
0005435722030	13601	1	1A
0005435720814	13601	2	1B
0005435722029	13601	3	2B
0005435720813	13601	4	2A
0005432295851	22765	1	6B
0005432295853	22765	2	6C
0005432295852	22765	3	22B
0005432295854	22765	4	22C
0005433342157	11096	1	1A
0005433342171	11096	2	1C
0005433342108	11096	3	1D
0005433342103	11096	4	1F
0005433342137	11096	5	2C
0005433342142	11096	6	2A
0005433342151	11096	7	2D
0005433342134	11096	8	3A
0005433342136	11096	9	2F
0005433342117	11096	10	3D
0005433342139	11096	11	3C
0005433342168	11096	12	3F
0005433342121	11096	13	4A
0005433342182	11096	14	4B
0005433342156	11096	15	4D
0005433342175	11096	16	4E
0005433342190	11096	17	4F
0005433342160	11096	18	5B
0005433342153	11096	19	5A
0005433342140	11096	20	5C
0005433342141	11096	21	5E
0005433342162	11096	22	6A
0005433342183	11096	23	5F
0005433342154	11096	24	6C
0005435097101	11096	25	6B
0005433342116	11096	26	6E
0005433342165	11096	27	7B
0005433342135	11096	28	7A
0005433342089	11096	29	7D
0005433342110	11096	30	7E
0005433342176	11096	31	8A
0005433342100	11096	32	7F
0005433342131	11096	33	8B
0005433342119	11096	34	8D
0005433342112	11096	35	8E
0005435097104	11096	36	8F
0005433342150	11096	37	9A
0005433342186	11096	38	9B
0005433342169	11096	39	9D
0005433342106	11096	40	9C
0005433342148	11096	41	9E
0005433342109	11096	42	10B
0005433342174	11096	43	10E
0005433342152	11096	44	10D
0005433342163	11096	45	11A
0005433342127	11096	46	11C
0005433342126	11096	47	11B
0005435097105	11096	48	11D
0005433342091	11096	49	11E
0005433342164	11096	50	11F
0005433342125	11096	51	12A
0005433342138	11096	52	12C
0005433342090	11096	53	12B
0005433342128	11096	54	12D
0005435097109	11096	55	12E
0005433342094	11096	56	12F
0005433342096	11096	57	13A
0005433342158	11096	58	13C
0005433342120	11096	59	13B
0005433342167	11096	60	13D
0005435097107	11096	61	13E
0005433342104	11096	62	14A
0005433342095	11096	63	13F
0005433342184	11096	64	14B
0005433342105	11096	65	14C
0005433342113	11096	66	14E
0005433342172	11096	67	15A
0005433342166	11096	68	14F
0005433342093	11096	69	15B
0005433342170	11096	70	15C
0005433342181	11096	71	15E
0005433342143	11096	72	16A
0005435097106	11096	73	15F
0005435097099	11096	74	16B
0005433342102	11096	75	16C
0005433342107	11096	76	16D
0005433342114	11096	77	16F
0005433342177	11096	78	16E
0005433342144	11096	79	17A
0005433342111	11096	80	17B
0005433342179	11096	81	17D
0005433342124	11096	82	17E
0005433342147	11096	83	17F
0005433342191	11096	84	18B
0005433342159	11096	85	18D
0005433342132	11096	86	18C
0005433342123	11096	87	18E
0005433342188	11096	88	18F
0005433342178	11096	89	19A
0005433342173	11096	90	19B
0005433342149	11096	91	19D
0005433342101	11096	92	19C
0005433342185	11096	93	19F
0005433342161	11096	94	19E
0005433342097	11096	95	20A
0005433342118	11096	96	20B
0005433342092	11096	97	20D
0005433342145	11096	98	20C
0005435097100	11096	99	20E
0005433342189	11096	100	20F
0005433342098	11096	101	21B
0005433342133	11096	102	21A
0005433342122	11096	103	21C
0005433342180	11096	104	21D
0005433342130	11096	105	21E
0005435097103	11096	106	22A
0005435097108	11096	107	21F
0005433342129	11096	108	22B
0005435097102	11096	109	22D
0005433342099	11096	110	22F
0005433342146	11096	111	22E
0005433342115	11096	112	23C
0005433342155	11096	113	23D
0005433342187	11096	114	23F
0005433341410	17106	1	1C
0005432293183	17106	2	1D
0005433341501	17106	3	2A
0005433341442	17106	4	1F
0005435380251	17106	5	5B
0005433341567	17106	6	6C
0005435380250	17106	7	6D
0005433341409	17106	8	7E
0005433341474	17106	9	8B
0005435380249	17106	10	8E
0005435380248	17106	11	9C
0005435545643	17106	12	9F
0005433341396	17106	13	10C
0005433341574	17106	14	11B
0005435545649	17106	15	11D
0005433341538	17106	16	12C
0005435545647	17106	17	12D
0005433341431	17106	18	13A
0005432293184	17106	19	13B
0005432293182	17106	20	13E
0005435545645	17106	21	16B
0005435545646	17106	22	16C
0005433341560	17106	23	16D
0005433341384	17106	24	17D
0005433341475	17106	25	18F
0005435380247	17106	26	18E
0005433341386	17106	27	19D
0005433341502	17106	28	20D
0005432293181	17106	29	21A
0005433341408	17106	30	21D
0005435545644	17106	31	21F
0005433341568	17106	32	23B
0005433341387	17106	33	23A
0005435545648	17106	34	23F
0005433481086	9106	1	1A
0005433506988	9106	2	2C
0005432919541	9106	3	2D
0005433506992	9106	4	3C
0005432919519	9106	5	4D
0005433481090	9106	6	4E
0005433506990	9106	7	5E
0005433506998	9106	8	6C
0005433481083	9106	9	6D
0005432919520	9106	10	7A
0005433506986	9106	11	7D
0005433481085	9106	12	8D
0005433506991	9106	13	9C
0005433506984	9106	14	9F
0005433506982	9106	15	10C
0005433506996	9106	16	10D
0005433506997	9106	17	10E
0005433481088	9106	18	11A
0005433507000	9106	19	11D
0005433506989	9106	20	11E
0005433506999	9106	21	12D
0005433506993	9106	22	12E
0005433506987	9106	23	13D
0005433506994	9106	24	13E
0005433506983	9106	25	14E
0005433506995	9106	26	15E
0005433507001	9106	27	17A
0005433481084	9106	28	18D
0005433481089	9106	29	18F
0005433506985	9106	30	20A
0005433481087	9106	31	20E
0005434158956	20440	1	2C
0005432919673	20440	2	2D
0005432919659	20440	3	2F
0005433506857	20440	4	3A
0005432919663	20440	5	3F
0005432919660	20440	6	4A
0005433506911	20440	7	4C
0005432919665	20440	8	4E
0005434158955	20440	9	5C
0005433506874	20440	10	5E
0005432919657	20440	11	5F
0005434158954	20440	12	6C
0005432919674	20440	13	6D
0005433506853	20440	14	6E
0005432919656	20440	15	7A
0005432919667	20440	16	7D
0005433506910	20440	17	7E
0005432919671	20440	18	10F
0005434158957	20440	19	11A
0005432919670	20440	20	11D
0005433506897	20440	21	11F
0005433481051	20440	22	12A
0005432919672	20440	23	12C
0005432919669	20440	24	12D
0005432919654	20440	25	12F
0005433506868	20440	26	13C
0005432919662	20440	27	13D
0005432919661	20440	28	14D
0005433506858	20440	29	15A
0005432919658	20440	30	15F
0005432919655	20440	31	16D
0005432919666	20440	32	18E
0005432919668	20440	33	19A
0005433506895	20440	34	19C
0005434158958	20440	35	19F
0005432919664	20440	36	20D
0005432396200	10134	1	1A
0005432394058	10134	2	2A
0005432396199	10134	3	2B
0005432396197	10134	4	3B
0005432396196	10134	5	4A
0005432394059	10134	6	4B
0005432394060	10134	7	5A
0005432394057	10134	8	5B
0005432396198	10134	9	6A
0005432400059	18330	1	1A
0005432400056	18330	2	2A
0005432400057	18330	3	3A
0005432400058	18330	4	3B
0005432400063	18330	5	4A
0005432400061	18330	6	5B
0005435554109	11047	1	1A
0005434411733	11047	2	3D
0005435125672	11047	3	4C
0005434411734	11047	4	4D
0005435125717	11047	5	5C
0005434411736	11047	6	6A
0005435125716	11047	7	7F
0005435125673	11047	8	11E
0005434411732	11047	9	11F
0005434928269	11047	10	12A
0005434928271	11047	11	12E
0005435125685	11047	12	13A
0005435125744	11047	13	15A
0005435125743	11047	14	16E
0005435125679	11047	15	17E
0005434411735	11047	16	17F
0005434928270	11047	17	18A
0005435554118	11047	18	18F
0005435125964	14691	1	1A
0005435625989	14691	2	1C
0005435125938	14691	3	1D
0005435554136	14691	4	1F
0005435625997	14691	5	2A
0005434928248	14691	6	2C
0005435125966	14691	7	2D
0005435125976	14691	8	3A
0005435125967	14691	9	3D
0005435125954	14691	10	3F
0005435125960	14691	11	4D
0005435125979	14691	12	4C
0005435554133	14691	13	4E
0005435625992	14691	14	4F
0005435125977	14691	15	5A
0005435625994	14691	16	5D
0005435625998	14691	17	5E
0005435125943	14691	18	5F
0005435125972	14691	19	6A
0005435554134	14691	20	6D
0005435625988	14691	21	6E
0005435125940	14691	22	6F
0005435125959	14691	23	7D
0005435125962	14691	24	7E
0005435125951	14691	25	7F
0005435554137	14691	26	8A
0005435125942	14691	27	8C
0005435125978	14691	28	8D
0005435125956	14691	29	8E
0005435125973	14691	30	8F
0005435125941	14691	31	9C
0005435125945	14691	32	9D
0005435125969	14691	33	9E
0005435125939	14691	34	10A
0005435125974	14691	35	10E
0005435625991	14691	36	10F
0005435554135	14691	37	11A
0005435125944	14691	38	11F
0005435125949	14691	39	12C
0005435125961	14691	40	12D
0005435625984	14691	41	13A
0005435625987	14691	42	13C
0005435125950	14691	43	13D
0005435625993	14691	44	13E
0005435125957	14691	45	14A
0005435625990	14691	46	14C
0005435125953	14691	47	14F
0005435125948	14691	48	15D
0005435125946	14691	49	15F
0005435625985	14691	50	16A
0005434928249	14691	51	16C
0005435125963	14691	52	16D
0005435125958	14691	53	16E
0005435556666	14691	54	17A
0005435125947	14691	55	17C
0005435625999	14691	56	17E
0005435556667	14691	57	17F
0005435625996	14691	58	18A
0005435125955	14691	59	18C
0005435125970	14691	60	18D
0005435125971	14691	61	18F
0005435125975	14691	62	19A
0005435125952	14691	63	19D
0005435625986	14691	64	19E
0005435125968	14691	65	19F
0005435625995	14691	66	20E
0005435125965	14691	67	20F
0005435715286	7139	1	2A
0005432400090	7139	2	4A
0005435443145	7139	3	5F
0005435715290	7139	4	6F
0005432398160	7139	5	7A
0005435715292	7139	6	7F
0005432398161	7139	7	8E
0005435178471	7139	8	9C
0005435715291	7139	9	9E
0005435443167	7139	10	10A
0005432400089	7139	11	10C
0005432400086	7139	12	10D
0005435715295	7139	13	10F
0005435715297	7139	14	12C
0005432400088	7139	15	13A
0005435715298	7139	16	13C
0005432398158	7139	17	13E
0005435715293	7139	18	13F
0005435715294	7139	19	14C
0005435715282	7139	20	14D
0005435715283	7139	21	15C
0005432400087	7139	22	15F
0005435443146	7139	23	16D
0005435715287	7139	24	16F
0005432398157	7139	25	17E
0005435715284	7139	26	18A
0005435715288	7139	27	18F
0005435715299	7139	28	19C
0005435715289	7139	29	19E
0005435715285	7139	30	20A
0005432398159	7139	31	20C
0005435715296	7139	32	20F
0005435443211	27077	1	2A
0005435443215	27077	2	4E
0005432394035	27077	3	5C
0005435443216	27077	4	5F
0005435443214	27077	5	7F
0005432394036	27077	6	9E
0005435715166	27077	7	12A
0005435715180	27077	8	13F
0005435443212	27077	9	15E
0005435443217	27077	10	17D
0005435443213	27077	11	18A
0005435443220	27077	12	18D
0005435443218	27077	13	19F
0005435443219	27077	14	19E
0005435715165	27077	15	20D
0005434084883	2739	1	1A
0005434084884	2739	2	5B
0005434084882	2739	3	6A
0005433060384	28476	1	1A
0005434084853	28476	2	1B
0005433060385	28476	3	2B
0005433060386	28476	4	4A
0005434084854	28476	5	6B
0005435517610	11364	1	4D
0005435517643	11364	2	5A
0005435540658	11364	3	9D
0005435540657	11364	4	10A
0005435517589	11364	5	12C
0005435540698	11364	6	16E
0005435540659	11364	7	16F
0005435540643	11364	8	17C
0005435517642	11364	9	17F
0005435517590	11364	10	18C
0005435517609	11364	11	18F
0005435517595	11364	12	19A
0005435540759	22225	1	2A
0005435529013	22225	2	2D
0005435540768	22225	3	3A
0005435540758	22225	4	3C
0005435529019	22225	5	3D
0005435529011	22225	6	3F
0005435540774	22225	7	4A
0005435529028	22225	8	4C
0005432294461	22225	9	4E
0005435529024	22225	10	4F
0005435540766	22225	11	5C
0005435540760	22225	12	5D
0005435540765	22225	13	5E
0005435529026	22225	14	6A
0005435540767	22225	15	6C
0005435529022	22225	16	6E
0005435529023	22225	17	6F
0005435529029	22225	18	7A
0005435540757	22225	19	8A
0005435540763	22225	20	8D
0005432294460	22225	21	9D
0005435529014	22225	22	9F
0005435529016	22225	23	10C
0005435529033	22225	24	10D
0005435529017	22225	25	10E
0005435540762	22225	26	11A
0005435540773	22225	27	11D
0005435540761	22225	28	11F
0005435540769	22225	29	12E
0005435529015	22225	30	13D
0005435540756	22225	31	13F
0005435540775	22225	32	14C
0005435529032	22225	33	14D
0005435529020	22225	34	15A
0005435540764	22225	35	15D
0005435529031	22225	36	16A
0005435529018	22225	37	16D
0005435540777	22225	38	16E
0005435529030	22225	39	17E
0005435529012	22225	40	18A
0005435529021	22225	41	18D
0005435540776	22225	42	18F
0005435540770	22225	43	19A
0005435540772	22225	44	19F
0005435540771	22225	45	20A
0005435529027	22225	46	20C
0005435529025	22225	47	20D
0005434906809	2318	1	1A
0005434906791	2318	2	1D
0005433250969	2318	3	1F
0005434906756	2318	4	2A
0005434906772	2318	5	2F
0005434906785	2318	6	3A
0005434906804	2318	7	3C
0005433250929	2318	8	3D
0005434906768	2318	9	3F
0005433250932	2318	10	4A
0005434906753	2318	11	4C
0005433251009	2318	12	4D
0005434906810	2318	13	4E
0005434906789	2318	14	4F
0005434906788	2318	15	5A
0005434906782	2318	16	5C
0005434906755	2318	17	5D
0005434906764	2318	18	5E
0005433250930	2318	19	5F
0005433251068	2318	20	6C
0005434906798	2318	21	6D
0005434906776	2318	22	6E
0005434906794	2318	23	6F
0005434906761	2318	24	7A
0005434906802	2318	25	7D
0005434906778	2318	26	7F
0005433250996	2318	27	8A
0005433251074	2318	28	8D
0005434906807	2318	29	8F
0005434906796	2318	30	9C
0005434906763	2318	31	9E
0005434906783	2318	32	9F
0005434906770	2318	33	10A
0005434906784	2318	34	10C
0005434906805	2318	35	10D
0005434906767	2318	36	10E
0005433251093	2318	37	10F
0005433250970	2318	38	11A
0005434906790	2318	39	11D
0005434906801	2318	40	11E
0005433250931	2318	41	11F
0005433251067	2318	42	12A
0005433250935	2318	43	12E
0005434906769	2318	44	12F
0005434906812	2318	45	13A
0005434906795	2318	46	13C
0005434906781	2318	47	13D
0005434906777	2318	48	13E
0005434906773	2318	49	13F
0005434906808	2318	50	14A
0005434906754	2318	51	14C
0005434906803	2318	52	14D
0005434906762	2318	53	14E
0005434906758	2318	54	14F
0005433251018	2318	55	15A
0005434906765	2318	56	15C
0005433400932	2318	57	15D
0005434906797	2318	58	15F
0005434906780	2318	59	16A
0005434906771	2318	60	16C
0005434906760	2318	61	16D
0005434906759	2318	62	16E
0005433400931	2318	63	16F
0005434906813	2318	64	17A
0005434906779	2318	65	17C
0005434906800	2318	66	17D
0005434906786	2318	67	17E
0005434906793	2318	68	17F
0005434906750	2318	69	18A
0005434906787	2318	70	18C
0005434906766	2318	71	18E
0005434906811	2318	72	18F
0005433251010	2318	73	19A
0005434906799	2318	74	19C
0005434906792	2318	75	19D
0005434906752	2318	76	19E
0005434906806	2318	77	19F
0005434906751	2318	78	20A
0005434906774	2318	79	20C
0005434906775	2318	80	20D
0005433250995	2318	81	20E
0005434906757	2318	82	20F
0005433251178	25609	1	2A
0005433251152	25609	2	2C
0005433400953	25609	3	2F
0005433251153	25609	4	3F
0005433251160	25609	5	4A
0005433251171	25609	6	5F
0005433251158	25609	7	6E
0005433251150	25609	8	6F
0005433251177	25609	9	7E
0005433251156	25609	10	8D
0005433251173	25609	11	8F
0005433251170	25609	12	9E
0005433251172	25609	13	10A
0005433251174	25609	14	11C
0005433251164	25609	15	11D
0005433251163	25609	16	12F
0005433251162	25609	17	13C
0005433251161	25609	18	13F
0005433251167	25609	19	14D
0005433251176	25609	20	14F
0005433251169	25609	21	15C
0005433251166	25609	22	15D
0005433400951	25609	23	15E
0005433251168	25609	24	16A
0005433251179	25609	25	17C
0005433251149	25609	26	17D
0005433251159	25609	27	17E
0005433400952	25609	28	18F
0005433251154	25609	29	19C
0005433251165	25609	30	19D
0005433251151	25609	31	19E
0005433251157	25609	32	20A
0005433251155	25609	33	20D
0005433251175	25609	34	20E
0005432620893	2521	1	1A
0005432862192	2521	2	2A
0005432620889	2521	3	2B
0005432620892	2521	4	2D
0005432620902	2521	5	3A
0005432620898	2521	6	4D
0005432620896	2521	7	5B
0005432620901	2521	8	5D
0005432862191	2521	9	6A
0005432620888	2521	10	6B
0005432620891	2521	11	6C
0005432620895	2521	12	6D
0005432620900	2521	13	7B
0005432620894	2521	14	7D
0005432862168	2521	15	18A
0005432862169	2521	16	18D
0005432862189	2521	17	19A
0005432620890	2521	18	19D
0005432862188	2521	19	20C
0005432620899	2521	20	21C
0005432620897	2521	21	23B
0005432862223	28044	1	2B
0005432862226	28044	2	3A
0005432862221	28044	3	3C
0005432862222	28044	4	4C
0005432620823	28044	5	6D
0005432620822	28044	6	18B
0005432862218	28044	7	18C
0005432862219	28044	8	19D
0005432862220	28044	9	20C
0005432862224	28044	10	21D
0005432862225	28044	11	22A
0005434097462	13112	1	2A
0005434097463	13112	2	3A
0005434097461	13112	3	6A
0005433451599	31095	1	1A
0005433452716	31095	2	1B
0005433451597	31095	3	3A
0005433451598	31095	4	3B
0005433452717	31095	5	4A
0005433452718	31095	6	4B
0005433134065	12015	1	3A
0005434142550	12015	2	20A
0005434142543	12015	3	22B
0005433131661	29848	1	1B
0005433134093	29848	2	2A
0005433134090	29848	3	2C
0005433134089	29848	4	3B
0005434142568	29848	5	3D
0005434142566	29848	6	6C
0005434183559	29848	7	7C
0005434142565	29848	8	7D
0005433134091	29848	9	18B
0005433134092	29848	10	18A
0005434183558	29848	11	19B
0005433131660	29848	12	19D
0005434184643	29848	13	20C
0005433131662	29848	14	21B
0005434142567	29848	15	21C
0005434184644	29848	16	23A
0005433134094	29848	17	23B
0005435798926	1608	1	1A
0005435798925	1608	2	1D
0005435798929	1608	3	2C
0005435798924	1608	4	4A
0005435798927	1608	5	6C
0005435798930	1608	6	7B
0005435798920	1608	7	18A
0005435798916	1608	8	18D
0005435798917	1608	9	19A
0005435798918	1608	10	19B
0005435798928	1608	11	20B
0005435798923	1608	12	20C
0005435798922	1608	13	21D
0005435798921	1608	14	22A
0005435798919	1608	15	22C
0005435697038	16495	1	1A
0005435697041	16495	2	1B
0005435934997	16495	3	1D
0005435697033	16495	4	2B
0005435697023	16495	5	2C
0005435697025	16495	6	2D
0005435697015	16495	7	3A
0005435697017	16495	8	4A
0005435697026	16495	9	5A
0005435697034	16495	10	5D
0005435697043	16495	11	6A
0005435697031	16495	12	6B
0005435697039	16495	13	6C
0005435697040	16495	14	7C
0005435697019	16495	15	18B
0005435697018	16495	16	18C
0005435697020	16495	17	18D
0005435697037	16495	18	19B
0005435697021	16495	19	19C
0005435697016	16495	20	20A
0005435697042	16495	21	20C
0005435697035	16495	22	20B
0005435697024	16495	23	21B
0005435697028	16495	24	21C
0005435697027	16495	25	21D
0005435697036	16495	26	22A
0005435697030	16495	27	22B
0005435697029	16495	28	22C
0005435697032	16495	29	23A
0005435697022	16495	30	23B
0005435696904	24712	1	1D
0005435935015	24712	2	2D
0005435696977	24712	3	4B
0005435696856	24712	4	5B
0005435696905	24712	5	5D
0005435696846	24712	6	6D
0005435696978	24712	7	7C
0005435696874	24712	8	19B
0005435696934	24712	9	20B
0005435696924	24712	10	21C
0005435935014	24712	11	22A
0005435696875	24712	12	22D
0005433724753	18783	1	1A
0005433724755	18783	2	1B
0005433724754	18783	3	3B
0005433724756	18783	4	4A
0005433724757	18783	5	5A
0005433724758	18783	6	5B
0005432968819	21607	1	4B
0005433724725	21607	2	5A
0005432968818	21607	3	6B
0005434137289	7342	1	1A
0005434137296	7342	2	1C
0005434137268	7342	3	1D
0005434137302	7342	4	1F
0005434137295	7342	5	2A
0005434137327	7342	6	2C
0005434137352	7342	7	2D
0005434137324	7342	8	3A
0005434137301	7342	9	3C
0005434137317	7342	10	3D
0005434137353	7342	11	3F
0005434137308	7342	12	4A
0005434137290	7342	13	4C
0005434137333	7342	14	4D
0005434137271	7342	15	4E
0005434137349	7342	16	4F
0005434087464	7342	17	5A
0005434087465	7342	18	5C
0005434137284	7342	19	5D
0005434137319	7342	20	5E
0005434137346	7342	21	5F
0005434137339	7342	22	6A
0005434137325	7342	23	6C
0005434137334	7342	24	6D
0005434137354	7342	25	6E
0005434137312	7342	26	6F
0005434137311	7342	27	7A
0005434137314	7342	28	7C
0005434137273	7342	29	7E
0005434137340	7342	30	7F
0005434137279	7342	31	8A
0005434137286	7342	32	8C
0005434137287	7342	33	8D
0005434137310	7342	34	8E
0005434137285	7342	35	8F
0005434137274	7342	36	9A
0005434137320	7342	37	9C
0005434137356	7342	38	9D
0005434137281	7342	39	9E
0005434137299	7342	40	9F
0005434137318	7342	41	10A
0005434137291	7342	42	10C
0005434137277	7342	43	10D
0005434137288	7342	44	10E
0005434137343	7342	45	10F
0005434137276	7342	46	11A
0005434137309	7342	47	11C
0005434137294	7342	48	11D
0005434137269	7342	49	11E
0005434137321	7342	50	11F
0005434137335	7342	51	12A
0005434137316	7342	52	12C
0005434137345	7342	53	12D
0005434137323	7342	54	12E
0005434137350	7342	55	12F
0005434137355	7342	56	13A
0005434137344	7342	57	13C
0005434137292	7342	58	13D
0005434137347	7342	59	13E
0005434137337	7342	60	13F
0005434137341	7342	61	14A
0005434137351	7342	62	14C
0005434137305	7342	63	14D
0005434137280	7342	64	14E
0005434137330	7342	65	14F
0005434137275	7342	66	15A
0005434137272	7342	67	15C
0005434087462	7342	68	15D
0005434087461	7342	69	15E
0005434137326	7342	70	15F
0005434137331	7342	71	16A
0005434137329	7342	72	16C
0005434137282	7342	73	16D
0005434137304	7342	74	16E
0005434137332	7342	75	16F
0005434137300	7342	76	17A
0005434137283	7342	77	17C
0005434137293	7342	78	17D
0005434137338	7342	79	17E
0005434087463	7342	80	17F
0005434137306	7342	81	18A
0005434137336	7342	82	18C
0005434137315	7342	83	18D
0005434137298	7342	84	18E
0005434137342	7342	85	18F
0005434137307	7342	86	19A
0005434087466	7342	87	19C
0005434137270	7342	88	19D
0005434137348	7342	89	19E
0005434137278	7342	90	19F
0005434137328	7342	91	20A
0005434137297	7342	92	20C
0005434137303	7342	93	20D
0005434137313	7342	94	20E
0005434137322	7342	95	20F
0005434136738	28578	1	2F
0005434136739	28578	2	7D
0005434087437	28578	3	9C
0005434136680	28578	4	13E
0005434087431	28578	5	14E
0005434136722	28578	6	16F
0005434136719	28578	7	17D
0005435808126	1929	1	1A
0005435808133	1929	2	1B
0005435808130	1929	3	1C
0005435808134	1929	4	2A
0005434610193	1929	5	3B
0005434610192	1929	6	5B
0005435808128	1929	7	6C
0005435808132	1929	8	7C
0005434610190	1929	9	18A
0005435808124	1929	10	18C
0005434610191	1929	11	19A
0005435808131	1929	12	19B
0005435808127	1929	13	20B
0005435808125	1929	14	20D
0005435808135	1929	15	21D
0005435808129	1929	16	22A
0005434503477	16685	1	2B
0005434503613	16685	2	5A
0005434503478	16685	3	7A
0005434503463	16685	4	7B
0005434503571	16685	5	7C
0005434503469	16685	6	18A
0005434503614	16685	7	20B
0005434503572	16685	8	21C
0005434503464	16685	9	21D
0005434503731	22921	1	1A
0005434503738	22921	2	1B
0005434503705	22921	3	1C
0005434503720	22921	4	1D
0005434503725	22921	5	2A
0005434503737	22921	6	2C
0005434503740	22921	7	2D
0005434503723	22921	8	3A
0005434503736	22921	9	3B
0005434503706	22921	10	3C
0005434503732	22921	11	3D
0005434503727	22921	12	4A
0005434503729	22921	13	4C
0005434503703	22921	14	4D
0005434503730	22921	15	5B
0005434503722	22921	16	5C
0005434503717	22921	17	5D
0005434503712	22921	18	6A
0005434503713	22921	19	6C
0005434503711	22921	20	6D
0005434503719	22921	21	7A
0005434503728	22921	22	7B
0005434503733	22921	23	7C
0005434503704	22921	24	7D
0005434503716	22921	25	18A
0005434503735	22921	26	18B
0005434503709	22921	27	18D
0005434503715	22921	28	19A
0005434503701	22921	29	19B
0005434503718	22921	30	19C
0005434503721	22921	31	19D
0005434503739	22921	32	20B
0005434503714	22921	33	20C
0005434503734	22921	34	20D
0005434503710	22921	35	21A
0005434503707	22921	36	21B
0005434503700	22921	37	21D
0005434503702	22921	38	22A
0005434503724	22921	39	22B
0005434503726	22921	40	22D
0005434503708	22921	41	23A
0005434608278	6504	1	1C
0005434608293	6504	2	2A
0005434608280	6504	3	3A
0005434608294	6504	4	4B
0005434608289	6504	5	4D
0005434608279	6504	6	5B
0005434608296	6504	7	5C
0005434608285	6504	8	6A
0005434608284	6504	9	6D
0005434608286	6504	10	7A
0005434608288	6504	11	7B
0005434608283	6504	12	7D
0005434608281	6504	13	18C
0005434608298	6504	14	18D
0005434608282	6504	15	19A
0005434608292	6504	16	19B
0005434608297	6504	17	20B
0005434608287	6504	18	22A
0005434608290	6504	19	22B
0005434608295	6504	20	23A
0005434608291	6504	21	23B
0005433266571	2177	1	1A
0005435078180	2177	2	2B
0005433266564	2177	3	2C
0005433266563	2177	4	3A
0005435078177	2177	5	3C
0005433266561	2177	6	3D
0005433266562	2177	7	5A
0005435078175	2177	8	5B
0005435078178	2177	9	5D
0005435078189	2177	10	6A
0005435078185	2177	11	6C
0005435078187	2177	12	7B
0005435078181	2177	13	7C
0005435078183	2177	14	18A
0005435078190	2177	15	19B
0005435078176	2177	16	19C
0005435078184	2177	17	19D
0005435078188	2177	18	20B
0005435078186	2177	19	20D
0005433266558	2177	20	21D
0005435078179	2177	21	22D
0005435078182	2177	22	23B
0005433266631	24319	1	2A
0005435078086	24319	2	2B
0005435078146	24319	3	3A
0005433266632	24319	4	3B
0005433266625	24319	5	5A
0005435078065	24319	6	5B
0005435078081	24319	7	6A
0005435078071	24319	8	6B
0005435078095	24319	9	6C
0005435078084	24319	10	7A
0005433266629	24319	11	7C
0005433266626	24319	12	18A
0005435078094	24319	13	18C
0005433266627	24319	14	19B
0005433266630	24319	15	20A
0005433266628	24319	16	21A
0005435078085	24319	17	22D
0005433266624	24319	18	23B
0005434988629	6666	1	1A
0005434988625	6666	2	1C
0005434988628	6666	3	2A
0005435803233	6666	4	2B
0005434988632	6666	5	5D
0005435803232	6666	6	6A
0005434988631	6666	7	7B
0005434988627	6666	8	7D
0005434988626	6666	9	18A
0005434988624	6666	10	18C
0005435803231	6666	11	19A
0005435803234	6666	12	19D
0005434988622	6666	13	20D
0005434988630	6666	14	21A
0005434988623	6666	15	21D
0005435464475	6666	16	22C
0005435464476	6666	17	22D
0005435464488	23639	1	3B
0005435464487	23639	2	20D
0005432382801	30453	1	1A
0005432382781	30453	2	1D
0005432382803	30453	3	1F
0005433449754	30453	4	2A
0005433449759	30453	5	2D
0005432382784	30453	6	3C
0005432382773	30453	7	3D
0005432382780	30453	8	4D
0005433449747	30453	9	4E
0005432382796	30453	10	5C
0005432382772	30453	11	5D
0005433449743	30453	12	5E
0005433449741	30453	13	5F
0005433449745	30453	14	6A
0005432382777	30453	15	6C
0005432382779	30453	16	6D
0005432382769	30453	17	6E
0005433449744	30453	18	6F
0005432382799	30453	19	7D
0005432382797	30453	20	7E
0005433449752	30453	21	8A
0005433449740	30453	22	8C
0005432382802	30453	23	8D
0005432382798	30453	24	8E
0005433454853	30453	25	9A
0005433449739	30453	26	9D
0005433449758	30453	27	9E
0005433449757	30453	28	10A
0005432382794	30453	29	10C
0005432382790	30453	30	10D
0005432382791	30453	31	10E
0005432382785	30453	32	11C
0005433449760	30453	33	11D
0005433449751	30453	34	11E
0005432382788	30453	35	12C
0005432382789	30453	36	12E
0005432382776	30453	37	13C
0005433449742	30453	38	13E
0005432382783	30453	39	13F
0005432382793	30453	40	14D
0005432382800	30453	41	14E
0005433449756	30453	42	15A
0005433449748	30453	43	15D
0005432382795	30453	44	15E
0005432382770	30453	45	15F
0005433449750	30453	46	16A
0005432382775	30453	47	16C
0005433454852	30453	48	16E
0005432382792	30453	49	16F
0005433449753	30453	50	17A
0005432382786	30453	51	17E
0005432382774	30453	52	17F
0005432382768	30453	53	18A
0005432382778	30453	54	18C
0005433449749	30453	55	18D
0005433449755	30453	56	19A
0005432382767	30453	57	19C
0005432382771	30453	58	19D
0005432382782	30453	59	19E
0005433449761	30453	60	19F
0005432382787	30453	61	20D
0005433449746	30453	62	20E
0005433449623	31311	1	7F
0005433449661	31311	2	9D
0005433449646	31311	3	13C
0005433449622	31311	4	17F
0005433449610	31311	5	20E
0005433788151	20831	1	1C
0005433788160	20831	2	3B
0005433788150	20831	3	5D
0005433788158	20831	4	6A
0005433788156	20831	5	6D
0005433788153	20831	6	19B
0005433788154	20831	7	19C
0005433788152	20831	8	19D
0005433788157	20831	9	20A
0005433788149	20831	10	20C
0005433788159	20831	11	23A
0005433788155	20831	12	23B
0005433131630	10802	1	2C
0005435299699	10802	2	22B
0005435299732	29725	1	1B
0005433129235	29725	2	2A
0005435299730	29725	3	3C
0005435299733	29725	4	4A
0005435299731	29725	5	4B
0005435299729	29725	6	4C
0005435302156	29725	7	6B
0005435302155	29725	8	6C
0005433129233	29725	9	7A
0005433126802	29725	10	7C
0005435302153	29725	11	18A
0005433126803	29725	12	19A
0005433126801	29725	13	19B
0005435302157	29725	14	19C
0005435302154	29725	15	19D
0005433129234	29725	16	20A
0005433129232	29725	17	21D
0005433126800	29725	18	23B
0005433109895	2416	1	1A
0005433109866	2416	2	1B
0005434287052	2416	3	1C
0005433109878	2416	4	1D
0005434287071	2416	5	2A
0005433109896	2416	6	2B
0005434287068	2416	7	2D
0005434287065	2416	8	3B
0005434287053	2416	9	3C
0005434287069	2416	10	3D
0005434287062	2416	11	4A
0005434287059	2416	12	4B
0005433109859	2416	13	4C
0005433109893	2416	14	4D
0005433109858	2416	15	5D
0005434287063	2416	16	6A
0005433109867	2416	17	6B
0005434287060	2416	18	6C
0005434287055	2416	19	6D
0005434287073	2416	20	7B
0005434287064	2416	21	7D
0005434287072	2416	22	18B
0005434287066	2416	23	18D
0005433109842	2416	24	19A
0005433109857	2416	25	19B
0005434287051	2416	26	19C
0005433109877	2416	27	20B
0005434287054	2416	28	20C
0005434287058	2416	29	20D
0005433109894	2416	30	21B
0005434287070	2416	31	21A
0005434287067	2416	32	21D
0005434287057	2416	33	22A
0005434287056	2416	34	22C
0005434287061	2416	35	23A
0005433109876	2416	36	23B
0005433109925	26862	1	2B
0005434286964	26862	2	3C
0005433109932	26862	3	4C
0005433109926	26862	4	5A
0005433109930	26862	5	5D
0005434286905	26862	6	6A
0005433109924	26862	7	7C
0005434286898	26862	8	7D
0005434286899	26862	9	18A
0005433109931	26862	10	18B
0005433109935	26862	11	18C
0005433109933	26862	12	19B
0005433109927	26862	13	20B
0005433109929	26862	14	20C
0005433109934	26862	15	20D
0005433109928	26862	16	21C
0005434286919	26862	17	22C
0005435856163	25492	1	1C
0005435856161	25492	2	6C
0005435856164	25492	3	7A
0005435856162	25492	4	21D
0005435856160	25492	5	22C
0005435856165	25492	6	23B
0005434273060	26667	1	1B
0005434273059	26667	2	4A
0005434272175	26667	3	18A
0005434273061	26667	4	19B
0005434272174	26667	5	20A
0005435314797	19083	1	1A
0005434520131	19083	2	3B
0005435314788	19083	3	3C
0005435314796	19083	4	4A
0005435314792	19083	5	5B
0005435314794	19083	6	6A
0005435314798	19083	7	6C
0005435314793	19083	8	7B
0005435314800	19083	9	7C
0005435314799	19083	10	18C
0005435314801	19083	11	19A
0005434520136	19083	12	19D
0005435314791	19083	13	20B
0005435314789	19083	14	20C
0005435314790	19083	15	22D
0005435314795	19083	16	23B
0005433874315	7780	1	1D
0005433874316	7780	2	2A
0005433874310	7780	3	2B
0005433874318	7780	4	3B
0005433874312	7780	5	6C
0005433874313	7780	6	19A
0005433874311	7780	7	19C
0005433874319	7780	8	20B
0005433874309	7780	9	21B
0005433874314	7780	10	21D
0005433874317	7780	11	22B
0005433874308	7780	12	23B
0005433874303	32636	1	18B
0005433874293	32636	2	22D
0005433868027	4772	1	1A
0005433868047	4772	2	1B
0005433868029	4772	3	1C
0005433868014	4772	4	1D
0005433868048	4772	5	2A
0005433868050	4772	6	2C
0005433868045	4772	7	2D
0005433868024	4772	8	3A
0005433868042	4772	9	3B
0005433868043	4772	10	3C
0005433868051	4772	11	3D
0005433868046	4772	12	4B
0005433868016	4772	13	4C
0005433868018	4772	14	5A
0005433868052	4772	15	4D
0005433868053	4772	16	5B
0005433868034	4772	17	5C
0005433868039	4772	18	5D
0005433868020	4772	19	6A
0005433868040	4772	20	6B
0005433868049	4772	21	6C
0005433868035	4772	22	6D
0005433868012	4772	23	7A
0005433868013	4772	24	7B
0005433868026	4772	25	7C
0005433868017	4772	26	7D
0005433868044	4772	27	18A
0005433868032	4772	28	18B
0005433868028	4772	29	18C
0005433868037	4772	30	18D
0005433868019	4772	31	19A
0005433868021	4772	32	19B
0005433868023	4772	33	19D
0005433868025	4772	34	20A
0005433868033	4772	35	20B
0005433868041	4772	36	21A
0005433868015	4772	37	21B
0005433868036	4772	38	21C
0005433868038	4772	39	22A
0005433868030	4772	40	22C
0005433868031	4772	41	22D
0005433868022	4772	42	23A
0005435860450	32567	1	1A
0005433867730	32567	2	2C
0005433867794	32567	3	2D
0005435860452	32567	4	5A
0005433867731	32567	5	5D
0005433867736	32567	6	6A
0005435860451	32567	7	6B
0005435860453	32567	8	7C
0005433867765	32567	9	18B
0005433867772	32567	10	19B
0005433867735	32567	11	19D
0005433867729	32567	12	20B
0005433867826	32567	13	21A
0005433867754	32567	14	22D
0005433867771	32567	15	23A
0005434663268	3408	1	1A
0005434663277	3408	2	1C
0005434663266	3408	3	2A
0005434663265	3408	4	3D
0005434461625	3408	5	4D
0005434461624	3408	6	5D
0005434461626	3408	7	6C
0005434663264	3408	8	7A
0005434663273	3408	9	7B
0005434461627	3408	10	7C
0005434663267	3408	11	19B
0005434663275	3408	12	20A
0005434663263	3408	13	20B
0005434663276	3408	14	20C
0005434663274	3408	15	21C
0005434663269	3408	16	21D
0005434663270	3408	17	22B
0005434663272	3408	18	22C
0005434663271	3408	19	22D
0005435911373	12494	1	1A
0005434663185	12494	2	2B
0005435911371	12494	3	2D
0005434663175	12494	4	3A
0005435911375	12494	5	3B
0005435911376	12494	6	3D
0005434460467	12494	7	5C
0005434663195	12494	8	5D
0005434663196	12494	9	6D
0005435911374	12494	10	7A
0005435911372	12494	11	7B
0005434663176	12494	12	7C
0005434663169	12494	13	7D
0005434663197	12494	14	18A
0005434663178	12494	15	19B
0005434663170	12494	16	19D
0005434663186	12494	17	20B
0005435911377	12494	18	21B
0005434663171	12494	19	21C
0005435911370	12494	20	23A
0005435860453	14530	1	1A
0005433867771	14530	2	2B
0005433867729	14530	3	3B
0005435860450	14530	4	4C
0005435860452	14530	5	5D
0005433867826	14530	6	6A
0005433867765	14530	7	7C
0005433867731	14530	8	18B
0005433867736	14530	9	19C
0005433867772	14530	10	20D
0005433867735	14530	11	21A
0005433867754	14530	12	21B
0005435860451	14530	13	21C
0005433867730	14530	14	22A
0005433867794	14530	15	22B
0005433867994	32680	1	1A
0005433867982	32680	2	1B
0005433868010	32680	3	1C
0005433867998	32680	4	1D
0005433867976	32680	5	2A
0005433867983	32680	6	2B
0005433867974	32680	7	2C
0005433867990	32680	8	2D
0005433867986	32680	9	3A
0005433867989	32680	10	3C
0005433867970	32680	11	3D
0005433867996	32680	12	4A
0005433867999	32680	13	4B
0005433867992	32680	14	4C
0005433867978	32680	15	5A
0005433868003	32680	16	5B
0005433868005	32680	17	5C
0005433867985	32680	18	5D
0005433868004	32680	19	6A
0005433867993	32680	20	6B
0005433868011	32680	21	6D
0005433867979	32680	22	7A
0005433867977	32680	23	7B
0005433868001	32680	24	7C
0005433868000	32680	25	7D
0005433867991	32680	26	18A
0005433867975	32680	27	18B
0005433868006	32680	28	18C
0005433867973	32680	29	18D
0005433868002	32680	30	19A
0005433867984	32680	31	19B
0005433867988	32680	32	19C
0005433868009	32680	33	19D
0005433867972	32680	34	20A
0005433867980	32680	35	20C
0005433867987	32680	36	21B
0005433867997	32680	37	21D
0005433867995	32680	38	22B
0005433868007	32680	39	22C
0005433868008	32680	40	22D
0005433867981	32680	41	23A
0005433867971	32680	42	23B
0005432798993	12113	1	1C
0005432798970	12113	2	2C
0005432799000	12113	3	4A
0005432798964	12113	4	4B
0005432798992	12113	5	6C
0005432798965	12113	6	7A
0005432798966	12113	7	7C
0005432799043	12113	8	19B
0005432798991	12113	9	19C
0005432799010	12113	10	21B
0005432799044	12113	11	23B
0005432799146	14834	1	1A
0005432799148	14834	2	1B
0005432799143	14834	3	1C
0005432799142	14834	4	1D
0005432799127	14834	5	2C
0005432799134	14834	6	2D
0005432799147	14834	7	3A
0005432799153	14834	8	3B
0005432799136	14834	9	3C
0005432799135	14834	10	3D
0005432799151	14834	11	5B
0005432799149	14834	12	6C
0005432799141	14834	13	6D
0005432799126	14834	14	7C
0005432799133	14834	15	7D
0005432799137	14834	16	18A
0005432799128	14834	17	18B
0005432799129	14834	18	18C
0005432799139	14834	19	18D
0005432799131	14834	20	19A
0005432799138	14834	21	19C
0005432799144	14834	22	20A
0005432799150	14834	23	20C
0005432799145	14834	24	20D
0005432799132	14834	25	21D
0005432799152	14834	26	22A
0005432799130	14834	27	22D
0005432799140	14834	28	23A
0005432799154	14834	29	23B
0005434407143	7070	1	1A
0005434407091	7070	2	1C
0005434407103	7070	3	1F
0005434407112	7070	4	2C
0005434407099	7070	5	2A
0005434407088	7070	6	2F
0005434407145	7070	7	3D
0005432153864	7070	8	4C
0005434407120	7070	9	4B
0005434299332	7070	10	4D
0005434407123	7070	11	4F
0005434299334	7070	12	4E
0005434407130	7070	13	5A
0005434407125	7070	14	5C
0005434299324	7070	15	5F
0005434407094	7070	16	6B
0005434407122	7070	17	6A
0005434407154	7070	18	6C
0005434407126	7070	19	6D
0005434407129	7070	20	6E
0005434407117	7070	21	6F
0005432153869	7070	22	7A
0005434407137	7070	23	7C
0005434407153	7070	24	7D
0005434407142	7070	25	7F
0005434407113	7070	26	7E
0005434407136	7070	27	8A
0005432153865	7070	28	8B
0005434407116	7070	29	8E
0005434407128	7070	30	8D
0005434407098	7070	31	9C
0005434407114	7070	32	9B
0005434407108	7070	33	9D
0005432108223	7070	34	9F
0005434299333	7070	35	10B
0005434407132	7070	36	10D
0005432153867	7070	37	10C
0005434299335	7070	38	11A
0005434407146	7070	39	10E
0005434407110	7070	40	11B
0005434407135	7070	41	11D
0005434299315	7070	42	11C
0005434407148	7070	43	11E
0005434407093	7070	44	11F
0005434299319	7070	45	12A
0005434299320	7070	46	12C
0005434299328	7070	47	12B
0005434407092	7070	48	12D
0005434407102	7070	49	12E
0005434407139	7070	50	13A
0005434407119	7070	51	13B
0005434407107	7070	52	13D
0005434299321	7070	53	13C
0005434407118	7070	54	13F
0005434407111	7070	55	14A
0005434407105	7070	56	14B
0005434407141	7070	57	14F
0005434407138	7070	58	15D
0005434299326	7070	59	15E
0005432153868	7070	60	16A
0005434407149	7070	61	15F
0005434407106	7070	62	16C
0005434299317	7070	63	16B
0005434299322	7070	64	16F
0005434407121	7070	65	16E
0005434407115	7070	66	17A
0005434299331	7070	67	17D
0005432108224	7070	68	17C
0005434407100	7070	69	17E
0005434299323	7070	70	18A
0005434407147	7070	71	18E
0005434407090	7070	72	18D
0005434299316	7070	73	19A
0005434407089	7070	74	18F
0005434407152	7070	75	19B
0005434407144	7070	76	19D
0005434407109	7070	77	19C
0005434299329	7070	78	19F
0005434407133	7070	79	19E
0005434407104	7070	80	20B
0005434299330	7070	81	20A
0005434407150	7070	82	20C
0005434407095	7070	83	21B
0005434407151	7070	84	21A
0005434299325	7070	85	22A
0005434299327	7070	86	21F
0005434407101	7070	87	22B
0005434407096	7070	88	22C
0005434407131	7070	89	22D
0005434407097	7070	90	23A
0005434407124	7070	91	22F
0005432153866	7070	92	23B
0005434407127	7070	93	23C
0005434407140	7070	94	23E
0005434407134	7070	95	23D
0005434299318	7070	96	23F
0005435293121	26895	1	1C
0005434299188	26895	2	1D
0005434299166	26895	3	2F
0005435310934	26895	4	3D
0005432058339	26895	5	3F
0005435310935	26895	6	5A
0005432058338	26895	7	5B
0005435293130	26895	8	5D
0005434299216	26895	9	5F
0005434299231	26895	10	6B
0005435310932	26895	11	6F
0005435293129	26895	12	6E
0005435310931	26895	13	7A
0005434406661	26895	14	8A
0005435293127	26895	15	8E
0005434299176	26895	16	9C
0005434406693	26895	17	9B
0005434406722	26895	18	9F
0005434299240	26895	19	10D
0005434299214	26895	20	10C
0005435293125	26895	21	11A
0005434299165	26895	22	10E
0005434406675	26895	23	12B
0005434299232	26895	24	12C
0005434406747	26895	25	13A
0005435310938	26895	26	13B
0005435310939	26895	27	14C
0005434406733	26895	28	15A
0005435293128	26895	29	15D
0005434299207	26895	30	15E
0005434406716	26895	31	16A
0005434406666	26895	32	16B
0005435293126	26895	33	16E
0005435310937	26895	34	17A
0005435293122	26895	35	17D
0005435293124	26895	36	18B
0005435310936	26895	37	18A
0005434299215	26895	38	18D
0005434299252	26895	39	18E
0005435310933	26895	40	18F
0005432058337	26895	41	19C
0005435293123	26895	42	20A
0005435310930	26895	43	21D
0005435310941	26895	44	21E
0005435310940	26895	45	22B
0005434299189	26895	46	22A
0005434299213	26895	47	23C
0005432603931	6449	1	1A
0005432603950	6449	2	1B
0005432603959	6449	3	1C
0005432603938	6449	4	1D
0005432603942	6449	5	2A
0005432603956	6449	6	2C
0005432603954	6449	7	3A
0005432603962	6449	8	3B
0005432603955	6449	9	3C
0005432603949	6449	10	3D
0005434512061	6449	11	4A
0005432603945	6449	12	4B
0005432603933	6449	13	4C
0005432603940	6449	14	4D
0005432603957	6449	15	5A
0005434512066	6449	16	5B
0005434512063	6449	17	5C
0005434512065	6449	18	5D
0005432603948	6449	19	6A
0005432603927	6449	20	6B
0005432603958	6449	21	6C
0005432603953	6449	22	6D
0005432603964	6449	23	7A
0005432603939	6449	24	7C
0005432603941	6449	25	7B
0005432603952	6449	26	7D
0005434512060	6449	27	18A
0005434512064	6449	28	18B
0005432603965	6449	29	18C
0005432603944	6449	30	18D
0005432603937	6449	31	19A
0005432603932	6449	32	19B
0005432603943	6449	33	19C
0005432603946	6449	34	19D
0005432603930	6449	35	20A
0005432603951	6449	36	20B
0005432603935	6449	37	20C
0005432603929	6449	38	20D
0005434512062	6449	39	21A
0005432603934	6449	40	21B
0005432603960	6449	41	21D
0005432603963	6449	42	22A
0005432603961	6449	43	22B
0005432603926	6449	44	22C
0005432603936	6449	45	22D
0005432603947	6449	46	23A
0005432603928	6449	47	23B
0005434512022	21371	1	1D
0005432603648	21371	2	3A
0005432603685	21371	3	3C
0005432603679	21371	4	5B
0005434512023	21371	5	6B
0005432603665	21371	6	6C
0005432603674	21371	7	6D
0005432603680	21371	8	7B
0005432603647	21371	9	18A
0005432603734	21371	10	18D
0005432603673	21371	11	20D
0005432603705	21371	12	22A
0005433251154	15005	1	2F
0005433251162	15005	2	3C
0005433251176	15005	3	4C
0005433251171	15005	4	4D
0005433251174	15005	5	6C
0005433251173	15005	6	6E
0005433251172	15005	7	8D
0005433251169	15005	8	8F
0005433251175	15005	9	9C
0005433251155	15005	10	9D
0005433251159	15005	11	9F
0005433251149	15005	12	10C
0005433251152	15005	13	11C
0005433251160	15005	14	11D
0005433251163	15005	15	11F
0005433251165	15005	16	12A
0005433251156	15005	17	12C
0005433251158	15005	18	12D
0005433251150	15005	19	12F
0005433251168	15005	20	13C
0005433251151	15005	21	14A
0005433251177	15005	22	14D
0005433251153	15005	23	14F
0005433251164	15005	24	15D
0005433251161	15005	25	15E
0005433251157	15005	26	16A
0005433251179	15005	27	16F
0005433251170	15005	28	18C
0005433251167	15005	29	19A
0005433251178	15005	30	20C
0005433251166	15005	31	20F
0005433250950	25876	1	1A
0005434906698	25876	2	1C
0005433250964	25876	3	1D
0005433251005	25876	4	1F
0005434906730	25876	5	2C
0005433250963	25876	6	2F
0005434906707	25876	7	3A
0005434906746	25876	8	3C
0005434906695	25876	9	3D
0005433250997	25876	10	3F
0005434906722	25876	11	4C
0005433251004	25876	12	4D
0005434906742	25876	13	4F
0005434906699	25876	14	5C
0005434906739	25876	15	5D
0005434906724	25876	16	5E
0005434906712	25876	17	5F
0005434906697	25876	18	6C
0005434906693	25876	19	6D
0005433250957	25876	20	6E
0005433251003	25876	21	6F
0005434906731	25876	22	7A
0005434906740	25876	23	7D
0005434906727	25876	24	7E
0005434906704	25876	25	7F
0005434906735	25876	26	8A
0005434906709	25876	27	8C
0005433250949	25876	28	8D
0005434906733	25876	29	8E
0005434906711	25876	30	8F
0005434906748	25876	31	9D
0005434906728	25876	32	9E
0005434906703	25876	33	10A
0005434906732	25876	34	10D
0005433250939	25876	35	10E
0005434906738	25876	36	11A
0005434906718	25876	37	11C
0005434906721	25876	38	11E
0005434906723	25876	39	11F
0005434906701	25876	40	12A
0005434906743	25876	41	12C
0005434906706	25876	42	12D
0005434906717	25876	43	12E
0005433250928	25876	44	12F
0005434906702	25876	45	13A
0005434906749	25876	46	13C
0005434906705	25876	47	13D
0005434906720	25876	48	13E
0005434906745	25876	49	13F
0005433250986	25876	50	14D
0005434906736	25876	51	14E
0005433250989	25876	52	14F
0005434906710	25876	53	15F
0005434906744	25876	54	16A
0005434906737	25876	55	16D
0005434906719	25876	56	16C
0005434906696	25876	57	16E
0005434906708	25876	58	16F
0005433250943	25876	59	17A
0005434906694	25876	60	17D
0005434906714	25876	61	17E
0005434906747	25876	62	17F
0005434906715	25876	63	18A
0005434906734	25876	64	18C
0005434906741	25876	65	18D
0005433250938	25876	66	18E
0005434906700	25876	67	18F
0005434906725	25876	68	19A
0005434906726	25876	69	19D
0005434906716	25876	70	19E
0005434906729	25876	71	19F
0005434906713	25876	72	20A
0005433251002	25876	73	20C
0005433250927	25876	74	20E
0005432609684	22481	1	1A
0005432607506	22481	2	1B
0005432607518	22481	3	1D
0005432609679	22481	4	2C
0005432607508	22481	5	2D
0005432607522	22481	6	3C
0005432609683	22481	7	3D
0005432607513	22481	8	4B
0005432607510	22481	9	4D
0005432607512	22481	10	5A
0005432609681	22481	11	5B
0005432609686	22481	12	5D
0005432609688	22481	13	5C
0005432607519	22481	14	6B
0005432609674	22481	15	6D
0005432609685	22481	16	7A
0005432609675	22481	17	7B
0005432609678	22481	18	7D
0005432607517	22481	19	18A
0005432609687	22481	20	18B
0005432609673	22481	21	18C
0005432607521	22481	22	18D
0005432607516	22481	23	19C
0005435842312	22481	24	19D
0005432607515	22481	25	20A
0005432609677	22481	26	20B
0005432609676	22481	27	20C
0005432607514	22481	28	20D
0005432609680	22481	29	21A
0005432607509	22481	30	21B
0005432607511	22481	31	21C
0005432607520	22481	32	21D
0005432609682	22481	33	22A
0005432607507	22481	34	22C
0005432609672	22481	35	23A
0005435842313	22481	36	23B
0005432609663	31718	1	5C
0005432609662	31718	2	5D
0005432613799	31718	3	20D
0005432609667	31718	4	21A
0005433008162	14208	1	1F
0005433008154	14208	2	2A
0005433008177	14208	3	2C
0005433008151	14208	4	2D
0005433008159	14208	5	3A
0005433008148	14208	6	4A
0005433008183	14208	7	4C
0005433008182	14208	8	4E
0005433008187	14208	9	5C
0005433008178	14208	10	5E
0005433008149	14208	11	6F
0005433008169	14208	12	7A
0005433008147	14208	13	7F
0005433008168	14208	14	8C
0005433008171	14208	15	8D
0005433008193	14208	16	9A
0005433008180	14208	17	9C
0005433008158	14208	18	9D
0005433008170	14208	19	10D
0005433008161	14208	20	11A
0005433008175	14208	21	11C
0005433008156	14208	22	11D
0005433008160	14208	23	12A
0005433008191	14208	24	12C
0005433008185	14208	25	12E
0005433008163	14208	26	13A
0005433008165	14208	27	13C
0005433008155	14208	28	13D
0005433008172	14208	29	13E
0005433008166	14208	30	13F
0005433008192	14208	31	14A
0005433008150	14208	32	14C
0005433008152	14208	33	14F
0005433008188	14208	34	15C
0005433008181	14208	35	16C
0005433008157	14208	36	16D
0005433008186	14208	37	16E
0005433008174	14208	38	17A
0005433008176	14208	39	17D
0005433008179	14208	40	17E
0005433008189	14208	41	19C
0005433008173	14208	42	19D
0005433008190	14208	43	19E
0005433008184	14208	44	20A
0005433008164	14208	45	20C
0005433008167	14208	46	20D
0005433008153	14208	47	20F
0005433007856	22873	1	1F
0005433007874	22873	2	6E
0005433007823	22873	3	7F
0005433007873	22873	4	8D
0005433810508	22873	5	8E
0005433007918	22873	6	9C
0005433810509	22873	7	12C
0005433007855	22873	8	12D
0005433007825	22873	9	12E
0005433007853	22873	10	12F
0005433007919	22873	11	14E
0005433007950	22873	12	15E
0005434925466	20514	1	1A
0005434925468	20514	2	1D
0005434925455	20514	3	2C
0005434925461	20514	4	3C
0005434925440	20514	5	4A
0005434925462	20514	6	5C
0005434925458	20514	7	5D
0005434925446	20514	8	6C
0005434925439	20514	9	6D
0005434925433	20514	10	6E
0005434925470	20514	11	7A
0005434925445	20514	12	6F
0005434925435	20514	13	7C
0005434925444	20514	14	7D
0005434925441	20514	15	8C
0005434925438	20514	16	9D
0005434925448	20514	17	9E
0005434925452	20514	18	9F
0005434925443	20514	19	10A
0005434925472	20514	20	10C
0005434925436	20514	21	10F
0005434925449	20514	22	11A
0005434925467	20514	23	12A
0005434925473	20514	24	12E
0005434925460	20514	25	12F
0005434925469	20514	26	13C
0005434925450	20514	27	14C
0005434925465	20514	28	14D
0005434925464	20514	29	15A
0005434925447	20514	30	15C
0005434925454	20514	31	16C
0005434925442	20514	32	16D
0005434925434	20514	33	16F
0005434925456	20514	34	17D
0005434925437	20514	35	17E
0005434925451	20514	36	18C
0005434925463	20514	37	18D
0005434925453	20514	38	18E
0005434925457	20514	39	20D
0005434925459	20514	40	20E
0005434925471	20514	41	20F
0005435487611	15811	1	1B
0005435487610	15811	2	1C
0005435487627	15811	3	1D
0005435487624	15811	4	2A
0005435487619	15811	5	2B
0005435487626	15811	6	3D
0005435487616	15811	7	5B
0005435487623	15811	8	5C
0005435487615	15811	9	6A
0005435487609	15811	10	6C
0005435487618	15811	11	6D
0005435487617	15811	12	7A
0005435487620	15811	13	7B
0005435487628	15811	14	7D
0005435487612	15811	15	18B
0005435487625	15811	16	18D
0005435487630	15811	17	20C
0005435487613	15811	18	21C
0005435487621	15811	19	22B
0005435487614	15811	20	22C
0005435487622	15811	21	22D
0005435487629	15811	22	23B
0005435999068	19697	1	1A
0005435999048	19697	2	1B
0005435999063	19697	3	1D
0005435999060	19697	4	2A
0005435999047	19697	5	2B
0005435999053	19697	6	2C
0005435999051	19697	7	2D
0005435999057	19697	8	3A
0005435999062	19697	9	3B
0005435999052	19697	10	3D
0005435999050	19697	11	4A
0005435999049	19697	12	4B
0005435999058	19697	13	4C
0005435999056	19697	14	6A
0005435999059	19697	15	6B
0005435999066	19697	16	6C
0005435999061	19697	17	6D
0005435999065	19697	18	7B
0005435999064	19697	19	19A
0005435999055	19697	20	20C
0005435999054	19697	21	22A
0005435999067	19697	22	22D
0005435472580	6019	1	1F
0005435839163	6019	2	3A
0005435839162	6019	3	3D
0005432659686	6019	4	3C
0005435839165	6019	5	4D
0005435839177	6019	6	5C
0005435839170	6019	7	5D
0005435839169	6019	8	6B
0005435472519	6019	9	6C
0005435839183	6019	10	7B
0005435472524	6019	11	7A
0005435839160	6019	12	6F
0005435839164	6019	13	8C
0005435839174	6019	14	8D
0005435839178	6019	15	8F
0005435472541	6019	16	9B
0005432660797	6019	17	9A
0005435839172	6019	18	9E
0005435839166	6019	19	9D
0005435839176	6019	20	10D
0005435839181	6019	21	11F
0005435839185	6019	22	12F
0005432659688	6019	23	13B
0005435472525	6019	24	13E
0005435839175	6019	25	13F
0005432660798	6019	26	14C
0005435839171	6019	27	14D
0005432142220	6019	28	14E
0005435839168	6019	29	16A
0005432659687	6019	30	16C
0005435839184	6019	31	16B
0005435472514	6019	32	17A
0005435472523	6019	33	17B
0005435839167	6019	34	17C
0005432142221	6019	35	17E
0005435839187	6019	36	18A
0005435839182	6019	37	18C
0005435839179	6019	38	18E
0005435472540	6019	39	19B
0005435839180	6019	40	19D
0005435839186	6019	41	20A
0005435839159	6019	42	20D
0005435839173	6019	43	21B
0005435839161	6019	44	21F
0005432537038	18079	1	2D
0005435472641	18079	2	3C
0005435838971	18079	3	4C
0005435472631	18079	4	6D
0005432537037	18079	5	6F
0005435838978	18079	6	7D
0005435838970	18079	7	8C
0005435472642	18079	8	8D
0005435472632	18079	9	9B
0005435472638	18079	10	9D
0005432537036	18079	11	10B
0005435839042	18079	12	10C
0005435472635	18079	13	11C
0005435839014	18079	14	12E
0005435472643	18079	15	13B
0005435472645	18079	16	14B
0005435472637	18079	17	16A
0005435839013	18079	18	16C
0005435838964	18079	19	17A
0005435472630	18079	20	17D
0005435472640	18079	21	17C
0005435472644	18079	22	17F
0005435472634	18079	23	19C
0005435472636	18079	24	19F
0005435839006	18079	25	20C
0005435472633	18079	26	20E
0005435838983	18079	27	21A
0005435472639	18079	28	21F
0005433463869	17269	1	1A
0005433462722	17269	2	3G
0005433463867	17269	3	3H
0005433462715	17269	4	4G
0005433463877	17269	5	5B
0005433463872	17269	6	5A
0005433463876	17269	7	11D
0005433462711	17269	8	11H
0005433462723	17269	9	12A
0005433463870	17269	10	12G
0005433462714	17269	11	15F
0005433463865	17269	12	16G
0005433462713	17269	13	16F
0005433462710	17269	14	16H
0005433462718	17269	15	20B
0005433463864	17269	16	20D
0005433462719	17269	17	20F
0005433462717	17269	18	20G
0005433463873	17269	19	22E
0005433462712	17269	20	22G
0005433462724	17269	21	23A
0005433462720	17269	22	24B
0005433463871	17269	23	24E
0005433463875	17269	24	28F
0005433463866	17269	25	29B
0005433463868	17269	26	30G
0005433462721	17269	27	30F
0005433463878	17269	28	32H
0005433462716	17269	29	33B
0005433463874	17269	30	35B
0005433284772	23019	1	3A
0005435103851	23019	2	9A
0005433284769	23019	3	9F
0005435103850	23019	4	10E
0005435103852	23019	5	12B
0005433284771	23019	6	16F
0005433284990	32098	1	2D
0005433284978	32098	2	3C
0005433284998	32098	3	3D
0005433284988	32098	4	3F
0005433285002	32098	5	4A
0005433285000	32098	6	4C
0005433284983	32098	7	4D
0005433284984	32098	8	5D
0005433284991	32098	9	7C
0005433284976	32098	10	7B
0005433284980	32098	11	9D
0005433285004	32098	12	10D
0005433284997	32098	13	10E
0005433284996	32098	14	11F
0005433284994	32098	15	12B
0005433284993	32098	16	13D
0005433285006	32098	17	14B
0005433284999	32098	18	14D
0005433284981	32098	19	15C
0005433284986	32098	20	15F
0005433284985	32098	21	17A
0005433284995	32098	22	17D
0005433284975	32098	23	17E
0005433284977	32098	24	18A
0005433285005	32098	25	18C
0005433284987	32098	26	18D
0005433285001	32098	27	19B
0005433285003	32098	28	20D
0005433284979	32098	29	21C
0005433284992	32098	30	22A
0005433284982	32098	31	22D
0005433284989	32098	32	23A
0005432159817	30606	1	1A
0005434066321	30606	2	2D
0005434066378	30606	3	3A
0005435212949	30606	4	3D
0005432533242	30606	5	3H
0005432525886	30606	6	3G
0005435212893	30606	7	4H
0005434066376	30606	8	5H
0005432525980	30606	9	11A
0005435212904	30606	10	11D
0005435212907	30606	11	11G
0005432526132	30606	12	11K
0005435212945	30606	13	12A
0005435212939	30606	14	12D
0005432526110	30606	15	12G
0005435212914	30606	16	12K
0005432525905	30606	17	12H
0005434066362	30606	18	13A
0005435212895	30606	19	13F
0005435212936	30606	20	13E
0005435212933	30606	21	13H
0005432526011	30606	22	14E
0005432211435	30606	23	14D
0005432525941	30606	24	14G
0005435212924	30606	25	14F
0005435212912	30606	26	14K
0005435212902	30606	27	14H
0005435212930	30606	28	15E
0005432525989	30606	29	15D
0005435212897	30606	30	15G
0005434066308	30606	31	16A
0005433656641	30606	32	16C
0005432525663	30606	33	16F
0005435212889	30606	34	16E
0005432535752	30606	35	16H
0005432525988	30606	36	16G
0005434066316	30606	37	17E
0005435212931	30606	38	17G
0005432526402	30606	39	17K
0005434066360	30606	40	18D
0005434066495	30606	41	18F
0005432211432	30606	42	18E
0005432525856	30606	43	18J
0005432526222	30606	44	19F
0005432525904	30606	45	19G
0005432525799	30606	46	20C
0005432533241	30606	47	20E
0005432525775	30606	48	20J
0005435212948	30606	49	20H
0005432159812	30606	50	21A
0005432159815	30606	51	21D
0005435212940	30606	52	21E
0005435212942	30606	53	21J
0005434066365	30606	54	22B
0005432525857	30606	55	22D
0005435212919	30606	56	22H
0005432525854	30606	57	22F
0005435212920	30606	58	22K
0005435212927	30606	59	23B
0005434066324	30606	60	23A
0005432211429	30606	61	23C
0005432525887	30606	62	23G
0005435212901	30606	63	23E
0005432525956	30606	64	23H
0005432211433	30606	65	24D
0005434066496	30606	66	23K
0005432526221	30606	67	24G
0005435725555	30606	68	24F
0005433656640	30606	69	25A
0005432533256	30606	70	25D
0005432526096	30606	71	26A
0005432525651	30606	72	26G
0005435212934	30606	73	26K
0005435212885	30606	74	26J
0005434066466	30606	75	26H
0005434066494	30606	76	27B
0005435212913	30606	77	27A
0005432211434	30606	78	27D
0005435212922	30606	79	27F
0005435212946	30606	80	27H
0005432526097	30606	81	28C
0005434066336	30606	82	28E
0005435630938	30606	83	28D
0005435212910	30606	84	28G
0005432525671	30606	85	28J
0005435212935	30606	86	29B
0005432525800	30606	87	29E
0005432526032	30606	88	29G
0005432211430	30606	89	30E
0005432525776	30606	90	30H
0005434066359	30606	91	30K
0005435212903	30606	92	31F
0005435212916	30606	93	31H
0005435212888	30606	94	31G
0005435212951	30606	95	31K
0005435212941	30606	96	32B
0005432525711	30606	97	32E
0005432211431	30606	98	32G
0005432525779	30606	99	32K
0005435725554	30606	100	32H
0005435212906	30606	101	33A
0005434066312	30606	102	33D
0005434066385	30606	103	33F
0005435212944	30606	104	33G
0005432526151	30606	105	33K
0005432211428	30606	106	33J
0005432525656	30606	107	34B
0005434066400	30606	108	34F
0005435212947	30606	109	34J
0005435212900	30606	110	34H
0005435212925	30606	111	35B
0005434066337	30606	112	35C
0005434066427	30606	113	35F
0005435212890	30606	114	36A
0005432526012	30606	115	36C
0005432525885	30606	116	36B
0005432525889	30606	117	36E
0005432535746	30606	118	36D
0005432428868	30606	119	36G
0005432525688	30606	120	36J
0005434066386	30606	121	36H
0005432525763	30606	122	37B
0005432159814	30606	123	37A
0005432525761	30606	124	37C
0005435212887	30606	125	37F
0005432525703	30606	126	37J
0005432525639	30606	127	38A
0005432525650	30606	128	37K
0005435212937	30606	129	38J
0005434066487	30606	130	39A
0005435212894	30606	131	38K
0005435212917	30606	132	39D
0005434066424	30606	133	39C
0005432525974	30606	134	39F
0005435212884	30606	135	39E
0005432211427	30606	136	40A
0005435212892	30606	137	40E
0005432525780	30606	138	40D
0005432535751	30606	139	40F
0005432159816	30606	140	40K
0005432525638	30606	141	40J
0005433656638	30606	142	40H
0005432525977	30606	143	41D
0005432525864	30606	144	41C
0005432526313	30606	145	41G
0005434066379	30606	146	41F
0005432525851	30606	147	42A
0005434066374	30606	148	41K
0005432525940	30606	149	42C
0005435212896	30606	150	42B
0005435212891	30606	151	42E
0005435212923	30606	152	42F
0005432525721	30606	153	42J
0005432525843	30606	154	43B
0005432525698	30606	155	43A
0005432537022	30606	156	43C
0005435212909	30606	157	43F
0005435212926	30606	158	43E
0005432526289	30606	159	43G
0005432525979	30606	160	43K
0005435212928	30606	161	44C
0005435212938	30606	162	44B
0005435212915	30606	163	44E
0005435725553	30606	164	44F
0005435212899	30606	165	44J
0005435212898	30606	166	45D
0005435212943	30606	167	45B
0005435212918	30606	168	45E
0005432526044	30606	169	45J
0005435212905	30606	170	46A
0005432159813	30606	171	46E
0005434066353	30606	172	46G
0005435212932	30606	173	46F
0005432526401	30606	174	46J
0005435212929	30606	175	46H
0005434066380	30606	176	47A
0005435630940	30606	177	46K
0005434066486	30606	178	47E
0005432525995	30606	179	47D
0005432428873	30606	180	47C
0005432428872	30606	181	47F
0005432533257	30606	182	48A
0005432526150	30606	183	47K
0005432525760	30606	184	48C
0005432525771	30606	185	48D
0005435212921	30606	186	48H
0005432525689	30606	187	48G
0005432525808	30606	188	48F
0005435212950	30606	189	49C
0005435212911	30606	190	48K
0005435212886	30606	191	49E
0005435212908	30606	192	49D
0005434066375	30606	193	49G
0005435725556	30606	194	49F
0005432525839	30606	195	50E
0005432525682	30606	196	50D
0005432526054	30606	197	50F
0005432525741	30606	198	50H
0005433656639	30606	199	51F
0005435630939	30606	200	51E
0005435652315	24872	1	1A
0005433367534	24872	2	1C
0005435652311	24872	3	1F
0005433367537	24872	4	2A
0005433367563	24872	5	3F
0005435652310	24872	6	4A
0005435652286	24872	7	4D
0005433367551	24872	8	4E
0005435652293	24872	9	4F
0005433367527	24872	10	5C
0005433367543	24872	11	5D
0005433367546	24872	12	5F
0005433367526	24872	13	6D
0005435652314	24872	14	6F
0005433367561	24872	15	7C
0005433367528	24872	16	7D
0005433367559	24872	17	7E
0005435652266	24872	18	7F
0005435652281	24872	19	8A
0005433367525	24872	20	8C
0005433367541	24872	21	8D
0005435652285	24872	22	9C
0005433367556	24872	23	9D
0005433367532	24872	24	10D
0005433367536	24872	25	10E
0005433367535	24872	26	10F
0005435652309	24872	27	11A
0005435652312	24872	28	11C
0005435652265	24872	29	11D
0005433367553	24872	30	11F
0005433367558	24872	31	12A
0005433367555	24872	32	12C
0005433367562	24872	33	12E
0005433367554	24872	34	13A
0005433367557	24872	35	13C
0005433367550	24872	36	13D
0005433367544	24872	37	13E
0005435652291	24872	38	13F
0005435652308	24872	39	14C
0005433367548	24872	40	15A
0005433367542	24872	41	15C
0005435652296	24872	42	15D
0005433367552	24872	43	15F
0005433367539	24872	44	16A
0005433367547	24872	45	16E
0005433367545	24872	46	17C
0005433367533	24872	47	17D
0005433367531	24872	48	17E
0005433367538	24872	49	17F
0005433367540	24872	50	18C
0005435652287	24872	51	19C
0005433367529	24872	52	19E
0005433367560	24872	53	19F
0005433367549	24872	54	20A
0005433367530	24872	55	20C
0005435652294	24872	56	20D
0005434979523	2065	1	1A
0005434979499	2065	2	1B
0005434979507	2065	3	1C
0005434979501	2065	4	1D
0005434979500	2065	5	2A
0005434979508	2065	6	2B
0005434979509	2065	7	2C
0005434979522	2065	8	2D
0005434979524	2065	9	3A
0005434979510	2065	10	3D
0005434979503	2065	11	4A
0005434979525	2065	12	4B
0005434979505	2065	13	4D
0005434979515	2065	14	5A
0005435801668	2065	15	5B
0005434979528	2065	16	5C
0005434979527	2065	17	5D
0005434979498	2065	18	6A
0005434979519	2065	19	6B
0005434979504	2065	20	7A
0005434979512	2065	21	7B
0005434979502	2065	22	18A
0005434979517	2065	23	18B
0005434979506	2065	24	19B
0005435801667	2065	25	19D
0005434979516	2065	26	20A
0005434979526	2065	27	20C
0005434979518	2065	28	21A
0005434979520	2065	29	21B
0005434979521	2065	30	22A
0005434979513	2065	31	22B
0005434979514	2065	32	22D
0005434979511	2065	33	23B
0005434979299	23578	1	2A
0005434979363	23578	2	3C
0005434979253	23578	3	3D
0005434979254	23578	4	5D
0005434979331	23578	5	6A
0005434979337	23578	6	6B
0005435801648	23578	7	18A
0005434979283	23578	8	22C
0005434979362	23578	9	23A
0005434979260	23578	10	23B
0005434952495	2628	1	1A
0005434952497	2628	2	2B
0005434952496	2628	3	6A
0005434952498	2628	4	5B
0005433256388	2629	1	2A
0005433256385	2629	2	4B
0005433256401	28239	1	1B
0005434952470	28239	2	3B
0005434952474	28239	3	4B
0005433111486	19806	1	2B
0005433111487	19806	2	3A
0005433111485	19806	3	4A
0005433111488	19806	4	4B
0005434136933	11928	1	2A
0005434136850	11928	2	2D
0005434136907	11928	3	3D
0005434136934	11928	4	4A
0005434136853	11928	5	4D
0005434136798	11928	6	4F
0005434136900	11928	7	5A
0005434136780	11928	8	6C
0005434136679	11928	9	6E
0005434136884	11928	10	7A
0005434136736	11928	11	7C
0005434136829	11928	12	7E
0005434136852	11928	13	8A
0005434136967	11928	14	8D
0005434136958	11928	15	8E
0005434136982	11928	16	9C
0005434136928	11928	17	9F
0005434136865	11928	18	10F
0005434136749	11928	19	11A
0005434136683	11928	20	11C
0005434136709	11928	21	11D
0005434136779	11928	22	11E
0005434136828	11928	23	11F
0005434137037	11928	24	12C
0005434136803	11928	25	12E
0005434136684	11928	26	12F
0005434136844	11928	27	13C
0005434136800	11928	28	13D
0005434136823	11928	29	13E
0005434136893	11928	30	13F
0005434136802	11928	31	14C
0005434136758	11928	32	14E
0005434136701	11928	33	14F
0005434136807	11928	34	15A
0005434136767	11928	35	15C
0005434136773	11928	36	15D
0005434136827	11928	37	16A
0005434136938	11928	38	16C
0005434136698	11928	39	16E
0005434136801	11928	40	17C
0005434136871	11928	41	17D
0005434136856	11928	42	17E
0005434136700	11928	43	17F
0005434136998	11928	44	18A
0005434136721	11928	45	18C
0005434136737	11928	46	18E
0005434136851	11928	47	18F
0005434136898	11928	48	19D
0005434136899	11928	49	19E
0005434136781	11928	50	19F
0005434137278	28751	1	1A
0005434137327	28751	2	1C
0005434137318	28751	3	1D
0005434137272	28751	4	1F
0005434137341	28751	5	2A
0005434137346	28751	6	2C
0005434137290	28751	7	2D
0005434137280	28751	8	2F
0005434137356	28751	9	3A
0005434137310	28751	10	3D
0005434137355	28751	11	3F
0005434137321	28751	12	4A
0005434137284	28751	13	4C
0005434137332	28751	14	4D
0005434137287	28751	15	4E
0005434137297	28751	16	4F
0005434137298	28751	17	5A
0005434137315	28751	18	5C
0005434137271	28751	19	5D
0005434137289	28751	20	5E
0005434137301	28751	21	5F
0005434137320	28751	22	6A
0005434137348	28751	23	6C
0005434137274	28751	24	6D
0005434137329	28751	25	6E
0005434137347	28751	26	6F
0005434137293	28751	27	7A
0005434137352	28751	28	7C
0005434137349	28751	29	7D
0005434137312	28751	30	7E
0005434137305	28751	31	7F
0005434137325	28751	32	8A
0005434137326	28751	33	8C
0005434137353	28751	34	8D
0005434137299	28751	35	8E
0005434137309	28751	36	9A
0005434137317	28751	37	9C
0005434137350	28751	38	9D
0005434137330	28751	39	9E
0005434137337	28751	40	9F
0005434137294	28751	41	10A
0005434137316	28751	42	10C
0005434137269	28751	43	10E
0005434137268	28751	44	10F
0005434137291	28751	45	11A
0005434137351	28751	46	11C
0005434137288	28751	47	11D
0005434137323	28751	48	11E
0005434137285	28751	49	11F
0005434137322	28751	50	12A
0005434137342	28751	51	12C
0005434137279	28751	52	12D
0005434137277	28751	53	12E
0005434137286	28751	54	12F
0005434137270	28751	55	13A
0005434137319	28751	56	13C
0005434137339	28751	57	13D
0005434137333	28751	58	13E
0005434137313	28751	59	13F
0005434137281	28751	60	14A
0005434137295	28751	61	14C
0005434137283	28751	62	14D
0005434137344	28751	63	14E
0005434137282	28751	64	14F
0005434137338	28751	65	15A
0005434137292	28751	66	15C
0005434137302	28751	67	15D
0005434137343	28751	68	15E
0005434137306	28751	69	15F
0005434137354	28751	70	16A
0005434137300	28751	71	16C
0005434137273	28751	72	16D
0005434137307	28751	73	16F
0005434137336	28751	74	17A
0005434137340	28751	75	17D
0005434137304	28751	76	17E
0005434137308	28751	77	17F
0005434137345	28751	78	18A
0005434137311	28751	79	18C
0005434137314	28751	80	18D
0005434137335	28751	81	18E
0005434137324	28751	82	18F
0005434137296	28751	83	19A
0005434137331	28751	84	19C
0005434137303	28751	85	19D
0005434137334	28751	86	19E
0005434137276	28751	87	19F
0005434137275	28751	88	20A
0005434137328	28751	89	20C
0005435259695	6790	1	1B
0005433534480	6790	2	3C
0005435259684	6790	3	3D
0005433538793	6790	4	4D
0005435259678	6790	5	5C
0005433538789	6790	6	6B
0005433538790	6790	7	7C
0005433538786	6790	8	7D
0005433538787	6790	9	18A
0005435259696	6790	10	19A
0005433538788	6790	11	19D
0005433534479	6790	12	21A
0005433538791	6790	13	21B
0005433534478	6790	14	22A
0005433538794	6790	15	22B
0005433538792	6790	16	22D
0005433538746	25035	1	2A
0005433538747	25035	2	2D
0005435259715	25035	3	6C
0005435259717	25035	4	20C
0005435259714	25035	5	22B
0005435259716	25035	6	23B
0005433511874	821	1	1B
0005433511877	821	2	3B
0005433511875	821	3	6C
0005433511871	821	4	7B
0005433511872	821	5	18D
0005432922467	821	6	20A
0005433511876	821	7	20C
0005433511870	821	8	21B
0005433511873	821	9	21C
0005432922486	16151	1	2A
0005433511818	16151	2	2C
0005433511814	16151	3	3A
0005432922488	16151	4	3B
0005432922487	16151	5	6B
0005433511813	16151	6	7C
0005433511819	16151	7	18A
0005433511839	16151	8	18C
0005432922489	16151	9	21A
0005435916121	3702	1	1A
0005435697073	3702	2	1B
0005435697077	3702	3	1C
0005435697082	3702	4	1D
0005435697094	3702	5	2C
0005435697085	3702	6	3A
0005435697100	3702	7	3B
0005435697091	3702	8	3C
0005435697092	3702	9	3D
0005434950488	3702	10	4A
0005435697087	3702	11	4B
0005435916123	3702	12	4D
0005435697097	3702	13	5A
0005435697081	3702	14	5B
0005435697101	3702	15	5C
0005435697088	3702	16	6A
0005435697083	3702	17	6B
0005435697093	3702	18	6C
0005435697099	3702	19	6D
0005435697096	3702	20	7A
0005435697076	3702	21	7C
0005435697084	3702	22	7D
0005435697078	3702	23	18A
0005434950489	3702	24	18B
0005435697074	3702	25	18C
0005435697090	3702	26	18D
0005435697086	3702	27	19A
0005435916124	3702	28	19D
0005435916120	3702	29	20A
0005435697095	3702	30	20B
0005435697080	3702	31	20C
0005435934993	3702	32	21A
0005434950487	3702	33	21B
0005435697098	3702	34	21D
0005435697079	3702	35	22A
0005435697089	3702	36	22B
0005435697075	3702	37	22C
0005434950486	3702	38	23A
0005435916141	16290	1	1B
0005434950452	16290	2	3B
0005435696905	16290	3	3C
0005435696846	16290	4	4C
0005435696856	16290	5	4D
0005435935014	16290	6	5C
0005435696875	16290	7	6D
0005435916142	16290	8	7B
0005435696904	16290	9	7D
0005435696924	16290	10	18A
0005434950456	16290	11	18B
0005435935015	16290	12	18D
0005435696934	16290	13	19A
0005435696874	16290	14	20A
0005435696978	16290	15	20B
0005435696977	16290	16	23A
0005434606794	3975	1	1A
0005434604868	3975	2	1B
0005434606797	3975	3	1D
0005432607528	3975	4	2B
0005433519415	3975	5	2D
0005432609696	3975	6	3B
0005433519418	3975	7	3C
0005433519414	3975	8	3D
0005432609695	3975	9	4B
0005435842315	3975	10	4C
0005433519417	3975	11	5D
0005432607529	3975	12	6A
0005432609694	3975	13	6C
0005432607530	3975	14	7B
0005434604867	3975	15	7C
0005433519416	3975	16	18D
0005434604866	3975	17	19C
0005434606795	3975	18	20A
0005434604865	3975	19	20C
0005435842316	3975	20	21A
0005434606796	3975	21	21C
0005432609692	3975	22	21D
0005432609693	3975	23	22D
0005433519382	22089	1	1B
0005432609662	22089	2	2A
0005432613799	22089	3	2C
0005432609667	22089	4	2D
0005433519383	22089	5	3B
0005433519378	22089	6	3D
0005432609663	22089	7	4D
0005435628696	697	1	1A
0005435628697	697	2	2A
0005435628698	697	3	3A
0005435628699	697	4	3B
0005433348894	697	5	6A
0005433348939	15904	1	1A
0005433348938	15904	2	1B
0005433348937	15904	3	2A
0005433348936	15904	4	3A
0005433348941	15904	5	3B
0005433348940	15904	6	4A
0005433348935	15904	7	4B
0005433348934	15904	8	5A
0005434445223	17191	1	1A
0005434446496	17191	2	4A
0005434446497	17191	3	4B
0005434446495	17191	4	5A
0005433159295	17591	1	1A
0005433159292	17591	2	1B
0005433159293	17591	3	5B
0005433159294	17591	4	6A
0005435132782	7884	1	1C
0005435132789	7884	2	1D
0005435132787	7884	3	4C
0005435132783	7884	4	5D
0005435132781	7884	5	6C
0005435132786	7884	6	18C
0005435132788	7884	7	19B
0005435132785	7884	8	20B
0005435132791	7884	9	21B
0005435132784	7884	10	22A
0005435132790	7884	11	22C
0005435383101	33071	1	1C
0005435132709	33071	2	3B
0005435383100	33071	3	3C
0005435132710	33071	4	4C
0005435383103	33071	5	6B
0005435383102	33071	6	6D
0005435383099	33071	7	18C
0005435132758	33071	8	19A
0005435132708	33071	9	20B
0005435132698	33071	10	21B
0005435811030	4420	1	4D
0005435811024	4420	2	6E
0005435938843	4420	3	9E
0005435811031	4420	4	10E
0005435811027	4420	5	11D
0005435811025	4420	6	12C
0005435811022	4420	7	15A
0005435811026	4420	8	15E
0005435811028	4420	9	17B
0005435811029	4420	10	17F
0005435811023	4420	11	21C
0005435938862	29448	1	4D
0005435938861	29448	2	8B
0005435810989	29448	3	9B
0005435938860	29448	4	10F
0005435938863	29448	5	14E
0005435938864	29448	6	16C
0005435810985	29448	7	20A
0005435810986	29448	8	20E
0005435160200	7518	1	1A
0005435160204	7518	2	1B
0005435390116	7518	3	1C
0005435160196	7518	4	1D
0005435160198	7518	5	4B
0005435390133	7518	6	4C
0005435390135	7518	7	5B
0005435390118	7518	8	5C
0005435390136	7518	9	6A
0005435160199	7518	10	7A
0005435160202	7518	11	7D
0005435160203	7518	12	18D
0005435160195	7518	13	19D
0005435160205	7518	14	20C
0005435390122	7518	15	20D
0005435160201	7518	16	21C
0005435160197	7518	17	22B
0005435160111	29581	1	1A
0005435160116	29581	2	1B
0005435160126	29581	3	1C
0005435390181	29581	4	1D
0005435390173	29581	5	2B
0005435390178	29581	6	3A
0005435390179	29581	7	3D
0005435160141	29581	8	5C
0005435390177	29581	9	6B
0005435160119	29581	10	7A
0005435160120	29581	11	7C
0005435390180	29581	12	18A
0005435160136	29581	13	18D
0005435160127	29581	14	19B
0005435160110	29581	15	19D
0005435390174	29581	16	20C
0005435160128	29581	17	20D
0005435390176	29581	18	21D
0005435390175	29581	19	22A
0005432398132	18456	1	1A
0005435178481	18456	2	3A
0005432398149	18456	3	3B
0005432394033	18456	4	4A
0005432394039	18456	5	5B
0005435178480	18456	6	6A
0005432400090	27172	1	1B
0005432400088	27172	2	1A
0005432398157	27172	3	2A
0005432400086	27172	4	2B
0005432400089	27172	5	3A
0005432400087	27172	6	3B
0005435178471	27172	7	4A
0005432398159	27172	8	4B
0005432398161	27172	9	5B
0005432398158	27172	10	6A
0005432398160	27172	11	6B
0005434503786	6541	1	1D
0005434503810	6541	2	1F
0005434503798	6541	3	2D
0005434503821	6541	4	3C
0005434503807	6541	5	3F
0005434503812	6541	6	4C
0005434503814	6541	7	4E
0005434503785	6541	8	5A
0005434503805	6541	9	5C
0005435103864	6541	10	5D
0005434503790	6541	11	5F
0005434503817	6541	12	6D
0005434503794	6541	13	6F
0005434503801	6541	14	7A
0005434503788	6541	15	7D
0005434503804	6541	16	7E
0005434503815	6541	17	8C
0005434503787	6541	18	8D
0005434503792	6541	19	8E
0005434503811	6541	20	9A
0005434503795	6541	21	9C
0005434503808	6541	22	9E
0005434503796	6541	23	9F
0005434503793	6541	24	11C
0005435103866	6541	25	11E
0005435103863	6541	26	11F
0005434503802	6541	27	12C
0005434503789	6541	28	12E
0005434503818	6541	29	12F
0005434503797	6541	30	13A
0005434503822	6541	31	14C
0005435103862	6541	32	15C
0005434503813	6541	33	15D
0005434503783	6541	34	15F
0005434503784	6541	35	16A
0005434503806	6541	36	17D
0005434503819	6541	37	17F
0005434503803	6541	38	18A
0005434503791	6541	39	18D
0005434503816	6541	40	19C
0005434503809	6541	41	19D
0005434503820	6541	42	19E
0005434503799	6541	43	20A
0005435103865	6541	44	20E
0005434503800	6541	45	20F
0005434503478	22638	1	1C
0005434503571	22638	2	2A
0005434503477	22638	3	2D
0005434503614	22638	4	9D
0005434503572	22638	5	10F
0005434503613	22638	6	12C
0005434503469	22638	7	15C
0005434503463	22638	8	16D
0005434503464	22638	9	20D
0005435800077	21307	1	1A
0005435800078	21307	2	2B
0005435800081	21307	3	21D
0005435652621	1646	1	1A
0005433367302	1646	2	1C
0005435652642	1646	3	1D
0005435652647	1646	4	2A
0005433367281	1646	5	2F
0005435652659	1646	6	3A
0005433367330	1646	7	3C
0005435652651	1646	8	3F
0005435652650	1646	9	4A
0005435652655	1646	10	4C
0005433367300	1646	11	4D
0005435652622	1646	12	5A
0005435652644	1646	13	5C
0005433367287	1646	14	5E
0005435652635	1646	15	5F
0005435652648	1646	16	6D
0005433367262	1646	17	6E
0005433367253	1646	18	6F
0005435652634	1646	19	7A
0005435652661	1646	20	7C
0005435652641	1646	21	7E
0005435652665	1646	22	7F
0005435652645	1646	23	8C
0005433367272	1646	24	8D
0005435652662	1646	25	8E
0005435652654	1646	26	8F
0005433367273	1646	27	9A
0005433367362	1646	28	9C
0005433367316	1646	29	9E
0005435652658	1646	30	9F
0005433367274	1646	31	10A
0005433367301	1646	32	10C
0005433367391	1646	33	10D
0005435652629	1646	34	11A
0005433367267	1646	35	11C
0005433367288	1646	36	11D
0005435652652	1646	37	11E
0005435652643	1646	38	11F
0005433367245	1646	39	12A
0005435652668	1646	40	12C
0005435652663	1646	41	12D
0005435652632	1646	42	12E
0005433367230	1646	43	12F
0005433367225	1646	44	13A
0005433367361	1646	45	13C
0005435652626	1646	46	13D
0005435652640	1646	47	13E
0005433367393	1646	48	13F
0005435652657	1646	49	14A
0005435652664	1646	50	14C
0005433367231	1646	51	14D
0005435652631	1646	52	14E
0005433367240	1646	53	15A
0005435652628	1646	54	15C
0005435652625	1646	55	15D
0005435652656	1646	56	15E
0005435652639	1646	57	16C
0005435652667	1646	58	16D
0005435652660	1646	59	16E
0005435652636	1646	60	17A
0005435652666	1646	61	17C
0005433367331	1646	62	17D
0005433367226	1646	63	17E
0005433367392	1646	64	17F
0005435652638	1646	65	18A
0005435652623	1646	66	18C
0005435652630	1646	67	18E
0005435652649	1646	68	18F
0005435652624	1646	69	19A
0005435652627	1646	70	19C
0005435652669	1646	71	19E
0005435652633	1646	72	19F
0005435652646	1646	73	20C
0005435652653	1646	74	20E
0005435652637	1646	75	20F
0005433367547	21709	1	2A
0005435652285	21709	2	2C
0005435652310	21709	3	2D
0005433367554	21709	4	3F
0005433367563	21709	5	4C
0005433367544	21709	6	4D
0005433367533	21709	7	4F
0005433367550	21709	8	4E
0005435652293	21709	9	5A
0005433367548	21709	10	5C
0005435652286	21709	11	5F
0005433367549	21709	12	6A
0005435652265	21709	13	6E
0005433367538	21709	14	6F
0005435652294	21709	15	7A
0005433367532	21709	16	8A
0005433367534	21709	17	8D
0005433367559	21709	18	8E
0005435652312	21709	19	9A
0005435652315	21709	20	9E
0005435652291	21709	21	10A
0005433367541	21709	22	10C
0005435652287	21709	23	10E
0005433367562	21709	24	10F
0005433367552	21709	25	11D
0005435652311	21709	26	11E
0005433367543	21709	27	12A
0005433367545	21709	28	12F
0005433367556	21709	29	13A
0005433367542	21709	30	13C
0005433367540	21709	31	13F
0005433367526	21709	32	14D
0005433367558	21709	33	14E
0005433367530	21709	34	14F
0005433367546	21709	35	15C
0005433367537	21709	36	15D
0005433367527	21709	37	16A
0005433367539	21709	38	16C
0005433367560	21709	39	16D
0005433367528	21709	40	16E
0005435652309	21709	41	16F
0005433367536	21709	42	17C
0005435652314	21709	43	17D
0005433367553	21709	44	17E
0005435652266	21709	45	17F
0005433367535	21709	46	18A
0005433367531	21709	47	18C
0005433367561	21709	48	18D
0005433367525	21709	49	18E
0005433367551	21709	50	18F
0005435652296	21709	51	19A
0005435652308	21709	52	19C
0005435652281	21709	53	19E
0005433367555	21709	54	19F
0005433367557	21709	55	20C
0005433367529	21709	56	20E
0005433985543	4168	1	1D
0005433985530	4168	2	1F
0005433985533	4168	3	2C
0005433985531	4168	4	2D
0005433985534	4168	5	3A
0005433985527	4168	6	3F
0005433985537	4168	7	4D
0005433985525	4168	8	4F
0005433985529	4168	9	5C
0005433985518	4168	10	5D
0005433985550	4168	11	5F
0005433985523	4168	12	6A
0005433985545	4168	13	6D
0005433985556	4168	14	7A
0005433985517	4168	15	7E
0005433985526	4168	16	8A
0005433985521	4168	17	8D
0005433985520	4168	18	8E
0005433985548	4168	19	8F
0005433985558	4168	20	9F
0005433985554	4168	21	10A
0005433985540	4168	22	10F
0005433985553	4168	23	11C
0005433985535	4168	24	11D
0005433985552	4168	25	11E
0005433985542	4168	26	12A
0005433985528	4168	27	12D
0005433985532	4168	28	13F
0005433985539	4168	29	14D
0005433985557	4168	30	15C
0005433985555	4168	31	15D
0005433985544	4168	32	15E
0005433985541	4168	33	15F
0005433985546	4168	34	16D
0005433985524	4168	35	18A
0005435788748	4168	36	18C
0005433985549	4168	37	18F
0005433985522	4168	38	19A
0005433985538	4168	39	19C
0005433985547	4168	40	19D
0005433985551	4168	41	19E
0005433985536	4168	42	20A
0005433985519	4168	43	20E
0005435788736	25683	1	2A
0005433985288	25683	2	3C
0005433985203	25683	3	4D
0005433985190	25683	4	5D
0005433985128	25683	5	5E
0005433985124	25683	6	6C
0005433985136	25683	7	6F
0005433985125	25683	8	7C
0005433985130	25683	9	7E
0005433985248	25683	10	7F
0005433985133	25683	11	8D
0005433985177	25683	12	9A
0005433985204	25683	13	11C
0005433985270	25683	14	11D
0005433985129	25683	15	12C
0005433985247	25683	16	13F
0005433985175	25683	17	14D
0005433985224	25683	18	14E
0005433985174	25683	19	17C
0005433985230	25683	20	19C
0005433985287	25683	21	19F
0005433985229	25683	22	20A
0005435720805	21289	1	1D
0005435720806	21289	2	23A
0005434509075	1615	1	2C
0005434509079	1615	2	3A
0005433168310	1615	3	3B
0005434509080	1615	4	3D
0005434509074	1615	5	4B
0005434509077	1615	6	4D
0005434509081	1615	7	5A
0005434509078	1615	8	5D
0005434509082	1615	9	6A
0005434509083	1615	10	7B
0005434509070	1615	11	7D
0005434509076	1615	12	18B
0005434509071	1615	13	18C
0005434509084	1615	14	19D
0005434509069	1615	15	20D
0005434509073	1615	16	21D
0005434509072	1615	17	22A
0005433168299	1615	18	22C
0005432869467	17825	1	2A
0005432655337	17825	2	4E
0005432665238	17825	3	5C
0005432655336	17825	4	6F
0005434151679	17825	5	7A
0005432869472	17825	6	7E
0005432869468	17825	7	8A
0005434151678	17825	8	9C
0005432666354	17825	9	10A
0005432659674	17825	10	12A
0005432869469	17825	11	12D
0005432657398	17825	12	12E
0005432869466	17825	13	14C
0005432869471	17825	14	15E
0005432869465	17825	15	16E
0005432657399	17825	16	17D
0005434151680	17825	17	17E
0005432869470	17825	18	19A
0005432655335	17825	19	19F
0005432666358	17825	20	20E
0005432655400	26336	1	1D
0005432666366	26336	2	2C
0005432657415	26336	3	2D
0005432665252	26336	4	2F
0005432660795	26336	5	3D
0005432655404	26336	6	4A
0005432655407	26336	7	5D
0005432658570	26336	8	5E
0005434151657	26336	9	6C
0005432655403	26336	10	7E
0005432655405	26336	11	8D
0005432660796	26336	12	9A
0005432655408	26336	13	9D
0005432655406	26336	14	9F
0005432667433	26336	15	10C
0005432869431	26336	16	11A
0005432655401	26336	17	12E
0005432666368	26336	18	13E
0005432655402	26336	19	13F
0005432659685	26336	20	14A
0005434151654	26336	21	14E
0005432658571	26336	22	14F
0005432869416	26336	23	15F
0005432666367	26336	24	16C
0005432658568	26336	25	16D
0005432666369	26336	26	16F
0005432657416	26336	27	17A
0005432655410	26336	28	17C
0005432655409	26336	29	18A
0005432659684	26336	30	18C
0005432657417	26336	31	18E
0005432658569	26336	32	18F
0005432869415	26336	33	19D
0005432665253	26336	34	20C
0005432667432	26336	35	20D
0005432865955	25068	1	2A
0005432865949	25068	2	2C
0005432638935	25068	3	3A
0005432638916	25068	4	3D
0005432865950	25068	5	4C
0005432638934	25068	6	4F
0005432638936	25068	7	6A
0005432865948	25068	8	6D
0005432638938	25068	9	7C
0005432865956	25068	10	7E
0005432638918	25068	11	7F
0005432638949	25068	12	9F
0005432638942	25068	13	10E
0005432865954	25068	14	12E
0005432638941	25068	15	12F
0005432638917	25068	16	14C
0005432865953	25068	17	15C
0005432865945	25068	18	15D
0005432865946	25068	19	15F
0005432865957	25068	20	16E
0005432865944	25068	21	17A
0005432865951	25068	22	18A
0005432865952	25068	23	18F
0005432865947	25068	24	20F
0005433438819	3088	1	1A
0005432905021	3088	2	1F
0005432328284	3088	3	2A
0005432328291	3088	4	2D
0005432328281	3088	5	2F
0005432328310	3088	6	3A
0005432328271	3088	7	3D
0005432328298	3088	8	4A
0005433438815	3088	9	4D
0005432287142	3088	10	4E
0005432328302	3088	11	4F
0005432328282	3088	12	5A
0005433438817	3088	13	5F
0005432328283	3088	14	6D
0005432328308	3088	15	7A
0005432328276	3088	16	7D
0005432328269	3088	17	7E
0005432328273	3088	18	7F
0005432328267	3088	19	8A
0005432328274	3088	20	8C
0005432328286	3088	21	8D
0005432328297	3088	22	8E
0005433438814	3088	23	8F
0005432328293	3088	24	9A
0005432328279	3088	25	9E
0005432328290	3088	26	9F
0005432287144	3088	27	10D
0005432328305	3088	28	10F
0005432328268	3088	29	11A
0005432328280	3088	30	11C
0005433438820	3088	31	11D
0005432328292	3088	32	11E
0005432328301	3088	33	11F
0005432287141	3088	34	12A
0005433438821	3088	35	12C
0005432328307	3088	36	12F
0005432328296	3088	37	13A
0005432905022	3088	38	13C
0005432328270	3088	39	13E
0005432905036	3088	40	13F
0005433438822	3088	41	14C
0005432328294	3088	42	14D
0005432328309	3088	43	14E
0005432328299	3088	44	14F
0005432287143	3088	45	15A
0005432328277	3088	46	15C
0005432328303	3088	47	15E
0005432328285	3088	48	16A
0005432328278	3088	49	16C
0005432328287	3088	50	16D
0005432328272	3088	51	16E
0005432328312	3088	52	17A
0005432328311	3088	53	17C
0005433438818	3088	54	17E
0005432328300	3088	55	17F
0005433438816	3088	56	18A
0005432328275	3088	57	19A
0005432328306	3088	58	19C
0005432328288	3088	59	19D
0005432328295	3088	60	19E
0005432328289	3088	61	20A
0005432328266	3088	62	20C
0005432287145	3088	63	20E
0005432328304	3088	64	20F
0005433438766	31136	1	1C
0005432327938	31136	2	1F
0005433438765	31136	3	2D
0005432905073	31136	4	4C
0005432054278	31136	5	4D
0005433438783	31136	6	5E
0005432327983	31136	7	6A
0005432327984	31136	8	6E
0005432327897	31136	9	7A
0005433438780	31136	10	7E
0005433438767	31136	11	8C
0005433438782	31136	12	9D
0005432327928	31136	13	11C
0005433438771	31136	14	13A
0005432327937	31136	15	13D
0005432327936	31136	16	13F
0005433438784	31136	17	14F
0005432054277	31136	18	15D
0005432905070	31136	19	15E
0005432905075	31136	20	15F
0005432327929	31136	21	16C
0005432905074	31136	22	17D
0005432327895	31136	23	17E
0005432905072	31136	24	17F
0005433438781	31136	25	18A
0005432905071	31136	26	19D
0005432054276	31136	27	20A
0005432327948	31136	28	20C
0005434309614	6200	1	1A
0005434309623	6200	2	1C
0005434309625	6200	3	2A
0005435999098	6200	4	3A
0005434309616	6200	5	3F
0005435999102	6200	6	4A
0005435999104	6200	7	4B
0005435999100	6200	8	4D
0005435999108	6200	9	4E
0005434309612	6200	10	5B
0005434309624	6200	11	5A
0005435999105	6200	12	5E
0005435999106	6200	13	5F
0005435999099	6200	14	6A
0005435487477	6200	15	6B
0005435999110	6200	16	6E
0005432146180	6200	17	7D
0005435487512	6200	18	8F
0005435999103	6200	19	10D
0005434309618	6200	20	10C
0005435487513	6200	21	11C
0005435999111	6200	22	11F
0005434309615	6200	23	12A
0005434309622	6200	24	12C
0005434309621	6200	25	12B
0005434309617	6200	26	13A
0005434309620	6200	27	13B
0005435487478	6200	28	14C
0005434309619	6200	29	14E
0005435999096	6200	30	15F
0005435999101	6200	31	15E
0005435487514	6200	32	17C
0005434309626	6200	33	17D
0005435999094	6200	34	18B
0005435487496	6200	35	18C
0005435999097	6200	36	18F
0005435487497	6200	37	18E
0005435999095	6200	38	19E
0005435999109	6200	39	21A
0005435487472	6200	40	21B
0005434309613	6200	41	22B
0005432146181	6200	42	23D
0005435999107	6200	43	23E
0005435296999	19563	1	1C
0005435487623	19563	2	1D
0005434309538	19563	3	3C
0005434309520	19563	4	3A
0005435296996	19563	5	3F
0005435487617	19563	6	4E
0005435487613	19563	7	6C
0005435487610	19563	8	7E
0005434309528	19563	9	8D
0005434309522	19563	10	8F
0005434309526	19563	11	9C
0005435487628	19563	12	9D
0005435487620	19563	13	10B
0005435487624	19563	14	11A
0005434309527	19563	15	11B
0005435487609	19563	16	11E
0005435296995	19563	17	12A
0005434309529	19563	18	12D
0005435487626	19563	19	12E
0005435487627	19563	20	13A
0005435296993	19563	21	13D
0005435487616	19563	22	14B
0005435296998	19563	23	14E
0005435487621	19563	24	15C
0005435296994	19563	25	15B
0005435487618	19563	26	16D
0005435487622	19563	27	16C
0005435487629	19563	28	17B
0005435487614	19563	29	19B
0005435487630	19563	30	20B
0005435487611	19563	31	21B
0005435487615	19563	32	21C
0005435487612	19563	33	21F
0005434309563	19563	34	22C
0005435487625	19563	35	22E
0005435296997	19563	36	23B
0005435487619	19563	37	23F
0005435517758	1554	1	1A
0005435502117	1554	2	1D
0005435502123	1554	3	1F
0005434565789	1554	4	2A
0005435508265	1554	5	2C
0005433185970	1554	6	2F
0005433186003	1554	7	3A
0005435502125	1554	8	3C
0005435502120	1554	9	3D
0005435508258	1554	10	3F
0005435517762	1554	11	4A
0005435517755	1554	12	4C
0005435502116	1554	13	4D
0005434565795	1554	14	4E
0005435508257	1554	15	5A
0005435502114	1554	16	5C
0005435517749	1554	17	5D
0005435517753	1554	18	5E
0005434565790	1554	19	5F
0005435508264	1554	20	6A
0005435502110	1554	21	6C
0005435502119	1554	22	6E
0005433186002	1554	23	6F
0005435517752	1554	24	7A
0005435517754	1554	25	7D
0005435517759	1554	26	7E
0005433186001	1554	27	7F
0005435508259	1554	28	8C
0005435517764	1554	29	8E
0005435502108	1554	30	8F
0005435508250	1554	31	9A
0005435502109	1554	32	9C
0005435502131	1554	33	9D
0005434565798	1554	34	9E
0005435502111	1554	35	9F
0005435502112	1554	36	10A
0005435508253	1554	37	10C
0005435508252	1554	38	10E
0005435502115	1554	39	10F
0005434565797	1554	40	11C
0005435517763	1554	41	11D
0005435502122	1554	42	11F
0005434565794	1554	43	12A
0005435508262	1554	44	12C
0005435502124	1554	45	12F
0005434565791	1554	46	13C
0005435502127	1554	47	13D
0005434565788	1554	48	13E
0005434565800	1554	49	13F
0005433185991	1554	50	14A
0005435517756	1554	51	14D
0005435502130	1554	52	14E
0005435517761	1554	53	14F
0005434565793	1554	54	15A
0005434565799	1554	55	15C
0005435502128	1554	56	15D
0005434565796	1554	57	15E
0005435508251	1554	58	15F
0005435508255	1554	59	16A
0005435502129	1554	60	16D
0005432291908	1554	61	16E
0005435517760	1554	62	16F
0005435508263	1554	63	17A
0005435517757	1554	64	17C
0005435508260	1554	65	17D
0005434565792	1554	66	17E
0005433185976	1554	67	17F
0005435502118	1554	68	18A
0005435517750	1554	69	18D
0005435517751	1554	70	18E
0005435502126	1554	71	19A
0005435508261	1554	72	19C
0005432291909	1554	73	19E
0005435502121	1554	74	19F
0005435502113	1554	75	20A
0005435508256	1554	76	20C
0005435517765	1554	77	20D
0005435508254	1554	78	20F
0005435528900	20893	1	2F
0005435501970	20893	2	5A
0005433186042	20893	3	6A
0005435501985	20893	4	7D
0005435501971	20893	5	8A
0005433186041	20893	6	8F
0005435528893	20893	7	9C
0005434565741	20893	8	9F
0005435501991	20893	9	10C
0005435528882	20893	10	10D
0005433186045	20893	11	10F
0005435501951	20893	12	11D
0005433186043	20893	13	12E
0005435501945	20893	14	12F
0005433186040	20893	15	13A
0005435528908	20893	16	13C
0005433186039	20893	17	14E
0005435528899	20893	18	15D
0005434565696	20893	19	16F
0005433186046	20893	20	18E
0005434565740	20893	21	19A
0005433186044	20893	22	19F
0005435153682	3931	1	4C
0005435153681	3931	2	5C
0005435153680	3931	3	5D
0005435931549	3931	4	7A
0005435153684	3931	5	7B
0005435931550	3931	6	19D
0005435931548	3931	7	20C
0005435931536	3931	8	21A
0005435153685	3931	9	22D
0005435153683	3931	10	23A
0005435931551	3931	11	23B
0005435931569	21856	1	1A
0005435153652	21856	2	2A
0005435931568	21856	3	2D
0005435931571	21856	4	3A
0005435153628	21856	5	3D
0005435153627	21856	6	5C
0005435153626	21856	7	7D
0005435931570	21856	8	18C
0005435153635	21856	9	19B
0005435931567	21856	10	19C
0005435153651	21856	11	19D
0005435153650	21856	12	20C
0005435931566	21856	13	21D
0005435153636	21856	14	22A
0005435153637	21856	15	22B
0005432628714	7214	1	2A
0005432628715	7214	2	2B
0005435225445	7214	3	3A
0005435225466	7214	4	3B
0005432628711	7214	5	3D
0005435225450	7214	6	4A
0005432628707	7214	7	4B
0005432628713	7214	8	5B
0005432628717	7214	9	6A
0005435225464	7214	10	6B
0005435225457	7214	11	6C
0005435225459	7214	12	6D
0005435225451	7214	13	7B
0005432628712	7214	14	18A
0005432628710	7214	15	18B
0005432628706	7214	16	18D
0005432628716	7214	17	19C
0005432628721	7214	18	19D
0005432628720	7214	19	20C
0005432628708	7214	20	21A
0005432628709	7214	21	21B
0005432628719	7214	22	22C
0005432628718	7214	23	23B
0005435225512	28117	1	2B
0005432628598	28117	2	4C
0005432628634	28117	3	5A
0005435225514	28117	4	5B
0005432628625	28117	5	5C
0005432628626	28117	6	6A
0005432628633	28117	7	6B
0005432628597	28117	8	6D
0005435225515	28117	9	18A
0005435225513	28117	10	19C
0005432628636	28117	11	21B
0005432628599	28117	12	21C
0005432628635	28117	13	22D
0005435225511	28117	14	23A
0005432628621	28117	15	23B
0005434267888	8745	1	2A
0005435960016	8745	2	5C
0005435960017	8745	3	18C
0005434267914	15268	1	2A
0005434267916	15268	2	3B
0005435959987	15268	3	4D
0005434267915	15268	4	6C
0005435959989	15268	5	18A
0005435959988	15268	6	19B
0005434267917	15268	7	22B
0005432692754	1212	1	1A
0005432674998	1212	2	2A
0005432675000	1212	3	3C
0005432692756	1212	4	3A
0005432674995	1212	5	3D
0005432692769	1212	6	4D
0005432692777	1212	7	4C
0005432674989	1212	8	5A
0005432674991	1212	9	7B
0005432692751	1212	10	7A
0005432692759	1212	11	6F
0005432674997	1212	12	7E
0005432677534	1212	13	8F
0005432692772	1212	14	9B
0005432692775	1212	15	9A
0005432692749	1212	16	9D
0005432692768	1212	17	9F
0005432692771	1212	18	10B
0005432692763	1212	19	11D
0005432692758	1212	20	11C
0005432674987	1212	21	12B
0005432692762	1212	22	12A
0005432692757	1212	23	12C
0005432674999	1212	24	12F
0005432677536	1212	25	13C
0005432692779	1212	26	13D
0005432873174	1212	27	13F
0005432692764	1212	28	13E
0005432692770	1212	29	14B
0005432675001	1212	30	14C
0005432674990	1212	31	15B
0005432674996	1212	32	15C
0005432692761	1212	33	15E
0005432692765	1212	34	16A
0005432692778	1212	35	16F
0005432677533	1212	36	16E
0005432692774	1212	37	17B
0005432692750	1212	38	17F
0005432674988	1212	39	17E
0005432677535	1212	40	18B
0005432692767	1212	41	18A
0005432692755	1212	42	18E
0005432692752	1212	43	18D
0005432692748	1212	44	18F
0005432692753	1212	45	19B
0005432692766	1212	46	19D
0005432692773	1212	47	19C
0005432674994	1212	48	20D
0005432674992	1212	49	20F
0005432674993	1212	50	21A
0005432692760	1212	51	21E
0005432692776	1212	52	21D
0005432677504	17496	1	1D
0005432674917	17496	2	2A
0005432692635	17496	3	2D
0005432873224	17496	4	4D
0005432674895	17496	5	5F
0005432674882	17496	6	5D
0005432692532	17496	7	6F
0005432674871	17496	8	7A
0005432692573	17496	9	7E
0005432674875	17496	10	8C
0005432692622	17496	11	8F
0005432873228	17496	12	11E
0005432873230	17496	13	12C
0005432674881	17496	14	13A
0005432873225	17496	15	12F
0005432873227	17496	16	14A
0005432873226	17496	17	14B
0005432677506	17496	18	15D
0005432677505	17496	19	16A
0005432692531	17496	20	17F
0005432677503	17496	21	18A
0005432674890	17496	22	19A
0005432873229	17496	23	19F
0005432674938	17496	24	21E
0005434435044	1106	1	1A
0005433156606	1106	2	1C
0005434435048	1106	3	2A
0005434435042	1106	4	2C
0005434435046	1106	5	3C
0005434435037	1106	6	4A
0005434435035	1106	7	5A
0005434435038	1106	8	6D
0005434435049	1106	9	7C
0005434435039	1106	10	7D
0005433156629	1106	11	18A
0005433156607	1106	12	18C
0005434435045	1106	13	18D
0005434435034	1106	14	19A
0005433156630	1106	15	19B
0005434435036	1106	16	19C
0005434435041	1106	17	19D
0005434435047	1106	18	21D
0005434435050	1106	19	22A
0005434435043	1106	20	22B
0005434435040	1106	21	23B
0005433156669	17285	1	1D
0005434434913	17285	2	2B
0005434434960	17285	3	2C
0005433156668	17285	4	3A
0005434434934	17285	5	3C
0005433156675	17285	6	4A
0005433156670	17285	7	4C
0005433156674	17285	8	5A
0005434434917	17285	9	5D
0005433156672	17285	10	7A
0005433156671	17285	11	7D
0005434434983	17285	12	18D
0005434434984	17285	13	19A
0005433156673	17285	14	19C
0005434434935	17285	15	19D
0005433156667	17285	16	20C
0005434434920	17285	17	23B
0005435928060	4072	1	1A
0005435086766	4072	2	4A
0005435086763	4072	3	6B
0005435086765	4072	4	7A
0005435086762	4072	5	7C
0005435086768	4072	6	18A
0005435086769	4072	7	18D
0005435086764	4072	8	20B
0005435086767	4072	9	22D
0005435086721	24389	1	3D
0005435086705	24389	2	5C
0005435928099	24389	3	7D
0005435928101	24389	4	19A
0005435086704	24389	5	19C
0005435928100	24389	6	20D
0005435086720	24389	7	21C
0005435928098	24389	8	23A
0005434964067	1332	1	1C
0005434964056	1332	2	2A
0005433261390	1332	3	2C
0005434964057	1332	4	3B
0005434964066	1332	5	3G
0005434964046	1332	6	4B
0005434964033	1332	7	4C
0005434964069	1332	8	4F
0005434964035	1332	9	4H
0005434964040	1332	10	5B
0005434964032	1332	11	9A
0005434964039	1332	12	11B
0005434964063	1332	13	11E
0005433261399	1332	14	12A
0005433261391	1332	15	13D
0005433261406	1332	16	13F
0005432279252	1332	17	14A
0005434964038	1332	18	14F
0005434964044	1332	19	14G
0005434964041	1332	20	15F
0005434964061	1332	21	15H
0005434964055	1332	22	17G
0005434964037	1332	23	18E
0005434964036	1332	24	19A
0005434964045	1332	25	19E
0005434964047	1332	26	20D
0005434964070	1332	27	21G
0005433261405	1332	28	21H
0005434964058	1332	29	22F
0005434964043	1332	30	25D
0005434964048	1332	31	27F
0005434964049	1332	32	28D
0005434964064	1332	33	29F
0005434964051	1332	34	30G
0005434964053	1332	35	31E
0005434964052	1332	36	31D
0005432279251	1332	37	32B
0005434964054	1332	38	34A
0005434964059	1332	39	34F
0005434964068	1332	40	35G
0005434964034	1332	41	35H
0005433261394	1332	42	36E
0005434964050	1332	43	36D
0005434964031	1332	44	36H
0005434964042	1332	45	37B
0005433261407	1332	46	37E
0005434964060	1332	47	37H
0005432279253	1332	48	38B
0005433261398	1332	49	38E
0005434964062	1332	50	38D
0005432279250	1332	51	38G
0005434964065	1332	52	38F
0005434963923	18235	1	3A
0005433261470	18235	2	3B
0005433261471	18235	3	5H
0005434963968	18235	4	9B
0005434963912	18235	5	12F
0005434963911	18235	6	13F
0005433261474	18235	7	13H
0005433261478	18235	8	14A
0005433261467	18235	9	14D
0005433261473	18235	10	15G
0005433261465	18235	11	16D
0005434963966	18235	12	17A
0005433261463	18235	13	18E
0005433261469	18235	14	19A
0005433261466	18235	15	19F
0005434963913	18235	16	19H
0005433261468	18235	17	20B
0005434963967	18235	18	20H
0005434963900	18235	19	21F
0005433261464	18235	20	22E
0005434963919	18235	21	24F
0005433261475	18235	22	29G
0005433261477	18235	23	30E
0005434963921	18235	24	32A
0005433261476	18235	25	32B
0005433261462	18235	26	32F
0005434963920	18235	27	33F
0005434963901	18235	28	34A
0005434963914	18235	29	34F
0005433261472	18235	30	35E
0005433261479	18235	31	37G
0005433261481	18235	32	38D
0005434963984	18235	33	38H
0005433261480	18235	34	39E
0005434625879	4817	1	2C
0005435907422	4817	2	4D
0005435907449	4817	3	4E
0005434625872	4817	4	8E
0005434625876	4817	5	9A
0005434625877	4817	6	9D
0005434625874	4817	7	10D
0005435907448	4817	8	12A
0005434625871	4817	9	13D
0005433194817	4817	10	14A
0005435907421	4817	11	14E
0005434625878	4817	12	15F
0005435907444	4817	13	16C
0005434625880	4817	14	16D
0005434625875	4817	15	17E
0005434625873	4817	16	18A
0005435907436	4817	17	18F
0005435907437	4817	18	19F
0005434625815	32879	1	1C
0005434625808	32879	2	2F
0005434625800	32879	3	4A
0005435907461	32879	4	4D
0005435907464	32879	5	6C
0005435907462	32879	6	7A
0005435907460	32879	7	7F
0005434625814	32879	8	9E
0005434625844	32879	9	10D
0005435907463	32879	10	11F
0005434625807	32879	11	12A
0005435907459	32879	12	13F
0005435907458	32879	13	15C
0005434625796	32879	14	16E
0005434625799	32879	15	17E
0005434625805	32879	16	18C
0005434625813	32879	17	20F
0005435937337	13796	1	2B
0005435784750	13796	2	2D
0005432195675	13796	3	3A
0005435937336	13796	4	3B
0005435937341	13796	5	3C
0005432195674	13796	6	3D
0005435937342	13796	7	4C
0005435937343	13796	8	4D
0005435784810	13796	9	6B
0005435784748	13796	10	7A
0005435937339	13796	11	7C
0005435784749	13796	12	19B
0005435937335	13796	13	19C
0005435937334	13796	14	20A
0005435787320	13796	15	20B
0005432195673	13796	16	20C
0005435937338	13796	17	21C
0005435784747	13796	18	21D
0005435937340	13796	19	23B
0005435784991	27446	1	1A
0005435784981	27446	2	1B
0005435784985	27446	3	1C
0005435785005	27446	4	1D
0005435784977	27446	5	2A
0005435784984	27446	6	2B
0005435785007	27446	7	2D
0005435784978	27446	8	3B
0005435785008	27446	9	3C
0005435785003	27446	10	3D
0005435785001	27446	11	4B
0005435784998	27446	12	4D
0005435787331	27446	13	5A
0005435785002	27446	14	5B
0005435784979	27446	15	5D
0005435784982	27446	16	6A
0005435785009	27446	17	6B
0005435784989	27446	18	6C
0005435784993	27446	19	6D
0005432190588	27446	20	7A
0005435784996	27446	21	7B
0005435784997	27446	22	7C
0005435784983	27446	23	18A
0005435784995	27446	24	18C
0005435784986	27446	25	18D
0005435784992	27446	26	19A
0005435784987	27446	27	19B
0005435784988	27446	28	19C
0005435785000	27446	29	19D
0005435787330	27446	30	20A
0005432190590	27446	31	20B
0005435784994	27446	32	20C
0005435784999	27446	33	21A
0005435785004	27446	34	21B
0005435784980	27446	35	21D
0005435784990	27446	36	22B
0005432190587	27446	37	22C
0005432190589	27446	38	22D
0005435785010	27446	39	23A
0005435785006	27446	40	23B
0005434406892	20282	1	1A
0005434406680	20282	2	1C
0005434406822	20282	3	1D
0005434406723	20282	4	1F
0005434406724	20282	5	2A
0005434406701	20282	6	2C
0005434406809	20282	7	2D
0005435310965	20282	8	2F
0005434406664	20282	9	3C
0005435310968	20282	10	4D
0005434406748	20282	11	4F
0005434406704	20282	12	5C
0005434406686	20282	13	5D
0005434406989	20282	14	5E
0005434406669	20282	15	5F
0005435310967	20282	16	6C
0005434406681	20282	17	7A
0005434406687	20282	18	6F
0005435310957	20282	19	7D
0005435310966	20282	20	7E
0005435310958	20282	21	7F
0005435310951	20282	22	8A
0005434406823	20282	23	8C
0005435310960	20282	24	8D
0005434406668	20282	25	8E
0005434406647	20282	26	8F
0005434406646	20282	27	9C
0005434406824	20282	28	9D
0005435310955	20282	29	9E
0005435310964	20282	30	10A
0005434406639	20282	31	10D
0005435310954	20282	32	10F
0005434406665	20282	33	11C
0005435310950	20282	34	11D
0005435310952	20282	35	11F
0005435310962	20282	36	12A
0005435310949	20282	37	12D
0005432058346	20282	38	12E
0005434406667	20282	39	12F
0005435310961	20282	40	13A
0005432058344	20282	41	13C
0005435310963	20282	42	13D
0005432058347	20282	43	13E
0005435310953	20282	44	13F
0005434406825	20282	45	14A
0005434406776	20282	46	14C
0005435310956	20282	47	15E
0005434406777	20282	48	16A
0005435310959	20282	49	16C
0005434406727	20282	50	16D
0005434406728	20282	51	17A
0005434406778	20282	52	17E
0005434406682	20282	53	18E
0005434406670	20282	54	18F
0005434406645	20282	55	19A
0005434406717	20282	56	19D
0005434406694	20282	57	19E
0005434406855	20282	58	19F
0005432058345	20282	59	20C
0005434406683	20282	60	20D
0005432153874	26987	1	1C
0005434407173	26987	2	1D
0005434407194	26987	3	1F
0005434407169	26987	4	2A
0005432153873	26987	5	2C
0005434407162	26987	6	3A
0005435310838	26987	7	3C
0005434407181	26987	8	3D
0005434407156	26987	9	4A
0005434407178	26987	10	4C
0005434407190	26987	11	4D
0005434407205	26987	12	4E
0005435310850	26987	13	5C
0005434407188	26987	14	5D
0005434407172	26987	15	5E
0005434407203	26987	16	5F
0005434407155	26987	17	6A
0005434407187	26987	18	6C
0005434407167	26987	19	6D
0005432153875	26987	20	6E
0005434407170	26987	21	6F
0005434407177	26987	22	7A
0005434407207	26987	23	7C
0005434407198	26987	24	7D
0005432153877	26987	25	7E
0005434407201	26987	26	7F
0005434407206	26987	27	8A
0005434407174	26987	28	8C
0005434407158	26987	29	8D
0005434407176	26987	30	8E
0005434407171	26987	31	8F
0005435310852	26987	32	9D
0005434407217	26987	33	9E
0005432153872	26987	34	9F
0005432153870	26987	35	10C
0005434407214	26987	36	10D
0005434407184	26987	37	10E
0005434407164	26987	38	10F
0005434407196	26987	39	11C
0005434407211	26987	40	11D
0005434407163	26987	41	11E
0005434407192	26987	42	11F
0005434407166	26987	43	12A
0005434407185	26987	44	12C
0005434407159	26987	45	12D
0005434407175	26987	46	12E
0005434407189	26987	47	12F
0005435310841	26987	48	13C
0005434407197	26987	49	13D
0005434407186	26987	50	13E
0005434407161	26987	51	13F
0005434407199	26987	52	14A
0005434407179	26987	53	14C
0005434407216	26987	54	14E
0005434407210	26987	55	14F
0005435310846	26987	56	15E
0005434407193	26987	57	16A
0005434407183	26987	58	16C
0005434407204	26987	59	16D
0005434407213	26987	60	16E
0005434407168	26987	61	16F
0005434407195	26987	62	17A
0005435310851	26987	63	17C
0005434407202	26987	64	17D
0005432153871	26987	65	17E
0005435310845	26987	66	17F
0005434407208	26987	67	18A
0005434407157	26987	68	18C
0005434407200	26987	69	18E
0005434407180	26987	70	18F
0005434407160	26987	71	19A
0005434407212	26987	72	19C
0005434407209	26987	73	19D
0005435310842	26987	74	19E
0005434407165	26987	75	19F
0005432153876	26987	76	20C
0005434407182	26987	77	20D
0005434407215	26987	78	20E
0005434407191	26987	79	20F
0005432109678	5688	1	1C
0005434319250	5688	2	2A
0005434319259	5688	3	2C
0005434319263	5688	4	2D
0005433123604	5688	5	3C
0005433123640	5688	6	3F
0005434319254	5688	7	4A
0005434319261	5688	8	4D
0005433123573	5688	9	4F
0005433123576	5688	10	6F
0005434319251	5688	11	7C
0005434319262	5688	12	7D
0005433123657	5688	13	8D
0005434319253	5688	14	8E
0005433123632	5688	15	10C
0005434319260	5688	16	11F
0005432109679	5688	17	12D
0005434319257	5688	18	13E
0005434319249	5688	19	15C
0005432109677	5688	20	16C
0005434319252	5688	21	17C
0005434319258	5688	22	17D
0005433123574	5688	23	17E
0005433123567	5688	24	19A
0005434319255	5688	25	19E
0005433123641	5688	26	19F
0005433123566	5688	27	20A
0005434319256	5688	28	20D
0005433123749	15689	1	3C
0005433123744	15689	2	4E
0005433123757	15689	3	5C
0005433123738	15689	4	5F
0005433123741	15689	5	6C
0005433123740	15689	6	6D
0005433123739	15689	7	6E
0005433123743	15689	8	6F
0005434319154	15689	9	7C
0005433123755	15689	10	7F
0005433123751	15689	11	8E
0005433123746	15689	12	9F
0005433123748	15689	13	10C
0005433123745	15689	14	10F
0005434319149	15689	15	11A
0005434319148	15689	16	11C
0005433123758	15689	17	12E
0005433123754	15689	18	13A
0005433123737	15689	19	13D
0005433123742	15689	20	14F
0005433123747	15689	21	15D
0005433123759	15689	22	18A
0005433123753	15689	23	18E
0005433123752	15689	24	19F
0005433123750	15689	25	20A
0005433123756	15689	26	20D
0005435220283	24971	1	19B
0005434484286	8965	1	2B
0005434484285	8965	2	3A
0005434484288	8965	3	4A
0005434189085	8965	4	6B
0005434484291	8965	5	7B
0005434484290	8965	6	18C
0005434189084	8965	7	19A
0005434484287	8965	8	20A
0005434189079	8965	9	21C
0005434484289	8965	10	23A
0005434189078	8965	11	23B
0005434189128	16639	1	2B
0005434189127	16639	2	4C
0005434189123	16639	3	5B
0005434484238	16639	4	5C
0005434484237	16639	5	6A
0005434189124	16639	6	19A
0005434189125	16639	7	20A
0005434484239	16639	8	21B
0005434189126	16639	9	22A
0005433123739	7536	1	1A
0005433123745	7536	2	1C
0005433123740	7536	3	1D
0005433123753	7536	4	1F
0005433123743	7536	5	2C
0005433123756	7536	6	5F
0005433123742	7536	7	6D
0005433123754	7536	8	7C
0005433123758	7536	9	7D
0005433123759	7536	10	9D
0005433123752	7536	11	11A
0005433123757	7536	12	11F
0005433123737	7536	13	12F
0005433123749	7536	14	13E
0005433123744	7536	15	13F
0005433123741	7536	16	14C
0005433123751	7536	17	14D
0005433123755	7536	18	18A
0005433123750	7536	19	19C
0005433123746	7536	20	19D
0005433123738	7536	21	19E
0005433123748	7536	22	19F
0005433123747	7536	23	20F
0005433449784	7534	1	1A
0005433449763	7534	2	1C
0005432692783	7534	3	1F
0005432692799	7534	4	2A
0005432692809	7534	5	2C
0005432692781	7534	6	2D
0005432692794	7534	7	2F
0005432720656	7534	8	3A
0005432692791	7534	9	3C
0005433449779	7534	10	3D
0005432720655	7534	11	3F
0005433449765	7534	12	4A
0005433449772	7534	13	4D
0005433449764	7534	14	4E
0005432692795	7534	15	4F
0005432720662	7534	16	5A
0005432692796	7534	17	5C
0005433449766	7534	18	5D
0005432720670	7534	19	5E
0005432720672	7534	20	5F
0005433449768	7534	21	6A
0005432720660	7534	22	6C
0005432720668	7534	23	6E
0005433449780	7534	24	7A
0005432692803	7534	25	7C
0005432720650	7534	26	7D
0005432692802	7534	27	7E
0005432692798	7534	28	7F
0005432720661	7534	29	8A
0005432692785	7534	30	8D
0005432692787	7534	31	8F
0005432720671	7534	32	9A
0005432692784	7534	33	9C
0005432692792	7534	34	9E
0005433449773	7534	35	10A
0005432720667	7534	36	10C
0005432720649	7534	37	10D
0005432720664	7534	38	10E
0005433449777	7534	39	11A
0005432692806	7534	40	11C
0005433449762	7534	41	11E
0005432692786	7534	42	11F
0005432692780	7534	43	12A
0005432720653	7534	44	12C
0005433449782	7534	45	12D
0005432720652	7534	46	12E
0005432720665	7534	47	12F
0005432692800	7534	48	13A
0005432692790	7534	49	13C
0005432720675	7534	50	13E
0005432720666	7534	51	13F
0005433449771	7534	52	14A
0005432692808	7534	53	14C
0005432692797	7534	54	14D
0005433449783	7534	55	14E
0005432692805	7534	56	14F
0005432692782	7534	57	15C
0005433449778	7534	58	15D
0005432692810	7534	59	15E
0005432071546	7534	60	15F
0005432720669	7534	61	16A
0005432720651	7534	62	16C
0005433449770	7534	63	16D
0005433449776	7534	64	16E
0005433449774	7534	65	16F
0005432692807	7534	66	17C
0005432720673	7534	67	17E
0005433449781	7534	68	17F
0005433449769	7534	69	18A
0005432720657	7534	70	18C
0005432692789	7534	71	18D
0005432692793	7534	72	18E
0005432071547	7534	73	18F
0005433449775	7534	74	19A
0005432720658	7534	75	19C
0005432720654	7534	76	19D
0005432720659	7534	77	19E
0005432720663	7534	78	19F
0005432692788	7534	79	20A
0005432692801	7534	80	20C
0005432692804	7534	81	20D
0005432720674	7534	82	20E
0005433449767	7534	83	20F
0005433449632	30382	1	2C
0005433449586	30382	2	2F
0005433449594	30382	3	4E
0005432692531	30382	4	4F
0005432692532	30382	5	5E
0005433449596	30382	6	6F
0005433449597	30382	7	8E
0005432692573	30382	8	9C
0005433449642	30382	9	12C
0005433449606	30382	10	14F
0005432692622	30382	11	15E
0005433449585	30382	12	17E
0005433449693	30382	13	19D
0005432692635	30382	14	19F
0005433449633	30382	15	20C
0005433123566	30381	1	1A
0005432720448	30381	2	1C
0005433123573	30381	3	1D
0005433123604	30381	4	2A
0005432720531	30381	5	3A
0005433123640	30381	6	4C
0005432720547	30381	7	4E
0005432720569	30381	8	5D
0005432720449	30381	9	6A
0005433722165	30381	10	6C
0005432720447	30381	11	7A
0005432720482	30381	12	7C
0005432720511	30381	13	8D
0005432720497	30381	14	8E
0005432720575	30381	15	8F
0005432720483	30381	16	10A
0005433722160	30381	17	10E
0005433722162	30381	18	11E
0005433722164	30381	19	12C
0005433722158	30381	20	12E
0005432720485	30381	21	13A
0005433722166	30381	22	13D
0005432720512	30381	23	14D
0005433123641	30381	24	14E
0005432720437	30381	25	15A
0005433722163	30381	26	15E
0005433123632	30381	27	15F
0005433123567	30381	28	16F
0005433123576	30381	29	17A
0005432720484	30381	30	17F
0005433722161	30381	31	18D
0005433722159	30381	32	18F
0005433123657	30381	33	19F
0005433123574	30381	34	20D
0005433192867	1384	1	1C
0005433524945	1384	2	1F
0005432270977	1384	3	2A
0005434586368	1384	4	2F
0005434513554	1384	5	3D
0005433192811	1384	6	4C
0005434586369	1384	7	4D
0005433524943	1384	8	5A
0005434586388	1384	9	5D
0005432270978	1384	10	5E
0005433524942	1384	11	5F
0005434586381	1384	12	6C
0005434586376	1384	13	6D
0005434586392	1384	14	6F
0005434514944	1384	15	7D
0005432270979	1384	16	7E
0005434586390	1384	17	8A
0005434586373	1384	18	8C
0005433524941	1384	19	8D
0005434586383	1384	20	9D
0005434586384	1384	21	10A
0005434586371	1384	22	10C
0005434586389	1384	23	10E
0005433724765	1384	24	10F
0005433724763	1384	25	11E
0005433524939	1384	26	12D
0005434586375	1384	27	12F
0005434586391	1384	28	13C
0005433524940	1384	29	13D
0005434586386	1384	30	13E
0005434586372	1384	31	14C
0005434514942	1384	32	14D
0005432270980	1384	33	14E
0005434513556	1384	34	14F
0005433724764	1384	35	15A
0005434586387	1384	36	15D
0005433524944	1384	37	15E
0005433524938	1384	38	15F
0005434514943	1384	39	16C
0005434586377	1384	40	16D
0005433192868	1384	41	16F
0005433524936	1384	42	17A
0005434586382	1384	43	17C
0005434586385	1384	44	17E
0005434586393	1384	45	17F
0005434586374	1384	46	18A
0005434586379	1384	47	18C
0005434586370	1384	48	18E
0005434586380	1384	49	18F
0005434513555	1384	50	19D
0005433724766	1384	51	19F
0005434586378	1384	52	20A
0005433524937	1384	53	20D
0005433192928	18504	1	1C
0005434586184	18504	2	1F
0005434586261	18504	3	2A
0005434514922	18504	4	2D
0005434586166	18504	5	2F
0005432927929	18504	6	3A
0005434514927	18504	7	5A
0005433192927	18504	8	6A
0005434586185	18504	9	6E
0005434586167	18504	10	7A
0005433724725	18504	11	7D
0005432927926	18504	12	7E
0005434514928	18504	13	8E
0005432968818	18504	14	8F
0005432927930	18504	15	9A
0005434586171	18504	16	9C
0005434514923	18504	17	9E
0005433192920	18504	18	10A
0005432968819	18504	19	10D
0005433192929	18504	20	10F
0005432927928	18504	21	11A
0005432927927	18504	22	11F
0005433524846	18504	23	13C
0005434586172	18504	24	14C
0005433192923	18504	25	15A
0005433192925	18504	26	15C
0005434586183	18504	27	16A
0005434586173	18504	28	16F
0005434586186	18504	29	17C
0005432927925	18504	30	17D
0005433192931	18504	31	18C
0005434586163	18504	32	18D
0005433192924	18504	33	18E
0005433192926	18504	34	19C
0005433192922	18504	35	19E
0005433192921	18504	36	20A
0005433192930	18504	37	20E
0005434343865	11481	1	1A
0005434343867	11481	2	1B
0005434343871	11481	3	1C
0005434343852	11481	4	1D
0005434343854	11481	5	2A
0005434343872	11481	6	2C
0005434343857	11481	7	3A
0005434343862	11481	8	3B
0005434343843	11481	9	3C
0005434343861	11481	10	3D
0005435304993	11481	11	4B
0005434343849	11481	12	4C
0005434343873	11481	13	4D
0005434343868	11481	14	5A
0005434142574	11481	15	5B
0005434343860	11481	16	5C
0005434343869	11481	17	5D
0005434343870	11481	18	6A
0005434343863	11481	19	6B
0005434343842	11481	20	6D
0005434343858	11481	21	7B
0005434343850	11481	22	7C
0005434343838	11481	23	7D
0005434343859	11481	24	18A
0005434142576	11481	25	18C
0005434343853	11481	26	18D
0005434343845	11481	27	19A
0005434343840	11481	28	19B
0005434343846	11481	29	19C
0005434343847	11481	30	19D
0005434343839	11481	31	20A
0005434343844	11481	32	20B
0005434343864	11481	33	20C
0005434343866	11481	34	20D
0005434343851	11481	35	21A
0005435304994	11481	36	21B
0005434142575	11481	37	21D
0005434343841	11481	38	22A
0005434343856	11481	39	22B
0005434343848	11481	40	22D
0005434343855	11481	41	23B
0005435305000	29777	1	1A
0005434343619	29777	2	2A
0005435304119	29777	3	3C
0005434343657	29777	4	3D
0005434343658	29777	5	4A
0005434343591	29777	6	4D
0005434343592	29777	7	6A
0005434142550	29777	8	7D
0005434343642	29777	9	19A
0005435304120	29777	10	19B
0005434142543	29777	11	19C
0005434343600	29777	12	19D
0005434343607	29777	13	20C
0005435304118	29777	14	22A
0005435304121	29777	15	23B
0005435824381	1294	1	1C
0005435824375	1294	2	1D
0005435824395	1294	3	4A
0005433415439	1294	4	4C
0005435824387	1294	5	5C
0005433415433	1294	6	6F
0005433415410	1294	7	8A
0005433415388	1294	8	8C
0005435824393	1294	9	9A
0005435824398	1294	10	9D
0005435824373	1294	11	10C
0005435824376	1294	12	10D
0005433415425	1294	13	11B
0005435824380	1294	14	11C
0005435824391	1294	15	12A
0005435824388	1294	16	12D
0005435824394	1294	17	12F
0005435824384	1294	18	13A
0005433415440	1294	19	13C
0005435824378	1294	20	13F
0005435824385	1294	21	14C
0005433415401	1294	22	14B
0005435824392	1294	23	15B
0005433415378	1294	24	15A
0005435824374	1294	25	15C
0005435824389	1294	26	15F
0005435824397	1294	27	16C
0005433415424	1294	28	16D
0005435824390	1294	29	17B
0005435824382	1294	30	17A
0005432284531	1294	31	18A
0005435824399	1294	32	18B
0005432284532	1294	33	19A
0005435824379	1294	34	19D
0005433415379	1294	35	19C
0005435824386	1294	36	19F
0005435824377	1294	37	19E
0005435824372	1294	38	20B
0005435824371	1294	39	21B
0005435824396	1294	40	21A
0005435824383	1294	41	21D
0005433415518	18005	1	1D
0005433415522	18005	2	2A
0005433415514	18005	3	3F
0005435824180	18005	4	4C
0005433415524	18005	5	4F
0005433415523	18005	6	5C
0005433415512	18005	7	6B
0005435824219	18005	8	7D
0005435824210	18005	9	8B
0005433415510	18005	10	8E
0005433415511	18005	11	9C
0005433415509	18005	12	9F
0005435824198	18005	13	9E
0005433415517	18005	14	10B
0005433415515	18005	15	11A
0005435824155	18005	16	11D
0005433415521	18005	17	12B
0005433415520	18005	18	12D
0005433415516	18005	19	13F
0005433415513	18005	20	15C
0005435824156	18005	21	15E
0005435824223	18005	22	15D
0005435824220	18005	23	16C
0005435824158	18005	24	16E
0005435824222	18005	25	17B
0005433415519	18005	26	18E
0005435824211	18005	27	19C
0005434461621	12571	1	1A
0005434461623	12571	2	1B
0005434460481	12571	3	2D
0005434461627	12571	4	3A
0005434461626	12571	5	4D
0005434461625	12571	6	5B
0005434461622	12571	7	7B
0005434460480	12571	8	7A
0005434460483	12571	9	7C
0005434460478	12571	10	18A
0005434460477	12571	11	18D
0005434460482	12571	12	19C
0005434461624	12571	13	20A
0005434460479	12571	14	22A
0005432143960	5612	1	1A
0005432783287	5612	2	1C
0005432783330	5612	3	1D
0005432783309	5612	4	1F
0005432783299	5612	5	2C
0005432783327	5612	6	2F
0005432783298	5612	7	3A
0005435242458	5612	8	3D
0005432783329	5612	9	4A
0005432783305	5612	10	4C
0005432783279	5612	11	4D
0005432783297	5612	12	4E
0005432783322	5612	13	5C
0005432783334	5612	14	5D
0005432783315	5612	15	5E
0005432783331	5612	16	5F
0005432783290	5612	17	6A
0005435242416	5612	18	6C
0005432143957	5612	19	6D
0005432783320	5612	20	6E
0005432783321	5612	21	7A
0005432783310	5612	22	6F
0005432783301	5612	23	7E
0005432783300	5612	24	8A
0005432783291	5612	25	8D
0005432783323	5612	26	8E
0005432783294	5612	27	8F
0005435242409	5612	28	9A
0005432783313	5612	29	9C
0005435242391	5612	30	9D
0005432783302	5612	31	9E
0005432783307	5612	32	9F
0005432783288	5612	33	10C
0005435242468	5612	34	10D
0005432783333	5612	35	10E
0005432783311	5612	36	10F
0005435242392	5612	37	11A
0005435242408	5612	38	11D
0005432783281	5612	39	11E
0005432783318	5612	40	11F
0005432783306	5612	41	12A
0005432783312	5612	42	12C
0005432783304	5612	43	12E
0005432143956	5612	44	12F
0005432143959	5612	45	13A
0005432783295	5612	46	13C
0005432783289	5612	47	13F
0005432783326	5612	48	14A
0005432783325	5612	49	14D
0005432783303	5612	50	14E
0005432143961	5612	51	14F
0005432783332	5612	52	15A
0005432783283	5612	53	15C
0005435242424	5612	54	15D
0005432783319	5612	55	15E
0005432143958	5612	56	15F
0005432783314	5612	57	16A
0005432783317	5612	58	16C
0005432783308	5612	59	16F
0005432783292	5612	60	17A
0005432783280	5612	61	17E
0005435242388	5612	62	17F
0005432783284	5612	63	18C
0005435242425	5612	64	18D
0005432783316	5612	65	18F
0005432783296	5612	66	19A
0005432783285	5612	67	19D
0005432783286	5612	68	19E
0005432783282	5612	69	19F
0005435242410	5612	70	20C
0005432783328	5612	71	20D
0005432783324	5612	72	20E
0005432783293	5612	73	20F
0005432782871	15377	1	1F
0005435242587	15377	2	2A
0005432782845	15377	3	2C
0005435242597	15377	4	2F
0005432783092	15377	5	3A
0005432782874	15377	6	3C
0005435242589	15377	7	3D
0005435242610	15377	8	3F
0005435242603	15377	9	4A
0005435242596	15377	10	4C
0005432782901	15377	11	4E
0005435242582	15377	12	4F
0005432782992	15377	13	5A
0005435242593	15377	14	5D
0005435242598	15377	15	5E
0005432782840	15377	16	6C
0005435242583	15377	17	6F
0005435242591	15377	18	7A
0005432782900	15377	19	7C
0005435242606	15377	20	7E
0005432782898	15377	21	7F
0005432782942	15377	22	8A
0005435242602	15377	23	8C
0005435242595	15377	24	8D
0005432783010	15377	25	8F
0005432783045	15377	26	9A
0005435476704	15377	27	9C
0005432782967	15377	28	9E
0005435242600	15377	29	10C
0005432782968	15377	30	10D
0005435242594	15377	31	10E
0005432783090	15377	32	10F
0005432783009	15377	33	11D
0005435476703	15377	34	11F
0005432783044	15377	35	12D
0005435242586	15377	36	12E
0005435242585	15377	37	12F
0005435242590	15377	38	13A
0005435242607	15377	39	13C
0005435242592	15377	40	13D
0005435242599	15377	41	14D
0005432782905	15377	42	14E
0005435242608	15377	43	14F
0005432782919	15377	44	15A
0005435242609	15377	45	16A
0005432782991	15377	46	16C
0005432783091	15377	47	16D
0005435242588	15377	48	16E
0005435242605	15377	49	16F
0005432782990	15377	50	17C
0005432782883	15377	51	17D
0005435242584	15377	52	18A
0005432782938	15377	53	18D
0005435476702	15377	54	18E
0005432783011	15377	55	19A
0005432782843	15377	56	19C
0005435242604	15377	57	19D
0005435242601	15377	58	19F
0005435476701	15377	59	20F
0005432848176	4377	1	1B
0005435850781	4377	2	2A
0005435850786	4377	3	2B
0005432848179	4377	4	3A
0005432848188	4377	5	3D
0005434462770	4377	6	4A
0005434463910	4377	7	4C
0005432848182	4377	8	4D
0005432848187	4377	9	5B
0005432848186	4377	10	5C
0005432848175	4377	11	5D
0005432848184	4377	12	6A
0005432848181	4377	13	6B
0005432848185	4377	14	6D
0005432848177	4377	15	7C
0005432848180	4377	16	7D
0005432848183	4377	17	19A
0005434463909	4377	18	19C
0005435850756	4377	19	20C
0005435850785	4377	20	21D
0005432848178	4377	21	22A
0005434462771	4377	22	22C
0005435850782	4377	23	22D
0005435850826	28864	1	1A
0005435850828	28864	2	2A
0005435850831	28864	3	3A
0005432848065	28864	4	4B
0005432848093	28864	5	5B
0005435850827	28864	6	7D
0005432848096	28864	7	18A
0005432848064	28864	8	19B
0005435850824	28864	9	20B
0005435850829	28864	10	20C
0005435850825	28864	11	21C
0005435850830	28864	12	22A
0005432848063	28864	13	22B
0005434925513	6241	1	1A
0005434925515	6241	2	1C
0005433496687	6241	3	1D
0005433496699	6241	4	1F
0005434925518	6241	5	2A
0005432075199	6241	6	2C
0005434925505	6241	7	2D
0005434925517	6241	8	2F
0005434443566	6241	9	3A
0005434443559	6241	10	3C
0005434925528	6241	11	3F
0005434925531	6241	12	4A
0005434443570	6241	13	4C
0005433496678	6241	14	4D
0005434443556	6241	15	4E
0005433496683	6241	16	4F
0005433496677	6241	17	5A
0005434443569	6241	18	5C
0005434443558	6241	19	5E
0005434925522	6241	20	5F
0005433496690	6241	21	6A
0005434443571	6241	22	6C
0005432075198	6241	23	6D
0005433496691	6241	24	6E
0005433496684	6241	25	6F
0005433496702	6241	26	7C
0005433496685	6241	27	7D
0005433496695	6241	28	7F
0005433496703	6241	29	8A
0005434443562	6241	30	8C
0005434925512	6241	31	8D
0005434925511	6241	32	8E
0005434925521	6241	33	8F
0005433496686	6241	34	9A
0005434443567	6241	35	9C
0005434925524	6241	36	9D
0005433496692	6241	37	9E
0005434925509	6241	38	9F
0005433496701	6241	39	10A
0005434925503	6241	40	10C
0005434925504	6241	41	10D
0005432075200	6241	42	11A
0005434925516	6241	43	11C
0005434925520	6241	44	11D
0005434443557	6241	45	11E
0005434925526	6241	46	12A
0005433496680	6241	47	12C
0005434443563	6241	48	12D
0005433496681	6241	49	12E
0005434443561	6241	50	12F
0005434925514	6241	51	13A
0005433496693	6241	52	13C
0005434925525	6241	53	13D
0005434443560	6241	54	13E
0005432075197	6241	55	13F
0005433496689	6241	56	14C
0005434443564	6241	57	14D
0005434443565	6241	58	14E
0005434925508	6241	59	14F
0005434925530	6241	60	15A
0005434443568	6241	61	15E
0005434925506	6241	62	16A
0005433496675	6241	63	16C
0005433496697	6241	64	16D
0005434925510	6241	65	16E
0005434925532	6241	66	16F
0005433496679	6241	67	17C
0005434925527	6241	68	17D
0005433496682	6241	69	17E
0005433496694	6241	70	17F
0005433496696	6241	71	18A
0005434925507	6241	72	18C
0005433496676	6241	73	18D
0005434925529	6241	74	19A
0005433496706	6241	75	19C
0005433496698	6241	76	19D
0005433496704	6241	77	19E
0005433496700	6241	78	19F
0005433496705	6241	79	20A
0005433496688	6241	80	20C
0005434925519	6241	81	20E
0005434925523	6241	82	20F
0005433496475	20426	1	2A
0005433496504	20426	2	2F
0005433496466	20426	3	3A
0005433496483	20426	4	3C
0005433496499	20426	5	3F
0005434443470	20426	6	4C
0005433496442	20426	7	4D
0005433496424	20426	8	5D
0005433496484	20426	9	5E
0005434443453	20426	10	5F
0005433496524	20426	11	6C
0005433496421	20426	12	7F
0005433496465	20426	13	8D
0005433496441	20426	14	9A
0005434443434	20426	15	9E
0005433496425	20426	16	9F
0005434443512	20426	17	11A
0005434443467	20426	18	11C
0005433496426	20426	19	12A
0005433496540	20426	20	13A
0005433496506	20426	21	13C
0005433496525	20426	22	13D
0005433496473	20426	23	14A
0005434443469	20426	24	14D
0005433496554	20426	25	14E
0005433496498	20426	26	16A
0005433496557	20426	27	16D
0005434443463	20426	28	16E
0005434443511	20426	29	17A
0005433496589	20426	30	17C
0005433496447	20426	31	17D
0005433496541	20426	32	18A
0005434443428	20426	33	18E
0005434443433	20426	34	19C
0005433496467	20426	35	19E
0005433496474	20426	36	20D
0005433496558	20426	37	20F
0005432782838	12184	1	1A
0005435242629	12184	2	2A
0005432783237	12184	3	2D
0005435242635	12184	4	2F
0005435242618	12184	5	3C
0005432782881	12184	6	3D
0005435242623	12184	7	3F
0005435242622	12184	8	4A
0005435242616	12184	9	4C
0005432782946	12184	10	5F
0005432782850	12184	11	6C
0005435242631	12184	12	6D
0005432782886	12184	13	6E
0005435242636	12184	14	7D
0005435242633	12184	15	7F
0005435242617	12184	16	8D
0005435242626	12184	17	8E
0005432782931	12184	18	8F
0005432782864	12184	19	9A
0005432782962	12184	20	9C
0005435242613	12184	21	9D
0005435242625	12184	22	9E
0005435242615	12184	23	9F
0005435242611	12184	24	10C
0005432782851	12184	25	10F
0005435242612	12184	26	11A
0005435242627	12184	27	11C
0005432782889	12184	28	11E
0005432783015	12184	29	11F
0005432782877	12184	30	12C
0005435242619	12184	31	12D
0005432782930	12184	32	12E
0005432782908	12184	33	13C
0005432782918	12184	34	13D
0005432783024	12184	35	13F
0005432782964	12184	36	14C
0005432782888	12184	37	14D
0005432783014	12184	38	14E
0005432782865	12184	39	14F
0005435242630	12184	40	15D
0005432783238	12184	41	15F
0005432782947	12184	42	16A
0005432782906	12184	43	16C
0005435242624	12184	44	16F
0005435242614	12184	45	17A
0005435242634	12184	46	17F
0005432782873	12184	47	18A
0005435242621	12184	48	18C
0005435242632	12184	49	18D
0005432782916	12184	50	18E
0005432782929	12184	51	18F
0005432782882	12184	52	19A
0005435242620	12184	53	19C
0005435242628	12184	54	19F
0005432782857	12184	55	20E
0005432782948	12184	56	20F
0005432783246	15409	1	1A
0005432783226	15409	2	1C
0005432783268	15409	3	1D
0005432783245	15409	4	1F
0005432783242	15409	5	2C
0005432783275	15409	6	2D
0005432783276	15409	7	2F
0005432783252	15409	8	3A
0005432783266	15409	9	3F
0005432783260	15409	10	4C
0005432783261	15409	11	4D
0005432783272	15409	12	4E
0005432783247	15409	13	5A
0005432783263	15409	14	5D
0005432783256	15409	15	5E
0005432783238	15409	16	6A
0005432783227	15409	17	6C
0005432783231	15409	18	6F
0005432783233	15409	19	7C
0005432783259	15409	20	7D
0005432783244	15409	21	7F
0005432783254	15409	22	8A
0005432783236	15409	23	8C
0005432783234	15409	24	8E
0005435242441	15409	25	9A
0005435242387	15409	26	9C
0005432783265	15409	27	9D
0005432783241	15409	28	9E
0005432783277	15409	29	9F
0005432783269	15409	30	10C
0005432783229	15409	31	10D
0005435242414	15409	32	10E
0005432783225	15409	33	11A
0005432783274	15409	34	11C
0005432783271	15409	35	11D
0005432783278	15409	36	11E
0005432783232	15409	37	12A
0005432783257	15409	38	12E
0005435242413	15409	39	13A
0005432783262	15409	40	13C
0005432783264	15409	41	13D
0005435242442	15409	42	14A
0005432783258	15409	43	14D
0005435242415	15409	44	14E
0005432783255	15409	45	15A
0005432783267	15409	46	15D
0005432783273	15409	47	15E
0005432783250	15409	48	15F
0005432783235	15409	49	16A
0005432783237	15409	50	16D
0005432783240	15409	51	16F
0005432783239	15409	52	17A
0005432783253	15409	53	17C
0005432783251	15409	54	17E
0005432783228	15409	55	17F
0005432783270	15409	56	18A
0005432783230	15409	57	18D
0005432783243	15409	58	18F
0005432783249	15409	59	19C
0005432783248	15409	60	19E
0005434877017	10114	1	1F
0005434876643	10114	2	2C
0005434758856	10114	3	2D
0005434910089	10114	4	3D
0005434877016	10114	5	4A
0005434876602	10114	6	4D
0005434876809	10114	7	5D
0005434876875	10114	8	6A
0005434910088	10114	9	7C
0005434876723	10114	10	7F
0005434876892	10114	11	8B
0005434876737	10114	12	8E
0005434876813	10114	13	8D
0005434876716	10114	14	8C
0005434876693	10114	15	8F
0005434876804	10114	16	9A
0005434876806	10114	17	9B
0005434876893	10114	18	9F
0005434876680	10114	19	10B
0005434876578	10114	20	11A
0005434876676	10114	21	12B
0005434876682	10114	22	12A
0005434876739	10114	23	12D
0005434876810	10114	24	12C
0005434876923	10114	25	12E
0005434876641	10114	26	13A
0005434876561	10114	27	13C
0005434876624	10114	28	13D
0005434876876	10114	29	14A
0005434876557	10114	30	13F
0005434758855	10114	31	14B
0005434876603	10114	32	15D
0005434876649	10114	33	15F
0005434876627	10114	34	15E
0005434876592	10114	35	16A
0005434876648	10114	36	16C
0005434876835	10114	37	16B
0005434876640	10114	38	16E
0005434877015	10114	39	16D
0005434876647	10114	40	17A
0005434876679	10114	41	17F
0005435913901	10114	42	17E
0005434876918	10114	43	18B
0005434876628	10114	44	18C
0005434876562	10114	45	18F
0005435913902	10114	46	19B
0005434876794	10114	47	20B
0005434876800	10114	48	20A
0005434876613	10114	49	20D
0005434876738	10114	50	20F
0005434876560	10114	51	21D
0005434877003	10114	52	21F
0005434877405	14645	1	1F
0005434877370	14645	2	1D
0005434877350	14645	3	2A
0005434877403	14645	4	2F
0005434877332	14645	5	2D
0005434877378	14645	6	2C
0005434877360	14645	7	3A
0005434877415	14645	8	3C
0005434877411	14645	9	4A
0005434877409	14645	10	3F
0005434877372	14645	11	5A
0005434877381	14645	12	4F
0005434877345	14645	13	5C
0005434877382	14645	14	5F
0005434877358	14645	15	5D
0005434877375	14645	16	6B
0005434877400	14645	17	6A
0005434877374	14645	18	6D
0005434877331	14645	19	6C
0005434877356	14645	20	6E
0005434877362	14645	21	7A
0005434877348	14645	22	6F
0005434877339	14645	23	7C
0005434877418	14645	24	7B
0005434877412	14645	25	7E
0005434877335	14645	26	7D
0005434877410	14645	27	7F
0005434877426	14645	28	8B
0005434877427	14645	29	8A
0005434877387	14645	30	8D
0005434877385	14645	31	8C
0005434877421	14645	32	8F
0005434877393	14645	33	9B
0005434877422	14645	34	9E
0005434877398	14645	35	9D
0005434877424	14645	36	10A
0005434877371	14645	37	9F
0005434877420	14645	38	10C
0005434877399	14645	39	10E
0005434877425	14645	40	10D
0005434877379	14645	41	11A
0005434877354	14645	42	10F
0005434877416	14645	43	11B
0005434877357	14645	44	11D
0005434877423	14645	45	11C
0005434877407	14645	46	11F
0005434877342	14645	47	11E
0005434877395	14645	48	12B
0005434877333	14645	49	12A
0005434877340	14645	50	12C
0005434877344	14645	51	12E
0005434877384	14645	52	12D
0005434877391	14645	53	13A
0005434877355	14645	54	12F
0005434877336	14645	55	13C
0005434877341	14645	56	13B
0005434877419	14645	57	13E
0005434877408	14645	58	13D
0005434877353	14645	59	13F
0005434877369	14645	60	14B
0005434877337	14645	61	14D
0005434877394	14645	62	14C
0005434877368	14645	63	14F
0005434877401	14645	64	14E
0005434877361	14645	65	15B
0005434877389	14645	66	15A
0005434877377	14645	67	15D
0005434877351	14645	68	15C
0005434877397	14645	69	15E
0005434877390	14645	70	16A
0005434877388	14645	71	15F
0005434877365	14645	72	16C
0005434877413	14645	73	16B
0005434877392	14645	74	16E
0005434910071	14645	75	16D
0005434877364	14645	76	16F
0005434877376	14645	77	17B
0005434877347	14645	78	17A
0005434877386	14645	79	17D
0005434877346	14645	80	17E
0005434877363	14645	81	18A
0005434877380	14645	82	17F
0005434877396	14645	83	18B
0005434877417	14645	84	18E
0005434877359	14645	85	18D
0005434877352	14645	86	19A
0005434877349	14645	87	19C
0005434877366	14645	88	19B
0005434877383	14645	89	19E
0005434877343	14645	90	19D
0005434877402	14645	91	19F
0005434877367	14645	92	20B
0005434877414	14645	93	20F
0005434877334	14645	94	20E
0005434877404	14645	95	21A
0005434877338	14645	96	21D
0005434877373	14645	97	21C
0005434877406	14645	98	21E
0005434758872	14645	99	21F
0005435660037	9268	1	1A
0005435660031	9268	2	1B
0005434251799	9268	3	1C
0005434251804	9268	4	1D
0005435660029	9268	5	3A
0005435660030	9268	6	5B
0005435660033	9268	7	6B
0005435660035	9268	8	6D
0005434251844	9268	9	7A
0005435660032	9268	10	18D
0005435660038	9268	11	19B
0005435660039	9268	12	19C
0005434251808	9268	13	20C
0005435660034	9268	14	21C
0005435660036	9268	15	23A
0005434251877	24647	1	1B
0005434251881	24647	2	1C
0005435659946	24647	3	2C
0005435659951	24647	4	3C
0005434251880	24647	5	5B
0005434251883	24647	6	5C
0005434251875	24647	7	6A
0005434251882	24647	8	6B
0005435659971	24647	9	6C
0005434251873	24647	10	7C
0005434251874	24647	11	18A
0005434251878	24647	12	19C
0005434251879	24647	13	19D
0005435659965	24647	14	21D
0005435659961	24647	15	22A
0005434251876	24647	16	22B
0005435659960	24647	17	22D
0005433680105	2808	1	1D
0005432966550	2808	2	2A
0005433680117	2808	3	2C
0005433680116	2808	4	2F
0005433680146	2808	5	3D
0005433680141	2808	6	3F
0005432222735	2808	7	4E
0005433680127	2808	8	4F
0005433680139	2808	9	5A
0005433680113	2808	10	5F
0005432966531	2808	11	6A
0005433680128	2808	12	6C
0005432222732	2808	13	6D
0005432222733	2808	14	7A
0005433680102	2808	15	7C
0005433680132	2808	16	7D
0005433680107	2808	17	7E
0005432222734	2808	18	7F
0005432966521	2808	19	8A
0005432966524	2808	20	8C
0005433680114	2808	21	8D
0005432966562	2808	22	8E
0005433680144	2808	23	8F
0005432966590	2808	24	9A
0005433680126	2808	25	9C
0005432966589	2808	26	9D
0005433684400	2808	27	9E
0005433680119	2808	28	9F
0005432222731	2808	29	10A
0005433680142	2808	30	10C
0005433680115	2808	31	10F
0005433680108	2808	32	11A
0005433680138	2808	33	11C
0005433680147	2808	34	11E
0005433680145	2808	35	12A
0005432966563	2808	36	12D
0005433680103	2808	37	12C
0005433680134	2808	38	12E
0005433680133	2808	39	12F
0005432966600	2808	40	13C
0005433680111	2808	41	13D
0005432966481	2808	42	13F
0005433680135	2808	43	14A
0005433680120	2808	44	14C
0005433680104	2808	45	14E
0005433680112	2808	46	14F
0005433680101	2808	47	15A
0005433680137	2808	48	15D
0005433680140	2808	49	15E
0005433680118	2808	50	15F
0005432966549	2808	51	16C
0005433680109	2808	52	16D
0005433680123	2808	53	16E
0005433680148	2808	54	16F
0005433680122	2808	55	17A
0005433680130	2808	56	17E
0005432966599	2808	57	17F
0005433684399	2808	58	18A
0005433680106	2808	59	18C
0005433680136	2808	60	18D
0005433680124	2808	61	18E
0005432966480	2808	62	19A
0005433680110	2808	63	19C
0005433680100	2808	64	19D
0005433680121	2808	65	19E
0005433680131	2808	66	19F
0005433680129	2808	67	20A
0005433680125	2808	68	20D
0005433680143	2808	69	20F
0005433679790	29138	1	1A
0005433679774	29138	2	1C
0005433679770	29138	3	1D
0005433679911	29138	4	1F
0005433679777	29138	5	2A
0005433679785	29138	6	2D
0005432966705	29138	7	2F
0005433690895	29138	8	3A
0005433679715	29138	9	3F
0005432966694	29138	10	4A
0005432966701	29138	11	4C
0005432966698	29138	12	4D
0005433679802	29138	13	4E
0005433679721	29138	14	4F
0005433684386	29138	15	5A
0005432966710	29138	16	5C
0005432005186	29138	17	5D
0005433679833	29138	18	5F
0005433679886	29138	19	6A
0005432966713	29138	20	6D
0005433679806	29138	21	6E
0005433679714	29138	22	6F
0005433679970	29138	23	7A
0005432966691	29138	24	7D
0005432966715	29138	25	7F
0005433679805	29138	26	8A
0005432966707	29138	27	8C
0005433679750	29138	28	8D
0005433679957	29138	29	8E
0005433690891	29138	30	8F
0005433684388	29138	31	9A
0005433679720	29138	32	9D
0005433680001	29138	33	9E
0005432966714	29138	34	9F
0005432966692	29138	35	10A
0005432966709	29138	36	10C
0005433679773	29138	37	10D
0005432966702	29138	38	10E
0005433684387	29138	39	10F
0005432966712	29138	40	11A
0005432966693	29138	41	11C
0005432966704	29138	42	11D
0005432966703	29138	43	12A
0005433679940	29138	44	12C
0005433679784	29138	45	12D
0005432966706	29138	46	12E
0005432966689	29138	47	12F
0005433679788	29138	48	13A
0005433679832	29138	49	13C
0005433679978	29138	50	14A
0005432966697	29138	51	14C
0005433679938	29138	52	14D
0005433690892	29138	53	14E
0005432005188	29138	54	14F
0005432966696	29138	55	15A
0005432966690	29138	56	15D
0005433679796	29138	57	15E
0005432966695	29138	58	16C
0005432966700	29138	59	16D
0005432966708	29138	60	16E
0005433679941	29138	61	17A
0005433679958	29138	62	17C
0005433680002	29138	63	17D
0005433679775	29138	64	18A
0005432005187	29138	65	18D
0005433690896	29138	66	18E
0005433679816	29138	67	18F
0005432966688	29138	68	19A
0005433679898	29138	69	19C
0005433679850	29138	70	19D
0005432966699	29138	71	19E
0005433679751	29138	72	20A
0005433679786	29138	73	20C
0005433679787	29138	74	20D
0005432966711	29138	75	20F
0005433633459	9311	1	1A
0005433613952	9311	2	1C
0005433633463	9311	3	1D
0005433633464	9311	4	2A
0005433633478	9311	5	1F
0005433613963	9311	6	2C
0005434269070	9311	7	2F
0005433613947	9311	8	3A
0005433613941	9311	9	3C
0005432145092	9311	10	3D
0005433633479	9311	11	4A
0005433613975	9311	12	3F
0005433577671	9311	13	4C
0005433577679	9311	14	4F
0005433577682	9311	15	4D
0005433613936	9311	16	5C
0005433613979	9311	17	5D
0005433633473	9311	18	5F
0005433613942	9311	19	6C
0005433633491	9311	20	6F
0005433633476	9311	21	6D
0005433613935	9311	22	7A
0005433613954	9311	23	7C
0005433613973	9311	24	7D
0005433577672	9311	25	8C
0005433633485	9311	26	8B
0005432755044	9311	27	8E
0005433577676	9311	28	8D
0005433577681	9311	29	8F
0005433613940	9311	30	9B
0005433613970	9311	31	9A
0005433613924	9311	32	9C
0005433613916	9311	33	9E
0005433613949	9311	34	9D
0005433613910	9311	35	9F
0005433613965	9311	36	10B
0005433613950	9311	37	10D
0005433613911	9311	38	10C
0005433613915	9311	39	10E
0005433613960	9311	40	10F
0005433633486	9311	41	11B
0005433613938	9311	42	11A
0005433577674	9311	43	11D
0005433577675	9311	44	11E
0005433633461	9311	45	11F
0005433613930	9311	46	12B
0005433613920	9311	47	12D
0005433633474	9311	48	12C
0005434163462	9311	49	12F
0005433633489	9311	50	12E
0005433613919	9311	51	13C
0005433613934	9311	52	13E
0005433633462	9311	53	13D
0005433613982	9311	54	14B
0005432755043	9311	55	14A
0005433577678	9311	56	14D
0005432756816	9311	57	14C
0005433613951	9311	58	14E
0005433613932	9311	59	14F
0005433577680	9311	60	15A
0005433633487	9311	61	15D
0005433633488	9311	62	15E
0005433613969	9311	63	16A
0005433577683	9311	64	16C
0005433613917	9311	65	16E
0005433613957	9311	66	17A
0005432756815	9311	67	16F
0005433613978	9311	68	17B
0005433633470	9311	69	17C
0005433633475	9311	70	17F
0005433613914	9311	71	18A
0005433633467	9311	72	18C
0005433613922	9311	73	18D
0005433633465	9311	74	18E
0005433613980	9311	75	18F
0005433613967	9311	76	19D
0005433613925	9311	77	20A
0005433613929	9311	78	19E
0005433613972	9311	79	20C
0005433613984	9311	80	20B
0005433633484	9311	81	20E
0005434163461	9311	82	20D
0005433613964	9311	83	21A
0005433613977	9311	84	21C
0005433613928	9311	85	21B
0005433613946	9311	86	21D
0005433613961	9311	87	21F
0005433633481	9311	88	22B
0005433613971	9311	89	22A
0005434163463	9311	90	22C
0005433613955	9311	91	22F
0005433633483	9311	92	22E
0005433613981	9311	93	23B
0005433613931	9311	94	23A
0005434163465	9311	95	23C
0005433633460	9311	96	23D
0005433577684	9311	97	23F
0005433613912	9311	98	24B
0005433613918	9311	99	24A
0005433633477	9311	100	24C
0005433613933	9311	101	24E
0005433577673	9311	102	24D
0005433613976	9311	103	24F
0005433613948	9311	104	25A
0005433613926	9311	105	25C
0005433613939	9311	106	25B
0005433613937	9311	107	25D
0005433613913	9311	108	25E
0005433577677	9311	109	26A
0005433633458	9311	110	25F
0005433613974	9311	111	26C
0005433613921	9311	112	26B
0005432145091	9311	113	26E
0005433633472	9311	114	27A
0005433613944	9311	115	27B
0005433613983	9311	116	27C
0005433613959	9311	117	27D
0005433633490	9311	118	28A
0005433613953	9311	119	27F
0005433613923	9311	120	28D
0005433633469	9311	121	28C
0005433613956	9311	122	28E
0005433633457	9311	123	28F
0005433613966	9311	124	29B
0005433613943	9311	125	29A
0005433633471	9311	126	29C
0005433633482	9311	127	29F
0005433613968	9311	128	30C
0005433613962	9311	129	30D
0005433613958	9311	130	30F
0005433633480	9311	131	31A
0005433613927	9311	132	31C
0005433633466	9311	133	31B
0005433633468	9311	134	31D
0005433613945	9311	135	31F
0005432756817	9311	136	31E
0005434163531	25213	1	1A
0005433613431	25213	2	1C
0005434163535	25213	3	1F
0005434163534	25213	4	2A
0005434163533	25213	5	3A
0005433613495	25213	6	3F
0005434163530	25213	7	4F
0005433613678	25213	8	5A
0005433633277	25213	9	6A
0005433613569	25213	10	6F
0005433613493	25213	11	8C
0005433613502	25213	12	8E
0005433613438	25213	13	10D
0005433633220	25213	14	10E
0005433613649	25213	15	10F
0005433613480	25213	16	11B
0005434273060	25213	17	12A
0005433633255	25213	18	12C
0005433613464	25213	19	12B
0005433613568	25213	20	12E
0005434272174	25213	21	13A
0005433633278	25213	22	13B
0005433577621	25213	23	13F
0005433577586	25213	24	14B
0005434163526	25213	25	14D
0005433613388	25213	26	15A
0005433613650	25213	27	15B
0005433613389	25213	28	15C
0005434163529	25213	29	16C
0005433613487	25213	30	16F
0005433577587	25213	31	17A
0005433613399	25213	32	17B
0005433613430	25213	33	17F
0005433613624	25213	34	18D
0005433613456	25213	35	18E
0005433613510	25213	36	19B
0005433633322	25213	37	20A
0005433633411	25213	38	20C
0005434163536	25213	39	21C
0005434163532	25213	40	21D
0005433613648	25213	41	21F
0005433577582	25213	42	22C
0005434163528	25213	43	22E
0005433613504	25213	44	22F
0005434272175	25213	45	23E
0005433613453	25213	46	24A
0005433633249	25213	47	23F
0005433577562	25213	48	24B
0005433577590	25213	49	24D
0005433613415	25213	50	24F
0005433613625	25213	51	24E
0005433613548	25213	52	25E
0005433633412	25213	53	26A
0005434273059	25213	54	26E
0005433633321	25213	55	27B
0005434273061	25213	56	28E
0005434163527	25213	57	29D
0005433613472	25213	58	30B
0005433613429	25213	59	30C
0005433613494	25213	60	30E
0005433633226	25213	61	31F
0005435856134	4234	1	3A
0005435856144	4234	2	5F
0005435986704	4234	3	12E
0005432184927	4234	4	16D
0005435856145	4234	5	16F
0005435947004	4234	6	17A
0005432184926	4234	7	17D
0005435947078	4234	8	19H
0005435986706	4234	9	20F
0005435986705	4234	10	21A
0005432184925	4234	11	21D
0005432571259	4234	12	23E
0005434271276	4234	13	23D
0005432184924	4234	14	27F
0005432184923	4234	15	28H
0005435947019	4234	16	33E
0005435947025	4234	17	36G
0005435947006	4234	18	37D
0005435787337	26595	1	1A
0005435947117	26595	2	2G
0005435947124	26595	3	4A
0005432571290	26595	4	9B
0005435947115	26595	5	12B
0005435947129	26595	6	13E
0005435947128	26595	7	13D
0005435947120	26595	8	14F
0005435947122	26595	9	15G
0005435856166	26595	10	16D
0005435947126	26595	11	17A
0005432571291	26595	12	19A
0005435787334	26595	13	19B
0005435947121	26595	14	19G
0005435787336	26595	15	20A
0005435947123	26595	16	20H
0005432571289	26595	17	21E
0005435947118	26595	18	22H
0005435947130	26595	19	23E
0005435856167	26595	20	25E
0005432571288	26595	21	27A
0005435787335	26595	22	27E
0005435986656	26595	23	30F
0005435947131	26595	24	31H
0005435947127	26595	25	33E
0005435986650	26595	26	34G
0005435947119	26595	27	37D
0005435947116	26595	28	37G
0005435947125	26595	29	37E
0005433129206	320	1	1A
0005433568479	320	2	1D
0005433568516	320	3	2A
0005433568530	320	4	2C
0005433568534	320	5	2D
0005433568526	320	6	2F
0005433074284	320	7	4A
0005433074282	320	8	5A
0005433568481	320	9	4F
0005433568478	320	10	6A
0005433568506	320	11	5F
0005432238883	320	12	6D
0005433568489	320	13	7C
0005432238881	320	14	7F
0005433134059	320	15	7D
0005432238878	320	16	8A
0005432238882	320	17	8D
0005433568495	320	18	9B
0005432947793	320	19	9C
0005433568486	320	20	9D
0005433568505	320	21	9E
0005433568480	320	22	9F
0005433568509	320	23	10C
0005433568494	320	24	10B
0005433568488	320	25	10E
0005433568499	320	26	11D
0005433568518	320	27	11F
0005433568519	320	28	11E
0005433568496	320	29	12A
0005433568533	320	30	12C
0005433568487	320	31	12B
0005433568513	320	32	12D
0005433568537	320	33	12E
0005433568484	320	34	13B
0005433568539	320	35	13A
0005433568501	320	36	13D
0005433568483	320	37	13E
0005433568482	320	38	14B
0005433568522	320	39	14C
0005433568536	320	40	14E
0005433568543	320	41	15A
0005433074285	320	42	14F
0005433568529	320	43	15C
0005432947769	320	44	15B
0005433568511	320	45	15E
0005433129211	320	46	15F
0005433568524	320	47	16A
0005433568525	320	48	16B
0005432947865	320	49	16D
0005433074289	320	50	17A
0005433074283	320	51	17C
0005433568510	320	52	17B
0005432238877	320	53	17D
0005433568517	320	54	17E
0005433074246	320	55	18B
0005432947794	320	56	18C
0005433568492	320	57	18D
0005433568512	320	58	19C
0005433568497	320	59	20A
0005433568528	320	60	19E
0005433568498	320	61	20C
0005433568535	320	62	20F
0005433568538	320	63	21A
0005433568541	320	64	21D
0005434087918	320	65	21F
0005433568500	320	66	22B
0005433568508	320	67	22D
0005433568485	320	68	22C
0005433568504	320	69	22E
0005433074198	320	70	23C
0005433074224	320	71	23D
0005432947784	320	72	24A
0005433568542	320	73	24E
0005433568540	320	74	25C
0005433568520	320	75	25B
0005433568527	320	76	25D
0005433074278	320	77	26B
0005433568514	320	78	26A
0005432947783	320	79	26E
0005433134061	320	80	26F
0005433134072	320	81	27B
0005432238880	320	82	27A
0005433568532	320	83	27C
0005433568493	320	84	27D
0005433074220	320	85	27E
0005433074242	320	86	27F
0005432238879	320	87	28A
0005433134071	320	88	28D
0005432947840	320	89	28F
0005433568521	320	90	28E
0005433568507	320	91	29C
0005433568503	320	92	29F
0005433568490	320	93	29E
0005433568502	320	94	30B
0005433568515	320	95	30C
0005433568523	320	96	30D
0005433074219	320	97	31B
0005433568491	320	98	31C
0005433568531	320	99	31D
0005432947864	320	100	31F
0005432948083	11586	1	1A
0005433074442	11586	2	1F
0005432948073	11586	3	2A
0005433074445	11586	4	2F
0005433074440	11586	5	3A
0005433074454	11586	6	4A
0005432948077	11586	7	4C
0005432948095	11586	8	4D
0005432948071	11586	9	4F
0005432948057	11586	10	5C
0005433074458	11586	11	5F
0005432948068	11586	12	6A
0005432948093	11586	13	6C
0005433074449	11586	14	6F
0005432192291	11586	15	7C
0005433134095	11586	16	7F
0005432948067	11586	17	8A
0005433568055	11586	18	8B
0005432948076	11586	19	9A
0005432948074	11586	20	9B
0005432948061	11586	21	9F
0005433074450	11586	22	9E
0005432948082	11586	23	10A
0005432948058	11586	24	11C
0005433074452	11586	25	11E
0005432948096	11586	26	11D
0005433568037	11586	27	12A
0005433074438	11586	28	12F
0005433131667	11586	29	13A
0005433074432	11586	30	13C
0005432948069	11586	31	13F
0005433131665	11586	32	14A
0005432948078	11586	33	14C
0005432948092	11586	34	15B
0005433074455	11586	35	15A
0005432948064	11586	36	15E
0005433074446	11586	37	16B
0005432948065	11586	38	16F
0005433134097	11586	39	17C
0005432948056	11586	40	17B
0005432948072	11586	41	17D
0005433074443	11586	42	17F
0005433131663	11586	43	17E
0005432948088	11586	44	18A
0005432948086	11586	45	18E
0005433074453	11586	46	18D
0005433074444	11586	47	19C
0005433074433	11586	48	19D
0005432948081	11586	49	19E
0005432948063	11586	50	20B
0005432948062	11586	51	20C
0005432948075	11586	52	20E
0005433074439	11586	53	20D
0005432192290	11586	54	20F
0005432948087	11586	55	21C
0005432948080	11586	56	21D
0005433074437	11586	57	22A
0005433074434	11586	58	21F
0005433074456	11586	59	22C
0005433074435	11586	60	22F
0005432948079	11586	61	23A
0005432948055	11586	62	23D
0005433131666	11586	63	23C
0005433074448	11586	64	23F
0005433568054	11586	65	23E
0005433131664	11586	66	24A
0005433568051	11586	67	24D
0005433074457	11586	68	25C
0005432948091	11586	69	25D
0005433074441	11586	70	25E
0005432948084	11586	71	26A
0005433134096	11586	72	26C
0005432948085	11586	73	26E
0005433074431	11586	74	27B
0005432948089	11586	75	27C
0005432948070	11586	76	27D
0005432948094	11586	77	28B
0005433074451	11586	78	28E
0005432948060	11586	79	28D
0005433074447	11586	80	28F
0005432948059	11586	81	29A
0005432948090	11586	82	30B
0005432948066	11586	83	30C
0005433074436	11586	84	31F
0005433817436	9979	1	2B
0005433817435	9979	2	3A
0005434732924	9979	3	4A
0005434732925	9979	4	4B
0005433817437	9979	5	5B
0005434732923	9979	6	6B
0005434732948	13997	1	1A
0005434732949	13997	2	2A
0005434732950	13997	3	3A
0005434732947	13997	4	3B
0005433753690	2365	1	1B
0005433753712	2365	2	1F
0005432655427	2365	3	1C
0005433753697	2365	4	1H
0005435981890	2365	5	2A
0005433764661	2365	6	2C
0005433753724	2365	7	2B
0005435981893	2365	8	2F
0005433753689	2365	9	2G
0005435981909	2365	10	3A
0005432225999	2365	11	3C
0005433753720	2365	12	3B
0005432300210	2365	13	3F
0005433753686	2365	14	3G
0005432984570	2365	15	3H
0005433753699	2365	16	4B
0005432984615	2365	17	4A
0005433766604	2365	18	4C
0005435981912	2365	19	4F
0005433753738	2365	20	4H
0005432655430	2365	21	5A
0005433753719	2365	22	5C
0005432300209	2365	23	5G
0005432226001	2365	24	5F
0005432984561	2365	25	5H
0005435981908	2365	26	9B
0005435981916	2365	27	9A
0005435981913	2365	28	9G
0005435981907	2365	29	11B
0005435981900	2365	30	11E
0005432655431	2365	31	11D
0005433753692	2365	32	11G
0005432300213	2365	33	12A
0005433753726	2365	34	12B
0005433753732	2365	35	12E
0005432869412	2365	36	12F
0005433434204	2365	37	12H
0005433753721	2365	38	13A
0005432984625	2365	39	13D
0005435981898	2365	40	13B
0005432869421	2365	41	13F
0005435981921	2365	42	13E
0005432225997	2365	43	14B
0005432984524	2365	44	14D
0005433434245	2365	45	14F
0005433753702	2365	46	14E
0005432984520	2365	47	14H
0005432984606	2365	48	15B
0005432984566	2365	49	15E
0005432300208	2365	50	15D
0005435981891	2365	51	15H
0005433434243	2365	52	15G
0005435981923	2365	53	16A
0005433434224	2365	54	16F
0005433766603	2365	55	16E
0005432984557	2365	56	16D
0005433766607	2365	57	16H
0005435981914	2365	58	16G
0005433766605	2365	59	17D
0005432655432	2365	60	17B
0005433753698	2365	61	17E
0005433434199	2365	62	17F
0005433434207	2365	63	18A
0005435981892	2365	64	17H
0005435981896	2365	65	18E
0005433434220	2365	66	18F
0005434731104	2365	67	18H
0005432655426	2365	68	19B
0005432655428	2365	69	19A
0005433753708	2365	70	19D
0005435981920	2365	71	19F
0005432869430	2365	72	19G
0005432984626	2365	73	19H
0005435981911	2365	74	20B
0005435981899	2365	75	20E
0005433434214	2365	76	20G
0005435981889	2365	77	20F
0005433753737	2365	78	20H
0005433753729	2365	79	21A
0005432984544	2365	80	21D
0005432984569	2365	81	21B
0005435981922	2365	82	21F
0005432300212	2365	83	21E
0005432984575	2365	84	21G
0005433753688	2365	85	22B
0005433434238	2365	86	22D
0005435981897	2365	87	22F
0005432655429	2365	88	22E
0005432655425	2365	89	22G
0005433753711	2365	90	22H
0005432984616	2365	91	23B
0005433753714	2365	92	23A
0005433753709	2365	93	23D
0005432984503	2365	94	23F
0005433753735	2365	95	23E
0005433434282	2365	96	23G
0005433753722	2365	97	23H
0005433753685	2365	98	24A
0005435981918	2365	99	24F
0005435981905	2365	100	24E
0005433753707	2365	101	24H
0005433753683	2365	102	24G
0005432655423	2365	103	25F
0005432984605	2365	104	25E
0005433753723	2365	105	27A
0005435981917	2365	106	27D
0005433434213	2365	107	27F
0005433753682	2365	108	27E
0005433753684	2365	109	27H
0005435981894	2365	110	27G
0005432655433	2365	111	28A
0005433753696	2365	112	28D
0005432984614	2365	113	28B
0005433753728	2365	114	28E
0005433753715	2365	115	28F
0005435981904	2365	116	28G
0005433753730	2365	117	29A
0005433753705	2365	118	29B
0005435981902	2365	119	29F
0005433434232	2365	120	29D
0005435981915	2365	121	29G
0005433753693	2365	122	30A
0005432984567	2365	123	30D
0005432655435	2365	124	30B
0005435981906	2365	125	30F
0005433766606	2365	126	30E
0005432225998	2365	127	30G
0005432984522	2365	128	31B
0005433753717	2365	129	31A
0005432655424	2365	130	31E
0005433434244	2365	131	31D
0005432984521	2365	132	31F
0005433764660	2365	133	32A
0005433434272	2365	134	31H
0005432869424	2365	135	32B
0005432655434	2365	136	32E
0005432984624	2365	137	32D
0005433434237	2365	138	32G
0005432984540	2365	139	32F
0005435981903	2365	140	32H
0005432869425	2365	141	33A
0005432869427	2365	142	33D
0005433753731	2365	143	33B
0005435981910	2365	144	33G
0005432300211	2365	145	33F
0005433434283	2365	146	33H
0005433753727	2365	147	34A
0005433753716	2365	148	34F
0005433753695	2365	149	34E
0005433753734	2365	150	34G
0005435981895	2365	151	34H
0005432226002	2365	152	35B
0005432984508	2365	153	35A
0005433753691	2365	154	35E
0005433753713	2365	155	35D
0005432984525	2365	156	35F
0005435981901	2365	157	36A
0005433753706	2365	158	35H
0005435981919	2365	159	36B
0005433753733	2365	160	36D
0005433434205	2365	161	36F
0005433753700	2365	162	36H
0005433753704	2365	163	36G
0005433434206	2365	164	37A
0005433434225	2365	165	37D
0005433753710	2365	166	37F
0005432226000	2365	167	38A
0005433753718	2365	168	38B
0005433753687	2365	169	38E
0005433434192	2365	170	38D
0005433753694	2365	171	38F
0005433753703	2365	172	38H
0005433753701	2365	173	38G
0005433753725	2365	174	39E
0005432984537	2365	175	39D
0005433753736	2365	176	39F
0005433753252	26192	1	1A
0005432049430	26192	2	1B
0005435981629	26192	3	1C
0005432984785	26192	4	1G
0005433753329	26192	5	1H
0005433434437	26192	6	2C
0005433434411	26192	7	2G
0005435981514	26192	8	2F
0005433766583	26192	9	3A
0005433434429	26192	10	3B
0005433753470	26192	11	3C
0005432984796	26192	12	4A
0005432869462	26192	13	4C
0005434731130	26192	14	4H
0005433753383	26192	15	5B
0005433434419	26192	16	5F
0005432869463	26192	17	9B
0005433434412	26192	18	9G
0005433434415	26192	19	9H
0005433764651	26192	20	11F
0005434731131	26192	21	12A
0005432984793	26192	22	12E
0005432984773	26192	23	12D
0005433753253	26192	24	12G
0005432984775	26192	25	12F
0005432984774	26192	26	12H
0005432984770	26192	27	13B
0005432984794	26192	28	13A
0005432049432	26192	29	13F
0005432869460	26192	30	13H
0005433753232	26192	31	14B
0005433434434	26192	32	14E
0005433753354	26192	33	14F
0005433753345	26192	34	14H
0005433753251	26192	35	14G
0005434731134	26192	36	15B
0005435981641	26192	37	15E
0005432984768	26192	38	15F
0005432984786	26192	39	16F
0005432869459	26192	40	16G
0005433434438	26192	41	17E
0005432655340	26192	42	18A
0005433766573	26192	43	17H
0005433753370	26192	44	18B
0005433753385	26192	45	18D
0005435981509	26192	46	18E
0005432984769	26192	47	18F
0005433434433	26192	48	18H
0005433434435	26192	49	19D
0005432984782	26192	50	19F
0005433753328	26192	51	20A
0005432984788	26192	52	20D
0005432984776	26192	53	20F
0005432655341	26192	54	20H
0005432051100	26192	55	20G
0005435981518	26192	56	21A
0005432984790	26192	57	21D
0005433753379	26192	58	21E
0005433434416	26192	59	21F
0005432984792	26192	60	21H
0005433753406	26192	61	22B
0005432984781	26192	62	22A
0005433753267	26192	63	22E
0005434731133	26192	64	22F
0005433766575	26192	65	23D
0005433753284	26192	66	23B
0005432984795	26192	67	23F
0005433434421	26192	68	23E
0005432051098	26192	69	23G
0005432984772	26192	70	23H
0005432984780	26192	71	24B
0005432984798	26192	72	24A
0005433434427	26192	73	24F
0005433434428	26192	74	24G
0005433434420	26192	75	25D
0005433434417	26192	76	24H
0005433753231	26192	77	25E
0005432984791	26192	78	27H
0005434731132	26192	79	27G
0005433434423	26192	80	28A
0005433434418	26192	81	28F
0005432984766	26192	82	28E
0005433434436	26192	83	28H
0005433753384	26192	84	29D
0005432984771	26192	85	29E
0005432869464	26192	86	29H
0005432984777	26192	87	30E
0005432869461	26192	88	31E
0005432984778	26192	89	31D
0005432984784	26192	90	32B
0005432984797	26192	91	32F
0005433434431	26192	92	32E
0005433753418	26192	93	32H
0005432984783	26192	94	32G
0005433434410	26192	95	33A
0005433753266	26192	96	33B
0005432984787	26192	97	33D
0005433753233	26192	98	33G
0005433434425	26192	99	33F
0005433434432	26192	100	33H
0005433766584	26192	101	34A
0005432051099	26192	102	34D
0005433434414	26192	103	34E
0005432049431	26192	104	34G
0005432984779	26192	105	34F
0005432984789	26192	106	35A
0005433434413	26192	107	34H
0005435981559	26192	108	35E
0005435981564	26192	109	35H
0005433434424	26192	110	36E
0005433753442	26192	111	36D
0005433766574	26192	112	36F
0005433753378	26192	113	37H
0005432984767	26192	114	38A
0005433753277	26192	115	38D
0005433434422	26192	116	38B
0005435981563	26192	117	38F
0005433434426	26192	118	38G
0005435981527	26192	119	39E
0005433434430	26192	120	39D
0005433150924	1530	1	1C
0005434374218	1530	2	1D
0005434374233	1530	3	2A
0005434374220	1530	4	1F
0005434374236	1530	5	2D
0005433460416	1530	6	2C
0005434374203	1530	7	2F
0005433460418	1530	8	3C
0005434374215	1530	9	3A
0005433764646	1530	10	3D
0005434374213	1530	11	3F
0005432267832	1530	12	4B
0005434374230	1530	13	4A
0005433150925	1530	14	4C
0005434374209	1530	15	5A
0005433150901	1530	16	5C
0005434374210	1530	17	5D
0005434374238	1530	18	5E
0005432267833	1530	19	6A
0005433150847	1530	20	5F
0005433150797	1530	21	6B
0005433460417	1530	22	6C
0005434374199	1530	23	6D
0005434374227	1530	24	6E
0005434374248	1530	25	8A
0005433460415	1530	26	7F
0005434374251	1530	27	8B
0005433150839	1530	28	8D
0005434374232	1530	29	8C
0005434374247	1530	30	8F
0005434374226	1530	31	9A
0005433150862	1530	32	9C
0005432267836	1530	33	9D
0005434374243	1530	34	10E
0005432267835	1530	35	11A
0005434374249	1530	36	11D
0005433150880	1530	37	11C
0005434374214	1530	38	11E
0005433461569	1530	39	12B
0005433461568	1530	40	12D
0005434374237	1530	41	12C
0005434374223	1530	42	12E
0005433150886	1530	43	13B
0005432267834	1530	44	13D
0005434374242	1530	45	13E
0005433150900	1530	46	13F
0005434374224	1530	47	14A
0005433150846	1530	48	14B
0005434374234	1530	49	14E
0005434374204	1530	50	14F
0005433931421	1530	51	15A
0005434374208	1530	52	15E
0005434374217	1530	53	15F
0005434374216	1530	54	16B
0005433150956	1530	55	16C
0005434374212	1530	56	16D
0005434374246	1530	57	16F
0005434374211	1530	58	16E
0005434374231	1530	59	17A
0005433150863	1530	60	17D
0005434374198	1530	61	17E
0005434374200	1530	62	18A
0005433150879	1530	63	17F
0005434374207	1530	64	18B
0005434374239	1530	65	18D
0005434374202	1530	66	18C
0005434374225	1530	67	18E
0005433150976	1530	68	19D
0005434374235	1530	69	19E
0005433150845	1530	70	19F
0005434374205	1530	71	20A
0005433764645	1530	72	20C
0005433150935	1530	73	20D
0005434374240	1530	74	20E
0005434374222	1530	75	20F
0005434374221	1530	76	21A
0005434374244	1530	77	21B
0005434374228	1530	78	21D
0005434374245	1530	79	21C
0005434374229	1530	80	21E
0005433150878	1530	81	21F
0005434374206	1530	82	22B
0005432267837	1530	83	22A
0005433150955	1530	84	22C
0005433931422	1530	85	22D
0005434374219	1530	86	22E
0005434374241	1530	87	23A
0005432267831	1530	88	22F
0005434374250	1530	89	23B
0005434374197	1530	90	23E
0005434374201	1530	91	23D
0005433151106	20111	1	1D
0005433764661	20111	2	1F
0005433151083	20111	3	2A
0005433151088	20111	4	2F
0005433151089	20111	5	3A
0005433151096	20111	6	3F
0005434029634	20111	7	4A
0005434373980	20111	8	4E
0005433151078	20111	9	4D
0005434373912	20111	10	5B
0005434373861	20111	11	5C
0005433151077	20111	12	5D
0005434373919	20111	13	5E
0005433151098	20111	14	6A
0005433151093	20111	15	6C
0005434374033	20111	16	6D
0005433151082	20111	17	6E
0005433151090	20111	18	7D
0005433151100	20111	19	7C
0005433151099	20111	20	7E
0005434374038	20111	21	7F
0005434373851	20111	22	8A
0005434373850	20111	23	8B
0005433931436	20111	24	8C
0005434374006	20111	25	8F
0005433151079	20111	26	9A
0005433151094	20111	27	9D
0005432056265	20111	28	9E
0005433151076	20111	29	9F
0005434373913	20111	30	10C
0005434374046	20111	31	10D
0005433151084	20111	32	10E
0005433151081	20111	33	11C
0005433151087	20111	34	11F
0005433151102	20111	35	11E
0005433151101	20111	36	12C
0005434373984	20111	37	12B
0005433151075	20111	38	12D
0005433151095	20111	39	12E
0005433931439	20111	40	12F
0005433151080	20111	41	14E
0005433151092	20111	42	15A
0005433931438	20111	43	15B
0005434373856	20111	44	15D
0005433151108	20111	45	15F
0005433151104	20111	46	16B
0005433151103	20111	47	16A
0005433931437	20111	48	16F
0005433151109	20111	49	17A
0005433151085	20111	50	17D
0005434373911	20111	51	17C
0005434374037	20111	52	17E
0005434373936	20111	53	18A
0005433151091	20111	54	18D
0005434373977	20111	55	19A
0005434374024	20111	56	19C
0005433151086	20111	57	19D
0005432056262	20111	58	20D
0005434373898	20111	59	20C
0005433764660	20111	60	20E
0005434373891	20111	61	20F
0005434029633	20111	62	21B
0005434373918	20111	63	21D
0005432056264	20111	64	21E
0005433151097	20111	65	22A
0005434373954	20111	66	22B
0005434373853	20111	67	22F
0005433151105	20111	68	23C
0005433151107	20111	69	23E
0005432056263	20111	70	23F
0005432424029	518	1	1D
0005432424026	518	2	1C
0005432424003	518	3	1F
0005432424034	518	4	2A
0005432424053	518	5	2C
0005432282798	518	6	3A
0005432424039	518	7	4A
0005432424035	518	8	4D
0005432424046	518	9	5C
0005432424050	518	10	5F
0005432424027	518	11	5D
0005432424001	518	12	7A
0005432424047	518	13	8C
0005432424004	518	14	9A
0005432424009	518	15	10A
0005432424015	518	16	9F
0005432424018	518	17	10C
0005432424022	518	18	10E
0005432424044	518	19	10F
0005432424051	518	20	11A
0005432424010	518	21	11F
0005432424041	518	22	12B
0005432424055	518	23	13B
0005432424005	518	24	13A
0005432424040	518	25	14A
0005432424052	518	26	14E
0005432424054	518	27	14D
0005432424030	518	28	15A
0005432424038	518	29	15E
0005432424011	518	30	16E
0005432424014	518	31	16F
0005432424021	518	32	17E
0005432424025	518	33	18B
0005432424057	518	34	18C
0005432282796	518	35	19C
0005432424037	518	36	20B
0005432424033	518	37	20F
0005432424024	518	38	21B
0005432424036	518	39	22B
0005432282802	518	40	23B
0005432424000	518	41	23C
0005432424002	518	42	23E
0005432424042	518	43	24A
0005432282801	518	44	23F
0005432424007	518	45	24F
0005432424028	518	46	25B
0005432424020	518	47	25A
0005432424043	518	48	25D
0005432424017	518	49	26A
0005432424032	518	50	25F
0005432424049	518	51	26D
0005432424019	518	52	26C
0005432424006	518	53	26E
0005432424012	518	54	27C
0005432424016	518	55	27B
0005432424045	518	56	27D
0005432424048	518	57	28A
0005432282797	518	58	28B
0005432424008	518	59	28C
0005432424031	518	60	28D
0005432282799	518	61	29B
0005432424013	518	62	29D
0005432424056	518	63	30F
0005432282800	518	64	31E
0005432424023	518	65	31F
0005432302296	12941	1	12A
0005432302297	12941	2	17C
0005434023075	438	1	1A
0005434023121	438	2	1C
0005433684384	438	3	1B
0005432235568	438	4	1H
0005434023065	438	5	3B
0005434023069	438	6	3C
0005434023091	438	7	3F
0005434023082	438	8	4B
0005432045593	438	9	4G
0005434023096	438	10	5A
0005434023105	438	11	5F
0005434031976	438	12	5H
0005432235572	438	13	9G
0005434023085	438	14	11A
0005434023057	438	15	11E
0005434031980	438	16	11F
0005434023062	438	17	11H
0005434023083	438	18	12B
0005434023104	438	19	12A
0005434023124	438	20	12G
0005434023125	438	21	12F
0005434023063	438	22	13G
0005434023059	438	23	13F
0005434023078	438	24	14B
0005434023093	438	25	14A
0005433057253	438	26	14D
0005434023074	438	27	14E
0005434029632	438	28	14G
0005434023092	438	29	15A
0005434023084	438	30	15B
0005434029630	438	31	15D
0005434023072	438	32	15F
0005434023106	438	33	15H
0005434023070	438	34	16D
0005434023079	438	35	16F
0005434023097	438	36	16H
0005434023086	438	37	17B
0005434023071	438	38	17E
0005434023073	438	39	17H
0005433057278	438	40	18A
0005434023102	438	41	18D
0005434735597	438	42	18B
0005434023088	438	43	18F
0005434023064	438	44	18G
0005432045594	438	45	19A
0005434023099	438	46	19D
0005434023101	438	47	19F
0005434023111	438	48	20A
0005433057266	438	49	19H
0005434031977	438	50	20E
0005433057201	438	51	20D
0005434023108	438	52	20F
0005434028267	438	53	20H
0005434023094	438	54	21A
0005434023087	438	55	21E
0005434028270	438	56	21G
0005434023118	438	57	22B
0005434023114	438	58	23A
0005433057299	438	59	23E
0005434031978	438	60	23D
0005434023123	438	61	23B
0005434023066	438	62	23F
0005434023103	438	63	24B
0005434023098	438	64	24D
0005433057269	438	65	24F
0005434023100	438	66	24G
0005434023122	438	67	27A
0005434023076	438	68	25F
0005434023119	438	69	27E
0005432235569	438	70	27G
0005434023120	438	71	28D
0005434023117	438	72	28E
0005434023107	438	73	28H
0005434023112	438	74	29D
0005434023060	438	75	29E
0005433057300	438	76	30D
0005433057285	438	77	30B
0005434023055	438	78	30F
0005433057225	438	79	30E
0005433057284	438	80	30G
0005434023056	438	81	31B
0005433057171	438	82	31A
0005434023061	438	83	31D
0005434023115	438	84	31F
0005432235570	438	85	31G
0005432045595	438	86	32A
0005434031979	438	87	32B
0005434028268	438	88	32D
0005434023090	438	89	32F
0005434023095	438	90	33B
0005433057270	438	91	33E
0005434023067	438	92	33D
0005434023113	438	93	33H
0005434023110	438	94	33G
0005433057226	438	95	34B
0005434023068	438	96	34D
0005434023077	438	97	34G
0005433684385	438	98	34F
0005434023058	438	99	34H
0005433057186	438	100	35B
0005432235571	438	101	35A
0005433057346	438	102	35F
0005432235567	438	103	35E
0005433057279	438	104	35G
0005434028269	438	105	35H
0005433057230	438	106	36B
0005434023109	438	107	36E
0005433057366	438	108	37B
0005434023080	438	109	38A
0005434023116	438	110	38B
0005434029631	438	111	38G
0005434023089	438	112	39D
0005434023081	438	113	39F
0005432156324	12690	1	1C
0005434022633	12690	2	1B
0005434022626	12690	3	1F
0005433057500	12690	4	2F
0005433929577	12690	5	2C
0005434022676	12690	6	2G
0005434022635	12690	7	3A
0005433057530	12690	8	3B
0005433057511	12690	9	4F
0005434022521	12690	10	5A
0005434022529	12690	11	4H
0005433057527	12690	12	5B
0005433057522	12690	13	5C
0005433057510	12690	14	5F
0005433057534	12690	15	9G
0005433057531	12690	16	11A
0005434022867	12690	17	9H
0005434022657	12690	18	11E
0005434022556	12690	19	11F
0005434022513	12690	20	11G
0005433057521	12690	21	11H
0005433057505	12690	22	12B
0005434022590	12690	23	12H
0005433057506	12690	24	13E
0005432156325	12690	25	13G
0005434022518	12690	26	13F
0005433057501	12690	27	14D
0005434022576	12690	28	14F
0005433057535	12690	29	14E
0005434022555	12690	30	14H
0005434022504	12690	31	15F
0005433057503	12690	32	15H
0005434022568	12690	33	15G
0005433057529	12690	34	16F
0005434022575	12690	35	16E
0005433057499	12690	36	16H
0005434022730	12690	37	17A
0005433057497	12690	38	17E
0005434031953	12690	39	17G
0005433057532	12690	40	18B
0005434022637	12690	41	18E
0005433929575	12690	42	19B
0005433057518	12690	43	19F
0005433057523	12690	44	19E
0005434022643	12690	45	19G
0005434735643	12690	46	20D
0005432157473	12690	47	20F
0005433057536	12690	48	20G
0005432157474	12690	49	20H
0005434022524	12690	50	21B
0005433057513	12690	51	21D
0005434022534	12690	52	22F
0005433929576	12690	53	22E
0005433057525	12690	54	23A
0005433684402	12690	55	22H
0005434022522	12690	56	23B
0005434022567	12690	57	23E
0005434022595	12690	58	23H
0005433057512	12690	59	23G
0005434022519	12690	60	24B
0005433057507	12690	61	24A
0005434022731	12690	62	24D
0005433929573	12690	63	24G
0005434022629	12690	64	24H
0005434022528	12690	65	27B
0005433057520	12690	66	27D
0005434022584	12690	67	27F
0005433057515	12690	68	27H
0005433057519	12690	69	28B
0005433057533	12690	70	28G
0005433057508	12690	71	29B
0005433057517	12690	72	30B
0005433057502	12690	73	30D
0005434022585	12690	74	30G
0005434022550	12690	75	31A
0005434022728	12690	76	30H
0005434022597	12690	77	31E
0005434022589	12690	78	31D
0005434022630	12690	79	31F
0005433057514	12690	80	32E
0005434022523	12690	81	32G
0005434735644	12690	82	33A
0005434022680	12690	83	33F
0005434031945	12690	84	33H
0005433057504	12690	85	34F
0005433057498	12690	86	34G
0005434022634	12690	87	34H
0005433057537	12690	88	35B
0005434022709	12690	89	35A
0005433057528	12690	90	35E
0005433684401	12690	91	35G
0005434735641	12690	92	35F
0005432156326	12690	93	36B
0005434735642	12690	94	36F
0005433057509	12690	95	36G
0005434022624	12690	96	37A
0005433057526	12690	97	37B
0005433929574	12690	98	37F
0005434022544	12690	99	37G
0005434022503	12690	100	38E
0005434022868	12690	101	38F
0005433057516	12690	102	38G
0005433057524	12690	103	39E
0005434022729	12690	104	39D
0005434022594	12690	105	39F
0005433922442	2116	1	1A
0005432231463	2116	2	1C
0005433922376	2116	3	1B
0005433922448	2116	4	1F
0005433931436	2116	5	1G
0005433922402	2116	6	2C
0005433035365	2116	7	2B
0005433922453	2116	8	3B
0005433922455	2116	9	3G
0005433922421	2116	10	4G
0005433922397	2116	11	5A
0005432231464	2116	12	4H
0005432749747	2116	13	5F
0005433035463	2116	14	9B
0005432231467	2116	15	9A
0005433922461	2116	16	9G
0005433035602	2116	17	9H
0005433922404	2116	18	11B
0005433922435	2116	19	11D
0005433922465	2116	20	11F
0005433931437	2116	21	11G
0005433922425	2116	22	12A
0005433922375	2116	23	12D
0005432231471	2116	24	12E
0005433922440	2116	25	12G
0005433922406	2116	26	12H
0005433922392	2116	27	13A
0005433875364	2116	28	13D
0005433035461	2116	29	13F
0005433035392	2116	30	13E
0005433922382	2116	31	13G
0005432231470	2116	32	14A
0005433929574	2116	33	14F
0005433922464	2116	34	14E
0005433929575	2116	35	15A
0005433922378	2116	36	15E
0005433922420	2116	37	15D
0005433922419	2116	38	15G
0005432044499	2116	39	15H
0005433922437	2116	40	16B
0005433035473	2116	41	16A
0005433922429	2116	42	16F
0005433035363	2116	43	17A
0005433922417	2116	44	17D
0005433922393	2116	45	17B
0005433922388	2116	46	17E
0005433922463	2116	47	17F
0005433922396	2116	48	17H
0005433922468	2116	49	18B
0005433922434	2116	50	18E
0005433922452	2116	51	18F
0005433922407	2116	52	19A
0005433035375	2116	53	19D
0005433922428	2116	54	19F
0005433922449	2116	55	19G
0005433922431	2116	56	19H
0005433922390	2116	57	20B
0005433922447	2116	58	20E
0005433922451	2116	59	20F
0005433922385	2116	60	20H
0005433922408	2116	61	20G
0005433922426	2116	62	21D
0005433922460	2116	63	21B
0005433922424	2116	64	21G
0005433922400	2116	65	21F
0005433922381	2116	66	22A
0005433922446	2116	67	22D
0005433922456	2116	68	22B
0005433035440	2116	69	22G
0005433929577	2116	70	22F
0005433922395	2116	71	23A
0005432231462	2116	72	22H
0005433922416	2116	73	23B
0005433922414	2116	74	23D
0005433922383	2116	75	23G
0005433922433	2116	76	23H
0005433035356	2116	77	24B
0005433922430	2116	78	24A
0005433922418	2116	79	24E
0005433922457	2116	80	24G
0005432231468	2116	81	24H
0005433035474	2116	82	25E
0005433922458	2116	83	27B
0005432044498	2116	84	27A
0005433922469	2116	85	27F
0005433035519	2116	86	27H
0005433922403	2116	87	27G
0005433922439	2116	88	28A
0005433035424	2116	89	28B
0005433922427	2116	90	28D
0005433035528	2116	91	28F
0005433922405	2116	92	28G
0005432231465	2116	93	28H
0005433922409	2116	94	29B
0005433922422	2116	95	29E
0005433035357	2116	96	29F
0005433035366	2116	97	30B
0005433922377	2116	98	30D
0005433922401	2116	99	30F
0005433922379	2116	100	30E
0005433922387	2116	101	30G
0005433922445	2116	102	31A
0005433035368	2116	103	30H
0005433035513	2116	104	31B
0005433929573	2116	105	31E
0005432749748	2116	106	31D
0005433922384	2116	107	31F
0005433035576	2116	108	31G
0005433929576	2116	109	31H
0005433922374	2116	110	32D
0005433922391	2116	111	32A
0005433035567	2116	112	32E
0005433922466	2116	113	32H
0005433035408	2116	114	32G
0005433922389	2116	115	33A
0005433922459	2116	116	33D
0005433922411	2116	117	33B
0005433035557	2116	118	33E
0005433922413	2116	119	33G
0005433922410	2116	120	34A
0005433035460	2116	121	33H
0005433922441	2116	122	34D
0005433035385	2116	123	34F
0005433922398	2116	124	34H
0005433922399	2116	125	35B
0005433922450	2116	126	35E
0005432231469	2116	127	35G
0005433922462	2116	128	35F
0005433922432	2116	129	36A
0005433035462	2116	130	35H
0005433922443	2116	131	36B
0005433922467	2116	132	36E
0005433931439	2116	133	36D
0005433922386	2116	134	36H
0005432231466	2116	135	36G
0005433922436	2116	136	37B
0005433922380	2116	137	37E
0005433922412	2116	138	37D
0005433922454	2116	139	37H
0005433922415	2116	140	37G
0005433922394	2116	141	38B
0005433922444	2116	142	38D
0005433931438	2116	143	38F
0005432044500	2116	144	38H
0005433922438	2116	145	38G
0005433922423	2116	146	39F
0005433035833	24091	1	1A
0005433921931	24091	2	1C
0005433921921	24091	3	1B
0005433035823	24091	4	1F
0005434028272	24091	5	1H
0005433921908	24091	6	2A
0005433921648	24091	7	2B
0005433921810	24091	8	2F
0005433035800	24091	9	2G
0005433921751	24091	10	3A
0005433921867	24091	11	3H
0005433921619	24091	12	4F
0005433035807	24091	13	5B
0005433921916	24091	14	5C
0005433035817	24091	15	5H
0005433035813	24091	16	9G
0005433035838	24091	17	11A
0005433035792	24091	18	11D
0005432749764	24091	19	11E
0005433921628	24091	20	11F
0005433921705	24091	21	12B
0005433035788	24091	22	11H
0005434028271	24091	23	12D
0005433035822	24091	24	12F
0005433035808	24091	25	13A
0005432206144	24091	26	13D
0005433035795	24091	27	13F
0005432206142	24091	28	13E
0005433921869	24091	29	14E
0005433922088	24091	30	14D
0005433922108	24091	31	14F
0005433035829	24091	32	14G
0005433035802	24091	33	15A
0005433921622	24091	34	15D
0005433035820	24091	35	15G
0005432749766	24091	36	16B
0005432749765	24091	37	16D
0005433921844	24091	38	16E
0005433921782	24091	39	16G
0005433921657	24091	40	16F
0005433035835	24091	41	17A
0005432207640	24091	42	17D
0005433035793	24091	43	17B
0005433929549	24091	44	17G
0005433921737	24091	45	17H
0005432206143	24091	46	18B
0005433035840	24091	47	18E
0005433035806	24091	48	20A
0005433921833	24091	49	20B
0005433921847	24091	50	20F
0005433921848	24091	51	20G
0005433921608	24091	52	21D
0005433035804	24091	53	21B
0005432207639	24091	54	21E
0005433921868	24091	55	21G
0005433921849	24091	56	22B
0005433921884	24091	57	22D
0005434028273	24091	58	22G
0005433921750	24091	59	22H
0005433035828	24091	60	23B
0005433921593	24091	61	23A
0005433035801	24091	62	23D
0005433035821	24091	63	23E
0005433035818	24091	64	23G
0005434028274	24091	65	24B
0005433921885	24091	66	24A
0005433035824	24091	67	24E
0005433921909	24091	68	24D
0005433035811	24091	69	24F
0005433921636	24091	70	24G
0005433921656	24091	71	25D
0005433921594	24091	72	24H
0005433035803	24091	73	25E
0005433922087	24091	74	25F
0005433931431	24091	75	27E
0005433035794	24091	76	27D
0005433921832	24091	77	27G
0005433921639	24091	78	27H
0005433035825	24091	79	28D
0005433035837	24091	80	28G
0005433035810	24091	81	29A
0005433035789	24091	82	29B
0005433921601	24091	83	29G
0005433035832	24091	84	30A
0005433035799	24091	85	29H
0005433035816	24091	86	30D
0005433035791	24091	87	30E
0005433035827	24091	88	30F
0005433035831	24091	89	30H
0005433035797	24091	90	31B
0005433035812	24091	91	31F
0005432207638	24091	92	31E
0005433035814	24091	93	32E
0005433035798	24091	94	32D
0005432207637	24091	95	32F
0005433921893	24091	96	32G
0005433035839	24091	97	33E
0005433035841	24091	98	33G
0005433035805	24091	99	34A
0005433035836	24091	100	33H
0005433921644	24091	101	34D
0005432206140	24091	102	34F
0005433035826	24091	103	35A
0005433921892	24091	104	34H
0005432206141	24091	105	35B
0005433921714	24091	106	35F
0005433921774	24091	107	35H
0005433035796	24091	108	36A
0005433921739	24091	109	36B
0005433921602	24091	110	36E
0005433035830	24091	111	36D
0005433035809	24091	112	37B
0005433921738	24091	113	37E
0005433921845	24091	114	38B
0005433035819	24091	115	38F
0005433035790	24091	116	38H
0005433035815	24091	117	39E
0005433035834	24091	118	39F
0005434724391	279	1	1C
0005433180729	279	2	1A
0005434724324	279	3	1D
0005434724342	279	4	1H
0005434724381	279	5	2C
0005434735636	279	6	2A
0005433233141	279	7	3A
0005434550759	279	8	2K
0005434724407	279	9	2H
0005434550718	279	10	3D
0005434724335	279	11	3H
0005432277681	279	12	4C
0005434724377	279	13	3K
0005432277682	279	14	4K
0005434724388	279	15	4H
0005434550706	279	16	5D
0005433180690	279	17	5A
0005434550720	279	18	5G
0005434724319	279	19	11A
0005434550732	279	20	11D
0005432277690	279	21	11C
0005434724417	279	22	11E
0005434302420	279	23	11H
0005434724389	279	24	11G
0005434724327	279	25	12C
0005434724343	279	26	12A
0005434724376	279	27	12D
0005434550745	279	28	12H
0005434550748	279	29	12G
0005434550708	279	30	12F
0005434550726	279	31	12K
0005433233152	279	32	13C
0005434550761	279	33	13F
0005434550719	279	34	13E
0005435142454	279	35	13K
0005434735638	279	36	14A
0005434724334	279	37	14D
0005434550749	279	38	14E
0005434724375	279	39	14G
0005433233089	279	40	15C
0005433233308	279	41	15A
0005434724314	279	42	15E
0005434724367	279	43	15G
0005435142447	279	44	15H
0005432277679	279	45	16C
0005434550723	279	46	16F
0005433126774	279	47	16E
0005434724310	279	48	16H
0005434550711	279	49	16K
0005433180680	279	50	17E
0005434724419	279	51	17D
0005434724387	279	52	17F
0005434724333	279	53	17H
0005434724332	279	54	18C
0005435142449	279	55	18E
0005434550752	279	56	18D
0005434735640	279	57	18J
0005434550713	279	58	19A
0005434550747	279	59	18K
0005434724401	279	60	19D
0005434550721	279	61	19C
0005434724406	279	62	19B
0005434724356	279	63	19F
0005434302418	279	64	19E
0005434724330	279	65	19H
0005434724395	279	66	20A
0005434724312	279	67	19K
0005434724374	279	68	19J
0005433233441	279	69	20E
0005433180734	279	70	20D
0005434724390	279	71	20F
0005434550735	279	72	20J
0005434735637	279	73	20H
0005434724422	279	74	21D
0005434724412	279	75	21F
0005434550740	279	76	21E
0005432277689	279	77	21J
0005434724328	279	78	22A
0005433111467	279	79	21K
0005435142448	279	80	22D
0005434550731	279	81	22C
0005434724416	279	82	22B
0005432277686	279	83	22F
0005434550736	279	84	22E
0005434724399	279	85	22G
0005434724366	279	86	22K
0005433289728	279	87	22J
0005434550734	279	88	23B
0005435142456	279	89	23E
0005435142452	279	90	23D
0005434724347	279	91	23C
0005434724346	279	92	24D
0005434724370	279	93	23K
0005435142457	279	94	23J
0005434724413	279	95	25B
0005434550737	279	96	25F
0005432277687	279	97	25E
0005434724371	279	98	25D
0005434724340	279	99	25G
0005434724415	279	100	25J
0005434724360	279	101	26C
0005434731128	279	102	26A
0005434724380	279	103	26E
0005433233096	279	104	26D
0005434724364	279	105	26G
0005434550756	279	106	26F
0005434550722	279	107	26J
0005434724397	279	108	26H
0005433180728	279	109	26K
0005435142450	279	110	27C
0005434550739	279	111	27F
0005434735639	279	112	27E
0005434724368	279	113	27D
0005433131632	279	114	27H
0005434724386	279	115	27G
0005433233310	279	116	27K
0005434724349	279	117	28C
0005433233176	279	118	28B
0005434724350	279	119	28A
0005434724421	279	120	28D
0005433233293	279	121	28G
0005434724382	279	122	28F
0005434550727	279	123	28E
0005434550709	279	124	28J
0005433289729	279	125	29D
0005434724383	279	126	29C
0005434724423	279	127	29B
0005434724302	279	128	29F
0005434724369	279	129	29E
0005434550733	279	130	29J
0005432277685	279	131	30C
0005434724400	279	132	30B
0005434550755	279	133	30E
0005434724301	279	134	30D
0005434550753	279	135	30G
0005434724361	279	136	30F
0005434724384	279	137	30J
0005434724352	279	138	31B
0005433126775	279	139	31D
0005434724344	279	140	31G
0005434302419	279	141	31F
0005434724398	279	142	31E
0005433233178	279	143	31J
0005434550707	279	144	31H
0005434550729	279	145	32A
0005434731126	279	146	31K
0005433233135	279	147	32B
0005434724420	279	148	32E
0005433126776	279	149	32D
0005434724408	279	150	32G
0005434724307	279	151	32F
0005434724365	279	152	32J
0005434724378	279	153	32H
0005434550762	279	154	33A
0005434724405	279	155	33H
0005433233087	279	156	34A
0005433233082	279	157	33K
0005434550712	279	158	34C
0005434550754	279	159	34B
0005434724362	279	160	34E
0005434550742	279	161	34G
0005434550746	279	162	34J
0005434724379	279	163	34H
0005434724323	279	164	35B
0005432277691	279	165	35A
0005434550714	279	166	35D
0005434724414	279	167	35C
0005434724410	279	168	35G
0005434724358	279	169	35F
0005434724359	279	170	35E
0005434724326	279	171	35J
0005434724318	279	172	36A
0005434550725	279	173	36E
0005433113495	279	174	36D
0005434724311	279	175	36G
0005434724331	279	176	36F
0005434550730	279	177	36K
0005433233083	279	178	36J
0005434724325	279	179	37B
0005434550724	279	180	37A
0005433233088	279	181	37D
0005434724315	279	182	37C
0005434724393	279	183	37G
0005434724404	279	184	37J
0005435142451	279	185	37H
0005434724305	279	186	38A
0005433233311	279	187	38J
0005434724411	279	188	38H
0005434550738	279	189	39D
0005434724317	279	190	39C
0005433233395	279	191	39F
0005434724321	279	192	39H
0005434724308	279	193	39K
0005435142453	279	194	40C
0005434724354	279	195	40B
0005434724372	279	196	40A
0005433233332	279	197	40E
0005434724355	279	198	40D
0005435142459	279	199	40G
0005434724357	279	200	40K
0005434724409	279	201	41B
0005433233165	279	202	41D
0005434724418	279	203	41C
0005435142455	279	204	41E
0005434724348	279	205	41H
0005434724353	279	206	41G
0005434724402	279	207	41K
0005434550744	279	208	42C
0005433233161	279	209	42B
0005434550715	279	210	42E
0005434724329	279	211	42D
0005434724385	279	212	42H
0005434550717	279	213	42G
0005434550743	279	214	42F
0005434550760	279	215	43B
0005434724394	279	216	43A
0005434550750	279	217	43C
0005434731127	279	218	43H
0005433233171	279	219	43G
0005434550741	279	220	43K
0005432277688	279	221	43J
0005435142458	279	222	44C
0005433233164	279	223	44B
0005433233153	279	224	44A
0005434724313	279	225	44E
0005434724351	279	226	44G
0005434724320	279	227	44J
0005434550757	279	228	44H
0005434724424	279	229	45B
0005432277683	279	230	45D
0005434724309	279	231	45E
0005432277684	279	232	45H
0005434724303	279	233	45G
0005433289730	279	234	45K
0005434724392	279	235	46B
0005434724316	279	236	46A
0005433233191	279	237	46D
0005433180668	279	238	46G
0005434724322	279	239	46F
0005434550710	279	240	46J
0005433233116	279	241	46H
0005434724336	279	242	47D
0005434724341	279	243	47C
0005434550728	279	244	47G
0005434724403	279	245	47F
0005434724425	279	246	47E
0005434724338	279	247	47H
0005433180743	279	248	48E
0005434724396	279	249	48D
0005434731129	279	250	48H
0005434724363	279	251	49A
0005434724339	279	252	48K
0005433233140	279	253	49C
0005434550716	279	254	49G
0005434724304	279	255	49F
0005434724337	279	256	49H
0005434724306	279	257	50C
0005434550758	279	258	50A
0005433131633	279	259	49K
0005434724373	279	260	50G
0005432277680	279	261	51D
0005433233179	279	262	50K
0005434724345	279	263	50H
0005433233312	279	264	51E
0005434550751	279	265	51G
0005433233600	9870	1	1H
0005433180880	9870	2	1G
0005433766606	9870	3	1D
0005434723813	9870	4	1K
0005434723515	9870	5	2A
0005433233613	9870	6	2H
0005432199180	9870	7	2G
0005433126800	9870	8	2D
0005434723378	9870	9	3A
0005434723627	9870	10	2K
0005434723557	9870	11	3C
0005434723468	9870	12	3H
0005433289783	9870	13	3G
0005433180873	9870	14	4C
0005433233626	9870	15	4A
0005434031984	9870	16	4G
0005433180860	9870	17	4D
0005433233647	9870	18	4K
0005434723558	9870	19	5C
0005434723758	9870	20	5D
0005434723481	9870	21	11A
0005434723855	9870	22	11F
0005433233639	9870	23	11H
0005432199185	9870	24	11K
0005434723644	9870	25	12E
0005433233651	9870	26	12H
0005433233615	9870	27	12G
0005433233630	9870	28	12F
0005433113515	9870	29	13G
0005432199182	9870	30	14C
0005435142342	9870	31	14D
0005434550458	9870	32	14F
0005434723338	9870	33	14H
0005434723320	9870	34	15C
0005433233597	9870	35	15A
0005434731104	9870	36	15E
0005433233607	9870	37	15D
0005433233595	9870	38	15F
0005434550363	9870	39	16A
0005433233610	9870	40	15K
0005433129232	9870	41	15H
0005434723528	9870	42	16F
0005433233648	9870	43	16K
0005433233609	9870	44	16H
0005433233643	9870	45	16G
0005434723469	9870	46	17D
0005434550327	9870	47	17F
0005433233646	9870	48	17K
0005433233601	9870	49	17H
0005433180876	9870	50	18C
0005433233653	9870	51	18A
0005433233633	9870	52	18E
0005433180879	9870	53	18D
0005432199183	9870	54	18H
0005433233596	9870	55	18G
0005433289784	9870	56	18F
0005433289776	9870	57	19A
0005434550381	9870	58	19F
0005434723871	9870	59	20A
0005434723851	9870	60	19J
0005434723802	9870	61	20D
0005433766607	9870	62	20H
0005433233632	9870	63	20F
0005434723966	9870	64	21B
0005434723608	9870	65	21A
0005433180869	9870	66	21C
0005433233656	9870	67	21F
0005433233606	9870	68	21H
0005433233640	9870	69	22A
0005432199186	9870	70	21K
0005434723411	9870	71	21J
0005433233605	9870	72	22C
0005434723814	9870	73	22E
0005432199181	9870	74	22H
0005433233657	9870	75	22G
0005434723912	9870	76	22F
0005434723410	9870	77	22K
0005434723497	9870	78	23B
0005434723351	9870	79	23A
0005434550516	9870	80	23D
0005434550362	9870	81	23G
0005434550498	9870	82	23F
0005433180859	9870	83	23E
0005434550276	9870	84	23H
0005433126803	9870	85	24D
0005433233612	9870	86	23K
0005433180878	9870	87	24F
0005433233617	9870	88	24E
0005434723358	9870	89	25B
0005433233619	9870	90	24G
0005434723498	9870	91	25G
0005433233645	9870	92	26A
0005433289782	9870	93	25J
0005434723516	9870	94	26C
0005433113513	9870	95	26B
0005433180874	9870	96	26E
0005434723314	9870	97	26D
0005433113514	9870	98	26G
0005434723647	9870	99	26F
0005433233621	9870	100	26J
0005434723823	9870	101	26H
0005434031981	9870	102	27A
0005434723354	9870	103	27D
0005433113516	9870	104	27C
0005433126801	9870	105	27J
0005434550275	9870	106	27K
0005434550319	9870	107	28C
0005434723657	9870	108	28B
0005434723500	9870	109	28D
0005434550285	9870	110	28G
0005433129234	9870	111	28F
0005433180858	9870	112	28J
0005434723329	9870	113	28H
0005433180877	9870	114	29B
0005433180861	9870	115	28K
0005434723439	9870	116	29F
0005434723431	9870	117	29D
0005434031983	9870	118	29H
0005434550266	9870	119	30A
0005433126802	9870	120	29K
0005433233642	9870	121	29J
0005434550313	9870	122	30C
0005433233622	9870	123	30E
0005433233604	9870	124	30G
0005434723850	9870	125	30F
0005434723643	9870	126	30J
0005434723445	9870	127	31B
0005434723337	9870	128	31C
0005433233637	9870	129	31G
0005433233627	9870	130	32A
0005434723473	9870	131	32E
0005434723630	9870	132	32D
0005433180864	9870	133	32K
0005433233658	9870	134	33D
0005433180866	9870	135	33E
0005433233629	9870	136	33J
0005433233598	9870	137	33H
0005433289778	9870	138	33G
0005434723453	9870	139	34A
0005434723319	9870	140	34F
0005434031982	9870	141	34J
0005434723822	9870	142	34H
0005434723757	9870	143	35A
0005433233623	9870	144	34K
0005433233649	9870	145	35C
0005433233641	9870	146	35E
0005433180870	9870	147	35G
0005434723522	9870	148	35K
0005434550273	9870	149	36D
0005434723471	9870	150	36C
0005434723315	9870	151	36E
0005434723631	9870	152	36H
0005433129235	9870	153	36G
0005432199188	9870	154	36F
0005433129233	9870	155	36K
0005433233628	9870	156	37B
0005434723330	9870	157	37C
0005433180856	9870	158	37G
0005433766604	9870	159	37F
0005435142335	9870	160	37E
0005433233603	9870	161	37H
0005433289781	9870	162	38A
0005434723321	9870	163	37K
0005433180872	9870	164	38H
0005433289785	9870	165	39B
0005433233636	9870	166	39A
0005434723735	9870	167	38K
0005434550274	9870	168	39C
0005433233655	9870	169	39F
0005434723424	9870	170	39J
0005433233625	9870	171	39H
0005433233634	9870	172	39G
0005433233652	9870	173	40A
0005434550312	9870	174	40C
0005433233654	9870	175	40B
0005434723480	9870	176	40K
0005434550457	9870	177	40J
0005433233624	9870	178	40H
0005434723847	9870	179	41B
0005434550515	9870	180	41A
0005435142362	9870	181	41D
0005434723607	9870	182	41C
0005434735614	9870	183	41G
0005433233635	9870	184	41E
0005433233631	9870	185	41K
0005433180862	9870	186	41J
0005434723852	9870	187	42C
0005434723535	9870	188	42B
0005434723590	9870	189	42E
0005433233620	9870	190	42D
0005434723451	9870	191	42G
0005433289780	9870	192	42F
0005434550297	9870	193	42J
0005433233659	9870	194	43B
0005433233614	9870	195	43D
0005433289779	9870	196	43C
0005434550348	9870	197	43H
0005433180867	9870	198	43K
0005433180863	9870	199	44C
0005433766603	9870	200	44D
0005434723646	9870	201	44G
0005433233616	9870	202	44F
0005433180855	9870	203	44K
0005433233618	9870	204	44H
0005434723432	9870	205	45C
0005433180875	9870	206	45F
0005433233599	9870	207	45E
0005434723313	9870	208	45J
0005434031985	9870	209	45H
0005433289777	9870	210	46A
0005434723433	9870	211	45K
0005433180857	9870	212	46C
0005434550265	9870	213	47A
0005434550288	9870	214	46K
0005433233650	9870	215	47G
0005434723409	9870	216	47F
0005433766605	9870	217	47H
0005434550263	9870	218	48C
0005433180865	9870	219	48A
0005433233644	9870	220	48H
0005433233608	9870	221	48F
0005433233638	9870	222	49G
0005434723732	9870	223	49F
0005432199184	9870	224	49E
0005433180868	9870	225	49K
0005433180871	9870	226	49H
0005434723470	9870	227	50C
0005433233611	9870	228	50A
0005433233602	9870	229	50F
0005434723448	9870	230	51D
0005432199187	9870	231	51F
0005434550270	9870	232	51G
0005432526781	7775	1	1C
0005432526733	7775	2	1D
0005432069521	7775	3	1K
0005435212401	7775	4	1H
0005432069520	7775	5	2C
0005435725520	7775	6	2H
0005434066877	7775	7	2G
0005433656615	7775	8	2D
0005432526759	7775	9	3G
0005432526758	7775	10	3D
0005435212530	7775	11	3C
0005434066926	7775	12	4A
0005432069525	7775	13	4G
0005432526833	7775	14	4K
0005434066888	7775	15	4H
0005432069528	7775	16	5A
0005435212337	7775	17	5G
0005435212448	7775	18	11A
0005432526795	7775	19	11D
0005434066897	7775	20	11E
0005432526716	7775	21	11H
0005434066887	7775	22	12C
0005432526772	7775	23	12A
0005432526798	7775	24	11K
0005434066885	7775	25	12E
0005432526745	7775	26	12D
0005432526780	7775	27	12H
0005435212373	7775	28	12G
0005435725528	7775	29	12K
0005432526836	7775	30	13C
0005432526752	7775	31	13F
0005432526815	7775	32	13E
0005432526787	7775	33	13H
0005432526736	7775	34	13G
0005434066916	7775	35	14C
0005432526791	7775	36	14A
0005432526750	7775	37	13K
0005434066919	7775	38	14D
0005432526755	7775	39	14G
0005432526784	7775	40	14E
0005432069522	7775	41	14K
0005435212412	7775	42	15C
0005432069519	7775	43	15E
0005432526763	7775	44	15G
0005432526831	7775	45	15K
0005434066918	7775	46	15H
0005432526819	7775	47	16K
0005432526838	7775	48	16H
0005434066914	7775	49	16G
0005432526777	7775	50	17A
0005432150121	7775	51	17D
0005432526811	7775	52	17C
0005435212374	7775	53	17G
0005432526807	7775	54	17F
0005432526809	7775	55	17K
0005434066909	7775	56	17H
0005432526711	7775	57	18B
0005434066930	7775	58	18A
0005432526710	7775	59	18D
0005432526751	7775	60	18F
0005434066945	7775	61	18H
0005432535788	7775	62	19B
0005434066901	7775	63	19A
0005434066895	7775	64	19D
0005432526740	7775	65	19C
0005432069517	7775	66	19F
0005432526778	7775	67	19E
0005435630914	7775	68	19J
0005435212381	7775	69	19H
0005432533264	7775	70	19G
0005432526767	7775	71	20A
0005434066886	7775	72	20D
0005432526834	7775	73	20H
0005432069516	7775	74	20G
0005432526729	7775	75	20J
0005432526722	7775	76	21B
0005434066898	7775	77	21A
0005434066917	7775	78	21D
0005434066908	7775	79	21F
0005432526732	7775	80	21E
0005432526837	7775	81	21H
0005434066927	7775	82	22A
0005432526718	7775	83	21K
0005432526822	7775	84	21J
0005435212446	7775	85	22B
0005432526816	7775	86	22F
0005434066905	7775	87	22D
0005432526810	7775	88	22G
0005432526792	7775	89	22K
0005434066881	7775	90	22J
0005434066920	7775	91	22H
0005435212340	7775	92	23A
0005435212422	7775	93	23D
0005434066934	7775	94	23C
0005432526743	7775	95	23F
0005432526790	7775	96	23E
0005432526720	7775	97	23J
0005432526827	7775	98	23H
0005434066913	7775	99	24F
0005435212640	7775	100	24D
0005434066933	7775	101	25C
0005432526782	7775	102	25B
0005432526764	7775	103	25F
0005432069524	7775	104	25E
0005432526756	7775	105	25H
0005432526735	7775	106	26A
0005434066944	7775	107	25K
0005432526754	7775	108	25J
0005432526802	7775	109	26C
0005432526741	7775	110	26B
0005432526824	7775	111	26E
0005432526805	7775	112	26D
0005435212344	7775	113	26F
0005432526761	7775	114	26J
0005434066878	7775	115	26H
0005432526818	7775	116	27A
0005432526793	7775	117	27C
0005434066935	7775	118	27E
0005432533265	7775	119	27H
0005432069526	7775	120	27G
0005434066882	7775	121	27K
0005432526713	7775	122	27J
0005432526820	7775	123	28E
0005432526747	7775	124	28C
0005432069527	7775	125	28G
0005432526749	7775	126	28J
0005434066900	7775	127	28H
0005434066946	7775	128	29B
0005434066876	7775	129	29F
0005434066911	7775	130	29E
0005435212380	7775	131	29H
0005435212593	7775	132	29G
0005432526823	7775	133	30A
0005432069513	7775	134	29K
0005432526774	7775	135	29J
0005432526783	7775	136	30B
0005434066929	7775	137	30D
0005432526804	7775	138	30C
0005434066880	7775	139	30G
0005432069518	7775	140	30F
0005435212359	7775	141	30J
0005432428898	7775	142	31A
0005434066884	7775	143	31D
0005434066932	7775	144	31C
0005434066938	7775	145	31B
0005432526730	7775	146	31F
0005432526768	7775	147	31E
0005432526832	7775	148	31H
0005435212342	7775	149	32A
0005432526788	7775	150	32C
0005432526794	7775	151	32B
0005432526796	7775	152	32G
0005432526766	7775	153	32F
0005432535790	7775	154	32K
0005434066879	7775	155	32J
0005432150119	7775	156	33B
0005434066903	7775	157	33A
0005432526771	7775	158	33D
0005434066893	7775	159	33G
0005432526719	7775	160	33F
0005434066912	7775	161	34A
0005432526708	7775	162	33K
0005432535786	7775	163	33J
0005432069523	7775	164	34C
0005435212397	7775	165	34E
0005432526724	7775	166	34D
0005435212360	7775	167	34H
0005432069515	7775	168	34G
0005432428897	7775	169	34F
0005432150125	7775	170	34K
0005432526817	7775	171	34J
0005432526739	7775	172	35D
0005434066921	7775	173	35C
0005434066941	7775	174	35B
0005432150122	7775	175	35E
0005435212400	7775	176	35J
0005434066915	7775	177	36A
0005435212423	7775	178	35K
0005434066943	7775	179	36C
0005432526821	7775	180	36B
0005432526748	7775	181	36E
0005432526765	7775	182	36D
0005434066904	7775	183	36H
0005434066889	7775	184	36G
0005432526814	7775	185	36F
0005432150123	7775	186	36J
0005432526738	7775	187	37D
0005434066923	7775	188	37C
0005435212639	7775	189	37F
0005434066940	7775	190	37E
0005432526773	7775	191	37K
0005432526829	7775	192	37J
0005432526728	7775	193	38B
0005432526712	7775	194	38K
0005432526714	7775	195	38H
0005432526826	7775	196	39B
0005432526785	7775	197	39A
0005432526746	7775	198	39D
0005434066906	7775	199	39C
0005435212584	7775	200	39G
0005432526770	7775	201	39F
0005434066910	7775	202	39E
0005432526799	7775	203	39J
0005432526744	7775	204	39H
0005435212498	7775	205	39K
0005432526742	7775	206	40A
0005432150118	7775	207	40D
0005435212368	7775	208	40H
0005434066907	7775	209	40G
0005432526840	7775	210	40F
0005432526707	7775	211	40K
0005435212413	7775	212	40J
0005432526801	7775	213	41B
0005435212414	7775	214	41D
0005432526769	7775	215	41C
0005434066924	7775	216	41F
0005432537038	7775	217	41E
0005432526828	7775	218	41J
0005432526808	7775	219	42C
0005434066896	7775	220	42B
0005432526715	7775	221	42D
0005435725511	7775	222	42G
0005432526803	7775	223	42F
0005434066939	7775	224	42J
0005432526789	7775	225	42H
0005434066890	7775	226	43B
0005435212341	7775	227	43D
0005432526753	7775	228	43C
0005432428895	7775	229	43E
0005432537037	7775	230	43J
0005434066947	7775	231	43G
0005434066942	7775	232	44A
0005432526737	7775	233	43K
0005432526757	7775	234	44B
0005435212531	7775	235	44E
0005432526760	7775	236	44C
0005434066883	7775	237	44K
0005432150124	7775	238	44J
0005432526723	7775	239	45B
0005432526825	7775	240	45A
0005432535789	7775	241	45F
0005432526725	7775	242	45E
0005432069514	7775	243	45G
0005434066899	7775	244	45K
0005432526731	7775	245	45J
0005434066902	7775	246	46A
0005434066891	7775	247	46E
0005432428896	7775	248	46D
0005435212338	7775	249	46C
0005432526806	7775	250	46J
0005434066928	7775	251	46H
0005432526734	7775	252	47C
0005432526779	7775	253	47A
0005432526813	7775	254	47E
0005432526726	7775	255	47D
0005432526800	7775	256	47G
0005432526717	7775	257	47K
0005434066937	7775	258	47H
0005434066936	7775	259	48D
0005434066892	7775	260	48C
0005432526709	7775	261	48A
0005434066925	7775	262	48E
0005432535787	7775	263	48H
0005432526775	7775	264	48G
0005432526776	7775	265	48K
0005432526797	7775	266	49E
0005432150120	7775	267	49C
0005432526839	7775	268	49G
0005432526786	7775	269	49F
0005432526835	7775	270	49K
0005432526830	7775	271	49H
0005435212407	7775	272	50C
0005434066922	7775	273	50A
0005434066931	7775	274	50E
0005432537036	7775	275	50F
0005432526727	7775	276	50K
0005434066894	7775	277	50H
0005432526812	7775	278	51E
0005432526721	7775	279	51D
0005432526762	7775	280	51G
0005435423647	5359	1	1C
0005435612648	5359	2	1A
0005435423759	5359	3	1G
0005434343888	5359	4	1D
0005435423819	5359	5	2A
0005435612620	5359	6	1H
0005435612677	5359	7	2D
0005435423618	5359	8	2C
0005435612621	5359	9	2H
0005434343896	5359	10	2G
0005435612615	5359	11	3A
0005435612646	5359	12	3D
0005435490192	5359	13	3C
0005435423838	5359	14	3G
0005434343875	5359	15	4A
0005435612652	5359	16	3K
0005434244550	5359	17	4K
0005435612682	5359	18	4H
0005435319453	5359	19	5D
0005434244583	5359	20	5C
0005435423729	5359	21	5A
0005434343877	5359	22	5G
0005435304990	5359	23	11A
0005434343892	5359	24	5K
0005435612635	5359	25	11D
0005435423833	5359	26	11F
0005434343900	5359	27	11E
0005435097127	5359	28	11K
0005435612640	5359	29	11H
0005432047516	5359	30	11G
0005434343876	5359	31	12C
0005434343881	5359	32	12E
0005434244455	5359	33	12D
0005435612636	5359	34	12F
0005434244462	5359	35	12K
0005435423793	5359	36	13A
0005435612619	5359	37	13F
0005435304991	5359	38	13E
0005435423926	5359	39	14C
0005435097120	5359	40	14D
0005434244463	5359	41	14G
0005434343891	5359	42	14F
0005435612617	5359	43	14K
0005435423577	5359	44	14H
0005435097124	5359	45	15C
0005435612667	5359	46	15E
0005435612679	5359	47	15D
0005435423679	5359	48	15H
0005435423754	5359	49	15G
0005434573217	5359	50	15F
0005434573229	5359	51	16A
0005434573223	5359	52	16D
0005434343899	5359	53	16C
0005435423617	5359	54	16F
0005434343910	5359	55	16E
0005434343908	5359	56	16G
0005435612632	5359	57	17A
0005435490193	5359	58	16K
0005435097129	5359	59	17E
0005434244514	5359	60	17D
0005434573222	5359	61	17F
0005432133073	5359	62	17H
0005432133074	5359	63	18E
0005435612645	5359	64	18D
0005435612681	5359	65	18G
0005434343903	5359	66	18F
0005433719086	5359	67	18J
0005435423813	5359	68	19B
0005432133080	5359	69	19A
0005435612639	5359	70	19D
0005434343890	5359	71	19F
0005434343874	5359	72	19E
0005434573226	5359	73	19H
0005434244492	5359	74	19G
0005432133068	5359	75	19J
0005435423706	5359	76	20B
0005435319445	5359	77	20E
0005434244502	5359	78	20D
0005435612613	5359	79	20C
0005435612637	5359	80	20G
0005435612680	5359	81	21A
0005435491422	5359	82	20K
0005434244525	5359	83	21D
0005435423583	5359	84	21C
0005435612655	5359	85	21B
0005434244476	5359	86	21F
0005434343893	5359	87	21E
0005432363364	5359	88	21H
0005435380224	5359	89	21G
0005435423666	5359	90	22A
0005434656521	5359	91	21K
0005434573219	5359	92	22B
0005434573231	5359	93	22H
0005434573230	5359	94	22G
0005435612633	5359	95	22K
0005432133065	5359	96	23A
0005435097123	5359	97	23F
0005435097121	5359	98	23E
0005434343887	5359	99	23H
0005434573224	5359	100	23K
0005435423790	5359	101	24F
0005435612616	5359	102	24E
0005435423775	5359	103	24G
0005434343907	5359	104	25D
0005434244544	5359	105	25F
0005435612647	5359	106	25G
0005435097119	5359	107	26A
0005435319432	5359	108	26C
0005434573227	5359	109	26B
0005434573225	5359	110	26F
0005435612661	5359	111	26H
0005434343879	5359	112	27B
0005434343883	5359	113	26K
0005432047515	5359	114	27E
0005435612638	5359	115	27H
0005435423709	5359	116	27G
0005435612641	5359	117	27K
0005435424012	5359	118	27J
0005434343882	5359	119	28C
0005434343884	5359	120	28B
0005435612612	5359	121	28E
0005435423922	5359	122	28D
0005434573220	5359	123	28G
0005435612650	5359	124	28F
0005435423731	5359	125	28J
0005435423728	5359	126	29B
0005435423700	5359	127	29A
0005434244513	5359	128	28K
0005434343902	5359	129	29D
0005432840977	5359	130	29C
0005435555348	5359	131	29F
0005435612670	5359	132	29E
0005435612623	5359	133	29J
0005435612664	5359	134	29H
0005435612666	5359	135	30A
0005435612658	5359	136	29K
0005432133071	5359	137	30B
0005432133078	5359	138	30E
0005435612630	5359	139	30D
0005435380225	5359	140	30G
0005432133067	5359	141	30F
0005434244512	5359	142	30K
0005434573218	5359	143	30J
0005435423791	5359	144	30H
0005435612676	5359	145	31B
0005432133075	5359	146	31A
0005435097122	5359	147	31D
0005433719087	5359	148	31E
0005432133077	5359	149	31G
0005434244464	5359	150	32A
0005435612624	5359	151	31K
0005432133066	5359	152	31J
0005435097126	5359	153	32B
0005435612663	5359	154	32E
0005435612659	5359	155	32D
0005435612629	5359	156	32C
0005435612649	5359	157	32H
0005435612657	5359	158	32G
0005434244474	5359	159	32F
0005435302120	5359	160	32J
0005435612634	5359	161	33B
0005434343901	5359	162	33A
0005434244549	5359	163	33D
0005435423799	5359	164	33E
0005434343889	5359	165	33J
0005435612626	5359	166	33G
0005434244491	5359	167	33K
0005435612625	5359	168	34A
0005434343878	5359	169	34E
0005435423753	5359	170	34D
0005432133069	5359	171	34K
0005435612675	5359	172	34J
0005435319446	5359	173	35A
0005435423714	5359	174	35D
0005435423812	5359	175	35F
0005434343897	5359	176	35E
0005435423834	5359	177	36A
0005435612660	5359	178	35J
0005434343904	5359	179	36B
0005435612643	5359	180	36E
0005434244478	5359	181	36H
0005432133076	5359	182	36G
0005435319427	5359	183	37C
0005435423629	5359	184	37G
0005435424011	5359	185	37E
0005435612631	5359	186	37J
0005434244475	5359	187	37K
0005435423880	5359	188	38B
0005435423752	5359	189	38K
0005435423713	5359	190	38J
0005434343880	5359	191	39D
0005434343886	5359	192	39C
0005435612642	5359	193	39B
0005435423708	5359	194	39E
0005432133072	5359	195	39J
0005435612614	5359	196	39G
0005435423907	5359	197	40C
0005435097125	5359	198	40B
0005435491420	5359	199	40E
0005435555349	5359	200	40D
0005434343885	5359	201	40K
0005435612627	5359	202	40J
0005435423625	5359	203	40H
0005435612644	5359	204	41B
0005434343909	5359	205	41D
0005434343894	5359	206	41G
0005435491421	5359	207	41F
0005435612671	5359	208	41J
0005434656520	5359	209	41H
0005435423818	5359	210	42C
0005434244545	5359	211	42B
0005435612651	5359	212	42E
0005432133070	5359	213	42G
0005435423774	5359	214	42J
0005432840978	5359	215	43A
0005435612653	5359	216	42K
0005434244459	5359	217	43D
0005434343906	5359	218	43B
0005432133079	5359	219	43F
0005435612662	5359	220	43E
0005435555350	5359	221	44A
0005432363363	5359	222	43K
0005435490194	5359	223	43J
0005434244495	5359	224	44B
0005435612668	5359	225	44E
0005434343905	5359	226	44C
0005435612618	5359	227	44G
0005435423817	5359	228	44F
0005435612622	5359	229	44J
0005434573228	5359	230	45B
0005435423923	5359	231	45A
0005435423681	5359	232	44K
0005435612656	5359	233	45D
0005435423690	5359	234	45F
0005435423816	5359	235	45H
0005435423663	5359	236	45K
0005435612628	5359	237	46B
0005435612672	5359	238	46G
0005435097128	5359	239	46F
0005435612654	5359	240	46J
0005434244539	5359	241	46K
0005435423896	5359	242	47E
0005434573221	5359	243	47G
0005435612678	5359	244	47F
0005434343895	5359	245	48F
0005435423794	5359	246	48E
0005435423732	5359	247	48H
0005435423623	5359	248	48K
0005435612669	5359	249	49D
0005435612674	5359	250	49C
0005435612665	5359	251	49E
0005434343898	5359	252	49H
0005434244607	5359	253	50A
0005435612673	5359	254	51E
0005435423695	5359	255	51D
0005435423597	5359	256	51G
0005435611758	10930	1	1C
0005435611709	10930	2	1H
0005435424201	10930	3	2H
0005435424177	10930	4	2G
0005435424203	10930	5	3D
0005435424156	10930	6	3C
0005434244709	10930	7	4C
0005435424161	10930	8	4A
0005435424143	10930	9	4G
0005434573129	10930	10	4K
0005434573126	10930	11	5A
0005435424184	10930	12	5G
0005434573125	10930	13	5K
0005434244699	10930	14	11D
0005434244715	10930	15	11F
0005435611799	10930	16	11K
0005435611760	10930	17	12A
0005432164966	10930	18	12H
0005433719108	10930	19	12G
0005435490172	10930	20	13D
0005434244701	10930	21	13A
0005434244707	10930	22	13F
0005435424178	10930	23	13H
0005435424204	10930	24	14C
0005435611837	10930	25	13K
0005435424206	10930	26	14E
0005432164967	10930	27	14D
0005435424183	10930	28	14G
0005434244712	10930	29	14H
0005435491406	10930	30	15C
0005435424205	10930	31	15D
0005435319494	10930	32	15G
0005435424196	10930	33	15K
0005435611740	10930	34	16H
0005432363385	10930	35	17A
0005435424146	10930	36	17D
0005435424145	10930	37	17G
0005435424166	10930	38	17H
0005435424167	10930	39	18C
0005435424173	10930	40	18G
0005435424192	10930	41	18F
0005435424148	10930	42	18J
0005435424189	10930	43	19A
0005435319488	10930	44	19D
0005434244723	10930	45	19E
0005435424195	10930	46	19H
0005435490171	10930	47	20A
0005434244721	10930	48	19K
0005435319490	10930	49	20D
0005434244718	10930	50	20F
0005435424152	10930	51	20J
0005434244716	10930	52	20H
0005432363384	10930	53	21B
0005435611798	10930	54	21J
0005434573124	10930	55	21H
0005435611700	10930	56	22A
0005434244700	10930	57	22C
0005435611860	10930	58	22B
0005435424191	10930	59	22D
0005434244705	10930	60	22G
0005433719111	10930	61	23C
0005435424202	10930	62	23G
0005435424199	10930	63	23F
0005433719110	10930	64	24D
0005435319491	10930	65	24E
0005435319489	10930	66	25B
0005434244719	10930	67	25K
0005434244696	10930	68	26B
0005435380248	10930	69	26E
0005434244724	10930	70	26F
0005435424163	10930	71	26J
0005434244714	10930	72	27A
0005435424174	10930	73	26K
0005435424169	10930	74	27E
0005435424171	10930	75	27J
0005435424157	10930	76	28B
0005435611840	10930	77	28J
0005432363386	10930	78	28K
0005434244703	10930	79	29D
0005432840994	10930	80	29F
0005432166871	10930	81	29E
0005435424149	10930	82	29H
0005435424208	10930	83	29G
0005435611727	10930	84	29K
0005435424197	10930	85	30C
0005435611736	10930	86	30B
0005435611702	10930	87	30A
0005435490173	10930	88	30D
0005434244698	10930	89	30F
0005435424158	10930	90	30J
0005435424141	10930	91	30H
0005435424187	10930	92	31B
0005435424200	10930	93	30K
0005434244720	10930	94	31H
0005434573119	10930	95	31K
0005434244713	10930	96	32E
0005435424142	10930	97	32D
0005434244722	10930	98	32G
0005435424144	10930	99	32J
0005435319496	10930	100	33D
0005435611708	10930	101	33C
0005434573127	10930	102	33B
0005434573128	10930	103	33F
0005435424160	10930	104	33E
0005435380249	10930	105	33J
0005435611734	10930	106	33H
0005434244710	10930	107	34C
0005435611728	10930	108	34D
0005435490169	10930	109	34F
0005435380250	10930	110	34K
0005435611738	10930	111	34J
0005435611769	10930	112	35D
0005433719112	10930	113	35F
0005432164965	10930	114	35E
0005435424198	10930	115	36C
0005435611732	10930	116	36E
0005435611861	10930	117	36D
0005432164970	10930	118	36H
0005435611835	10930	119	36J
0005435611801	10930	120	37A
0005435424151	10930	121	37E
0005435424209	10930	122	37H
0005435611735	10930	123	37K
0005435611739	10930	124	39B
0005435319492	10930	125	39A
0005434573109	10930	126	39D
0005435424194	10930	127	39C
0005435380247	10930	128	39F
0005435424182	10930	129	39H
0005435424172	10930	130	40D
0005433719109	10930	131	40H
0005435424139	10930	132	40G
0005435611864	10930	133	40F
0005434244704	10930	134	40K
0005434244702	10930	135	41B
0005435319495	10930	136	41A
0005435424168	10930	137	41D
0005435424188	10930	138	41G
0005435424170	10930	139	41F
0005435319493	10930	140	41E
0005435611752	10930	141	41J
0005435424181	10930	142	42A
0005434573110	10930	143	42C
0005434244708	10930	144	42E
0005435424147	10930	145	42D
0005434343584	10930	146	42G
0005435611836	10930	147	42F
0005435424193	10930	148	42K
0005435424165	10930	149	42J
0005435611759	10930	150	43B
0005432164964	10930	151	43F
0005432164969	10930	152	43H
0005434244695	10930	153	43K
0005435611707	10930	154	43J
0005435611706	10930	155	44C
0005435611757	10930	156	44F
0005435611841	10930	157	44G
0005435611698	10930	158	44J
0005432363388	10930	159	45B
0005434244697	10930	160	45A
0005435319487	10930	161	45C
0005432164968	10930	162	45F
0005435424180	10930	163	45E
0005435611701	10930	164	45G
0005435424190	10930	165	46A
0005434244706	10930	166	46E
0005435042836	10930	167	46D
0005435380251	10930	168	46H
0005435611800	10930	169	46G
0005435424207	10930	170	46F
0005432840993	10930	171	46J
0005435424179	10930	172	47A
0005435424155	10930	173	47E
0005435424150	10930	174	47D
0005435424176	10930	175	47G
0005432363387	10930	176	47F
0005435424164	10930	177	47H
0005434244717	10930	178	48E
0005435611747	10930	179	48H
0005435424185	10930	180	48G
0005435424186	10930	181	48F
0005435424153	10930	182	49C
0005435424159	10930	183	49A
0005435424175	10930	184	48K
0005435611699	10930	185	49H
0005434244694	10930	186	50C
0005435424140	10930	187	49K
0005435042835	10930	188	50D
0005432166872	10930	189	50H
0005435424162	10930	190	50F
0005434244711	10930	191	50K
0005435611868	10930	192	51F
0005435424154	10930	193	51E
0005432181523	3359	1	1C
0005432181511	3359	2	1A
0005433507012	3359	3	1D
0005432459205	3359	4	2A
0005432459077	3359	5	1F
0005433507018	3359	6	2F
0005432181520	3359	7	3A
0005433805067	3359	8	3D
0005432181506	3359	9	3C
0005433633499	3359	10	3F
0005433507010	3359	11	4C
0005432181517	3359	12	4F
0005433633524	3359	13	4D
0005433633501	3359	14	5A
0005433633497	3359	15	5C
0005433805074	3359	16	6A
0005433633522	3359	17	5F
0005432459096	3359	18	6C
0005433633517	3359	19	6D
0005432459217	3359	20	7A
0005433805076	3359	21	7D
0005433633502	3359	22	7C
0005433805064	3359	23	7F
0005432181508	3359	24	8C
0005432458965	3359	25	8B
0005432458960	3359	26	8A
0005433507007	3359	27	8E
0005433633519	3359	28	9A
0005433633494	3359	29	9B
0005432459038	3359	30	9D
0005433507002	3359	31	9F
0005433507013	3359	32	10A
0005432181504	3359	33	10B
0005433805055	3359	34	10F
0005433805075	3359	35	10E
0005433507003	3359	36	11C
0005433507020	3359	37	11F
0005433633525	3359	38	11E
0005433633496	3359	39	12A
0005433805054	3359	40	12B
0005432181505	3359	41	12D
0005433633509	3359	42	12C
0005433805070	3359	43	12E
0005433633506	3359	44	12F
0005433633518	3359	45	13B
0005432459121	3359	46	13E
0005432459103	3359	47	14C
0005432459227	3359	48	14B
0005432181516	3359	49	14E
0005433507014	3359	50	14F
0005433633504	3359	51	15A
0005432181522	3359	52	15C
0005433507019	3359	53	15B
0005433633516	3359	54	15D
0005433507022	3359	55	15E
0005432181509	3359	56	16A
0005433633492	3359	57	16B
0005433507008	3359	58	16C
0005433805059	3359	59	17A
0005433805056	3359	60	16F
0005432459025	3359	61	17B
0005433507004	3359	62	17C
0005433633495	3359	63	17E
0005433633520	3359	64	17D
0005433507023	3359	65	17F
0005433805072	3359	66	18A
0005432458978	3359	67	18C
0005432458967	3359	68	18B
0005433633513	3359	69	18E
0005433633523	3359	70	18D
0005432459061	3359	71	18F
0005432181503	3359	72	19B
0005433805062	3359	73	19D
0005433507021	3359	74	19E
0005433507006	3359	75	20C
0005433633498	3359	76	20D
0005433633512	3359	77	20F
0005433805051	3359	78	21A
0005432458973	3359	79	21C
0005432459037	3359	80	21B
0005433507005	3359	81	21D
0005433805060	3359	82	22A
0005432181510	3359	83	21F
0005433805047	3359	84	22B
0005432459060	3359	85	22C
0005433633503	3359	86	22E
0005433805061	3359	87	22D
0005433507009	3359	88	22F
0005433805071	3359	89	23A
0005433633510	3359	90	23B
0005433805069	3359	91	23D
0005433633493	3359	92	23F
0005433507015	3359	93	24B
0005432181521	3359	94	24A
0005433633508	3359	95	24D
0005433805068	3359	96	24C
0005433805048	3359	97	24E
0005432459036	3359	98	25A
0005433633511	3359	99	25C
0005432459100	3359	100	25B
0005432181513	3359	101	25E
0005433805066	3359	102	26B
0005432181515	3359	103	26A
0005433805073	3359	104	26D
0005432181512	3359	105	26E
0005433633500	3359	106	26F
0005432181507	3359	107	27B
0005432181519	3359	108	27C
0005433633514	3359	109	27D
0005432181514	3359	110	27E
0005433805065	3359	111	28A
0005433805050	3359	112	28B
0005433805057	3359	113	28D
0005433507016	3359	114	28C
0005433805049	3359	115	28E
0005432459101	3359	116	29A
0005432459097	3359	117	28F
0005433805052	3359	118	29B
0005432459226	3359	119	29C
0005433805063	3359	120	29E
0005433633526	3359	121	29D
0005433805058	3359	122	30A
0005433633507	3359	123	30B
0005433633521	3359	124	30D
0005432458968	3359	125	30C
0005433805053	3359	126	30E
0005433507011	3359	127	31A
0005432181518	3359	128	30F
0005433633505	3359	129	31C
0005433507017	3359	130	31F
0005433633515	3359	131	31E
0005435884433	3360	1	3F
0005435884555	3360	2	4A
0005435884575	3360	3	5C
0005435884466	3360	4	8F
0005435884472	3360	5	10E
0005435884556	3360	6	11E
0005435884412	3360	7	12B
0005435884447	3360	8	13C
0005435884606	3360	9	13B
0005435884493	3360	10	13D
0005435884452	3360	11	13F
0005435884471	3360	12	15D
0005435884437	3360	13	16B
0005435884487	3360	14	16F
0005435884414	3360	15	17A
0005435884413	3360	16	17C
0005435884371	3360	17	17E
0005435884644	3360	18	17F
0005435884486	3360	19	18B
0005435884557	3360	20	18C
0005435884563	3360	21	20D
0005435884432	3360	22	20F
0005435884446	3360	23	21C
0005435884438	3360	24	23B
0005435884485	3360	25	23D
0005435884379	3360	26	23F
0005435884370	3360	27	24B
0005435884434	3360	28	24A
0005435884415	3360	29	24C
0005435884401	3360	30	24F
0005435884396	3360	31	25A
0005435884425	3360	32	25D
0005435884451	3360	33	27B
0005435884424	3360	34	27A
0005435884498	3360	35	27D
0005435884459	3360	36	29C
0005435884576	3360	37	30C
0005435884468	3360	38	31C
0005435884467	3360	39	31D
0005435884564	3360	40	31F
0005432459408	8221	1	1A
0005432459426	8221	2	1C
0005432042588	8221	3	1F
0005435884795	8221	4	1D
0005432459421	8221	5	2A
0005435884773	8221	6	2C
0005435884821	8221	7	2F
0005435884822	8221	8	2D
0005435884819	8221	9	3A
0005432459389	8221	10	3C
0005432459398	8221	11	3D
0005435884825	8221	12	4A
0005432042589	8221	13	3F
0005435884809	8221	14	4D
0005432459436	8221	15	5A
0005432459424	8221	16	4F
0005432459405	8221	17	5C
0005435884797	8221	18	5D
0005432459431	8221	19	6A
0005432459392	8221	20	6C
0005435884802	8221	21	6D
0005432042590	8221	22	7A
0005433506910	8221	23	6F
0005432459384	8221	24	7C
0005435884784	8221	25	7F
0005432459409	8221	26	7D
0005432459413	8221	27	8A
0005432459429	8221	28	8B
0005432459393	8221	29	8C
0005435884775	8221	30	8E
0005432459419	8221	31	8D
0005432459397	8221	32	8F
0005435884811	8221	33	9C
0005435884827	8221	34	9D
0005432459432	8221	35	9E
0005432459406	8221	36	9F
0005434326264	8221	37	10C
0005432459402	8221	38	10E
0005435884798	8221	39	10F
0005432459407	8221	40	11B
0005432459415	8221	41	11C
0005432459414	8221	42	11D
0005432042591	8221	43	11F
0005434312300	8221	44	11E
0005435884782	8221	45	12A
0005432459401	8221	46	12B
0005435884779	8221	47	12D
0005435884794	8221	48	12C
0005435884771	8221	49	12F
0005435884801	8221	50	13B
0005432042581	8221	51	13A
0005432042585	8221	52	13C
0005435884816	8221	53	13E
0005432459428	8221	54	13F
0005435884799	8221	55	14B
0005435884796	8221	56	14A
0005435884791	8221	57	14D
0005435884823	8221	58	14C
0005432459396	8221	59	14E
0005435884817	8221	60	15A
0005432459388	8221	61	15C
0005432459386	8221	62	15B
0005435884770	8221	63	15D
0005435884781	8221	64	15F
0005435884820	8221	65	16A
0005432459434	8221	66	16B
0005435884790	8221	67	16E
0005432459390	8221	68	16D
0005435884826	8221	69	17A
0005432459418	8221	70	16F
0005435884805	8221	71	17B
0005435884815	8221	72	17C
0005435884788	8221	73	17D
0005432459412	8221	74	17E
0005432459430	8221	75	18A
0005432459435	8221	76	18C
0005432042583	8221	77	18E
0005435884789	8221	78	18F
0005432459423	8221	79	20A
0005435884814	8221	80	19E
0005432459387	8221	81	20B
0005433506868	8221	82	20D
0005433506853	8221	83	20C
0005433506897	8221	84	20E
0005434312302	8221	85	20F
0005432459416	8221	86	21B
0005435884803	8221	87	21A
0005432042587	8221	88	21D
0005432042593	8221	89	21E
0005432459417	8221	90	21F
0005435884785	8221	91	22C
0005432459411	8221	92	22E
0005435884824	8221	93	22D
0005435884793	8221	94	23A
0005432042594	8221	95	23C
0005435884777	8221	96	23B
0005435884806	8221	97	23D
0005432459420	8221	98	23E
0005432459403	8221	99	24A
0005432459425	8221	100	24C
0005435884774	8221	101	24E
0005435884807	8221	102	24D
0005434312301	8221	103	24F
0005432042586	8221	104	25A
0005432459410	8221	105	25C
0005435884804	8221	106	25B
0005433506895	8221	107	25D
0005433506911	8221	108	25E
0005435884776	8221	109	26A
0005432459385	8221	110	25F
0005435884808	8221	111	26B
0005435884818	8221	112	26C
0005433506857	8221	113	26E
0005435884800	8221	114	26D
0005435884810	8221	115	26F
0005435884783	8221	116	27C
0005432042582	8221	117	27B
0005435884813	8221	118	27D
0005435884787	8221	119	27E
0005433506858	8221	120	27F
0005435884769	8221	121	28B
0005435884792	8221	122	28A
0005432459394	8221	123	28C
0005435884772	8221	124	28E
0005432459433	8221	125	29A
0005432042592	8221	126	29C
0005435884786	8221	127	29B
0005432459399	8221	128	29E
0005432459400	8221	129	29D
0005434326265	8221	130	30A
0005432042584	8221	131	30B
0005432459422	8221	132	30D
0005432459395	8221	133	30C
0005432459404	8221	134	30E
0005435884812	8221	135	30F
0005432459427	8221	136	31B
0005433506874	8221	137	31A
0005435884778	8221	138	31C
0005435884780	8221	139	31E
0005432459391	8221	140	31F
0005433804836	8219	1	1A
0005433804938	8219	2	1F
0005433804888	8219	3	3D
0005433804787	8219	4	5A
0005433804889	8219	5	4F
0005433804922	8219	6	6A
0005433804805	8219	7	7D
0005433804788	8219	8	8B
0005433633249	8219	9	8C
0005433804807	8219	10	9F
0005433804799	8219	11	12C
0005433633255	8219	12	13B
0005434271281	8219	13	16C
0005433633412	8219	14	16B
0005433804777	8219	15	16F
0005433633321	8219	16	17A
0005433633322	8219	17	18A
0005433633277	8219	18	18F
0005433633278	8219	19	21F
0005433804781	8219	20	21E
0005433633411	8219	21	22B
0005433804800	8219	22	23C
0005433804830	8219	23	23F
0005433633220	8219	24	23E
0005433804868	8219	25	25B
0005433633226	8219	26	26E
0005433804829	8219	27	26F
0005433804778	8219	28	27D
0005433804847	8219	29	30B
0005432727826	4602	1	1D
0005432382826	4602	2	1F
0005433453746	4602	3	2A
0005432382821	4602	4	2C
0005432382816	4602	5	2D
0005433453743	4602	6	2F
0005432382838	4602	7	3C
0005432382809	4602	8	3D
0005432727827	4602	9	3F
0005432382834	4602	10	4A
0005432382828	4602	11	4F
0005433194832	4602	12	5A
0005432382804	4602	13	5C
0005432382818	4602	14	5D
0005432382808	4602	15	5E
0005432382812	4602	16	5F
0005433722163	4602	17	6A
0005432382824	4602	18	6C
0005432382832	4602	19	6F
0005432382806	4602	20	7A
0005433722159	4602	21	7C
0005432727823	4602	22	7E
0005432382811	4602	23	8A
0005432727824	4602	24	8D
0005432382805	4602	25	8E
0005432727820	4602	26	8F
0005433194831	4602	27	9A
0005432382813	4602	28	9C
0005432382836	4602	29	9D
0005432382815	4602	30	9E
0005433722160	4602	31	10A
0005432382810	4602	32	10C
0005432382837	4602	33	10D
0005432382841	4602	34	10E
0005432382817	4602	35	10F
0005432382819	4602	36	11C
0005432727818	4602	37	11D
0005433194833	4602	38	11E
0005432382835	4602	39	11F
0005433454854	4602	40	12C
0005432727819	4602	41	12D
0005432382839	4602	42	12E
0005432382830	4602	43	12F
0005432382814	4602	44	13A
0005432382820	4602	45	13C
0005432382822	4602	46	13D
0005432382829	4602	47	14A
0005432727821	4602	48	14C
0005432382825	4602	49	14F
0005432382827	4602	50	15A
0005433194828	4602	51	15C
0005432382840	4602	52	15D
0005432382842	4602	53	15E
0005433454855	4602	54	15F
0005432727828	4602	55	16C
0005433722158	4602	56	16D
0005432382833	4602	57	16E
0005432727830	4602	58	16F
0005433722164	4602	59	17A
0005433722165	4602	60	17C
0005432382843	4602	61	17D
0005433194829	4602	62	17E
0005432727829	4602	63	17F
0005432382807	4602	64	18C
0005432382823	4602	65	18D
0005433722161	4602	66	18E
0005433722166	4602	67	19A
0005433453745	4602	68	19C
0005432382831	4602	69	19D
0005433194830	4602	70	19E
0005432727825	4602	71	19F
0005433722162	4602	72	20A
0005433453744	4602	73	20D
0005432727822	4602	74	20F
0005433194817	30167	1	7C
0005432727727	30167	2	8F
0005432727765	30167	3	19A
0005432727766	30167	4	19C
0005432727726	30167	5	20F
0005435529074	1739	1	1A
0005435540819	1739	2	1C
0005432924961	1739	3	2C
0005435540802	1739	4	3D
0005435529071	1739	5	3F
0005435540808	1739	6	4D
0005433516804	1739	7	4E
0005435540813	1739	8	5A
0005433516802	1739	9	5C
0005435540821	1739	10	5D
0005433516799	1739	11	5E
0005435540816	1739	12	5F
0005435540804	1739	13	6A
0005435540815	1739	14	6E
0005435540810	1739	15	6F
0005435529062	1739	16	7A
0005435529063	1739	17	7C
0005433516797	1739	18	7D
0005435529073	1739	19	7E
0005432924954	1739	20	8A
0005435529075	1739	21	8C
0005435540806	1739	22	8E
0005435540822	1739	23	8F
0005435540814	1739	24	9A
0005435540818	1739	25	9D
0005435529061	1739	26	9E
0005435529057	1739	27	10A
0005435540807	1739	28	10C
0005435529064	1739	29	10D
0005435529076	1739	30	10E
0005435540803	1739	31	10F
0005435540817	1739	32	11D
0005435529060	1739	33	11E
0005435529059	1739	34	11F
0005433516801	1739	35	12A
0005435529066	1739	36	12C
0005435529072	1739	37	12E
0005435540805	1739	38	12F
0005433516798	1739	39	13C
0005435529069	1739	40	13D
0005435529056	1739	41	13E
0005435529067	1739	42	13F
0005435529070	1739	43	14A
0005435529055	1739	44	14C
0005435529065	1739	45	14F
0005433516805	1739	46	15A
0005432294465	1739	47	15C
0005435529077	1739	48	15E
0005435540809	1739	49	15F
0005435540820	1739	50	16D
0005432294466	1739	51	16E
0005435529058	1739	52	17A
0005433516803	1739	53	17E
0005435529068	1739	54	17F
0005435540800	1739	55	18A
0005435540801	1739	56	18D
0005433516800	1739	57	18F
0005435540812	1739	58	20C
0005435540811	1739	59	20F
0005433516764	22021	1	1A
0005435517642	22021	2	1D
0005435517643	22021	3	4C
0005435517610	22021	4	4E
0005433516728	22021	5	5D
0005435540643	22021	6	5F
0005433516739	22021	7	6A
0005433516729	22021	8	6F
0005433516732	22021	9	9A
0005433516733	22021	10	9D
0005432924993	22021	11	9F
0005435540658	22021	12	10A
0005435517590	22021	13	13D
0005435517589	22021	14	14E
0005435540657	22021	15	14F
0005432924992	22021	16	15D
0005432924991	22021	17	15F
0005433516738	22021	18	17C
0005435540698	22021	19	17F
0005435540659	22021	20	19A
0005432924994	22021	21	20C
0005435517595	22021	22	20A
0005435517609	22021	23	20D
0005432838745	7352	1	1A
0005432838748	7352	2	1C
0005432073357	7352	3	1D
0005432838766	7352	4	1F
0005432838742	7352	5	2A
0005434664919	7352	6	2C
0005434458614	7352	7	2D
0005434458624	7352	8	2F
0005432838737	7352	9	3A
0005432838735	7352	10	3C
0005434458617	7352	11	3D
0005435252433	7352	12	3F
0005434458621	7352	13	4A
0005435252387	7352	14	4C
0005434458620	7352	15	4D
0005432838739	7352	16	4E
0005432838757	7352	17	4F
0005434458616	7352	18	5A
0005432838758	7352	19	5C
0005434458610	7352	20	5D
0005434458611	7352	21	5F
0005432073358	7352	22	6C
0005432838756	7352	23	6D
0005435252467	7352	24	6E
0005432838753	7352	25	6F
0005432838764	7352	26	7A
0005435252402	7352	27	7C
0005432073360	7352	28	7D
0005432838743	7352	29	7E
0005435252385	7352	30	8A
0005432838740	7352	31	8D
0005432073359	7352	32	8E
0005432838736	7352	33	8F
0005432838754	7352	34	9A
0005432838741	7352	35	9E
0005434458618	7352	36	9F
0005434458606	7352	37	10A
0005434458613	7352	38	10D
0005432838752	7352	39	10E
0005432838761	7352	40	10F
0005434458609	7352	41	11A
0005434458619	7352	42	11D
0005434458615	7352	43	12A
0005432838765	7352	44	12E
0005432823430	7352	45	12F
0005432838738	7352	46	13A
0005432838746	7352	47	13E
0005434458604	7352	48	14D
0005432823429	7352	49	14E
0005432838760	7352	50	14F
0005435252434	7352	51	15A
0005434458605	7352	52	15F
0005432838759	7352	53	16A
0005432838751	7352	54	16C
0005435491407	7352	55	16D
0005434458623	7352	56	17A
0005432840992	7352	57	17C
0005434458608	7352	58	17D
0005435252386	7352	59	17F
0005432838763	7352	60	18C
0005432838755	7352	61	18D
0005434458607	7352	62	19A
0005432838762	7352	63	19C
0005432840991	7352	64	19D
0005432838747	7352	65	19E
0005432838750	7352	66	19F
0005432838744	7352	67	20C
0005434458622	7352	68	20D
0005432838749	7352	69	20E
0005434458612	7352	70	20F
0005432838542	28942	1	1F
0005435252540	28942	2	2A
0005432838502	28942	3	2C
0005435252542	28942	4	3A
0005432838522	28942	5	3C
0005432838519	28942	6	3D
0005435491423	28942	7	4A
0005435252545	28942	8	4E
0005435252536	28942	9	5D
0005432838580	28942	10	5E
0005432838523	28942	11	6A
0005432838524	28942	12	6C
0005432838518	28942	13	6D
0005434458523	28942	14	6E
0005432838555	28942	15	6F
0005435252531	28942	16	7C
0005434458527	28942	17	7D
0005435491424	28942	18	7E
0005435252533	28942	19	7F
0005435252541	28942	20	8A
0005434458525	28942	21	9E
0005435252538	28942	22	10A
0005434458434	28942	23	10D
0005432838531	28942	24	11A
0005432838503	28942	25	12A
0005434458441	28942	26	12C
0005435252532	28942	27	12D
0005435252534	28942	28	12E
0005434458461	28942	29	13C
0005435252535	28942	30	13D
0005432838496	28942	31	13F
0005435252544	28942	32	14D
0005432838510	28942	33	14F
0005434664939	28942	34	15A
0005432838534	28942	35	15C
0005435252529	28942	36	15D
0005435252537	28942	37	15E
0005432838582	28942	38	15F
0005432838549	28942	39	16C
0005435491425	28942	40	16D
0005435252530	28942	41	16F
0005432001005	28942	42	17C
0005434458474	28942	43	17D
0005432838511	28942	44	17E
0005432838576	28942	45	17F
0005434458491	28942	46	18A
0005434458440	28942	47	18C
0005432838497	28942	48	18E
0005434458526	28942	49	18F
0005435252543	28942	50	19A
0005432838556	28942	51	20A
0005432838501	28942	52	20C
0005435252539	28942	53	20D
0005435990558	8821	1	2C
0005435990561	8821	2	8D
0005435990562	8821	3	10D
0005435990556	8821	4	12B
0005434275927	8821	5	12A
0005435990557	8821	6	16B
0005435990559	8821	7	16F
0005434275926	8821	8	18C
0005435990560	8821	9	18B
0005435990555	8821	10	19D
0005434275975	15757	1	2D
0005434275971	15757	2	6B
0005434275976	15757	3	11A
0005434275972	15757	4	11B
0005434275974	15757	5	20B
0005434275973	15757	6	20C
0005435990505	15757	7	21C
0005432427123	20617	1	1C
0005433476857	20617	2	4C
0005432427120	20617	3	4D
0005432427124	20617	4	6B
0005432427122	20617	5	7C
0005432427121	20617	6	7D
0005433476864	20617	7	19C
0005433476865	20617	8	20C
0005432427111	30843	1	2B
0005433476873	30843	2	4D
0005433476871	30843	3	18A
0005432427112	30843	4	21A
0005433476872	30843	5	21B
0005432427106	30843	6	21C
0005433476870	30843	7	22A
0005432427107	30843	8	23B
0005432359912	6386	1	1A
0005435176643	6386	2	1C
0005432359941	6386	3	1D
0005432363384	6386	4	1F
0005432359927	6386	5	2D
0005432359903	6386	6	3A
0005432335922	6386	7	2F
0005432359902	6386	8	3C
0005434149539	6386	9	3D
0005435176683	6386	10	3F
0005435490169	6386	11	4A
0005432359945	6386	12	4C
0005432335927	6386	13	4B
0005435176605	6386	14	4E
0005432359919	6386	15	4D
0005435176636	6386	16	4F
0005432062183	6386	17	5A
0005432359943	6386	18	5C
0005435176635	6386	19	5E
0005432359915	6386	20	5F
0005432359911	6386	21	6A
0005432359929	6386	22	6C
0005432359922	6386	23	6B
0005432359935	6386	24	6D
0005432359924	6386	25	7A
0005432359921	6386	26	7B
0005432359910	6386	27	7C
0005434149540	6386	28	7D
0005432359933	6386	29	8C
0005435176609	6386	30	8D
0005435490172	6386	31	8F
0005435176684	6386	32	8E
0005432363386	6386	33	9A
0005435723012	6386	34	9E
0005435176634	6386	35	9D
0005432359948	6386	36	9F
0005432359901	6386	37	10C
0005432359930	6386	38	10B
0005432363387	6386	39	10E
0005434149572	6386	40	10D
0005432335924	6386	41	11A
0005432359900	6386	42	11C
0005432363385	6386	43	11B
0005432359914	6386	44	11E
0005432359940	6386	45	12B
0005432359917	6386	46	12D
0005432359932	6386	47	12E
0005432359920	6386	48	13A
0005432359939	6386	49	12F
0005432359938	6386	50	13C
0005432062180	6386	51	13B
0005432359926	6386	52	13D
0005432335920	6386	53	13E
0005432359923	6386	54	13F
0005432359925	6386	55	14A
0005432062177	6386	56	14C
0005432359918	6386	57	14D
0005432359931	6386	58	15A
0005432359936	6386	59	15C
0005435490173	6386	60	15B
0005432363388	6386	61	15D
0005432359907	6386	62	15F
0005432359934	6386	63	16B
0005432062182	6386	64	16A
0005432335925	6386	65	16C
0005435723009	6386	66	16E
0005432359906	6386	67	17B
0005432359944	6386	68	17A
0005432335919	6386	69	17C
0005435176615	6386	70	17D
0005432335928	6386	71	18A
0005435176711	6386	72	18B
0005432335923	6386	73	18C
0005432359942	6386	74	18D
0005435176608	6386	75	18F
0005432062179	6386	76	19A
0005432359908	6386	77	19B
0005432359916	6386	78	19E
0005434149571	6386	79	20A
0005432335921	6386	80	20C
0005432359937	6386	81	20B
0005432359946	6386	82	20D
0005432359909	6386	83	20F
0005432062181	6386	84	21C
0005435490171	6386	85	21B
0005434149538	6386	86	21D
0005432335929	6386	87	22B
0005432335926	6386	88	22A
0005432359947	6386	89	22C
0005432359905	6386	90	22D
0005432359913	6386	91	22E
0005435176601	6386	92	23A
0005432359904	6386	93	23C
0005432359928	6386	94	23F
0005432062178	6386	95	23E
0005435490198	21006	1	1A
0005435176812	21006	2	1C
0005435176822	21006	3	1D
0005435490197	21006	4	3C
0005434149621	21006	5	3D
0005432359586	21006	6	3F
0005435176829	21006	7	4B
0005432359609	21006	8	4D
0005435176817	21006	9	4E
0005432335830	21006	10	4F
0005435176825	21006	11	5E
0005432359624	21006	12	5F
0005432359633	21006	13	6A
0005435490195	21006	14	6E
0005435176811	21006	15	6F
0005434149622	21006	16	7B
0005435176826	21006	17	7E
0005435176828	21006	18	8A
0005435176836	21006	19	8B
0005435176834	21006	20	8D
0005435176821	21006	21	8F
0005432052718	21006	22	8E
0005435176838	21006	23	9A
0005432363360	21006	24	9C
0005435490196	21006	25	9E
0005435723028	21006	26	9D
0005435176823	21006	27	9F
0005435176837	21006	28	10B
0005432359553	21006	29	10D
0005432359585	21006	30	10C
0005435723027	21006	31	11A
0005432359530	21006	32	10E
0005435176818	21006	33	11C
0005432359611	21006	34	12A
0005432359604	21006	35	12D
0005432335869	21006	36	12E
0005432363359	21006	37	13A
0005432359625	21006	38	13E
0005435176833	21006	39	13F
0005435176815	21006	40	14B
0005434149620	21006	41	14D
0005434149623	21006	42	14C
0005432359605	21006	43	14E
0005434149627	21006	44	14F
0005435176830	21006	45	15C
0005432359655	21006	46	15B
0005432359752	21006	47	15D
0005434149616	21006	48	15F
0005432363365	21006	49	15E
0005432335860	21006	50	16A
0005435176814	21006	51	16B
0005435176820	21006	52	16E
0005435176816	21006	53	16D
0005435176827	21006	54	16F
0005434149626	21006	55	17C
0005432359653	21006	56	17E
0005435723029	21006	57	17F
0005432335831	21006	58	18A
0005432359635	21006	59	18C
0005435176835	21006	60	18B
0005432052717	21006	61	18E
0005432359515	21006	62	18D
0005434149624	21006	63	18F
0005435176813	21006	64	19B
0005435176819	21006	65	19D
0005432359751	21006	66	19F
0005435176824	21006	67	20C
0005432359560	21006	68	20E
0005432359567	21006	69	20D
0005435176831	21006	70	21A
0005432052719	21006	71	21B
0005435176832	21006	72	21E
0005434149619	21006	73	21F
0005432363372	21006	74	22A
0005434149625	21006	75	22C
0005434149617	21006	76	22D
0005432359511	21006	77	22E
0005432359634	21006	78	23A
0005432363366	21006	79	23B
0005432359552	21006	80	23C
0005432359610	21006	81	23E
0005434149618	21006	82	23F
0005434458507	17688	1	1D
0005434458481	17688	2	2B
0005434458513	17688	3	3A
0005434458450	17688	4	4C
0005434458480	17688	5	5D
0005434186172	17688	6	6B
0005434458452	17688	7	18C
0005434186173	17688	8	18D
0005434461610	17688	9	19D
0005434448263	17688	10	20A
0005434461609	17688	11	20C
0005434458451	17688	12	20D
0005434448262	17688	13	21A
0005434186174	17688	14	21B
0005434458515	17688	15	22B
0005434458466	17688	16	22C
0005434448258	17688	17	22D
0005434448264	17688	18	23A
0005434458611	29114	1	1A
0005434186151	29114	2	1B
0005434458616	29114	3	2A
0005434458612	29114	4	2B
0005434448279	29114	5	2C
0005434458619	29114	6	2D
0005434458610	29114	7	3A
0005434458624	29114	8	3B
0005434458605	29114	9	3C
0005434458621	29114	10	4A
0005434448280	29114	11	4B
0005434463907	29114	12	4D
0005434462769	29114	13	5A
0005434458623	29114	14	5B
0005434458614	29114	15	5C
0005434458622	29114	16	5D
0005434186152	29114	17	6C
0005434186150	29114	18	7A
0005434448281	29114	19	7B
0005434448278	29114	20	7C
0005434462768	29114	21	18A
0005434458607	29114	22	19A
0005434458604	29114	23	19D
0005434463908	29114	24	20C
0005434458613	29114	25	20B
0005434463906	29114	26	20D
0005434458609	29114	27	21A
0005434458615	29114	28	21B
0005434458618	29114	29	21C
0005434462767	29114	30	21D
0005434458617	29114	31	22B
0005434458606	29114	32	22D
0005434458608	29114	33	23A
0005434458620	29114	34	23B
0005432603959	21442	1	1A
0005432603936	21442	2	1B
0005432603948	21442	3	1C
0005432603941	21442	4	1D
0005432603950	21442	5	2B
0005432603949	21442	6	2D
0005432603944	21442	7	3B
0005432603955	21442	8	3C
0005432603953	21442	9	4A
0005432603930	21442	10	4B
0005432603957	21442	11	4C
0005432603964	21442	12	4D
0005432603932	21442	13	5A
0005432603958	21442	14	5B
0005432603937	21442	15	5C
0005432603954	21442	16	5D
0005432603934	21442	17	6A
0005432603965	21442	18	6B
0005432603929	21442	19	6C
0005432603946	21442	20	6D
0005432603956	21442	21	7A
0005432603931	21442	22	7B
0005432603928	21442	23	7C
0005432603938	21442	24	7D
0005432603963	21442	25	18B
0005432603952	21442	26	18C
0005432603927	21442	27	18D
0005432603943	21442	28	19A
0005432603962	21442	29	19B
0005432603933	21442	30	19C
0005432603940	21442	31	20A
0005432603942	21442	32	20B
0005432603935	21442	33	20C
0005432603945	21442	34	20D
0005432603947	21442	35	21B
0005432603961	21442	36	21C
0005432603939	21442	37	22A
0005432603926	21442	38	22D
0005432603951	21442	39	23A
0005432603960	21442	40	23B
0005432603642	31682	1	1A
0005432603666	31682	2	1B
0005432603691	31682	3	1C
0005435221047	31682	4	2A
0005432603655	31682	5	2C
0005432603714	31682	6	3B
0005432603712	31682	7	4A
0005432603663	31682	8	4C
0005432603695	31682	9	4D
0005432603667	31682	10	5A
0005435221506	31682	11	5B
0005432603692	31682	12	7B
0005432603719	31682	13	7D
0005432603694	31682	14	18A
0005435221046	31682	15	18B
0005435221507	31682	16	18C
0005432603763	31682	17	20A
0005432603713	31682	18	20D
0005432603661	31682	19	21A
0005432603736	31682	20	22A
0005432603684	31682	21	22B
0005435221508	31682	22	22D
0005435904890	18846	1	1B
0005434606760	18846	2	2B
0005434606759	18846	3	3A
0005435904891	18846	4	6A
0005434606791	22316	1	1A
0005434604863	22316	2	1B
0005434606792	22316	3	2A
0005434606789	22316	4	3B
0005434606790	22316	5	5A
0005434606793	22316	6	5B
0005434604864	22316	7	6B
0005432747181	416	1	1A
0005432747216	416	2	1C
0005432890720	416	3	1D
0005432890702	416	4	2A
0005432749762	416	5	2C
0005432747210	416	6	2D
0005432747195	416	7	2F
0005432747192	416	8	3C
0005432890722	416	9	3D
0005432747211	416	10	3F
0005432747205	416	11	4A
0005432747183	416	12	4F
0005432747196	416	13	5A
0005432747190	416	14	5E
0005433875356	416	15	5F
0005432219961	416	16	6A
0005432747217	416	17	6D
0005432890679	416	18	6E
0005432749763	416	19	7C
0005432751493	416	20	7E
0005432747199	416	21	8D
0005432747201	416	22	8E
0005432747206	416	23	8F
0005432747185	416	24	9C
0005432890670	416	25	9D
0005432747204	416	26	9E
0005432747209	416	27	9F
0005432751492	416	28	10A
0005432219963	416	29	10C
0005432747203	416	30	10E
0005432747200	416	31	11A
0005432747208	416	32	11D
0005432747189	416	33	12A
0005432890682	416	34	12C
0005432753267	416	35	12D
0005432747212	416	36	12E
0005433875355	416	37	12F
0005432753268	416	38	13C
0005432219962	416	39	13D
0005432747197	416	40	13E
0005432890687	416	41	13F
0005432747213	416	42	14A
0005432890680	416	43	14E
0005432747215	416	44	14F
0005432747198	416	45	15A
0005432747207	416	46	15C
0005432747188	416	47	15D
0005432747186	416	48	15F
0005433293143	416	49	16A
0005432219964	416	50	16D
0005432753266	416	51	16E
0005432747182	416	52	16F
0005432747187	416	53	17A
0005432747193	416	54	17E
0005432747191	416	55	18D
0005432747184	416	56	19A
0005432890683	416	57	18F
0005432890719	416	58	19C
0005432890721	416	59	19D
0005432747202	416	60	19E
0005432890671	416	61	19F
0005432747214	416	62	20C
0005432747218	416	63	20D
0005432747194	416	64	20F
0005433293189	12062	1	1A
0005434153524	12062	2	1C
0005432890847	12062	3	1D
0005433293181	12062	4	1F
0005433293194	12062	5	2C
0005432890846	12062	6	2D
0005432746949	12062	7	2F
0005432746877	12062	8	3A
0005432890830	12062	9	3C
0005432746879	12062	10	3D
0005432746939	12062	11	3F
0005432746954	12062	12	4C
0005432746962	12062	13	4E
0005432890835	12062	14	5A
0005433293180	12062	15	5F
0005432746935	12062	16	6C
0005432746894	12062	17	6D
0005433293185	12062	18	7A
0005432749749	12062	19	7C
0005432890836	12062	20	7D
0005433293182	12062	21	7F
0005433293190	12062	22	8C
0005433293193	12062	23	8D
0005432890841	12062	24	8E
0005433293195	12062	25	8F
0005432746978	12062	26	9A
0005432890845	12062	27	9C
0005433875365	12062	28	9E
0005432890831	12062	29	9F
0005433293196	12062	30	10A
0005432890834	12062	31	10C
0005432890833	12062	32	10D
0005433293197	12062	33	10E
0005432746931	12062	34	10F
0005433293179	12062	35	11C
0005432747049	12062	36	11D
0005432214782	12062	37	11F
0005433293192	12062	38	12D
0005432214783	12062	39	12E
0005432890829	12062	40	12F
0005432890839	12062	41	13A
0005433293178	12062	42	13C
0005432746878	12062	43	13D
0005433293183	12062	44	13E
0005432747000	12062	45	13F
0005432747097	12062	46	14D
0005432890844	12062	47	14F
0005432746936	12062	48	15A
0005432890837	12062	49	15C
0005432747047	12062	50	15D
0005432753243	12062	51	16A
0005432890832	12062	52	16D
0005432890838	12062	53	16E
0005432890843	12062	54	16F
0005433293188	12062	55	17A
0005432747048	12062	56	17C
0005432890842	12062	57	17D
0005432890848	12062	58	17E
0005433293186	12062	59	17F
0005432214784	12062	60	18A
0005432747052	12062	61	18D
0005432747001	12062	62	18E
0005432746886	12062	63	18F
0005433293187	12062	64	19C
0005432746888	12062	65	19D
0005432749750	12062	66	19F
0005432890840	12062	67	20A
0005432746904	12062	68	20C
0005433293191	12062	69	20D
0005433293184	12062	70	20E
0005432753242	12062	71	20F
0005433524926	18995	1	1D
0005433531253	18995	2	2B
0005433524927	18995	3	2C
0005433524928	18995	4	3A
0005433524924	18995	5	3B
0005433531256	18995	6	3C
0005432927887	18995	7	3D
0005433531252	18995	8	4A
0005433524923	18995	9	4C
0005433533269	18995	10	5A
0005432927896	18995	11	5D
0005433531254	18995	12	6A
0005433524929	18995	13	6C
0005433524925	18995	14	6D
0005432927891	18995	15	7A
0005433524933	18995	16	7B
0005433533270	18995	17	7C
0005433524934	18995	18	7D
0005433531255	18995	19	18D
0005433524932	18995	20	19A
0005432927892	18995	21	19B
0005433533268	18995	22	19C
0005433524931	18995	23	20C
0005432927895	18995	24	22A
0005433524930	18995	25	22C
0005432927897	18995	26	23A
0005433524935	18995	27	23B
0005432927935	32480	1	1C
0005432927933	32480	2	3D
0005433524863	32480	3	4A
0005433524850	32480	4	4C
0005432927932	32480	5	5A
0005433524858	32480	6	5C
0005433524872	32480	7	6B
0005433524849	32480	8	7D
0005432927931	32480	9	18A
0005433527204	32480	10	18B
0005433524873	32480	11	19A
0005433524857	32480	12	19B
0005432927934	32480	13	20A
0005433524862	32480	14	21B
0005433524859	32480	15	22D
0005434558200	5265	1	1A
0005434822447	5265	2	1K
0005434822478	5265	3	1H
0005434822423	5265	4	2C
0005434822384	5265	5	2A
0005434558203	5265	6	3A
0005434822379	5265	7	3D
0005434822476	5265	8	3G
0005434822431	5265	9	4C
0005434822434	5265	10	4G
0005434822474	5265	11	4K
0005434822424	5265	12	4H
0005435149907	5265	13	5D
0005434828669	5265	14	5C
0005432823418	5265	15	5A
0005434822441	5265	16	11D
0005434822460	5265	17	11C
0005434822426	5265	18	11G
0005435372225	5265	19	11E
0005435372350	5265	20	12C
0005435149902	5265	21	12A
0005434822356	5265	22	11K
0005435372407	5265	23	12D
0005434822361	5265	24	12F
0005435372357	5265	25	13A
0005434831104	5265	26	12K
0005434822407	5265	27	13D
0005434822468	5265	28	13G
0005434558204	5265	29	14C
0005434822369	5265	30	13K
0005434822401	5265	31	14G
0005434822410	5265	32	14F
0005432121198	5265	33	14E
0005434822417	5265	34	14K
0005435372246	5265	35	14H
0005434822405	5265	36	15E
0005435386487	5265	37	15G
0005434822442	5265	38	15F
0005434822464	5265	39	16A
0005434822358	5265	40	16C
0005434822479	5265	41	16G
0005434822398	5265	42	16E
0005434822413	5265	43	16K
0005434822360	5265	44	17C
0005435149899	5265	45	17E
0005434822430	5265	46	17D
0005434822370	5265	47	17K
0005435372258	5265	48	18C
0005434822433	5265	49	18B
0005435304102	5265	50	18D
0005432396207	5265	51	18F
0005434822357	5265	52	18E
0005434822432	5265	53	18J
0005435372094	5265	54	18H
0005434822392	5265	55	19B
0005432121201	5265	56	18K
0005434822446	5265	57	19D
0005434822437	5265	58	19F
0005434822381	5265	59	19E
0005434822450	5265	60	19H
0005434822368	5265	61	20A
0005434822403	5265	62	19J
0005434822475	5265	63	20D
0005434822453	5265	64	20G
0005434822466	5265	65	20F
0005434822387	5265	66	20K
0005434822402	5265	67	21A
0005435372273	5265	68	21F
0005434831102	5265	69	21J
0005434822473	5265	70	21H
0005434822429	5265	71	21G
0005434822389	5265	72	22C
0005432121207	5265	73	22B
0005432121205	5265	74	22E
0005434828668	5265	75	22F
0005435372215	5265	76	23G
0005434822451	5265	77	23J
0005434822420	5265	78	23H
0005434558199	5265	79	24F
0005432121210	5265	80	24E
0005435149912	5265	81	25A
0005434822422	5265	82	25C
0005434831105	5265	83	25B
0005435299698	5265	84	25D
0005434822399	5265	85	25H
0005434822383	5265	86	25G
0005434822385	5265	87	25J
0005434822418	5265	88	26B
0005434822448	5265	89	26E
0005435372125	5265	90	26D
0005434822365	5265	91	26J
0005432121199	5265	92	27A
0005434822461	5265	93	26K
0005434822386	5265	94	27D
0005434822421	5265	95	27C
0005434822439	5265	96	27B
0005432121200	5265	97	27F
0005434831101	5265	98	27E
0005434822364	5265	99	27J
0005435372162	5265	100	27H
0005434822404	5265	101	28C
0005432396205	5265	102	28G
0005434822366	5265	103	28F
0005434822465	5265	104	28K
0005434831103	5265	105	29D
0005434822416	5265	106	29C
0005434822409	5265	107	29B
0005435372126	5265	108	29F
0005434822436	5265	109	29E
0005435372290	5265	110	29H
0005434822372	5265	111	29K
0005432121211	5265	112	30E
0005434822458	5265	113	30D
0005434822382	5265	114	30G
0005435149903	5265	115	30H
0005432394067	5265	116	31A
0005434822354	5265	117	31D
0005434822443	5265	118	31G
0005435372182	5265	119	31J
0005434822467	5265	120	32A
0005435149904	5265	121	31K
0005434822396	5265	122	32C
0005435372144	5265	123	32E
0005435149911	5265	124	32D
0005434822438	5265	125	32G
0005432121208	5265	126	32F
0005434822359	5265	127	32J
0005434822352	5265	128	33B
0005434822455	5265	129	33A
0005434822427	5265	130	33D
0005435149908	5265	131	33E
0005435149901	5265	132	33G
0005434822391	5265	133	33K
0005435372143	5265	134	33J
0005434822449	5265	135	34F
0005432121206	5265	136	34J
0005434822415	5265	137	34H
0005434822353	5265	138	35C
0005434822462	5265	139	35E
0005434822477	5265	140	35H
0005435149905	5265	141	35J
0005434822400	5265	142	36G
0005432121197	5265	143	36J
0005434822373	5265	144	37B
0005434822452	5265	145	37A
0005434822454	5265	146	37D
0005434822463	5265	147	37C
0005434822351	5265	148	38A
0005434822390	5265	149	38C
0005434822408	5265	150	38B
0005434822388	5265	151	39B
0005434822471	5265	152	39A
0005434664936	5265	153	39D
0005435149910	5265	154	39F
0005435386464	5265	155	39E
0005434822378	5265	156	39H
0005434822414	5265	157	39G
0005434822355	5265	158	39J
0005434822377	5265	159	40C
0005435304101	5265	160	40B
0005435372253	5265	161	40F
0005434822444	5265	162	40H
0005434822411	5265	163	41B
0005435372274	5265	164	41D
0005434822425	5265	165	41H
0005434822419	5265	166	41G
0005435299705	5265	167	41K
0005434822435	5265	168	42A
0005434822412	5265	169	42G
0005434822470	5265	170	42F
0005434822374	5265	171	42J
0005432396204	5265	172	43A
0005434822395	5265	173	43D
0005434822380	5265	174	43C
0005434822367	5265	175	43H
0005434822456	5265	176	43G
0005432121202	5265	177	44A
0005432396206	5265	178	43K
0005432394068	5265	179	43J
0005434822472	5265	180	44E
0005432121204	5265	181	44C
0005434558201	5265	182	44H
0005434822362	5265	183	44F
0005435372356	5265	184	44K
0005434822445	5265	185	44J
0005432394066	5265	186	45A
0005434558198	5265	187	45D
0005434822457	5265	188	45B
0005434822440	5265	189	45F
0005434664938	5265	190	45E
0005435372406	5265	191	45H
0005434822371	5265	192	45J
0005434558202	5265	193	46C
0005435149909	5265	194	46A
0005434664937	5265	195	46E
0005434822397	5265	196	46D
0005435149906	5265	197	46H
0005434822375	5265	198	46K
0005434822394	5265	199	47D
0005435149900	5265	200	47K
0005432121209	5265	201	47H
0005434831100	5265	202	48D
0005435372134	5265	203	48C
0005435372257	5265	204	48A
0005435372209	5265	205	48F
0005434822459	5265	206	48E
0005434822428	5265	207	48H
0005434822469	5265	208	48G
0005435372133	5265	209	49D
0005435372251	5265	210	49C
0005435372216	5265	211	49K
0005434822393	5265	212	50A
0005435149913	5265	213	50H
0005432394065	5265	214	50G
0005434822406	5265	215	50F
0005434822376	5265	216	51D
0005432121203	5265	217	51E
0005434822363	5265	218	51G
0005435372689	9914	1	1D
0005435386517	9914	2	1C
0005435372630	9914	3	2G
0005435372633	9914	4	2K
0005435372674	9914	5	3K
0005434821883	9914	6	3H
0005435372680	9914	7	3G
0005434821399	9914	8	4H
0005434821760	9914	9	5D
0005434821457	9914	10	5C
0005434821388	9914	11	5A
0005435735096	9914	12	5G
0005435372628	9914	13	11A
0005435372687	9914	14	11E
0005434821625	9914	15	11D
0005435372642	9914	16	11F
0005435372657	9914	17	12H
0005435735097	9914	18	13A
0005434821823	9914	19	12K
0005434821674	9914	20	13D
0005435386513	9914	21	13F
0005432396177	9914	22	13E
0005435372635	9914	23	13H
0005434821774	9914	24	14A
0005435372676	9914	25	14E
0005435372665	9914	26	14D
0005435372634	9914	27	14F
0005434821824	9914	28	14K
0005435372673	9914	29	14H
0005434821371	9914	30	14G
0005435386512	9914	31	15C
0005434821515	9914	32	15A
0005434821332	9914	33	15H
0005435372650	9914	34	16F
0005434821367	9914	35	16E
0005434821429	9914	36	16H
0005435386511	9914	37	16K
0005432823432	9914	38	17E
0005434821338	9914	39	17G
0005434831074	9914	40	18C
0005434821551	9914	41	18B
0005435661905	9914	42	18E
0005434821430	9914	43	18D
0005435372647	9914	44	19A
0005434821324	9914	45	19C
0005435372651	9914	46	19E
0005435372654	9914	47	19D
0005434821323	9914	48	19H
0005435372649	9914	49	20E
0005435372670	9914	50	20D
0005435372640	9914	51	20G
0005435735099	9914	52	20F
0005434821541	9914	53	20J
0005434821425	9914	54	21B
0005435302156	9914	55	21D
0005435372631	9914	56	21F
0005434821521	9914	57	21E
0005435386516	9914	58	21G
0005434821942	9914	59	22D
0005435372677	9914	60	22J
0005434821366	9914	61	23A
0005432202995	9914	62	23D
0005435372691	9914	63	23C
0005435661904	9914	64	23E
0005434821431	9914	65	24F
0005434821773	9914	66	24E
0005435372639	9914	67	24G
0005435372652	9914	68	25F
0005435372663	9914	69	25E
0005435372662	9914	70	25H
0005434822083	9914	71	26B
0005435372629	9914	72	26E
0005435372643	9914	73	26D
0005434821382	9914	74	26G
0005434821707	9914	75	26F
0005435372661	9914	76	27F
0005434821565	9914	77	27J
0005435299729	9914	78	28F
0005432396178	9914	79	28K
0005435372672	9914	80	29B
0005434821497	9914	81	29D
0005435372641	9914	82	29J
0005434822011	9914	83	29H
0005434821689	9914	84	29G
0005435372686	9914	85	30E
0005435302153	9914	86	30D
0005434821659	9914	87	30G
0005435372664	9914	88	30F
0005434821383	9914	89	30H
0005435372690	9914	90	31A
0005434821489	9914	91	31D
0005435386515	9914	92	31C
0005435372682	9914	93	31F
0005435372648	9914	94	31H
0005435372638	9914	95	31G
0005434821372	9914	96	32A
0005435149793	9914	97	31K
0005434821758	9914	98	32C
0005434831072	9914	99	32D
0005434821672	9914	100	32G
0005434821711	9914	101	32J
0005432202996	9914	102	33B
0005434821545	9914	103	33F
0005435372667	9914	104	33J
0005434821351	9914	105	34C
0005435372655	9914	106	34B
0005434821678	9914	107	34E
0005434821487	9914	108	35C
0005434821432	9914	109	35F
0005432202997	9914	110	35E
0005434821346	9914	111	35G
0005435302154	9914	112	36A
0005435372636	9914	113	35K
0005434821458	9914	114	36B
0005435372675	9914	115	36E
0005435372678	9914	116	36H
0005434821861	9914	117	36F
0005434821673	9914	118	36K
0005434821424	9914	119	36J
0005435735098	9914	120	37B
0005435372688	9914	121	37D
0005435372632	9914	122	37F
0005435372627	9914	123	37H
0005435372659	9914	124	38A
0005435372681	9914	125	38B
0005434821532	9914	126	39A
0005435372671	9914	127	38K
0005434821334	9914	128	39G
0005434821563	9914	129	40A
0005434821597	9914	130	40D
0005434821386	9914	131	40G
0005435302155	9914	132	40K
0005435299731	9914	133	40H
0005432400060	9914	134	41B
0005435372653	9914	135	41E
0005434821333	9914	136	41C
0005435372693	9914	137	41G
0005434821516	9914	138	41F
0005434821389	9914	139	41J
0005434821398	9914	140	41H
0005432202998	9914	141	42A
0005434821345	9914	142	41K
0005435149794	9914	143	42E
0005435299730	9914	144	42H
0005435372683	9914	145	42G
0005434821362	9914	146	42F
0005435372646	9914	147	42J
0005435299732	9914	148	43A
0005434821552	9914	149	43D
0005434821524	9914	150	43F
0005435299733	9914	151	43H
0005434821368	9914	152	44A
0005434821355	9914	153	43K
0005434821488	9914	154	44B
0005434821439	9914	155	44E
0005435661903	9914	156	44C
0005434821566	9914	157	44K
0005432202999	9914	158	45D
0005435372658	9914	159	45C
0005435372684	9914	160	45B
0005435372685	9914	161	45F
0005434821522	9914	162	45G
0005434822084	9914	163	46A
0005435372645	9914	164	46C
0005432202994	9914	165	46B
0005432823431	9914	166	46E
0005435372656	9914	167	46D
0005434821525	9914	168	47A
0005435386514	9914	169	46K
0005435302157	9914	170	47D
0005435372666	9914	171	47E
0005435372644	9914	172	47H
0005435372679	9914	173	48D
0005434821337	9914	174	48C
0005434821759	9914	175	48A
0005434821772	9914	176	48H
0005435179389	9914	177	48G
0005434821822	9914	178	49A
0005435372668	9914	179	48K
0005434821655	9914	180	49E
0005434821681	9914	181	49D
0005432202993	9914	182	49K
0005432400062	9914	183	49H
0005435372692	9914	184	50D
0005435372660	9914	185	50E
0005435372637	9914	186	50H
0005434821705	9914	187	50K
0005434821682	9914	188	51F
0005435372669	9914	189	51E
0005435790279	7010	1	4A
0005435790278	7010	2	4D
0005435790280	7010	3	5D
0005435082711	7010	4	18A
0005435082712	7010	5	18D
0005435082716	7010	6	21B
0005435082714	7010	7	21C
0005435082715	7010	8	22A
0005435082713	7010	9	22C
0005435790265	26010	1	5C
0005435790263	26010	2	6A
0005435790262	26010	3	7D
0005435790256	26010	4	21A
0005435790255	26010	5	22A
0005434756064	9538	1	1A
0005434756077	9538	2	1C
0005434756068	9538	3	2F
0005434213741	9538	4	3C
0005434756052	9538	5	3F
0005434756062	9538	6	4A
0005434756055	9538	7	4C
0005434756088	9538	8	4F
0005434756079	9538	9	5A
0005434756086	9538	10	5D
0005434756060	9538	11	6A
0005434756063	9538	12	6C
0005434756083	9538	13	6D
0005434756076	9538	14	6E
0005434213743	9538	15	6F
0005434756087	9538	16	7A
0005434756053	9538	17	7E
0005434213776	9538	18	8D
0005434756054	9538	19	8E
0005434756059	9538	20	8F
0005434213869	9538	21	9C
0005434756049	9538	22	9D
0005434756081	9538	23	9F
0005434213769	9538	24	10A
0005434756065	9538	25	10C
0005434756085	9538	26	10E
0005434213772	9538	27	10F
0005434756089	9538	28	11C
0005434756071	9538	29	11D
0005434756056	9538	30	11E
0005434213715	9538	31	12D
0005434756073	9538	32	12E
0005434213768	9538	33	13E
0005434213784	9538	34	13F
0005434756072	9538	35	14A
0005434756066	9538	36	14D
0005434756051	9538	37	14E
0005434213778	9538	38	15A
0005434756058	9538	39	15D
0005434213880	9538	40	15E
0005434756075	9538	41	15F
0005434756067	9538	42	16A
0005434213879	9538	43	16C
0005434756070	9538	44	16D
0005434756061	9538	45	17A
0005434213742	9538	46	17D
0005434756074	9538	47	17E
0005434213771	9538	48	17F
0005434756057	9538	49	18A
0005434213777	9538	50	18D
0005434756082	9538	51	18E
0005434756078	9538	52	18F
0005434213716	9538	53	19A
0005434756069	9538	54	19D
0005434756084	9538	55	20C
0005434756050	9538	56	20D
0005434756080	9538	57	20E
0005434214051	28615	1	1D
0005434214069	28615	2	2A
0005434214037	28615	3	2F
0005434214032	28615	4	3A
0005434214065	28615	5	3C
0005434214061	28615	6	3D
0005434214043	28615	7	4F
0005434214050	28615	8	5C
0005434214035	28615	9	5D
0005434214052	28615	10	5E
0005434214071	28615	11	5F
0005434214046	28615	12	6E
0005434214067	28615	13	7A
0005434214066	28615	14	7C
0005434214053	28615	15	7D
0005434214070	28615	16	8E
0005434214039	28615	17	9C
0005434214031	28615	18	9E
0005434214058	28615	19	9F
0005434214077	28615	20	10A
0005434214057	28615	21	10C
0005434214078	28615	22	10D
0005434214049	28615	23	10F
0005434214064	28615	24	11E
0005434214068	28615	25	11F
0005434214047	28615	26	12A
0005434214045	28615	27	12C
0005434214056	28615	28	12E
0005434214072	28615	29	13A
0005434214074	28615	30	13E
0005434214075	28615	31	14A
0005434214076	28615	32	14D
0005434214042	28615	33	14E
0005434214036	28615	34	15C
0005434214038	28615	35	15D
0005434214044	28615	36	15E
0005434214040	28615	37	16D
0005434214060	28615	38	16E
0005434214073	28615	39	16F
0005434214055	28615	40	18A
0005434214048	28615	41	18E
0005434214054	28615	42	19A
0005434214033	28615	43	19C
0005434214063	28615	44	19E
0005434214062	28615	45	20A
0005434214041	28615	46	20C
0005434214059	28615	47	20D
0005434214034	28615	48	20E
0005435100096	10811	1	2B
0005435100095	10811	2	20D
0005435100069	31804	1	1D
0005435100075	31804	2	2A
0005434760174	31804	3	6A
0005434760175	31804	4	22A
0005434760173	31804	5	22B
0005435100070	31804	6	22D
0005434639079	1955	1	1C
0005434639084	1955	2	1D
0005434639093	1955	3	2A
0005433202111	1955	4	2B
0005433202102	1955	5	2C
0005434639091	1955	6	2D
0005434639088	1955	7	3A
0005432290606	1955	8	3C
0005434639086	1955	9	3D
0005434639077	1955	10	4A
0005434639085	1955	11	4C
0005434639074	1955	12	4D
0005434639092	1955	13	5A
0005434639095	1955	14	5B
0005434639082	1955	15	5C
0005434639080	1955	16	5D
0005434639094	1955	17	6A
0005434639089	1955	18	6B
0005434639087	1955	19	6C
0005434639072	1955	20	6D
0005434639076	1955	21	7A
0005434639081	1955	22	7B
0005434639073	1955	23	7D
0005433202140	1955	24	7C
0005434639078	1955	25	18B
0005434639075	1955	26	18C
0005434639071	1955	27	19A
0005433202113	1955	28	19C
0005434639083	1955	29	19D
0005434639096	1955	30	20A
0005434639090	1955	31	20D
0005433202139	1955	32	21B
0005434639097	1955	33	21C
0005434639098	1955	34	21D
0005432290605	1955	35	22A
0005433202110	1955	36	22C
0005434639070	1955	37	23A
0005434638859	23288	1	1B
0005433202219	23288	2	1D
0005433202212	23288	3	2A
0005433202210	23288	4	2C
0005433202215	23288	5	3A
0005433202211	23288	6	3C
0005433202213	23288	7	4A
0005433202208	23288	8	4B
0005433202217	23288	9	4C
0005433202222	23288	10	4D
0005434638881	23288	11	5B
0005434638915	23288	12	5C
0005433202216	23288	13	6D
0005434638852	23288	14	7C
0005433202220	23288	15	18C
0005434638861	23288	16	18D
0005433202209	23288	17	19A
0005434638914	23288	18	19C
0005434638851	23288	19	19D
0005433202221	23288	20	20B
0005433202218	23288	21	20C
0005434638855	23288	22	21A
0005434638853	23288	23	21D
0005433202214	23288	24	22B
0005434638913	23288	25	22D
0005434638882	23288	26	23B
0005432111252	6071	1	1A
0005434600559	6071	2	1C
0005435326512	6071	3	1F
0005433531258	6071	4	2C
0005433533275	6071	5	2D
0005432111250	6071	6	3A
0005434600550	6071	7	3D
0005434600551	6071	8	4A
0005434600549	6071	9	4E
0005433533274	6071	10	4F
0005434600561	6071	11	5A
0005433531260	6071	12	5D
0005434600548	6071	13	6A
0005433533271	6071	14	6C
0005435326515	6071	15	6F
0005433533272	6071	16	7A
0005434600569	6071	17	7C
0005434600556	6071	18	7D
0005434600571	6071	19	7E
0005433531259	6071	20	7F
0005434600565	6071	21	8D
0005434600572	6071	22	8F
0005434600552	6071	23	9A
0005434600560	6071	24	9C
0005434600564	6071	25	9E
0005435326545	6071	26	10C
0005433533273	6071	27	10E
0005434600553	6071	28	11D
0005432111253	6071	29	11E
0005434600555	6071	30	12A
0005434600563	6071	31	12C
0005434600566	6071	32	13A
0005434600570	6071	33	13E
0005434600558	6071	34	14A
0005435326546	6071	35	14D
0005434600554	6071	36	15A
0005434600574	6071	37	16A
0005433531257	6071	38	16D
0005435326516	6071	39	16F
0005432111251	6071	40	17E
0005434600567	6071	41	17F
0005434600573	6071	42	18A
0005434600568	6071	43	19F
0005434600557	6071	44	20C
0005434600562	6071	45	20D
0005435326517	6071	46	20E
0005435326623	18612	1	1F
0005435326613	18612	2	2A
0005434600366	18612	3	3A
0005434600373	18612	4	4D
0005434600372	18612	5	4E
0005435326614	18612	6	4F
0005435326611	18612	7	5A
0005434600339	18612	8	5C
0005435326618	18612	9	5D
0005434600423	18612	10	5E
0005434600413	18612	11	6C
0005435326617	18612	12	7C
0005435326616	18612	13	7F
0005435326610	18612	14	8A
0005434600352	18612	15	8D
0005435326615	18612	16	9F
0005435326624	18612	17	10C
0005434600393	18612	18	10E
0005435326619	18612	19	11E
0005435326622	18612	20	14D
0005435326620	18612	21	15A
0005434600329	18612	22	15D
0005434600370	18612	23	16F
0005434600400	18612	24	17F
0005434600338	18612	25	18F
0005434600420	18612	26	19A
0005435326621	18612	27	20C
0005435326612	18612	28	20E
0005434550699	10678	1	1A
0005434550651	10678	2	1C
0005434550690	10678	3	1D
0005434550666	10678	4	1F
0005434550704	10678	5	2A
0005434550695	10678	6	2D
0005433180678	10678	7	3A
0005434554042	10678	8	3C
0005434550672	10678	9	3D
0005434550653	10678	10	4A
0005434550662	10678	11	4F
0005434558195	10678	12	5A
0005434550691	10678	13	5C
0005434550671	10678	14	5E
0005434558196	10678	15	5F
0005433180676	10678	16	6A
0005434550698	10678	17	6C
0005433180658	10678	18	6F
0005434550655	10678	19	7A
0005433180675	10678	20	7C
0005434550664	10678	21	7D
0005434550654	10678	22	7E
0005434550673	10678	23	7F
0005434550667	10678	24	8A
0005434550703	10678	25	8C
0005434550705	10678	26	8D
0005434550681	10678	27	8E
0005433180711	10678	28	8F
0005434550677	10678	29	9A
0005434550656	10678	30	9C
0005434550658	10678	31	9E
0005434550684	10678	32	9F
0005434550689	10678	33	10A
0005434550657	10678	34	10C
0005434550680	10678	35	10E
0005434550700	10678	36	10F
0005434550659	10678	37	11C
0005434550688	10678	38	11A
0005434550701	10678	39	11E
0005434550652	10678	40	11F
0005434550670	10678	41	12A
0005433180672	10678	42	12D
0005434550692	10678	43	12F
0005434550661	10678	44	13A
0005434558197	10678	45	13C
0005433180679	10678	46	13D
0005434550687	10678	47	13E
0005434550685	10678	48	13F
0005433180666	10678	49	14A
0005433180654	10678	50	14D
0005434550676	10678	51	14E
0005434558194	10678	52	14F
0005434550665	10678	53	15A
0005434550682	10678	54	15D
0005434550675	10678	55	15E
0005434550694	10678	56	15F
0005434550683	10678	57	16D
0005434550697	10678	58	16E
0005434550674	10678	59	16F
0005433180683	10678	60	17A
0005434550663	10678	61	17C
0005434550696	10678	62	17D
0005434550668	10678	63	17F
0005434554043	10678	64	18A
0005434550686	10678	65	18C
0005433180742	10678	66	18D
0005434550702	10678	67	18E
0005434550678	10678	68	18F
0005434550693	10678	69	19A
0005433180709	10678	70	19C
0005434550679	10678	71	19D
0005433180653	10678	72	19E
0005434550660	10678	73	19F
0005433180671	10678	74	20A
0005434558193	10678	75	20C
0005434550669	10678	76	20D
0005433180875	27738	1	1D
0005433180876	27738	2	2C
0005433180878	27738	3	4A
0005433180872	27738	4	4C
0005433180859	27738	5	6C
0005433180880	27738	6	8E
0005433180867	27738	7	8F
0005433180877	27738	8	10C
0005433180879	27738	9	10E
0005433180864	27738	10	11F
0005433180857	27738	11	12A
0005433180863	27738	12	12F
0005433180856	27738	13	13A
0005433180862	27738	14	13C
0005433180861	27738	15	13D
0005433180858	27738	16	13E
0005433180869	27738	17	15D
0005433180873	27738	18	15E
0005433180874	27738	19	17A
0005433180855	27738	20	18A
0005433180860	27738	21	18C
0005433180870	27738	22	18F
0005433180871	27738	23	20A
0005433180866	27738	24	20D
0005433180868	27738	25	20E
0005433180865	27738	26	20F
0005434550335	27736	1	1D
0005434550296	27736	2	3A
0005434554025	27736	3	4A
0005434550407	27736	4	6D
0005434550279	27736	5	6E
0005434550409	27736	6	6F
0005434550295	27736	7	7F
0005434550392	27736	8	8D
0005434550347	27736	9	8F
0005434550310	27736	10	9A
0005434550278	27736	11	9D
0005434550408	27736	12	9E
0005434550405	27736	13	10C
0005434550340	27736	14	10D
0005434550271	27736	15	10E
0005434550406	27736	16	11E
0005434550349	27736	17	12D
0005434550304	27736	18	12F
0005434550355	27736	19	13D
0005434550343	27736	20	14C
0005434550307	27736	21	14D
0005434550311	27736	22	14E
0005434550423	27736	23	15A
0005434550337	27736	24	16E
0005434550289	27736	25	18D
0005434550350	27736	26	19A
0005434550473	27736	27	19E
0005434550272	27736	28	20C
0005434550370	27736	29	20E
0005433459180	6119	1	1A
0005433459178	6119	2	1B
0005433459181	6119	3	3B
0005435254437	6119	4	4B
0005433459179	6119	5	5B
0005435254433	6119	6	6A
0005435254450	19335	1	1A
0005433459164	19335	2	1B
0005435254451	19335	3	3A
0005433459163	19335	4	4A
0005433459148	19335	5	3B
0005433459149	19335	6	4B
0005435254452	19335	7	5A
0005433459145	19335	8	5B
0005433459147	19335	9	6A
0005433459162	19335	10	6B
0005435681730	6765	1	2C
0005435681747	6765	2	2D
0005435681757	6765	3	2F
0005432136121	6765	4	3A
0005435437582	6765	5	3C
0005435681731	6765	6	3D
0005435437581	6765	7	3F
0005435681732	6765	8	4C
0005435630936	6765	9	4D
0005435630937	6765	10	5A
0005435437603	6765	11	5C
0005435681753	6765	12	5E
0005435681755	6765	13	5F
0005435661900	6765	14	6C
0005435681743	6765	15	6D
0005435681760	6765	16	6E
0005435437608	6765	17	6F
0005435681744	6765	18	7C
0005435681746	6765	19	7D
0005435661902	6765	20	7E
0005435437554	6765	21	7F
0005435437648	6765	22	8A
0005435437617	6765	23	8C
0005435719558	6765	24	8D
0005435681764	6765	25	8E
0005435681754	6765	26	8F
0005435437560	6765	27	9C
0005435437565	6765	28	9E
0005435681752	6765	29	9F
0005432136122	6765	30	10D
0005435681745	6765	31	10E
0005432136119	6765	32	11A
0005435681765	6765	33	11C
0005435681761	6765	34	11D
0005435681736	6765	35	11E
0005435681749	6765	36	12C
0005435681756	6765	37	12D
0005435681735	6765	38	12E
0005435681750	6765	39	12F
0005435437583	6765	40	13A
0005435681738	6765	41	13C
0005435681766	6765	42	13E
0005432136123	6765	43	13F
0005435437552	6765	44	14A
0005435681739	6765	45	14D
0005435681758	6765	46	14E
0005435681742	6765	47	14F
0005435681767	6765	48	15A
0005435437566	6765	49	15C
0005435630935	6765	50	16C
0005435681737	6765	51	16E
0005435681741	6765	52	16F
0005435661901	6765	53	17A
0005435681759	6765	54	17C
0005435681733	6765	55	17D
0005432136120	6765	56	17F
0005435681740	6765	57	18F
0005435681748	6765	58	19A
0005435681763	6765	59	19C
0005435681762	6765	60	20C
0005435681734	6765	61	20D
0005435217676	6765	62	20E
0005435681751	6765	63	20F
0005435437733	24604	1	1C
0005435437739	24604	2	1D
0005435219177	24604	3	2F
0005435437734	24604	4	3A
0005435661887	24604	5	3C
0005435219176	24604	6	5C
0005435437754	24604	7	5E
0005432305725	24604	8	6C
0005435437755	24604	9	6D
0005435681405	24604	10	6E
0005435220295	24604	11	7D
0005435220299	24604	12	7E
0005435437737	24604	13	7F
0005432305726	24604	14	8A
0005435437744	24604	15	8D
0005434828672	24604	16	8E
0005435437756	24604	17	8F
0005435219175	24604	18	9A
0005434828671	24604	19	9C
0005435437750	24604	20	9D
0005435437736	24604	21	9F
0005435437740	24604	22	10C
0005435437753	24604	23	10D
0005435437749	24604	24	11A
0005435437745	24604	25	11D
0005435220298	24604	26	11E
0005435219179	24604	27	11F
0005435681393	24604	28	12A
0005435437743	24604	29	12C
0005435437735	24604	30	12D
0005434828673	24604	31	12E
0005435437752	24604	32	13C
0005435681396	24604	33	13D
0005435661889	24604	34	13E
0005435437742	24604	35	14D
0005435437748	24604	36	14E
0005435437751	24604	37	14F
0005432533265	24604	38	15A
0005434828670	24604	39	15C
0005435437746	24604	40	15E
0005435220296	24604	41	16A
0005435220297	24604	42	16D
0005435681388	24604	43	17A
0005435437741	24604	44	17D
0005435661888	24604	45	17E
0005435219180	24604	46	18C
0005435219178	24604	47	18D
0005435681394	24604	48	18F
0005435437747	24604	49	19A
0005435437738	24604	50	19D
0005435681406	24604	51	19E
0005435661886	24604	52	19F
0005432533264	24604	53	20E
0005435630914	24604	54	20F
0005435098534	11531	1	1C
0005435098537	11531	2	2A
0005435125971	11531	3	2D
0005435125947	11531	4	3A
0005435125968	11531	5	4F
0005435125963	11531	6	5A
0005435098532	11531	7	5C
0005435125954	11531	8	5D
0005435125958	11531	9	5E
0005435125967	11531	10	6E
0005435125977	11531	11	6F
0005435125976	11531	12	7A
0005435125970	11531	13	7C
0005435125948	11531	14	7E
0005435125955	11531	15	8A
0005435125943	11531	16	8C
0005435558046	11531	17	8E
0005435125962	11531	18	8F
0005435098536	11531	19	9A
0005435125944	11531	20	9C
0005435125966	11531	21	9E
0005435105950	11531	22	9F
0005435125946	11531	23	10D
0005435098533	11531	24	10E
0005435125974	11531	25	10F
0005435125940	11531	26	11A
0005435125951	11531	27	11C
0005435105949	11531	28	11D
0005435125956	11531	29	11F
0005435125949	11531	30	12A
0005435105951	11531	31	12D
0005435125941	11531	32	12E
0005435098530	11531	33	12F
0005435105952	11531	34	13A
0005435125964	11531	35	13C
0005435125979	11531	36	13D
0005435125978	11531	37	13E
0005435125969	11531	38	13F
0005435125961	11531	39	14A
0005435125939	11531	40	14C
0005435098529	11531	41	14F
0005435125942	11531	42	15A
0005435098535	11531	43	15C
0005435125975	11531	44	15D
0005435125960	11531	45	15E
0005435125950	11531	46	16D
0005435125965	11531	47	16F
0005435558045	11531	48	17A
0005435125959	11531	49	17E
0005435125973	11531	50	17F
0005435125938	11531	51	18A
0005435558044	11531	52	18C
0005435125972	11531	53	18E
0005435125953	11531	54	19A
0005435125952	11531	55	19C
0005435125957	11531	56	20A
0005435098531	11531	57	20D
0005435125945	11531	58	20E
0005435105926	31907	1	1A
0005435125735	31907	2	1D
0005435125671	31907	3	2C
0005435125734	31907	4	2D
0005435125674	31907	5	3A
0005435125782	31907	6	4A
0005435125801	31907	7	4E
0005435125658	31907	8	4F
0005435125784	31907	9	5A
0005435125701	31907	10	5E
0005435125687	31907	11	6E
0005435125733	31907	12	6F
0005435125676	31907	13	7D
0005435125783	31907	14	7F
0005435125675	31907	15	8D
0005435125694	31907	16	8F
0005435125661	31907	17	9D
0005435558064	31907	18	10C
0005435125662	31907	19	10D
0005435125767	31907	20	10F
0005435125656	31907	21	12A
0005435125768	31907	22	12C
0005435558061	31907	23	15A
0005435125659	31907	24	16D
0005435125754	31907	25	16F
0005435558063	31907	26	17A
0005435105940	31907	27	18A
0005435105934	31907	28	18C
0005435558062	31907	29	18D
0005435125660	31907	30	18E
0005435125753	31907	31	19C
0005435125688	31907	32	19D
0005435125709	31907	33	20C
0005435732131	13562	1	1A
0005433397616	13562	2	1C
0005433397593	13562	3	1D
0005433397601	13562	4	1F
0005433397592	13562	5	2F
0005433397581	13562	6	3C
0005433397594	13562	7	4D
0005435732160	13562	8	4F
0005433397626	13562	9	5A
0005433397611	13562	10	5E
0005433397618	13562	11	5F
0005433397596	13562	12	6A
0005435732130	13562	13	6C
0005433397599	13562	14	6E
0005433397614	13562	15	6F
0005433397612	13562	16	7A
0005433397624	13562	17	7E
0005435732137	13562	18	7F
0005433397591	13562	19	8A
0005433397586	13562	20	8C
0005433397597	13562	21	8D
0005433397600	13562	22	8E
0005435732138	13562	23	9D
0005433397625	13562	24	9E
0005433397577	13562	25	10A
0005433397584	13562	26	10C
0005433397580	13562	27	10D
0005433397589	13562	28	11A
0005433397602	13562	29	11C
0005433397603	13562	30	12A
0005433397595	13562	31	12E
0005433397604	13562	32	13A
0005433397579	13562	33	13C
0005433397615	13562	34	13D
0005433397621	13562	35	13E
0005433397588	13562	36	13F
0005433397583	13562	37	14A
0005433397585	13562	38	14D
0005433397578	13562	39	14F
0005433397613	13562	40	15D
0005433397623	13562	41	16D
0005433397609	13562	42	16E
0005433397622	13562	43	16F
0005433397582	13562	44	17A
0005433397587	13562	45	17D
0005433397608	13562	46	17F
0005433397605	13562	47	18A
0005433397610	13562	48	18D
0005433397607	13562	49	18F
0005435732159	13562	50	19A
0005433397619	13562	51	19C
0005433397598	13562	52	19E
0005433397606	13562	53	20A
0005433397617	13562	54	20C
0005433397590	13562	55	20D
0005433397620	13562	56	20F
0005433397188	19380	1	1A
0005433397245	19380	2	1D
0005433397259	19380	3	1F
0005433397254	19380	4	2A
0005433397252	19380	5	2C
0005435732223	19380	6	2F
0005432297253	19380	7	3F
0005435732220	19380	8	5C
0005433397250	19380	9	5E
0005433397222	19380	10	6A
0005435732216	19380	11	5F
0005435732217	19380	12	6C
0005433397297	19380	13	7E
0005433397300	19380	14	8A
0005433397217	19380	15	8D
0005433397260	19380	16	9C
0005433397257	19380	17	9D
0005432297252	19380	18	9E
0005433397290	19380	19	9F
0005433397251	19380	20	10A
0005433397347	19380	21	10D
0005433397348	19380	22	11A
0005433397226	19380	23	11E
0005433397187	19380	24	11F
0005435732225	19380	25	12C
0005433397410	19380	26	12E
0005433397230	19380	27	12F
0005433397273	19380	28	13A
0005435732224	19380	29	13D
0005433397296	19380	30	13E
0005435732218	19380	31	14C
0005435732214	19380	32	15A
0005433397221	19380	33	15D
0005433397301	19380	34	15F
0005433397203	19380	35	16D
0005435732215	19380	36	16E
0005435732219	19380	37	17A
0005433397200	19380	38	18E
0005435732221	19380	39	18F
0005433397225	19380	40	19E
0005433397220	19380	41	20D
0005435732222	19380	42	20E
0005433397330	19380	43	20F
0005435925167	13186	1	1D
0005435925160	13186	2	2A
0005435925165	13186	3	2F
0005435925175	13186	4	3A
0005435925158	13186	5	3D
0005435925155	13186	6	3F
0005435925166	13186	7	4D
0005435068230	13186	8	4E
0005435925157	13186	9	6A
0005435925159	13186	10	7A
0005435068165	13186	11	7E
0005435925162	13186	12	8A
0005435068186	13186	13	9D
0005435068160	13186	14	10A
0005435925174	13186	15	10C
0005435068159	13186	16	10E
0005435068185	13186	17	10F
0005435925176	13186	18	11F
0005435925161	13186	19	12C
0005435925156	13186	20	12D
0005435925173	13186	21	12F
0005435068187	13186	22	13D
0005435925172	13186	23	13F
0005435925170	13186	24	14D
0005435068194	13186	25	14E
0005435925169	13186	26	15F
0005435068322	13186	27	16D
0005435925168	13186	28	17D
0005435925171	13186	29	18E
0005435925164	13186	30	18F
0005435068184	13186	31	19A
0005435925163	13186	32	19E
0005435068231	13186	33	20D
0005435068158	13186	34	20E
0005435068568	15474	1	1C
0005435068555	15474	2	1D
0005435068575	15474	3	2A
0005435068535	15474	4	2C
0005435068549	15474	5	2F
0005435068547	15474	6	3A
0005435068541	15474	7	3D
0005435068572	15474	8	3F
0005435068552	15474	9	4A
0005435068566	15474	10	4C
0005435068531	15474	11	5A
0005435068569	15474	12	5F
0005435068560	15474	13	6C
0005435068545	15474	14	6D
0005435068578	15474	15	6E
0005435068567	15474	16	7A
0005435068532	15474	17	7C
0005435068558	15474	18	7E
0005435068537	15474	19	7F
0005435068533	15474	20	8A
0005435068563	15474	21	9A
0005435068564	15474	22	9C
0005435068559	15474	23	9D
0005435068530	15474	24	9F
0005435068540	15474	25	10C
0005435068580	15474	26	10D
0005435068565	15474	27	11D
0005435068550	15474	28	11F
0005435068577	15474	29	12C
0005435068536	15474	30	13A
0005435068554	15474	31	13C
0005435068571	15474	32	13E
0005435068543	15474	33	14D
0005435068542	15474	34	14F
0005435068562	15474	35	15C
0005435068579	15474	36	15E
0005435068538	15474	37	16A
0005435068546	15474	38	16E
0005435068539	15474	39	16F
0005435068529	15474	40	17A
0005435068553	15474	41	17C
0005435068573	15474	42	17D
0005435068561	15474	43	17E
0005435068548	15474	44	17F
0005435068557	15474	45	18D
0005435068574	15474	46	18E
0005435068551	15474	47	18F
0005435068570	15474	48	19A
0005435068534	15474	49	19C
0005435068576	15474	50	19E
0005435068544	15474	51	19F
0005435068581	15474	52	20A
0005435068556	15474	53	20E
0005435808123	23179	1	1A
0005435808126	23179	2	1D
0005435808130	23179	3	2B
0005435808120	23179	4	3C
0005433407480	23179	5	3D
0005435808128	23179	6	5C
0005435808117	23179	7	5D
0005435808127	23179	8	6A
0005435808124	23179	9	6B
0005435808119	23179	10	7A
0005435808114	23179	11	7B
0005435808132	23179	12	7C
0005435808113	23179	13	7D
0005435808129	23179	14	18A
0005435808118	23179	15	18B
0005435808115	23179	16	18C
0005435808135	23179	17	19D
0005435808134	23179	18	20B
0005435808121	23179	19	21A
0005435808122	23179	20	21C
0005435808133	23179	21	22C
0005435808131	23179	22	22D
0005435808125	23179	23	23A
0005435808116	23179	24	23B
0005434214103	10698	1	1A
0005434214117	10698	2	1D
0005434214104	10698	3	2D
0005434214121	10698	4	3A
0005434214113	10698	5	3C
0005434214100	10698	6	3D
0005434214091	10698	7	3F
0005434214087	10698	8	4C
0005434214096	10698	9	4D
0005434214099	10698	10	4E
0005434214112	10698	11	4F
0005434214119	10698	12	5A
0005434214079	10698	13	5D
0005434755741	10698	14	5E
0005434214124	10698	15	5F
0005434214092	10698	16	6D
0005434214123	10698	17	6E
0005434214089	10698	18	6F
0005434214098	10698	19	7A
0005434214115	10698	20	7D
0005434755725	10698	21	7E
0005434214101	10698	22	8D
0005434214085	10698	23	8E
0005434214102	10698	24	8F
0005434214125	10698	25	9C
0005434214111	10698	26	10A
0005434214116	10698	27	10E
0005434755792	10698	28	11A
0005434214090	10698	29	11E
0005434214110	10698	30	11F
0005434214084	10698	31	12A
0005434214088	10698	32	12E
0005434214094	10698	33	12F
0005434755787	10698	34	13D
0005434755758	10698	35	13F
0005434214120	10698	36	14F
0005434214126	10698	37	15A
0005434214086	10698	38	15C
0005434755740	10698	39	15D
0005434214083	10698	40	15F
0005434214107	10698	41	16A
0005434214080	10698	42	16C
0005434214081	10698	43	16D
0005434214082	10698	44	16E
0005434214114	10698	45	17C
0005434755717	10698	46	17D
0005434214106	10698	47	17E
0005434214097	10698	48	17F
0005434214108	10698	49	18A
0005434214095	10698	50	18C
0005434214109	10698	51	18D
0005434214105	10698	52	18E
0005434214122	10698	53	19A
0005434214118	10698	54	19D
0005434214093	10698	55	19F
0005434756044	28697	1	1D
0005434756012	28697	2	2A
0005434756017	28697	3	2D
0005434756020	28697	4	3A
0005434756019	28697	5	3C
0005434213770	28697	6	4A
0005434756011	28697	7	4F
0005434756010	28697	8	5D
0005434756022	28697	9	5E
0005434756014	28697	10	6A
0005434756041	28697	11	6F
0005434213811	28697	12	7A
0005434756028	28697	13	7C
0005434756025	28697	14	7D
0005434756037	28697	15	7E
0005434756008	28697	16	8C
0005434756036	28697	17	8F
0005434756029	28697	18	9A
0005434756047	28697	19	9C
0005434756027	28697	20	10A
0005434756016	28697	21	10D
0005434756039	28697	22	10F
0005434756042	28697	23	11D
0005434756035	28697	24	11C
0005434756045	28697	25	11F
0005434756046	28697	26	12C
0005434213734	28697	27	12D
0005434756026	28697	28	13F
0005434756034	28697	29	14D
0005434756018	28697	30	14F
0005434756033	28697	31	15A
0005434756030	28697	32	15D
0005434756038	28697	33	16E
0005434756021	28697	34	16F
0005434756009	28697	35	17D
0005434756040	28697	36	18A
0005434756043	28697	37	18C
0005434756024	28697	38	18D
0005434756023	28697	39	18E
0005434756015	28697	40	18F
0005434213810	28697	41	19D
0005434756032	28697	42	19E
0005434756031	28697	43	20A
0005434756048	28697	44	20D
0005434756013	28697	45	20F
0005432125381	5464	1	1A
0005435039188	5464	2	1C
0005435039155	5464	3	1D
0005435039133	5464	4	1F
0005435039127	5464	5	2C
0005435043276	5464	6	2A
0005435039177	5464	7	2D
0005435039179	5464	8	3A
0005435039180	5464	9	2F
0005435006792	5464	10	3D
0005435039169	5464	11	3C
0005435039163	5464	12	3F
0005435039165	5464	13	4A
0005434229025	5464	14	4B
0005435006805	5464	15	4D
0005435039182	5464	16	4C
0005435006797	5464	17	4E
0005434228973	5464	18	5A
0005435039186	5464	19	4F
0005435006806	5464	20	5B
0005435006814	5464	21	5C
0005435039132	5464	22	5D
0005435039181	5464	23	5E
0005435039178	5464	24	6A
0005435039126	5464	25	5F
0005435039174	5464	26	6C
0005435042835	5464	27	6B
0005434228976	5464	28	6F
0005435006809	5464	29	6E
0005435039146	5464	30	7A
0005435006803	5464	31	7C
0005435039190	5464	32	7E
0005435006810	5464	33	7D
0005435006811	5464	34	7F
0005435039183	5464	35	8A
0005435039129	5464	36	8B
0005435006799	5464	37	8C
0005435039136	5464	38	8E
0005434229003	5464	39	8D
0005435006815	5464	40	9B
0005435039149	5464	41	9A
0005435006802	5464	42	8F
0005432125382	5464	43	9D
0005435039135	5464	44	9C
0005435006808	5464	45	9E
0005435039171	5464	46	10B
0005435039191	5464	47	10D
0005434228987	5464	48	10C
0005435039159	5464	49	11A
0005435039185	5464	50	10E
0005434228975	5464	51	11B
0005435006816	5464	52	11D
0005435039162	5464	53	11E
0005435039175	5464	54	11F
0005435039141	5464	55	12B
0005434228989	5464	56	12A
0005435039150	5464	57	12C
0005435039158	5464	58	12E
0005435039134	5464	59	12D
0005435039140	5464	60	13A
0005432125380	5464	61	13C
0005435039172	5464	62	13E
0005435039189	5464	63	14A
0005435006795	5464	64	13F
0005435039131	5464	65	14B
0005435039168	5464	66	14C
0005435039137	5464	67	14D
0005435039154	5464	68	14E
0005432125384	5464	69	14F
0005435039170	5464	70	15B
0005435006804	5464	71	15C
0005435006794	5464	72	15D
0005434229053	5464	73	15E
0005435039152	5464	74	15F
0005432125385	5464	75	16A
0005435039164	5464	76	16C
0005434229055	5464	77	16B
0005435039157	5464	78	16D
0005434229013	5464	79	16F
0005435006807	5464	80	16E
0005435042836	5464	81	17A
0005435006800	5464	82	17B
0005432125383	5464	83	17C
0005435039192	5464	84	17E
0005435039145	5464	85	17D
0005435039130	5464	86	18A
0005435006801	5464	87	17F
0005435039128	5464	88	18B
0005435039138	5464	89	18D
0005435039166	5464	90	18E
0005435039160	5464	91	18F
0005434229026	5464	92	19A
0005435039153	5464	93	19C
0005435039139	5464	94	19B
0005435039148	5464	95	19D
0005435039161	5464	96	19F
0005435039187	5464	97	19E
0005435039143	5464	98	20B
0005435006812	5464	99	20A
0005435039184	5464	100	20C
0005434228988	5464	101	20D
0005435039144	5464	102	20E
0005435039156	5464	103	20F
0005434229001	5464	104	21A
0005435039151	5464	105	21B
0005435006813	5464	106	21D
0005435006796	5464	107	21C
0005435039125	5464	108	21E
0005435006793	5464	109	21F
0005435039147	5464	110	22B
0005435006798	5464	111	22C
0005434229054	5464	112	22E
0005435039176	5464	113	22D
0005434228986	5464	114	23A
0005435039173	5464	115	22F
0005435039142	5464	116	23B
0005435039167	5464	117	23E
0005435038774	12950	1	1A
0005435038647	12950	2	1F
0005434229154	12950	3	2C
0005435038775	12950	4	2D
0005434229170	12950	5	2F
0005435038880	12950	6	3C
0005435038643	12950	7	3A
0005432304362	12950	8	3D
0005435038744	12950	9	3F
0005435038717	12950	10	4A
0005434229157	12950	11	4B
0005434229151	12950	12	4D
0005434229156	12950	13	4E
0005434229173	12950	14	5A
0005435006696	12950	15	4F
0005435038740	12950	16	5C
0005435038665	12950	17	5E
0005435038684	12950	18	6B
0005434229152	12950	19	6C
0005435038829	12950	20	6D
0005435038638	12950	21	7A
0005434229167	12950	22	7B
0005435038642	12950	23	7E
0005435038637	12950	24	7D
0005435038639	12950	25	8A
0005434229155	12950	26	7F
0005434229158	12950	27	8B
0005435006660	12950	28	8C
0005435038780	12950	29	8F
0005435038621	12950	30	9D
0005435006622	12950	31	9F
0005435038622	12950	32	9E
0005435038716	12950	33	10C
0005435038685	12950	34	10E
0005435038803	12950	35	11C
0005435038731	12950	36	11E
0005435038826	12950	37	12B
0005435006697	12950	38	12D
0005434229161	12950	39	12E
0005434229162	12950	40	13B
0005435038664	12950	41	13A
0005434229164	12950	42	13C
0005435006695	12950	43	13D
0005435038843	12950	44	14A
0005435006667	12950	45	13F
0005435038795	12950	46	14B
0005435038672	12950	47	14D
0005435006659	12950	48	14F
0005434229160	12950	49	15A
0005434229166	12950	50	15C
0005434229163	12950	51	15E
0005435038746	12950	52	15F
0005435038881	12950	53	16D
0005435006693	12950	54	16F
0005435038644	12950	55	17C
0005435038741	12950	56	17E
0005435038844	12950	57	17D
0005435006628	12950	58	18B
0005435038630	12950	59	18E
0005434229168	12950	60	19A
0005435038747	12950	61	19C
0005434229165	12950	62	19E
0005434229172	12950	63	20E
0005435038663	12950	64	21B
0005434229153	12950	65	21A
0005434229159	12950	66	21C
0005435038745	12950	67	21D
0005432304363	12950	68	21E
0005435038679	12950	69	21F
0005435038651	12950	70	22C
0005434229171	12950	71	22B
0005435038682	12950	72	22E
0005432304361	12950	73	22D
0005435038650	12950	74	23B
0005434229169	12950	75	23C
0005435038666	12950	76	23E
0005432188575	14859	1	2A
0005434426311	14859	2	3C
0005434426324	14859	3	3D
0005434426305	14859	4	4A
0005434426304	14859	5	4C
0005434426319	14859	6	4E
0005434426301	14859	7	5C
0005434426296	14859	8	5E
0005435554109	14859	9	6A
0005434411735	14859	10	6C
0005434426300	14859	11	6D
0005434426322	14859	12	6E
0005434426306	14859	13	7A
0005434426297	14859	14	7F
0005434426321	14859	15	8C
0005432188573	14859	16	9A
0005434426318	14859	17	9C
0005434426313	14859	18	9D
0005434426308	14859	19	10C
0005434426302	14859	20	10F
0005434426323	14859	21	11C
0005434426310	14859	22	11E
0005434426317	14859	23	12E
0005434426303	14859	24	14D
0005434411734	14859	25	14E
0005434411733	14859	26	15A
0005432188574	14859	27	15F
0005434411732	14859	28	16A
0005435902414	14859	29	16E
0005434426316	14859	30	16F
0005434411736	14859	31	17A
0005434426314	14859	32	17D
0005434426298	14859	33	17C
0005434426309	14859	34	17E
0005434426299	14859	35	17F
0005434426312	14859	36	18A
0005434426307	14859	37	18C
0005435554118	14859	38	18D
0005435902413	14859	39	18F
0005435902412	14859	40	19D
0005434426315	14859	41	19F
0005434426325	14859	42	20C
0005435902394	14859	43	20E
0005434426320	14859	44	20F
0005432059485	20235	1	1A
0005434426137	20235	2	1C
0005434426233	20235	3	1D
0005435902536	20235	4	1F
0005435902534	20235	5	2A
0005434426188	20235	6	2C
0005435902548	20235	7	2F
0005435902547	20235	8	3D
0005434426185	20235	9	3F
0005434426127	20235	10	5D
0005435902540	20235	11	6D
0005434426187	20235	12	7C
0005435902545	20235	13	7D
0005435902538	20235	14	8E
0005435902537	20235	15	9E
0005435554148	20235	16	10C
0005435902544	20235	17	10D
0005434426184	20235	18	10E
0005435902531	20235	19	10F
0005434426104	20235	20	11A
0005435554146	20235	21	11C
0005435902533	20235	22	11D
0005435902546	20235	23	11E
0005435902532	20235	24	12A
0005434426115	20235	25	12D
0005435902542	20235	26	12E
0005435554147	20235	27	12F
0005434411704	20235	28	13A
0005434426146	20235	29	15C
0005435902539	20235	30	15D
0005434426087	20235	31	15E
0005434426102	20235	32	16A
0005434426109	20235	33	16E
0005435554144	20235	34	17A
0005434411709	20235	35	17D
0005434426231	20235	36	17F
0005435554145	20235	37	18A
0005435902530	20235	38	18C
0005434426106	20235	39	19A
0005435902541	20235	40	19C
0005434426105	20235	41	19D
0005435902543	20235	42	19E
0005435902535	20235	43	20D
0005434426114	20235	44	20E
0005432059486	20235	45	20F
0005433434202	26538	1	1A
0005435981870	26538	2	1D
0005435981872	26538	3	1F
0005435981849	26538	4	2A
0005433434190	26538	5	2C
0005435981867	26538	6	2F
0005435981846	26538	7	3A
0005435981886	26538	8	3C
0005435981871	26538	9	3D
0005435981848	26538	10	3F
0005433434203	26538	11	4C
0005435981874	26538	12	4D
0005435981850	26538	13	4E
0005435981843	26538	14	5A
0005435981877	26538	15	5C
0005433434210	26538	16	5F
0005435981887	26538	17	6D
0005435981884	26538	18	6E
0005435981845	26538	19	7C
0005435981863	26538	20	7F
0005432300203	26538	21	8C
0005433434194	26538	22	8D
0005435981879	26538	23	8F
0005433434252	26538	24	9A
0005433434196	26538	25	9C
0005435981878	26538	26	9D
0005435981873	26538	27	9F
0005435981862	26538	28	10C
0005435981856	26538	29	10E
0005435981842	26538	30	10F
0005435981864	26538	31	11A
0005435981880	26538	32	11D
0005435981853	26538	33	11E
0005433434181	26538	34	11F
0005433434195	26538	35	12C
0005433434187	26538	36	12D
0005435981857	26538	37	12E
0005435981865	26538	38	13A
0005435981881	26538	39	13C
0005434270170	26538	40	13D
0005435981859	26538	41	13E
0005435981868	26538	42	13F
0005435981858	26538	43	14C
0005435981875	26538	44	14D
0005433434191	26538	45	14E
0005433434185	26538	46	14F
0005433434186	26538	47	15A
0005432300207	26538	48	15D
0005433434184	26538	49	15E
0005435981854	26538	50	15F
0005435981866	26538	51	16A
0005433434180	26538	52	16C
0005435981869	26538	53	16E
0005435981847	26538	54	16F
0005432300206	26538	55	17A
0005432300205	26538	56	17D
0005435981888	26538	57	17E
0005435981860	26538	58	18A
0005432300204	26538	59	18D
0005435981844	26538	60	18E
0005435981883	26538	61	18F
0005435981852	26538	62	19A
0005435981882	26538	63	19D
0005435981876	26538	64	19E
0005435981885	26538	65	19F
0005435981851	26538	66	20A
0005434273052	26538	67	20C
0005433434209	26538	68	20D
0005435981861	26538	69	20E
0005435981855	26538	70	20F
0005433434416	26705	1	1A
0005433434430	26705	2	1C
0005433434418	26705	3	1D
0005433434423	26705	4	1F
0005434271293	26705	5	2A
0005433434432	26705	6	2D
0005435981559	26705	7	2F
0005433434434	26705	8	3D
0005435981641	26705	9	3F
0005433434417	26705	10	5A
0005435981563	26705	11	5C
0005433434426	26705	12	5D
0005435981514	26705	13	5F
0005435981564	26705	14	6A
0005434270188	26705	15	6C
0005433434420	26705	16	6E
0005433434435	26705	17	6F
0005433434436	26705	18	7A
0005433434410	26705	19	7E
0005433434421	26705	20	8E
0005433434437	26705	21	8F
0005433434438	26705	22	9F
0005433434425	26705	23	10F
0005434269083	26705	24	11A
0005434270187	26705	25	11C
0005433434412	26705	26	11D
0005432051099	26705	27	12E
0005433434414	26705	28	12F
0005434271294	26705	29	13A
0005435981629	26705	30	13E
0005434271292	26705	31	13F
0005435981518	26705	32	14D
0005435981509	26705	33	14E
0005434270186	26705	34	15A
0005433434419	26705	35	15F
0005432051100	26705	36	16A
0005433434433	26705	37	16C
0005433434422	26705	38	16E
0005433434428	26705	39	16F
0005433434429	26705	40	17E
0005433434415	26705	41	17F
0005433434431	26705	42	18A
0005433434424	26705	43	18C
0005435981527	26705	44	18D
0005433434411	26705	45	19C
0005434269084	26705	46	19F
0005432051098	26705	47	20A
0005433434413	26705	48	20C
0005433434427	26705	49	20D
0005432583791	3186	1	1A
0005432583812	3186	2	1C
0005432583802	3186	3	1D
0005432583809	3186	4	2A
0005432583805	3186	5	2B
0005432583792	3186	6	2C
0005432583806	3186	7	3A
0005432583793	3186	8	3B
0005432583813	3186	9	3C
0005432583790	3186	10	3D
0005432216246	3186	11	4A
0005432583800	3186	12	4B
0005432583794	3186	13	5A
0005432857898	3186	14	5B
0005432583796	3186	15	6A
0005432583795	3186	16	6D
0005432583798	3186	17	7A
0005432583788	3186	18	7B
0005432583797	3186	19	7C
0005432583799	3186	20	7D
0005432216248	3186	21	18A
0005432583807	3186	22	18D
0005432583804	3186	23	19A
0005432857881	3186	24	19B
0005432583811	3186	25	19C
0005432583810	3186	26	20A
0005432216245	3186	27	20B
0005432216247	3186	28	20D
0005432857852	3186	29	21D
0005432583803	3186	30	22A
0005432583801	3186	31	22B
0005432583789	3186	32	23A
0005432583808	3186	33	23B
0005432583638	31497	1	1B
0005432583723	31497	2	1C
0005432583696	31497	3	1D
0005432583639	31497	4	2A
0005432583722	31497	5	2B
0005432857950	31497	6	3B
0005432857954	31497	7	3C
0005432583679	31497	8	3D
0005432583629	31497	9	4B
0005432857957	31497	10	4D
0005432583628	31497	11	5A
0005432583689	31497	12	5D
0005432857951	31497	13	6A
0005432857953	31497	14	6B
0005432857956	31497	15	6C
0005432857960	31497	16	6D
0005432583627	31497	17	7C
0005432583692	31497	18	18B
0005432583607	31497	19	18C
0005432583623	31497	20	19A
0005432583702	31497	21	19C
0005432583646	31497	22	19D
0005432583652	31497	23	20B
0005432583618	31497	24	20C
0005432857949	31497	25	20D
0005432583678	31497	26	21A
0005432857952	31497	27	21B
0005432857955	31497	28	22B
0005432857959	31497	29	22C
0005432857958	31497	30	22D
0005432583697	31497	31	23A
0005432583680	31497	32	23B
0005434943268	914	1	1A
0005434943263	914	2	1B
0005434943264	914	3	2C
0005434943265	914	4	2D
0005434943262	914	5	3D
0005433255047	914	6	5C
0005433255040	914	7	6A
0005433255039	914	8	6C
0005433255021	914	9	18A
0005434943266	914	10	19C
0005433255036	914	11	19D
0005434943269	914	12	20A
0005434943261	914	13	21C
0005434943267	914	14	23A
0005434943237	16227	1	1A
0005434943211	16227	2	2B
0005433255069	16227	3	5C
0005434943206	16227	4	6C
0005433255070	16227	5	7A
0005434943209	16227	6	7B
0005433255068	16227	7	7C
0005433255066	16227	8	7D
0005434943184	16227	9	19A
0005433255071	16227	10	19D
0005434943210	16227	11	20C
0005433255067	16227	12	21D
0005435652605	21736	1	1A
0005435652593	21736	2	1C
0005435652573	21736	3	1F
0005435652608	21736	4	2A
0005435652619	21736	5	2C
0005435652591	21736	6	2D
0005435652562	21736	7	2F
0005435652580	21736	8	3A
0005435652590	21736	9	3C
0005433367257	21736	10	3D
0005433367284	21736	11	3F
0005435652567	21736	12	4A
0005433367229	21736	13	4D
0005435652613	21736	14	4E
0005435652594	21736	15	4F
0005435652584	21736	16	5A
0005435652565	21736	17	5C
0005435652582	21736	18	5D
0005435652611	21736	19	5F
0005435652577	21736	20	6C
0005435652596	21736	21	6E
0005435652620	21736	22	6F
0005435652561	21736	23	7C
0005435652571	21736	24	7E
0005433367233	21736	25	7F
0005435652601	21736	26	8A
0005435652583	21736	27	8C
0005435652576	21736	28	8D
0005435652617	21736	29	8E
0005435652599	21736	30	8F
0005433367242	21736	31	9D
0005435652578	21736	32	10A
0005435652604	21736	33	10C
0005435652568	21736	34	10D
0005435652595	21736	35	10F
0005435652610	21736	36	11C
0005435652612	21736	37	11E
0005435652607	21736	38	11F
0005435652598	21736	39	12A
0005435652588	21736	40	12C
0005433367256	21736	41	12D
0005435652563	21736	42	12E
0005435652570	21736	43	12F
0005433367277	21736	44	13A
0005433367280	21736	45	13C
0005435652564	21736	46	13F
0005435652603	21736	47	14A
0005433367251	21736	48	14C
0005435652587	21736	49	14D
0005435652618	21736	50	14E
0005435652602	21736	51	14F
0005435652585	21736	52	15A
0005435652569	21736	53	15C
0005435652579	21736	54	15D
0005435652581	21736	55	15E
0005435652575	21736	56	16A
0005435652616	21736	57	16C
0005433367232	21736	58	16D
0005435652615	21736	59	16F
0005435652566	21736	60	17A
0005435652600	21736	61	17C
0005435652606	21736	62	17E
0005435652597	21736	63	18A
0005435652586	21736	64	18D
0005433367397	21736	65	18E
0005435652589	21736	66	18F
0005435652609	21736	67	19C
0005435652572	21736	68	19D
0005435652592	21736	69	20A
0005435652574	21736	70	20D
0005433367258	21736	71	20E
0005435652614	21736	72	20F
0005433784620	9385	1	1B
0005434270176	9385	2	1C
0005433805056	9385	3	2F
0005433784605	9385	4	2G
0005433763073	9385	5	3A
0005433784601	9385	6	2H
0005433784621	9385	7	3B
0005433784610	9385	8	3F
0005434270174	9385	9	4G
0005433763076	9385	10	4H
0005432665254	9385	11	5C
0005433805055	9385	12	5G
0005433784587	9385	13	9G
0005433805072	9385	14	9H
0005433805062	9385	15	11B
0005434170842	9385	16	11E
0005433805067	9385	17	11G
0005433805061	9385	18	12A
0005434170869	9385	19	11H
0005433784619	9385	20	12E
0005433784614	9385	21	13A
0005434270173	9385	22	13B
0005432665256	9385	23	13E
0005432667434	9385	24	13H
0005433784599	9385	25	14D
0005433805065	9385	26	14G
0005433784623	9385	27	14F
0005434170799	9385	28	14H
0005433784617	9385	29	15B
0005433763072	9385	30	15E
0005433805064	9385	31	15F
0005433784589	9385	32	15G
0005433784602	9385	33	16E
0005432657420	9385	34	16F
0005433784615	9385	35	17B
0005433784597	9385	36	17A
0005433805052	9385	37	17D
0005433784595	9385	38	17F
0005432667435	9385	39	18A
0005434273046	9385	40	18E
0005433784596	9385	41	18B
0005433763069	9385	42	18G
0005433784591	9385	43	19F
0005433805070	9385	44	19G
0005433805073	9385	45	20A
0005433784608	9385	46	19H
0005433763070	9385	47	20B
0005433763063	9385	48	20E
0005433805050	9385	49	20D
0005434170823	9385	50	20G
0005433784607	9385	51	20H
0005433784613	9385	52	21A
0005432665257	9385	53	21E
0005433763075	9385	54	22B
0005433784604	9385	55	22A
0005433784611	9385	56	23B
0005433805057	9385	57	23D
0005434170804	9385	58	23H
0005433805058	9385	59	24D
0005434270175	9385	60	24B
0005433805059	9385	61	24E
0005433784593	9385	62	24G
0005433784588	9385	63	25F
0005433805071	9385	64	27E
0005433805049	9385	65	27D
0005433805066	9385	66	27G
0005434170818	9385	67	28F
0005433763067	9385	68	28G
0005434170855	9385	69	29A
0005433784609	9385	70	29E
0005433805063	9385	71	29F
0005433805054	9385	72	30D
0005433805051	9385	73	30F
0005433763064	9385	74	30E
0005434151655	9385	75	30H
0005433784598	9385	76	30G
0005433784603	9385	77	31A
0005433784612	9385	78	31B
0005433805048	9385	79	31D
0005434170810	9385	80	31G
0005433784622	9385	81	32E
0005432657418	9385	82	32G
0005433805047	9385	83	33A
0005433784600	9385	84	32H
0005433763065	9385	85	33E
0005432657419	9385	86	33D
0005433805053	9385	87	33H
0005433784592	9385	88	34A
0005433784594	9385	89	34G
0005433805076	9385	90	35A
0005433784590	9385	91	34H
0005433805074	9385	92	35B
0005433784616	9385	93	35E
0005432665255	9385	94	35D
0005434270172	9385	95	36A
0005433805060	9385	96	35H
0005433763071	9385	97	36B
0005433763074	9385	98	36D
0005433805069	9385	99	36E
0005433763066	9385	100	36G
0005433805075	9385	101	37B
0005433805068	9385	102	37A
0005433784618	9385	103	37E
0005432667436	9385	104	37D
0005434170798	9385	105	37G
0005433763068	9385	106	37F
0005433784606	9385	107	38E
0005434170812	9385	108	38G
0005433804888	26242	1	1F
0005433784402	26242	2	1G
0005434170927	26242	3	2A
0005432666360	26242	4	1H
0005433762955	26242	5	2G
0005433784328	26242	6	3F
0005435269684	26242	7	4B
0005434170917	26242	8	5F
0005434269081	26242	9	9B
0005435269679	26242	10	11E
0005433804889	26242	11	11D
0005434170919	26242	12	12D
0005432666359	26242	13	12B
0005434151676	26242	14	12E
0005434170923	26242	15	13D
0005433784415	26242	16	13E
0005434271290	26242	17	14A
0005434170918	26242	18	13H
0005433804836	26242	19	14F
0005434170925	26242	20	14H
0005433804787	26242	21	15E
0005433784430	26242	22	15D
0005433784404	26242	23	16A
0005435269678	26242	24	16D
0005434270185	26242	25	16G
0005433804807	26242	26	16F
0005433804938	26242	27	17D
0005433804781	26242	28	17B
0005433804800	26242	29	17E
0005434170924	26242	30	17H
0005433784309	26242	31	18A
0005434170916	26242	32	18D
0005434170926	26242	33	19A
0005435269677	26242	34	18H
0005433784294	26242	35	19E
0005433804778	26242	36	19F
0005433784339	26242	37	19H
0005433784416	26242	38	20D
0005435269683	26242	39	20E
0005435269675	26242	40	21D
0005433804847	26242	41	21G
0005433762945	26242	42	23G
0005434170922	26242	43	23H
0005435269682	26242	44	24B
0005433804799	26242	45	24E
0005435269680	26242	46	24D
0005433784311	26242	47	24F
0005434271291	26242	48	25D
0005433762987	26242	49	25F
0005433804805	26242	50	27D
0005433762954	26242	51	27H
0005434170915	26242	52	27G
0005433784293	26242	53	28A
0005434170920	26242	54	28E
0005433804868	26242	55	29D
0005433804788	26242	56	29E
0005434151677	26242	57	29F
0005434151675	26242	58	30A
0005433804829	26242	59	30F
0005434170921	26242	60	31B
0005433762946	26242	61	31D
0005433784310	26242	62	31F
0005432657393	26242	63	32F
0005433784312	26242	64	33A
0005433784403	26242	65	33B
0005434270184	26242	66	33F
0005433784292	26242	67	33H
0005435269676	26242	68	34D
0005435269681	26242	69	35E
0005434269082	26242	70	36D
0005434170928	26242	71	36G
0005433804922	26242	72	37G
0005433804777	26242	73	38A
0005433784295	26242	74	38D
0005433804830	26242	75	39D
0005435135624	4931	1	2C
0005435135622	4931	2	5A
0005435135625	4931	3	5D
0005435135623	4931	4	19B
0005435929599	4931	5	19C
0005435929598	4931	6	20D
0005435929595	4931	7	22B
0005435929617	33045	1	3A
0005435929619	33045	2	7B
0005435929618	33045	3	22B
0005434983238	9452	1	1C
0005434983236	9452	2	2C
0005434217901	9452	3	4C
0005434983241	9452	4	7D
0005434983240	9452	5	20C
0005434983239	9452	6	22A
0005434983237	9452	7	22C
0005434983220	27345	1	3B
0005434983193	27345	2	5C
0005434217928	27345	3	7C
0005434983194	27345	4	18B
0005434217930	27345	5	18D
0005434217931	27345	6	19C
0005434983208	27345	7	20C
0005434983219	27345	8	21D
0005434217929	27345	9	22B
0005434983200	27345	10	23B
0005433959865	24249	1	3C
0005433985175	24249	2	3F
0005433985128	24249	3	9B
0005433985130	24249	4	9A
0005433959868	24249	5	11H
0005433985133	24249	6	13D
0005433985247	24249	7	18H
0005433985174	24249	8	20B
0005433985190	24249	9	21F
0005433985287	24249	10	24E
0005433985129	24249	11	27D
0005433985248	24249	12	27F
0005433985203	24249	13	27E
0005433985229	24249	14	28G
0005433985177	24249	15	30B
0005433985204	24249	16	31F
0005433985136	24249	17	32D
0005433985230	24249	18	32H
0005433985124	24249	19	35F
0005433985288	24249	20	36G
0005433985224	24249	21	36H
0005433985125	24249	22	37G
0005433959861	24249	23	37H
0005433985270	24249	24	38G
0005433985504	25926	1	1C
0005433960330	25926	2	1B
0005433960328	25926	3	1H
0005433960285	25926	4	1G
0005433960289	25926	5	2A
0005433985470	25926	6	2B
0005433985485	25926	7	2H
0005433985491	25926	8	2G
0005433960321	25926	9	2F
0005433960291	25926	10	3B
0005433960326	25926	11	3A
0005433985476	25926	12	3C
0005433960333	25926	13	3G
0005433960290	25926	14	4B
0005433985486	25926	15	4F
0005433960316	25926	16	4C
0005433960286	25926	17	4G
0005433985478	25926	18	5A
0005433985497	25926	19	5B
0005433960335	25926	20	5C
0005433960308	25926	21	5H
0005433985508	25926	22	9B
0005433960274	25926	23	9G
0005433985503	25926	24	11B
0005433960287	25926	25	11F
0005433960292	25926	26	11H
0005433985484	25926	27	13A
0005433960278	25926	28	13B
0005433960336	25926	29	13E
0005433985516	25926	30	13G
0005433960322	25926	31	14B
0005433985481	25926	32	15B
0005433960283	25926	33	15A
0005433960309	25926	34	15F
0005433960270	25926	35	15E
0005433960272	25926	36	15H
0005433985515	25926	37	16D
0005433985474	25926	38	16E
0005433960317	25926	39	16H
0005433960276	25926	40	16G
0005433985490	25926	41	17B
0005433960319	25926	42	17F
0005433960307	25926	43	17E
0005433960298	25926	44	17G
0005433960281	25926	45	18B
0005433985496	25926	46	18A
0005433985510	25926	47	18E
0005433985509	25926	48	18D
0005433960294	25926	49	18F
0005433985480	25926	50	19B
0005433985512	25926	51	19E
0005433960323	25926	52	19F
0005433985483	25926	53	19H
0005433960314	25926	54	19G
0005433985511	25926	55	21A
0005433985472	25926	56	21B
0005433985501	25926	57	21D
0005433960300	25926	58	22D
0005433985505	25926	59	22B
0005433960268	25926	60	22E
0005433960296	25926	61	22G
0005433985477	25926	62	22H
0005433960302	25926	63	23B
0005433960304	25926	64	23G
0005433960331	25926	65	23F
0005433985471	25926	66	24B
0005433985500	25926	67	24E
0005433960277	25926	68	24H
0005433985502	25926	69	24G
0005433960293	25926	70	25D
0005433960271	25926	71	25F
0005433985468	25926	72	27B
0005433960282	25926	73	27E
0005433985467	25926	74	27F
0005433960325	25926	75	27G
0005433960318	25926	76	28E
0005433985492	25926	77	28F
0005433985482	25926	78	28H
0005433985488	25926	79	28G
0005433960295	25926	80	29A
0005433985469	25926	81	29B
0005433960303	25926	82	29E
0005433960305	25926	83	29D
0005433960297	25926	84	29G
0005433960310	25926	85	29F
0005433985507	25926	86	29H
0005433960284	25926	87	30B
0005433960280	25926	88	30D
0005433960324	25926	89	30E
0005433985479	25926	90	30G
0005433960320	25926	91	31B
0005433985493	25926	92	31D
0005433985494	25926	93	31F
0005433985487	25926	94	31E
0005433985473	25926	95	31H
0005433960311	25926	96	31G
0005433960275	25926	97	32B
0005433960306	25926	98	32D
0005433960279	25926	99	32G
0005433960315	25926	100	32F
0005433960312	25926	101	33D
0005433960269	25926	102	33B
0005433960329	25926	103	33H
0005433960299	25926	104	34B
0005433985513	25926	105	34D
0005433985465	25926	106	34H
0005433985495	25926	107	35A
0005433960273	25926	108	35G
0005433960288	25926	109	36B
0005433985475	25926	110	36A
0005433960313	25926	111	36F
0005433960334	25926	112	36E
0005433960301	25926	113	36G
0005433985489	25926	114	37A
0005433985464	25926	115	37D
0005433985514	25926	116	37F
0005433985466	25926	117	37H
0005433985499	25926	118	38D
0005433985506	25926	119	38E
0005433960327	25926	120	38H
0005433985498	25926	121	39E
0005433960332	25926	122	39F
0005433165762	953	1	1A
0005434480083	953	2	1B
0005434480092	953	3	1C
0005434480099	953	4	1D
0005434480087	953	5	2A
0005434480106	953	6	2B
0005434480105	953	7	3B
0005434480088	953	8	3C
0005432269468	953	9	4A
0005432269470	953	10	4B
0005434480102	953	11	4C
0005433165706	953	12	5A
0005433165726	953	13	5B
0005434480107	953	14	5C
0005432269469	953	15	5D
0005434480100	953	16	6A
0005434480096	953	17	6C
0005433165678	953	18	6D
0005434480103	953	19	7A
0005434480082	953	20	7B
0005434480085	953	21	7D
0005433165718	953	22	18B
0005434480097	953	23	18C
0005434480104	953	24	18D
0005434480086	953	25	19B
0005433165677	953	26	19C
0005433165699	953	27	19D
0005434480093	953	28	20A
0005434480084	953	29	20B
0005434480091	953	30	20C
0005434480094	953	31	20D
0005433165761	953	32	21B
0005434480090	953	33	21C
0005434480089	953	34	21D
0005434480101	953	35	22A
0005434480095	953	36	22C
0005434480098	953	37	22D
0005434479929	16574	1	1B
0005433165783	16574	2	2A
0005433165790	16574	3	3A
0005433165781	16574	4	3C
0005433165776	16574	5	3D
0005434479920	16574	6	4A
0005434479919	16574	7	4B
0005434480003	16574	8	4C
0005433165789	16574	9	5A
0005433165777	16574	10	5B
0005433165786	16574	11	5C
0005433165785	16574	12	6B
0005434479917	16574	13	6D
0005433165778	16574	14	7B
0005434479908	16574	15	7C
0005433165788	16574	16	18A
0005434479893	16574	17	18B
0005433165782	16574	18	18D
0005433165779	16574	19	19B
0005433165787	16574	20	20B
0005434479891	16574	21	20C
0005434479944	16574	22	21C
0005434479909	16574	23	21D
0005434479890	16574	24	22A
0005434479928	16574	25	22C
0005433165784	16574	26	22D
0005433165780	16574	27	23B
0005435149889	10344	1	1A
0005435149896	10344	2	1C
0005435149893	10344	3	1D
0005435149895	10344	4	2A
0005435142443	10344	5	2B
0005435142435	10344	6	2C
0005435142444	10344	7	3B
0005435149892	10344	8	3C
0005435149886	10344	9	3D
0005435142436	10344	10	4A
0005435149887	10344	11	4B
0005435149898	10344	12	5B
0005435149894	10344	13	5C
0005435142441	10344	14	5D
0005435142442	10344	15	6A
0005435142434	10344	16	6B
0005435142437	10344	17	7A
0005435149888	10344	18	7C
0005435142446	10344	19	18D
0005435142433	10344	20	20A
0005435142440	10344	21	20B
0005435142445	10344	22	20D
0005435142439	10344	23	21A
0005435149891	10344	24	21B
0005435149885	10344	25	21C
0005435142432	10344	26	22A
0005435149890	10344	27	22B
0005435149897	10344	28	22C
0005435142438	10344	29	23A
0005435142346	21968	1	1B
0005435149794	21968	2	1C
0005433289786	21968	3	2C
0005435386513	21968	4	3D
0005433289788	21968	5	4C
0005435386516	21968	6	4D
0005435386515	21968	7	5A
0005435142345	21968	8	5C
0005435149793	21968	9	6A
0005433289790	21968	10	6B
0005433289787	21968	11	6C
0005435386511	21968	12	7A
0005435386517	21968	13	7C
0005435142358	21968	14	18B
0005433289789	21968	15	19A
0005435142347	21968	16	19C
0005435386514	21968	17	19D
0005435142339	21968	18	21B
0005435386512	21968	19	22D
0005435528897	11179	1	1A
0005434573207	11179	2	2A
0005435501936	11179	3	3C
0005434573209	11179	4	3D
0005435528920	11179	5	4A
0005434573214	11179	6	4C
0005435528887	11179	7	5D
0005435501964	11179	8	5F
0005434573215	11179	9	6C
0005435528884	11179	10	6D
0005434573211	11179	11	7F
0005435528886	11179	12	8C
0005435319428	11179	13	8E
0005435528939	11179	14	9A
0005434573208	11179	15	9E
0005435501976	11179	16	10E
0005435528896	11179	17	10F
0005434573213	11179	18	11A
0005434573204	11179	19	12A
0005435501948	11179	20	12E
0005435528885	11179	21	12F
0005435501967	11179	22	14E
0005435319429	11179	23	14F
0005434573206	11179	24	15C
0005435501965	11179	25	15D
0005435528938	11179	26	16D
0005435501937	11179	27	16E
0005435501947	11179	28	17A
0005434573205	11179	29	18A
0005434573210	11179	30	18D
0005434573212	11179	31	18F
0005434573203	11179	32	19C
0005435501931	11179	33	19D
0005435501935	11179	34	20A
0005434573216	11179	35	20F
0005435319502	20942	1	1A
0005435508236	20942	2	1C
0005434573108	20942	3	1D
0005435502100	20942	4	2A
0005435517734	20942	5	2D
0005435502090	20942	6	3A
0005435517744	20942	7	3C
0005435517746	20942	8	3F
0005435319501	20942	9	4C
0005435502089	20942	10	4E
0005435502096	20942	11	4F
0005435517741	20942	12	5A
0005435517733	20942	13	5C
0005432291905	20942	14	5D
0005435508247	20942	15	5E
0005435502103	20942	16	6C
0005435517738	20942	17	6D
0005435508242	20942	18	6E
0005435502086	20942	19	7A
0005435319504	20942	20	7D
0005435517735	20942	21	7E
0005435502095	20942	22	7F
0005435508235	20942	23	8A
0005435502091	20942	24	8C
0005435517740	20942	25	8D
0005435517739	20942	26	8F
0005435502101	20942	27	9C
0005435508241	20942	28	9D
0005435502107	20942	29	9F
0005435502092	20942	30	10A
0005435508245	20942	31	10C
0005435517743	20942	32	10D
0005435508240	20942	33	10F
0005435517737	20942	34	11A
0005435502104	20942	35	11C
0005435517732	20942	36	11D
0005432291907	20942	37	11E
0005435319505	20942	38	12A
0005435502088	20942	39	12C
0005435319497	20942	40	12D
0005432291906	20942	41	12E
0005435502099	20942	42	12F
0005435508243	20942	43	13A
0005435319503	20942	44	13C
0005435502106	20942	45	13F
0005435502087	20942	46	14A
0005435502105	20942	47	14C
0005435319498	20942	48	14D
0005435517747	20942	49	14E
0005435319499	20942	50	15A
0005435502093	20942	51	15C
0005435517748	20942	52	15F
0005435508237	20942	53	16A
0005435502097	20942	54	16D
0005435502098	20942	55	16F
0005435517742	20942	56	17A
0005435319500	20942	57	17D
0005435502102	20942	58	17E
0005435508246	20942	59	17F
0005435508239	20942	60	18A
0005435508249	20942	61	18C
0005435517745	20942	62	18F
0005435502094	20942	63	19A
0005435517736	20942	64	19E
0005435508248	20942	65	19F
0005435508238	20942	66	20A
0005435508244	20942	67	20E
0005432692622	3022	1	4A
0005432692573	3022	2	5D
0005432692635	3022	3	12E
0005432692531	3022	4	15C
0005432692532	3022	5	15F
0005432880573	3021	1	1D
0005432880597	3021	2	1F
0005432706538	3021	3	2F
0005433123576	3021	4	3D
0005432706535	3021	5	4C
0005433123574	3021	6	4A
0005432706518	3021	7	4E
0005433123657	3021	8	4F
0005433123641	3021	9	5C
0005432706527	3021	10	5D
0005433123573	3021	11	5E
0005432706540	3021	12	6C
0005432706533	3021	13	6D
0005432706528	3021	14	6E
0005432880580	3021	15	6F
0005432706520	3021	16	7D
0005432217749	3021	17	7F
0005433123632	3021	18	8C
0005432880564	3021	19	9C
0005433123640	3021	20	9D
0005432706542	3021	21	9F
0005432706531	3021	22	10A
0005432880575	3021	23	10F
0005432706537	3021	24	11D
0005432706522	3021	25	12A
0005432706524	3021	26	12C
0005432706526	3021	27	12D
0005432217748	3021	28	12E
0005433123566	3021	29	12F
0005432706534	3021	30	13C
0005432880579	3021	31	13D
0005432706529	3021	32	14A
0005432706541	3021	33	14E
0005432880552	3021	34	15D
0005432706519	3021	35	15E
0005432706523	3021	36	16D
0005432880551	3021	37	16F
0005432706539	3021	38	17A
0005432706530	3021	39	17C
0005433123567	3021	40	17D
0005432706525	3021	41	17E
0005432217750	3021	42	18A
0005432706536	3021	43	18E
0005432880565	3021	44	19C
0005433123604	3021	45	20C
0005432706532	3021	46	20E
0005432706521	3021	47	20F
0005432706417	29939	1	1C
0005432706319	29939	2	1A
0005433123735	29939	3	1D
0005433123726	29939	4	1F
0005432692781	29939	5	2A
0005432692809	29939	6	2C
0005432692792	29939	7	2D
0005432692782	29939	8	2F
0005432692802	29939	9	3D
0005432692801	29939	10	3F
0005432692780	29939	11	4A
0005432706346	29939	12	4C
0005432880677	29939	13	4D
0005433123729	29939	14	4E
0005433123721	29939	15	4F
0005432880678	29939	16	5A
0005432692783	29939	17	5C
0005433123714	29939	18	5D
0005433194832	29939	19	5E
0005432692794	29939	20	5F
0005432880679	29939	21	6A
0005432880680	29939	22	6D
0005433123734	29939	23	6E
0005432692786	29939	24	6F
0005432692796	29939	25	7A
0005432692804	29939	26	7C
0005432692791	29939	27	7D
0005432692793	29939	28	7E
0005433194829	29939	29	7F
0005432692785	29939	30	8C
0005433194830	29939	31	8D
0005432692789	29939	32	8E
0005432692810	29939	33	8F
0005432692807	29939	34	9A
0005432880672	29939	35	9C
0005432880673	29939	36	9D
0005433194828	29939	37	9E
0005433123718	29939	38	9F
0005432880671	29939	39	10A
0005433194831	29939	40	10C
0005432880682	29939	41	10D
0005432706335	29939	42	10E
0005432692806	29939	43	10F
0005433123719	29939	44	11C
0005433123730	29939	45	11D
0005432880684	29939	46	11E
0005432880683	29939	47	12A
0005433123716	29939	48	12C
0005433123728	29939	49	12D
0005432706352	29939	50	12E
0005432706361	29939	51	12F
0005432706318	29939	52	13A
0005433123722	29939	53	13C
0005433123725	29939	54	13D
0005433123736	29939	55	13E
0005433123733	29939	56	13F
0005432706459	29939	57	14A
0005432880674	29939	58	14C
0005432880685	29939	59	14D
0005432880675	29939	60	14E
0005432706418	29939	61	14F
0005432706397	29939	62	15A
0005432692805	29939	63	15C
0005432692808	29939	64	15D
0005432706341	29939	65	15E
0005432692800	29939	66	16A
0005432692797	29939	67	16C
0005432706395	29939	68	16D
0005432880681	29939	69	16F
0005432692787	29939	70	17A
0005432706309	29939	71	17C
0005432880676	29939	72	17D
0005432692798	29939	73	17E
0005433194833	29939	74	17F
0005433123727	29939	75	18A
0005433123720	29939	76	18D
0005433123732	29939	77	18E
0005433123715	29939	78	18F
0005433123724	29939	79	19A
0005432692799	29939	80	19C
0005433123717	29939	81	19D
0005432692784	29939	82	19E
0005432692803	29939	83	19F
0005432692795	29939	84	20A
0005432692790	29939	85	20C
0005433123731	29939	86	20D
0005433123723	29939	87	20E
0005432692788	29939	88	20F
0005434988627	23697	1	1A
0005434979486	23697	2	1B
0005434979469	23697	3	1C
0005434979489	23697	4	1D
0005434979471	23697	5	2A
0005434979497	23697	6	2D
0005434979490	23697	7	3B
0005434979487	23697	8	3C
0005434979473	23697	9	3D
0005434979474	23697	10	4A
0005434988628	23697	11	4B
0005434979468	23697	12	4C
0005434979481	23697	13	4D
0005434979482	23697	14	5A
0005434988626	23697	15	5C
0005434979477	23697	16	5D
0005434979493	23697	17	6A
0005434979483	23697	18	6B
0005434979475	23697	19	6C
0005434979478	23697	20	6D
0005434988622	23697	21	7A
0005434979492	23697	22	7C
0005434979495	23697	23	7D
0005434979479	23697	24	18A
0005434988623	23697	25	18B
0005434979491	23697	26	18C
0005434979476	23697	27	18D
0005434979485	23697	28	19A
0005434979472	23697	29	19B
0005434979470	23697	30	19C
0005434988624	23697	31	19D
0005434979494	23697	32	20A
0005434988625	23697	33	20B
0005434979484	23697	34	20D
0005434988631	23697	35	21A
0005434979496	23697	36	21B
0005434979480	23697	37	21D
0005434979467	23697	38	22A
0005434979488	23697	39	22B
0005434988630	23697	40	22C
0005434988632	23697	41	23A
0005434988629	23697	42	23B
0005434979325	27567	1	1C
0005434979296	27567	2	3C
0005434979396	27567	3	6D
0005434979301	27567	4	18A
0005434979300	27567	5	19C
0005434979298	27567	6	20C
0005434979297	27567	7	21A
0005434979313	27567	8	22A
0005433111469	10256	1	2C
0005433111471	10256	2	4A
0005434302414	10256	3	7A
0005434302417	10256	4	18A
0005433113496	10256	5	20A
0005434302415	10256	6	20D
0005434302416	10256	7	21B
0005433111468	10256	8	22A
0005434302413	10256	9	22D
0005433113516	19628	1	6B
0005433113515	19628	2	21A
0005433113514	19628	3	21B
0005433113513	19628	4	22D
0005435068632	3573	1	1A
0005435925055	3573	2	1C
0005435925060	3573	3	1F
0005435068589	3573	4	2A
0005435068606	3573	5	2C
0005435068607	3573	6	2D
0005435068614	3573	7	2F
0005435068625	3573	8	3C
0005435068624	3573	9	3D
0005435068588	3573	10	3F
0005435068584	3573	11	4C
0005435068618	3573	12	4E
0005435068629	3573	13	4F
0005435718892	3573	14	5D
0005435068628	3573	15	5E
0005435068595	3573	16	5F
0005435925081	3573	17	6C
0005435718886	3573	18	6D
0005435068630	3573	19	6E
0005435925082	3573	20	6F
0005435068633	3573	21	7A
0005435718889	3573	22	7C
0005435068626	3573	23	7F
0005435068582	3573	24	8A
0005435068620	3573	25	8D
0005435068605	3573	26	8F
0005435068592	3573	27	9A
0005435068593	3573	28	9C
0005435925059	3573	29	9D
0005435068609	3573	30	9E
0005435068587	3573	31	9F
0005435068627	3573	32	10A
0005435068599	3573	33	10C
0005435068623	3573	34	10F
0005435068590	3573	35	11A
0005435718890	3573	36	11C
0005435068613	3573	37	11D
0005435068610	3573	38	11E
0005435068616	3573	39	11F
0005435068596	3573	40	12A
0005435068608	3573	41	12C
0005435068585	3573	42	12F
0005435068631	3573	43	13A
0005435068622	3573	44	13C
0005435068621	3573	45	13D
0005435925086	3573	46	13E
0005435068612	3573	47	14A
0005435068594	3573	48	14C
0005435925064	3573	49	14E
0005435925056	3573	50	14F
0005435068586	3573	51	15A
0005435068583	3573	52	15C
0005435068602	3573	53	15D
0005435068619	3573	54	15E
0005435925094	3573	55	15F
0005435068634	3573	56	16A
0005435068617	3573	57	16C
0005435925063	3573	58	16D
0005435068601	3573	59	16F
0005435939857	3573	60	17A
0005435068597	3573	61	17C
0005435068598	3573	62	17D
0005435718891	3573	63	17E
0005435068600	3573	64	17F
0005435068603	3573	65	18D
0005435718887	3573	66	18E
0005435925066	3573	67	18F
0005435718885	3573	68	19A
0005435068611	3573	69	19D
0005435068604	3573	70	19E
0005435718888	3573	71	20A
0005435068591	3573	72	20D
0005435068615	3573	73	20E
0005435925167	15297	1	2C
0005435925171	15297	2	2D
0005435068322	15297	3	3F
0005435925161	15297	4	4C
0005435068230	15297	5	4E
0005435925155	15297	6	5A
0005435925166	15297	7	5D
0005435925175	15297	8	6A
0005435925159	15297	9	7D
0005435068158	15297	10	7F
0005435925172	15297	11	9D
0005435068187	15297	12	10E
0005435068184	15297	13	10F
0005435925156	15297	14	11C
0005435925158	15297	15	11D
0005435068159	15297	16	11F
0005435925162	15297	17	13C
0005435068194	15297	18	13D
0005435925169	15297	19	13E
0005435068165	15297	20	13F
0005435925174	15297	21	14A
0005435925173	15297	22	15A
0005435925160	15297	23	15D
0005435925168	15297	24	16C
0005435068231	15297	25	16E
0005435068186	15297	26	16F
0005435925163	15297	27	17A
0005435068185	15297	28	18A
0005435925165	15297	29	18F
0005435068160	15297	30	19A
0005435925176	15297	31	20A
0005435925164	15297	32	20C
0005435925170	15297	33	20D
0005435925157	15297	34	20F
0005432659688	18144	1	1A
0005432659687	18144	2	2A
0005432660797	18144	3	3B
0005432660798	18144	4	5B
0005432659686	18144	5	6B
0005433101271	130	1	1D
0005432901326	130	2	3A
0005432919565	130	3	3D
0005432919524	130	4	5A
0005432157474	130	5	7C
0005433101280	130	6	7D
0005433101281	130	7	9B
0005432677506	130	8	9F
0005433101267	130	9	10A
0005433101194	130	10	10B
0005433101290	130	11	10E
0005432919523	130	12	10F
0005432919536	130	13	11A
0005433101211	130	14	11C
0005432919516	130	15	11D
0005433101186	130	16	12A
0005432677505	130	17	13A
0005433101212	130	18	13F
0005432919566	130	19	14D
0005433101207	130	20	15C
0005432919506	130	21	15D
0005433101157	130	22	15E
0005432901318	130	23	16C
0005432901378	130	24	17A
0005433101229	130	25	18B
0005432901336	130	26	18C
0005433101196	130	27	18F
0005433101285	130	28	19C
0005433101189	130	29	19E
0005432677504	130	30	20B
0005433101266	130	31	20E
0005433101270	130	32	21B
0005433101244	130	33	21A
0005433101249	130	34	21C
0005433101209	130	35	21F
0005432901345	130	36	22B
0005433101191	130	37	22A
0005432901329	130	38	22C
0005433101243	130	39	22D
0005432677503	130	40	23A
0005432901304	130	41	23D
0005433101163	130	42	25A
0005432919540	130	43	26A
0005433101210	130	44	26C
0005432901297	130	45	26E
0005432157473	130	46	27A
0005433101173	130	47	27B
0005432901427	130	48	27D
0005433101188	130	49	27E
0005432901428	130	50	28F
0005433101276	130	51	29B
0005432901354	130	52	30B
0005432901303	130	53	30F
0005433101230	130	54	31B
0005432261468	129	1	1A
0005432756796	129	2	1C
0005432261469	129	3	1D
0005432261463	129	4	2A
0005432817192	129	5	1F
0005432817198	129	6	2D
0005432817184	129	7	3F
0005432261497	129	8	4C
0005432288957	129	9	4F
0005432207636	129	10	4D
0005432261491	129	11	5A
0005432207635	129	12	5D
0005432261472	129	13	7F
0005432817185	129	14	8A
0005432261500	129	15	8C
0005432261482	129	16	8E
0005432261499	129	17	8F
0005432817190	129	18	9C
0005432261461	129	19	9E
0005432817210	129	20	10A
0005432261479	129	21	9F
0005432288955	129	22	10B
0005432817183	129	23	10D
0005432817207	129	24	10C
0005432817195	129	25	10E
0005432817180	129	26	11A
0005432261494	129	27	11C
0005432261484	129	28	11F
0005432817199	129	29	11E
0005432261493	129	30	12A
0005432261501	129	31	12B
0005432261495	129	32	12C
0005432261467	129	33	12E
0005432261480	129	34	12D
0005432817189	129	35	13C
0005432261498	129	36	13D
0005432817188	129	37	13F
0005432261485	129	38	13E
0005432817187	129	39	14B
0005432261464	129	40	15C
0005432817206	129	41	15F
0005432261503	129	42	16A
0005432288958	129	43	16C
0005432261486	129	44	16E
0005432261481	129	45	18A
0005432207634	129	46	17F
0005432817201	129	47	18B
0005432817208	129	48	19C
0005432261477	129	49	20A
0005432261466	129	50	19E
0005432261505	129	51	21A
0005432261474	129	52	21D
0005432261507	129	53	21E
0005432261478	129	54	21F
0005432261506	129	55	22C
0005432261462	129	56	22E
0005432817202	129	57	22D
0005432261483	129	58	22F
0005432261504	129	59	23B
0005432261488	129	60	23D
0005432817186	129	61	23E
0005432817191	129	62	23F
0005432261489	129	63	24B
0005432817211	129	64	25A
0005432261475	129	65	25C
0005432817182	129	66	25D
0005432261502	129	67	25E
0005432817204	129	68	26A
0005432817200	129	69	25F
0005432817209	129	70	26C
0005432817203	129	71	26E
0005432261476	129	72	26D
0005432817197	129	73	27C
0005432288954	129	74	27F
0005432261471	129	75	27E
0005432261487	129	76	28A
0005432261496	129	77	28D
0005432288956	129	78	28F
0005432817193	129	79	28E
0005432261473	129	80	29B
0005432817181	129	81	29A
0005432261465	129	82	29C
0005432261492	129	83	29E
0005432261490	129	84	30C
0005432817194	129	85	30B
0005432817196	129	86	30D
0005432817205	129	87	31E
0005432261470	129	88	31F
0005433101653	8055	1	1A
0005432677538	8055	2	1C
0005433101650	8055	3	2C
0005432919662	8055	4	2F
0005433101670	8055	5	3A
0005433101635	8055	6	3D
0005433101668	8055	7	4A
0005433101652	8055	8	3F
0005432919657	8055	9	4D
0005433101629	8055	10	4C
0005433101676	8055	11	5A
0005432919670	8055	12	4F
0005433101628	8055	13	5C
0005432020002	8055	14	5D
0005432919655	8055	15	6A
0005432753270	8055	16	5F
0005432045597	8055	17	6D
0005432020010	8055	18	6C
0005433101651	8055	19	7A
0005432753271	8055	20	7F
0005433101640	8055	21	7D
0005433101642	8055	22	8D
0005432020023	8055	23	8C
0005433101639	8055	24	8E
0005433101665	8055	25	9A
0005432919673	8055	26	8F
0005432020007	8055	27	9B
0005432020000	8055	28	9C
0005432020014	8055	29	9D
0005433101631	8055	30	9F
0005432020020	8055	31	10B
0005432919661	8055	32	10D
0005432391971	8055	33	10E
0005433101626	8055	34	10F
0005432919660	8055	35	11A
0005433101647	8055	36	11C
0005432019999	8055	37	11E
0005432020005	8055	38	11F
0005433101645	8055	39	12B
0005433101636	8055	40	12D
0005433101646	8055	41	12E
0005432753269	8055	42	12F
0005432391970	8055	43	13B
0005432919654	8055	44	13D
0005433101633	8055	45	13F
0005432751494	8055	46	14A
0005433101655	8055	47	14B
0005432020025	8055	48	14D
0005432919659	8055	49	15C
0005433101623	8055	50	15B
0005432020021	8055	51	15F
0005432020013	8055	52	15E
0005433101674	8055	53	16A
0005433101654	8055	54	16B
0005432020019	8055	55	16D
0005432919667	8055	56	16F
0005432020017	8055	57	17B
0005433101661	8055	58	17C
0005432919672	8055	59	17D
0005432020016	8055	60	17F
0005432677539	8055	61	17E
0005433101666	8055	62	18A
0005433101675	8055	63	18B
0005432020024	8055	64	18E
0005432020009	8055	65	18D
0005432677537	8055	66	18F
0005433101641	8055	67	19C
0005433101643	8055	68	19B
0005433101672	8055	69	19D
0005432020003	8055	70	20A
0005432044498	8055	71	20C
0005433101671	8055	72	20D
0005433101663	8055	73	20F
0005433101621	8055	74	20E
0005433101625	8055	75	21A
0005432919669	8055	76	21B
0005432391972	8055	77	21D
0005432919665	8055	78	21F
0005433101659	8055	79	22C
0005433101657	8055	80	22E
0005433101620	8055	81	22F
0005433101638	8055	82	23A
0005432919674	8055	83	23B
0005433101662	8055	84	23D
0005433101656	8055	85	23C
0005433101637	8055	86	23E
0005433101630	8055	87	24A
0005433101658	8055	88	23F
0005433101667	8055	89	24B
0005432020004	8055	90	24C
0005432020006	8055	91	24E
0005432751496	8055	92	24D
0005433101669	8055	93	24F
0005432919666	8055	94	25B
0005433101660	8055	95	25D
0005432919671	8055	96	25C
0005433101634	8055	97	25F
0005432020011	8055	98	25E
0005432919663	8055	99	26A
0005432753272	8055	100	26B
0005433101632	8055	101	26C
0005433101622	8055	102	26E
0005432020001	8055	103	26F
0005432919664	8055	104	27A
0005432020018	8055	105	27E
0005433101673	8055	106	27D
0005432919656	8055	107	27F
0005433101648	8055	108	28A
0005432751495	8055	109	28B
0005432020022	8055	110	28D
0005433101678	8055	111	28C
0005433101664	8055	112	28E
0005433101649	8055	113	29B
0005432020015	8055	114	29C
0005432919658	8055	115	29E
0005432044500	8055	116	30A
0005432919668	8055	117	29F
0005432044499	8055	118	30C
0005433101624	8055	119	30B
0005432020012	8055	120	30E
0005433101627	8055	121	30F
0005433101677	8055	122	31B
0005432020008	8055	123	31C
0005432751497	8055	124	31D
0005433101644	8055	125	31F
0005432045596	8055	126	31E
0005432816995	8056	1	2F
0005432901442	8056	2	2D
0005432901445	8056	3	4A
0005432901441	8056	4	3F
0005432816993	8056	5	4F
0005432817022	8056	6	5D
0005432816940	8056	7	8A
0005432901449	8056	8	9B
0005432816975	8056	9	9E
0005432901448	8056	10	10A
0005432816948	8056	11	10D
0005432901438	8056	12	11A
0005432901447	8056	13	11B
0005432816960	8056	14	11D
0005432816968	8056	15	12B
0005432901439	8056	16	12C
0005432817009	8056	17	13B
0005432816976	8056	18	13E
0005432816981	8056	19	15D
0005432817050	8056	20	15E
0005432901440	8056	21	16A
0005432901443	8056	22	16C
0005432901453	8056	23	16B
0005432816961	8056	24	17B
0005432901437	8056	25	18A
0005432901454	8056	26	18B
0005432816994	8056	27	20B
0005432817051	8056	28	22D
0005432901451	8056	29	23C
0005432002057	8056	30	24B
0005432901450	8056	31	24D
0005432901444	8056	32	25C
0005432901446	8056	33	27C
0005432816991	8056	34	27D
0005432816969	8056	35	28A
0005432816992	8056	36	28D
0005432901452	8056	37	29B
0005432816939	8056	38	31B
0005432002056	8056	39	31C
0005433870711	9637	1	1A
0005434175684	9637	2	2B
0005433870712	9637	3	2A
0005434175679	9637	4	3A
0005433870709	9637	5	3B
0005434175683	9637	6	4A
0005434175678	9637	7	4B
0005434175685	9637	8	5B
0005433870710	9637	9	6A
0005434175712	32354	1	3A
0005434175711	32354	2	3B
0005434175714	32354	3	4B
0005434175713	32354	4	5B
0005435125980	3499	1	1D
0005434877420	3499	2	1C
0005435126011	3499	3	1A
0005435626013	3499	4	1G
0005434877375	3499	5	2D
0005434877405	3499	6	2C
0005434877413	3499	7	2A
0005435902403	3499	8	2H
0005434937964	3499	9	2G
0005432799198	3499	10	3A
0005435626019	3499	11	3G
0005435125993	3499	12	3D
0005434877402	3499	13	3C
0005434426341	3499	14	3K
0005434877376	3499	15	3H
0005434426340	3499	16	4C
0005435626022	3499	17	4G
0005435626001	3499	18	4D
0005435125998	3499	19	4K
0005434877408	3499	20	5C
0005434877382	3499	21	5H
0005434877337	3499	22	11A
0005434877343	3499	23	5K
0005435626008	3499	24	11D
0005435902463	3499	25	11C
0005434877345	3499	26	11F
0005434877333	3499	27	11E
0005434877427	3499	28	11H
0005434426334	3499	29	11G
0005434877400	3499	30	12C
0005435126019	3499	31	12A
0005432799189	3499	32	11K
0005435626011	3499	33	12G
0005434877340	3499	34	12F
0005434426355	3499	35	12K
0005432799207	3499	36	12H
0005434426339	3499	37	13D
0005434877393	3499	38	13F
0005435902402	3499	39	14A
0005435626010	3499	40	13K
0005435902400	3499	41	14C
0005434426353	3499	42	14G
0005435626012	3499	43	14F
0005434937961	3499	44	14K
0005434877414	3499	45	14H
0005434877381	3499	46	15A
0005435126010	3499	47	15G
0005432799193	3499	48	15F
0005432799195	3499	49	15K
0005435125985	3499	50	16C
0005432799211	3499	51	16F
0005434877358	3499	52	16H
0005435126021	3499	53	17C
0005434877380	3499	54	17G
0005432183446	3499	55	17F
0005434937962	3499	56	17E
0005432188579	3499	57	18A
0005434426350	3499	58	17H
0005432799201	3499	59	18B
0005432613825	3499	60	18E
0005435626006	3499	61	18F
0005434877404	3499	62	18K
0005434877416	3499	63	18J
0005434877348	3499	64	18H
0005435126000	3499	65	19C
0005435626002	3499	66	19J
0005434877371	3499	67	20C
0005434426331	3499	68	20A
0005434877369	3499	69	20E
0005435126013	3499	70	20D
0005432613824	3499	71	20H
0005434937959	3499	72	21A
0005434877407	3499	73	21G
0005432799200	3499	74	21F
0005432799208	3499	75	21H
0005434426327	3499	76	22A
0005435126008	3499	77	21K
0005434426347	3499	78	22C
0005432799199	3499	79	22E
0005432611675	3499	80	22G
0005434877391	3499	81	22F
0005434937971	3499	82	22K
0005432799210	3499	83	22H
0005434877353	3499	84	23B
0005434426354	3499	85	23E
0005434877399	3499	86	23D
0005435126016	3499	87	23F
0005435125995	3499	88	24D
0005434877339	3499	89	23K
0005434877388	3499	90	23J
0005434877352	3499	91	24F
0005435125984	3499	92	24E
0005432799206	3499	93	25D
0005434426348	3499	94	25C
0005434426329	3499	95	25B
0005434426328	3499	96	25F
0005435626016	3499	97	25H
0005434937955	3499	98	25K
0005434877383	3499	99	25J
0005435126020	3499	100	26E
0005434426333	3499	101	26D
0005434877331	3499	102	26G
0005434877415	3499	103	26F
0005432799190	3499	104	26H
0005435626020	3499	105	26K
0005434426345	3499	106	27D
0005435626004	3499	107	27C
0005434877397	3499	108	27F
0005434937970	3499	109	27E
0005435125981	3499	110	27G
0005434877374	3499	111	28A
0005434426335	3499	112	27K
0005434877395	3499	113	27J
0005435126004	3499	114	28H
0005434877346	3499	115	28J
0005432799186	3499	116	29A
0005434877362	3499	117	29D
0005432188577	3499	118	29C
0005432611673	3499	119	29F
0005432799209	3499	120	29J
0005434426338	3499	121	29G
0005435126005	3499	122	29K
0005432799192	3499	123	30C
0005434877359	3499	124	30B
0005435126006	3499	125	30E
0005434426342	3499	126	30F
0005434877401	3499	127	30K
0005434877368	3499	128	31D
0005434877334	3499	129	31C
0005434937954	3499	130	31F
0005434877354	3499	131	31E
0005434877418	3499	132	31H
0005435626014	3499	133	31G
0005435125997	3499	134	31K
0005435126001	3499	135	31J
0005434877378	3499	136	32B
0005434426346	3499	137	32A
0005435126002	3499	138	32E
0005432188578	3499	139	32D
0005432799191	3499	140	32F
0005432799202	3499	141	32J
0005432799205	3499	142	33B
0005434877347	3499	143	33A
0005434877412	3499	144	33D
0005435126009	3499	145	33G
0005434937957	3499	146	33F
0005434937965	3499	147	33E
0005434877342	3499	148	34A
0005434426332	3499	149	33K
0005434877357	3499	150	33J
0005435125987	3499	151	34B
0005434877372	3499	152	34E
0005432799196	3499	153	34D
0005434877356	3499	154	34G
0005434877384	3499	155	34F
0005432611674	3499	156	34K
0005434937967	3499	157	34J
0005434877364	3499	158	34H
0005434426344	3499	159	35B
0005432799185	3499	160	35A
0005434877379	3499	161	35C
0005434877389	3499	162	35F
0005434877398	3499	163	35H
0005434877406	3499	164	35K
0005432799184	3499	165	35J
0005435126015	3499	166	36B
0005435125992	3499	167	36E
0005434877361	3499	168	36D
0005435125994	3499	169	36H
0005434877336	3499	170	36F
0005434877373	3499	171	36K
0005434426326	3499	172	37B
0005435626007	3499	173	37A
0005434877360	3499	174	37E
0005434877370	3499	175	37C
0005434877338	3499	176	37G
0005434877335	3499	177	37H
0005434426349	3499	178	37K
0005434877341	3499	179	38C
0005435126007	3499	180	38B
0005435126003	3499	181	38J
0005434426336	3499	182	38H
0005434877349	3499	183	39A
0005434426330	3499	184	39D
0005432799212	3499	185	39C
0005434877419	3499	186	39B
0005435626005	3499	187	39F
0005432183449	3499	188	39E
0005434877350	3499	189	39H
0005434426337	3499	190	39G
0005435626018	3499	191	39K
0005434877403	3499	192	39J
0005432613823	3499	193	40B
0005434877367	3499	194	40A
0005434937969	3499	195	40F
0005432613826	3499	196	40E
0005435902401	3499	197	40D
0005434877423	3499	198	40J
0005434877344	3499	199	40H
0005434877332	3499	200	41B
0005435626009	3499	201	41A
0005434877424	3499	202	40K
0005435125990	3499	203	41D
0005435626017	3499	204	41F
0005435125988	3499	205	41J
0005434937966	3499	206	41H
0005434877392	3499	207	42A
0005432183448	3499	208	41K
0005432799188	3499	209	42B
0005434877351	3499	210	42F
0005434877387	3499	211	42D
0005432611672	3499	212	42G
0005434937968	3499	213	42J
0005434877410	3499	214	43A
0005435626015	3499	215	43C
0005432183447	3499	216	43F
0005434877366	3499	217	43H
0005432613822	3499	218	43K
0005435126018	3499	219	43J
0005434937958	3499	220	44C
0005434877426	3499	221	44E
0005434937952	3499	222	44D
0005434937960	3499	223	44G
0005435125983	3499	224	44J
0005434937953	3499	225	44H
0005434426343	3499	226	45A
0005435126012	3499	227	45C
0005434877409	3499	228	45B
0005434877421	3499	229	45F
0005432799203	3499	230	45E
0005435125986	3499	231	45H
0005434877390	3499	232	45G
0005435626021	3499	233	45K
0005432799194	3499	234	45J
0005435126017	3499	235	46B
0005434877422	3499	236	46A
0005435125996	3499	237	46E
0005435125999	3499	238	46D
0005434877377	3499	239	46G
0005434877365	3499	240	46H
0005434426352	3499	241	47E
0005432799204	3499	242	47D
0005435902411	3499	243	47G
0005432799187	3499	244	47K
0005434937963	3499	245	48F
0005434426351	3499	246	48G
0005435126014	3499	247	49A
0005434877396	3499	248	48K
0005434937956	3499	249	49D
0005432799197	3499	250	49C
0005432188576	3499	251	49E
0005435626000	3499	252	49G
0005434877394	3499	253	50C
0005435125982	3499	254	50A
0005434877385	3499	255	50E
0005434877425	3499	256	50D
0005435125991	3499	257	50H
0005434877355	3499	258	50G
0005434877386	3499	259	50F
0005434877411	3499	260	51D
0005435125989	3499	261	50K
0005434877417	3499	262	51F
0005435626003	3499	263	51E
0005434877363	3499	264	51G
0005434876800	14586	1	1C
0005434876716	14586	2	1G
0005434876809	14586	3	1K
0005435125697	14586	4	2D
0005434876810	14586	5	4C
0005432798981	14586	6	3K
0005434876628	14586	7	11A
0005435902546	14586	8	5K
0005434876875	14586	9	5H
0005434876561	14586	10	11D
0005435125696	14586	11	11H
0005432059485	14586	12	12G
0005434876649	14586	13	12F
0005434876560	14586	14	13A
0005435625863	14586	15	12H
0005434426109	14586	16	13G
0005432799022	14586	17	14A
0005434426146	14586	18	14E
0005434876804	14586	19	14C
0005434876592	14586	20	14G
0005435625864	14586	21	14F
0005434876602	14586	22	15C
0005435902540	14586	23	15F
0005434876679	14586	24	15K
0005435625859	14586	25	16D
0005435902532	14586	26	16G
0005432607494	14586	27	17A
0005434426233	14586	28	17E
0005434876643	14586	29	17D
0005435125698	14586	30	17K
0005434876737	14586	31	18E
0005435125695	14586	32	19B
0005432799023	14586	33	18K
0005435125729	14586	34	19D
0005434426231	14586	35	19C
0005434937854	14586	36	19H
0005432799086	14586	37	19K
0005435902544	14586	38	20G
0005434877016	14586	39	20K
0005434877015	14586	40	21C
0005434877003	14586	41	21G
0005435902530	14586	42	22H
0005434876918	14586	43	22G
0005434876680	14586	44	23B
0005432059486	14586	45	23D
0005434937883	14586	46	23J
0005434876892	14586	47	23G
0005434937882	14586	48	24D
0005435902531	14586	49	23K
0005432799014	14586	50	24F
0005434937858	14586	51	25D
0005435913902	14586	52	25F
0005434876794	14586	53	25K
0005434876923	14586	54	26B
0005434876557	14586	55	26A
0005434876562	14586	56	26H
0005432798982	14586	57	27A
0005432798977	14586	58	26K
0005432799028	14586	59	27B
0005434426137	14586	60	28E
0005434876676	14586	61	29A
0005434937871	14586	62	29F
0005434426106	14586	63	29H
0005435902543	14586	64	30B
0005434876876	14586	65	30E
0005435902545	14586	66	30D
0005434876813	14586	67	30F
0005434426188	14586	68	31D
0005434876603	14586	69	31H
0005435902535	14586	70	31G
0005434937849	14586	71	32A
0005434426187	14586	72	31K
0005432799005	14586	73	32J
0005434876613	14586	74	33A
0005434426127	14586	75	33D
0005434426087	14586	76	33J
0005434937853	14586	77	34B
0005432798978	14586	78	34E
0005434876578	14586	79	34D
0005435902534	14586	80	35A
0005435902548	14586	81	35D
0005434937852	14586	82	35C
0005434426105	14586	83	35H
0005432607505	14586	84	35G
0005434876806	14586	85	36B
0005434877017	14586	86	36E
0005435902536	14586	87	36K
0005432799040	14586	88	36J
0005434937850	14586	89	37C
0005434937859	14586	90	37K
0005434876640	14586	91	38C
0005434426102	14586	92	39A
0005435902541	14586	93	39B
0005434426185	14586	94	40B
0005432798969	14586	95	40D
0005434876641	14586	96	40F
0005435902547	14586	97	40H
0005434937796	14586	98	41A
0005434426115	14586	99	41C
0005434876723	14586	100	41B
0005434876738	14586	101	41H
0005435902539	14586	102	41J
0005435902537	14586	103	42D
0005434426114	14586	104	42H
0005434876682	14586	105	43B
0005435902533	14586	106	43D
0005435902538	14586	107	43E
0005434876693	14586	108	43G
0005432799049	14586	109	44A
0005434876627	14586	110	44F
0005434876739	14586	111	45H
0005434876624	14586	112	46A
0005432799090	14586	113	46C
0005432799029	14586	114	46G
0005434876835	14586	115	46H
0005434937820	14586	116	47C
0005434876647	14586	117	47G
0005435913901	14586	118	48D
0005434426104	14586	119	49E
0005434876893	14586	120	49K
0005434426184	14586	121	49G
0005435902542	14586	122	50D
0005434876648	14586	123	50G
0005432798971	14586	124	50F
0005435625865	14586	125	51D
0005434325542	3605	1	1B
0005434325537	3605	2	2A
0005434312299	3605	3	2B
0005434325544	3605	4	3B
0005434325539	3605	5	4A
0005434325546	3605	6	4B
0005434325538	3605	7	4D
0005435889793	3605	8	5A
0005434325545	3605	9	5B
0005434325543	3605	10	5D
0005434325547	3605	11	6D
0005434312298	3605	12	7D
0005434325540	3605	13	19B
0005434325548	3605	14	19C
0005434325541	3605	15	22A
0005435889841	15643	1	2A
0005435889840	15643	2	2D
0005435889842	15643	3	3C
0005434325521	15643	4	4A
0005434325482	15643	5	6A
0005434325471	15643	6	6C
0005435889843	15643	7	6D
0005434325489	15643	8	7C
0005434325445	15643	9	20B
0005435889839	15643	10	21D
0005434325490	15643	11	22B
0005434325452	15643	12	22C
0005435957566	642	1	2D
0005435957560	642	2	3D
0005435957571	642	3	4A
0005435957565	642	4	5D
0005435957568	642	5	6C
0005435957563	642	6	6D
0005435957567	642	7	18A
0005435957573	642	8	20A
0005433420269	642	9	20B
0005435957572	642	10	20C
0005435957564	642	11	20D
0005435957561	642	12	21A
0005435957570	642	13	21B
0005435957562	642	14	21D
0005435957559	642	15	22C
0005435957569	642	16	23B
0005433420327	15209	1	1C
0005435957457	15209	2	2C
0005435957458	15209	3	2D
0005433420322	15209	4	3C
0005433420321	15209	5	4A
0005435957454	15209	6	6A
0005433420324	15209	7	18A
0005433420323	15209	8	18C
0005433420320	15209	9	19A
0005433420325	15209	10	20C
0005433420326	15209	11	20D
0005435629393	8941	1	3A
0005435629394	8941	2	6B
0005434247123	16013	1	1B
0005434247125	16013	2	3A
0005434247124	16013	3	3B
0005435629388	16013	4	5B
0005435797347	2883	1	1D
0005435797351	2883	2	4C
0005435797348	2883	3	5E
0005435797342	2883	4	6C
0005433404686	2883	5	7D
0005433404685	2883	6	7F
0005435797340	2883	7	8D
0005435797339	2883	8	9F
0005435797346	2883	9	12C
0005435797344	2883	10	12D
0005435797343	2883	11	12F
0005435797350	2883	12	13D
0005435797341	2883	13	14A
0005435797349	2883	14	18C
0005433404699	2883	15	20C
0005435797345	2883	16	20E
0005433404739	29347	1	1D
0005435797223	29347	2	4F
0005433404741	29347	3	5D
0005433404742	29347	4	5F
0005435797261	29347	5	9C
0005433404743	29347	6	11A
0005433404745	29347	7	12C
0005433404740	29347	8	12D
0005435797259	29347	9	16C
0005435797264	29347	10	16D
0005435797251	29347	11	16F
0005435797222	29347	12	17A
0005433404744	29347	13	19C
0005433404738	29347	14	19F
0005435797250	29347	15	20C
0005435797260	29347	16	20D
0005435797243	29347	17	20E
0005434947945	5766	1	1B
0005434947943	5766	2	2A
0005434947941	5766	3	3A
0005434947947	5766	4	4A
0005434947940	5766	5	3B
0005434947946	5766	6	4B
0005434947942	5766	7	5B
0005434947944	5766	8	6A
0005434947948	5766	9	6B
0005434947889	16399	1	1A
0005434947886	16399	2	2B
0005434947887	16399	3	3B
0005434947871	16399	4	3A
0005434947904	16399	5	4A
0005434947939	16399	6	5A
0005435376330	16399	7	4B
0005434947870	16399	8	5B
0005434947872	16399	9	6A
0005434947890	16399	10	6B
0005433960349	6952	1	1A
0005433960375	6952	2	1C
0005433960357	6952	3	1D
0005433960342	6952	4	2A
0005433960368	6952	5	2C
0005433960379	6952	6	2F
0005433960351	6952	7	3A
0005433960389	6952	8	4D
0005433960340	6952	9	4E
0005433960367	6952	10	5C
0005433960345	6952	11	5D
0005433960359	6952	12	5E
0005433960370	6952	13	5F
0005433960387	6952	14	6A
0005433960343	6952	15	6C
0005433960364	6952	16	6F
0005433960344	6952	17	7C
0005433960378	6952	18	7D
0005433960338	6952	19	8C
0005433960372	6952	20	9A
0005433960361	6952	21	9D
0005433960388	6952	22	10C
0005433960384	6952	23	10E
0005433960376	6952	24	11E
0005433960355	6952	25	11F
0005433960380	6952	26	12A
0005433960346	6952	27	12E
0005433960341	6952	28	13A
0005433960365	6952	29	13D
0005433960373	6952	30	13E
0005433960337	6952	31	13F
0005433960339	6952	32	14A
0005433960360	6952	33	14E
0005433960385	6952	34	14F
0005433960386	6952	35	15A
0005433960352	6952	36	15C
0005433960371	6952	37	16A
0005433960363	6952	38	16E
0005433960348	6952	39	17A
0005433960354	6952	40	17C
0005433960377	6952	41	17E
0005433960362	6952	42	18C
0005433960347	6952	43	18D
0005433960353	6952	44	18E
0005433960374	6952	45	18F
0005433960356	6952	46	19A
0005433960382	6952	47	19C
0005433960350	6952	48	19E
0005433960383	6952	49	19F
0005433960369	6952	50	20A
0005433960366	6952	51	20D
0005433960358	6952	52	20E
0005433960381	6952	53	20F
0005435082704	26131	1	2A
0005435082705	26131	2	3A
0005435082708	26131	3	4A
0005435082710	26131	4	4B
0005435082709	26131	5	5A
0005435082706	26131	6	6A
0005435082707	26131	7	6B
0005432166871	5003	1	2F
0005434244708	5003	2	3A
0005435286544	5003	3	4C
0005434244703	5003	4	4D
0005434244695	5003	5	6A
0005434244707	5003	6	8E
0005434244706	5003	7	10D
0005435286540	5003	8	10F
0005434244715	5003	9	11C
0005434244702	5003	10	11F
0005432166872	5003	11	11E
0005434244699	5003	12	12A
0005434244714	5003	13	12F
0005434244713	5003	14	13C
0005435286541	5003	15	13B
0005434244696	5003	16	13D
0005434244697	5003	17	14A
0005434244709	5003	18	14C
0005434244704	5003	19	14E
0005434244712	5003	20	16F
0005434244717	5003	21	16E
0005434244719	5003	22	17E
0005434244694	5003	23	20C
0005434244724	5003	24	20B
0005434244711	5003	25	21F
0005434244701	5003	26	24A
0005434244710	5003	27	23F
0005434244698	5003	28	24C
0005434244720	5003	29	24F
0005434244718	5003	30	25D
0005434244705	5003	31	26A
0005434244716	5003	32	26D
0005434244723	5003	33	27E
0005434244700	5003	34	28D
0005434244722	5003	35	29D
0005435286538	5003	36	31A
0005434244721	5003	37	31E
0005433614058	5004	1	1A
0005433614016	5004	2	1C
0005433784595	5004	3	1D
0005433613988	5004	4	2A
0005432105109	5004	5	1F
0005433613998	5004	6	2C
0005433614036	5004	7	2D
0005432105131	5004	8	3A
0005432105130	5004	9	2F
0005433614023	5004	10	3C
0005432105147	5004	11	3F
0005433614040	5004	12	3D
0005433614039	5004	13	4C
0005433614001	5004	14	4A
0005433614006	5004	15	4F
0005433613996	5004	16	4D
0005433614015	5004	17	5A
0005433784613	5004	18	5C
0005433613993	5004	19	5F
0005433614002	5004	20	5D
0005433613992	5004	21	6A
0005433614043	5004	22	6C
0005432665256	5004	23	6F
0005432105129	5004	24	6D
0005432105115	5004	25	7A
0005433784610	5004	26	7C
0005432105141	5004	27	7D
0005432105107	5004	28	8A
0005433784620	5004	29	7F
0005432105116	5004	30	8B
0005432105136	5004	31	8D
0005433614018	5004	32	8C
0005433614020	5004	33	8E
0005433784599	5004	34	9A
0005433784612	5004	35	8F
0005432105140	5004	36	9B
0005432105150	5004	37	9C
0005432105127	5004	38	9D
0005433784596	5004	39	9F
0005433614051	5004	40	9E
0005433614042	5004	41	10A
0005433614021	5004	42	10B
0005432105149	5004	43	10D
0005433614005	5004	44	10C
0005432105118	5004	45	10E
0005432667436	5004	46	10F
0005433613999	5004	47	11B
0005433614038	5004	48	11A
0005433614045	5004	49	11C
0005433614046	5004	50	11D
0005433614028	5004	51	11E
0005433614034	5004	52	12A
0005433614014	5004	53	11F
0005432105132	5004	54	12B
0005433784617	5004	55	12D
0005432105146	5004	56	12C
0005432105142	5004	57	12F
0005433784607	5004	58	12E
0005433784592	5004	59	13A
0005432105113	5004	60	13C
0005432105122	5004	61	13B
0005432105111	5004	62	13D
0005433613997	5004	63	13E
0005433784606	5004	64	14A
0005433614032	5004	65	13F
0005433614027	5004	66	14C
0005432667435	5004	67	14B
0005432105152	5004	68	14D
0005432105138	5004	69	14E
0005433613989	5004	70	14F
0005433614010	5004	71	15B
0005433784621	5004	72	15A
0005432105110	5004	73	15C
0005433614009	5004	74	15D
0005432665257	5004	75	15E
0005433614024	5004	76	16A
0005432105117	5004	77	15F
0005433614056	5004	78	16C
0005432105139	5004	79	16B
0005433784591	5004	80	16D
0005433614059	5004	81	16E
0005433784597	5004	82	16F
0005433784623	5004	83	17B
0005433784587	5004	84	17A
0005432105123	5004	85	17C
0005433613987	5004	86	17D
0005433784619	5004	87	17E
0005433784588	5004	88	18A
0005433614037	5004	89	17F
0005433614007	5004	90	18C
0005433614031	5004	91	18B
0005432105121	5004	92	18D
0005433784611	5004	93	18E
0005433614013	5004	94	18F
0005432105104	5004	95	19C
0005433614000	5004	96	19B
0005433784589	5004	97	19D
0005433614025	5004	98	19E
0005433784594	5004	99	20A
0005432105114	5004	100	20C
0005432105124	5004	101	20B
0005433784600	5004	102	20D
0005433784616	5004	103	20F
0005433784605	5004	104	20E
0005433614033	5004	105	21A
0005433614029	5004	106	21C
0005432665254	5004	107	21B
0005433614044	5004	108	21D
0005433614057	5004	109	22A
0005433613986	5004	110	21F
0005433784593	5004	111	22B
0005433614053	5004	112	22C
0005433613985	5004	113	22E
0005433613990	5004	114	22D
0005433614026	5004	115	22F
0005432105106	5004	116	23A
0005432665255	5004	117	23B
0005432105135	5004	118	23D
0005433614048	5004	119	23C
0005432105119	5004	120	23F
0005433614052	5004	121	23E
0005433784618	5004	122	24A
0005433614050	5004	123	24B
0005433614003	5004	124	24C
0005433784614	5004	125	24E
0005432105128	5004	126	24D
0005432105112	5004	127	24F
0005432105151	5004	128	25B
0005433614011	5004	129	25A
0005433614012	5004	130	25C
0005432105126	5004	131	25D
0005433784608	5004	132	25F
0005433614030	5004	133	25E
0005433614041	5004	134	26A
0005432667434	5004	135	26B
0005433614055	5004	136	26C
0005433784609	5004	137	26E
0005433613995	5004	138	26D
0005433614054	5004	139	26F
0005432105137	5004	140	27A
0005432145093	5004	141	27C
0005433784603	5004	142	27B
0005433613991	5004	143	27D
0005433784590	5004	144	27E
0005432105148	5004	145	28A
0005432105105	5004	146	27F
0005433614035	5004	147	28B
0005432105125	5004	148	28C
0005432105120	5004	149	28E
0005433784601	5004	150	28D
0005433614019	5004	151	29A
0005433614004	5004	152	28F
0005432105144	5004	153	29B
0005432105143	5004	154	29C
0005433784615	5004	155	29D
0005432105145	5004	156	29E
0005433784598	5004	157	30A
0005433614022	5004	158	29F
0005433784604	5004	159	30B
0005432105133	5004	160	30C
0005433614008	5004	161	30D
0005433613994	5004	162	30F
0005432105134	5004	163	30E
0005433784622	5004	164	31A
0005433614049	5004	165	31C
0005433784602	5004	166	31B
0005432105108	5004	167	31E
0005433614017	5004	168	31D
0005433614047	5004	169	31F
0005433688773	5006	1	2C
0005434149618	5006	2	2F
0005434229152	5006	3	2D
0005434229156	5006	4	3A
0005434229160	5006	5	3D
0005433815303	5006	6	4C
0005434229165	5006	7	4D
0005434264908	5006	8	5C
0005434149622	5006	9	5F
0005434264912	5006	10	5D
0005434264909	5006	11	6C
0005435269643	5006	12	6D
0005434264906	5006	13	6F
0005434173481	5006	14	7D
0005435006697	5006	15	7C
0005435006667	5006	16	7F
0005434229157	5006	17	8B
0005434229163	5006	18	8D
0005434264893	5006	19	8E
0005432335860	5006	20	9C
0005434229172	5006	21	9D
0005434173484	5006	22	9F
0005434264891	5006	23	10C
0005434264889	5006	24	10B
0005434229167	5006	25	10D
0005435269638	5006	26	10F
0005434229151	5006	27	11A
0005435006695	5006	28	11F
0005434149620	5006	29	12A
0005434264896	5006	30	12B
0005434264902	5006	31	12C
0005435006696	5006	32	12E
0005434264894	5006	33	13C
0005435006693	5006	34	13D
0005434264905	5006	35	13F
0005434229171	5006	36	14A
0005434149623	5006	37	14C
0005434229169	5006	38	14F
0005434229154	5006	39	15E
0005435006628	5006	40	16D
0005434149627	5006	41	17B
0005434149621	5006	42	17A
0005434264898	5006	43	17D
0005434149616	5006	44	17F
0005434229161	5006	45	18B
0005434264888	5006	46	18E
0005434229162	5006	47	18D
0005434229153	5006	48	18F
0005434229158	5006	49	19C
0005434149624	5006	50	19B
0005435269622	5006	51	19E
0005435006659	5006	52	20C
0005434264901	5006	53	20B
0005434264887	5006	54	20E
0005435269633	5006	55	20D
0005434149617	5006	56	20F
0005434264892	5006	57	21F
0005435006622	5006	58	21E
0005435006660	5006	59	22B
0005434264907	5006	60	22E
0005432335830	5006	61	22D
0005434264910	5006	62	23C
0005434264895	5006	63	23D
0005435269637	5006	64	24B
0005433688784	5006	65	24E
0005434229155	5006	66	25B
0005434229164	5006	67	25C
0005434149625	5006	68	25D
0005432335869	5006	69	25F
0005434173483	5006	70	25E
0005434229166	5006	71	26D
0005434149626	5006	72	26F
0005434229168	5006	73	26E
0005434264913	5006	74	27A
0005434149619	5006	75	27C
0005434264897	5006	76	27B
0005434264911	5006	77	27D
0005434264903	5006	78	27E
0005434264900	5006	79	28A
0005434229170	5006	80	28B
0005434264890	5006	81	29A
0005434264904	5006	82	29B
0005432335831	5006	83	29E
0005434173482	5006	84	30D
0005434229173	5006	85	30C
0005434264899	5006	86	30F
0005435269640	5006	87	31C
0005434229159	5006	88	31F
0005433784309	8387	1	1F
0005434244510	8387	2	1D
0005432666359	8387	3	2A
0005434244528	8387	4	2F
0005433784294	8387	5	2D
0005433784292	8387	6	3C
0005435269677	8387	7	4C
0005434244490	8387	8	5D
0005434244535	8387	9	5F
0005433784404	8387	10	6A
0005434244537	8387	11	7F
0005434244589	8387	12	8A
0005434244485	8387	13	8C
0005435269684	8387	14	9B
0005433784416	8387	15	9E
0005434244536	8387	16	10A
0005434244511	8387	17	13A
0005435269675	8387	18	14A
0005435269683	8387	19	14B
0005435269676	8387	20	15B
0005433784311	8387	21	15A
0005435269681	8387	22	15D
0005435269679	8387	23	16B
0005435269680	8387	24	17A
0005433784293	8387	25	16F
0005433784403	8387	26	18A
0005434244534	8387	27	18B
0005432666360	8387	28	18E
0005434244465	8387	29	19D
0005435269678	8387	30	21A
0005434244467	8387	31	20F
0005434244494	8387	32	22D
0005435269682	8387	33	23E
0005433784295	8387	34	24B
0005433784402	8387	35	24C
0005434244571	8387	36	25C
0005434244522	8387	37	26A
0005434244569	8387	38	26B
0005433784312	8387	39	26E
0005433784430	8387	40	28C
0005434244468	8387	41	28D
0005433784328	8387	42	29A
0005434244466	8387	43	29B
0005433784310	8387	44	29D
0005433784415	8387	45	29F
0005434244486	8387	46	30C
0005433784339	8387	47	31C
0005433613389	8386	1	5A
0005433613504	8386	2	6A
0005433613399	8386	3	7A
0005433613510	8386	4	7C
0005433613438	8386	5	8F
0005433613456	8386	6	9B
0005433613649	8386	7	9C
0005433613487	8386	8	9D
0005433613472	8386	9	11B
0005433613650	8386	10	13C
0005433613388	8386	11	14B
0005433613495	8386	12	15F
0005433613624	8386	13	17B
0005433613464	8386	14	18B
0005433613678	8386	15	18D
0005433613648	8386	16	20D
0005433613415	8386	17	20F
0005433613548	8386	18	24D
0005433613493	8386	19	24F
0005433613494	8386	20	26A
0005433613502	8386	21	26E
0005433613453	8386	22	27B
0005433613429	8386	23	27D
0005433613569	8386	24	28D
0005433613431	8386	25	28F
0005433613480	8386	26	30C
0005433613625	8386	27	30E
0005433613568	8386	28	31E
0005433613430	8386	29	31D
0005432034690	8385	1	1A
0005435006803	8385	2	1C
0005434264726	8385	3	1D
0005435286568	8385	4	2A
0005432335927	8385	5	1F
0005434264687	8385	6	2F
0005434228989	8385	7	3D
0005434229055	8385	8	3C
0005434264735	8385	9	3F
0005432034685	8385	10	4A
0005433534480	8385	11	4F
0005432034691	8385	12	4D
0005432335926	8385	13	5A
0005432034683	8385	14	5D
0005434264759	8385	15	5C
0005435006816	8385	16	6A
0005433689892	8385	17	6C
0005432034704	8385	18	6D
0005434229026	8385	19	7A
0005434264760	8385	20	7D
0005432335922	8385	21	7C
0005432034692	8385	22	8A
0005432034702	8385	23	7F
0005435006801	8385	24	8C
0005435006804	8385	25	8B
0005434264766	8385	26	8E
0005432034695	8385	27	8D
0005432047515	8385	28	9A
0005435006799	8385	29	9C
0005434228973	8385	30	9E
0005435006814	8385	31	10C
0005434228975	8385	32	10D
0005434229053	8385	33	10F
0005432335923	8385	34	11A
0005434228988	8385	35	11C
0005435006812	8385	36	11B
0005433688791	8385	37	12A
0005434264736	8385	38	12D
0005432335929	8385	39	12C
0005433534479	8385	40	12E
0005434228976	8385	41	13C
0005434229025	8385	42	13D
0005433815343	8385	43	13F
0005435286569	8385	44	13E
0005432034694	8385	45	14A
0005433815342	8385	46	14C
0005435006809	8385	47	14B
0005432034689	8385	48	14D
0005434264734	8385	49	14E
0005433690907	8385	50	14F
0005434149538	8385	51	15A
0005432335928	8385	52	15B
0005435006800	8385	53	15C
0005432335919	8385	54	15F
0005434149540	8385	55	16B
0005434264779	8385	56	16D
0005435006813	8385	57	16F
0005432034677	8385	58	16E
0005434264719	8385	59	17B
0005433690908	8385	60	17A
0005435006793	8385	61	17C
0005432034687	8385	62	17E
0005435006805	8385	63	18A
0005432034681	8385	64	18C
0005435286567	8385	65	18D
0005435006798	8385	66	18E
0005432034698	8385	67	19B
0005432034701	8385	68	18F
0005432047516	8385	69	19C
0005435006806	8385	70	19D
0005435006796	8385	71	20A
0005432034686	8385	72	19E
0005434264716	8385	73	20C
0005432034697	8385	74	21A
0005433688790	8385	75	21C
0005434149571	8385	76	21D
0005433689891	8385	77	21E
0005432034688	8385	78	22A
0005434264717	8385	79	22D
0005435006807	8385	80	22F
0005432034682	8385	81	22E
0005434228986	8385	82	23B
0005432034699	8385	83	23D
0005434264699	8385	84	23E
0005432034679	8385	85	23F
0005432335921	8385	86	24B
0005432034703	8385	87	24C
0005435006795	8385	88	24F
0005434229013	8385	89	24E
0005432335925	8385	90	25A
0005432034684	8385	91	25C
0005435006810	8385	92	26A
0005434229001	8385	93	26B
0005434229003	8385	94	26D
0005433815344	8385	95	26F
0005435286566	8385	96	27A
0005434264691	8385	97	27C
0005434228987	8385	98	27B
0005433815340	8385	99	27E
0005432335924	8385	100	27D
0005433534478	8385	101	27F
0005435006808	8385	102	28C
0005435006811	8385	103	28B
0005434149572	8385	104	28E
0005433815341	8385	105	28F
0005435006815	8385	106	29B
0005432335920	8385	107	29A
0005435006802	8385	108	29E
0005432034700	8385	109	30A
0005435006794	8385	110	29F
0005434264780	8385	111	30B
0005434229054	8385	112	30C
0005432034696	8385	113	30E
0005435006797	8385	114	30D
0005435006792	8385	115	30F
0005432034678	8385	116	31A
0005434149539	8385	117	31C
0005432034693	8385	118	31B
0005432034680	8385	119	31E
0005433202224	12633	1	1A
0005434638992	12633	2	1B
0005433202231	12633	3	1C
0005433202223	12633	4	1D
0005434638917	12633	5	2A
0005434638903	12633	6	2B
0005433202225	12633	7	2C
0005434638893	12633	8	2D
0005433202234	12633	9	3B
0005434638854	12633	10	3D
0005434638991	12633	11	4B
0005434638916	12633	12	4D
0005434638864	12633	13	5A
0005433202236	12633	14	5B
0005433202233	12633	15	6A
0005434638886	12633	16	7A
0005434638900	12633	17	7B
0005434638885	12633	18	7D
0005433202237	12633	19	18A
0005433202226	12633	20	18B
0005434638879	12633	21	18D
0005433202238	12633	22	19A
0005434638904	12633	23	19B
0005434638894	12633	24	19D
0005434638887	12633	25	20B
0005433202235	12633	26	20C
0005433202228	12633	27	20D
0005434638924	12633	28	21A
0005434638899	12633	29	21C
0005433202229	12633	30	21D
0005433202230	12633	31	22A
0005433202232	12633	32	22C
0005434638850	12633	33	23A
0005433202227	12633	34	23B
0005434639064	23375	1	1A
0005432290602	23375	2	1C
0005434639050	23375	3	2A
0005434639045	23375	4	2B
0005432290603	23375	5	2C
0005432290604	23375	6	2D
0005434639060	23375	7	3A
0005434639053	23375	8	3D
0005434639056	23375	9	4A
0005434639066	23375	10	4B
0005433202109	23375	11	4C
0005434639054	23375	12	4D
0005434639069	23375	13	5B
0005433202114	23375	14	6B
0005434639065	23375	15	6C
0005434639061	23375	16	6D
0005434639068	23375	17	7B
0005434639057	23375	18	7D
0005434639044	23375	19	18B
0005432290601	23375	20	18C
0005433202119	23375	21	19B
0005434639047	23375	22	19D
0005434639063	23375	23	20A
0005434639049	23375	24	20D
0005434639046	23375	25	21A
0005434639051	23375	26	21B
0005433202116	23375	27	21D
0005434639062	23375	28	21C
0005434639067	23375	29	22B
0005434639055	23375	30	22A
0005434639059	23375	31	22C
0005434639052	23375	32	22D
0005434639058	23375	33	23A
0005434639048	23375	34	23B
0005432327948	21108	1	1D
0005432382484	21108	2	1F
0005432327937	21108	3	2A
0005432054277	21108	4	5A
0005432382544	21108	5	5C
0005432382510	21108	6	5D
0005432382559	21108	7	5E
0005432054276	21108	8	7C
0005432327936	21108	9	7E
0005432382490	21108	10	8D
0005432382536	21108	11	8F
0005432382545	21108	12	9C
0005432382507	21108	13	9F
0005432382508	21108	14	11D
0005432327983	21108	15	11F
0005432327938	21108	16	12A
0005432382521	21108	17	12D
0005432382509	21108	18	12E
0005432382519	21108	19	14F
0005432382572	21108	20	15C
0005432382501	21108	21	16A
0005432327897	21108	22	16D
0005432382503	21108	23	17D
0005432054278	21108	24	17E
0005432327984	21108	25	17F
0005432382487	21108	26	18C
0005432382518	21108	27	18D
0005432327895	21108	28	20D
0005432327929	21108	29	20E
0005432327928	21108	30	20F
0005432328261	31227	1	1A
0005432328264	31227	2	1C
0005432287137	31227	3	1D
0005432328247	31227	4	1F
0005432328260	31227	5	2A
0005432382783	31227	6	2C
0005432382796	31227	7	2F
0005432328245	31227	8	3A
0005432328233	31227	9	3C
0005432328246	31227	10	3D
0005432328225	31227	11	3F
0005432382772	31227	12	4A
0005432382769	31227	13	4C
0005432382776	31227	14	4D
0005432382781	31227	15	4E
0005432382787	31227	16	4F
0005432328231	31227	17	5A
0005432328265	31227	18	5C
0005432328256	31227	19	5E
0005432328229	31227	20	5F
0005432328220	31227	21	6A
0005432328219	31227	22	6C
0005432382771	31227	23	6D
0005432328257	31227	24	6E
0005432287138	31227	25	6F
0005432287136	31227	26	7A
0005432328251	31227	27	7D
0005432328242	31227	28	7E
0005432328230	31227	29	7F
0005432328254	31227	30	8A
0005432328221	31227	31	8C
0005432328255	31227	32	8D
0005432328234	31227	33	8E
0005432382795	31227	34	8F
0005432382784	31227	35	9A
0005432382798	31227	36	9C
0005432328244	31227	37	9D
0005432328236	31227	38	9E
0005432328228	31227	39	9F
0005432328222	31227	40	10A
0005432287139	31227	41	10C
0005432382790	31227	42	10D
0005432382773	31227	43	10E
0005432382788	31227	44	10F
0005432382791	31227	45	11A
0005432328252	31227	46	11C
0005432382785	31227	47	11D
0005432382775	31227	48	11E
0005432328248	31227	49	11F
0005432382779	31227	50	12C
0005432328223	31227	51	12D
0005432382799	31227	52	12E
0005432382789	31227	53	12F
0005432382793	31227	54	13A
0005432328227	31227	55	13C
0005432382777	31227	56	13D
0005432382803	31227	57	13E
0005432328253	31227	58	13F
0005432328232	31227	59	14A
0005432328237	31227	60	14C
0005432382786	31227	61	14D
0005432382770	31227	62	14E
0005432328226	31227	63	14F
0005432382797	31227	64	15A
0005432328263	31227	65	15C
0005432328249	31227	66	15D
0005432382774	31227	67	15E
0005432382802	31227	68	15F
0005432328240	31227	69	16A
0005432382768	31227	70	16C
0005432328262	31227	71	16D
0005432287140	31227	72	16E
0005432328239	31227	73	17A
0005432382792	31227	74	17C
0005432328241	31227	75	17D
0005432382778	31227	76	17E
0005432382782	31227	77	17F
0005432328250	31227	78	18A
0005432328224	31227	79	18C
0005432382800	31227	80	18D
0005432382794	31227	81	18E
0005432382767	31227	82	18F
0005432328258	31227	83	19D
0005432328243	31227	84	19E
0005432382801	31227	85	19F
0005432328259	31227	86	20A
0005432328235	31227	87	20C
0005432382780	31227	88	20D
0005432328238	31227	89	20F
0005432423974	13325	1	1A
0005432423996	13325	2	2A
0005432423965	13325	3	2D
0005432423982	13325	4	3A
0005432423960	13325	5	3F
0005432423958	13325	6	4A
0005432423968	13325	7	4C
0005432423986	13325	8	5D
0005432423992	13325	9	5E
0005432423976	13325	10	6A
0005432423973	13325	11	7A
0005432423980	13325	12	7D
0005432423990	13325	13	7E
0005432423983	13325	14	8A
0005432423957	13325	15	8D
0005432423989	13325	16	8F
0005432423994	13325	17	9C
0005432423981	13325	18	9D
0005432423964	13325	19	9E
0005432423956	13325	20	10C
0005432423971	13325	21	10D
0005432423963	13325	22	10E
0005432423997	13325	23	11A
0005432423995	13325	24	11C
0005432423977	13325	25	11D
0005432423979	13325	26	11F
0005432423991	13325	27	14A
0005432423972	13325	28	14C
0005432423999	13325	29	14E
0005432423998	13325	30	14F
0005432423978	13325	31	15A
0005432423969	13325	32	15E
0005432423975	13325	33	16C
0005432423962	13325	34	16F
0005432423984	13325	35	17A
0005432423988	13325	36	17C
0005432423993	13325	37	17D
0005432423987	13325	38	18A
0005432423961	13325	39	18D
0005432423985	13325	40	19A
0005432423959	13325	41	19F
0005432423966	13325	42	20A
0005432423967	13325	43	20C
0005432423970	13325	44	20D
0005434186157	9589	1	1A
0005434448284	9589	2	2D
0005432817195	9589	3	3A
0005432817196	9589	4	3C
0005432817207	9589	5	3D
0005432817202	9589	6	3F
0005432817206	9589	7	4A
0005432817210	9589	8	4D
0005432817187	9589	9	4E
0005434448282	9589	10	4F
0005432901306	9589	11	5A
0005434157355	9589	12	5C
0005432822130	9589	13	5E
0005432817181	9589	14	5F
0005432817180	9589	15	6A
0005432817208	9589	16	6C
0005432288957	9589	17	6D
0005432817209	9589	18	6F
0005432817183	9589	19	7C
0005432288954	9589	20	7D
0005432817182	9589	21	7E
0005434157354	9589	22	7F
0005432817199	9589	23	8A
0005432901302	9589	24	8C
0005434186159	9589	25	8D
0005432901346	9589	26	8E
0005432901295	9589	27	8F
0005432901369	9589	28	9A
0005432288955	9589	29	9C
0005432822134	9589	30	9D
0005432822133	9589	31	9E
0005432822129	9589	32	10D
0005432817192	9589	33	10E
0005432817204	9589	34	11A
0005432817200	9589	35	11C
0005432817189	9589	36	11E
0005432901380	9589	37	11F
0005432817186	9589	38	12A
0005432901370	9589	39	12C
0005432817185	9589	40	12D
0005432901301	9589	41	12E
0005432817191	9589	42	12F
0005432901356	9589	43	13A
0005432901317	9589	44	13C
0005432288956	9589	45	13F
0005432817211	9589	46	14A
0005432901319	9589	47	14C
0005432817203	9589	48	14D
0005432288958	9589	49	14E
0005432817198	9589	50	14F
0005432901361	9589	51	15A
0005432817201	9589	52	15C
0005432901305	9589	53	15D
0005432817194	9589	54	15E
0005432817193	9589	55	16A
0005432817205	9589	56	16C
0005434186158	9589	57	16F
0005434448283	9589	58	17C
0005432817197	9589	59	17D
0005432817188	9589	60	17E
0005434157358	9589	61	18A
0005432901293	9589	62	18C
0005432901316	9589	63	18D
0005432817184	9589	64	18F
0005432822127	9589	65	19E
0005432822128	9589	66	19F
0005434186154	9589	67	20A
0005432817190	9589	68	20C
0005432901381	9589	69	20D
0005432822131	9589	70	20E
0005432822132	9589	71	20F
0005432816948	29007	1	1A
0005432817022	29007	2	1C
0005432816976	29007	3	2C
0005432822081	29007	4	2D
0005432901447	29007	5	2F
0005432901439	29007	6	3C
0005432817009	29007	7	3D
0005432817050	29007	8	3F
0005432816992	29007	9	4E
0005432816995	29007	10	4F
0005432816969	29007	11	5C
0005432901448	29007	12	5D
0005434157407	29007	13	5E
0005432901445	29007	14	5F
0005432002057	29007	15	6A
0005434157408	29007	16	6D
0005432901451	29007	17	6E
0005432901444	29007	18	7D
0005432901450	29007	19	7F
0005434157411	29007	20	8A
0005432816939	29007	21	8D
0005432816960	29007	22	9D
0005432901452	29007	23	9E
0005434157404	29007	24	9F
0005432901446	29007	25	10D
0005432901453	29007	26	11A
0005432822073	29007	27	11C
0005432901437	29007	28	11D
0005434186169	29007	29	12C
0005432816994	29007	30	12D
0005432901454	29007	31	12F
0005432816991	29007	32	13F
0005432816993	29007	33	14E
0005432901443	29007	34	14F
0005432901442	29007	35	15A
0005432901440	29007	36	15C
0005432901441	29007	37	15E
0005434157405	29007	38	15F
0005434186170	29007	39	16A
0005434157406	29007	40	16C
0005434157410	29007	41	16D
0005432901449	29007	42	16F
0005432817051	29007	43	17A
0005432816940	29007	44	17E
0005434157409	29007	45	17F
0005432901438	29007	46	18C
0005432816981	29007	47	18D
0005434186168	29007	48	18F
0005432002056	29007	49	19A
0005432816975	29007	50	19E
0005432816961	29007	51	20C
0005432816968	29007	52	20D
0005434186171	29007	53	20F
0005432613822	15036	1	1B
0005432611672	15036	2	2A
0005432611675	15036	3	2B
0005432613825	15036	4	4A
0005432611673	15036	5	4B
0005432611674	15036	6	5A
0005432613823	15036	7	5B
0005432613826	15036	8	6A
0005432613824	15036	9	6B
0005432607494	31570	1	2B
0005432607505	31570	2	6B
0005433568440	11843	1	1A
0005433568435	11843	2	1D
0005433568430	11843	3	2C
0005433568427	11843	4	2D
0005433568425	11843	5	3C
0005433568463	11843	6	2F
0005433568477	11843	7	3F
0005433568454	11843	8	4C
0005433568433	11843	9	4A
0005432947797	11843	10	4D
0005433568434	11843	11	5F
0005433568447	11843	12	6B
0005433568438	11843	13	6E
0005433568450	11843	14	7C
0005433568432	11843	15	7E
0005433568476	11843	16	7D
0005433568442	11843	17	7F
0005433568452	11843	18	8F
0005433568461	11843	19	9B
0005433568444	11843	20	9A
0005432947776	11843	21	9C
0005433568443	11843	22	9F
0005433568424	11843	23	9E
0005433568441	11843	24	10A
0005433568449	11843	25	10B
0005433568423	11843	26	10D
0005433568437	11843	27	11B
0005433568474	11843	28	11D
0005432947796	11843	29	11F
0005433568465	11843	30	12B
0005433568472	11843	31	12C
0005433568460	11843	32	12F
0005433568473	11843	33	12E
0005433568436	11843	34	14A
0005433568455	11843	35	13F
0005433568471	11843	36	14B
0005433568462	11843	37	14C
0005433568428	11843	38	15B
0005433568458	11843	39	15A
0005433568445	11843	40	15D
0005432947764	11843	41	16A
0005433568464	11843	42	16C
0005433568431	11843	43	16B
0005433568468	11843	44	16E
0005433568429	11843	45	17A
0005433568457	11843	46	16F
0005433568459	11843	47	17B
0005433568469	11843	48	18A
0005433568448	11843	49	18E
0005433568467	11843	50	18D
0005433568466	11843	51	19A
0005433568451	11843	52	18F
0005433568456	11843	53	19C
0005433568475	11843	54	19F
0005433568446	11843	55	19E
0005433568453	11843	56	20B
0005433568426	11843	57	20D
0005432947775	11843	58	21C
0005433568439	11843	59	21B
0005433568470	11843	60	21E
0005432948127	25271	1	1A
0005433568071	25271	2	1D
0005432948104	25271	3	2A
0005433568073	25271	4	2D
0005432948129	25271	5	3D
0005433568033	25271	6	3C
0005432948102	25271	7	4A
0005432948097	25271	8	3F
0005432948138	25271	9	4D
0005432948132	25271	10	5A
0005432948134	25271	11	6B
0005432948109	25271	12	6C
0005432948098	25271	13	6E
0005432948136	25271	14	7F
0005433568027	25271	15	8C
0005432948121	25271	16	8F
0005432948118	25271	17	8E
0005433568076	25271	18	9A
0005432948107	25271	19	9C
0005432948100	25271	20	9B
0005433568023	25271	21	9D
0005432948105	25271	22	10C
0005432948120	25271	23	10B
0005432948117	25271	24	10D
0005432948115	25271	25	11A
0005433568072	25271	26	11B
0005432948123	25271	27	11D
0005432948131	25271	28	11C
0005432948130	25271	29	12C
0005432948128	25271	30	12E
0005432948126	25271	31	13C
0005432948111	25271	32	13D
0005432948133	25271	33	14A
0005432948110	25271	34	14D
0005432948137	25271	35	15B
0005433568070	25271	36	15A
0005432948122	25271	37	15F
0005432948106	25271	38	15D
0005432948114	25271	39	16D
0005432948116	25271	40	16F
0005432948112	25271	41	17B
0005432948108	25271	42	17C
0005432948119	25271	43	18C
0005433568082	25271	44	19A
0005432948113	25271	45	19E
0005432948125	25271	46	19D
0005432948101	25271	47	19C
0005432948135	25271	48	20A
0005432948099	25271	49	20C
0005432948103	25271	50	20F
0005432948124	25271	51	21B
0005434654425	5398	1	1A
0005434654401	5398	2	2D
0005434654421	5398	3	2F
0005432114173	5398	4	3A
0005435340050	5398	5	4E
0005435340048	5398	6	5A
0005435340009	5398	7	5C
0005434654403	5398	8	6D
0005434654402	5398	9	6E
0005432114172	5398	10	6F
0005434654417	5398	11	7C
0005434654422	5398	12	8E
0005435340039	5398	13	9A
0005434654405	5398	14	9C
0005434654427	5398	15	9D
0005434654424	5398	16	9E
0005434654416	5398	17	10A
0005434654404	5398	18	10E
0005435340012	5398	19	11D
0005435340038	5398	20	11E
0005435340010	5398	21	11F
0005434654423	5398	22	12C
0005435340027	5398	23	12D
0005434654412	5398	24	12E
0005434654406	5398	25	12F
0005434654426	5398	26	14C
0005434654428	5398	27	14D
0005434654413	5398	28	14E
0005434654411	5398	29	15C
0005435340020	5398	30	15D
0005434654400	5398	31	15E
0005435340011	5398	32	15F
0005434654408	5398	33	16A
0005434654415	5398	34	16C
0005435339995	5398	35	16D
0005434654407	5398	36	16E
0005434654410	5398	37	17A
0005434654399	5398	38	17C
0005434654414	5398	39	17D
0005434654420	5398	40	17F
0005432114174	5398	41	18A
0005435340049	5398	42	18C
0005434654418	5398	43	18E
0005434654409	5398	44	19C
0005432114171	5398	45	19F
0005434654419	5398	46	20E
0005434654198	12555	1	1A
0005435555351	12555	2	2A
0005434654187	12555	3	3C
0005434654174	12555	4	3D
0005434654186	12555	5	3F
0005435340113	12555	6	4A
0005434656523	12555	7	4D
0005435340125	12555	8	5A
0005435340120	12555	9	5E
0005435340124	12555	10	7A
0005435340116	12555	11	7D
0005434654305	12555	12	8D
0005435340122	12555	13	9C
0005435340127	12555	14	9F
0005435340119	12555	15	10D
0005435340114	12555	16	10F
0005434654216	12555	17	11C
0005435340126	12555	18	11E
0005435340121	12555	19	12C
0005435555352	12555	20	12D
0005435340123	12555	21	13D
0005434654217	12555	22	16A
0005434654301	12555	23	16C
0005435340115	12555	24	16F
0005434654200	12555	25	17A
0005435340128	12555	26	17D
0005435340118	12555	27	19A
0005434654225	12555	28	19C
0005435555353	12555	29	19E
0005435340117	12555	30	20A
0005433715492	7458	1	1A
0005433715520	7458	2	1D
0005433656637	7458	3	2A
0005433715521	7458	4	2C
0005433715504	7458	5	2D
0005433689889	7458	6	3A
0005433715516	7458	7	3D
0005432428871	7458	8	4A
0005433715517	7458	9	4C
0005433715524	7458	10	4B
0005433715478	7458	11	4E
0005433715514	7458	12	4F
0005433715484	7458	13	5A
0005433722155	7458	14	5C
0005433715526	7458	15	5D
0005433715501	7458	16	5F
0005432078058	7458	17	6C
0005433656635	7458	18	6B
0005433719105	7458	19	7A
0005433715490	7458	20	6F
0005433688788	7458	21	7C
0005433715494	7458	22	7D
0005433690906	7458	23	8A
0005433715525	7458	24	8C
0005433715502	7458	25	8F
0005433688789	7458	26	9A
0005433715509	7458	27	9C
0005433715506	7458	28	9B
0005433715523	7458	29	9E
0005433715489	7458	30	9F
0005433715477	7458	31	10C
0005433715499	7458	32	10E
0005433715479	7458	33	11D
0005433688787	7458	34	11F
0005433715512	7458	35	12A
0005433715480	7458	36	12C
0005433715498	7458	37	12F
0005433715500	7458	38	13B
0005433715513	7458	39	13C
0005433715485	7458	40	13D
0005432078057	7458	41	13E
0005433715487	7458	42	13F
0005433656636	7458	43	14D
0005433715491	7458	44	14F
0005432078054	7458	45	15B
0005433719107	7458	46	15C
0005433715511	7458	47	15D
0005433715515	7458	48	15F
0005433715518	7458	49	16B
0005432078056	7458	50	16E
0005433689890	7458	51	17A
0005433715475	7458	52	16F
0005433715508	7458	53	17B
0005433715495	7458	54	17C
0005433715519	7458	55	17F
0005433715483	7458	56	18B
0005433715507	7458	57	18C
0005433715496	7458	58	18E
0005433690905	7458	59	19A
0005433722156	7458	60	19C
0005433715493	7458	61	19E
0005432078055	7458	62	19F
0005433715482	7458	63	20B
0005433715522	7458	64	20D
0005433715505	7458	65	20E
0005433715510	7458	66	20F
0005433715503	7458	67	21B
0005433715488	7458	68	21A
0005432428870	7458	69	21F
0005433715497	7458	70	22B
0005433715476	7458	71	22F
0005433715481	7458	72	22E
0005433719106	7458	73	23B
0005433722157	7458	74	23E
0005433715486	7458	75	23F
0005433715169	29215	1	1A
0005433715094	29215	2	1D
0005432006733	29215	3	1F
0005433656615	29215	4	2F
0005433715087	29215	5	3A
0005433715069	29215	6	4A
0005433715091	29215	7	4E
0005433715116	29215	8	6A
0005433715324	29215	9	6C
0005433715081	29215	10	6F
0005433715122	29215	11	7B
0005432428897	29215	12	8A
0005433688773	29215	13	8B
0005435266115	29215	14	8F
0005433688784	29215	15	9A
0005435266114	29215	16	9D
0005433715093	29215	17	9C
0005433715255	29215	18	9F
0005432006736	29215	19	10B
0005433715082	29215	20	10C
0005432428896	29215	21	10E
0005433715185	29215	22	11A
0005433715095	29215	23	11B
0005433715090	29215	24	11C
0005433715098	29215	25	11D
0005433715121	29215	26	11F
0005433715200	29215	27	12A
0005433715083	29215	28	12B
0005433715120	29215	29	12D
0005435266113	29215	30	13F
0005432428898	29215	31	14D
0005435266116	29215	32	14F
0005432006735	29215	33	15A
0005433715187	29215	34	15D
0005435266112	29215	35	15E
0005433715118	29215	36	15F
0005433715155	29215	37	16A
0005435266111	29215	38	16C
0005433715254	29215	39	17B
0005432006732	29215	40	17C
0005433715140	29215	41	18D
0005433715167	29215	42	19B
0005432006734	29215	43	19D
0005432428895	29215	44	20A
0005433715325	29215	45	20C
0005433715170	29215	46	21A
0005433715141	29215	47	21F
0005433715186	29215	48	21E
0005433715166	29215	49	22E
0005435266110	29215	50	23E
0005434184629	8667	1	3A
0005434182034	8667	2	3C
0005434095142	8667	3	3F
0005434095133	8667	4	4C
0005434182033	8667	5	6E
0005434181985	8667	6	7D
0005434326085	8667	7	9A
0005434095137	8667	8	9E
0005434095138	8667	9	10D
0005434095144	8667	10	10E
0005434095136	8667	11	11A
0005434095134	8667	12	11D
0005434095145	8667	13	11E
0005434095140	8667	14	12F
0005434095135	8667	15	14A
0005434095141	8667	16	15C
0005434095147	8667	17	16C
0005434095139	8667	18	17A
0005434181959	8667	19	17C
0005434184630	8667	20	18D
0005434095146	8667	21	18E
0005434095143	8667	22	19A
0005434182063	11665	1	1A
0005434182067	11665	2	1D
0005434184644	11665	3	3D
0005434182071	11665	4	4C
0005434182060	11665	5	4D
0005434182061	11665	6	5C
0005434182066	11665	7	6D
0005434183559	11665	8	7A
0005434183558	11665	9	7F
0005434182069	11665	10	8C
0005434182065	11665	11	9C
0005434182068	11665	12	11E
0005434095033	11665	13	12D
0005434182062	11665	14	13F
0005434095034	11665	15	14A
0005434182064	11665	16	14F
0005434182070	11665	17	15D
0005434184643	11665	18	18C
0005433397260	1458	1	1C
0005435732224	1458	2	1D
0005433397226	1458	3	1F
0005433397254	1458	4	3A
0005433397330	1458	5	3C
0005433456930	1458	6	3D
0005435732217	1458	7	3F
0005433397222	1458	8	4A
0005433397347	1458	9	4C
0005433397252	1458	10	4D
0005435732221	1458	11	4E
0005433456932	1458	12	4F
0005433397200	1458	13	5E
0005433397220	1458	14	6D
0005433397250	1458	15	6E
0005433397410	1458	16	6F
0005435732216	1458	17	7A
0005433397348	1458	18	7D
0005433397251	1458	19	8A
0005435732218	1458	20	8C
0005435732225	1458	21	8E
0005432297253	1458	22	9D
0005435732220	1458	23	10A
0005433397297	1458	24	10C
0005433397301	1458	25	10D
0005435732222	1458	26	10F
0005435732223	1458	27	11E
0005433397273	1458	28	11F
0005435732214	1458	29	12A
0005433397225	1458	30	12D
0005433397300	1458	31	13C
0005433397221	1458	32	13D
0005433456931	1458	33	13E
0005433397217	1458	34	14D
0005432297252	1458	35	15A
0005433397296	1458	36	15C
0005435732219	1458	37	15D
0005433397187	1458	38	16E
0005435732215	1458	39	17A
0005433397259	1458	40	17C
0005433397245	1458	41	18A
0005433397188	1458	42	18C
0005433397290	1458	43	18D
0005433397203	1458	44	18F
0005433397230	1458	45	20D
0005433397257	1458	46	20E
0005433456929	1458	47	20F
0005433397625	19273	1	1A
0005432906514	19273	2	1C
0005433397620	19273	3	1F
0005433397591	19273	4	2A
0005433397600	19273	5	2C
0005435732137	19273	6	2D
0005433397598	19273	7	2F
0005433397614	19273	8	3C
0005433397607	19273	9	3D
0005433397608	19273	10	3F
0005433397621	19273	11	4A
0005433397616	19273	12	4D
0005433397609	19273	13	4E
0005432906513	19273	14	5C
0005433397579	19273	15	5D
0005433397618	19273	16	5E
0005433397589	19273	17	6A
0005433397626	19273	18	6D
0005433397597	19273	19	6F
0005433397578	19273	20	7A
0005432906511	19273	21	7C
0005435732160	19273	22	7D
0005433397599	19273	23	7E
0005433397593	19273	24	7F
0005433456899	19273	25	8D
0005433397624	19273	26	8E
0005433397588	19273	27	8F
0005433397606	19273	28	9A
0005433397580	19273	29	10D
0005432906515	19273	30	11A
0005435732138	19273	31	11D
0005433397612	19273	32	11E
0005433397604	19273	33	11F
0005435732130	19273	34	12A
0005433397594	19273	35	12D
0005433397581	19273	36	12F
0005433397583	19273	37	13A
0005433397617	19273	38	13C
0005433397601	19273	39	13D
0005433397592	19273	40	13F
0005433397577	19273	41	14A
0005433397611	19273	42	14D
0005433397582	19273	43	14E
0005435732159	19273	44	15A
0005433397595	19273	45	15C
0005433397623	19273	46	15D
0005433397605	19273	47	15E
0005433397584	19273	48	16A
0005435732131	19273	49	15F
0005433456904	19273	50	16C
0005432906512	19273	51	16E
0005433397585	19273	52	17C
0005433397596	19273	53	17D
0005433397603	19273	54	17E
0005433397613	19273	55	17F
0005433397587	19273	56	18C
0005433397622	19273	57	18D
0005433456900	19273	58	18E
0005433397610	19273	59	18F
0005433456903	19273	60	19D
0005433397586	19273	61	19E
0005433397615	19273	62	19F
0005433397619	19273	63	20A
0005433397590	19273	64	20C
0005433397602	19273	65	20D
0005434443433	17387	1	1A
0005434443434	17387	2	3C
0005434443463	17387	3	4A
0005434443512	17387	4	4B
0005434443511	17387	5	5D
0005434443453	17387	6	6D
0005434443470	17387	7	7A
0005434443469	17387	8	18B
0005434443467	17387	9	19D
0005434443428	17387	10	21B
0005434443552	20570	1	1B
0005434443542	20570	2	1D
0005434443546	20570	3	2C
0005434443539	20570	4	3D
0005434443553	20570	5	4C
0005434443550	20570	6	4D
0005434443554	20570	7	5C
0005434443548	20570	8	6A
0005434443555	20570	9	6C
0005434443545	20570	10	6D
0005434443544	20570	11	18A
0005434443543	20570	12	19A
0005434443551	20570	13	20A
0005434443540	20570	14	21B
0005434443541	20570	15	22C
0005434443549	20570	16	23A
0005434443547	20570	17	23B
0005434954571	7231	1	1B
0005434954573	7231	2	3A
0005435377542	7231	3	4A
0005435377541	7231	4	4B
0005434954572	7231	5	6B
0005435377560	28322	1	1B
0005435377558	28322	2	3A
0005435377557	28322	3	5B
0005435377559	28322	4	6A
0005435377556	28322	5	6B
0005434351568	4483	1	1B
0005434351569	4483	2	1C
0005434351573	4483	3	1D
0005434351570	4483	4	2B
0005434351577	4483	5	3A
0005434351571	4483	6	3B
0005434183549	4483	7	3C
0005434351572	4483	8	4A
0005434326265	4483	9	4C
0005435893521	4483	10	4D
0005434351580	4483	11	5A
0005434351574	4483	12	5C
0005434351579	4483	13	6C
0005434183548	4483	14	7D
0005434351575	4483	15	19A
0005434351576	4483	16	19C
0005434326264	4483	17	20B
0005434351581	4483	18	21D
0005435893504	4483	19	22A
0005434351578	4483	20	22D
0005435893565	29665	1	1A
0005434351464	29665	2	2B
0005434351472	29665	3	2C
0005434351470	29665	4	3D
0005435893562	29665	5	4B
0005435893563	29665	6	5B
0005434351474	29665	7	5D
0005434351471	29665	8	6C
0005435893561	29665	9	7A
0005434351466	29665	10	7B
0005435893567	29665	11	18C
0005435893568	29665	12	19C
0005435893564	29665	13	20A
0005435893566	29665	14	22D
0005434351476	29665	15	23A
0005434351512	29665	16	23B
0005433463879	1083	1	1C
0005433341684	1083	2	2B
0005435091981	1083	3	2F
0005433341443	1083	4	3B
0005435091976	1083	5	5A
0005434445224	1083	6	5G
0005434446500	1083	7	9B
0005435091978	1083	8	9G
0005433341575	1083	9	11F
0005433341533	1083	10	11H
0005433341421	1083	11	12A
0005435091979	1083	12	13B
0005433341433	1083	13	13H
0005433462725	1083	14	14B
0005433341777	1083	15	14A
0005433341941	1083	16	15F
0005433158099	1083	17	16B
0005433341453	1083	18	16F
0005435545654	1083	19	16H
0005435545652	1083	20	17D
0005433341423	1083	21	17F
0005433341411	1083	22	18B
0005433341782	1083	23	18G
0005435091977	1083	24	18F
0005434445225	1083	25	19D
0005432293185	1083	26	20F
0005433341696	1083	27	21D
0005433341452	1083	28	21E
0005435091983	1083	29	21F
0005433341653	1083	30	22D
0005433341596	1083	31	22F
0005433269636	1083	32	22E
0005433341434	1083	33	22G
0005433462726	1083	34	23E
0005435545650	1083	35	23G
0005435091974	1083	36	24A
0005435545651	1083	37	24D
0005433341422	1083	38	24G
0005434446498	1083	39	27G
0005435091982	1083	40	28A
0005433341636	1083	41	28B
0005435091975	1083	42	28E
0005433341942	1083	43	29B
0005433341576	1083	44	29E
0005433341440	1083	45	29F
0005433341637	1083	46	30E
0005433463880	1083	47	30G
0005433341395	1083	48	31E
0005433341430	1083	49	32A
0005433462727	1083	50	33A
0005433269629	1083	51	33B
0005433341407	1083	52	33D
0005433341648	1083	53	33H
0005433341473	1083	54	34A
0005435545653	1083	55	34G
0005434446499	1083	56	34F
0005433341441	1083	57	35D
0005433341697	1083	58	35B
0005433341404	1083	59	36F
0005433341764	1083	60	36G
0005435091980	1083	61	37A
0005433159274	1083	62	38F
0005433342148	17038	1	1A
0005433269664	17038	2	1C
0005433342121	17038	3	1B
0005433342122	17038	4	1F
0005435091918	17038	5	1G
0005433342185	17038	6	2B
0005433342179	17038	7	2F
0005433342096	17038	8	2G
0005434445209	17038	9	2H
0005433342109	17038	10	3A
0005433342158	17038	11	3G
0005434445208	17038	12	4A
0005433342110	17038	13	4B
0005433342165	17038	14	4C
0005433342175	17038	15	4H
0005433342172	17038	16	5B
0005433342170	17038	17	5C
0005433342162	17038	18	5F
0005433342119	17038	19	9A
0005433342180	17038	20	9G
0005433342104	17038	21	9H
0005433342143	17038	22	11E
0005433342138	17038	23	11F
0005433342191	17038	24	11H
0005433342126	17038	25	11G
0005433342135	17038	26	12B
0005433342189	17038	27	12E
0005433342171	17038	28	13B
0005433342098	17038	29	13D
0005433342131	17038	30	13E
0005433342153	17038	31	13G
0005433342140	17038	32	13H
0005433342103	17038	33	14B
0005433342090	17038	34	14D
0005433269665	17038	35	15A
0005433159290	17038	36	15B
0005433342101	17038	37	15F
0005433342176	17038	38	15H
0005433342151	17038	39	16A
0005433342190	17038	40	16D
0005433342129	17038	41	16F
0005433269668	17038	42	16H
0005433342188	17038	43	17E
0005433342169	17038	44	17G
0005433342141	17038	45	17F
0005433342167	17038	46	17H
0005435091938	17038	47	18D
0005433342095	17038	48	19B
0005433342116	17038	49	19D
0005433342137	17038	50	19G
0005433269666	17038	51	20A
0005433342106	17038	52	20D
0005433269669	17038	53	20B
0005433342092	17038	54	20G
0005433342139	17038	55	21A
0005433342144	17038	56	21B
0005433342159	17038	57	21E
0005433342183	17038	58	21H
0005433342117	17038	59	21G
0005433159291	17038	60	22F
0005433342156	17038	61	22E
0005433342147	17038	62	22G
0005433342134	17038	63	22H
0005435091898	17038	64	23B
0005433342160	17038	65	23E
0005433342186	17038	66	23G
0005433342164	17038	67	23F
0005433342146	17038	68	23H
0005433342094	17038	69	24E
0005433342132	17038	70	24H
0005433269670	17038	71	27A
0005433342114	17038	72	27D
0005433342149	17038	73	27E
0005433342168	17038	74	28A
0005433342111	17038	75	27H
0005433342124	17038	76	28D
0005433342089	17038	77	28F
0005433342112	17038	78	28E
0005433342115	17038	79	29A
0005433342187	17038	80	29E
0005433342181	17038	81	29D
0005433342142	17038	82	29G
0005433342128	17038	83	29F
0005433342093	17038	84	29H
0005433342157	17038	85	30A
0005433342174	17038	86	31A
0005433342105	17038	87	30H
0005433269667	17038	88	31D
0005433342177	17038	89	31E
0005433342118	17038	90	31G
0005435091899	17038	91	31F
0005433342125	17038	92	32A
0005433342133	17038	93	32D
0005433342097	17038	94	32G
0005433342123	17038	95	33F
0005433342150	17038	96	34B
0005433342182	17038	97	34F
0005433342154	17038	98	34E
0005433342155	17038	99	34G
0005433342166	17038	100	35A
0005433342152	17038	101	35B
0005433342113	17038	102	35D
0005433342108	17038	103	35E
0005433342163	17038	104	35G
0005433342100	17038	105	35H
0005433342178	17038	106	36E
0005433342161	17038	107	36F
0005433342127	17038	108	36G
0005435091921	17038	109	37D
0005433342184	17038	110	37B
0005433342107	17038	111	37A
0005433342091	17038	112	37F
0005433342120	17038	113	38A
0005433342130	17038	114	38B
0005433342099	17038	115	38E
0005433342145	17038	116	38F
0005433342173	17038	117	38H
0005433342102	17038	118	39E
0005433342136	17038	119	39F
0005434066495	12809	1	1C
0005434081517	12809	2	1F
0005434081545	12809	3	2C
0005434066486	12809	4	2A
0005434066466	12809	5	2D
0005433812880	12809	6	3C
0005434066496	12809	7	3F
0005432159816	12809	8	4B
0005432159813	12809	9	4E
0005433812876	12809	10	5B
0005434066359	12809	11	5A
0005434066386	12809	12	5C
0005432433627	12809	13	5D
0005434066376	12809	14	5F
0005434066336	12809	15	6C
0005434066427	12809	16	7A
0005434081529	12809	17	7D
0005434081482	12809	18	8A
0005433989690	12809	19	8B
0005434026669	12809	20	8D
0005432433631	12809	21	8E
0005434066379	12809	22	9B
0005432159814	12809	23	9E
0005432433630	12809	24	10B
0005434066362	12809	25	10C
0005434066337	12809	26	10E
0005433989684	12809	27	11A
0005432433629	12809	28	11B
0005432433626	12809	29	11C
0005434026670	12809	30	11E
0005433812878	12809	31	11F
0005434026671	12809	32	12A
0005434081501	12809	33	12B
0005434081495	12809	34	12C
0005432159817	12809	35	12E
0005434066374	12809	36	12F
0005432159812	12809	37	13B
0005434066308	12809	38	13A
0005434081539	12809	39	13C
0005434081490	12809	40	13D
0005434081491	12809	41	13F
0005433812877	12809	42	14B
0005434066487	12809	43	14C
0005434066378	12809	44	14D
0005434066375	12809	45	14F
0005434066353	12809	46	16B
0005434066324	12809	47	17C
0005434081500	12809	48	17F
0005434081541	12809	49	17E
0005434066385	12809	50	18A
0005434066380	12809	51	18B
0005434066321	12809	52	18D
0005432161129	12809	53	18E
0005434066365	12809	54	18F
0005433989683	12809	55	19A
0005432161131	12809	56	20A
0005432161130	12809	57	19F
0005432159815	12809	58	20C
0005434066316	12809	59	20F
0005432433628	12809	60	21A
0005434066400	12809	61	21C
0005433812879	12809	62	21D
0005434066494	12809	63	21E
0005434081489	12809	64	22A
0005434066360	12809	65	23B
0005434066424	12809	66	23C
0005433989691	12809	67	23E
0005434066312	12809	68	23F
0005434081666	30675	1	1C
0005434066841	30675	2	1A
0005434066839	30675	3	1D
0005434066852	30675	4	2A
0005434066808	30675	5	1F
0005434066806	30675	6	2C
0005434066843	30675	7	2F
0005434066869	30675	8	3A
0005432433608	30675	9	3D
0005434066848	30675	10	3C
0005434066844	30675	11	3F
0005434066826	30675	12	4A
0005432186833	30675	13	4B
0005434081654	30675	14	4D
0005434066827	30675	15	4C
0005434081671	30675	16	4E
0005434066809	30675	17	4F
0005434066854	30675	18	5B
0005434081664	30675	19	5A
0005434066849	30675	20	5C
0005434066828	30675	21	5D
0005434081669	30675	22	5E
0005434081665	30675	23	5F
0005432186831	30675	24	6B
0005434066847	30675	25	6C
0005434066816	30675	26	6E
0005433989721	30675	27	7A
0005434066857	30675	28	6F
0005434066864	30675	29	7B
0005434081670	30675	30	7C
0005434066810	30675	31	7D
0005434066811	30675	32	7F
0005434066868	30675	33	7E
0005434066862	30675	34	8A
0005434081661	30675	35	8B
0005434066820	30675	36	8C
0005434081653	30675	37	8E
0005434066815	30675	38	8D
0005434081656	30675	39	8F
0005434066867	30675	40	9A
0005434081667	30675	41	9B
0005433989723	30675	42	9C
0005434066873	30675	43	9E
0005434026686	30675	44	9D
0005434081673	30675	45	9F
0005434081663	30675	46	10C
0005434066865	30675	47	10B
0005432150115	30675	48	10D
0005434066874	30675	49	11A
0005434081672	30675	50	10E
0005434026684	30675	51	11C
0005432150112	30675	52	11B
0005434066871	30675	53	11F
0005434066846	30675	54	12A
0005434066872	30675	55	12B
0005432150111	30675	56	12C
0005434081668	30675	57	12E
0005434066850	30675	58	13A
0005434066823	30675	59	12F
0005434081657	30675	60	13C
0005434066861	30675	61	13B
0005434066866	30675	62	13D
0005434066822	30675	63	13E
0005432150116	30675	64	13F
0005434066824	30675	65	14A
0005432186832	30675	66	14B
0005434066825	30675	67	14D
0005434066819	30675	68	14C
0005434066818	30675	69	14E
0005434081662	30675	70	14F
0005434026685	30675	71	15C
0005434066840	30675	72	15E
0005434026681	30675	73	16A
0005434066829	30675	74	15F
0005434066863	30675	75	16B
0005434066842	30675	76	16C
0005434066821	30675	77	16D
0005434026682	30675	78	16E
0005433989720	30675	79	17A
0005434066836	30675	80	16F
0005434066832	30675	81	17B
0005434066858	30675	82	17C
0005434066804	30675	83	17D
0005434066807	30675	84	17E
0005434066855	30675	85	18A
0005434066813	30675	86	17F
0005433989724	30675	87	18B
0005434066845	30675	88	18C
0005434066875	30675	89	18E
0005434081660	30675	90	18D
0005432150110	30675	91	18F
0005434081659	30675	92	19A
0005434066837	30675	93	19B
0005434026683	30675	94	19C
0005434066833	30675	95	19E
0005434081655	30675	96	19F
0005432150117	30675	97	20B
0005434066856	30675	98	20A
0005434066870	30675	99	20C
0005434066859	30675	100	20D
0005434066805	30675	101	20E
0005434066838	30675	102	21A
0005434066817	30675	103	21C
0005434066814	30675	104	21B
0005433989722	30675	105	21D
0005433812861	30675	106	21E
0005434066830	30675	107	22A
0005434066812	30675	108	21F
0005434066853	30675	109	22B
0005434081658	30675	110	22C
0005434066860	30675	111	22E
0005434066835	30675	112	22D
0005432150113	30675	113	22F
0005434066851	30675	114	23B
0005432433597	30675	115	23A
0005434066831	30675	116	23D
0005434066834	30675	117	23C
0005432150114	30675	118	23F
0005435765649	5542	1	1C
0005435765647	5542	2	1B
0005434264724	5542	3	1G
0005435765618	5542	4	1H
0005435461793	5542	5	2B
0005435765659	5542	6	2F
0005435765620	5542	7	2C
0005435765638	5542	8	2G
0005435765637	5542	9	3B
0005432140366	5542	10	3C
0005435725547	5542	11	3G
0005435725551	5542	12	4A
0005435765612	5542	13	4B
0005435765645	5542	14	4F
0005435765639	5542	15	4C
0005434264733	5542	16	4G
0005435461865	5542	17	4H
0005432140368	5542	18	5B
0005435765624	5542	19	5F
0005433529243	5542	20	5G
0005435765643	5542	21	5H
0005435765615	5542	22	9H
0005434264715	5542	23	11D
0005435461770	5542	24	11B
0005435765644	5542	25	11G
0005435765635	5542	26	11F
0005435765632	5542	27	11E
0005435765628	5542	28	12A
0005435461794	5542	29	11H
0005435725549	5542	30	12D
0005435735095	5542	31	12F
0005435765657	5542	32	12H
0005435735093	5542	33	13A
0005435765633	5542	34	13D
0005435722031	5542	35	13E
0005435765667	5542	36	13H
0005432535748	5542	37	13G
0005435461821	5542	38	14A
0005435461809	5542	39	14D
0005435765663	5542	40	14F
0005435765646	5542	41	14E
0005435765621	5542	42	14G
0005435765668	5542	43	14H
0005435461811	5542	44	15A
0005435765651	5542	45	15D
0005435765642	5542	46	16D
0005435765660	5542	47	16B
0005435765669	5542	48	16H
0005434264679	5542	49	17B
0005435765656	5542	50	17A
0005435765617	5542	51	17F
0005435765609	5542	52	17G
0005435461800	5542	53	18B
0005435765622	5542	54	18A
0005435765670	5542	55	18F
0005435765672	5542	56	18E
0005435461810	5542	57	18G
0005435765655	5542	58	18H
0005433529242	5542	59	19D
0005434264694	5542	60	19E
0005433527231	5542	61	19F
0005434264693	5542	62	19H
0005435461790	5542	63	20B
0005435735091	5542	64	20E
0005435723026	5542	65	20F
0005432140369	5542	66	21B
0005435765634	5542	67	21A
0005433527233	5542	68	20H
0005435765631	5542	69	21E
0005435461791	5542	70	21F
0005435461863	5542	71	21H
0005435765653	5542	72	22B
0005434264723	5542	73	22D
0005435765650	5542	74	22G
0005432140372	5542	75	23A
0005432140367	5542	76	23B
0005434264753	5542	77	23G
0005434264678	5542	78	23H
0005435765648	5542	79	24F
0005435765623	5542	80	24G
0005434264768	5542	81	25D
0005434264767	5542	82	25F
0005435765666	5542	83	25E
0005435461799	5542	84	27A
0005435461771	5542	85	27B
0005435765662	5542	86	27E
0005435461787	5542	87	28A
0005435735094	5542	88	27H
0005435765652	5542	89	28D
0005435765654	5542	90	28E
0005435725548	5542	91	28F
0005435765610	5542	92	28H
0005435723025	5542	93	28G
0005435735090	5542	94	29B
0005435765658	5542	95	29F
0005432140370	5542	96	30A
0005433529244	5542	97	30D
0005435765671	5542	98	30B
0005432140373	5542	99	30F
0005434264686	5542	100	31B
0005435765641	5542	101	31A
0005435765611	5542	102	31D
0005435765661	5542	103	31F
0005433527232	5542	104	31H
0005432140371	5542	105	32B
0005435765629	5542	106	32H
0005435765630	5542	107	33A
0005434264713	5542	108	33B
0005434831069	5542	109	33E
0005434264720	5542	110	33F
0005435765627	5542	111	33H
0005435461798	5542	112	33G
0005435765614	5542	113	34E
0005435765626	5542	114	34G
0005435765636	5542	115	34H
0005435765664	5542	116	35A
0005435722033	5542	117	35B
0005435461781	5542	118	35F
0005435461888	5542	119	35E
0005435765665	5542	120	35G
0005435461788	5542	121	36A
0005435765625	5542	122	36F
0005432535747	5542	123	37A
0005435461782	5542	124	36H
0005435725550	5542	125	37E
0005435765619	5542	126	38A
0005435765616	5542	127	38B
0005435765640	5542	128	38F
0005435725552	5542	129	38H
0005435765613	5542	130	39E
0005435735092	5542	131	39D
0005435722032	5542	132	39F
0005435462080	13450	1	1A
0005434264912	13450	2	1B
0005434264908	13450	3	2A
0005435462103	13450	4	1H
0005435462081	13450	5	2B
0005435462066	13450	6	2F
0005435462092	13450	7	2C
0005435462067	13450	8	3A
0005435765142	13450	9	3F
0005435462073	13450	10	3H
0005435462101	13450	11	3G
0005435462083	13450	12	4A
0005434264895	13450	13	4B
0005434264906	13450	14	5B
0005434831106	13450	15	5F
0005434264889	13450	16	9G
0005435765148	13450	17	11D
0005434264911	13450	18	11G
0005435462072	13450	19	12A
0005434831107	13450	20	12F
0005435462084	13450	21	12E
0005434264909	13450	22	12G
0005435735056	13450	23	13B
0005434264905	13450	24	13E
0005434264893	13450	25	13H
0005435462069	13450	26	14E
0005432194473	13450	27	15A
0005435765145	13450	28	15D
0005434264900	13450	29	15G
0005434264903	13450	30	16B
0005435462075	13450	31	16D
0005435462096	13450	32	16E
0005434264898	13450	33	16H
0005435462071	13450	34	16G
0005435735057	13450	35	17F
0005435725528	13450	36	17G
0005435462100	13450	37	17H
0005435043276	13450	38	19A
0005435462097	13450	39	19F
0005434264901	13450	40	20A
0005435765146	13450	41	20D
0005434264892	13450	42	21B
0005435462077	13450	43	21A
0005435462094	13450	44	21G
0005432535789	13450	45	21F
0005435723012	13450	46	22B
0005434264894	13450	47	22E
0005432194470	13450	48	22G
0005434831109	13450	49	23A
0005434264902	13450	50	22H
0005435725520	13450	51	23D
0005434264891	13450	52	23E
0005435765143	13450	53	23G
0005435462091	13450	54	24E
0005434264899	13450	55	24D
0005435723009	13450	56	25D
0005435462086	13450	57	24H
0005432535790	13450	58	25F
0005435462074	13450	59	25E
0005435462078	13450	60	27F
0005435725511	13450	61	27E
0005432535788	13450	62	27G
0005435462082	13450	63	28A
0005434264896	13450	64	27H
0005432535787	13450	65	28D
0005435462079	13450	66	28B
0005435765108	13450	67	28E
0005432194471	13450	68	28H
0005435462095	13450	69	29A
0005434264913	13450	70	29E
0005433529210	13450	71	29F
0005435765117	13450	72	29H
0005434831108	13450	73	30E
0005434264904	13450	74	30D
0005435462093	13450	75	30G
0005435462099	13450	76	30H
0005435462098	13450	77	31B
0005435765116	13450	78	31A
0005435462070	13450	79	31D
0005435765126	13450	80	32A
0005435462102	13450	81	32F
0005435765115	13450	82	32E
0005434264890	13450	83	32G
0005434264888	13450	84	33A
0005434264887	13450	85	33E
0005435462076	13450	86	33G
0005435462089	13450	87	33F
0005434264910	13450	88	33H
0005435462087	13450	89	34D
0005435462088	13450	90	35A
0005434264897	13450	91	35F
0005435462085	13450	92	35E
0005435462090	13450	93	35G
0005432194472	13450	94	36B
0005435765111	13450	95	36E
0005435462068	13450	96	36G
0005432535786	13450	97	36H
0005435735065	13450	98	38E
0005434264907	13450	99	38G
0005434602865	18712	1	2A
0005434513553	18707	1	1A
0005434604840	18707	2	2A
0005434513552	18707	3	2B
0005434514940	18707	4	4A
0005434604839	18707	5	4B
0005434514941	18707	6	5A
0005434513551	18707	7	6A
0005434604838	18707	8	6B
0005434514921	19131	1	2B
0005432649347	4130	1	1C
0005432632673	4130	2	1D
0005432649344	4130	3	2A
0005432632674	4130	4	2C
0005432649342	4130	5	3C
0005432649340	4130	6	6D
0005432649350	4130	7	6E
0005432632675	4130	8	6F
0005432632678	4130	9	8A
0005432649345	4130	10	9C
0005432632680	4130	11	9D
0005432632672	4130	12	9F
0005432632681	4130	13	10C
0005432632671	4130	14	10F
0005432632682	4130	15	11C
0005432649349	4130	16	12D
0005432632683	4130	17	14E
0005432632676	4130	18	15C
0005432649343	4130	19	15F
0005432632670	4130	20	16A
0005432649346	4130	21	17D
0005432649341	4130	22	18C
0005432632679	4130	23	18F
0005432649351	4130	24	19D
0005432632677	4130	25	19E
0005432649339	4130	26	19F
0005432649348	4130	27	20C
0005433007895	1821	1	1C
0005433007900	1821	2	2C
0005433284775	1821	3	2D
0005433284816	1821	4	2F
0005433007912	1821	5	3D
0005433007829	1821	6	4A
0005433007849	1821	7	4C
0005433007839	1821	8	4E
0005433008035	1821	9	4F
0005433007832	1821	10	5C
0005433284856	1821	11	5E
0005433007887	1821	12	6A
0005433007836	1821	13	6C
0005433284774	1821	14	6D
0005433007936	1821	15	6E
0005433007886	1821	16	6F
0005433007989	1821	17	7E
0005433007889	1821	18	7F
0005433008036	1821	19	8C
0005432295856	1821	20	8E
0005433284817	1821	21	8F
0005433007976	1821	22	9A
0005433007991	1821	23	9E
0005433284865	1821	24	9F
0005433284859	1821	25	10C
0005433008071	1821	26	10D
0005433284808	1821	27	10E
0005433284829	1821	28	10F
0005433007914	1821	29	11C
0005433007882	1821	30	11D
0005433007892	1821	31	11F
0005433007935	1821	32	12C
0005433810510	1821	33	12E
0005433284792	1821	34	12F
0005433007881	1821	35	13C
0005433284878	1821	36	13F
0005433810511	1821	37	14C
0005433810513	1821	38	14D
0005433810514	1821	39	14F
0005433007859	1821	40	15A
0005433008037	1821	41	15C
0005433007901	1821	42	15D
0005433284788	1821	43	15E
0005433007861	1821	44	16A
0005433284877	1821	45	16D
0005433284807	1821	46	16E
0005433007828	1821	47	17C
0005433284785	1821	48	17D
0005433007990	1821	49	17F
0005433284948	1821	50	18A
0005432295855	1821	51	18C
0005433007870	1821	52	18D
0005433007977	1821	53	18F
0005433007869	1821	54	19D
0005433810512	1821	55	19E
0005433007988	1821	56	20A
0005433284855	1821	57	20C
0005433008072	1821	58	20F
0005433284984	22618	1	1A
0005433008176	22618	2	1C
0005433284997	22618	3	1D
0005433285001	22618	4	1F
0005433008163	22618	5	2C
0005433284983	22618	6	2D
0005433008171	22618	7	2F
0005433008175	22618	8	3A
0005433284977	22618	9	3C
0005433008161	22618	10	3D
0005433284996	22618	11	3F
0005433008154	22618	12	4D
0005433008184	22618	13	4E
0005433008180	22618	14	5A
0005433008192	22618	15	5C
0005433008167	22618	16	5D
0005433008182	22618	17	5E
0005433284985	22618	18	5F
0005433008160	22618	19	6A
0005433008187	22618	20	6E
0005433284994	22618	21	6F
0005433285002	22618	22	7A
0005433284978	22618	23	7C
0005433008178	22618	24	7D
0005433008166	22618	25	7F
0005433008177	22618	26	8A
0005433008189	22618	27	8C
0005433008148	22618	28	8D
0005433008153	22618	29	8E
0005433008162	22618	30	8F
0005433008170	22618	31	9A
0005433008185	22618	32	9C
0005433284979	22618	33	9D
0005433008158	22618	34	9E
0005433008169	22618	35	9F
0005433008173	22618	36	10A
0005433284982	22618	37	10C
0005433008149	22618	38	10E
0005433008157	22618	39	11A
0005433008155	22618	40	11C
0005433008151	22618	41	11D
0005433285005	22618	42	11E
0005433285004	22618	43	11F
0005433284987	22618	44	12A
0005433284995	22618	45	12C
0005433008193	22618	46	12D
0005433284989	22618	47	12E
0005433008168	22618	48	12F
0005433008147	22618	49	13A
0005433285006	22618	50	13C
0005433284980	22618	51	13D
0005433008186	22618	52	13E
0005433008152	22618	53	13F
0005433284975	22618	54	14A
0005433008159	22618	55	14D
0005433008156	22618	56	15A
0005433284999	22618	57	15C
0005433008190	22618	58	15D
0005433008174	22618	59	16A
0005433008179	22618	60	16D
0005433285003	22618	61	16E
0005433284993	22618	62	16F
0005433284976	22618	63	17A
0005433008150	22618	64	17C
0005433284991	22618	65	17D
0005433284992	22618	66	17E
0005433284986	22618	67	17F
0005433008191	22618	68	18A
0005433284998	22618	69	18C
0005433284981	22618	70	18D
0005433008183	22618	71	18E
0005433008188	22618	72	19A
0005433008172	22618	73	19C
0005433008165	22618	74	19D
0005433284988	22618	75	19E
0005433008164	22618	76	19F
0005433285000	22618	77	20A
0005433008181	22618	78	20C
0005433284990	22618	79	20D
0005433815336	5548	1	1D
0005433846190	5548	2	2A
0005435282080	5548	3	1F
0005433846179	5548	4	2D
0005435282081	5548	5	2C
0005433846195	5548	6	3A
0005433846166	5548	7	3D
0005433846185	5548	8	4A
0005435282093	5548	9	3F
0005433846143	5548	10	4C
0005433815338	5548	11	5A
0005433846162	5548	12	5D
0005433846170	5548	13	6B
0005433846183	5548	14	6C
0005433815339	5548	15	6F
0005433846193	5548	16	6D
0005433846181	5548	17	7A
0005433846172	5548	18	7C
0005433846163	5548	19	7B
0005433846189	5548	20	7E
0005433846160	5548	21	7D
0005433846157	5548	22	8A
0005432081447	5548	23	7F
0005433846152	5548	24	8D
0005433846178	5548	25	8C
0005433846196	5548	26	8F
0005433846151	5548	27	8E
0005433846180	5548	28	9B
0005432081446	5548	29	9A
0005433846161	5548	30	9D
0005433846168	5548	31	9C
0005433846142	5548	32	10B
0005433846198	5548	33	10A
0005435282052	5548	34	9F
0005433846173	5548	35	10C
0005432081449	5548	36	10D
0005433846164	5548	37	10E
0005433846188	5548	38	11C
0005433846197	5548	39	11E
0005434173450	5548	40	11D
0005435282058	5548	41	11F
0005435282197	5548	42	12C
0005435282050	5548	43	12E
0005433846187	5548	44	13A
0005435282196	5548	45	13C
0005433846177	5548	46	13D
0005433846146	5548	47	13F
0005433846192	5548	48	14C
0005433846191	5548	49	14B
0005432081451	5548	50	14D
0005435282064	5548	51	14F
0005433846169	5548	52	14E
0005433846182	5548	53	15B
0005433846174	5548	54	15A
0005433846167	5548	55	15D
0005432081452	5548	56	15C
0005433846147	5548	57	15F
0005433846148	5548	58	15E
0005434173456	5548	59	16D
0005433815337	5548	60	16C
0005433846145	5548	61	17A
0005433846186	5548	62	16F
0005433846154	5548	63	17B
0005433846150	5548	64	17D
0005433846175	5548	65	17C
0005433846149	5548	66	17F
0005433846199	5548	67	17E
0005433846155	5548	68	18B
0005433846141	5548	69	18A
0005433846194	5548	70	18D
0005433846144	5548	71	18C
0005435282057	5548	72	18F
0005435282124	5548	73	18E
0005433846159	5548	74	19A
0005433846200	5548	75	19B
0005433846156	5548	76	19D
0005433846184	5548	77	19C
0005433846158	5548	78	19E
0005433846165	5548	79	20A
0005435282115	5548	80	20D
0005434173453	5548	81	20C
0005434173452	5548	82	20E
0005432081448	5548	83	21A
0005433846153	5548	84	20F
0005432081450	5548	85	21C
0005433846171	5548	86	21D
0005433846176	5548	87	21F
0005433845675	13867	1	1F
0005435282261	13867	2	2F
0005433845760	13867	3	3C
0005435282273	13867	4	5F
0005432003673	13867	5	6B
0005435282272	13867	6	6F
0005435282263	13867	7	7A
0005435282282	13867	8	7E
0005435282267	13867	9	7D
0005435282275	13867	10	8E
0005435282271	13867	11	9A
0005435282280	13867	12	9D
0005435282283	13867	13	10D
0005435282274	13867	14	11B
0005434173484	13867	15	11C
0005435282278	13867	16	12B
0005433845834	13867	17	12D
0005435282276	13867	18	12C
0005433845833	13867	19	12F
0005435282284	13867	20	12E
0005433845826	13867	21	13C
0005433845768	13867	22	13B
0005435282270	13867	23	14C
0005434173483	13867	24	14D
0005433845825	13867	25	15A
0005432003672	13867	26	14F
0005433845686	13867	27	14E
0005433845835	13867	28	15B
0005435282268	13867	29	15C
0005435282279	13867	30	15E
0005435282269	13867	31	16A
0005435282262	13867	32	15F
0005434173481	13867	33	16C
0005435282265	13867	34	16E
0005433845895	13867	35	16D
0005433845821	13867	36	17A
0005435282277	13867	37	18B
0005433845896	13867	38	18A
0005435282266	13867	39	18D
0005434173482	13867	40	18C
0005435282281	13867	41	18E
0005433845709	13867	42	18F
0005433845897	13867	43	19C
0005433845755	13867	44	19D
0005432003671	13867	45	20B
0005433845855	13867	46	20C
0005433845759	13867	47	20E
0005435282264	13867	48	21C
0005433815303	13867	49	21B
0005434620392	7798	1	1B
0005434620399	7798	2	1D
0005432112493	7798	3	1C
0005434620405	7798	4	2A
0005434620410	7798	5	2B
0005434620398	7798	6	2C
0005435332180	7798	7	3A
0005435332146	7798	8	3B
0005434620390	7798	9	3C
0005435332179	7798	10	3D
0005434620394	7798	11	4A
0005435332166	7798	12	4B
0005435332156	7798	13	5B
0005434620401	7798	14	6A
0005435332167	7798	15	6B
0005432112495	7798	16	7A
0005434620391	7798	17	7B
0005434620409	7798	18	7D
0005434620400	7798	19	18A
0005434620408	7798	20	18C
0005434620393	7798	21	18D
0005435332153	7798	22	19A
0005435332157	7798	23	19B
0005435332155	7798	24	19C
0005434620402	7798	25	19D
0005432112494	7798	26	20C
0005434620407	7798	27	20D
0005434620396	7798	28	21B
0005434620397	7798	29	21C
0005435332158	7798	30	21D
0005434620404	7798	31	22A
0005434620395	7798	32	22B
0005434620406	7798	33	22C
0005434620403	7798	34	23B
0005434620234	32977	1	1D
0005434620280	32977	2	2C
0005434620252	32977	3	3B
0005434620281	32977	4	3C
0005435332239	32977	5	3D
0005434620253	32977	6	4B
0005434620268	32977	7	4C
0005434620321	32977	8	5B
0005434620227	32977	9	5C
0005434620273	32977	10	6A
0005434620269	32977	11	6C
0005435332234	32977	12	7C
0005435332237	32977	13	7D
0005434620267	32977	14	18A
0005434620266	32977	15	18B
0005434620251	32977	16	18C
0005435332241	32977	17	19B
0005435332235	32977	18	19C
0005435332231	32977	19	20A
0005435332232	32977	20	21B
0005435332236	32977	21	21C
0005435332240	32977	22	21D
0005435332233	32977	23	22B
0005434620320	32977	24	22C
0005434620228	32977	25	22D
0005435332238	32977	26	23B
0005432190595	4290	1	1A
0005434993930	4290	2	1C
0005435785044	4290	3	2A
0005434993927	4290	4	2C
0005435785015	4290	5	2F
0005434993928	4290	6	3F
0005435785032	4290	7	4A
0005435785028	4290	8	4D
0005435918571	4290	9	4E
0005435785017	4290	10	5A
0005435785011	4290	11	5C
0005432190591	4290	12	5D
0005435785018	4290	13	5F
0005435785016	4290	14	6A
0005432190592	4290	15	6D
0005435785043	4290	16	6E
0005435785045	4290	17	6F
0005435787332	4290	18	7A
0005435785039	4290	19	7C
0005435785035	4290	20	7D
0005435785038	4290	21	7F
0005435785030	4290	22	8A
0005435785034	4290	23	8C
0005435785013	4290	24	8D
0005435785020	4290	25	8E
0005435937305	4290	26	8F
0005435785042	4290	27	9C
0005435785029	4290	28	9D
0005434993933	4290	29	9F
0005432190594	4290	30	10A
0005434993932	4290	31	10D
0005435918579	4290	32	11A
0005435785037	4290	33	11C
0005435918586	4290	34	11F
0005435785022	4290	35	12A
0005434993925	4290	36	12D
0005434993934	4290	37	12E
0005435785041	4290	38	12F
0005434993929	4290	39	13C
0005435785026	4290	40	13E
0005435787333	4290	41	13F
0005435785019	4290	42	14A
0005435785021	4290	43	14C
0005432190593	4290	44	14D
0005435785036	4290	45	15A
0005435785023	4290	46	15C
0005435785040	4290	47	15D
0005435918583	4290	48	16A
0005435918593	4290	49	16C
0005435785025	4290	50	16D
0005435785031	4290	51	16E
0005435918572	4290	52	17C
0005435937306	4290	53	17E
0005434993926	4290	54	18A
0005435785014	4290	55	18C
0005435785012	4290	56	19A
0005435785027	4290	57	19D
0005435785024	4290	58	19E
0005435918582	4290	59	19F
0005435785033	4290	60	20C
0005434993931	4290	61	20D
0005435918585	4290	62	20F
0005434993861	27296	1	3F
0005435784734	27296	2	4E
0005435918609	27296	3	4F
0005435918607	27296	4	7A
0005435784782	27296	5	7C
0005434993886	27296	6	7E
0005435784740	27296	7	8A
0005434993878	27296	8	8C
0005434993877	27296	9	9C
0005432195671	27296	10	11D
0005434993879	27296	11	12F
0005435918610	27296	12	13D
0005435784743	27296	13	14D
0005435918611	27296	14	14E
0005435784728	27296	15	15D
0005432195672	27296	16	16C
0005434993885	27296	17	16D
0005435784811	27296	18	16F
0005435784733	27296	19	17F
0005435918608	27296	20	18F
0005435784727	27296	21	19F
0005434993884	27296	22	20C
0005432146179	19859	1	4D
0005432146178	19859	2	20D
0005432567078	4710	1	1A
0005432567051	4710	2	1C
0005432567058	4710	3	1F
0005432459336	4710	4	1G
0005432459332	4710	5	2A
0005432567081	4710	6	1H
0005432459339	4710	7	2B
0005432571285	4710	8	2G
0005432567027	4710	9	3B
0005432459381	4710	10	3C
0005434081679	4710	11	3G
0005432567031	4710	12	3F
0005432567079	4710	13	4A
0005433452719	4710	14	4F
0005432459343	4710	15	4C
0005432459340	4710	16	5A
0005432567062	4710	17	4H
0005432567064	4710	18	5B
0005434081691	4710	19	5F
0005432567035	4710	20	5C
0005432459351	4710	21	5G
0005432567033	4710	22	9A
0005432567036	4710	23	5H
0005432170325	4710	24	9B
0005432567056	4710	25	9G
0005432170326	4710	26	9H
0005432459352	4710	27	11B
0005432567059	4710	28	11A
0005432459341	4710	29	11H
0005433726082	4710	30	12A
0005432567040	4710	31	12E
0005432459364	4710	32	12G
0005432459374	4710	33	12F
0005432459330	4710	34	12H
0005432567071	4710	35	13B
0005432459360	4710	36	13A
0005432567034	4710	37	13D
0005434081689	4710	38	13E
0005434081680	4710	39	14B
0005432459346	4710	40	14A
0005432571284	4710	41	14D
0005432567063	4710	42	14G
0005434081687	4710	43	15B
0005433726083	4710	44	15A
0005432567046	4710	45	15E
0005432459334	4710	46	15F
0005432567052	4710	47	16A
0005432567080	4710	48	16E
0005432459342	4710	49	16D
0005432459356	4710	50	16H
0005432567055	4710	51	16G
0005432567074	4710	52	17A
0005432459338	4710	53	17D
0005432459376	4710	54	17B
0005433451601	4710	55	17E
0005434081678	4710	56	17G
0005432567042	4710	57	18B
0005432459348	4710	58	18A
0005432459355	4710	59	18D
0005432459379	4710	60	18E
0005432567076	4710	61	18G
0005432567041	4710	62	18H
0005432459382	4710	63	19B
0005432567026	4710	64	19D
0005434081693	4710	65	19F
0005432170321	4710	66	19H
0005432567039	4710	67	19G
0005432567049	4710	68	20A
0005432567065	4710	69	20D
0005433452720	4710	70	20B
0005432459362	4710	71	20E
0005434081697	4710	72	20F
0005432459370	4710	73	20H
0005434081674	4710	74	20G
0005432567060	4710	75	21A
0005432459383	4710	76	21D
0005432459350	4710	77	21B
0005434081688	4710	78	21E
0005432459380	4710	79	21G
0005432459361	4710	80	21H
0005432567084	4710	81	22B
0005432567053	4710	82	22A
0005432459363	4710	83	22D
0005432459345	4710	84	22G
0005432567086	4710	85	23A
0005432567050	4710	86	22H
0005432567045	4710	87	23B
0005432459359	4710	88	23D
0005432567083	4710	89	23F
0005432459349	4710	90	23G
0005432186835	4710	91	23H
0005434081677	4710	92	24B
0005434081681	4710	93	24A
0005432459335	4710	94	24D
0005432567054	4710	95	24E
0005432567077	4710	96	24G
0005434081686	4710	97	25D
0005432459367	4710	98	24H
0005432170327	4710	99	25E
0005434081682	4710	100	25F
0005432567032	4710	101	27A
0005434081676	4710	102	27F
0005433451600	4710	103	27G
0005432567068	4710	104	28E
0005432567070	4710	105	28G
0005432170322	4710	106	28H
0005432459337	4710	107	29B
0005432459347	4710	108	29G
0005432459344	4710	109	30A
0005432459354	4710	110	30E
0005432186836	4710	111	30B
0005432567075	4710	112	30G
0005432459372	4710	113	30F
0005432567087	4710	114	31A
0005432459331	4710	115	30H
0005432459375	4710	116	31D
0005432170323	4710	117	31F
0005432459366	4710	118	31E
0005434081695	4710	119	31G
0005432186834	4710	120	32A
0005432567067	4710	121	31H
0005434081675	4710	122	32B
0005432567057	4710	123	32D
0005432567037	4710	124	32F
0005432567047	4710	125	32E
0005432567038	4710	126	33B
0005432459365	4710	127	32H
0005432571287	4710	128	33D
0005434081692	4710	129	33E
0005432459358	4710	130	33F
0005432567028	4710	131	33H
0005432567043	4710	132	33G
0005432459333	4710	133	34A
0005432567082	4710	134	34D
0005432567061	4710	135	34B
0005432567073	4710	136	34G
0005434081683	4710	137	34F
0005434081690	4710	138	35A
0005432170324	4710	139	35E
0005434081694	4710	140	35G
0005434081684	4710	141	35F
0005432459369	4710	142	36A
0005432567069	4710	143	35H
0005432459357	4710	144	36B
0005432459377	4710	145	36D
0005432571286	4710	146	36F
0005434081696	4710	147	36E
0005432567029	4710	148	36G
0005432567044	4710	149	37A
0005432459371	4710	150	36H
0005432567085	4710	151	37D
0005432459378	4710	152	37B
0005432459368	4710	153	37F
0005432459373	4710	154	37H
0005434081685	4710	155	38A
0005432567048	4710	156	38E
0005432459353	4710	157	38D
0005432567030	4710	158	38H
0005432567072	4710	159	39D
0005432567066	4710	160	39F
0005432459223	30524	1	2A
0005434081529	30524	2	2G
0005433454849	30524	3	2H
0005432459005	30524	4	3B
0005432459084	30524	5	3C
0005432566603	30524	6	3G
0005432566604	30524	7	4C
0005432566774	30524	8	4F
0005434081491	30524	9	9H
0005432566551	30524	10	11D
0005432459002	30524	11	11H
0005432459018	30524	12	12E
0005434081490	30524	13	13A
0005432566564	30524	14	13F
0005433454850	30524	15	14A
0005432566885	30524	16	14B
0005432566663	30524	17	14G
0005434081495	30524	18	15A
0005432566937	30524	19	15D
0005432566545	30524	20	16A
0005432459000	30524	21	16B
0005432459003	30524	22	16H
0005432566536	30524	23	17E
0005432566756	30524	24	17H
0005434081545	30524	25	18B
0005432566763	30524	26	18D
0005432161131	30524	27	18H
0005432566884	30524	28	19D
0005432566571	30524	29	19E
0005432566591	30524	30	19H
0005432459085	30524	31	20D
0005432213571	30524	32	20B
0005432459224	30524	33	20G
0005432566565	30524	34	21A
0005432566631	30524	35	21E
0005432161130	30524	36	21G
0005432566533	30524	37	22G
0005432566635	30524	38	22F
0005434081482	30524	39	23A
0005432566613	30524	40	23D
0005432459001	30524	41	24A
0005435840358	30524	42	23H
0005434081489	30524	43	24E
0005432459130	30524	44	24D
0005432566808	30524	45	25F
0005432161129	30524	46	25E
0005432459140	30524	47	28B
0005434081541	30524	48	28F
0005432566532	30524	49	30D
0005432571258	30524	50	30F
0005432566582	30524	51	30G
0005432213569	30524	52	31A
0005432566820	30524	53	30H
0005434081500	30524	54	31E
0005432566592	30524	55	31G
0005432566566	30524	56	32E
0005432566622	30524	57	32D
0005432459129	30524	58	32F
0005432459088	30524	59	32H
0005432566648	30524	60	33E
0005432566539	30524	61	33D
0005434081539	30524	62	33H
0005432459004	30524	63	34A
0005434081501	30524	64	34E
0005434081517	30524	65	34G
0005432566609	30524	66	35F
0005432458987	30524	67	35E
0005432566611	30524	68	35G
0005432213570	30524	69	35H
0005432213572	30524	70	36D
0005432566538	30524	71	36H
0005432459098	30524	72	37E
0005432458981	30524	73	37D
0005432566583	30524	74	37F
0005432566719	30524	75	38A
0005432566610	30524	76	38H
0005432566647	30524	77	39E
0005435722031	13581	1	3A
0005435722033	13581	2	3B
0005435722032	13581	3	6A
0005435722015	21113	1	2B
0005432295856	22772	1	19A
0005432295855	22772	2	20D
0005433342284	11095	1	1A
0005433342224	11095	2	1C
0005433342214	11095	3	1F
0005433342194	11095	4	2A
0005433342211	11095	5	2D
0005433342259	11095	6	2C
0005433342219	11095	7	3A
0005435097112	11095	8	2F
0005433342196	11095	9	3C
0005435097115	11095	10	3D
0005433342222	11095	11	3F
0005433342199	11095	12	4A
0005433342212	11095	13	4B
0005433342202	11095	14	4C
0005433342192	11095	15	4E
0005433342255	11095	16	4D
0005433342213	11095	17	4F
0005433342207	11095	18	5A
0005433342193	11095	19	5B
0005433342293	11095	20	5D
0005433342226	11095	21	5C
0005433342253	11095	22	5E
0005433342270	11095	23	5F
0005435508174	11095	24	6B
0005433342263	11095	25	6A
0005433342233	11095	26	6C
0005433342217	11095	27	6D
0005433342272	11095	28	6E
0005433342279	11095	29	6F
0005433342243	11095	30	7B
0005433342282	11095	31	7A
0005433342265	11095	32	7D
0005433342200	11095	33	7E
0005433342209	11095	34	7F
0005433342247	11095	35	8B
0005433342291	11095	36	8A
0005433342267	11095	37	8D
0005433342244	11095	38	8C
0005433342269	11095	39	8F
0005433342290	11095	40	8E
0005433342286	11095	41	9B
0005435508173	11095	42	9D
0005433342241	11095	43	9C
0005433342216	11095	44	9E
0005433342289	11095	45	9F
0005433342228	11095	46	10B
0005433342204	11095	47	10C
0005433342285	11095	48	10E
0005435508167	11095	49	11A
0005433342225	11095	50	11C
0005433342203	11095	51	11B
0005435097117	11095	52	11D
0005433342250	11095	53	11E
0005433342271	11095	54	11F
0005433342264	11095	55	12C
0005435097110	11095	56	12B
0005433342229	11095	57	12E
0005435508165	11095	58	12D
0005433342287	11095	59	12F
0005433342205	11095	60	13B
0005433342292	11095	61	13A
0005433342278	11095	62	13D
0005433342234	11095	63	13C
0005433342268	11095	64	13E
0005435097116	11095	65	13F
0005433342245	11095	66	14B
0005433342230	11095	67	14A
0005435097118	11095	68	14C
0005433342277	11095	69	14D
0005433342237	11095	70	14F
0005433342257	11095	71	15B
0005433342266	11095	72	15A
0005433342280	11095	73	15C
0005433342218	11095	74	15D
0005433342239	11095	75	15F
0005433342246	11095	76	16A
0005433342197	11095	77	16D
0005433342206	11095	78	16F
0005435097114	11095	79	16E
0005433342221	11095	80	17A
0005433342201	11095	81	17B
0005433342283	11095	82	17C
0005433342275	11095	83	17E
0005433342223	11095	84	17D
0005433342258	11095	85	18A
0005433342261	11095	86	17F
0005433342274	11095	87	18B
0005433342249	11095	88	18C
0005433342235	11095	89	18E
0005433342276	11095	90	18D
0005433342238	11095	91	18F
0005433342251	11095	92	19A
0005433342281	11095	93	19B
0005433342208	11095	94	19C
0005433342240	11095	95	19E
0005433342273	11095	96	19F
0005433342210	11095	97	20A
0005433342262	11095	98	20C
0005433342256	11095	99	20E
0005433342232	11095	100	20F
0005433342248	11095	101	21B
0005433342260	11095	102	21C
0005433342288	11095	103	21D
0005433342231	11095	104	21F
0005433342198	11095	105	21E
0005433342227	11095	106	22B
0005433342236	11095	107	22A
0005435097113	11095	108	22C
0005435508171	11095	109	22D
0005433342242	11095	110	22E
0005435508170	11095	111	23A
0005433342195	11095	112	22F
0005433342220	11095	113	23B
0005433342215	11095	114	23C
0005435097111	11095	115	23E
0005433342254	11095	116	23D
0005433342252	11095	117	23F
0005433341473	17084	1	2A
0005433341452	17084	2	2D
0005433341684	17084	3	4B
0005435380255	17084	4	4D
0005433341942	17084	5	4F
0005435545651	17084	6	5C
0005433341648	17084	7	5B
0005433341423	17084	8	5D
0005435380252	17084	9	5E
0005432293185	17084	10	6A
0005433341411	17084	11	7A
0005433341404	17084	12	7B
0005435380256	17084	13	7C
0005435380259	17084	14	8C
0005433341453	17084	15	9A
0005433341941	17084	16	9F
0005433341421	17084	17	10D
0005433341441	17084	18	11B
0005433341764	17084	19	11D
0005433341434	17084	20	12B
0005433341575	17084	21	12D
0005433341440	17084	22	12C
0005433341422	17084	23	12E
0005433341637	17084	24	13B
0005435380254	17084	25	13C
0005435380258	17084	26	13F
0005433341782	17084	27	14C
0005433341395	17084	28	14E
0005433341443	17084	29	15A
0005433341653	17084	30	15F
0005435545653	17084	31	16A
0005433341533	17084	32	16E
0005433341777	17084	33	16F
0005435545652	17084	34	17D
0005433341576	17084	35	18E
0005433341636	17084	36	19B
0005433341407	17084	37	19D
0005433341430	17084	38	20B
0005435380257	17084	39	20A
0005435380253	17084	40	20D
0005435545650	17084	41	21C
0005433341596	17084	42	21B
0005433341696	17084	43	21F
0005435545654	17084	44	22B
0005435097055	17084	45	22C
0005433341433	17084	46	22D
0005433341697	17084	47	23D
0005433507010	9087	1	1A
0005433507023	9087	2	2D
0005433507016	9087	3	3F
0005433507021	9087	4	4A
0005433507009	9087	5	4E
0005433507019	9087	6	5D
0005433507011	9087	7	6A
0005434158944	9087	8	6D
0005433481093	9087	9	6E
0005433507017	9087	10	7D
0005433507003	9087	11	7E
0005434158949	9087	12	7F
0005432919527	9087	13	8E
0005433481095	9087	14	8F
0005433507006	9087	15	9A
0005433507007	9087	16	9D
0005433507008	9087	17	9F
0005433507020	9087	18	10A
0005433507012	9087	19	10F
0005433481098	9087	20	11D
0005432919562	9087	21	11E
0005433507005	9087	22	13A
0005433481096	9087	23	13E
0005433507015	9087	24	13D
0005433481092	9087	25	14D
0005433507018	9087	26	14E
0005433507014	9087	27	15D
0005433507022	9087	28	15E
0005433507013	9087	29	15F
0005432919535	9087	30	16E
0005433507004	9087	31	17A
0005432919528	9087	32	17D
0005433481091	9087	33	17F
0005433481097	9087	34	18F
0005433507002	9087	35	19C
0005432919529	9087	36	19F
0005433481094	9087	37	20A
0005432919692	20432	1	1F
0005432919683	20432	2	2C
0005434158959	20432	3	4C
0005432919686	20432	4	4E
0005432919681	20432	5	5A
0005433506890	20432	6	5D
0005433481058	20432	7	5F
0005433481071	20432	8	6A
0005433506930	20432	9	6E
0005432919679	20432	10	7C
0005432919687	20432	11	8A
0005434158960	20432	12	8C
0005432919693	20432	13	8D
0005433506864	20432	14	8E
0005432919677	20432	15	8F
0005433481033	20432	16	9A
0005433506880	20432	17	9C
0005432919675	20432	18	9F
0005432919676	20432	19	10C
0005432919690	20432	20	10D
0005432919678	20432	21	10F
0005432919685	20432	22	11C
0005432919689	20432	23	12A
0005432919688	20432	24	12D
0005433481055	20432	25	12F
0005433506893	20432	26	13A
0005433481059	20432	27	13F
0005433506903	20432	28	14A
0005432919684	20432	29	14D
0005432919691	20432	30	14E
0005432919680	20432	31	15D
0005433506876	20432	32	16A
0005433506902	20432	33	17C
0005433506881	20432	34	18D
0005432919682	20432	35	18E
0005433506861	20432	36	18F
0005433506942	20432	37	19C
0005433506859	20432	38	19E
0005433481034	20432	39	19F
0005433506887	20432	40	20C
0005432919694	20432	41	20D
0005432394063	10177	1	1B
0005432396203	10177	2	2B
0005432396201	10177	3	3A
0005432394061	10177	4	3B
0005432396202	10177	5	4A
0005432394062	10177	6	5A
0005432394064	10177	7	6B
0005432400060	18390	1	2A
0005432396177	18390	2	3B
0005432396178	18390	3	4B
0005432400062	18390	4	5B
0005435179389	18390	5	6A
0005435625863	11039	1	2D
0005434411740	11039	2	3A
0005435625859	11039	3	4C
0005435125696	11039	4	4F
0005434928274	11039	5	5C
0005434411739	11039	6	6F
0005435125697	11039	7	8A
0005435625864	11039	8	8C
0005434928273	11039	9	8F
0005434411738	11039	10	9E
0005434928275	11039	11	9F
0005435125729	11039	12	11E
0005435625865	11039	13	12C
0005435554111	11039	14	15F
0005434411737	11039	15	17E
0005435125695	11039	16	19D
0005435125698	11039	17	19F
0005434928272	11039	18	20F
0005435125983	14772	1	1A
0005435125987	14772	2	1C
0005435554140	14772	3	1D
0005435626018	14772	4	2A
0005434928251	14772	5	2C
0005435626015	14772	6	2D
0005435126016	14772	7	2F
0005435126006	14772	8	3A
0005435554143	14772	9	3D
0005435126001	14772	10	3F
0005435125986	14772	11	4A
0005435554138	14772	12	4D
0005435125980	14772	13	4E
0005435125985	14772	14	5A
0005435126013	14772	15	5D
0005435126015	14772	16	5F
0005435126005	14772	17	6A
0005435626016	14772	18	6C
0005435125996	14772	19	6D
0005435126014	14772	20	6F
0005435126021	14772	21	7A
0005435626020	14772	22	7C
0005435626003	14772	23	7D
0005435556668	14772	24	7E
0005435126012	14772	25	8A
0005435626001	14772	26	8C
0005435126018	14772	27	8E
0005434928250	14772	28	9A
0005435626008	14772	29	9C
0005435126000	14772	30	9D
0005435626010	14772	31	9E
0005435126007	14772	32	9F
0005435125998	14772	33	10A
0005435626021	14772	34	10C
0005435126002	14772	35	10D
0005435126019	14772	36	10E
0005435554141	14772	37	10F
0005435125989	14772	38	11A
0005435126004	14772	39	11D
0005435125984	14772	40	11E
0005435626005	14772	41	11F
0005435125997	14772	42	12D
0005435125982	14772	43	12F
0005435554142	14772	44	13C
0005435626019	14772	45	13E
0005435626006	14772	46	13F
0005435125981	14772	47	14A
0005435626012	14772	48	14C
0005435126008	14772	49	14D
0005435126003	14772	50	14E
0005435125993	14772	51	14F
0005435126009	14772	52	15A
0005435125991	14772	53	15C
0005435626007	14772	54	15E
0005435125994	14772	55	15F
0005435554139	14772	56	16C
0005435626000	14772	57	16D
0005435125999	14772	58	16E
0005435626017	14772	59	16F
0005435126010	14772	60	17A
0005435626004	14772	61	17C
0005435125992	14772	62	17D
0005434411702	14772	63	17E
0005435126020	14772	64	17F
0005435125995	14772	65	18A
0005435626009	14772	66	18D
0005435626011	14772	67	18E
0005435126011	14772	68	18F
0005435626014	14772	69	19A
0005435126017	14772	70	19C
0005435626022	14772	71	19D
0005435626013	14772	72	19E
0005435125990	14772	73	20A
0005434928253	14772	74	20D
0005435626002	14772	75	20E
0005435125988	14772	76	20F
0005435715302	7124	1	1D
0005435715309	7124	2	2A
0005435443148	7124	3	3A
0005435715310	7124	4	3D
0005435715307	7124	5	3F
0005432400094	7124	6	4D
0005435443175	7124	7	4E
0005435443147	7124	8	4F
0005432400092	7124	9	5A
0005435443187	7124	10	6D
0005435221036	7124	11	6F
0005435443159	7124	12	7A
0005435715303	7124	13	7E
0005432400093	7124	14	8A
0005435443160	7124	15	8E
0005435715312	7124	16	9E
0005435715305	7124	17	9F
0005435443181	7124	18	10A
0005435715308	7124	19	10C
0005435715311	7124	20	11E
0005435715313	7124	21	11F
0005432400091	7124	22	12A
0005435715316	7124	23	12C
0005435715315	7124	24	12E
0005432398162	7124	25	13C
0005435715301	7124	26	14A
0005435715304	7124	27	14D
0005435178469	7124	28	15A
0005435715314	7124	29	15C
0005432398164	7124	30	15D
0005435715306	7124	31	16A
0005432398163	7124	32	16F
0005435443158	7124	33	17C
0005432400095	7124	34	18C
0005435715300	7124	35	18E
0005435443180	7124	36	20E
0005435217692	27105	1	1D
0005435443229	27105	2	1F
0005435216562	27105	3	2A
0005435218106	27105	4	2D
0005435217685	27105	5	2F
0005435216564	27105	6	3D
0005435715169	27105	7	4C
0005435178983	27105	8	5D
0005435217694	27105	9	5E
0005435715207	27105	10	5F
0005435715177	27105	11	6D
0005435715204	27105	12	6E
0005435443222	27105	13	7C
0005435217686	27105	14	7E
0005435443221	27105	15	8A
0005435216566	27105	16	8C
0005435443228	27105	17	8E
0005435443227	27105	18	8F
0005435216567	27105	19	9C
0005435178479	27105	20	9E
0005435178478	27105	21	10D
0005435217693	27105	22	11C
0005435216561	27105	23	11E
0005435217689	27105	24	11F
0005435715193	27105	25	12A
0005435443226	27105	26	12D
0005435443223	27105	27	12E
0005435715170	27105	28	12F
0005435216568	27105	29	13A
0005435218108	27105	30	13C
0005435218107	27105	31	14C
0005435216563	27105	32	14D
0005435715208	27105	33	14E
0005435217688	27105	34	14F
0005435217687	27105	35	15D
0005435443225	27105	36	15F
0005435218105	27105	37	16C
0005435216565	27105	38	16E
0005435217691	27105	39	18A
0005435216569	27105	40	18D
0005435715174	27105	41	18E
0005435443230	27105	42	19A
0005435178984	27105	43	19C
0005435217690	27105	44	19E
0005435443224	27105	45	20A
0005433060373	2747	1	1A
0005434084885	2747	2	1B
0005434084886	2747	3	2A
0005433060374	2747	4	2B
0005433060366	2747	5	3A
0005433060372	2747	6	3B
0005433060367	2747	7	4A
0005434084888	2747	8	5A
0005433060370	2747	9	5B
0005434084887	2747	10	6A
0005434084858	28505	1	1A
0005434084859	28505	2	1B
0005433060387	28505	3	2A
0005433060389	28505	4	3A
0005433060388	28505	5	5B
0005434084850	28505	6	5A
0005434084849	28505	7	6B
0005433788174	11171	1	1C
0005433788161	11171	2	1D
0005433788164	11171	3	2A
0005433788168	11171	4	2C
0005433788162	11171	5	2D
0005433788163	11171	6	3A
0005433788171	11171	7	3B
0005433788173	11171	8	3C
0005433788166	11171	9	6B
0005433788167	11171	10	6C
0005433788177	11171	11	7C
0005433788170	11171	12	19A
0005433788165	11171	13	19B
0005433788172	11171	14	20D
0005433788176	11171	15	22B
0005433788175	11171	16	22C
0005433788169	11171	17	22D
0005435548441	20678	1	1B
0005435548448	20678	2	2A
0005435548447	20678	3	2D
0005435548446	20678	4	3B
0005435548449	20678	5	4D
0005435548444	20678	6	5A
0005435548442	20678	7	19A
0005435548440	20678	8	19C
0005435548443	20678	9	19D
0005435548445	20678	10	21D
0005435540747	11386	1	1A
0005435540638	11386	2	1F
0005435540721	11386	3	2A
0005435540636	11386	4	2D
0005435540693	11386	5	3A
0005435540662	11386	6	4D
0005435517600	11386	7	4E
0005435540722	11386	8	4F
0005435517593	11386	9	5C
0005435517592	11386	10	5E
0005435540723	11386	11	6A
0005435517599	11386	12	6C
0005435517613	11386	13	6D
0005435540645	11386	14	8C
0005435540644	11386	15	8D
0005435517639	11386	16	8F
0005435517638	11386	17	10F
0005435517614	11386	18	11E
0005435540669	11386	19	13D
0005435540681	11386	20	14A
0005435540680	11386	21	14E
0005435517615	11386	22	16F
0005435517668	11386	23	17C
0005435517612	11386	24	17E
0005435540641	11386	25	18A
0005435540637	11386	26	18C
0005435517591	11386	27	18E
0005435517601	11386	28	20D
0005432294463	22229	1	1A
0005435529039	22229	2	1F
0005435529045	22229	3	2C
0005435529046	22229	4	2D
0005435540789	22229	5	2F
0005435540781	22229	6	3C
0005435540790	22229	7	3D
0005435529054	22229	8	4C
0005435540780	22229	9	4F
0005435529038	22229	10	5C
0005435540797	22229	11	6A
0005435540782	22229	12	6C
0005435529035	22229	13	6D
0005435529044	22229	14	7A
0005435529037	22229	15	7C
0005435540788	22229	16	8A
0005435540794	22229	17	8D
0005432294462	22229	18	8F
0005435529052	22229	19	9A
0005435540791	22229	20	9D
0005435529050	22229	21	9E
0005435540784	22229	22	10A
0005435529051	22229	23	10D
0005435529041	22229	24	10E
0005435540792	22229	25	10F
0005435540783	22229	26	11C
0005435540778	22229	27	11D
0005435540798	22229	28	12A
0005435529040	22229	29	12E
0005435529036	22229	30	13A
0005435540779	22229	31	13E
0005435529042	22229	32	14A
0005435529048	22229	33	14E
0005435529043	22229	34	14F
0005432294464	22229	35	15A
0005435540799	22229	36	15D
0005435540785	22229	37	16D
0005435529053	22229	38	17D
0005435540796	22229	39	18C
0005435540787	22229	40	18F
0005435529047	22229	41	19A
0005435540793	22229	42	19E
0005435529034	22229	43	20A
0005435529049	22229	44	20D
0005435540786	22229	45	20E
0005435540795	22229	46	20F
0005433250953	2277	1	1A
0005434906850	2277	2	1C
0005434906841	2277	3	1D
0005433251031	2277	4	2A
0005434906821	2277	5	2C
0005434906856	2277	6	3A
0005434906828	2277	7	3D
0005434906852	2277	8	3F
0005433251012	2277	9	4A
0005434906837	2277	10	4C
0005434906818	2277	11	4D
0005434906848	2277	12	4E
0005433250941	2277	13	4F
0005433251019	2277	14	5A
0005434906849	2277	15	5C
0005434906822	2277	16	5D
0005433250936	2277	17	5E
0005433251096	2277	18	5F
0005434906842	2277	19	6C
0005434906815	2277	20	6D
0005434906851	2277	21	6E
0005434906835	2277	22	6F
0005434906824	2277	23	7A
0005434906838	2277	24	7C
0005433250954	2277	25	7D
0005434906840	2277	26	8A
0005433250958	2277	27	8D
0005434906827	2277	28	8E
0005434906825	2277	29	9A
0005434906839	2277	30	9C
0005434906819	2277	31	9E
0005434906845	2277	32	10A
0005434906833	2277	33	10C
0005434906858	2277	34	10D
0005433251066	2277	35	10E
0005434906830	2277	36	10F
0005434906826	2277	37	11A
0005433250973	2277	38	11D
0005433251058	2277	39	11E
0005434906816	2277	40	11F
0005433250983	2277	41	12C
0005434906832	2277	42	12D
0005434906823	2277	43	12F
0005433251033	2277	44	13A
0005434906814	2277	45	13E
0005434906843	2277	46	13F
0005434906847	2277	47	14A
0005433251065	2277	48	14D
0005433251095	2277	49	14E
0005433251013	2277	50	14F
0005434906846	2277	51	15C
0005434906855	2277	52	15D
0005434906817	2277	53	15E
0005434906857	2277	54	15F
0005434906853	2277	55	16D
0005433251011	2277	56	16F
0005434906836	2277	57	17A
0005434906844	2277	58	17C
0005433250967	2277	59	17E
0005433250952	2277	60	18A
0005434906854	2277	61	18C
0005433250974	2277	62	18E
0005434906829	2277	63	18F
0005433251098	2277	64	19C
0005434906831	2277	65	19D
0005434906820	2277	66	19E
0005434906834	2277	67	19F
0005433250962	2277	68	20C
0005433250979	2277	69	20D
0005434906524	25611	1	1A
0005434906410	25611	2	1D
0005433251199	25611	3	1F
0005434906421	25611	4	2A
0005434906428	25611	5	2D
0005433251180	25611	6	2F
0005434906560	25611	7	3A
0005433400955	25611	8	4A
0005434906559	25611	9	4E
0005433400956	25611	10	4D
0005434906381	25611	11	4F
0005433251205	25611	12	5A
0005433251184	25611	13	5D
0005433251195	25611	14	6C
0005434906422	25611	15	6D
0005434906397	25611	16	6F
0005433251208	25611	17	7A
0005433251198	25611	18	7C
0005434906400	25611	19	7F
0005433251190	25611	20	8C
0005433251194	25611	21	8D
0005433251193	25611	22	9C
0005434906525	25611	23	9D
0005433251196	25611	24	9F
0005434906376	25611	25	10C
0005433251185	25611	26	10E
0005433251206	25611	27	10F
0005434906433	25611	28	11A
0005434906558	25611	29	11D
0005433251183	25611	30	11E
0005434906375	25611	31	12C
0005433400954	25611	32	12D
0005434906374	25611	33	12F
0005434906423	25611	34	13E
0005434906526	25611	35	14A
0005434906373	25611	36	14C
0005434906403	25611	37	14D
0005433251181	25611	38	14E
0005433251197	25611	39	14F
0005433251192	25611	40	15A
0005433251207	25611	41	15F
0005433251202	25611	42	16C
0005434906444	25611	43	16D
0005433251209	25611	44	16E
0005433251186	25611	45	17C
0005433251188	25611	46	17D
0005433251200	25611	47	17F
0005433251189	25611	48	18A
0005433251182	25611	49	18C
0005433251203	25611	50	18D
0005433251187	25611	51	18F
0005434906427	25611	52	19A
0005433251211	25611	53	19C
0005434906490	25611	54	19D
0005433251204	25611	55	19F
0005434906366	25611	56	20A
0005433251210	25611	57	20D
0005433251201	25611	58	20E
0005433251191	25611	59	20F
0005432620909	2494	1	2B
0005432620904	2494	2	3A
0005432620914	2494	3	3B
0005432620908	2494	4	3C
0005432620912	2494	5	4B
0005432620903	2494	6	5A
0005432620906	2494	7	5B
0005432620910	2494	8	6B
0005432620905	2494	9	6D
0005432862167	2494	10	7B
0005432620907	2494	11	7C
0005432862209	2494	12	19D
0005432862163	2494	13	21B
0005432620911	2494	14	22B
0005432620915	2494	15	23A
0005432620913	2494	16	23B
0005432620833	28068	1	1A
0005432620798	28068	2	1B
0005432620799	28068	3	4A
0005432620821	28068	4	4B
0005432620796	28068	5	4C
0005432862229	28068	6	4D
0005432862231	28068	7	5C
0005432862228	28068	8	7C
0005432620795	28068	9	18A
0005432620800	28068	10	19B
0005432862230	28068	11	20A
0005432862227	28068	12	20B
0005432862232	28068	13	20C
0005432862233	28068	14	21D
0005432620797	28068	15	22A
0005432620834	28068	16	22C
0005433452719	30985	1	3B
0005433452720	30985	2	5B
0005433451600	30985	3	6A
0005433451601	30985	4	6B
0005433454849	31398	1	1A
0005433454850	31398	2	2B
0005434142540	11997	1	1C
0005433134072	11997	2	2A
0005433129206	11997	3	3B
0005434142544	11997	4	4B
0005433134071	11997	5	7B
0005433129211	11997	6	7C
0005433134059	11997	7	20B
0005434184633	11997	8	21C
0005433134061	11997	9	23B
0005434142573	29823	1	1B
0005434183561	29823	2	1D
0005433131667	29823	3	2B
0005434142569	29823	4	3D
0005434183562	29823	5	4A
0005434184645	29823	6	5C
0005434142570	29823	7	5D
0005434142572	29823	8	6A
0005434184646	29823	9	6B
0005433131665	29823	10	6D
0005433131664	29823	11	7B
0005433134096	29823	12	7C
0005433131666	29823	13	18B
0005433134097	29823	14	19B
0005434142571	29823	15	19C
0005433131663	29823	16	19D
0005433134095	29823	17	20B
0005434183560	29823	18	20D
0005435798915	21297	1	21C
0005435697072	16461	1	1A
0005435697071	16461	2	1B
0005435697053	16461	3	1C
0005435697050	16461	4	2A
0005435697045	16461	5	2C
0005435697065	16461	6	3A
0005435697048	16461	7	3C
0005435697062	16461	8	3D
0005435697069	16461	9	4A
0005435697063	16461	10	4B
0005435697047	16461	11	4D
0005435697068	16461	12	5A
0005435697056	16461	13	5C
0005435697070	16461	14	5D
0005435697055	16461	15	6A
0005435697067	16461	16	6C
0005435697057	16461	17	6D
0005435697052	16461	18	7B
0005435697060	16461	19	7C
0005435697051	16461	20	18A
0005435697064	16461	21	18C
0005435697059	16461	22	18D
0005435697061	16461	23	19A
0005435697044	16461	24	20B
0005435697066	16461	25	21B
0005435697046	16461	26	21C
0005435697049	16461	27	22A
0005435697058	16461	28	22C
0005435697054	16461	29	23A
0005435696855	24727	1	1C
0005435696877	24727	2	2B
0005435696940	24727	3	3B
0005435696896	24727	4	3D
0005435696882	24727	5	4C
0005435696894	24727	6	4D
0005435696864	24727	7	5C
0005435696870	24727	8	6A
0005435696876	24727	9	6C
0005435935016	24727	10	7A
0005435696854	24727	11	7B
0005435696883	24727	12	7C
0005435696859	24727	13	7D
0005435696897	24727	14	18C
0005435696853	24727	15	19B
0005435697058	24727	16	19C
0005435935017	24727	17	20A
0005435696881	24727	18	20C
0005435696857	24727	19	21A
0005435696871	24727	20	21B
0005435696898	24727	21	21D
0005435696889	24727	22	22A
0005435696865	24727	23	22C
0005435696858	24727	24	22D
0005433724759	18797	1	4B
0005433724761	18797	2	5A
0005433724762	18797	3	6A
0005433724760	18797	4	5B
0005433724726	21647	1	2A
0005433724734	21647	2	3B
0005432968821	21647	3	4B
0005432968822	21647	4	4A
0005432968820	21647	5	5A
0005433724727	21647	6	6A
0005434137441	7326	1	1A
0005434137394	7326	2	1C
0005434137383	7326	3	1D
0005434087469	7326	4	1F
0005434137375	7326	5	2A
0005434137401	7326	6	2C
0005434137386	7326	7	2D
0005434137381	7326	8	2F
0005434137361	7326	9	3A
0005434137360	7326	10	3C
0005434137405	7326	11	3D
0005434137396	7326	12	3F
0005434137400	7326	13	4A
0005434137399	7326	14	4C
0005434137374	7326	15	4D
0005434137391	7326	16	4E
0005434087467	7326	17	4F
0005434137427	7326	18	5A
0005434137358	7326	19	5C
0005434137368	7326	20	5D
0005434137367	7326	21	5E
0005434137420	7326	22	5F
0005434137380	7326	23	6A
0005434087470	7326	24	6C
0005434137432	7326	25	6D
0005434137385	7326	26	6E
0005434137390	7326	27	6F
0005434137389	7326	28	7A
0005434137370	7326	29	7C
0005434137377	7326	30	7D
0005434137376	7326	31	7E
0005434137364	7326	32	7F
0005434137411	7326	33	8A
0005434137365	7326	34	8C
0005434137363	7326	35	8D
0005434137359	7326	36	8E
0005434137398	7326	37	8F
0005434137382	7326	38	9A
0005434137412	7326	39	9C
0005434087471	7326	40	9D
0005434137372	7326	41	9E
0005434137437	7326	42	9F
0005434137418	7326	43	10A
0005434137384	7326	44	10C
0005434137362	7326	45	10D
0005434137421	7326	46	10E
0005434137357	7326	47	11A
0005434137416	7326	48	11C
0005434137425	7326	49	11D
0005434137403	7326	50	11E
0005434137378	7326	51	11F
0005434137366	7326	52	12A
0005434137392	7326	53	12C
0005434137424	7326	54	12D
0005434137438	7326	55	12E
0005434137423	7326	56	12F
0005434137419	7326	57	13A
0005434137388	7326	58	13C
0005434137439	7326	59	13D
0005434137408	7326	60	13E
0005434137431	7326	61	13F
0005434137417	7326	62	14C
0005434137406	7326	63	14D
0005434137442	7326	64	14F
0005434137422	7326	65	15A
0005434137426	7326	66	15C
0005434137369	7326	67	15D
0005434137397	7326	68	15E
0005434137410	7326	69	15F
0005434137445	7326	70	16A
0005434137435	7326	71	16C
0005434137402	7326	72	16D
0005434137443	7326	73	16E
0005434137413	7326	74	16F
0005434137434	7326	75	17A
0005434137407	7326	76	17C
0005434137387	7326	77	17D
0005434137373	7326	78	17E
0005434137371	7326	79	17F
0005434137395	7326	80	18A
0005434137436	7326	81	18C
0005434137404	7326	82	18D
0005434137430	7326	83	18E
0005434137428	7326	84	18F
0005434137415	7326	85	19A
0005434137409	7326	86	19C
0005434137444	7326	87	19D
0005434137433	7326	88	19E
0005434087468	7326	89	19F
0005434137414	7326	90	20A
0005434137429	7326	91	20C
0005434137379	7326	92	20D
0005434137440	7326	93	20E
0005434137393	7326	94	20F
0005434087435	28584	1	1F
0005434136761	28584	2	2A
0005434136832	28584	3	3C
0005434087429	28584	4	3F
0005434136678	28584	5	4D
0005434136717	28584	6	4E
0005434136748	28584	7	5A
0005434136677	28584	8	6D
0005434136687	28584	9	8A
0005434136688	28584	10	9C
0005434136733	28584	11	11A
0005434136718	28584	12	11C
0005434136848	28584	13	12E
0005434136849	28584	14	15D
0005434136699	28584	15	15E
0005434087440	28584	16	16A
0005434136686	28584	17	16C
0005434136831	28584	18	16E
0005434136760	28584	19	17A
0005434136726	28584	20	17C
0005434087434	28584	21	18C
0005434136806	28584	22	18E
0005434136920	28584	23	20E
0005434136753	28584	24	20F
0005435808137	1895	1	1D
0005435808140	1895	2	2D
0005435808144	1895	3	3B
0005434610197	1895	4	4D
0005433407485	1895	5	5A
0005433407477	1895	6	5C
0005434610194	1895	7	6B
0005434610195	1895	8	6D
0005435808141	1895	9	7D
0005433407484	1895	10	20D
0005435808139	1895	11	21C
0005435808138	1895	12	21B
0005435808136	1895	13	22A
0005434610196	1895	14	22C
0005435808143	1895	15	23A
0005435808142	1895	16	23B
0005435808050	23069	1	1A
0005435808051	23069	2	1C
0005433407506	23069	3	2A
0005433407504	23069	4	2B
0005435808052	23069	5	2D
0005433407511	23069	6	3A
0005433407517	23069	7	4A
0005433407512	23069	8	5C
0005433407510	23069	9	6A
0005433407513	23069	10	6B
0005433407515	23069	11	6C
0005433407503	23069	12	7A
0005433407505	23069	13	7D
0005433407516	23069	14	18A
0005433407514	23069	15	18C
0005433407508	23069	16	19C
0005433407507	23069	17	22A
0005433407509	23069	18	22D
0005434503526	16704	1	1D
0005434503530	16704	2	2A
0005434503575	16704	3	3A
0005434503496	16704	4	4C
0005434503654	16704	5	5C
0005434503529	16704	6	21B
0005434503745	22917	1	1A
0005434503761	22917	2	1C
0005434503782	22917	3	2A
0005434503771	22917	4	2B
0005434503743	22917	5	2C
0005434503755	22917	6	2D
0005434503777	22917	7	3A
0005434503770	22917	8	3C
0005434503754	22917	9	3D
0005434503774	22917	10	4A
0005434503758	22917	11	4B
0005434503776	22917	12	4C
0005434503744	22917	13	4D
0005434503779	22917	14	5A
0005434503746	22917	15	5B
0005434503767	22917	16	5D
0005434503756	22917	17	5C
0005434503757	22917	18	6A
0005434503768	22917	19	6B
0005434503764	22917	20	6D
0005434503760	22917	21	7A
0005434503766	22917	22	7B
0005434503763	22917	23	7C
0005434503750	22917	24	7D
0005434503762	22917	25	18C
0005434503773	22917	26	18D
0005434503781	22917	27	19A
0005434503772	22917	28	19B
0005434503780	22917	29	19D
0005434503749	22917	30	20A
0005434503775	22917	31	20B
0005434503748	22917	32	20C
0005434503741	22917	33	20D
0005434503747	22917	34	21A
0005434503753	22917	35	21B
0005434503769	22917	36	21D
0005434503778	22917	37	22A
0005434503751	22917	38	22B
0005434503765	22917	39	22C
0005434503742	22917	40	22D
0005434503752	22917	41	23A
0005434503759	22917	42	23B
0005433266584	2209	1	1A
0005435078198	2209	2	1D
0005435078193	2209	3	2D
0005435078206	2209	4	3D
0005435078195	2209	5	4A
0005435078204	2209	6	4D
0005435078194	2209	7	6B
0005435078205	2209	8	7A
0005435078202	2209	9	18C
0005433266585	2209	10	19A
0005433266575	2209	11	19C
0005435078203	2209	12	19D
0005435078197	2209	13	20A
0005435078192	2209	14	20B
0005435078200	2209	15	20C
0005433266598	2209	16	21C
0005433266557	2209	17	21D
0005435078201	2209	18	22A
0005435078196	2209	19	22C
0005435078199	2209	20	22D
0005435078191	2209	21	23A
0005433266576	2209	22	23B
0005433266638	24323	1	1A
0005435078063	24323	2	1C
0005433266639	24323	3	2B
0005435078142	24323	4	2C
0005435078092	24323	5	3A
0005433266637	24323	6	3D
0005435078102	24323	7	4D
0005433266640	24323	8	5B
0005433266636	24323	9	7A
0005433266634	24323	10	18B
0005433266641	24323	11	18C
0005435078132	24323	12	19B
0005435078070	24323	13	20B
0005433266633	24323	14	20C
0005435078103	24323	15	22A
0005433266635	24323	16	23A
0005435803235	6667	1	4D
0005435803237	6667	2	5B
0005435803236	6667	3	5D
0005434988636	6667	4	7C
0005434988637	6667	5	7D
0005434988634	6667	6	18C
0005434988633	6667	7	21A
0005435464474	6667	8	21D
0005434988635	6667	9	23A
0005435464489	23608	1	5A
0005435803214	23608	2	7A
0005435803217	23608	3	7D
0005435803215	23608	4	18D
0005435803216	23608	5	21A
0005432382821	30499	1	1A
0005432382806	30499	2	1C
0005432382812	30499	3	1D
0005432382835	30499	4	2A
0005432382814	30499	5	2C
0005432382830	30499	6	2D
0005433453744	30499	7	2F
0005432382823	30499	8	3A
0005433449777	30499	9	3D
0005432382832	30499	10	4C
0005433449768	30499	11	4D
0005432382815	30499	12	4F
0005432382805	30499	13	5A
0005433449782	30499	14	5C
0005432382807	30499	15	5D
0005432382828	30499	16	5E
0005432382833	30499	17	6C
0005433449774	30499	18	6D
0005432382810	30499	19	6E
0005432382819	30499	20	6F
0005433454855	30499	21	7A
0005432382818	30499	22	7C
0005433449783	30499	23	7D
0005433449767	30499	24	7F
0005433449781	30499	25	8A
0005433453743	30499	26	8C
0005432382817	30499	27	8D
0005433449776	30499	28	8E
0005432382843	30499	29	8F
0005432382839	30499	30	9A
0005432382808	30499	31	9C
0005432382824	30499	32	9D
0005432382831	30499	33	9E
0005432382811	30499	34	9F
0005433453745	30499	35	10A
0005433449763	30499	36	10C
0005432382837	30499	37	10E
0005432382842	30499	38	10F
0005432382822	30499	39	11D
0005432382826	30499	40	11E
0005432382816	30499	41	12A
0005433449769	30499	42	12C
0005433449772	30499	43	12D
0005433449780	30499	44	12E
0005432382820	30499	45	12F
0005432382841	30499	46	13A
0005433449773	30499	47	13C
0005433449771	30499	48	13D
0005433449779	30499	49	14A
0005432382813	30499	50	14C
0005433449775	30499	51	15E
0005432382838	30499	52	15D
0005433449766	30499	53	15F
0005433449762	30499	54	16A
0005433449784	30499	55	16D
0005433453746	30499	56	17A
0005432382827	30499	57	17C
0005433449764	30499	58	17D
0005433449778	30499	59	17F
0005433449770	30499	60	18A
0005432382809	30499	61	18C
0005432382825	30499	62	18D
0005433454854	30499	63	18E
0005433449765	30499	64	19A
0005432382829	30499	65	19C
0005432382804	30499	66	19D
0005432382834	30499	67	19E
0005432382836	30499	68	19F
0005432382840	30499	69	20C
0005433449633	31322	1	1A
0005432382520	31322	2	3C
0005432382531	31322	3	3D
0005432382511	31322	4	6D
0005433449642	31322	5	6E
0005432382533	31322	6	7A
0005432382556	31322	7	7E
0005433451583	31322	8	8A
0005433449594	31322	9	10D
0005433449596	31322	10	10F
0005433449606	31322	11	12F
0005432382555	31322	12	13D
0005433449632	31322	13	14A
0005432382532	31322	14	14C
0005433449585	31322	15	15C
0005432382541	31322	16	16C
0005433449586	31322	17	17C
0005433449597	31322	18	17E
0005433449693	31322	19	17F
0005432382586	31322	20	20D
0005433453728	31322	21	20F
0005435299697	10755	1	1A
0005433131626	10755	2	3B
0005433131627	10755	3	5C
0005433126771	10755	4	6A
0005433126770	10755	5	7C
0005435304094	10755	6	18B
0005433131629	10755	7	21B
0005435304093	10755	8	22A
0005433126806	29736	1	1A
0005433129237	29736	2	1C
0005433129239	29736	3	2A
0005433129240	29736	4	2B
0005435299735	29736	5	3B
0005433126807	29736	6	3C
0005435302159	29736	7	3D
0005433126805	29736	8	4D
0005435299738	29736	9	5D
0005433126808	29736	10	6D
0005435299737	29736	11	18C
0005435299736	29736	12	19A
0005433126804	29736	13	19B
0005435299734	29736	14	19C
0005435302163	29736	15	19D
0005433129238	29736	16	20B
0005435302162	29736	17	21D
0005435302161	29736	18	22A
0005435302160	29736	19	22C
0005435302158	29736	20	23A
0005433129236	29736	21	23B
0005433109904	2428	1	1A
0005434287084	2428	2	1C
0005434287088	2428	3	2A
0005434287092	2428	4	2B
0005433109849	2428	5	2C
0005433109862	2428	6	2D
0005434287082	2428	7	3B
0005434287086	2428	8	3C
0005434287087	2428	9	4A
0005434287096	2428	10	4C
0005434287079	2428	11	4D
0005434287094	2428	12	5A
0005434287090	2428	13	5B
0005434287080	2428	14	6A
0005432264454	2428	15	6C
0005432264453	2428	16	7B
0005432264452	2428	17	18A
0005434287089	2428	18	18C
0005434287083	2428	19	18D
0005434287095	2428	20	19A
0005434287093	2428	21	19D
0005434287077	2428	22	20A
0005434287081	2428	23	20B
0005434287091	2428	24	20D
0005434287078	2428	25	21A
0005434287085	2428	26	21C
0005434287076	2428	27	21D
0005432264451	2428	28	22A
0005434287075	2428	29	22B
0005433109901	2428	30	22C
0005433109852	2428	31	22D
0005434287074	2428	32	23B
0005434286916	26847	1	1A
0005433109942	26847	2	1D
0005434286932	26847	3	2D
0005433109939	26847	4	3B
0005434286949	26847	5	3C
0005434286901	26847	6	4A
0005434286893	26847	7	4B
0005433109943	26847	8	4C
0005434286902	26847	9	5C
0005434286928	26847	10	6A
0005434286896	26847	11	6B
0005433109937	26847	12	6D
0005433109938	26847	13	7B
0005434286994	26847	14	7D
0005434286938	26847	15	18C
0005434286897	26847	16	18D
0005433109941	26847	17	19A
0005433109944	26847	18	19B
0005434286950	26847	19	19C
0005433109936	26847	20	19D
0005433109945	26847	21	20A
0005433109948	26847	22	20C
0005434286965	26847	23	20D
0005433109946	26847	24	21D
0005434286907	26847	25	22A
0005433109947	26847	26	22C
0005434286954	26847	27	23A
0005433109940	26847	28	23B
0005434272167	25464	1	6C
0005435856166	25464	2	21B
0005435856167	25464	3	22C
0005434272176	26660	1	5D
0005434272177	26660	2	22A
0005434273062	26660	3	23B
0005433868058	4803	1	1A
0005433868079	4803	2	1B
0005433868093	4803	3	2A
0005433868055	4803	4	2B
0005433868085	4803	5	2C
0005433868073	4803	6	2D
0005433868076	4803	7	3C
0005433868090	4803	8	3B
0005433868074	4803	9	3D
0005433868092	4803	10	4A
0005433868068	4803	11	4B
0005433868083	4803	12	4C
0005433868057	4803	13	4D
0005433868082	4803	14	5A
0005433868078	4803	15	5C
0005433868061	4803	16	5D
0005433868086	4803	17	6A
0005433868067	4803	18	6C
0005433868089	4803	19	6D
0005433868069	4803	20	7A
0005433868064	4803	21	7B
0005433868084	4803	22	7C
0005433868077	4803	23	18A
0005433868062	4803	24	18B
0005433868060	4803	25	18C
0005433868088	4803	26	18D
0005433868065	4803	27	19A
0005433868075	4803	28	19B
0005433868063	4803	29	19D
0005433868059	4803	30	20B
0005433868072	4803	31	20C
0005433868081	4803	32	20D
0005433868070	4803	33	21A
0005433868056	4803	34	21B
0005433868087	4803	35	21C
0005433868054	4803	36	21D
0005433868094	4803	37	22B
0005433868071	4803	38	22C
0005433868066	4803	39	22D
0005433868091	4803	40	23A
0005433868080	4803	41	23B
0005435860456	32588	1	1A
0005433867746	32588	2	1D
0005435860461	32588	3	2B
0005433867763	32588	4	2C
0005435860454	32588	5	3A
0005433867885	32588	6	4B
0005433867728	32588	7	4C
0005433867762	32588	8	4D
0005433867792	32588	9	5C
0005433867800	32588	10	6C
0005435860460	32588	11	7A
0005435860459	32588	12	7B
0005435860457	32588	13	7D
0005433867799	32588	14	18A
0005433867801	32588	15	18C
0005433867773	32588	16	18D
0005435860455	32588	17	19A
0005433867761	32588	18	19C
0005433867734	32588	19	20A
0005435860458	32588	20	23A
0005435911322	3414	1	1A
0005435911326	3414	2	1B
0005434663282	3414	3	1C
0005435911328	3414	4	1D
0005434460485	3414	5	2B
0005434663288	3414	6	2C
0005434663284	3414	7	3D
0005434663291	3414	8	4A
0005434663285	3414	9	5D
0005434663283	3414	10	6A
0005434460484	3414	11	6C
0005434663290	3414	12	6D
0005434460486	3414	13	7A
0005434663286	3414	14	7D
0005434663289	3414	15	19B
0005434663280	3414	16	19C
0005434663279	3414	17	19D
0005434663278	3414	18	20B
0005435911317	3414	19	20C
0005434663287	3414	20	22B
0005434663281	3414	21	22C
0005434663168	12473	1	1D
0005435911381	12473	2	2A
0005435911379	12473	3	3B
0005434663198	12473	4	4B
0005435911378	12473	5	6D
0005435911380	12473	6	7A
0005434663174	12473	7	7B
0005434663177	12473	8	18A
0005435911385	12473	9	18D
0005435911382	12473	10	19A
0005435911383	12473	11	19D
0005435911384	12473	12	20B
0005434663167	12473	13	20C
0005433867746	14496	1	1A
0005433867885	14496	2	1C
0005433867792	14496	3	1D
0005435860460	14496	4	2D
0005435860461	14496	5	3A
0005433867801	14496	6	3B
0005433867800	14496	7	3C
0005435860458	14496	8	4B
0005433867773	14496	9	4C
0005435860454	14496	10	5D
0005433867734	14496	11	6B
0005433867762	14496	12	7B
0005435860459	14496	13	7C
0005433867799	14496	14	18B
0005433867728	14496	15	19C
0005435860455	14496	16	19D
0005433867761	14496	17	20A
0005433867763	14496	18	20B
0005435860457	14496	19	22C
0005435860456	14496	20	22D
0005433868034	32664	1	1A
0005433868049	32664	2	1B
0005433868041	32664	3	1C
0005433868053	32664	4	1D
0005433868022	32664	5	2A
0005433868030	32664	6	2B
0005433868032	32664	7	2C
0005433868031	32664	8	2D
0005433868035	32664	9	3A
0005433868047	32664	10	3B
0005433868026	32664	11	3C
0005433868033	32664	12	3D
0005433868029	32664	13	4A
0005433868021	32664	14	4B
0005433868023	32664	15	4C
0005433868052	32664	16	4D
0005433868014	32664	17	5B
0005433868042	32664	18	6A
0005433868037	32664	19	5D
0005433868051	32664	20	6B
0005433868038	32664	21	6D
0005433868017	32664	22	7A
0005433868039	32664	23	7B
0005433868036	32664	24	7C
0005433868027	32664	25	7D
0005433868016	32664	26	18A
0005433868013	32664	27	18B
0005433868025	32664	28	18D
0005433868050	32664	29	19A
0005433868018	32664	30	19B
0005433868024	32664	31	19C
0005433868048	32664	32	19D
0005433868020	32664	33	20A
0005433868046	32664	34	20C
0005433868019	32664	35	20B
0005433868044	32664	36	20D
0005433868045	32664	37	21B
0005433868028	32664	38	21C
0005433868012	32664	39	21D
0005433868040	32664	40	22A
0005433868043	32664	41	23A
0005433868015	32664	42	23B
0005432798971	12107	1	2A
0005432799028	12107	2	2D
0005432798982	12107	3	3D
0005432799022	12107	4	4A
0005432799086	12107	5	4C
0005432798981	12107	6	4D
0005432799049	12107	7	5C
0005432799029	12107	8	6A
0005432798969	12107	9	6C
0005432798978	12107	10	7A
0005432799005	12107	11	18B
0005432799040	12107	12	19B
0005432798977	12107	13	19D
0005432799090	12107	14	20A
0005432799023	12107	15	21D
0005432799014	12107	16	22C
0005432799181	14793	1	1B
0005432799183	14793	2	2A
0005432799182	14793	3	2B
0005432799164	14793	4	2C
0005432799169	14793	5	3B
0005432799177	14793	6	3C
0005432799165	14793	7	4A
0005432799166	14793	8	5B
0005432799179	14793	9	5C
0005432799155	14793	10	5D
0005432799158	14793	11	6B
0005432799172	14793	12	6C
0005432799174	14793	13	7A
0005432799180	14793	14	7C
0005432799157	14793	15	18A
0005432799176	14793	16	18B
0005432799178	14793	17	18D
0005432799175	14793	18	19A
0005432799170	14793	19	19B
0005432799173	14793	20	19C
0005432799156	14793	21	19D
0005432799167	14793	22	20C
0005432799168	14793	23	20D
0005432799163	14793	24	21A
0005432799171	14793	25	21B
0005432799162	14793	26	21C
0005432799159	14793	27	22A
0005432799161	14793	28	22C
0005432799160	14793	29	23A
0005434299349	7064	1	1A
0005434299351	7064	2	1C
0005434407200	7064	3	1D
0005434407197	7064	4	2A
0005434407169	7064	5	1F
0005434407172	7064	6	2C
0005434299346	7064	7	2D
0005434407166	7064	8	2F
0005434407160	7064	9	3A
0005434407185	7064	10	3D
0005434299356	7064	11	3C
0005434407163	7064	12	3F
0005434407164	7064	13	4A
0005434299338	7064	14	4C
0005434407208	7064	15	4D
0005432153877	7064	16	4E
0005434407187	7064	17	4F
0005434407168	7064	18	5A
0005434299341	7064	19	5D
0005434407192	7064	20	5C
0005434407177	7064	21	5E
0005434407171	7064	22	5F
0005434299342	7064	23	6B
0005435310841	7064	24	6A
0005434407186	7064	25	6D
0005432153876	7064	26	6F
0005434407182	7064	27	6E
0005434299359	7064	28	7A
0005435310851	7064	29	7B
0005432153870	7064	30	7D
0005434407179	7064	31	7C
0005435310852	7064	32	7E
0005434407165	7064	33	7F
0005434407195	7064	34	8A
0005434407194	7064	35	8B
0005435310845	7064	36	8C
0005434299360	7064	37	8E
0005435310838	7064	38	8D
0005432153875	7064	39	8F
0005434407213	7064	40	9C
0005434299353	7064	41	9B
0005434299352	7064	42	9D
0005434299348	7064	43	9E
0005434407206	7064	44	9F
0005434299339	7064	45	10B
0005434407196	7064	46	10C
0005435310842	7064	47	10D
0005435310850	7064	48	11A
0005432153874	7064	49	10E
0005434407167	7064	50	11D
0005434407198	7064	51	11F
0005434407204	7064	52	11E
0005434407199	7064	53	12B
0005434407159	7064	54	12C
0005434407170	7064	55	12D
0005435310846	7064	56	12E
0005434407205	7064	57	13A
0005434407158	7064	58	13B
0005434299357	7064	59	13D
0005435293073	7064	60	13C
0005434407191	7064	61	13E
0005435293068	7064	62	13F
0005434407173	7064	63	14B
0005434407175	7064	64	14A
0005434407183	7064	65	14C
0005434407215	7064	66	14D
0005434407210	7064	67	14E
0005432153873	7064	68	14F
0005434299340	7064	69	15B
0005434407201	7064	70	15C
0005434407216	7064	71	15D
0005434299355	7064	72	15E
0005434299350	7064	73	16B
0005434407188	7064	74	16C
0005434299354	7064	75	16E
0005434407176	7064	76	16D
0005434407162	7064	77	16F
0005432108225	7064	78	17B
0005434407184	7064	79	17A
0005434407189	7064	80	17C
0005434407190	7064	81	17D
0005434407180	7064	82	18C
0005434407155	7064	83	18B
0005434407157	7064	84	18D
0005434407207	7064	85	18E
0005432153871	7064	86	19A
0005432153872	7064	87	19B
0005434407202	7064	88	19C
0005434299345	7064	89	19D
0005434407181	7064	90	19F
0005434407217	7064	91	19E
0005434299343	7064	92	20A
0005434407212	7064	93	20B
0005434299344	7064	94	20E
0005434299336	7064	95	20D
0005432108226	7064	96	20F
0005434299358	7064	97	21C
0005434407203	7064	98	21D
0005434407211	7064	99	21F
0005434299337	7064	100	21E
0005434407174	7064	101	22B
0005434407209	7064	102	22C
0005434299347	7064	103	22E
0005434407178	7064	104	23A
0005434407193	7064	105	23B
0005434407214	7064	106	23C
0005434407156	7064	107	23E
0005434407161	7064	108	23D
0005432108227	7064	109	23F
0005434406784	26881	1	1A
0005435310943	26881	2	2D
0005434406663	26881	3	3C
0005434299192	26881	4	3A
0005434406783	26881	5	3D
0005434406713	26881	6	4C
0005435293138	26881	7	4E
0005434299179	26881	8	4D
0005435310945	26881	9	4F
0005434299205	26881	10	5B
0005435293132	26881	11	5E
0005435293139	26881	12	6A
0005434406662	26881	13	6B
0005434406917	26881	14	7A
0005435293136	26881	15	7B
0005435293143	26881	16	8B
0005434299196	26881	17	8E
0005434299158	26881	18	8F
0005434299156	26881	19	9C
0005435310947	26881	20	9B
0005434406862	26881	21	10C
0005434406674	26881	22	11A
0005435293135	26881	23	11D
0005434299193	26881	24	11C
0005434406770	26881	25	11E
0005435293134	26881	26	12E
0005434299269	26881	27	12F
0005434406743	26881	28	13E
0005434299225	26881	29	13F
0005434299210	26881	30	14C
0005435310942	26881	31	14E
0005432058342	26881	32	14F
0005434406821	26881	33	15B
0005434299268	26881	34	15E
0005435293142	26881	35	15D
0005434299224	26881	36	15F
0005434406834	26881	37	16B
0005435293137	26881	38	16C
0005435310948	26881	39	16D
0005434406810	26881	40	17B
0005435310944	26881	41	17D
0005434406800	26881	42	17F
0005435293140	26881	43	18F
0005434406729	26881	44	18E
0005432058340	26881	45	19C
0005434299206	26881	46	19D
0005435293141	26881	47	19F
0005435293133	26881	48	20A
0005432058343	26881	49	20C
0005432058341	26881	50	20B
0005434406742	26881	51	20E
0005434406660	26881	52	20F
0005434299162	26881	53	21B
0005435310946	26881	54	21C
0005435293131	26881	55	21D
0005434406730	26881	56	22A
0005434299150	26881	57	22D
0005434406751	26881	58	22E
0005432603980	6456	1	1A
0005432603985	6456	2	1B
0005435218104	6456	3	1C
0005432603986	6456	4	1D
0005432603977	6456	5	2A
0005432603994	6456	6	2B
0005434512067	6456	7	2D
0005432604001	6456	8	3A
0005432603979	6456	9	3B
0005434512069	6456	10	3C
0005432603988	6456	11	3D
0005432603975	6456	12	4A
0005432603971	6456	13	4B
0005432603973	6456	14	4C
0005432604000	6456	15	4D
0005432603968	6456	16	5A
0005432603990	6456	17	5B
0005432603966	6456	18	5C
0005432603996	6456	19	5D
0005434512071	6456	20	6A
0005432603978	6456	21	6B
0005432603981	6456	22	6C
0005432603995	6456	23	7A
0005432603967	6456	24	7B
0005434512070	6456	25	7C
0005432603998	6456	26	7D
0005432603976	6456	27	18A
0005434512068	6456	28	18B
0005432603991	6456	29	18C
0005432603974	6456	30	18D
0005432603970	6456	31	19A
0005432603982	6456	32	19B
0005432604002	6456	33	19D
0005432603969	6456	34	19C
0005432603989	6456	35	20A
0005432604004	6456	36	20B
0005432604005	6456	37	20C
0005432603984	6456	38	20D
0005432603992	6456	39	21A
0005432603997	6456	40	21B
0005434512072	6456	41	21C
0005432603993	6456	42	21D
0005432603987	6456	43	22A
0005432603999	6456	44	22C
0005432603983	6456	45	22D
0005432603972	6456	46	23A
0005432604003	6456	47	23B
0005432603713	21349	1	1A
0005432603684	21349	2	1B
0005432603642	21349	3	2A
0005434512037	21349	4	2B
0005434512040	21349	5	3B
0005432603661	21349	6	4A
0005432603695	21349	7	4C
0005432603692	21349	8	5A
0005435221046	21349	9	5B
0005435221506	21349	10	5C
0005432603655	21349	11	5D
0005434512032	21349	12	6A
0005432603719	21349	13	6C
0005432603663	21349	14	6D
0005432603763	21349	15	7A
0005432603694	21349	16	7B
0005432603666	21349	17	7C
0005432603712	21349	18	7D
0005432603736	21349	19	18B
0005435221047	21349	20	18C
0005435221508	21349	21	18D
0005434512033	21349	22	19B
0005432603691	21349	23	19C
0005434512021	21349	24	19D
0005435221507	21349	25	20B
0005432603714	21349	26	20C
0005434512030	21349	27	21C
0005434512017	21349	28	22A
0005434512041	21349	29	22B
0005432603667	21349	30	23B
0005433251183	14977	1	1C
0005434906490	14977	2	1D
0005433251182	14977	3	2C
0005434906410	14977	4	2D
0005434906422	14977	5	2F
0005433251205	14977	6	3A
0005433251186	14977	7	3C
0005433251188	14977	8	3F
0005433251206	14977	9	4C
0005433251209	14977	10	4D
0005433251201	14977	11	4E
0005433251210	14977	12	4F
0005433251194	14977	13	5D
0005433251184	14977	14	5E
0005434906397	14977	15	6A
0005433251196	14977	16	5F
0005433251187	14977	17	6C
0005433251185	14977	18	6F
0005433251189	14977	19	7A
0005433251211	14977	20	7E
0005434906403	14977	21	8D
0005433251202	14977	22	8E
0005434906526	14977	23	8F
0005433251193	14977	24	9A
0005434906444	14977	25	9C
0005434906525	14977	26	10C
0005434906559	14977	27	10D
0005433251192	14977	28	11C
0005434906376	14977	29	12A
0005433251190	14977	30	12C
0005433251197	14977	31	12D
0005434906400	14977	32	12E
0005434906560	14977	33	12F
0005433251200	14977	34	13A
0005434906433	14977	35	13E
0005434906524	14977	36	13F
0005434906373	14977	37	14D
0005433251198	14977	38	14E
0005433251203	14977	39	16A
0005434906381	14977	40	16C
0005433251199	14977	41	16D
0005433251195	14977	42	16E
0005434906428	14977	43	16F
0005433251204	14977	44	17A
0005434906374	14977	45	17C
0005434906366	14977	46	17E
0005433251191	14977	47	17F
0005433251181	14977	48	18C
0005433251207	14977	49	18D
0005434906421	14977	50	18F
0005434906423	14977	51	19A
0005434906375	14977	52	19C
0005433251208	14977	53	19F
0005433251180	14977	54	20C
0005434906558	14977	55	20D
0005434906427	14977	56	20F
0005434906793	25873	1	1A
0005434906811	25873	2	1C
0005434906798	25873	3	1F
0005434906801	25873	4	2C
0005434906807	25873	5	2D
0005434906796	25873	6	2F
0005434906782	25873	7	3A
0005434906771	25873	8	3C
0005434906759	25873	9	3D
0005434906775	25873	10	3F
0005434906757	25873	11	4A
0005434906809	25873	12	4C
0005433251074	25873	13	4D
0005434906768	25873	14	4E
0005434906758	25873	15	4F
0005434906774	25873	16	5A
0005434906756	25873	17	5C
0005434906778	25873	18	5D
0005434906770	25873	19	5E
0005434906803	25873	20	5F
0005434906794	25873	21	6A
0005434906779	25873	22	6C
0005434906813	25873	23	6D
0005433250995	25873	24	6E
0005433250932	25873	25	6F
0005433251018	25873	26	7A
0005433251068	25873	27	7D
0005434906750	25873	28	7E
0005434906755	25873	29	7F
0005434906804	25873	30	8C
0005434906772	25873	31	8D
0005434906783	25873	32	8E
0005434906764	25873	33	9A
0005434906792	25873	34	9F
0005434906806	25873	35	10A
0005434906788	25873	36	10C
0005434906773	25873	37	10D
0005434906797	25873	38	10E
0005434906800	25873	39	10F
0005434906787	25873	40	11A
0005433251093	25873	41	11C
0005434906751	25873	42	11D
0005433250931	25873	43	11E
0005434906761	25873	44	11F
0005434906791	25873	45	12A
0005434906776	25873	46	12C
0005434906766	25873	47	12D
0005433250969	25873	48	12F
0005434906790	25873	49	13A
0005434906760	25873	50	13C
0005434906767	25873	51	13D
0005434906810	25873	52	13E
0005434906780	25873	53	14A
0005433250929	25873	54	14C
0005434906769	25873	55	14E
0005434906777	25873	56	15A
0005434906753	25873	57	15D
0005434906786	25873	58	15E
0005433250935	25873	59	15F
0005434906795	25873	60	16A
0005433251009	25873	61	16C
0005433250996	25873	62	16D
0005434906762	25873	63	16E
0005434906802	25873	64	16F
0005434906789	25873	65	17A
0005434906781	25873	66	17C
0005434906799	25873	67	17F
0005434906784	25873	68	18C
0005433251067	25873	69	18D
0005434906763	25873	70	18E
0005433250930	25873	71	18F
0005434906805	25873	72	19A
0005433251010	25873	73	19C
0005434906808	25873	74	19D
0005434906812	25873	75	19E
0005434906765	25873	76	19F
0005434906785	25873	77	20A
0005433250970	25873	78	20D
0005434906752	25873	79	20E
0005434906754	25873	80	20F
0005433008198	14166	1	1C
0005433008197	14166	2	1D
0005433008231	14166	3	1F
0005433008232	14166	4	2C
0005433008208	14166	5	2F
0005433008235	14166	6	3A
0005433008228	14166	7	3D
0005433008205	14166	8	4F
0005433008215	14166	9	5C
0005433008201	14166	10	5D
0005433008203	14166	11	5E
0005433008220	14166	12	6D
0005433008200	14166	13	6E
0005433008225	14166	14	6F
0005433008210	14166	15	7D
0005433008236	14166	16	7C
0005433008227	14166	17	7E
0005433008233	14166	18	7F
0005433008226	14166	19	8A
0005433008219	14166	20	9A
0005433008214	14166	21	9C
0005433008238	14166	22	10E
0005433008221	14166	23	11A
0005433008218	14166	24	11C
0005433008194	14166	25	11F
0005433008199	14166	26	12A
0005433008213	14166	27	12C
0005433008212	14166	28	13A
0005433008211	14166	29	13C
0005433008217	14166	30	13E
0005433008216	14166	31	13F
0005433008206	14166	32	14C
0005433008195	14166	33	14F
0005433008237	14166	34	16A
0005433008202	14166	35	16D
0005433008209	14166	36	16F
0005433008239	14166	37	17A
0005433008224	14166	38	17F
0005433008223	14166	39	18D
0005433008229	14166	40	19A
0005433008230	14166	41	19C
0005433008207	14166	42	19D
0005433008196	14166	43	20A
0005433008204	14166	44	20C
0005433008222	14166	45	20D
0005433008234	14166	46	20F
0005433007899	22835	1	2C
0005433007929	22835	2	4C
0005433007987	22835	3	4D
0005433007834	22835	4	6C
0005433007848	22835	5	7A
0005433007876	22835	6	7E
0005433007847	22835	7	9C
0005433007875	22835	8	9D
0005433007910	22835	9	11F
0005433007860	22835	10	12D
0005433007911	22835	11	13A
0005433007868	22835	12	13C
0005433007822	22835	13	14D
0005433008006	22835	14	16A
0005433007877	22835	15	19A
0005433007985	22835	16	19E
0005433007986	22835	17	19F
0005435718864	15518	1	1A
0005435718871	15518	2	1C
0005435718870	15518	3	1D
0005435718836	15518	4	1F
0005435718868	15518	5	2A
0005435718879	15518	6	2D
0005435718847	15518	7	3F
0005435718859	15518	8	4C
0005435718865	15518	9	4D
0005435718866	15518	10	5A
0005435718858	15518	11	5D
0005435718845	15518	12	5E
0005435718882	15518	13	6A
0005435718842	15518	14	6E
0005435718881	15518	15	7A
0005435718832	15518	16	7C
0005435718872	15518	17	7D
0005435718862	15518	18	7E
0005435718837	15518	19	8D
0005435718873	15518	20	9A
0005435718840	15518	21	9C
0005435718851	15518	22	9D
0005435718850	15518	23	10A
0005435718846	15518	24	10D
0005435718833	15518	25	10E
0005435718878	15518	26	10F
0005435718841	15518	27	11A
0005435718875	15518	28	11E
0005435718839	15518	29	12E
0005435718838	15518	30	13C
0005435718852	15518	31	13F
0005435718877	15518	32	14A
0005435718835	15518	33	14C
0005435718861	15518	34	14D
0005435718863	15518	35	14F
0005435718880	15518	36	15C
0005435718874	15518	37	15E
0005435718876	15518	38	15F
0005435718848	15518	39	16D
0005435718884	15518	40	16E
0005435718844	15518	41	16F
0005435718883	15518	42	17D
0005435718857	15518	43	18D
0005435718860	15518	44	18F
0005435718853	15518	45	19A
0005435718869	15518	46	19C
0005435718849	15518	47	19D
0005435718834	15518	48	19F
0005435718855	15518	49	20A
0005435718854	15518	50	20C
0005435718856	15518	51	20D
0005435718843	15518	52	20E
0005435718867	15518	53	20F
0005434925502	20527	1	1A
0005434925489	20527	2	1C
0005434925478	20527	3	1F
0005434925476	20527	4	2A
0005434925487	20527	5	2D
0005434925493	20527	6	3C
0005434925485	20527	7	3D
0005434925482	20527	8	4D
0005434925486	20527	9	5C
0005434925498	20527	10	6E
0005434925495	20527	11	6F
0005434925483	20527	12	7E
0005434925492	20527	13	8A
0005434925475	20527	14	8D
0005434925481	20527	15	8F
0005434925479	20527	16	10A
0005434925490	20527	17	10D
0005434925484	20527	18	10E
0005434925488	20527	19	11D
0005434925499	20527	20	12A
0005434925500	20527	21	12E
0005434925501	20527	22	12F
0005434925494	20527	23	14D
0005434925497	20527	24	14F
0005434925474	20527	25	15A
0005434925491	20527	26	19D
0005434925480	20527	27	19F
0005434925477	20527	28	20C
0005434925496	20527	29	20D
0005435487645	15812	1	1D
0005435998966	15812	2	2A
0005435998962	15812	3	2C
0005435487646	15812	4	2D
0005435487651	15812	5	3A
0005435487635	15812	6	3C
0005435487650	15812	7	3D
0005435487637	15812	8	4D
0005435487642	15812	9	5B
0005435998967	15812	10	5D
0005435487633	15812	11	6A
0005435998976	15812	12	6B
0005435487641	15812	13	6C
0005435487648	15812	14	7A
0005435487638	15812	15	7D
0005435487649	15812	16	18A
0005435487639	15812	17	18B
0005435487644	15812	18	18D
0005435487640	15812	19	19C
0005435487634	15812	20	19D
0005435487631	15812	21	20A
0005435487652	15812	22	20D
0005435487632	15812	23	21B
0005435998969	15812	24	21C
0005435487643	15812	25	22B
0005435487636	15812	26	22C
0005435487647	15812	27	23A
0005435999069	19678	1	1A
0005435999084	19678	2	1B
0005435999075	19678	3	1C
0005435999091	19678	4	1D
0005435999083	19678	5	2A
0005435999081	19678	6	2B
0005435999093	19678	7	3A
0005435999080	19678	8	3B
0005435999085	19678	9	3C
0005435999090	19678	10	4A
0005435487461	19678	11	4B
0005435999071	19678	12	4C
0005435487468	19678	13	4D
0005435999086	19678	14	5A
0005435999078	19678	15	5C
0005435999077	19678	16	5D
0005435999082	19678	17	6C
0005435999092	19678	18	7A
0005435999070	19678	19	7B
0005435999076	19678	20	18C
0005435999087	19678	21	19D
0005435999073	19678	22	21A
0005435999072	19678	23	21C
0005435999079	19678	24	22A
0005435999074	19678	25	22B
0005435999088	19678	26	22D
0005435999089	19678	27	23A
0005435839189	6012	1	1C
0005435839215	6012	2	1A
0005435839211	6012	3	1D
0005435839201	6012	4	2D
0005435839206	6012	5	2F
0005435839203	6012	6	3D
0005435472582	6012	7	5D
0005432660800	6012	8	6B
0005435472527	6012	9	6A
0005435839200	6012	10	7A
0005432142224	6012	11	8A
0005435839208	6012	12	8C
0005432660799	6012	13	9B
0005432659689	6012	14	9A
0005435839205	6012	15	10A
0005435839197	6012	16	10C
0005435839194	6012	17	11B
0005432658574	6012	18	11D
0005435839202	6012	19	12A
0005435839217	6012	20	12D
0005435839193	6012	21	12F
0005435839204	6012	22	13B
0005435839190	6012	23	13F
0005432142222	6012	24	14E
0005435839199	6012	25	14C
0005435839216	6012	26	14F
0005435839209	6012	27	15B
0005435839212	6012	28	15A
0005435472534	6012	29	15C
0005435472528	6012	30	15E
0005435839198	6012	31	15D
0005432658573	6012	32	15F
0005435839214	6012	33	16C
0005432142226	6012	34	16D
0005432142223	6012	35	17B
0005435839213	6012	36	18A
0005432658575	6012	37	18B
0005435839192	6012	38	19A
0005435839196	6012	39	18F
0005435839207	6012	40	19D
0005435839188	6012	41	20B
0005432660801	6012	42	20C
0005432658572	6012	43	20F
0005435839210	6012	44	21A
0005435839191	6012	45	21D
0005432142225	6012	46	21F
0005435839195	6012	47	21E
0005432537041	18058	1	1C
0005435472655	18058	2	1D
0005435472652	18058	3	2C
0005435839111	18058	4	3F
0005435472654	18058	5	4A
0005435838975	18058	6	5C
0005435472659	18058	7	6B
0005435838976	18058	8	6F
0005435838998	18058	9	7C
0005435838963	18058	10	8A
0005435472661	18058	11	7F
0005435472657	18058	12	8C
0005435472656	18058	13	8B
0005435472662	18058	14	8D
0005435839023	18058	15	9B
0005435472646	18058	16	9A
0005435472651	18058	17	10A
0005432537039	18058	18	10E
0005435839022	18058	19	12B
0005435838999	18058	20	13A
0005435472648	18058	21	13C
0005435472660	18058	22	13B
0005435839067	18058	23	14C
0005435472649	18058	24	14B
0005432537040	18058	25	14F
0005435838988	18058	26	14E
0005435838989	18058	27	15B
0005435839069	18058	28	15F
0005435472650	18058	29	16A
0005435472647	18058	30	16C
0005435839068	18058	31	16B
0005435839001	18058	32	16E
0005435839033	18058	33	16F
0005435472653	18058	34	21C
0005435472658	18058	35	21E
0005433284775	23041	1	1D
0005433284816	23041	2	2C
0005435103857	23041	3	2F
0005433284948	23041	4	4A
0005433284856	23041	5	4E
0005435103858	23041	6	4F
0005435103853	23041	7	5B
0005433284829	23041	8	5E
0005433284774	23041	9	6A
0005435103861	23041	10	6D
0005435103860	23041	11	7A
0005433284855	23041	12	8A
0005433284788	23041	13	9B
0005433284792	23041	14	11E
0005435103854	23041	15	12D
0005433284859	23041	16	13D
0005435103855	23041	17	13E
0005433284865	23041	18	14C
0005435103856	23041	19	14B
0005433284785	23041	20	15E
0005433284807	23041	21	15F
0005433284817	23041	22	16E
0005433284878	23041	23	19C
0005433284877	23041	24	20C
0005433284808	23041	25	21F
0005435103859	23041	26	23E
0005433285020	32057	1	2A
0005433285022	32057	2	3D
0005433285028	32057	3	3C
0005433285036	32057	4	4A
0005433285025	32057	5	4C
0005433285024	32057	6	4D
0005433285029	32057	7	4E
0005433285012	32057	8	5D
0005433285013	32057	9	5F
0005433285030	32057	10	6C
0005433285019	32057	11	8E
0005433285031	32057	12	9D
0005433285017	32057	13	11C
0005433285034	32057	14	11E
0005433285032	32057	15	12B
0005433285016	32057	16	12D
0005433285014	32057	17	12E
0005433285038	32057	18	13B
0005433285011	32057	19	13D
0005433285027	32057	20	13E
0005433285015	32057	21	14D
0005433285035	32057	22	15E
0005433285008	32057	23	16F
0005433285023	32057	24	17A
0005433285009	32057	25	18F
0005433285033	32057	26	19B
0005433285018	32057	27	19F
0005433285007	32057	28	20A
0005433285021	32057	29	22C
0005433285037	32057	30	22D
0005433285026	32057	31	22E
0005433285010	32057	32	23B
0005432802456	1479	1	2C
0005432802454	1479	2	3C
0005432802449	1479	3	3A
0005432802464	1479	4	4C
0005432802457	1479	5	4A
0005432802465	1479	6	4F
0005432892719	1479	7	6D
0005432802438	1479	8	7A
0005432802461	1479	9	7E
0005432802460	1479	10	9F
0005432802443	1479	11	10C
0005432802462	1479	12	10D
0005432802466	1479	13	11A
0005432802437	1479	14	11B
0005432802450	1479	15	11D
0005432802446	1479	16	11F
0005432802448	1479	17	11E
0005432802447	1479	18	12D
0005432802453	1479	19	13D
0005432802439	1479	20	14B
0005432802445	1479	21	14C
0005432802440	1479	22	15C
0005432802455	1479	23	15B
0005432802458	1479	24	16E
0005432802436	1479	25	17B
0005432802459	1479	26	17A
0005432802467	1479	27	17D
0005432802442	1479	28	17E
0005432802452	1479	29	19C
0005432802441	1479	30	20E
0005432802444	1479	31	21A
0005432802463	1479	32	21C
0005432802451	1479	33	21F
0005435852545	23867	1	2A
0005433475636	23867	2	2B
0005435852551	23867	3	2D
0005435852547	23867	4	3A
0005433475632	23867	5	3C
0005435852552	23867	6	5C
0005435852544	23867	7	6C
0005433475633	23867	8	7A
0005435852548	23867	9	7B
0005435852549	23867	10	19A
0005435852546	23867	11	19B
0005435852550	23867	12	21B
0005432525807	30598	1	1D
0005435212970	30598	2	1C
0005432525686	30598	3	1A
0005432525926	30598	4	1K
0005435725558	30598	5	1H
0005432525762	30598	6	2A
0005432526039	30598	7	2H
0005435212969	30598	8	2K
0005435212964	30598	9	3G
0005434066432	30598	10	3D
0005432526276	30598	11	3C
0005435213005	30598	12	3K
0005435212958	30598	13	3H
0005432525975	30598	14	4A
0005432526838	30598	15	4G
0005432525991	30598	16	4H
0005432525900	30598	17	5G
0005435212977	30598	18	11A
0005432535763	30598	19	5K
0005432525822	30598	20	5H
0005434066438	30598	21	11F
0005432526297	30598	22	11E
0005432525918	30598	23	11K
0005432526162	30598	24	12C
0005432525806	30598	25	12A
0005435212994	30598	26	12E
0005435212985	30598	27	12D
0005432159820	30598	28	12F
0005432525880	30598	29	13A
0005432525821	30598	30	12K
0005434066369	30598	31	12H
0005435213004	30598	32	13D
0005432525964	30598	33	13C
0005432526003	30598	34	13F
0005432525925	30598	35	13H
0005435213002	30598	36	13G
0005432525878	30598	37	14A
0005435213003	30598	38	13K
0005432525647	30598	39	14C
0005432525764	30598	40	14F
0005435630943	30598	41	14G
0005432525737	30598	42	15A
0005434066320	30598	43	15F
0005435212992	30598	44	15E
0005432525768	30598	45	15H
0005435212989	30598	46	15G
0005432526165	30598	47	16A
0005432525852	30598	48	16D
0005432525999	30598	49	16F
0005432525790	30598	50	16E
0005432526224	30598	51	16K
0005435213019	30598	52	16H
0005434066346	30598	53	16G
0005435213015	30598	54	17C
0005434066352	30598	55	17G
0005435212965	30598	56	17F
0005432211437	30598	57	17E
0005435212981	30598	58	17K
0005432525733	30598	59	17H
0005432526208	30598	60	18C
0005432525879	30598	61	18E
0005432526013	30598	62	18D
0005435213008	30598	63	18H
0005435213007	30598	64	18J
0005434066491	30598	65	19A
0005432525919	30598	66	19D
0005432525815	30598	67	19C
0005435212973	30598	68	19F
0005435212962	30598	69	19E
0005435212995	30598	70	19G
0005432525789	30598	71	19K
0005435213010	30598	72	20C
0005432526199	30598	73	20B
0005435212999	30598	74	20E
0005432525715	30598	75	20G
0005432211441	30598	76	20F
0005435212974	30598	77	20K
0005435212986	30598	78	21A
0005432525973	30598	79	21D
0005432526146	30598	80	21C
0005432525966	30598	81	21F
0005432526079	30598	82	21H
0005432525986	30598	83	21K
0005433656643	30598	84	21J
0005434066468	30598	85	22B
0005432211440	30598	86	22G
0005433656644	30598	87	22K
0005432525931	30598	88	22J
0005432525913	30598	89	23B
0005434066387	30598	90	23F
0005435212956	30598	91	23J
0005435213012	30598	92	23G
0005435212963	30598	93	24D
0005432526083	30598	94	23K
0005435213000	30598	95	24F
0005434066449	30598	96	24E
0005435212959	30598	97	24G
0005432525873	30598	98	25D
0005435212990	30598	99	25C
0005432525805	30598	100	25B
0005432525965	30598	101	25F
0005432526000	30598	102	25K
0005432525892	30598	103	26C
0005432526145	30598	104	26A
0005432535765	30598	105	26E
0005435212967	30598	106	26D
0005432535749	30598	107	26G
0005435213017	30598	108	26F
0005432525717	30598	109	26H
0005435212984	30598	110	27D
0005432525984	30598	111	27F
0005432525985	30598	112	27E
0005432526557	30598	113	27J
0005432525666	30598	114	28C
0005434066309	30598	115	28B
0005432211438	30598	116	28A
0005435212979	30598	117	28E
0005432525710	30598	118	28G
0005432526839	30598	119	28F
0005432526257	30598	120	28H
0005435725560	30598	121	29B
0005432525667	30598	122	29A
0005435212982	30598	123	29D
0005434066410	30598	124	29F
0005432525700	30598	125	29E
0005432526084	30598	126	29H
0005432525714	30598	127	29J
0005432525699	30598	128	30E
0005432525868	30598	129	30D
0005432211439	30598	130	30G
0005432525869	30598	131	30J
0005435212998	30598	132	31B
0005434066504	30598	133	31D
0005432525908	30598	134	31C
0005434066388	30598	135	31F
0005435213016	30598	136	31H
0005435213006	30598	137	32A
0005434066303	30598	138	31K
0005432525824	30598	139	32E
0005432525765	30598	140	32D
0005435213013	30598	141	32J
0005435212954	30598	142	33A
0005435213011	30598	143	33D
0005432525838	30598	144	33C
0005434066413	30598	145	33F
0005432526014	30598	146	33E
0005434066548	30598	147	33H
0005435213001	30598	148	34A
0005432526288	30598	149	33K
0005435212955	30598	150	34B
0005435212960	30598	151	34E
0005432533240	30598	152	34D
0005432525788	30598	153	34C
0005432526428	30598	154	34G
0005434066653	30598	155	34F
0005435212957	30598	156	35A
0005435212971	30598	157	35D
0005435725561	30598	158	35E
0005432526005	30598	159	35J
0005432525907	30598	160	35K
0005434066295	30598	161	36C
0005435212997	30598	162	36A
0005432525950	30598	163	36E
0005432526075	30598	164	36D
0005432535750	30598	165	36G
0005435213020	30598	166	36F
0005432526002	30598	167	36J
0005432525848	30598	168	37D
0005435212988	30598	169	37C
0005432525755	30598	170	37G
0005434066368	30598	171	37F
0005434066345	30598	172	37E
0005435212983	30598	173	37H
0005434066430	30598	174	37K
0005434066342	30598	175	38B
0005432525836	30598	176	38K
0005432211436	30598	177	38J
0005434066318	30598	178	38H
0005432525819	30598	179	39D
0005435212991	30598	180	39C
0005432535762	30598	181	39B
0005432525948	30598	182	39F
0005432525976	30598	183	39E
0005432526004	30598	184	39G
0005432526023	30598	185	39K
0005432525736	30598	186	40C
0005432159818	30598	187	40B
0005435213014	30598	188	40A
0005432526001	30598	189	40F
0005435212993	30598	190	40E
0005432525917	30598	191	40D
0005435630942	30598	192	40G
0005432525990	30598	193	40K
0005435725559	30598	194	40J
0005432526213	30598	195	40H
0005432535757	30598	196	41D
0005432525750	30598	197	41F
0005432525853	30598	198	41H
0005435213018	30598	199	42A
0005432525751	30598	200	41K
0005434066317	30598	201	42C
0005434066412	30598	202	42B
0005432525932	30598	203	42D
0005432525818	30598	204	42G
0005434066341	30598	205	42K
0005432525837	30598	206	42H
0005434066439	30598	207	43A
0005432526030	30598	208	43D
0005432526368	30598	209	43C
0005432526563	30598	210	43B
0005432526315	30598	211	43F
0005434066761	30598	212	43E
0005432525756	30598	213	44C
0005435630941	30598	214	44D
0005435212953	30598	215	44G
0005435212978	30598	216	44J
0005435212987	30598	217	45B
0005434066296	30598	218	45C
0005432525899	30598	219	45F
0005432525646	30598	220	45D
0005432525884	30598	221	45J
0005435213009	30598	222	46A
0005432525816	30598	223	46E
0005435212996	30598	224	46D
0005434066450	30598	225	46G
0005432535764	30598	226	46F
0005435212966	30598	227	46K
0005435212976	30598	228	46J
0005435725557	30598	229	46H
0005433656642	30598	230	47C
0005432525823	30598	231	47A
0005432525683	30598	232	47E
0005432535756	30598	233	47D
0005434066319	30598	234	47G
0005432526427	30598	235	47F
0005435212980	30598	236	47K
0005432526031	30598	237	47H
0005435212972	30598	238	48D
0005432159819	30598	239	48C
0005432526131	30598	240	48F
0005435212961	30598	241	48E
0005434066579	30598	242	48H
0005432525888	30598	243	48G
0005432525943	30598	244	48K
0005432526009	30598	245	49E
0005432525749	30598	246	49D
0005434066340	30598	247	49G
0005432525947	30598	248	49H
0005435212968	30598	249	50E
0005435212975	30598	250	50G
0005434066411	30598	251	50F
0005432525914	30598	252	50K
0005435212952	30598	253	51F
0005432525716	30598	254	51E
0005434066503	30598	255	51G
0005433367575	24858	1	1A
0005435652328	24858	2	1C
0005433367580	24858	3	1D
0005433367579	24858	4	1F
0005435652327	24858	5	2A
0005435652289	24858	6	2D
0005435652262	24858	7	2F
0005433367590	24858	8	3A
0005435652263	24858	9	3F
0005433367568	24858	10	4D
0005433367594	24858	11	4E
0005433367587	24858	12	4F
0005433367601	24858	13	5A
0005435652356	24858	14	5D
0005433367577	24858	15	5F
0005435652290	24858	16	6D
0005433367566	24858	17	6E
0005435652374	24858	18	6F
0005433367586	24858	19	7C
0005435652345	24858	20	7E
0005433367581	24858	21	7F
0005433367578	24858	22	8A
0005433367596	24858	23	8E
0005433367569	24858	24	9E
0005433367600	24858	25	9F
0005433367570	24858	26	10C
0005435652271	24858	27	10D
0005435652279	24858	28	10E
0005435652295	24858	29	10F
0005435652254	24858	30	11A
0005435652323	24858	31	11C
0005435652355	24858	32	11E
0005435652273	24858	33	11F
0005433367565	24858	34	12A
0005435652373	24858	35	12E
0005433367582	24858	36	12F
0005435652272	24858	37	13A
0005435652354	24858	38	13E
0005435652274	24858	39	14A
0005433367584	24858	40	14C
0005433367593	24858	41	14D
0005433367591	24858	42	14F
0005433367567	24858	43	15A
0005433367598	24858	44	15C
0005433367585	24858	45	15D
0005433367564	24858	46	15E
0005433367592	24858	47	15F
0005433367573	24858	48	16C
0005433367574	24858	49	16D
0005433367589	24858	50	17A
0005433367588	24858	51	17C
0005433367576	24858	52	17D
0005433367571	24858	53	18A
0005433367599	24858	54	18C
0005433367583	24858	55	19A
0005433367572	24858	56	19C
0005435652280	24858	57	19F
0005433367597	24858	58	19E
0005433367595	24858	59	20C
0005434979546	2034	1	1A
0005434979555	2034	2	1B
0005434979557	2034	3	1C
0005434979539	2034	4	1D
0005435801671	2034	5	2A
0005434979556	2034	6	2B
0005435801669	2034	7	3A
0005434979530	2034	8	3B
0005434979542	2034	9	3C
0005434979554	2034	10	4A
0005434979529	2034	11	4C
0005434979549	2034	12	5A
0005434979548	2034	13	5B
0005434979538	2034	14	6A
0005434979536	2034	15	6B
0005434979550	2034	16	6C
0005434979553	2034	17	6D
0005434979537	2034	18	7A
0005434979543	2034	19	7D
0005434979532	2034	20	18A
0005434979551	2034	21	18B
0005434979558	2034	22	18C
0005434979552	2034	23	18D
0005434979547	2034	24	19A
0005434979544	2034	25	19C
0005434979531	2034	26	19D
0005434979533	2034	27	20B
0005434979535	2034	28	20C
0005434979545	2034	29	20D
0005434979541	2034	30	21B
0005434979559	2034	31	21A
0005435801670	2034	32	21C
0005434979534	2034	33	21D
0005434979540	2034	34	23A
0005434979313	23561	1	1A
0005435801646	23561	2	1C
0005434979301	23561	3	2D
0005434979325	23561	4	5A
0005434979300	23561	5	7B
0005434979298	23561	6	18A
0005434979396	23561	7	19C
0005434979296	23561	8	21C
0005435801643	23561	9	22A
0005434979297	23561	10	22C
0005434952499	2560	1	2B
0005434952501	2560	2	4B
0005434952500	2560	3	5A
0005433256403	28297	1	2A
0005433256404	28297	2	3A
0005434952471	28297	3	3B
0005433256402	28297	4	5B
0005434952472	28297	5	6B
0005433111489	19802	1	2B
0005433112362	19802	2	5A
0005434136732	11945	1	1C
0005434136708	11945	2	1D
0005434136693	11945	3	2A
0005434136707	11945	4	2D
0005434136763	11945	5	2F
0005434136830	11945	6	3A
0005434136792	11945	7	3D
0005434136879	11945	8	4C
0005434136714	11945	9	4E
0005434136710	11945	10	5A
0005434136799	11945	11	5C
0005434136924	11945	12	5D
0005434136930	11945	13	5E
0005434136771	11945	14	5F
0005434136704	11945	15	6C
0005434136867	11945	16	6D
0005434136703	11945	17	6E
0005434136797	11945	18	6F
0005434136711	11945	19	7A
0005434136756	11945	20	7C
0005434136731	11945	21	7D
0005434136712	11945	22	7E
0005434136815	11945	23	8D
0005434136841	11945	24	8E
0005434136745	11945	25	8F
0005434136916	11945	26	9C
0005434136866	11945	27	9F
0005434136835	11945	28	10C
0005434136691	11945	29	10D
0005434136681	11945	30	11A
0005434136746	11945	31	11C
0005434136915	11945	32	11D
0005434136692	11945	33	11E
0005434136791	11945	34	12C
0005434136834	11945	35	12D
0005434136747	11945	36	12F
0005434136878	11945	37	13A
0005434136929	11945	38	13C
0005434136786	11945	39	14A
0005434136925	11945	40	14D
0005434136785	11945	41	14F
0005434136839	11945	42	15A
0005434136880	11945	43	15C
0005434136752	11945	44	15E
0005434136905	11945	45	15F
0005434136735	11945	46	16A
0005434136904	11945	47	16C
0005434136702	11945	48	16D
0005434136816	11945	49	16E
0005434136744	11945	50	17A
0005434136793	11945	51	17C
0005434136919	11945	52	17E
0005434136727	11945	53	18A
0005434136734	11945	54	18C
0005434136906	11945	55	18D
0005434136885	11945	56	19E
0005434136713	11945	57	20A
0005434136819	11945	58	20F
0005434137431	28746	1	1A
0005434137445	28746	2	1C
0005434137393	28746	3	1D
0005434137416	28746	4	1F
0005434137376	28746	5	2A
0005434137365	28746	6	2C
0005434137444	28746	7	2D
0005434137396	28746	8	2F
0005434137424	28746	9	3A
0005434137357	28746	10	3C
0005434137437	28746	11	3D
0005434137388	28746	12	3F
0005434137411	28746	13	4A
0005434137441	28746	14	4C
0005434137443	28746	15	4D
0005434137363	28746	16	4E
0005434137362	28746	17	5A
0005434137403	28746	18	4F
0005434137422	28746	19	5C
0005434137375	28746	20	5E
0005434137420	28746	21	5F
0005434137386	28746	22	6A
0005434137436	28746	23	6C
0005434137428	28746	24	6D
0005434137370	28746	25	6E
0005434137369	28746	26	6F
0005434137359	28746	27	7A
0005434137373	28746	28	7C
0005434137361	28746	29	7D
0005434137380	28746	30	7E
0005434137387	28746	31	7F
0005434137413	28746	32	8A
0005434137425	28746	33	8C
0005434137417	28746	34	8D
0005434137430	28746	35	8E
0005434137368	28746	36	9C
0005434137405	28746	37	9E
0005434137397	28746	38	9F
0005434137383	28746	39	10A
0005434137377	28746	40	10C
0005434137390	28746	41	10D
0005434137366	28746	42	10E
0005434137433	28746	43	11A
0005434137395	28746	44	11C
0005434137371	28746	45	11D
0005434137414	28746	46	11E
0005434137398	28746	47	11F
0005434137429	28746	48	12A
0005434137381	28746	49	12C
0005434137435	28746	50	12D
0005434137372	28746	51	12E
0005434137360	28746	52	13A
0005434137434	28746	53	13C
0005434137440	28746	54	13D
0005434137358	28746	55	13E
0005434137401	28746	56	14A
0005434137404	28746	57	14C
0005434137432	28746	58	14D
0005434137402	28746	59	14E
0005434137415	28746	60	14F
0005434137439	28746	61	15A
0005434137408	28746	62	15C
0005434137438	28746	63	15D
0005434137400	28746	64	15E
0005434137410	28746	65	15F
0005434137378	28746	66	16A
0005434137412	28746	67	16C
0005434137394	28746	68	16D
0005434137418	28746	69	16F
0005434137391	28746	70	16E
0005434137385	28746	71	17A
0005434137379	28746	72	17C
0005434137442	28746	73	17D
0005434137399	28746	74	17E
0005434137409	28746	75	17F
0005434137382	28746	76	18C
0005434137426	28746	77	18D
0005434137384	28746	78	18E
0005434137367	28746	79	18F
0005434137407	28746	80	19A
0005434137392	28746	81	19C
0005434137423	28746	82	19D
0005434137364	28746	83	19E
0005434137419	28746	84	19F
0005434137374	28746	85	20A
0005434137421	28746	86	20C
0005434137406	28746	87	20D
0005434137427	28746	88	20E
0005434137389	28746	89	20F
0005434466425	6566	1	1B
0005434466423	6566	2	2B
0005434466422	6566	3	3A
0005434466416	6566	4	3B
0005434466411	6566	5	3C
0005435312765	6566	6	3D
0005434466420	6566	7	4A
0005434466409	6566	8	4C
0005434466419	6566	9	5A
0005434466413	6566	10	6A
0005434466414	6566	11	7D
0005434466410	6566	12	18D
0005434466417	6566	13	19B
0005434466415	6566	14	19C
0005435312766	6566	15	20A
0005434466424	6566	16	20B
0005434466412	6566	17	20D
0005434466421	6566	18	22B
0005435312769	6566	19	22D
0005434466418	6566	20	23B
0005433534481	6823	1	2C
0005433538800	6823	2	3C
0005433538798	6823	3	4D
0005433538799	6823	4	6B
0005435259680	6823	5	6C
0005433538796	6823	6	6D
0005433538803	6823	7	7C
0005433538797	6823	8	19B
0005433538801	6823	9	20A
0005433538795	6823	10	20D
0005433538802	6823	11	22A
0005435259679	6823	12	22D
0005433538720	25034	1	1A
0005435259720	25034	2	1C
0005435259718	25034	3	3A
0005435259722	25034	4	3D
0005433538721	25034	5	4A
0005433534465	25034	6	4C
0005435259723	25034	7	4D
0005433534464	25034	8	6C
0005433538739	25034	9	7D
0005433538740	25034	10	18A
0005433534468	25034	11	18B
0005435259719	25034	12	18D
0005435259721	25034	13	19A
0005433538735	25034	14	20A
0005433534466	25034	15	20D
0005433538734	25034	16	21A
0005433538738	25034	17	22B
0005433534467	25034	18	22C
0005433538736	25034	19	22D
0005433511883	838	1	3D
0005432922459	838	2	4B
0005433511884	838	3	4C
0005433511878	838	4	5C
0005433511885	838	5	6B
0005432922457	838	6	6D
0005432922458	838	7	7A
0005433511886	838	8	7B
0005433511879	838	9	19A
0005433511882	838	10	20B
0005433511881	838	11	21D
0005433511880	838	12	22C
0005432922491	16131	1	1B
0005433511837	16131	2	1C
0005433511802	16131	3	2A
0005433511803	16131	4	3D
0005433511809	16131	5	4A
0005433511838	16131	6	4D
0005433511808	16131	7	5B
0005432922490	16131	8	5C
0005433511840	16131	9	5D
0005432922492	16131	10	7B
0005433511804	16131	11	7D
0005433511828	16131	12	18D
0005432922493	16131	13	20B
0005433511836	16131	14	21B
0005433511824	16131	15	23A
0005433511825	16131	16	23B
0005433475672	4038	1	1A
0005433475670	4038	2	1C
0005433475668	4038	3	3B
0005433475669	4038	4	5D
0005433475666	4038	5	6B
0005433475667	4038	6	19A
0005435852525	4038	7	19B
0005435852530	4038	8	20B
0005433475671	4038	9	20A
0005435852528	4038	10	22A
0005433475673	4038	11	22C
0005435697115	3674	1	1C
0005434950491	3674	2	1D
0005435934995	3674	3	2A
0005435697111	3674	4	2B
0005435697119	3674	5	2C
0005435697103	3674	6	2D
0005435697110	3674	7	3A
0005435697120	3674	8	3B
0005435697106	3674	9	3C
0005435697126	3674	10	4A
0005435697122	3674	11	3D
0005434950492	3674	12	4B
0005435697116	3674	13	4D
0005435697109	3674	14	5A
0005435697112	3674	15	5B
0005435697117	3674	16	5C
0005435934994	3674	17	6C
0005435697118	3674	18	6D
0005435697104	3674	19	7A
0005435697107	3674	20	7B
0005435697102	3674	21	7D
0005435697114	3674	22	18A
0005435934996	3674	23	18B
0005435697125	3674	24	18C
0005435697121	3674	25	18D
0005435697124	3674	26	19B
0005435697128	3674	27	19C
0005435697123	3674	28	19D
0005434950494	3674	29	20B
0005435697108	3674	30	20C
0005435697130	3674	31	20D
0005434950493	3674	32	21A
0005434950490	3674	33	21B
0005435697129	3674	34	21C
0005435697113	3674	35	22B
0005435697127	3674	36	22C
0005435697105	3674	37	23A
0005435916144	16284	1	1D
0005435696896	16284	2	2A
0005435696898	16284	3	2B
0005435696940	16284	4	2C
0005435696897	16284	5	2D
0005435696883	16284	6	3B
0005435696854	16284	7	4C
0005435696882	16284	8	4D
0005435696870	16284	9	6B
0005435696864	16284	10	6C
0005435916145	16284	11	7A
0005435935016	16284	12	7B
0005435696857	16284	13	7C
0005435935017	16284	14	7D
0005435696877	16284	15	18A
0005435696889	16284	16	18C
0005435696876	16284	17	18D
0005435697058	16284	18	19A
0005435696894	16284	19	19D
0005434950469	16284	20	20B
0005435696865	16284	21	20C
0005435696881	16284	22	20D
0005435696858	16284	23	21A
0005435696855	16284	24	21B
0005435916143	16284	25	21D
0005435696859	16284	26	22D
0005435696871	16284	27	23A
0005435696853	16284	28	23B
0005434606800	3963	1	1B
0005434604869	3963	2	1D
0005433519421	3963	3	2A
0005434604870	3963	4	2C
0005432609698	3963	5	2D
0005433519422	3963	6	3C
0005432609700	3963	7	3D
0005435853584	3963	8	4B
0005432609699	3963	9	4C
0005432607532	3963	10	4D
0005435853580	3963	11	6B
0005435853583	3963	12	7A
0005432609697	3963	13	19A
0005433519419	3963	14	19B
0005435841462	3963	15	19C
0005432607533	3963	16	19D
0005432607534	3963	17	20A
0005435853579	3963	18	20B
0005433519420	3963	19	20C
0005434606799	3963	20	20D
0005435842311	3963	21	21B
0005434606798	3963	22	21D
0005432609701	3963	23	22C
0005434606801	3963	24	22D
0005432607531	3963	25	23B
0005433519399	22045	1	1C
0005435853597	22045	2	2A
0005433519385	22045	3	2C
0005435853596	22045	4	3A
0005433519380	22045	5	4D
0005433519391	22045	6	6C
0005435853594	22045	7	6D
0005433519397	22045	8	18B
0005434606760	22045	9	19B
0005433519398	22045	10	19C
0005435904890	22045	11	20D
0005434606759	22045	12	21D
0005435904891	22045	13	22B
0005433519384	22045	14	23A
0005435853595	22045	15	23B
0005435628703	774	1	1A
0005433348892	774	2	1B
0005433348912	774	3	2B
0005433348904	774	4	3A
0005433348905	774	5	3B
0005435628701	774	6	4B
0005433348897	774	7	5B
0005435628702	774	8	6A
0005435628700	774	9	6B
0005433348946	15961	1	1A
0005433348943	15961	2	2B
0005433348942	15961	3	3B
0005433348945	15961	4	6A
0005433348944	15961	5	6B
0005434446500	17147	1	1A
0005434446499	17147	2	1B
0005433158099	17147	3	2B
0005433159274	17147	4	3A
0005434446498	17147	5	4A
0005434445225	17147	6	4B
0005434445224	17147	7	6A
0005434445211	17599	1	1A
0005433159296	17599	2	4B
0005433159297	17599	3	5B
0005434445212	17599	4	6A
0005435132794	7870	1	1A
0005435383073	7870	2	1B
0005435132796	7870	3	3C
0005435132797	7870	4	4A
0005435383069	7870	5	4D
0005435132799	7870	6	5A
0005435132798	7870	7	6A
0005435383067	7870	8	6D
0005435132800	7870	9	7A
0005435132795	7870	10	7B
0005435132793	7870	11	7D
0005435132801	7870	12	19A
0005435383068	7870	13	19B
0005435383070	7870	14	20D
0005435132792	7870	15	21A
0005435383105	33064	1	1C
0005435132755	33064	2	2A
0005435383109	33064	3	3A
0005435132711	33064	4	4C
0005435383104	33064	5	5A
0005435132712	33064	6	5C
0005435132697	33064	7	6B
0005435383107	33064	8	7A
0005435383108	33064	9	7D
0005435132718	33064	10	18C
0005435383106	33064	11	19B
0005435132717	33064	12	19C
0005435132725	33064	13	20C
0005435132696	33064	14	20D
0005435132721	33064	15	21B
0005435390132	7485	1	2C
0005435160213	7485	2	2D
0005435160206	7485	3	3B
0005435160211	7485	4	3D
0005435160210	7485	5	4C
0005435160209	7485	6	5B
0005435160215	7485	7	6C
0005435160214	7485	8	7D
0005435160216	7485	9	19A
0005435160207	7485	10	20A
0005435390145	7485	11	21A
0005435160212	7485	12	21C
0005435160208	7485	13	22B
0005435160217	7485	14	22D
0005435390186	29538	1	2B
0005435160157	29538	2	3D
0005435160125	29538	3	4C
0005435160114	29538	4	4D
0005435160181	29538	5	5B
0005435160108	29538	6	6C
0005435390182	29538	7	7A
0005435390188	29538	8	18A
0005435160106	29538	9	18C
0005435160112	29538	10	18D
0005435390187	29538	11	19C
0005435390185	29538	12	19D
0005435160107	29538	13	20A
0005435390184	29538	14	21A
0005435160132	29538	15	21B
0005435390183	29538	16	23B
0005435178483	18436	1	1A
0005432394034	18436	2	2A
0005435178482	18436	3	2B
0005432398135	18436	4	3A
0005432394045	18436	5	3B
0005432394041	18436	6	4A
0005432398131	18436	7	4B
0005432398142	18436	8	5A
0005432394046	18436	9	6A
0005432394042	18436	10	5B
0005432394044	18436	11	6B
0005432400095	27171	1	1A
0005432398164	27171	2	1B
0005432400093	27171	3	2B
0005435178469	27171	4	3B
0005432398162	27171	5	4A
0005432398163	27171	6	4B
0005432400094	27171	7	5B
0005432400092	27171	8	6B
0005432400091	27171	9	6A
0005432639039	2239	1	2A
0005432865906	2239	2	3C
0005432639033	2239	3	3F
0005432639019	2239	4	4F
0005432639036	2239	5	5C
0005432639038	2239	6	5D
0005432865896	2239	7	6A
0005432639035	2239	8	6C
0005432639016	2239	9	6E
0005432865905	2239	10	7D
0005432639015	2239	11	7E
0005432639022	2239	12	8C
0005432865895	2239	13	8E
0005432639037	2239	14	9A
0005432639018	2239	15	9C
0005432639023	2239	16	9D
0005432639009	2239	17	9F
0005432639010	2239	18	10C
0005432639014	2239	19	10D
0005432639032	2239	20	10E
0005432639012	2239	21	10F
0005432639005	2239	22	11C
0005432639041	2239	23	12D
0005432639021	2239	24	13A
0005432639008	2239	25	13D
0005432639024	2239	26	13E
0005432639029	2239	27	13F
0005432639026	2239	28	14A
0005432639006	2239	29	14C
0005432639034	2239	30	15C
0005432639017	2239	31	15D
0005432639013	2239	32	16E
0005432639027	2239	33	16F
0005432639025	2239	34	17A
0005432865897	2239	35	18C
0005432639028	2239	36	18D
0005432639030	2239	37	18F
0005432639007	2239	38	19A
0005432639031	2239	39	19C
0005432639040	2239	40	19E
0005432639020	2239	41	19F
0005432639011	2239	42	20A
0005434503829	6550	1	1A
0005434503824	6550	2	1C
0005434503839	6550	3	1F
0005434503852	6550	4	2A
0005434503832	6550	5	2C
0005435103873	6550	6	3C
0005435103874	6550	7	3D
0005434503857	6550	8	4A
0005434503836	6550	9	4C
0005435103868	6550	10	4D
0005434503837	6550	11	4E
0005434503828	6550	12	4F
0005434503858	6550	13	5A
0005434503851	6550	14	5C
0005435103875	6550	15	5E
0005435103869	6550	16	5F
0005434503843	6550	17	6D
0005435103877	6550	18	6E
0005434503860	6550	19	6F
0005435103871	6550	20	7C
0005434503854	6550	21	7D
0005434503842	6550	22	8A
0005434503856	6550	23	8F
0005434503826	6550	24	9A
0005434503841	6550	25	9C
0005434503859	6550	26	9E
0005434503834	6550	27	10A
0005434503840	6550	28	10D
0005434503846	6550	29	11A
0005434503849	6550	30	11C
0005434503830	6550	31	11F
0005434503853	6550	32	12C
0005434503825	6550	33	12D
0005434503838	6550	34	13C
0005434503844	6550	35	13D
0005434503827	6550	36	13F
0005434503847	6550	37	14A
0005435103876	6550	38	15C
0005435103867	6550	39	16D
0005435103872	6550	40	16E
0005434503861	6550	41	17E
0005434503823	6550	42	17F
0005434503850	6550	43	18A
0005434503835	6550	44	18C
0005434503831	6550	45	18D
0005434503862	6550	46	19A
0005434503833	6550	47	19D
0005435103870	6550	48	19E
0005434503855	6550	49	19F
0005434503848	6550	50	20A
0005434503845	6550	51	20E
0005434503530	22690	1	1A
0005434503526	22690	2	5E
0005434503496	22690	3	6C
0005434503529	22690	4	14E
0005434503654	22690	5	20A
0005434503575	22690	6	20C
0005435800087	6424	1	1A
0005435800085	6424	2	1D
0005435800095	6424	3	3A
0005435800092	6424	4	3B
0005435800084	6424	5	4A
0005435800090	6424	6	4D
0005435800091	6424	7	5A
0005435800096	6424	8	5B
0005435800093	6424	9	5C
0005435800088	6424	10	6A
0005435800089	6424	11	6D
0005435800086	6424	12	18A
0005435800097	6424	13	18B
0005435800083	6424	14	20D
0005435800082	6424	15	21D
0005435800094	6424	16	22C
0005435652703	1687	1	1A
0005433367266	1687	2	1C
0005435652695	1687	3	2A
0005435652682	1687	4	2C
0005435652681	1687	5	2D
0005433367264	1687	6	2F
0005433367471	1687	7	3A
0005435652701	1687	8	3C
0005435652674	1687	9	3D
0005435652676	1687	10	3F
0005435652671	1687	11	4A
0005435652692	1687	12	4C
0005435652680	1687	13	4E
0005433367297	1687	14	4F
0005435652690	1687	15	5A
0005435652730	1687	16	5D
0005435652673	1687	17	5E
0005435652729	1687	18	5F
0005435652697	1687	19	6A
0005435652718	1687	20	6C
0005435652678	1687	21	6D
0005435652710	1687	22	6E
0005433367370	1687	23	6F
0005435652677	1687	24	7A
0005435652711	1687	25	7D
0005433367286	1687	26	7E
0005435652721	1687	27	7F
0005435652704	1687	28	8A
0005433367243	1687	29	8C
0005435652688	1687	30	8D
0005435652714	1687	31	8F
0005433367371	1687	32	9C
0005435652709	1687	33	9D
0005433367337	1687	34	9F
0005433367406	1687	35	10A
0005433367377	1687	36	10C
0005435652700	1687	37	10D
0005435652706	1687	38	10F
0005433367298	1687	39	11A
0005433367227	1687	40	11C
0005435652696	1687	41	11D
0005435652725	1687	42	11E
0005435652724	1687	43	11F
0005435652689	1687	44	12A
0005435652693	1687	45	12C
0005435652719	1687	46	12D
0005435652705	1687	47	12E
0005433367354	1687	48	12F
0005435652675	1687	49	13A
0005433367472	1687	50	13C
0005435652683	1687	51	13D
0005435652702	1687	52	13E
0005435652722	1687	53	13F
0005433367378	1687	54	14A
0005435652670	1687	55	14C
0005433367385	1687	56	14D
0005435652712	1687	57	14E
0005435652679	1687	58	14F
0005435652686	1687	59	15A
0005433367285	1687	60	15C
0005435652687	1687	61	15D
0005435652708	1687	62	15E
0005433367323	1687	63	15F
0005435652699	1687	64	16A
0005435652684	1687	65	16C
0005433367357	1687	66	16D
0005435652685	1687	67	16E
0005435652715	1687	68	16F
0005433367260	1687	69	17A
0005433367317	1687	70	17C
0005435652691	1687	71	17D
0005435652727	1687	72	17E
0005433367299	1687	73	17F
0005435652694	1687	74	18A
0005435652717	1687	75	18C
0005435652726	1687	76	18D
0005435652728	1687	77	18E
0005435652723	1687	78	18F
0005435652713	1687	79	19A
0005435652672	1687	80	19C
0005435652698	1687	81	19D
0005435652716	1687	82	19E
0005435652720	1687	83	19F
0005433367355	1687	84	20C
0005433367261	1687	85	20D
0005435652707	1687	86	20E
0005435652345	21705	1	1D
0005433367576	21705	2	1F
0005433367578	21705	3	2A
0005433367594	21705	4	2C
0005433367581	21705	5	2D
0005433367600	21705	6	2F
0005433367598	21705	7	3A
0005435652254	21705	8	3C
0005435652354	21705	9	3F
0005435652323	21705	10	4C
0005433367568	21705	11	4D
0005435652328	21705	12	4E
0005433367572	21705	13	4F
0005435652279	21705	14	5E
0005433367592	21705	15	5F
0005433367596	21705	16	6C
0005435652295	21705	17	6D
0005435652262	21705	18	6E
0005433367597	21705	19	7A
0005433367586	21705	20	7E
0005435652356	21705	21	8A
0005433367590	21705	22	8E
0005435652274	21705	23	9D
0005433367575	21705	24	9E
0005433367580	21705	25	9F
0005433367587	21705	26	10A
0005433367585	21705	27	10C
0005435652374	21705	28	10D
0005433367577	21705	29	10E
0005433367582	21705	30	10F
0005435652271	21705	31	11C
0005433367599	21705	32	11D
0005433367565	21705	33	11E
0005433367571	21705	34	11F
0005435652355	21705	35	12C
0005433367589	21705	36	12E
0005433367583	21705	37	13A
0005435652273	21705	38	13D
0005435652373	21705	39	13E
0005435652272	21705	40	13F
0005433367593	21705	41	14E
0005433367569	21705	42	14F
0005435652290	21705	43	15A
0005433367601	21705	44	15C
0005433367566	21705	45	15D
0005435652289	21705	46	15E
0005433367574	21705	47	15F
0005433367584	21705	48	16C
0005433367588	21705	49	16D
0005435652280	21705	50	16E
0005433367579	21705	51	17E
0005433367567	21705	52	17F
0005433367573	21705	53	18A
0005435652327	21705	54	18E
0005433367591	21705	55	19C
0005433367570	21705	56	19D
0005433367595	21705	57	19E
0005433367564	21705	58	20C
0005435652263	21705	59	20D
0005434466392	23239	1	1C
0005434466374	23239	2	1D
0005434466377	23239	3	3A
0005434466375	23239	4	3B
0005435312785	23239	5	3C
0005435312784	23239	6	4D
0005434466391	23239	7	5A
0005434466378	23239	8	5C
0005435312780	23239	9	6A
0005434466381	23239	10	6B
0005435312787	23239	11	6C
0005434466385	23239	12	18D
0005434466373	23239	13	19B
0005434466387	23239	14	19C
0005434466386	23239	15	20A
0005435312782	23239	16	20D
0005435312786	23239	17	21A
0005435312781	23239	18	22B
0005435312783	23239	19	23B
0005433985573	4175	1	1C
0005433985581	4175	2	1F
0005433985599	4175	3	2A
0005433985604	4175	4	2C
0005433985588	4175	5	2D
0005433985572	4175	6	2F
0005433985564	4175	7	3F
0005433985578	4175	8	4C
0005433985563	4175	9	4E
0005435788751	4175	10	5F
0005433985567	4175	11	6A
0005433985597	4175	12	6D
0005433985562	4175	13	6E
0005433985590	4175	14	7C
0005433985571	4175	15	7D
0005435788749	4175	16	7E
0005433985559	4175	17	7F
0005433985587	4175	18	8D
0005433985602	4175	19	8F
0005433985594	4175	20	9E
0005435788750	4175	21	10A
0005433985605	4175	22	10C
0005433985580	4175	23	10D
0005433985596	4175	24	11C
0005433985600	4175	25	11D
0005433985582	4175	26	11F
0005433985569	4175	27	12E
0005433985595	4175	28	12F
0005433985598	4175	29	13C
0005433985576	4175	30	13D
0005433985565	4175	31	13E
0005433985591	4175	32	14C
0005433985561	4175	33	14E
0005433985601	4175	34	14F
0005433985570	4175	35	15A
0005433985566	4175	36	15D
0005433985575	4175	37	15E
0005433985592	4175	38	15F
0005433985574	4175	39	16A
0005433985589	4175	40	16D
0005433985586	4175	41	17D
0005433985560	4175	42	18A
0005433985584	4175	43	18F
0005433985585	4175	44	19A
0005433985583	4175	45	19C
0005433985593	4175	46	19E
0005433985568	4175	47	19F
0005433985579	4175	48	20A
0005433985577	4175	49	20E
0005433985603	4175	50	20F
0005435788729	25651	1	3A
0005435788728	25651	2	5A
0005435788727	25651	3	7C
0005435788726	25651	4	9F
0005435788725	25651	5	18A
0005435720801	21271	1	2D
0005435719558	24761	1	4C
0005434509014	21313	1	2A
0005434509028	21313	2	2B
0005434509034	21313	3	2D
0005433168340	21313	4	3A
0005433168337	21313	5	5B
0005434509036	21313	6	5D
0005433168335	21313	7	6B
0005433168336	21313	8	7C
0005433168338	21313	9	18C
0005433168334	21313	10	20C
0005434509027	21313	11	21B
0005434509035	21313	12	21C
0005433168333	21313	13	21D
0005433168341	21313	14	22A
0005433168339	21313	15	23A
0005434151682	17816	1	3D
0005432666352	17816	2	3F
0005432666353	17816	3	4D
0005432869476	17816	4	6C
0005432869477	17816	5	6E
0005434151681	17816	6	6F
0005434151683	17816	7	7F
0005432869475	17816	8	8A
0005432869474	17816	9	8F
0005432655353	17816	10	9D
0005432665239	17816	11	10A
0005432657401	17816	12	12A
0005432655326	17816	13	12C
0005432655327	17816	14	13D
0005432659672	17816	15	13F
0005432869478	17816	16	14C
0005432655328	17816	17	14D
0005432655351	17816	18	15D
0005432667420	17816	19	16A
0005432666357	17816	20	16C
0005432869473	17816	21	16E
0005432665244	17816	22	17A
0005432665240	17816	23	18D
0005432666356	17816	24	18E
0005432655331	17816	25	18F
0005432665245	17816	26	20C
0005432660798	26316	1	1C
0005432667435	26316	2	1F
0005432655421	26316	3	2C
0005432655420	26316	4	4A
0005432655417	26316	5	4D
0005432655415	26316	6	4F
0005432665254	26316	7	5F
0005432655419	26316	8	6F
0005432665256	26316	9	8A
0005432659688	26316	10	8F
0005432655412	26316	11	9A
0005432655413	26316	12	9D
0005432667436	26316	13	10C
0005432655416	26316	14	10F
0005432655418	26316	15	11C
0005432657418	26316	16	13D
0005432665255	26316	17	13E
0005432659686	26316	18	13F
0005432657419	26316	19	14A
0005432667434	26316	20	15E
0005432660797	26316	21	16E
0005432665257	26316	22	16F
0005432655411	26316	23	17C
0005432655414	26316	24	18C
0005432659687	26316	25	19E
0005432657420	26316	26	20C
0005434151655	26316	27	20D
0005432655422	26316	28	20F
0005432328317	3115	1	1C
0005432328329	3115	2	1F
0005432328332	3115	3	2A
0005432328324	3115	4	2C
0005432287148	3115	5	2D
0005432328350	3115	6	2F
0005432328326	3115	7	3A
0005432328337	3115	8	3C
0005432328325	3115	9	3D
0005432328345	3115	10	4A
0005432328343	3115	11	4C
0005432328340	3115	12	4D
0005432905029	3115	13	4E
0005432328344	3115	14	5A
0005432905056	3115	15	5C
0005432328333	3115	16	5D
0005432328316	3115	17	5F
0005432328346	3115	18	6A
0005433438825	3115	19	6C
0005432328354	3115	20	6D
0005432905030	3115	21	6E
0005433438826	3115	22	6F
0005433438824	3115	23	7A
0005433438823	3115	24	7C
0005432328352	3115	25	7D
0005432328323	3115	26	8C
0005432328356	3115	27	8D
0005432328351	3115	28	8E
0005432328321	3115	29	8F
0005433438829	3115	30	9D
0005432328349	3115	31	9E
0005432328327	3115	32	9F
0005432328348	3115	33	10A
0005433438827	3115	34	10C
0005432328315	3115	35	10D
0005432328347	3115	36	10E
0005432328341	3115	37	11A
0005432328357	3115	38	12A
0005432328319	3115	39	12C
0005433438828	3115	40	12D
0005432905043	3115	41	12E
0005432328318	3115	42	12F
0005432328353	3115	43	13C
0005432328342	3115	44	13D
0005432328358	3115	45	13E
0005432328330	3115	46	14A
0005432328320	3115	47	14C
0005432287147	3115	48	14D
0005432905057	3115	49	14E
0005433438830	3115	50	15C
0005432328313	3115	51	15E
0005432328322	3115	52	15F
0005432287146	3115	53	17A
0005432328355	3115	54	17D
0005432328331	3115	55	18A
0005432328336	3115	56	18C
0005432328334	3115	57	18E
0005432905033	3115	58	18F
0005432287149	3115	59	19A
0005432328314	3115	60	19C
0005432328359	3115	61	19D
0005432287150	3115	62	19F
0005432328338	3115	63	20A
0005432328328	3115	64	20C
0005432328339	3115	65	20E
0005432328335	3115	66	20F
0005432328133	31114	1	2A
0005433438775	31114	2	2C
0005432054279	31114	3	2F
0005432327954	31114	4	3C
0005432054281	31114	5	4A
0005432327903	31114	6	5C
0005432327912	31114	7	5E
0005432327892	31114	8	6D
0005432327946	31114	9	7C
0005432327910	31114	10	8A
0005433438770	31114	11	8D
0005432327893	31114	12	8E
0005432327980	31114	13	9E
0005432905081	31114	14	11F
0005432905079	31114	15	12A
0005432327913	31114	16	13A
0005432327981	31114	17	13F
0005432328028	31114	18	14F
0005432327982	31114	19	15A
0005432327949	31114	20	16A
0005432905077	31114	21	16D
0005432328079	31114	22	16E
0005432327894	31114	23	16F
0005432905080	31114	24	17A
0005432328109	31114	25	17D
0005432905076	31114	26	19A
0005432327891	31114	27	19C
0005432905078	31114	28	19D
0005432054280	31114	29	19E
0005432327955	31114	30	19F
0005432328027	31114	31	20D
0005434309641	6187	1	1D
0005434309636	6187	2	3F
0005435999118	6187	3	3D
0005435999128	6187	4	4C
0005435296967	6187	5	4B
0005435487508	6187	6	4E
0005435999113	6187	7	5D
0005434309634	6187	8	6C
0005435487464	6187	9	6D
0005434309629	6187	10	6E
0005434309630	6187	11	7C
0005435999122	6187	12	7F
0005435999117	6187	13	7E
0005434309633	6187	14	8A
0005432146182	6187	15	8B
0005435999119	6187	16	8D
0005435296951	6187	17	8E
0005435487479	6187	18	9C
0005434309632	6187	19	9E
0005435296945	6187	20	9D
0005434309631	6187	21	9F
0005435487463	6187	22	10B
0005435487458	6187	23	12B
0005435487466	6187	24	12E
0005434309635	6187	25	12F
0005434309637	6187	26	13B
0005432146183	6187	27	13E
0005435296968	6187	28	13D
0005434309628	6187	29	14A
0005435487465	6187	30	14C
0005435999121	6187	31	15A
0005435487456	6187	32	15C
0005435487467	6187	33	15F
0005435999120	6187	34	16E
0005434309638	6187	35	17C
0005435999115	6187	36	17D
0005435487480	6187	37	17F
0005435487459	6187	38	18A
0005435999112	6187	39	18F
0005435999126	6187	40	19A
0005435999124	6187	41	19E
0005434309639	6187	42	19D
0005435487489	6187	43	20A
0005435999116	6187	44	20B
0005435999125	6187	45	20C
0005435999123	6187	46	21A
0005435999127	6187	47	20F
0005434309640	6187	48	21D
0005435296969	6187	49	21E
0005435487457	6187	50	22A
0005435487475	6187	51	22F
0005434309627	6187	52	23B
0005435999114	6187	53	23E
0005434309500	19553	1	1D
0005434309501	19553	2	2F
0005435487634	19553	3	3F
0005435487637	19553	4	4C
0005435487645	19553	5	5A
0005434309510	19553	6	5B
0005435487631	19553	7	5D
0005435487642	19553	8	5E
0005434309511	19553	9	5F
0005435487639	19553	10	6A
0005434309565	19553	11	6D
0005435297007	19553	12	7A
0005435487650	19553	13	7F
0005434309512	19553	14	8F
0005435998967	19553	15	9A
0005434309507	19553	16	9B
0005435487648	19553	17	9C
0005435998962	19553	18	9F
0005435487646	19553	19	10B
0005435998966	19553	20	10E
0005435487632	19553	21	10D
0005435998976	19553	22	11E
0005434309570	19553	23	12A
0005435487644	19553	24	12D
0005434309518	19553	25	12C
0005434309513	19553	26	12E
0005435297000	19553	27	13D
0005435487651	19553	28	14C
0005435297006	19553	29	14B
0005435487649	19553	30	14E
0005435487641	19553	31	14F
0005434309548	19553	32	15C
0005435487635	19553	33	15E
0005435487643	19553	34	15F
0005434309566	19553	35	16F
0005435487640	19553	36	17B
0005435297003	19553	37	17C
0005435487652	19553	38	17D
0005434309519	19553	39	17F
0005435297002	19553	40	18B
0005435297001	19553	41	18E
0005435487647	19553	42	19A
0005435297004	19553	43	18F
0005434309504	19553	44	20A
0005435487638	19553	45	20D
0005434309517	19553	46	21B
0005435487633	19553	47	22B
0005435297005	19553	48	22C
0005435487636	19553	49	22D
0005435998969	19553	50	23F
0005433158115	17542	1	3A
0005434446482	17542	2	4A
0005433158112	17542	3	6B
0005433158114	17542	4	21A
0005434446483	17542	5	21C
0005433158113	17542	6	23A
0005435517771	1549	1	1A
0005432291910	1549	2	1C
0005435502149	1549	3	1D
0005434565805	1549	4	1F
0005435508268	1549	5	2F
0005435508272	1549	6	3A
0005435502135	1549	7	3C
0005435502151	1549	8	3D
0005433185974	1549	9	3F
0005433185988	1549	10	4A
0005435508273	1549	11	4C
0005435502152	1549	12	4D
0005435502133	1549	13	4F
0005433185975	1549	14	5A
0005434565811	1549	15	5C
0005435508270	1549	16	5D
0005433185973	1549	17	5E
0005435508269	1549	18	5F
0005433185977	1549	19	6A
0005434565810	1549	20	6E
0005435517770	1549	21	6F
0005435517769	1549	22	7A
0005435517766	1549	23	7C
0005435502142	1549	24	7D
0005435508274	1549	25	7E
0005434565814	1549	26	7F
0005435517774	1549	27	8A
0005434565809	1549	28	8C
0005434565803	1549	29	8D
0005433185969	1549	30	8E
0005435502138	1549	31	8F
0005435502141	1549	32	9A
0005435502132	1549	33	9C
0005435502150	1549	34	9F
0005435502144	1549	35	10A
0005435502146	1549	36	10C
0005433185982	1549	37	10D
0005435508267	1549	38	10F
0005434565812	1549	39	11C
0005435517772	1549	40	11D
0005435502143	1549	41	11E
0005433185987	1549	42	11F
0005435502148	1549	43	12A
0005434565801	1549	44	12C
0005435502137	1549	45	12D
0005434565802	1549	46	13D
0005435502140	1549	47	13E
0005435502139	1549	48	13F
0005434565804	1549	49	14A
0005435517777	1549	50	14C
0005433185983	1549	51	14D
0005435508266	1549	52	14E
0005434565807	1549	53	14F
0005434565808	1549	54	15C
0005435502136	1549	55	15E
0005435502147	1549	56	16A
0005433185979	1549	57	16C
0005435517775	1549	58	17A
0005435502145	1549	59	16F
0005433186005	1549	60	17C
0005435502134	1549	61	17E
0005433185972	1549	62	17F
0005435517767	1549	63	18A
0005434565806	1549	64	18C
0005433185984	1549	65	18D
0005435508271	1549	66	18E
0005434565813	1549	67	18F
0005435508275	1549	68	19A
0005435517768	1549	69	19D
0005435517773	1549	70	19E
0005432291911	1549	71	19F
0005435517776	1549	72	20C
0005433185978	1549	73	20D
0005435501937	20864	1	1C
0005435528897	20864	2	1D
0005435528939	20864	3	2A
0005435501935	20864	4	2C
0005433186050	20864	5	2D
0005434565723	20864	6	2F
0005435501947	20864	7	4A
0005435528885	20864	8	4D
0005434565710	20864	9	5D
0005435501948	20864	10	5E
0005433186049	20864	11	5F
0005435528886	20864	12	7C
0005435528938	20864	13	8C
0005435501965	20864	14	9A
0005433186048	20864	15	9C
0005435501967	20864	16	11F
0005435501931	20864	17	12A
0005435501976	20864	18	13A
0005433186054	20864	19	13E
0005435501936	20864	20	14E
0005433186053	20864	21	14F
0005435528920	20864	22	16D
0005435528896	20864	23	17D
0005434565711	20864	24	18E
0005433186047	20864	25	19C
0005433186052	20864	26	19D
0005435528884	20864	27	19E
0005435501964	20864	28	19F
0005435528887	20864	29	20A
0005433186051	20864	30	20F
0005435153689	3905	1	1B
0005435153690	3905	2	1C
0005435931547	3905	3	1D
0005435153687	3905	4	2B
0005435153692	3905	5	6C
0005435153686	3905	6	7B
0005435153691	3905	7	7C
0005435153688	3905	8	20D
0005435153693	3905	9	21B
0005435931541	3905	10	21C
0005435153638	21857	1	4B
0005435931572	21857	2	5A
0005435153642	21857	3	5D
0005435153653	21857	4	7A
0005435153641	21857	5	18A
0005435153643	21857	6	20B
0005435153639	21857	7	21B
0005435153646	21857	8	22C
0005435153647	21857	9	23B
0005435225460	7194	1	1A
0005432628722	7194	2	3A
0005432628733	7194	3	3D
0005432628728	7194	4	4B
0005432628731	7194	5	4C
0005432628735	7194	6	6A
0005432628729	7194	7	6D
0005435225479	7194	8	7A
0005432628724	7194	9	19B
0005432628726	7194	10	19C
0005432628734	7194	11	20C
0005432628727	7194	12	20D
0005432628730	7194	13	21B
0005432628732	7194	14	21C
0005432628736	7194	15	22A
0005432628725	7194	16	22C
0005435225461	7194	17	22D
0005432628723	7194	18	23A
0005432628592	28097	1	1B
0005435225516	28097	2	3C
0005435225520	28097	3	4A
0005432628651	28097	4	4B
0005435225519	28097	5	5A
0005432628628	28097	6	5B
0005432628619	28097	7	5C
0005432628593	28097	8	6A
0005435225524	28097	9	6B
0005435225523	28097	10	6C
0005435225518	28097	11	7C
0005435225521	28097	12	7D
0005435225517	28097	13	18A
0005435225522	28097	14	18C
0005432628629	28097	15	20A
0005432628669	28097	16	20D
0005432628591	28097	17	21C
0005432628630	28097	18	21D
0005434267884	8726	1	3C
0005435960021	8726	2	4D
0005435960019	8726	3	7D
0005435960018	8726	4	18B
0005435960020	8726	5	20B
0005435959994	15266	1	1B
0005435959998	15266	2	1C
0005434267920	15266	3	3B
0005434267919	15266	4	3D
0005435959999	15266	5	7A
0005434267921	15266	6	7B
0005435960007	15266	7	7C
0005434267918	15266	8	18D
0005435959982	15266	9	21C
0005435959995	15266	10	22B
0005432692789	1199	1	1F
0005432675011	1199	2	2A
0005432692797	1199	3	3A
0005432675005	1199	4	3C
0005432692810	1199	5	4A
0005432692800	1199	6	3F
0005432692792	1199	7	5A
0005432692787	1199	8	5C
0005432692801	1199	9	6D
0005432692806	1199	10	7B
0005432692794	1199	11	7D
0005432692788	1199	12	7F
0005432692802	1199	13	8B
0005432692781	1199	14	8C
0005432675014	1199	15	8F
0005432675004	1199	16	8E
0005432692785	1199	17	9B
0005432692809	1199	18	9E
0005432692784	1199	19	9F
0005432692786	1199	20	10F
0005432675016	1199	21	11B
0005432692803	1199	22	11A
0005432692798	1199	23	11D
0005432873184	1199	24	11F
0005432692796	1199	25	12B
0005432675007	1199	26	12F
0005432677537	1199	27	13C
0005432675013	1199	28	13E
0005432692793	1199	29	13F
0005432692808	1199	30	14B
0005432692783	1199	31	14D
0005432692805	1199	32	14C
0005432675003	1199	33	15A
0005432675009	1199	34	16A
0005432675012	1199	35	16C
0005432675010	1199	36	16B
0005432692807	1199	37	16D
0005432692791	1199	38	17B
0005432675015	1199	39	17A
0005432692780	1199	40	17F
0005432675006	1199	41	17E
0005432692804	1199	42	18D
0005432677538	1199	43	19A
0005432692782	1199	44	18F
0005432675002	1199	45	19D
0005432692795	1199	46	19F
0005432677539	1199	47	20C
0005432692799	1199	48	20F
0005432692790	1199	49	21C
0005432675008	1199	50	21D
0005432674897	17479	1	2C
0005432674863	17479	2	4A
0005432692567	17479	3	6C
0005432692572	17479	4	6F
0005432873233	17479	5	6E
0005432674870	17479	6	6D
0005432674965	17479	7	7A
0005432873232	17479	8	8D
0005432692579	17479	9	8C
0005432674903	17479	10	9D
0005432692553	17479	11	10A
0005432674896	17479	12	10E
0005432674884	17479	13	11C
0005432692554	17479	14	11B
0005432674899	17479	15	11D
0005432692555	17479	16	12B
0005432873234	17479	17	12F
0005432674888	17479	18	13C
0005432873231	17479	19	14D
0005432692644	17479	20	14E
0005432674883	17479	21	16B
0005432692566	17479	22	16E
0005432692562	17479	23	16D
0005432692547	17479	24	16F
0005432873236	17479	25	18A
0005432873235	17479	26	18B
0005432692528	17479	27	18F
0005432873237	17479	28	18D
0005432674900	17479	29	19D
0005432692561	17479	30	20A
0005432674864	17479	31	19F
0005432674924	17479	32	20B
0005432692580	17479	33	21A
0005432674935	17479	34	20F
0005432692535	17479	35	21B
0005434435053	1123	1	1B
0005434435065	1123	2	2B
0005434435060	1123	3	2C
0005434435054	1123	4	2D
0005434435058	1123	5	3D
0005433156601	1123	6	4A
0005434435057	1123	7	4B
0005433156602	1123	8	4D
0005433156631	1123	9	5B
0005433156600	1123	10	5C
0005434435051	1123	11	6C
0005433156603	1123	12	6D
0005434435056	1123	13	7C
0005434435059	1123	14	18D
0005434435064	1123	15	19A
0005434435062	1123	16	19B
0005434435052	1123	17	20D
0005434435055	1123	18	21B
0005433156644	1123	19	21C
0005434435061	1123	20	22B
0005433156621	1123	21	22C
0005434435063	1123	22	22D
0005434434938	17299	1	1B
0005434434957	17299	2	2A
0005434434931	17299	3	3A
0005434434937	17299	4	3B
0005433156677	17299	5	4B
0005434434956	17299	6	4C
0005434434930	17299	7	4D
0005433156684	17299	8	5C
0005434434915	17299	9	5D
0005433156678	17299	10	6A
0005434434969	17299	11	6B
0005433156679	17299	12	6C
0005433156680	17299	13	7A
0005434434962	17299	14	7D
0005434434909	17299	15	18A
0005434434933	17299	16	18B
0005434434970	17299	17	18C
0005434434925	17299	18	19A
0005434434926	17299	19	19B
0005433156683	17299	20	20A
0005434434961	17299	21	20B
0005433156682	17299	22	20C
0005434434927	17299	23	20D
0005434434916	17299	24	21D
0005433156676	17299	25	22A
0005434434928	17299	26	22C
0005433156681	17299	27	23A
0005435086771	4064	1	2B
0005435086777	4064	2	4D
0005435086770	4064	3	5B
0005435086772	4064	4	5C
0005435928083	4064	5	7B
0005435086776	4064	6	18A
0005435086774	4064	7	18D
0005435086775	4064	8	20A
0005435086773	4064	9	20B
0005435928103	24422	1	4A
0005435086709	24422	2	4D
0005435086703	24422	3	7D
0005435086718	24422	4	18A
0005435928102	24422	5	18B
0005435928105	24422	6	19B
0005435928106	24422	7	19C
0005435086728	24422	8	21A
0005435928104	24422	9	22A
0005435086727	24422	10	22C
0005435706215	2447	1	1D
0005435706250	2447	2	1F
0005435706251	2447	3	2A
0005435706236	2447	4	2C
0005435706260	2447	5	2D
0005435706253	2447	6	3C
0005435706221	2447	7	3F
0005435706229	2447	8	4A
0005435706214	2447	9	4C
0005435706225	2447	10	4D
0005435706220	2447	11	5A
0005433373384	2447	12	5F
0005435706262	2447	13	6D
0005435706257	2447	14	6E
0005435706217	2447	15	6F
0005435706261	2447	16	7A
0005435706258	2447	17	7C
0005435706223	2447	18	7D
0005435706252	2447	19	7E
0005435706259	2447	20	7F
0005435706249	2447	21	8D
0005435706230	2447	22	8E
0005435706233	2447	23	8F
0005435706224	2447	24	9E
0005435706219	2447	25	9F
0005435706238	2447	26	10A
0005435706242	2447	27	10C
0005435706232	2447	28	10F
0005435706226	2447	29	11C
0005435706228	2447	30	11F
0005435706247	2447	31	12C
0005435706235	2447	32	12D
0005435706216	2447	33	12E
0005435706218	2447	34	12F
0005433373383	2447	35	13A
0005433373397	2447	36	13C
0005435706237	2447	37	13D
0005435706248	2447	38	14A
0005435706222	2447	39	14C
0005433373418	2447	40	14E
0005435706241	2447	41	14F
0005435706239	2447	42	15A
0005435706213	2447	43	15D
0005433373412	2447	44	16C
0005433373393	2447	45	16E
0005435706244	2447	46	16F
0005433373396	2447	47	17D
0005435706245	2447	48	17E
0005433373407	2447	49	17F
0005433373395	2447	50	18A
0005435706234	2447	51	18C
0005433373408	2447	52	18D
0005435706246	2447	53	18E
0005435706254	2447	54	19C
0005433373394	2447	55	19A
0005435706227	2447	56	19D
0005435706255	2447	57	19E
0005435706243	2447	58	19F
0005435706240	2447	59	20A
0005435706256	2447	60	20D
0005435706231	2447	61	20E
0005433373454	27039	1	1C
0005435706097	27039	2	2A
0005433373461	27039	3	2D
0005433373455	27039	4	2F
0005433373458	27039	5	3C
0005433373464	27039	6	3D
0005435706096	27039	7	3F
0005435706119	27039	8	4C
0005433373443	27039	9	4D
0005433373446	27039	10	4F
0005435706109	27039	11	4E
0005433373467	27039	12	5C
0005433373444	27039	13	5D
0005433373452	27039	14	6A
0005433373450	27039	15	7D
0005435706108	27039	16	7E
0005433373453	27039	17	7F
0005435706111	27039	18	8F
0005433373442	27039	19	9C
0005433373439	27039	20	9D
0005433373465	27039	21	10C
0005435706132	27039	22	10F
0005435706107	27039	23	11A
0005433373448	27039	24	11C
0005433373459	27039	25	12A
0005433373441	27039	26	12E
0005433373457	27039	27	12F
0005435706172	27039	28	13A
0005433373440	27039	29	13C
0005433373445	27039	30	13F
0005435706122	27039	31	14E
0005435706135	27039	32	15E
0005435706112	27039	33	15F
0005433373460	27039	34	16D
0005433373463	27039	35	16E
0005435706104	27039	36	17C
0005435706156	27039	37	17D
0005435706137	27039	38	17F
0005433373451	27039	39	18A
0005433373466	27039	40	18D
0005433373462	27039	41	18E
0005435706129	27039	42	19C
0005435706143	27039	43	19E
0005433373449	27039	44	19F
0005433373456	27039	45	20A
0005435706136	27039	46	20D
0005433373447	27039	47	20E
0005435706155	27039	48	20F
0005435907417	4858	1	1F
0005435907445	4858	2	2A
0005435907432	4858	3	2C
0005434625886	4858	4	4D
0005434625887	4858	5	5C
0005434625890	4858	6	5F
0005434625884	4858	7	6A
0005434625889	4858	8	6C
0005435907420	4858	9	10D
0005435907423	4858	10	13E
0005435907433	4858	11	15C
0005434625882	4858	12	15E
0005435907431	4858	13	16D
0005434625888	4858	14	18E
0005434625885	4858	15	18F
0005434625883	4858	16	19C
0005434625881	4858	17	20C
0005435907466	32907	1	1C
0005434625839	32907	2	2C
0005434625826	32907	3	7E
0005435907468	32907	4	9C
0005434625819	32907	5	10F
0005434625803	32907	6	11C
0005434625794	32907	7	11F
0005434625836	32907	8	12F
0005434625837	32907	9	14F
0005434625809	32907	10	15E
0005434625793	32907	11	16F
0005435907467	32907	12	17C
0005434625820	32907	13	17E
0005435907465	32907	14	17F
0005435937347	13793	1	1B
0005435784856	13793	2	1D
0005435784877	13793	3	2C
0005435937346	13793	4	3A
0005435784758	13793	5	4C
0005435937345	13793	6	5B
0005435787322	13793	7	5D
0005435784759	13793	8	6A
0005435787321	13793	9	6C
0005435784756	13793	10	7A
0005432195676	13793	11	7B
0005435784798	13793	12	7D
0005435784902	13793	13	18C
0005435784874	13793	14	18D
0005435784736	13793	15	19B
0005435784885	13793	16	19C
0005435784757	13793	17	19D
0005435937348	13793	18	20A
0005435784799	13793	19	20B
0005435784797	13793	20	20C
0005435784737	13793	21	20D
0005432195677	13793	22	22B
0005435787323	13793	23	22D
0005435937344	13793	24	23A
0005435785026	27450	1	1B
0005435785012	27450	2	1C
0005435785027	27450	3	1D
0005435785041	27450	4	2A
0005435937306	27450	5	2C
0005435785011	27450	6	2D
0005435785033	27450	7	3B
0005435785038	27450	8	3C
0005435785029	27450	9	3D
0005435785021	27450	10	4A
0005435937305	27450	11	4B
0005432190594	27450	12	4C
0005435785016	27450	13	4D
0005435785015	27450	14	5A
0005435785036	27450	15	5C
0005435787332	27450	16	5D
0005435785013	27450	17	6A
0005435785031	27450	18	6B
0005435785014	27450	19	6C
0005435785028	27450	20	6D
0005435785034	27450	21	7C
0005435787333	27450	22	7D
0005435785039	27450	23	18A
0005435785023	27450	24	18B
0005435785042	27450	25	18C
0005432190595	27450	26	18D
0005435785020	27450	27	19A
0005435785017	27450	28	19B
0005435785044	27450	29	19C
0005432190593	27450	30	19D
0005432190592	27450	31	20A
0005432190591	27450	32	20B
0005435785032	27450	33	20C
0005435785035	27450	34	20D
0005435785024	27450	35	21A
0005435785030	27450	36	21B
0005435785045	27450	37	21C
0005435785018	27450	38	21D
0005435785022	27450	39	22A
0005435785019	27450	40	22B
0005435785037	27450	41	22C
0005435785040	27450	42	22D
0005435785043	27450	43	23A
0005435785025	27450	44	23B
0005434406744	20261	1	1C
0005434406707	20261	2	1F
0005435310976	20261	3	2C
0005434406773	20261	4	2D
0005435310971	20261	5	3C
0005434406986	20261	6	3D
0005434406779	20261	7	3F
0005434406695	20261	8	4A
0005432058350	20261	9	4D
0005434406761	20261	10	4F
0005434406696	20261	11	5A
0005435310975	20261	12	5C
0005434406640	20261	13	5D
0005434406984	20261	14	5E
0005434406762	20261	15	5F
0005434406654	20261	16	6E
0005434406891	20261	17	8D
0005434406794	20261	18	9A
0005434406709	20261	19	9F
0005434406745	20261	20	10A
0005434406994	20261	21	10D
0005434406679	20261	22	10F
0005434406853	20261	23	11A
0005435310969	20261	24	11F
0005435310973	20261	25	12C
0005434406959	20261	26	12D
0005435310970	20261	27	13A
0005434406746	20261	28	13C
0005435310972	20261	29	13F
0005434406708	20261	30	14E
0005434406649	20261	31	14F
0005434406656	20261	32	15C
0005435310977	20261	33	15E
0005434406859	20261	34	15F
0005434406797	20261	35	16A
0005434406655	20261	36	16C
0005435310974	20261	37	16D
0005434406993	20261	38	16E
0005434406860	20261	39	16F
0005434406985	20261	40	17A
0005434407071	20261	41	17C
0005434406750	20261	42	17D
0005434406883	20261	43	18C
0005434406650	20261	44	18E
0005432058351	20261	45	18F
0005432058348	20261	46	19D
0005432058349	20261	47	19E
0005434406732	20261	48	19F
0005434406890	20261	49	20E
0005434406808	20261	50	20F
0005434407248	26981	1	1A
0005434407225	26981	2	1C
0005434407272	26981	3	1F
0005434407264	26981	4	2A
0005434407271	26981	5	2D
0005434407244	26981	6	2F
0005434407249	26981	7	3A
0005434407276	26981	8	3D
0005434407238	26981	9	3F
0005435310856	26981	10	4A
0005434407223	26981	11	4D
0005434407274	26981	12	4E
0005434407241	26981	13	5A
0005435310867	26981	14	5C
0005432153880	26981	15	5D
0005432153883	26981	16	5E
0005434407229	26981	17	5F
0005434407260	26981	18	6A
0005434407253	26981	19	6C
0005434407277	26981	20	6D
0005432153878	26981	21	6E
0005434407279	26981	22	6F
0005432153882	26981	23	7A
0005435310855	26981	24	7C
0005434407243	26981	25	7E
0005434407247	26981	26	7F
0005434407254	26981	27	8A
0005434407218	26981	28	8C
0005434407270	26981	29	8D
0005434407265	26981	30	8E
0005434407234	26981	31	8F
0005434407262	26981	32	9A
0005434407235	26981	33	9C
0005434407278	26981	34	9D
0005434407267	26981	35	9E
0005434407252	26981	36	10A
0005434407281	26981	37	10C
0005434407257	26981	38	10D
0005434407232	26981	39	10E
0005432153884	26981	40	10F
0005434407224	26981	41	11A
0005434407236	26981	42	11C
0005434407275	26981	43	11E
0005435310873	26981	44	11F
0005434407227	26981	45	12C
0005434407221	26981	46	12D
0005434407245	26981	47	12E
0005432153879	26981	48	12F
0005435310872	26981	49	13A
0005434407251	26981	50	13E
0005434407230	26981	51	14C
0005434407259	26981	52	14D
0005434407219	26981	53	14E
0005434407256	26981	54	15A
0005434407258	26981	55	15C
0005434407220	26981	56	15E
0005432153881	26981	57	16A
0005434407237	26981	58	16C
0005434407222	26981	59	16D
0005434407250	26981	60	16F
0005434407228	26981	61	17A
0005435310858	26981	62	17C
0005434407268	26981	63	17D
0005435310840	26981	64	17E
0005434407226	26981	65	17F
0005434407263	26981	66	18A
0005434407231	26981	67	18C
0005434407273	26981	68	18D
0005434407240	26981	69	18E
0005435310857	26981	70	18F
0005434407266	26981	71	19A
0005434407255	26981	72	19D
0005434407261	26981	73	19E
0005434407242	26981	74	19F
0005434407239	26981	75	20A
0005434407246	26981	76	20C
0005434407233	26981	77	20D
0005434407269	26981	78	20E
0005434407280	26981	79	20F
0005434319276	5689	1	1A
0005434319286	5689	2	1D
0005434319279	5689	3	1F
0005434319266	5689	4	3A
0005434319264	5689	5	3C
0005434319274	5689	6	4A
0005434319277	5689	7	4C
0005434319265	5689	8	5F
0005434319278	5689	9	8A
0005434319280	5689	10	8C
0005433123613	5689	11	8E
0005434319283	5689	12	9A
0005432109682	5689	13	9E
0005432109681	5689	14	9F
0005433123589	5689	15	10E
0005433123651	5689	16	10F
0005434311202	5689	17	12A
0005434319272	5689	18	12D
0005434319281	5689	19	12F
0005434319273	5689	20	13D
0005434319267	5689	21	13F
0005434319271	5689	22	15A
0005433123642	5689	23	15F
0005434319269	5689	24	16C
0005432109680	5689	25	16D
0005433123612	5689	26	16E
0005434319285	5689	27	16F
0005434311203	5689	28	17A
0005434319275	5689	29	17F
0005434319270	5689	30	19C
0005434311201	5689	31	19F
0005434319282	5689	32	20C
0005434319268	5689	33	20D
0005434319284	5689	34	20E
0005433123776	15693	1	2D
0005434319205	15693	2	3D
0005433123771	15693	3	3F
0005433123762	15693	4	4D
0005433123778	15693	5	5A
0005433123760	15693	6	6A
0005433123773	15693	7	6E
0005433123774	15693	8	6F
0005434319190	15693	9	7A
0005434319152	15693	10	7E
0005433123764	15693	11	8C
0005433123775	15693	12	9E
0005433123765	15693	13	9F
0005433123780	15693	14	11C
0005433123772	15693	15	11D
0005433123769	15693	16	12C
0005434319192	15693	17	13A
0005433123767	15693	18	13C
0005433123768	15693	19	13D
0005433123770	15693	20	14E
0005434319227	15693	21	15E
0005434319191	15693	22	15F
0005433123777	15693	23	16D
0005434319206	15693	24	16E
0005434319178	15693	25	16F
0005433123766	15693	26	17E
0005433123779	15693	27	17F
0005433123761	15693	28	18C
0005434319207	15693	29	18D
0005434319153	15693	30	19A
0005434319208	15693	31	19D
0005433123763	15693	32	19F
0005435219183	31759	1	1A
0005435219185	31759	2	1B
0005435220300	31759	3	2C
0005435220303	31759	4	2D
0005435219182	31759	5	3A
0005435220304	31759	6	5A
0005435219186	31759	7	6A
0005435220302	31759	8	7C
0005435219184	31759	9	18C
0005435219181	31759	10	20B
0005435220301	31759	11	20C
0005434484296	9003	1	2D
0005434189083	9003	2	3A
0005434484294	9003	3	3C
0005434484293	9003	4	4A
0005434189096	9003	5	5A
0005434189086	9003	6	6A
0005434189082	9003	7	7C
0005434189075	9003	8	20A
0005434484292	9003	9	20B
0005434189080	9003	10	20C
0005434484297	9003	11	21B
0005434189103	9003	12	22B
0005434484295	9003	13	23B
0005434189130	16655	1	1B
0005434189133	16655	2	1C
0005434484234	16655	3	3D
0005434189132	16655	4	5C
0005434189134	16655	5	6D
0005434484235	16655	6	18C
0005434189131	16655	7	20A
0005434189129	16655	8	21A
0005434484266	16655	9	21C
0005433123775	7611	1	3D
0005433123779	7611	2	4A
0005433123760	7611	3	6D
0005433123762	7611	4	7D
0005433123773	7611	5	7F
0005433123765	7611	6	8A
0005433123778	7611	7	8C
0005433123769	7611	8	9A
0005433123774	7611	9	10C
0005433123761	7611	10	10D
0005433123776	7611	11	11E
0005433123767	7611	12	12D
0005433123764	7611	13	12F
0005433123763	7611	14	13D
0005433123770	7611	15	16E
0005433123780	7611	16	17C
0005433123771	7611	17	17F
0005433123766	7611	18	18A
0005433123777	7611	19	18D
0005433123772	7611	20	18F
0005433123768	7611	21	19E
0005433449790	7612	1	1A
0005432692819	7612	2	1D
0005432720686	7612	3	1F
0005432720696	7612	4	2A
0005433449800	7612	5	2C
0005432071548	7612	6	2D
0005432720689	7612	7	2F
0005432692832	7612	8	3A
0005432720695	7612	9	3C
0005433449795	7612	10	3D
0005432720700	7612	11	3F
0005433449793	7612	12	4A
0005433449803	7612	13	4C
0005432692841	7612	14	4E
0005432720694	7612	15	4F
0005432692816	7612	16	5C
0005433449797	7612	17	5D
0005432692835	7612	18	6C
0005432720692	7612	19	6D
0005432720681	7612	20	6E
0005432692839	7612	21	6F
0005432692830	7612	22	7A
0005433449788	7612	23	7C
0005433449798	7612	24	7D
0005432692837	7612	25	7E
0005433449794	7612	26	7F
0005432692833	7612	27	8A
0005432692834	7612	28	8C
0005433449799	7612	29	8D
0005432720685	7612	30	8E
0005433449787	7612	31	9A
0005432720697	7612	32	9C
0005432720682	7612	33	9D
0005432692840	7612	34	9E
0005433449805	7612	35	9F
0005432692812	7612	36	10C
0005432720678	7612	37	10A
0005432720693	7612	38	10D
0005432720690	7612	39	10E
0005433449786	7612	40	11A
0005432692825	7612	41	11C
0005432720688	7612	42	11E
0005433449789	7612	43	11F
0005433449791	7612	44	12A
0005433449785	7612	45	12C
0005432071550	7612	46	12D
0005433449801	7612	47	12E
0005432720679	7612	48	12F
0005432720698	7612	49	13C
0005433449796	7612	50	13D
0005432692817	7612	51	13E
0005432692813	7612	52	13F
0005433449802	7612	53	14A
0005432720684	7612	54	14C
0005432720676	7612	55	14E
0005432720683	7612	56	15A
0005432071549	7612	57	15C
0005432692842	7612	58	15D
0005432692827	7612	59	15E
0005432692824	7612	60	15F
0005432692811	7612	61	16A
0005432692815	7612	62	16C
0005432692836	7612	63	16D
0005432692828	7612	64	16E
0005432720699	7612	65	16F
0005432720677	7612	66	17C
0005432692822	7612	67	17D
0005432720701	7612	68	17F
0005432692826	7612	69	18A
0005432692831	7612	70	18C
0005432692823	7612	71	18D
0005432720687	7612	72	18E
0005432692818	7612	73	18F
0005432692821	7612	74	19A
0005432692820	7612	75	19C
0005432692814	7612	76	19D
0005433449804	7612	77	19E
0005432720691	7612	78	19F
0005433449792	7612	79	20A
0005432720680	7612	80	20C
0005432720702	7612	81	20D
0005432692838	7612	82	20E
0005432692829	7612	83	20F
0005432692547	30373	1	1C
0005432692579	30373	2	1D
0005432692566	30373	3	1F
0005433449599	30373	4	2C
0005433449584	30373	5	2D
0005433449628	30373	6	3D
0005433449615	30373	7	5D
0005433449583	30373	8	5E
0005433449590	30373	9	6F
0005433449598	30373	10	7C
0005432692553	30373	11	7E
0005433449659	30373	12	8C
0005432692572	30373	13	9A
0005433449593	30373	14	9D
0005433449660	30373	15	9E
0005432692580	30373	16	10D
0005432692554	30373	17	11C
0005432692567	30373	18	12A
0005432692562	30373	19	12F
0005433449639	30373	20	15A
0005432692561	30373	21	15D
0005432692528	30373	22	15E
0005433449653	30373	23	16D
0005432692535	30373	24	18C
0005432692644	30373	25	18D
0005432692555	30373	26	19F
0005432720507	30372	1	2C
0005432720514	30372	2	2D
0005432720463	30372	3	3C
0005432720438	30372	4	4F
0005433123651	30372	5	5A
0005432720618	30372	6	5D
0005433722168	30372	7	6C
0005432720480	30372	8	7D
0005432720546	30372	9	7E
0005432720674	30372	10	8A
0005432720675	30372	11	8E
0005432720504	30372	12	9A
0005432720431	30372	13	10D
0005433123642	30372	14	10E
0005433123613	30372	15	11A
0005433722169	30372	16	11C
0005432720436	30372	17	11D
0005432720474	30372	18	12E
0005432720619	30372	19	13E
0005433123612	30372	20	13F
0005432720508	30372	21	14A
0005432720579	30372	22	14C
0005432720439	30372	23	14D
0005432720526	30372	24	14E
0005433722167	30372	25	15E
0005432720473	30372	26	17C
0005433123589	30372	27	19D
0005432720478	30372	28	19E
0005432720442	30372	29	19F
0005432720430	30372	30	20A
0005432720435	30372	31	20E
0005433192824	1398	1	1A
0005434586404	1398	2	1C
0005432927900	1398	3	1D
0005432927910	1398	4	1F
0005434586408	1398	5	2C
0005433524956	1398	6	2D
0005432927912	1398	7	2F
0005433192833	1398	8	3A
0005434586395	1398	9	3C
0005433192832	1398	10	3D
0005434586398	1398	11	3F
0005433192850	1398	12	4A
0005434586403	1398	13	4C
0005433192837	1398	14	4D
0005434586397	1398	15	4E
0005432968801	1398	16	4F
0005434586411	1398	17	5A
0005434586400	1398	18	5C
0005434586396	1398	19	5D
0005433524954	1398	20	5E
0005434586399	1398	21	5F
0005433724767	1398	22	6A
0005433192842	1398	23	6C
0005432927899	1398	24	6D
0005434586412	1398	25	6E
0005433192874	1398	26	7C
0005434586418	1398	27	7D
0005432270981	1398	28	7E
0005433192875	1398	29	7F
0005433192835	1398	30	8A
0005434586405	1398	31	8C
0005432927890	1398	32	8D
0005433524948	1398	33	8F
0005432927906	1398	34	9A
0005434586402	1398	35	9C
0005434586409	1398	36	10A
0005433524946	1398	37	10C
0005433524951	1398	38	10F
0005432927885	1398	39	11A
0005434586394	1398	40	11C
0005433192836	1398	41	11E
0005434586420	1398	42	12A
0005432270982	1398	43	12D
0005433192827	1398	44	12E
0005433524955	1398	45	12F
0005434513559	1398	46	13A
0005433524949	1398	47	13D
0005433724770	1398	48	13E
0005434586406	1398	49	13F
0005433192852	1398	50	14A
0005433524950	1398	51	14C
0005433724771	1398	52	14D
0005434586417	1398	53	14E
0005432927913	1398	54	14F
0005434586410	1398	55	15C
0005434586415	1398	56	15D
0005434513558	1398	57	15E
0005433192831	1398	58	15F
0005433192859	1398	59	16A
0005433192823	1398	60	16C
0005434586407	1398	61	16D
0005434586416	1398	62	16E
0005433724768	1398	63	16F
0005433192853	1398	64	17A
0005434586413	1398	65	17C
0005433192860	1398	66	17D
0005434514945	1398	67	17E
0005434586401	1398	68	17F
0005432927893	1398	69	18D
0005434513557	1398	70	18E
0005434514946	1398	71	18F
0005433524953	1398	72	19A
0005433524952	1398	73	19C
0005434513560	1398	74	19D
0005434514947	1398	75	19E
0005433724769	1398	76	19F
0005433192834	1398	77	20A
0005434586414	1398	78	20C
0005434586419	1398	79	20D
0005433524947	1398	80	20E
0005433192858	1398	81	20F
0005433192932	18544	1	1A
0005434586196	18544	2	1C
0005434586250	18544	3	2A
0005433192940	18544	4	2F
0005432927934	18544	5	3D
0005433192941	18544	6	4A
0005433524862	18544	7	4D
0005432927935	18544	8	4E
0005433192943	18544	9	4F
0005433524859	18544	10	5A
0005433724727	18544	11	5C
0005433192944	18544	12	5D
0005433724726	18544	13	5E
0005433192936	18544	14	6C
0005434586206	18544	15	8C
0005433524857	18544	16	8D
0005434586224	18544	17	8E
0005433524850	18544	18	9C
0005434586242	18544	19	10C
0005434586248	18544	20	11C
0005434586225	18544	21	11E
0005432927932	18544	22	11F
0005434586245	18544	23	12C
0005433192938	18544	24	13D
0005434586226	18544	25	13E
0005433192939	18544	26	13F
0005433524872	18544	27	14A
0005433524863	18544	28	14C
0005433192935	18544	29	14F
0005432927933	18544	30	15C
0005434586251	18544	31	15D
0005432968820	18544	32	15E
0005434586249	18544	33	16E
0005432968822	18544	34	16F
0005433192933	18544	35	17A
0005434586227	18544	36	17C
0005433192934	18544	37	17D
0005434586181	18544	38	17E
0005433524873	18544	39	18A
0005434514921	18544	40	18C
0005432927931	18544	41	19A
0005433192937	18544	42	19C
0005433524858	18544	43	19F
0005433724734	18544	44	20A
0005433524849	18544	45	20C
0005433192942	18544	46	20D
0005432968821	18544	47	20F
0005434343882	11448	1	1A
0005434343895	11448	2	1B
0005434343874	11448	3	1C
0005434142578	11448	4	1D
0005434343879	11448	5	2A
0005434142577	11448	6	2B
0005434343901	11448	7	2C
0005434343880	11448	8	2D
0005434343878	11448	9	3A
0005434343886	11448	10	3B
0005434343910	11448	11	3C
0005435302120	11448	12	3D
0005434343899	11448	13	4A
0005434142581	11448	14	4B
0005434343890	11448	15	4C
0005434343885	11448	16	4D
0005434343889	11448	17	5A
0005434343904	11448	18	5B
0005434343891	11448	19	5C
0005434343894	11448	20	5D
0005434343896	11448	21	6B
0005435304990	11448	22	6C
0005434343909	11448	23	6D
0005434343902	11448	24	7A
0005434343897	11448	25	7C
0005434343908	11448	26	7D
0005434142580	11448	27	18A
0005434343898	11448	28	18B
0005434343888	11448	29	18C
0005435304991	11448	30	18D
0005434343907	11448	31	19A
0005434343875	11448	32	19B
0005434343877	11448	33	19C
0005434343892	11448	34	19D
0005434343903	11448	35	20A
0005434343881	11448	36	20B
0005434343906	11448	37	20D
0005434343876	11448	38	21B
0005434343893	11448	39	21C
0005434343883	11448	40	22A
0005434343905	11448	41	22B
0005434343884	11448	42	22C
0005434142579	11448	43	22D
0005434343887	11448	44	23A
0005434343900	11448	45	23B
0005434343621	29748	1	1A
0005434343663	29748	2	1B
0005434343709	29748	3	1C
0005434343672	29748	4	1D
0005434343599	29748	5	2B
0005434343648	29748	6	2C
0005434343583	29748	7	3A
0005434343664	29748	8	3B
0005434343597	29748	9	3C
0005434343609	29748	10	3D
0005434343587	29748	11	4A
0005434343598	29748	12	4B
0005434343703	29748	13	4C
0005434343710	29748	14	5C
0005434343605	29748	15	5D
0005435304125	29748	16	6B
0005434343649	29748	17	6D
0005434142540	29748	18	7A
0005434343589	29748	19	7D
0005434343628	29748	20	18A
0005435304122	29748	21	18B
0005435304126	29748	22	18C
0005434343606	29748	23	18D
0005434343699	29748	24	19A
0005434343611	29748	25	19C
0005434343631	29748	26	19D
0005435304123	29748	27	20A
0005434343673	29748	28	20B
0005434343684	29748	29	20C
0005434343630	29748	30	21B
0005434343645	29748	31	21C
0005434343610	29748	32	22B
0005435304124	29748	33	22C
0005434142544	29748	34	22D
0005434343588	29748	35	23A
0005435824412	1306	1	2D
0005433415463	1306	2	2F
0005433415396	1306	3	3D
0005435824420	1306	4	3C
0005432284533	1306	5	4A
0005433415412	1306	6	3F
0005433415411	1306	7	4C
0005435824418	1306	8	5D
0005435824424	1306	9	5C
0005435824411	1306	10	6A
0005432284534	1306	11	6E
0005433415458	1306	12	7A
0005433415432	1306	13	6F
0005435824413	1306	14	7C
0005435824400	1306	15	7D
0005435824421	1306	16	8C
0005435824414	1306	17	8F
0005435824422	1306	18	8E
0005435824401	1306	19	9B
0005435824416	1306	20	9A
0005433415484	1306	21	9F
0005433415386	1306	22	11A
0005435824425	1306	23	11C
0005433415435	1306	24	11B
0005435824406	1306	25	11E
0005433415423	1306	26	12B
0005435824417	1306	27	12A
0005435824423	1306	28	12D
0005435824403	1306	29	12C
0005433415408	1306	30	12E
0005435824409	1306	31	13E
0005435824410	1306	32	14A
0005435824404	1306	33	13F
0005435824407	1306	34	15B
0005433415409	1306	35	15C
0005433415436	1306	36	15E
0005432284535	1306	37	16C
0005435824405	1306	38	16D
0005433415464	1306	39	17B
0005433415431	1306	40	17E
0005433415406	1306	41	18C
0005435824419	1306	42	18B
0005435824408	1306	43	19F
0005433415456	1306	44	20D
0005433415395	1306	45	21C
0005435824415	1306	46	21D
0005435824402	1306	47	21F
0005433415531	18020	1	2C
0005435824261	18020	2	3F
0005435824260	18020	3	5F
0005435824224	18020	4	5D
0005435824187	18020	5	6A
0005433415534	18020	6	7D
0005433415525	18020	7	7F
0005435824209	18020	8	9F
0005435824157	18020	9	10E
0005433415528	18020	10	11B
0005435824217	18020	11	11C
0005433415539	18020	12	11E
0005433415536	18020	13	13A
0005435824218	18020	14	13E
0005433415540	18020	15	13F
0005435824195	18020	16	14D
0005435824186	18020	17	14E
0005433415535	18020	18	15D
0005433415530	18020	19	15E
0005435824207	18020	20	16D
0005433415526	18020	21	17A
0005433415538	18020	22	17F
0005435824208	18020	23	18B
0005435824152	18020	24	18A
0005433415532	18020	25	18D
0005435824190	18020	26	19A
0005433415529	18020	27	19B
0005435824196	18020	28	19E
0005433415527	18020	29	20A
0005433415537	18020	30	20C
0005433415533	18020	31	21C
0005435242432	5655	1	1A
0005432783376	5655	2	1C
0005432783340	5655	3	1D
0005432783339	5655	4	2A
0005432783361	5655	5	2C
0005435242475	5655	6	2D
0005432783386	5655	7	3A
0005432783345	5655	8	3C
0005432783388	5655	9	3D
0005432783373	5655	10	3F
0005432783351	5655	11	4A
0005432783337	5655	12	4D
0005432783370	5655	13	4E
0005432783343	5655	14	4F
0005432783367	5655	15	5A
0005432783389	5655	16	5C
0005435242396	5655	17	5D
0005432783355	5655	18	5E
0005435242437	5655	19	6A
0005435242430	5655	20	6C
0005432783366	5655	21	6D
0005432783365	5655	22	6E
0005435242398	5655	23	6F
0005432783354	5655	24	7A
0005432783357	5655	25	7C
0005432783384	5655	26	7D
0005435242397	5655	27	7E
0005432783364	5655	28	7F
0005435242452	5655	29	8C
0005432783372	5655	30	8D
0005435476644	5655	31	9A
0005435242450	5655	32	9C
0005432783377	5655	33	9D
0005432783341	5655	34	9F
0005432783380	5655	35	10A
0005435476637	5655	36	10C
0005432783353	5655	37	10D
0005435242453	5655	38	10E
0005435242513	5655	39	10F
0005432783335	5655	40	11D
0005432783356	5655	41	11E
0005432783371	5655	42	11F
0005432783382	5655	43	12A
0005432783383	5655	44	12D
0005432783363	5655	45	12E
0005435242476	5655	46	13A
0005432783346	5655	47	13C
0005432783379	5655	48	13D
0005432783369	5655	49	13E
0005435476640	5655	50	13F
0005435242405	5655	51	14A
0005432783342	5655	52	14D
0005432783375	5655	53	14E
0005432783390	5655	54	14F
0005432783349	5655	55	15A
0005432783348	5655	56	15C
0005432783385	5655	57	15D
0005432783338	5655	58	15E
0005435242429	5655	59	16A
0005435242431	5655	60	16D
0005432783358	5655	61	16E
0005435476643	5655	62	16F
0005432783347	5655	63	17C
0005432783360	5655	64	17D
0005432783336	5655	65	17E
0005432783387	5655	66	17F
0005432783378	5655	67	18A
0005432783374	5655	68	18C
0005432783350	5655	69	18D
0005432783368	5655	70	18E
0005432143962	5655	71	18F
0005435242402	5655	72	19C
0005432783352	5655	73	19D
0005432783344	5655	74	19E
0005432783362	5655	75	20A
0005432783359	5655	76	20C
0005435242446	5655	77	20D
0005432783381	5655	78	20F
0005435242624	15390	1	1A
0005432782962	15390	2	1D
0005432783237	15390	3	1C
0005432782838	15390	4	1F
0005432782908	15390	5	2C
0005432782877	15390	6	2F
0005432782865	15390	7	3A
0005435476708	15390	8	3D
0005432782889	15390	9	3F
0005435242634	15390	10	4A
0005432782864	15390	11	4F
0005435242616	15390	12	5A
0005432782873	15390	13	5C
0005432782888	15390	14	5D
0005432782947	15390	15	6D
0005432782857	15390	16	6E
0005432782918	15390	17	6F
0005435242618	15390	18	7A
0005435242628	15390	19	7E
0005435242615	15390	20	8C
0005435242623	15390	21	8D
0005435242621	15390	22	8E
0005432782882	15390	23	8F
0005432782881	15390	24	9A
0005432782916	15390	25	9E
0005435242619	15390	26	10E
0005435476707	15390	27	10F
0005435242617	15390	28	11E
0005432782946	15390	29	11F
0005435242613	15390	30	12A
0005435242631	15390	31	12C
0005435242630	15390	32	12D
0005432782851	15390	33	12F
0005435242611	15390	34	13A
0005435242627	15390	35	13C
0005435242612	15390	36	13D
0005435476706	15390	37	13E
0005432782964	15390	38	13F
0005435242635	15390	39	14C
0005432782931	15390	40	14E
0005435242629	15390	41	14F
0005432782930	15390	42	15D
0005435476705	15390	43	15F
0005435242626	15390	44	16A
0005432782948	15390	45	16C
0005432782929	15390	46	16E
0005435242622	15390	47	17A
0005435242636	15390	48	17C
0005435242625	15390	49	17E
0005432783024	15390	50	17F
0005432782886	15390	51	18C
0005432783015	15390	52	18E
0005435242632	15390	53	18F
0005435242614	15390	54	19D
0005435242620	15390	55	19E
0005432782850	15390	56	19F
0005432782906	15390	57	20A
0005435242633	15390	58	20C
0005432783238	15390	59	20D
0005432783014	15390	60	20F
0005435850752	4359	1	1A
0005432848193	4359	2	1B
0005435850765	4359	3	1C
0005435850753	4359	4	1D
0005432848191	4359	5	2A
0005435850804	4359	6	2B
0005432848201	4359	7	3A
0005434463912	4359	8	3B
0005435850788	4359	9	3C
0005435850766	4359	10	3D
0005435850789	4359	11	4A
0005432848196	4359	12	5A
0005432848202	4359	13	5B
0005432848203	4359	14	5C
0005434462772	4359	15	5D
0005432848194	4359	16	6A
0005432848199	4359	17	6B
0005435850779	4359	18	6C
0005435850773	4359	19	6D
0005435850778	4359	20	7B
0005435850771	4359	21	7A
0005434462773	4359	22	7C
0005432848198	4359	23	7D
0005434463911	4359	24	18A
0005435850803	4359	25	18B
0005435850809	4359	26	18C
0005435850780	4359	27	18D
0005432848192	4359	28	19A
0005435850776	4359	29	19B
0005432848200	4359	30	20D
0005434463913	4359	31	21A
0005432848197	4359	32	21B
0005432848189	4359	33	21D
0005432848195	4359	34	22A
0005432848190	4359	35	22B
0005435850769	4359	36	22C
0005435850787	4359	37	22D
0005432848107	28855	1	1C
0005435850839	28855	2	2B
0005435850841	28855	3	2C
0005432848109	28855	4	2D
0005435850832	28855	5	3A
0005434461610	28855	6	3C
0005432848112	28855	7	5B
0005432848108	28855	8	5C
0005435850833	28855	9	6D
0005432848111	28855	10	7D
0005435850840	28855	11	18A
0005434461609	28855	12	18C
0005435850835	28855	13	19A
0005432848078	28855	14	19B
0005435850837	28855	15	21A
0005435850836	28855	16	21C
0005435850834	28855	17	21D
0005435850838	28855	18	22C
0005432075203	6238	1	1A
0005434925560	6238	2	1C
0005434443578	6238	3	1D
0005434443584	6238	4	1F
0005433496710	6238	5	2A
0005433496718	6238	6	2C
0005433496737	6238	7	2D
0005432075202	6238	8	2F
0005433496722	6238	9	3A
0005434925535	6238	10	3C
0005434925534	6238	11	3D
0005434925554	6238	12	3F
0005434925540	6238	13	4A
0005434925561	6238	14	4C
0005434925547	6238	15	4D
0005433496715	6238	16	4E
0005433496734	6238	17	4F
0005434925557	6238	18	5A
0005433496720	6238	19	5C
0005432075201	6238	20	5D
0005434925559	6238	21	5E
0005434925566	6238	22	5F
0005433496708	6238	23	6A
0005434443574	6238	24	6C
0005433496725	6238	25	6D
0005434925562	6238	26	6E
0005434925548	6238	27	7A
0005434443589	6238	28	7C
0005433496736	6238	29	7D
0005434925569	6238	30	7E
0005434925550	6238	31	7F
0005434925571	6238	32	8A
0005434925538	6238	33	8C
0005433496726	6238	34	8D
0005434925565	6238	35	8E
0005434925564	6238	36	8F
0005434925543	6238	37	9A
0005433496713	6238	38	9C
0005434443588	6238	39	9D
0005434925546	6238	40	9E
0005434925570	6238	41	9F
0005433496712	6238	42	10A
0005433496730	6238	43	10C
0005433496724	6238	44	10D
0005434443583	6238	45	10E
0005434925556	6238	46	10F
0005433496735	6238	47	11A
0005433496711	6238	48	11C
0005434925542	6238	49	11D
0005434443581	6238	50	11E
0005434443572	6238	51	11F
0005434443580	6238	52	12A
0005434443579	6238	53	12C
0005434925553	6238	54	12D
0005434443576	6238	55	12E
0005434925544	6238	56	12F
0005434443573	6238	57	13A
0005433496716	6238	58	13C
0005433496723	6238	59	13D
0005433496733	6238	60	13F
0005433496729	6238	61	14A
0005434925536	6238	62	14C
0005434925549	6238	63	14D
0005434925537	6238	64	14E
0005433496732	6238	65	15A
0005434443575	6238	66	15C
0005433496727	6238	67	15D
0005433496717	6238	68	15E
0005434443587	6238	69	15F
0005434443585	6238	70	16A
0005433496719	6238	71	16C
0005434925555	6238	72	16D
0005434925545	6238	73	16F
0005433496728	6238	74	17C
0005433496721	6238	75	17D
0005434925567	6238	76	17E
0005433496731	6238	77	17F
0005433496714	6238	78	18A
0005434925551	6238	79	18C
0005434925533	6238	80	18D
0005434925563	6238	81	18E
0005434925552	6238	82	18F
0005434925558	6238	83	19A
0005434925568	6238	84	19C
0005434925539	6238	85	19D
0005434443582	6238	86	19E
0005434443577	6238	87	19F
0005433496707	6238	88	20A
0005434925541	6238	89	20D
0005433496709	6238	90	20E
0005434443586	6238	91	20F
0005434925249	20411	1	1C
0005433496552	20411	2	1F
0005433496488	20411	3	2C
0005434925271	20411	4	2D
0005433496470	20411	5	3C
0005434443497	20411	6	3D
0005433496550	20411	7	4C
0005434443425	20411	8	4E
0005433496521	20411	9	4F
0005433496446	20411	10	5A
0005434925310	20411	11	5F
0005434443479	20411	12	6A
0005433496509	20411	13	6D
0005434443446	20411	14	6E
0005434443460	20411	15	6F
0005433496487	20411	16	7C
0005433496598	20411	17	7D
0005433496574	20411	18	7F
0005433496458	20411	19	8A
0005433496522	20411	20	8F
0005434925252	20411	21	9A
0005434925272	20411	22	9C
0005433496489	20411	23	9E
0005434443478	20411	24	9F
0005433496508	20411	25	10A
0005433496618	20411	26	10C
0005433496597	20411	27	10D
0005433496463	20411	28	10E
0005434443459	20411	29	10F
0005434925250	20411	30	11A
0005433496573	20411	31	11F
0005433496507	20411	32	12F
0005434925291	20411	33	13C
0005434443504	20411	34	13D
0005433496551	20411	35	13F
0005434925279	20411	36	14A
0005434925247	20411	37	14E
0005434443438	20411	38	15E
0005434925270	20411	39	15F
0005434925292	20411	40	16E
0005434443452	20411	41	17C
0005434925261	20411	42	17F
0005433496457	20411	43	19A
0005433496566	20411	44	19E
0005433496565	20411	45	19F
0005433496641	20411	46	20D
0005435242654	12159	1	1C
0005432782876	12159	2	1F
0005432782924	12159	3	2A
0005432783042	12159	4	2F
0005435242659	12159	5	3A
0005432782866	12159	6	3C
0005432782854	12159	7	4A
0005435242660	12159	8	4C
0005432783089	12159	9	4E
0005435242658	12159	10	4F
0005432782923	12159	11	5A
0005435242655	12159	12	5C
0005435242637	12159	13	5D
0005435242645	12159	14	5E
0005432782894	12159	15	6D
0005432783057	12159	16	6E
0005432782956	12159	17	7A
0005432782943	12159	18	7C
0005432782961	12159	19	7D
0005432783112	12159	20	7E
0005435242647	12159	21	8A
0005435242641	12159	22	8C
0005432783193	12159	23	8D
0005432782909	12159	24	10C
0005435242662	12159	25	10E
0005432782853	12159	26	10F
0005435242657	12159	27	11A
0005432782922	12159	28	11C
0005435242648	12159	29	11D
0005435242640	12159	30	11F
0005432782987	12159	31	12A
0005432782846	12159	32	12C
0005432782875	12159	33	12D
0005435242643	12159	34	12F
0005435242649	12159	35	13A
0005435242639	12159	36	13C
0005435242651	12159	37	14F
0005432782988	12159	38	15A
0005432782856	12159	39	15D
0005435242638	12159	40	15E
0005435242653	12159	41	15F
0005432782944	12159	42	16A
0005432782983	12159	43	16C
0005435242663	12159	44	16D
0005435242650	12159	45	17A
0005432782855	12159	46	17C
0005432782960	12159	47	17D
0005432782841	12159	48	17F
0005432782939	12159	49	18C
0005435242646	12159	50	18D
0005432782895	12159	51	18E
0005432783192	12159	52	18F
0005435242656	12159	53	19A
0005432782936	12159	54	19C
0005435242642	12159	55	19D
0005432782993	12159	56	19F
0005435242644	12159	57	20A
0005435242652	12159	58	20D
0005432782867	12159	59	20E
0005435242661	12159	60	20F
0005432783316	15410	1	1C
0005432783312	15410	2	1D
0005432783297	15410	3	1F
0005432783296	15410	4	2A
0005432783283	15410	5	2C
0005432783332	15410	6	2D
0005435242392	15410	7	2F
0005432783290	15410	8	3A
0005432783315	15410	9	3C
0005432783317	15410	10	3D
0005432783307	15410	11	4A
0005435242416	15410	12	4E
0005432783326	15410	13	4F
0005432783304	15410	14	5C
0005432783303	15410	15	5E
0005432783325	15410	16	5F
0005432783308	15410	17	6A
0005435242424	15410	18	6C
0005435242458	15410	19	7A
0005432783331	15410	20	7C
0005432783300	15410	21	7D
0005432783319	15410	22	7E
0005432783294	15410	23	7F
0005435242468	15410	24	8C
0005432783285	15410	25	8E
0005432783322	15410	26	9D
0005432783301	15410	27	9E
0005432783314	15410	28	9F
0005432783279	15410	29	10A
0005432783327	15410	30	10D
0005432783289	15410	31	10E
0005435242409	15410	32	10F
0005435242425	15410	33	11C
0005432783298	15410	34	11D
0005432783328	15410	35	11E
0005432783333	15410	36	11F
0005432783288	15410	37	12A
0005432783329	15410	38	12C
0005432783324	15410	39	12D
0005432783284	15410	40	12E
0005432783334	15410	41	12F
0005432783318	15410	42	13C
0005432783287	15410	43	13D
0005432783302	15410	44	13E
0005432783305	15410	45	13F
0005432783313	15410	46	14C
0005432783286	15410	47	14D
0005435242410	15410	48	14E
0005432783282	15410	49	14F
0005432783306	15410	50	15C
0005432783310	15410	51	16A
0005432783280	15410	52	16C
0005432783281	15410	53	16F
0005432783291	15410	54	17A
0005432783309	15410	55	17C
0005432783293	15410	56	17D
0005432783321	15410	57	17E
0005432783330	15410	58	18A
0005432783311	15410	59	18D
0005435242391	15410	60	18F
0005432783323	15410	61	19A
0005435242408	15410	62	19C
0005432783295	15410	63	19D
0005432783299	15410	64	19E
0005435242388	15410	65	19F
0005432783320	15410	66	20C
0005432783292	15410	67	20F
0005434876629	10069	1	1C
0005434876908	10069	2	1A
0005434877053	10069	3	1F
0005434876728	10069	4	1D
0005434876900	10069	5	2C
0005435913907	10069	6	3C
0005434910091	10069	7	2F
0005434876778	10069	8	3D
0005434876633	10069	9	4A
0005434876594	10069	10	3F
0005434876895	10069	11	4C
0005434876772	10069	12	4F
0005434876734	10069	13	5D
0005434876894	10069	14	5A
0005434876644	10069	15	5F
0005434758861	10069	16	6C
0005434876823	10069	17	6F
0005434876791	10069	18	7B
0005434876636	10069	19	7A
0005434876570	10069	20	7C
0005434876803	10069	21	7E
0005434876799	10069	22	7D
0005434877136	10069	23	7F
0005434876684	10069	24	8C
0005434876715	10069	25	8B
0005434876692	10069	26	8D
0005434876843	10069	27	8E
0005434876730	10069	28	9A
0005434876709	10069	29	9E
0005434876866	10069	30	10A
0005435913903	10069	31	9F
0005434876824	10069	32	10E
0005434876708	10069	33	11A
0005434876595	10069	34	10F
0005434758859	10069	35	11C
0005434876695	10069	36	11B
0005434876994	10069	37	11E
0005434876790	10069	38	11F
0005434877029	10069	39	12B
0005434876732	10069	40	12D
0005434876579	10069	41	12E
0005434876665	10069	42	13A
0005434876705	10069	43	12F
0005434758860	10069	44	13C
0005434876822	10069	45	13B
0005435913905	10069	46	13D
0005434876753	10069	47	14B
0005434876731	10069	48	14A
0005434876846	10069	49	14C
0005434876857	10069	50	14F
0005434877028	10069	51	14E
0005434876844	10069	52	15D
0005435913908	10069	53	15C
0005435913906	10069	54	15E
0005434876727	10069	55	16A
0005434877052	10069	56	16C
0005434876839	10069	57	16B
0005434876733	10069	58	16D
0005434876712	10069	59	17B
0005434876751	10069	60	17A
0005434876698	10069	61	17D
0005434876580	10069	62	17C
0005434876699	10069	63	18A
0005434876637	10069	64	18D
0005434876638	10069	65	18E
0005434876593	10069	66	19B
0005434876729	10069	67	19C
0005434876981	10069	68	20A
0005434910090	10069	69	20D
0005434876845	10069	70	20C
0005435913904	10069	71	20E
0005434876681	10069	72	21D
0005434877137	10069	73	21C
0005434876639	10069	74	21F
0005434876573	10069	75	21E
0005434877454	14628	1	1A
0005434877466	14628	2	1D
0005434877487	14628	3	2C
0005434877499	14628	4	2A
0005434877446	14628	5	1F
0005434877432	14628	6	2F
0005434877508	14628	7	2D
0005434877493	14628	8	3A
0005434877512	14628	9	3D
0005434877519	14628	10	3F
0005434877491	14628	11	4C
0005434877484	14628	12	4A
0005434877428	14628	13	4F
0005434877520	14628	14	4D
0005434877485	14628	15	5C
0005434877482	14628	16	5F
0005434877473	14628	17	5D
0005434877436	14628	18	6B
0005434877510	14628	19	6A
0005434877516	14628	20	6D
0005434877504	14628	21	6C
0005434877501	14628	22	6F
0005434877502	14628	23	6E
0005434877461	14628	24	7C
0005434877513	14628	25	7B
0005434877445	14628	26	7E
0005434877481	14628	27	7F
0005434877460	14628	28	8B
0005434877435	14628	29	8C
0005434877439	14628	30	8F
0005434877438	14628	31	8E
0005434877474	14628	32	9B
0005434877440	14628	33	9A
0005434877457	14628	34	9D
0005434877470	14628	35	9C
0005434877472	14628	36	9E
0005434877496	14628	37	10A
0005434877521	14628	38	9F
0005434877434	14628	39	10B
0005434877433	14628	40	10E
0005434877518	14628	41	10D
0005434877500	14628	42	10F
0005434877465	14628	43	11B
0005434877522	14628	44	11A
0005434877468	14628	45	11D
0005434877448	14628	46	11F
0005434877451	14628	47	12B
0005434877514	14628	48	12A
0005434877447	14628	49	12C
0005434877509	14628	50	12F
0005434877458	14628	51	12E
0005434877515	14628	52	12D
0005434877430	14628	53	13A
0005434877477	14628	54	13C
0005434877455	14628	55	13B
0005434877494	14628	56	13E
0005434877444	14628	57	13D
0005434877490	14628	58	14A
0005434877503	14628	59	13F
0005434877495	14628	60	14B
0005434877486	14628	61	14D
0005434877507	14628	62	14C
0005434758873	14628	63	14F
0005434877456	14628	64	14E
0005434877462	14628	65	15B
0005434877497	14628	66	15A
0005434877492	14628	67	15D
0005434877450	14628	68	15C
0005434877517	14628	69	15E
0005434877464	14628	70	16A
0005434877429	14628	71	15F
0005434877511	14628	72	16C
0005434877475	14628	73	16B
0005434758874	14628	74	16E
0005434877506	14628	75	16D
0005434877469	14628	76	16F
0005434877441	14628	77	17A
0005434877437	14628	78	17C
0005434758876	14628	79	17E
0005434877471	14628	80	18A
0005434877463	14628	81	17F
0005434877479	14628	82	18C
0005435913849	14628	83	18B
0005434877483	14628	84	18E
0005434877467	14628	85	18D
0005434877498	14628	86	18F
0005434877443	14628	87	19C
0005434877452	14628	88	19B
0005434877459	14628	89	19D
0005434758875	14628	90	19F
0005434877505	14628	91	20B
0005434877453	14628	92	20A
0005434877449	14628	93	20D
0005434877431	14628	94	20C
0005434877488	14628	95	20E
0005434877476	14628	96	21B
0005434877478	14628	97	21A
0005434877442	14628	98	21C
0005434877489	14628	99	21E
0005434877480	14628	100	21D
0005435660046	9209	1	1C
0005434251831	9209	2	1D
0005435660043	9209	3	2A
0005435660051	9209	4	4B
0005434251825	9209	5	5B
0005435660047	9209	6	6A
0005435660042	9209	7	6C
0005435660048	9209	8	6D
0005435660049	9209	9	7C
0005434251830	9209	10	18A
0005435660050	9209	11	18D
0005435660041	9209	12	19A
0005435660040	9209	13	21A
0005435660045	9209	14	21D
0005435660044	9209	15	23B
0005434251887	24624	1	2C
0005434251890	24624	2	2D
0005435659968	24624	3	4A
0005434251884	24624	4	4C
0005434251885	24624	5	5C
0005434251886	24624	6	6B
0005435659969	24624	7	6D
0005434251889	24624	8	7A
0005435659945	24624	9	7D
0005434251891	24624	10	18A
0005435660003	24624	11	19A
0005434251888	24624	12	19D
0005435659975	24624	13	20A
0005435659944	24624	14	20B
0005434251892	24624	15	22A
0005433680168	2769	1	1A
0005433680193	2769	2	1C
0005433680156	2769	3	1D
0005432966527	2769	4	1F
0005433680157	2769	5	2A
0005432222741	2769	6	2D
0005433680152	2769	7	3C
0005433680185	2769	8	3D
0005433680175	2769	9	3F
0005433680177	2769	10	4C
0005432222737	2769	11	4D
0005433680194	2769	12	4E
0005432222736	2769	13	5A
0005433680189	2769	14	5D
0005433680178	2769	15	5E
0005433680160	2769	16	5F
0005433680171	2769	17	6C
0005432222738	2769	18	6D
0005433680180	2769	19	6F
0005433680153	2769	20	7A
0005433680172	2769	21	7C
0005432966555	2769	22	7E
0005433680165	2769	23	7F
0005432966516	2769	24	8A
0005433680179	2769	25	8C
0005432966545	2769	26	9A
0005433684402	2769	27	9D
0005432222739	2769	28	9E
0005433680162	2769	29	9F
0005432966528	2769	30	10A
0005432966537	2769	31	10C
0005433680182	2769	32	10D
0005433680187	2769	33	10E
0005433680174	2769	34	10F
0005432222740	2769	35	11A
0005433680167	2769	36	11C
0005433680150	2769	37	11D
0005433680192	2769	38	11E
0005433680173	2769	39	11F
0005433680149	2769	40	12A
0005433680195	2769	41	12C
0005433680170	2769	42	13A
0005433680186	2769	43	13C
0005433680151	2769	44	13D
0005433680166	2769	45	13E
0005433680158	2769	46	14A
0005433680196	2769	47	14E
0005433680176	2769	48	15A
0005432966532	2769	49	15D
0005433680155	2769	50	15F
0005433680181	2769	51	16A
0005433680164	2769	52	16C
0005433680184	2769	53	16D
0005433680190	2769	54	16E
0005433680161	2769	55	16F
0005432966556	2769	56	17C
0005432966597	2769	57	17D
0005433680169	2769	58	17E
0005433680183	2769	59	17F
0005432966596	2769	60	18C
0005433680159	2769	61	18D
0005433680191	2769	62	18F
0005433684401	2769	63	19E
0005432966535	2769	64	19F
0005433680163	2769	65	20C
0005433680154	2769	66	20D
0005433680188	2769	67	20E
0005433690894	29182	1	1A
0005433679804	29182	2	1C
0005432005190	29182	3	1D
0005432966726	29182	4	1F
0005432966721	29182	5	2A
0005432966729	29182	6	2C
0005433679760	29182	7	2D
0005433679759	29182	8	2F
0005433679709	29182	9	3A
0005432966737	29182	10	3C
0005432966731	29182	11	3D
0005433679782	29182	12	3F
0005432966724	29182	13	4A
0005432966719	29182	14	4E
0005433679779	29182	15	4F
0005433679778	29182	16	5A
0005433679983	29182	17	5C
0005433679851	29182	18	5D
0005432005192	29182	19	5E
0005432966727	29182	20	6A
0005433679922	29182	21	6D
0005433679920	29182	22	6E
0005432005189	29182	23	6F
0005432966725	29182	24	7A
0005432966732	29182	25	7D
0005432966735	29182	26	7E
0005433679801	29182	27	7F
0005432966738	29182	28	8A
0005433679931	29182	29	8C
0005432966730	29182	30	8D
0005433679813	29182	31	8E
0005432966733	29182	32	8F
0005433684390	29182	33	9A
0005433679953	29182	34	9C
0005433679811	29182	35	9D
0005432966740	29182	36	10C
0005433679789	29182	37	10D
0005433679899	29182	38	10E
0005433679841	29182	39	11A
0005433679825	29182	40	11C
0005433679863	29182	41	11D
0005432966717	29182	42	11E
0005433679919	29182	43	12C
0005433679860	29182	44	12D
0005432966728	29182	45	12E
0005433679900	29182	46	12F
0005433679952	29182	47	13A
0005432966722	29182	48	13C
0005433679861	29182	49	13D
0005433679719	29182	50	13F
0005433684392	29182	51	14A
0005432966723	29182	52	14C
0005432966718	29182	53	14F
0005433679862	29182	54	15C
0005432966739	29182	55	15F
0005433679872	29182	56	16D
0005433679857	29182	57	16E
0005432966736	29182	58	16F
0005432005191	29182	59	17A
0005433679907	29182	60	17C
0005433690899	29182	61	17E
0005433679814	29182	62	17F
0005432966720	29182	63	18A
0005433679923	29182	64	18C
0005433679944	29182	65	18D
0005433679873	29182	66	18E
0005433679800	29182	67	18F
0005433679917	29182	68	19A
0005432966734	29182	69	19C
0005433679824	29182	70	19D
0005432966716	29182	71	19E
0005433679718	29182	72	19F
0005433679712	29182	73	20D
0005433679738	29182	74	20E
0005433679783	29182	75	20F
0005433614005	9281	1	1A
0005433633505	9281	2	1C
0005433614052	9281	3	1D
0005433614032	9281	4	2A
0005433577695	9281	5	1F
0005433613997	9281	6	2D
0005432145093	9281	7	3C
0005433614014	9281	8	3A
0005433577696	9281	9	4A
0005433614036	9281	10	3F
0005433613986	9281	11	4C
0005433614015	9281	12	4F
0005433614001	9281	13	4D
0005433614044	9281	14	5A
0005433633492	9281	15	5C
0005433614004	9281	16	5D
0005433614040	9281	17	6A
0005433633501	9281	18	5F
0005433633519	9281	19	6D
0005433633513	9281	20	6C
0005433633514	9281	21	6F
0005433633509	9281	22	7A
0005433577686	9281	23	7C
0005433577693	9281	24	7D
0005432756819	9281	25	8A
0005433614025	9281	26	7F
0005433614057	9281	27	8D
0005433614043	9281	28	8C
0005433614006	9281	29	8E
0005433633495	9281	30	8F
0005433614022	9281	31	9B
0005433614026	9281	32	9C
0005433614021	9281	33	9D
0005433633517	9281	34	9F
0005433577687	9281	35	9E
0005433614046	9281	36	10B
0005433614042	9281	37	10D
0005433633521	9281	38	10C
0005432756820	9281	39	10E
0005433633506	9281	40	10F
0005433614039	9281	41	11B
0005433577697	9281	42	11A
0005432755045	9281	43	11C
0005433577694	9281	44	11D
0005433614010	9281	45	11E
0005433614055	9281	46	12A
0005433577689	9281	47	11F
0005433614028	9281	48	12B
0005433633498	9281	49	12E
0005433613991	9281	50	12D
0005433613992	9281	51	13A
0005433614003	9281	52	12F
0005433633504	9281	53	13C
0005433614041	9281	54	13B
0005432756818	9281	55	13D
0005433633520	9281	56	13E
0005433633524	9281	57	14A
0005434163480	9281	58	13F
0005433633500	9281	59	14B
0005434163506	9281	60	14D
0005433613994	9281	61	14C
0005434152755	9281	62	14E
0005433633499	9281	63	14F
0005433633512	9281	64	15A
0005433614017	9281	65	15C
0005432755046	9281	66	15B
0005432755047	9281	67	15D
0005433613990	9281	68	15E
0005433614038	9281	69	16A
0005434163482	9281	70	15F
0005433633496	9281	71	16B
0005433633497	9281	72	16D
0005433614007	9281	73	16E
0005434272170	9281	74	16F
0005433614024	9281	75	17B
0005434163468	9281	76	17A
0005433614054	9281	77	17E
0005433613995	9281	78	17D
0005433633494	9281	79	18B
0005433614019	9281	80	18A
0005434163478	9281	81	18C
0005433633493	9281	82	18D
0005433577685	9281	83	18E
0005433614023	9281	84	19B
0005433577691	9281	85	19C
0005433633525	9281	86	19E
0005433633515	9281	87	19D
0005433614030	9281	88	20A
0005433614034	9281	89	20C
0005433614049	9281	90	20E
0005433614047	9281	91	20D
0005433613993	9281	92	20F
0005433633502	9281	93	21A
0005433614009	9281	94	21C
0005433633511	9281	95	21B
0005433614027	9281	96	21D
0005433614048	9281	97	22A
0005433614012	9281	98	21F
0005433613985	9281	99	22B
0005434272169	9281	100	22D
0005433614011	9281	101	22C
0005433613987	9281	102	22E
0005433633526	9281	103	23A
0005433633523	9281	104	23B
0005433577690	9281	105	23D
0005433613988	9281	106	23F
0005433614051	9281	107	23E
0005433577692	9281	108	24B
0005433613989	9281	109	24A
0005433614002	9281	110	24D
0005433633508	9281	111	24C
0005433614053	9281	112	24E
0005434163481	9281	113	24F
0005433633516	9281	114	25B
0005433633522	9281	115	25C
0005433614031	9281	116	25D
0005433614008	9281	117	25E
0005434163469	9281	118	26A
0005432755048	9281	119	25F
0005433614059	9281	120	26E
0005433633518	9281	121	26D
0005433613999	9281	122	26F
0005433614016	9281	123	27B
0005433614037	9281	124	27A
0005433633510	9281	125	27C
0005433614033	9281	126	28B
0005433614013	9281	127	28C
0005433577698	9281	128	28D
0005433613996	9281	129	29A
0005433614029	9281	130	29C
0005433613998	9281	131	29B
0005433614035	9281	132	29F
0005433633503	9281	133	29E
0005433614000	9281	134	30A
0005433614018	9281	135	30B
0005434163466	9281	136	30C
0005434163479	9281	137	30D
0005433614050	9281	138	30F
0005433577688	9281	139	31B
0005433633507	9281	140	31A
0005433614058	9281	141	31C
0005433614056	9281	142	31E
0005433614045	9281	143	31D
0005433614020	9281	144	31F
0005433613447	25264	1	2C
0005433577563	25264	2	3A
0005434272176	25264	3	3C
0005433633336	25264	4	3D
0005434273062	25264	5	4C
0005433613561	25264	6	4F
0005433633248	25264	7	5C
0005433633227	25264	8	6A
0005433613546	25264	9	6C
0005434163537	25264	10	8A
0005434163547	25264	11	8E
0005433613460	25264	12	9B
0005433577581	25264	13	9A
0005433613562	25264	14	9C
0005433613710	25264	15	9D
0005433633284	25264	16	9E
0005433633279	25264	17	10B
0005433613545	25264	18	10E
0005433613652	25264	19	10D
0005433577612	25264	20	10F
0005433613633	25264	21	11B
0005433613392	25264	22	11D
0005434163541	25264	23	11C
0005434163539	25264	24	12A
0005434272177	25264	25	12B
0005433613437	25264	26	12E
0005433613395	25264	27	12D
0005433613454	25264	28	12F
0005434163540	25264	29	13C
0005433633251	25264	30	13B
0005433613535	25264	31	13D
0005435854045	25264	32	14E
0005433633363	25264	33	16A
0005433613653	25264	34	16B
0005434163543	25264	35	16F
0005433577580	25264	36	17A
0005433613523	25264	37	17C
0005433633250	25264	38	17D
0005434163544	25264	39	17F
0005434163546	25264	40	18A
0005433613518	25264	41	18F
0005434163542	25264	42	19B
0005433613566	25264	43	19D
0005433613413	25264	44	19C
0005433613663	25264	45	19E
0005433613522	25264	46	20B
0005433613448	25264	47	20C
0005434163548	25264	48	20E
0005434163545	25264	49	21B
0005433613393	25264	50	21C
0005433577611	25264	51	22A
0005433613662	25264	52	22F
0005433633290	25264	53	25A
0005433577614	25264	54	25C
0005433613455	25264	55	25D
0005433613405	25264	56	25E
0005433613503	25264	57	26C
0005433613412	25264	58	26E
0005433613664	25264	59	27F
0005435854046	25264	60	28A
0005433613406	25264	61	28B
0005433613567	25264	62	28D
0005434163538	25264	63	28E
0005433633254	25264	64	28F
0005433633283	25264	65	29B
0005433577595	25264	66	29C
0005433613505	25264	67	29E
0005433613519	25264	68	30B
0005433613394	25264	69	30E
0005433613660	25264	70	31A
0005433633297	25264	71	31C
0005433633285	25264	72	31B
0005435854047	25264	73	31F
0005433633271	25264	74	31E
0005435947038	4233	1	5F
0005435986710	4233	2	11B
0005435986709	4233	3	12D
0005435947016	4233	4	14A
0005435986714	4233	5	15A
0005435787320	4233	6	15E
0005434271281	4233	7	16D
0005435947028	4233	8	16B
0005435947036	4233	9	16H
0005435947037	4233	10	17E
0005435986707	4233	11	17G
0005435986713	4233	12	18D
0005435947003	4233	13	19D
0005435986711	4233	14	27H
0005435986708	4233	15	28F
0005435947030	4233	16	29E
0005435986715	4233	17	30D
0005432184928	4233	18	34G
0005435986712	4233	19	35D
0005432571258	4233	20	36F
0005435856133	4233	21	37B
0005435947031	4233	22	38A
0005432571292	26607	1	1G
0005435856169	26607	2	2B
0005435947135	26607	3	4G
0005435947145	26607	4	5C
0005435856168	26607	5	11F
0005435787338	26607	6	12A
0005435947144	26607	7	12E
0005435856170	26607	8	15B
0005432571293	26607	9	15F
0005435947136	26607	10	16D
0005435947143	26607	11	16B
0005435856171	26607	12	17D
0005435947133	26607	13	21D
0005435787340	26607	14	21E
0005435787339	26607	15	23B
0005435947139	26607	16	23G
0005435947138	26607	17	24D
0005432571294	26607	18	29H
0005435947140	26607	19	30A
0005435947134	26607	20	30F
0005435947142	26607	21	31F
0005435947132	26607	22	33E
0005435947141	26607	23	36G
0005435856172	26607	24	37A
0005435947137	26607	25	37E
0005432947955	315	1	1C
0005433074241	315	2	1D
0005433568567	315	3	2C
0005432947824	315	4	2A
0005432947779	315	5	2D
0005433568550	315	6	2F
0005433074216	315	7	3C
0005433568587	315	8	3F
0005433568592	315	9	5A
0005433568595	315	10	5C
0005433129201	315	11	5F
0005433568597	315	12	5D
0005433568559	315	13	6A
0005432947823	315	14	6D
0005433568600	315	15	6C
0005433074217	315	16	7A
0005432238889	315	17	7D
0005433568575	315	18	8A
0005433074280	315	19	7F
0005433568588	315	20	8B
0005433568590	315	21	8D
0005433074215	315	22	8C
0005432947899	315	23	8E
0005432947915	315	24	9B
0005433568593	315	25	9A
0005433568558	315	26	9C
0005433568605	315	27	9E
0005433568544	315	28	9D
0005433568548	315	29	10A
0005433568594	315	30	10C
0005432947954	315	31	10B
0005433074251	315	32	10E
0005432947881	315	33	10D
0005433568546	315	34	10F
0005433568585	315	35	11B
0005432947916	315	36	11C
0005433568564	315	37	11D
0005432238884	315	38	11F
0005433568549	315	39	12B
0005433074296	315	40	12D
0005433074300	315	41	12C
0005433568547	315	42	13B
0005433074256	315	43	13C
0005433568562	315	44	13D
0005433568573	315	45	13F
0005433568561	315	46	14A
0005432238887	315	47	14D
0005433568563	315	48	14E
0005432947825	315	49	14F
0005433134058	315	50	15B
0005433568582	315	51	15C
0005432238886	315	52	15D
0005432238885	315	53	16B
0005433074214	315	54	16F
0005433568602	315	55	16E
0005433568599	315	56	17A
0005432947917	315	57	17C
0005433568579	315	58	17B
0005433568552	315	59	17D
0005432947803	315	60	17F
0005433568591	315	61	17E
0005433074297	315	62	18B
0005433568569	315	63	18D
0005433568572	315	64	18C
0005433568598	315	65	18E
0005433568571	315	66	18F
0005433074211	315	67	19C
0005433074328	315	68	19D
0005432947882	315	69	20A
0005433568556	315	70	19E
0005433074225	315	71	20B
0005433568578	315	72	20C
0005433568601	315	73	20E
0005433568554	315	74	20D
0005433568551	315	75	20F
0005433074212	315	76	21B
0005433074213	315	77	21E
0005433568584	315	78	21F
0005432947956	315	79	22D
0005433074363	315	80	22C
0005433568580	315	81	22F
0005433074255	315	82	22E
0005433568570	315	83	23A
0005433568545	315	84	23B
0005433568555	315	85	23D
0005433568553	315	86	23F
0005433074275	315	87	23E
0005433074334	315	88	24A
0005433568586	315	89	24D
0005433568576	315	90	24C
0005433074299	315	91	24E
0005432947953	315	92	24F
0005433568604	315	93	25B
0005433074252	315	94	25D
0005433568583	315	95	25E
0005433074281	315	96	26A
0005432947931	315	97	25F
0005433568565	315	98	26B
0005433129200	315	99	26E
0005433074230	315	100	26F
0005433074257	315	101	27A
0005433568577	315	102	27E
0005433568574	315	103	27C
0005433568581	315	104	27F
0005433074333	315	105	28B
0005433074231	315	106	28A
0005433074277	315	107	28C
0005433568568	315	108	28E
0005433568589	315	109	29B
0005432947857	315	110	29E
0005433568603	315	111	30A
0005432238888	315	112	29F
0005433568596	315	113	30D
0005433568560	315	114	30E
0005433568566	315	115	31B
0005433568557	315	116	31A
0005432947932	315	117	31E
0005432948117	11597	1	1C
0005432948114	11597	2	1F
0005433074470	11597	3	1D
0005432948126	11597	4	2A
0005433074461	11597	5	3A
0005432948129	11597	6	3C
0005432948125	11597	7	4A
0005433074486	11597	8	4F
0005433074469	11597	9	5F
0005433134098	11597	10	6C
0005432948121	11597	11	6F
0005432948109	11597	12	7A
0005432192295	11597	13	7C
0005432948134	11597	14	7D
0005433074464	11597	15	8C
0005433074484	11597	16	8D
0005432948135	11597	17	8F
0005432192292	11597	18	9D
0005433074460	11597	19	9E
0005433074468	11597	20	10A
0005433131673	11597	21	10C
0005433074462	11597	22	10D
0005432948136	11597	23	10F
0005432948111	11597	24	11C
0005433568082	11597	25	11B
0005432948107	11597	26	12E
0005433568076	11597	27	12D
0005433074472	11597	28	12F
0005433074466	11597	29	13D
0005432948115	11597	30	13E
0005433131671	11597	31	14A
0005433568073	11597	32	13F
0005433568071	11597	33	14B
0005433074482	11597	34	14D
0005433568070	11597	35	14E
0005433134102	11597	36	14F
0005432948120	11597	37	15B
0005433074467	11597	38	15C
0005432948124	11597	39	15F
0005433134099	11597	40	16D
0005432192293	11597	41	17B
0005432948108	11597	42	17A
0005433074478	11597	43	17E
0005433131672	11597	44	17F
0005432948105	11597	45	18C
0005432948131	11597	46	18B
0005433074459	11597	47	18D
0005433568027	11597	48	18E
0005433568033	11597	49	18F
0005432948110	11597	50	19C
0005433074480	11597	51	19B
0005433568072	11597	52	19E
0005433568023	11597	53	19D
0005433074476	11597	54	20B
0005432948132	11597	55	20C
0005433074481	11597	56	21A
0005432948097	11597	57	21B
0005432948138	11597	58	21E
0005432948116	11597	59	22A
0005432948099	11597	60	21F
0005433074487	11597	61	22B
0005433074485	11597	62	22D
0005432948127	11597	63	22C
0005432948137	11597	64	22F
0005433134101	11597	65	23A
0005433074477	11597	66	23C
0005432948130	11597	67	23B
0005433074475	11597	68	23D
0005433131669	11597	69	24A
0005432948123	11597	70	24B
0005433074474	11597	71	24F
0005432948102	11597	72	25A
0005432948106	11597	73	25D
0005432948112	11597	74	25F
0005432948104	11597	75	26B
0005432192294	11597	76	26A
0005432948119	11597	77	26E
0005433074471	11597	78	26F
0005433131670	11597	79	27B
0005432948101	11597	80	27C
0005433074473	11597	81	27E
0005432948098	11597	82	28C
0005432948118	11597	83	28B
0005433074483	11597	84	28E
0005432948133	11597	85	29B
0005433074463	11597	86	29A
0005433131668	11597	87	29C
0005433074479	11597	88	29E
0005432948100	11597	89	29D
0005433074465	11597	90	29F
0005432948128	11597	91	30C
0005432948113	11597	92	30D
0005432948122	11597	93	30E
0005432948103	11597	94	31C
0005433134100	11597	95	31E
0005433817439	9984	1	1A
0005434732933	9984	2	1B
0005433817438	9984	3	2A
0005433817440	9984	4	2B
0005433817441	9984	5	3B
0005434732926	9984	6	4A
0005434732927	9984	7	4B
0005434732928	9984	8	6B
0005434732953	14002	1	1A
0005433817427	14002	2	2B
0005434732951	14002	3	3A
0005434732952	14002	4	3B
0005434732954	14002	5	4A
0005432984553	2350	1	1B
0005435981947	2350	2	1A
0005432984600	2350	3	1C
0005435981927	2350	4	1F
0005432984583	2350	5	1G
0005432869420	2350	6	2A
0005435981937	2350	7	1H
0005433753794	2350	8	2C
0005435981960	2350	9	2B
0005433753766	2350	10	2F
0005433434218	2350	11	2G
0005433753782	2350	12	3A
0005433753754	2350	13	2H
0005432984555	2350	14	3B
0005433434259	2350	15	3H
0005435981953	2350	16	3G
0005432226009	2350	17	4B
0005432984581	2350	18	4F
0005435981936	2350	19	4G
0005432984562	2350	20	5B
0005433753772	2350	21	5A
0005435981938	2350	22	5F
0005432984539	2350	23	5C
0005433753758	2350	24	5G
0005432300214	2350	25	9G
0005435981958	2350	26	11A
0005433753748	2350	27	11D
0005433753759	2350	28	11E
0005432984559	2350	29	11F
0005433753784	2350	30	11G
0005433753780	2350	31	12A
0005433753762	2350	32	11H
0005432226007	2350	33	12B
0005433753745	2350	34	12E
0005434731098	2350	35	12D
0005433753761	2350	36	12F
0005435981928	2350	37	12H
0005433753760	2350	38	12G
0005432655444	2350	39	13B
0005433753769	2350	40	13A
0005433764663	2350	41	13D
0005432655436	2350	42	13E
0005432226008	2350	43	13G
0005432655441	2350	44	13F
0005433753795	2350	45	13H
0005432984603	2350	46	14A
0005435981959	2350	47	14D
0005433753793	2350	48	14B
0005433766609	2350	49	14E
0005432226005	2350	50	15A
0005433753749	2350	51	15E
0005433434260	2350	52	15G
0005433434235	2350	53	15F
0005433434261	2350	54	15H
0005435981925	2350	55	16D
0005432984627	2350	56	16B
0005433753757	2350	57	16F
0005432655438	2350	58	16H
0005433753781	2350	59	17B
0005432984588	2350	60	17A
0005435981946	2350	61	17D
0005433766608	2350	62	17G
0005435981950	2350	63	17H
0005435981934	2350	64	18D
0005435981952	2350	65	18F
0005435981945	2350	66	18E
0005432300218	2350	67	18G
0005433753776	2350	68	19B
0005435981949	2350	69	19G
0005433753742	2350	70	20A
0005433753783	2350	71	19H
0005433753790	2350	72	20B
0005435981951	2350	73	20E
0005433753775	2350	74	20G
0005432984636	2350	75	21A
0005433753755	2350	76	21D
0005432300216	2350	77	21E
0005432655442	2350	78	21F
0005432984584	2350	79	21H
0005433753739	2350	80	21G
0005433753791	2350	81	22A
0005433753768	2350	82	22D
0005433753764	2350	83	22B
0005432984612	2350	84	22F
0005433753752	2350	85	22G
0005433753774	2350	86	22H
0005432984633	2350	87	23E
0005433753786	2350	88	23D
0005435981926	2350	89	23B
0005433434234	2350	90	23G
0005432300215	2350	91	23F
0005432655440	2350	92	23H
0005433753777	2350	93	24B
0005432300217	2350	94	24F
0005432300220	2350	95	24H
0005432226004	2350	96	24G
0005435981935	2350	97	25D
0005435981942	2350	98	25E
0005433753787	2350	99	27A
0005432655447	2350	100	25F
0005433753773	2350	101	27B
0005433434270	2350	102	27F
0005433753765	2350	103	27E
0005433753751	2350	104	27G
0005433753750	2350	105	28A
0005433753779	2350	106	28B
0005432655446	2350	107	28E
0005432655448	2350	108	28D
0005433753778	2350	109	28F
0005433753770	2350	110	28H
0005432300219	2350	111	28G
0005433753744	2350	112	29A
0005432984533	2350	113	29B
0005435981961	2350	114	29F
0005432984727	2350	115	29E
0005435981944	2350	116	29D
0005435981930	2350	117	29H
0005432984579	2350	118	29G
0005433753756	2350	119	30A
0005433434258	2350	120	30D
0005433764662	2350	121	30B
0005432984556	2350	122	30E
0005432655439	2350	123	30G
0005433753789	2350	124	30F
0005435981929	2350	125	31A
0005432655437	2350	126	30H
0005433434257	2350	127	31B
0005435981932	2350	128	31E
0005433753747	2350	129	31D
0005432655443	2350	130	31F
0005433434223	2350	131	31G
0005435981954	2350	132	32A
0005433434236	2350	133	31H
0005432869419	2350	134	32B
0005435981940	2350	135	32E
0005432984632	2350	136	32F
0005435981957	2350	137	32G
0005432984580	2350	138	33A
0005433753792	2350	139	33B
0005433753746	2350	140	33E
0005434731106	2350	141	33D
0005435981955	2350	142	33G
0005433753740	2350	143	33F
0005433753796	2350	144	33H
0005435981933	2350	145	34A
0005435981931	2350	146	34D
0005432226003	2350	147	34B
0005433753741	2350	148	34E
0005433434284	2350	149	34G
0005435981943	2350	150	35A
0005433753743	2350	151	34H
0005432984552	2350	152	35B
0005433434256	2350	153	35E
0005432984618	2350	154	35G
0005432655445	2350	155	35H
0005432984587	2350	156	36B
0005433753767	2350	157	36A
0005433434219	2350	158	36E
0005433753785	2350	159	36F
0005435981941	2350	160	36H
0005433753763	2350	161	36G
0005435981948	2350	162	37B
0005433434347	2350	163	37E
0005433434255	2350	164	37D
0005435981956	2350	165	37G
0005433753771	2350	166	37F
0005433753753	2350	167	38A
0005433434222	2350	168	37H
0005435981924	2350	169	38B
0005433766610	2350	170	38E
0005432226006	2350	171	38F
0005435981939	2350	172	38G
0005432984601	2350	173	39D
0005433753788	2350	174	39F
0005433434269	2350	175	39E
0005433753224	26188	1	1A
0005433753281	26188	2	1C
0005432984822	26188	3	1B
0005435981522	26188	4	1F
0005432984812	26188	5	1H
0005433434452	26188	6	2A
0005433434461	26188	7	2B
0005433753473	26188	8	2F
0005432984808	26188	9	2C
0005433753369	26188	10	3A
0005433753325	26188	11	3B
0005432051104	26188	12	3F
0005432984810	26188	13	3C
0005433753222	26188	14	3H
0005433434456	26188	15	4C
0005432869468	26188	16	4G
0005432984815	26188	17	4H
0005432984816	26188	18	5A
0005432984811	26188	19	5F
0005435981546	26188	20	5H
0005435981606	26188	21	9H
0005433766578	26188	22	11B
0005433434466	26188	23	11E
0005433753294	26188	24	11H
0005433434446	26188	25	12A
0005433434451	26188	26	12D
0005433753349	26188	27	12B
0005433753437	26188	28	12E
0005432655337	26188	29	12G
0005432049435	26188	30	12F
0005433753324	26188	31	13B
0005432869472	26188	32	13A
0005432051103	26188	33	13D
0005433753389	26188	34	13E
0005433434460	26188	35	13G
0005433434444	26188	36	14A
0005432984799	26188	37	14E
0005435981547	26188	38	14B
0005433434465	26188	39	14F
0005434731138	26188	40	14G
0005433753460	26188	41	15A
0005432984801	26188	42	15E
0005433753472	26188	43	15D
0005433434445	26188	44	15F
0005435981587	26188	45	15H
0005432984819	26188	46	16D
0005433753348	26188	47	16G
0005433434443	26188	48	16H
0005432984806	26188	49	17A
0005433753531	26188	50	17D
0005432655335	26188	51	17E
0005435981583	26188	52	17G
0005432869466	26188	53	17H
0005432051102	26188	54	18B
0005433753221	26188	55	18D
0005433434467	26188	56	18E
0005433753368	26188	57	18G
0005435981554	26188	58	19A
0005432049434	26188	59	18H
0005433753408	26188	60	19D
0005433753415	26188	61	19B
0005432984803	26188	62	19H
0005433766577	26188	63	20A
0005433753282	26188	64	20D
0005433434442	26188	65	20B
0005433753478	26188	66	20E
0005435981553	26188	67	20F
0005433753261	26188	68	20H
0005435981550	26188	69	21D
0005435981524	26188	70	21E
0005433753293	26188	71	21G
0005433434462	26188	72	21H
0005433434454	26188	73	22B
0005433753225	26188	74	22D
0005432869470	26188	75	22E
0005433434447	26188	76	22G
0005433434453	26188	77	22F
0005435981582	26188	78	22H
0005432984827	26188	79	23A
0005432984800	26188	80	23E
0005433434449	26188	81	23D
0005435981520	26188	82	23F
0005432984814	26188	83	23H
0005432869471	26188	84	24B
0005432049433	26188	85	24A
0005433753226	26188	86	24D
0005433753420	26188	87	24F
0005433753530	26188	88	24G
0005433753367	26188	89	25F
0005432984813	26188	90	27B
0005433434455	26188	91	27A
0005432984807	26188	92	27D
0005432984820	26188	93	27G
0005432984828	26188	94	28A
0005432984804	26188	95	28E
0005433753421	26188	96	28D
0005432869465	26188	97	28G
0005433434458	26188	98	29B
0005432984809	26188	99	29A
0005435981585	26188	100	28H
0005432051101	26188	101	30D
0005433434450	26188	102	30F
0005435981627	26188	103	30E
0005432984825	26188	104	30G
0005432984818	26188	105	31A
0005433434464	26188	106	30H
0005433766587	26188	107	31B
0005432984824	26188	108	31D
0005432984823	26188	109	31F
0005433753386	26188	110	31E
0005432984829	26188	111	31H
0005432869467	26188	112	32E
0005433434439	26188	113	32D
0005435981552	26188	114	33A
0005433753407	26188	115	32H
0005434731136	26188	116	33D
0005432984826	26188	117	33B
0005434731135	26188	118	33E
0005435981648	26188	119	33G
0005433434448	26188	120	34D
0005435981638	26188	121	34B
0005434731137	26188	122	34E
0005432984830	26188	123	34G
0005433753443	26188	124	34F
0005433753283	26188	125	35A
0005432984817	26188	126	35B
0005433753409	26188	127	35D
0005433753297	26188	128	35F
0005432984831	26188	129	35E
0005432984805	26188	130	36A
0005435981523	26188	131	35H
0005433753326	26188	132	36G
0005433434463	26188	133	36H
0005432655336	26188	134	37A
0005435981647	26188	135	37E
0005433434459	26188	136	37D
0005433753250	26188	137	37F
0005433434441	26188	138	37H
0005433764643	26188	139	37G
0005433434457	26188	140	38B
0005433753479	26188	141	38E
0005432984821	26188	142	38D
0005433753279	26188	143	38F
0005433434468	26188	144	38H
0005432869469	26188	145	39E
0005432984802	26188	146	39D
0005433434440	26188	147	39F
0005434374257	1495	1	1C
0005434374277	1495	2	1D
0005433461570	1495	3	1F
0005434374291	1495	4	2A
0005433150852	1495	5	2D
0005434374270	1495	6	3A
0005434374302	1495	7	3D
0005434374305	1495	8	3F
0005433150980	1495	9	4C
0005434029613	1495	10	4B
0005433150800	1495	11	5A
0005434374264	1495	12	5C
0005434374256	1495	13	5D
0005434374273	1495	14	5E
0005433150875	1495	15	5F
0005433150817	1495	16	6B
0005432267838	1495	17	6C
0005434374298	1495	18	6D
0005434374280	1495	19	6E
0005434374293	1495	20	7A
0005432267841	1495	21	7C
0005434374294	1495	22	7D
0005434374269	1495	23	7F
0005434374309	1495	24	7E
0005434374292	1495	25	8A
0005434374253	1495	26	8B
0005433764651	1495	27	8D
0005434374255	1495	28	8F
0005434374254	1495	29	9A
0005433460419	1495	30	9B
0005433150930	1495	31	9C
0005434374265	1495	32	9E
0005434374285	1495	33	9F
0005433150840	1495	34	10B
0005432267844	1495	35	10C
0005434374283	1495	36	10E
0005434374258	1495	37	11B
0005433150960	1495	38	11D
0005434374266	1495	39	11F
0005433150943	1495	40	11E
0005433150981	1495	41	12A
0005433150965	1495	42	12B
0005432267842	1495	43	12D
0005433150951	1495	44	13A
0005433150952	1495	45	13C
0005434374261	1495	46	13B
0005433150870	1495	47	13D
0005434374286	1495	48	13F
0005433150843	1495	49	13E
0005434374274	1495	50	14A
0005433150957	1495	51	14C
0005433150841	1495	52	14B
0005433150922	1495	53	14E
0005433461571	1495	54	14F
0005434374271	1495	55	15B
0005434374301	1495	56	15C
0005433150876	1495	57	15D
0005434374300	1495	58	15F
0005433150872	1495	59	15E
0005434374260	1495	60	16A
0005433150893	1495	61	16B
0005434374252	1495	62	16D
0005434374272	1495	63	16E
0005434374295	1495	64	17A
0005433150871	1495	65	16F
0005434374304	1495	66	17B
0005433150950	1495	67	17D
0005434374290	1495	68	17C
0005434374281	1495	69	17F
0005434374306	1495	70	18A
0005434374289	1495	71	18B
0005434374259	1495	72	18D
0005434374308	1495	73	18C
0005434374287	1495	74	18E
0005432267840	1495	75	18F
0005434374284	1495	76	19A
0005434374303	1495	77	19C
0005434374262	1495	78	19B
0005434374267	1495	79	19D
0005433931431	1495	80	19E
0005432267839	1495	81	19F
0005433150874	1495	82	20B
0005434374268	1495	83	20A
0005434374307	1495	84	20C
0005434374296	1495	85	20D
0005434374288	1495	86	20E
0005434374297	1495	87	21B
0005434374299	1495	88	21A
0005434374282	1495	89	21C
0005434374263	1495	90	21D
0005433150842	1495	91	21F
0005433150961	1495	92	22A
0005434374278	1495	93	22B
0005433150990	1495	94	22C
0005433150944	1495	95	22E
0005434374276	1495	96	23A
0005432267843	1495	97	23C
0005434374275	1495	98	23E
0005434374279	1495	99	23D
0005433150818	1495	100	23F
0005434373895	20110	1	1C
0005433151132	20110	2	1F
0005433151134	20110	3	1D
0005432056266	20110	4	2C
0005432056267	20110	5	3A
0005434373948	20110	6	3D
0005433151122	20110	7	3C
0005434373866	20110	8	3F
0005433151124	20110	9	4B
0005434373939	20110	10	4D
0005434374020	20110	11	5E
0005434374022	20110	12	6B
0005433151121	20110	13	6A
0005434373875	20110	14	6C
0005434374011	20110	15	6D
0005434374021	20110	16	6F
0005434373947	20110	17	7A
0005434373940	20110	18	7C
0005433931441	20110	19	7D
0005434373982	20110	20	7E
0005434373944	20110	21	7F
0005433151136	20110	22	8B
0005433764662	20110	23	8A
0005433151126	20110	24	8C
0005433151143	20110	25	8D
0005433151127	20110	26	8F
0005433151137	20110	27	9A
0005434373897	20110	28	9C
0005433151112	20110	29	9F
0005434373917	20110	30	9E
0005434374019	20110	31	10B
0005433151111	20110	32	10E
0005434373949	20110	33	10D
0005434373991	20110	34	11A
0005433151117	20110	35	11D
0005432056269	20110	36	11F
0005432056270	20110	37	12B
0005434373880	20110	38	12C
0005433151123	20110	39	12E
0005434373983	20110	40	12F
0005433151118	20110	41	13A
0005434373946	20110	42	13C
0005433151131	20110	43	13D
0005433151116	20110	44	13E
0005434029635	20110	45	13F
0005434029637	20110	46	14B
0005434373950	20110	47	14C
0005433764663	20110	48	14E
0005433151144	20110	49	14F
0005433151125	20110	50	15A
0005434373997	20110	51	15B
0005433151113	20110	52	15D
0005434373972	20110	53	15E
0005433151141	20110	54	15F
0005433151139	20110	55	16C
0005434373894	20110	56	16D
0005433931440	20110	57	16E
0005434373951	20110	58	17B
0005433151119	20110	59	17A
0005433151135	20110	60	17D
0005434374012	20110	61	17E
0005433151110	20110	62	18A
0005433151142	20110	63	17F
0005433151138	20110	64	18C
0005433151114	20110	65	18E
0005433151128	20110	66	18F
0005433151140	20110	67	19B
0005433151120	20110	68	19D
0005433151115	20110	69	19F
0005434373879	20110	70	19E
0005433151130	20110	71	20E
0005434373896	20110	72	20F
0005434029636	20110	73	21C
0005434374007	20110	74	21F
0005433151129	20110	75	22B
0005432056268	20110	76	23A
0005433151133	20110	77	23D
0005434373990	20110	78	23F
0005432424059	599	1	2C
0005432424075	599	2	3C
0005432282808	599	3	3D
0005432424068	599	4	4A
0005432282806	599	5	3F
0005432424095	599	6	5C
0005432424071	599	7	6A
0005432424087	599	8	6F
0005432424094	599	9	7D
0005432424069	599	10	8A
0005432424061	599	11	8B
0005432424092	599	12	8C
0005432282804	599	13	8E
0005432424096	599	14	8D
0005432424080	599	15	8F
0005432282809	599	16	9E
0005432424081	599	17	10B
0005432424090	599	18	10E
0005432424079	599	19	12F
0005432282807	599	20	13A
0005432424082	599	21	13D
0005432424088	599	22	14B
0005432424076	599	23	14E
0005432424084	599	24	15B
0005432424083	599	25	15C
0005432424093	599	26	16B
0005432424063	599	27	16D
0005432424086	599	28	17D
0005432424073	599	29	18B
0005432424097	599	30	18E
0005432424074	599	31	20C
0005432424066	599	32	20D
0005432424067	599	33	20F
0005432424091	599	34	21B
0005432424070	599	35	22A
0005432424072	599	36	22C
0005432282810	599	37	22F
0005432282805	599	38	23A
0005432424064	599	39	24B
0005432424085	599	40	25E
0005432424077	599	41	26C
0005432424058	599	42	26D
0005432282803	599	43	27E
0005432424062	599	44	27D
0005432424065	599	45	27F
0005432424089	599	46	29A
0005432424060	599	47	29D
0005432424078	599	48	31B
0005433158114	12829	1	1D
0005432302298	12829	2	6C
0005432302302	12829	3	8D
0005432302300	12829	4	9D
0005433158115	12829	5	13C
0005432302301	12829	6	16B
0005432302299	12829	7	18B
0005433158112	12829	8	29E
0005434446483	12829	9	30B
0005434446482	12829	10	30C
0005433158113	12829	11	31A
0005432423616	12926	1	2C
0005432423635	12926	2	11E
0005432423654	12926	3	13A
0005432423665	12926	4	13B
0005432423664	12926	5	15A
0005432423644	12926	6	16E
0005432423615	12926	7	16F
0005432423606	12926	8	19C
0005432423640	12926	9	21C
0005432423645	12926	10	23B
0005432423620	12926	11	24C
0005432423646	12926	12	25A
0005432423619	12926	13	26D
0005432423604	12926	14	27D
0005433057209	461	1	1A
0005434023133	461	2	1C
0005433684386	461	3	1B
0005434023157	461	4	2A
0005434023179	461	5	2B
0005433057200	461	6	2F
0005433057319	461	7	2C
0005434023166	461	8	2H
0005433057178	461	9	2G
0005434023135	461	10	3C
0005434028273	461	11	4A
0005434023152	461	12	3H
0005434028272	461	13	4C
0005432235576	461	14	4G
0005433057441	461	15	5C
0005432235575	461	16	5G
0005434023164	461	17	5F
0005433057389	461	18	11A
0005434023191	461	19	9H
0005434023181	461	20	11B
0005434023171	461	21	11D
0005434023194	461	22	11H
0005433057206	461	23	12E
0005434023176	461	24	12H
0005433057220	461	25	12G
0005434023131	461	26	13B
0005432235578	461	27	13E
0005434031985	461	28	13G
0005434023168	461	29	14B
0005434031983	461	30	14G
0005433057238	461	31	15A
0005433057325	461	32	14H
0005434023142	461	33	15E
0005432235573	461	34	15D
0005434023175	461	35	15G
0005434023180	461	36	15F
0005434023187	461	37	15H
0005434023192	461	38	16A
0005434023145	461	39	16B
0005434023128	461	40	16E
0005434023160	461	41	16D
0005433057227	461	42	16F
0005433057281	461	43	16H
0005433057326	461	44	16G
0005434023165	461	45	17E
0005434023185	461	46	18F
0005434023150	461	47	18G
0005434023158	461	48	19A
0005432045597	461	49	18H
0005434023184	461	50	19B
0005434023146	461	51	19D
0005432235577	461	52	19F
0005434023134	461	53	19E
0005434023156	461	54	19H
0005433057198	461	55	19G
0005434023169	461	56	20A
0005434023163	461	57	20B
0005434023174	461	58	20F
0005434023183	461	59	20G
0005434023130	461	60	21B
0005434028274	461	61	21E
0005432235579	461	62	21F
0005434031982	461	63	22A
0005434023139	461	64	22D
0005434023167	461	65	22B
0005434023189	461	66	22G
0005433684388	461	67	22F
0005434023126	461	68	23B
0005434023143	461	69	23E
0005434023154	461	70	24A
0005434023144	461	71	24B
0005434023127	461	72	24D
0005434023153	461	73	24E
0005434023173	461	74	25E
0005434023147	461	75	27A
0005433057317	461	76	27D
0005434023149	461	77	27B
0005434023182	461	78	27E
0005432045596	461	79	27F
0005434023141	461	80	28E
0005434023170	461	81	29B
0005434023162	461	82	28H
0005433057316	461	83	30A
0005434031981	461	84	30D
0005433057199	461	85	30E
0005434023136	461	86	31D
0005433057318	461	87	31B
0005434023129	461	88	32A
0005434023188	461	89	32B
0005433929549	461	90	32E
0005434028271	461	91	33B
0005434023151	461	92	33G
0005434023148	461	93	33F
0005434029634	461	94	33H
0005433057235	461	95	34A
0005432235580	461	96	34F
0005433057207	461	97	34G
0005434023172	461	98	35B
0005434023193	461	99	35A
0005434023138	461	100	35D
0005434023155	461	101	35F
0005434023161	461	102	35E
0005434023186	461	103	35G
0005433057280	461	104	36A
0005434023137	461	105	36F
0005432235574	461	106	36H
0005434029633	461	107	36G
0005434023190	461	108	37A
0005434023159	461	109	37B
0005433057182	461	110	37D
0005434023178	461	111	37E
0005434023132	461	112	37G
0005434023177	461	113	38B
0005434031984	461	114	38D
0005434735614	461	115	38G
0005433684387	461	116	38F
0005434023140	461	117	39D
0005433057545	12665	1	1A
0005434022663	12665	2	1C
0005434022833	12665	3	1F
0005434022533	12665	4	1H
0005434022607	12665	5	2B
0005434022804	12665	6	3B
0005434022904	12665	7	3F
0005434022588	12665	8	3G
0005433684405	12665	9	3H
0005434022832	12665	10	4C
0005433057538	12665	11	5A
0005433057540	12665	12	9G
0005434022587	12665	13	11A
0005434022636	12665	14	9H
0005434022530	12665	15	11D
0005433057566	12665	16	11B
0005433929578	12665	17	11H
0005434022605	12665	18	12B
0005433057551	12665	19	12F
0005433057565	12665	20	12H
0005434022642	12665	21	13B
0005433057570	12665	22	13A
0005433057550	12665	23	13D
0005433057559	12665	24	14A
0005434022761	12665	25	14F
0005433057556	12665	26	14E
0005433057554	12665	27	14G
0005434022653	12665	28	15D
0005432156331	12665	29	15H
0005434022748	12665	30	15G
0005434022646	12665	31	16E
0005434029613	12665	32	16G
0005433057578	12665	33	17D
0005433057542	12665	34	17E
0005434022573	12665	35	17G
0005434022578	12665	36	18A
0005433057555	12665	37	18F
0005433929579	12665	38	19B
0005434028252	12665	39	19A
0005433057553	12665	40	19E
0005434022686	12665	41	19D
0005433057547	12665	42	19H
0005433057541	12665	43	20B
0005434022903	12665	44	20D
0005433057549	12665	45	20F
0005434022563	12665	46	20H
0005433057574	12665	47	21B
0005434022712	12665	48	21E
0005434022535	12665	49	21F
0005433057560	12665	50	21H
0005434735648	12665	51	22B
0005433057562	12665	52	22D
0005434022606	12665	53	22G
0005433929580	12665	54	22F
0005434028246	12665	55	23A
0005434022614	12665	56	23D
0005433057544	12665	57	23E
0005432157476	12665	58	24A
0005433057569	12665	59	23H
0005434022622	12665	60	24B
0005433057571	12665	61	24E
0005434028248	12665	62	24D
0005433057543	12665	63	24F
0005434022834	12665	64	24H
0005433057561	12665	65	24G
0005434022620	12665	66	25D
0005433057539	12665	67	25E
0005434735645	12665	68	25F
0005432156332	12665	69	27B
0005433057573	12665	70	27F
0005434022685	12665	71	27G
0005434735646	12665	72	27H
0005434022841	12665	73	28E
0005434022608	12665	74	28F
0005432156327	12665	75	28G
0005433057563	12665	76	29B
0005434022647	12665	77	29A
0005434022623	12665	78	28H
0005434735649	12665	79	29D
0005434028253	12665	80	29E
0005434022902	12665	81	29G
0005434022619	12665	82	29F
0005433057575	12665	83	30B
0005433057572	12665	84	30A
0005433057579	12665	85	30F
0005432156328	12665	86	30E
0005434022714	12665	87	31B
0005433684404	12665	88	31F
0005432156329	12665	89	31E
0005434031946	12665	90	31G
0005433057568	12665	91	31H
0005433057576	12665	92	32E
0005432156330	12665	93	32D
0005434022641	12665	94	32F
0005433057558	12665	95	32G
0005434022666	12665	96	33B
0005433057567	12665	97	33G
0005432157475	12665	98	34A
0005434022540	12665	99	34D
0005434022711	12665	100	34E
0005432157477	12665	101	34H
0005434022742	12665	102	34G
0005434022715	12665	103	35A
0005433057557	12665	104	35D
0005434022739	12665	105	35B
0005434022922	12665	106	35E
0005433057548	12665	107	35G
0005434022609	12665	108	36D
0005434735647	12665	109	36F
0005434022703	12665	110	37A
0005434022536	12665	111	36H
0005433057577	12665	112	37D
0005433057546	12665	113	37B
0005433684403	12665	114	37G
0005434022727	12665	115	37F
0005433057552	12665	116	37H
0005433057564	12665	117	38E
0005434022662	12665	118	38F
0005434022611	12665	119	38H
0005434022710	12665	120	38G
0005434022601	12665	121	39E
0005433922567	2161	1	1A
0005433922540	2161	2	1H
0005433035589	2161	3	1G
0005433922496	2161	4	2A
0005432231482	2161	5	2B
0005433922547	2161	6	2C
0005433922524	2161	7	2G
0005433922549	2161	8	2F
0005433922546	2161	9	3A
0005433922528	2161	10	3C
0005432749750	2161	11	3B
0005433922523	2161	12	3G
0005433922501	2161	13	4A
0005433922556	2161	14	4B
0005433922568	2161	15	4F
0005433922481	2161	16	5A
0005433922519	2161	17	4H
0005433922525	2161	18	5B
0005433931440	2161	19	5C
0005433922482	2161	20	5F
0005433922495	2161	21	9A
0005433922542	2161	22	5H
0005433035383	2161	23	9B
0005433922530	2161	24	9G
0005433922503	2161	25	11A
0005432231481	2161	26	11E
0005433922517	2161	27	11F
0005433035607	2161	28	11H
0005433922508	2161	29	11G
0005433922513	2161	30	12D
0005433035415	2161	31	12B
0005433922473	2161	32	12E
0005433922491	2161	33	12F
0005433035455	2161	34	12G
0005433035372	2161	35	13B
0005433922471	2161	36	13D
0005433922536	2161	37	13E
0005433922551	2161	38	13H
0005433922534	2161	39	14B
0005433922543	2161	40	14E
0005433922537	2161	41	14F
0005433922512	2161	42	14H
0005433035416	2161	43	14G
0005433922506	2161	44	15A
0005433922545	2161	45	15B
0005433922531	2161	46	15E
0005433922527	2161	47	15F
0005433922541	2161	48	15H
0005433922569	2161	49	16D
0005434028252	2161	50	16B
0005432044501	2161	51	16F
0005432231477	2161	52	16E
0005433922555	2161	53	16G
0005433922539	2161	54	16H
0005433922561	2161	55	17A
0005433035422	2161	56	17F
0005433922518	2161	57	17E
0005433922474	2161	58	17G
0005433035542	2161	59	18B
0005433922552	2161	60	18A
0005432231478	2161	61	18E
0005433035587	2161	62	18G
0005432231474	2161	63	19A
0005432231472	2161	64	19D
0005433922475	2161	65	19F
0005433922490	2161	66	19E
0005432231479	2161	67	19H
0005433922499	2161	68	19G
0005433922554	2161	69	20A
0005433922520	2161	70	20B
0005433035377	2161	71	20E
0005433922472	2161	72	20D
0005432749749	2161	73	20F
0005433922529	2161	74	20G
0005433035606	2161	75	21A
0005433922498	2161	76	21E
0005433922484	2161	77	21D
0005433922487	2161	78	21G
0005433922477	2161	79	21F
0005432044502	2161	80	21H
0005433922538	2161	81	22D
0005433922558	2161	82	22E
0005433922522	2161	83	22G
0005432231476	2161	84	22H
0005433922564	2161	85	23B
0005433929578	2161	86	23D
0005433922500	2161	87	23E
0005433922478	2161	88	23H
0005434028246	2161	89	23G
0005433922535	2161	90	24B
0005433035433	2161	91	24D
0005432231473	2161	92	24F
0005432231475	2161	93	24E
0005433922557	2161	94	24G
0005433922565	2161	95	25E
0005433035526	2161	96	27A
0005433922533	2161	97	27D
0005433922560	2161	98	27B
0005433922521	2161	99	27E
0005433922562	2161	100	27F
0005433922566	2161	101	28A
0005433035419	2161	102	28B
0005433931441	2161	103	28F
0005433922514	2161	104	29E
0005433922526	2161	105	29F
0005433922515	2161	106	29H
0005433922497	2161	107	29G
0005433035404	2161	108	30B
0005433035417	2161	109	30E
0005434028253	2161	110	30G
0005433035421	2161	111	30F
0005433035588	2161	112	30H
0005433922553	2161	113	31A
0005433922504	2161	114	31D
0005432044503	2161	115	31F
0005433922509	2161	116	31E
0005433922505	2161	117	31G
0005433922494	2161	118	32A
0005434028248	2161	119	31H
0005433035571	2161	120	32D
0005433875365	2161	121	32E
0005433922502	2161	122	32H
0005433922510	2161	123	32G
0005433922470	2161	124	33A
0005433035516	2161	125	33D
0005433922532	2161	126	33E
0005433922511	2161	127	33F
0005433922492	2161	128	34A
0005433922486	2161	129	34D
0005433035376	2161	130	34F
0005432231480	2161	131	34E
0005433922488	2161	132	34G
0005433035551	2161	133	34H
0005433922516	2161	134	35A
0005433922476	2161	135	35D
0005433922483	2161	136	35E
0005433929580	2161	137	35G
0005433922559	2161	138	36A
0005433922479	2161	139	36B
0005433922493	2161	140	36G
0005433922563	2161	141	37D
0005433922548	2161	142	37F
0005433922507	2161	143	37E
0005433035434	2161	144	37H
0005433922544	2161	145	37G
0005433929579	2161	146	38A
0005433035432	2161	147	38D
0005433035525	2161	148	38E
0005433922480	2161	149	38G
0005433922550	2161	150	38F
0005433922485	2161	151	39F
0005433922489	2161	152	39E
0005433921852	24132	1	1A
0005433921850	24132	2	1C
0005433921918	24132	3	1B
0005433035862	24132	4	2F
0005433035856	24132	5	2C
0005433921748	24132	6	2H
0005433921756	24132	7	3C
0005433035885	24132	8	4A
0005433921642	24132	9	3H
0005433035891	24132	10	4B
0005433035881	24132	11	4F
0005433921862	24132	12	4G
0005433921606	24132	13	4H
0005433921905	24132	14	5B
0005433922070	24132	15	5G
0005433035895	24132	16	5H
0005433921623	24132	17	9B
0005433035883	24132	18	9A
0005433929556	24132	19	9G
0005433921972	24132	20	11A
0005433921962	24132	21	9H
0005433035875	24132	22	11D
0005433035887	24132	23	11G
0005433921712	24132	24	11F
0005433035852	24132	25	11H
0005433922103	24132	26	12D
0005433035851	24132	27	12B
0005433921699	24132	28	12E
0005433921920	24132	29	12F
0005432207641	24132	30	12H
0005433921855	24132	31	13A
0005433035845	24132	32	13D
0005432206149	24132	33	13B
0005433921757	24132	34	13E
0005433921917	24132	35	13F
0005433929557	24132	36	14A
0005432206145	24132	37	13H
0005433035866	24132	38	13G
0005433921779	24132	39	14B
0005433035871	24132	40	14D
0005433035849	24132	41	14E
0005433035893	24132	42	14G
0005433921969	24132	43	14F
0005433035863	24132	44	15A
0005433035865	24132	45	14H
0005433035878	24132	46	15B
0005433931414	24132	47	15D
0005433035859	24132	48	15F
0005433035843	24132	49	15H
0005433921652	24132	50	15G
0005433035850	24132	51	16A
0005433922116	24132	52	16E
0005433035894	24132	53	16G
0005433035847	24132	54	16F
0005432206147	24132	55	16H
0005433035886	24132	56	17A
0005433921853	24132	57	17D
0005433035868	24132	58	17G
0005433035848	24132	59	17F
0005433921942	24132	60	17H
0005433921771	24132	61	18A
0005433035842	24132	62	18E
0005433921709	24132	63	18D
0005433035876	24132	64	19A
0005433035889	24132	65	18H
0005433921906	24132	66	19E
0005433035844	24132	67	19F
0005433921710	24132	68	19G
0005433921666	24132	69	20A
0005432749768	24132	70	20D
0005433921981	24132	71	20F
0005432206150	24132	72	20G
0005433035858	24132	73	21B
0005433035890	24132	74	21E
0005434028276	24132	75	21D
0005433921676	24132	76	21G
0005433035888	24132	77	21F
0005432206148	24132	78	22B
0005433035864	24132	79	22A
0005433921703	24132	80	22D
0005433921735	24132	81	22F
0005433931424	24132	82	23A
0005433921761	24132	83	22H
0005433921776	24132	84	23D
0005433921673	24132	85	23B
0005433921629	24132	86	23F
0005433929558	24132	87	24B
0005433035874	24132	88	24G
0005433921672	24132	89	27A
0005433035882	24132	90	27D
0005433921746	24132	91	27F
0005433035880	24132	92	27E
0005433921653	24132	93	27G
0005433035896	24132	94	28A
0005433921894	24132	95	27H
0005433035857	24132	96	28D
0005433921768	24132	97	28B
0005432749767	24132	98	28F
0005433921895	24132	99	28H
0005433921863	24132	100	28G
0005433921654	24132	101	29A
0005433035854	24132	102	29D
0005433921898	24132	103	29E
0005433929559	24132	104	29G
0005433921736	24132	105	29H
0005433921791	24132	106	30B
0005433921702	24132	107	30D
0005433921723	24132	108	30F
0005433921745	24132	109	31B
0005433035892	24132	110	31E
0005433921919	24132	111	31D
0005433035884	24132	112	31F
0005433035855	24132	113	31H
0005433035872	24132	114	32B
0005433921607	24132	115	32E
0005433931427	24132	116	32F
0005433921980	24132	117	32G
0005433921600	24132	118	32H
0005432206146	24132	119	33D
0005433921769	24132	120	33B
0005433035861	24132	121	33E
0005434028275	24132	122	33F
0005433921777	24132	123	33H
0005433035877	24132	124	33G
0005433921590	24132	125	34E
0005433035879	24132	126	35A
0005433035867	24132	127	35D
0005433931413	24132	128	35G
0005433921700	24132	129	36A
0005433035873	24132	130	36B
0005433035869	24132	131	36D
0005433035870	24132	132	36F
0005433921912	24132	133	36E
0005433922117	24132	134	36G
0005433035846	24132	135	37A
0005433921744	24132	136	36H
0005433922022	24132	137	37D
0005433929539	24132	138	37B
0005433035853	24132	139	37G
0005433922073	24132	140	38B
0005433921722	24132	141	38A
0005433921713	24132	142	38D
0005433931420	24132	143	38E
0005433035860	24132	144	38F
0005433921747	24132	145	38H
0005433922259	24132	146	38G
0005433921858	24132	147	39D
0005432277695	295	1	1C
0005433233259	295	2	1A
0005435142461	295	3	1G
0005433766575	295	4	1D
0005434724443	295	5	1H
0005433233106	295	6	2D
0005434724472	295	7	2C
0005434724481	295	8	2H
0005433233382	295	9	3A
0005433180712	295	10	2K
0005434735644	295	11	3D
0005434724501	295	12	4C
0005435142465	295	13	4G
0005434724545	295	14	4K
0005434724542	295	15	4H
0005434724495	295	16	5D
0005434724504	295	17	5C
0005434724485	295	18	5A
0005434550816	295	19	5H
0005434724479	295	20	5G
0005433233383	295	21	5K
0005434550792	295	22	11D
0005434550774	295	23	11C
0005434550818	295	24	11G
0005434302425	295	25	11F
0005434724533	295	26	11E
0005433180662	295	27	11K
0005434550798	295	28	11H
0005434724475	295	29	12C
0005435142469	295	30	12A
0005434724427	295	31	12E
0005433766573	295	32	12D
0005434724509	295	33	12G
0005434550786	295	34	12F
0005434724487	295	35	12K
0005434724440	295	36	13D
0005434724470	295	37	13A
0005434724465	295	38	13F
0005434724520	295	39	13E
0005434724518	295	40	13H
0005433233166	295	41	13G
0005433233123	295	42	14A
0005434724506	295	43	13K
0005434724539	295	44	14E
0005434724461	295	45	14D
0005433180650	295	46	14G
0005434724474	295	47	14F
0005435142462	295	48	14K
0005434724449	295	49	14H
0005434302422	295	50	15A
0005434724471	295	51	15H
0005434724514	295	52	15G
0005434550788	295	53	15F
0005435142460	295	54	16A
0005434724453	295	55	15K
0005434724498	295	56	16D
0005435142463	295	57	16G
0005434724452	295	58	16F
0005435142473	295	59	16E
0005433233575	295	60	16H
0005434550781	295	61	17C
0005434724446	295	62	16K
0005433233193	295	63	17E
0005433233190	295	64	17D
0005434550799	295	65	17H
0005434724437	295	66	17F
0005434724536	295	67	18B
0005434724477	295	68	18A
0005434724431	295	69	18D
0005432277692	295	70	18F
0005434724503	295	71	18E
0005432277696	295	72	18J
0005433131634	295	73	19B
0005434724483	295	74	19A
0005434550779	295	75	19D
0005434735641	295	76	19F
0005434550794	295	77	19E
0005434550804	295	78	19G
0005433233233	295	79	20A
0005434724468	295	80	19J
0005434550810	295	81	20B
0005433233274	295	82	20E
0005434550766	295	83	20D
0005434731131	295	84	20G
0005433233183	295	85	20F
0005434724460	295	86	20K
0005434724447	295	87	21A
0005434724548	295	88	21D
0005434302423	295	89	21F
0005432277706	295	90	21E
0005434724490	295	91	21J
0005434550815	295	92	21H
0005434731134	295	93	22A
0005434550782	295	94	21K
0005433766584	295	95	22C
0005434550796	295	96	22F
0005434724458	295	97	22E
0005434724529	295	98	22G
0005433233167	295	99	22K
0005433233192	295	100	22H
0005434724531	295	101	23B
0005434724507	295	102	23A
0005433233124	295	103	23D
0005433131636	295	104	23C
0005434550765	295	105	23F
0005433233264	295	106	23J
0005434724543	295	107	23K
0005433180727	295	108	24G
0005434724523	295	109	25B
0005434724535	295	110	25D
0005434724429	295	111	25C
0005434550809	295	112	25F
0005433126768	295	113	25E
0005434724521	295	114	25H
0005434724426	295	115	25G
0005432277697	295	116	25K
0005433766583	295	117	26B
0005434735643	295	118	26A
0005433180665	295	119	26E
0005435142472	295	120	26C
0005433180651	295	121	26H
0005434550768	295	122	26G
0005434724525	295	123	27B
0005434550789	295	124	26K
0005434550803	295	125	27C
0005434724544	295	126	27E
0005434550772	295	127	27J
0005434724448	295	128	27G
0005434550787	295	129	28C
0005434550793	295	130	28B
0005434724510	295	131	28A
0005434724445	295	132	28D
0005434302426	295	133	28E
0005434724513	295	134	28J
0005434724442	295	135	28H
0005434550769	295	136	29B
0005433180674	295	137	29A
0005434724541	295	138	29D
0005434724527	295	139	29C
0005432277694	295	140	29E
0005432277700	295	141	29H
0005433233181	295	142	29G
0005434550776	295	143	30A
0005434550784	295	144	29K
0005434724489	295	145	30B
0005433233125	295	146	30E
0005434724500	295	147	30C
0005434550777	295	148	30H
0005435142464	295	149	30G
0005433233313	295	150	30J
0005434724439	295	151	31B
0005434550778	295	152	31A
0005434724488	295	153	31D
0005434724515	295	154	31C
0005433233247	295	155	31F
0005434724486	295	156	31H
0005433131644	295	157	31G
0005434550801	295	158	32A
0005433233126	295	159	31K
0005433289731	295	160	31J
0005434550790	295	161	32E
0005434724546	295	162	32D
0005434724476	295	163	32C
0005434724434	295	164	32G
0005433180726	295	165	32F
0005434550808	295	166	32H
0005434724516	295	167	33B
0005433233234	295	168	33A
0005434724480	295	169	32K
0005432277701	295	170	33D
0005434724519	295	171	33C
0005433766574	295	172	33F
0005434724530	295	173	33H
0005434724435	295	174	33G
0005434731133	295	175	34A
0005434724441	295	176	33K
0005433180663	295	177	34C
0005433180684	295	178	34B
0005434724432	295	179	34H
0005432277702	295	180	34G
0005433233091	295	181	34J
0005433233576	295	182	35B
0005433233103	295	183	35A
0005433180673	295	184	35E
0005434724454	295	185	35D
0005434724496	295	186	35C
0005434724499	295	187	35H
0005433233105	295	188	36A
0005434550770	295	189	35K
0005435142471	295	190	35J
0005434724538	295	191	36C
0005433233184	295	192	36B
0005434724494	295	193	36F
0005432277699	295	194	36E
0005434550783	295	195	36H
0005434724526	295	196	36G
0005434724457	295	197	36K
0005433180713	295	198	36J
0005434724512	295	199	37B
0005433289739	295	200	37D
0005433180685	295	201	37C
0005434724524	295	202	37G
0005434550771	295	203	37F
0005434724463	295	204	37H
0005434302424	295	205	38A
0005435142467	295	206	37K
0005433233381	295	207	38H
0005434724450	295	208	38C
0005434550811	295	209	38J
0005433180661	295	210	39B
0005434724547	295	211	39A
0005433180769	295	212	38K
0005434724493	295	213	39C
0005434724428	295	214	39F
0005434550805	295	215	39E
0005433233336	295	216	39J
0005434724502	295	217	39H
0005434550763	295	218	40A
0005433233185	295	219	39K
0005434724517	295	220	40C
0005434724537	295	221	40B
0005434724505	295	222	40E
0005434724444	295	223	40D
0005434550764	295	224	40F
0005434735642	295	225	40J
0005432277698	295	226	40H
0005433180664	295	227	41A
0005434724464	295	228	41C
0005434550813	295	229	41F
0005434550814	295	230	41E
0005433233104	295	231	41H
0005434550797	295	232	41G
0005434550795	295	233	42A
0005433233242	295	234	41K
0005434724456	295	235	41J
0005434724451	295	236	42C
0005434550775	295	237	42B
0005434031945	295	238	42E
0005434724528	295	239	42D
0005432277693	295	240	42F
0005434724522	295	241	42J
0005433233182	295	242	43D
0005434724469	295	243	43B
0005433180686	295	244	43E
0005434724467	295	245	43G
0005435142468	295	246	44A
0005434550785	295	247	43J
0005434550780	295	248	44B
0005434550802	295	249	44D
0005434550773	295	250	44K
0005432277703	295	251	44J
0005434550767	295	252	44H
0005434550817	295	253	45A
0005434724433	295	254	45D
0005434550807	295	255	45B
0005434031953	295	256	45F
0005434302421	295	257	45H
0005434724455	295	258	45G
0005433289732	295	259	46A
0005434724484	295	260	45K
0005434724462	295	261	45J
0005434724430	295	262	46C
0005432277705	295	263	46B
0005435142466	295	264	46E
0005434550806	295	265	46D
0005434724478	295	266	46G
0005433233335	295	267	46F
0005434731130	295	268	46J
0005434724473	295	269	46H
0005434550791	295	270	47A
0005434724466	295	271	46K
0005434724540	295	272	47D
0005434724534	295	273	47C
0005434724482	295	274	47F
0005434724492	295	275	47E
0005433126769	295	276	47H
0005434724459	295	277	48A
0005434724511	295	278	48F
0005434724508	295	279	48E
0005434302854	295	280	48D
0005434724491	295	281	49A
0005434724438	295	282	49C
0005433233156	295	283	49G
0005435142470	295	284	49F
0005434550800	295	285	49K
0005432277704	295	286	50A
0005434731132	295	287	50E
0005434550812	295	288	50D
0005434724436	295	289	50G
0005434724497	295	290	50K
0005434724532	295	291	51E
0005433233314	295	292	51G
0005433233692	9875	1	1A
0005434723640	9875	2	1K
0005434723373	9875	3	2C
0005433233685	9875	4	2A
0005433180883	9875	5	2G
0005433126804	9875	6	3A
0005433233672	9875	7	3D
0005433233670	9875	8	3C
0005433180902	9875	9	3H
0005434723573	9875	10	3G
0005434550392	9875	11	4D
0005434723760	9875	12	4K
0005434723744	9875	13	4H
0005434723592	9875	14	5C
0005434735605	9875	15	5H
0005434723414	9875	16	5D
0005434723560	9875	17	11G
0005432199194	9875	18	11F
0005433233714	9875	19	11K
0005434550307	9875	20	12C
0005434723743	9875	21	12D
0005433233698	9875	22	12H
0005434550423	9875	23	12G
0005434735604	9875	24	12K
0005434031988	9875	25	13D
0005434723632	9875	26	13F
0005433233695	9875	27	13G
0005434550355	9875	28	13K
0005433233699	9875	29	14D
0005433289787	9875	30	14G
0005433180887	9875	31	14F
0005434723478	9875	32	14H
0005434550311	9875	33	15C
0005433233703	9875	34	15F
0005434723420	9875	35	15D
0005434550278	9875	36	15H
0005433233690	9875	37	16A
0005434723349	9875	38	15K
0005434724009	9875	39	16C
0005433129240	9875	40	16F
0005433233697	9875	41	16E
0005433233688	9875	42	16H
0005434723452	9875	43	16G
0005433233661	9875	44	17C
0005434723634	9875	45	17A
0005433233665	9875	46	16K
0005434723443	9875	47	17E
0005433233713	9875	48	17D
0005434723748	9875	49	17F
0005434724105	9875	50	18A
0005433180884	9875	51	17H
0005434723574	9875	52	18H
0005434723396	9875	53	18F
0005434723334	9875	54	19C
0005434723429	9875	55	19B
0005434723434	9875	56	19F
0005433129238	9875	57	19E
0005434723602	9875	58	19D
0005433233705	9875	59	19H
0005434550279	9875	60	20A
0005434723559	9875	61	19K
0005434031987	9875	62	20B
0005434550349	9875	63	20E
0005434723421	9875	64	20D
0005434723369	9875	65	20H
0005433233663	9875	66	20F
0005433180904	9875	67	20J
0005433180896	9875	68	21B
0005433233687	9875	69	21A
0005434723489	9875	70	21F
0005432199190	9875	71	21E
0005434723564	9875	72	21J
0005434723518	9875	73	21K
0005433289788	9875	74	22C
0005433289789	9875	75	22B
0005433180886	9875	76	22F
0005433233668	9875	77	22G
0005434723791	9875	78	22H
0005433233701	9875	79	23B
0005433126808	9875	80	23A
0005434723437	9875	81	23E
0005433180900	9875	82	23D
0005433113518	9875	83	23C
0005434723585	9875	84	23F
0005434723615	9875	85	23J
0005434550408	9875	86	23H
0005434723928	9875	87	23G
0005434302393	9875	88	24D
0005433233681	9875	89	23K
0005434731098	9875	90	24F
0005434723645	9875	91	24G
0005434723444	9875	92	25D
0005433233673	9875	93	25C
0005434550271	9875	94	25F
0005433233671	9875	95	25E
0005433113517	9875	96	25H
0005434723423	9875	97	25G
0005434723622	9875	98	25K
0005433289790	9875	99	25J
0005434550296	9875	100	26C
0005433233723	9875	101	26E
0005433233667	9875	102	26D
0005433233693	9875	103	26H
0005433233675	9875	104	26F
0005434550409	9875	105	27B
0005434723635	9875	106	27A
0005434723333	9875	107	27D
0005434723371	9875	108	27E
0005433129239	9875	109	27H
0005433289786	9875	110	27K
0005434550337	9875	111	28A
0005434550473	9875	112	28E
0005433766610	9875	113	28G
0005434550304	9875	114	29A
0005434550310	9875	115	29D
0005434723866	9875	116	29B
0005433180890	9875	117	29F
0005434723914	9875	118	29H
0005434723576	9875	119	30A
0005434723792	9875	120	29J
0005434723633	9875	121	30B
0005434723775	9875	122	30F
0005434723345	9875	123	30J
0005434723565	9875	124	30H
0005433180892	9875	125	31D
0005434723440	9875	126	31C
0005434723495	9875	127	31G
0005434723539	9875	128	32A
0005433233717	9875	129	32E
0005434723344	9875	130	32D
0005434302388	9875	131	32C
0005433233709	9875	132	32F
0005433233678	9875	133	32K
0005434302392	9875	134	32J
0005434723672	9875	135	32H
0005435142358	9875	136	33B
0005433233689	9875	137	33F
0005433233682	9875	138	33J
0005433233677	9875	139	33H
0005433180882	9875	140	34A
0005433233702	9875	141	34C
0005434723575	9875	142	34B
0005433233669	9875	143	34E
0005434731106	9875	144	34D
0005433180888	9875	145	34G
0005433233706	9875	146	34F
0005433180898	9875	147	34K
0005432199193	9875	148	35A
0005433233674	9875	149	35C
0005433233696	9875	150	35G
0005433180881	9875	151	35F
0005433180895	9875	152	35J
0005433233707	9875	153	36A
0005434723479	9875	154	35K
0005434723370	9875	155	36C
0005433233676	9875	156	36B
0005433233712	9875	157	36F
0005432199189	9875	158	36E
0005434723488	9875	159	36D
0005433233694	9875	160	36G
0005433233684	9875	161	36J
0005433126807	9875	162	36H
0005433233704	9875	163	37E
0005435142345	9875	164	37C
0005434550407	9875	165	37G
0005434723747	9875	166	37J
0005434550405	9875	167	37K
0005434550370	9875	168	38C
0005433126805	9875	169	38K
0005434550343	9875	170	38H
0005434723724	9875	171	39A
0005434723761	9875	172	39C
0005433233715	9875	173	39F
0005434550406	9875	174	39E
0005435142346	9875	175	39D
0005434550295	9875	176	39G
0005434723649	9875	177	39J
0005434550335	9875	178	40C
0005434723708	9875	179	40B
0005434723894	9875	180	40E
0005433233721	9875	181	40D
0005433766609	9875	182	40G
0005434723584	9875	183	40K
0005433233680	9875	184	41A
0005434723929	9875	185	41D
0005434723665	9875	186	41C
0005433233664	9875	187	41E
0005433180897	9875	188	41G
0005434031989	9875	189	41K
0005434723413	9875	190	42C
0005433129236	9875	191	42B
0005433233708	9875	192	42E
0005434550289	9875	193	42D
0005434723428	9875	194	42G
0005433129237	9875	195	42F
0005433233686	9875	196	42K
0005435142347	9875	197	42H
0005434723730	9875	198	43D
0005433233711	9875	199	43C
0005434302391	9875	200	43E
0005434723606	9875	201	43H
0005433233662	9875	202	43G
0005433233700	9875	203	43K
0005434723336	9875	204	43J
0005433180894	9875	205	44A
0005433233666	9875	206	44G
0005433233719	9875	207	44F
0005434723422	9875	208	45A
0005434550272	9875	209	44K
0005434723725	9875	210	45D
0005433233716	9875	211	45C
0005434031986	9875	212	45F
0005434723780	9875	213	45H
0005433233718	9875	214	45G
0005432199192	9875	215	46A
0005433180899	9875	216	45K
0005433233720	9875	217	46B
0005433233660	9875	218	46E
0005434723746	9875	219	46K
0005433233722	9875	220	46H
0005434550347	9875	221	47A
0005433180905	9875	222	47E
0005434723965	9875	223	47D
0005434723601	9875	224	47G
0005433233679	9875	225	47H
0005433180889	9875	226	48D
0005433233683	9875	227	48C
0005432199191	9875	228	48A
0005433126806	9875	229	48F
0005433180893	9875	230	48E
0005433233691	9875	231	48G
0005433233710	9875	232	49C
0005434550350	9875	233	49D
0005434550340	9875	234	49K
0005434723412	9875	235	49G
0005435142339	9875	236	50C
0005434723650	9875	237	50A
0005433180891	9875	238	50E
0005434723427	9875	239	50G
0005434723519	9875	240	50F
0005433180903	9875	241	51D
0005433180901	9875	242	51F
0005433766608	9875	243	51E
0005433180885	9875	244	51G
0005432526883	7744	1	1C
0005432526923	7744	2	1A
0005434067012	7744	3	1H
0005435212351	7744	4	1G
0005432526892	7744	5	1D
0005435212410	7744	6	1K
0005432069540	7744	7	2C
0005432533267	7744	8	2H
0005435212477	7744	9	3A
0005432526935	7744	10	3G
0005432526938	7744	11	3C
0005432535795	7744	12	3K
0005432526953	7744	13	4G
0005432526969	7744	14	4D
0005432526968	7744	15	5A
0005432526954	7744	16	4K
0005432526841	7744	17	4H
0005434066995	7744	18	5C
0005434066973	7744	19	11A
0005432526893	7744	20	11D
0005435212713	7744	21	11C
0005432069539	7744	22	11G
0005434066992	7744	23	11F
0005432150133	7744	24	11E
0005434066954	7744	25	11H
0005434066993	7744	26	12C
0005432526886	7744	27	12A
0005434066962	7744	28	11K
0005432526872	7744	29	12E
0005432069531	7744	30	12D
0005432069542	7744	31	12G
0005432526903	7744	32	12F
0005434066960	7744	33	12K
0005432526974	7744	34	12H
0005434066998	7744	35	13C
0005432526944	7744	36	13A
0005434067018	7744	37	13F
0005432526901	7744	38	13E
0005432526857	7744	39	13G
0005432526865	7744	40	14C
0005432526947	7744	41	14A
0005432526956	7744	42	13K
0005432537039	7744	43	14D
0005434066988	7744	44	14F
0005432526920	7744	45	14E
0005432533268	7744	46	14K
0005435212456	7744	47	14H
0005432526843	7744	48	15C
0005432526958	7744	49	15A
0005432526880	7744	50	15F
0005432526848	7744	51	15E
0005434067017	7744	52	15H
0005434067010	7744	53	15G
0005432533266	7744	54	15K
0005432526870	7744	55	16D
0005434066952	7744	56	16A
0005432526975	7744	57	16F
0005432526908	7744	58	16K
0005435212515	7744	59	16H
0005435212503	7744	60	17D
0005434067002	7744	61	17C
0005432526868	7744	62	17G
0005432526902	7744	63	17F
0005434067015	7744	64	17H
0005432526916	7744	65	18B
0005432069534	7744	66	18A
0005434066975	7744	67	18E
0005434066984	7744	68	18D
0005432526963	7744	69	18C
0005434066977	7744	70	18H
0005435212698	7744	71	18G
0005434066955	7744	72	18F
0005434066968	7744	73	18J
0005434067000	7744	74	19B
0005435212502	7744	75	18K
0005434066994	7744	76	19C
0005432069536	7744	77	19E
0005435212483	7744	78	19D
0005432526856	7744	79	19H
0005432526910	7744	80	19G
0005434067003	7744	81	19J
0005432526973	7744	82	20C
0005434066985	7744	83	20B
0005434066971	7744	84	20A
0005432526849	7744	85	20D
0005434067011	7744	86	20G
0005435212480	7744	87	20F
0005434066989	7744	88	20J
0005432526971	7744	89	21B
0005435212336	7744	90	21A
0005432526913	7744	91	21D
0005432526858	7744	92	21C
0005432526866	7744	93	21E
0005432526966	7744	94	21J
0005432526931	7744	95	21H
0005432526889	7744	96	21K
0005435212550	7744	97	22C
0005435212476	7744	98	22B
0005432526891	7744	99	22E
0005432526946	7744	100	22D
0005432526928	7744	101	22G
0005432428900	7744	102	22F
0005435212630	7744	103	22K
0005434067008	7744	104	22J
0005432526861	7744	105	23B
0005432526961	7744	106	23A
0005432526847	7744	107	23D
0005432069532	7744	108	23C
0005434066951	7744	109	23G
0005432526929	7744	110	23F
0005432526941	7744	111	23E
0005432526952	7744	112	23J
0005432526942	7744	113	23H
0005435212597	7744	114	24D
0005434066983	7744	115	23K
0005432526922	7744	116	24F
0005432526884	7744	117	25B
0005435212516	7744	118	25A
0005432526917	7744	119	24G
0005435212352	7744	120	25D
0005432526948	7744	121	25C
0005432526970	7744	122	25F
0005434066967	7744	123	25E
0005434066980	7744	124	25H
0005432526862	7744	125	25G
0005434067013	7744	126	25K
0005434066966	7744	127	26C
0005432526936	7744	128	26B
0005434066972	7744	129	26A
0005432526890	7744	130	26E
0005432526894	7744	131	26D
0005432069533	7744	132	26G
0005435212529	7744	133	26J
0005435212481	7744	134	26H
0005432526873	7744	135	27A
0005435212349	7744	136	27D
0005432526897	7744	137	27C
0005432526879	7744	138	27B
0005432069537	7744	139	27E
0005435212482	7744	140	27G
0005432526937	7744	141	27K
0005432526904	7744	142	27J
0005434066974	7744	143	28E
0005432069535	7744	144	28G
0005434067006	7744	145	28F
0005432526972	7744	146	28J
0005432526853	7744	147	28H
0005432526909	7744	148	29C
0005432526850	7744	149	29B
0005432526882	7744	150	29F
0005432526895	7744	151	29E
0005432526885	7744	152	29J
0005435212362	7744	153	30C
0005435212617	7744	154	30E
0005432526845	7744	155	30D
0005432526949	7744	156	30H
0005435630916	7744	157	30F
0005432526959	7744	158	30J
0005432526962	7744	159	31B
0005432526955	7744	160	31A
0005432526915	7744	161	30K
0005434066965	7744	162	31C
0005434067016	7744	163	31F
0005432526854	7744	164	31H
0005434066982	7744	165	31G
0005435212427	7744	166	31K
0005434066959	7744	167	32C
0005432526925	7744	168	32B
0005432526876	7744	169	32A
0005432526950	7744	170	32E
0005432535791	7744	171	32D
0005432526852	7744	172	32G
0005435212387	7744	173	32J
0005434066961	7744	174	33B
0005432526860	7744	175	33A
0005435212547	7744	176	32K
0005434066978	7744	177	33C
0005432526896	7744	178	33G
0005434067001	7744	179	33F
0005432526844	7744	180	33E
0005432526864	7744	181	33J
0005432526867	7744	182	33H
0005434066990	7744	183	33K
0005432526869	7744	184	34B
0005432526957	7744	185	34A
0005434066970	7744	186	34D
0005434066976	7744	187	34C
0005434067009	7744	188	34K
0005432526898	7744	189	34H
0005434067014	7744	190	35B
0005432069538	7744	191	35A
0005434066969	7744	192	35D
0005434067007	7744	193	35F
0005432150130	7744	194	35E
0005432526932	7744	195	35G
0005435212712	7744	196	36A
0005435212628	7744	197	35K
0005435212377	7744	198	36B
0005432535793	7744	199	36E
0005432526933	7744	200	36D
0005434066949	7744	201	36J
0005432526878	7744	202	37A
0005432428901	7744	203	37F
0005432150131	7744	204	37E
0005432150128	7744	205	37J
0005434067004	7744	206	37H
0005432526945	7744	207	37G
0005432526934	7744	208	38A
0005435630915	7744	209	38C
0005432526911	7744	210	38B
0005432526967	7744	211	38K
0005432526960	7744	212	38J
0005435212596	7744	213	38H
0005432526943	7744	214	39D
0005434066981	7744	215	39C
0005432069529	7744	216	39F
0005434066986	7744	217	39H
0005432526906	7744	218	39G
0005432526951	7744	219	40A
0005432526842	7744	220	40B
0005434066958	7744	221	40E
0005432526926	7744	222	40F
0005432526874	7744	223	40K
0005432535794	7744	224	40J
0005432526881	7744	225	40H
0005432526927	7744	226	41B
0005432526964	7744	227	41A
0005432150126	7744	228	41D
0005435212406	7744	229	41C
0005432526921	7744	230	41F
0005432526888	7744	231	41E
0005432526940	7744	232	41H
0005432150132	7744	233	41G
0005432537041	7744	234	42A
0005432526912	7744	235	41J
0005434067005	7744	236	42C
0005432526918	7744	237	42E
0005435212390	7744	238	42G
0005432526914	7744	239	42F
0005432150127	7744	240	42H
0005432526899	7744	241	43A
0005434066997	7744	242	42K
0005432526905	7744	243	43F
0005434066957	7744	244	43E
0005432526877	7744	245	43K
0005432526875	7744	246	43J
0005432428899	7744	247	44C
0005434066999	7744	248	44B
0005435725513	7744	249	44A
0005432069541	7744	250	44E
0005434066987	7744	251	44D
0005434066948	7744	252	44F
0005435212561	7744	253	44K
0005432526851	7744	254	44J
0005432069530	7744	255	44H
0005432526871	7744	256	45B
0005435725514	7744	257	45A
0005432526846	7744	258	45C
0005432526859	7744	259	45D
0005434066963	7744	260	45G
0005432535792	7744	261	46A
0005435212350	7744	262	45K
0005434066964	7744	263	46B
0005434066956	7744	264	46E
0005434066979	7744	265	46D
0005435212491	7744	266	46G
0005432526919	7744	267	46F
0005432526855	7744	268	46H
0005435212388	7744	269	47E
0005432526965	7744	270	47C
0005434066991	7744	271	47F
0005432526863	7744	272	47K
0005435212492	7744	273	48D
0005432526887	7744	274	49A
0005432526939	7744	275	48K
0005434066953	7744	276	49E
0005434067020	7744	277	49D
0005432537040	7744	278	49C
0005432150129	7744	279	49G
0005432526924	7744	280	49F
0005435212490	7744	281	50C
0005434067019	7744	282	49K
0005435212629	7744	283	50E
0005432526930	7744	284	50G
0005435212711	7744	285	50F
0005432526900	7744	286	50K
0005432526907	7744	287	51F
0005434066996	7744	288	51E
0005435212416	7744	289	51D
0005434066950	7744	290	51G
0005435491423	5331	1	1C
0005435612694	5331	2	1A
0005435423968	5331	3	1G
0005432133089	5331	4	1D
0005435612714	5331	5	1K
0005435612750	5331	6	1H
0005434343936	5331	7	2C
0005435423840	5331	8	2H
0005435612726	5331	9	2D
0005434573243	5331	10	3C
0005432133082	5331	11	3D
0005435612688	5331	12	3K
0005435612707	5331	13	3H
0005435612744	5331	14	4C
0005435423807	5331	15	4G
0005435612774	5331	16	4D
0005435612700	5331	17	4K
0005434343917	5331	18	4H
0005434244534	5331	19	5D
0005435423967	5331	20	5C
0005435319435	5331	21	5A
0005435423737	5331	22	5H
0005435612775	5331	23	5G
0005432047517	5331	24	11A
0005434573240	5331	25	5K
0005435555352	5331	26	11D
0005434573244	5331	27	11C
0005435612772	5331	28	11F
0005435423925	5331	29	11E
0005435612745	5331	30	11H
0005435380228	5331	31	11G
0005434244466	5331	32	12C
0005435423776	5331	33	12A
0005435423884	5331	34	12E
0005435612790	5331	35	12D
0005434244522	5331	36	12F
0005435612754	5331	37	12K
0005434343929	5331	38	13D
0005434343934	5331	39	13C
0005435612731	5331	40	13A
0005435423808	5331	41	13F
0005435423648	5331	42	13G
0005435424006	5331	43	14C
0005435612741	5331	44	13K
0005432133090	5331	45	14D
0005434343940	5331	46	14F
0005434343937	5331	47	14E
0005435612787	5331	48	14G
0005435423786	5331	49	15C
0005435423821	5331	50	15E
0005435612743	5331	51	15H
0005435612785	5331	52	15G
0005435612749	5331	53	15F
0005435423801	5331	54	16A
0005435423883	5331	55	15K
0005435490195	5331	56	16D
0005435490198	5331	57	16F
0005435423742	5331	58	16E
0005435423638	5331	59	16H
0005434573233	5331	60	16G
0005435612706	5331	61	17E
0005435612753	5331	62	17D
0005435380229	5331	63	17C
0005435423895	5331	64	17G
0005435612703	5331	65	17K
0005434244537	5331	66	17H
0005434244535	5331	67	18B
0005432133093	5331	68	18E
0005435423771	5331	69	18D
0005434244468	5331	70	18C
0005435612757	5331	71	18G
0005435612733	5331	72	18K
0005434573239	5331	73	18J
0005435423694	5331	74	19A
0005435423680	5331	75	19D
0005435612786	5331	76	19C
0005435612713	5331	77	19F
0005435612722	5331	78	19H
0005434244589	5331	79	19G
0005434244485	5331	80	20A
0005434343946	5331	81	19K
0005435423609	5331	82	20B
0005435612759	5331	83	20E
0005435612789	5331	84	20D
0005434343948	5331	85	20C
0005435612758	5331	86	20J
0005435319459	5331	87	21B
0005435612738	5331	88	21A
0005435612788	5331	89	21D
0005435612724	5331	90	21C
0005434573234	5331	91	21E
0005435491424	5331	92	21H
0005435612792	5331	93	22A
0005434244465	5331	94	21K
0005434573235	5331	95	21J
0005435423581	5331	96	22C
0005435423768	5331	97	22B
0005435612695	5331	98	22E
0005435423656	5331	99	22D
0005435612725	5331	100	22G
0005435612778	5331	101	23B
0005435612720	5331	102	23A
0005435612701	5331	103	23D
0005435423785	5331	104	23G
0005434244494	5331	105	23F
0005432133083	5331	106	23E
0005432133086	5331	107	23J
0005435612689	5331	108	23H
0005435423879	5331	109	23K
0005434343911	5331	110	24G
0005435612710	5331	111	24D
0005435423669	5331	112	25A
0005434343924	5331	113	25C
0005432047519	5331	114	25F
0005435423651	5331	115	25E
0005435097138	5331	116	25D
0005435423668	5331	117	25H
0005435612793	5331	118	25G
0005435423637	5331	119	25K
0005435612755	5331	120	25J
0005434343916	5331	121	26C
0005434343947	5331	122	26B
0005435612705	5331	123	26A
0005435302131	5331	124	26F
0005435612699	5331	125	26E
0005435612764	5331	126	26D
0005435612780	5331	127	26G
0005434343942	5331	128	26J
0005432363359	5331	129	26H
0005435423662	5331	130	27B
0005435423734	5331	131	27A
0005432363372	5331	132	27C
0005435423743	5331	133	27F
0005432133091	5331	134	27E
0005434343928	5331	135	27K
0005434343926	5331	136	28B
0005435612711	5331	137	28E
0005435612702	5331	138	28D
0005435612783	5331	139	28C
0005432133087	5331	140	28F
0005435612779	5331	141	28J
0005435612716	5331	142	29B
0005434573245	5331	143	29A
0005435097133	5331	144	28K
0005435612751	5331	145	29C
0005435612762	5331	146	29G
0005435612727	5331	147	29F
0005435423697	5331	148	29E
0005435612735	5331	149	29D
0005434244510	5331	150	29H
0005435097132	5331	151	30A
0005435612698	5331	152	29K
0005434573232	5331	153	30B
0005435612734	5331	154	30E
0005435612718	5331	155	30D
0005435424087	5331	156	30C
0005435612708	5331	157	30G
0005435319458	5331	158	30F
0005435490196	5331	159	30K
0005435380245	5331	160	30H
0005435612761	5331	161	31B
0005434343941	5331	162	31A
0005434343922	5331	163	31D
0005432133081	5331	164	31C
0005435612717	5331	165	31F
0005435612696	5331	166	31E
0005435612765	5331	167	31J
0005435612719	5331	168	31G
0005434343931	5331	169	31K
0005435097137	5331	170	32C
0005434343913	5331	171	32B
0005435380246	5331	172	32E
0005435612795	5331	173	32D
0005435612729	5331	174	32F
0005435424007	5331	175	32K
0005434573242	5331	176	32J
0005435423995	5331	177	32H
0005434244536	5331	178	33D
0005435612768	5331	179	33C
0005435423912	5331	180	33B
0005434343945	5331	181	33F
0005434244528	5331	182	33E
0005434343914	5331	183	33H
0005434573236	5331	184	33K
0005434343932	5331	185	33J
0005435612690	5331	186	34C
0005434244571	5331	187	34A
0005435612799	5331	188	34E
0005434343930	5331	189	34D
0005434656523	5331	190	34G
0005435612684	5331	191	34F
0005434573241	5331	192	34K
0005434343925	5331	193	34J
0005434244511	5331	194	34H
0005435423608	5331	195	35B
0005435612742	5331	196	35A
0005434343927	5331	197	35D
0005435612697	5331	198	35C
0005435423820	5331	199	35F
0005434244486	5331	200	35E
0005435423839	5331	201	35H
0005435423643	5331	202	35G
0005435612692	5331	203	36A
0005435612769	5331	204	35K
0005435612767	5331	205	35J
0005435612704	5331	206	36D
0005435612723	5331	207	36C
0005435097136	5331	208	36E
0005435612796	5331	209	36H
0005432133088	5331	210	36F
0005435612776	5331	211	37D
0005435612712	5331	212	37C
0005435423772	5331	213	37F
0005432133084	5331	214	37E
0005435423652	5331	215	37H
0005435555351	5331	216	37G
0005434343935	5331	217	37K
0005435097134	5331	218	37J
0005435612728	5331	219	38C
0005434343943	5331	220	38J
0005435423806	5331	221	38H
0005434244569	5331	222	39A
0005435612784	5331	223	38K
0005435423894	5331	224	39C
0005435490197	5331	225	39F
0005435612732	5331	226	39H
0005435555353	5331	227	39G
0005435612740	5331	228	40A
0005435423767	5331	229	40C
0005435097131	5331	230	40E
0005434343915	5331	231	40D
0005435380227	5331	232	40H
0005435612781	5331	233	40G
0005435612736	5331	234	40F
0005435612709	5331	235	41B
0005435612752	5331	236	41A
0005432363360	5331	237	41D
0005435423667	5331	238	41C
0005435423649	5331	239	41E
0005432047520	5331	240	41J
0005435612791	5331	241	41H
0005434343944	5331	242	41G
0005432363366	5331	243	41K
0005435423769	5331	244	42B
0005435097139	5331	245	42E
0005435423929	5331	246	42D
0005435612798	5331	247	42J
0005435612773	5331	248	42H
0005435612794	5331	249	43B
0005435423802	5331	250	43A
0005435612691	5331	251	43C
0005435612721	5331	252	43E
0005435491425	5331	253	43D
0005435612685	5331	254	43H
0005435423809	5331	255	43G
0005435612763	5331	256	44A
0005435423740	5331	257	43K
0005434244490	5331	258	43J
0005435612770	5331	259	44B
0005434343918	5331	260	44E
0005432133094	5331	261	44D
0005434343921	5331	262	44C
0005435423671	5331	263	44G
0005435612747	5331	264	44F
0005435612739	5331	265	44J
0005434573238	5331	266	44H
0005435612686	5331	267	45B
0005435423877	5331	268	45A
0005435612683	5331	269	45C
0005434573237	5331	270	45F
0005435612782	5331	271	45D
0005434244467	5331	272	45J
0005435423715	5331	273	45H
0005432047518	5331	274	45K
0005432133085	5331	275	46C
0005435612715	5331	276	46B
0005435612737	5331	277	46A
0005435423760	5331	278	46E
0005435612748	5331	279	46D
0005432133092	5331	280	46G
0005435097130	5331	281	46F
0005435612797	5331	282	46H
0005434343938	5331	283	47A
0005435612760	5331	284	47E
0005432363365	5331	285	47D
0005435612771	5331	286	47G
0005435097140	5331	287	47K
0005434343919	5331	288	47H
0005435302132	5331	289	48C
0005435612687	5331	290	48A
0005435612730	5331	291	48F
0005435423966	5331	292	48E
0005435612756	5331	293	48D
0005435612693	5331	294	48G
0005434343939	5331	295	48K
0005435423590	5331	296	49C
0005435612766	5331	297	49F
0005435423642	5331	298	49E
0005434343912	5331	299	49K
0005434343920	5331	300	49H
0005434343923	5331	301	49G
0005434343933	5331	302	50C
0005435423924	5331	303	50A
0005435423735	5331	304	50H
0005435612746	5331	305	50F
0005435097135	5331	306	50K
0005435423789	5331	307	51D
0005435612777	5331	308	51G
0005435424241	10881	1	1D
0005435424269	10881	2	1C
0005435424267	10881	3	1A
0005435490177	10881	4	2A
0005435612106	10881	5	1H
0005435424266	10881	6	2H
0005435612031	10881	7	2G
0005435611865	10881	8	2K
0005435612032	10881	9	3C
0005435319504	10881	10	3G
0005434244734	10881	11	4A
0005435490182	10881	12	3K
0005432164977	10881	13	4D
0005435611815	10881	14	4K
0005434343592	10881	15	4H
0005435380257	10881	16	5D
0005435424236	10881	17	11A
0005435611893	10881	18	5K
0005435380259	10881	19	11D
0005435424233	10881	20	11G
0005432164974	10881	21	11F
0005435424277	10881	22	11K
0005432164973	10881	23	12C
0005435304121	10881	24	12E
0005435424237	10881	25	12D
0005435319505	10881	26	12G
0005434244737	10881	27	12F
0005435611787	10881	28	12K
0005435611755	10881	29	13C
0005435319498	10881	30	13F
0005435424234	10881	31	13H
0005435611849	10881	32	13G
0005435424230	10881	33	13K
0005435611896	10881	34	14E
0005435424216	10881	35	14D
0005435424224	10881	36	14C
0005435611898	10881	37	15E
0005432166874	10881	38	16D
0005435424223	10881	39	16C
0005435611830	10881	40	16A
0005435611817	10881	41	16F
0005435380253	10881	42	16E
0005434244745	10881	43	16H
0005435424261	10881	44	17A
0005435097055	10881	45	16K
0005435612018	10881	46	17E
0005435612339	10881	47	17D
0005435424262	10881	48	17C
0005435424271	10881	49	17G
0005435611876	10881	50	17K
0005435611831	10881	51	17H
0005435612254	10881	52	18C
0005435424257	10881	53	18D
0005432166875	10881	54	18F
0005435424225	10881	55	18J
0005432164972	10881	56	19E
0005434343607	10881	57	19G
0005435612238	10881	58	19K
0005435424253	10881	59	20C
0005435424239	10881	60	20F
0005435611790	10881	61	20J
0005435611859	10881	62	21B
0005435612060	10881	63	21A
0005435424268	10881	64	20K
0005435424259	10881	65	21D
0005434244728	10881	66	21C
0005435612017	10881	67	21F
0005435611874	10881	68	21E
0005435424278	10881	69	22A
0005435611863	10881	70	21J
0005435424247	10881	71	22C
0005435380254	10881	72	22B
0005435611810	10881	73	22E
0005435424232	10881	74	22D
0005434244741	10881	75	22H
0005435305000	10881	76	22F
0005435611866	10881	77	22J
0005434244747	10881	78	23B
0005435424219	10881	79	23A
0005435612228	10881	80	23C
0005435612340	10881	81	23F
0005435612235	10881	82	24D
0005434343619	10881	83	23K
0005435611791	10881	84	24F
0005434244733	10881	85	24E
0005435424274	10881	86	25B
0005435424227	10881	87	24G
0005435304118	10881	88	25D
0005435612193	10881	89	25F
0005434656538	10881	90	25E
0005435611721	10881	91	25K
0005434244751	10881	92	26A
0005435611756	10881	93	26D
0005434343600	10881	94	26G
0005435612411	10881	95	26F
0005435611886	10881	96	26H
0005435424265	10881	97	27B
0005435612040	10881	98	26K
0005433719113	10881	99	27C
0005432164975	10881	100	27F
0005434244740	10881	101	27E
0005435424254	10881	102	28C
0005435424249	10881	103	28B
0005435611766	10881	104	28A
0005434244743	10881	105	28D
0005435424222	10881	106	28G
0005434656540	10881	107	28J
0005434244730	10881	108	29A
0005435612270	10881	109	29D
0005435424256	10881	110	29F
0005434244748	10881	111	29E
0005435612148	10881	112	29H
0005435424260	10881	113	30A
0005434244738	10881	114	30B
0005432166873	10881	115	30E
0005435611737	10881	116	30G
0005432840995	10881	117	30J
0005435424248	10881	118	31B
0005435612278	10881	119	30K
0005435611802	10881	120	31F
0005435380255	10881	121	31E
0005435555337	10881	122	31J
0005435380258	10881	123	31G
0005434573108	10881	124	32A
0005435424245	10881	125	32C
0005435611862	10881	126	32B
0005434656539	10881	127	32E
0005434244725	10881	128	32D
0005435612239	10881	129	32G
0005435612076	10881	130	32F
0005434244736	10881	131	33D
0005435611928	10881	132	33C
0005435424275	10881	133	33E
0005435611887	10881	134	33J
0005435424211	10881	135	33H
0005435611726	10881	136	34A
0005435424235	10881	137	33K
0005435319497	10881	138	34B
0005435380256	10881	139	34D
0005434244746	10881	140	34G
0005435424251	10881	141	34F
0005435424226	10881	142	34J
0005435424263	10881	143	34H
0005435612014	10881	144	35A
0005435424244	10881	145	35D
0005435319501	10881	146	35F
0005435611754	10881	147	35E
0005433719114	10881	148	36A
0005435424212	10881	149	35K
0005435611803	10881	150	36C
0005435424215	10881	151	36F
0005435424279	10881	152	36H
0005435611829	10881	153	36G
0005434244752	10881	154	37A
0005435424264	10881	155	37D
0005435424229	10881	156	37C
0005435424250	10881	157	37F
0005435424214	10881	158	37H
0005435424238	10881	159	38A
0005432164976	10881	160	37K
0005435611731	10881	161	38C
0005434244749	10881	162	38B
0005435380252	10881	163	38K
0005435424213	10881	164	38J
0005435611786	10881	165	38H
0005435424252	10881	166	39A
0005435611897	10881	167	39D
0005434244742	10881	168	39B
0005432164971	10881	169	39F
0005432164978	10881	170	39K
0005435319503	10881	171	40C
0005435424221	10881	172	40D
0005435319502	10881	173	40F
0005435555336	10881	174	40K
0005435319500	10881	175	40J
0005435424240	10881	176	41B
0005435304119	10881	177	41E
0005435424210	10881	178	41J
0005435611984	10881	179	41K
0005435424273	10881	180	42B
0005435611743	10881	181	42D
0005435612094	10881	182	42G
0005434343658	10881	183	42K
0005434343642	10881	184	42J
0005435611844	10881	185	42H
0005435304120	10881	186	43B
0005435424270	10881	187	43A
0005435424258	10881	188	43C
0005435424242	10881	189	43F
0005435612131	10881	190	43H
0005434244753	10881	191	43G
0005435319499	10881	192	43K
0005434244744	10881	193	43J
0005432363389	10881	194	44C
0005435424255	10881	195	44B
0005435611816	10881	196	45A
0005434244732	10881	197	44K
0005435611916	10881	198	45D
0005435424276	10881	199	45C
0005435611873	10881	200	45B
0005435424228	10881	201	45E
0005434244739	10881	202	45H
0005435612013	10881	203	45G
0005435611776	10881	204	45J
0005432840996	10881	205	46C
0005435424218	10881	206	46B
0005434343591	10881	207	46E
0005435611917	10881	208	46D
0005435424217	10881	209	46F
0005434244735	10881	210	46K
0005435424243	10881	211	46J
0005435611950	10881	212	47E
0005435424246	10881	213	47D
0005434244750	10881	214	47C
0005435611838	10881	215	47G
0005435611975	10881	216	47K
0005435611877	10881	217	48D
0005434244731	10881	218	48C
0005435424231	10881	219	48A
0005435424220	10881	220	48G
0005434244726	10881	221	49A
0005432363390	10881	222	49D
0005435611753	10881	223	49C
0005435612279	10881	224	49G
0005435612265	10881	225	49F
0005435424272	10881	226	49E
0005434244729	10881	227	49K
0005435612237	10881	228	49H
0005434244727	10881	229	50C
0005435612229	10881	230	50H
0005435611765	10881	231	50F
0005434343657	10881	232	51F
0005434143710	3377	1	1C
0005432181524	3377	2	1F
0005433805077	3377	3	1D
0005432459223	3377	4	2A
0005433507039	3377	5	2D
0005432181540	3377	6	2C
0005433805110	3377	7	2F
0005433507038	3377	8	3A
0005433507027	3377	9	3C
0005433507024	3377	10	3D
0005433633558	3377	11	4D
0005433805083	3377	12	4C
0005432459085	3377	13	5A
0005433805090	3377	14	4F
0005433805094	3377	15	5D
0005434143707	3377	16	5C
0005432459084	3377	17	6A
0005433633553	3377	18	5F
0005433633559	3377	19	6C
0005432181543	3377	20	6D
0005432181528	3377	21	7A
0005433805106	3377	22	6F
0005434143708	3377	23	7C
0005433805109	3377	24	7F
0005432459224	3377	25	7D
0005433805089	3377	26	8A
0005433805117	3377	27	8C
0005433633554	3377	28	8B
0005433633561	3377	29	8E
0005433633556	3377	30	8D
0005433633529	3377	31	9A
0005432458981	3377	32	8F
0005433805099	3377	33	9B
0005433805086	3377	34	9C
0005432181539	3377	35	9D
0005433633555	3377	36	9E
0005433805118	3377	37	9F
0005433805081	3377	38	10B
0005433507042	3377	39	10D
0005433805105	3377	40	10C
0005433633542	3377	41	10E
0005433633552	3377	42	11A
0005433507037	3377	43	10F
0005433633548	3377	44	11B
0005432459140	3377	45	11C
0005433805093	3377	46	11E
0005432459018	3377	47	11D
0005433633560	3377	48	11F
0005433805103	3377	49	12A
0005433805084	3377	50	12B
0005433805113	3377	51	12C
0005433805079	3377	52	12E
0005433507034	3377	53	12D
0005432459130	3377	54	13B
0005432181541	3377	55	13C
0005432181536	3377	56	13D
0005434143712	3377	57	13F
0005433805091	3377	58	13E
0005433507026	3377	59	14A
0005433805096	3377	60	14B
0005432181532	3377	61	14D
0005433805104	3377	62	14C
0005434143713	3377	63	15A
0005432181542	3377	64	14F
0005433633545	3377	65	14E
0005433633550	3377	66	15C
0005434143711	3377	67	15D
0005433633531	3377	68	15E
0005433633530	3377	69	16A
0005433633528	3377	70	16B
0005433805100	3377	71	16C
0005432459098	3377	72	16E
0005433633539	3377	73	16D
0005434143714	3377	74	16F
0005433633551	3377	75	17A
0005433507029	3377	76	17D
0005433633544	3377	77	17C
0005433805097	3377	78	17B
0005432181525	3377	79	17F
0005433633533	3377	80	17E
0005433805101	3377	81	18A
0005432459129	3377	82	18B
0005433507030	3377	83	18D
0005433805087	3377	84	18C
0005433633543	3377	85	18F
0005433633540	3377	86	19B
0005432459003	3377	87	19C
0005434143706	3377	88	19E
0005433805098	3377	89	20B
0005433633534	3377	90	20A
0005433805085	3377	91	20C
0005433805108	3377	92	20D
0005433507025	3377	93	20F
0005432181546	3377	94	20E
0005432181545	3377	95	21B
0005433633557	3377	96	21E
0005433805092	3377	97	21D
0005433633547	3377	98	21F
0005433507033	3377	99	22B
0005433805107	3377	100	22A
0005432181526	3377	101	22C
0005432459002	3377	102	22E
0005433805078	3377	103	22F
0005432459005	3377	104	23A
0005433805114	3377	105	23B
0005432181531	3377	106	23E
0005433805095	3377	107	24A
0005433507031	3377	108	24B
0005433507036	3377	109	24D
0005433507041	3377	110	24C
0005433633537	3377	111	24E
0005432181538	3377	112	24F
0005433633541	3377	113	25A
0005433507028	3377	114	25C
0005433805082	3377	115	25B
0005433805102	3377	116	25D
0005432181533	3377	117	25F
0005433805088	3377	118	25E
0005432459001	3377	119	26A
0005434143709	3377	120	26B
0005433633546	3377	121	26D
0005432181534	3377	122	26C
0005433633549	3377	123	26E
0005433507040	3377	124	26F
0005433805080	3377	125	27B
0005433633536	3377	126	27E
0005432181527	3377	127	27D
0005433805116	3377	128	27C
0005432458987	3377	129	28A
0005432181529	3377	130	27F
0005433507035	3377	131	28B
0005432459004	3377	132	28C
0005432459000	3377	133	28D
0005432181537	3377	134	29B
0005433633532	3377	135	29D
0005432181530	3377	136	29F
0005433633535	3377	137	30A
0005433507032	3377	138	30B
0005433633527	3377	139	30C
0005433805115	3377	140	30E
0005433633538	3377	141	30F
0005433805112	3377	142	31B
0005432181535	3377	143	31A
0005432181544	3377	144	31C
0005432459088	3377	145	31D
0005433805111	3377	146	31E
0005435884610	3378	1	1D
0005435884456	3378	2	5C
0005435884508	3378	3	6C
0005435884397	3378	4	7D
0005435884522	3378	5	8F
0005435884523	3378	6	10B
0005435884380	3378	7	10C
0005435884419	3378	8	12D
0005435884428	3378	9	13C
0005435884381	3378	10	13F
0005435884514	3378	11	13E
0005435884416	3378	12	14D
0005435884398	3378	13	14E
0005435884496	3378	14	15A
0005435884430	3378	15	16A
0005435884382	3378	16	18B
0005435884539	3378	17	18D
0005435884643	3378	18	20B
0005435884541	3378	19	22E
0005435884418	3378	20	23A
0005435884647	3378	21	24B
0005435884501	3378	22	24A
0005435884540	3378	23	25D
0005435884621	3378	24	27B
0005435884499	3378	25	27D
0005435884651	3378	26	28C
0005435884445	3378	27	28B
0005435884517	3378	28	28D
0005435884500	3378	29	29F
0005435884620	3378	30	30C
0005435884553	3378	31	30E
0005435884385	3378	32	31E
0005432459468	8248	1	1A
0005432459448	8248	2	1C
0005435884847	8248	3	1D
0005433506861	8248	4	1F
0005432042599	8248	5	2D
0005435884862	8248	6	3A
0005432042602	8248	7	4A
0005435884857	8248	8	3F
0005432459458	8248	9	4C
0005432459470	8248	10	4D
0005432459462	8248	11	5A
0005432459449	8248	12	4F
0005435884830	8248	13	5D
0005435884861	8248	14	5F
0005432459473	8248	15	6A
0005435884836	8248	16	6C
0005432459489	8248	17	6D
0005432459441	8248	18	7A
0005432459457	8248	19	7C
0005435884828	8248	20	7F
0005435884845	8248	21	8A
0005432459467	8248	22	8B
0005432042608	8248	23	8D
0005432459480	8248	24	8F
0005433506890	8248	25	9B
0005435884842	8248	26	9A
0005432459439	8248	27	9C
0005432459455	8248	28	9D
0005433506887	8248	29	9F
0005433506859	8248	30	9E
0005435884835	8248	31	10A
0005432459487	8248	32	10B
0005432459474	8248	33	10D
0005432459447	8248	34	10F
0005435884840	8248	35	11C
0005432459469	8248	36	11B
0005435884863	8248	37	11F
0005435884838	8248	38	12B
0005432459438	8248	39	12C
0005435884843	8248	40	12D
0005432459456	8248	41	12F
0005432459440	8248	42	13B
0005433506864	8248	43	13A
0005433506930	8248	44	13C
0005435884860	8248	45	13D
0005432459451	8248	46	14A
0005432459478	8248	47	13F
0005432459486	8248	48	14B
0005435884844	8248	49	14C
0005435884837	8248	50	14E
0005432459477	8248	51	14D
0005432459485	8248	52	14F
0005432042598	8248	53	15A
0005432459482	8248	54	15C
0005432459488	8248	55	15D
0005432459471	8248	56	15E
0005432459465	8248	57	15F
0005435884834	8248	58	16C
0005432459464	8248	59	16B
0005432042604	8248	60	16D
0005433506903	8248	61	17A
0005435884852	8248	62	17C
0005432459452	8248	63	17B
0005432459450	8248	64	17E
0005432042601	8248	65	18C
0005432459479	8248	66	18D
0005432459445	8248	67	18F
0005435884859	8248	68	18E
0005432459483	8248	69	19B
0005435884853	8248	70	19C
0005432459466	8248	71	19E
0005432042606	8248	72	20A
0005433506876	8248	73	20C
0005433506880	8248	74	20E
0005432459459	8248	75	21A
0005435884841	8248	76	21C
0005432459461	8248	77	21B
0005435884858	8248	78	21D
0005432042596	8248	79	22C
0005433506902	8248	80	22E
0005432459444	8248	81	22D
0005435884832	8248	82	22F
0005434312304	8248	83	23C
0005432042605	8248	84	23D
0005432459463	8248	85	23E
0005434312303	8248	86	23F
0005435884849	8248	87	24B
0005435884856	8248	88	24C
0005432459442	8248	89	24F
0005432459446	8248	90	24E
0005432042600	8248	91	25A
0005435884831	8248	92	25B
0005435884839	8248	93	25D
0005432459481	8248	94	25C
0005435884850	8248	95	25F
0005432459437	8248	96	26C
0005432459460	8248	97	26E
0005433506942	8248	98	27A
0005432459476	8248	99	27C
0005432459472	8248	100	27E
0005435884848	8248	101	27D
0005432459475	8248	102	27F
0005433506881	8248	103	28A
0005433506893	8248	104	28B
0005435884829	8248	105	28D
0005432459484	8248	106	28E
0005432042607	8248	107	28F
0005435884846	8248	108	29B
0005435884833	8248	109	29A
0005435884855	8248	110	29C
0005432459454	8248	111	29E
0005432042595	8248	112	30C
0005435884851	8248	113	30E
0005432042603	8248	114	30F
0005432459443	8248	115	31B
0005435884854	8248	116	31A
0005432459453	8248	117	31D
0005432042597	8248	118	31F
0005433633271	8245	1	3F
0005433633250	8245	2	4D
0005433804857	8245	3	4C
0005435854045	8245	4	5C
0005433804891	8245	5	5D
0005433633248	8245	6	7A
0005433804828	8245	7	6F
0005433633290	8245	8	7C
0005433633336	8245	9	8F
0005433633254	8245	10	11C
0005433804892	8245	11	11F
0005433633251	8245	12	12E
0005433804798	8245	13	12F
0005433804840	8245	14	13D
0005433804849	8245	15	13E
0005435854047	8245	16	14D
0005433633227	8245	17	17B
0005434271277	8245	18	17D
0005433804932	8245	19	19D
0005433633279	8245	20	20F
0005433804818	8245	21	21D
0005435854046	8245	22	21F
0005433804837	8245	23	22B
0005433804827	8245	24	22D
0005433804783	8245	25	23C
0005433633285	8245	26	23B
0005434271278	8245	27	24A
0005433804979	8245	28	24B
0005433804782	8245	29	24C
0005433804801	8245	30	25A
0005433804803	8245	31	25E
0005434271279	8245	32	25F
0005433633297	8245	33	27A
0005433633363	8245	34	27F
0005433633284	8245	35	28A
0005433804793	8245	36	28C
0005434271280	8245	37	29A
0005434271287	8245	38	30E
0005433633283	8245	39	31A
0005434183547	8244	1	2A
0005432727834	4673	1	1A
0005432382869	4673	2	1D
0005433722167	4673	3	2A
0005432382876	4673	4	2C
0005432382884	4673	5	3A
0005432382848	4673	6	3D
0005432727839	4673	7	4A
0005433453747	4673	8	4D
0005432382849	4673	9	4F
0005432382868	4673	10	5A
0005432382855	4673	11	5D
0005433453748	4673	12	5E
0005432382870	4673	13	6A
0005433722168	4673	14	6E
0005432382856	4673	15	7A
0005432382864	4673	16	7C
0005432382845	4673	17	7D
0005432382857	4673	18	7E
0005432382874	4673	19	7F
0005432382859	4673	20	8A
0005433454857	4673	21	8F
0005432382853	4673	22	9D
0005432727843	4673	23	9E
0005432382852	4673	24	10A
0005432727835	4673	25	10C
0005432727831	4673	26	10D
0005432382880	4673	27	10E
0005432382850	4673	28	11A
0005432382862	4673	29	11F
0005432382882	4673	30	12C
0005432382866	4673	31	12D
0005432382875	4673	32	12E
0005432727840	4673	33	12F
0005432382878	4673	34	13A
0005432382865	4673	35	13C
0005432382883	4673	36	13D
0005432382881	4673	37	13E
0005433454858	4673	38	13F
0005432382863	4673	39	14A
0005432382846	4673	40	14C
0005432382877	4673	41	14E
0005432727841	4673	42	14F
0005432382872	4673	43	15C
0005432382867	4673	44	15F
0005432382847	4673	45	16A
0005432382885	4673	46	16E
0005432727838	4673	47	16F
0005432382858	4673	48	17C
0005432382873	4673	49	17D
0005433454856	4673	50	17E
0005432382871	4673	51	18A
0005432727832	4673	52	18C
0005433722169	4673	53	18D
0005432727836	4673	54	18E
0005432727837	4673	55	18F
0005432382861	4673	56	19A
0005432382844	4673	57	19C
0005432382854	4673	58	19E
0005432382860	4673	59	19F
0005432382879	4673	60	20C
0005432727842	4673	61	20D
0005432382851	4673	62	20E
0005432727833	4673	63	20F
0005433453728	30255	1	4D
0005432382533	30255	2	5A
0005432727743	30255	3	5D
0005432727789	30255	4	8D
0005432382520	30255	5	8E
0005432382555	30255	6	8F
0005432727742	30255	7	9D
0005432382511	30255	8	9F
0005432382586	30255	9	10A
0005432727722	30255	10	13A
0005432382531	30255	11	13D
0005432727746	30255	12	13F
0005432382532	30255	13	14C
0005432727747	30255	14	15C
0005432727790	30255	15	15E
0005432382556	30255	16	16D
0005433451583	30255	17	17C
0005432382541	30255	18	17E
0005432727721	30255	19	17F
0005435540832	1726	1	1A
0005433516815	1726	2	1C
0005433516810	1726	3	1D
0005435529090	1726	4	1F
0005435540842	1726	5	2C
0005433516807	1726	6	2D
0005435540833	1726	7	2F
0005435529088	1726	8	3A
0005435529086	1726	9	3F
0005435540835	1726	10	4A
0005433516809	1726	11	4C
0005435529087	1726	12	4D
0005435529096	1726	13	4E
0005432924964	1726	14	5A
0005435540831	1726	15	5C
0005432294469	1726	16	5E
0005435540837	1726	17	6D
0005435529079	1726	18	6E
0005435540841	1726	19	6F
0005435529092	1726	20	7D
0005435529089	1726	21	7E
0005433516814	1726	22	7F
0005435529080	1726	23	8D
0005435540843	1726	24	8E
0005435540834	1726	25	8F
0005435529085	1726	26	9A
0005433516812	1726	27	9C
0005435540840	1726	28	9D
0005435529081	1726	29	9E
0005435529098	1726	30	10C
0005433516816	1726	31	10D
0005435529093	1726	32	10E
0005432294468	1726	33	10F
0005435540828	1726	34	11A
0005432294467	1726	35	11C
0005435540825	1726	36	11D
0005435529097	1726	37	11E
0005435540830	1726	38	12A
0005435540829	1726	39	12E
0005435529078	1726	40	12F
0005435529083	1726	41	13A
0005435540836	1726	42	13C
0005435529094	1726	43	13D
0005435529084	1726	44	14C
0005432924966	1726	45	14D
0005433516811	1726	46	15A
0005435540826	1726	47	15C
0005435540823	1726	48	15F
0005432924965	1726	49	16A
0005433516806	1726	50	16C
0005435540827	1726	51	16E
0005435529082	1726	52	16F
0005435529095	1726	53	17C
0005435540838	1726	54	17F
0005435540824	1726	55	18C
0005433516808	1726	56	18D
0005435540839	1726	57	18E
0005435529091	1726	58	18F
0005435529099	1726	59	19F
0005432924955	1726	60	20C
0005433516813	1726	61	20E
0005435540638	21985	1	1A
0005435540637	21985	2	1C
0005432924995	21985	3	2F
0005435517614	21985	4	3A
0005435540722	21985	5	3C
0005435540681	21985	6	3D
0005435540645	21985	7	3F
0005435517591	21985	8	4D
0005433516740	21985	9	4E
0005435517668	21985	10	5D
0005435540669	21985	11	5E
0005435517638	21985	12	7A
0005435540662	21985	13	9C
0005432924996	21985	14	9D
0005435517593	21985	15	10F
0005435517601	21985	16	11C
0005435540723	21985	17	11D
0005432924999	21985	18	11E
0005435540641	21985	19	11F
0005435540747	21985	20	12E
0005435517599	21985	21	14D
0005435517612	21985	22	14E
0005435517592	21985	23	14F
0005435540721	21985	24	15C
0005435540693	21985	25	15D
0005435517615	21985	26	16E
0005433516725	21985	27	17D
0005433516773	21985	28	17E
0005435540636	21985	29	17F
0005432924998	21985	30	18A
0005432924997	21985	31	18C
0005435517600	21985	32	18D
0005435517639	21985	33	19C
0005433516772	21985	34	19D
0005433516734	21985	35	19E
0005435540644	21985	36	20C
0005435540680	21985	37	20D
0005435517613	21985	38	20E
0005434458638	7357	1	1A
0005434458641	7357	2	1C
0005432838770	7357	3	1D
0005432838784	7357	4	1F
0005432838776	7357	5	2F
0005432823432	7357	6	3A
0005432073362	7357	7	3C
0005435252457	7357	8	3D
0005435252407	7357	9	3F
0005432838797	7357	10	4C
0005432838769	7357	11	4D
0005432838775	7357	12	4E
0005434458640	7357	13	4F
0005435252396	7357	14	5A
0005432838771	7357	15	5C
0005432838788	7357	16	5D
0005435252392	7357	17	5F
0005432838774	7357	18	6A
0005432838778	7357	19	6C
0005432073363	7357	20	6D
0005434458630	7357	21	6F
0005434458642	7357	22	7A
0005434458644	7357	23	7E
0005435252405	7357	24	7F
0005432838773	7357	25	8A
0005432838781	7357	26	8D
0005434458645	7357	27	8F
0005435252395	7357	28	9A
0005432838791	7357	29	9D
0005434458633	7357	30	10A
0005434458646	7357	31	10C
0005434458636	7357	32	10D
0005434458637	7357	33	10F
0005432838783	7357	34	11A
0005432838777	7357	35	11C
0005432838790	7357	36	11D
0005434458643	7357	37	11F
0005434458639	7357	38	12C
0005432823431	7357	39	12D
0005432838793	7357	40	12E
0005434458625	7357	41	12F
0005432838782	7357	42	13A
0005434458634	7357	43	13D
0005434458632	7357	44	13F
0005434458627	7357	45	14C
0005432838789	7357	46	14D
0005435252404	7357	47	14F
0005434458635	7357	48	15A
0005432073361	7357	49	15C
0005435252394	7357	50	15D
0005435252406	7357	51	16A
0005432838794	7357	52	16C
0005432838772	7357	53	16D
0005432838792	7357	54	16E
0005432838779	7357	55	17A
0005434458631	7357	56	17C
0005435252393	7357	57	17D
0005434458628	7357	58	17E
0005434458626	7357	59	17F
0005432838787	7357	60	18A
0005432838795	7357	61	18D
0005432838767	7357	62	18F
0005432840993	7357	63	19A
0005432838785	7357	64	19C
0005432838780	7357	65	19D
0005435491406	7357	66	19E
0005432838796	7357	67	20A
0005432840994	7357	68	19F
0005432838768	7357	69	20C
0005434458629	7357	70	20D
0005432838786	7357	71	20F
0005435252559	28915	1	1A
0005435252561	28915	2	1F
0005432838573	28915	3	2A
0005432838509	28915	4	2C
0005432838548	28915	5	2D
0005432838545	28915	6	2F
0005435252556	28915	7	3C
0005434458466	28915	8	3D
0005432838533	28915	9	3F
0005435252547	28915	10	4A
0005432838612	28915	11	4C
0005434458507	28915	12	4D
0005434458513	28915	13	4F
0005434664941	28915	14	5A
0005435252560	28915	15	5C
0005435252562	28915	16	5F
0005432838546	28915	17	6A
0005435252546	28915	18	6C
0005434664942	28915	19	6D
0005432838620	28915	20	6E
0005432838484	28915	21	6F
0005435252564	28915	22	7A
0005435491427	28915	23	7D
0005435252555	28915	24	7F
0005432001007	28915	25	8D
0005434458452	28915	26	8E
0005432838492	28915	27	8F
0005432838491	28915	28	9A
0005435252563	28915	29	9E
0005435252550	28915	30	9F
0005435252558	28915	31	10A
0005432838532	28915	32	10C
0005435252557	28915	33	10D
0005435252554	28915	34	10E
0005435252553	28915	35	10F
0005432838486	28915	36	11A
0005432823427	28915	37	11E
0005435491426	28915	38	12F
0005432838563	28915	39	13C
0005435252549	28915	40	15C
0005432001006	28915	41	16C
0005434458451	28915	42	16E
0005432838487	28915	43	16F
0005434664940	28915	44	17A
0005432838619	28915	45	17C
0005432838483	28915	46	17D
0005432838550	28915	47	17F
0005434458481	28915	48	18D
0005432838521	28915	49	18E
0005434458515	28915	50	18F
0005434458450	28915	51	19C
0005435252548	28915	52	19E
0005434458480	28915	53	20A
0005435252552	28915	54	20C
0005435252551	28915	55	20E
0005432838547	28915	56	20F
0005435990564	8831	1	4C
0005435990563	8831	2	7A
0005435990566	8831	3	7C
0005434275942	8831	4	8D
0005434275930	8831	5	9E
0005434275957	8831	6	10A
0005434275943	8831	7	10B
0005435990568	8831	8	13D
0005434275946	8831	9	13F
0005434275940	8831	10	15D
0005434275938	8831	11	16F
0005434275931	8831	12	17C
0005434275932	8831	13	18A
0005435990565	8831	14	18D
0005434275952	8831	15	18E
0005434275941	8831	16	19A
0005435990567	8831	17	20F
0005434275982	15734	1	6B
0005435990501	15734	2	7C
0005435990499	15734	3	7E
0005434275979	15734	4	8D
0005434275977	15734	5	9C
0005434275978	15734	6	11C
0005435990514	15734	7	13D
0005434275980	15734	8	14D
0005435990527	15734	9	16C
0005435990500	15734	10	17F
0005435990502	15734	11	20B
0005434275981	15734	12	20F
0005435990524	15734	13	20E
0005433468267	2099	1	1A
0005433468259	2099	2	2A
0005433468269	2099	3	2C
0005433468264	2099	4	3C
0005433468256	2099	5	4A
0005433468261	2099	6	4D
0005433468260	2099	7	5A
0005433468263	2099	8	5B
0005433468266	2099	9	5D
0005433468254	2099	10	6B
0005433468265	2099	11	6A
0005433468257	2099	12	6C
0005432909197	2099	13	7B
0005432909192	2099	14	18A
0005433468268	2099	15	18C
0005432909206	2099	16	19C
0005432909199	2099	17	20A
0005433468270	2099	18	20D
0005433468255	2099	19	21A
0005433468258	2099	20	22A
0005432909198	2099	21	22B
0005433468262	2099	22	22C
0005432909205	2099	23	23A
0005432909200	2099	24	23B
0005432909236	23841	1	1A
0005433468206	23841	2	1C
0005432909230	23841	3	1D
0005432909235	23841	4	2D
0005433468188	23841	5	3A
0005433468203	23841	6	3B
0005432909240	23841	7	4A
0005432909232	23841	8	6A
0005432909239	23841	9	6D
0005432909242	23841	10	7A
0005432909228	23841	11	7C
0005432909241	23841	12	7D
0005432909231	23841	13	18D
0005433468187	23841	14	19C
0005432909233	23841	15	19D
0005432909238	23841	16	20A
0005433468184	23841	17	20B
0005432909234	23841	18	20D
0005432909243	23841	19	21A
0005432909237	23841	20	21C
0005433468181	23841	21	21D
0005432909229	23841	22	22C
0005432359987	6403	1	1A
0005432359997	6403	2	1C
0005432359990	6403	3	1D
0005432359991	6403	4	2A
0005432359994	6403	5	1F
0005432359984	6403	6	2D
0005432335936	6403	7	2C
0005435176663	6403	8	2F
0005435176627	6403	9	3C
0005432359976	6403	10	3D
0005432359992	6403	11	3F
0005432359949	6403	12	4A
0005435176689	6403	13	4C
0005432359975	6403	14	4D
0005432359989	6403	15	4E
0005435176704	6403	16	4F
0005435176668	6403	17	5C
0005435490177	6403	18	5B
0005435176716	6403	19	5E
0005432359988	6403	20	5F
0005435176665	6403	21	6C
0005434149536	6403	22	6B
0005432335930	6403	23	6D
0005432335934	6403	24	6E
0005432359969	6403	25	7A
0005435176751	6403	26	6F
0005432335939	6403	27	7B
0005432359980	6403	28	7D
0005432359971	6403	29	7E
0005432359953	6403	30	8A
0005432062186	6403	31	8B
0005432363389	6403	32	8D
0005435176616	6403	33	8C
0005432359993	6403	34	8E
0005435176585	6403	35	9A
0005435176690	6403	36	8F
0005435176623	6403	37	9B
0005432335931	6403	38	9D
0005435176666	6403	39	9C
0005435176699	6403	40	9E
0005435723015	6403	41	10B
0005432359977	6403	42	10D
0005435176667	6403	43	10C
0005435723011	6403	44	11A
0005432335933	6403	45	11C
0005435176651	6403	46	11D
0005432335935	6403	47	11F
0005435176644	6403	48	11E
0005432359986	6403	49	12A
0005432359985	6403	50	12B
0005435176622	6403	51	12D
0005432359995	6403	52	12C
0005432335932	6403	53	12E
0005432062185	6403	54	12F
0005435176717	6403	55	13B
0005432359972	6403	56	13E
0005435176713	6403	57	14A
0005432359996	6403	58	13F
0005435176721	6403	59	14C
0005432363390	6403	60	14B
0005432359978	6403	61	14F
0005432359963	6403	62	14E
0005432359982	6403	63	15A
0005432359951	6403	64	15C
0005432359961	6403	65	15D
0005432359962	6403	66	15E
0005432359979	6403	67	16A
0005432359957	6403	68	16B
0005432359958	6403	69	16F
0005432335938	6403	70	16E
0005432062184	6403	71	17A
0005432335940	6403	72	17B
0005432335941	6403	73	17C
0005435176590	6403	74	17D
0005432359965	6403	75	17F
0005435490182	6403	76	18A
0005432359956	6403	77	18B
0005432359955	6403	78	18C
0005432359983	6403	79	18E
0005434149531	6403	80	18D
0005434149530	6403	81	18F
0005432359952	6403	82	19A
0005432062187	6403	83	19C
0005432359959	6403	84	19E
0005435176722	6403	85	19D
0005432359973	6403	86	20B
0005435176682	6403	87	20A
0005435176669	6403	88	20E
0005432359966	6403	89	20F
0005434149537	6403	90	21A
0005432359954	6403	91	21C
0005432359960	6403	92	21B
0005435176709	6403	93	21D
0005432359974	6403	94	21E
0005432335942	6403	95	22A
0005435176700	6403	96	21F
0005435176720	6403	97	22C
0005432359981	6403	98	22B
0005432359950	6403	99	22D
0005432359967	6403	100	23A
0005435176741	6403	101	23B
0005432359970	6403	102	23C
0005432359968	6403	103	23D
0005432335937	6403	104	23F
0005432359964	6403	105	23E
0005432359581	20986	1	1A
0005435176848	20986	2	1C
0005432359573	20986	3	1D
0005432359618	20986	4	2C
0005432359603	20986	5	2D
0005435176849	20986	6	2F
0005432359524	20986	7	3D
0005434149630	20986	8	3C
0005435176847	20986	9	3F
0005432359572	20986	10	4A
0005432052722	20986	11	4C
0005432335885	20986	12	4B
0005435176865	20986	13	4D
0005435176851	20986	14	4E
0005435176863	20986	15	5B
0005435176841	20986	16	5A
0005432363371	20986	17	5C
0005432359649	20986	18	5D
0005435490201	20986	19	5E
0005432359536	20986	20	6A
0005434149634	20986	21	6B
0005435176866	20986	22	6C
0005434149639	20986	23	6E
0005435490199	20986	24	6D
0005432359534	20986	25	7A
0005435176858	20986	26	6F
0005435176855	20986	27	7B
0005432359810	20986	28	7C
0005435176857	20986	29	7D
0005432359621	20986	30	7F
0005432335853	20986	31	8A
0005432052723	20986	32	8B
0005432335854	20986	33	8D
0005432359575	20986	34	8C
0005434149635	20986	35	8E
0005432359648	20986	36	8F
0005432335821	20986	37	9B
0005432335839	20986	38	9E
0005432335850	20986	39	9D
0005435176850	20986	40	9F
0005432359509	20986	41	10D
0005435176861	20986	42	11A
0005432359523	20986	43	11C
0005434149632	20986	44	11B
0005435176852	20986	45	11D
0005432359506	20986	46	11E
0005435176844	20986	47	11F
0005432359713	20986	48	12A
0005435176842	20986	49	12B
0005432363368	20986	50	12D
0005432359589	20986	51	12C
0005435176840	20986	52	12F
0005432363369	20986	53	13A
0005435176853	20986	54	13C
0005432363370	20986	55	13D
0005434149636	20986	56	13E
0005432335820	20986	57	13F
0005432359619	20986	58	14B
0005432359516	20986	59	14D
0005434149638	20986	60	14F
0005432359712	20986	61	15A
0005435176846	20986	62	15B
0005435176843	20986	63	15E
0005432335832	20986	64	16D
0005432359590	20986	65	16C
0005432359580	20986	66	16E
0005432335840	20986	67	17A
0005432359531	20986	68	17B
0005435176845	20986	69	17D
0005432359576	20986	70	17C
0005435176854	20986	71	17F
0005432052721	20986	72	18B
0005435176862	20986	73	18C
0005434149631	20986	74	18F
0005435176856	20986	75	19A
0005432052720	20986	76	19B
0005432359579	20986	77	19C
0005434149629	20986	78	19D
0005432335866	20986	79	19E
0005435490202	20986	80	20A
0005435490200	20986	81	20D
0005432359720	20986	82	21A
0005432359620	20986	83	21C
0005435176864	20986	84	21D
0005432335865	20986	85	21E
0005434149633	20986	86	21F
0005432359517	20986	87	22A
0005435176839	20986	88	22B
0005435723030	20986	89	22D
0005434149628	20986	90	23A
0005432359671	20986	91	22F
0005435176859	20986	92	23B
0005435176860	20986	93	23D
0005432359608	20986	94	23C
0005434149637	20986	95	23F
0005434186177	17703	1	1C
0005434458505	17703	2	1D
0005434458468	17703	3	2A
0005434458456	17703	4	2C
0005434458436	17703	5	2D
0005434458516	17703	6	3A
0005434458508	17703	7	3C
0005434458455	17703	8	4B
0005434458437	17703	9	4D
0005434461617	17703	10	5B
0005434458435	17703	11	5C
0005434458433	17703	12	6A
0005434458457	17703	13	6B
0005434458531	17703	14	6C
0005434458479	17703	15	6D
0005434458467	17703	16	7A
0005434458487	17703	17	7C
0005434461616	17703	18	18A
0005434448257	17703	19	19C
0005434186176	17703	20	19D
0005434458509	17703	21	20C
0005434458506	17703	22	20D
0005434186175	17703	23	21B
0005434458470	17703	24	21C
0005434458532	17703	25	22D
0005434458638	29093	1	1A
0005434458626	29093	2	1B
0005434458633	29093	3	1C
0005434463910	29093	4	2C
0005434458625	29093	5	3A
0005434458642	29093	6	3B
0005434463909	29093	7	3C
0005434458627	29093	8	3D
0005434458635	29093	9	4B
0005434186159	29093	10	4D
0005434458644	29093	11	6C
0005434458640	29093	12	6D
0005434458634	29093	13	7B
0005434186154	29093	14	7C
0005434458632	29093	15	7D
0005434458645	29093	16	18A
0005434448283	29093	17	18B
0005434186158	29093	18	18C
0005434458630	29093	19	19A
0005434458639	29093	20	18D
0005434448282	29093	21	19B
0005434458643	29093	22	19C
0005434458641	29093	23	20A
0005434458636	29093	24	20B
0005434186157	29093	25	20C
0005434448284	29093	26	20D
0005434458637	29093	27	21A
0005434458646	29093	28	21B
0005434462770	29093	29	21C
0005434458629	29093	30	22C
0005434458631	29093	31	22D
0005434458628	29093	32	23A
0005434462771	29093	33	23B
0005435218104	21461	1	1A
0005432603968	21461	2	1B
0005432603993	21461	3	1C
0005432603977	21461	4	1D
0005432603970	21461	5	2A
0005432603995	21461	6	2C
0005432603988	21461	7	2D
0005432603994	21461	8	3A
0005432603985	21461	9	3B
0005432603982	21461	10	4A
0005432603986	21461	11	4B
0005432603999	21461	12	4C
0005432604003	21461	13	4D
0005432603989	21461	14	5A
0005432603976	21461	15	5B
0005432603979	21461	16	5C
0005432603992	21461	17	5D
0005432603998	21461	18	6A
0005432603978	21461	19	6B
0005432604000	21461	20	6C
0005432603974	21461	21	6D
0005432603996	21461	22	7A
0005432604002	21461	23	7B
0005432603966	21461	24	7C
0005432603990	21461	25	18A
0005432603980	21461	26	18C
0005432603997	21461	27	18D
0005432603987	21461	28	19A
0005432603969	21461	29	19D
0005432603983	21461	30	20A
0005432603984	21461	31	20C
0005432603991	21461	32	21A
0005432603967	21461	33	21B
0005432603975	21461	34	21C
0005432604004	21461	35	21D
0005432603972	21461	36	22A
0005432604001	21461	37	22B
0005432603981	21461	38	22C
0005432603973	21461	39	22D
0005432604005	21461	40	23A
0005432603971	21461	41	23B
0005432603651	31657	1	1A
0005432603645	31657	2	1B
0005432603701	31657	3	2A
0005432603658	31657	4	3A
0005432603643	31657	5	3B
0005432603737	31657	6	3C
0005432603672	31657	7	4A
0005432603644	31657	8	4C
0005432603653	31657	9	5A
0005432603659	31657	10	6B
0005432603738	31657	11	7B
0005432603682	31657	12	7D
0005432603783	31657	13	18B
0005432603652	31657	14	18C
0005432603739	31657	15	19B
0005432603671	31657	16	19D
0005432603699	31657	17	20A
0005432603654	31657	18	20B
0005432603660	31657	19	20D
0005432603650	31657	20	21A
0005432603649	31657	21	21C
0005432603702	31657	22	21D
0005432603797	31657	23	23A
0005432603740	31657	24	23B
0005433293199	29607	1	2A
0005433293200	29607	2	4A
0005433293203	29607	3	5C
0005433293209	29607	4	6D
0005433293198	29607	5	19A
0005433293205	29607	6	19B
0005433293202	29607	7	20A
0005433293206	29607	8	20C
0005433293208	29607	9	21B
0005433293204	29607	10	21C
0005433293201	29607	11	22A
0005433293207	29607	12	22B
0005433473180	6687	1	1B
0005435257166	6687	2	1C
0005433473189	6687	3	3A
0005433473181	6687	4	3B
0005435257167	6687	5	4B
0005433473179	6687	6	4A
0005433473182	6687	7	4D
0005433473176	6687	8	5B
0005433473185	6687	9	5D
0005433473193	6687	10	6B
0005433473190	6687	11	6D
0005433473177	6687	12	7A
0005433473178	6687	13	7D
0005433473183	6687	14	18A
0005433473192	6687	15	19A
0005433473188	6687	16	19C
0005433473187	6687	17	19D
0005433473186	6687	18	20D
0005433473175	6687	19	21A
0005435257162	6687	20	22A
0005433473184	6687	21	22D
0005433473191	6687	22	23A
0005435257163	6687	23	23B
0005435257195	23901	1	1A
0005435257194	23901	2	1B
0005433473115	23901	3	1C
0005435257187	23901	4	1D
0005435257184	23901	5	2A
0005435257198	23901	6	2D
0005433473122	23901	7	3B
0005435257186	23901	8	3C
0005433473105	23901	9	4C
0005435257182	23901	10	5B
0005433473128	23901	11	5D
0005433473101	23901	12	6A
0005433473121	23901	13	6B
0005433473102	23901	14	6C
0005433473118	23901	15	6D
0005435257190	23901	16	7D
0005435257197	23901	17	18A
0005435257188	23901	18	18C
0005435257196	23901	19	19A
0005433473120	23901	20	19D
0005435257191	23901	21	20A
0005435257183	23901	22	20D
0005435257193	23901	23	21A
0005433473119	23901	24	21C
0005435257189	23901	25	22A
0005435257185	23901	26	22C
0005435257192	23901	27	23B
0005435904892	18900	1	6A
0005434606796	22332	1	1A
0005434606794	22332	2	2A
0005434606797	22332	3	2B
0005434606795	22332	4	3A
0005434604868	22332	5	4A
0005434604865	22332	6	5B
0005434604866	22332	7	6A
0005434604867	22332	8	6B
0005434522407	3860	1	1D
0005434522414	3860	2	2B
0005434522406	3860	3	3A
0005434602875	3860	4	4A
0005434602877	3860	5	4D
0005434522405	3860	6	5A
0005434522412	3860	7	5D
0005434522408	3860	8	6A
0005434522413	3860	9	6D
0005434522404	3860	10	7A
0005434602876	3860	11	18D
0005434602879	3860	12	19D
0005434522409	3860	13	20B
0005434522410	3860	14	20D
0005434602878	3860	15	21D
0005434522411	3860	16	22C
0005434522415	3860	17	22D
0005434522416	3860	18	23A
0005435904367	3860	19	23B
0005435904383	19047	1	1C
0005434602864	19047	2	2A
0005434604838	19047	3	2B
0005434604840	19047	4	4C
0005435904389	19047	5	4D
0005434602865	19047	6	5B
0005434604837	19047	7	5D
0005434522378	19047	8	6C
0005434522385	19047	9	18A
0005435904388	19047	10	18B
0005435904385	19047	11	18C
0005435904390	19047	12	20A
0005435904384	19047	13	20B
0005435904386	19047	14	21C
0005434522386	19047	15	22A
0005435904387	19047	16	22B
0005434522376	19047	17	22C
0005434604839	19047	18	23B
0005432747221	423	1	1C
0005432747234	423	2	1A
0005432890724	423	3	1D
0005432747242	423	4	1F
0005432747227	423	5	2A
0005432890681	423	6	2D
0005432747252	423	7	3A
0005432747249	423	8	3C
0005432747228	423	9	3D
0005432749766	423	10	4A
0005432890703	423	11	4C
0005432753269	423	12	4E
0005432890758	423	13	4F
0005432890786	423	14	5A
0005432890715	423	15	5C
0005432749764	423	16	5D
0005432747254	423	17	5E
0005432890685	423	18	5F
0005432751495	423	19	6C
0005432747235	423	20	6F
0005432747256	423	21	7A
0005432753270	423	22	7C
0005432219966	423	23	7D
0005432747220	423	24	7F
0005432747241	423	25	8A
0005432747226	423	26	8C
0005432747237	423	27	8D
0005432747230	423	28	8F
0005432747246	423	29	9C
0005432747251	423	30	9D
0005432219968	423	31	9E
0005432747219	423	32	9F
0005432747244	423	33	10E
0005432890723	423	34	10F
0005432890733	423	35	11A
0005432747223	423	36	11C
0005432747233	423	37	11D
0005432747255	423	38	11F
0005432747225	423	39	12C
0005432747245	423	40	12F
0005432751496	423	41	13A
0005432751497	423	42	13C
0005432747229	423	43	13D
0005432890770	423	44	13E
0005432747240	423	45	13F
0005432747248	423	46	14A
0005432751494	423	47	14C
0005432890732	423	48	14D
0005432890757	423	49	14E
0005432219965	423	50	14F
0005432747258	423	51	15C
0005432747224	423	52	16C
0005432747257	423	53	16D
0005432747250	423	54	16E
0005432747243	423	55	16F
0005432890707	423	56	17C
0005432747238	423	57	17D
0005432749765	423	58	17F
0005432747222	423	59	18A
0005432753271	423	60	18C
0005432753272	423	61	18D
0005432747232	423	62	18E
0005432747231	423	63	19D
0005432747239	423	64	19E
0005432219967	423	65	19F
0005432747236	423	66	20A
0005435627113	423	67	20C
0005432747253	423	68	20D
0005432747247	423	69	20E
0005432746911	12083	1	1C
0005432890869	12083	2	1F
0005432890862	12083	3	2C
0005432890860	12083	4	2D
0005432890852	12083	5	2F
0005432746980	12083	6	3A
0005432747084	12083	7	3C
0005432747082	12083	8	3D
0005432746907	12083	9	3F
0005432890857	12083	10	4A
0005432746991	12083	11	4C
0005432747129	12083	12	4E
0005432890864	12083	13	4F
0005432746921	12083	14	5A
0005432890856	12083	15	5C
0005432746872	12083	16	5E
0005432890851	12083	17	6A
0005432747116	12083	18	6C
0005432890859	12083	19	6D
0005432890858	12083	20	6E
0005432746999	12083	21	6F
0005432747046	12083	22	7C
0005434153526	12083	23	7E
0005432746897	12083	24	8A
0005432890853	12083	25	8E
0005432890866	12083	26	8F
0005432890849	12083	27	9C
0005432890850	12083	28	9D
0005432746898	12083	29	9F
0005432890868	12083	30	10A
0005432746900	12083	31	10C
0005432746922	12083	32	10F
0005432753258	12083	33	11C
0005432756795	12083	34	11D
0005432890855	12083	35	11E
0005432747117	12083	36	12A
0005432747038	12083	37	12C
0005432746893	12083	38	12E
0005432890867	12083	39	12F
0005432746903	12083	40	13A
0005432747056	12083	41	13C
0005432747039	12083	42	13D
0005432890863	12083	43	13F
0005434153525	12083	44	14C
0005432746979	12083	45	14F
0005432746905	12083	46	15A
0005432746959	12083	47	15D
0005432890861	12083	48	15E
0005432753245	12083	49	15F
0005432746912	12083	50	16A
0005432890865	12083	51	16C
0005432746924	12083	52	16E
0005432747130	12083	53	16F
0005432214786	12083	54	17C
0005432214785	12083	55	17D
0005432747088	12083	56	17E
0005432746906	12083	57	18C
0005432747089	12083	58	18D
0005432747055	12083	59	18E
0005432747083	12083	60	19A
0005432890854	12083	61	19C
0005433875366	12083	62	19D
0005432746873	12083	63	19E
0005432756794	12083	64	20C
0005432746960	12083	65	20D
0005432746882	12083	66	20F
0005433531258	18999	1	1B
0005433524937	18999	2	1C
0005433533274	18999	3	1D
0005433531259	18999	4	2A
0005433524941	18999	5	2D
0005433533272	18999	6	3C
0005433524936	18999	7	4B
0005433524944	18999	8	4D
0005433531257	18999	9	5A
0005433524942	18999	10	6C
0005433524945	18999	11	7B
0005433524939	18999	12	7C
0005433531260	18999	13	19A
0005433533275	18999	14	19B
0005433524943	18999	15	19D
0005433533273	18999	16	20A
0005433533271	18999	17	21C
0005433524940	18999	18	23A
0005433524938	18999	19	23B
0005433524902	32465	1	1A
0005433524896	32465	2	1C
0005432927936	32465	3	2D
0005433531248	32465	4	3C
0005433524881	32465	5	3D
0005433531240	32465	6	4B
0005433531235	32465	7	4D
0005432927939	32465	8	5B
0005433524853	32465	9	5C
0005432927940	32465	10	5D
0005433524874	32465	11	6A
0005433524886	32465	12	6D
0005433524870	32465	13	7A
0005433524885	32465	14	7D
0005433531247	32465	15	18A
0005433531236	32465	16	19A
0005433524875	32465	17	19B
0005432927938	32465	18	19C
0005432927941	32465	19	21A
0005433524860	32465	20	21C
0005433524861	32465	21	21D
0005432927937	32465	22	22C
0005433524901	32465	23	23A
0005434558207	5249	1	1C
0005435386478	5249	2	1A
0005432394070	5249	3	1G
0005435372248	5249	4	1D
0005434822553	5249	5	1K
0005434822545	5249	6	2D
0005434822571	5249	7	2C
0005435372128	5249	8	2G
0005434822522	5249	9	3C
0005434664939	5249	10	3G
0005435372174	5249	11	3K
0005435372314	5249	12	3H
0005432121219	5249	13	4A
0005435149921	5249	14	4G
0005434822599	5249	15	4K
0005435149925	5249	16	4H
0005434822527	5249	17	5D
0005434822606	5249	18	5H
0005435304099	5249	19	11A
0005434822488	5249	20	11F
0005434822481	5249	21	11E
0005432121213	5249	22	11H
0005434822568	5249	23	11G
0005434822559	5249	24	12C
0005435304092	5249	25	12G
0005434558208	5249	26	12K
0005434822560	5249	27	13D
0005434822607	5249	28	13C
0005434822580	5249	29	13A
0005434822500	5249	30	13K
0005434822587	5249	31	13G
0005434822511	5249	32	14A
0005435299706	5249	33	14C
0005434822582	5249	34	14F
0005435372218	5249	35	14E
0005435372294	5249	36	14K
0005434822498	5249	37	14H
0005435661888	5249	38	15D
0005434822480	5249	39	15C
0005434822557	5249	40	15G
0005435299700	5249	41	16A
0005434822552	5249	42	15K
0005434822512	5249	43	16C
0005434822584	5249	44	16F
0005435661889	5249	45	16K
0005435149915	5249	46	17C
0005435735057	5249	47	17A
0005434822499	5249	48	17E
0005432394072	5249	49	17D
0005434822490	5249	50	17G
0005435372164	5249	51	17H
0005435372315	5249	52	18A
0005434822593	5249	53	18E
0005434822536	5249	54	18C
0005434822528	5249	55	18G
0005434822547	5249	56	18F
0005434822492	5249	57	18H
0005434831107	5249	58	19B
0005434822523	5249	59	18K
0005434822595	5249	60	19C
0005432121215	5249	61	19E
0005434828672	5249	62	19G
0005434822491	5249	63	19J
0005434822533	5249	64	20B
0005435372194	5249	65	20E
0005435372163	5249	66	20F
0005434822573	5249	67	20K
0005434822600	5249	68	21C
0005435149916	5249	69	21H
0005434822555	5249	70	22C
0005434822529	5249	71	22B
0005434822503	5249	72	22E
0005434822525	5249	73	22D
0005435372342	5249	74	22H
0005435372313	5249	75	22G
0005432121216	5249	76	22F
0005434822514	5249	77	23C
0005434822484	5249	78	23B
0005434822585	5249	79	23G
0005434822589	5249	80	23F
0005434558210	5249	81	23E
0005434822608	5249	82	23J
0005435372491	5249	83	24G
0005434822513	5249	84	24F
0005432121224	5249	85	25A
0005435372303	5249	86	25D
0005434822581	5249	87	25C
0005434822530	5249	88	25F
0005435149926	5249	89	25E
0005434558209	5249	90	25J
0005434822520	5249	91	25H
0005434822574	5249	92	25G
0005435372200	5249	93	25K
0005434822493	5249	94	26B
0005434822577	5249	95	26A
0005434822497	5249	96	26D
0005434822602	5249	97	26G
0005435372192	5249	98	26F
0005435372319	5249	99	26H
0005434828671	5249	100	27B
0005435372284	5249	101	27A
0005434822505	5249	102	27C
0005434822605	5249	103	27G
0005432121220	5249	104	28B
0005434822532	5249	105	28A
0005434822575	5249	106	28D
0005435149923	5249	107	28C
0005434822544	5249	108	28G
0005435372382	5249	109	28F
0005434822546	5249	110	28E
0005435735065	5249	111	28K
0005432121214	5249	112	28H
0005434822537	5249	113	29A
0005434822506	5249	114	29D
0005434822566	5249	115	29C
0005434822569	5249	116	29F
0005435372234	5249	117	29H
0005434558206	5249	118	29K
0005434822563	5249	119	30C
0005434822508	5249	120	30E
0005434822561	5249	121	30G
0005434831106	5249	122	30F
0005434822539	5249	123	30J
0005435149918	5249	124	31B
0005434822485	5249	125	31D
0005434822502	5249	126	31C
0005435372175	5249	127	31F
0005435304100	5249	128	31E
0005434822483	5249	129	31H
0005432396209	5249	130	32E
0005435149922	5249	131	32D
0005434822548	5249	132	32G
0005434822596	5249	133	32J
0005432121221	5249	134	32H
0005434831109	5249	135	33B
0005435661887	5249	136	33A
0005435372241	5249	137	32K
0005434822554	5249	138	33G
0005435372172	5249	139	33E
0005432121222	5249	140	33H
0005435149914	5249	141	34A
0005435372199	5249	142	33K
0005435372461	5249	143	33J
0005434822487	5249	144	34B
0005435372292	5249	145	34E
0005434822564	5249	146	34D
0005432121212	5249	147	34C
0005435372170	5249	148	34G
0005435386468	5249	149	34F
0005435372211	5249	150	34H
0005435179687	5249	151	35A
0005432121225	5249	152	34K
0005434822576	5249	153	35D
0005435179686	5249	154	35F
0005434822598	5249	155	35J
0005434822516	5249	156	35H
0005434822482	5249	157	35G
0005435372140	5249	158	36A
0005435372418	5249	159	36C
0005434822583	5249	160	36E
0005434822604	5249	161	36D
0005434822486	5249	162	36G
0005434822590	5249	163	36F
0005435304107	5249	164	36K
0005434558205	5249	165	36J
0005435372109	5249	166	36H
0005434822489	5249	167	37B
0005434822509	5249	168	37A
0005434822562	5249	169	37D
0005434822494	5249	170	37C
0005434822526	5249	171	37E
0005435372272	5249	172	37K
0005434822601	5249	173	38C
0005434822496	5249	174	38B
0005434822534	5249	175	38J
0005434822565	5249	176	39A
0005435372108	5249	177	39F
0005432121217	5249	178	39D
0005434822521	5249	179	39G
0005435149919	5249	180	40C
0005434822541	5249	181	40B
0005435372181	5249	182	40A
0005432121223	5249	183	40F
0005434822524	5249	184	40E
0005434822519	5249	185	40H
0005435149920	5249	186	40G
0005434822588	5249	187	40K
0005434822603	5249	188	40J
0005435149924	5249	189	41B
0005434822551	5249	190	41C
0005434822556	5249	191	41G
0005434822510	5249	192	41F
0005435299701	5249	193	42A
0005432394071	5249	194	41K
0005434822558	5249	195	42C
0005434822540	5249	196	42B
0005435372198	5249	197	42E
0005434822579	5249	198	42D
0005434822592	5249	199	42G
0005434822501	5249	200	43B
0005434822570	5249	201	43A
0005434828673	5249	202	42K
0005432396208	5249	203	43D
0005434831108	5249	204	43C
0005434822542	5249	205	43F
0005435735056	5249	206	43H
0005434822549	5249	207	43G
0005434822507	5249	208	43J
0005435372334	5249	209	44C
0005435372193	5249	210	44B
0005434822495	5249	211	44D
0005432396211	5249	212	44H
0005434822518	5249	213	44F
0005432121218	5249	214	44J
0005434822567	5249	215	45A
0005434822550	5249	216	45C
0005435372217	5249	217	45B
0005434822531	5249	218	45G
0005434822535	5249	219	45J
0005432396210	5249	220	46B
0005434822538	5249	221	46A
0005435372171	5249	222	46D
0005434828670	5249	223	46G
0005434822572	5249	224	46J
0005435372189	5249	225	47A
0005435372191	5249	226	47D
0005434822597	5249	227	47G
0005432394069	5249	228	47H
0005434822586	5249	229	48C
0005434822517	5249	230	48F
0005435372271	5249	231	48E
0005435372235	5249	232	48G
0005435372462	5249	233	49A
0005435149917	5249	234	48K
0005435372374	5249	235	49D
0005435372268	5249	236	49C
0005435661886	5249	237	49F
0005435372343	5249	238	49H
0005434822515	5249	239	49G
0005435372320	5249	240	50C
0005435372293	5249	241	50A
0005434822594	5249	242	49K
0005434822591	5249	243	50E
0005435372417	5249	244	50D
0005434822578	5249	245	50G
0005435304097	5249	246	50F
0005434822543	5249	247	51D
0005435372212	5249	248	50H
0005434822504	5249	249	51F
0005435372697	9893	1	1C
0005434821644	9893	2	1D
0005435372739	9893	3	1K
0005432396176	9893	4	1H
0005435661907	9893	5	2A
0005435372744	9893	6	2H
0005435372727	9893	7	2D
0005435372725	9893	8	3A
0005435372759	9893	9	3C
0005434821401	9893	10	3K
0005434822052	9893	11	4A
0005435372751	9893	12	4G
0005434821916	9893	13	4H
0005434822047	9893	14	5H
0005435372711	9893	15	11A
0005435372719	9893	16	5K
0005434822006	9893	17	11D
0005435735100	9893	18	11F
0005435302160	9893	19	11H
0005434821753	9893	20	11K
0005435661906	9893	21	12E
0005432203005	9893	22	12D
0005435372736	9893	23	12G
0005434821444	9893	24	12F
0005434822010	9893	25	13A
0005434821478	9893	26	12K
0005434831067	9893	27	12H
0005434821622	9893	28	13F
0005435149840	9893	29	13G
0005434821600	9893	30	14A
0005435149802	9893	31	14D
0005435372732	9893	32	14F
0005432396184	9893	33	14K
0005435372729	9893	34	14H
0005435372756	9893	35	15C
0005435372714	9893	36	15E
0005435386520	9893	37	15D
0005432203006	9893	38	15F
0005435149839	9893	39	15K
0005435299736	9893	40	16C
0005435372738	9893	41	16F
0005435299735	9893	42	16E
0005435372748	9893	43	16D
0005434821413	9893	44	16H
0005434821535	9893	45	17A
0005434821470	9893	46	17D
0005434821776	9893	47	17G
0005435372743	9893	48	17K
0005434821445	9893	49	17H
0005435302159	9893	50	18A
0005435372757	9893	51	18D
0005435386524	9893	52	18C
0005434821813	9893	53	18F
0005435386521	9893	54	18J
0005435372752	9893	55	18H
0005435735104	9893	56	19B
0005434821503	9893	57	19A
0005434821533	9893	58	18K
0005434821580	9893	59	19D
0005435372694	9893	60	19F
0005434821529	9893	61	19E
0005434821797	9893	62	19J
0005435372741	9893	63	19H
0005434821798	9893	64	19K
0005435372749	9893	65	20B
0005435372731	9893	66	20C
0005434831068	9893	67	20F
0005434821775	9893	68	20K
0005434821604	9893	69	20J
0005435372712	9893	70	21B
0005434821589	9893	71	21A
0005434821339	9893	72	21C
0005435386519	9893	73	21H
0005434821313	9893	74	22A
0005435302162	9893	75	21K
0005434821706	9893	76	21J
0005434821661	9893	77	22G
0005435372742	9893	78	22J
0005434821534	9893	79	23A
0005435149824	9893	80	22K
0005435149810	9893	81	23D
0005435372737	9893	82	23E
0005435372755	9893	83	23G
0005435372723	9893	84	23K
0005434821325	9893	85	24G
0005432203003	9893	86	24F
0005434821645	9893	87	25A
0005434821567	9893	88	25F
0005434821748	9893	89	25K
0005435372745	9893	90	26C
0005432396174	9893	91	26D
0005432203001	9893	92	26G
0005434821471	9893	93	26F
0005434821795	9893	94	26J
0005434821320	9893	95	26H
0005434822056	9893	96	27D
0005435372702	9893	97	27C
0005435299738	9893	98	27J
0005435372747	9893	99	27G
0005434821626	9893	100	28C
0005434821757	9893	101	28B
0005434821761	9893	102	28D
0005434821648	9893	103	28G
0005435372730	9893	104	28F
0005434664921	9893	105	28K
0005434821699	9893	106	28J
0005435372750	9893	107	29D
0005434821479	9893	108	29F
0005435386522	9893	109	29E
0005435386523	9893	110	29J
0005434822057	9893	111	29K
0005434821569	9893	112	30C
0005435372700	9893	113	30B
0005435372707	9893	114	30E
0005434821927	9893	115	30D
0005434821880	9893	116	30G
0005434821443	9893	117	30K
0005434821793	9893	118	30J
0005434821452	9893	119	30H
0005435149851	9893	120	31C
0005435372713	9893	121	31F
0005434821352	9893	122	31E
0005434821495	9893	123	31H
0005435372718	9893	124	31G
0005435372734	9893	125	31J
0005432203007	9893	126	32C
0005435372708	9893	127	32B
0005435302161	9893	128	32E
0005434822009	9893	129	32G
0005434822048	9893	130	32K
0005434821578	9893	131	33B
0005434821360	9893	132	33G
0005434821387	9893	133	33K
0005434821877	9893	134	34C
0005432823433	9893	135	34B
0005434821472	9893	136	34A
0005435372728	9893	137	34E
0005432823434	9893	138	34D
0005434821794	9893	139	34H
0005435302163	9893	140	35B
0005435372753	9893	141	35A
0005434821631	9893	142	34K
0005435372704	9893	143	35D
0005435372758	9893	144	35C
0005435372706	9893	145	35K
0005435149823	9893	146	35J
0005434821577	9893	147	36C
0005435386518	9893	148	36G
0005432400071	9893	149	36K
0005434831073	9893	150	36J
0005434821531	9893	151	37B
0005435372721	9893	152	37A
0005434821568	9893	153	37D
0005434821438	9893	154	37G
0005435372733	9893	155	37J
0005434821692	9893	156	38A
0005434821850	9893	157	38C
0005435372699	9893	158	38B
0005432203002	9893	159	39B
0005434821684	9893	160	39A
0005432400070	9893	161	38K
0005434821663	9893	162	39C
0005434821321	9893	163	39F
0005435372698	9893	164	39G
0005434821530	9893	165	39K
0005434831078	9893	166	39J
0005435372703	9893	167	40B
0005434821527	9893	168	40A
0005432396175	9893	169	40J
0005434821361	9893	170	41B
0005435299737	9893	171	41A
0005435372710	9893	172	41D
0005432203004	9893	173	41C
0005435372740	9893	174	41G
0005435299734	9893	175	41F
0005435661909	9893	176	41J
0005435149852	9893	177	41K
0005435372705	9893	178	42C
0005434821700	9893	179	42A
0005434821404	9893	180	42E
0005434821603	9893	181	42H
0005434821881	9893	182	42G
0005435661908	9893	183	42K
0005435372724	9893	184	43B
0005434821664	9893	185	43A
0005434821400	9893	186	43D
0005434821693	9893	187	43F
0005434822055	9893	188	43H
0005435735103	9893	189	43G
0005435372701	9893	190	43K
0005435372709	9893	191	43J
0005435149809	9893	192	44C
0005435372720	9893	193	44B
0005434821473	9893	194	44E
0005435302158	9893	195	44D
0005434821570	9893	196	44G
0005435372735	9893	197	44J
0005432203000	9893	198	44H
0005435372715	9893	199	45A
0005435372746	9893	200	44K
0005434821662	9893	201	45D
0005435735102	9893	202	45C
0005435372726	9893	203	45H
0005435372722	9893	204	45K
0005435149801	9893	205	45J
0005434821341	9893	206	46C
0005434821591	9893	207	46D
0005434821715	9893	208	46G
0005435372696	9893	209	46J
0005432203008	9893	210	47F
0005434821461	9893	211	48D
0005435372716	9893	212	48C
0005434821359	9893	213	48F
0005435372754	9893	214	48E
0005434821617	9893	215	48K
0005434821903	9893	216	49D
0005434821508	9893	217	49C
0005434821923	9893	218	49G
0005434821557	9893	219	49E
0005435735101	9893	220	50C
0005434821904	9893	221	50A
0005435372695	9893	222	50F
0005432400064	9893	223	50K
0005435372717	9893	224	51F
0005434821544	9893	225	51E
0005434821749	9893	226	51G
0005435082726	7001	1	1A
0005435082719	7001	2	2B
0005435082727	7001	3	2C
0005435790282	7001	4	3D
0005435082721	7001	5	4D
0005435082717	7001	6	5A
0005435082718	7001	7	7D
0005435082720	7001	8	18C
0005435790281	7001	9	19B
0005435082723	7001	10	20C
0005435082722	7001	11	21B
0005435082725	7001	12	21D
0005435790283	7001	13	22B
0005435082724	7001	14	22D
0005435082680	25986	1	2D
0005435082667	25986	2	7A
0005435082647	25986	3	7D
0005435082661	25986	4	18A
0005435082644	25986	5	19A
0005435790269	25986	6	20C
0005435790268	25986	7	21A
0005435082660	25986	8	22A
0005435082646	25986	9	22C
0005435082645	25986	10	23B
0005434756099	9531	1	1C
0005434756112	9531	2	1F
0005434213841	9531	3	2A
0005434213792	9531	4	2D
0005434213757	9531	5	3A
0005434213745	9531	6	4C
0005434213731	9531	7	4D
0005434756113	9531	8	4E
0005434756114	9531	9	5C
0005434756102	9531	10	5E
0005434756091	9531	11	5F
0005434213738	9531	12	6A
0005434213699	9531	13	6C
0005434756116	9531	14	6D
0005434213854	9531	15	6E
0005434213707	9531	16	6F
0005434213767	9531	17	7A
0005434213815	9531	18	7D
0005434756097	9531	19	7E
0005434213814	9531	20	8A
0005434213700	9531	21	8D
0005434213717	9531	22	8F
0005434213813	9531	23	9A
0005434213793	9531	24	9C
0005434756098	9531	25	9D
0005434756103	9531	26	10A
0005434756096	9531	27	10D
0005434213752	9531	28	10E
0005434756090	9531	29	11A
0005434756100	9531	30	11D
0005434756092	9531	31	11F
0005434213783	9531	32	12A
0005434756095	9531	33	12C
0005434756094	9531	34	12F
0005434213698	9531	35	13A
0005434756106	9531	36	13C
0005434213829	9531	37	13D
0005434756111	9531	38	13E
0005434213718	9531	39	14C
0005434213756	9531	40	14E
0005434756105	9531	41	15A
0005434213863	9531	42	15C
0005434756101	9531	43	16E
0005434213766	9531	44	17D
0005434756104	9531	45	17E
0005434756108	9531	46	17F
0005434756117	9531	47	18A
0005434756118	9531	48	18C
0005434756110	9531	49	18D
0005434756115	9531	50	18E
0005434756093	9531	51	19A
0005434756109	9531	52	19C
0005434213786	9531	53	19D
0005434756107	9531	54	19E
0005434213755	9531	55	20D
0005434213754	9531	56	20E
0005434214118	28610	1	1A
0005434214091	28610	2	2A
0005434214103	28610	3	2C
0005434214081	28610	4	3C
0005434214080	28610	5	3F
0005434214115	28610	6	4C
0005434214086	28610	7	4D
0005434214125	28610	8	4E
0005434214110	28610	9	4F
0005434214113	28610	10	5A
0005434214096	28610	11	5C
0005434214098	28610	12	5E
0005434755725	28610	13	5F
0005434214102	28610	14	6D
0005434214087	28610	15	6E
0005434214088	28610	16	6F
0005434214079	28610	17	7A
0005434214119	28610	18	7D
0005434214117	28610	19	7E
0005434214124	28610	20	8A
0005434214100	28610	21	8C
0005434214092	28610	22	8E
0005434214084	28610	23	8F
0005434755792	28610	24	9A
0005434214107	28610	25	10D
0005434214122	28610	26	10F
0005434214126	28610	27	11A
0005434214104	28610	28	11C
0005434214108	28610	29	11E
0005434214085	28610	30	11F
0005434214093	28610	31	12D
0005434214090	28610	32	12E
0005434214121	28610	33	13A
0005434214123	28610	34	14D
0005434755717	28610	35	14E
0005434214105	28610	36	15A
0005434755787	28610	37	15C
0005434214082	28610	38	15D
0005434214101	28610	39	15E
0005434214120	28610	40	15F
0005434214112	28610	41	16C
0005434214097	28610	42	16D
0005434755740	28610	43	16E
0005434755758	28610	44	16F
0005434214116	28610	45	17A
0005434214083	28610	46	17C
0005434214089	28610	47	17F
0005434214114	28610	48	18C
0005434755741	28610	49	18D
0005434214094	28610	50	18E
0005434214099	28610	51	18F
0005434214106	28610	52	19A
0005434214111	28610	53	19D
0005434214109	28610	54	20D
0005434214095	28610	55	20F
0005435100097	10833	1	1C
0005435100099	10833	2	2B
0005435100098	10833	3	4C
0005434760157	10833	4	5A
0005434760168	10833	5	18C
0005435100084	31791	1	3B
0005435100071	31791	2	3D
0005434760179	31791	3	4A
0005435100083	31791	4	5A
0005435100077	31791	5	6A
0005434760178	31791	6	18D
0005434760176	31791	7	22A
0005434760177	31791	8	22D
0005434639111	2003	1	1A
0005434639101	2003	2	1B
0005434639114	2003	3	1C
0005434639110	2003	4	1D
0005433202126	2003	5	2A
0005434639108	2003	6	2B
0005434639125	2003	7	2C
0005433202129	2003	8	2D
0005434639113	2003	9	3A
0005433202125	2003	10	3B
0005434639115	2003	11	3C
0005433202115	2003	12	3D
0005434639121	2003	13	4B
0005434639122	2003	14	4D
0005434639117	2003	15	5A
0005434639119	2003	16	5B
0005434639103	2003	17	5C
0005434639118	2003	18	5D
0005432290608	2003	19	6A
0005434639112	2003	20	6B
0005433202107	2003	21	6C
0005433202106	2003	22	6D
0005434639105	2003	23	7A
0005433202172	2003	24	7D
0005434639124	2003	25	18A
0005433202120	2003	26	18B
0005434639102	2003	27	18C
0005432290607	2003	28	18D
0005434639104	2003	29	19B
0005434639100	2003	30	19D
0005434639120	2003	31	20A
0005434639116	2003	32	20B
0005434639123	2003	33	20C
0005434639099	2003	34	20D
0005432290609	2003	35	21D
0005434639106	2003	36	22A
0005433202121	2003	37	22B
0005434639109	2003	38	22C
0005433202146	2003	39	22D
0005434639107	2003	40	23A
0005434638903	23280	1	1A
0005433202229	23280	2	1B
0005434638917	23280	3	1C
0005434638991	23280	4	1D
0005433202235	23280	5	2A
0005434638893	23280	6	2B
0005433202231	23280	7	2C
0005434638850	23280	8	3A
0005434638916	23280	9	3B
0005434638864	23280	10	3C
0005433202223	23280	11	4A
0005433202224	23280	12	4B
0005434638879	23280	13	4C
0005434638900	23280	14	5A
0005433202226	23280	15	5B
0005434638899	23280	16	6A
0005434638894	23280	17	6B
0005433202230	23280	18	6C
0005434638887	23280	19	6D
0005434638924	23280	20	7B
0005433202228	23280	21	7D
0005434638992	23280	22	18B
0005434638886	23280	23	18D
0005433202236	23280	24	19A
0005433202225	23280	25	19B
0005433202233	23280	26	19C
0005433202237	23280	27	19D
0005433202232	23280	28	20A
0005433202227	23280	29	20D
0005434638885	23280	30	21A
0005434638854	23280	31	21B
0005433202238	23280	32	21D
0005434638904	23280	33	22C
0005433202234	23280	34	23B
0005434600577	6068	1	1A
0005432111255	6068	2	1F
0005435326527	6068	3	2A
0005434600597	6068	4	2F
0005433533276	6068	5	4A
0005435326498	6068	6	4C
0005432111256	6068	7	4D
0005434600598	6068	8	4E
0005434600601	6068	9	4F
0005433531264	6068	10	5C
0005435326510	6068	11	5E
0005434600602	6068	12	6E
0005433533277	6068	13	6F
0005434600578	6068	14	7D
0005433531262	6068	15	7E
0005433533278	6068	16	8F
0005434600585	6068	17	9C
0005434600599	6068	18	9E
0005434600587	6068	19	10D
0005434600590	6068	20	10E
0005433531261	6068	21	11C
0005434600584	6068	22	11D
0005433531263	6068	23	12A
0005434600583	6068	24	12D
0005434600596	6068	25	12E
0005434600600	6068	26	13A
0005434600592	6068	27	13D
0005432111254	6068	28	13F
0005434600582	6068	29	14A
0005434600595	6068	30	14D
0005434600576	6068	31	14E
0005434600586	6068	32	15D
0005434600579	6068	33	16A
0005434600594	6068	34	16E
0005435326524	6068	35	16F
0005434600593	6068	36	17C
0005434600575	6068	37	17D
0005434600591	6068	38	18A
0005435326511	6068	39	18C
0005434600589	6068	40	18E
0005434600581	6068	41	19D
0005434600588	6068	42	20C
0005435326523	6068	43	20D
0005434600580	6068	44	20E
0005434600358	18614	1	1C
0005434600443	18614	2	1F
0005434600391	18614	3	2A
0005435326632	18614	4	2C
0005434600446	18614	5	2D
0005434600441	18614	6	3D
0005434600380	18614	7	3F
0005435326633	18614	8	4F
0005434600345	18614	9	5C
0005434600383	18614	10	5D
0005435326626	18614	11	5E
0005435326628	18614	12	5F
0005435326630	18614	13	6F
0005433527204	18614	14	7A
0005435326627	18614	15	7E
0005434600355	18614	16	8A
0005434600390	18614	17	8F
0005434600371	18614	18	9C
0005435326635	18614	19	9E
0005434600374	18614	20	10D
0005434600347	18614	21	10F
0005435326629	18614	22	11D
0005434600440	18614	23	11E
0005434600350	18614	24	12A
0005435326636	18614	25	12F
0005434600414	18614	26	13C
0005435326638	18614	27	13D
0005435326639	18614	28	13E
0005434600435	18614	29	13F
0005434600471	18614	30	14F
0005435326625	18614	31	15E
0005434600359	18614	32	16A
0005434600498	18614	33	16D
0005435326637	18614	34	16F
0005434600341	18614	35	17D
0005434600340	18614	36	17E
0005434600382	18614	37	17F
0005435326631	18614	38	18C
0005434600434	18614	39	18D
0005434600402	18614	40	18F
0005434600346	18614	41	19D
0005434600397	18614	42	20C
0005434600360	18614	43	20D
0005435326634	18614	44	20E
0005434600442	18614	45	20F
0005434550718	10655	1	1A
0005434550747	10655	2	1C
0005434550732	10655	3	1D
0005434550740	10655	4	1F
0005434550733	10655	5	2A
0005434550727	10655	6	2C
0005434550712	10655	7	2D
0005433180729	10655	8	2F
0005434550746	10655	9	3C
0005434558202	10655	10	3D
0005434550762	10655	11	3F
0005434550719	10655	12	4A
0005434550739	10655	13	4C
0005433180668	10655	14	4D
0005434558203	10655	15	4E
0005434550744	10655	16	5A
0005434550755	10655	17	5C
0005434550726	10655	18	5E
0005433180734	10655	19	6A
0005434550715	10655	20	6C
0005434550756	10655	21	6D
0005434550724	10655	22	6E
0005434550742	10655	23	6F
0005434550738	10655	24	7C
0005434550749	10655	25	7D
0005434554044	10655	26	7F
0005434550714	10655	27	8F
0005434550751	10655	28	9C
0005434550741	10655	29	9A
0005434558199	10655	30	9D
0005434550753	10655	31	9E
0005434558198	10655	32	9F
0005434550736	10655	33	10A
0005434550717	10655	34	10C
0005434550710	10655	35	10D
0005433180690	10655	36	10E
0005433180680	10655	37	11A
0005434550722	10655	38	11C
0005434550737	10655	39	11D
0005434550743	10655	40	11E
0005433180743	10655	41	12A
0005434550760	10655	42	12C
0005434554045	10655	43	12D
0005434550721	10655	44	12E
0005434550758	10655	45	12F
0005434550711	10655	46	13D
0005434558201	10655	47	13E
0005434554046	10655	48	13F
0005434550708	10655	49	14C
0005434550729	10655	50	14D
0005434550757	10655	51	14E
0005433180728	10655	52	14F
0005434550728	10655	53	15A
0005434550752	10655	54	15C
0005434558200	10655	55	15E
0005434550725	10655	56	16A
0005434550759	10655	57	16C
0005434550713	10655	58	16D
0005434550716	10655	59	16E
0005434550748	10655	60	17C
0005434550754	10655	61	17D
0005434550761	10655	62	17E
0005434550709	10655	63	17F
0005434550731	10655	64	18A
0005434550730	10655	65	18D
0005434550707	10655	66	18E
0005434558204	10655	67	18F
0005434550750	10655	68	19A
0005434550720	10655	69	19C
0005434550734	10655	70	19D
0005434550723	10655	71	19E
0005434550745	10655	72	20D
0005434550735	10655	73	20E
0005434550706	10655	74	20F
0005433180895	27766	1	2C
0005433180899	27766	2	2F
0005433180903	27766	3	3F
0005433180897	27766	4	4D
0005433180905	27766	5	5C
0005433180885	27766	6	8A
0005433180893	27766	7	8D
0005433180902	27766	8	8E
0005433180892	27766	9	8F
0005433180900	27766	10	12A
0005433180883	27766	11	12F
0005433180886	27766	12	13A
0005433180884	27766	13	13F
0005433180894	27766	14	14D
0005433180901	27766	15	14E
0005433180898	27766	16	16A
0005433180887	27766	17	16E
0005433180891	27766	18	17C
0005433180881	27766	19	17D
0005433180904	27766	20	17F
0005433180889	27766	21	18D
0005433180890	27766	22	18E
0005433180896	27766	23	19E
0005433180882	27766	24	19F
0005433180888	27766	25	20D
0005434558144	27765	1	1A
0005434550324	27765	2	1C
0005434550323	27765	3	1D
0005434550303	27765	4	1F
0005434550378	27765	5	2C
0005434550369	27765	6	2D
0005434550493	27765	7	3D
0005434550477	27765	8	3F
0005434558142	27765	9	4A
0005434558140	27765	10	4C
0005434550606	27765	11	5A
0005434550268	27765	12	5C
0005434550532	27765	13	5E
0005434550318	27765	14	6A
0005434550528	27765	15	7C
0005434550395	27765	16	7D
0005434550379	27765	17	7F
0005434550396	27765	18	8C
0005434550372	27765	19	8F
0005434550332	27765	20	9A
0005434550492	27765	21	9C
0005434550424	27765	22	9E
0005434550507	27765	23	10C
0005434550267	27765	24	10F
0005434550543	27765	25	11A
0005434550506	27765	26	11C
0005434550478	27765	27	11E
0005434550364	27765	28	12A
0005434550261	27765	29	12C
0005434550346	27765	30	12D
0005434550450	27765	31	12F
0005434550354	27765	32	13A
0005434550305	27765	33	13D
0005434550360	27765	34	14E
0005434550394	27765	35	15A
0005434550605	27765	36	15C
0005434550361	27765	37	15D
0005434550294	27765	38	15E
0005434550353	27765	39	15F
0005434550302	27765	40	16C
0005434558143	27765	41	17A
0005434550491	27765	42	17C
0005434550373	27765	43	18A
0005434550328	27765	44	19A
0005434550293	27765	45	20F
0005433459184	6115	1	2A
0005433459183	6115	2	2B
0005433459186	6115	3	3A
0005433459185	6115	4	4B
0005433459182	6115	5	5B
0005433459143	19289	1	2B
0005433459146	19289	2	3A
0005433459144	19289	3	4A
0005435254454	19289	4	5A
0005435254453	19289	5	6A
0005435681798	6763	1	1C
0005435437640	6763	2	1D
0005435437716	6763	3	1F
0005435681768	6763	4	2A
0005435681770	6763	5	2C
0005432533242	6763	6	2D
0005435681801	6763	7	2F
0005435681791	6763	8	3A
0005435681797	6763	9	3C
0005435437598	6763	10	3D
0005435720127	6763	11	4A
0005435681803	6763	12	4C
0005435681795	6763	13	4D
0005435221499	6763	14	4E
0005435437699	6763	15	4F
0005435681809	6763	16	5A
0005435681782	6763	17	5C
0005435681780	6763	18	5D
0005435681796	6763	19	5E
0005435681784	6763	20	5F
0005435681800	6763	21	6A
0005435681805	6763	22	6C
0005435630939	6763	23	6D
0005435681786	6763	24	6E
0005435681804	6763	25	7A
0005435681789	6763	26	7C
0005435681793	6763	27	7D
0005435681781	6763	28	7F
0005435221500	6763	29	8A
0005435681779	6763	30	8D
0005435437551	6763	31	8E
0005435661903	6763	32	8F
0005435719559	6763	33	9A
0005435437555	6763	34	9C
0005435221498	6763	35	9E
0005435681769	6763	36	9F
0005435437613	6763	37	10A
0005435681777	6763	38	10C
0005432533256	6763	39	10D
0005435681792	6763	40	10E
0005435681785	6763	41	10F
0005432533241	6763	42	11A
0005435681773	6763	43	11C
0005435681794	6763	44	11D
0005435437629	6763	45	11E
0005435630938	6763	46	11F
0005435681799	6763	47	12A
0005435681771	6763	48	12C
0005435681788	6763	49	12D
0005435437558	6763	50	12E
0005435661904	6763	51	12F
0005435437602	6763	52	13A
0005435681807	6763	53	13C
0005435719560	6763	54	13D
0005432136128	6763	55	13F
0005432136129	6763	56	14A
0005435437570	6763	57	14D
0005435217682	6763	58	14E
0005432136124	6763	59	14F
0005435681776	6763	60	15C
0005432136125	6763	61	15D
0005435681787	6763	62	15F
0005435681778	6763	63	16A
0005435437557	6763	64	16C
0005435437612	6763	65	16D
0005432136127	6763	66	16E
0005435437556	6763	67	16F
0005435681808	6763	68	17A
0005432136126	6763	69	17C
0005435437649	6763	70	17D
0005435437590	6763	71	17E
0005435661905	6763	72	17F
0005435681775	6763	73	18A
0005435630940	6763	74	18D
0005435681790	6763	75	18F
0005435681802	6763	76	19A
0005435437594	6763	77	19C
0005435681806	6763	78	19D
0005432533257	6763	79	19E
0005435681783	6763	80	19F
0005435681772	6763	81	20A
0005435437639	6763	82	20D
0005435681774	6763	83	20E
0005435437775	24589	1	1A
0005435681461	24589	2	1C
0005435437778	24589	3	1D
0005435437764	24589	4	1F
0005435437759	24589	5	2A
0005432533267	24589	6	2C
0005435681534	24589	7	2F
0005435437771	24589	8	3D
0005435681455	24589	9	3F
0005435437765	24589	10	4A
0005435681481	24589	11	4F
0005435681415	24589	12	5A
0005435437757	24589	13	5C
0005435437761	24589	14	5D
0005435681451	24589	15	5E
0005432305728	24589	16	5F
0005435681522	24589	17	6C
0005435681440	24589	18	6D
0005432305730	24589	19	7A
0005435681521	24589	20	7D
0005435437766	24589	21	7E
0005435681430	24589	22	7F
0005435681663	24589	23	8A
0005432305727	24589	24	8C
0005435681546	24589	25	8E
0005435437777	24589	26	8F
0005434828675	24589	27	9E
0005432533268	24589	28	9F
0005435681431	24589	29	10A
0005435437758	24589	30	10C
0005435681408	24589	31	10D
0005432533266	24589	32	10E
0005435681470	24589	33	10F
0005435437768	24589	34	11A
0005435681416	24589	35	11D
0005435681453	24589	36	11E
0005435681533	24589	37	11F
0005435437769	24589	38	12C
0005435681403	24589	39	12E
0005434828674	24589	40	13A
0005435681439	24589	41	13C
0005435437763	24589	42	14C
0005435681409	24589	43	14D
0005435437760	24589	44	14F
0005435437772	24589	45	15C
0005435681448	24589	46	15D
0005435681438	24589	47	15E
0005435437770	24589	48	16A
0005435681389	24589	49	16C
0005435681509	24589	50	17A
0005435437776	24589	51	17C
0005435720805	24589	52	17D
0005435437767	24589	53	17E
0005435437773	24589	54	18A
0005435681454	24589	55	18C
0005435437762	24589	56	18E
0005435720806	24589	57	18F
0005435681433	24589	58	19A
0005435681462	24589	59	19C
0005435681502	24589	60	19D
0005435437774	24589	61	19E
0005435681463	24589	62	19F
0005435630915	24589	63	20A
0005435630916	24589	64	20C
0005432305729	24589	65	20D
0005435681501	24589	66	20E
0005435125981	11505	1	1A
0005435558040	11505	2	1C
0005435126012	11505	3	1D
0005435125995	11505	4	2A
0005435126021	11505	5	2D
0005435125989	11505	6	3C
0005435125999	11505	7	3D
0005435558047	11505	8	4A
0005435558049	11505	9	5D
0005435126005	11505	10	5E
0005435126007	11505	11	5F
0005435126000	11505	12	6A
0005435125998	11505	13	6D
0005435125988	11505	14	6E
0005435126002	11505	15	7A
0005435125997	11505	16	7C
0005435558041	11505	17	7D
0005435126017	11505	18	7E
0005435125994	11505	19	8A
0005435126015	11505	20	8E
0005435125985	11505	21	8F
0005435125996	11505	22	9C
0005435125992	11505	23	9E
0005435126014	11505	24	9F
0005435126003	11505	25	10A
0005435126004	11505	26	10D
0005435105953	11505	27	10E
0005435125980	11505	28	11A
0005435126010	11505	29	11C
0005435126016	11505	30	13D
0005435126001	11505	31	13E
0005435126018	11505	32	13F
0005435125993	11505	33	14C
0005435105954	11505	34	15C
0005435125982	11505	35	15D
0005435126019	11505	36	15F
0005435558050	11505	37	16A
0005435126013	11505	38	16C
0005435126020	11505	39	16D
0005435125991	11505	40	16E
0005435126011	11505	41	17D
0005435126006	11505	42	17E
0005435125990	11505	43	18C
0005435126009	11505	44	18D
0005435125984	11505	45	18E
0005435125987	11505	46	19A
0005435558039	11505	47	19D
0005435126008	11505	48	19F
0005435125986	11505	49	20A
0005435125983	11505	50	20E
0005435125722	31860	1	1D
0005435558066	31860	2	2A
0005435105932	31860	3	2F
0005435125825	31860	4	3A
0005435125693	31860	5	3C
0005435558065	31860	6	3D
0005435125708	31860	7	3F
0005435125712	31860	8	4D
0005435125718	31860	9	4E
0005435125725	31860	10	5A
0005435125705	31860	11	5C
0005435125691	31860	12	5E
0005435125648	31860	13	6A
0005435125680	31860	14	6D
0005435125727	31860	15	7C
0005435125690	31860	16	7F
0005435125711	31860	17	9A
0005435125682	31860	18	9C
0005435125781	31860	19	9D
0005435125883	31860	20	9E
0005435125882	31860	21	11C
0005435125655	31860	22	11D
0005435105923	31860	23	11E
0005435125762	31860	24	12A
0005435125692	31860	25	12D
0005435125647	31860	26	12E
0005435125746	31860	27	13A
0005435125677	31860	28	13D
0005435125707	31860	29	14D
0005435125678	31860	30	14F
0005435125726	31860	31	15C
0005435105925	31860	32	15D
0005435125922	31860	33	15F
0005435105939	31860	34	16D
0005435125836	31860	35	16F
0005435125689	31860	36	17F
0005435125721	31860	37	19F
0005435105924	31860	38	20C
0005435098521	31860	39	20E
0005433397640	13542	1	1C
0005433397670	13542	2	2D
0005433397663	13542	3	2F
0005435732150	13542	4	3A
0005433397628	13542	5	3C
0005433397651	13542	6	3F
0005433397641	13542	7	4A
0005433397665	13542	8	4E
0005435732142	13542	9	5A
0005433397655	13542	10	5D
0005433397650	13542	11	5E
0005433397639	13542	12	5F
0005433397662	13542	13	6D
0005433397658	13542	14	6E
0005433397652	13542	15	6F
0005433397627	13542	16	7E
0005433397673	13542	17	7F
0005435732141	13542	18	8C
0005435732122	13542	19	8D
0005433397637	13542	20	9D
0005433397657	13542	21	9E
0005433397666	13542	22	9F
0005433397644	13542	23	10C
0005433397653	13542	24	10D
0005433397669	13542	25	11C
0005433397661	13542	26	11D
0005433397636	13542	27	11E
0005433397671	13542	28	11F
0005433397634	13542	29	12D
0005433397646	13542	30	12E
0005433397632	13542	31	12F
0005433397642	13542	32	13A
0005433397635	13542	33	13D
0005435732151	13542	34	13E
0005433397667	13542	35	14C
0005433397638	13542	36	14D
0005433397629	13542	37	14F
0005433397675	13542	38	15C
0005433397672	13542	39	15D
0005433397668	13542	40	15F
0005433397647	13542	41	16C
0005433397643	13542	42	16D
0005435732126	13542	43	17A
0005433397660	13542	44	17C
0005433397649	13542	45	17D
0005433397645	13542	46	17E
0005433397656	13542	47	17F
0005433397659	13542	48	18C
0005433397633	13542	49	18D
0005433397674	13542	50	19A
0005433397631	13542	51	19D
0005433397654	13542	52	19E
0005433397648	13542	53	20A
0005435732121	13542	54	20C
0005435732120	13542	55	20D
0005433397664	13542	56	20E
0005433397630	13542	57	20F
0005433397275	19423	1	1A
0005433397318	19423	2	1C
0005433397313	19423	3	2A
0005435732232	19423	4	4D
0005433397306	19423	5	5C
0005433397361	19423	6	6A
0005435732229	19423	7	6C
0005433397396	19423	8	6D
0005433397274	19423	9	7F
0005435732227	19423	10	8A
0005433397270	19423	11	8D
0005433397304	19423	12	8F
0005433397456	19423	13	9C
0005433397307	19423	14	9D
0005433397298	19423	15	9E
0005433397269	19423	16	9F
0005433397276	19423	17	10A
0005432297254	19423	18	10C
0005433397299	19423	19	10D
0005432297255	19423	20	11C
0005433397215	19423	21	11D
0005435732231	19423	22	12E
0005433397266	19423	23	13A
0005433397265	19423	24	14C
0005433397204	19423	25	14D
0005433397317	19423	26	14E
0005433397337	19423	27	15A
0005433397244	19423	28	16A
0005432297256	19423	29	16C
0005433397366	19423	30	17A
0005435732230	19423	31	17D
0005433397214	19423	32	17E
0005433397264	19423	33	17F
0005433397262	19423	34	18D
0005435732228	19423	35	18F
0005433397263	19423	36	19A
0005433397443	19423	37	19D
0005435732226	19423	38	19E
0005433397213	19423	39	19F
0005433397305	19423	40	20D
0005433397248	19423	41	20E
0005433397397	19423	42	20F
0005435068349	13131	1	1A
0005435925188	13131	2	1C
0005435068339	13131	3	2A
0005435925182	13131	4	2C
0005435925178	13131	5	2D
0005435068219	13131	6	3C
0005435068213	13131	7	3D
0005435925190	13131	8	4A
0005435925185	13131	9	4C
0005435068179	13131	10	4D
0005435925186	13131	11	5A
0005435925180	13131	12	6A
0005435068202	13131	13	6D
0005435068235	13131	14	7A
0005435068234	13131	15	7C
0005435925177	13131	16	7D
0005435925183	13131	17	8A
0005435068366	13131	18	8F
0005435068285	13131	19	9F
0005435068257	13131	20	10A
0005435925191	13131	21	10D
0005435925184	13131	22	10E
0005435068258	13131	23	10F
0005435068306	13131	24	12C
0005435068407	13131	25	12E
0005435068259	13131	26	12F
0005435068188	13131	27	13A
0005435068210	13131	28	13E
0005435068338	13131	29	14A
0005435068240	13131	30	14E
0005435925181	13131	31	14F
0005435068348	13131	32	15C
0005435925179	13131	33	15D
0005435068241	13131	34	15F
0005435068312	13131	35	16A
0005435068180	13131	36	16E
0005435068225	13131	37	17A
0005435068307	13131	38	18A
0005435068189	13131	39	18C
0005435068220	13131	40	18E
0005435925187	13131	41	19C
0005435068226	13131	42	19E
0005435925189	13131	43	19F
0005435068367	13131	44	20C
0005435068209	13131	45	20E
0005435925059	15499	1	1A
0005435925064	15499	2	1C
0005435068629	15499	3	1F
0005435068598	15499	4	2A
0005435925082	15499	5	2C
0005435068605	15499	6	2D
0005435925056	15499	7	2F
0005435925063	15499	8	3D
0005435925055	15499	9	3F
0005435068611	15499	10	4A
0005435068625	15499	11	4C
0005435068631	15499	12	4D
0005435068623	15499	13	4E
0005435068590	15499	14	4F
0005435068624	15499	15	5C
0005435925060	15499	16	5D
0005435068591	15499	17	6A
0005435068627	15499	18	6C
0005435925081	15499	19	6D
0005435068603	15499	20	6E
0005435068608	15499	21	7A
0005435068599	15499	22	7C
0005435068613	15499	23	7E
0005435068626	15499	24	8C
0005435068630	15499	25	8D
0005435068610	15499	26	9A
0005435068582	15499	27	9F
0005435068596	15499	28	10A
0005435068601	15499	29	10D
0005435068588	15499	30	10F
0005435068620	15499	31	11D
0005435925086	15499	32	11C
0005435068587	15499	33	11E
0005435068600	15499	34	11F
0005435068584	15499	35	12A
0005435068606	15499	36	12C
0005435068633	15499	37	12E
0005435068595	15499	38	12F
0005435068622	15499	39	13E
0005435068586	15499	40	14A
0005435068621	15499	41	14C
0005435068615	15499	42	14D
0005435068593	15499	43	14E
0005435068604	15499	44	15A
0005435068594	15499	45	15C
0005435068628	15499	46	15D
0005435068616	15499	47	15F
0005435068592	15499	48	16A
0005435068609	15499	49	16C
0005435068583	15499	50	16D
0005435068585	15499	51	16E
0005435068618	15499	52	16F
0005435068617	15499	53	17A
0005435068607	15499	54	17E
0005435068597	15499	55	18C
0005435068614	15499	56	18E
0005435068602	15499	57	19A
0005435068634	15499	58	19C
0005435925094	15499	59	19D
0005435068632	15499	60	19F
0005435068589	15499	61	20A
0005435068612	15499	62	20D
0005435068619	15499	63	20E
0005435925066	15499	64	20F
0005435808059	29501	1	1B
0005435808065	29501	2	1C
0005435808073	29501	3	2A
0005435808069	29501	4	3A
0005433407527	29501	5	3C
0005433407525	29501	6	3D
0005435808054	29501	7	4A
0005433407522	29501	8	4B
0005435808055	29501	9	4C
0005433407526	29501	10	4D
0005435808070	29501	11	5B
0005433407521	29501	12	5C
0005435808064	29501	13	5D
0005435808061	29501	14	6A
0005435808062	29501	15	7A
0005433407528	29501	16	7D
0005433407520	29501	17	18B
0005433407529	29501	18	18C
0005435808060	29501	19	19A
0005435808067	29501	20	20B
0005433407524	29501	21	20D
0005435808066	29501	22	21A
0005433407523	29501	23	21B
0005433407519	29501	24	22B
0005433407518	29501	25	23A
0005435808058	29501	26	23B
0005434214172	10704	1	1A
0005434214147	10704	2	1C
0005434214140	10704	3	2A
0005434214161	10704	4	2C
0005434755706	10704	5	2D
0005434214138	10704	6	2F
0005434214159	10704	7	3A
0005434755762	10704	8	3C
0005434214158	10704	9	4A
0005434214137	10704	10	4C
0005434214151	10704	11	4D
0005434755766	10704	12	4F
0005434214136	10704	13	5A
0005434214169	10704	14	5C
0005434755770	10704	15	5E
0005434214148	10704	16	6C
0005434214133	10704	17	6D
0005434755763	10704	18	6E
0005434214135	10704	19	7A
0005434214149	10704	20	7C
0005434755771	10704	21	7D
0005434755707	10704	22	7F
0005434214173	10704	23	8D
0005434214165	10704	24	8E
0005434755756	10704	25	9A
0005434755705	10704	26	9C
0005434214129	10704	27	9D
0005434755738	10704	28	9E
0005434214152	10704	29	9F
0005434214139	10704	30	10A
0005434755757	10704	31	10F
0005434755726	10704	32	11A
0005434214153	10704	33	11C
0005434755727	10704	34	11D
0005434214146	10704	35	11E
0005434214134	10704	36	12A
0005434214131	10704	37	12E
0005434214164	10704	38	12F
0005434214170	10704	39	13A
0005434214155	10704	40	13C
0005434214128	10704	41	13D
0005434755742	10704	42	13E
0005434755711	10704	43	13F
0005434755712	10704	44	14A
0005434214154	10704	45	14C
0005434214141	10704	46	14D
0005434214160	10704	47	14E
0005434214156	10704	48	14F
0005434214132	10704	49	15A
0005434214127	10704	50	15F
0005434214168	10704	51	16A
0005434214150	10704	52	16C
0005434214145	10704	53	16D
0005434214157	10704	54	16F
0005434755759	10704	55	17A
0005434755750	10704	56	17D
0005434214162	10704	57	17E
0005434214166	10704	58	17F
0005434214142	10704	59	18C
0005434214130	10704	60	18E
0005434214144	10704	61	18F
0005434755769	10704	62	19A
0005434214167	10704	63	19C
0005434214143	10704	64	19D
0005434755772	10704	65	19E
0005434214171	10704	66	20A
0005434755748	10704	67	20C
0005434755760	10704	68	20E
0005434214163	10704	69	20F
0005434213716	28671	1	1C
0005434756084	28671	2	1D
0005434213784	28671	3	1F
0005434213772	28671	4	2A
0005434756057	28671	5	2F
0005434756089	28671	6	3D
0005434756051	28671	7	3F
0005434213743	28671	8	4C
0005434756049	28671	9	4D
0005434213778	28671	10	4E
0005434213715	28671	11	4F
0005434756068	28671	12	5C
0005434756079	28671	13	5D
0005434756053	28671	14	5F
0005434756087	28671	15	6A
0005434756061	28671	16	6C
0005434756054	28671	17	6D
0005434756066	28671	18	6E
0005434756080	28671	19	7A
0005434756055	28671	20	7D
0005434213771	28671	21	7C
0005434756085	28671	22	7E
0005434756086	28671	23	7F
0005434756056	28671	24	8E
0005434756075	28671	25	8F
0005434756088	28671	26	9C
0005434756071	28671	27	9E
0005434756083	28671	28	10A
0005434756073	28671	29	10D
0005434213777	28671	30	11C
0005434756076	28671	31	11D
0005434213869	28671	32	11F
0005434756058	28671	33	12A
0005434756074	28671	34	12D
0005434213880	28671	35	13A
0005434756081	28671	36	13F
0005434756064	28671	37	14C
0005434756060	28671	38	14D
0005434213769	28671	39	14F
0005434756050	28671	40	15A
0005434756067	28671	41	15C
0005434213776	28671	42	15F
0005434756077	28671	43	16A
0005434756082	28671	44	16C
0005434213741	28671	45	16D
0005434756072	28671	46	16E
0005434756063	28671	47	16F
0005434756059	28671	48	17C
0005434213879	28671	49	17D
0005434213768	28671	50	17E
0005434756069	28671	51	17F
0005434756065	28671	52	18A
0005434756062	28671	53	18E
0005434756078	28671	54	19A
0005434213742	28671	55	20A
0005434756070	28671	56	20D
0005434756052	28671	57	20F
0005435039246	5465	1	1A
0005435006830	5465	2	1D
0005435039216	5465	3	1F
0005435039211	5465	4	2C
0005435039225	5465	5	2A
0005435039212	5465	6	2F
0005435039227	5465	7	2D
0005435039262	5465	8	3C
0005434228980	5465	9	3A
0005435039226	5465	10	3D
0005435006817	5465	11	3F
0005435006832	5465	12	4A
0005435039241	5465	13	4B
0005435006820	5465	14	4D
0005435039204	5465	15	4C
0005435039221	5465	16	4E
0005435039198	5465	17	4F
0005432125387	5465	18	5B
0005434228969	5465	19	5A
0005435039253	5465	20	5D
0005432125389	5465	21	5C
0005434228970	5465	22	5E
0005435039249	5465	23	5F
0005435039194	5465	24	6B
0005435039209	5465	25	6A
0005435039223	5465	26	6C
0005435039201	5465	27	6D
0005434228981	5465	28	7A
0005432125388	5465	29	7C
0005434229004	5465	30	7E
0005434228998	5465	31	7D
0005434228996	5465	32	7F
0005434229035	5465	33	8A
0005435039213	5465	34	8B
0005435039254	5465	35	8C
0005435039234	5465	36	8D
0005435039255	5465	37	8E
0005435039193	5465	38	9A
0005435039237	5465	39	8F
0005435039250	5465	40	9B
0005435039205	5465	41	9D
0005435039238	5465	42	9C
0005435039195	5465	43	9F
0005435039240	5465	44	9E
0005435039200	5465	45	10C
0005435006829	5465	46	10E
0005435006836	5465	47	10D
0005434229027	5465	48	11A
0005432125391	5465	49	11B
0005435006841	5465	50	11D
0005435039256	5465	51	11E
0005434229048	5465	52	11F
0005435006837	5465	53	12A
0005435039228	5465	54	12B
0005435039230	5465	55	12D
0005435006821	5465	56	12C
0005435039260	5465	57	12E
0005434229020	5465	58	12F
0005435039235	5465	59	13A
0005435039215	5465	60	13C
0005435006839	5465	61	13B
0005435039257	5465	62	13D
0005435039236	5465	63	13E
0005435006822	5465	64	13F
0005435039251	5465	65	14B
0005435039202	5465	66	14A
0005434228997	5465	67	14C
0005435039220	5465	68	14D
0005432125393	5465	69	14E
0005435006819	5465	70	14F
0005435039197	5465	71	15B
0005435039207	5465	72	15A
0005434229028	5465	73	15C
0005435039229	5465	74	15D
0005435006823	5465	75	15F
0005435039243	5465	76	15E
0005435039210	5465	77	16B
0005435039196	5465	78	16A
0005434229021	5465	79	16C
0005435039199	5465	80	16E
0005435039239	5465	81	16D
0005434229047	5465	82	17A
0005434228971	5465	83	16F
0005435006828	5465	84	17B
0005435039219	5465	85	17C
0005435039218	5465	86	17D
0005435039206	5465	87	17E
0005435006838	5465	88	18A
0005435039258	5465	89	17F
0005435039252	5465	90	18B
0005435039214	5465	91	18C
0005435006834	5465	92	18D
0005434228985	5465	93	18F
0005432125386	5465	94	19A
0005432125392	5465	95	19B
0005435039208	5465	96	19D
0005434229005	5465	97	19E
0005435006833	5465	98	19F
0005435039244	5465	99	20A
0005435006825	5465	100	20C
0005435039231	5465	101	20B
0005435039222	5465	102	20D
0005435039247	5465	103	20E
0005435006818	5465	104	20F
0005435006840	5465	105	21A
0005435039242	5465	106	21B
0005435039259	5465	107	21D
0005432125390	5465	108	21C
0005435039248	5465	109	21E
0005435039232	5465	110	22A
0005435039224	5465	111	21F
0005435039245	5465	112	22B
0005435039261	5465	113	22D
0005435039217	5465	114	22C
0005434228984	5465	115	22E
0005435006827	5465	116	22F
0005435006835	5465	117	23B
0005435006831	5465	118	23A
0005435006826	5465	119	23C
0005435039233	5465	120	23D
0005435006824	5465	121	23F
0005435039203	5465	122	23E
0005434229176	12980	1	1D
0005434229180	12980	2	1C
0005435038718	12980	3	1A
0005435038659	12980	4	2A
0005434229195	12980	5	1F
0005435038629	12980	6	2F
0005434229183	12980	7	3C
0005435038695	12980	8	3A
0005435038611	12980	9	3F
0005435038763	12980	10	4A
0005435006728	12980	11	4C
0005435006648	12980	12	4B
0005435038628	12980	13	5B
0005435038656	12980	14	5D
0005435006684	12980	15	5C
0005434229185	12980	16	5E
0005435038688	12980	17	5F
0005435006720	12980	18	6A
0005435038839	12980	19	6C
0005435006626	12980	20	6B
0005434229182	12980	21	6D
0005434229194	12980	22	6E
0005435038727	12980	23	7B
0005435038613	12980	24	7D
0005434229177	12980	25	7F
0005435038888	12980	26	8B
0005434229189	12980	27	8E
0005435006679	12980	28	8D
0005435038750	12980	29	9A
0005435038804	12980	30	9C
0005434229192	12980	31	9B
0005434229186	12980	32	9E
0005434229184	12980	33	9F
0005435038719	12980	34	10B
0005435038660	12980	35	10D
0005435006621	12980	36	10E
0005435038704	12980	37	11A
0005435038835	12980	38	11B
0005432304365	12980	39	11D
0005435038764	12980	40	11C
0005435006680	12980	41	11E
0005434229175	12980	42	11F
0005435038798	12980	43	12C
0005435038618	12980	44	12B
0005435038900	12980	45	12E
0005432304366	12980	46	12D
0005434229179	12980	47	12F
0005435038702	12980	48	13A
0005435038712	12980	49	13B
0005435038692	12980	50	13D
0005435038687	12980	51	13E
0005434229193	12980	52	13F
0005434229196	12980	53	14B
0005435038739	12980	54	14A
0005432304364	12980	55	14C
0005435038610	12980	56	14D
0005435006681	12980	57	15A
0005434229178	12980	58	15D
0005435038667	12980	59	15E
0005435038612	12980	60	16A
0005435038794	12980	61	16D
0005435038725	12980	62	16F
0005434229174	12980	63	16E
0005435038681	12980	64	17A
0005435038617	12980	65	17C
0005435038616	12980	66	17D
0005435006638	12980	67	17F
0005435006647	12980	68	17E
0005435038620	12980	69	18C
0005434229181	12980	70	18D
0005435038693	12980	71	18F
0005434229187	12980	72	18E
0005434229190	12980	73	19D
0005434229191	12980	74	19E
0005435038691	12980	75	20D
0005434229188	12980	76	20C
0005435038784	12980	77	20E
0005435038658	12980	78	21A
0005435006721	12980	79	21B
0005435038887	12980	80	21D
0005435006700	12980	81	21F
0005435038668	12980	82	21E
0005432304367	12980	83	22A
0005435006682	12980	84	22B
0005435006627	12980	85	22C
0005435038762	12980	86	22E
0005435038696	12980	87	23A
0005435038754	12980	88	23B
0005435038619	12980	89	23E
0005435038655	12980	90	23D
0005434229197	12980	91	23F
0005435902400	14881	1	1C
0005434426332	14881	2	1D
0005434426342	14881	3	2A
0005434411737	14881	4	2F
0005434426349	14881	5	3F
0005434426348	14881	6	4C
0005434426344	14881	7	4D
0005435554111	14881	8	4F
0005434426328	14881	9	5E
0005435902411	14881	10	6A
0005434426335	14881	11	6C
0005434426343	14881	12	6D
0005434426347	14881	13	6E
0005434426330	14881	14	7D
0005434411739	14881	15	7F
0005434426355	14881	16	8D
0005435902401	14881	17	9C
0005434426350	14881	18	9E
0005432188576	14881	19	9F
0005434426331	14881	20	10C
0005434426340	14881	21	11C
0005434426354	14881	22	11F
0005434426338	14881	23	12D
0005432188579	14881	24	12F
0005434426337	14881	25	13C
0005435902403	14881	26	13E
0005434426329	14881	27	14D
0005434426346	14881	28	14E
0005434426336	14881	29	15A
0005435902463	14881	30	15C
0005434426341	14881	31	15D
0005434426327	14881	32	15E
0005435902402	14881	33	15F
0005434426334	14881	34	16A
0005434426352	14881	35	16D
0005434426345	14881	36	16E
0005434411738	14881	37	16F
0005434426339	14881	38	17A
0005434426353	14881	39	17E
0005432188577	14881	40	18A
0005434426333	14881	41	18D
0005434426326	14881	42	19C
0005432188578	14881	43	19D
0005434411740	14881	44	19E
0005434426351	14881	45	20E
0005434426103	20238	1	1D
0005434426107	20238	2	1F
0005434426170	20238	3	2C
0005435902556	20238	4	2D
0005434426139	20238	5	2F
0005434426099	20238	6	3C
0005435554152	20238	7	3F
0005434426238	20238	8	5A
0005432059488	20238	9	5D
0005434426214	20238	10	5F
0005434426173	20238	11	6A
0005434426141	20238	12	6D
0005435902559	20238	13	6F
0005434426175	20238	14	7C
0005435554151	20238	15	7E
0005435902564	20238	16	7F
0005435902555	20238	17	8D
0005432059487	20238	18	9E
0005434411708	20238	19	10A
0005435902565	20238	20	10C
0005435902553	20238	21	10D
0005435902549	20238	22	11E
0005434426142	20238	23	12A
0005435902551	20238	24	12D
0005434426172	20238	25	13A
0005435902561	20238	26	13C
0005434426118	20238	27	13D
0005434426186	20238	28	13F
0005435902560	20238	29	14A
0005435902558	20238	30	14D
0005435554149	20238	31	15A
0005435902552	20238	32	15D
0005435902554	20238	33	16A
0005434411701	20238	34	16C
0005434426237	20238	35	16D
0005434426156	20238	36	16F
0005435902557	20238	37	17C
0005434426119	20238	38	17E
0005434426171	20238	39	18A
0005435902562	20238	40	18E
0005435554150	20238	41	19D
0005435902550	20238	42	20C
0005435902563	20238	43	20D
0005434426140	20238	44	20E
0005432462492	28019	1	1A
0005432462496	28019	2	6B
0005432462493	28019	3	7B
0005434523737	28019	4	10D
0005432462495	28019	5	11A
0005432462497	28019	6	12A
0005432462494	28019	7	13F
0005432462498	28019	8	19C
0005434523736	28019	9	19F
0005434523733	28019	10	19E
0005432462499	28019	11	21B
0005435981908	26518	1	1A
0005435981918	26518	2	1D
0005435981895	26518	3	2A
0005435981902	26518	4	2D
0005432300208	26518	5	2F
0005433434199	26518	6	3A
0005433434272	26518	7	3C
0005435981923	26518	8	3D
0005433434220	26518	9	3F
0005434270175	26518	10	4C
0005434270174	26518	11	4D
0005435981898	26518	12	4E
0005435981891	26518	13	5A
0005433434205	26518	14	5C
0005433434243	26518	15	5D
0005435981896	26518	16	5E
0005435981921	26518	17	6A
0005435981889	26518	18	6C
0005432300210	26518	19	6D
0005435981893	26518	20	6E
0005435981892	26518	21	6F
0005435981905	26518	22	7A
0005435981920	26518	23	7C
0005435981910	26518	24	7E
0005435981916	26518	25	7F
0005435981899	26518	26	8A
0005433434213	26518	27	8C
0005435981897	26518	28	8F
0005432300213	26518	29	8E
0005433434204	26518	30	9A
0005435981900	26518	31	9C
0005433434237	26518	32	9E
0005434273046	26518	33	9F
0005434270176	26518	34	10A
0005435981914	26518	35	10D
0005432300211	26518	36	10E
0005435981894	26518	37	11D
0005433434232	26518	38	11E
0005433434206	26518	39	11F
0005433434283	26518	40	12F
0005435981913	26518	41	13A
0005435981890	26518	42	13C
0005435981901	26518	43	13E
0005435981917	26518	44	13F
0005434270172	26518	45	14C
0005434270173	26518	46	14D
0005433434238	26518	47	14E
0005435981912	26518	48	14F
0005433434192	26518	49	15A
0005435981907	26518	50	15C
0005435981915	26518	51	15D
0005433434225	26518	52	15F
0005435981903	26518	53	16A
0005432300209	26518	54	16C
0005433434244	26518	55	16D
0005433434224	26518	56	16E
0005435981911	26518	57	16F
0005435981919	26518	58	17A
0005432300212	26518	59	17C
0005435981906	26518	60	18C
0005433434214	26518	61	18F
0005433434207	26518	62	19A
0005435981922	26518	63	19C
0005433434245	26518	64	19D
0005433434282	26518	65	19F
0005435981904	26518	66	20D
0005435981909	26518	67	20F
0005435981648	26694	1	1A
0005433434467	26694	2	1C
0005433434462	26694	3	2D
0005435981585	26694	4	2F
0005434270189	26694	5	4A
0005435981550	26694	6	4C
0005433434445	26694	7	4D
0005433434450	26694	8	4E
0005433434452	26694	9	4F
0005433434444	26694	10	5A
0005433434459	26694	11	5D
0005434269085	26694	12	5E
0005435981554	26694	13	5F
0005433434451	26694	14	6A
0005435981582	26694	15	6D
0005432051103	26694	16	6F
0005433434455	26694	17	7A
0005435981547	26694	18	7D
0005433434456	26694	19	7E
0005433434447	26694	20	7F
0005433434457	26694	21	8A
0005433434443	26694	22	8D
0005435981638	26694	23	8E
0005433434468	26694	24	9A
0005433434449	26694	25	9C
0005433434442	26694	26	9D
0005435981606	26694	27	9E
0005435981627	26694	28	9F
0005433434460	26694	29	10A
0005432051101	26694	30	10C
0005433434454	26694	31	10D
0005434271295	26694	32	10F
0005433434441	26694	33	11C
0005435981553	26694	34	11E
0005435981583	26694	35	11F
0005435981522	26694	36	12D
0005433434458	26694	37	13C
0005432051104	26694	38	13E
0005435981523	26694	39	14A
0005433434446	26694	40	14C
0005433434463	26694	41	14F
0005435981546	26694	42	15A
0005433434466	26694	43	15D
0005433434440	26694	44	16A
0005435981552	26694	45	16C
0005434270190	26694	46	16F
0005434269086	26694	47	17D
0005435981524	26694	48	17E
0005433434453	26694	49	17F
0005435981587	26694	50	18A
0005435981520	26694	51	18C
0005434269087	26694	52	18D
0005435981647	26694	53	18E
0005433434461	26694	54	19A
0005433434448	26694	55	19D
0005433434465	26694	56	20C
0005432051102	26694	57	20D
0005433434439	26694	58	20E
0005433434464	26694	59	20F
0005433689883	29263	1	2C
0005433689874	29263	2	2D
0005433689884	29263	3	3A
0005433689881	29263	4	3C
0005433689882	29263	5	3D
0005433689878	29263	6	7C
0005433689880	29263	7	18A
0005433689879	29263	8	20C
0005433689877	29263	9	21C
0005432857884	3177	1	1A
0005432857894	3177	2	1B
0005432583831	3177	3	1C
0005432583829	3177	4	1D
0005432857895	3177	5	2A
0005432583821	3177	6	2B
0005432583836	3177	7	2C
0005432583815	3177	8	2D
0005432583839	3177	9	3A
0005432583838	3177	10	3B
0005432583837	3177	11	3C
0005432583814	3177	12	3D
0005432857853	3177	13	4A
0005432216251	3177	14	5A
0005432583827	3177	15	5B
0005432583830	3177	16	5C
0005432583819	3177	17	6A
0005432857947	3177	18	6C
0005432857864	3177	19	6B
0005432857865	3177	20	6D
0005432216250	3177	21	7A
0005432583833	3177	22	7C
0005432583818	3177	23	7D
0005432583817	3177	24	18B
0005432583834	3177	25	18C
0005432583828	3177	26	18D
0005432216249	3177	27	19A
0005432857896	3177	28	19B
0005432583826	3177	29	19D
0005432857866	3177	30	20B
0005432583816	3177	31	20C
0005432857886	3177	32	20D
0005432583820	3177	33	21A
0005432583822	3177	34	21B
0005432583825	3177	35	21D
0005432583832	3177	36	22A
0005432857854	3177	37	22B
0005432583835	3177	38	22C
0005432583823	3177	39	23A
0005432583824	3177	40	23B
0005432583664	31500	1	1A
0005432583709	31500	2	1B
0005432583591	31500	3	2A
0005432583643	31500	4	2B
0005432583631	31500	5	2D
0005432583609	31500	6	3C
0005432583630	31500	7	3D
0005432857973	31500	8	4A
0005432583645	31500	9	4B
0005432583668	31500	10	4C
0005432583599	31500	11	4D
0005432857965	31500	12	5A
0005432857967	31500	13	5B
0005432583598	31500	14	5C
0005432583648	31500	15	6B
0005432583597	31500	16	6C
0005432583624	31500	17	6D
0005432857962	31500	18	7A
0005432583708	31500	19	7B
0005432857970	31500	20	7C
0005432583647	31500	21	18A
0005432583610	31500	22	18B
0005432583705	31500	23	18C
0005432583637	31500	24	18D
0005432857971	31500	25	19A
0005432857968	31500	26	19B
0005432583616	31500	27	19C
0005432857966	31500	28	19D
0005432857963	31500	29	20A
0005432857964	31500	30	20B
0005432583636	31500	31	20D
0005432857972	31500	32	21A
0005432583611	31500	33	21B
0005432583644	31500	34	21D
0005432857969	31500	35	22A
0005432583617	31500	36	22C
0005432857961	31500	37	22D
0005432583736	31500	38	23A
0005434943270	903	1	3D
0005433255051	903	2	4D
0005434943276	903	3	6C
0005434943274	903	4	6D
0005434943271	903	5	7B
0005434943273	903	6	20C
0005434943277	903	7	21A
0005434943278	903	8	22C
0005434943272	903	9	22D
0005434943275	903	10	23A
0005433255074	16233	1	2C
0005433255073	16233	2	4C
0005434943238	16233	3	6C
0005434943205	16233	4	7B
0005433255076	16233	5	7C
0005434943235	16233	6	18A
0005433255075	16233	7	18D
0005434943202	16233	8	21A
0005434943231	16233	9	21C
0005434943203	16233	10	21D
0005433255072	16233	11	22D
0005434943196	16233	12	23A
0005435652638	21726	1	1A
0005435652627	21726	2	1C
0005435652645	21726	3	1D
0005433367267	21726	4	1F
0005435652642	21726	5	2A
0005433367272	21726	6	2C
0005435652621	21726	7	2F
0005433367302	21726	8	3A
0005433367331	21726	9	3C
0005435652653	21726	10	3D
0005435652632	21726	11	3F
0005435652650	21726	12	4A
0005435652651	21726	13	4C
0005433367240	21726	14	4D
0005435652663	21726	15	4E
0005435652643	21726	16	4F
0005435652669	21726	17	5C
0005435652628	21726	18	5D
0005435652625	21726	19	5E
0005435652630	21726	20	5F
0005435652631	21726	21	6A
0005435652637	21726	22	6C
0005433367225	21726	23	6D
0005435652646	21726	24	6E
0005435652666	21726	25	6F
0005433367287	21726	26	7A
0005433367274	21726	27	7C
0005435652635	21726	28	7D
0005435652657	21726	29	8A
0005435652667	21726	30	8C
0005435652640	21726	31	8D
0005433367301	21726	32	8E
0005433367273	21726	33	8F
0005435652623	21726	34	9A
0005435652658	21726	35	9C
0005435652659	21726	36	9D
0005433367362	21726	37	9E
0005433367253	21726	38	10A
0005435652662	21726	39	10E
0005435652661	21726	40	10F
0005433367300	21726	41	11C
0005435652649	21726	42	11D
0005435652660	21726	43	11E
0005433367245	21726	44	11F
0005435652624	21726	45	12A
0005433367288	21726	46	12C
0005433367226	21726	47	12E
0005433367330	21726	48	12F
0005433367393	21726	49	13D
0005435652648	21726	50	13E
0005433367231	21726	51	13F
0005435652626	21726	52	14D
0005433367392	21726	53	14E
0005435652654	21726	54	14F
0005435652636	21726	55	15C
0005433367316	21726	56	15D
0005435652629	21726	57	15E
0005433367230	21726	58	15F
0005433367281	21726	59	16A
0005435652655	21726	60	16C
0005435652668	21726	61	16E
0005435652644	21726	62	16F
0005435652664	21726	63	17C
0005435652665	21726	64	17D
0005435652634	21726	65	18A
0005433367262	21726	66	18C
0005435652622	21726	67	18D
0005435652639	21726	68	18E
0005435652641	21726	69	19A
0005435652656	21726	70	19D
0005435652652	21726	71	19E
0005435652633	21726	72	20A
0005433367391	21726	73	20D
0005433367361	21726	74	20E
0005435652647	21726	75	20F
0005433805081	9378	1	1A
0005433763090	9378	2	1G
0005433784661	9378	3	2A
0005433805106	9378	4	1H
0005433805091	9378	5	2C
0005433784651	9378	6	2F
0005433805094	9378	7	3A
0005433763082	9378	8	3F
0005433805095	9378	9	4A
0005433805113	9378	10	3H
0005433784658	9378	11	4B
0005432657425	9378	12	4C
0005433805105	9378	13	4F
0005433784625	9378	14	5A
0005432657423	9378	15	4H
0005433805117	9378	16	5B
0005433784653	9378	17	5G
0005433784635	9378	18	5H
0005433763083	9378	19	9A
0005433784652	9378	20	9G
0005432667438	9378	21	11B
0005433763084	9378	22	11E
0005434170878	9378	23	11D
0005433784645	9378	24	11G
0005434170816	9378	25	12A
0005433784648	9378	26	12B
0005433805080	9378	27	12G
0005433784631	9378	28	12F
0005433784644	9378	29	13A
0005433805099	9378	30	13E
0005433784649	9378	31	13F
0005433784636	9378	32	14A
0005433805089	9378	33	13H
0005433784662	9378	34	14B
0005433805079	9378	35	14D
0005433805109	9378	36	14F
0005433784626	9378	37	14E
0005432657424	9378	38	14G
0005433763086	9378	39	14H
0005434170801	9378	40	16B
0005433784642	9378	41	16G
0005434170820	9378	42	16F
0005433784641	9378	43	16H
0005434170853	9378	44	17A
0005435269643	9378	45	17B
0005433784643	9378	46	17G
0005433805111	9378	47	18A
0005433805103	9378	48	18B
0005433805118	9378	49	18F
0005433805101	9378	50	18H
0005433784633	9378	51	19B
0005433784650	9378	52	19A
0005432666370	9378	53	19F
0005433805082	9378	54	19H
0005433784639	9378	55	20D
0005433784656	9378	56	20E
0005433805085	9378	57	20G
0005432666372	9378	58	20F
0005434170811	9378	59	20H
0005433784624	9378	60	21A
0005433784632	9378	61	21B
0005433805086	9378	62	21E
0005434170846	9378	63	21G
0005433805084	9378	64	21F
0005433805096	9378	65	21H
0005433805087	9378	66	22A
0005432657421	9378	67	22E
0005434151656	9378	68	22H
0005433805115	9378	69	23D
0005433784659	9378	70	23G
0005432666371	9378	71	23H
0005433763087	9378	72	24A
0005433805100	9378	73	24E
0005433784654	9378	74	24F
0005433784640	9378	75	24G
0005433805097	9378	76	25D
0005433784629	9378	77	24H
0005433784637	9378	78	25E
0005433805110	9378	79	27D
0005435269622	9378	80	27E
0005433784646	9378	81	28B
0005433805112	9378	82	28E
0005433805107	9378	83	28D
0005433805093	9378	84	28F
0005435269640	9378	85	28H
0005433763077	9378	86	29A
0005433763089	9378	87	29B
0005433805102	9378	88	29D
0005433763081	9378	89	29G
0005432667437	9378	90	30B
0005433805116	9378	91	30A
0005433763078	9378	92	30D
0005435269633	9378	93	30F
0005433805078	9378	94	30G
0005433784655	9378	95	30H
0005433805092	9378	96	31G
0005433805077	9378	97	32B
0005434170819	9378	98	32E
0005435269637	9378	99	32D
0005433763088	9378	100	32F
0005435269638	9378	101	33D
0005433805088	9378	102	33B
0005433805090	9378	103	33F
0005434170827	9378	104	33H
0005433805114	9378	105	33G
0005433805083	9378	106	34A
0005433784630	9378	107	34D
0005433784628	9378	108	34B
0005432657422	9378	109	34F
0005433784647	9378	110	35A
0005433763091	9378	111	35B
0005434170821	9378	112	35D
0005433805098	9378	113	35E
0005433784657	9378	114	36E
0005433763080	9378	115	36D
0005434170815	9378	116	36H
0005433784634	9378	117	37B
0005433784660	9378	118	37F
0005433763085	9378	119	37G
0005433805104	9378	120	38B
0005433763079	9378	121	38G
0005433784638	9378	122	38H
0005433805108	9378	123	39E
0005433784627	9378	124	39D
0005434170938	26258	1	1H
0005433762948	26258	2	3A
0005433804828	26258	3	3F
0005435269689	26258	4	3H
0005435269686	26258	5	4C
0005433804793	26258	6	4F
0005433784437	26258	7	5A
0005432666358	26258	8	5G
0005433784302	26258	9	5H
0005434269083	26258	10	9G
0005433784409	26258	11	11F
0005433804891	26258	12	12F
0005433784440	26258	13	14B
0005433762978	26258	14	14A
0005433784320	26258	15	14F
0005434151678	26258	16	15A
0005433804783	26258	17	14H
0005434271294	26258	18	15E
0005433784387	26258	19	15D
0005433784321	26258	20	15H
0005433804801	26258	21	16A
0005433784319	26258	22	16D
0005433784483	26258	23	16G
0005434170935	26258	24	17B
0005433804892	26258	25	17D
0005433784351	26258	26	18A
0005434170932	26258	27	18B
0005434170934	26258	28	18D
0005434170942	26258	29	18H
0005433804857	26258	30	19D
0005435269685	26258	31	20D
0005434170937	26258	32	20B
0005433784368	26258	33	20F
0005433804818	26258	34	20G
0005434270186	26258	35	21E
0005435269690	26258	36	21D
0005433804782	26258	37	21F
0005433804849	26258	38	22B
0005433784401	26258	39	22F
0005433804837	26258	40	22G
0005433804979	26258	41	23D
0005433784405	26258	42	23F
0005434271293	26258	43	23E
0005434170931	26258	44	24A
0005435269687	26258	45	25D
0005433784374	26258	46	24H
0005434269084	26258	47	25E
0005433784334	26258	48	27A
0005434170936	26258	49	27H
0005434271292	26258	50	28E
0005434151679	26258	51	28G
0005433784316	26258	52	29A
0005435269688	26258	53	28H
0005433784419	26258	54	29G
0005434170933	26258	55	29H
0005433784435	26258	56	30B
0005432657398	26258	57	30E
0005433784367	26258	58	30H
0005434170929	26258	59	31A
0005434170941	26258	60	31G
0005433784322	26258	61	32H
0005434270187	26258	62	33E
0005432659674	26258	63	33G
0005433804827	26258	64	33F
0005433804803	26258	65	33H
0005433784482	26258	66	34A
0005435269692	26258	67	34D
0005434170939	26258	68	35D
0005434151680	26258	69	35F
0005433784436	26258	70	35E
0005433762953	26258	71	36D
0005435269691	26258	72	36F
0005433804798	26258	73	36G
0005433762967	26258	74	37A
0005432666354	26258	75	37B
0005433804840	26258	76	37F
0005433804932	26258	77	37G
0005434170940	26258	78	38B
0005434170930	26258	79	38A
0005433762951	26258	80	38E
0005432657399	26258	81	38G
0005434270188	26258	82	39E
0005435135629	4891	1	1C
0005435135630	4891	2	2B
0005435929604	4891	3	6B
0005435929597	4891	4	7C
0005435135628	4891	5	20A
0005435135626	4891	6	22B
0005435135627	4891	7	22D
0005435929620	33038	1	3C
0005435135584	33038	2	18A
0005435929621	33038	3	18C
0005435929622	33038	4	20D
0005435135585	33038	5	22C
0005434983245	9496	1	1A
0005434983246	9496	2	1C
0005434217900	9496	3	18C
0005434217923	9496	4	19B
0005434983242	9496	5	19C
0005434983244	9496	6	21A
0005434983243	9496	7	21D
0005434217899	9496	8	22D
0005434217924	9496	9	23A
0005434983198	27383	1	1B
0005434217932	27383	2	5A
0005434983197	27383	3	5B
0005434217934	27383	4	6C
0005434983214	27383	5	7D
0005434217933	27383	6	19A
0005434983213	27383	7	19B
0005434983224	27383	8	21D
0005434217935	27383	9	23B
0005433985554	25956	1	1F
0005433960352	25956	2	1C
0005433985545	25956	3	1G
0005433960361	25956	4	2C
0005433960359	25956	5	2G
0005433985541	25956	6	3A
0005433985523	25956	7	3F
0005433985543	25956	8	3C
0005433960384	25956	9	4A
0005433985551	25956	10	3H
0005433985520	25956	11	4B
0005433985556	25956	12	5A
0005433960358	25956	13	4H
0005433960348	25956	14	5C
0005433960351	25956	15	5F
0005433985552	25956	16	9G
0005433985548	25956	17	11B
0005433985553	25956	18	11F
0005433960337	25956	19	11E
0005433985555	25956	20	11H
0005433985530	25956	21	12A
0005433985542	25956	22	12D
0005433960371	25956	23	12E
0005433960377	25956	24	12G
0005433960374	25956	25	13A
0005433960354	25956	26	12H
0005433985546	25956	27	13D
0005433960376	25956	28	13E
0005433960382	25956	29	13H
0005433985526	25956	30	14A
0005433985558	25956	31	14E
0005433985525	25956	32	15B
0005433960360	25956	33	15D
0005433985518	25956	34	15F
0005433960350	25956	35	15G
0005433960356	25956	36	16B
0005433960345	25956	37	16A
0005433960385	25956	38	16F
0005433960338	25956	39	16H
0005433960387	25956	40	17E
0005433985532	25956	41	17F
0005433985557	25956	42	18B
0005433960381	25956	43	18A
0005433985528	25956	44	18D
0005433960355	25956	45	18F
0005433985547	25956	46	18E
0005433960388	25956	47	18G
0005433960372	25956	48	19E
0005433960357	25956	49	19D
0005433960339	25956	50	20A
0005433960346	25956	51	20B
0005433985549	25956	52	20F
0005433960386	25956	53	20G
0005433960379	25956	54	21A
0005433985524	25956	55	21B
0005433960365	25956	56	22D
0005433985517	25956	57	23A
0005433985537	25956	58	23E
0005433985539	25956	59	23H
0005433960373	25956	60	24D
0005433960383	25956	61	24G
0005433960340	25956	62	24H
0005433985527	25956	63	25E
0005433960342	25956	64	27B
0005433985535	25956	65	27F
0005433960366	25956	66	28B
0005433960341	25956	67	28D
0005433985531	25956	68	29G
0005433960368	25956	69	30A
0005433960370	25956	70	30D
0005433985522	25956	71	30E
0005433985529	25956	72	30G
0005433985550	25956	73	31G
0005433960362	25956	74	31H
0005433985544	25956	75	32B
0005433960375	25956	76	32D
0005433960369	25956	77	33A
0005433960353	25956	78	33D
0005433960380	25956	79	33B
0005433960343	25956	80	33E
0005433960367	25956	81	34D
0005433985533	25956	82	34B
0005433985536	25956	83	34G
0005433985534	25956	84	35B
0005433960347	25956	85	35F
0005433960349	25956	86	35E
0005433960389	25956	87	35G
0005433985538	25956	88	36B
0005433985540	25956	89	36A
0005433960344	25956	90	36E
0005433985521	25956	91	36G
0005433960364	25956	92	37A
0005433960378	25956	93	37B
0005433985519	25956	94	37E
0005433960363	25956	95	37F
0005434480108	950	1	1B
0005433165710	950	2	1C
0005434480122	950	3	2A
0005434480129	950	4	2B
0005434480126	950	5	2D
0005434480125	950	6	3A
0005434480124	950	7	3B
0005434480110	950	8	3D
0005434480111	950	9	4B
0005434480131	950	10	4C
0005433165688	950	11	4D
0005434480119	950	12	5B
0005434480117	950	13	5C
0005432269472	950	14	5D
0005434480112	950	15	6C
0005434480130	950	16	7B
0005434480109	950	17	7C
0005434480113	950	18	18B
0005434480128	950	19	18C
0005434480118	950	20	19A
0005434480116	950	21	19C
0005434480133	950	22	19D
0005432269473	950	23	20A
0005434480132	950	24	20B
0005434480127	950	25	20C
0005434480115	950	26	21A
0005434480121	950	27	21B
0005434480120	950	28	21D
0005434480114	950	29	22B
0005432269471	950	30	22D
0005434480123	950	31	23A
0005434479912	16595	1	1A
0005433165802	16595	2	1D
0005433165796	16595	3	2A
0005433165801	16595	4	2C
0005434480011	16595	5	3C
0005434479930	16595	6	4A
0005434479953	16595	7	4B
0005433165794	16595	8	4C
0005434479937	16595	9	4D
0005434479970	16595	10	5A
0005434479933	16595	11	6A
0005434480012	16595	12	6D
0005433165798	16595	13	7A
0005433165792	16595	14	7B
0005433165797	16595	15	7C
0005434479931	16595	16	18A
0005433165795	16595	17	18B
0005434479887	16595	18	18D
0005434479932	16595	19	19B
0005433165799	16595	20	20A
0005434479881	16595	21	20C
0005433165791	16595	22	21C
0005433165793	16595	23	21D
0005433165800	16595	24	22C
0005434479984	16595	25	23A
0005434479952	16595	26	23B
0005433872454	3195	1	3B
0005433872459	3195	2	3D
0005433872458	3195	3	5B
0005433872455	3195	4	7B
0005433872457	3195	5	20D
0005433872456	3195	6	23B
0005433872431	32555	1	20A
0005433872430	32555	2	20B
0005433872435	32555	3	22C
0005435386487	10373	1	1A
0005435149910	10373	2	1B
0005435142457	10373	3	1C
0005435142455	10373	4	1D
0005435149909	10373	5	2A
0005435142447	10373	6	2B
0005435142456	10373	7	2C
0005435149908	10373	8	3C
0005435142452	10373	9	4A
0005435142454	10373	10	4B
0005435142458	10373	11	4D
0005435149913	10373	12	5A
0005433289730	10373	13	5B
0005433289729	10373	14	5C
0005435149904	10373	15	5D
0005435149903	10373	16	6A
0005435149907	10373	17	6B
0005435149901	10373	18	6D
0005435149899	10373	19	7C
0005435149911	10373	20	7D
0005435149912	10373	21	18C
0005435142448	10373	22	19C
0005435142459	10373	23	19D
0005435149905	10373	24	20A
0005435149906	10373	25	20B
0005435142450	10373	26	20D
0005433289728	10373	27	21D
0005435386464	10373	28	22A
0005435149902	10373	29	22B
0005435142453	10373	30	22C
0005435142451	10373	31	22D
0005435149900	10373	32	23A
0005435142449	10373	33	23B
0005435149840	21963	1	1A
0005433289796	21963	2	1B
0005435386522	21963	3	1C
0005435142336	21963	4	3A
0005435149852	21963	5	3C
0005435386521	21963	6	3D
0005435149809	21963	7	4A
0005435386518	21963	8	4B
0005435386519	21963	9	4C
0005433289791	21963	10	5A
0005433289795	21963	11	5B
0005435386520	21963	12	5C
0005433289797	21963	13	6B
0005435142416	21963	14	6C
0005435149801	21963	15	6D
0005435149824	21963	16	7A
0005433289792	21963	17	7C
0005435149810	21963	18	18B
0005435142366	21963	19	19B
0005435142354	21963	20	19D
0005435142343	21963	21	20A
0005435386524	21963	22	20D
0005435386523	21963	23	21A
0005435149839	21963	24	21B
0005433289793	21963	25	21D
0005435142365	21963	26	22A
0005433289794	21963	27	22B
0005435149802	21963	28	22C
0005435149851	21963	29	23A
0005435149823	21963	30	23B
0005434573218	11212	1	1C
0005435502003	11212	2	1F
0005435528929	11212	3	2D
0005435528918	11212	4	2F
0005435501997	11212	5	3A
0005435528954	11212	6	3F
0005435319432	11212	7	4A
0005435501969	11212	8	4D
0005434573231	11212	9	4F
0005435501963	11212	10	5C
0005435502035	11212	11	5D
0005435501946	11212	12	5E
0005434573222	11212	13	5F
0005435528930	11212	14	6D
0005434573228	11212	15	7A
0005434573224	11212	16	7C
0005434573223	11212	17	7D
0005435528928	11212	18	8A
0005435528931	11212	19	8C
0005435319445	11212	20	8E
0005435545618	11212	21	9C
0005435501995	11212	22	9E
0005435319446	11212	23	9F
0005434573227	11212	24	10A
0005435545619	11212	25	10C
0005435502012	11212	26	10D
0005435528919	11212	27	10F
0005435501968	11212	28	11D
0005434573226	11212	29	11F
0005435528913	11212	30	12C
0005435528909	11212	31	13A
0005435528894	11212	32	13E
0005434573230	11212	33	13F
0005435501989	11212	34	14A
0005434573219	11212	35	14C
0005435502002	11212	36	14E
0005434573221	11212	37	15C
0005435528898	11212	38	15F
0005435501939	11212	39	16C
0005435501934	11212	40	16E
0005435501977	11212	41	17E
0005434573225	11212	42	17F
0005434573217	11212	43	18A
0005435319427	11212	44	18C
0005435501978	11212	45	18D
0005434573220	11212	46	18E
0005435501940	11212	47	18F
0005435319453	11212	48	19C
0005435501996	11212	49	19E
0005435502001	11212	50	20C
0005435502009	11212	51	20D
0005434573229	11212	52	20E
0005435502117	20951	1	1C
0005435502115	20951	2	1D
0005435502124	20951	3	1F
0005435502120	20951	4	2A
0005435517759	20951	5	2C
0005435502126	20951	6	2D
0005435502127	20951	7	3A
0005435319510	20951	8	3C
0005435508254	20951	9	3D
0005435319511	20951	10	3F
0005435517763	20951	11	4A
0005435319512	20951	12	4C
0005435319513	20951	13	4D
0005435502121	20951	14	4E
0005435502119	20951	15	4F
0005435517752	20951	16	5A
0005435502122	20951	17	5C
0005435508263	20951	18	5D
0005435508258	20951	19	5F
0005434573141	20951	20	6C
0005435517751	20951	21	6D
0005435517756	20951	22	6E
0005435502112	20951	23	6F
0005435502113	20951	24	7A
0005435502116	20951	25	7E
0005435508251	20951	26	7F
0005435502130	20951	27	8E
0005435508264	20951	28	9C
0005435508250	20951	29	9D
0005435517762	20951	30	9E
0005432291908	20951	31	9F
0005435517764	20951	32	10C
0005435517758	20951	33	10D
0005435508252	20951	34	10E
0005432291909	20951	35	11A
0005435319507	20951	36	11D
0005435502125	20951	37	11E
0005434573168	20951	38	11F
0005435508253	20951	39	12A
0005435517754	20951	40	12C
0005435502118	20951	41	12D
0005435502129	20951	42	12E
0005435508265	20951	43	13A
0005434573164	20951	44	13D
0005435502123	20951	45	13F
0005434573130	20951	46	14A
0005435517760	20951	47	14C
0005435502108	20951	48	14E
0005435502111	20951	49	14F
0005435517757	20951	50	15A
0005435319509	20951	51	15C
0005435319506	20951	52	15E
0005434573183	20951	53	15F
0005435508261	20951	54	16A
0005435517753	20951	55	16C
0005435508260	20951	56	16D
0005435517749	20951	57	17A
0005435517755	20951	58	17C
0005435502109	20951	59	17D
0005435502110	20951	60	17E
0005434573175	20951	61	17F
0005435517765	20951	62	18A
0005435319508	20951	63	18C
0005435502131	20951	64	18D
0005435517750	20951	65	18E
0005435508262	20951	66	18F
0005434573116	20951	67	19A
0005435508257	20951	68	19C
0005435502128	20951	69	19D
0005435502114	20951	70	19E
0005435517761	20951	71	19F
0005435508255	20951	72	20A
0005435508259	20951	73	20C
0005434573163	20951	74	20E
0005435508256	20951	75	20F
0005432692562	2962	1	1D
0005432692547	2962	2	2C
0005432692553	2962	3	3C
0005432692579	2962	4	6E
0005432692528	2962	5	7C
0005432692561	2962	6	9C
0005432692572	2962	7	11D
0005432692566	2962	8	12D
0005432692555	2962	9	14D
0005432692567	2962	10	16D
0005432692554	2962	11	17E
0005432692535	2962	12	18E
0005432692580	2962	13	19A
0005432692644	2962	14	20F
0005432706552	2961	1	1A
0005433194820	2961	2	1C
0005432880566	2961	3	2A
0005432880595	2961	4	2C
0005432706555	2961	5	2D
0005432706548	2961	6	2F
0005432706544	2961	7	3A
0005432880588	2961	8	3C
0005432880567	2961	9	3F
0005432706561	2961	10	4C
0005432706566	2961	11	4E
0005432706545	2961	12	4F
0005432880590	2961	13	5A
0005432880599	2961	14	5C
0005432706567	2961	15	5F
0005432706558	2961	16	6A
0005433123589	2961	17	6C
0005432880587	2961	18	8A
0005432706568	2961	19	8D
0005432706553	2961	20	8F
0005433123651	2961	21	9C
0005433123613	2961	22	9D
0005432880576	2961	23	10A
0005433123612	2961	24	10D
0005432217752	2961	25	11C
0005433123642	2961	26	11E
0005432706549	2961	27	12C
0005432880563	2961	28	12D
0005432706562	2961	29	12E
0005432706564	2961	30	12F
0005432880560	2961	31	13C
0005432880561	2961	32	13D
0005433194819	2961	33	13E
0005432706546	2961	34	13F
0005432706551	2961	35	14C
0005432706560	2961	36	15A
0005432706554	2961	37	15D
0005432880562	2961	38	15E
0005432706559	2961	39	16A
0005432706547	2961	40	16E
0005432217751	2961	41	16F
0005432706556	2961	42	17A
0005432706563	2961	43	17C
0005432706543	2961	44	17D
0005432706550	2961	45	17E
0005432880589	2961	46	17F
0005433194818	2961	47	18A
0005433194825	2961	48	18D
0005432217753	2961	49	19A
0005432880598	2961	50	19C
0005432706565	2961	51	19D
0005432706557	2961	52	20F
0005432880692	29950	1	1A
0005432692825	29950	2	1C
0005433123748	29950	3	1D
0005432692835	29950	4	1F
0005433123753	29950	5	2A
0005432880688	29950	6	2C
0005432706432	29950	7	2D
0005433123752	29950	8	2F
0005432706367	29950	9	3A
0005433123750	29950	10	3C
0005433123742	29950	11	3D
0005432706413	29950	12	3F
0005432692837	29950	13	4A
0005433123739	29950	14	4C
0005432706388	29950	15	4D
0005432706368	29950	16	4E
0005432706393	29950	17	5A
0005432706351	29950	18	5C
0005432706308	29950	19	5D
0005432706324	29950	20	5E
0005432692823	29950	21	5F
0005432706365	29950	22	6A
0005432706357	29950	23	6C
0005433123743	29950	24	6D
0005433123759	29950	25	6E
0005432880687	29950	26	6F
0005432692842	29950	27	7A
0005433123757	29950	28	7C
0005433123747	29950	29	7D
0005432880698	29950	30	7E
0005432692812	29950	31	7F
0005432706447	29950	32	8A
0005432692836	29950	33	8C
0005432692838	29950	34	8D
0005433123744	29950	35	8E
0005433123755	29950	36	8F
0005432880689	29950	37	9A
0005433123751	29950	38	9C
0005432692822	29950	39	9D
0005432880690	29950	40	9E
0005433123758	29950	41	9F
0005433123738	29950	42	10A
0005432692831	29950	43	10C
0005432880700	29950	44	10D
0005433123741	29950	45	10E
0005432692816	29950	46	10F
0005432706430	29950	47	11A
0005433123746	29950	48	11C
0005432880699	29950	49	11D
0005432692820	29950	50	11E
0005432706342	29950	51	11F
0005433123740	29950	52	12A
0005432880696	29950	53	12C
0005432692815	29950	54	12D
0005432706386	29950	55	12E
0005432692827	29950	56	13A
0005432692818	29950	57	13C
0005432880695	29950	58	13D
0005432706437	29950	59	13E
0005432706353	29950	60	13F
0005432692828	29950	61	14C
0005432692826	29950	62	14D
0005432692833	29950	63	14E
0005432706448	29950	64	14F
0005432692841	29950	65	15A
0005433123749	29950	66	15C
0005432692819	29950	67	15D
0005432692821	29950	68	15E
0005432706325	29950	69	15F
0005432692824	29950	70	16A
0005433123754	29950	71	16C
0005433123737	29950	72	16D
0005432692839	29950	73	16E
0005433123756	29950	74	16F
0005432880693	29950	75	17A
0005432880697	29950	76	17C
0005432706345	29950	77	17D
0005432692840	29950	78	17E
0005432706431	29950	79	17F
0005432880691	29950	80	18A
0005432692811	29950	81	18C
0005432706343	29950	82	18D
0005432692830	29950	83	18E
0005432692829	29950	84	18F
0005432692832	29950	85	19A
0005432692814	29950	86	19C
0005432692813	29950	87	19D
0005432880686	29950	88	19E
0005433123745	29950	89	19F
0005432692834	29950	90	20A
0005432706372	29950	91	20C
0005432692817	29950	92	20D
0005432880694	29950	93	20E
0005432706310	29950	94	20F
0005434979516	23699	1	1B
0005434979514	23699	2	1D
0005434988633	23699	3	2A
0005434979520	23699	4	2B
0005434979500	23699	5	2C
0005434979517	23699	6	2D
0005434979525	23699	7	3C
0005434979510	23699	8	3D
0005434979519	23699	9	4B
0005434979501	23699	10	4C
0005434979526	23699	11	4D
0005434979506	23699	12	5B
0005434979511	23699	13	5D
0005434979522	23699	14	6A
0005434979513	23699	15	6B
0005434988637	23699	16	6C
0005434979503	23699	17	6D
0005434979528	23699	18	7A
0005434979524	23699	19	7C
0005434979515	23699	20	7D
0005434979521	23699	21	18A
0005434979499	23699	22	18B
0005434979505	23699	23	18C
0005434979502	23699	24	18D
0005434979504	23699	25	19A
0005434988634	23699	26	19B
0005434988636	23699	27	20B
0005434979498	23699	28	20C
0005434979509	23699	29	20D
0005434979512	23699	30	21A
0005434988635	23699	31	21B
0005434979523	23699	32	21C
0005434979518	23699	33	21D
0005434979527	23699	34	22A
0005434979508	23699	35	22B
0005434979507	23699	36	23A
0005434979320	27562	1	1A
0005434988564	27562	2	3A
0005434979322	27562	3	3D
0005434979280	27562	4	4A
0005434988560	27562	5	4B
0005434979302	27562	6	4D
0005434979338	27562	7	5A
0005434979265	27562	8	5D
0005434979341	27562	9	6D
0005434988561	27562	10	7C
0005434979367	27562	11	18C
0005434979282	27562	12	19A
0005434979278	27562	13	20B
0005434979252	27562	14	21A
0005434979295	27562	15	22D
0005434979321	27562	16	23A
0005433111467	10265	1	2B
0005434302419	10265	2	4A
0005434302418	10265	3	18D
0005433113495	10265	4	21D
0005434302420	10265	5	22B
0005434302393	19641	1	2C
0005433113517	19641	2	2D
0005434302391	19641	3	6D
0005434302392	19641	4	18C
0005434302388	19641	5	19B
0005433113518	19641	6	23B
0005435068679	3557	1	1A
0005435068663	3557	2	1C
0005435068645	3557	3	1D
0005435718895	3557	4	1F
0005435068654	3557	5	2A
0005435068681	3557	6	2C
0005435068666	3557	7	2F
0005435925053	3557	8	3A
0005435068685	3557	9	3C
0005435925047	3557	10	3D
0005435068659	3557	11	4A
0005435068642	3557	12	4C
0005435925050	3557	13	4E
0005435718897	3557	14	5A
0005435068656	3557	15	5C
0005435068670	3557	16	5D
0005435068661	3557	17	5E
0005435925054	3557	18	6D
0005435068652	3557	19	6E
0005435718898	3557	20	7C
0005435068651	3557	21	7E
0005435068639	3557	22	7F
0005435068683	3557	23	8A
0005435068653	3557	24	8C
0005435068680	3557	25	8D
0005435718901	3557	26	8E
0005435718900	3557	27	9A
0005435068668	3557	28	9C
0005435068658	3557	29	9D
0005435068637	3557	30	9E
0005435068667	3557	31	9F
0005435718896	3557	32	10A
0005435068669	3557	33	10C
0005435068675	3557	34	10E
0005435068647	3557	35	10F
0005435068657	3557	36	11D
0005435925071	3557	37	11F
0005435068664	3557	38	12A
0005435068660	3557	39	12C
0005435068650	3557	40	12D
0005435068638	3557	41	12E
0005435068686	3557	42	12F
0005435068649	3557	43	13C
0005435068674	3557	44	13D
0005435068662	3557	45	13E
0005435068684	3557	46	13F
0005435068640	3557	47	14C
0005435925049	3557	48	14D
0005435068635	3557	49	14E
0005435068673	3557	50	14F
0005435068678	3557	51	15A
0005435068641	3557	52	15D
0005435068676	3557	53	15E
0005435068687	3557	54	16A
0005435068644	3557	55	16D
0005435068671	3557	56	16C
0005435068655	3557	57	16E
0005435068636	3557	58	16F
0005435068643	3557	59	17A
0005435718893	3557	60	17D
0005435939856	3557	61	18A
0005435068648	3557	62	18C
0005435068672	3557	63	18D
0005435068682	3557	64	18E
0005435925048	3557	65	18F
0005435925068	3557	66	19A
0005435068677	3557	67	19E
0005435718894	3557	68	19F
0005435068646	3557	69	20A
0005435925067	3557	70	20C
0005435718899	3557	71	20D
0005435068665	3557	72	20E
0005435068367	15280	1	2A
0005435925180	15280	2	2D
0005435068188	15280	3	2F
0005435925183	15280	4	3C
0005435068209	15280	5	3D
0005435925182	15280	6	3F
0005435068179	15280	7	4C
0005435068202	15280	8	4E
0005435925181	15280	9	4F
0005435068180	15280	10	5A
0005435068306	15280	11	5C
0005435068349	15280	12	5D
0005435925190	15280	13	5E
0005435068189	15280	14	5F
0005435068338	15280	15	6C
0005435925185	15280	16	6F
0005435068241	15280	17	7A
0005435068234	15280	18	7F
0005435925184	15280	19	8A
0005435068219	15280	20	8D
0005435925178	15280	21	9A
0005435068225	15280	22	9C
0005435925191	15280	23	9D
0005435068366	15280	24	9E
0005435925189	15280	25	10C
0005435068220	15280	26	10D
0005435925188	15280	27	10E
0005435068240	15280	28	10F
0005435068307	15280	29	11C
0005435939865	15280	30	12A
0005435068348	15280	31	13C
0005435068235	15280	32	13E
0005435068210	15280	33	14C
0005435068226	15280	34	14D
0005435068407	15280	35	14F
0005435068285	15280	36	15C
0005435925177	15280	37	15D
0005435925186	15280	38	15E
0005435925179	15280	39	15F
0005435068339	15280	40	16F
0005435925187	15280	41	17D
0005435068312	15280	42	18E
0005435068213	15280	43	19A
0005435068258	15280	44	19D
0005435068257	15280	45	20D
0005435068259	15280	46	20E
0005432659689	18112	1	1A
0005432660799	18112	2	2A
0005432658573	18112	3	2B
0005432658575	18112	4	3A
0005432660800	18112	5	3B
0005432658574	18112	6	4B
0005432660801	18112	7	6A
0005432658572	18112	8	6B
0005433101269	214	1	1A
0005433101251	214	2	1C
0005432901344	214	3	1D
0005433101187	214	4	2A
0005432919547	214	5	4C
0005433101287	214	6	4D
0005432901388	214	7	5C
0005433101182	214	8	6A
0005433101154	214	9	6D
0005433101180	214	10	7A
0005433101274	214	11	7F
0005433101282	214	12	8D
0005432157476	214	13	8E
0005432919503	214	14	8F
0005433101233	214	15	9C
0005433101217	214	16	9F
0005433101219	214	17	10E
0005433101224	214	18	10F
0005432157477	214	19	11D
0005433101179	214	20	11E
0005433101225	214	21	12A
0005433101261	214	22	12B
0005432157475	214	23	12C
0005433101275	214	24	13B
0005433101247	214	25	14F
0005433101248	214	26	15A
0005433101239	214	27	15E
0005433101183	214	28	15F
0005433101151	214	29	16B
0005432901296	214	30	16E
0005432901362	214	31	17B
0005432919551	214	32	17E
0005433101277	214	33	18B
0005433101178	214	34	18D
0005432901337	214	35	18F
0005433101232	214	36	19C
0005433101263	214	37	20B
0005432901360	214	38	20C
0005433101208	214	39	20E
0005433101176	214	40	20F
0005432901343	214	41	21A
0005433101240	214	42	21C
0005433101175	214	43	21F
0005433101259	214	44	22C
0005433101148	214	45	23A
0005433101215	214	46	23C
0005432919543	214	47	23F
0005433101278	214	48	23E
0005432901359	214	49	24A
0005433101252	214	50	24C
0005433101258	214	51	24E
0005432919522	214	52	24D
0005433101181	214	53	25E
0005433101262	214	54	26D
0005432901328	214	55	26F
0005433101214	214	56	27C
0005433101241	214	57	27B
0005433101190	214	58	27E
0005432901322	214	59	29A
0005432901355	214	60	29B
0005433101165	214	61	29D
0005432901323	214	62	30B
0005432919521	214	63	31C
0005432817212	209	1	1A
0005432207638	209	2	3A
0005432261550	209	3	4D
0005432261521	209	4	4C
0005432261532	209	5	5A
0005432261540	209	6	4F
0005432817240	209	7	5C
0005432261525	209	8	5F
0005432817236	209	9	7F
0005432817238	209	10	7D
0005432261549	209	11	8A
0005432817230	209	12	8B
0005432817226	209	13	8D
0005432261524	209	14	8C
0005432817219	209	15	8E
0005432817225	209	16	9B
0005432261511	209	17	9A
0005432261513	209	18	9C
0005432261543	209	19	9D
0005432261539	209	20	9E
0005432817223	209	21	9F
0005432817228	209	22	10E
0005432817216	209	23	11C
0005432817222	209	24	12A
0005434153524	209	25	12B
0005432261544	209	26	12C
0005432261554	209	27	12E
0005432261527	209	28	12D
0005432817218	209	29	13B
0005432817220	209	30	13A
0005432817213	209	31	13D
0005432261541	209	32	14D
0005432288959	209	33	14C
0005432261526	209	34	14E
0005432817235	209	35	15B
0005433690892	209	36	15D
0005433690895	209	37	16B
0005432261520	209	38	16D
0005432261516	209	39	17A
0005432261508	209	40	16F
0005432261509	209	41	17B
0005432261545	209	42	17C
0005432261538	209	43	17F
0005432817214	209	44	17E
0005432261514	209	45	18A
0005432261530	209	46	18B
0005432261518	209	47	18C
0005432817224	209	48	18E
0005432261536	209	49	19B
0005432817233	209	50	18F
0005432261533	209	51	19D
0005432261522	209	52	20A
0005432207639	209	53	20B
0005432817215	209	54	20D
0005432261537	209	55	20E
0005432261534	209	56	21D
0005432817231	209	57	21F
0005433690891	209	58	22A
0005432817217	209	59	22C
0005432817227	209	60	22D
0005432261512	209	61	23B
0005432261510	209	62	23A
0005432261519	209	63	23F
0005432817221	209	64	24A
0005432261553	209	65	24B
0005432261529	209	66	24C
0005432817232	209	67	24E
0005432753243	209	68	25B
0005432261546	209	69	25D
0005432261515	209	70	25E
0005432288960	209	71	26A
0005432207640	209	72	26B
0005432817234	209	73	26D
0005432753242	209	74	26F
0005432261547	209	75	27C
0005432261517	209	76	27B
0005432817237	209	77	27D
0005432207637	209	78	28C
0005432817229	209	79	29A
0005432261552	209	80	28F
0005432261551	209	81	29D
0005432261548	209	82	29F
0005432261535	209	83	30A
0005432261528	209	84	30C
0005432817239	209	85	30D
0005432261531	209	86	31A
0005433690896	209	87	31C
0005432261523	209	88	31B
0005432261542	209	89	31E
0005433101722	7960	1	1A
0005433101728	7960	2	1C
0005433101689	7960	3	1F
0005432020049	7960	4	1D
0005433101687	7960	5	2A
0005433101718	7960	6	2C
0005432020037	7960	7	2F
0005433101725	7960	8	2D
0005432020030	7960	9	3A
0005432919689	7960	10	3F
0005433101692	7960	11	4A
0005432020044	7960	12	4D
0005433101703	7960	13	4C
0005433101724	7960	14	5A
0005433101704	7960	15	5C
0005432020043	7960	16	5D
0005432391973	7960	17	6A
0005433101719	7960	18	5F
0005433101709	7960	19	6F
0005433101700	7960	20	7A
0005433101682	7960	21	7D
0005433101705	7960	22	7F
0005432919684	7960	23	8B
0005433101726	7960	24	8E
0005432020040	7960	25	8F
0005432753275	7960	26	9B
0005432919682	7960	27	9D
0005433101710	7960	28	9E
0005432753274	7960	29	10A
0005432044502	7960	30	10B
0005433101680	7960	31	10D
0005433101708	7960	32	10C
0005432751500	7960	33	10E
0005432919680	7960	34	11C
0005433101706	7960	35	11D
0005433101712	7960	36	12A
0005432391975	7960	37	12C
0005432919683	7960	38	12D
0005433101732	7960	39	12E
0005433101685	7960	40	12F
0005433101684	7960	41	13A
0005433101720	7960	42	13C
0005432020029	7960	43	13D
0005433101733	7960	44	14B
0005433101699	7960	45	14D
0005432020033	7960	46	14C
0005432391974	7960	47	14E
0005432020045	7960	48	15A
0005432677542	7960	49	15C
0005432020028	7960	50	15F
0005433101688	7960	51	15E
0005433101695	7960	52	16A
0005432919691	7960	53	16C
0005432919677	7960	54	16D
0005433101711	7960	55	17A
0005432919685	7960	56	16F
0005432677540	7960	57	17E
0005433101730	7960	58	18A
0005433101727	7960	59	18C
0005432045598	7960	60	18B
0005432677543	7960	61	18D
0005432020050	7960	62	18E
0005432020034	7960	63	18F
0005433101686	7960	64	19B
0005433101702	7960	65	19D
0005433101697	7960	66	19E
0005432919687	7960	67	20B
0005432020027	7960	68	20E
0005433101683	7960	69	20D
0005432020047	7960	70	20F
0005432677541	7960	71	21D
0005432020038	7960	72	21E
0005433101681	7960	73	22A
0005432020039	7960	74	22B
0005433101713	7960	75	22C
0005432751499	7960	76	22E
0005433101693	7960	77	22D
0005432044503	7960	78	22F
0005432751501	7960	79	23A
0005432020042	7960	80	23D
0005433101679	7960	81	23E
0005432919690	7960	82	24A
0005432919686	7960	83	23F
0005432020026	7960	84	24B
0005432919693	7960	85	24C
0005433101729	7960	86	24E
0005432020032	7960	87	24D
0005433101707	7960	88	24F
0005432020041	7960	89	25B
0005433101691	7960	90	25D
0005433101690	7960	91	25C
0005433101717	7960	92	25E
0005432919688	7960	93	25F
0005432020046	7960	94	26B
0005432919675	7960	95	26A
0005433101734	7960	96	26D
0005433101731	7960	97	26F
0005433101715	7960	98	26E
0005432020031	7960	99	27B
0005432919678	7960	100	27C
0005433101696	7960	101	27D
0005432919681	7960	102	27E
0005433101716	7960	103	28B
0005432919692	7960	104	28C
0005432751498	7960	105	28E
0005432020051	7960	106	28D
0005433101723	7960	107	28F
0005432020052	7960	108	29B
0005433101694	7960	109	29A
0005432919679	7960	110	29D
0005432020035	7960	111	29E
0005432020036	7960	112	30A
0005433101698	7960	113	29F
0005432753273	7960	114	30E
0005432020048	7960	115	30D
0005433101714	7960	116	30F
0005432044501	7960	117	31B
0005432919694	7960	118	31A
0005433101701	7960	119	31C
0005432919676	7960	120	31F
0005433101721	7960	121	31E
0005432817021	7958	1	1C
0005432816990	7958	2	3A
0005432816988	7958	3	3F
0005432816987	7958	4	8E
0005432817048	7958	5	9F
0005432901457	7958	6	10A
0005432901468	7958	7	10D
0005432901464	7958	8	10E
0005432817020	7958	9	11E
0005432901465	7958	10	12B
0005432901461	7958	11	12D
0005432901458	7958	12	13F
0005432817052	7958	13	15B
0005432901459	7958	14	15C
0005432817008	7958	15	15F
0005432816945	7958	16	17B
0005432901456	7958	17	17C
0005432817015	7958	18	17E
0005432901471	7958	19	18D
0005432817043	7958	20	18E
0005432901455	7958	21	20F
0005432901469	7958	22	21E
0005432816966	7958	23	22F
0005432816980	7958	24	23B
0005432901466	7958	25	24E
0005432901470	7958	26	25F
0005432901462	7958	27	26E
0005432901472	7958	28	27B
0005432901467	7958	29	27A
0005432816977	7958	30	28D
0005432002059	7958	31	29D
0005432901463	7958	32	29F
0005432817010	7958	33	30A
0005432817014	7958	34	30B
0005432816989	7958	35	30D
0005432817049	7958	36	31A
0005432002058	7958	37	30F
0005432901460	7958	38	31B
0005432002060	7958	39	31E
0005434175682	9641	1	1A
0005434175692	9641	2	2A
0005434175681	9641	3	1B
0005434175691	9641	4	4B
0005434175693	9641	5	5A
0005434175687	9641	6	6A
0005433870713	9641	7	6B
0005433870693	32346	1	1A
0005434175716	32346	2	2A
0005434175715	32346	3	2B
0005433870694	32346	4	3A
0005434175719	32346	5	3B
0005434175717	32346	6	4B
0005434175718	32346	7	6B
0005435126056	3485	1	1A
0005434877463	3485	2	1H
0005434426375	3485	3	1G
0005432799237	3485	4	1D
0005434426385	3485	5	2A
0005434877521	3485	6	2C
0005434937976	3485	7	2H
0005434877488	3485	8	2G
0005432613827	3485	9	3A
0005434877455	3485	10	3K
0005434877466	3485	11	3H
0005434937982	3485	12	3G
0005434426358	3485	13	4C
0005434937984	3485	14	4A
0005434877467	3485	15	4D
0005434937990	3485	16	5A
0005435126040	3485	17	4K
0005432613830	3485	18	4H
0005434426377	3485	19	5H
0005434877513	3485	20	5G
0005434937977	3485	21	5D
0005434877445	3485	22	11A
0005435626028	3485	23	5K
0005434937986	3485	24	11D
0005435902420	3485	25	11E
0005435126026	3485	26	11K
0005434877447	3485	27	11H
0005434877434	3485	28	11G
0005432799238	3485	29	12C
0005435626037	3485	30	12H
0005432799235	3485	31	12F
0005435126041	3485	32	12K
0005434877476	3485	33	13A
0005435626026	3485	34	13E
0005432799214	3485	35	13H
0005435626038	3485	36	13G
0005435626034	3485	37	14A
0005434877435	3485	38	13K
0005435126029	3485	39	14D
0005435126022	3485	40	14C
0005432799236	3485	41	14H
0005434426360	3485	42	15E
0005435126042	3485	43	15D
0005434426381	3485	44	15G
0005432799226	3485	45	15F
0005434877503	3485	46	16A
0005434877472	3485	47	15H
0005434877479	3485	48	16D
0005434426368	3485	49	16C
0005434877462	3485	50	16F
0005434877504	3485	51	17C
0005432799241	3485	52	17A
0005434426380	3485	53	16K
0005434877436	3485	54	17D
0005434877510	3485	55	17G
0005434426378	3485	56	17F
0005434426384	3485	57	17E
0005434937972	3485	58	17K
0005434877461	3485	59	17H
0005434877442	3485	60	18A
0005434937989	3485	61	18E
0005432611676	3485	62	18C
0005434877508	3485	63	18G
0005435126045	3485	64	18J
0005435126033	3485	65	19B
0005432799228	3485	66	18K
0005434426365	3485	67	19D
0005432799242	3485	68	19C
0005434877450	3485	69	19F
0005434426366	3485	70	19E
0005432799221	3485	71	19H
0005435126039	3485	72	19G
0005434877433	3485	73	20A
0005435126057	3485	74	19K
0005434877481	3485	75	19J
0005434877457	3485	76	20B
0005434877452	3485	77	20F
0005434877501	3485	78	20E
0005434877498	3485	79	20D
0005435126053	3485	80	20G
0005435126032	3485	81	20K
0005435626032	3485	82	20J
0005434877465	3485	83	21B
0005435126037	3485	84	21A
0005434877458	3485	85	21D
0005434937978	3485	86	21G
0005435902433	3485	87	21E
0005435626039	3485	88	21J
0005435913849	3485	89	21K
0005434877456	3485	90	22C
0005434877459	3485	91	22E
0005432799213	3485	92	22D
0005432799215	3485	93	22H
0005432611677	3485	94	22F
0005434937979	3485	95	22K
0005434877490	3485	96	22J
0005435126035	3485	97	23B
0005435126047	3485	98	23D
0005434426371	3485	99	23C
0005434877429	3485	100	23F
0005435126063	3485	101	23E
0005435902443	3485	102	23H
0005434877437	3485	103	23G
0005435126031	3485	104	23K
0005434426383	3485	105	23J
0005435626029	3485	106	24G
0005434877438	3485	107	24E
0005434877499	3485	108	24D
0005434877471	3485	109	25C
0005434877446	3485	110	25F
0005435126025	3485	111	25H
0005435126052	3485	112	25G
0005435126023	3485	113	25J
0005435126054	3485	114	26C
0005434877486	3485	115	26A
0005434877514	3485	116	26E
0005434877432	3485	117	26D
0005435626023	3485	118	26F
0005435902390	3485	119	26K
0005432613828	3485	120	26J
0005435126034	3485	121	27B
0005434877441	3485	122	27F
0005432799220	3485	123	27E
0005434877475	3485	124	28A
0005434937985	3485	125	27K
0005435126038	3485	126	28C
0005434426362	3485	127	28B
0005435626031	3485	128	28D
0005435626035	3485	129	28G
0005434877502	3485	130	28K
0005434877460	3485	131	28J
0005435126059	3485	132	28H
0005434877477	3485	133	29F
0005434877487	3485	134	29E
0005435902469	3485	135	29H
0005434426379	3485	136	30B
0005435126055	3485	137	30E
0005434426372	3485	138	30D
0005432799230	3485	139	30H
0005434937987	3485	140	30G
0005435902442	3485	141	30J
0005434877430	3485	142	31B
0005434877469	3485	143	30K
0005434937983	3485	144	31D
0005434877443	3485	145	31C
0005435126060	3485	146	31E
0005434877495	3485	147	32A
0005434877497	3485	148	32E
0005432611679	3485	149	32D
0005434877494	3485	150	32G
0005434877505	3485	151	32F
0005435126050	3485	152	32H
0005434426359	3485	153	33B
0005434877454	3485	154	32K
0005434877439	3485	155	33D
0005432799223	3485	156	33F
0005435626033	3485	157	33E
0005434877451	3485	158	33G
0005435126049	3485	159	34A
0005432799227	3485	160	33K
0005434877468	3485	161	34C
0005435626024	3485	162	34B
0005434877509	3485	163	34E
0005434937974	3485	164	34D
0005434426367	3485	165	34G
0005434937981	3485	166	34J
0005435126036	3485	167	35B
0005432188581	3485	168	35A
0005435626030	3485	169	35D
0005434877511	3485	170	35C
0005432799233	3485	171	35H
0005432188582	3485	172	35G
0005435126030	3485	173	36C
0005435902444	3485	174	36E
0005434877489	3485	175	36F
0005435902419	3485	176	36K
0005434877480	3485	177	36H
0005434877449	3485	178	37C
0005432188580	3485	179	37B
0005435126028	3485	180	37E
0005434937975	3485	181	37D
0005434877482	3485	182	37J
0005434877493	3485	183	37H
0005435126027	3485	184	38A
0005432799224	3485	185	38C
0005434877470	3485	186	38B
0005432799222	3485	187	38K
0005432799217	3485	188	39D
0005435126061	3485	189	39C
0005434937973	3485	190	39B
0005434877491	3485	191	39F
0005434877506	3485	192	39E
0005432799232	3485	193	39K
0005435126046	3485	194	39J
0005434937991	3485	195	40D
0005432611678	3485	196	40G
0005434426357	3485	197	40K
0005432799240	3485	198	40H
0005435626025	3485	199	41C
0005435126062	3485	200	41F
0005432799231	3485	201	41E
0005434877428	3485	202	41H
0005435902432	3485	203	41K
0005432799229	3485	204	41J
0005432799216	3485	205	42C
0005434426374	3485	206	42E
0005434877440	3485	207	42D
0005434877500	3485	208	42G
0005434877484	3485	209	43A
0005434877517	3485	210	43D
0005434877520	3485	211	43C
0005434877431	3485	212	43B
0005434877507	3485	213	43F
0005435902434	3485	214	43E
0005434877496	3485	215	43G
0005435126044	3485	216	44B
0005435626027	3485	217	44A
0005435126024	3485	218	44G
0005434877519	3485	219	45A
0005434877483	3485	220	45D
0005434877453	3485	221	45C
0005435126048	3485	222	45B
0005434937988	3485	223	45F
0005434877474	3485	224	46A
0005435126051	3485	225	45K
0005434877444	3485	226	45J
0005434877522	3485	227	46C
0005434426369	3485	228	46B
0005432799225	3485	229	46D
0005434426364	3485	230	46J
0005434426363	3485	231	46H
0005434426361	3485	232	47A
0005432799239	3485	233	46K
0005432613829	3485	234	47D
0005434937980	3485	235	47C
0005434426370	3485	236	47G
0005434877512	3485	237	47F
0005432799219	3485	238	47K
0005435126043	3485	239	48C
0005434877464	3485	240	48A
0005434426376	3485	241	48F
0005434426373	3485	242	48E
0005434877448	3485	243	48D
0005434426356	3485	244	48H
0005434877492	3485	245	48G
0005432799234	3485	246	49A
0005434877515	3485	247	48K
0005434426382	3485	248	49D
0005434877485	3485	249	49F
0005432799218	3485	250	49H
0005434877473	3485	251	49G
0005434877518	3485	252	50A
0005434877478	3485	253	50E
0005434877516	3485	254	50D
0005435626036	3485	255	50H
0005435126058	3485	256	50K
0005434937911	14585	1	1C
0005435902553	14585	2	1D
0005434876981	14585	3	2A
0005432798960	14585	4	1K
0005435913908	14585	5	2G
0005435125767	14585	6	2K
0005434876799	14585	7	3H
0005435125701	14585	8	4C
0005434876665	14585	9	4D
0005432799068	14585	10	4K
0005432799039	14585	11	4H
0005435625870	14585	12	5D
0005432798955	14585	13	5G
0005434876727	14585	14	11D
0005435125734	14585	15	11C
0005434426140	14585	16	11F
0005434937856	14585	17	12F
0005434426099	14585	18	12D
0005432799006	14585	19	12H
0005434876790	14585	20	12G
0005434937860	14585	21	13C
0005434876705	14585	22	13F
0005434876692	14585	23	13H
0005435125688	14585	24	14A
0005434876712	14585	25	13K
0005434426142	14585	26	14D
0005434876728	14585	27	14G
0005435125768	14585	28	14F
0005432798963	14585	29	14K
0005435125694	14585	30	14H
0005434937857	14585	31	15A
0005435902563	14585	32	15F
0005435902562	14585	33	15E
0005432798954	14585	34	15D
0005434876778	14585	35	15H
0005434877029	14585	36	16D
0005434426175	14585	37	17K
0005435125784	14585	38	17H
0005435125733	14585	39	18G
0005434876791	14585	40	18E
0005434426214	14585	41	18J
0005435902555	14585	42	18H
0005434876843	14585	43	19A
0005434937865	14585	44	19D
0005432799016	14585	45	20C
0005434877053	14585	46	20E
0005432607497	14585	47	20D
0005435125801	14585	48	20F
0005432799094	14585	49	20H
0005434876636	14585	50	20K
0005434937833	14585	51	21D
0005434426107	14585	52	21E
0005434876731	14585	53	21J
0005434876695	14585	54	21H
0005434876994	14585	55	22C
0005435902556	14585	56	22B
0005434876895	14585	57	22H
0005434876751	14585	58	22G
0005435625874	14585	59	22F
0005434876644	14585	60	22J
0005434426186	14585	61	23B
0005434876570	14585	62	23D
0005435125674	14585	63	23F
0005435625871	14585	64	23G
0005434876734	14585	65	24D
0005434876639	14585	66	23K
0005434876844	14585	67	23J
0005435125687	14585	68	25F
0005435902552	14585	69	25E
0005432799097	14585	70	26G
0005434426170	14585	71	26J
0005435902549	14585	72	27A
0005434426156	14585	73	26K
0005434877136	14585	74	27D
0005434876715	14585	75	27C
0005434876772	14585	76	27B
0005434876846	14585	77	27F
0005434876753	14585	78	27H
0005434876900	14585	79	27J
0005435125662	14585	80	28B
0005432607498	14585	81	28E
0005434876822	14585	82	28F
0005434876633	14585	83	28J
0005434426103	14585	84	28H
0005434877028	14585	85	29H
0005435902558	14585	86	29G
0005432799027	14585	87	29K
0005432799035	14585	88	29J
0005435902565	14585	89	30C
0005432611651	14585	90	30B
0005434876698	14585	91	30G
0005435125658	14585	92	30J
0005432799001	14585	93	30H
0005435902560	14585	94	30K
0005432799098	14585	95	31D
0005434876866	14585	96	31C
0005434426139	14585	97	31E
0005435902561	14585	98	32C
0005435902551	14585	99	32B
0005432798967	14585	100	32A
0005435902559	14585	101	32D
0005435913905	14585	102	32F
0005432059488	14585	103	32J
0005435913903	14585	104	33A
0005434876894	14585	105	33C
0005434937838	14585	106	33G
0005432798983	14585	107	33F
0005432611646	14585	108	33J
0005435914690	14585	109	33K
0005432799037	14585	110	34C
0005432611649	14585	111	34B
0005434876823	14585	112	34D
0005434876684	14585	113	34H
0005434426171	14585	114	34J
0005435902554	14585	115	35B
0005434426172	14585	116	35D
0005432059487	14585	117	35C
0005432798968	14585	118	35H
0005435125659	14585	119	36C
0005434876730	14585	120	36A
0005435913907	14585	121	36D
0005432611644	14585	122	36F
0005432798956	14585	123	36K
0005432798959	14585	124	36J
0005434876803	14585	125	37D
0005432799034	14585	126	37C
0005435625873	14585	127	37F
0005434876579	14585	128	37E
0005434426238	14585	129	37J
0005434426118	14585	130	37K
0005435625872	14585	131	38C
0005434937875	14585	132	38B
0005434876580	14585	133	38K
0005434876593	14585	134	38H
0005434876729	14585	135	39C
0005432798953	14585	136	39B
0005435914689	14585	137	39F
0005434876681	14585	138	39E
0005434937822	14585	139	40A
0005435902557	14585	140	40B
0005434876733	14585	141	40E
0005434876857	14585	142	40H
0005432798976	14585	143	41A
0005434876732	14585	144	41D
0005434877052	14585	145	41F
0005435125782	14585	146	41J
0005434876573	14585	147	41H
0005435125754	14585	148	42A
0005434426141	14585	149	41K
0005432799002	14585	150	42F
0005435125709	14585	151	42E
0005434876845	14585	152	42G
0005434877137	14585	153	42H
0005434876708	14585	154	43B
0005434876637	14585	155	43A
0005435625866	14585	156	42K
0005435125676	14585	157	43F
0005435625862	14585	158	43E
0005435625867	14585	159	43J
0005435125753	14585	160	43H
0005434426119	14585	161	44B
0005432799041	14585	162	44F
0005434426173	14585	163	44J
0005434937846	14585	164	45A
0005434876595	14585	165	45E
0005434876699	14585	166	45D
0005434876824	14585	167	46A
0005435125675	14585	168	45K
0005434876638	14585	169	45J
0005432798961	14585	170	46E
0005435913906	14585	171	46C
0005432798995	14585	172	46G
0005435125661	14585	173	46F
0005432799021	14585	174	46J
0005435125735	14585	175	47C
0005435125660	14585	176	47A
0005434876594	14585	177	47E
0005434426237	14585	178	47D
0005435902550	14585	179	47H
0005435913904	14585	180	48A
0005434876839	14585	181	48F
0005434937855	14585	182	48E
0005435125671	14585	183	49A
0005435902564	14585	184	49D
0005435125656	14585	185	49F
0005434937910	14585	186	50C
0005434876908	14585	187	50D
0005434876629	14585	188	50K
0005434876709	14585	189	50H
0005435125783	14585	190	51E
0005434325560	3599	1	1A
0005434312301	3599	2	1B
0005435889798	3599	3	2C
0005435889801	3599	4	3C
0005434325554	3599	5	3D
0005435889805	3599	6	4B
0005434312300	3599	7	5D
0005434325558	3599	8	6D
0005434325550	3599	9	18A
0005434325556	3599	10	18D
0005434325552	3599	11	19A
0005434312302	3599	12	19C
0005435889802	3599	13	19D
0005435889804	3599	14	20C
0005434325551	3599	15	20D
0005435889794	3599	16	21C
0005434325555	3599	17	21D
0005434325553	3599	18	22A
0005434325549	3599	19	22C
0005434325559	3599	20	22D
0005434325557	3599	21	23B
0005435889848	15589	1	1A
0005434325507	15589	2	1B
0005434325500	15589	3	1D
0005435889849	15589	4	2B
0005434325487	15589	5	3B
0005434325480	15589	6	3D
0005434325499	15589	7	4A
0005434325488	15589	8	4B
0005435889847	15589	9	4D
0005435889846	15589	10	5A
0005434325506	15589	11	5D
0005435889844	15589	12	6C
0005434325476	15589	13	7D
0005434325498	15589	14	18C
0005435889845	15589	15	19A
0005434325479	15589	16	21B
0005435957574	620	1	1D
0005435957582	620	2	2B
0005435957579	620	3	2D
0005435957583	620	4	3B
0005435957575	620	5	3D
0005435957580	620	6	4B
0005433420257	620	7	4C
0005435957581	620	8	6B
0005435957587	620	9	6C
0005433420265	620	10	6D
0005435957578	620	11	7B
0005435957585	620	12	18A
0005435957577	620	13	18D
0005435957586	620	14	19D
0005435957588	620	15	21C
0005435957584	620	16	23A
0005435957576	620	17	22D
0005435957443	15169	1	1A
0005433420330	15169	2	2D
0005435957455	15169	3	3D
0005435957471	15169	4	4B
0005435957459	15169	5	4C
0005433420334	15169	6	5A
0005433420333	15169	7	5B
0005435957508	15169	8	5C
0005433420328	15169	9	5D
0005435957450	15169	10	6B
0005433420329	15169	11	7B
0005433420332	15169	12	18B
0005435957449	15169	13	19A
0005435957469	15169	14	19B
0005433420336	15169	15	20C
0005433420335	15169	16	21A
0005435957442	15169	17	21C
0005435957448	15169	18	21D
0005433420331	15169	19	22B
0005435957513	15169	20	22D
0005435957460	15169	21	23B
0005434247107	8833	1	1B
0005434247102	8833	2	2A
0005434247100	8833	3	2B
0005434247108	8833	4	3A
0005434247110	8833	5	3B
0005434247105	8833	6	4B
0005434247109	8833	7	5A
0005434247101	8833	8	5B
0005434247126	16119	1	3A
0005435629386	16119	2	5A
0005435629387	16119	3	6B
0005435163193	4440	1	1A
0005435933394	4440	2	1B
0005435163192	4440	3	1D
0005435163189	4440	4	3D
0005435163182	4440	5	4A
0005435163191	4440	6	4C
0005435163188	4440	7	5B
0005435933399	4440	8	5C
0005435933400	4440	9	6B
0005435933410	4440	10	6D
0005435163187	4440	11	7A
0005435163183	4440	12	18B
0005435163186	4440	13	18C
0005435163190	4440	14	19B
0005435163185	4440	15	20A
0005435933398	4440	16	20C
0005435163184	4440	17	21B
0005435163155	29504	1	1C
0005435163146	29504	2	2A
0005435163140	29504	3	3B
0005435933421	29504	4	5A
0005435933423	29504	5	5C
0005435933427	29504	6	6A
0005435933425	29504	7	7C
0005435933422	29504	8	19C
0005435933428	29504	9	20C
0005435163145	29504	10	20D
0005435163141	29504	11	21B
0005435933426	29504	12	21C
0005435933424	29504	13	22A
0005435797361	2867	1	3C
0005435797358	2867	2	5D
0005433404702	2867	3	5F
0005435797359	2867	4	7A
0005435797357	2867	5	7C
0005435797365	2867	6	9C
0005435797355	2867	7	9D
0005435797353	2867	8	10A
0005433404701	2867	9	11F
0005435797360	2867	10	12F
0005435797354	2867	11	13C
0005435797352	2867	12	14A
0005435797356	2867	13	15F
0005435797362	2867	14	17D
0005435797363	2867	15	17E
0005433404684	2867	16	17F
0005433404681	2867	17	18D
0005435797366	2867	18	18E
0005435797364	2867	19	20E
0005435797277	29323	1	1D
0005435797234	29323	2	3F
0005435797228	29323	3	5F
0005433404747	29323	4	7A
0005435797233	29323	5	10D
0005435797265	29323	6	11A
0005433404746	29323	7	12E
0005435797268	29323	8	13F
0005433404750	29323	9	15F
0005435797267	29323	10	17D
0005435797229	29323	11	17F
0005433404752	29323	12	18A
0005435797247	29323	13	18F
0005433404749	29323	14	19A
0005433404748	29323	15	19D
0005433404751	29323	16	19E
0005435797266	29323	17	20E
0005435376312	5748	1	5B
0005434947952	5741	1	1A
0005434947953	5741	2	2A
0005434947954	5741	3	2B
0005434947955	5741	4	3B
0005434947949	5741	5	4A
0005434947956	5741	6	5B
0005434947950	5741	7	6A
0005434947951	5741	8	6B
0005434947880	16393	1	1B
0005434947897	16393	2	2A
0005435376333	16393	3	2B
0005435376332	16393	4	3A
0005434947899	16393	5	3B
0005435376331	16393	6	4A
0005434947874	16393	7	4B
0005434947901	16393	8	5B
0005434947900	16393	9	6A
0005435376334	16393	10	6B
0005433960400	6910	1	1D
0005433960411	6910	2	1F
0005433960440	6910	3	2A
0005433960393	6910	4	2C
0005433960433	6910	5	2F
0005433960424	6910	6	3A
0005433960429	6910	7	3C
0005433960422	6910	8	3D
0005433960435	6910	9	4C
0005433960406	6910	10	4D
0005433960405	6910	11	5D
0005433960436	6910	12	6A
0005433960430	6910	13	7A
0005433960416	6910	14	7C
0005433960391	6910	15	7D
0005433960441	6910	16	7E
0005433960423	6910	17	8A
0005433960414	6910	18	8C
0005433960396	6910	19	8D
0005433960439	6910	20	8E
0005433960401	6910	21	9A
0005433960407	6910	22	9D
0005433960427	6910	23	9E
0005433960425	6910	24	9F
0005433960438	6910	25	11A
0005433960442	6910	26	11C
0005433960390	6910	27	11D
0005433960403	6910	28	11F
0005433960428	6910	29	12A
0005433960432	6910	30	12C
0005433960418	6910	31	12E
0005433960412	6910	32	13A
0005433960408	6910	33	13E
0005433960434	6910	34	13F
0005433960413	6910	35	14A
0005433960421	6910	36	14D
0005433960397	6910	37	14E
0005433960420	6910	38	14F
0005433960410	6910	39	15E
0005433960437	6910	40	16C
0005433960419	6910	41	16E
0005433960404	6910	42	18C
0005433960431	6910	43	18E
0005433960415	6910	44	18F
0005433960399	6910	45	19A
0005433960417	6910	46	19C
0005433960395	6910	47	19E
0005433960409	6910	48	19F
0005433960426	6910	49	20A
0005433960394	6910	50	20C
0005433960402	6910	51	20D
0005433960392	6910	52	20E
0005433960398	6910	53	20F
0005433959868	25808	1	2D
0005433959865	25808	2	2F
0005433959861	25808	3	18E
0005435082661	24487	1	1A
0005435082645	24487	2	1B
0005435082644	24487	3	2A
0005435082660	24487	4	3B
0005435082646	24487	5	4A
0005435082667	24487	6	4B
0005435082680	24487	7	6A
0005435082647	24487	8	6B
0005435082714	26062	1	1B
0005435082716	26062	2	4A
0005435082711	26062	3	4B
0005435082713	26062	4	5A
0005435082715	26062	5	6A
0005435082712	26062	6	6B
0005434244753	5129	1	1D
0005434244726	5129	2	4A
0005434244730	5129	3	5A
0005434244729	5129	4	5C
0005434244737	5129	5	6A
0005433534464	5129	6	7C
0005434244749	5129	7	7F
0005434244732	5129	8	8E
0005432166875	5129	9	8D
0005434244743	5129	10	10E
0005433534468	5129	11	10F
0005434244747	5129	12	12B
0005434244738	5129	13	12D
0005434244735	5129	14	12F
0005435286549	5129	15	13F
0005434244748	5129	16	14D
0005433534465	5129	17	14E
0005434244733	5129	18	14F
0005434244752	5129	19	15A
0005434244739	5129	20	15C
0005434244741	5129	21	15D
0005434244744	5129	22	15F
0005434244728	5129	23	18B
0005434244751	5129	24	18E
0005434244740	5129	25	20D
0005434244746	5129	26	21A
0005434244734	5129	27	21F
0005432166874	5129	28	23E
0005433534466	5129	29	24A
0005434244745	5129	30	24B
0005433534467	5129	31	25B
0005434244742	5129	32	25A
0005435286550	5129	33	25E
0005434244736	5129	34	25D
0005432166873	5129	35	26D
0005434244731	5129	36	28A
0005434244750	5129	37	28C
0005434244727	5129	38	29B
0005434244725	5129	39	30E
0005433614105	5130	1	1A
0005433784658	5130	2	1C
0005433784629	5130	3	1F
0005432105200	5130	4	2A
0005432105196	5130	5	2C
0005433614075	5130	6	2F
0005433784648	5130	7	2D
0005432105172	5130	8	3A
0005432105163	5130	9	3D
0005433614065	5130	10	3C
0005433784645	5130	11	4A
0005433784624	5130	12	3F
0005433614134	5130	13	4C
0005433784634	5130	14	4D
0005433614132	5130	15	5A
0005433614112	5130	16	4F
0005433784653	5130	17	5C
0005433784655	5130	18	5F
0005433784642	5130	19	5D
0005433784643	5130	20	6A
0005432145094	5130	21	6C
0005433784636	5130	22	6D
0005433784661	5130	23	7A
0005432105165	5130	24	6F
0005433614083	5130	25	7C
0005433784646	5130	26	7D
0005432105168	5130	27	8A
0005433784638	5130	28	7F
0005433614102	5130	29	8C
0005433614068	5130	30	8B
0005433614109	5130	31	8E
0005432105194	5130	32	8D
0005433784650	5130	33	8F
0005433614078	5130	34	9A
0005433784630	5130	35	9D
0005432666372	5130	36	9C
0005432105190	5130	37	9B
0005432105167	5130	38	9F
0005433784641	5130	39	9E
0005433784662	5130	40	10A
0005433784647	5130	41	10C
0005432105174	5130	42	10B
0005433614098	5130	43	10D
0005433784659	5130	44	10E
0005432105153	5130	45	11A
0005433614099	5130	46	10F
0005433614107	5130	47	11B
0005433614129	5130	48	11C
0005433784632	5130	49	11D
0005433784631	5130	50	11E
0005433784651	5130	51	12A
0005433614091	5130	52	11F
0005433614067	5130	53	12B
0005433784637	5130	54	12D
0005433614093	5130	55	12C
0005433614073	5130	56	12E
0005432105191	5130	57	12F
0005433614114	5130	58	13B
0005433614119	5130	59	13A
0005433614115	5130	60	13C
0005433614061	5130	61	13E
0005433614111	5130	62	13D
0005432105187	5130	63	14A
0005433614066	5130	64	13F
0005432105186	5130	65	14B
0005433614104	5130	66	14D
0005432667437	5130	67	14C
0005432105175	5130	68	14E
0005433614079	5130	69	14F
0005433614103	5130	70	15A
0005432105171	5130	71	15C
0005433784625	5130	72	15B
0005433614092	5130	73	15D
0005433614100	5130	74	15F
0005432105158	5130	75	15E
0005433784626	5130	76	16A
0005432105156	5130	77	16B
0005433784639	5130	78	16C
0005433614121	5130	79	16E
0005432667438	5130	80	16D
0005432105185	5130	81	16F
0005433614128	5130	82	17B
0005433614116	5130	83	17A
0005433784635	5130	84	17C
0005432105193	5130	85	17E
0005433614133	5130	86	17D
0005432105180	5130	87	18A
0005432105183	5130	88	17F
0005432105157	5130	89	18B
0005433614071	5130	90	18C
0005433614117	5130	91	18E
0005432105197	5130	92	18D
0005433614097	5130	93	18F
0005433614122	5130	94	19C
0005432105169	5130	95	19B
0005433614125	5130	96	19D
0005433614072	5130	97	19E
0005433784656	5130	98	20B
0005433614062	5130	99	20A
0005433614081	5130	100	20C
0005433614069	5130	101	20D
0005433614085	5130	102	20F
0005432105184	5130	103	20E
0005433614084	5130	104	21B
0005432105154	5130	105	21A
0005433614094	5130	106	21C
0005433614113	5130	107	21D
0005433614126	5130	108	21E
0005432145095	5130	109	21F
0005432105170	5130	110	22B
0005433614088	5130	111	22A
0005433614101	5130	112	22C
0005433784627	5130	113	22D
0005433614087	5130	114	22F
0005433614108	5130	115	22E
0005433784640	5130	116	23A
0005432105195	5130	117	23C
0005433784649	5130	118	23B
0005433614130	5130	119	23D
0005433614080	5130	120	23E
0005433614070	5130	121	24A
0005432105181	5130	122	23F
0005432666370	5130	123	24B
0005433614064	5130	124	24C
0005432105160	5130	125	24D
0005432105192	5130	126	24F
0005433614076	5130	127	24E
0005433614063	5130	128	25B
0005433784628	5130	129	25A
0005433614089	5130	130	25C
0005432105159	5130	131	25D
0005432105162	5130	132	25E
0005433614095	5130	133	25F
0005433614077	5130	134	26B
0005433614086	5130	135	26A
0005433784657	5130	136	26D
0005433614118	5130	137	26C
0005432666371	5130	138	26E
0005432105199	5130	139	26F
0005432105189	5130	140	27A
0005433784644	5130	141	27C
0005432105179	5130	142	27B
0005432105188	5130	143	27D
0005432105177	5130	144	27E
0005433614131	5130	145	27F
0005433784633	5130	146	28B
0005433614124	5130	147	28A
0005433614127	5130	148	28D
0005433784652	5130	149	28C
0005432105176	5130	150	28E
0005433784660	5130	151	28F
0005432105173	5130	152	29B
0005433614074	5130	153	29A
0005432105182	5130	154	29C
0005433614106	5130	155	29E
0005432105178	5130	156	29D
0005433614123	5130	157	29F
0005433614096	5130	158	30A
0005432105155	5130	159	30B
0005432105166	5130	160	30C
0005432105161	5130	161	30E
0005433614060	5130	162	30D
0005432105164	5130	163	31A
0005433614082	5130	164	30F
0005432105198	5130	165	31C
0005433784654	5130	166	31B
0005433614110	5130	167	31E
0005433614120	5130	168	31D
0005433614090	5130	169	31F
0005432335865	5132	1	1C
0005434173487	5132	2	2A
0005432335866	5132	3	2D
0005432335840	5132	4	2C
0005434149636	5132	5	3C
0005434264930	5132	6	3F
0005434229195	5132	7	3D
0005434264914	5132	8	4A
0005434229192	5132	9	4C
0005435006680	5132	10	4F
0005434264937	5132	11	5F
0005432335885	5132	12	5D
0005434264934	5132	13	6A
0005434229196	5132	14	6C
0005434229193	5132	15	7A
0005434229177	5132	16	7C
0005435006681	5132	17	7D
0005435006626	5132	18	8A
0005434149631	5132	19	8B
0005433815317	5132	20	8D
0005434264925	5132	21	9A
0005435006721	5132	22	8F
0005434229176	5132	23	9C
0005434264921	5132	24	9B
0005434229197	5132	25	9D
0005434264923	5132	26	10C
0005434229194	5132	27	10F
0005434229181	5132	28	11A
0005435006684	5132	29	11E
0005434264927	5132	30	11D
0005433815319	5132	31	11F
0005435006648	5132	32	12C
0005434149629	5132	33	12F
0005434229182	5132	34	13D
0005434264922	5132	35	13E
0005434229186	5132	36	14A
0005434149630	5132	37	14B
0005434264926	5132	38	14F
0005434264940	5132	39	15B
0005434264924	5132	40	15C
0005434229175	5132	41	15F
0005434149634	5132	42	16B
0005432335853	5132	43	16C
0005433688776	5132	44	17A
0005434173488	5132	45	16F
0005432335820	5132	46	17C
0005435006679	5132	47	17D
0005434229178	5132	48	17F
0005434264918	5132	49	17E
0005434229174	5132	50	18A
0005432335832	5132	51	18B
0005432335839	5132	52	18E
0005434264936	5132	53	18F
0005434264919	5132	54	19E
0005434149633	5132	55	20C
0005434229191	5132	56	20E
0005435006720	5132	57	21A
0005435006621	5132	58	21B
0005433815307	5132	59	21C
0005434229187	5132	60	21E
0005434264939	5132	61	22A
0005434229189	5132	62	21F
0005435006627	5132	63	22C
0005434149639	5132	64	22D
0005434149637	5132	65	22F
0005435006647	5132	66	22E
0005435006700	5132	67	23B
0005433815318	5132	68	23C
0005434229185	5132	69	23D
0005434149632	5132	70	24A
0005435006682	5132	71	24B
0005434264928	5132	72	24C
0005432335850	5132	73	24E
0005434264929	5132	74	24D
0005432335854	5132	75	25B
0005434264933	5132	76	25A
0005434229184	5132	77	25C
0005434149638	5132	78	25D
0005434264938	5132	79	25F
0005434264920	5132	80	26A
0005434264917	5132	81	26D
0005434149628	5132	82	26C
0005432335821	5132	83	26E
0005434173486	5132	84	27A
0005434229188	5132	85	26F
0005434264916	5132	86	27E
0005434264932	5132	87	27D
0005433815306	5132	88	27F
0005434264931	5132	89	28A
0005435006728	5132	90	28C
0005434264935	5132	91	28E
0005434229179	5132	92	29C
0005434149635	5132	93	29F
0005434173485	5132	94	30B
0005434229180	5132	95	30D
0005435006638	5132	96	30E
0005434229190	5132	97	31B
0005434264915	5132	98	31E
0005434229183	5132	99	31D
0005433784322	8372	1	1D
0005434244554	8372	2	1F
0005434244470	8372	3	3A
0005435269685	8372	4	3F
0005433784316	8372	5	4C
0005433784321	8372	6	4F
0005433784483	8372	7	5A
0005432666354	8372	8	9A
0005433784437	8372	9	10A
0005434244603	8372	10	9F
0005433784405	8372	11	10E
0005435269687	8372	12	10F
0005434244508	8372	13	11B
0005435269686	8372	14	11E
0005433784419	8372	15	12A
0005435269691	8372	16	12C
0005434244500	8372	17	13B
0005433784440	8372	18	13A
0005434244471	8372	19	13E
0005433784401	8372	20	14A
0005434244501	8372	21	13F
0005434244564	8372	22	14C
0005435269690	8372	23	14E
0005434244601	8372	24	15B
0005433784435	8372	25	15A
0005433784319	8372	26	15E
0005434244472	8372	27	16E
0005433784367	8372	28	17D
0005434244597	8372	29	17E
0005435269692	8372	30	18A
0005433784482	8372	31	18E
0005433784436	8372	32	19B
0005433784374	8372	33	20C
0005434244509	8372	34	21F
0005434244543	8372	35	22D
0005434244493	8372	36	22E
0005434244487	8372	37	23A
0005434244542	8372	38	24D
0005433784302	8372	39	24F
0005434244574	8372	40	25B
0005433784409	8372	41	25F
0005435269689	8372	42	26E
0005434244643	8372	43	27B
0005434244577	8372	44	27D
0005432666358	8372	45	27E
0005433784368	8372	46	28C
0005432659674	8372	47	28D
0005434244497	8372	48	28F
0005434244602	8372	49	29A
0005433784351	8372	50	29C
0005433784320	8372	51	29D
0005433784334	8372	52	29F
0005434244469	8372	53	30B
0005433784387	8372	54	30C
0005434244575	8372	55	30F
0005434244576	8372	56	31B
0005435269688	8372	57	31E
0005433613392	8371	1	3C
0005433613663	8371	2	4A
0005433613652	8371	3	6A
0005433613519	8371	4	8F
0005433613660	8371	5	9B
0005433613505	8371	6	9D
0005433613437	8371	7	10E
0005433613567	8371	8	11A
0005433613523	8371	9	12A
0005433613664	8371	10	13D
0005433613562	8371	11	13E
0005433613460	8371	12	14C
0005433613454	8371	13	14F
0005433613395	8371	14	15C
0005433613546	8371	15	15F
0005433613522	8371	16	16B
0005433613405	8371	17	16F
0005433613566	8371	18	17E
0005433613448	8371	19	19E
0005433613633	8371	20	20D
0005433613518	8371	21	21D
0005433613561	8371	22	21F
0005433613653	8371	23	22D
0005433613503	8371	24	24C
0005433613412	8371	25	24F
0005433613393	8371	26	25B
0005433613447	8371	27	25D
0005433613413	8371	28	25F
0005433613455	8371	29	26A
0005433613394	8371	30	26D
0005433613545	8371	31	27A
0005433613662	8371	32	26F
0005433613710	8371	33	28D
0005433613406	8371	34	30C
0005433613535	8371	35	31F
0005434264794	8370	1	1C
0005435286573	8370	2	2A
0005432034718	8370	3	1F
0005435286570	8370	4	2C
0005432034708	8370	5	2D
0005432335933	8370	6	3C
0005434264741	8370	7	3A
0005432034729	8370	8	3D
0005432335931	8370	9	4A
0005434229035	8370	10	3F
0005432034722	8370	11	4C
0005432335934	8370	12	5A
0005435286574	8370	13	5D
0005433688794	8370	14	5C
0005432335940	8370	15	5F
0005432034707	8370	16	6A
0005434149537	8370	17	6D
0005434229020	8370	18	6F
0005432034730	8370	19	7A
0005435006825	8370	20	7D
0005434311202	8370	21	7C
0005433815350	8370	22	7F
0005435006829	8370	23	8C
0005434229028	8370	24	8E
0005434264709	8370	25	9A
0005432335936	8370	26	9C
0005434264756	8370	27	9B
0005434264793	8370	28	9D
0005432034716	8370	29	9F
0005432034727	8370	30	10A
0005432335939	8370	31	10B
0005432034717	8370	32	10D
0005432034724	8370	33	10C
0005434228969	8370	34	10F
0005434228981	8370	35	11A
0005435006841	8370	36	11C
0005435006821	8370	37	11B
0005435006837	8370	38	11D
0005432034705	8370	39	11F
0005435006831	8370	40	11E
0005433689894	8370	41	12A
0005432034709	8370	42	12C
0005435006830	8370	43	12B
0005434264752	8370	44	12D
0005434264708	8370	45	12E
0005434228996	8370	46	12F
0005434229005	8370	47	13A
0005434228997	8370	48	13C
0005435286576	8370	49	13D
0005432047519	8370	50	14A
0005434264746	8370	51	14B
0005433688793	8370	52	14D
0005435006823	8370	53	14F
0005435006832	8370	54	15B
0005432335942	8370	55	15A
0005432034731	8370	56	15C
0005434149530	8370	57	15F
0005432034721	8370	58	15E
0005432034720	8370	59	16A
0005433815347	8370	60	16B
0005434228971	8370	61	16D
0005435006828	8370	62	16C
0005432047520	8370	63	16E
0005435286578	8370	64	16F
0005435006819	8370	65	17B
0005435286571	8370	66	17A
0005434228985	8370	67	17D
0005434264750	8370	68	17E
0005432034732	8370	69	18A
0005433688792	8370	70	18B
0005434149531	8370	71	18C
0005434228970	8370	72	18E
0005435286572	8370	73	19B
0005435006818	8370	74	18F
0005432335938	8370	75	19C
0005432335941	8370	76	19D
0005432034711	8370	77	20A
0005432034723	8370	78	19E
0005433690909	8370	79	20C
0005432034715	8370	80	20B
0005433815348	8370	81	20E
0005434311203	8370	82	20D
0005433815346	8370	83	20F
0005435006838	8370	84	21A
0005434228998	8370	85	21C
0005434264749	8370	86	21B
0005432034726	8370	87	21D
0005434264683	8370	88	21F
0005435006826	8370	89	22B
0005435006822	8370	90	22C
0005434228980	8370	91	22D
0005434264728	8370	92	22F
0005432047518	8370	93	22E
0005433815349	8370	94	23A
0005432335937	8370	95	23C
0005432034712	8370	96	23B
0005432034706	8370	97	23D
0005432034734	8370	98	23E
0005434228984	8370	99	23F
0005432034728	8370	100	24A
0005435006834	8370	101	24D
0005432335932	8370	102	24C
0005434311201	8370	103	24F
0005432034713	8370	104	24E
0005434229004	8370	105	25A
0005435006839	8370	106	25C
0005432034719	8370	107	25B
0005432034714	8370	108	26A
0005435006820	8370	109	25F
0005432335935	8370	110	26C
0005433690911	8370	111	26F
0005435006827	8370	112	26E
0005435006836	8370	113	27A
0005433815345	8370	114	27C
0005435286575	8370	115	27D
0005434264751	8370	116	28A
0005434173451	8370	117	27F
0005432034733	8370	118	28C
0005435006833	8370	119	28D
0005433689893	8370	120	28E
0005435006840	8370	121	28F
0005434149536	8370	122	29A
0005433690910	8370	123	29C
0005435006824	8370	124	29B
0005435006817	8370	125	29D
0005432335930	8370	126	30A
0005434264744	8370	127	29F
0005435006835	8370	128	30B
0005434229021	8370	129	30C
0005434229027	8370	130	30D
0005434264684	8370	131	30F
0005434229048	8370	132	30E
0005432034710	8370	133	31A
0005433534481	8370	134	31C
0005432047517	8370	135	31B
0005434229047	8370	136	31E
0005432034725	8370	137	31D
0005435286577	8370	138	31F
0005434638892	12630	1	1A
0005433202252	12630	2	1B
0005433202243	12630	3	1D
0005433202242	12630	4	2A
0005434638849	12630	5	2C
0005433202241	12630	6	3A
0005433202239	12630	7	3B
0005434638875	12630	8	4A
0005433202250	12630	9	4C
0005434638874	12630	10	5A
0005433202245	12630	11	5C
0005433202251	12630	12	6A
0005434638856	12630	13	6B
0005433202240	12630	14	6D
0005433202247	12630	15	6C
0005433202249	12630	16	18A
0005434638872	12630	17	18C
0005434638934	12630	18	19A
0005433202248	12630	19	19B
0005434638935	12630	20	19C
0005434638873	12630	21	20A
0005434638868	12630	22	20C
0005433202244	12630	23	20D
0005434638891	12630	24	21B
0005434638932	12630	25	21C
0005434638867	12630	26	21D
0005434638869	12630	27	22A
0005433202246	12630	28	22D
0005434638976	12630	29	23B
0005434639070	23383	1	1A
0005433202113	23383	2	1B
0005434639078	23383	3	1C
0005434639073	23383	4	1D
0005433202111	23383	5	2B
0005434639075	23383	6	3A
0005434639089	23383	7	2D
0005434639080	23383	8	3B
0005434639090	23383	9	3C
0005433202102	23383	10	3D
0005434639097	23383	11	4A
0005434639081	23383	12	4B
0005434639093	23383	13	4C
0005434639079	23383	14	5A
0005434639096	23383	15	5C
0005434639098	23383	16	6A
0005434639083	23383	17	6B
0005434639087	23383	18	6C
0005434639077	23383	19	6D
0005432290606	23383	20	7B
0005432290605	23383	21	7C
0005434639095	23383	22	7D
0005433202110	23383	23	18A
0005434639092	23383	24	18B
0005434639071	23383	25	18C
0005434639086	23383	26	19A
0005434639088	23383	27	19B
0005433202139	23383	28	19C
0005434639084	23383	29	20B
0005434639072	23383	30	20C
0005434639074	23383	31	20D
0005434639082	23383	32	21A
0005434639094	23383	33	21B
0005434639085	23383	34	21D
0005434639091	23383	35	21C
0005433202140	23383	36	22A
0005434639076	23383	37	22D
0005432382550	21109	1	1A
0005432382765	21109	2	1C
0005432327949	21109	3	1F
0005432327892	21109	4	2A
0005432054279	21109	5	2C
0005432327954	21109	6	3C
0005432328027	21109	7	3D
0005432328028	21109	8	4E
0005432328133	21109	9	4F
0005432054281	21109	10	5D
0005432327982	21109	11	5E
0005432382667	21109	12	6A
0005432327910	21109	13	6D
0005432382530	21109	14	6E
0005432382599	21109	15	7C
0005432382612	21109	16	8C
0005432327894	21109	17	9A
0005432382764	21109	18	9C
0005432327955	21109	19	9E
0005432382485	21109	20	9F
0005432382585	21109	21	11F
0005432327891	21109	22	12A
0005432327913	21109	23	12D
0005432327981	21109	24	12F
0005432382539	21109	25	13A
0005432382766	21109	26	13F
0005432328079	21109	27	14A
0005432382551	21109	28	14C
0005432328109	21109	29	14E
0005432382486	21109	30	15A
0005432382537	21109	31	15D
0005432382567	21109	32	15F
0005432382560	21109	33	16A
0005432382522	21109	34	16D
0005432327946	21109	35	16E
0005432327912	21109	36	16F
0005432382538	21109	37	17A
0005432382549	21109	38	17C
0005432382593	21109	39	18A
0005432382529	21109	40	18C
0005432327903	21109	41	18E
0005432327980	21109	42	18F
0005432382668	21109	43	19A
0005432327893	21109	44	19E
0005432382594	21109	45	20D
0005432054280	21109	46	20E
0005432328308	31232	1	1A
0005432328275	31232	2	1C
0005432328284	31232	3	1D
0005432382822	31232	4	1F
0005432382843	31232	5	2A
0005432382838	31232	6	2C
0005432328266	31232	7	2D
0005432328303	31232	8	2F
0005432382813	31232	9	3A
0005432382815	31232	10	3C
0005432328287	31232	11	3D
0005432328307	31232	12	3F
0005432382827	31232	13	4A
0005432382828	31232	14	4C
0005432328298	31232	15	4D
0005432382807	31232	16	4E
0005432382821	31232	17	4F
0005432382818	31232	18	5C
0005432328310	31232	19	5A
0005432382831	31232	20	5D
0005432328292	31232	21	5F
0005432287145	31232	22	6A
0005432328274	31232	23	6C
0005432287144	31232	24	6D
0005432328268	31232	25	6E
0005432382808	31232	26	6F
0005432328277	31232	27	7A
0005432382834	31232	28	7C
0005432328270	31232	29	7D
0005432382811	31232	30	7E
0005432382820	31232	31	8A
0005432328285	31232	32	8C
0005432287143	31232	33	8D
0005432382805	31232	34	8E
0005432328290	31232	35	9A
0005432328282	31232	36	9C
0005432382830	31232	37	9D
0005432328279	31232	38	9E
0005432287142	31232	39	9F
0005432328267	31232	40	10A
0005432382812	31232	41	10C
0005432328300	31232	42	10D
0005432382841	31232	43	10E
0005432382810	31232	44	10F
0005432382817	31232	45	11A
0005432328297	31232	46	11C
0005432328286	31232	47	11D
0005432382836	31232	48	11E
0005432382804	31232	49	11F
0005432328291	31232	50	12C
0005432328278	31232	51	12A
0005432328302	31232	52	12D
0005432328280	31232	53	12E
0005432382837	31232	54	12F
0005432328293	31232	55	13A
0005432328276	31232	56	13C
0005432382823	31232	57	13D
0005432328304	31232	58	13E
0005432382840	31232	59	13F
0005432328272	31232	60	14A
0005432382806	31232	61	14C
0005432328273	31232	62	14D
0005432382814	31232	63	14E
0005432382839	31232	64	14F
0005432328269	31232	65	15A
0005432328299	31232	66	15D
0005432328295	31232	67	15C
0005432382809	31232	68	15E
0005432328271	31232	69	15F
0005432328306	31232	70	16A
0005432382819	31232	71	16C
0005432382833	31232	72	16D
0005432328294	31232	73	16E
0005432328312	31232	74	16F
0005432382842	31232	75	17C
0005432382832	31232	76	17D
0005432382829	31232	77	17E
0005432328296	31232	78	17F
0005432328305	31232	79	18A
0005432382835	31232	80	18C
0005432328311	31232	81	18D
0005432328288	31232	82	18E
0005432328281	31232	83	18F
0005432328283	31232	84	19A
0005432328289	31232	85	19C
0005432382826	31232	86	19D
0005432287141	31232	87	19E
0005432328309	31232	88	19F
0005432382824	31232	89	20A
0005432382825	31232	90	20C
0005432382816	31232	91	20E
0005432328301	31232	92	20F
0005433642224	2487	1	1A
0005433642216	2487	2	1C
0005433642215	2487	3	4A
0005433642214	2487	4	4D
0005433642228	2487	5	5A
0005433642209	2487	6	5D
0005432953790	2487	7	6D
0005433642199	2487	8	6E
0005433642207	2487	9	6F
0005433642202	2487	10	7C
0005433642208	2487	11	8C
0005433642203	2487	12	8F
0005433642220	2487	13	9C
0005433642204	2487	14	9F
0005433642198	2487	15	10A
0005432953805	2487	16	10C
0005433642211	2487	17	10D
0005432953803	2487	18	10E
0005433642210	2487	19	11A
0005433642222	2487	20	11D
0005433642227	2487	21	11E
0005433642200	2487	22	12F
0005433642205	2487	23	13E
0005433642223	2487	24	14A
0005433642226	2487	25	14C
0005433642196	2487	26	15A
0005433642197	2487	27	15C
0005433642225	2487	28	15E
0005433642206	2487	29	16D
0005433642212	2487	30	16F
0005433642213	2487	31	17C
0005433642221	2487	32	17D
0005433642217	2487	33	17F
0005432953804	2487	34	18A
0005432953786	2487	35	18E
0005433642218	2487	36	18F
0005433642219	2487	37	19A
0005433642201	2487	38	19D
0005432953797	2487	39	20C
0005432953848	27584	1	1A
0005432953870	27584	2	1D
0005433642097	27584	3	1F
0005432953857	27584	4	2F
0005433642081	27584	5	3D
0005433642129	27584	6	4D
0005432953867	27584	7	4E
0005432953850	27584	8	5C
0005433642130	27584	9	6D
0005433642125	27584	10	6F
0005432953866	27584	11	7F
0005432953858	27584	12	8A
0005433642085	27584	13	8C
0005432953864	27584	14	9A
0005432953854	27584	15	9D
0005432953849	27584	16	9F
0005432953852	27584	17	10D
0005432953846	27584	18	10F
0005433642073	27584	19	11A
0005432953871	27584	20	11C
0005433642114	27584	21	11D
0005432953855	27584	22	11F
0005432953860	27584	23	12C
0005433642105	27584	24	12F
0005432953861	27584	25	13A
0005433642115	27584	26	14A
0005432953859	27584	27	15A
0005433642098	27584	28	15D
0005432953869	27584	29	15E
0005432953872	27584	30	16C
0005433642077	27584	31	16F
0005432953862	27584	32	17A
0005432953856	27584	33	17C
0005433642112	27584	34	17D
0005433642076	27584	35	17E
0005433642086	27584	36	18A
0005432953865	27584	37	18C
0005432953853	27584	38	18D
0005432953851	27584	39	18F
0005432953863	27584	40	19F
0005432953847	27584	41	20C
0005432953868	27584	42	20D
0005433642113	27584	43	20E
0005433642111	27584	44	20F
0005432424025	13365	1	1A
0005432424024	13365	2	1D
0005432424001	13365	3	2A
0005432424044	13365	4	2C
0005432424052	13365	5	2D
0005432424048	13365	6	2F
0005432424050	13365	7	3A
0005432424000	13365	8	3C
0005432424006	13365	9	3D
0005432424034	13365	10	3F
0005432424005	13365	11	4A
0005432424011	13365	12	4E
0005432424043	13365	13	5C
0005432424054	13365	14	5D
0005432424016	13365	15	5F
0005432424038	13365	16	6A
0005432424009	13365	17	6C
0005432424046	13365	18	6E
0005432424055	13365	19	7C
0005432424027	13365	20	7F
0005432424049	13365	21	8A
0005432424031	13365	22	8C
0005432424035	13365	23	8D
0005432424017	13365	24	8F
0005432424022	13365	25	9C
0005432424002	13365	26	9E
0005432424013	13365	27	9F
0005432424014	13365	28	10D
0005432424003	13365	29	10E
0005432424045	13365	30	10F
0005432424018	13365	31	11A
0005432424041	13365	32	11F
0005432424023	13365	33	12A
0005432424037	13365	34	12C
0005432424019	13365	35	12D
0005432424030	13365	36	12E
0005432424039	13365	37	12F
0005432424056	13365	38	13A
0005432424032	13365	39	13C
0005432424008	13365	40	13D
0005432424012	13365	41	13E
0005432424036	13365	42	14C
0005432424020	13365	43	14D
0005432424021	13365	44	14E
0005432424004	13365	45	15A
0005432424026	13365	46	15D
0005432424015	13365	47	16A
0005432424057	13365	48	16C
0005432424007	13365	49	16D
0005432424033	13365	50	16E
0005432424028	13365	51	17D
0005432424040	13365	52	18D
0005432424042	13365	53	19C
0005432424029	13365	54	19E
0005432424010	13365	55	20C
0005432424047	13365	56	20D
0005432424053	13365	57	20E
0005432424051	13365	58	20F
0005432423615	30804	1	1A
0005432423664	30804	2	4A
0005432423620	30804	3	4E
0005432423665	30804	4	5F
0005432423645	30804	5	7D
0005432423646	30804	6	10A
0005432423604	30804	7	14A
0005432423635	30804	8	14E
0005432423606	30804	9	15E
0005432423640	30804	10	17A
0005432423616	30804	11	18E
0005432423654	30804	12	19A
0005432423644	30804	13	19F
0005432423619	30804	14	20D
0005434157349	9609	1	1C
0005432817232	9609	2	1D
0005434157348	9609	3	1F
0005432817213	9609	4	2A
0005434448288	9609	5	2D
0005432901336	9609	6	3C
0005434448289	9609	7	4A
0005432817226	9609	8	4C
0005432822139	9609	9	4E
0005432817233	9609	10	4F
0005432817235	9609	11	5A
0005432822137	9609	12	5D
0005432822138	9609	13	5F
0005432901428	9609	14	6C
0005432822142	9609	15	6D
0005434157359	9609	16	6E
0005432817225	9609	17	6F
0005432822136	9609	18	7A
0005432901345	9609	19	7C
0005432817239	9609	20	7F
0005434448287	9609	21	8A
0005432901329	9609	22	8D
0005434157356	9609	23	8F
0005432901318	9609	24	9D
0005432901427	9609	25	9E
0005432817228	9609	26	10A
0005432822140	9609	27	9F
0005432817231	9609	28	10C
0005432817224	9609	29	10E
0005432817222	9609	30	11A
0005432288960	9609	31	10F
0005432817212	9609	32	11C
0005432817237	9609	33	11D
0005434157350	9609	34	11E
0005434157368	9609	35	11F
0005432817217	9609	36	12A
0005432901326	9609	37	12C
0005432288959	9609	38	12D
0005432817240	9609	39	12F
0005434157386	9609	40	13A
0005432817215	9609	41	13C
0005432817236	9609	42	13D
0005432901378	9609	43	13F
0005432817227	9609	44	14A
0005432822135	9609	45	14C
0005432817214	9609	46	14D
0005432817219	9609	47	14F
0005432817220	9609	48	15A
0005432901354	9609	49	15D
0005432817223	9609	50	15E
0005432817218	9609	51	16A
0005432822141	9609	52	16C
0005432901297	9609	53	16D
0005432817229	9609	54	16E
0005432901303	9609	55	16F
0005432817216	9609	56	17A
0005432817230	9609	57	17E
0005432817234	9609	58	18A
0005434448285	9609	59	18F
0005432817238	9609	60	19C
0005432901304	9609	61	19E
0005434448286	9609	62	20C
0005432817221	9609	63	20D
0005432817020	29010	1	1F
0005432901471	29010	2	1D
0005432816988	29010	3	2A
0005432816966	29010	4	2C
0005432002060	29010	5	2D
0005432002058	29010	6	2F
0005432901467	29010	7	3C
0005432901469	29010	8	3D
0005432817049	29010	9	4C
0005434448258	29010	10	4D
0005432817008	29010	11	4E
0005432817048	29010	12	5A
0005432901459	29010	13	5C
0005432816987	29010	14	5E
0005432816945	29010	15	5F
0005434157415	29010	16	6C
0005432817021	29010	17	6F
0005432901455	29010	18	7A
0005434157417	29010	19	7C
0005432901460	29010	20	7E
0005434157412	29010	21	8A
0005432002059	29010	22	8D
0005432901472	29010	23	8E
0005432817010	29010	24	9A
0005434448262	29010	25	9D
0005434186172	29010	26	10C
0005432816989	29010	27	10F
0005432817043	29010	28	11A
0005432901464	29010	29	11D
0005432816990	29010	30	11E
0005432817014	29010	31	12A
0005432817052	29010	32	12D
0005434448264	29010	33	12E
0005432901462	29010	34	12F
0005434448263	29010	35	13C
0005432822070	29010	36	13E
0005432901466	29010	37	13F
0005432901470	29010	38	14A
0005432901468	29010	39	14C
0005432901456	29010	40	14D
0005432901463	29010	41	14E
0005432901457	29010	42	15D
0005432816980	29010	43	15F
0005432901458	29010	44	16C
0005432901461	29010	45	16D
0005432901465	29010	46	16F
0005432816977	29010	47	17C
0005434186174	29010	48	17D
0005432817015	29010	49	17E
0005434157414	29010	50	18A
0005434157413	29010	51	18C
0005434157416	29010	52	18E
0005434157418	29010	53	19C
0005434186173	29010	54	20D
0005432611679	15133	1	1A
0005432611678	15133	2	1B
0005432611677	15133	3	2A
0005432611676	15133	4	2B
0005432613828	15133	5	3A
0005432613829	15133	6	4A
0005432613827	15133	7	6A
0005432613830	15133	8	6B
0005432611646	31630	1	1A
0005432611644	31630	2	3B
0005432611651	31630	3	3A
0005432607497	31630	4	5A
0005432611649	31630	5	5B
0005432607498	31630	6	6A
0005432947783	11879	1	1C
0005433568511	11879	2	1A
0005433568533	11879	3	1D
0005433568493	11879	4	2C
0005433568538	11879	5	2A
0005432947840	11879	6	2F
0005433568504	11879	7	2D
0005433568534	11879	8	3D
0005432947793	11879	9	4C
0005433568529	11879	10	5A
0005433568491	11879	11	4F
0005433568535	11879	12	5C
0005433568516	11879	13	5D
0005433568536	11879	14	6A
0005433568539	11879	15	6D
0005433568507	11879	16	6C
0005433568505	11879	17	6F
0005433568495	11879	18	6E
0005433568503	11879	19	7A
0005433568515	11879	20	7B
0005433568524	11879	21	7F
0005433568520	11879	22	8B
0005433568523	11879	23	8D
0005433568519	11879	24	9A
0005433568506	11879	25	8F
0005433568518	11879	26	8E
0005432947864	11879	27	9C
0005433568492	11879	28	9F
0005433568489	11879	29	10B
0005433568541	11879	30	10D
0005433568531	11879	31	10F
0005433568484	11879	32	11B
0005433568490	11879	33	11D
0005433568514	11879	34	12B
0005432947784	11879	35	12A
0005433568509	11879	36	12C
0005433568478	11879	37	12E
0005433568521	11879	38	13A
0005433568502	11879	39	12F
0005433568522	11879	40	13C
0005433568494	11879	41	13B
0005433568513	11879	42	13E
0005433568517	11879	43	13D
0005433568526	11879	44	14A
0005433568480	11879	45	14C
0005433568540	11879	46	14B
0005432947769	11879	47	14F
0005433568537	11879	48	15B
0005433568527	11879	49	15D
0005433568486	11879	50	15C
0005433568496	11879	51	15E
0005433568479	11879	52	15F
0005433568497	11879	53	16C
0005433568510	11879	54	16B
0005433568543	11879	55	16E
0005433568500	11879	56	16F
0005433568528	11879	57	17B
0005433568512	11879	58	17D
0005433568532	11879	59	17C
0005432947794	11879	60	17E
0005433568508	11879	61	18B
0005432947865	11879	62	18D
0005433568481	11879	63	18C
0005433568498	11879	64	18E
0005433568499	11879	65	18F
0005433568530	11879	66	19B
0005433568501	11879	67	19F
0005433568525	11879	68	19E
0005433568483	11879	69	20A
0005433568482	11879	70	20E
0005433568485	11879	71	21C
0005433568542	11879	72	21B
0005433568487	11879	73	21D
0005433568488	11879	74	21F
0005432948176	25305	1	1A
0005432948180	25305	2	2A
0005432948155	25305	3	2D
0005432948179	25305	4	3D
0005432948170	25305	5	4A
0005432948140	25305	6	4D
0005433568119	25305	7	5F
0005433568022	25305	8	5D
0005432948167	25305	9	6A
0005433568084	25305	10	6F
0005433568064	25305	11	7C
0005432948160	25305	12	7D
0005433568050	25305	13	7F
0005433568024	25305	14	8B
0005433568042	25305	15	8D
0005432948173	25305	16	8C
0005433568025	25305	17	8F
0005432948163	25305	18	8E
0005432948172	25305	19	9A
0005433568113	25305	20	9F
0005433568118	25305	21	10B
0005432948147	25305	22	10C
0005432948157	25305	23	10E
0005432948143	25305	24	11B
0005432948154	25305	25	11E
0005432948149	25305	26	11F
0005433568112	25305	27	12C
0005432948177	25305	28	12E
0005432948146	25305	29	13A
0005432948178	25305	30	13C
0005433568038	25305	31	13B
0005433568021	25305	32	13D
0005432948169	25305	33	14A
0005432948175	25305	34	13F
0005432948142	25305	35	14E
0005432948161	25305	36	14D
0005432948164	25305	37	15B
0005432948153	25305	38	15A
0005432948158	25305	39	15C
0005433568086	25305	40	15E
0005432948165	25305	41	16A
0005433568052	25305	42	15F
0005433568039	25305	43	16B
0005432948141	25305	44	16D
0005432948168	25305	45	16C
0005433568017	25305	46	17A
0005432948156	25305	47	17B
0005432948139	25305	48	17D
0005432948145	25305	49	17C
0005432948144	25305	50	18B
0005432948152	25305	51	18A
0005432948150	25305	52	18C
0005432948159	25305	53	18E
0005433568102	25305	54	19A
0005432948162	25305	55	19C
0005432948148	25305	56	19F
0005433568069	25305	57	19E
0005433568026	25305	58	20C
0005432948171	25305	59	20B
0005432948166	25305	60	20A
0005433568049	25305	61	20D
0005432948151	25305	62	21C
0005432948174	25305	63	21E
0005435339989	5371	1	1A
0005435340019	5371	2	2A
0005434656538	5371	3	2C
0005434654455	5371	4	2D
0005434654451	5371	5	2F
0005435339991	5371	6	3C
0005434654447	5371	7	3D
0005434656540	5371	8	3F
0005435340003	5371	9	4A
0005434654439	5371	10	4F
0005435340005	5371	11	5C
0005434654442	5371	12	5E
0005434654449	5371	13	5F
0005434654436	5371	14	6A
0005435340006	5371	15	6D
0005435340024	5371	16	6C
0005434654453	5371	17	6E
0005434654430	5371	18	7A
0005435339990	5371	19	7C
0005435339996	5371	20	7D
0005435555336	5371	21	7E
0005434654438	5371	22	7F
0005435340001	5371	23	8C
0005434654445	5371	24	10C
0005434656539	5371	25	10E
0005432114176	5371	26	10F
0005434654452	5371	27	11C
0005435340018	5371	28	11D
0005434654441	5371	29	11E
0005434654454	5371	30	11F
0005434654434	5371	31	12D
0005434654444	5371	32	12E
0005434654459	5371	33	12F
0005434654450	5371	34	13A
0005432114175	5371	35	13D
0005434654433	5371	36	14A
0005432114177	5371	37	14D
0005434654443	5371	38	14F
0005434654458	5371	39	15A
0005434654460	5371	40	15C
0005434654435	5371	41	15F
0005434654429	5371	42	16A
0005435339997	5371	43	16C
0005434654446	5371	44	16D
0005434654432	5371	45	16F
0005435555337	5371	46	17C
0005434654431	5371	47	18F
0005434654437	5371	48	19A
0005434654457	5371	49	19C
0005434654448	5371	50	19E
0005435339992	5371	51	19F
0005434654456	5371	52	20C
0005434654440	5371	53	20D
0005435340002	5371	54	20F
0005434654220	12542	1	1A
0005434654215	12542	2	2A
0005435340141	12542	3	2D
0005434654169	12542	4	3A
0005434656522	12542	5	4A
0005434654238	12542	6	4E
0005434654190	12542	7	5D
0005435340135	12542	8	6C
0005435340130	12542	9	6E
0005435340132	12542	10	7C
0005434654219	12542	11	7D
0005434654196	12542	12	7E
0005434654265	12542	13	8A
0005434654195	12542	14	8C
0005434654362	12542	15	8D
0005434654182	12542	16	8F
0005434654229	12542	17	10A
0005434654201	12542	18	10C
0005434654281	12542	19	10E
0005435340133	12542	20	10F
0005434654264	12542	21	11A
0005435340140	12542	22	11C
0005435340131	12542	23	11D
0005434654170	12542	24	11E
0005434654261	12542	25	12E
0005434654166	12542	26	12F
0005435340139	12542	27	13A
0005435340134	12542	28	13D
0005434654235	12542	29	13F
0005434654263	12542	30	14A
0005434654363	12542	31	14C
0005435340129	12542	32	14E
0005435340143	12542	33	14F
0005434654233	12542	34	15C
0005434656525	12542	35	15E
0005435340136	12542	36	16A
0005434656529	12542	37	16D
0005434654171	12542	38	16F
0005435340137	12542	39	17C
0005435340138	12542	40	17F
0005435555355	12542	41	19A
0005434654262	12542	42	19E
0005435340142	12542	43	19F
0005435555354	12542	44	20C
0005434654276	12542	45	20E
0005433719112	7468	1	2C
0005433722163	7468	2	2A
0005433715542	7468	3	2D
0005433715556	7468	4	2F
0005433715574	7468	5	3A
0005433715555	7468	6	3D
0005433715567	7468	7	3C
0005433715573	7468	8	4A
0005433715575	7468	9	4C
0005433656641	7468	10	4B
0005433715537	7468	11	4D
0005433722165	7468	12	4E
0005432428872	7468	13	5C
0005433715562	7468	14	5B
0005433715548	7468	15	5E
0005433722160	7468	16	5F
0005433715534	7468	17	6B
0005433722162	7468	18	6A
0005433715531	7468	19	6C
0005433715533	7468	20	6D
0005433715564	7468	21	6F
0005433715572	7468	22	7B
0005433719108	7468	23	7D
0005433715551	7468	24	7E
0005433690907	7468	25	8A
0005433722158	7468	26	8B
0005432428868	7468	27	8F
0005433715563	7468	28	8E
0005433715571	7468	29	9B
0005433719111	7468	30	9C
0005433689892	7468	31	9D
0005433715535	7468	32	9E
0005433715549	7468	33	10D
0005433656638	7468	34	10E
0005433715527	7468	35	11B
0005433715530	7468	36	11C
0005433689891	7468	37	11D
0005433715532	7468	38	12B
0005433719110	7468	39	12E
0005433715529	7468	40	12F
0005432078060	7468	41	13B
0005433688790	7468	42	13D
0005433715553	7468	43	13E
0005433715543	7468	44	13F
0005433715545	7468	45	14A
0005432078059	7468	46	14B
0005433656640	7468	47	14C
0005433715559	7468	48	14E
0005433715539	7468	49	15A
0005433656639	7468	50	15C
0005433722159	7468	51	15B
0005433715568	7468	52	15D
0005433715557	7468	53	15E
0005433715552	7468	54	16A
0005433690908	7468	55	16C
0005433715570	7468	56	16B
0005433715569	7468	57	16D
0005433715544	7468	58	16F
0005433722164	7468	59	17B
0005433715561	7468	60	17C
0005432078062	7468	61	17F
0005432078061	7468	62	18B
0005433715565	7468	63	18A
0005433688791	7468	64	18E
0005433715536	7468	65	18F
0005433715560	7468	66	19A
0005433715566	7468	67	19B
0005433715540	7468	68	19D
0005433715546	7468	69	19F
0005433715576	7468	70	20A
0005433722166	7468	71	20B
0005433715558	7468	72	20D
0005433722161	7468	73	20F
0005433715550	7468	74	21D
0005432078064	7468	75	21E
0005433719109	7468	76	21F
0005433715554	7468	77	22B
0005432428873	7468	78	22A
0005433715541	7468	79	22C
0005432078063	7468	80	23B
0005433715528	7468	81	23D
0005433715547	7468	82	23F
0005433715538	7468	83	23E
0005433715164	29203	1	1A
0005433719080	29203	2	2A
0005433715123	29203	3	2C
0005433715270	29203	4	3D
0005433715336	29203	5	4B
0005433715113	29203	6	4C
0005433715217	29203	7	4F
0005433715171	29203	8	5B
0005435266117	29203	9	5A
0005433715079	29203	10	6B
0005433719083	29203	11	6A
0005433715189	29203	12	6E
0005433715153	29203	13	7A
0005432428900	29203	14	7D
0005433719081	29203	15	8B
0005433715269	29203	16	9A
0005433715197	29203	17	9C
0005433715111	29203	18	9F
0005433715181	29203	19	10D
0005433715158	29203	20	11B
0005432428901	29203	21	11D
0005433715154	29203	22	12C
0005433688776	29203	23	13B
0005433715227	29203	24	13D
0005433715204	29203	25	14A
0005433715240	29203	26	14E
0005432428899	29203	27	15C
0005433715114	29203	28	15F
0005433715092	29203	29	15E
0005433715133	29203	30	16A
0005433715190	29203	31	16D
0005432006737	29203	32	17C
0005433715335	29203	33	18D
0005433715271	29203	34	18E
0005433715163	29203	35	19A
0005433715124	29203	36	19B
0005433715160	29203	37	19E
0005433715086	29203	38	20B
0005433715196	29203	39	20A
0005433715182	29203	40	20E
0005433715152	29203	41	21B
0005433715183	29203	42	21A
0005433715084	29203	43	21C
0005433715172	29203	44	21D
0005432006738	29203	45	22A
0005433715203	29203	46	23B
0005433715115	29203	47	23E
0005434095148	8663	1	1F
0005434182037	8663	2	4A
0005434182011	8663	3	4C
0005434095153	8663	4	4D
0005434095157	8663	5	4E
0005434095160	8663	6	4F
0005434182002	8663	7	5D
0005434181977	8663	8	6A
0005434095150	8663	9	6C
0005434095158	8663	10	6F
0005434095159	8663	11	7D
0005434143712	8663	12	7E
0005434143714	8663	13	7F
0005434143708	8663	14	8C
0005434095152	8663	15	9D
0005434182000	8663	16	9F
0005434143711	8663	17	10F
0005434181980	8663	18	11D
0005434143713	8663	19	11F
0005434095155	8663	20	12E
0005434095149	8663	21	13A
0005434182029	8663	22	13F
0005434181979	8663	23	14D
0005434095151	8663	24	15A
0005434182006	8663	25	15C
0005434143706	8663	26	15D
0005434095162	8663	27	16F
0005434095156	8663	28	17C
0005434095161	8663	29	17D
0005434095154	8663	30	17E
0005434181992	8663	31	18C
0005434143709	8663	32	18E
0005434143707	8663	33	18F
0005434143710	8663	34	19A
0005434181993	8663	35	20F
0005434095098	11681	1	1A
0005434182073	11681	2	1C
0005434095062	11681	3	1D
0005434182077	11681	4	3A
0005434184646	11681	5	4C
0005434095016	11681	6	4D
0005434095061	11681	7	5D
0005434182083	11681	8	5E
0005434095019	11681	9	6C
0005434182079	11681	10	8C
0005434095029	11681	11	9C
0005434095015	11681	12	9D
0005434182075	11681	13	10E
0005434182084	11681	14	11C
0005434182081	11681	15	13D
0005434182074	11681	16	14A
0005434095022	11681	17	14C
0005434183562	11681	18	14F
0005434183561	11681	19	15E
0005434095068	11681	20	15F
0005434182078	11681	21	16A
0005434095069	11681	22	17D
0005434095077	11681	23	17E
0005434182072	11681	24	18C
0005434184645	11681	25	18D
0005434095063	11681	26	18F
0005434182076	11681	27	19A
0005434095078	11681	28	19C
0005434182082	11681	29	19E
0005434183560	11681	30	20A
0005434182080	11681	31	20D
0005434095021	11681	32	20F
0005433397269	1435	1	1D
0005433397244	1435	2	1F
0005433397366	1435	3	2C
0005432906495	1435	4	2D
0005433397317	1435	5	2F
0005433397318	1435	6	4D
0005433397397	1435	7	4E
0005433397443	1435	8	4F
0005435732227	1435	9	5A
0005433397262	1435	10	5C
0005433456936	1435	11	5E
0005433397276	1435	12	6E
0005433456933	1435	13	7D
0005433397299	1435	14	7F
0005433397266	1435	15	8A
0005433397263	1435	16	8C
0005435732231	1435	17	9D
0005433397265	1435	18	10E
0005432297255	1435	19	10F
0005433456934	1435	20	11C
0005435732229	1435	21	11D
0005433397307	1435	22	11E
0005435732232	1435	23	11F
0005435732230	1435	24	12C
0005433397204	1435	25	12E
0005433397248	1435	26	13C
0005435732228	1435	27	13E
0005433397264	1435	28	13F
0005433397298	1435	29	14A
0005433397396	1435	30	14C
0005433397214	1435	31	14D
0005433397270	1435	32	14F
0005433397275	1435	33	15D
0005433397337	1435	34	15E
0005432297256	1435	35	16A
0005433397361	1435	36	16C
0005433456935	1435	37	16D
0005435732226	1435	38	17E
0005432297254	1435	39	18A
0005433397304	1435	40	18C
0005433397274	1435	41	18E
0005433397305	1435	42	18F
0005433397306	1435	43	19A
0005433397313	1435	44	19C
0005433397215	1435	45	19F
0005433397456	1435	46	20D
0005433397213	1435	47	20F
0005433397648	19239	1	1A
0005433456913	19239	2	1C
0005433397662	19239	3	2A
0005433397647	19239	4	2C
0005433397641	19239	5	2F
0005433397674	19239	6	3A
0005433397634	19239	7	3F
0005433397669	19239	8	4F
0005435732141	19239	9	5C
0005433397671	19239	10	5D
0005433456912	19239	11	5E
0005433397628	19239	12	5F
0005435732150	19239	13	6C
0005433397627	19239	14	6F
0005433397666	19239	15	7A
0005433397640	19239	16	7C
0005433397643	19239	17	8A
0005433397668	19239	18	8D
0005433397644	19239	19	8E
0005433397659	19239	20	9A
0005433397664	19239	21	9E
0005435732151	19239	22	10C
0005433397663	19239	23	10D
0005433397675	19239	24	10F
0005433397661	19239	25	11A
0005435732121	19239	26	11C
0005433397649	19239	27	11E
0005433397651	19239	28	12A
0005433397657	19239	29	12C
0005433397636	19239	30	12D
0005433397639	19239	31	12E
0005433397630	19239	32	13D
0005433397650	19239	33	13E
0005433397632	19239	34	14D
0005433397667	19239	35	14E
0005433397656	19239	36	15A
0005433397654	19239	37	15D
0005433397670	19239	38	15E
0005433397637	19239	39	16A
0005435732126	19239	40	15F
0005433397655	19239	41	16C
0005433397633	19239	42	16D
0005433397635	19239	43	16F
0005433397629	19239	44	17A
0005435732120	19239	45	17D
0005433397672	19239	46	17E
0005433397638	19239	47	18A
0005435732122	19239	48	18C
0005433397646	19239	49	18D
0005433397645	19239	50	18F
0005435732142	19239	51	18E
0005433397653	19239	52	19A
0005433397660	19239	53	19C
0005433397631	19239	54	19D
0005433397642	19239	55	19E
0005433397673	19239	56	19F
0005433397658	19239	57	20D
0005433397665	19239	58	20E
0005433397652	19239	59	20F
0005434443460	17389	1	2C
0005434443425	17389	2	3B
0005434443446	17389	3	4B
0005434443497	17389	4	5C
0005434443452	17389	5	6A
0005434443504	17389	6	6B
0005434443479	17389	7	6D
0005434443459	17389	8	20D
0005434443438	17389	9	21B
0005434443478	17389	10	22C
0005434443565	20580	1	3C
0005434443566	20580	2	3B
0005434443562	20580	3	4C
0005434443567	20580	4	5B
0005434443556	20580	5	5C
0005434443561	20580	6	6C
0005434443559	20580	7	6D
0005434443557	20580	8	7D
0005434443558	20580	9	18B
0005434443570	20580	10	18D
0005434443568	20580	11	19C
0005434443560	20580	12	20A
0005434443564	20580	13	19D
0005434443571	20580	14	20B
0005434443569	20580	15	21A
0005434443563	20580	16	22D
0005434954575	7280	1	1B
0005435377546	7280	2	2A
0005434954577	7280	3	3A
0005434954574	7280	4	3B
0005434954576	7280	5	4B
0005434954539	28341	1	2B
0005434954541	28341	2	3B
0005434954538	28341	3	4A
0005434954537	28341	4	5A
0005434954566	28341	5	5B
0005434351590	4496	1	1A
0005434351585	4496	2	2A
0005434351587	4496	3	2C
0005434351582	4496	4	2D
0005435893531	4496	5	3C
0005434351591	4496	6	6A
0005435893532	4496	7	7B
0005434351583	4496	8	18A
0005435893511	4496	9	18C
0005435893547	4496	10	18D
0005434351584	4496	11	19A
0005434351592	4496	12	19C
0005434351588	4496	13	20C
0005435893530	4496	14	20D
0005434351594	4496	15	21A
0005434351589	4496	16	21C
0005434351586	4496	17	22A
0005434351593	4496	18	22B
0005434351463	29633	1	1A
0005435893572	29633	2	1D
0005434351495	29633	3	3C
0005434351505	29633	4	3D
0005435893574	29633	5	4A
0005434351491	29633	6	4B
0005434351481	29633	7	5A
0005434351487	29633	8	5C
0005434351467	29633	9	7A
0005434351493	29633	10	7D
0005434351504	29633	11	20A
0005435893571	29633	12	20C
0005435893570	29633	13	21C
0005435893569	29633	14	21D
0005434351486	29633	15	22A
0005435893573	29633	16	23A
0005435545664	1066	1	1B
0005433341532	1066	2	1H
0005435091994	1066	3	1G
0005435545661	1066	4	2A
0005432293188	1066	5	2B
0005433463882	1066	6	2F
0005433341703	1066	7	2C
0005433341704	1066	8	3B
0005435091984	1066	9	3C
0005434445229	1066	10	3H
0005435545668	1066	11	5B
0005433269632	1066	12	5A
0005433341415	1066	13	5C
0005435091993	1066	14	5F
0005433341425	1066	15	5H
0005433341854	1066	16	5G
0005433341635	1066	17	9A
0005433341477	1066	18	9H
0005433341400	1066	19	9G
0005434445227	1066	20	12A
0005432293186	1066	21	12F
0005435091991	1066	22	12H
0005434446502	1066	23	13G
0005435545665	1066	24	14B
0005433269647	1066	25	14G
0005435545659	1066	26	15A
0005433341500	1066	27	15E
0005433341429	1066	28	15D
0005435545656	1066	29	15H
0005435091987	1066	30	16E
0005435545657	1066	31	16D
0005435545662	1066	32	16G
0005433341620	1066	33	17A
0005433341853	1066	34	18A
0005435545669	1066	35	17H
0005433463881	1066	36	18G
0005433341607	1066	37	18H
0005433341836	1066	38	19F
0005433341461	1066	39	19E
0005433341734	1066	40	20B
0005433341428	1066	41	20H
0005434445226	1066	42	21B
0005435545658	1066	43	21G
0005434446503	1066	44	22B
0005435091986	1066	45	22E
0005433341671	1066	46	23B
0005435091992	1066	47	23A
0005433462729	1066	48	23D
0005435091995	1066	49	23F
0005433341488	1066	50	23E
0005433341382	1066	51	24A
0005435091989	1066	52	24D
0005433463883	1066	53	24E
0005433341402	1066	54	24G
0005434445228	1066	55	25D
0005433341486	1066	56	24H
0005433341449	1066	57	25F
0005435545660	1066	58	25E
0005435091985	1066	59	27A
0005433341815	1066	60	27D
0005433341835	1066	61	27F
0005433341641	1066	62	27G
0005433341595	1066	63	28A
0005433159282	1066	64	28F
0005434446501	1066	65	29D
0005433462728	1066	66	29E
0005435545670	1066	67	29G
0005433341669	1066	68	30D
0005433341667	1066	69	30F
0005432293187	1066	70	30E
0005433341412	1066	71	31E
0005433269635	1066	72	31H
0005435545666	1066	73	31G
0005435545663	1066	74	32F
0005433341417	1066	75	32H
0005435545655	1066	76	34D
0005433341603	1066	77	34F
0005433341649	1066	78	34E
0005433341738	1066	79	35B
0005433341561	1066	80	35F
0005435091988	1066	81	35G
0005435545667	1066	82	36A
0005433341650	1066	83	36G
0005433341683	1066	84	36H
0005435091990	1066	85	37E
0005433341586	1066	86	37G
0005433341383	1066	87	37F
0005433341424	1066	88	37H
0005433341601	1066	89	38A
0005435545671	1066	90	38B
0005433341448	1066	91	38E
0005433341505	1066	92	38G
0005433341587	1066	93	38F
0005433341391	1066	94	39D
0005433341462	1066	95	39E
0005433342271	17053	1	1A
0005433342281	17053	2	1C
0005433342259	17053	3	2A
0005433159294	17053	4	2C
0005433342251	17053	5	2G
0005433342248	17053	6	3F
0005433342220	17053	7	3C
0005433342290	17053	8	4B
0005433159293	17053	9	4A
0005433342213	17053	10	4C
0005433342215	17053	11	4G
0005433342232	17053	12	4H
0005433342252	17053	13	5C
0005433342247	17053	14	5F
0005433342235	17053	15	5H
0005433342211	17053	16	9G
0005433269674	17053	17	9B
0005433342287	17053	18	11A
0005433342258	17053	19	11B
0005433342280	17053	20	11E
0005435508171	17053	21	11F
0005433342192	17053	22	11H
0005433342218	17053	23	11G
0005433342240	17053	24	12A
0005433342286	17053	25	12G
0005433342243	17053	26	13A
0005433342223	17053	27	13B
0005433342279	17053	28	13E
0005433342198	17053	29	13G
0005433342264	17053	30	13H
0005433342250	17053	31	14A
0005433159295	17053	32	14E
0005433342217	17053	33	14D
0005433342245	17053	34	14F
0005433342212	17053	35	15D
0005433342269	17053	36	15B
0005433342292	17053	37	15F
0005435091935	17053	38	15H
0005433342200	17053	39	16A
0005433342277	17053	40	16B
0005433342261	17053	41	16F
0005433342209	17053	42	17A
0005433342262	17053	43	17D
0005433342273	17053	44	17G
0005433342204	17053	45	18A
0005433342268	17053	46	18E
0005433342266	17053	47	18D
0005433342256	17053	48	18B
0005433342195	17053	49	18F
0005433342278	17053	50	19E
0005433342205	17053	51	19D
0005433342203	17053	52	19F
0005433342234	17053	53	19G
0005433342265	17053	54	19H
0005433342257	17053	55	20B
0005435508173	17053	56	20E
0005433342249	17053	57	20D
0005433159292	17053	58	20F
0005435091929	17053	59	21E
0005433342202	17053	60	21D
0005433342210	17053	61	21F
0005433342197	17053	62	21H
0005433342272	17053	63	22A
0005433342199	17053	64	22B
0005433342233	17053	65	22E
0005433342283	17053	66	22G
0005433342242	17053	67	22F
0005433269672	17053	68	23A
0005433342288	17053	69	23B
0005433342208	17053	70	23F
0005433342228	17053	71	24A
0005433342246	17053	72	23H
0005433342291	17053	73	24B
0005433342206	17053	74	24F
0005433342230	17053	75	24G
0005433342253	17053	76	25F
0005433342225	17053	77	27B
0005433342229	17053	78	27F
0005435508167	17053	79	28B
0005435091946	17053	80	28D
0005433342274	17053	81	28F
0005433342270	17053	82	28E
0005433269671	17053	83	29A
0005433342221	17053	84	29E
0005433342236	17053	85	29D
0005433342293	17053	86	29F
0005433342239	17053	87	30B
0005433342244	17053	88	30F
0005433342207	17053	89	30H
0005433342193	17053	90	30G
0005433342284	17053	91	31A
0005433342241	17053	92	31B
0005433342214	17053	93	31D
0005433342267	17053	94	31G
0005433342219	17053	95	32A
0005433342238	17053	96	32B
0005433342237	17053	97	32E
0005435508174	17053	98	32D
0005435091905	17053	99	32F
0005433342276	17053	100	32G
0005433342226	17053	101	33A
0005433342260	17053	102	33B
0005433342231	17053	103	33E
0005433342222	17053	104	33F
0005433342263	17053	105	34A
0005435508165	17053	106	34D
0005433342275	17053	107	34E
0005433342285	17053	108	34F
0005433342194	17053	109	34H
0005433342224	17053	110	35F
0005433342227	17053	111	35G
0005435508170	17053	112	36B
0005433342216	17053	113	36A
0005433342196	17053	114	36D
0005435091945	17053	115	37D
0005433269673	17053	116	37B
0005433342289	17053	117	37G
0005433342282	17053	118	37F
0005433342254	17053	119	38D
0005433342201	17053	120	38B
0005435091936	17053	121	38F
0005433342255	17053	122	39F
0005432390036	1344	1	1F
0005432851830	1344	2	1C
0005432390051	1344	3	2D
0005432390032	1344	4	3C
0005432390038	1344	5	3F
0005432851833	1344	6	4D
0005432390030	1344	7	5C
0005432390022	1344	8	5A
0005432391965	1344	9	6B
0005432851831	1344	10	6A
0005432391968	1344	11	6C
0005432390048	1344	12	6E
0005432391969	1344	13	7A
0005432851832	1344	14	7C
0005432390027	1344	15	7B
0005432390039	1344	16	7D
0005432391966	1344	17	8A
0005432390050	1344	18	7F
0005432390044	1344	19	8B
0005432851817	1344	20	8E
0005432390031	1344	21	8F
0005432390026	1344	22	9B
0005432390016	1344	23	9C
0005432390049	1344	24	10D
0005432390021	1344	25	10F
0005432390034	1344	26	11B
0005432390025	1344	27	11A
0005432390024	1344	28	11C
0005432390017	1344	29	12A
0005432390018	1344	30	12D
0005432390037	1344	31	12C
0005432390040	1344	32	13B
0005432391967	1344	33	14C
0005432851818	1344	34	14D
0005432390020	1344	35	14F
0005432391971	1344	36	15A
0005432391970	1344	37	15C
0005432390046	1344	38	15E
0005432851834	1344	39	16E
0005432390047	1344	40	17B
0005432390033	1344	41	17D
0005432390028	1344	42	17C
0005432390042	1344	43	17F
0005432390023	1344	44	17E
0005432391972	1344	45	18A
0005432390019	1344	46	18D
0005432851815	1344	47	19A
0005432390041	1344	48	19D
0005432390035	1344	49	20B
0005432390043	1344	50	20C
0005432390029	1344	51	21F
0005432390045	1344	52	21E
0005434081481	12820	1	1A
0005434066295	12820	2	1F
0005432433635	12820	3	2C
0005434081503	12820	4	2F
0005434066468	12820	5	2D
0005433989689	12820	6	3D
0005434066340	12820	7	4B
0005434081494	12820	8	4A
0005434066504	12820	9	4C
0005434066491	12820	10	4E
0005434081473	12820	11	5A
0005434066368	12820	12	4F
0005434066303	12820	13	5B
0005432161132	12820	14	5D
0005434081513	12820	15	5C
0005434066413	12820	16	5F
0005434081514	12820	17	6C
0005432159818	12820	18	6D
0005434066579	12820	19	7B
0005434066309	12820	20	7C
0005434066450	12820	21	7D
0005432433632	12820	22	8A
0005434081507	12820	23	8E
0005432159819	12820	24	9D
0005434066341	12820	25	9C
0005434066449	12820	26	9E
0005434066430	12820	27	9F
0005434066387	12820	28	10D
0005434066388	12820	29	10C
0005434081493	12820	30	10E
0005434081506	12820	31	11B
0005434081535	12820	32	11C
0005434081472	12820	33	11D
0005434081521	12820	34	11F
0005434066410	12820	35	12A
0005434066438	12820	36	12C
0005434066369	12820	37	13B
0005434081492	12820	38	13E
0005432433636	12820	39	13F
0005434081478	12820	40	14B
0005432161133	12820	41	14A
0005434066653	12820	42	14D
0005433989709	12820	43	15A
0005434081483	12820	44	15C
0005434066411	12820	45	15B
0005432433633	12820	46	15D
0005434066320	12820	47	15E
0005434066761	12820	48	16A
0005434066503	12820	49	16B
0005434066432	12820	50	16E
0005434081479	12820	51	16F
0005434066342	12820	52	17B
0005434066352	12820	53	17C
0005433989702	12820	54	17D
0005434081505	12820	55	17E
0005434066439	12820	56	18A
0005434066317	12820	57	17F
0005434066318	12820	58	18C
0005434066346	12820	59	18E
0005432433634	12820	60	19A
0005434066548	12820	61	19E
0005434066345	12820	62	20C
0005434081475	12820	63	20E
0005434081536	12820	64	20F
0005434081498	12820	65	21A
0005434066319	12820	66	21D
0005433989703	12820	67	22A
0005432159820	12820	68	22C
0005434066412	12820	69	22B
0005434081480	12820	70	22D
0005434081497	12820	71	23D
0005434066296	12820	72	23F
0005434066876	30645	1	1A
0005434081677	30645	2	1C
0005434081688	30645	3	1F
0005432433612	30645	4	2C
0005434066931	30645	5	2A
0005434066892	30645	6	2D
0005432433611	30645	7	2F
0005434066878	30645	8	3A
0005432150125	30645	9	3C
0005434066947	30645	10	4A
0005434066893	30645	11	4C
0005434066912	30645	12	4D
0005434081676	30645	13	4E
0005434066883	30645	14	4F
0005434066933	30645	15	5B
0005434081681	30645	16	5A
0005434081679	30645	17	5C
0005434066946	30645	18	5D
0005434066894	30645	19	5E
0005434066880	30645	20	5F
0005432150123	30645	21	6A
0005434066895	30645	22	6C
0005434066882	30645	23	6B
0005432433605	30645	24	6D
0005434066908	30645	25	6E
0005434081693	30645	26	6F
0005434066942	30645	27	7A
0005433989725	30645	28	7C
0005434066896	30645	29	7B
0005434081694	30645	30	7E
0005433989727	30645	31	7D
0005432186835	30645	32	7F
0005434066920	30645	33	8A
0005434066929	30645	34	8B
0005432186836	30645	35	8C
0005434066939	30645	36	8D
0005434066927	30645	37	8F
0005433989728	30645	38	8E
0005434066898	30645	39	9A
0005434066886	30645	40	9B
0005432433588	30645	41	9D
0005434081684	30645	42	9C
0005434066909	30645	43	9E
0005434081695	30645	44	9F
0005434066905	30645	45	10B
0005432186834	30645	46	10C
0005434066900	30645	47	11A
0005434066943	30645	48	10E
0005434066901	30645	49	11C
0005434066921	30645	50	11B
0005434066941	30645	51	11E
0005434066928	30645	52	11D
0005434066936	30645	53	11F
0005432150120	30645	54	12A
0005434066918	30645	55	12B
0005434066917	30645	56	12C
0005432150121	30645	57	12E
0005432433607	30645	58	12D
0005434066904	30645	59	12F
0005434081675	30645	60	13B
0005434066930	30645	61	13A
0005432150119	30645	62	13D
0005434066890	30645	63	13E
0005434081680	30645	64	14A
0005434066911	30645	65	14C
0005434081690	30645	66	14E
0005434081692	30645	67	14D
0005434066885	30645	68	14F
0005434066937	30645	69	15B
0005434081686	30645	70	15A
0005434066902	30645	71	15C
0005434066914	30645	72	15D
0005434066919	30645	73	15E
0005432150124	30645	74	16A
0005434081691	30645	75	15F
0005434066884	30645	76	16B
0005434066897	30645	77	16C
0005434081689	30645	78	16D
0005434081674	30645	79	16F
0005434066932	30645	80	16E
0005434066922	30645	81	17A
0005434081696	30645	82	17B
0005434066923	30645	83	17C
0005434081682	30645	84	17D
0005434066889	30645	85	17E
0005434066881	30645	86	18A
0005434066906	30645	87	17F
0005434066940	30645	88	18B
0005434066915	30645	89	18C
0005433989729	30645	90	18E
0005434066888	30645	91	18D
0005432433587	30645	92	19A
0005434066935	30645	93	18F
0005434066926	30645	94	19B
0005434066907	30645	95	19D
0005434081678	30645	96	19C
0005434066913	30645	97	19F
0005434066877	30645	98	20B
0005434081683	30645	99	20A
0005434081697	30645	100	20D
0005434066924	30645	101	20C
0005432150122	30645	102	20E
0005433989726	30645	103	20F
0005434066934	30645	104	21B
0005434066916	30645	105	21C
0005432433606	30645	106	21D
0005434066938	30645	107	21E
0005432150118	30645	108	22A
0005434066944	30645	109	21F
0005434066903	30645	110	22B
0005434066945	30645	111	22C
0005434066910	30645	112	22E
0005434066925	30645	113	22D
0005434081687	30645	114	22F
0005434066891	30645	115	23B
0005434066899	30645	116	23C
0005434066879	30645	117	23E
0005434081685	30645	118	23D
0005434066887	30645	119	23F
0005435461856	5497	1	1C
0005434264734	5497	2	1B
0005435765733	5497	3	1F
0005435720816	5497	4	2A
0005435461885	5497	5	2B
0005435765703	5497	6	2C
0005435461881	5497	7	2G
0005435765720	5497	8	3A
0005432140375	5497	9	3B
0005434264759	5497	10	3F
0005435765734	5497	11	3H
0005435765735	5497	12	4B
0005435461927	5497	13	4C
0005435765709	5497	14	4G
0005435765731	5497	15	5B
0005433529247	5497	16	5F
0005435765711	5497	17	9G
0005432140377	5497	18	11A
0005435765738	5497	19	11D
0005435461852	5497	20	11B
0005435765691	5497	21	11F
0005434264736	5497	22	12A
0005434264735	5497	23	12B
0005434264716	5497	24	12E
0005435765717	5497	25	12F
0005433529246	5497	26	12H
0005432140380	5497	27	12G
0005435461918	5497	28	13A
0005433527237	5497	29	13D
0005434264717	5497	30	13B
0005434264780	5497	31	13F
0005435735096	5497	32	13E
0005435461760	5497	33	13G
0005432535746	5497	34	14B
0005435765718	5497	35	14D
0005435725553	5497	36	14F
0005435765699	5497	37	15A
0005435722035	5497	38	14H
0005432140374	5497	39	15D
0005435765729	5497	40	15B
0005435765707	5497	41	15E
0005435723027	5497	42	15F
0005435735097	5497	43	15G
0005435765706	5497	44	16A
0005435765675	5497	45	16D
0005435720815	5497	46	16B
0005435765677	5497	47	16E
0005435765710	5497	48	16F
0005435765692	5497	49	17A
0005435765722	5497	50	17E
0005435765737	5497	51	17G
0005435765732	5497	52	17F
0005435765697	5497	53	17H
0005432140376	5497	54	18B
0005435765713	5497	55	18D
0005434264687	5497	56	18G
0005435765690	5497	57	18F
0005435735099	5497	58	18H
0005435461764	5497	59	19B
0005432140378	5497	60	19D
0005435461839	5497	61	19F
0005435723028	5497	62	19H
0005435461841	5497	63	19G
0005435765723	5497	64	20B
0005435461956	5497	65	20E
0005435765725	5497	66	20D
0005435461884	5497	67	20F
0005435765684	5497	68	20H
0005433527234	5497	69	20G
0005434264719	5497	70	21B
0005433527235	5497	71	21A
0005435765740	5497	72	21E
0005435461804	5497	73	21F
0005435765724	5497	74	21H
0005435765704	5497	75	22B
0005432140379	5497	76	22G
0005435461867	5497	77	22F
0005435765728	5497	78	22H
0005435765730	5497	79	23D
0005435765678	5497	80	23B
0005435765681	5497	81	23F
0005435765719	5497	82	23E
0005435765700	5497	83	23G
0005432535751	5497	84	23H
0005435765716	5497	85	24D
0005435461840	5497	86	24B
0005435765673	5497	87	24E
0005435765682	5497	88	24F
0005432140381	5497	89	24H
0005435725556	5497	90	27A
0005435765693	5497	91	27B
0005435765727	5497	92	27E
0005435765705	5497	93	27D
0005435765695	5497	94	27F
0005435765698	5497	95	27H
0005434264760	5497	96	28A
0005435765679	5497	97	28D
0005435765714	5497	98	28F
0005435725555	5497	99	28G
0005434264726	5497	100	29B
0005435725554	5497	101	29E
0005434264779	5497	102	29G
0005435461789	5497	103	29F
0005435765721	5497	104	29H
0005435461796	5497	105	30B
0005435765687	5497	106	30D
0005435765702	5497	107	30E
0005435765683	5497	108	30G
0005434831072	5497	109	31A
0005435765680	5497	110	30H
0005435765701	5497	111	31B
0005435461919	5497	112	31F
0005433529245	5497	113	31E
0005435765694	5497	114	31G
0005434831074	5497	115	32A
0005435765674	5497	116	31H
0005435723029	5497	117	32F
0005435765736	5497	118	32G
0005434264766	5497	119	33A
0005433527236	5497	120	33B
0005435461880	5497	121	33E
0005435765689	5497	122	33F
0005435461935	5497	123	34A
0005435461837	5497	124	34D
0005435722034	5497	125	34B
0005433527238	5497	126	34E
0005432535752	5497	127	34F
0005434264691	5497	128	34H
0005435765676	5497	129	35A
0005435461826	5497	130	35D
0005435765686	5497	131	35B
0005435765685	5497	132	35F
0005435461838	5497	133	35E
0005435765688	5497	134	35G
0005435765715	5497	135	35H
0005435765708	5497	136	36D
0005434264699	5497	137	36F
0005435461866	5497	138	36G
0005435765696	5497	139	37A
0005435461915	5497	140	37D
0005435765712	5497	141	37B
0005435461785	5497	142	37G
0005435461806	5497	143	37H
0005435765726	5497	144	38B
0005435735098	5497	145	38H
0005435765739	5497	146	38G
0005433529248	5497	147	39D
0005435765250	13472	1	1B
0005435765396	13472	2	2A
0005435765273	13472	3	2C
0005435462118	13472	4	2H
0005435765191	13472	5	2F
0005435765175	13472	6	3B
0005435462116	13472	7	3F
0005435765502	13472	8	3C
0005435462133	13472	9	4B
0005434264933	13472	10	4C
0005435765312	13472	11	5A
0005435765245	13472	12	4H
0005435765253	13472	13	5F
0005434264924	13472	14	5C
0005435765174	13472	15	5H
0005435462123	13472	16	9B
0005435462132	13472	17	9A
0005435765165	13472	18	9G
0005435765163	13472	19	11A
0005435723011	13472	20	11E
0005435765318	13472	21	11D
0005435462119	13472	22	11F
0005434264927	13472	23	11H
0005435765181	13472	24	11G
0005434264937	13472	25	12A
0005435765311	13472	26	12D
0005435765202	13472	27	12B
0005434264926	13472	28	12E
0005435462135	13472	29	13A
0005434264936	13472	30	13B
0005435462117	13472	31	13E
0005432535794	13472	32	13G
0005435765162	13472	33	13F
0005435765252	13472	34	13H
0005435765321	13472	35	14B
0005434264922	13472	36	14E
0005435462120	13472	37	14D
0005435765254	13472	38	14H
0005435735062	13472	39	15B
0005435765204	13472	40	15E
0005435462125	13472	41	15D
0005435765399	13472	42	15G
0005435462139	13472	43	15F
0005435765285	13472	44	15H
0005435462105	13472	45	16A
0005435735063	13472	46	16H
0005435765248	13472	47	17B
0005434264915	13472	48	17E
0005432194477	13472	49	17G
0005435765149	13472	50	17H
0005434264929	13472	51	18B
0005435462137	13472	52	18E
0005435765172	13472	53	18G
0005435462108	13472	54	18F
0005435723015	13472	55	18H
0005435462122	13472	56	19B
0005435462131	13472	57	19D
0005435462134	13472	58	19E
0005434264935	13472	59	19G
0005435462111	13472	60	20B
0005435735066	13472	61	20E
0005435462106	13472	62	20D
0005432194474	13472	63	20G
0005434264919	13472	64	20F
0005435765316	13472	65	21B
0005434831111	13472	66	21A
0005435462104	13472	67	21D
0005434264934	13472	68	21E
0005434264938	13472	69	21F
0005435765317	13472	70	21H
0005434264917	13472	71	22B
0005435462121	13472	72	22D
0005432194475	13472	73	22E
0005434264921	13472	74	22F
0005435765310	13472	75	23A
0005435765323	13472	76	23E
0005435765304	13472	77	23F
0005435462107	13472	78	24A
0005435462130	13472	79	24D
0005434264925	13472	80	24F
0005432535792	13472	81	24H
0005435765110	13472	82	24G
0005435725514	13472	83	25E
0005435462141	13472	84	27A
0005434264918	13472	85	25F
0005434831110	13472	86	27E
0005432535791	13472	87	27H
0005435765303	13472	88	27G
0005435462113	13472	89	28A
0005435462112	13472	90	28D
0005435462138	13472	91	28B
0005435462142	13472	92	28F
0005434264931	13472	93	28H
0005434264920	13472	94	28G
0005435765203	13472	95	29A
0005435462124	13472	96	29D
0005435765247	13472	97	29B
0005435765164	13472	98	29F
0005435462126	13472	99	30A
0005434831113	13472	100	30B
0005434264928	13472	101	30G
0005432194476	13472	102	31E
0005435462115	13472	103	31D
0005434831114	13472	104	31H
0005435735061	13472	105	31G
0005435462110	13472	106	32A
0005435765329	13472	107	32B
0005432535793	13472	108	32E
0005435765166	13472	109	32G
0005434831112	13472	110	32F
0005435765542	13472	111	32H
0005435765554	13472	112	33D
0005435462109	13472	113	33E
0005434264932	13472	114	33F
0005434264914	13472	115	34A
0005435462127	13472	116	34D
0005435765341	13472	117	34B
0005435765249	13472	118	34F
0005434264923	13472	119	34E
0005435765261	13472	120	34G
0005435462140	13472	121	35B
0005435765211	13472	122	35A
0005432194478	13472	123	35D
0005435462129	13472	124	35E
0005435462136	13472	125	35H
0005432535795	13472	126	35G
0005434264916	13472	127	36F
0005435765121	13472	128	36G
0005435765182	13472	129	37A
0005435765308	13472	130	36H
0005435735055	13472	131	37D
0005435725513	13472	132	37B
0005435765173	13472	133	37G
0005434264940	13472	134	37F
0005435462128	13472	135	38D
0005435722015	13472	136	38B
0005434264930	13472	137	38G
0005435462114	13472	138	38F
0005434264939	13472	139	39D
0005434602873	18663	1	1B
0005434602874	18663	2	4B
0005434602860	18663	3	5B
0005434513554	18659	1	1A
0005434514942	18659	2	1B
0005434513555	18659	3	2A
0005434604837	18659	4	4A
0005434513556	18659	5	5A
0005434514943	18659	6	6A
0005434514944	18659	7	6B
0005434514931	19223	1	2B
0005435846219	25082	1	5D
0005435846220	25082	2	7D
0005435846223	25082	3	9F
0005435846218	25082	4	11C
0005432649298	25082	5	11F
0005435846222	25082	6	13E
0005435846224	25082	7	13D
0005435846221	25082	8	17D
0005432649301	25082	9	18A
0005433007938	1826	1	1C
0005433007928	1826	2	1D
0005433007939	1826	3	2A
0005433007844	1826	4	2D
0005433008114	1826	5	2F
0005433284786	1826	6	3A
0005433007975	1826	7	3C
0005433007827	1826	8	3D
0005433007862	1826	9	3F
0005433008013	1826	10	4C
0005433284890	1826	11	5A
0005433007954	1826	12	5C
0005433284815	1826	13	5E
0005433284891	1826	14	5F
0005433007891	1826	15	6A
0005433284840	1826	16	6F
0005433008113	1826	17	7F
0005433284828	1826	18	8D
0005433284818	1826	19	8E
0005433008129	1826	20	9D
0005433007863	1826	21	9F
0005433284798	1826	22	10A
0005433008001	1826	23	10C
0005432295857	1826	24	10D
0005433008130	1826	25	10E
0005433008050	1826	26	11A
0005433284795	1826	27	11D
0005433284892	1826	28	11E
0005433008049	1826	29	11F
0005433284841	1826	30	12A
0005433284842	1826	31	12C
0005432295858	1826	32	12D
0005433008042	1826	33	12F
0005433810517	1826	34	13A
0005433284796	1826	35	13C
0005433284873	1826	36	13D
0005433008045	1826	37	13E
0005433007826	1826	38	14C
0005433284819	1826	39	14D
0005433008022	1826	40	14F
0005433007872	1826	41	15C
0005433007830	1826	42	15E
0005433810516	1826	43	16C
0005433810515	1826	44	16D
0005433284787	1826	45	17C
0005433284845	1826	46	17E
0005433284876	1826	47	18C
0005433008000	1826	48	18D
0005433007974	1826	49	18E
0005433008043	1826	50	18F
0005433284825	1826	51	19A
0005433284773	1826	52	19C
0005433007913	1826	53	19D
0005433284872	1826	54	19F
0005433008023	1826	55	20A
0005433007831	1826	56	20C
0005433007968	1826	57	20E
0005433008239	22614	1	1A
0005433008226	22614	2	1C
0005433008200	22614	3	1D
0005433008222	22614	4	1F
0005433008232	22614	5	2C
0005433285031	22614	6	2D
0005433008208	22614	7	3A
0005433285008	22614	8	3C
0005433285036	22614	9	3D
0005433008229	22614	10	3F
0005433008194	22614	11	4C
0005433285010	22614	12	4D
0005433008224	22614	13	4F
0005433008197	22614	14	5A
0005433008235	22614	15	5C
0005433285028	22614	16	5D
0005433008231	22614	17	5E
0005433285024	22614	18	5F
0005433008219	22614	19	6A
0005433008230	22614	20	6C
0005433285007	22614	21	6D
0005433008206	22614	22	7A
0005433008213	22614	23	7C
0005433285033	22614	24	7D
0005433285016	22614	25	7E
0005433008234	22614	26	7F
0005433008198	22614	27	8A
0005433285018	22614	28	8C
0005433008212	22614	29	8D
0005433008204	22614	30	8E
0005433285014	22614	31	8F
0005433285019	22614	32	9C
0005433008209	22614	33	9E
0005433008214	22614	34	9F
0005433008203	22614	35	10A
0005433285030	22614	36	10C
0005433008202	22614	37	10D
0005433285015	22614	38	10E
0005433285020	22614	39	10F
0005433008233	22614	40	11C
0005433008227	22614	41	11D
0005433008225	22614	42	11F
0005433008199	22614	43	12A
0005433008215	22614	44	12C
0005433008195	22614	45	12D
0005433008238	22614	46	12E
0005433285032	22614	47	12F
0005433285009	22614	48	13A
0005433285012	22614	49	13D
0005433285026	22614	50	13E
0005433008220	22614	51	13F
0005433285021	22614	52	14A
0005433008196	22614	53	14D
0005433285029	22614	54	15A
0005433285037	22614	55	15C
0005433285025	22614	56	15D
0005433008221	22614	57	15E
0005433008237	22614	58	15F
0005433008217	22614	59	16C
0005433285038	22614	60	16D
0005433008218	22614	61	16E
0005433008201	22614	62	17A
0005433285022	22614	63	17C
0005433008223	22614	64	17E
0005433008211	22614	65	17F
0005433008216	22614	66	18A
0005433008205	22614	67	18D
0005433285034	22614	68	18E
0005433008207	22614	69	18F
0005433008210	22614	70	19A
0005433285027	22614	71	19C
0005433285011	22614	72	19D
0005433285013	22614	73	19E
0005433008236	22614	74	19F
0005433285023	22614	75	20C
0005433285017	22614	76	20D
0005433008228	22614	77	20E
0005433285035	22614	78	20F
0005432755021	12283	1	2C
0005434152777	12283	2	6C
0005432751469	12283	3	7C
0005434152779	12283	4	8C
0005434152780	12283	5	8D
0005432755022	12283	6	8F
0005434152772	12283	7	12E
0005434152773	12283	8	14E
0005432755015	12283	9	16D
0005432751468	12283	10	16E
0005434152774	12283	11	17D
0005434152775	12283	12	18D
0005434152776	12283	13	20E
0005434152778	12283	14	20F
0005435282152	5576	1	2A
0005433815340	5576	2	2F
0005433846241	5576	3	2C
0005433846252	5576	4	3A
0005433846203	5576	5	3D
0005435282090	5576	6	3C
0005433846248	5576	7	4A
0005433846245	5576	8	3F
0005433846244	5576	9	5A
0005433815341	5576	10	4F
0005433846215	5576	11	5C
0005433846247	5576	12	5F
0005435282130	5576	13	5D
0005433815343	5576	14	6A
0005433846261	5576	15	6D
0005433846254	5576	16	6E
0005435282104	5576	17	7A
0005433846260	5576	18	6F
0005433846237	5576	19	7B
0005433815342	5576	20	7E
0005433846259	5576	21	7D
0005433846221	5576	22	8A
0005433846232	5576	23	7F
0005435282134	5576	24	8B
0005433846239	5576	25	8D
0005435282131	5576	26	8E
0005433846255	5576	27	9B
0005433846214	5576	28	9C
0005433846258	5576	29	9E
0005433846220	5576	30	10B
0005432081459	5576	31	10A
0005433846246	5576	32	10C
0005433846228	5576	33	10E
0005433846240	5576	34	10D
0005433846223	5576	35	10F
0005433846257	5576	36	11A
0005433846217	5576	37	11D
0005433846236	5576	38	11C
0005433846209	5576	39	11F
0005433846242	5576	40	11E
0005435282084	5576	41	12B
0005433846213	5576	42	12D
0005432081458	5576	43	12F
0005433846205	5576	44	12E
0005433846218	5576	45	13A
0005432081453	5576	46	13C
0005433846256	5576	47	13B
0005433846253	5576	48	13F
0005432081455	5576	49	14B
0005433846212	5576	50	14D
0005433846231	5576	51	14C
0005435282116	5576	52	14F
0005433846230	5576	53	15B
0005433846216	5576	54	15D
0005433846229	5576	55	15C
0005433846227	5576	56	16A
0005435282070	5576	57	15F
0005432081457	5576	58	16B
0005433846211	5576	59	16E
0005432081456	5576	60	16D
0005435282085	5576	61	16C
0005433846249	5576	62	16F
0005433846250	5576	63	17B
0005432081454	5576	64	17D
0005433846206	5576	65	17C
0005433846225	5576	66	17E
0005433846238	5576	67	18B
0005433815344	5576	68	18A
0005433846224	5576	69	18C
0005433846234	5576	70	18F
0005433846226	5576	71	18D
0005433846222	5576	72	19A
0005435282133	5576	73	19C
0005433846207	5576	74	19B
0005433846251	5576	75	19E
0005433846243	5576	76	19D
0005433846235	5576	77	19F
0005435282107	5576	78	20C
0005433846202	5576	79	20A
0005433846201	5576	80	20D
0005433846210	5576	81	20F
0005435282119	5576	82	21A
0005433846219	5576	83	21C
0005433846208	5576	84	21B
0005433846233	5576	85	21F
0005433846204	5576	86	21D
0005433815307	13854	1	1A
0005432003675	13854	2	1F
0005432003676	13854	3	1D
0005435282292	13854	4	2D
0005433845802	13854	5	2C
0005433845784	13854	6	3A
0005435282287	13854	7	3D
0005433845751	13854	8	4A
0005435282306	13854	9	3F
0005435282301	13854	10	4C
0005433845910	13854	11	4D
0005433845901	13854	12	5A
0005435282300	13854	13	6B
0005433815319	13854	14	6A
0005435282303	13854	15	6C
0005434173488	13854	16	6F
0005434173486	13854	17	7B
0005433845790	13854	18	7A
0005433845735	13854	19	7D
0005435282302	13854	20	7F
0005433845778	13854	21	7E
0005435282298	13854	22	8C
0005434173485	13854	23	8D
0005435282308	13854	24	8F
0005433845725	13854	25	8E
0005435282299	13854	26	9B
0005433845726	13854	27	9A
0005433845841	13854	28	9D
0005435282293	13854	29	9F
0005432003674	13854	30	9E
0005433815318	13854	31	10B
0005433845707	13854	32	10A
0005433845777	13854	33	10C
0005433845830	13854	34	10E
0005435282295	13854	35	11C
0005433845979	13854	36	11B
0005433845748	13854	37	12B
0005435282305	13854	38	12F
0005433845706	13854	39	13C
0005433845708	13854	40	13B
0005434173487	13854	41	13D
0005435282304	13854	42	14D
0005433815317	13854	43	14F
0005433845872	13854	44	15B
0005435282309	13854	45	15A
0005433845744	13854	46	15D
0005435282294	13854	47	15E
0005435282296	13854	48	15F
0005433845902	13854	49	16B
0005435282288	13854	50	16D
0005433815306	13854	51	17B
0005433845730	13854	52	17A
0005433845893	13854	53	17D
0005433845769	13854	54	17F
0005435282285	13854	55	17E
0005433845879	13854	56	18B
0005435282307	13854	57	18C
0005433845700	13854	58	18F
0005435282289	13854	59	19E
0005433845776	13854	60	19C
0005433845734	13854	61	20B
0005433845878	13854	62	20D
0005433845978	13854	63	20C
0005433845974	13854	64	20F
0005435282297	13854	65	20E
0005433845722	13854	66	21C
0005435282286	13854	67	21B
0005435282291	13854	68	21E
0005435282290	13854	69	21D
0005434620424	7829	1	1A
0005434620427	7829	2	1B
0005434620430	7829	3	1C
0005434620418	7829	4	1D
0005434620422	7829	5	2A
0005435332154	7829	6	2B
0005435332174	7829	7	2C
0005434620428	7829	8	2D
0005434620431	7829	9	3A
0005434620415	7829	10	3B
0005434620419	7829	11	3C
0005435332162	7829	12	4A
0005435332209	7829	13	4D
0005434620411	7829	14	5A
0005434620425	7829	15	5C
0005432112497	7829	16	5D
0005434620429	7829	17	6B
0005434620414	7829	18	7A
0005434620416	7829	19	7B
0005435332175	7829	20	7D
0005434620413	7829	21	18B
0005434620412	7829	22	18D
0005434620420	7829	23	19A
0005435332161	7829	24	19B
0005434620421	7829	25	20A
0005435332163	7829	26	20B
0005434620423	7829	27	20C
0005434620417	7829	28	20D
0005435332191	7829	29	21A
0005435332199	7829	30	21C
0005432112496	7829	31	21D
0005434620432	7829	32	22A
0005435332169	7829	33	23A
0005434620426	7829	34	23B
0005434620326	32957	1	1B
0005434620225	32957	2	1D
0005434620313	32957	3	2A
0005435332248	32957	4	2B
0005435332250	32957	5	2C
0005435332245	32957	6	3B
0005434620296	32957	7	4A
0005434620262	32957	8	4C
0005434620245	32957	9	4D
0005434620226	32957	10	5B
0005434620297	32957	11	6A
0005435332246	32957	12	6B
0005435332244	32957	13	7B
0005435332252	32957	14	7C
0005435332242	32957	15	18B
0005434620244	32957	16	18D
0005435332253	32957	17	19B
0005435332251	32957	18	19D
0005434620249	32957	19	20C
0005435332243	32957	20	21B
0005434620246	32957	21	22A
0005434620261	32957	22	22B
0005435332247	32957	23	22C
0005435332249	32957	24	22D
0005434620243	32957	25	23B
0005435785056	4282	1	1A
0005434993938	4282	2	1D
0005435785067	4282	3	2C
0005435785049	4282	4	2F
0005435785070	4282	5	3C
0005435785064	4282	6	3D
0005434993941	4282	7	3F
0005434993937	4282	8	4A
0005434993942	4282	9	4D
0005435787334	4282	10	4F
0005435785074	4282	11	5A
0005435785060	4282	12	5F
0005434993939	4282	13	6A
0005434993936	4282	14	6C
0005435785057	4282	15	6D
0005435787336	4282	16	6F
0005435785068	4282	17	7D
0005435785047	4282	18	7E
0005435785078	4282	19	7F
0005432190597	4282	20	8A
0005435785063	4282	21	8C
0005435785071	4282	22	8D
0005432190596	4282	23	8E
0005435918597	4282	24	8F
0005435937317	4282	25	9D
0005435785072	4282	26	9F
0005435785052	4282	27	10C
0005435785061	4282	28	10D
0005432190598	4282	29	10F
0005435785080	4282	30	11D
0005435785055	4282	31	11E
0005435785054	4282	32	11F
0005434993944	4282	33	12E
0005434993935	4282	34	12F
0005435785076	4282	35	13C
0005435785048	4282	36	13D
0005434993940	4282	37	13E
0005434993945	4282	38	13F
0005435785075	4282	39	14A
0005435785069	4282	40	14D
0005435785077	4282	41	14E
0005434993943	4282	42	15A
0005435937310	4282	43	15C
0005435785058	4282	44	15D
0005435787335	4282	45	15F
0005435785079	4282	46	16C
0005435937316	4282	47	16E
0005435937311	4282	48	16F
0005435785065	4282	49	17C
0005435785059	4282	50	18A
0005435785062	4282	51	18C
0005435785051	4282	52	18D
0005435787337	4282	53	19A
0005435918581	4282	54	19C
0005435785066	4282	55	19E
0005435785046	4282	56	20A
0005435785050	4282	57	20C
0005435785073	4282	58	20D
0005435785053	4282	59	20E
0005435937341	27312	1	1A
0005435918615	27312	2	2A
0005435937337	27312	3	2F
0005435937342	27312	4	4E
0005435784750	27312	5	5D
0005435784748	27312	6	5E
0005435937339	27312	7	7A
0005435784747	27312	8	7D
0005432195674	27312	9	8A
0005435784749	27312	10	8C
0005434993871	27312	11	8E
0005432195675	27312	12	8F
0005435787320	27312	13	9A
0005435937334	27312	14	9D
0005434993853	27312	15	9E
0005434993870	27312	16	10D
0005435937340	27312	17	11A
0005435937338	27312	18	11C
0005435784810	27312	19	11F
0005435937343	27312	20	13C
0005434993857	27312	21	13E
0005434993854	27312	22	14C
0005434993856	27312	23	14E
0005434993867	27312	24	15A
0005435918613	27312	25	15C
0005435937335	27312	26	16C
0005434993887	27312	27	17C
0005435937336	27312	28	17F
0005435918614	27312	29	18C
0005435918616	27312	30	18D
0005435918612	27312	31	19F
0005432195673	27312	32	20A
0005432146180	19894	1	18A
0005432146181	19894	2	23B
0005434081717	4746	1	1A
0005432567095	4746	2	1B
0005432459416	4746	3	1F
0005432459407	4746	4	1C
0005434081708	4746	5	1G
0005433451603	4746	6	2A
0005432459414	4746	7	1H
0005432567096	4746	8	2B
0005432459408	4746	9	2F
0005432567088	4746	10	2C
0005432170333	4746	11	3A
0005432459436	4746	12	2H
0005432459405	4746	13	3B
0005432567117	4746	14	3G
0005432459392	4746	15	4A
0005432567115	4746	16	3H
0005432567143	4746	17	4B
0005433726085	4746	18	4C
0005432571290	4746	19	4H
0005432459423	4746	20	5B
0005432567147	4746	21	5C
0005434081721	4746	22	5G
0005432459420	4746	23	5H
0005432459395	4746	24	9G
0005432567108	4746	25	11E
0005433451602	4746	26	11D
0005432459389	4746	27	11F
0005432459426	4746	28	11H
0005432567129	4746	29	11G
0005432567133	4746	30	12A
0005432567132	4746	31	12D
0005432459402	4746	32	12B
0005434081715	4746	33	12E
0005432567094	4746	34	12F
0005432567100	4746	35	12H
0005432567128	4746	36	12G
0005434081698	4746	37	13B
0005432459399	4746	38	13A
0005432567136	4746	39	13D
0005432567116	4746	40	13G
0005432170328	4746	41	13F
0005432459396	4746	42	14A
0005432567092	4746	43	14D
0005432567126	4746	44	14E
0005434081723	4746	45	14G
0005432567109	4746	46	14F
0005432567152	4746	47	15A
0005432567141	4746	48	14H
0005432170334	4746	49	15D
0005432459387	4746	50	15B
0005432459421	4746	51	15E
0005434081727	4746	52	15F
0005432459429	4746	53	15H
0005433452722	4746	54	15G
0005432567142	4746	55	16B
0005432459428	4746	56	16A
0005432567137	4746	57	16D
0005432459400	4746	58	16E
0005432170332	4746	59	16F
0005432186840	4746	60	17D
0005432567127	4746	61	17E
0005432567099	4746	62	17F
0005432459401	4746	63	17H
0005432170329	4746	64	18A
0005434081700	4746	65	18D
0005432459403	4746	66	18F
0005434081713	4746	67	18H
0005434081699	4746	68	19F
0005432567151	4746	69	19E
0005432571291	4746	70	19H
0005432459431	4746	71	19G
0005432567120	4746	72	20B
0005434081702	4746	73	20E
0005432459409	4746	74	20F
0005432571288	4746	75	20H
0005432567150	4746	76	20G
0005432459384	4746	77	21A
0005432567102	4746	78	21D
0005432567146	4746	79	21B
0005434081712	4746	80	21E
0005432567113	4746	81	21F
0005432186839	4746	82	21G
0005432170331	4746	83	22B
0005434081707	4746	84	22A
0005432459418	4746	85	22D
0005434081709	4746	86	22F
0005434081726	4746	87	23A
0005434081725	4746	88	22H
0005432459425	4746	89	23B
0005432567097	4746	90	23D
0005434081724	4746	91	23F
0005432459430	4746	92	23G
0005432459404	4746	93	24A
0005432459398	4746	94	24B
0005433726084	4746	95	24E
0005432567123	4746	96	24F
0005432567098	4746	97	24G
0005432186838	4746	98	25D
0005432459433	4746	99	25F
0005432459391	4746	100	25E
0005432567134	4746	101	27A
0005432459394	4746	102	27D
0005434081705	4746	103	27F
0005432459427	4746	104	27G
0005432459435	4746	105	28A
0005432459390	4746	106	27H
0005432567107	4746	107	28B
0005432459413	4746	108	28E
0005432170330	4746	109	28D
0005432459406	4746	110	28H
0005434081716	4746	111	28G
0005432186837	4746	112	29A
0005433452721	4746	113	29B
0005432459385	4746	114	29E
0005434081703	4746	115	29D
0005432459419	4746	116	29G
0005432459434	4746	117	29F
0005432567138	4746	118	29H
0005432459432	4746	119	30B
0005432567125	4746	120	30D
0005434081719	4746	121	30F
0005432567106	4746	122	30E
0005432567130	4746	123	30G
0005432567131	4746	124	31D
0005432567093	4746	125	31F
0005434081711	4746	126	31E
0005434081720	4746	127	31H
0005432571289	4746	128	32B
0005432567090	4746	129	32E
0005432567089	4746	130	32F
0005432567121	4746	131	32H
0005434081714	4746	132	32G
0005432567110	4746	133	33A
0005432567145	4746	134	33D
0005432567105	4746	135	33B
0005432567148	4746	136	33F
0005432567114	4746	137	33H
0005432567122	4746	138	34B
0005432567118	4746	139	34A
0005434081706	4746	140	34D
0005432459424	4746	141	34F
0005432567091	4746	142	34E
0005432567103	4746	143	34G
0005434081701	4746	144	35B
0005432567101	4746	145	35A
0005432567144	4746	146	35E
0005432567104	4746	147	35D
0005432567139	4746	148	35F
0005434081718	4746	149	35G
0005434081722	4746	150	36B
0005432459411	4746	151	36A
0005432459393	4746	152	36D
0005432567140	4746	153	36F
0005434081704	4746	154	36G
0005432459422	4746	155	37A
0005432567149	4746	156	36H
0005432567119	4746	157	37B
0005432567111	4746	158	37E
0005432459410	4746	159	37D
0005432459397	4746	160	37G
0005432459417	4746	161	37F
0005432567124	4746	162	38A
0005432459415	4746	163	38B
0005432459386	4746	164	38G
0005432459388	4746	165	38F
0005432567112	4746	166	38H
0005432459412	4746	167	39D
0005432567135	4746	168	39F
0005434081710	4746	169	39E
0005432566713	30544	1	1A
0005432566660	30544	2	1B
0005432458974	30544	3	1F
0005432566858	30544	4	1C
0005433452707	30544	5	1H
0005432459055	30544	6	1G
0005432459093	30544	7	2A
0005432459110	30544	8	2B
0005432459156	30544	9	2F
0005432566722	30544	10	2H
0005432571260	30544	11	2G
0005432459069	30544	12	3A
0005432571264	30544	13	3B
0005432161133	30544	14	3G
0005432566847	30544	15	3H
0005432566901	30544	16	4B
0005432571262	30544	17	4A
0005432459271	30544	18	4F
0005432459108	30544	19	4G
0005434081521	30544	20	4H
0005432459150	30544	21	5B
0005432458994	30544	22	5F
0005432459058	30544	23	5C
0005434081472	30544	24	5G
0005434081478	30544	25	9A
0005434081513	30544	26	5H
0005432213575	30544	27	9G
0005432459054	30544	28	11B
0005432459045	30544	29	11D
0005432459147	30544	30	11F
0005433454843	30544	31	11H
0005432459095	30544	32	11G
0005432459270	30544	33	12A
0005432161132	30544	34	12D
0005432459157	30544	35	12B
0005432213574	30544	36	12E
0005432566834	30544	37	12G
0005432566727	30544	38	12F
0005432566664	30544	39	13A
0005432571263	30544	40	13F
0005432566844	30544	41	13D
0005432459044	30544	42	13G
0005432459106	30544	43	13H
0005432459053	30544	44	14B
0005432566630	30544	45	14A
0005434081479	30544	46	14D
0005432459073	30544	47	14F
0005432566619	30544	48	15A
0005434081492	30544	49	14H
0005432566736	30544	50	15B
0005434081498	30544	51	15E
0005432459169	30544	52	15H
0005434081480	30544	53	15G
0005434081481	30544	54	16A
0005434081506	30544	55	16D
0005432459017	30544	56	16B
0005432566659	30544	57	16F
0005432566725	30544	58	16G
0005434081497	30544	59	16H
0005432566689	30544	60	17A
0005432566643	30544	61	17D
0005432566955	30544	62	17E
0005432566681	30544	63	17F
0005433454838	30544	64	18B
0005432566690	30544	65	18G
0005432459146	30544	66	19A
0005432458966	30544	67	18H
0005432566569	30544	68	19D
0005434081507	30544	69	19F
0005432566641	30544	70	19G
0005432458963	30544	71	19H
0005434081483	30544	72	20B
0005432566712	30544	73	20E
0005432459113	30544	74	20D
0005432459135	30544	75	20F
0005432566760	30544	76	20H
0005432459071	30544	77	20G
0005432566838	30544	78	21A
0005433454837	30544	79	21D
0005432566692	30544	80	21B
0005432459166	30544	81	21E
0005432566903	30544	82	21F
0005432458977	30544	83	21H
0005432458962	30544	84	22A
0005432566669	30544	85	22D
0005432566675	30544	86	22B
0005432459034	30544	87	22F
0005432459086	30544	88	22E
0005432459109	30544	89	22G
0005432459074	30544	90	23A
0005432566684	30544	91	22H
0005434081475	30544	92	23E
0005432571265	30544	93	23G
0005432459059	30544	94	23H
0005432459099	30544	95	24B
0005434081536	30544	96	24A
0005432459046	30544	97	24E
0005433452713	30544	98	24D
0005432566845	30544	99	24F
0005432459114	30544	100	24G
0005432566568	30544	101	25D
0005432459165	30544	102	25E
0005432566646	30544	103	25F
0005432566570	30544	104	27B
0005432566972	30544	105	27A
0005432566638	30544	106	27E
0005432459379	30544	107	27F
0005434081505	30544	108	27H
0005432459155	30544	109	28B
0005432566651	30544	110	28E
0005432566640	30544	111	28D
0005432566642	30544	112	28G
0005432458976	30544	113	28F
0005432566821	30544	114	29B
0005432459193	30544	115	29A
0005432459107	30544	116	28H
0005432459131	30544	117	29D
0005432459010	30544	118	29H
0005432566691	30544	119	30F
0005432459163	30544	120	30G
0005434081494	30544	121	31A
0005432459138	30544	122	31D
0005434081503	30544	123	31G
0005432459151	30544	124	31F
0005432566550	30544	125	32A
0005432566661	30544	126	32B
0005432458993	30544	127	32G
0005433452712	30544	128	32F
0005432459164	30544	129	32E
0005432566561	30544	130	33A
0005432566594	30544	131	32H
0005432459194	30544	132	33B
0005432459170	30544	133	33D
0005432566714	30544	134	33H
0005432566628	30544	135	33G
0005434081473	30544	136	34D
0005432458983	30544	137	34B
0005432566833	30544	138	34F
0005432566902	30544	139	34E
0005432459006	30544	140	35B
0005432459011	30544	141	35A
0005434081535	30544	142	35D
0005432459111	30544	143	35E
0005432566682	30544	144	35F
0005434081493	30544	145	35H
0005432566544	30544	146	36D
0005432459152	30544	147	36F
0005432459094	30544	148	36E
0005432566629	30544	149	36G
0005432566637	30544	150	37D
0005432566846	30544	151	37B
0005432566761	30544	152	37E
0005432213576	30544	153	37F
0005432571261	30544	154	37H
0005432213573	30544	155	37G
0005432566683	30544	156	38D
0005432459047	30544	157	38B
0005434081514	30544	158	38E
0005432566527	30544	159	38G
0005432566676	30544	160	39F
0005435720816	13658	1	2A
0005435722035	13658	2	3A
0005435720815	13658	3	4B
0005435722034	13658	4	6B
0005432295858	22791	1	2D
0005432295857	22791	2	20C
0005435097129	11091	1	1A
0005435097124	11091	2	1C
0005433342301	11091	3	1D
0005433342298	11091	4	1F
0005433342329	11091	5	2A
0005433342318	11091	6	2D
0005433342379	11091	7	2C
0005433342384	11091	8	3A
0005433342367	11091	9	2F
0005433342361	11091	10	3C
0005433342304	11091	11	4A
0005433342352	11091	12	4C
0005433342328	11091	13	4B
0005433342378	11091	14	4D
0005433342357	11091	15	4E
0005433342307	11091	16	4F
0005433342317	11091	17	5A
0005433342339	11091	18	5C
0005433342386	11091	19	5B
0005433342322	11091	20	5D
0005433342333	11091	21	5E
0005433342337	11091	22	6A
0005433342354	11091	23	5F
0005435097122	11091	24	6B
0005433342306	11091	25	6D
0005433342359	11091	26	6C
0005433342346	11091	27	6F
0005433342366	11091	28	7A
0005433342342	11091	29	7C
0005435097121	11091	30	7D
0005433342341	11091	31	7E
0005433342294	11091	32	8A
0005435508164	11091	33	7F
0005433342381	11091	34	8B
0005433342356	11091	35	8C
0005433342348	11091	36	8D
0005433342364	11091	37	8F
0005433342311	11091	38	8E
0005433342309	11091	39	9A
0005433342391	11091	40	9B
0005433342332	11091	41	9D
0005433342389	11091	42	9C
0005433342380	11091	43	10B
0005433342320	11091	44	10C
0005433342325	11091	45	10D
0005433342350	11091	46	11A
0005433342305	11091	47	10E
0005433342326	11091	48	11C
0005433342335	11091	49	11B
0005433342371	11091	50	11E
0005433342312	11091	51	11D
0005433342363	11091	52	11F
0005433342393	11091	53	12A
0005433342336	11091	54	12C
0005433342331	11091	55	12B
0005433342330	11091	56	12D
0005435097123	11091	57	12E
0005433342343	11091	58	13A
0005433342368	11091	59	12F
0005433342390	11091	60	13B
0005433342362	11091	61	13D
0005435097125	11091	62	13E
0005433342308	11091	63	14A
0005433342382	11091	64	13F
0005433342392	11091	65	14B
0005433342376	11091	66	14D
0005433342372	11091	67	14E
0005433342313	11091	68	15A
0005433342327	11091	69	14F
0005435097128	11091	70	15C
0005433342345	11091	71	15B
0005433342370	11091	72	15E
0005433342369	11091	73	15D
0005433342302	11091	74	15F
0005433342349	11091	75	16A
0005433342297	11091	76	16B
0005435380224	11091	77	16D
0005433342385	11091	78	16C
0005435097120	11091	79	16F
0005433342355	11091	80	16E
0005433342324	11091	81	17A
0005433342314	11091	82	17B
0005433342296	11091	83	17D
0005433342365	11091	84	18A
0005435097119	11091	85	17F
0005433342377	11091	86	18C
0005433342388	11091	87	18B
0005433342310	11091	88	18D
0005433342358	11091	89	18F
0005433342374	11091	90	18E
0005433342316	11091	91	19B
0005433342340	11091	92	19A
0005433342387	11091	93	19C
0005433342323	11091	94	19D
0005433342303	11091	95	19F
0005433342375	11091	96	20A
0005435097126	11091	97	20B
0005433342321	11091	98	20D
0005433342319	11091	99	20C
0005433342300	11091	100	20E
0005435380225	11091	101	20F
0005433342295	11091	102	21A
0005433342338	11091	103	21E
0005433342299	11091	104	21F
0005433342351	11091	105	22B
0005433342383	11091	106	22C
0005433342347	11091	107	22E
0005433342394	11091	108	22D
0005433342315	11091	109	22F
0005433342353	11091	110	23A
0005433342373	11091	111	23B
0005433342360	11091	112	23D
0005433342334	11091	113	23C
0005433342344	11091	114	23E
0005435097127	11091	115	23F
0005433341488	17090	1	1A
0005433341667	17090	2	1C
0005433341412	17090	3	1D
0005433341641	17090	4	2A
0005433341448	17090	5	3D
0005433341669	17090	6	4A
0005435545662	17090	7	4C
0005435097062	17090	8	4F
0005433341424	17090	9	5A
0005435380263	17090	10	5C
0005433341500	17090	11	5B
0005433341486	17090	12	5E
0005433341429	17090	13	5F
0005433341704	17090	14	6B
0005435545663	17090	15	6A
0005433341382	17090	16	6D
0005433341853	17090	17	6E
0005433341836	17090	18	7C
0005433341586	17090	19	8C
0005435545668	17090	20	8D
0005433341815	17090	21	9B
0005433341532	17090	22	9D
0005433341835	17090	23	9C
0005435545659	17090	24	9E
0005435545657	17090	25	10D
0005433341477	17090	26	10E
0005433341425	17090	27	11A
0005433341462	17090	28	11B
0005432293188	17090	29	11D
0005433341461	17090	30	11C
0005433341428	17090	31	11E
0005435545660	17090	32	12B
0005435545658	17090	33	12D
0005433341449	17090	34	12C
0005435545656	17090	35	12F
0005433341400	17090	36	13B
0005435097044	17090	37	13D
0005433341417	17090	38	13C
0005433341601	17090	39	13F
0005433341734	17090	40	14C
0005435545655	17090	41	14D
0005433341603	17090	42	14E
0005433341561	17090	43	14F
0005435545661	17090	44	15A
0005433341402	17090	45	15C
0005435545665	17090	46	15D
0005433341391	17090	47	15F
0005435380260	17090	48	16A
0005433341607	17090	49	16C
0005433341587	17090	50	16E
0005433341650	17090	51	17A
0005433341683	17090	52	16F
0005433341595	17090	53	17B
0005435545671	17090	54	17C
0005433341738	17090	55	17D
0005433341620	17090	56	17F
0005432293186	17090	57	18B
0005435545669	17090	58	18D
0005435545664	17090	59	18F
0005435545666	17090	60	19A
0005435545667	17090	61	19B
0005435097063	17090	62	19D
0005433341854	17090	63	19E
0005433341703	17090	64	20D
0005433341649	17090	65	20F
0005435380262	17090	66	21A
0005433341671	17090	67	21C
0005435380261	17090	68	21D
0005432293187	17090	69	22C
0005433341635	17090	70	22D
0005435545670	17090	71	22F
0005435097089	17090	72	23B
0005433341415	17090	73	23D
0005435097045	17090	74	23C
0005433341383	17090	75	23E
0005433341505	17090	76	23F
0005432919524	9104	1	1F
0005433507040	9104	2	2F
0005433507042	9104	3	3D
0005433507036	9104	4	4A
0005433507025	9104	5	4C
0005433507029	9104	6	4F
0005433481106	9104	7	5A
0005434158947	9104	8	5E
0005433481102	9104	9	6A
0005432919516	9104	10	6C
0005434158948	9104	11	7C
0005433507032	9104	12	9E
0005433507038	9104	13	9F
0005432919506	9104	14	10C
0005433507034	9104	15	10D
0005433507028	9104	16	11C
0005433507027	9104	17	11D
0005432919523	9104	18	12A
0005433481105	9104	19	12D
0005432919540	9104	20	12F
0005433507026	9104	21	13A
0005433507035	9104	22	13E
0005433507030	9104	23	13F
0005433507039	9104	24	14A
0005433507024	9104	25	14D
0005434158945	9104	26	15D
0005432919565	9104	27	15E
0005433507041	9104	28	16D
0005434158950	9104	29	16F
0005432919566	9104	30	17A
0005433481099	9104	31	17C
0005433481101	9104	32	17E
0005433481100	9104	33	17F
0005433507037	9104	34	18A
0005433507033	9104	35	18C
0005433481104	9104	36	18D
0005432919536	9104	37	18F
0005433507031	9104	38	20D
0005433481103	9104	39	20F
0005433506862	20433	1	1F
0005433506908	20433	2	2A
0005433481035	20433	3	2D
0005432919705	20433	4	3A
0005432919708	20433	5	4A
0005432919701	20433	6	4E
0005432919695	20433	7	5C
0005433506928	20433	8	5E
0005432919704	20433	9	6C
0005432919700	20433	10	6D
0005432919702	20433	11	6E
0005433506904	20433	12	7F
0005432919712	20433	13	8A
0005433481032	20433	14	8C
0005433481062	20433	15	8E
0005433506866	20433	16	9C
0005432919696	20433	17	10A
0005433506892	20433	18	10D
0005433506879	20433	19	11A
0005433506912	20433	20	11C
0005433506882	20433	21	12C
0005432919710	20433	22	13C
0005433506896	20433	23	13F
0005432919703	20433	24	14A
0005432919697	20433	25	14C
0005433506865	20433	26	14D
0005432919706	20433	27	15A
0005432919707	20433	28	15D
0005432919716	20433	29	16C
0005432919699	20433	30	16E
0005433481031	20433	31	18A
0005432919713	20433	32	18C
0005432919714	20433	33	19A
0005433481063	20433	34	19D
0005432919711	20433	35	19E
0005432919698	20433	36	19F
0005432919715	20433	37	20D
0005432919709	20433	38	20F
0005432396206	10170	1	1A
0005432394068	10170	2	1B
0005432396204	10170	3	2A
0005432394067	10170	4	3B
0005432396205	10170	5	4B
0005432394065	10170	6	5B
0005432396207	10170	7	6A
0005432394066	10170	8	6B
0005432400071	18392	1	1A
0005432396175	18392	2	2A
0005432400070	18392	3	3A
0005432396176	18392	4	4A
0005432396184	18392	5	4B
0005432396174	18392	6	5B
0005432400064	18392	7	6B
0005435625862	11002	1	1C
0005434411743	11002	2	1F
0005435554103	11002	3	2D
0005435625867	11002	4	3A
0005435125662	11002	5	3D
0005435125676	11002	6	4D
0005435125688	11002	7	5A
0005434411742	11002	8	5E
0005435556646	11002	9	5F
0005435125735	11002	10	6E
0005435125753	11002	11	6F
0005435125687	11002	12	7A
0005435125656	11002	13	7D
0005434928276	11002	14	8D
0005435125694	11002	15	8E
0005435125754	11002	16	8F
0005434411741	11002	17	9C
0005434928277	11002	18	9D
0005435125671	11002	19	9E
0005435625870	11002	20	10A
0005435125659	11002	21	10C
0005435125661	11002	22	10D
0005435554115	11002	23	10F
0005435125768	11002	24	11A
0005435125658	11002	25	11C
0005435625866	11002	26	11D
0005435125783	11002	27	11E
0005435125675	11002	28	12A
0005435625874	11002	29	12E
0005434411744	11002	30	13F
0005435625873	11002	31	14C
0005435125701	11002	32	14E
0005435625871	11002	33	14F
0005435125734	11002	34	15A
0005435125709	11002	35	15C
0005435125733	11002	36	15D
0005435125782	11002	37	15F
0005435625872	11002	38	17A
0005435125784	11002	39	18A
0005435125660	11002	40	18C
0005435125801	11002	41	18D
0005435125674	11002	42	19D
0005435554104	11002	43	20A
0005435556653	11002	44	20E
0005435125767	11002	45	20F
0005435126032	14675	1	1C
0005435126061	14675	2	1D
0005435126034	14675	3	1F
0005435126059	14675	4	2A
0005435126023	14675	5	2F
0005435126045	14675	6	3C
0005434928254	14675	7	3F
0005435126051	14675	8	4A
0005435626028	14675	9	4C
0005435126062	14675	10	4D
0005435626029	14675	11	4E
0005435126057	14675	12	4F
0005435554147	14675	13	5D
0005435626027	14675	14	5F
0005435626033	14675	15	6C
0005435554145	14675	16	6D
0005435126036	14675	17	6E
0005435626025	14675	18	7A
0005435626030	14675	19	7C
0005435626035	14675	20	7E
0005435126029	14675	21	8A
0005435126054	14675	22	8D
0005435126040	14675	23	8E
0005435126031	14675	24	8F
0005435126046	14675	25	9D
0005435126041	14675	26	9E
0005435126025	14675	27	9F
0005435556669	14675	28	10D
0005435126049	14675	29	11A
0005435554146	14675	30	11D
0005435126052	14675	31	11F
0005435126056	14675	32	12A
0005435126055	14675	33	12C
0005434411709	14675	34	12D
0005435126058	14675	35	12E
0005435626039	14675	36	12F
0005435126035	14675	37	13A
0005435556671	14675	38	13C
0005435626036	14675	39	13D
0005435126048	14675	40	13E
0005435626031	14675	41	13F
0005435126026	14675	42	14A
0005434411704	14675	43	14C
0005435126039	14675	44	14D
0005435126063	14675	45	14E
0005435556670	14675	46	14F
0005435126033	14675	47	15A
0005435126027	14675	48	15C
0005435554144	14675	49	15D
0005435126043	14675	50	15E
0005435626024	14675	51	15F
0005435126038	14675	52	16A
0005435626034	14675	53	16C
0005435126030	14675	54	16D
0005435126050	14675	55	16E
0005435554148	14675	56	16F
0005435126060	14675	57	17D
0005435126053	14675	58	17E
0005435126037	14675	59	17F
0005435126022	14675	60	18A
0005435126024	14675	61	18D
0005435626037	14675	62	18E
0005435626038	14675	63	18F
0005435626026	14675	64	19C
0005435626032	14675	65	19D
0005435126047	14675	66	19E
0005435126028	14675	67	19F
0005435626023	14675	68	20C
0005435126044	14675	69	20E
0005435126042	14675	70	20F
0005435443155	7093	1	1A
0005435715329	7093	2	1C
0005432400096	7093	3	1D
0005432398165	7093	4	2A
0005435715328	7093	5	2C
0005435715330	7093	6	2D
0005435715327	7093	7	4C
0005435443154	7093	8	4E
0005435443165	7093	9	4D
0005435219173	7093	10	4F
0005435715319	7093	11	5D
0005435715320	7093	12	5F
0005435715322	7093	13	6A
0005435443164	7093	14	7A
0005435443163	7093	15	9A
0005435715324	7093	16	10A
0005435443152	7093	17	10C
0005435715318	7093	18	11D
0005432398167	7093	19	11E
0005435219168	7093	20	12E
0005435178473	7093	21	13A
0005435715323	7093	22	13D
0005435715332	7093	23	13E
0005435715333	7093	24	15E
0005435715317	7093	25	16A
0005435443144	7093	26	16F
0005435715331	7093	27	17A
0005435715321	7093	28	17E
0005435715326	7093	29	18C
0005435715325	7093	30	18E
0005435178476	7093	31	19A
0005435715334	7093	32	19C
0005432398166	7093	33	19F
0005435178480	27053	1	3A
0005435443231	27053	2	3C
0005435715176	27053	3	3D
0005432398132	27053	4	4D
0005435715167	27053	5	4E
0005435443235	27053	6	4F
0005432398149	27053	7	5E
0005435443237	27053	8	6A
0005435443234	27053	9	7C
0005435443241	27053	10	7E
0005435715164	27053	11	7F
0005435443233	27053	12	8F
0005435715245	27053	13	10F
0005435715197	27053	14	11D
0005435178481	27053	15	11F
0005435715213	27053	16	12C
0005435715216	27053	17	12F
0005432394039	27053	18	13A
0005435715168	27053	19	15C
0005435715194	27053	20	15D
0005435443239	27053	21	16F
0005435443232	27053	22	17A
0005435443240	27053	23	17C
0005435715175	27053	24	18D
0005432394033	27053	25	19D
0005435443238	27053	26	19F
0005435443236	27053	27	20A
0005434084893	2752	1	1A
0005434084890	2752	2	1B
0005434084895	2752	3	2B
0005434084892	2752	4	3A
0005434084894	2752	5	3B
0005433060368	2752	6	4A
0005434084891	2752	7	6A
0005434084889	2752	8	6B
0005433060390	28521	1	1A
0005434084862	28521	2	2A
0005434084852	28521	3	2B
0005433060391	28521	4	3A
0005434084856	28521	5	3B
0005434084857	28521	6	4A
0005434084855	28521	7	4B
0005433060392	28521	8	5A
0005434084868	28521	9	6A
0005434084848	28521	10	6B
0005435540674	11408	1	1D
0005435540728	11408	2	2C
0005435517626	11408	3	2F
0005435540631	11408	4	3C
0005435540695	11408	5	4D
0005435540654	11408	6	4F
0005435517644	11408	7	5A
0005435517628	11408	8	5C
0005435540697	11408	9	5E
0005435540632	11408	10	6C
0005435517621	11408	11	6D
0005435517707	11408	12	6E
0005435540685	11408	13	6F
0005435517679	11408	14	7C
0005435517607	11408	15	9A
0005435517611	11408	16	12C
0005435517687	11408	17	12E
0005435540684	11408	18	13A
0005435540672	11408	19	13C
0005435540686	11408	20	13E
0005435540671	11408	21	13F
0005435517608	11408	22	14F
0005435540622	11408	23	15C
0005435540629	11408	24	15E
0005435540663	11408	25	16A
0005435517661	11408	26	16C
0005435517660	11408	27	17A
0005435540664	11408	28	17E
0005435540656	11408	29	17F
0005435540623	11408	30	18A
0005435540702	11408	31	18D
0005435540655	11408	32	19A
0005435517604	11408	33	19C
0005435540729	11408	34	19F
0005435540642	11408	35	20A
0005435517645	11408	36	20D
0005435517680	11408	37	20F
0005435540814	22264	1	1F
0005435529067	22264	2	2C
0005435529060	22264	3	2D
0005435529069	22264	4	3A
0005435529071	22264	5	3C
0005435540809	22264	6	3F
0005432294465	22264	7	4D
0005435540807	22264	8	4E
0005435529074	22264	9	4F
0005435540801	22264	10	5C
0005435540817	22264	11	5F
0005435540803	22264	12	6A
0005435529075	22264	13	7A
0005435540815	22264	14	7C
0005435540818	22264	15	7D
0005435529070	22264	16	7E
0005435529072	22264	17	8C
0005435529066	22264	18	8D
0005432294466	22264	19	8E
0005435540820	22264	20	9A
0005435529064	22264	21	9D
0005435529057	22264	22	9F
0005435529055	22264	23	10C
0005435540812	22264	24	10D
0005435529077	22264	25	10F
0005435540816	22264	26	11D
0005435540811	22264	27	11F
0005435540819	22264	28	12D
0005435540821	22264	29	12F
0005435529056	22264	30	13C
0005435540805	22264	31	13D
0005435540800	22264	32	13F
0005435529073	22264	33	14A
0005435529068	22264	34	14C
0005435540808	22264	35	14D
0005435529058	22264	36	14E
0005435529062	22264	37	15E
0005435540810	22264	38	15F
0005435540806	22264	39	16A
0005435529076	22264	40	16D
0005435540804	22264	41	16E
0005435529063	22264	42	18C
0005435540813	22264	43	18D
0005435540802	22264	44	18E
0005435540822	22264	45	18F
0005435529059	22264	46	19C
0005435529065	22264	47	19D
0005435529061	22264	48	20E
0005434906875	2308	1	1A
0005433251064	2308	2	1D
0005433251071	2308	3	2A
0005434906896	2308	4	2D
0005433251059	2308	5	2F
0005434906862	2308	6	3C
0005434906888	2308	7	3D
0005433251117	2308	8	3F
0005434906894	2308	9	4A
0005434906864	2308	10	4C
0005434906871	2308	11	4D
0005433251069	2308	12	5A
0005433250988	2308	13	5C
0005434906863	2308	14	5D
0005434906865	2308	15	5E
0005434906877	2308	16	5F
0005434906899	2308	17	6C
0005434906880	2308	18	6D
0005433251038	2308	19	6F
0005434906874	2308	20	7A
0005433251116	2308	21	7D
0005434906867	2308	22	7E
0005434906869	2308	23	8A
0005434906879	2308	24	8C
0005434906860	2308	25	8D
0005434906902	2308	26	8F
0005433250984	2308	27	9A
0005434906901	2308	28	9D
0005433250985	2308	29	9E
0005434906900	2308	30	9F
0005433250955	2308	31	10A
0005433250993	2308	32	11A
0005433250959	2308	33	11E
0005434906903	2308	34	12A
0005434906898	2308	35	12C
0005434906891	2308	36	12F
0005434906904	2308	37	13C
0005434906861	2308	38	13F
0005434906885	2308	39	14A
0005434906883	2308	40	14C
0005434906886	2308	41	14D
0005434906873	2308	42	14E
0005434906887	2308	43	15A
0005433250956	2308	44	15C
0005434906876	2308	45	15D
0005433251070	2308	46	15E
0005434906870	2308	47	15F
0005434906890	2308	48	16A
0005433251016	2308	49	16C
0005433251015	2308	50	16D
0005434906895	2308	51	16F
0005434906878	2308	52	17A
0005434906868	2308	53	17D
0005434906893	2308	54	17F
0005434906884	2308	55	18C
0005434906859	2308	56	18D
0005434906881	2308	57	18F
0005434906889	2308	58	19C
0005434906882	2308	59	19F
0005434906872	2308	60	20A
0005433400937	2308	61	20C
0005434906866	2308	62	20D
0005434906892	2308	63	20E
0005434906897	2308	64	20F
0005434906447	25582	1	1C
0005434906360	25582	2	1F
0005434906438	25582	3	2C
0005433251242	25582	4	3A
0005434906420	25582	5	3C
0005433251218	25582	6	3D
0005433251233	25582	7	3F
0005434906436	25582	8	4D
0005433251239	25582	9	4E
0005433251234	25582	10	4F
0005433251216	25582	11	5A
0005433251231	25582	12	5C
0005433400959	25582	13	5D
0005433400957	25582	14	5F
0005433251230	25582	15	6C
0005433251213	25582	16	6D
0005433251236	25582	17	7A
0005434906437	25582	18	7C
0005433251219	25582	19	8A
0005434906368	25582	20	8D
0005433251226	25582	21	8C
0005434906415	25582	22	8E
0005433251224	25582	23	8F
0005433251215	25582	24	9A
0005433251214	25582	25	9D
0005433251241	25582	26	9E
0005433251240	25582	27	10C
0005433251238	25582	28	10D
0005433251225	25582	29	10F
0005433251228	25582	30	11F
0005434906367	25582	31	12C
0005433251237	25582	32	12E
0005434906390	25582	33	12F
0005433251227	25582	34	13A
0005434906401	25582	35	13E
0005433251221	25582	36	14D
0005434906389	25582	37	14E
0005433251235	25582	38	14F
0005433251223	25582	39	15A
0005434906441	25582	40	15D
0005433400958	25582	41	15F
0005434906395	25582	42	16A
0005434906391	25582	43	16F
0005433251232	25582	44	17A
0005433251217	25582	45	17C
0005434906445	25582	46	17E
0005434906442	25582	47	18C
0005433251229	25582	48	18D
0005433251220	25582	49	18E
0005433251212	25582	50	18F
0005433251222	25582	51	19C
0005434906370	25582	52	19D
0005434906409	25582	53	20A
0005434906446	25582	54	20C
0005434906407	25582	55	20D
0005434906431	25582	56	20E
0005432620919	2542	1	2A
0005432862171	2542	2	2C
0005432620925	2542	3	2D
0005432620929	2542	4	3A
0005432620930	2542	5	3D
0005432620926	2542	6	4A
0005432620920	2542	7	4B
0005432620922	2542	8	4D
0005432862170	2542	9	5A
0005432620916	2542	10	5C
0005432862181	2542	11	6A
0005432620918	2542	12	7C
0005432620924	2542	13	18A
0005432620931	2542	14	18B
0005432862165	2542	15	18D
0005432620928	2542	16	20B
0005432620921	2542	17	20C
0005432620927	2542	18	20D
0005432620923	2542	19	21C
0005432620917	2542	20	22C
0005432620932	2542	21	22D
0005432620824	28083	1	3B
0005432862235	28083	2	4B
0005432862241	28083	3	5B
0005432620814	28083	4	5D
0005432862238	28083	5	6A
0005432862240	28083	6	6B
0005432862239	28083	7	6C
0005432620812	28083	8	7A
0005432620827	28083	9	7C
0005432620825	28083	10	19B
0005432862234	28083	11	19C
0005432620826	28083	12	20B
0005432620790	28083	13	21C
0005432862237	28083	14	21D
0005432620817	28083	15	22A
0005432620828	28083	16	22C
0005432862236	28083	17	22D
0005432620818	28083	18	23B
0005434097455	11787	1	2A
0005434097454	11787	2	6A
0005434097464	13080	1	1B
0005434097465	13080	2	4A
0005433451603	31009	1	1A
0005433452721	31009	2	1B
0005433452722	31009	3	4B
0005433451602	31009	4	5B
0005433454843	31355	1	2A
0005433454838	31355	2	3A
0005433452713	31355	3	3B
0005433452707	31355	4	4B
0005433452712	31355	5	5A
0005433454837	31355	6	6B
0005433129201	12008	1	2A
0005434184629	12008	2	7D
0005434184630	12008	3	18C
0005433134058	12008	4	20D
0005434326085	12008	5	21B
0005433129200	12008	6	21D
0005433134102	29867	1	1A
0005434142576	29867	2	1B
0005434184647	29867	3	1D
0005433134099	29867	4	2B
0005433131670	29867	5	2C
0005434142575	29867	6	3B
0005434184648	29867	7	4B
0005434326259	29867	8	5A
0005433134100	29867	9	5C
0005433131669	29867	10	6B
0005434326260	29867	11	6C
0005433131671	29867	12	7A
0005433134098	29867	13	7C
0005433134101	29867	14	7D
0005433131672	29867	15	18A
0005433131673	29867	16	20C
0005434183563	29867	17	21A
0005433131668	29867	18	22B
0005434184649	29867	19	22C
0005434142574	29867	20	23A
0005435697099	16502	1	1B
0005435697082	16502	2	2A
0005435697097	16502	3	2B
0005435697090	16502	4	2D
0005435934993	16502	5	3A
0005435697077	16502	6	3B
0005435697096	16502	7	3C
0005435697089	16502	8	3D
0005435697098	16502	9	4C
0005435697083	16502	10	5A
0005435697092	16502	11	5B
0005435697074	16502	12	6A
0005435697088	16502	13	6C
0005435697091	16502	14	6D
0005435697101	16502	15	7A
0005435697078	16502	16	18A
0005435697079	16502	17	18B
0005435697081	16502	18	18C
0005435697087	16502	19	19A
0005435697073	16502	20	19B
0005435697093	16502	21	19D
0005435697084	16502	22	20A
0005435697094	16502	23	20B
0005435697076	16502	24	21B
0005435697100	16502	25	21C
0005435697085	16502	26	21D
0005435697075	16502	27	22A
0005435697086	16502	28	22C
0005435697095	16502	29	23A
0005435697080	16502	30	23B
0005435696907	24717	1	1A
0005435696906	24717	2	1C
0005435697007	24717	3	3D
0005435696975	24717	4	4A
0005435696962	24717	5	4D
0005435697008	24717	6	5A
0005435696915	24717	7	5B
0005435935019	24717	8	6B
0005435935018	24717	9	6D
0005435696916	24717	10	7B
0005435696948	24717	11	7D
0005435696949	24717	12	18B
0005435696852	24717	13	18C
0005435696843	24717	14	19A
0005435696922	24717	15	19D
0005435696869	24717	16	20A
0005435696895	24717	17	21B
0005435696908	24717	18	22A
0005435696844	24717	19	22C
0005435696941	24717	20	23A
0005435696851	24717	21	23B
0005433724766	18808	1	1B
0005433724763	18808	2	3B
0005433724764	18808	3	4A
0005433724765	18808	4	5B
0005432968824	21598	1	1B
0005433724730	21598	2	2A
0005433724737	21598	3	3B
0005432968823	21598	4	6A
0005433724738	21598	5	6B
0005434137518	7339	1	1A
0005434137452	7339	2	1C
0005434137480	7339	3	1D
0005434137483	7339	4	1F
0005434137448	7339	5	2A
0005434137460	7339	6	2C
0005434137490	7339	7	2D
0005434137454	7339	8	2F
0005434137496	7339	9	3A
0005434137450	7339	10	3C
0005434137477	7339	11	3D
0005434137506	7339	12	3F
0005434137464	7339	13	4A
0005434137503	7339	14	4C
0005434137473	7339	15	4D
0005434137500	7339	16	4E
0005434137531	7339	17	4F
0005434137512	7339	18	5A
0005434137517	7339	19	5C
0005434137535	7339	20	5D
0005434137526	7339	21	5E
0005434137537	7339	22	5F
0005434137498	7339	23	6A
0005434137489	7339	24	6C
0005434137478	7339	25	6D
0005434137494	7339	26	6E
0005434137523	7339	27	6F
0005434137527	7339	28	7A
0005434137469	7339	29	7C
0005434137475	7339	30	7D
0005434137513	7339	31	7E
0005434137491	7339	32	7F
0005434137461	7339	33	8A
0005434137462	7339	34	8C
0005434137521	7339	35	8D
0005434137502	7339	36	8E
0005434137481	7339	37	8F
0005434137530	7339	38	9A
0005434137455	7339	39	9C
0005434087476	7339	40	9D
0005434137507	7339	41	9E
0005434137466	7339	42	9F
0005434137467	7339	43	10A
0005434137459	7339	44	10C
0005434137501	7339	45	10D
0005434137486	7339	46	10E
0005434137493	7339	47	10F
0005434137476	7339	48	11A
0005434137529	7339	49	11C
0005434137453	7339	50	11D
0005434137451	7339	51	11E
0005434137457	7339	52	11F
0005434137516	7339	53	12A
0005434137446	7339	54	12C
0005434137519	7339	55	12D
0005434137495	7339	56	12E
0005434137479	7339	57	12F
0005434137505	7339	58	13A
0005434137447	7339	59	13C
0005434087474	7339	60	13D
0005434137456	7339	61	13E
0005434137470	7339	62	13F
0005434137525	7339	63	14A
0005434137536	7339	64	14C
0005434137468	7339	65	14D
0005434137482	7339	66	14E
0005434137509	7339	67	14F
0005434137514	7339	68	15A
0005434137472	7339	69	15C
0005434137492	7339	70	15D
0005434137515	7339	71	15E
0005434137511	7339	72	15F
0005434137522	7339	73	16A
0005434087475	7339	74	16C
0005434137520	7339	75	16D
0005434137465	7339	76	16E
0005434137524	7339	77	16F
0005434137534	7339	78	17A
0005434087473	7339	79	17C
0005434137499	7339	80	17D
0005434137533	7339	81	17E
0005434137487	7339	82	17F
0005434137532	7339	83	18A
0005434137508	7339	84	18C
0005434137449	7339	85	18D
0005434137474	7339	86	18E
0005434137458	7339	87	18F
0005434137471	7339	88	19A
0005434137510	7339	89	19C
0005434137504	7339	90	19D
0005434137528	7339	91	19E
0005434137485	7339	92	19F
0005434137463	7339	93	20A
0005434137488	7339	94	20C
0005434137497	7339	95	20D
0005434087472	7339	96	20E
0005434137484	7339	97	20F
0005434136829	28529	1	1C
0005434136700	28529	2	1D
0005434136844	28529	3	2C
0005434136958	28529	4	2D
0005434136856	28529	5	2F
0005434087445	28529	6	3A
0005434136827	28529	7	3D
0005434136884	28529	8	3F
0005434136701	28529	9	4A
0005434136698	28529	10	4D
0005434136679	28529	11	4E
0005434136684	28529	12	4F
0005434136800	28529	13	5A
0005434136852	28529	14	5F
0005434136749	28529	15	6C
0005434087444	28529	16	6E
0005434136898	28529	17	6F
0005434136938	28529	18	7D
0005434136899	28529	19	7E
0005434136998	28529	20	7F
0005434136871	28529	21	8C
0005434136982	28529	22	8F
0005434136767	28529	23	9E
0005434136853	28529	24	9F
0005434136893	28529	25	10D
0005434136801	28529	26	10E
0005434137037	28529	27	10F
0005434136850	28529	28	11C
0005434087447	28529	29	11D
0005434136907	28529	30	11F
0005434136780	28529	31	12A
0005434136758	28529	32	12D
0005434136721	28529	33	12F
0005434136709	28529	34	13C
0005434136779	28529	35	13D
0005434136933	28529	36	13E
0005434136900	28529	37	13F
0005434136802	28529	38	14F
0005434136934	28529	39	15C
0005434136823	28529	40	15E
0005434136781	28529	41	16C
0005434136865	28529	42	16F
0005434136773	28529	43	17A
0005434136828	28529	44	17C
0005434136967	28529	45	17D
0005434087446	28529	46	17F
0005434136803	28529	47	18A
0005434136683	28529	48	18C
0005434136851	28529	49	18D
0005434136737	28529	50	18E
0005434136807	28529	51	18F
0005434136928	28529	52	19C
0005434136736	28529	53	19D
0005434136798	28529	54	19F
0005435808148	1909	1	1B
0005435808153	1909	2	3B
0005435808146	1909	3	3C
0005434610199	1909	4	3D
0005435808145	1909	5	4B
0005434610198	1909	6	4D
0005435808155	1909	7	5A
0005435808149	1909	8	5C
0005435808154	1909	9	6C
0005433407483	1909	10	7B
0005434610200	1909	11	21C
0005435808150	1909	12	22B
0005435808147	1909	13	22D
0005435808151	1909	14	23A
0005435808152	1909	15	23B
0005434610176	23096	1	6B
0005434503568	16690	1	1C
0005434503569	16690	2	1D
0005434503494	16690	3	2B
0005434503623	16690	4	3A
0005434503542	16690	5	3B
0005434503525	16690	6	3C
0005434503483	16690	7	4A
0005434503564	16690	8	4C
0005434503541	16690	9	5C
0005434503540	16690	10	6C
0005434503616	16690	11	7D
0005434503547	16690	12	18B
0005434503617	16690	13	19B
0005434503658	16690	14	20A
0005434503493	16690	15	20B
0005434503492	16690	16	20D
0005434503488	16690	17	21B
0005434503591	16690	18	21D
0005434503570	16690	19	22C
0005434503563	16690	20	23A
0005434503499	16690	21	23B
0005434503789	22910	1	1A
0005434503807	22910	2	1B
0005434503786	22910	3	1D
0005434503813	22910	4	2B
0005434503799	22910	5	2C
0005434503805	22910	6	2D
0005434503792	22910	7	3A
0005434503788	22910	8	3C
0005434503796	22910	9	3D
0005434503806	22910	10	4A
0005434503783	22910	11	4D
0005434503815	22910	12	5B
0005434503787	22910	13	5C
0005434503812	22910	14	5D
0005434503803	22910	15	6A
0005434503808	22910	16	6B
0005434503814	22910	17	6C
0005434503794	22910	18	6D
0005434503811	22910	19	7B
0005434503820	22910	20	7C
0005434503798	22910	21	7D
0005434503821	22910	22	18A
0005434503804	22910	23	18B
0005434503810	22910	24	18C
0005434503790	22910	25	18D
0005434503816	22910	26	19A
0005434503801	22910	27	19B
0005434503784	22910	28	19C
0005434503818	22910	29	19D
0005434503797	22910	30	20A
0005434503822	22910	31	20B
0005434503809	22910	32	20D
0005434503791	22910	33	21B
0005434503819	22910	34	21C
0005434503785	22910	35	21D
0005434503795	22910	36	22A
0005434503793	22910	37	22C
0005434503802	22910	38	22D
0005434503817	22910	39	23A
0005434503800	22910	40	23B
0005435078216	2185	1	1A
0005435078221	2185	2	2A
0005435078208	2185	3	3B
0005435078209	2185	4	4A
0005435078218	2185	5	4B
0005435078213	2185	6	5A
0005435078207	2185	7	5D
0005435078210	2185	8	6B
0005435078219	2185	9	6D
0005433266578	2185	10	7B
0005435078212	2185	11	18A
0005433266596	2185	12	18B
0005435078211	2185	13	19A
0005433266588	2185	14	19C
0005435078215	2185	15	19D
0005435078214	2185	16	20B
0005435078222	2185	17	20C
0005433266586	2185	18	20D
0005435078220	2185	19	21D
0005435078217	2185	20	23A
0005435078138	24326	1	1A
0005435078105	24326	2	1B
0005433266646	24326	3	1D
0005435078169	24326	4	2A
0005433266649	24326	5	2C
0005435078150	24326	6	3A
0005435078168	24326	7	3D
0005435078083	24326	8	3C
0005433266642	24326	9	4B
0005435078126	24326	10	4C
0005433266645	24326	11	4D
0005433266647	24326	12	5A
0005435078147	24326	13	6A
0005433266644	24326	14	6C
0005433266648	24326	15	6D
0005433266652	24326	16	19B
0005435078082	24326	17	20D
0005433266651	24326	18	22A
0005433266650	24326	19	22D
0005435078127	24326	20	23A
0005433266643	24326	21	23B
0005434988651	6644	1	1C
0005435803238	6644	2	2B
0005434988645	6644	3	2D
0005434988647	6644	4	3C
0005434988649	6644	5	3D
0005434988642	6644	6	4A
0005435803240	6644	7	4D
0005434988646	6644	8	6A
0005434988652	6644	9	6C
0005434988650	6644	10	7C
0005434988640	6644	11	7D
0005434988643	6644	12	18A
0005434988638	6644	13	18B
0005434988648	6644	14	19C
0005434988644	6644	15	20A
0005434988639	6644	16	20C
0005434988641	6644	17	20D
0005435803239	6644	18	21B
0005434988653	6644	19	23A
0005435464490	23622	1	1B
0005435464491	23622	2	21D
0005432382865	30488	1	1A
0005433453747	30488	2	1C
0005432382871	30488	3	1D
0005432382864	30488	4	1F
0005432382853	30488	5	2A
0005432382856	30488	6	2C
0005433449801	30488	7	2D
0005433453748	30488	8	3A
0005433449799	30488	9	3D
0005432382850	30488	10	3F
0005433449802	30488	11	4A
0005432382869	30488	12	4E
0005432382875	30488	13	4D
0005433454856	30488	14	4F
0005433449786	30488	15	5A
0005432382867	30488	16	5D
0005433449785	30488	17	5E
0005433449794	30488	18	5F
0005433449787	30488	19	6C
0005432382868	30488	20	7A
0005432382866	30488	21	8C
0005432382847	30488	22	8D
0005433449791	30488	23	9A
0005432382881	30488	24	8F
0005432382848	30488	25	9C
0005433449792	30488	26	9D
0005432382846	30488	27	9E
0005432382852	30488	28	9F
0005432382872	30488	29	10D
0005433454858	30488	30	10E
0005432382870	30488	31	10F
0005432382844	30488	32	11A
0005433454857	30488	33	11C
0005432382862	30488	34	11D
0005433449795	30488	35	11E
0005433449803	30488	36	12A
0005432382859	30488	37	12C
0005433449797	30488	38	12D
0005432382874	30488	39	12E
0005433449804	30488	40	12F
0005432382883	30488	41	13D
0005432382860	30488	42	13F
0005432382878	30488	43	14A
0005432382863	30488	44	14D
0005433449805	30488	45	14F
0005432382885	30488	46	15A
0005432382880	30488	47	15C
0005432382851	30488	48	15E
0005433449790	30488	49	15F
0005432382861	30488	50	16A
0005433449800	30488	51	16C
0005433449796	30488	52	16E
0005432382854	30488	53	16F
0005433449789	30488	54	17A
0005432382858	30488	55	17C
0005432382884	30488	56	17F
0005432382845	30488	57	18A
0005432382882	30488	58	18C
0005432382877	30488	59	18D
0005432382876	30488	60	18E
0005432382855	30488	61	18F
0005432382849	30488	62	19A
0005432382873	30488	63	19C
0005432382857	30488	64	19F
0005433449793	30488	65	20C
0005433449798	30488	66	20A
0005433449788	30488	67	20D
0005432382879	30488	68	20E
0005433453729	31329	1	1A
0005432382510	31329	2	2F
0005433449653	31329	3	3C
0005432382545	31329	4	5A
0005433449590	31329	5	5C
0005433449583	31329	6	5D
0005432382484	31329	7	6F
0005433451582	31329	8	7E
0005432382490	31329	9	8E
0005432382507	31329	10	8F
0005433449628	31329	11	9C
0005433449615	31329	12	9E
0005433449599	31329	13	10E
0005433449659	31329	14	11A
0005432382501	31329	15	11F
0005433449660	31329	16	12A
0005432382572	31329	17	12C
0005432382559	31329	18	12D
0005433451591	31329	19	13E
0005433451592	31329	20	14A
0005432382536	31329	21	14C
0005433451586	31329	22	14E
0005432382518	31329	23	16A
0005433451593	31329	24	16C
0005433449593	31329	25	16E
0005432382509	31329	26	16F
0005433449598	31329	27	17A
0005432382544	31329	28	17D
0005432382519	31329	29	18A
0005432382508	31329	30	18C
0005432382503	31329	31	18D
0005432382487	31329	32	18F
0005432382521	31329	33	19E
0005433449584	31329	34	20D
0005433449639	31329	35	20F
0005433788172	20833	1	1C
0005433788167	20833	2	2D
0005433788166	20833	3	3B
0005433788174	20833	4	3D
0005433788168	20833	5	4A
0005433788171	20833	6	4C
0005433788176	20833	7	4D
0005433788165	20833	8	5D
0005433788177	20833	9	6A
0005433788163	20833	10	7B
0005433788173	20833	11	7D
0005433788162	20833	12	18D
0005433788161	20833	13	19C
0005433788169	20833	14	20A
0005433788170	20833	15	20C
0005433788164	20833	16	21B
0005433788175	20833	17	22B
0005435548451	26470	1	2B
0005435548452	26470	2	2D
0005435548460	26470	3	4A
0005433788142	26470	4	4C
0005433788144	26470	5	5D
0005435548456	26470	6	6B
0005433788141	26470	7	6C
0005435548453	26470	8	6D
0005435548461	26470	9	7C
0005435548450	26470	10	18D
0005435548455	26470	11	19B
0005435548457	26470	12	20B
0005435548462	26470	13	20D
0005435548458	26470	14	21D
0005435548454	26470	15	22C
0005435548459	26470	16	22D
0005433788148	26470	17	23B
0005435299698	10764	1	1D
0005433126775	10764	2	2B
0005433126776	10764	3	3B
0005433126774	10764	4	5A
0005435304102	10764	5	5C
0005435304101	10764	6	19B
0005435299705	10764	7	21B
0005433131633	10764	8	21D
0005433131632	10764	9	22B
0005435302164	29698	1	1B
0005433129245	29698	2	2C
0005433129243	29698	3	3C
0005433126813	29698	4	4A
0005433126809	29698	5	3D
0005435302167	29698	6	4C
0005433129244	29698	7	5B
0005435299741	29698	8	5D
0005435302165	29698	9	6B
0005433126812	29698	10	7A
0005433126811	29698	11	7D
0005433126810	29698	12	18C
0005435299743	29698	13	18D
0005433129242	29698	14	19A
0005433129241	29698	15	19D
0005435302166	29698	16	21D
0005435299740	29698	17	22D
0005435299742	29698	18	23A
0005435299739	29698	19	23B
0005434287108	2381	1	1B
0005434287113	2381	2	2B
0005434287119	2381	3	2C
0005434287111	2381	4	3A
0005434287106	2381	5	3B
0005434287099	2381	6	3C
0005434287118	2381	7	3D
0005434287104	2381	8	4B
0005432264456	2381	9	4C
0005433109856	2381	10	4D
0005433109892	2381	11	5B
0005434287110	2381	12	5C
0005434287105	2381	13	6A
0005434287109	2381	14	6D
0005434287114	2381	15	7B
0005434287098	2381	16	7C
0005434287116	2381	17	7D
0005434287097	2381	18	18B
0005434287103	2381	19	18C
0005433109865	2381	20	19B
0005434287120	2381	21	20B
0005432264455	2381	22	20D
0005434287107	2381	23	21A
0005434287112	2381	24	21B
0005434287100	2381	25	21C
0005434287117	2381	26	21D
0005434287101	2381	27	22B
0005434287115	2381	28	22D
0005434287102	2381	29	23B
0005434286963	26875	1	1A
0005434286922	26875	2	1B
0005434286972	26875	3	2B
0005434287002	26875	4	2C
0005433109949	26875	5	4A
0005433109950	26875	6	4B
0005433109951	26875	7	4C
0005434286904	26875	8	4D
0005434286924	26875	9	5C
0005434287001	26875	10	6B
0005433109958	26875	11	6C
0005434286956	26875	12	6D
0005434286903	26875	13	7A
0005433109956	26875	14	7B
0005434286923	26875	15	7C
0005433109957	26875	16	7D
0005434286955	26875	17	18B
0005434286937	26875	18	18C
0005433109952	26875	19	18D
0005434286948	26875	20	19B
0005433109955	26875	21	19C
0005433109960	26875	22	19D
0005433109953	26875	23	20A
0005434286925	26875	24	20C
0005433109959	26875	25	20D
0005433109954	26875	26	21A
0005433109961	26875	27	21C
0005434286917	26875	28	21D
0005434286947	26875	29	23B
0005435856172	25478	1	1A
0005434269070	25478	2	2B
0005435856168	25478	3	3D
0005435856171	25478	4	5C
0005435856169	25478	5	7A
0005435856170	25478	6	21D
0005434273063	26654	1	1A
0005434272179	26654	2	2C
0005434272178	26654	3	3B
0005434273064	26654	4	6D
0005435856143	26654	5	18D
0005434520191	6101	1	1A
0005434520187	6101	2	1B
0005434520193	6101	3	1C
0005434520203	6101	4	1D
0005434520210	6101	5	2B
0005434520196	6101	6	2C
0005434520199	6101	7	2D
0005434520190	6101	8	3A
0005434520194	6101	9	3B
0005434520204	6101	10	4A
0005434520192	6101	11	4B
0005434520200	6101	12	5B
0005435314784	6101	13	5D
0005434520197	6101	14	6B
0005435314776	6101	15	6C
0005434520205	6101	16	18A
0005434520188	6101	17	18B
0005434520189	6101	18	18C
0005434520195	6101	19	19A
0005434520208	6101	20	19B
0005435314775	6101	21	20A
0005434520202	6101	22	20B
0005434520201	6101	23	20C
0005434520207	6101	24	20D
0005434520206	6101	25	21A
0005434520209	6101	26	21B
0005435314770	6101	27	21C
0005434520198	6101	28	22B
0005434520186	6101	29	22C
0005435314769	6101	30	22D
0005435314782	6101	31	23A
0005433650478	7165	1	1A
0005433650505	7165	2	1C
0005433650509	7165	3	1F
0005433650474	7165	4	2A
0005433650471	7165	5	2C
0005433650525	7165	6	2D
0005435263479	7165	7	2F
0005435263491	7165	8	3A
0005433650473	7165	9	3C
0005433650519	7165	10	3D
0005433650494	7165	11	3F
0005435263485	7165	12	4C
0005433650502	7165	13	4D
0005433650492	7165	14	4E
0005433650483	7165	15	5A
0005433650490	7165	16	4F
0005433650503	7165	17	5D
0005433650475	7165	18	5E
0005433650498	7165	19	5F
0005433650467	7165	20	6A
0005433650526	7165	21	6C
0005435263490	7165	22	6D
0005433650497	7165	23	6E
0005433650472	7165	24	6F
0005435263489	7165	25	7A
0005433650521	7165	26	7C
0005433650470	7165	27	8A
0005433650514	7165	28	7F
0005433650506	7165	29	8C
0005433650518	7165	30	8E
0005433650524	7165	31	8F
0005433650504	7165	32	9A
0005433650507	7165	33	9D
0005433650463	7165	34	9E
0005433650466	7165	35	9F
0005435263497	7165	36	10A
0005433650501	7165	37	10C
0005433650496	7165	38	10D
0005433650477	7165	39	11C
0005433650522	7165	40	11D
0005433650469	7165	41	11E
0005433650486	7165	42	11F
0005435263487	7165	43	12A
0005433650493	7165	44	12C
0005433650499	7165	45	12F
0005433650479	7165	46	13C
0005433650488	7165	47	13D
0005433650481	7165	48	13E
0005433650476	7165	49	13F
0005435263484	7165	50	14A
0005433650491	7165	51	14C
0005433650523	7165	52	14D
0005435263486	7165	53	14F
0005433650508	7165	54	15A
0005433650464	7165	55	15D
0005433650468	7165	56	15E
0005435263480	7165	57	15F
0005433650489	7165	58	16A
0005433650512	7165	59	16C
0005433650480	7165	60	16D
0005433650482	7165	61	16F
0005433650487	7165	62	17A
0005435263481	7165	63	17C
0005433650511	7165	64	17D
0005433650500	7165	65	17F
0005433650495	7165	66	18A
0005433650517	7165	67	18D
0005433650516	7165	68	18E
0005433650465	7165	69	18F
0005435263488	7165	70	19C
0005435263482	7165	71	19E
0005433650484	7165	72	19F
0005433650485	7165	73	20A
0005433650510	7165	74	20C
0005433650515	7165	75	20D
0005433650520	7165	76	20E
0005433650513	7165	77	20F
0005433650401	27625	1	1A
0005435263553	27625	2	1C
0005433650448	27625	3	1F
0005433650381	27625	4	2A
0005435263546	27625	5	2C
0005435263541	27625	6	2D
0005435263562	27625	7	2F
0005435263544	27625	8	3D
0005435263561	27625	9	3F
0005433650419	27625	10	4A
0005435263537	27625	11	4C
0005433650391	27625	12	4E
0005433650400	27625	13	5A
0005433650384	27625	14	5C
0005435263560	27625	15	5D
0005435263563	27625	16	5E
0005433650454	27625	17	5F
0005435263555	27625	18	6C
0005433650369	27625	19	6E
0005433650449	27625	20	6F
0005433650386	27625	21	7A
0005433650374	27625	22	7E
0005433650387	27625	23	7F
0005433650411	27625	24	8A
0005433650385	27625	25	8F
0005435263545	27625	26	9C
0005435263539	27625	27	9D
0005433650408	27625	28	9E
0005435263559	27625	29	9F
0005433650375	27625	30	10C
0005435263557	27625	31	10E
0005433650392	27625	32	10F
0005435263551	27625	33	11D
0005433650376	27625	34	12A
0005435263549	27625	35	13C
0005433650412	27625	36	13D
0005435263556	27625	37	13E
0005433650420	27625	38	13F
0005435263536	27625	39	14A
0005433650367	27625	40	14C
0005435263543	27625	41	14F
0005435263552	27625	42	15F
0005435263540	27625	43	16C
0005435263542	27625	44	16D
0005435263547	27625	45	17A
0005435263558	27625	46	18A
0005433650388	27625	47	18E
0005433650370	27625	48	19A
0005435263554	27625	49	20A
0005435263550	27625	50	20C
0005435263548	27625	51	20D
0005435263538	27625	52	20F
0005433868110	4788	1	1A
0005433868130	4788	2	1B
0005433868097	4788	3	1C
0005433868105	4788	4	1D
0005433868115	4788	5	2A
0005433868123	4788	6	2B
0005433868136	4788	7	2C
0005433868134	4788	8	2D
0005433868106	4788	9	3A
0005433868101	4788	10	3B
0005433868117	4788	11	3C
0005433868118	4788	12	3D
0005433868100	4788	13	4A
0005433868116	4788	14	4B
0005433868133	4788	15	4C
0005433868121	4788	16	4D
0005433868128	4788	17	5A
0005433868109	4788	18	5B
0005433868124	4788	19	5D
0005433868119	4788	20	6B
0005433868095	4788	21	6C
0005433868096	4788	22	6D
0005433868131	4788	23	7A
0005433868129	4788	24	7B
0005433868107	4788	25	7C
0005433868125	4788	26	18B
0005433868103	4788	27	18C
0005433868102	4788	28	18D
0005433868120	4788	29	19B
0005433868132	4788	30	19C
0005433868135	4788	31	19D
0005433868098	4788	32	20A
0005433868113	4788	33	20B
0005433868104	4788	34	20D
0005433868127	4788	35	21A
0005433868099	4788	36	21C
0005433868114	4788	37	21D
0005433868112	4788	38	22B
0005433868122	4788	39	22C
0005433868108	4788	40	22D
0005433868111	4788	41	23A
0005433868126	4788	42	23B
0005433867764	32591	1	1B
0005433867751	32591	2	1C
0005433867850	32591	3	1D
0005435860462	32591	4	2C
0005433867849	32591	5	3C
0005435860466	32591	6	4C
0005433867872	32591	7	4D
0005433867802	32591	8	5A
0005433867732	32591	9	5B
0005433867776	32591	10	5C
0005433867966	32591	11	6C
0005433867820	32591	12	7A
0005433867755	32591	13	18C
0005433867780	32591	14	18D
0005435860464	32591	15	19A
0005435860463	32591	16	19C
0005433867873	32591	17	20B
0005433867766	32591	18	21B
0005433867733	32591	19	21C
0005433867810	32591	20	22A
0005435860465	32591	21	22D
0005433867752	32591	22	23B
0005434663302	3436	1	2A
0005434663306	3436	2	2C
0005434663296	3436	3	2D
0005435911318	3436	4	3C
0005434663305	3436	5	4B
0005434663298	3436	6	5A
0005434663304	3436	7	5D
0005434460489	3436	8	6A
0005434663301	3436	9	6B
0005434663300	3436	10	6D
0005434663299	3436	11	7A
0005435911335	3436	12	7B
0005434460490	3436	13	7C
0005434461630	3436	14	18A
0005434663295	3436	15	18C
0005435911316	3436	16	18D
0005434663303	3436	17	19A
0005434460488	3436	18	19D
0005435911319	3436	19	20B
0005434461628	3436	20	20C
0005434663294	3436	21	21A
0005434663297	3436	22	21B
0005434663292	3436	23	21C
0005434663293	3436	24	22A
0005435911315	3436	25	21D
0005434461629	3436	26	22B
0005435911320	3436	27	22D
0005434460487	3436	28	23B
0005435911387	12489	1	2C
0005435911393	12489	2	4B
0005435911386	12489	3	4C
0005435911390	12489	4	4D
0005435911392	12489	5	5B
0005434663218	12489	6	6A
0005434663187	12489	7	7A
0005434663216	12489	8	7B
0005434663172	12489	9	7D
0005435911389	12489	10	18D
0005434663192	12489	11	19B
0005435911391	12489	12	21B
0005434663217	12489	13	21C
0005435911388	12489	14	21D
0005433867872	14523	1	1C
0005433867966	14523	2	2B
0005433867820	14523	3	3B
0005433867751	14523	4	3D
0005435860464	14523	5	4A
0005433867802	14523	6	4B
0005433867780	14523	7	4C
0005433867755	14523	8	4D
0005433867776	14523	9	5B
0005433867873	14523	10	5C
0005433867732	14523	11	5D
0005435860465	14523	12	6A
0005435860463	14523	13	6B
0005433867733	14523	14	6D
0005435860462	14523	15	7A
0005433867752	14523	16	18C
0005433867766	14523	17	18D
0005433867850	14523	18	19D
0005433867849	14523	19	20B
0005433867810	14523	20	21C
0005435860466	14523	21	22A
0005433867764	14523	22	22C
0005433868061	32657	1	1A
0005433868081	32657	2	1B
0005433868091	32657	3	1C
0005433868094	32657	4	2A
0005433868065	32657	5	2B
0005433868077	32657	6	2C
0005433868078	32657	7	2D
0005433868082	32657	8	3B
0005433868083	32657	9	3C
0005433868069	32657	10	3D
0005433868059	32657	11	4A
0005433868066	32657	12	4B
0005433868088	32657	13	4C
0005433868064	32657	14	4D
0005433868079	32657	15	5A
0005433868084	32657	16	5B
0005433868062	32657	17	5C
0005433868055	32657	18	5D
0005433868074	32657	19	6A
0005433868085	32657	20	6D
0005433868070	32657	21	7A
0005433868080	32657	22	7B
0005433868068	32657	23	18A
0005433868056	32657	24	18B
0005433868075	32657	25	18C
0005433868092	32657	26	18D
0005433868073	32657	27	19A
0005433868087	32657	28	19B
0005433868063	32657	29	19C
0005433868093	32657	30	19D
0005433868089	32657	31	20A
0005433868072	32657	32	20C
0005433868054	32657	33	20D
0005433868057	32657	34	21A
0005433868086	32657	35	21B
0005433868060	32657	36	21C
0005433868067	32657	37	21D
0005433868090	32657	38	22A
0005433868071	32657	39	22D
0005433868058	32657	40	23A
0005433868076	32657	41	23B
0005432798961	12116	1	1A
0005432799027	12116	2	1C
0005432799016	12116	3	1D
0005432799037	12116	4	2A
0005432798967	12116	5	2C
0005432798960	12116	6	3D
0005432799068	12116	7	4A
0005432798956	12116	8	4B
0005432799034	12116	9	4C
0005432798976	12116	10	4D
0005432798955	12116	11	5A
0005432799001	12116	12	5C
0005432799021	12116	13	6B
0005432798963	12116	14	6C
0005432799097	12116	15	6D
0005432799006	12116	16	7A
0005432798995	12116	17	7D
0005432799035	12116	18	18C
0005432799002	12116	19	18D
0005432798954	12116	20	19A
0005432799041	12116	21	19C
0005432798968	12116	22	20A
0005432798953	12116	23	20B
0005432798959	12116	24	21A
0005432799039	12116	25	21C
0005432799098	12116	26	21D
0005432798983	12116	27	22A
0005432799094	12116	28	22D
0005432799211	14796	1	1C
0005432799200	14796	2	1D
0005432799209	14796	3	2A
0005432799189	14796	4	2B
0005432799190	14796	5	2C
0005432799206	14796	6	2D
0005432799196	14796	7	3A
0005432799194	14796	8	3B
0005432799201	14796	9	3C
0005432799193	14796	10	3D
0005432799187	14796	11	4A
0005432799204	14796	12	4C
0005432799203	14796	13	5A
0005432799210	14796	14	5B
0005432799207	14796	15	5C
0005432799205	14796	16	6B
0005432799185	14796	17	6C
0005432799188	14796	18	6D
0005432799186	14796	19	7C
0005432799197	14796	20	7D
0005432799192	14796	21	18A
0005432799195	14796	22	19C
0005432799202	14796	23	19D
0005432799198	14796	24	20C
0005432799199	14796	25	21B
0005432799184	14796	26	22A
0005432799191	14796	27	22B
0005432799208	14796	28	22C
0005432799212	14796	29	23B
0005434299365	7066	1	1A
0005434407276	7066	2	1C
0005434299370	7066	3	1F
0005434299372	7066	4	1D
0005434407255	7066	5	2D
0005434299379	7066	6	3A
0005434407258	7066	7	2F
0005432153882	7066	8	3D
0005435310873	7066	9	4A
0005434407251	7066	10	4C
0005434299361	7066	11	4B
0005434407256	7066	12	4D
0005434299374	7066	13	4F
0005434299368	7066	14	4E
0005434407233	7066	15	5A
0005434407263	7066	16	5B
0005434407279	7066	17	5D
0005434407230	7066	18	5C
0005434407245	7066	19	5E
0005434407246	7066	20	6A
0005434407274	7066	21	5F
0005434299380	7066	22	6B
0005434299381	7066	23	6C
0005434407262	7066	24	6D
0005434407265	7066	25	6E
0005434407232	7066	26	6F
0005434407223	7066	27	7B
0005434407261	7066	28	7A
0005434407278	7066	29	7C
0005434407257	7066	30	7E
0005434407268	7066	31	7F
0005434299367	7066	32	8A
0005434407252	7066	33	8D
0005434407236	7066	34	8C
0005432153881	7066	35	8E
0005434299378	7066	36	8F
0005434407239	7066	37	9B
0005434407224	7066	38	9D
0005435310840	7066	39	9C
0005434407237	7066	40	9F
0005434407281	7066	41	9E
0005434407247	7066	42	10B
0005434299382	7066	43	10C
0005434407241	7066	44	10E
0005435310872	7066	45	10D
0005434407253	7066	46	11A
0005432108229	7066	47	11F
0005432153884	7066	48	11E
0005435293045	7066	49	12B
0005434299376	7066	50	12A
0005434407269	7066	51	12C
0005435293075	7066	52	12D
0005434407219	7066	53	12F
0005434407234	7066	54	13A
0005435310856	7066	55	13C
0005434407267	7066	56	13B
0005434299366	7066	57	13D
0005434299364	7066	58	13E
0005434407271	7066	59	14A
0005435310858	7066	60	13F
0005434299383	7066	61	14C
0005434299375	7066	62	14B
0005432153878	7066	63	14D
0005432153883	7066	64	14F
0005434407226	7066	65	14E
0005434407221	7066	66	15A
0005434407280	7066	67	15B
0005434407259	7066	68	15C
0005434407218	7066	69	15D
0005434407244	7066	70	15E
0005434407248	7066	71	16B
0005434299369	7066	72	16A
0005435293061	7066	73	16C
0005435293076	7066	74	16D
0005434407272	7066	75	16F
0005434299371	7066	76	16E
0005435293062	7066	77	17A
0005434407225	7066	78	17B
0005435310867	7066	79	17C
0005432153879	7066	80	17D
0005434407227	7066	81	17F
0005434407277	7066	82	17E
0005434299362	7066	83	18A
0005435293074	7066	84	18B
0005434407249	7066	85	18C
0005434407275	7066	86	19A
0005434407260	7066	87	18F
0005434407240	7066	88	19B
0005434407229	7066	89	19E
0005434407273	7066	90	19D
0005434407242	7066	91	19F
0005434407235	7066	92	20B
0005434407228	7066	93	20D
0005434407243	7066	94	20C
0005434407266	7066	95	20E
0005435310857	7066	96	20F
0005434407250	7066	97	21B
0005434407231	7066	98	21A
0005434407270	7066	99	21D
0005434299363	7066	100	21C
0005434407238	7066	101	21E
0005435293096	7066	102	22A
0005432153880	7066	103	21F
0005435310855	7066	104	22D
0005434407222	7066	105	22F
0005434407254	7066	106	22E
0005432108228	7066	107	23B
0005434299373	7066	108	23C
0005434407264	7066	109	23E
0005434407220	7066	110	23D
0005434299377	7066	111	23F
0005434406727	26921	1	1C
0005434406824	26921	2	1D
0005434406825	26921	3	2A
0005435310958	26921	4	3A
0005435310960	26921	5	3C
0005434299260	26921	6	3F
0005435293145	26921	7	4B
0005434299161	26921	8	4A
0005434406728	26921	9	4D
0005434406778	26921	10	4C
0005434406717	26921	11	5A
0005434299160	26921	12	5C
0005434406748	26921	13	5B
0005435293148	26921	14	5D
0005434406647	26921	15	5E
0005434406777	26921	16	5F
0005434299285	26921	17	6B
0005434299244	26921	18	6C
0005435310967	26921	19	6E
0005434406701	26921	20	6D
0005435310965	26921	21	6F
0005434406686	26921	22	7B
0005434406667	26921	23	7A
0005435310964	26921	24	7C
0005435293147	26921	25	7E
0005435293155	26921	26	8A
0005435293151	26921	27	8B
0005435310950	26921	28	8D
0005434406989	26921	29	8F
0005434299236	26921	30	9A
0005434299279	26921	31	9C
0005434406704	26921	32	9B
0005435310951	26921	33	9D
0005432058346	26921	34	9F
0005435310953	26921	35	10B
0005434299227	26921	36	10E
0005434299204	26921	37	11B
0005434406646	26921	38	11F
0005435293150	26921	39	12B
0005434406680	26921	40	12D
0005435310954	26921	41	12C
0005435293152	26921	42	12E
0005434406809	26921	43	12F
0005435310952	26921	44	13A
0005434299217	26921	45	13C
0005435310966	26921	46	13B
0005434299219	26921	47	13D
0005435310961	26921	48	14A
0005435293146	26921	49	14C
0005434406670	26921	50	14D
0005434406668	26921	51	14E
0005434406723	26921	52	15A
0005434406823	26921	53	14F
0005435310968	26921	54	15B
0005434406669	26921	55	15D
0005435293154	26921	56	16B
0005434406681	26921	57	16A
0005434406639	26921	58	16C
0005435310963	26921	59	16D
0005434299218	26921	60	16F
0005434299220	26921	61	16E
0005432058347	26921	62	17A
0005435310956	26921	63	17B
0005435310949	26921	64	17C
0005434299261	26921	65	17D
0005434299221	26921	66	18A
0005435310955	26921	67	17F
0005435310959	26921	68	18B
0005434406855	26921	69	18E
0005434299209	26921	70	18F
0005435293156	26921	71	19B
0005432058344	26921	72	19D
0005434406664	26921	73	19E
0005434406665	26921	74	20A
0005434406776	26921	75	20C
0005435293149	26921	76	20B
0005434406683	26921	77	20D
0005434406645	26921	78	20F
0005435310962	26921	79	21B
0005434299284	26921	80	21A
0005434406892	26921	81	21C
0005435310957	26921	82	21F
0005435293153	26921	83	21E
0005434406682	26921	84	22A
0005434406724	26921	85	22C
0005432058345	26921	86	22D
0005434299262	26921	87	22E
0005434406687	26921	88	23A
0005434406694	26921	89	23B
0005435293144	26921	90	23D
0005434406822	26921	91	23E
0005432604028	6452	1	1A
0005432604032	6452	2	1B
0005432604026	6452	3	1C
0005432604027	6452	4	1D
0005432604010	6452	5	2A
0005432604030	6452	6	2B
0005432604037	6452	7	2C
0005432604035	6452	8	2D
0005434512076	6452	9	3A
0005432604016	6452	10	3B
0005432604018	6452	11	3C
0005432604043	6452	12	3D
0005432604029	6452	13	4A
0005432604031	6452	14	4B
0005432604021	6452	15	4C
0005434512073	6452	16	4D
0005432604044	6452	17	5A
0005432604019	6452	18	5B
0005432604034	6452	19	5D
0005432604041	6452	20	6A
0005434512079	6452	21	6B
0005432604046	6452	22	6C
0005432604022	6452	23	6D
0005432604017	6452	24	7A
0005432604012	6452	25	7B
0005432604013	6452	26	7C
0005432604040	6452	27	7D
0005432604023	6452	28	18A
0005432604007	6452	29	18B
0005432604024	6452	30	18C
0005432604014	6452	31	18D
0005432604009	6452	32	19A
0005432604025	6452	33	19B
0005432604045	6452	34	19C
0005432604036	6452	35	19D
0005432604039	6452	36	20A
0005434512078	6452	37	20B
0005432604006	6452	38	20C
0005432604020	6452	39	20D
0005432604042	6452	40	21A
0005434512080	6452	41	21B
0005432604008	6452	42	21C
0005434512075	6452	43	21D
0005432604015	6452	44	22A
0005432604011	6452	45	22B
0005434512077	6452	46	22C
0005432604038	6452	47	22D
0005432604033	6452	48	23A
0005434512074	6452	49	23B
0005432603643	21389	1	1D
0005432603737	21389	2	2B
0005432603739	21389	3	3A
0005432603645	21389	4	3B
0005432603797	21389	5	3C
0005432603659	21389	6	3D
0005432603671	21389	7	4B
0005432603672	21389	8	4C
0005432603738	21389	9	4D
0005432603682	21389	10	5B
0005432603652	21389	11	5C
0005432603651	21389	12	6A
0005432603701	21389	13	6B
0005432603658	21389	14	7A
0005432603649	21389	15	7C
0005432603660	21389	16	7D
0005432603654	21389	17	18A
0005432603740	21389	18	18B
0005432603650	21389	19	19A
0005432603644	21389	20	19D
0005432603699	21389	21	20B
0005432603653	21389	22	21B
0005432603783	21389	23	21C
0005432603702	21389	24	22D
0005434906401	15020	1	1A
0005434906447	15020	2	1C
0005433251237	15020	3	1D
0005433251233	15020	4	2C
0005433251222	15020	5	2F
0005433251221	15020	6	3C
0005433251234	15020	7	3D
0005434906420	15020	8	3F
0005434906389	15020	9	4D
0005433251240	15020	10	5C
0005433251235	15020	11	5E
0005433251228	15020	12	5F
0005433251223	15020	13	6A
0005433251230	15020	14	6D
0005433251229	15020	15	6E
0005433251225	15020	16	6F
0005433251242	15020	17	7A
0005434906446	15020	18	7F
0005434906407	15020	19	8D
0005433251232	15020	20	8C
0005433251216	15020	21	8E
0005433251212	15020	22	8F
0005433251220	15020	23	9D
0005434906431	15020	24	9F
0005434906391	15020	25	10F
0005433251238	15020	26	11A
0005434906415	15020	27	11E
0005433251214	15020	28	11F
0005433251213	15020	29	12A
0005433251236	15020	30	12C
0005434906442	15020	31	13A
0005434906367	15020	32	13F
0005433251219	15020	33	14A
0005434906445	15020	34	14D
0005434906437	15020	35	14F
0005433251224	15020	36	15D
0005434906368	15020	37	15E
0005433251231	15020	38	16A
0005434906438	15020	39	16E
0005433251226	15020	40	17C
0005434906360	15020	41	17E
0005434906436	15020	42	17F
0005434906395	15020	43	18A
0005433251218	15020	44	18E
0005433251227	15020	45	18F
0005434906409	15020	46	19A
0005434906390	15020	47	19E
0005433251241	15020	48	19F
0005434906441	15020	49	20A
0005433251215	15020	50	20C
0005433251239	15020	51	20D
0005433251217	15020	52	20E
0005434906370	15020	53	20F
0005433250967	25870	1	1A
0005433251096	25870	2	1C
0005433251012	25870	3	1D
0005434906818	25870	4	1F
0005433250958	25870	5	2A
0005434906848	25870	6	2D
0005434906852	25870	7	3A
0005433251019	25870	8	3C
0005434906857	25870	9	3D
0005433251098	25870	10	3F
0005434906826	25870	11	4A
0005434906817	25870	12	4C
0005434906816	25870	13	4D
0005433250941	25870	14	4E
0005433250953	25870	15	4F
0005434906823	25870	16	5D
0005434906839	25870	17	5E
0005434906844	25870	18	5F
0005434906834	25870	19	6A
0005434906855	25870	20	6C
0005433251095	25870	21	6E
0005433251013	25870	22	6F
0005433251033	25870	23	7A
0005434906845	25870	24	7C
0005434906830	25870	25	7D
0005434906814	25870	26	7E
0005433250973	25870	27	8A
0005434906835	25870	28	8C
0005433250952	25870	29	8D
0005434906821	25870	30	8F
0005433251011	25870	31	9A
0005434906853	25870	32	9C
0005433251031	25870	33	9D
0005434906820	25870	34	9E
0005434906824	25870	35	10A
0005434906847	25870	36	10E
0005434906838	25870	37	11A
0005434906825	25870	38	11C
0005434906842	25870	39	11D
0005434906850	25870	40	11F
0005434906836	25870	41	12A
0005434906815	25870	42	13A
0005433250954	25870	43	13C
0005434906829	25870	44	13E
0005434906843	25870	45	14A
0005434906856	25870	46	14C
0005434906822	25870	47	14D
0005434906854	25870	48	14E
0005434906832	25870	49	15C
0005434906827	25870	50	15D
0005434906858	25870	51	16D
0005434906819	25870	52	16C
0005433250983	25870	53	16F
0005433251066	25870	54	17A
0005433250936	25870	55	17E
0005434906828	25870	56	17F
0005434906851	25870	57	18A
0005433251058	25870	58	18D
0005433251065	25870	59	18E
0005434906833	25870	60	18F
0005433250962	25870	61	19A
0005434906837	25870	62	19C
0005433250979	25870	63	19D
0005434906846	25870	64	19E
0005434906849	25870	65	19F
0005434906840	25870	66	20A
0005434906841	25870	67	20C
0005433250974	25870	68	20D
0005434906831	25870	69	20F
0005433008278	14194	1	1A
0005433008272	14194	2	2A
0005433008258	14194	3	3F
0005433008264	14194	4	4C
0005433008254	14194	5	4F
0005433008241	14194	6	5C
0005433008253	14194	7	5E
0005433008261	14194	8	5F
0005433008275	14194	9	6C
0005433008259	14194	10	7A
0005433008285	14194	11	7D
0005433008270	14194	12	7E
0005433008263	14194	13	7F
0005433008277	14194	14	8A
0005433008255	14194	15	8D
0005433008282	14194	16	8F
0005433008252	14194	17	9A
0005433008262	14194	18	9D
0005433008273	14194	19	10C
0005433008281	14194	20	10D
0005433008284	14194	21	11A
0005433008260	14194	22	11C
0005433008280	14194	23	11D
0005433008247	14194	24	11E
0005433008256	14194	25	11F
0005433008240	14194	26	12D
0005433008276	14194	27	12F
0005433008257	14194	28	13E
0005433008245	14194	29	13F
0005433008246	14194	30	14C
0005433008251	14194	31	14D
0005433008242	14194	32	14E
0005433008267	14194	33	15D
0005433008271	14194	34	16A
0005433008265	14194	35	16C
0005433008266	14194	36	17C
0005433008268	14194	37	17D
0005433008248	14194	38	18C
0005433008274	14194	39	18D
0005433008244	14194	40	19A
0005433008243	14194	41	19E
0005433008283	14194	42	19F
0005433008249	14194	43	20A
0005433008279	14194	44	20C
0005433008269	14194	45	20E
0005433008250	14194	46	20F
0005433007989	22845	1	1C
0005433007870	22845	2	1D
0005433008072	22845	3	1F
0005433007895	22845	4	2A
0005433007839	22845	5	2F
0005433007836	22845	6	3A
0005433007892	22845	7	3C
0005433810512	22845	8	4E
0005433007828	22845	9	5A
0005433007859	22845	10	5C
0005433007976	22845	11	5D
0005433007936	22845	12	5E
0005433007881	22845	13	5F
0005433007901	22845	14	6A
0005433007849	22845	15	8C
0005433007861	22845	16	9C
0005433007990	22845	17	9F
0005433007869	22845	18	10A
0005433007832	22845	19	11A
0005433007882	22845	20	11F
0005433810511	22845	21	12A
0005433007977	22845	22	12C
0005433007887	22845	23	12F
0005433008035	22845	24	13D
0005433007829	22845	25	13F
0005433007991	22845	26	14C
0005433007886	22845	27	14D
0005433008071	22845	28	16C
0005433007988	22845	29	17D
0005433007900	22845	30	17F
0005433007914	22845	31	18A
0005433008037	22845	32	18C
0005433810513	22845	33	18E
0005433008036	22845	34	18F
0005433810514	22845	35	19C
0005433007889	22845	36	19E
0005433810510	22845	37	20A
0005433007912	22845	38	20C
0005433007935	22845	39	20E
0005434925247	14930	1	2A
0005434925252	14930	2	3C
0005434925250	14930	3	3D
0005434925272	14930	4	6F
0005434925279	14930	5	10F
0005434925310	14930	6	11A
0005434925261	14930	7	13D
0005434925291	14930	8	13E
0005434925292	14930	9	16A
0005434925249	14930	10	16D
0005434925271	14930	11	17A
0005434925270	14930	12	20D
0005434925513	20525	1	1C
0005434925519	20525	2	1F
0005434925510	20525	3	1D
0005434925505	20525	4	2C
0005434925527	20525	5	5A
0005434925511	20525	6	6D
0005434925530	20525	7	7D
0005434925526	20525	8	7E
0005434925515	20525	9	7F
0005434925522	20525	10	9D
0005434925518	20525	11	9E
0005434925516	20525	12	9F
0005434925523	20525	13	10D
0005434925532	20525	14	10E
0005434925503	20525	15	11C
0005434925529	20525	16	12C
0005434925531	20525	17	12E
0005434925514	20525	18	14D
0005434925524	20525	19	14E
0005434925507	20525	20	15A
0005434925525	20525	21	15E
0005434925506	20525	22	15F
0005434925520	20525	23	16A
0005434925509	20525	24	16C
0005434925521	20525	25	16D
0005434925508	20525	26	17D
0005434925504	20525	27	18A
0005434925517	20525	28	18F
0005434925528	20525	29	20D
0005434925512	20525	30	20E
0005435487664	15815	1	1A
0005435487663	15815	2	2B
0005435487672	15815	3	2D
0005435487655	15815	4	3A
0005435487658	15815	5	3B
0005435487660	15815	6	3D
0005435487673	15815	7	4A
0005435487656	15815	8	4C
0005435487667	15815	9	4D
0005435487668	15815	10	5D
0005435487662	15815	11	6A
0005435487669	15815	12	6B
0005435487666	15815	13	6D
0005435487661	15815	14	18D
0005435487671	15815	15	19D
0005435998957	15815	16	20B
0005435487659	15815	17	20C
0005435487654	15815	18	20D
0005435487675	15815	19	21A
0005435487674	15815	20	21B
0005435487665	15815	21	21D
0005435487653	15815	22	22B
0005435487657	15815	23	23A
0005435487670	15815	24	23B
0005435999103	19712	1	1C
0005435999098	19712	2	1D
0005435999096	19712	3	2B
0005435999101	19712	4	2D
0005435999095	19712	5	3C
0005435999108	19712	6	3D
0005435999097	19712	7	4C
0005435487497	19712	8	5A
0005435999100	19712	9	6C
0005435487513	19712	10	6D
0005435487512	19712	11	7B
0005435999106	19712	12	7C
0005435999099	19712	13	7D
0005435487496	19712	14	18D
0005435487472	19712	15	19C
0005435999104	19712	16	19D
0005435487477	19712	17	20A
0005435999102	19712	18	20B
0005435999107	19712	19	20C
0005435999105	19712	20	21B
0005435999094	19712	21	21C
0005435999110	19712	22	22A
0005435999109	19712	23	22B
0005435487514	19712	24	22C
0005435999111	19712	25	23A
0005435487478	19712	26	23B
0005435839228	6018	1	1C
0005435839241	6018	2	1D
0005435839236	6018	3	2A
0005435472520	6018	4	2D
0005435472549	6018	5	2C
0005435472548	6018	6	3A
0005435472533	6018	7	4C
0005435839235	6018	8	5A
0005435472532	6018	9	5C
0005435839226	6018	10	5F
0005435472537	6018	11	6C
0005435472573	6018	12	6E
0005435839230	6018	13	8A
0005435839233	6018	14	8B
0005435839225	6018	15	8E
0005435839227	6018	16	9B
0005432660803	6018	17	9A
0005435839220	6018	18	9F
0005435839222	6018	19	9E
0005435839246	6018	20	10C
0005435839223	6018	21	10E
0005432660802	6018	22	11A
0005435839219	6018	23	11E
0005435839242	6018	24	12A
0005435472536	6018	25	12C
0005435839229	6018	26	12E
0005435839224	6018	27	13A
0005435839243	6018	28	13C
0005435472511	6018	29	13D
0005432537022	6018	30	13F
0005432659691	6018	31	14C
0005435472558	6018	32	14F
0005432658577	6018	33	14E
0005435839238	6018	34	15B
0005435839234	6018	35	15A
0005432659690	6018	36	15C
0005435472512	6018	37	16A
0005435839218	6018	38	16C
0005435472538	6018	39	16B
0005432142228	6018	40	16D
0005435839221	6018	41	17A
0005435472539	6018	42	17D
0005435839240	6018	43	17C
0005432658576	6018	44	18C
0005435472572	6018	45	18B
0005435839231	6018	46	19C
0005435839244	6018	47	19D
0005435839239	6018	48	20A
0005432142227	6018	49	20B
0005435839237	6018	50	21A
0005435839232	6018	51	21B
0005435839245	6018	52	21E
0005435838973	18078	1	1C
0005435472670	18078	2	1A
0005435838987	18078	3	1F
0005435838984	18078	4	2C
0005435472665	18078	5	2D
0005435839060	18078	6	3A
0005435839101	18078	7	4F
0005435472676	18078	8	5A
0005435472679	18078	9	5D
0005435838967	18078	10	6B
0005435838982	18078	11	8A
0005435472678	18078	12	8B
0005435838969	18078	13	8C
0005435839091	18078	14	9B
0005435472677	18078	15	9A
0005435472673	18078	16	9D
0005435472675	18078	17	10C
0005432537043	18078	18	10E
0005435472663	18078	19	10D
0005435472667	18078	20	10F
0005435839000	18078	21	11F
0005435839073	18078	22	11E
0005435839019	18078	23	12D
0005435472664	18078	24	12C
0005435472672	18078	25	13A
0005435472680	18078	26	13F
0005435839092	18078	27	16C
0005435472666	18078	28	16F
0005435472674	18078	29	16E
0005435472669	18078	30	17A
0005435838986	18078	31	17C
0005435838968	18078	32	17F
0005432537042	18078	33	19C
0005435839002	18078	34	19E
0005435472671	18078	35	20D
0005435472668	18078	36	20E
0005433462708	19909	1	28A
0005435103865	23029	1	1C
0005433284873	23029	2	1D
0005433284773	23029	3	4A
0005433284828	23029	4	4D
0005433284840	23029	5	5D
0005433284795	23029	6	6A
0005433284796	23029	7	6F
0005433284845	23029	8	7C
0005435103864	23029	9	7D
0005435103862	23029	10	10C
0005433284891	23029	11	10D
0005435103866	23029	12	11A
0005433284818	23029	13	11B
0005433284842	23029	14	13A
0005433284815	23029	15	13F
0005433284787	23029	16	15A
0005433284876	23029	17	14F
0005433284825	23029	18	15C
0005433284841	23029	19	16E
0005433284872	23029	20	18C
0005433284819	23029	21	18F
0005433284890	23029	22	19E
0005433284786	23029	23	19F
0005433284798	23029	24	20C
0005435103863	23029	25	22D
0005433284892	23029	26	23F
0005433285061	32067	1	2D
0005433285041	32067	2	3C
0005433285046	32067	3	3F
0005433285065	32067	4	4B
0005433285054	32067	5	4A
0005433285057	32067	6	4C
0005433285059	32067	7	4D
0005433285040	32067	8	4E
0005433285062	32067	9	5B
0005433285069	32067	10	5E
0005433285048	32067	11	6B
0005433285053	32067	12	7D
0005433285043	32067	13	8C
0005433285045	32067	14	10E
0005433285056	32067	15	11C
0005433285047	32067	16	11B
0005433285044	32067	17	12E
0005433285050	32067	18	13D
0005433285055	32067	19	14E
0005433285064	32067	20	14F
0005433285068	32067	21	15B
0005433285039	32067	22	16B
0005433285051	32067	23	17C
0005433285067	32067	24	18B
0005433285070	32067	25	18D
0005433285042	32067	26	19A
0005433285058	32067	27	19B
0005433285063	32067	28	20A
0005433285052	32067	29	20B
0005433285066	32067	30	22B
0005433285049	32067	31	23A
0005433285060	32067	32	23C
0005433111476	19947	1	1D
0005432892742	19947	2	3C
0005433112357	19947	3	3A
0005432892729	19947	4	3D
0005433111481	19947	5	5C
0005432892736	19947	6	5D
0005433111485	19947	7	6A
0005432802429	19947	8	6F
0005432892726	19947	9	7A
0005432892731	19947	10	7C
0005433111479	19947	11	7E
0005432892735	19947	12	7F
0005432892727	19947	13	8B
0005432892739	19947	14	8E
0005433111483	19947	15	9B
0005432802435	19947	16	9E
0005433112360	19947	17	10A
0005433112359	19947	18	9F
0005432892738	19947	19	10D
0005432892741	19947	20	10F
0005433111484	19947	21	11B
0005433112356	19947	22	11F
0005432802430	19947	23	12B
0005432892734	19947	24	12C
0005432892730	19947	25	12F
0005433112358	19947	26	14A
0005433111482	19947	27	13F
0005433111474	19947	28	14D
0005432892732	19947	29	14F
0005433111472	19947	30	15A
0005432892737	19947	31	15D
0005433112353	19947	32	15C
0005433111480	19947	33	15F
0005432892728	19947	34	16E
0005433111487	19947	35	16D
0005433111477	19947	36	16F
0005433111473	19947	37	17B
0005433112351	19947	38	17C
0005432892740	19947	39	18A
0005432802431	19947	40	18C
0005432892743	19947	41	18E
0005433111486	19947	42	18F
0005433112354	19947	43	19B
0005432802432	19947	44	19E
0005433111478	19947	45	19D
0005433112361	19947	46	19C
0005432802433	19947	47	19F
0005432892733	19947	48	20B
0005433111488	19947	49	20D
0005433112355	19947	50	21A
0005433112352	19947	51	21E
0005433111475	19947	52	21F
0005432525953	30629	1	1H
0005434066414	30629	2	1G
0005435630945	30629	3	1D
0005435213065	30629	4	2D
0005432526168	30629	5	2G
0005435213035	30629	6	3H
0005432526291	30629	7	3G
0005435213080	30629	8	4D
0005435213074	30629	9	4K
0005434066302	30629	10	4H
0005435213043	30629	11	5C
0005432525781	30629	12	5G
0005432525712	30629	13	11A
0005434066517	30629	14	5K
0005432525690	30629	15	11F
0005432159822	30629	16	11E
0005432525777	30629	17	11H
0005432526582	30629	18	11G
0005432526010	30629	19	12E
0005432525794	30629	20	12D
0005435213036	30629	21	12H
0005434066420	30629	22	12F
0005432525992	30629	23	12K
0005432526143	30629	24	13F
0005432525784	30629	25	13E
0005432525726	30629	26	13D
0005435213024	30629	27	13H
0005435213023	30629	28	13G
0005432525657	30629	29	13K
0005433656648	30629	30	14C
0005435213083	30629	31	14F
0005435213087	30629	32	14H
0005432526385	30629	33	15E
0005432526241	30629	34	15D
0005432526230	30629	35	15G
0005435213079	30629	36	16D
0005435213044	30629	37	16A
0005435213042	30629	38	16F
0005432525923	30629	39	16K
0005434066425	30629	40	16G
0005432526433	30629	41	17A
0005432525691	30629	42	17E
0005434066507	30629	43	17C
0005434066343	30629	44	18A
0005432525855	30629	45	18B
0005434066436	30629	46	18D
0005434066357	30629	47	18G
0005432211448	30629	48	18F
0005432526195	30629	49	18K
0005432211442	30629	50	18J
0005434066435	30629	51	18H
0005435213086	30629	52	19B
0005432526058	30629	53	19A
0005432525692	30629	54	19D
0005435213025	30629	55	19F
0005432525861	30629	56	19G
0005435213068	30629	57	19K
0005432525660	30629	58	20C
0005432526038	30629	59	20A
0005432525719	30629	60	20E
0005432211445	30629	61	20D
0005435213051	30629	62	20F
0005435213062	30629	63	20K
0005432526057	30629	64	20J
0005432525959	30629	65	21B
0005435213090	30629	66	21F
0005434066399	30629	67	21E
0005432526411	30629	68	21H
0005435213076	30629	69	21G
0005432159823	30629	70	22A
0005434066419	30629	71	21K
0005432211449	30629	72	21J
0005433656645	30629	73	22F
0005432526384	30629	74	22E
0005432526128	30629	75	22D
0005432525720	30629	76	22H
0005432159821	30629	77	22G
0005435630946	30629	78	22K
0005433656647	30629	79	22J
0005434066622	30629	80	23B
0005432526467	30629	81	23A
0005432525928	30629	82	23F
0005435213039	30629	83	23H
0005435213085	30629	84	24F
0005435725564	30629	85	24E
0005434066728	30629	86	25C
0005432211444	30629	87	25B
0005434066391	30629	88	25F
0005435213053	30629	89	25E
0005432525927	30629	90	25H
0005434066443	30629	91	25G
0005432525738	30629	92	25K
0005432526190	30629	93	25J
0005432525954	30629	94	26B
0005435213082	30629	95	26E
0005434066429	30629	96	26F
0005435213049	30629	97	26K
0005432525955	30629	98	26J
0005432525746	30629	99	27A
0005432526081	30629	100	27C
0005434066571	30629	101	27B
0005434066465	30629	102	27E
0005434066423	30629	103	27H
0005435213026	30629	104	27J
0005435725565	30629	105	28C
0005435213059	30629	106	28B
0005435213058	30629	107	28E
0005435213060	30629	108	28K
0005432526104	30629	109	29C
0005432525924	30629	110	29G
0005435213028	30629	111	29J
0005432525685	30629	112	29K
0005434066408	30629	113	30G
0005434066621	30629	114	30F
0005435213046	30629	115	30J
0005432525662	30629	116	31A
0005433656646	30629	117	30K
0005434066509	30629	118	31D
0005432525641	30629	119	31C
0005432159825	30629	120	31B
0005434066605	30629	121	31F
0005432525828	30629	122	31H
0005434066301	30629	123	31G
0005432525745	30629	124	32A
0005435213081	30629	125	31K
0005434066358	30629	126	31J
0005432526036	30629	127	32B
0005432525661	30629	128	32E
0005435213040	30629	129	32D
0005432533250	30629	130	32G
0005435213037	30629	131	32J
0005434066418	30629	132	32H
0005432526232	30629	133	33A
0005432526060	30629	134	32K
0005435213041	30629	135	33D
0005432525929	30629	136	33B
0005432428879	30629	137	33E
0005432525727	30629	138	34A
0005435213031	30629	139	33K
0005432525648	30629	140	34B
0005435213066	30629	141	34G
0005432526025	30629	142	34K
0005432159824	30629	143	34H
0005432525684	30629	144	35B
0005435213027	30629	145	35A
0005432526037	30629	146	35C
0005432525782	30629	147	35F
0005435213047	30629	148	35E
0005435213064	30629	149	35H
0005435213045	30629	150	35G
0005435630944	30629	151	35K
0005432526142	30629	152	35J
0005432526024	30629	153	36B
0005434066363	30629	154	36E
0005432526179	30629	155	36D
0005435213033	30629	156	36H
0005435213073	30629	157	36G
0005432525877	30629	158	36F
0005432525883	30629	159	37A
0005435213063	30629	160	37C
0005432525728	30629	161	37F
0005432526171	30629	162	37H
0005435213055	30629	163	38A
0005432526059	30629	164	37K
0005432525709	30629	165	38J
0005432526215	30629	166	38H
0005432526294	30629	167	39B
0005434066508	30629	168	38K
0005434066417	30629	169	39D
0005435213057	30629	170	39C
0005435725562	30629	171	39F
0005435630947	30629	172	39E
0005432525758	30629	173	40A
0005432526251	30629	174	40C
0005435213067	30629	175	40B
0005434066444	30629	176	40E
0005435213069	30629	177	40G
0005435213048	30629	178	40K
0005432525946	30629	179	40J
0005432525902	30629	180	40H
0005432525796	30629	181	41A
0005435213070	30629	182	41D
0005432526008	30629	183	41J
0005432526141	30629	184	41H
0005432211443	30629	185	41G
0005432525729	30629	186	42A
0005435213089	30629	187	41K
0005435213075	30629	188	42E
0005432526239	30629	189	42D
0005435213022	30629	190	42F
0005435725563	30629	191	42J
0005432525930	30629	192	43A
0005434066415	30629	193	42K
0005435213034	30629	194	43D
0005432526432	30629	195	43C
0005432533254	30629	196	43B
0005435213088	30629	197	43F
0005434066469	30629	198	43E
0005432211446	30629	199	43H
0005432526196	30629	200	43G
0005435213061	30629	201	43J
0005432526129	30629	202	44B
0005432525994	30629	203	44A
0005432526434	30629	204	44C
0005435213056	30629	205	44G
0005434066447	30629	206	44F
0005432526016	30629	207	44J
0005432526007	30629	208	45B
0005432526394	30629	209	45A
0005435213084	30629	210	44K
0005432526240	30629	211	45D
0005432526238	30629	212	45C
0005435213054	30629	213	45E
0005435213077	30629	214	45J
0005432526538	30629	215	46B
0005432525903	30629	216	46D
0005432526229	30629	217	46G
0005435213050	30629	218	46F
0005434066506	30629	219	46J
0005432525867	30629	220	47A
0005435213032	30629	221	47G
0005435213038	30629	222	47F
0005435213071	30629	223	47K
0005432525901	30629	224	48A
0005435213052	30629	225	48F
0005434066729	30629	226	48E
0005432525774	30629	227	48D
0005435725566	30629	228	48H
0005435213021	30629	229	48G
0005432526395	30629	230	49A
0005432525952	30629	231	48K
0005435213029	30629	232	49D
0005432525778	30629	233	49F
0005432525693	30629	234	49K
0005432211447	30629	235	50A
0005435213030	30629	236	50F
0005432525658	30629	237	50E
0005435213072	30629	238	50D
0005432525834	30629	239	50G
0005434066310	30629	240	50H
0005432526130	30629	241	51F
0005432526147	30629	242	51E
0005435213078	30629	243	51G
0005433367640	24827	1	1A
0005433367620	24827	2	1C
0005433367622	24827	3	1D
0005433367611	24827	4	1F
0005435652336	24827	5	2A
0005435652334	24827	6	2C
0005435652267	24827	7	2D
0005435652270	24827	8	2F
0005435652303	24827	9	3A
0005435652251	24827	10	3D
0005435652372	24827	11	3F
0005435652346	24827	12	4A
0005433367621	24827	13	4C
0005435652283	24827	14	4D
0005433367635	24827	15	4F
0005433367619	24827	16	5A
0005433367630	24827	17	5D
0005433367633	24827	18	5E
0005433367627	24827	19	6A
0005435652369	24827	20	6D
0005435652352	24827	21	6E
0005433367602	24827	22	6F
0005433367634	24827	23	7D
0005433367636	24827	24	7E
0005433367604	24827	25	8A
0005433367632	24827	26	8C
0005433367617	24827	27	8E
0005433367614	24827	28	8F
0005435652269	24827	29	9D
0005433367639	24827	30	9E
0005435652250	24827	31	10C
0005435652252	24827	32	10A
0005435652268	24827	33	10D
0005433367610	24827	34	10F
0005433367631	24827	35	11A
0005435652277	24827	36	11D
0005435652284	24827	37	11E
0005433367609	24827	38	11F
0005433367618	24827	39	12A
0005433367613	24827	40	12E
0005435652313	24827	41	12F
0005435652302	24827	42	13A
0005435652351	24827	43	13C
0005435652322	24827	44	13D
0005433367605	24827	45	13F
0005435652282	24827	46	14E
0005435652377	24827	47	14F
0005435652253	24827	48	15A
0005433367624	24827	49	15C
0005433367637	24827	50	15E
0005435652358	24827	51	16C
0005435652297	24827	52	16D
0005435652298	24827	53	16E
0005435652350	24827	54	16F
0005433367607	24827	55	17A
0005433367623	24827	56	17C
0005433367603	24827	57	17D
0005433367606	24827	58	17E
0005433367628	24827	59	17F
0005435652276	24827	60	18A
0005433367629	24827	61	18C
0005435652378	24827	62	18D
0005433367615	24827	63	18F
0005433367638	24827	64	19A
0005435652261	24827	65	19C
0005435652347	24827	66	19D
0005433367612	24827	67	19F
0005433367626	24827	68	20A
0005433367616	24827	69	20C
0005433367625	24827	70	20D
0005433367608	24827	71	20E
0005435652335	24827	72	20F
0005435949764	6600	1	1A
0005435949754	6600	2	1B
0005435949758	6600	3	2C
0005435949753	6600	4	2D
0005435949759	6600	5	4C
0005435949757	6600	6	6A
0005435949755	6600	7	6D
0005435949763	6600	8	7B
0005435949756	6600	9	18C
0005435949752	6600	10	19D
0005435949762	6600	11	20B
0005435949760	6600	12	22A
0005435949761	6600	13	22C
0005434979591	2059	1	1A
0005434979565	2059	2	1C
0005434979567	2059	3	2A
0005434979568	2059	4	2B
0005434979586	2059	5	2C
0005434979569	2059	6	3A
0005434979587	2059	7	3B
0005434979571	2059	8	3C
0005434979566	2059	9	3D
0005434979562	2059	10	4A
0005434979573	2059	11	4B
0005434979582	2059	12	4C
0005434979580	2059	13	4D
0005434979590	2059	14	5A
0005435801674	2059	15	5B
0005434979570	2059	16	5C
0005434979574	2059	17	6A
0005435801673	2059	18	6D
0005434979564	2059	19	7A
0005434979584	2059	20	7B
0005434979578	2059	21	7C
0005434979589	2059	22	18A
0005434979561	2059	23	18C
0005434979572	2059	24	19C
0005434979575	2059	25	19D
0005434979560	2059	26	20A
0005434979583	2059	27	20B
0005434979576	2059	28	20C
0005435801672	2059	29	21A
0005435801675	2059	30	21C
0005434979581	2059	31	21D
0005434979577	2059	32	22A
0005434979588	2059	33	22C
0005434979579	2059	34	22D
0005434979585	2059	35	23A
0005434979563	2059	36	23B
0005434979321	23569	1	1D
0005435801644	23569	2	2D
0005434979265	23569	3	3A
0005434979280	23569	4	4C
0005434979282	23569	5	5B
0005434979295	23569	6	6A
0005434979341	23569	7	6D
0005434979322	23569	8	7A
0005435801652	23569	9	7D
0005434979302	23569	10	19B
0005434979320	23569	11	19C
0005434979278	23569	12	20B
0005434979367	23569	13	22B
0005434979338	23569	14	22D
0005434979252	23569	15	23A
0005434952503	2658	1	2A
0005434952504	2658	2	3A
0005434952505	2658	3	4A
0005434952502	2658	4	5A
0005433256392	2648	1	6A
0005434952467	28257	1	1A
0005434952477	28257	2	1B
0005433256406	28257	3	2A
0005434952465	28257	4	2B
0005434952464	28257	5	3A
0005434952482	28257	6	3B
0005434952481	28257	7	4B
0005433256405	28257	8	5A
0005433256407	28257	9	5B
0005434952483	28257	10	6A
0005434952466	28257	11	6B
0005433111490	19796	1	2A
0005433111491	19796	2	6B
0005434136811	11946	1	1A
0005434136917	11946	2	1C
0005434136805	11946	3	1D
0005434136914	11946	4	1F
0005434137008	11946	5	2A
0005434136887	11946	6	2C
0005434136842	11946	7	2D
0005434137056	11946	8	3A
0005434136959	11946	9	3C
0005434136975	11946	10	3D
0005434136729	11946	11	3F
0005434136913	11946	12	4C
0005434136776	11946	13	4D
0005434136992	11946	14	4F
0005434136817	11946	15	5A
0005434136846	11946	16	5C
0005434136974	11946	17	5D
0005434136948	11946	18	5E
0005434136921	11946	19	5F
0005434136772	11946	20	6A
0005434137021	11946	21	6C
0005434136863	11946	22	6D
0005434136716	11946	23	6E
0005434136690	11946	24	6F
0005434136810	11946	25	7A
0005434136742	11946	26	7C
0005434137070	11946	27	7E
0005434136897	11946	28	7F
0005434137064	11946	29	8A
0005434136911	11946	30	8C
0005434136912	11946	31	8D
0005434136796	11946	32	8E
0005434136843	11946	33	8F
0005434136862	11946	34	9A
0005434137023	11946	35	9D
0005434136743	11946	36	9F
0005434136755	11946	37	10A
0005434136984	11946	38	10E
0005434136918	11946	39	10F
0005434136730	11946	40	11A
0005434136762	11946	41	11C
0005434136720	11946	42	11D
0005434136804	11946	43	11E
0005434137045	11946	44	12A
0005434136881	11946	45	12C
0005434136965	11946	46	12E
0005434137034	11946	47	12F
0005434136993	11946	48	13A
0005434136888	11946	49	13C
0005434137097	11946	50	13D
0005434136861	11946	51	13F
0005434136909	11946	52	14A
0005434137002	11946	53	14C
0005434136750	11946	54	14D
0005434136922	11946	55	14E
0005434136715	11946	56	15C
0005434136949	11946	57	15D
0005434136960	11946	58	15E
0005434136751	11946	59	16A
0005434137061	11946	60	15F
0005434136910	11946	61	16C
0005434136983	11946	62	16E
0005434136966	11946	63	16F
0005434137096	11946	64	17A
0005434137101	11946	65	17C
0005434136886	11946	66	17E
0005434137069	11946	67	18A
0005434136908	11946	68	18C
0005434137046	11946	69	18D
0005434136809	11946	70	18E
0005434136864	11946	71	18F
0005434136808	11946	72	19A
0005434136877	11946	73	19C
0005434137035	11946	74	19D
0005434136894	11946	75	20A
0005434137060	11946	76	20C
0005434136728	11946	77	20D
0005434136857	11946	78	20F
0005434137457	28765	1	1A
0005434137494	28765	2	1C
0005434137518	28765	3	1D
0005434137519	28765	4	2A
0005434137523	28765	5	2C
0005434137447	28765	6	2F
0005434137461	28765	7	3A
0005434137490	28765	8	3C
0005434137504	28765	9	3D
0005434137506	28765	10	3F
0005434137448	28765	11	4A
0005434137477	28765	12	4C
0005434137508	28765	13	4D
0005434137525	28765	14	4E
0005434137524	28765	15	4F
0005434137510	28765	16	5A
0005434137459	28765	17	5C
0005434137527	28765	18	5D
0005434137500	28765	19	5E
0005434137532	28765	20	5F
0005434137465	28765	21	6D
0005434137496	28765	22	6E
0005434137488	28765	23	6F
0005434137522	28765	24	7A
0005434137531	28765	25	7C
0005434137516	28765	26	7D
0005434137480	28765	27	7E
0005434137450	28765	28	7F
0005434137528	28765	29	8A
0005434137456	28765	30	8C
0005434137530	28765	31	8D
0005434137464	28765	32	8E
0005434137446	28765	33	8F
0005434137536	28765	34	9A
0005434137520	28765	35	9C
0005434137475	28765	36	9D
0005434137505	28765	37	9E
0005434137481	28765	38	9F
0005434137455	28765	39	10A
0005434137482	28765	40	10C
0005434137470	28765	41	10D
0005434137460	28765	42	10E
0005434137452	28765	43	10F
0005434137493	28765	44	11A
0005434137484	28765	45	11C
0005434137453	28765	46	11E
0005434137513	28765	47	11F
0005434137463	28765	48	12A
0005434137476	28765	49	12C
0005434137485	28765	50	12D
0005434137474	28765	51	12E
0005434137534	28765	52	12F
0005434137514	28765	53	13A
0005434137473	28765	54	13C
0005434137468	28765	55	13D
0005434137499	28765	56	13E
0005434137471	28765	57	13F
0005434137535	28765	58	14A
0005434137489	28765	59	14C
0005434137509	28765	60	14D
0005434137458	28765	61	14E
0005434137497	28765	62	14F
0005434137492	28765	63	15A
0005434137503	28765	64	15C
0005434137469	28765	65	15E
0005434137487	28765	66	15D
0005434137511	28765	67	15F
0005434137507	28765	68	16A
0005434137533	28765	69	16C
0005434137512	28765	70	16D
0005434137486	28765	71	16E
0005434137515	28765	72	16F
0005434137521	28765	73	17A
0005434137502	28765	74	17C
0005434137498	28765	75	17D
0005434137526	28765	76	17E
0005434137529	28765	77	17F
0005434137479	28765	78	18A
0005434137501	28765	79	18C
0005434137454	28765	80	18D
0005434137495	28765	81	18E
0005434137451	28765	82	18F
0005434137491	28765	83	19A
0005434137483	28765	84	19C
0005434137537	28765	85	19D
0005434137478	28765	86	19E
0005434137472	28765	87	19F
0005434137462	28765	88	20A
0005434137517	28765	89	20C
0005434137449	28765	90	20D
0005434137466	28765	91	20E
0005434137467	28765	92	20F
0005433538806	6809	1	1A
0005435259697	6809	2	1B
0005435259682	6809	3	1C
0005433534482	6809	4	2C
0005433538805	6809	5	2D
0005433538807	6809	6	3C
0005433538809	6809	7	6A
0005433538810	6809	8	6C
0005433534483	6809	9	18A
0005433538808	6809	10	18B
0005433538804	6809	11	19C
0005433538811	6809	12	20A
0005433538812	6809	13	22A
0005435259727	25026	1	2B
0005435259724	25026	2	3D
0005435259726	25026	3	19A
0005435259725	25026	4	19C
0005433538749	25026	5	21B
0005433538750	25026	6	22B
0005433538787	25026	7	22C
0005433511893	816	1	1C
0005432922476	816	2	3D
0005433511888	816	3	4B
0005433511890	816	4	7A
0005433511895	816	5	18B
0005433511892	816	6	19B
0005433511887	816	7	19C
0005433511889	816	8	20C
0005433511896	816	9	20D
0005432922475	816	10	22A
0005433511894	816	11	23A
0005433511891	816	12	23B
0005433511847	16126	1	2C
0005432922496	16126	2	3B
0005432922494	16126	3	4A
0005432922497	16126	4	5A
0005433511845	16126	5	5D
0005432922495	16126	6	6B
0005433511841	16126	7	7A
0005433511857	16126	8	20A
0005433511848	16126	9	20D
0005433511858	16126	10	21A
0005433511823	16126	11	23A
0005435697131	3648	1	1A
0005435697148	3648	2	1B
0005434950497	3648	3	1C
0005435697136	3648	4	1D
0005435935008	3648	5	2B
0005434950496	3648	6	2C
0005435697137	3648	7	2D
0005435697143	3648	8	3A
0005435697149	3648	9	3B
0005435697145	3648	10	3D
0005435697151	3648	11	4A
0005435697158	3648	12	4B
0005435916128	3648	13	4C
0005435697142	3648	14	4D
0005435697132	3648	15	5B
0005435697144	3648	16	5C
0005435935009	3648	17	5D
0005435697154	3648	18	6B
0005435697157	3648	19	6C
0005435697139	3648	20	6D
0005435697152	3648	21	7A
0005435697147	3648	22	7B
0005435697134	3648	23	7C
0005435697156	3648	24	7D
0005435697140	3648	25	18B
0005434950499	3648	26	18D
0005435934999	3648	27	19A
0005435934992	3648	28	19B
0005435697146	3648	29	19C
0005435697133	3648	30	19D
0005435697150	3648	31	20A
0005435697153	3648	32	20D
0005434950495	3648	33	21A
0005435916127	3648	34	21C
0005435697155	3648	35	21D
0005435697138	3648	36	22A
0005435697141	3648	37	22C
0005435697135	3648	38	22D
0005434950498	3648	39	23A
0005435916137	3648	40	23B
0005435696922	16255	1	1A
0005435696895	16255	2	1B
0005435696916	16255	3	2C
0005435696949	16255	4	4A
0005435935018	16255	5	4C
0005435696948	16255	6	5A
0005435696975	16255	7	5D
0005435916147	16255	8	6B
0005435696962	16255	9	6C
0005435916146	16255	10	7C
0005435696844	16255	11	7D
0005435696915	16255	12	18A
0005435696906	16255	13	18B
0005435696908	16255	14	18C
0005435696869	16255	15	19A
0005435935019	16255	16	19C
0005435697008	16255	17	19D
0005435696851	16255	18	20A
0005435696907	16255	19	20B
0005435696852	16255	20	20C
0005435916148	16255	21	22B
0005435696941	16255	22	22C
0005435697007	16255	23	23A
0005435696843	16255	24	23B
0005434604872	3969	1	2A
0005434604874	3969	2	3A
0005434604873	3969	3	3C
0005434606802	3969	4	3D
0005432607535	3969	5	4A
0005432607536	3969	6	4B
0005433519424	3969	7	4D
0005433519426	3969	8	7A
0005433519425	3969	9	7B
0005432607537	3969	10	7C
0005432609703	3969	11	18D
0005432607538	3969	12	19B
0005435853587	3969	13	19C
0005432609702	3969	14	20A
0005434606804	3969	15	20B
0005433519427	3969	16	21B
0005434606805	3969	17	21C
0005434606803	3969	18	22B
0005433519423	3969	19	22C
0005434604871	3969	20	23B
0005435904892	22039	1	1C
0005433519377	22039	2	4A
0005435853598	22039	3	23B
0005433348895	685	1	1A
0005433348889	685	2	1B
0005433348908	685	3	2B
0005435628706	685	4	4A
0005435628705	685	5	5A
0005435628704	685	6	5B
0005433348899	685	7	6A
0005435628675	15953	1	1A
0005433348950	15953	2	1B
0005433348949	15953	3	2A
0005435628669	15953	4	2B
0005435628671	15953	5	3A
0005435628670	15953	6	3B
0005435628672	15953	7	4A
0005433348948	15953	8	4B
0005433348951	15953	9	5B
0005435628673	15953	10	6A
0005433348947	15953	11	6B
0005434445229	17170	1	1A
0005434446502	17170	2	1B
0005434446501	17170	3	3A
0005434446503	17170	4	4A
0005434445228	17170	5	4B
0005434445227	17170	6	5A
0005434445226	17170	7	5B
0005433159282	17170	8	6B
0005433159298	17621	1	1A
0005434445207	17621	2	3A
0005435132806	7905	1	2C
0005435383056	7905	2	2D
0005435132811	7905	3	3A
0005435132810	7905	4	3C
0005435383057	7905	5	4A
0005435132809	7905	6	7A
0005435132807	7905	7	7B
0005435132805	7905	8	7D
0005435383055	7905	9	18B
0005435132804	7905	10	19A
0005435132803	7905	11	19C
0005435132802	7905	12	20A
0005435383065	7905	13	20B
0005435132808	7905	14	21A
0005435383064	7905	15	21B
0005435132812	7905	16	22D
0005435383066	7905	17	23A
0005435383112	33065	1	1A
0005435132768	33065	2	1B
0005435132769	33065	3	1C
0005435383110	33065	4	2A
0005435132720	33065	5	2D
0005435132707	33065	6	3A
0005435383111	33065	7	3D
0005435132723	33065	8	4A
0005435132705	33065	9	4D
0005435132750	33065	10	5D
0005435132738	33065	11	6C
0005435132731	33065	12	6D
0005435383113	33065	13	7A
0005435132695	33065	14	7B
0005435132766	33065	15	7C
0005435132722	33065	16	7D
0005435132732	33065	17	18B
0005435132767	33065	18	19A
0005435132694	33065	19	19D
0005435132733	33065	20	20B
0005435132749	33065	21	20C
0005435132713	33065	22	21B
0005435132724	33065	23	22A
0005435383114	33065	24	22D
0005435132741	33065	25	23B
0005435160218	7520	1	1A
0005435160222	7520	2	1D
0005435390131	7520	3	2A
0005435160223	7520	4	2C
0005435160224	7520	5	3B
0005435160225	7520	6	3C
0005435160228	7520	7	4C
0005435160226	7520	8	5D
0005435160220	7520	9	18D
0005435160221	7520	10	19C
0005435160227	7520	11	21A
0005435160219	7520	12	21B
0005435390144	7520	13	21C
0005435160118	29567	1	1A
0005435160117	29567	2	1C
0005435160135	29567	3	2B
0005435390191	29567	4	2D
0005435390193	29567	5	3B
0005435390192	29567	6	5D
0005435390189	29567	7	6A
0005435390190	29567	8	6D
0005435160105	29567	9	7D
0005435390195	29567	10	20C
0005435160182	29567	11	22B
0005435390194	29567	12	22C
0005432398145	18441	1	1B
0005435178486	18441	2	2A
0005435178985	18441	3	2B
0005435178988	18441	4	3A
0005435178987	18441	5	4A
0005432398144	18441	6	4B
0005432398143	18441	7	5A
0005435178484	18441	8	5B
0005435178986	18441	9	6A
0005435178485	18441	10	6B
0005435178473	27169	1	1B
0005432398166	27169	2	4A
0005432398165	27169	3	4B
0005432400096	27169	4	5A
0005432398167	27169	5	5B
0005435178476	27169	6	6A
0005432661909	21841	1	2A
0005432661912	21841	2	2C
0005432664113	21841	3	2F
0005432664114	21841	4	3C
0005432661900	21841	5	5A
0005432664126	21841	6	5F
0005432663012	21841	7	6B
0005432664119	21841	8	6E
0005432663020	21841	9	6D
0005432663021	21841	10	7F
0005432663019	21841	11	8C
0005432663025	21841	12	8F
0005432664116	21841	13	8E
0005432661903	21841	14	9A
0005432664117	21841	15	9D
0005432664124	21841	16	9C
0005432664120	21841	17	9B
0005432663015	21841	18	9E
0005432661908	21841	19	10A
0005432664118	21841	20	11B
0005432661904	21841	21	11C
0005432664122	21841	22	12D
0005432663017	21841	23	12F
0005432661905	21841	24	13A
0005432663026	21841	25	14C
0005432664127	21841	26	14D
0005432661901	21841	27	14F
0005432664121	21841	28	14E
0005432661907	21841	29	15A
0005432661898	21841	30	15D
0005432663013	21841	31	15C
0005432663022	21841	32	15E
0005432661910	21841	33	16B
0005432663016	21841	34	17E
0005432661902	21841	35	18A
0005432661906	21841	36	18C
0005432663024	21841	37	18B
0005432661899	21841	38	18E
0005432664125	21841	39	18F
0005432663023	21841	40	19C
0005432663014	21841	41	19B
0005432661911	21841	42	20B
0005432664123	21841	43	20C
0005432663018	21841	44	20F
0005432664115	21841	45	21C
0005434503887	6514	1	1C
0005434503883	6514	2	1F
0005434503896	6514	3	2A
0005434503891	6514	4	3C
0005434503879	6514	5	4A
0005434503884	6514	6	4F
0005434503878	6514	7	5A
0005434503870	6514	8	5C
0005434503882	6514	9	5D
0005434503888	6514	10	5F
0005434503889	6514	11	6A
0005434503876	6514	12	6C
0005434503872	6514	13	7E
0005434503885	6514	14	7F
0005434503863	6514	15	8C
0005434503897	6514	16	8E
0005434503874	6514	17	8F
0005434503865	6514	18	9D
0005434503886	6514	19	9F
0005434503890	6514	20	11C
0005434503880	6514	21	11E
0005434503869	6514	22	11F
0005434503900	6514	23	12A
0005434503895	6514	24	12E
0005434503877	6514	25	13C
0005434503894	6514	26	13D
0005434503867	6514	27	13E
0005434503868	6514	28	14A
0005434503866	6514	29	14C
0005434503864	6514	30	15E
0005434503899	6514	31	15F
0005434503881	6514	32	16A
0005434503893	6514	33	16C
0005434503898	6514	34	16F
0005434503875	6514	35	18C
0005434503871	6514	36	19A
0005434503892	6514	37	19D
0005434503873	6514	38	19E
0005434503569	22650	1	1A
0005434503568	22650	2	1F
0005434503623	22650	3	4A
0005434503616	22650	4	5E
0005434503483	22650	5	6D
0005434503563	22650	6	7F
0005434503493	22650	7	9F
0005434503570	22650	8	11D
0005434503488	22650	9	11F
0005434503499	22650	10	12A
0005434503494	22650	11	12E
0005434503617	22650	12	13D
0005434503591	22650	13	13E
0005434503541	22650	14	15E
0005434503542	22650	15	16C
0005434503658	22650	16	16F
0005434503492	22650	17	18F
0005434503525	22650	18	19C
0005434503564	22650	19	20A
0005434503540	22650	20	20E
0005434503547	22650	21	20F
0005433367424	1672	1	1A
0005435652771	1672	2	1C
0005433367320	1672	3	1D
0005435652769	1672	4	1F
0005435652762	1672	5	2A
0005435652768	1672	6	2D
0005435652765	1672	7	2F
0005433367221	1672	8	3A
0005435652770	1672	9	3C
0005435652777	1672	10	3D
0005433367271	1672	11	3F
0005435652784	1672	12	4A
0005435652763	1672	13	4E
0005435652733	1672	14	4F
0005435652745	1672	15	5C
0005433367246	1672	16	5D
0005435652783	1672	17	5E
0005435652752	1672	18	5F
0005435652779	1672	19	6A
0005435652761	1672	20	6C
0005435652732	1672	21	6D
0005435652753	1672	22	6E
0005435652742	1672	23	7C
0005435652744	1672	24	7D
0005433367314	1672	25	7E
0005433367321	1672	26	7F
0005435652766	1672	27	8A
0005435652755	1672	28	8C
0005435652780	1672	29	8F
0005435652735	1672	30	9A
0005435652739	1672	31	9D
0005435652764	1672	32	9E
0005435652746	1672	33	9F
0005435652748	1672	34	10C
0005435652756	1672	35	10E
0005435652737	1672	36	10F
0005433367252	1672	37	11A
0005435652754	1672	38	11C
0005435652738	1672	39	11D
0005433367293	1672	40	11E
0005433367310	1672	41	12A
0005435652759	1672	42	12C
0005435652782	1672	43	12D
0005435652749	1672	44	12E
0005433367350	1672	45	12F
0005435652751	1672	46	13A
0005435652747	1672	47	13D
0005435652775	1672	48	13E
0005435652731	1672	49	13F
0005433367423	1672	50	14A
0005433367389	1672	51	14D
0005433367319	1672	52	14E
0005433367292	1672	53	14F
0005433367315	1672	54	15A
0005435652772	1672	55	15C
0005433367294	1672	56	15D
0005433367456	1672	57	15E
0005435652750	1672	58	15F
0005435652767	1672	59	16A
0005435652781	1672	60	16E
0005435652740	1672	61	16F
0005435652743	1672	62	17A
0005433367324	1672	63	17C
0005435652773	1672	64	17D
0005435652776	1672	65	17E
0005435652758	1672	66	17F
0005435652785	1672	67	18A
0005433367255	1672	68	18C
0005435652778	1672	69	18D
0005435652760	1672	70	18E
0005435652734	1672	71	18F
0005435652757	1672	72	19A
0005433367434	1672	73	19C
0005435652774	1672	74	19D
0005433367254	1672	75	19E
0005433367322	1672	76	20A
0005435652741	1672	77	20D
0005435652736	1672	78	20F
0005435652347	21663	1	1A
0005433367635	21663	2	1C
0005435652369	21663	3	1D
0005433367606	21663	4	1F
0005435652322	21663	5	2A
0005433367621	21663	6	2D
0005433367605	21663	7	2C
0005433367614	21663	8	2F
0005433367609	21663	9	3C
0005433367634	21663	10	3D
0005433367611	21663	11	3F
0005435652377	21663	12	4A
0005435652336	21663	13	4C
0005435652358	21663	14	4E
0005435652283	21663	15	4F
0005435652251	21663	16	5A
0005433367627	21663	17	5C
0005433367612	21663	18	5D
0005433367602	21663	19	5E
0005433367630	21663	20	5F
0005435652267	21663	21	6A
0005435652334	21663	22	6C
0005433367633	21663	23	6E
0005433367604	21663	24	6F
0005435652346	21663	25	7D
0005433367619	21663	26	7F
0005433367632	21663	27	8A
0005433367629	21663	28	8C
0005433367617	21663	29	8F
0005435652298	21663	30	9C
0005435652269	21663	31	9D
0005435652252	21663	32	9E
0005433367615	21663	33	9F
0005435652297	21663	34	10A
0005435652335	21663	35	10C
0005433367636	21663	36	10D
0005433367640	21663	37	10E
0005435652351	21663	38	10F
0005435652270	21663	39	11C
0005435652276	21663	40	11E
0005433367603	21663	41	11F
0005433367610	21663	42	12A
0005433367613	21663	43	12D
0005435652253	21663	44	12E
0005435652277	21663	45	12F
0005433367631	21663	46	13A
0005435652284	21663	47	13F
0005435652378	21663	48	14A
0005433367638	21663	49	14C
0005433367608	21663	50	14D
0005433367624	21663	51	14E
0005435652261	21663	52	14F
0005433367625	21663	53	15A
0005433367620	21663	54	15C
0005435652282	21663	55	15E
0005433367626	21663	56	15F
0005433367607	21663	57	16A
0005435652302	21663	58	16C
0005433367616	21663	59	16E
0005435652350	21663	60	16F
0005433367639	21663	61	17A
0005433367622	21663	62	17C
0005433367623	21663	63	17F
0005435652303	21663	64	18A
0005435652268	21663	65	18C
0005433367628	21663	66	18D
0005433367618	21663	67	18F
0005433367637	21663	68	19E
0005435652250	21663	69	19F
0005435652313	21663	70	20A
0005435652372	21663	71	20C
0005435652352	21663	72	20E
0005435627113	12250	1	3A
0005433985637	4191	1	1C
0005433985628	4191	2	2C
0005433985633	4191	3	2D
0005433985634	4191	4	3A
0005433985614	4191	5	3F
0005433985615	4191	6	4D
0005433985606	4191	7	4F
0005433985622	4191	8	5A
0005433985642	4191	9	6D
0005433985639	4191	10	6E
0005433985620	4191	11	6F
0005433985636	4191	12	7A
0005433985612	4191	13	8C
0005433985632	4191	14	8D
0005433985623	4191	15	8E
0005433985644	4191	16	8F
0005433985635	4191	17	9A
0005433985629	4191	18	9D
0005433985616	4191	19	9E
0005433985640	4191	20	9F
0005433985647	4191	21	10C
0005433985643	4191	22	10E
0005433985618	4191	23	11A
0005433985610	4191	24	11D
0005433985646	4191	25	11E
0005433985619	4191	26	12C
0005433985611	4191	27	12D
0005433985631	4191	28	12E
0005435788753	4191	29	12F
0005433985621	4191	30	14C
0005433985641	4191	31	14E
0005433985627	4191	32	14F
0005433985645	4191	33	15D
0005433985625	4191	34	15F
0005433985607	4191	35	16A
0005433985608	4191	36	16D
0005433985630	4191	37	16E
0005433985624	4191	38	17A
0005435788752	4191	39	17E
0005433985613	4191	40	17F
0005433985609	4191	41	18C
0005433985626	4191	42	19A
0005433985617	4191	43	19E
0005433985638	4191	44	20C
0005433985292	25658	1	1C
0005433985373	25658	2	1D
0005435788731	25658	3	2C
0005433985374	25658	4	3C
0005433985344	25658	5	4A
0005433985160	25658	6	4D
0005433985406	25658	7	4E
0005435788733	25658	8	4F
0005433985271	25658	9	6C
0005433985233	25658	10	6E
0005433985135	25658	11	6D
0005433985199	25658	12	6F
0005433985221	25658	13	7D
0005433985201	25658	14	7F
0005433985197	25658	15	8C
0005435788732	25658	16	8E
0005433985215	25658	17	8F
0005433985127	25658	18	9A
0005433985165	25658	19	9C
0005435788738	25658	20	9F
0005433985163	25658	21	11A
0005433985220	25658	22	11C
0005433985138	25658	23	11D
0005433985143	25658	24	11F
0005433985273	25658	25	12A
0005433985140	25658	26	12D
0005433985144	25658	27	13A
0005433985303	25658	28	13C
0005433985243	25658	29	13D
0005433985141	25658	30	13F
0005433985142	25658	31	14A
0005433985274	25658	32	14C
0005433985147	25658	33	14D
0005433985272	25658	34	14F
0005433985162	25658	35	15A
0005433985216	25658	36	15C
0005433985157	25658	37	15D
0005433985278	25658	38	15F
0005433985148	25658	39	16C
0005433985202	25658	40	16D
0005433985198	25658	41	17A
0005433985200	25658	42	17C
0005433985293	25658	43	18C
0005433985170	25658	44	18D
0005433985164	25658	45	18E
0005433985139	25658	46	19D
0005433985304	25658	47	19E
0005433985285	25658	48	20A
0005435788734	25658	49	20D
0005435720804	21269	1	1C
0005435720803	21269	2	4C
0005435720809	21269	3	6A
0005435720810	21269	4	6D
0005435720807	21269	5	18C
0005435719552	21269	6	20A
0005435720802	21269	7	22D
0005435719560	24786	1	3C
0005435719559	24786	2	5D
0005435720127	24786	3	20B
0005434516065	9019	1	1B
0005434190368	9019	2	1D
0005434516059	9019	3	3B
0005434516058	9019	4	3C
0005434190372	9019	5	3D
0005434190374	9019	6	5A
0005434516064	9019	7	6A
0005434190367	9019	8	6D
0005434516066	9019	9	7D
0005434190375	9019	10	18A
0005434516062	9019	11	19C
0005434516063	9019	12	20D
0005434516061	9019	13	22A
0005434516060	9019	14	22D
0005432667419	17824	1	1A
0005432657396	17824	2	1C
0005432665243	17824	3	1F
0005432655367	17824	4	2A
0005432666364	17824	5	3F
0005432655373	17824	6	4C
0005434151685	17824	7	4F
0005432657397	17824	8	5C
0005432869481	17824	9	5D
0005432665242	17824	10	5E
0005432658566	17824	11	6D
0005432655363	17824	12	7A
0005432660786	17824	13	9C
0005432657400	17824	14	9D
0005432666355	17824	15	10C
0005432869485	17824	16	10D
0005434151688	17824	17	11A
0005432665241	17824	18	11D
0005432660787	17824	19	12C
0005432655364	17824	20	12F
0005432655369	17824	21	13E
0005432655368	17824	22	13F
0005432655366	17824	23	14A
0005434151684	17824	24	14F
0005432666363	17824	25	15A
0005432869479	17824	26	15D
0005432655372	17824	27	15E
0005432658561	17824	28	15F
0005432869482	17824	29	16A
0005432658565	17824	30	17A
0005432869484	17824	31	17C
0005434151687	17824	32	17E
0005434151686	17824	33	18C
0005432869483	17824	34	19C
0005432869480	17824	35	20C
0005432666370	26280	1	1A
0005432869430	26280	2	2C
0005432657423	26280	3	3D
0005432869421	26280	4	4D
0005432655423	26280	5	5A
0005432655433	26280	6	5E
0005432657421	26280	7	6C
0005432869424	26280	8	7A
0005432658574	26280	9	8C
0005432869425	26280	10	8E
0005432655429	26280	11	9C
0005432655424	26280	12	9F
0005432655425	26280	13	10A
0005432658573	26280	14	10D
0005432655427	26280	15	11E
0005432667438	26280	16	12C
0005432655434	26280	17	12F
0005432655435	26280	18	13E
0005432869427	26280	19	13F
0005432660801	26280	20	14A
0005432655430	26280	21	14E
0005432660800	26280	22	15A
0005432657424	26280	23	15D
0005432655432	26280	24	15F
0005432655426	26280	25	16A
0005432666371	26280	26	16F
0005432657425	26280	27	17C
0005432655431	26280	28	17D
0005432869412	26280	29	17F
0005432659689	26280	30	18C
0005432655428	26280	31	18E
0005432658575	26280	32	18F
0005434151656	26280	33	19A
0005432657422	26280	34	19F
0005432666372	26280	35	20A
0005432658572	26280	36	20C
0005432667437	26280	37	20D
0005432660799	26280	38	20F
0005432328385	3094	1	1A
0005432328379	3094	2	1C
0005432287152	3094	3	1D
0005432328387	3094	4	1F
0005432905024	3094	5	2A
0005432328369	3094	6	2C
0005432287154	3094	7	2D
0005432287151	3094	8	2F
0005433438836	3094	9	3C
0005432328400	3094	10	3F
0005432328367	3094	11	4D
0005432328391	3094	12	4F
0005432328372	3094	13	5C
0005432328386	3094	14	5F
0005432287157	3094	15	6A
0005432328378	3094	16	6D
0005432328403	3094	17	6E
0005432328366	3094	18	6F
0005432328377	3094	19	7A
0005432328395	3094	20	7C
0005432328368	3094	21	7E
0005432287156	3094	22	7F
0005432328365	3094	23	8C
0005432328361	3094	24	8F
0005432328390	3094	25	9A
0005433438833	3094	26	9D
0005432287153	3094	27	9E
0005432328402	3094	28	10A
0005432328360	3094	29	10C
0005432905062	3094	30	10D
0005432328394	3094	31	10E
0005432905025	3094	32	10F
0005432328380	3094	33	11A
0005432328375	3094	34	11C
0005432328373	3094	35	11F
0005432328374	3094	36	12A
0005432328381	3094	37	12C
0005433438834	3094	38	12D
0005433438832	3094	39	13A
0005432328405	3094	40	13D
0005432328388	3094	41	13E
0005432328404	3094	42	13F
0005432328364	3094	43	14D
0005432328376	3094	44	14F
0005432905061	3094	45	15A
0005432328371	3094	46	16C
0005432328362	3094	47	16E
0005432328401	3094	48	16D
0005432328398	3094	49	16F
0005432328370	3094	50	17A
0005432328389	3094	51	17C
0005432328397	3094	52	17D
0005432287155	3094	53	17E
0005432328383	3094	54	18A
0005433438831	3094	55	18C
0005433438837	3094	56	18D
0005433438835	3094	57	18E
0005432328392	3094	58	19A
0005432328382	3094	59	19C
0005432328393	3094	60	19D
0005432328406	3094	61	19F
0005432328363	3094	62	20A
0005432328399	3094	63	20C
0005432328396	3094	64	20D
0005432328384	3094	65	20F
0005432327973	31156	1	2A
0005433438794	31156	2	2C
0005432328053	31156	3	3A
0005432327972	31156	4	3D
0005432905088	31156	5	4A
0005432327970	31156	6	4C
0005432054283	31156	7	4F
0005432328051	31156	8	5A
0005432327911	31156	9	5C
0005433438801	31156	10	5F
0005433438800	31156	11	6C
0005432905084	31156	12	6F
0005432328055	31156	13	7A
0005432328024	31156	14	7C
0005432905086	31156	15	8A
0005432328072	31156	16	8C
0005432905089	31156	17	8D
0005432905087	31156	18	8E
0005433438790	31156	19	8F
0005432328011	31156	20	9A
0005432328013	31156	21	9C
0005433438789	31156	22	9D
0005432328025	31156	23	10A
0005432328110	31156	24	10C
0005432328066	31156	25	10D
0005432905090	31156	26	10F
0005432328061	31156	27	11D
0005432054284	31156	28	11E
0005432327925	31156	29	11F
0005432054282	31156	30	12E
0005432328056	31156	31	13A
0005433438791	31156	32	13C
0005432327898	31156	33	13D
0005433438769	31156	34	13E
0005432327896	31156	35	14C
0005432328026	31156	36	14D
0005432327968	31156	37	14F
0005432905083	31156	38	15A
0005432905085	31156	39	15C
0005432327934	31156	40	15D
0005432328014	31156	41	15E
0005432054285	31156	42	15F
0005432327969	31156	43	16A
0005432328054	31156	44	17E
0005432328060	31156	45	18A
0005432328057	31156	46	18F
0005432905082	31156	47	19C
0005432327935	31156	48	19F
0005432328134	31156	49	20C
0005433438795	31156	50	20D
0005435999142	6214	1	1C
0005435999140	6214	2	1A
0005435487493	6214	3	2A
0005435999134	6214	4	2F
0005434309644	6214	5	3A
0005435487525	6214	6	4A
0005435296956	6214	7	4B
0005435999135	6214	8	4D
0005435999133	6214	9	5A
0005434309642	6214	10	5B
0005434309653	6214	11	5E
0005435999139	6214	12	6A
0005435487536	6214	13	6D
0005434309649	6214	14	7A
0005435296952	6214	15	6F
0005435487537	6214	16	7C
0005432146185	6214	17	7D
0005435487545	6214	18	8B
0005435999143	6214	19	8A
0005435487453	6214	20	8E
0005434309643	6214	21	8F
0005435999130	6214	22	9C
0005435487524	6214	23	9D
0005434309654	6214	24	9F
0005435487454	6214	25	10E
0005435487623	6214	26	11E
0005435999138	6214	27	12B
0005435296950	6214	28	12C
0005435487546	6214	29	13B
0005434309646	6214	30	13A
0005432146184	6214	31	13D
0005435999141	6214	32	13C
0005435999129	6214	33	14B
0005434309647	6214	34	14D
0005435487483	6214	35	14C
0005434309651	6214	36	14F
0005435296941	6214	37	15B
0005434309652	6214	38	15D
0005435487455	6214	39	16B
0005435296955	6214	40	17A
0005435999136	6214	41	17C
0005434309648	6214	42	17D
0005435999131	6214	43	18C
0005435296949	6214	44	18E
0005434309650	6214	45	19A
0005435487471	6214	46	19B
0005435487460	6214	47	19F
0005434309645	6214	48	21A
0005435487488	6214	49	21C
0005435999137	6214	50	21B
0005435487487	6214	51	21D
0005435487535	6214	52	21E
0005435999132	6214	53	23C
0005435487462	6214	54	23F
0005435297010	19561	1	1A
0005435487662	19561	2	1F
0005435297012	19561	3	2F
0005434309503	19561	4	4A
0005434309574	19561	5	4B
0005435487669	19561	6	4F
0005435297014	19561	7	5D
0005435297008	19561	8	6C
0005434309535	19561	9	6E
0005434309502	19561	10	6D
0005435487653	19561	11	7A
0005435487668	19561	12	6F
0005435487657	19561	13	7C
0005435998957	19561	14	7F
0005434309543	19561	15	8D
0005435487665	19561	16	8E
0005435487661	19561	17	9B
0005435487670	19561	18	9F
0005435487655	19561	19	9E
0005435487654	19561	20	10C
0005435487667	19561	21	12D
0005435297016	19561	22	13E
0005435487673	19561	23	14A
0005435487658	19561	24	14C
0005434309553	19561	25	15D
0005435487666	19561	26	16A
0005434309584	19561	27	16B
0005435487659	19561	28	16C
0005435487671	19561	29	17A
0005435297015	19561	30	17B
0005435297011	19561	31	17E
0005435297013	19561	32	18C
0005435487674	19561	33	19A
0005435487675	19561	34	19B
0005434309506	19561	35	19D
0005435487664	19561	36	19E
0005435487672	19561	37	20E
0005435487660	19561	38	20F
0005435487663	19561	39	21E
0005435297009	19561	40	22B
0005435487656	19561	41	22D
0005435502155	1579	1	1A
0005434565817	1579	2	1D
0005435502154	1579	3	2A
0005433185989	1579	4	1F
0005435502157	1579	5	2D
0005434565819	1579	6	2F
0005434565826	1579	7	3A
0005433185990	1579	8	3C
0005435517783	1579	9	3F
0005435502160	1579	10	4A
0005435502164	1579	11	4C
0005435502162	1579	12	4D
0005435517793	1579	13	4E
0005435502158	1579	14	4F
0005435508284	1579	15	5A
0005434565818	1579	16	5C
0005434565824	1579	17	5D
0005435502172	1579	18	5E
0005434565828	1579	19	5F
0005435502159	1579	20	6A
0005435508283	1579	21	6C
0005435502153	1579	22	6D
0005435517797	1579	23	6E
0005434565825	1579	24	6F
0005432291914	1579	25	7C
0005435517796	1579	26	7E
0005435508278	1579	27	7F
0005434565815	1579	28	8A
0005435517778	1579	29	8D
0005435508281	1579	30	8E
0005435502167	1579	31	8F
0005435517799	1579	32	9A
0005435517790	1579	33	10C
0005435502163	1579	34	10D
0005435517795	1579	35	10F
0005435517794	1579	36	11A
0005435508276	1579	37	11C
0005432291913	1579	38	11D
0005435502171	1579	39	11F
0005435502169	1579	40	11E
0005435517788	1579	41	12A
0005435517791	1579	42	12C
0005435517798	1579	43	12D
0005435517787	1579	44	12F
0005435502174	1579	45	13A
0005435508279	1579	46	13D
0005435508282	1579	47	13E
0005435502165	1579	48	13F
0005435502161	1579	49	14A
0005435502173	1579	50	14D
0005434565816	1579	51	14E
0005435517789	1579	52	14F
0005435508285	1579	53	15C
0005435508277	1579	54	15D
0005435502166	1579	55	15E
0005434565827	1579	56	15F
0005435517786	1579	57	16C
0005435502170	1579	58	16D
0005434565822	1579	59	17A
0005435502168	1579	60	16F
0005435517782	1579	61	17C
0005435508280	1579	62	17D
0005435517781	1579	63	17E
0005434565820	1579	64	17F
0005435517785	1579	65	18A
0005435517780	1579	66	18D
0005435517784	1579	67	18F
0005435517779	1579	68	19C
0005435502156	1579	69	19D
0005434565821	1579	70	19E
0005435517792	1579	71	19F
0005434565823	1579	72	20C
0005432291912	1579	73	20F
0005434565713	20900	1	1D
0005435545618	20900	2	1F
0005435528918	20900	3	2C
0005434565683	20900	4	2D
0005435528930	20900	5	3A
0005434565761	20900	6	3C
0005435528898	20900	7	3D
0005433186061	20900	8	3F
0005435501939	20900	9	4A
0005434565678	20900	10	5A
0005435528954	20900	11	5C
0005434565685	20900	12	5D
0005435502003	20900	13	5E
0005435502002	20900	14	6A
0005435528909	20900	15	6C
0005435502035	20900	16	6F
0005435528894	20900	17	7D
0005435528929	20900	18	7E
0005433186062	20900	19	7F
0005435501995	20900	20	8A
0005435528928	20900	21	8C
0005433186055	20900	22	8D
0005435501963	20900	23	8E
0005434565712	20900	24	8F
0005435502001	20900	25	9A
0005434565688	20900	26	9D
0005434565697	20900	27	10A
0005435501997	20900	28	10C
0005434565737	20900	29	10D
0005433186056	20900	30	11A
0005435501989	20900	31	11C
0005435528919	20900	32	11E
0005435528931	20900	33	11D
0005433186058	20900	34	11F
0005434565714	20900	35	12E
0005435501969	20900	36	12D
0005435501968	20900	37	12F
0005433186057	20900	38	13D
0005434565726	20900	39	13E
0005435501946	20900	40	14A
0005433186060	20900	41	14C
0005434565687	20900	42	14D
0005433186063	20900	43	14E
0005434565684	20900	44	15A
0005435501977	20900	45	15C
0005435501934	20900	46	15D
0005434565720	20900	47	15E
0005435545619	20900	48	15F
0005435501978	20900	49	16E
0005434565727	20900	50	17C
0005433186064	20900	51	17D
0005435528913	20900	52	17E
0005435502009	20900	53	17F
0005433186059	20900	54	18A
0005435502012	20900	55	18D
0005434565679	20900	56	18F
0005434565698	20900	57	19E
0005435501996	20900	58	20A
0005435501940	20900	59	20D
0005434565692	20900	60	20E
0005435153698	3877	1	1D
0005435153694	3877	2	7C
0005435153695	3877	3	7D
0005435153696	3877	4	18D
0005435153699	3877	5	19D
0005435153700	3877	6	20B
0005435153697	3877	7	23A
0005435153634	21858	1	1A
0005435931574	21858	2	2A
0005435931577	21858	3	5A
0005435153664	21858	4	6A
0005435931575	21858	5	6D
0005435153631	21858	6	7C
0005435931573	21858	7	18A
0005435931576	21858	8	19B
0005435153649	21858	9	21D
0005432628747	7176	1	1A
0005435225462	7176	2	1C
0005432628743	7176	3	1D
0005432628751	7176	4	2A
0005432628741	7176	5	2D
0005435225477	7176	6	3B
0005432628748	7176	7	3C
0005432628749	7176	8	5D
0005432628737	7176	9	6A
0005432628738	7176	10	6C
0005435225448	7176	11	7B
0005432628740	7176	12	18A
0005432628742	7176	13	18D
0005432628750	7176	14	20C
0005432628744	7176	15	20D
0005435225444	7176	16	21B
0005432628745	7176	17	22B
0005432628746	7176	18	22C
0005432628739	7176	19	22D
0005432628637	28150	1	1B
0005435225525	28150	2	2B
0005432628586	28150	3	2A
0005432628624	28150	4	3D
0005432628590	28150	5	4A
0005435225527	28150	6	4C
0005432628671	28150	7	4D
0005432628640	28150	8	5A
0005432628649	28150	9	5B
0005432628622	28150	10	5C
0005435225528	28150	11	5D
0005435225530	28150	12	6B
0005432628650	28150	13	6C
0005432628607	28150	14	6D
0005432628608	28150	15	7A
0005432628680	28150	16	7B
0005432628690	28150	17	7C
0005435225532	28150	18	7D
0005435225526	28150	19	18A
0005435225533	28150	20	19A
0005435225534	28150	21	19D
0005432628589	28150	22	21B
0005435225531	28150	23	21D
0005435225529	28150	24	22D
0005434267885	8767	1	1A
0005434267891	8767	2	1D
0005435960022	8767	3	2D
0005435960023	8767	4	18D
0005435960025	8767	5	20C
0005435960024	8767	6	21C
0005435960015	15251	1	3A
0005434267923	15251	2	4A
0005435960013	15251	3	4D
0005434267924	15251	4	6D
0005435960014	15251	5	18A
0005434267922	15251	6	20C
0005432675028	1170	1	1D
0005432692815	1170	2	2A
0005432692834	1170	3	2F
0005432675019	1170	4	2D
0005432873185	1170	5	2C
0005432677542	1170	6	3D
0005432692818	1170	7	3C
0005432675032	1170	8	4A
0005432675024	1170	9	4D
0005432675022	1170	10	5D
0005432692811	1170	11	5C
0005432692822	1170	12	5A
0005432873170	1170	13	5F
0005432692827	1170	14	6E
0005432675018	1170	15	7A
0005432675029	1170	16	7B
0005432692838	1170	17	8C
0005432692820	1170	18	8B
0005432692829	1170	19	8E
0005432692832	1170	20	8D
0005432873190	1170	21	9D
0005432675026	1170	22	9E
0005432692814	1170	23	10C
0005432692813	1170	24	10D
0005432692816	1170	25	11A
0005432692821	1170	26	10F
0005432692823	1170	27	11E
0005432692826	1170	28	11F
0005432692837	1170	29	12A
0005432692831	1170	30	12D
0005432873167	1170	31	13C
0005432692839	1170	32	13E
0005432677543	1170	33	13D
0005432675027	1170	34	14A
0005432873169	1170	35	14F
0005432873168	1170	36	14E
0005432677540	1170	37	15E
0005432675020	1170	38	16A
0005432692840	1170	39	15F
0005432692825	1170	40	16C
0005432692830	1170	41	16B
0005432692812	1170	42	17A
0005432675021	1170	43	17D
0005432675025	1170	44	17C
0005432692836	1170	45	18B
0005432675030	1170	46	18A
0005432675023	1170	47	18E
0005432692828	1170	48	19B
0005432692841	1170	49	20B
0005432677541	1170	50	20A
0005432675017	1170	51	20C
0005432692819	1170	52	20F
0005432692824	1170	53	20E
0005432692817	1170	54	21A
0005432692842	1170	55	21D
0005432692835	1170	56	21C
0005432692833	1170	57	21B
0005432675031	1170	58	21F
0005432692597	17456	1	2A
0005432692529	17456	2	2F
0005432674873	17456	3	3D
0005432873244	17456	4	4A
0005432692546	17456	5	4D
0005432873242	17456	6	5C
0005432692538	17456	7	6B
0005432692539	17456	8	7B
0005432674955	17456	9	7D
0005432692634	17456	10	8D
0005432692615	17456	11	8C
0005432677514	17456	12	9A
0005432677507	17456	13	9D
0005432692591	17456	14	9C
0005432674867	17456	15	9B
0005432692556	17456	16	9F
0005432873245	17456	17	10C
0005432692699	17456	18	10E
0005432674894	17456	19	10F
0005432674891	17456	20	11B
0005432692596	17456	21	11C
0005432677521	17456	22	11F
0005432692595	17456	23	12F
0005432873239	17456	24	12D
0005432873238	17456	25	13A
0005432674874	17456	26	13D
0005432692700	17456	27	14B
0005432674865	17456	28	14F
0005432677522	17456	29	14E
0005432677513	17456	30	15F
0005432692560	17456	31	15E
0005432873243	17456	32	16A
0005432873241	17456	33	16F
0005432692533	17456	34	17B
0005432692545	17456	35	17C
0005432674898	17456	36	18B
0005432692544	17456	37	19A
0005432692530	17456	38	18F
0005432674866	17456	39	19C
0005432674931	17456	40	19B
0005432692559	17456	41	19F
0005432692604	17456	42	19E
0005432692618	17456	43	20B
0005432674954	17456	44	20D
0005432674892	17456	45	20C
0005432674922	17456	46	20F
0005432692594	17456	47	21B
0005432692564	17456	48	21F
0005432873240	17456	49	21E
0005434435077	1149	1	1A
0005433156626	1149	2	1B
0005433156639	1149	3	1D
0005434435070	1149	4	2C
0005434435078	1149	5	3A
0005434435069	1149	6	3B
0005434435072	1149	7	3C
0005433156640	1149	8	4C
0005434435076	1149	9	5D
0005434435068	1149	10	6A
0005434435073	1149	11	7C
0005434435066	1149	12	18A
0005434435081	1149	13	18C
0005434435080	1149	14	19A
0005433156641	1149	15	19C
0005433156617	1149	16	19D
0005434435071	1149	17	20A
0005434435074	1149	18	20B
0005434435079	1149	19	21D
0005434435067	1149	20	22B
0005434435075	1149	21	22D
0005433156692	17282	1	1B
0005433156688	17282	2	1D
0005434434939	17282	3	3B
0005434434919	17282	4	3C
0005433156687	17282	5	4C
0005433156686	17282	6	5B
0005433156691	17282	7	6A
0005434434940	17282	8	6B
0005434434980	17282	9	6D
0005434434981	17282	10	7C
0005434435009	17282	11	18A
0005433156685	17282	12	20B
0005433156689	17282	13	20C
0005433156690	17282	14	23B
0005435086780	4083	1	3C
0005435928069	4083	2	5D
0005435086778	4083	3	19D
0005435086781	4083	4	20C
0005435086783	4083	5	21A
0005435086782	4083	6	21B
0005435086779	4083	7	22D
0005435086784	4083	8	23A
0005435086733	24398	1	2B
0005435928108	24398	2	4B
0005435086719	24398	3	5B
0005435086708	24398	4	5C
0005435928110	24398	5	6C
0005435086738	24398	6	6D
0005435086707	24398	7	19C
0005435086734	24398	8	21D
0005435928107	24398	9	22C
0005435928109	24398	10	23B
0005435551508	11062	1	11E
0005435551509	11062	2	13H
0005435551504	11062	3	14B
0005435551491	11062	4	18A
0005435551507	11062	5	21D
0005435551502	11062	6	25F
0005435551527	11062	7	28E
0005435098521	11062	8	29G
0005435551503	11062	9	33E
0005435551526	11062	10	33D
0005435551493	11062	11	34A
0005435551510	11062	12	36G
0005435551552	17005	1	1A
0005435098542	17005	2	2B
0005435098540	17005	3	11A
0005435098539	17005	4	15E
0005435551544	17005	5	15H
0005435551554	17005	6	16E
0005435551537	17005	7	17B
0005435551551	17005	8	18D
0005435551538	17005	9	18G
0005435551543	17005	10	19E
0005435551549	17005	11	19G
0005435551542	17005	12	22A
0005435551546	17005	13	22F
0005435551547	17005	14	23A
0005435551553	17005	15	24F
0005435551550	17005	16	27F
0005435551541	17005	17	29A
0005435098538	17005	18	29H
0005435551540	17005	19	29G
0005435098541	17005	20	31B
0005435551545	17005	21	32F
0005435551539	17005	22	33E
0005435551548	17005	23	36E
0005435098543	17005	24	37B
0005435551555	17005	25	37F
0005433261495	18245	1	2B
0005433261492	18245	2	3B
0005433261493	18245	3	3C
0005434963931	18245	4	4C
0005434963927	18245	5	5B
0005434963933	18245	6	5C
0005434963899	18245	7	5G
0005433261498	18245	8	11A
0005434964006	18245	9	9H
0005434963961	18245	10	11D
0005433261490	18245	11	11F
0005434963926	18245	12	12G
0005433261487	18245	13	12H
0005433261501	18245	14	13A
0005434963945	18245	15	13D
0005434963992	18245	16	14G
0005433261483	18245	17	14F
0005434963936	18245	18	15A
0005433261482	18245	19	15F
0005433261503	18245	20	17D
0005433261502	18245	21	18B
0005434963949	18245	22	18F
0005433261496	18245	23	19G
0005434963944	18245	24	20G
0005434963897	18245	25	23G
0005434963954	18245	26	23F
0005433261500	18245	27	24F
0005434963955	18245	28	24G
0005433261494	18245	29	25F
0005433261486	18245	30	27E
0005434963924	18245	31	28A
0005434963963	18245	32	27H
0005433261489	18245	33	28D
0005434964000	18245	34	28G
0005434963898	18245	35	30B
0005434963928	18245	36	30F
0005433261484	18245	37	32D
0005434963999	18245	38	32E
0005434963998	18245	39	33E
0005433261491	18245	40	33H
0005434963964	18245	41	34G
0005433261485	18245	42	35D
0005434963950	18245	43	35G
0005433261497	18245	44	35H
0005434963925	18245	45	37E
0005433261488	18245	46	37H
0005434963948	18245	47	38B
0005433261499	18245	48	38H
0005434625892	4848	1	2F
0005434625896	4848	2	4A
0005433194819	4848	3	4C
0005434625897	4848	4	5A
0005433194825	4848	5	5E
0005435907430	4848	6	6D
0005434625898	4848	7	6E
0005435907424	4848	8	7A
0005434625893	4848	9	8D
0005434625901	4848	10	8E
0005434625891	4848	11	11E
0005435907429	4848	12	12E
0005433194820	4848	13	13E
0005434625899	4848	14	15A
0005435907425	4848	15	17D
0005434625894	4848	16	18F
0005433194818	4848	17	19E
0005434625895	4848	18	20D
0005434625900	4848	19	20E
0005433194840	32923	1	1A
0005435907472	32923	2	1C
0005433194837	32923	3	1D
0005434625854	32923	4	2F
0005433194838	32923	5	3C
0005433194836	32923	6	4E
0005435907471	32923	7	7A
0005435907470	32923	8	7E
0005433194835	32923	9	9A
0005433194839	32923	10	10A
0005435907473	32923	11	10C
0005434625827	32923	12	10D
0005435907469	32923	13	11A
0005434625852	32923	14	13D
0005433194842	32923	15	13E
0005434625806	32923	16	13F
0005433194834	32923	17	15D
0005434625849	32923	18	15E
0005434625832	32923	19	15F
0005434625856	32923	20	16F
0005433194841	32923	21	17C
0005434625850	32923	22	17E
0005434625831	32923	23	19E
0005434625851	32923	24	20C
0005434625838	32923	25	20E
0005435784775	13768	1	1B
0005435784825	13768	2	1D
0005435937356	13768	3	2C
0005435784833	13768	4	2D
0005435784789	13768	5	3B
0005435937349	13768	6	3C
0005435784904	13768	7	3D
0005435784903	13768	8	4A
0005435784768	13768	9	4C
0005432195678	13768	10	4D
0005435784807	13768	11	5A
0005435784873	13768	12	5B
0005435784858	13768	13	5C
0005435937352	13768	14	5D
0005435784770	13768	15	6A
0005435784826	13768	16	6B
0005435784738	13768	17	6D
0005435937350	13768	18	7A
0005435784774	13768	19	7B
0005435784844	13768	20	7C
0005435784808	13768	21	7D
0005435937351	13768	22	18B
0005435784812	13768	23	18C
0005435937357	13768	24	18D
0005435784830	13768	25	19A
0005435784776	13768	26	19B
0005435784739	13768	27	19D
0005435784792	13768	28	20A
0005435784780	13768	29	20C
0005435784742	13768	30	21A
0005435784853	13768	31	22A
0005435937353	13768	32	22B
0005435937354	13768	33	22C
0005435784793	13768	34	22D
0005435937355	13768	35	23A
0005435784755	13768	36	23B
0005435785047	27448	1	1A
0005435785063	27448	2	1B
0005435785066	27448	3	1C
0005435787334	27448	4	1D
0005435785065	27448	5	2B
0005435785059	27448	6	2A
0005435787335	27448	7	2C
0005435785060	27448	8	2D
0005435785079	27448	9	3A
0005435937311	27448	10	3B
0005435785055	27448	11	3C
0005435785071	27448	12	3D
0005435785062	27448	13	4A
0005435785058	27448	14	4B
0005435785080	27448	15	4C
0005435787336	27448	16	4D
0005432190596	27448	17	5A
0005435785067	27448	18	5B
0005435785074	27448	19	5C
0005435785048	27448	20	5D
0005435785078	27448	21	6A
0005435785077	27448	22	6B
0005435785072	27448	23	6C
0005432190597	27448	24	6D
0005435937317	27448	25	7A
0005435785049	27448	26	7B
0005435785056	27448	27	7D
0005435785076	27448	28	18A
0005435937310	27448	29	18B
0005435785064	27448	30	18C
0005435785068	27448	31	18D
0005435785046	27448	32	19A
0005435785053	27448	33	19B
0005435785052	27448	34	19C
0005435785070	27448	35	19D
0005435785054	27448	36	20A
0005435785069	27448	37	20B
0005435785057	27448	38	20C
0005435785050	27448	39	20D
0005435785061	27448	40	21C
0005435787337	27448	41	21D
0005432190598	27448	42	22A
0005435785073	27448	43	22B
0005435785051	27448	44	22C
0005435785075	27448	45	22D
0005435937316	27448	46	23A
0005434406659	20277	1	1A
0005434406698	20277	2	1C
0005434406843	20277	3	1D
0005434406893	20277	4	1F
0005434406781	20277	5	2D
0005434406658	20277	6	3D
0005434406844	20277	7	3F
0005434406684	20277	8	4A
0005435310987	20277	9	4C
0005434406689	20277	10	4E
0005435310979	20277	11	4F
0005434406702	20277	12	5A
0005435310983	20277	13	5C
0005435310990	20277	14	5D
0005434406774	20277	15	5E
0005434406936	20277	16	5F
0005434406880	20277	17	6A
0005432058356	20277	18	6C
0005435310988	20277	19	6D
0005434406882	20277	20	6F
0005432058353	20277	21	7A
0005434406901	20277	22	7C
0005434406718	20277	23	7D
0005434407033	20277	24	7E
0005434406676	20277	25	7F
0005435310980	20277	26	8A
0005435310991	20277	27	8C
0005434406657	20277	28	8D
0005434406977	20277	29	8E
0005434406894	20277	30	8F
0005434406725	20277	31	9A
0005434406842	20277	32	9C
0005434406699	20277	33	9E
0005435310978	20277	34	9F
0005435310992	20277	35	10A
0005434406881	20277	36	10C
0005434407048	20277	37	10E
0005434406752	20277	38	11A
0005432058352	20277	39	11C
0005434406967	20277	40	11E
0005435310994	20277	41	11F
0005434406738	20277	42	12A
0005435310985	20277	43	12D
0005434406760	20277	44	12E
0005434406754	20277	45	12F
0005434406895	20277	46	13A
0005434406943	20277	47	13C
0005434406845	20277	48	13D
0005434406671	20277	49	13E
0005434406739	20277	50	13F
0005434406648	20277	51	14C
0005435310995	20277	52	14D
0005434407087	20277	53	14F
0005435310981	20277	54	15D
0005434406697	20277	55	15E
0005434406672	20277	56	15F
0005434406780	20277	57	16A
0005434406688	20277	58	16C
0005435310989	20277	59	16D
0005434406753	20277	60	16F
0005435310982	20277	61	17C
0005435310986	20277	62	17D
0005434406812	20277	63	17F
0005434406731	20277	64	18A
0005432058354	20277	65	18C
0005435310993	20277	66	18E
0005434406811	20277	67	18F
0005434406678	20277	68	19A
0005434406641	20277	69	19D
0005434406703	20277	70	19E
0005435310984	20277	71	19F
0005434406978	20277	72	20A
0005434406677	20277	73	20C
0005432058355	20277	74	20D
0005434406807	20277	75	20E
0005434406814	20277	76	20F
0005434407341	26975	1	1A
0005434407302	26975	2	1D
0005434407316	26975	3	2A
0005434407293	26975	4	2D
0005434407323	26975	5	2F
0005434407343	26975	6	3C
0005434407315	26975	7	3D
0005434407325	26975	8	3F
0005434407298	26975	9	4A
0005434407317	26975	10	4D
0005434407344	26975	11	4E
0005434407310	26975	12	5D
0005434407337	26975	13	5E
0005434407303	26975	14	5F
0005434407300	26975	15	6A
0005434407340	26975	16	6C
0005432153890	26975	17	6D
0005434407296	26975	18	6E
0005434407299	26975	19	6F
0005434407333	26975	20	7C
0005434407328	26975	21	7D
0005434407335	26975	22	7E
0005432153891	26975	23	7F
0005434407331	26975	24	8A
0005432153888	26975	25	8C
0005434407287	26975	26	8D
0005434407284	26975	27	8E
0005434407311	26975	28	8F
0005434407282	26975	29	9A
0005434407286	26975	30	9D
0005434407306	26975	31	9E
0005432153885	26975	32	9F
0005432153889	26975	33	10A
0005434407312	26975	34	10C
0005434407336	26975	35	10D
0005434407345	26975	36	10E
0005434407327	26975	37	11A
0005434407329	26975	38	11C
0005434407313	26975	39	11D
0005434407309	26975	40	11E
0005434407330	26975	41	11F
0005434407295	26975	42	12A
0005434407324	26975	43	12C
0005434407346	26975	44	12E
0005434407326	26975	45	12F
0005434407314	26975	46	13C
0005434407288	26975	47	13E
0005434407291	26975	48	13F
0005434407294	26975	49	14C
0005434407301	26975	50	14D
0005434407283	26975	51	14E
0005434407307	26975	52	15A
0005434407308	26975	53	15D
0005434407297	26975	54	15F
0005434407339	26975	55	16A
0005434407320	26975	56	16C
0005434407334	26975	57	16D
0005434407305	26975	58	16E
0005432153886	26975	59	17A
0005432153887	26975	60	17D
0005434407318	26975	61	17E
0005434407290	26975	62	18D
0005434407321	26975	63	18E
0005434407304	26975	64	18F
0005434407292	26975	65	19C
0005434407285	26975	66	19D
0005434407332	26975	67	19F
0005434407319	26975	68	20A
0005434407289	26975	69	20C
0005434407338	26975	70	20D
0005434407342	26975	71	20E
0005434407322	26975	72	20F
0005434311205	5692	1	1F
0005434319291	5692	2	2A
0005434311204	5692	3	2C
0005433123595	5692	4	2D
0005433123644	5692	5	2F
0005433123600	5692	6	4F
0005433123606	5692	7	6A
0005433123594	5692	8	6D
0005433123622	5692	9	6E
0005433123565	5692	10	7A
0005433123614	5692	11	7E
0005433123607	5692	12	7F
0005433123649	5692	13	9C
0005433123599	5692	14	9E
0005434319290	5692	15	10E
0005434319287	5692	16	11D
0005432109683	5692	17	11E
0005433123598	5692	18	13C
0005432109684	5692	19	13F
0005433123608	5692	20	14C
0005433123643	5692	21	15A
0005433123617	5692	22	15C
0005433123648	5692	23	16D
0005433123570	5692	24	17A
0005433123592	5692	25	17C
0005434319288	5692	26	17D
0005434319289	5692	27	17E
0005434319292	5692	28	18F
0005434319293	5692	29	19E
0005434319294	5692	30	20C
0005433123597	5692	31	20E
0005433123647	5692	32	20F
0005434319197	15652	1	1A
0005433123794	15652	2	2A
0005434319204	15652	3	2C
0005433123793	15652	4	2F
0005434311192	15652	5	3D
0005433123786	15652	6	3F
0005433123781	15652	7	4A
0005434319157	15652	8	4C
0005434311193	15652	9	4D
0005434311197	15652	10	4F
0005434319182	15652	11	5A
0005434319143	15652	12	5D
0005433123798	15652	13	6D
0005434319146	15652	14	6E
0005434319150	15652	15	7A
0005434319202	15652	16	8C
0005433123788	15652	17	8E
0005433123803	15652	18	8F
0005433123790	15652	19	9A
0005434311200	15652	20	9E
0005434319144	15652	21	10D
0005434311199	15652	22	10E
0005433123797	15652	23	10F
0005433123787	15652	24	11C
0005433123800	15652	25	11D
0005433123792	15652	26	11E
0005433123802	15652	27	11F
0005433123796	15652	28	12D
0005433123785	15652	29	12E
0005434319195	15652	30	13D
0005433123782	15652	31	14C
0005433123789	15652	32	14E
0005434311198	15652	33	14F
0005434319184	15652	34	15A
0005434319163	15652	35	15C
0005433123784	15652	36	15D
0005433123791	15652	37	15F
0005434319183	15652	38	16A
0005434319196	15652	39	17D
0005434319198	15652	40	17E
0005434319203	15652	41	18A
0005433123799	15652	42	18D
0005433123783	15652	43	19E
0005433123801	15652	44	19F
0005434319165	15652	45	20A
0005434319147	15652	46	20D
0005433123795	15652	47	20E
0005434319194	15652	48	20F
0005435221499	24986	1	1C
0005435217676	24986	2	6B
0005435217682	24986	3	19B
0005435221500	24986	4	19D
0005435221498	24986	5	23B
0005434189081	8958	1	2A
0005434189115	8958	2	3A
0005434484306	8958	3	3D
0005434189097	8958	4	4B
0005434189098	8958	5	4C
0005434484299	8958	6	5A
0005434484298	8958	7	5C
0005434189114	8958	8	7A
0005434484303	8958	9	18A
0005434189116	8958	10	18C
0005434484301	8958	11	18D
0005434484304	8958	12	19D
0005434484305	8958	13	22A
0005434484302	8958	14	22B
0005434484300	8958	15	22C
0005434484256	16628	1	1C
0005434484233	16628	2	1D
0005434484259	16628	3	2B
0005434484244	16628	4	4B
0005434189137	16628	5	5A
0005434484249	16628	6	5C
0005434189140	16628	7	5D
0005434189136	16628	8	6A
0005434484257	16628	9	6B
0005434189139	16628	10	6D
0005434189135	16628	11	18A
0005434484252	16628	12	18D
0005434484243	16628	13	19B
0005434484246	16628	14	20A
0005434189138	16628	15	20C
0005434484245	16628	16	21C
0005434484255	16628	17	21D
0005433722115	7613	1	2C
0005433123793	7613	2	3A
0005433123790	7613	3	4C
0005433123803	7613	4	4D
0005433722106	7613	5	5F
0005433123800	7613	6	6E
0005433123792	7613	7	6F
0005433123797	7613	8	7E
0005433123785	7613	9	8C
0005433123786	7613	10	9D
0005433123787	7613	11	9F
0005433123781	7613	12	10C
0005433123782	7613	13	10F
0005433123798	7613	14	11A
0005433123791	7613	15	11C
0005433123801	7613	16	11D
0005433722103	7613	17	12E
0005433123783	7613	18	13E
0005433123789	7613	19	14E
0005433123796	7613	20	15E
0005433123794	7613	21	17A
0005433123799	7613	22	17D
0005433123795	7613	23	17E
0005433123784	7613	24	19A
0005433123802	7613	25	19F
0005433123788	7613	26	20E
0005432720724	7610	1	1A
0005433449808	7610	2	1C
0005432692861	7610	3	1D
0005433449824	7610	4	1F
0005432692863	7610	5	2A
0005432720715	7610	6	2C
0005432720717	7610	7	2F
0005433449814	7610	8	3A
0005432692846	7610	9	3C
0005432692870	7610	10	3D
0005432720722	7610	11	3F
0005433449811	7610	12	4A
0005433449809	7610	13	4C
0005432692848	7610	14	4D
0005432720711	7610	15	4F
0005432720707	7610	16	5A
0005432692858	7610	17	5C
0005433449817	7610	18	5D
0005433449823	7610	19	5E
0005432720713	7610	20	5F
0005432692844	7610	21	6A
0005432720704	7610	22	6C
0005432692855	7610	23	6E
0005432692868	7610	24	6F
0005432720720	7610	25	7A
0005432692856	7610	26	7D
0005432692849	7610	27	7E
0005432720718	7610	28	7F
0005432720710	7610	29	8A
0005432720726	7610	30	8C
0005433449812	7610	31	8D
0005432692845	7610	32	8E
0005432720725	7610	33	9A
0005432071551	7610	34	9C
0005432720706	7610	35	9D
0005432720714	7610	36	9E
0005433449822	7610	37	9F
0005432692872	7610	38	10A
0005432692852	7610	39	10C
0005433449821	7610	40	10D
0005432692857	7610	41	10E
0005432692865	7610	42	10F
0005432720705	7610	43	11A
0005432692862	7610	44	11C
0005433449815	7610	45	11D
0005432720723	7610	46	11E
0005432720716	7610	47	11F
0005433449818	7610	48	12A
0005432720708	7610	49	12C
0005432720709	7610	50	12D
0005433449807	7610	51	12E
0005432692843	7610	52	12F
0005432720727	7610	53	13A
0005432692869	7610	54	13E
0005432071553	7610	55	13F
0005432720729	7610	56	14A
0005433449819	7610	57	14E
0005433449820	7610	58	15A
0005433449825	7610	59	15C
0005432692873	7610	60	15D
0005432692860	7610	61	15E
0005432692854	7610	62	15F
0005433449806	7610	63	16A
0005433449816	7610	64	16C
0005432720728	7610	65	16D
0005432720712	7610	66	16E
0005432071554	7610	67	16F
0005432720721	7610	68	17A
0005432692859	7610	69	17C
0005432720719	7610	70	17D
0005432692866	7610	71	17E
0005432692850	7610	72	17F
0005432692847	7610	73	18C
0005432720703	7610	74	18D
0005433449826	7610	75	18F
0005433449827	7610	76	18E
0005432692867	7610	77	19A
0005432692864	7610	78	19E
0005433449813	7610	79	19F
0005432071552	7610	80	20A
0005433449810	7610	81	20C
0005432692871	7610	82	20D
0005432692853	7610	83	20E
0005432692851	7610	84	20F
0005432692529	30367	1	1A
0005432692538	30367	2	1F
0005432692530	30367	3	3A
0005432692556	30367	4	3F
0005433449620	30367	5	4D
0005432692539	30367	6	4E
0005432692559	30367	7	4F
0005433449601	30367	8	5A
0005432692597	30367	9	5D
0005432692533	30367	10	5E
0005433449592	30367	11	6A
0005433449667	30367	12	7C
0005433449657	30367	13	7E
0005433449673	30367	14	7D
0005433449678	30367	15	8E
0005432692595	30367	16	9C
0005432692544	30367	17	9D
0005432692564	30367	18	10C
0005432692596	30367	19	10F
0005433449708	30367	20	11A
0005433449694	30367	21	11C
0005433449756	30367	22	11E
0005433449669	30367	23	11F
0005432692591	30367	24	13D
0005433449755	30367	25	14E
0005432692699	30367	26	14F
0005433449672	30367	27	15A
0005432692618	30367	28	15D
0005433449587	30367	29	15E
0005433449645	30367	30	15F
0005432692560	30367	31	16C
0005432692700	30367	32	16D
0005432692604	30367	33	17A
0005433449611	30367	34	18A
0005432692546	30367	35	18F
0005432692634	30367	36	19A
0005432692615	30367	37	19D
0005432692594	30367	38	19E
0005432692545	30367	39	20A
0005433449607	30367	40	20D
0005433449600	30367	41	20E
0005433123606	30366	1	1A
0005433123595	30366	2	1D
0005433123565	30366	3	2A
0005432720587	30366	4	3C
0005433123570	30366	5	3D
0005433123608	30366	6	3F
0005432720524	30366	7	4D
0005433123649	30366	8	4F
0005433123617	30366	9	5A
0005432720541	30366	10	5D
0005433123594	30366	11	6A
0005432720630	30366	12	6E
0005432720486	30366	13	7C
0005432720586	30366	14	7D
0005432720595	30366	15	7E
0005432720469	30366	16	7F
0005433123607	30366	17	8A
0005432720568	30366	18	8C
0005433722171	30366	19	8D
0005433123648	30366	20	8F
0005432720588	30366	21	9A
0005432720536	30366	22	9C
0005433722172	30366	23	9D
0005432720457	30366	24	9E
0005433123622	30366	25	10C
0005432720537	30366	26	10D
0005433722175	30366	27	10E
0005432720468	30366	28	11A
0005433722173	30366	29	12A
0005433123598	30366	30	12E
0005433722178	30366	31	13A
0005433722174	30366	32	13C
0005433722170	30366	33	13F
0005433123592	30366	34	14A
0005433123597	30366	35	15C
0005433123644	30366	36	15D
0005433722176	30366	37	15F
0005433722177	30366	38	16A
0005432720662	30366	39	16C
0005433123643	30366	40	16D
0005432720471	30366	41	16F
0005432720576	30366	42	17E
0005433123614	30366	43	17F
0005432720533	30366	44	18A
0005433123600	30366	45	18F
0005432720663	30366	46	19A
0005433123647	30366	47	19D
0005432720525	30366	48	20A
0005433123599	30366	49	20D
0005432720567	30366	50	20F
0005434586429	1381	1	1A
0005433524959	1381	2	1C
0005432927886	1381	3	1F
0005433192822	1381	4	2C
0005433192821	1381	5	2F
0005433724776	1381	6	3C
0005434586430	1381	7	3A
0005434586424	1381	8	3D
0005432968802	1381	9	3F
0005433524962	1381	10	4A
0005433192895	1381	11	4C
0005434586444	1381	12	4E
0005433192877	1381	13	4F
0005433192819	1381	14	5A
0005434586422	1381	15	5C
0005433524957	1381	16	5D
0005434514948	1381	17	5E
0005434586441	1381	18	5F
0005434586421	1381	19	6A
0005434514949	1381	20	6F
0005434586434	1381	21	7A
0005433724772	1381	22	7D
0005433192854	1381	23	7F
0005434586428	1381	24	8A
0005433524958	1381	25	8C
0005432968803	1381	26	8D
0005434586437	1381	27	8F
0005434586442	1381	28	9A
0005433724773	1381	29	9D
0005433192880	1381	30	9E
0005433524963	1381	31	9F
0005433524961	1381	32	10A
0005433192812	1381	33	10C
0005433724774	1381	34	10D
0005432270983	1381	35	10F
0005434586438	1381	36	11A
0005434586427	1381	37	11C
0005434513561	1381	38	11D
0005434586433	1381	39	11E
0005434586425	1381	40	12A
0005433192845	1381	41	12C
0005434586445	1381	42	12D
0005433524965	1381	43	12E
0005433192846	1381	44	13A
0005432927889	1381	45	13D
0005434586426	1381	46	13E
0005434586423	1381	47	14C
0005434513564	1381	48	14A
0005433524964	1381	49	14D
0005434586443	1381	50	14E
0005433192863	1381	51	14F
0005433192896	1381	52	15D
0005434586436	1381	53	15E
0005432270984	1381	54	15F
0005434586446	1381	55	16A
0005433192897	1381	56	16D
0005433192862	1381	57	16E
0005434586432	1381	58	16F
0005432968811	1381	59	17A
0005433524967	1381	60	17D
0005434586439	1381	61	17E
0005434513562	1381	62	17F
0005433192865	1381	63	18A
0005432270985	1381	64	18C
0005434586431	1381	65	18D
0005434586435	1381	66	18E
0005434586440	1381	67	18F
0005434513563	1381	68	19A
0005432927901	1381	69	19E
0005433524966	1381	70	19F
0005433524960	1381	71	20C
0005432927902	1381	72	20E
0005433724775	1381	73	20F
0005432927939	18551	1	1C
0005434586187	18551	2	1D
0005434586191	18551	3	1F
0005433192952	18551	4	2A
0005433192954	18551	5	2C
0005433192958	18551	6	2F
0005433524885	18551	7	3A
0005432927941	18551	8	3C
0005433192956	18551	9	3D
0005434586201	18551	10	3F
0005434586246	18551	11	4A
0005432927938	18551	12	4C
0005434586189	18551	13	4E
0005434586221	18551	14	5D
0005434586307	18551	15	6C
0005432927940	18551	16	6D
0005434586200	18551	17	6E
0005434514931	18551	18	7A
0005434586282	18551	19	7C
0005433524874	18551	20	7D
0005433524853	18551	21	7F
0005432968823	18551	22	8A
0005434586195	18551	23	8C
0005433524901	18551	24	8D
0005433192951	18551	25	8E
0005434586266	18551	26	8F
0005433192955	18551	27	9A
0005434586265	18551	28	9C
0005433524875	18551	29	9D
0005434586176	18551	30	9E
0005434586218	18551	31	9F
0005434586278	18551	32	10A
0005434586198	18551	33	10C
0005432968824	18551	34	11C
0005433192950	18551	35	11E
0005434586235	18551	36	12A
0005433524886	18551	37	12C
0005433524896	18551	38	12E
0005433192949	18551	39	12F
0005433192953	18551	40	13C
0005434586264	18551	41	13D
0005432927936	18551	42	13F
0005433192957	18551	43	14A
0005433192947	18551	44	14C
0005433192948	18551	45	14D
0005433524902	18551	46	15C
0005434586247	18551	47	15D
0005434586193	18551	48	15E
0005434586188	18551	49	15F
0005434586174	18551	50	16D
0005433724730	18551	51	16E
0005434586254	18551	52	16F
0005433524860	18551	53	17A
0005432927937	18551	54	17C
0005433524861	18551	55	17D
0005434586212	18551	56	17E
0005433524881	18551	57	17F
0005434586194	18551	58	18A
0005434586199	18551	59	18E
0005433524870	18551	60	18F
0005434586217	18551	61	19A
0005434586220	18551	62	19C
0005433192945	18551	63	19D
0005433724738	18551	64	19E
0005433192946	18551	65	20A
0005433724737	18551	66	20C
0005434586175	18551	67	20F
0005434343927	11474	1	1A
0005434343948	11474	2	1B
0005434343929	11474	3	1C
0005434343938	11474	4	1D
0005434343928	11474	5	2A
0005434343930	11474	6	2B
0005434343921	11474	7	2C
0005434343918	11474	8	2D
0005435302131	11474	9	3A
0005434343916	11474	10	3B
0005434343946	11474	11	3C
0005435302132	11474	12	3D
0005434343943	11474	13	4B
0005434142582	11474	14	4C
0005434343912	11474	15	4D
0005434343939	11474	16	5A
0005434343932	11474	17	5B
0005434343915	11474	18	5C
0005434343936	11474	19	5D
0005434343923	11474	20	6A
0005434343911	11474	21	6B
0005434343940	11474	22	6C
0005434343913	11474	23	7A
0005434343933	11474	24	7B
0005434142583	11474	25	7D
0005434343941	11474	26	18C
0005434343942	11474	27	18D
0005434343944	11474	28	19A
0005434343914	11474	29	19B
0005434343935	11474	30	19C
0005434343937	11474	31	19D
0005434343920	11474	32	20A
0005434343947	11474	33	20C
0005434142584	11474	34	20D
0005434343922	11474	35	21A
0005434343945	11474	36	21B
0005434343924	11474	37	21D
0005434343925	11474	38	22A
0005434343926	11474	39	22B
0005434343931	11474	40	22C
0005434343934	11474	41	22D
0005434343919	11474	42	23A
0005434343917	11474	43	23B
0005434343736	29775	1	1A
0005434343632	29775	2	1B
0005435304128	29775	3	1C
0005434343705	29775	4	1D
0005435304129	29775	5	2A
0005435305003	29775	6	2B
0005434343670	29775	7	3A
0005435304130	29775	8	3B
0005434343681	29775	9	3D
0005435304127	29775	10	4B
0005434343745	29775	11	4D
0005434343678	29775	12	5B
0005434343622	29775	13	5C
0005434343582	29775	14	5D
0005434343740	29775	15	6A
0005434343706	29775	16	6C
0005434343593	29775	17	7B
0005434343602	29775	18	7C
0005434343615	29775	19	7D
0005434343744	29775	20	18A
0005434343616	29775	21	18B
0005434343671	29775	22	18D
0005434343679	29775	23	19C
0005434343771	29775	24	19D
0005435305004	29775	25	20B
0005435304131	29775	26	20C
0005434343603	29775	27	21A
0005434343641	29775	28	21B
0005435305002	29775	29	21C
0005435305001	29775	30	22B
0005434343650	29775	31	22C
0005434343640	29775	32	23A
0005435824443	1290	1	1C
0005432284537	1290	2	1F
0005433415465	1290	3	1D
0005435824426	1290	4	3C
0005435824452	1290	5	3A
0005435824432	1290	6	3D
0005435824447	1290	7	4D
0005435824433	1290	8	5C
0005435824441	1290	9	5F
0005435824442	1290	10	7F
0005435824431	1290	11	8B
0005435824439	1290	12	8C
0005435824434	1290	13	8F
0005435824445	1290	14	9C
0005435824427	1290	15	9F
0005432284538	1290	16	9E
0005435824449	1290	17	10E
0005435824436	1290	18	11A
0005435824428	1290	19	10F
0005435824430	1290	20	11C
0005435824446	1290	21	11E
0005433415414	1290	22	12B
0005435824440	1290	23	12A
0005435824438	1290	24	13A
0005433415394	1290	25	12F
0005435824444	1290	26	13C
0005433415416	1290	27	14A
0005433415417	1290	28	14E
0005432284536	1290	29	14C
0005435824450	1290	30	15C
0005433415398	1290	31	16E
0005435824435	1290	32	17D
0005435824448	1290	33	18A
0005435824451	1290	34	18B
0005433415441	1290	35	19C
0005433415415	1290	36	20E
0005435824437	1290	37	21A
0005435824429	1290	38	20F
0005433415557	17983	1	1C
0005433415551	17983	2	1D
0005433415543	17983	3	1F
0005435824313	17983	4	3D
0005435824228	17983	5	4A
0005435824314	17983	6	4F
0005435824182	17983	7	7A
0005433415548	17983	8	6F
0005435824316	17983	9	7C
0005435824297	17983	10	7B
0005435824172	17983	11	7E
0005435824315	17983	12	8A
0005435824272	17983	13	8C
0005435824227	17983	14	8B
0005433415552	17983	15	8D
0005435824237	17983	16	9D
0005433415541	17983	17	10A
0005435824229	17983	18	9F
0005435824197	17983	19	10B
0005435824174	17983	20	11A
0005433415544	17983	21	11C
0005433415547	17983	22	11E
0005433415542	17983	23	12B
0005433415549	17983	24	12E
0005435824151	17983	25	14D
0005435824362	17983	26	14C
0005433415550	17983	27	15A
0005433415556	17983	28	15E
0005433415554	17983	29	16A
0005435824256	17983	30	16B
0005435824165	17983	31	16D
0005433415553	17983	32	17A
0005435824214	17983	33	17D
0005433415545	17983	34	19A
0005435824253	17983	35	19B
0005433415546	17983	36	20B
0005435824226	17983	37	20D
0005435824255	17983	38	20C
0005433415555	17983	39	20E
0005435824173	17983	40	21C
0005435824300	17983	41	21B
0005435824290	17983	42	21E
0005434460466	17532	1	1C
0005434460473	17532	2	2A
0005434460468	17532	3	3A
0005434462752	17532	4	20C
0005434462757	17532	5	20D
0005434460476	17532	6	21D
0005435242428	5620	1	1A
0005435476634	5620	2	1C
0005435242412	5620	3	1F
0005432783409	5620	4	2D
0005432143964	5620	5	2F
0005432783401	5620	6	3A
0005432783440	5620	7	3D
0005432783405	5620	8	4A
0005432783432	5620	9	4C
0005435242481	5620	10	4D
0005432783434	5620	11	4F
0005432783392	5620	12	5C
0005432783397	5620	13	5D
0005432143963	5620	14	5E
0005435242403	5620	15	5F
0005432783428	5620	16	6A
0005432783437	5620	17	6C
0005432783398	5620	18	6D
0005432783435	5620	19	6E
0005432783418	5620	20	6F
0005435242512	5620	21	7A
0005432783415	5620	22	7C
0005432783417	5620	23	7D
0005432783426	5620	24	7F
0005432783431	5620	25	8A
0005432783425	5620	26	8C
0005435242390	5620	27	8D
0005432783441	5620	28	8F
0005432783410	5620	29	9A
0005432783436	5620	30	9C
0005432783391	5620	31	9D
0005432783413	5620	32	9E
0005432783394	5620	33	9F
0005435242553	5620	34	10A
0005432783412	5620	35	10C
0005432783416	5620	36	10D
0005432783396	5620	37	10E
0005432783399	5620	38	10F
0005432783400	5620	39	11A
0005432783442	5620	40	11C
0005432783395	5620	41	11D
0005432783422	5620	42	11E
0005432783423	5620	43	12D
0005432783429	5620	44	12E
0005435242418	5620	45	12F
0005432143965	5620	46	13A
0005435476647	5620	47	13C
0005435242457	5620	48	13D
0005432783402	5620	49	13F
0005435476659	5620	50	14C
0005432783411	5620	51	14D
0005432783427	5620	52	14E
0005435242389	5620	53	15A
0005432783439	5620	54	15C
0005435242480	5620	55	15E
0005432783424	5620	56	16A
0005432783430	5620	57	16C
0005432783433	5620	58	16D
0005432783403	5620	59	16F
0005432783438	5620	60	17A
0005432783421	5620	61	17C
0005432783407	5620	62	17D
0005432783420	5620	63	17E
0005435476655	5620	64	17F
0005435242448	5620	65	18A
0005435476654	5620	66	18C
0005432783404	5620	67	18D
0005432783393	5620	68	18E
0005432783408	5620	69	19A
0005432783443	5620	70	19C
0005432783414	5620	71	19E
0005435242456	5620	72	19F
0005435242552	5620	73	20C
0005432783419	5620	74	20D
0005432783406	5620	75	20F
0005432783089	15391	1	1A
0005432782909	15391	2	1D
0005435242642	15391	3	1F
0005432782867	15391	4	2A
0005435242637	15391	5	2D
0005435242638	15391	6	2F
0005435242657	15391	7	3C
0005435476715	15391	8	3D
0005432782876	15391	9	4C
0005432782866	15391	10	4D
0005432782853	15391	11	4E
0005432783042	15391	12	4F
0005435242646	15391	13	5A
0005432782936	15391	14	5C
0005435476711	15391	15	5D
0005432782846	15391	16	5E
0005435242643	15391	17	5F
0005432782894	15391	18	6A
0005435242639	15391	19	6D
0005432782983	15391	20	6F
0005432782943	15391	21	7A
0005432782987	15391	22	7D
0005435476712	15391	23	7E
0005432782856	15391	24	7F
0005432782855	15391	25	8A
0005435242649	15391	26	8D
0005435242661	15391	27	8E
0005432782988	15391	28	8F
0005432782841	15391	29	9A
0005432783193	15391	30	9D
0005432782875	15391	31	9E
0005435242641	15391	32	10C
0005435242640	15391	33	10D
0005435242655	15391	34	11A
0005435242660	15391	35	11C
0005435242654	15391	36	11D
0005432782961	15391	37	11E
0005432783057	15391	38	11F
0005435242647	15391	39	12A
0005432782956	15391	40	12C
0005432782854	15391	41	12D
0005432782923	15391	42	12F
0005435242644	15391	43	13A
0005432782922	15391	44	13F
0005432782939	15391	45	14A
0005435242662	15391	46	14C
0005435476710	15391	47	14E
0005435476709	15391	48	15A
0005432782993	15391	49	15C
0005435242650	15391	50	15D
0005435242653	15391	51	15E
0005432782895	15391	52	16A
0005435242651	15391	53	16C
0005435242663	15391	54	16E
0005435242648	15391	55	16F
0005432783112	15391	56	17C
0005432782960	15391	57	17D
0005435242656	15391	58	17E
0005435476714	15391	59	17F
0005432782944	15391	60	18A
0005435476716	15391	61	18C
0005435476713	15391	62	18D
0005432783192	15391	63	18E
0005435242652	15391	64	18F
0005432782924	15391	65	19E
0005435242658	15391	66	20C
0005435242659	15391	67	20D
0005435242645	15391	68	20E
0005435850764	4346	1	1A
0005432848216	4346	2	1C
0005432848205	4346	3	1D
0005432848204	4346	4	2B
0005435850784	4346	5	2C
0005435850816	4346	6	3A
0005435850758	4346	7	4A
0005432848208	4346	8	4C
0005435850812	4346	9	4D
0005435850793	4346	10	5B
0005434463914	4346	11	6C
0005432848210	4346	12	7D
0005435850762	4346	13	19A
0005432848207	4346	14	19B
0005434462775	4346	15	19C
0005432848211	4346	16	19D
0005432848217	4346	17	20A
0005432848213	4346	18	20B
0005432848209	4346	19	20C
0005432848215	4346	20	20D
0005432848212	4346	21	21A
0005432848214	4346	22	22A
0005432848206	4346	23	22B
0005435850763	4346	24	22C
0005434462774	4346	25	22D
0005432848090	28873	1	1A
0005434461616	28873	2	1D
0005435850845	28873	3	2A
0005434461617	28873	4	2C
0005432848070	28873	5	2D
0005435850850	28873	6	3B
0005432848083	28873	7	3D
0005432848125	28873	8	4A
0005435850849	28873	9	4B
0005432848082	28873	10	4C
0005432848072	28873	11	5A
0005432848061	28873	12	5B
0005432848080	28873	13	5D
0005432848081	28873	14	6A
0005435850843	28873	15	6C
0005432848085	28873	16	6D
0005435850844	28873	17	7A
0005432848084	28873	18	7D
0005435850846	28873	19	18A
0005432848069	28873	20	18B
0005432848086	28873	21	18C
0005432848089	28873	22	19B
0005432848101	28873	23	20A
0005435850847	28873	24	20C
0005435850842	28873	25	20B
0005432848066	28873	26	21A
0005432848062	28873	27	21D
0005432848071	28873	28	22C
0005435850848	28873	29	23A
0005433496752	6273	1	1A
0005433496761	6273	2	1C
0005434443599	6273	3	1D
0005434925573	6273	4	1F
0005434443597	6273	5	2A
0005433496767	6273	6	2C
0005434925581	6273	7	2F
0005434925597	6273	8	3A
0005434925603	6273	9	3C
0005434925594	6273	10	3D
0005433496741	6273	11	4A
0005433496763	6273	12	4C
0005434925572	6273	13	4D
0005434925580	6273	14	4E
0005434925595	6273	15	4F
0005434443594	6273	16	5A
0005434925601	6273	17	5C
0005434925599	6273	18	5D
0005433496768	6273	19	5E
0005434925584	6273	20	5F
0005434443598	6273	21	6A
0005434925579	6273	22	6D
0005434925576	6273	23	6E
0005433496738	6273	24	6F
0005434925575	6273	25	7A
0005433496746	6273	26	7C
0005434925606	6273	27	7D
0005432075206	6273	28	7E
0005434925583	6273	29	7F
0005433496742	6273	30	8A
0005434925582	6273	31	8C
0005434925602	6273	32	8D
0005434925588	6273	33	8E
0005434925578	6273	34	8F
0005434443602	6273	35	9A
0005432075205	6273	36	9C
0005433496771	6273	37	9D
0005434925585	6273	38	9E
0005433496739	6273	39	9F
0005434443595	6273	40	10C
0005434443591	6273	41	10D
0005433496769	6273	42	10E
0005434443593	6273	43	10F
0005434925604	6273	44	11C
0005433496744	6273	45	11D
0005434443603	6273	46	11E
0005434443604	6273	47	11F
0005432075208	6273	48	12A
0005434443601	6273	49	12C
0005434443592	6273	50	12D
0005433496757	6273	51	12E
0005433496750	6273	52	12F
0005433496755	6273	53	13A
0005434925605	6273	54	13C
0005434925591	6273	55	13D
0005433496760	6273	56	13E
0005434925592	6273	57	13F
0005433496766	6273	58	14A
0005433496770	6273	59	14C
0005433496759	6273	60	14D
0005434925593	6273	61	14E
0005433496740	6273	62	14F
0005433496743	6273	63	15A
0005434925587	6273	64	15C
0005434443600	6273	65	15D
0005434443590	6273	66	15F
0005433496756	6273	67	16C
0005434925574	6273	68	16D
0005432075207	6273	69	16E
0005434925586	6273	70	16F
0005433496749	6273	71	17A
0005433496747	6273	72	17C
0005433496764	6273	73	17D
0005433496762	6273	74	17E
0005434925600	6273	75	17F
0005433496751	6273	76	18A
0005432075204	6273	77	18C
0005433496753	6273	78	18D
0005433496765	6273	79	18E
0005434925577	6273	80	18F
0005434925598	6273	81	19A
0005433496748	6273	82	19C
0005434925596	6273	83	19D
0005434443596	6273	84	19E
0005433496745	6273	85	19F
0005433496754	6273	86	20A
0005433496758	6273	87	20C
0005434925590	6273	88	20E
0005434925589	6273	89	20F
0005433496438	20422	1	1C
0005434443458	20422	2	1D
0005433496636	20422	3	1F
0005434925267	20422	4	3A
0005434925309	20422	5	3C
0005434925315	20422	6	3F
0005433496587	20422	7	4A
0005433496420	20422	8	4E
0005433496532	20422	9	5C
0005434925257	20422	10	5D
0005433496529	20422	11	6A
0005433496539	20422	12	6D
0005433496544	20422	13	6E
0005434443424	20422	14	6F
0005433496543	20422	15	7C
0005434925329	20422	16	7E
0005434925268	20422	17	7F
0005433496531	20422	18	8A
0005433496482	20422	19	8C
0005434925308	20422	20	8D
0005433496556	20422	21	9C
0005433496533	20422	22	10A
0005434925284	20422	23	10C
0005434925269	20422	24	10D
0005434443435	20422	25	10F
0005433496572	20422	26	11A
0005434925307	20422	27	11C
0005433496496	20422	28	11D
0005433496481	20422	29	12A
0005433496555	20422	30	12C
0005434443495	20422	31	12D
0005434443451	20422	32	13A
0005434925336	20422	33	13C
0005433496437	20422	34	13D
0005433496637	20422	35	13F
0005433496454	20422	36	14A
0005434443440	20422	37	14C
0005434443450	20422	38	14D
0005433496536	20422	39	14F
0005434443444	20422	40	15C
0005434925335	20422	41	15F
0005433496638	20422	42	16C
0005433496535	20422	43	16D
0005433496429	20422	44	16E
0005433496514	20422	45	16F
0005433496586	20422	46	17A
0005433496538	20422	47	17C
0005434925317	20422	48	17D
0005433496439	20422	49	18A
0005433496517	20422	50	18D
0005433496518	20422	51	18E
0005434925313	20422	52	18F
0005433496469	20422	53	19F
0005433496480	20422	54	20C
0005433496468	20422	55	20D
0005434925324	20422	56	20E
0005435242676	12172	1	1A
0005432783102	12172	2	1C
0005432782872	12172	3	1D
0005432783070	12172	4	1F
0005432783019	12172	5	2C
0005432783072	12172	6	3D
0005432783006	12172	7	4D
0005435242689	12172	8	5A
0005435242678	12172	9	5C
0005435242679	12172	10	5E
0005432783103	12172	11	5F
0005432783054	12172	12	6A
0005432782984	12172	13	6C
0005432783002	12172	14	6D
0005435242669	12172	15	6E
0005432782953	12172	16	6F
0005432782921	12172	17	7A
0005435242665	12172	18	7E
0005432783110	12172	19	7F
0005435242677	12172	20	8A
0005435242685	12172	21	8C
0005432782887	12172	22	8E
0005435242684	12172	23	8F
0005432783143	12172	24	9A
0005432783039	12172	25	9C
0005435242668	12172	26	9D
0005435242674	12172	27	9E
0005435242687	12172	28	9F
0005432783079	12172	29	10A
0005435242671	12172	30	10C
0005432782952	12172	31	10F
0005432783031	12172	32	11A
0005432783246	12172	33	11C
0005432782884	12172	34	11D
0005432783245	12172	35	11E
0005432783053	12172	36	12A
0005432783005	12172	37	12C
0005432783174	12172	38	12D
0005435242686	12172	39	13C
0005432783001	12172	40	13F
0005435242675	12172	41	14C
0005435242681	12172	42	14D
0005432783040	12172	43	14E
0005435242690	12172	44	15A
0005432783107	12172	45	15C
0005435242691	12172	46	15D
0005435242680	12172	47	15E
0005435242688	12172	48	15F
0005435242667	12172	49	16A
0005432782891	12172	50	16C
0005435242672	12172	51	16D
0005432782907	12172	52	16E
0005435242683	12172	53	17A
0005435242666	12172	54	17C
0005432782893	12172	55	17D
0005432782860	12172	56	17E
0005432782892	12172	57	18C
0005435242673	12172	58	18D
0005432783026	12172	59	18E
0005432783080	12172	60	18F
0005435242670	12172	61	19D
0005432783160	12172	62	20C
0005435242682	12172	63	20D
0005432782995	12172	64	20E
0005435242664	12172	65	20F
0005435242397	15412	1	1C
0005432783382	15412	2	1D
0005432783363	15412	3	1F
0005432783346	15412	4	2A
0005432783384	15412	5	2C
0005432783364	15412	6	2D
0005432783356	15412	7	2F
0005432783378	15412	8	3C
0005432783347	15412	9	3D
0005432783359	15412	10	3F
0005432783389	15412	11	4A
0005432783375	15412	12	4D
0005432783352	15412	13	4F
0005432783385	15412	14	5A
0005432783350	15412	15	5D
0005432783374	15412	16	5E
0005432783341	15412	17	5F
0005432783362	15412	18	6C
0005432783344	15412	19	6D
0005435242513	15412	20	6E
0005432783383	15412	21	6F
0005432783358	15412	22	7D
0005432783339	15412	23	7E
0005432783386	15412	24	7F
0005435242432	15412	25	8A
0005435242429	15412	26	8C
0005432783372	15412	27	8D
0005432783370	15412	28	9E
0005435242396	15412	29	10A
0005432783338	15412	30	10C
0005432783357	15412	31	10D
0005432783366	15412	32	10E
0005432783369	15412	33	10F
0005435242475	15412	34	11A
0005435242405	15412	35	11E
0005432783379	15412	36	11F
0005435242430	15412	37	12C
0005435242437	15412	38	12E
0005432783349	15412	39	12F
0005432783373	15412	40	13A
0005432783381	15412	41	13C
0005432783365	15412	42	13D
0005435242431	15412	43	13E
0005435242452	15412	44	13F
0005432783355	15412	45	14A
0005432783361	15412	46	14C
0005432783351	15412	47	14F
0005432783340	15412	48	15A
0005432783343	15412	49	15D
0005432783380	15412	50	15E
0005432783387	15412	51	15F
0005432783342	15412	52	16A
0005432783348	15412	53	16C
0005432783388	15412	54	16D
0005432783336	15412	55	17A
0005432783337	15412	56	17C
0005435242402	15412	57	17D
0005432783335	15412	58	17E
0005435242453	15412	59	17F
0005435242450	15412	60	18A
0005432783360	15412	61	18D
0005432783354	15412	62	18E
0005432783345	15412	63	18F
0005432783368	15412	64	19A
0005432783371	15412	65	19C
0005435242446	15412	66	19D
0005435242476	15412	67	19E
0005432783377	15412	68	19F
0005432783376	15412	69	20A
0005432783353	15412	70	20C
0005432783367	15412	71	20D
0005432783390	15412	72	20E
0005435242398	15412	73	20F
0005434876601	10078	1	1A
0005434876922	10078	2	1D
0005434876837	10078	3	2A
0005434876748	10078	4	2D
0005434877005	10078	5	2C
0005434876888	10078	6	3A
0005434877114	10078	7	2F
0005434876929	10078	8	3C
0005434876915	10078	9	4F
0005434876587	10078	10	4D
0005434876683	10078	11	5C
0005434876565	10078	12	5A
0005434876623	10078	13	5F
0005434877031	10078	14	6B
0005434876805	10078	15	6A
0005434910093	10078	16	6C
0005434877077	10078	17	6F
0005434877115	10078	18	6E
0005434876577	10078	19	6D
0005434877072	10078	20	7B
0005435913910	10078	21	7A
0005434877004	10078	22	7E
0005434876707	10078	23	7D
0005434877127	10078	24	8A
0005434876710	10078	25	8E
0005434876949	10078	26	8D
0005434876706	10078	27	8F
0005434876872	10078	28	9A
0005434876711	10078	29	9D
0005434876943	10078	30	9F
0005434877078	10078	31	9E
0005434876797	10078	32	10A
0005434876942	10078	33	10C
0005434876776	10078	34	10D
0005435913909	10078	35	10F
0005434877065	10078	36	11A
0005434910094	10078	37	11C
0005434876634	10078	38	11F
0005434876687	10078	39	11E
0005434876597	10078	40	12D
0005434876599	10078	41	12E
0005434876618	10078	42	12F
0005434876651	10078	43	13B
0005434876838	10078	44	13F
0005434876995	10078	45	14B
0005434876702	10078	46	14A
0005434876747	10078	47	14D
0005434876721	10078	48	14F
0005434877148	10078	49	14E
0005434877146	10078	50	15A
0005434876975	10078	51	15C
0005434876719	10078	52	15F
0005434876887	10078	53	15E
0005434877147	10078	54	16C
0005434876689	10078	55	16B
0005434876559	10078	56	16F
0005434877323	10078	57	17B
0005434876897	10078	58	17A
0005434876596	10078	59	17C
0005434877046	10078	60	17F
0005434877066	10078	61	17E
0005434876840	10078	62	18A
0005434876720	10078	63	19A
0005434876854	10078	64	19C
0005434876653	10078	65	19E
0005434877087	10078	66	20A
0005434876600	10078	67	19F
0005434910092	10078	68	20B
0005434876873	10078	69	20D
0005434876853	10078	70	20C
0005434876566	10078	71	20F
0005434876781	10078	72	20E
0005434876910	10078	73	21C
0005435913911	10078	74	21E
0005434876920	10078	75	21F
0005434877524	14597	1	1C
0005434877576	14597	2	1A
0005434877614	14597	3	1F
0005434877585	14597	4	1D
0005434877577	14597	5	2A
0005434877554	14597	6	2F
0005434877562	14597	7	2D
0005434877530	14597	8	2C
0005434877536	14597	9	3A
0005434877574	14597	10	3C
0005434877533	14597	11	4A
0005434877605	14597	12	3F
0005434877602	14597	13	4C
0005434877615	14597	14	4F
0005434877609	14597	15	4D
0005434877600	14597	16	5C
0005434877569	14597	17	5A
0005434877538	14597	18	5D
0005434910073	14597	19	6A
0005434877527	14597	20	6D
0005434877597	14597	21	6C
0005434877618	14597	22	6B
0005434877620	14597	23	6F
0005434877587	14597	24	6E
0005434877584	14597	25	7B
0005434877537	14597	26	7A
0005434877542	14597	27	7C
0005434877568	14597	28	7E
0005434877583	14597	29	7D
0005434877573	14597	30	8A
0005434877588	14597	31	8B
0005434877608	14597	32	8D
0005434877599	14597	33	8C
0005434877558	14597	34	8F
0005434877525	14597	35	8E
0005434877534	14597	36	9A
0005434877563	14597	37	9D
0005434877593	14597	38	9C
0005434877564	14597	39	9B
0005434877559	14597	40	9E
0005434877592	14597	41	10B
0005434877601	14597	42	10A
0005434877549	14597	43	9F
0005434877619	14597	44	10D
0005434877546	14597	45	10F
0005434877578	14597	46	10E
0005434877603	14597	47	11B
0005434877551	14597	48	11A
0005434877616	14597	49	11D
0005434877586	14597	50	11F
0005434758877	14597	51	11E
0005434877613	14597	52	12A
0005434877531	14597	53	12D
0005434877548	14597	54	12C
0005434877570	14597	55	12E
0005434877539	14597	56	13B
0005434877566	14597	57	13A
0005434877543	14597	58	12F
0005434877545	14597	59	13E
0005434877580	14597	60	13D
0005434877560	14597	61	14A
0005434877572	14597	62	13F
0005434877590	14597	63	14B
0005434877552	14597	64	14D
0005434877612	14597	65	14C
0005434877579	14597	66	14F
0005434877571	14597	67	14E
0005434877607	14597	68	15B
0005434877610	14597	69	15A
0005434877581	14597	70	15E
0005434877595	14597	71	16A
0005434877529	14597	72	15F
0005434877565	14597	73	16C
0005434877526	14597	74	16B
0005434877591	14597	75	16E
0005434877556	14597	76	16D
0005434877582	14597	77	17A
0005434877555	14597	78	16F
0005434877553	14597	79	17C
0005434910078	14597	80	17B
0005434877540	14597	81	17D
0005434877561	14597	82	17E
0005434877604	14597	83	18A
0005434877594	14597	84	17F
0005434877567	14597	85	18C
0005434877547	14597	86	18B
0005434877557	14597	87	18E
0005434877611	14597	88	19A
0005434877575	14597	89	18F
0005434877532	14597	90	19B
0005434877598	14597	91	19E
0005434877528	14597	92	19D
0005434877596	14597	93	19F
0005434877544	14597	94	20B
0005434877617	14597	95	20D
0005434877606	14597	96	20C
0005434877523	14597	97	20F
0005434877550	14597	98	20E
0005434877535	14597	99	21D
0005434910077	14597	100	21C
0005434877541	14597	101	21E
0005434877589	14597	102	21F
0005434251806	9255	1	1C
0005435660055	9255	2	1D
0005435660061	9255	3	2B
0005434251807	9255	4	3A
0005435660058	9255	5	3B
0005435660062	9255	6	4D
0005435660057	9255	7	5A
0005435660056	9255	8	6D
0005435660060	9255	9	7C
0005434251845	9255	10	7D
0005435660052	9255	11	18A
0005434251805	9255	12	18C
0005435660054	9255	13	19B
0005434251795	9255	14	19C
0005434251798	9255	15	20C
0005434251824	9255	16	20D
0005435660059	9255	17	21A
0005434251796	9255	18	22B
0005434251814	9255	19	22C
0005435660053	9255	20	23B
0005434251893	24636	1	1D
0005434251894	24636	2	2A
0005434251898	24636	3	2D
0005435659973	24636	4	3C
0005434251901	24636	5	5C
0005435659954	24636	6	5D
0005435659959	24636	7	7A
0005434251897	24636	8	7B
0005435660000	24636	9	7C
0005434251895	24636	10	18A
0005435659950	24636	11	18B
0005435659942	24636	12	18D
0005435659943	24636	13	19B
0005434251896	24636	14	21D
0005434251899	24636	15	22B
0005434251900	24636	16	23A
0005435659982	24636	17	23B
0005432966584	2814	1	1A
0005433680237	2814	2	1C
0005433680235	2814	3	1D
0005432966506	2814	4	2A
0005433680220	2814	5	2C
0005433684404	2814	6	2F
0005433680224	2814	7	3A
0005433680197	2814	8	3C
0005433680238	2814	9	3D
0005433680228	2814	10	3F
0005433680208	2814	11	4C
0005433680233	2814	12	4D
0005432966483	2814	13	4E
0005432966595	2814	14	4F
0005433680229	2814	15	5A
0005433680226	2814	16	5D
0005433680239	2814	17	5E
0005433680231	2814	18	5F
0005432966614	2814	19	6A
0005432966583	2814	20	6C
0005433680230	2814	21	6E
0005433680245	2814	22	6F
0005432222743	2814	23	7A
0005432966552	2814	24	7D
0005432966495	2814	25	7E
0005433680218	2814	26	7F
0005433680234	2814	27	8A
0005432966548	2814	28	8C
0005433680241	2814	29	8D
0005433684403	2814	30	8E
0005432966497	2814	31	8F
0005433680240	2814	32	9A
0005433680216	2814	33	9D
0005432222744	2814	34	9E
0005433680206	2814	35	9F
0005433680214	2814	36	10A
0005433680212	2814	37	10C
0005432966575	2814	38	10D
0005433680223	2814	39	10E
0005432966510	2814	40	10F
0005432966511	2814	41	11C
0005433680221	2814	42	11D
0005432966496	2814	43	11E
0005432966490	2814	44	11F
0005432966498	2814	45	12A
0005432966492	2814	46	12C
0005432966618	2814	47	12D
0005433684405	2814	48	12F
0005433680242	2814	49	13C
0005433680217	2814	50	13D
0005433680201	2814	51	13E
0005433680202	2814	52	13F
0005433680244	2814	53	14A
0005433680211	2814	54	14C
0005433680213	2814	55	14D
0005432966612	2814	56	14E
0005433680227	2814	57	14F
0005433680215	2814	58	15A
0005432966547	2814	59	15C
0005433680225	2814	60	15D
0005433680210	2814	61	15F
0005432966493	2814	62	16A
0005432222746	2814	63	16C
0005432966512	2814	64	16D
0005433680204	2814	65	16E
0005433680203	2814	66	16F
0005433680209	2814	67	17C
0005433680219	2814	68	17D
0005433680200	2814	69	17E
0005433680246	2814	70	17F
0005432966482	2814	71	18A
0005433680243	2814	72	18C
0005433680236	2814	73	18D
0005432222745	2814	74	18E
0005433680205	2814	75	18F
0005432966513	2814	76	19A
0005432966604	2814	77	19C
0005432966557	2814	78	19E
0005433680232	2814	79	19F
0005432222742	2814	80	20A
0005433680207	2814	81	20C
0005433680222	2814	82	20D
0005433680199	2814	83	20E
0005433680198	2814	84	20F
0005433679798	29169	1	1D
0005432966767	29169	2	1F
0005433679834	29169	3	2A
0005432966755	29169	4	2C
0005432966761	29169	5	2D
0005433679908	29169	6	2F
0005433680003	29169	7	3A
0005432966744	29169	8	3D
0005433679929	29169	9	3F
0005432005193	29169	10	4F
0005433679810	29169	11	5A
0005432966747	29169	12	5C
0005433680036	29169	13	5D
0005433680034	29169	14	5E
0005433680035	29169	15	5F
0005433679840	29169	16	6C
0005432966756	29169	17	6D
0005432966762	29169	18	6E
0005433679878	29169	19	6F
0005433679823	29169	20	7A
0005432966741	29169	21	7C
0005433679930	29169	22	7E
0005433679724	29169	23	7F
0005432966752	29169	24	8D
0005432966753	29169	25	8E
0005433679901	29169	26	8F
0005433679918	29169	27	9A
0005433679839	29169	28	9C
0005433679858	29169	29	9E
0005433679733	29169	30	9D
0005433679812	29169	31	9F
0005432966745	29169	32	10C
0005433679820	29169	33	10D
0005432966746	29169	34	10E
0005432966749	29169	35	10F
0005433679856	29169	36	11C
0005432966764	29169	37	11D
0005433679795	29169	38	11F
0005432966751	29169	39	12A
0005433679731	29169	40	12C
0005433680026	29169	41	12D
0005433679809	29169	42	12F
0005432966765	29169	43	13C
0005433679761	29169	44	13D
0005433679966	29169	45	13E
0005432966759	29169	46	13F
0005432966742	29169	47	14A
0005432966743	29169	48	14D
0005433679730	29169	49	14F
0005433679965	29169	50	15A
0005433687683	29169	51	15C
0005433679903	29169	52	15D
0005432966754	29169	53	15E
0005433679829	29169	54	16A
0005433679737	29169	55	16C
0005433680033	29169	56	16D
0005432966748	29169	57	16E
0005432966763	29169	58	16F
0005433679904	29169	59	17A
0005433679848	29169	60	17C
0005433679818	29169	61	17D
0005433679732	29169	62	17E
0005433679849	29169	63	17F
0005433679855	29169	64	18A
0005432966766	29169	65	18C
0005432966757	29169	66	18D
0005433679902	29169	67	18E
0005433679819	29169	68	18F
0005432005194	29169	69	19C
0005432966750	29169	70	19D
0005432966760	29169	71	19E
0005433679897	29169	72	19F
0005432966758	29169	73	20A
0005433679776	29169	74	20C
0005433679933	29169	75	20E
0005433633532	9324	1	1A
0005433614134	9324	2	1C
0005434272162	9324	3	1D
0005433614091	9324	4	2A
0005433614060	9324	5	1F
0005433633549	9324	6	2C
0005433614122	9324	7	2D
0005433633558	9324	8	2F
0005432755050	9324	9	3C
0005433633537	9324	10	3F
0005433577706	9324	11	3D
0005433614108	9324	12	4C
0005433614124	9324	13	4D
0005433633529	9324	14	5A
0005433614064	9324	15	4F
0005433614088	9324	16	5C
0005433614095	9324	17	5D
0005433633548	9324	18	6A
0005433614079	9324	19	5F
0005433577710	9324	20	6F
0005433633553	9324	21	6D
0005434272163	9324	22	7F
0005433614119	9324	23	7D
0005433614129	9324	24	8A
0005433614099	9324	25	8B
0005433614085	9324	26	8C
0005433614067	9324	27	8E
0005433633531	9324	28	8D
0005433614111	9324	29	8F
0005433633536	9324	30	9B
0005433614069	9324	31	9A
0005433633552	9324	32	9C
0005433633541	9324	33	9D
0005433614070	9324	34	9E
0005433633550	9324	35	10A
0005433614078	9324	36	9F
0005433614074	9324	37	10B
0005433614126	9324	38	10D
0005433614123	9324	39	10C
0005433614112	9324	40	10E
0005434163484	9324	41	10F
0005433577700	9324	42	11A
0005433633561	9324	43	11C
0005433577707	9324	44	11F
0005433614107	9324	45	11E
0005434163471	9324	46	12A
0005434153517	9324	47	12B
0005433614068	9324	48	12D
0005432755049	9324	49	12C
0005432756823	9324	50	12E
0005433614077	9324	51	12F
0005433614117	9324	52	13A
0005433633556	9324	53	13B
0005434163521	9324	54	13D
0005433614098	9324	55	13C
0005432756821	9324	56	13F
0005433614118	9324	57	13E
0005434269072	9324	58	14A
0005433614061	9324	59	14C
0005433614116	9324	60	14B
0005433633559	9324	61	14E
0005433633543	9324	62	14D
0005433614073	9324	63	14F
0005433614103	9324	64	15B
0005433633533	9324	65	15A
0005433577705	9324	66	15C
0005433614109	9324	67	15E
0005433614104	9324	68	15D
0005433633530	9324	69	15F
0005433614092	9324	70	16B
0005433633542	9324	71	16D
0005433614132	9324	72	16F
0005433614084	9324	73	17B
0005433633528	9324	74	17A
0005433633545	9324	75	17C
0005433614087	9324	76	17D
0005433614083	9324	77	17E
0005433614096	9324	78	17F
0005434163489	9324	79	18C
0005433614120	9324	80	18B
0005433633540	9324	81	18D
0005433633555	9324	82	18E
0005433614063	9324	83	19B
0005433614133	9324	84	18F
0005433614072	9324	85	19D
0005433633546	9324	86	19C
0005433614127	9324	87	19E
0005433577708	9324	88	20B
0005433614093	9324	89	20A
0005434163464	9324	90	20C
0005433614128	9324	91	20E
0005433633527	9324	92	20D
0005433614081	9324	93	20F
0005433614066	9324	94	21A
0005433614100	9324	95	21B
0005433633547	9324	96	21C
0005433633544	9324	97	21E
0005433633534	9324	98	22A
0005433614075	9324	99	21F
0005433614076	9324	100	22B
0005433577704	9324	101	22C
0005433614121	9324	102	22D
0005433633554	9324	103	22F
0005434163486	9324	104	22E
0005433614082	9324	105	23B
0005433614125	9324	106	23C
0005433633551	9324	107	23D
0005434163520	9324	108	23E
0005434163488	9324	109	24A
0005433614086	9324	110	23F
0005433577712	9324	111	24B
0005434163477	9324	112	24E
0005433614106	9324	113	24D
0005433577701	9324	114	25A
0005433577699	9324	115	25C
0005434163476	9324	116	25B
0005433633535	9324	117	25D
0005433614105	9324	118	25E
0005433614113	9324	119	26A
0005433577709	9324	120	25F
0005432756822	9324	121	26C
0005432145094	9324	122	26E
0005433577703	9324	123	26D
0005434269073	9324	124	27A
0005433614110	9324	125	27B
0005432755051	9324	126	27C
0005433614090	9324	127	27E
0005433614131	9324	128	27D
0005433614114	9324	129	28A
0005433633560	9324	130	27F
0005434272164	9324	131	28C
0005433614102	9324	132	28B
0005433577702	9324	133	28E
0005433614130	9324	134	28F
0005433633557	9324	135	29B
0005432756824	9324	136	29A
0005433614065	9324	137	29C
0005433614094	9324	138	29D
0005433614071	9324	139	29F
0005433614101	9324	140	29E
0005434163487	9324	141	30A
0005433614115	9324	142	30B
0005433577711	9324	143	30C
0005433633539	9324	144	30E
0005433633538	9324	145	30D
0005433614089	9324	146	30F
0005432145095	9324	147	31A
0005433614097	9324	148	31C
0005433614062	9324	149	31E
0005434153515	9324	150	31D
0005433614080	9324	151	31F
0005433577592	25251	1	1D
0005434273064	25251	2	1C
0005433633225	25251	3	2D
0005433577633	25251	4	2C
0005432755015	25251	5	2F
0005433613642	25251	6	3A
0005433613420	25251	7	3F
0005433633256	25251	8	4A
0005433613657	25251	9	4C
0005433633236	25251	10	4F
0005433613533	25251	11	4D
0005432751469	25251	12	5C
0005434163558	25251	13	5F
0005433613723	25251	14	5D
0005433633234	25251	15	6A
0005433613532	25251	16	6C
0005433577597	25251	17	6D
0005433633435	25251	18	7C
0005433577593	25251	19	7F
0005433613586	25251	20	8B
0005433613593	25251	21	8C
0005433633276	25251	22	8E
0005433613712	25251	23	8D
0005433613724	25251	24	8F
0005433613428	25251	25	9B
0005433613408	25251	26	9C
0005433613462	25251	27	9D
0005433613768	25251	28	9F
0005434163556	25251	29	10A
0005433613391	25251	30	10B
0005433613615	25251	31	10D
0005434272179	25251	32	10E
0005433577591	25251	33	11A
0005434163550	25251	34	11C
0005433613461	25251	35	11D
0005433613766	25251	36	11E
0005433613435	25251	37	12A
0005434163552	25251	38	12B
0005433613602	25251	39	12E
0005433613440	25251	40	12D
0005433633240	25251	41	12F
0005433613670	25251	42	13B
0005433613767	25251	43	13A
0005433613603	25251	44	13C
0005433613538	25251	45	13E
0005433613409	25251	46	14A
0005433613711	25251	47	14E
0005433613416	25251	48	14F
0005432755022	25251	49	15B
0005433613496	25251	50	15F
0005434152774	25251	51	16A
0005434152777	25251	52	16C
0005433613672	25251	53	16B
0005433633221	25251	54	16D
0005433613594	25251	55	16E
0005434163554	25251	56	17A
0005432751468	25251	57	16F
0005433613558	25251	58	17C
0005433613823	25251	59	17E
0005433613516	25251	60	17D
0005434163555	25251	61	18A
0005433633244	25251	62	18B
0005433633317	25251	63	18D
0005433613417	25251	64	18E
0005433613491	25251	65	18F
0005434152778	25251	66	19C
0005433633273	25251	67	19B
0005432755021	25251	68	20A
0005433577567	25251	69	20D
0005433613419	25251	70	20F
0005433613824	25251	71	21A
0005434163553	25251	72	21C
0005433633245	25251	73	21B
0005433613434	25251	74	21D
0005433613390	25251	75	21F
0005434272178	25251	76	21E
0005434163557	25251	77	22A
0005433613604	25251	78	22C
0005433613512	25251	79	22D
0005433633241	25251	80	22F
0005433613421	25251	81	23B
0005434163559	25251	82	23C
0005433613722	25251	83	23F
0005433613433	25251	84	24B
0005433633223	25251	85	24D
0005434152773	25251	86	24E
0005434163549	25251	87	24F
0005434163551	25251	88	25A
0005433613825	25251	89	25B
0005433633335	25251	90	26A
0005434152772	25251	91	26C
0005433633275	25251	92	26D
0005434152780	25251	93	27A
0005434273063	25251	94	26F
0005433613441	25251	95	27B
0005433633274	25251	96	27D
0005433613643	25251	97	28E
0005434152775	25251	98	28F
0005433613601	25251	99	29A
0005433633299	25251	100	29D
0005433613492	25251	101	30A
0005433633222	25251	102	30C
0005433613511	25251	103	30B
0005433633257	25251	104	30E
0005434152779	25251	105	31A
0005434152776	25251	106	31C
0005433613442	25251	107	31B
0005433633224	25251	108	31F
0005433633319	25251	109	31E
0005435787321	4221	1	1B
0005435787322	4221	2	2H
0005435947024	4221	3	4A
0005435787323	4221	4	4G
0005434271279	4221	5	11G
0005432184929	4221	6	12G
0005435856136	4221	7	13E
0005435947001	4221	8	16E
0005432184931	4221	9	17B
0005434271278	4221	10	18D
0005434271277	4221	11	18H
0005435856142	4221	12	20B
0005432571265	4221	13	21A
0005435947074	4221	14	20H
0005435856131	4221	15	21D
0005435856130	4221	16	21F
0005435946998	4221	17	22H
0005435947029	4221	18	25F
0005432571264	4221	19	27B
0005432571263	4221	20	28G
0005435947008	4221	21	30F
0005435947002	4221	22	30E
0005435947023	4221	23	30H
0005435946997	4221	24	31E
0005432571261	4221	25	33F
0005432571262	4221	26	33H
0005435856137	4221	27	34A
0005435947009	4221	28	34E
0005432184930	4221	29	34G
0005435947054	4221	30	36B
0005435947063	4221	31	36G
0005434271287	4221	32	37H
0005435947064	4221	33	38D
0005432571260	4221	34	38E
0005434271280	4221	35	38F
0005435947156	26570	1	1G
0005432571297	26570	2	2C
0005435947157	26570	3	2G
0005435947150	26570	4	3C
0005435947149	26570	5	4H
0005435856173	26570	6	11F
0005435947148	26570	7	12D
0005435947151	26570	8	12F
0005435947154	26570	9	13H
0005435947158	26570	10	19B
0005432571296	26570	11	21B
0005435947155	26570	12	22G
0005432571298	26570	13	27B
0005435856174	26570	14	28F
0005435856176	26570	15	28H
0005435856175	26570	16	30G
0005435947153	26570	17	30F
0005435947146	26570	18	31A
0005432571295	26570	19	31D
0005435947152	26570	20	35H
0005435947147	26570	21	37E
0005435947159	26570	22	39D
0005433568664	307	1	1A
0005433568607	307	2	1C
0005433074274	307	3	1D
0005433568625	307	4	2A
0005433568615	307	5	1F
0005433568649	307	6	2D
0005433568645	307	7	3A
0005433568673	307	8	2F
0005433568648	307	9	3C
0005433568647	307	10	3F
0005432947819	307	11	3D
0005433568624	307	12	4C
0005433568637	307	13	4D
0005433074294	307	14	5A
0005433568632	307	15	4F
0005433074260	307	16	5C
0005433568675	307	17	6A
0005433568678	307	18	5F
0005432947838	307	19	6F
0005433568668	307	20	6D
0005433568618	307	21	7C
0005432238891	307	22	7F
0005433074295	307	23	8A
0005432238895	307	24	8B
0005432947855	307	25	8D
0005433129213	307	26	8F
0005433568622	307	27	9A
0005433568623	307	28	9C
0005433568676	307	29	9B
0005433568638	307	30	9E
0005432947839	307	31	9D
0005433568611	307	32	10A
0005432947895	307	33	9F
0005433568662	307	34	10B
0005433568670	307	35	10C
0005432947868	307	36	10D
0005432947842	307	37	11A
0005433134076	307	38	10F
0005433568617	307	39	11C
0005432947849	307	40	11F
0005433568609	307	41	11E
0005433568654	307	42	12B
0005432947821	307	43	12D
0005433568616	307	44	12C
0005433568642	307	45	12F
0005432947818	307	46	12E
0005433074204	307	47	13B
0005432238892	307	48	13A
0005433568665	307	49	13C
0005432947853	307	50	13D
0005433074264	307	51	13E
0005433568626	307	52	14A
0005433568657	307	53	13F
0005433568653	307	54	14D
0005433129216	307	55	14E
0005433134062	307	56	14F
0005433568672	307	57	15B
0005433074203	307	58	15C
0005433074269	307	59	15D
0005432238896	307	60	15E
0005433134064	307	61	16A
0005432947869	307	62	16B
0005433568671	307	63	16D
0005433568628	307	64	16C
0005433129212	307	65	16E
0005432238894	307	66	17A
0005432947795	307	67	16F
0005433568659	307	68	17B
0005433568679	307	69	17C
0005433568658	307	70	17D
0005433074291	307	71	17F
0005432947777	307	72	17E
0005433568636	307	73	18A
0005433568669	307	74	18C
0005432948006	307	75	18E
0005433568652	307	76	18F
0005432947765	307	77	19D
0005433568639	307	78	19C
0005432947850	307	79	20A
0005433568650	307	80	20C
0005432238893	307	81	20B
0005433074218	307	82	20E
0005433568651	307	83	20D
0005433568619	307	84	20F
0005433568621	307	85	21B
0005433568629	307	86	21A
0005433568612	307	87	21C
0005433568663	307	88	21D
0005433568633	307	89	21E
0005433568634	307	90	21F
0005432947808	307	91	22B
0005433568640	307	92	22C
0005433568677	307	93	22E
0005432947854	307	94	22D
0005433568631	307	95	23B
0005432948005	307	96	23D
0005433568646	307	97	23F
0005433568613	307	98	23E
0005433568666	307	99	24A
0005433074292	307	100	24B
0005433074351	307	101	24C
0005433568606	307	102	24E
0005433568674	307	103	25A
0005433568656	307	104	25B
0005432947817	307	105	25D
0005433568660	307	106	25C
0005433568610	307	107	26A
0005433074354	307	108	26B
0005433134077	307	109	26D
0005432947910	307	110	26C
0005433568661	307	111	26E
0005433568614	307	112	26F
0005433568620	307	113	27A
0005432947979	307	114	27C
0005432947894	307	115	27D
0005433129217	307	116	28A
0005433074262	307	117	28B
0005433568630	307	118	28D
0005432238890	307	119	28C
0005433568641	307	120	28E
0005433568643	307	121	29B
0005433074293	307	122	29A
0005433568667	307	123	29C
0005432947856	307	124	29D
0005433568644	307	125	29F
0005433074288	307	126	30E
0005433134056	307	127	30F
0005433568627	307	128	31B
0005433074273	307	129	31A
0005433568655	307	130	31C
0005433568635	307	131	31D
0005433568608	307	132	31F
0005433074352	307	133	31E
0005433568022	11583	1	1A
0005433074513	11583	2	1C
0005432948161	11583	3	2A
0005433568112	11583	4	2C
0005433134103	11583	5	3A
0005433131675	11583	6	3D
0005433134106	11583	7	4C
0005433074495	11583	8	4D
0005433074496	11583	9	4F
0005433074494	11583	10	5C
0005432948158	11583	11	6A
0005432948179	11583	12	6C
0005433074508	11583	13	6F
0005432948154	11583	14	7A
0005433131676	11583	15	7F
0005433074518	11583	16	7D
0005433074515	11583	17	8C
0005432192296	11583	18	8D
0005433134104	11583	19	8E
0005432948171	11583	20	9A
0005432948167	11583	21	8F
0005432948153	11583	22	10C
0005433568052	11583	23	10B
0005433074498	11583	24	10E
0005433568118	11583	25	10D
0005433568084	11583	26	10F
0005432948150	11583	27	11A
0005432948149	11583	28	11C
0005433568119	11583	29	11D
0005433568049	11583	30	12A
0005433074499	11583	31	11F
0005433568042	11583	32	12D
0005433568017	11583	33	12F
0005432948172	11583	34	12E
0005432948176	11583	35	13A
0005433074490	11583	36	13C
0005432948143	11583	37	13B
0005432948156	11583	38	13D
0005432948166	11583	39	14A
0005433131677	11583	40	13F
0005432948140	11583	41	14D
0005433568038	11583	42	14E
0005433074491	11583	43	15C
0005433074489	11583	44	15D
0005432948162	11583	45	15E
0005432948142	11583	46	16A
0005432948165	11583	47	16C
0005433074507	11583	48	16B
0005432948164	11583	49	16E
0005432948139	11583	50	16D
0005433074514	11583	51	16F
0005433074517	11583	52	17A
0005432948168	11583	53	17E
0005433568025	11583	54	17F
0005432948155	11583	55	18C
0005432948144	11583	56	18B
0005433131674	11583	57	18D
0005432948160	11583	58	18E
0005433568039	11583	59	18F
0005433074500	11583	60	19C
0005433074501	11583	61	19B
0005432948157	11583	62	19E
0005433074503	11583	63	20A
0005433074504	11583	64	20C
0005432948148	11583	65	20D
0005433134107	11583	66	21A
0005433074509	11583	67	21B
0005433074493	11583	68	21D
0005432948178	11583	69	21F
0005433074492	11583	70	22B
0005433568086	11583	71	22A
0005433568069	11583	72	22C
0005432948173	11583	73	22E
0005433568026	11583	74	22F
0005433568024	11583	75	23A
0005433074512	11583	76	23D
0005433074510	11583	77	23F
0005433074511	11583	78	23E
0005432192297	11583	79	24A
0005432948163	11583	80	24D
0005432948170	11583	81	24C
0005432948147	11583	82	24E
0005432948177	11583	83	24F
0005432948174	11583	84	25B
0005432948180	11583	85	25C
0005433568113	11583	86	26B
0005433074505	11583	87	26E
0005433568102	11583	88	26F
0005432948152	11583	89	27A
0005433074516	11583	90	27B
0005432192298	11583	91	27D
0005433074497	11583	92	27F
0005433074488	11583	93	28C
0005432948151	11583	94	28D
0005432948145	11583	95	28E
0005433568064	11583	96	28F
0005433568050	11583	97	29B
0005433074502	11583	98	29A
0005433074506	11583	99	29D
0005432948141	11583	100	29C
0005432948146	11583	101	29E
0005432948159	11583	102	30A
0005433568021	11583	103	30B
0005433134105	11583	104	30C
0005432948175	11583	105	31B
0005432948169	11583	106	31A
0005434732945	9973	1	2B
0005433817444	9973	2	2A
0005433817442	9973	3	3A
0005434732929	9973	4	4A
0005433817443	9973	5	4B
0005434732922	9973	6	5A
0005433817445	9973	7	6B
0005433817416	13891	1	1A
0005433817406	13891	2	2A
0005434732955	13891	3	1B
0005434732958	13891	4	2B
0005433817412	13891	5	3A
0005433817407	13891	6	3B
0005434732956	13891	7	4A
0005433817415	13891	8	4B
0005433817417	13891	9	5A
0005434732957	13891	10	5B
0005433817405	13891	11	6B
0005433817413	13891	12	6A
0005433434379	2376	1	1A
0005433753809	2376	2	1C
0005432655449	2376	3	1B
0005432984504	2376	4	1F
0005433753833	2376	5	2A
0005432984547	2376	6	1H
0005433753840	2376	7	2B
0005433753837	2376	8	2F
0005435982002	2376	9	2C
0005433753819	2376	10	2G
0005435981968	2376	11	3A
0005435981976	2376	12	2H
0005432869434	2376	13	3B
0005432226014	2376	14	3F
0005435981983	2376	15	4A
0005433766614	2376	16	3H
0005435982004	2376	17	4C
0005433434294	2376	18	4B
0005433753806	2376	19	4F
0005433753805	2376	20	4G
0005433753825	2376	21	4H
0005435981977	2376	22	5B
0005433753803	2376	23	5G
0005432984505	2376	24	5F
0005433753804	2376	25	5H
0005433753832	2376	26	9B
0005433766612	2376	27	9A
0005435982012	2376	28	9H
0005435982006	2376	29	9G
0005433764665	2376	30	11D
0005432226013	2376	31	11B
0005435981981	2376	32	11A
0005433753807	2376	33	11F
0005435981963	2376	34	11H
0005432984548	2376	35	12A
0005433753798	2376	36	12D
0005432300221	2376	37	12B
0005432655459	2376	38	12E
0005432984538	2376	39	12G
0005433753846	2376	40	12H
0005433434227	2376	41	13D
0005435981979	2376	42	13B
0005433753808	2376	43	13E
0005433434189	2376	44	13F
0005432984629	2376	45	13H
0005432655454	2376	46	13G
0005432655456	2376	47	14B
0005433753827	2376	48	14A
0005432984638	2376	49	14D
0005432984515	2376	50	14F
0005433434295	2376	51	14G
0005433434201	2376	52	14H
0005433753830	2376	53	15D
0005433753853	2376	54	15B
0005433434361	2376	55	15E
0005433753838	2376	56	15F
0005432655450	2376	57	15G
0005435981973	2376	58	16A
0005433766613	2376	59	16E
0005433434228	2376	60	16F
0005435982001	2376	61	16G
0005432300222	2376	62	17B
0005433434253	2376	63	17A
0005435981992	2376	64	17D
0005432655452	2376	65	17E
0005433753821	2376	66	17G
0005433753813	2376	67	17F
0005433434348	2376	68	17H
0005435981997	2376	69	18B
0005432984649	2376	70	18A
0005434731100	2376	71	18E
0005435981984	2376	72	18D
0005433753814	2376	73	18G
0005433753826	2376	74	18F
0005433753811	2376	75	18H
0005433753845	2376	76	19B
0005432655457	2376	77	19A
0005435981971	2376	78	19E
0005433434362	2376	79	19F
0005432655453	2376	80	19G
0005433764664	2376	81	19H
0005433753797	2376	82	20B
0005435982000	2376	83	20E
0005435982007	2376	84	20D
0005433434290	2376	85	20H
0005435981975	2376	86	20G
0005435981962	2376	87	21A
0005433753828	2376	88	21D
0005432984535	2376	89	21B
0005433753822	2376	90	21F
0005435982010	2376	91	21E
0005435981969	2376	92	21G
0005432984582	2376	93	22D
0005435982008	2376	94	22F
0005433753839	2376	95	22E
0005435981966	2376	96	22G
0005435981970	2376	97	22H
0005432655451	2376	98	23A
0005435981996	2376	99	23D
0005432226011	2376	100	23F
0005433753851	2376	101	23E
0005433753850	2376	102	23G
0005433753835	2376	103	24A
0005433434254	2376	104	23H
0005435981982	2376	105	24B
0005433753834	2376	106	24E
0005433753823	2376	107	24D
0005433434240	2376	108	24F
0005433753818	2376	109	24G
0005433434188	2376	110	25D
0005435981999	2376	111	25E
0005435981972	2376	112	25F
0005432300223	2376	113	27B
0005435981990	2376	114	27E
0005432984652	2376	115	27G
0005433753817	2376	116	27F
0005435981967	2376	117	28B
0005433434229	2376	118	28E
0005432655455	2376	119	28H
0005435981980	2376	120	28G
0005433753848	2376	121	29D
0005433753847	2376	122	29B
0005433753849	2376	123	29F
0005433753836	2376	124	30A
0005435981994	2376	125	29G
0005432869417	2376	126	30B
0005432226012	2376	127	30D
0005435981986	2376	128	30F
0005435981989	2376	129	30E
0005435981964	2376	130	30G
0005433753812	2376	131	31A
0005432655458	2376	132	31B
0005433766611	2376	133	31D
0005432984607	2376	134	31F
0005433434200	2376	135	31E
0005433753816	2376	136	31G
0005433434226	2376	137	32A
0005435981993	2376	138	31H
0005435981978	2376	139	32B
0005433753852	2376	140	32E
0005435982011	2376	141	32D
0005433753829	2376	142	32F
0005435981995	2376	143	32G
0005433753844	2376	144	33A
0005432984554	2376	145	32H
0005433753810	2376	146	33B
0005433753841	2376	147	33E
0005432984593	2376	148	33D
0005432300225	2376	149	33F
0005435981974	2376	150	33H
0005433753815	2376	151	33G
0005432984619	2376	152	34B
0005432984653	2376	153	34A
0005432984565	2376	154	34D
0005432984592	2376	155	34F
0005435981965	2376	156	34G
0005433753831	2376	157	35A
0005433753842	2376	158	34H
0005433434239	2376	159	35E
0005435982013	2376	160	35D
0005433753799	2376	161	35B
0005432300224	2376	162	35G
0005432984620	2376	163	35F
0005433753800	2376	164	36B
0005433764666	2376	165	36D
0005435982005	2376	166	36F
0005435981987	2376	167	36E
0005432869429	2376	168	36G
0005433753820	2376	169	37A
0005433753824	2376	170	36H
0005433753802	2376	171	37D
0005435981998	2376	172	37B
0005435982003	2376	173	37G
0005433753843	2376	174	37E
0005433753801	2376	175	38A
0005435981985	2376	176	37H
0005435982009	2376	177	38D
0005435981988	2376	178	38F
0005432984536	2376	179	38H
0005434731097	2376	180	38G
0005432226015	2376	181	39E
0005435981991	2376	182	39D
0005432226010	2376	183	39F
0005433753433	26163	1	1A
0005435981571	26163	2	1C
0005433434494	26163	3	1F
0005435981512	26163	4	1H
0005432984841	26163	5	2C
0005432984840	26163	6	2H
0005432984839	26163	7	3A
0005434731141	26163	8	3B
0005433434480	26163	9	3F
0005433434486	26163	10	3C
0005433753289	26163	11	4A
0005432984855	26163	12	4B
0005435981621	26163	13	4C
0005433753548	26163	14	4G
0005432655328	26163	15	4F
0005432984860	26163	16	4H
0005432984848	26163	17	5A
0005435981639	26163	18	5C
0005433753562	26163	19	5F
0005432869475	26163	20	5H
0005435981617	26163	21	9B
0005433753298	26163	22	11A
0005434731139	26163	23	9H
0005432869476	26163	24	11D
0005432049437	26163	25	11B
0005433753509	26163	26	11E
0005433434492	26163	27	11F
0005435981603	26163	28	11G
0005433434469	26163	29	12A
0005433753259	26163	30	11H
0005432984847	26163	31	12B
0005433434471	26163	32	12E
0005435981618	26163	33	12D
0005433753425	26163	34	12F
0005435981539	26163	35	13A
0005433753327	26163	36	12G
0005432984846	26163	37	13B
0005432984857	26163	38	13E
0005433434470	26163	39	13G
0005434731140	26163	40	13F
0005435981531	26163	41	13H
0005433434487	26163	42	14B
0005435981698	26163	43	14A
0005433753321	26163	44	14F
0005433434479	26163	45	14E
0005435981521	26163	46	14G
0005433753322	26163	47	14H
0005433434484	26163	48	15A
0005432984845	26163	49	15E
0005435981684	26163	50	15D
0005433434481	26163	51	15G
0005433434496	26163	52	15F
0005435981540	26163	53	15H
0005433434478	26163	54	16D
0005433753380	26163	55	16B
0005435981590	26163	56	16E
0005432869477	26163	57	16H
0005433753411	26163	58	16G
0005433753428	26163	59	17D
0005432984833	26163	60	17B
0005435981735	26163	61	17G
0005432049439	26163	62	17F
0005432984842	26163	63	18A
0005433753508	26163	64	17H
0005432984850	26163	65	18B
0005432984861	26163	66	18D
0005433434483	26163	67	18F
0005433434491	26163	68	18G
0005432051105	26163	69	19A
0005432049438	26163	70	18H
0005433753262	26163	71	19B
0005435981578	26163	72	19D
0005432984854	26163	73	19F
0005432655327	26163	74	19G
0005435981658	26163	75	20A
0005433753366	26163	76	19H
0005432655351	26163	77	20B
0005433434472	26163	78	20E
0005432984856	26163	79	20H
0005433753450	26163	80	21B
0005435981549	26163	81	21E
0005432984844	26163	82	21F
0005435981530	26163	83	21H
0005433753313	26163	84	21G
0005433753246	26163	85	22A
0005432049436	26163	86	22D
0005432984837	26163	87	22B
0005433753286	26163	88	22F
0005432984849	26163	89	22E
0005433434477	26163	90	22G
0005435981622	26163	91	22H
0005432984852	26163	92	23B
0005433753506	26163	93	23A
0005435981555	26163	94	23E
0005435981755	26163	95	23G
0005433753363	26163	96	23F
0005435981681	26163	97	23H
0005435981657	26163	98	24B
0005432051106	26163	99	24A
0005432984859	26163	100	24E
0005432984836	26163	101	24D
0005432984838	26163	102	24F
0005433753561	26163	103	24G
0005435981516	26163	104	25D
0005435981689	26163	105	24H
0005435981709	26163	106	25F
0005433753431	26163	107	27A
0005432984862	26163	108	27B
0005433766576	26163	109	27E
0005435981640	26163	110	27F
0005433753304	26163	111	27G
0005432984853	26163	112	28A
0005432869474	26163	113	28E
0005432984863	26163	114	28G
0005435981632	26163	115	29A
0005435981596	26163	116	29B
0005435981715	26163	117	29F
0005432984864	26163	118	30D
0005435981714	26163	119	30E
0005432984843	26163	120	30G
0005432655331	26163	121	31A
0005433753285	26163	122	30H
0005433434490	26163	123	31B
0005433434493	26163	124	31E
0005432984835	26163	125	31F
0005435981656	26163	126	31H
0005435981662	26163	127	32B
0005432984858	26163	128	32A
0005435981581	26163	129	32H
0005432984865	26163	130	32G
0005432655353	26163	131	33A
0005433434488	26163	132	33B
0005432984851	26163	133	33E
0005433753306	26163	134	33D
0005433753310	26163	135	33G
0005433434485	26163	136	33F
0005435981703	26163	137	33H
0005433434474	26163	138	34A
0005433753290	26163	139	34D
0005435981548	26163	140	34E
0005432984834	26163	141	34G
0005433753507	26163	142	35B
0005433753426	26163	143	35E
0005433434495	26163	144	35D
0005432869478	26163	145	35F
0005433434489	26163	146	35G
0005435981675	26163	147	35H
0005432869473	26163	148	36D
0005433434475	26163	149	36F
0005432984832	26163	150	36H
0005432051107	26163	151	36G
0005433753299	26163	152	37B
0005433753307	26163	153	37D
0005433753344	26163	154	37F
0005433434482	26163	155	37G
0005434731142	26163	156	38B
0005433434476	26163	157	38A
0005433753432	26163	158	38F
0005432655326	26163	159	38H
0005433753263	26163	160	38G
0005433434473	26163	161	39E
0005433753427	26163	162	39F
0005433150858	1526	1	1A
0005432267849	1526	2	1F
0005433764643	1526	3	1D
0005433151102	1526	4	2C
0005434374362	1526	5	2D
0005434374336	1526	6	3A
0005434374311	1526	7	2F
0005434374360	1526	8	3C
0005434374342	1526	9	3D
0005434374337	1526	10	4A
0005433150830	1526	11	4B
0005433150916	1526	12	4D
0005434374351	1526	13	4E
0005434374354	1526	14	5A
0005433150995	1526	15	4F
0005434374340	1526	16	5D
0005433151084	1526	17	5C
0005433150915	1526	18	5E
0005433461573	1526	19	6A
0005434374352	1526	20	6B
0005434374334	1526	21	6D
0005433150923	1526	22	7A
0005433150803	1526	23	6F
0005434374327	1526	24	7B
0005434374318	1526	25	7C
0005433150895	1526	26	7D
0005433150883	1526	27	7F
0005433150848	1526	28	7E
0005433150977	1526	29	8A
0005433150948	1526	30	8B
0005432267848	1526	31	8D
0005434374328	1526	32	8C
0005434374341	1526	33	8E
0005433151083	1526	34	8F
0005434374349	1526	35	9C
0005434374331	1526	36	9E
0005433461572	1526	37	9F
0005434374347	1526	38	10B
0005434374357	1526	39	10D
0005434374353	1526	40	10E
0005434374312	1526	41	11B
0005434374333	1526	42	11C
0005434374339	1526	43	11E
0005433150933	1526	44	11D
0005433931424	1526	45	11F
0005434374358	1526	46	12A
0005434374324	1526	47	12C
0005434374348	1526	48	12D
0005433931420	1526	49	12E
0005433460421	1526	50	12F
0005433150894	1526	51	13A
0005434374355	1526	52	13C
0005433150889	1526	53	13B
0005433931413	1526	54	13D
0005434374329	1526	55	13E
0005433151101	1526	56	13F
0005433150823	1526	57	14A
0005432267847	1526	58	14C
0005434374346	1526	59	14B
0005433150909	1526	60	14D
0005433150834	1526	61	14F
0005434374359	1526	62	14E
0005433150833	1526	63	15A
0005433151010	1526	64	15B
0005434374314	1526	65	15C
0005434374343	1526	66	15F
0005433150816	1526	67	15E
0005434374332	1526	68	16A
0005433150947	1526	69	16E
0005434374317	1526	70	16F
0005433150824	1526	71	17B
0005432267850	1526	72	17A
0005434374322	1526	73	17C
0005434374350	1526	74	17D
0005433150849	1526	75	17E
0005434374330	1526	76	18A
0005434374361	1526	77	17F
0005434374323	1526	78	18B
0005434374310	1526	79	18C
0005434374345	1526	80	18D
0005434374321	1526	81	18F
0005434374338	1526	82	19A
0005434374313	1526	83	19B
0005433150804	1526	84	19D
0005434374344	1526	85	19E
0005434374320	1526	86	19F
0005433150988	1526	87	20A
0005434374316	1526	88	20C
0005434374325	1526	89	20B
0005434374319	1526	90	20D
0005433150877	1526	91	21A
0005434374326	1526	92	21B
0005433931414	1526	93	21D
0005434374315	1526	94	21C
0005433150892	1526	95	21E
0005433931427	1526	96	22A
0005433150949	1526	97	21F
0005432267846	1526	98	22C
0005433150891	1526	99	22B
0005432267845	1526	100	22D
0005433150835	1526	101	22E
0005433150807	1526	102	23A
0005434374335	1526	103	22F
0005434374356	1526	104	23E
0005433150868	1526	105	23D
0005433460420	1526	106	23F
0005433931444	20116	1	1A
0005433151174	20116	2	1C
0005433151171	20116	3	1F
0005433151158	20116	4	2C
0005434373927	20116	5	2A
0005434374063	20116	6	2F
0005433151179	20116	7	3A
0005433151146	20116	8	3D
0005433151150	20116	9	3F
0005434029638	20116	10	4C
0005434373869	20116	11	4B
0005433151147	20116	12	4E
0005433151161	20116	13	4D
0005433151155	20116	14	5B
0005434373922	20116	15	5C
0005433151145	20116	16	5D
0005434029640	20116	17	5F
0005434373846	20116	18	6C
0005434373989	20116	19	6D
0005433151164	20116	20	6F
0005433151154	20116	21	7B
0005434374015	20116	22	7C
0005434029639	20116	23	7E
0005434374076	20116	24	7D
0005434373999	20116	25	7F
0005433764664	20116	26	8B
0005434374075	20116	27	8D
0005433151165	20116	28	8E
0005434373965	20116	29	9C
0005432056272	20116	30	9E
0005433764665	20116	31	9D
0005434373870	20116	32	9F
0005433151162	20116	33	10B
0005433764666	20116	34	10E
0005433151156	20116	35	10D
0005433151167	20116	36	11A
0005433151151	20116	37	11B
0005434373973	20116	38	11D
0005434373889	20116	39	11F
0005433151148	20116	40	12A
0005433151163	20116	41	12B
0005434374031	20116	42	12E
0005434374074	20116	43	12D
0005433151176	20116	44	13A
0005433151170	20116	45	13B
0005434374027	20116	46	13D
0005433151172	20116	47	14A
0005434374000	20116	48	14C
0005433151178	20116	49	14D
0005434373874	20116	50	14F
0005434374064	20116	51	15A
0005433151177	20116	52	15C
0005434373988	20116	53	15D
0005434374056	20116	54	15E
0005434373928	20116	55	15F
0005434374067	20116	56	16B
0005433151168	20116	57	16A
0005434374055	20116	58	16D
0005432056271	20116	59	16C
0005433931442	20116	60	17C
0005433151152	20116	61	17E
0005434373868	20116	62	17D
0005434373967	20116	63	18A
0005433151173	20116	64	17F
0005434374026	20116	65	18C
0005434374032	20116	66	18D
0005434373873	20116	67	19A
0005433151166	20116	68	19B
0005434373906	20116	69	19D
0005433151157	20116	70	20C
0005433151153	20116	71	20B
0005433931443	20116	72	20D
0005434374010	20116	73	21A
0005434373964	20116	74	21C
0005433151169	20116	75	21D
0005433151160	20116	76	21F
0005434374041	20116	77	21E
0005434373985	20116	78	22D
0005434373966	20116	79	22F
0005433151149	20116	80	22E
0005434373987	20116	81	23A
0005433151175	20116	82	23B
0005433151159	20116	83	23C
0005432056273	20116	84	23F
0005432424150	519	1	1F
0005432282811	519	2	2C
0005432424157	519	3	2D
0005432282816	519	4	3C
0005432424110	519	5	4A
0005432282812	519	6	3F
0005432282817	519	7	4C
0005432424122	519	8	4F
0005432424155	519	9	5C
0005432424159	519	10	6A
0005432424139	519	11	6F
0005432424152	519	12	7D
0005432424158	519	13	7C
0005432424113	519	14	8E
0005432424148	519	15	9B
0005432424117	519	16	9F
0005432282815	519	17	10A
0005432424109	519	18	10C
0005432282813	519	19	11D
0005432424156	519	20	11E
0005432424137	519	21	12E
0005432424119	519	22	13C
0005432424098	519	23	13D
0005432424100	519	24	13E
0005432424129	519	25	15A
0005432424125	519	26	15C
0005432424105	519	27	16A
0005432424112	519	28	16E
0005432424134	519	29	17C
0005432424147	519	30	17F
0005432424131	519	31	17E
0005432424135	519	32	18B
0005432424128	519	33	18D
0005432424121	519	34	18C
0005432424107	519	35	19B
0005432424145	519	36	19C
0005432424124	519	37	19E
0005432424143	519	38	20C
0005432424116	519	39	20B
0005432424154	519	40	20D
0005432424151	519	41	20F
0005432424140	519	42	21C
0005432282814	519	43	22C
0005432424132	519	44	22E
0005432424115	519	45	22D
0005432424141	519	46	23A
0005432424104	519	47	24D
0005432424108	519	48	24E
0005432424130	519	49	25A
0005432424127	519	50	25B
0005432424123	519	51	25D
0005432424146	519	52	26C
0005432424136	519	53	26D
0005432424126	519	54	26F
0005432424144	519	55	27C
0005432424111	519	56	27E
0005432424153	519	57	28A
0005432424114	519	58	27F
0005432424101	519	59	28B
0005432424102	519	60	28E
0005432424138	519	61	29A
0005432424099	519	62	28F
0005432424142	519	63	29F
0005432424133	519	64	30D
0005432424118	519	65	30C
0005432424120	519	66	31B
0005432424106	519	67	31A
0005432424149	519	68	31C
0005432424103	519	69	31D
0005432302303	12901	1	5C
0005432302305	12901	2	6C
0005432302304	12901	3	22F
0005432423730	12887	1	1C
0005432423722	12887	2	2C
0005432423729	12887	3	2D
0005432423660	12887	4	8C
0005432423697	12887	5	8E
0005432423613	12887	6	9B
0005432423649	12887	7	10E
0005432423735	12887	8	10D
0005432423669	12887	9	10F
0005432423724	12887	10	12A
0005432423689	12887	11	12E
0005432423706	12887	12	13C
0005432423614	12887	13	14D
0005432423762	12887	14	17A
0005432423690	12887	15	17E
0005432423636	12887	16	18B
0005432423681	12887	17	19B
0005432423668	12887	18	21A
0005432423631	12887	19	22A
0005432423721	12887	20	22C
0005432423731	12887	21	23B
0005432423627	12887	22	25B
0005432423680	12887	23	27E
0005432423707	12887	24	28A
0005432423628	12887	25	28C
0005432423653	12887	26	29A
0005432423748	12887	27	29B
0005432423723	12887	28	30B
0005432423632	12887	29	31A
0005434023241	435	1	1C
0005434023206	435	2	1B
0005434023263	435	3	1F
0005434023213	435	4	2A
0005434023256	435	5	2C
0005433057275	435	6	2H
0005434023239	435	7	2G
0005434023217	435	8	3A
0005434023249	435	9	3B
0005434023240	435	10	3C
0005434023259	435	11	3G
0005434023209	435	12	3F
0005434023211	435	13	3H
0005434023246	435	14	4C
0005434023204	435	15	4G
0005434023230	435	16	5B
0005433057176	435	17	5A
0005433929556	435	18	5F
0005434023254	435	19	9A
0005434023244	435	20	5H
0005434023225	435	21	9H
0005432235582	435	22	11B
0005433929559	435	23	11H
0005434031986	435	24	11G
0005433057336	435	25	12A
0005434023233	435	26	12D
0005433057288	435	27	12F
0005434023196	435	28	12H
0005433057307	435	29	13D
0005434023200	435	30	13B
0005433057363	435	31	13E
0005433057194	435	32	13F
0005433057184	435	33	14A
0005433057210	435	34	14B
0005434023250	435	35	14F
0005433057302	435	36	14G
0005434023216	435	37	15A
0005434023234	435	38	14H
0005434023228	435	39	15D
0005434023262	435	40	15F
0005432235584	435	41	15G
0005434023210	435	42	16A
0005433057405	435	43	15H
0005432235588	435	44	16E
0005434031987	435	45	16H
0005433684392	435	46	17B
0005434023237	435	47	17A
0005434023226	435	48	17D
0005433057352	435	49	17G
0005434023238	435	50	17F
0005434023227	435	51	18A
0005434023257	435	52	17H
0005434023198	435	53	18D
0005434023218	435	54	18H
0005433057355	435	55	19B
0005433057348	435	56	19D
0005434023235	435	57	19H
0005433057342	435	58	19G
0005433684390	435	59	20B
0005433057190	435	60	20E
0005434023223	435	61	20D
0005432235586	435	62	20F
0005433057428	435	63	21A
0005433057173	435	64	20H
0005434023243	435	65	21D
0005433057533	435	66	21F
0005433057174	435	67	22B
0005433057191	435	68	22A
0005432235581	435	69	22D
0005434023214	435	70	22F
0005434023261	435	71	22H
0005434023221	435	72	23B
0005434023219	435	73	23A
0005433057187	435	74	23F
0005434028275	435	75	23E
0005432235583	435	76	23G
0005434023222	435	77	23H
0005433929557	435	78	24B
0005434023251	435	79	24E
0005434023203	435	80	24D
0005434023215	435	81	24G
0005434023248	435	82	25D
0005434028276	435	83	24H
0005434023258	435	84	27A
0005433057347	435	85	25F
0005433057205	435	86	27B
0005434031988	435	87	27E
0005434023199	435	88	27D
0005434023220	435	89	27F
0005433057303	435	90	28A
0005434023229	435	91	28D
0005433929539	435	92	28B
0005434023236	435	93	28E
0005434735604	435	94	28F
0005433057440	435	95	28H
0005433057185	435	96	29D
0005434023245	435	97	29B
0005433057331	435	98	29E
0005433057432	435	99	29G
0005434029635	435	100	29H
0005433057308	435	101	30A
0005432235585	435	102	30D
0005434023195	435	103	30G
0005434023212	435	104	31A
0005433057534	435	105	30H
0005433057362	435	106	31D
0005433057249	435	107	31F
0005433057175	435	108	31G
0005432045598	435	109	31H
0005434031989	435	110	32B
0005433057268	435	111	32D
0005433057433	435	112	32F
0005434735605	435	113	32E
0005433057442	435	114	32H
0005434029637	435	115	33D
0005434023197	435	116	33B
0005434023232	435	117	33E
0005434023201	435	118	33H
0005434023247	435	119	34A
0005434023231	435	120	34D
0005433057204	435	121	34E
0005434023242	435	122	34H
0005434023260	435	123	35D
0005434023252	435	124	35B
0005434023205	435	125	35G
0005433929558	435	126	36B
0005434023255	435	127	36E
0005434023202	435	128	36D
0005432235587	435	129	36F
0005433057298	435	130	36G
0005434029636	435	131	36H
0005433057301	435	132	37D
0005434023208	435	133	38B
0005434023224	435	134	38E
0005434023207	435	135	38G
0005434023253	435	136	39D
0005433057283	435	137	39F
0005433057443	435	138	39E
0005434022679	12649	1	1F
0005433057603	12649	2	1C
0005433057586	12649	3	1G
0005434022836	12649	4	2A
0005433057581	12649	5	2F
0005433057594	12649	6	3A
0005434022795	12649	7	2H
0005434022736	12649	8	3C
0005434022695	12649	9	3H
0005434022678	12649	10	4A
0005432156335	12649	11	4F
0005434735655	12649	12	5A
0005434022667	12649	13	4H
0005434028250	12649	14	5F
0005433057605	12649	15	5C
0005433057588	12649	16	5G
0005434022699	12649	17	5H
0005433929585	12649	18	9A
0005434022696	12649	19	9H
0005434022694	12649	20	9G
0005433057601	12649	21	11E
0005433057593	12649	22	11D
0005433057583	12649	23	11G
0005433057602	12649	24	12A
0005434022644	12649	25	12B
0005434022700	12649	26	12G
0005433057610	12649	27	13A
0005433057615	12649	28	13E
0005434022747	12649	29	13G
0005433057591	12649	30	13F
0005433929583	12649	31	13H
0005434735651	12649	32	14B
0005433057619	12649	33	14A
0005433057597	12649	34	14D
0005434028249	12649	35	14G
0005434022628	12649	36	14H
0005434022741	12649	37	15E
0005433057590	12649	38	15F
0005434735652	12649	39	15H
0005434022805	12649	40	15G
0005434022883	12649	41	16A
0005434022665	12649	42	16B
0005433684406	12649	43	16H
0005434022791	12649	44	17F
0005434022794	12649	45	17E
0005433057596	12649	46	18B
0005434022617	12649	47	18A
0005434022861	12649	48	18D
0005433057618	12649	49	18H
0005434022837	12649	50	19D
0005434022974	12649	51	19G
0005433057606	12649	52	20A
0005433057604	12649	53	19H
0005433057612	12649	54	20B
0005434022638	12649	55	20E
0005432156333	12649	56	20H
0005433057613	12649	57	20G
0005432157478	12649	58	21A
0005434022862	12649	59	21D
0005433057582	12649	60	21F
0005434022702	12649	61	23D
0005433057600	12649	62	24E
0005434022571	12649	63	24D
0005434022698	12649	64	24F
0005434022708	12649	65	24G
0005433057611	12649	66	25D
0005434022835	12649	67	27A
0005434022618	12649	68	27B
0005433057587	12649	69	27E
0005433057595	12649	70	27G
0005432156334	12649	71	28A
0005433929581	12649	72	28B
0005433929582	12649	73	28E
0005433057617	12649	74	28F
0005434735650	12649	75	28H
0005434031947	12649	76	28G
0005433057598	12649	77	29B
0005433057616	12649	78	29A
0005434022884	12649	79	29E
0005434022598	12649	80	29F
0005433057584	12649	81	30B
0005434028247	12649	82	30D
0005433057607	12649	83	30E
0005434022592	12649	84	30H
0005434735654	12649	85	31A
0005434022645	12649	86	31F
0005432156336	12649	87	31H
0005434022893	12649	88	31G
0005433057592	12649	89	32E
0005434022674	12649	90	32G
0005433057609	12649	91	32H
0005434735653	12649	92	33B
0005434022776	12649	93	33E
0005434022788	12649	94	33G
0005433057589	12649	95	34A
0005433057580	12649	96	35E
0005433057608	12649	97	35G
0005434022701	12649	98	35F
0005434022754	12649	99	35H
0005433929584	12649	100	36B
0005434022843	12649	101	36A
0005434028251	12649	102	36D
0005433057585	12649	103	36F
0005434031956	12649	104	36E
0005434022668	12649	105	37A
0005434022664	12649	106	37B
0005434022600	12649	107	37E
0005434022975	12649	108	37F
0005434022689	12649	109	37H
0005433057614	12649	110	38A
0005434022825	12649	111	38B
0005433057620	12649	112	38F
0005433057599	12649	113	39D
0005434022627	12649	114	39E
0005433527237	13818	1	1F
0005433529237	13818	2	3A
0005433529248	13818	3	4D
0005433527234	13818	4	6D
0005433529239	13818	5	7F
0005433527231	13818	6	8C
0005433527238	13818	7	8B
0005433527227	13818	8	9A
0005433527236	13818	9	12A
0005433527233	13818	10	12E
0005433529240	13818	11	12F
0005433527232	13818	12	13F
0005433529243	13818	13	14E
0005433527228	13818	14	14D
0005433529241	13818	15	14F
0005433529246	13818	16	15E
0005433527235	13818	17	16B
0005433529247	13818	18	16F
0005433529242	13818	19	17B
0005433527230	13818	20	17D
0005433527229	13818	21	18C
0005433529244	13818	22	18D
0005433529238	13818	23	19B
0005433529245	13818	24	20B
0005433527226	13818	25	21A
0005433533243	32442	1	4A
0005433533240	32442	2	5C
0005433533257	32442	3	5F
0005433529216	32442	4	6D
0005433533245	32442	5	10D
0005433533241	32442	6	14A
0005433533242	32442	7	15B
0005433533259	32442	8	15D
0005433533246	32442	9	16F
0005433529215	32442	10	18C
0005433533244	32442	11	18E
0005433533258	32442	12	20C
0005432231483	2125	1	1B
0005433922589	2125	2	1A
0005433922623	2125	3	1C
0005433035569	2125	4	1F
0005432231490	2125	5	1H
0005433035436	2125	6	1G
0005433922618	2125	7	2F
0005433922607	2125	8	2H
0005432231488	2125	9	3B
0005432231484	2125	10	3A
0005433922663	2125	11	3F
0005433929583	2125	12	3C
0005433035403	2125	13	3G
0005433035482	2125	14	4A
0005433035395	2125	15	4B
0005433035600	2125	16	4C
0005432231486	2125	17	4G
0005433035575	2125	18	4F
0005433931443	2125	19	5B
0005433922644	2125	20	5A
0005433922578	2125	21	5C
0005433922638	2125	22	5H
0005433035505	2125	23	9B
0005433922626	2125	24	9A
0005432231487	2125	25	9G
0005433035601	2125	26	11A
0005433035549	2125	27	11D
0005434028247	2125	28	11B
0005433922613	2125	29	11E
0005433922584	2125	30	11H
0005433922603	2125	31	12A
0005432231485	2125	32	12B
0005433922639	2125	33	12E
0005432231491	2125	34	12F
0005433035540	2125	35	12H
0005433035711	2125	36	12G
0005433922599	2125	37	13B
0005433922665	2125	38	13A
0005433922606	2125	39	13G
0005433922574	2125	40	13F
0005433922652	2125	41	14A
0005433035496	2125	42	14B
0005433035492	2125	43	14F
0005433035541	2125	44	14E
0005433922657	2125	45	15A
0005433035471	2125	46	15D
0005433922660	2125	47	15B
0005433922586	2125	48	15E
0005433922646	2125	49	15G
0005433922662	2125	50	15F
0005432231492	2125	51	15H
0005432231489	2125	52	16B
0005433931444	2125	53	16A
0005434028251	2125	54	16E
0005433922572	2125	55	16G
0005433922576	2125	56	16H
0005433922605	2125	57	17A
0005433035497	2125	58	17D
0005433922609	2125	59	17F
0005433922655	2125	60	17G
0005433922590	2125	61	18A
0005433035621	2125	62	17H
0005433929584	2125	63	18B
0005433922629	2125	64	18E
0005433922601	2125	65	18F
0005433035425	2125	66	18G
0005433922592	2125	67	19A
0005433035469	2125	68	19B
0005433922581	2125	69	19E
0005433922617	2125	70	19H
0005433035570	2125	71	19G
0005433035402	2125	72	20A
0005433922645	2125	73	20D
0005433922587	2125	74	20B
0005433035409	2125	75	20E
0005433922651	2125	76	20F
0005433922636	2125	77	20G
0005434028250	2125	78	21A
0005433922602	2125	79	21D
0005433922621	2125	80	21B
0005433035550	2125	81	21E
0005433035498	2125	82	21F
0005433922612	2125	83	21H
0005432044505	2125	84	21G
0005433922642	2125	85	22D
0005433922631	2125	86	22B
0005433922582	2125	87	22E
0005433922615	2125	88	22G
0005433922598	2125	89	22F
0005433922608	2125	90	23B
0005433035418	2125	91	23A
0005433922637	2125	92	23E
0005433922600	2125	93	23H
0005433922625	2125	94	23G
0005433922654	2125	95	23F
0005433035379	2125	96	24B
0005433929582	2125	97	24A
0005433922630	2125	98	24E
0005433035410	2125	99	24D
0005433035457	2125	100	24F
0005433931442	2125	101	24G
0005433035476	2125	102	25D
0005433922619	2125	103	24H
0005433922641	2125	104	25E
0005433922611	2125	105	27A
0005433922624	2125	106	25F
0005433035466	2125	107	27B
0005433922594	2125	108	27E
0005433922620	2125	109	27D
0005433922650	2125	110	27G
0005433922577	2125	111	28A
0005433035610	2125	112	27H
0005433922633	2125	113	28B
0005433922622	2125	114	28F
0005433922616	2125	115	28G
0005433922585	2125	116	29A
0005432231493	2125	117	29D
0005433922649	2125	118	29E
0005433922659	2125	119	29G
0005433922604	2125	120	29F
0005433875366	2125	121	29H
0005433922597	2125	122	30D
0005433922640	2125	123	30E
0005433035483	2125	124	30G
0005433922593	2125	125	31A
0005433035423	2125	126	30H
0005433922614	2125	127	31B
0005433922596	2125	128	31E
0005433035544	2125	129	31D
0005433922627	2125	130	31F
0005433035362	2125	131	31H
0005433035552	2125	132	31G
0005433035452	2125	133	32A
0005433922634	2125	134	32B
0005433035387	2125	135	32E
0005433922628	2125	136	32F
0005433922610	2125	137	33D
0005432231494	2125	138	33B
0005433922588	2125	139	33F
0005433922635	2125	140	33H
0005433922570	2125	141	33G
0005433035472	2125	142	34B
0005432044504	2125	143	34A
0005433035493	2125	144	34D
0005433035445	2125	145	34E
0005433035380	2125	146	34F
0005433035456	2125	147	35A
0005433922664	2125	148	34H
0005433922632	2125	149	34G
0005433922573	2125	150	35B
0005433922595	2125	151	35E
0005433922571	2125	152	35D
0005433922580	2125	153	35F
0005433922575	2125	154	35G
0005433922658	2125	155	36B
0005433035545	2125	156	36A
0005433922666	2125	157	36D
0005433035555	2125	158	36E
0005433929585	2125	159	36G
0005433035386	2125	160	36H
0005433922661	2125	161	37B
0005433922579	2125	162	37E
0005433035499	2125	163	37D
0005433922591	2125	164	37F
0005433922653	2125	165	38B
0005433929581	2125	166	38A
0005433035470	2125	167	37H
0005433922643	2125	168	38D
0005433922583	2125	169	38E
0005434028249	2125	170	38F
0005433035554	2125	171	38H
0005433922647	2125	172	39E
0005433922648	2125	173	39D
0005433922656	2125	174	39F
0005433921760	24131	1	1A
0005432206154	24131	2	1C
0005433035914	24131	3	1B
0005433922016	24131	4	1G
0005433921805	24131	5	2A
0005433922034	24131	6	1H
0005432207642	24131	7	2B
0005432207644	24131	8	2C
0005433035903	24131	9	2G
0005433921667	24131	10	3A
0005433035913	24131	11	2H
0005433921789	24131	12	3B
0005433035941	24131	13	3F
0005433929542	24131	14	3C
0005433921825	24131	15	3H
0005433921816	24131	16	4B
0005433035905	24131	17	4C
0005433922097	24131	18	4G
0005433035904	24131	19	5A
0005433035906	24131	20	4H
0005433921719	24131	21	5B
0005433931418	24131	22	5F
0005433035924	24131	23	5H
0005433929543	24131	24	5G
0005433921704	24131	25	9G
0005433922176	24131	26	11A
0005433035948	24131	27	9H
0005433035945	24131	28	11G
0005433921965	24131	29	11E
0005433035943	24131	30	11H
0005433921944	24131	31	12D
0005433035901	24131	32	12B
0005433921650	24131	33	12G
0005433921649	24131	34	12F
0005433921690	24131	35	12H
0005433921763	24131	36	13B
0005433035907	24131	37	13A
0005434028277	24131	38	13D
0005433922264	24131	39	13E
0005433921651	24131	40	13G
0005433035921	24131	41	13F
0005433921730	24131	42	13H
0005433931415	24131	43	14B
0005433922145	24131	44	14A
0005433921841	24131	45	14E
0005433035900	24131	46	14D
0005433035912	24131	47	14G
0005433921943	24131	48	14H
0005432206156	24131	49	15D
0005432207643	24131	50	15B
0005433035947	24131	51	15E
0005433922082	24131	52	15F
0005433929565	24131	53	15H
0005433921806	24131	54	15G
0005433921813	24131	55	16A
0005433921966	24131	56	16D
0005433035910	24131	57	16B
0005433035931	24131	58	16E
0005433922119	24131	59	16G
0005433035922	24131	60	16H
0005433922223	24131	61	17B
0005432749770	24131	62	17A
0005433035919	24131	63	17D
0005433921630	24131	64	17E
0005433035926	24131	65	17G
0005433921861	24131	66	17F
0005433929548	24131	67	17H
0005433035902	24131	68	18B
0005433921759	24131	69	18D
0005433035930	24131	70	18F
0005433921883	24131	71	18E
0005433921731	24131	72	18H
0005434028279	24131	73	18G
0005433921902	24131	74	19B
0005432749769	24131	75	19E
0005433929545	24131	76	19D
0005433921945	24131	77	19F
0005433921788	24131	78	19G
0005433035915	24131	79	20A
0005433921790	24131	80	19H
0005433921967	24131	81	20B
0005433921773	24131	82	20D
0005433035944	24131	83	20F
0005433035933	24131	84	20E
0005433922042	24131	85	20H
0005433921801	24131	86	21B
0005433035925	24131	87	21F
0005433035934	24131	88	21G
0005433921618	24131	89	22B
0005433921696	24131	90	22A
0005433922033	24131	91	22D
0005433035916	24131	92	22F
0005433035949	24131	93	22G
0005432206153	24131	94	23A
0005433929553	24131	95	22H
0005433035938	24131	96	23B
0005433035899	24131	97	23D
0005432207645	24131	98	23F
0005433921631	24131	99	23H
0005433922068	24131	100	24B
0005433921990	24131	101	24E
0005433921828	24131	102	24D
0005433921797	24131	103	25D
0005433035942	24131	104	24H
0005433035929	24131	105	25F
0005433921978	24131	106	27B
0005433921979	24131	107	27E
0005433035935	24131	108	27D
0005433035927	24131	109	27G
0005432206155	24131	110	27F
0005433035918	24131	111	28A
0005433035936	24131	112	28D
0005433921948	24131	113	28B
0005433921992	24131	114	28E
0005432206151	24131	115	28F
0005433922273	24131	116	28G
0005433921857	24131	117	28H
0005433921964	24131	118	29D
0005433922001	24131	119	29E
0005433922274	24131	120	29F
0005433035950	24131	121	29H
0005433922144	24131	122	30A
0005433921817	24131	123	30D
0005433921698	24131	124	30F
0005433921840	24131	125	30E
0005433921903	24131	126	30G
0005433921960	24131	127	30H
0005433921989	24131	128	31B
0005433931423	24131	129	31E
0005433035897	24131	130	31G
0005433035939	24131	131	32B
0005433035940	24131	132	32E
0005433922035	24131	133	32F
0005433931416	24131	134	32G
0005433921711	24131	135	33A
0005434028278	24131	136	32H
0005433921772	24131	137	33D
0005432206152	24131	138	33F
0005433035917	24131	139	33H
0005433035946	24131	140	33G
0005433921827	24131	141	34D
0005433922069	24131	142	34B
0005433922043	24131	143	34E
0005433922120	24131	144	34G
0005433922083	24131	145	34F
0005433931419	24131	146	34H
0005433035908	24131	147	35B
0005433035923	24131	148	35A
0005433035909	24131	149	35D
0005433035898	24131	150	35F
0005433921991	24131	151	35E
0005433921770	24131	152	35H
0005433922081	24131	153	35G
0005433035932	24131	154	36B
0005433921860	24131	155	36F
0005433921765	24131	156	36E
0005433921764	24131	157	37A
0005433035920	24131	158	36H
0005433035911	24131	159	37B
0005433921824	24131	160	37E
0005433035928	24131	161	37D
0005433921697	24131	162	37F
0005433929544	24131	163	37G
0005433921794	24131	164	38E
0005433035937	24131	165	38F
0005433921812	24131	166	39E
0005433921901	24131	167	39D
0005433921687	24131	168	39F
0005433180707	272	1	1D
0005434550848	272	2	1C
0005434724591	272	3	1A
0005434550851	272	4	1G
0005434724568	272	5	1K
0005434550858	272	6	1H
0005433180702	272	7	2D
0005434735649	272	8	2C
0005433233507	272	9	2A
0005434550845	272	10	2G
0005433233385	272	11	3A
0005433131641	272	12	2K
0005435142483	272	13	3D
0005433233249	272	14	3C
0005433180741	272	15	3G
0005434550862	272	16	4C
0005432277708	272	17	4A
0005433233112	272	18	3K
0005433131640	272	19	4H
0005434724554	272	20	4G
0005434724665	272	21	4D
0005434724636	272	22	5A
0005433233226	272	23	5D
0005434031946	272	24	5C
0005433233239	272	25	5H
0005433180681	272	26	11A
0005433233216	272	27	5K
0005434731135	272	28	11D
0005434724593	272	29	11C
0005433233270	272	30	11F
0005433289741	272	31	12C
0005434724648	272	32	12A
0005434724571	272	33	12D
0005434724653	272	34	12H
0005434724671	272	35	12G
0005433233301	272	36	12F
0005434550833	272	37	13A
0005434724599	272	38	12K
0005432277720	272	39	13D
0005434724622	272	40	13F
0005434731137	272	41	13E
0005434550847	272	42	13H
0005435142475	272	43	14C
0005433111470	272	44	14A
0005434724560	272	45	14D
0005434724629	272	46	14E
0005434550826	272	47	14K
0005433233271	272	48	14H
0005433233215	272	49	15D
0005434550838	272	50	15C
0005434724573	272	51	15A
0005433766578	272	52	15G
0005434724580	272	53	15F
0005432277707	272	54	15K
0005433233252	272	55	16C
0005433233409	272	56	16A
0005435142476	272	57	16F
0005434550856	272	58	16E
0005434724578	272	59	16H
0005433233272	272	60	16G
0005433180714	272	61	17C
0005434724592	272	62	17A
0005433233187	272	63	17E
0005434724640	272	64	17D
0005434724656	272	65	17G
0005434724557	272	66	17F
0005434724563	272	67	18A
0005433233587	272	68	17K
0005433180715	272	69	17H
0005434724652	272	70	18C
0005434550869	272	71	18B
0005434550846	272	72	18E
0005433180774	272	73	18D
0005434550829	272	74	18G
0005434550859	272	75	18F
0005434724609	272	76	18K
0005433233151	272	77	18H
0005434724614	272	78	19B
0005435142481	272	79	19A
0005434735646	272	80	19C
0005434724632	272	81	19F
0005433233384	272	82	19E
0005435142479	272	83	19H
0005434731136	272	84	19K
0005434724666	272	85	20C
0005434724577	272	86	20B
0005435142487	272	87	20E
0005433233227	272	88	20D
0005434724600	272	89	20G
0005434550874	272	90	20F
0005434724588	272	91	20K
0005433233202	272	92	20J
0005434724589	272	93	20H
0005434550827	272	94	21A
0005434724634	272	95	21C
0005433131638	272	96	21F
0005434550861	272	97	21E
0005434724590	272	98	21G
0005434550863	272	99	22A
0005433289733	272	100	21K
0005434724627	272	101	21J
0005433233111	272	102	22C
0005434550836	272	103	22B
0005434724605	272	104	22E
0005434724623	272	105	22D
0005434550864	272	106	22G
0005433233107	272	107	22F
0005434724649	272	108	22J
0005434724556	272	109	22H
0005434724617	272	110	23B
0005434550834	272	111	23A
0005433289759	272	112	23C
0005434724670	272	113	23G
0005434550819	272	114	23F
0005435142482	272	115	23E
0005435142477	272	116	23H
0005433233253	272	117	24D
0005432277714	272	118	23K
0005433180716	272	119	24F
0005434724655	272	120	24E
0005434550867	272	121	24G
0005434550832	272	122	25B
0005433233194	272	123	25F
0005434724631	272	124	25D
0005435142485	272	125	25H
0005434724587	272	126	25G
0005433180655	272	127	25K
0005434550854	272	128	25J
0005434724650	272	129	26C
0005434724582	272	130	26B
0005434550843	272	131	26E
0005433233115	272	132	26D
0005435142480	272	133	26H
0005434724581	272	134	26G
0005433766587	272	135	26J
0005434550853	272	136	27B
0005433180775	272	137	26K
0005434550868	272	138	27D
0005434724610	272	139	27C
0005432277713	272	140	27E
0005434724621	272	141	27H
0005435142474	272	142	27G
0005432277709	272	143	27F
0005433126781	272	144	27J
0005434724553	272	145	28C
0005433180659	272	146	28B
0005434724659	272	147	28A
0005433233148	272	148	28E
0005434724551	272	149	28D
0005434724596	272	150	28G
0005434550870	272	151	28K
0005432277716	272	152	28H
0005434550825	272	153	29A
0005434724658	272	154	29D
0005434724633	272	155	29C
0005434731138	272	156	29B
0005433233346	272	157	29F
0005434724584	272	158	29E
0005434724615	272	159	29K
0005433233162	272	160	30C
0005434724570	272	161	30B
0005433180738	272	162	30A
0005434724585	272	163	30E
0005434724641	272	164	30D
0005433233180	272	165	30G
0005434724558	272	166	30F
0005433233585	272	167	30J
0005434724564	272	168	30H
0005434724549	272	169	31B
0005434550823	272	170	31A
0005433233347	272	171	30K
0005433131637	272	172	31C
0005434724625	272	173	31F
0005433766577	272	174	31E
0005434724661	272	175	31D
0005434724664	272	176	31H
0005434550828	272	177	31G
0005435142486	272	178	32C
0005433289744	272	179	32B
0005433289734	272	180	32E
0005434550866	272	181	32D
0005434550872	272	182	32G
0005434724663	272	183	32F
0005434724569	272	184	32J
0005434724603	272	185	32H
0005433180706	272	186	33A
0005433180694	272	187	33D
0005433180710	272	188	33F
0005433233217	272	189	33E
0005434550830	272	190	33G
0005434724645	272	191	33K
0005434550852	272	192	33J
0005433233196	272	193	34A
0005433233388	272	194	34E
0005434724575	272	195	34D
0005434724601	272	196	34C
0005433233131	272	197	34F
0005434724602	272	198	35B
0005434724673	272	199	35A
0005434724561	272	200	35D
0005432277710	272	201	35C
0005433233236	272	202	35G
0005433113498	272	203	35F
0005434550850	272	204	35K
0005434735648	272	205	35J
0005433233149	272	206	36D
0005434724566	272	207	36C
0005432277712	272	208	36B
0005434550860	272	209	36A
0005434724619	272	210	36F
0005434724660	272	211	36E
0005434724606	272	212	36G
0005434724574	272	213	36K
0005433180677	272	214	36H
0005434550873	272	215	37B
0005433289760	272	216	37A
0005434550822	272	217	37C
0005434724552	272	218	37G
0005432277719	272	219	37F
0005434724604	272	220	37E
0005433233130	272	221	38A
0005434724579	272	222	37K
0005434724613	272	223	38B
0005433233120	272	224	38J
0005434550835	272	225	39B
0005433289761	272	226	39A
0005434724618	272	227	38K
0005434724637	272	228	39D
0005434550820	272	229	39F
0005433233300	272	230	39E
0005434724624	272	231	39J
0005434724607	272	232	39H
0005434735645	272	233	39G
0005434724550	272	234	40A
0005434724620	272	235	40C
0005433233250	272	236	40B
0005434724608	272	237	40D
0005433113499	272	238	40G
0005434724672	272	239	40K
0005433233284	272	240	40J
0005432277717	272	241	40H
0005434550844	272	242	41A
0005433180735	272	243	41D
0005434302427	272	244	41C
0005434724616	272	245	41G
0005434724565	272	246	41F
0005433233584	272	247	41E
0005434724667	272	248	41J
0005433180739	272	249	41H
0005434724654	272	250	42A
0005434724576	272	251	42B
0005434550837	272	252	42E
0005433289743	272	253	42D
0005433180740	272	254	42G
0005434724635	272	255	42F
0005434724639	272	256	42J
0005434724642	272	257	42H
0005434550857	272	258	43B
0005433180811	272	259	42K
0005434724668	272	260	43D
0005433233266	272	261	43C
0005434724611	272	262	43E
0005434302429	272	263	43G
0005435142484	272	264	43K
0005434550871	272	265	43J
0005432277715	272	266	44A
0005434550875	272	267	44E
0005434302428	272	268	44D
0005434724626	272	269	44C
0005434724628	272	270	44H
0005434724646	272	271	44G
0005434724562	272	272	44F
0005433131642	272	273	44J
0005434724595	272	274	45B
0005434724644	272	275	45A
0005433233391	272	276	45D
0005434550840	272	277	45C
0005434724597	272	278	45F
0005434724651	272	279	45E
0005433233269	272	280	45J
0005434550841	272	281	45H
0005433289740	272	282	45G
0005434724594	272	283	46A
0005433233410	272	284	45K
0005434724630	272	285	46C
0005433233244	272	286	46B
0005434724638	272	287	46D
0005434724598	272	288	46G
0005434724572	272	289	46F
0005432277718	272	290	46J
0005433180695	272	291	46H
0005434724583	272	292	47A
0005434550831	272	293	46K
0005434550839	272	294	47D
0005434550824	272	295	47G
0005434724586	272	296	47F
0005434550842	272	297	48A
0005433180705	272	298	47K
0005434724647	272	299	48D
0005434735647	272	300	48C
0005434724555	272	301	48F
0005432277711	272	302	48E
0005434724612	272	303	48H
0005433233186	272	304	49C
0005434724657	272	305	49A
0005433233214	272	306	48K
0005434550821	272	307	49E
0005433233238	272	308	49F
0005433180682	272	309	49H
0005435142478	272	310	49G
0005433113497	272	311	50D
0005434550865	272	312	50C
0005434724669	272	313	50A
0005434550849	272	314	50E
0005434724559	272	315	50G
0005433126777	272	316	51D
0005434550855	272	317	50K
0005434724567	272	318	50H
0005434724643	272	319	51F
0005434724662	272	320	51E
0005433180708	272	321	51G
0005433233742	9825	1	1A
0005434550424	9825	2	1G
0005434723805	9825	3	1D
0005434723658	9825	4	2A
0005433233729	9825	5	1K
0005433180922	9825	6	1H
0005433233740	9825	7	2C
0005433233724	9825	8	2H
0005434550323	9825	9	2G
0005433233749	9825	10	3A
0005434550353	9825	11	2K
0005434550493	9825	12	3D
0005433233751	9825	13	3C
0005434723426	9825	14	3K
0005433233761	9825	15	3H
0005433180932	9825	16	4C
0005434723581	9825	17	4G
0005433180909	9825	18	4D
0005434723456	9825	19	4K
0005434723906	9825	20	4H
0005434550354	9825	21	5A
0005434550506	9825	22	5G
0005434724076	9825	23	5D
0005434550373	9825	24	11C
0005433180924	9825	25	11A
0005434550346	9825	26	5K
0005433233785	9825	27	11D
0005434550364	9825	28	11G
0005434723723	9825	29	11E
0005433233734	9825	30	11K
0005434550369	9825	31	11H
0005434731100	9825	32	12C
0005434550606	9825	33	12A
0005433180918	9825	34	12D
0005433180912	9825	35	12G
0005434550396	9825	36	12F
0005433233777	9825	37	13A
0005433233760	9825	38	12K
0005433233755	9825	39	12H
0005433289793	9825	40	13D
0005434724002	9825	41	13C
0005434723955	9825	42	13F
0005434723899	9825	43	13E
0005433180926	9825	44	13H
0005433129243	9825	45	13K
0005433233748	9825	46	14D
0005433233736	9825	47	14C
0005434550492	9825	48	14G
0005434723588	9825	49	14F
0005434550261	9825	50	14E
0005433233752	9825	51	15C
0005433180928	9825	52	15A
0005435142366	9825	53	15F
0005433180929	9825	54	15E
0005433180920	9825	55	15D
0005433766611	9825	56	15G
0005433289797	9825	57	15H
0005433180907	9825	58	16D
0005433233758	9825	59	16C
0005434550528	9825	60	16F
0005434550294	9825	61	16H
0005434550293	9825	62	16G
0005433233784	9825	63	17C
0005434724255	9825	64	17G
0005434723806	9825	65	17F
0005433180913	9825	66	17E
0005434723476	9825	67	17K
0005434724064	9825	68	17H
0005434723832	9825	69	18B
0005434031992	9825	70	18A
0005433233779	9825	71	18E
0005434723360	9825	72	18D
0005433289794	9825	73	18C
0005434723377	9825	74	18F
0005434724065	9825	75	18K
0005434031994	9825	76	19B
0005434723983	9825	77	19A
0005433180931	9825	78	19D
0005434723556	9825	79	19C
0005434723896	9825	80	19G
0005433233730	9825	81	19J
0005434723797	9825	82	19H
0005434550328	9825	83	19K
0005434550360	9825	84	20C
0005434723425	9825	85	20E
0005434723807	9825	86	20D
0005434723568	9825	87	20G
0005433180906	9825	88	20F
0005434723654	9825	89	20J
0005434723956	9825	90	21B
0005434723884	9825	91	21A
0005434550605	9825	92	21D
0005434731097	9825	93	21C
0005433233733	9825	94	21E
0005434550268	9825	95	21H
0005434550318	9825	96	21G
0005433233772	9825	97	22A
0005434723954	9825	98	21K
0005433233786	9825	99	22C
0005434550305	9825	100	22B
0005433180915	9825	101	22E
0005433180925	9825	102	22G
0005434550302	9825	103	22F
0005433233775	9825	104	22K
0005435142365	9825	105	22J
0005434723380	9825	106	22H
0005434723487	9825	107	23B
0005434723745	9825	108	23A
0005434550394	9825	109	23C
0005434723827	9825	110	23G
0005434723722	9825	111	23E
0005434723662	9825	112	23J
0005434723550	9825	113	24D
0005434724254	9825	114	24F
0005432199199	9825	115	25A
0005434723686	9825	116	24G
0005433113522	9825	117	25D
0005433766614	9825	118	25C
0005434723367	9825	119	25F
0005435142354	9825	120	25J
0005433233768	9825	121	25G
0005433233754	9825	122	25K
0005434723531	9825	123	26A
0005433289791	9825	124	26E
0005434550378	9825	125	26D
0005434723525	9825	126	26K
0005434550532	9825	127	26J
0005434723666	9825	128	26H
0005433180917	9825	129	27B
0005433129245	9825	130	27A
0005433126812	9825	131	27D
0005433233745	9825	132	27J
0005434723526	9825	133	28A
0005433180914	9825	134	27K
0005433180908	9825	135	28E
0005434723477	9825	136	28D
0005434723795	9825	137	28C
0005433233728	9825	138	28G
0005434550450	9825	139	28K
0005434550491	9825	140	28J
0005433126810	9825	141	28H
0005433113520	9825	142	29A
0005433233781	9825	143	29D
0005434723653	9825	144	29C
0005434723322	9825	145	29B
0005433233738	9825	146	29F
0005434723611	9825	147	29E
0005434723838	9825	148	29H
0005434723619	9825	149	29G
0005434723897	9825	150	30A
0005433126813	9825	151	29K
0005432199196	9825	152	30C
0005434723549	9825	153	30E
0005433233743	9825	154	30G
0005433233776	9825	155	30F
0005434723494	9825	156	30K
0005433180927	9825	157	31A
0005433233744	9825	158	31D
0005434723457	9825	159	31C
0005434723663	9825	160	31E
0005434723368	9825	161	31H
0005434723540	9825	162	31G
0005434723834	9825	163	32A
0005434031993	9825	164	31K
0005433180930	9825	165	31J
0005434723803	9825	166	32E
0005434550267	9825	167	32D
0005434723670	9825	168	32G
0005433233771	9825	169	32F
0005434723465	9825	170	32J
0005434723876	9825	171	32H
0005433126809	9825	172	33B
0005433289795	9825	173	33A
0005433766612	9825	174	32K
0005434723950	9825	175	33D
0005434723898	9825	176	33F
0005433233766	9825	177	33E
0005433129244	9825	178	33J
0005434031991	9825	179	33H
0005434723524	9825	180	33G
0005433233750	9825	181	33K
0005433233765	9825	182	34C
0005433129241	9825	183	34B
0005435142343	9825	184	34A
0005433233746	9825	185	34E
0005433233769	9825	186	34D
0005433233737	9825	187	34G
0005434723435	9825	188	34J
0005432199198	9825	189	34H
0005433233782	9825	190	35B
0005434723347	9825	191	35A
0005434723527	9825	192	34K
0005433233762	9825	193	35D
0005434723671	9825	194	35E
0005433233770	9825	195	35J
0005434723589	9825	196	35H
0005433180919	9825	197	36C
0005433233727	9825	198	36A
0005434723376	9825	199	36G
0005434723362	9825	200	36F
0005434723339	9825	201	36K
0005433233726	9825	202	36H
0005434550395	9825	203	37B
0005434724195	9825	204	37A
0005434550324	9825	205	37D
0005433233747	9825	206	37F
0005434550507	9825	207	37H
0005434724087	9825	208	37G
0005433233783	9825	209	38A
0005434723464	9825	210	37K
0005434723659	9825	211	38C
0005434723512	9825	212	38H
0005434550477	9825	213	39A
0005434723340	9825	214	38K
0005433180911	9825	215	39D
0005434723508	9825	216	39C
0005433233756	9825	217	39B
0005434031990	9825	218	39G
0005433126811	9825	219	39F
0005434550332	9825	220	39E
0005433180910	9825	221	39J
0005434723578	9825	222	39H
0005434723984	9825	223	40A
0005433233741	9825	224	40C
0005434723323	9825	225	40B
0005434723669	9825	226	40E
0005434723833	9825	227	40G
0005433233773	9825	228	40F
0005434723361	9825	229	40K
0005434723625	9825	230	40J
0005434724253	9825	231	41A
0005433233753	9825	232	41D
0005433289792	9825	233	41C
0005433233774	9825	234	41G
0005432199200	9825	235	41F
0005434723952	9825	236	41E
0005433233732	9825	237	41H
0005433180916	9825	238	41K
0005433113519	9825	239	41J
0005434723903	9825	240	42C
0005434723364	9825	241	42A
0005434723683	9825	242	42E
0005433233735	9825	243	42D
0005433233757	9825	244	42G
0005432199197	9825	245	42F
0005435142416	9825	246	42H
0005434550372	9825	247	43B
0005434723363	9825	248	43A
0005434723475	9825	249	43D
0005434550303	9825	250	43C
0005434723826	9825	251	43F
0005434723668	9825	252	43E
0005434723553	9825	253	43G
0005434723501	9825	254	43K
0005433289796	9825	255	43J
0005434723664	9825	256	44C
0005434723883	9825	257	44A
0005434723438	9825	258	44E
0005432199201	9825	259	44D
0005434550543	9825	260	44G
0005434723406	9825	261	44F
0005433113521	9825	262	44J
0005433129242	9825	263	44H
0005434550361	9825	264	45B
0005434723953	9825	265	45A
0005434723692	9825	266	45D
0005433233739	9825	267	45C
0005433233767	9825	268	45F
0005434723503	9825	269	45H
0005433233778	9825	270	45K
0005434550478	9825	271	45J
0005434724031	9825	272	46B
0005434550379	9825	273	46C
0005433233725	9825	274	46G
0005434723580	9825	275	46F
0005434723343	9825	276	46J
0005434723555	9825	277	46H
0005433233763	9825	278	47A
0005433180921	9825	279	46K
0005432199195	9825	280	47E
0005434723384	9825	281	47D
0005433180923	9825	282	47G
0005435142336	9825	283	47F
0005434723667	9825	284	47H
0005433766613	9825	285	48D
0005434723485	9825	286	48C
0005434723375	9825	287	48F
0005433233787	9825	288	48G
0005434723486	9825	289	49A
0005434724032	9825	290	49D
0005434723511	9825	291	49C
0005434724152	9825	292	49G
0005434723673	9825	293	49F
0005433233764	9825	294	49H
0005434723684	9825	295	50D
0005433233759	9825	296	50C
0005434723579	9825	297	50A
0005434724106	9825	298	50E
0005433233731	9825	299	50G
0005434723702	9825	300	50F
0005434723675	9825	301	51D
0005434723387	9825	302	50H
0005434723502	9825	303	51F
0005433233780	9825	304	51G
0005434067080	7766	1	1D
0005432527010	7766	2	1C
0005434067064	7766	3	1A
0005435212437	7766	4	1G
0005432533271	7766	5	2A
0005432527053	7766	6	1K
0005432527104	7766	7	1H
0005432526983	7766	8	2D
0005435212787	7766	9	2C
0005435725515	7766	10	2H
0005435212643	7766	11	3A
0005432527004	7766	12	2K
0005432526976	7766	13	3D
0005434067041	7766	14	3C
0005435725534	7766	15	3K
0005432527022	7766	16	3H
0005432527065	7766	17	3G
0005432527073	7766	18	4C
0005435212785	7766	19	4A
0005432069544	7766	20	4G
0005434067076	7766	21	4D
0005435212663	7766	22	5C
0005432527098	7766	23	5A
0005432069548	7766	24	5H
0005432527101	7766	25	5D
0005435212460	7766	26	11A
0005434067033	7766	27	11D
0005432527025	7766	28	11C
0005435212449	7766	29	11F
0005432527089	7766	30	11H
0005434067058	7766	31	11G
0005432527054	7766	32	12C
0005435212558	7766	33	12A
0005435212732	7766	34	12D
0005432527050	7766	35	12G
0005432069549	7766	36	13A
0005435212475	7766	37	12K
0005432428904	7766	38	12H
0005435212501	7766	39	13D
0005434067091	7766	40	13C
0005432526978	7766	41	13F
0005435212461	7766	42	13E
0005432150138	7766	43	13G
0005432527103	7766	44	14D
0005432526979	7766	45	14F
0005435212398	7766	46	14E
0005432527102	7766	47	14K
0005432537042	7766	48	14H
0005434067072	7766	49	15C
0005432535799	7766	50	15A
0005435212361	7766	51	15E
0005434067061	7766	52	15D
0005432069557	7766	53	15G
0005435212452	7766	54	15F
0005432150134	7766	55	15K
0005434067054	7766	56	16C
0005432527006	7766	57	16G
0005432527029	7766	58	16F
0005434067048	7766	59	16E
0005432527085	7766	60	16K
0005432535800	7766	61	16H
0005435212486	7766	62	17A
0005432527020	7766	63	17E
0005434067040	7766	64	17D
0005432527040	7766	65	17C
0005435212644	7766	66	17F
0005435212518	7766	67	17H
0005432527091	7766	68	18C
0005435212662	7766	69	18B
0005435212733	7766	70	18E
0005432527036	7766	71	18G
0005432069547	7766	72	18F
0005435630928	7766	73	18J
0005432526987	7766	74	18H
0005432527001	7766	75	19B
0005432526991	7766	76	19A
0005435212543	7766	77	18K
0005434067090	7766	78	19D
0005432527059	7766	79	19C
0005434067073	7766	80	19G
0005432526998	7766	81	19F
0005432527048	7766	82	19E
0005435212519	7766	83	19J
0005432527076	7766	84	19H
0005435212467	7766	85	19K
0005432069558	7766	86	20C
0005432527064	7766	87	20B
0005435212566	7766	88	20D
0005432535801	7766	89	20G
0005432526993	7766	90	20F
0005434067074	7766	91	20K
0005434067036	7766	92	20J
0005434067047	7766	93	20H
0005435212642	7766	94	21A
0005432527094	7766	95	21D
0005435212533	7766	96	21C
0005435212590	7766	97	21G
0005434067052	7766	98	21F
0005434067038	7766	99	21E
0005433656616	7766	100	21J
0005432527079	7766	101	21H
0005432527075	7766	102	22A
0005432527078	7766	103	21K
0005432527107	7766	104	22C
0005432526999	7766	105	22B
0005432526996	7766	106	22F
0005432533269	7766	107	22E
0005435212532	7766	108	22H
0005432527088	7766	109	22G
0005432527069	7766	110	22J
0005432527038	7766	111	23B
0005434067059	7766	112	23D
0005432535798	7766	113	23C
0005435212774	7766	114	23F
0005432527082	7766	115	23E
0005435212421	7766	116	23J
0005434067055	7766	117	23G
0005435212435	7766	118	23K
0005432527068	7766	119	24F
0005432069553	7766	120	24E
0005432527108	7766	121	25A
0005435725524	7766	122	24G
0005432527087	7766	123	25D
0005432533270	7766	124	25C
0005432527044	7766	125	25F
0005432527042	7766	126	25H
0005432527084	7766	127	26A
0005432527034	7766	128	25K
0005434067077	7766	129	26C
0005434067023	7766	130	26E
0005434067043	7766	131	26D
0005434067086	7766	132	26G
0005432527019	7766	133	26F
0005435212389	7766	134	26J
0005432527097	7766	135	26H
0005432527031	7766	136	27A
0005435212500	7766	137	26K
0005432527046	7766	138	27B
0005432527009	7766	139	27F
0005432527047	7766	140	27D
0005434067082	7766	141	27K
0005432527070	7766	142	27J
0005432527041	7766	143	28B
0005432527014	7766	144	28E
0005432527008	7766	145	28D
0005432527074	7766	146	28G
0005435212586	7766	147	28F
0005432527095	7766	148	28K
0005432527060	7766	149	28H
0005434067032	7766	150	29B
0005432527057	7766	151	29A
0005432526992	7766	152	29D
0005432069551	7766	153	29F
0005432526986	7766	154	29E
0005434067053	7766	155	29J
0005432527051	7766	156	29H
0005435212459	7766	157	29G
0005432527056	7766	158	29K
0005434067063	7766	159	30C
0005434067030	7766	160	30E
0005432527105	7766	161	30D
0005432527013	7766	162	30H
0005435630921	7766	163	30G
0005432527062	7766	164	30F
0005434067044	7766	165	30K
0005432526994	7766	166	31B
0005432527063	7766	167	31D
0005434067068	7766	168	31C
0005432069545	7766	169	31F
0005432526982	7766	170	31E
0005432527080	7766	171	31G
0005432527015	7766	172	32A
0005432150141	7766	173	31J
0005435212619	7766	174	32C
0005435212672	7766	175	32B
0005434067062	7766	176	32E
0005432527055	7766	177	32F
0005432527083	7766	178	32J
0005434067071	7766	179	32H
0005432527037	7766	180	33B
0005435725523	7766	181	33A
0005434067028	7766	182	32K
0005434067069	7766	183	33D
0005435212786	7766	184	33C
0005434067089	7766	185	33F
0005432527067	7766	186	33E
0005435725516	7766	187	34B
0005432527093	7766	188	34A
0005432527005	7766	189	34E
0005434067024	7766	190	34D
0005432069555	7766	191	34C
0005435212339	7766	192	34H
0005435212485	7766	193	34G
0005432527017	7766	194	34F
0005434067060	7766	195	34K
0005432527077	7766	196	35B
0005432526984	7766	197	35A
0005435212534	7766	198	35D
0005434067075	7766	199	35F
0005432428903	7766	200	35E
0005432527099	7766	201	35H
0005435212775	7766	202	35G
0005435212451	7766	203	35K
0005435725530	7766	204	36C
0005432428902	7766	205	36B
0005434067022	7766	206	36A
0005432526997	7766	207	36E
0005434067029	7766	208	36D
0005434067093	7766	209	36H
0005434067049	7766	210	36F
0005435725531	7766	211	36K
0005434067087	7766	212	37B
0005434067046	7766	213	37D
0005432069554	7766	214	37C
0005434067067	7766	215	37G
0005435212436	7766	216	37F
0005435630927	7766	217	37E
0005432527021	7766	218	37H
0005434067057	7766	219	38A
0005435212384	7766	220	37J
0005432527106	7766	221	38C
0005432527043	7766	222	38B
0005434067039	7766	223	38J
0005432150142	7766	224	38H
0005435212535	7766	225	39A
0005432527039	7766	226	38K
0005432150140	7766	227	39D
0005432069546	7766	228	39C
0005432527052	7766	229	39B
0005435212571	7766	230	39F
0005434067085	7766	231	39E
0005432527024	7766	232	39H
0005435212528	7766	233	39G
0005432150139	7766	234	39K
0005435212544	7766	235	39J
0005432526990	7766	236	40A
0005435212673	7766	237	40E
0005432535796	7766	238	40D
0005434067084	7766	239	40G
0005432527109	7766	240	40F
0005435212658	7766	241	40K
0005432527049	7766	242	40J
0005432150135	7766	243	40H
0005432526988	7766	244	41B
0005432527002	7766	245	41C
0005432527090	7766	246	41F
0005432527026	7766	247	41E
0005435212773	7766	248	41H
0005435212393	7766	249	41G
0005434067079	7766	250	42A
0005434067050	7766	251	42C
0005435212567	7766	252	42B
0005432527096	7766	253	42E
0005432527028	7766	254	42D
0005434067092	7766	255	42G
0005432527032	7766	256	42H
0005434067066	7766	257	43B
0005432527035	7766	258	43A
0005434067081	7766	259	42K
0005432527058	7766	260	43C
0005434067031	7766	261	43F
0005432526981	7766	262	43E
0005432527000	7766	263	43H
0005432527030	7766	264	43G
0005432527061	7766	265	44A
0005434067037	7766	266	43K
0005434067045	7766	267	43J
0005432526977	7766	268	44E
0005432527012	7766	269	44D
0005435630922	7766	270	44G
0005432428905	7766	271	44F
0005432527072	7766	272	44K
0005435212385	7766	273	44J
0005432150137	7766	274	44H
0005432527033	7766	275	45B
0005432527023	7766	276	45A
0005432527016	7766	277	45D
0005434067051	7766	278	45C
0005432069550	7766	279	45F
0005432526995	7766	280	45E
0005432527018	7766	281	45H
0005434067027	7766	282	46A
0005434067026	7766	283	45K
0005434067065	7766	284	46B
0005434067034	7766	285	46E
0005434067025	7766	286	46D
0005432526985	7766	287	46C
0005432069556	7766	288	46F
0005435212465	7766	289	46K
0005435212772	7766	290	46J
0005432527011	7766	291	46H
0005432527045	7766	292	47A
0005434067070	7766	293	47E
0005432527100	7766	294	47D
0005432527003	7766	295	47C
0005432527066	7766	296	47G
0005435212493	7766	297	47F
0005432069543	7766	298	47H
0005435212442	7766	299	48D
0005432537043	7766	300	48C
0005434067083	7766	301	48F
0005432527081	7766	302	48E
0005434067088	7766	303	48H
0005432069552	7766	304	48G
0005432527027	7766	305	49A
0005432527007	7766	306	48K
0005434067035	7766	307	49D
0005434067078	7766	308	49C
0005432535797	7766	309	49G
0005434067056	7766	310	49F
0005432526980	7766	311	49E
0005432526989	7766	312	49K
0005435212466	7766	313	50C
0005435212472	7766	314	50A
0005434067042	7766	315	50F
0005432527092	7766	316	50E
0005434067021	7766	317	50H
0005435212779	7766	318	50G
0005435212394	7766	319	50K
0005432527071	7766	320	51E
0005432527086	7766	321	51D
0005432150136	7766	322	51G
0005435423973	5319	1	1C
0005435423858	5319	2	1G
0005435380237	5319	3	1D
0005435423615	5319	4	2A
0005434244577	5319	5	1K
0005435612865	5319	6	1H
0005434343982	5319	7	2G
0005435423919	5319	8	3A
0005434244471	5319	9	2K
0005434573250	5319	10	2H
0005432133099	5319	11	3G
0005435612815	5319	12	3D
0005434343987	5319	13	3C
0005435612905	5319	14	3K
0005435424102	5319	15	4G
0005435612824	5319	16	4D
0005432047523	5319	17	4K
0005435612825	5319	18	5D
0005435490199	5319	19	5C
0005432133104	5319	20	5A
0005435612879	5319	21	5H
0005432133101	5319	22	5G
0005435612831	5319	23	11A
0005435612846	5319	24	11D
0005435612853	5319	25	11F
0005435612875	5319	26	11E
0005434244576	5319	27	11H
0005435612804	5319	28	12C
0005435612855	5319	29	12D
0005432133095	5319	30	12G
0005434573256	5319	31	12F
0005435423784	5319	32	13A
0005435612830	5319	33	12K
0005435612867	5319	34	12H
0005434244469	5319	35	13D
0005432363370	5319	36	13C
0005435423683	5319	37	13F
0005434343979	5319	38	13E
0005435612833	5319	39	13H
0005435612829	5319	40	13G
0005435319454	5319	41	14C
0005434244501	5319	42	14E
0005434343985	5319	43	14D
0005435612864	5319	44	14F
0005434573247	5319	45	14K
0005434343986	5319	46	14H
0005434573260	5319	47	14G
0005435612802	5319	48	15C
0005435612810	5319	49	15A
0005435612873	5319	50	15F
0005435423738	5319	51	15D
0005435612803	5319	52	15K
0005434244575	5319	53	16A
0005435612857	5319	54	16E
0005435423756	5319	55	16K
0005435612832	5319	56	16H
0005432047524	5319	57	17C
0005435612807	5319	58	17G
0005434244508	5319	59	17K
0005435423824	5319	60	17H
0005434343951	5319	61	18B
0005435490201	5319	62	18A
0005435612823	5319	63	18E
0005435423980	5319	64	18D
0005434343977	5319	65	18H
0005435423874	5319	66	18K
0005435612808	5319	67	18J
0005435612843	5319	68	19B
0005435424131	5319	69	19D
0005435319471	5319	70	19E
0005435423773	5319	71	19H
0005435612813	5319	72	19G
0005435612882	5319	73	20A
0005435424016	5319	74	20C
0005435612869	5319	75	20B
0005435612800	5319	76	20E
0005434343968	5319	77	20F
0005434343967	5319	78	20K
0005434573251	5319	79	20J
0005435612811	5319	80	21A
0005435490200	5319	81	21G
0005435612883	5319	82	21F
0005435612837	5319	83	21J
0005432133102	5319	84	21H
0005435423646	5319	85	22C
0005435612889	5319	86	22B
0005435555354	5319	87	22E
0005435612878	5319	88	22D
0005434656529	5319	89	22G
0005435612821	5319	90	22J
0005435612891	5319	91	23B
0005434343984	5319	92	23A
0005434343952	5319	93	22K
0005435612897	5319	94	23C
0005435612902	5319	95	23F
0005433719080	5319	96	23J
0005435424101	5319	97	24D
0005434244487	5319	98	23K
0005434343970	5319	99	24F
0005432363369	5319	100	24E
0005435612858	5319	101	25A
0005435423783	5319	102	25C
0005434244643	5319	103	25B
0005432133110	5319	104	25F
0005435424110	5319	105	25E
0005434573253	5319	106	25H
0005432363368	5319	107	25G
0005435423606	5319	108	25K
0005432133100	5319	109	25J
0005435423678	5319	110	26C
0005434244543	5319	111	26B
0005435423739	5319	112	26A
0005432047522	5319	113	26D
0005435097145	5319	114	26G
0005434343972	5319	115	26F
0005435423672	5319	116	26J
0005435423859	5319	117	26H
0005434244472	5319	118	27B
0005435423797	5319	119	27A
0005435612816	5319	120	26K
0005435612841	5319	121	27C
0005435423686	5319	122	27F
0005435424127	5319	123	27K
0005432047521	5319	124	27J
0005435612863	5319	125	28B
0005435612884	5319	126	28A
0005434244509	5319	127	28D
0005432133105	5319	128	28C
0005435612819	5319	129	28G
0005435423670	5319	130	28F
0005435612887	5319	131	28J
0005435423981	5319	132	28H
0005434343957	5319	133	29A
0005434343955	5319	134	29C
0005435097143	5319	135	29G
0005434343961	5319	136	29F
0005435612861	5319	137	29E
0005435423684	5319	138	29D
0005435612866	5319	139	29H
0005434244493	5319	140	30A
0005435423829	5319	141	29K
0005435612856	5319	142	29J
0005434343950	5319	143	30C
0005435612877	5319	144	30B
0005434244601	5319	145	30G
0005435319438	5319	146	30E
0005435423582	5319	147	30K
0005432133106	5319	148	30J
0005434244554	5319	149	30H
0005435319475	5319	150	31D
0005435319449	5319	151	31F
0005435612859	5319	152	31E
0005435423927	5319	153	31H
0005435424126	5319	154	31G
0005432133098	5319	155	31K
0005435612818	5319	156	31J
0005435612854	5319	157	32B
0005435319444	5319	158	32E
0005435612847	5319	159	32C
0005434343975	5319	160	32F
0005434656522	5319	161	32J
0005434343959	5319	162	32H
0005435423846	5319	163	33B
0005435423720	5319	164	33A
0005434343949	5319	165	32K
0005435612893	5319	166	33D
0005435612899	5319	167	33F
0005435423764	5319	168	33E
0005435612898	5319	169	33H
0005435424247	5319	170	33G
0005435612838	5319	171	33K
0005435612852	5319	172	33J
0005435612848	5319	173	34B
0005434244500	5319	174	34E
0005435424100	5319	175	34C
0005434343973	5319	176	34H
0005435612890	5319	177	34F
0005435424132	5319	178	34J
0005434343983	5319	179	35B
0005434343978	5319	180	34K
0005435612834	5319	181	35D
0005435612809	5319	182	35C
0005435423938	5319	183	35F
0005433719081	5319	184	35E
0005433719083	5319	185	35J
0005435612801	5319	186	35H
0005434343976	5319	187	35G
0005434244603	5319	188	36A
0005435612839	5319	189	35K
0005435612894	5319	190	36C
0005432363371	5319	191	36E
0005435423972	5319	192	36D
0005435612840	5319	193	36G
0005435423719	5319	194	36F
0005435302136	5319	195	36K
0005432133103	5319	196	36J
0005435612844	5319	197	37B
0005435097141	5319	198	37A
0005435612892	5319	199	37D
0005434343963	5319	200	37C
0005435612828	5319	201	37E
0005435612868	5319	202	37J
0005434343953	5319	203	37H
0005434343962	5319	204	37G
0005434573246	5319	205	38A
0005434244542	5319	206	38C
0005435612870	5319	207	38B
0005435423951	5319	208	38J
0005435612826	5319	209	39B
0005434573258	5319	210	39A
0005434656525	5319	211	38K
0005434343954	5319	212	39C
0005434573259	5319	213	39G
0005434244564	5319	214	39E
0005435302124	5319	215	39H
0005435302125	5319	216	40A
0005435612904	5319	217	39K
0005432133107	5319	218	40C
0005435612820	5319	219	40E
0005435319447	5319	220	40D
0005435612836	5319	221	40F
0005434343965	5319	222	40K
0005434573254	5319	223	40J
0005434343971	5319	224	40H
0005435612817	5319	225	41B
0005435612827	5319	226	41A
0005435612851	5319	227	41D
0005432133096	5319	228	41C
0005432133097	5319	229	41F
0005434343958	5319	230	41E
0005435612885	5319	231	41J
0005434343964	5319	232	41H
0005435423655	5319	233	42A
0005435612812	5319	234	41K
0005432133109	5319	235	42C
0005435423804	5319	236	42B
0005435612862	5319	237	42E
0005435097144	5319	238	42D
0005435612896	5319	239	42G
0005435612881	5319	240	42F
0005435423920	5319	241	42K
0005435491427	5319	242	42H
0005435423845	5319	243	43A
0005434343960	5319	244	43D
0005432133108	5319	245	43C
0005435423921	5319	246	43E
0005435423823	5319	247	43H
0005435555355	5319	248	43G
0005434573257	5319	249	44A
0005434343966	5319	250	43J
0005435612814	5319	251	44C
0005435612880	5319	252	44E
0005435612822	5319	253	44G
0005435612806	5319	254	44F
0005435612900	5319	255	44J
0005435490202	5319	256	44H
0005435423766	5319	257	45A
0005435612835	5319	258	44K
0005434343974	5319	259	45D
0005435423798	5319	260	45C
0005435612860	5319	261	45F
0005435423755	5319	262	45E
0005434343969	5319	263	45H
0005435423952	5319	264	45J
0005434343980	5319	265	46A
0005435612901	5319	266	46E
0005435612888	5319	267	46D
0005435423979	5319	268	46H
0005435423803	5319	269	46J
0005434244597	5319	270	47C
0005435612903	5319	271	47A
0005434244574	5319	272	46K
0005435319456	5319	273	47E
0005435491426	5319	274	47G
0005434573252	5319	275	47F
0005434573249	5319	276	47H
0005435612850	5319	277	48D
0005435097142	5319	278	48C
0005435423909	5319	279	48A
0005435612845	5319	280	48E
0005434343981	5319	281	48H
0005435612895	5319	282	48G
0005435612849	5319	283	49A
0005434573255	5319	284	48K
0005434244497	5319	285	49D
0005435612805	5319	286	49C
0005435612842	5319	287	49G
0005434244470	5319	288	49F
0005435612871	5319	289	49E
0005435612874	5319	290	49K
0005435612876	5319	291	50C
0005435612872	5319	292	50A
0005435423932	5319	293	50E
0005434573248	5319	294	50D
0005435319461	5319	295	50G
0005434343956	5319	296	50F
0005435319448	5319	297	51D
0005434244602	5319	298	50H
0005435612886	5319	299	51F
0005435423687	5319	300	51G
0005435612137	10885	1	1A
0005435611995	10885	2	2A
0005435611941	10885	3	1K
0005433719117	10885	4	2D
0005434343587	10885	5	2C
0005435611998	10885	6	2G
0005435424327	10885	7	3A
0005435424315	10885	8	2H
0005435611704	10885	9	3C
0005435424286	10885	10	3H
0005435424305	10885	11	3G
0005434573163	10885	12	4C
0005435611811	10885	13	4A
0005434244784	10885	14	4G
0005435424299	10885	15	4D
0005434573164	10885	16	4K
0005434343588	10885	17	4H
0005435424284	10885	18	5D
0005435611964	10885	19	5A
0005432840998	10885	20	5H
0005435611808	10885	21	5G
0005434244783	10885	22	11A
0005435611857	10885	23	5K
0005435424300	10885	24	11C
0005435424311	10885	25	11E
0005435424348	10885	26	11H
0005435611900	10885	27	12A
0005435612283	10885	28	11K
0005432164986	10885	29	12D
0005434343628	10885	30	12G
0005435611804	10885	31	12H
0005435611875	10885	32	13C
0005434573116	10885	33	13F
0005435612058	10885	34	13E
0005434343645	10885	35	13D
0005435424318	10885	36	13H
0005435612153	10885	37	14A
0005435380261	10885	38	14E
0005435612056	10885	39	14C
0005435611779	10885	40	14G
0005435612077	10885	41	14F
0005435611937	10885	42	14K
0005435611979	10885	43	14H
0005435304123	10885	44	15C
0005435424336	10885	45	15H
0005435424292	10885	46	16A
0005432166879	10885	47	15K
0005435491408	10885	48	16D
0005435424319	10885	49	16C
0005435611767	10885	50	16E
0005434244769	10885	51	16H
0005434343699	10885	52	16G
0005435491412	10885	53	17A
0005435380260	10885	54	17E
0005434343648	10885	55	17D
0005435611869	10885	56	17C
0005434244754	10885	57	17G
0005435611883	10885	58	18A
0005435097089	10885	59	17H
0005435319510	10885	60	18E
0005434244768	10885	61	18D
0005435304124	10885	62	18G
0005434244780	10885	63	18F
0005435611772	10885	64	18J
0005435424340	10885	65	19B
0005435612027	10885	66	19A
0005435611973	10885	67	18K
0005435380262	10885	68	19D
0005435424320	10885	69	19G
0005435424280	10885	70	20A
0005432164980	10885	71	19K
0005435611768	10885	72	20B
0005432164979	10885	73	20E
0005435424298	10885	74	20D
0005434343597	10885	75	20G
0005434343710	10885	76	20F
0005435612035	10885	77	20K
0005435424321	10885	78	20H
0005433719118	10885	79	21B
0005434244766	10885	80	21A
0005435611814	10885	81	21C
0005435611936	10885	82	21G
0005434244771	10885	83	21F
0005434244776	10885	84	21H
0005435611885	10885	85	22A
0005434656542	10885	86	21J
0005433719116	10885	87	22C
0005435424297	10885	88	22B
0005435611967	10885	89	22E
0005434343630	10885	90	22D
0005435611924	10885	91	22H
0005434343621	10885	92	22G
0005432164981	10885	93	22F
0005434573130	10885	94	22J
0005435611809	10885	95	23C
0005434244772	10885	96	23B
0005435319513	10885	97	23A
0005435424322	10885	98	23E
0005435611996	10885	99	23D
0005435424314	10885	100	23F
0005435424288	10885	101	23J
0005435424349	10885	102	23H
0005432363393	10885	103	23G
0005435424313	10885	104	24D
0005434244757	10885	105	23K
0005435424341	10885	106	24F
0005435612105	10885	107	24E
0005435612089	10885	108	24G
0005435424295	10885	109	25F
0005435097063	10885	110	25E
0005434343583	10885	111	25D
0005435424332	10885	112	25G
0005435612260	10885	113	25K
0005434343598	10885	114	25J
0005432363392	10885	115	26C
0005432840997	10885	116	26A
0005435304125	10885	117	26E
0005435424324	10885	118	26D
0005435424283	10885	119	26G
0005434244762	10885	120	26F
0005434244777	10885	121	26J
0005435424338	10885	122	26H
0005435611741	10885	123	27B
0005435611939	10885	124	27F
0005434343684	10885	125	27D
0005435612020	10885	126	27H
0005434244779	10885	127	28A
0005435424345	10885	128	27K
0005434244785	10885	129	27J
0005435304122	10885	130	28C
0005435380263	10885	131	28B
0005435424281	10885	132	28E
0005434244767	10885	133	28D
0005435611813	10885	134	28H
0005435612218	10885	135	28G
0005435424330	10885	136	28F
0005435555343	10885	137	28J
0005434244781	10885	138	29A
0005435611958	10885	139	28K
0005435611807	10885	140	29D
0005435611985	10885	141	29C
0005435612149	10885	142	29B
0005435424337	10885	143	29E
0005435611805	10885	144	29H
0005435611918	10885	145	29G
0005432164985	10885	146	29K
0005435612135	10885	147	29J
0005432166876	10885	148	30C
0005434343609	10885	149	30B
0005435611930	10885	150	30A
0005435612098	10885	151	30E
0005432164984	10885	152	30F
0005434343611	10885	153	30J
0005435611780	10885	154	31B
0005435612316	10885	155	31A
0005434244758	10885	156	30K
0005435612187	10885	157	31C
0005434244764	10885	158	31G
0005435304126	10885	159	31F
0005435611923	10885	160	31H
0005435611781	10885	161	32A
0005434343610	10885	162	31J
0005435611730	10885	163	32E
0005435424287	10885	164	32D
0005435611858	10885	165	32C
0005435611974	10885	166	32G
0005435424308	10885	167	32F
0005434244761	10885	168	32J
0005434573141	10885	169	32H
0005435424317	10885	170	33B
0005435611959	10885	171	32K
0005435042837	10885	172	33D
0005435424333	10885	173	33C
0005435612078	10885	174	33F
0005435612026	10885	175	33H
0005435611812	10885	176	33G
0005435611751	10885	177	33K
0005434244755	10885	178	34B
0005435424291	10885	179	34A
0005435424339	10885	180	34E
0005434343663	10885	181	34D
0005432164982	10885	182	34G
0005435424302	10885	183	34F
0005435612315	10885	184	34J
0005435319509	10885	185	35A
0005435424326	10885	186	35D
0005434244760	10885	187	35F
0005434343599	10885	188	35G
0005435612182	10885	189	36A
0005435612049	10885	190	35K
0005435611997	10885	191	35J
0005435424329	10885	192	36B
0005435424282	10885	193	36E
0005432363391	10885	194	36D
0005435319508	10885	195	36F
0005434573183	10885	196	36K
0005435611971	10885	197	36J
0005435424342	10885	198	37B
0005435611778	10885	199	37A
0005435424306	10885	200	37C
0005435097062	10885	201	37F
0005434244770	10885	202	37E
0005435611934	10885	203	38A
0005434573168	10885	204	37K
0005435491411	10885	205	38C
0005434244759	10885	206	38B
0005435424312	10885	207	38J
0005435319511	10885	208	38H
0005434244774	10885	209	39B
0005434244778	10885	210	39A
0005435611966	10885	211	38K
0005434343631	10885	212	39D
0005435611925	10885	213	39F
0005435424304	10885	214	39H
0005435424309	10885	215	39K
0005435424294	10885	216	39J
0005434244763	10885	217	40C
0005434343589	10885	218	40B
0005435424346	10885	219	40E
0005434573175	10885	220	40D
0005435424344	10885	221	40G
0005435424323	10885	222	40F
0005435611848	10885	223	40K
0005432166877	10885	224	40J
0005435611870	10885	225	40H
0005435424307	10885	226	41B
0005435611892	10885	227	41A
0005435612097	10885	228	41C
0005434244765	10885	229	41F
0005435424293	10885	230	41E
0005435612285	10885	231	42A
0005435042838	10885	232	42D
0005435424285	10885	233	42F
0005435612120	10885	234	42J
0005435097045	10885	235	43B
0005434343606	10885	236	43A
0005435611927	10885	237	43D
0005435612136	10885	238	43C
0005435424290	10885	239	43F
0005434244775	10885	240	43E
0005435424296	10885	241	43J
0005435611742	10885	242	43H
0005435612012	10885	243	43G
0005435611931	10885	244	43K
0005434343703	10885	245	44C
0005435612183	10885	246	44B
0005434343672	10885	247	44A
0005435611705	10885	248	44E
0005435424343	10885	249	44D
0005435424303	10885	250	44G
0005434244756	10885	251	44F
0005434656541	10885	252	44K
0005432166878	10885	253	44H
0005434343605	10885	254	45B
0005435612121	10885	255	45A
0005435424350	10885	256	45D
0005435424316	10885	257	45C
0005435612147	10885	258	45F
0005435424347	10885	259	45E
0005435611929	10885	260	45H
0005435612096	10885	261	45K
0005435424334	10885	262	45J
0005434343673	10885	263	46B
0005435490170	10885	264	46E
0005435612095	10885	265	46D
0005435424310	10885	266	46K
0005435097044	10885	267	46J
0005435612059	10885	268	46H
0005435611926	10885	269	47A
0005435612327	10885	270	47D
0005435611986	10885	271	47C
0005435319512	10885	272	47G
0005435424301	10885	273	47F
0005432164983	10885	274	47E
0005435611957	10885	275	48D
0005435611899	10885	276	48C
0005435612227	10885	277	48F
0005435424289	10885	278	48E
0005435424325	10885	279	48G
0005435611795	10885	280	49C
0005434343664	10885	281	49A
0005435424335	10885	282	48K
0005435611749	10885	283	49D
0005434343649	10885	284	49E
0005434343709	10885	285	49K
0005435612144	10885	286	49G
0005432363394	10885	287	50C
0005435424331	10885	288	50E
0005435319507	10885	289	50D
0005435319506	10885	290	50H
0005435612266	10885	291	50G
0005433719115	10885	292	50F
0005435611773	10885	293	51D
0005435424328	10885	294	51F
0005434244782	10885	295	51E
0005434244773	10885	296	51G
0005432181563	3398	1	1A
0005432458974	3398	2	1C
0005433633590	3398	3	1D
0005432181552	3398	4	1F
0005432459094	3398	5	2C
0005433633592	3398	6	2F
0005432181565	3398	7	2D
0005432181561	3398	8	3C
0005433633598	3398	9	3A
0005432459110	3398	10	3F
0005433633580	3398	11	3D
0005432459034	3398	12	4A
0005433633574	3398	13	4C
0005432459017	3398	14	4D
0005433507053	3398	15	5A
0005433805121	3398	16	4F
0005432181555	3398	17	5D
0005433507046	3398	18	5C
0005433633568	3398	19	5F
0005432458976	3398	20	6D
0005432181566	3398	21	6C
0005433507052	3398	22	7A
0005432459095	3398	23	6F
0005432459151	3398	24	7C
0005432459109	3398	25	7D
0005433633564	3398	26	8C
0005433633588	3398	27	8E
0005432459113	3398	28	8D
0005432459108	3398	29	8F
0005433507055	3398	30	9B
0005432181558	3398	31	9A
0005433633591	3398	32	9C
0005432459131	3398	33	9D
0005432459146	3398	34	9F
0005432459006	3398	35	9E
0005432459156	3398	36	10A
0005433633589	3398	37	10C
0005432458977	3398	38	10B
0005433633569	3398	39	10D
0005432459194	3398	40	10F
0005432181548	3398	41	11A
0005433633585	3398	42	11D
0005433507054	3398	43	11E
0005432181547	3398	44	11F
0005432459055	3398	45	12B
0005432459071	3398	46	12E
0005433805120	3398	47	12D
0005432458983	3398	48	12F
0005432459114	3398	49	13B
0005432459044	3398	50	13A
0005433633577	3398	51	13C
0005432459165	3398	52	13D
0005432459073	3398	53	13F
0005432459093	3398	54	13E
0005432181549	3398	55	14A
0005433633575	3398	56	14B
0005432459058	3398	57	14D
0005433633596	3398	58	14C
0005432459111	3398	59	14E
0005433507047	3398	60	14F
0005433633594	3398	61	15A
0005432459047	3398	62	15E
0005433805125	3398	63	15D
0005433633562	3398	64	15F
0005432459193	3398	65	16A
0005433507051	3398	66	16B
0005433507044	3398	67	16C
0005433633571	3398	68	16E
0005433633570	3398	69	16D
0005433633572	3398	70	16F
0005432459152	3398	71	17C
0005432181568	3398	72	17B
0005433507061	3398	73	17E
0005432458966	3398	74	17D
0005432458994	3398	75	17F
0005432181556	3398	76	18A
0005432459106	3398	77	18B
0005432459054	3398	78	18D
0005432459150	3398	79	18C
0005432181557	3398	80	18E
0005433805124	3398	81	19C
0005432459379	3398	82	19D
0005433507048	3398	83	20A
0005433633573	3398	84	19E
0005433633595	3398	85	20B
0005433507060	3398	86	20C
0005432459166	3398	87	20D
0005433633581	3398	88	20F
0005432181551	3398	89	20E
0005433633584	3398	90	21A
0005432459046	3398	91	21B
0005432181567	3398	92	21E
0005432459155	3398	93	21F
0005433805122	3398	94	22B
0005433805119	3398	95	22A
0005432459053	3398	96	22C
0005432459074	3398	97	22E
0005432459163	3398	98	22D
0005433633582	3398	99	22F
0005432459099	3398	100	23A
0005432459069	3398	101	23B
0005433507043	3398	102	23D
0005433633579	3398	103	23C
0005432181553	3398	104	23E
0005432181559	3398	105	24A
0005433633576	3398	106	23F
0005432181564	3398	107	24B
0005432459010	3398	108	24E
0005432459135	3398	109	24D
0005432459147	3398	110	24F
0005433633593	3398	111	25A
0005433633567	3398	112	25C
0005433507059	3398	113	25B
0005433633586	3398	114	25E
0005432459170	3398	115	25F
0005432458963	3398	116	26B
0005432459169	3398	117	26C
0005433507049	3398	118	26D
0005433633578	3398	119	26E
0005432459157	3398	120	27B
0005433805123	3398	121	27A
0005433633587	3398	122	27C
0005433633566	3398	123	27D
0005433633597	3398	124	27E
0005432459107	3398	125	28A
0005433507057	3398	126	27F
0005432459011	3398	127	28B
0005433507050	3398	128	28D
0005432459270	3398	129	28E
0005432459045	3398	130	28F
0005432181554	3398	131	29B
0005432459138	3398	132	29C
0005432181560	3398	133	29D
0005433633565	3398	134	29F
0005433507058	3398	135	29E
0005432459059	3398	136	30B
0005432458962	3398	137	30A
0005433507056	3398	138	30D
0005433633583	3398	139	30C
0005432458993	3398	140	30E
0005432181562	3398	141	30F
0005433507045	3398	142	31B
0005433633563	3398	143	31A
0005432459086	3398	144	31C
0005432181550	3398	145	31D
0005432459164	3398	146	31E
0005432459271	3398	147	31F
0005435884488	3399	1	1A
0005435884701	3399	2	2D
0005435884690	3399	3	3D
0005435884552	3399	4	4A
0005435884443	3399	5	5F
0005435884717	3399	6	6C
0005435884718	3399	7	6D
0005435884572	3399	8	8A
0005435884604	3399	9	8F
0005435884650	3399	10	9B
0005435884719	3399	11	9C
0005435884789	3399	12	9E
0005435884788	3399	13	10D
0005435884700	3399	14	12A
0005435884431	3399	15	11F
0005435884527	3399	16	12C
0005435884458	3399	17	12F
0005435884581	3399	18	13C
0005435884671	3399	19	14A
0005435884440	3399	20	16E
0005435884656	3399	21	16F
0005435884588	3399	22	18A
0005435884509	3399	23	18E
0005435884670	3399	24	19B
0005435884702	3399	25	20A
0005435884578	3399	26	21A
0005435884439	3399	27	22D
0005435884571	3399	28	22C
0005435884657	3399	29	23A
0005435884790	3399	30	24D
0005435884603	3399	31	24C
0005435884489	3399	32	25A
0005435884587	3399	33	26D
0005435884731	3399	34	28B
0005435884781	3399	35	28D
0005435884524	3399	36	29A
0005435884542	3399	37	29B
0005435884420	3399	38	29D
0005435884549	3399	39	30B
0005435884675	3399	40	30C
0005435884890	8334	1	1A
0005432459533	8334	2	1C
0005432459522	8334	3	1D
0005432459490	8334	4	2C
0005435884871	8334	5	2D
0005435884901	8334	6	3A
0005432459530	8334	7	2F
0005432459526	8334	8	3C
0005435884875	8334	9	4A
0005435884878	8334	10	3F
0005434326267	8334	11	4C
0005432042610	8334	12	4D
0005435884896	8334	13	4F
0005435884899	8334	14	5C
0005435884872	8334	15	5F
0005432459527	8334	16	5D
0005432459514	8334	17	6A
0005432459536	8334	18	6C
0005432042616	8334	19	6F
0005434312307	8334	20	6D
0005432459544	8334	21	7A
0005432459515	8334	22	7C
0005432459525	8334	23	7F
0005432042618	8334	24	7D
0005435884897	8334	25	8A
0005432042622	8334	26	8B
0005432459520	8334	27	8D
0005432459528	8334	28	8C
0005432459543	8334	29	9B
0005432459538	8334	30	9A
0005432459507	8334	31	9E
0005432459504	8334	32	9F
0005435884888	8334	33	10A
0005433506896	8334	34	10B
0005435884894	8334	35	10D
0005432459529	8334	36	10C
0005432459501	8334	37	10E
0005432459516	8334	38	10F
0005432459495	8334	39	11A
0005435884869	8334	40	11E
0005435884895	8334	41	11F
0005432459508	8334	42	12B
0005432459531	8334	43	12C
0005432459505	8334	44	12D
0005432042625	8334	45	12F
0005433506908	8334	46	13B
0005433506928	8334	47	13D
0005435884882	8334	48	13F
0005432459535	8334	49	14C
0005435884881	8334	50	14B
0005432042609	8334	51	14D
0005432459534	8334	52	14E
0005432042619	8334	53	14F
0005435884876	8334	54	15A
0005432459537	8334	55	15C
0005433506882	8334	56	15D
0005432459512	8334	57	15F
0005432459491	8334	58	16A
0005432459519	8334	59	16C
0005434312308	8334	60	16B
0005435884864	8334	61	16D
0005432459524	8334	62	16E
0005432459492	8334	63	17A
0005432459502	8334	64	16F
0005435884886	8334	65	17B
0005432459542	8334	66	17D
0005432042624	8334	67	17F
0005435884870	8334	68	18A
0005432459498	8334	69	18B
0005435884877	8334	70	18C
0005432042613	8334	71	18D
0005435884866	8334	72	18E
0005433506904	8334	73	19E
0005432459539	8334	74	19D
0005432459509	8334	75	19C
0005432042620	8334	76	20B
0005433506866	8334	77	20A
0005435884891	8334	78	20C
0005432459513	8334	79	20D
0005432042611	8334	80	20F
0005433506865	8334	81	20E
0005433506879	8334	82	21A
0005435884874	8334	83	21B
0005435884867	8334	84	21D
0005432459494	8334	85	21C
0005435884889	8334	86	21E
0005432042623	8334	87	21F
0005434312306	8334	88	22B
0005435884880	8334	89	22A
0005432459523	8334	90	22E
0005435884898	8334	91	22D
0005432459521	8334	92	23B
0005432459500	8334	93	23C
0005432459540	8334	94	23E
0005432459496	8334	95	24B
0005432459511	8334	96	24D
0005432459506	8334	97	24C
0005432042615	8334	98	25A
0005432042621	8334	99	25D
0005435884887	8334	100	25E
0005435884873	8334	101	26B
0005432459503	8334	102	26E
0005435884885	8334	103	26F
0005433506862	8334	104	27A
0005432459518	8334	105	27C
0005435884883	8334	106	27B
0005432042614	8334	107	27D
0005432459499	8334	108	28A
0005435884868	8334	109	28D
0005432459510	8334	110	28C
0005435884893	8334	111	28E
0005432459497	8334	112	28F
0005435884865	8334	113	29C
0005432459493	8334	114	29B
0005435884884	8334	115	29D
0005432042612	8334	116	29F
0005432459517	8334	117	29E
0005434326266	8334	118	30A
0005432459532	8334	119	30C
0005432459541	8334	120	30D
0005435884900	8334	121	30F
0005433506912	8334	122	30E
0005435884879	8334	123	31B
0005434312305	8334	124	31C
0005433506892	8334	125	31D
0005435884892	8334	126	31F
0005432042617	8334	127	31E
0005433633240	8340	1	1A
0005433633244	8340	2	1C
0005433804856	8340	3	1F
0005434271275	8340	4	2A
0005433804804	8340	5	4D
0005433633256	8340	6	5D
0005433804952	8340	7	7A
0005433633435	8340	8	7F
0005433633222	8340	9	8A
0005433804817	8340	10	8D
0005433804822	8340	11	8C
0005433633225	8340	12	9C
0005433633224	8340	13	10B
0005433633273	8340	14	10F
0005433804826	8340	15	11C
0005433633274	8340	16	11D
0005433633275	8340	17	12D
0005433633236	8340	18	13D
0005433804839	8340	19	13F
0005433804789	8340	20	13E
0005433804814	8340	21	14C
0005433804816	8340	22	14E
0005433633223	8340	23	15F
0005434143701	8340	24	15E
0005433804846	8340	25	16C
0005433804833	8340	26	17F
0005433804844	8340	27	20A
0005433804838	8340	28	20D
0005433633245	8340	29	21C
0005433633234	8340	30	21F
0005433633221	8340	31	22A
0005434271284	8340	32	22D
0005434271285	8340	33	23B
0005433633335	8340	34	23D
0005433804853	8340	35	24E
0005433633317	8340	36	24F
0005433633319	8340	37	25D
0005433633276	8340	38	28D
0005433804848	8340	39	28F
0005433804925	8340	40	29A
0005433633241	8340	41	29C
0005433804951	8340	42	29D
0005433633299	8340	43	29F
0005433633257	8340	44	31C
0005433804950	8340	45	31D
0005433804825	8340	46	31F
0005434183560	8341	1	5F
0005434183546	8341	2	20E
0005434183545	8341	3	29A
0005432382903	4613	1	1C
0005432382919	4613	2	1D
0005432382896	4613	3	1F
0005432727845	4613	4	2A
0005432382924	4613	5	2D
0005433454861	4613	6	2F
0005432382910	4613	7	3C
0005432382918	4613	8	3D
0005432727852	4613	9	3F
0005432382891	4613	10	4A
0005433454859	4613	11	4E
0005432382920	4613	12	4F
0005432382902	4613	13	5A
0005432382900	4613	14	5C
0005432382905	4613	15	5D
0005432382886	4613	16	5F
0005432382915	4613	17	6A
0005432382890	4613	18	6C
0005432382914	4613	19	6E
0005432382921	4613	20	6F
0005432727855	4613	21	7A
0005432727854	4613	22	7D
0005432382904	4613	23	7E
0005433722171	4613	24	8A
0005432382912	4613	25	8D
0005432382925	4613	26	8F
0005432727850	4613	27	9A
0005432727847	4613	28	9C
0005432382895	4613	29	9D
0005433722174	4613	30	9E
0005433722177	4613	31	9F
0005433722175	4613	32	10A
0005432382892	4613	33	10D
0005432382898	4613	34	11C
0005432382888	4613	35	11D
0005433722173	4613	36	11E
0005432382922	4613	37	12A
0005433722178	4613	38	12D
0005432382907	4613	39	12F
0005433722170	4613	40	13A
0005432727851	4613	41	13D
0005432727848	4613	42	14A
0005433722172	4613	43	14D
0005432382911	4613	44	14E
0005432727849	4613	45	15A
0005432382899	4613	46	15D
0005432382897	4613	47	15E
0005433453749	4613	48	15F
0005432382889	4613	49	16A
0005432382916	4613	50	16C
0005432727846	4613	51	16D
0005432382901	4613	52	16E
0005432382906	4613	53	16F
0005432727844	4613	54	17A
0005433722176	4613	55	17C
0005433454860	4613	56	17E
0005432382923	4613	57	17F
0005432382909	4613	58	18A
0005433454862	4613	59	18C
0005432727856	4613	60	18D
0005432382894	4613	61	18E
0005432382926	4613	62	18F
0005432382887	4613	63	19A
0005432382913	4613	64	19D
0005432727853	4613	65	19F
0005432382917	4613	66	20A
0005432382908	4613	67	20E
0005432382893	4613	68	20F
0005432727729	30098	1	1A
0005432382521	30098	2	1D
0005432382559	30098	3	2A
0005432727760	30098	4	3A
0005432382509	30098	5	3C
0005432382490	30098	6	3F
0005432727731	30098	7	4C
0005433194820	30098	8	4D
0005432727728	30098	9	4E
0005433451591	30098	10	5E
0005432382536	30098	11	5F
0005432382544	30098	12	6D
0005433453729	30098	13	6E
0005432382487	30098	14	7D
0005432382572	30098	15	8A
0005433451586	30098	16	9C
0005432727720	30098	17	9F
0005432382503	30098	18	11A
0005432382484	30098	19	11C
0005432727745	30098	20	11E
0005433451582	30098	21	11F
0005432727730	30098	22	12A
0005432382510	30098	23	12C
0005432382518	30098	24	12D
0005433451592	30098	25	14D
0005432382508	30098	26	14F
0005432382545	30098	27	16A
0005432382519	30098	28	16C
0005432727768	30098	29	16E
0005433194819	30098	30	16F
0005433194825	30098	31	17A
0005432382501	30098	32	18E
0005432727717	30098	33	18F
0005432382507	30098	34	19D
0005433194818	30098	35	20C
0005433451593	30098	36	20E
0005435529116	1719	1	1C
0005433516820	1719	2	1F
0005435540844	1719	3	2F
0005435529113	1719	4	3D
0005435529120	1719	5	3F
0005435529973	1719	6	4C
0005435529102	1719	7	4D
0005435529103	1719	8	4E
0005435540853	1719	9	4F
0005435540861	1719	10	5A
0005435540849	1719	11	5C
0005433516826	1719	12	5D
0005435529101	1719	13	5F
0005433516817	1719	14	6A
0005433516825	1719	15	6C
0005433516818	1719	16	6D
0005435529104	1719	17	7D
0005432924958	1719	18	7F
0005432294470	1719	19	8A
0005435540846	1719	20	8D
0005435540848	1719	21	8F
0005433516821	1719	22	9C
0005435529105	1719	23	9D
0005435540860	1719	24	9F
0005435540856	1719	25	10A
0005435529112	1719	26	10C
0005435540854	1719	27	10D
0005435529107	1719	28	10E
0005435529119	1719	29	10F
0005435529115	1719	30	11A
0005435540851	1719	31	11F
0005435540850	1719	32	12A
0005435529100	1719	33	12C
0005433516824	1719	34	12D
0005432924976	1719	35	12E
0005435529111	1719	36	13A
0005435529117	1719	37	13D
0005432924956	1719	38	13E
0005432294472	1719	39	14A
0005435529108	1719	40	14D
0005435540845	1719	41	14F
0005435529110	1719	42	15C
0005435529118	1719	43	15D
0005435540862	1719	44	15E
0005433516823	1719	45	15F
0005435529109	1719	46	16A
0005435540863	1719	47	17A
0005435540847	1719	48	17C
0005435529106	1719	49	17D
0005435540857	1719	50	17E
0005435540864	1719	51	17F
0005435540852	1719	52	18C
0005435540858	1719	53	18D
0005435529121	1719	54	18E
0005433516819	1719	55	18F
0005432294471	1719	56	19A
0005432924975	1719	57	19D
0005433516822	1719	58	19E
0005435540855	1719	59	20A
0005435540865	1719	60	20C
0005435529114	1719	61	20D
0005435540859	1719	62	20E
0005435517660	21980	1	1C
0005435540702	21980	2	3D
0005435540642	21980	3	4A
0005435540685	21980	4	4C
0005435540728	21980	5	4D
0005435540672	21980	6	4E
0005435517628	21980	7	4F
0005435517680	21980	8	5A
0005432925004	21980	9	6A
0005435540655	21980	10	6D
0005435517687	21980	11	6E
0005433516745	21980	12	6F
0005435517607	21980	13	7A
0005435540671	21980	14	7D
0005435517645	21980	15	8C
0005432925003	21980	16	8E
0005435540664	21980	17	9A
0005435517661	21980	18	9D
0005435540656	21980	19	9E
0005435517611	21980	20	9F
0005435517679	21980	21	10C
0005435540629	21980	22	11A
0005435540663	21980	23	11F
0005435540674	21980	24	12A
0005435540631	21980	25	12C
0005435540729	21980	26	12D
0005435517608	21980	27	13C
0005433516737	21980	28	13D
0005435540632	21980	29	13E
0005435540622	21980	30	13F
0005435540695	21980	31	14A
0005435517707	21980	32	14E
0005435540654	21980	33	15A
0005435517621	21980	34	15C
0005435540697	21980	35	15D
0005435517644	21980	36	15E
0005433516748	21980	37	16A
0005435540684	21980	38	16C
0005433516743	21980	39	16D
0005433516735	21980	40	17A
0005435517626	21980	41	17C
0005432925001	21980	42	18A
0005435517604	21980	43	18C
0005435540686	21980	44	18E
0005432925002	21980	45	19D
0005433516736	21980	46	19E
0005432925000	21980	47	20A
0005435540623	21980	48	20E
0005433516727	21980	49	20F
0005432838829	7405	1	1A
0005432838821	7405	2	1C
0005432838798	7405	3	1D
0005432823434	7405	4	1F
0005432838806	7405	5	2C
0005434458647	7405	6	2D
0005435252410	7405	7	2F
0005432838818	7405	8	3A
0005434664921	7405	9	3D
0005432838813	7405	10	3F
0005434458666	7405	11	4A
0005432838828	7405	12	4C
0005432840996	7405	13	4D
0005432838812	7405	14	4F
0005435252411	7405	15	5A
0005432838815	7405	16	5C
0005435252463	7405	17	5D
0005432838802	7405	18	5F
0005435252427	7405	19	6C
0005432838807	7405	20	6A
0005432073366	7405	21	6D
0005432073365	7405	22	6F
0005435252464	7405	23	7A
0005432838817	7405	24	7C
0005432840995	7405	25	7D
0005432073367	7405	26	7E
0005432838822	7405	27	8A
0005434458656	7405	28	8D
0005432838810	7405	29	8E
0005432838800	7405	30	8F
0005432073364	7405	31	9A
0005432838808	7405	32	9C
0005432838826	7405	33	9D
0005434458661	7405	34	9F
0005432838799	7405	35	10A
0005432838827	7405	36	10C
0005435252424	7405	37	10D
0005434458660	7405	38	10E
0005434458658	7405	39	10F
0005432838819	7405	40	11A
0005435252412	7405	41	11C
0005432838801	7405	42	11E
0005434458662	7405	43	11D
0005434458657	7405	44	11F
0005432838825	7405	45	12A
0005434458663	7405	46	12C
0005434458651	7405	47	12D
0005435252397	7405	48	12E
0005435252422	7405	49	13A
0005432073368	7405	50	13C
0005434458665	7405	51	13D
0005432838803	7405	52	13E
0005434458650	7405	53	13F
0005435252423	7405	54	14A
0005434458655	7405	55	14C
0005435252465	7405	56	14D
0005432838804	7405	57	14E
0005432823433	7405	58	14F
0005432838816	7405	59	15A
0005432838809	7405	60	15C
0005434458652	7405	61	15F
0005432073369	7405	62	16D
0005432838823	7405	63	16E
0005434458648	7405	64	16F
0005432838805	7405	65	17A
0005432838814	7405	66	17D
0005435252443	7405	67	17E
0005435252421	7405	68	17F
0005432073370	7405	69	18A
0005432838811	7405	70	18C
0005435252450	7405	71	18D
0005435252398	7405	72	18E
0005434458653	7405	73	18F
0005434458649	7405	74	19A
0005435252466	7405	75	19C
0005434458664	7405	76	19D
0005432838820	7405	77	19E
0005434458659	7405	78	19F
0005435252449	7405	79	20A
0005432838830	7405	80	20C
0005432838824	7405	81	20D
0005435252408	7405	82	20E
0005434458654	7405	83	20F
0005432840980	28946	1	1C
0005435252565	28946	2	1F
0005435252577	28946	3	2C
0005435252580	28946	4	2D
0005432838565	28946	5	2F
0005435252567	28946	6	3A
0005432838616	28946	7	3C
0005432840985	28946	8	3D
0005434458509	28946	9	3F
0005432838589	28946	10	4A
0005435252582	28946	11	4E
0005432838596	28946	12	5A
0005434458516	28946	13	5C
0005432838513	28946	14	5D
0005434664945	28946	15	5E
0005435252574	28946	16	5F
0005432838574	28946	17	6A
0005432001008	28946	18	6C
0005434458479	28946	19	6D
0005435252566	28946	20	6E
0005435491429	28946	21	6F
0005432838613	28946	22	7A
0005432840981	28946	23	7C
0005432838564	28946	24	7D
0005432838614	28946	25	7E
0005435491428	28946	26	7F
0005432838525	28946	27	8A
0005435252569	28946	28	8D
0005432838593	28946	29	8E
0005432840986	28946	30	8F
0005435252568	28946	31	9A
0005432838575	28946	32	9C
0005434458456	28946	33	9D
0005434458437	28946	34	9F
0005434664943	28946	35	10A
0005432838485	28946	36	10D
0005432823416	28946	37	10E
0005434458508	28946	38	10F
0005432838618	28946	39	11A
0005434458467	28946	40	11C
0005432838615	28946	41	11E
0005434458455	28946	42	12D
0005434458487	28946	43	12E
0005434664944	28946	44	12F
0005434458531	28946	45	13A
0005432838498	28946	46	13C
0005432838592	28946	47	13D
0005432838590	28946	48	13E
0005434458470	28946	49	13F
0005432838788	28946	50	14A
0005432838583	28946	51	14D
0005435252572	28946	52	15C
0005434458506	28946	53	15D
0005432840982	28946	54	15F
0005435252583	28946	55	16A
0005435252573	28946	56	16C
0005434458433	28946	57	16E
0005432838588	28946	58	16F
0005435252578	28946	59	17C
0005435252576	28946	60	17D
0005434458468	28946	61	17E
0005435252579	28946	62	18A
0005435252575	28946	63	18C
0005434458436	28946	64	18D
0005432838584	28946	65	18E
0005434458435	28946	66	18F
0005432001009	28946	67	19C
0005435252570	28946	68	19D
0005434458457	28946	69	19E
0005434458532	28946	70	20A
0005435252571	28946	71	20C
0005434458505	28946	72	20D
0005435252581	28946	73	20E
0005432838595	28946	74	20F
0005435990573	8822	1	2D
0005434275936	8822	2	3C
0005434275967	8822	3	4C
0005435990572	8822	4	5D
0005435990575	8822	5	6D
0005434275937	8822	6	8B
0005434275947	8822	7	10D
0005434275934	8822	8	11B
0005435990574	8822	9	11E
0005435990570	8822	10	12A
0005435990577	8822	11	13D
0005434275959	8822	12	13F
0005435990569	8822	13	14C
0005435990576	8822	14	16E
0005435990571	8822	15	18B
0005434275950	8822	16	18D
0005434275935	8822	17	21E
0005435990521	15719	1	1D
0005434275988	15719	2	2D
0005435990512	15719	3	4A
0005435990513	15719	4	5C
0005434275983	15719	5	5A
0005435990510	15719	6	6A
0005434275989	15719	7	6D
0005434275985	15719	8	6F
0005434275984	15719	9	7E
0005435990515	15719	10	11E
0005435990532	15719	11	12A
0005434275986	15719	12	16B
0005435990511	15719	13	17A
0005434275987	15719	14	18C
0005432427125	20637	1	1B
0005432427126	20637	2	4A
0005432427128	20637	3	18B
0005432427129	20637	4	18C
0005433476863	20637	5	20A
0005433476862	20637	6	23A
0005432427127	20637	7	23B
0005435490170	6375	1	1A
0005432360045	6375	2	1D
0005432360030	6375	3	1F
0005434149551	6375	4	2C
0005432335953	6375	5	2A
0005434149542	6375	6	2D
0005434149521	6375	7	2F
0005434149534	6375	8	3D
0005435176600	6375	9	3C
0005434149553	6375	10	3F
0005432335946	6375	11	4B
0005434149580	6375	12	4A
0005432335950	6375	13	4C
0005435176587	6375	14	4D
0005432360026	6375	15	4F
0005432360043	6375	16	4E
0005432335944	6375	17	5B
0005432360014	6375	18	5C
0005432360040	6375	19	5E
0005432360021	6375	20	5F
0005435176705	6375	21	6C
0005432360007	6375	22	6E
0005432360036	6375	23	6D
0005432335954	6375	24	7A
0005435176685	6375	25	7B
0005432360020	6375	26	7D
0005434149526	6375	27	7F
0005435176657	6375	28	7E
0005432360038	6375	29	8A
0005432360011	6375	30	8B
0005432360003	6375	31	8C
0005432335947	6375	32	8E
0005432359998	6375	33	8D
0005432360044	6375	34	8F
0005432360009	6375	35	9A
0005432360019	6375	36	9B
0005432360010	6375	37	9D
0005432062190	6375	38	9C
0005432363393	6375	39	9E
0005435176599	6375	40	9F
0005432363391	6375	41	10B
0005432360013	6375	42	10C
0005435176726	6375	43	10D
0005435176691	6375	44	11A
0005432360035	6375	45	10E
0005432360039	6375	46	11B
0005434149528	6375	47	11C
0005432360016	6375	48	11E
0005432360008	6375	49	11F
0005432360027	6375	50	12A
0005432360023	6375	51	12B
0005435176725	6375	52	12D
0005432360032	6375	53	12C
0005432360028	6375	54	12E
0005432062188	6375	55	12F
0005432360004	6375	56	13C
0005432360031	6375	57	13B
0005432360033	6375	58	13D
0005432360018	6375	59	13E
0005432360041	6375	60	13F
0005432335943	6375	61	14C
0005432360022	6375	62	14B
0005435176659	6375	63	14F
0005434149557	6375	64	15A
0005435176653	6375	65	15C
0005434149567	6375	66	15D
0005432360012	6375	67	15E
0005432360025	6375	68	16B
0005434149520	6375	69	16A
0005432062192	6375	70	16C
0005432363392	6375	71	16E
0005432360015	6375	72	16D
0005435176586	6375	73	16F
0005435176724	6375	74	17A
0005432360029	6375	75	17B
0005432335948	6375	76	17C
0005435176758	6375	77	18A
0005432062193	6375	78	17F
0005432360002	6375	79	18B
0005435176672	6375	80	18D
0005432335952	6375	81	18C
0005432360024	6375	82	18E
0005432360001	6375	83	19A
0005432062189	6375	84	19C
0005432359999	6375	85	19B
0005432360042	6375	86	19D
0005432335949	6375	87	19F
0005432335951	6375	88	20A
0005435176695	6375	89	20B
0005432062191	6375	90	20C
0005432360017	6375	91	21A
0005432360037	6375	92	20F
0005435176656	6375	93	21B
0005432360046	6375	94	21D
0005432360000	6375	95	21C
0005432363394	6375	96	21F
0005435723010	6375	97	21E
0005432335945	6375	98	22B
0005434149556	6375	99	22D
0005434149543	6375	100	22F
0005432062194	6375	101	22E
0005432360005	6375	102	23A
0005432360006	6375	103	23B
0005434149527	6375	104	23D
0005434149555	6375	105	23E
0005432360034	6375	106	23F
0005432335875	21029	1	1A
0005432359571	21029	2	1D
0005434149650	21029	3	2C
0005432052724	21029	4	2A
0005432359707	21029	5	2D
0005432335844	21029	6	3C
0005432359631	21029	7	3F
0005432359736	21029	8	3D
0005432363384	21029	9	4A
0005435176884	21029	10	4B
0005432359545	21029	11	4D
0005435176891	21029	12	4E
0005432363361	21029	13	4F
0005435176870	21029	14	5B
0005434149644	21029	15	5C
0005432359535	21029	16	5E
0005435490203	21029	17	5F
0005432359704	21029	18	6B
0005432335886	21029	19	6A
0005432052725	21029	20	6C
0005432359592	21029	21	6F
0005432359508	21029	22	6E
0005435176887	21029	23	7A
0005435176883	21029	24	7C
0005432359674	21029	25	7B
0005432359726	21029	26	7F
0005435490206	21029	27	8A
0005435176885	21029	28	8B
0005435176869	21029	29	8D
0005435176872	21029	30	8C
0005434149643	21029	31	8F
0005432359541	21029	32	9C
0005434149646	21029	33	9E
0005434149648	21029	34	9D
0005432359656	21029	35	9F
0005432359661	21029	36	10C
0005435490207	21029	37	10B
0005432335837	21029	38	10D
0005435176878	21029	39	11A
0005435490204	21029	40	10E
0005434149640	21029	41	11B
0005435176882	21029	42	11D
0005435723031	21029	43	11C
0005432359699	21029	44	11E
0005435176875	21029	45	11F
0005432359697	21029	46	12A
0005435176892	21029	47	12B
0005432335846	21029	48	12E
0005432335829	21029	49	12F
0005432359721	21029	50	13A
0005432335838	21029	51	13C
0005432359593	21029	52	13B
0005432359642	21029	53	13D
0005432359632	21029	54	13E
0005432359600	21029	55	13F
0005434149645	21029	56	14B
0005432335851	21029	57	14D
0005432359722	21029	58	14E
0005435176876	21029	59	15A
0005435176888	21029	60	14F
0005435176893	21029	61	15B
0005435176886	21029	62	15D
0005435176879	21029	63	15E
0005432359539	21029	64	16B
0005434149647	21029	65	16A
0005432359789	21029	66	16C
0005434149641	21029	67	16E
0005434149642	21029	68	16D
0005432359594	21029	69	16F
0005432359507	21029	70	17B
0005432335871	21029	71	17A
0005432359660	21029	72	17C
0005435723032	21029	73	17E
0005432359673	21029	74	17D
0005432335855	21029	75	17F
0005435176880	21029	76	18B
0005435176881	21029	77	18D
0005435490205	21029	78	19A
0005434149649	21029	79	19C
0005432359735	21029	80	19B
0005435176890	21029	81	19E
0005432359670	21029	82	19F
0005432359544	21029	83	20A
0005435176874	21029	84	20B
0005432359790	21029	85	20E
0005435176867	21029	86	21B
0005435176894	21029	87	21C
0005435176877	21029	88	21D
0005432359662	21029	89	21F
0005434149651	21029	90	21E
0005435176871	21029	91	22A
0005435176873	21029	92	22B
0005432335845	21029	93	22C
0005435176889	21029	94	23A
0005435176868	21029	95	23C
0005432359540	21029	96	23F
0005434458504	17738	1	1A
0005434458454	17738	2	1B
0005434458483	17738	3	1D
0005434463894	17738	4	2A
0005434458501	17738	5	2C
0005434458458	17738	6	3A
0005434458591	17738	7	3B
0005434458563	17738	8	3C
0005434458546	17738	9	3D
0005434458485	17738	10	4A
0005434458459	17738	11	4B
0005434458446	17738	12	4D
0005434458447	17738	13	4C
0005434458460	17738	14	5B
0005434186179	17738	15	5C
0005434458484	17738	16	5D
0005434458541	17738	17	6B
0005434463893	17738	18	6C
0005434458542	17738	19	6D
0005434458488	17738	20	7A
0005434458533	17738	21	7B
0005434458590	17738	22	7C
0005434461615	17738	23	18A
0005434463895	17738	24	18B
0005434458497	17738	25	19A
0005434458472	17738	26	19B
0005434458521	17738	27	19C
0005434458486	17738	28	19D
0005434448261	17738	29	20A
0005434458482	17738	30	20B
0005434461614	17738	31	20C
0005434458564	17738	32	20D
0005434186178	17738	33	21B
0005434448271	17738	34	21C
0005434458477	17738	35	21D
0005434458473	17738	36	22A
0005434458539	17738	37	22B
0005434458502	17738	38	22C
0005434458503	17738	39	22D
0005434458498	17738	40	23A
0005434458547	17738	41	23B
0005434448286	29134	1	1C
0005434448287	29134	2	1D
0005434458653	29134	3	2A
0005434463912	29134	4	2B
0005434458652	29134	5	2C
0005434458665	29134	6	3A
0005434458664	29134	7	3D
0005434458648	29134	8	4A
0005434448289	29134	9	4C
0005434458649	29134	10	4D
0005434458650	29134	11	5A
0005434458666	29134	12	5B
0005434458659	29134	13	5C
0005434458663	29134	14	5D
0005434458660	29134	15	6B
0005434463911	29134	16	6C
0005434462773	29134	17	6D
0005434458662	29134	18	7B
0005434448285	29134	19	7C
0005434458655	29134	20	18A
0005434458657	29134	21	18B
0005434458647	29134	22	19C
0005434463913	29134	23	19D
0005434458661	29134	24	20A
0005434458656	29134	25	20B
0005434458658	29134	26	21A
0005434462772	29134	27	21B
0005434458651	29134	28	21D
0005434458654	29134	29	21C
0005434448288	29134	30	22A
0005432604006	21412	1	1A
0005432604030	21412	2	1B
0005432604011	21412	3	1D
0005432604029	21412	4	2A
0005432604016	21412	5	2C
0005432604028	21412	6	2D
0005432604041	21412	7	3B
0005432604036	21412	8	3C
0005432604032	21412	9	4A
0005432604009	21412	10	3D
0005432604010	21412	11	4C
0005432604040	21412	12	4D
0005432604045	21412	13	5A
0005432604042	21412	14	5B
0005432604013	21412	15	5C
0005432604033	21412	16	5D
0005432604023	21412	17	6A
0005432604025	21412	18	6B
0005432604015	21412	19	6C
0005432604017	21412	20	6D
0005432604026	21412	21	7B
0005432604019	21412	22	18A
0005432604012	21412	23	18B
0005432604027	21412	24	18C
0005432604043	21412	25	19A
0005432604021	21412	26	19B
0005432604008	21412	27	19C
0005432604031	21412	28	19D
0005432604035	21412	29	20A
0005432604024	21412	30	20B
0005432604014	21412	31	20C
0005432604020	21412	32	20D
0005432604022	21412	33	21B
0005432604046	21412	34	21C
0005432604044	21412	35	21D
0005432604018	21412	36	22A
0005432604007	21412	37	22B
0005432604034	21412	38	22C
0005432604039	21412	39	22D
0005432604038	21412	40	23A
0005432604037	21412	41	23B
0005432603698	31708	1	1A
0005432603704	31708	2	1C
0005432603759	31708	3	2A
0005432603742	31708	4	2B
0005432603703	31708	5	3B
0005432603772	31708	6	3D
0005432603690	31708	7	4C
0005432603735	31708	8	4D
0005432603670	31708	9	5B
0005435221048	31708	10	5C
0005432603760	31708	11	6B
0005432603689	31708	12	6C
0005432603833	31708	13	6D
0005432603750	31708	14	7C
0005432603683	31708	15	7D
0005432603696	31708	16	18A
0005432603730	31708	17	18C
0005435221510	31708	18	19A
0005432603801	31708	19	19C
0005432603677	31708	20	20A
0005435221049	31708	21	20B
0005432603815	31708	22	20C
0005432603741	31708	23	21A
0005432603669	31708	24	21D
0005432603729	31708	25	22C
0005432603807	31708	26	22D
0005432603793	31708	27	23A
0005435221509	31708	28	23B
0005433293143	12310	1	21D
0005434606772	18868	1	2A
0005434606778	18868	2	2B
0005434606777	18868	3	3B
0005435904893	18868	4	4A
0005434606761	18868	5	6A
0005434604869	22342	1	1A
0005434606798	22342	2	1B
0005434606799	22342	3	2B
0005434606801	22342	4	3A
0005434606800	22342	5	5A
0005434604870	22342	6	6A
0005432747283	427	1	1A
0005432890726	427	2	1C
0005432747284	427	3	2A
0005432747282	427	4	2C
0005432747263	427	5	2D
0005432747278	427	6	3A
0005435154591	427	7	3D
0005432890808	427	8	4A
0005432747269	427	9	4D
0005432747266	427	10	4E
0005432747291	427	11	4F
0005432747264	427	12	5D
0005432747281	427	13	5E
0005432753273	427	14	5F
0005432747294	427	15	6C
0005432751498	427	16	6D
0005432751499	427	17	6E
0005432747265	427	18	6F
0005432747271	427	19	7A
0005433293157	427	20	7C
0005432890708	427	21	7D
0005432747270	427	22	7E
0005432890709	427	23	7F
0005432747276	427	24	8A
0005432219971	427	25	8C
0005432747268	427	26	8D
0005432751500	427	27	8E
0005432751501	427	28	8F
0005432753275	427	29	9A
0005432749768	427	30	9E
0005432890728	427	31	10A
0005432890686	427	32	10D
0005432749767	427	33	10E
0005432747274	427	34	10F
0005432890672	427	35	11A
0005433293144	427	36	11C
0005432747259	427	37	11D
0005432747267	427	38	11E
0005432890744	427	39	11F
0005432890730	427	40	12A
0005432890700	427	41	12C
0005432747285	427	42	12D
0005432890725	427	43	12E
0005432747272	427	44	13A
0005432219969	427	45	13C
0005432890714	427	46	13E
0005432747275	427	47	13F
0005433293155	427	48	14A
0005432219970	427	49	14C
0005432747293	427	50	14E
0005432747287	427	51	14F
0005432219972	427	52	15C
0005435627115	427	53	15E
0005432747297	427	54	15F
0005432747295	427	55	16A
0005432890727	427	56	16D
0005432747290	427	57	16E
0005432747260	427	58	16F
0005432747296	427	59	17A
0005432219973	427	60	17C
0005432747273	427	61	17D
0005432890712	427	62	17E
0005432747262	427	63	17F
0005432747277	427	64	18C
0005432890745	427	65	18D
0005432747279	427	66	18E
0005432747261	427	67	18F
0005432747292	427	68	19C
0005435627114	427	69	19E
0005432747288	427	70	19F
0005432753274	427	71	20A
0005432747286	427	72	20C
0005433293145	427	73	20D
0005432747289	427	74	20E
0005432747280	427	75	20F
0005432747032	12087	1	1C
0005432746957	12087	2	1D
0005432747138	12087	3	1F
0005432746869	12087	4	2C
0005432747009	12087	5	2D
0005432890875	12087	6	2F
0005432747074	12087	7	3C
0005432746971	12087	8	3D
0005432747071	12087	9	3F
0005432890880	12087	10	4A
0005432756788	12087	11	4C
0005432890881	12087	12	4D
0005432746920	12087	13	4E
0005432890874	12087	14	4F
0005432890872	12087	15	5A
0005432746908	12087	16	5C
0005432747031	12087	17	5E
0005432890884	12087	18	5F
0005432747104	12087	19	6A
0005433875367	12087	20	6C
0005432747015	12087	21	6D
0005433293203	12087	22	6E
0005432746977	12087	23	6F
0005432746990	12087	24	7A
0005433293204	12087	25	7C
0005432756789	12087	26	7D
0005432890870	12087	27	7E
0005432747065	12087	28	7F
0005432747101	12087	29	8C
0005432214787	12087	30	8D
0005432746958	12087	31	8E
0005432746923	12087	32	8F
0005433293201	12087	33	9A
0005432890877	12087	34	9C
0005432890889	12087	35	9D
0005432746944	12087	36	9F
0005432747073	12087	37	10C
0005432753254	12087	38	10D
0005432890878	12087	39	10E
0005433293199	12087	40	10F
0005432756807	12087	41	11A
0005432753253	12087	42	11D
0005432746956	12087	43	11F
0005432746987	12087	44	12A
0005432746953	12087	45	12C
0005433293207	12087	46	12D
0005432747062	12087	47	12E
0005433293200	12087	48	12F
0005432747072	12087	49	13A
0005432747030	12087	50	13C
0005432890873	12087	51	13D
0005432890887	12087	52	13E
0005432890885	12087	53	13F
0005432746933	12087	54	14A
0005432890883	12087	55	14C
0005433293198	12087	56	14D
0005432890888	12087	57	14E
0005432747033	12087	58	14F
0005432746970	12087	59	15E
0005432890876	12087	60	15F
0005432890882	12087	61	16A
0005432753251	12087	62	16D
0005432214788	12087	63	16E
0005432747016	12087	64	16F
0005432746874	12087	65	17C
0005432746955	12087	66	17D
0005432746981	12087	67	17E
0005433293202	12087	68	17F
0005433293208	12087	69	18A
0005432890871	12087	70	18C
0005432747026	12087	71	18D
0005432890879	12087	72	18E
0005432746998	12087	73	18F
0005432746950	12087	74	19A
0005432746976	12087	75	19C
0005433293206	12087	76	19D
0005432753244	12087	77	19E
0005433293205	12087	78	19F
0005433293209	12087	79	20A
0005432890886	12087	80	20C
0005432746943	12087	81	20D
0005432746942	12087	82	20E
0005432746951	12087	83	20F
0005433524951	18983	1	1A
0005432927893	18983	2	1C
0005432927913	18983	3	2A
0005433533278	18983	4	2B
0005432927890	18983	5	3A
0005432927912	18983	6	3C
0005433524955	18983	7	3B
0005432927885	18983	8	3D
0005433531261	18983	9	4C
0005433531263	18983	10	5B
0005432927900	18983	11	5C
0005433524956	18983	12	7A
0005433533276	18983	13	6D
0005432927899	18983	14	7C
0005433524950	18983	15	18B
0005433524946	18983	16	18C
0005433524952	18983	17	19A
0005432927906	18983	18	19B
0005433524949	18983	19	19C
0005433524947	18983	20	19D
0005433531262	18983	21	20A
0005432927910	18983	22	20D
0005433524953	18983	23	21A
0005433533277	18983	24	21B
0005433531264	18983	25	22A
0005433524948	18983	26	23A
0005433524954	18983	27	23B
0005433531231	32463	1	1A
0005433524895	32463	2	1D
0005433524871	32463	3	2D
0005433524854	32463	4	3D
0005432927944	32463	5	4B
0005432927945	32463	6	4D
0005432927946	32463	7	5A
0005432927948	32463	8	5D
0005433524880	32463	9	6D
0005432927947	32463	10	7D
0005433524882	32463	11	18D
0005433524906	32463	12	19B
0005433524879	32463	13	19D
0005432927943	32463	14	20A
0005433524894	32463	15	20B
0005432927942	32463	16	20D
0005433524907	32463	17	21A
0005433531232	32463	18	22A
0005433531233	32463	19	22B
0005433524878	32463	20	23B
0005434664941	5271	1	1A
0005434822647	5271	2	1G
0005434822633	5271	3	1D
0005434822728	5271	4	2A
0005434822623	5271	5	1K
0005435372298	5271	6	1H
0005434822729	5271	7	2D
0005434822637	5271	8	3D
0005435149930	5271	9	3G
0005434822723	5271	10	4C
0005434822709	5271	11	3K
0005434822669	5271	12	4G
0005434822619	5271	13	4D
0005435149935	5271	14	4K
0005435149927	5271	15	5A
0005434822695	5271	16	5G
0005434828675	5271	17	11A
0005434822610	5271	18	5K
0005434822675	5271	19	11D
0005432121228	5271	20	11G
0005435735062	5271	21	11F
0005435372129	5271	22	11E
0005434822665	5271	23	12C
0005434822738	5271	24	12A
0005434831111	5271	25	12D
0005434822704	5271	26	12G
0005432121230	5271	27	12F
0005435149931	5271	28	13A
0005435372518	5271	29	12K
0005435372490	5271	30	12H
0005434822684	5271	31	13D
0005434822668	5271	32	13C
0005434822679	5271	33	13E
0005435386476	5271	34	13H
0005435372242	5271	35	14A
0005434822636	5271	36	14D
0005434822718	5271	37	14G
0005434828674	5271	38	14F
0005434822680	5271	39	14H
0005435735066	5271	40	15C
0005434822656	5271	41	15A
0005432121236	5271	42	15D
0005434822614	5271	43	15G
0005434822697	5271	44	16A
0005434831110	5271	45	16F
0005435372124	5271	46	16K
0005432121240	5271	47	16H
0005435372169	5271	48	16G
0005434822713	5271	49	17D
0005434822629	5271	50	17G
0005435372388	5271	51	17K
0005434822626	5271	52	18A
0005434822648	5271	53	18D
0005435372300	5271	54	18G
0005434822661	5271	55	18K
0005434822685	5271	56	18J
0005435372441	5271	57	18H
0005434822678	5271	58	19B
0005435149933	5271	59	19A
0005434822644	5271	60	19D
0005435372205	5271	61	19F
0005434822672	5271	62	19J
0005434822715	5271	63	20A
0005434822708	5271	64	20E
0005435372161	5271	65	20G
0005434822617	5271	66	20F
0005434822707	5271	67	20J
0005435372353	5271	68	21A
0005434558217	5271	69	20K
0005434822691	5271	70	21D
0005434822649	5271	71	21B
0005435372318	5271	72	21E
0005434822724	5271	73	21G
0005434822620	5271	74	22A
0005434822705	5271	75	21K
0005434822640	5271	76	22C
0005434822622	5271	77	22D
0005434822694	5271	78	22G
0005434822650	5271	79	22K
0005434822662	5271	80	22J
0005434822667	5271	81	23E
0005435372167	5271	82	23C
0005434831112	5271	83	23H
0005434822616	5271	84	23G
0005434822673	5271	85	24D
0005435372305	5271	86	25A
0005434822664	5271	87	25C
0005435149929	5271	88	25G
0005432823427	5271	89	26A
0005434822674	5271	90	25J
0005434822641	5271	91	26C
0005434822716	5271	92	26B
0005434822733	5271	93	26H
0005435372219	5271	94	26G
0005434822687	5271	95	26F
0005435372196	5271	96	26J
0005434822727	5271	97	27B
0005434558218	5271	98	27A
0005434822717	5271	99	27D
0005434822689	5271	100	27F
0005435735063	5271	101	27E
0005434822660	5271	102	27K
0005434822734	5271	103	28B
0005435372185	5271	104	28A
0005434822737	5271	105	28G
0005434822671	5271	106	28F
0005435149932	5271	107	29B
0005434822711	5271	108	29D
0005432121231	5271	109	29C
0005434822681	5271	110	29F
0005435372101	5271	111	30C
0005432396212	5271	112	30B
0005435372387	5271	113	30A
0005434822706	5271	114	30D
0005434822621	5271	115	30G
0005435372299	5271	116	30J
0005434822730	5271	117	31B
0005434822702	5271	118	31A
0005434558215	5271	119	31D
0005435299709	5271	120	31C
0005434822690	5271	121	31F
0005434822736	5271	122	31E
0005435299708	5271	123	31H
0005432121238	5271	124	32C
0005434822659	5271	125	32A
0005434822701	5271	126	32G
0005432121226	5271	127	32J
0005435372304	5271	128	32H
0005434822677	5271	129	32K
0005434822703	5271	130	33B
0005435372130	5271	131	33E
0005434831113	5271	132	34A
0005434822720	5271	133	34B
0005434822732	5271	134	34E
0005432121235	5271	135	34D
0005435735055	5271	136	34F
0005434822652	5271	137	34K
0005434822712	5271	138	35B
0005435372341	5271	139	35A
0005432121234	5271	140	35E
0005434822645	5271	141	35G
0005434822634	5271	142	36A
0005435386477	5271	143	35J
0005434822688	5271	144	36D
0005434822698	5271	145	36E
0005434822725	5271	146	36G
0005435299702	5271	147	36J
0005434822625	5271	148	37B
0005434822710	5271	149	37A
0005434822686	5271	150	36K
0005434822682	5271	151	37D
0005434822654	5271	152	37F
0005435149934	5271	153	37E
0005435149936	5271	154	37J
0005435372111	5271	155	38C
0005432121232	5271	156	38B
0005434822628	5271	157	38H
0005434558212	5271	158	39B
0005434822653	5271	159	39D
0005432394076	5271	160	39F
0005435372269	5271	161	39E
0005434822657	5271	162	39H
0005434822663	5271	163	39G
0005435372322	5271	164	40B
0005435372256	5271	165	40F
0005434822630	5271	166	40G
0005434822611	5271	167	40J
0005434558214	5271	168	40H
0005434558213	5271	169	41B
0005434822655	5271	170	41A
0005435372255	5271	171	40K
0005435372321	5271	172	41D
0005434822651	5271	173	41C
0005434822632	5271	174	41F
0005434822719	5271	175	41E
0005435386499	5271	176	41J
0005434822627	5271	177	41G
0005434822692	5271	178	42F
0005434822683	5271	179	42E
0005434822714	5271	180	42G
0005434822624	5271	181	42J
0005435372302	5271	182	42H
0005434822699	5271	183	43A
0005434664942	5271	184	43D
0005434822618	5271	185	43B
0005434558211	5271	186	43F
0005434822646	5271	187	43E
0005434822638	5271	188	43G
0005434822726	5271	189	44C
0005434822666	5271	190	44D
0005434822721	5271	191	44G
0005432121229	5271	192	44F
0005435372195	5271	193	44J
0005434558216	5271	194	44H
0005434822613	5271	195	45B
0005434822643	5271	196	45A
0005434822609	5271	197	45D
0005434664940	5271	198	45E
0005432396213	5271	199	45G
0005434822631	5271	200	45K
0005432394074	5271	201	45J
0005434822612	5271	202	46A
0005435179688	5271	203	46D
0005434822696	5271	204	46G
0005435372297	5271	205	46F
0005434822658	5271	206	46J
0005432396214	5271	207	46H
0005434822731	5271	208	47C
0005432121237	5271	209	46K
0005432396215	5271	210	47E
0005434822615	5271	211	47D
0005434822735	5271	212	47G
0005432121239	5271	213	48A
0005432121233	5271	214	47K
0005434822700	5271	215	47H
0005434822676	5271	216	48C
0005432121227	5271	217	48F
0005434831114	5271	218	48E
0005434822635	5271	219	48H
0005435372168	5271	220	48G
0005435299711	5271	221	48K
0005435735061	5271	222	49D
0005432394075	5271	223	49E
0005434822639	5271	224	50C
0005434822670	5271	225	49K
0005434822722	5271	226	50D
0005435149928	5271	227	50G
0005434822693	5271	228	51D
0005435372123	5271	229	50K
0005434822642	5271	230	51F
0005432394073	5271	231	51G
0005435372822	9934	1	1G
0005434821586	9934	2	1K
0005435372767	9934	3	1H
0005435372770	9934	4	2C
0005435372801	9934	5	2G
0005435372791	9934	6	2D
0005435372795	9934	7	2K
0005434821520	9934	8	3D
0005435372772	9934	9	3C
0005434822019	9934	10	3K
0005435299742	9934	11	3H
0005435372761	9934	12	4C
0005434821952	9934	13	4A
0005435372779	9934	14	4G
0005435386528	9934	15	4D
0005434822131	9934	16	4K
0005435372806	9934	17	4H
0005432823436	9934	18	5C
0005435372823	9934	19	5A
0005435372825	9934	20	5H
0005435372789	9934	21	5G
0005435372799	9934	22	5K
0005434828653	9934	23	11C
0005434822096	9934	24	11G
0005434821449	9934	25	12A
0005435372807	9934	26	12E
0005435372763	9934	27	12H
0005435372821	9934	28	13A
0005434821838	9934	29	12K
0005434821611	9934	30	13D
0005434821612	9934	31	13C
0005435372783	9934	32	13E
0005434821940	9934	33	13H
0005435372781	9934	34	13G
0005435149818	9934	35	14A
0005434821736	9934	36	13K
0005434822130	9934	37	14G
0005435372811	9934	38	14F
0005435372818	9934	39	14H
0005435372797	9934	40	14K
0005434821777	9934	41	15E
0005434821446	9934	42	15H
0005434821462	9934	43	15G
0005434821717	9934	44	15F
0005435372800	9934	45	16C
0005434821941	9934	46	16G
0005435372768	9934	47	16F
0005435149789	9934	48	16E
0005434821747	9934	49	16K
0005435302165	9934	50	17C
0005435149838	9934	51	17A
0005435372816	9934	52	17D
0005434822315	9934	53	17E
0005435372784	9934	54	17K
0005434821729	9934	55	18B
0005435372774	9934	56	18D
0005434821340	9934	57	18G
0005435386527	9934	58	18F
0005434821789	9934	59	18H
0005435386526	9934	60	19B
0005434821801	9934	61	19A
0005435372820	9934	62	19D
0005434821778	9934	63	19F
0005435372792	9934	64	19E
0005435149791	9934	65	19K
0005435372814	9934	66	20C
0005434821629	9934	67	20E
0005434821857	9934	68	20D
0005435386529	9934	69	20J
0005434821633	9934	70	20H
0005435735106	9934	71	21A
0005434821939	9934	72	20K
0005435372785	9934	73	21D
0005434821450	9934	74	21F
0005435372812	9934	75	21H
0005434821624	9934	76	22A
0005435372769	9934	77	22D
0005434822204	9934	78	22C
0005434821888	9934	79	22B
0005434821519	9934	80	22E
0005435299743	9934	81	22H
0005434822399	9934	82	22J
0005435372778	9934	83	23B
0005435661912	9934	84	22K
0005434821784	9934	85	23C
0005435372782	9934	86	23G
0005435372805	9934	87	23F
0005435372762	9934	88	23E
0005434822046	9934	89	23H
0005435372794	9934	90	24D
0005434831075	9934	91	23K
0005434821897	9934	92	25B
0005434664928	9934	93	25A
0005434821540	9934	94	24G
0005435372803	9934	95	25D
0005434821620	9934	96	25F
0005434821539	9934	97	25E
0005435299740	9934	98	25H
0005435149819	9934	99	25K
0005434821787	9934	100	25J
0005434821459	9934	101	26C
0005434821837	9934	102	26J
0005435372815	9934	103	27A
0005434821318	9934	104	26K
0005434821512	9934	105	27C
0005434558140	9934	106	27F
0005434821595	9934	107	27H
0005434821427	9934	108	27G
0005432203011	9934	109	27J
0005435372775	9934	110	28C
0005435149803	9934	111	28B
0005434822032	9934	112	28A
0005434821448	9934	113	28G
0005434821718	9934	114	28F
0005434821542	9934	115	28J
0005432203009	9934	116	29B
0005435302166	9934	117	29A
0005434822017	9934	118	29D
0005435372798	9934	119	29F
0005435372826	9934	120	29E
0005435149814	9934	121	29J
0005435735108	9934	122	30B
0005435179390	9934	123	30E
0005434821732	9934	124	30J
0005432203013	9934	125	31B
0005434822033	9934	126	31A
0005434821896	9934	127	30K
0005434821734	9934	128	31C
0005434821455	9934	129	31F
0005434821485	9934	130	31H
0005435299739	9934	131	31K
0005434821314	9934	132	31J
0005434821344	9934	133	32C
0005435386530	9934	134	32E
0005435372813	9934	135	32G
0005435372760	9934	136	32F
0005435372796	9934	137	32K
0005434821675	9934	138	33B
0005435372765	9934	139	33A
0005434664927	9934	140	33C
0005434821543	9934	141	33E
0005435372819	9934	142	33J
0005435372787	9934	143	34B
0005434821376	9934	144	34F
0005435372802	9934	145	34H
0005434664926	9934	146	35A
0005434821890	9934	147	35B
0005435372777	9934	148	35F
0005432203014	9934	149	35J
0005435149792	9934	150	36A
0005434821630	9934	151	35K
0005435149804	9934	152	36F
0005435372793	9934	153	36J
0005435372790	9934	154	37B
0005434831070	9934	155	37A
0005434821550	9934	156	37D
0005435735107	9934	157	37G
0005434821742	9934	158	37H
0005434821614	9934	159	38A
0005434821513	9934	160	37J
0005434821639	9934	161	38C
0005434828652	9934	162	38K
0005434821800	9934	163	39A
0005435372776	9934	164	39D
0005435372824	9934	165	39C
0005434558144	9934	166	39B
0005434821463	9934	167	39J
0005434821730	9934	168	40A
0005432823435	9934	169	39K
0005434821456	9934	170	40F
0005434821735	9934	171	40E
0005435735105	9934	172	40D
0005432203010	9934	173	40G
0005434821756	9934	174	40J
0005435372804	9934	175	41A
0005434821615	9934	176	41D
0005435302167	9934	177	41G
0005434558143	9934	178	42A
0005434821451	9934	179	42C
0005434821695	9934	180	42B
0005434821460	9934	181	42E
0005435372766	9934	182	42G
0005434821428	9934	183	42F
0005434821465	9934	184	42K
0005435372817	9934	185	43A
0005434821640	9934	186	43C
0005435372808	9934	187	43F
0005434821594	9934	188	43E
0005435661910	9934	189	43D
0005435372764	9934	190	43H
0005434821676	9934	191	43G
0005435386525	9934	192	44C
0005432203012	9934	193	44B
0005434821694	9934	194	44E
0005435372786	9934	195	44F
0005435372788	9934	196	44K
0005434821677	9934	197	44H
0005434821585	9934	198	45D
0005434822018	9934	199	45C
0005435372780	9934	200	45B
0005434821610	9934	201	45F
0005434831076	9934	202	45E
0005434821623	9934	203	45J
0005435302164	9934	204	45H
0005435149820	9934	205	46C
0005435179689	9934	206	46A
0005435372771	9934	207	46D
0005435149813	9934	208	46G
0005435149858	9934	209	46F
0005434821628	9934	210	46J
0005435372773	9934	211	47A
0005434821454	9934	212	47E
0005434821785	9934	213	47D
0005435661911	9934	214	47F
0005434558142	9934	215	47K
0005434821928	9934	216	48A
0005434821599	9934	217	48F
0005435372810	9934	218	48D
0005435372809	9934	219	48K
0005434821407	9934	220	49E
0005435149790	9934	221	49D
0005435299741	9934	222	49C
0005434821863	9934	223	49G
0005435735109	9934	224	50C
0005434821843	9934	225	50D
0005434664929	9934	226	50K
0005434821466	9934	227	51F
0005434821641	9934	228	51E
0005435082731	7028	1	1D
0005435790285	7028	2	2B
0005435082728	7028	3	3A
0005435082732	7028	4	3B
0005435082734	7028	5	6C
0005435790286	7028	6	7C
0005435790284	7028	7	7D
0005435082733	7028	8	18C
0005435082730	7028	9	21B
0005435082729	7028	10	22C
0005435082735	7028	11	22D
0005435082652	26014	1	2A
0005435790266	26014	2	2C
0005435082653	26014	3	3C
0005435082650	26014	4	5B
0005435082674	26014	5	6C
0005435790267	26014	6	7A
0005435082673	26014	7	19D
0005434756153	9554	1	1C
0005434756147	9554	2	1D
0005434756129	9554	3	1F
0005434213763	9554	4	2A
0005434213822	9554	5	2C
0005434756158	9554	6	2D
0005434756151	9554	7	3A
0005434756167	9554	8	3C
0005434756146	9554	9	3D
0005434213714	9554	10	4A
0005434213713	9554	11	4D
0005434756156	9554	12	4E
0005434756135	9554	13	4F
0005434213843	9554	14	5A
0005434756121	9554	15	5D
0005434213730	9554	16	5F
0005434756125	9554	17	6A
0005434756119	9554	18	6C
0005434756123	9554	19	6F
0005434756134	9554	20	7A
0005434756133	9554	21	7C
0005434756142	9554	22	7E
0005434756162	9554	23	7F
0005434756141	9554	24	8A
0005434756127	9554	25	8C
0005434756131	9554	26	8D
0005434756128	9554	27	8E
0005434756143	9554	28	8F
0005434756139	9554	29	9C
0005434756145	9554	30	9D
0005434213774	9554	31	9E
0005434213708	9554	32	9F
0005434213724	9554	33	10A
0005434213723	9554	34	10C
0005434213703	9554	35	10D
0005434756144	9554	36	10F
0005434756132	9554	37	11A
0005434213788	9554	38	11C
0005434756159	9554	39	11D
0005434213737	9554	40	11E
0005434756154	9554	41	11F
0005434756138	9554	42	12A
0005434756124	9554	43	12C
0005434213702	9554	44	12E
0005434213865	9554	45	13A
0005434213727	9554	46	13C
0005434213789	9554	47	13E
0005434756155	9554	48	13D
0005434756165	9554	49	13F
0005434756126	9554	50	14A
0005434756163	9554	51	14D
0005434756136	9554	52	14F
0005434756152	9554	53	14E
0005434213787	9554	54	15A
0005434756120	9554	55	15C
0005434213898	9554	56	15D
0005434213709	9554	57	15E
0005434213775	9554	58	15F
0005434756122	9554	59	16A
0005434756161	9554	60	16C
0005434756157	9554	61	16D
0005434213710	9554	62	16E
0005434756140	9554	63	16F
0005434756160	9554	64	17C
0005434756130	9554	65	17D
0005434213866	9554	66	17E
0005434213808	9554	67	17F
0005434213844	9554	68	18A
0005434756164	9554	69	18C
0005434756166	9554	70	18F
0005434756149	9554	71	19C
0005434756148	9554	72	19D
0005434756137	9554	73	19E
0005434213711	9554	74	20A
0005434213704	9554	75	20C
0005434213722	9554	76	20D
0005434756150	9554	77	20E
0005434213764	9554	78	20F
0005434755770	28588	1	1A
0005434214146	28588	2	2A
0005434214150	28588	3	2C
0005434214147	28588	4	2D
0005434755727	28588	5	2F
0005434214152	28588	6	3A
0005434214149	28588	7	3C
0005434214173	28588	8	3D
0005434214153	28588	9	3F
0005434214154	28588	10	4A
0005434755706	28588	11	4D
0005434214165	28588	12	4F
0005434755762	28588	13	5A
0005434214170	28588	14	5E
0005434755738	28588	15	6A
0005434214127	28588	16	6D
0005434755766	28588	17	6E
0005434755756	28588	18	6F
0005434214137	28588	19	7A
0005434214148	28588	20	7C
0005434214134	28588	21	7D
0005434214162	28588	22	7E
0005434755772	28588	23	7F
0005434755726	28588	24	8C
0005434214144	28588	25	8D
0005434755748	28588	26	8E
0005434755769	28588	27	9A
0005434214136	28588	28	9C
0005434214155	28588	29	9D
0005434214171	28588	30	9E
0005434214167	28588	31	9F
0005434755707	28588	32	10A
0005434755712	28588	33	10C
0005434214157	28588	34	10D
0005434214159	28588	35	10F
0005434755711	28588	36	11A
0005434214135	28588	37	11C
0005434214130	28588	38	11D
0005434214143	28588	39	12D
0005434214145	28588	40	12E
0005434214138	28588	41	12F
0005434214132	28588	42	13A
0005434214169	28588	43	13C
0005434214163	28588	44	13D
0005434214168	28588	45	13E
0005434755759	28588	46	13F
0005434214172	28588	47	14C
0005434214131	28588	48	14E
0005434214128	28588	49	14F
0005434755760	28588	50	15F
0005434214140	28588	51	16C
0005434755750	28588	52	16E
0005434214156	28588	53	16F
0005434214158	28588	54	17A
0005434214142	28588	55	17C
0005434214160	28588	56	17D
0005434755771	28588	57	17E
0005434755763	28588	58	18A
0005434214166	28588	59	18C
0005434755705	28588	60	18D
0005434755742	28588	61	19A
0005434214141	28588	62	19C
0005434755757	28588	63	19D
0005434214164	28588	64	19E
0005434214129	28588	65	19F
0005434214151	28588	66	20C
0005434214139	28588	67	20D
0005434214161	28588	68	20E
0005434214133	28588	69	20F
0005435100101	10841	1	1A
0005434760158	10841	2	3A
0005435100102	10841	3	20B
0005435100100	10841	4	22B
0005434760180	31827	1	5D
0005435100082	31827	2	6A
0005435100081	31827	3	6B
0005434639135	1973	1	1A
0005434639131	1973	2	1C
0005434639149	1973	3	1D
0005434639141	1973	4	2A
0005435948319	1973	5	2B
0005434639152	1973	6	2D
0005434639143	1973	7	3A
0005432290612	1973	8	3B
0005434639147	1973	9	3C
0005433202124	1973	10	3D
0005433202163	1973	11	4A
0005432290610	1973	12	4C
0005433202176	1973	13	4D
0005434639127	1973	14	5A
0005434639137	1973	15	5B
0005434639151	1973	16	5C
0005434639136	1973	17	5D
0005434639153	1973	18	6A
0005434639139	1973	19	6B
0005435948318	1973	20	6C
0005433202103	1973	21	6D
0005434639148	1973	22	7A
0005432290613	1973	23	7B
0005432290611	1973	24	7C
0005434639129	1973	25	7D
0005434639144	1973	26	18A
0005434639132	1973	27	18B
0005433202127	1973	28	18C
0005435948317	1973	29	19A
0005434639126	1973	30	19B
0005434639146	1973	31	19C
0005434639150	1973	32	19D
0005434639140	1973	33	20A
0005434639128	1973	34	20B
0005432290614	1973	35	20D
0005434639130	1973	36	21B
0005434639134	1973	37	21C
0005433202134	1973	38	22A
0005434639133	1973	39	22B
0005433202128	1973	40	22C
0005434639145	1973	41	22D
0005434639142	1973	42	23A
0005434639138	1973	43	23B
0005433202242	23276	1	1A
0005433202244	23276	2	1B
0005434638874	23276	3	1C
0005433202247	23276	4	2B
0005433202239	23276	5	2C
0005434638892	23276	6	2D
0005435948306	23276	7	3A
0005434638935	23276	8	3C
0005434638868	23276	9	5A
0005433202250	23276	10	5B
0005434638856	23276	11	5C
0005434638932	23276	12	5D
0005433202245	23276	13	6A
0005435948305	23276	14	6B
0005434638875	23276	15	6C
0005434638934	23276	16	7A
0005434638867	23276	17	7B
0005433202241	23276	18	18A
0005433202240	23276	19	18D
0005433202251	23276	20	19A
0005434638976	23276	21	19B
0005433202252	23276	22	19D
0005433202248	23276	23	20C
0005434638869	23276	24	21A
0005433202249	23276	25	21B
0005434638849	23276	26	21C
0005433202243	23276	27	22A
0005434638891	23276	28	22B
0005434638872	23276	29	22C
0005434638873	23276	30	23A
0005433202246	23276	31	23B
0005435326581	6062	1	1A
0005433533282	6062	2	1D
0005433533279	6062	3	3A
0005434600609	6062	4	3C
0005434600622	6062	5	3D
0005433531265	6062	6	4A
0005434600624	6062	7	4C
0005435326534	6062	8	4D
0005435326537	6062	9	5A
0005434600608	6062	10	5C
0005434600610	6062	11	5D
0005434600628	6062	12	5F
0005434600623	6062	13	7A
0005435326514	6062	14	7F
0005435326505	6062	15	8D
0005433531267	6062	16	9A
0005432111257	6062	17	9D
0005434600618	6062	18	10E
0005435326550	6062	19	10F
0005434600603	6062	20	11A
0005434600617	6062	21	11C
0005434600625	6062	22	11D
0005434600607	6062	23	11E
0005434600627	6062	24	11F
0005434600615	6062	25	12A
0005434600605	6062	26	12C
0005433533281	6062	27	12F
0005433531268	6062	28	13C
0005434600621	6062	29	14A
0005434600606	6062	30	14E
0005434600620	6062	31	15D
0005434600613	6062	32	15E
0005435326497	6062	33	16A
0005434600619	6062	34	16D
0005434600604	6062	35	16E
0005432111258	6062	36	16F
0005435326533	6062	37	17A
0005434600612	6062	38	17F
0005433533280	6062	39	18A
0005435326538	6062	40	18C
0005434600616	6062	41	18E
0005434600629	6062	42	19C
0005434600614	6062	43	19D
0005433531266	6062	44	19E
0005434600626	6062	45	20A
0005435326580	6062	46	20C
0005434600611	6062	47	20D
0005435326513	6062	48	20F
0005434600424	18611	1	1C
0005434600363	18611	2	1F
0005434600343	18611	3	2A
0005434600335	18611	4	2F
0005434600362	18611	5	3A
0005434600342	18611	6	3C
0005434600375	18611	7	3D
0005434600457	18611	8	4A
0005435326645	18611	9	4C
0005435326652	18611	10	5A
0005434600364	18611	11	6A
0005434600425	18611	12	6C
0005433531248	18611	13	6E
0005434600419	18611	14	7A
0005434600365	18611	15	7D
0005434600452	18611	16	8A
0005434600454	18611	17	9A
0005434600436	18611	18	9F
0005434600412	18611	19	10A
0005435326649	18611	20	10D
0005435326640	18611	21	10F
0005435326651	18611	22	11A
0005435326646	18611	23	11C
0005435326641	18611	24	11D
0005433531235	18611	25	11E
0005434600396	18611	26	12F
0005435326642	18611	27	13A
0005435326653	18611	28	13C
0005433531247	18611	29	14A
0005435326650	18611	30	14E
0005435326644	18611	31	14F
0005433531236	18611	32	15D
0005434600354	18611	33	16F
0005435326643	18611	34	17D
0005435326648	18611	35	17F
0005434600344	18611	36	18A
0005434600455	18611	37	18E
0005435326647	18611	38	20A
0005433531240	18611	39	20D
0005434558206	10574	1	1A
0005434550779	10574	2	1F
0005434550775	10574	3	2A
0005433180769	10574	4	2C
0005434550790	10574	5	2D
0005434550793	10574	6	2F
0005434550796	10574	7	3A
0005433180726	10574	8	3F
0005434550766	10574	9	4A
0005434550810	10574	10	4C
0005433180673	10574	11	4D
0005434550776	10574	12	4F
0005433180713	10574	13	5A
0005434550800	10574	14	5C
0005434550806	10574	15	5D
0005433180651	10574	16	5E
0005434558205	10574	17	5F
0005434558207	10574	18	6A
0005434550798	10574	19	6C
0005434550792	10574	20	6D
0005433180674	10574	21	6E
0005434554047	10574	22	6F
0005434550771	10574	23	7A
0005433180712	10574	24	7E
0005434550801	10574	25	7F
0005434550812	10574	26	8A
0005433180685	10574	27	8C
0005434550799	10574	28	8D
0005434550788	10574	29	8E
0005434550815	10574	30	8F
0005434554048	10574	31	9A
0005434550770	10574	32	9C
0005434558210	10574	33	9E
0005434558208	10574	34	9F
0005434550797	10574	35	10A
0005433180684	10574	36	10D
0005434550774	10574	37	10E
0005433180650	10574	38	10F
0005434550773	10574	39	11C
0005434558209	10574	40	11D
0005434550794	10574	41	11E
0005434550791	10574	42	11F
0005434550805	10574	43	12A
0005434550795	10574	44	12C
0005434550782	10574	45	12D
0005434550764	10574	46	12E
0005433180661	10574	47	12F
0005434550769	10574	48	13A
0005434550804	10574	49	13C
0005433180664	10574	50	13D
0005434550765	10574	51	13F
0005433180686	10574	52	14A
0005434550780	10574	53	14C
0005434550803	10574	54	14D
0005434550817	10574	55	14E
0005434550816	10574	56	14F
0005434550814	10574	57	15A
0005433180727	10574	58	15D
0005433180662	10574	59	15E
0005434550785	10574	60	15F
0005434550767	10574	61	16A
0005434550781	10574	62	16D
0005434550813	10574	63	16E
0005433180665	10574	64	16F
0005434550768	10574	65	17A
0005434550802	10574	66	17C
0005433180663	10574	67	17D
0005434550789	10574	68	17E
0005434550784	10574	69	17F
0005434550787	10574	70	18E
0005434550777	10574	71	18F
0005434550811	10574	72	19A
0005434550818	10574	73	19C
0005434550808	10574	74	19D
0005434550763	10574	75	19E
0005434550807	10574	76	19F
0005434550772	10574	77	20A
0005434550783	10574	78	20C
0005434550786	10574	79	20D
0005434550809	10574	80	20E
0005434550778	10574	81	20F
0005433180906	27741	1	1F
0005433180913	27741	2	2F
0005433180915	27741	3	4F
0005433180921	27741	4	5E
0005433180917	27741	5	6F
0005433180910	27741	6	7A
0005433180925	27741	7	7C
0005433180916	27741	8	7D
0005433180931	27741	9	8A
0005433180918	27741	10	8C
0005433180932	27741	11	8E
0005433180927	27741	12	9A
0005433180930	27741	13	10E
0005433180909	27741	14	11C
0005433180926	27741	15	11A
0005433180911	27741	16	12E
0005433180908	27741	17	12F
0005433180928	27741	18	13C
0005433180922	27741	19	14E
0005433180929	27741	20	15E
0005433180923	27741	21	16A
0005433180912	27741	22	17A
0005433180919	27741	23	17E
0005433180907	27741	24	18A
0005433180924	27741	25	18E
0005433180920	27741	26	18F
0005433180914	27741	27	20A
0005434550481	27761	1	1A
0005434554031	27761	2	1C
0005434550352	27761	3	1D
0005434550351	27761	4	1F
0005434550366	27761	5	2A
0005434550430	27761	6	2F
0005434550280	27761	7	3C
0005434550480	27761	8	3D
0005434550483	27761	9	3F
0005434550413	27761	10	4A
0005434550284	27761	11	4C
0005434550259	27761	12	4D
0005434550578	27761	13	4E
0005434550326	27761	14	5A
0005434550260	27761	15	5C
0005434550331	27761	16	5E
0005434554027	27761	17	5F
0005434550388	27761	18	6A
0005434550522	27761	19	6C
0005434550422	27761	20	7A
0005434550367	27761	21	7C
0005434550501	27761	22	7F
0005434550383	27761	23	8A
0005434550577	27761	24	9E
0005434550298	27761	25	10D
0005434550301	27761	26	10E
0005434550377	27761	27	11A
0005434550432	27761	28	11D
0005434550339	27761	29	11C
0005434550557	27761	30	12A
0005434550281	27761	31	12E
0005434550325	27761	32	13A
0005434550386	27761	33	13F
0005434550581	27761	34	14A
0005434550365	27761	35	14C
0005434550429	27761	36	14E
0005434550488	27761	37	15A
0005434550449	27761	38	15C
0005434550511	27761	39	15D
0005434550484	27761	40	15F
0005434550500	27761	41	16A
0005434550410	27761	42	16D
0005434550389	27761	43	16E
0005434550420	27761	44	17C
0005434550357	27761	45	17D
0005434550508	27761	46	18E
0005434550446	27761	47	18F
0005434550411	27761	48	19A
0005434550368	27761	49	19C
0005434550421	27761	50	19D
0005434550320	27761	51	19E
0005434554026	27761	52	20A
0005434550384	27761	53	20C
0005434550495	27761	54	20E
0005433459188	6156	1	1A
0005433459190	6156	2	2A
0005435254439	6156	3	2B
0005433459187	6156	4	3A
0005435254429	6156	5	4B
0005433459191	6156	6	4A
0005435254430	6156	7	5B
0005435254438	6156	8	6B
0005433459189	6156	9	6A
0005435254458	19288	1	2A
0005433459161	19288	2	1B
0005433459156	19288	3	2B
0005435254456	19288	4	3B
0005435254455	19288	5	4B
0005433459160	19288	6	4A
0005435254457	19288	7	6A
0005435681820	6735	1	1A
0005435437665	6735	2	1C
0005435437717	6735	3	1D
0005435681817	6735	4	2A
0005435681821	6735	5	2C
0005435720128	6735	6	2D
0005435437611	6735	7	2F
0005432136132	6735	8	3A
0005435661909	6735	9	3C
0005435437627	6735	10	3F
0005435681811	6735	11	4A
0005435661907	6735	12	4C
0005435681830	6735	13	4F
0005435437559	6735	14	5A
0005435681843	6735	15	5D
0005435437616	6735	16	5E
0005435681835	6735	17	5F
0005435681833	6735	18	6C
0005435681837	6735	19	6D
0005435681831	6735	20	6E
0005435437666	6735	21	6F
0005435681810	6735	22	7A
0005435719562	6735	23	7D
0005435681829	6735	24	7E
0005435681842	6735	25	7F
0005435681838	6735	26	8A
0005435217678	6735	27	8D
0005435437579	6735	28	8E
0005435681847	6735	29	9A
0005435630941	6735	30	9C
0005435220285	6735	31	9D
0005435437647	6735	32	9E
0005435681841	6735	33	9F
0005435681836	6735	34	10C
0005435661908	6735	35	10D
0005435681828	6735	36	10E
0005435681815	6735	37	10F
0005435681825	6735	38	11A
0005435681824	6735	39	11C
0005435681840	6735	40	11D
0005435681822	6735	41	11E
0005435437597	6735	42	11F
0005435437624	6735	43	12A
0005432136133	6735	44	12C
0005432136130	6735	45	12D
0005432136134	6735	46	12E
0005435630943	6735	47	12F
0005435681845	6735	48	13A
0005435437684	6735	49	13C
0005435681826	6735	50	13D
0005435681813	6735	51	13E
0005435681823	6735	52	13F
0005435437636	6735	53	14A
0005435681844	6735	54	14C
0005435437610	6735	55	14D
0005435681846	6735	56	14F
0005435681816	6735	57	15A
0005435681839	6735	58	15D
0005432136131	6735	59	15C
0005435437637	6735	60	16A
0005432136135	6735	61	16C
0005435437664	6735	62	16D
0005435437650	6735	63	16E
0005435437623	6735	64	16F
0005435661906	6735	65	17C
0005435681832	6735	66	17D
0005435437626	6735	67	17E
0005435437628	6735	68	17F
0005435681819	6735	69	18A
0005435681812	6735	70	18C
0005435437668	6735	71	18E
0005435719561	6735	72	18F
0005435437625	6735	73	19A
0005432533240	6735	74	19C
0005435681834	6735	75	19E
0005435630942	6735	76	19F
0005435681827	6735	77	20A
0005435681814	6735	78	20C
0005435437646	6735	79	20D
0005435681818	6735	80	20E
0005432533271	24564	1	1C
0005435437798	24564	2	1D
0005435681483	24564	3	2A
0005435437780	24564	4	2C
0005435681551	24564	5	2D
0005435437789	24564	6	2F
0005435681556	24564	7	3A
0005435681450	24564	8	3C
0005435681618	24564	9	4A
0005435437783	24564	10	4C
0005435681611	24564	11	4D
0005435681468	24564	12	4E
0005435437793	24564	13	4F
0005435681513	24564	14	5A
0005435437790	24564	15	5C
0005435681421	24564	16	5F
0005435681499	24564	17	6C
0005435437784	24564	18	6D
0005435437792	24564	19	6F
0005435681531	24564	20	7C
0005435681476	24564	21	7D
0005432305731	24564	22	7E
0005435219181	24564	23	7F
0005435219186	24564	24	8C
0005435630927	24564	25	8D
0005435681428	24564	26	8E
0005435681429	24564	27	8F
0005435681580	24564	28	9A
0005435681469	24564	29	9C
0005435219184	24564	30	9D
0005435437797	24564	31	9E
0005435437791	24564	32	9F
0005435720801	24564	33	10C
0005435681411	24564	34	10D
0005435681532	24564	35	10F
0005435220303	24564	36	11A
0005435220300	24564	37	11C
0005435220301	24564	38	11D
0005435681541	24564	39	11E
0005435437786	24564	40	12A
0005434828676	24564	41	12C
0005435630928	24564	42	12D
0005435681435	24564	43	12E
0005435681401	24564	44	12F
0005434828677	24564	45	13C
0005434828678	24564	46	13A
0005435437796	24564	47	13F
0005435437787	24564	48	14A
0005435681505	24564	49	14C
0005435681540	24564	50	14D
0005435661881	24564	51	14E
0005435437788	24564	52	14F
0005435630922	24564	53	15C
0005435220302	24564	54	15E
0005435219185	24564	55	15F
0005435681550	24564	56	16A
0005435681434	24564	57	16C
0005435437795	24564	58	16E
0005432533269	24564	59	16F
0005435219183	24564	60	17E
0005435437794	24564	61	17F
0005435681471	24564	62	18A
0005435437800	24564	63	18C
0005435437785	24564	64	18D
0005432533270	24564	65	18F
0005435437782	24564	66	19A
0005435661879	24564	67	19C
0005435630921	24564	68	19D
0005435681530	24564	69	19E
0005435437781	24564	70	19F
0005435219182	24564	71	20A
0005435437799	24564	72	20C
0005435681441	24564	73	20D
0005435437779	24564	74	20E
0005435220304	24564	75	20F
0005435126026	11502	1	1A
0005435126027	11502	2	2A
0005435126036	11502	3	4A
0005435126041	11502	4	4C
0005435126057	11502	5	4D
0005435126033	11502	6	4E
0005435126031	11502	7	5C
0005435126022	11502	8	5D
0005435105958	11502	9	5F
0005435126054	11502	10	6A
0005435126046	11502	11	6E
0005435126024	11502	12	6F
0005435105957	11502	13	7A
0005435126030	11502	14	8A
0005435126034	11502	15	8F
0005435126037	11502	16	9C
0005435126056	11502	17	10D
0005435126052	11502	18	10E
0005435126028	11502	19	10F
0005435126055	11502	20	11C
0005435126040	11502	21	11E
0005435126025	11502	22	12D
0005435126043	11502	23	12E
0005435126049	11502	24	12F
0005435105956	11502	25	13A
0005435126047	11502	26	13C
0005435126050	11502	27	13D
0005435126045	11502	28	13E
0005435126058	11502	29	14A
0005435126051	11502	30	14C
0005435126032	11502	31	15A
0005435126060	11502	32	15D
0005435558048	11502	33	15E
0005435126044	11502	34	16C
0005435126039	11502	35	16D
0005435105955	11502	36	16E
0005435126061	11502	37	17A
0005435126062	11502	38	17C
0005435126029	11502	39	18D
0005435126063	11502	40	19C
0005435126048	11502	41	19D
0005435126042	11502	42	19E
0005435126023	11502	43	19F
0005435126059	11502	44	20A
0005435126035	11502	45	20D
0005435126053	11502	46	20E
0005435126038	11502	47	20F
0005435125885	31871	1	1A
0005435125713	31871	2	1C
0005435125809	31871	3	2D
0005435125736	31871	4	3D
0005435558068	31871	5	3F
0005435125723	31871	6	4C
0005435125739	31871	7	4F
0005435125666	31871	8	5C
0005435125738	31871	9	5D
0005435125702	31871	10	5E
0005435125758	31871	11	5F
0005435125759	31871	12	6C
0005435125665	31871	13	6D
0005435125699	31871	14	7E
0005435125686	31871	15	8E
0005435125788	31871	16	9C
0005435125800	31871	17	9D
0005435125737	31871	18	10C
0005435125664	31871	19	10E
0005435125817	31871	20	11A
0005435125785	31871	21	11C
0005435125792	31871	22	11D
0005435125842	31871	23	12D
0005435125651	31871	24	12E
0005435125720	31871	25	13A
0005435125847	31871	26	13C
0005435125740	31871	27	14A
0005435125756	31871	28	14C
0005435105937	31871	29	14D
0005435125724	31871	30	15E
0005435558067	31871	31	16A
0005435125683	31871	32	16C
0005435125846	31871	33	17D
0005435125650	31871	34	18C
0005435098522	31871	35	18D
0005435125884	31871	36	19A
0005435125789	31871	37	19C
0005435125766	31871	38	19F
0005435125700	31871	39	20A
0005435125757	31871	40	20C
0005435125706	31871	41	20E
0005435125763	31871	42	20F
0005435732196	13556	1	1C
0005433397722	13556	2	1D
0005433397717	13556	3	1F
0005433397720	13556	4	2A
0005433397679	13556	5	2C
0005433397682	13556	6	2D
0005433397721	13556	7	2F
0005433397696	13556	8	4A
0005433397709	13556	9	4C
0005433397718	13556	10	4E
0005433397688	13556	11	5A
0005433397699	13556	12	5F
0005435732144	13556	13	6A
0005433397714	13556	14	6E
0005433397693	13556	15	6D
0005433397680	13556	16	6F
0005433397683	13556	17	7A
0005433397708	13556	18	7C
0005433397715	13556	19	7D
0005435732147	13556	20	7E
0005433397700	13556	21	8A
0005433397698	13556	22	8C
0005433397710	13556	23	9A
0005433397687	13556	24	9E
0005433397690	13556	25	10D
0005435732143	13556	26	10F
0005435732146	13556	27	11A
0005433397678	13556	28	11C
0005435732132	13556	29	11E
0005435732115	13556	30	11F
0005433397719	13556	31	12A
0005433397695	13556	32	12C
0005433397713	13556	33	12D
0005433397705	13556	34	12E
0005433397692	13556	35	12F
0005433397712	13556	36	13C
0005433397711	13556	37	13F
0005433397677	13556	38	14D
0005433397701	13556	39	14E
0005433397689	13556	40	15A
0005433397707	13556	41	15C
0005433397686	13556	42	15F
0005435732161	13556	43	16A
0005433397685	13556	44	16C
0005433397723	13556	45	16D
0005435732212	13556	46	16E
0005433397702	13556	47	17A
0005433397691	13556	48	17D
0005433397703	13556	49	17E
0005433397725	13556	50	17F
0005433397724	13556	51	18A
0005435732114	13556	52	18C
0005433397676	13556	53	18D
0005433397716	13556	54	18F
0005433397684	13556	55	19A
0005435732213	13556	56	19C
0005433397697	13556	57	19E
0005433397694	13556	58	20A
0005433397706	13556	59	20D
0005433397704	13556	60	20E
0005433397681	13556	61	20F
0005433397472	19392	1	1C
0005433397232	19392	2	1D
0005433397231	19392	3	1F
0005435732239	19392	4	2F
0005433397233	19392	5	3A
0005435732235	19392	6	3C
0005435732238	19392	7	3D
0005432297258	19392	8	3F
0005433397311	19392	9	4A
0005432297259	19392	10	4C
0005435732246	19392	11	4D
0005433397223	19392	12	4F
0005435732243	19392	13	5C
0005433397349	19392	14	6A
0005435732254	19392	15	6E
0005433397261	19392	16	6F
0005435732252	19392	17	7A
0005433397186	19392	18	7C
0005435732236	19392	19	7E
0005433397193	19392	20	7F
0005435732250	19392	21	8C
0005435732251	19392	22	8D
0005433397280	19392	23	8E
0005433397294	19392	24	9D
0005433397180	19392	25	9F
0005433397329	19392	26	10A
0005433397192	19392	27	10C
0005435732242	19392	28	10D
0005433397235	19392	29	10E
0005433397281	19392	30	10F
0005435732244	19392	31	11A
0005433397282	19392	32	11D
0005435732237	19392	33	11E
0005435732234	19392	34	12C
0005433397320	19392	35	12D
0005435732241	19392	36	12E
0005435732247	19392	37	12F
0005435732248	19392	38	13C
0005433397253	19392	39	13D
0005433397328	19392	40	13F
0005433397295	19392	41	14A
0005435732240	19392	42	14D
0005433397243	19392	43	14E
0005433397399	19392	44	14F
0005435732233	19392	45	15A
0005435732255	19392	46	15C
0005433397277	19392	47	15D
0005435732256	19392	48	16A
0005435732245	19392	49	16C
0005433397312	19392	50	16D
0005433397400	19392	51	16F
0005433397256	19392	52	17A
0005432297257	19392	53	17C
0005432297260	19392	54	17F
0005433397240	19392	55	18D
0005435732253	19392	56	19C
0005433397519	19392	57	19E
0005433397344	19392	58	19F
0005433397458	19392	59	20A
0005435732249	19392	60	20E
0005435068354	13177	1	1D
0005435068199	13177	2	1F
0005435068295	13177	3	2D
0005435068298	13177	4	3A
0005435068176	13177	5	3D
0005435068273	13177	6	4D
0005435068262	13177	7	4F
0005435068253	13177	8	5F
0005435068254	13177	9	6E
0005435068177	13177	10	7A
0005435068201	13177	11	8C
0005435068163	13177	12	8E
0005435068453	13177	13	9D
0005435068383	13177	14	9E
0005435068454	13177	15	10A
0005435068244	13177	16	10D
0005435068382	13177	17	11C
0005435068333	13177	18	12F
0005435068164	13177	19	13A
0005435068356	13177	20	13C
0005435068296	13177	21	13E
0005435068174	13177	22	14A
0005435068249	13177	23	14C
0005435068303	13177	24	15C
0005435068355	13177	25	15E
0005435068248	13177	26	15F
0005435068297	13177	27	16A
0005435068261	13177	28	16D
0005435068299	13177	29	16E
0005435068467	13177	30	17C
0005435068317	13177	31	18D
0005435068294	13177	32	19C
0005435068182	13177	33	19D
0005435068173	13177	34	19F
0005435068316	13177	35	20C
0005435068468	13177	36	20D
0005435068639	15512	1	1A
0005435068680	15512	2	1C
0005435068686	15512	3	1D
0005435068643	15512	4	2A
0005435068638	15512	5	2C
0005435068681	15512	6	2D
0005435068653	15512	7	2F
0005435068658	15512	8	3C
0005435068670	15512	9	3F
0005435925049	15512	10	4A
0005435068676	15512	11	4C
0005435068661	15512	12	5A
0005435068663	15512	13	5C
0005435925047	15512	14	5D
0005435068637	15512	15	5E
0005435068646	15512	16	6D
0005435068666	15512	17	6E
0005435068664	15512	18	6F
0005435068648	15512	19	7A
0005435068652	15512	20	7C
0005435068685	15512	21	7D
0005435068673	15512	22	8A
0005435068683	15512	23	8C
0005435068675	15512	24	8D
0005435068654	15512	25	8F
0005435925067	15512	26	9A
0005435925071	15512	27	9D
0005435068642	15512	28	9F
0005435068660	15512	29	10A
0005435068678	15512	30	10C
0005435068645	15512	31	10E
0005435068667	15512	32	11A
0005435068644	15512	33	11C
0005435925054	15512	34	11D
0005435068650	15512	35	11E
0005435068682	15512	36	12A
0005435068655	15512	37	12C
0005435068649	15512	38	12D
0005435068672	15512	39	12F
0005435068674	15512	40	13E
0005435068671	15512	41	14D
0005435068635	15512	42	14F
0005435068669	15512	43	15A
0005435068668	15512	44	15D
0005435925050	15512	45	15F
0005435068684	15512	46	16C
0005435068656	15512	47	16F
0005435068679	15512	48	17C
0005435068677	15512	49	17F
0005435068651	15512	50	18A
0005435925048	15512	51	18C
0005435068662	15512	52	18D
0005435925068	15512	53	18E
0005435068659	15512	54	18F
0005435068657	15512	55	19A
0005435068641	15512	56	19C
0005435925053	15512	57	19D
0005435068647	15512	58	19E
0005435068640	15512	59	19F
0005435068665	15512	60	20A
0005435068687	15512	61	20E
0005435068636	15512	62	20F
0005435808153	23177	1	1A
0005435808150	23177	2	1D
0005435808144	23177	3	2A
0005435808154	23177	4	3A
0005435808137	23177	5	3B
0005435808140	23177	6	3C
0005435808147	23177	7	3D
0005435808141	23177	8	4B
0005433407485	23177	9	5C
0005435808138	23177	10	6C
0005435808151	23177	11	6D
0005435808142	23177	12	7B
0005435808146	23177	13	18A
0005435808148	23177	14	18D
0005435808136	23177	15	19B
0005433407483	23177	16	19D
0005435808149	23177	17	20A
0005433407477	23177	18	20D
0005435808139	23177	19	21A
0005435808143	23177	20	21C
0005433407484	23177	21	21D
0005435808145	23177	22	22A
0005435808155	23177	23	22B
0005435808152	23177	24	22D
0005434755764	10736	1	1A
0005434755703	10736	2	1F
0005434214193	10736	3	2A
0005434214188	10736	4	2F
0005434214200	10736	5	3D
0005434214186	10736	6	3F
0005434214215	10736	7	4A
0005434214178	10736	8	4C
0005434214187	10736	9	4F
0005434214179	10736	10	5C
0005434214207	10736	11	5D
0005434214199	10736	12	5E
0005434214202	10736	13	6A
0005434214208	10736	14	6D
0005434214217	10736	15	6E
0005434214196	10736	16	7A
0005434755811	10736	17	7E
0005434214204	10736	18	7F
0005434755737	10736	19	8A
0005434755810	10736	20	8C
0005434755754	10736	21	8E
0005434755704	10736	22	8F
0005434214220	10736	23	9A
0005434214184	10736	24	9C
0005434214198	10736	25	9D
0005434214189	10736	26	9E
0005434214181	10736	27	9F
0005434214192	10736	28	10C
0005434214218	10736	29	10F
0005434214175	10736	30	11A
0005434755778	10736	31	11C
0005434755823	10736	32	11D
0005434755801	10736	33	11E
0005434214185	10736	34	11F
0005434214177	10736	35	12C
0005434214180	10736	36	12D
0005434755777	10736	37	12E
0005434755799	10736	38	12F
0005434214211	10736	39	13C
0005434214203	10736	40	13D
0005434755761	10736	41	13E
0005434214205	10736	42	13F
0005434214191	10736	43	14C
0005434214183	10736	44	14D
0005434755822	10736	45	14F
0005434214212	10736	46	15A
0005434214219	10736	47	15D
0005434214176	10736	48	15E
0005434755719	10736	49	15F
0005434214214	10736	50	16C
0005434214194	10736	51	16D
0005434214206	10736	52	16E
0005434755723	10736	53	16F
0005434214210	10736	54	17A
0005434214213	10736	55	17C
0005434755739	10736	56	17D
0005434214190	10736	57	17F
0005434214195	10736	58	18A
0005434214216	10736	59	18C
0005434755732	10736	60	18E
0005434214182	10736	61	18F
0005434214197	10736	62	19A
0005434214201	10736	63	19C
0005434755809	10736	64	19D
0005434755746	10736	65	19E
0005434755765	10736	66	19F
0005434755776	10736	67	20A
0005434755731	10736	68	20C
0005434214209	10736	69	20D
0005434755708	10736	70	20E
0005434214174	10736	71	20F
0005434756103	28680	1	1A
0005434213792	28680	2	1C
0005434756116	28680	3	1F
0005434213829	28680	4	2C
0005434213707	28680	5	2D
0005434213717	28680	6	2F
0005434756099	28680	7	3A
0005434756118	28680	8	3C
0005434756117	28680	9	3F
0005434213738	28680	10	4C
0005434213754	28680	11	4D
0005434213793	28680	12	4F
0005434213698	28680	13	5A
0005434756104	28680	14	5E
0005434756093	28680	15	5F
0005434756097	28680	16	6D
0005434756115	28680	17	6E
0005434756114	28680	18	6F
0005434213783	28680	19	7D
0005434756113	28680	20	7E
0005434756091	28680	21	7F
0005434756098	28680	22	8A
0005434213813	28680	23	8C
0005434213863	28680	24	8D
0005434213786	28680	25	8E
0005434756090	28680	26	9D
0005434756092	28680	27	9E
0005434756102	28680	28	9F
0005434756106	28680	29	10A
0005434756100	28680	30	10C
0005434756111	28680	31	10D
0005434756109	28680	32	10E
0005434213757	28680	33	10F
0005434756112	28680	34	11A
0005434213756	28680	35	11D
0005434213700	28680	36	13A
0005434213731	28680	37	13F
0005434756101	28680	38	14A
0005434756094	28680	39	14F
0005434756110	28680	40	15A
0005434213745	28680	41	15D
0005434756107	28680	42	15E
0005434213767	28680	43	16A
0005434213815	28680	44	17C
0005434213699	28680	45	17D
0005434213718	28680	46	17E
0005434213766	28680	47	17F
0005434213841	28680	48	18C
0005434756105	28680	49	18D
0005434756108	28680	50	18E
0005434756096	28680	51	18F
0005434213755	28680	52	19A
0005434213752	28680	53	19F
0005434756095	28680	54	20C
0005434213814	28680	55	20D
0005434213854	28680	56	20F
0005435039323	5479	1	1A
0005435039271	5479	2	1D
0005435006846	5479	3	1C
0005435039276	5479	4	1F
0005435039327	5479	5	2C
0005434229056	5479	6	2A
0005435039277	5479	7	2D
0005434229011	5479	8	3C
0005435039307	5479	9	3A
0005432125395	5479	10	3D
0005434229061	5479	11	3F
0005432125399	5479	12	4B
0005432125401	5479	13	4A
0005435039300	5479	14	4C
0005435039312	5479	15	4D
0005435006857	5479	16	4E
0005435039281	5479	17	4F
0005435039283	5479	18	5A
0005435006845	5479	19	5D
0005435039296	5479	20	5C
0005435039326	5479	21	5E
0005435006859	5479	22	6A
0005435006863	5479	23	5F
0005432125403	5479	24	6B
0005435039275	5479	25	6D
0005435006847	5479	26	6C
0005435006850	5479	27	6E
0005435039297	5479	28	7A
0005435006844	5479	29	7B
0005435039328	5479	30	7C
0005434229101	5479	31	7E
0005435006866	5479	32	7D
0005432125400	5479	33	8A
0005435039270	5479	34	8B
0005435039294	5479	35	8C
0005432125396	5479	36	8D
0005435006858	5479	37	8F
0005435043277	5479	38	8E
0005434228995	5479	39	9A
0005435039282	5479	40	9C
0005435039304	5479	41	9B
0005435042838	5479	42	9D
0005435039317	5479	43	9E
0005435039289	5479	44	9F
0005432125397	5479	45	10B
0005435039284	5479	46	10C
0005435039274	5479	47	10E
0005435042837	5479	48	10D
0005435006856	5479	49	11A
0005435039315	5479	50	11C
0005435039268	5479	51	11B
0005434229060	5479	52	11D
0005435039286	5479	53	11E
0005435039280	5479	54	11F
0005435006843	5479	55	12A
0005435006855	5479	56	12C
0005435039278	5479	57	12B
0005434229010	5479	58	12D
0005435039311	5479	59	12E
0005434228991	5479	60	12F
0005432125402	5479	61	13B
0005434229045	5479	62	13C
0005435039290	5479	63	13D
0005434229065	5479	64	13E
0005435006861	5479	65	13F
0005435039299	5479	66	14A
0005435039306	5479	67	14B
0005435039305	5479	68	14D
0005435006864	5479	69	14C
0005435039291	5479	70	14E
0005435006853	5479	71	14F
0005435039302	5479	72	15B
0005435039265	5479	73	15A
0005435039293	5479	74	15C
0005434229109	5479	75	15E
0005435006862	5479	76	16A
0005435006849	5479	77	15F
0005435039295	5479	78	16B
0005435006867	5479	79	16C
0005435039264	5479	80	16E
0005435006860	5479	81	16D
0005435039298	5479	82	16F
0005435039308	5479	83	17B
0005435039329	5479	84	17A
0005435039285	5479	85	17C
0005435039320	5479	86	17D
0005432125394	5479	87	17F
0005435006852	5479	88	17E
0005434229100	5479	89	18A
0005435006842	5479	90	18B
0005435039279	5479	91	18C
0005435039287	5479	92	18D
0005435006854	5479	93	18F
0005435039321	5479	94	18E
0005434229138	5479	95	19A
0005435039303	5479	96	19B
0005434229102	5479	97	19D
0005435006851	5479	98	19C
0005435039319	5479	99	19F
0005435039301	5479	100	19E
0005435039322	5479	101	20A
0005434229044	5479	102	20C
0005435039325	5479	103	20B
0005435039292	5479	104	20D
0005435006865	5479	105	20E
0005435039310	5479	106	21A
0005432125398	5479	107	20F
0005435039272	5479	108	21C
0005435039316	5479	109	21B
0005435039267	5479	110	21D
0005435039273	5479	111	21E
0005435039313	5479	112	22A
0005435039314	5479	113	21F
0005435039266	5479	114	22C
0005434229071	5479	115	22B
0005434229043	5479	116	22D
0005435039324	5479	117	22F
0005434228979	5479	118	22E
0005435039288	5479	119	23A
0005435039318	5479	120	23C
0005435039309	5479	121	23B
0005435039263	5479	122	23E
0005435039269	5479	123	23D
0005435006848	5479	124	23F
0005435038908	12988	1	1A
0005435038975	12988	2	1C
0005435038801	12988	3	1F
0005435006637	12988	4	2C
0005435042824	12988	5	2F
0005434229214	12988	6	3C
0005434229199	12988	7	3D
0005435038670	12988	8	4A
0005435038765	12988	9	4C
0005435038737	12988	10	4B
0005432304371	12988	11	4D
0005435038853	12988	12	5B
0005435377902	12988	13	5A
0005434229218	12988	14	5C
0005435038942	12988	15	5E
0005435038957	12988	16	6A
0005435377903	12988	17	5F
0005435038926	12988	18	6C
0005435006762	12988	19	6E
0005434229207	12988	20	7A
0005435038943	12988	21	6F
0005435038758	12988	22	7C
0005435042820	12988	23	7D
0005434229201	12988	24	8A
0005435038967	12988	25	7F
0005435038886	12988	26	8D
0005434229209	12988	27	8F
0005434229215	12988	28	9A
0005435038906	12988	29	9C
0005435042830	12988	30	9B
0005434229205	12988	31	9E
0005435038736	12988	32	9D
0005434229198	12988	33	10B
0005434229202	12988	34	10D
0005435039163	12988	35	10C
0005435006665	12988	36	10E
0005435038726	12988	37	11A
0005434229213	12988	38	11B
0005435006678	12988	39	11C
0005434229203	12988	40	11E
0005435038852	12988	41	12A
0005435006686	12988	42	12C
0005434229212	12988	43	12B
0005435006644	12988	44	12E
0005435006694	12988	45	12F
0005435038732	12988	46	13A
0005435039165	12988	47	13C
0005432304370	12988	48	13B
0005434229211	12988	49	13D
0005435038983	12988	50	13E
0005434229200	12988	51	14A
0005435006727	12988	52	13F
0005435006761	12988	53	14C
0005435377901	12988	54	14D
0005435042822	12988	55	14E
0005435038834	12988	56	15A
0005435038873	12988	57	14F
0005435006607	12988	58	15B
0005435038721	12988	59	15C
0005435039029	12988	60	15D
0005435038954	12988	61	16A
0005435042821	12988	62	15F
0005435039162	12988	63	16B
0005435038709	12988	64	16D
0005435038905	12988	65	16F
0005435038671	12988	66	16E
0005435038678	12988	67	17B
0005434229204	12988	68	17A
0005435006604	12988	69	17C
0005432304368	12988	70	17E
0005435006718	12988	71	17D
0005435039164	12988	72	17F
0005435038703	12988	73	18B
0005435038657	12988	74	18C
0005435038720	12988	75	18D
0005434229210	12988	76	18F
0005435006625	12988	77	18E
0005435006657	12988	78	19A
0005435038918	12988	79	19C
0005434229208	12988	80	19E
0005435006636	12988	81	19D
0005434229219	12988	82	19F
0005435038632	12988	83	20A
0005435038838	12988	84	20B
0005435006652	12988	85	20D
0005435038699	12988	86	20C
0005435042829	12988	87	21A
0005435038891	12988	88	21B
0005435038874	12988	89	21C
0005435038951	12988	90	21D
0005435038968	12988	91	21E
0005435006674	12988	92	22A
0005432304369	12988	93	21F
0005434229206	12988	94	22B
0005435006605	12988	95	22C
0005434229217	12988	96	22E
0005435038640	12988	97	22D
0005435006692	12988	98	23A
0005434229216	12988	99	22F
0005435038890	12988	100	23B
0005435038708	12988	101	23D
0005435042825	12988	102	23F
0005435038766	12988	103	23E
0005435902433	14864	1	1C
0005435902432	14864	2	1D
0005434411742	14864	3	2A
0005435554103	14864	4	3A
0005434426383	14864	5	3C
0005435554115	14864	6	3D
0005435902434	14864	7	4A
0005434426375	14864	8	4D
0005435902444	14864	9	5A
0005434411743	14864	10	5D
0005434426369	14864	11	5E
0005434426365	14864	12	6D
0005434426357	14864	13	7C
0005435902443	14864	14	7F
0005434426364	14864	15	8C
0005435902390	14864	16	8D
0005434426382	14864	17	9A
0005435902419	14864	18	9C
0005434426362	14864	19	9D
0005432188580	14864	20	9F
0005434426385	14864	21	10A
0005434426380	14864	22	10E
0005434426381	14864	23	11D
0005434426377	14864	24	11E
0005434426376	14864	25	11F
0005434426356	14864	26	12A
0005434426374	14864	27	12C
0005435902469	14864	28	12D
0005434426368	14864	29	12F
0005434426384	14864	30	13A
0005434426358	14864	31	13F
0005434426371	14864	32	14A
0005434426379	14864	33	14C
0005434426359	14864	34	14D
0005434426367	14864	35	15A
0005434426360	14864	36	15C
0005434426372	14864	37	15E
0005435902442	14864	38	16C
0005434426378	14864	39	17C
0005434411744	14864	40	17D
0005435554104	14864	41	17F
0005434411741	14864	42	18C
0005434426361	14864	43	18D
0005432188582	14864	44	18F
0005435902420	14864	45	19C
0005434426370	14864	46	19D
0005434426366	14864	47	19E
0005434426373	14864	48	20A
0005432188581	14864	49	20D
0005434426363	14864	50	20E
0005435902569	20222	1	1A
0005434426129	20222	2	1C
0005435902570	20222	3	1D
0005434426192	20222	4	2C
0005435902582	20222	5	3A
0005434426194	20222	6	3F
0005435554154	20222	7	4D
0005434426123	20222	8	4E
0005434426154	20222	9	4F
0005435902581	20222	10	5D
0005434426122	20222	11	5E
0005434411712	20222	12	6A
0005434411711	20222	13	6C
0005434426112	20222	14	6D
0005435902580	20222	15	7A
0005435902574	20222	16	7C
0005432059490	20222	17	7D
0005435902577	20222	18	7E
0005434426153	20222	19	7F
0005435902575	20222	20	8C
0005435554156	20222	21	8D
0005434426168	20222	22	8E
0005435902579	20222	23	9C
0005434426167	20222	24	9E
0005435554157	20222	25	9F
0005434426195	20222	26	10C
0005435902571	20222	27	11A
0005435554153	20222	28	11C
0005435902583	20222	29	11D
0005434411710	20222	30	11E
0005434426152	20222	31	11F
0005435902578	20222	32	12A
0005435902566	20222	33	12C
0005434426151	20222	34	12F
0005435902567	20222	35	13C
0005434426166	20222	36	13E
0005435554155	20222	37	14A
0005434426128	20222	38	14E
0005435902572	20222	39	14F
0005434426133	20222	40	15A
0005435902568	20222	41	15C
0005434426150	20222	42	15D
0005435902576	20222	43	15F
0005432059489	20222	44	16D
0005434426132	20222	45	16E
0005435902573	20222	46	17A
0005434426101	20222	47	17D
0005434426191	20222	48	17E
0005434426125	20222	49	18D
0005434426157	20222	50	19E
0005434426095	20222	51	20C
0005434523750	30880	1	4C
0005434523752	30880	2	5C
0005434523756	30880	3	7D
0005434523757	30880	4	10D
0005434523751	30880	5	12C
0005434523747	30880	6	12D
0005434523755	30880	7	13B
0005434523749	30880	8	15A
0005434523753	30880	9	17C
0005434523754	30880	10	18D
0005434523748	30880	11	20C
0005432300220	26549	1	1A
0005433434261	26549	2	1C
0005433434223	26549	3	1D
0005435981949	26549	4	1F
0005433434219	26549	5	2A
0005435981960	26549	6	2C
0005435981926	26549	7	2D
0005432300215	26549	8	2F
0005432300217	26549	9	3A
0005435981925	26549	10	3F
0005432300214	26549	11	4A
0005433434256	26549	12	4C
0005435981940	26549	13	4D
0005433434255	26549	14	4E
0005435981943	26549	15	5A
0005433434235	26549	16	5C
0005435981927	26549	17	5D
0005435981945	26549	18	5E
0005435981956	26549	19	6A
0005435981928	26549	20	6E
0005435981935	26549	21	7A
0005433434218	26549	22	6F
0005435981955	26549	23	7C
0005435981942	26549	24	7D
0005435981939	26549	25	7F
0005435981951	26549	26	8D
0005432300216	26549	27	8E
0005433434260	26549	28	8F
0005433434258	26549	29	9A
0005435981938	26549	30	9D
0005433434270	26549	31	10C
0005433434284	26549	32	10D
0005433434222	26549	33	10F
0005435981936	26549	34	11E
0005432300219	26549	35	12A
0005435981946	26549	36	12D
0005433434269	26549	37	12F
0005432300218	26549	38	13C
0005435981933	26549	39	13D
0005435981937	26549	40	13E
0005435981941	26549	41	13F
0005435981931	26549	42	14A
0005435981929	26549	43	14C
0005433434257	26549	44	14F
0005435981947	26549	45	15A
0005435981930	26549	46	15C
0005435981944	26549	47	16D
0005435981957	26549	48	16E
0005433434259	26549	49	16F
0005435981950	26549	50	17A
0005435981954	26549	51	17C
0005435981934	26549	52	17F
0005433434236	26549	53	18A
0005435981952	26549	54	18C
0005435981924	26549	55	18D
0005435981932	26549	56	18F
0005435981953	26549	57	19A
0005435981961	26549	58	19C
0005435981958	26549	59	19F
0005433434347	26549	60	20A
0005433434234	26549	61	20C
0005435981959	26549	62	20D
0005435981948	26549	63	20E
0005433434477	26719	1	1A
0005434269089	26719	2	1C
0005435981578	26719	3	1F
0005435981698	26719	4	2A
0005433434481	26719	5	2C
0005435981735	26719	6	2F
0005433434479	26719	7	3A
0005435981657	26719	8	3C
0005433434474	26719	9	3D
0005435981709	26719	10	3F
0005433434496	26719	11	4A
0005434271296	26719	12	4D
0005435981714	26719	13	4E
0005435981581	26719	14	5A
0005435981539	26719	15	5D
0005435981512	26719	16	5E
0005433434492	26719	17	5F
0005434271297	26719	18	6A
0005433434485	26719	19	6C
0005432051107	26719	20	6D
0005433434484	26719	21	6E
0005435981531	26719	22	7A
0005435981603	26719	23	7C
0005433434494	26719	24	7D
0005435981755	26719	25	7E
0005435981662	26719	26	7F
0005433434478	26719	27	8A
0005433434487	26719	28	8D
0005435981521	26719	29	8E
0005433434469	26719	30	8F
0005435981689	26719	31	9A
0005435981548	26719	32	9D
0005435981658	26719	33	9F
0005433434471	26719	34	10A
0005433434475	26719	35	10C
0005434271298	26719	36	10E
0005435981530	26719	37	10F
0005433434491	26719	38	11C
0005434270192	26719	39	11E
0005433434480	26719	40	11F
0005435981684	26719	41	12A
0005435981617	26719	42	12C
0005432051106	26719	43	12E
0005433434486	26719	44	13A
0005435981715	26719	45	13C
0005433434495	26719	46	13E
0005435981555	26719	47	13F
0005433434472	26719	48	14A
0005435981632	26719	49	14C
0005434270191	26719	50	14D
0005433434482	26719	51	14F
0005435981639	26719	52	15A
0005435981621	26719	53	15C
0005435981640	26719	54	15D
0005433434488	26719	55	15F
0005435981703	26719	56	16A
0005435981571	26719	57	16C
0005433434483	26719	58	16E
0005432051105	26719	59	16F
0005434269088	26719	60	17A
0005433434476	26719	61	17C
0005435981596	26719	62	17D
0005435981549	26719	63	17E
0005435981540	26719	64	17F
0005433434470	26719	65	18C
0005433434473	26719	66	18E
0005433434493	26719	67	18F
0005435981618	26719	68	19A
0005435981681	26719	69	19C
0005435981675	26719	70	19D
0005433434490	26719	71	19E
0005435981516	26719	72	19F
0005435981590	26719	73	20C
0005433434489	26719	74	20D
0005435981622	26719	75	20E
0005435981656	26719	76	20F
0005432857870	3182	1	1A
0005432583848	3182	2	1B
0005432583841	3182	3	2A
0005432857893	3182	4	2B
0005432583850	3182	5	2C
0005432583861	3182	6	2D
0005432857888	3182	7	3A
0005432583854	3182	8	3B
0005432857889	3182	9	3D
0005432583860	3182	10	4A
0005432583856	3182	11	4B
0005432583842	3182	12	4C
0005432583853	3182	13	5A
0005432583845	3182	14	5B
0005432583852	3182	15	5D
0005432583858	3182	16	5C
0005432857882	3182	17	6A
0005432583840	3182	18	6B
0005432583851	3182	19	6C
0005432583843	3182	20	6D
0005432216252	3182	21	7A
0005432583862	3182	22	18A
0005432583859	3182	23	18B
0005432583849	3182	24	18D
0005432857871	3182	25	19A
0005432583844	3182	26	19B
0005432857929	3182	27	19C
0005432583865	3182	28	19D
0005432583863	3182	29	20A
0005432583864	3182	30	20B
0005432583847	3182	31	20C
0005432857862	3182	32	20D
0005432583857	3182	33	22B
0005432583855	3182	34	22C
0005432583846	3182	35	23B
0005432857977	31496	1	1A
0005432857982	31496	2	1D
0005432583588	31496	3	2A
0005432857974	31496	4	2B
0005432583660	31496	5	2D
0005432857976	31496	6	3A
0005432857980	31496	7	3B
0005432857984	31496	8	3C
0005432583700	31496	9	3D
0005432583612	31496	10	4B
0005432583619	31496	11	4A
0005432583767	31496	12	4C
0005432583641	31496	13	4D
0005432857978	31496	14	5A
0005432583711	31496	15	5C
0005432583659	31496	16	5D
0005432583586	31496	17	6A
0005432583701	31496	18	6B
0005432583685	31496	19	6C
0005432857981	31496	20	6D
0005432583667	31496	21	7A
0005432857985	31496	22	7B
0005432583622	31496	23	7C
0005432583699	31496	24	18A
0005432583651	31496	25	18B
0005432857983	31496	26	18C
0005432583674	31496	27	19B
0005432857975	31496	28	19D
0005432583676	31496	29	20A
0005432583675	31496	30	20B
0005432583665	31496	31	20C
0005432857979	31496	32	21A
0005432583642	31496	33	21B
0005432583658	31496	34	21C
0005432583684	31496	35	21D
0005432583677	31496	36	22B
0005432583635	31496	37	23B
0005434943286	871	1	1B
0005434943279	871	2	1C
0005434943285	871	3	2C
0005433255027	871	4	2D
0005434943288	871	5	3D
0005434943287	871	6	4B
0005433255037	871	7	5A
0005434943280	871	8	5B
0005434943282	871	9	6A
0005434943284	871	10	6D
0005434943281	871	11	7D
0005434943283	871	12	19C
0005433255026	871	13	20A
0005433255043	871	14	20C
0005433255077	16224	1	1D
0005433255081	16224	2	2B
0005434943193	16224	3	2C
0005433255082	16224	4	3C
0005433255080	16224	5	4A
0005434943220	16224	6	4C
0005434943213	16224	7	7C
0005433255079	16224	8	18B
0005434943185	16224	9	18D
0005434943194	16224	10	19D
0005433255078	16224	11	22A
0005433255083	16224	12	22C
0005435858519	27612	1	1F
0005435858522	27612	2	2D
0005433654652	27612	3	3D
0005435858525	27612	4	3C
0005433654663	27612	5	5F
0005433654682	27612	6	6A
0005435858515	27612	7	6D
0005435858518	27612	8	7A
0005435858520	27612	9	8A
0005435858527	27612	10	9A
0005433654680	27612	11	9D
0005433654662	27612	12	9C
0005433654658	27612	13	10A
0005435858531	27612	14	10B
0005435858523	27612	15	10D
0005435858516	27612	16	11A
0005435858530	27612	17	10F
0005433654648	27612	18	12B
0005435858524	27612	19	13A
0005433654653	27612	20	14A
0005433654647	27612	21	14E
0005433654679	27612	22	15A
0005435858526	27612	23	16B
0005433654678	27612	24	16A
0005435858521	27612	25	15F
0005435858529	27612	26	17B
0005435858517	27612	27	20D
0005433654677	27612	28	20C
0005435858528	27612	29	21A
0005435858514	27612	30	20F
0005435652724	21743	1	1A
0005435652671	21743	2	1C
0005435652728	21743	3	1F
0005435652709	21743	4	2A
0005435652703	21743	5	2C
0005435652712	21743	6	2D
0005435652679	21743	7	2F
0005435652698	21743	8	3A
0005435652681	21743	9	3C
0005435652691	21743	10	3F
0005435652694	21743	11	4A
0005433367371	21743	12	4C
0005433367471	21743	13	4D
0005435652680	21743	14	4F
0005435652687	21743	15	5A
0005433367354	21743	16	5C
0005435652674	21743	17	5E
0005433367298	21743	18	5F
0005435652693	21743	19	6A
0005433367227	21743	20	6C
0005433367377	21743	21	6D
0005435652729	21743	22	6E
0005435652705	21743	23	6F
0005435652682	21743	24	7A
0005435652675	21743	25	7C
0005433367385	21743	26	7D
0005435652707	21743	27	7E
0005435652723	21743	28	7F
0005435652726	21743	29	8A
0005433367243	21743	30	8C
0005435652711	21743	31	8E
0005435652688	21743	32	8F
0005435652677	21743	33	9A
0005435652725	21743	34	9E
0005435652719	21743	35	9F
0005433367355	21743	36	10A
0005435652714	21743	37	10C
0005433367472	21743	38	10D
0005435652720	21743	39	10E
0005433367299	21743	40	10F
0005435652715	21743	41	11A
0005433367323	21743	42	11C
0005435652721	21743	43	11D
0005435652700	21743	44	11F
0005435652722	21743	45	12A
0005435652676	21743	46	12C
0005435652683	21743	47	12D
0005435652690	21743	48	12F
0005435652670	21743	49	13A
0005433367264	21743	50	13C
0005435652713	21743	51	13D
0005435652717	21743	52	13E
0005435652678	21743	53	13F
0005433367317	21743	54	14A
0005435652685	21743	55	14C
0005433367260	21743	56	14D
0005435652730	21743	57	14E
0005433367297	21743	58	14F
0005433367266	21743	59	15A
0005433367406	21743	60	15C
0005433367357	21743	61	15D
0005433367261	21743	62	15E
0005433367337	21743	63	15F
0005435652684	21743	64	16A
0005433367285	21743	65	16C
0005435652699	21743	66	16D
0005435652696	21743	67	16E
0005435652701	21743	68	16F
0005433367370	21743	69	17A
0005435652697	21743	70	17E
0005435652692	21743	71	17F
0005435652695	21743	72	18A
0005435652727	21743	73	18C
0005433367286	21743	74	18D
0005435652718	21743	75	18E
0005433367378	21743	76	18F
0005435652702	21743	77	19A
0005435652686	21743	78	19D
0005435652710	21743	79	19C
0005435652673	21743	80	19E
0005435652689	21743	81	19F
0005435652716	21743	82	20A
0005435652672	21743	83	20C
0005435652708	21743	84	20D
0005435652704	21743	85	20E
0005435652706	21743	86	20F
0005433763096	9352	1	1C
0005433805122	9352	2	1F
0005433784682	9352	3	2A
0005433805120	9352	4	1H
0005433805119	9352	5	2B
0005433784679	9352	6	2H
0005432665260	9352	7	3G
0005433784695	9352	8	3H
0005433784692	9352	9	4G
0005434170825	9352	10	9B
0005432667439	9352	11	9A
0005433763099	9352	12	9G
0005432665259	9352	13	12E
0005434170873	9352	14	13B
0005433763094	9352	15	13E
0005433784674	9352	16	13H
0005433784670	9352	17	14B
0005434170835	9352	18	14E
0005434151668	9352	19	15A
0005433784669	9352	20	14H
0005433784694	9352	21	15F
0005433784672	9352	22	16B
0005434170813	9352	23	17D
0005433784678	9352	24	17B
0005433784668	9352	25	17E
0005433784681	9352	26	17F
0005434170822	9352	27	18A
0005433784691	9352	28	17H
0005433784693	9352	29	18F
0005433784688	9352	30	18G
0005434170850	9352	31	18H
0005433784690	9352	32	19D
0005432665258	9352	33	19G
0005433763101	9352	34	19H
0005434270178	9352	35	20D
0005433784698	9352	36	20B
0005432657427	9352	37	20E
0005432666373	9352	38	20F
0005433784677	9352	39	20H
0005433805121	9352	40	20G
0005434170828	9352	41	21A
0005433763100	9352	42	21D
0005433784680	9352	43	21E
0005433763105	9352	44	21F
0005433784667	9352	45	21G
0005433784663	9352	46	22D
0005434170843	9352	47	23A
0005433763102	9352	48	22H
0005433763098	9352	49	23B
0005434273055	9352	50	23E
0005433784666	9352	51	23G
0005433805124	9352	52	24A
0005434270179	9352	53	24G
0005434170844	9352	54	25E
0005433784664	9352	55	25F
0005434170854	9352	56	27B
0005434270171	9352	57	27E
0005433763092	9352	58	27G
0005434170863	9352	59	28A
0005433784665	9352	60	27H
0005432657426	9352	61	28B
0005433784684	9352	62	28D
0005433784696	9352	63	28F
0005433784687	9352	64	28G
0005433784683	9352	65	29A
0005432657428	9352	66	29E
0005433763106	9352	67	30E
0005433763107	9352	68	30F
0005433784673	9352	69	31B
0005433763093	9352	70	31E
0005433805125	9352	71	31D
0005433784697	9352	72	31F
0005433763104	9352	73	32D
0005433763097	9352	74	32G
0005434170849	9352	75	33A
0005433763095	9352	76	33B
0005434273056	9352	77	33H
0005434170806	9352	78	34A
0005434151669	9352	79	34E
0005433784675	9352	80	34G
0005433784689	9352	81	35A
0005433784671	9352	82	35F
0005433784686	9352	83	35H
0005433784685	9352	84	36A
0005434170848	9352	85	36B
0005433784676	9352	86	36D
0005433763103	9352	87	36E
0005434170836	9352	88	37B
0005432666374	9352	89	37E
0005433784699	9352	90	38A
0005434151662	9352	91	38B
0005434170840	9352	92	39D
0005433805123	9352	93	39F
0005433784463	26233	1	1C
0005433784318	26233	2	1B
0005433804950	26233	3	1F
0005433804817	26233	4	1G
0005433804839	26233	5	2B
0005433804822	26233	6	3A
0005434270189	26233	7	2H
0005435269695	26233	8	3C
0005433762966	26233	9	4A
0005434170949	26233	10	3H
0005434151682	26233	11	5A
0005433784383	26233	12	4H
0005433763015	26233	13	5G
0005433804853	26233	14	5F
0005433784420	26233	15	9B
0005434269087	26233	16	11D
0005433763018	26233	17	11G
0005434170958	26233	18	12B
0005433784329	26233	19	12E
0005433784317	26233	20	12G
0005433784423	26233	21	12H
0005433784494	26233	22	13A
0005433804816	26233	23	13E
0005432666353	26233	24	14G
0005434170947	26233	25	15B
0005432659672	26233	26	15D
0005432657401	26233	27	15F
0005433804856	26233	28	15H
0005434170946	26233	29	15G
0005433784350	26233	30	16A
0005433784377	26233	31	16F
0005433784431	26233	32	17D
0005433804789	26233	33	17H
0005433784417	26233	34	18A
0005433762995	26233	35	18G
0005433763011	26233	36	19A
0005434170954	26233	37	19H
0005433784418	26233	38	19G
0005433804838	26233	39	20A
0005433784444	26233	40	20E
0005434151683	26233	41	20H
0005433784327	26233	42	20G
0005433762958	26233	43	21D
0005434151681	26233	44	21F
0005434170955	26233	45	21E
0005434170951	26233	46	21H
0005433784439	26233	47	22A
0005433804844	26233	48	22D
0005433784375	26233	49	22E
0005433784443	26233	50	22G
0005435269693	26233	51	22H
0005434170956	26233	52	23B
0005433784498	26233	53	23E
0005433784300	26233	54	23H
0005433804814	26233	55	24B
0005433784487	26233	56	24E
0005434170945	26233	57	24F
0005433804826	26233	58	27B
0005433762996	26233	59	27E
0005434170948	26233	60	27D
0005433804833	26233	61	27F
0005433784510	26233	62	27H
0005433804951	26233	63	28B
0005433784308	26233	64	28E
0005433784427	26233	65	29E
0005433804848	26233	66	29H
0005433762985	26233	67	30A
0005433784307	26233	68	30E
0005433784493	26233	69	30D
0005433784559	26233	70	31A
0005433784462	26233	71	31H
0005433804952	26233	72	32B
0005434170950	26233	73	32D
0005433804825	26233	74	33D
0005435269694	26233	75	33H
0005432666356	26233	76	33G
0005434170943	26233	77	34E
0005433804925	26233	78	34G
0005434170953	26233	79	34F
0005433784393	26233	80	34H
0005433762994	26233	81	35B
0005434270190	26233	82	35A
0005434269085	26233	83	35D
0005434170952	26233	84	35F
0005434269086	26233	85	36A
0005433804804	26233	86	36B
0005434170944	26233	87	36F
0005434271295	26233	88	37A
0005433762959	26233	89	36H
0005433763019	26233	90	37D
0005432666357	26233	91	37F
0005433804846	26233	92	37H
0005433762965	26233	93	38A
0005433784362	26233	94	38E
0005432666352	26233	95	38F
0005433784376	26233	96	39D
0005434170957	26233	97	39F
0005435929596	4923	1	1A
0005435135633	4923	2	2B
0005435135635	4923	3	3C
0005435135634	4923	4	4B
0005435135631	4923	5	5A
0005435929610	4923	6	6C
0005435135632	4923	7	21D
0005435929605	4923	8	23B
0005435929624	33057	1	1B
0005435135607	33057	2	3D
0005435929623	33057	3	6C
0005435135593	33057	4	20D
0005435929625	33057	5	22C
0005434983251	9482	1	1A
0005434217894	9482	2	2A
0005434983247	9482	3	3D
0005434983249	9482	4	4D
0005434217914	9482	5	5A
0005434983250	9482	6	7A
0005434217915	9482	7	18C
0005434217913	9482	8	19D
0005434983252	9482	9	20C
0005434983248	9482	10	21C
0005434983211	27335	1	1B
0005434217939	27335	2	3D
0005434217937	27335	3	7C
0005434983212	27335	4	7D
0005434217936	27335	5	20D
0005434217938	27335	6	21C
0005433959960	24290	1	1F
0005433985143	24290	2	1C
0005433985271	24290	3	1H
0005433985406	24290	4	4A
0005433985140	24290	5	4G
0005433985170	24290	6	5A
0005433959934	24290	7	9A
0005433959924	24290	8	9H
0005433959895	24290	9	9G
0005433985164	24290	10	11A
0005433985303	24290	11	12D
0005433959943	24290	12	13B
0005433985274	24290	13	13A
0005433985147	24290	14	13G
0005433959959	24290	15	13H
0005433985221	24290	16	14B
0005433985273	24290	17	14H
0005433959872	24290	18	15E
0005433985216	24290	19	15D
0005433985199	24290	20	15H
0005433985304	24290	21	16A
0005433959913	24290	22	16D
0005433959933	24290	23	16H
0005433959944	24290	24	17A
0005433959904	24290	25	17B
0005433959963	24290	26	17G
0005433985272	24290	27	17F
0005433985220	24290	28	17H
0005433959869	24290	29	18F
0005433985135	24290	30	19B
0005433985163	24290	31	19D
0005433985144	24290	32	19F
0005433985243	24290	33	19G
0005433985200	24290	34	20B
0005433959952	24290	35	20G
0005433985293	24290	36	20F
0005433985285	24290	37	21A
0005433985138	24290	38	21G
0005433959893	24290	39	21F
0005433985162	24290	40	22B
0005433959894	24290	41	22D
0005433985160	24290	42	22F
0005433959907	24290	43	23F
0005433985142	24290	44	23G
0005433985373	24290	45	24B
0005433985202	24290	46	24A
0005433985127	24290	47	27D
0005433985344	24290	48	27H
0005433985374	24290	49	28D
0005433985139	24290	50	28F
0005433985292	24290	51	29B
0005433959897	24290	52	30H
0005433959947	24290	53	31B
0005433985233	24290	54	31D
0005433959914	24290	55	31G
0005433959871	24290	56	32F
0005433985141	24290	57	32G
0005433985197	24290	58	33H
0005433985278	24290	59	34F
0005433985198	24290	60	36A
0005433959950	24290	61	35H
0005433985165	24290	62	36D
0005433959873	24290	63	37A
0005433985215	24290	64	37B
0005433985148	24290	65	37H
0005433985201	24290	66	38D
0005433959900	24290	67	38E
0005433985157	24290	68	38G
0005433959874	24290	69	39E
0005433960405	25930	1	1B
0005433985559	25930	2	2B
0005433960409	25930	3	2H
0005433985564	25930	4	4B
0005433985582	25930	5	4C
0005433960413	25930	6	4H
0005433960429	25930	7	5B
0005433960412	25930	8	5A
0005433985586	25930	9	5F
0005433985584	25930	10	11A
0005433960416	25930	11	11H
0005433985565	25930	12	12D
0005433960439	25930	13	12B
0005433960390	25930	14	12E
0005433960437	25930	15	12H
0005433985563	25930	16	12G
0005433985571	25930	17	13G
0005433960438	25930	18	14A
0005433985598	25930	19	13H
0005433960421	25930	20	14B
0005433960434	25930	21	14D
0005433985602	25930	22	14G
0005433960398	25930	23	15E
0005433985579	25930	24	15D
0005433985580	25930	25	15F
0005433960393	25930	26	16A
0005433985566	25930	27	16B
0005433985578	25930	28	16F
0005433960406	25930	29	16E
0005433985587	25930	30	16H
0005433960415	25930	31	17A
0005433985591	25930	32	17F
0005433985576	25930	33	18B
0005433960427	25930	34	18H
0005433960418	25930	35	19E
0005433960394	25930	36	19D
0005433985573	25930	37	19G
0005433985604	25930	38	20B
0005433960442	25930	39	20D
0005433985597	25930	40	20F
0005433960432	25930	41	20G
0005433960392	25930	42	21E
0005433985568	25930	43	21H
0005433985594	25930	44	22D
0005433985588	25930	45	22E
0005433960435	25930	46	23G
0005433985600	25930	47	23F
0005433960396	25930	48	23H
0005433960440	25930	49	24B
0005433985592	25930	50	24F
0005433960417	25930	51	24E
0005433985575	25930	52	24G
0005433960441	25930	53	25D
0005433985569	25930	54	27A
0005433985581	25930	55	25F
0005433960424	25930	56	27E
0005433960431	25930	57	27F
0005433960420	25930	58	28A
0005433960404	25930	59	28B
0005433985560	25930	60	28D
0005433985561	25930	61	28F
0005433960433	25930	62	29A
0005433985574	25930	63	29D
0005433960395	25930	64	29E
0005433985577	25930	65	29F
0005433960426	25930	66	30B
0005433960414	25930	67	30A
0005433985596	25930	68	30E
0005433960410	25930	69	30G
0005433985601	25930	70	30F
0005433960399	25930	71	30H
0005433960397	25930	72	31B
0005433985595	25930	73	31D
0005433960400	25930	74	31E
0005433960411	25930	75	32A
0005433985585	25930	76	32F
0005433960408	25930	77	32E
0005433985603	25930	78	32G
0005433960425	25930	79	33A
0005433960402	25930	80	33B
0005433960419	25930	81	33E
0005433985567	25930	82	33F
0005433985572	25930	83	33H
0005433960403	25930	84	34B
0005433985599	25930	85	34D
0005433985593	25930	86	34E
0005433985589	25930	87	35A
0005433960430	25930	88	35D
0005433960391	25930	89	36B
0005433985605	25930	90	36D
0005433960423	25930	91	36F
0005433960401	25930	92	36G
0005433985583	25930	93	37A
0005433985562	25930	94	37B
0005433960422	25930	95	37D
0005433985590	25930	96	37G
0005433985570	25930	97	37F
0005433960428	25930	98	38A
0005433960436	25930	99	38E
0005433960407	25930	100	38G
0005434480140	924	1	1B
0005434480154	924	2	1C
0005434480135	924	3	1D
0005434480144	924	4	2A
0005432269475	924	5	2B
0005433165722	924	6	2C
0005433165747	924	7	2D
0005434480147	924	8	3A
0005434480149	924	9	3C
0005433165695	924	10	3D
0005433165719	924	11	4B
0005434480142	924	12	4A
0005434480146	924	13	4C
0005434480148	924	14	4D
0005434480136	924	15	5A
0005433165721	924	16	5B
0005433165705	924	17	5C
0005434480141	924	18	5D
0005433165713	924	19	6A
0005433165696	924	20	6B
0005433165698	924	21	6C
0005434480159	924	22	6D
0005434480153	924	23	7B
0005434480138	924	24	7A
0005432269474	924	25	7D
0005434480152	924	26	18B
0005434480137	924	27	18C
0005434480150	924	28	19A
0005433165720	924	29	19C
0005434480134	924	30	19D
0005434480139	924	31	20A
0005434480156	924	32	20C
0005434480151	924	33	21A
0005433165759	924	34	21C
0005434480145	924	35	21D
0005434480157	924	36	22A
0005434480155	924	37	22D
0005434480143	924	38	23A
0005434480158	924	39	23B
0005434479883	16579	1	1A
0005434479987	16579	2	1B
0005433165807	16579	3	1C
0005434479925	16579	4	1D
0005433165806	16579	5	2B
0005434479950	16579	6	2C
0005433165809	16579	7	2D
0005433165812	16579	8	3D
0005433165813	16579	9	4A
0005434479906	16579	10	5B
0005434480030	16579	11	5C
0005433165810	16579	12	5D
0005434479900	16579	13	6A
0005434479988	16579	14	6B
0005434479910	16579	15	6C
0005433165808	16579	16	7A
0005433165815	16579	17	7B
0005433165811	16579	18	7C
0005434479964	16579	19	18A
0005434479946	16579	20	18B
0005433165803	16579	21	18C
0005434479911	16579	22	19B
0005434479936	16579	23	19C
0005434480029	16579	24	19D
0005433165814	16579	25	20A
0005434479958	16579	26	20D
0005434479947	16579	27	21A
0005433165804	16579	28	21B
0005434479924	16579	29	21C
0005434479899	16579	30	21D
0005434479907	16579	31	22B
0005433165805	16579	32	23B
0005435149914	10322	1	1A
0005435142465	10322	2	1C
0005435149916	10322	3	1D
0005435142464	10322	4	2B
0005435149922	10322	5	2C
0005435142471	10322	6	3C
0005433289739	10322	7	3D
0005435149925	10322	8	4B
0005435142463	10322	9	4D
0005435142473	10322	10	5B
0005435149917	10322	11	5C
0005435149923	10322	12	6A
0005435149920	10322	13	6B
0005435149926	10322	14	7A
0005435142461	10322	15	7B
0005435142467	10322	16	7D
0005435142460	10322	17	18B
0005435149919	10322	18	18D
0005435142469	10322	19	19A
0005435149924	10322	20	19C
0005433289731	10322	21	19D
0005435142468	10322	22	20A
0005435149915	10322	23	20B
0005435149921	10322	24	20C
0005435142470	10322	25	20D
0005435386478	10322	26	21B
0005435149918	10322	27	21D
0005435142466	10322	28	22A
0005435386468	10322	29	22B
0005433289732	10322	30	22D
0005435142462	10322	31	22C
0005435142472	10322	32	23A
0005435149820	21965	1	1A
0005433289800	21965	2	1B
0005435142388	21965	3	1D
0005435149838	21965	4	2A
0005433289807	21965	5	2B
0005435149789	21965	6	2C
0005435149792	21965	7	2D
0005433289806	21965	8	3B
0005435386525	21965	9	3C
0005433289803	21965	10	3D
0005433289798	21965	11	4B
0005435149819	21965	12	4C
0005435386526	21965	13	4D
0005433289805	21965	14	5A
0005435142386	21965	15	5C
0005435142403	21965	16	5D
0005435386529	21965	17	6A
0005435142338	21965	18	6B
0005435149803	21965	19	6C
0005435142341	21965	20	6D
0005435149804	21965	21	7A
0005435142363	21965	22	7B
0005435386528	21965	23	7C
0005435142387	21965	24	18A
0005435149858	21965	25	18B
0005435386530	21965	26	18D
0005433289801	21965	27	19C
0005435142337	21965	28	19B
0005433289799	21965	29	20A
0005435149791	21965	30	20B
0005435142344	21965	31	20C
0005435386527	21965	32	20D
0005435142404	21965	33	21A
0005433289802	21965	34	21B
0005433289804	21965	35	21C
0005435149818	21965	36	21D
0005435149814	21965	37	22B
0005435142394	21965	38	22D
0005435149790	21965	39	22C
0005435149813	21965	40	23B
0005435319458	11223	1	1C
0005435528916	11223	2	1D
0005434573235	11223	3	2A
0005435502019	11223	4	2D
0005435528902	11223	5	2F
0005434573239	11223	6	3A
0005435528945	11223	7	4A
0005435545634	11223	8	4C
0005434573237	11223	9	5A
0005434573234	11223	10	5C
0005434573245	11223	11	5F
0005434573240	11223	12	6A
0005435528999	11223	13	6C
0005435501979	11223	14	6D
0005435502000	11223	15	7A
0005434573233	11223	16	7D
0005435502048	11223	17	7F
0005435319435	11223	18	8D
0005435502049	11223	19	9C
0005435528964	11223	20	9D
0005435528922	11223	21	10C
0005435528934	11223	22	11E
0005435528946	11223	23	11F
0005434573243	11223	24	12A
0005435528914	11223	25	12F
0005435528944	11223	26	13C
0005435528950	11223	27	13F
0005434573236	11223	28	14A
0005435502020	11223	29	14D
0005434573232	11223	30	15A
0005435501955	11223	31	16C
0005435528888	11223	32	16D
0005434573241	11223	33	16E
0005434573244	11223	34	16F
0005435319459	11223	35	17A
0005435501957	11223	36	17F
0005435528915	11223	37	18C
0005435545621	11223	38	19D
0005435545635	11223	39	19E
0005435501956	11223	40	20A
0005434573238	11223	41	20D
0005434573242	11223	42	20E
0005435502047	11223	43	20F
0005434573136	20908	1	1C
0005435502146	20908	2	1D
0005435502133	20908	3	1F
0005435517770	20908	4	2A
0005435502150	20908	5	2C
0005435517767	20908	6	2D
0005432291910	20908	7	2F
0005435517771	20908	8	3A
0005435508275	20908	9	3C
0005435502141	20908	10	3F
0005435319516	20908	11	4A
0005434573118	20908	12	4C
0005435502138	20908	13	4D
0005434573117	20908	14	5A
0005434573155	20908	15	5C
0005434573113	20908	16	5E
0005435508272	20908	17	6A
0005434573111	20908	18	6C
0005435517766	20908	19	6D
0005435319522	20908	20	7A
0005435319521	20908	21	7D
0005435502152	20908	22	7E
0005435319517	20908	23	7F
0005435502145	20908	24	8A
0005435502136	20908	25	8D
0005435508269	20908	26	8F
0005435502149	20908	27	9A
0005435508267	20908	28	9C
0005435508270	20908	29	9D
0005432291911	20908	30	9F
0005435517775	20908	31	10C
0005435517774	20908	32	10D
0005434573114	20908	33	10F
0005435502143	20908	34	11C
0005435319520	20908	35	11E
0005435508266	20908	36	12C
0005435517777	20908	37	12E
0005435517768	20908	38	12F
0005435319523	20908	39	13C
0005435508274	20908	40	13D
0005435502144	20908	41	13E
0005434573121	20908	42	13F
0005434573133	20908	43	14A
0005435319514	20908	44	14D
0005435502148	20908	45	15D
0005435502134	20908	46	15E
0005435502132	20908	47	15F
0005435502137	20908	48	16A
0005435502142	20908	49	16C
0005434573157	20908	50	16D
0005435517776	20908	51	16F
0005435502135	20908	52	17A
0005435502139	20908	53	17C
0005435319518	20908	54	17D
0005435319519	20908	55	17E
0005435502140	20908	56	17F
0005435502147	20908	57	18A
0005434573154	20908	58	18C
0005435319515	20908	59	18E
0005434573153	20908	60	18F
0005435517773	20908	61	19A
0005435508273	20908	62	19C
0005435508271	20908	63	19D
0005435517772	20908	64	19E
0005435508268	20908	65	19F
0005435502151	20908	66	20A
0005434573107	20908	67	20C
0005435517769	20908	68	20F
0005433683316	24307	1	2B
0005433683314	24307	2	4A
0005433683312	24307	3	5B
0005433683317	24307	4	7A
0005433683319	24307	5	18B
0005433683315	24307	6	18C
0005433927400	24307	7	20C
0005433683318	24307	8	20D
0005433927403	24307	9	22C
0005433683313	24307	10	23A
0005433683299	29286	1	1B
0005433927419	29286	2	1C
0005433927420	29286	3	2B
0005433683298	29286	4	3C
0005433927421	29286	5	4A
0005433927418	29286	6	5A
0005433927424	29286	7	6A
0005433927417	29286	8	7B
0005433683300	29286	9	19A
0005433927423	29286	10	19B
0005433927422	29286	11	20C
0005432692545	2938	1	1D
0005432692560	2938	2	2C
0005432692618	2938	3	3D
0005432692634	2938	4	5C
0005432692530	2938	5	6D
0005432692538	2938	6	7C
0005432692533	2938	7	8D
0005432692529	2938	8	9A
0005432692595	2938	9	9E
0005432692559	2938	10	10A
0005432692556	2938	11	10D
0005432692546	2938	12	12C
0005432692544	2938	13	12F
0005432692591	2938	14	13A
0005432692604	2938	15	14E
0005432692596	2938	16	14F
0005432692700	2938	17	15E
0005432692615	2938	18	16A
0005432692539	2938	19	16E
0005432692597	2938	20	16F
0005432692699	2938	21	17F
0005432692564	2938	22	18F
0005432692594	2938	23	19D
0005433123607	2924	1	1D
0005432706583	2924	2	2C
0005432706587	2924	3	2F
0005432706579	2924	4	3C
0005433123570	2924	5	3D
0005433194827	2924	6	3F
0005433123643	2924	7	4D
0005432880568	2924	8	4E
0005432706591	2924	9	4F
0005433123608	2924	10	5A
0005432880601	2924	11	5C
0005432880603	2924	12	5D
0005432706569	2924	13	5F
0005432880662	2924	14	6A
0005432880602	2924	15	6E
0005432706572	2924	16	6F
0005432706580	2924	17	7C
0005433123600	2924	18	7D
0005432706573	2924	19	7E
0005432706584	2924	20	7F
0005432706592	2924	21	8C
0005432880559	2924	22	8E
0005432706578	2924	23	9A
0005432880558	2924	24	9E
0005433123617	2924	25	9F
0005432880570	2924	26	10F
0005433123592	2924	27	11E
0005432706589	2924	28	12C
0005432706585	2924	29	12A
0005432706590	2924	30	12D
0005432706574	2924	31	12E
0005432706593	2924	32	13C
0005432706577	2924	33	13D
0005432706571	2924	34	13E
0005432217755	2924	35	13F
0005433123648	2924	36	14A
0005432706575	2924	37	14C
0005432706570	2924	38	14F
0005432880606	2924	39	15A
0005432706581	2924	40	15D
0005433123644	2924	41	15E
0005433123595	2924	42	15F
0005433123606	2924	43	16A
0005433123622	2924	44	16C
0005432706586	2924	45	16D
0005433123614	2924	46	17A
0005432706576	2924	47	17C
0005432880577	2924	48	17D
0005432706594	2924	49	17E
0005433123599	2924	50	17F
0005433123565	2924	51	18A
0005432880608	2924	52	18C
0005432217756	2924	53	18E
0005432217754	2924	54	19A
0005433123647	2924	55	19C
0005432706588	2924	56	19D
0005433123649	2924	57	19E
0005433123597	2924	58	19F
0005432880569	2924	59	20A
0005432880578	2924	60	20C
0005433123594	2924	61	20D
0005432706582	2924	62	20E
0005433123598	2924	63	20F
0005432692858	30064	1	1A
0005432692844	30064	2	1C
0005432692857	30064	3	1D
0005433123762	30064	4	1F
0005432706402	30064	5	2A
0005432706334	30064	6	2C
0005433123775	30064	7	2D
0005432692872	30064	8	2F
0005432692862	30064	9	3A
0005433123771	30064	10	3C
0005432880701	30064	11	3D
0005432692870	30064	12	3F
0005433123776	30064	13	4A
0005432692859	30064	14	4C
0005432880711	30064	15	4D
0005432880706	30064	16	4E
0005433123777	30064	17	5A
0005432692869	30064	18	5C
0005433123766	30064	19	5D
0005432706408	30064	20	5E
0005432692866	30064	21	5F
0005432692856	30064	22	6A
0005432706347	30064	23	6C
0005432706435	30064	24	6D
0005432692854	30064	25	6E
0005432706394	30064	26	6F
0005432880710	30064	27	7A
0005432706453	30064	28	7C
0005432880712	30064	29	7D
0005432706320	30064	30	7E
0005433123779	30064	31	7F
0005432692845	30064	32	8A
0005433123768	30064	33	8C
0005432692847	30064	34	8E
0005433123770	30064	35	8F
0005432706356	30064	36	9A
0005432880703	30064	37	9C
0005432706426	30064	38	9D
0005433123769	30064	39	9E
0005433123773	30064	40	9F
0005432692861	30064	41	10A
0005432692851	30064	42	10D
0005432706369	30064	43	10E
0005432706336	30064	44	10F
0005432706509	30064	45	11A
0005432692848	30064	46	11D
0005432692867	30064	47	11E
0005433123765	30064	48	11F
0005432706434	30064	49	12A
0005433123774	30064	50	12C
0005432706477	30064	51	12D
0005432880704	30064	52	12E
0005432880715	30064	53	12F
0005432880713	30064	54	13A
0005432692850	30064	55	13D
0005432706427	30064	56	13E
0005432692846	30064	57	13F
0005432706436	30064	58	14A
0005433123763	30064	59	14C
0005433123761	30064	60	14D
0005432880708	30064	61	14E
0005432706484	30064	62	14F
0005432692871	30064	63	15A
0005433123767	30064	64	15C
0005432706407	30064	65	15D
0005432706333	30064	66	15E
0005432692855	30064	67	15F
0005433123778	30064	68	16A
0005432706452	30064	69	16C
0005432692865	30064	70	16D
0005432692843	30064	71	16E
0005432692863	30064	72	16F
0005432692868	30064	73	17A
0005432692853	30064	74	17C
0005432880714	30064	75	17D
0005432880705	30064	76	17E
0005432706399	30064	77	17F
0005433123772	30064	78	18A
0005432692852	30064	79	18C
0005432692860	30064	80	18E
0005432880707	30064	81	18F
0005432692864	30064	82	19A
0005432880702	30064	83	19C
0005433123760	30064	84	19D
0005432692849	30064	85	19E
0005432880709	30064	86	19F
0005433123780	30064	87	20A
0005432706410	30064	88	20C
0005432706398	30064	89	20D
0005432692873	30064	90	20E
0005433123764	30064	91	20F
0005434979557	23678	1	1A
0005434988647	23678	2	1B
0005434979559	23678	3	1C
0005434988651	23678	4	1D
0005434979542	23678	5	2B
0005434988648	23678	6	2A
0005434979538	23678	7	2C
0005434988646	23678	8	2D
0005434988650	23678	9	3A
0005434979551	23678	10	3B
0005434979532	23678	11	3C
0005434988642	23678	12	3D
0005434988638	23678	13	4A
0005434979548	23678	14	4B
0005434979534	23678	15	4D
0005434988645	23678	16	5A
0005434979533	23678	17	5B
0005434979546	23678	18	5D
0005434988652	23678	19	6A
0005434988649	23678	20	6B
0005434979535	23678	21	6C
0005434979537	23678	22	6D
0005434979550	23678	23	7B
0005434979536	23678	24	7C
0005434988639	23678	25	7D
0005434988644	23678	26	18A
0005434979531	23678	27	18B
0005434979555	23678	28	18C
0005434979553	23678	29	18D
0005434979554	23678	30	19A
0005434979556	23678	31	19B
0005434979558	23678	32	19C
0005434979549	23678	33	19D
0005434988641	23678	34	20A
0005434979529	23678	35	20B
0005434979539	23678	36	20C
0005434988653	23678	37	20D
0005434979544	23678	38	21A
0005434979543	23678	39	21B
0005434988643	23678	40	21C
0005434979540	23678	41	21D
0005434979547	23678	42	22A
0005434988640	23678	43	22B
0005434979545	23678	44	22C
0005434979530	23678	45	22D
0005434979541	23678	46	23A
0005434979552	23678	47	23B
0005434979391	27518	1	1A
0005434979294	27518	2	1C
0005434979372	27518	3	1D
0005434979289	27518	4	2B
0005434979279	27518	5	2C
0005434979284	27518	6	3A
0005434979266	27518	7	3C
0005434979307	27518	8	4B
0005434979309	27518	9	4C
0005434979290	27518	10	4D
0005434979310	27518	11	5B
0005434979342	27518	12	5C
0005434979381	27518	13	5D
0005434979267	27518	14	6B
0005434979276	27518	15	6C
0005434979288	27518	16	6D
0005434979355	27518	17	7C
0005434979271	27518	18	18A
0005434979349	27518	19	18C
0005434979457	27518	20	19A
0005434979458	27518	21	20A
0005434979357	27518	22	20B
0005434979268	27518	23	20C
0005434979308	27518	24	21A
0005434979380	27518	25	21B
0005434979382	27518	26	21C
0005434979269	27518	27	21D
0005434979348	27518	28	22D
0005434302421	10300	1	3B
0005434302426	10300	2	18A
0005434302425	10300	3	18B
0005434302424	10300	4	18D
0005434302423	10300	5	19C
0005434302854	10300	6	21B
0005434302422	10300	7	23A
0005433113519	19618	1	4C
0005433113520	19618	2	18A
0005433113521	19618	3	18D
0005433113522	19618	4	20D
0005435939863	3582	1	1A
0005435068735	3582	2	1F
0005435068702	3582	3	2A
0005435068706	3582	4	2C
0005435068732	3582	5	2D
0005435068726	3582	6	2F
0005435068728	3582	7	3A
0005435068731	3582	8	3D
0005435925077	3582	9	3C
0005435068707	3582	10	3F
0005435925090	3582	11	4A
0005435925091	3582	12	4C
0005435925074	3582	13	4D
0005435068696	3582	14	4E
0005435068733	3582	15	4F
0005435068711	3582	16	5A
0005435068690	3582	17	5D
0005435925070	3582	18	6A
0005435718907	3582	19	6D
0005435068703	3582	20	6E
0005435068691	3582	21	7A
0005435068715	3582	22	7D
0005435068692	3582	23	7F
0005435068698	3582	24	8A
0005435068722	3582	25	8C
0005435068725	3582	26	8D
0005435068729	3582	27	8E
0005435068720	3582	28	9A
0005435068694	3582	29	9C
0005435068740	3582	30	9D
0005435925076	3582	31	9E
0005435068713	3582	32	9F
0005435068721	3582	33	10A
0005435925089	3582	34	10C
0005435068718	3582	35	10E
0005435068708	3582	36	10D
0005435068730	3582	37	10F
0005435068724	3582	38	11A
0005435068723	3582	39	11C
0005435068719	3582	40	11F
0005435068689	3582	41	12A
0005435068736	3582	42	12C
0005435068701	3582	43	12F
0005435925093	3582	44	13C
0005435068709	3582	45	13D
0005435068712	3582	46	14A
0005435068688	3582	47	14C
0005435718903	3582	48	14D
0005435068693	3582	49	14E
0005435068697	3582	50	15A
0005435068704	3582	51	15C
0005435068738	3582	52	15D
0005435068699	3582	53	15E
0005435718906	3582	54	15F
0005435068716	3582	55	16C
0005435718904	3582	56	16F
0005435068717	3582	57	17C
0005435068710	3582	58	17D
0005435068734	3582	59	17E
0005435068727	3582	60	18C
0005435718908	3582	61	18D
0005435718905	3582	62	18F
0005435068737	3582	63	19A
0005435068705	3582	64	19C
0005435068700	3582	65	19D
0005435068714	3582	66	19E
0005435068739	3582	67	19F
0005435925088	3582	68	20D
0005435718902	3582	69	20E
0005435068695	3582	70	20F
0005435068454	15304	1	1A
0005435068468	15304	2	1C
0005435068273	15304	3	1D
0005435068303	15304	4	2F
0005435068244	15304	5	3A
0005435068182	15304	6	4E
0005435068317	15304	7	4F
0005435068261	15304	8	5E
0005435068297	15304	9	7D
0005435068354	15304	10	7E
0005435068382	15304	11	8C
0005435068262	15304	12	8D
0005435068176	15304	13	8E
0005435068201	15304	14	8F
0005435068356	15304	15	9D
0005435068248	15304	16	11E
0005435068298	15304	17	12A
0005435068467	15304	18	12C
0005435068199	15304	19	12D
0005435068174	15304	20	12E
0005435068173	15304	21	13E
0005435068253	15304	22	14A
0005435068163	15304	23	15A
0005435068333	15304	24	15F
0005435068164	15304	25	16A
0005435068316	15304	26	16E
0005435068295	15304	27	17A
0005435068249	15304	28	17C
0005435068296	15304	29	17E
0005435068254	15304	30	17F
0005435068299	15304	31	18C
0005435068294	15304	32	18E
0005435068383	15304	33	18F
0005435068453	15304	34	19C
0005435068177	15304	35	19E
0005435068355	15304	36	20A
0005432659691	18116	1	1A
0005432658576	18116	2	1B
0005432660802	18116	3	4A
0005432659690	18116	4	5A
0005432658577	18116	5	6A
0005432660803	18116	6	6B
0005432667420	26405	1	2A
0005432677522	67	1	1D
0005433101273	67	2	1F
0005432919567	67	3	2F
0005432901298	67	4	3A
0005432677521	67	5	3D
0005432919573	67	6	3F
0005433101216	67	7	4C
0005432919602	67	8	4F
0005432919515	67	9	4D
0005433101308	67	10	6A
0005433101203	67	11	6D
0005432919624	67	12	6C
0005433101231	67	13	7A
0005433101172	67	14	6F
0005432919553	67	15	7F
0005433101264	67	16	8A
0005432901314	67	17	8C
0005433101331	67	18	9A
0005433101205	67	19	8F
0005433101257	67	20	9B
0005433101307	67	21	9E
0005433101272	67	22	10B
0005432919569	67	23	10D
0005432901352	67	24	11A
0005433101206	67	25	11C
0005432391950	67	26	12C
0005433101327	67	27	12E
0005433101265	67	28	12D
0005432919534	67	29	12F
0005432901377	67	30	13A
0005433101289	67	31	13B
0005432919589	67	32	13F
0005432919531	67	33	14B
0005433101326	67	34	14E
0005432919563	67	35	15E
0005433101298	67	36	15D
0005432919561	67	37	15F
0005432919533	67	38	16A
0005433101301	67	39	16B
0005432919570	67	40	16D
0005432919623	67	41	16C
0005432919514	67	42	16E
0005432901351	67	43	16F
0005432919544	67	44	17A
0005433101171	67	45	17B
0005433101200	67	46	17D
0005433101238	67	47	18B
0005432919568	67	48	19B
0005432919564	67	49	18F
0005432919548	67	50	18E
0005433101256	67	51	19D
0005433101288	67	52	19E
0005432901363	67	53	20A
0005432919556	67	54	21D
0005433101305	67	55	21E
0005433101328	67	56	21F
0005432901364	67	57	22B
0005432677513	67	58	22D
0005433101336	67	59	23A
0005432919557	67	60	23C
0005433101227	67	61	23D
0005432901313	67	62	23E
0005432157478	67	63	24A
0005433101260	67	64	23F
0005432677507	67	65	24C
0005432901325	67	66	24E
0005432919572	67	67	24D
0005433101296	67	68	25B
0005432919622	67	69	25A
0005433101218	67	70	25D
0005433101226	67	71	25F
0005432901371	67	72	27A
0005433101228	67	73	27D
0005433101306	67	74	27E
0005433101204	67	75	28A
0005433101156	67	76	27F
0005433101295	67	77	28C
0005432919504	67	78	28F
0005432919588	67	79	29B
0005433101235	67	80	29A
0005432677514	67	81	29C
0005433101333	67	82	29F
0005432901357	67	83	30D
0005433101279	67	84	30F
0005432901350	67	85	31B
0005433101329	67	86	31A
0005433101332	67	87	31C
0005433101330	67	88	31E
0005432391951	67	89	31F
0005432817268	229	1	1A
0005432261593	229	2	1C
0005432261589	229	3	2C
0005432261584	229	4	3A
0005432261575	229	5	3D
0005432207641	229	6	3C
0005432817246	229	7	4A
0005432261566	229	8	5C
0005432753245	229	9	5D
0005432817249	229	10	6A
0005432261597	229	11	5F
0005432756794	229	12	6D
0005432753258	229	13	6C
0005432261572	229	14	7A
0005432261590	229	15	7D
0005432261573	229	16	8A
0005432817253	229	17	7F
0005432817260	229	18	9A
0005432817252	229	19	9C
0005432817266	229	20	9E
0005432261565	229	21	9D
0005432261594	229	22	9F
0005432261555	229	23	10F
0005432817254	229	24	11D
0005433690894	229	25	11C
0005432261582	229	26	12A
0005432261559	229	27	12E
0005432817251	229	28	12D
0005432817247	229	29	12F
0005432261596	229	30	13B
0005432261556	229	31	13E
0005432261558	229	32	14A
0005432261600	229	33	14B
0005432261569	229	34	14E
0005432261601	229	35	14D
0005432817270	229	36	14F
0005432288961	229	37	15C
0005434153525	229	38	15B
0005432261560	229	39	15F
0005432817261	229	40	15E
0005432261588	229	41	16B
0005432261591	229	42	16E
0005432261599	229	43	16D
0005432261581	229	44	16F
0005432817242	229	45	17B
0005432261576	229	46	17A
0005432261562	229	47	17F
0005432261579	229	48	18A
0005432261578	229	49	18C
0005434153526	229	50	18E
0005432261580	229	51	18D
0005432817269	229	52	19B
0005432817264	229	53	20A
0005432817241	229	54	20C
0005432817244	229	55	20B
0005432288962	229	56	20D
0005432817259	229	57	21B
0005432261577	229	58	21F
0005432261561	229	59	22C
0005432261567	229	60	22D
0005432261592	229	61	22F
0005432817258	229	62	23A
0005432261586	229	63	23C
0005433690899	229	64	23D
0005432261598	229	65	23E
0005432261564	229	66	24A
0005432261571	229	67	24D
0005432817248	229	68	24C
0005432261574	229	69	24E
0005432261602	229	70	25A
0005432817262	229	71	25B
0005432817255	229	72	26B
0005432261563	229	73	26C
0005432817243	229	74	26E
0005432817263	229	75	26D
0005432261557	229	76	27A
0005432817257	229	77	26F
0005432261568	229	78	27D
0005432817267	229	79	27F
0005432261583	229	80	27E
0005432756795	229	81	28B
0005432817265	229	82	28C
0005432817256	229	83	29A
0005432261570	229	84	29C
0005432261595	229	85	29E
0005432817245	229	86	29F
0005432288963	229	87	30C
0005432261585	229	88	30D
0005432261587	229	89	30F
0005432817250	229	90	31B
0005432020079	8041	1	1C
0005433101745	8041	2	1A
0005432044505	8041	3	1F
0005432919711	8041	4	1D
0005432391977	8041	5	2C
0005433101769	8041	6	2A
0005433101759	8041	7	3D
0005432677547	8041	8	3C
0005433101772	8041	9	4A
0005433101756	8041	10	3F
0005432020053	8041	11	4C
0005433101779	8041	12	5A
0005433101739	8041	13	5C
0005432020077	8041	14	5F
0005433101767	8041	15	6C
0005432677544	8041	16	6D
0005432020057	8041	17	7A
0005432751504	8041	18	7C
0005432751502	8041	19	8A
0005432751503	8041	20	7F
0005433101750	8041	21	8B
0005433101742	8041	22	8E
0005432020072	8041	23	9B
0005432020060	8041	24	9A
0005432020078	8041	25	9C
0005432020061	8041	26	9D
0005432020062	8041	27	10A
0005432919701	8041	28	9F
0005433101776	8041	29	10C
0005432020071	8041	30	11A
0005432020063	8041	31	10F
0005433101777	8041	32	11B
0005432020066	8041	33	11D
0005433101761	8041	34	12C
0005433101741	8041	35	12B
0005433101738	8041	36	12D
0005432391978	8041	37	13A
0005432919715	8041	38	13C
0005432020068	8041	39	13B
0005432919708	8041	40	13F
0005433101758	8041	41	13E
0005433101782	8041	42	14B
0005433101747	8041	43	14C
0005432020076	8041	44	14E
0005433101771	8041	45	14D
0005432919716	8041	46	14F
0005433101740	8041	47	15F
0005432919703	8041	48	16A
0005432753278	8041	49	16B
0005432919704	8041	50	16D
0005432020056	8041	51	16C
0005433101736	8041	52	16F
0005432045599	8041	53	17B
0005432045600	8041	54	17C
0005433101746	8041	55	17F
0005432753276	8041	56	18A
0005433101753	8041	57	18B
0005432391979	8041	58	18D
0005433101743	8041	59	18C
0005432919710	8041	60	18E
0005432677545	8041	61	18F
0005432020075	8041	62	19C
0005432020073	8041	63	19B
0005432020059	8041	64	19D
0005432919705	8041	65	20A
0005432919702	8041	66	19E
0005432020064	8041	67	20B
0005432020055	8041	68	20C
0005433101752	8041	69	20F
0005432919714	8041	70	21B
0005433101768	8041	71	21C
0005433101764	8041	72	22A
0005433101754	8041	73	21F
0005432391976	8041	74	22B
0005432753277	8041	75	22D
0005432044504	8041	76	22C
0005433101783	8041	77	22E
0005432919700	8041	78	22F
0005433101749	8041	79	23B
0005432020070	8041	80	23D
0005432919706	8041	81	23E
0005432677546	8041	82	23F
0005433101735	8041	83	24C
0005433101755	8041	84	24E
0005432919707	8041	85	24F
0005432020054	8041	86	25B
0005433101763	8041	87	25A
0005432919695	8041	88	25D
0005432020065	8041	89	25F
0005433101765	8041	90	26B
0005432020067	8041	91	26D
0005432919709	8041	92	26E
0005433101781	8041	93	27A
0005433101744	8041	94	27C
0005433101762	8041	95	27B
0005433101778	8041	96	27D
0005433101774	8041	97	27F
0005433101760	8041	98	27E
0005432919713	8041	99	28A
0005433101770	8041	100	28B
0005433101773	8041	101	28C
0005432020058	8041	102	28E
0005432020074	8041	103	28D
0005432919712	8041	104	28F
0005432919697	8041	105	29B
0005433101775	8041	106	29A
0005432919696	8041	107	29C
0005433101751	8041	108	29E
0005433101757	8041	109	29F
0005433101737	8041	110	30B
0005433101748	8041	111	30C
0005433101780	8041	112	30E
0005432919699	8041	113	31A
0005432020069	8041	114	31C
0005433101766	8041	115	31F
0005432919698	8041	116	31E
0005432816982	8040	1	1D
0005432817004	8040	2	2A
0005432817062	8040	3	2C
0005432901487	8040	4	2F
0005432901479	8040	5	3C
0005432817029	8040	6	3F
0005432817133	8040	7	3D
0005432901478	8040	8	4A
0005432817122	8040	9	4C
0005432817091	8040	10	5D
0005432002061	8040	11	7A
0005432901474	8040	12	8A
0005432901481	8040	13	8B
0005432901491	8040	14	8D
0005432901476	8040	15	9C
0005432816946	8040	16	11A
0005432816973	8040	17	11B
0005432901477	8040	18	12C
0005432901486	8040	19	12E
0005432901482	8040	20	13C
0005432901484	8040	21	13E
0005432817003	8040	22	14A
0005432816997	8040	23	15A
0005432817035	8040	24	15D
0005432901483	8040	25	15E
0005432817064	8040	26	16D
0005432817092	8040	27	16F
0005432817093	8040	28	17A
0005432817002	8040	29	18B
0005432901480	8040	30	18C
0005432901488	8040	31	20A
0005432816996	8040	32	20F
0005432817072	8040	33	21D
0005432817005	8040	34	21F
0005432901473	8040	35	22F
0005432817028	8040	36	24D
0005432901485	8040	37	25C
0005432816998	8040	38	26B
0005432817121	8040	39	26F
0005432816947	8040	40	27C
0005432901490	8040	41	28C
0005432816999	8040	42	28E
0005432901489	8040	43	29C
0005432817063	8040	44	29F
0005432817040	8040	45	30C
0005432816967	8040	46	30E
0005432817001	8040	47	30F
0005432817065	8040	48	31B
0005432901475	8040	49	31F
0005432817019	8040	50	31E
0005434175680	9638	1	2A
0005434175690	9638	2	4B
0005433870715	9638	3	5B
0005433870714	9638	4	6B
0005434175723	32333	1	1A
0005434175720	32333	2	2B
0005434175721	32333	3	3A
0005434175722	32333	4	6B
0005432799254	3508	1	1C
0005434877524	3508	2	1A
0005434877573	3508	3	1H
0005434877565	3508	4	1G
0005434877560	3508	5	1D
0005432799256	3508	6	1K
0005434877586	3508	7	2D
0005434877527	3508	8	2C
0005434877587	3508	9	2A
0005434426408	3508	10	2H
0005434877602	3508	11	2G
0005435841081	3508	12	3A
0005434877580	3508	13	2K
0005435126098	3508	14	3H
0005434426406	3508	15	3G
0005434877577	3508	16	3K
0005434877581	3508	17	4D
0005434877540	3508	18	4H
0005432799267	3508	19	5A
0005435626052	3508	20	11A
0005435626045	3508	21	11D
0005435626048	3508	22	11F
0005434877592	3508	23	11K
0005434877562	3508	24	11H
0005435902392	3508	25	12A
0005435126070	3508	26	12E
0005434426403	3508	27	12D
0005434877604	3508	28	12H
0005434426415	3508	29	13A
0005435902448	3508	30	13G
0005435126080	3508	31	14A
0005434426409	3508	32	14D
0005434877554	3508	33	14C
0005434877546	3508	34	14F
0005435626053	3508	35	14K
0005434877599	3508	36	14H
0005432799265	3508	37	15C
0005434877608	3508	38	15A
0005435126072	3508	39	15F
0005434877601	3508	40	15E
0005435626047	3508	41	15D
0005432188583	3508	42	15G
0005434937994	3508	43	15K
0005434877568	3508	44	15H
0005432613834	3508	45	16F
0005434937996	3508	46	16E
0005434877552	3508	47	16H
0005434877612	3508	48	16G
0005432611680	3508	49	17C
0005434877545	3508	50	17G
0005434877523	3508	51	17F
0005434426410	3508	52	18A
0005432611681	3508	53	17K
0005432799248	3508	54	18B
0005432613833	3508	55	18E
0005434877549	3508	56	18D
0005435126086	3508	57	18G
0005435902423	3508	58	18F
0005435126065	3508	59	18K
0005434877557	3508	60	18J
0005435902437	3508	61	19B
0005434426414	3508	62	19A
0005435126084	3508	63	19D
0005435626046	3508	64	19C
0005434937997	3508	65	19F
0005434426387	3508	66	19E
0005434877529	3508	67	19H
0005432799259	3508	68	19G
0005434877585	3508	69	20C
0005434877582	3508	70	20B
0005435126083	3508	71	20E
0005434877591	3508	72	20F
0005434877543	3508	73	20H
0005434877600	3508	74	21A
0005435626044	3508	75	20K
0005434938006	3508	76	21D
0005434426404	3508	77	21B
0005432799269	3508	78	21G
0005434877567	3508	79	21J
0005434877548	3508	80	21H
0005434938001	3508	81	22A
0005434877547	3508	82	22D
0005434877563	3508	83	22C
0005435126071	3508	84	22B
0005432799245	3508	85	22E
0005434877569	3508	86	22G
0005434877570	3508	87	22K
0005435126068	3508	88	22J
0005434877550	3508	89	23A
0005432799266	3508	90	23D
0005434877531	3508	91	23C
0005434426393	3508	92	23F
0005434877574	3508	93	23E
0005435626042	3508	94	23J
0005434426411	3508	95	23H
0005435126089	3508	96	23G
0005434877614	3508	97	24D
0005435902435	3508	98	23K
0005434937995	3508	99	24G
0005435126066	3508	100	24E
0005434877575	3508	101	25A
0005435126088	3508	102	25D
0005435126103	3508	103	25C
0005432183452	3508	104	25B
0005435126075	3508	105	25F
0005435126095	3508	106	25E
0005432183451	3508	107	25H
0005434937993	3508	108	25G
0005434938007	3508	109	25K
0005434877607	3508	110	25J
0005434877532	3508	111	26C
0005435126085	3508	112	26B
0005434426394	3508	113	26A
0005434877572	3508	114	26D
0005434426399	3508	115	26G
0005435126078	3508	116	26F
0005434877583	3508	117	26J
0005432799243	3508	118	27C
0005435626050	3508	119	27E
0005434937992	3508	120	27H
0005434877564	3508	121	27G
0005435902397	3508	122	27F
0005435902416	3508	123	27K
0005434937998	3508	124	28C
0005432799262	3508	125	28B
0005434877534	3508	126	28A
0005435902384	3508	127	28H
0005434877603	3508	128	28F
0005432799268	3508	129	28K
0005434877616	3508	130	29D
0005432799244	3508	131	29C
0005434877595	3508	132	29J
0005432799258	3508	133	29K
0005434877576	3508	134	30C
0005435902391	3508	135	30B
0005434877618	3508	136	30A
0005434426400	3508	137	30D
0005435126074	3508	138	30G
0005435126091	3508	139	30F
0005434877556	3508	140	30J
0005435626041	3508	141	30H
0005434877541	3508	142	31B
0005435126077	3508	143	31A
0005434877542	3508	144	30K
0005434877530	3508	145	31C
0005435126069	3508	146	31F
0005434426407	3508	147	31E
0005435126093	3508	148	31H
0005434426413	3508	149	32B
0005432799264	3508	150	32E
0005435126067	3508	151	32D
0005434877551	3508	152	32G
0005432799260	3508	153	32F
0005434877559	3508	154	32K
0005435902452	3508	155	32H
0005434877538	3508	156	33B
0005435626054	3508	157	33D
0005434877617	3508	158	33C
0005434938010	3508	159	33F
0005435841086	3508	160	33E
0005434426391	3508	161	33G
0005432188584	3508	162	33K
0005434877544	3508	163	34B
0005434877553	3508	164	34E
0005432799251	3508	165	34D
0005435126099	3508	166	34C
0005435126100	3508	167	34G
0005435126104	3508	168	34F
0005434877597	3508	169	34J
0005432611683	3508	170	34H
0005434877596	3508	171	35B
0005432799252	3508	172	35A
0005432799246	3508	173	35D
0005435126096	3508	174	35F
0005434877525	3508	175	35E
0005435902409	3508	176	35H
0005434426386	3508	177	35K
0005434426392	3508	178	36C
0005435902395	3508	179	36B
0005435126082	3508	180	36F
0005435126081	3508	181	36E
0005434426390	3508	182	36G
0005435902427	3508	183	36K
0005434877558	3508	184	36J
0005434938004	3508	185	37B
0005434937999	3508	186	37A
0005432188585	3508	187	37E
0005434877620	3508	188	37C
0005434426398	3508	189	37J
0005434426402	3508	190	38A
0005434877561	3508	191	37K
0005434877555	3508	192	38C
0005434426396	3508	193	38J
0005432611682	3508	194	38H
0005434426405	3508	195	39B
0005434938011	3508	196	39A
0005434877611	3508	197	38K
0005434426412	3508	198	39C
0005435126092	3508	199	39J
0005435902488	3508	200	39H
0005434877571	3508	201	39G
0005435126090	3508	202	40C
0005434938008	3508	203	40B
0005434426395	3508	204	40E
0005434938002	3508	205	40D
0005434877615	3508	206	40G
0005434877566	3508	207	40F
0005435626051	3508	208	40K
0005434877528	3508	209	41D
0005435902445	3508	210	41B
0005435126101	3508	211	41F
0005435626049	3508	212	41J
0005435902436	3508	213	41H
0005434426388	3508	214	42C
0005435841085	3508	215	42B
0005434877613	3508	216	42E
0005434877610	3508	217	42F
0005435126076	3508	218	42J
0005435126087	3508	219	42H
0005435626040	3508	220	43B
0005434877526	3508	221	43A
0005434877605	3508	222	42K
0005434877598	3508	223	43C
0005434877594	3508	224	43G
0005434426401	3508	225	43J
0005434877593	3508	226	44B
0005434877584	3508	227	44A
0005434938000	3508	228	44H
0005434877609	3508	229	45B
0005435126079	3508	230	45A
0005434877606	3508	231	45D
0005435902385	3508	232	45F
0005432799261	3508	233	45J
0005434877533	3508	234	45H
0005432799257	3508	235	45G
0005434877579	3508	236	45K
0005435902451	3508	237	46C
0005434877588	3508	238	46E
0005432613831	3508	239	46D
0005434938003	3508	240	46J
0005434877536	3508	241	46H
0005432799247	3508	242	47C
0005432799253	3508	243	47A
0005434877619	3508	244	47E
0005435126094	3508	245	47K
0005432183450	3508	246	47H
0005434877535	3508	247	48C
0005434877590	3508	248	48A
0005432799263	3508	249	48E
0005432613832	3508	250	48H
0005435126073	3508	251	48F
0005435126097	3508	252	49A
0005432799250	3508	253	48K
0005435126105	3508	254	49E
0005432799270	3508	255	49D
0005435126064	3508	256	49C
0005434426397	3508	257	49F
0005432799255	3508	258	49K
0005434426389	3508	259	49H
0005434877539	3508	260	49G
0005434938005	3508	261	50C
0005432799249	3508	262	50A
0005434877578	3508	263	50D
0005435626043	3508	264	50G
0005434938009	3508	265	50F
0005434877589	3508	266	51D
0005435902428	3508	267	50K
0005434877537	3508	268	50H
0005435126102	3508	269	51F
0005435125726	14548	1	1A
0005434937844	14548	2	1G
0005434876920	14548	3	2A
0005435625885	14548	4	1K
0005434876776	14548	5	1H
0005434426095	14548	6	2C
0005435125883	14548	7	2K
0005434876872	14548	8	3D
0005432798986	14548	9	3H
0005434876566	14548	10	4A
0005434876634	14548	11	4G
0005432799060	14548	12	4H
0005434426122	14548	13	5K
0005435902566	14548	14	11E
0005435902578	14548	15	11C
0005434876587	14548	16	11F
0005434937884	14548	17	11G
0005434937889	14548	18	12F
0005435913909	14548	19	13A
0005432798980	14548	20	13D
0005435125718	14548	21	13C
0005435125721	14548	22	13F
0005434876599	14548	23	13E
0005434876689	14548	24	13G
0005434876943	14548	25	14A
0005435902570	14548	26	13K
0005434876888	14548	27	14E
0005434876922	14548	28	14D
0005432611643	14548	29	14H
0005434876873	14548	30	14G
0005434937874	14548	31	15F
0005434876949	14548	32	16A
0005434877147	14548	33	16D
0005434877005	14548	34	16E
0005434876710	14548	35	16H
0005434426132	14548	36	17C
0005435125682	14548	37	17E
0005435125882	14548	38	17G
0005435902572	14548	39	17F
0005435902583	14548	40	18B
0005435625883	14548	41	18A
0005434426195	14548	42	18D
0005435625896	14548	43	18G
0005432607501	14548	44	18F
0005432607504	14548	45	18H
0005432607503	14548	46	19B
0005434876840	14548	47	19C
0005434876623	14548	48	19F
0005434876719	14548	49	19H
0005434876721	14548	50	19G
0005432059489	14548	51	20C
0005435125746	14548	52	20B
0005432799116	14548	53	20E
0005434937800	14548	54	20G
0005435125692	14548	55	21B
0005434876797	14548	56	21D
0005434877066	14548	57	21G
0005434876577	14548	58	21F
0005434876683	14548	59	21H
0005432799069	14548	60	22A
0005434876915	14548	61	21K
0005434877087	14548	62	22C
0005435625901	14548	63	22B
0005435902579	14548	64	22F
0005434426194	14548	65	22E
0005434876837	14548	66	22D
0005434876559	14548	67	22K
0005434937912	14548	68	22J
0005435125727	14548	69	23B
0005435842323	14548	70	23A
0005435125691	14548	71	23E
0005432799057	14548	72	23D
0005434876565	14548	73	23H
0005435625895	14548	74	23G
0005434937821	14548	75	24D
0005434877046	14548	76	23K
0005434877148	14548	77	25E
0005434876707	14548	78	25D
0005434876748	14548	79	25H
0005435125781	14548	80	25K
0005435842324	14548	81	25J
0005434876601	14548	82	26C
0005434937839	14548	83	26A
0005434937825	14548	84	26E
0005434937811	14548	85	26F
0005435125680	14548	86	26K
0005434877115	14548	87	26J
0005434876651	14548	88	27A
0005435625881	14548	89	27C
0005434426125	14548	90	27F
0005432798990	14548	91	27E
0005434876853	14548	92	27G
0005434877072	14548	93	28A
0005434426112	14548	94	27K
0005434876600	14548	95	27J
0005434877004	14548	96	28C
0005435902573	14548	97	28E
0005432799077	14548	98	28D
0005432799058	14548	99	28G
0005434426192	14548	100	28F
0005435125707	14548	101	29D
0005432799108	14548	102	29C
0005434876942	14548	103	29F
0005434426151	14548	104	29E
0005434426133	14548	105	29G
0005434426191	14548	106	30A
0005434426152	14548	107	29K
0005435902580	14548	108	30B
0005435914691	14548	109	30E
0005434876706	14548	110	30D
0005435125655	14548	111	30G
0005434876653	14548	112	30F
0005435125711	14548	113	31B
0005435125712	14548	114	30K
0005434876781	14548	115	31D
0005434876597	14548	116	31C
0005434426150	14548	117	31F
0005434937885	14548	118	31E
0005435125690	14548	119	32B
0005435902575	14548	120	32A
0005435902567	14548	121	32D
0005435841816	14548	122	32F
0005435125722	14548	123	32K
0005434426128	14548	124	32H
0005434876838	14548	125	33D
0005434937888	14548	126	33E
0005435625879	14548	127	33H
0005434426123	14548	128	33K
0005434876687	14548	129	34A
0005432799070	14548	130	34E
0005434877127	14548	131	34G
0005434937873	14548	132	34F
0005434426101	14548	133	35J
0005434876747	14548	134	36C
0005434937819	14548	135	36E
0005434876618	14548	136	36D
0005434877077	14548	137	36G
0005432799036	14548	138	36K
0005432798987	14548	139	36J
0005434877323	14548	140	36H
0005435902581	14548	141	37G
0005435902571	14548	142	37H
0005434426153	14548	143	38A
0005434877078	14548	144	37K
0005435125762	14548	145	38C
0005434937842	14548	146	38J
0005432798996	14548	147	39B
0005434937801	14548	148	38K
0005435841814	14548	149	39D
0005435125705	14548	150	39G
0005434876702	14548	151	39F
0005432798985	14548	152	39E
0005434877065	14548	153	40A
0005435902574	14548	154	39K
0005434426157	14548	155	40C
0005435902569	14548	156	40B
0005435125677	14548	157	40E
0005435902577	14548	158	40D
0005435125708	14548	159	41D
0005432799059	14548	160	41G
0005432799078	14548	161	41F
0005434937866	14548	162	41H
0005432799013	14548	163	42C
0005434876995	14548	164	42B
0005435125836	14548	165	42D
0005434877031	14548	166	42G
0005434426129	14548	167	42F
0005435902568	14548	168	42J
0005434426168	14548	169	42H
0005434426154	14548	170	43B
0005435125693	14548	171	43A
0005432799009	14548	172	43C
0005434937826	14548	173	43J
0005435914692	14548	174	44B
0005435125825	14548	175	44H
0005435913911	14548	176	44G
0005435125648	14548	177	44F
0005435625900	14548	178	44J
0005434877146	14548	179	45B
0005435125689	14548	180	45A
0005435125922	14548	181	45C
0005434876805	14548	182	45H
0005435841815	14548	183	45K
0005435902576	14548	184	46B
0005435625880	14548	185	46A
0005434876910	14548	186	46D
0005434876897	14548	187	46G
0005434876711	14548	188	46F
0005432059490	14548	189	46H
0005435913910	14548	190	47A
0005435125647	14548	191	47E
0005434876929	14548	192	47G
0005434876887	14548	193	47F
0005434876975	14548	194	47H
0005435902582	14548	195	48E
0005435625884	14548	196	48D
0005434877114	14548	197	49A
0005434426166	14548	198	48K
0005434876854	14548	199	49E
0005434426167	14548	200	49D
0005435625882	14548	201	49G
0005435125678	14548	202	50C
0005434876596	14548	203	50H
0005434937807	14548	204	50G
0005435125725	14548	205	51D
0005434876720	14548	206	51E
0005434325562	3588	1	1A
0005434325568	3588	2	1B
0005434325567	3588	3	1D
0005434325571	3588	4	2D
0005435889830	3588	5	4A
0005434312303	3588	6	5C
0005434312304	3588	7	6B
0005434325566	3588	8	6C
0005434325563	3588	9	18A
0005434325564	3588	10	18C
0005434325565	3588	11	19D
0005434325570	3588	12	20C
0005434325569	3588	13	22A
0005434325561	3588	14	22B
0005434325572	3588	15	22C
0005435889852	15591	1	1C
0005434325464	15591	2	2A
0005435889851	15591	3	3A
0005435889855	15591	4	3B
0005434325465	15591	5	4D
0005435889850	15591	6	5A
0005435889854	15591	7	7B
0005435889853	15591	8	18A
0005434325467	15591	9	18D
0005434325510	15591	10	19D
0005434325477	15591	11	21A
0005434325466	15591	12	21D
0005434325456	15591	13	23B
0005433420250	650	1	1B
0005433420288	650	2	1C
0005433420258	650	3	1D
0005433420276	650	4	2D
0005435957592	650	5	3C
0005433420256	650	6	3D
0005435957589	650	7	4B
0005435957603	650	8	5B
0005435957604	650	9	5D
0005435957602	650	10	7B
0005435957599	650	11	7C
0005435957591	650	12	18B
0005435957593	650	13	18C
0005435957590	650	14	19A
0005435957601	650	15	19B
0005433420255	650	16	19D
0005435957594	650	17	20A
0005435957597	650	18	20B
0005435957596	650	19	21A
0005433420251	650	20	21B
0005435957598	650	21	21C
0005435957600	650	22	21D
0005433420289	650	23	22D
0005435957595	650	24	23B
0005435957472	15155	1	1A
0005433420345	15155	2	1D
0005435957504	15155	3	2A
0005433420339	15155	4	2C
0005435957439	15155	5	2D
0005433420340	15155	6	3A
0005435957507	15155	7	3B
0005435957452	15155	8	4D
0005433420344	15155	9	5C
0005433420337	15155	10	6C
0005433420341	15155	11	6D
0005433420342	15155	12	7A
0005435957456	15155	13	7C
0005435957467	15155	14	18C
0005433420338	15155	15	18D
0005435957466	15155	16	20C
0005435957505	15155	17	21A
0005435957451	15155	18	21C
0005433420343	15155	19	22D
0005435957509	15155	20	23B
0005435216575	31770	1	1C
0005435216572	31770	2	2B
0005435218109	31770	3	2C
0005435217699	31770	4	3B
0005435216570	31770	5	4A
0005435216574	31770	6	4B
0005435217698	31770	7	4C
0005435217695	31770	8	7B
0005435217697	31770	9	7D
0005435216573	31770	10	19C
0005435216571	31770	11	20D
0005435217696	31770	12	22D
0005434995285	6700	1	2D
0005434995289	6700	2	3F
0005434995294	6700	3	4C
0005434995286	6700	4	6A
0005434995290	6700	5	7B
0005434995284	6700	6	9B
0005434995291	6700	7	9D
0005434995288	6700	8	12F
0005434995292	6700	9	14A
0005434995283	6700	10	14E
0005434995296	6700	11	18C
0005434995295	6700	12	19A
0005434995293	6700	13	20F
0005434995287	6700	14	22B
0005435629397	8907	1	2A
0005434247103	8907	2	2B
0005435629395	8907	3	4A
0005435629396	8907	4	5B
0005434247111	8907	5	6A
0005434247104	8907	6	6B
0005435629390	16113	1	1A
0005434247128	16113	2	2A
0005434247127	16113	3	3A
0005434247129	16113	4	5B
0005434467747	4013	1	2C
0005434467748	4013	2	4B
0005434467742	4013	3	4D
0005434467745	4013	4	5A
0005434467743	4013	5	7A
0005434467744	4013	6	7B
0005434467746	4013	7	20B
0005434096725	20176	1	1B
0005434096728	20176	2	1C
0005434096723	20176	3	4C
0005434096721	20176	4	4D
0005434096727	20176	5	7A
0005434096722	20176	6	7C
0005434096726	20176	7	7D
0005434096724	20176	8	18B
0005432645870	6831	1	1A
0005432645883	6831	2	2D
0005432645877	6831	3	3C
0005435229319	6831	4	3D
0005432645867	6831	5	4C
0005432645866	6831	6	4D
0005432645879	6831	7	5D
0005432645905	6831	8	6A
0005432645874	6831	9	6C
0005432645876	6831	10	6E
0005432645887	6831	11	6F
0005432645897	6831	12	7A
0005432645868	6831	13	7F
0005435229310	6831	14	8A
0005435229321	6831	15	9A
0005435229303	6831	16	9C
0005432645888	6831	17	9D
0005432645891	6831	18	10A
0005432645899	6831	19	10C
0005432645881	6831	20	10D
0005432645878	6831	21	10F
0005435229325	6831	22	11C
0005432645884	6831	23	11D
0005432645896	6831	24	11E
0005432645903	6831	25	11F
0005432645869	6831	26	12C
0005435229308	6831	27	12E
0005432645898	6831	28	12F
0005432645875	6831	29	13A
0005432645889	6831	30	14D
0005432645893	6831	31	15A
0005432645902	6831	32	15C
0005432645885	6831	33	15D
0005435229309	6831	34	15E
0005432645880	6831	35	15F
0005432645873	6831	36	16A
0005435229322	6831	37	16C
0005432645901	6831	38	16E
0005435229323	6831	39	16F
0005432645871	6831	40	17A
0005432645892	6831	41	17D
0005432645894	6831	42	17E
0005432645882	6831	43	17F
0005435229307	6831	44	18A
0005435229318	6831	45	18D
0005432645895	6831	46	18E
0005432645872	6831	47	18F
0005432645890	6831	48	19A
0005432645886	6831	49	19C
0005432645904	6831	50	19E
0005432645900	6831	51	20C
0005435229326	6831	52	20F
0005432645764	25118	1	1C
0005432645775	25118	2	1D
0005435229353	25118	3	1F
0005432645765	25118	4	2D
0005435229354	25118	5	3A
0005435229372	25118	6	3D
0005432645802	25118	7	3F
0005432645796	25118	8	4A
0005432645805	25118	9	4C
0005435229379	25118	10	4D
0005432645768	25118	11	4E
0005432645776	25118	12	4F
0005432645761	25118	13	5C
0005432645809	25118	14	5D
0005435229366	25118	15	5E
0005435229375	25118	16	6A
0005435229362	25118	17	6C
0005432645774	25118	18	6D
0005432645766	25118	19	6F
0005435229381	25118	20	7A
0005435229373	25118	21	7C
0005432645788	25118	22	7D
0005432645804	25118	23	8A
0005435229377	25118	24	8D
0005435229361	25118	25	8E
0005435229363	25118	26	9D
0005432645812	25118	27	9F
0005432645770	25118	28	10C
0005432645763	25118	29	10D
0005435229367	25118	30	10E
0005435229360	25118	31	11A
0005435229359	25118	32	11E
0005435229371	25118	33	11F
0005435229358	25118	34	12C
0005435229376	25118	35	12D
0005435229355	25118	36	13A
0005432645810	25118	37	13D
0005435229382	25118	38	14A
0005435229356	25118	39	14C
0005435229374	25118	40	14D
0005435229368	25118	41	14F
0005432645811	25118	42	15D
0005435229364	25118	43	15E
0005432645762	25118	44	15F
0005432645787	25118	45	16A
0005432645795	25118	46	16C
0005432645801	25118	47	16E
0005435229365	25118	48	16F
0005435229383	25118	49	17D
0005432645803	25118	50	17E
0005435229378	25118	51	17F
0005435229357	25118	52	18D
0005435229369	25118	53	18E
0005432645767	25118	54	19A
0005435229380	25118	55	20A
0005435229370	25118	56	20C
0005433404692	2871	1	3A
0005433404688	2871	2	3D
0005435797369	2871	3	4E
0005435797382	2871	4	4F
0005435797380	2871	5	6A
0005435797381	2871	6	7A
0005435797375	2871	7	7E
0005435797378	2871	8	8A
0005433404679	2871	9	9C
0005435797373	2871	10	9D
0005435797374	2871	11	11A
0005435797371	2871	12	12E
0005435797367	2871	13	13D
0005433404687	2871	14	14C
0005435797376	2871	15	14F
0005433404691	2871	16	15A
0005433404680	2871	17	15D
0005435797368	2871	18	16F
0005435797370	2871	19	17F
0005433404677	2871	20	18D
0005435797379	2871	21	18E
0005433404678	2871	22	19C
0005435797372	2871	23	19F
0005435797377	2871	24	20C
0005435797241	29338	1	4C
0005435797248	29338	2	4E
0005433404757	29338	3	5E
0005435797237	29338	4	5F
0005435797242	29338	5	6C
0005435797252	29338	6	6F
0005435797296	29338	7	8C
0005435797239	29338	8	8D
0005435797258	29338	9	8F
0005435797257	29338	10	9C
0005435797292	29338	11	10E
0005435797295	29338	12	12D
0005433404759	29338	13	12F
0005435797249	29338	14	13D
0005435797240	29338	15	13E
0005433404755	29338	16	14A
0005435797238	29338	17	14D
0005433404756	29338	18	16A
0005435797226	29338	19	17A
0005433404758	29338	20	17E
0005435797253	29338	21	18C
0005433404754	29338	22	19C
0005433404753	29338	23	20A
0005435376320	5788	1	2A
0005435376321	5788	2	3A
0005434947961	5780	1	1A
0005434947958	5780	2	1B
0005434947963	5780	3	2B
0005434947960	5780	4	3A
0005434947957	5780	5	4B
0005434947962	5780	6	5A
0005434947959	5780	7	5B
0005434947898	16387	1	1A
0005434947893	16387	2	1B
0005434947884	16387	3	2A
0005434947885	16387	4	2B
0005434947882	16387	5	3A
0005434947895	16387	6	4A
0005434947909	16387	7	4B
0005434947883	16387	8	5A
0005434947894	16387	9	6A
0005434947881	16387	10	6B
0005433960468	6947	1	1C
0005433960449	6947	2	1D
0005433960454	6947	3	2A
0005433960467	6947	4	2C
0005433960476	6947	5	2D
0005433960488	6947	6	3A
0005433960443	6947	7	3D
0005433960477	6947	8	4A
0005433960459	6947	9	4D
0005433960457	6947	10	4C
0005433960481	6947	11	4F
0005433960486	6947	12	5A
0005433960487	6947	13	5D
0005433960460	6947	14	5E
0005433960445	6947	15	6C
0005433960466	6947	16	6D
0005433960482	6947	17	6E
0005433960495	6947	18	6F
0005433960498	6947	19	7A
0005433960496	6947	20	7C
0005433960475	6947	21	8E
0005433960489	6947	22	9E
0005433960458	6947	23	9F
0005433960473	6947	24	10A
0005433960456	6947	25	10C
0005433960450	6947	26	10E
0005433960451	6947	27	11C
0005433960463	6947	28	11E
0005433960474	6947	29	12E
0005433960490	6947	30	12F
0005433960471	6947	31	13C
0005433960491	6947	32	13F
0005433960462	6947	33	14C
0005433960472	6947	34	14F
0005433960461	6947	35	15A
0005433960448	6947	36	15C
0005433960483	6947	37	15D
0005433960479	6947	38	15E
0005433960484	6947	39	15F
0005433960447	6947	40	16A
0005433960492	6947	41	16C
0005433960464	6947	42	16D
0005433960470	6947	43	16E
0005433960494	6947	44	16F
0005433960480	6947	45	17A
0005433960453	6947	46	17C
0005433960478	6947	47	17D
0005433960446	6947	48	17E
0005433960469	6947	49	18A
0005433960493	6947	50	18D
0005433960465	6947	51	18E
0005433960497	6947	52	19D
0005433960444	6947	53	19F
0005433960455	6947	54	20A
0005433960485	6947	55	20D
0005433960452	6947	56	20E
0005435082674	24502	1	1B
0005435082673	24502	2	3B
0005435082652	24502	3	4B
0005435082653	24502	4	5A
0005435082650	24502	5	6B
0005435082727	26117	1	1A
0005435082722	26117	2	1B
0005435082723	26117	3	2A
0005435082726	26117	4	2B
0005435082719	26117	5	3A
0005435082721	26117	6	4A
0005435082725	26117	7	3B
0005435082720	26117	8	4B
0005435082724	26117	9	6A
0005435082718	26117	10	5B
0005435082717	26117	11	6B
0005435286548	5235	1	1A
0005434244777	5235	2	3C
0005434244785	5235	3	3D
0005434244757	5235	4	4C
0005434244765	5235	5	4D
0005434244767	5235	6	6A
0005434244782	5235	7	7F
0005434244754	5235	8	7D
0005434244755	5235	9	8B
0005434244764	5235	10	8D
0005435286542	5235	11	9B
0005434244762	5235	12	10E
0005434244758	5235	13	10F
0005435286543	5235	14	12E
0005434244760	5235	15	12D
0005434244781	5235	16	13C
0005434244776	5235	17	14C
0005434244759	5235	18	14E
0005434244769	5235	19	16B
0005434244774	5235	20	16F
0005434244783	5235	21	19D
0005434244775	5235	22	20A
0005434244761	5235	23	19E
0005434244766	5235	24	23C
0005435286547	5235	25	23F
0005434244756	5235	26	23E
0005434244772	5235	27	24B
0005432166879	5235	28	24D
0005432166877	5235	29	24F
0005434244778	5235	30	25C
0005432166878	5235	31	26A
0005432166876	5235	32	27E
0005434244773	5235	33	27D
0005434244784	5235	34	28B
0005434244779	5235	35	29A
0005434244768	5235	36	29C
0005434244770	5235	37	30B
0005435286551	5235	38	30E
0005434244780	5235	39	31A
0005434244771	5235	40	31E
0005434244763	5235	41	31F
0005432145098	5190	1	1A
0005432105201	5190	2	1C
0005432105208	5190	3	1F
0005432105247	5190	4	1D
0005433614136	5190	5	2A
0005433614171	5190	6	2C
0005433614208	5190	7	2D
0005432105228	5190	8	3A
0005432105213	5190	9	2F
0005432105204	5190	10	3D
0005433614156	5190	11	3C
0005432105214	5190	12	3F
0005433614150	5190	13	4A
0005433614140	5190	14	4C
0005433614178	5190	15	4F
0005433614145	5190	16	4D
0005433784677	5190	17	5A
0005433614184	5190	18	5D
0005432105224	5190	19	5C
0005433784691	5190	20	6A
0005433784686	5190	21	5F
0005433784688	5190	22	6C
0005433614137	5190	23	6F
0005433784669	5190	24	6D
0005433784675	5190	25	7A
0005433614138	5190	26	7C
0005433614168	5190	27	7F
0005433614207	5190	28	7D
0005433614170	5190	29	8A
0005432105222	5190	30	8B
0005432105237	5190	31	8C
0005432145097	5190	32	8E
0005433614142	5190	33	8D
0005433784699	5190	34	9A
0005432665258	5190	35	8F
0005432105203	5190	36	9B
0005433614167	5190	37	9C
0005433614172	5190	38	9E
0005432105212	5190	39	9D
0005432666374	5190	40	9F
0005433614199	5190	41	10A
0005432667439	5190	42	10C
0005432105245	5190	43	10B
0005433614153	5190	44	10E
0005433784694	5190	45	10D
0005433784690	5190	46	10F
0005433614179	5190	47	11B
0005433784663	5190	48	11A
0005433614151	5190	49	11C
0005433614169	5190	50	11D
0005433784697	5190	51	11F
0005433784683	5190	52	11E
0005433614160	5190	53	12A
0005433614193	5190	54	12B
0005433614186	5190	55	12D
0005433614204	5190	56	12C
0005433614176	5190	57	12E
0005433614154	5190	58	12F
0005432105248	5190	59	13A
0005433614147	5190	60	13C
0005433784692	5190	61	13B
0005433784666	5190	62	13D
0005433784664	5190	63	13F
0005432105249	5190	64	13E
0005433614197	5190	65	14B
0005433614188	5190	66	14A
0005432665259	5190	67	14D
0005433614152	5190	68	14C
0005433784667	5190	69	14E
0005433784693	5190	70	15A
0005433614144	5190	71	14F
0005433614195	5190	72	15B
0005433784681	5190	73	15C
0005433614187	5190	74	15D
0005433784687	5190	75	15E
0005432105232	5190	76	16A
0005433784684	5190	77	15F
0005433614173	5190	78	16C
0005432105233	5190	79	16B
0005432105215	5190	80	16D
0005432105240	5190	81	16E
0005433784680	5190	82	17A
0005432105216	5190	83	16F
0005433614183	5190	84	17C
0005432665260	5190	85	17B
0005433614198	5190	86	17D
0005433614166	5190	87	17F
0005432105219	5190	88	17E
0005432105229	5190	89	18A
0005433614157	5190	90	18B
0005433784682	5190	91	18C
0005432105211	5190	92	18D
0005433614141	5190	93	19B
0005432105202	5190	94	18F
0005432105244	5190	95	18E
0005433784698	5190	96	19C
0005433784665	5190	97	19D
0005432105223	5190	98	19E
0005432105209	5190	99	20B
0005433614202	5190	100	20A
0005433614163	5190	101	20C
0005433614161	5190	102	20E
0005433614158	5190	103	20D
0005432105235	5190	104	20F
0005433614205	5190	105	21A
0005433784671	5190	106	21B
0005432105218	5190	107	21D
0005433784670	5190	108	21C
0005433614149	5190	109	21E
0005433614175	5190	110	21F
0005433614192	5190	111	22B
0005432105221	5190	112	22A
0005432105230	5190	113	22C
0005432105236	5190	114	22E
0005432105220	5190	115	22D
0005432105205	5190	116	22F
0005433784685	5190	117	23A
0005432105239	5190	118	23C
0005433784679	5190	119	23B
0005433614182	5190	120	23D
0005432105206	5190	121	23E
0005433614143	5190	122	24A
0005433784696	5190	123	23F
0005433614162	5190	124	24B
0005433614189	5190	125	24D
0005433784678	5190	126	24C
0005433614135	5190	127	24E
0005433784695	5190	128	24F
0005433784674	5190	129	25B
0005433614200	5190	130	25A
0005432105207	5190	131	25C
0005432105238	5190	132	25D
0005432105243	5190	133	25E
0005432105241	5190	134	25F
0005433614148	5190	135	26B
0005433614203	5190	136	26A
0005433784689	5190	137	26D
0005432105225	5190	138	26C
0005433614194	5190	139	26E
0005433614209	5190	140	27A
0005433614196	5190	141	26F
0005433614180	5190	142	27C
0005432105231	5190	143	27B
0005433614165	5190	144	27E
0005432105242	5190	145	27D
0005433614190	5190	146	27F
0005433614155	5190	147	28A
0005433614185	5190	148	28C
0005433614201	5190	149	28B
0005432145096	5190	150	28D
0005432105226	5190	151	28E
0005433614139	5190	152	28F
0005433614164	5190	153	29A
0005433614159	5190	154	29C
0005433784676	5190	155	29B
0005433784672	5190	156	29D
0005432105210	5190	157	29F
0005432666373	5190	158	29E
0005433614177	5190	159	30A
0005433784668	5190	160	30C
0005433614206	5190	161	30B
0005432105227	5190	162	30D
0005433614181	5190	163	30E
0005433614146	5190	164	31A
0005432105234	5190	165	30F
0005432105217	5190	166	31C
0005433784673	5190	167	31B
0005432105246	5190	168	31D
0005433614174	5190	169	31E
0005433614191	5190	170	31F
0005434264958	5139	1	1A
0005434264959	5139	2	1C
0005435006657	5139	3	1D
0005434264948	5139	4	2A
0005435006604	5139	5	2F
0005435269624	5139	6	3D
0005434229217	5139	7	3C
0005434149650	5139	8	3F
0005434264942	5139	9	4A
0005434264953	5139	10	4C
0005434229216	5139	11	4F
0005434264943	5139	12	5C
0005434229200	5139	13	5A
0005432335838	5139	14	5D
0005434229201	5139	15	6A
0005432335829	5139	16	5F
0005434229207	5139	17	6C
0005432335851	5139	18	6F
0005434311193	5139	19	6D
0005435006607	5139	20	7A
0005434264946	5139	21	7C
0005434229203	5139	22	7D
0005434264952	5139	23	8B
0005435006718	5139	24	8D
0005434229202	5139	25	8C
0005435269630	5139	26	8E
0005432335875	5139	27	9B
0005435006637	5139	28	9A
0005434311192	5139	29	9C
0005432335886	5139	30	9E
0005434149644	5139	31	10A
0005435006762	5139	32	9F
0005432335871	5139	33	10C
0005433815305	5139	34	10B
0005435006625	5139	35	10D
0005434264957	5139	36	10F
0005435269627	5139	37	11A
0005434173490	5139	38	11C
0005435006692	5139	39	11D
0005434264954	5139	40	11F
0005433815315	5139	41	12A
0005434149647	5139	42	12B
0005434149646	5139	43	12E
0005434149642	5139	44	12F
0005435006761	5139	45	13B
0005434229208	5139	46	13A
0005434229214	5139	47	14A
0005434229210	5139	48	13F
0005434149649	5139	49	14C
0005432335845	5139	50	14B
0005434311197	5139	51	14E
0005434173489	5139	52	14D
0005434264955	5139	53	14F
0005434173491	5139	54	15A
0005434149641	5139	55	15C
0005435269623	5139	56	15E
0005434264962	5139	57	15D
0005434229218	5139	58	15F
0005433685494	5139	59	16C
0005434173492	5139	60	16E
0005435269625	5139	61	17A
0005434264950	5139	62	16F
0005434149640	5139	63	17B
0005433815316	5139	64	17F
0005434229204	5139	65	18A
0005435269641	5139	66	18B
0005435269628	5139	67	18D
0005434229205	5139	68	18C
0005432335844	5139	69	19B
0005434229219	5139	70	20B
0005434264945	5139	71	20A
0005434264941	5139	72	20C
0005434264949	5139	73	20E
0005435006686	5139	74	20D
0005434149643	5139	75	20F
0005434311200	5139	76	21A
0005434229206	5139	77	21C
0005435269629	5139	78	21B
0005435006694	5139	79	21D
0005435006605	5139	80	21E
0005434229199	5139	81	22B
0005433815309	5139	82	22D
0005434229215	5139	83	22C
0005434149648	5139	84	22F
0005435006678	5139	85	22E
0005434229211	5139	86	23A
0005435006636	5139	87	23E
0005434264961	5139	88	24C
0005434229198	5139	89	24E
0005435006665	5139	90	25A
0005435006644	5139	91	25B
0005434311198	5139	92	25D
0005432335837	5139	93	25C
0005434311199	5139	94	26A
0005432335846	5139	95	26B
0005435269647	5139	96	26E
0005433815304	5139	97	26F
0005434149645	5139	98	27A
0005435006674	5139	99	27C
0005434229213	5139	100	27D
0005434264951	5139	101	27E
0005434264963	5139	102	27F
0005434229209	5139	103	28F
0005434264960	5139	104	29A
0005435006727	5139	105	29C
0005435006652	5139	106	29D
0005432335855	5139	107	29F
0005434264965	5139	108	30B
0005435269626	5139	109	30C
0005434149651	5139	110	30E
0005435269642	5139	111	30D
0005434264964	5139	112	30F
0005434264956	5139	113	31A
0005434229212	5139	114	31C
0005434264947	5139	115	31B
0005434264944	5139	116	31F
0005433784444	8355	1	2A
0005432666356	8355	2	2C
0005435269693	8355	3	3A
0005433784498	8355	4	3F
0005433784463	8355	5	4A
0005434244567	8355	6	4D
0005433784423	8355	7	6D
0005433784431	8355	8	7A
0005435269694	8355	9	7D
0005434244546	8355	10	7F
0005434244553	8355	11	8C
0005432666353	8355	12	8E
0005433784317	8355	13	8D
0005434244572	8355	14	9C
0005433784376	8355	15	10B
0005434244588	8355	16	10D
0005434244521	8355	17	10C
0005434244650	8355	18	10E
0005434244566	8355	19	11C
0005432666352	8355	20	11B
0005432659672	8355	21	11F
0005433784377	8355	22	12B
0005434244498	8355	23	12D
0005433784493	8355	24	12C
0005434244552	8355	25	12E
0005434244507	8355	26	13B
0005433784443	8355	27	13E
0005434244520	8355	28	14C
0005433784417	8355	29	14E
0005433784393	8355	30	16A
0005433784420	8355	31	16C
0005434244568	8355	32	16F
0005433784362	8355	33	17F
0005433784307	8355	34	18B
0005433784308	8355	35	18F
0005433784300	8355	36	20A
0005433784327	8355	37	20D
0005433784383	8355	38	20F
0005435269695	8355	39	23D
0005433784350	8355	40	23E
0005433784418	8355	41	23F
0005433784427	8355	42	24B
0005433784487	8355	43	24C
0005433784329	8355	44	25A
0005433784462	8355	45	27A
0005434244551	8355	46	27F
0005433784439	8355	47	28D
0005434244477	8355	48	29A
0005433784318	8355	49	29C
0005433784375	8355	50	29D
0005433784510	8355	51	29E
0005433784559	8355	52	30B
0005434244538	8355	53	30A
0005432666357	8355	54	30D
0005434244614	8355	55	31C
0005433784494	8355	56	31B
0005433613532	8356	1	1C
0005433613416	8356	2	2C
0005433613766	8356	3	3F
0005433613420	8356	4	5D
0005433613421	8356	5	5C
0005433613434	8356	6	5F
0005433613441	8356	7	7A
0005433613672	8356	8	8A
0005433613512	8356	9	8B
0005433613642	8356	10	8C
0005433613538	8356	11	8E
0005433613496	8356	12	9F
0005433613593	8356	13	10E
0005433613768	8356	14	11A
0005433613594	8356	15	11C
0005433613724	8356	16	11D
0005433613391	8356	17	12A
0005433613712	8356	18	12D
0005433613428	8356	19	12F
0005433613417	8356	20	13A
0005433613442	8356	21	13B
0005433613433	8356	22	13E
0005433613604	8356	23	14A
0005433613492	8356	24	14B
0005433613533	8356	25	15A
0005433613711	8356	26	14F
0005433613511	8356	27	16B
0005433613491	8356	28	16C
0005433613462	8356	29	17A
0005433613722	8356	30	17F
0005433613723	8356	31	18D
0005433613823	8356	32	23A
0005433613586	8356	33	23C
0005433613603	8356	34	23F
0005433613440	8356	35	24A
0005433613558	8356	36	24B
0005433613602	8356	37	24F
0005433613419	8356	38	27A
0005433613408	8356	39	26F
0005433613615	8356	40	27C
0005433613657	8356	41	27E
0005433613643	8356	42	27F
0005433613601	8356	43	28F
0005433613435	8356	44	28E
0005433613824	8356	45	29B
0005433613767	8356	46	29E
0005433613409	8356	47	30A
0005433613670	8356	48	30B
0005433613461	8356	49	30D
0005433613390	8356	50	30F
0005433613825	8356	51	31E
0005433613516	8356	52	31F
0005434264702	8357	1	1A
0005432034759	8357	2	1C
0005434229010	8357	3	1F
0005435006862	8357	4	1D
0005432335954	8357	5	2A
0005432034738	8357	6	2C
0005435006844	8357	7	2F
0005432034760	8357	8	2D
0005435286581	8357	9	3A
0005433689897	8357	10	3C
0005432034751	8357	11	3F
0005432034749	8357	12	3D
0005433815354	8357	13	4A
0005434149526	8357	14	4C
0005434149555	8357	15	4F
0005432034745	8357	16	4D
0005434229060	8357	17	5A
0005434229100	8357	18	5C
0005433815353	8357	19	5F
0005434264797	8357	20	5D
0005434264740	8357	21	6D
0005433534482	8357	22	6C
0005432034755	8357	23	6A
0005434173454	8357	24	6F
0005434264789	8357	25	7A
0005432034752	8357	26	7C
0005433689896	8357	27	7F
0005434149534	8357	28	7D
0005434229043	8357	29	8A
0005432335944	8357	30	8B
0005434264705	8357	31	8E
0005433688796	8357	32	8D
0005434229065	8357	33	9A
0005434229045	8357	34	8F
0005435286587	8357	35	9B
0005435006860	8357	36	9C
0005432034742	8357	37	9E
0005435286579	8357	38	9D
0005433534483	8357	39	9F
0005435006855	8357	40	10A
0005432335950	8357	41	10B
0005435286585	8357	42	10D
0005435286582	8357	43	10C
0005432034758	8357	44	10E
0005432335953	8357	45	10F
0005432335951	8357	46	11A
0005432034746	8357	47	11C
0005433815352	8357	48	11B
0005435286580	8357	49	11D
0005432034753	8357	50	12A
0005434264690	8357	51	11F
0005435006848	8357	52	12B
0005434173459	8357	53	12C
0005434228979	8357	54	12E
0005432034736	8357	55	12D
0005434229138	8357	56	12F
0005434264827	8357	57	13A
0005434264788	8357	58	13C
0005432034740	8357	59	13B
0005434229109	8357	60	13D
0005434264701	8357	61	13F
0005435006853	8357	62	13E
0005433688795	8357	63	14A
0005434229071	8357	64	14B
0005434264778	8357	65	14D
0005434149542	8357	66	14C
0005434228991	8357	67	14E
0005434311204	8357	68	14F
0005434264816	8357	69	15B
0005435006859	8357	70	15A
0005435286584	8357	71	15C
0005435006852	8357	72	15D
0005435006845	8357	73	15F
0005432335949	8357	74	15E
0005434149520	8357	75	16A
0005434149556	8357	76	16B
0005432047521	8357	77	16D
0005432034750	8357	78	16E
0005434229102	8357	79	17A
0005432047524	8357	80	17B
0005434311205	8357	81	17C
0005432034741	8357	82	17E
0005434264688	8357	83	17D
0005435006864	8357	84	17F
0005432335948	8357	85	18B
0005432034737	8357	86	18E
0005434264739	8357	87	18D
0005434149543	8357	88	18F
0005433690912	8357	89	19C
0005434149553	8357	90	19B
0005434149567	8357	91	19D
0005432034756	8357	92	20A
0005432034761	8357	93	19E
0005433690913	8357	94	20B
0005434149551	8357	95	20C
0005435006856	8357	96	20D
0005435006867	8357	97	20E
0005434229011	8357	98	21A
0005435006858	8357	99	20F
0005434264722	8357	100	21C
0005435006851	8357	101	21B
0005434228995	8357	102	21D
0005434264692	8357	103	21F
0005435006847	8357	104	21E
0005434229056	8357	105	22B
0005432335947	8357	106	22C
0005432034743	8357	107	22D
0005432034754	8357	108	22F
0005435006846	8357	109	23A
0005434229101	8357	110	23B
0005435006861	8357	111	23D
0005434264828	8357	112	23C
0005434149528	8357	113	23F
0005434264677	8357	114	23E
0005435286586	8357	115	24A
0005435006843	8357	116	24B
0005435006842	8357	117	24C
0005434264689	8357	118	24E
0005434264795	8357	119	24D
0005435006854	8357	120	24F
0005432034748	8357	121	25A
0005434173472	8357	122	25B
0005434149521	8357	123	25D
0005435006866	8357	124	25C
0005434264703	8357	125	25E
0005434264685	8357	126	26A
0005432335946	8357	127	25F
0005434173458	8357	128	26C
0005434149527	8357	129	26D
0005432034744	8357	130	26E
0005435006849	8357	131	26F
0005432335943	8357	132	27B
0005434264737	8357	133	27A
0005432034739	8357	134	27C
0005434264704	8357	135	27D
0005433815351	8357	136	27F
0005432034735	8357	137	27E
0005433689895	8357	138	28A
0005432047523	8357	139	28B
0005434149557	8357	140	28D
0005434264770	8357	141	28C
0005435006865	8357	142	28E
0005434264738	8357	143	29A
0005432034757	8357	144	28F
0005432335945	8357	145	29C
0005434229044	8357	146	29B
0005434264773	8357	147	29D
0005432047522	8357	148	29E
0005434264787	8357	149	30A
0005434264777	8357	150	29F
0005435006850	8357	151	30B
0005434229061	8357	152	30D
0005434149580	8357	153	30C
0005432034747	8357	154	30E
0005434264700	8357	155	30F
0005432335952	8357	156	31B
0005434264748	8357	157	31C
0005435006857	8357	158	31D
0005435006863	8357	159	31F
0005435286583	8357	160	31E
0005434638866	12588	1	1A
0005433202264	12588	2	2B
0005433202255	12588	3	2C
0005434638863	12588	4	2D
0005434638968	12588	5	3B
0005434638950	12588	6	3D
0005433202254	12588	7	4A
0005434638947	12588	8	4B
0005434638951	12588	9	5C
0005434638982	12588	10	6A
0005433202260	12588	11	6B
0005433202263	12588	12	6C
0005434638983	12588	13	6D
0005434638896	12588	14	7B
0005434638898	12588	15	7A
0005433202262	12588	16	7C
0005433202267	12588	17	18C
0005433202256	12588	18	18D
0005433202266	12588	19	19A
0005434638988	12588	20	19B
0005434638931	12588	21	19D
0005433202258	12588	22	20A
0005434638848	12588	23	20B
0005434638989	12588	24	20C
0005433202259	12588	25	21B
0005433202253	12588	26	21D
0005433202261	12588	27	22A
0005434638984	12588	28	22B
0005434638908	12588	29	22C
0005434638895	12588	30	22D
0005433202257	12588	31	23A
0005433202265	12588	32	23B
0005434639111	23395	1	1C
0005433202146	23395	2	1D
0005434639120	23395	3	2D
0005433202125	23395	4	3A
0005434639108	23395	5	3B
0005433202121	23395	6	3D
0005434639123	23395	7	4A
0005434639105	23395	8	4B
0005434639104	23395	9	4C
0005434639125	23395	10	4D
0005433202172	23395	11	5A
0005434639110	23395	12	5D
0005434639122	23395	13	6A
0005434639119	23395	14	6B
0005434639118	23395	15	6C
0005434639115	23395	16	6D
0005434639103	23395	17	7B
0005434639116	23395	18	7A
0005434639107	23395	19	7C
0005434639101	23395	20	7D
0005433202120	23395	21	18A
0005433202106	23395	22	18B
0005434639124	23395	23	18C
0005433202126	23395	24	18D
0005434639114	23395	25	19A
0005434639121	23395	26	19B
0005434639099	23395	27	19D
0005434639117	23395	28	19C
0005432290609	23395	29	20A
0005434639102	23395	30	20C
0005432290607	23395	31	20D
0005434639109	23395	32	21A
0005433202115	23395	33	21B
0005433202129	23395	34	21C
0005434639113	23395	35	21D
0005434639112	23395	36	22A
0005434639100	23395	37	22B
0005433202107	23395	38	22C
0005432290608	23395	39	22D
0005434639106	23395	40	23B
0005432382504	21090	1	1A
0005432382557	21090	2	1C
0005432382643	21090	3	1D
0005432328055	21090	4	1F
0005432054284	21090	5	2C
0005432382546	21090	6	2D
0005432327972	21090	7	2F
0005432054283	21090	8	3D
0005432382563	21090	9	3F
0005432327969	21090	10	4A
0005432382605	21090	11	4C
0005432327968	21090	12	4D
0005432328026	21090	13	4E
0005432382562	21090	14	4F
0005432328060	21090	15	5C
0005432382598	21090	16	5D
0005432327896	21090	17	5E
0005432382488	21090	18	5F
0005432328056	21090	19	6A
0005432054282	21090	20	6D
0005432328024	21090	21	7C
0005432328013	21090	22	7F
0005432328051	21090	23	8C
0005432054285	21090	24	8F
0005432382489	21090	25	9C
0005432382528	21090	26	9E
0005432327970	21090	27	9F
0005432382573	21090	28	10A
0005432382498	21090	29	10C
0005432382590	21090	30	10D
0005432327925	21090	31	10E
0005432328057	21090	32	11A
0005432327973	21090	33	11C
0005432382558	21090	34	11D
0005432382506	21090	35	11E
0005432382547	21090	36	11F
0005432327898	21090	37	12A
0005432382527	21090	38	12D
0005432328072	21090	39	13A
0005432382581	21090	40	13E
0005432382517	21090	41	13F
0005432382497	21090	42	14C
0005432328025	21090	43	14D
0005432328011	21090	44	14E
0005432327935	21090	45	15C
0005432328014	21090	46	15D
0005432328066	21090	47	15F
0005432382597	21090	48	16A
0005432382524	21090	49	16E
0005432327934	21090	50	16F
0005432327911	21090	51	17A
0005432382502	21090	52	17C
0005432328061	21090	53	17D
0005432382514	21090	54	17F
0005432382512	21090	55	18A
0005432328054	21090	56	18C
0005432382591	21090	57	18E
0005432328134	21090	58	18F
0005432382548	21090	59	19A
0005432382635	21090	60	19D
0005432382561	21090	61	19E
0005432328053	21090	62	19F
0005432382513	21090	63	20C
0005432328110	21090	64	20F
0005432382844	31255	1	1A
0005432382884	31255	2	1C
0005432328337	31255	3	1D
0005432382866	31255	4	1F
0005432328327	31255	5	2A
0005432328342	31255	6	2C
0005432382862	31255	7	2D
0005432328326	31255	8	2F
0005432328343	31255	9	3A
0005432328352	31255	10	3C
0005432328315	31255	11	3D
0005432382845	31255	12	3F
0005432382852	31255	13	4A
0005432382874	31255	14	4C
0005432328355	31255	15	4D
0005432382882	31255	16	4E
0005432328347	31255	17	4F
0005432328356	31255	18	5A
0005432287148	31255	19	5C
0005432382867	31255	20	5D
0005432382856	31255	21	5E
0005432328354	31255	22	5F
0005432382865	31255	23	6C
0005432328332	31255	24	6D
0005432382849	31255	25	6E
0005432382878	31255	26	6F
0005432328335	31255	27	7A
0005432287149	31255	28	7C
0005432328321	31255	29	7D
0005432382861	31255	30	7E
0005432382855	31255	31	7F
0005432287150	31255	32	8A
0005432382871	31255	33	8C
0005432382869	31255	34	8D
0005432328349	31255	35	8E
0005432328331	31255	36	8F
0005432328344	31255	37	9A
0005432328316	31255	38	9C
0005432382885	31255	39	9D
0005432328314	31255	40	9E
0005432328353	31255	41	9F
0005432328319	31255	42	10A
0005432328329	31255	43	10C
0005432382877	31255	44	10D
0005432328323	31255	45	10F
0005432328339	31255	46	11A
0005432328348	31255	47	11C
0005432328330	31255	48	11D
0005432382848	31255	49	11E
0005432382880	31255	50	11F
0005432382868	31255	51	12A
0005432382879	31255	52	12C
0005432382863	31255	53	12D
0005432287146	31255	54	12E
0005432382883	31255	55	12F
0005432382859	31255	56	13A
0005432328325	31255	57	13C
0005432382847	31255	58	13D
0005432328336	31255	59	13E
0005432328345	31255	60	13F
0005432328318	31255	61	14A
0005432328313	31255	62	14C
0005432382851	31255	63	14D
0005432382850	31255	64	14E
0005432328333	31255	65	14F
0005432328341	31255	66	15A
0005432382881	31255	67	15C
0005432328351	31255	68	15D
0005432328317	31255	69	15E
0005432328358	31255	70	15F
0005432328340	31255	71	16A
0005432328350	31255	72	16C
0005432382853	31255	73	16E
0005432382858	31255	74	16F
0005432382872	31255	75	17A
0005432328359	31255	76	17C
0005432382875	31255	77	17D
0005432328338	31255	78	17E
0005432382876	31255	79	17F
0005432328320	31255	80	18A
0005432382873	31255	81	18C
0005432382857	31255	82	18D
0005432328328	31255	83	18E
0005432328357	31255	84	18F
0005432382864	31255	85	19A
0005432328322	31255	86	19C
0005432382860	31255	87	19D
0005432328324	31255	88	19E
0005432287147	31255	89	19F
0005432382846	31255	90	20A
0005432328334	31255	91	20C
0005432382870	31255	92	20D
0005432382854	31255	93	20F
0005432328346	31255	94	20E
0005432424092	13379	1	1A
0005432424068	13379	2	1F
0005432424062	13379	3	2A
0005432424069	13379	4	2C
0005432424086	13379	5	3A
0005432424087	13379	6	4C
0005432424093	13379	7	6D
0005432424078	13379	8	6F
0005432424075	13379	9	7D
0005432424085	13379	10	7E
0005432424064	13379	11	7F
0005432424058	13379	12	8A
0005432424088	13379	13	8C
0005432424060	13379	14	8F
0005432424079	13379	15	9C
0005432424070	13379	16	9D
0005432424076	13379	17	9F
0005432424072	13379	18	10C
0005432424073	13379	19	11C
0005432424074	13379	20	11D
0005432424071	13379	21	11E
0005432424059	13379	22	12A
0005432424084	13379	23	13C
0005432424082	13379	24	13F
0005432424094	13379	25	14D
0005432424067	13379	26	14F
0005432424080	13379	27	15A
0005432424063	13379	28	15E
0005432424089	13379	29	16D
0005432424065	13379	30	16E
0005432424081	13379	31	17C
0005432424096	13379	32	17E
0005432424066	13379	33	18C
0005432424097	13379	34	18D
0005432424090	13379	35	18E
0005432424083	13379	36	18F
0005432424095	13379	37	19A
0005432424061	13379	38	19F
0005432424091	13379	39	20A
0005432424077	13379	40	20C
0005432423706	30749	1	1C
0005432423722	30749	2	1F
0005432423723	30749	3	2C
0005432423689	30749	4	2F
0005432423668	30749	5	5C
0005432423613	30749	6	5E
0005432423731	30749	7	5F
0005432423730	30749	8	6A
0005432423653	30749	9	6C
0005432423627	30749	10	6D
0005432423724	30749	11	7D
0005432423636	30749	12	8A
0005432423631	30749	13	10A
0005432423614	30749	14	11F
0005432423681	30749	15	12D
0005432423628	30749	16	12E
0005432423680	30749	17	13A
0005432423690	30749	18	14A
0005432423649	30749	19	14E
0005432423748	30749	20	14F
0005432423632	30749	21	15A
0005432423729	30749	22	15C
0005432423735	30749	23	16F
0005432423707	30749	24	17F
0005432423697	30749	25	18E
0005432423721	30749	26	19F
0005432423669	30749	27	20A
0005432423660	30749	28	20E
0005432423762	30749	29	20F
0005434186162	9581	1	1A
0005432817253	9581	2	1C
0005432822149	9581	3	1F
0005432822144	9581	4	2C
0005432288963	9581	5	2F
0005432817268	9581	6	3A
0005432817261	9581	7	3C
0005432817242	9581	8	3F
0005432817257	9581	9	4C
0005434448290	9581	10	4D
0005432901359	9581	11	4E
0005434186153	9581	12	4F
0005432822150	9581	13	5C
0005432817259	9581	14	5E
0005432817241	9581	15	5F
0005432817250	9581	16	6D
0005434186161	9581	17	6F
0005434157361	9581	18	7A
0005432901388	9581	19	7C
0005432817246	9581	20	7D
0005432817245	9581	21	7F
0005434157373	9581	22	8A
0005432817244	9581	23	8C
0005432817264	9581	24	8D
0005432817252	9581	25	8E
0005432817248	9581	26	8F
0005432901296	9581	27	9A
0005432901323	9581	28	9E
0005432288961	9581	29	9F
0005434157353	9581	30	10C
0005432817270	9581	31	10D
0005432817263	9581	32	11A
0005432817256	9581	33	11C
0005432901322	9581	34	11E
0005432901337	9581	35	12A
0005432817269	9581	36	12C
0005432288962	9581	37	12D
0005432817247	9581	38	12E
0005432817258	9581	39	13A
0005432817262	9581	40	13C
0005432901328	9581	41	13D
0005432901355	9581	42	13F
0005432901362	9581	43	14C
0005432817255	9581	44	14D
0005432901344	9581	45	14E
0005432817249	9581	46	14F
0005432817266	9581	47	15A
0005432901360	9581	48	15C
0005432817254	9581	49	15D
0005434448291	9581	50	15F
0005432817251	9581	51	16D
0005432817260	9581	52	16E
0005432822145	9581	53	16F
0005432817265	9581	54	17A
0005432817267	9581	55	17C
0005432822146	9581	56	17E
0005432822143	9581	57	17F
0005432817243	9581	58	18A
0005434186147	9581	59	18C
0005434448292	9581	60	18D
0005434157372	9581	61	18E
0005432901343	9581	62	18F
0005432822147	9581	63	19A
0005434157347	9581	64	19D
0005434157352	9581	65	19F
0005434157362	9581	66	20A
0005432822148	9581	67	20C
0005432901482	28979	1	1A
0005432817062	28979	2	1C
0005432817065	28979	3	2C
0005432822103	28979	4	2D
0005432901489	28979	5	2F
0005432901483	28979	6	3A
0005434157422	28979	7	3D
0005434157420	28979	8	3F
0005432002061	28979	9	4A
0005434157426	28979	10	4C
0005432817091	28979	11	4D
0005432817003	28979	12	4E
0005432901490	28979	13	4F
0005432817040	28979	14	5D
0005432901491	28979	15	5E
0005432901484	28979	16	5F
0005432901481	28979	17	6A
0005432816946	28979	18	6D
0005432817133	28979	19	6E
0005432816998	28979	20	6F
0005432817121	28979	21	7A
0005432822102	28979	22	7C
0005432901487	28979	23	7D
0005434186176	28979	24	7F
0005434157425	28979	25	8C
0005432901475	28979	26	8E
0005432817035	28979	27	8F
0005432817002	28979	28	9A
0005434186175	28979	29	9C
0005432817005	28979	30	9E
0005432817122	28979	31	10A
0005432822099	28979	32	10C
0005432901477	28979	33	10D
0005432822064	28979	34	10F
0005432901480	28979	35	11A
0005434157421	28979	36	11C
0005432822104	28979	37	11E
0005432816947	28979	38	11F
0005432816996	28979	39	12C
0005432822076	28979	40	12A
0005432901476	28979	41	12D
0005432817019	28979	42	12E
0005432901474	28979	43	12F
0005434186177	28979	44	13A
0005432816967	28979	45	13C
0005432901485	28979	46	13D
0005432816982	28979	47	13F
0005432817001	28979	48	14A
0005432822069	28979	49	14C
0005434448257	28979	50	14D
0005432901473	28979	51	14E
0005432817072	28979	52	15A
0005432817004	28979	53	15C
0005432901479	28979	54	15D
0005434157427	28979	55	16D
0005432822105	28979	56	16E
0005432901486	28979	57	16F
0005432901488	28979	58	17A
0005432817093	28979	59	17C
0005434157424	28979	60	17E
0005432816997	28979	61	17F
0005432817092	28979	62	18A
0005432817029	28979	63	18C
0005434157419	28979	64	18D
0005432901478	28979	65	19A
0005434157423	28979	66	19C
0005432816999	28979	67	20A
0005432816973	28979	68	20C
0005432817064	28979	69	20D
0005432817063	28979	70	20E
0005432817028	28979	71	20F
0005432613834	15041	1	1A
0005435841081	15041	2	1B
0005432613831	15041	3	2A
0005435841085	15041	4	2B
0005432613833	15041	5	3A
0005435841086	15041	6	4A
0005432611680	15041	7	3B
0005432611681	15041	8	4B
0005432613832	15041	9	5A
0005432611682	15041	10	6A
0005432611683	15041	11	6B
0005435842324	31610	1	1B
0005435841815	31610	2	2A
0005432607503	31610	3	3A
0005435841814	31610	4	3B
0005435842323	31610	5	4B
0005435841816	31610	6	5A
0005432607501	31610	7	6A
0005432611643	31610	8	5B
0005432607504	31610	9	6B
0005433568598	11889	1	1C
0005433568595	11889	2	1A
0005433568603	11889	3	1F
0005433568549	11889	4	2A
0005433568602	11889	5	2D
0005433568575	11889	6	3A
0005433568562	11889	7	2F
0005433568571	11889	8	3D
0005433568578	11889	9	3C
0005433568605	11889	10	3F
0005433568589	11889	11	4C
0005433568599	11889	12	4A
0005432947882	11889	13	4D
0005433568573	11889	14	5C
0005433568569	11889	15	5A
0005433568561	11889	16	5D
0005433568572	11889	17	6B
0005433568548	11889	18	6C
0005433568574	11889	19	6F
0005433568555	11889	20	6E
0005433568594	11889	21	6D
0005432947932	11889	22	7C
0005433568556	11889	23	7E
0005433568544	11889	24	7D
0005432947956	11889	25	8B
0005433568551	11889	26	8F
0005433568587	11889	27	8E
0005433568552	11889	28	9B
0005432947953	11889	29	9A
0005432947881	11889	30	9E
0005432947823	11889	31	9F
0005433568600	11889	32	10C
0005433568576	11889	33	10B
0005432947915	11889	34	10E
0005433568592	11889	35	11B
0005433568550	11889	36	11A
0005432947779	11889	37	11D
0005433568559	11889	38	11C
0005433568554	11889	39	11F
0005433568546	11889	40	12D
0005432947917	11889	41	12C
0005433568604	11889	42	12F
0005433568590	11889	43	13C
0005433568593	11889	44	13B
0005432947857	11889	45	13E
0005433568597	11889	46	13D
0005433568568	11889	47	14A
0005433568584	11889	48	14C
0005433568547	11889	49	14B
0005433568596	11889	50	14E
0005432947916	11889	51	14D
0005433568557	11889	52	14F
0005433568582	11889	53	15A
0005433568601	11889	54	15B
0005433568566	11889	55	15E
0005432947955	11889	56	16A
0005433568580	11889	57	15F
0005433568579	11889	58	16D
0005433568560	11889	59	16C
0005433568558	11889	60	16F
0005433568570	11889	61	17C
0005432947954	11889	62	17E
0005433568581	11889	63	18A
0005432947825	11889	64	17F
0005433568565	11889	65	18C
0005433568563	11889	66	18F
0005433568564	11889	67	19C
0005432947899	11889	68	19E
0005432947803	11889	69	20A
0005433568545	11889	70	19F
0005433568583	11889	71	20B
0005433568577	11889	72	20D
0005433568567	11889	73	20C
0005433568585	11889	74	20E
0005433568553	11889	75	21A
0005433568588	11889	76	21C
0005433568591	11889	77	21B
0005433568586	11889	78	21F
0005432947931	11889	79	21E
0005432947824	11889	80	21D
0005432948207	25323	1	1C
0005433568180	25323	2	1A
0005433568162	25323	3	2C
0005433568053	25323	4	2D
0005433568098	25323	5	3A
0005433568186	25323	6	2F
0005433568182	25323	7	3D
0005433568048	25323	8	3C
0005432948194	25323	9	3F
0005432948185	25323	10	4D
0005433568059	25323	11	4C
0005432948213	25323	12	4A
0005432948215	25323	13	5A
0005433568159	25323	14	5F
0005433568066	25323	15	5D
0005432948191	25323	16	6A
0005432948188	25323	17	6D
0005432948216	25323	18	6C
0005433568018	25323	19	6B
0005432948187	25323	20	7C
0005433568198	25323	21	7B
0005432948202	25323	22	7E
0005432948181	25323	23	7D
0005432948190	25323	24	8A
0005432948184	25323	25	8D
0005432948203	25323	26	8C
0005432948183	25323	27	8F
0005433568140	25323	28	8E
0005432948201	25323	29	9A
0005433568015	25323	30	9D
0005433568099	25323	31	9B
0005433568029	25323	32	9E
0005433568215	25323	33	10C
0005432948200	25323	34	10E
0005432948189	25323	35	10F
0005433568183	25323	36	11B
0005432948219	25323	37	11A
0005433568152	25323	38	11D
0005432948198	25323	39	11C
0005432948204	25323	40	11F
0005432948211	25323	41	12B
0005433568108	25323	42	12E
0005433568028	25323	43	12D
0005433568217	25323	44	13A
0005433568160	25323	45	12F
0005432948195	25323	46	13C
0005433568104	25323	47	13B
0005432948220	25323	48	13E
0005432948214	25323	49	13D
0005432948197	25323	50	13F
0005433568155	25323	51	14B
0005433568103	25323	52	14A
0005432948199	25323	53	14E
0005432948206	25323	54	14D
0005432948182	25323	55	15B
0005433568185	25323	56	15A
0005433568030	25323	57	15D
0005432948212	25323	58	15C
0005432948205	25323	59	15E
0005432948208	25323	60	16A
0005433568101	25323	61	15F
0005433568121	25323	62	16C
0005433568120	25323	63	16B
0005432948193	25323	64	16E
0005432948210	25323	65	16D
0005433568058	25323	66	16F
0005433568175	25323	67	17A
0005433568041	25323	68	17C
0005433568019	25323	69	17E
0005433568031	25323	70	18C
0005433568204	25323	71	18E
0005433568218	25323	72	18D
0005433568184	25323	73	19A
0005432948209	25323	74	18F
0005433568096	25323	75	19B
0005433568224	25323	76	19D
0005433568256	25323	77	19C
0005433568063	25323	78	20A
0005433568097	25323	79	19E
0005432948186	25323	80	20B
0005433568156	25323	81	20D
0005433568134	25323	82	20C
0005433568179	25323	83	20F
0005432948218	25323	84	21B
0005432948221	25323	85	21A
0005432948192	25323	86	21C
0005432948217	25323	87	21E
0005433568016	25323	88	21D
0005432948196	25323	89	21F
0005433808342	30820	1	1A
0005432430807	30820	2	3F
0005433808345	30820	3	6C
0005433808347	30820	4	8D
0005433808340	30820	5	9F
0005433812875	30820	6	9E
0005433808341	30820	7	9D
0005434026670	30820	8	10E
0005433808339	30820	9	10F
0005433808344	30820	10	11C
0005433808343	30820	11	11D
0005432430803	30820	12	12E
0005433812879	30820	13	12D
0005433812876	30820	14	13E
0005433808346	30820	15	14B
0005433812880	30820	16	14C
0005433812878	30820	17	14F
0005433812877	30820	18	16A
0005433808338	30820	19	16B
0005432430802	30820	20	18A
0005434026671	30820	21	18D
0005432430813	30820	22	18C
0005433808337	30820	23	19A
0005434026669	30820	24	20A
0005433808336	30820	25	20B
0005433812874	30820	26	21E
0005432114178	5375	1	1C
0005434654463	5375	2	2C
0005434656542	5375	3	2D
0005434654485	5375	4	2F
0005434654482	5375	5	3F
0005434654487	5375	6	4E
0005434654476	5375	7	4F
0005434654470	5375	8	5D
0005434654473	5375	9	5F
0005435340016	5375	10	6A
0005434654486	5375	11	6C
0005434656541	5375	12	6E
0005434654464	5375	13	6F
0005434654467	5375	14	7D
0005435340014	5375	15	7F
0005434654477	5375	16	8A
0005435340066	5375	17	9A
0005435340061	5375	18	9C
0005434654474	5375	19	9D
0005434654488	5375	20	9E
0005435340015	5375	21	9F
0005434654466	5375	22	10A
0005434654465	5375	23	11A
0005434654483	5375	24	11C
0005434654471	5375	25	12C
0005435340035	5375	26	12D
0005434654478	5375	27	13C
0005435555343	5375	28	13E
0005434654479	5375	29	13F
0005432114180	5375	30	14A
0005434654462	5375	31	14D
0005435340060	5375	32	14E
0005434654468	5375	33	14F
0005434654469	5375	34	15E
0005434654481	5375	35	16D
0005435340080	5375	36	16E
0005435340081	5375	37	17C
0005435340013	5375	38	17D
0005434654472	5375	39	17E
0005434654461	5375	40	17F
0005432114179	5375	41	18F
0005434654480	5375	42	19D
0005434654484	5375	43	20A
0005434654475	5375	44	20C
0005435340145	12540	1	1A
0005435340150	12540	2	1C
0005434654337	12540	3	1F
0005434654241	12540	4	2F
0005434654256	12540	5	3A
0005434654269	12540	6	3C
0005434654228	12540	7	3F
0005434654251	12540	8	4A
0005434654227	12540	9	4D
0005434654203	12540	10	4E
0005435340149	12540	11	5A
0005435340153	12540	12	5D
0005434654304	12540	13	5F
0005434654268	12540	14	6D
0005434654257	12540	15	6E
0005434654211	12540	16	6F
0005434654177	12540	17	7A
0005435340146	12540	18	7C
0005434654163	12540	19	7D
0005434654260	12540	20	7F
0005435340157	12540	21	8D
0005435340158	12540	22	8F
0005434654164	12540	23	9C
0005435340156	12540	24	9F
0005435340155	12540	25	10F
0005434654348	12540	26	11A
0005434654298	12540	27	12A
0005435340154	12540	28	12D
0005434654214	12540	29	12E
0005434654328	12540	30	13A
0005434654297	12540	31	13D
0005434654193	12540	32	13E
0005434654199	12540	33	13F
0005434654327	12540	34	14D
0005434654162	12540	35	14F
0005435340147	12540	36	15D
0005434654168	12540	37	15F
0005435340144	12540	38	16A
0005434654178	12540	39	16E
0005435340152	12540	40	17A
0005434654165	12540	41	17C
0005434654383	12540	42	18A
0005434654240	12540	43	18C
0005434654210	12540	44	18D
0005435340159	12540	45	18E
0005435340151	12540	46	19C
0005435340148	12540	47	19D
0005434654338	12540	48	19E
0005435555356	12540	49	20C
0005434654189	12540	50	20E
0005434654179	12540	51	20F
0005433656642	7420	1	1D
0005433715599	7420	2	2A
0005433715613	7420	3	1F
0005433715626	7420	4	2F
0005433715605	7420	5	3A
0005433715607	7420	6	3D
0005433690911	7420	7	3C
0005433722168	7420	8	4A
0005433715587	7420	9	5A
0005433715584	7420	10	4F
0005432078065	7420	11	5D
0005433715597	7420	12	5C
0005433689894	7420	13	6B
0005433689893	7420	14	6C
0005432078067	7420	15	6E
0005433715627	7420	16	6D
0005433715594	7420	17	6F
0005433715621	7420	18	7C
0005433715602	7420	19	7D
0005433715590	7420	20	7E
0005433719114	7420	21	8B
0005433715578	7420	22	8D
0005433715623	7420	23	8C
0005433715586	7420	24	8E
0005433715625	7420	25	9A
0005433690910	7420	26	9B
0005433715614	7420	27	9D
0005433688794	7420	28	10E
0005433715591	7420	29	10D
0005433715580	7420	30	11A
0005433715581	7420	31	11B
0005433715620	7420	32	11D
0005433690909	7420	33	11F
0005433688793	7420	34	12A
0005433715608	7420	35	12C
0005433715612	7420	36	12D
0005433715606	7420	37	12F
0005433715618	7420	38	12E
0005433715615	7420	39	13A
0005432078070	7420	40	13C
0005433715610	7420	41	13E
0005433715583	7420	42	14A
0005433715604	7420	43	14B
0005433715619	7420	44	14E
0005433715577	7420	45	15A
0005432078069	7420	46	14F
0005433715617	7420	47	15C
0005433722167	7420	48	15B
0005433656643	7420	49	16C
0005433715579	7420	50	16B
0005433715592	7420	51	16D
0005433715611	7420	52	17B
0005432078068	7420	53	17F
0005433715593	7420	54	17E
0005433715595	7420	55	18B
0005433715616	7420	56	18E
0005433715609	7420	57	18D
0005433715603	7420	58	19A
0005432078066	7420	59	19C
0005433715588	7420	60	19D
0005433715600	7420	61	19F
0005433722169	7420	62	20A
0005433715585	7420	63	20C
0005433715622	7420	64	20B
0005433688792	7420	65	20E
0005433656644	7420	66	21A
0005433719113	7420	67	21B
0005435266074	7420	68	21C
0005433715582	7420	69	22B
0005433715598	7420	70	22C
0005433715589	7420	71	22D
0005433715624	7420	72	23B
0005433715601	7420	73	23A
0005433715596	7420	74	23F
0005432428902	29248	1	1A
0005433715119	29248	2	1D
0005433715282	29248	3	2C
0005433715145	29248	4	2A
0005433719082	29248	5	2D
0005433722103	29248	6	3A
0005433715313	29248	7	4D
0005433722115	29248	8	4E
0005433715180	29248	9	5A
0005433715364	29248	10	5E
0005433715143	29248	11	6A
0005433715188	29248	12	7A
0005432006739	29248	13	7B
0005433715209	29248	14	7F
0005433715210	29248	15	8B
0005433715144	29248	16	8C
0005433719089	29248	17	9B
0005433715208	29248	18	9D
0005433715298	29248	19	9C
0005433715349	29248	20	9E
0005433715108	29248	21	9F
0005435266120	29248	22	10D
0005433715135	29248	23	11B
0005433685494	29248	24	12D
0005432428905	29248	25	12C
0005433715146	29248	26	12E
0005433715175	29248	27	13A
0005432006740	29248	28	13D
0005433715174	29248	29	13E
0005433715110	29248	30	14C
0005433715077	29248	31	14B
0005433715283	29248	32	14D
0005433715288	29248	33	14F
0005433715151	29248	34	15D
0005432428903	29248	35	15F
0005433715226	29248	36	16B
0005433715150	29248	37	16C
0005433656616	29248	38	16E
0005433715117	29248	39	16F
0005433715279	29248	40	17B
0005433715296	29248	41	17A
0005433715225	29248	42	17E
0005433715109	29248	43	18C
0005433715085	29248	44	19A
0005435266119	29248	45	19D
0005433715245	29248	46	20B
0005433715134	29248	47	20F
0005433715215	29248	48	21B
0005433722106	29248	49	21A
0005433715224	29248	50	21D
0005432428904	29248	51	21F
0005433715136	29248	52	22A
0005433715345	29248	53	22B
0005433715129	29248	54	22C
0005433715419	29248	55	22D
0005435266118	29248	56	22F
0005433715297	29248	57	22E
0005433715173	29248	58	23A
0005433715363	29248	59	23B
0005433715096	29248	60	23E
0005434181982	8650	1	1A
0005434095165	8650	2	2A
0005434182057	8650	3	3A
0005434184632	8650	4	3C
0005434095166	8650	5	4A
0005434182015	8650	6	5A
0005434181969	8650	7	5C
0005434095171	8650	8	5D
0005434095176	8650	9	5F
0005434095170	8650	10	6D
0005434182012	8650	11	6F
0005434095172	8650	12	7C
0005434095175	8650	13	8E
0005434181970	8650	14	9E
0005434182008	8650	15	9F
0005434181958	8650	16	10A
0005434184631	8650	17	10D
0005434095168	8650	18	11C
0005434182014	8650	19	12F
0005434182004	8650	20	13D
0005434095169	8650	21	14E
0005434095163	8650	22	15A
0005434095167	8650	23	15D
0005434095164	8650	24	16A
0005434182003	8650	25	16E
0005434095173	8650	26	17A
0005434181983	8650	27	19F
0005434095174	8650	28	20C
0005434182085	11639	1	1C
0005434184648	11639	2	2C
0005434095128	11639	3	2F
0005434182093	11639	4	3D
0005434182088	11639	5	4C
0005434182092	11639	6	4D
0005434182094	11639	7	5D
0005434095065	11639	8	5F
0005434184649	11639	9	6D
0005434182087	11639	10	6E
0005434095064	11639	11	7C
0005434182096	11639	12	8F
0005434326259	11639	13	9A
0005434095113	11639	14	9C
0005434326260	11639	15	9E
0005434182095	11639	16	10C
0005434182086	11639	17	10E
0005434182097	11639	18	11D
0005434182091	11639	19	11F
0005434095129	11639	20	12C
0005434095049	11639	21	13A
0005434095112	11639	22	14C
0005434182090	11639	23	15C
0005434095083	11639	24	15F
0005434184647	11639	25	16C
0005434095072	11639	26	16E
0005434095084	11639	27	17C
0005434143701	11639	28	17D
0005434182098	11639	29	18A
0005434095073	11639	30	18E
0005434182089	11639	31	19E
0005434183563	11639	32	20D
0005433397261	1462	1	1A
0005433397180	1462	2	1C
0005433397186	1462	3	1F
0005433397281	1462	4	2D
0005433397519	1462	5	2F
0005435732243	1462	6	3C
0005435732237	1462	7	3D
0005433397253	1462	8	3F
0005433397400	1462	9	4A
0005435732236	1462	10	4C
0005435732247	1462	11	4E
0005433456938	1462	12	4F
0005433456941	1462	13	5C
0005433397328	1462	14	5A
0005433397294	1462	15	5D
0005433397349	1462	16	5F
0005433397193	1462	17	6C
0005435732246	1462	18	6D
0005435732242	1462	19	6F
0005433397235	1462	20	7A
0005433397344	1462	21	7C
0005433397312	1462	22	7D
0005435732251	1462	23	7E
0005433397243	1462	24	8A
0005435732245	1462	25	8C
0005435732253	1462	26	8D
0005433397240	1462	27	8E
0005435732235	1462	28	9C
0005433456940	1462	29	9F
0005433397472	1462	30	11A
0005435732249	1462	31	11C
0005433397311	1462	32	11D
0005433397280	1462	33	11F
0005435732234	1462	34	12A
0005435732240	1462	35	12C
0005435732254	1462	36	12D
0005435732248	1462	37	12E
0005433397329	1462	38	12F
0005433397458	1462	39	13A
0005435732250	1462	40	13C
0005432297259	1462	41	13D
0005433397233	1462	42	14A
0005433397320	1462	43	14D
0005435732241	1462	44	14F
0005433397223	1462	45	15A
0005432297257	1462	46	15E
0005435732252	1462	47	16D
0005435732256	1462	48	16E
0005435732238	1462	49	16F
0005433397231	1462	50	17A
0005433397295	1462	51	17D
0005433397256	1462	52	17E
0005433456939	1462	53	17F
0005435732244	1462	54	18A
0005432297260	1462	55	18C
0005435732255	1462	56	18E
0005433397192	1462	57	18F
0005433397399	1462	58	19A
0005435732233	1462	59	19C
0005433397282	1462	60	19D
0005435732239	1462	61	19E
0005432297258	1462	62	19F
0005433397277	1462	63	20A
0005433397232	1462	64	20D
0005433456937	1462	65	20E
0005435732144	19264	1	1A
0005433397719	19264	2	1C
0005433397687	19264	3	1D
0005433397683	19264	4	1F
0005433397681	19264	5	2A
0005435732213	19264	6	2D
0005433397679	19264	7	2F
0005435732147	19264	8	3A
0005433397724	19264	9	3C
0005433397682	19264	10	3F
0005432906516	19264	11	5A
0005433397703	19264	12	5E
0005435732115	19264	13	5F
0005433397714	19264	14	6A
0005433397712	19264	15	6D
0005433397696	19264	16	6E
0005433397713	19264	17	6F
0005433397704	19264	18	7A
0005433397699	19264	19	7C
0005433397721	19264	20	7F
0005433397698	19264	21	8A
0005433456911	19264	22	8C
0005433397706	19264	23	8D
0005433397685	19264	24	8E
0005433397680	19264	25	8F
0005433397723	19264	26	9C
0005433397716	19264	27	9D
0005435732212	19264	28	9E
0005433397722	19264	29	10C
0005433397692	19264	30	10E
0005433397677	19264	31	10F
0005433397709	19264	32	11A
0005433456902	19264	33	11D
0005433397702	19264	34	11E
0005435732132	19264	35	12A
0005433397695	19264	36	12C
0005433397678	19264	37	12E
0005433397707	19264	38	12F
0005435732146	19264	39	13A
0005433397690	19264	40	13E
0005433397686	19264	41	14A
0005433397701	19264	42	14C
0005433456901	19264	43	14D
0005433397691	19264	44	14F
0005433397689	19264	45	15A
0005432906518	19264	46	15D
0005433397694	19264	47	16A
0005435732143	19264	48	16C
0005433397705	19264	49	16D
0005435732114	19264	50	16E
0005433397725	19264	51	16F
0005433456920	19264	52	17A
0005433397708	19264	53	17C
0005433397697	19264	54	17D
0005433397717	19264	55	17E
0005433397710	19264	56	18A
0005433397688	19264	57	18C
0005433397684	19264	58	18D
0005433397693	19264	59	18E
0005433397718	19264	60	19A
0005433397700	19264	61	19D
0005433397720	19264	62	19E
0005433397676	19264	63	19F
0005435732196	19264	64	20A
0005433397711	19264	65	20C
0005435732161	19264	66	20D
0005432906517	19264	67	20E
0005433397715	19264	68	20F
0005434443450	17347	1	3D
0005434443435	17347	2	5A
0005434443495	17347	3	6A
0005434443424	17347	4	6C
0005434443458	17347	5	7B
0005434443440	17347	6	7C
0005434443444	17347	7	20C
0005434443451	17347	8	21D
0005434443584	20598	1	1A
0005434443578	20598	2	1C
0005434443585	20598	3	1D
0005434443580	20598	4	2B
0005434443576	20598	5	3A
0005434443574	20598	6	3C
0005434443579	20598	7	5A
0005434443588	20598	8	5B
0005434443586	20598	9	5D
0005434443582	20598	10	6A
0005434443589	20598	11	7A
0005434443572	20598	12	7D
0005434443583	20598	13	18B
0005434443577	20598	14	18D
0005434443575	20598	15	19C
0005434443581	20598	16	22A
0005434443587	20598	17	22B
0005434443573	20598	18	23A
0005435377538	7235	1	1A
0005435377543	7235	2	2B
0005435377540	7235	3	2A
0005435377545	7235	4	3B
0005435377539	7235	5	4A
0005434954580	7235	6	4B
0005434954579	7235	7	5B
0005434954581	7235	8	6A
0005434954578	7235	9	6B
0005434954555	28347	1	2A
0005434954554	28347	2	3A
0005435377562	28347	3	4A
0005435377565	28347	4	4B
0005435377561	28347	5	5A
0005435377564	28347	6	5B
0005435377563	28347	7	6A
0005434351605	4477	1	1A
0005434351603	4477	2	2A
0005435893508	4477	3	2D
0005434351597	4477	4	3A
0005435893514	4477	5	3D
0005434351602	4477	6	4A
0005434326267	4477	7	4B
0005435893523	4477	8	5A
0005435893535	4477	9	5B
0005435893529	4477	10	6A
0005434351604	4477	11	6C
0005435893524	4477	12	6D
0005435893517	4477	13	7A
0005435893536	4477	14	7B
0005434351598	4477	15	7C
0005434183547	4477	16	7D
0005435893516	4477	17	18A
0005435893542	4477	18	18D
0005435893509	4477	19	19A
0005434351600	4477	20	19B
0005434351608	4477	21	19D
0005435893541	4477	22	20A
0005434351606	4477	23	20B
0005434351599	4477	24	20D
0005434351607	4477	25	21A
0005434351596	4477	26	21C
0005434351601	4477	27	22A
0005434351595	4477	28	22B
0005435893522	4477	29	22D
0005434326266	4477	30	23A
0005435893534	4477	31	23B
0005434351499	29645	1	1B
0005434351519	29645	2	1C
0005434351532	29645	3	2A
0005434351533	29645	4	3C
0005435893575	29645	5	4A
0005435893580	29645	6	5B
0005434351479	29645	7	6C
0005435893581	29645	8	6D
0005434351480	29645	9	7B
0005434351497	29645	10	7C
0005435893576	29645	11	7D
0005435893582	29645	12	18A
0005434351498	29645	13	18B
0005435893577	29645	14	18C
0005434351515	29645	15	18D
0005435893579	29645	16	19B
0005434351526	29645	17	20D
0005434351514	29645	18	21A
0005434351531	29645	19	21B
0005434351492	29645	20	22C
0005434351484	29645	21	23A
0005435893578	29645	22	23B
0005433341591	1057	1	1A
0005433158102	1057	2	1B
0005433341435	1057	3	1F
0005433341770	1057	4	1C
0005433341491	1057	5	1G
0005433341677	1057	6	2B
0005433341419	1057	7	2C
0005433341464	1057	8	3A
0005433341609	1057	9	2H
0005435092002	1057	10	3B
0005433463884	1057	11	3F
0005433341676	1057	12	4A
0005433341418	1057	13	4B
0005433341482	1057	14	4C
0005433341540	1057	15	4G
0005433341761	1057	16	5A
0005433341503	1057	17	5B
0005433341838	1057	18	5F
0005433341753	1057	19	9A
0005433341546	1057	20	5H
0005433341526	1057	21	9G
0005433341392	1057	22	11A
0005433341837	1057	23	11B
0005433341795	1057	24	11D
0005433341732	1057	25	11F
0005433341745	1057	26	11H
0005433341467	1057	27	12A
0005433462731	1057	28	12B
0005433341523	1057	29	12D
0005433269637	1057	30	12F
0005433341706	1057	31	13B
0005433341644	1057	32	13E
0005433341680	1057	33	13G
0005435092005	1057	34	13H
0005433341763	1057	35	14B
0005433341437	1057	36	14E
0005433269639	1057	37	14G
0005435091998	1057	38	15A
0005433341541	1057	39	15B
0005433341499	1057	40	15E
0005433341839	1057	41	15D
0005433159279	1057	42	15F
0005435092001	1057	43	16A
0005433341652	1057	44	16B
0005433341744	1057	45	16E
0005433341804	1057	46	16D
0005435092000	1057	47	16G
0005433341830	1057	48	16F
0005433341771	1057	49	17B
0005433341645	1057	50	17F
0005433341516	1057	51	17G
0005433341937	1057	52	18B
0005433341875	1057	53	18A
0005433341542	1057	54	18D
0005433341829	1057	55	18F
0005434445232	1057	56	18E
0005433341874	1057	57	19A
0005435091997	1057	58	19D
0005433159280	1057	59	20E
0005433341438	1057	60	20D
0005433462730	1057	61	20G
0005433341457	1057	62	21A
0005433341840	1057	63	20H
0005433463885	1057	64	21B
0005433341524	1057	65	21E
0005433462732	1057	66	21H
0005433341512	1057	67	22D
0005433341865	1057	68	22F
0005433341705	1057	69	22E
0005433341762	1057	70	22H
0005433341610	1057	71	23A
0005433341397	1057	72	23B
0005433341479	1057	73	23G
0005435091996	1057	74	24B
0005433341444	1057	75	24D
0005433341420	1057	76	24F
0005433341681	1057	77	25D
0005433341547	1057	78	25F
0005434445231	1057	79	25E
0005433341659	1057	80	27A
0005433341746	1057	81	27D
0005433341388	1057	82	28A
0005433341841	1057	83	27H
0005433158103	1057	84	28E
0005433341674	1057	85	28G
0005432293190	1057	86	29A
0005433341436	1057	87	28H
0005433341707	1057	88	29B
0005433341588	1057	89	29E
0005433341504	1057	90	29G
0005433341543	1057	91	29F
0005433341666	1057	92	29H
0005433341393	1057	93	30A
0005433341936	1057	94	30F
0005433341498	1057	95	31A
0005433341640	1057	96	31B
0005433341571	1057	97	31D
0005435092003	1057	98	31E
0005433159277	1057	99	31H
0005434445230	1057	100	32F
0005433158101	1057	101	32H
0005433341517	1057	102	32G
0005433341511	1057	103	33A
0005433341668	1057	104	33B
0005433341718	1057	105	33F
0005433341660	1057	106	34A
0005433341521	1057	107	34B
0005432293189	1057	108	34F
0005433341522	1057	109	34E
0005433341463	1057	110	34D
0005433341398	1057	111	34G
0005433341445	1057	112	35A
0005433269620	1057	113	35D
0005433341394	1057	114	36A
0005433341483	1057	115	35H
0005435092004	1057	116	36B
0005433341717	1057	117	36E
0005433341769	1057	118	37A
0005433341468	1057	119	37E
0005433341497	1057	120	37F
0005433341456	1057	121	37H
0005435091999	1057	122	38B
0005433341794	1057	123	38G
0005433269638	1057	124	38H
0005433342310	17059	1	1A
0005433342383	17059	2	1B
0005433342389	17059	3	1F
0005435091933	17059	4	2B
0005435091952	17059	5	2F
0005433342322	17059	6	2C
0005433342327	17059	7	2H
0005433342311	17059	8	2G
0005433342365	17059	9	3B
0005433342328	17059	10	3F
0005433342392	17059	11	4A
0005433342339	17059	12	3H
0005433342364	17059	13	4G
0005433342369	17059	14	4F
0005433342326	17059	15	5B
0005433269680	17059	16	5A
0005433342388	17059	17	5F
0005433342376	17059	18	5C
0005435091910	17059	19	9B
0005433342306	17059	20	9G
0005433342359	17059	21	11E
0005433342301	17059	22	11D
0005433342366	17059	23	11F
0005433342362	17059	24	12A
0005433342313	17059	25	12B
0005435091916	17059	26	12F
0005433342342	17059	27	12G
0005433342348	17059	28	13A
0005433342357	17059	29	13D
0005434445211	17059	30	13F
0005433342371	17059	31	13E
0005433342296	17059	32	13H
0005433342323	17059	33	14B
0005433342375	17059	34	14D
0005433342374	17059	35	14F
0005433342379	17059	36	14G
0005433269676	17059	37	15E
0005433342370	17059	38	15G
0005433342312	17059	39	16B
0005433342333	17059	40	16E
0005433342367	17059	41	16G
0005433342324	17059	42	16H
0005433342295	17059	43	17B
0005433342352	17059	44	17D
0005433342384	17059	45	17F
0005433342309	17059	46	17E
0005434445212	17059	47	17G
0005433159297	17059	48	18A
0005433342330	17059	49	17H
0005433269679	17059	50	18D
0005433342336	17059	51	18G
0005433342360	17059	52	19B
0005433342294	17059	53	19G
0005433342303	17059	54	19H
0005433342353	17059	55	20B
0005433342325	17059	56	20F
0005433342378	17059	57	20H
0005433342318	17059	58	20G
0005433342305	17059	59	21B
0005433342304	17059	60	21E
0005433269677	17059	61	21G
0005433342391	17059	62	21H
0005433342350	17059	63	22A
0005433342332	17059	64	22F
0005433269675	17059	65	23G
0005433342361	17059	66	23F
0005433342363	17059	67	24A
0005433342308	17059	68	23H
0005433342349	17059	69	24B
0005433342351	17059	70	24H
0005433342377	17059	71	25E
0005433342340	17059	72	25F
0005433462708	17059	73	27A
0005433342345	17059	74	27E
0005433269678	17059	75	27H
0005433342329	17059	76	28A
0005433342355	17059	77	28B
0005433342354	17059	78	28H
0005433342358	17059	79	29A
0005433342334	17059	80	29E
0005433159296	17059	81	29D
0005433342372	17059	82	29H
0005435508164	17059	83	29G
0005433342302	17059	84	30D
0005433342394	17059	85	30B
0005433342316	17059	86	30E
0005435091937	17059	87	30G
0005433342315	17059	88	30F
0005433342356	17059	89	30H
0005433342314	17059	90	31F
0005433342297	17059	91	31E
0005433342393	17059	92	31G
0005433342341	17059	93	32F
0005433342320	17059	94	32E
0005433342390	17059	95	33B
0005433342385	17059	96	33E
0005433342373	17059	97	33D
0005433342338	17059	98	33F
0005433342299	17059	99	33H
0005433342380	17059	100	34D
0005433342347	17059	101	34F
0005433342387	17059	102	35F
0005433342321	17059	103	35E
0005433342317	17059	104	35G
0005433342344	17059	105	35H
0005433342335	17059	106	36E
0005433342337	17059	107	36H
0005433342381	17059	108	36G
0005433342307	17059	109	37B
0005433342331	17059	110	37E
0005433342298	17059	111	38A
0005433342343	17059	112	37H
0005433342382	17059	113	38D
0005433342386	17059	114	38B
0005433342319	17059	115	38F
0005433342346	17059	116	38H
0005433342368	17059	117	39E
0005433342300	17059	118	39F
0005432851872	18266	1	1C
0005432851873	18266	2	2F
0005432851864	18266	3	3C
0005432389940	18266	4	4A
0005432389945	18266	5	4C
0005432851878	18266	6	5A
0005432851870	18266	7	6A
0005432389939	18266	8	6E
0005432851865	18266	9	7B
0005432389955	18266	10	8D
0005432389934	18266	11	9C
0005432851866	18266	12	9D
0005432389935	18266	13	10C
0005432851881	18266	14	10D
0005432851869	18266	15	10F
0005432851871	18266	16	11A
0005432389961	18266	17	12D
0005432851882	18266	18	13A
0005432389933	18266	19	12F
0005432851877	18266	20	13E
0005432389941	18266	21	13F
0005432389963	18266	22	14D
0005432851876	18266	23	15A
0005432389950	18266	24	14E
0005432389960	18266	25	16B
0005432389954	18266	26	16D
0005432391951	18266	27	17A
0005432851875	18266	28	17C
0005432391950	18266	29	17F
0005432389943	18266	30	17E
0005432389936	18266	31	18C
0005432851874	18266	32	18E
0005432851880	18266	33	18D
0005432851879	18266	34	19B
0005432389984	18266	35	19E
0005432851868	18266	36	20B
0005432851867	18266	37	20D
0005434066729	12771	1	1C
0005433989686	12771	2	1D
0005434066425	12771	3	2A
0005434081615	12771	4	2C
0005432433638	12771	5	3C
0005434081572	12771	6	3A
0005432433637	12771	7	3D
0005434066429	12771	8	4E
0005434066420	12771	9	5A
0005434081533	12771	10	4F
0005432159823	12771	11	5B
0005434081540	12771	12	6C
0005434066509	12771	13	6B
0005434066358	12771	14	6E
0005434066414	12771	15	6D
0005432161135	12771	16	7A
0005432161134	12771	17	7F
0005434081542	12771	18	8A
0005434066444	12771	19	8F
0005434066301	12771	20	9A
0005433812881	12771	21	9D
0005434066447	12771	22	9F
0005434066357	12771	23	10B
0005434066621	12771	24	10E
0005434066465	12771	25	10D
0005434066391	12771	26	11B
0005434081534	12771	27	11C
0005432159821	12771	28	11E
0005434066508	12771	29	11D
0005434066408	12771	30	11F
0005434066728	12771	31	12A
0005434066506	12771	32	12C
0005434066343	12771	33	12B
0005434081616	12771	34	12E
0005434066419	12771	35	13A
0005434066302	12771	36	13B
0005434066310	12771	37	13E
0005432433642	12771	38	13F
0005434066363	12771	39	14B
0005434066435	12771	40	14A
0005434081574	12771	41	14C
0005432159824	12771	42	15A
0005434066436	12771	43	15B
0005434066469	12771	44	15D
0005434066415	12771	45	16A
0005433812882	12771	46	16C
0005434066443	12771	47	16E
0005433989685	12771	48	17A
0005434081571	12771	49	17B
0005434066399	12771	50	17F
0005434081525	12771	51	17E
0005434066423	12771	52	18A
0005434081554	12771	53	18D
0005432433641	12771	54	18F
0005434066571	12771	55	19D
0005433812883	12771	56	19F
0005432433640	12771	57	19E
0005433989697	12771	58	20A
0005433989687	12771	59	20C
0005434066417	12771	60	20F
0005434081476	12771	61	21B
0005434066507	12771	62	21C
0005434066418	12771	63	21E
0005432159822	12771	64	22A
0005432433639	12771	65	21F
0005432159825	12771	66	22C
0005434066622	12771	67	22B
0005434081575	12771	68	22E
0005434066605	12771	69	22F
0005434081524	12771	70	23B
0005434066517	12771	71	23C
0005434081569	12771	72	23E
0005434081570	12771	73	23F
0005433989730	30657	1	1A
0005434066954	30657	2	1C
0005434066999	30657	3	1D
0005433989733	30657	4	1F
0005434081727	30657	5	2C
0005434081720	30657	6	2A
0005434081701	30657	7	2F
0005432150131	30657	8	3A
0005434067015	30657	9	3D
0005434067006	30657	10	3C
0005432186837	30657	11	3F
0005434066950	30657	12	4B
0005432433602	30657	13	4A
0005434081714	30657	14	4C
0005433989731	30657	15	4D
0005434081698	30657	16	4E
0005434066976	30657	17	4F
0005434081704	30657	18	5B
0005434081706	30657	19	5A
0005434066975	30657	20	5D
0005434066977	30657	21	5E
0005434081723	30657	22	6A
0005434066961	30657	23	5F
0005432150129	30657	24	6B
0005434066970	30657	25	6C
0005434067016	30657	26	6D
0005434067010	30657	27	6F
0005434066994	30657	28	6E
0005434081707	30657	29	7B
0005434067001	30657	30	7A
0005434081702	30657	31	7C
0005434081713	30657	32	7E
0005434066972	30657	33	7D
0005433989734	30657	34	7F
0005434066956	30657	35	8A
0005434066982	30657	36	8B
0005434081725	30657	37	8D
0005434081715	30657	38	8C
0005432186839	30657	39	8E
0005434067012	30657	40	8F
0005434066968	30657	41	9A
0005432150127	30657	42	9B
0005434081710	30657	43	9D
0005434066964	30657	44	9C
0005434081719	30657	45	9E
0005434067004	30657	46	9F
0005432150133	30657	47	10B
0005434067003	30657	48	10C
0005434081724	30657	49	10E
0005434067014	30657	50	10D
0005434066960	30657	51	11A
0005432186838	30657	52	11B
0005434066997	30657	53	11D
0005434081709	30657	54	11C
0005434066951	30657	55	11E
0005434066966	30657	56	11F
0005434066995	30657	57	12B
0005434066981	30657	58	12A
0005434067019	30657	59	12D
0005434066969	30657	60	12C
0005434067007	30657	61	12E
0005434081717	30657	62	12F
0005434067020	30657	63	13B
0005434066971	30657	64	13A
0005434066955	30657	65	13C
0005433989732	30657	66	13E
0005434081726	30657	67	13D
0005434066986	30657	68	14B
0005434066996	30657	69	14A
0005434081716	30657	70	14C
0005434067017	30657	71	14D
0005432150128	30657	72	14E
0005434066973	30657	73	14F
0005434066987	30657	74	15B
0005434081722	30657	75	15A
0005434066967	30657	76	15C
0005434066963	30657	77	15E
0005434067000	30657	78	15D
0005434066984	30657	79	16B
0005432150126	30657	80	16A
0005434067011	30657	81	16C
0005434081712	30657	82	16D
0005434066989	30657	83	17A
0005434066983	30657	84	16F
0005434066949	30657	85	17B
0005434066958	30657	86	17C
0005434066991	30657	87	17E
0005432150132	30657	88	17D
0005434081711	30657	89	18A
0005434066978	30657	90	17F
0005434081703	30657	91	18C
0005434066988	30657	92	18E
0005434081718	30657	93	18D
0005432433595	30657	94	18F
0005434066990	30657	95	19A
0005434067013	30657	96	19B
0005434081700	30657	97	19D
0005432186840	30657	98	19C
0005434066993	30657	99	19E
0005434066979	30657	100	20A
0005434066965	30657	101	19F
0005434067018	30657	102	20D
0005434081699	30657	103	20C
0005434067008	30657	104	20E
0005434066992	30657	105	20F
0005434066980	30657	106	21B
0005434066953	30657	107	21A
0005434066952	30657	108	21D
0005432150130	30657	109	21C
0005434081705	30657	110	21E
0005434066998	30657	111	22A
0005434081708	30657	112	22B
0005434067009	30657	113	22C
0005434066985	30657	114	22D
0005434066962	30657	115	22F
0005434066974	30657	116	22E
0005434067005	30657	117	23A
0005434066948	30657	118	23B
0005434081721	30657	119	23C
0005434066957	30657	120	23D
0005434066959	30657	121	23E
0005434067002	30657	122	23F
0005433686621	9046	1	1D
0005433687689	9046	2	2A
0005433685509	9046	3	2B
0005433685508	9046	4	2C
0005433685507	9046	5	2D
0005433686619	9046	6	3A
0005433687696	9046	7	3B
0005433685513	9046	8	4C
0005433687695	9046	9	5A
0005433686623	9046	10	5B
0005433687693	9046	11	5C
0005433685511	9046	12	6A
0005433686620	9046	13	6B
0005433685510	9046	14	7B
0005433686617	9046	15	7D
0005433685514	9046	16	18A
0005433686622	9046	17	18B
0005433687692	9046	18	19C
0005433687690	9046	19	20A
0005433685512	9046	20	21A
0005433686618	9046	21	21B
0005433687691	9046	22	21D
0005433686624	9046	23	22A
0005433687694	9046	24	23B
0005434264750	5515	1	1B
0005435765765	5515	2	1F
0005435461828	5515	3	1C
0005432535757	5515	4	1H
0005435720818	5515	5	1G
0005434264683	5515	6	2B
0005434264744	5515	7	2G
0005435765795	5515	8	2F
0005434264794	5515	9	2H
0005432140382	5515	10	3C
0005433529249	5515	11	3B
0005432535764	5515	12	3F
0005435765789	5515	13	3H
0005435765771	5515	14	4C
0005435765787	5515	15	4B
0005435765768	5515	16	4F
0005432535765	5515	17	4G
0005432140388	5515	18	4H
0005434831067	5515	19	5B
0005435461909	5515	20	5A
0005435765751	5515	21	5F
0005434831068	5515	22	5C
0005434264756	5515	23	9A
0005435720817	5515	24	5H
0005435765745	5515	25	9G
0005433529251	5515	26	11A
0005432140387	5515	27	9H
0005435765784	5515	28	11B
0005435765776	5515	29	11E
0005435765757	5515	30	11G
0005435461854	5515	31	12B
0005435765769	5515	32	12A
0005434264741	5515	33	12D
0005435765764	5515	34	12H
0005435461983	5515	35	13A
0005435765802	5515	36	13D
0005433529250	5515	37	13B
0005435765743	5515	38	13E
0005435765758	5515	39	13F
0005435765746	5515	40	13H
0005432535762	5515	41	14B
0005435722037	5515	42	14F
0005435461872	5515	43	14E
0005435765761	5515	44	14G
0005435765741	5515	45	15A
0005434264709	5515	46	15D
0005434264752	5515	47	15G
0005432140386	5515	48	16B
0005432535756	5515	49	16E
0005435722038	5515	50	16G
0005432535750	5515	51	16F
0005435725561	5515	52	17A
0005435765798	5515	53	17D
0005435722036	5515	54	17B
0005435735102	5515	55	17E
0005432140390	5515	56	17G
0005435765797	5515	57	17F
0005435461893	5515	58	18A
0005432140384	5515	59	17H
0005433527240	5515	60	18E
0005435765756	5515	61	18F
0005435765807	5515	62	18H
0005432535763	5515	63	19B
0005435723030	5515	64	19E
0005435735103	5515	65	20A
0005435765775	5515	66	19H
0005435765792	5515	67	20D
0005435765777	5515	68	20G
0005434831073	5515	69	21B
0005435461910	5515	70	21A
0005435765772	5515	71	21E
0005433529253	5515	72	21D
0005434831078	5515	73	21H
0005435765780	5515	74	22A
0005435765788	5515	75	22D
0005435765794	5515	76	22B
0005432140385	5515	77	22G
0005435765744	5515	78	22F
0005432140383	5515	79	22H
0005435765796	5515	80	23A
0005435765785	5515	81	23F
0005435461822	5515	82	23G
0005435461926	5515	83	24A
0005435461892	5515	84	23H
0005435461827	5515	85	24B
0005434264746	5515	86	24E
0005435461895	5515	87	24H
0005435765804	5515	88	24G
0005435461808	5515	89	25E
0005434264793	5515	90	27A
0005435765793	5515	91	25F
0005435461896	5515	92	27B
0005435461815	5515	93	27D
0005435735101	5515	94	27E
0005435735104	5515	95	27H
0005435725559	5515	96	28A
0005435765799	5515	97	28B
0005435461807	5515	98	28E
0005435765750	5515	99	28D
0005435765782	5515	100	28H
0005434264728	5515	101	28G
0005435765742	5515	102	29B
0005435765753	5515	103	29G
0005434264684	5515	104	29F
0005432140389	5515	105	30B
0005435765801	5515	106	30A
0005433527241	5515	107	30F
0005435765749	5515	108	30E
0005435765805	5515	109	30G
0005435765770	5515	110	31A
0005434264708	5515	111	30H
0005434264749	5515	112	31B
0005435765806	5515	113	31E
0005435735100	5515	114	31D
0005435765803	5515	115	31H
0005435461816	5515	116	32D
0005435765755	5515	117	32B
0005433527239	5515	118	32E
0005435765748	5515	119	32H
0005435461925	5515	120	32G
0005435765783	5515	121	33A
0005435765763	5515	122	33D
0005435461819	5515	123	33F
0005435765791	5515	124	33H
0005435765786	5515	125	33G
0005434264751	5515	126	34A
0005435765790	5515	127	34F
0005435765760	5515	128	34E
0005435765800	5515	129	34G
0005435765766	5515	130	34H
0005435765774	5515	131	35D
0005435765747	5515	132	35B
0005435725560	5515	133	35F
0005435765781	5515	134	35E
0005435461871	5515	135	35H
0005435461850	5515	136	35G
0005435461820	5515	137	36A
0005435461891	5515	138	36D
0005433529252	5515	139	36H
0005435765762	5515	140	37B
0005435765767	5515	141	37E
0005435765759	5515	142	37D
0005435725558	5515	143	37F
0005435765779	5515	144	37G
0005435765773	5515	145	38D
0005435725557	5515	146	38B
0005435461849	5515	147	38E
0005435765754	5515	148	38F
0005432535749	5515	149	38G
0005435765778	5515	150	39E
0005435765752	5515	151	39D
0005435461984	5515	152	39F
0005435765178	13485	1	1B
0005435765131	13485	2	1A
0005435725524	13485	3	1F
0005435462165	13485	4	1G
0005435765287	13485	5	2C
0005432535796	13485	6	2B
0005432535801	13485	7	2H
0005435765251	13485	8	2G
0005435725534	13485	9	3A
0005435462166	13485	10	3B
0005435765222	13485	11	3C
0005432535799	13485	12	3G
0005435462147	13485	13	3F
0005434264948	13485	14	4A
0005435462164	13485	15	4F
0005435765343	13485	16	4C
0005435462159	13485	17	4G
0005434264946	13485	18	5A
0005435765185	13485	19	5B
0005432194481	13485	20	5F
0005434264942	13485	21	5H
0005435462180	13485	22	5G
0005435462174	13485	23	9A
0005435462150	13485	24	9G
0005435462149	13485	25	9B
0005435765283	13485	26	9H
0005432194480	13485	27	11A
0005435462157	13485	28	11D
0005432535797	13485	29	11F
0005435462163	13485	30	12B
0005432535798	13485	31	12E
0005435462177	13485	32	12G
0005432194479	13485	33	12F
0005435765405	13485	34	13A
0005435765180	13485	35	13B
0005432535800	13485	36	14A
0005435725523	13485	37	13H
0005435765395	13485	38	14F
0005435765184	13485	39	14E
0005435765366	13485	40	14G
0005435765129	13485	41	15B
0005435462158	13485	42	15E
0005435765133	13485	43	15G
0005434264955	13485	44	16A
0005435462156	13485	45	16F
0005434264961	13485	46	16H
0005435765284	13485	47	17B
0005435462169	13485	48	17A
0005434831115	13485	49	17D
0005435462168	13485	50	17F
0005434264963	13485	51	17H
0005435765301	13485	52	18B
0005434264947	13485	53	18D
0005435765223	13485	54	18F
0005435765394	13485	55	18G
0005435725531	13485	56	19D
0005434264960	13485	57	19B
0005434831120	13485	58	19E
0005435765118	13485	59	19G
0005435765484	13485	60	19H
0005434264964	13485	61	20D
0005435765295	13485	62	20F
0005434264962	13485	63	20G
0005435462152	13485	64	21A
0005435462143	13485	65	21D
0005435765244	13485	66	21B
0005434264957	13485	67	21E
0005435462153	13485	68	21G
0005435462175	13485	69	22A
0005435765491	13485	70	22D
0005435765286	13485	71	22B
0005435765547	13485	72	22E
0005434264956	13485	73	22G
0005435462155	13485	74	22F
0005435462161	13485	75	23A
0005434831118	13485	76	23G
0005435765139	13485	77	24E
0005434264953	13485	78	24D
0005435765365	13485	79	24H
0005435462167	13485	80	27A
0005435765224	13485	81	25F
0005435725530	13485	82	27E
0005435765229	13485	83	27F
0005434264943	13485	84	27G
0005434264951	13485	85	28B
0005435765265	13485	86	28E
0005434831119	13485	87	29A
0005435765546	13485	88	29E
0005435043277	13485	89	29D
0005435723010	13485	90	29F
0005435462179	13485	91	30A
0005435765105	13485	92	30D
0005434264958	13485	93	30B
0005435725516	13485	94	30F
0005434264950	13485	95	30E
0005435462178	13485	96	30G
0005434264954	13485	97	31A
0005435462146	13485	98	30H
0005435462148	13485	99	31B
0005435765179	13485	100	31D
0005435765293	13485	101	31F
0005434264952	13485	102	31E
0005435765545	13485	103	31H
0005435765210	13485	104	32A
0005435765130	13485	105	32D
0005435462172	13485	106	32G
0005435462176	13485	107	32F
0005435462151	13485	108	32H
0005435462173	13485	109	33A
0005435765106	13485	110	33D
0005434264949	13485	111	33B
0005435765404	13485	112	33E
0005435462160	13485	113	33H
0005435462144	13485	114	34A
0005435462162	13485	115	34D
0005435462171	13485	116	34H
0005434831116	13485	117	35B
0005434264944	13485	118	35D
0005434831117	13485	119	35G
0005435462145	13485	120	36A
0005434264945	13485	121	36D
0005434264959	13485	122	36F
0005435725515	13485	123	36E
0005435735060	13485	124	36H
0005435462154	13485	125	37A
0005435765302	13485	126	37E
0005435765159	13485	127	37D
0005435765107	13485	128	37F
0005435765611	13485	129	37H
0005435765209	13485	130	37G
0005435765294	13485	131	38B
0005434264965	13485	132	39D
0005434264941	13485	133	38H
0005435462170	13485	134	39E
0005434514946	18654	1	1B
0005434513557	18654	2	2A
0005434513560	18654	3	2B
0005434514947	18654	4	4A
0005434514945	18654	5	4B
0005434513559	18654	6	6A
0005434513558	18654	7	6B
0005434514926	19200	1	1A
0005434602877	19200	2	2A
0005434602878	19200	3	1B
0005434514934	19200	4	2B
0005434602879	19200	5	3A
0005434514935	19200	6	3B
0005434602876	19200	7	5A
0005434602875	19200	8	5B
0005433007908	1847	1	1C
0005433007880	1847	2	1F
0005433007960	1847	3	2A
0005433008034	1847	4	2D
0005433284803	1847	5	3A
0005433007947	1847	6	3C
0005433007843	1847	7	3F
0005433007951	1847	8	4A
0005432295859	1847	9	4F
0005433007915	1847	10	5A
0005433008044	1847	11	5C
0005433007934	1847	12	5D
0005433284910	1847	13	5E
0005433007948	1847	14	5F
0005433007983	1847	15	6A
0005433007992	1847	16	6C
0005433007894	1847	17	6D
0005432295860	1847	18	6E
0005433007904	1847	19	6F
0005433007884	1847	20	7A
0005433284900	1847	21	7D
0005433007883	1847	22	7E
0005433284837	1847	23	7F
0005433284814	1847	24	8A
0005433007833	1847	25	8E
0005433007933	1847	26	8F
0005433008094	1847	27	9C
0005433284799	1847	28	9A
0005433007952	1847	29	9D
0005433284804	1847	30	9E
0005433007871	1847	31	9F
0005433008029	1847	32	10A
0005433284934	1847	33	10D
0005433284776	1847	34	10E
0005433284883	1847	35	10F
0005433007949	1847	36	11D
0005433007997	1847	37	11E
0005433007916	1847	38	12C
0005433007967	1847	39	12E
0005432295861	1847	40	12F
0005433284813	1847	41	13A
0005433284896	1847	42	13D
0005433007982	1847	43	13E
0005433007888	1847	44	13F
0005433008095	1847	45	14A
0005433284917	1847	46	14C
0005433007981	1847	47	14D
0005433007897	1847	48	14E
0005433007824	1847	49	14F
0005433284849	1847	50	15A
0005433007838	1847	51	15D
0005433007905	1847	52	15E
0005433284853	1847	53	15F
0005433284800	1847	54	16A
0005433284784	1847	55	16C
0005433284854	1847	56	17A
0005433284843	1847	57	17C
0005433284901	1847	58	17F
0005433008077	1847	59	18A
0005433007932	1847	60	18C
0005433007898	1847	61	18D
0005433284844	1847	62	18F
0005433284812	1847	63	19A
0005433007850	1847	64	19D
0005433007946	1847	65	19E
0005433007964	1847	66	19F
0005433284983	1847	67	20A
0005433007835	1847	68	20C
0005433007837	1847	69	20D
0005433007858	1847	70	20F
0005433008266	22602	1	1A
0005433008250	22602	2	1D
0005433285046	22602	3	2A
0005433285067	22602	4	2C
0005433008278	22602	5	2D
0005433008281	22602	6	3C
0005433285056	22602	7	3D
0005433285045	22602	8	3F
0005433008284	22602	9	4C
0005433285049	22602	10	4D
0005433285070	22602	11	4E
0005433008245	22602	12	4F
0005433008262	22602	13	5E
0005433285042	22602	14	5F
0005433008279	22602	15	6A
0005433285040	22602	16	6C
0005433008242	22602	17	6E
0005433285061	22602	18	6F
0005433008283	22602	19	7A
0005433285065	22602	20	7C
0005433008277	22602	21	7D
0005433285039	22602	22	7E
0005433285062	22602	23	7F
0005433285064	22602	24	8A
0005433008275	22602	25	8C
0005433008270	22602	26	8E
0005433285069	22602	27	8F
0005433008285	22602	28	9C
0005433285044	22602	29	9D
0005433008282	22602	30	9E
0005433285047	22602	31	9F
0005433285054	22602	32	10C
0005433285048	22602	33	10D
0005433285057	22602	34	10E
0005433285055	22602	35	11A
0005433008248	22602	36	11C
0005433008252	22602	37	11D
0005433008280	22602	38	11F
0005433008257	22602	39	12A
0005433008247	22602	40	12C
0005433285068	22602	41	12D
0005433285052	22602	42	12E
0005433285053	22602	43	12F
0005433285066	22602	44	13A
0005433008243	22602	45	13C
0005433285043	22602	46	13D
0005433008265	22602	47	13F
0005433285063	22602	48	14A
0005433008240	22602	49	14C
0005433285060	22602	50	14F
0005433008263	22602	51	15A
0005433008255	22602	52	15C
0005433008271	22602	53	15D
0005433285058	22602	54	15E
0005433008267	22602	55	15F
0005433285050	22602	56	16A
0005433008272	22602	57	16C
0005433008256	22602	58	16D
0005433008246	22602	59	16E
0005433008268	22602	60	16F
0005433008273	22602	61	17A
0005433285059	22602	62	17C
0005433008269	22602	63	17D
0005433008258	22602	64	17E
0005433008274	22602	65	17F
0005433008260	22602	66	18A
0005433008264	22602	67	18C
0005433008251	22602	68	18D
0005433008249	22602	69	18E
0005433008261	22602	70	18F
0005433285041	22602	71	19A
0005433008244	22602	72	19D
0005433008259	22602	73	19E
0005433285051	22602	74	19F
0005433008276	22602	75	20C
0005433008254	22602	76	20D
0005433008253	22602	77	20E
0005433008241	22602	78	20F
0005432756811	25336	1	1A
0005432756817	25336	2	1C
0005434152755	25336	3	5D
0005432755042	25336	4	5E
0005432755048	25336	5	6A
0005432755043	25336	6	6D
0005432756816	25336	7	7F
0005432755041	25336	8	9E
0005432756815	25336	9	10D
0005432756813	25336	10	10F
0005432755044	25336	11	12A
0005432756818	25336	12	13A
0005432755046	25336	13	14A
0005432756814	25336	14	14D
0005432756820	25336	15	15A
0005432755040	25336	16	15D
0005432756812	25336	17	15E
0005432755045	25336	18	16C
0005432755047	25336	19	17C
0005432755039	25336	20	17E
0005432756819	25336	21	20E
0005433846288	5591	1	1A
0005433846290	5591	2	1F
0005433846267	5591	3	1D
0005433846301	5591	4	2C
0005433846279	5591	5	2A
0005433846299	5591	6	2D
0005433815348	5591	7	3A
0005433846266	5591	8	2F
0005435282218	5591	9	3C
0005435282193	5591	10	4A
0005433846281	5591	11	3F
0005435282170	5591	12	4C
0005433846271	5591	13	4F
0005433846283	5591	14	4D
0005435282118	5591	15	5C
0005433846289	5591	16	5A
0005435282127	5591	17	5D
0005432081464	5591	18	6B
0005435282171	5591	19	5F
0005435282051	5591	20	6C
0005432081460	5591	21	6E
0005433846285	5591	22	6D
0005433846318	5591	23	7A
0005433846278	5591	24	6F
0005435282088	5591	25	7C
0005433846315	5591	26	7B
0005435282101	5591	27	7E
0005433846277	5591	28	7D
0005435282078	5591	29	8A
0005433846313	5591	30	7F
0005433846297	5591	31	8B
0005433846274	5591	32	8D
0005433846312	5591	33	8C
0005433846319	5591	34	8E
0005433846308	5591	35	9B
0005435282154	5591	36	9A
0005433815350	5591	37	9D
0005435282216	5591	38	9C
0005432081463	5591	39	9F
0005435282067	5591	40	9E
0005433846314	5591	41	10A
0005435282083	5591	42	10C
0005435282215	5591	43	10B
0005433846264	5591	44	10D
0005433846292	5591	45	11A
0005433815347	5591	46	10F
0005433846294	5591	47	11B
0005435282068	5591	48	11D
0005433846262	5591	49	11F
0005433846302	5591	50	11E
0005433846272	5591	51	12A
0005433846303	5591	52	12C
0005433846306	5591	53	12E
0005434173451	5591	54	12D
0005433846300	5591	55	13A
0005435282072	5591	56	13C
0005433846284	5591	57	13B
0005433846309	5591	58	13E
0005433846320	5591	59	14A
0005433846268	5591	60	13F
0005433846287	5591	61	14C
0005435282140	5591	62	14B
0005433846295	5591	63	14D
0005433815346	5591	64	14F
0005433846263	5591	65	14E
0005433846317	5591	66	15A
0005433846291	5591	67	15D
0005432081465	5591	68	15C
0005435282087	5591	69	15B
0005433846305	5591	70	16A
0005435282053	5591	71	15F
0005433815345	5591	72	16B
0005433846307	5591	73	16E
0005433846298	5591	74	16D
0005435282217	5591	75	16C
0005433846273	5591	76	17A
0005433846269	5591	77	16F
0005433846275	5591	78	17B
0005433846304	5591	79	17D
0005433815349	5591	80	17C
0005435282054	5591	81	17F
0005435282141	5591	82	18A
0005433846311	5591	83	18C
0005435282172	5591	84	18E
0005433846286	5591	85	18D
0005435282132	5591	86	19A
0005433846265	5591	87	18F
0005435282138	5591	88	19C
0005435282241	5591	89	19D
0005433846276	5591	90	19F
0005433846282	5591	91	20B
0005433846310	5591	92	20A
0005433846316	5591	93	20C
0005432081462	5591	94	20E
0005435282102	5591	95	21A
0005433846296	5591	96	21C
0005433846293	5591	97	21B
0005432081461	5591	98	21E
0005433846280	5591	99	21D
0005433846270	5591	100	21F
0005433845694	13853	1	1A
0005433845680	13853	2	1C
0005433845930	13853	3	2C
0005433845782	13853	4	1F
0005434173491	13853	5	2F
0005433845696	13853	6	2D
0005433845828	13853	7	3D
0005433815315	13853	8	3C
0005433845809	13853	9	4A
0005433815305	13853	10	3F
0005433845715	13853	11	5F
0005433845958	13853	12	6A
0005433845785	13853	13	6C
0005433845944	13853	14	6E
0005435282311	13853	15	6D
0005433845740	13853	16	7A
0005433845822	13853	17	7C
0005435282320	13853	18	7B
0005435282332	13853	19	8A
0005433845719	13853	20	7F
0005435282312	13853	21	8B
0005433845736	13853	22	8D
0005433845697	13853	23	8F
0005435282330	13853	24	8E
0005435282324	13853	25	9A
0005433846063	13853	26	9C
0005435282321	13853	27	9E
0005433815309	13853	28	10A
0005433845960	13853	29	10C
0005435282310	13853	30	10B
0005435282335	13853	31	10E
0005433845938	13853	32	10D
0005435282313	13853	33	11B
0005435282325	13853	34	11A
0005435282319	13853	35	11C
0005433846080	13853	36	11E
0005433845861	13853	37	12A
0005433845800	13853	38	12D
0005433846151	13853	39	12C
0005433845927	13853	40	12E
0005432003678	13853	41	13A
0005434173492	13853	42	13C
0005433815304	13853	43	13B
0005433845873	13853	44	13E
0005433845681	13853	45	13D
0005434173489	13853	46	14A
0005433845723	13853	47	13F
0005435282328	13853	48	14C
0005433845957	13853	49	14B
0005435282333	13853	50	14E
0005433845823	13853	51	14D
0005433845756	13853	52	14F
0005435282318	13853	53	15B
0005435282334	13853	54	15A
0005432003679	13853	55	15C
0005433845837	13853	56	15E
0005432003677	13853	57	16A
0005435282338	13853	58	16B
0005435282329	13853	59	16E
0005433845852	13853	60	16F
0005435282315	13853	61	17C
0005433845679	13853	62	17B
0005434173490	13853	63	17A
0005435282323	13853	64	17D
0005435282327	13853	65	17F
0005435282337	13853	66	17E
0005433845741	13853	67	18B
0005433845928	13853	68	18A
0005433845820	13853	69	18D
0005433846008	13853	70	18C
0005433815316	13853	71	18F
0005435282317	13853	72	19C
0005433845743	13853	73	19B
0005433845695	13853	74	19D
0005435282326	13853	75	20A
0005435282336	13853	76	19F
0005435282314	13853	77	20D
0005433845836	13853	78	20C
0005435282331	13853	79	20E
0005433845737	13853	80	21B
0005433845959	13853	81	21A
0005435282316	13853	82	20F
0005433846135	13853	83	21C
0005435282322	13853	84	21E
0005433845727	13853	85	21D
0005434620444	7851	1	1B
0005434620440	7851	2	2A
0005432112498	7851	3	3B
0005434620442	7851	4	3D
0005435332168	7851	5	4A
0005434620446	7851	6	4B
0005434620445	7851	7	4C
0005435332182	7851	8	4D
0005434620438	7851	9	5A
0005435332164	7851	10	5B
0005432112499	7851	11	5C
0005434620448	7851	12	5D
0005434620441	7851	13	6A
0005434620447	7851	14	7D
0005434620439	7851	15	18B
0005434620451	7851	16	18C
0005434620449	7851	17	18D
0005434620434	7851	18	19D
0005434620436	7851	19	20A
0005434620452	7851	20	20D
0005434620433	7851	21	21A
0005434620437	7851	22	21D
0005435332165	7851	23	22B
0005434620450	7851	24	22C
0005434620443	7851	25	22D
0005434620435	7851	26	23A
0005435332200	7851	27	23B
0005434620242	32990	1	1A
0005435332258	32990	2	1B
0005434620254	32990	3	1C
0005434620347	32990	4	2A
0005434620299	32990	5	2B
0005434620256	32990	6	2D
0005434620231	32990	7	3A
0005434620302	32990	8	3B
0005434620300	32990	9	3C
0005434620257	32990	10	3D
0005435332259	32990	11	4A
0005434620250	32990	12	4C
0005434620263	32990	13	4D
0005435332263	32990	14	5A
0005434620236	32990	15	5C
0005434620346	32990	16	5D
0005435332254	32990	17	6B
0005435332255	32990	18	6D
0005435332261	32990	19	7A
0005434620312	32990	20	7C
0005434620265	32990	21	18A
0005434620295	32990	22	18C
0005434620310	32990	23	19A
0005435332262	32990	24	19B
0005434620304	32990	25	20A
0005435332256	32990	26	20B
0005434620301	32990	27	20C
0005434620311	32990	28	20D
0005434620303	32990	29	21A
0005435332260	32990	30	21C
0005435332257	32990	31	22A
0005434993954	4261	1	1A
0005435787338	4261	2	1C
0005434993953	4261	3	2A
0005432190601	4261	4	2C
0005434993948	4261	5	2D
0005435785082	4261	6	3F
0005435785105	4261	7	4A
0005432190602	4261	8	4C
0005432190599	4261	9	4E
0005435785091	4261	10	5A
0005435785099	4261	11	5C
0005435785092	4261	12	5D
0005434993951	4261	13	5F
0005435785111	4261	14	7A
0005434993952	4261	15	6F
0005435785085	4261	16	7E
0005435787340	4261	17	7F
0005435785086	4261	18	8A
0005435785083	4261	19	8C
0005435785108	4261	20	9C
0005435785089	4261	21	9D
0005435785112	4261	22	9E
0005435785110	4261	23	10D
0005435787339	4261	24	10F
0005435785095	4261	25	11A
0005435785081	4261	26	11F
0005435785087	4261	27	12A
0005435785093	4261	28	12C
0005435785106	4261	29	12E
0005435785109	4261	30	12F
0005435785115	4261	31	13E
0005434993950	4261	32	14C
0005435785102	4261	33	14E
0005435785090	4261	34	14F
0005435785084	4261	35	15A
0005434993949	4261	36	15C
0005434993947	4261	37	15D
0005435785097	4261	38	16A
0005435785100	4261	39	16C
0005435785114	4261	40	16D
0005435785094	4261	41	16E
0005435785107	4261	42	17A
0005432190600	4261	43	17E
0005435785113	4261	44	18D
0005435785103	4261	45	18E
0005434993946	4261	46	18F
0005435785098	4261	47	19C
0005435785104	4261	48	19E
0005435785088	4261	49	20C
0005435785096	4261	50	20E
0005435785101	4261	51	20F
0005435784756	27316	1	1C
0005435787321	27316	2	2C
0005435784798	27316	3	2F
0005434993850	27316	4	3A
0005435784877	27316	5	3F
0005435784874	27316	6	4C
0005435918619	27316	7	4D
0005434993849	27316	8	4E
0005435784799	27316	9	5A
0005435784737	27316	10	6F
0005434993862	27316	11	7A
0005435784757	27316	12	7F
0005435784736	27316	13	8E
0005434993855	27316	14	9A
0005435918618	27316	15	9C
0005435937346	27316	16	9D
0005435918617	27316	17	9F
0005435784856	27316	18	10A
0005435787322	27316	19	10C
0005434993866	27316	20	10E
0005435784902	27316	21	10F
0005432195676	27316	22	11D
0005434993865	27316	23	12A
0005435784885	27316	24	12D
0005434993863	27316	25	12E
0005435937345	27316	26	12F
0005435918620	27316	27	13A
0005434993875	27316	28	13D
0005434993874	27316	29	14A
0005434993858	27316	30	14D
0005435784758	27316	31	14E
0005434993881	27316	32	15C
0005434993848	27316	33	15E
0005435937344	27316	34	16C
0005435784797	27316	35	16D
0005432195677	27316	36	16F
0005435784759	27316	37	17D
0005435787323	27316	38	17E
0005435937347	27316	39	18D
0005435918621	27316	40	19D
0005435937348	27316	41	19E
0005432146183	19862	1	2A
0005432146182	19862	2	2D
0005434081728	4714	1	1B
0005432567188	4714	2	1C
0005432459474	4714	3	1G
0005432567198	4714	4	2A
0005432459462	4714	5	1H
0005432567174	4714	6	2F
0005432459487	4714	7	2H
0005432459468	4714	8	3A
0005433452723	4714	9	3B
0005432567193	4714	10	3F
0005432567156	4714	11	3G
0005434081742	4714	12	4A
0005432459445	4714	13	3H
0005432567197	4714	14	4B
0005434081736	4714	15	4F
0005432567203	4714	16	4C
0005432459438	4714	17	4H
0005432567157	4714	18	5B
0005432567158	4714	19	5A
0005432567154	4714	20	5C
0005432459440	4714	21	5F
0005432459444	4714	22	5H
0005434559088	4714	23	9B
0005432567191	4714	24	9G
0005432459453	4714	25	9H
0005432567175	4714	26	11B
0005432567179	4714	27	11E
0005434559089	4714	28	11F
0005432567202	4714	29	11H
0005432170340	4714	30	11G
0005432567173	4714	31	12B
0005432170336	4714	32	12G
0005434081745	4714	33	12F
0005434081737	4714	34	12H
0005432459447	4714	35	13A
0005432567155	4714	36	13D
0005432186841	4714	37	13F
0005432459459	4714	38	13G
0005432567172	4714	39	14B
0005432459483	4714	40	14A
0005434081732	4714	41	14D
0005432567207	4714	42	14H
0005432459437	4714	43	15D
0005433726086	4714	44	15B
0005432459489	4714	45	15A
0005433726087	4714	46	15E
0005432567168	4714	47	15F
0005432459470	4714	48	15H
0005432567170	4714	49	16D
0005432567159	4714	50	16F
0005432567210	4714	51	16H
0005434081739	4714	52	17A
0005432170337	4714	53	17E
0005432567176	4714	54	17F
0005432186842	4714	55	18A
0005432567161	4714	56	18F
0005432459439	4714	57	19A
0005432567211	4714	58	19B
0005432459467	4714	59	19E
0005432459475	4714	60	19F
0005434081740	4714	61	19G
0005432567187	4714	62	20B
0005432567164	4714	63	20E
0005432567212	4714	64	20D
0005434081744	4714	65	20H
0005432459469	4714	66	20G
0005432459446	4714	67	21A
0005432567200	4714	68	21D
0005434081735	4714	69	21B
0005432567201	4714	70	21E
0005432186845	4714	71	21F
0005433452724	4714	72	22B
0005432459477	4714	73	22D
0005432459443	4714	74	22E
0005432567181	4714	75	22G
0005432567206	4714	76	22F
0005432459458	4714	77	22H
0005432567185	4714	78	23B
0005432567186	4714	79	23D
0005434081741	4714	80	23F
0005432459452	4714	81	23E
0005432567195	4714	82	23G
0005432567183	4714	83	24A
0005432459482	4714	84	24E
0005432459488	4714	85	24D
0005434081747	4714	86	24F
0005434081729	4714	87	24H
0005432170338	4714	88	24G
0005432567184	4714	89	25D
0005432459465	4714	90	25F
0005432459451	4714	91	25E
0005432459449	4714	92	27B
0005432459454	4714	93	27F
0005432459441	4714	94	27E
0005432567160	4714	95	27H
0005432459479	4714	96	28A
0005433451604	4714	97	28B
0005432567169	4714	98	28D
0005432567162	4714	99	28F
0005432459450	4714	100	28H
0005432567192	4714	101	29A
0005432567199	4714	102	29D
0005432459485	4714	103	29B
0005432567194	4714	104	29E
0005432459442	4714	105	29F
0005432459448	4714	106	29H
0005432567171	4714	107	30B
0005432567180	4714	108	30E
0005432459486	4714	109	30F
0005432567153	4714	110	31A
0005432567205	4714	111	30H
0005432459472	4714	112	31B
0005432567204	4714	113	31E
0005432567213	4714	114	31F
0005432567178	4714	115	31G
0005432459466	4714	116	32A
0005432459456	4714	117	31H
0005432459455	4714	118	32B
0005434081748	4714	119	32E
0005434081730	4714	120	32D
0005432459476	4714	121	32F
0005432459481	4714	122	33A
0005432567190	4714	123	32H
0005432571292	4714	124	33D
0005432567182	4714	125	33B
0005432567208	4714	126	33G
0005432571293	4714	127	33H
0005434081731	4714	128	34A
0005432170339	4714	129	34D
0005432459478	4714	130	34F
0005434081743	4714	131	34E
0005434081734	4714	132	34H
0005432459463	4714	133	34G
0005432170335	4714	134	35B
0005432459473	4714	135	35A
0005432567189	4714	136	35E
0005434081738	4714	137	35F
0005432459457	4714	138	35G
0005432567177	4714	139	36A
0005432567166	4714	140	35H
0005432186844	4714	141	36D
0005432567196	4714	142	36F
0005432459460	4714	143	36E
0005432567209	4714	144	36G
0005434081746	4714	145	37D
0005433451605	4714	146	37B
0005434081733	4714	147	37G
0005432459464	4714	148	37E
0005433726088	4714	149	38A
0005432567165	4714	150	37H
0005432571294	4714	151	38D
0005432459480	4714	152	38B
0005432459461	4714	153	38E
0005432186843	4714	154	38G
0005432567167	4714	155	38F
0005432459484	4714	156	38H
0005432459471	4714	157	39E
0005432567163	4714	158	39F
0005432566679	30561	1	1A
0005432213578	30561	2	1B
0005432566633	30561	3	1C
0005432566600	30561	4	1G
0005432566632	30561	5	2C
0005434081616	30561	6	2B
0005432566824	30561	7	3A
0005432566581	30561	8	3B
0005432567020	30561	9	3F
0005432566751	30561	10	3C
0005432161135	30561	11	3H
0005432458970	30561	12	4C
0005432566775	30561	13	4G
0005432566855	30561	14	4F
0005432459286	30561	15	5A
0005432566778	30561	16	5F
0005432566697	30561	17	5B
0005432459280	30561	18	5G
0005432566852	30561	19	5H
0005432566749	30561	20	9G
0005434081575	30561	21	9H
0005432459020	30561	22	11B
0005434081574	30561	23	11D
0005432566870	30561	24	11F
0005432566526	30561	25	11H
0005432566741	30561	26	12A
0005432566862	30561	27	12E
0005432566850	30561	28	12D
0005432571274	30561	29	12H
0005432459066	30561	30	12G
0005432566750	30561	31	13A
0005432566905	30561	32	13D
0005432566935	30561	33	13E
0005432459133	30561	34	13G
0005432566890	30561	35	13F
0005432459276	30561	36	13H
0005434081570	30561	37	14B
0005432566912	30561	38	14A
0005432566708	30561	39	14D
0005432459033	30561	40	14F
0005432459051	30561	41	14G
0005432459211	30561	42	15A
0005432566828	30561	43	15B
0005432566752	30561	44	15D
0005432213577	30561	45	15F
0005432566931	30561	46	15G
0005432566836	30561	47	16A
0005432566747	30561	48	15H
0005432566626	30561	49	16D
0005432459057	30561	50	16B
0005432459201	30561	51	16E
0005432459021	30561	52	16F
0005433452706	30561	53	16H
0005432459009	30561	54	16G
0005432213579	30561	55	17A
0005432459024	30561	56	17D
0005432566780	30561	57	17G
0005432566572	30561	58	18A
0005432566887	30561	59	17H
0005432566693	30561	60	18E
0005432458969	30561	61	18D
0005432566888	30561	62	18G
0005432566830	30561	63	18F
0005432566685	30561	64	18H
0005432459040	30561	65	19B
0005432566777	30561	66	19E
0005434081540	30561	67	19D
0005432566742	30561	68	19F
0005432459182	30561	69	19G
0005432566829	30561	70	19H
0005432458964	30561	71	20D
0005432459118	30561	72	20B
0005432566704	30561	73	20F
0005432566695	30561	74	20E
0005432566825	30561	75	20G
0005432566815	30561	76	20H
0005432161134	30561	77	21B
0005432566869	30561	78	21F
0005432566739	30561	79	21G
0005434081533	30561	80	22B
0005432459028	30561	81	22A
0005432566540	30561	82	22E
0005432458992	30561	83	22F
0005432566867	30561	84	23A
0005432566680	30561	85	23D
0005432459120	30561	86	23F
0005432459056	30561	87	23G
0005432458972	30561	88	24A
0005432566720	30561	89	23H
0005432459052	30561	90	24D
0005432566837	30561	91	24E
0005432566788	30561	92	24G
0005432567019	30561	93	25D
0005432459022	30561	94	24H
0005432566706	30561	95	25E
0005432566740	30561	96	27B
0005432566525	30561	97	27D
0005432566849	30561	98	27F
0005432459039	30561	99	27E
0005432571273	30561	100	27G
0005432459142	30561	101	27H
0005434081476	30561	102	28D
0005434081525	30561	103	28B
0005432459030	30561	104	28F
0005434081542	30561	105	28G
0005434081571	30561	106	29B
0005432458971	30561	107	29E
0005432571266	30561	108	29H
0005432566717	30561	109	30B
0005432566585	30561	110	30A
0005432459032	30561	111	30H
0005432459067	30561	112	30G
0005432459019	30561	113	31A
0005434081572	30561	114	31B
0005432459285	30561	115	31D
0005432566776	30561	116	31F
0005432566748	30561	117	31G
0005433454845	30561	118	31H
0005432459112	30561	119	32E
0005434081554	30561	120	32H
0005432566831	30561	121	33D
0005432566718	30561	122	33B
0005432566694	30561	123	33E
0005432459181	30561	124	33G
0005432459139	30561	125	33F
0005434081569	30561	126	33H
0005432566535	30561	127	34A
0005432566634	30561	128	34D
0005432566801	30561	129	34B
0005432459029	30561	130	34E
0005433454846	30561	131	34G
0005432566707	30561	132	34F
0005432459212	30561	133	34H
0005432566731	30561	134	35B
0005432566534	30561	135	35D
0005432566584	30561	136	35E
0005432566599	30561	137	35G
0005432566936	30561	138	36B
0005432566835	30561	139	36F
0005432566678	30561	140	36G
0005432566823	30561	141	37A
0005432458999	30561	142	37D
0005432566541	30561	143	37E
0005432566745	30561	144	37F
0005432566746	30561	145	37H
0005432566802	30561	146	37G
0005434081524	30561	147	38A
0005432566889	30561	148	38B
0005432566868	30561	149	38F
0005433454851	30561	150	38E
0005434081534	30561	151	38D
0005432459068	30561	152	38G
0005434081615	30561	153	39E
0005432459075	30561	154	39F
0005435722037	13624	1	2B
0005435722038	13624	2	4B
0005435720818	13624	3	5A
0005435722036	13624	4	6A
0005435720817	13624	5	6B
0005435720119	21217	1	2A
0005435720118	21217	2	2B
0005432295861	22761	1	3D
0005432295859	22761	2	20B
0005432295860	22761	3	23B
0005433342452	11104	1	1A
0005433342453	11104	2	1C
0005433342443	11104	3	1D
0005433342486	11104	4	2A
0005433342402	11104	5	1F
0005433342404	11104	6	2D
0005433342466	11104	7	2F
0005433342437	11104	8	3C
0005433342442	11104	9	3A
0005435380227	11104	10	3D
0005433342398	11104	11	3F
0005433342438	11104	12	4A
0005433342468	11104	13	4C
0005435097134	11104	14	4B
0005433342456	11104	15	4D
0005435097139	11104	16	4F
0005433342416	11104	17	4E
0005433342423	11104	18	5A
0005433342479	11104	19	5C
0005433342405	11104	20	5B
0005433342487	11104	21	5D
0005433342424	11104	22	5F
0005433342395	11104	23	5E
0005433342429	11104	24	6A
0005433342467	11104	25	6C
0005433342433	11104	26	6B
0005433342436	11104	27	6D
0005435508168	11104	28	6E
0005433342427	11104	29	7A
0005435097131	11104	30	6F
0005433342474	11104	31	7B
0005433342417	11104	32	7C
0005435508169	11104	33	7E
0005433342488	11104	34	7D
0005433342459	11104	35	8A
0005433342410	11104	36	7F
0005435380246	11104	37	8B
0005433342495	11104	38	8C
0005433342478	11104	39	8D
0005433342460	11104	40	8F
0005433342471	11104	41	8E
0005433342477	11104	42	9A
0005433342497	11104	43	9B
0005433342414	11104	44	9D
0005433342421	11104	45	9C
0005433342426	11104	46	9E
0005433342454	11104	47	9F
0005433342400	11104	48	10B
0005433342418	11104	49	10E
0005433342425	11104	50	10D
0005433342461	11104	51	11A
0005433342430	11104	52	11B
0005433342439	11104	53	11D
0005433342490	11104	54	11C
0005435508181	11104	55	11E
0005433342483	11104	56	12A
0005433342464	11104	57	12C
0005433342451	11104	58	12B
0005433342492	11104	59	12D
0005433342419	11104	60	12E
0005435097137	11104	61	12F
0005433342449	11104	62	13B
0005433342447	11104	63	13A
0005433342485	11104	64	13D
0005435097135	11104	65	13E
0005433342480	11104	66	14A
0005435508182	11104	67	13F
0005433342473	11104	68	14B
0005435097138	11104	69	14D
0005433342431	11104	70	14C
0005433342472	11104	71	14E
0005433342489	11104	72	15A
0005433342448	11104	73	14F
0005433342482	11104	74	15B
0005433342496	11104	75	15C
0005433342445	11104	76	15D
0005433342491	11104	77	15E
0005433342457	11104	78	16A
0005433342401	11104	79	15F
0005433342397	11104	80	16B
0005433342413	11104	81	16C
0005433342458	11104	82	16E
0005433342420	11104	83	16D
0005435380228	11104	84	16F
0005433342407	11104	85	17B
0005433342476	11104	86	17A
0005433342403	11104	87	17C
0005433342494	11104	88	17D
0005433342462	11104	89	17E
0005433342463	11104	90	18A
0005433342406	11104	91	17F
0005433342470	11104	92	18B
0005433342422	11104	93	18D
0005433342428	11104	94	18C
0005433342446	11104	95	18E
0005433342465	11104	96	18F
0005433342481	11104	97	19B
0005433342493	11104	98	19A
0005435508188	11104	99	19C
0005433342396	11104	100	19E
0005433342450	11104	101	19D
0005433342444	11104	102	19F
0005435097136	11104	103	20A
0005433342409	11104	104	20C
0005435097140	11104	105	20B
0005435097132	11104	106	20D
0005435508187	11104	107	20E
0005433342411	11104	108	21A
0005433342408	11104	109	21B
0005433342440	11104	110	21D
0005433342412	11104	111	21C
0005433342475	11104	112	21E
0005433342432	11104	113	21F
0005433342415	11104	114	22A
0005433342435	11104	115	22C
0005433342469	11104	116	22B
0005435380229	11104	117	22D
0005435097133	11104	118	22F
0005433342441	11104	119	22E
0005433342434	11104	120	23A
0005433342399	11104	121	23B
0005435380245	11104	122	23D
0005433342455	11104	123	23C
0005433342484	11104	124	23E
0005435097130	11104	125	23F
0005433341393	17081	1	1A
0005433341397	17081	2	1C
0005433341499	17081	3	1F
0005433341745	17081	4	2A
0005433341526	17081	5	2D
0005433341838	17081	6	2C
0005433341770	17081	7	3A
0005433341837	17081	8	2F
0005433341660	17081	9	3C
0005433341771	17081	10	4A
0005433341705	17081	11	4E
0005432293189	17081	12	5A
0005433341523	17081	13	4F
0005433341503	17081	14	5C
0005433341418	17081	15	5B
0005433341394	17081	16	5E
0005433341591	17081	17	5F
0005433341645	17081	18	6B
0005433341504	17081	19	6A
0005433341674	17081	20	6C
0005433341392	17081	21	6F
0005433341491	17081	22	6E
0005433341541	17081	23	7A
0005433341875	17081	24	7C
0005433341677	17081	25	7E
0005433341659	17081	26	7F
0005433341732	17081	27	8A
0005433341436	17081	28	8E
0005433341706	17081	29	8D
0005433341521	17081	30	9A
0005433341830	17081	31	8F
0005433341744	17081	32	9B
0005433341463	17081	33	9E
0005433341497	17081	34	10D
0005433341571	17081	35	10C
0005432293190	17081	36	10E
0005433341457	17081	37	11A
0005433341666	17081	38	11B
0005433341388	17081	39	11C
0005433341762	17081	40	11D
0005433341464	17081	41	11F
0005433341681	17081	42	11E
0005433341829	17081	43	12A
0005433341512	17081	44	12B
0005433341839	17081	45	12D
0005433341444	17081	46	12C
0005433341524	17081	47	12E
0005433341398	17081	48	13A
0005433341707	17081	49	13D
0005433341761	17081	50	13C
0005433341936	17081	51	13E
0005433341511	17081	52	13F
0005433341753	17081	53	14A
0005433341438	17081	54	14C
0005433341456	17081	55	14B
0005433341763	17081	56	14D
0005433341483	17081	57	14E
0005433341588	17081	58	15A
0005433341640	17081	59	14F
0005433341522	17081	60	15B
0005433341840	17081	61	15D
0005433341517	17081	62	15E
0005433341516	17081	63	16A
0005433341546	17081	64	16D
0005433341435	17081	65	16E
0005433341610	17081	66	17A
0005433341874	17081	67	16F
0005433341479	17081	68	17B
0005433341795	17081	69	17C
0005433341652	17081	70	17D
0005433341746	17081	71	17E
0005433341718	17081	72	18A
0005433341468	17081	73	18B
0005433341482	17081	74	18F
0005433341419	17081	75	19B
0005433341542	17081	76	19C
0005433341540	17081	77	19E
0005433341547	17081	78	19F
0005433341668	17081	79	20B
0005433341841	17081	80	20A
0005433341437	17081	81	20D
0005433341804	17081	82	20C
0005433341676	17081	83	20E
0005433341420	17081	84	20F
0005433341680	17081	85	21A
0005433341609	17081	86	21C
0005433341498	17081	87	21B
0005433341445	17081	88	21D
0005433341794	17081	89	21E
0005433341769	17081	90	22A
0005433341467	17081	91	21F
0005433341717	17081	92	22B
0005433341543	17081	93	22C
0005433341865	17081	94	23A
0005433341937	17081	95	23F
0005433341644	17081	96	23E
0005433481108	9069	1	2A
0005433507059	9069	2	2D
0005432919503	9069	3	2F
0005433507058	9069	4	3F
0005433507055	9069	5	4E
0005433507061	9069	6	4F
0005433481111	9069	7	5C
0005433507049	9069	8	5D
0005433481112	9069	9	7C
0005433481114	9069	10	7D
0005432919521	9069	11	8A
0005433507056	9069	12	8D
0005433507054	9069	13	9C
0005433507048	9069	14	9D
0005433481110	9069	15	10A
0005433507050	9069	16	10E
0005432919551	9069	17	11C
0005433507052	9069	18	11F
0005433507044	9069	19	13C
0005432919522	9069	20	13D
0005433481109	9069	21	13F
0005433507045	9069	22	14A
0005432919543	9069	23	15A
0005432919547	9069	24	16A
0005433507053	9069	25	16D
0005433507046	9069	26	16F
0005433507047	9069	27	17A
0005433507051	9069	28	17C
0005433507043	9069	29	17F
0005433507057	9069	30	19E
0005433481113	9069	31	19F
0005433507060	9069	32	20A
0005433481107	9069	33	20C
0005432919730	20439	1	1A
0005432919731	20439	2	1C
0005432919720	20439	3	1F
0005433506870	20439	4	2C
0005433481046	20439	5	2D
0005432919725	20439	6	2F
0005432919723	20439	7	3C
0005434158961	20439	8	3A
0005433506901	20439	9	3D
0005433506854	20439	10	5C
0005432919734	20439	11	5D
0005433506959	20439	12	5E
0005433506938	20439	13	6A
0005433506909	20439	14	6F
0005433481040	20439	15	7C
0005433481067	20439	16	7D
0005432919717	20439	17	7E
0005432919736	20439	18	8C
0005433506947	20439	19	8F
0005433481027	20439	20	9D
0005432919718	20439	21	9F
0005434158963	20439	22	10C
0005432919735	20439	23	11C
0005432919724	20439	24	11E
0005433506916	20439	25	11F
0005434158962	20439	26	12C
0005433481084	20439	27	12D
0005432919727	20439	28	13C
0005433506894	20439	29	13D
0005433481074	20439	30	14D
0005432919733	20439	31	14F
0005432919719	20439	32	15C
0005433481028	20439	33	15A
0005432919722	20439	34	15F
0005432919721	20439	35	16A
0005432919729	20439	36	16D
0005433506921	20439	37	16F
0005432919728	20439	38	17E
0005433481075	20439	39	18A
0005432919732	20439	40	18D
0005433506981	20439	41	18E
0005433481068	20439	42	19A
0005433506922	20439	43	19E
0005433506905	20439	44	19F
0005432919737	20439	45	20A
0005432919726	20439	46	20E
0005432394072	10211	1	1A
0005432394070	10211	2	2A
0005432396209	10211	3	1B
0005432396208	10211	4	2B
0005432394069	10211	5	3A
0005435179687	10211	6	4A
0005432396211	10211	7	5A
0005432394071	10211	8	5B
0005435179686	10211	9	6A
0005432396210	10211	10	6B
0005435179390	18343	1	2A
0005435179689	18343	2	3A
0005435125762	11050	1	1A
0005435125692	11050	2	1C
0005434928278	11050	3	1D
0005435556651	11050	4	1F
0005435556649	11050	5	2D
0005435125677	11050	6	3A
0005435625896	11050	7	3C
0005435125689	11050	8	3F
0005435125648	11050	9	4A
0005434928280	11050	10	4C
0005435625885	11050	11	4D
0005434411749	11050	12	4F
0005435625901	11050	13	5A
0005435125712	11050	14	5D
0005435125718	11050	15	6C
0005434411745	11050	16	6D
0005434411746	11050	17	6E
0005435625895	11050	18	6F
0005435125680	11050	19	7A
0005435125690	11050	20	7C
0005435556647	11050	21	7F
0005435125708	11050	22	8A
0005434928279	11050	23	8D
0005434928281	11050	24	9A
0005435125725	11050	25	9D
0005435125707	11050	26	10A
0005435125746	11050	27	10C
0005435625880	11050	28	10E
0005435125647	11050	29	11C
0005435625900	11050	30	11D
0005435556648	11050	31	11F
0005435125678	11050	32	12A
0005435125722	11050	33	12D
0005435125655	11050	34	12E
0005435125693	11050	35	12F
0005435125711	11050	36	13A
0005435125727	11050	37	13E
0005434411747	11050	38	14A
0005435125883	11050	39	14C
0005435125682	11050	40	14D
0005435625879	11050	41	14E
0005434411748	11050	42	15D
0005435125825	11050	43	15E
0005435125922	11050	44	15F
0005435625883	11050	45	16C
0005435556652	11050	46	16E
0005435625881	11050	47	16F
0005435556650	11050	48	17A
0005435125836	11050	49	17D
0005435125781	11050	50	18C
0005435125721	11050	51	18D
0005435625884	11050	52	18F
0005435125705	11050	53	19A
0005435625882	11050	54	19D
0005435125726	11050	55	19E
0005435125691	11050	56	20D
0005435125882	11050	57	20F
0005435626043	14731	1	2A
0005435626045	14731	2	2D
0005435126077	14731	3	3C
0005435126067	14731	4	3D
0005435126096	14731	5	3F
0005435126076	14731	6	4A
0005435126071	14731	7	4C
0005435126081	14731	8	4D
0005435126099	14731	9	4E
0005434411708	14731	10	4F
0005434411701	14731	11	5A
0005435626050	14731	12	5C
0005435126095	14731	13	5D
0005435626051	14731	14	5E
0005435126082	14731	15	6C
0005435126094	14731	16	6D
0005435126098	14731	17	6E
0005435626046	14731	18	6F
0005435126078	14731	19	7A
0005435554149	14731	20	7C
0005435126075	14731	21	7D
0005435126088	14731	22	7E
0005435626047	14731	23	7F
0005435126091	14731	24	8D
0005435126083	14731	25	9D
0005435626042	14731	26	9E
0005435126090	14731	27	9F
0005435556672	14731	28	10C
0005435126092	14731	29	10D
0005435626048	14731	30	10E
0005435126101	14731	31	10F
0005435126100	14731	32	11A
0005435626041	14731	33	11C
0005435126097	14731	34	11D
0005435126089	14731	35	11E
0005435126073	14731	36	11F
0005435126103	14731	37	12C
0005435126085	14731	38	12E
0005435126093	14731	39	13A
0005435126084	14731	40	13D
0005435126066	14731	41	14A
0005435626049	14731	42	14C
0005435126087	14731	43	14D
0005435126069	14731	44	14E
0005435126068	14731	45	15A
0005435126086	14731	46	15F
0005435626044	14731	47	16D
0005435126070	14731	48	16E
0005435126080	14731	49	16F
0005435126102	14731	50	17A
0005435554152	14731	51	17D
0005435554151	14731	52	17E
0005435626053	14731	53	17F
0005435556673	14731	54	18A
0005435626040	14731	55	18C
0005435554150	14731	56	18D
0005435126065	14731	57	18E
0005435126064	14731	58	18F
0005434928258	14731	59	19A
0005435126072	14731	60	19C
0005435126079	14731	61	19D
0005435626052	14731	62	19E
0005435126105	14731	63	19F
0005435126074	14731	64	20C
0005435626054	14731	65	20D
0005435126104	14731	66	20E
0005435715338	7115	1	1A
0005435715348	7115	2	1F
0005435715353	7115	3	2F
0005435715339	7115	4	3A
0005435715341	7115	5	3C
0005435219172	7115	6	3D
0005435443188	7115	7	3F
0005435221040	7115	8	4A
0005432400097	7115	9	4D
0005435715350	7115	10	5A
0005435443150	7115	11	6E
0005435221039	7115	12	7E
0005432398169	7115	13	8E
0005435443161	7115	14	9A
0005432398171	7115	15	9E
0005435715351	7115	16	11A
0005432398168	7115	17	11C
0005432398170	7115	18	12C
0005435715346	7115	19	12D
0005435715347	7115	20	13C
0005435715337	7115	21	13D
0005435715343	7115	22	14D
0005435443149	7115	23	14E
0005435219171	7115	24	16A
0005435221037	7115	25	16E
0005432398172	7115	26	17A
0005435715352	7115	27	17E
0005435715344	7115	28	18F
0005435221038	7115	29	19D
0005435715349	7115	30	19E
0005435715335	7115	31	19F
0005435715342	7115	32	20A
0005435443168	7115	33	20C
0005435715340	7115	34	20D
0005435715345	7115	35	20E
0005435715336	7115	36	20F
0005432398135	27096	1	1C
0005432398142	27096	2	1D
0005432394042	27096	3	2C
0005435715258	27096	4	3C
0005435443247	27096	5	3D
0005435715226	27096	6	4E
0005435443244	27096	7	4F
0005435178483	27096	8	5A
0005435715273	27096	9	5C
0005435715173	27096	10	5D
0005435715274	27096	11	5E
0005435715259	27096	12	6E
0005435715214	27096	13	7C
0005435715251	27096	14	7D
0005435715218	27096	15	7E
0005435443242	27096	16	7F
0005432394045	27096	17	8A
0005435715222	27096	18	8C
0005435443243	27096	19	9C
0005432394041	27096	20	9E
0005435715187	27096	21	9F
0005432394034	27096	22	10A
0005432394046	27096	23	10D
0005435443245	27096	24	10F
0005435443248	27096	25	11D
0005435715223	27096	26	12A
0005435715191	27096	27	12E
0005435715201	27096	28	13A
0005435715221	27096	29	13C
0005435443249	27096	30	13D
0005435443246	27096	31	13F
0005435715250	27096	32	14A
0005435715192	27096	33	15A
0005435178482	27096	34	15E
0005435715188	27096	35	15F
0005432398131	27096	36	16E
0005435715264	27096	37	19C
0005432394044	27096	38	19F
0005435715200	27096	39	20F
0005434084898	2715	1	1A
0005434084896	2715	2	2A
0005434084897	2715	3	2B
0005434084899	2715	4	6A
0005433060377	2715	5	6B
0005434084869	28492	1	1A
0005434084880	28492	2	1B
0005434084863	28492	3	2A
0005434084881	28492	4	2B
0005434084879	28492	5	3A
0005433060394	28492	6	3B
0005434084851	28492	7	4A
0005433060393	28492	8	4B
0005432632666	25199	1	1C
0005432632674	25199	2	1D
0005432632659	25199	3	2A
0005432632655	25199	4	2B
0005432632679	25199	5	3A
0005432632656	25199	6	4D
0005432632668	25199	7	5B
0005432632660	25199	8	6A
0005432632678	25199	9	6B
0005432632680	25199	10	6C
0005432632671	25199	11	7A
0005432632683	25199	12	7B
0005432632664	25199	13	7C
0005432632669	25199	14	7D
0005432632676	25199	15	18A
0005432632670	25199	16	18B
0005432632657	25199	17	18D
0005432632677	25199	18	19A
0005432632682	25199	19	20A
0005432632661	25199	20	20B
0005432632675	25199	21	20C
0005432632681	25199	22	20D
0005432632672	25199	23	21A
0005432632667	25199	24	21B
0005432632673	25199	25	21C
0005432632665	25199	26	22A
0005432632662	25199	27	22C
0005432632658	25199	28	22D
0005432632663	25199	29	23B
0005435844288	28170	1	1C
0005435844292	28170	2	1D
0005435844294	28170	3	2B
0005435844297	28170	4	2C
0005432632636	28170	5	2D
0005435844289	28170	6	3A
0005432632629	28170	7	4D
0005435844298	28170	8	4C
0005435844284	28170	9	5C
0005432632632	28170	10	7A
0005435844295	28170	11	7B
0005435844296	28170	12	7C
0005435844290	28170	13	7D
0005435844291	28170	14	19B
0005432632623	28170	15	19C
0005435844285	28170	16	20A
0005435844287	28170	17	21A
0005435844293	28170	18	21B
0005432632640	28170	19	22B
0005435844283	28170	20	23A
0005435844286	28170	21	23B
0005435540700	11417	1	2C
0005435517684	11417	2	2F
0005435540627	11417	3	5F
0005435517631	11417	4	7F
0005435517666	11417	5	8A
0005435517622	11417	6	8C
0005435517598	11417	7	8D
0005435540726	11417	8	9A
0005435540699	11417	9	9D
0005435540737	11417	10	10C
0005435540624	11417	11	10F
0005435517625	11417	12	11A
0005435517686	11417	13	11E
0005435517685	11417	14	12A
0005435517617	11417	15	13A
0005435540646	11417	16	13F
0005435517681	11417	17	17C
0005435540625	11417	18	17D
0005435540750	11417	19	18E
0005435540703	11417	20	18F
0005435540673	11417	21	19E
0005435517630	11417	22	20A
0005435517662	11417	23	19F
0005435517619	11417	24	20F
0005435540839	22266	1	1D
0005435529079	22266	2	1F
0005435540825	22266	3	2A
0005435529090	22266	4	3A
0005435540843	22266	5	3C
0005435529087	22266	6	4A
0005435529080	22266	7	4C
0005435540835	22266	8	4E
0005435529086	22266	9	5C
0005435540828	22266	10	5D
0005435529082	22266	11	5E
0005435529088	22266	12	6A
0005435540831	22266	13	6C
0005435529099	22266	14	6E
0005435540829	22266	15	6F
0005435529085	22266	16	7C
0005435540824	22266	17	7F
0005435529078	22266	18	8A
0005435529095	22266	19	8D
0005435540838	22266	20	8E
0005435529094	22266	21	8F
0005435529081	22266	22	9A
0005435540830	22266	23	9D
0005435540823	22266	24	9E
0005435529092	22266	25	9F
0005435540836	22266	26	10C
0005432294467	22266	27	10D
0005435529097	22266	28	10F
0005435529084	22266	29	11A
0005435540841	22266	30	11F
0005435529091	22266	31	12C
0005435540833	22266	32	12D
0005435540842	22266	33	13D
0005435540832	22266	34	13E
0005432294469	22266	35	14D
0005435529096	22266	36	14F
0005435529083	22266	37	15A
0005432294468	22266	38	15E
0005435540826	22266	39	15F
0005435529098	22266	40	16D
0005435540840	22266	41	16F
0005435529093	22266	42	17D
0005435540834	22266	43	18F
0005435540827	22266	44	19C
0005435529089	22266	45	19E
0005435540837	22266	46	20F
0005433251043	2312	1	1A
0005434906916	2312	2	1C
0005434906928	2312	3	1D
0005434906929	2312	4	2C
0005433250992	2312	5	2F
0005433251105	2312	6	3A
0005434906945	2312	7	3C
0005433250972	2312	8	3D
0005434906936	2312	9	3F
0005433251104	2312	10	4A
0005434906947	2312	11	4C
0005433251128	2312	12	4E
0005433251049	2312	13	4F
0005433251048	2312	14	5A
0005433251086	2312	15	5C
0005434906942	2312	16	5D
0005434906937	2312	17	5E
0005434906911	2312	18	5F
0005434906917	2312	19	6A
0005434906921	2312	20	6D
0005433251061	2312	21	6E
0005434906915	2312	22	6F
0005433251073	2312	23	7A
0005434906923	2312	24	7C
0005434906922	2312	25	7D
0005434906932	2312	26	7E
0005434906909	2312	27	7F
0005433251063	2312	28	8C
0005433251142	2312	29	8E
0005434906935	2312	30	8F
0005434906905	2312	31	9A
0005433250965	2312	32	9C
0005433251040	2312	33	9D
0005434906934	2312	34	9E
0005434906941	2312	35	9F
0005433251143	2312	36	10A
0005434906944	2312	37	10C
0005434906946	2312	38	10D
0005434906908	2312	39	10F
0005434906918	2312	40	11A
0005434906914	2312	41	11C
0005434906930	2312	42	11D
0005433251088	2312	43	11E
0005434906925	2312	44	11F
0005433400930	2312	45	12A
0005434906949	2312	46	12C
0005434906913	2312	47	12D
0005434906939	2312	48	12E
0005434906943	2312	49	12F
0005433251087	2312	50	13A
0005433400936	2312	51	13C
0005433250971	2312	52	13D
0005434906940	2312	53	13E
0005434906912	2312	54	13F
0005433250975	2312	55	14C
0005433251053	2312	56	14D
0005434906907	2312	57	14E
0005434906924	2312	58	14F
0005434906927	2312	59	15A
0005433251204	2312	60	15C
0005434906926	2312	61	15D
0005433251047	2312	62	15F
0005434906938	2312	63	16F
0005434906919	2312	64	17A
0005434906948	2312	65	17C
0005433251083	2312	66	17F
0005434906933	2312	67	18C
0005433251052	2312	68	18E
0005434906920	2312	69	18F
0005434906950	2312	70	19A
0005433251103	2312	71	19C
0005434906906	2312	72	19D
0005434906931	2312	73	19E
0005434906910	2312	74	19F
0005433251032	2312	75	20A
0005433251149	2312	76	20C
0005433250987	2312	77	20D
0005433251041	2312	78	20E
0005433251254	25595	1	1A
0005433251260	25595	2	1C
0005434906556	25595	3	1D
0005433251271	25595	4	1F
0005434906412	25595	5	2A
0005433251247	25595	6	2C
0005433251255	25595	7	2D
0005433251261	25595	8	3A
0005433251264	25595	9	3D
0005434906516	25595	10	3F
0005433251262	25595	11	4A
0005434906538	25595	12	4C
0005433400962	25595	13	4D
0005434906435	25595	14	4E
0005433251258	25595	15	4F
0005433251266	25595	16	5A
0005434906417	25595	17	5C
0005434906515	25595	18	5E
0005434906419	25595	19	5F
0005434906416	25595	20	6A
0005433251243	25595	21	6C
0005433251246	25595	22	6D
0005434906514	25595	23	6F
0005434906413	25595	24	7A
0005434906562	25595	25	7C
0005434906484	25595	26	7D
0005434906522	25595	27	7E
0005433251273	25595	28	7F
0005433251248	25595	29	8A
0005434906393	25595	30	8C
0005433400960	25595	31	8E
0005433251256	25595	32	9A
0005434906545	25595	33	9C
0005433251274	25595	34	9D
0005433251259	25595	35	10A
0005433251253	25595	36	10C
0005434906392	25595	37	10D
0005434906481	25595	38	10E
0005434906495	25595	39	10F
0005434906426	25595	40	11C
0005434906448	25595	41	11D
0005433251245	25595	42	12A
0005433251267	25595	43	12C
0005433251272	25595	44	12D
0005434906506	25595	45	12E
0005434906521	25595	46	12F
0005434906402	25595	47	13A
0005433251250	25595	48	13E
0005434906364	25595	49	14A
0005434906443	25595	50	14C
0005434906414	25595	51	14D
0005433251263	25595	52	15A
0005434906523	25595	53	15D
0005433251265	25595	54	15F
0005433251249	25595	55	16D
0005433251252	25595	56	17A
0005434906449	25595	57	17C
0005434906528	25595	58	17E
0005433400961	25595	59	17F
0005434906517	25595	60	18A
0005434906496	25595	61	18D
0005433251268	25595	62	18E
0005433251244	25595	63	18F
0005433251257	25595	64	19D
0005433251251	25595	65	19F
0005433251269	25595	66	20C
0005434906534	25595	67	20D
0005433251270	25595	68	20E
0005434906518	25595	69	20F
0005432862206	2529	1	1B
0005432620944	2529	2	1D
0005432862212	2529	3	1C
0005432862183	2529	4	2A
0005432862178	2529	5	2B
0005432620937	2529	6	2D
0005432620933	2529	7	3A
0005432620938	2529	8	4C
0005432620939	2529	9	4D
0005432862172	2529	10	5B
0005432620935	2529	11	5D
0005432620940	2529	12	6B
0005432862177	2529	13	6C
0005432862207	2529	14	6D
0005432862213	2529	15	7A
0005432620941	2529	16	18A
0005432620934	2529	17	19A
0005432862180	2529	18	19C
0005432620943	2529	19	19D
0005432620936	2529	20	20A
0005432862179	2529	21	21B
0005432862211	2529	22	22A
0005432862182	2529	23	22B
0005432620942	2529	24	22D
0005432862184	2529	25	23B
0005432620876	28072	1	1A
0005432620813	28072	2	1B
0005432620856	28072	3	1D
0005432862242	28072	4	2A
0005432862245	28072	5	2B
0005432620855	28072	6	3A
0005432620804	28072	7	3D
0005432862243	28072	8	4C
0005432620805	28072	9	4D
0005432620864	28072	10	6C
0005432862249	28072	11	7A
0005432862248	28072	12	7B
0005432862247	28072	13	7C
0005432620803	28072	14	18B
0005432620807	28072	15	18C
0005432862246	28072	16	19C
0005432620829	28072	17	19D
0005432620808	28072	18	20A
0005432620802	28072	19	21C
0005432620801	28072	20	22D
0005432862244	28072	21	23B
0005434097449	11737	1	3B
0005434097458	11737	2	5A
0005434097466	13028	1	1A
0005433451604	31068	1	1A
0005433451605	31068	2	2A
0005433452723	31068	3	5A
0005433452724	31068	4	5B
0005433452706	31430	1	2A
0005433454845	31430	2	5A
0005433454851	31430	3	5B
0005433454846	31430	4	6B
0005433129212	12028	1	1D
0005433134064	12028	2	2B
0005433134056	12028	3	3A
0005433134062	12028	4	3C
0005433134077	12028	5	5A
0005433129217	12028	6	5D
0005433134076	12028	7	7A
0005433129216	12028	8	7D
0005434142552	12028	9	18A
0005433129213	12028	10	20A
0005434142557	12028	11	20B
0005434142553	12028	12	21B
0005434142551	12028	13	22D
0005434183565	29820	1	1D
0005434184650	29820	2	3B
0005433134103	29820	3	3C
0005433134104	29820	4	4C
0005433134105	29820	5	5A
0005434142577	29820	6	5B
0005434183564	29820	7	5C
0005433134106	29820	8	6B
0005434142579	29820	9	7A
0005433131675	29820	10	18D
0005433131674	29820	11	19B
0005433134107	29820	12	19C
0005434142578	29820	13	20A
0005434184651	29820	14	20B
0005434142581	29820	15	21A
0005434142580	29820	16	21B
0005433131677	29820	17	21D
0005433131676	29820	18	22C
0005435697103	16453	1	1A
0005435697118	16453	2	1B
0005435697125	16453	3	1C
0005435697115	16453	4	2B
0005435697106	16453	5	2C
0005435697109	16453	6	3A
0005435697130	16453	7	3C
0005435697127	16453	8	4A
0005435697107	16453	9	4B
0005435697124	16453	10	4C
0005435934996	16453	11	4D
0005435697104	16453	12	5A
0005435697111	16453	13	5C
0005435697122	16453	14	6B
0005435697116	16453	15	7A
0005435697102	16453	16	7B
0005435697113	16453	17	18A
0005435697108	16453	18	18B
0005435697129	16453	19	18C
0005435697110	16453	20	19A
0005435697119	16453	21	19B
0005435697120	16453	22	19C
0005435697117	16453	23	19D
0005435697123	16453	24	20A
0005435697128	16453	25	20D
0005435697105	16453	26	21A
0005435934994	16453	27	21B
0005435934995	16453	28	22A
0005435697114	16453	29	22B
0005435697126	16453	30	22D
0005435697121	16453	31	23A
0005435697112	16453	32	23B
0005435696992	24732	1	1B
0005435696963	24732	2	1C
0005435935022	24732	3	2A
0005435696911	24732	4	2B
0005435696943	24732	5	3A
0005435696912	24732	6	3C
0005435696942	24732	7	3D
0005435696997	24732	8	4C
0005435935020	24732	9	4D
0005435696892	24732	10	5C
0005435696959	24732	11	6B
0005435935023	24732	12	6D
0005435696958	24732	13	7A
0005435696956	24732	14	7B
0005435696903	24732	15	18A
0005435696890	24732	16	18C
0005435696899	24732	17	19A
0005435696935	24732	18	18D
0005435696902	24732	19	19B
0005435696913	24732	20	20B
0005435696999	24732	21	20C
0005435696873	24732	22	20D
0005435696998	24732	23	21D
0005435696900	24732	24	22A
0005435935021	24732	25	22B
0005435696955	24732	26	23B
0005433724770	18759	1	1B
0005432968801	18759	2	2B
0005433724769	18759	3	3A
0005433724767	18759	4	5A
0005433724771	18759	5	5B
0005433724768	18759	6	6B
0005433724756	21608	1	1A
0005433724733	21608	2	3B
0005432968825	21608	3	5A
0005432968826	21608	4	6A
0005433724747	21608	5	5B
0005433724755	21608	6	6B
0005434137607	7348	1	1C
0005434137557	7348	2	1D
0005434087478	7348	3	2A
0005434137604	7348	4	2C
0005434137616	7348	5	2D
0005434137551	7348	6	2F
0005434137580	7348	7	3A
0005434137591	7348	8	3C
0005434137553	7348	9	3D
0005434137599	7348	10	3F
0005434137608	7348	11	4A
0005434087477	7348	12	4C
0005434137541	7348	13	4D
0005434137560	7348	14	4E
0005434137576	7348	15	4F
0005434137617	7348	16	5A
0005434137572	7348	17	5C
0005434137620	7348	18	5D
0005434137565	7348	19	5E
0005434137547	7348	20	5F
0005434137585	7348	21	6A
0005434137561	7348	22	6C
0005434137601	7348	23	6D
0005434137605	7348	24	6E
0005434087479	7348	25	7A
0005434137543	7348	26	7C
0005434137562	7348	27	7D
0005434137611	7348	28	7E
0005434137544	7348	29	7F
0005434137564	7348	30	8A
0005434137567	7348	31	8C
0005434137618	7348	32	8D
0005434137583	7348	33	8E
0005434137595	7348	34	8F
0005434137593	7348	35	9A
0005434137549	7348	36	9C
0005434137570	7348	37	9D
0005434137615	7348	38	9E
0005434137546	7348	39	9F
0005434137554	7348	40	10A
0005434137540	7348	41	10C
0005434137614	7348	42	10D
0005434137573	7348	43	10E
0005434137556	7348	44	10F
0005434137577	7348	45	11A
0005434137563	7348	46	11C
0005434137590	7348	47	11D
0005434137552	7348	48	11F
0005434137602	7348	49	12A
0005434137606	7348	50	12C
0005434137596	7348	51	12D
0005434137609	7348	52	12E
0005434137610	7348	53	12F
0005434137575	7348	54	13A
0005434137538	7348	55	13C
0005434137555	7348	56	13D
0005434137594	7348	57	13E
0005434137588	7348	58	13F
0005434137574	7348	59	14A
0005434137571	7348	60	14D
0005434137545	7348	61	14E
0005434137548	7348	62	14F
0005434137579	7348	63	15A
0005434137619	7348	64	15C
0005434137539	7348	65	15D
0005434137613	7348	66	15E
0005434137566	7348	67	15F
0005434137542	7348	68	16A
0005434137569	7348	69	16C
0005434137597	7348	70	16D
0005434137598	7348	71	16E
0005434087480	7348	72	16F
0005434137582	7348	73	17A
0005434137587	7348	74	17C
0005434137622	7348	75	17D
0005434137589	7348	76	17E
0005434137558	7348	77	17F
0005434137600	7348	78	18A
0005434137586	7348	79	18C
0005434137603	7348	80	18D
0005434137592	7348	81	18E
0005434137559	7348	82	18F
0005434137550	7348	83	19A
0005434137581	7348	84	19C
0005434137578	7348	85	19E
0005434137584	7348	86	19F
0005434137621	7348	87	20A
0005434137612	7348	88	20C
0005434137568	7348	89	20D
0005434137623	7348	90	20F
0005434136930	28585	1	1A
0005434136745	28585	2	1D
0005434136708	28585	3	1F
0005434136771	28585	4	2C
0005434136707	28585	5	2D
0005434136867	28585	6	3A
0005434087427	28585	7	4A
0005434136835	28585	8	4C
0005434136703	28585	9	4E
0005434136691	28585	10	5D
0005434136830	28585	11	5E
0005434136681	28585	12	5F
0005434136819	28585	13	6A
0005434087428	28585	14	6C
0005434136747	28585	15	6D
0005434136916	28585	16	6F
0005434136786	28585	17	7A
0005434136885	28585	18	7C
0005434136906	28585	19	7D
0005434136915	28585	20	7E
0005434087441	28585	21	7F
0005434136878	28585	22	8D
0005434136744	28585	23	8E
0005434136710	28585	24	8F
0005434136752	28585	25	9A
0005434136702	28585	26	9C
0005434136799	28585	27	9E
0005434136727	28585	28	9F
0005434136732	28585	29	10C
0005434136905	28585	30	10E
0005434136756	28585	31	10F
0005434136735	28585	32	11C
0005434136925	28585	33	11D
0005434136919	28585	34	11E
0005434136731	28585	35	11F
0005434136785	28585	36	12A
0005434136815	28585	37	12C
0005434136929	28585	38	12D
0005434136746	28585	39	12F
0005434136763	28585	40	13A
0005434136734	28585	41	13D
0005434136816	28585	42	13E
0005434136797	28585	43	13F
0005434136793	28585	44	14A
0005434136704	28585	45	14C
0005434136866	28585	46	15A
0005434136834	28585	47	15D
0005434136924	28585	48	15E
0005434136792	28585	49	15F
0005434087442	28585	50	16C
0005434136714	28585	51	16D
0005434136692	28585	52	16F
0005434136693	28585	53	16E
0005434136711	28585	54	17C
0005434136841	28585	55	17D
0005434136713	28585	56	17E
0005434136791	28585	57	17F
0005434136879	28585	58	18E
0005434136904	28585	59	19A
0005434136839	28585	60	19F
0005434136712	28585	61	20A
0005434136880	28585	62	20E
0005434610204	1930	1	1A
0005435808163	1930	2	1D
0005435808158	1930	3	4D
0005435808160	1930	4	5A
0005434610205	1930	5	5B
0005433407489	1930	6	5D
0005434610203	1930	7	6A
0005435808165	1930	8	6C
0005434610202	1930	9	6D
0005435808166	1930	10	7B
0005435808164	1930	11	18B
0005435808156	1930	12	19B
0005435808161	1930	13	20B
0005435808159	1930	14	21A
0005433407502	1930	15	21B
0005435808167	1930	16	21C
0005435808157	1930	17	21D
0005435808162	1930	18	22B
0005434610201	1930	19	23B
0005435808062	23079	1	1A
0005433407529	23079	2	1B
0005435808073	23079	3	1C
0005433407526	23079	4	2A
0005435808058	23079	5	2B
0005433407520	23079	6	2D
0005435808059	23079	7	3A
0005435808066	23079	8	3B
0005435808064	23079	9	3D
0005435808060	23079	10	4A
0005435808067	23079	11	4B
0005435808070	23079	12	4C
0005433407527	23079	13	5B
0005433407523	23079	14	5C
0005434610171	23079	15	6C
0005435808061	23079	16	7A
0005433407524	23079	17	18A
0005433407519	23079	18	18B
0005435808055	23079	19	18D
0005433407518	23079	20	19A
0005434610172	23079	21	19C
0005435808054	23079	22	19D
0005435808069	23079	23	20C
0005433407521	23079	24	21A
0005433407528	23079	25	21B
0005433407522	23079	26	21C
0005435808065	23079	27	21D
0005433407525	23079	28	22B
0005434503498	16701	1	1A
0005434503633	16701	2	1B
0005434503607	16701	3	1D
0005434503471	16701	4	2D
0005434503604	16701	5	3D
0005434503631	16701	6	4B
0005434503532	16701	7	4C
0005434503470	16701	8	4D
0005434503512	16701	9	5B
0005434503497	16701	10	5D
0005434503609	16701	11	6A
0005434503582	16701	12	6D
0005434503508	16701	13	7B
0005434503559	16701	14	7C
0005434503555	16701	15	18B
0005434503558	16701	16	19D
0005434503632	16701	17	20B
0005434503507	16701	18	20C
0005434503598	16701	19	20D
0005434503472	16701	20	21D
0005434503482	16701	21	22B
0005434503517	16701	22	22C
0005434503573	16701	23	23B
0005434503824	22891	1	1A
0005434503851	22891	2	1C
0005434503839	22891	3	1D
0005434503846	22891	4	2A
0005434503835	22891	5	2C
0005434503856	22891	6	2D
0005434503857	22891	7	3A
0005434503832	22891	8	3C
0005434503836	22891	9	3D
0005434503829	22891	10	4A
0005434503834	22891	11	4B
0005434503825	22891	12	4C
0005434503854	22891	13	4D
0005434503830	22891	14	5A
0005434503847	22891	15	5B
0005434503850	22891	16	5C
0005434503853	22891	17	5D
0005434503842	22891	18	6A
0005434503840	22891	19	6B
0005434503861	22891	20	6C
0005434503852	22891	21	6D
0005434503855	22891	22	7C
0005434503837	22891	23	7D
0005434503860	22891	24	18A
0005434503838	22891	25	18C
0005434503826	22891	26	18D
0005434503858	22891	27	19A
0005434503848	22891	28	19C
0005434503831	22891	29	19D
0005434503841	22891	30	20A
0005434503828	22891	31	20B
0005434503823	22891	32	20D
0005434503844	22891	33	21A
0005434503859	22891	34	21B
0005434503843	22891	35	21C
0005434503862	22891	36	21D
0005434503849	22891	37	22A
0005434503833	22891	38	22B
0005434503845	22891	39	22C
0005434503827	22891	40	22D
0005433266581	2179	1	1D
0005435078223	2179	2	2A
0005433266582	2179	3	2D
0005435078225	2179	4	3A
0005435078238	2179	5	3B
0005433266559	2179	6	3C
0005433266573	2179	7	4C
0005433266560	2179	8	4D
0005433266572	2179	9	5A
0005435078226	2179	10	5B
0005435078236	2179	11	6A
0005433266568	2179	12	6B
0005435078235	2179	13	6C
0005435078233	2179	14	7A
0005435078230	2179	15	7B
0005435078224	2179	16	7D
0005433266569	2179	17	18B
0005435078228	2179	18	18C
0005435078227	2179	19	18D
0005435078232	2179	20	19A
0005433266621	2179	21	19D
0005435078237	2179	22	20A
0005433266583	2179	23	21A
0005433266587	2179	24	21C
0005435078231	2179	25	21D
0005435078229	2179	26	22A
0005435078234	2179	27	22D
0005433266658	24375	1	1C
0005435078109	24375	2	1D
0005433266657	24375	3	2A
0005433266654	24375	4	3D
0005433266660	24375	5	4A
0005435078072	24375	6	4B
0005433266659	24375	7	5C
0005433266655	24375	8	6A
0005435078079	24375	9	6C
0005435078078	24375	10	6D
0005435078114	24375	11	7B
0005435078096	24375	12	18C
0005435078069	24375	13	18D
0005435078093	24375	14	19A
0005435078091	24375	15	19D
0005435078073	24375	16	20A
0005435078145	24375	17	20C
0005433266653	24375	18	20B
0005435078123	24375	19	21B
0005433266656	24375	20	22A
0005435078088	24375	21	22C
0005435078122	24375	22	22D
0005435078097	24375	23	23A
0005435803242	6655	1	1B
0005434988655	6655	2	1C
0005434988657	6655	3	2A
0005435803241	6655	4	3A
0005434988666	6655	5	3D
0005434988663	6655	6	4C
0005434988662	6655	7	5A
0005435803245	6655	8	5D
0005434988665	6655	9	6B
0005434988660	6655	10	7A
0005434988661	6655	11	7C
0005435803244	6655	12	18A
0005435803243	6655	13	19A
0005434988656	6655	14	19B
0005434988664	6655	15	19D
0005434988658	6655	16	21B
0005434988659	6655	17	22A
0005434988654	6655	18	23A
0005434988564	23629	1	1B
0005435803226	23629	2	6A
0005435464492	23629	3	7A
0005435803218	23629	4	19A
0005435464493	23629	5	20B
0005434988560	23629	6	21A
0005434988561	23629	7	21C
0005435803219	23629	8	22D
0005432382926	30507	1	1A
0005433449806	30507	2	1C
0005432382913	30507	3	1D
0005432382920	30507	4	1F
0005433449810	30507	5	2A
0005432382924	30507	6	2C
0005432382915	30507	7	2D
0005433449826	30507	8	2F
0005433449813	30507	9	3D
0005433453749	30507	10	3F
0005433449811	30507	11	4A
0005432382894	30507	12	4C
0005433449817	30507	13	4D
0005433454859	30507	14	4E
0005432382901	30507	15	4F
0005433449818	30507	16	5C
0005432382897	30507	17	5D
0005432382898	30507	18	5F
0005432382887	30507	19	6A
0005432382906	30507	20	6F
0005433454860	30507	21	7A
0005432382903	30507	22	7C
0005433449809	30507	23	7D
0005432382890	30507	24	7F
0005432382917	30507	25	8A
0005432382902	30507	26	8C
0005432382916	30507	27	8D
0005433449819	30507	28	8E
0005432382888	30507	29	8F
0005433449822	30507	30	9C
0005432382914	30507	31	9D
0005432382918	30507	32	9E
0005432382904	30507	33	9F
0005432382895	30507	34	10C
0005433449814	30507	35	10D
0005433449812	30507	36	10E
0005433449821	30507	37	11D
0005432382910	30507	38	11E
0005433449823	30507	39	11F
0005433449808	30507	40	12A
0005433449807	30507	41	12C
0005432382905	30507	42	12E
0005432382899	30507	43	12F
0005432382900	30507	44	13A
0005433454862	30507	45	13E
0005432382892	30507	46	13F
0005432382907	30507	47	14A
0005433449816	30507	48	14D
0005432382889	30507	49	14E
0005432382891	30507	50	15A
0005432382908	30507	51	15C
0005433449824	30507	52	15D
0005432382923	30507	53	15F
0005432382886	30507	54	16A
0005432382909	30507	55	16C
0005433454861	30507	56	16D
0005433449815	30507	57	16F
0005432382893	30507	58	17A
0005432382912	30507	59	18A
0005433449825	30507	60	18C
0005432382911	30507	61	18D
0005432382925	30507	62	18E
0005432382922	30507	63	19C
0005433449820	30507	64	19D
0005432382896	30507	65	19E
0005433449827	30507	66	20D
0005432382921	30507	67	20E
0005432382919	30507	68	20F
0005433449673	31321	1	1C
0005432382551	31321	2	1D
0005433453740	31321	3	1F
0005433449694	31321	4	2F
0005433451584	31321	5	3D
0005432382550	31321	6	5C
0005432382764	31321	7	5D
0005433449678	31321	8	5E
0005433449607	31321	9	5F
0005432382668	31321	10	6A
0005432382593	31321	11	6D
0005433449600	31321	12	6E
0005433449611	31321	13	7C
0005433449669	31321	14	8A
0005432382585	31321	15	8E
0005433449672	31321	16	9D
0005433449708	31321	17	10D
0005432382567	31321	18	11A
0005432382560	31321	19	11D
0005433453742	31321	20	12D
0005432382765	31321	21	13C
0005432382549	31321	22	13D
0005433453741	31321	23	13E
0005432382612	31321	24	13F
0005433449601	31321	25	14A
0005433451585	31321	26	14D
0005432382594	31321	27	14F
0005433453726	31321	28	15C
0005432382522	31321	29	15D
0005432382530	31321	30	15F
0005433449755	31321	31	16C
0005432382537	31321	32	16D
0005432382538	31321	33	16F
0005433449667	31321	34	17A
0005433453727	31321	35	17D
0005432382667	31321	36	17F
0005432382486	31321	37	18A
0005433449657	31321	38	18C
0005432382599	31321	39	18D
0005433449587	31321	40	18E
0005433449592	31321	41	18F
0005432382539	31321	42	19A
0005433449620	31321	43	19C
0005432382485	31321	44	19E
0005433449645	31321	45	20A
0005432382529	31321	46	20C
0005432382766	31321	47	20D
0005433449756	31321	48	20E
0005435304099	10753	1	1C
0005433131636	10753	2	3B
0005433126768	10753	3	4A
0005433126769	10753	4	4B
0005435299706	10753	5	4C
0005433131634	10753	6	5D
0005435304097	10753	7	6B
0005433131644	10753	8	7D
0005435299700	10753	9	18C
0005435304100	10753	10	19C
0005435304092	10753	11	19D
0005435304107	10753	12	20D
0005435299701	10753	13	23B
0005433129247	29734	1	1B
0005435299748	29734	2	1D
0005435302172	29734	3	2A
0005433126817	29734	4	2B
0005433126815	29734	5	2C
0005435299744	29734	6	2D
0005433129246	29734	7	3D
0005433129248	29734	8	4C
0005433126816	29734	9	5A
0005435299749	29734	10	5C
0005435299745	29734	11	5D
0005435302168	29734	12	6C
0005435299746	29734	13	7A
0005433126819	29734	14	7B
0005435302171	29734	15	18A
0005433126814	29734	16	18B
0005433129251	29734	17	18C
0005433126818	29734	18	19B
0005433129249	29734	19	19D
0005435302169	29734	20	20B
0005435299747	29734	21	20D
0005433129250	29734	22	21A
0005435302170	29734	23	23A
0005434287123	2408	1	1C
0005434287125	2408	2	1D
0005434287130	2408	3	2B
0005434287134	2408	4	3A
0005434287121	2408	5	3B
0005433109885	2408	6	3D
0005434287126	2408	7	4A
0005434287133	2408	8	4C
0005433109884	2408	9	4D
0005434287131	2408	10	5B
0005434287138	2408	11	5C
0005432264458	2408	12	6A
0005432264457	2408	13	6C
0005434287141	2408	14	6D
0005434287129	2408	15	7A
0005434287137	2408	16	7C
0005434287136	2408	17	18A
0005434287127	2408	18	18C
0005433109887	2408	19	19A
0005434287128	2408	20	19B
0005433109889	2408	21	19C
0005434287122	2408	22	20B
0005433109864	2408	23	20C
0005434287139	2408	24	20D
0005433109888	2408	25	21B
0005434287140	2408	26	21C
0005434287132	2408	27	21D
0005433109886	2408	28	22A
0005433109879	2408	29	22D
0005434287124	2408	30	23A
0005434287135	2408	31	23B
0005433109963	26855	1	1A
0005434286952	26855	2	1B
0005434286914	26855	3	2A
0005433109968	26855	4	2B
0005433109964	26855	5	2C
0005434286960	26855	6	2D
0005433109971	26855	7	3B
0005434286989	26855	8	3D
0005433109970	26855	9	4A
0005434287005	26855	10	4D
0005434287041	26855	11	5A
0005434286953	26855	12	5C
0005434287020	26855	13	5D
0005434286971	26855	14	6A
0005433109962	26855	15	6B
0005434287021	26855	16	6C
0005434286909	26855	17	7B
0005434286958	26855	18	7C
0005434286984	26855	19	7D
0005433109969	26855	20	18B
0005434287040	26855	21	19B
0005434286929	26855	22	19C
0005434287019	26855	23	19D
0005434287012	26855	24	20C
0005434286957	26855	25	21B
0005433109966	26855	26	21C
0005434287011	26855	27	21D
0005433109967	26855	28	22C
0005433109965	26855	29	22D
0005434286976	26855	30	23A
0005433109972	26855	31	23B
0005435856173	25445	1	1D
0005435856175	25445	2	2A
0005435856176	25445	3	18B
0005434272169	25445	4	19A
0005434272170	25445	5	21B
0005435856174	25445	6	21D
0005434273066	26645	1	5C
0005435856144	26645	2	7A
0005435856145	26645	3	18A
0005434272180	26645	4	18C
0005435856134	26645	5	20B
0005434273065	26645	6	21D
0005433868172	4802	1	1C
0005433868150	4802	2	1D
0005433868139	4802	3	2A
0005433868170	4802	4	2B
0005433868156	4802	5	2C
0005433868137	4802	6	2D
0005433868174	4802	7	3A
0005433868146	4802	8	3B
0005433868158	4802	9	3C
0005433868151	4802	10	3D
0005433868140	4802	11	4A
0005433868145	4802	12	4C
0005433868142	4802	13	5A
0005433868138	4802	14	5B
0005433868171	4802	15	5C
0005433868148	4802	16	5D
0005433868160	4802	17	6A
0005433868141	4802	18	6B
0005433868167	4802	19	6C
0005433868147	4802	20	6D
0005433868154	4802	21	7A
0005433868162	4802	22	7B
0005433868159	4802	23	18A
0005433868178	4802	24	18C
0005433868144	4802	25	18D
0005433868149	4802	26	19A
0005433868175	4802	27	19B
0005433868152	4802	28	19C
0005433868155	4802	29	19D
0005433868168	4802	30	20A
0005433868161	4802	31	20B
0005433868166	4802	32	20C
0005433868165	4802	33	20D
0005433868143	4802	34	21A
0005433868157	4802	35	21B
0005433868169	4802	36	21C
0005433868164	4802	37	21D
0005433868173	4802	38	22B
0005433868177	4802	39	22A
0005433868163	4802	40	22C
0005433868176	4802	41	23A
0005433868153	4802	42	23B
0005433867738	32572	1	1A
0005433867789	32572	2	1B
0005433867767	32572	3	1C
0005433867727	32572	4	2A
0005433867777	32572	5	2B
0005433867813	32572	6	2D
0005433867795	32572	7	3A
0005433867840	32572	8	3B
0005433867744	32572	9	4A
0005433867807	32572	10	4B
0005433867743	32572	11	4C
0005433867831	32572	12	5B
0005433867786	32572	13	5D
0005433867839	32572	14	6C
0005433867737	32572	15	6D
0005433867818	32572	16	7B
0005433867832	32572	17	7C
0005433867847	32572	18	18A
0005433867846	32572	19	18B
0005433867787	32572	20	18D
0005433867804	32572	21	19A
0005433867788	32572	22	19B
0005433867816	32572	23	19C
0005433867778	32572	24	19D
0005433867779	32572	25	20A
0005433867817	32572	26	20B
0005433867830	32572	27	20C
0005433867791	32572	28	21A
0005433867825	32572	29	21C
0005433867790	32572	30	21D
0005433867808	32572	31	22B
0005433867768	32572	32	22D
0005433867769	32572	33	23A
0005434663311	3441	1	1A
0005434663312	3441	2	1C
0005435911341	3441	3	1D
0005434663313	3441	4	2A
0005434663317	3441	5	2B
0005434663307	3441	6	2D
0005434461631	3441	7	3A
0005435911350	3441	8	3D
0005434663310	3441	9	4A
0005435911352	3441	10	4B
0005434663318	3441	11	4C
0005435911345	3441	12	5B
0005435911372	3441	13	6A
0005434461633	3441	14	6B
0005434663315	3441	15	6C
0005434663316	3441	16	7A
0005435911325	3441	17	7D
0005434663309	3441	18	19D
0005434461632	3441	19	19C
0005435911336	3441	20	20A
0005435911346	3441	21	20B
0005434663314	3441	22	21A
0005435911353	3441	23	21B
0005435911373	3441	24	21D
0005435911351	3441	25	22B
0005435911331	3441	26	22C
0005434663308	3441	27	23B
0005434663173	12453	1	1D
0005434663202	12453	2	2A
0005435911399	12453	3	2B
0005434663193	12453	4	2C
0005434663232	12453	5	3A
0005434663194	12453	6	3C
0005434663204	12453	7	4B
0005434663246	12453	8	4D
0005434663219	12453	9	5A
0005434663191	12453	10	5B
0005434663233	12453	11	5D
0005434663182	12453	12	6A
0005434663165	12453	13	6B
0005434663207	12453	14	6D
0005434663245	12453	15	7C
0005435911394	12453	16	7D
0005435911400	12453	17	18B
0005435911397	12453	18	18C
0005434663209	12453	19	19A
0005434663203	12453	20	19C
0005434663210	12453	21	20B
0005435911395	12453	22	21A
0005435911396	12453	23	21C
0005434663228	12453	24	21D
0005434663231	12453	25	22D
0005435911398	12453	26	23A
0005433867743	14511	1	1A
0005433867790	14511	2	1B
0005433867787	14511	3	2A
0005433867807	14511	4	2B
0005433867816	14511	5	2C
0005433867847	14511	6	3B
0005433867727	14511	7	3C
0005433867786	14511	8	3D
0005433867830	14511	9	4D
0005433867831	14511	10	5A
0005433867768	14511	11	5B
0005433867795	14511	12	5C
0005433867789	14511	13	5D
0005433867804	14511	14	6A
0005433867769	14511	15	6B
0005433867737	14511	16	6D
0005433867779	14511	17	7B
0005433867777	14511	18	7D
0005433867832	14511	19	18A
0005433867846	14511	20	18B
0005433867818	14511	21	19A
0005433867788	14511	22	19B
0005433867791	14511	23	19C
0005433867778	14511	24	19D
0005433867808	14511	25	20B
0005433867813	14511	26	20C
0005433867744	14511	27	20D
0005433867840	14511	28	21B
0005433867839	14511	29	21C
0005433867767	14511	30	22A
0005433867738	14511	31	22C
0005433867817	14511	32	22D
0005433867825	14511	33	23A
0005433868097	32671	1	1A
0005433868095	32671	2	1B
0005433868136	32671	3	1C
0005433868098	32671	4	1D
0005433868099	32671	5	2A
0005433868118	32671	6	2B
0005433868113	32671	7	2C
0005433868114	32671	8	2D
0005433868127	32671	9	3A
0005433868135	32671	10	3B
0005433868122	32671	11	3C
0005433868120	32671	12	3D
0005433868117	32671	13	4A
0005433868121	32671	14	4D
0005433868101	32671	15	5A
0005433868116	32671	16	5B
0005433868129	32671	17	5C
0005433868107	32671	18	5D
0005433868111	32671	19	6B
0005433868130	32671	20	6C
0005433868125	32671	21	6D
0005433868115	32671	22	7A
0005433868112	32671	23	7B
0005433868096	32671	24	7C
0005433868100	32671	25	7D
0005433868131	32671	26	18A
0005433868132	32671	27	18B
0005433868123	32671	28	18D
0005433868134	32671	29	19A
0005433868104	32671	30	19D
0005433868103	32671	31	20B
0005433868109	32671	32	20C
0005433868124	32671	33	20D
0005433868128	32671	34	21A
0005433868133	32671	35	21B
0005433868106	32671	36	21C
0005433868105	32671	37	22A
0005433868102	32671	38	22B
0005433868110	32671	39	22C
0005433868108	32671	40	22D
0005433868126	32671	41	23A
0005433868119	32671	42	23B
0005432799060	12131	1	2C
0005432798996	12131	2	3C
0005432799108	12131	3	4A
0005432799009	12131	4	4B
0005432799036	12131	5	4C
0005432798985	12131	6	5C
0005432798987	12131	7	6B
0005432799057	12131	8	7A
0005432799058	12131	9	7B
0005432798980	12131	10	7C
0005432799069	12131	11	18D
0005432799070	12131	12	19C
0005432799059	12131	13	20A
0005432799116	12131	14	20B
0005432799077	12131	15	21B
0005432799078	12131	16	21D
0005432798990	12131	17	22A
0005432799013	12131	18	22C
0005432798986	12131	19	22D
0005432799240	14780	1	1B
0005432799228	14780	2	1C
0005432799236	14780	3	2B
0005432799222	14780	4	2C
0005432799237	14780	5	3C
0005432799216	14780	6	3D
0005432799234	14780	7	4C
0005432799224	14780	8	5A
0005432799215	14780	9	5D
0005432799227	14780	10	6A
0005432799230	14780	11	6D
0005432799229	14780	12	7B
0005432799225	14780	13	7C
0005432799235	14780	14	18A
0005432799241	14780	15	18B
0005432799239	14780	16	18C
0005432799238	14780	17	19B
0005432799217	14780	18	19C
0005432799218	14780	19	19D
0005432799231	14780	20	20A
0005432799223	14780	21	20B
0005432799242	14780	22	20C
0005432799214	14780	23	20D
0005432799219	14780	24	21A
0005432799233	14780	25	21B
0005432799232	14780	26	21D
0005432799220	14780	27	22A
0005432799221	14780	28	22C
0005432799213	14780	29	22D
0005432799226	14780	30	23A
0005435293072	7080	1	1A
0005434407343	7080	2	1C
0005434407306	7080	3	1D
0005434407293	7080	4	2A
0005434407319	7080	5	1F
0005434299395	7080	6	2C
0005434407330	7080	7	2D
0005434407336	7080	8	2F
0005434407320	7080	9	3C
0005434407337	7080	10	3F
0005434407317	7080	11	3D
0005434407312	7080	12	4A
0005435293100	7080	13	4B
0005434299397	7080	14	4D
0005432153891	7080	15	4F
0005435293060	7080	16	4E
0005434299388	7080	17	5B
0005435293119	7080	18	5A
0005434299399	7080	19	5D
0005434407302	7080	20	5E
0005434407310	7080	21	5F
0005434299401	7080	22	6B
0005434299406	7080	23	6A
0005434407333	7080	24	6C
0005434407331	7080	25	6E
0005434407344	7080	26	6D
0005434407345	7080	27	6F
0005435293071	7080	28	7B
0005434407313	7080	29	7A
0005434407340	7080	30	7C
0005434407326	7080	31	7E
0005434407318	7080	32	7D
0005435293070	7080	33	8A
0005434299384	7080	34	7F
0005435293065	7080	35	8B
0005434299404	7080	36	8C
0005434407307	7080	37	8F
0005432153888	7080	38	9A
0005434299396	7080	39	9D
0005434407339	7080	40	9F
0005434407286	7080	41	9E
0005434299390	7080	42	10B
0005434407300	7080	43	10D
0005434407301	7080	44	10C
0005434299394	7080	45	10E
0005434407283	7080	46	11A
0005434407288	7080	47	11B
0005434299391	7080	48	11C
0005432108230	7080	49	11E
0005434299392	7080	50	11D
0005434407324	7080	51	11F
0005434407297	7080	52	12A
0005432153890	7080	53	12C
0005434407291	7080	54	12B
0005434407299	7080	55	12D
0005434407329	7080	56	12E
0005435293077	7080	57	12F
0005434407295	7080	58	13A
0005432153886	7080	59	13C
0005434407294	7080	60	13E
0005434407315	7080	61	13F
0005434407282	7080	62	14A
0005434299386	7080	63	14C
0005434407342	7080	64	14B
0005434407289	7080	65	14D
0005434299402	7080	66	14E
0005434407285	7080	67	15A
0005434407304	7080	68	14F
0005434407296	7080	69	15B
0005434407322	7080	70	15C
0005434299393	7080	71	15D
0005434407341	7080	72	15E
0005434407323	7080	73	15F
0005435293102	7080	74	16B
0005435293109	7080	75	16A
0005434407303	7080	76	16D
0005434407325	7080	77	16F
0005434407292	7080	78	16E
0005434407334	7080	79	17A
0005434299387	7080	80	17B
0005435293064	7080	81	17C
0005434407332	7080	82	17D
0005434407314	7080	83	17E
0005434407327	7080	84	18A
0005434407316	7080	85	17F
0005435293087	7080	86	18B
0005434407338	7080	87	18C
0005432153889	7080	88	18D
0005435293094	7080	89	18F
0005434407335	7080	90	18E
0005434407308	7080	91	19A
0005434299407	7080	92	19B
0005434407309	7080	93	19C
0005434407328	7080	94	19D
0005434407287	7080	95	19F
0005432108232	7080	96	19E
0005434407298	7080	97	20B
0005434299403	7080	98	20A
0005434299400	7080	99	20C
0005435293093	7080	100	20E
0005432108231	7080	101	20F
0005434407321	7080	102	21A
0005435293088	7080	103	21C
0005434407311	7080	104	21B
0005434299398	7080	105	21E
0005435293110	7080	106	22A
0005435293069	7080	107	21F
0005435293048	7080	108	22B
0005434299405	7080	109	22C
0005434407305	7080	110	22D
0005434407290	7080	111	22F
0005434407284	7080	112	22E
0005434407346	7080	113	23A
0005434299385	7080	114	23B
0005435293101	7080	115	23C
0005432153885	7080	116	23D
0005432153887	7080	117	23F
0005434299389	7080	118	23E
0005434299174	26910	1	1C
0005435293169	26910	2	1F
0005434406679	26910	3	1D
0005432058348	26910	4	2A
0005434406986	26910	5	2C
0005435310976	26910	6	2F
0005434406762	26910	7	3C
0005434406773	26910	8	3D
0005435293164	26910	9	3F
0005434406744	26910	10	4A
0005435293168	26910	11	4E
0005434406649	26910	12	4F
0005434406808	26910	13	5A
0005435293162	26910	14	5C
0005434406750	26910	15	5E
0005435310974	26910	16	5F
0005434406797	26910	17	6A
0005435293157	26910	18	6D
0005435310971	26910	19	7A
0005434299247	26910	20	6F
0005434406984	26910	21	7B
0005434299235	26910	22	7D
0005434406732	26910	23	7F
0005434406779	26910	24	8A
0005435293163	26910	25	8B
0005434299212	26910	26	8D
0005432058349	26910	27	8F
0005435310972	26910	28	9A
0005435310975	26910	29	9B
0005435310970	26910	30	10B
0005434406655	26910	31	10E
0005432058350	26910	32	10D
0005435293159	26910	33	11A
0005434299222	26910	34	11C
0005434407071	26910	35	11E
0005434299152	26910	36	12A
0005434299241	26910	37	12E
0005434406883	26910	38	13C
0005434299282	26910	39	13D
0005434299223	26910	40	13E
0005434299283	26910	41	13F
0005434299303	26910	42	14B
0005434299147	26910	43	14A
0005435293166	26910	44	14C
0005435310977	26910	45	14D
0005434299181	26910	46	14E
0005434406656	26910	47	14F
0005434406696	26910	48	15A
0005434299153	26910	49	15C
0005435293167	26910	50	15B
0005435293165	26910	51	15D
0005435310969	26910	52	15E
0005434406761	26910	53	16A
0005434406890	26910	54	15F
0005435293160	26910	55	16B
0005435310973	26910	56	16D
0005434406709	26910	57	16E
0005432058351	26910	58	16F
0005434406695	26910	59	17B
0005434406853	26910	60	17C
0005434406794	26910	61	17D
0005434299304	26910	62	18B
0005434406707	26910	63	18D
0005434406994	26910	64	18F
0005435293161	26910	65	19C
0005434406654	26910	66	19D
0005434406650	26910	67	19F
0005434406860	26910	68	20A
0005434406746	26910	69	20E
0005435293158	26910	70	20D
0005434406745	26910	71	21A
0005434406708	26910	72	21D
0005434406959	26910	73	21F
0005434299184	26910	74	21E
0005434406640	26910	75	22A
0005434406891	26910	76	22C
0005434406993	26910	77	22F
0005434406985	26910	78	23B
0005434299183	26910	79	23E
0005434406859	26910	80	23D
0005432604059	6438	1	1A
0005432604055	6438	2	1B
0005432604077	6438	3	1C
0005432604081	6438	4	1D
0005432604087	6438	5	2B
0005432604060	6438	6	2A
0005432604058	6438	7	2D
0005432604070	6438	8	3A
0005432604075	6438	9	3B
0005432604084	6438	10	3C
0005432604057	6438	11	3D
0005432604083	6438	12	4A
0005432604068	6438	13	4B
0005434512084	6438	14	4C
0005432604085	6438	15	4D
0005432604079	6438	16	5A
0005432604078	6438	17	5D
0005432604051	6438	18	6A
0005432604050	6438	19	6B
0005432604056	6438	20	6C
0005434512083	6438	21	6D
0005434512082	6438	22	7A
0005432604047	6438	23	7B
0005432604064	6438	24	7C
0005432604065	6438	25	7D
0005432604082	6438	26	18A
0005432604049	6438	27	18B
0005432604086	6438	28	18D
0005432604071	6438	29	19A
0005432604062	6438	30	19B
0005432604069	6438	31	19C
0005432604076	6438	32	19D
0005432604054	6438	33	20A
0005432604073	6438	34	20B
0005432604080	6438	35	20C
0005432604067	6438	36	20D
0005432604053	6438	37	21A
0005434512081	6438	38	21B
0005432604066	6438	39	21C
0005432604072	6438	40	21D
0005432604074	6438	41	22A
0005432604063	6438	42	22B
0005432604061	6438	43	22C
0005432604048	6438	44	22D
0005432604052	6438	45	23A
0005435218099	6438	46	23B
0005434512039	21361	1	1B
0005432603807	21361	2	1C
0005435221510	21361	3	1D
0005432603689	21361	4	2A
0005434512038	21361	5	2D
0005434512028	21361	6	3A
0005432603760	21361	7	3B
0005432603742	21361	8	3C
0005432603772	21361	9	4A
0005432603696	21361	10	4B
0005435221048	21361	11	4D
0005432603730	21361	12	5A
0005432603690	21361	13	5B
0005434512029	21361	14	5D
0005432603793	21361	15	6A
0005432603698	21361	16	6C
0005432603677	21361	17	6D
0005432603703	21361	18	7A
0005432603801	21361	19	7D
0005435221049	21361	20	18C
0005432603670	21361	21	18D
0005432603735	21361	22	19A
0005432603815	21361	23	19C
0005432603704	21361	24	20A
0005434512043	21361	25	20B
0005434512042	21361	26	20C
0005432603683	21361	27	20D
0005432603669	21361	28	21C
0005432603741	21361	29	22A
0005432603750	21361	30	22B
0005435221509	21361	31	22C
0005432603833	21361	32	22D
0005432603759	21361	33	23A
0005432603729	21361	34	23B
0005434906413	15014	1	1D
0005434906515	15014	2	1F
0005433251251	15014	3	3A
0005434906514	15014	4	3C
0005433251272	15014	5	3D
0005433251248	15014	6	3F
0005434906435	15014	7	4A
0005433251255	15014	8	4D
0005433251267	15014	9	4E
0005433251261	15014	10	4F
0005434906534	15014	11	5A
0005433251274	15014	12	5C
0005434906393	15014	13	5D
0005433251252	15014	14	5E
0005434906523	15014	15	6A
0005434906426	15014	16	6C
0005433251247	15014	17	6D
0005434906516	15014	18	6E
0005433251268	15014	19	6F
0005433251265	15014	20	7A
0005433251259	15014	21	7F
0005433251266	15014	22	8A
0005434906517	15014	23	8C
0005434906496	15014	24	8E
0005434906484	15014	25	9A
0005434906392	15014	26	9D
0005433251273	15014	27	9E
0005433251264	15014	28	9F
0005434906562	15014	29	10C
0005433251250	15014	30	10D
0005434906495	15014	31	10E
0005434906417	15014	32	10F
0005433251245	15014	33	11A
0005434906364	15014	34	11C
0005433251246	15014	35	11E
0005434906412	15014	36	11F
0005433251256	15014	37	12A
0005433251244	15014	38	12C
0005433251243	15014	39	12D
0005433251260	15014	40	12E
0005433251254	15014	41	12F
0005434906481	15014	42	13A
0005433251270	15014	43	13F
0005434906518	15014	44	14A
0005433251249	15014	45	14C
0005434906556	15014	46	14D
0005433251257	15014	47	14E
0005433251269	15014	48	14F
0005433251271	15014	49	15C
0005433251258	15014	50	15D
0005434906545	15014	51	16C
0005434906443	15014	52	16E
0005434906522	15014	53	16F
0005434906402	15014	54	17D
0005434906521	15014	55	17E
0005434906416	15014	56	18A
0005434906414	15014	57	18C
0005433251263	15014	58	18D
0005434906449	15014	59	18E
0005434906419	15014	60	18F
0005433251253	15014	61	19A
0005434906506	15014	62	19C
0005433251262	15014	63	19E
0005434906448	15014	64	20D
0005434906528	15014	65	20E
0005434906538	15014	66	20F
0005434906859	25853	1	1A
0005434906863	25853	2	1C
0005434906901	25853	3	1D
0005434906894	25853	4	1F
0005434906902	25853	5	2A
0005434906880	25853	6	2C
0005434906891	25853	7	2D
0005434906890	25853	8	3A
0005434906893	25853	9	3C
0005433250959	25853	10	3D
0005434906895	25853	11	3F
0005434906896	25853	12	4A
0005434906875	25853	13	4E
0005434906889	25853	14	4F
0005433251059	25853	15	5F
0005434906897	25853	16	6C
0005434906869	25853	17	6D
0005434906860	25853	18	6E
0005433250984	25853	19	7A
0005433250985	25853	20	7C
0005434906879	25853	21	7D
0005434906876	25853	22	7E
0005434906888	25853	23	7F
0005433251117	25853	24	8A
0005434906864	25853	25	8E
0005434906865	25853	26	9C
0005434906900	25853	27	9D
0005434906862	25853	28	9E
0005434906870	25853	29	9F
0005433251015	25853	30	10A
0005434906878	25853	31	10C
0005434906861	25853	32	10F
0005434906871	25853	33	11A
0005433250988	25853	34	11C
0005433251064	25853	35	11D
0005434906882	25853	36	11E
0005434906883	25853	37	12C
0005433251070	25853	38	12D
0005433250955	25853	39	12F
0005434906872	25853	40	13A
0005433251038	25853	41	13C
0005434906877	25853	42	13D
0005434906881	25853	43	13E
0005433251071	25853	44	13F
0005433251016	25853	45	14A
0005434906867	25853	46	14C
0005434906898	25853	47	14D
0005434906885	25853	48	14E
0005433250993	25853	49	15D
0005434906903	25853	50	15E
0005434906904	25853	51	16F
0005433251116	25853	52	17C
0005434906899	25853	53	17D
0005433250956	25853	54	17E
0005434906887	25853	55	17F
0005433251069	25853	56	18C
0005434906874	25853	57	18D
0005434906873	25853	58	19A
0005434906886	25853	59	19D
0005434906892	25853	60	19E
0005434906868	25853	61	20C
0005434906866	25853	62	20D
0005434906884	25853	63	20E
0005432609691	22467	1	1B
0005432607527	22467	2	1D
0005432609698	22467	3	2B
0005432607530	22467	4	2D
0005432607524	22467	5	3A
0005432609699	22467	6	3B
0005435841462	22467	7	4B
0005432607534	22467	8	4C
0005432607533	22467	9	4D
0005432609700	22467	10	5C
0005432607528	22467	11	5D
0005432609694	22467	12	6B
0005432609690	22467	13	6D
0005432609693	22467	14	7A
0005432607531	22467	15	7D
0005432607529	22467	16	18A
0005432609689	22467	17	18C
0005435842311	22467	18	18D
0005432607523	22467	19	19A
0005432609697	22467	20	19D
0005432607526	22467	21	20A
0005432609701	22467	22	20B
0005435842315	22467	23	21B
0005432607525	22467	24	21C
0005432607532	22467	25	22A
0005432609695	22467	26	22B
0005432609696	22467	27	22C
0005435842316	22467	28	23A
0005432609692	22467	29	23B
0005435841466	31728	1	1B
0005432609668	31728	2	1D
0005435841088	31728	3	2A
0005432609665	31728	4	2B
0005432609664	31728	5	2C
0005432613797	31728	6	2D
0005435841469	31728	7	3C
0005435841090	31728	8	4A
0005435841089	31728	9	5D
0005432613795	31728	10	6A
0005435841465	31728	11	7B
0005435841467	31728	12	7C
0005432613789	31728	13	7D
0005432613796	31728	14	18C
0005432613794	31728	15	19A
0005435841087	31728	16	20C
0005435841091	31728	17	20D
0005435841092	31728	18	21D
0005432609666	31728	19	22A
0005435841470	31728	20	22C
0005435841468	31728	21	23A
0005433008314	14187	1	1A
0005433008316	14187	2	1F
0005433008323	14187	3	2A
0005433008328	14187	4	3A
0005433008315	14187	5	3D
0005433008292	14187	6	3F
0005433008302	14187	7	4D
0005433008320	14187	8	5D
0005433008318	14187	9	5E
0005433008317	14187	10	5F
0005433008296	14187	11	6C
0005433008321	14187	12	6E
0005433008297	14187	13	7C
0005433008291	14187	14	7E
0005433008329	14187	15	7F
0005433008300	14187	16	8E
0005433008287	14187	17	10A
0005433008332	14187	18	10D
0005433008307	14187	19	10F
0005433008309	14187	20	11C
0005433008313	14187	21	11E
0005433008294	14187	22	11F
0005433008301	14187	23	12C
0005433008299	14187	24	12E
0005433008304	14187	25	13C
0005433008308	14187	26	13E
0005433008327	14187	27	13F
0005433008325	14187	28	14D
0005433008288	14187	29	14E
0005433008303	14187	30	14F
0005433008322	14187	31	15A
0005433008306	14187	32	15D
0005433008305	14187	33	15E
0005433008310	14187	34	15F
0005433008312	14187	35	16D
0005433008290	14187	36	16F
0005433008311	14187	37	17D
0005433008295	14187	38	17E
0005433008293	14187	39	18A
0005433008298	14187	40	18D
0005433008289	14187	41	18F
0005433008286	14187	42	19A
0005433008324	14187	43	19D
0005433008331	14187	44	19F
0005433008326	14187	45	20A
0005433008330	14187	46	20C
0005433008319	14187	47	20D
0005433810515	22854	1	1C
0005433008113	22854	2	1D
0005433007844	22854	3	1F
0005433007939	22854	4	3A
0005433810517	22854	5	3C
0005433008049	22854	6	3D
0005433007954	22854	7	4D
0005433008043	22854	8	4E
0005433008129	22854	9	4F
0005433008045	22854	10	5A
0005433008023	22854	11	5C
0005433008130	22854	12	5F
0005433008050	22854	13	6F
0005433007831	22854	14	8A
0005433007862	22854	15	8E
0005433810516	22854	16	9E
0005433007974	22854	17	10C
0005433007975	22854	18	10D
0005433007863	22854	19	11A
0005433007826	22854	20	11D
0005433007928	22854	21	11E
0005433007872	22854	22	13D
0005433008001	22854	23	14C
0005433007891	22854	24	14D
0005433007830	22854	25	14E
0005433007938	22854	26	14F
0005433008022	22854	27	15A
0005433008042	22854	28	15C
0005433008000	22854	29	15E
0005433007827	22854	30	15D
0005433007913	22854	31	17A
0005433008114	22854	32	18A
0005433008013	22854	33	18C
0005433007968	22854	34	19C
0005434925284	14916	1	1D
0005434925309	14916	2	5C
0005434925336	14916	3	6E
0005434925267	14916	4	9D
0005434925308	14916	5	9E
0005434925257	14916	6	11A
0005434925307	14916	7	11F
0005434925269	14916	8	12D
0005434925329	14916	9	14C
0005434925268	14916	10	14E
0005434925317	14916	11	15E
0005434925313	14916	12	15F
0005434925335	14916	13	16F
0005434925324	14916	14	17A
0005434925315	14916	15	19F
0005434925566	20523	1	1F
0005434925548	20523	2	2C
0005434925539	20523	3	2D
0005434925568	20523	4	2F
0005434925547	20523	5	3A
0005434925544	20523	6	3C
0005434925558	20523	7	3D
0005434925562	20523	8	4A
0005434925571	20523	9	4C
0005434925552	20523	10	4F
0005434925555	20523	11	6A
0005434925536	20523	12	6F
0005434925556	20523	13	7A
0005434925557	20523	14	7D
0005434925540	20523	15	7E
0005434925538	20523	16	7F
0005434925541	20523	17	8A
0005434925561	20523	18	8E
0005434925543	20523	19	9A
0005434925537	20523	20	10C
0005434925545	20523	21	10F
0005434925570	20523	22	11D
0005434925549	20523	23	11E
0005434925559	20523	24	12A
0005434925535	20523	25	13F
0005434925553	20523	26	14C
0005434925533	20523	27	14F
0005434925542	20523	28	15D
0005434925551	20523	29	15E
0005434925550	20523	30	16A
0005434925563	20523	31	16C
0005434925567	20523	32	17C
0005434925565	20523	33	18A
0005434925534	20523	34	18E
0005434925546	20523	35	19A
0005434925564	20523	36	19C
0005434925560	20523	37	20C
0005434925554	20523	38	20D
0005434925569	20523	39	20E
0005435487676	15817	1	1A
0005435487690	15817	2	1B
0005435998991	15817	3	2B
0005435487683	15817	4	2C
0005435487696	15817	5	2D
0005435487688	15817	6	3A
0005435487685	15817	7	3B
0005435487686	15817	8	3C
0005435998961	15817	9	3D
0005435998953	15817	10	4A
0005435487677	15817	11	4B
0005435487682	15817	12	5A
0005435487678	15817	13	6B
0005435487691	15817	14	6C
0005435998983	15817	15	6D
0005435998979	15817	16	7A
0005435487679	15817	17	7B
0005435487695	15817	18	7C
0005435487692	15817	19	18B
0005435998996	15817	20	18C
0005435487684	15817	21	18D
0005435487689	15817	22	19A
0005435487687	15817	23	19C
0005435487694	15817	24	20A
0005435487681	15817	25	20C
0005435487680	15817	26	21A
0005435998951	15817	27	21B
0005435998965	15817	28	21C
0005435487693	15817	29	21D
0005435998952	15817	30	22C
0005435998995	15817	31	23A
0005435999115	19665	1	1A
0005435487480	19665	2	2A
0005435999123	19665	3	2D
0005435487457	19665	4	3A
0005435999117	19665	5	3C
0005435999126	19665	6	3D
0005435999112	19665	7	4A
0005435999114	19665	8	4C
0005435487508	19665	9	4D
0005435487464	19665	10	5A
0005435487479	19665	11	5B
0005435487467	19665	12	5C
0005435999121	19665	13	5D
0005435999124	19665	14	6A
0005435999128	19665	15	6D
0005435487456	19665	16	7C
0005435999119	19665	17	7D
0005435999125	19665	18	18A
0005435999116	19665	19	18B
0005435487465	19665	20	18D
0005435999118	19665	21	19A
0005435487459	19665	22	20A
0005435999120	19665	23	20B
0005435487458	19665	24	20C
0005435999113	19665	25	20D
0005435487466	19665	26	21A
0005435487489	19665	27	21C
0005435487475	19665	28	22B
0005435999122	19665	29	22C
0005435999127	19665	30	22D
0005435487463	19665	31	23A
0005435472521	5978	1	1C
0005435839252	5978	2	1A
0005432659692	5978	3	2A
0005435472522	5978	4	2F
0005435839268	5978	5	3D
0005435839273	5978	6	3C
0005435839266	5978	7	4A
0005435839253	5978	8	4C
0005435839250	5978	9	4F
0005435472554	5978	10	6A
0005435472571	5978	11	6C
0005435839263	5978	12	7B
0005432142230	5978	13	7F
0005432658578	5978	14	8B
0005435839265	5978	15	8D
0005435839261	5978	16	8C
0005435839254	5978	17	9A
0005435839257	5978	18	9C
0005432660805	5978	19	9F
0005432142229	5978	20	10C
0005435839249	5978	21	10B
0005435839269	5978	22	10E
0005435472513	5978	23	11C
0005435472569	5978	24	11B
0005432659693	5978	25	12B
0005435472560	5978	26	13A
0005435839251	5978	27	12F
0005435839264	5978	28	13C
0005435839259	5978	29	13B
0005435472570	5978	30	14C
0005435839256	5978	31	14B
0005435839248	5978	32	15A
0005435839258	5978	33	16C
0005432660804	5978	34	16E
0005435839271	5978	35	16F
0005435839272	5978	36	17A
0005435839247	5978	37	18E
0005435839262	5978	38	18F
0005435472547	5978	39	19C
0005435839260	5978	40	19B
0005432142231	5978	41	19E
0005435839267	5978	42	20B
0005435472535	5978	43	20A
0005435839270	5978	44	20D
0005435839255	5978	45	20C
0005435472561	5978	46	21A
0005435472555	5978	47	21B
0005435838996	18090	1	1A
0005435472686	18090	2	1F
0005435472688	18090	3	1D
0005435839020	18090	4	2C
0005435839017	18090	5	2D
0005435472689	18090	6	3D
0005435839008	18090	7	4A
0005435838995	18090	8	4D
0005435839024	18090	9	5C
0005435839032	18090	10	5A
0005435472684	18090	11	6F
0005435472695	18090	12	7E
0005435839047	18090	13	7F
0005435472687	18090	14	8A
0005435838991	18090	15	9B
0005435472691	18090	16	9D
0005435472683	18090	17	9F
0005435839044	18090	18	10A
0005435839079	18090	19	10C
0005435472696	18090	20	11D
0005432537044	18090	21	12C
0005435839009	18090	22	12F
0005435838977	18090	23	12E
0005435472693	18090	24	12D
0005435839058	18090	25	13C
0005435839086	18090	26	13B
0005435839021	18090	27	13E
0005435838992	18090	28	13F
0005435472682	18090	29	14E
0005435839015	18090	30	15A
0005435838966	18090	31	15E
0005435839043	18090	32	16A
0005435838985	18090	33	16C
0005435472694	18090	34	16B
0005435839018	18090	35	16F
0005435838972	18090	36	16E
0005435839016	18090	37	17B
0005435472685	18090	38	17C
0005435839012	18090	39	18B
0005435839003	18090	40	18C
0005435472692	18090	41	18F
0005435839078	18090	42	19B
0005435839087	18090	43	20A
0005435838974	18090	44	20C
0005435472681	18090	45	20E
0005435472690	18090	46	21D
0005433284837	23011	1	3F
0005433284803	23011	2	5B
0005433284901	23011	3	5A
0005435103869	23011	4	5D
0005433284776	23011	5	5C
0005435103877	23011	6	5E
0005435103873	23011	7	6A
0005433284844	23011	8	6E
0005435103872	23011	9	7F
0005433284814	23011	10	8B
0005433284799	23011	11	8C
0005433284900	23011	12	8E
0005433284983	23011	13	9C
0005435103875	23011	14	9E
0005433284843	23011	15	10C
0005433284883	23011	16	11D
0005435103874	23011	17	13D
0005433284917	23011	18	14B
0005433284812	23011	19	14C
0005433284853	23011	20	14E
0005433284896	23011	21	15B
0005433284854	23011	22	15D
0005435103868	23011	23	16D
0005435103870	23011	24	16E
0005433284934	23011	25	17B
0005433284910	23011	26	17F
0005433284813	23011	27	18C
0005433284849	23011	28	19A
0005435103867	23011	29	19F
0005435103876	23011	30	20B
0005433284804	23011	31	21B
0005433284800	23011	32	21D
0005435103871	23011	33	23B
0005433284784	23011	34	23C
0005433285075	32089	1	2A
0005433285071	32089	2	1F
0005433285082	32089	3	2C
0005433285073	32089	4	3A
0005433285087	32089	5	4D
0005433285079	32089	6	4E
0005433285084	32089	7	5E
0005433285080	32089	8	6D
0005433285097	32089	9	6F
0005435103800	32089	10	7E
0005433285072	32089	11	7D
0005435103799	32089	12	7F
0005433285089	32089	13	8B
0005433285081	32089	14	9B
0005433285078	32089	15	9F
0005433285093	32089	16	10D
0005435103797	32089	17	10E
0005433285088	32089	18	11B
0005433285096	32089	19	12B
0005433285102	32089	20	12C
0005433285076	32089	21	12F
0005433285090	32089	22	13C
0005433285086	32089	23	13D
0005433285095	32089	24	14C
0005433285091	32089	25	14B
0005433285094	32089	26	16B
0005435103802	32089	27	16D
0005433285099	32089	28	17C
0005435103793	32089	29	18F
0005433285101	32089	30	19A
0005433285074	32089	31	19F
0005433285098	32089	32	20C
0005433285085	32089	33	21F
0005433285092	32089	34	22A
0005433285083	32089	35	23A
0005433285100	32089	36	22F
0005433285077	32089	37	23F
0005433475639	23859	1	1B
0005433475634	23859	2	2A
0005435852558	23859	3	2B
0005433475635	23859	4	2D
0005435852556	23859	5	3A
0005433475630	23859	6	4A
0005435852554	23859	7	5A
0005433475659	23859	8	7B
0005435852555	23859	9	19C
0005435852557	23859	10	20B
0005435852553	23859	11	21C
0005433475631	23859	12	22B
0005432526356	30619	1	1A
0005435213123	30619	2	1D
0005432525681	30619	3	2A
0005433656650	30619	4	1H
0005434066520	30619	5	2C
0005435213098	30619	6	2G
0005432526327	30619	7	3A
0005432526205	30619	8	2K
0005435213105	30619	9	3D
0005435213107	30619	10	3K
0005435213137	30619	11	3H
0005434066545	30619	12	4G
0005434066593	30619	13	4D
0005432428881	30619	14	4K
0005434066562	30619	15	5C
0005435630948	30619	16	5A
0005435213093	30619	17	5H
0005434066461	30619	18	5G
0005432525870	30619	19	11A
0005432525935	30619	20	5K
0005432526020	30619	21	11D
0005433656649	30619	22	11E
0005435213109	30619	23	11K
0005435213153	30619	24	11G
0005435213159	30619	25	12C
0005435213126	30619	26	12A
0005432526206	30619	27	12D
0005432526316	30619	28	12G
0005432535766	30619	29	12K
0005434066409	30619	30	12H
0005434066322	30619	31	13C
0005432525643	30619	32	13F
0005434066771	30619	33	13E
0005435725571	30619	34	13K
0005435213111	30619	35	13H
0005435213106	30619	36	13G
0005434066381	30619	37	14A
0005432525891	30619	38	14E
0005432526369	30619	39	14F
0005434066382	30619	40	14K
0005432526095	30619	41	15F
0005435213118	30619	42	15D
0005432525826	30619	43	15H
0005432159830	30619	44	15G
0005432526325	30619	45	16A
0005435213155	30619	46	15K
0005435213143	30619	47	16D
0005432526357	30619	48	16C
0005435213100	30619	49	16F
0005432526403	30619	50	16E
0005432525862	30619	51	16K
0005435725567	30619	52	17E
0005434066616	30619	53	17D
0005432526015	30619	54	17C
0005432526017	30619	55	17G
0005434066642	30619	56	17F
0005433656652	30619	57	18A
0005435213128	30619	58	17H
0005435725568	30619	59	18E
0005434066458	30619	60	18F
0005434066473	30619	61	18J
0005435213157	30619	62	19B
0005432526231	30619	63	19A
0005432525863	30619	64	18K
0005434066398	30619	65	19H
0005432525792	30619	66	19G
0005432159828	30619	67	19J
0005432526071	30619	68	20C
0005435213154	30619	69	20A
0005434066475	30619	70	20E
0005432526309	30619	71	20D
0005435213140	30619	72	20H
0005432526399	30619	73	20G
0005435213131	30619	74	20K
0005435213127	30619	75	21A
0005434066366	30619	76	21D
0005432526264	30619	77	21C
0005435213151	30619	78	21G
0005434066477	30619	79	21J
0005435213142	30619	80	22A
0005432526324	30619	81	21K
0005435213150	30619	82	22C
0005435213099	30619	83	22B
0005432526135	30619	84	22F
0005432525845	30619	85	22E
0005432535754	30619	86	22D
0005432526163	30619	87	22G
0005432526043	30619	88	22J
0005435213091	30619	89	23B
0005432526300	30619	90	22K
0005434066489	30619	91	23E
0005432159829	30619	92	23D
0005432525951	30619	93	23G
0005432526574	30619	94	23F
0005432526247	30619	95	23J
0005434066392	30619	96	23K
0005435630949	30619	97	24F
0005432525906	30619	98	24E
0005432525825	30619	99	25B
0005432428882	30619	100	25A
0005432537033	30619	101	25C
0005432526459	30619	102	25F
0005435213108	30619	103	25E
0005434066537	30619	104	25H
0005435213146	30619	105	25G
0005434066538	30619	106	25K
0005435213113	30619	107	26B
0005432533243	30619	108	26E
0005432211456	30619	109	26D
0005435213110	30619	110	26G
0005432526159	30619	111	26F
0005432525769	30619	112	26H
0005432526290	30619	113	27A
0005432535767	30619	114	27D
0005435213104	30619	115	27C
0005435213121	30619	116	27B
0005434066779	30619	117	27E
0005433656651	30619	118	27H
0005434066631	30619	119	27G
0005432525642	30619	120	27K
0005435213094	30619	121	27J
0005432526182	30619	122	28B
0005432526126	30619	123	28E
0005435213133	30619	124	28G
0005435213103	30619	125	28F
0005432211454	30619	126	28J
0005432526019	30619	127	29A
0005432526329	30619	128	29C
0005432428880	30619	129	29F
0005435213145	30619	130	29K
0005434066377	30619	131	30B
0005435213135	30619	132	30A
0005432159827	30619	133	30D
0005432526137	30619	134	30F
0005435213147	30619	135	30J
0005432535755	30619	136	31B
0005434066355	30619	137	30K
0005434066825	30619	138	31C
0005432526301	30619	139	31E
0005435213117	30619	140	31H
0005435213116	30619	141	31K
0005432525997	30619	142	31J
0005432526281	30619	143	32B
0005434066572	30619	144	32A
0005432526550	30619	145	32D
0005434066617	30619	146	32G
0005432526069	30619	147	32J
0005435213115	30619	148	32K
0005435213156	30619	149	33D
0005435213138	30619	150	33B
0005432526154	30619	151	33E
0005435213134	30619	152	33H
0005434066502	30619	153	33G
0005432526282	30619	154	34A
0005434066314	30619	155	33K
0005435213096	30619	156	33J
0005434066493	30619	157	34C
0005434066564	30619	158	34B
0005432525734	30619	159	34G
0005435213095	30619	160	34K
0005432526006	30619	161	34J
0005434066472	30619	162	35B
0005434066455	30619	163	35A
0005432525937	30619	164	35C
0005432526169	30619	165	35F
0005432526086	30619	166	35E
0005432526051	30619	167	35H
0005434066641	30619	168	36A
0005435213097	30619	169	35K
0005432526120	30619	170	36C
0005432526100	30619	171	36B
0005432526526	30619	172	36F
0005435213114	30619	173	36E
0005432525791	30619	174	36D
0005435213125	30619	175	36H
0005435725570	30619	176	36K
0005434066383	30619	177	36J
0005432526119	30619	178	37D
0005432526573	30619	179	37C
0005432211457	30619	180	37F
0005435213119	30619	181	37J
0005432211450	30619	182	37H
0005435213141	30619	183	38C
0005435213112	30619	184	38B
0005432526572	30619	185	38K
0005432526166	30619	186	38J
0005435213102	30619	187	39A
0005432525938	30619	188	39D
0005435213139	30619	189	39C
0005432526328	30619	190	39F
0005432526070	30619	191	39E
0005435213158	30619	192	39J
0005435213148	30619	193	39K
0005434066565	30619	194	40C
0005432526236	30619	195	40E
0005432211453	30619	196	40D
0005432525680	30619	197	40G
0005434066448	30619	198	40F
0005432526033	30619	199	40J
0005432525890	30619	200	40H
0005432537035	30619	201	41B
0005435725572	30619	202	41A
0005432526029	30619	203	41D
0005432526273	30619	204	41C
0005432525844	30619	205	41E
0005434066492	30619	206	41J
0005434066389	30619	207	41G
0005434066393	30619	208	42A
0005434066712	30619	209	41K
0005434066344	30619	210	42C
0005432211451	30619	211	42B
0005432159826	30619	212	42D
0005435213120	30619	213	42G
0005435725569	30619	214	42F
0005434066524	30619	215	42K
0005432211452	30619	216	42J
0005435213132	30619	217	42H
0005435213122	30619	218	43B
0005435213130	30619	219	43D
0005432525704	30619	220	43F
0005432533244	30619	221	43E
0005434066601	30619	222	43J
0005434066405	30619	223	43H
0005434066630	30619	224	43G
0005435213160	30619	225	44B
0005432526525	30619	226	44A
0005432526207	30619	227	44D
0005432526321	30619	228	44H
0005434066356	30619	229	44F
0005435213101	30619	230	44K
0005432525770	30619	231	44J
0005432428869	30619	232	45B
0005434066315	30619	233	45A
0005435213136	30619	234	45D
0005432525827	30619	235	45C
0005432535753	30619	236	45F
0005432525676	30619	237	45J
0005432525713	30619	238	45H
0005432525922	30619	239	45G
0005435213129	30619	240	46A
0005432526350	30619	241	45K
0005434066437	30619	242	46C
0005434066501	30619	243	46E
0005432526502	30619	244	46D
0005434066454	30619	245	46G
0005434066585	30619	246	46F
0005435213149	30619	247	46J
0005435213144	30619	248	47A
0005432526436	30619	249	47E
0005435213092	30619	250	47F
0005435213124	30619	251	47K
0005432526483	30619	252	48C
0005432211455	30619	253	48A
0005434066401	30619	254	48F
0005432526085	30619	255	48D
0005432526164	30619	256	48H
0005432525635	30619	257	48G
0005432525996	30619	258	49C
0005432525793	30619	259	48K
0005435213152	30619	260	49E
0005432526458	30619	261	49F
0005432526123	30619	262	50E
0005432526034	30619	263	50G
0005434066323	30619	264	50F
0005432537034	30619	265	50K
0005432526127	30619	266	51E
0005432525705	30619	267	51D
0005432525783	30619	268	51G
0005433367646	24825	1	1C
0005435652479	24825	2	1F
0005435652464	24825	3	1D
0005433367663	24825	4	2A
0005433367664	24825	5	2D
0005435652256	24825	6	3A
0005433367650	24825	7	3D
0005433367675	24825	8	3F
0005433367643	24825	9	4C
0005435652340	24825	10	4D
0005433367672	24825	11	4E
0005433367670	24825	12	4F
0005435652333	24825	13	5A
0005435652386	24825	14	5C
0005433367678	24825	15	5F
0005433367673	24825	16	6A
0005433367674	24825	17	6D
0005433367648	24825	18	6E
0005435652456	24825	19	6F
0005433367668	24825	20	7A
0005433367660	24825	21	7C
0005435652348	24825	22	7D
0005435652435	24825	23	8A
0005435652452	24825	24	8C
0005433367677	24825	25	8D
0005435652461	24825	26	8E
0005435652445	24825	27	9A
0005435652275	24825	28	9C
0005435652463	24825	29	10A
0005435652332	24825	30	10E
0005435652330	24825	31	10F
0005433367641	24825	32	11D
0005435652457	24825	33	11E
0005435652414	24825	34	12A
0005435652480	24825	35	12C
0005433367662	24825	36	12D
0005435652329	24825	37	12E
0005433367659	24825	38	12F
0005433367656	24825	39	13A
0005433367644	24825	40	13C
0005433367658	24825	41	13D
0005435652331	24825	42	13E
0005433367676	24825	43	13F
0005435652384	24825	44	14A
0005435652501	24825	45	14C
0005435652468	24825	46	14D
0005433367645	24825	47	14F
0005435652453	24825	48	15A
0005435652454	24825	49	15C
0005433367661	24825	50	15D
0005435652343	24825	51	15E
0005435652455	24825	52	15F
0005435652357	24825	53	16A
0005433367652	24825	54	16C
0005433367657	24825	55	16D
0005433367649	24825	56	16F
0005433367671	24825	57	17A
0005435652523	24825	58	17C
0005435652478	24825	59	17D
0005433367647	24825	60	17F
0005435652469	24825	61	18A
0005433367666	24825	62	18C
0005433367654	24825	63	18D
0005433367655	24825	64	18E
0005433367667	24825	65	19A
0005435652444	24825	66	19C
0005435652288	24825	67	19D
0005435652408	24825	68	19F
0005433367665	24825	69	19E
0005433367651	24825	70	20A
0005433367653	24825	71	20C
0005433367642	24825	72	20D
0005433367669	24825	73	20E
0005435949736	23321	1	3A
0005435949733	23321	2	5B
0005435949734	23321	3	6A
0005435949748	23321	4	18C
0005435949738	23321	5	21B
0005435949732	23321	6	22A
0005435949737	23321	7	22D
0005435949742	23321	8	23A
0005434979602	2039	1	1A
0005434979596	2039	2	1B
0005435801679	2039	3	1C
0005434979612	2039	4	1D
0005434979611	2039	5	2A
0005434979615	2039	6	2B
0005434979592	2039	7	3B
0005434979603	2039	8	3C
0005434979607	2039	9	3D
0005434979599	2039	10	4A
0005434979597	2039	11	4C
0005434979609	2039	12	5B
0005434979621	2039	13	5C
0005434979614	2039	14	5D
0005434979604	2039	15	6A
0005434979606	2039	16	6B
0005435801677	2039	17	7A
0005434979610	2039	18	7B
0005434979620	2039	19	7C
0005434979598	2039	20	7D
0005434979618	2039	21	18A
0005434979616	2039	22	18B
0005434979595	2039	23	18C
0005434979608	2039	24	18D
0005434979600	2039	25	19A
0005434979601	2039	26	19B
0005435801678	2039	27	19C
0005434979619	2039	28	20B
0005435801676	2039	29	20D
0005434979613	2039	30	21A
0005434979594	2039	31	21C
0005434979605	2039	32	22A
0005434979593	2039	33	22D
0005434979617	2039	34	23A
0005435801654	23550	1	1A
0005434979289	23550	2	1B
0005434979294	23550	3	1C
0005434979342	23550	4	2A
0005434979458	23550	5	2C
0005434979391	23550	6	2D
0005434979268	23550	7	3A
0005434979269	23550	8	3B
0005435801645	23550	9	3C
0005434979288	23550	10	3D
0005434979284	23550	11	4A
0005434979357	23550	12	4C
0005434979307	23550	13	4D
0005434979279	23550	14	5B
0005434979382	23550	15	5C
0005434979349	23550	16	5D
0005434979308	23550	17	6A
0005434979309	23550	18	6B
0005434979381	23550	19	7B
0005434979290	23550	20	7D
0005435801650	23550	21	18A
0005434979355	23550	22	18B
0005435801647	23550	23	18C
0005434979348	23550	24	18D
0005435801649	23550	25	19C
0005435801653	23550	26	20C
0005434979380	23550	27	21B
0005434979457	23550	28	21C
0005434979271	23550	29	21D
0005434979266	23550	30	22A
0005434979267	23550	31	22C
0005434979276	23550	32	22D
0005434979310	23550	33	23A
0005434979372	23550	34	23B
0005434952507	2577	1	1B
0005434952509	2577	2	3B
0005434952508	2577	3	4B
0005434952506	2577	4	6A
0005433256386	2578	1	3B
0005433256408	28223	1	3B
0005434952475	28223	2	4B
0005433256409	28223	3	5A
0005434952476	28223	4	6A
0005433112364	19792	1	1B
0005433111493	19792	2	2A
0005433111494	19792	3	2B
0005433111495	19792	4	5B
0005433112363	19792	5	6A
0005433111492	19792	6	6B
0005434137051	11927	1	1A
0005434136947	11927	2	1C
0005434136724	11927	3	1D
0005434136845	11927	4	1F
0005434136956	11927	5	2A
0005434136937	11927	6	2C
0005434136825	11927	7	2D
0005434136940	11927	8	3A
0005434136826	11927	9	3C
0005434137052	11927	10	3F
0005434136935	11927	11	4C
0005434137006	11927	12	4D
0005434136988	11927	13	4E
0005434137087	11927	14	4F
0005434137044	11927	15	5C
0005434136689	11927	16	5D
0005434136946	11927	17	5E
0005434136682	11927	18	5F
0005434136931	11927	19	6A
0005434137027	11927	20	6D
0005434137080	11927	21	6E
0005434137153	11927	22	6F
0005434137025	11927	23	7A
0005434136979	11927	24	7C
0005434136977	11927	25	7D
0005434137331	11927	26	7E
0005434136936	11927	27	7F
0005434137071	11927	28	8C
0005434136941	11927	29	8D
0005434137310	11927	30	8E
0005434136764	11927	31	8F
0005434137075	11927	32	9A
0005434136980	11927	33	9C
0005434136814	11927	34	9E
0005434137140	11927	35	9F
0005434137094	11927	36	10A
0005434137074	11927	37	10C
0005434137079	11927	38	10D
0005434137242	11927	39	10F
0005434137122	11927	40	11A
0005434136838	11927	41	11C
0005434136932	11927	42	11E
0005434136754	11927	43	12A
0005434137012	11927	44	12C
0005434136813	11927	45	12D
0005434136725	11927	46	12E
0005434136874	11927	47	12F
0005434136889	11927	48	13A
0005434137095	11927	49	13C
0005434137098	11927	50	13D
0005434137193	11927	51	13E
0005434136818	11927	52	13F
0005434137254	11927	53	14A
0005434137165	11927	54	14C
0005434136891	11927	55	14D
0005434137082	11927	56	15D
0005434136968	11927	57	15E
0005434136783	11927	58	15F
0005434137232	11927	59	16A
0005434137028	11927	60	16D
0005434137007	11927	61	16E
0005434136765	11927	62	16F
0005434137113	11927	63	17A
0005434136766	11927	64	17C
0005434137176	11927	65	17D
0005434137127	11927	66	17E
0005434136837	11927	67	17F
0005434137086	11927	68	18A
0005434136978	11927	69	18C
0005434136976	11927	70	18E
0005434137241	11927	71	18F
0005434137332	11927	72	19A
0005434137443	11927	73	19C
0005434137253	11927	74	19E
0005434137081	11927	75	19F
0005434137128	11927	76	20C
0005434137131	11927	77	20D
0005434136787	11927	78	20E
0005434137538	28757	1	1A
0005434137566	28757	2	1C
0005434137613	28757	3	1D
0005434137611	28757	4	1F
0005434137608	28757	5	2A
0005434137574	28757	6	2C
0005434137563	28757	7	2D
0005434137595	28757	8	3A
0005434137615	28757	9	3D
0005434137562	28757	10	3F
0005434137589	28757	11	4A
0005434137618	28757	12	4C
0005434137619	28757	13	4D
0005434137590	28757	14	4E
0005434137539	28757	15	4F
0005434137545	28757	16	5A
0005434137579	28757	17	5C
0005434137580	28757	18	5E
0005434137555	28757	19	5F
0005434137601	28757	20	6A
0005434137543	28757	21	6C
0005434137610	28757	22	6D
0005434137577	28757	23	6F
0005434137606	28757	24	7C
0005434137592	28757	25	7D
0005434137553	28757	26	7E
0005434137616	28757	27	7F
0005434137607	28757	28	8A
0005434137558	28757	29	8C
0005434137564	28757	30	8D
0005434137585	28757	31	8E
0005434137600	28757	32	8F
0005434137593	28757	33	9A
0005434137573	28757	34	9C
0005434137581	28757	35	9D
0005434137582	28757	36	9E
0005434137565	28757	37	9F
0005434137622	28757	38	10A
0005434137597	28757	39	10C
0005434137542	28757	40	10D
0005434137568	28757	41	10F
0005434137591	28757	42	11A
0005434137559	28757	43	11C
0005434137550	28757	44	11D
0005434137621	28757	45	11E
0005434137570	28757	46	11F
0005434137614	28757	47	12C
0005434137554	28757	48	12D
0005434137567	28757	49	12E
0005434137578	28757	50	13A
0005434137575	28757	51	13C
0005434137571	28757	52	13D
0005434137551	28757	53	13E
0005434137604	28757	54	13F
0005434137547	28757	55	14A
0005434137557	28757	56	14C
0005434137602	28757	57	14D
0005434137540	28757	58	14E
0005434137587	28757	59	14F
0005434137572	28757	60	15A
0005434137588	28757	61	15C
0005434137561	28757	62	15D
0005434137544	28757	63	15F
0005434137599	28757	64	16A
0005434137576	28757	65	16C
0005434137620	28757	66	16D
0005434137586	28757	67	16E
0005434137617	28757	68	17A
0005434137583	28757	69	17C
0005434137546	28757	70	17D
0005434137584	28757	71	17E
0005434137549	28757	72	17F
0005434137612	28757	73	18C
0005434137552	28757	74	18D
0005434137605	28757	75	18E
0005434137548	28757	76	18F
0005434137541	28757	77	19A
0005434137556	28757	78	19C
0005434137603	28757	79	19D
0005434137594	28757	80	19E
0005434137569	28757	81	19F
0005434137609	28757	82	20A
0005434137596	28757	83	20C
0005434137560	28757	84	20D
0005434137623	28757	85	20E
0005434137598	28757	86	20F
0005435312771	6581	1	1A
0005434466430	6581	2	2B
0005434466426	6581	3	4A
0005434466429	6581	4	5C
0005435312768	6581	5	5D
0005434466428	6581	6	6A
0005434466431	6581	7	18A
0005434466427	6581	8	18C
0005434466432	6581	9	21C
0005435312767	6581	10	22A
0005434513543	19099	1	1D
0005434190391	19099	2	2B
0005434516049	19099	3	3A
0005434516047	19099	4	3D
0005434190385	19099	5	4C
0005434513546	19099	6	5A
0005434190389	19099	7	5C
0005434513538	19099	8	6B
0005434513537	19099	9	7A
0005434513539	19099	10	7B
0005434190386	19099	11	18B
0005434190388	19099	12	19D
0005434513545	19099	13	20A
0005434516050	19099	14	20B
0005434190387	19099	15	20D
0005434190390	19099	16	21A
0005434513542	19099	17	21B
0005434190392	19099	18	22B
0005433538817	6815	1	1A
0005435259701	6815	2	1C
0005433538814	6815	3	2C
0005435259690	6815	4	3B
0005433534484	6815	5	3D
0005433538822	6815	6	4D
0005435259692	6815	7	5A
0005433534485	6815	8	5B
0005433538820	6815	9	6A
0005433538815	6815	10	6B
0005435259691	6815	11	6C
0005433538819	6815	12	7D
0005433538813	6815	13	18A
0005433538816	6815	14	18C
0005433538821	6815	15	19B
0005435259693	6815	16	19C
0005433538818	6815	17	20B
0005435259689	6815	18	21A
0005435259704	6815	19	21D
0005435259705	6815	20	22C
0005433538742	25017	1	1D
0005435259731	25017	2	2A
0005433534460	25017	3	3C
0005433534469	25017	4	4D
0005433538748	25017	5	6A
0005435259730	25017	6	18C
0005433538718	25017	7	19B
0005433538758	25017	8	20B
0005435259729	25017	9	20C
0005433538757	25017	10	21D
0005433538717	25017	11	22A
0005435259728	25017	12	23A
0005432922462	808	1	2A
0005432922461	808	2	3B
0005433511903	808	3	3C
0005433511901	808	4	4C
0005433511902	808	5	5A
0005433511899	808	6	5C
0005432922456	808	7	7D
0005433511900	808	8	19D
0005433511898	808	9	20A
0005432922464	808	10	21D
0005433511897	808	11	22B
0005433511829	16174	1	2B
0005433511844	16174	2	4C
0005432922499	16174	3	5D
0005432922498	16174	4	6A
0005433511869	16174	5	6C
0005433511846	16174	6	19C
0005432922500	16174	7	20A
0005432922501	16174	8	20C
0005433511830	16174	9	21C
0005433511831	16174	10	22B
0005435697162	3665	1	1A
0005435697177	3665	2	1C
0005435697159	3665	3	1D
0005435697166	3665	4	2B
0005435697179	3665	5	2C
0005435697170	3665	6	2D
0005435697165	3665	7	3A
0005435697163	3665	8	3C
0005435697178	3665	9	3D
0005435697172	3665	10	4B
0005434950504	3665	11	4A
0005435697186	3665	12	4C
0005435935003	3665	13	4D
0005435697164	3665	14	5A
0005435697185	3665	15	5D
0005435697168	3665	16	6A
0005435697174	3665	17	6C
0005435697182	3665	18	6D
0005435935005	3665	19	7A
0005435935004	3665	20	7B
0005435697180	3665	21	7C
0005435697161	3665	22	7D
0005435935007	3665	23	18A
0005434950501	3665	24	18B
0005435697183	3665	25	18C
0005434950502	3665	26	18D
0005435697175	3665	27	19A
0005435697160	3665	28	19C
0005435935016	3665	29	19D
0005435697173	3665	30	20C
0005435697176	3665	31	21A
0005435697167	3665	32	21B
0005434950503	3665	33	21C
0005435697171	3665	34	21D
0005435697187	3665	35	22B
0005435697184	3665	36	22C
0005435697169	3665	37	22D
0005435697181	3665	38	23A
0005434950500	3665	39	23B
0005434950462	16258	1	1B
0005435696992	16258	2	1C
0005435696963	16258	3	1D
0005435696998	16258	4	2A
0005435916150	16258	5	2B
0005435935021	16258	6	2C
0005435916151	16258	7	2D
0005435696873	16258	8	3A
0005435696900	16258	9	3C
0005435935022	16258	10	3D
0005435696903	16258	11	4A
0005435696997	16258	12	5C
0005434950463	16258	13	5D
0005435696955	16258	14	6A
0005435696999	16258	15	6B
0005435696902	16258	16	6C
0005435696913	16258	17	6D
0005435696899	16258	18	7A
0005435696956	16258	19	7B
0005435696911	16258	20	18B
0005435935020	16258	21	18C
0005435696958	16258	22	18D
0005435935023	16258	23	19A
0005435696959	16258	24	19C
0005435696890	16258	25	20C
0005435696912	16258	26	20B
0005435696935	16258	27	21B
0005435696942	16258	28	21C
0005435696892	16258	29	21D
0005435696943	16258	30	22C
0005435916149	16258	31	23A
0005434604875	3941	1	1A
0005435853588	3941	2	1B
0005433519432	3941	3	1C
0005435853596	3941	4	1D
0005432607542	3941	5	2A
0005434606807	3941	6	2B
0005433519429	3941	7	2C
0005433519431	3941	8	2D
0005432607543	3941	9	3B
0005433519430	3941	10	3C
0005432609707	3941	11	3D
0005435842314	3941	12	4A
0005434604876	3941	13	4B
0005435853597	3941	14	4C
0005432609708	3941	15	5A
0005434606810	3941	16	5B
0005435853589	3941	17	5C
0005432609706	3941	18	6B
0005432609705	3941	19	6C
0005434606808	3941	20	7B
0005434604877	3941	21	7D
0005432607539	3941	22	18A
0005433519428	3941	23	18B
0005432607541	3941	24	18C
0005432607540	3941	25	18D
0005435853593	3941	26	19A
0005435842318	3941	27	19D
0005434606811	3941	28	20A
0005434604879	3941	29	20B
0005435853582	3941	30	20C
0005434606806	3941	31	20D
0005432609704	3941	32	21C
0005434606809	3941	33	21D
0005435853581	3941	34	22B
0005434604878	3941	35	23A
0005435853592	3941	36	23B
0005435841091	22053	1	1C
0005435841089	22053	2	1D
0005432609668	22053	3	2B
0005435841468	22053	4	2C
0005435841092	22053	5	2D
0005435841088	22053	6	3A
0005432613796	22053	7	3B
0005435841469	22053	8	3C
0005434606778	22053	9	3D
0005435841466	22053	10	4A
0005433519394	22053	11	5A
0005435853601	22053	12	5C
0005432609665	22053	13	6B
0005432609666	22053	14	6C
0005435841090	22053	15	6D
0005435853600	22053	16	7A
0005432613794	22053	17	7C
0005435841467	22053	18	7D
0005432613789	22053	19	18C
0005435904893	22053	20	18D
0005435841470	22053	21	19C
0005434606777	22053	22	19D
0005432613797	22053	23	20B
0005435841087	22053	24	20C
0005432613795	22053	25	20D
0005432609664	22053	26	21A
0005435841465	22053	27	21C
0005435853599	22053	28	21D
0005434606761	22053	29	22C
0005434606772	22053	30	22D
0005433348915	786	1	1A
0005433348900	786	2	1B
0005433348906	786	3	2A
0005433348907	786	4	2B
0005433348893	786	5	3A
0005433348913	786	6	3B
0005433348890	786	7	4A
0005433348914	786	8	4B
0005433348896	786	9	5A
0005435628707	786	10	6A
0005435628708	786	11	6B
0005433348957	15992	1	1A
0005433348956	15992	2	1B
0005433348954	15992	3	2A
0005435628683	15992	4	2B
0005435628680	15992	5	3A
0005433348955	15992	6	3B
0005435628684	15992	7	4A
0005433348952	15992	8	5A
0005433348953	15992	9	6A
0005435628688	15992	10	5B
0005435628689	15992	11	6B
0005434445231	17212	1	1A
0005433158103	17212	2	2A
0005433159277	17212	3	1B
0005433159280	17212	4	2B
0005434445232	17212	5	3A
0005433159279	17212	6	3B
0005433158102	17212	7	4A
0005433158101	17212	8	5A
0005434445230	17212	9	6B
0005433159300	17674	1	2A
0005433159299	17674	2	2B
0005434445213	17674	3	3B
0005435383059	7880	1	1A
0005435132817	7880	2	1D
0005435132814	7880	3	2B
0005435383058	7880	4	3C
0005435132820	7880	5	4D
0005435383063	7880	6	5A
0005435132818	7880	7	5C
0005435132823	7880	8	6A
0005435132821	7880	9	6C
0005435132816	7880	10	7B
0005435383093	7880	11	18B
0005435132824	7880	12	18C
0005435383061	7880	13	18D
0005435132819	7880	14	19C
0005435132813	7880	15	20C
0005435383062	7880	16	21C
0005435132815	7880	17	21D
0005435132822	7880	18	22A
0005435132759	33080	1	1C
0005435383120	33080	2	3C
0005435383119	33080	3	3D
0005435383116	33080	4	4C
0005435132740	33080	5	5A
0005435132739	33080	6	6A
0005435383117	33080	7	6C
0005435383115	33080	8	19A
0005435132748	33080	9	19B
0005435383118	33080	10	21C
0005435132745	33080	11	22B
0005435132726	33080	12	22C
0005435132744	33080	13	23B
0005435938857	4413	1	3C
0005435938847	4413	2	3F
0005435811047	4413	3	4D
0005435811038	4413	4	4C
0005435811041	4413	5	6D
0005435811046	4413	6	7A
0005435811045	4413	7	6F
0005435811039	4413	8	10C
0005435811033	4413	9	11E
0005435811036	4413	10	12D
0005435811032	4413	11	14F
0005435811037	4413	12	15D
0005435811043	4413	13	16A
0005435811034	4413	14	17D
0005435811042	4413	15	18F
0005435811044	4413	16	19B
0005435811040	4413	17	20A
0005435811035	4413	18	20E
0005435810992	29454	1	5F
0005435938868	29454	2	7E
0005435938865	29454	3	9E
0005435811004	29454	4	10A
0005435811010	29454	5	10D
0005435811007	29454	6	11E
0005435938867	29454	7	13A
0005435810994	29454	8	13C
0005435938870	29454	9	13B
0005435811002	29454	10	13F
0005435810993	29454	11	14B
0005435938872	29454	12	14E
0005435810991	29454	13	16A
0005435938869	29454	14	16F
0005435810987	29454	15	18B
0005435938871	29454	16	18F
0005435938866	29454	17	20A
0005435811005	29454	18	20C
0005435160230	7505	1	1D
0005435160233	7505	2	2C
0005435160229	7505	3	3A
0005435160236	7505	4	3C
0005435160238	7505	5	5A
0005435390151	7505	6	5D
0005435160237	7505	7	6C
0005435390152	7505	8	6D
0005435390124	7505	9	7D
0005435160232	7505	10	18C
0005435390159	7505	11	18D
0005435390143	7505	12	20C
0005435390128	7505	13	20D
0005435390125	7505	14	21A
0005435160239	7505	15	21C
0005435390134	7505	16	22B
0005435160235	7505	17	22A
0005435390158	7505	18	22D
0005435160234	7505	19	23A
0005435160231	7505	20	23B
0005435160162	29563	1	2A
0005435160133	29563	2	2B
0005435160115	29563	3	2D
0005435160130	29563	4	4A
0005435390196	29563	5	4B
0005435390200	29563	6	4D
0005435160109	29563	7	5A
0005435160131	29563	8	6A
0005435390201	29563	9	7A
0005435160150	29563	10	7B
0005435160193	29563	11	7D
0005435160139	29563	12	18A
0005435390197	29563	13	18C
0005435160140	29563	14	18D
0005435160134	29563	15	19C
0005435160151	29563	16	19D
0005435390198	29563	17	21A
0005435160124	29563	18	21B
0005435160173	29563	19	21D
0005435390199	29563	20	22B
0005435178487	18427	1	2A
0005435178488	18427	2	3A
0005435178989	18427	3	4A
0005432394032	18427	4	4B
0005432394043	18427	5	5A
0005432398154	18427	6	5B
0005432394048	18427	7	6A
0005432398171	27168	1	2A
0005432398168	27168	2	4A
0005432398170	27168	3	5A
0005432398169	27168	4	4B
0005432400097	27168	5	6B
0005432398172	27168	6	6A
0005432865928	2254	1	1D
0005432639049	2254	2	1F
0005432865914	2254	3	2F
0005432639048	2254	4	3A
0005432639060	2254	5	3C
0005432865943	2254	6	3D
0005432865910	2254	7	4A
0005432865913	2254	8	5C
0005432639064	2254	9	5F
0005432865912	2254	10	6D
0005432865894	2254	11	6F
0005432639047	2254	12	7C
0005432639063	2254	13	7E
0005432639065	2254	14	8A
0005432639062	2254	15	8C
0005432639050	2254	16	8E
0005432639058	2254	17	9E
0005432639046	2254	18	9F
0005432639056	2254	19	10F
0005432865909	2254	20	11A
0005432639055	2254	21	11D
0005432639043	2254	22	11F
0005432865917	2254	23	13E
0005432639054	2254	24	14A
0005432639044	2254	25	14E
0005432639053	2254	26	14F
0005432639051	2254	27	15A
0005432639059	2254	28	15F
0005432639052	2254	29	17C
0005432639045	2254	30	17E
0005432865904	2254	31	18C
0005432639066	2254	32	18D
0005432639042	2254	33	18F
0005432865903	2254	34	19F
0005432639061	2254	35	20A
0005432639057	2254	36	20D
0005434503939	6518	1	1A
0005434503911	6518	2	1C
0005435103878	6518	3	1F
0005434503908	6518	4	2D
0005434503934	6518	5	3A
0005434503904	6518	6	3C
0005434503910	6518	7	3D
0005434503916	6518	8	3F
0005434503912	6518	9	5A
0005434503914	6518	10	5E
0005434503927	6518	11	5F
0005435103880	6518	12	6C
0005434503923	6518	13	6E
0005435103882	6518	14	7C
0005435103884	6518	15	7D
0005435103881	6518	16	8C
0005434503926	6518	17	8D
0005434503936	6518	18	8E
0005434503915	6518	19	9D
0005434503913	6518	20	9E
0005434503929	6518	21	9F
0005434503922	6518	22	10C
0005435103885	6518	23	10D
0005434503909	6518	24	10E
0005434503907	6518	25	11C
0005434503918	6518	26	11D
0005434503935	6518	27	11E
0005434503933	6518	28	11F
0005435103879	6518	29	12E
0005434503917	6518	30	12F
0005434503937	6518	31	13A
0005434503938	6518	32	13C
0005434503919	6518	33	13D
0005435103883	6518	34	13E
0005434503930	6518	35	14A
0005434503901	6518	36	14E
0005434503928	6518	37	14F
0005434503931	6518	38	15D
0005434503932	6518	39	16D
0005434503921	6518	40	17C
0005434503920	6518	41	17D
0005434503925	6518	42	17E
0005434503903	6518	43	18D
0005434503906	6518	44	18F
0005434503924	6518	45	19C
0005434503902	6518	46	20A
0005434503905	6518	47	20C
0005434503573	22647	1	2A
0005435103797	22647	2	3A
0005434503582	22647	3	3C
0005434503631	22647	4	3D
0005434503607	22647	5	4E
0005434503559	22647	6	5E
0005434503497	22647	7	5F
0005434503532	22647	8	6A
0005434503508	22647	9	6C
0005434503598	22647	10	6E
0005434503555	22647	11	6F
0005435103793	22647	12	8A
0005434503633	22647	13	8D
0005434503498	22647	14	9C
0005434503604	22647	15	9D
0005434503507	22647	16	11A
0005434503609	22647	17	12E
0005434503512	22647	18	12F
0005435103799	22647	19	13A
0005434503471	22647	20	13C
0005434503558	22647	21	14C
0005434503470	22647	22	15D
0005434503517	22647	23	15E
0005435103800	22647	24	18D
0005435103802	22647	25	18E
0005434503632	22647	26	19F
0005434503482	22647	27	20A
0005434503472	22647	28	20C
0005435652814	1657	1	1A
0005433367318	1657	2	1C
0005433367303	1657	3	1D
0005435652833	1657	4	2A
0005435652825	1657	5	2C
0005433367332	1657	6	2F
0005433367244	1657	7	3A
0005435652804	1657	8	3D
0005435652811	1657	9	3F
0005435652828	1657	10	4C
0005433367312	1657	11	4E
0005435652802	1657	12	4F
0005435652827	1657	13	5A
0005435652817	1657	14	5C
0005433367306	1657	15	5D
0005433367250	1657	16	5E
0005435652794	1657	17	5F
0005433367276	1657	18	6A
0005435652791	1657	19	6C
0005435652821	1657	20	6D
0005435652836	1657	21	6E
0005433367559	1657	22	6F
0005435652796	1657	23	7A
0005435652799	1657	24	7C
0005433367558	1657	25	7D
0005435652788	1657	26	7E
0005435652829	1657	27	7F
0005435652819	1657	28	8A
0005435652810	1657	29	8C
0005433367367	1657	30	8E
0005433367238	1657	31	8F
0005435652805	1657	32	9A
0005435652812	1657	33	9C
0005433367352	1657	34	9D
0005433367356	1657	35	9E
0005433367283	1657	36	9F
0005435652822	1657	37	10A
0005435652803	1657	38	10C
0005433367341	1657	39	10D
0005435652786	1657	40	10E
0005435652798	1657	41	10F
0005433367259	1657	42	11A
0005433367265	1657	43	11D
0005435652800	1657	44	11E
0005435652797	1657	45	11F
0005433367368	1657	46	12A
0005433367304	1657	47	12C
0005433367557	1657	48	12E
0005435652809	1657	49	12F
0005435652787	1657	50	13A
0005435652830	1657	51	13C
0005435652835	1657	52	13E
0005433367239	1657	53	14A
0005435652816	1657	54	14C
0005435652792	1657	55	14D
0005433367360	1657	56	14F
0005435652824	1657	57	14E
0005433367249	1657	58	15A
0005435652826	1657	59	15C
0005433367382	1657	60	15D
0005433367387	1657	61	15F
0005435652834	1657	62	16A
0005435652832	1657	63	16C
0005435652823	1657	64	16D
0005435652808	1657	65	16E
0005435652795	1657	66	16F
0005435652807	1657	67	17A
0005435652793	1657	68	17C
0005435652837	1657	69	17D
0005435652831	1657	70	17E
0005433367366	1657	71	17F
0005433367372	1657	72	18A
0005435652801	1657	73	18C
0005435652815	1657	74	18D
0005435652818	1657	75	18F
0005435652789	1657	76	19D
0005435652820	1657	77	19E
0005435652813	1657	78	19F
0005433367383	1657	79	20A
0005433367311	1657	80	20C
0005435652790	1657	81	20D
0005435652806	1657	82	20E
0005435652480	21662	1	1A
0005435652457	21662	2	1C
0005435652332	21662	3	1D
0005435652386	21662	4	1F
0005433367671	21662	5	2A
0005435652384	21662	6	2C
0005433367678	21662	7	2D
0005433367643	21662	8	2F
0005435652256	21662	9	3A
0005435652463	21662	10	3C
0005435652444	21662	11	3D
0005433367658	21662	12	3F
0005433367645	21662	13	4A
0005435652479	21662	14	4E
0005433367675	21662	15	4F
0005435652275	21662	16	5A
0005433367662	21662	17	5D
0005435652445	21662	18	5E
0005435652343	21662	19	5F
0005435652461	21662	20	6A
0005435652331	21662	21	6C
0005433367676	21662	22	6E
0005435652408	21662	23	6F
0005435652456	21662	24	7A
0005435652454	21662	25	7C
0005433367664	21662	26	7D
0005433367651	21662	27	7E
0005435652330	21662	28	7F
0005433367663	21662	29	8A
0005433367665	21662	30	8D
0005435652468	21662	31	8E
0005433367669	21662	32	8F
0005435652455	21662	33	9A
0005435652469	21662	34	9C
0005433367673	21662	35	9D
0005433367670	21662	36	9E
0005435652348	21662	37	10A
0005433367642	21662	38	10C
0005433367668	21662	39	10D
0005433367653	21662	40	10F
0005433367659	21662	41	11A
0005435652453	21662	42	11C
0005433367674	21662	43	11D
0005433367641	21662	44	11E
0005435652501	21662	45	12A
0005435652435	21662	46	12D
0005433367648	21662	47	12E
0005435652452	21662	48	12F
0005433367660	21662	49	13A
0005433367657	21662	50	13C
0005433367655	21662	51	13D
0005433367647	21662	52	13E
0005433367649	21662	53	14A
0005435652478	21662	54	14F
0005433367666	21662	55	15E
0005433367677	21662	56	16C
0005433367652	21662	57	16D
0005433367667	21662	58	17C
0005435652414	21662	59	17E
0005433367654	21662	60	17F
0005433367656	21662	61	18A
0005433367644	21662	62	18C
0005435652333	21662	63	18D
0005435652340	21662	64	18E
0005435652357	21662	65	18F
0005433367672	21662	66	19A
0005435652329	21662	67	19C
0005435652523	21662	68	19E
0005433367650	21662	69	19F
0005435652288	21662	70	20A
0005433367646	21662	71	20C
0005433367661	21662	72	20E
0005435652464	21662	73	20F
0005435627114	12221	1	1A
0005435627115	12221	2	3A
0005434466390	23225	1	1A
0005434466376	23225	2	1B
0005434466379	23225	3	1C
0005435312788	23225	4	1D
0005435312790	23225	5	2A
0005434466394	23225	6	3A
0005435312789	23225	7	4A
0005434466389	23225	8	4B
0005434466395	23225	9	4D
0005434466382	23225	10	5D
0005435312793	23225	11	6A
0005434466407	23225	12	6C
0005434466383	23225	13	18A
0005434466408	23225	14	18C
0005434466372	23225	15	19C
0005434466380	23225	16	20A
0005435312792	23225	17	22D
0005435312791	23225	18	23A
0005434466403	23225	19	23B
0005433985652	4184	1	1A
0005433985672	4184	2	1F
0005433985685	4184	3	2C
0005433985659	4184	4	2D
0005433985654	4184	5	2F
0005433985683	4184	6	3C
0005433985665	4184	7	4A
0005433985682	4184	8	4D
0005433985666	4184	9	4E
0005433985671	4184	10	4F
0005433985656	4184	11	5A
0005433985680	4184	12	5E
0005433985677	4184	13	6D
0005433985678	4184	14	6F
0005433985658	4184	15	7C
0005433985664	4184	16	8D
0005433985670	4184	17	8F
0005433985650	4184	18	9A
0005433985688	4184	19	9D
0005433985662	4184	20	9E
0005435788756	4184	21	10D
0005433985679	4184	22	11A
0005433985651	4184	23	11C
0005435788755	4184	24	11D
0005433985660	4184	25	11E
0005433985657	4184	26	12A
0005433985673	4184	27	12C
0005433985687	4184	28	12E
0005433985663	4184	29	13A
0005433985649	4184	30	13C
0005433985676	4184	31	13D
0005433985653	4184	32	13F
0005433985686	4184	33	14C
0005433985675	4184	34	14F
0005433985669	4184	35	15A
0005433985674	4184	36	15E
0005433985648	4184	37	16A
0005433985684	4184	38	16C
0005433985668	4184	39	16E
0005435788754	4184	40	17F
0005433985655	4184	41	18D
0005435788757	4184	42	18F
0005433985681	4184	43	19D
0005433985667	4184	44	20C
0005433985661	4184	45	20D
0005433985242	25693	1	2C
0005433985180	25693	2	3D
0005433985152	25693	3	4C
0005433985212	25693	4	4E
0005433985249	25693	5	5A
0005433985232	25693	6	5F
0005433985250	25693	7	6E
0005433985122	25693	8	7E
0005433985123	25693	9	8C
0005433985151	25693	10	8E
0005433985223	25693	11	8F
0005433985161	25693	12	9D
0005433985154	25693	13	10A
0005433985186	25693	14	10C
0005433985253	25693	15	10D
0005433985244	25693	16	11A
0005433985209	25693	17	11D
0005433985185	25693	18	11E
0005433985222	25693	19	12A
0005433985132	25693	20	12D
0005433985191	25693	21	13A
0005433985155	25693	22	13C
0005433985231	25693	23	14D
0005433985146	25693	24	15D
0005433985145	25693	25	17A
0005433985241	25693	26	17F
0005433985187	25693	27	18C
0005433985234	25693	28	18F
0005433985131	25693	29	19A
0005433985176	25693	30	20A
0005433463863	19918	1	1H
0005433463861	19918	2	11G
0005433461563	19918	3	17H
0005433463862	19918	4	20H
0005433461564	19918	5	39F
0005435719561	24757	1	2A
0005435719562	24757	2	4C
0005435720128	24757	3	21D
0005434509095	1616	1	1B
0005434509107	1616	2	2A
0005433168304	1616	3	2B
0005433168322	1616	4	3A
0005434509105	1616	5	3B
0005434509106	1616	6	3C
0005433168302	1616	7	4B
0005434509099	1616	8	5A
0005433168305	1616	9	5C
0005434509100	1616	10	5D
0005434509102	1616	11	6B
0005434509087	1616	12	6C
0005434509103	1616	13	6D
0005433168306	1616	14	7B
0005434509094	1616	15	7C
0005434509089	1616	16	7D
0005434509085	1616	17	18A
0005433168311	1616	18	18B
0005434509088	1616	19	18C
0005434509104	1616	20	19A
0005433168309	1616	21	19B
0005434509091	1616	22	19C
0005434509086	1616	23	19D
0005434509098	1616	24	20B
0005433168308	1616	25	20C
0005433168315	1616	26	20D
0005434509097	1616	27	21A
0005433168321	1616	28	21B
0005434509093	1616	29	21C
0005434509096	1616	30	21D
0005434509090	1616	31	22A
0005434509092	1616	32	22D
0005434509101	1616	33	23B
0005432658567	17836	1	1A
0005432869491	17836	2	2C
0005432655392	17836	3	3D
0005432655365	17836	4	4D
0005432869486	17836	5	4E
0005432655344	17836	6	5A
0005432667421	17836	7	5C
0005432665249	17836	8	5D
0005432869490	17836	9	5F
0005432667418	17836	10	7D
0005432655345	17836	11	7F
0005432655350	17836	12	8A
0005432655342	17836	13	9C
0005432869489	17836	14	10E
0005432869487	17836	15	11A
0005432659671	17836	16	11C
0005432869488	17836	17	12A
0005432655376	17836	18	12C
0005434151689	17836	19	14C
0005432655375	17836	20	15C
0005432667422	17836	21	20D
0005434151669	26326	1	1A
0005432665260	26326	2	1C
0005432657428	26326	3	1D
0005432655443	26326	4	1F
0005432665258	26326	5	2A
0005432664121	26326	6	2C
0005432661907	26326	7	2D
0005432657426	26326	8	2F
0005432869420	26326	9	3A
0005432663021	26326	10	3C
0005432661898	26326	11	3D
0005432664117	26326	12	3F
0005432666374	26326	13	4A
0005434151662	26326	14	4D
0005432661909	26326	15	4C
0005432664115	26326	16	4E
0005432663015	26326	17	4F
0005432658577	26326	18	5C
0005432655438	26326	19	5D
0005432667439	26326	20	5E
0005432664126	26326	21	5F
0005432661905	26326	22	6C
0005432664114	26326	23	6D
0005432663016	26326	24	6E
0005432661912	26326	25	7A
0005432661906	26326	26	7C
0005432655442	26326	27	7D
0005432663013	26326	28	7E
0005432660802	26326	29	7F
0005432665259	26326	30	8A
0005432658576	26326	31	8E
0005432661904	26326	32	9C
0005432661900	26326	33	9D
0005432663020	26326	34	9E
0005432655448	26326	35	10A
0005432664123	26326	36	10C
0005432655446	26326	37	10E
0005432659690	26326	38	11A
0005432655437	26326	39	11C
0005432663019	26326	40	11E
0005432664118	26326	41	11F
0005432663012	26326	42	12A
0005432660803	26326	43	12D
0005432664127	26326	44	12F
0005432655447	26326	45	13C
0005432661899	26326	46	13D
0005432664124	26326	47	13E
0005432655440	26326	48	13F
0005432663018	26326	49	14A
0005432659691	26326	50	14C
0005432664116	26326	51	14D
0005432661908	26326	52	14E
0005432664122	26326	53	14F
0005432657427	26326	54	15A
0005432664120	26326	55	15D
0005432661903	26326	56	15F
0005432663024	26326	57	16E
0005432663026	26326	58	16F
0005432664125	26326	59	17A
0005432666373	26326	60	17C
0005432661910	26326	61	17D
0005432661901	26326	62	17E
0005432661911	26326	63	17F
0005434151668	26326	64	18A
0005432655436	26326	65	18C
0005432663023	26326	66	18D
0005432655444	26326	67	18E
0005432664113	26326	68	18F
0005432664119	26326	69	19A
0005432655441	26326	70	19C
0005432655439	26326	71	19D
0005432661902	26326	72	19E
0005432869419	26326	73	19F
0005432655445	26326	74	20A
0005432663017	26326	75	20C
0005432663022	26326	76	20D
0005432663025	26326	77	20E
0005432663014	26326	78	20F
0005432638969	25059	1	1A
0005432865973	25059	2	1C
0005432638947	25059	3	1F
0005432865970	25059	4	2A
0005432638920	25059	5	2C
0005432865979	25059	6	2F
0005432865977	25059	7	3D
0005432865974	25059	8	3F
0005432638915	25059	9	4D
0005432865962	25059	10	5C
0005432865961	25059	11	5F
0005432865975	25059	12	6A
0005432865972	25059	13	6D
0005432865968	25059	14	6E
0005432638948	25059	15	7A
0005432638940	25059	16	7C
0005432865978	25059	17	7D
0005432865980	25059	18	7E
0005432638973	25059	19	7F
0005432865971	25059	20	8A
0005432638951	25059	21	8C
0005432638998	25059	22	8E
0005432865967	25059	23	9A
0005432638971	25059	24	9D
0005432638997	25059	25	9E
0005432638978	25059	26	10A
0005432865969	25059	27	10C
0005432638939	25059	28	10D
0005432638928	25059	29	10F
0005432638962	25059	30	11A
0005432638926	25059	31	11E
0005432865964	25059	32	12A
0005432638963	25059	33	12E
0005432638927	25059	34	14A
0005432865959	25059	35	14C
0005432638974	25059	36	14D
0005432865965	25059	37	14E
0005432638950	25059	38	14F
0005432638976	25059	39	15A
0005432865960	25059	40	15D
0005432865958	25059	41	15E
0005432638933	25059	42	16A
0005432865963	25059	43	17F
0005432638919	25059	44	18A
0005432865966	25059	45	18D
0005432639000	25059	46	18E
0005432638975	25059	47	19A
0005432865976	25059	48	19E
0005432638977	25059	49	20A
0005432638952	25059	50	20C
0005432328417	3085	1	1A
0005432328422	3085	2	1C
0005432328408	3085	3	1D
0005432287159	3085	4	1F
0005432328410	3085	5	2C
0005432905050	3085	6	2D
0005432328442	3085	7	2F
0005432905020	3085	8	3A
0005432905058	3085	9	3C
0005432328416	3085	10	4A
0005432328431	3085	11	4C
0005432287161	3085	12	4E
0005432328433	3085	13	5A
0005432905046	3085	14	6A
0005432287158	3085	15	6D
0005432328412	3085	16	6E
0005432328432	3085	17	6F
0005432905074	3085	18	7A
0005432328444	3085	19	7C
0005432905019	3085	20	7D
0005432328440	3085	21	7E
0005433438838	3085	22	7F
0005432328436	3085	23	8C
0005432905054	3085	24	8D
0005432905047	3085	25	8E
0005432328448	3085	26	9A
0005433438839	3085	27	9C
0005432328407	3085	28	9D
0005432328452	3085	29	9E
0005432905059	3085	30	9F
0005432328429	3085	31	10A
0005432287160	3085	32	10C
0005432328445	3085	33	10D
0005432328446	3085	34	10E
0005432328430	3085	35	10F
0005432328411	3085	36	11C
0005432905051	3085	37	11D
0005432328409	3085	38	12A
0005432328438	3085	39	12C
0005432328435	3085	40	12E
0005432328415	3085	41	12F
0005432328439	3085	42	13A
0005432328450	3085	43	13C
0005433438840	3085	44	13D
0005432328425	3085	45	13F
0005432328424	3085	46	14E
0005432328428	3085	47	15A
0005432328413	3085	48	15D
0005432328437	3085	49	15E
0005432328447	3085	50	16C
0005432328453	3085	51	16D
0005432328423	3085	52	16E
0005432328426	3085	53	17D
0005432328451	3085	54	17E
0005432328421	3085	55	18C
0005432328419	3085	56	18D
0005432328449	3085	57	18E
0005432328427	3085	58	19A
0005432328414	3085	59	19D
0005432328420	3085	60	19E
0005432328434	3085	61	19F
0005432328418	3085	62	20D
0005432328443	3085	63	20E
0005432328441	3085	64	20F
0005432328081	31130	1	1A
0005432327923	31130	2	1C
0005432327966	31130	3	1F
0005432328258	31130	4	2A
0005433438798	31130	5	2C
0005432328083	31130	6	2D
0005432905095	31130	7	2F
0005432327918	31130	8	3A
0005432328129	31130	9	3F
0005432905091	31130	10	4D
0005432327956	31130	11	4E
0005432327967	31130	12	5D
0005432328086	31130	13	6A
0005433438763	31130	14	6C
0005432327899	31130	15	6E
0005432328021	31130	16	7C
0005432327957	31130	17	7D
0005432327924	31130	18	7E
0005432328020	31130	19	7F
0005432848837	31130	20	8C
0005432327999	31130	21	8D
0005432328084	31130	22	8E
0005432328155	31130	23	8F
0005432328071	31130	24	9A
0005432327917	31130	25	9C
0005432327900	31130	26	9D
0005432327951	31130	27	9E
0005432328111	31130	28	10A
0005432905096	31130	29	10C
0005432327890	31130	30	10D
0005433438785	31130	31	10E
0005432327958	31130	32	11C
0005432328000	31130	33	12C
0005432327971	31130	34	12D
0005432327952	31130	35	12E
0005433438768	31130	36	12F
0005432054286	31130	37	13A
0005432905093	31130	38	13C
0005432328023	31130	39	13E
0005432327977	31130	40	14D
0005432328035	31130	41	15A
0005432054287	31130	42	15D
0005432328077	31130	43	16A
0005432905092	31130	44	16C
0005432327959	31130	45	16D
0005432328022	31130	46	16F
0005432328156	31130	47	17A
0005432328169	31130	48	17D
0005432327978	31130	49	18D
0005432328143	31130	50	18E
0005432327991	31130	51	18F
0005432327979	31130	52	19A
0005432328103	31130	53	19C
0005432905094	31130	54	20C
0005433438786	31130	55	20E
0005432328104	31130	56	20F
0005435999153	6230	1	1A
0005435487515	6230	2	1C
0005435999167	6230	3	1F
0005434309660	6230	4	2C
0005435999156	6230	5	2A
0005432146187	6230	6	3A
0005435999144	6230	7	4A
0005435296959	6230	8	4D
0005434309665	6230	9	4C
0005435999171	6230	10	5A
0005435999152	6230	11	5B
0005434309658	6230	12	5D
0005435999160	6230	13	6A
0005435487532	6230	14	6B
0005435999147	6230	15	6D
0005432146186	6230	16	6F
0005435999154	6230	17	6E
0005435999166	6230	18	7A
0005434309656	6230	19	7C
0005435999172	6230	20	7F
0005435999149	6230	21	8C
0005434309668	6230	22	8F
0005434309655	6230	23	9F
0005434309663	6230	24	11A
0005435999151	6230	25	11B
0005434309666	6230	26	11D
0005434309657	6230	27	11C
0005435296940	6230	28	12D
0005435487511	6230	29	12F
0005435999165	6230	30	13A
0005435487542	6230	31	13D
0005435296939	6230	32	13C
0005435487541	6230	33	13F
0005434309661	6230	34	14B
0005435999162	6230	35	14C
0005435999164	6230	36	15B
0005434309664	6230	37	15C
0005435999157	6230	38	16A
0005435999168	6230	39	16B
0005435999150	6230	40	16D
0005435999163	6230	41	17D
0005435999170	6230	42	18E
0005434309662	6230	43	18D
0005435999145	6230	44	19B
0005434309659	6230	45	19F
0005435999159	6230	46	20B
0005435999146	6230	47	20A
0005434309667	6230	48	20C
0005435999155	6230	49	20E
0005435487506	6230	50	20F
0005435296944	6230	51	21F
0005435487507	6230	52	22B
0005435999169	6230	53	22C
0005434309669	6230	54	22D
0005435999161	6230	55	22F
0005435999158	6230	56	23B
0005435999148	6230	57	23F
0005435487693	19535	1	3F
0005435297017	19535	2	3D
0005435998996	19535	3	4A
0005435297019	19535	4	4B
0005435998965	19535	5	4D
0005434309551	19535	6	5F
0005435487681	19535	7	6B
0005435487687	19535	8	6E
0005435487689	19535	9	7A
0005435487684	19535	10	7C
0005435998961	19535	11	7F
0005435487686	19535	12	7E
0005435487688	19535	13	8A
0005435487685	19535	14	8E
0005435297022	19535	15	9E
0005435297020	19535	16	9D
0005435998991	19535	17	9F
0005435998979	19535	18	10D
0005435487694	19535	19	11D
0005435297021	19535	20	12A
0005435487683	19535	21	12F
0005435297018	19535	22	13B
0005435487680	19535	23	13A
0005435998952	19535	24	13F
0005435487691	19535	25	16A
0005435487695	19535	26	16C
0005435998951	19535	27	16D
0005434309536	19535	28	16E
0005435487682	19535	29	17C
0005435998995	19535	30	17D
0005435487692	19535	31	17E
0005434309550	19535	32	19B
0005435487690	19535	33	20C
0005434309552	19535	34	20B
0005435487679	19535	35	21A
0005435998983	19535	36	21D
0005435998953	19535	37	21E
0005435487696	19535	38	22B
0005435487676	19535	39	22A
0005435487677	19535	40	22F
0005434309537	19535	41	22E
0005435487678	19535	42	23E
0005433158118	17546	1	1A
0005434446478	17546	2	2C
0005434446492	17546	3	3C
0005434446493	17546	4	5C
0005434446479	17546	5	5D
0005434446477	17546	6	6B
0005433158116	17546	7	6C
0005434446489	17546	8	7A
0005434446494	17546	9	7B
0005434446476	17546	10	19A
0005434446480	17546	11	19B
0005434446484	17546	12	19C
0005434446481	17546	13	21A
0005433158119	17546	14	21B
0005433158117	17546	15	21D
0005435502193	1593	1	1C
0005435508295	1593	2	1D
0005435508288	1593	3	1F
0005434565831	1593	4	2A
0005435502186	1593	5	2C
0005434565835	1593	6	2D
0005435517817	1593	7	2F
0005435517803	1593	8	3C
0005434565829	1593	9	3D
0005435517807	1593	10	3F
0005435502176	1593	11	4C
0005433185998	1593	12	4D
0005433186014	1593	13	4E
0005435502195	1593	14	4F
0005435508296	1593	15	5C
0005435517806	1593	16	5D
0005435517816	1593	17	5E
0005433186008	1593	18	6A
0005435517813	1593	19	6C
0005435502179	1593	20	6D
0005433186012	1593	21	6F
0005435502180	1593	22	7A
0005435517811	1593	23	7C
0005435502178	1593	24	7D
0005435508287	1593	25	7E
0005435502184	1593	26	7F
0005433186000	1593	27	8A
0005432291916	1593	28	8C
0005433186013	1593	29	8D
0005434565839	1593	30	8E
0005435517805	1593	31	8F
0005435517804	1593	32	9A
0005434565836	1593	33	9C
0005434565841	1593	34	9E
0005435502191	1593	35	10A
0005435502185	1593	36	10D
0005435508293	1593	37	10E
0005433185999	1593	38	10F
0005435502196	1593	39	11C
0005435517809	1593	40	11D
0005435502181	1593	41	11E
0005435502182	1593	42	11F
0005434565834	1593	43	12A
0005435502190	1593	44	12C
0005435508294	1593	45	12D
0005435502177	1593	46	12F
0005435517802	1593	47	13D
0005435517812	1593	48	13E
0005432291915	1593	49	13F
0005434565838	1593	50	14D
0005435517814	1593	51	14E
0005435508291	1593	52	14F
0005434565842	1593	53	15A
0005435508286	1593	54	15C
0005434565833	1593	55	15D
0005435517800	1593	56	15E
0005435517801	1593	57	15F
0005435502175	1593	58	16A
0005435502192	1593	59	16E
0005433185992	1593	60	16F
0005435517810	1593	61	17C
0005435508290	1593	62	17D
0005435508292	1593	63	18A
0005435502188	1593	64	18C
0005435517815	1593	65	18D
0005434565832	1593	66	18E
0005435502183	1593	67	18F
0005434565830	1593	68	19A
0005435502189	1593	69	19C
0005435517808	1593	70	19D
0005435502194	1593	71	19E
0005435502187	1593	72	19F
0005433186010	1593	73	20A
0005435508289	1593	74	20D
0005434565840	1593	75	20E
0005434565837	1593	76	20F
0005434565731	20853	1	1A
0005433186072	20853	2	2C
0005435528944	20853	3	2D
0005435528922	20853	4	2F
0005435502048	20853	5	3D
0005435528916	20853	6	4A
0005434565701	20853	7	4C
0005435528902	20853	8	4D
0005434565758	20853	9	4E
0005433186071	20853	10	5A
0005434565700	20853	11	5C
0005434565705	20853	12	5E
0005434565757	20853	13	5F
0005433186066	20853	14	6A
0005435528888	20853	15	6C
0005434565760	20853	16	6E
0005435502047	20853	17	6F
0005435501956	20853	18	7C
0005435501955	20853	19	7D
0005435528946	20853	20	7E
0005435502049	20853	21	8C
0005435528915	20853	22	8D
0005434565694	20853	23	9D
0005435502019	20853	24	9F
0005435528950	20853	25	10C
0005434565704	20853	26	10D
0005433186065	20853	27	10E
0005435528914	20853	28	11D
0005435528964	20853	29	11F
0005433186067	20853	30	12C
0005434565799	20853	31	12F
0005434565750	20853	32	13A
0005435528934	20853	33	13C
0005435528945	20853	34	13D
0005434565755	20853	35	13F
0005434565728	20853	36	14D
0005435545635	20853	37	14F
0005435502020	20853	38	15A
0005434565702	20853	39	15E
0005434565732	20853	40	15F
0005435501979	20853	41	16A
0005434565751	20853	42	17A
0005433186070	20853	43	17C
0005435501957	20853	44	17D
0005434565730	20853	45	17E
0005435528999	20853	46	18A
0005434565745	20853	47	18C
0005435545634	20853	48	18D
0005433186068	20853	49	18F
0005433186069	20853	50	19A
0005435502000	20853	51	19C
0005434565733	20853	52	19E
0005435545621	20853	53	20A
0005434565682	20853	54	20F
0005435931539	3880	1	2C
0005435931560	3880	2	2D
0005435931545	3880	3	4C
0005435153702	3880	4	5A
0005435153703	3880	5	6B
0005435931546	3880	6	18C
0005435931540	3880	7	18D
0005435153706	3880	8	19A
0005435931555	3880	9	20A
0005435153701	3880	10	20B
0005435153705	3880	11	22C
0005435153704	3880	12	23B
0005435153666	21859	1	1D
0005435931580	21859	2	3B
0005435931578	21859	3	3C
0005435931582	21859	4	5A
0005435153648	21859	5	7D
0005435931581	21859	6	20C
0005435931579	21859	7	22B
0005435153659	21859	8	22C
0005435153632	21859	9	22D
0005435153633	21859	10	23A
0005435153658	21859	11	23B
0005432628756	7178	1	1A
0005432628759	7178	2	1C
0005435225473	7178	3	1D
0005432628760	7178	4	2B
0005432628763	7178	5	2C
0005435225467	7178	6	2D
0005432628753	7178	7	3C
0005435225490	7178	8	3D
0005435225453	7178	9	4A
0005435225468	7178	10	4D
0005432628755	7178	11	6A
0005435225476	7178	12	6C
0005432628765	7178	13	7A
0005432628758	7178	14	7C
0005435225452	7178	15	7D
0005432628757	7178	16	19A
0005432628752	7178	17	19D
0005432628761	7178	18	20A
0005432628766	7178	19	20C
0005432628762	7178	20	20D
0005435225475	7178	21	21B
0005432628764	7178	22	21C
0005435225474	7178	23	22A
0005432628754	7178	24	22D
0005432628670	28111	1	1B
0005432628682	28111	2	2C
0005432628644	28111	3	3B
0005435225538	28111	4	4D
0005432628673	28111	5	6A
0005432628620	28111	6	6B
0005432628639	28111	7	7B
0005435225537	28111	8	7C
0005435225535	28111	9	18A
0005435225540	28111	10	18B
0005432628654	28111	11	20A
0005432628674	28111	12	20C
0005432628672	28111	13	20D
0005435225536	28111	14	21B
0005435225539	28111	15	21C
0005432628660	28111	16	22C
0005435960029	8766	1	1A
0005435960030	8766	2	4A
0005435960028	8766	3	4D
0005435960027	8766	4	5B
0005435960026	8766	5	18D
0005434267892	8766	6	19C
0005434267899	8766	7	20C
0005434267889	8766	8	21D
0005434267926	15258	1	1D
0005434267927	15258	2	2D
0005434267928	15258	3	5D
0005435960001	15258	4	7D
0005434267925	15258	5	18A
0005435959984	15258	6	20A
0005435959985	15258	7	21C
0005434267929	15258	8	22C
0005432677546	1171	1	1D
0005432873208	1171	2	2A
0005432692855	1171	3	1F
0005432675046	1171	4	2C
0005432873177	1171	5	3A
0005432675048	1171	6	2F
0005432692864	1171	7	3C
0005432692846	1171	8	3F
0005432675040	1171	9	5A
0005432692867	1171	10	5C
0005432675043	1171	11	5F
0005432692850	1171	12	5D
0005432692854	1171	13	6E
0005432692853	1171	14	6F
0005432692872	1171	15	7C
0005432692873	1171	16	7D
0005432692851	1171	17	8A
0005432873178	1171	18	7F
0005432675044	1171	19	8D
0005432675045	1171	20	9B
0005432675047	1171	21	9A
0005432677547	1171	22	9C
0005432675038	1171	23	9E
0005432692869	1171	24	9D
0005432692860	1171	25	10B
0005432675039	1171	26	10F
0005432692857	1171	27	11C
0005432692862	1171	28	11D
0005432873207	1171	29	12C
0005432675041	1171	30	12B
0005432692866	1171	31	13A
0005432692852	1171	32	12F
0005432692868	1171	33	13E
0005432675033	1171	34	14B
0005432675034	1171	35	14A
0005432692861	1171	36	15A
0005432675042	1171	37	14F
0005432675036	1171	38	14E
0005432873183	1171	39	15D
0005432692870	1171	40	15E
0005432675035	1171	41	16A
0005432873199	1171	42	16C
0005432692848	1171	43	16F
0005432675037	1171	44	16E
0005432692847	1171	45	17C
0005432692865	1171	46	17B
0005432692858	1171	47	17A
0005432873186	1171	48	18B
0005432677545	1171	49	18A
0005432692844	1171	50	17F
0005432677544	1171	51	18D
0005432692859	1171	52	19E
0005432692843	1171	53	19C
0005432692863	1171	54	20D
0005432692856	1171	55	20C
0005432692845	1171	56	21A
0005432692871	1171	57	21D
0005432692849	1171	58	21E
0005432692633	17487	1	1C
0005432692590	17487	2	1A
0005432692608	17487	3	1D
0005432692558	17487	4	2C
0005432873248	17487	5	1F
0005432692647	17487	6	2F
0005432692666	17487	7	4C
0005432674946	17487	8	5F
0005432674876	17487	9	6B
0005432873247	17487	10	6D
0005432873250	17487	11	6C
0005432873246	17487	12	7E
0005432692675	17487	13	7F
0005432692639	17487	14	8B
0005432873252	17487	15	8E
0005432674901	17487	16	8D
0005432692534	17487	17	8F
0005432674928	17487	18	9A
0005432692638	17487	19	10A
0005432692627	17487	20	10C
0005432677512	17487	21	10B
0005432692631	17487	22	11C
0005432674877	17487	23	11E
0005432692537	17487	24	12A
0005432677511	17487	25	12E
0005432692603	17487	26	13A
0005432674945	17487	27	13D
0005432692569	17487	28	13F
0005432674966	17487	29	14A
0005432692645	17487	30	14E
0005432692557	17487	31	15C
0005432692568	17487	32	15D
0005432674919	17487	33	16A
0005432674923	17487	34	15F
0005432674879	17487	35	16B
0005432674902	17487	36	16E
0005432674880	17487	37	16D
0005432692582	17487	38	17A
0005432674878	17487	39	17C
0005432873249	17487	40	17F
0005432873251	17487	41	17E
0005432692674	17487	42	18E
0005432692683	17487	43	20D
0005432692682	17487	44	20C
0005432692648	17487	45	20F
0005432674915	17487	46	20E
0005432674918	17487	47	21A
0005432692571	17487	48	21C
0005432674967	17487	49	21B
0005432692646	17487	50	21E
0005432674916	17487	51	21D
0005434435087	1105	1	1D
0005433156665	1105	2	3B
0005434435086	1105	3	3D
0005434435098	1105	4	4A
0005434435096	1105	5	4D
0005434435094	1105	6	5A
0005433156620	1105	7	5D
0005433156633	1105	8	6A
0005433156658	1105	9	6B
0005433156625	1105	10	6C
0005434435092	1105	11	6D
0005434435083	1105	12	7A
0005434435091	1105	13	18A
0005434435089	1105	14	18B
0005433156628	1105	15	18C
0005433156627	1105	16	18D
0005433156634	1105	17	19B
0005434435093	1105	18	19C
0005434435095	1105	19	19D
0005433156666	1105	20	21B
0005434435082	1105	21	21D
0005434435084	1105	22	22A
0005434435097	1105	23	22C
0005434435088	1105	24	22D
0005434435085	1105	25	23A
0005434435090	1105	26	23B
0005433156693	17290	1	1A
0005433156700	17290	2	1C
0005433156701	17290	3	1D
0005433156697	17290	4	2A
0005434434994	17290	5	3B
0005434434912	17290	6	3D
0005433156699	17290	7	4A
0005434434997	17290	8	4C
0005434434998	17290	9	5A
0005433156696	17290	10	6A
0005434434946	17290	11	6C
0005434434943	17290	12	7B
0005434434954	17290	13	18A
0005433156694	17290	14	18B
0005434434955	17290	15	18C
0005434435015	17290	16	18D
0005434435024	17290	17	20D
0005434435026	17290	18	21B
0005434434918	17290	19	21C
0005434435023	17290	20	22C
0005433156698	17290	21	23A
0005433156695	17290	22	23B
0005435928088	4088	1	1C
0005435928070	4088	2	2B
0005435086791	4088	3	2D
0005435086786	4088	4	3C
0005435086793	4088	5	4A
0005435928057	4088	6	4D
0005435928065	4088	7	5C
0005435086792	4088	8	6A
0005435086785	4088	9	6C
0005435928058	4088	10	6D
0005435928064	4088	11	7A
0005435928066	4088	12	18D
0005435086788	4088	13	19A
0005435086789	4088	14	19C
0005435928059	4088	15	20C
0005435928067	4088	16	20D
0005435086790	4088	17	21C
0005435928068	4088	18	21D
0005435928087	4088	19	22B
0005435086787	4088	20	23A
0005435086744	24388	1	2D
0005435086722	24388	2	3A
0005435086706	24388	3	3C
0005435086742	24388	4	3D
0005435086701	24388	5	4A
0005435928116	24388	6	7B
0005435928114	24388	7	18A
0005435086725	24388	8	18B
0005435928113	24388	9	19A
0005435928115	24388	10	20C
0005435928111	24388	11	21A
0005435086743	24388	12	22C
0005435086723	24388	13	22D
0005435928112	24388	14	23A
0005435706293	2445	1	1D
0005435706268	2445	2	1F
0005435706278	2445	3	2C
0005435706264	2445	4	3A
0005435706276	2445	5	3C
0005435706287	2445	6	3D
0005435706282	2445	7	4A
0005433373391	2445	8	4E
0005435706294	2445	9	4F
0005435706295	2445	10	5A
0005433373381	2445	11	5C
0005435706279	2445	12	5D
0005435706263	2445	13	6A
0005435706280	2445	14	6D
0005435706271	2445	15	6E
0005435706266	2445	16	7F
0005435706277	2445	17	8A
0005435706275	2445	18	8C
0005435706274	2445	19	8D
0005435706270	2445	20	8E
0005435706267	2445	21	9C
0005433373413	2445	22	9D
0005435706265	2445	23	9F
0005433373406	2445	24	10A
0005433373426	2445	25	10C
0005435706289	2445	26	10E
0005435706269	2445	27	10F
0005435706272	2445	28	11C
0005435706288	2445	29	11D
0005433373414	2445	30	11F
0005433373405	2445	31	13D
0005433373388	2445	32	13F
0005435706281	2445	33	14C
0005435706286	2445	34	14D
0005433373415	2445	35	14E
0005435706296	2445	36	15A
0005435706284	2445	37	15C
0005435706292	2445	38	15D
0005433373432	2445	39	16C
0005433373389	2445	40	16D
0005433373376	2445	41	16E
0005435706285	2445	42	17E
0005433373429	2445	43	18E
0005435706283	2445	44	18F
0005435706291	2445	45	19C
0005435706290	2445	46	19D
0005433373390	2445	47	19F
0005435706273	2445	48	20D
0005433373380	2445	49	20F
0005435706105	27026	1	1A
0005435706195	27026	2	1C
0005433373468	27026	3	1D
0005435706102	27026	4	2D
0005435706113	27026	5	2F
0005435706152	27026	6	3C
0005433373476	27026	7	3D
0005435706114	27026	8	3F
0005433373483	27026	9	4E
0005435706101	27026	10	5A
0005435706116	27026	11	5D
0005433373484	27026	12	5E
0005435706153	27026	13	6C
0005433373473	27026	14	6D
0005433373474	27026	15	7A
0005435706117	27026	16	7E
0005433373478	27026	17	7F
0005433373475	27026	18	8C
0005435706168	27026	19	8E
0005435706144	27026	20	8F
0005433373479	27026	21	9D
0005433373470	27026	22	9F
0005435706142	27026	23	10D
0005433373477	27026	24	10F
0005435706145	27026	25	11A
0005433373485	27026	26	11D
0005435706103	27026	27	11E
0005433373472	27026	28	11F
0005435706115	27026	29	12A
0005435706170	27026	30	12F
0005435706110	27026	31	13D
0005435706175	27026	32	13F
0005435706095	27026	33	14E
0005435706169	27026	34	14F
0005433373481	27026	35	16D
0005435706165	27026	36	16E
0005435706147	27026	37	17A
0005435706106	27026	38	17C
0005435706131	27026	39	17D
0005433373480	27026	40	17F
0005435706146	27026	41	18A
0005433373482	27026	42	18E
0005433373471	27026	43	18F
0005435706171	27026	44	19D
0005435706128	27026	45	19E
0005433373469	27026	46	20A
0005434964097	1319	1	1B
0005433261444	1319	2	1A
0005433261402	1319	3	1C
0005434964084	1319	4	1F
0005433261451	1319	5	2F
0005434964093	1319	6	2G
0005433261429	1319	7	2H
0005433261428	1319	8	3H
0005433261404	1319	9	4B
0005434964101	1319	10	4F
0005433261443	1319	11	5B
0005433261419	1319	12	5C
0005434964075	1319	13	5H
0005432279258	1319	14	9A
0005434964085	1319	15	9H
0005432279255	1319	16	11E
0005432279259	1319	17	12A
0005434964099	1319	18	11H
0005434964122	1319	19	12B
0005434964089	1319	20	12E
0005433261413	1319	21	12G
0005434964117	1319	22	12H
0005433261388	1319	23	13E
0005433261395	1319	24	13F
0005434964086	1319	25	14B
0005434964105	1319	26	14D
0005434964119	1319	27	14F
0005433261450	1319	28	14G
0005433261408	1319	29	15B
0005434964111	1319	30	15F
0005434964071	1319	31	16B
0005434964091	1319	32	16F
0005433261422	1319	33	16G
0005434964096	1319	34	17D
0005434964104	1319	35	17E
0005434964107	1319	36	18B
0005434964121	1319	37	19F
0005433261389	1319	38	19E
0005434964080	1319	39	19G
0005433261414	1319	40	20A
0005434964108	1319	41	19H
0005434964092	1319	42	20D
0005434964094	1319	43	20H
0005434964083	1319	44	20G
0005433261403	1319	45	21F
0005434964102	1319	46	21H
0005433261417	1319	47	22A
0005434964081	1319	48	22E
0005434964087	1319	49	22F
0005432279257	1319	50	22H
0005434964120	1319	51	23B
0005434964077	1319	52	23E
0005433261400	1319	53	23G
0005433261420	1319	54	24B
0005432279261	1319	55	24F
0005432279260	1319	56	24H
0005434964076	1319	57	24G
0005434964115	1319	58	27A
0005434964073	1319	59	27D
0005434964078	1319	60	27F
0005434964116	1319	61	28A
0005434964125	1319	62	28E
0005434964074	1319	63	28F
0005433261423	1319	64	28H
0005434964126	1319	65	29A
0005434964103	1319	66	29D
0005434964098	1319	67	29E
0005434964118	1319	68	29G
0005433261427	1319	69	29F
0005434964090	1319	70	30A
0005433261418	1319	71	30B
0005434964110	1319	72	30E
0005434964123	1319	73	30H
0005434964109	1319	74	31B
0005434964114	1319	75	31E
0005433261397	1319	76	31H
0005434964128	1319	77	32B
0005434964095	1319	78	32E
0005434964113	1319	79	32D
0005434964112	1319	80	32G
0005433261455	1319	81	33F
0005432279256	1319	82	34D
0005434964124	1319	83	34G
0005434964079	1319	84	34H
0005434964082	1319	85	35G
0005433261396	1319	86	35F
0005434964106	1319	87	35H
0005434964072	1319	88	36B
0005434964100	1319	89	36A
0005434964127	1319	90	36D
0005433261421	1319	91	37B
0005433261412	1319	92	37F
0005432279254	1319	93	37H
0005434964088	1319	94	38A
0005433261401	1319	95	39F
0005434625909	4820	1	3C
0005434625910	4820	2	9E
0005434625902	4820	3	11C
0005435907428	4820	4	11E
0005435907460	4820	5	11F
0005434625908	4820	6	12D
0005434625903	4820	7	12F
0005435907416	4820	8	15E
0005434625906	4820	9	17A
0005433194827	4820	10	18A
0005434625907	4820	11	18C
0005434625905	4820	12	18F
0005434625904	4820	13	20A
0005433194850	32928	1	1A
0005435907476	32928	2	2C
0005434625853	32928	3	2D
0005433194844	32928	4	4A
0005434625835	32928	5	4D
0005433194848	32928	6	6E
0005435907477	32928	7	6F
0005434625860	32928	8	8D
0005434625828	32928	9	8E
0005434625859	32928	10	9A
0005433194843	32928	11	9F
0005435907475	32928	12	10A
0005434625830	32928	13	10C
0005435907474	32928	14	10D
0005435907478	32928	15	10E
0005434625829	32928	16	12F
0005434625823	32928	17	14F
0005433194846	32928	18	15A
0005434625834	32928	19	16D
0005435907479	32928	20	17F
0005433194847	32928	21	18A
0005434625824	32928	22	18F
0005433194845	32928	23	20C
0005434625858	32928	24	20D
0005433194849	32928	25	20E
0005435784777	13790	1	1A
0005435784806	13790	2	1B
0005435784745	13790	3	2A
0005435784836	13790	4	2B
0005435784753	13790	5	2C
0005435784761	13790	6	3A
0005435784769	13790	7	3B
0005435784829	13790	8	3C
0005432195681	13790	9	4A
0005435784783	13790	10	4B
0005435784831	13790	11	4C
0005435784890	13790	12	5A
0005435784828	13790	13	5B
0005435784766	13790	14	5C
0005435784760	13790	15	6A
0005435784824	13790	16	6B
0005435784900	13790	17	6C
0005435784763	13790	18	6D
0005435784762	13790	19	7B
0005432195679	13790	20	7A
0005435784744	13790	21	7C
0005435784767	13790	22	7D
0005435784850	13790	23	18A
0005435784779	13790	24	18B
0005435784754	13790	25	18D
0005435784870	13790	26	19A
0005432195680	13790	27	19B
0005435784730	13790	28	19C
0005435784899	13790	29	19D
0005435784813	13790	30	20B
0005435784765	13790	31	20D
0005435784876	13790	32	21A
0005435784832	13790	33	21B
0005435784778	13790	34	21C
0005435784795	13790	35	21D
0005435784814	13790	36	22A
0005435784823	13790	37	22C
0005435784785	13790	38	22D
0005435784875	13790	39	23A
0005435785083	27410	1	1A
0005432190599	27410	2	1B
0005435785081	27410	3	1C
0005435785089	27410	4	1D
0005435785096	27410	5	2A
0005435785102	27410	6	2B
0005435785115	27410	7	2C
0005435785088	27410	8	2D
0005435785098	27410	9	3B
0005435785114	27410	10	3C
0005435785110	27410	11	4B
0005432190600	27410	12	4C
0005435785101	27410	13	4D
0005435785099	27410	14	5A
0005435785108	27410	15	5B
0005435785103	27410	16	5C
0005435785091	27410	17	5D
0005435785109	27410	18	6A
0005432190602	27410	19	6B
0005435785100	27410	20	6C
0005435785090	27410	21	6D
0005435785097	27410	22	7A
0005435785113	27410	23	7C
0005435785082	27410	24	7D
0005435785085	27410	25	18A
0005435785106	27410	26	18B
0005435785111	27410	27	18C
0005435785086	27410	28	18D
0005435785105	27410	29	19B
0005435785094	27410	30	19D
0005435785093	27410	31	19C
0005435785112	27410	32	20A
0005435785084	27410	33	20B
0005435787338	27410	34	20C
0005435785104	27410	35	20D
0005432190601	27410	36	21C
0005435785092	27410	37	22A
0005435785095	27410	38	22B
0005435785107	27410	39	22C
0005435787340	27410	40	22D
0005435787339	27410	41	23A
0005435785087	27410	42	23B
0005434406767	20306	1	1A
0005432058359	20306	2	1C
0005435311000	20306	3	1D
0005434406868	20306	4	1F
0005434406930	20306	5	2A
0005434406706	20306	6	2C
0005434406805	20306	7	2F
0005434406806	20306	8	3A
0005434406935	20306	9	3C
0005434406948	20306	10	3D
0005434407067	20306	11	3F
0005434407078	20306	12	4A
0005434406803	20306	13	4C
0005434407018	20306	14	4D
0005434407057	20306	15	4E
0005435310996	20306	16	4F
0005434406818	20306	17	5A
0005434406651	20306	18	5C
0005434406766	20306	19	5D
0005435311007	20306	20	5F
0005434406833	20306	21	6A
0005434406642	20306	22	6C
0005434406982	20306	23	6D
0005434407047	20306	24	6E
0005432058358	20306	25	6F
0005434406787	20306	26	7A
0005434406820	20306	27	7C
0005434406848	20306	28	7E
0005434406749	20306	29	8A
0005435310998	20306	30	8C
0005434406971	20306	31	8D
0005434406819	20306	32	8E
0005434406817	20306	33	8F
0005434406852	20306	34	9A
0005434406757	20306	35	9D
0005435311001	20306	36	9E
0005434406949	20306	37	9F
0005435311004	20306	38	11C
0005434406756	20306	39	11E
0005434406877	20306	40	11F
0005434406931	20306	41	12A
0005435311012	20306	42	12C
0005434406768	20306	43	12D
0005435311009	20306	44	12E
0005434406953	20306	45	12F
0005434407017	20306	46	13C
0005434407040	20306	47	13D
0005434406802	20306	48	13F
0005435311008	20306	49	14C
0005434407066	20306	50	14D
0005435310997	20306	51	14E
0005434406755	20306	52	14F
0005434406764	20306	53	15A
0005434406804	20306	54	15D
0005434406816	20306	55	15E
0005435311011	20306	56	16C
0005434406782	20306	57	16D
0005434406685	20306	58	16E
0005434406932	20306	59	16F
0005434406954	20306	60	17A
0005434406851	20306	61	17C
0005434406866	20306	62	17F
0005434406869	20306	63	18A
0005435310999	20306	64	18C
0005435311005	20306	65	18E
0005435311013	20306	66	18F
0005434406785	20306	67	19A
0005434406737	20306	68	19C
0005432058357	20306	69	19D
0005435311010	20306	70	19E
0005435311014	20306	71	19F
0005434406889	20306	72	20A
0005435311003	20306	73	20C
0005435311002	20306	74	20E
0005435311006	20306	75	20F
0005434407381	26991	1	1A
0005434407379	26991	2	1C
0005434407382	26991	3	1D
0005434407406	26991	4	2A
0005434407378	26991	5	2D
0005434407402	26991	6	2F
0005434407391	26991	7	3A
0005432153893	26991	8	3C
0005434407392	26991	9	3D
0005434407383	26991	10	3F
0005434407380	26991	11	4A
0005434407371	26991	12	4D
0005434407393	26991	13	4E
0005434407350	26991	14	4F
0005435310879	26991	15	5A
0005435310836	26991	16	5C
0005434407355	26991	17	5E
0005434407389	26991	18	6A
0005434407356	26991	19	6C
0005435310882	26991	20	6D
0005434407367	26991	21	6F
0005434407385	26991	22	7A
0005434407370	26991	23	7C
0005434407394	26991	24	7D
0005434407366	26991	25	7E
0005434407390	26991	26	8A
0005435310853	26991	27	8C
0005434407411	26991	28	8D
0005434407361	26991	29	8F
0005432153892	26991	30	8E
0005434407363	26991	31	9A
0005432153897	26991	32	9C
0005434407360	26991	33	9D
0005435310878	26991	34	9E
0005434407372	26991	35	9F
0005434407352	26991	36	10A
0005434407351	26991	37	10C
0005434407369	26991	38	10D
0005435310859	26991	39	10E
0005434407407	26991	40	10F
0005435310860	26991	41	11C
0005434407387	26991	42	11D
0005435310861	26991	43	11E
0005434407374	26991	44	11F
0005434407398	26991	45	12A
0005432153895	26991	46	12C
0005435310888	26991	47	12D
0005434407384	26991	48	12E
0005434407348	26991	49	12F
0005434407365	26991	50	13A
0005434407412	26991	51	13C
0005434407405	26991	52	13D
0005434407404	26991	53	13E
0005434407401	26991	54	13F
0005434407347	26991	55	14A
0005432153898	26991	56	14C
0005434407376	26991	57	14D
0005432153896	26991	58	14E
0005434407364	26991	59	15A
0005434407354	26991	60	15C
0005434407408	26991	61	15D
0005434407395	26991	62	15E
0005434407349	26991	63	16A
0005435310880	26991	64	15F
0005434407409	26991	65	16C
0005434407377	26991	66	16D
0005434407362	26991	67	16E
0005434407386	26991	68	16F
0005434407396	26991	69	17A
0005434407400	26991	70	17D
0005434407373	26991	71	17E
0005434407410	26991	72	18A
0005432153894	26991	73	18C
0005434407375	26991	74	18D
0005434407397	26991	75	18E
0005434407359	26991	76	18F
0005434407403	26991	77	19A
0005434407368	26991	78	19C
0005434407357	26991	79	19D
0005435310881	26991	80	19F
0005434407358	26991	81	20A
0005434407399	26991	82	20C
0005434407353	26991	83	20D
0005434407388	26991	84	20E
0005435310876	26991	85	20F
0005433123681	5693	1	1C
0005434319299	5693	2	1D
0005433123719	5693	3	2C
0005433123616	5693	4	2D
0005434311206	5693	5	3A
0005432109685	5693	6	3D
0005434319309	5693	7	4C
0005434319302	5693	8	5C
0005433123673	5693	9	5D
0005433123652	5693	10	5E
0005434319296	5693	11	5F
0005434319307	5693	12	6A
0005434319301	5693	13	6C
0005434319304	5693	14	6D
0005433123582	5693	15	7E
0005433123631	5693	16	7F
0005434319298	5693	17	8C
0005433123662	5693	18	9E
0005433123730	5693	19	10A
0005434319300	5693	20	10C
0005433123664	5693	21	10D
0005434311207	5693	22	11A
0005433123637	5693	23	11C
0005433123690	5693	24	11D
0005433123601	5693	25	12A
0005434319306	5693	26	12E
0005434319308	5693	27	12F
0005433123623	5693	28	13F
0005433123731	5693	29	14C
0005433123626	5693	30	14D
0005434311208	5693	31	15A
0005434319295	5693	32	15D
0005434319297	5693	33	15E
0005432109687	5693	34	16E
0005433123627	5693	35	16F
0005433123624	5693	36	17C
0005433123602	5693	37	18C
0005434319303	5693	38	18D
0005433123709	5693	39	19A
0005434319305	5693	40	19C
0005433123639	5693	41	19E
0005433123691	5693	42	20C
0005432109686	5693	43	20D
0005434312293	15702	1	2C
0005433123804	15702	2	2F
0005434319174	15702	3	3A
0005434319180	15702	4	3C
0005433123814	15702	5	3D
0005434311188	15702	6	3F
0005434319176	15702	7	4D
0005433123810	15702	8	4F
0005433123818	15702	9	5E
0005434319173	15702	10	6A
0005434319213	15702	11	6E
0005433123809	15702	12	6F
0005434319215	15702	13	7A
0005433123821	15702	14	7D
0005434319175	15702	15	7E
0005433123807	15702	16	8F
0005433123824	15702	17	9C
0005433123820	15702	18	9D
0005434312295	15702	19	9E
0005434311183	15702	20	10A
0005433123823	15702	21	10C
0005433123808	15702	22	10E
0005434319218	15702	23	11A
0005433123811	15702	24	11C
0005433123816	15702	25	11F
0005434319169	15702	26	12A
0005434319172	15702	27	12C
0005433123806	15702	28	12E
0005434311189	15702	29	12F
0005434319168	15702	30	13A
0005433123826	15702	31	13F
0005433123812	15702	32	14A
0005434319145	15702	33	15D
0005434311190	15702	34	16F
0005433123813	15702	35	17C
0005433123815	15702	36	17D
0005433123817	15702	37	17E
0005433123819	15702	38	18A
0005433123805	15702	39	18D
0005434319214	15702	40	18F
0005433123825	15702	41	19C
0005434311184	15702	42	20C
0005433123822	15702	43	20D
0005435219189	31750	1	1A
0005435220489	31750	2	2C
0005435219188	31750	3	3A
0005435220307	31750	4	4A
0005435220310	31750	5	4B
0005435220308	31750	6	7B
0005435220305	31750	7	7C
0005435219190	31750	8	19D
0005435220306	31750	9	20A
0005435220309	31750	10	22A
0005435219191	31750	11	22B
0005435219187	31750	12	22C
0005434189077	9004	1	1C
0005434189112	9004	2	2C
0005434189107	9004	3	2D
0005434484308	9004	4	3B
0005434189106	9004	5	4D
0005434189089	9004	6	5C
0005434484307	9004	7	6A
0005434189113	9004	8	7A
0005434189093	9004	9	7D
0005434484310	9004	10	18A
0005434189091	9004	11	19C
0005434484311	9004	12	20A
0005434484309	9004	13	21B
0005434189099	9004	14	22A
0005434189111	9004	15	23A
0005434484251	16631	1	1A
0005434189145	16631	2	1D
0005434484263	16631	3	3A
0005434484232	16631	4	3B
0005434484248	16631	5	3C
0005434484262	16631	6	4A
0005434189141	16631	7	4B
0005434189144	16631	8	6A
0005434189143	16631	9	6C
0005434189146	16631	10	7B
0005434189142	16631	11	18A
0005434484260	16631	12	18C
0005434484231	16631	13	19A
0005434484250	16631	14	20D
0005433123825	7642	1	1C
0005433123813	7642	2	2A
0005433123804	7642	3	3A
0005433123807	7642	4	4A
0005433123814	7642	5	4E
0005433123810	7642	6	4F
0005433123812	7642	7	5F
0005433123818	7642	8	6C
0005433123823	7642	9	6E
0005433123811	7642	10	8D
0005433123822	7642	11	9C
0005433123821	7642	12	9F
0005433123806	7642	13	10A
0005433123816	7642	14	10C
0005433123805	7642	15	11F
0005433123826	7642	16	12A
0005433123824	7642	17	12D
0005433123808	7642	18	13C
0005433123820	7642	19	15D
0005433123817	7642	20	16D
0005433123815	7642	21	16E
0005433123819	7642	22	19A
0005433123809	7642	23	20F
0005433449849	7643	1	1A
0005432692886	7643	2	1C
0005432692892	7643	3	1D
0005433449850	7643	4	1F
0005432720730	7643	5	2A
0005432720750	7643	6	2C
0005432692900	7643	7	2D
0005432692890	7643	8	2F
0005432692893	7643	9	3A
0005432692888	7643	10	3C
0005432692891	7643	11	3D
0005433449839	7643	12	3F
0005433449834	7643	13	4A
0005432720742	7643	14	4C
0005432720749	7643	15	4D
0005432692874	7643	16	4E
0005432720751	7643	17	4F
0005432692904	7643	18	5A
0005432692894	7643	19	5C
0005433449830	7643	20	5E
0005432692897	7643	21	5F
0005433449831	7643	22	6A
0005433449835	7643	23	6C
0005432692902	7643	24	6D
0005432692901	7643	25	6E
0005432071556	7643	26	6F
0005432720735	7643	27	7A
0005433449848	7643	28	7D
0005432071557	7643	29	7E
0005432692875	7643	30	8A
0005433449838	7643	31	8C
0005432692887	7643	32	8D
0005432720757	7643	33	8F
0005432692895	7643	34	9C
0005432720752	7643	35	9D
0005433449832	7643	36	9E
0005432692889	7643	37	9F
0005432720746	7643	38	10A
0005432720741	7643	39	10C
0005433449829	7643	40	10D
0005432692877	7643	41	10E
0005432692878	7643	42	11A
0005432720745	7643	43	11C
0005432720747	7643	44	11D
0005432692876	7643	45	11E
0005432720732	7643	46	11F
0005432720738	7643	47	12A
0005433449843	7643	48	12C
0005432692903	7643	49	12E
0005433449840	7643	50	12F
0005432692885	7643	51	13A
0005433449841	7643	52	13C
0005432720743	7643	53	13D
0005432692905	7643	54	13E
0005432720734	7643	55	13F
0005432720737	7643	56	14C
0005432692898	7643	57	14E
0005432720733	7643	58	14F
0005432692896	7643	59	15A
0005432692884	7643	60	15C
0005432720753	7643	61	15D
0005432720744	7643	62	15E
0005433449828	7643	63	15F
0005432071555	7643	64	16A
0005432720739	7643	65	16C
0005432720754	7643	66	16E
0005432720736	7643	67	16D
0005433449837	7643	68	17A
0005432720755	7643	69	17C
0005433449846	7643	70	17D
0005432692883	7643	71	17E
0005433449845	7643	72	17F
0005432720748	7643	73	18A
0005433449833	7643	74	18C
0005433449842	7643	75	18F
0005432720740	7643	76	18E
0005433449847	7643	77	19A
0005432692882	7643	78	19C
0005432720756	7643	79	19D
0005433449836	7643	80	19E
0005432692899	7643	81	19F
0005432720731	7643	82	20A
0005433449844	7643	83	20C
0005432692879	7643	84	20D
0005432692881	7643	85	20E
0005432692880	7643	86	20F
0005432692631	30358	1	1A
0005432692603	30358	2	1C
0005432692558	30358	3	1D
0005433449617	30358	4	2C
0005433449612	30358	5	3A
0005433449614	30358	6	3C
0005433449613	30358	7	4F
0005432692675	30358	8	5C
0005432692590	30358	9	5D
0005433449691	30358	10	6A
0005433449668	30358	11	6D
0005432692647	30358	12	7D
0005432692569	30358	13	8C
0005433449627	30358	14	8D
0005433449595	30358	15	9E
0005433449629	30358	16	9F
0005432692683	30358	17	10A
0005432692645	30358	18	10D
0005432692571	30358	19	10E
0005432692646	30358	20	10F
0005432692648	30358	21	11E
0005433449666	30358	22	11F
0005432692557	30358	23	12C
0005432692682	30358	24	13A
0005432692608	30358	25	13F
0005433449621	30358	26	14D
0005432692568	30358	27	14F
0005433449616	30358	28	15A
0005432692537	30358	29	15C
0005432692666	30358	30	15D
0005433449692	30358	31	15E
0005432692638	30358	32	16A
0005432692674	30358	33	17A
0005432692627	30358	34	17F
0005432692633	30358	35	18A
0005432692639	30358	36	18C
0005433449670	30358	37	18F
0005432692582	30358	38	19D
0005432692534	30358	39	19F
0005433449703	30358	40	20A
0005433449644	30358	41	20D
0005432720596	30357	1	1A
0005432720562	30357	2	1C
0005433123637	30357	3	1F
0005433722180	30357	4	2A
0005432720605	30357	5	2C
0005433123616	30357	6	2D
0005432720561	30357	7	3A
0005432720632	30357	8	3F
0005433123639	30357	9	4C
0005433123691	30357	10	4D
0005433123623	30357	11	4E
0005433123690	30357	12	4F
0005433123681	30357	13	5D
0005433722186	30357	14	5E
0005432720609	30357	15	5F
0005432720459	30357	16	6C
0005433722179	30357	17	6F
0005433722182	30357	18	7A
0005432720519	30357	19	7E
0005433123624	30357	20	8D
0005433123731	30357	21	8E
0005433123582	30357	22	9A
0005432720591	30357	23	9C
0005432720614	30357	24	9D
0005433722181	30357	25	9E
0005432720523	30357	26	9F
0005432720465	30357	27	10D
0005433123652	30357	28	10E
0005432720563	30357	29	10F
0005432720538	30357	30	11C
0005432720506	30357	31	11A
0005432720428	30357	32	11D
0005433123602	30357	33	11F
0005432720551	30357	34	12A
0005433123662	30357	35	12C
0005433123601	30357	36	12E
0005432720597	30357	37	13A
0005432720608	30357	38	13C
0005433123627	30357	39	14A
0005432720532	30357	40	14C
0005432720458	30357	41	14D
0005432720499	30357	42	14E
0005433722183	30357	43	15D
0005433123673	30357	44	16D
0005433123631	30357	45	16F
0005433123709	30357	46	17A
0005432720530	30357	47	17D
0005433123664	30357	48	17F
0005433123730	30357	49	18C
0005432720456	30357	50	18D
0005432720489	30357	51	18E
0005433123719	30357	52	19A
0005432720466	30357	53	19C
0005433722184	30357	54	19F
0005432720490	30357	55	20A
0005433722185	30357	56	20C
0005433123626	30357	57	20E
0005432720491	30357	58	20F
0005434586464	1397	1	1A
0005434586463	1397	2	1C
0005433192886	1397	3	1D
0005433192847	1397	4	1F
0005433524969	1397	5	2C
0005432968806	1397	6	2D
0005434586451	1397	7	2F
0005434586458	1397	8	3C
0005434586460	1397	9	3A
0005434514953	1397	10	3D
0005433192830	1397	11	3F
0005434586455	1397	12	4A
0005433724781	1397	13	4C
0005433524971	1397	14	4D
0005434586450	1397	15	4E
0005433192878	1397	16	4F
0005433524972	1397	17	5C
0005433192857	1397	18	5E
0005433524970	1397	19	6A
0005434586448	1397	20	6C
0005434586468	1397	21	7A
0005434586456	1397	22	7C
0005434514952	1397	23	7E
0005434586449	1397	24	8A
0005434586471	1397	25	8C
0005433192873	1397	26	8D
0005434586465	1397	27	8E
0005434586462	1397	28	8F
0005434586454	1397	29	9C
0005433724780	1397	30	9F
0005434514951	1397	31	10A
0005433724778	1397	32	10C
0005434586461	1397	33	10D
0005433192871	1397	34	10E
0005433192820	1397	35	10F
0005434586459	1397	36	11D
0005433192870	1397	37	11F
0005432270986	1397	38	12C
0005433524968	1397	39	12F
0005433524976	1397	40	13D
0005432270988	1397	41	13E
0005433192916	1397	42	14A
0005433524975	1397	43	14C
0005433192902	1397	44	14D
0005433192844	1397	45	14E
0005433724777	1397	46	15A
0005432927919	1397	47	15C
0005433524973	1397	48	15D
0005432927918	1397	49	15E
0005433192890	1397	50	15F
0005434586470	1397	51	16D
0005434514950	1397	52	16E
0005433724779	1397	53	16F
0005432270987	1397	54	17A
0005433524977	1397	55	17C
0005433524974	1397	56	17E
0005433192876	1397	57	17F
0005434586469	1397	58	18C
0005432927894	1397	59	18D
0005434586467	1397	60	18E
0005433524978	1397	61	18F
0005432927920	1397	62	19A
0005433192887	1397	63	19C
0005434586457	1397	64	19E
0005434586466	1397	65	20A
0005434586453	1397	66	20C
0005434586452	1397	67	20E
0005434586447	1397	68	20F
0005433524880	18519	1	1A
0005434586178	18519	2	1C
0005434586244	18519	3	1D
0005434586238	18519	4	2A
0005433524879	18519	5	2C
0005433192961	18519	6	2D
0005434586243	18519	7	2F
0005433724755	18519	8	3A
0005433524895	18519	9	3C
0005433192959	18519	10	3F
0005433724733	18519	11	4A
0005433724756	18519	12	4D
0005434586258	18519	13	4E
0005434514935	18519	14	5A
0005433524878	18519	15	5C
0005433524882	18519	16	5D
0005433192968	18519	17	5E
0005433192970	18519	18	6A
0005434586192	18519	19	6C
0005433524907	18519	20	6D
0005433192972	18519	21	6E
0005432927942	18519	22	6F
0005434586283	18519	23	7A
0005433192964	18519	24	7C
0005434586284	18519	25	7D
0005433192971	18519	26	7E
0005432968825	18519	27	8A
0005432927946	18519	28	9A
0005433524906	18519	29	9C
0005434586260	18519	30	9E
0005434586179	18519	31	9F
0005434586326	18519	32	10A
0005434586298	18519	33	10C
0005433724747	18519	34	10D
0005434586233	18519	35	10E
0005432968826	18519	36	10F
0005434586275	18519	37	11A
0005434586357	18519	38	11C
0005434586320	18519	39	11E
0005433192969	18519	40	12C
0005434514934	18519	41	12D
0005434514926	18519	42	12E
0005434586204	18519	43	13A
0005434586205	18519	44	13C
0005432927948	18519	45	13F
0005434586259	18519	46	14C
0005434586314	18519	47	14D
0005432927944	18519	48	14F
0005434586234	18519	49	15A
0005433192967	18519	50	15C
0005434586159	18519	51	15E
0005433524871	18519	52	16A
0005433192966	18519	53	16C
0005434586327	18519	54	16D
0005432927947	18519	55	16E
0005434586228	18519	56	16F
0005433192962	18519	57	17A
0005432927945	18519	58	17C
0005433524894	18519	59	17D
0005433192963	18519	60	17F
0005434586207	18519	61	18A
0005433192960	18519	62	18E
0005434586344	18519	63	19A
0005433192965	18519	64	19C
0005434586229	18519	65	19D
0005434586202	18519	66	19E
0005432927943	18519	67	19F
0005433524854	18519	68	20C
0005434586345	18519	69	20D
0005434586299	18519	70	20E
0005434586203	18519	71	20F
0005434343983	11423	1	1A
0005434343982	11423	2	1B
0005434142587	11423	3	1C
0005434343966	11423	4	1D
0005434343955	11423	5	2A
0005434343978	11423	6	2B
0005434343961	11423	7	2C
0005434343979	11423	8	2D
0005434343954	11423	9	3A
0005434343975	11423	10	3B
0005434343977	11423	11	3C
0005434343974	11423	12	3D
0005434343969	11423	13	4A
0005434343953	11423	14	4B
0005434343972	11423	15	4C
0005434343985	11423	16	4D
0005434142588	11423	17	5A
0005434343962	11423	18	5B
0005434343959	11423	19	5C
0005434343968	11423	20	5D
0005434343973	11423	21	6A
0005434343980	11423	22	6B
0005434343957	11423	23	6D
0005434343950	11423	24	7A
0005434343956	11423	25	7C
0005434343967	11423	26	7D
0005434343951	11423	27	18A
0005434142586	11423	28	18C
0005434343964	11423	29	18D
0005434343958	11423	30	19A
0005435302124	11423	31	19B
0005434343960	11423	32	19C
0005434343952	11423	33	19D
0005434343984	11423	34	20A
0005435302136	11423	35	20B
0005434343963	11423	36	20C
0005434343986	11423	37	20D
0005434343976	11423	38	21A
0005434343970	11423	39	21B
0005434343981	11423	40	21C
0005434343971	11423	41	21D
0005434343965	11423	42	22A
0005434343987	11423	43	22B
0005434343949	11423	44	22C
0005435302125	11423	45	23A
0005434142585	11423	46	23B
0005434343789	29786	1	1A
0005434142552	29786	2	1B
0005434343624	29786	3	1C
0005434142553	29786	4	1D
0005434343836	29786	5	2A
0005434343723	29786	6	2B
0005434343746	29786	7	2C
0005434343727	29786	8	2D
0005434343604	29786	9	3A
0005434142551	29786	10	3B
0005434343687	29786	11	3C
0005434343714	29786	12	3D
0005434343608	29786	13	4A
0005434343696	29786	14	4B
0005434343835	29786	15	4C
0005435305006	29786	16	4D
0005434343724	29786	17	5A
0005434343729	29786	18	5B
0005435305005	29786	19	5C
0005435304136	29786	20	5D
0005434343702	29786	21	6A
0005434343747	29786	22	6B
0005434343743	29786	23	6C
0005434343750	29786	24	6D
0005434343623	29786	25	7A
0005434343682	29786	26	7B
0005434343646	29786	27	7C
0005434343711	29786	28	7D
0005434343691	29786	29	18A
0005434343647	29786	30	18B
0005434343837	29786	31	18C
0005434343697	29786	32	18D
0005435304133	29786	33	19A
0005434343686	29786	34	19B
0005434343680	29786	35	19C
0005434343692	29786	36	19D
0005435304134	29786	37	20A
0005434343783	29786	38	20D
0005434343683	29786	39	21A
0005434343728	29786	40	21B
0005434343752	29786	41	21C
0005435304132	29786	42	21D
0005434142557	29786	43	22A
0005434343748	29786	44	22B
0005435304135	29786	45	22C
0005434343590	29786	46	22D
0005434343798	29786	47	23A
0005434343665	29786	48	23B
0005435824468	1254	1	1C
0005435824455	1254	2	1A
0005432284540	1254	3	1F
0005435824466	1254	4	1D
0005433415402	1254	5	2C
0005435824454	1254	6	2A
0005435824481	1254	7	3A
0005435824469	1254	8	3D
0005435824464	1254	9	3F
0005435824467	1254	10	4D
0005432284542	1254	11	4F
0005433415443	1254	12	5F
0005435824457	1254	13	6E
0005435824459	1254	14	8B
0005435824478	1254	15	8D
0005433415444	1254	16	9D
0005433415503	1254	17	9C
0005435824480	1254	18	10B
0005435824473	1254	19	11A
0005435824458	1254	20	10E
0005433415393	1254	21	11B
0005432284539	1254	22	11D
0005435824477	1254	23	11C
0005433415399	1254	24	11E
0005435824476	1254	25	12B
0005435824462	1254	26	13A
0005433415499	1254	27	13F
0005433415470	1254	28	14C
0005433415427	1254	29	14B
0005433415392	1254	30	15A
0005435824474	1254	31	15C
0005433415442	1254	32	16B
0005435824460	1254	33	16A
0005435824470	1254	34	15F
0005435824471	1254	35	16F
0005435824475	1254	36	17C
0005435824472	1254	37	17F
0005435824463	1254	38	17E
0005435824453	1254	39	18A
0005435824465	1254	40	18D
0005433415434	1254	41	18C
0005432284541	1254	42	18E
0005433415428	1254	43	19E
0005433415457	1254	44	19D
0005435824461	1254	45	20D
0005435824456	1254	46	20E
0005435824479	1254	47	21E
0005435824242	18007	1	1A
0005435824233	18007	2	2F
0005433415572	18007	3	2C
0005433415567	18007	4	6A
0005433415562	18007	5	6C
0005435824247	18007	6	6D
0005433415569	18007	7	7A
0005433415559	18007	8	6F
0005433415566	18007	9	8A
0005435824311	18007	10	8B
0005433415571	18007	11	8C
0005433415568	18007	12	8F
0005435824271	18007	13	9B
0005435824159	18007	14	10A
0005433415565	18007	15	10D
0005435824308	18007	16	11B
0005435824240	18007	17	11F
0005435824192	18007	18	11E
0005435824312	18007	19	12B
0005435824246	18007	20	13A
0005433415561	18007	21	13E
0005433415574	18007	22	13D
0005433415573	18007	23	13F
0005435824193	18007	24	14B
0005435824166	18007	25	15C
0005433415558	18007	26	15F
0005433415560	18007	27	16F
0005435824258	18007	28	17E
0005433415564	18007	29	18A
0005435824281	18007	30	19D
0005435824194	18007	31	20B
0005435824269	18007	32	20A
0005435824270	18007	33	20C
0005433415570	18007	34	21B
0005435824230	18007	35	21A
0005435824231	18007	36	21C
0005433415563	18007	37	21F
0005435242464	5640	1	1A
0005432783464	5640	2	1C
0005432783496	5640	3	1F
0005435242395	5640	4	1D
0005435242499	5640	5	2A
0005432783479	5640	6	2C
0005432783455	5640	7	2D
0005435242406	5640	8	3A
0005432783469	5640	9	3C
0005432143966	5640	10	3D
0005432783475	5640	11	3F
0005432783487	5640	12	4A
0005432783482	5640	13	4C
0005435476660	5640	14	4D
0005435242506	5640	15	4E
0005432143967	5640	16	4F
0005432783494	5640	17	5A
0005432783458	5640	18	5C
0005432783484	5640	19	5D
0005432783492	5640	20	5E
0005435242407	5640	21	5F
0005432783485	5640	22	6A
0005432783478	5640	23	6C
0005435242459	5640	24	6D
0005435242539	5640	25	6E
0005435476658	5640	26	6F
0005432783462	5640	27	7A
0005435242470	5640	28	7C
0005432783471	5640	29	7D
0005432783488	5640	30	7E
0005432143969	5640	31	7F
0005432783489	5640	32	8A
0005432783470	5640	33	8C
0005435476668	5640	34	8D
0005432783486	5640	35	8E
0005432783449	5640	36	8F
0005432783460	5640	37	9A
0005435242477	5640	38	9D
0005435242404	5640	39	9E
0005432783474	5640	40	9F
0005432783472	5640	41	10A
0005432783466	5640	42	10C
0005435476642	5640	43	10D
0005432783457	5640	44	10E
0005432783459	5640	45	10F
0005435242443	5640	46	11C
0005432783493	5640	47	11D
0005432783461	5640	48	11F
0005435242489	5640	49	12A
0005432783468	5640	50	12C
0005435476641	5640	51	12D
0005435242601	5640	52	12E
0005432783467	5640	53	12F
0005432783454	5640	54	13C
0005435242472	5640	55	13E
0005435476635	5640	56	13D
0005432783480	5640	57	13F
0005435242490	5640	58	14A
0005435242507	5640	59	14C
0005432783452	5640	60	14D
0005432783483	5640	61	14E
0005432783497	5640	62	14F
0005432783498	5640	63	15A
0005435242399	5640	64	15C
0005432783456	5640	65	15D
0005435476688	5640	66	15E
0005432783450	5640	67	16A
0005432783495	5640	68	16C
0005435242530	5640	69	16D
0005432143968	5640	70	16E
0005432783465	5640	71	16F
0005432783444	5640	72	17A
0005432783446	5640	73	17C
0005432783451	5640	74	17E
0005435242471	5640	75	17F
0005432783477	5640	76	18A
0005432783481	5640	77	18C
0005432783463	5640	78	18D
0005432783491	5640	79	18E
0005432783473	5640	80	18F
0005432783453	5640	81	19A
0005435242411	5640	82	19E
0005432783448	5640	83	20A
0005432783476	5640	84	19F
0005432783447	5640	85	20C
0005432783490	5640	86	20D
0005432783445	5640	87	20F
0005432782884	15346	1	1A
0005435242672	15346	2	1C
0005435242673	15346	3	1D
0005435476718	15346	4	1F
0005435242668	15346	5	2C
0005432783079	15346	6	2D
0005432783072	15346	7	2F
0005432782907	15346	8	3A
0005435242679	15346	9	3C
0005432783001	15346	10	3D
0005435242677	15346	11	3F
0005435242687	15346	12	4A
0005432782872	15346	13	4D
0005432782952	15346	14	4E
0005432783040	15346	15	5A
0005435242674	15346	16	5E
0005432783246	15346	17	5F
0005432783053	15346	18	6A
0005432782921	15346	19	6C
0005435242681	15346	20	6D
0005432782860	15346	21	7C
0005432783110	15346	22	7D
0005435242676	15346	23	8A
0005432783019	15346	24	8D
0005432782953	15346	25	8E
0005435242689	15346	26	8F
0005432783026	15346	27	9A
0005432783143	15346	28	9C
0005435242670	15346	29	9D
0005435242666	15346	30	9E
0005432783054	15346	31	9F
0005432783160	15346	32	10A
0005435242682	15346	33	10D
0005435242691	15346	34	10E
0005432782984	15346	35	10F
0005435242667	15346	36	11A
0005432783174	15346	37	11C
0005432783107	15346	38	11D
0005435242688	15346	39	11E
0005435242683	15346	40	11F
0005435242665	15346	41	12A
0005432782891	15346	42	12C
0005435242690	15346	43	12D
0005435242678	15346	44	12F
0005435242664	15346	45	13A
0005432782995	15346	46	13D
0005432783080	15346	47	14D
0005435476719	15346	48	14E
0005432783031	15346	49	14F
0005432783070	15346	50	15D
0005432783005	15346	51	15F
0005435242675	15346	52	16A
0005435242669	15346	53	16C
0005435242671	15346	54	16D
0005435242680	15346	55	16E
0005432783103	15346	56	17A
0005432782892	15346	57	17C
0005435242684	15346	58	17D
0005435242686	15346	59	17E
0005432782887	15346	60	17F
0005432783245	15346	61	18C
0005432782893	15346	62	18E
0005435242685	15346	63	18F
0005432783002	15346	64	19A
0005432783006	15346	65	19E
0005432783039	15346	66	20A
0005435476717	15346	67	20C
0005432783102	15346	68	20E
0005432848228	4394	1	1A
0005432848226	4394	2	1B
0005434463916	4394	3	1C
0005432848219	4394	4	2A
0005435850777	4394	5	2C
0005432848227	4394	6	2D
0005434462778	4394	7	3A
0005432848231	4394	8	3B
0005432848220	4394	9	3D
0005434462776	4394	10	4B
0005434462779	4394	11	5D
0005434462777	4394	12	6C
0005432848221	4394	13	6D
0005432848230	4394	14	7C
0005432848218	4394	15	18A
0005435850807	4394	16	18C
0005432848232	4394	17	18D
0005434463917	4394	18	19C
0005435850760	4394	19	20A
0005432848229	4394	20	20C
0005432848224	4394	21	21B
0005435850808	4394	22	21A
0005435850815	4394	23	21C
0005435850759	4394	24	22A
0005432848225	4394	25	22B
0005434463915	4394	26	22C
0005432848222	4394	27	22D
0005432848223	4394	28	23A
0005432848074	28870	1	1A
0005432848073	28870	2	1C
0005432848110	28870	3	1D
0005432848076	28870	4	2A
0005435850859	28870	5	2B
0005432848088	28870	6	2C
0005432848059	28870	7	2D
0005432848105	28870	8	3D
0005434463895	28870	9	4D
0005432848087	28870	10	5A
0005435850851	28870	11	5C
0005434463894	28870	12	5D
0005435850858	28870	13	6A
0005435850857	28870	14	6C
0005435850853	28870	15	6D
0005434461615	28870	16	7A
0005432848099	28870	17	7C
0005435850852	28870	18	7D
0005432848106	28870	19	18A
0005434463893	28870	20	18C
0005432848060	28870	21	19A
0005435850856	28870	22	19C
0005434461614	28870	23	19D
0005432848134	28870	24	20A
0005432848140	28870	25	21C
0005432848136	28870	26	21D
0005435850854	28870	27	22A
0005432848135	28870	28	22C
0005432848141	28870	29	22D
0005432848077	28870	30	23A
0005435850855	28870	31	23B
0005434925632	6300	1	1A
0005433496800	6300	2	1C
0005433496791	6300	3	1D
0005434925635	6300	4	1F
0005432075210	6300	5	2A
0005434443612	6300	6	2C
0005432075209	6300	7	2D
0005433496784	6300	8	2F
0005433496774	6300	9	3A
0005434443611	6300	10	3C
0005433496799	6300	11	3D
0005434925631	6300	12	3F
0005434925641	6300	13	4A
0005434925619	6300	14	4C
0005434925649	6300	15	4D
0005434925636	6300	16	4E
0005434443618	6300	17	4F
0005433496794	6300	18	5A
0005434925612	6300	19	5C
0005434925644	6300	20	5D
0005434925633	6300	21	5E
0005433496782	6300	22	5F
0005433496781	6300	23	6A
0005434925634	6300	24	6C
0005433496787	6300	25	6D
0005433496802	6300	26	6E
0005434443616	6300	27	6F
0005434443610	6300	28	7A
0005434925624	6300	29	7C
0005434925609	6300	30	7E
0005434925622	6300	31	7F
0005433496793	6300	32	8A
0005434925617	6300	33	8C
0005433496801	6300	34	8D
0005433496783	6300	35	8E
0005433496776	6300	36	8F
0005434443613	6300	37	9A
0005433496792	6300	38	9C
0005434443605	6300	39	9D
0005434925623	6300	40	9E
0005434443608	6300	41	9F
0005434925626	6300	42	10A
0005434925610	6300	43	10C
0005433496795	6300	44	10D
0005434925615	6300	45	10E
0005434925625	6300	46	10F
0005434925650	6300	47	11A
0005433496790	6300	48	11C
0005434925639	6300	49	11D
0005433496789	6300	50	11E
0005433496779	6300	51	11F
0005434443619	6300	52	12A
0005434925637	6300	53	12C
0005434925618	6300	54	12D
0005434925613	6300	55	12E
0005434925630	6300	56	12F
0005433496775	6300	57	13A
0005433496796	6300	58	13C
0005434443614	6300	59	13D
0005434925651	6300	60	13E
0005433496780	6300	61	13F
0005434443617	6300	62	14A
0005434925629	6300	63	14C
0005434925647	6300	64	14D
0005433496773	6300	65	14E
0005434925645	6300	66	14F
0005434925648	6300	67	15A
0005434925620	6300	68	15C
0005433496798	6300	69	15D
0005434443609	6300	70	15E
0005434925628	6300	71	15F
0005434443620	6300	72	16A
0005434443607	6300	73	16C
0005434925611	6300	74	16D
0005434925627	6300	75	16E
0005434925608	6300	76	16F
0005434925643	6300	77	17A
0005433496777	6300	78	17C
0005434443621	6300	79	17D
0005434925642	6300	80	17E
0005434443615	6300	81	17F
0005434925638	6300	82	18A
0005433496772	6300	83	18C
0005433496788	6300	84	18D
0005434925640	6300	85	18E
0005433496778	6300	86	18F
0005434925616	6300	87	19A
0005434443606	6300	88	19C
0005434925614	6300	89	19D
0005433496797	6300	90	19E
0005434925646	6300	91	20A
0005433496786	6300	92	20C
0005433496785	6300	93	20D
0005434925607	6300	94	20E
0005434925621	6300	95	20F
0005434925276	20406	1	1A
0005434925305	20406	2	1C
0005434925361	20406	3	1D
0005434925381	20406	4	1F
0005434443442	20406	5	2C
0005434925265	20406	6	2F
0005433496629	20406	7	3A
0005434443437	20406	8	3C
0005433496640	20406	9	3D
0005434925306	20406	10	3F
0005434443488	20406	11	4A
0005434925266	20406	12	4C
0005434443436	20406	13	4E
0005434925278	20406	14	4F
0005434443486	20406	15	5A
0005433496493	20406	16	5C
0005433496571	20406	17	5D
0005434925319	20406	18	5E
0005433496501	20406	19	6C
0005434925312	20406	20	6E
0005433496569	20406	21	7C
0005434925457	20406	22	7E
0005434925311	20406	23	7F
0005434925320	20406	24	8E
0005434925360	20406	25	9A
0005434925359	20406	26	9C
0005434925412	20406	27	9D
0005434925263	20406	28	9E
0005434925341	20406	29	9F
0005433496534	20406	30	10A
0005433496625	20406	31	10C
0005434925262	20406	32	10D
0005434443455	20406	33	10E
0005434925353	20406	34	10F
0005433496478	20406	35	11C
0005434925301	20406	36	11F
0005434925340	20406	37	12A
0005434925277	20406	38	12D
0005433496479	20406	39	12E
0005434925387	20406	40	12F
0005434443449	20406	41	13A
0005433496639	20406	42	13F
0005434925358	20406	43	14D
0005434443487	20406	44	14E
0005434443472	20406	45	14F
0005434925459	20406	46	15C
0005434443443	20406	47	15D
0005434443514	20406	48	15E
0005434925253	20406	49	15F
0005434443513	20406	50	16A
0005433496582	20406	51	16D
0005434443500	20406	52	16E
0005433496528	20406	53	16F
0005433496724	20406	54	17A
0005434925458	20406	55	17C
0005433496500	20406	56	17E
0005433496590	20406	57	18A
0005434443461	20406	58	18D
0005434443477	20406	59	18E
0005434925254	20406	60	18F
0005434925304	20406	61	19A
0005433496630	20406	62	19C
0005433496568	20406	63	19F
0005434925411	20406	64	20E
0005432782896	12164	1	1A
0005432782969	12164	2	1C
0005435242719	12164	3	2A
0005435242692	12164	4	2C
0005435242713	12164	5	2D
0005432782897	12164	6	2F
0005435242693	12164	7	3C
0005435242712	12164	8	3F
0005432783016	12164	9	4A
0005432782937	12164	10	4C
0005432783025	12164	11	4D
0005435242714	12164	12	4E
0005432783023	12164	13	5C
0005432782842	12164	14	6C
0005432783247	12164	15	6D
0005432782957	12164	16	6F
0005435242709	12164	17	7A
0005432783069	12164	18	7C
0005435242703	12164	19	7D
0005432782940	12164	20	7E
0005435242707	12164	21	7F
0005435242716	12164	22	8A
0005432782917	12164	23	8C
0005435242700	12164	24	8D
0005432782951	12164	25	8E
0005432782954	12164	26	8F
0005432783106	12164	27	9C
0005432783052	12164	28	9E
0005432783134	12164	29	9F
0005432783098	12164	30	10A
0005435242697	12164	31	10C
0005432783047	12164	32	10E
0005432783077	12164	33	10F
0005432783094	12164	34	11A
0005435242711	12164	35	11C
0005435242715	12164	36	11D
0005435242702	12164	37	11F
0005432783068	12164	38	12A
0005432783099	12164	39	12D
0005432783093	12164	40	12E
0005435242696	12164	41	13A
0005432783041	12164	42	13D
0005435242699	12164	43	13E
0005432782959	12164	44	14A
0005432782852	12164	45	14C
0005435242701	12164	46	14D
0005432782941	12164	47	15A
0005432783051	12164	48	15C
0005435242710	12164	49	15E
0005432783164	12164	50	15F
0005432783046	12164	51	16C
0005435242694	12164	52	16E
0005432783013	12164	53	16F
0005435242708	12164	54	17A
0005435242717	12164	55	17C
0005435242695	12164	56	17D
0005432782949	12164	57	17E
0005432782970	12164	58	18A
0005432783087	12164	59	18C
0005435242718	12164	60	18D
0005435242704	12164	61	19A
0005435242706	12164	62	19C
0005432782950	12164	63	19D
0005432783108	12164	64	19F
0005435242705	12164	65	20C
0005432783201	12164	66	20D
0005435242698	12164	67	20E
0005435242512	15413	1	1C
0005432783422	15413	2	1F
0005435242457	15413	3	2A
0005432783427	15413	4	2D
0005435242412	15413	5	3C
0005432783439	15413	6	4C
0005432783399	15413	7	4D
0005432783426	15413	8	4F
0005432783411	15413	9	5C
0005432783401	15413	10	5D
0005432783408	15413	11	5E
0005432783443	15413	12	5F
0005432783418	15413	13	6A
0005432783395	15413	14	6C
0005432783438	15413	15	6D
0005432783425	15413	16	6E
0005432783437	15413	17	6F
0005435242480	15413	18	7A
0005432783397	15413	19	7D
0005432783416	15413	20	7E
0005432783430	15413	21	8A
0005432783434	15413	22	8C
0005432783440	15413	23	8F
0005432783415	15413	24	9A
0005432783410	15413	25	9C
0005435242553	15413	26	9D
0005432783428	15413	27	9E
0005432783424	15413	28	9F
0005432783419	15413	29	10A
0005435242481	15413	30	10C
0005432783396	15413	31	10D
0005432783400	15413	32	10E
0005432783402	15413	33	10F
0005435242428	15413	34	11C
0005432783431	15413	35	11E
0005432783442	15413	36	11F
0005432783393	15413	37	12A
0005432783433	15413	38	12D
0005432783407	15413	39	12F
0005432783423	15413	40	13A
0005435242448	15413	41	13D
0005432783435	15413	42	13E
0005432783398	15413	43	14A
0005432783404	15413	44	14C
0005432783391	15413	45	14F
0005435242456	15413	46	15A
0005432783432	15413	47	15C
0005432783406	15413	48	15E
0005432783403	15413	49	15F
0005432783436	15413	50	16C
0005432783413	15413	51	16E
0005432783394	15413	52	17C
0005432783417	15413	53	17D
0005432783421	15413	54	17F
0005432783420	15413	55	18C
0005435242418	15413	56	18D
0005432783412	15413	57	18E
0005435242552	15413	58	18F
0005435242389	15413	59	19A
0005432783392	15413	60	19C
0005435242403	15413	61	19D
0005432783409	15413	62	19F
0005432783441	15413	63	20A
0005432783414	15413	64	20C
0005435242390	15413	65	20D
0005432783429	15413	66	20E
0005432783405	15413	67	20F
0005434876677	10066	1	1C
0005434876938	10066	2	1A
0005434876890	10066	3	1D
0005434876885	10066	4	2A
0005434876793	10066	5	1F
0005434876901	10066	6	2D
0005434876785	10066	7	2C
0005434876768	10066	8	3A
0005434876652	10066	9	2F
0005434876914	10066	10	3C
0005435913913	10066	11	3F
0005434876685	10066	12	4C
0005434876959	10066	13	4F
0005434876877	10066	14	4D
0005434876967	10066	15	5C
0005434876584	10066	16	5F
0005434876911	10066	17	5D
0005434877197	10066	18	6A
0005434877018	10066	19	6D
0005434876941	10066	20	6C
0005434876792	10066	21	6E
0005434876946	10066	22	7A
0005434876870	10066	23	6F
0005434876940	10066	24	7B
0005434876569	10066	25	7E
0005434876610	10066	26	7D
0005435913915	10066	27	8A
0005434910098	10066	28	8C
0005435913922	10066	29	8B
0005434758852	10066	30	8E
0005434877000	10066	31	8D
0005434876567	10066	32	8F
0005434876765	10066	33	9B
0005434877027	10066	34	9A
0005434876939	10066	35	9C
0005434876912	10066	36	9F
0005434876924	10066	37	9E
0005434876869	10066	38	9D
0005434877193	10066	39	10A
0005434876664	10066	40	10B
0005434876619	10066	41	10E
0005434876735	10066	42	10D
0005434876718	10066	43	11A
0005434876896	10066	44	10F
0005434877014	10066	45	11B
0005434876724	10066	46	11D
0005434876802	10066	47	11C
0005434876934	10066	48	11E
0005434876746	10066	49	12B
0005434876657	10066	50	12C
0005434877143	10066	51	12F
0005434877129	10066	52	12E
0005434876658	10066	53	13A
0005435913918	10066	54	13E
0005434876726	10066	55	13D
0005434876745	10066	56	14A
0005434876921	10066	57	13F
0005434876996	10066	58	14B
0005434876937	10066	59	14C
0005435913921	10066	60	14F
0005434876777	10066	61	15A
0005434876935	10066	62	15D
0005434876860	10066	63	15C
0005434876878	10066	64	15E
0005434876796	10066	65	16A
0005434910097	10066	66	15F
0005434877007	10066	67	16C
0005434876767	10066	68	16B
0005434876861	10066	69	16D
0005435913914	10066	70	16E
0005435913923	10066	71	17B
0005435913912	10066	72	17A
0005434758867	10066	73	17D
0005434876801	10066	74	17F
0005435913919	10066	75	17E
0005434876725	10066	76	18B
0005434876836	10066	77	18A
0005434876690	10066	78	18C
0005435913920	10066	79	18E
0005434910096	10066	80	18D
0005435913916	10066	81	18F
0005434876968	10066	82	19C
0005434876766	10066	83	19B
0005434876913	10066	84	19D
0005434876958	10066	85	20B
0005434876868	10066	86	20A
0005434876697	10066	87	20D
0005434877001	10066	88	20C
0005434876891	10066	89	20E
0005434876862	10066	90	21B
0005434910095	10066	91	21C
0005434876879	10066	92	21F
0005434877142	10066	93	21E
0005435913917	10066	94	21D
0005434877638	14616	1	1A
0005434877696	14616	2	1F
0005434877683	14616	3	1D
0005434877694	14616	4	1C
0005434877691	14616	5	2C
0005434877648	14616	6	2A
0005434877673	14616	7	2F
0005434877649	14616	8	3A
0005434877669	14616	9	3D
0005434877674	14616	10	3C
0005434877709	14616	11	4A
0005434877716	14616	12	4C
0005434877641	14616	13	4F
0005434877637	14616	14	4D
0005434877657	14616	15	5C
0005434877645	14616	16	5A
0005434877702	14616	17	5F
0005434877697	14616	18	5D
0005434877640	14616	19	6B
0005434877699	14616	20	6A
0005434877704	14616	21	6C
0005434877670	14616	22	6E
0005434758878	14616	23	6D
0005434877650	14616	24	7A
0005434877678	14616	25	6F
0005434877661	14616	26	7C
0005434877695	14616	27	7B
0005434877705	14616	28	7E
0005434877676	14616	29	8A
0005434877627	14616	30	7F
0005434877701	14616	31	8C
0005435913850	14616	32	8B
0005434877662	14616	33	8D
0005434877642	14616	34	8F
0005434877700	14616	35	8E
0005434877710	14616	36	9B
0005434877632	14616	37	9A
0005434877646	14616	38	9C
0005434910087	14616	39	9E
0005434877714	14616	40	10B
0005435913854	14616	41	10A
0005434877671	14616	42	9F
0005434877652	14616	43	10C
0005434877677	14616	44	10E
0005434758879	14616	45	10D
0005434877629	14616	46	11A
0005434877659	14616	47	10F
0005434877625	14616	48	11B
0005434877684	14616	49	11C
0005434877668	14616	50	11F
0005434877656	14616	51	12B
0005434877655	14616	52	12A
0005434877626	14616	53	12C
0005434877689	14616	54	12F
0005434877663	14616	55	12E
0005434877692	14616	56	13A
0005434877682	14616	57	13C
0005434877708	14616	58	13B
0005434877712	14616	59	13E
0005434877654	14616	60	13D
0005434877693	14616	61	14A
0005434877633	14616	62	13F
0005434877703	14616	63	14C
0005434877647	14616	64	14B
0005434877622	14616	65	14F
0005435913857	14616	66	15B
0005434877706	14616	67	15E
0005434877707	14616	68	15D
0005434877630	14616	69	16A
0005434877639	14616	70	15F
0005434877711	14616	71	16C
0005434877658	14616	72	16B
0005434877679	14616	73	16D
0005435913855	14616	74	16F
0005435913853	14616	75	16E
0005434877664	14616	76	17B
0005434877687	14616	77	17A
0005434877628	14616	78	17D
0005434877685	14616	79	17C
0005434877660	14616	80	17F
0005434877631	14616	81	17E
0005434877690	14616	82	18A
0005434877643	14616	83	18D
0005434877688	14616	84	18C
0005434910086	14616	85	18B
0005434877621	14616	86	18E
0005434877713	14616	87	19A
0005434877624	14616	88	18F
0005434877653	14616	89	19C
0005434877665	14616	90	19B
0005434877680	14616	91	19E
0005434877666	14616	92	19D
0005434877644	14616	93	19F
0005434877651	14616	94	20B
0005434877623	14616	95	20A
0005434877672	14616	96	20D
0005434877698	14616	97	20C
0005434877667	14616	98	20E
0005434877681	14616	99	21B
0005434877686	14616	100	21A
0005434877675	14616	101	20F
0005434877634	14616	102	21C
0005434877715	14616	103	21E
0005434877636	14616	104	21D
0005434877635	14616	105	21F
0005435660065	9242	1	1C
0005435660074	9242	2	1D
0005435660067	9242	3	2A
0005434251815	9242	4	2B
0005434251816	9242	5	2C
0005434251837	9242	6	3D
0005434251834	9242	7	4A
0005435660075	9242	8	5B
0005435660070	9242	9	5D
0005434251836	9242	10	6A
0005435660072	9242	11	6C
0005434251817	9242	12	6D
0005435660063	9242	13	7B
0005434251833	9242	14	18A
0005434251828	9242	15	18B
0005435660073	9242	16	19B
0005435660069	9242	17	19C
0005434251838	9242	18	21A
0005435660068	9242	19	21C
0005435660064	9242	20	21D
0005435660066	9242	21	22C
0005435660071	9242	22	23A
0005434251902	24650	1	1B
0005434251907	24650	2	1D
0005435659949	24650	3	3B
0005434251909	24650	4	4B
0005435659962	24650	5	4D
0005435659972	24650	6	5B
0005435659991	24650	7	5D
0005435660001	24650	8	6A
0005435659979	24650	9	6C
0005434251911	24650	10	7D
0005435659967	24650	11	18A
0005434251904	24650	12	18B
0005435659957	24650	13	18C
0005435659978	24650	14	19B
0005435659976	24650	15	20C
0005435659999	24650	16	21A
0005435659966	24650	17	21B
0005434251905	24650	18	21C
0005434251903	24650	19	21D
0005434251906	24650	20	22A
0005435659958	24650	21	22B
0005434251908	24650	22	22C
0005434251910	24650	23	22D
0005435659980	24650	24	23B
0005433680295	2800	1	1A
0005432966543	2800	2	1C
0005433680254	2800	3	1D
0005432222747	2800	4	1F
0005432222752	2800	5	2A
0005433680258	2800	6	2C
0005433680267	2800	7	2F
0005433680262	2800	8	3A
0005433680274	2800	9	3C
0005433680247	2800	10	3D
0005433680271	2800	11	3F
0005432222749	2800	12	4A
0005433680263	2800	13	4C
0005433680269	2800	14	4D
0005432966508	2800	15	4E
0005433680261	2800	16	5A
0005432966567	2800	17	5C
0005433680290	2800	18	5D
0005433680265	2800	19	5F
0005432966541	2800	20	6C
0005433680283	2800	21	6D
0005432966500	2800	22	6E
0005433684406	2800	23	6F
0005432966533	2800	24	7A
0005433680249	2800	25	7C
0005433680277	2800	26	7D
0005433680251	2800	27	7E
0005433680248	2800	28	8C
0005433680268	2800	29	8D
0005433680255	2800	30	8E
0005433680276	2800	31	8F
0005433680256	2800	32	9A
0005433680284	2800	33	9C
0005432222748	2800	34	9D
0005432966613	2800	35	9E
0005432966568	2800	36	9F
0005432966601	2800	37	10A
0005432222750	2800	38	10C
0005433680281	2800	39	10D
0005433680291	2800	40	10E
0005433680252	2800	41	11A
0005433680289	2800	42	11C
0005433680253	2800	43	11E
0005433680273	2800	44	12A
0005433680275	2800	45	12D
0005433680282	2800	46	13A
0005432966674	2800	47	13C
0005433680292	2800	48	13D
0005433680250	2800	49	13E
0005432966501	2800	50	13F
0005432966487	2800	51	14A
0005433680264	2800	52	14C
0005433680272	2800	53	14E
0005433680293	2800	54	15A
0005433680266	2800	55	15D
0005433680259	2800	56	15E
0005433680270	2800	57	15F
0005432966542	2800	58	16A
0005432966538	2800	59	16C
0005432966488	2800	60	16E
0005432966603	2800	61	16F
0005432966489	2800	62	17A
0005433680286	2800	63	17C
0005433680280	2800	64	17D
0005433680294	2800	65	17E
0005433680288	2800	66	17F
0005433680287	2800	67	18A
0005432222751	2800	68	18C
0005433680257	2800	69	19A
0005433680279	2800	70	19C
0005432966546	2800	71	19D
0005433680285	2800	72	19E
0005432966602	2800	73	19F
0005433680278	2800	74	20A
0005433680260	2800	75	20D
0005432966534	2800	76	20E
0005432966770	29147	1	1C
0005433679881	29147	2	1D
0005432966782	29147	3	1F
0005432966772	29147	4	2A
0005432966780	29147	5	2C
0005433679889	29147	6	2F
0005432966776	29147	7	3A
0005432966785	29147	8	3C
0005432966768	29147	9	3D
0005433679992	29147	10	4C
0005432966786	29147	11	4D
0005433679962	29147	12	4E
0005433679926	29147	13	4F
0005433679741	29147	14	5A
0005432966773	29147	15	5C
0005433679740	29147	16	5D
0005433679942	29147	17	5F
0005433680113	29147	18	6C
0005432966771	29147	19	6E
0005433679793	29147	20	6F
0005432966790	29147	21	7C
0005433680067	29147	22	7D
0005432966775	29147	23	7F
0005432966779	29147	24	8A
0005433679747	29147	25	8C
0005433679961	29147	26	8D
0005433679927	29147	27	8E
0005432966792	29147	28	8F
0005432966774	29147	29	9D
0005433679877	29147	30	10A
0005433680191	29147	31	10C
0005432966787	29147	32	10E
0005433679853	29147	33	10F
0005432966778	29147	34	11C
0005433679817	29147	35	11D
0005433679880	29147	36	11E
0005433680005	29147	37	11F
0005432966777	29147	38	12A
0005432966788	29147	39	12D
0005433680135	29147	40	12E
0005433679876	29147	41	13A
0005433680049	29147	42	14C
0005432005195	29147	43	14E
0005432966789	29147	44	14F
0005432005196	29147	45	15A
0005433680066	29147	46	15C
0005433679794	29147	47	15D
0005432966791	29147	48	15E
0005432005197	29147	49	15F
0005433679956	29147	50	16A
0005433679854	29147	51	16C
0005433679792	29147	52	16D
0005433679949	29147	53	16F
0005433679921	29147	54	17A
0005433679875	29147	55	17D
0005433679864	29147	56	17E
0005432966783	29147	57	17F
0005433679842	29147	58	18A
0005432966784	29147	59	18D
0005432966781	29147	60	18E
0005433679728	29147	61	19C
0005433679879	29147	62	19D
0005433680047	29147	63	19E
0005432966769	29147	64	20E
0005433633564	9326	1	1A
0005433614141	9326	2	1D
0005434163483	9326	3	1C
0005433614204	9326	4	1F
0005433614139	9326	5	2A
0005433614138	9326	6	2C
0005433614140	9326	7	2D
0005433614153	9326	8	3A
0005433614151	9326	9	2F
0005433633585	9326	10	3C
0005433614182	9326	11	3F
0005433614170	9326	12	3D
0005433614158	9326	13	4A
0005433577721	9326	14	4D
0005432145097	9326	15	4C
0005433614199	9326	16	4F
0005433633568	9326	17	5A
0005433577723	9326	18	5C
0005433577724	9326	19	5F
0005433614167	9326	20	5D
0005434269067	9326	21	6A
0005433614174	9326	22	6C
0005434163498	9326	23	6D
0005434269069	9326	24	7A
0005433614168	9326	25	6F
0005433614198	9326	26	7D
0005433633595	9326	27	7C
0005432756826	9326	28	7F
0005433614150	9326	29	8A
0005433614162	9326	30	8B
0005432755055	9326	31	8D
0005433577715	9326	32	8C
0005433614136	9326	33	8E
0005433633576	9326	34	8F
0005433633584	9326	35	9B
0005433614137	9326	36	9A
0005433633579	9326	37	9D
0005433614164	9326	38	9E
0005433577726	9326	39	10A
0005433633580	9326	40	10B
0005433614188	9326	41	10C
0005433577719	9326	42	10E
0005433577722	9326	43	10D
0005433633590	9326	44	10F
0005433577718	9326	45	11B
0005433577717	9326	46	11A
0005433614202	9326	47	11C
0005433614152	9326	48	11D
0005434269079	9326	49	11E
0005433614146	9326	50	12A
0005433614206	9326	51	11F
0005433614144	9326	52	12B
0005433614209	9326	53	12D
0005433614205	9326	54	12E
0005433614176	9326	55	12F
0005433614185	9326	56	13B
0005433633571	9326	57	13A
0005433633587	9326	58	13C
0005433633597	9326	59	13D
0005434269078	9326	60	13F
0005433633589	9326	61	13E
0005432755054	9326	62	14A
0005433614181	9326	63	14B
0005433633572	9326	64	14D
0005432756825	9326	65	14C
0005433614172	9326	66	14E
0005433614142	9326	67	14F
0005434163490	9326	68	15A
0005432755052	9326	69	15C
0005433614156	9326	70	15D
0005433614179	9326	71	15E
0005434152753	9326	72	16A
0005433614184	9326	73	16B
0005433614154	9326	74	16C
0005433577720	9326	75	16E
0005433614192	9326	76	16D
0005434163497	9326	77	17A
0005433633567	9326	78	17C
0005433614157	9326	79	17D
0005433614145	9326	80	17F
0005433614160	9326	81	17E
0005433633593	9326	82	18A
0005433614169	9326	83	18B
0005433614166	9326	84	18D
0005432756827	9326	85	18C
0005433633596	9326	86	18E
0005433614208	9326	87	19B
0005433614195	9326	88	18F
0005434163470	9326	89	19D
0005433633569	9326	90	19C
0005433633581	9326	91	20A
0005433577714	9326	92	19E
0005433633574	9326	93	20B
0005433614155	9326	94	20D
0005433614197	9326	95	20C
0005433614163	9326	96	20F
0005434163491	9326	97	21B
0005433633592	9326	98	21A
0005434163499	9326	99	21C
0005433633582	9326	100	21D
0005434269068	9326	101	22A
0005433614187	9326	102	21F
0005433633594	9326	103	22B
0005433614194	9326	104	22C
0005433633588	9326	105	22E
0005434163467	9326	106	22D
0005433614180	9326	107	22F
0005434163475	9326	108	23A
0005433577716	9326	109	23C
0005433614186	9326	110	23B
0005433614183	9326	111	23D
0005433614175	9326	112	23E
0005433614196	9326	113	24A
0005433633578	9326	114	23F
0005433633562	9326	115	24B
0005433633566	9326	116	24C
0005434272161	9326	117	24E
0005434152759	9326	118	24D
0005434272168	9326	119	24F
0005434152754	9326	120	25B
0005433614171	9326	121	25A
0005434152758	9326	122	25C
0005433614149	9326	123	25D
0005433633577	9326	124	25E
0005433614147	9326	125	25F
0005433633573	9326	126	26B
0005432145096	9326	127	26A
0005434153526	9326	128	26C
0005434163517	9326	129	26E
0005432145098	9326	130	26D
0005433614191	9326	131	26F
0005433577713	9326	132	27A
0005433633583	9326	133	27C
0005433614165	9326	134	27B
0005433633598	9326	135	27D
0005433614203	9326	136	27F
0005433577725	9326	137	27E
0005433633586	9326	138	28A
0005433614200	9326	139	28B
0005433614161	9326	140	28D
0005433633575	9326	141	28E
0005433614189	9326	142	28F
0005433614190	9326	143	29B
0005432755053	9326	144	29C
0005433614135	9326	145	29D
0005433633563	9326	146	29E
0005433614148	9326	147	30A
0005433614207	9326	148	29F
0005433614178	9326	149	30B
0005433633570	9326	150	30D
0005433633591	9326	151	30C
0005433614159	9326	152	30F
0005433614201	9326	153	30E
0005433614173	9326	154	31A
0005433614177	9326	155	31D
0005433633565	9326	156	31C
0005433614143	9326	157	31E
0005433614193	9326	158	31F
0005433613718	25217	1	1C
0005433613640	25217	2	1D
0005433613474	25217	3	2A
0005433577578	25217	4	1F
0005434163568	25217	5	2C
0005433633360	25217	6	2F
0005433633268	25217	7	2D
0005433633265	25217	8	3A
0005433613463	25217	9	3C
0005434163564	25217	10	4A
0005433613679	25217	11	4C
0005434163566	25217	12	4F
0005433613717	25217	13	4D
0005433613449	25217	14	5A
0005433613800	25217	15	5F
0005433633263	25217	16	6A
0005433633267	25217	17	6D
0005434163562	25217	18	7A
0005433613707	25217	19	6F
0005433613784	25217	20	7C
0005433613753	25217	21	7F
0005433613446	25217	22	7D
0005433613826	25217	23	8A
0005433633351	25217	24	8B
0005433613411	25217	25	8F
0005433633237	25217	26	9B
0005433633258	25217	27	9C
0005433613473	25217	28	9E
0005433613639	25217	29	10A
0005433633294	25217	30	10B
0005433633293	25217	31	10D
0005434273065	25217	32	10C
0005433613514	25217	33	10E
0005434163563	25217	34	10F
0005433633228	25217	35	11B
0005433633387	25217	36	11A
0005433633264	25217	37	11C
0005433577564	25217	38	11D
0005433633239	25217	39	11F
0005434163569	25217	40	11E
0005433613549	25217	41	12A
0005433613465	25217	42	12B
0005433613708	25217	43	12C
0005433613500	25217	44	13B
0005433633280	25217	45	13D
0005433613488	25217	46	13F
0005433577577	25217	47	13E
0005433613669	25217	48	14A
0005433633349	25217	49	14C
0005433613682	25217	50	14E
0005433633261	25217	51	14F
0005433633260	25217	52	15A
0005433613557	25217	53	15C
0005433613403	25217	54	15B
0005433633343	25217	55	15E
0005433613659	25217	56	15D
0005433633350	25217	57	16A
0005433633262	25217	58	15F
0005433577623	25217	59	16C
0005433613709	25217	60	16B
0005433633229	25217	61	16D
0005434163565	25217	62	16F
0005433613541	25217	63	17B
0005433613404	25217	64	17A
0005434163560	25217	65	17C
0005433633310	25217	66	17F
0005433577594	25217	67	17E
0005433577629	25217	68	18C
0005433613681	25217	69	18E
0005433613422	25217	70	18D
0005433577585	25217	71	18F
0005433613528	25217	72	19B
0005433613579	25217	73	19D
0005433613481	25217	74	19C
0005433613542	25217	75	19E
0005434163570	25217	76	20C
0005433633259	25217	77	20B
0005433633311	25217	78	20E
0005433613751	25217	79	20D
0005433633238	25217	80	20F
0005433613628	25217	81	21B
0005433613470	25217	82	21A
0005434163567	25217	83	21C
0005433613641	25217	84	21E
0005433613475	25217	85	21D
0005433633300	25217	86	21F
0005433613543	25217	87	22B
0005433613821	25217	88	22A
0005433613425	25217	89	22C
0005433613501	25217	90	22F
0005433577637	25217	91	23A
0005433633331	25217	92	23C
0005433613400	25217	93	23D
0005433613788	25217	94	23E
0005433613402	25217	95	24A
0005433613489	25217	96	23F
0005433613401	25217	97	24B
0005433613635	25217	98	24C
0005433633384	25217	99	24E
0005433633364	25217	100	24D
0005433633356	25217	101	24F
0005434272180	25217	102	25A
0005433613513	25217	103	25C
0005433633266	25217	104	25B
0005433613445	25217	105	25D
0005433613450	25217	106	25F
0005433633348	25217	107	25E
0005433613458	25217	108	26A
0005433613595	25217	109	26B
0005433633298	25217	110	26C
0005433613654	25217	111	26E
0005433577617	25217	112	26F
0005433613550	25217	113	27A
0005433613576	25217	114	27B
0005433613754	25217	115	27D
0005433613556	25217	116	27C
0005433577653	25217	117	27F
0005433613577	25217	118	28A
0005434273066	25217	119	28C
0005433613634	25217	120	28E
0005433613733	25217	121	28D
0005433577596	25217	122	28F
0005433613760	25217	123	29A
0005433613396	25217	124	29C
0005433613560	25217	125	29B
0005433613457	25217	126	29D
0005433633326	25217	127	29E
0005434163561	25217	128	29F
0005433613769	25217	129	30B
0005433633325	25217	130	30D
0005433613578	25217	131	30C
0005433633304	25217	132	30E
0005433613759	25217	133	30F
0005433613783	25217	134	31B
0005433613476	25217	135	31C
0005433577624	25217	136	31F
0005435856154	4216	1	1B
0005435947049	4216	2	1G
0005432184934	4216	3	2B
0005435947047	4216	4	4H
0005434271285	4216	5	5C
0005432184932	4216	6	14A
0005435856167	4216	7	14D
0005435947005	4216	8	14F
0005435856141	4216	9	16F
0005435856153	4216	10	17F
0005432571266	4216	11	18G
0005432571273	4216	12	19E
0005435946999	4216	13	19D
0005435947055	4216	14	19H
0005435986717	4216	15	21D
0005435947056	4216	16	21F
0005432571274	4216	17	22B
0005435986716	4216	18	23H
0005432184935	4216	19	24B
0005435947044	4216	20	25D
0005435947094	4216	21	27H
0005434271284	4216	22	28E
0005435947032	4216	23	29F
0005435947014	4216	24	30B
0005435947099	4216	25	30A
0005432184933	4216	26	30E
0005435947000	4216	27	31E
0005435947035	4216	28	32E
0005435947093	4216	29	33B
0005435947048	4216	30	34B
0005435947062	4216	31	35H
0005434271275	4216	32	36F
0005435856139	4216	33	36G
0005435947034	4216	34	36H
0005435947013	4216	35	37F
0005435856140	4216	36	37H
0005435856138	4216	37	38F
0005435986654	26593	1	2A
0005435856179	26593	2	1H
0005435947165	26593	3	3B
0005435986661	26593	4	3F
0005435947167	26593	5	3G
0005432571302	26593	6	4A
0005435947170	26593	7	9G
0005435947173	26593	8	11B
0005435947161	26593	9	12A
0005435947166	26593	10	11H
0005432571300	26593	11	12D
0005435787343	26593	12	12E
0005432571299	26593	13	13F
0005435856180	26593	14	16E
0005435947164	26593	15	18F
0005435986663	26593	16	18H
0005435947163	26593	17	19A
0005435947171	26593	18	19D
0005435986660	26593	19	23G
0005435787342	26593	20	24D
0005435856178	26593	21	24E
0005432571301	26593	22	25E
0005435787341	26593	23	27D
0005435947162	26593	24	27H
0005435947160	26593	25	28B
0005435856177	26593	26	31E
0005435947169	26593	27	32F
0005435947168	26593	28	35F
0005435947174	26593	29	38B
0005435947172	26593	30	39E
0005433568695	308	1	1C
0005433568697	308	2	1D
0005433074202	308	3	1F
0005433134080	308	4	2C
0005432947969	308	5	2F
0005433568693	308	6	2D
0005433568707	308	7	3A
0005433074337	308	8	3C
0005432947951	308	9	3D
0005433134075	308	10	4A
0005433568714	308	11	3F
0005433568730	308	12	4D
0005433568709	308	13	4C
0005433074272	308	14	4F
0005433074359	308	15	5C
0005433074240	308	16	5A
0005433134066	308	17	5F
0005433074338	308	18	5D
0005433568684	308	19	6A
0005433568722	308	20	6C
0005432947780	308	21	6D
0005433568712	308	22	6F
0005433134097	308	23	7C
0005432947921	308	24	7F
0005432238902	308	25	7D
0005433568687	308	26	8A
0005432238898	308	27	8C
0005433568731	308	28	8D
0005432947816	308	29	8F
0005432948008	308	30	9B
0005432947832	308	31	9A
0005432947767	308	32	9C
0005433568708	308	33	9D
0005433074197	308	34	9E
0005432947901	308	35	10A
0005433568728	308	36	9F
0005432238903	308	37	10C
0005432947866	308	38	10B
0005433074317	308	39	10E
0005433074320	308	40	10D
0005432947970	308	41	10F
0005432947875	308	42	11B
0005432947802	308	43	11A
0005433568681	308	44	11C
0005432947924	308	45	11D
0005433568706	308	46	12A
0005433568700	308	47	11F
0005433568736	308	48	12C
0005432947918	308	49	12B
0005433074374	308	50	12E
0005433074392	308	51	12D
0005433074393	308	52	13A
0005433568710	308	53	12F
0005433568725	308	54	13C
0005432238899	308	55	13B
0005433074324	308	56	13D
0005432947911	308	57	13E
0005432947923	308	58	14A
0005432947848	308	59	14C
0005433074383	308	60	14B
0005433568685	308	61	14E
0005433568727	308	62	14D
0005433568691	308	63	14F
0005432947902	308	64	15B
0005433134069	308	65	15A
0005432947922	308	66	15C
0005433568680	308	67	15D
0005433129204	308	68	15F
0005433568711	308	69	15E
0005432947768	308	70	16A
0005433568688	308	71	16B
0005433134078	308	72	16D
0005433074325	308	73	16C
0005433568726	308	74	16E
0005432947781	308	75	17A
0005433568689	308	76	16F
0005432947828	308	77	17C
0005433568732	308	78	17B
0005432947815	308	79	17E
0005433568698	308	80	17D
0005433568694	308	81	17F
0005432238900	308	82	18A
0005433568682	308	83	18B
0005432947950	308	84	18C
0005433074364	308	85	18E
0005433074349	308	86	18F
0005433134068	308	87	19B
0005432238897	308	88	19D
0005433568704	308	89	19C
0005433568716	308	90	20A
0005433568699	308	91	20C
0005433074309	308	92	20D
0005432947766	308	93	20F
0005433568690	308	94	20E
0005433568720	308	95	21A
0005432947801	308	96	21B
0005433568696	308	97	21D
0005433568692	308	98	21E
0005432947904	308	99	22A
0005432947844	308	100	21F
0005432947822	308	101	22D
0005432947820	308	102	22C
0005433568729	308	103	22B
0005432947814	308	104	22F
0005433134063	308	105	22E
0005433568715	308	106	23B
0005432947831	308	107	23D
0005432238901	308	108	23C
0005433568703	308	109	24D
0005432947863	308	110	24F
0005432947870	308	111	24E
0005433074228	308	112	25B
0005433568702	308	113	25A
0005433568723	308	114	25C
0005433568721	308	115	25D
0005432947900	308	116	25E
0005432947871	308	117	26A
0005433134067	308	118	25F
0005432947952	308	119	26C
0005433568701	308	120	26D
0005432948009	308	121	26F
0005433568718	308	122	27B
0005432947845	308	123	27A
0005433568734	308	124	27C
0005432947813	308	125	27D
0005433568724	308	126	27F
0005432947885	308	127	28A
0005433074348	308	128	28B
0005433568686	308	129	28D
0005433074329	308	130	28C
0005433568717	308	131	28E
0005433568705	308	132	28F
0005433074232	308	133	29B
0005433568733	308	134	29A
0005433568683	308	135	29C
0005433568735	308	136	29D
0005433568713	308	137	29F
0005433074239	308	138	29E
0005432948082	308	139	30A
0005433134074	308	140	30B
0005433074227	308	141	30D
0005433074367	308	142	30C
0005432947782	308	143	30E
0005433129205	308	144	31A
0005433568719	308	145	30F
0005433568737	308	146	31C
0005433129210	308	147	31E
0005433074382	308	148	31D
0005432947929	308	149	31F
0005432948191	11585	1	1A
0005433568218	11585	2	1C
0005433074532	11585	3	1F
0005432948195	11585	4	2A
0005433568016	11585	5	2C
0005432948211	11585	6	2F
0005432948212	11585	7	2D
0005433568031	11585	8	3C
0005433074528	11585	9	3D
0005433568121	11585	10	4A
0005433568058	11585	11	3F
0005433074540	11585	12	4C
0005433568183	11585	13	4D
0005433568134	11585	14	5A
0005433074541	11585	15	5C
0005433568018	11585	16	5F
0005433074534	11585	17	5D
0005432948207	11585	18	6C
0005433134108	11585	19	6A
0005433568215	11585	20	6F
0005433568041	11585	21	6D
0005433134109	11585	22	7A
0005433074531	11585	23	7F
0005433568104	11585	24	7D
0005432948200	11585	25	8D
0005433568059	11585	26	8C
0005433568198	11585	27	9A
0005433131678	11585	28	8F
0005433074535	11585	29	9D
0005433568098	11585	30	9E
0005433074521	11585	31	10A
0005433568184	11585	32	10B
0005433568063	11585	33	10C
0005433131681	11585	34	10D
0005433568053	11585	35	11A
0005432948184	11585	36	10F
0005432948190	11585	37	11B
0005432948202	11585	38	11C
0005432192301	11585	39	11D
0005433568159	11585	40	11F
0005433074519	11585	41	12B
0005433568108	11585	42	12C
0005433074533	11585	43	12E
0005433074536	11585	44	13A
0005432948215	11585	45	13B
0005433568182	11585	46	13D
0005432948217	11585	47	13C
0005432948204	11585	48	13E
0005432948196	11585	49	14A
0005432948221	11585	50	14D
0005433074537	11585	51	14C
0005433568204	11585	52	14E
0005433568162	11585	53	15B
0005433568186	11585	54	15A
0005433568256	11585	55	15E
0005433568029	11585	56	15D
0005433568066	11585	57	15F
0005433568028	11585	58	16A
0005432948218	11585	59	16C
0005432948194	11585	60	16B
0005433568217	11585	61	16D
0005433074520	11585	62	16E
0005433131682	11585	63	17A
0005433074529	11585	64	17C
0005433074538	11585	65	17D
0005433131683	11585	66	17F
0005432948197	11585	67	17E
0005433568097	11585	68	18A
0005432192300	11585	69	18C
0005432948192	11585	70	18B
0005433131680	11585	71	18E
0005433131679	11585	72	19C
0005433568224	11585	73	19B
0005433074539	11585	74	19D
0005433074543	11585	75	20B
0005433134111	11585	76	20A
0005433568096	11585	77	20C
0005433568101	11585	78	20E
0005433074525	11585	79	20D
0005432948219	11585	80	20F
0005433074524	11585	81	21D
0005433568120	11585	82	21E
0005432948199	11585	83	22A
0005433074542	11585	84	22C
0005432948181	11585	85	22D
0005433568019	11585	86	22F
0005432948209	11585	87	23A
0005432948187	11585	88	23C
0005432948203	11585	89	23B
0005433568160	11585	90	23D
0005433568099	11585	91	23E
0005432948216	11585	92	23F
0005433074545	11585	93	24D
0005433568179	11585	94	24C
0005433568140	11585	95	24E
0005432948193	11585	96	24F
0005433568175	11585	97	25A
0005432192299	11585	98	25B
0005433568103	11585	99	25D
0005432948198	11585	100	25C
0005432948189	11585	101	25F
0005433568180	11585	102	25E
0005433568156	11585	103	26A
0005432948220	11585	104	26B
0005433568185	11585	105	26C
0005433074523	11585	106	26D
0005432948183	11585	107	26F
0005432948186	11585	108	27D
0005433134110	11585	109	27E
0005433074522	11585	110	28B
0005433074526	11585	111	28D
0005433568030	11585	112	28C
0005433074530	11585	113	28E
0005432948182	11585	114	28F
0005433568152	11585	115	29B
0005432948206	11585	116	29A
0005432948213	11585	117	29C
0005432948185	11585	118	29D
0005432948210	11585	119	29E
0005432948214	11585	120	30A
0005433074527	11585	121	30B
0005432948201	11585	122	30D
0005432948208	11585	123	30F
0005433074544	11585	124	31B
0005432948188	11585	125	31A
0005432948205	11585	126	31C
0005433568048	11585	127	31D
0005433568155	11585	128	31E
0005433568015	11585	129	31F
0005433817446	9997	1	1A
0005434732931	9997	2	1B
0005433817447	9997	3	3A
0005434732932	9997	4	3B
0005434732942	9997	5	4A
0005434732940	9997	6	4B
0005433817449	9997	7	5A
0005434732930	9997	8	5B
0005433817448	9997	9	6A
0005434732962	13992	1	1B
0005434732961	13992	2	3A
0005434732959	13992	3	5A
0005434732960	13992	4	6A
0005433753875	2358	1	1A
0005432655464	2358	2	1C
0005433434315	2358	3	1B
0005432226016	2358	4	1F
0005433753896	2358	5	1H
0005433766615	2358	6	1G
0005432984572	2358	7	2A
0005435982046	2358	8	2B
0005433753870	2358	9	2F
0005433434249	2358	10	2C
0005433753865	2358	11	2G
0005435982052	2358	12	3A
0005433753893	2358	13	2H
0005432984527	2358	14	3B
0005435982025	2358	15	3C
0005432984628	2358	16	3G
0005432984604	2358	17	3F
0005432655469	2358	18	4A
0005433753859	2358	19	3H
0005433434314	2358	20	4B
0005435982036	2358	21	4C
0005433753905	2358	22	4G
0005433434266	2358	23	4F
0005433753878	2358	24	5A
0005433753887	2358	25	4H
0005432300230	2358	26	5B
0005435982037	2358	27	5F
0005435982041	2358	28	5C
0005432984560	2358	29	5G
0005433753854	2358	30	5H
0005434731108	2358	31	9B
0005432226022	2358	32	9A
0005432655470	2358	33	9G
0005432300226	2358	34	9H
0005432984509	2358	35	11D
0005435982044	2358	36	11B
0005433753879	2358	37	11F
0005433434275	2358	38	11E
0005433434313	2358	39	11H
0005433753908	2358	40	11G
0005432655462	2358	41	12B
0005432984611	2358	42	12A
0005433753864	2358	43	12D
0005432984526	2358	44	12G
0005432300228	2358	45	12F
0005432984645	2358	46	12H
0005435982032	2358	47	13B
0005433766616	2358	48	13A
0005434731114	2358	49	13D
0005433753907	2358	50	13E
0005433753892	2358	51	13F
0005435982042	2358	52	13H
0005433753906	2358	53	14A
0005433753880	2358	54	14D
0005432984571	2358	55	14B
0005432984602	2358	56	14F
0005432984685	2358	57	14E
0005433434333	2358	58	14H
0005432655465	2358	59	14G
0005433434251	2358	60	15A
0005433753868	2358	61	15D
0005433753897	2358	62	15B
0005432300231	2358	63	15E
0005432984591	2358	64	15F
0005432984806	2358	65	15H
0005433753904	2358	66	16B
0005432984630	2358	67	16A
0005435982047	2358	68	16D
0005432655468	2358	69	16F
0005435982029	2358	70	16E
0005433753898	2358	71	16G
0005433753866	2358	72	16H
0005433434241	2358	73	17A
0005432300229	2358	74	17D
0005432226020	2358	75	17B
0005433753909	2358	76	17E
0005435982033	2358	77	17G
0005432984622	2358	78	17F
0005433753890	2358	79	17H
0005432655460	2358	80	18A
0005432984711	2358	81	18D
0005433753860	2358	82	18B
0005435982038	2358	83	18E
0005433753867	2358	84	18G
0005433753872	2358	85	19A
0005433753856	2358	86	18H
0005435982018	2358	87	19B
0005433753901	2358	88	19D
0005433753862	2358	89	19F
0005433753882	2358	90	19H
0005433753883	2358	91	19G
0005432226017	2358	92	20A
0005433434317	2358	93	20D
0005432984670	2358	94	20B
0005435982050	2358	95	20E
0005433434267	2358	96	20F
0005435982040	2358	97	20H
0005433434242	2358	98	20G
0005433434286	2358	99	21B
0005432984534	2358	100	21F
0005433434330	2358	101	21E
0005435982019	2358	102	21G
0005433764668	2358	103	21H
0005432984721	2358	104	22B
0005433753871	2358	105	22A
0005435982028	2358	106	22D
0005433753873	2358	107	22F
0005432984805	2358	108	22E
0005433753894	2358	109	22G
0005433753861	2358	110	23A
0005435982045	2358	111	22H
0005433753855	2358	112	23B
0005433753903	2358	113	23D
0005433434293	2358	114	23F
0005432869423	2358	115	23E
0005432984500	2358	116	23G
0005433434320	2358	117	23H
0005435982035	2358	118	24D
0005432226021	2358	119	24B
0005435982022	2358	120	24A
0005433753877	2358	121	24E
0005432984735	2358	122	24G
0005433753863	2358	123	24F
0005433764667	2358	124	24H
0005433434336	2358	125	25E
0005433753899	2358	126	25D
0005433753869	2358	127	25F
0005435982026	2358	128	27B
0005432226018	2358	129	27A
0005433434335	2358	130	27D
0005433434312	2358	131	27F
0005433753891	2358	132	27E
0005435982016	2358	133	27G
0005435982049	2358	134	28A
0005435982017	2358	135	27H
0005432869422	2358	136	28B
0005433434287	2358	137	28E
0005435982023	2358	138	28D
0005432984658	2358	139	28G
0005433753895	2358	140	28F
0005434731096	2358	141	28H
0005432984659	2358	142	29A
0005432984516	2358	143	29B
0005435982048	2358	144	29E
0005432984586	2358	145	29D
0005432655467	2358	146	29G
0005433434250	2358	147	29F
0005433434208	2358	148	30A
0005432984510	2358	149	29H
0005432984613	2358	150	30D
0005433753857	2358	151	30F
0005432869433	2358	152	30E
0005433753885	2358	153	30H
0005435982039	2358	154	31A
0005432984631	2358	155	31F
0005432984669	2358	156	31E
0005433753911	2358	157	31G
0005432655461	2358	158	32A
0005435982043	2358	159	31H
0005433753889	2358	160	32B
0005433753858	2358	161	32D
0005433753910	2358	162	32G
0005433753874	2358	163	32F
0005433434298	2358	164	32E
0005433434216	2358	165	33A
0005435982027	2358	166	33B
0005435982053	2358	167	33E
0005433753888	2358	168	33D
0005433753900	2358	169	33G
0005433766618	2358	170	33F
0005433434276	2358	171	34A
0005435982015	2358	172	34D
0005433753881	2358	173	34F
0005432984743	2358	174	34G
0005432869413	2358	175	35A
0005433434321	2358	176	34H
0005433434327	2358	177	35B
0005435982020	2358	178	35E
0005435982021	2358	179	35D
0005434731115	2358	180	35F
0005432226019	2358	181	35H
0005435982031	2358	182	36B
0005433766617	2358	183	36D
0005433434332	2358	184	36F
0005432300227	2358	185	36E
0005432984712	2358	186	36G
0005433753886	2358	187	37A
0005433753876	2358	188	36H
0005435982034	2358	189	37D
0005432655463	2358	190	37B
0005433434316	2358	191	37E
0005433434331	2358	192	37F
0005433434319	2358	193	37G
0005432655466	2358	194	38A
0005433753884	2358	195	38B
0005433753902	2358	196	38E
0005435982030	2358	197	38D
0005432655471	2358	198	38G
0005435982014	2358	199	38F
0005435982024	2358	200	39D
0005435982051	2358	201	38H
0005432984573	2358	202	39E
0005435981746	26179	1	1A
0005432869482	26179	2	1B
0005433753463	26179	3	1F
0005433766590	26179	4	1C
0005434731147	26179	5	1H
0005433434522	26179	6	2B
0005432049443	26179	7	2F
0005435981515	26179	8	2C
0005433753552	26179	9	2G
0005432049441	26179	10	3A
0005432051109	26179	11	2H
0005432984874	26179	12	3C
0005433434507	26179	13	3B
0005435981619	26179	14	3F
0005433434512	26179	15	3H
0005433753449	26179	16	3G
0005433753240	26179	17	4B
0005433753235	26179	18	4F
0005432051110	26179	19	5A
0005432984884	26179	20	5C
0005435981671	26179	21	5F
0005435981663	26179	22	9A
0005435981612	26179	23	9H
0005433434509	26179	24	9G
0005432984894	26179	25	11B
0005433753553	26179	26	11A
0005432869481	26179	27	11D
0005433753523	26179	28	11F
0005433753445	26179	29	11E
0005433753296	26179	30	11G
0005435981570	26179	31	12D
0005433753536	26179	32	12B
0005432984888	26179	33	12E
0005433434510	26179	34	12F
0005432984867	26179	35	12H
0005433753484	26179	36	12G
0005433753400	26179	37	13A
0005433753371	26179	38	13D
0005432984885	26179	39	13B
0005433753487	26179	40	13F
0005434731146	26179	41	13E
0005432655372	26179	42	13H
0005433753337	26179	43	13G
0005433434511	26179	44	14B
0005432984896	26179	45	14A
0005433753387	26179	46	14E
0005433434499	26179	47	14D
0005433434500	26179	48	14H
0005432984887	26179	49	15D
0005433753241	26179	50	15B
0005435981600	26179	51	15A
0005433753503	26179	52	15F
0005432984875	26179	53	15H
0005433753623	26179	54	15G
0005435981573	26179	55	16A
0005432655364	26179	56	16D
0005434731144	26179	57	16B
0005432049440	26179	58	16E
0005433753481	26179	59	16H
0005433434497	26179	60	17B
0005433434520	26179	61	17A
0005432984869	26179	62	17D
0005435981628	26179	63	17E
0005435981597	26179	64	17G
0005432869479	26179	65	18A
0005433434519	26179	66	18B
0005432984892	26179	67	18E
0005433434515	26179	68	18F
0005435981666	26179	69	19A
0005432984870	26179	70	18H
0005435981649	26179	71	19D
0005433434523	26179	72	19F
0005435981568	26179	73	19E
0005432984873	26179	74	19G
0005434731145	26179	75	20A
0005435981792	26179	76	19H
0005433753619	26179	77	20B
0005433434518	26179	78	20D
0005433764650	26179	79	20F
0005435981774	26179	80	20G
0005432655363	26179	81	21A
0005433766586	26179	82	20H
0005435981572	26179	83	21D
0005433766597	26179	84	21B
0005433753416	26179	85	21E
0005433753374	26179	86	21F
0005432869480	26179	87	21H
0005435981636	26179	88	22A
0005433434505	26179	89	22D
0005432984877	26179	90	22B
0005433753239	26179	91	22E
0005432984891	26179	92	22G
0005435981537	26179	93	22F
0005435981704	26179	94	23A
0005432984879	26179	95	23D
0005433434502	26179	96	23B
0005435981591	26179	97	23G
0005433434521	26179	98	23F
0005435981683	26179	99	24A
0005433753486	26179	100	23H
0005432984866	26179	101	24E
0005432984893	26179	102	24F
0005432984881	26179	103	24G
0005433434516	26179	104	25D
0005432984871	26179	105	24H
0005435981620	26179	106	25E
0005435981747	26179	107	27A
0005433434503	26179	108	25F
0005433753464	26179	109	27B
0005433434501	26179	110	27E
0005433753474	26179	111	27D
0005433434508	26179	112	27G
0005432051111	26179	113	27F
0005433434498	26179	114	28A
0005432051108	26179	115	27H
0005433753357	26179	116	28B
0005433753351	26179	117	28D
0005432655369	26179	118	28G
0005432984883	26179	119	28F
0005433434524	26179	120	29A
0005433434513	26179	121	29E
0005432049442	26179	122	29D
0005433753342	26179	123	29G
0005433753388	26179	124	29F
0005433766582	26179	125	30D
0005435981637	26179	126	30B
0005435981584	26179	127	30E
0005433434506	26179	128	30F
0005434731143	26179	129	31B
0005433753498	26179	130	31A
0005435981508	26179	131	31E
0005435981542	26179	132	31D
0005432984878	26179	133	31F
0005432655373	26179	134	31H
0005432984868	26179	135	31G
0005432655368	26179	136	32A
0005433753571	26179	137	32B
0005433434517	26179	138	32D
0005432984897	26179	139	32G
0005435981743	26179	140	32F
0005432984882	26179	141	32H
0005432984898	26179	142	33B
0005435981541	26179	143	33A
0005433753336	26179	144	33E
0005433753343	26179	145	33F
0005432984889	26179	146	34A
0005435981569	26179	147	34B
0005433434504	26179	148	34E
0005432655366	26179	149	34G
0005432984876	26179	150	34F
0005433753510	26179	151	35B
0005432984880	26179	152	35E
0005433753334	26179	153	35D
0005433753341	26179	154	35H
0005432984886	26179	155	35G
0005435981519	26179	156	36A
0005433753419	26179	157	36B
0005432869485	26179	158	36F
0005432984895	26179	159	36E
0005432655367	26179	160	36G
0005433753533	26179	161	37A
0005433753358	26179	162	36H
0005432984890	26179	163	37D
0005433434514	26179	164	37E
0005433753444	26179	165	37G
0005435981538	26179	166	37H
0005433753234	26179	167	38A
0005433753480	26179	168	38D
0005432984872	26179	169	38B
0005435981532	26179	170	38E
0005432869484	26179	171	38F
0005432869483	26179	172	38H
0005433753609	26179	173	38G
0005433753260	26179	174	39D
0005432049444	26179	175	39F
0005433151019	1493	1	1C
0005434374403	1493	2	1D
0005434374413	1493	3	2C
0005434374417	1493	4	2A
0005433150902	1493	5	2D
0005432267854	1493	6	3C
0005433931415	1493	7	3D
0005433151038	1493	8	3F
0005434374389	1493	9	4A
0005433151018	1493	10	4C
0005434374419	1493	11	4B
0005433150885	1493	12	4D
0005434374405	1493	13	4F
0005434374397	1493	14	5B
0005434374390	1493	15	5C
0005434374391	1493	16	5D
0005433150971	1493	17	5F
0005434374376	1493	18	5E
0005433150998	1493	19	6B
0005434374412	1493	20	6A
0005433150994	1493	21	6C
0005434374369	1493	22	6D
0005434374411	1493	23	6F
0005434374401	1493	24	7A
0005434374400	1493	25	7C
0005432267855	1493	26	7B
0005433931423	1493	27	7D
0005433150946	1493	28	7F
0005433461576	1493	29	7E
0005433150932	1493	30	8A
0005434374388	1493	31	8B
0005434374370	1493	32	8D
0005434374395	1493	33	8C
0005434374368	1493	34	8F
0005433461575	1493	35	9B
0005434374387	1493	36	9C
0005433150992	1493	37	9E
0005434374378	1493	38	10B
0005434374407	1493	39	10D
0005434374406	1493	40	10C
0005434374363	1493	41	11A
0005434374380	1493	42	11B
0005433150806	1493	43	11D
0005434374418	1493	44	11C
0005434374398	1493	45	11E
0005434374367	1493	46	12B
0005433151072	1493	47	12A
0005433931418	1493	48	12D
0005434374386	1493	49	12C
0005434374383	1493	50	12E
0005434374375	1493	51	12F
0005433931419	1493	52	13B
0005434374394	1493	53	13A
0005433150921	1493	54	13C
0005434374399	1493	55	13D
0005433150898	1493	56	13E
0005434374396	1493	57	13F
0005434374364	1493	58	14A
0005433150882	1493	59	14B
0005434374416	1493	60	14D
0005434374415	1493	61	14C
0005434374408	1493	62	15A
0005433151017	1493	63	14F
0005433931416	1493	64	15B
0005434374414	1493	65	15D
0005433150850	1493	66	15F
0005434374384	1493	67	15E
0005432267853	1493	68	16B
0005434374374	1493	69	16C
0005434374379	1493	70	16E
0005433460422	1493	71	17C
0005434374392	1493	72	17D
0005434374409	1493	73	17F
0005433150805	1493	74	17E
0005433150931	1493	75	18A
0005434374373	1493	76	18B
0005434374366	1493	77	18C
0005432267851	1493	78	18F
0005433150838	1493	79	18E
0005433150810	1493	80	19A
0005432267852	1493	81	19B
0005434374371	1493	82	19D
0005433150884	1493	83	19C
0005434374404	1493	84	19F
0005433150881	1493	85	20A
0005433150993	1493	86	20B
0005434374410	1493	87	20D
0005433150897	1493	88	20C
0005433151037	1493	89	20E
0005434374393	1493	90	20F
0005434374385	1493	91	21B
0005433150890	1493	92	21A
0005433461574	1493	93	21C
0005434374381	1493	94	21D
0005432267856	1493	95	21E
0005434374365	1493	96	22A
0005434374377	1493	97	22B
0005434374402	1493	98	22C
0005433460423	1493	99	22E
0005434374372	1493	100	23A
0005434374382	1493	101	23B
0005433151023	1493	102	23C
0005434374420	1493	103	23E
0005432267857	1493	104	23D
0005434373886	20125	1	1C
0005434374054	20125	2	1F
0005433151213	20125	3	1D
0005434374034	20125	4	2A
0005432056274	20125	5	2C
0005434374059	20125	6	2D
0005434373900	20125	7	3C
0005434373995	20125	8	3D
0005432056276	20125	9	3F
0005434374052	20125	10	4A
0005434374072	20125	11	4B
0005434373994	20125	12	4D
0005433151197	20125	13	4C
0005434373907	20125	14	5A
0005433151187	20125	15	5B
0005434373925	20125	16	5D
0005434374009	20125	17	5F
0005433151206	20125	18	5E
0005434374057	20125	19	6B
0005434374079	20125	20	6C
0005433151189	20125	21	6D
0005434374066	20125	22	7A
0005434374078	20125	23	6F
0005434373953	20125	24	7C
0005433151205	20125	25	7E
0005433764668	20125	26	7D
0005434374049	20125	27	7F
0005433151186	20125	28	8A
0005434374044	20125	29	8B
0005434029641	20125	30	8D
0005433151212	20125	31	8E
0005434374071	20125	32	8F
0005433151200	20125	33	9A
0005434374080	20125	34	9B
0005433151199	20125	35	9E
0005434374017	20125	36	9D
0005433151180	20125	37	9F
0005433151204	20125	38	10E
0005434374060	20125	39	11A
0005433151214	20125	40	11B
0005433931447	20125	41	11C
0005433151184	20125	42	11D
0005434373943	20125	43	11F
0005434373986	20125	44	12A
0005434373899	20125	45	12B
0005433764667	20125	46	12F
0005433151207	20125	47	13B
0005433151181	20125	48	13D
0005433931446	20125	49	13C
0005434374035	20125	50	13F
0005434029642	20125	51	13E
0005434374051	20125	52	14A
0005433151191	20125	53	14C
0005434373962	20125	54	14E
0005433151194	20125	55	15B
0005433151211	20125	56	15D
0005434374040	20125	57	15F
0005433151183	20125	58	16B
0005434374050	20125	59	16A
0005434374047	20125	60	16C
0005434373847	20125	61	16E
0005434374081	20125	62	17B
0005434373952	20125	63	17C
0005433151203	20125	64	17E
0005432056277	20125	65	18A
0005434373998	20125	66	17F
0005434374053	20125	67	18B
0005434373885	20125	68	18D
0005434373960	20125	69	18E
0005433151192	20125	70	19A
0005434373926	20125	71	18F
0005433151208	20125	72	19C
0005434373969	20125	73	19D
0005433931448	20125	74	19E
0005434373905	20125	75	20A
0005433151210	20125	76	20C
0005433151202	20125	77	20E
0005433151193	20125	78	20D
0005433151190	20125	79	21A
0005433151196	20125	80	20F
0005434373887	20125	81	21B
0005433151198	20125	82	21D
0005433151209	20125	83	21C
0005433151182	20125	84	21E
0005434373961	20125	85	21F
0005433151195	20125	86	22B
0005432056275	20125	87	22A
0005433931445	20125	88	22D
0005433151201	20125	89	22E
0005433151185	20125	90	23B
0005434374039	20125	91	23D
0005433151188	20125	92	23C
0005434373974	20125	93	23E
0005432424178	590	1	3C
0005432424188	590	2	4D
0005432424168	590	3	5D
0005432424176	590	4	6F
0005432424171	590	5	8F
0005432424180	590	6	9C
0005432424184	590	7	10E
0005432424187	590	8	10D
0005432424170	590	9	11D
0005432282823	590	10	11F
0005432282820	590	11	12C
0005432282818	590	12	13A
0005432424172	590	13	13F
0005432282822	590	14	14C
0005432282821	590	15	15D
0005432424182	590	16	16D
0005432424160	590	17	16C
0005432424166	590	18	17B
0005432424183	590	19	17D
0005432424163	590	20	18B
0005432282825	590	21	18E
0005432424165	590	22	20A
0005432282819	590	23	21A
0005432424181	590	24	22C
0005432424175	590	25	23A
0005432282824	590	26	23D
0005432424162	590	27	23F
0005432424169	590	28	25D
0005432424173	590	29	26A
0005432424186	590	30	27A
0005432424161	590	31	26F
0005432424179	590	32	27E
0005432424167	590	33	28B
0005432424177	590	34	29E
0005432424164	590	35	30A
0005432424185	590	36	30E
0005432424174	590	37	31D
0005433158116	12881	1	1C
0005433158117	12881	2	5D
0005434446476	12881	3	10E
0005434446494	12881	4	11C
0005434446492	12881	5	12F
0005434446477	12881	6	14A
0005434446493	12881	7	14B
0005434446478	12881	8	14C
0005432302310	12881	9	14E
0005432302306	12881	10	15A
0005434446484	12881	11	16D
0005434446489	12881	12	17E
0005432302308	12881	13	18A
0005434446481	12881	14	18B
0005432302307	12881	15	21F
0005433158119	12881	16	22C
0005434446480	12881	17	24E
0005433158118	12881	18	29E
0005432302309	12881	19	30D
0005434446479	12881	20	31E
0005432423743	12900	1	1C
0005432423733	12900	2	1D
0005432423621	12900	3	2C
0005432423624	12900	4	3D
0005432423741	12900	5	4F
0005432423725	12900	6	6C
0005432423682	12900	7	6D
0005432423700	12900	8	7F
0005432423718	12900	9	8A
0005432423744	12900	10	8F
0005432423679	12900	11	9F
0005432423659	12900	12	10B
0005432423678	12900	13	12A
0005432423626	12900	14	13C
0005432423698	12900	15	14C
0005432423694	12900	16	14E
0005432423610	12900	17	14F
0005432423639	12900	18	15C
0005432423759	12900	19	15D
0005432423695	12900	20	16C
0005432423726	12900	21	16E
0005432423699	12900	22	17A
0005432423611	12900	23	16F
0005432423637	12900	24	17B
0005432423658	12900	25	18B
0005432423648	12900	26	18C
0005432423655	12900	27	18E
0005432423677	12900	28	19C
0005432423657	12900	29	19E
0005432423663	12900	30	20A
0005432423638	12900	31	21B
0005432423673	12900	32	21C
0005432423651	12900	33	21E
0005432423617	12900	34	21F
0005432423754	12900	35	23A
0005432423758	12900	36	23D
0005432423656	12900	37	24A
0005432423662	12900	38	24F
0005432423740	12900	39	25B
0005432423675	12900	40	25F
0005432423625	12900	41	26C
0005432423732	12900	42	26D
0005432423671	12900	43	27A
0005432423701	12900	44	27C
0005432423674	12900	45	28D
0005432423753	12900	46	29F
0005432423634	12900	47	30F
0005432423641	12900	48	31B
0005432423661	12900	49	31A
0005434023327	480	1	1A
0005433057384	480	2	1B
0005433929545	480	3	1F
0005434023297	480	4	1H
0005434023332	480	5	1G
0005434023265	480	6	2A
0005433057383	480	7	2B
0005434023296	480	8	3B
0005433057350	480	9	4A
0005433057258	480	10	3H
0005433057455	480	11	4B
0005432235591	480	12	4F
0005434023322	480	13	5B
0005434023312	480	14	5F
0005434023315	480	15	5C
0005434023276	480	16	5G
0005434023270	480	17	5H
0005434023316	480	18	9B
0005434023287	480	19	9G
0005433057315	480	20	11A
0005433057349	480	21	11B
0005434023280	480	22	11D
0005433057262	480	23	11F
0005433057293	480	24	11G
0005434023298	480	25	12A
0005433057261	480	26	12D
0005434031991	480	27	12B
0005433057528	480	28	12E
0005433057367	480	29	12G
0005434023319	480	30	12F
0005434023299	480	31	13B
0005434023307	480	32	13A
0005434031990	480	33	13E
0005433057505	480	34	13G
0005434023329	480	35	13F
0005434023300	480	36	13H
0005433057390	480	37	14A
0005434023331	480	38	14E
0005434023271	480	39	14D
0005434023295	480	40	14H
0005434023313	480	41	15B
0005434023275	480	42	15E
0005433057444	480	43	15D
0005433057391	480	44	15F
0005434023306	480	45	15H
0005434023293	480	46	15G
0005433057506	480	47	16A
0005433057369	480	48	16B
0005434023302	480	49	16E
0005434023264	480	50	16F
0005434023286	480	51	16H
0005433929565	480	52	17D
0005433929553	480	53	17G
0005432235592	480	54	18B
0005434023267	480	55	18A
0005433057341	480	56	18D
0005433057256	480	57	18E
0005434023266	480	58	18G
0005432235594	480	59	19B
0005434023317	480	60	19A
0005434023333	480	61	19D
0005433057252	480	62	19G
0005434023328	480	63	20A
0005434023294	480	64	19H
0005433057357	480	65	20D
0005434031992	480	66	20E
0005433057241	480	67	21A
0005433057353	480	68	21B
0005433057419	480	69	21D
0005433057407	480	70	22A
0005432045600	480	71	22D
0005433057361	480	72	22F
0005434023268	480	73	22E
0005433057345	480	74	22H
0005433057250	480	75	22G
0005434023318	480	76	23B
0005434023326	480	77	23A
0005433057418	480	78	23D
0005433057309	480	79	23F
0005434023277	480	80	23G
0005434023323	480	81	24A
0005434023269	480	82	23H
0005433057382	480	83	24E
0005433057294	480	84	24G
0005433057356	480	85	25E
0005434023285	480	86	25D
0005433057368	480	87	27A
0005434023311	480	88	25F
0005434029640	480	89	27D
0005433057522	480	90	27B
0005432045599	480	91	27E
0005433929548	480	92	27G
0005434023284	480	93	27H
0005434028277	480	94	28B
0005434023325	480	95	28E
0005434023308	480	96	28D
0005433057215	480	97	28F
0005432235590	480	98	29B
0005434031993	480	99	29A
0005434029639	480	100	29H
0005434023289	480	101	30B
0005434023283	480	102	30D
0005433057417	480	103	30F
0005432235589	480	104	30H
0005433929544	480	105	31B
0005434023303	480	106	31A
0005434023291	480	107	31F
0005434023290	480	108	31G
0005434023330	480	109	32D
0005433057376	480	110	32F
0005434028278	480	111	32H
0005434023288	480	112	32G
0005432235593	480	113	33E
0005433057420	480	114	33D
0005434023324	480	115	33G
0005432235595	480	116	33F
0005434023305	480	117	33H
0005433929542	480	118	34B
0005434023309	480	119	34E
0005434023321	480	120	34F
0005433057242	480	121	34H
0005434028279	480	122	35A
0005433057523	480	123	35D
0005433057340	480	124	35B
0005434023314	480	125	35F
0005434023281	480	126	35E
0005434023301	480	127	35G
0005434023320	480	128	36B
0005433057214	480	129	36A
0005434023282	480	130	36F
0005433057251	480	131	36E
0005434031994	480	132	36H
0005433057395	480	133	36G
0005434023273	480	134	37A
0005434023274	480	135	37B
0005434023278	480	136	37D
0005433929543	480	137	37F
0005433057388	480	138	38B
0005434023272	480	139	38E
0005434023279	480	140	38F
0005434029638	480	141	38H
0005434023310	480	142	38G
0005434023304	480	143	39D
0005434023292	480	144	39F
0005434022889	12688	1	1F
0005433057622	12688	2	1G
0005433057645	12688	3	2C
0005433929587	12688	4	2B
0005434735659	12688	5	2F
0005434022953	12688	6	2G
0005434028256	12688	7	2H
0005434022763	12688	8	3B
0005433929589	12688	9	3A
0005434022888	12688	10	3F
0005434022683	12688	11	3C
0005434022502	12688	12	4F
0005434022876	12688	13	4G
0005433057641	12688	14	5A
0005434022621	12688	15	5B
0005434022692	12688	16	5G
0005433057627	12688	17	9A
0005432157480	12688	18	9H
0005432156341	12688	19	11E
0005433057621	12688	20	11G
0005434022940	12688	21	12A
0005434735657	12688	22	12B
0005433684408	12688	23	12E
0005433057659	12688	24	12D
0005434022925	12688	25	12G
0005433057652	12688	26	13A
0005434031951	12688	27	13D
0005433057654	12688	28	13E
0005434022750	12688	29	13F
0005434022704	12688	30	13H
0005434022548	12688	31	14D
0005434028259	12688	32	14B
0005433057647	12688	33	14E
0005434022740	12688	34	15A
0005433057631	12688	35	14H
0005434022659	12688	36	15D
0005434022705	12688	37	15B
0005434022860	12688	38	16F
0005433057639	12688	39	16H
0005434022924	12688	40	16G
0005432156340	12688	41	17B
0005434022669	12688	42	17A
0005434022851	12688	43	17G
0005434022852	12688	44	17F
0005433057634	12688	45	17H
0005433057648	12688	46	18B
0005434022757	12688	47	18A
0005434735658	12688	48	18D
0005434022786	12688	49	18F
0005434022751	12688	50	18H
0005434022819	12688	51	18G
0005434022677	12688	52	19A
0005433057626	12688	53	19D
0005434022610	12688	54	19F
0005434022952	12688	55	19H
0005433929588	12688	56	19G
0005433057635	12688	57	20A
0005433929586	12688	58	20B
0005433057642	12688	59	20E
0005434022778	12688	60	20H
0005434022773	12688	61	21D
0005433057637	12688	62	21B
0005433057651	12688	63	21F
0005432156337	12688	64	21G
0005434022652	12688	65	22B
0005434022806	12688	66	23A
0005433057644	12688	67	23D
0005434022682	12688	68	23B
0005434735660	12688	69	23F
0005433057658	12688	70	23E
0005433057646	12688	71	24A
0005433057636	12688	72	23H
0005434022577	12688	73	24D
0005433684407	12688	74	24F
0005433057638	12688	75	25D
0005433057650	12688	76	27A
0005434022684	12688	77	27D
0005434022559	12688	78	27F
0005434022820	12688	79	27E
0005434735656	12688	80	27H
0005434022807	12688	81	28B
0005434022826	12688	82	28D
0005432157481	12688	83	28G
0005434031958	12688	84	29A
0005433057630	12688	85	29G
0005433057624	12688	86	29H
0005433057653	12688	87	30D
0005434022877	12688	88	30E
0005434022520	12688	89	30G
0005432156342	12688	90	31A
0005434022984	12688	91	30H
0005434022572	12688	92	31B
0005433684409	12688	93	31E
0005433057625	12688	94	31F
0005433057660	12688	95	32A
0005433057656	12688	96	32B
0005434022671	12688	97	32D
0005433057640	12688	98	32F
0005434022941	12688	99	33E
0005432156338	12688	100	33D
0005434022785	12688	101	33H
0005434022847	12688	102	34B
0005434022808	12688	103	34A
0005434022880	12688	104	34D
0005434022849	12688	105	34F
0005433057632	12688	106	34E
0005434031975	12688	107	34H
0005434022549	12688	108	35E
0005434022942	12688	109	35D
0005434022691	12688	110	35H
0005434022511	12688	111	35G
0005432156339	12688	112	36A
0005432157479	12688	113	36B
0005433057623	12688	114	36F
0005434022561	12688	115	37D
0005433057629	12688	116	37B
0005433057643	12688	117	37E
0005434022749	12688	118	37F
0005434022890	12688	119	37H
0005434022560	12688	120	38D
0005433057657	12688	121	38B
0005433057628	12688	122	38E
0005434022501	12688	123	38G
0005433057649	12688	124	38H
0005433057633	12688	125	39D
0005433057655	12688	126	39F
0005433035487	2156	1	1B
0005433922742	2156	2	1A
0005433035358	2156	3	1F
0005433922757	2156	4	1G
0005433922728	2156	5	1H
0005433035517	2156	6	2C
0005433922729	2156	7	2B
0005433922745	2156	8	2A
0005433922667	2156	9	2F
0005433922677	2156	10	2G
0005433922678	2156	11	3A
0005433922740	2156	12	2H
0005433922715	2156	13	3F
0005433035762	2156	14	3C
0005433922701	2156	15	3H
0005433922751	2156	16	4B
0005433922688	2156	17	4A
0005433929588	2156	18	4F
0005433922699	2156	19	4C
0005433035668	2156	20	4G
0005433922723	2156	21	4H
0005433922695	2156	22	5B
0005433922687	2156	23	5A
0005433922756	2156	24	5F
0005433922760	2156	25	9A
0005433922697	2156	26	5H
0005432231503	2156	27	9B
0005433922683	2156	28	9G
0005433929589	2156	29	11A
0005433922704	2156	30	11B
0005433922698	2156	31	11D
0005433931448	2156	32	11F
0005433922755	2156	33	11G
0005433035481	2156	34	12A
0005434028256	2156	35	12B
0005433035560	2156	36	12E
0005433922680	2156	37	12D
0005433922694	2156	38	12G
0005433922702	2156	39	12F
0005433922705	2156	40	12H
0005432044507	2156	41	13A
0005433922747	2156	42	13D
0005433035512	2156	43	13E
0005433035480	2156	44	13F
0005433922675	2156	45	14A
0005432231497	2156	46	13H
0005433922710	2156	47	14D
0005433922739	2156	48	14E
0005433922714	2156	49	14H
0005433929587	2156	50	14G
0005433922731	2156	51	14F
0005433035479	2156	52	15B
0005433922737	2156	53	15A
0005433922669	2156	54	15E
0005432231505	2156	55	15D
0005433922730	2156	56	15G
0005433922679	2156	57	16A
0005433035656	2156	58	16D
0005433035563	2156	59	16B
0005433931446	2156	60	16E
0005433922671	2156	61	16F
0005433035523	2156	62	16G
0005433922706	2156	63	17B
0005433922722	2156	64	17F
0005433035779	2156	65	17E
0005433922750	2156	66	18B
0005433931447	2156	67	18A
0005433035636	2156	68	18D
0005433922693	2156	69	18F
0005433922712	2156	70	18E
0005433035547	2156	71	18G
0005433922717	2156	72	18H
0005433875367	2156	73	19A
0005433035515	2156	74	19E
0005433922684	2156	75	19D
0005433035509	2156	76	19F
0005433922761	2156	77	19H
0005433035514	2156	78	20A
0005433922763	2156	79	20B
0005433035367	2156	80	20E
0005433922711	2156	81	20D
0005433922721	2156	82	20G
0005433922672	2156	83	21A
0005432231504	2156	84	20H
0005433035658	2156	85	21E
0005433922726	2156	86	21D
0005433035591	2156	87	21F
0005433922673	2156	88	21H
0005433922686	2156	89	22B
0005433922719	2156	90	22A
0005433922764	2156	91	22D
0005433922709	2156	92	22F
0005433035625	2156	93	22E
0005433035592	2156	94	22G
0005433035447	2156	95	23A
0005433035548	2156	96	22H
0005432231495	2156	97	23D
0005432231498	2156	98	23B
0005433922682	2156	99	23E
0005433035506	2156	100	23G
0005434028259	2156	101	23F
0005433922727	2156	102	23H
0005433035464	2156	103	24E
0005433922744	2156	104	24F
0005433035561	2156	105	24G
0005433922691	2156	106	25D
0005433922749	2156	107	24H
0005433922752	2156	108	27A
0005433035431	2156	109	25F
0005433922733	2156	110	27B
0005433929586	2156	111	27E
0005433922748	2156	112	27D
0005433922759	2156	113	27F
0005433922724	2156	114	28A
0005433035714	2156	115	27H
0005432231500	2156	116	28B
0005433922765	2156	117	28E
0005433922720	2156	118	28F
0005433922700	2156	119	28H
0005433922746	2156	120	28G
0005433035780	2156	121	29A
0005433922689	2156	122	29D
0005433922716	2156	123	29E
0005432231499	2156	124	29G
0005433922753	2156	125	29H
0005433922708	2156	126	30B
0005433035539	2156	127	30A
0005433035596	2156	128	30E
0005433035630	2156	129	30H
0005433922674	2156	130	31B
0005433035616	2156	131	31E
0005433035583	2156	132	31D
0005433922718	2156	133	31F
0005433035420	2156	134	32A
0005433035617	2156	135	32B
0005433922668	2156	136	32E
0005432044508	2156	137	32D
0005433922762	2156	138	32G
0005433922734	2156	139	32F
0005433035465	2156	140	32H
0005433922743	2156	141	33A
0005433035568	2156	142	33E
0005433035626	2156	143	33D
0005433922692	2156	144	33G
0005433922681	2156	145	33F
0005433922736	2156	146	33H
0005432231501	2156	147	34D
0005433035657	2156	148	34B
0005433922735	2156	149	34G
0005433922741	2156	150	34F
0005433922703	2156	151	34H
0005433035533	2156	152	35B
0005433035520	2156	153	35F
0005433922690	2156	154	35G
0005433922713	2156	155	35H
0005433035524	2156	156	36B
0005433035562	2156	157	36A
0005433922707	2156	158	36F
0005433035518	2156	159	36E
0005433922725	2156	160	36G
0005433931445	2156	161	37A
0005433922738	2156	162	36H
0005433922758	2156	163	37E
0005432231496	2156	164	37F
0005432044506	2156	165	37H
0005433035430	2156	166	37G
0005433922685	2156	167	38A
0005433035676	2156	168	38B
0005433035659	2156	169	38E
0005433922754	2156	170	38G
0005433922676	2156	171	38F
0005433922732	2156	172	38H
0005433922670	2156	173	39D
0005432231502	2156	174	39F
0005433922696	2156	175	39E
0005433921624	24088	1	1C
0005433035981	24088	2	1F
0005432207646	24088	3	1H
0005433035960	24088	4	2A
0005433922159	24088	5	2C
0005433035965	24088	6	2B
0005433035967	24088	7	2F
0005433921734	24088	8	2H
0005433921904	24088	9	2G
0005433921626	24088	10	3A
0005433921755	24088	11	3C
0005433929566	24088	12	3B
0005432749771	24088	13	3F
0005433929550	24088	14	3H
0005433921729	24088	15	4A
0005433922122	24088	16	4B
0005433922039	24088	17	4C
0005433035982	24088	18	4G
0005433035999	24088	19	4F
0005433922143	24088	20	5A
0005433921689	24088	21	4H
0005433921749	24088	22	5B
0005433921900	24088	23	5F
0005433035966	24088	24	5C
0005433921842	24088	25	5G
0005434028280	24088	26	5H
0005433921957	24088	27	9A
0005432749772	24088	28	9G
0005433921907	24088	29	11A
0005433921638	24088	30	9H
0005433035987	24088	31	11B
0005433921783	24088	32	11E
0005433922142	24088	33	11D
0005433035971	24088	34	11F
0005432207647	24088	35	11G
0005433035983	24088	36	12A
0005433035978	24088	37	12D
0005433921708	24088	38	12F
0005433921886	24088	39	12H
0005433035956	24088	40	13A
0005433035976	24088	41	13B
0005433922040	24088	42	13F
0005433921707	24088	43	13E
0005433921896	24088	44	13H
0005433921728	24088	45	14D
0005433921811	24088	46	14F
0005433921843	24088	47	15A
0005433875354	24088	48	15D
0005433921733	24088	49	15B
0005433921822	24088	50	15E
0005433921953	24088	51	15F
0005433035996	24088	52	15H
0005433922062	24088	53	16A
0005433921634	24088	54	16B
0005433035975	24088	55	16F
0005433035986	24088	56	16E
0005433035991	24088	57	16D
0005433035955	24088	58	16G
0005433035959	24088	59	16H
0005433035951	24088	60	17B
0005433035977	24088	61	17A
0005433929552	24088	62	17D
0005433922260	24088	63	17G
0005433921655	24088	64	17H
0005433921786	24088	65	18B
0005433035962	24088	66	18A
0005433035984	24088	67	18F
0005433035995	24088	68	18E
0005433036003	24088	69	19A
0005433921985	24088	70	18H
0005433921928	24088	71	19B
0005433922154	24088	72	19E
0005433035954	24088	73	19F
0005434028282	24088	74	19G
0005433035952	24088	75	20A
0005433921767	24088	76	19H
0005433921754	24088	77	20D
0005432749773	24088	78	20F
0005433921873	24088	79	20G
0005433922237	24088	80	21A
0005433922002	24088	81	20H
0005433921872	24088	82	21D
0005433921950	24088	83	21B
0005433922155	24088	84	21E
0005433921993	24088	85	21F
0005433035988	24088	86	21H
0005433921968	24088	87	21G
0005433921814	24088	88	22B
0005433921826	24088	89	22A
0005434028283	24088	90	22E
0005433035972	24088	91	22G
0005433921954	24088	92	22F
0005433922218	24088	93	23B
0005433035970	24088	94	23A
0005433035993	24088	95	23E
0005433922141	24088	96	23H
0005433921874	24088	97	24B
0005433921839	24088	98	24A
0005433921838	24088	99	24E
0005433921706	24088	100	24F
0005432206157	24088	101	24G
0005434028281	24088	102	25D
0005433922238	24088	103	24H
0005433921625	24088	104	25F
0005433035980	24088	105	25E
0005433035961	24088	106	27A
0005433921899	24088	107	27B
0005432206160	24088	108	27E
0005432206162	24088	109	27F
0005433922258	24088	110	28A
0005432206159	24088	111	27H
0005432749774	24088	112	28B
0005433035969	24088	113	28E
0005433921958	24088	114	28F
0005433929551	24088	115	28G
0005433921688	24088	116	28H
0005433922269	24088	117	29B
0005433035979	24088	118	29F
0005433035968	24088	119	29H
0005433922211	24088	120	30A
0005433929567	24088	121	30D
0005432206161	24088	122	30B
0005433922026	24088	123	30E
0005432206158	24088	124	30F
0005433921669	24088	125	31A
0005433036001	24088	126	30H
0005433921961	24088	127	31B
0005433922193	24088	128	31D
0005433921633	24088	129	31F
0005433035964	24088	130	31E
0005433036000	24088	131	31G
0005433035973	24088	132	32B
0005433035989	24088	133	32D
0005433921804	24088	134	33A
0005433921897	24088	135	33D
0005433922121	24088	136	33B
0005433035963	24088	137	33E
0005433921951	24088	138	33F
0005433921632	24088	139	34D
0005433921637	24088	140	34E
0005433922175	24088	141	34G
0005433921856	24088	142	34F
0005433035985	24088	143	35B
0005433035994	24088	144	35D
0005433035997	24088	145	35F
0005433875353	24088	146	35G
0005433922051	24088	147	35H
0005433035998	24088	148	36B
0005433921835	24088	149	36A
0005433035992	24088	150	36D
0005433921621	24088	151	36F
0005433035958	24088	152	36E
0005433921643	24088	153	37A
0005433036002	24088	154	36H
0005433922010	24088	155	37E
0005433035990	24088	156	37D
0005433035953	24088	157	37G
0005433922171	24088	158	38A
0005433035974	24088	159	38B
0005433921929	24088	160	38E
0005433035957	24088	161	39D
0005433921974	24088	162	39F
0005434724776	302	1	1C
0005433233446	302	2	1A
0005432277726	302	3	1H
0005433180736	302	4	1G
0005433180762	302	5	1D
0005435142499	302	6	2A
0005433233295	302	7	1K
0005433233208	302	8	2H
0005434550921	302	9	3C
0005433289762	302	10	3A
0005434724709	302	11	3G
0005434724727	302	12	3K
0005434550907	302	13	4C
0005433233305	302	14	4A
0005433180687	302	15	4D
0005434550877	302	16	4H
0005434550901	302	17	5D
0005433233205	302	18	5C
0005434550891	302	19	5A
0005434724682	302	20	5H
0005434724708	302	21	5G
0005434724785	302	22	11A
0005434724777	302	23	5K
0005434724720	302	24	11D
0005433233243	302	25	11C
0005434724764	302	26	11G
0005434724794	302	27	11F
0005434724734	302	28	11E
0005434724695	302	29	11K
0005434550893	302	30	11H
0005434550913	302	31	12C
0005434724751	302	32	12A
0005434724719	302	33	12E
0005434550903	302	34	12D
0005434724686	302	35	12H
0005434550917	302	36	12G
0005433233344	302	37	12F
0005434550898	302	38	13A
0005433233433	302	39	12K
0005434724767	302	40	13D
0005434550923	302	41	13C
0005435142491	302	42	13F
0005433180737	302	43	13E
0005434550885	302	44	13H
0005434550930	302	45	14A
0005434724677	302	46	14E
0005434724728	302	47	14D
0005434724688	302	48	14C
0005434724684	302	49	14F
0005433233081	302	50	14K
0005434724753	302	51	14H
0005433180697	302	52	14G
0005435142500	302	53	15C
0005433180698	302	54	15A
0005434724730	302	55	15E
0005433766576	302	56	15D
0005433180689	302	57	15H
0005435142501	302	58	15G
0005434031947	302	59	15F
0005434724713	302	60	16A
0005433233085	302	61	15K
0005434724791	302	62	16D
0005434724769	302	63	16C
0005434724788	302	64	16F
0005434724726	302	65	16E
0005434724707	302	66	16H
0005434724786	302	67	16G
0005434724773	302	68	16K
0005434550914	302	69	17E
0005434550909	302	70	17D
0005434550889	302	71	17G
0005434724747	302	72	17F
0005434550888	302	73	18A
0005433180724	302	74	17K
0005433131655	302	75	17H
0005435142493	302	76	18C
0005434550928	302	77	18B
0005434724783	302	78	18E
0005434724787	302	79	18D
0005433180700	302	80	18G
0005434724718	302	81	18H
0005434724741	302	82	19B
0005433289747	302	83	19A
0005434724683	302	84	19C
0005433233366	302	85	19F
0005433233206	302	86	19E
0005434735654	302	87	19D
0005433233200	302	88	19J
0005433233278	302	89	19H
0005433233440	302	90	19G
0005434724746	302	91	19K
0005433233460	302	92	20B
0005434724736	302	93	20D
0005434550911	302	94	20C
0005434724744	302	95	20G
0005434724699	302	96	20J
0005434724737	302	97	20H
0005432277723	302	98	21A
0005433180699	302	99	21D
0005434724721	302	100	21C
0005434550925	302	101	21G
0005434550929	302	102	21F
0005433289753	302	103	21J
0005434724752	302	104	22A
0005434724687	302	105	22C
0005434724705	302	106	22B
0005434724724	302	107	22D
0005434724679	302	108	22G
0005433233448	302	109	22F
0005432277722	302	110	22K
0005434550924	302	111	22J
0005434724759	302	112	22H
0005434550884	302	113	23A
0005434724704	302	114	23D
0005434724750	302	115	23C
0005434724716	302	116	23F
0005432277729	302	117	23J
0005433233297	302	118	23H
0005432277724	302	119	23G
0005434724749	302	120	23K
0005434724714	302	121	24F
0005434724796	302	122	25A
0005434302430	302	123	24G
0005434550895	302	124	25D
0005434550883	302	125	25C
0005434724782	302	126	25F
0005434724690	302	127	25E
0005434724675	302	128	25H
0005433233246	302	129	25G
0005434302431	302	130	25J
0005434550905	302	131	26C
0005433180767	302	132	26A
0005435142495	302	133	26E
0005434724732	302	134	26D
0005433233477	302	135	26G
0005433233327	302	136	26F
0005434724722	302	137	26H
0005433233084	302	138	27B
0005433126780	302	139	27A
0005434550890	302	140	27F
0005433233459	302	141	27E
0005434724680	302	142	27D
0005434302433	302	143	27H
0005434724692	302	144	27G
0005434550927	302	145	28C
0005434724771	302	146	28B
0005434724757	302	147	28A
0005433233583	302	148	28D
0005434724768	302	149	28G
0005434724748	302	150	28F
0005433111473	302	151	28E
0005433180830	302	152	28J
0005434724715	302	153	29A
0005434724711	302	154	28K
0005435142498	302	155	29C
0005434724762	302	156	29B
0005433233127	302	157	29G
0005434724766	302	158	29E
0005435142488	302	159	29H
0005433233256	302	160	30A
0005434735653	302	161	29K
0005434724702	302	162	30C
0005434731141	302	163	30B
0005434724740	302	164	30E
0005433233432	302	165	30D
0005434724698	302	166	30F
0005434724681	302	167	30H
0005434724697	302	168	31B
0005434724760	302	169	31A
0005432277727	302	170	30K
0005434724793	302	171	31C
0005434550881	302	172	31F
0005434724795	302	173	31G
0005434550918	302	174	31K
0005433180770	302	175	32C
0005433233197	302	176	32B
0005434550916	302	177	32E
0005432277733	302	178	32F
0005433289763	302	179	32K
0005434724735	302	180	32J
0005434724696	302	181	32H
0005433233080	302	182	33B
0005434735651	302	183	33A
0005434550902	302	184	33C
0005434724738	302	185	33E
0005433180725	302	186	33J
0005433233325	302	187	34C
0005435142490	302	188	34B
0005433180717	302	189	34A
0005434724758	302	190	34E
0005434731140	302	191	34G
0005434550900	302	192	34H
0005434550887	302	193	35A
0005433233476	302	194	35D
0005433233486	302	195	35C
0005434550897	302	196	35B
0005434735650	302	197	35F
0005434550910	302	198	35E
0005434724706	302	199	35H
0005434724689	302	200	36A
0005434724745	302	201	35K
0005434724739	302	202	36B
0005434550876	302	203	36E
0005433233304	302	204	36D
0005433233319	302	205	36H
0005434302434	302	206	36G
0005434724765	302	207	36F
0005433233484	302	208	37B
0005434550904	302	209	37A
0005433131656	302	210	37D
0005434724723	302	211	37C
0005434724693	302	212	37G
0005434735655	302	213	37F
0005434302855	302	214	37J
0005434724774	302	215	37H
0005433233195	302	216	38A
0005434724789	302	217	38C
0005434550922	302	218	38B
0005433180763	302	219	38J
0005434724700	302	220	38H
0005434724678	302	221	39A
0005434724755	302	222	38K
0005434550919	302	223	39B
0005433233207	302	224	39E
0005433233421	302	225	39D
0005435142502	302	226	39H
0005434550906	302	227	40A
0005434724779	302	228	39K
0005433131631	302	229	40C
0005434724676	302	230	40F
0005435142489	302	231	40J
0005434550879	302	232	40H
0005434724710	302	233	41B
0005433233392	302	234	41A
0005434724703	302	235	40K
0005432277728	302	236	41D
0005434731139	302	237	41F
0005432277721	302	238	41E
0005433233303	302	239	41J
0005434550880	302	240	41H
0005434731142	302	241	41K
0005433180798	302	242	42C
0005433233225	302	243	42B
0005434031956	302	244	42F
0005434550931	302	245	42D
0005433233173	302	246	42G
0005433233110	302	247	42J
0005434724770	302	248	43B
0005432277725	302	249	43A
0005434724712	302	250	42K
0005434724731	302	251	43C
0005434724763	302	252	43F
0005433180754	302	253	43E
0005434724691	302	254	43D
0005434550920	302	255	43H
0005434724725	302	256	43G
0005433233320	302	257	44A
0005434724756	302	258	43J
0005434550899	302	259	44C
0005434724792	302	260	44G
0005434550894	302	261	44F
0005433180688	302	262	44J
0005434724717	302	263	44H
0005434724742	302	264	45B
0005434724685	302	265	45D
0005434724784	302	266	45C
0005434550915	302	267	45H
0005432277730	302	268	45K
0005434724780	302	269	45J
0005434724761	302	270	46C
0005434302432	302	271	46B
0005434724754	302	272	46A
0005435142492	302	273	46E
0005434724733	302	274	46D
0005434550886	302	275	46G
0005434724775	302	276	46F
0005433180696	302	277	46J
0005434550882	302	278	46H
0005435142496	302	279	47C
0005433233442	302	280	47A
0005434724674	302	281	46K
0005434724772	302	282	47D
0005434724694	302	283	47G
0005434550908	302	284	47E
0005433113501	302	285	47K
0005434724743	302	286	48C
0005434550926	302	287	48F
0005432277731	302	288	48D
0005434550912	302	289	48H
0005435142494	302	290	48G
0005434724781	302	291	49D
0005433233345	302	292	49C
0005434724701	302	293	49G
0005433289727	302	294	49F
0005433233117	302	295	49E
0005434550896	302	296	49K
0005432277732	302	297	49H
0005434550878	302	298	50A
0005434724790	302	299	50F
0005435142497	302	300	50E
0005433233203	302	301	50G
0005434735652	302	302	50K
0005434724729	302	303	51F
0005434724778	302	304	51E
0005434550892	302	305	51G
0005433180948	9836	1	1A
0005433289801	9836	2	1G
0005434723529	9836	3	2A
0005433233825	9836	4	1K
0005433233842	9836	5	1H
0005434723690	9836	6	2C
0005433233822	9836	7	2D
0005433180934	9836	8	3A
0005433233813	9836	9	2K
0005433233818	9836	10	2H
0005434550388	9836	11	3D
0005434723739	9836	12	3C
0005435142337	9836	13	3K
0005433233804	9836	14	3H
0005434723678	9836	15	4C
0005433289805	9836	16	4A
0005433289798	9836	17	4G
0005434550386	9836	18	4D
0005433233823	9836	19	4K
0005433233828	9836	20	4H
0005433233841	9836	21	5C
0005434550259	9836	22	5A
0005434724084	9836	23	5H
0005435142386	9836	24	5D
0005433180953	9836	25	11A
0005433233849	9836	26	5K
0005434723997	9836	27	11D
0005433180949	9836	28	11C
0005433233846	9836	29	11F
0005433233838	9836	30	11H
0005434550481	9836	31	12C
0005434724111	9836	32	12A
0005434550281	9836	33	11K
0005434723913	9836	34	12D
0005433126816	9836	35	12G
0005434723774	9836	36	12F
0005433129248	9836	37	13A
0005433180952	9836	38	12K
0005434550557	9836	39	12H
0005435142388	9836	40	13D
0005433129247	9836	41	13C
0005433180951	9836	42	13F
0005433766616	9836	43	13E
0005434723442	9836	44	13H
0005433180940	9836	45	13G
0005434723385	9836	46	14A
0005434550383	9836	47	13K
0005433180944	9836	48	14E
0005434550508	9836	49	14D
0005434723404	9836	50	14C
0005434723969	9836	51	14F
0005434723924	9836	52	14K
0005434723770	9836	53	14H
0005433233830	9836	54	15C
0005433233844	9836	55	15A
0005434723925	9836	56	15F
0005434723783	9836	57	15D
0005434550446	9836	58	15H
0005434550430	9836	59	15G
0005433233837	9836	60	16A
0005433126819	9836	61	15K
0005433233810	9836	62	16D
0005434724049	9836	63	16C
0005433180946	9836	64	16F
0005434723674	9836	65	16E
0005435142403	9836	66	16K
0005434724021	9836	67	16H
0005434735620	9836	68	17A
0005434031999	9836	69	17F
0005432199207	9836	70	17K
0005434723754	9836	71	17H
0005434550357	9836	72	18E
0005435142363	9836	73	18D
0005434550411	9836	74	18C
0005433233827	9836	75	18G
0005434723652	9836	76	18F
0005434724219	9836	77	18K
0005434735599	9836	78	18J
0005434550366	9836	79	19A
0005434723934	9836	80	19C
0005433180936	9836	81	19E
0005433180945	9836	82	19D
0005434550352	9836	83	19J
0005433233798	9836	84	19H
0005434723496	9836	85	19G
0005434723491	9836	86	20A
0005434550480	9836	87	19K
0005433289804	9836	88	20C
0005434723781	9836	89	20E
0005433233851	9836	90	20D
0005435142341	9836	91	20F
0005433766618	9836	92	20J
0005434723711	9836	93	21B
0005434723651	9836	94	21A
0005434723916	9836	95	21E
0005434723436	9836	96	21D
0005434723721	9836	97	21C
0005434550365	9836	98	21F
0005434723849	9836	99	21H
0005434731114	9836	100	22A
0005434723756	9836	101	21J
0005434723612	9836	102	22B
0005434550501	9836	103	22E
0005433289807	9836	104	22D
0005434032000	9836	105	22H
0005434550368	9836	106	22G
0005434723474	9836	107	22K
0005433233847	9836	108	22J
0005434735598	9836	109	23B
0005433233797	9836	110	23A
0005434731096	9836	111	23D
0005434735613	9836	112	23C
0005433233821	9836	113	23F
0005434550522	9836	114	23E
0005434723905	9836	115	23J
0005433233791	9836	116	23H
0005434723507	9836	117	24F
0005433289802	9836	118	24E
0005433180955	9836	119	25A
0005432199205	9836	120	24G
0005433129246	9836	121	25D
0005433180933	9836	122	25B
0005434723709	9836	123	25F
0005432199204	9836	124	25E
0005434723509	9836	125	25H
0005434723766	9836	126	25G
0005433180943	9836	127	25K
0005434550301	9836	128	25J
0005433233836	9836	129	26E
0005434550413	9836	130	26D
0005433233832	9836	131	26C
0005434723691	9836	132	26F
0005432199206	9836	133	26J
0005434550581	9836	134	27B
0005434723750	9836	135	27D
0005434723927	9836	136	27C
0005434723858	9836	137	27F
0005434723831	9836	138	27J
0005434724134	9836	139	28A
0005434550449	9836	140	28B
0005433233795	9836	141	28D
0005433233839	9836	142	28C
0005433233814	9836	143	28H
0005433233805	9836	144	28F
0005433180941	9836	145	29B
0005433766615	9836	146	29A
0005434550488	9836	147	28K
0005433180942	9836	148	29C
0005433129251	9836	149	29F
0005433233803	9836	150	29E
0005433129249	9836	151	29G
0005434723352	9836	152	30A
0005434723926	9836	153	29K
0005433233809	9836	154	29J
0005433180957	9836	155	30B
0005434723547	9836	156	30D
0005435142338	9836	157	30G
0005434723570	9836	158	30J
0005434723407	9836	159	30H
0005434723510	9836	160	31B
0005434723848	9836	161	31A
0005433233807	9836	162	31D
0005434723331	9836	163	31E
0005434723505	9836	164	31H
0005434735603	9836	165	31G
0005434723737	9836	166	31K
0005434724276	9836	167	31J
0005434550367	9836	168	32C
0005433233845	9836	169	32A
0005433233812	9836	170	32D
0005433233819	9836	171	32H
0005434723348	9836	172	32K
0005434723332	9836	173	32J
0005434302384	9836	174	33B
0005433289800	9836	175	33D
0005434735607	9836	176	33H
0005433233800	9836	177	33G
0005434723637	9836	178	33J
0005433180947	9836	179	34C
0005434723530	9836	180	34B
0005434550483	9836	181	34A
0005434550298	9836	182	34E
0005434723405	9836	183	34D
0005434723755	9836	184	34F
0005434723809	9836	185	34J
0005434723618	9836	186	34H
0005434550326	9836	187	35B
0005433233831	9836	188	35A
0005434723493	9836	189	34K
0005433233843	9836	190	35D
0005433233802	9836	191	35C
0005434550432	9836	192	35F
0005435142387	9836	193	35H
0005434550389	9836	194	35G
0005434724025	9836	195	36A
0005433233850	9836	196	35J
0005434550421	9836	197	36C
0005434550578	9836	198	36B
0005434723490	9836	199	36E
0005434550351	9836	200	36D
0005434723450	9836	201	36H
0005433180956	9836	202	36G
0005432199202	9836	203	36K
0005435142394	9836	204	36J
0005433233816	9836	205	37C
0005433126814	9836	206	37B
0005434031996	9836	207	37A
0005434723416	9836	208	37D
0005433233817	9836	209	37G
0005433233835	9836	210	37F
0005434723353	9836	211	37K
0005435142404	9836	212	37J
0005434724261	9836	213	38H
0005433233848	9836	214	38C
0005433126815	9836	215	38B
0005433180938	9836	216	38A
0005434550325	9836	217	38J
0005433233796	9836	218	39B
0005434724024	9836	219	38K
0005434550495	9836	220	39D
0005434550384	9836	221	39C
0005434031995	9836	222	39G
0005435142344	9836	223	39E
0005433289799	9836	224	39H
0005434723765	9836	225	39J
0005434550577	9836	226	40C
0005434550377	9836	227	40B
0005433180935	9836	228	40A
0005434723707	9836	229	40G
0005433233826	9836	230	40F
0005434031997	9836	231	40J
0005434723499	9836	232	40H
0005434550284	9836	233	41B
0005434724260	9836	234	41A
0005434723840	9836	235	41D
0005433129250	9836	236	41E
0005434723506	9836	237	41H
0005432199203	9836	238	41G
0005434723904	9836	239	42A
0005433233833	9836	240	41J
0005433180950	9836	241	42C
0005433233852	9836	242	42B
0005434723569	9836	243	42E
0005434550410	9836	244	42D
0005434550422	9836	245	42H
0005434723782	9836	246	42G
0005434550331	9836	247	42F
0005434723687	9836	248	42J
0005433233811	9836	249	43A
0005433233793	9836	250	42K
0005433180954	9836	251	43C
0005433233834	9836	252	43B
0005433180939	9836	253	43E
0005434723968	9836	254	43D
0005433233789	9836	255	43H
0005433233808	9836	256	43G
0005433126817	9836	257	43K
0005434550500	9836	258	44C
0005433289806	9836	259	44A
0005433233820	9836	260	44D
0005434723982	9836	261	44G
0005433766617	9836	262	44J
0005434724326	9836	263	45A
0005434550420	9836	264	45D
0005434550429	9836	265	45C
0005434550260	9836	266	45K
0005433233794	9836	267	45J
0005434550320	9836	268	46B
0005434723714	9836	269	46A
0005434723517	9836	270	46C
0005434723738	9836	271	46G
0005434723356	9836	272	46F
0005433233806	9836	273	46K
0005434550484	9836	274	46H
0005434550280	9836	275	47A
0005434723548	9836	276	47E
0005434723689	9836	277	47D
0005433233840	9836	278	47C
0005434724133	9836	279	47F
0005433289803	9836	280	47K
0005434724325	9836	281	47H
0005434723909	9836	282	48D
0005434731115	9836	283	48C
0005434723733	9836	284	48A
0005434723386	9836	285	48F
0005433233815	9836	286	48E
0005433233799	9836	287	48H
0005433233788	9836	288	48G
0005433180937	9836	289	49A
0005434723355	9836	290	48K
0005434723441	9836	291	49E
0005433233829	9836	292	49D
0005434723957	9836	293	49G
0005433126818	9836	294	49F
0005434031998	9836	295	49K
0005433233792	9836	296	49H
0005433233824	9836	297	50C
0005434550339	9836	298	50A
0005433233790	9836	299	50E
0005434302383	9836	300	50D
0005434731108	9836	301	50H
0005434550511	9836	302	50G
0005433233801	9836	303	51F
0005434724165	9836	304	51E
0005432199208	9836	305	51D
0005434723887	9836	306	51G
0005434067138	7720	1	1C
0005432527121	7720	2	1A
0005434067097	7720	3	1G
0005432527215	7720	4	1D
0005434067148	7720	5	2A
0005432527195	7720	6	1K
0005434067142	7720	7	1H
0005435725537	7720	8	2C
0005435212669	7720	9	2H
0005435212791	7720	10	2G
0005435212417	7720	11	3A
0005434067135	7720	12	3G
0005432069562	7720	13	3C
0005432527161	7720	14	3K
0005432527122	7720	15	3H
0005435212402	7720	16	4C
0005432527177	7720	17	4A
0005435212577	7720	18	4G
0005432527175	7720	19	4D
0005432527145	7720	20	4K
0005432527111	7720	21	4H
0005432428908	7720	22	5C
0005435212607	7720	23	5A
0005432527148	7720	24	5D
0005432527144	7720	25	11A
0005434067156	7720	26	5K
0005432527160	7720	27	11E
0005432527115	7720	28	11D
0005435212391	7720	29	11C
0005432527193	7720	30	11F
0005432527183	7720	31	11K
0005434067154	7720	32	11H
0005432527139	7720	33	11G
0005435212601	7720	34	12C
0005432533274	7720	35	12E
0005432527170	7720	36	12D
0005432150147	7720	37	12H
0005434067120	7720	38	12G
0005432150149	7720	39	12F
0005434067126	7720	40	13D
0005432527199	7720	41	13E
0005432527218	7720	42	13H
0005435212415	7720	43	13G
0005432527219	7720	44	14A
0005435212517	7720	45	13K
0005432527186	7720	46	14G
0005432527159	7720	47	14F
0005432527213	7720	48	14E
0005432527150	7720	49	14H
0005432069570	7720	50	15A
0005434067146	7720	51	14K
0005434067125	7720	52	15E
0005434067127	7720	53	15D
0005435212575	7720	54	15H
0005435212539	7720	55	15K
0005432527235	7720	56	16D
0005435212770	7720	57	16C
0005432069571	7720	58	16F
0005432535803	7720	59	16K
0005435212405	7720	60	16H
0005434067145	7720	61	17A
0005435212585	7720	62	17D
0005434067122	7720	63	17G
0005435212330	7720	64	17F
0005432527136	7720	65	17E
0005434067155	7720	66	18A
0005432527174	7720	67	17H
0005432527129	7720	68	18C
0005434067143	7720	69	18B
0005434067113	7720	70	18E
0005434067161	7720	71	18D
0005435212657	7720	72	18G
0005432527214	7720	73	18K
0005432527176	7720	74	18J
0005435212353	7720	75	18H
0005432150144	7720	76	19B
0005432527133	7720	77	19A
0005435212814	7720	78	19D
0005434067128	7720	79	19C
0005434067166	7720	80	19F
0005435212769	7720	81	19E
0005432527242	7720	82	19H
0005432527208	7720	83	19G
0005435212511	7720	84	20A
0005432527217	7720	85	19J
0005435212715	7720	86	20E
0005435212484	7720	87	20D
0005432150143	7720	88	20G
0005432527172	7720	89	20F
0005432527114	7720	90	20K
0005432527234	7720	91	20J
0005432535806	7720	92	20H
0005432527236	7720	93	21B
0005434067123	7720	94	21A
0005432527188	7720	95	21D
0005432527157	7720	96	21E
0005434067108	7720	97	21H
0005435212329	7720	98	21G
0005432535804	7720	99	22A
0005435212403	7720	100	21K
0005434067100	7720	101	21J
0005432527239	7720	102	22C
0005434067147	7720	103	22B
0005432527196	7720	104	22E
0005434067158	7720	105	22D
0005432069567	7720	106	22H
0005432537044	7720	107	22K
0005432428906	7720	108	22J
0005432150145	7720	109	23B
0005435212667	7720	110	23A
0005432527155	7720	111	23C
0005435212404	7720	112	23E
0005432527241	7720	113	23H
0005434067132	7720	114	24D
0005435212602	7720	115	23K
0005432527209	7720	116	23J
0005432527229	7720	117	24F
0005432069559	7720	118	24E
0005432527227	7720	119	25B
0005432527202	7720	120	25A
0005432527143	7720	121	24G
0005432069560	7720	122	25C
0005435212625	7720	123	25E
0005432527138	7720	124	25H
0005432527124	7720	125	25G
0005434067111	7720	126	25F
0005434067103	7720	127	25K
0005432527127	7720	128	25J
0005432527220	7720	129	26B
0005434067139	7720	130	26A
0005434067117	7720	131	26C
0005435212450	7720	132	26H
0005434067109	7720	133	26G
0005435212574	7720	134	26F
0005434067151	7720	135	26J
0005435212700	7720	136	27A
0005435212722	7720	137	26K
0005435212568	7720	138	27D
0005435212661	7720	139	27F
0005432527110	7720	140	27H
0005432069568	7720	141	27G
0005432527153	7720	142	27K
0005432527212	7720	143	28A
0005432527166	7720	144	28E
0005435212395	7720	145	28D
0005435212504	7720	146	28C
0005435212453	7720	147	28G
0005434067134	7720	148	28F
0005432527135	7720	149	28J
0005432527112	7720	150	28H
0005434067099	7720	151	29B
0005432527154	7720	152	29D
0005432527120	7720	153	29F
0005435212438	7720	154	29E
0005434067159	7720	155	29H
0005432527221	7720	156	30A
0005434067112	7720	157	29J
0005434067149	7720	158	30E
0005432527207	7720	159	30D
0005432533272	7720	160	30G
0005432527158	7720	161	30K
0005432527163	7720	162	30J
0005432527149	7720	163	30H
0005432527123	7720	164	31B
0005432527243	7720	165	31A
0005432527147	7720	166	31D
0005434067104	7720	167	31F
0005435212576	7720	168	31E
0005434067164	7720	169	31H
0005435725519	7720	170	32B
0005432527187	7720	171	32A
0005432527178	7720	172	32E
0005432527117	7720	173	32G
0005432527210	7720	174	32F
0005433656613	7720	175	32K
0005432527190	7720	176	32J
0005434067160	7720	177	32H
0005432527180	7720	178	33D
0005434067133	7720	179	33E
0005434067110	7720	180	33H
0005432527146	7720	181	33G
0005432527119	7720	182	34A
0005432069566	7720	183	33K
0005434067119	7720	184	33J
0005432527223	7720	185	34C
0005432527224	7720	186	34B
0005432527140	7720	187	34E
0005434067136	7720	188	34D
0005434067107	7720	189	34H
0005434067140	7720	190	34G
0005432527203	7720	191	34F
0005432527182	7720	192	34J
0005432527171	7720	193	35B
0005435212573	7720	194	35A
0005432527116	7720	195	35D
0005432527238	7720	196	35C
0005432527126	7720	197	35G
0005435212670	7720	198	35E
0005434067153	7720	199	35K
0005434067165	7720	200	35J
0005432527240	7720	201	36C
0005434067150	7720	202	36E
0005432535802	7720	203	36F
0005432527211	7720	204	36K
0005432069561	7720	205	36J
0005435212433	7720	206	36H
0005435212600	7720	207	37B
0005432527189	7720	208	37C
0005434067130	7720	209	37G
0005432069563	7720	210	37H
0005434067144	7720	211	38A
0005432527216	7720	212	37K
0005434067121	7720	213	37J
0005435212538	7720	214	38C
0005434067102	7720	215	38B
0005432527179	7720	216	38K
0005432527173	7720	217	38J
0005432527165	7720	218	38H
0005432527230	7720	219	39A
0005435212656	7720	220	39D
0005435212588	7720	221	39C
0005432527168	7720	222	39E
0005434067101	7720	223	39H
0005432069565	7720	224	39G
0005432527226	7720	225	40A
0005432533273	7720	226	39K
0005432535805	7720	227	39J
0005432527113	7720	228	40C
0005432527205	7720	229	40E
0005435212714	7720	230	40D
0005432527132	7720	231	40J
0005432527204	7720	232	40H
0005432527137	7720	233	40K
0005432527169	7720	234	41D
0005432527225	7720	235	41C
0005432527156	7720	236	41F
0005435725538	7720	237	41E
0005434067094	7720	238	41H
0005432527118	7720	239	41G
0005432527192	7720	240	41K
0005435212572	7720	241	42B
0005434067114	7720	242	42A
0005434067163	7720	243	42E
0005432527198	7720	244	42D
0005432527151	7720	245	42C
0005435212797	7720	246	42G
0005434067152	7720	247	42F
0005432527232	7720	248	43B
0005433656614	7720	249	43A
0005434067137	7720	250	42K
0005435212366	7720	251	43C
0005434067162	7720	252	43F
0005432527128	7720	253	43E
0005432527233	7720	254	44A
0005432428907	7720	255	43K
0005432527228	7720	256	44B
0005432527184	7720	257	44E
0005435212507	7720	258	44G
0005432527162	7720	259	44J
0005434067157	7720	260	44H
0005435212367	7720	261	45B
0005432527237	7720	262	45D
0005434067095	7720	263	45C
0005432527185	7720	264	45E
0005432527134	7720	265	45H
0005435212668	7720	266	45K
0005434067115	7720	267	45J
0005432527131	7720	268	46B
0005434067105	7720	269	46A
0005432527201	7720	270	46E
0005432527141	7720	271	46D
0005432527142	7720	272	46C
0005435212587	7720	273	46G
0005434067116	7720	274	46F
0005432069569	7720	275	46J
0005435212792	7720	276	46H
0005434067141	7720	277	47C
0005432527167	7720	278	47A
0005432069564	7720	279	46K
0005434067118	7720	280	47G
0005432150146	7720	281	47F
0005432527164	7720	282	47H
0005432527181	7720	283	48C
0005432527200	7720	284	48A
0005432150148	7720	285	48F
0005434067096	7720	286	48E
0005432527231	7720	287	48D
0005432527197	7720	288	48H
0005432069572	7720	289	48G
0005432527130	7720	290	49A
0005432527191	7720	291	48K
0005434067131	7720	292	49E
0005435212399	7720	293	49D
0005434067106	7720	294	49C
0005434067124	7720	295	49G
0005432527194	7720	296	49F
0005435212392	7720	297	49H
0005432527222	7720	298	50C
0005434067129	7720	299	50A
0005432527152	7720	300	50E
0005432527125	7720	301	50D
0005435212328	7720	302	50F
0005434067098	7720	303	51F
0005432527206	7720	304	51E
0005435212458	7720	305	51G
0005435612946	5310	1	1G
0005434573264	5310	2	1D
0005435613019	5310	3	1K
0005435612973	5310	4	1H
0005434244507	5310	5	2D
0005435423856	5310	6	2C
0005434343998	5310	7	2A
0005435612959	5310	8	2H
0005435612920	5310	9	2G
0005435612947	5310	10	3A
0005434344009	5310	11	2K
0005435612943	5310	12	3G
0005432133114	5310	13	3D
0005434343997	5310	14	3K
0005435319465	5310	15	4A
0005435097149	5310	16	4G
0005434344002	5310	17	4C
0005432133125	5310	18	4K
0005435423872	5310	19	4H
0005434244567	5310	20	5D
0005434344004	5310	21	5C
0005435612986	5310	22	5A
0005435423724	5310	23	5H
0005435612930	5310	24	5G
0005435490206	5310	25	11A
0005435423977	5310	26	5K
0005435612966	5310	27	11D
0005435097146	5310	28	11C
0005434344001	5310	29	11G
0005435423591	5310	30	11F
0005435097151	5310	31	11E
0005434573267	5310	32	11K
0005432133111	5310	33	11H
0005435423704	5310	34	12C
0005435424109	5310	35	12A
0005434344008	5310	36	12E
0005434343996	5310	37	12D
0005434244498	5310	38	12G
0005435423978	5310	39	12K
0005435612911	5310	40	13D
0005435423955	5310	41	13C
0005435423830	5310	42	13H
0005435555356	5310	43	13G
0005432133115	5310	44	14A
0005432047527	5310	45	13K
0005434573266	5310	46	14D
0005435612988	5310	47	14C
0005435423800	5310	48	14F
0005434344022	5310	49	14E
0005435491428	5310	50	14K
0005435423911	5310	51	14H
0005435612953	5310	52	15C
0005435319450	5310	53	15A
0005434244572	5310	54	15E
0005435380247	5310	55	15D
0005435097147	5310	56	15H
0005435612971	5310	57	15G
0005432133121	5310	58	15F
0005435612913	5310	59	15K
0005435612936	5310	60	16D
0005435319443	5310	61	16F
0005435612997	5310	62	16E
0005432840982	5310	63	16H
0005435423914	5310	64	16G
0005435613007	5310	65	17C
0005435612961	5310	66	17A
0005435613002	5310	67	17E
0005435423916	5310	68	17D
0005435612992	5310	69	17G
0005435380231	5310	70	17F
0005435612942	5310	71	17K
0005435424091	5310	72	17H
0005434344011	5310	73	18B
0005435612951	5310	74	18E
0005434244614	5310	75	18D
0005435423575	5310	76	18C
0005432840985	5310	77	18J
0005435319439	5310	78	18H
0005435612915	5310	79	19B
0005435612967	5310	80	19A
0005435612980	5310	81	18K
0005435612987	5310	82	19D
0005434244521	5310	83	19C
0005435612916	5310	84	19E
0005435302130	5310	85	19H
0005434573272	5310	86	19G
0005434573261	5310	87	20A
0005435042825	5310	88	19K
0005434244538	5310	89	19J
0005435612926	5310	90	20C
0005434344003	5310	91	20B
0005434344020	5310	92	20E
0005435612941	5310	93	20D
0005435612963	5310	94	20G
0005435612929	5310	95	20H
0005435319482	5310	96	21B
0005435613015	5310	97	21A
0005435613006	5310	98	20K
0005435612974	5310	99	21C
0005434244546	5310	100	21F
0005435423953	5310	101	21E
0005435490204	5310	102	21H
0005435612989	5310	103	21G
0005432133123	5310	104	22A
0005435424000	5310	105	21K
0005435612977	5310	106	22D
0005435612969	5310	107	22C
0005434344023	5310	108	22B
0005435612933	5310	109	22E
0005435612979	5310	110	22H
0005434244566	5310	111	22G
0005434343999	5310	112	22F
0005435423873	5310	113	22K
0005435613003	5310	114	22J
0005434573270	5310	115	23A
0005435612998	5310	116	23D
0005435613000	5310	117	23C
0005432133119	5310	118	23G
0005435097152	5310	119	23F
0005434344014	5310	120	23E
0005435612983	5310	121	23J
0005435424093	5310	122	23H
0005434344007	5310	123	24D
0005434344016	5310	124	24G
0005435612949	5310	125	25D
0005435423996	5310	126	25F
0005435612972	5310	127	25E
0005435423831	5310	128	25H
0005432840981	5310	129	25J
0005435612996	5310	130	26B
0005434244551	5310	131	26A
0005435612944	5310	132	26E
0005435319484	5310	133	26G
0005434343991	5310	134	26K
0005435612962	5310	135	26J
0005435612924	5310	136	26H
0005434344021	5310	137	27B
0005435423888	5310	138	27A
0005435424061	5310	139	27F
0005435612932	5310	140	27E
0005434344012	5310	141	27D
0005435612954	5310	142	27H
0005435612995	5310	143	27K
0005435490205	5310	144	27J
0005435319442	5310	145	28A
0005434573269	5310	146	28E
0005435613001	5310	147	28D
0005435612909	5310	148	28G
0005433719089	5310	149	28F
0005435304989	5310	150	28J
0005435042822	5310	151	28H
0005432133113	5310	152	29A
0005435612931	5310	153	29D
0005435423991	5310	154	29B
0005435319462	5310	155	29F
0005434244650	5310	156	29E
0005435097156	5310	157	29H
0005435613012	5310	158	29K
0005435423837	5310	159	30C
0005435319440	5310	160	30B
0005435612957	5310	161	30E
0005434344000	5310	162	30D
0005435613011	5310	163	30F
0005435423890	5310	164	30H
0005435612978	5310	165	31B
0005434573273	5310	166	31A
0005435612945	5310	167	31C
0005434344015	5310	168	31F
0005435612993	5310	169	31E
0005435612910	5310	170	31H
0005435097154	5310	171	31G
0005434344019	5310	172	31J
0005435613004	5310	173	32C
0005435612958	5310	174	32B
0005434244477	5310	175	32D
0005434343995	5310	176	32G
0005435612990	5310	177	32F
0005435302129	5310	178	32J
0005435612928	5310	179	33B
0005435423982	5310	180	33D
0005432363384	5310	181	33C
0005435612908	5310	182	33F
0005435424024	5310	183	33E
0005435424056	5310	184	34A
0005435612939	5310	185	33K
0005434244520	5310	186	33J
0005434343992	5310	187	34B
0005434244568	5310	188	34E
0005435424004	5310	189	34G
0005434343988	5310	190	34F
0005435612960	5310	191	34K
0005435097148	5310	192	34J
0005435423860	5310	193	35B
0005435612952	5310	194	35D
0005435612938	5310	195	35C
0005435423903	5310	196	35F
0005434344018	5310	197	35E
0005435424057	5310	198	35J
0005432133112	5310	199	35H
0005432840986	5310	200	35G
0005435612970	5310	201	35K
0005435423904	5310	202	36C
0005435612927	5310	203	36B
0005435042824	5310	204	36A
0005435612907	5310	205	36E
0005435319466	5310	206	36D
0005435612950	5310	207	36H
0005435302128	5310	208	36G
0005435613016	5310	209	36F
0005435612914	5310	210	36K
0005434344010	5310	211	36J
0005434573265	5310	212	37C
0005435423857	5310	213	37A
0005432047528	5310	214	37G
0005434573262	5310	215	37E
0005435612922	5310	216	37J
0005435042820	5310	217	38A
0005434344006	5310	218	37K
0005434344017	5310	219	38B
0005435612981	5310	220	38J
0005432133118	5310	221	39A
0005435612984	5310	222	38K
0005434573271	5310	223	39C
0005434343990	5310	224	39F
0005433719082	5310	225	39E
0005435423864	5310	226	39G
0005434344013	5310	227	39J
0005434343989	5310	228	40C
0005435424066	5310	229	40B
0005435304996	5310	230	40F
0005434244553	5310	231	40E
0005435612917	5310	232	40G
0005435612921	5310	233	40J
0005435423600	5310	234	40H
0005435612955	5310	235	41B
0005435612975	5310	236	40K
0005435613005	5310	237	41C
0005435424161	5310	238	41F
0005435424002	5310	239	41E
0005435613008	5310	240	41H
0005435612925	5310	241	41G
0005435423901	5310	242	42A
0005435612923	5310	243	41K
0005435424003	5310	244	42C
0005435423990	5310	245	42B
0005435424067	5310	246	42E
0005435612982	5310	247	42D
0005435423660	5310	248	42G
0005435424160	5310	249	42F
0005435612964	5310	250	42K
0005435042829	5310	251	42J
0005435613009	5310	252	42H
0005435424092	5310	253	43D
0005432047526	5310	254	43C
0005432133120	5310	255	43E
0005434244588	5310	256	43H
0005435612940	5310	257	44A
0005435423902	5310	258	43J
0005435612976	5310	259	44C
0005435612919	5310	260	44B
0005435319483	5310	261	44E
0005435613013	5310	262	44D
0005435042830	5310	263	44K
0005435491429	5310	264	44J
0005434343994	5310	265	44H
0005435423889	5310	266	45A
0005435423705	5310	267	45C
0005435423913	5310	268	45F
0005432133124	5310	269	45E
0005435490203	5310	270	45H
0005435423594	5310	271	45G
0005435490207	5310	272	45K
0005434343993	5310	273	46C
0005435612965	5310	274	46B
0005434573268	5310	275	46E
0005435612937	5310	276	46D
0005435097155	5310	277	46G
0005435423659	5310	278	46F
0005435612906	5310	279	46H
0005435097153	5310	280	47C
0005435612918	5310	281	46K
0005435612935	5310	282	47E
0005435612934	5310	283	47D
0005435424051	5310	284	47G
0005435612912	5310	285	47F
0005435613018	5310	286	47K
0005435612956	5310	287	48F
0005432133116	5310	288	48E
0005434344005	5310	289	48D
0005432133117	5310	290	48H
0005435423931	5310	291	48G
0005432363361	5310	292	49A
0005435612999	5310	293	49D
0005435613010	5310	294	49C
0005435612948	5310	295	49F
0005435612985	5310	296	49K
0005435612991	5310	297	49H
0005435097150	5310	298	49G
0005435613014	5310	299	50C
0005432133122	5310	300	50F
0005432840980	5310	301	50E
0005434573263	5310	302	50D
0005435612968	5310	303	50H
0005434244552	5310	304	50K
0005435042821	5310	305	51F
0005435612994	5310	306	51E
0005432047525	5310	307	51D
0005435613017	5310	308	51G
0005435424410	10933	1	1A
0005435424353	10933	2	1G
0005435611954	10933	3	1K
0005435424367	10933	4	1H
0005435424407	10933	5	2C
0005435319519	10933	6	2A
0005435611912	10933	7	2G
0005435424417	10933	8	2D
0005435611951	10933	9	3A
0005435424416	10933	10	2K
0005435491413	10933	11	3G
0005435424369	10933	12	3D
0005435612255	10933	13	3C
0005435424404	10933	14	3H
0005432164993	10933	15	3K
0005435424385	10933	16	4G
0005435424420	10933	17	4K
0005432164989	10933	18	5A
0005435612108	10933	19	5G
0005435424381	10933	20	5K
0005434573107	10933	21	11D
0005433719121	10933	22	11C
0005435612102	10933	23	11F
0005434343615	10933	24	11E
0005435612159	10933	25	11G
0005435042840	10933	26	12C
0005435424360	10933	27	12A
0005435042842	10933	28	12E
0005435424374	10933	29	12D
0005435612054	10933	30	12F
0005434244815	10933	31	12K
0005434244800	10933	32	13D
0005435424377	10933	33	13C
0005435611771	10933	34	13F
0005435611788	10933	35	13E
0005435042843	10933	36	13H
0005435612086	10933	37	14C
0005435424397	10933	38	14E
0005435612262	10933	39	14D
0005435319517	10933	40	14G
0005434343622	10933	41	14K
0005435611890	10933	42	14H
0005432164987	10933	43	15C
0005435424366	10933	44	15A
0005435612080	10933	45	15E
0005435424379	10933	46	15D
0005435611718	10933	47	15H
0005435612019	10933	48	15G
0005434656543	10933	49	15F
0005435319514	10933	50	16A
0005434573114	10933	51	15K
0005435612028	10933	52	16D
0005435424351	10933	53	16H
0005435612428	10933	54	16G
0005435424395	10933	55	17A
0005435555338	10933	56	16K
0005435612233	10933	57	17E
0005435612294	10933	58	17G
0005434244795	10933	59	17F
0005435611796	10933	60	17K
0005434343740	10933	61	17H
0005435424405	10933	62	18A
0005435424387	10933	63	18E
0005435612418	10933	64	18D
0005434343745	10933	65	18G
0005435424406	10933	66	18F
0005435424364	10933	67	18J
0005434244793	10933	68	18H
0005435612431	10933	69	19B
0005435424411	10933	70	19A
0005435305002	10933	71	18K
0005435612412	10933	72	19D
0005434244814	10933	73	19C
0005435611993	10933	74	19H
0005434343670	10933	75	19G
0005435612209	10933	76	20A
0005435611722	10933	77	19K
0005434573154	10933	78	19J
0005434343632	10933	79	20C
0005435612176	10933	80	20B
0005435304128	10933	81	20E
0005432841000	10933	82	20D
0005434244802	10933	83	20G
0005434244809	10933	84	20F
0005434343640	10933	85	20K
0005435612308	10933	86	20J
0005435612107	10933	87	20H
0005435611952	10933	88	21B
0005435611783	10933	89	21C
0005435612310	10933	90	21F
0005435612432	10933	91	21H
0005435612085	10933	92	21G
0005434244801	10933	93	22A
0005434244807	10933	94	21K
0005435611746	10933	95	22C
0005435612346	10933	96	22B
0005434343771	10933	97	22F
0005434343736	10933	98	22E
0005435612093	10933	99	22D
0005435612586	10933	100	22G
0005435612079	10933	101	22K
0005435612082	10933	102	23B
0005435612314	10933	103	23D
0005434244805	10933	104	23C
0005435424372	10933	105	23E
0005435611999	10933	106	23H
0005435424373	10933	107	23G
0005435424408	10933	108	24D
0005434244811	10933	109	23K
0005435424361	10933	110	23J
0005435612223	10933	111	24E
0005435491414	10933	112	25B
0005435612271	10933	113	25A
0005435424414	10933	114	24G
0005434573157	10933	115	25C
0005435424399	10933	116	25F
0005435612065	10933	117	25E
0005434343706	10933	118	25H
0005435319520	10933	119	25K
0005434244796	10933	120	25J
0005433719120	10933	121	26B
0005434343641	10933	122	26A
0005435424422	10933	123	26E
0005435424382	10933	124	26G
0005435424390	10933	125	26F
0005434343650	10933	126	26H
0005435611994	10933	127	27A
0005435612066	10933	128	26K
0005435612157	10933	129	27D
0005434244813	10933	130	27C
0005434573118	10933	131	27E
0005435424378	10933	132	27J
0005435612309	10933	133	27H
0005435612072	10933	134	27G
0005435611882	10933	135	27K
0005435612312	10933	136	28C
0005432841001	10933	137	28B
0005435305001	10933	138	28A
0005435612143	10933	139	28E
0005435612103	10933	140	28D
0005435424394	10933	141	28G
0005434244797	10933	142	28F
0005435611948	10933	143	28J
0005434573121	10933	144	28H
0005435424409	10933	145	29B
0005435612044	10933	146	29A
0005435612074	10933	147	29D
0005435319515	10933	148	29C
0005434343616	10933	149	29F
0005435611949	10933	150	29E
0005435611713	10933	151	29H
0005435424391	10933	152	29G
0005434343603	10933	153	29K
0005435305004	10933	154	29J
0005435612134	10933	155	30B
0005435612599	10933	156	30D
0005435424368	10933	157	30G
0005435042839	10933	158	30F
0005435612289	10933	159	30H
0005434656544	10933	160	31A
0005435304129	10933	161	30K
0005432166881	10933	162	31D
0005434244804	10933	163	31F
0005435612213	10933	164	31E
0005435319518	10933	165	31H
0005435612022	10933	166	31G
0005435612208	10933	167	32A
0005435304130	10933	168	31K
0005435611851	10933	169	31J
0005435611891	10933	170	32C
0005435611968	10933	171	32B
0005435424403	10933	172	32E
0005435612347	10933	173	32D
0005435305003	10933	174	32F
0005435612124	10933	175	32H
0005435611955	10933	176	33B
0005434244812	10933	177	33D
0005434244803	10933	178	33C
0005434573155	10933	179	33F
0005435424401	10933	180	33E
0005435424389	10933	181	33H
0005434343671	10933	182	33G
0005435424375	10933	183	33K
0005435424356	10933	184	33J
0005434573117	10933	185	34C
0005435612471	10933	186	34B
0005434573153	10933	187	34A
0005432164992	10933	188	34D
0005435612075	10933	189	34F
0005435424412	10933	190	34J
0005434244789	10933	191	35B
0005435611856	10933	192	34K
0005432166880	10933	193	35E
0005435612125	10933	194	35C
0005434343582	10933	195	35F
0005432840999	10933	196	35H
0005435424419	10933	197	35G
0005435424418	10933	198	35J
0005435555342	10933	199	36B
0005434244794	10933	200	36E
0005435611980	10933	201	36D
0005435424413	10933	202	36G
0005435424359	10933	203	36K
0005435611881	10933	204	36H
0005435042841	10933	205	37B
0005434343681	10933	206	37A
0005435304127	10933	207	37D
0005435611953	10933	208	37F
0005435319522	10933	209	37E
0005432363395	10933	210	37H
0005434573113	10933	211	37G
0005434244787	10933	212	38A
0005435424398	10933	213	37K
0005435424376	10933	214	37J
0005435612041	10933	215	39B
0005435612221	10933	216	39A
0005435612275	10933	217	39D
0005432164991	10933	218	39F
0005435612000	10933	219	39E
0005434244792	10933	220	39H
0005432164990	10933	221	39G
0005435424388	10933	222	40A
0005434573136	10933	223	39K
0005434343705	10933	224	40C
0005435424358	10933	225	40B
0005435612234	10933	226	40D
0005432164988	10933	227	40G
0005435611922	10933	228	40F
0005434244810	10933	229	40K
0005435424384	10933	230	40J
0005435424380	10933	231	41B
0005434343678	10933	232	41A
0005435424363	10933	233	41E
0005435611972	10933	234	41F
0005435611703	10933	235	41J
0005435424392	10933	236	41H
0005435611770	10933	237	41G
0005434244808	10933	238	42A
0005435611894	10933	239	42D
0005433719119	10933	240	42G
0005435612293	10933	241	42F
0005435424354	10933	242	42J
0005435611850	10933	243	42H
0005435612220	10933	244	43B
0005434343679	10933	245	43A
0005435319521	10933	246	42K
0005435424396	10933	247	43C
0005435424402	10933	248	43F
0005435424371	10933	249	43J
0005435424400	10933	250	43H
0005435612429	10933	251	43K
0005435612332	10933	252	44B
0005434343593	10933	253	44A
0005434573133	10933	254	44D
0005435612104	10933	255	44C
0005435611843	10933	256	44F
0005435611794	10933	257	44J
0005435424352	10933	258	44H
0005435304131	10933	259	45A
0005435424383	10933	260	44K
0005435611969	10933	261	45D
0005435424357	10933	262	45C
0005435424415	10933	263	45B
0005432166882	10933	264	45F
0005435611761	10933	265	45E
0005435612175	10933	266	45H
0005434244806	10933	267	45G
0005435611855	10933	268	45K
0005432363396	10933	269	45J
0005434244798	10933	270	46C
0005435612297	10933	271	46A
0005435611712	10933	272	46E
0005435611913	10933	273	46D
0005435490176	10933	274	46G
0005435612073	10933	275	46J
0005435611842	10933	276	46H
0005435612067	10933	277	47C
0005434573111	10933	278	47A
0005432164994	10933	279	46K
0005435612313	10933	280	47D
0005435424365	10933	281	47G
0005435424362	10933	282	47F
0005435319523	10933	283	47H
0005435424393	10933	284	48C
0005432363397	10933	285	48F
0005434244799	10933	286	48H
0005435612092	10933	287	48G
0005435611820	10933	288	48K
0005434244790	10933	289	49D
0005435611945	10933	290	49C
0005435319516	10933	291	49G
0005435612001	10933	292	49F
0005434343744	10933	293	49K
0005435424386	10933	294	50A
0005434244788	10933	295	50E
0005434244791	10933	296	50D
0005434244786	10933	297	50G
0005435611977	10933	298	50F
0005435424421	10933	299	50K
0005434343602	10933	300	50H
0005435424355	10933	301	51F
0005435424370	10933	302	51G
0005433633626	3394	1	1A
0005433633625	3394	2	1C
0005433805146	3394	3	1F
0005433805153	3394	4	1D
0005432459142	3394	5	2A
0005433507062	3394	6	2C
0005432458964	3394	7	2D
0005432181576	3394	8	3A
0005433805127	3394	9	2F
0005432459276	3394	10	3D
0005433805159	3394	11	3C
0005432181570	3394	12	4A
0005433805158	3394	13	3F
0005433507074	3394	14	4C
0005432459182	3394	15	4F
0005432459040	3394	16	4D
0005433805162	3394	17	5C
0005432459280	3394	18	5F
0005432459022	3394	19	6A
0005432459181	3394	20	6C
0005433805143	3394	21	6D
0005433805126	3394	22	7A
0005432181585	3394	23	6F
0005433507065	3394	24	7D
0005433805156	3394	25	7C
0005433633612	3394	26	7F
0005433633608	3394	27	8A
0005432459056	3394	28	8B
0005433507075	3394	29	8D
0005433633631	3394	30	8C
0005432459139	3394	31	8E
0005433805129	3394	32	9A
0005433507068	3394	33	8F
0005433633615	3394	34	9B
0005433507063	3394	35	9C
0005433633629	3394	36	9D
0005433805128	3394	37	9F
0005432458969	3394	38	9E
0005433633611	3394	39	10A
0005432181582	3394	40	10C
0005432459066	3394	41	10B
0005432459133	3394	42	10D
0005433805137	3394	43	10F
0005432459024	3394	44	11A
0005432181590	3394	45	11C
0005432459051	3394	46	11B
0005433633616	3394	47	11D
0005433507069	3394	48	11E
0005433805138	3394	49	12A
0005433805133	3394	50	11F
0005433633618	3394	51	12C
0005432459028	3394	52	12B
0005432458970	3394	53	12E
0005432181583	3394	54	12D
0005432459009	3394	55	13A
0005433507066	3394	56	12F
0005433633600	3394	57	13C
0005432181589	3394	58	13B
0005432459286	3394	59	13D
0005433805132	3394	60	13F
0005432181574	3394	61	13E
0005432459030	3394	62	14B
0005434143715	3394	63	14C
0005432459112	3394	64	14E
0005432459201	3394	65	14D
0005432459211	3394	66	14F
0005432459052	3394	67	15A
0005432458999	3394	68	15C
0005433507067	3394	69	15B
0005432181572	3394	70	15D
0005433633602	3394	71	15F
0005432459039	3394	72	15E
0005433633607	3394	73	16A
0005433805140	3394	74	16C
0005433805165	3394	75	16B
0005433633628	3394	76	16F
0005433805151	3394	77	16E
0005433633613	3394	78	16D
0005432181569	3394	79	17A
0005432181584	3394	80	17B
0005433805131	3394	81	17C
0005433805135	3394	82	18A
0005432181581	3394	83	17F
0005432458992	3394	84	18C
0005432181575	3394	85	18B
0005432181588	3394	86	18E
0005433633603	3394	87	18D
0005433805142	3394	88	18F
0005433805139	3394	89	19C
0005433805163	3394	90	19B
0005432181580	3394	91	19E
0005432459033	3394	92	20B
0005433805155	3394	93	20C
0005432181577	3394	94	20D
0005433633606	3394	95	20F
0005432181571	3394	96	21B
0005433805157	3394	97	21A
0005433507070	3394	98	21C
0005433805149	3394	99	21D
0005433633623	3394	100	21E
0005433633601	3394	101	21F
0005433805154	3394	102	22B
0005433633610	3394	103	22A
0005433805164	3394	104	22C
0005433633617	3394	105	22D
0005432181578	3394	106	22E
0005433633630	3394	107	23A
0005432459029	3394	108	22F
0005433633609	3394	109	23B
0005432458971	3394	110	23D
0005433507064	3394	111	23C
0005433805147	3394	112	23E
0005432459019	3394	113	23F
0005433633627	3394	114	24B
0005432459020	3394	115	24A
0005432181586	3394	116	24C
0005433805161	3394	117	24D
0005433805160	3394	118	24F
0005433805134	3394	119	24E
0005433633622	3394	120	25A
0005432459032	3394	121	25C
0005432181573	3394	122	25B
0005433507076	3394	123	25D
0005433805130	3394	124	25E
0005433805141	3394	125	26A
0005433633614	3394	126	25F
0005433507073	3394	127	26B
0005433633624	3394	128	26D
0005433633620	3394	129	26C
0005433805152	3394	130	26E
0005432459068	3394	131	26F
0005433633604	3394	132	27B
0005432458972	3394	133	27C
0005432181591	3394	134	27D
0005432459212	3394	135	27F
0005433805150	3394	136	27E
0005433805166	3394	137	28B
0005433633621	3394	138	28A
0005432459021	3394	139	28C
0005432459057	3394	140	28E
0005433805167	3394	141	28D
0005434143716	3394	142	29A
0005432459285	3394	143	29C
0005432459118	3394	144	29B
0005432181579	3394	145	29D
0005433633605	3394	146	29E
0005432459120	3394	147	30A
0005432181587	3394	148	30C
0005433805148	3394	149	30B
0005433507071	3394	150	30D
0005433633599	3394	151	30E
0005433805144	3394	152	31A
0005432459075	3394	153	30F
0005433805145	3394	154	31B
0005433633619	3394	155	31C
0005433805136	3394	156	31D
0005432459067	3394	157	31F
0005433507072	3394	158	31E
0005435884521	3393	1	1A
0005435884597	3393	2	1D
0005435884383	3393	3	3F
0005435884469	3393	4	6A
0005435884400	3393	5	6F
0005435884672	3393	6	7A
0005435884479	3393	7	8D
0005435884827	3393	8	8F
0005435884494	3393	9	9E
0005435884530	3393	10	12B
0005435884410	3393	11	12D
0005435884699	3393	12	13A
0005435884513	3393	13	15C
0005435884442	3393	14	16A
0005435884495	3393	15	16D
0005435884821	3393	16	17A
0005435884624	3393	17	17B
0005435884475	3393	18	17F
0005435884625	3393	19	17E
0005435884626	3393	20	18B
0005435884646	3393	21	19E
0005435884569	3393	22	20A
0005435884654	3393	23	20C
0005435884453	3393	24	20D
0005435884474	3393	25	21D
0005435884645	3393	26	21E
0005435884546	3393	27	22D
0005435884548	3393	28	24B
0005435884655	3393	29	24E
0005435884547	3393	30	25C
0005435884529	3393	31	26D
0005435884470	3393	32	27F
0005435884436	3393	33	27E
0005435884545	3393	34	28A
0005435884769	3393	35	30A
0005435884435	3393	36	30C
0005435884660	3393	37	31C
0005435884534	3393	38	31E
0005435884932	8188	1	1C
0005432459549	8188	2	1A
0005435884954	8188	3	1D
0005435884906	8188	4	2A
0005435884924	8188	5	1F
0005433506905	8188	6	2C
0005432459553	8188	7	2D
0005435884957	8188	8	3A
0005435884947	8188	9	2F
0005435884958	8188	10	3C
0005432459585	8188	11	3D
0005435884944	8188	12	4C
0005432459558	8188	13	4F
0005432459564	8188	14	4D
0005435884909	8188	15	5A
0005435884917	8188	16	5C
0005435884922	8188	17	5F
0005435884918	8188	18	6A
0005432459568	8188	19	6C
0005432459583	8188	20	6F
0005432459586	8188	21	6D
0005432459548	8188	22	7A
0005432459577	8188	23	7C
0005432459560	8188	24	7F
0005435884962	8188	25	7D
0005432459571	8188	26	8B
0005435884914	8188	27	8D
0005435884933	8188	28	8C
0005435884927	8188	29	8E
0005435884916	8188	30	8F
0005435884956	8188	31	9C
0005432459551	8188	32	9B
0005435884903	8188	33	9D
0005435884905	8188	34	9F
0005435884931	8188	35	9E
0005435884946	8188	36	10C
0005435884964	8188	37	10B
0005435884925	8188	38	10D
0005432042633	8188	39	10E
0005432459567	8188	40	10F
0005432459547	8188	41	11A
0005435884952	8188	42	11C
0005432459552	8188	43	11D
0005435884951	8188	44	11E
0005432459576	8188	45	12A
0005432459579	8188	46	12B
0005432042638	8188	47	12C
0005433506938	8188	48	12E
0005433506981	8188	49	12D
0005432459589	8188	50	12F
0005435884959	8188	51	13A
0005435884926	8188	52	13C
0005432459594	8188	53	13D
0005432042631	8188	54	13F
0005432459570	8188	55	14A
0005432459593	8188	56	14C
0005435884935	8188	57	14B
0005432459587	8188	58	14D
0005433506959	8188	59	14E
0005435884943	8188	60	14F
0005432459580	8188	61	15A
0005435884938	8188	62	15C
0005432459569	8188	63	15B
0005435884942	8188	64	15E
0005435884937	8188	65	15D
0005432042630	8188	66	15F
0005435884940	8188	67	16A
0005432459584	8188	68	16B
0005435884967	8188	69	16D
0005435884960	8188	70	16C
0005435884939	8188	71	16E
0005435884923	8188	72	16F
0005432042627	8188	73	17B
0005433506921	8188	74	17C
0005432459575	8188	75	17D
0005435884963	8188	76	17E
0005432459588	8188	77	17F
0005433506947	8188	78	18B
0005435884949	8188	79	18E
0005435884934	8188	80	18D
0005432459546	8188	81	18F
0005435884904	8188	82	19C
0005432459573	8188	83	19B
0005432042634	8188	84	19D
0005435884941	8188	85	19E
0005433506909	8188	86	20B
0005435884929	8188	87	20C
0005432459591	8188	88	20D
0005432459556	8188	89	20E
0005432459572	8188	90	21A
0005435884950	8188	91	21C
0005435884911	8188	92	21B
0005432459574	8188	93	21D
0005432042628	8188	94	21E
0005432459582	8188	95	22A
0005432459596	8188	96	22B
0005432459563	8188	97	22D
0005435884910	8188	98	22C
0005435884921	8188	99	22F
0005432459559	8188	100	22E
0005433506854	8188	101	23B
0005435884948	8188	102	23D
0005432459550	8188	103	23C
0005432459565	8188	104	24A
0005432042629	8188	105	23F
0005435884945	8188	106	24D
0005432042637	8188	107	25A
0005433506901	8188	108	25C
0005432042626	8188	109	25B
0005432459555	8188	110	25D
0005433506916	8188	111	25F
0005435884930	8188	112	25E
0005435884928	8188	113	26B
0005432459595	8188	114	26D
0005432042636	8188	115	26C
0005432459592	8188	116	26F
0005435884913	8188	117	27B
0005433506894	8188	118	27A
0005432459562	8188	119	27D
0005435884965	8188	120	27F
0005435884966	8188	121	27E
0005435884955	8188	122	28A
0005435884912	8188	123	28B
0005432459578	8188	124	28C
0005435884936	8188	125	28E
0005432459554	8188	126	28D
0005432459545	8188	127	29A
0005432459557	8188	128	28F
0005432459561	8188	129	29B
0005435884915	8188	130	29C
0005432459581	8188	131	29D
0005433506922	8188	132	29F
0005435884902	8188	133	29E
0005435884953	8188	134	30A
0005432042635	8188	135	30B
0005435884919	8188	136	30C
0005432459590	8188	137	30E
0005435884920	8188	138	30D
0005432459566	8188	139	30F
0005435884907	8188	140	31B
0005435884961	8188	141	31C
0005432042632	8188	142	31E
0005435884908	8188	143	31D
0005433506870	8188	144	31F
0005433804824	8187	1	1A
0005433804905	8187	2	1F
0005433633229	8187	3	2C
0005433633351	8187	4	2F
0005433633350	8187	5	2D
0005433633294	8187	6	3C
0005433633325	8187	7	3D
0005433633267	8187	8	5D
0005433804819	8187	9	6C
0005433633268	8187	10	7C
0005433633239	8187	11	7D
0005433804834	8187	12	8A
0005433633343	8187	13	8D
0005433633384	8187	14	8E
0005433804945	8187	15	9C
0005433804921	8187	16	9B
0005433804876	8187	17	9D
0005433804835	8187	18	10D
0005433804821	8187	19	10E
0005433633300	8187	20	12B
0005433804968	8187	21	12F
0005433804942	8187	22	14B
0005433804946	8187	23	14E
0005434271283	8187	24	14F
0005433633259	8187	25	15C
0005433804937	8187	26	15B
0005433633348	8187	27	15D
0005433804831	8187	28	15F
0005433633260	8187	29	16A
0005433633263	8187	30	17A
0005433633237	8187	31	16F
0005433633387	8187	32	17D
0005433804873	8187	33	17C
0005433633360	8187	34	18A
0005433633364	8187	35	19D
0005433633280	8187	36	19C
0005433633293	8187	37	19E
0005433633304	8187	38	20C
0005433804930	8187	39	20B
0005433633266	8187	40	20E
0005433804845	8187	41	21B
0005433633349	8187	42	21C
0005433633265	8187	43	21E
0005433804944	8187	44	23A
0005433804813	8187	45	23D
0005433633311	8187	46	23E
0005433804896	8187	47	24A
0005433633264	8187	48	24B
0005434271282	8187	49	24E
0005433804894	8187	50	24D
0005433633356	8187	51	25A
0005433804872	8187	52	25B
0005433804875	8187	53	25E
0005433633326	8187	54	25D
0005433804893	8187	55	26B
0005433633298	8187	56	26D
0005433633262	8187	57	26F
0005433633261	8187	58	28B
0005433633310	8187	59	28F
0005433804915	8187	60	29A
0005433633258	8187	61	29C
0005433633331	8187	62	29D
0005433804862	8187	63	29E
0005433804881	8187	64	29F
0005433633228	8187	65	30E
0005433804851	8187	66	30F
0005433804899	8187	67	31E
0005433633238	8187	68	31D
0005434183550	8186	1	1D
0005433194837	4582	1	1C
0005432382946	4582	2	1D
0005432382937	4582	3	1F
0005433194839	4582	4	2A
0005432382942	4582	5	2C
0005433722182	4582	6	2D
0005432382952	4582	7	3A
0005433722179	4582	8	3C
0005433194836	4582	9	3D
0005433194834	4582	10	3F
0005432382950	4582	11	4A
0005432382965	4582	12	4C
0005433722183	4582	13	4D
0005433722186	4582	14	4E
0005433722185	4582	15	4F
0005433722181	4582	16	5C
0005433194838	4582	17	5F
0005432382960	4582	18	6A
0005432382927	4582	19	6C
0005432382963	4582	20	6E
0005432382935	4582	21	6F
0005432382953	4582	22	7A
0005432382948	4582	23	7C
0005432727865	4582	24	7D
0005432727864	4582	25	7F
0005432382955	4582	26	8A
0005432382933	4582	27	8C
0005432382949	4582	28	8E
0005432727860	4582	29	8F
0005432382958	4582	30	9A
0005432727862	4582	31	9C
0005433453752	4582	32	9E
0005432382957	4582	33	9F
0005432382938	4582	34	10C
0005433194842	4582	35	10D
0005433722184	4582	36	10E
0005433194841	4582	37	10F
0005432382954	4582	38	11A
0005432382945	4582	39	11C
0005432382956	4582	40	11D
0005433453751	4582	41	11E
0005432382966	4582	42	11F
0005432382951	4582	43	12C
0005432382967	4582	44	12E
0005432382941	4582	45	13D
0005432727857	4582	46	13E
0005432727868	4582	47	13F
0005432727859	4582	48	14A
0005432382932	4582	49	14C
0005432382947	4582	50	14E
0005432382959	4582	51	14F
0005432727858	4582	52	15A
0005432727866	4582	53	15C
0005432727861	4582	54	15D
0005432382930	4582	55	15F
0005432727867	4582	56	16A
0005432382931	4582	57	16D
0005432382929	4582	58	16E
0005432382944	4582	59	16F
0005432382961	4582	60	17A
0005432382928	4582	61	17C
0005432382940	4582	62	17E
0005433722180	4582	63	18C
0005432382934	4582	64	18D
0005432382964	4582	65	18E
0005432382936	4582	66	18F
0005432727863	4582	67	19A
0005432382943	4582	68	19C
0005432382939	4582	69	19D
0005433453750	4582	70	19E
0005432382962	4582	71	19F
0005433194840	4582	72	20A
0005433194835	4582	73	20C
0005432382968	4582	74	20D
0005432382538	30220	1	1A
0005432382766	30220	2	1F
0005432382539	30220	3	4A
0005433453742	30220	4	5C
0005432382550	30220	5	5E
0005432382485	30220	6	6C
0005432382593	30220	7	6E
0005433722103	30220	8	7C
0005433451584	30220	9	7D
0005432382764	30220	10	8C
0005433722115	30220	11	8D
0005432727797	30220	12	9C
0005432382530	30220	13	9E
0005432382585	30220	14	10C
0005432382560	30220	15	10D
0005433453740	30220	16	10F
0005432382765	30220	17	11C
0005433453741	30220	18	11D
0005432727752	30220	19	11E
0005432727757	30220	20	12D
0005432727758	30220	21	12F
0005432727769	30220	22	13A
0005432382612	30220	23	13C
0005433194827	30220	24	13D
0005432727820	30220	25	13F
0005433722106	30220	26	14C
0005432382567	30220	27	15A
0005432382549	30220	28	15C
0005432382594	30220	29	15D
0005432382551	30220	30	15F
0005432382599	30220	31	16A
0005432382668	30220	32	16C
0005433451585	30220	33	16F
0005432382667	30220	34	17E
0005432727761	30220	35	18C
0005433453726	30220	36	18D
0005432382529	30220	37	19C
0005432382486	30220	38	19D
0005432382537	30220	39	19F
0005432727762	30220	40	20A
0005432382522	30220	41	20C
0005433453727	30220	42	20D
0005435540869	1716	1	1A
0005435540884	1716	2	1F
0005432924963	1716	3	2A
0005435529142	1716	4	2D
0005435529132	1716	5	2F
0005435529141	1716	6	3A
0005435540872	1716	7	3C
0005435540878	1716	8	3F
0005435529123	1716	9	4E
0005433516835	1716	10	4F
0005433516834	1716	11	5A
0005432924967	1716	12	5C
0005433516830	1716	13	5E
0005435540873	1716	14	5F
0005435529139	1716	15	6C
0005435529129	1716	16	6D
0005435529127	1716	17	6E
0005433516827	1716	18	7A
0005433516831	1716	19	7C
0005433516832	1716	20	7E
0005435529124	1716	21	8C
0005435540881	1716	22	8D
0005435540870	1716	23	8F
0005435540867	1716	24	9C
0005433516828	1716	25	9E
0005432924953	1716	26	9F
0005432924960	1716	27	10A
0005435540882	1716	28	10F
0005435529133	1716	29	11C
0005435529134	1716	30	11D
0005435529140	1716	31	11E
0005435540875	1716	32	11F
0005435540866	1716	33	12C
0005435540883	1716	34	12D
0005435540868	1716	35	12F
0005432924962	1716	36	13A
0005433516833	1716	37	13C
0005435529138	1716	38	13D
0005435529131	1716	39	13E
0005433516829	1716	40	14A
0005435529122	1716	41	14C
0005435529125	1716	42	14D
0005435540877	1716	43	14E
0005435529137	1716	44	15C
0005432924959	1716	45	15D
0005435540879	1716	46	15E
0005432924983	1716	47	16A
0005435540885	1716	48	16F
0005435540887	1716	49	17C
0005432924982	1716	50	17D
0005435529128	1716	51	17E
0005435540876	1716	52	17F
0005435529135	1716	53	18A
0005435540871	1716	54	18C
0005435540886	1716	55	18D
0005435540880	1716	56	18E
0005435529126	1716	57	18F
0005435529143	1716	58	19C
0005432294473	1716	59	19D
0005435540874	1716	60	19F
0005435529130	1716	61	20A
0005435529136	1716	62	20D
0005435540699	21986	1	2A
0005435540737	21986	2	3C
0005435517686	21986	3	3F
0005433516776	21986	4	4C
0005435540726	21986	5	4D
0005435540700	21986	6	4E
0005435517681	21986	7	5C
0005433516796	21986	8	5D
0005435540750	21986	9	5E
0005435517619	21986	10	6D
0005435540673	21986	11	6E
0005435517662	21986	12	8C
0005435540625	21986	13	8F
0005435517617	21986	14	9A
0005432925006	21986	15	9C
0005435540627	21986	16	9E
0005435540624	21986	17	9F
0005435540646	21986	18	10D
0005435517631	21986	19	10F
0005433516759	21986	20	11D
0005432925007	21986	21	12A
0005435517625	21986	22	12F
0005433516731	21986	23	13C
0005435517684	21986	24	13F
0005435540703	21986	25	14C
0005433516730	21986	26	14F
0005432925009	21986	27	15D
0005432925005	21986	28	15E
0005435517685	21986	29	16F
0005435517622	21986	30	17A
0005435517666	21986	31	17D
0005435517598	21986	32	17F
0005432925008	21986	33	18A
0005433516751	21986	34	19A
0005435517630	21986	35	20F
0005435252489	7385	1	1A
0005434458683	7385	2	1D
0005432838849	7385	3	1F
0005432838852	7385	4	2A
0005432838845	7385	5	2D
0005432838853	7385	6	2F
0005432840998	7385	7	3A
0005432838843	7385	8	3C
0005435252425	7385	9	4A
0005434458687	7385	10	4D
0005432838841	7385	11	4E
0005435252479	7385	12	5A
0005432838833	7385	13	5C
0005434458686	7385	14	5D
0005435252490	7385	15	5E
0005432838842	7385	16	5F
0005434458688	7385	17	6A
0005435491408	7385	18	6C
0005434458678	7385	19	6D
0005434458667	7385	20	6F
0005434664929	7385	21	7C
0005434458669	7385	22	7D
0005435252480	7385	23	7E
0005434458670	7385	24	8A
0005432823436	7385	25	8D
0005432838848	7385	26	8E
0005434458668	7385	27	9C
0005432823435	7385	28	9D
0005432838859	7385	29	9E
0005435252488	7385	30	9F
0005434458685	7385	31	10A
0005434458681	7385	32	10C
0005432838838	7385	33	10D
0005435252437	7385	34	10E
0005434458679	7385	35	10F
0005434664926	7385	36	11A
0005432838839	7385	37	11C
0005432838858	7385	38	11D
0005432838840	7385	39	11E
0005434458673	7385	40	12A
0005432838846	7385	41	12E
0005434458689	7385	42	12F
0005434458676	7385	43	13C
0005434458675	7385	44	13D
0005434458671	7385	45	13F
0005432838857	7385	46	14A
0005435491411	7385	47	14C
0005434458680	7385	48	14D
0005434664928	7385	49	14E
0005432838836	7385	50	15A
0005432838844	7385	51	15C
0005434664927	7385	52	15D
0005432838834	7385	53	15E
0005432838861	7385	54	15F
0005432838854	7385	55	16A
0005432838855	7385	56	16C
0005432838847	7385	57	16D
0005432838831	7385	58	16E
0005434458682	7385	59	16F
0005432838837	7385	60	17A
0005432838832	7385	61	17C
0005432838835	7385	62	17D
0005432838851	7385	63	17E
0005432838856	7385	64	17F
0005435252401	7385	65	18A
0005434458674	7385	66	18D
0005432838850	7385	67	18F
0005435491412	7385	68	19C
0005432840997	7385	69	19D
0005434458677	7385	70	20A
0005434458684	7385	71	20C
0005434458672	7385	72	20D
0005432838860	7385	73	20F
0005435252600	28923	1	1A
0005432838608	28923	2	1C
0005435252587	28923	3	1F
0005434458482	28923	4	2A
0005432838750	28923	5	2C
0005434458458	28923	6	2D
0005434458472	28923	7	3A
0005432838719	28923	8	2F
0005434458486	28923	9	3C
0005434458460	28923	10	3D
0005432838679	28923	11	3F
0005435252589	28923	12	4A
0005435491430	28923	13	4C
0005434458591	28923	14	4D
0005435252590	28923	15	4E
0005432838749	28923	16	4F
0005432838640	28923	17	5A
0005434458447	28923	18	5C
0005434458485	28923	19	5D
0005434458454	28923	20	5E
0005434458590	28923	21	5F
0005432838551	28923	22	6A
0005434458488	28923	23	6C
0005432838720	28923	24	6D
0005432838680	28923	25	6E
0005432840979	28923	26	6F
0005434458533	28923	27	7A
0005435252592	28923	28	7C
0005432838737	28923	29	7D
0005432838631	28923	30	7E
0005435252588	28923	31	7F
0005432838740	28923	32	8A
0005435252584	28923	33	8C
0005432838514	28923	34	8D
0005432838594	28923	35	8E
0005435252593	28923	36	8F
0005432001011	28923	37	9A
0005434458547	28923	38	9C
0005432823419	28923	39	9D
0005432838638	28923	40	9E
0005435252594	28923	41	9F
0005434458564	28923	42	10A
0005434458446	28923	43	10C
0005432823421	28923	44	10D
0005432838630	28923	45	10E
0005434458483	28923	46	11A
0005432840987	28923	47	11C
0005432838603	28923	48	11D
0005432838553	28923	49	11E
0005435252585	28923	50	11F
0005434458484	28923	51	12A
0005432838515	28923	52	12D
0005432838557	28923	53	12E
0005434458504	28923	54	12F
0005434458497	28923	55	13A
0005434458563	28923	56	13C
0005434458477	28923	57	13D
0005434458498	28923	58	13E
0005432838601	28923	59	13F
0005432823426	28923	60	14A
0005434664947	28923	61	14C
0005434458502	28923	62	14D
0005432838626	28923	63	14E
0005432838639	28923	64	15A
0005435252595	28923	65	14F
0005434458541	28923	66	15C
0005432838663	28923	67	15D
0005432823420	28923	68	15E
0005434458521	28923	69	15F
0005432838683	28923	70	16A
0005435252599	28923	71	16C
0005432840988	28923	72	16D
0005432838629	28923	73	16E
0005434458459	28923	74	16F
0005434458503	28923	75	17A
0005435252586	28923	76	17C
0005434664948	28923	77	17D
0005434458546	28923	78	17E
0005432838602	28923	79	17F
0005435252601	28923	80	18A
0005432838552	28923	81	18C
0005434458473	28923	82	18D
0005435252591	28923	83	18E
0005434664946	28923	84	19A
0005432001010	28923	85	19C
0005435252596	28923	86	19D
0005434458539	28923	87	19E
0005435252598	28923	88	19F
0005435252597	28923	89	20A
0005432838662	28923	90	20C
0005432823417	28923	91	20D
0005434458501	28923	92	20E
0005434458542	28923	93	20F
0005435990578	8813	1	2D
0005435990581	8813	2	4D
0005435990583	8813	3	7D
0005435990584	8813	4	10D
0005435990585	8813	5	12C
0005435990579	8813	6	13B
0005434275956	8813	7	14D
0005435990580	8813	8	17A
0005435990582	8813	9	20F
0005434275994	15758	1	3F
0005434275993	15758	2	4C
0005434275992	15758	3	7A
0005434275990	15758	4	8C
0005435990537	15758	5	11A
0005435990518	15758	6	15C
0005435990517	15758	7	18E
0005434275991	15758	8	19F
0005435990538	15758	9	19E
0005435990536	15758	10	20D
0005433476878	30841	1	1B
0005432427118	30841	2	2C
0005433476880	30841	3	7A
0005433476879	30841	4	7B
0005433476874	30841	5	18D
0005433476875	30841	6	20D
0005433476876	30841	7	21A
0005433476877	30841	8	21C
0005433468194	23846	1	1A
0005432909252	23846	2	1C
0005432909247	23846	3	1D
0005432909248	23846	4	2B
0005433468200	23846	5	3C
0005433468220	23846	6	4B
0005432909244	23846	7	4C
0005433468198	23846	8	5A
0005433468219	23846	9	5B
0005432909253	23846	10	5D
0005433468193	23846	11	6B
0005432909245	23846	12	6C
0005433468199	23846	13	6D
0005432909251	23846	14	7B
0005433468205	23846	15	18A
0005432909249	23846	16	18B
0005432909250	23846	17	20A
0005432909254	23846	18	20D
0005433468218	23846	19	21A
0005433468195	23846	20	21D
0005432909246	23846	21	22A
0005433468233	23846	22	22B
0005433468185	23846	23	22C
0005433468192	23846	24	23B
0005434149563	6371	1	1C
0005435176591	6371	2	1A
0005432062198	6371	3	1F
0005432360096	6371	4	1D
0005435176757	6371	5	2A
0005432360066	6371	6	2C
0005432360073	6371	7	2D
0005435176648	6371	8	2F
0005432360090	6371	9	3C
0005434149547	6371	10	3A
0005435176592	6371	11	3D
0005432360052	6371	12	3F
0005435723014	6371	13	4B
0005434149564	6371	14	4A
0005432360084	6371	15	4C
0005432360064	6371	16	4D
0005434149607	6371	17	5A
0005432335960	6371	18	4F
0005432363397	6371	19	5B
0005432360088	6371	20	5D
0005432360054	6371	21	5E
0005432360049	6371	22	6A
0005432360048	6371	23	5F
0005435176686	6371	24	6B
0005434149582	6371	25	6D
0005432360095	6371	26	6F
0005432335955	6371	27	6E
0005435176696	6371	28	7B
0005432335957	6371	29	7A
0005432335964	6371	30	7D
0005432360092	6371	31	7C
0005435176764	6371	32	7F
0005432363395	6371	33	7E
0005434149583	6371	34	8A
0005432335965	6371	35	8B
0005432360062	6371	36	8C
0005432335958	6371	37	8D
0005435176710	6371	38	8F
0005432360063	6371	39	8E
0005432335963	6371	40	9A
0005435176806	6371	41	9B
0005432360086	6371	42	9C
0005432062197	6371	43	9E
0005432335956	6371	44	9F
0005434149549	6371	45	10B
0005435176612	6371	46	10D
0005434149548	6371	47	10C
0005432335966	6371	48	10E
0005432062196	6371	49	11A
0005434149550	6371	50	11B
0005435176735	6371	51	11C
0005435176756	6371	52	11E
0005434149576	6371	53	11D
0005435176729	6371	54	11F
0005432062195	6371	55	12A
0005435176780	6371	56	12B
0005435176715	6371	57	12D
0005435176719	6371	58	12C
0005432360089	6371	59	12E
0005432360076	6371	60	13A
0005432360078	6371	61	12F
0005432360074	6371	62	13B
0005432363396	6371	63	13C
0005432360056	6371	64	13D
0005435176611	6371	65	13E
0005435176734	6371	66	13F
0005432360067	6371	67	14A
0005432360065	6371	68	14C
0005435176718	6371	69	14D
0005432360094	6371	70	14F
0005435176728	6371	71	14E
0005432335959	6371	72	15A
0005435176755	6371	73	15B
0005435176687	6371	74	15C
0005432360081	6371	75	15E
0005432360075	6371	76	15F
0005432360055	6371	77	16A
0005435176742	6371	78	16C
0005434149565	6371	79	16B
0005435176765	6371	80	16D
0005435176753	6371	81	16F
0005435176754	6371	82	17B
0005432360058	6371	83	17C
0005435176748	6371	84	17D
0005432360070	6371	85	17F
0005432360050	6371	86	18A
0005432360077	6371	87	18B
0005432360072	6371	88	18D
0005435176733	6371	89	18C
0005432360053	6371	90	18F
0005432360061	6371	91	18E
0005435176805	6371	92	19A
0005432360060	6371	93	19B
0005432360093	6371	94	19C
0005432360082	6371	95	19E
0005432360057	6371	96	19D
0005432360068	6371	97	19F
0005435723016	6371	98	20A
0005432360085	6371	99	20B
0005434149558	6371	100	20D
0005435176647	6371	101	20C
0005432360087	6371	102	20E
0005432360080	6371	103	20F
0005432335961	6371	104	21A
0005432360069	6371	105	21C
0005435490176	6371	106	21B
0005432360047	6371	107	21D
0005435176597	6371	108	22A
0005435176747	6371	109	21F
0005432360059	6371	110	22C
0005434149581	6371	111	22B
0005434149577	6371	112	22D
0005432360071	6371	113	22E
0005432360083	6371	114	23A
0005432360051	6371	115	22F
0005432335962	6371	116	23C
0005432360091	6371	117	23E
0005435176779	6371	118	23D
0005432360079	6371	119	23F
0005432335868	20995	1	1A
0005435176910	20995	2	1C
0005435176919	20995	3	1D
0005432359770	20995	4	1F
0005432359628	20995	5	2C
0005432359613	20995	6	2A
0005432335847	20995	7	2D
0005432359744	20995	8	2F
0005435176899	20995	9	3A
0005434149660	20995	10	3D
0005432359805	20995	11	3C
0005432052729	20995	12	3F
0005432359532	20995	13	4B
0005435490210	20995	14	4C
0005432359717	20995	15	4D
0005435176901	20995	16	4E
0005434149665	20995	17	5A
0005435176920	20995	18	4F
0005435176913	20995	19	5B
0005434149662	20995	20	5D
0005435490208	20995	21	5E
0005432359574	20995	22	6A
0005432359781	20995	23	6B
0005432359636	20995	24	6C
0005434149663	20995	25	6E
0005434149653	20995	26	6D
0005435176912	20995	27	6F
0005432359528	20995	28	7A
0005432359596	20995	29	7B
0005432359554	20995	30	7D
0005435176916	20995	31	7F
0005432359705	20995	32	7E
0005432335836	20995	33	8A
0005432335874	20995	34	8B
0005435176906	20995	35	8D
0005432359773	20995	36	8C
0005435176905	20995	37	8F
0005435176917	20995	38	8E
0005432359627	20995	39	9A
0005435176921	20995	40	9B
0005432359637	20995	41	9D
0005432335881	20995	42	9C
0005432359555	20995	43	9F
0005432335822	20995	44	9E
0005432359533	20995	45	10B
0005434149655	20995	46	10E
0005432335918	20995	47	10D
0005432359622	20995	48	11A
0005432335824	20995	49	11B
0005435176902	20995	50	11C
0005435176897	20995	51	11E
0005434149664	20995	52	11D
0005432052726	20995	53	11F
0005432359525	20995	54	12A
0005434149659	20995	55	12C
0005432335835	20995	56	12E
0005434149652	20995	57	12D
0005432359764	20995	58	12F
0005435176914	20995	59	13A
0005435176915	20995	60	13C
0005435176909	20995	61	13B
0005432363377	20995	62	13E
0005432335867	20995	63	13D
0005432359569	20995	64	13F
0005435176911	20995	65	14B
0005432359595	20995	66	14A
0005432359741	20995	67	14C
0005432359678	20995	68	14D
0005432359765	20995	69	14E
0005432359821	20995	70	15A
0005432359706	20995	71	14F
0005432359559	20995	72	15C
0005432359566	20995	73	15B
0005432359568	20995	74	15D
0005432335894	20995	75	15F
0005432359587	20995	76	16B
0005432359749	20995	77	16A
0005435176898	20995	78	16C
0005434149656	20995	79	16E
0005432359743	20995	80	16D
0005432335848	20995	81	16F
0005432359647	20995	82	17B
0005435723034	20995	83	17A
0005435176895	20995	84	17C
0005435176896	20995	85	17F
0005434149661	20995	86	17E
0005432359679	20995	87	18A
0005432359646	20995	88	18B
0005432359614	20995	89	18C
0005432359623	20995	90	18D
0005432359526	20995	91	18F
0005432359693	20995	92	18E
0005435176908	20995	93	19A
0005434149658	20995	94	19B
0005432359772	20995	95	19C
0005435176903	20995	96	19E
0005435176918	20995	97	19D
0005432052727	20995	98	19F
0005432335917	20995	99	20A
0005432359680	20995	100	20C
0005432335834	20995	101	20B
0005432335841	20995	102	20D
0005432359774	20995	103	20F
0005432359777	20995	104	21A
0005432359863	20995	105	21C
0005432359829	20995	106	21B
0005435176900	20995	107	21D
0005434149654	20995	108	21E
0005435176907	20995	109	21F
0005432052728	20995	110	22B
0005435176922	20995	111	22C
0005432359701	20995	112	22D
0005432335893	20995	113	22E
0005435490209	20995	114	23A
0005432359617	20995	115	22F
0005435176904	20995	116	23B
0005432359750	20995	117	23C
0005432359763	20995	118	23E
0005435723033	20995	119	23D
0005434149657	20995	120	23F
0005434458536	17722	1	1A
0005434458444	17722	2	1D
0005434458540	17722	3	2A
0005434463900	17722	4	2B
0005434463898	17722	5	2C
0005434458495	17722	6	3A
0005434461612	17722	7	3B
0005434461620	17722	8	3D
0005434458592	17722	9	4A
0005434186182	17722	10	4B
0005434458496	17722	11	5A
0005434458443	17722	12	5B
0005434463897	17722	13	5C
0005434458566	17722	14	5D
0005434448254	17722	15	6A
0005434458445	17722	16	6B
0005434458522	17722	17	6C
0005434458537	17722	18	7A
0005434458538	17722	19	7B
0005434458500	17722	20	7C
0005434448256	17722	21	7D
0005434186181	17722	22	18B
0005434458530	17722	23	18C
0005434461619	17722	24	18D
0005434458549	17722	25	19A
0005434458469	17722	26	19B
0005434458442	17722	27	19D
0005434458494	17722	28	20A
0005434448255	17722	29	20B
0005434461618	17722	30	20C
0005434186180	17722	31	20D
0005434458565	17722	32	21A
0005434463896	17722	33	21D
0005434458529	17722	34	22A
0005434461613	17722	35	22C
0005434448265	17722	36	23A
0005434458684	29124	1	1C
0005434458686	29124	2	1D
0005434458682	29124	3	2A
0005434458688	29124	4	2B
0005434186147	29124	5	2D
0005434458689	29124	6	2C
0005434448290	29124	7	3B
0005434458677	29124	8	3C
0005434458687	29124	9	3D
0005434458680	29124	10	4A
0005434458669	29124	11	4B
0005434462775	29124	12	4C
0005434458685	29124	13	4D
0005434462774	29124	14	5A
0005434458681	29124	15	6B
0005434448291	29124	16	6C
0005434458674	29124	17	7A
0005434458678	29124	18	7B
0005434186153	29124	19	7C
0005434458675	29124	20	7D
0005434458672	29124	21	18B
0005434458671	29124	22	18C
0005434458673	29124	23	19A
0005434458676	29124	24	19B
0005434458667	29124	25	19C
0005434458683	29124	26	19D
0005434458679	29124	27	20B
0005434448292	29124	28	20D
0005434463914	29124	29	21A
0005434186161	29124	30	21B
0005434186162	29124	31	21C
0005434458670	29124	32	21D
0005434458668	29124	33	22D
0005432604052	21444	1	1A
0005432604055	21444	2	1B
0005432604047	21444	3	1D
0005432604079	21444	4	2B
0005432604049	21444	5	2A
0005432604072	21444	6	2C
0005432604051	21444	7	3A
0005432604087	21444	8	3B
0005435218099	21444	9	3C
0005432604067	21444	10	3D
0005432604078	21444	11	4A
0005432604075	21444	12	4B
0005432604076	21444	13	4C
0005432604057	21444	14	4D
0005432604086	21444	15	5A
0005432604059	21444	16	5B
0005432604060	21444	17	5C
0005432604065	21444	18	6A
0005432604085	21444	19	6B
0005432604084	21444	20	6C
0005432604063	21444	21	6D
0005432604071	21444	22	7A
0005432604083	21444	23	7B
0005432604061	21444	24	7D
0005432604058	21444	25	18A
0005432604082	21444	26	18B
0005432604074	21444	27	18C
0005432604054	21444	28	18D
0005432604068	21444	29	19B
0005432604069	21444	30	19C
0005432604070	21444	31	20A
0005432604081	21444	32	20B
0005432604050	21444	33	20D
0005432604056	21444	34	21B
0005432604048	21444	35	21A
0005432604080	21444	36	21C
0005432604073	21444	37	21D
0005432604053	21444	38	22A
0005432604064	21444	39	22C
0005432604062	21444	40	22D
0005432604077	21444	41	23A
0005432604066	21444	42	23B
0005432603656	31683	1	1A
0005432603765	31683	2	1C
0005432603766	31683	3	1D
0005432603706	31683	4	2A
0005432603711	31683	5	2B
0005432603794	31683	6	2C
0005432603913	31683	7	3A
0005432603710	31683	8	3B
0005432603776	31683	9	3C
0005432604015	31683	10	3D
0005432603681	31683	11	4B
0005432603926	31683	12	4C
0005432603808	31683	13	4D
0005432603708	31683	14	5A
0005432603803	31683	15	5B
0005432603687	31683	16	5C
0005432603915	31683	17	5D
0005432603914	31683	18	6A
0005432603916	31683	19	6C
0005432603709	31683	20	6D
0005432603829	31683	21	7A
0005432603756	31683	22	7B
0005432603697	31683	23	7D
0005432603743	31683	24	18B
0005432603762	31683	25	18D
0005432603755	31683	26	19C
0005432603727	31683	27	19D
0005432603720	31683	28	20D
0005432603723	31683	29	21A
0005432603764	31683	30	21B
0005432603688	31683	31	21D
0005432603707	31683	32	22B
0005432603821	31683	33	22C
0005432603777	31683	34	23A
0005432604014	31683	35	23B
0005433293223	29598	1	1D
0005433293213	29598	2	2A
0005433293219	29598	3	5C
0005433293218	29598	4	7A
0005433293222	29598	5	7D
0005433293215	29598	6	19B
0005433293216	29598	7	19C
0005433293220	29598	8	20A
0005433293221	29598	9	20B
0005433293217	29598	10	21C
0005433293210	29598	11	21D
0005433293211	29598	12	22B
0005433293212	29598	13	22C
0005433293214	29598	14	23A
0005433473203	6681	1	1A
0005433473209	6681	2	1C
0005435257156	6681	3	1D
0005433473210	6681	4	2C
0005433473207	6681	5	3B
0005433473196	6681	6	3C
0005433473211	6681	7	3D
0005435257155	6681	8	4B
0005435257143	6681	9	4C
0005435257165	6681	10	4D
0005435257146	6681	11	5B
0005435257144	6681	12	5C
0005433473206	6681	13	6A
0005435257164	6681	14	6B
0005435257148	6681	15	7B
0005435257147	6681	16	7C
0005433473194	6681	17	18A
0005433473201	6681	18	18B
0005435257154	6681	19	19A
0005433473198	6681	20	19B
0005433473197	6681	21	19C
0005433473199	6681	22	19D
0005433473212	6681	23	20A
0005433473200	6681	24	20C
0005433473202	6681	25	20D
0005433473204	6681	26	21A
0005433473205	6681	27	21D
0005433473208	6681	28	22A
0005435257153	6681	29	22B
0005433473195	6681	30	22D
0005433473144	23885	1	1A
0005435257206	23885	2	1B
0005433473141	23885	3	1C
0005433473100	23885	4	1D
0005433473116	23885	5	2A
0005433473142	23885	6	2D
0005435257201	23885	7	3A
0005435257207	23885	8	3B
0005433473132	23885	9	3C
0005435257200	23885	10	3D
0005433473104	23885	11	4D
0005433473135	23885	12	5A
0005433473117	23885	13	6A
0005433473131	23885	14	6B
0005435257208	23885	15	6C
0005433473111	23885	16	6D
0005435257205	23885	17	7D
0005433473129	23885	18	18C
0005435257199	23885	19	18D
0005433473109	23885	20	19B
0005435257202	23885	21	19C
0005435257204	23885	22	19D
0005433473174	23885	23	20C
0005433473103	23885	24	21B
0005433473106	23885	25	21C
0005433473110	23885	26	21D
0005435257203	23885	27	22A
0005433473143	23885	28	22B
0005434606771	18931	1	4A
0005434606770	18931	2	4B
0005434606773	18931	3	6A
0005434606803	22362	1	1A
0005434604871	22362	2	2A
0005434606805	22362	3	3A
0005434606802	22362	4	2B
0005434604873	22362	5	3B
0005434604874	22362	6	4A
0005434606804	22362	7	5A
0005434604872	22362	8	4B
0005434602884	3843	1	1C
0005434522419	3843	2	2A
0005435904369	3843	3	2B
0005435904366	3843	4	3A
0005434602885	3843	5	3B
0005434602881	3843	6	3C
0005434602880	3843	7	5B
0005434522421	3843	8	6D
0005435904368	3843	9	7B
0005434522420	3843	10	7D
0005435904376	3843	11	18A
0005434522417	3843	12	18C
0005434602882	3843	13	18D
0005434522418	3843	14	19A
0005434522423	3843	15	20D
0005434602883	3843	16	21A
0005435904377	3843	17	21B
0005434522422	3843	18	21C
0005435904375	3843	19	21D
0005435904370	3843	20	22A
0005434604841	19058	1	1C
0005435904394	19058	2	2A
0005434602874	19058	3	3A
0005434522398	19058	4	3B
0005434602860	19058	5	4A
0005434604853	19058	6	5A
0005435904391	19058	7	7A
0005435904393	19058	8	7B
0005434522397	19058	9	7D
0005434522377	19058	10	18A
0005434602873	19058	11	19C
0005435904392	19058	12	20C
0005434522381	19058	13	22A
0005434604842	19058	14	22B
0005434522395	19058	15	22D
0005432747315	425	1	1A
0005432747314	425	2	1C
0005432747304	425	3	1D
0005432747327	425	4	2C
0005432890673	425	5	2D
0005433293147	425	6	2F
0005432747336	425	7	3A
0005432747298	425	8	3C
0005432753277	425	9	3D
0005432747307	425	10	4A
0005432747323	425	11	4D
0005432219977	425	12	4E
0005432747321	425	13	4F
0005432751503	425	14	5A
0005432747324	425	15	5C
0005432747301	425	16	5D
0005432747333	425	17	5E
0005432747332	425	18	5F
0005432219976	425	19	6C
0005432753276	425	20	6E
0005432747308	425	21	6F
0005432747316	425	22	7A
0005433293174	425	23	7C
0005432747319	425	24	7D
0005432219975	425	25	7E
0005432751504	425	26	7F
0005432747309	425	27	8A
0005432747331	425	28	8C
0005432890676	425	29	8D
0005432890705	425	30	8E
0005432753278	425	31	9A
0005433293152	425	32	9C
0005432747320	425	33	9E
0005432890694	425	34	10C
0005432747329	425	35	10D
0005432747303	425	36	10F
0005432747328	425	37	11A
0005433293173	425	38	11C
0005432747313	425	39	11E
0005432747311	425	40	11F
0005432747326	425	41	12C
0005432890678	425	42	12A
0005432747312	425	43	12D
0005432219974	425	44	12E
0005435154593	425	45	12F
0005433293146	425	46	13C
0005432747299	425	47	13D
0005433293142	425	48	13E
0005432747330	425	49	13F
0005435154592	425	50	14A
0005432751502	425	51	14D
0005432747334	425	52	14F
0005432890706	425	53	15C
0005432747317	425	54	15D
0005432749770	425	55	15F
0005433293153	425	56	16A
0005432747318	425	57	16D
0005432747302	425	58	16F
0005432890677	425	59	17E
0005432747306	425	60	17F
0005433293159	425	61	18A
0005432747325	425	62	18C
0005432749769	425	63	18E
0005432747300	425	64	19A
0005432747335	425	65	19D
0005432747322	425	66	19F
0005432747305	425	67	20A
0005432747310	425	68	20C
0005432890762	425	69	20F
0005432747025	12091	1	1A
0005432890903	12091	2	1C
0005432890895	12091	3	2A
0005432747096	12091	4	2D
0005432890906	12091	5	2F
0005432747013	12091	6	3A
0005432890907	12091	7	3F
0005432749752	12091	8	4E
0005432746965	12091	9	4F
0005432890890	12091	10	5A
0005432890908	12091	11	5C
0005432890896	12091	12	5F
0005432214790	12091	13	6C
0005432746982	12091	14	6D
0005432746975	12091	15	7A
0005432747080	12091	16	7D
0005432747024	12091	17	7E
0005432747042	12091	18	7F
0005432746889	12091	19	8D
0005432890892	12091	20	8E
0005432746952	12091	21	9A
0005432890897	12091	22	9C
0005432749758	12091	23	9E
0005432746865	12091	24	9F
0005432890898	12091	25	10C
0005432890902	12091	26	10D
0005432890901	12091	27	10F
0005433875369	12091	28	11A
0005432890905	12091	29	11C
0005432890900	12091	30	11D
0005432747302	12091	31	11F
0005432890891	12091	32	12D
0005432756792	12091	33	12E
0005432747099	12091	34	12F
0005432747095	12091	35	13A
0005432747081	12091	36	13C
0005433875368	12091	37	14C
0005432747114	12091	38	14D
0005432747028	12091	39	16A
0005432747005	12091	40	16D
0005432747014	12091	41	16E
0005432890904	12091	42	16F
0005432746909	12091	43	17C
0005432214789	12091	44	17F
0005432890894	12091	45	18A
0005432747066	12091	46	18C
0005432746885	12091	47	18E
0005432890893	12091	48	19A
0005432747098	12091	49	19F
0005432746964	12091	50	20A
0005432890899	12091	51	20C
0005432890909	12091	52	20E
0005433531267	18991	1	2A
0005433524966	18991	2	2D
0005432927902	18991	3	3A
0005433524964	18991	4	4A
0005433524959	18991	5	5B
0005433533282	18991	6	5C
0005433531266	18991	7	6A
0005433524963	18991	8	6D
0005432927886	18991	9	7A
0005432927889	18991	10	7C
0005433533281	18991	11	18A
0005433524962	18991	12	18B
0005433524958	18991	13	18C
0005433533279	18991	14	19C
0005433533280	18991	15	20A
0005433524960	18991	16	20C
0005433524965	18991	17	21A
0005432927901	18991	18	21B
0005433531265	18991	19	21D
0005433524967	18991	20	22A
0005433524961	18991	21	22B
0005433531268	18991	22	22C
0005433524957	18991	23	23A
0005433531241	32478	1	1D
0005433524876	32478	2	2C
0005433527203	32478	3	3A
0005433531242	32478	4	3B
0005433524848	32478	5	3D
0005433524847	32478	6	4C
0005433531225	32478	7	4D
0005432927953	32478	8	5B
0005432927950	32478	9	5C
0005433524851	32478	10	5D
0005433531226	32478	11	6A
0005433524917	32478	12	7D
0005433524903	32478	13	18B
0005433531239	32478	14	18C
0005432927951	32478	15	18D
0005433524866	32478	16	19A
0005433524918	32478	17	19B
0005432927949	32478	18	19C
0005433531234	32478	19	20A
0005433524891	32478	20	20C
0005432927952	32478	21	20D
0005433524877	32478	22	21B
0005433524890	32478	23	23B
0005435372220	5242	1	1C
0005435372505	5242	2	1A
0005434822860	5242	3	1G
0005434822753	5242	4	1D
0005435372409	5242	5	1K
0005432121252	5242	6	2C
0005434822758	5242	7	2G
0005434822769	5242	8	2D
0005435149940	5242	9	3A
0005432121246	5242	10	2K
0005435372412	5242	11	3G
0005434822820	5242	12	3D
0005434822798	5242	13	3C
0005435372472	5242	14	4C
0005435372464	5242	15	4A
0005434822767	5242	16	5D
0005435372471	5242	17	5A
0005434822756	5242	18	5G
0005435304108	5242	19	11A
0005434822791	5242	20	5K
0005434822742	5242	21	11C
0005434822845	5242	22	11F
0005434822823	5242	23	11E
0005434822755	5242	24	11H
0005435149937	5242	25	12A
0005434822789	5242	26	11K
0005435372254	5242	27	12E
0005434822787	5242	28	12D
0005435372599	5242	29	12G
0005435149944	5242	30	12F
0005434822843	5242	31	12K
0005434822834	5242	32	12H
0005434822803	5242	33	13C
0005434822831	5242	34	13A
0005435372433	5242	35	13G
0005435149948	5242	36	13F
0005435386482	5242	37	13K
0005434822846	5242	38	14K
0005435372301	5242	39	14H
0005434822747	5242	40	14G
0005435372213	5242	41	15C
0005434822856	5242	42	15G
0005435372482	5242	43	15F
0005435149946	5242	44	15K
0005434822779	5242	45	16D
0005432121250	5242	46	16C
0005435372376	5242	47	16F
0005434828676	5242	48	16E
0005434822822	5242	49	16H
0005434822836	5242	50	17A
0005435386463	5242	51	16K
0005434822746	5242	52	17E
0005432394078	5242	53	17D
0005434828677	5242	54	17G
0005435372413	5242	55	17K
0005434822867	5242	56	17H
0005435372479	5242	57	18C
0005435386479	5242	58	18B
0005434822830	5242	59	18A
0005435372432	5242	60	18E
0005434822776	5242	61	18D
0005435299696	5242	62	18H
0005434822740	5242	63	18G
0005434822751	5242	64	18F
0005435372132	5242	65	18K
0005434822752	5242	66	19D
0005435372252	5242	67	19C
0005434822761	5242	68	19G
0005434822768	5242	69	19F
0005434822771	5242	70	19J
0005432121243	5242	71	19H
0005434822804	5242	72	19K
0005434822833	5242	73	20C
0005435661881	5242	74	20B
0005435372377	5242	75	20E
0005434822763	5242	76	20D
0005435386454	5242	77	20F
0005435372316	5242	78	20J
0005435372317	5242	79	21A
0005435386466	5242	80	20K
0005434822777	5242	81	21C
0005434664945	5242	82	21B
0005434558225	5242	83	21F
0005434822857	5242	84	21E
0005434822812	5242	85	21G
0005434822759	5242	86	22A
0005434822807	5242	87	21K
0005434822858	5242	88	21J
0005434558219	5242	89	22C
0005435372122	5242	90	22B
0005435372683	5242	91	22D
0005435372331	5242	92	22G
0005434822741	5242	93	22K
0005435372244	5242	94	22J
0005434822814	5242	95	22H
0005434558222	5242	96	23D
0005432823416	5242	97	23C
0005434822854	5242	98	23F
0005432121247	5242	99	23J
0005435386483	5242	100	24G
0005434822816	5242	101	24F
0005434822743	5242	102	24E
0005435372480	5242	103	24D
0005434822813	5242	104	25A
0005434822835	5242	105	25D
0005432396217	5242	106	25C
0005432396219	5242	107	25H
0005434831116	5242	108	25G
0005434822795	5242	109	25K
0005435372100	5242	110	25J
0005435372131	5242	111	26C
0005434822852	5242	112	26A
0005435149947	5242	113	26E
0005434822848	5242	114	26D
0005434822828	5242	115	26G
0005434822773	5242	116	26F
0005434822757	5242	117	27B
0005434664944	5242	118	27D
0005435372399	5242	119	27C
0005434828678	5242	120	27E
0005434558226	5242	121	27H
0005432121251	5242	122	27G
0005434822806	5242	123	27J
0005434822838	5242	124	28B
0005434822784	5242	125	28E
0005432394079	5242	126	28D
0005434831119	5242	127	28G
0005434822774	5242	128	28F
0005434822786	5242	129	28J
0005434822801	5242	130	28H
0005435372400	5242	131	29A
0005435661879	5242	132	29F
0005434822815	5242	133	29E
0005432121241	5242	134	29J
0005434822862	5242	135	29H
0005434822825	5242	136	29G
0005434822824	5242	137	29K
0005434822762	5242	138	30C
0005434558223	5242	139	30E
0005434822826	5242	140	30D
0005435372265	5242	141	30G
0005434822829	5242	142	30F
0005432121244	5242	143	30J
0005434822866	5242	144	30H
0005434822775	5242	145	31B
0005434822859	5242	146	31A
0005435372348	5242	147	31D
0005435372368	5242	148	31C
0005434822797	5242	149	31F
0005432396216	5242	150	31E
0005434822766	5242	151	31H
0005435149942	5242	152	31K
0005434664943	5242	153	31J
0005435372245	5242	154	32C
0005435372186	5242	155	32B
0005434822864	5242	156	32D
0005435372107	5242	157	32G
0005432396218	5242	158	32F
0005434822819	5242	159	32H
0005435372378	5242	160	33B
0005435372397	5242	161	33A
0005435372176	5242	162	33F
0005434822855	5242	163	34B
0005434822827	5242	164	34A
0005435386480	5242	165	34E
0005435149941	5242	166	34D
0005434822837	5242	167	34G
0005434822792	5242	168	34F
0005434822760	5242	169	34J
0005434822749	5242	170	34H
0005435372224	5242	171	34K
0005434831118	5242	172	35B
0005435149949	5242	173	35F
0005434822799	5242	174	35J
0005435372287	5242	175	35H
0005435372221	5242	176	35G
0005435372113	5242	177	36A
0005434822849	5242	178	35K
0005434558221	5242	179	36C
0005434822847	5242	180	36B
0005432121242	5242	181	36E
0005434822790	5242	182	36H
0005434822782	5242	183	36F
0005434822793	5242	184	36K
0005435386467	5242	185	36J
0005435299703	5242	186	37D
0005434822841	5242	187	37E
0005434822811	5242	188	37J
0005435372506	5242	189	37G
0005434822817	5242	190	37K
0005434822783	5242	191	38C
0005435372414	5242	192	38A
0005435372226	5242	193	38K
0005435372098	5242	194	38H
0005434822810	5242	195	39B
0005434822765	5242	196	39C
0005434822832	5242	197	39F
0005434822745	5242	198	39G
0005435372545	5242	199	40C
0005434822805	5242	200	40B
0005434822780	5242	201	40A
0005434822778	5242	202	40G
0005434822770	5242	203	40J
0005435372270	5242	204	41B
0005434822750	5242	205	41A
0005434831117	5242	206	41D
0005434822839	5242	207	41F
0005434822840	5242	208	41H
0005435149943	5242	209	41G
0005435372166	5242	210	42A
0005435149938	5242	211	41J
0005432121248	5242	212	42C
0005434822772	5242	213	42B
0005434822748	5242	214	42E
0005434822850	5242	215	42D
0005435372481	5242	216	42G
0005434822844	5242	217	42F
0005434822788	5242	218	42H
0005434822796	5242	219	42K
0005434822861	5242	220	43C
0005434822809	5242	221	43B
0005434822863	5242	222	43F
0005435372349	5242	223	43H
0005435372521	5242	224	44A
0005432121245	5242	225	43K
0005435372520	5242	226	43J
0005434822754	5242	227	44G
0005434822800	5242	228	44F
0005434822868	5242	229	44K
0005434822865	5242	230	44J
0005432121253	5242	231	45E
0005434822808	5242	232	45D
0005434822744	5242	233	45H
0005434822739	5242	234	45K
0005434822785	5242	235	46B
0005435372332	5242	236	46A
0005435372600	5242	237	46D
0005435372470	5242	238	46H
0005432394077	5242	239	46G
0005434831115	5242	240	46F
0005435149939	5242	241	46E
0005432394080	5242	242	46K
0005434822764	5242	243	47C
0005435372106	5242	244	47E
0005432121254	5242	245	47G
0005434822853	5242	246	47F
0005435178978	5242	247	47K
0005434822794	5242	248	47H
0005435735060	5242	249	48D
0005434822842	5242	250	48A
0005434822851	5242	251	48F
0005435372282	5242	252	48E
0005435149945	5242	253	48H
0005434831120	5242	254	48G
0005432121255	5242	255	48K
0005435372177	5242	256	49F
0005434558220	5242	257	49E
0005432121249	5242	258	50A
0005435372291	5242	259	50E
0005435372375	5242	260	50D
0005434822818	5242	261	50G
0005434822781	5242	262	50F
0005435372443	5242	263	50K
0005434822802	5242	264	50H
0005434558224	5242	265	51F
0005434822821	5242	266	51D
0005435149805	9931	1	1D
0005432203021	9931	2	1C
0005435149849	9931	3	1A
0005434821691	9931	4	1H
0005432203019	9931	5	1G
0005434831066	9931	6	1K
0005434821820	9931	7	2D
0005434822157	9931	8	2C
0005434822025	9931	9	2G
0005435299747	9931	10	3C
0005432203015	9931	11	4D
0005434822002	9931	12	4K
0005434821847	9931	13	4H
0005435302169	9931	14	5A
0005435372867	9931	15	5H
0005434821873	9931	16	5G
0005432203016	9931	17	5K
0005434821767	9931	18	11D
0005435372865	9931	19	11C
0005435149807	9931	20	11F
0005434822041	9931	21	11H
0005435372830	9931	22	12A
0005435372881	9931	23	12E
0005434821728	9931	24	12D
0005435372859	9931	25	12G
0005435372893	9931	26	12F
0005435372887	9931	27	13A
0005435735110	9931	28	12K
0005435372871	9931	29	12H
0005435372853	9931	30	13C
0005434821752	9931	31	13E
0005435299749	9931	32	13H
0005435372875	9931	33	13K
0005435372891	9931	34	14D
0005434822042	9931	35	14F
0005434821507	9931	36	14E
0005432400066	9931	37	14K
0005434821733	9931	38	14H
0005435372832	9931	39	15D
0005435299748	9931	40	15G
0005434821741	9931	41	16A
0005435149862	9931	42	15K
0005435386532	9931	43	16C
0005435149795	9931	44	16F
0005434821995	9931	45	16E
0005434822257	9931	46	16G
0005434821687	9931	47	17A
0005434821596	9931	48	17E
0005435372864	9931	49	18A
0005435372846	9931	50	17K
0005435149861	9931	51	17H
0005435386538	9931	52	18C
0005434821727	9931	53	18B
0005434828649	9931	54	18D
0005435372884	9931	55	18F
0005434821712	9931	56	18H
0005435372876	9931	57	19A
0005435372844	9931	58	18K
0005434821766	9931	59	19D
0005434821608	9931	60	19B
0005435372873	9931	61	19F
0005434828651	9931	62	19E
0005435372863	9931	63	19J
0005435372894	9931	64	19H
0005435372836	9931	65	20C
0005432396173	9931	66	20B
0005434821685	9931	67	20E
0005435735113	9931	68	20D
0005435302168	9931	69	20G
0005435372860	9931	70	20F
0005432203017	9931	71	20J
0005434821665	9931	72	21A
0005435372843	9931	73	20K
0005435372872	9931	74	21E
0005432396193	9931	75	21F
0005434821377	9931	76	21J
0005434821575	9931	77	21H
0005434821768	9931	78	21G
0005435149787	9931	79	22A
0005434831079	9931	80	22D
0005434822237	9931	81	22C
0005434821498	9931	82	22B
0005435149806	9931	83	22H
0005434821786	9931	84	22G
0005434821638	9931	85	22J
0005434821505	9931	86	23D
0005434822318	9931	87	23C
0005435661913	9931	88	23G
0005435372842	9931	89	23F
0005434821474	9931	90	23J
0005435372848	9931	91	23H
0005435735112	9931	92	24D
0005432823438	9931	93	23K
0005435372866	9931	94	24E
0005434821895	9931	95	24G
0005435372862	9931	96	25D
0005434821350	9931	97	25C
0005434822003	9931	98	25B
0005434822069	9931	99	25H
0005432396180	9931	100	25J
0005434821499	9931	101	26B
0005434831084	9931	102	26A
0005434821381	9931	103	26E
0005434821435	9931	104	26D
0005434664923	9931	105	26G
0005435372874	9931	106	26F
0005434821858	9931	107	26K
0005432823437	9931	108	27B
0005434821744	9931	109	27A
0005434821731	9931	110	27D
0005435372845	9931	111	27C
0005435302172	9931	112	27G
0005435372849	9931	113	28A
0005434831088	9931	114	27J
0005435372850	9931	115	28C
0005432396197	9931	116	28E
0005434821437	9931	117	28D
0005435302171	9931	118	29B
0005435372831	9931	119	29A
0005434821802	9931	120	28K
0005435372885	9931	121	29D
0005434821336	9931	122	29C
0005434821506	9931	123	29E
0005434831077	9931	124	29H
0005435299746	9931	125	29G
0005435372877	9931	126	30A
0005435372833	9931	127	29K
0005435372889	9931	128	29J
0005434821764	9931	129	30E
0005435372861	9931	130	30G
0005434822202	9931	131	30K
0005435372890	9931	132	30J
0005435372854	9931	133	30H
0005434822317	9931	134	31B
0005434821808	9931	135	31D
0005435299745	9931	136	31C
0005434822004	9931	137	31F
0005435372837	9931	138	31E
0005432203018	9931	139	31H
0005434831085	9931	140	31G
0005432203020	9931	141	31J
0005434821546	9931	142	32C
0005435302170	9931	143	32A
0005435372829	9931	144	32E
0005434821480	9931	145	32D
0005434822333	9931	146	32H
0005434821946	9931	147	32G
0005435149826	9931	148	32J
0005435372841	9931	149	33A
0005435372851	9931	150	32K
0005435386537	9931	151	33D
0005435372834	9931	152	33C
0005435149850	9931	153	33F
0005434821872	9931	154	33E
0005434821935	9931	155	33H
0005434821686	9931	156	33G
0005434821829	9931	157	33K
0005432396179	9931	158	34A
0005434821636	9931	159	34D
0005434821637	9931	160	34F
0005434822036	9931	161	34K
0005434821871	9931	162	34J
0005434664920	9931	163	34H
0005434821815	9931	164	35D
0005434831095	9931	165	35C
0005434821481	9931	166	35J
0005434822331	9931	167	35G
0005435386536	9931	168	36C
0005434831096	9931	169	36B
0005435386533	9931	170	36E
0005435372892	9931	171	36D
0005434664924	9931	172	36H
0005435372868	9931	173	36K
0005435372840	9931	174	37B
0005435372869	9931	175	37D
0005435735115	9931	176	37G
0005435735114	9931	177	37F
0005435372880	9931	178	37E
0005434822193	9931	179	37H
0005435735116	9931	180	38A
0005434821609	9931	181	38B
0005435372878	9931	182	38H
0005434822186	9931	183	39A
0005434821579	9931	184	38K
0005435372870	9931	185	39D
0005435179391	9931	186	39C
0005434821494	9931	187	39E
0005435372828	9931	188	39H
0005435372855	9931	189	39G
0005434821804	9931	190	39K
0005435299744	9931	191	39J
0005434822035	9931	192	40B
0005435372883	9931	193	40E
0005434821980	9931	194	40D
0005434822072	9931	195	40H
0005435372857	9931	196	40J
0005435386534	9931	197	41A
0005435372888	9931	198	40K
0005432396183	9931	199	41D
0005434821814	9931	200	41G
0005435386531	9931	201	41F
0005435149788	9931	202	41J
0005434821619	9931	203	41H
0005435179690	9931	204	42A
0005434821894	9931	205	41K
0005435386535	9931	206	42D
0005434821469	9931	207	42H
0005434821592	9931	208	42J
0005434822037	9931	209	43B
0005434821667	9931	210	43A
0005434821962	9931	211	43C
0005434822068	9931	212	43F
0005434821514	9931	213	43E
0005435372839	9931	214	43G
0005434821805	9931	215	44A
0005435372856	9931	216	43K
0005434821436	9931	217	44B
0005434822263	9931	218	44D
0005435372886	9931	219	44G
0005434821889	9931	220	44J
0005434821704	9931	221	45B
0005434822038	9931	222	45A
0005435149796	9931	223	45C
0005434821993	9931	224	45F
0005434821523	9931	225	45E
0005434821762	9931	226	45H
0005435735111	9931	227	46A
0005435372827	9931	228	45K
0005435372847	9931	229	45J
0005435372835	9931	230	46C
0005435149800	9931	231	46E
0005434821486	9931	232	46D
0005435661914	9931	233	46K
0005432400072	9931	234	46H
0005434821369	9931	235	47E
0005434821666	9931	236	47C
0005435149863	9931	237	47G
0005435372882	9931	238	47H
0005435372852	9931	239	49D
0005434821902	9931	240	49F
0005435372858	9931	241	49H
0005434821751	9931	242	50C
0005434828650	9931	243	50H
0005435372879	9931	244	50F
0005434821574	9931	245	50K
0005435372838	9931	246	51F
0005434822334	9931	247	51E
0005434821576	9931	248	51G
0005435082739	6980	1	1D
0005435082736	6980	2	2D
0005435082738	6980	3	5A
0005435790289	6980	4	5D
0005435082737	6980	5	6D
0005435790291	6980	6	18C
0005435790290	6980	7	19A
0005435790288	6980	8	20A
0005435082740	6980	9	20B
0005435082741	6980	10	22A
0005435790287	6980	11	23B
0005435082651	25966	1	1D
0005435082665	25966	2	2B
0005435082666	25966	3	2D
0005435790272	25966	4	3B
0005435082669	25966	5	3D
0005435082675	25966	6	6A
0005435082658	25966	7	6B
0005435082659	25966	8	18B
0005435082657	25966	9	19D
0005435082664	25966	10	20D
0005434756200	9551	1	1A
0005434213827	9551	2	1C
0005434756170	9551	3	1D
0005434213874	9551	4	1F
0005434213735	9551	5	2A
0005434756184	9551	6	2C
0005434213725	9551	7	2F
0005434213925	9551	8	3A
0005434213917	9551	9	3C
0005434756173	9551	10	3F
0005434756169	9551	11	4A
0005434213805	9551	12	4C
0005434213785	9551	13	4D
0005434213992	9551	14	4E
0005434213871	9551	15	4F
0005434213870	9551	16	5A
0005434213721	9551	17	5C
0005434213951	9551	18	5D
0005434213826	9551	19	5E
0005434756192	9551	20	5F
0005434213746	9551	21	6A
0005434756175	9551	22	6C
0005434756182	9551	23	6D
0005434756201	9551	24	6E
0005434213753	9551	25	6F
0005434213922	9551	26	7A
0005434213828	9551	27	7C
0005434213875	9551	28	7E
0005434756172	9551	29	7F
0005434213736	9551	30	8C
0005434756186	9551	31	8D
0005434756195	9551	32	8E
0005434756183	9551	33	8F
0005434756174	9551	34	9A
0005434213744	9551	35	9C
0005434756179	9551	36	9D
0005434756190	9551	37	9E
0005434213807	9551	38	10A
0005434213747	9551	39	10C
0005434213780	9551	40	10F
0005434213751	9551	41	11A
0005434213916	9551	42	11C
0005434213860	9551	43	11D
0005434213953	9551	44	11E
0005434756187	9551	45	11F
0005434756177	9551	46	12A
0005434213806	9551	47	12C
0005434214026	9551	48	12D
0005434213728	9551	49	12E
0005434756189	9551	50	12F
0005434213796	9551	51	13A
0005434756196	9551	52	13C
0005434756181	9551	53	13D
0005434213952	9551	54	13F
0005434213856	9551	55	14C
0005434756191	9551	56	14A
0005434213758	9551	57	14D
0005434214071	9551	58	14E
0005434756193	9551	59	14F
0005434213950	9551	60	15A
0005434213798	9551	61	15C
0005434213926	9551	62	15D
0005434213726	9551	63	15E
0005434756171	9551	64	15F
0005434213872	9551	65	16A
0005434756198	9551	66	16C
0005434213864	9551	67	16F
0005434756185	9551	68	16E
0005434213797	9551	69	17A
0005434213729	9551	70	17C
0005434756199	9551	71	17D
0005434756188	9551	72	17E
0005434213765	9551	73	18A
0005434213739	9551	74	18C
0005434756176	9551	75	19A
0005434756178	9551	76	19C
0005434213921	9551	77	19D
0005434213840	9551	78	19E
0005434756194	9551	79	19F
0005434756180	9551	80	20C
0005434756168	9551	81	20E
0005434756197	9551	82	20F
0005434214175	28644	1	1A
0005434214180	28644	2	1C
0005434214184	28644	3	1D
0005434755799	28644	4	2C
0005434755765	28644	5	2F
0005434214176	28644	6	3A
0005434214207	28644	7	3C
0005434214210	28644	8	3D
0005434755777	28644	9	3F
0005434214217	28644	10	4A
0005434214192	28644	11	4C
0005434755719	28644	12	4E
0005434214205	28644	13	5A
0005434214195	28644	14	5C
0005434214208	28644	15	5E
0005434755823	28644	16	6A
0005434214189	28644	17	6C
0005434755822	28644	18	6D
0005434755764	28644	19	7A
0005434214206	28644	20	7D
0005434755754	28644	21	7E
0005434755704	28644	22	8A
0005434214186	28644	23	8C
0005434214216	28644	24	8D
0005434214197	28644	25	8E
0005434755746	28644	26	8F
0005434755809	28644	27	9C
0005434214199	28644	28	9D
0005434214215	28644	29	9E
0005434755737	28644	30	9F
0005434214202	28644	31	10A
0005434214203	28644	32	10C
0005434214211	28644	33	11A
0005434214218	28644	34	11C
0005434755776	28644	35	11D
0005434214185	28644	36	11E
0005434214219	28644	37	11F
0005434755810	28644	38	12A
0005434214174	28644	39	12E
0005434214193	28644	40	12F
0005434214183	28644	41	13A
0005434214187	28644	42	13C
0005434755731	28644	43	13D
0005434214209	28644	44	13E
0005434214212	28644	45	14A
0005434755732	28644	46	14C
0005434214213	28644	47	14E
0005434214177	28644	48	15C
0005434214182	28644	49	15E
0005434755801	28644	50	15F
0005434214181	28644	51	16A
0005434214191	28644	52	16C
0005434214220	28644	53	16D
0005434755723	28644	54	16F
0005434214196	28644	55	17A
0005434214194	28644	56	17C
0005434214198	28644	57	17D
0005434755761	28644	58	17E
0005434214214	28644	59	17F
0005434214188	28644	60	18C
0005434214190	28644	61	18D
0005434214204	28644	62	18E
0005434755703	28644	63	18F
0005434755811	28644	64	19A
0005434214201	28644	65	19C
0005434214200	28644	66	19D
0005434755739	28644	67	19E
0005434755708	28644	68	20A
0005434755778	28644	69	20C
0005434214178	28644	70	20D
0005434214179	28644	71	20F
0005435100105	10817	1	2A
0005435100103	10817	2	3B
0005434760153	10817	3	4B
0005435100104	10817	4	5D
0005434760160	10817	5	18D
0005435100076	31829	1	4A
0005435100089	31829	2	6A
0005434760181	31829	3	20B
0005434760182	31829	4	21A
0005434639174	1979	1	1B
0005432290615	1979	2	1C
0005434639172	1979	3	1D
0005434639170	1979	4	2A
0005434639179	1979	5	2B
0005434639163	1979	6	2C
0005434639169	1979	7	2D
0005434639178	1979	8	3A
0005433202122	1979	9	3B
0005433202138	1979	10	3C
0005434639177	1979	11	3D
0005434639156	1979	12	4A
0005433202173	1979	13	4B
0005434639180	1979	14	4C
0005434639167	1979	15	4D
0005434639168	1979	16	5A
0005434639165	1979	17	5B
0005433202108	1979	18	5C
0005433202190	1979	19	5D
0005434639157	1979	20	6A
0005433202132	1979	21	6B
0005433202157	1979	22	6C
0005433202171	1979	23	6D
0005434639181	1979	24	7A
0005433202104	1979	25	7B
0005434639171	1979	26	7C
0005434639173	1979	27	7D
0005434639161	1979	28	18A
0005434639182	1979	29	18B
0005433202130	1979	30	18C
0005434639154	1979	31	19A
0005435948320	1979	32	18D
0005432290616	1979	33	19B
0005434639155	1979	34	19C
0005433202153	1979	35	19D
0005435948321	1979	36	20A
0005433202131	1979	37	20B
0005434639162	1979	38	20C
0005434639166	1979	39	20D
0005434639159	1979	40	21A
0005434639175	1979	41	21B
0005434639160	1979	42	21C
0005433202167	1979	43	21D
0005434639158	1979	44	22A
0005434639164	1979	45	22C
0005434639176	1979	46	22D
0005433202105	1979	47	23A
0005433202137	1979	48	23B
0005433202256	23266	1	1A
0005434638898	23266	2	1B
0005433202265	23266	3	1C
0005434638968	23266	4	1D
0005433202259	23266	5	2A
0005433202266	23266	6	2C
0005433202267	23266	7	2D
0005433202257	23266	8	3B
0005433202254	23266	9	3C
0005434638984	23266	10	3D
0005433202264	23266	11	4A
0005434638982	23266	12	4B
0005434638848	23266	13	4C
0005433202255	23266	14	4D
0005434638988	23266	15	5A
0005433202258	23266	16	6A
0005433202253	23266	17	6B
0005434638863	23266	18	6C
0005433202260	23266	19	6D
0005434638866	23266	20	7B
0005434638896	23266	21	7C
0005434638951	23266	22	18A
0005434638895	23266	23	18C
0005434638983	23266	24	19A
0005433202263	23266	25	18D
0005434638931	23266	26	20B
0005433202262	23266	27	21A
0005434638947	23266	28	21B
0005434638950	23266	29	22A
0005434638908	23266	30	21D
0005434638989	23266	31	22C
0005433202261	23266	32	22D
0005433533285	6092	1	1C
0005434600655	6092	2	2A
0005433531271	6092	3	2C
0005434600650	6092	4	2D
0005434600646	6092	5	3C
0005434600656	6092	6	3D
0005435326541	6092	7	3F
0005434600648	6092	8	4A
0005434600639	6092	9	4E
0005434600644	6092	10	4F
0005432111262	6092	11	5E
0005434600640	6092	12	6F
0005434600633	6092	13	7A
0005435326528	6092	14	7C
0005434600631	6092	15	7E
0005434600652	6092	16	7F
0005433531269	6092	17	8C
0005434600637	6092	18	8D
0005433531270	6092	19	9A
0005434600638	6092	20	9F
0005434600645	6092	21	10D
0005433533286	6092	22	11C
0005435326552	6092	23	11D
0005435326554	6092	24	11F
0005434600657	6092	25	12C
0005434600647	6092	26	12D
0005433533283	6092	27	12E
0005435326544	6092	28	12F
0005434600632	6092	29	13C
0005435326559	6092	30	13D
0005434600649	6092	31	13E
0005434600642	6092	32	14A
0005434600654	6092	33	14D
0005433533284	6092	34	14F
0005434600641	6092	35	15A
0005434600634	6092	36	15E
0005435326543	6092	37	16E
0005434600643	6092	38	16F
0005434600651	6092	39	17C
0005435326551	6092	40	17D
0005434600635	6092	41	17E
0005432111260	6092	42	17F
0005435326499	6092	43	18A
0005433531272	6092	44	19A
0005434600653	6092	45	19C
0005434600630	6092	46	19D
0005432111259	6092	47	19E
0005434600636	6092	48	20C
0005432111261	6092	49	20F
0005435326654	18609	1	1A
0005435326666	18609	2	2C
0005435326662	18609	3	3F
0005433531233	18609	4	4E
0005434600416	18609	5	5C
0005435326661	18609	6	6A
0005434600554	18609	7	7D
0005435326655	18609	8	8E
0005435326659	18609	9	9A
0005435326656	18609	10	9C
0005434600477	18609	11	9E
0005435326657	18609	12	10A
0005434600357	18609	13	10D
0005433531231	18609	14	10E
0005434600463	18609	15	10F
0005435326658	18609	16	11C
0005435326665	18609	17	11E
0005434600361	18609	18	12A
0005434600438	18609	19	12C
0005434600516	18609	20	12D
0005434600509	18609	21	13D
0005435326663	18609	22	13F
0005434600405	18609	23	14A
0005433531232	18609	24	15A
0005435326660	18609	25	15C
0005434600415	18609	26	15D
0005434600439	18609	27	16A
0005434600386	18609	28	16D
0005434600351	18609	29	16F
0005434600389	18609	30	17C
0005434600356	18609	31	18D
0005434600462	18609	32	19A
0005434600450	18609	33	20A
0005435326664	18609	34	20C
0005434600458	18609	35	20E
0005434550843	10616	1	1A
0005434554050	10616	2	1C
0005434550874	10616	3	1D
0005434550823	10616	4	1F
0005433180706	10616	5	2A
0005434550865	10616	6	2C
0005433180655	10616	7	2D
0005434550847	10616	8	2F
0005433180659	10616	9	3A
0005434550862	10616	10	3C
0005434550870	10616	11	3D
0005433180716	10616	12	3F
0005434550848	10616	13	4A
0005434550849	10616	14	4C
0005434550828	10616	15	4E
0005434550838	10616	16	5A
0005434550845	10616	17	5C
0005434550840	10616	18	5D
0005434558215	10616	19	5E
0005434550826	10616	20	5F
0005434558214	10616	21	6A
0005434550863	10616	22	6C
0005434550833	10616	23	6D
0005434550853	10616	24	6F
0005434550873	10616	25	7A
0005434550835	10616	26	7C
0005434558213	10616	27	7D
0005434550875	10616	28	7E
0005434550824	10616	29	7F
0005434550822	10616	30	8A
0005433180708	10616	31	8C
0005434550864	10616	32	8D
0005434550836	10616	33	8E
0005433180710	10616	34	8F
0005434550850	10616	35	9A
0005434550825	10616	36	9C
0005434550841	10616	37	9D
0005433180681	10616	38	9E
0005433180702	10616	39	9F
0005434550851	10616	40	10C
0005434550869	10616	41	10D
0005433180811	10616	42	10E
0005433180695	10616	43	10F
0005433180740	10616	44	11A
0005434550858	10616	45	11C
0005433180707	10616	46	11D
0005434550855	10616	47	11E
0005434550871	10616	48	11F
0005434550866	10616	49	12C
0005434550830	10616	50	12D
0005434550859	10616	51	12E
0005433180715	10616	52	12F
0005434550839	10616	53	13A
0005434550872	10616	54	13C
0005434558212	10616	55	13D
0005434558218	10616	56	13E
0005433180741	10616	57	13F
0005434550854	10616	58	14A
0005433180735	10616	59	14C
0005433180714	10616	60	14D
0005434554049	10616	61	14E
0005434550846	10616	62	14F
0005434550834	10616	63	15A
0005434550827	10616	64	15D
0005434550837	10616	65	15C
0005434550842	10616	66	15E
0005434558217	10616	67	15F
0005433180774	10616	68	16A
0005433180739	10616	69	16C
0005434550831	10616	70	16D
0005434550857	10616	71	16E
0005434550820	10616	72	16F
0005434550861	10616	73	17C
0005433180705	10616	74	17D
0005434550852	10616	75	17E
0005434550832	10616	76	17F
0005433180775	10616	77	18A
0005434550856	10616	78	18C
0005434550844	10616	79	18D
0005434558211	10616	80	18E
0005433180694	10616	81	18F
0005433180738	10616	82	19A
0005434550860	10616	83	19C
0005434558216	10616	84	19D
0005433180677	10616	85	19E
0005433180682	10616	86	19F
0005434550821	10616	87	20A
0005434550819	10616	88	20C
0005434550829	10616	89	20D
0005434550868	10616	90	20E
0005434550867	10616	91	20F
0005433180954	27720	1	3C
0005433180952	27720	2	4D
0005433180933	27720	3	4E
0005433180940	27720	4	5F
0005433180944	27720	5	6A
0005433180939	27720	6	6E
0005433180955	27720	7	7C
0005433180945	27720	8	7F
0005433180942	27720	9	8A
0005433180948	27720	10	11C
0005433180950	27720	11	11D
0005433180936	27720	12	13A
0005433180935	27720	13	13F
0005433180951	27720	14	14E
0005433180946	27720	15	14F
0005433180937	27720	16	15E
0005433180947	27720	17	15F
0005433180957	27720	18	16D
0005433180953	27720	19	17F
0005433180938	27720	20	18A
0005433180943	27720	21	18F
0005433180941	27720	22	19A
0005433180934	27720	23	19C
0005433180949	27720	24	19E
0005433180956	27720	25	20F
0005434550317	27721	1	1C
0005434550571	27721	2	1F
0005434550675	27721	3	2A
0005434550575	27721	4	2C
0005434550417	27721	5	2D
0005434550569	27721	6	2F
0005434550358	27721	7	3A
0005434550341	27721	8	3D
0005434554029	27721	9	4A
0005434550460	27721	10	4C
0005434550701	27721	11	4D
0005434558150	27721	12	4E
0005434550677	27721	13	4F
0005434550283	27721	14	5C
0005434550526	27721	15	5F
0005434558147	27721	16	6A
0005434550602	27721	17	6C
0005434550463	27721	18	6D
0005434550520	27721	19	7A
0005434550399	27721	20	7C
0005434550415	27721	21	7E
0005434550524	27721	22	7F
0005434550676	27721	23	8C
0005434550624	27721	24	8D
0005434550414	27721	25	9A
0005434550427	27721	26	9C
0005434550398	27721	27	9E
0005434550479	27721	28	10A
0005434550359	27721	29	9F
0005434550418	27721	30	10C
0005434550628	27721	31	10E
0005434550523	27721	32	11A
0005434558151	27721	33	11C
0005434558152	27721	34	11D
0005434550642	27721	35	11E
0005434550553	27721	36	11F
0005434550345	27721	37	12A
0005434550382	27721	38	12F
0005434550428	27721	39	13C
0005434550282	27721	40	13E
0005434550416	27721	41	14A
0005434550702	27721	42	14C
0005434550262	27721	43	14F
0005434550503	27721	44	15C
0005434550336	27721	45	15D
0005434550459	27721	46	15F
0005434550400	27721	47	16A
0005434550529	27721	48	16C
0005434550525	27721	49	16D
0005434554028	27721	50	16F
0005434558145	27721	51	16E
0005434550342	27721	52	17C
0005434550434	27721	53	17E
0005434550435	27721	54	17F
0005434550448	27721	55	18A
0005434550623	27721	56	19D
0005434558148	27721	57	19E
0005434550645	27721	58	19F
0005434550572	27721	59	20A
0005434550344	27721	60	20C
0005434550277	27721	61	20F
0005435254431	6169	1	2A
0005435254432	6169	2	2B
0005433459192	6169	3	3A
0005433459194	6169	4	5A
0005435254441	6169	5	6A
0005433459193	6169	6	6B
0005435254459	19293	1	1A
0005433459158	19293	2	1B
0005435254460	19293	3	2B
0005433459157	19293	4	3B
0005435254461	19293	5	4A
0005433459150	19293	6	4B
0005433459151	19293	7	5A
0005433459152	19293	8	5B
0005433459168	19293	9	6B
0005435719564	6727	1	1A
0005435630944	6727	2	1C
0005435681859	6727	3	1D
0005435681887	6727	4	1F
0005435681879	6727	5	2A
0005435720129	6727	6	2D
0005435681872	6727	7	2F
0005435681857	6727	8	3C
0005435681873	6727	9	3F
0005435681864	6727	10	4A
0005435681889	6727	11	4C
0005435630946	6727	12	4D
0005435681848	6727	13	4F
0005432533250	6727	14	4E
0005435217684	6727	15	5C
0005435681883	6727	16	5D
0005435681871	6727	17	5E
0005435681866	6727	18	5F
0005435681862	6727	19	6A
0005435661912	6727	20	6C
0005435437591	6727	21	6D
0005435437675	6727	22	6E
0005435437694	6727	23	6F
0005435681878	6727	24	7A
0005435437695	6727	25	7C
0005435681850	6727	26	7D
0005435661910	6727	27	7E
0005432136136	6727	28	7F
0005432136137	6727	29	8A
0005435681865	6727	30	8C
0005435661911	6727	31	8D
0005435437711	6727	32	8E
0005435681877	6727	33	8F
0005434828653	6727	34	9A
0005435630945	6727	35	9D
0005435681863	6727	36	9E
0005434828652	6727	37	9F
0005435681855	6727	38	10A
0005435681888	6727	39	10C
0005435681874	6727	40	10D
0005435437593	6727	41	10E
0005435437592	6727	42	10F
0005435681851	6727	43	11A
0005435681853	6727	44	11C
0005435681880	6727	45	11D
0005435437587	6727	46	11E
0005435681867	6727	47	11F
0005435221497	6727	48	12A
0005435437575	6727	49	12C
0005435437645	6727	50	12D
0005432533254	6727	51	12E
0005435681854	6727	52	13A
0005435437644	6727	53	13C
0005432136139	6727	54	13D
0005435681870	6727	55	13E
0005435681884	6727	56	14A
0005435719563	6727	57	14C
0005435681881	6727	58	14D
0005435681860	6727	59	15A
0005435681882	6727	60	15D
0005435630947	6727	61	15F
0005435681849	6727	62	16A
0005435221506	6727	63	16D
0005435681868	6727	64	16E
0005435681890	6727	65	16F
0005435681852	6727	66	17A
0005435681886	6727	67	17C
0005435437718	6727	68	17D
0005432136138	6727	69	17E
0005435681869	6727	70	17F
0005435437635	6727	71	18A
0005435217683	6727	72	18C
0005435681861	6727	73	18D
0005435437606	6727	74	18F
0005435220284	6727	75	19A
0005435681875	6727	76	19C
0005435681856	6727	77	19D
0005435437669	6727	78	19E
0005435681885	6727	79	19F
0005435437586	6727	80	20A
0005435681858	6727	81	20C
0005435681876	6727	82	20E
0005435437604	6727	83	20F
0005435437806	24569	1	1A
0005435681480	24569	2	1C
0005435437818	24569	3	1F
0005435681548	24569	4	2C
0005432533273	24569	5	3A
0005435681467	24569	6	3C
0005435720809	24569	7	3D
0005435681526	24569	8	3F
0005435681385	24569	9	4C
0005435437807	24569	10	4D
0005435681582	24569	11	4E
0005435681437	24569	12	4F
0005435681539	24569	13	5C
0005435681701	24569	14	5D
0005435437822	24569	15	5E
0005435661884	24569	16	5F
0005435681575	24569	17	6A
0005432305732	24569	18	6C
0005435681702	24569	19	6D
0005435681592	24569	20	6E
0005435681479	24569	21	7A
0005435681536	24569	22	7D
0005435437823	24569	23	7F
0005435661895	24569	24	8C
0005435437819	24569	25	8D
0005432533274	24569	26	8E
0005432305734	24569	27	8F
0005435720810	24569	28	9C
0005435681555	24569	29	9D
0005435681535	24569	30	9E
0005435437812	24569	31	10A
0005435437803	24569	32	10C
0005434828680	24569	33	10D
0005435681492	24569	34	10E
0005435437809	24569	35	10F
0005435437808	24569	36	11C
0005435681624	24569	37	11D
0005435681473	24569	38	11E
0005435720804	24569	39	11F
0005435681474	24569	40	12A
0005435437820	24569	41	12C
0005435681577	24569	42	12D
0005435661894	24569	43	12E
0005435437801	24569	44	12F
0005435437804	24569	45	13A
0005435681601	24569	46	13C
0005435681537	24569	47	13F
0005435437802	24569	48	14A
0005435720807	24569	49	14C
0005435681573	24569	50	14D
0005435720802	24569	51	14F
0005432533272	24569	52	15A
0005434828681	24569	53	15C
0005435437814	24569	54	15E
0005435437821	24569	55	16D
0005435681527	24569	56	16E
0005432305733	24569	57	16F
0005435437815	24569	58	17C
0005435437811	24569	59	17D
0005435681545	24569	60	17E
0005435720803	24569	61	17F
0005435437816	24569	62	18C
0005435437817	24569	63	18A
0005435437813	24569	64	18D
0005435681563	24569	65	18E
0005435681436	24569	66	18F
0005435437810	24569	67	19A
0005435681588	24569	68	19D
0005434828679	24569	69	19E
0005435437805	24569	70	20A
0005435681574	24569	71	20D
0005435681583	24569	72	20E
0005435719552	24569	73	20F
0005435126088	11514	1	1A
0005435126098	11514	2	1C
0005435126093	11514	3	1F
0005435126078	11514	4	2C
0005435098542	11514	5	2F
0005435126072	11514	6	3D
0005435558042	11514	7	3F
0005435098543	11514	8	4F
0005435126077	11514	9	5D
0005435126101	11514	10	5E
0005435126069	11514	11	5F
0005435098538	11514	12	6E
0005435126090	11514	13	7D
0005435098540	11514	14	7F
0005435126100	11514	15	8A
0005435126074	11514	16	8D
0005435126081	11514	17	8E
0005435105960	11514	18	8F
0005435126073	11514	19	9A
0005435098541	11514	20	9C
0005435126089	11514	21	9E
0005435126105	11514	22	9F
0005435126086	11514	23	10C
0005435126084	11514	24	10D
0005435126080	11514	25	10E
0005435126076	11514	26	11A
0005435126087	11514	27	11C
0005435126097	11514	28	12C
0005435126064	11514	29	12A
0005435098539	11514	30	12E
0005435126099	11514	31	13A
0005435126067	11514	32	13C
0005435126075	11514	33	13D
0005435126102	11514	34	13E
0005435126096	11514	35	13F
0005435126104	11514	36	14F
0005435126094	11514	37	15D
0005435126071	11514	38	15F
0005435126103	11514	39	16D
0005435126065	11514	40	16E
0005435126085	11514	41	17D
0005435105961	11514	42	17E
0005435126066	11514	43	17F
0005435126083	11514	44	18A
0005435126079	11514	45	18D
0005435126095	11514	46	18E
0005435126092	11514	47	18F
0005435126091	11514	48	19A
0005435105959	11514	49	19C
0005435126068	11514	50	19D
0005435126070	11514	51	19E
0005435126082	11514	52	20E
0005435125806	31897	1	1A
0005435105931	31897	2	1C
0005435125799	31897	3	1D
0005435125652	31897	4	2A
0005435125742	31897	5	2F
0005435125793	31897	6	3A
0005435125864	31897	7	3F
0005435125741	31897	8	4F
0005435125816	31897	9	5D
0005435125663	31897	10	5E
0005435125704	31897	11	5F
0005435125795	31897	12	6C
0005435098528	31897	13	6F
0005435125834	31897	14	7D
0005435125710	31897	15	8A
0005435125841	31897	16	8C
0005435125805	31897	17	9A
0005435125910	31897	18	9E
0005435125764	31897	19	9F
0005435125897	31897	20	10A
0005435125911	31897	21	10C
0005435105930	31897	22	10D
0005435125794	31897	23	10E
0005435125804	31897	24	10F
0005435558070	31897	25	11E
0005435125895	31897	26	12C
0005435125937	31897	27	12E
0005435125844	31897	28	13C
0005435125869	31897	29	13F
0005435125824	31897	30	14C
0005435125667	31897	31	14D
0005435125760	31897	32	14E
0005435125796	31897	33	14F
0005435125761	31897	34	15A
0005435125913	31897	35	15C
0005435125654	31897	36	15D
0005435125653	31897	37	15E
0005435125863	31897	38	15F
0005435125751	31897	39	16F
0005435125912	31897	40	17C
0005435125752	31897	41	17D
0005435125896	31897	42	17E
0005435558069	31897	43	17F
0005435125891	31897	44	18D
0005435558071	31897	45	19A
0005435125728	31897	46	19C
0005435125894	31897	47	19F
0005435125770	31897	48	20C
0005433397729	13521	1	1A
0005433397748	13521	2	1D
0005433397751	13521	3	2A
0005433397736	13521	4	2C
0005433397768	13521	5	3F
0005433397766	13521	6	4A
0005433397738	13521	7	4D
0005433397731	13521	8	4E
0005433397726	13521	9	5D
0005433397747	13521	10	6A
0005433397762	13521	11	6C
0005433397742	13521	12	6E
0005433397774	13521	13	6F
0005435732194	13521	14	7C
0005433397734	13521	15	7D
0005433397744	13521	16	7E
0005433397767	13521	17	8C
0005433397737	13521	18	8E
0005433397773	13521	19	9A
0005433397761	13521	20	9C
0005435732153	13521	21	9E
0005433397770	13521	22	10A
0005435732154	13521	23	10C
0005433397765	13521	24	10D
0005435732201	13521	25	10E
0005433397760	13521	26	11E
0005433397730	13521	27	11F
0005433397746	13521	28	12A
0005433397759	13521	29	12E
0005433397732	13521	30	12F
0005435732172	13521	31	13C
0005433397728	13521	32	13E
0005433397763	13521	33	14A
0005433397757	13521	34	14C
0005433397753	13521	35	14D
0005433397758	13521	36	14E
0005433397764	13521	37	14F
0005433397755	13521	38	15A
0005433397769	13521	39	15C
0005433397752	13521	40	15D
0005433397727	13521	41	15F
0005433397735	13521	42	16A
0005433397733	13521	43	16C
0005433397745	13521	44	16E
0005433397740	13521	45	16F
0005433397750	13521	46	17A
0005435732152	13521	47	17D
0005433397743	13521	48	17E
0005433397756	13521	49	18C
0005433397771	13521	50	18F
0005433397741	13521	51	19D
0005433397739	13521	52	19E
0005433397772	13521	53	19F
0005435732140	13521	54	20A
0005433397754	13521	55	20D
0005433397749	13521	56	20E
0005435732158	13521	57	20F
0005433397237	19370	1	1A
0005433397303	19370	2	1D
0005435732262	19370	3	1F
0005433397210	19370	4	2A
0005433397496	19370	5	2F
0005433397287	19370	6	3A
0005433397325	19370	7	3C
0005435732258	19370	8	3D
0005435732273	19370	9	4C
0005433397493	19370	10	4E
0005433397196	19370	11	5A
0005433397548	19370	12	5C
0005435732268	19370	13	5D
0005432297261	19370	14	5E
0005433397380	19370	15	5F
0005433397292	19370	16	6A
0005435732259	19370	17	6D
0005433397419	19370	18	6E
0005433397291	19370	19	6F
0005433397546	19370	20	7C
0005435732270	19370	21	7E
0005433397498	19370	22	7F
0005435732257	19370	23	8A
0005433397255	19370	24	8C
0005433397468	19370	25	8D
0005433397212	19370	26	8E
0005435732274	19370	27	8F
0005433397283	19370	28	9A
0005435732266	19370	29	9C
0005433397489	19370	30	9D
0005433397383	19370	31	9E
0005433397488	19370	32	9F
0005433397271	19370	33	10C
0005433397492	19370	34	10E
0005435732267	19370	35	10F
0005433397326	19370	36	11A
0005433397504	19370	37	11E
0005435732276	19370	38	12D
0005435732265	19370	39	12E
0005433397509	19370	40	13A
0005433397569	19370	41	13C
0005433397618	19370	42	13D
0005435732271	19370	43	14A
0005435732275	19370	44	14C
0005433397497	19370	45	14E
0005433397288	19370	46	14F
0005433397420	19370	47	15A
0005433397505	19370	48	15D
0005433397490	19370	49	16A
0005435732264	19370	50	16D
0005435732260	19370	51	16E
0005435732261	19370	52	17A
0005435732263	19370	53	17C
0005435732272	19370	54	17D
0005433397284	19370	55	17E
0005433397413	19370	56	18A
0005433397211	19370	57	19A
0005433397272	19370	58	19C
0005433397568	19370	59	19E
0005433397466	19370	60	20C
0005435732269	19370	61	20D
0005433397465	19370	62	20E
0005433397355	19370	63	20F
0005435068520	13165	1	1A
0005435068315	13165	2	1C
0005435068426	13165	3	1D
0005435925202	13165	4	1F
0005435068331	13165	5	2D
0005435925196	13165	6	2F
0005435925195	13165	7	3A
0005435925192	13165	8	3C
0005435068314	13165	9	3D
0005435068385	13165	10	3F
0005435068470	13165	11	4A
0005435068290	13165	12	4E
0005435925199	13165	13	5A
0005435068365	13165	14	5D
0005435068302	13165	15	6C
0005435925201	13165	16	6F
0005435068425	13165	17	7A
0005435068291	13165	18	7E
0005435068222	13165	19	8A
0005435068329	13165	20	8E
0005435068171	13165	21	8F
0005435068363	13165	22	9A
0005435925197	13165	23	9D
0005435068323	13165	24	9E
0005435068357	13165	25	10A
0005435925198	13165	26	10D
0005435068527	13165	27	11C
0005435068403	13165	28	11D
0005435068289	13165	29	11E
0005435068364	13165	30	12A
0005435068170	13165	31	12D
0005435068301	13165	32	13A
0005435925193	13165	33	13D
0005435068224	13165	34	13E
0005435068360	13165	35	13F
0005435925203	13165	36	14A
0005435068519	13165	37	14C
0005435068207	13165	38	14D
0005435068237	13165	39	14F
0005435068336	13165	40	15C
0005435068200	13165	41	15D
0005435068223	13165	42	15E
0005435068277	13165	43	15F
0005435068167	13165	44	16D
0005435068394	13165	45	17D
0005435068166	13165	46	18A
0005435925200	13165	47	18C
0005435068281	13165	48	19A
0005435068215	13165	49	19C
0005435068402	13165	50	19D
0005435068358	13165	51	19E
0005435068276	13165	52	19F
0005435068255	13165	53	20D
0005435068528	13165	54	20E
0005435925194	13165	55	20F
0005435068710	15462	1	1C
0005435068735	15462	2	1D
0005435925070	15462	3	2C
0005435068689	15462	4	2D
0005435925077	15462	5	3A
0005435068713	15462	6	2F
0005435068695	15462	7	3C
0005435068709	15462	8	3D
0005435068739	15462	9	3F
0005435068730	15462	10	4A
0005435068728	15462	11	4C
0005435068708	15462	12	4D
0005435925093	15462	13	4F
0005435925091	15462	14	5C
0005435068700	15462	15	5D
0005435068696	15462	16	5E
0005435068721	15462	17	5F
0005435068720	15462	18	6A
0005435068729	15462	19	6E
0005435068734	15462	20	6F
0005435068704	15462	21	7C
0005435068694	15462	22	7D
0005435068737	15462	23	7E
0005435925088	15462	24	8A
0005435068711	15462	25	8D
0005435068716	15462	26	8F
0005435925089	15462	27	9A
0005435068693	15462	28	9C
0005435925076	15462	29	9E
0005435068699	15462	30	9F
0005435068723	15462	31	10D
0005435068736	15462	32	10E
0005435068692	15462	33	10F
0005435068690	15462	34	11D
0005435068740	15462	35	11E
0005435068707	15462	36	11F
0005435068691	15462	37	12C
0005435068703	15462	38	12D
0005435068712	15462	39	12F
0005435068738	15462	40	13C
0005435925090	15462	41	13E
0005435068725	15462	42	14A
0005435068722	15462	43	14C
0005435068714	15462	44	14D
0005435068724	15462	45	14E
0005435068701	15462	46	15D
0005435068688	15462	47	15E
0005435068698	15462	48	15F
0005435068726	15462	49	16A
0005435068719	15462	50	16C
0005435068706	15462	51	16E
0005435068702	15462	52	17A
0005435068718	15462	53	17D
0005435068732	15462	54	17E
0005435068733	15462	55	17F
0005435068715	15462	56	18A
0005435068697	15462	57	18D
0005435068727	15462	58	19D
0005435068717	15462	59	19E
0005435068705	15462	60	20A
0005435925074	15462	61	20D
0005435068731	15462	62	20E
0005433407530	29494	1	1A
0005433407534	29494	2	1D
0005435808057	29494	3	4B
0005435808072	29494	4	4C
0005435808071	29494	5	5B
0005433407537	29494	6	5C
0005435808053	29494	7	5D
0005433407536	29494	8	6C
0005433407531	29494	9	6B
0005433407532	29494	10	7B
0005433407535	29494	11	7D
0005435808056	29494	12	18C
0005435808063	29494	13	18D
0005433407538	29494	14	19C
0005433407533	29494	15	20D
0005435808115	29494	16	23A
0005434214249	10684	1	1C
0005434755870	10684	2	1D
0005434755873	10684	3	1F
0005434755800	10684	4	2C
0005434214245	10684	5	2D
0005434214235	10684	6	3A
0005434214242	10684	7	3C
0005434755874	10684	8	3F
0005434214256	10684	9	4A
0005434214233	10684	10	4C
0005434214265	10684	11	4E
0005434214228	10684	12	4F
0005434755797	10684	13	5A
0005434214240	10684	14	5C
0005434755755	10684	15	5D
0005434214268	10684	16	5E
0005434214231	10684	17	5F
0005434755808	10684	18	6A
0005434214250	10684	19	6D
0005434214252	10684	20	6E
0005434755729	10684	21	6F
0005434214267	10684	22	7A
0005434755869	10684	23	7C
0005434214237	10684	24	7D
0005434214222	10684	25	7F
0005434755844	10684	26	8A
0005434755724	10684	27	8C
0005434214263	10684	28	8D
0005434214264	10684	29	9C
0005434214224	10684	30	9D
0005434755733	10684	31	9E
0005434214230	10684	32	9F
0005434214232	10684	33	10C
0005434755839	10684	34	10A
0005434755816	10684	35	10D
0005434755743	10684	36	10E
0005434214229	10684	37	10F
0005434214241	10684	38	11A
0005434755866	10684	39	11C
0005434214255	10684	40	11D
0005434755843	10684	41	11F
0005434214257	10684	42	12A
0005434755736	10684	43	12C
0005434755773	10684	44	12D
0005434214227	10684	45	12E
0005434214221	10684	46	12F
0005434214251	10684	47	13A
0005434755722	10684	48	13C
0005434214253	10684	49	13D
0005434214247	10684	50	13E
0005434214258	10684	51	13F
0005434214236	10684	52	14A
0005434755818	10684	53	14D
0005434755790	10684	54	14E
0005434214225	10684	55	14F
0005434214246	10684	56	15D
0005434214254	10684	57	15C
0005434755730	10684	58	15E
0005434214226	10684	59	15F
0005434214262	10684	60	16C
0005434214243	10684	61	16D
0005434755876	10684	62	16E
0005434214223	10684	63	16F
0005434755903	10684	64	17C
0005434214244	10684	65	17F
0005434214259	10684	66	18A
0005434755838	10684	67	18C
0005434214238	10684	68	18D
0005434214266	10684	69	18E
0005434214234	10684	70	18F
0005434214261	10684	71	19A
0005434755875	10684	72	19E
0005434755815	10684	73	19F
0005434214239	10684	74	20A
0005434214248	10684	75	20C
0005434755782	10684	76	20E
0005434214260	10684	77	20F
0005434213787	28664	1	1A
0005434756156	28664	2	1C
0005434213713	28664	3	1F
0005434756128	28664	4	2A
0005434756133	28664	5	2C
0005434756163	28664	6	2D
0005434756138	28664	7	3A
0005434213808	28664	8	3C
0005434213788	28664	9	3D
0005434213898	28664	10	4A
0005434213843	28664	11	4C
0005434213865	28664	12	4D
0005434213822	28664	13	4E
0005434213723	28664	14	4F
0005434756131	28664	15	5A
0005434213710	28664	16	5E
0005434213764	28664	17	6C
0005434213844	28664	18	6D
0005434213722	28664	19	6E
0005434756144	28664	20	7A
0005434756158	28664	21	7C
0005434756135	28664	22	7D
0005434756149	28664	23	7E
0005434213737	28664	24	7F
0005434756167	28664	25	8C
0005434756125	28664	26	8D
0005434213711	28664	27	8E
0005434213724	28664	28	8F
0005434213763	28664	29	9A
0005434756151	28664	30	9D
0005434756153	28664	31	9F
0005434756119	28664	32	10C
0005434756122	28664	33	10D
0005434213703	28664	34	10E
0005434756143	28664	35	10F
0005434213789	28664	36	11A
0005434756130	28664	37	11D
0005434756148	28664	38	11C
0005434756142	28664	39	12A
0005434756136	28664	40	12C
0005434756140	28664	41	12D
0005434213730	28664	42	12E
0005434756139	28664	43	12F
0005434756137	28664	44	13A
0005434213709	28664	45	13D
0005434756162	28664	46	13E
0005434756152	28664	47	13F
0005434756166	28664	48	14A
0005434756124	28664	49	14C
0005434756129	28664	50	14E
0005434756146	28664	51	14F
0005434213866	28664	52	15A
0005434756157	28664	53	15C
0005434756126	28664	54	15D
0005434756154	28664	55	15E
0005434756121	28664	56	15F
0005434213704	28664	57	16C
0005434213708	28664	58	16D
0005434756147	28664	59	16E
0005434756145	28664	60	16F
0005434756165	28664	61	17A
0005434756120	28664	62	17D
0005434213727	28664	63	17C
0005434756160	28664	64	17E
0005434756150	28664	65	17F
0005434213702	28664	66	18A
0005434756161	28664	67	18C
0005434756132	28664	68	18E
0005434756155	28664	69	18F
0005434756134	28664	70	19A
0005434756141	28664	71	19C
0005434756127	28664	72	19D
0005434213775	28664	73	19E
0005434756164	28664	74	19F
0005434213774	28664	75	20A
0005434756123	28664	76	20D
0005434756159	28664	77	20E
0005434213714	28664	78	20F
0005435039353	5469	1	1A
0005435039342	5469	2	1C
0005434229079	5469	3	1D
0005435039387	5469	4	2A
0005435043279	5469	5	1F
0005434229090	5469	6	2D
0005435039343	5469	7	2F
0005435006885	5469	8	3C
0005435039364	5469	9	3A
0005434229080	5469	10	3D
0005434229091	5469	11	3F
0005434229119	5469	12	4A
0005435039394	5469	13	4C
0005435039391	5469	14	4E
0005435006875	5469	15	4D
0005435039389	5469	16	5A
0005435006876	5469	17	4F
0005435006887	5469	18	5C
0005435006878	5469	19	5B
0005435039345	5469	20	5D
0005435039332	5469	21	5E
0005435039384	5469	22	5F
0005435039392	5469	23	6B
0005435039396	5469	24	6A
0005435006877	5469	25	6D
0005435039361	5469	26	6C
0005435042842	5469	27	6F
0005434229032	5469	28	7B
0005435039393	5469	29	7A
0005435039348	5469	30	7C
0005435039333	5469	31	7D
0005435043278	5469	32	7F
0005435039366	5469	33	7E
0005434229030	5469	34	8A
0005435039337	5469	35	8B
0005435039362	5469	36	8C
0005435039358	5469	37	8E
0005435039360	5469	38	8D
0005435039331	5469	39	8F
0005435006872	5469	40	9A
0005435039350	5469	41	9C
0005434229031	5469	42	9B
0005435006868	5469	43	9D
0005435039354	5469	44	9F
0005435039339	5469	45	9E
0005434229052	5469	46	10C
0005435006870	5469	47	10B
0005435039386	5469	48	10E
0005435039376	5469	49	10D
0005435006869	5469	50	11A
0005434229033	5469	51	11B
0005435006871	5469	52	11D
0005435006882	5469	53	11C
0005435039371	5469	54	11F
0005435006892	5469	55	11E
0005435039330	5469	56	12B
0005435006874	5469	57	12A
0005435039395	5469	58	12C
0005435039374	5469	59	12E
0005435039338	5469	60	12D
0005435042841	5469	61	12F
0005435006891	5469	62	13B
0005435039351	5469	63	13D
0005435039372	5469	64	13E
0005432125408	5469	65	13F
0005432125407	5469	66	14A
0005435043280	5469	67	14B
0005434229014	5469	68	14D
0005435039335	5469	69	14C
0005435006884	5469	70	14E
0005434229024	5469	71	14F
0005435039388	5469	72	15A
0005435039385	5469	73	15C
0005435006879	5469	74	15B
0005434229022	5469	75	15D
0005435006890	5469	76	15F
0005435039370	5469	77	15E
0005435042840	5469	78	16A
0005432125404	5469	79	16B
0005435006888	5469	80	16C
0005435039334	5469	81	16D
0005435006880	5469	82	16F
0005435006886	5469	83	16E
0005435039369	5469	84	17A
0005435039377	5469	85	17B
0005435039383	5469	86	17C
0005435039344	5469	87	17E
0005435039357	5469	88	17D
0005435006881	5469	89	17F
0005435039340	5469	90	18A
0005435039378	5469	91	18B
0005435039352	5469	92	18C
0005435042839	5469	93	18E
0005435006883	5469	94	18D
0005435039359	5469	95	18F
0005435039379	5469	96	19A
0005435006889	5469	97	19C
0005434228999	5469	98	19B
0005432125405	5469	99	19D
0005435039365	5469	100	19F
0005434229141	5469	101	19E
0005435039382	5469	102	20A
0005435006873	5469	103	20D
0005435039356	5469	104	20C
0005434229093	5469	105	20E
0005435039341	5469	106	20F
0005434229120	5469	107	21B
0005434229075	5469	108	21A
0005435039336	5469	109	21C
0005434229015	5469	110	21D
0005435039347	5469	111	21F
0005435039373	5469	112	21E
0005435039363	5469	113	22B
0005435039368	5469	114	22A
0005435039390	5469	115	22C
0005435039381	5469	116	22E
0005435039349	5469	117	22D
0005435039375	5469	118	23A
0005435039367	5469	119	22F
0005435042843	5469	120	23B
0005435039380	5469	121	23D
0005432125406	5469	122	23C
0005435039346	5469	123	23E
0005435039355	5469	124	23F
0005435006651	12962	1	1A
0005435038997	12962	2	1C
0005435006645	12962	3	1D
0005435039054	12962	4	2A
0005435038930	12962	5	1F
0005435038854	12962	6	2D
0005435043273	12962	7	3A
0005435038832	12962	8	3D
0005434229231	12962	9	3C
0005435039053	12962	10	3F
0005432304374	12962	11	4A
0005435038627	12962	12	4B
0005435006764	12962	13	4C
0005435006646	12962	14	4E
0005435038641	12962	15	5A
0005435038833	12962	16	5B
0005435038931	12962	17	5C
0005432304375	12962	18	5D
0005435038868	12962	19	5F
0005435038673	12962	20	5E
0005435039033	12962	21	6A
0005435038831	12962	22	6D
0005435038783	12962	23	6E
0005434229229	12962	24	6F
0005435006650	12962	25	7A
0005434229237	12962	26	7C
0005434229220	12962	27	7D
0005435006666	12962	28	7F
0005435039115	12962	29	8B
0005435038863	12962	30	8C
0005435038864	12962	31	8D
0005434229227	12962	32	8E
0005434229230	12962	33	9A
0005434229242	12962	34	8F
0005435038933	12962	35	9B
0005435038615	12962	36	9D
0005434229225	12962	37	9C
0005434229235	12962	38	9E
0005435006724	12962	39	9F
0005434229239	12962	40	10C
0005435038867	12962	41	10B
0005432304373	12962	42	10D
0005435038823	12962	43	11A
0005435038661	12962	44	10E
0005435038645	12962	45	11B
0005434229223	12962	46	11D
0005435038723	12962	47	11E
0005435043274	12962	48	11F
0005435006672	12962	49	12B
0005434229228	12962	50	12E
0005434229221	12962	51	12D
0005435006664	12962	52	12F
0005434229238	12962	53	13A
0005435039042	12962	54	13B
0005434229224	12962	55	13D
0005435038825	12962	56	13C
0005435038689	12962	57	13F
0005435038818	12962	58	14B
0005435038897	12962	59	14D
0005435038799	12962	60	14C
0005434229226	12962	61	14E
0005435038998	12962	62	15B
0005435038936	12962	63	15A
0005435038782	12962	64	15D
0005435038686	12962	65	15E
0005435038987	12962	66	16A
0005434229232	12962	67	16B
0005435006701	12962	68	16C
0005435038920	12962	69	16E
0005434229222	12962	70	16F
0005435038923	12962	71	17B
0005434229240	12962	72	17E
0005435006675	12962	73	17D
0005435038824	12962	74	18B
0005435038724	12962	75	18C
0005434229236	12962	76	18D
0005435006702	12962	77	18F
0005435006649	12962	78	19B
0005434229233	12962	79	19C
0005435038770	12962	80	19E
0005435038743	12962	81	19F
0005435038828	12962	82	20B
0005435038742	12962	83	20E
0005435006685	12962	84	20D
0005435038944	12962	85	20F
0005435038822	12962	86	21B
0005435038910	12962	87	21D
0005435038819	12962	88	21E
0005435038646	12962	89	21F
0005435038820	12962	90	22B
0005435039114	12962	91	22C
0005435038674	12962	92	22E
0005435038836	12962	93	22D
0005434229241	12962	94	23A
0005435038614	12962	95	22F
0005435038760	12962	96	23B
0005434229234	12962	97	23C
0005435006754	12962	98	23E
0005435038919	12962	99	23D
0005432304372	12962	100	23F
0005434411746	14895	1	1C
0005434426394	14895	2	1F
0005434426391	14895	3	2A
0005434426396	14895	4	2C
0005434426410	14895	5	3A
0005434426402	14895	6	3C
0005434426392	14895	7	3F
0005435902392	14895	8	4F
0005434426408	14895	9	5C
0005432188584	14895	10	5E
0005434426395	14895	11	6E
0005434411748	14895	12	7A
0005434426388	14895	13	7C
0005434426399	14895	14	7F
0005434426405	14895	15	8A
0005435902448	14895	16	8C
0005435902423	14895	17	8D
0005435902435	14895	18	8F
0005435902416	14895	19	9A
0005435902384	14895	20	10A
0005435902437	14895	21	10D
0005434426400	14895	22	10E
0005434426398	14895	23	10F
0005435902427	14895	24	11A
0005435902428	14895	25	11D
0005432188583	14895	26	11F
0005435902385	14895	27	12A
0005434426414	14895	28	12C
0005435902397	14895	29	12F
0005434411745	14895	30	13C
0005435902445	14895	31	13D
0005434426386	14895	32	13E
0005434426390	14895	33	13F
0005434426397	14895	34	14C
0005434426401	14895	35	14D
0005434426387	14895	36	14E
0005434426393	14895	37	15A
0005434426411	14895	38	15C
0005434426412	14895	39	15E
0005435902452	14895	40	15F
0005434426406	14895	41	16A
0005435902451	14895	42	16C
0005434426413	14895	43	16D
0005434426407	14895	44	16E
0005435902391	14895	45	17A
0005434411747	14895	46	17C
0005434426404	14895	47	17D
0005435902395	14895	48	17F
0005434426389	14895	49	18A
0005434411749	14895	50	18C
0005435902436	14895	51	18D
0005432188585	14895	52	18E
0005434426409	14895	53	18F
0005434426415	14895	54	19A
0005435902409	14895	55	19C
0005434426403	14895	56	19D
0005435902488	14895	57	20F
0005434426134	20232	1	1A
0005432059493	20232	2	1F
0005434426165	20232	3	2A
0005435902589	20232	4	2D
0005434426198	20232	5	2F
0005434426135	20232	6	3A
0005434426143	20232	7	3D
0005435554161	20232	8	3F
0005432059492	20232	9	5A
0005435902593	20232	10	5C
0005434426239	20232	11	5D
0005435554162	20232	12	5E
0005432059491	20232	13	6A
0005435902602	20232	14	6C
0005434426220	20232	15	6E
0005435554159	20232	16	6F
0005434411718	20232	17	7E
0005434426155	20232	18	7F
0005434426224	20232	19	8A
0005435902598	20232	20	8C
0005434426136	20232	21	8D
0005434426126	20232	22	8E
0005435902599	20232	23	9D
0005434426144	20232	24	10E
0005434426177	20232	25	11A
0005435902588	20232	26	11E
0005435554163	20232	27	11F
0005435902596	20232	28	12A
0005434411714	20232	29	12C
0005434426093	20232	30	12D
0005435902594	20232	31	12E
0005435902592	20232	32	13A
0005434411722	20232	33	13C
0005435902585	20232	34	13F
0005435902590	20232	35	15A
0005434411713	20232	36	15D
0005434426227	20232	37	15E
0005434426088	20232	38	16A
0005435902584	20232	39	16C
0005434411703	20232	40	16D
0005435902600	20232	41	16F
0005434426138	20232	42	17A
0005435554160	20232	43	17E
0005435554158	20232	44	17F
0005434426145	20232	45	18C
0005435902601	20232	46	18A
0005435902591	20232	47	18D
0005435902595	20232	48	18E
0005435902587	20232	49	19C
0005434411723	20232	50	19D
0005435902586	20232	51	20A
0005435902597	20232	52	20D
0005435981998	26497	1	1A
0005433434362	26497	2	1C
0005435981990	26497	3	1D
0005434273055	26497	4	1F
0005433434227	26497	5	2A
0005432300221	26497	6	2C
0005435981971	26497	7	2D
0005435981994	26497	8	2F
0005433434290	26497	9	3C
0005435981967	26497	10	3D
0005435981973	26497	11	3F
0005435981966	26497	12	4A
0005435981980	26497	13	4C
0005435981992	26497	14	4D
0005435981976	26497	15	5A
0005433434254	26497	16	5C
0005435982005	26497	17	5D
0005435982009	26497	18	5F
0005433434239	26497	19	6A
0005435981986	26497	20	6C
0005435981962	26497	21	6D
0005435982012	26497	22	6E
0005433434229	26497	23	6F
0005434270178	26497	24	7A
0005435981977	26497	25	7C
0005435982008	26497	26	7D
0005433434361	26497	27	7E
0005435982006	26497	28	8A
0005435981988	26497	29	8C
0005435982001	26497	30	8D
0005435981983	26497	31	9A
0005433434200	26497	32	9C
0005435981963	26497	33	9E
0005435982007	26497	34	9F
0005433434188	26497	35	10A
0005435981982	26497	36	10C
0005433434294	26497	37	10D
0005435981964	26497	38	10E
0005435981997	26497	39	10F
0005433434228	26497	40	11A
0005433434189	26497	41	11C
0005435981985	26497	42	11D
0005432300223	26497	43	11F
0005433434226	26497	44	12A
0005435981978	26497	45	12C
0005435981984	26497	46	12D
0005432300224	26497	47	12E
0005435981981	26497	48	12F
0005435981991	26497	49	13A
0005435982013	26497	50	13C
0005435981969	26497	51	13D
0005433434348	26497	52	13E
0005435982010	26497	53	13F
0005435981999	26497	54	14A
0005435981979	26497	55	14C
0005435981987	26497	56	14D
0005435982004	26497	57	14F
0005435981989	26497	58	15A
0005435981968	26497	59	15C
0005435981993	26497	60	15F
0005435982002	26497	61	16A
0005433434240	26497	62	16C
0005434270179	26497	63	16D
0005435981972	26497	64	16E
0005434273056	26497	65	17A
0005433434201	26497	66	17C
0005433434379	26497	67	17D
0005432300222	26497	68	17E
0005435981965	26497	69	17F
0005435981975	26497	70	18A
0005433434253	26497	71	18C
0005433434295	26497	72	18D
0005435982011	26497	73	18E
0005435982000	26497	74	18F
0005434270171	26497	75	19A
0005435981970	26497	76	19C
0005435982003	26497	77	19E
0005435981995	26497	78	19F
0005435981996	26497	79	20A
0005435981974	26497	80	20C
0005432300225	26497	81	20D
0005433434524	26712	1	1A
0005433434520	26712	2	1D
0005435981532	26712	3	1F
0005433434504	26712	4	2C
0005432051109	26712	5	2D
0005435981747	26712	6	2F
0005435981537	26712	7	3A
0005435981541	26712	8	3D
0005433434519	26712	9	3F
0005434270193	26712	10	4A
0005435981637	26712	11	4C
0005435981515	26712	12	4D
0005433434513	26712	13	4E
0005433434506	26712	14	4F
0005435981568	26712	15	5A
0005435981663	26712	16	5C
0005433434512	26712	17	5D
0005435981774	26712	18	5E
0005435981600	26712	19	5F
0005434269091	26712	20	6A
0005435981683	26712	21	6D
0005435981743	26712	22	6E
0005435981591	26712	23	6F
0005435981619	26712	24	7A
0005433434503	26712	25	7C
0005435981538	26712	26	7E
0005433434521	26712	27	7F
0005435981792	26712	28	8A
0005432051108	26712	29	8C
0005435981704	26712	30	8D
0005434271299	26712	31	8F
0005435981542	26712	32	9A
0005432051110	26712	33	9C
0005433434502	26712	34	9D
0005434271300	26712	35	10D
0005433434505	26712	36	10E
0005433434514	26712	37	10F
0005433434517	26712	38	11A
0005435981636	26712	39	11D
0005435981573	26712	40	11F
0005433434500	26712	41	12A
0005435981572	26712	42	12C
0005433434518	26712	43	12D
0005434270194	26712	44	12E
0005433434522	26712	45	12F
0005435981628	26712	46	13A
0005435981671	26712	47	13C
0005433434509	26712	48	13E
0005435981569	26712	49	13F
0005433434508	26712	50	14C
0005433434499	26712	51	14D
0005435981746	26712	52	15A
0005432051111	26712	53	15C
0005435981508	26712	54	15F
0005435981612	26712	55	16A
0005433434501	26712	56	16C
0005433434498	26712	57	16E
0005433434523	26712	58	17A
0005433434507	26712	59	17D
0005435981519	26712	60	17F
0005433434510	26712	61	18A
0005433434511	26712	62	18C
0005433434497	26712	63	18D
0005435981649	26712	64	18E
0005433434515	26712	65	18F
0005435981597	26712	66	19A
0005435981584	26712	67	19C
0005433434516	26712	68	19D
0005434269090	26712	69	19E
0005435981620	26712	70	20C
0005435981570	26712	71	20D
0005435981666	26712	72	20E
0005432857861	3134	1	1A
0005432857885	3134	2	1B
0005432583889	3134	3	1D
0005432857913	3134	4	2A
0005432583878	3134	5	2B
0005432583883	3134	6	2C
0005432583881	3134	7	2D
0005432583866	3134	8	3B
0005432583886	3134	9	4A
0005432857899	3134	10	3D
0005432583871	3134	11	4B
0005432857887	3134	12	4C
0005432583873	3134	13	4D
0005432583885	3134	14	5A
0005432857859	3134	15	5B
0005432857920	3134	16	5C
0005432583879	3134	17	5D
0005432857907	3134	18	6A
0005432583868	3134	19	6B
0005432583874	3134	20	6D
0005432216253	3134	21	7A
0005432583875	3134	22	7B
0005432857860	3134	23	7C
0005432857868	3134	24	18A
0005432583877	3134	25	18B
0005432583887	3134	26	18C
0005432583876	3134	27	18D
0005432857923	3134	28	19A
0005432583867	3134	29	19B
0005432857912	3134	30	19C
0005432857909	3134	31	19D
0005432583882	3134	32	20A
0005432583869	3134	33	20B
0005432583872	3134	34	20C
0005432857918	3134	35	20D
0005432216254	3134	36	21A
0005432857869	3134	37	21B
0005432583880	3134	38	21C
0005432583890	3134	39	21D
0005432583870	3134	40	22A
0005432857932	3134	41	22B
0005432583884	3134	42	22C
0005432857921	3134	43	22D
0005432583888	3134	44	23A
0005432216255	3134	45	23B
0005432857990	31473	1	1A
0005432583719	31473	2	1B
0005432857989	31473	3	1C
0005432857997	31473	4	1D
0005432583681	31473	5	2A
0005432583584	31473	6	2B
0005432583718	31473	7	2D
0005432583601	31473	8	3A
0005432857994	31473	9	3B
0005432583691	31473	10	3C
0005432583650	31473	11	4B
0005432583666	31473	12	4C
0005432583585	31473	13	5A
0005432857993	31473	14	5B
0005432583731	31473	15	5C
0005432857988	31473	16	5D
0005432583640	31473	17	6B
0005432583698	31473	18	6C
0005432583730	31473	19	6D
0005432583716	31473	20	7A
0005432857991	31473	21	18A
0005432583600	31473	22	18B
0005432583693	31473	23	18C
0005432857986	31473	24	18D
0005432857992	31473	25	19B
0005432583740	31473	26	19D
0005432583739	31473	27	20B
0005432857995	31473	28	20C
0005432583690	31473	29	20D
0005432583672	31473	30	21B
0005432583745	31473	31	21C
0005432857987	31473	32	21D
0005432583682	31473	33	22A
0005432583673	31473	34	22B
0005432857996	31473	35	22D
0005432583734	31473	36	23A
0005432583735	31473	37	23B
0005434943294	906	1	2B
0005433255034	906	2	2D
0005434943295	906	3	3B
0005433255031	906	4	4C
0005434943291	906	5	5D
0005433255042	906	6	6A
0005433255041	906	7	7C
0005434943297	906	8	18C
0005433255033	906	9	18D
0005434943293	906	10	20A
0005434943289	906	11	20C
0005434943296	906	12	21B
0005434943290	906	13	21D
0005434943292	906	14	22B
0005433255030	906	15	22C
0005434943248	16250	1	2D
0005434943215	16250	2	3C
0005434943259	16250	3	4D
0005433255086	16250	4	5C
0005433255087	16250	5	6C
0005434943250	16250	6	6D
0005434943195	16250	7	7A
0005434943186	16250	8	7C
0005434943249	16250	9	19B
0005433255084	16250	10	19C
0005433255085	16250	11	20B
0005434943204	16250	12	22B
0005434943260	16250	13	23B
0005435858485	4321	1	1C
0005433654731	4321	2	2D
0005433654727	4321	3	3A
0005433654714	4321	4	3D
0005435858489	4321	5	4C
0005433654708	4321	6	4F
0005433654733	4321	7	5C
0005433654734	4321	8	6A
0005433654732	4321	9	6C
0005433654718	4321	10	8A
0005435858488	4321	11	7F
0005433654730	4321	12	8E
0005435858495	4321	13	10A
0005433654719	4321	14	10B
0005433654713	4321	15	10D
0005435858484	4321	16	10F
0005435858496	4321	17	11C
0005435858483	4321	18	12F
0005435858492	4321	19	12E
0005433654720	4321	20	13A
0005433654725	4321	21	13C
0005433654711	4321	22	13E
0005433654716	4321	23	13F
0005433654735	4321	24	14E
0005433654728	4321	25	15C
0005435858491	4321	26	16A
0005433654710	4321	27	17C
0005435858487	4321	28	17B
0005433654726	4321	29	17A
0005433654709	4321	30	17D
0005433654715	4321	31	18B
0005433654712	4321	32	18E
0005433654736	4321	33	18D
0005433654723	4321	34	19A
0005433654724	4321	35	18F
0005435858482	4321	36	19E
0005433654717	4321	37	19D
0005433654721	4321	38	20D
0005435858490	4321	39	21B
0005433654722	4321	40	20F
0005433654729	4321	41	21E
0005435652773	21772	1	1A
0005435652781	21772	2	1D
0005435652772	21772	3	2A
0005435652768	21772	4	2C
0005435652779	21772	5	2D
0005435652737	21772	6	3A
0005433367423	21772	7	3C
0005433367319	21772	8	3D
0005435652731	21772	9	3F
0005433367350	21772	10	4A
0005433367456	21772	11	4C
0005435652771	21772	12	4D
0005435652769	21772	13	4E
0005435652745	21772	14	4F
0005435652785	21772	15	5A
0005435652770	21772	16	5C
0005433367254	21772	17	5D
0005433367424	21772	18	5E
0005433367310	21772	19	5F
0005435652760	21772	20	6A
0005435652753	21772	21	6C
0005433367271	21772	22	6D
0005433367324	21772	23	6E
0005433367294	21772	24	6F
0005435652764	21772	25	7A
0005433367292	21772	26	7C
0005435652732	21772	27	7D
0005433367252	21772	28	7E
0005435652776	21772	29	7F
0005435652746	21772	30	8A
0005433367321	21772	31	8C
0005435652738	21772	32	8D
0005433367315	21772	33	8E
0005435652743	21772	34	8F
0005435652734	21772	35	9A
0005435652742	21772	36	9D
0005435652775	21772	37	9E
0005435652754	21772	38	10A
0005435652736	21772	39	10C
0005435652759	21772	40	10E
0005435652757	21772	41	10D
0005435652767	21772	42	10F
0005435652784	21772	43	11A
0005435652765	21772	44	11C
0005435652761	21772	45	11D
0005435652749	21772	46	11E
0005435652758	21772	47	11F
0005435652751	21772	48	12A
0005435652747	21772	49	12C
0005435652774	21772	50	12D
0005435652755	21772	51	12E
0005435652756	21772	52	12F
0005435652763	21772	53	13A
0005435652744	21772	54	13D
0005435652750	21772	55	13E
0005433367293	21772	56	14C
0005433367314	21772	57	14E
0005435652778	21772	58	14F
0005433367320	21772	59	15A
0005433367322	21772	60	15D
0005433367246	21772	61	15E
0005435652783	21772	62	15F
0005435652766	21772	63	16A
0005435652739	21772	64	16C
0005435652733	21772	65	16D
0005435652762	21772	66	16E
0005433367221	21772	67	16F
0005433367255	21772	68	17D
0005435652777	21772	69	17E
0005435652748	21772	70	17F
0005435652782	21772	71	18A
0005435652735	21772	72	18D
0005435652740	21772	73	19D
0005435652780	21772	74	19E
0005433367434	21772	75	19F
0005435652741	21772	76	20C
0005435652752	21772	77	20D
0005433367389	21772	78	20E
0005434170890	9380	1	1A
0005433763118	9380	2	1C
0005433805149	9380	3	1B
0005433805160	9380	4	1H
0005433784732	9380	5	1G
0005433784712	9380	6	2C
0005433784713	9380	7	2H
0005433763115	9380	8	2G
0005434151658	9380	9	2F
0005435269626	9380	10	3A
0005433784738	9380	11	3C
0005433805158	9380	12	3F
0005433805161	9380	13	4B
0005434170892	9380	14	4A
0005433784707	9380	15	4G
0005434151659	9380	16	5B
0005433784721	9380	17	5A
0005435269623	9380	18	5F
0005433805166	9380	19	5H
0005433805147	9380	20	9A
0005433784709	9380	21	9H
0005433784700	9380	22	11B
0005433763117	9380	23	11A
0005434151666	9380	24	11E
0005435269624	9380	25	11D
0005433805156	9380	26	11G
0005433784719	9380	27	12A
0005433784731	9380	28	12B
0005435269642	9380	29	12E
0005433805154	9380	30	12G
0005433805133	9380	31	12F
0005433805151	9380	32	13A
0005433784702	9380	33	13D
0005433805146	9380	34	13B
0005433805167	9380	35	13H
0005435269628	9380	36	14F
0005434170874	9380	37	14E
0005433763111	9380	38	15B
0005433805128	9380	39	15D
0005433805148	9380	40	15G
0005433805164	9380	41	15F
0005433805126	9380	42	15E
0005433805159	9380	43	15H
0005435269625	9380	44	16D
0005433805134	9380	45	16E
0005433805165	9380	46	16F
0005433763119	9380	47	16H
0005433805144	9380	48	17A
0005433784715	9380	49	17D
0005434170904	9380	50	17E
0005433784704	9380	51	17F
0005433805157	9380	52	17H
0005433805155	9380	53	18A
0005433805129	9380	54	18G
0005434170864	9380	55	18F
0005434270177	9380	56	19A
0005432665261	9380	57	18H
0005433805140	9380	58	19F
0005434170814	9380	59	20A
0005433784718	9380	60	20E
0005434170883	9380	61	20H
0005433784720	9380	62	20G
0005434170824	9380	63	21E
0005433784710	9380	64	21F
0005433784734	9380	65	21H
0005434170875	9380	66	22B
0005433784727	9380	67	22A
0005433763120	9380	68	22H
0005433805162	9380	69	23B
0005433805153	9380	70	23A
0005434151660	9380	71	23D
0005433763110	9380	72	23F
0005433784728	9380	73	23E
0005435269647	9380	74	23G
0005434151661	9380	75	24A
0005433763112	9380	76	23H
0005434151663	9380	77	24B
0005435269630	9380	78	24E
0005433763121	9380	79	24H
0005433805142	9380	80	25E
0005434170861	9380	81	27A
0005433784723	9380	82	25F
0005435269641	9380	83	27E
0005433784716	9380	84	27D
0005432667440	9380	85	27F
0005433763108	9380	86	27G
0005433805132	9380	87	28A
0005433805150	9380	88	28B
0005434170862	9380	89	28E
0005433784733	9380	90	28F
0005433763109	9380	91	28H
0005433805152	9380	92	29D
0005432666375	9380	93	29F
0005433784714	9380	94	29G
0005432657429	9380	95	30B
0005433784703	9380	96	30A
0005434170891	9380	97	30E
0005433805145	9380	98	31E
0005433784724	9380	99	31D
0005435269629	9380	100	31F
0005433784711	9380	101	31H
0005433805138	9380	102	32D
0005433763116	9380	103	32B
0005433784705	9380	104	32H
0005433784722	9380	105	33A
0005433784730	9380	106	33B
0005433784735	9380	107	33E
0005432657431	9380	108	33D
0005432667441	9380	109	33F
0005433805139	9380	110	33H
0005433763113	9380	111	34A
0005433805131	9380	112	34D
0005433784737	9380	113	34B
0005433763114	9380	114	34E
0005432666376	9380	115	34H
0005433805130	9380	116	35A
0005433805136	9380	117	35G
0005434170882	9380	118	36A
0005435269627	9380	119	35H
0005433784717	9380	120	36B
0005433784701	9380	121	36E
0005433805137	9380	122	36G
0005433805141	9380	123	37D
0005432657430	9380	124	37B
0005433784725	9380	125	37F
0005433805143	9380	126	37E
0005433784708	9380	127	37G
0005433784706	9380	128	38A
0005433784726	9380	129	38D
0005433784729	9380	130	38B
0005434170903	9380	131	38E
0005432665262	9380	132	38G
0005433805163	9380	133	38H
0005433805127	9380	134	39D
0005433784736	9380	135	39F
0005433805135	9380	136	39E
0005433784364	26259	1	1A
0005434170960	26259	2	1C
0005433804930	26259	3	1F
0005433763022	26259	4	1H
0005433784434	26259	5	2A
0005434170964	26259	6	2B
0005433784390	26259	7	2F
0005434151687	26259	8	2H
0005433784355	26259	9	3A
0005433804946	26259	10	3C
0005433804937	26259	11	3F
0005434170962	26259	12	3G
0005434151684	26259	13	4G
0005435269700	26259	14	4H
0005434271298	26259	15	5A
0005433763041	26259	16	5C
0005433784386	26259	17	5H
0005433784396	26259	18	9B
0005433784359	26259	19	11A
0005433762970	26259	20	11B
0005433784353	26259	21	11D
0005433804921	26259	22	11H
0005435269702	26259	23	12B
0005433804824	26259	24	12E
0005433763003	26259	25	12F
0005433784333	26259	26	13F
0005433784299	26259	27	13H
0005433784472	26259	28	14E
0005433804835	26259	29	14D
0005433784400	26259	30	14H
0005435269701	26259	31	15E
0005433784380	26259	32	15F
0005433784424	26259	33	15G
0005434170965	26259	34	16A
0005433804896	26259	35	16D
0005433762942	26259	36	16B
0005433804821	26259	37	16E
0005433804819	26259	38	16F
0005434170961	26259	39	17A
0005434151685	26259	40	17D
0005433804813	26259	41	17F
0005435269696	26259	42	17H
0005433804851	26259	43	18B
0005433762961	26259	44	18A
0005434269089	26259	45	18D
0005433762984	26259	46	18F
0005433784536	26259	47	18E
0005432666364	26259	48	18G
0005433784385	26259	49	19A
0005433804893	26259	50	19B
0005433784411	26259	51	19H
0005432657397	26259	52	19G
0005433784464	26259	53	20A
0005434170963	26259	54	20D
0005434151688	26259	55	20B
0005433804915	26259	56	20F
0005433763006	26259	57	20E
0005434151686	26259	58	20H
0005433784395	26259	59	21A
0005433804831	26259	60	21B
0005434170959	26259	61	21D
0005434170972	26259	62	22B
0005434170970	26259	63	22D
0005432666355	26259	64	22F
0005433804945	26259	65	22E
0005433784425	26259	66	22G
0005434271296	26259	67	23A
0005434170967	26259	68	23F
0005432666363	26259	69	24A
0005433784357	26259	70	24E
0005433762969	26259	71	24F
0005432657400	26259	72	24G
0005434170971	26259	73	25D
0005433804894	26259	74	27A
0005433784365	26259	75	27B
0005433762960	26259	76	27D
0005433804875	26259	77	27G
0005434270192	26259	78	28A
0005433804834	26259	79	27H
0005433784382	26259	80	28D
0005432657396	26259	81	28E
0005433804862	26259	82	29A
0005433804845	26259	83	29B
0005435269703	26259	84	29G
0005433784352	26259	85	30A
0005433784412	26259	86	29H
0005433804968	26259	87	30B
0005433804942	26259	88	30F
0005434269088	26259	89	31A
0005433784345	26259	90	30H
0005435269698	26259	91	31D
0005433784381	26259	92	31F
0005433804872	26259	93	31E
0005434170968	26259	94	32A
0005433784344	26259	95	33E
0005433762991	26259	96	33D
0005433804905	26259	97	33H
0005433804899	26259	98	34D
0005433804876	26259	99	34B
0005433804881	26259	100	34F
0005433784473	26259	101	35A
0005433784358	26259	102	35D
0005433762982	26259	103	35F
0005434270191	26259	104	35G
0005433784429	26259	105	36A
0005434170969	26259	106	36B
0005433784388	26259	107	36E
0005433763042	26259	108	36D
0005434170966	26259	109	36G
0005433763007	26259	110	37B
0005433804873	26259	111	37F
0005434271297	26259	112	38D
0005433784389	26259	113	38B
0005435269697	26259	114	38F
0005435269699	26259	115	38H
0005433784543	26259	116	39D
0005433804944	26259	117	39F
0005435135638	4900	1	4A
0005435135637	4900	2	20A
0005435135639	4900	3	20D
0005435135636	4900	4	22B
0005435135640	4900	5	22C
0005435135589	33060	1	1C
0005435135596	33060	2	2B
0005435135590	33060	3	3C
0005435135597	33060	4	6A
0005435929626	33060	5	19D
0005435135599	33060	6	20B
0005435929627	33060	7	21B
0005434983256	9456	1	2C
0005434983255	9456	2	7C
0005434983253	9456	3	21A
0005434983254	9456	4	21D
0005434983201	27340	1	1A
0005434983229	27340	2	2B
0005434983204	27340	3	3C
0005434217944	27340	4	3D
0005434983205	27340	5	5A
0005434217941	27340	6	5D
0005434217940	27340	7	6C
0005434217943	27340	8	6D
0005434983217	27340	9	7B
0005434983209	27340	10	7D
0005434983230	27340	11	18A
0005434983228	27340	12	18B
0005434217942	27340	13	21C
0005434983210	27340	14	22C
0005433985132	24243	1	1A
0005433985185	24243	2	2G
0005433959899	24243	3	2F
0005433959918	24243	4	3B
0005433959879	24243	5	4A
0005433959877	24243	6	4G
0005433985152	24243	7	9G
0005433959982	24243	8	11F
0005433959870	24243	9	12B
0005433959993	24243	10	12E
0005433960000	24243	11	12F
0005433985187	24243	12	13D
0005433959866	24243	13	13B
0005433985176	24243	14	13G
0005433959962	24243	15	14E
0005433959864	24243	16	15H
0005433959875	24243	17	16D
0005433960002	24243	18	16B
0005433985209	24243	19	16E
0005433959863	24243	20	16G
0005433959880	24243	21	17A
0005433959955	24243	22	17B
0005433985242	24243	23	17E
0005433960003	24243	24	18B
0005433959964	24243	25	18F
0005433959878	24243	26	19A
0005433959910	24243	27	19F
0005433985154	24243	28	19G
0005433959920	24243	29	19H
0005433985244	24243	30	20F
0005433959889	24243	31	20G
0005433985122	24243	32	21D
0005433959974	24243	33	21H
0005433959867	24243	34	22E
0005433959927	24243	35	23H
0005433959876	24243	36	23G
0005433959953	24243	37	24B
0005433985249	24243	38	27A
0005433960001	24243	39	25F
0005433985231	24243	40	27B
0005433959961	24243	41	27F
0005433959965	24243	42	27H
0005433985234	24243	43	28B
0005433985155	24243	44	28F
0005433959976	24243	45	28H
0005433959886	24243	46	28G
0005433985123	24243	47	29A
0005433985223	24243	48	29E
0005433985146	24243	49	30B
0005433959938	24243	50	30E
0005433959887	24243	51	31B
0005433959977	24243	52	31E
0005433959862	24243	53	31H
0005433985250	24243	54	32B
0005433985180	24243	55	32F
0005433959939	24243	56	32H
0005433985253	24243	57	33A
0005433985222	24243	58	33D
0005433985241	24243	59	33B
0005433985191	24243	60	34D
0005433985186	24243	61	34F
0005433959906	24243	62	35A
0005433985161	24243	63	35E
0005433959973	24243	64	35H
0005433985212	24243	65	36B
0005433985131	24243	66	36D
0005433959905	24243	67	37B
0005433959994	24243	68	37D
0005433959881	24243	69	38B
0005433985232	24243	70	38A
0005433959954	24243	71	38E
0005433985151	24243	72	38D
0005433959940	24243	73	38H
0005433985145	24243	74	39D
0005433959919	24243	75	39F
0005433985615	25962	1	1A
0005433985647	25962	2	2C
0005433985612	25962	3	3A
0005433985639	25962	4	2H
0005433985608	25962	5	4C
0005433985617	25962	6	4G
0005433985619	25962	7	5A
0005433960482	25962	8	5B
0005433960471	25962	9	5C
0005433960450	25962	10	5G
0005433985633	25962	11	5H
0005433985638	25962	12	9B
0005433960495	25962	13	9A
0005433960458	25962	14	9H
0005433960480	25962	15	11D
0005433960476	25962	16	12E
0005433960490	25962	17	12G
0005433960467	25962	18	13F
0005433985643	25962	19	13H
0005433960489	25962	20	14F
0005433960455	25962	21	15A
0005433985623	25962	22	15D
0005433960479	25962	23	16B
0005433960488	25962	24	16A
0005433960466	25962	25	15H
0005433960444	25962	26	16E
0005433960484	25962	27	16H
0005433985634	25962	28	16G
0005433960445	25962	29	17A
0005433985607	25962	30	17D
0005433985626	25962	31	17F
0005433960473	25962	32	17E
0005433985632	25962	33	17H
0005433985644	25962	34	18B
0005433985628	25962	35	18A
0005433960446	25962	36	18D
0005433985613	25962	37	18E
0005433960448	25962	38	18H
0005433985620	25962	39	19H
0005433960451	25962	40	20D
0005433960460	25962	41	20G
0005433985621	25962	42	21A
0005433985629	25962	43	21D
0005433985618	25962	44	21H
0005433985616	25962	45	22F
0005433985609	25962	46	22H
0005433960486	25962	47	23B
0005433960463	25962	48	23A
0005433960457	25962	49	23D
0005433960447	25962	50	23F
0005433985641	25962	51	23G
0005433985625	25962	52	24D
0005433960465	25962	53	24F
0005433960496	25962	54	24E
0005433985627	25962	55	24G
0005433960478	25962	56	27A
0005433960485	25962	57	27B
0005433985635	25962	58	27F
0005433960477	25962	59	27G
0005433960494	25962	60	28B
0005433960452	25962	61	28D
0005433960497	25962	62	28F
0005433960481	25962	63	28G
0005433960464	25962	64	29A
0005433985614	25962	65	29D
0005433960483	25962	66	29E
0005433985640	25962	67	29F
0005433960472	25962	68	29H
0005433960493	25962	69	29G
0005433960498	25962	70	30D
0005433985637	25962	71	30E
0005433985636	25962	72	30F
0005433985611	25962	73	31B
0005433960469	25962	74	31F
0005433985610	25962	75	31G
0005433960492	25962	76	32A
0005433960449	25962	77	31H
0005433985606	25962	78	32E
0005433985645	25962	79	32G
0005433960475	25962	80	33D
0005433985630	25962	81	33G
0005433985642	25962	82	34E
0005433960456	25962	83	34G
0005433960491	25962	84	35A
0005433960454	25962	85	35B
0005433960462	25962	86	35E
0005433960453	25962	87	35G
0005433960461	25962	88	35H
0005433960459	25962	89	36A
0005433985624	25962	90	36D
0005433960443	25962	91	36F
0005433960470	25962	92	36H
0005433960468	25962	93	37D
0005433960474	25962	94	37B
0005433960487	25962	95	37F
0005433985622	25962	96	38B
0005433985631	25962	97	38F
0005433985646	25962	98	39F
0005433165684	928	1	1A
0005433165806	928	2	1C
0005433165768	928	3	1D
0005434480168	928	4	2A
0005432269478	928	5	2B
0005433165690	928	6	2C
0005433165773	928	7	2D
0005434480160	928	8	3A
0005434480175	928	9	3B
0005433165753	928	10	3C
0005434480173	928	11	4A
0005434480177	928	12	4B
0005434480164	928	13	4C
0005434480166	928	14	4D
0005434480167	928	15	5A
0005433165689	928	16	5B
0005434480163	928	17	6A
0005434480172	928	18	6B
0005434480181	928	19	6C
0005434480180	928	20	6D
0005434480178	928	21	7A
0005434480182	928	22	7B
0005434480171	928	23	7C
0005434480174	928	24	7D
0005434480185	928	25	18A
0005434480162	928	26	18C
0005434480176	928	27	18D
0005433165697	928	28	19A
0005434480161	928	29	19C
0005434480179	928	30	19D
0005433165685	928	31	20B
0005432269477	928	32	20D
0005433165731	928	33	21A
0005434480184	928	34	21B
0005434480183	928	35	21C
0005433165752	928	36	21D
0005434480165	928	37	22B
0005434480170	928	38	22C
0005434480169	928	39	22D
0005433165805	928	40	23A
0005432269476	928	41	23B
0005434480002	16580	1	1A
0005434479921	16580	2	1B
0005434479995	16580	3	1C
0005434479967	16580	4	2A
0005433165828	16580	5	2B
0005434480001	16580	6	2C
0005434479968	16580	7	2D
0005434479978	16580	8	3A
0005434479991	16580	9	3B
0005433165823	16580	10	3C
0005434479996	16580	11	3D
0005433165824	16580	12	4A
0005433165819	16580	13	4B
0005434479975	16580	14	4C
0005434479963	16580	15	4D
0005434479969	16580	16	5A
0005433165821	16580	17	5B
0005434479980	16580	18	5C
0005434479979	16580	19	5D
0005434479935	16580	20	6A
0005434479974	16580	21	6B
0005434479954	16580	22	6C
0005434479960	16580	23	6D
0005434480075	16580	24	7A
0005434479992	16580	25	7B
0005433165826	16580	26	7C
0005434479997	16580	27	7D
0005433165822	16580	28	18B
0005433165817	16580	29	18C
0005434480073	16580	30	18D
0005434479966	16580	31	19A
0005434479884	16580	32	19C
0005434480074	16580	33	19D
0005433165818	16580	34	20A
0005434479951	16580	35	20B
0005434480028	16580	36	20C
0005434480019	16580	37	20D
0005434479939	16580	38	21A
0005433165816	16580	39	21B
0005433165825	16580	40	21C
0005434479885	16580	41	22A
0005433165827	16580	42	21D
0005434479886	16580	43	22B
0005434479882	16580	44	22C
0005434479999	16580	45	22D
0005433165820	16580	46	23A
0005433872463	3208	1	2D
0005433872461	3208	2	3A
0005433872464	3208	3	3D
0005433872462	3208	4	7C
0005433872460	3208	5	19B
0005433872466	3208	6	20D
0005433872465	3208	7	23A
0005433872434	32545	1	1B
0005433872428	32545	2	18C
0005433872442	32545	3	19A
0005433872438	32545	4	19D
0005435142476	10343	1	1A
0005433289744	10343	2	1B
0005435142487	10343	3	1C
0005433289743	10343	4	1D
0005433289759	10343	5	2A
0005435386476	10343	6	2B
0005435142483	10343	7	2D
0005435149935	10343	8	3A
0005435142486	10343	9	3B
0005435142475	10343	10	3D
0005435142480	10343	11	4A
0005435142484	10343	12	4C
0005435149936	10343	13	4D
0005435142477	10343	14	5A
0005433289760	10343	15	5C
0005435149930	10343	16	5D
0005435142481	10343	17	6A
0005433289740	10343	18	6B
0005435386477	10343	19	6C
0005435386499	10343	20	6D
0005435142474	10343	21	7A
0005435149928	10343	22	7B
0005435149934	10343	23	7C
0005435149929	10343	24	18A
0005435142482	10343	25	18B
0005435149933	10343	26	18C
0005433289733	10343	27	18D
0005433289741	10343	28	19B
0005435149927	10343	29	20D
0005433289734	10343	30	21C
0005435142478	10343	31	22A
0005435142479	10343	32	22B
0005433289761	10343	33	22C
0005435149932	10343	34	22D
0005435149931	10343	35	23A
0005435142485	10343	36	23B
0005435142372	21924	1	1A
0005435142381	21924	2	1B
0005435149796	21924	3	1C
0005433289809	21924	4	2A
0005435149805	21924	5	2C
0005433289812	21924	6	2D
0005435386531	21924	7	3A
0005435386532	21924	8	3B
0005433289808	21924	9	3C
0005435386534	21924	10	4B
0005435149787	21924	11	4C
0005435386536	21924	12	4D
0005435149806	21924	13	5C
0005435142353	21924	14	5D
0005435142373	21924	15	6A
0005435149862	21924	16	6B
0005435386535	21924	17	6D
0005435386533	21924	18	7B
0005435149863	21924	19	7C
0005435149826	21924	20	7D
0005435149849	21924	21	18B
0005433289810	21924	22	18D
0005435142380	21924	23	19A
0005435142397	21924	24	19B
0005433289811	21924	25	19C
0005435149850	21924	26	19D
0005435149807	21924	27	20B
0005435149795	21924	28	20C
0005435149861	21924	29	20D
0005435142379	21924	30	21A
0005435149788	21924	31	21B
0005435142389	21924	32	21D
0005435386538	21924	33	22A
0005435149800	21924	34	22D
0005435386537	21924	35	23A
0005435502013	11233	1	1C
0005434573247	11233	2	1F
0005435501959	11233	3	2A
0005435528937	11233	4	2D
0005434573253	11233	5	2F
0005434573254	11233	6	3A
0005435501966	11233	7	3C
0005435528936	11233	8	3D
0005434573258	11233	9	3F
0005435319449	11233	10	4A
0005434573260	11233	11	4C
0005435501953	11233	12	4D
0005435528961	11233	13	4F
0005434573252	11233	14	5A
0005435502091	11233	15	5C
0005434573250	11233	16	5D
0005435528903	11233	17	5E
0005435528978	11233	18	5F
0005435528911	11233	19	6A
0005435528962	11233	20	6D
0005435528979	11233	21	6E
0005435502065	11233	22	6F
0005435528881	11233	23	7C
0005435501958	11233	24	7D
0005435501954	11233	25	7F
0005435501933	11233	26	8C
0005435319471	11233	27	8D
0005435545616	11233	28	8E
0005435501975	11233	29	8F
0005435528988	11233	30	9A
0005434573259	11233	31	9D
0005434573256	11233	32	9E
0005435319444	11233	33	9F
0005435502014	11233	34	10A
0005435529011	11233	35	10C
0005435528982	11233	36	10D
0005435502016	11233	37	11A
0005435319448	11233	38	11C
0005435501932	11233	39	11E
0005434573249	11233	40	12A
0005435502089	11233	41	12E
0005435528963	11233	42	12F
0005435528987	11233	43	13A
0005435319454	11233	44	13C
0005435502004	11233	45	13E
0005435319461	11233	46	13F
0005434573248	11233	47	14C
0005435319475	11233	48	14E
0005434573257	11233	49	14F
0005435319438	11233	50	15A
0005435528948	11233	51	15C
0005435502015	11233	52	15D
0005435528912	11233	53	15E
0005434573255	11233	54	16A
0005435528924	11233	55	16E
0005435501986	11233	56	16F
0005435529012	11233	57	17C
0005435319447	11233	58	17F
0005435528932	11233	59	18A
0005435501990	11233	60	18C
0005435319456	11233	61	18D
0005435528943	11233	62	18E
0005435528949	11233	63	19D
0005434573246	11233	64	19E
0005435528923	11233	65	19F
0005435502090	11233	66	20A
0005435528990	11233	67	20C
0005434573251	11233	68	20D
0005435502160	20927	1	1A
0005435517795	20927	2	1C
0005432291914	20927	3	1D
0005434573103	20927	4	1F
0005435502163	20927	5	2A
0005435508280	20927	6	2D
0005434573104	20927	7	2F
0005435508276	20927	8	3A
0005435502168	20927	9	3C
0005435502171	20927	10	3D
0005434573120	20927	11	3F
0005432291912	20927	12	4A
0005435508283	20927	13	4C
0005435319530	20927	14	4F
0005435502169	20927	15	5A
0005435517789	20927	16	5D
0005434573101	20927	17	5F
0005435508284	20927	18	6A
0005435319527	20927	19	6F
0005435319524	20927	20	7A
0005435502166	20927	21	7C
0005435502155	20927	22	7D
0005435517791	20927	23	7E
0005435502157	20927	24	7F
0005435502170	20927	25	8A
0005434573170	20927	26	8C
0005435502173	20927	27	8D
0005435517788	20927	28	8E
0005435319525	20927	29	8F
0005435517797	20927	30	9A
0005435502156	20927	31	9D
0005434573102	20927	32	9E
0005435508277	20927	33	10A
0005435502159	20927	34	10C
0005435508279	20927	35	10D
0005435502153	20927	36	10E
0005435508278	20927	37	10F
0005435517792	20927	38	11A
0005435517786	20927	39	11D
0005434573171	20927	40	11E
0005435517796	20927	41	11F
0005435508281	20927	42	12A
0005435517782	20927	43	12C
0005435502154	20927	44	12D
0005435319526	20927	45	12F
0005434573135	20927	46	13A
0005435502167	20927	47	13C
0005435319531	20927	48	13D
0005435502165	20927	49	13E
0005435517784	20927	50	13F
0005435517790	20927	51	14A
0005435517787	20927	52	14C
0005432291913	20927	53	14E
0005435517783	20927	54	14F
0005434573123	20927	55	15C
0005435319528	20927	56	15D
0005435517781	20927	57	15E
0005435517778	20927	58	15F
0005435502174	20927	59	16A
0005435319529	20927	60	16C
0005435517794	20927	61	16D
0005435517799	20927	62	16E
0005435502162	20927	63	17A
0005434573161	20927	64	17C
0005434573167	20927	65	17D
0005435502172	20927	66	17E
0005435517793	20927	67	17F
0005435517798	20927	68	18D
0005435502164	20927	69	18E
0005435502161	20927	70	18F
0005435502158	20927	71	19A
0005435517780	20927	72	19C
0005435517779	20927	73	19D
0005434573172	20927	74	19E
0005434573160	20927	75	19F
0005435508282	20927	76	20A
0005435517785	20927	77	20C
0005434573159	20927	78	20E
0005435508285	20927	79	20F
0005432692571	2896	1	1A
0005432692683	2896	2	1D
0005432692534	2896	3	3A
0005432692558	2896	4	3C
0005432692638	2896	5	4C
0005432692569	2896	6	5E
0005432692647	2896	7	6A
0005432692666	2896	8	7A
0005432692631	2896	9	7E
0005432692608	2896	10	8D
0005432692674	2896	11	8F
0005432692646	2896	12	9A
0005432692603	2896	13	12C
0005432692582	2896	14	13F
0005432692627	2896	15	16D
0005432692557	2896	16	17A
0005432692648	2896	17	17C
0005432692590	2896	18	17D
0005432692633	2896	19	17E
0005432692682	2896	20	18D
0005432692645	2896	21	19A
0005432692639	2896	22	19F
0005432692675	2896	23	20A
0005432692568	2896	24	20C
0005432692537	2896	25	20F
0005432706613	2897	1	1A
0005432706603	2897	2	1C
0005432706616	2897	3	1D
0005433194822	2897	4	1F
0005432706607	2897	5	2A
0005432880611	2897	6	2D
0005432706608	2897	7	3A
0005432706620	2897	8	3C
0005433123662	2897	9	3D
0005433123624	2897	10	3F
0005433123627	2897	11	4C
0005432706595	2897	12	4D
0005432706618	2897	13	4E
0005433123673	2897	14	4F
0005432706602	2897	15	5A
0005432706611	2897	16	5D
0005432706604	2897	17	5F
0005432706596	2897	18	6C
0005432706612	2897	19	6D
0005433123664	2897	20	6E
0005433123731	2897	21	6F
0005433123709	2897	22	7A
0005432706619	2897	23	7C
0005432706614	2897	24	7D
0005433123626	2897	25	7F
0005432706598	2897	26	8C
0005432880553	2897	27	8D
0005432706601	2897	28	8E
0005432880585	2897	29	9D
0005432706609	2897	30	10C
0005433123602	2897	31	10D
0005433123719	2897	32	10E
0005433123730	2897	33	10F
0005433123652	2897	34	11E
0005432706597	2897	35	12A
0005432706617	2897	36	12D
0005432706615	2897	37	12F
0005432706606	2897	38	13D
0005432706605	2897	39	13F
0005432880639	2897	40	14A
0005433123601	2897	41	14D
0005432706610	2897	42	14F
0005432217757	2897	43	15D
0005432880621	2897	44	15E
0005432880615	2897	45	15F
0005433123639	2897	46	16A
0005432706599	2897	47	16D
0005433194823	2897	48	16F
0005433123690	2897	49	17A
0005433123616	2897	50	17C
0005433123637	2897	51	17D
0005433123582	2897	52	17E
0005432880620	2897	53	18A
0005432217758	2897	54	18D
0005433123631	2897	55	18E
0005432880555	2897	56	18F
0005433123681	2897	57	19C
0005432706600	2897	58	19A
0005433123691	2897	59	19E
0005433194824	2897	60	19F
0005433123623	2897	61	20D
0005432706489	29942	1	1A
0005432692903	29942	2	1C
0005432880731	29942	3	1D
0005432692875	29942	4	1F
0005433123789	29942	5	2A
0005432692896	29942	6	2C
0005433123781	29942	7	2D
0005432706403	29942	8	2F
0005432692874	29942	9	3A
0005433123791	29942	10	3C
0005432706488	29942	11	3D
0005432692888	29942	12	3F
0005433123792	29942	13	4A
0005432706475	29942	14	4C
0005433194842	29942	15	4D
0005432692879	29942	16	4E
0005432706440	29942	17	4F
0005432880718	29942	18	5A
0005432692905	29942	19	5C
0005432692880	29942	20	5D
0005432880725	29942	21	5E
0005433123784	29942	22	5F
0005432880730	29942	23	6A
0005432692892	29942	24	6C
0005432706442	29942	25	6D
0005433123783	29942	26	6E
0005432692886	29942	27	7A
0005432692883	29942	28	6F
0005433123800	29942	29	7D
0005433123794	29942	30	7C
0005432692893	29942	31	7E
0005432692891	29942	32	7F
0005433123787	29942	33	8A
0005432880724	29942	34	8C
0005433194839	29942	35	8D
0005432692894	29942	36	8E
0005433123786	29942	37	8F
0005432706472	29942	38	9A
0005432880719	29942	39	9C
0005432706508	29942	40	9D
0005432880721	29942	41	9E
0005433123801	29942	42	9F
0005432880723	29942	43	10A
0005432692876	29942	44	10C
0005432692878	29942	45	10D
0005433194835	29942	46	10E
0005432706468	29942	47	10F
0005432692904	29942	48	11A
0005432692899	29942	49	11C
0005432692898	29942	50	11D
0005433123796	29942	51	11E
0005433123788	29942	52	11F
0005433123802	29942	53	12A
0005433194834	29942	54	12C
0005432880729	29942	55	12D
0005432706409	29942	56	12E
0005432692887	29942	57	12F
0005432880728	29942	58	13A
0005432706506	29942	59	13C
0005432692882	29942	60	13D
0005432692895	29942	61	13E
0005433123795	29942	62	13F
0005432692890	29942	63	14A
0005432880716	29942	64	14C
0005433123793	29942	65	14D
0005433123798	29942	66	14E
0005432692901	29942	67	14F
0005432692902	29942	68	15A
0005432880722	29942	69	15C
0005432692884	29942	70	15D
0005432692897	29942	71	15E
0005433123803	29942	72	15F
0005433194836	29942	73	16A
0005432880717	29942	74	16C
0005432692885	29942	75	16D
0005433123797	29942	76	16E
0005432706439	29942	77	16F
0005432880727	29942	78	17A
0005432706375	29942	79	17C
0005432692900	29942	80	17D
0005432880720	29942	81	17E
0005432692881	29942	82	17F
0005432692877	29942	83	18A
0005432706455	29942	84	18C
0005432880726	29942	85	18D
0005433123790	29942	86	18E
0005432706379	29942	87	18F
0005433194837	29942	88	19A
0005432706473	29942	89	19C
0005433194838	29942	90	19D
0005433194840	29942	91	19E
0005432706443	29942	92	19F
0005432692889	29942	93	20A
0005433123782	29942	94	20C
0005433123799	29942	95	20D
0005433194841	29942	96	20E
0005433123785	29942	97	20F
0005434979577	23672	1	1A
0005434979583	23672	2	1B
0005434979589	23672	3	1C
0005434979563	23672	4	1D
0005434979591	23672	5	2A
0005434988655	23672	6	2B
0005434979579	23672	7	2C
0005434979565	23672	8	2D
0005434979580	23672	9	3A
0005434979561	23672	10	3B
0005434979582	23672	11	3C
0005434988657	23672	12	3D
0005434979568	23672	13	4A
0005434988662	23672	14	4B
0005434979560	23672	15	4C
0005434979567	23672	16	4D
0005434979584	23672	17	5A
0005434979581	23672	18	5B
0005434988663	23672	19	5D
0005434988656	23672	20	6A
0005434988654	23672	21	6B
0005434979570	23672	22	6D
0005434979569	23672	23	7A
0005434988666	23672	24	7B
0005434979585	23672	25	7C
0005434979586	23672	26	7D
0005434988658	23672	27	18A
0005434979578	23672	28	18B
0005434979587	23672	29	18C
0005434988664	23672	30	18D
0005434988660	23672	31	19A
0005434979566	23672	32	19B
0005434988659	23672	33	19D
0005434979572	23672	34	20A
0005434979574	23672	35	20C
0005434988661	23672	36	20D
0005434979571	23672	37	21A
0005434979590	23672	38	21B
0005434988665	23672	39	21C
0005434979564	23672	40	21D
0005434979575	23672	41	22A
0005434979588	23672	42	22B
0005434979562	23672	43	22D
0005434979576	23672	44	23A
0005434979573	23672	45	23B
0005434979323	27565	1	1B
0005434979335	27565	2	2B
0005434979264	27565	3	2C
0005434979314	27565	4	2D
0005434979352	27565	5	3A
0005434979360	27565	6	3C
0005434979390	27565	7	3D
0005434979263	27565	8	4A
0005434988569	27565	9	5A
0005434979407	27565	10	5B
0005434979319	27565	11	5C
0005434988565	27565	12	5D
0005434979351	27565	13	6C
0005434979256	27565	14	6D
0005434979399	27565	15	7A
0005434979430	27565	16	7B
0005434979398	27565	17	7C
0005434979336	27565	18	19A
0005434979345	27565	19	19B
0005434979334	27565	20	19D
0005434988563	27565	21	20A
0005434988559	27565	22	20B
0005434988562	27565	23	20D
0005434979257	27565	24	21A
0005434988556	27565	25	21B
0005434988566	27565	26	21C
0005434979465	27565	27	22A
0005434979359	27565	28	22B
0005434979370	27565	29	22C
0005434988572	27565	30	22D
0005434979318	27565	31	23A
0005434979369	27565	32	23B
0005434302428	10257	1	2A
0005434302427	10257	2	2C
0005434302429	10257	3	3B
0005433113499	10257	4	5B
0005433113497	10257	5	5D
0005433111470	10257	6	20D
0005433113498	10257	7	23B
0005434302383	19619	1	5D
0005434302384	19619	2	22A
0005435718913	3554	1	1A
0005435068783	3554	2	1C
0005435718916	3554	3	1D
0005435068779	3554	4	1F
0005435718909	3554	5	2D
0005435068766	3554	6	2C
0005435068763	3554	7	2F
0005435068764	3554	8	3A
0005435068788	3554	9	3C
0005435068780	3554	10	3D
0005435068793	3554	11	3F
0005435068743	3554	12	4A
0005435068752	3554	13	4C
0005435068756	3554	14	4F
0005435068790	3554	15	5C
0005435068755	3554	16	5D
0005435068774	3554	17	5E
0005435925046	3554	18	5F
0005435068762	3554	19	6A
0005435068787	3554	20	6C
0005435068773	3554	21	6D
0005435925120	3554	22	6E
0005435068758	3554	23	7C
0005435068761	3554	24	7D
0005435068741	3554	25	7F
0005435068771	3554	26	8A
0005435068765	3554	27	8C
0005435068775	3554	28	8D
0005435068751	3554	29	8E
0005435925069	3554	30	8F
0005435068760	3554	31	9A
0005435718915	3554	32	9C
0005435925051	3554	33	9D
0005435068750	3554	34	9E
0005435718912	3554	35	9F
0005435068772	3554	36	10A
0005435068781	3554	37	10C
0005435068789	3554	38	10D
0005435068748	3554	39	10F
0005435925110	3554	40	11C
0005435925092	3554	41	11D
0005435925052	3554	42	12A
0005435068746	3554	43	12C
0005435068757	3554	44	12D
0005435718911	3554	45	12E
0005435068744	3554	46	13A
0005435068782	3554	47	13D
0005435068770	3554	48	13F
0005435925085	3554	49	14A
0005435068742	3554	50	14C
0005435068768	3554	51	14D
0005435925119	3554	52	14F
0005435068792	3554	53	15A
0005435068749	3554	54	15C
0005435925115	3554	55	15D
0005435925098	3554	56	15F
0005435068791	3554	57	16A
0005435925075	3554	58	16C
0005435068747	3554	59	16D
0005435718914	3554	60	16E
0005435718910	3554	61	16F
0005435925072	3554	62	17A
0005435068767	3554	63	17C
0005435068745	3554	64	17E
0005435718917	3554	65	18A
0005435925111	3554	66	18C
0005435068778	3554	67	18E
0005435068759	3554	68	19A
0005435068754	3554	69	18F
0005435068753	3554	70	19C
0005435068785	3554	71	19D
0005435068786	3554	72	19F
0005435068769	3554	73	20A
0005435068784	3554	74	20C
0005435068777	3554	75	20D
0005435068776	3554	76	20F
0005435068331	15290	1	1A
0005435939870	15290	2	1D
0005435939867	15290	3	1F
0005435068365	15290	4	2A
0005435925201	15290	5	3A
0005435068170	15290	6	3C
0005435068171	15290	7	3D
0005435925203	15290	8	3F
0005435068364	15290	9	4A
0005435068289	15290	10	4C
0005435925195	15290	11	4F
0005435068281	15290	12	5A
0005435068215	15290	13	5C
0005435068385	15290	14	5D
0005435068302	15290	15	5F
0005435068315	15290	16	6D
0005435925196	15290	17	6F
0005435068291	15290	18	7A
0005435068200	15290	19	7D
0005435068323	15290	20	7F
0005435068358	15290	21	8A
0005435068276	15290	22	8C
0005435925199	15290	23	8E
0005435068255	15290	24	8F
0005435068402	15290	25	9A
0005435939866	15290	26	9C
0005435068224	15290	27	9D
0005435068360	15290	28	9E
0005435068470	15290	29	9F
0005435068336	15290	30	10C
0005435925200	15290	31	10E
0005435068363	15290	32	11A
0005435068528	15290	33	11C
0005435925197	15290	34	11E
0005435925194	15290	35	11F
0005435068167	15290	36	12C
0005435068329	15290	37	12F
0005435925192	15290	38	13A
0005435068277	15290	39	13C
0005435925198	15290	40	13E
0005435068394	15290	41	14A
0005435068301	15290	42	14D
0005435068520	15290	43	14F
0005435068207	15290	44	15A
0005435925202	15290	45	15D
0005435068290	15290	46	15E
0005435068425	15290	47	16A
0005435068403	15290	48	16C
0005435068519	15290	49	16E
0005435068166	15290	50	16F
0005435068314	15290	51	17D
0005435068223	15290	52	17E
0005435939869	15290	53	18C
0005435068222	15290	54	18E
0005435068527	15290	55	19A
0005435068426	15290	56	19C
0005435925193	15290	57	19F
0005435068357	15290	58	20A
0005435939868	15290	59	20C
0005435068237	15290	60	20D
0005432659693	18162	1	1A
0005432658578	18162	2	3B
0005432659692	18162	3	4B
0005432660805	18162	4	5B
0005432660804	18162	5	6B
0005432660786	26343	1	2B
0005432667419	26343	2	3B
0005432660787	26343	3	6B
0005432919507	181	1	1A
0005433101314	181	2	1F
0005433101316	181	3	1D
0005432901386	181	4	2A
0005432901330	181	5	2C
0005432901402	181	6	2F
0005433101320	181	7	3D
0005433101202	181	8	3C
0005433101303	181	9	4A
0005432919525	181	10	4C
0005433101184	181	11	4F
0005432919550	181	12	5C
0005432901338	181	13	6A
0005432919587	181	14	6C
0005432919509	181	15	7C
0005432919607	181	16	7F
0005433101236	181	17	8C
0005433101167	181	18	8B
0005432901334	181	19	8F
0005432901341	181	20	9A
0005432901374	181	21	9F
0005433101149	181	22	9E
0005432901419	181	23	10A
0005433101315	181	24	10C
0005433101309	181	25	10D
0005432919586	181	26	11A
0005433101376	181	27	10F
0005432919629	181	28	11C
0005432919526	181	29	11B
0005432919508	181	30	11F
0005433101161	181	31	12A
0005433101246	181	32	12C
0005433101185	181	33	12F
0005433101221	181	34	12E
0005433101174	181	35	13B
0005433101201	181	36	13A
0005433101381	181	37	13D
0005432919545	181	38	13E
0005432919605	181	39	14B
0005433101223	181	40	14C
0005433101346	181	41	15B
0005433101363	181	42	15A
0005432919585	181	43	15E
0005432919510	181	44	17B
0005433101220	181	45	17A
0005433101283	181	46	17D
0005433101234	181	47	17F
0005432919620	181	48	18B
0005432919584	181	49	18C
0005433101384	181	50	18F
0005433101166	181	51	19B
0005432919595	181	52	19E
0005433101343	181	53	20B
0005432901385	181	54	20C
0005433101380	181	55	20E
0005432919606	181	56	21B
0005432901372	181	57	21C
0005432677512	181	58	21E
0005433101370	181	59	21F
0005433101302	181	60	22E
0005433101300	181	61	23C
0005433101347	181	62	24F
0005433101199	181	63	25A
0005432901333	181	64	25D
0005433101198	181	65	26A
0005432901384	181	66	26C
0005432901375	181	67	26B
0005432677511	181	68	26E
0005432919596	181	69	26F
0005433101197	181	70	27D
0005433101162	181	71	27C
0005433101304	181	72	28C
0005432157481	181	73	28B
0005432157480	181	74	28D
0005432157479	181	75	29A
0005433101321	181	76	28F
0005433101367	181	77	29B
0005433101250	181	78	30A
0005432901358	181	79	29F
0005433101222	181	80	31C
0005433101369	181	81	31B
0005433101150	181	82	31D
0005433101313	181	83	31F
0005432261610	183	1	1A
0005432261614	183	2	1D
0005432817290	183	3	2A
0005432261629	183	4	3A
0005432817294	183	5	2F
0005432207644	183	6	3C
0005432817283	183	7	4A
0005432817296	183	8	3F
0005432288966	183	9	4C
0005432817291	183	10	5A
0005432261615	183	11	5C
0005432261606	183	12	5F
0005432261644	183	13	5D
0005432817299	183	14	6A
0005432261643	183	15	6F
0005432261639	183	16	7A
0005432753254	183	17	8A
0005432261646	183	18	8B
0005432817286	183	19	8C
0005432817285	183	20	8E
0005432817298	183	21	9B
0005432261617	183	22	9D
0005432817287	183	23	10B
0005432261616	183	24	10C
0005432261634	183	25	10D
0005432817276	183	26	10F
0005432261622	183	27	11F
0005432817301	183	28	12D
0005432261647	183	29	12C
0005432756788	183	30	12E
0005432817274	183	31	13B
0005432817280	183	32	13E
0005432207645	183	33	14A
0005432261612	183	34	14E
0005432261608	183	35	14F
0005432261633	183	36	15A
0005432261645	183	37	15C
0005432261641	183	38	15F
0005432261626	183	39	16B
0005432817281	183	40	16D
0005432261635	183	41	16F
0005432261623	183	42	17A
0005432756807	183	43	17B
0005432288964	183	44	17D
0005432817293	183	45	17F
0005432753244	183	46	18A
0005432817300	183	47	18B
0005432817273	183	48	18F
0005432207643	183	49	19E
0005432261603	183	50	20B
0005432261619	183	51	20C
0005432261605	183	52	20D
0005432261609	183	53	21C
0005432288965	183	54	21B
0005432261611	183	55	21F
0005432753251	183	56	22B
0005432756789	183	57	22D
0005433687683	183	58	23B
0005432817284	183	59	23E
0005432261632	183	60	24A
0005432261642	183	61	24B
0005432817297	183	62	24C
0005432817275	183	63	24E
0005432261631	183	64	24D
0005432207642	183	65	24F
0005432817289	183	66	25A
0005432261624	183	67	25C
0005432261648	183	68	25B
0005432817282	183	69	25D
0005432261613	183	70	25F
0005432261630	183	71	26A
0005432261627	183	72	26B
0005432261640	183	73	26E
0005432817278	183	74	26D
0005432261638	183	75	26F
0005432817271	183	76	27A
0005432261607	183	77	27C
0005432817279	183	78	27B
0005432817277	183	79	27F
0005432261637	183	80	27E
0005432817272	183	81	28A
0005432817295	183	82	28B
0005432261604	183	83	28D
0005432753253	183	84	28E
0005432817288	183	85	29B
0005432261628	183	86	29C
0005432261618	183	87	29E
0005432261620	183	88	30C
0005432261621	183	89	30A
0005432817292	183	90	31A
0005432261625	183	91	31D
0005432261636	183	92	31E
0005433101829	7930	1	1C
0005433101839	7930	2	1F
0005432020085	7930	3	1D
0005433101794	7930	4	2A
0005433101815	7930	5	2C
0005433101821	7930	6	2D
0005432919730	7930	7	3D
0005432919718	7930	8	3C
0005433101803	7930	9	4A
0005432751505	7930	10	3F
0005432020090	7930	11	4C
0005433101830	7930	12	4F
0005432919727	7930	13	4D
0005433101827	7930	14	5A
0005432919724	7930	15	5C
0005432044507	7930	16	5F
0005433101819	7930	17	5D
0005432044506	7930	18	6A
0005432020091	7930	19	6C
0005433101792	7930	20	6F
0005432751506	7930	21	7D
0005433101826	7930	22	7C
0005433101797	7930	23	8A
0005432751508	7930	24	8C
0005432751507	7930	25	8B
0005433101823	7930	26	8D
0005432020107	7930	27	8E
0005432391980	7930	28	8F
0005432753279	7930	29	9A
0005432020097	7930	30	9C
0005432391981	7930	31	9B
0005433101791	7930	32	9D
0005432020092	7930	33	9F
0005432020083	7930	34	10B
0005433101795	7930	35	10D
0005432919725	7930	36	10C
0005432020087	7930	37	10E
0005433101814	7930	38	11B
0005433101805	7930	39	11A
0005433101790	7930	40	11C
0005433101793	7930	41	11E
0005432020098	7930	42	11F
0005433101811	7930	43	12B
0005433101836	7930	44	12C
0005433101784	7930	45	12E
0005432020102	7930	46	12F
0005433101837	7930	47	13A
0005432677550	7930	48	13C
0005432753280	7930	49	13B
0005432045603	7930	50	13D
0005432919728	7930	51	13F
0005433101786	7930	52	14B
0005433101799	7930	53	14A
0005432677551	7930	54	14C
0005432919723	7930	55	14D
0005432919719	7930	56	14F
0005433101812	7930	57	15B
0005432919721	7930	58	15C
0005433101822	7930	59	15D
0005433101828	7930	60	15E
0005432677548	7930	61	16C
0005433101813	7930	62	16B
0005432020089	7930	63	16D
0005433101809	7930	64	16F
0005433101789	7930	65	17A
0005432919726	7930	66	17C
0005433101831	7930	67	17B
0005433101824	7930	68	18A
0005432919731	7930	69	17F
0005432020093	7930	70	18D
0005432020082	7930	71	18C
0005433101835	7930	72	18E
0005432391982	7930	73	19B
0005432020099	7930	74	19D
0005432919735	7930	75	19C
0005432020101	7930	76	20A
0005433101788	7930	77	20D
0005433101800	7930	78	20F
0005433101820	7930	79	20E
0005432020086	7930	80	21B
0005432020080	7930	81	21C
0005433101808	7930	82	21E
0005433101798	7930	83	21D
0005433101807	7930	84	21F
0005433101834	7930	85	22B
0005433101818	7930	86	22A
0005433101838	7930	87	22E
0005433101841	7930	88	22D
0005432919737	7930	89	23A
0005432753281	7930	90	23C
0005432045602	7930	91	23B
0005432919729	7930	92	23D
0005432919732	7930	93	23E
0005432020095	7930	94	24A
0005432753282	7930	95	23F
0005432020081	7930	96	24B
0005432919734	7930	97	24C
0005433101810	7930	98	24E
0005432919736	7930	99	24F
0005432919722	7930	100	25A
0005432044508	7930	101	25C
0005432020105	7930	102	25B
0005433101816	7930	103	25E
0005433101833	7930	104	25F
0005432020104	7930	105	26C
0005432919717	7930	106	26A
0005432020094	7930	107	26D
0005433101785	7930	108	26F
0005433101787	7930	109	27B
0005432020096	7930	110	27A
0005432020100	7930	111	27C
0005432677549	7930	112	27D
0005432919720	7930	113	28A
0005432919733	7930	114	28C
0005433101804	7930	115	28D
0005433101801	7930	116	28E
0005432753283	7930	117	29C
0005432391983	7930	118	29D
0005432020084	7930	119	29E
0005433101825	7930	120	30A
0005433101842	7930	121	29F
0005432020106	7930	122	30B
0005433101832	7930	123	30D
0005433101817	7930	124	30E
0005433101802	7930	125	31A
0005433101840	7930	126	30F
0005432020088	7930	127	31B
0005432020103	7930	128	31C
0005433101796	7930	129	31D
0005433101806	7930	130	31F
0005432045601	7930	131	31E
0005432816962	7929	1	1D
0005432816971	7929	2	2D
0005432901496	7929	3	3C
0005432817073	7929	4	3D
0005432816970	7929	5	5A
0005432817034	7929	6	4F
0005432817033	7929	7	6A
0005434513546	7929	8	6C
0005432901508	7929	9	7A
0005432901501	7929	10	7D
0005432901492	7929	11	8A
0005432817056	7929	12	9A
0005432817088	7929	13	9C
0005432816949	7929	14	9D
0005434513545	7929	15	9F
0005432817017	7929	16	10E
0005432816979	7929	17	10D
0005434513537	7929	18	11A
0005432901503	7929	19	10F
0005432817027	7929	20	11C
0005432816941	7929	21	11B
0005432901494	7929	22	12A
0005434513543	7929	23	12D
0005432002063	7929	24	12C
0005432901499	7929	25	12E
0005432817084	7929	26	13D
0005432901498	7929	27	14A
0005432901502	7929	28	14F
0005432817096	7929	29	15A
0005432817011	7929	30	15D
0005434513538	7929	31	16B
0005434513542	7929	32	16E
0005432817047	7929	33	16F
0005432901507	7929	34	17A
0005432901493	7929	35	17E
0005432817071	7929	36	18A
0005432816983	7929	37	19C
0005432816950	7929	38	20A
0005432901495	7929	39	20C
0005432816942	7929	40	20F
0005432817055	7929	41	20E
0005432816978	7929	42	21D
0005432002062	7929	43	22D
0005432817167	7929	44	22C
0005432816951	7929	45	22F
0005434513539	7929	46	22E
0005432817018	7929	47	23A
0005432002064	7929	48	23D
0005432817097	7929	49	24A
0005432816956	7929	50	24B
0005432901504	7929	51	24E
0005432901506	7929	52	25F
0005432901500	7929	53	26C
0005432817057	7929	54	26E
0005432901497	7929	55	29A
0005432816984	7929	56	29D
0005432817087	7929	57	30A
0005432817168	7929	58	29F
0005432901505	7929	59	30B
0005432817006	7929	60	30F
0005432817026	7929	61	31B
0005433870717	9661	1	1A
0005433870716	9661	2	5A
0005434175726	32355	1	1B
0005433870700	32355	2	2B
0005434175724	32355	3	4A
0005434175725	32355	4	4B
0005434175728	32355	5	5A
0005434175727	32355	6	6A
0005435902498	3477	1	1C
0005435913853	3477	2	1H
0005435126133	3477	3	1D
0005435126113	3477	4	2A
0005434877637	3477	5	1K
0005434877652	3477	6	2H
0005434877653	3477	7	2G
0005434426434	3477	8	3C
0005434426421	3477	9	3H
0005434877644	3477	10	3G
0005432799292	3477	11	4C
0005432613838	3477	12	4G
0005432611685	3477	13	4D
0005434877716	3477	14	5D
0005435126124	3477	15	5C
0005434877622	3477	16	5A
0005434877624	3477	17	5H
0005435626065	3477	18	5G
0005435126123	3477	19	11A
0005434877683	3477	20	5K
0005432799298	3477	21	11F
0005435626064	3477	22	11E
0005432188586	3477	23	11K
0005432799301	3477	24	11H
0005435626061	3477	25	12C
0005432188588	3477	26	12A
0005434877693	3477	27	12D
0005432611687	3477	28	12G
0005434877674	3477	29	12F
0005435126117	3477	30	13D
0005435126125	3477	31	13A
0005435126110	3477	32	13F
0005432611688	3477	33	13G
0005435126141	3477	34	14C
0005432799281	3477	35	14A
0005435902417	3477	36	13K
0005435126143	3477	37	14E
0005432613837	3477	38	14F
0005435902415	3477	39	14H
0005435126115	3477	40	15C
0005432799277	3477	41	15A
0005434877664	3477	42	15E
0005434877711	3477	43	15G
0005435126131	3477	44	15F
0005432799272	3477	45	16A
0005434877641	3477	46	15K
0005435126137	3477	47	16D
0005435902487	3477	48	16C
0005434877675	3477	49	16H
0005434426417	3477	50	16G
0005435126135	3477	51	17A
0005434877631	3477	52	17D
0005432799278	3477	53	17C
0005435126126	3477	54	17G
0005434877635	3477	55	17F
0005434877633	3477	56	17K
0005435626062	3477	57	18C
0005434877654	3477	58	18B
0005435902418	3477	59	18E
0005434877676	3477	60	18G
0005432799300	3477	61	18F
0005434877715	3477	62	18H
0005434426447	3477	63	19A
0005434877707	3477	64	18K
0005435913855	3477	65	19D
0005434877691	3477	66	19C
0005432611684	3477	67	19B
0005435913857	3477	68	19G
0005435126127	3477	69	19F
0005432188587	3477	70	19E
0005434938020	3477	71	19J
0005434938031	3477	72	20C
0005434877687	3477	73	20B
0005434877650	3477	74	20E
0005432799294	3477	75	20D
0005432799271	3477	76	20G
0005434426445	3477	77	20F
0005434426416	3477	78	20K
0005435126129	3477	79	21B
0005434938015	3477	80	21A
0005434938025	3477	81	21D
0005435902468	3477	82	21C
0005434877655	3477	83	21F
0005434938022	3477	84	21E
0005435126111	3477	85	21J
0005435626059	3477	86	21H
0005435626067	3477	87	21G
0005434938019	3477	88	22A
0005435902410	3477	89	21K
0005434877710	3477	90	22C
0005432799295	3477	91	22B
0005434877659	3477	92	22F
0005434877667	3477	93	22E
0005432799280	3477	94	22D
0005435902446	3477	95	22G
0005432611686	3477	96	22J
0005435913850	3477	97	23B
0005435126142	3477	98	22K
0005434877694	3477	99	23D
0005432799285	3477	100	23C
0005435126139	3477	101	23E
0005434877670	3477	102	23H
0005434877623	3477	103	23G
0005432613835	3477	104	24D
0005435126145	3477	105	23K
0005434426424	3477	106	23J
0005435902470	3477	107	24F
0005434877706	3477	108	24E
0005435902422	3477	109	25A
0005434426418	3477	110	25C
0005432183453	3477	111	25B
0005434877700	3477	112	25F
0005434426444	3477	113	25E
0005434877705	3477	114	25D
0005434938023	3477	115	25J
0005432799291	3477	116	25G
0005434877656	3477	117	26A
0005434426436	3477	118	26E
0005434877669	3477	119	26D
0005434877657	3477	120	26G
0005435626060	3477	121	26F
0005432799288	3477	122	26J
0005434877702	3477	123	27A
0005434877642	3477	124	26K
0005434938026	3477	125	27D
0005434877714	3477	126	27C
0005435126140	3477	127	27F
0005434877621	3477	128	27G
0005432183454	3477	129	28A
0005432799286	3477	130	27K
0005434877662	3477	131	27J
0005435126112	3477	132	28E
0005434877686	3477	133	28D
0005434877701	3477	134	28C
0005434938024	3477	135	28H
0005434877682	3477	136	28G
0005434877666	3477	137	28F
0005434877646	3477	138	29B
0005435902447	3477	139	29A
0005434877685	3477	140	29D
0005434426420	3477	141	29E
0005434877696	3477	142	29G
0005434938013	3477	143	30C
0005435626055	3477	144	30B
0005434877648	3477	145	30A
0005434877647	3477	146	30E
0005435126121	3477	147	30D
0005434426427	3477	148	30F
0005432799275	3477	149	30J
0005434938018	3477	150	31A
0005435913854	3477	151	31D
0005432799289	3477	152	31B
0005435126136	3477	153	31E
0005434938016	3477	154	31H
0005434877665	3477	155	31G
0005434877709	3477	156	31K
0005432799299	3477	157	31J
0005434877671	3477	158	32B
0005432799276	3477	159	32A
0005435126120	3477	160	32G
0005435126118	3477	161	32J
0005434426442	3477	162	33B
0005435126134	3477	163	33A
0005434877634	3477	164	32K
0005434426423	3477	165	33D
0005432799283	3477	166	33H
0005434938027	3477	167	33G
0005434877677	3477	168	34A
0005435626069	3477	169	33K
0005434426446	3477	170	33J
0005435626068	3477	171	34C
0005435126108	3477	172	34B
0005435126122	3477	173	34E
0005434877643	3477	174	34H
0005434877630	3477	175	34G
0005435126130	3477	176	34J
0005434877679	3477	177	35B
0005434877713	3477	178	35A
0005435902438	3477	179	35E
0005432799282	3477	180	35D
0005434426443	3477	181	35G
0005434426439	3477	182	35F
0005434877684	3477	183	35J
0005434426430	3477	184	35H
0005434877704	3477	185	35K
0005434938028	3477	186	36C
0005434877663	3477	187	36B
0005435126128	3477	188	36E
0005434426441	3477	189	36D
0005434877658	3477	190	36G
0005435126147	3477	191	36F
0005434877632	3477	192	36K
0005434877695	3477	193	36J
0005434877651	3477	194	36H
0005432799297	3477	195	37B
0005434877645	3477	196	37F
0005434426431	3477	197	37E
0005434426432	3477	198	37J
0005434877639	3477	199	37H
0005435126107	3477	200	37G
0005434426425	3477	201	38A
0005434877628	3477	202	37K
0005432799273	3477	203	38B
0005434877660	3477	204	39A
0005432799296	3477	205	39D
0005435126106	3477	206	39C
0005435626066	3477	207	39E
0005435126138	3477	208	39H
0005435126148	3477	209	39G
0005435626063	3477	210	40A
0005435902486	3477	211	40C
0005434877698	3477	212	40B
0005435126116	3477	213	40F
0005434938021	3477	214	40E
0005435126109	3477	215	40H
0005434426429	3477	216	40J
0005435126146	3477	217	41B
0005434938014	3477	218	41A
0005434877625	3477	219	40K
0005434877689	3477	220	42A
0005435841083	3477	221	42D
0005434877627	3477	222	42G
0005434877680	3477	223	42J
0005434877708	3477	224	42H
0005434938012	3477	225	43A
0005434877636	3477	226	42K
0005434426419	3477	227	43D
0005434877672	3477	228	43C
0005432613836	3477	229	43H
0005434877678	3477	230	43G
0005434877629	3477	231	43J
0005435126119	3477	232	44C
0005435841084	3477	233	44B
0005434426438	3477	234	44E
0005434877673	3477	235	44D
0005434877649	3477	236	44G
0005434877703	3477	237	44F
0005434877681	3477	238	44J
0005435626056	3477	239	44H
0005434877712	3477	240	45A
0005434426426	3477	241	45D
0005434426437	3477	242	45C
0005432799290	3477	243	45B
0005434877699	3477	244	45F
0005435126114	3477	245	45E
0005434426435	3477	246	45G
0005435626058	3477	247	46A
0005434938029	3477	248	45K
0005434938017	3477	249	46C
0005432799274	3477	250	46G
0005432188589	3477	251	46H
0005434877690	3477	252	47A
0005434877626	3477	253	47C
0005434877661	3477	254	47G
0005434426428	3477	255	47H
0005435126132	3477	256	48D
0005434426422	3477	257	48C
0005434426433	3477	258	48A
0005434426440	3477	259	48F
0005432799284	3477	260	48E
0005432799279	3477	261	49A
0005434877688	3477	262	48K
0005435126144	3477	263	49D
0005432799287	3477	264	49C
0005434877697	3477	265	49K
0005432799293	3477	266	49G
0005434877692	3477	267	50C
0005434877638	3477	268	50A
0005434877668	3477	269	50D
0005434877640	3477	270	50G
0005434938030	3477	271	50F
0005435626057	3477	272	51D
0005435902439	3477	273	50H
0005435625899	14546	1	1D
0005435913923	14546	2	1C
0005434937823	14546	3	1A
0005434877142	14546	4	1G
0005434876718	14546	5	2A
0005434426177	14546	6	1K
0005434877197	14546	7	2G
0005432799067	14546	8	2D
0005434876767	14546	9	2K
0005434876911	14546	10	3D
0005435902587	14546	11	3H
0005435902600	14546	12	3G
0005435913922	14546	13	4A
0005435913913	14546	14	4D
0005435125736	14546	15	5A
0005435125763	14546	16	4H
0005435125759	14546	17	5D
0005434876870	14546	18	5C
0005434426224	14546	19	5H
0005435125785	14546	20	5G
0005434877001	14546	21	11A
0005435625876	14546	22	11E
0005435913920	14546	23	11D
0005435125666	14546	24	11K
0005434876924	14546	25	12E
0005434937794	14546	26	12D
0005434876726	14546	27	12G
0005434877000	14546	28	12F
0005432799030	14546	29	13D
0005432607516	14546	30	13C
0005432799151	14546	31	13E
0005434876890	14546	32	13H
0005435125702	14546	33	13G
0005434426136	14546	34	14D
0005434937954	14546	35	14C
0005435913912	14546	36	14K
0005434877193	14546	37	14H
0005434876658	14546	38	15C
0005435125706	14546	39	15A
0005435125713	14546	40	15E
0005434937847	14546	41	15K
0005434876869	14546	42	15H
0005434876802	14546	43	16D
0005432799026	14546	44	16C
0005432611650	14546	45	16F
0005434937878	14546	46	16K
0005434426198	14546	47	16H
0005435125740	14546	48	16G
0005435125789	14546	49	17C
0005434876765	14546	50	17G
0005435125809	14546	51	17K
0005434426145	14546	52	17H
0005434937862	14546	53	18E
0005432798999	14546	54	18D
0005434876914	14546	55	18H
0005434877014	14546	56	19D
0005435902584	14546	57	19C
0005435902596	14546	58	19B
0005434876891	14546	59	19F
0005434876584	14546	60	19H
0005434937953	14546	61	19G
0005435625877	14546	62	19J
0005434937879	14546	63	20E
0005435902601	14546	64	20D
0005432799152	14546	65	20G
0005434876885	14546	66	20F
0005434426220	14546	67	20H
0005432799202	14546	68	21A
0005435902599	14546	69	21C
0005432799065	14546	70	21F
0005432799031	14546	71	22D
0005435625860	14546	72	22B
0005435125686	14546	73	22K
0005432611647	14546	74	22J
0005434876766	14546	75	23B
0005434426126	14546	76	23A
0005435914693	14546	77	23F
0005435125683	14546	78	23E
0005434877027	14546	79	23H
0005435902598	14546	80	23G
0005432059491	14546	81	24G
0005435902602	14546	82	25D
0005434876934	14546	83	25C
0005434937835	14546	84	25F
0005434876785	14546	85	25H
0005434877007	14546	86	26B
0005434426134	14546	87	26A
0005432607502	14546	88	26D
0005434876946	14546	89	26F
0005434426227	14546	90	26H
0005435125665	14546	91	26K
0005434937834	14546	92	27C
0005434876879	14546	93	27F
0005434876768	14546	94	27E
0005434876619	14546	95	27H
0005434937867	14546	96	27G
0005435902588	14546	97	28A
0005434937916	14546	98	27J
0005434937840	14546	99	28C
0005434876724	14546	100	28D
0005434876937	14546	101	28G
0005435913914	14546	102	28F
0005434937896	14546	103	28K
0005435125800	14546	104	29C
0005435913919	14546	105	29B
0005435913916	14546	106	29E
0005435902590	14546	107	29G
0005435125846	14546	108	29K
0005434876901	14546	109	30C
0005434876896	14546	110	30B
0005434426239	14546	111	30A
0005432799066	14546	112	30E
0005435125847	14546	113	30D
0005434876967	14546	114	30G
0005432799025	14546	115	31B
0005434876746	14546	116	31A
0005434937841	14546	117	31C
0005434876878	14546	118	31F
0005432607517	14546	119	31E
0005434937848	14546	120	31H
0005434426138	14546	121	31G
0005432059492	14546	122	32A
0005435125738	14546	123	31J
0005435125720	14546	124	32C
0005435902595	14546	125	32E
0005432059493	14546	126	32D
0005435125651	14546	127	32F
0005435625898	14546	128	32K
0005435125699	14546	129	32J
0005434876793	14546	130	32H
0005432799064	14546	131	33A
0005435902591	14546	132	33D
0005434426135	14546	133	33C
0005434876941	14546	134	33B
0005434876745	14546	135	33F
0005432799203	14546	136	33J
0005435125737	14546	137	33H
0005432799139	14546	138	33K
0005434877018	14546	139	34C
0005435913915	14546	140	34B
0005435902593	14546	141	34A
0005434876860	14546	142	34E
0005435841817	14546	143	34D
0005434876912	14546	144	34G
0005432799072	14546	145	34K
0005434876913	14546	146	34J
0005434877143	14546	147	34H
0005434876796	14546	148	35B
0005432798994	14546	149	35A
0005435125723	14546	150	35D
0005434876862	14546	151	35F
0005435125756	14546	152	35G
0005435125757	14546	153	36A
0005435125664	14546	154	36D
0005435125817	14546	155	36G
0005434426143	14546	156	36F
0005434426155	14546	157	36J
0005435125788	14546	158	36H
0005434876685	14546	159	37B
0005434876921	14546	160	37A
0005432799024	14546	161	37F
0005432798984	14546	162	37E
0005434876567	14546	163	37J
0005435125792	14546	164	37H
0005434876877	14546	165	37K
0005435625902	14546	166	38C
0005432798962	14546	167	38B
0005435625886	14546	168	38A
0005434876968	14546	169	38J
0005435902597	14546	170	38H
0005434876664	14546	171	39A
0005434937795	14546	172	38K
0005435902592	14546	173	39D
0005434937824	14546	174	39B
0005434426144	14546	175	39F
0005435902589	14546	176	39E
0005435913921	14546	177	39H
0005434937861	14546	178	39G
0005434876935	14546	179	39K
0005435125739	14546	180	40C
0005434876958	14546	181	40E
0005434876610	14546	182	40H
0005432799048	14546	183	40G
0005434876868	14546	184	40F
0005432611645	14546	185	40K
0005434876861	14546	186	40J
0005434876677	14546	187	41D
0005435625878	14546	188	41C
0005435902585	14546	189	41B
0005435625869	14546	190	41H
0005434876792	14546	191	42A
0005434426165	14546	192	42B
0005434876996	14546	193	42D
0005434426093	14546	194	42G
0005434876697	14546	195	43F
0005435625889	14546	196	43H
0005435125766	14546	197	43G
0005435913917	14546	198	43K
0005432799123	14546	199	44C
0005434876959	14546	200	44B
0005434876652	14546	201	44D
0005435902594	14546	202	44H
0005435125884	14546	203	45A
0005434876940	14546	204	45D
0005434876801	14546	205	45C
0005434876725	14546	206	45E
0005432607515	14546	207	45G
0005434876657	14546	208	45K
0005435125842	14546	209	45J
0005435902586	14546	210	46C
0005435125758	14546	211	46B
0005434937932	14546	212	46F
0005434876569	14546	213	46J
0005434876939	14546	214	47C
0005432607500	14546	215	46K
0005434876690	14546	216	47E
0005435913918	14546	217	47G
0005435125724	14546	218	47F
0005434876938	14546	219	47H
0005434937931	14546	220	48D
0005434876735	14546	221	48F
0005435125650	14546	222	48G
0005435625861	14546	223	48K
0005434876836	14546	224	49E
0005432799054	14546	225	49G
0005434876777	14546	226	50E
0005435125885	14546	227	50G
0005435125700	14546	228	50F
0005432799120	14546	229	51D
0005434877129	14546	230	51F
0005434426088	14546	231	51G
0005434312305	3637	1	1A
0005435889790	3637	2	2A
0005434325574	3637	3	2B
0005435889832	3637	4	2C
0005434325580	3637	5	3A
0005434325576	3637	6	3D
0005435889788	3637	7	4A
0005434325573	3637	8	4C
0005434325581	3637	9	4B
0005435889806	3637	10	5B
0005435889824	3637	11	5C
0005434325578	3637	12	5D
0005435889800	3637	13	6C
0005434325583	3637	14	6D
0005435889791	3637	15	7C
0005434325584	3637	16	7D
0005435889789	3637	17	18B
0005434325582	3637	18	19A
0005434325579	3637	19	20C
0005434325577	3637	20	22A
0005434312306	3637	21	22B
0005434325575	3637	22	22C
0005434312308	3637	23	23A
0005434312307	3637	24	23B
0005435889860	15647	1	1D
0005435889856	15647	2	2A
0005434325491	15647	3	2C
0005435889861	15647	4	2D
0005435889859	15647	5	5C
0005434325522	15647	6	7A
0005435889858	15647	7	7B
0005434325475	15647	8	21A
0005435889862	15647	9	22B
0005435889857	15647	10	22D
0005435957605	670	1	1A
0005433420259	670	2	1C
0005433420286	670	3	2A
0005435957613	670	4	2B
0005433420291	670	5	2D
0005433420292	670	6	3B
0005433420260	670	7	4A
0005435957615	670	8	4C
0005435957617	670	9	4D
0005435957620	670	10	5B
0005433420290	670	11	5C
0005435957609	670	12	5D
0005435957618	670	13	6C
0005433420261	670	14	7A
0005435957616	670	15	7B
0005435957611	670	16	7C
0005433420296	670	17	18A
0005433420264	670	18	18B
0005435957614	670	19	18C
0005435957619	670	20	18D
0005435957612	670	21	19A
0005435957607	670	22	19C
0005435957606	670	23	19D
0005433420295	670	24	20C
0005433420282	670	25	20D
0005433420254	670	26	21A
0005435957608	670	27	21B
0005433420281	670	28	21C
0005435957610	670	29	22B
0005435957490	15194	1	1A
0005435957446	15194	2	1D
0005435957506	15194	3	2A
0005433420349	15194	4	2B
0005435957440	15194	5	3C
0005433420347	15194	6	3D
0005435957526	15194	7	4A
0005435957461	15194	8	4B
0005435957497	15194	9	5B
0005433420346	15194	10	6A
0005435957510	15194	11	6C
0005435957524	15194	12	7C
0005435957489	15194	13	18C
0005435957462	15194	14	18D
0005433420350	15194	15	19B
0005433420351	15194	16	19D
0005435957445	15194	17	20B
0005435957511	15194	18	20C
0005433420352	15194	19	21A
0005433420354	15194	20	21D
0005435957535	15194	21	22D
0005433420353	15194	22	22C
0005433420348	15194	23	23A
0005435957496	15194	24	23B
0005435221038	27270	1	1A
0005435219173	27270	2	1B
0005435219168	27270	3	2A
0005435221040	27270	4	3C
0005435219172	27270	5	4B
0005435221036	27270	6	4C
0005435221039	27270	7	5A
0005435221037	27270	8	6D
0005435219171	27270	9	19C
0005435219165	27270	10	21C
0005435216560	27270	11	22C
0005435629398	8878	1	3B
0005435629384	16004	1	1A
0005434247132	16004	2	2B
0005434247130	16004	3	3A
0005435629385	16004	4	3B
0005434247131	16004	5	5A
0005435629389	16004	6	6A
0005435933395	4436	1	1B
0005435163200	4436	2	1C
0005435163199	4436	3	1D
0005435163194	4436	4	2A
0005435163204	4436	5	2B
0005435933397	4436	6	3A
0005435163195	4436	7	4C
0005435163202	4436	8	6A
0005435163196	4436	9	6B
0005435163203	4436	10	7A
0005435163198	4436	11	18C
0005435163201	4436	12	20A
0005435933396	4436	13	20B
0005435163197	4436	14	23B
0005435797385	2850	1	1F
0005433404693	2850	2	2F
0005435797386	2850	3	3D
0005435797396	2850	4	4C
0005433404690	2850	5	4F
0005435797392	2850	6	6A
0005435797393	2850	7	6D
0005435797391	2850	8	7C
0005433404689	2850	9	8A
0005433404735	2850	10	9D
0005435797387	2850	11	10F
0005435797395	2850	12	11E
0005435797389	2850	13	11F
0005435797383	2850	14	12C
0005433404713	2850	15	13D
0005435797390	2850	16	14D
0005435797394	2850	17	14E
0005435797388	2850	18	14F
0005433404714	2850	19	17A
0005435797384	2850	20	19F
0005435797297	29313	1	1D
0005433404764	29313	2	3F
0005435797256	29313	3	4A
0005435797285	29313	4	8A
0005433404760	29313	5	8E
0005433404762	29313	6	8F
0005433404766	29313	7	9F
0005433404767	29313	8	10E
0005433404761	29313	9	11A
0005435797287	29313	10	11C
0005435797330	29313	11	12E
0005435797305	29313	12	13D
0005433404763	29313	13	13E
0005435797289	29313	14	14F
0005435797288	29313	15	15A
0005435797284	29313	16	15D
0005435797333	29313	17	15E
0005435797298	29313	18	17D
0005435797293	29313	19	18A
0005433404765	29313	20	19C
0005435376325	5849	1	5B
0005434947967	5850	1	1A
0005434947971	5850	2	1B
0005434947969	5850	3	2A
0005434947964	5850	4	2B
0005434947973	5850	5	4A
0005434947972	5850	6	3B
0005434947968	5850	7	4B
0005434947966	5850	8	5A
0005434947970	5850	9	5B
0005434947965	5850	10	6B
0005435376335	16383	1	1A
0005434947920	16383	2	1B
0005434947914	16383	3	2A
0005434947903	16383	4	3A
0005434947902	16383	5	2B
0005434947921	16383	6	3B
0005434947922	16383	7	4A
0005434947932	16383	8	4B
0005434947888	16383	9	5A
0005434947912	16383	10	5B
0005434947911	16383	11	6A
0005434947927	16383	12	6B
0005433960504	6892	1	1A
0005433960519	6892	2	1C
0005433960511	6892	3	1D
0005433960561	6892	4	1F
0005433960537	6892	5	2A
0005433960517	6892	6	2C
0005433960500	6892	7	3C
0005433960513	6892	8	3D
0005433960542	6892	9	3F
0005433960530	6892	10	4A
0005433960522	6892	11	4C
0005433960518	6892	12	4D
0005433960557	6892	13	4E
0005433960507	6892	14	4F
0005433960503	6892	15	5C
0005433960565	6892	16	5E
0005433960528	6892	17	6C
0005433960546	6892	18	6E
0005433960566	6892	19	6F
0005433960529	6892	20	7A
0005433960514	6892	21	7C
0005433960505	6892	22	7D
0005433960558	6892	23	7F
0005433960569	6892	24	8A
0005433960501	6892	25	8C
0005433960525	6892	26	8D
0005433960499	6892	27	8E
0005433960520	6892	28	8F
0005433960531	6892	29	9A
0005433960556	6892	30	9C
0005433960524	6892	31	9D
0005433960560	6892	32	9F
0005433960510	6892	33	10C
0005433960543	6892	34	10D
0005433960536	6892	35	10F
0005433960552	6892	36	11A
0005433960571	6892	37	11C
0005433960540	6892	38	11E
0005433960512	6892	39	12D
0005433960544	6892	40	12E
0005433960568	6892	41	12F
0005433960515	6892	42	13C
0005433960547	6892	43	13D
0005433960521	6892	44	13E
0005433960563	6892	45	13F
0005433960534	6892	46	14C
0005433960548	6892	47	14D
0005433960559	6892	48	14F
0005433960527	6892	49	15C
0005433960516	6892	50	15E
0005433960567	6892	51	15F
0005433960523	6892	52	16A
0005433960553	6892	53	16C
0005433960539	6892	54	16D
0005433960506	6892	55	16E
0005433960550	6892	56	16F
0005433960562	6892	57	17A
0005433960502	6892	58	17C
0005433960570	6892	59	17D
0005433960554	6892	60	17E
0005433960509	6892	61	17F
0005433960564	6892	62	18A
0005433960555	6892	63	18C
0005433960551	6892	64	18D
0005433960508	6892	65	18E
0005433960533	6892	66	18F
0005433960549	6892	67	19C
0005433960532	6892	68	19F
0005433960526	6892	69	20A
0005433960541	6892	70	20C
0005433960545	6892	71	20D
0005433960538	6892	72	20E
0005433960535	6892	73	20F
0005433959950	25763	1	2A
0005433959874	25763	2	2D
0005433959873	25763	3	3C
0005433959934	25763	4	6A
0005433959897	25763	5	6C
0005433959895	25763	6	7C
0005433959907	25763	7	7D
0005433959960	25763	8	9F
0005433959894	25763	9	10D
0005433959947	25763	10	11A
0005433959869	25763	11	11D
0005433959933	25763	12	11C
0005433959963	25763	13	11E
0005433959952	25763	14	12A
0005433959924	25763	15	13A
0005433959871	25763	16	13C
0005433959900	25763	17	14F
0005433959893	25763	18	15F
0005433959914	25763	19	16F
0005433959872	25763	20	17D
0005433959913	25763	21	18C
0005433959943	25763	22	18D
0005433959959	25763	23	19A
0005433959904	25763	24	19C
0005433959944	25763	25	20A
0005435082657	24514	1	1B
0005435082651	24514	2	2A
0005435082658	24514	3	2B
0005435082664	24514	4	3A
0005435082675	24514	5	3B
0005435082659	24514	6	4A
0005435082666	24514	7	4B
0005435082669	24514	8	5B
0005435082665	24514	9	6B
0005435082732	26093	1	1B
0005435082729	26093	2	2B
0005435082735	26093	3	3A
0005435082728	26093	4	3B
0005435082733	26093	5	4A
0005435082731	26093	6	5A
0005435082734	26093	7	5B
0005435082730	26093	8	6B
0005434244794	5153	1	2C
0005434244792	5153	2	3D
0005432166882	5153	3	4A
0005434244801	5153	4	5F
0005434244789	5153	5	6F
0005434244802	5153	6	7C
0005434244786	5153	7	7D
0005435286552	5153	8	7F
0005434244807	5153	9	8B
0005432166880	5153	10	9A
0005434244809	5153	11	10E
0005434244796	5153	12	12B
0005432166881	5153	13	12C
0005434244814	5153	14	13C
0005434244805	5153	15	13F
0005434244811	5153	16	14E
0005434244795	5153	17	15F
0005434244798	5153	18	18B
0005434244812	5153	19	18E
0005433534469	5153	20	18D
0005434244806	5153	21	19C
0005434244788	5153	22	20C
0005434244797	5153	23	20D
0005434244803	5153	24	21A
0005434244810	5153	25	22C
0005434244815	5153	26	23B
0005434244804	5153	27	23D
0005434244800	5153	28	25C
0005434244799	5153	29	26A
0005434244790	5153	30	26C
0005433534460	5153	31	27A
0005434244791	5153	32	27D
0005434244813	5153	33	28E
0005434244808	5153	34	28F
0005434244793	5153	35	30C
0005434244787	5153	36	31E
0005433614245	5152	1	1C
0005433614281	5152	2	1A
0005432105285	5152	3	1F
0005432105283	5152	4	1D
0005432105270	5152	5	2A
0005432105262	5152	6	2C
0005433784716	5152	7	2F
0005432105264	5152	8	2D
0005433614263	5152	9	3A
0005433614254	5152	10	3C
0005433784733	5152	11	3F
0005433784709	5152	12	3D
0005432105261	5152	13	4A
0005432105267	5152	14	4C
0005433614231	5152	15	4F
0005433614244	5152	16	4D
0005433784714	5152	17	5A
0005433784702	5152	18	5C
0005433614221	5152	19	5F
0005433614250	5152	20	5D
0005433614247	5152	21	6A
0005433614255	5152	22	6C
0005432665262	5152	23	6F
0005432105281	5152	24	6D
0005433784723	5152	25	7A
0005433784718	5152	26	7C
0005432105292	5152	27	7F
0005433784730	5152	28	7D
0005433784729	5152	29	8A
0005433784719	5152	30	8C
0005433784708	5152	31	8B
0005432105277	5152	32	8D
0005433614248	5152	33	8E
0005433614232	5152	34	9A
0005433784707	5152	35	8F
0005433614237	5152	36	9B
0005433614212	5152	37	9C
0005433784724	5152	38	9D
0005433784726	5152	39	9F
0005433614273	5152	40	9E
0005433614258	5152	41	10A
0005433784734	5152	42	10B
0005433614271	5152	43	10D
0005433614235	5152	44	10C
0005432105260	5152	45	10E
0005432667440	5152	46	10F
0005433784737	5152	47	11B
0005433614276	5152	48	11A
0005432105288	5152	49	11C
0005432105257	5152	50	11D
0005433614277	5152	51	11E
0005432145099	5152	52	12A
0005433614266	5152	53	11F
0005432665261	5152	54	12B
0005433784731	5152	55	12C
0005433784727	5152	56	12E
0005432105251	5152	57	12D
0005432105275	5152	58	12F
0005433614217	5152	59	13B
0005432666375	5152	60	13A
0005433614264	5152	61	13C
0005433614226	5152	62	13D
0005433784704	5152	63	13F
0005433614219	5152	64	13E
0005433614213	5152	65	14A
0005432105273	5152	66	14B
0005433614242	5152	67	14D
0005432105282	5152	68	14C
0005433614239	5152	69	14E
0005433614270	5152	70	14F
0005432105272	5152	71	15A
0005433784736	5152	72	15C
0005432105254	5152	73	15B
0005432105287	5152	74	15E
0005433614222	5152	75	15D
0005432105266	5152	76	15F
0005433614233	5152	77	16A
0005433784703	5152	78	16C
0005432105290	5152	79	16B
0005432105286	5152	80	16D
0005432666376	5152	81	16E
0005433784701	5152	82	17A
0005433614267	5152	83	16F
0005433784722	5152	84	17B
0005433614261	5152	85	17C
0005432105293	5152	86	17D
0005433614268	5152	87	17E
0005432105297	5152	88	18A
0005432105271	5152	89	17F
0005433784715	5152	90	18B
0005432105263	5152	91	18C
0005432105295	5152	92	18E
0005432105265	5152	93	18D
0005433614253	5152	94	19B
0005432105253	5152	95	18F
0005433784732	5152	96	19C
0005433614234	5152	97	19D
0005432105294	5152	98	20A
0005433784735	5152	99	19E
0005433614210	5152	100	20B
0005433614274	5152	101	20C
0005432105268	5152	102	20D
0005433784700	5152	103	20F
0005433614238	5152	104	20E
0005432105250	5152	105	21B
0005433614269	5152	106	21A
0005433614251	5152	107	21C
0005433614282	5152	108	21D
0005432105279	5152	109	21F
0005433614265	5152	110	21E
0005433614214	5152	111	22B
0005433784705	5152	112	22A
0005433614283	5152	113	22C
0005433614275	5152	114	22D
0005433614260	5152	115	22F
0005432105298	5152	116	22E
0005433614278	5152	117	23A
0005433614259	5152	118	23C
0005433614215	5152	119	23B
0005433614230	5152	120	23D
0005433614246	5152	121	23E
0005433784717	5152	122	24A
0005433614229	5152	123	23F
0005433784713	5152	124	24B
0005433614240	5152	125	24C
0005432105252	5152	126	24E
0005433784706	5152	127	24D
0005432105255	5152	128	25A
0005432105284	5152	129	24F
0005433784710	5152	130	25B
0005433614249	5152	131	25C
0005432105291	5152	132	25D
0005433614272	5152	133	25E
0005433614243	5152	134	25F
0005432105278	5152	135	26B
0005433614236	5152	136	26A
0005433614228	5152	137	26D
0005433614216	5152	138	26C
0005433784725	5152	139	26E
0005433784720	5152	140	26F
0005432105256	5152	141	27A
0005433614211	5152	142	27C
0005432105274	5152	143	27B
0005432105289	5152	144	27D
0005433784711	5152	145	27F
0005433614224	5152	146	27E
0005432105269	5152	147	28A
0005433614220	5152	148	28B
0005433614252	5152	149	28D
0005433614225	5152	150	28C
0005433784738	5152	151	28E
0005432105276	5152	152	28F
0005433614256	5152	153	29B
0005433614262	5152	154	29A
0005432105259	5152	155	29C
0005433784721	5152	156	29D
0005433614227	5152	157	29E
0005433784712	5152	158	30A
0005433614218	5152	159	29F
0005432105258	5152	160	30C
0005433614279	5152	161	30B
0005432105280	5152	162	30E
0005433784728	5152	163	30D
0005432667441	5152	164	30F
0005433614257	5152	165	31A
0005433614280	5152	166	31B
0005433614223	5152	167	31E
0005433614284	5152	168	31D
0005433614241	5152	169	31C
0005432105296	5152	170	31F
0005434264970	5150	1	1A
0005434312293	5150	2	1C
0005434149656	5150	3	1D
0005432335824	5150	4	1F
0005432335867	5150	5	2D
0005434149665	5150	6	3A
0005432335917	5150	7	2F
0005434264976	5150	8	3F
0005434229224	5150	9	3D
0005434149664	5150	10	4A
0005434229236	5150	11	4D
0005435269631	5150	12	5A
0005435006664	5150	13	5C
0005434229242	5150	14	5F
0005434149654	5150	15	5D
0005434229223	5150	16	6C
0005434264983	5150	17	6F
0005435006685	5150	18	7C
0005434312295	5150	19	7F
0005435006651	5150	20	7D
0005432335918	5150	21	8B
0005434149660	5150	22	8D
0005434264985	5150	23	8C
0005434173495	5150	24	8E
0005435006646	5150	25	8F
0005434264972	5150	26	9B
0005434229241	5150	27	9D
0005432335894	5150	28	9F
0005434264982	5150	29	9E
0005434149657	5150	30	10A
0005432335834	5150	31	10C
0005434264978	5150	32	10E
0005434229227	5150	33	10D
0005434229233	5150	34	10F
0005433688777	5150	35	11F
0005433688781	5150	36	11E
0005434264990	5150	37	12A
0005434264968	5150	38	12B
0005435006675	5150	39	12E
0005433688779	5150	40	12F
0005434264974	5150	41	13B
0005434229226	5150	42	13E
0005434229220	5150	43	13D
0005434264987	5150	44	13F
0005433688778	5150	45	14A
0005434311188	5150	46	14C
0005435006650	5150	47	14D
0005434311184	5150	48	14F
0005435269621	5150	49	14E
0005435006666	5150	50	15B
0005434264971	5150	51	15E
0005435269632	5150	52	16B
0005434149661	5150	53	16C
0005434264973	5150	54	16E
0005434264984	5150	55	16F
0005435006672	5150	56	17E
0005435006649	5150	57	17F
0005432335835	5150	58	18A
0005434173493	5150	59	18B
0005432335881	5150	60	18D
0005434229235	5150	61	18E
0005434173497	5150	62	19C
0005434229231	5150	63	19B
0005434149663	5150	64	19D
0005434229225	5150	65	20B
0005432335848	5150	66	20A
0005434229239	5150	67	20D
0005434264989	5150	68	20C
0005432335893	5150	69	21A
0005432335841	5150	70	21D
0005434264977	5150	71	21F
0005434229240	5150	72	22B
0005434264986	5150	73	22D
0005433815314	5150	74	22C
0005434311190	5150	75	22F
0005434311183	5150	76	23A
0005432335874	5150	77	23C
0005434264979	5150	78	23E
0005434149652	5150	79	23F
0005433688780	5150	80	24B
0005434229221	5150	81	24A
0005434149658	5150	82	24C
0005434264980	5150	83	24E
0005434229238	5150	84	24D
0005434264966	5150	85	24F
0005434229229	5150	86	25A
0005434264981	5150	87	25C
0005435006701	5150	88	25B
0005435006724	5150	89	25E
0005434311189	5150	90	26A
0005434264975	5150	91	25F
0005434149662	5150	92	26B
0005435006754	5150	93	26E
0005435006702	5150	94	26F
0005435006645	5150	95	27B
0005434149653	5150	96	27A
0005434264969	5150	97	27E
0005434149655	5150	98	27D
0005432335847	5150	99	27F
0005434229222	5150	100	28A
0005434264991	5150	101	28B
0005434229232	5150	102	28D
0005432335868	5150	103	28C
0005434173494	5150	104	28F
0005434229228	5150	105	29A
0005434264988	5150	106	29C
0005434264967	5150	107	29B
0005435006764	5150	108	29D
0005434173496	5150	109	29E
0005434149659	5150	110	29F
0005434229230	5150	111	30B
0005434229237	5150	112	30E
0005432335836	5150	113	31C
0005434229234	5150	114	31E
0005432335822	5150	115	31D
0005433784389	8365	1	1A
0005434244482	8365	2	1F
0005433784388	8365	3	2C
0005433784473	8365	4	3A
0005434244592	8365	5	2F
0005434244515	8365	6	3C
0005433784400	8365	7	3D
0005433784386	8365	8	4A
0005434244705	8365	9	3F
0005434244531	8365	10	4C
0005434244529	8365	11	4F
0005434244526	8365	12	4D
0005434244479	8365	13	5F
0005433784333	8365	14	6A
0005434244594	8365	15	6F
0005434244687	8365	16	7D
0005434244523	8365	17	8F
0005433784412	8365	18	8E
0005434244682	8365	19	9C
0005435269702	8365	20	9E
0005435269700	8365	21	10A
0005433784536	8365	22	10C
0005434244496	8365	23	10E
0005433784355	8365	24	11D
0005433784424	8365	25	11C
0005434244681	8365	26	11F
0005434244626	8365	27	11E
0005434244547	8365	28	12A
0005433784359	8365	29	12C
0005435269697	8365	30	12B
0005433784344	8365	31	12E
0005434244593	8365	32	12D
0005433784352	8365	33	12F
0005433784543	8365	34	13C
0005432666363	8365	35	13B
0005434244622	8365	36	13F
0005433784364	8365	37	14F
0005433784395	8365	38	15C
0005433784380	8365	39	15E
0005434244586	8365	40	16C
0005434244562	8365	41	16F
0005433784358	8365	42	17A
0005432666355	8365	43	17C
0005434244598	8365	44	17E
0005434244579	8365	45	17D
0005433784434	8365	46	18B
0005433784396	8365	47	17F
0005434244555	8365	48	18D
0005433784299	8365	49	18E
0005433784464	8365	50	19B
0005433784411	8365	51	18F
0005434244527	8365	52	20B
0005433784381	8365	53	20A
0005433784472	8365	54	20E
0005434244599	8365	55	20D
0005434244653	8365	56	21A
0005434244516	8365	57	21D
0005434244619	8365	58	21F
0005433784390	8365	59	22B
0005434244686	8365	60	22A
0005434244625	8365	61	22D
0005433784365	8365	62	22F
0005433784385	8365	63	23B
0005434244704	8365	64	23F
0005433784429	8365	65	23E
0005435269701	8365	66	24B
0005435269696	8365	67	24E
0005433784425	8365	68	25B
0005434244519	8365	69	25E
0005434244620	8365	70	26A
0005435269699	8365	71	26D
0005433784382	8365	72	26F
0005432666364	8365	73	27A
0005434244635	8365	74	27F
0005434244480	8365	75	28C
0005434244483	8365	76	28F
0005434244666	8365	77	29A
0005433784353	8365	78	29B
0005433784357	8365	79	30A
0005435269698	8365	80	29F
0005435269703	8365	81	31B
0005433784345	8365	82	31F
0005434244548	8365	83	31E
0005433613463	8366	1	1C
0005433613475	8366	2	2A
0005433613474	8366	3	3A
0005433613458	8366	4	3C
0005433613628	8366	5	4A
0005433613754	8366	6	4D
0005433613465	8366	7	5A
0005433613717	8366	8	6D
0005433613488	8366	9	7A
0005433613826	8366	10	7F
0005433613654	8366	11	8A
0005433613556	8366	12	8B
0005433613707	8366	13	8C
0005433613784	8366	14	9A
0005433613542	8366	15	9C
0005433613578	8366	16	9D
0005433613550	8366	17	9E
0005433613470	8366	18	10B
0005433613513	8366	19	10C
0005433613634	8366	20	10E
0005433613769	8366	21	10F
0005433613541	8366	22	11C
0005433613449	8366	23	11F
0005433613450	8366	24	11E
0005433613639	8366	25	12D
0005433613446	8366	26	12F
0005433613659	8366	27	12E
0005433613411	8366	28	13C
0005433613753	8366	29	13E
0005433613425	8366	30	14D
0005433613473	8366	31	14F
0005433613669	8366	32	15C
0005433613783	8366	33	15D
0005433613800	8366	34	15F
0005433613422	8366	35	16C
0005433613821	8366	36	17B
0005433613549	8366	37	18C
0005433613709	8366	38	19D
0005433613595	8366	39	19E
0005433613543	8366	40	20A
0005433613751	8366	41	20E
0005433613476	8366	42	20F
0005433613557	8366	43	21B
0005433613759	8366	44	21C
0005433613402	8366	45	21F
0005433613733	8366	46	22D
0005433613396	8366	47	22C
0005433613445	8366	48	22E
0005433613489	8366	49	23A
0005433613501	8366	50	23F
0005433613403	8366	51	23E
0005433613579	8366	52	24A
0005433613760	8366	53	24D
0005433613640	8366	54	24E
0005433613577	8366	55	24F
0005433613514	8366	56	25B
0005433613400	8366	57	25D
0005433613576	8366	58	26A
0005433613528	8366	59	25F
0005433613401	8366	60	26D
0005433613718	8366	61	27E
0005433613788	8366	62	28B
0005433613679	8366	63	28F
0005433613641	8366	64	29B
0005433613635	8366	65	29D
0005433613682	8366	66	29F
0005433613457	8366	67	29E
0005433613500	8366	68	30B
0005433613708	8366	69	30A
0005433613481	8366	70	30E
0005433613404	8366	71	31B
0005433613560	8366	72	31A
0005433613681	8366	73	31E
0005433534484	8367	1	1D
0005434229032	8367	2	2A
0005434264815	8367	3	1F
0005434264837	8367	4	2D
0005432034787	8367	5	3A
0005434229093	8367	6	3C
0005434264714	8367	7	3F
0005433534485	8367	8	3D
0005435286589	8367	9	4A
0005434229080	8367	10	4C
0005434311208	8367	11	4F
0005434149583	8367	12	4D
0005434264743	8367	13	5A
0005434149549	8367	14	5C
0005434228999	8367	15	6A
0005434229014	8367	16	6C
0005434264822	8367	17	6F
0005433689898	8367	18	6D
0005434229079	8367	19	7A
0005434149577	8367	20	7C
0005434229015	8367	21	7F
0005435006890	8367	22	7D
0005434149563	8367	23	8C
0005435286595	8367	24	8E
0005432034767	8367	25	9A
0005434264712	8367	26	8F
0005435006892	8367	27	9B
0005435006871	8367	28	9C
0005432034784	8367	29	9D
0005435006889	8367	30	9E
0005435006884	8367	31	9F
0005432034780	8367	32	10C
0005433690914	8367	33	10E
0005435006875	8367	34	10D
0005434149607	8367	35	11A
0005432335960	8367	36	10F
0005434149550	8367	37	11B
0005434229024	8367	38	11C
0005432335963	8367	39	11E
0005432034770	8367	40	11D
0005432335957	8367	41	11F
0005434264813	8367	42	12A
0005435006877	8367	43	12B
0005434264808	8367	44	12D
0005432034790	8367	45	12C
0005433815358	8367	46	12E
0005432047526	8367	47	12F
0005434149548	8367	48	13B
0005433815355	8367	49	13A
0005433688797	8367	50	13C
0005432034771	8367	51	13D
0005432034786	8367	52	13F
0005432034768	8367	53	13E
0005435006868	8367	54	14A
0005434149558	8367	55	14D
0005434264819	8367	56	14C
0005432034764	8367	57	14E
0005434229022	8367	58	14F
0005433815357	8367	59	15B
0005434264754	8367	60	15A
0005435006878	8367	61	15C
0005435286591	8367	62	15D
0005432034776	8367	63	15F
0005433690916	8367	64	15E
0005435006885	8367	65	16A
0005432335959	8367	66	16B
0005434229141	8367	67	16D
0005435286592	8367	68	16E
0005434264742	8367	69	16F
0005432034765	8367	70	17B
0005435006879	8367	71	17A
0005435286594	8367	72	17C
0005435006880	8367	73	17D
0005434264732	8367	74	17E
0005432034766	8367	75	18A
0005434264803	8367	76	17F
0005435006883	8367	77	18B
0005435006872	8367	78	18C
0005435006888	8367	79	18D
0005435006881	8367	80	19B
0005432034772	8367	81	18F
0005433690915	8367	82	19C
0005434229075	8367	83	19D
0005434264818	8367	84	19E
0005434229090	8367	85	20A
0005432335965	8367	86	20C
0005434311206	8367	87	20D
0005434229120	8367	88	20E
0005434229119	8367	89	21B
0005432335964	8367	90	21D
0005432335958	8367	91	21C
0005435006891	8367	92	21F
0005432034783	8367	93	21E
0005434311207	8367	94	22A
0005435006874	8367	95	22B
0005432335956	8367	96	22C
0005435286590	8367	97	22E
0005432034782	8367	98	22D
0005432034763	8367	99	22F
0005434149582	8367	100	23B
0005434229030	8367	101	23A
0005432047528	8367	102	23D
0005434229052	8367	103	23E
0005433815356	8367	104	24A
0005435006882	8367	105	24B
0005434264711	8367	106	24C
0005432034785	8367	107	24E
0005432034779	8367	108	24D
0005432034789	8367	109	24F
0005435006870	8367	110	25A
0005432335955	8367	111	25C
0005432335961	8367	112	25B
0005434229033	8367	113	25D
0005435006869	8367	114	25E
0005432034769	8367	115	26A
0005435006876	8367	116	25F
0005432034788	8367	117	26B
0005432034781	8367	118	26C
0005434264676	8367	119	26E
0005435286593	8367	120	26D
0005432034774	8367	121	27B
0005432335962	8367	122	27A
0005432034775	8367	123	27C
0005434149564	8367	124	27D
0005434149576	8367	125	27F
0005434264762	8367	126	27E
0005434264761	8367	127	28A
0005434149581	8367	128	28D
0005434149547	8367	129	28C
0005432034777	8367	130	28E
0005432034773	8367	131	28F
0005434229091	8367	132	29B
0005432047527	8367	133	29C
0005432047525	8367	134	29F
0005432034778	8367	135	29E
0005435006887	8367	136	30A
0005432034762	8367	137	30B
0005435286588	8367	138	30C
0005432335966	8367	139	30E
0005434149565	8367	140	30D
0005434264880	8367	141	30F
0005433689899	8367	142	31A
0005435006873	8367	143	31C
0005434229031	8367	144	31B
0005435006886	8367	145	31E
0005434638901	12629	1	1A
0005434638860	12629	2	1B
0005434638952	12629	3	1C
0005434639011	12629	4	2A
0005433202275	12629	5	2B
0005434638912	12629	6	2C
0005434638877	12629	7	3A
0005434638949	12629	8	2D
0005434638876	12629	9	3B
0005434638888	12629	10	3C
0005433202279	12629	11	3D
0005434638948	12629	12	4A
0005434638963	12629	13	4B
0005434638956	12629	14	4C
0005433202271	12629	15	4D
0005434638964	12629	16	5B
0005433202268	12629	17	5C
0005433202272	12629	18	5D
0005434638980	12629	19	6A
0005434638880	12629	20	6B
0005434638970	12629	21	6C
0005434639005	12629	22	6D
0005433202278	12629	23	7A
0005433202282	12629	24	7B
0005433202269	12629	25	7C
0005434638953	12629	26	7D
0005433202277	12629	27	18A
0005433202274	12629	28	18B
0005434638858	12629	29	18C
0005433202273	12629	30	18D
0005434638918	12629	31	19A
0005434638857	12629	32	19C
0005434638911	12629	33	19D
0005434639059	12629	34	20A
0005433202276	12629	35	20B
0005433202280	12629	36	20C
0005434638967	12629	37	20D
0005434638922	12629	38	21A
0005433202270	12629	39	21B
0005433202281	12629	40	21D
0005434638962	12629	41	22A
0005434638923	12629	42	22B
0005434638940	12629	43	22C
0005434638944	12629	44	22D
0005434638945	12629	45	23A
0005434638925	12629	46	23B
0005432290613	23343	1	1A
0005434639140	23343	2	1B
0005434639142	23343	3	1C
0005434639147	23343	4	1D
0005434639134	23343	5	2A
0005434639133	23343	6	2B
0005434639141	23343	7	3A
0005434639126	23343	8	3B
0005434639146	23343	9	3C
0005434639129	23343	10	3D
0005433202163	23343	11	4C
0005434639144	23343	12	4D
0005434639131	23343	13	5A
0005434639138	23343	14	5B
0005434639130	23343	15	5C
0005432290612	23343	16	5D
0005434639151	23343	17	6A
0005433202124	23343	18	6B
0005434639139	23343	19	6D
0005434639153	23343	20	7A
0005434639127	23343	21	7C
0005434639150	23343	22	18A
0005432290610	23343	23	18D
0005433202176	23343	24	19A
0005432290614	23343	25	19B
0005434639148	23343	26	19C
0005434639135	23343	27	19D
0005434639145	23343	28	20A
0005434639136	23343	29	20B
0005434639132	23343	30	20D
0005433202127	23343	31	21A
0005434639128	23343	32	21B
0005433202103	23343	33	21C
0005434639152	23343	34	21D
0005433202134	23343	35	22A
0005432290611	23343	36	22B
0005434639137	23343	37	22C
0005434639149	23343	38	22D
0005433202128	23343	39	23A
0005434639143	23343	40	23B
0005432327924	21078	1	1A
0005432327952	21078	2	1C
0005432327900	21078	3	1D
0005432382706	21078	4	2A
0005432382802	21078	5	2C
0005432382592	21078	6	2F
0005432327957	21078	7	3A
0005432327917	21078	8	3C
0005432327918	21078	9	3D
0005432382515	21078	10	3F
0005432054287	21078	11	4A
0005432327956	21078	12	4C
0005432327890	21078	13	4D
0005432382493	21078	14	4E
0005432382571	21078	15	5A
0005432382575	21078	16	5D
0005432054286	21078	17	5F
0005432328021	21078	18	6A
0005432382494	21078	19	6C
0005432382678	21078	20	6D
0005432382692	21078	21	7A
0005432328035	21078	22	7C
0005432327923	21078	23	7F
0005432328086	21078	24	8A
0005432382564	21078	25	8C
0005432382570	21078	26	8F
0005432382693	21078	27	9A
0005432327966	21078	28	9C
0005432327978	21078	29	9E
0005432328111	21078	30	10A
0005432328022	21078	31	10C
0005432327979	21078	32	10F
0005432328081	21078	33	11A
0005432328155	21078	34	11E
0005432327951	21078	35	11F
0005432382607	21078	36	12A
0005432328083	21078	37	12D
0005432382633	21078	38	12E
0005432327977	21078	39	13A
0005432327958	21078	40	13E
0005432328000	21078	41	13F
0005432328156	21078	42	14A
0005432328169	21078	43	14C
0005432327899	21078	44	14D
0005432328077	21078	45	14E
0005432327999	21078	46	14F
0005432382622	21078	47	15C
0005432382803	21078	48	15D
0005432382617	21078	49	15F
0005432382516	21078	50	16D
0005432382499	21078	51	16E
0005432328143	21078	52	16F
0005432327991	21078	53	17A
0005432327967	21078	54	17C
0005432328023	21078	55	17D
0005432382707	21078	56	17F
0005432327971	21078	57	18A
0005432382610	21078	58	18D
0005432328104	21078	59	18E
0005432328084	21078	60	18F
0005432328129	21078	61	19A
0005432328071	21078	62	19C
0005432328258	21078	63	19D
0005432848837	21078	64	19F
0005432327959	21078	65	20A
0005432382609	21078	66	20C
0005432328103	21078	67	20E
0005432328020	21078	68	20F
0005432382891	31236	1	1A
0005432328390	31236	2	1C
0005432328377	31236	3	1D
0005432328381	31236	4	1F
0005432328374	31236	5	2A
0005432382925	31236	6	2C
0005432328392	31236	7	2D
0005432328371	31236	8	2F
0005432328360	31236	9	3A
0005432328405	31236	10	3C
0005432328398	31236	11	3D
0005432382907	31236	12	3F
0005432328370	31236	13	4A
0005432287152	31236	14	4C
0005432328402	31236	15	4D
0005432328406	31236	16	4E
0005432287156	31236	17	4F
0005432328369	31236	18	5A
0005432328375	31236	19	5C
0005432328384	31236	20	5D
0005432328385	31236	21	5E
0005432382919	31236	22	5F
0005432328362	31236	23	6A
0005432382902	31236	24	6C
0005432328394	31236	25	6D
0005432328399	31236	26	6E
0005432382921	31236	27	6F
0005432328382	31236	28	7A
0005432382901	31236	29	7C
0005432382913	31236	30	7D
0005432382910	31236	31	7E
0005432382903	31236	32	7F
0005432328380	31236	33	8A
0005432382894	31236	34	8C
0005432382905	31236	35	8D
0005432287157	31236	36	8E
0005432328387	31236	37	8F
0005432382897	31236	38	9A
0005432382917	31236	39	9C
0005432328368	31236	40	9D
0005432382926	31236	41	9E
0005432382918	31236	42	9F
0005432328403	31236	43	10A
0005432328364	31236	44	10C
0005432328400	31236	45	10D
0005432287153	31236	46	10E
0005432382890	31236	47	10F
0005432382900	31236	48	11A
0005432382889	31236	49	11C
0005432328361	31236	50	11D
0005432328367	31236	51	11E
0005432382922	31236	52	11F
0005432382898	31236	53	12A
0005432328378	31236	54	12C
0005432328363	31236	55	12E
0005432382895	31236	56	12F
0005432382888	31236	57	13A
0005432382899	31236	58	13C
0005432328388	31236	59	13D
0005432328389	31236	60	13E
0005432382906	31236	61	13F
0005432287154	31236	62	14A
0005432328397	31236	63	14C
0005432382920	31236	64	14D
0005432382915	31236	65	14E
0005432382893	31236	66	14F
0005432382914	31236	67	15A
0005432382887	31236	68	15C
0005432328376	31236	69	15D
0005432328386	31236	70	15E
0005432382896	31236	71	15F
0005432328379	31236	72	16A
0005432382923	31236	73	16C
0005432382908	31236	74	16E
0005432328404	31236	75	16F
0005432328393	31236	76	17A
0005432382904	31236	77	17C
0005432382924	31236	78	17D
0005432328373	31236	79	17E
0005432328365	31236	80	17F
0005432328401	31236	81	18A
0005432382909	31236	82	18C
0005432382911	31236	83	18D
0005432328396	31236	84	18E
0005432328383	31236	85	18F
0005432382886	31236	86	19A
0005432328372	31236	87	19C
0005432328366	31236	88	19D
0005432287151	31236	89	19E
0005432382892	31236	90	19F
0005432328391	31236	91	20A
0005432382916	31236	92	20C
0005432287155	31236	93	20D
0005432382912	31236	94	20E
0005432328395	31236	95	20F
0005433642238	2480	1	1D
0005433642244	2480	2	2A
0005432953819	2480	3	2C
0005433642246	2480	4	2F
0005432953811	2480	5	4A
0005432953798	2480	6	4E
0005432953807	2480	7	5D
0005433642245	2480	8	5E
0005433642248	2480	9	6D
0005432953808	2480	10	6E
0005432953809	2480	11	7A
0005433642247	2480	12	7C
0005433642242	2480	13	7D
0005432953793	2480	14	7F
0005433642256	2480	15	8F
0005433642252	2480	16	9A
0005432953789	2480	17	9C
0005433642237	2480	18	9D
0005433642239	2480	19	9E
0005433642253	2480	20	10A
0005433642243	2480	21	10C
0005432953810	2480	22	10D
0005432953792	2480	23	10E
0005432953806	2480	24	10F
0005433642251	2480	25	11D
0005432953802	2480	26	12C
0005432953794	2480	27	13C
0005433642236	2480	28	13F
0005432953791	2480	29	14C
0005433642231	2480	30	14E
0005433642230	2480	31	14F
0005433642250	2480	32	15C
0005432953799	2480	33	15E
0005433642255	2480	34	15F
0005433642241	2480	35	16A
0005433642249	2480	36	16D
0005433642232	2480	37	16E
0005433642254	2480	38	17A
0005433642235	2480	39	17E
0005433642233	2480	40	17F
0005432953801	2480	41	18C
0005432953800	2480	42	18E
0005433642240	2480	43	19C
0005433642257	2480	44	19D
0005433642229	2480	45	20C
0005433642234	2480	46	20D
0005433642099	27591	1	1F
0005433642079	27591	2	2A
0005432953873	27591	3	2D
0005433642123	27591	4	2F
0005432953879	27591	5	3A
0005432953878	27591	6	3C
0005433642117	27591	7	3D
0005432953882	27591	8	4C
0005433642078	27591	9	5A
0005432953877	27591	10	5C
0005432953875	27591	11	5F
0005432953884	27591	12	6C
0005433642089	27591	13	7D
0005433642127	27591	14	7E
0005432953880	27591	15	7F
0005433642143	27591	16	8C
0005432953883	27591	17	8D
0005433642144	27591	18	8E
0005432953881	27591	19	8F
0005433642145	27591	20	9A
0005433642075	27591	21	9F
0005433642084	27591	22	10D
0005433642090	27591	23	10F
0005433642120	27591	24	11A
0005432953888	27591	25	11C
0005433642074	27591	26	11E
0005432953889	27591	27	11D
0005433642110	27591	28	13A
0005433642116	27591	29	13C
0005432953885	27591	30	13E
0005432953886	27591	31	14A
0005433642121	27591	32	14C
0005433642148	27591	33	14D
0005433642109	27591	34	15C
0005433642142	27591	35	15D
0005433642147	27591	36	15E
0005432953874	27591	37	16C
0005433642126	27591	38	16D
0005433642128	27591	39	17C
0005432953876	27591	40	17D
0005433642100	27591	41	18A
0005433642093	27591	42	19D
0005433642088	27591	43	19F
0005433642149	27591	44	20A
0005432953887	27591	45	20C
0005432424158	13260	1	1A
0005432424142	13260	2	1D
0005432424119	13260	3	1F
0005432424156	13260	4	2A
0005432424107	13260	5	2D
0005432424112	13260	6	2F
0005432424103	13260	7	3A
0005432424127	13260	8	3C
0005432424129	13260	9	3D
0005432424145	13260	10	4C
0005432424136	13260	11	5A
0005432424114	13260	12	5C
0005432424144	13260	13	5D
0005432424140	13260	14	5E
0005432424111	13260	15	5F
0005432424118	13260	16	6A
0005432424150	13260	17	6F
0005432424105	13260	18	7A
0005432424143	13260	19	7C
0005432424115	13260	20	7F
0005432424155	13260	21	8D
0005432424126	13260	22	8E
0005432424151	13260	23	9A
0005432424153	13260	24	9E
0005432424109	13260	25	9F
0005432424149	13260	26	10D
0005432424106	13260	27	10E
0005432424139	13260	28	10F
0005432424147	13260	29	11D
0005432424098	13260	30	11E
0005432424137	13260	31	11F
0005432424113	13260	32	12C
0005432424138	13260	33	12D
0005432424148	13260	34	12E
0005432424102	13260	35	12F
0005432424132	13260	36	13C
0005432424117	13260	37	13D
0005432424121	13260	38	13E
0005432424099	13260	39	13F
0005432424146	13260	40	14A
0005432424104	13260	41	14C
0005432424128	13260	42	14E
0005432424108	13260	43	15A
0005432424120	13260	44	15C
0005432424134	13260	45	15E
0005432424116	13260	46	16C
0005432424133	13260	47	16D
0005432424122	13260	48	16E
0005432424159	13260	49	16F
0005432424124	13260	50	17A
0005432424123	13260	51	17E
0005432424157	13260	52	17F
0005432424141	13260	53	18A
0005432424131	13260	54	18D
0005432424101	13260	55	18E
0005432424125	13260	56	19A
0005432424100	13260	57	19C
0005432424152	13260	58	19E
0005432424130	13260	59	20A
0005432424135	13260	60	20C
0005432424110	13260	61	20D
0005432424154	13260	62	20E
0005432423621	30799	1	1A
0005432423758	30799	2	1F
0005432423639	30799	3	2A
0005432423656	30799	4	2C
0005432423610	30799	5	2D
0005432423625	30799	6	4A
0005432423659	30799	7	4C
0005432423743	30799	8	4D
0005432423744	30799	9	4E
0005432423655	30799	10	4F
0005432423624	30799	11	5A
0005432423638	30799	12	5D
0005432423754	30799	13	5F
0005432423673	30799	14	6A
0005432423674	30799	15	6F
0005432423733	30799	16	7A
0005432423700	30799	17	7C
0005432423699	30799	18	7E
0005432423662	30799	19	8C
0005432423718	30799	20	8E
0005432423732	30799	21	9C
0005432423726	30799	22	9E
0005432423611	30799	23	10A
0005432423663	30799	24	10E
0005432423648	30799	25	10F
0005432423641	30799	26	12D
0005432423658	30799	27	12F
0005432423679	30799	28	13A
0005432423698	30799	29	13F
0005432423661	30799	30	14A
0005432423740	30799	31	14C
0005432423651	30799	32	15C
0005432423675	30799	33	15D
0005432423637	30799	34	15E
0005432423753	30799	35	15F
0005432423682	30799	36	16A
0005432423695	30799	37	16C
0005432423677	30799	38	16E
0005432423759	30799	39	17F
0005432423671	30799	40	18A
0005432423701	30799	41	18C
0005432423694	30799	42	18E
0005432423678	30799	43	18F
0005432423617	30799	44	19A
0005432423626	30799	45	19D
0005432423725	30799	46	19E
0005432423741	30799	47	19F
0005432423634	30799	48	20A
0005432423657	30799	49	20E
0005432817282	9616	1	1C
0005432288966	9616	2	1F
0005432901313	9616	3	2A
0005434157382	9616	4	2C
0005432817273	9616	5	2D
0005432901325	9616	6	3A
0005432822155	9616	7	3C
0005432822151	9616	8	3D
0005434157381	9616	9	4A
0005432822153	9616	10	4D
0005432817297	9616	11	4F
0005432817299	9616	12	5C
0005432817291	9616	13	5E
0005432817279	9616	14	5F
0005432901350	9616	15	6A
0005432817284	9616	16	6C
0005432817287	9616	17	6D
0005434186156	9616	18	6F
0005434157343	9616	19	7A
0005432822152	9616	20	7C
0005432817300	9616	21	7F
0005432817272	9616	22	8A
0005432817301	9616	23	8C
0005432817283	9616	24	8D
0005432901357	9616	25	8E
0005434186148	9616	26	8F
0005432822157	9616	27	9A
0005432822158	9616	28	9D
0005432817276	9616	29	9F
0005432288964	9616	30	10A
0005434186155	9616	31	10C
0005432817290	9616	32	10E
0005432817285	9616	33	10F
0005432817298	9616	34	11A
0005432288965	9616	35	11D
0005432901298	9616	36	11F
0005432817296	9616	37	11E
0005432817271	9616	38	12C
0005432901377	9616	39	12D
0005432817295	9616	40	12F
0005432817293	9616	41	13D
0005432817289	9616	42	13E
0005432817274	9616	43	13F
0005432822154	9616	44	14A
0005432817280	9616	45	14C
0005434448295	9616	46	14F
0005432817275	9616	47	15A
0005434157374	9616	48	15C
0005432901314	9616	49	15F
0005432817281	9616	50	16C
0005432817278	9616	51	16D
0005432901351	9616	52	16E
0005432901371	9616	53	16F
0005432901363	9616	54	17A
0005432817286	9616	55	17C
0005432822156	9616	56	17D
0005434448294	9616	57	17E
0005434448293	9616	58	18C
0005434186149	9616	59	18D
0005432817292	9616	60	18F
0005432817288	9616	61	19D
0005434186160	9616	62	19E
0005432817294	9616	63	19F
0005432901364	9616	64	20A
0005432901352	9616	65	20D
0005432817277	9616	66	20E
0005434157380	9616	67	20F
0005432822068	29006	1	1A
0005432817047	29006	2	1C
0005432817011	29006	3	1D
0005432817034	29006	4	1F
0005432816941	29006	5	2A
0005432822100	29006	6	2C
0005432817084	29006	7	2D
0005432901503	29006	8	2F
0005432822101	29006	9	3A
0005434157428	29006	10	3C
0005432817087	29006	11	3F
0005432901494	29006	12	4A
0005432901501	29006	13	4C
0005432817097	29006	14	4D
0005432901506	29006	15	4E
0005434448261	29006	16	5A
0005434448271	29006	17	5C
0005434157434	29006	18	5E
0005432901502	29006	19	5F
0005432822127	29006	20	6A
0005432002062	29006	21	6C
0005432822077	29006	22	6E
0005434186178	29006	23	6F
0005432901495	29006	24	7A
0005432822084	29006	25	7C
0005432822078	29006	26	7D
0005432817026	29006	27	7E
0005432822079	29006	28	8A
0005432817006	29006	29	8C
0005432822065	29006	30	8D
0005432817096	29006	31	8E
0005434157430	29006	32	8F
0005432901508	29006	33	9A
0005432817056	29006	34	9C
0005432817027	29006	35	9D
0005432002064	29006	36	9F
0005432817088	29006	37	10A
0005432816951	29006	38	10C
0005432817017	29006	39	10D
0005432822083	29006	40	10E
0005432901499	29006	41	11A
0005432816979	29006	42	11C
0005432816950	29006	43	11D
0005432817018	29006	44	11E
0005432822075	29006	45	11F
0005432901500	29006	46	12C
0005432817167	29006	47	12E
0005432816949	29006	48	12F
0005432822129	29006	49	13A
0005432817168	29006	50	13C
0005434157435	29006	51	13D
0005432901493	29006	52	13F
0005432817033	29006	53	14A
0005432816956	29006	54	14C
0005432901505	29006	55	14D
0005432901497	29006	56	14F
0005432002063	29006	57	15A
0005432816942	29006	58	15C
0005432817071	29006	59	15D
0005432901498	29006	60	15E
0005432816962	29006	61	15F
0005432901496	29006	62	16A
0005432817073	29006	63	16C
0005432822066	29006	64	16D
0005434157429	29006	65	16E
0005432816984	29006	66	16F
0005432816978	29006	67	17A
0005434157432	29006	68	17D
0005434186179	29006	69	17E
0005432901492	29006	70	17F
0005432816983	29006	71	18A
0005432822074	29006	72	18C
0005432901507	29006	73	18E
0005432817055	29006	74	18F
0005432816971	29006	75	19A
0005432901504	29006	76	19D
0005432816970	29006	77	19E
0005432817057	29006	78	19F
0005432822090	29006	79	20A
0005434157431	29006	80	20C
0005432822128	29006	81	20D
0005434157433	29006	82	20F
0005432611687	15033	1	1A
0005432611686	15033	2	1B
0005432613835	15033	3	2A
0005432613838	15033	4	2B
0005435841083	15033	5	3B
0005432611688	15033	6	3A
0005432611684	15033	7	4A
0005432611685	15033	8	4B
0005432613837	15033	9	5A
0005432613836	15033	10	5B
0005435841084	15033	11	6A
0005435841817	31538	1	1A
0005432607515	31538	2	1B
0005432607500	31538	3	2B
0005432611647	31538	4	3A
0005432611650	31538	5	4A
0005432607516	31538	6	4B
0005432611645	31538	7	5A
0005432607517	31538	8	6A
0005432607502	31538	9	6B
0005433568646	11885	1	1A
0005432947854	11885	2	1F
0005433568676	11885	3	1D
0005433568640	11885	4	1C
0005433568625	11885	5	2F
0005432947849	11885	6	2C
0005433568638	11885	7	3A
0005433568633	11885	8	3D
0005433568607	11885	9	3F
0005433568668	11885	10	4D
0005433568674	11885	11	4C
0005432947855	11885	12	4A
0005432948005	11885	13	4F
0005432947839	11885	14	5C
0005433568631	11885	15	5A
0005433568643	11885	16	5F
0005433568672	11885	17	5D
0005433568665	11885	18	6D
0005432948006	11885	19	6C
0005433568645	11885	20	6B
0005433568634	11885	21	6E
0005433568609	11885	22	7B
0005433568647	11885	23	7A
0005432947765	11885	24	6F
0005433568658	11885	25	7C
0005433568627	11885	26	7E
0005433568624	11885	27	7D
0005433568661	11885	28	8A
0005432947821	11885	29	8B
0005433568641	11885	30	8C
0005433568678	11885	31	8F
0005432947895	11885	32	9A
0005433568670	11885	33	9F
0005433568662	11885	34	9E
0005433568616	11885	35	9D
0005432947817	11885	36	10A
0005432947838	11885	37	10C
0005433568622	11885	38	10B
0005433568612	11885	39	10E
0005432947777	11885	40	10D
0005433568623	11885	41	10F
0005433568628	11885	42	11B
0005432947819	11885	43	11A
0005432947853	11885	44	11E
0005433568626	11885	45	11D
0005433568637	11885	46	11C
0005433568642	11885	47	11F
0005433568614	11885	48	12B
0005433568675	11885	49	12A
0005433568671	11885	50	12C
0005433568610	11885	51	12E
0005433568650	11885	52	13A
0005433568651	11885	53	12F
0005433568666	11885	54	13C
0005433568673	11885	55	13B
0005433568620	11885	56	13E
0005432947795	11885	57	13D
0005433568608	11885	58	13F
0005433568639	11885	59	14B
0005433568621	11885	60	14A
0005433568636	11885	61	14D
0005433568649	11885	62	14C
0005433568644	11885	63	14F
0005433568660	11885	64	14E
0005433568648	11885	65	15B
0005433568656	11885	66	15A
0005432947869	11885	67	15C
0005433568659	11885	68	15E
0005432947850	11885	69	15D
0005432947842	11885	70	16A
0005432947894	11885	71	15F
0005433568652	11885	72	16C
0005433568615	11885	73	16B
0005432947818	11885	74	16E
0005433568617	11885	75	16D
0005433568679	11885	76	17A
0005433568619	11885	77	16F
0005432947808	11885	78	17D
0005433568657	11885	79	17C
0005433568606	11885	80	17F
0005433568669	11885	81	17E
0005433568667	11885	82	18A
0005433568653	11885	83	18B
0005433568632	11885	84	18E
0005433568629	11885	85	18D
0005433568654	11885	86	18F
0005433568655	11885	87	19C
0005433568618	11885	88	19B
0005433568613	11885	89	19E
0005432947868	11885	90	19F
0005432947910	11885	91	20B
0005433568611	11885	92	20D
0005433568677	11885	93	20C
0005432947856	11885	94	20E
0005433568635	11885	95	21B
0005433568630	11885	96	21A
0005432947979	11885	97	21D
0005433568663	11885	98	21C
0005433568664	11885	99	21E
0005432948260	25296	1	1A
0005433568161	25296	2	1F
0005433568107	25296	3	2D
0005432948222	25296	4	2F
0005432948235	25296	5	3D
0005432948257	25296	6	3C
0005433568176	25296	7	3F
0005432948244	25296	8	4D
0005432948240	25296	9	4C
0005433568169	25296	10	4A
0005432948253	25296	11	4F
0005432948245	25296	12	5C
0005432948223	25296	13	5A
0005432948255	25296	14	6A
0005432948250	25296	15	6D
0005432948251	25296	16	7A
0005433568106	25296	17	6F
0005433568189	25296	18	7C
0005433568095	25296	19	7B
0005433568088	25296	20	7E
0005432948262	25296	21	7D
0005433568114	25296	22	8A
0005432948230	25296	23	7F
0005432948239	25296	24	8C
0005432948252	25296	25	8D
0005432948227	25296	26	8E
0005432948229	25296	27	9A
0005432948256	25296	28	9D
0005433568083	25296	29	9F
0005433568177	25296	30	9E
0005433568132	25296	31	10B
0005432948247	25296	32	10A
0005432948248	25296	33	10C
0005432948254	25296	34	11A
0005432948241	25296	35	10F
0005433568174	25296	36	11C
0005432948236	25296	37	11B
0005433568157	25296	38	11F
0005432948228	25296	39	12A
0005433568077	25296	40	12F
0005433568214	25296	41	12D
0005433568094	25296	42	13A
0005432948243	25296	43	13B
0005433568188	25296	44	13E
0005433568212	25296	45	13D
0005432948246	25296	46	13F
0005433568238	25296	47	14B
0005432948238	25296	48	14C
0005432948259	25296	49	14E
0005432948242	25296	50	15B
0005432948231	25296	51	15D
0005432948263	25296	52	15F
0005432948224	25296	53	16A
0005433568207	25296	54	16B
0005433568081	25296	55	16D
0005432948261	25296	56	16C
0005432948232	25296	57	16E
0005433568206	25296	58	17C
0005432948249	25296	59	17B
0005432948258	25296	60	17E
0005432948234	25296	61	18A
0005433568111	25296	62	18E
0005433568213	25296	63	18F
0005433568089	25296	64	19B
0005433568158	25296	65	19E
0005432948226	25296	66	19D
0005432948237	25296	67	19C
0005433568067	25296	68	20B
0005433568166	25296	69	20C
0005432948225	25296	70	20E
0005433568105	25296	71	20F
0005433568173	25296	72	21C
0005433568068	25296	73	21E
0005432948233	25296	74	21F
0005433808308	14455	1	1C
0005433808307	14455	2	1A
0005433812860	14455	3	2C
0005433808311	14455	4	2F
0005433808318	14455	5	2D
0005434026687	14455	6	4A
0005432430844	14455	7	5A
0005434026690	14455	8	5C
0005434026689	14455	9	5F
0005434026693	14455	10	6C
0005433808319	14455	11	6E
0005432430830	14455	12	6F
0005434026694	14455	13	9A
0005432430837	14455	14	10C
0005433812857	14455	15	10F
0005432430843	14455	16	11E
0005434026688	14455	17	12B
0005433812859	14455	18	12F
0005433812858	14455	19	13C
0005432430836	14455	20	13E
0005432430840	14455	21	13F
0005432430831	14455	22	14E
0005433808309	14455	23	15D
0005432430841	14455	24	16A
0005434026691	14455	25	15F
0005432430842	14455	26	16F
0005432430838	14455	27	17A
0005432430834	14455	28	17D
0005433808317	14455	29	19B
0005432430832	14455	30	19F
0005432430833	14455	31	19E
0005432430835	14455	32	20A
0005432430839	14455	33	20F
0005434026692	14455	34	21C
0005433808306	14455	35	21B
0005434654503	5376	1	1A
0005434654510	5376	2	1D
0005434656543	5376	3	1F
0005435340128	5376	4	2A
0005435340045	5376	5	2C
0005435340072	5376	6	2F
0005435340034	5376	7	3C
0005434654491	5376	8	4A
0005435340026	5376	9	4C
0005435340044	5376	10	4E
0005435340103	5376	11	5A
0005435555338	5376	12	5E
0005434656544	5376	13	6A
0005434654500	5376	14	6C
0005434654512	5376	15	6D
0005434654504	5376	16	6E
0005434654509	5376	17	7D
0005434654505	5376	18	7F
0005432114181	5376	19	8A
0005434654496	5376	20	8D
0005434654516	5376	21	8F
0005435340030	5376	22	9A
0005434654493	5376	23	9F
0005434654492	5376	24	10C
0005435340062	5376	25	10D
0005434654501	5376	26	10E
0005435340079	5376	27	11C
0005434654514	5376	28	11D
0005435340031	5376	29	11E
0005435340104	5376	30	11F
0005435340033	5376	31	12C
0005435340017	5376	32	12D
0005434654495	5376	33	12E
0005434654511	5376	34	12F
0005432114182	5376	35	13A
0005435340059	5376	36	13E
0005434654489	5376	37	14C
0005434654508	5376	38	14F
0005434654490	5376	39	14E
0005434654506	5376	40	15A
0005434654513	5376	41	15C
0005434654517	5376	42	15E
0005434654498	5376	43	16A
0005432114183	5376	44	16D
0005435340032	5376	45	16E
0005435340073	5376	46	17C
0005435340025	5376	47	17E
0005434654507	5376	48	18A
0005434654499	5376	49	18C
0005434654502	5376	50	18E
0005432114184	5376	51	19A
0005435555342	5376	52	19D
0005434654497	5376	53	20A
0005434654515	5376	54	20D
0005434654494	5376	55	20E
0005434654212	12507	1	1F
0005434656528	12507	2	2A
0005435340168	12507	3	2C
0005434654273	12507	4	2F
0005434654308	12507	5	3A
0005435340174	12507	6	3C
0005434654325	12507	7	3F
0005434654254	12507	8	4C
0005434654307	12507	9	4D
0005434654180	12507	10	4E
0005435340173	12507	11	6D
0005434654181	12507	12	7F
0005435340166	12507	13	8D
0005435555358	12507	14	8E
0005434654287	12507	15	8F
0005434654285	12507	16	9D
0005434654242	12507	17	9F
0005435340165	12507	18	10C
0005435555357	12507	19	10D
0005435340161	12507	20	11D
0005435340172	12507	21	11F
0005435340164	12507	22	12E
0005435340163	12507	23	12F
0005434654213	12507	24	13E
0005434654284	12507	25	14C
0005435340169	12507	26	14D
0005434654319	12507	27	14E
0005434654323	12507	28	15D
0005434654197	12507	29	16C
0005434654191	12507	30	16D
0005435340167	12507	31	17E
0005435340171	12507	32	17F
0005435340160	12507	33	18D
0005434654324	12507	34	18F
0005434654192	12507	35	19E
0005434654230	12507	36	19F
0005435340162	12507	37	20A
0005434654272	12507	38	20C
0005435340170	12507	39	20D
0005432078071	7469	1	1A
0005433656645	7469	2	1D
0005433656647	7469	3	2C
0005433715644	7469	4	2D
0005433715654	7469	5	2F
0005433715643	7469	6	3D
0005433715672	7469	7	3F
0005433715674	7469	8	4A
0005433715667	7469	9	4C
0005433715630	7469	10	4B
0005433715666	7469	11	4D
0005433715649	7469	12	4F
0005433715657	7469	13	5A
0005433715634	7469	14	5B
0005433715663	7469	15	5C
0005432078073	7469	16	5E
0005433690913	7469	17	6B
0005433715633	7469	18	6A
0005433715640	7469	19	6E
0005433715645	7469	20	6D
0005433715635	7469	21	6F
0005433715678	7469	22	7B
0005433715650	7469	23	7A
0005433719118	7469	24	7C
0005433722174	7469	25	7E
0005433688796	7469	26	7F
0005433715637	7469	27	8A
0005433715632	7469	28	8B
0005433690912	7469	29	8D
0005433722178	7469	30	8C
0005433715662	7469	31	8E
0005433715661	7469	32	8F
0005433715659	7469	33	9C
0005433722176	7469	34	9D
0005433719115	7469	35	9E
0005433688795	7469	36	10B
0005432078072	7469	37	10C
0005432428879	7469	38	10E
0005433715675	7469	39	10D
0005433715646	7469	40	11A
0005432078076	7469	41	11C
0005433715652	7469	42	11F
0005433715631	7469	43	11E
0005433715677	7469	44	12A
0005433656648	7469	45	12C
0005433722177	7469	46	12B
0005433715653	7469	47	13A
0005433715658	7469	48	13B
0005432078075	7469	49	13C
0005433715673	7469	50	13D
0005433715671	7469	51	13F
0005433715641	7469	52	14A
0005432078074	7469	53	14E
0005433715669	7469	54	15A
0005433715638	7469	55	15C
0005433722170	7469	56	15D
0005433715636	7469	57	15E
0005433715668	7469	58	16A
0005433715651	7469	59	16F
0005433715655	7469	60	17B
0005433656646	7469	61	17C
0005433719116	7469	62	17E
0005433715670	7469	63	17D
0005433715639	7469	64	17F
0005433722173	7469	65	18A
0005433715642	7469	66	18D
0005433689897	7469	67	18F
0005433715628	7469	68	19A
0005433689896	7469	69	19F
0005433715676	7469	70	20A
0005433715656	7469	71	20C
0005435266075	7469	72	20B
0005433715647	7469	73	20D
0005433715629	7469	74	20E
0005433722172	7469	75	20F
0005433689895	7469	76	21C
0005433715664	7469	77	21D
0005433715648	7469	78	22A
0005433719117	7469	79	21F
0005433715660	7469	80	22C
0005433715665	7469	81	22B
0005433722171	7469	82	23B
0005433715679	7469	83	23C
0005433722175	7469	84	23D
0005433715161	29235	1	1A
0005432428906	29235	2	2A
0005433688779	29235	3	1F
0005433715319	29235	4	2D
0005433715071	29235	5	2C
0005435266123	29235	6	3A
0005433715253	29235	7	3D
0005433715070	29235	8	3F
0005433715249	29235	9	4C
0005433688778	29235	10	4B
0005433715088	29235	11	4D
0005433715244	29235	12	5A
0005433715067	29235	13	5C
0005433656614	29235	14	5E
0005433715105	29235	15	5F
0005433715229	29235	16	6A
0005433715348	29235	17	6E
0005433688781	29235	18	6D
0005433715198	29235	19	6F
0005435266124	29235	20	8C
0005433715230	29235	21	8E
0005433715377	29235	22	9C
0005433715331	29235	23	9E
0005433715350	29235	24	9D
0005433715168	29235	25	9F
0005433715262	29235	26	10C
0005433715430	29235	27	11B
0005433715207	29235	28	11E
0005432006741	29235	29	11F
0005433715241	29235	30	12A
0005433715318	29235	31	12C
0005433715177	29235	32	12F
0005433688780	29235	33	13A
0005433715261	29235	34	13C
0005433715159	29235	35	13E
0005433715104	29235	36	13F
0005435266122	29235	37	14A
0005433715382	29235	38	14C
0005433715206	29235	39	14B
0005433719099	29235	40	14D
0005433715275	29235	41	14F
0005433715429	29235	42	15F
0005432006743	29235	43	16F
0005433715103	29235	44	17B
0005433715179	29235	45	18A
0005433715199	29235	46	18B
0005433715306	29235	47	18C
0005433688777	29235	48	18E
0005433715162	29235	49	19B
0005433715346	29235	50	19E
0005432428908	29235	51	19F
0005433656613	29235	52	20A
0005433715221	29235	53	20D
0005433715272	29235	54	20E
0005433715178	29235	55	21B
0005435266121	29235	56	21A
0005432428907	29235	57	21C
0005433715347	29235	58	22E
0005433715165	29235	59	22F
0005433715258	29235	60	23A
0005433715205	29235	61	23F
0005432006742	29235	62	23E
0005434095187	8655	1	1A
0005434182010	8655	2	1C
0005434182007	8655	3	2C
0005434095177	8655	4	2F
0005434181999	8655	5	3D
0005434181971	8655	6	4D
0005434095185	8655	7	4E
0005434181986	8655	8	5C
0005434095181	8655	9	5E
0005434095190	8655	10	6A
0005434182027	8655	11	6C
0005434181972	8655	12	6F
0005434095179	8655	13	7F
0005434095182	8655	14	9A
0005434095186	8655	15	9D
0005434181973	8655	16	9E
0005434095183	8655	17	10A
0005434095189	8655	18	11C
0005434095178	8655	19	11D
0005434181987	8655	20	12A
0005434143716	8655	21	15C
0005434143715	8655	22	15D
0005434181981	8655	23	16A
0005434095191	8655	24	17C
0005434095184	8655	25	17F
0005434095180	8655	26	19A
0005434095188	8655	27	19D
0005434182013	8655	28	20C
0005434095038	11654	1	1D
0005434095037	11654	2	2A
0005434183564	11654	3	3A
0005434182109	11654	4	3F
0005434182106	11654	5	4D
0005434182104	11654	6	5D
0005434182105	11654	7	6E
0005434182103	11654	8	6F
0005434182108	11654	9	8C
0005434182110	11654	10	8E
0005434184651	11654	11	8F
0005434182107	11654	12	9A
0005434183565	11654	13	9E
0005434095040	11654	14	10C
0005434095042	11654	15	11D
0005434182100	11654	16	11E
0005434095030	11654	17	11F
0005434184650	11654	18	13D
0005434182102	11654	19	14A
0005434095130	11654	20	14E
0005434095060	11654	21	15F
0005434182099	11654	22	18F
0005434095020	11654	23	19A
0005434095041	11654	24	19D
0005434182101	11654	25	20C
0005433397326	1436	1	1A
0005433397618	1436	2	1F
0005433397488	1436	3	2A
0005433397548	1436	4	2F
0005435732275	1436	5	3C
0005433397303	1436	6	3D
0005433397272	1436	7	4C
0005433456942	1436	8	4F
0005432297261	1436	9	5A
0005433397211	1436	10	5C
0005433397237	1436	11	5D
0005433397291	1436	12	5E
0005433397355	1436	13	5F
0005435732262	1436	14	6D
0005433397504	1436	15	7A
0005433397292	1436	16	7C
0005433397383	1436	17	7D
0005433397466	1436	18	7E
0005433397413	1436	19	7F
0005433397283	1436	20	8A
0005433397509	1436	21	8C
0005433397490	1436	22	8D
0005433397468	1436	23	8E
0005433397505	1436	24	8F
0005435732269	1436	25	9A
0005433397568	1436	26	9C
0005433397420	1436	27	9D
0005433397288	1436	28	9E
0005435732274	1436	29	9F
0005435732261	1436	30	10A
0005433397496	1436	31	10E
0005433397196	1436	32	10F
0005433397419	1436	33	11A
0005435732271	1436	34	11C
0005435732264	1436	35	11D
0005435732272	1436	36	11E
0005433397325	1436	37	11F
0005435732273	1436	38	12A
0005433397271	1436	39	12C
0005432906499	1436	40	12D
0005433397498	1436	41	12E
0005435732267	1436	42	12F
0005433397212	1436	43	13A
0005433397465	1436	44	13E
0005435732260	1436	45	13F
0005433397255	1436	46	14A
0005435732258	1436	47	14D
0005432906497	1436	48	14E
0005433397489	1436	49	14F
0005433397284	1436	50	15A
0005435732263	1436	51	15C
0005435732265	1436	52	15F
0005435732259	1436	53	16A
0005433456944	1436	54	16C
0005435732276	1436	55	16E
0005433397493	1436	56	17A
0005433456945	1436	57	17C
0005435732270	1436	58	17D
0005433397569	1436	59	17F
0005432906501	1436	60	18A
0005433397210	1436	61	18C
0005432906498	1436	62	18D
0005433397497	1436	63	18E
0005433397546	1436	64	19A
0005435732257	1436	65	19C
0005435732266	1436	66	19D
0005433456943	1436	67	19F
0005435732268	1436	68	20A
0005433397492	1436	69	20C
0005433397287	1436	70	20E
0005433397380	1436	71	20F
0005433397768	19272	1	1A
0005433397736	19272	2	1C
0005433397756	19272	3	1D
0005432906521	19272	4	2A
0005433397770	19272	5	2C
0005432906519	19272	6	2D
0005433397727	19272	7	2F
0005433397764	19272	8	3A
0005433397728	19272	9	3C
0005433397754	19272	10	3F
0005433397757	19272	11	4A
0005433397755	19272	12	4C
0005433397742	19272	13	4D
0005433397726	19272	14	4E
0005433397751	19272	15	4F
0005433397762	19272	16	5A
0005433397766	19272	17	5F
0005435732140	19272	18	6A
0005433397753	19272	19	6C
0005433397731	19272	20	6D
0005433397774	19272	21	7A
0005433397734	19272	22	7E
0005433456898	19272	23	7F
0005433397771	19272	24	8A
0005433397739	19272	25	8D
0005433397729	19272	26	8F
0005433397738	19272	27	9A
0005433397747	19272	28	9C
0005433397759	19272	29	9D
0005433397741	19272	30	10C
0005433397763	19272	31	10D
0005435732152	19272	32	11A
0005433397743	19272	33	11C
0005433397773	19272	34	11E
0005435732153	19272	35	11F
0005433397767	19272	36	12A
0005433397772	19272	37	12C
0005433397748	19272	38	12D
0005433397746	19272	39	12F
0005435732154	19272	40	13A
0005433456905	19272	41	13C
0005433397735	19272	42	13D
0005433397744	19272	43	13E
0005435732172	19272	44	13F
0005435732158	19272	45	14A
0005433397733	19272	46	14C
0005433456910	19272	47	14D
0005433397769	19272	48	14E
0005433456909	19272	49	15C
0005433397765	19272	50	15D
0005433397761	19272	51	15E
0005433397749	19272	52	15F
0005433397732	19272	53	16C
0005433397737	19272	54	16D
0005433397740	19272	55	16F
0005435732201	19272	56	17A
0005433456897	19272	57	17C
0005432906520	19272	58	17F
0005433397758	19272	59	18E
0005433397745	19272	60	19A
0005433397760	19272	61	19C
0005433397750	19272	62	19D
0005433397730	19272	63	19F
0005435732194	19272	64	20A
0005433397752	19272	65	20D
0005433456916	19272	66	20F
0005434443461	17381	1	1B
0005434443486	17381	2	2B
0005434443437	17381	3	3C
0005434443455	17381	4	3D
0005434443477	17381	5	4B
0005434443488	17381	6	4D
0005434443449	17381	7	5D
0005434443442	17381	8	7A
0005434443443	17381	9	18A
0005434443472	17381	10	19A
0005434443514	17381	11	19D
0005434443513	17381	12	21C
0005434443500	17381	13	22A
0005434443436	17381	14	23A
0005434443487	17381	15	23B
0005434443604	20604	1	1A
0005434443603	20604	2	1C
0005434443599	20604	3	4A
0005434443590	20604	4	5A
0005434443598	20604	5	5C
0005434443596	20604	6	6A
0005434443597	20604	7	6C
0005434443602	20604	8	18D
0005434443600	20604	9	19B
0005434443594	20604	10	19C
0005434443601	20604	11	20B
0005434443592	20604	12	20D
0005434443595	20604	13	21C
0005434443591	20604	14	21D
0005434443593	20604	15	22C
0005434954582	7242	1	2B
0005435377544	7242	2	3A
0005434954585	7242	3	3B
0005434954584	7242	4	4B
0005434954583	7242	5	5A
0005434954549	28315	1	3A
0005434954546	28315	2	4B
0005434954550	28315	3	5B
0005434351617	4497	1	1B
0005434351614	4497	2	1D
0005434351615	4497	3	2B
0005434351620	4497	4	2C
0005434351618	4497	5	3B
0005434183545	4497	6	3C
0005434351611	4497	7	4B
0005435893527	4497	8	4C
0005435893515	4497	9	5A
0005434351609	4497	10	5D
0005435893518	4497	11	6A
0005435893503	4497	12	6B
0005434183560	4497	13	7D
0005435893525	4497	14	18A
0005434183546	4497	15	18C
0005434351619	4497	16	18D
0005435893513	4497	17	19A
0005434351610	4497	18	19D
0005435893526	4497	19	20A
0005434351616	4497	20	20D
0005434351613	4497	21	21C
0005435893528	4497	22	21D
0005435893555	4497	23	22B
0005435893519	4497	24	22C
0005434351612	4497	25	22D
0005435893583	29678	1	1D
0005434351501	29678	2	3C
0005434351542	29678	3	3D
0005434351477	29678	4	4A
0005435893584	29678	5	4D
0005434351500	29678	6	5A
0005434351544	29678	7	5B
0005435893589	29678	8	6A
0005434351490	29678	9	6D
0005434351496	29678	10	7A
0005434351539	29678	11	7B
0005435893585	29678	12	18B
0005434351510	29678	13	19A
0005435893588	29678	14	19C
0005435893590	29678	15	22B
0005435893586	29678	16	22D
0005435893587	29678	17	23A
0005433341711	1064	1	1A
0005433341562	1064	2	1B
0005435545681	1064	3	1H
0005433269663	1064	4	1G
0005433341493	1064	5	2A
0005433342085	1064	6	2F
0005433341451	1064	7	2C
0005433341539	1064	8	2H
0005432293192	1064	9	2G
0005432293195	1064	10	3A
0005433341662	1064	11	3B
0005433341519	1064	12	3C
0005433341709	1064	13	3F
0005433341695	1064	14	4A
0005433341737	1064	15	3H
0005433341724	1064	16	4F
0005434446504	1064	17	4C
0005433341534	1064	18	5B
0005433341712	1064	19	5A
0005433341885	1064	20	5G
0005433341506	1064	21	9A
0005433341886	1064	22	9G
0005435545684	1064	23	11A
0005433341688	1064	24	11D
0005433341638	1064	25	11F
0005433341812	1064	26	12A
0005433341551	1064	27	12D
0005433341759	1064	28	12B
0005432293194	1064	29	12H
0005435545676	1064	30	12G
0005433341639	1064	31	13A
0005435545678	1064	32	13G
0005435545679	1064	33	13F
0005435545675	1064	34	14B
0005433341626	1064	35	14E
0005433341663	1064	36	14F
0005433341611	1064	37	14G
0005433341651	1064	38	14H
0005433341857	1064	39	15B
0005433341781	1064	40	15A
0005433341687	1064	41	15E
0005433341378	1064	42	15D
0005433463886	1064	43	15H
0005433341439	1064	44	16B
0005434446507	1064	45	16A
0005433341678	1064	46	16H
0005433341559	1064	47	18A
0005433341784	1064	48	18D
0005432293193	1064	49	18E
0005434445233	1064	50	18H
0005433341552	1064	51	19B
0005435092014	1064	52	19A
0005433341682	1064	53	19F
0005433341454	1064	54	19H
0005433158093	1064	55	20A
0005432293191	1064	56	20D
0005433341710	1064	57	20B
0005434446506	1064	58	20E
0005435545673	1064	59	20H
0005433341750	1064	60	21D
0005435545689	1064	61	21E
0005433341700	1064	62	21H
0005433341725	1064	63	21G
0005435092010	1064	64	22F
0005435092012	1064	65	22E
0005433341555	1064	66	22H
0005435545686	1064	67	23B
0005433341530	1064	68	23D
0005435545688	1064	69	23E
0005433269644	1064	70	23G
0005435092009	1064	71	24B
0005433341487	1064	72	24D
0005435092006	1064	73	24G
0005433158094	1064	74	25D
0005435545683	1064	75	25E
0005434445234	1064	76	27F
0005435545690	1064	77	27G
0005433269630	1064	78	28A
0005435545677	1064	79	28F
0005433341399	1064	80	28E
0005433341520	1064	81	28G
0005433341783	1064	82	28H
0005433341557	1064	83	29D
0005433341699	1064	84	29F
0005435092007	1064	85	29H
0005435092011	1064	86	29G
0005433341379	1064	87	30B
0005433341478	1064	88	30A
0005433341507	1064	89	30D
0005435545685	1064	90	30F
0005435092008	1064	91	30G
0005434445235	1064	92	31E
0005433462733	1064	93	31D
0005433341515	1064	94	31F
0005433463887	1064	95	31G
0005433342084	1064	96	31H
0005433341887	1064	97	32D
0005433341403	1064	98	32F
0005432293196	1064	99	32E
0005433341768	1064	100	32G
0005435545687	1064	101	33A
0005433341510	1064	102	33D
0005433341450	1064	103	34B
0005433341715	1064	104	34E
0005433341834	1064	105	35B
0005435545672	1064	106	35D
0005435545674	1064	107	35E
0005433341563	1064	108	35G
0005433341531	1064	109	36A
0005433341514	1064	110	36B
0005435545680	1064	111	36F
0005433341556	1064	112	36H
0005433341694	1064	113	36G
0005435092013	1064	114	37B
0005433269650	1064	115	37F
0005433341579	1064	116	37H
0005435545682	1064	117	38B
0005433341956	1064	118	38G
0005433341772	1064	119	39D
0005434446505	1064	120	39F
0005433342418	17022	1	1B
0005433342412	17022	2	1A
0005433342478	17022	3	1F
0005435508188	17022	4	1H
0005433342479	17022	5	1G
0005433342472	17022	6	2A
0005433342489	17022	7	2C
0005433342420	17022	8	2H
0005433342431	17022	9	2G
0005433342463	17022	10	2F
0005433342407	17022	11	3C
0005433342422	17022	12	3G
0005435508181	17022	13	4B
0005433342457	17022	14	4A
0005433342419	17022	15	4F
0005433342473	17022	16	4C
0005433342493	17022	17	4G
0005433342442	17022	18	5A
0005433342456	17022	19	4H
0005435091913	17022	20	9A
0005433269685	17022	21	5H
0005433342446	17022	22	9B
0005433342464	17022	23	9G
0005433342495	17022	24	11G
0005435091940	17022	25	12A
0005433342402	17022	26	12B
0005433342477	17022	27	12E
0005433342403	17022	28	12F
0005433269684	17022	29	12H
0005433342465	17022	30	13B
0005433342443	17022	31	13D
0005433342474	17022	32	13E
0005433342449	17022	33	13F
0005435091968	17022	34	13H
0005433342494	17022	35	14B
0005433342445	17022	36	14A
0005433342423	17022	37	14D
0005433342428	17022	38	14F
0005433342395	17022	39	15A
0005433342485	17022	40	14H
0005433342454	17022	41	15D
0005433342414	17022	42	15B
0005433342486	17022	43	15E
0005433342458	17022	44	16E
0005433342491	17022	45	16F
0005433342487	17022	46	17G
0005433342416	17022	47	17H
0005433342404	17022	48	18D
0005433342488	17022	49	18H
0005433342429	17022	50	19B
0005433342448	17022	51	19D
0005433342490	17022	52	19E
0005433342400	17022	53	19H
0005433342453	17022	54	20B
0005433342459	17022	55	20F
0005433342483	17022	56	20H
0005433342410	17022	57	21B
0005435508187	17022	58	21A
0005433342421	17022	59	21D
0005433342497	17022	60	21G
0005433269682	17022	61	22B
0005433342396	17022	62	22E
0005433342401	17022	63	22F
0005433342484	17022	64	23B
0005433342451	17022	65	23E
0005435091949	17022	66	23D
0005433342426	17022	67	23F
0005435508182	17022	68	23H
0005433342462	17022	69	24D
0005433342435	17022	70	24F
0005433342409	17022	71	27A
0005433342470	17022	72	25F
0005433342413	17022	73	27B
0005433342444	17022	74	27D
0005433342471	17022	75	27G
0005433342406	17022	76	27H
0005435508168	17022	77	28B
0005433342452	17022	78	28E
0005435508169	17022	79	28D
0005433342466	17022	80	28F
0005433342455	17022	81	29H
0005433342460	17022	82	29G
0005433342469	17022	83	30D
0005433342433	17022	84	30H
0005433342468	17022	85	31B
0005433342467	17022	86	31E
0005433342441	17022	87	32A
0005433342461	17022	88	31H
0005433342427	17022	89	32B
0005433269681	17022	90	32E
0005435091939	17022	91	32D
0005435091951	17022	92	32H
0005433342439	17022	93	33D
0005433342480	17022	94	33B
0005433342440	17022	95	33E
0005433342397	17022	96	33G
0005433342408	17022	97	33F
0005433342476	17022	98	34A
0005433342398	17022	99	34F
0005433342481	17022	100	34G
0005433342432	17022	101	35A
0005433342399	17022	102	34H
0005433342482	17022	103	35B
0005435091953	17022	104	35D
0005433342475	17022	105	35G
0005434445207	17022	106	35F
0005433342424	17022	107	35H
0005433342437	17022	108	36A
0005433342492	17022	109	36E
0005433342438	17022	110	36D
0005433342415	17022	111	36F
0005433342411	17022	112	36G
0005433342450	17022	113	36H
0005433342496	17022	114	37E
0005433342434	17022	115	37D
0005433342405	17022	116	37G
0005433342417	17022	117	37F
0005433269683	17022	118	37H
0005433159298	17022	119	38A
0005433342436	17022	120	38E
0005433342430	17022	121	38F
0005433342447	17022	122	38G
0005433342425	17022	123	39E
0005434066492	12769	1	1C
0005434081511	12769	2	1F
0005434066493	12769	3	1D
0005434066472	12769	4	2A
0005434081594	12769	5	2C
0005432433643	12769	6	2F
0005434066642	12769	7	3D
0005434066355	12769	8	3F
0005434081538	12769	9	4A
0005434066383	12769	10	4D
0005434066593	12769	11	5A
0005434081515	12769	12	4F
0005434066779	12769	13	5D
0005434081499	12769	14	6A
0005434026675	12769	15	6C
0005434081593	12769	16	6D
0005432433644	12769	17	6E
0005434066344	12769	18	6F
0005434066631	12769	19	7B
0005434066455	12769	20	7A
0005434066475	12769	21	7C
0005434066473	12769	22	7F
0005434066501	12769	23	8B
0005432159827	12769	24	8D
0005434066389	12769	25	8F
0005434081487	12769	26	9A
0005434081555	12769	27	9B
0005434066437	12769	28	9E
0005432161138	12769	29	9D
0005434081544	12769	30	9F
0005434066545	12769	31	10B
0005434066712	12769	32	10D
0005434066398	12769	33	10C
0005434066458	12769	34	10E
0005434066401	12769	35	11C
0005434066564	12769	36	11B
0005432159829	12769	37	11D
0005434066502	12769	38	11F
0005434066771	12769	39	11E
0005432433647	12769	40	12A
0005434066382	12769	41	12C
0005434066322	12769	42	12B
0005434081484	12769	43	12F
0005434066323	12769	44	13B
0005434066477	12769	45	13D
0005434066641	12769	46	13C
0005433812885	12769	47	13E
0005433989681	12769	48	14A
0005434066356	12769	49	14B
0005434066366	12769	50	14D
0005434066314	12769	51	14C
0005432161136	12769	52	14E
0005434081579	12769	53	14F
0005434066617	12769	54	15C
0005434066520	12769	55	15B
0005434066630	12769	56	15E
0005434066572	12769	57	15D
0005434066489	12769	58	15F
0005434066454	12769	59	16C
0005432161139	12769	60	16E
0005434066538	12769	61	16F
0005433989682	12769	62	17A
0005434066377	12769	63	17B
0005432159830	12769	64	17C
0005434066524	12769	65	17D
0005434066393	12769	66	17E
0005434066825	12769	67	18D
0005434026674	12769	68	18C
0005432159828	12769	69	18E
0005434066461	12769	70	18F
0005434066381	12769	71	19A
0005434066585	12769	72	19C
0005434066562	12769	73	19D
0005434066405	12769	74	19E
0005434066448	12769	75	20B
0005434066565	12769	76	20A
0005434081519	12769	77	20D
0005434066601	12769	78	20C
0005434081520	12769	79	20E
0005432433645	12769	80	21A
0005432161137	12769	81	21C
0005434081550	12769	82	21D
0005434066392	12769	83	21F
0005434026676	12769	84	22A
0005434081512	12769	85	22B
0005434066616	12769	86	22E
0005433812884	12769	87	22D
0005434066315	12769	88	22C
0005434066537	12769	89	22F
0005434066409	12769	90	23B
0005434081530	12769	91	23C
0005432433646	12769	92	23D
0005432159826	12769	93	23F
0005434081477	12769	94	23E
0005434067023	30695	1	1A
0005434067022	30695	2	1C
0005434067060	30695	3	1D
0005434067045	30695	4	2A
0005434067077	30695	5	2D
0005432186845	30695	6	2C
0005434067065	30695	7	2F
0005434081731	30695	8	3A
0005432150140	30695	9	3D
0005434067051	30695	10	3C
0005434067024	30695	11	4A
0005434067087	30695	12	3F
0005434067079	30695	13	4B
0005434067086	30695	14	4C
0005433989736	30695	15	4D
0005434081728	30695	16	4E
0005434067052	30695	17	4F
0005434067049	30695	18	5A
0005434067036	30695	19	5C
0005434067069	30695	20	5B
0005432186841	30695	21	5D
0005434067025	30695	22	5E
0005434067040	30695	23	5F
0005432150137	30695	24	6B
0005434081737	30695	25	6C
0005434067092	30695	26	6D
0005434067041	30695	27	6F
0005432150136	30695	28	6E
0005434067056	30695	29	7B
0005434067043	30695	30	7A
0005434067066	30695	31	7C
0005434067037	30695	32	7D
0005433989738	30695	33	7E
0005432150138	30695	34	8A
0005434067035	30695	35	8B
0005432433589	30695	36	8C
0005434067068	30695	37	8E
0005434081735	30695	38	9A
0005434067090	30695	39	8F
0005434081730	30695	40	9B
0005434067078	30695	41	9D
0005432150142	30695	42	9C
0005434067091	30695	43	9E
0005434067089	30695	44	9F
0005434067085	30695	45	10B
0005434067054	30695	46	10D
0005434067088	30695	47	11A
0005434067050	30695	48	10E
0005432186843	30695	49	11B
0005434067026	30695	50	11D
0005434067083	30695	51	11C
0005434067062	30695	52	11F
0005434067064	30695	53	12A
0005434081729	30695	54	12C
0005434067033	30695	55	12B
0005433989739	30695	56	12E
0005432150139	30695	57	12F
0005434067093	30695	58	13B
0005434067073	30695	59	13A
0005434067061	30695	60	13C
0005433989737	30695	61	13E
0005434067034	30695	62	13D
0005434081748	30695	63	13F
0005434067039	30695	64	14B
0005434067044	30695	65	14A
0005434067048	30695	66	14D
0005434067031	30695	67	14C
0005434081739	30695	68	14F
0005434081742	30695	69	14E
0005434067030	30695	70	15A
0005434081747	30695	71	15C
0005432433584	30695	72	15E
0005434067046	30695	73	15F
0005432150135	30695	74	16A
0005434081743	30695	75	16B
0005434067021	30695	76	16C
0005434067059	30695	77	16D
0005432150141	30695	78	16E
0005434067027	30695	79	17A
0005434081740	30695	80	17B
0005434067032	30695	81	17D
0005434067067	30695	82	17C
0005434067038	30695	83	17F
0005434067029	30695	84	17E
0005434067082	30695	85	18A
0005434067080	30695	86	18B
0005434067072	30695	87	18C
0005434067058	30695	88	18E
0005432150134	30695	89	18D
0005434067081	30695	90	18F
0005434081732	30695	91	19A
0005434067047	30695	92	19B
0005434067070	30695	93	19C
0005434081738	30695	94	19E
0005434067028	30695	95	19D
0005433989735	30695	96	19F
0005434067057	30695	97	20A
0005434081746	30695	98	20B
0005432433593	30695	99	20D
0005432186842	30695	100	20C
0005434081745	30695	101	20E
0005434067071	30695	102	20F
0005434067063	30695	103	21B
0005432186844	30695	104	21A
0005434067042	30695	105	21C
0005434067075	30695	106	21D
0005434067084	30695	107	21F
0005434081733	30695	108	21E
0005434067074	30695	109	22B
0005432433590	30695	110	22C
0005432433583	30695	111	22D
0005434081741	30695	112	22E
0005434067076	30695	113	22F
0005434067055	30695	114	23B
0005434081734	30695	115	23A
0005432433591	30695	116	23C
0005434067053	30695	117	23E
0005434081736	30695	118	23D
0005434081744	30695	119	23F
0005433689878	19365	1	3B
0005433689877	19365	2	4D
0005433689884	19365	3	5A
0005433689879	19365	4	5C
0005433689874	19365	5	6C
0005433689883	19365	6	18C
0005433689881	19365	7	19D
0005433689882	19365	8	20D
0005433689880	19365	9	21A
0005434264692	5501	1	1A
0005435765830	5501	2	1F
0005435765869	5501	3	1H
0005434264748	5501	4	2B
0005435461930	5501	5	2F
0005434264737	5501	6	2C
0005435765851	5501	7	2G
0005434264677	5501	8	3A
0005435461933	5501	9	3B
0005433527243	5501	10	3F
0005435765850	5501	11	3C
0005435461913	5501	12	3G
0005434264700	5501	13	4B
0005435765854	5501	14	4A
0005434264797	5501	15	4C
0005435725563	5501	16	4G
0005435765849	5501	17	5A
0005435765812	5501	18	5B
0005435765823	5501	19	5C
0005435461859	5501	20	5G
0005435722040	5501	21	9A
0005435765853	5501	22	9G
0005435765848	5501	23	11A
0005435765831	5501	24	11B
0005435461902	5501	25	11G
0005434264722	5501	26	11F
0005435765860	5501	27	11H
0005435461813	5501	28	12B
0005434264773	5501	29	12A
0005435765858	5501	30	12D
0005435461968	5501	31	12E
0005435461977	5501	32	12G
0005435765837	5501	33	12F
0005435765835	5501	34	12H
0005435461834	5501	35	13A
0005435461878	5501	36	13D
0005435765843	5501	37	13B
0005435461768	5501	38	13E
0005435765832	5501	39	13G
0005433527242	5501	40	13F
0005435765826	5501	41	13H
0005435461914	5501	42	14A
0005434264739	5501	43	14D
0005434264788	5501	44	14B
0005435461814	5501	45	14E
0005434264703	5501	46	14G
0005435723031	5501	47	14F
0005435765808	5501	48	15A
0005434264828	5501	49	14H
0005435725564	5501	50	15B
0005435765845	5501	51	15E
0005435765817	5501	52	15G
0005433529255	5501	53	15H
0005434264827	5501	54	16A
0005435765842	5501	55	16D
0005434264705	5501	56	16B
0005435461797	5501	57	16F
0005435765815	5501	58	16H
0005433529256	5501	59	16G
0005435461879	5501	60	17B
0005435765824	5501	61	17A
0005435765864	5501	62	17D
0005433527246	5501	63	17E
0005435765866	5501	64	17G
0005435765861	5501	65	17F
0005435765821	5501	66	17H
0005434264777	5501	67	18B
0005435461795	5501	68	19A
0005435461931	5501	69	19D
0005435765820	5501	70	19F
0005435765829	5501	71	19E
0005435461903	5501	72	19G
0005435735106	5501	73	20B
0005435765839	5501	74	20E
0005435461890	5501	75	20D
0005435461858	5501	76	20G
0005435461973	5501	77	20H
0005435461907	5501	78	21D
0005435765871	5501	79	21B
0005434264770	5501	80	21E
0005434264690	5501	81	21F
0005435765811	5501	82	21H
0005434264789	5501	83	21G
0005435722039	5501	84	22B
0005435765809	5501	85	22A
0005435765816	5501	86	22D
0005435765828	5501	87	22E
0005435735108	5501	88	22G
0005432140396	5501	89	22H
0005434264689	5501	90	23B
0005432140392	5501	91	23E
0005435765844	5501	92	23G
0005435461857	5501	93	23F
0005435765870	5501	94	23H
0005435461937	5501	95	24B
0005435461901	5501	96	24A
0005434264704	5501	97	24F
0005435723032	5501	98	24E
0005435461801	5501	99	24G
0005435735105	5501	100	25E
0005435765827	5501	101	25F
0005435765814	5501	102	27B
0005435461938	5501	103	27A
0005435725565	5501	104	27E
0005435765838	5501	105	27D
0005434264740	5501	106	27H
0005435765856	5501	107	27G
0005432140393	5501	108	28A
0005435725562	5501	109	28D
0005435461851	5501	110	28B
0005432140398	5501	111	28E
0005432140391	5501	112	28F
0005433527244	5501	113	28G
0005434264795	5501	114	28H
0005434264685	5501	115	29B
0005435765855	5501	116	29E
0005435765868	5501	117	29D
0005435765836	5501	118	29G
0005435765813	5501	119	29F
0005435461853	5501	120	29H
0005435765865	5501	121	30A
0005435765857	5501	122	30D
0005435461774	5501	123	30H
0005435765834	5501	124	30G
0005435765852	5501	125	30F
0005435765846	5501	126	31A
0005432140397	5501	127	31D
0005435461976	5501	128	31G
0005432140394	5501	129	31H
0005433529254	5501	130	32D
0005434831076	5501	131	32B
0005435461784	5501	132	32F
0005434831075	5501	133	32H
0005434264701	5501	134	32G
0005435461783	5501	135	33E
0005435765822	5501	136	33G
0005435461904	5501	137	33F
0005435765810	5501	138	33H
0005435765833	5501	139	34A
0005435765859	5501	140	34B
0005432140395	5501	141	34F
0005435765819	5501	142	34E
0005435461802	5501	143	35A
0005434831070	5501	144	34H
0005435765825	5501	145	35B
0005434264816	5501	146	35D
0005434264738	5501	147	35F
0005435461767	5501	148	35E
0005435461882	5501	149	35G
0005434264778	5501	150	36E
0005433527245	5501	151	36D
0005434264787	5501	152	36F
0005435735107	5501	153	37A
0005435765840	5501	154	36H
0005435765867	5501	155	37D
0005435765863	5501	156	37B
0005434264702	5501	157	37G
0005435735109	5501	158	38A
0005435725566	5501	159	37H
0005435765841	5501	160	38D
0005435765862	5501	161	38B
0005434264688	5501	162	38E
0005435765818	5501	163	38G
0005435461844	5501	164	38H
0005435765847	5501	165	39E
0005435461886	5501	166	39D
0005435461912	5501	167	39F
0005434264983	13471	1	1F
0005434264980	13471	2	2A
0005434264979	13471	3	1H
0005435462182	13471	4	2C
0005433533241	13471	5	2H
0005435765313	13471	6	2G
0005434264978	13471	7	3B
0005435462206	13471	8	3G
0005434264967	13471	9	3H
0005433529215	13471	10	4B
0005435720119	13471	11	4A
0005432535802	13471	12	4G
0005432194486	13471	13	4H
0005434264987	13471	14	5A
0005434264991	13471	15	5F
0005434264982	13471	16	9A
0005435723016	13471	17	5H
0005434264986	13471	18	9G
0005433533240	13471	19	11A
0005435765236	13471	20	9H
0005435462190	13471	21	11B
0005435462211	13471	22	11D
0005435765221	13471	23	11F
0005435765199	13471	24	12A
0005435462189	13471	25	11H
0005435765151	13471	26	12D
0005432535805	13471	27	12B
0005433533244	13471	28	12E
0005435462185	13471	29	12F
0005435765332	13471	30	12H
0005435765275	13471	31	13A
0005435765279	13471	32	13D
0005435765276	13471	33	13E
0005435765225	13471	34	14A
0005434264976	13471	35	14D
0005435765200	13471	36	14E
0005435725538	13471	37	15A
0005435462213	13471	38	16D
0005435765330	13471	39	16G
0005434264990	13471	40	16H
0005434264966	13471	41	17G
0005435462194	13471	42	17F
0005435765150	13471	43	18A
0005435462215	13471	44	18B
0005435043280	13471	45	18D
0005433533242	13471	46	18G
0005433533243	13471	47	18H
0005435765230	13471	48	19B
0005435043278	13471	49	19A
0005433533259	13471	50	19F
0005435462192	13471	51	19E
0005434831121	13471	52	19H
0005435462183	13471	53	19G
0005435462201	13471	54	20F
0005435765298	13471	55	21A
0005435735082	13471	56	20H
0005435462193	13471	57	21D
0005435462218	13471	58	21H
0005435462198	13471	59	21G
0005435765331	13471	60	22D
0005434264975	13471	61	22E
0005435462191	13471	62	22G
0005435043279	13471	63	22F
0005434264974	13471	64	23A
0005435462202	13471	65	22H
0005434264969	13471	66	23F
0005434264972	13471	67	23E
0005435765157	13471	68	23H
0005435462209	13471	69	24B
0005435462195	13471	70	24A
0005435765158	13471	71	24E
0005435462196	13471	72	24H
0005434831123	13471	73	25F
0005435462208	13471	74	25E
0005435462214	13471	75	27A
0005435765193	13471	76	27E
0005435462186	13471	77	27F
0005435725519	13471	78	27H
0005435765192	13471	79	27G
0005434831122	13471	80	28B
0005435765266	13471	81	28E
0005435765288	13471	82	28D
0005435765154	13471	83	28F
0005433533246	13471	84	28H
0005435462200	13471	85	28G
0005435765198	13471	86	29A
0005435725537	13471	87	29B
0005432194485	13471	88	29E
0005432194482	13471	89	29G
0005435462184	13471	90	30D
0005435720118	13471	91	30E
0005435462216	13471	92	30G
0005434264971	13471	93	30H
0005434264989	13471	94	31D
0005435462217	13471	95	31F
0005435462204	13471	96	31E
0005434264985	13471	97	31G
0005433533257	13471	98	32A
0005435462199	13471	99	31H
0005435462203	13471	100	32B
0005435765258	13471	101	32F
0005435765227	13471	102	32H
0005435462207	13471	103	33B
0005435462205	13471	104	33H
0005435462219	13471	105	33G
0005435462197	13471	106	34A
0005434264970	13471	107	34F
0005435765194	13471	108	34E
0005435462210	13471	109	34G
0005434264968	13471	110	35B
0005432535806	13471	111	35A
0005434264988	13471	112	35D
0005435462181	13471	113	35F
0005434264973	13471	114	35G
0005432535804	13471	115	36A
0005433533258	13471	116	36B
0005435462188	13471	117	36D
0005432194484	13471	118	36F
0005432535803	13471	119	36G
0005433529216	13471	120	37A
0005435765231	13471	121	36H
0005435765226	13471	122	37E
0005434264984	13471	123	37D
0005435723014	13471	124	37F
0005435462187	13471	125	37H
0005432194483	13471	126	38A
0005434264977	13471	127	38B
0005435462212	13471	128	38E
0005434264981	13471	129	38G
0005433533245	13471	130	39E
0005434602859	18743	1	2A
0005434602862	18743	2	3B
0005434602863	18743	3	4A
0005434602858	18743	4	5A
0005434602861	18743	5	5B
0005434604841	18671	1	2A
0005434513561	18671	2	1B
0005434604842	18671	3	2B
0005434513563	18671	4	3A
0005434514949	18671	5	3B
0005434513562	18671	6	4A
0005434513564	18671	7	5A
0005434514948	18671	8	5B
0005434604853	18671	9	6A
0005432632704	4122	1	1C
0005435844260	4122	2	2A
0005435846195	4122	3	2D
0005435846197	4122	4	4A
0005432632687	4122	5	4C
0005432649361	4122	6	4F
0005432649360	4122	7	5A
0005432632694	4122	8	5F
0005432632688	4122	9	6A
0005432649369	4122	10	6C
0005432632699	4122	11	6E
0005432632691	4122	12	6F
0005432649363	4122	13	7C
0005432649364	4122	14	7E
0005432632705	4122	15	8C
0005432632686	4122	16	9C
0005432649357	4122	17	9F
0005435846193	4122	18	10C
0005432649362	4122	19	10E
0005432632700	4122	20	10F
0005432632701	4122	21	11C
0005432632690	4122	22	11D
0005432649368	4122	23	11E
0005432632684	4122	24	12A
0005432649365	4122	25	12E
0005432649353	4122	26	13E
0005435844261	4122	27	14A
0005432632693	4122	28	14C
0005435846196	4122	29	15C
0005432649352	4122	30	15D
0005435846216	4122	31	15E
0005432649359	4122	32	15F
0005435846191	4122	33	16C
0005435846200	4122	34	16D
0005432632702	4122	35	16E
0005432649354	4122	36	16F
0005432632703	4122	37	17C
0005432632685	4122	38	17D
0005432632695	4122	39	17E
0005432632696	4122	40	17F
0005432632689	4122	41	18A
0005432649356	4122	42	18D
0005432632692	4122	43	19A
0005432649367	4122	44	19C
0005432649355	4122	45	19E
0005432649366	4122	46	19F
0005432632697	4122	47	20A
0005432649358	4122	48	20E
0005432632698	4122	49	20F
0005432295862	1818	1	1A
0005433008038	1818	2	1C
0005433007931	1818	3	1D
0005433007890	1818	4	1F
0005433284871	1818	5	2A
0005433284833	1818	6	2C
0005433284908	1818	7	2D
0005433284778	1818	8	2F
0005433284839	1818	9	3A
0005433284922	1818	10	3C
0005433284874	1818	11	3D
0005433284864	1818	12	3F
0005433007972	1818	13	4A
0005433284926	1818	14	4D
0005433284960	1818	15	4E
0005433284832	1818	16	4F
0005433008212	1818	17	5A
0005433284959	1818	18	5C
0005433284779	1818	19	5D
0005433284882	1818	20	5E
0005433008109	1818	21	5F
0005432295865	1818	22	6A
0005433007958	1818	23	6C
0005433007923	1818	24	6D
0005433008121	1818	25	6E
0005433007980	1818	26	6F
0005433008016	1818	27	7A
0005432295863	1818	28	7C
0005433007944	1818	29	7E
0005433284810	1818	30	7F
0005433284863	1818	31	8A
0005433284827	1818	32	8C
0005433284811	1818	33	8D
0005433008073	1818	34	8E
0005433008028	1818	35	8F
0005433284826	1818	36	9A
0005433284880	1818	37	9C
0005433284889	1818	38	9D
0005433007943	1818	39	9E
0005433284940	1818	40	9F
0005433284920	1818	41	10A
0005433284927	1818	42	10D
0005433284847	1818	43	10E
0005433284921	1818	44	10F
0005433284835	1818	45	11A
0005433007925	1818	46	11C
0005433007878	1818	47	11D
0005433007924	1818	48	11E
0005433284943	1818	49	11F
0005433810520	1818	50	12A
0005433007893	1818	51	12C
0005433284846	1818	52	12D
0005433284881	1818	53	12E
0005433284862	1818	54	12F
0005433284836	1818	55	13A
0005433284831	1818	56	13C
0005433007953	1818	57	13D
0005432295864	1818	58	13F
0005433284834	1818	59	14A
0005433007971	1818	60	14D
0005433007970	1818	61	14E
0005433007959	1818	62	14F
0005433810518	1818	63	15A
0005433284830	1818	64	15D
0005433284937	1818	65	16A
0005433008116	1818	66	16D
0005433284909	1818	67	16E
0005433284860	1818	68	16F
0005433284850	1818	69	17A
0005433007969	1818	70	17C
0005433007841	1818	71	17D
0005433007930	1818	72	17E
0005433007973	1818	73	17F
0005433007917	1818	74	18A
0005433008063	1818	75	18C
0005433007879	1818	76	18D
0005433284789	1818	77	18F
0005433008085	1818	78	19A
0005433008074	1818	79	19C
0005433810519	1818	80	19D
0005433007979	1818	81	19E
0005433008017	1818	82	19F
0005433284848	1818	83	20A
0005433008027	1818	84	20C
0005433284851	1818	85	20E
0005433284790	1818	86	20F
0005433285075	22596	1	1C
0005433008306	22596	2	1D
0005433008292	22596	3	1F
0005433285083	22596	4	2A
0005433285100	22596	5	2C
0005433008320	22596	6	2D
0005433285072	22596	7	2F
0005433285080	22596	8	3A
0005433285091	22596	9	3C
0005433285092	22596	10	3D
0005433008309	22596	11	3F
0005433008294	22596	12	4A
0005433008289	22596	13	4C
0005433008305	22596	14	4D
0005433285081	22596	15	4E
0005433008310	22596	16	5E
0005433008290	22596	17	6A
0005433008286	22596	18	6C
0005433008327	22596	19	6D
0005433008304	22596	20	6E
0005433285087	22596	21	6F
0005433285094	22596	22	7A
0005433285098	22596	23	7C
0005433008301	22596	24	7D
0005433008317	22596	25	7F
0005433285089	22596	26	8C
0005433008316	22596	27	8D
0005433008311	22596	28	8F
0005433285101	22596	29	9A
0005433008293	22596	30	9C
0005433008329	22596	31	9D
0005433008319	22596	32	9E
0005433008287	22596	33	9F
0005433008291	22596	34	10A
0005433008314	22596	35	10C
0005433008297	22596	36	10D
0005433008298	22596	37	10E
0005433008332	22596	38	10F
0005433008315	22596	39	11A
0005433008330	22596	40	11C
0005433008322	22596	41	11D
0005433008328	22596	42	11F
0005433285082	22596	43	12A
0005433008321	22596	44	12C
0005433285090	22596	45	12F
0005433008318	22596	46	13A
0005433008295	22596	47	13C
0005433008303	22596	48	13D
0005433285077	22596	49	13E
0005433285073	22596	50	13F
0005433008296	22596	51	14A
0005433285074	22596	52	14C
0005433008307	22596	53	14D
0005433285095	22596	54	14E
0005433008312	22596	55	14F
0005433285093	22596	56	15A
0005433285076	22596	57	15D
0005433285088	22596	58	15E
0005433008324	22596	59	15F
0005433285079	22596	60	16C
0005433285078	22596	61	16E
0005433008326	22596	62	16F
0005433285084	22596	63	17A
0005433008331	22596	64	17C
0005433285086	22596	65	17D
0005433008300	22596	66	17E
0005433008325	22596	67	18A
0005433008313	22596	68	18C
0005433008323	22596	69	18D
0005433285096	22596	70	18E
0005433008302	22596	71	18F
0005433008288	22596	72	19C
0005433285102	22596	73	19E
0005433008308	22596	74	19F
0005433008299	22596	75	20A
0005433285099	22596	76	20C
0005433285071	22596	77	20D
0005433285097	22596	78	20E
0005433285085	22596	79	20F
0005435282055	5590	1	1C
0005433846366	5590	2	1A
0005435282176	5590	3	1F
0005435282109	5590	4	1D
0005433846348	5590	5	2C
0005433815352	5590	6	2D
0005433815354	5590	7	3A
0005433846378	5590	8	2F
0005433846370	5590	9	3D
0005433815353	5590	10	3C
0005432081469	5590	11	3F
0005435282188	5590	12	4C
0005433846359	5590	13	4A
0005433846336	5590	14	4D
0005433846349	5590	15	5C
0005433815351	5590	16	5F
0005433846352	5590	17	6B
0005434173459	5590	18	6A
0005433846328	5590	19	6C
0005433846362	5590	20	6D
0005433846356	5590	21	6F
0005433846324	5590	22	7D
0005433846369	5590	23	8A
0005433846344	5590	24	8C
0005433846373	5590	25	8D
0005435282175	5590	26	8F
0005433846342	5590	27	8E
0005433846329	5590	28	9B
0005433846351	5590	29	9A
0005435282065	5590	30	9C
0005433846365	5590	31	9E
0005435282203	5590	32	10A
0005433846376	5590	33	9F
0005435282122	5590	34	10C
0005432081472	5590	35	10B
0005433846335	5590	36	10E
0005433846331	5590	37	10D
0005433846361	5590	38	11A
0005433846346	5590	39	10F
0005433846363	5590	40	11B
0005433846350	5590	41	11D
0005435282202	5590	42	11C
0005432081471	5590	43	11F
0005433846325	5590	44	11E
0005434173472	5590	45	12B
0005435282189	5590	46	12A
0005433846337	5590	47	12D
0005435282066	5590	48	12C
0005433846368	5590	49	12F
0005433846338	5590	50	12E
0005433846357	5590	51	13A
0005433846353	5590	52	13B
0005433846340	5590	53	13D
0005433846345	5590	54	14A
0005435282149	5590	55	13F
0005435282167	5590	56	14C
0005433846334	5590	57	14B
0005435282181	5590	58	14E
0005432081468	5590	59	14F
0005433846341	5590	60	15B
0005434173458	5590	61	15A
0005433846354	5590	62	15D
0005433846367	5590	63	16A
0005433846355	5590	64	15F
0005435282147	5590	65	16B
0005433846360	5590	66	16D
0005433846374	5590	67	17A
0005433846321	5590	68	16E
0005432081467	5590	69	17B
0005433846358	5590	70	17D
0005433846375	5590	71	17C
0005433846326	5590	72	17E
0005433846343	5590	73	18A
0005433846330	5590	74	18D
0005433846332	5590	75	18C
0005433846327	5590	76	18B
0005433846371	5590	77	18E
0005434173454	5590	78	19A
0005433846364	5590	79	18F
0005433846339	5590	80	19B
0005433846347	5590	81	19F
0005433846322	5590	82	20B
0005433846377	5590	83	20A
0005433846372	5590	84	20D
0005435282086	5590	85	20C
0005433846379	5590	86	20F
0005435282056	5590	87	21A
0005432081470	5590	88	21D
0005433846333	5590	89	21C
0005435282110	5590	90	21B
0005432081466	5590	91	21F
0005433846323	5590	92	21E
0005434173497	13857	1	1A
0005433845911	13857	2	1D
0005435282344	13857	3	1C
0005435282347	13857	4	1F
0005433846065	13857	5	3A
0005435282364	13857	6	2F
0005433845786	13857	7	3C
0005433845922	13857	8	4D
0005435282361	13857	9	4C
0005433845827	13857	10	4F
0005433846055	13857	11	5D
0005435282363	13857	12	5C
0005435282362	13857	13	5A
0005433845714	13857	14	5F
0005433845804	13857	15	6B
0005435282348	13857	16	6A
0005433845819	13857	17	6D
0005432003681	13857	18	6E
0005433845989	13857	19	7C
0005433845742	13857	20	7B
0005435282360	13857	21	7F
0005433845712	13857	22	7E
0005435282340	13857	23	8C
0005433845945	13857	24	8B
0005433845954	13857	25	8A
0005433846054	13857	26	8D
0005435282359	13857	27	9B
0005433845891	13857	28	9A
0005435282353	13857	29	9C
0005435282367	13857	30	9E
0005433845838	13857	31	9D
0005433846025	13857	32	10A
0005433845803	13857	33	10C
0005433845975	13857	34	10B
0005435282366	13857	35	10D
0005435282339	13857	36	10F
0005433845898	13857	37	10E
0005433845713	13857	38	11D
0005433845781	13857	39	11F
0005435282357	13857	40	12B
0005435282358	13857	41	12A
0005433845774	13857	42	12D
0005433846000	13857	43	12E
0005433815314	13857	44	13B
0005434173494	13857	45	13A
0005435282355	13857	46	13C
0005435282356	13857	47	13E
0005435282351	13857	48	13D
0005433845874	13857	49	13F
0005435282352	13857	50	14C
0005433845683	13857	51	14B
0005433845705	13857	52	14A
0005435282349	13857	53	14D
0005433845889	13857	54	15B
0005433845815	13857	55	15A
0005432003680	13857	56	15C
0005435282346	13857	57	15F
0005433845856	13857	58	15E
0005434173493	13857	59	15D
0005433845885	13857	60	16A
0005433845818	13857	61	16C
0005435282354	13857	62	16B
0005435282342	13857	63	16E
0005433845859	13857	64	16D
0005433845929	13857	65	16F
0005432003682	13857	66	17A
0005433845787	13857	67	17D
0005433845711	13857	68	17C
0005433846053	13857	69	17F
0005435282345	13857	70	17E
0005433845892	13857	71	18C
0005435282365	13857	72	18B
0005433845988	13857	73	18E
0005433845914	13857	74	18D
0005433845934	13857	75	19A
0005433845884	13857	76	18F
0005433845995	13857	77	19D
0005433845807	13857	78	19C
0005435282341	13857	79	19F
0005433845779	13857	80	19E
0005433845996	13857	81	20B
0005433845990	13857	82	20A
0005434173496	13857	83	20D
0005435282350	13857	84	20E
0005435282343	13857	85	21A
0005433846039	13857	86	20F
0005433845899	13857	87	21C
0005433845780	13857	88	21B
0005434173495	13857	89	21E
0005433845976	13857	90	21D
0005434620473	7824	1	1A
0005434620465	7824	2	1B
0005434620458	7824	3	1C
0005435332177	7824	4	1D
0005434620464	7824	5	2A
0005434620466	7824	6	2B
0005435332189	7824	7	2C
0005434620471	7824	8	3C
0005434620454	7824	9	4C
0005434620453	7824	10	4D
0005434620455	7824	11	5A
0005434620461	7824	12	5B
0005432112501	7824	13	5D
0005434620468	7824	14	6A
0005432112502	7824	15	6C
0005435332190	7824	16	6D
0005434620467	7824	17	7A
0005434620457	7824	18	7C
0005435332184	7824	19	7D
0005435332203	7824	20	18B
0005435332204	7824	21	18D
0005434620456	7824	22	19A
0005435332202	7824	23	19B
0005434620470	7824	24	19C
0005434620459	7824	25	20A
0005434620469	7824	26	20B
0005435332212	7824	27	20C
0005434620463	7824	28	21A
0005432112500	7824	29	21B
0005434620462	7824	30	21C
0005435332213	7824	31	21D
0005434620472	7824	32	22C
0005434620460	7824	33	22D
0005434620366	32963	1	1C
0005434620233	32963	2	1B
0005434620343	32963	3	2A
0005434620365	32963	4	2B
0005434620315	32963	5	3A
0005434620305	32963	6	3B
0005434620247	32963	7	3C
0005434620314	32963	8	4C
0005434620318	32963	9	5B
0005434620367	32963	10	5C
0005434620232	32963	11	5D
0005435332265	32963	12	6B
0005435332273	32963	13	6D
0005434620238	32963	14	7B
0005435332271	32963	15	7C
0005434620248	32963	16	7D
0005435332264	32963	17	18B
0005434620237	32963	18	18D
0005434620319	32963	19	19A
0005434620342	32963	20	19C
0005435332270	32963	21	19B
0005435332272	32963	22	19D
0005434620283	32963	23	20B
0005434620279	32963	24	20C
0005435332267	32963	25	20D
0005435332269	32963	26	21B
0005434620282	32963	27	21D
0005435332266	32963	28	22A
0005435332268	32963	29	22C
0005435785123	4278	1	1A
0005435785126	4278	2	1C
0005432190606	4278	3	1D
0005434993962	4278	4	1F
0005435785146	4278	5	2D
0005435785122	4278	6	3A
0005435785139	4278	7	3C
0005435785117	4278	8	3D
0005435785118	4278	9	3F
0005434993960	4278	10	4A
0005435785142	4278	11	4D
0005435785135	4278	12	4E
0005435785125	4278	13	4F
0005435785130	4278	14	5C
0005435785150	4278	15	5D
0005435785133	4278	16	5E
0005435937323	4278	17	5F
0005435937324	4278	18	6D
0005435937307	4278	19	6F
0005434993955	4278	20	7C
0005435785140	4278	21	7D
0005435918598	4278	22	7E
0005435785136	4278	23	8C
0005435785144	4278	24	8E
0005435918580	4278	25	8F
0005434993958	4278	26	9A
0005435785124	4278	27	9F
0005435918610	4278	28	10A
0005435785129	4278	29	10C
0005432190604	4278	30	10E
0005435785132	4278	31	11C
0005434993961	4278	32	11D
0005435785148	4278	33	11E
0005434993964	4278	34	12A
0005434993957	4278	35	12C
0005435918589	4278	36	12D
0005435785143	4278	37	12E
0005435785127	4278	38	13C
0005435785138	4278	39	13E
0005435785120	4278	40	13F
0005432190603	4278	41	14A
0005434993956	4278	42	14C
0005435937319	4278	43	14D
0005435785145	4278	44	14E
0005435918588	4278	45	14F
0005435785131	4278	46	15A
0005435785147	4278	47	15D
0005435937308	4278	48	15E
0005435785121	4278	49	15F
0005435785149	4278	50	16A
0005435785119	4278	51	16C
0005435785116	4278	52	16F
0005434993963	4278	53	17F
0005435937322	4278	54	18A
0005435918592	4278	55	18C
0005432190605	4278	56	18D
0005434993959	4278	57	19A
0005435785141	4278	58	19C
0005435785134	4278	59	19D
0005435785137	4278	60	20A
0005435785128	4278	61	20C
0005435785152	4278	62	20E
0005435785151	4278	63	20F
0005435784742	27306	1	1A
0005435784768	27306	2	1C
0005435784873	27306	3	1D
0005435918623	27306	4	1F
0005435784755	27306	5	2A
0005435784776	27306	6	2D
0005432195678	27306	7	3F
0005435784780	27306	8	4C
0005435784853	27306	9	4D
0005435784739	27306	10	5A
0005435784825	27306	11	5C
0005434993903	27306	12	5E
0005435784833	27306	13	5F
0005435784789	27306	14	6A
0005434993901	27306	15	6C
0005435784775	27306	16	6F
0005435784858	27306	17	7C
0005435784770	27306	18	7E
0005434993868	27306	19	8D
0005435784830	27306	20	8F
0005434993902	27306	21	9A
0005435784808	27306	22	9C
0005435784812	27306	23	9F
0005435784793	27306	24	10C
0005435937357	27306	25	11C
0005434993876	27306	26	11E
0005435937352	27306	27	11F
0005435937353	27306	28	12A
0005435784792	27306	29	12C
0005434993873	27306	30	13A
0005435918626	27306	31	13C
0005435937349	27306	32	13E
0005434993847	27306	33	13F
0005435937355	27306	34	14E
0005435784904	27306	35	15C
0005435784807	27306	36	16A
0005435918624	27306	37	16D
0005434993869	27306	38	16E
0005435784844	27306	39	17A
0005435784774	27306	40	17C
0005435784738	27306	41	17F
0005435918625	27306	42	18A
0005435937350	27306	43	18C
0005435937356	27306	44	18E
0005435937354	27306	45	19A
0005435784903	27306	46	19D
0005435784826	27306	47	19F
0005435918622	27306	48	20A
0005435937351	27306	49	20D
0005432146184	19853	1	5D
0005432146185	19853	2	21B
0005432459516	4724	1	1A
0005432459517	4724	2	1B
0005433451607	4724	3	1F
0005432567254	4724	4	1G
0005432571298	4724	5	2A
0005432459535	4724	6	1H
0005432459493	4724	7	2B
0005434081751	4724	8	2C
0005432459496	4724	9	2H
0005432567274	4724	10	2G
0005432459506	4724	11	3B
0005432459503	4724	12	3C
0005432459534	4724	13	3G
0005432186847	4724	14	4B
0005432459509	4724	15	4C
0005432459505	4724	16	4G
0005433452728	4724	17	4H
0005432459525	4724	18	5G
0005432567217	4724	19	9A
0005432459491	4724	20	9H
0005434081755	4724	21	9G
0005432567245	4724	22	11A
0005432567237	4724	23	11D
0005432567225	4724	24	11B
0005432567239	4724	25	11E
0005432459508	4724	26	11F
0005432170343	4724	27	11H
0005432459492	4724	28	11G
0005432459499	4724	29	12B
0005434081753	4724	30	12D
0005432567264	4724	31	12G
0005432459538	4724	32	12F
0005432567249	4724	33	12H
0005434081754	4724	34	13A
0005432459530	4724	35	13D
0005432567250	4724	36	13B
0005432567214	4724	37	13F
0005432567255	4724	38	13E
0005432170341	4724	39	13G
0005433452727	4724	40	14B
0005432567222	4724	41	14E
0005432567235	4724	42	14D
0005432459510	4724	43	14G
0005432567253	4724	44	15A
0005432459539	4724	45	14H
0005432459495	4724	46	15B
0005432170347	4724	47	15E
0005432567260	4724	48	15F
0005432186846	4724	49	16B
0005432459518	4724	50	16A
0005432567269	4724	51	16D
0005432567267	4724	52	16G
0005432459500	4724	53	17A
0005432567231	4724	54	17B
0005432459494	4724	55	17E
0005432459541	4724	56	18A
0005432170345	4724	57	17H
0005432459512	4724	58	18D
0005432459521	4724	59	18B
0005432567262	4724	60	18E
0005432567257	4724	61	18H
0005432567258	4724	62	19B
0005432459522	4724	63	19E
0005432567263	4724	64	19D
0005433451606	4724	65	19F
0005432567271	4724	66	19H
0005432567252	4724	67	19G
0005432567241	4724	68	20A
0005432571295	4724	69	20B
0005432170344	4724	70	20F
0005432459537	4724	71	20H
0005432459542	4724	72	20G
0005432459531	4724	73	21B
0005432567251	4724	74	21G
0005432571296	4724	75	21F
0005432459513	4724	76	21H
0005432567270	4724	77	22A
0005432459515	4724	78	22E
0005432567228	4724	79	23B
0005434081749	4724	80	23E
0005432567273	4724	81	23G
0005432567247	4724	82	23F
0005432567261	4724	83	24A
0005432459504	4724	84	23H
0005432459523	4724	85	24B
0005432567256	4724	86	24D
0005432567227	4724	87	24F
0005432567246	4724	88	24E
0005432459528	4724	89	24H
0005432459520	4724	90	25E
0005432459514	4724	91	25D
0005432170346	4724	92	27A
0005432567226	4724	93	25F
0005432567268	4724	94	27B
0005434081752	4724	95	28A
0005434081758	4724	96	27H
0005432567221	4724	97	28D
0005432571297	4724	98	28B
0005432567224	4724	99	28E
0005432459507	4724	100	28H
0005432567238	4724	101	28G
0005432459490	4724	102	29A
0005432567242	4724	103	29E
0005432567266	4724	104	29D
0005432459543	4724	105	29F
0005432567230	4724	106	30A
0005432459511	4724	107	30D
0005434081757	4724	108	30B
0005432567220	4724	109	30F
0005432567265	4724	110	30E
0005432459498	4724	111	30G
0005432567215	4724	112	30H
0005433726090	4724	113	31B
0005432459519	4724	114	31A
0005432459544	4724	115	31E
0005432567259	4724	116	31D
0005432567233	4724	117	31F
0005432567229	4724	118	31G
0005432459497	4724	119	31H
0005433452725	4724	120	32B
0005432567219	4724	121	32D
0005432567240	4724	122	32F
0005432459540	4724	123	32E
0005432567272	4724	124	32H
0005432567236	4724	125	33B
0005432459502	4724	126	33F
0005432567218	4724	127	33H
0005434081756	4724	128	34B
0005434559090	4724	129	34F
0005432459536	4724	130	34E
0005432567243	4724	131	34G
0005432170342	4724	132	35E
0005434559091	4724	133	35G
0005432567244	4724	134	36A
0005432459533	4724	135	35H
0005432567275	4724	136	36B
0005432459501	4724	137	36D
0005432459526	4724	138	36G
0005432459529	4724	139	36H
0005432459527	4724	140	37E
0005432459524	4724	141	37D
0005434081750	4724	142	37F
0005432567248	4724	143	37G
0005433726089	4724	144	38B
0005432459532	4724	145	37H
0005432567223	4724	146	38D
0005432567232	4724	147	38E
0005433452726	4724	148	38F
0005432567216	4724	149	39D
0005432567234	4724	150	39F
0005432459213	30570	1	1B
0005432459141	30570	2	1F
0005432566593	30570	3	2C
0005432566886	30570	4	2H
0005432459016	30570	5	3C
0005432459173	30570	6	3G
0005432459233	30570	7	4B
0005432566621	30570	8	4F
0005432213582	30570	9	4G
0005432566875	30570	10	4H
0005432213583	30570	11	5B
0005432459382	30570	12	5H
0005434081499	30570	13	9B
0005432459215	30570	14	9A
0005432458997	30570	15	9H
0005432566723	30570	16	11A
0005432566842	30570	17	11B
0005432458979	30570	18	11E
0005432459347	30570	19	11F
0005434081512	30570	20	11G
0005434081579	30570	21	12A
0005432566612	30570	22	12D
0005432459297	30570	23	12H
0005432566605	30570	24	12G
0005434081519	30570	25	13B
0005433454844	30570	26	13F
0005432458991	30570	27	13G
0005434081538	30570	28	13H
0005432571257	30570	29	14A
0005432459346	30570	30	14D
0005432213581	30570	31	14B
0005432566766	30570	32	14F
0005432566671	30570	33	15A
0005435840359	30570	34	15E
0005432459243	30570	35	15G
0005432571289	30570	36	15H
0005432459207	30570	37	16E
0005432458961	30570	38	16H
0005432566702	30570	39	17E
0005432458998	30570	40	17F
0005432566881	30570	41	18A
0005434081477	30570	42	18D
0005432458990	30570	43	18E
0005434081484	30570	44	18H
0005432459078	30570	45	19D
0005432566874	30570	46	19F
0005432566606	30570	47	19E
0005432566672	30570	48	19G
0005432566715	30570	49	19H
0005434081530	30570	50	20D
0005432566798	30570	51	20B
0005432571272	30570	52	20E
0005432161139	30570	53	20H
0005432161137	30570	54	21B
0005432459023	30570	55	21E
0005432567002	30570	56	21H
0005432571276	30570	57	22E
0005432566954	30570	58	23A
0005434081550	30570	59	22H
0005432566703	30570	60	23D
0005434081520	30570	61	23F
0005432459200	30570	62	23E
0005432566925	30570	63	23H
0005432459090	30570	64	24D
0005432566757	30570	65	24B
0005432566893	30570	66	24A
0005432566729	30570	67	24F
0005434081555	30570	68	24H
0005432566910	30570	69	24G
0005432458989	30570	70	25D
0005432459012	30570	71	25F
0005432459015	30570	72	27A
0005432566785	30570	73	27H
0005432213580	30570	74	28A
0005432459206	30570	75	28E
0005432566552	30570	76	29A
0005432566765	30570	77	29E
0005432459216	30570	78	29H
0005432459274	30570	79	30B
0005434081593	30570	80	30F
0005432566730	30570	81	30G
0005434081487	30570	82	31D
0005432566724	30570	83	31F
0005432459246	30570	84	31E
0005432566670	30570	85	31G
0005432161138	30570	86	32B
0005432566992	30570	87	32D
0005432566989	30570	88	32G
0005432567011	30570	89	33A
0005432458995	30570	90	33E
0005432459159	30570	91	33D
0005434081511	30570	92	33H
0005432459199	30570	93	34B
0005432459105	30570	94	34A
0005432458996	30570	95	34D
0005432566786	30570	96	34F
0005432459091	30570	97	34E
0005432566773	30570	98	34G
0005432566608	30570	99	35B
0005432566882	30570	100	35D
0005432566993	30570	101	35F
0005432566764	30570	102	35E
0005432459115	30570	103	35G
0005432161136	30570	104	35H
0005432566787	30570	105	36B
0005432566771	30570	106	36A
0005432459104	30570	107	36D
0005432566879	30570	108	36F
0005432566607	30570	109	36E
0005432566968	30570	110	36G
0005432571268	30570	111	37A
0005434081515	30570	112	37G
0005432459160	30570	113	37F
0005432566840	30570	114	37H
0005432566620	30570	115	38D
0005434081594	30570	116	38B
0005432566944	30570	117	38G
0005434081544	30570	118	38H
0005432566819	30570	119	39E
0005435722040	13569	1	5B
0005435722039	13569	2	6A
0005435720126	21141	1	2B
0005435720125	21141	2	4A
0005435722032	21141	3	5B
0005435722033	21141	4	6A
0005435722013	21141	5	6B
0005432295863	22806	1	6B
0005432295864	22806	2	19A
0005432295865	22806	3	21A
0005432295862	22806	4	22C
0005433342570	11111	1	1A
0005435508185	11111	2	1C
0005433342504	11111	3	1F
0005433342583	11111	4	1D
0005433342531	11111	5	2A
0005433342515	11111	6	2D
0005433342545	11111	7	2C
0005433342586	11111	8	2F
0005433342558	11111	9	3A
0005433342544	11111	10	3D
0005433342591	11111	11	3F
0005433342548	11111	12	4A
0005433342555	11111	13	4C
0005435097141	11111	14	4B
0005433342507	11111	15	4D
0005433342501	11111	16	4E
0005433342588	11111	17	4F
0005435508184	11111	18	5A
0005433342596	11111	19	5B
0005435508178	11111	20	5D
0005433342500	11111	21	5C
0005435508196	11111	22	5E
0005433342546	11111	23	6A
0005433342498	11111	24	5F
0005435508212	11111	25	6C
0005433342551	11111	26	6B
0005433342516	11111	27	6D
0005433342564	11111	28	6F
0005433342510	11111	29	6E
0005433342559	11111	30	7A
0005433342577	11111	31	7B
0005433342539	11111	32	7D
0005433342506	11111	33	7C
0005433342576	11111	34	7F
0005433342561	11111	35	7E
0005433342528	11111	36	8B
0005433342598	11111	37	8A
0005435508192	11111	38	8C
0005433342517	11111	39	8E
0005433342529	11111	40	8D
0005433342581	11111	41	8F
0005433342549	11111	42	9A
0005433342593	11111	43	9B
0005433342532	11111	44	9C
0005433342579	11111	45	9F
0005433342527	11111	46	9E
0005433342585	11111	47	10B
0005433342508	11111	48	10C
0005433342526	11111	49	10D
0005433342562	11111	50	11A
0005433342590	11111	51	10E
0005433342513	11111	52	11B
0005433342578	11111	53	11C
0005433342584	11111	54	11E
0005433342597	11111	55	11F
0005435508183	11111	56	12B
0005433342518	11111	57	12A
0005433342514	11111	58	12C
0005433342511	11111	59	12D
0005433342573	11111	60	12E
0005433342580	11111	61	12F
0005435097143	11111	62	13A
0005435097145	11111	63	13C
0005433342554	11111	64	13B
0005435097142	11111	65	13D
0005433342542	11111	66	13E
0005433342530	11111	67	13F
0005433342571	11111	68	14B
0005435508194	11111	69	14A
0005433342556	11111	70	14C
0005433342582	11111	71	14D
0005433342565	11111	72	14F
0005433342589	11111	73	14E
0005433342574	11111	74	15B
0005433342543	11111	75	15A
0005433342552	11111	76	15C
0005433342535	11111	77	15D
0005433342568	11111	78	15F
0005433342567	11111	79	15E
0005435380237	11111	80	16B
0005433342499	11111	81	16A
0005433342563	11111	82	16C
0005433342512	11111	83	16E
0005433342541	11111	84	16D
0005435508208	11111	85	16F
0005435508209	11111	86	17B
0005433342566	11111	87	17A
0005435508172	11111	88	17D
0005433342575	11111	89	17C
0005433342521	11111	90	17E
0005433342523	11111	91	18A
0005435508195	11111	92	17F
0005433342533	11111	93	18C
0005433342587	11111	94	18E
0005433342502	11111	95	18D
0005433342537	11111	96	18F
0005433342553	11111	97	19B
0005433342569	11111	98	19A
0005435097144	11111	99	19D
0005433342572	11111	100	19E
0005433342538	11111	101	19F
0005433342520	11111	102	20B
0005433342505	11111	103	20A
0005433342560	11111	104	20C
0005435508193	11111	105	20D
0005435508198	11111	106	20E
0005435508197	11111	107	20F
0005433342534	11111	108	21A
0005433342522	11111	109	21C
0005433342519	11111	110	21B
0005433342503	11111	111	21D
0005433342595	11111	112	21F
0005435508230	11111	113	22B
0005433342550	11111	114	22A
0005433342592	11111	115	22C
0005433342525	11111	116	22D
0005433342536	11111	117	22E
0005433342509	11111	118	23A
0005435508179	11111	119	22F
0005433342557	11111	120	23B
0005433342547	11111	121	23C
0005433342540	11111	122	23E
0005433342594	11111	123	23D
0005433342524	11111	124	23F
0005435545684	17097	1	1A
0005435545672	17097	2	1C
0005433341493	17097	3	1D
0005435545682	17097	4	1F
0005433341725	17097	5	2C
0005435545678	17097	6	2D
0005433341772	17097	7	3A
0005433341682	17097	8	2F
0005435545677	17097	9	3D
0005435545680	17097	10	3F
0005433342084	17097	11	4B
0005433341530	17097	12	4A
0005432293194	17097	13	4C
0005433341626	17097	14	4D
0005432293196	17097	15	4E
0005433341552	17097	16	4F
0005435545685	17097	17	5A
0005433341663	17097	18	5C
0005433341562	17097	19	5D
0005433341695	17097	20	5E
0005433341834	17097	21	6B
0005433341724	17097	22	6E
0005433341515	17097	23	6D
0005432293195	17097	24	6C
0005435097084	17097	25	6F
0005433341450	17097	26	7A
0005433341750	17097	27	7B
0005435545686	17097	28	7C
0005435097067	17097	29	7D
0005435097054	17097	30	7F
0005433341710	17097	31	7E
0005433341559	17097	32	8A
0005435545673	17097	33	8B
0005433341711	17097	34	8D
0005435545681	17097	35	8C
0005435545687	17097	36	8E
0005435380268	17097	37	8F
0005433341759	17097	38	9B
0005433341579	17097	39	9C
0005433341519	17097	40	9D
0005433341783	17097	41	9F
0005433341378	17097	42	10C
0005433341699	17097	43	10B
0005433341956	17097	44	10D
0005433341520	17097	45	11A
0005435545679	17097	46	10E
0005433341478	17097	47	11B
0005433341514	17097	48	11D
0005433341715	17097	49	11F
0005435545689	17097	50	11E
0005435545675	17097	51	12C
0005435380265	17097	52	12E
0005433342085	17097	53	12D
0005433341768	17097	54	12F
0005435545683	17097	55	13B
0005433341487	17097	56	13A
0005435097083	17097	57	13C
0005433341403	17097	58	13D
0005435380266	17097	59	13F
0005433341611	17097	60	14B
0005433341887	17097	61	14A
0005432293193	17097	62	14D
0005433341712	17097	63	14E
0005432293191	17097	64	14F
0005435545690	17097	65	15A
0005433341885	17097	66	15C
0005433341700	17097	67	15B
0005435380267	17097	68	15E
0005435380264	17097	69	15D
0005435097091	17097	70	15F
0005433341555	17097	71	16C
0005433341399	17097	72	16D
0005432293192	17097	73	16E
0005433341510	17097	74	16F
0005433341556	17097	75	17C
0005433341709	17097	76	17F
0005433341857	17097	77	17E
0005433341439	17097	78	18A
0005433341781	17097	79	18B
0005433341662	17097	80	18C
0005433341563	17097	81	18D
0005433341678	17097	82	18F
0005433341539	17097	83	19B
0005435545676	17097	84	19D
0005433341687	17097	85	19C
0005433341379	17097	86	19F
0005435545688	17097	87	20B
0005435380269	17097	88	20A
0005433341557	17097	89	20C
0005433341886	17097	90	20E
0005433341784	17097	91	20D
0005433341534	17097	92	21A
0005433341638	17097	93	20F
0005433341737	17097	94	21B
0005435545674	17097	95	21D
0005433341454	17097	96	21E
0005433341507	17097	97	21F
0005433341506	17097	98	22A
0005433341451	17097	99	22C
0005433341694	17097	100	22D
0005433341551	17097	101	22E
0005433341531	17097	102	23A
0005433341688	17097	103	22F
0005433341639	17097	104	23C
0005433341812	17097	105	23E
0005435097077	17097	106	23D
0005433341651	17097	107	23F
0005432919573	9077	1	1C
0005433481115	9077	2	1F
0005432919563	9077	3	2F
0005433507075	9077	4	4C
0005433507072	9077	5	4E
0005432919553	9077	6	4F
0005432919622	9077	7	5A
0005433481116	9077	8	5C
0005432919515	9077	9	5D
0005433507076	9077	10	6D
0005433507071	9077	11	6E
0005432919589	9077	12	6F
0005432919624	9077	13	7D
0005433507062	9077	14	7E
0005433481122	9077	15	7F
0005432919557	9077	16	8A
0005432919567	9077	17	8E
0005432919533	9077	18	8F
0005432919561	9077	19	9C
0005433481119	9077	20	9F
0005432919623	9077	21	10C
0005432919534	9077	22	10E
0005432919570	9077	23	10F
0005432919569	9077	24	11A
0005433507068	9077	25	11E
0005433507067	9077	26	11F
0005433481120	9077	27	12A
0005433481118	9077	28	12D
0005433507065	9077	29	14A
0005432919564	9077	30	14C
0005432919572	9077	31	15A
0005432919568	9077	32	15D
0005433507063	9077	33	15E
0005432919588	9077	34	16C
0005433507070	9077	35	16D
0005432919531	9077	36	16E
0005432919556	9077	37	17A
0005432919602	9077	38	17D
0005433507073	9077	39	17E
0005433507074	9077	40	17F
0005432919514	9077	41	18A
0005432919504	9077	42	18C
0005433481121	9077	43	18E
0005432919544	9077	44	18F
0005432919548	9077	45	19A
0005433507066	9077	46	19C
0005433507069	9077	47	19D
0005433507064	9077	48	20A
0005433481117	9077	49	20C
0005433506931	20443	1	1A
0005432919740	20443	2	1C
0005432919745	20443	3	1D
0005433506975	20443	4	1F
0005432919742	20443	5	2C
0005433506860	20443	6	2F
0005432919758	20443	7	3D
0005433506969	20443	8	4A
0005433506972	20443	9	4E
0005432919746	20443	10	4F
0005433481069	20443	11	5D
0005432919749	20443	12	5E
0005433481053	20443	13	5F
0005433506982	20443	14	6A
0005432919743	20443	15	6C
0005433506979	20443	16	6F
0005433506889	20443	17	7A
0005433506888	20443	18	8A
0005432919739	20443	19	8C
0005433506943	20443	20	8F
0005432919747	20443	21	9D
0005433506878	20443	22	9F
0005433506970	20443	23	11C
0005433506973	20443	24	11D
0005432919757	20443	25	11F
0005434158964	20443	26	12E
0005432919748	20443	27	13C
0005432919751	20443	28	13D
0005432919759	20443	29	13E
0005432919750	20443	30	14A
0005433481036	20443	31	14C
0005432919753	20443	32	14D
0005433506906	20443	33	14E
0005432919744	20443	34	14F
0005433481049	20443	35	15E
0005432919741	20443	36	15F
0005433481038	20443	37	16A
0005432919752	20443	38	16E
0005433481050	20443	39	16F
0005433506989	20443	40	17A
0005434158965	20443	41	17C
0005432919754	20443	42	18A
0005433506990	20443	43	18C
0005433506877	20443	44	18D
0005432919755	20443	45	18F
0005433506971	20443	46	19C
0005433506907	20443	47	19D
0005433481037	20443	48	19E
0005432919756	20443	49	20A
0005432919738	20443	50	20E
0005432396213	10209	1	1A
0005432396215	10209	2	2A
0005435179688	10209	3	1B
0005432396214	10209	4	2B
0005432394075	10209	5	3A
0005432396212	10209	6	4A
0005432394074	10209	7	4B
0005432394076	10209	8	5A
0005432394073	10209	9	5B
0005432396197	18301	1	1A
0005432396183	18301	2	1B
0005432396193	18301	3	2A
0005432396179	18301	4	3A
0005432400066	18301	5	3B
0005432396180	18301	6	5A
0005435179391	18301	7	4B
0005432396173	18301	8	5B
0005432400072	18301	9	6A
0005435179690	18301	10	6B
0005435125736	10980	1	1C
0005434411751	10980	2	1D
0005435125665	10980	3	1F
0005435125766	10980	4	2D
0005435125788	10980	5	2F
0005435125666	10980	6	3A
0005435125706	10980	7	3C
0005435625869	10980	8	3D
0005435125756	10980	9	3F
0005435125847	10980	10	4A
0005435556658	10980	11	4C
0005435125724	10980	12	4D
0005435625898	10980	13	4E
0005435125723	10980	14	4F
0005435625877	10980	15	5A
0005435125759	10980	16	6A
0005435125817	10980	17	6D
0005434928283	10980	18	6E
0005435556662	10980	19	6F
0005435125683	10980	20	7C
0005435125651	10980	21	7D
0005435554116	10980	22	7E
0005435125763	10980	23	7F
0005435625886	10980	24	8A
0005435125739	10980	25	8C
0005435125785	10980	26	8F
0005435125740	10980	27	9C
0005435125664	10980	28	9D
0005435125846	10980	29	9F
0005435125757	10980	30	10A
0005435625902	10980	31	10C
0005435554123	10980	32	11A
0005435554110	10980	33	11D
0005435556661	10980	34	11E
0005435625860	10980	35	11F
0005435125885	10980	36	12C
0005435125713	10980	37	12D
0005434411750	10980	38	13C
0005435125738	10980	39	13E
0005434411753	10980	40	13F
0005435625878	10980	41	14A
0005435625899	10980	42	14D
0005435125720	10980	43	14E
0005435125737	10980	44	15A
0005435125650	10980	45	15C
0005435125758	10980	46	15D
0005434928282	10980	47	15F
0005435125699	10980	48	16A
0005435554117	10980	49	16C
0005435125792	10980	50	16D
0005435125789	10980	51	16E
0005435125809	10980	52	16F
0005435125702	10980	53	17A
0005435125800	10980	54	17C
0005435125700	10980	55	17D
0005435625889	10980	56	17F
0005435625876	10980	57	18D
0005435625861	10980	58	18E
0005435125884	10980	59	19C
0005434411752	10980	60	19E
0005435125686	10980	61	20C
0005435125842	10980	62	20D
0005435626069	14702	1	1A
0005435556676	14702	2	1C
0005435126137	14702	3	1D
0005434411711	14702	4	1F
0005435626064	14702	5	2C
0005435126143	14702	6	2D
0005435126130	14702	7	2F
0005434411712	14702	8	3A
0005435126133	14702	9	3D
0005435556679	14702	10	3F
0005435554153	14702	11	4A
0005435126140	14702	12	4C
0005435126112	14702	13	4D
0005435126106	14702	14	4E
0005435126122	14702	15	4F
0005435626068	14702	16	5A
0005435554154	14702	17	5C
0005435126136	14702	18	5F
0005435126138	14702	19	6A
0005435126115	14702	20	6C
0005435626061	14702	21	6D
0005435126145	14702	22	7A
0005435126125	14702	23	7C
0005435126110	14702	24	7D
0005435126144	14702	25	7F
0005435554155	14702	26	8A
0005435626057	14702	27	8C
0005435626058	14702	28	8D
0005435126108	14702	29	8F
0005435126113	14702	30	9A
0005435126146	14702	31	9C
0005435126121	14702	32	9D
0005435556678	14702	33	9F
0005435126132	14702	34	10A
0005435626065	14702	35	10C
0005435126116	14702	36	10D
0005435126120	14702	37	10F
0005435626063	14702	38	11A
0005435126139	14702	39	11D
0005435126142	14702	40	11E
0005435126147	14702	41	12F
0005435626060	14702	42	13A
0005435126141	14702	43	13C
0005435126109	14702	44	13E
0005435126119	14702	45	13F
0005435126124	14702	46	14A
0005435126128	14702	47	14C
0005435626059	14702	48	14D
0005435126118	14702	49	14E
0005435126114	14702	50	14F
0005435126148	14702	51	15A
0005435556677	14702	52	15C
0005435554157	14702	53	15D
0005435554156	14702	54	15E
0005435126134	14702	55	15F
0005435556674	14702	56	16D
0005435126117	14702	57	16E
0005435556675	14702	58	16F
0005435126107	14702	59	17A
0005435126126	14702	60	17E
0005435626066	14702	61	17F
0005435626062	14702	62	18A
0005434411710	14702	63	18C
0005435126131	14702	64	18D
0005435626056	14702	65	18E
0005435126129	14702	66	19A
0005435626067	14702	67	19C
0005435126123	14702	68	19D
0005435126135	14702	69	19F
0005435626055	14702	70	20A
0005435126127	14702	71	20C
0005435126111	14702	72	20F
0005435715359	7091	1	1F
0005435715368	7091	2	2C
0005435715355	7091	3	4A
0005432398173	7091	4	5A
0005432400099	7091	5	6A
0005435715360	7091	6	6C
0005435715369	7091	7	6F
0005435715358	7091	8	7E
0005435715356	7091	9	8A
0005435216560	7091	10	8D
0005435715365	7091	11	8E
0005435443171	7091	12	8F
0005435219165	7091	13	10D
0005435715364	7091	14	11A
0005432398174	7091	15	11E
0005435715354	7091	16	11F
0005435715363	7091	17	12A
0005435715357	7091	18	12C
0005435443166	7091	19	13A
0005432400098	7091	20	13E
0005432398175	7091	21	14D
0005435715361	7091	22	17A
0005432400100	7091	23	17D
0005435443172	7091	24	18A
0005435179389	7091	25	18C
0005435715362	7091	26	18D
0005435443170	7091	27	19E
0005435715366	7091	28	20A
0005435715367	7091	29	20F
0005435443253	27081	1	1C
0005435216571	27081	2	1D
0005432398144	27081	3	2A
0005435443254	27081	4	2D
0005435715190	27081	5	2F
0005435216574	27081	6	3C
0005435178484	27081	7	3D
0005435217697	27081	8	4E
0005435715189	27081	9	4F
0005435715196	27081	10	5C
0005435715211	27081	11	5D
0005435715253	27081	12	6A
0005435218109	27081	13	6D
0005435443255	27081	14	6E
0005435216572	27081	15	7D
0005435443250	27081	16	7E
0005435715184	27081	17	7F
0005435715239	27081	18	8D
0005435715183	27081	19	8E
0005435443258	27081	20	8F
0005435178987	27081	21	9D
0005432398145	27081	22	9E
0005435217696	27081	23	10C
0005435178988	27081	24	11A
0005435178485	27081	25	11D
0005435216570	27081	26	11F
0005435178486	27081	27	12A
0005435216573	27081	28	12E
0005435217695	27081	29	14C
0005435178985	27081	30	14D
0005435443256	27081	31	14F
0005435217698	27081	32	15A
0005435443259	27081	33	15D
0005435443257	27081	34	15E
0005435715240	27081	35	16A
0005435178986	27081	36	16C
0005435715199	27081	37	17C
0005435443251	27081	38	17D
0005435217699	27081	39	17F
0005435443252	27081	40	18A
0005435715198	27081	41	18E
0005435715195	27081	42	18F
0005435216575	27081	43	19C
0005432398143	27081	44	19D
0005435715212	27081	45	19E
0005434084902	2709	1	1B
0005434084904	2709	2	2A
0005434084903	2709	3	2B
0005434084900	2709	4	3B
0005434084901	2709	5	6A
0005434084872	28523	1	1A
0005433060397	28523	2	2B
0005434084867	28523	3	3A
0005433060395	28523	4	3B
0005434084864	28523	5	4A
0005434084874	28523	6	5B
0005433060396	28523	7	6B
0005435548422	11166	1	1B
0005433788188	11166	2	3A
0005433788183	11166	3	3B
0005433788187	11166	4	3C
0005433788189	11166	5	4B
0005435548433	11166	6	4C
0005433788185	11166	7	4D
0005433788184	11166	8	5C
0005435548436	11166	9	5D
0005435548434	11166	10	7B
0005433788182	11166	11	7C
0005435548435	11166	12	18A
0005433788186	11166	13	18D
0005433788178	11166	14	19A
0005433788179	11166	15	19C
0005435548423	11166	16	20B
0005433788180	11166	17	21B
0005433788181	11166	18	23A
0005435548470	20672	1	1B
0005433788141	20672	2	1C
0005435548467	20672	3	1D
0005435548469	20672	4	2B
0005435548460	20672	5	3A
0005435548459	20672	6	3C
0005435548458	20672	7	3D
0005433788148	20672	8	4A
0005433788158	20672	9	4B
0005435548454	20672	10	4D
0005433788143	20672	11	5D
0005435548452	20672	12	6A
0005435548457	20672	13	6B
0005435548455	20672	14	6C
0005435548453	20672	15	6D
0005435548451	20672	16	7A
0005435548461	20672	17	7B
0005435548463	20672	18	7C
0005435548471	20672	19	18A
0005435548464	20672	20	18C
0005435548468	20672	21	18D
0005435548456	20672	22	19A
0005435548472	20672	23	19B
0005433788142	20672	24	19C
0005435548465	20672	25	19D
0005435548466	20672	26	20A
0005433788144	20672	27	20B
0005435548462	20672	28	21D
0005433788154	20672	29	22C
0005435548450	20672	30	22D
0005435548473	20672	31	23B
0005435540710	11401	1	1C
0005435517652	11401	2	1D
0005435517594	11401	3	3A
0005435517710	11401	4	4E
0005435517641	11401	5	4F
0005435540752	11401	6	5A
0005435540764	11401	7	5D
0005435540704	11401	8	6A
0005435540692	11401	9	6E
0005435517596	11401	10	7A
0005435540648	11401	11	7C
0005435517588	11401	12	8A
0005435540694	11401	13	8C
0005435540765	11401	14	8F
0005435540718	11401	15	9A
0005435540759	11401	16	9F
0005435540760	11401	17	10D
0005435517637	11401	18	10F
0005435540651	11401	19	11A
0005435540640	11401	20	11C
0005435517714	11401	21	11D
0005435517636	11401	22	11E
0005435540796	11401	23	11F
0005435540628	11401	24	12C
0005435540668	11401	25	12F
0005435517709	11401	26	13A
0005435517648	11401	27	13C
0005435540682	11401	28	13F
0005435540649	11401	29	14A
0005435517620	11401	30	14C
0005435517649	11401	31	14D
0005435540691	11401	32	14E
0005435540667	11401	33	15E
0005435517654	11401	34	15F
0005435540795	11401	35	16A
0005435540705	11401	36	16C
0005435540719	11401	37	16E
0005435517655	11401	38	17D
0005435517653	11401	39	17E
0005435517640	11401	40	17F
0005435540753	11401	41	18A
0005435540769	11401	42	18C
0005435517633	11401	43	18D
0005435540650	11401	44	18F
0005435540683	11401	45	19D
0005435529111	22239	1	1A
0005435540856	22239	2	1D
0005435529104	22239	3	2D
0005435529102	22239	4	2F
0005435540858	22239	5	3A
0005435529101	22239	6	3D
0005435540865	22239	7	4A
0005432294472	22239	8	4D
0005435529120	22239	9	4E
0005435540852	22239	10	5D
0005432294470	22239	11	6A
0005435540850	22239	12	6F
0005435540857	22239	13	7A
0005435540864	22239	14	7E
0005435529114	22239	15	7F
0005435540863	22239	16	8A
0005435540851	22239	17	8D
0005435529107	22239	18	8E
0005435529105	22239	19	9A
0005435540849	22239	20	9D
0005435540854	22239	21	9E
0005435529108	22239	22	10D
0005435529100	22239	23	10E
0005435529118	22239	24	11A
0005435540859	22239	25	11C
0005435529110	22239	26	11E
0005435540848	22239	27	12A
0005435529973	22239	28	13D
0005435529113	22239	29	13E
0005435529115	22239	30	13F
0005435540846	22239	31	14A
0005435529119	22239	32	14C
0005435529109	22239	33	14E
0005435529117	22239	34	15A
0005435540860	22239	35	15C
0005435540855	22239	36	15E
0005435529112	22239	37	16D
0005435540844	22239	38	17A
0005435540845	22239	39	18D
0005435540862	22239	40	18F
0005435529121	22239	41	19A
0005435529116	22239	42	19C
0005435529106	22239	43	19D
0005435540853	22239	44	19E
0005435540861	22239	45	19F
0005435529103	22239	46	20C
0005435540847	22239	47	20D
0005432294471	22239	48	20F
0005434907000	2263	1	1A
0005433251039	2263	2	1C
0005434906978	2263	3	1D
0005433251000	2263	4	1F
0005433251007	2263	5	2A
0005433400935	2263	6	2D
0005434907005	2263	7	2C
0005434907007	2263	8	2F
0005434906979	2263	9	3A
0005434906985	2263	10	3C
0005433251072	2263	11	3D
0005434907009	2263	12	3F
0005434906969	2263	13	4A
0005434906989	2263	14	4C
0005434906974	2263	15	4D
0005434907010	2263	16	4E
0005434906984	2263	17	4F
0005434906976	2263	18	5A
0005434906987	2263	19	5C
0005434906988	2263	20	5E
0005434906998	2263	21	5D
0005434906977	2263	22	5F
0005433400946	2263	23	6A
0005434906970	2263	24	6C
0005433251001	2263	25	6D
0005434906972	2263	26	6E
0005434906965	2263	27	6F
0005433251130	2263	28	7A
0005434906986	2263	29	7C
0005434906983	2263	30	7D
0005434907008	2263	31	7E
0005433250978	2263	32	7F
0005434906982	2263	33	8A
0005434906963	2263	34	8C
0005433251062	2263	35	8D
0005434906980	2263	36	8E
0005433251014	2263	37	8F
0005434906995	2263	38	9A
0005433250991	2263	39	9C
0005434906956	2263	40	9D
0005433251250	2263	41	9E
0005433250990	2263	42	9F
0005433251045	2263	43	10A
0005434906993	2263	44	10C
0005434906975	2263	45	10D
0005433251054	2263	46	10E
0005434906968	2263	47	10F
0005434906961	2263	48	11A
0005434907004	2263	49	11C
0005433251160	2263	50	11D
0005433250998	2263	51	11F
0005434907006	2263	52	12A
0005433251075	2263	53	12C
0005433251215	2263	54	12D
0005434906999	2263	55	12E
0005433250976	2263	56	12F
0005434906957	2263	57	13A
0005434906996	2263	58	13C
0005433251021	2263	59	13D
0005434906958	2263	60	13E
0005434906994	2263	61	13F
0005434906997	2263	62	14A
0005434907002	2263	63	14C
0005434906966	2263	64	14D
0005434906992	2263	65	14E
0005433251020	2263	66	14F
0005433251044	2263	67	15A
0005433250999	2263	68	15C
0005433250977	2263	69	15D
0005434906954	2263	70	15E
0005434906953	2263	71	15F
0005433250944	2263	72	16A
0005434906990	2263	73	16C
0005434906964	2263	74	16D
0005433251238	2263	75	16E
0005434906991	2263	76	16F
0005434906960	2263	77	17A
0005434906959	2263	78	17C
0005434906955	2263	79	17D
0005434907003	2263	80	17E
0005433251076	2263	81	17F
0005433251008	2263	82	18A
0005433251129	2263	83	18C
0005433251050	2263	84	18D
0005434906951	2263	85	18E
0005434906962	2263	86	18F
0005434906973	2263	87	19A
0005434906971	2263	88	19C
0005434906967	2263	89	19D
0005433251051	2263	90	19F
0005434906981	2263	91	20A
0005433251158	2263	92	20C
0005434907001	2263	93	20E
0005434906952	2263	94	20F
0005434906533	25608	1	1A
0005433251294	25608	2	1C
0005434906452	25608	3	1D
0005434906603	25608	4	1F
0005434906536	25608	5	2C
0005434906432	25608	6	2F
0005433251290	25608	7	3A
0005433251299	25608	8	3C
0005433251305	25608	9	3D
0005434906532	25608	10	3F
0005433251278	25608	11	4A
0005433251284	25608	12	4C
0005434906460	25608	13	4D
0005433251286	25608	14	4E
0005434906434	25608	15	4F
0005434906519	25608	16	5A
0005433251300	25608	17	5C
0005433251277	25608	18	5D
0005433251292	25608	19	5E
0005434906363	25608	20	5F
0005434906512	25608	21	6C
0005433251297	25608	22	6D
0005433251287	25608	23	6E
0005433251275	25608	24	6F
0005433251281	25608	25	7A
0005434906505	25608	26	7E
0005434906411	25608	27	7F
0005434906461	25608	28	8A
0005434906477	25608	29	9A
0005433251293	25608	30	9D
0005434906480	25608	31	9E
0005433251303	25608	32	9F
0005433400965	25608	33	10C
0005434906388	25608	34	10D
0005433251291	25608	35	10E
0005434906575	25608	36	11A
0005434906453	25608	37	11C
0005433251279	25608	38	11D
0005434906398	25608	39	11F
0005434906493	25608	40	12A
0005433251304	25608	41	12C
0005434906459	25608	42	12D
0005434906387	25608	43	12E
0005433251282	25608	44	12F
0005434906668	25608	45	13A
0005434906551	25608	46	13C
0005434906399	25608	47	13D
0005434906550	25608	48	13E
0005433400964	25608	49	13F
0005433251296	25608	50	14C
0005434906359	25608	51	14A
0005433251288	25608	52	14E
0005434906520	25608	53	15A
0005434906458	25608	54	15C
0005434906619	25608	55	15D
0005433251280	25608	56	15E
0005433251301	25608	57	16A
0005433400963	25608	58	16C
0005434906669	25608	59	16D
0005434906585	25608	60	16F
0005434906677	25608	61	17C
0005434906464	25608	62	17D
0005434906676	25608	63	17E
0005433251302	25608	64	18A
0005434906482	25608	65	18C
0005434906671	25608	66	18E
0005433251295	25608	67	19A
0005434906690	25608	68	19D
0005433251298	25608	69	19E
0005434906476	25608	70	19F
0005433251285	25608	71	20A
0005433251276	25608	72	20C
0005433251289	25608	73	20D
0005433251283	25608	74	20E
0005434906474	25608	75	20F
0005432620958	2527	1	1A
0005432862174	2527	2	1C
0005432862186	2527	3	2A
0005432862164	2527	4	3A
0005432620959	2527	5	3D
0005432620947	2527	6	4A
0005432620946	2527	7	4B
0005432620956	2527	8	5A
0005432620957	2527	9	5C
0005432620945	2527	10	7B
0005432620954	2527	11	7C
0005432620948	2527	12	7D
0005432620955	2527	13	18C
0005432620953	2527	14	18D
0005432620949	2527	15	20B
0005432620951	2527	16	21A
0005432862203	2527	17	21D
0005432620950	2527	18	22A
0005432620952	2527	19	22C
0005432862202	2527	20	23A
0005432862256	28055	1	1A
0005432620820	28055	2	2B
0005432620793	28055	3	2C
0005432620832	28055	4	3B
0005432620842	28055	5	3C
0005432620788	28055	6	3D
0005432862258	28055	7	4D
0005432862250	28055	8	5A
0005432862255	28055	9	5D
0005432620843	28055	10	6B
0005432620889	28055	11	6C
0005432620890	28055	12	7B
0005432862251	28055	13	7D
0005432862253	28055	14	18B
0005432620792	28055	15	18C
0005432620841	28055	16	19A
0005432620791	28055	17	19D
0005432620867	28055	18	20D
0005432862257	28055	19	21A
0005432862252	28055	20	21C
0005432620819	28055	21	21D
0005432620845	28055	22	22B
0005432862254	28055	23	23A
0005434097450	11759	1	1A
0005434097453	11759	2	2B
0005434097452	11759	3	3B
0005434097451	11759	4	6A
0005434097467	13064	1	5A
0005433452725	31016	1	3A
0005433451607	31016	2	4A
0005433451606	31016	3	4B
0005433452728	31016	4	5A
0005433452727	31016	5	5B
0005433452726	31016	6	6B
0005433454844	31375	1	2A
0005434184631	11995	1	1A
0005433134063	11995	2	1C
0005433134068	11995	3	4A
0005433134067	11995	4	5C
0005433134097	11995	5	6A
0005434142548	11995	6	6C
0005433129205	11995	7	6D
0005433134080	11995	8	7D
0005434184632	11995	9	18A
0005433129210	11995	10	18B
0005433134069	11995	11	19D
0005433134074	11995	12	20A
0005433129204	11995	13	20B
0005433134066	11995	14	21C
0005433134078	11995	15	21D
0005433134075	11995	16	22D
0005434183566	29850	1	1A
0005434142582	29850	2	1B
0005433134108	29850	3	1D
0005434184652	29850	4	2A
0005434142583	29850	5	2C
0005433134110	29850	6	3B
0005434142584	29850	7	3D
0005433131681	29850	8	5C
0005433134111	29850	9	7B
0005433131680	29850	10	18B
0005434184653	29850	11	18C
0005433134109	29850	12	19D
0005434183567	29850	13	20B
0005433131682	29850	14	20C
0005433131678	29850	15	21C
0005433131683	29850	16	22B
0005433131679	29850	17	23A
0005435697150	16476	1	1A
0005435935009	16476	2	1C
0005435697158	16476	3	1D
0005435697137	16476	4	2A
0005435697157	16476	5	2B
0005435934992	16476	6	2D
0005435697133	16476	7	3B
0005435697152	16476	8	3C
0005435697156	16476	9	3D
0005435697131	16476	10	4B
0005435697139	16476	11	4C
0005435697149	16476	12	5B
0005435697141	16476	13	5C
0005435697155	16476	14	5D
0005435697148	16476	15	6A
0005435697153	16476	16	6D
0005435697132	16476	17	6C
0005435697144	16476	18	7A
0005435697134	16476	19	7C
0005435697151	16476	20	18C
0005435697146	16476	21	19A
0005435697140	16476	22	19B
0005435934999	16476	23	19C
0005435697142	16476	24	20A
0005435935008	16476	25	21A
0005435697143	16476	26	21B
0005435697145	16476	27	21D
0005435697154	16476	28	22B
0005435697147	16476	29	22C
0005435697135	16476	30	22D
0005435697136	16476	31	23A
0005435697138	16476	32	23B
0005435696861	24688	1	1B
0005435697033	24688	2	1C
0005435696860	24688	3	1D
0005435696987	24688	4	2A
0005435696933	24688	5	3A
0005435696984	24688	6	3B
0005435696970	24688	7	3D
0005435935026	24688	8	4B
0005435696884	24688	9	4C
0005435697023	24688	10	5A
0005435696926	24688	11	5B
0005435696967	24688	12	5D
0005435697019	24688	13	6B
0005435696952	24688	14	6D
0005435696925	24688	15	7B
0005435696893	24688	16	7C
0005435935025	24688	17	7D
0005435696969	24688	18	18A
0005435935024	24688	19	18B
0005435696957	24688	20	19A
0005435935027	24688	21	19B
0005435697060	24688	22	19C
0005435696928	24688	23	20A
0005435696850	24688	24	20B
0005435696932	24688	25	20D
0005435696947	24688	26	21B
0005435696927	24688	27	21D
0005435696985	24688	28	22A
0005435696885	24688	29	22B
0005435696968	24688	30	22C
0005435696966	24688	31	23B
0005432968803	18762	1	1A
0005433724775	18762	2	1B
0005433724773	18762	3	2A
0005433724776	18762	4	2B
0005432968802	18762	5	3B
0005432968811	18762	6	5B
0005433724774	18762	7	6A
0005433724772	18762	8	6B
0005432968828	21651	1	2B
0005433724724	21651	2	3A
0005433724736	21651	3	3B
0005432968829	21651	4	5A
0005433724740	21651	5	6A
0005432968827	21651	6	5B
0005434137644	7297	1	1A
0005434137683	7297	2	1C
0005434137669	7297	3	1F
0005434137660	7297	4	2A
0005434137690	7297	5	2C
0005434137698	7297	6	2D
0005434137641	7297	7	2F
0005434137665	7297	8	3A
0005434137642	7297	9	3C
0005434137625	7297	10	3D
0005434137633	7297	11	3F
0005434137629	7297	12	4A
0005434137684	7297	13	4C
0005434137647	7297	14	4D
0005434137657	7297	15	4E
0005434137694	7297	16	4F
0005434087485	7297	17	5C
0005434137705	7297	18	5E
0005434137628	7297	19	5D
0005434137654	7297	20	5F
0005434137681	7297	21	6A
0005434137674	7297	22	6C
0005434137666	7297	23	6D
0005434137662	7297	24	6E
0005434087486	7297	25	6F
0005434137630	7297	26	7A
0005434137649	7297	27	7C
0005434137637	7297	28	7D
0005434137696	7297	29	7E
0005434137675	7297	30	7F
0005434137672	7297	31	8A
0005434137677	7297	32	8C
0005434137635	7297	33	8D
0005434137663	7297	34	8E
0005434137646	7297	35	8F
0005434137692	7297	36	9A
0005434137688	7297	37	9C
0005434137651	7297	38	9D
0005434137679	7297	39	9E
0005434137703	7297	40	9F
0005434087481	7297	41	10A
0005434087484	7297	42	10C
0005434137687	7297	43	10D
0005434137631	7297	44	10E
0005434137678	7297	45	10F
0005434137700	7297	46	11A
0005434137689	7297	47	11C
0005434137640	7297	48	11D
0005434137643	7297	49	11E
0005434137658	7297	50	11F
0005434137695	7297	51	12A
0005434137691	7297	52	12D
0005434137634	7297	53	12E
0005434137653	7297	54	12F
0005434137686	7297	55	13A
0005434137655	7297	56	13C
0005434137661	7297	57	13E
0005434137638	7297	58	13F
0005434137701	7297	59	14A
0005434137706	7297	60	14C
0005434137676	7297	61	14D
0005434137670	7297	62	14E
0005434137671	7297	63	14F
0005434137648	7297	64	15A
0005434137697	7297	65	15C
0005434137624	7297	66	15D
0005434137680	7297	67	15E
0005434137699	7297	68	16A
0005434137702	7297	69	16C
0005434137652	7297	70	16D
0005434137667	7297	71	16E
0005434087483	7297	72	16F
0005434137685	7297	73	17A
0005434137668	7297	74	17C
0005434087482	7297	75	17D
0005434137627	7297	76	17E
0005434137704	7297	77	17F
0005434137626	7297	78	18A
0005434137639	7297	79	18D
0005434137632	7297	80	18E
0005434137645	7297	81	18F
0005434137659	7297	82	19A
0005434137682	7297	83	19C
0005434137673	7297	84	19E
0005434137693	7297	85	19F
0005434137656	7297	86	20A
0005434137636	7297	87	20C
0005434137664	7297	88	20D
0005434137650	7297	89	20E
0005434137707	7297	90	20F
0005434136796	28580	1	1A
0005434137008	28580	2	2A
0005434136983	28580	3	2C
0005434136922	28580	4	2D
0005434136742	28580	5	3A
0005434136804	28580	6	3C
0005434136743	28580	7	3D
0005434136948	28580	8	3F
0005434136729	28580	9	4A
0005434136894	28580	10	4C
0005434137023	28580	11	4D
0005434136913	28580	12	4E
0005434136857	28580	13	4F
0005434136690	28580	14	5A
0005434136864	28580	15	5C
0005434136959	28580	16	5D
0005434087450	28580	17	5E
0005434137060	28580	18	5F
0005434136897	28580	19	6A
0005434136861	28580	20	6C
0005434136809	28580	21	6D
0005434136993	28580	22	6E
0005434136762	28580	23	6F
0005434137070	28580	24	7A
0005434137061	28580	25	7C
0005434136974	28580	26	7D
0005434136992	28580	27	8A
0005434137045	28580	28	8C
0005434136908	28580	29	8D
0005434136911	28580	30	8E
0005434136805	28580	31	8F
0005434136965	28580	32	9A
0005434136811	28580	33	9E
0005434136715	28580	34	9F
0005434136750	28580	35	10A
0005434136716	28580	36	10C
0005434137021	28580	37	10D
0005434136842	28580	38	10F
0005434136909	28580	39	11A
0005434136918	28580	40	11C
0005434136808	28580	41	11D
0005434136984	28580	42	11E
0005434137101	28580	43	11F
0005434137056	28580	44	12A
0005434136921	28580	45	12D
0005434137097	28580	46	12E
0005434136877	28580	47	12F
0005434137035	28580	48	13A
0005434136975	28580	49	13C
0005434136914	28580	50	13E
0005434137002	28580	51	13F
0005434136728	28580	52	14A
0005434136846	28580	53	14C
0005434136912	28580	54	14E
0005434137034	28580	55	14F
0005434136730	28580	56	15C
0005434136755	28580	57	15D
0005434136910	28580	58	15E
0005434136843	28580	59	15F
0005434136949	28580	60	16C
0005434137096	28580	61	16D
0005434136810	28580	62	16E
0005434136720	28580	63	16F
0005434136886	28580	64	17A
0005434137046	28580	65	17C
0005434137069	28580	66	17E
0005434136888	28580	67	17F
0005434136776	28580	68	18D
0005434136881	28580	69	18E
0005434136862	28580	70	18F
0005434136960	28580	71	19A
0005434136772	28580	72	19C
0005434136817	28580	73	19D
0005434136966	28580	74	19E
0005434136917	28580	75	19F
0005434087451	28580	76	20A
0005434137064	28580	77	20C
0005434136887	28580	78	20D
0005434136863	28580	79	20E
0005434136751	28580	80	20F
0005435808171	1902	1	1A
0005435808174	1902	2	2B
0005435808168	1902	3	2C
0005434610207	1902	4	2D
0005433407478	1902	5	3B
0005433407479	1902	6	3D
0005433407490	1902	7	5C
0005435808172	1902	8	5D
0005435808173	1902	9	7A
0005435808175	1902	10	18B
0005435808169	1902	11	19D
0005434610208	1902	12	21C
0005434610206	1902	13	21D
0005435808170	1902	14	22B
0005435808176	1902	15	22D
0005434610177	23067	1	3B
0005434610170	23067	2	4A
0005434610169	23067	3	7D
0005434610181	23067	4	20A
0005434610180	23067	5	22A
0005434503615	16729	1	1B
0005434503458	16729	2	1C
0005434503503	16729	3	1D
0005434503550	16729	4	3B
0005434503513	16729	5	3D
0005434503565	16729	6	4A
0005434503608	16729	7	4B
0005434503535	16729	8	4D
0005434503610	16729	9	5B
0005434503521	16729	10	5C
0005434503514	16729	11	5D
0005434503566	16729	12	6A
0005434503536	16729	13	6D
0005434503659	16729	14	7A
0005434503502	16729	15	7D
0005434503592	16729	16	18A
0005434503534	16729	17	18C
0005434503576	16729	18	18D
0005434503538	16729	19	19A
0005434503548	16729	20	19D
0005434503583	16729	21	20D
0005434503640	16729	22	21B
0005434503549	16729	23	21C
0005434503476	16729	24	21D
0005434503520	16729	25	22A
0005434503611	16729	26	22C
0005434503485	16729	27	22D
0005434503643	16729	28	23B
0005434503899	22915	1	1B
0005434503884	22915	2	1C
0005434503865	22915	3	2A
0005434503897	22915	4	2B
0005434503888	22915	5	2C
0005434503866	22915	6	2D
0005434503886	22915	7	3A
0005434503898	22915	8	3D
0005434503875	22915	9	4A
0005434503874	22915	10	4B
0005434503881	22915	11	4C
0005434503867	22915	12	4D
0005434503887	22915	13	5A
0005434503868	22915	14	5C
0005434503871	22915	15	5D
0005434503863	22915	16	6B
0005434503876	22915	17	6C
0005434503864	22915	18	6D
0005434503894	22915	19	7C
0005434503896	22915	20	18A
0005434503883	22915	21	18C
0005434503878	22915	22	18B
0005434503895	22915	23	18D
0005434503877	22915	24	19B
0005434503900	22915	25	19C
0005434503873	22915	26	19D
0005434503870	22915	27	20A
0005434503890	22915	28	20B
0005434503872	22915	29	20C
0005434503879	22915	30	20D
0005434503885	22915	31	21A
0005434503869	22915	32	21B
0005434503893	22915	33	21C
0005434503891	22915	34	21D
0005434503889	22915	35	22A
0005434503880	22915	36	22D
0005434503892	22915	37	23A
0005434503882	22915	38	23B
0005435078244	2227	1	1A
0005433266556	2227	2	1D
0005435078243	2227	3	2B
0005435078248	2227	4	2C
0005435078241	2227	5	3A
0005435078250	2227	6	3C
0005435078251	2227	7	4A
0005435078239	2227	8	4B
0005433266565	2227	9	4C
0005433266570	2227	10	5A
0005435078246	2227	11	5B
0005435078242	2227	12	5D
0005433266577	2227	13	6A
0005433266614	2227	14	6C
0005433266599	2227	15	7B
0005435078247	2227	16	7C
0005435078249	2227	17	18A
0005435078253	2227	18	18D
0005433266606	2227	19	19C
0005433266607	2227	20	19D
0005433266566	2227	21	20B
0005435078245	2227	22	20C
0005433266602	2227	23	20D
0005435078240	2227	24	21A
0005433266615	2227	25	21C
0005435078252	2227	26	21D
0005433266600	2227	27	22B
0005435078254	2227	28	23B
0005435078107	24364	1	1C
0005435078067	24364	2	1D
0005435078087	24364	3	2B
0005433266662	24364	4	2D
0005433266667	24364	5	3A
0005433266670	24364	6	3B
0005433266665	24364	7	3C
0005435078156	24364	8	3D
0005433266668	24364	9	4B
0005433266672	24364	10	5B
0005433266664	24364	11	5D
0005435078068	24364	12	6B
0005435078128	24364	13	7C
0005435078144	24364	14	18A
0005435078074	24364	15	19A
0005435078089	24364	16	19C
0005435078075	24364	17	20A
0005433266663	24364	18	19D
0005435078129	24364	19	20B
0005433266669	24364	20	20D
0005435078157	24364	21	21A
0005433266661	24364	22	21B
0005433266671	24364	23	21D
0005435078066	24364	24	22A
0005433266666	24364	25	22D
0005435464479	6615	1	1A
0005435464477	6615	2	1B
0005434988667	6615	3	3D
0005434988672	6615	4	4D
0005434988677	6615	5	5B
0005435464478	6615	6	6A
0005434988673	6615	7	6C
0005434988670	6615	8	7D
0005434988669	6615	9	18B
0005434988676	6615	10	20B
0005435803246	6615	11	20C
0005434988675	6615	12	20D
0005435803247	6615	13	21A
0005434988674	6615	14	21C
0005434988668	6615	15	22C
0005434988671	6615	16	22D
0005435803213	23597	1	1A
0005435464495	23597	2	1B
0005435803212	23597	3	2D
0005435803227	23597	4	4C
0005435464494	23597	5	5C
0005432382965	30495	1	1A
0005432382928	30495	2	1C
0005432382938	30495	3	1D
0005433449831	30495	4	2C
0005432382954	30495	5	2D
0005432382944	30495	6	2F
0005433449834	30495	7	3C
0005433449837	30495	8	4A
0005432382946	30495	9	4C
0005433453752	30495	10	4F
0005432382930	30495	11	5C
0005432382947	30495	12	5D
0005433449840	30495	13	5E
0005433449850	30495	14	5F
0005432382955	30495	15	6A
0005433449849	30495	16	6C
0005432382952	30495	17	6D
0005432382951	30495	18	6E
0005432382936	30495	19	7D
0005433449844	30495	20	7E
0005432382964	30495	21	8A
0005432382927	30495	22	8C
0005432382949	30495	23	8E
0005432382939	30495	24	8F
0005433449848	30495	25	9E
0005433449835	30495	26	9F
0005433449829	30495	27	10C
0005432382929	30495	28	10D
0005432382942	30495	29	10F
0005432382956	30495	30	11A
0005432382966	30495	31	11C
0005433453751	30495	32	11E
0005433449847	30495	33	12A
0005433449830	30495	34	12C
0005433449842	30495	35	12F
0005433449841	30495	36	13A
0005432382948	30495	37	13D
0005433449846	30495	38	13F
0005432382959	30495	39	14A
0005432382945	30495	40	14D
0005432382963	30495	41	14F
0005432382943	30495	42	15A
0005433449833	30495	43	15C
0005432382932	30495	44	15D
0005432382961	30495	45	15E
0005433449828	30495	46	15F
0005432382960	30495	47	16A
0005432382967	30495	48	16C
0005433449845	30495	49	16D
0005432382933	30495	50	16E
0005432382937	30495	51	16F
0005433453750	30495	52	17A
0005432382950	30495	53	17C
0005432382962	30495	54	17D
0005432382957	30495	55	17E
0005432382934	30495	56	17F
0005433449839	30495	57	18A
0005432382958	30495	58	18C
0005433449832	30495	59	18D
0005433449843	30495	60	18E
0005432382941	30495	61	18F
0005432382931	30495	62	19A
0005433449836	30495	63	19C
0005432382968	30495	64	19D
0005433449838	30495	65	19E
0005432382935	30495	66	20C
0005432382953	30495	67	20D
0005432382940	30495	68	20F
0005432382506	31282	1	1A
0005432382547	31282	2	1C
0005433449703	31282	3	1F
0005432382527	31282	4	2A
0005432382514	31282	5	2C
0005432382557	31282	6	2D
0005432382502	31282	7	2F
0005433449692	31282	8	3D
0005433449629	31282	9	4C
0005432382488	31282	10	4F
0005433449627	31282	11	5C
0005432382498	31282	12	5E
0005433449616	31282	13	6C
0005433449670	31282	14	6D
0005433453730	31282	15	6E
0005432382546	31282	16	7A
0005432382489	31282	17	7D
0005433453739	31282	18	7F
0005432382591	31282	19	8A
0005432382598	31282	20	8C
0005433449614	31282	21	8F
0005433453731	31282	22	9D
0005432382562	31282	23	9E
0005432382504	31282	24	10C
0005433449666	31282	25	10D
0005432382597	31282	26	11E
0005433449691	31282	27	12C
0005432382581	31282	28	13C
0005432382513	31282	29	13D
0005433449668	31282	30	13E
0005432382590	31282	31	13F
0005432382512	31282	32	14A
0005433449621	31282	33	14C
0005432382497	31282	34	14D
0005433449595	31282	35	14F
0005432382528	31282	36	15C
0005432382558	31282	37	15D
0005432382563	31282	38	15E
0005433449612	31282	39	15F
0005432382643	31282	40	16D
0005432382635	31282	41	16F
0005433449617	31282	42	17D
0005432382573	31282	43	17E
0005433453738	31282	44	18C
0005433449644	31282	45	18D
0005432382548	31282	46	18E
0005433451599	31282	47	19C
0005432382524	31282	48	19D
0005433449613	31282	49	19E
0005432382561	31282	50	19F
0005432382517	31282	51	20E
0005432382605	31282	52	20F
0005435548467	26462	1	2A
0005435548464	26462	2	2C
0005435548463	26462	3	3C
0005435548468	26462	4	4B
0005435548472	26462	5	4D
0005433788154	26462	6	5C
0005435548471	26462	7	6C
0005433788158	26462	8	7C
0005435548473	26462	9	7D
0005433788143	26462	10	18A
0005435548469	26462	11	18B
0005435548470	26462	12	20C
0005435548466	26462	13	21D
0005435548465	26462	14	23B
0005433126781	10772	1	1C
0005433131638	10772	2	2B
0005435299711	10772	3	2D
0005433126777	10772	4	5A
0005433131640	10772	5	5D
0005433131637	10772	6	7A
0005435299708	10772	7	20B
0005435299702	10772	8	21B
0005433131642	10772	9	21D
0005435299709	10772	10	22A
0005433131641	10772	11	22D
0005433126821	29693	1	1A
0005435299750	29693	2	2A
0005435302178	29693	3	2C
0005433129252	29693	4	3D
0005435302176	29693	5	4C
0005433126822	29693	6	5A
0005435302174	29693	7	5B
0005435299753	29693	8	6D
0005433126820	29693	9	18C
0005435302173	29693	10	19A
0005435302175	29693	11	19C
0005433129253	29693	12	20C
0005435299752	29693	13	21D
0005435302177	29693	14	23A
0005435299751	29693	15	23B
0005432264459	2422	1	1A
0005434287162	2422	2	1B
0005432264461	2422	3	1C
0005433109863	2422	4	1D
0005434287151	2422	5	2A
0005434287164	2422	6	2B
0005433109869	2422	7	2C
0005434287163	2422	8	2D
0005433109846	2422	9	3A
0005433109934	2422	10	3C
0005434287152	2422	11	3D
0005434287157	2422	12	4A
0005434287155	2422	13	4C
0005433109900	2422	14	5A
0005434287161	2422	15	5B
0005434287148	2422	16	5C
0005434287159	2422	17	6A
0005434287154	2422	18	6B
0005433109897	2422	19	6C
0005433109845	2422	20	7A
0005434287158	2422	21	7B
0005433109868	2422	22	7C
0005434287147	2422	23	7D
0005434287146	2422	24	18B
0005434287143	2422	25	18C
0005434287156	2422	26	19A
0005433109902	2422	27	19B
0005434287160	2422	28	19C
0005434287153	2422	29	19D
0005434287145	2422	30	20A
0005434287149	2422	31	20B
0005434287144	2422	32	20C
0005432264460	2422	33	21A
0005434287150	2422	34	21B
0005433109931	2422	35	21C
0005434287142	2422	36	21D
0005433109906	2422	37	22A
0005433109871	2422	38	23A
0005433109898	2422	39	23B
0005434286980	26869	1	1B
0005433109977	26869	2	1C
0005433109982	26869	3	2B
0005434287024	26869	4	2C
0005434286951	26869	5	3A
0005433109974	26869	6	3B
0005434286993	26869	7	4A
0005434286997	26869	8	4D
0005433109976	26869	9	5A
0005434286979	26869	10	5B
0005433109979	26869	11	5D
0005433109973	26869	12	7A
0005433109978	26869	13	7B
0005433109981	26869	14	7C
0005434286992	26869	15	18B
0005434286995	26869	16	18C
0005434287017	26869	17	18D
0005434286936	26869	18	19C
0005433109975	26869	19	19D
0005433109984	26869	20	20A
0005433109985	26869	21	20B
0005434287018	26869	22	21B
0005433109983	26869	23	21D
0005434287016	26869	24	22A
0005433109980	26869	25	22C
0005434286921	26869	26	23A
0005434272164	25490	1	1B
0005435856180	25490	2	4B
0005435856178	25490	3	4C
0005434272162	25490	4	6A
0005434272163	25490	5	6C
0005434269072	25490	6	7A
0005434269073	25490	7	18D
0005435856177	25490	8	21A
0005435856179	25490	9	22A
0005434272181	26640	1	5B
0005435856133	26640	2	6C
0005434273068	26640	3	7A
0005434272182	26640	4	7B
0005434273067	26640	5	18A
0005434520137	19081	1	1A
0005434520145	19081	2	1B
0005435314809	19081	3	1C
0005435314802	19081	4	2A
0005435314803	19081	5	2B
0005434520151	19081	6	2C
0005434520139	19081	7	3A
0005435314804	19081	8	3B
0005434520157	19081	9	3C
0005435314808	19081	10	3D
0005434520126	19081	11	4A
0005434520132	19081	12	4B
0005434520150	19081	13	4C
0005435314807	19081	14	5A
0005435314812	19081	15	5B
0005434520140	19081	16	6A
0005435314811	19081	17	6B
0005434520127	19081	18	6D
0005434520146	19081	19	7A
0005434520147	19081	20	7B
0005434520149	19081	21	7D
0005434520142	19081	22	18A
0005434520148	19081	23	18C
0005434520165	19081	24	19A
0005435314806	19081	25	19B
0005435314805	19081	26	19C
0005434520141	19081	27	20A
0005435314810	19081	28	20C
0005435314814	19081	29	20D
0005434520133	19081	30	21A
0005434520134	19081	31	21B
0005434520138	19081	32	21C
0005434520144	19081	33	22B
0005435314813	19081	34	22D
0005433874332	7793	1	1A
0005433874334	7793	2	2A
0005433874330	7793	3	3D
0005433874321	7793	4	4B
0005433874322	7793	5	4D
0005433874331	7793	6	5B
0005433874329	7793	7	6C
0005433874320	7793	8	18A
0005433874325	7793	9	19A
0005433874333	7793	10	19B
0005433874328	7793	11	20A
0005433874323	7793	12	20B
0005433874326	7793	13	22A
0005433874327	7793	14	22C
0005433874324	7793	15	23B
0005433874319	32638	1	3A
0005433874307	32638	2	4B
0005433874302	32638	3	4D
0005433874298	32638	4	5C
0005433874297	32638	5	5D
0005433874318	32638	6	18A
0005433874295	32638	7	20A
0005433874306	32638	8	20B
0005433874292	32638	9	21B
0005433874291	32638	10	22D
0005433868211	4758	1	1A
0005433868190	4758	2	1C
0005433868215	4758	3	1D
0005433868182	4758	4	2B
0005435860432	4758	5	2C
0005433868203	4758	6	2D
0005433868202	4758	7	3A
0005433868210	4758	8	3B
0005433868186	4758	9	3C
0005433868181	4758	10	3D
0005433868209	4758	11	4A
0005433868179	4758	12	4B
0005433868220	4758	13	4C
0005433868199	4758	14	4D
0005433868191	4758	15	5A
0005433868193	4758	16	5C
0005433868188	4758	17	5D
0005433868194	4758	18	6A
0005433868185	4758	19	6B
0005433868198	4758	20	6C
0005433868192	4758	21	6D
0005433868205	4758	22	7A
0005433868208	4758	23	7B
0005433868216	4758	24	7D
0005433868195	4758	25	18A
0005433868204	4758	26	18B
0005433868201	4758	27	18C
0005433868187	4758	28	18D
0005433868219	4758	29	19A
0005433868212	4758	30	19B
0005433868200	4758	31	19C
0005433868213	4758	32	19D
0005433868197	4758	33	20A
0005435860433	4758	34	20B
0005433868183	4758	35	20C
0005433868184	4758	36	20D
0005433868196	4758	37	21A
0005433868180	4758	38	21B
0005433868189	4758	39	21C
0005433868218	4758	40	21D
0005433868217	4758	41	22B
0005433868207	4758	42	22C
0005433868206	4758	43	22D
0005433868214	4758	44	23A
0005433867829	32568	1	1A
0005433867859	32568	2	1B
0005433867878	32568	3	1C
0005433867888	32568	4	1D
0005433867977	32568	5	2D
0005433867823	32568	6	3A
0005433867784	32568	7	3B
0005433867824	32568	8	3D
0005433867879	32568	9	4A
0005433867954	32568	10	4B
0005433867877	32568	11	4C
0005433867837	32568	12	4D
0005433867822	32568	13	5B
0005433867745	32568	14	5C
0005433867750	32568	15	5D
0005433867835	32568	16	6A
0005433867978	32568	17	6C
0005433867783	32568	18	6D
0005433867741	32568	19	7A
0005433867950	32568	20	7B
0005433867851	32568	21	7C
0005433867875	32568	22	7D
0005433867946	32568	23	18A
0005433867913	32568	24	18B
0005433867928	32568	25	18C
0005433867843	32568	26	18D
0005435860467	32568	27	19A
0005433867838	32568	28	19B
0005433867742	32568	29	19D
0005433867739	32568	30	19C
0005433867749	32568	31	20B
0005433867842	32568	32	20D
0005433867929	32568	33	21A
0005433867836	32568	34	21B
0005433867841	32568	35	21C
0005433867900	32568	36	21D
0005433867785	32568	37	22A
0005433867951	32568	38	22B
0005433868030	32568	39	22C
0005433867927	32568	40	22D
0005433867856	32568	41	23A
0005433867999	32568	42	23B
0005434663319	3452	1	1A
0005434460494	3452	2	1B
0005434663323	3452	3	1D
0005434663331	3452	4	2D
0005434663320	3452	5	3A
0005434663329	3452	6	3C
0005434663328	3452	7	4C
0005434663330	3452	8	4D
0005435911340	3452	9	5A
0005434663332	3452	10	5D
0005434663327	3452	11	6C
0005434460493	3452	12	7C
0005434460492	3452	13	18C
0005434663324	3452	14	18D
0005434663321	3452	15	19A
0005434460491	3452	16	19C
0005434663326	3452	17	19D
0005434461634	3452	18	20D
0005435911321	3452	19	21C
0005435911332	3452	20	22B
0005434663322	3452	21	22D
0005434663325	3452	22	23A
0005435911405	12450	1	1C
0005434663199	12450	2	1D
0005435911401	12450	3	2B
0005434663223	12450	4	3A
0005434462757	12450	5	3D
0005434460473	12450	6	4C
0005435911409	12450	7	4D
0005434663190	12450	8	5C
0005434663179	12450	9	5D
0005435911404	12450	10	6A
0005435911403	12450	11	6B
0005434462752	12450	12	7B
0005434663189	12450	13	7D
0005435911402	12450	14	18A
0005434460468	12450	15	18C
0005435911408	12450	16	18D
0005434460476	12450	17	19A
0005434663263	12450	18	21A
0005434663188	12450	19	21B
0005435911407	12450	20	21C
0005434663222	12450	21	21D
0005434460466	12450	22	22B
0005434663206	12450	23	22C
0005435911406	12450	24	23B
0005433867739	14489	1	1A
0005433867745	14489	2	1B
0005433867783	14489	3	1D
0005433867784	14489	4	2A
0005433867829	14489	5	2B
0005433867954	14489	6	2C
0005433867856	14489	7	2D
0005433867785	14489	8	3A
0005433867838	14489	9	3B
0005433867742	14489	10	3C
0005433867900	14489	11	3D
0005433867836	14489	12	4A
0005433867877	14489	13	4B
0005433867824	14489	14	4C
0005433867841	14489	15	5A
0005433867843	14489	16	5B
0005433867875	14489	17	5C
0005433867927	14489	18	5D
0005433867928	14489	19	6A
0005433867837	14489	20	6B
0005433867951	14489	21	6C
0005433867842	14489	22	7A
0005433867946	14489	23	7C
0005433867822	14489	24	7D
0005433867835	14489	25	18A
0005433867823	14489	26	18B
0005433867879	14489	27	18C
0005433867878	14489	28	18D
0005435860467	14489	29	19A
0005433867950	14489	30	19D
0005433867888	14489	31	20A
0005433867978	14489	32	20B
0005433867999	14489	33	20C
0005433868030	14489	34	20D
0005433867913	14489	35	21B
0005433867977	14489	36	21C
0005433867859	14489	37	21D
0005433867741	14489	38	22A
0005433867749	14489	39	22B
0005433867929	14489	40	22C
0005433867851	14489	41	22D
0005433867750	14489	42	23A
0005433868155	32679	1	1B
0005433868174	32679	2	1C
0005433868171	32679	3	1D
0005433868163	32679	4	2A
0005433868150	32679	5	2B
0005433868158	32679	6	2C
0005433868162	32679	7	2D
0005433868145	32679	8	3A
0005433868175	32679	9	3C
0005433868169	32679	10	4A
0005433868153	32679	11	4B
0005433868152	32679	12	4C
0005433868178	32679	13	4D
0005433868170	32679	14	5A
0005433868165	32679	15	5B
0005433868142	32679	16	5C
0005433868149	32679	17	5D
0005433868159	32679	18	6B
0005433868140	32679	19	6C
0005433868141	32679	20	6D
0005433868154	32679	21	7A
0005433868139	32679	22	7B
0005433868164	32679	23	7C
0005433868173	32679	24	18A
0005433868138	32679	25	18B
0005433868161	32679	26	18C
0005433868148	32679	27	18D
0005433868176	32679	28	19A
0005433868143	32679	29	19C
0005433868160	32679	30	19D
0005433868172	32679	31	20A
0005433868147	32679	32	20B
0005433868167	32679	33	20C
0005433868177	32679	34	20D
0005433868144	32679	35	21A
0005433868168	32679	36	21B
0005433868156	32679	37	21D
0005433868146	32679	38	22A
0005433868137	32679	39	22B
0005433868166	32679	40	22C
0005433868157	32679	41	23A
0005433868151	32679	42	23B
0005432799024	12138	1	1A
0005432799031	12138	2	1B
0005432798984	12138	3	1C
0005432799120	12138	4	2B
0005432798994	12138	5	3A
0005432799067	12138	6	3B
0005432799203	12138	7	4B
0005432798962	12138	8	5C
0005432799030	12138	9	5D
0005432799066	12138	10	6B
0005432799026	12138	11	6C
0005432799025	12138	12	6D
0005432799072	12138	13	7B
0005432799064	12138	14	7C
0005432799065	12138	15	18A
0005432799123	12138	16	19B
0005432799202	12138	17	20A
0005432799152	12138	18	21A
0005432799048	12138	19	22B
0005432799151	12138	20	22C
0005432799054	12138	21	22D
0005432798999	12138	22	23A
0005432799139	12138	23	23B
0005432799251	14783	1	1A
0005432799248	14783	2	1B
0005432799255	14783	3	1D
0005432799254	14783	4	2A
0005432799250	14783	5	2D
0005432799262	14783	6	3A
0005432799263	14783	7	3C
0005432799267	14783	8	4A
0005432799257	14783	9	4D
0005432799256	14783	10	5B
0005432799253	14783	11	5D
0005432799249	14783	12	6D
0005432799259	14783	13	7B
0005432799246	14783	14	7C
0005432799260	14783	15	7D
0005432799252	14783	16	18A
0005432799243	14783	17	18B
0005432799268	14783	18	18C
0005432799264	14783	19	18D
0005432799245	14783	20	19B
0005432799266	14783	21	19C
0005432799247	14783	22	20C
0005432799258	14783	23	20D
0005432799244	14783	24	21B
0005432799269	14783	25	21C
0005432799270	14783	26	22B
0005432799265	14783	27	22C
0005432799261	14783	28	22D
0005434299421	7050	1	1A
0005434407397	7050	2	1C
0005435310853	7050	3	1F
0005432108235	7050	4	2A
0005434407402	7050	5	2D
0005434299419	7050	6	3A
0005435310859	7050	7	2F
0005434299418	7050	8	3D
0005434407412	7050	9	3C
0005434407348	7050	10	3F
0005434407387	7050	11	4A
0005434407369	7050	12	4C
0005435310888	7050	13	4B
0005434407376	7050	14	4D
0005434407400	7050	15	4E
0005434407350	7050	16	4F
0005432153895	7050	17	5B
0005432153896	7050	18	5A
0005435310860	7050	19	5C
0005434407391	7050	20	5D
0005434299409	7050	21	5E
0005434407383	7050	22	5F
0005434407375	7050	23	6B
0005434299420	7050	24	6C
0005434407401	7050	25	6D
0005435293046	7050	26	6F
0005434407399	7050	27	6E
0005434407377	7050	28	7A
0005434407411	7050	29	7B
0005434299430	7050	30	7C
0005434299417	7050	31	7D
0005434299422	7050	32	7F
0005434407361	7050	33	8A
0005434407410	7050	34	8B
0005434299426	7050	35	8D
0005434407398	7050	36	8C
0005434299414	7050	37	8E
0005432108233	7050	38	8F
0005434407384	7050	39	9A
0005434407366	7050	40	9C
0005434407365	7050	41	9B
0005434299429	7050	42	9E
0005435310836	7050	43	9D
0005434407352	7050	44	9F
0005434407355	7050	45	10B
0005434299413	7050	46	10D
0005435310861	7050	47	10C
0005435293047	7050	48	10E
0005434407362	7050	49	11A
0005434407394	7050	50	11B
0005435310879	7050	51	11D
0005435293112	7050	52	11C
0005435293089	7050	53	11F
0005434407359	7050	54	11E
0005432153892	7050	55	12A
0005434407389	7050	56	12C
0005434407363	7050	57	12B
0005434407392	7050	58	12D
0005434407408	7050	59	12E
0005434407368	7050	60	12F
0005434407406	7050	61	13B
0005434407396	7050	62	13A
0005434407354	7050	63	13C
0005434407374	7050	64	13D
0005432108236	7050	65	13E
0005434299408	7050	66	13F
0005434407382	7050	67	14C
0005434299415	7050	68	14B
0005434407405	7050	69	14D
0005434407347	7050	70	14E
0005435293081	7050	71	15A
0005435310880	7050	72	14F
0005434299424	7050	73	15B
0005432153893	7050	74	15C
0005434407388	7050	75	15D
0005434407380	7050	76	15E
0005435293085	7050	77	16A
0005434407409	7050	78	15F
0005432153894	7050	79	16B
0005434407385	7050	80	16D
0005434299427	7050	81	16E
0005434407386	7050	82	17A
0005432108234	7050	83	16F
0005434299423	7050	84	17B
0005434299416	7050	85	17D
0005434407393	7050	86	17E
0005434407372	7050	87	18A
0005434407407	7050	88	17F
0005432153898	7050	89	18B
0005434407367	7050	90	18D
0005435310882	7050	91	18C
0005434299410	7050	92	18F
0005434299428	7050	93	19A
0005434407371	7050	94	19C
0005434407370	7050	95	19B
0005434407349	7050	96	19D
0005435310876	7050	97	19F
0005434407360	7050	98	19E
0005434299431	7050	99	20B
0005434407373	7050	100	20A
0005434407357	7050	101	20C
0005434407390	7050	102	20D
0005434407356	7050	103	20E
0005434407379	7050	104	20F
0005434299412	7050	105	21A
0005434407404	7050	106	21C
0005434407381	7050	107	21B
0005435293124	7050	108	21D
0005434407358	7050	109	21F
0005435310878	7050	110	21E
0005434299425	7050	111	22A
0005432153897	7050	112	22B
0005434407403	7050	113	22C
0005434407378	7050	114	22D
0005434407351	7050	115	22E
0005435310881	7050	116	22F
0005434407353	7050	117	23B
0005435293057	7050	118	23A
0005434299411	7050	119	23C
0005434407364	7050	120	23E
0005435293123	7050	121	23D
0005434407395	7050	122	23F
0005435310979	26905	1	1A
0005434406807	26905	2	1C
0005435293176	26905	3	1F
0005434406672	26905	4	1D
0005435310991	26905	5	2A
0005434406731	26905	6	2D
0005434407087	26905	7	3A
0005434406845	26905	8	2F
0005434406895	26905	9	3C
0005434299202	26905	10	3F
0005435293179	26905	11	3D
0005434299278	26905	12	4A
0005434299338	26905	13	4B
0005432058354	26905	14	4F
0005434406671	26905	15	5A
0005434406814	26905	16	5B
0005434406774	26905	17	5D
0005434406780	26905	18	5E
0005434299337	26905	19	5F
0005435310994	26905	20	6B
0005434406738	26905	21	6C
0005435293173	26905	22	6E
0005432058355	26905	23	6D
0005434406739	26905	24	7A
0005435293177	26905	25	6F
0005435293175	26905	26	7B
0005435310989	26905	27	7C
0005434406811	26905	28	7D
0005434406967	26905	29	7F
0005434406725	26905	30	8A
0005434406678	26905	31	8B
0005435310992	26905	32	8D
0005435310981	26905	33	8E
0005434406882	26905	34	9A
0005434406659	26905	35	8F
0005434406657	26905	36	9B
0005435310978	26905	37	9C
0005435310984	26905	38	9E
0005434406648	26905	39	9F
0005434406893	26905	40	10B
0005434406658	26905	41	10C
0005434299297	26905	42	10E
0005435310990	26905	43	10D
0005432058353	26905	44	11B
0005435293181	26905	45	11C
0005434406781	26905	46	11E
0005434406697	26905	47	11F
0005434406699	26905	48	12A
0005434406753	26905	49	12D
0005434406943	26905	50	12E
0005434299291	26905	51	12F
0005434299177	26905	52	13B
0005434299336	26905	53	13C
0005434406718	26905	54	13D
0005434299264	26905	55	13E
0005435310985	26905	56	13F
0005434406703	26905	57	14C
0005432058356	26905	58	14B
0005435293171	26905	59	14D
0005434299199	26905	60	14E
0005434299288	26905	61	15B
0005434406880	26905	62	15A
0005435310993	26905	63	15C
0005434299295	26905	64	15E
0005435310988	26905	65	15D
0005434406641	26905	66	16A
0005434406978	26905	67	15F
0005434406977	26905	68	16C
0005434299296	26905	69	16D
0005434406752	26905	70	16E
0005434406684	26905	71	17B
0005435310986	26905	72	17A
0005434299249	26905	73	17C
0005434299149	26905	74	17D
0005434406843	26905	75	17F
0005434299226	26905	76	18A
0005434406698	26905	77	18B
0005435293178	26905	78	18C
0005434406936	26905	79	18D
0005434299203	26905	80	19A
0005435310995	26905	81	18F
0005435293180	26905	82	19B
0005435293174	26905	83	19D
0005434406881	26905	84	19F
0005434407048	26905	85	19E
0005435310987	26905	86	20B
0005434406844	26905	87	20A
0005434406754	26905	88	20C
0005434406812	26905	89	20D
0005434406760	26905	90	20E
0005435310982	26905	91	20F
0005434406689	26905	92	21B
0005434299178	26905	93	21A
0005434406688	26905	94	21D
0005432058352	26905	95	21C
0005434406894	26905	96	21E
0005434406842	26905	97	21F
0005435310983	26905	98	22A
0005434406676	26905	99	22C
0005434299248	26905	100	22D
0005434407033	26905	101	22E
0005434299326	26905	102	23A
0005435310980	26905	103	22F
0005434406901	26905	104	23B
0005435293170	26905	105	23C
0005434406677	26905	106	23E
0005435293172	26905	107	23D
0005434406702	26905	108	23F
0005432604092	6471	1	1A
0005434512087	6471	2	1B
0005435218102	6471	3	1C
0005432604105	6471	4	1D
0005432604120	6471	5	2A
0005432604095	6471	6	2B
0005432604093	6471	7	2C
0005432604125	6471	8	3A
0005432604124	6471	9	3B
0005432604115	6471	10	3C
0005432604123	6471	11	3D
0005432604097	6471	12	4A
0005432604099	6471	13	4B
0005432604103	6471	14	4C
0005434512085	6471	15	4D
0005432604111	6471	16	5A
0005432604107	6471	17	5B
0005432604109	6471	18	5C
0005432604104	6471	19	5D
0005434512088	6471	20	6A
0005432604091	6471	21	6B
0005432604119	6471	22	6C
0005432604110	6471	23	6D
0005432604106	6471	24	7A
0005432604096	6471	25	7C
0005432604090	6471	26	7D
0005432604102	6471	27	18A
0005432604127	6471	28	18B
0005434512089	6471	29	18C
0005432604122	6471	30	18D
0005432604112	6471	31	19A
0005432604088	6471	32	19B
0005432604100	6471	33	19C
0005432604108	6471	34	19D
0005432604094	6471	35	20A
0005432604118	6471	36	20B
0005432604089	6471	37	20C
0005432604116	6471	38	20D
0005434512086	6471	39	21A
0005432604113	6471	40	21B
0005432604098	6471	41	21D
0005432604117	6471	42	22A
0005432604126	6471	43	22B
0005432604114	6471	44	22C
0005432604101	6471	45	22D
0005432604121	6471	46	23A
0005435218101	6471	47	23B
0005432603776	21342	1	1A
0005432603756	21342	2	1B
0005432603914	21342	3	1C
0005432604014	21342	4	2A
0005432604015	21342	5	2B
0005432603656	21342	6	2C
0005432603727	21342	7	2D
0005432603764	21342	8	3A
0005434512020	21342	9	3B
0005432603709	21342	10	3D
0005432603765	21342	11	4A
0005434512047	21342	12	4B
0005432603706	21342	13	4C
0005432603755	21342	14	4D
0005432603821	21342	15	5A
0005434512056	21342	16	5B
0005432603913	21342	17	5C
0005434512031	21342	18	5D
0005432603688	21342	19	6A
0005432603707	21342	20	6C
0005432603710	21342	21	6D
0005434512050	21342	22	7B
0005432603794	21342	23	7C
0005432603697	21342	24	7D
0005432603915	21342	25	18A
0005432603743	21342	26	18B
0005432603723	21342	27	18C
0005432603808	21342	28	18D
0005432603720	21342	29	19A
0005432603681	21342	30	19B
0005432603711	21342	31	19C
0005432603926	21342	32	19D
0005434512019	21342	33	20A
0005432603829	21342	34	20B
0005434512018	21342	35	20C
0005432603803	21342	36	20D
0005432603708	21342	37	21A
0005434512035	21342	38	21C
0005432603916	21342	39	22A
0005432603766	21342	40	22B
0005432603687	21342	41	22C
0005432603762	21342	42	22D
0005432603777	21342	43	23B
0005433251289	14984	1	2A
0005434906533	14984	2	2D
0005433251296	14984	3	2F
0005433251292	14984	4	3A
0005433251282	14984	5	3D
0005434906575	14984	6	3F
0005433251285	14984	7	4A
0005434906619	14984	8	4C
0005434906677	14984	9	4D
0005434906476	14984	10	4E
0005433251294	14984	11	4F
0005433251293	14984	12	5A
0005433251300	14984	13	5C
0005434906452	14984	14	5D
0005433251284	14984	15	5F
0005434906669	14984	16	6C
0005433251287	14984	17	6D
0005434906363	14984	18	6E
0005434906482	14984	19	6F
0005433251298	14984	20	7C
0005434906551	14984	21	7D
0005433251281	14984	22	7F
0005434906460	14984	23	8A
0005434906668	14984	24	8C
0005434906474	14984	25	8D
0005433251280	14984	26	8E
0005433251286	14984	27	8F
0005434906532	14984	28	9A
0005434906519	14984	29	9C
0005433251295	14984	30	9D
0005433251301	14984	31	9E
0005434906536	14984	32	9F
0005434906458	14984	33	10A
0005434906432	14984	34	11A
0005434906398	14984	35	10F
0005434906387	14984	36	11C
0005433251304	14984	37	11D
0005434906477	14984	38	11E
0005433251277	14984	39	11F
0005434906671	14984	40	12A
0005434906399	14984	41	12C
0005434906493	14984	42	12D
0005433251299	14984	43	12E
0005434906359	14984	44	13A
0005433251278	14984	45	13C
0005433251275	14984	46	13D
0005434906459	14984	47	13E
0005433251276	14984	48	13F
0005433251283	14984	49	14A
0005434906690	14984	50	14D
0005434906520	14984	51	14E
0005433251290	14984	52	14F
0005434906464	14984	53	15A
0005433251288	14984	54	15E
0005433251279	14984	55	16C
0005434906585	14984	56	16D
0005433251305	14984	57	16F
0005434906603	14984	58	17A
0005434906550	14984	59	17C
0005433251291	14984	60	17D
0005434906676	14984	61	18A
0005434906411	14984	62	18C
0005434906453	14984	63	18D
0005434906512	14984	64	19C
0005433251302	14984	65	19D
0005434906505	14984	66	19E
0005434906434	14984	67	19F
0005434906480	14984	68	20A
0005434906461	14984	69	20C
0005433251303	14984	70	20D
0005434906388	14984	71	20E
0005433251297	14984	72	20F
0005434906925	25863	1	1A
0005434906905	25863	2	1C
0005434906937	25863	3	1D
0005434906920	25863	4	2A
0005434906915	25863	5	2C
0005433250992	25863	6	2D
0005434906934	25863	7	2F
0005433251149	25863	8	3A
0005434906930	25863	9	3C
0005433251105	25863	10	3D
0005434906921	25863	11	3F
0005434906922	25863	12	4A
0005434906912	25863	13	4C
0005433251083	25863	14	4D
0005433251142	25863	15	5A
0005433251088	25863	16	5C
0005434906940	25863	17	5D
0005433251032	25863	18	5E
0005433251049	25863	19	6A
0005434906924	25863	20	6D
0005433251143	25863	21	6C
0005434906911	25863	22	6E
0005434906907	25863	23	7C
0005434906933	25863	24	7D
0005433251043	25863	25	7E
0005434906936	25863	26	7F
0005433251103	25863	27	8A
0005434906916	25863	28	8C
0005433251073	25863	29	8D
0005433251052	25863	30	8E
0005434906910	25863	31	8F
0005434906945	25863	32	9A
0005434906943	25863	33	9C
0005433251040	25863	34	9D
0005433251047	25863	35	9E
0005433251053	25863	36	9F
0005434906928	25863	37	10A
0005434906938	25863	38	10C
0005434906926	25863	39	10D
0005434906948	25863	40	10E
0005434906932	25863	41	11A
0005433251086	25863	42	11C
0005434906927	25863	43	11D
0005434906939	25863	44	11E
0005434906950	25863	45	11F
0005434906935	25863	46	12A
0005434906942	25863	47	12C
0005433251048	25863	48	12E
0005433250987	25863	49	12F
0005433251087	25863	50	13A
0005433251204	25863	51	13C
0005434906929	25863	52	13E
0005434906917	25863	53	13F
0005434906947	25863	54	14A
0005433250971	25863	55	14C
0005434906944	25863	56	14E
0005434906946	25863	57	14F
0005434906909	25863	58	15A
0005434906919	25863	59	15C
0005433251061	25863	60	15D
0005433250965	25863	61	15F
0005433250972	25863	62	16A
0005434906931	25863	63	16D
0005434906913	25863	64	16E
0005434906923	25863	65	17D
0005434906908	25863	66	17F
0005433251104	25863	67	18A
0005434906949	25863	68	18C
0005434906914	25863	69	18F
0005434906941	25863	70	19A
0005433251041	25863	71	19C
0005433250975	25863	72	19D
0005433251063	25863	73	19E
0005433251128	25863	74	19F
0005434906906	25863	75	20C
0005434906918	25863	76	20D
0005433008377	14191	1	1A
0005433008337	14191	2	1C
0005433008341	14191	3	1D
0005433008333	14191	4	1F
0005433008357	14191	5	2C
0005433008339	14191	6	3C
0005433008354	14191	7	3F
0005433008360	14191	8	4A
0005433008343	14191	9	4D
0005433008364	14191	10	4E
0005433008334	14191	11	5A
0005433008342	14191	12	5D
0005433008350	14191	13	5E
0005433008352	14191	14	6A
0005433008375	14191	15	6C
0005433008378	14191	16	6D
0005433008344	14191	17	7D
0005433008369	14191	18	7E
0005433008348	14191	19	7F
0005433008367	14191	20	8D
0005433008366	14191	21	8E
0005433008336	14191	22	9A
0005433008362	14191	23	9C
0005433008370	14191	24	9F
0005433008345	14191	25	10C
0005433008349	14191	26	10D
0005433008356	14191	27	10E
0005433008347	14191	28	11A
0005433008353	14191	29	11C
0005433008355	14191	30	12D
0005433008373	14191	31	12F
0005433008338	14191	32	13C
0005433008335	14191	33	13D
0005433008361	14191	34	13E
0005433008368	14191	35	14A
0005433008374	14191	36	15A
0005433008351	14191	37	15C
0005433008376	14191	38	15E
0005433008372	14191	39	16C
0005433008371	14191	40	17F
0005433810488	14191	41	18D
0005433008358	14191	42	18F
0005433008363	14191	43	19C
0005433008346	14191	44	19E
0005433008340	14191	45	20C
0005433008365	14191	46	20D
0005433008359	14191	47	20F
0005433007883	22830	1	1A
0005433007850	22830	2	1C
0005433007838	22830	3	1D
0005433007915	22830	4	1F
0005433007949	22830	5	2A
0005433007948	22830	6	2C
0005433007997	22830	7	2D
0005433007934	22830	8	3A
0005433007897	22830	9	3C
0005433008034	22830	10	4C
0005433008094	22830	11	4E
0005433008077	22830	12	5D
0005433007904	22830	13	7C
0005433007905	22830	14	8F
0005433007888	22830	15	9A
0005433007952	22830	16	9E
0005433008029	22830	17	9F
0005433007992	22830	18	10F
0005433007933	22830	19	11A
0005433007932	22830	20	11C
0005433007981	22830	21	11E
0005433007916	22830	22	12C
0005433007880	22830	23	13C
0005433007946	22830	24	13A
0005433007898	22830	25	14C
0005433007983	22830	26	14E
0005433007908	22830	27	14F
0005433007871	22830	28	15A
0005433008095	22830	29	15C
0005433007967	22830	30	16C
0005433008044	22830	31	16D
0005433007960	22830	32	16E
0005433007894	22830	33	17C
0005433007833	22830	34	17E
0005433007824	22830	35	17F
0005433007858	22830	36	18C
0005433007982	22830	37	18E
0005433007843	22830	38	18F
0005433007947	22830	39	19A
0005433007884	22830	40	19D
0005433007835	22830	41	19E
0005433007951	22830	42	20A
0005433007837	22830	43	20C
0005433007964	22830	44	20F
0005434925340	14911	1	1F
0005434925301	14911	2	1D
0005434925381	14911	3	2A
0005434925319	14911	4	4A
0005434925459	14911	5	4D
0005434925253	14911	6	4E
0005434925361	14911	7	5F
0005434925277	14911	8	6A
0005434925263	14911	9	6F
0005434925358	14911	10	7F
0005434925265	14911	11	8A
0005434925457	14911	12	8C
0005434925266	14911	13	8F
0005434925306	14911	14	10C
0005434925353	14911	15	10E
0005434925411	14911	16	11A
0005434925359	14911	17	11C
0005434925262	14911	18	12A
0005434925278	14911	19	13E
0005434925304	14911	20	14D
0005434925360	14911	21	15A
0005434925254	14911	22	16A
0005434925458	14911	23	17A
0005434925311	14911	24	17C
0005434925312	14911	25	17E
0005434925412	14911	26	17F
0005434925387	14911	27	18E
0005434925320	14911	28	18F
0005434925276	14911	29	19D
0005434925305	14911	30	19F
0005434925341	14911	31	20E
0005434925585	20495	1	1A
0005434925596	20495	2	5A
0005434925606	20495	3	5C
0005434925594	20495	4	5E
0005434925590	20495	5	6A
0005434925573	20495	6	6D
0005434925604	20495	7	7D
0005434925603	20495	8	7F
0005434925600	20495	9	8C
0005434925578	20495	10	9A
0005434925592	20495	11	9D
0005434925588	20495	12	9F
0005434925574	20495	13	10A
0005434925587	20495	14	10D
0005434925584	20495	15	11C
0005434925593	20495	16	11D
0005434925599	20495	17	12C
0005434925589	20495	18	12D
0005434925583	20495	19	12E
0005434925605	20495	20	14A
0005434925580	20495	21	14C
0005434925597	20495	22	15D
0005434925579	20495	23	16A
0005434925586	20495	24	16C
0005434925591	20495	25	17D
0005434925581	20495	26	18A
0005434925572	20495	27	18C
0005434925577	20495	28	18E
0005434925595	20495	29	18F
0005434925601	20495	30	19A
0005434925582	20495	31	19C
0005434925575	20495	32	19D
0005434925576	20495	33	19F
0005434925602	20495	34	20A
0005434925598	20495	35	20E
0005435998974	15819	1	1A
0005435487699	15819	2	1B
0005435998998	15819	3	1C
0005435487716	15819	4	2A
0005435487713	15819	5	2B
0005435998992	15819	6	2C
0005435998985	15819	7	2D
0005435487701	15819	8	3A
0005435487711	15819	9	3B
0005435998986	15819	10	3C
0005435998954	15819	11	3D
0005435487714	15819	12	4A
0005435998993	15819	13	4C
0005435487702	15819	14	4D
0005435487712	15819	15	5B
0005435487706	15819	16	5C
0005435487698	15819	17	5D
0005435998956	15819	18	6A
0005435998958	15819	19	6B
0005435487718	15819	20	6C
0005435998977	15819	21	7B
0005435998960	15819	22	7C
0005435487704	15819	23	7D
0005435998959	15819	24	18A
0005435487700	15819	25	18C
0005435998997	15819	26	18D
0005435998963	15819	27	19A
0005435487703	15819	28	19B
0005435487710	15819	29	19C
0005435487705	15819	30	19D
0005435998955	15819	31	20B
0005435998981	15819	32	20C
0005435487707	15819	33	20D
0005435487717	15819	34	21C
0005435487709	15819	35	21D
0005435487708	15819	36	22A
0005435998994	15819	37	22B
0005435487697	15819	38	22C
0005435998964	15819	39	22D
0005435998973	15819	40	23A
0005435487715	15819	41	23B
0005435999140	19689	1	1A
0005435999135	19689	2	1B
0005435487535	19689	3	2A
0005435487493	19689	4	3A
0005435999136	19689	5	3C
0005435487488	19689	6	3D
0005435487537	19689	7	4A
0005435487483	19689	8	4B
0005435999129	19689	9	4D
0005435999141	19689	10	4C
0005435487460	19689	11	6A
0005435999132	19689	12	6B
0005435487536	19689	13	6C
0005435999130	19689	14	7A
0005435999138	19689	15	7B
0005435487524	19689	16	7C
0005435999133	19689	17	7D
0005435487454	19689	18	18A
0005435487471	19689	19	18B
0005435999134	19689	20	18C
0005435487546	19689	21	18D
0005435487455	19689	22	19A
0005435487453	19689	23	19B
0005435999131	19689	24	19C
0005435487545	19689	25	19D
0005435999142	19689	26	20A
0005435999137	19689	27	21B
0005435487525	19689	28	21C
0005435999143	19689	29	21D
0005435487462	19689	30	22B
0005435487487	19689	31	22C
0005435487623	19689	32	23A
0005435999139	19689	33	23B
0005435839285	6021	1	1C
0005435472604	6021	2	1A
0005435839301	6021	3	2F
0005435839294	6021	4	2D
0005435472530	6021	5	3D
0005435839297	6021	6	4D
0005435472566	6021	7	5A
0005435472545	6021	8	5F
0005432660806	6021	9	6E
0005432659694	6021	10	7F
0005435839280	6021	11	8B
0005435839296	6021	12	8D
0005435839298	6021	13	8E
0005432659696	6021	14	9B
0005432142233	6021	15	9C
0005435839300	6021	16	9E
0005435839291	6021	17	10B
0005435472546	6021	18	10E
0005435839290	6021	19	10F
0005435472563	6021	20	11B
0005432142234	6021	21	11A
0005435839274	6021	22	12A
0005435472559	6021	23	12C
0005435472610	6021	24	12E
0005435839276	6021	25	12F
0005435839282	6021	26	13E
0005435839281	6021	27	13D
0005435839299	6021	28	14A
0005435839293	6021	29	14C
0005435472529	6021	30	14B
0005432658579	6021	31	15B
0005435839286	6021	32	15A
0005435472562	6021	33	15C
0005435472564	6021	34	16A
0005435839284	6021	35	15F
0005435472567	6021	36	16C
0005435472611	6021	37	16D
0005435839289	6021	38	17A
0005435839283	6021	39	17C
0005435839279	6021	40	17B
0005435839275	6021	41	17D
0005435839288	6021	42	17F
0005432142232	6021	43	18B
0005432660807	6021	44	18E
0005432659695	6021	45	19A
0005435839287	6021	46	18F
0005435839292	6021	47	19C
0005435472551	6021	48	19B
0005432658580	6021	49	19E
0005435839278	6021	50	19D
0005435839277	6021	51	20A
0005435472531	6021	52	20D
0005435839295	6021	53	20C
0005435472603	6021	54	21A
0005435839302	6021	55	21C
0005432658581	6021	56	21F
0005432667420	18073	1	1C
0005435472698	18073	2	2F
0005435839128	18073	3	4A
0005435472705	18073	4	5A
0005432537046	18073	5	5D
0005435839158	18073	6	6B
0005435472701	18073	7	6A
0005435839061	18073	8	8B
0005435839104	18073	9	8F
0005435839108	18073	10	9B
0005435838962	18073	11	9A
0005435472706	18073	12	9F
0005435472699	18073	13	9D
0005435839107	18073	14	10A
0005435839010	18073	15	10C
0005435472697	18073	16	10F
0005435472711	18073	17	11F
0005435838961	18073	18	12D
0005435839057	18073	19	12C
0005435472710	18073	20	12E
0005435839105	18073	21	13D
0005435839046	18073	22	14B
0005435472703	18073	23	14D
0005435472709	18073	24	16A
0005435472708	18073	25	16E
0005435839045	18073	26	16D
0005435472707	18073	27	16F
0005435472702	18073	28	17C
0005435472704	18073	29	17E
0005435839040	18073	30	18B
0005435839106	18073	31	18A
0005435472712	18073	32	18D
0005435472713	18073	33	19C
0005435472700	18073	34	20A
0005435839041	18073	35	19E
0005432537047	18073	36	20C
0005432537045	18073	37	21A
0005435839011	18073	38	21C
0005435839157	18073	39	21E
0005433284937	23044	1	1A
0005433284833	23044	2	1D
0005433284863	23044	3	2C
0005433284920	23044	4	2D
0005433284881	23044	5	3C
0005433284921	23044	6	3F
0005433284790	23044	7	4D
0005433284908	23044	8	4C
0005433284960	23044	9	4E
0005433284779	23044	10	5A
0005433284874	23044	11	5B
0005433284926	23044	12	6C
0005433284830	23044	13	6E
0005433284846	23044	14	7B
0005433284864	23044	15	7D
0005433284850	23044	16	8E
0005433284778	23044	17	9A
0005433284789	23044	18	9D
0005433284827	23044	19	9F
0005433284847	23044	20	10E
0005433284831	23044	21	11F
0005433284862	23044	22	12F
0005433284810	23044	23	13B
0005433284880	23044	24	13D
0005433284832	23044	25	13C
0005433284826	23044	26	14A
0005433284851	23044	27	14E
0005433284871	23044	28	14F
0005433284860	23044	29	15E
0005433284943	23044	30	16D
0005433284848	23044	31	17E
0005433284836	23044	32	17F
0005433284882	23044	33	18C
0005433284922	23044	34	19D
0005433284940	23044	35	20A
0005433284927	23044	36	20D
0005433284835	23044	37	20F
0005433284889	23044	38	21E
0005433284839	23044	39	21F
0005433284811	23044	40	22A
0005433284834	23044	41	22D
0005433284959	23044	42	23A
0005433284909	23044	43	23D
0005433285133	32075	1	3C
0005433285106	32075	2	4A
0005435103817	32075	3	4D
0005433285124	32075	4	4E
0005433285125	32075	5	5A
0005433285113	32075	6	5C
0005433285104	32075	7	6A
0005433285123	32075	8	6C
0005433285112	32075	9	6D
0005433285117	32075	10	8B
0005435103811	32075	11	8D
0005433285128	32075	12	8F
0005433285110	32075	13	9C
0005433285109	32075	14	9F
0005435103806	32075	15	10E
0005433285121	32075	16	11B
0005433285116	32075	17	11C
0005433285134	32075	18	12E
0005433285114	32075	19	12D
0005433285129	32075	20	13F
0005433285105	32075	21	14A
0005433285122	32075	22	14C
0005433285120	32075	23	15E
0005433285131	32075	24	17A
0005435103803	32075	25	17E
0005433285108	32075	26	18A
0005433285130	32075	27	18D
0005433285118	32075	28	19A
0005433285111	32075	29	19D
0005435103810	32075	30	20A
0005433285132	32075	31	20D
0005435103816	32075	32	21D
0005433285127	32075	33	21F
0005433285103	32075	34	22C
0005433285107	32075	35	22E
0005433285119	32075	36	22F
0005433285126	32075	37	23B
0005433285115	32075	38	23F
0005435213204	30586	1	1A
0005435213227	30586	2	1D
0005432526111	30586	3	2A
0005435213197	30586	4	1K
0005432525982	30586	5	1H
0005435213185	30586	6	2C
0005435213196	30586	7	2H
0005432526686	30586	8	2G
0005435213170	30586	9	3A
0005434066534	30586	10	3K
0005434066746	30586	11	3H
0005432211459	30586	12	3G
0005432526267	30586	13	4C
0005434066730	30586	14	4A
0005432526056	30586	15	4D
0005432525672	30586	16	5A
0005432526194	30586	17	4K
0005432526219	30586	18	5D
0005432526418	30586	19	5C
0005432526440	30586	20	5G
0005432525835	30586	21	11A
0005432526491	30586	22	11F
0005432525735	30586	23	11E
0005435213208	30586	24	11H
0005432526308	30586	25	11G
0005434066845	30586	26	12C
0005434066402	30586	27	12A
0005432525811	30586	28	12E
0005435213163	30586	29	12D
0005434066451	30586	30	12G
0005434066464	30586	31	12F
0005434066608	30586	32	12K
0005432428887	30586	33	13D
0005432525957	30586	34	13C
0005435213195	30586	35	13A
0005432526439	30586	36	13E
0005432525708	30586	37	13H
0005434066636	30586	38	14C
0005432533247	30586	39	13K
0005432526183	30586	40	14D
0005432526339	30586	41	14G
0005432526446	30586	42	14F
0005434066514	30586	43	14K
0005432525803	30586	44	14H
0005434066846	30586	45	15A
0005432526537	30586	46	15D
0005432428876	30586	47	15H
0005432526068	30586	48	15G
0005435630952	30586	49	15F
0005434066681	30586	50	16A
0005435213201	30586	51	15K
0005432525874	30586	52	16D
0005435213226	30586	53	16C
0005434066650	30586	54	16G
0005433656654	30586	55	16F
0005435213192	30586	56	16E
0005435213202	30586	57	16H
0005434066536	30586	58	17C
0005432526736	30586	59	17G
0005432525970	30586	60	17F
0005435213164	30586	61	17E
0005434066370	30586	62	17K
0005432526234	30586	63	17H
0005434066431	30586	64	18A
0005435213168	30586	65	18E
0005432526118	30586	66	18D
0005435213228	30586	67	18C
0005432525812	30586	68	18G
0005434066635	30586	69	18F
0005432526737	30586	70	18H
0005432535745	30586	71	19B
0005434066535	30586	72	19A
0005432525786	30586	73	19D
0005432526185	30586	74	19C
0005435213176	30586	75	19F
0005435213166	30586	76	19E
0005432525752	30586	77	19H
0005435213174	30586	78	19G
0005435213191	30586	79	20C
0005432526407	30586	80	20B
0005432526437	30586	81	20E
0005432526042	30586	82	20D
0005434066541	30586	83	20H
0005435213207	30586	84	20F
0005432525920	30586	85	20J
0005434066573	30586	86	21B
0005434066453	30586	87	21A
0005432526404	30586	88	20K
0005435725574	30586	89	21D
0005434066628	30586	90	21C
0005435213171	30586	91	21G
0005432526200	30586	92	21E
0005432526101	30586	93	21H
0005435213162	30586	94	21J
0005432526536	30586	95	22C
0005432537028	30586	96	22B
0005432526687	30586	97	22F
0005432526140	30586	98	22E
0005435213188	30586	99	22G
0005435213216	30586	100	22K
0005432526331	30586	101	22J
0005435630954	30586	102	23B
0005432526237	30586	103	23D
0005432159836	30586	104	23C
0005432525987	30586	105	23G
0005432525910	30586	106	23F
0005432526568	30586	107	23E
0005432525921	30586	108	24D
0005434066372	30586	109	23K
0005432533251	30586	110	24F
0005435725575	30586	111	24E
0005432526105	30586	112	24G
0005434066484	30586	113	25C
0005434066609	30586	114	25H
0005432526098	30586	115	25G
0005432525898	30586	116	26A
0005434066396	30586	117	25J
0005434066570	30586	118	26C
0005432525695	30586	119	26E
0005432526117	30586	120	26D
0005432526416	30586	121	26G
0005432526157	30586	122	26F
0005432526067	30586	123	26J
0005435213213	30586	124	26H
0005432525850	30586	125	27A
0005432211464	30586	126	26K
0005432527097	30586	127	27D
0005434066738	30586	128	27C
0005432428877	30586	129	27B
0005435213211	30586	130	27F
0005432526028	30586	131	27E
0005435213181	30586	132	27J
0005435213173	30586	133	27H
0005434066553	30586	134	28A
0005432159833	30586	135	27K
0005432428875	30586	136	28B
0005435213200	30586	137	28D
0005432526397	30586	138	28K
0005434066580	30586	139	28J
0005432526688	30586	140	28H
0005434066582	30586	141	29A
0005432526677	30586	142	29D
0005435213186	30586	143	29C
0005432526287	30586	144	29F
0005432525787	30586	145	29E
0005432526302	30586	146	29J
0005432428867	30586	147	29H
0005434066332	30586	148	30A
0005432525668	30586	149	29K
0005432159835	30586	150	30D
0005435213199	30586	151	30G
0005432526604	30586	152	30H
0005432526226	30586	153	31B
0005435213215	30586	154	30K
0005432526139	30586	155	31D
0005435213190	30586	156	31C
0005432211460	30586	157	31F
0005432525897	30586	158	31E
0005435213224	30586	159	31H
0005432525912	30586	160	31G
0005432526303	30586	161	31K
0005432526233	30586	162	31J
0005432526255	30586	163	32B
0005435725577	30586	164	32E
0005432526352	30586	165	32D
0005432428878	30586	166	32J
0005432526296	30586	167	32H
0005432526094	30586	168	33B
0005435213218	30586	169	33A
0005432527071	30586	170	32K
0005434066452	30586	171	33D
0005434066471	30586	172	33C
0005432525802	30586	173	33F
0005434066416	30586	174	33E
0005432533249	30586	175	33H
0005432526426	30586	176	33G
0005434066404	30586	177	33K
0005432533255	30586	178	33J
0005435213210	30586	179	34C
0005432525881	30586	180	34B
0005435213219	30586	181	34E
0005432526167	30586	182	34D
0005435213175	30586	183	34G
0005432526529	30586	184	34H
0005435630950	30586	185	35B
0005434066550	30586	186	35A
0005435725576	30586	187	34K
0005432525785	30586	188	35C
0005432526312	30586	189	35G
0005432526396	30586	190	35F
0005434066403	30586	191	35E
0005433656653	30586	192	35J
0005435213229	30586	193	35H
0005435213169	30586	194	36A
0005432526203	30586	195	35K
0005434066373	30586	196	36C
0005432526186	30586	197	36B
0005432525958	30586	198	36D
0005435213165	30586	199	36G
0005435213206	30586	200	36F
0005432211461	30586	201	36J
0005435213167	30586	202	36H
0005432535769	30586	203	37B
0005435213161	30586	204	37A
0005432211465	30586	205	37D
0005434066333	30586	206	37F
0005432526372	30586	207	37E
0005434066334	30586	208	37J
0005432525833	30586	209	37H
0005435213223	30586	210	38A
0005435213222	30586	211	37K
0005432526066	30586	212	38C
0005434066354	30586	213	38B
0005432526125	30586	214	38J
0005432525981	30586	215	38H
0005435213220	30586	216	39B
0005435213172	30586	217	39A
0005432526438	30586	218	39C
0005432525847	30586	219	39E
0005434066574	30586	220	39J
0005432526099	30586	221	39H
0005434066559	30586	222	39K
0005432525804	30586	223	40C
0005434066556	30586	224	40B
0005434066632	30586	225	40A
0005435630953	30586	226	40E
0005432526156	30586	227	40D
0005434066651	30586	228	40G
0005432526503	30586	229	40F
0005435213221	30586	230	40J
0005432526112	30586	231	41B
0005432525911	30586	232	41A
0005432525797	30586	233	40K
0005435213179	30586	234	41D
0005434066347	30586	235	41C
0005432526027	30586	236	41F
0005432526263	30586	237	41E
0005432535768	30586	238	41K
0005432526304	30586	239	42C
0005432211458	30586	240	42B
0005434066557	30586	241	42A
0005432159834	30586	242	42E
0005434066680	30586	243	42D
0005432526225	30586	244	42H
0005434066584	30586	245	42G
0005432526286	30586	246	42F
0005432526415	30586	247	42J
0005435213184	30586	248	43A
0005432211463	30586	249	42K
0005432533248	30586	250	43D
0005432211462	30586	251	43C
0005432526220	30586	252	43B
0005434066446	30586	253	43F
0005435630951	30586	254	43E
0005434066814	30586	255	43H
0005435213187	30586	256	43G
0005435213203	30586	257	44A
0005432526087	30586	258	44C
0005432526244	30586	259	44B
0005432211466	30586	260	44E
0005432159832	30586	261	44G
0005435213217	30586	262	44F
0005435213178	30586	263	44J
0005435213209	30586	264	44H
0005432526055	30586	265	45A
0005434066335	30586	266	45F
0005432526827	30586	267	45E
0005435213214	30586	268	45D
0005434066518	30586	269	45G
0005432526254	30586	270	45K
0005434066581	30586	271	45J
0005432526035	30586	272	46B
0005432526447	30586	273	46E
0005433656655	30586	274	46D
0005435213177	30586	275	46C
0005432526077	30586	276	46G
0005435213205	30586	277	46F
0005432526367	30586	278	46J
0005435213193	30586	279	46H
0005435213189	30586	280	47C
0005435213198	30586	281	47A
0005432526544	30586	282	47E
0005432159831	30586	283	47D
0005435213183	30586	284	47G
0005432428886	30586	285	47F
0005432526545	30586	286	47K
0005432526603	30586	287	48C
0005435213180	30586	288	48A
0005434066371	30586	289	48F
0005432525846	30586	290	48E
0005435213194	30586	291	48H
0005434066627	30586	292	49A
0005435213225	30586	293	49D
0005435213212	30586	294	49C
0005432537029	30586	295	49F
0005434066682	30586	296	49E
0005434066549	30586	297	49K
0005432428885	30586	298	49H
0005435213182	30586	299	50C
0005434066847	30586	300	50A
0005435725573	30586	301	50E
0005434066569	30586	302	50D
0005432525882	30586	303	50G
0005434066600	30586	304	50F
0005432526460	30586	305	51D
0005432526262	30586	306	50K
0005432526088	30586	307	50H
0005434066519	30586	308	51F
0005432525971	30586	309	51E
0005432526702	30586	310	51G
0005433367712	24857	1	1A
0005435652393	24857	2	1C
0005433367714	24857	3	1D
0005435652257	24857	4	1F
0005433367680	24857	5	2C
0005435652420	24857	6	2D
0005435652264	24857	7	2F
0005433367693	24857	8	3A
0005435652413	24857	9	3C
0005435652387	24857	10	3D
0005433367690	24857	11	3F
0005435652427	24857	12	4E
0005435652317	24857	13	4F
0005435652342	24857	14	5A
0005433367703	24857	15	5D
0005435652278	24857	16	5E
0005435652418	24857	17	5F
0005435652383	24857	18	6A
0005435652326	24857	19	6C
0005435652316	24857	20	6E
0005435652259	24857	21	6F
0005433367682	24857	22	7A
0005433367681	24857	23	7C
0005433367706	24857	24	7D
0005435652319	24857	25	7E
0005433367709	24857	26	7F
0005433367716	24857	27	8A
0005435652409	24857	28	8D
0005433367711	24857	29	8F
0005435652388	24857	30	9A
0005435652364	24857	31	9D
0005433367695	24857	32	9E
0005433367692	24857	33	10A
0005435652392	24857	34	10C
0005433367715	24857	35	10E
0005435652371	24857	36	10F
0005433367694	24857	37	11A
0005435652394	24857	38	11C
0005435652368	24857	39	11E
0005433367679	24857	40	11F
0005435652382	24857	41	12A
0005433367683	24857	42	12C
0005433367708	24857	43	12D
0005433367710	24857	44	12E
0005433367696	24857	45	12F
0005433367705	24857	46	13A
0005435652321	24857	47	13C
0005433367702	24857	48	13D
0005433367699	24857	49	13E
0005435652363	24857	50	13F
0005433367698	24857	51	14A
0005435652361	24857	52	14E
0005435652260	24857	53	14F
0005435652318	24857	54	15A
0005433367704	24857	55	15C
0005435652304	24857	56	15D
0005433367691	24857	57	15E
0005433367685	24857	58	16A
0005433367684	24857	59	16C
0005435652362	24857	60	16D
0005433367687	24857	61	16E
0005433367688	24857	62	16F
0005435652446	24857	63	17A
0005433367686	24857	64	17C
0005433367689	24857	65	17D
0005435652255	24857	66	17E
0005435652410	24857	67	17F
0005433367713	24857	68	18A
0005435652433	24857	69	18C
0005433367707	24857	70	18E
0005433367701	24857	71	18F
0005433367697	24857	72	19A
0005435652419	24857	73	19D
0005433367700	24857	74	19E
0005435652341	24857	75	20A
0005435652349	24857	76	20C
0005435652441	24857	77	20F
0005435801680	2035	1	1B
0005434979648	2035	2	1D
0005434979637	2035	3	2C
0005434979629	2035	4	2D
0005434979647	2035	5	3B
0005434979635	2035	6	3C
0005434979626	2035	7	4A
0005434979632	2035	8	4B
0005434979645	2035	9	4C
0005434979625	2035	10	5A
0005434979633	2035	11	5C
0005434979643	2035	12	5D
0005434979641	2035	13	6A
0005435801681	2035	14	6B
0005434979642	2035	15	6C
0005434979651	2035	16	6D
0005434979644	2035	17	7A
0005434979638	2035	18	7C
0005434979628	2035	19	7D
0005434979622	2035	20	18B
0005434979639	2035	21	19A
0005434979631	2035	22	19B
0005434979630	2035	23	20A
0005434979624	2035	24	20C
0005434979623	2035	25	21A
0005434979627	2035	26	21C
0005434979646	2035	27	21D
0005434979649	2035	28	22A
0005434979636	2035	29	22C
0005434979650	2035	30	22D
0005434979634	2035	31	23A
0005434979640	2035	32	23B
0005434979335	23558	1	1A
0005434979399	23558	2	1C
0005434979334	23558	3	1D
0005434979369	23558	4	2A
0005435801660	23558	5	2C
0005434979407	23558	6	3A
0005434979323	23558	7	3C
0005434979360	23558	8	4A
0005434979430	23558	9	4B
0005434979336	23558	10	4C
0005434979390	23558	11	4D
0005434979370	23558	12	5B
0005435801651	23558	13	5C
0005434979257	23558	14	6A
0005434979345	23558	15	6C
0005434979398	23558	16	7C
0005434979465	23558	17	18A
0005434979264	23558	18	18C
0005434979318	23558	19	18D
0005434979263	23558	20	19D
0005434979351	23558	21	20C
0005434979319	23558	22	20D
0005434979256	23558	23	21A
0005434979352	23558	24	21C
0005434979314	23558	25	23A
0005434979359	23558	26	23B
0005434952512	2590	1	1A
0005434952510	2590	2	4A
0005434952513	2590	3	4B
0005434952511	2590	4	5A
0005433256391	2589	1	1B
0005433256396	2589	2	3B
0005433256398	2589	3	4A
0005433256397	2589	4	6B
0005433256410	28228	1	1A
0005434952473	28228	2	6B
0005433112365	19787	1	3A
0005433112366	19787	2	4A
0005434136858	11951	1	1A
0005434137029	11951	2	1C
0005434136759	11951	3	1F
0005434137180	11951	4	2A
0005434136939	11951	5	2C
0005434136991	11951	6	2D
0005434136774	11951	7	3C
0005434137173	11951	8	3F
0005434136685	11951	9	4A
0005434137160	11951	10	4C
0005434137161	11951	11	4F
0005434136990	11951	12	5A
0005434137019	11951	13	5C
0005434136784	11951	14	5D
0005434136986	11951	15	5E
0005434136833	11951	16	5F
0005434136695	11951	17	6C
0005434136927	11951	18	6E
0005434136923	11951	19	6F
0005434137084	11951	20	7A
0005434137145	11951	21	7C
0005434137047	11951	22	7D
0005434137136	11951	23	7E
0005434137308	11951	24	7F
0005434136697	11951	25	8C
0005434136892	11951	26	8D
0005434137201	11951	27	8E
0005434136782	11951	28	9A
0005434137211	11951	29	9C
0005434136971	11951	30	9D
0005434136790	11951	31	9E
0005434136795	11951	32	9F
0005434137020	11951	33	10A
0005434136705	11951	34	10C
0005434137252	11951	35	10D
0005434136775	11951	36	10E
0005434137125	11951	37	10F
0005434137207	11951	38	11A
0005434137174	11951	39	11C
0005434136901	11951	40	11D
0005434137171	11951	41	11E
0005434136794	11951	42	12A
0005434136996	11951	43	12C
0005434136951	11951	44	12D
0005434137251	11951	45	12E
0005434136789	11951	46	12F
0005434137085	11951	47	13A
0005434136953	11951	48	13C
0005434137083	11951	49	13D
0005434136985	11951	50	13E
0005434136696	11951	51	14A
0005434136694	11951	52	14C
0005434136820	11951	53	14D
0005434137172	11951	54	14E
0005434137055	11951	55	14F
0005434136972	11951	56	15A
0005434137236	11951	57	15C
0005434136952	11951	58	15F
0005434137126	11951	59	16A
0005434136954	11951	60	16C
0005434137163	11951	61	16E
0005434136989	11951	62	16F
0005434137137	11951	63	17C
0005434137162	11951	64	17D
0005434136847	11951	65	17E
0005434136926	11951	66	17F
0005434136987	11951	67	18A
0005434137175	11951	68	18C
0005434137092	11951	69	18D
0005434137102	11951	70	18E
0005434137292	11951	71	18F
0005434137022	11951	72	19A
0005434137190	11951	73	19D
0005434137293	11951	74	19E
0005434136824	11951	75	20A
0005434136706	11951	76	20C
0005434136997	11951	77	20D
0005434137200	11951	78	20F
0005434137644	28711	1	1D
0005434137707	28711	2	1F
0005434137703	28711	3	2A
0005434137666	28711	4	2C
0005434137697	28711	5	2D
0005434137702	28711	6	2F
0005434137679	28711	7	3A
0005434137658	28711	8	3C
0005434137637	28711	9	3D
0005434137667	28711	10	3F
0005434137690	28711	11	4A
0005434137625	28711	12	4C
0005434137698	28711	13	4D
0005434137705	28711	14	4E
0005434137675	28711	15	5A
0005434137632	28711	16	5D
0005434137687	28711	17	5E
0005434137642	28711	18	5F
0005434137680	28711	19	6A
0005434137659	28711	20	6C
0005434137665	28711	21	6D
0005434137694	28711	22	6E
0005434137695	28711	23	7A
0005434137700	28711	24	7C
0005434137669	28711	25	7D
0005434137630	28711	26	7E
0005434137636	28711	27	7F
0005434137635	28711	28	8A
0005434137691	28711	29	8D
0005434137677	28711	30	8E
0005434137668	28711	31	8F
0005434137682	28711	32	9A
0005434137693	28711	33	9D
0005434137699	28711	34	9E
0005434137643	28711	35	9F
0005434137640	28711	36	10A
0005434137661	28711	37	10C
0005434137686	28711	38	10D
0005434137651	28711	39	10E
0005434137657	28711	40	10F
0005434137664	28711	41	11A
0005434137624	28711	42	11C
0005434137648	28711	43	11D
0005434137653	28711	44	11F
0005434137652	28711	45	12A
0005434137670	28711	46	12C
0005434137684	28711	47	12D
0005434137650	28711	48	12E
0005434137639	28711	49	12F
0005434137673	28711	50	13A
0005434137647	28711	51	13C
0005434137627	28711	52	13D
0005434137681	28711	53	13E
0005434137676	28711	54	13F
0005434137646	28711	55	14A
0005434137689	28711	56	14C
0005434137629	28711	57	14D
0005434137671	28711	58	14E
0005434137655	28711	59	14F
0005434137701	28711	60	15A
0005434137688	28711	61	15C
0005434137683	28711	62	15E
0005434137656	28711	63	16A
0005434137649	28711	64	16C
0005434137662	28711	65	16D
0005434137706	28711	66	16E
0005434137641	28711	67	16F
0005434137663	28711	68	17A
0005434137660	28711	69	17D
0005434137704	28711	70	17F
0005434137678	28711	71	18A
0005434137645	28711	72	18D
0005434137685	28711	73	18E
0005434137634	28711	74	18F
0005434137633	28711	75	19A
0005434137674	28711	76	19C
0005434137654	28711	77	19D
0005434137626	28711	78	19E
0005434137672	28711	79	19F
0005434137692	28711	80	20A
0005434137638	28711	81	20C
0005434137631	28711	82	20D
0005434137628	28711	83	20E
0005434137696	28711	84	20F
0005435259706	6818	1	1A
0005433538825	6818	2	1B
0005433538828	6818	3	1C
0005433538826	6818	4	2D
0005433534486	6818	5	3A
0005433538829	6818	6	3D
0005433534488	6818	7	5A
0005433538831	6818	8	5D
0005435259694	6818	9	6A
0005433538823	6818	10	19B
0005433538824	6818	11	19C
0005435259707	6818	12	19D
0005433538827	6818	13	21A
0005433534487	6818	14	21B
0005435259708	6818	15	21C
0005433538830	6818	16	21D
0005433538782	25033	1	6A
0005435259733	25033	2	6B
0005435259732	25033	3	6C
0005435259736	25033	4	18A
0005435259734	25033	5	19B
0005435259735	25033	6	19D
0005433538722	25033	7	20B
0005433538723	25033	8	21C
0005433511905	841	1	1D
0005433511913	841	2	2A
0005432922493	841	3	3B
0005433511904	841	4	5D
0005433511908	841	5	6D
0005432922460	841	6	7A
0005433511912	841	7	7C
0005433511907	841	8	18B
0005433511911	841	9	19C
0005433511910	841	10	21D
0005433511909	841	11	22A
0005433511906	841	12	22C
0005433511815	16164	1	1D
0005433511832	16164	2	2C
0005432922502	16164	3	3C
0005433511816	16164	4	3D
0005433511861	16164	5	4B
0005432922504	16164	6	4D
0005432922503	16164	7	6C
0005433511827	16164	8	18B
0005433511833	16164	9	22C
0005432922505	16164	10	23B
0005433475677	4031	1	1B
0005433475675	4031	2	2A
0005433475679	4031	3	3A
0005433475681	4031	4	4D
0005433475686	4031	5	5A
0005433475688	4031	6	5B
0005435852542	4031	7	5D
0005433475676	4031	8	6A
0005433475678	4031	9	7B
0005435852527	4031	10	18B
0005433475682	4031	11	18C
0005435852531	4031	12	19C
0005433475674	4031	13	19D
0005435852543	4031	14	20B
0005433475687	4031	15	20C
0005433475680	4031	16	20D
0005433475685	4031	17	21C
0005435852529	4031	18	21D
0005433475683	4031	19	23A
0005433475684	4031	20	23B
0005435697216	3668	1	1A
0005435697194	3668	2	1C
0005435697208	3668	3	1D
0005435697200	3668	4	2B
0005435697201	3668	5	2C
0005435697198	3668	6	2D
0005435697206	3668	7	3A
0005435697189	3668	8	3B
0005435697214	3668	9	3C
0005435697215	3668	10	3D
0005435697188	3668	11	4A
0005435697204	3668	12	4B
0005435697199	3668	13	4C
0005435916129	3668	14	4D
0005435697203	3668	15	5A
0005435697207	3668	16	5D
0005435916138	3668	17	6A
0005435697197	3668	18	6B
0005435697205	3668	19	6C
0005434950508	3668	20	6D
0005435916146	3668	21	7A
0005435697191	3668	22	7B
0005434950506	3668	23	7C
0005434950505	3668	24	7D
0005435697209	3668	25	18B
0005435935006	3668	26	18D
0005435697213	3668	27	19A
0005435697210	3668	28	19B
0005435697196	3668	29	19C
0005435697192	3668	30	19D
0005435697193	3668	31	20B
0005434950507	3668	32	21A
0005435697190	3668	33	21B
0005435697212	3668	34	21C
0005435916126	3668	35	22C
0005435697211	3668	36	22B
0005435697195	3668	37	23A
0005435916125	3668	38	22D
0005435697202	3668	39	23B
0005434950490	16269	1	1A
0005435696926	16269	2	1B
0005435696932	16269	3	1C
0005435696985	16269	4	1D
0005435697060	16269	5	2B
0005435696861	16269	6	2C
0005435696893	16269	7	2D
0005435935025	16269	8	3A
0005435696952	16269	9	3B
0005435916152	16269	10	3C
0005435696970	16269	11	4B
0005434950465	16269	12	4C
0005435697023	16269	13	5B
0005435935024	16269	14	5C
0005435916154	16269	15	5D
0005435696860	16269	16	6B
0005435696947	16269	17	6C
0005435696850	16269	18	6D
0005435696884	16269	19	7A
0005435696968	16269	20	7B
0005435696969	16269	21	7C
0005435696925	16269	22	7D
0005434950478	16269	23	18A
0005435696928	16269	24	18B
0005435696933	16269	25	18C
0005435696885	16269	26	19A
0005435696984	16269	27	20A
0005434950479	16269	28	20C
0005435916153	16269	29	20D
0005435696967	16269	30	21A
0005435696927	16269	31	21B
0005435696966	16269	32	21C
0005435935026	16269	33	21D
0005435696957	16269	34	22A
0005435697033	16269	35	22B
0005435696987	16269	36	22C
0005435697019	16269	37	22D
0005435935027	16269	38	23A
0005434950477	16269	39	23B
0005432609713	3954	1	1C
0005434604880	3954	2	2A
0005432609710	3954	3	2B
0005432609709	3954	4	2C
0005432607547	3954	5	2D
0005432607545	3954	6	4A
0005435904890	3954	7	4B
0005434606814	3954	8	4D
0005433519434	3954	9	5C
0005432607544	3954	10	5D
0005433519433	3954	11	6A
0005433519436	3954	12	6B
0005435853590	3954	13	6C
0005434604881	3954	14	7D
0005435853586	3954	15	18D
0005434606812	3954	16	20B
0005433519435	3954	17	20D
0005432609712	3954	18	20C
0005435842319	3954	19	21D
0005432607546	3954	20	22B
0005432609711	3954	21	22C
0005435853585	3954	22	22D
0005434606813	3954	23	23A
0005433519390	22054	1	1A
0005433519396	22054	2	2A
0005434606773	22054	3	2D
0005433519389	22054	4	3D
0005435853603	22054	5	5A
0005433519392	22054	6	5C
0005434606771	22054	7	18B
0005434606770	22054	8	18C
0005433519393	22054	9	20D
0005435853602	22054	10	22C
0005435853604	22054	11	22D
0005433348930	674	1	2A
0005433348903	674	2	3A
0005433348898	674	3	3B
0005433348918	674	4	5B
0005433348963	15974	1	1A
0005435628681	15974	2	1B
0005433348962	15974	3	2B
0005435628676	15974	4	3B
0005433348961	15974	5	3A
0005433348960	15974	6	4B
0005433348959	15974	7	5A
0005433348958	15974	8	5B
0005435628679	15974	9	6A
0005435628682	15974	10	6B
0005434445233	17245	1	1A
0005434446504	17245	2	1B
0005434445235	17245	3	2A
0005434446506	17245	4	2B
0005433158094	17245	5	4A
0005433158093	17245	6	5A
0005434445234	17245	7	5B
0005434446505	17245	8	6A
0005434446507	17245	9	6B
0005433159302	17642	1	1A
0005433159301	17642	2	3B
0005433159303	17642	3	4B
0005434445216	17642	4	6A
0005435132833	7903	1	1A
0005435132827	7903	2	1C
0005435132829	7903	3	1D
0005435132825	7903	4	2C
0005435132831	7903	5	4C
0005435383072	7903	6	4D
0005435132832	7903	7	6B
0005435132828	7903	8	19B
0005435132830	7903	9	21A
0005435132834	7903	10	21C
0005435132826	7903	11	21D
0005435383125	33118	1	1B
0005435383121	33118	2	2A
0005435132735	33118	3	5B
0005435132736	33118	4	5C
0005435132751	33118	5	5D
0005435132776	33118	6	6D
0005435383123	33118	7	7A
0005435383124	33118	8	7D
0005435132737	33118	9	18B
0005435132775	33118	10	19B
0005435383122	33118	11	19C
0005435132752	33118	12	20C
0005435132765	33118	13	21B
0005435132764	33118	14	21C
0005435132729	33118	15	22C
0005435132734	33118	16	23A
0005435160246	7482	1	1A
0005435390139	7482	2	1D
0005435390147	7482	3	2A
0005435390154	7482	4	2D
0005435160251	7482	5	3D
0005435390141	7482	6	4A
0005435390140	7482	7	4C
0005435390150	7482	8	5B
0005435390146	7482	9	5D
0005435160248	7482	10	6B
0005435160247	7482	11	6C
0005435160244	7482	12	7A
0005435160243	7482	13	7D
0005435390149	7482	14	18C
0005435160240	7482	15	19A
0005435390153	7482	16	19C
0005435160250	7482	17	19D
0005435160241	7482	18	20A
0005435160249	7482	19	20B
0005435160245	7482	20	21B
0005435160242	7482	21	22D
0005435390203	29532	1	1B
0005435390205	29532	2	1D
0005435160172	29532	3	2B
0005435160159	29532	4	2D
0005435160144	29532	5	3D
0005435390202	29532	6	4A
0005435160190	29532	7	5A
0005435390206	29532	8	5B
0005435160158	29532	9	5C
0005435160160	29532	10	6A
0005435160188	29532	11	6C
0005435160189	29532	12	6D
0005435160145	29532	13	7B
0005435160192	29532	14	7D
0005435160143	29532	15	18C
0005435390204	29532	16	19D
0005435160142	29532	17	20C
0005435390207	29532	18	21B
0005435160146	29532	19	22C
0005435160156	29532	20	23A
0005435390208	29532	21	23B
0005435178490	18438	1	1A
0005432394059	18438	2	2A
0005432398136	18438	3	2B
0005432398139	18438	4	3A
0005435178990	18438	5	3B
0005432398146	18438	6	4A
0005432398140	18438	7	4B
0005432394047	18438	8	5A
0005432398151	18438	9	5B
0005435178489	18438	10	6B
0005432398141	18438	11	6A
0005435179389	27166	1	1A
0005432400098	27166	2	2A
0005432398175	27166	3	2B
0005432398174	27166	4	3B
0005432398173	27166	5	4A
0005432400100	27166	6	5A
0005432400099	27166	7	6B
0005434191261	9708	1	2B
0005434191260	9708	2	3A
0005435103892	6532	1	1A
0005435103900	6532	2	1C
0005435103896	6532	3	1D
0005435103894	6532	4	2A
0005434503940	6532	5	2C
0005434503978	6532	6	2D
0005434503959	6532	7	3A
0005434503963	6532	8	3C
0005434503979	6532	9	3F
0005434503957	6532	10	4A
0005434503980	6532	11	4D
0005434503976	6532	12	5C
0005434503941	6532	13	5D
0005435103893	6532	14	5F
0005434503975	6532	15	6A
0005435103891	6532	16	6C
0005435103889	6532	17	6D
0005434503965	6532	18	6E
0005434503972	6532	19	7D
0005434503961	6532	20	7E
0005434503966	6532	21	7F
0005434503974	6532	22	8C
0005434503981	6532	23	8D
0005434503942	6532	24	9D
0005434503954	6532	25	9E
0005434503971	6532	26	9F
0005435103888	6532	27	10A
0005434503956	6532	28	10C
0005435103897	6532	29	10D
0005434503950	6532	30	10E
0005434503967	6532	31	11A
0005434503948	6532	32	11C
0005434503946	6532	33	12A
0005434503947	6532	34	12C
0005435103886	6532	35	13C
0005435103901	6532	36	13D
0005434503977	6532	37	13E
0005434503945	6532	38	14A
0005434503962	6532	39	14F
0005435103898	6532	40	15A
0005435103890	6532	41	15D
0005434503960	6532	42	15E
0005434503964	6532	43	16A
0005435103887	6532	44	16F
0005434503952	6532	45	16E
0005434503949	6532	46	17A
0005434503968	6532	47	17C
0005434503973	6532	48	17F
0005435103895	6532	49	18C
0005434503943	6532	50	18D
0005434503951	6532	51	18E
0005434503944	6532	52	19D
0005435103899	6532	53	19C
0005434503955	6532	54	19E
0005434503970	6532	55	19F
0005434503953	6532	56	20C
0005434503969	6532	57	20D
0005434503958	6532	58	20E
0005434503538	22689	1	1A
0005434503476	22689	2	2F
0005434503640	22689	3	3F
0005434503503	22689	4	4D
0005435103811	22689	5	4F
0005434503611	22689	6	5F
0005434503550	22689	7	6E
0005434503566	22689	8	7C
0005434503583	22689	9	7E
0005434503458	22689	10	8A
0005434503521	22689	11	8D
0005435103806	22689	12	9E
0005435103816	22689	13	9F
0005434503485	22689	14	11A
0005434503549	22689	15	11D
0005434503502	22689	16	11E
0005434503536	22689	17	12D
0005434503659	22689	18	12E
0005434503608	22689	19	12F
0005434503615	22689	20	13A
0005435103817	22689	21	13C
0005434503514	22689	22	13D
0005434503576	22689	23	13F
0005434503610	22689	24	15C
0005434503535	22689	25	15E
0005435103803	22689	26	16D
0005434503643	22689	27	16E
0005434503592	22689	28	17A
0005434503565	22689	29	17E
0005434503513	22689	30	18D
0005434503534	22689	31	19C
0005434503548	22689	32	19D
0005434503520	22689	33	20A
0005435103810	22689	34	20D
0005435652870	1661	1	1C
0005435652875	1661	2	1D
0005433367348	1661	3	1F
0005433367338	1661	4	2A
0005435652843	1661	5	2C
0005435652858	1661	6	2F
0005435652868	1661	7	3C
0005435652857	1661	8	3D
0005433367228	1661	9	3F
0005435652856	1661	10	4A
0005435652865	1661	11	4C
0005433367428	1661	12	4D
0005433367329	1661	13	4E
0005435652853	1661	14	4F
0005433367396	1661	15	5A
0005433367340	1661	16	5D
0005435652872	1661	17	5E
0005435652862	1661	18	5F
0005433367358	1661	19	6A
0005433367468	1661	20	6C
0005435652855	1661	21	6D
0005435652860	1661	22	7A
0005435652840	1661	23	7C
0005435652844	1661	24	7D
0005433367483	1661	25	7E
0005435652842	1661	26	7F
0005433367270	1661	27	8A
0005433367446	1661	28	8C
0005435652859	1661	29	8D
0005433367403	1661	30	8F
0005433367237	1661	31	9A
0005433367349	1661	32	9C
0005435652871	1661	33	9D
0005435652874	1661	34	9E
0005433367345	1661	35	9F
0005433367347	1661	36	10A
0005435652845	1661	37	10D
0005435652869	1661	38	11A
0005435652849	1661	39	11C
0005433367289	1661	40	11D
0005433367400	1661	41	11E
0005433367339	1661	42	11F
0005433367278	1661	43	12A
0005433367359	1661	44	12C
0005435652838	1661	45	12D
0005433367346	1661	46	12F
0005435652841	1661	47	13A
0005433367543	1661	48	13C
0005435652864	1661	49	13D
0005435652876	1661	50	13F
0005435652852	1661	51	14D
0005435652873	1661	52	14E
0005435652861	1661	53	15A
0005435652854	1661	54	15C
0005433367279	1661	55	15D
0005435652867	1661	56	15F
0005433367290	1661	57	16D
0005433367222	1661	58	16E
0005433367263	1661	59	16F
0005435652877	1661	60	17A
0005433367219	1661	61	17C
0005435652847	1661	62	17D
0005433367309	1661	63	17F
0005435652848	1661	64	18A
0005433367405	1661	65	18C
0005435652851	1661	66	18D
0005435652850	1661	67	18E
0005435652846	1661	68	18F
0005433367351	1661	69	19A
0005433367328	1661	70	19C
0005435652839	1661	71	19D
0005433367327	1661	72	19F
0005433367398	1661	73	20A
0005435652863	1661	74	20D
0005435652866	1661	75	20E
0005433367516	1661	76	20F
0005435652318	21678	1	1A
0005435652317	21678	2	1C
0005433367708	21678	3	1D
0005435652304	21678	4	1F
0005433367701	21678	5	2A
0005433367692	21678	6	2C
0005435652342	21678	7	2D
0005435652255	21678	8	3A
0005435652363	21678	9	3C
0005433367690	21678	10	3F
0005433367710	21678	11	4C
0005433367711	21678	12	4D
0005435652433	21678	13	4E
0005435652260	21678	14	4F
0005435652382	21678	15	5A
0005435652383	21678	16	5D
0005433367688	21678	17	6A
0005433367709	21678	18	6C
0005435652446	21678	19	6D
0005435652257	21678	20	6E
0005435652321	21678	21	7A
0005433367695	21678	22	7D
0005433367703	21678	23	7E
0005433367699	21678	24	8A
0005433367715	21678	25	8C
0005433367713	21678	26	8D
0005435652319	21678	27	8E
0005435652427	21678	28	8F
0005433367702	21678	29	9A
0005433367679	21678	30	9C
0005435652392	21678	31	9D
0005433367705	21678	32	10C
0005433367706	21678	33	10D
0005433367685	21678	34	10E
0005435652413	21678	35	10F
0005435652278	21678	36	11A
0005433367683	21678	37	11C
0005435652341	21678	38	11D
0005433367707	21678	39	11E
0005435652418	21678	40	11F
0005435652316	21678	41	12A
0005433367682	21678	42	12C
0005433367680	21678	43	12D
0005433367704	21678	44	12E
0005433367681	21678	45	13A
0005435652393	21678	46	13C
0005435652362	21678	47	13D
0005435652420	21678	48	13E
0005435652387	21678	49	13F
0005435652364	21678	50	14A
0005433367691	21678	51	14C
0005433367697	21678	52	14D
0005433367700	21678	53	15A
0005435652388	21678	54	15C
0005433367714	21678	55	15D
0005433367684	21678	56	15E
0005435652371	21678	57	15F
0005435652368	21678	58	16A
0005433367693	21678	59	16C
0005435652419	21678	60	16D
0005433367698	21678	61	16E
0005435652349	21678	62	16F
0005435652409	21678	63	17C
0005435652361	21678	64	17D
0005435652259	21678	65	17E
0005433367696	21678	66	18C
0005435652410	21678	67	18D
0005435652441	21678	68	18E
0005433367689	21678	69	18F
0005433367712	21678	70	19A
0005433367716	21678	71	19C
0005433367687	21678	72	19D
0005433367686	21678	73	20A
0005435652326	21678	74	19F
0005433367694	21678	75	20C
0005435652264	21678	76	20D
0005435652394	21678	77	20F
0005433985735	4180	1	1A
0005433985702	4180	2	1C
0005433985729	4180	3	1D
0005433985701	4180	4	1F
0005433985722	4180	5	2A
0005433985715	4180	6	2D
0005433985707	4180	7	2F
0005433985698	4180	8	3A
0005433985717	4180	9	3C
0005433985731	4180	10	3D
0005433985718	4180	11	4A
0005433985700	4180	12	4C
0005433985733	4180	13	4F
0005433985716	4180	14	5A
0005433985734	4180	15	5D
0005433985696	4180	16	5F
0005433985704	4180	17	6C
0005433985721	4180	18	6D
0005433985725	4180	19	6F
0005433985737	4180	20	7A
0005433985710	4180	21	7C
0005433985703	4180	22	7D
0005433985690	4180	23	7E
0005433985695	4180	24	7F
0005433985726	4180	25	8A
0005433985724	4180	26	8F
0005433985730	4180	27	9A
0005433985736	4180	28	9C
0005433985708	4180	29	9E
0005433985732	4180	30	10A
0005433985727	4180	31	10C
0005433985738	4180	32	10D
0005435788758	4180	33	10F
0005433985719	4180	34	11C
0005433985728	4180	35	12D
0005433985699	4180	36	13F
0005433985691	4180	37	14A
0005433985712	4180	38	14E
0005433985689	4180	39	14F
0005433985711	4180	40	15D
0005433985692	4180	41	16A
0005433985709	4180	42	16C
0005433985713	4180	43	16D
0005433985705	4180	44	17A
0005433985697	4180	45	17E
0005433985720	4180	46	18A
0005433985693	4180	47	18D
0005435788759	4180	48	18E
0005433985694	4180	49	19C
0005433985706	4180	50	19E
0005433985723	4180	51	19F
0005433985714	4180	52	20D
0005433985158	25678	1	1C
0005433985283	25678	2	2C
0005433985206	25678	3	2D
0005433985315	25678	4	3D
0005433985282	25678	5	4C
0005433985194	25678	6	4D
0005433985265	25678	7	4E
0005433985346	25678	8	4F
0005433985333	25678	9	5A
0005433985354	25678	10	5C
0005433985370	25678	11	5D
0005433985359	25678	12	6D
0005433985149	25678	13	6F
0005433985267	25678	14	7C
0005433985237	25678	15	7F
0005433985435	25678	16	8A
0005433985195	25678	17	8C
0005433985332	25678	18	8D
0005433985156	25678	19	8E
0005433985167	25678	20	9C
0005433985205	25678	21	9D
0005433985400	25678	22	9E
0005433985266	25678	23	9F
0005433985433	25678	24	10A
0005433985299	25678	25	10C
0005433985369	25678	26	10E
0005433985402	25678	27	11A
0005433985178	25678	28	11C
0005433985196	25678	29	11D
0005433985533	25678	30	11E
0005433985401	25678	31	12A
0005433985314	25678	32	12E
0005433985547	25678	33	12F
0005433985349	25678	34	13A
0005433985424	25678	35	13D
0005433985238	25678	36	13E
0005433985184	25678	37	14A
0005435788740	25678	38	14D
0005433985318	25678	39	15A
0005433985281	25678	40	15D
0005433985360	25678	41	15F
0005433985166	25678	42	16A
0005433985240	25678	43	16F
0005433985254	25678	44	17E
0005433985239	25678	45	17F
0005433985225	25678	46	18D
0005433985423	25678	47	18E
0005433985298	25678	48	19D
0005433985334	25678	49	19E
0005433985313	25678	50	19F
0005433985422	25678	51	20A
0005433985255	25678	52	20E
0005433985345	25678	53	20F
0005435720129	24784	1	2B
0005435719563	24784	2	18A
0005435719564	24784	3	19A
0005433168354	21318	1	1A
0005434509031	21318	2	1B
0005434509042	21318	3	1C
0005434509062	21318	4	1D
0005433168348	21318	5	2A
0005434509040	21318	6	2B
0005434509083	21318	7	2C
0005434509033	21318	8	2D
0005434509023	21318	9	3B
0005434509038	21318	10	3C
0005434509049	21318	11	3D
0005434509053	21318	12	4A
0005434509025	21318	13	4B
0005434509017	21318	14	4C
0005434509032	21318	15	4D
0005434509026	21318	16	5A
0005433168350	21318	17	5B
0005434509058	21318	18	5D
0005433168344	21318	19	6A
0005434509052	21318	20	6B
0005433168346	21318	21	6C
0005434509022	21318	22	6D
0005433168351	21318	23	7A
0005434509048	21318	24	7B
0005433168345	21318	25	7C
0005434509059	21318	26	7D
0005434509041	21318	27	18A
0005433168347	21318	28	18B
0005434509075	21318	29	18C
0005434509063	21318	30	18D
0005434509037	21318	31	19A
0005433168355	21318	32	19B
0005434509018	21318	33	19C
0005433168353	21318	34	19D
0005433168352	21318	35	20B
0005434509020	21318	36	20C
0005434509047	21318	37	20D
0005434509046	21318	38	21A
0005433168349	21318	39	21B
0005434509039	21318	40	21C
0005434509045	21318	41	22A
0005433168342	21318	42	22B
0005433168343	21318	43	22C
0005434509021	21318	44	22D
0005434509084	21318	45	23B
0005432657410	17852	1	1C
0005432665250	17852	2	1D
0005434151690	17852	3	2A
0005432655334	17852	4	2D
0005432667427	17852	5	4A
0005432659679	17852	6	4E
0005432659683	17852	7	5C
0005432655383	17852	8	5F
0005432655382	17852	9	6D
0005432869493	17852	10	7A
0005432655343	17852	11	7C
0005432869494	17852	12	7D
0005432655354	17852	13	7E
0005432659677	17852	14	7F
0005432869492	17852	15	8C
0005432655410	17852	16	10A
0005432659678	17852	17	10F
0005432655338	17852	18	11A
0005432660789	17852	19	12E
0005432655339	17852	20	13D
0005432655359	17852	21	13F
0005432657417	17852	22	14D
0005432657404	17852	23	14E
0005432655352	17852	24	14F
0005432869498	17852	25	15C
0005434151691	17852	26	15D
0005432655346	17852	27	15F
0005432655329	17852	28	16A
0005432869496	17852	29	17C
0005432659682	17852	30	17F
0005432667426	17852	31	18A
0005432869497	17852	32	18E
0005432667428	17852	33	18F
0005434151692	17852	34	19A
0005432660790	17852	35	19D
0005432869495	17852	36	20C
0005432655330	17852	37	20D
0005432660788	17852	38	20F
0005432666376	26283	1	1A
0005432869434	26283	2	1C
0005432657431	26283	3	3F
0005434151660	26283	4	4A
0005432655451	26283	5	4C
0005432869429	26283	6	4D
0005432667441	26283	7	5D
0005432655454	26283	8	6A
0005434151663	26283	9	7E
0005432657429	26283	10	8A
0005432655457	26283	11	8C
0005432666375	26283	12	9A
0005432660805	26283	13	9C
0005432657430	26283	14	9E
0005434151658	26283	15	10C
0005432655455	26283	16	10F
0005432659693	26283	17	11A
0005432660804	26283	18	11C
0005432869417	26283	19	12A
0005432665261	26283	20	13A
0005432658578	26283	21	13C
0005432655453	26283	22	13E
0005432659692	26283	23	14A
0005432655458	26283	24	14D
0005432655449	26283	25	14E
0005432655450	26283	26	14F
0005432667440	26283	27	15E
0005434151659	26283	28	17C
0005434151661	26283	29	17E
0005432655459	26283	30	18A
0005432655452	26283	31	19A
0005434151666	26283	32	19D
0005432665262	26283	33	19E
0005432655456	26283	34	20A
0005432328462	3126	1	1A
0005432328495	3126	2	1C
0005432905045	3126	3	2A
0005432905044	3126	4	2F
0005432328469	3126	5	3C
0005432328460	3126	6	3D
0005432328471	3126	7	3F
0005432328497	3126	8	4C
0005433438845	3126	9	4E
0005432328500	3126	10	4F
0005433438841	3126	11	5A
0005432328493	3126	12	5C
0005432328482	3126	13	5E
0005432328464	3126	14	5F
0005432328499	3126	15	6A
0005432287164	3126	16	6C
0005432328473	3126	17	6D
0005433438844	3126	18	6E
0005432328468	3126	19	6F
0005432905042	3126	20	7A
0005432328483	3126	21	7C
0005432328492	3126	22	7D
0005432287167	3126	23	7E
0005432328465	3126	24	8A
0005432328475	3126	25	8C
0005432328484	3126	26	8D
0005433438842	3126	27	9D
0005432328457	3126	28	9E
0005432328491	3126	29	9F
0005432287163	3126	30	10A
0005433438843	3126	31	10C
0005432328490	3126	32	10F
0005432328481	3126	33	11D
0005432328487	3126	34	11E
0005432328477	3126	35	12D
0005432905035	3126	36	12E
0005432905026	3126	37	13A
0005432328463	3126	38	13C
0005432328489	3126	39	13D
0005432328478	3126	40	13E
0005432328480	3126	41	13F
0005433438846	3126	42	14D
0005432287166	3126	43	14E
0005432328454	3126	44	15A
0005432328470	3126	45	15E
0005432287162	3126	46	15F
0005432328498	3126	47	16A
0005433438847	3126	48	16C
0005432328459	3126	49	16D
0005432905034	3126	50	16E
0005432328488	3126	51	16F
0005432328476	3126	52	17A
0005432328461	3126	53	17D
0005432328472	3126	54	17E
0005432328474	3126	55	18C
0005432328486	3126	56	18E
0005432328458	3126	57	18F
0005432328467	3126	58	19A
0005432328479	3126	59	19C
0005432328496	3126	60	19D
0005432328456	3126	61	19E
0005432328485	3126	62	19F
0005432328494	3126	63	20A
0005432328466	3126	64	20D
0005432287165	3126	65	20E
0005432328455	3126	66	20F
0005432327975	31128	1	1A
0005433438815	31128	2	1D
0005432327974	31128	3	2F
0005432328043	31128	4	3A
0005432328016	31128	5	3D
0005432327922	31128	6	3F
0005432327987	31128	7	4A
0005432327964	31128	8	4D
0005432054289	31128	9	5C
0005432905102	31128	10	5D
0005432905101	31128	11	5F
0005432327976	31128	12	6A
0005432054291	31128	13	6D
0005432328041	31128	14	6E
0005432328050	31128	15	7A
0005432327986	31128	16	7C
0005432328123	31128	17	7E
0005433438797	31128	18	8A
0005432327988	31128	19	8C
0005432328207	31128	20	8D
0005432328074	31128	21	8E
0005432327953	31128	22	8F
0005432905098	31128	23	9A
0005432905100	31128	24	9C
0005432328008	31128	25	9D
0005432328046	31128	26	9F
0005432328045	31128	27	10A
0005432327963	31128	28	10D
0005432328132	31128	29	10E
0005432054288	31128	30	10F
0005432328216	31128	31	11C
0005432328122	31128	32	11F
0005432328048	31128	33	12C
0005433438816	31128	34	12F
0005432327927	31128	35	14D
0005432328032	31128	36	15D
0005432327926	31128	37	15F
0005432328007	31128	38	16C
0005433438773	31128	39	16D
0005432328042	31128	40	16E
0005432328044	31128	41	16F
0005433438774	31128	42	17A
0005432905097	31128	43	17D
0005432327961	31128	44	17F
0005432328047	31128	45	18A
0005432054290	31128	46	18C
0005432328049	31128	47	18F
0005432328017	31128	48	19C
0005432905099	31128	49	19E
0005432327960	31128	50	19F
0005432905103	31128	51	20A
0005432328215	31128	52	20C
0005432328036	31128	53	20E
0005432328157	31128	54	20F
0005435296970	6210	1	1C
0005435999177	6210	2	1F
0005432146189	6210	3	2D
0005435487531	6210	4	2C
0005435487470	6210	5	2F
0005435487476	6210	6	3F
0005435999174	6210	7	4A
0005435999181	6210	8	4D
0005435999178	6210	9	4E
0005434309674	6210	10	5B
0005435296962	6210	11	5A
0005435999175	6210	12	5C
0005435296963	6210	13	5E
0005435487547	6210	14	6A
0005434309673	6210	15	6C
0005435487490	6210	16	6F
0005435487570	6210	17	7C
0005434309682	6210	18	7D
0005435487576	6210	19	8C
0005435487528	6210	20	8E
0005434309680	6210	21	8D
0005435487598	6210	22	9A
0005434309681	6210	23	9D
0005435487509	6210	24	10C
0005435487526	6210	25	10B
0005434309672	6210	26	10E
0005435999173	6210	27	10D
0005432146188	6210	28	12A
0005435487548	6210	29	12C
0005434309675	6210	30	12D
0005435487543	6210	31	12F
0005435487498	6210	32	13A
0005435487544	6210	33	13C
0005435487560	6210	34	13B
0005434309670	6210	35	13D
0005435296948	6210	36	13E
0005435296964	6210	37	15A
0005435487597	6210	38	14F
0005435487527	6210	39	15D
0005435487558	6210	40	16A
0005435487492	6210	41	17A
0005434309676	6210	42	17B
0005434309677	6210	43	17C
0005435999179	6210	44	17E
0005432146190	6210	45	18A
0005434309679	6210	46	18B
0005435296971	6210	47	18D
0005435999176	6210	48	19B
0005434309678	6210	49	19C
0005434309671	6210	50	19F
0005435487499	6210	51	20B
0005435487574	6210	52	20D
0005435487584	6210	53	20E
0005435487522	6210	54	20F
0005435999180	6210	55	21B
0005435487491	6210	56	21D
0005435487585	6210	57	22B
0005435487575	6210	58	22D
0005435487620	6210	59	22F
0005435487500	6210	60	23B
0005435487563	6210	61	23E
0005435487571	6210	62	23F
0005435998954	19525	1	2A
0005435998994	19525	2	2C
0005434309583	19525	3	2D
0005435998960	19525	4	2F
0005434309586	19525	5	3C
0005435998985	19525	6	3D
0005435998998	19525	7	3F
0005435998956	19525	8	4A
0005435297023	19525	9	4C
0005435487702	19525	10	4E
0005435998997	19525	11	4F
0005435487712	19525	12	5B
0005435998977	19525	13	5C
0005435487703	19525	14	5F
0005434309582	19525	15	6B
0005435998993	19525	16	6D
0005435487706	19525	17	6F
0005435487713	19525	18	7E
0005435487711	19525	19	8F
0005435487705	19525	20	9D
0005435487716	19525	21	9F
0005435297026	19525	22	10B
0005435487718	19525	23	10D
0005434309588	19525	24	11B
0005435487710	19525	25	12C
0005435998958	19525	26	12B
0005435487708	19525	27	12F
0005434309549	19525	28	13B
0005434309568	19525	29	13F
0005434309587	19525	30	14B
0005434309579	19525	31	14F
0005435297028	19525	32	15D
0005434309578	19525	33	15F
0005435487715	19525	34	15E
0005435487714	19525	35	16C
0005435998955	19525	36	16D
0005435487700	19525	37	16F
0005435487717	19525	38	16E
0005435998963	19525	39	17B
0005435998992	19525	40	17C
0005434309567	19525	41	17D
0005435487709	19525	42	17E
0005435297024	19525	43	18A
0005434309544	19525	44	18D
0005434309534	19525	45	18F
0005435487699	19525	46	18E
0005435998981	19525	47	19B
0005435487701	19525	48	20B
0005435487697	19525	49	20E
0005435998973	19525	50	20D
0005435487704	19525	51	21B
0005435998959	19525	52	21A
0005435487707	19525	53	21C
0005435487698	19525	54	22B
0005435297027	19525	55	22C
0005435297025	19525	56	22D
0005435998964	19525	57	22F
0005435998974	19525	58	23C
0005434309585	19525	59	23E
0005435998986	19525	60	23F
0005435502208	1582	1	1A
0005434565852	1582	2	1C
0005435517821	1582	3	1D
0005433185995	1582	4	1F
0005435502211	1582	5	2C
0005435502205	1582	6	2F
0005434565854	1582	7	2D
0005433186032	1582	8	3C
0005435502200	1582	9	3D
0005432291919	1582	10	4A
0005435508306	1582	11	4C
0005435508302	1582	12	4D
0005435508298	1582	13	4F
0005434565855	1582	14	5A
0005435508297	1582	15	5D
0005435508304	1582	16	5E
0005433186018	1582	17	5F
0005433186033	1582	18	6C
0005435502204	1582	19	6D
0005435502198	1582	20	6F
0005435502218	1582	21	7A
0005435502212	1582	22	7C
0005435517823	1582	23	7D
0005434565844	1582	24	7E
0005434565848	1582	25	7F
0005435517828	1582	26	8A
0005435517834	1582	27	8C
0005435517832	1582	28	8D
0005433186011	1582	29	8F
0005432291920	1582	30	9A
0005435517833	1582	31	9D
0005435508305	1582	32	9E
0005435517830	1582	33	9F
0005435502217	1582	34	10C
0005435508301	1582	35	10D
0005435502215	1582	36	10F
0005435517822	1582	37	11C
0005435517820	1582	38	11D
0005435502213	1582	39	11E
0005435517819	1582	40	12A
0005435517836	1582	41	12C
0005435502216	1582	42	12D
0005435517824	1582	43	12E
0005435508300	1582	44	12F
0005434565846	1582	45	13A
0005435502209	1582	46	13E
0005435517835	1582	47	13F
0005434565850	1582	48	14A
0005434565851	1582	49	14D
0005435502210	1582	50	14F
0005435517829	1582	51	15A
0005435517827	1582	52	15C
0005435517831	1582	53	15D
0005435502197	1582	54	15E
0005435517826	1582	55	15F
0005435502207	1582	56	16C
0005434565847	1582	57	16D
0005435508303	1582	58	16E
0005432291917	1582	59	17A
0005435502203	1582	60	17C
0005432291918	1582	61	17D
0005435517825	1582	62	17F
0005435508299	1582	63	18A
0005435508307	1582	64	18D
0005435502214	1582	65	18E
0005434565853	1582	66	18F
0005435517818	1582	67	19A
0005435508308	1582	68	19D
0005434565849	1582	69	19E
0005435502199	1582	70	19F
0005434565843	1582	71	20A
0005435502201	1582	72	20C
0005434565845	1582	73	20D
0005435502202	1582	74	20E
0005435502206	1582	75	20F
0005434565752	20886	1	1C
0005435528912	20886	2	1D
0005435502091	20886	3	1F
0005433186074	20886	4	2C
0005434565729	20886	5	2D
0005435528943	20886	6	2F
0005435528978	20886	7	3C
0005434565707	20886	8	4C
0005434565749	20886	9	4D
0005435528911	20886	10	4E
0005434565681	20886	11	4F
0005435528948	20886	12	5A
0005435528923	20886	13	5D
0005433186078	20886	14	5F
0005435528903	20886	15	6A
0005435502065	20886	16	6C
0005433186073	20886	17	6D
0005434565725	20886	18	6E
0005435501954	20886	19	7A
0005435501975	20886	20	7C
0005435528979	20886	21	7D
0005435528924	20886	22	7E
0005435528963	20886	23	7F
0005435501933	20886	24	8C
0005435501990	20886	25	8D
0005435528982	20886	26	8E
0005434565748	20886	27	9D
0005435528937	20886	28	9E
0005435501959	20886	29	9F
0005435528881	20886	30	10C
0005435529012	20886	31	10F
0005435502014	20886	32	11E
0005435528988	20886	33	11F
0005433186077	20886	34	12C
0005435545616	20886	35	12D
0005433186081	20886	36	12F
0005435528990	20886	37	13A
0005433186079	20886	38	13C
0005435501953	20886	39	13D
0005435528936	20886	40	13E
0005434565677	20886	41	13F
0005434565680	20886	42	14A
0005435501932	20886	43	14C
0005435502015	20886	44	14D
0005435528962	20886	45	14E
0005435528987	20886	46	14F
0005433186075	20886	47	15A
0005435528949	20886	48	15C
0005435502090	20886	49	15F
0005433186080	20886	50	16A
0005435502013	20886	51	16C
0005435528961	20886	52	16D
0005435528932	20886	53	16F
0005435502089	20886	54	17C
0005435529011	20886	55	17D
0005433186076	20886	56	17E
0005435501958	20886	57	18D
0005434565724	20886	58	18E
0005435501986	20886	59	19A
0005434565722	20886	60	19D
0005435502016	20886	61	20C
0005435501966	20886	62	20D
0005435502004	20886	63	20E
0005435931558	3896	1	2D
0005435153711	3896	2	5D
0005435153712	3896	3	6C
0005435931543	3896	4	7B
0005435931544	3896	5	18B
0005435931557	3896	6	18C
0005435153707	3896	7	21A
0005435153709	3896	8	22A
0005435153708	3896	9	22C
0005435153710	3896	10	22D
0005435153655	21860	1	4A
0005435153645	21860	2	6C
0005435153660	21860	3	6D
0005435153656	21860	4	18C
0005435153654	21860	5	19C
0005435931584	21860	6	19D
0005435931583	21860	7	20C
0005435931585	21860	8	20D
0005435153644	21860	9	21A
0005435153657	21860	10	21D
0005432628768	7188	1	1A
0005432628769	7188	2	1C
0005435225446	7188	3	2A
0005435225449	7188	4	2D
0005432628770	7188	5	3A
0005432628774	7188	6	3C
0005432628781	7188	7	4C
0005432628767	7188	8	5C
0005435225458	7188	9	5D
0005432628776	7188	10	6A
0005432628771	7188	11	6B
0005432628779	7188	12	7C
0005432628772	7188	13	18D
0005432628778	7188	14	19B
0005432628780	7188	15	20A
0005432628775	7188	16	20D
0005432628773	7188	17	21B
0005435225463	7188	18	22A
0005432628777	7188	19	22D
0005432628676	28140	1	1A
0005435225548	28140	2	1B
0005432628657	28140	3	1D
0005435225547	28140	4	2A
0005432628714	28140	5	2B
0005435225543	28140	6	2C
0005432628652	28140	7	3A
0005432628662	28140	8	3D
0005432628595	28140	9	4C
0005432628692	28140	10	4D
0005432628647	28140	11	5B
0005435225545	28140	12	5C
0005435225544	28140	13	5D
0005432628664	28140	14	6A
0005435225549	28140	15	6B
0005432628668	28140	16	6C
0005432628606	28140	17	7A
0005435225546	28140	18	7D
0005432628648	28140	19	18B
0005432628638	28140	20	19A
0005432628653	28140	21	19C
0005432628675	28140	22	20A
0005435225542	28140	23	21B
0005435225541	28140	24	22A
0005432628656	28140	25	23A
0005432628663	28140	26	23B
0005434267900	8739	1	5B
0005435960033	8739	2	5D
0005434267894	8739	3	6A
0005434267913	8739	4	6C
0005435960032	8739	5	7A
0005434267887	8739	6	7D
0005435960031	8739	7	19C
0005435959993	15217	1	4B
0005435960003	15217	2	4D
0005435960011	15217	3	5B
0005435959990	15217	4	5C
0005435960016	15217	5	7A
0005435960025	15217	6	7B
0005435959991	15217	7	18D
0005434267930	15217	8	20A
0005434267931	15217	9	21A
0005435960005	15217	10	21B
0005435959992	15217	11	21D
0005434267932	15217	12	22B
0005435960000	15217	13	23B
0005432692879	1188	1	1C
0005432692890	1188	2	1F
0005432692898	1188	3	1D
0005432692875	1188	4	2C
0005432873198	1188	5	2A
0005432692883	1188	6	2F
0005432873216	1188	7	2D
0005432677549	1188	8	3A
0005432692889	1188	9	3C
0005432692902	1188	10	5A
0005432692891	1188	11	4D
0005432675051	1188	12	5F
0005432692896	1188	13	6C
0005432692884	1188	14	6E
0005432873180	1188	15	6F
0005432677550	1188	16	7C
0005432675059	1188	17	7B
0005432692876	1188	18	7E
0005432692888	1188	19	7D
0005432675055	1188	20	8B
0005432692881	1188	21	8A
0005432692897	1188	22	8D
0005432677551	1188	23	8F
0005432675057	1188	24	9B
0005432692900	1188	25	9F
0005432692882	1188	26	10B
0005432692893	1188	27	10D
0005432873197	1188	28	11A
0005432675058	1188	29	10F
0005432692905	1188	30	11C
0005432692901	1188	31	11E
0005432675062	1188	32	12B
0005432675060	1188	33	12A
0005432675061	1188	34	12D
0005432692887	1188	35	12C
0005432675053	1188	36	12E
0005432692903	1188	37	13B
0005432692885	1188	38	13D
0005432692895	1188	39	14C
0005432692886	1188	40	15A
0005432675050	1188	41	15C
0005432692899	1188	42	16A
0005432692894	1188	43	16C
0005432692878	1188	44	16D
0005432692904	1188	45	17B
0005432692880	1188	46	17C
0005432675052	1188	47	17F
0005432873188	1188	48	18B
0005432675049	1188	49	18A
0005432692877	1188	50	18C
0005432675054	1188	51	18D
0005432692892	1188	52	19A
0005432677548	1188	53	19B
0005432692874	1188	54	20B
0005432675063	1188	55	20A
0005432675056	1188	56	20F
0005432873253	17500	1	1C
0005432677518	17500	2	1D
0005432674964	17500	3	2D
0005432692719	17500	4	3A
0005432692602	17500	5	4A
0005432692667	17500	6	4F
0005432692678	17500	7	5C
0005432873258	17500	8	5A
0005432674911	17500	9	5F
0005432692676	17500	10	6C
0005432692704	17500	11	6F
0005432692690	17500	12	6E
0005432692540	17500	13	7B
0005432692619	17500	14	8A
0005432692668	17500	15	8C
0005432674887	17500	16	8D
0005432692706	17500	17	8F
0005432674943	17500	18	8E
0005432692599	17500	19	9A
0005432677523	17500	20	9E
0005432692711	17500	21	10E
0005432692679	17500	22	11A
0005432692673	17500	23	11F
0005432873256	17500	24	11E
0005432692549	17500	25	12D
0005432692548	17500	26	12C
0005432692735	17500	27	13E
0005432692588	17500	28	13F
0005432692677	17500	29	14A
0005432692720	17500	30	14D
0005432674912	17500	31	14F
0005432674910	17500	32	14E
0005432674909	17500	33	15A
0005432873259	17500	34	16F
0005432692550	17500	35	17D
0005432692614	17500	36	17E
0005432692736	17500	37	18D
0005432692587	17500	38	18B
0005432873254	17500	39	18F
0005432873255	17500	40	19B
0005432692600	17500	41	19D
0005432692689	17500	42	20C
0005432873257	17500	43	20F
0005432692803	17500	44	20E
0005432692672	17500	45	21C
0005432674869	17500	46	21F
0005433156612	1111	1	1A
0005433156635	1111	2	1B
0005434435101	1111	3	1C
0005433156637	1111	4	2B
0005433156649	1111	5	2D
0005433156611	1111	6	3C
0005433156657	1111	7	4A
0005434435104	1111	8	4B
0005434435111	1111	9	5A
0005434435105	1111	10	5D
0005434435108	1111	11	6B
0005433156636	1111	12	6C
0005434435109	1111	13	6D
0005434435099	1111	14	7B
0005433156654	1111	15	18A
0005434435110	1111	16	18B
0005433156650	1111	17	19A
0005433156647	1111	18	19C
0005434435107	1111	19	19D
0005433156646	1111	20	20B
0005434435112	1111	21	20C
0005434435113	1111	22	20D
0005433156648	1111	23	21B
0005433156638	1111	24	21C
0005434435106	1111	25	21D
0005434435102	1111	26	22C
0005434435100	1111	27	22D
0005434435103	1111	28	23A
0005433156705	17286	1	1A
0005433156702	17286	2	1C
0005433156709	17286	3	2A
0005434435031	17286	4	2C
0005434434914	17286	5	3D
0005434434963	17286	6	5A
0005434434973	17286	7	5B
0005434434976	17286	8	6B
0005433156707	17286	9	6D
0005434435029	17286	10	7A
0005433156704	17286	11	7B
0005434434982	17286	12	7C
0005434435030	17286	13	18C
0005433156710	17286	14	18D
0005433156703	17286	15	19A
0005434434985	17286	16	19B
0005434434945	17286	17	19D
0005433156708	17286	18	20C
0005434435003	17286	19	20D
0005434434986	17286	20	21A
0005434435002	17286	21	21B
0005433156706	17286	22	21C
0005434434972	17286	23	21D
0005434435032	17286	24	22B
0005434435004	17286	25	22C
0005435086799	4071	1	1D
0005435086796	4071	2	2B
0005435928074	4071	3	4A
0005435928072	4071	4	4D
0005435086800	4071	5	5B
0005435086795	4071	6	6B
0005435928073	4071	7	6D
0005435086797	4071	8	18D
0005435086794	4071	9	20C
0005435086798	4071	10	22B
0005435928082	4071	11	22C
0005435086750	24427	1	1A
0005435928117	24427	2	2B
0005435086739	24427	3	4A
0005435086717	24427	4	5B
0005435928118	24427	5	5D
0005435928119	24427	6	7A
0005435928120	24427	7	20B
0005435086745	24427	8	21D
0005434625913	4847	1	1C
0005434625912	4847	2	2F
0005433194824	4847	3	3D
0005434625917	4847	4	4C
0005434625918	4847	5	6C
0005435907458	4847	6	9C
0005434625915	4847	7	11C
0005433194823	4847	8	12A
0005434625916	4847	9	13C
0005434625911	4847	10	13E
0005435907439	4847	11	13F
0005434625914	4847	12	15E
0005433194822	4847	13	15F
0005434625919	4847	14	18D
0005435907459	4847	15	19C
0005434625875	32904	1	1F
0005434625845	32904	2	2C
0005435907483	32904	3	2D
0005434625863	32904	4	3D
0005435907482	32904	5	5F
0005435907480	32904	6	6C
0005434625862	32904	7	11A
0005434625855	32904	8	14D
0005434625818	32904	9	15D
0005434625840	32904	10	15E
0005435907484	32904	11	16A
0005434625861	32904	12	17A
0005434625812	32904	13	18E
0005434625810	32904	14	20C
0005435907481	32904	15	20F
0005435784821	13775	1	1A
0005435784840	13775	2	1B
0005435784863	13775	3	1C
0005435784815	13775	4	1D
0005435937358	13775	5	2A
0005435784800	13775	6	2B
0005435937365	13775	7	2C
0005435784855	13775	8	2D
0005435937360	13775	9	3A
0005432195682	13775	10	3C
0005435784822	13775	11	3B
0005435784911	13775	12	3D
0005435787326	13775	13	4A
0005435937366	13775	14	4B
0005435787325	13775	15	4C
0005435784860	13775	16	4D
0005435784886	13775	17	5A
0005435784805	13775	18	5B
0005435784889	13775	19	5D
0005435784820	13775	20	6A
0005435784732	13775	21	6B
0005435937361	13775	22	6C
0005435784771	13775	23	6D
0005435784918	13775	24	7A
0005435784901	13775	25	7B
0005435784788	13775	26	7C
0005435784912	13775	27	7D
0005435784837	13775	28	18A
0005435784818	13775	29	18B
0005435937364	13775	30	18C
0005435784731	13775	31	18D
0005435784949	13775	32	19A
0005435784787	13775	33	19B
0005435784868	13775	34	19D
0005435784917	13775	35	20A
0005432195683	13775	36	20B
0005435937363	13775	37	20C
0005435787324	13775	38	20D
0005435784794	13775	39	21A
0005435784746	13775	40	21B
0005435784772	13775	41	21C
0005435784888	13775	42	21D
0005435937359	13775	43	22C
0005435784773	13775	44	22D
0005435937362	13775	45	23A
0005435785121	27441	1	1B
0005435937308	27441	2	1C
0005435785129	27441	3	1D
0005435785140	27441	4	2A
0005435785119	27441	5	2B
0005435937322	27441	6	2C
0005432190604	27441	7	2D
0005435785150	27441	8	3A
0005435785122	27441	9	3B
0005435937319	27441	10	3C
0005435785127	27441	11	3D
0005435785148	27441	12	4A
0005435785146	27441	13	4B
0005435785117	27441	14	4C
0005435785151	27441	15	4D
0005435937307	27441	16	5A
0005435785145	27441	17	5B
0005435785139	27441	18	5C
0005432190605	27441	19	5D
0005435785116	27441	20	6A
0005435785118	27441	21	6B
0005435785137	27441	22	6C
0005435785149	27441	23	6D
0005435785143	27441	24	7A
0005432190603	27441	25	7C
0005435785123	27441	26	7D
0005435785134	27441	27	18A
0005435785142	27441	28	18B
0005435785126	27441	29	18C
0005435785138	27441	30	18D
0005435785131	27441	31	19A
0005435785141	27441	32	19B
0005432190606	27441	33	19C
0005435937323	27441	34	19D
0005435785152	27441	35	20B
0005435785147	27441	36	20C
0005435785133	27441	37	20D
0005435785120	27441	38	21A
0005435785132	27441	39	21B
0005435937324	27441	40	21C
0005435785128	27441	41	21D
0005435785136	27441	42	22A
0005435785130	27441	43	22B
0005435785125	27441	44	22C
0005435785124	27441	45	22D
0005435785144	27441	46	23A
0005435785135	27441	47	23B
0005434407056	20269	1	1C
0005434407109	20269	2	1D
0005434406871	20269	3	1F
0005434406910	20269	4	2A
0005435311019	20269	5	2C
0005434406735	20269	6	2D
0005434406711	20269	7	2F
0005434406875	20269	8	3A
0005434406876	20269	9	3C
0005434406828	20269	10	3D
0005434407143	20269	11	3F
0005434407165	20269	12	4A
0005432058363	20269	13	4C
0005434407144	20269	14	4D
0005434407064	20269	15	4E
0005434406832	20269	16	5A
0005434406886	20269	17	5C
0005435311015	20269	18	5D
0005432058362	20269	19	5F
0005434406652	20269	20	6A
0005434406983	20269	21	6C
0005435311022	20269	22	6D
0005434406741	20269	23	6E
0005434407019	20269	24	6F
0005434406916	20269	25	7A
0005434406772	20269	26	7C
0005435311021	20269	27	7D
0005434406736	20269	28	7E
0005434406643	20269	29	8A
0005432058360	20269	30	7F
0005434406896	20269	31	8C
0005434406793	20269	32	8D
0005434406769	20269	33	8E
0005434406734	20269	34	8F
0005434406763	20269	35	9A
0005434406775	20269	36	9C
0005434406992	20269	37	9D
0005435311024	20269	38	9E
0005434406923	20269	39	9F
0005434406765	20269	40	10A
0005434406872	20269	41	10D
0005434407014	20269	42	10E
0005434406771	20269	43	10F
0005435311018	20269	44	11A
0005432058361	20269	45	11C
0005434406719	20269	46	11D
0005434406909	20269	47	11E
0005434406873	20269	48	11F
0005434406924	20269	49	12A
0005434406712	20269	50	12C
0005435311020	20269	51	12D
0005435311017	20269	52	12E
0005434406887	20269	53	12F
0005434406653	20269	54	13A
0005434406867	20269	55	13C
0005434406847	20269	56	13D
0005434406801	20269	57	13F
0005435311023	20269	58	14A
0005434407110	20269	59	14C
0005434406829	20269	60	14D
0005434407065	20269	61	14E
0005434406929	20269	62	14F
0005434406826	20269	63	15A
0005434406897	20269	64	15C
0005435311025	20269	65	15D
0005434406740	20269	66	15E
0005434406900	20269	67	15F
0005434406692	20269	68	16A
0005434406835	20269	69	16C
0005434406838	20269	70	16D
0005434407005	20269	71	16F
0005434406965	20269	72	17A
0005434406846	20269	73	17C
0005434406898	20269	74	17D
0005434406878	20269	75	17E
0005434406950	20269	76	17F
0005434406934	20269	77	18A
0005434406644	20269	78	18C
0005434406879	20269	79	18D
0005435311016	20269	80	18E
0005434407004	20269	81	19A
0005434406710	20269	82	19C
0005434406911	20269	83	19D
0005434406888	20269	84	19E
0005434406945	20269	85	20A
0005434407013	20269	86	20C
0005434407145	20269	87	20D
0005434406830	20269	88	20E
0005434406786	20269	89	20F
0005434407421	27004	1	1A
0005434407463	27004	2	1C
0005434407441	27004	3	1D
0005434407442	27004	4	2A
0005434407445	27004	5	2D
0005434407447	27004	6	2F
0005432153903	27004	7	3A
0005434407446	27004	8	3C
0005434407444	27004	9	3D
0005432153901	27004	10	3F
0005435310849	27004	11	4A
0005434407468	27004	12	4D
0005434407415	27004	13	4E
0005434407455	27004	14	4F
0005434407423	27004	15	5A
0005434407420	27004	16	5C
0005435310884	27004	17	5D
0005434407432	27004	18	5E
0005432153904	27004	19	5F
0005434407451	27004	20	6A
0005434407475	27004	21	6D
0005434407413	27004	22	6E
0005434407427	27004	23	6F
0005434407466	27004	24	7A
0005434407422	27004	25	7C
0005434407460	27004	26	7D
0005434407454	27004	27	7E
0005434407448	27004	28	7F
0005434407434	27004	29	8A
0005434407461	27004	30	8C
0005432153905	27004	31	8D
0005434407471	27004	32	9A
0005435310837	27004	33	9C
0005434407428	27004	34	9D
0005434407419	27004	35	9E
0005434407431	27004	36	9F
0005434407470	27004	37	10A
0005434407414	27004	38	10C
0005435310848	27004	39	10D
0005434407433	27004	40	11A
0005434407459	27004	41	11C
0005434407437	27004	42	11D
0005434407456	27004	43	11E
0005434407462	27004	44	11F
0005434407443	27004	45	12A
0005434407418	27004	46	12C
0005434407430	27004	47	12D
0005435310863	27004	48	12E
0005435310885	27004	49	12F
0005432153900	27004	50	13A
0005434407452	27004	51	13D
0005434407436	27004	52	13E
0005434407473	27004	53	13F
0005435310847	27004	54	14A
0005434407458	27004	55	14C
0005434407439	27004	56	14E
0005435310894	27004	57	14F
0005434407464	27004	58	15A
0005434407429	27004	59	15C
0005434407426	27004	60	15D
0005434407450	27004	61	15E
0005434407465	27004	62	15F
0005435310889	27004	63	16A
0005434407472	27004	64	16C
0005435310869	27004	65	16D
0005434407469	27004	66	16E
0005434407474	27004	67	16F
0005434407457	27004	68	17C
0005434407438	27004	69	17D
0005434407435	27004	70	17E
0005434407416	27004	71	17F
0005434407425	27004	72	18A
0005434407424	27004	73	18C
0005432153899	27004	74	18D
0005434407417	27004	75	18E
0005434407449	27004	76	18F
0005434407440	27004	77	19A
0005434407476	27004	78	19C
0005434407467	27004	79	19D
0005435310862	27004	80	20A
0005434407453	27004	81	20D
0005432153902	27004	82	20E
0005434319317	5695	1	1C
0005433123611	5695	2	1D
0005433123645	5695	3	1F
0005432109689	5695	4	2C
0005434319313	5695	5	3A
0005433123618	5695	6	3D
0005434319310	5695	7	4C
0005434319321	5695	8	4F
0005434319311	5695	9	5A
0005432109690	5695	10	5D
0005433123650	5695	11	5F
0005433123684	5695	12	6A
0005434319324	5695	13	6D
0005434319328	5695	14	7A
0005433123621	5695	15	7D
0005434319319	5695	16	7E
0005433123615	5695	17	8A
0005434311209	5695	18	8C
0005434319323	5695	19	8D
0005434319325	5695	20	8F
0005434319327	5695	21	9E
0005434319320	5695	22	9F
0005434319316	5695	23	10C
0005433123619	5695	24	11A
0005434319312	5695	25	11C
0005434319318	5695	26	11F
0005433123658	5695	27	12A
0005432109688	5695	28	13D
0005433123620	5695	29	14C
0005433123635	5695	30	14E
0005433123685	5695	31	15F
0005434319322	5695	32	16A
0005434319326	5695	33	16D
0005433123634	5695	34	17D
0005433123660	5695	35	18E
0005434319315	5695	36	19A
0005433123603	5695	37	20C
0005434319314	5695	38	20D
0005433123831	15650	1	1D
0005433123838	15650	2	1F
0005433123840	15650	3	2A
0005434319231	15650	4	2F
0005434312294	15650	5	4A
0005434319167	15650	6	4F
0005434319155	15650	7	5D
0005433123835	15650	8	5E
0005434319164	15650	9	5F
0005434312290	15650	10	7A
0005434319170	15650	11	7E
0005433123834	15650	12	7F
0005433123842	15650	13	8A
0005434319156	15650	14	8E
0005433123832	15650	15	8F
0005433123833	15650	16	11D
0005434319166	15650	17	11E
0005434312284	15650	18	11F
0005434319189	15650	19	12A
0005433123837	15650	20	13C
0005433123827	15650	21	15E
0005434312289	15650	22	15F
0005433123828	15650	23	16A
0005433123829	15650	24	16C
0005433123830	15650	25	16D
0005433123839	15650	26	16F
0005434311186	15650	27	17A
0005434311187	15650	28	17C
0005433123836	15650	29	17E
0005434319210	15650	30	18D
0005433123843	15650	31	19C
0005434319171	15650	32	19E
0005433123841	15650	33	20D
0005434484315	8977	1	1B
0005434484316	8977	2	2D
0005434189105	8977	3	3C
0005434189110	8977	4	5A
0005434484319	8977	5	5B
0005434189102	8977	6	5C
0005434484318	8977	7	5D
0005434484312	8977	8	7A
0005434484313	8977	9	18B
0005434484314	8977	10	21A
0005434189087	8977	11	21B
0005434484317	8977	12	22C
0005434189092	8977	13	22D
0005434484264	16648	1	1D
0005434189151	16648	2	2C
0005434189150	16648	3	3D
0005434484276	16648	4	4A
0005434484282	16648	5	4D
0005434189148	16648	6	5B
0005434189147	16648	7	6B
0005434484261	16648	8	7D
0005434189149	16648	9	20C
0005434484240	16648	10	21B
0005434484241	16648	11	21C
0005434484236	16648	12	23A
0005434189152	16648	13	23B
0005433123838	7670	1	1C
0005433722105	7670	2	2A
0005433123837	7670	3	3A
0005433123834	7670	4	4D
0005433722124	7670	5	4E
0005433722110	7670	6	5C
0005433123839	7670	7	7C
0005433123835	7670	8	7D
0005433722130	7670	9	8C
0005433123833	7670	10	9E
0005433123836	7670	11	9F
0005433123828	7670	12	10F
0005433123831	7670	13	11E
0005433722111	7670	14	13D
0005433722117	7670	15	14A
0005433123843	7670	16	15C
0005433123832	7670	17	15E
0005433722112	7670	18	15F
0005433722120	7670	19	16D
0005433123829	7670	20	16F
0005433123830	7670	21	17D
0005433123827	7670	22	17E
0005433123841	7670	23	18C
0005433123840	7670	24	18D
0005433123842	7670	25	19E
0005433722107	7670	26	20D
0005433722109	7670	27	20E
0005432692924	7666	1	1A
0005432692912	7666	2	1C
0005433449872	7666	3	1D
0005432071558	7666	4	2A
0005433449852	7666	5	1F
0005433449868	7666	6	2C
0005432692923	7666	7	2D
0005432720763	7666	8	3A
0005432692907	7666	9	3C
0005432692933	7666	10	3D
0005432692909	7666	11	3F
0005433449870	7666	12	4A
0005432720769	7666	13	4C
0005432720778	7666	14	4D
0005432720758	7666	15	4F
0005432720762	7666	16	5A
0005432720780	7666	17	5C
0005433449853	7666	18	5D
0005432720760	7666	19	5E
0005432720771	7666	20	5F
0005433449865	7666	21	6A
0005433449861	7666	22	6C
0005433449859	7666	23	6D
0005432692922	7666	24	6E
0005432692932	7666	25	6F
0005432692920	7666	26	7A
0005432692913	7666	27	7C
0005432720761	7666	28	7E
0005433449864	7666	29	7F
0005432720766	7666	30	8A
0005433449860	7666	31	8C
0005432720764	7666	32	8D
0005432692925	7666	33	8F
0005433449866	7666	34	9C
0005433449862	7666	35	9F
0005433449857	7666	36	10A
0005432720784	7666	37	10C
0005433449863	7666	38	10D
0005432720782	7666	39	10E
0005432692935	7666	40	10F
0005432720775	7666	41	11D
0005432692906	7666	42	11E
0005432692911	7666	43	11F
0005432692931	7666	44	12A
0005433449858	7666	45	12D
0005432692926	7666	46	12E
0005432692936	7666	47	12F
0005432720759	7666	48	13A
0005432720767	7666	49	13C
0005432720770	7666	50	13D
0005432720774	7666	51	13E
0005433449855	7666	52	13F
0005432692916	7666	53	14A
0005433449871	7666	54	14C
0005432692918	7666	55	14D
0005432692914	7666	56	14E
0005432692928	7666	57	14F
0005432692927	7666	58	15C
0005432720781	7666	59	15D
0005432720783	7666	60	15E
0005432720773	7666	61	15F
0005432692919	7666	62	16A
0005433449851	7666	63	16D
0005432692915	7666	64	16E
0005432720779	7666	65	16F
0005432720765	7666	66	17A
0005433449854	7666	67	17C
0005432720776	7666	68	17D
0005433449856	7666	69	17E
0005432692910	7666	70	17F
0005432692930	7666	71	18A
0005432720777	7666	72	18C
0005432071559	7666	73	18D
0005432720772	7666	74	18E
0005432692908	7666	75	19A
0005433449867	7666	76	19C
0005432692921	7666	77	19D
0005432692934	7666	78	19E
0005432692917	7666	79	20A
0005432720768	7666	80	20C
0005433449869	7666	81	20D
0005432692929	7666	82	20E
0005432692676	30349	1	1A
0005433449656	30349	2	1C
0005432692672	30349	3	1D
0005433449745	30349	4	2A
0005432692599	30349	5	3D
0005432692540	30349	6	4A
0005432692600	30349	7	4C
0005432692679	30349	8	4F
0005432692706	30349	9	5C
0005433449608	30349	10	5E
0005433449625	30349	11	6A
0005433449734	30349	12	6C
0005433449677	30349	13	6D
0005432692735	30349	14	6E
0005432692711	30349	15	6F
0005433449809	30349	16	7A
0005432692548	30349	17	7D
0005433449654	30349	18	7E
0005432692668	30349	19	8A
0005432692690	30349	20	8C
0005432692677	30349	21	8D
0005433449624	30349	22	9E
0005432692587	30349	23	10A
0005432692720	30349	24	10E
0005433449658	30349	25	10F
0005432692588	30349	26	11D
0005433449671	30349	27	12A
0005433449746	30349	28	12C
0005432692619	30349	29	12E
0005433449731	30349	30	12F
0005432692549	30349	31	13E
0005433449631	30349	32	14A
0005432692678	30349	33	14F
0005433449640	30349	34	15A
0005433449674	30349	35	15C
0005432692667	30349	36	15F
0005432692689	30349	37	16A
0005433449655	30349	38	16D
0005432692614	30349	39	16E
0005433449641	30349	40	16F
0005432692704	30349	41	17A
0005433449732	30349	42	17C
0005433449626	30349	43	17E
0005433449638	30349	44	18A
0005432692803	30349	45	18E
0005433449630	30349	46	18F
0005433449675	30349	47	19A
0005432692550	30349	48	19C
0005433449676	30349	49	19D
0005432692602	30349	50	19E
0005433449680	30349	51	19F
0005432692719	30349	52	20A
0005432692736	30349	53	20C
0005433449735	30349	54	20D
0005432692673	30349	55	20F
0005433123603	30348	1	1A
0005432720598	30348	2	1F
0005432720488	30348	3	2A
0005433123685	30348	4	2C
0005433123645	30348	5	3F
0005432720444	30348	6	4C
0005433123618	30348	7	4D
0005433123615	30348	8	4E
0005433722191	30348	9	4F
0005432720487	30348	10	5A
0005433722196	30348	11	5C
0005433722194	30348	12	5D
0005433123684	30348	13	5E
0005432720445	30348	14	5F
0005432720625	30348	15	6A
0005432720522	30348	16	6D
0005432720509	30348	17	6E
0005433123621	30348	18	7A
0005432720510	30348	19	7C
0005433722193	30348	20	7E
0005432720639	30348	21	8A
0005432720554	30348	22	8C
0005432720513	30348	23	8D
0005432720647	30348	24	8F
0005432720556	30348	25	9C
0005433123660	30348	26	9E
0005432720634	30348	27	9F
0005432720443	30348	28	10A
0005432720479	30348	29	10C
0005433123658	30348	30	10D
0005433722189	30348	31	11A
0005433722187	30348	32	11C
0005432720570	30348	33	11D
0005433722195	30348	34	12A
0005433123611	30348	35	12C
0005432720565	30348	36	12D
0005432720503	30348	37	12E
0005432720564	30348	38	12F
0005432720590	30348	39	13A
0005432720696	30348	40	13E
0005432720515	30348	41	13F
0005432720648	30348	42	14C
0005432720633	30348	43	14D
0005432720502	30348	44	14F
0005432720698	30348	45	15A
0005433722192	30348	46	15D
0005433123619	30348	47	15E
0005432720697	30348	48	15F
0005432720521	30348	49	16A
0005432720566	30348	50	16D
0005432720472	30348	51	16E
0005433722188	30348	52	16F
0005432720542	30348	53	17C
0005432720520	30348	54	17F
0005432720577	30348	55	18A
0005432720557	30348	56	18C
0005433123650	30348	57	18D
0005433722190	30348	58	18E
0005432720498	30348	59	18F
0005432720610	30348	60	19A
0005433123635	30348	61	19C
0005432720578	30348	62	19D
0005433123634	30348	63	19E
0005432720555	30348	64	20A
0005432720543	30348	65	20C
0005433123620	30348	66	20E
0005433192861	1367	1	1A
0005434586489	1367	2	1C
0005432270989	1367	3	1D
0005434514954	1367	4	1F
0005433524981	1367	5	2A
0005434513568	1367	6	2C
0005433192925	1367	7	2D
0005434586472	1367	8	3A
0005433524986	1367	9	3C
0005434586487	1367	10	3D
0005433192829	1367	11	3F
0005434586490	1367	12	4A
0005434586494	1367	13	4C
0005433192892	1367	14	4D
0005434586491	1367	15	4E
0005434586495	1367	16	4F
0005433192856	1367	17	5A
0005434513565	1367	18	5C
0005432927915	1367	19	5E
0005433192855	1367	20	5F
0005434586473	1367	21	6A
0005433192891	1367	22	6C
0005433524983	1367	23	6D
0005433524987	1367	24	6E
0005433524982	1367	25	6F
0005432968808	1367	26	7A
0005433524989	1367	27	7D
0005434586478	1367	28	7F
0005433192851	1367	29	8C
0005434586477	1367	30	8E
0005433192816	1367	31	8F
0005432927950	1367	32	9C
0005432270991	1367	33	9D
0005434586499	1367	34	9E
0005434586481	1367	35	9F
0005433192926	1367	36	10A
0005433192942	1367	37	10C
0005432927914	1367	38	10D
0005434586476	1367	39	10E
0005434586486	1367	40	10F
0005432968809	1367	41	11A
0005434586479	1367	42	11C
0005433192866	1367	43	11E
0005432927917	1367	44	11F
0005434514956	1367	45	12A
0005434586498	1367	46	12C
0005433724782	1367	47	12D
0005434586497	1367	48	12E
0005432927916	1367	49	12F
0005432927909	1367	50	13A
0005434586484	1367	51	13C
0005432927924	1367	52	13D
0005432927923	1367	53	13E
0005433524980	1367	54	13F
0005433192924	1367	55	14A
0005433724785	1367	56	14C
0005433524985	1367	57	14D
0005434513567	1367	58	14E
0005434586496	1367	59	14F
0005433524984	1367	60	15A
0005433192879	1367	61	15C
0005434586474	1367	62	15D
0005432927922	1367	63	15E
0005434586480	1367	64	15F
0005432968805	1367	65	16C
0005432270990	1367	66	16D
0005434586492	1367	67	16E
0005433192817	1367	68	16F
0005432968804	1367	69	17A
0005434513566	1367	70	17C
0005433524988	1367	71	17D
0005434514955	1367	72	17F
0005433724786	1367	73	18A
0005434586493	1367	74	18C
0005432927888	1367	75	18D
0005434586485	1367	76	18E
0005434586488	1367	77	18F
0005434586483	1367	78	19A
0005433192828	1367	79	19C
0005433724784	1367	80	19D
0005433724783	1367	81	19E
0005433524990	1367	82	20A
0005434586475	1367	83	20C
0005434586482	1367	84	20E
0005433524979	1367	85	20F
0005433524890	18505	1	1A
0005433192974	18505	2	2A
0005434586210	18505	3	2F
0005433192976	18505	4	3D
0005433524847	18505	5	3F
0005433724740	18505	6	4A
0005434586253	18505	7	4C
0005432968827	18505	8	5A
0005434586322	18505	9	5C
0005433524918	18505	10	5D
0005433192985	18505	11	5E
0005433192984	18505	12	5F
0005433524891	18505	13	6A
0005433724736	18505	14	6C
0005432927951	18505	15	6F
0005433524917	18505	16	7C
0005433724724	18505	17	7D
0005434586290	18505	18	8A
0005433192980	18505	19	8C
0005433192978	18505	20	8E
0005434586158	18505	21	9C
0005432927949	18505	22	9D
0005434586292	18505	23	9E
0005434586197	18505	24	10C
0005433192981	18505	25	10D
0005434586356	18505	26	11A
0005434586219	18505	27	11E
0005433524851	18505	28	11F
0005432927952	18505	29	12A
0005433192975	18505	30	12C
0005433524903	18505	31	12D
0005433192982	18505	32	12E
0005433192973	18505	33	12F
0005434586257	18505	34	13D
0005433524877	18505	35	13E
0005434586313	18505	36	14C
0005434586256	18505	37	14E
0005434586269	18505	38	15D
0005434586263	18505	39	15E
0005433192979	18505	40	15F
0005432968828	18505	41	16A
0005434586319	18505	42	16C
0005433192977	18505	43	16D
0005433192983	18505	44	17A
0005432927950	18505	45	17C
0005432968829	18505	46	17F
0005434586323	18505	47	18A
0005433524866	18505	48	18C
0005434586211	18505	49	18D
0005433524876	18505	50	18E
0005434586328	18505	51	18F
0005433192986	18505	52	19A
0005432927953	18505	53	19C
0005433524848	18505	54	19F
0005434586289	18505	55	20A
0005434586232	18505	56	20C
0005434586360	18505	57	20D
0005434586252	18505	58	20E
0005434586291	18505	59	20F
0005434343997	11469	1	1A
0005434343999	11469	2	1B
0005434344018	11469	3	1C
0005434344010	11469	4	1D
0005434344013	11469	5	2B
0005434343991	11469	6	2D
0005434344016	11469	7	2C
0005434142590	11469	8	3B
0005434343989	11469	9	3C
0005434343993	11469	10	3D
0005434142592	11469	11	4A
0005434344001	11469	12	4B
0005434343994	11469	13	4C
0005434343992	11469	14	4D
0005435302128	11469	15	5A
0005434344004	11469	16	5B
0005434344021	11469	17	5C
0005434344008	11469	18	5D
0005434343998	11469	19	6B
0005434344017	11469	20	6C
0005434343995	11469	21	6D
0005434344000	11469	22	7A
0005434344005	11469	23	7B
0005434344003	11469	24	7C
0005435304996	11469	25	7D
0005434344007	11469	26	18A
0005435302130	11469	27	18B
0005434343996	11469	28	18C
0005434344020	11469	29	18D
0005434344022	11469	30	19B
0005434344002	11469	31	19C
0005434344023	11469	32	19D
0005434344006	11469	33	20A
0005435302129	11469	34	20B
0005434344012	11469	35	20C
0005434142591	11469	36	21A
0005434344015	11469	37	21B
0005434344014	11469	38	21C
0005434344009	11469	39	21D
0005434142589	11469	40	22A
0005434344011	11469	41	22B
0005434343988	11469	42	22C
0005434344019	11469	43	22D
0005435304989	11469	44	23A
0005434343990	11469	45	23B
0005434343917	29765	1	1A
0005434343655	29765	2	1B
0005434343635	29765	3	1C
0005434343716	29765	4	1D
0005434343695	29765	5	2A
0005434343613	29765	6	2B
0005434343760	29765	7	2D
0005434343595	29765	8	2C
0005435304138	29765	9	3A
0005434343636	29765	10	3B
0005434343685	29765	11	3D
0005434343637	29765	12	4A
0005434343639	29765	13	4B
0005434343585	29765	14	4C
0005434343690	29765	15	4D
0005434343627	29765	16	5A
0005434343715	29765	17	5B
0005434343612	29765	18	5D
0005434343761	29765	19	6A
0005434343675	29765	20	6B
0005434343625	29765	21	6D
0005434343674	29765	22	7A
0005434343708	29765	23	7B
0005434343701	29765	24	7C
0005434343889	29765	25	7D
0005434343638	29765	26	18A
0005435304137	29765	27	18B
0005434343634	29765	28	18C
0005434343773	29765	29	18D
0005434142548	29765	30	19A
0005434343720	29765	31	19B
0005434343626	29765	32	19C
0005434343617	29765	33	19D
0005434343741	29765	34	20A
0005434343614	29765	35	20B
0005434343620	29765	36	20C
0005434343831	29765	37	20D
0005434343644	29765	38	21A
0005434343721	29765	39	21B
0005434343772	29765	40	21C
0005434343633	29765	41	21D
0005434343586	29765	42	22A
0005434343888	29765	43	22B
0005434343643	29765	44	22C
0005434343596	29765	45	22D
0005434343656	29765	46	23A
0005434343757	29765	47	23B
0005433415459	1255	1	1C
0005433415471	1255	2	2A
0005435824505	1255	3	1F
0005433415516	1255	4	2F
0005433415450	1255	5	3D
0005435824490	1255	6	3C
0005432284543	1255	7	3F
0005435824492	1255	8	4D
0005435824491	1255	9	5F
0005435824503	1255	10	6B
0005435824498	1255	11	6C
0005433415485	1255	12	6D
0005433415467	1255	13	6F
0005435824494	1255	14	7E
0005435824502	1255	15	8F
0005435824495	1255	16	9F
0005433415468	1255	17	10C
0005435824485	1255	18	10B
0005435824508	1255	19	10D
0005433415507	1255	20	11B
0005435824496	1255	21	11C
0005435824500	1255	22	12C
0005433415472	1255	23	12D
0005432284544	1255	24	13C
0005435824506	1255	25	14E
0005435824504	1255	26	15A
0005433415421	1255	27	16B
0005432284545	1255	28	16D
0005435824497	1255	29	16C
0005435824487	1255	30	16F
0005435824493	1255	31	16E
0005433415446	1255	32	17A
0005433415455	1255	33	17F
0005435824488	1255	34	17E
0005435824486	1255	35	18A
0005435824483	1255	36	18B
0005435824482	1255	37	18E
0005433415413	1255	38	18D
0005433415449	1255	39	19A
0005433415447	1255	40	18F
0005433415422	1255	41	19B
0005435824484	1255	42	19D
0005433415466	1255	43	19E
0005435824489	1255	44	20A
0005435824507	1255	45	20D
0005433415508	1255	46	21B
0005435824499	1255	47	21A
0005433415448	1255	48	21D
0005435824501	1255	49	21C
0005433415477	1255	50	21F
0005435824287	17973	1	1C
0005435824321	17973	2	1A
0005435824232	17973	3	2D
0005433415576	17973	4	3A
0005433415580	17973	5	3F
0005435824249	17973	6	7C
0005435824306	17973	7	7F
0005435824245	17973	8	8B
0005433415588	17973	9	8D
0005435824326	17973	10	8C
0005435824188	17973	11	8E
0005435824250	17973	12	9C
0005435824303	17973	13	9B
0005435824221	17973	14	9D
0005433415575	17973	15	10A
0005433415587	17973	16	10E
0005435824310	17973	17	11D
0005433415583	17973	18	11E
0005435824175	17973	19	12B
0005433415589	17973	20	13C
0005433415577	17973	21	13E
0005435824327	17973	22	14A
0005435824154	17973	23	14C
0005433415586	17973	24	14B
0005433415584	17973	25	15D
0005433415585	17973	26	15C
0005435824361	17973	27	16A
0005435824282	17973	28	16B
0005435824380	17973	29	16D
0005435824212	17973	30	18D
0005433415582	17973	31	19C
0005433415581	17973	32	19B
0005435824302	17973	33	19E
0005435824153	17973	34	20D
0005433415578	17973	35	20C
0005435824241	17973	36	21A
0005433415590	17973	37	20F
0005433415579	17973	38	21D
0005435824189	17973	39	21C
0005435824360	17973	40	21E
0005434461631	12566	1	1B
0005434460494	12566	2	1C
0005434460493	12566	3	2B
0005434461632	12566	4	2C
0005434461633	12566	5	3A
0005434460486	12566	6	3C
0005434460492	12566	7	3D
0005434460491	12566	8	4D
0005434461628	12566	9	6D
0005434460487	12566	10	7A
0005434460488	12566	11	18C
0005434460490	12566	12	19B
0005434460485	12566	13	19D
0005434461629	12566	14	21A
0005434460484	12566	15	22A
0005434460489	12566	16	22B
0005434461634	12566	17	22D
0005434461630	12566	18	23A
0005432783508	5667	1	1A
0005432783540	5667	2	1C
0005432783499	5667	3	1D
0005432783505	5667	4	1F
0005435242426	5667	5	2A
0005432783536	5667	6	2C
0005432783546	5667	7	2D
0005432783523	5667	8	3A
0005432783515	5667	9	3C
0005432783550	5667	10	3D
0005432783513	5667	11	3F
0005435242527	5667	12	4A
0005432783500	5667	13	4C
0005432783541	5667	14	4D
0005435242487	5667	15	4E
0005432783528	5667	16	5A
0005435476639	5667	17	5C
0005432783532	5667	18	5D
0005432783514	5667	19	5E
0005432783521	5667	20	5F
0005435242469	5667	21	6A
0005432783526	5667	22	6C
0005435242494	5667	23	6D
0005432783542	5667	24	6E
0005435242421	5667	25	6F
0005432143971	5667	26	7A
0005435242444	5667	27	7C
0005432783504	5667	28	7D
0005435242434	5667	29	7E
0005435242455	5667	30	7F
0005432783529	5667	31	8A
0005435242501	5667	32	8E
0005432783553	5667	33	8F
0005435242610	5667	34	9A
0005432783538	5667	35	9C
0005432783537	5667	36	9D
0005432783512	5667	37	9E
0005432783535	5667	38	9F
0005432783506	5667	39	10A
0005435242609	5667	40	10C
0005432783533	5667	41	10D
0005432783502	5667	42	10E
0005435242607	5667	43	11A
0005432783503	5667	44	11D
0005432143972	5667	45	11E
0005435242485	5667	46	11F
0005432783551	5667	47	12A
0005432783507	5667	48	12D
0005435242484	5667	49	12C
0005435242496	5667	50	12E
0005432143970	5667	51	12F
0005435242495	5667	52	13A
0005432783511	5667	53	13C
0005435242486	5667	54	13D
0005432783520	5667	55	13E
0005435242420	5667	56	13F
0005435242579	5667	57	14A
0005432783510	5667	58	14C
0005432783527	5667	59	14D
0005435242445	5667	60	14E
0005432783509	5667	61	14F
0005432783519	5667	62	15A
0005432783547	5667	63	15C
0005432783517	5667	64	15D
0005435476650	5667	65	15F
0005435242419	5667	66	16A
0005432783552	5667	67	16C
0005432783522	5667	68	16D
0005435476651	5667	69	16F
0005432783534	5667	70	17A
0005432783543	5667	71	17C
0005435476638	5667	72	17D
0005432783545	5667	73	17E
0005432783530	5667	74	17F
0005432783539	5667	75	18A
0005432783544	5667	76	18C
0005432783549	5667	77	18D
0005435242521	5667	78	18E
0005432783525	5667	79	18F
0005435242438	5667	80	19A
0005435242608	5667	81	19C
0005432783531	5667	82	19E
0005432783548	5667	83	19F
0005432783518	5667	84	20A
0005432783501	5667	85	20C
0005435242500	5667	86	20D
0005432783516	5667	87	20E
0005432783524	5667	88	20F
0005432782969	15350	1	1A
0005435476726	15350	2	1C
0005432783106	15350	3	1D
0005432783094	15350	4	1F
0005435476731	15350	5	2A
0005432782957	15350	6	2D
0005432783087	15350	7	2F
0005432783093	15350	8	3A
0005432783247	15350	9	3C
0005432782896	15350	10	3D
0005435476730	15350	11	3F
0005432783047	15350	12	4A
0005432783134	15350	13	4D
0005435242698	15350	14	4E
0005435476727	15350	15	5A
0005435476724	15350	16	5D
0005432783013	15350	17	5E
0005432782937	15350	18	5F
0005435242705	15350	19	6A
0005435242700	15350	20	6C
0005435242697	15350	21	6D
0005435242708	15350	22	6E
0005432782852	15350	23	6F
0005435242695	15350	24	7A
0005435242706	15350	25	7D
0005435476722	15350	26	7E
0005435242702	15350	27	7F
0005435476721	15350	28	8D
0005435242696	15350	29	8E
0005435242717	15350	30	8F
0005435242712	15350	31	9A
0005432783016	15350	32	9C
0005432783201	15350	33	9D
0005435242704	15350	34	9E
0005435242707	15350	35	9F
0005432782941	15350	36	10A
0005435242692	15350	37	10C
0005432783023	15350	38	10D
0005432783051	15350	39	10E
0005435242714	15350	40	11C
0005432783098	15350	41	11D
0005435242718	15350	42	11E
0005435242713	15350	43	11F
0005435242716	15350	44	12A
0005435476720	15350	45	12E
0005432782970	15350	46	12F
0005432782950	15350	47	13A
0005435242694	15350	48	13C
0005435242710	15350	49	13D
0005435242699	15350	50	13E
0005432783108	15350	51	13F
0005432782954	15350	52	14A
0005432782897	15350	53	14C
0005432782951	15350	54	14D
0005432783046	15350	55	14E
0005435242701	15350	56	14F
0005435242693	15350	57	15A
0005435242719	15350	58	15C
0005432783052	15350	59	15D
0005432783077	15350	60	15E
0005432783068	15350	61	15F
0005435242703	15350	62	16F
0005432783041	15350	63	17C
0005435476728	15350	64	17D
0005435242711	15350	65	17E
0005432782917	15350	66	17F
0005432783069	15350	67	18A
0005432782959	15350	68	18C
0005432782940	15350	69	18E
0005432782949	15350	70	18F
0005435242709	15350	71	19A
0005432782842	15350	72	19C
0005435476729	15350	73	19D
0005432783025	15350	74	19E
0005435242715	15350	75	20A
0005435476723	15350	76	20C
0005435476725	15350	77	20D
0005432783164	15350	78	20E
0005432783099	15350	79	20F
0005435850783	4368	1	1A
0005435850792	4368	2	1D
0005434462780	4368	3	2B
0005432848242	4368	4	2C
0005432848244	4368	5	3A
0005432848234	4368	6	3D
0005432848246	4368	7	4B
0005432848235	4368	8	4C
0005435850768	4368	9	5A
0005432848239	4368	10	5B
0005432848236	4368	11	5C
0005434463919	4368	12	6B
0005435850805	4368	13	6D
0005435850828	4368	14	7B
0005432848247	4368	15	18A
0005432848233	4368	16	18B
0005435850810	4368	17	18C
0005435850829	4368	18	18D
0005432848237	4368	19	19D
0005432848245	4368	20	20A
0005435850821	4368	21	20B
0005435850791	4368	22	20C
0005432848240	4368	23	20D
0005435850798	4368	24	21B
0005435850794	4368	25	21C
0005432848243	4368	26	21D
0005434463918	4368	27	22A
0005432848241	4368	28	22B
0005432848238	4368	29	22C
0005435850817	4368	30	23B
0005434461620	28834	1	1A
0005435850868	28834	2	1D
0005432848079	28834	3	2A
0005432848100	28834	4	2B
0005435850867	28834	5	2C
0005432848113	28834	6	2D
0005435850860	28834	7	3A
0005435850866	28834	8	3B
0005435850864	28834	9	3C
0005432848126	28834	10	4B
0005434463900	28834	11	4C
0005434461612	28834	12	5A
0005432848142	28834	13	5D
0005434463898	28834	14	6A
0005435850862	28834	15	6B
0005435850863	28834	16	6D
0005434461613	28834	17	7A
0005435850869	28834	18	7B
0005434461618	28834	19	7C
0005432848138	28834	20	7D
0005434463896	28834	21	18A
0005432848127	28834	22	18B
0005432848130	28834	23	19A
0005435850865	28834	24	20C
0005434461619	28834	25	20D
0005435850861	28834	26	21C
0005434463897	28834	27	21D
0005432848150	28834	28	22C
0005432848148	28834	29	23A
0005432848149	28834	30	23B
0005433496834	6299	1	1C
0005434443622	6299	2	1F
0005434925654	6299	3	2C
0005434925676	6299	4	2D
0005433496830	6299	5	2F
0005433496820	6299	6	3A
0005434925653	6299	7	3C
0005434925671	6299	8	3D
0005434925673	6299	9	3F
0005433496821	6299	10	4A
0005433496812	6299	11	4D
0005433496803	6299	12	4E
0005434443628	6299	13	4F
0005434925664	6299	14	5A
0005434443631	6299	15	5C
0005433496824	6299	16	5D
0005434925657	6299	17	5E
0005434925652	6299	18	5F
0005434443624	6299	19	6A
0005434925660	6299	20	6C
0005434443637	6299	21	6D
0005434925674	6299	22	6E
0005433496831	6299	23	6F
0005434925667	6299	24	7A
0005434925656	6299	25	7C
0005433496826	6299	26	7E
0005434443629	6299	27	7F
0005434925675	6299	28	8A
0005433496810	6299	29	8D
0005432075214	6299	30	8E
0005433496817	6299	31	8F
0005433496815	6299	32	9A
0005433496819	6299	33	9C
0005434443626	6299	34	9D
0005434443625	6299	35	9E
0005434925661	6299	36	9F
0005433496813	6299	37	10A
0005433496829	6299	38	10C
0005434443635	6299	39	10E
0005434443634	6299	40	10F
0005433496809	6299	41	11A
0005434925668	6299	42	11C
0005434443630	6299	43	11D
0005433496811	6299	44	11E
0005434443636	6299	45	12A
0005434925670	6299	46	12C
0005434443627	6299	47	12D
0005432075213	6299	48	12E
0005434925659	6299	49	12F
0005434925658	6299	50	13A
0005433496832	6299	51	13C
0005433496807	6299	52	13D
0005433496833	6299	53	13E
0005432075212	6299	54	13F
0005434925663	6299	55	14D
0005433496814	6299	56	14E
0005432075211	6299	57	14F
0005434443632	6299	58	15A
0005433496828	6299	59	15D
0005433496806	6299	60	15E
0005433496823	6299	61	15F
0005433496805	6299	62	16C
0005434925666	6299	63	16D
0005434925672	6299	64	16E
0005433496825	6299	65	16F
0005434925655	6299	66	17A
0005433496804	6299	67	17C
0005434443623	6299	68	17D
0005434925677	6299	69	17E
0005433496816	6299	70	17F
0005433496818	6299	71	18A
0005434443633	6299	72	18C
0005434925665	6299	73	19A
0005434925662	6299	74	19D
0005433496827	6299	75	19E
0005433496822	6299	76	20A
0005434925669	6299	77	20C
0005433496808	6299	78	20E
0005434925385	20317	1	1A
0005434925275	20317	2	1C
0005434443530	20317	3	1D
0005433496738	20317	4	2C
0005433496667	20317	5	2D
0005434925378	20317	6	2F
0005434925274	20317	7	3A
0005434925349	20317	8	3C
0005434925362	20317	9	3D
0005434925347	20317	10	3F
0005434925338	20317	11	4A
0005434925285	20317	12	4C
0005434925382	20317	13	4E
0005434443529	20317	14	4D
0005433496605	20317	15	5C
0005434925390	20317	16	5D
0005433496546	20317	17	5E
0005434443473	20317	18	5F
0005434443456	20317	19	6A
0005433496600	20317	20	6C
0005434925426	20317	21	6D
0005434925283	20317	22	6E
0005434925379	20317	23	6F
0005433496673	20317	24	7C
0005434925332	20317	25	7E
0005434925389	20317	26	7F
0005433496588	20317	27	8A
0005434925491	20317	28	8C
0005433496666	20317	29	8D
0005433496545	20317	30	8E
0005434925439	20317	31	8F
0005434925465	20317	32	9A
0005433496604	20317	33	9C
0005433496564	20317	34	9E
0005434443538	20317	35	10A
0005433496603	20317	36	10C
0005434443532	20317	37	10D
0005433496584	20317	38	10E
0005434443454	20317	39	11A
0005434925427	20317	40	11C
0005433496594	20317	41	11D
0005434925522	20317	42	11E
0005434443503	20317	43	11F
0005434925325	20317	44	12C
0005434925377	20317	45	12F
0005434443464	20317	46	13A
0005433496485	20317	47	13D
0005433496599	20317	48	13E
0005434443471	20317	49	14C
0005434925348	20317	50	14D
0005434925337	20317	51	14E
0005434925339	20317	52	14F
0005433496606	20317	53	15A
0005434443439	20317	54	15C
0005433496657	20317	55	15D
0005434443531	20317	56	16A
0005434925503	20317	57	16D
0005434925286	20317	58	16E
0005434925416	20317	59	16F
0005434925489	20317	60	17A
0005433496505	20317	61	17C
0005433496523	20317	62	17D
0005434925380	20317	63	17E
0005433496674	20317	64	17F
0005434443445	20317	65	18A
0005434925490	20317	66	18C
0005434925296	20317	67	18D
0005434925326	20317	68	18E
0005434443489	20317	69	19C
0005433496537	20317	70	19D
0005434925280	20317	71	20A
0005434925470	20317	72	20C
0005434443490	20317	73	20F
0005432782928	12188	1	1A
0005435242723	12188	2	1C
0005432782986	12188	3	1D
0005435242730	12188	4	1F
0005435242738	12188	5	2A
0005435242733	12188	6	2C
0005432783265	12188	7	2D
0005432783320	12188	8	2F
0005432783116	12188	9	3A
0005435242725	12188	10	3C
0005432783097	12188	11	3D
0005432782926	12188	12	3F
0005432782981	12188	13	4A
0005435242734	12188	14	4C
0005432783035	12188	15	4D
0005432782925	12188	16	4E
0005435242739	12188	17	4F
0005432783184	12188	18	5A
0005432783119	12188	19	5C
0005432783172	12188	20	5D
0005432783125	12188	21	5E
0005432783066	12188	22	5F
0005432782910	12188	23	6A
0005435242728	12188	24	6C
0005432782994	12188	25	6D
0005432783264	12188	26	6E
0005432783177	12188	27	6F
0005432783055	12188	28	7A
0005435242732	12188	29	7C
0005432783270	12188	30	7D
0005432782977	12188	31	7E
0005432782913	12188	32	7F
0005432782903	12188	33	8A
0005432782963	12188	34	8C
0005432783004	12188	35	8D
0005432783048	12188	36	8E
0005432782912	12188	37	8F
0005432783196	12188	38	9A
0005435242737	12188	39	9C
0005432783183	12188	40	9D
0005435242724	12188	41	9E
0005432783105	12188	42	9F
0005432783319	12188	43	10A
0005432782927	12188	44	10C
0005435242722	12188	45	10D
0005435242720	12188	46	10E
0005432783074	12188	47	10F
0005435242729	12188	48	11A
0005432782998	12188	49	11D
0005432783256	12188	50	11C
0005432782858	12188	51	11E
0005432783036	12188	52	11F
0005432783197	12188	53	12A
0005432782914	12188	54	12C
0005432783082	12188	55	12D
0005432782975	12188	56	12E
0005432783065	12188	57	12F
0005432783064	12188	58	13A
0005432782945	12188	59	13C
0005432782915	12188	60	13D
0005432782920	12188	61	13E
0005435242736	12188	62	13F
0005432782861	12188	63	14A
0005432782859	12188	64	14C
0005432783096	12188	65	14D
0005435242731	12188	66	14E
0005432782965	12188	67	14F
0005432782974	12188	68	15A
0005432782862	12188	69	15C
0005435242740	12188	70	15D
0005432783129	12188	71	15E
0005432782966	12188	72	15F
0005435242727	12188	73	16A
0005432783218	12188	74	16C
0005435242735	12188	75	16D
0005432782997	12188	76	16E
0005432783083	12188	77	16F
0005432782973	12188	78	17A
0005432783003	12188	79	17C
0005432782972	12188	80	17D
0005432783084	12188	81	17E
0005432783061	12188	82	17F
0005435242726	12188	83	18A
0005432783081	12188	84	18C
0005432783171	12188	85	18D
0005432783095	12188	86	18E
0005432783037	12188	87	18F
0005432783139	12188	88	19A
0005432783104	12188	89	19C
0005432783219	12188	90	19D
0005432783038	12188	91	19E
0005435242741	12188	92	19F
0005435242721	12188	93	20A
0005432783187	12188	94	20C
0005432782982	12188	95	20D
0005432783195	12188	96	20E
0005432782976	12188	97	20F
0005432783479	15415	1	1A
0005432783463	15415	2	1C
0005432783491	15415	3	1D
0005435242406	15415	4	1F
0005435242395	15415	5	2A
0005432783455	15415	6	2C
0005432783480	15415	7	2F
0005432783476	15415	8	3A
0005435242601	15415	9	3D
0005435242471	15415	10	3F
0005432783460	15415	11	4A
0005435242507	15415	12	4C
0005432783464	15415	13	4D
0005432783468	15415	14	4E
0005435242490	15415	15	4F
0005432783495	15415	16	5A
0005435242472	15415	17	5D
0005432783492	15415	18	5E
0005435242470	15415	19	5F
0005432783494	15415	20	6A
0005432783489	15415	21	6D
0005432783498	15415	22	6E
0005432783477	15415	23	7A
0005435242539	15415	24	7D
0005432783459	15415	25	7E
0005435242499	15415	26	7F
0005432783481	15415	27	8A
0005432783444	15415	28	8D
0005432783487	15415	29	8F
0005432783484	15415	30	9C
0005432783450	15415	31	9D
0005432783470	15415	32	9E
0005432783445	15415	33	10A
0005432783469	15415	34	10C
0005432783466	15415	35	10E
0005432783458	15415	36	10F
0005432783472	15415	37	11C
0005432783496	15415	38	11E
0005432783448	15415	39	11F
0005432783471	15415	40	12D
0005435242489	15415	41	12E
0005435242399	15415	42	12F
0005432783457	15415	43	13A
0005432783456	15415	44	13D
0005435242477	15415	45	13E
0005435242459	15415	46	14A
0005432783467	15415	47	14C
0005432783473	15415	48	14D
0005432783454	15415	49	14E
0005432783485	15415	50	14F
0005432783490	15415	51	15A
0005432783453	15415	52	15C
0005432783465	15415	53	15D
0005432783483	15415	54	15E
0005432783447	15415	55	15F
0005432783475	15415	56	16C
0005432783474	15415	57	16D
0005432783446	15415	58	16E
0005435242404	15415	59	16F
0005432783452	15415	60	17A
0005432783493	15415	61	17C
0005432783451	15415	62	17D
0005435242464	15415	63	17E
0005432783461	15415	64	17F
0005432783478	15415	65	18A
0005435242407	15415	66	18C
0005432783486	15415	67	18E
0005432783449	15415	68	18F
0005432783497	15415	69	19C
0005432783482	15415	70	19E
0005435242506	15415	71	19F
0005435242443	15415	72	20A
0005432783488	15415	73	20C
0005435242411	15415	74	20D
0005435242530	15415	75	20E
0005432783462	15415	76	20F
0005434876999	10088	1	1C
0005435913924	10088	2	1F
0005434758857	10088	3	1D
0005434877024	10088	4	2A
0005434876635	10088	5	2D
0005434876775	10088	6	3C
0005434877445	10088	7	3A
0005434876842	10088	8	2F
0005434876598	10088	9	3D
0005434877064	10088	10	4A
0005434876865	10088	11	3F
0005434876755	10088	12	5A
0005434877229	10088	13	4F
0005434877083	10088	14	4D
0005434876779	10088	15	5C
0005434758858	10088	16	5D
0005434876903	10088	17	6B
0005434877086	10088	18	6D
0005434877043	10088	19	6C
0005434910099	10088	20	7A
0005434876928	10088	21	6F
0005434877232	10088	22	7C
0005434876631	10088	23	7B
0005434877025	10088	24	7E
0005434877002	10088	25	7F
0005434876811	10088	26	8B
0005434877089	10088	27	8A
0005434910100	10088	28	8D
0005434876756	10088	29	8E
0005434876713	10088	30	9B
0005434876773	10088	31	9A
0005434876980	10088	32	9D
0005434876948	10088	33	9C
0005434877313	10088	34	9E
0005434910101	10088	35	10A
0005434877363	10088	36	10C
0005434876998	10088	37	10B
0005434877163	10088	38	10E
0005434877326	10088	39	10D
0005434876714	10088	40	10F
0005434876947	10088	41	11B
0005434876798	10088	42	11A
0005435913926	10088	43	11D
0005434876589	10088	44	11C
0005434876953	10088	45	11F
0005434876850	10088	46	11E
0005434877165	10088	47	12A
0005434876780	10088	48	12D
0005434877048	10088	49	12C
0005434877171	10088	50	12B
0005434877085	10088	51	13A
0005434876691	10088	52	12F
0005434877399	10088	53	13C
0005434876954	10088	54	13B
0005434877170	10088	55	13E
0005434877010	10088	56	13F
0005434876807	10088	57	14C
0005435913927	10088	58	14B
0005434876889	10088	59	14A
0005434876774	10088	60	14E
0005434876758	10088	61	14D
0005434876904	10088	62	14F
0005435913925	10088	63	15B
0005434877162	10088	64	15D
0005434877230	10088	65	15F
0005434877386	10088	66	15E
0005434877172	10088	67	16A
0005434877530	10088	68	16C
0005434877050	10088	69	16B
0005434876740	10088	70	16E
0005434877049	10088	71	16D
0005434876926	10088	72	16F
0005434876757	10088	73	17B
0005434877045	10088	74	17C
0005434876812	10088	75	17F
0005434876907	10088	76	17E
0005434876957	10088	77	18B
0005434876944	10088	78	18A
0005434876663	10088	79	18E
0005434876997	10088	80	19A
0005434876678	10088	81	18F
0005434876736	10088	82	19C
0005434876886	10088	83	19B
0005434876984	10088	84	19D
0005434877026	10088	85	20A
0005434876927	10088	86	19F
0005434877387	10088	87	19E
0005434877128	10088	88	20B
0005434876590	10088	89	20D
0005434877044	10088	90	20C
0005434876591	10088	91	20F
0005434877159	10088	92	20E
0005434877195	10088	93	21A
0005434877166	10088	94	21D
0005434877084	10088	95	21C
0005434877208	10088	96	21E
0005434877766	14642	1	1A
0005434877793	14642	2	1F
0005434877800	14642	3	1D
0005434877730	14642	4	1C
0005434877787	14642	5	2A
0005434877721	14642	6	2D
0005434877802	14642	7	2C
0005434877808	14642	8	3A
0005434877768	14642	9	2F
0005434877788	14642	10	3D
0005434877724	14642	11	4A
0005434877791	14642	12	3F
0005434877754	14642	13	4C
0005434877806	14642	14	4F
0005434877739	14642	15	4D
0005434877719	14642	16	5C
0005434877815	14642	17	5A
0005434877805	14642	18	5F
0005434877769	14642	19	6B
0005434877772	14642	20	6A
0005434877785	14642	21	6F
0005434877731	14642	22	6E
0005434877771	14642	23	7A
0005434877737	14642	24	7C
0005434877732	14642	25	7B
0005434910072	14642	26	7E
0005434758880	14642	27	7D
0005434877735	14642	28	8A
0005434877796	14642	29	7F
0005434877783	14642	30	8C
0005434877763	14642	31	8B
0005434877814	14642	32	8E
0005434877717	14642	33	8D
0005434877797	14642	34	8F
0005434877747	14642	35	9A
0005434877767	14642	36	9D
0005434877733	14642	37	9C
0005434877773	14642	38	9B
0005434877741	14642	39	9E
0005434877812	14642	40	10B
0005434877734	14642	41	10A
0005434877725	14642	42	9F
0005434877809	14642	43	10C
0005434877726	14642	44	10E
0005434877738	14642	45	11A
0005434877795	14642	46	10F
0005434758881	14642	47	11B
0005434877810	14642	48	11D
0005434877777	14642	49	11C
0005434877789	14642	50	11F
0005434877720	14642	51	12A
0005434877765	14642	52	12D
0005434877807	14642	53	12F
0005434877786	14642	54	12E
0005434877718	14642	55	13B
0005434877722	14642	56	13A
0005434877750	14642	57	13C
0005434877804	14642	58	13D
0005434877755	14642	59	14A
0005434877742	14642	60	13F
0005434877748	14642	61	14B
0005434877746	14642	62	14D
0005434877743	14642	63	14C
0005434877727	14642	64	14F
0005434877775	14642	65	14E
0005434877798	14642	66	15B
0005434877752	14642	67	15A
0005434877778	14642	68	15D
0005434877759	14642	69	15C
0005434877749	14642	70	15E
0005434877761	14642	71	16A
0005434877790	14642	72	15F
0005434877736	14642	73	16C
0005434877813	14642	74	16B
0005434877776	14642	75	16E
0005435913852	14642	76	16D
0005434877745	14642	77	16F
0005434877744	14642	78	17B
0005434877792	14642	79	17A
0005434877803	14642	80	17D
0005434758882	14642	81	17C
0005434877756	14642	82	17E
0005434877811	14642	83	18B
0005434877794	14642	84	17F
0005434877779	14642	85	18C
0005434877740	14642	86	18E
0005434877799	14642	87	18D
0005434877729	14642	88	19A
0005434877762	14642	89	18F
0005434877760	14642	90	19B
0005434877757	14642	91	19E
0005434877782	14642	92	19D
0005434877770	14642	93	19C
0005434877728	14642	94	20A
0005434877781	14642	95	19F
0005434877774	14642	96	20B
0005434877780	14642	97	20D
0005434877751	14642	98	20C
0005434877764	14642	99	20F
0005434877801	14642	100	20E
0005434877758	14642	101	21B
0005434877723	14642	102	21C
0005435913851	14642	103	21E
0005434877753	14642	104	21D
0005434877784	14642	105	21F
0005434251812	9210	1	1D
0005435660086	9210	2	3A
0005435660082	9210	3	3B
0005435660079	9210	4	4C
0005435660084	9210	5	5D
0005434251829	9210	6	6B
0005434251859	9210	7	7A
0005435660080	9210	8	7B
0005434251853	9210	9	7C
0005435660083	9210	10	7D
0005434251810	9210	11	18A
0005434251809	9210	12	18D
0005435660078	9210	13	19B
0005435660076	9210	14	19D
0005435660081	9210	15	20A
0005434251854	9210	16	20C
0005434251832	9210	17	21B
0005434251827	9210	18	21C
0005434251851	9210	19	21D
0005435660077	9210	20	22D
0005435660085	9210	21	23B
0005434251914	24669	1	3B
0005435659941	24669	2	3C
0005435659981	24669	3	4C
0005435659983	24669	4	5A
0005434251917	24669	5	5B
0005434251918	24669	6	5D
0005434251913	24669	7	6B
0005435659985	24669	8	7C
0005435659984	24669	9	18C
0005434251920	24669	10	19B
0005434251915	24669	11	19C
0005434251912	24669	12	19D
0005434251919	24669	13	20A
0005435660005	24669	14	20B
0005434251921	24669	15	20D
0005435660004	24669	16	21A
0005434251916	24669	17	21B
0005434251922	24669	18	21C
0005435660009	24669	19	21D
0005432966673	2777	1	1C
0005433680310	2777	2	1D
0005433684408	2777	3	1F
0005433680306	2777	4	2A
0005432966652	2777	5	2C
0005433680326	2777	6	2D
0005432966646	2777	7	2F
0005432966505	2777	8	3A
0005432966627	2777	9	3C
0005432966634	2777	10	3D
0005433680343	2777	11	3F
0005433684407	2777	12	4A
0005433680339	2777	13	4C
0005433680313	2777	14	4D
0005433680320	2777	15	4F
0005433680332	2777	16	5A
0005433680328	2777	17	5C
0005432222753	2777	18	5D
0005433680308	2777	19	5E
0005433680297	2777	20	5F
0005432966560	2777	21	6A
0005433680312	2777	22	6C
0005433680318	2777	23	6D
0005432966651	2777	24	6E
0005433680322	2777	25	6F
0005433680305	2777	26	7A
0005433680342	2777	27	7C
0005433680317	2777	28	7E
0005433680330	2777	29	7F
0005432966630	2777	30	8A
0005433680336	2777	31	8C
0005432222754	2777	32	8D
0005432966570	2777	33	8E
0005432966520	2777	34	8F
0005433680340	2777	35	9A
0005432222757	2777	36	9C
0005433680341	2777	37	9D
0005432966564	2777	38	9E
0005433680327	2777	39	9F
0005433680309	2777	40	10A
0005433680301	2777	41	10D
0005433680323	2777	42	10C
0005432966703	2777	43	10E
0005432966561	2777	44	11C
0005433680298	2777	45	11E
0005433680329	2777	46	11F
0005433680311	2777	47	12A
0005433680333	2777	48	12C
0005433680300	2777	49	12F
0005433680319	2777	50	12E
0005433680316	2777	51	13A
0005433680299	2777	52	13D
0005433680314	2777	53	13E
0005432966485	2777	54	13F
0005432966518	2777	55	14C
0005432966609	2777	56	14D
0005432966626	2777	57	14E
0005432966571	2777	58	14F
0005433680307	2777	59	15A
0005433680324	2777	60	15C
0005432966553	2777	61	15D
0005433680338	2777	62	15E
0005432966544	2777	63	16A
0005433680302	2777	64	16C
0005432966579	2777	65	16D
0005433680303	2777	66	16F
0005432966559	2777	67	17A
0005432966580	2777	68	17C
0005433680344	2777	69	17D
0005433680296	2777	70	17E
0005433680334	2777	71	17F
0005432966519	2777	72	18A
0005432966484	2777	73	18D
0005433680331	2777	74	18E
0005432966517	2777	75	18F
0005432222755	2777	76	19A
0005433680304	2777	77	19C
0005433680321	2777	78	19D
0005433680337	2777	79	19E
0005433684409	2777	80	19F
0005433680335	2777	81	20A
0005432966569	2777	82	20C
0005433680325	2777	83	20D
0005433680315	2777	84	20E
0005432222756	2777	85	20F
0005432966811	29170	1	1A
0005433680043	29170	2	1C
0005432966818	29170	3	1D
0005432966808	29170	4	1F
0005432966814	29170	5	2A
0005432966802	29170	6	2C
0005433679989	29170	7	2D
0005432966797	29170	8	2F
0005432966817	29170	9	3A
0005433679845	29170	10	3C
0005433680118	29170	11	3D
0005433680136	29170	12	3F
0005433679987	29170	13	4A
0005433679847	29170	14	4C
0005433680000	29170	15	4D
0005432966801	29170	16	4F
0005433679870	29170	17	5A
0005433680079	29170	18	5C
0005433680045	29170	19	5D
0005432966799	29170	20	5E
0005433679988	29170	21	6A
0005433679945	29170	22	6C
0005433679866	29170	23	6D
0005433679943	29170	24	6F
0005433680057	29170	25	7A
0005433680019	29170	26	7C
0005433679868	29170	27	7D
0005432966806	29170	28	7E
0005433679822	29170	29	7F
0005432966813	29170	30	8A
0005432966800	29170	31	8C
0005432966810	29170	32	8D
0005433680101	29170	33	8E
0005433679916	29170	34	8F
0005432966809	29170	35	9A
0005433679895	29170	36	9C
0005432966794	29170	37	9D
0005433679890	29170	38	9E
0005433680016	29170	39	9F
0005432966805	29170	40	10A
0005433680058	29170	41	10C
0005433680062	29170	42	10D
0005433679758	29170	43	10E
0005432966795	29170	44	10F
0005433679894	29170	45	11A
0005433679981	29170	46	11C
0005433680020	29170	47	11D
0005433680063	29170	48	11E
0005433679871	29170	49	11F
0005433679893	29170	50	12A
0005433680119	29170	51	12E
0005433680044	29170	52	12F
0005433679726	29170	53	13A
0005433679979	29170	54	13C
0005432966803	29170	55	13D
0005433679905	29170	56	13F
0005432966816	29170	57	14A
0005433679963	29170	58	14C
0005433679865	29170	59	14D
0005433679869	29170	60	14E
0005433679885	29170	61	14F
0005433679977	29170	62	15A
0005432966807	29170	63	15C
0005433679993	29170	64	15D
0005433679896	29170	65	15E
0005432005198	29170	66	16A
0005432966798	29170	67	16C
0005432966793	29170	68	16D
0005432966815	29170	69	16E
0005433679980	29170	70	16F
0005432966796	29170	71	17C
0005433679771	29170	72	17D
0005433679955	29170	73	17E
0005433680092	29170	74	17F
0005433679867	29170	75	18A
0005433680042	29170	76	18D
0005432966812	29170	77	18F
0005432005199	29170	78	19C
0005433679990	29170	79	19A
0005433679763	29170	80	19D
0005433679969	29170	81	19E
0005433680004	29170	82	19F
0005433679846	29170	83	20A
0005433679831	29170	84	20D
0005432966804	29170	85	20F
0005433679982	29170	86	20E
0005433614276	9316	1	1A
0005433614216	9316	2	1F
0005433577730	9316	3	1D
0005432755056	9316	4	2C
0005433614261	9316	5	2A
0005433577740	9316	6	3A
0005433614279	9316	7	2F
0005432756830	9316	8	3C
0005433614278	9316	9	3F
0005433633629	9316	10	3D
0005433633604	9316	11	4A
0005433614227	9316	12	4F
0005433614272	9316	13	4D
0005433614240	9316	14	5C
0005433614228	9316	15	5D
0005433614270	9316	16	6A
0005433614263	9316	17	6F
0005433614235	9316	18	6D
0005433633616	9316	19	7A
0005433633617	9316	20	7D
0005433614269	9316	21	7F
0005433633600	9316	22	8A
0005433614245	9316	23	8B
0005433614242	9316	24	8C
0005433577729	9316	25	8E
0005433577731	9316	26	8D
0005433614256	9316	27	8F
0005433577733	9316	28	9E
0005433614266	9316	29	9D
0005433614212	9316	30	9F
0005433633608	9316	31	10A
0005433614265	9316	32	10B
0005433614226	9316	33	10D
0005433614260	9316	34	10C
0005433577735	9316	35	10E
0005433577727	9316	36	10F
0005434272166	9316	37	11A
0005434163510	9316	38	11B
0005433614284	9316	39	11D
0005433614271	9316	40	11E
0005433633628	9316	41	12A
0005433614213	9316	42	11F
0005433614282	9316	43	12B
0005433633611	9316	44	12E
0005433614246	9316	45	12D
0005433633625	9316	46	13A
0005433633605	9316	47	13C
0005433614277	9316	48	13D
0005433633599	9316	49	13F
0005433614254	9316	50	13E
0005433614241	9316	51	14A
0005433614211	9316	52	14B
0005433614248	9316	53	14D
0005433633627	9316	54	14C
0005433614225	9316	55	14E
0005433614220	9316	56	14F
0005433614250	9316	57	15A
0005433633612	9316	58	15E
0005433614234	9316	59	15C
0005432756828	9316	60	15F
0005433614267	9316	61	16A
0005433577736	9316	62	16B
0005434152765	9316	63	16D
0005434163508	9316	64	16C
0005433614233	9316	65	16E
0005433614247	9316	66	16F
0005433633606	9316	67	17A
0005433614232	9316	68	17D
0005434163503	9316	69	17C
0005433577734	9316	70	17B
0005433614258	9316	71	17E
0005433614251	9316	72	18A
0005433577739	9316	73	18B
0005433614210	9316	74	18D
0005433614257	9316	75	18E
0005433614215	9316	76	18F
0005433633613	9316	77	19B
0005433614283	9316	78	19D
0005433614275	9316	79	19C
0005433633624	9316	80	19E
0005432756831	9316	81	20B
0005433614217	9316	82	20A
0005433614274	9316	83	20D
0005433614224	9316	84	20F
0005433614280	9316	85	21A
0005433633630	9316	86	21B
0005433633619	9316	87	21C
0005433633602	9316	88	21E
0005433614273	9316	89	21F
0005433614230	9316	90	22A
0005433633614	9316	91	22C
0005433633618	9316	92	22E
0005433614219	9316	93	22D
0005433577732	9316	94	22F
0005433614239	9316	95	23A
0005433633615	9316	96	23C
0005433614268	9316	97	23B
0005432756832	9316	98	23D
0005433633603	9316	99	23F
0005433577728	9316	100	24B
0005433614262	9316	101	24A
0005433614255	9316	102	24D
0005433614264	9316	103	24C
0005433614249	9316	104	24E
0005433614231	9316	105	24F
0005433633610	9316	106	25C
0005433614223	9316	107	25B
0005432145099	9316	108	25D
0005433577738	9316	109	25E
0005433633621	9316	110	26A
0005434272171	9316	111	26C
0005433614281	9316	112	26E
0005432756829	9316	113	26D
0005433633609	9316	114	26F
0005433614222	9316	115	27A
0005433614237	9316	116	27C
0005433614253	9316	117	27E
0005433633607	9316	118	27D
0005433614243	9316	119	28A
0005433614221	9316	120	28C
0005433633631	9316	121	28B
0005433614238	9316	122	28E
0005433633601	9316	123	28D
0005433614252	9316	124	28F
0005433614214	9316	125	29B
0005433577737	9316	126	29A
0005432755057	9316	127	29E
0005433614244	9316	128	29D
0005433614229	9316	129	29C
0005433614236	9316	130	29F
0005432755058	9316	131	30B
0005433633623	9316	132	30C
0005433633626	9316	133	30D
0005433614259	9316	134	31B
0005433633622	9316	135	31A
0005433633620	9316	136	31C
0005434152751	9316	137	31D
0005433614218	9316	138	31E
0005434163509	9316	139	31F
0005433577635	25229	1	1C
0005434163572	25229	2	1D
0005433613607	25229	3	2C
0005433633328	25229	4	2D
0005434163580	25229	5	3C
0005433613714	25229	6	3F
0005433633337	25229	7	3D
0005433613622	25229	8	4C
0005433613713	25229	9	4D
0005433613705	25229	10	5D
0005433613752	25229	11	5C
0005433613479	25229	12	6A
0005433577602	25229	13	6C
0005433613468	25229	14	7A
0005433613636	25229	15	6F
0005433633383	25229	16	7D
0005435854049	25229	17	7C
0005433613531	25229	18	8A
0005433633327	25229	19	8C
0005433613623	25229	20	8E
0005433577588	25229	21	8F
0005433613690	25229	22	9A
0005433613506	25229	23	9C
0005433633333	25229	24	9D
0005433613482	25229	25	9F
0005433633340	25229	26	10A
0005433633458	25229	27	10B
0005433577604	25229	28	10D
0005433633397	25229	29	10F
0005434163577	25229	30	10E
0005433613697	25229	31	11C
0005433577589	25229	32	11D
0005434273068	25229	33	12C
0005433613606	25229	34	12B
0005433613497	25229	35	12E
0005433577668	25229	36	12F
0005434163575	25229	37	13A
0005433613598	25229	38	13C
0005433633243	25229	39	13E
0005433633235	25229	40	13D
0005433613515	25229	41	14A
0005433633230	25229	42	14D
0005433613537	25229	43	14F
0005433633339	25229	44	15E
0005433613507	25229	45	16A
0005433633402	25229	46	16C
0005433633398	25229	47	16B
0005433577601	25229	48	16D
0005435854048	25229	49	16F
0005433577606	25229	50	17A
0005434273067	25229	51	17C
0005433577613	25229	52	17D
0005433613793	25229	53	17E
0005433633318	25229	54	18A
0005433633231	25229	55	17F
0005434163574	25229	56	18B
0005434163576	25229	57	18D
0005433613658	25229	58	18F
0005433577603	25229	59	19B
0005433633434	25229	60	19D
0005433633426	25229	61	20B
0005434272182	25229	62	20A
0005433633282	25229	63	20D
0005433633305	25229	64	20C
0005433577627	25229	65	20F
0005433613702	25229	66	21B
0005433633338	25229	67	21A
0005433613673	25229	68	21D
0005433613596	25229	69	21E
0005433613677	25229	70	22A
0005433613517	25229	71	22C
0005433613575	25229	72	22F
0005433613725	25229	73	23C
0005434163579	25229	74	23B
0005433613483	25229	75	23D
0005433613552	25229	76	23F
0005433633334	25229	77	24B
0005433613735	25229	78	24A
0005433633286	25229	79	24C
0005433633281	25229	80	24E
0005433633308	25229	81	24D
0005433613597	25229	82	24F
0005433633437	25229	83	25B
0005433613469	25229	84	25A
0005433613553	25229	85	25D
0005433633459	25229	86	25F
0005433613574	25229	87	25E
0005433613621	25229	88	26A
0005433633242	25229	89	26B
0005433613555	25229	90	26E
0005433613850	25229	91	26F
0005433633372	25229	92	27B
0005433633306	25229	93	27A
0005433633307	25229	94	27D
0005433613605	25229	95	27C
0005433613536	25229	96	27F
0005433577599	25229	97	28B
0005433577605	25229	98	28E
0005433613715	25229	99	28D
0005435854050	25229	100	29B
0005433613655	25229	101	29D
0005433613466	25229	102	29E
0005433613841	25229	103	30A
0005434163571	25229	104	29F
0005434163573	25229	105	30E
0005433577600	25229	106	30D
0005434163578	25229	107	31B
0005433613701	25229	108	31A
0005434272181	25229	109	31C
0005433577598	25229	110	31E
0005433613680	25229	111	31D
0005433613547	25229	112	31F
0005432571276	4215	1	1F
0005435947051	4215	2	4B
0005435856152	4215	3	9B
0005432571272	4215	4	9H
0005432184937	4215	5	11A
0005435947098	4215	6	14G
0005435947050	4215	7	16H
0005432571268	4215	8	17F
0005435947107	4215	9	20F
0005435986720	4215	10	20G
0005435947017	4215	11	22D
0005435947083	4215	12	24D
0005435854044	4215	13	24E
0005435947052	4215	14	25D
0005435856159	4215	15	27A
0005435947018	4215	16	27G
0005435856150	4215	17	28F
0005435947120	4215	18	28G
0005432571289	4215	19	30D
0005435947068	4215	20	30G
0005435986719	4215	21	31B
0005432571257	4215	22	32A
0005434271282	4215	23	33A
0005435986718	4215	24	33D
0005435856146	4215	25	33B
0005434271283	4215	26	36D
0005435854041	4215	27	37D
0005432184936	4215	28	39D
0005435986659	26557	1	1G
0005435856184	26557	2	2A
0005435947184	26557	3	1H
0005435856183	26557	4	3B
0005435947178	26557	5	3C
0005435947189	26557	6	4F
0005435947185	26557	7	11F
0005432571304	26557	8	12D
0005432571305	26557	9	13F
0005435856182	26557	10	16F
0005432571306	26557	11	16H
0005435947182	26557	12	17B
0005435947177	26557	13	17E
0005435986653	26557	14	18A
0005435947188	26557	15	18E
0005435856181	26557	16	21E
0005435947180	26557	17	21H
0005435986657	26557	18	22E
0005435947175	26557	19	22F
0005432571307	26557	20	23F
0005435947183	26557	21	25D
0005435947186	26557	22	27G
0005435947179	26557	23	32B
0005435947181	26557	24	32E
0005435986668	26557	25	33E
0005435787345	26557	26	33G
0005435947176	26557	27	34B
0005435787344	26557	28	34F
0005432571303	26557	29	35E
0005435947187	26557	30	37A
0005435986667	26557	31	36H
0005435986669	26557	32	37H
0005433568795	312	1	1C
0005432947914	312	2	1D
0005433568759	312	3	1F
0005433129218	312	4	2C
0005432238908	312	5	2F
0005432947905	312	6	2D
0005433568786	312	7	3A
0005433074410	312	8	3D
0005433074368	312	9	3C
0005433074318	312	10	3F
0005433129209	312	11	4A
0005432238907	312	12	4C
0005433568801	312	13	4F
0005433568777	312	14	4D
0005433568752	312	15	5A
0005433568767	312	16	5C
0005433568753	312	17	5F
0005433074416	312	18	6A
0005432947861	312	19	6D
0005432947957	312	20	6C
0005433134085	312	21	7A
0005433568746	312	22	7C
0005433568792	312	23	7D
0005432947948	312	24	8A
0005433568780	312	25	7F
0005433568776	312	26	8B
0005433134086	312	27	8D
0005432947878	312	28	8C
0005433568738	312	29	8E
0005433568797	312	30	8F
0005433568770	312	31	9B
0005433568740	312	32	9A
0005433568739	312	33	9D
0005432948024	312	34	9F
0005433074287	312	35	10A
0005432947778	312	36	10B
0005432947851	312	37	10D
0005432947852	312	38	10C
0005432947890	312	39	10E
0005433568755	312	40	10F
0005433129214	312	41	11B
0005432238906	312	42	11A
0005433568749	312	43	11C
0005432947933	312	44	11D
0005433074384	312	45	11F
0005433568791	312	46	11E
0005433568762	312	47	12A
0005433568741	312	48	12B
0005433074305	312	49	12D
0005433568763	312	50	12C
0005433134088	312	51	12E
0005433074286	312	52	12F
0005432948004	312	53	13B
0005433568773	312	54	13A
0005433568771	312	55	13C
0005432238904	312	56	13E
0005433568750	312	57	13D
0005433074233	312	58	14A
0005433568778	312	59	13F
0005433074301	312	60	14B
0005432947790	312	61	14C
0005432947967	312	62	14E
0005433074254	312	63	15A
0005432947880	312	64	14F
0005432947805	312	65	15B
0005433568745	312	66	15D
0005433074415	312	67	15F
0005433568754	312	68	15E
0005433568798	312	69	16A
0005432948055	312	70	16C
0005432947891	312	71	16B
0005433568751	312	72	16D
0005433074380	312	73	16E
0005433074298	312	74	17B
0005433074345	312	75	17A
0005432948001	312	76	17D
0005433074350	312	77	17E
0005432947990	312	78	18A
0005433134087	312	79	17F
0005433568802	312	80	18B
0005432947913	312	81	18C
0005433074208	312	82	18E
0005433568769	312	83	18F
0005433568768	312	84	19C
0005432947930	312	85	19B
0005433568796	312	86	19D
0005433074226	312	87	19E
0005432947806	312	88	20B
0005433568774	312	89	20A
0005433568787	312	90	20C
0005433134073	312	91	20E
0005432948023	312	92	20D
0005432947928	312	93	20F
0005433568772	312	94	21B
0005433568761	312	95	21A
0005433074356	312	96	21D
0005433568748	312	97	21E
0005433568758	312	98	21F
0005433074310	312	99	22B
0005433568788	312	100	22A
0005433074311	312	101	22D
0005433568789	312	102	22C
0005432947958	312	103	22F
0005433568744	312	104	22E
0005433074209	312	105	23B
0005433074253	312	106	23A
0005433568756	312	107	23D
0005432947860	312	108	23C
0005432947959	312	109	23F
0005432947906	312	110	23E
0005433568800	312	111	24A
0005433568775	312	112	24B
0005433074302	312	113	24D
0005433074378	312	114	24C
0005432948102	312	115	24F
0005433568743	312	116	24E
0005433568790	312	117	25A
0005433568766	312	118	25C
0005432947984	312	119	25E
0005432948026	312	120	26A
0005433568784	312	121	25F
0005432238905	312	122	26B
0005432947791	312	123	26D
0005432948025	312	124	26C
0005433074381	312	125	26E
0005432947889	312	126	26F
0005433568781	312	127	27C
0005433568779	312	128	27D
0005432947991	312	129	27E
0005433568765	312	130	28A
0005433074358	312	131	27F
0005433568799	312	132	28B
0005433568783	312	133	28D
0005433568764	312	134	28C
0005433074306	312	135	28E
0005433074303	312	136	29B
0005433568757	312	137	29C
0005433568742	312	138	29D
0005433074304	312	139	29F
0005433568793	312	140	29E
0005433568760	312	141	30A
0005432947807	312	142	30B
0005433568785	312	143	30C
0005433568782	312	144	30D
0005433568794	312	145	31A
0005432947983	312	146	30F
0005432947949	312	147	31C
0005432947886	312	148	31B
0005432947966	312	149	31D
0005433568747	312	150	31F
0005432947879	312	151	31E
0005432948248	11582	1	1A
0005433134112	11582	2	1C
0005433074563	11582	3	1F
0005433568238	11582	4	2C
0005433074556	11582	5	3A
0005432948232	11582	6	3D
0005433568206	11582	7	4A
0005433074565	11582	8	4D
0005432948231	11582	9	4C
0005433074553	11582	10	5A
0005433568105	11582	11	4F
0005433568157	11582	12	5C
0005433568077	11582	13	5F
0005433134116	11582	14	5D
0005432948252	11582	15	6F
0005432948255	11582	16	7A
0005433134114	11582	17	7C
0005433074560	11582	18	7D
0005433074557	11582	19	8A
0005433074567	11582	20	8B
0005432192304	11582	21	8E
0005433568158	11582	22	8D
0005433568068	11582	23	8F
0005433074554	11582	24	9B
0005432948230	11582	25	9C
0005432948243	11582	26	9D
0005432948247	11582	27	9E
0005432948254	11582	28	10A
0005432192302	11582	29	10B
0005433074566	11582	30	10D
0005433568177	11582	31	10C
0005432948237	11582	32	10E
0005433568095	11582	33	10F
0005433134113	11582	34	11C
0005433568081	11582	35	11B
0005433074561	11582	36	11D
0005433568214	11582	37	11F
0005432948229	11582	38	11E
0005433074549	11582	39	12A
0005433131686	11582	40	12C
0005432948256	11582	41	12B
0005433568083	11582	42	12E
0005433568213	11582	43	12D
0005432948257	11582	44	12F
0005433074569	11582	45	13B
0005432948223	11582	46	13A
0005433074568	11582	47	13E
0005433074551	11582	48	13F
0005433074547	11582	49	14A
0005433131685	11582	50	14B
0005433074562	11582	51	14C
0005433074546	11582	52	14E
0005432948239	11582	53	14F
0005432948224	11582	54	15B
0005433568106	11582	55	15C
0005433568189	11582	56	15D
0005432948235	11582	57	15F
0005432948234	11582	58	16A
0005432948261	11582	59	16E
0005433134115	11582	60	16D
0005432948241	11582	61	16F
0005433568114	11582	62	17C
0005433568166	11582	63	17F
0005432948259	11582	64	18A
0005433074574	11582	65	18B
0005432948236	11582	66	18D
0005432948258	11582	67	18C
0005432948244	11582	68	18E
0005432192303	11582	69	19C
0005433568174	11582	70	19D
0005432948263	11582	71	19E
0005433074548	11582	72	20C
0005432948226	11582	73	20E
0005433568132	11582	74	20D
0005433568207	11582	75	20F
0005433568111	11582	76	21E
0005433074555	11582	77	21D
0005432948225	11582	78	22A
0005433568088	11582	79	21F
0005432948227	11582	80	22B
0005433074573	11582	81	22C
0005432948238	11582	82	22D
0005432948222	11582	83	22F
0005433074550	11582	84	23A
0005432948246	11582	85	23D
0005433568173	11582	86	23E
0005433074558	11582	87	23F
0005433568212	11582	88	24B
0005433074572	11582	89	24D
0005433568067	11582	90	24E
0005433568107	11582	91	25A
0005432948251	11582	92	25C
0005433568094	11582	93	25E
0005432948233	11582	94	26D
0005432948260	11582	95	27C
0005432948249	11582	96	27F
0005432948262	11582	97	27E
0005433568188	11582	98	28A
0005432948245	11582	99	28C
0005432948242	11582	100	28E
0005432948240	11582	101	28D
0005433074564	11582	102	29A
0005433568089	11582	103	29C
0005433568161	11582	104	29B
0005432948253	11582	105	29D
0005433568176	11582	106	29F
0005433074559	11582	107	29E
0005432948228	11582	108	30B
0005433568169	11582	109	30D
0005433131684	11582	110	30F
0005433074570	11582	111	30E
0005432948250	11582	112	31B
0005433074571	11582	113	31C
0005433074552	11582	114	31D
0005433817450	10030	1	1A
0005433817454	10030	2	1B
0005433817452	10030	3	2A
0005433817451	10030	4	2B
0005434732943	10030	5	3B
0005433817453	10030	6	4B
0005434732947	10030	7	5B
0005434732944	10030	8	6A
0005434732964	13989	1	1A
0005434732965	13989	2	2A
0005433817430	13989	3	1B
0005433817429	13989	4	2B
0005434732963	13989	5	5B
0005433817410	13989	6	6A
0005433817411	13989	7	6B
0005433753926	2326	1	1C
0005435982075	2326	2	1B
0005432984532	2326	3	1F
0005433753951	2326	4	1H
0005435982091	2326	5	2A
0005433753959	2326	6	2B
0005433753939	2326	7	2C
0005434731116	2326	8	2G
0005433434264	2326	9	2F
0005433753936	2326	10	2H
0005432869435	2326	11	3B
0005433434215	2326	12	3C
0005433434386	2326	13	3G
0005433753963	2326	14	3F
0005433434338	2326	15	3H
0005433753924	2326	16	4C
0005433753953	2326	17	4B
0005432226027	2326	18	4A
0005433753949	2326	19	4G
0005435982067	2326	20	4F
0005432655477	2326	21	4H
0005435982056	2326	22	5B
0005433434387	2326	23	5A
0005435982076	2326	24	5G
0005432226023	2326	25	5F
0005433434263	2326	26	9A
0005434731102	2326	27	9B
0005434731105	2326	28	9H
0005435982094	2326	29	9G
0005435982080	2326	30	11A
0005433753934	2326	31	11B
0005432226029	2326	32	11E
0005432226025	2326	33	11D
0005433753929	2326	34	11F
0005432984661	2326	35	11H
0005433434262	2326	36	11G
0005435982084	2326	37	12A
0005432984662	2326	38	12D
0005433753921	2326	39	12B
0005434731101	2326	40	12E
0005433753932	2326	41	12G
0005433766620	2326	42	12F
0005433753952	2326	43	12H
0005432300234	2326	44	13A
0005435982063	2326	45	13D
0005433753950	2326	46	13B
0005435982071	2326	47	13F
0005433434247	2326	48	13E
0005433434230	2326	49	13G
0005433434322	2326	50	13H
0005435982081	2326	51	14B
0005435982062	2326	52	14A
0005432869414	2326	53	14E
0005433434371	2326	54	14D
0005432655480	2326	55	14H
0005435982065	2326	56	14G
0005435982061	2326	57	15A
0005432655475	2326	58	15B
0005433753964	2326	59	15D
0005435982089	2326	60	15G
0005433753944	2326	61	15E
0005434731129	2326	62	15H
0005433753931	2326	63	16A
0005435982095	2326	64	16D
0005433753943	2326	65	16B
0005433753919	2326	66	16E
0005432226028	2326	67	16G
0005432869460	2326	68	16F
0005433753918	2326	69	16H
0005433434372	2326	70	17A
0005432655473	2326	71	17D
0005433753965	2326	72	17B
0005435982092	2326	73	17E
0005433753935	2326	74	17G
0005432984507	2326	75	17F
0005435982090	2326	76	17H
0005433753941	2326	77	18B
0005433753917	2326	78	18E
0005433434233	2326	79	18D
0005435982072	2326	80	18F
0005433753962	2326	81	18G
0005433753915	2326	82	19A
0005433753938	2326	83	19D
0005433434373	2326	84	19B
0005432984688	2326	85	19E
0005433753920	2326	86	19F
0005435982088	2326	87	19G
0005432984657	2326	88	20A
0005433753967	2326	89	19H
0005433434277	2326	90	20B
0005433753937	2326	91	20E
0005432984617	2326	92	20D
0005433753912	2326	93	20F
0005433753914	2326	94	20H
0005432869455	2326	95	20G
0005433753928	2326	96	21A
0005432984609	2326	97	21B
0005433753957	2326	98	21F
0005433753925	2326	99	21E
0005433753956	2326	100	21D
0005432984511	2326	101	21H
0005435982093	2326	102	21G
0005432655472	2326	103	22B
0005435982058	2326	104	22A
0005435982086	2326	105	22D
0005433753955	2326	106	22F
0005433753930	2326	107	22G
0005435982068	2326	108	23A
0005433753942	2326	109	22H
0005432984517	2326	110	23B
0005435982070	2326	111	23E
0005433753916	2326	112	23D
0005433766621	2326	113	23G
0005432984726	2326	114	24A
0005433766622	2326	115	23H
0005432226024	2326	116	24B
0005433753947	2326	117	24E
0005432984702	2326	118	24D
0005432226026	2326	119	24F
0005435982057	2326	120	24G
0005432655481	2326	121	25D
0005435982073	2326	122	24H
0005433753966	2326	123	25F
0005433753969	2326	124	25E
0005432655483	2326	125	27A
0005433766619	2326	126	27B
0005434731128	2326	127	27E
0005433434308	2326	128	27D
0005433753954	2326	129	27G
0005433764669	2326	130	27F
0005432300233	2326	131	27H
0005432984700	2326	132	28A
0005432984663	2326	133	28B
0005433434301	2326	134	28E
0005433753948	2326	135	28F
0005435982083	2326	136	28H
0005433753960	2326	137	28G
0005435982082	2326	138	29A
0005433434292	2326	139	29D
0005432984730	2326	140	29B
0005433434231	2326	141	29E
0005432655478	2326	142	29G
0005432655479	2326	143	29F
0005433764670	2326	144	29H
0005432984660	2326	145	30B
0005433434300	2326	146	30A
0005435982087	2326	147	30F
0005432869459	2326	148	30E
0005432984699	2326	149	30G
0005432655476	2326	150	31A
0005432984642	2326	151	30H
0005433434246	2326	152	31B
0005435982085	2326	153	31D
0005432984656	2326	154	31F
0005432984608	2326	155	31E
0005432300236	2326	156	31H
0005433434281	2326	157	32A
0005433753913	2326	158	32E
0005434731103	2326	159	32D
0005435982079	2326	160	32G
0005433753946	2326	161	32F
0005432984716	2326	162	32H
0005433753945	2326	163	33A
0005435982077	2326	164	33D
0005432984512	2326	165	33B
0005433753927	2326	166	33E
0005432300235	2326	167	33G
0005433753968	2326	168	33F
0005435982078	2326	169	33H
0005433753961	2326	170	34B
0005433434309	2326	171	34A
0005433434370	2326	172	34D
0005435982059	2326	173	34E
0005433434291	2326	174	34G
0005433434211	2326	175	34F
0005433753933	2326	176	34H
0005432869428	2326	177	35B
0005432984585	2326	178	35A
0005433434288	2326	179	35E
0005433434265	2326	180	35D
0005433753958	2326	181	35G
0005432300237	2326	182	35F
0005433434339	2326	183	36B
0005432984506	2326	184	36A
0005433753922	2326	185	36E
0005435982060	2326	186	36D
0005433753923	2326	187	36F
0005435982069	2326	188	36H
0005433753940	2326	189	36G
0005432300232	2326	190	37A
0005433434310	2326	191	37B
0005433434311	2326	192	37E
0005433434289	2326	193	37D
0005433434341	2326	194	37F
0005435982054	2326	195	38A
0005432655482	2326	196	38D
0005432655474	2326	197	38B
0005435982064	2326	198	38F
0005435982055	2326	199	38H
0005435982066	2326	200	38G
0005432655484	2326	201	39D
0005435982074	2326	202	39F
0005433753439	26181	1	1A
0005435981707	26181	2	1B
0005432984927	26181	3	1F
0005433753236	26181	4	1C
0005433753513	26181	5	1G
0005432984922	26181	6	2A
0005433434538	26181	7	1H
0005432655342	26181	8	2B
0005433434532	26181	9	2F
0005432984901	26181	10	2C
0005432655375	26181	11	2G
0005432869490	26181	12	3A
0005433434542	26181	13	2H
0005435981699	26181	14	3B
0005433434548	26181	15	3F
0005433753538	26181	16	3G
0005433753382	26181	17	4A
0005433753558	26181	18	3H
0005432655344	26181	19	4B
0005432051112	26181	20	4F
0005433434549	26181	21	4C
0005435981599	26181	22	4H
0005432984915	26181	23	5B
0005433434528	26181	24	5A
0005435981661	26181	25	5F
0005435981745	26181	26	5C
0005432984902	26181	27	5G
0005433753601	26181	28	5H
0005433753500	26181	29	9B
0005435981623	26181	30	9A
0005433753499	26181	31	9G
0005432049448	26181	32	11A
0005435981830	26181	33	9H
0005433434543	26181	34	11B
0005435981793	26181	35	11F
0005433753496	26181	36	11E
0005432984920	26181	37	11G
0005432984906	26181	38	12A
0005433753346	26181	39	11H
0005435981701	26181	40	12D
0005433753305	26181	41	12B
0005433434526	26181	42	12E
0005432655365	26181	43	12F
0005435981678	26181	44	12H
0005433753440	26181	45	12G
0005433753596	26181	46	13A
0005433753402	26181	47	13D
0005433764649	26181	48	13E
0005432984923	26181	49	13F
0005435981626	26181	50	13H
0005434731150	26181	51	14B
0005432984912	26181	52	14A
0005433753323	26181	53	14D
0005433753467	26181	54	14E
0005433753489	26181	55	14G
0005432869488	26181	56	14H
0005432869486	26181	57	15B
0005433434525	26181	58	15A
0005434731148	26181	59	15D
0005432869487	26181	60	15G
0005433753243	26181	61	15F
0005433753636	26181	62	16A
0005433434552	26181	63	16D
0005432984899	26181	64	16B
0005435981593	26181	65	16E
0005433753495	26181	66	16H
0005432984903	26181	67	16G
0005432655376	26181	68	17A
0005435981660	26181	69	17D
0005434731149	26181	70	17B
0005433434527	26181	71	17E
0005432869489	26181	72	17F
0005432984904	26181	73	17H
0005435981768	26181	74	18B
0005435981595	26181	75	18A
0005433753451	26181	76	18D
0005433434545	26181	77	18E
0005433753331	26181	78	18G
0005435981526	26181	79	18F
0005433753424	26181	80	19A
0005433434536	26181	81	18H
0005433434534	26181	82	19B
0005433753537	26181	83	19D
0005432655392	26181	84	19F
0005432984910	26181	85	19E
0005432984916	26181	86	19H
0005433434531	26181	87	19G
0005433434550	26181	88	20A
0005433753355	26181	89	20D
0005435981567	26181	90	20B
0005432984914	26181	91	20E
0005435981611	26181	92	20F
0005435981609	26181	93	20H
0005433434551	26181	94	20G
0005433753278	26181	95	21A
0005433753595	26181	96	21D
0005433753303	26181	97	21B
0005432984913	26181	98	21E
0005435981566	26181	99	21H
0005433764648	26181	100	22A
0005433753535	26181	101	22D
0005433434535	26181	102	22B
0005432984911	26181	103	22E
0005433753502	26181	104	22G
0005433434530	26181	105	22F
0005433766601	26181	106	22H
0005432984926	26181	107	23A
0005433753458	26181	108	23D
0005435981602	26181	109	23F
0005433753488	26181	110	23E
0005432984917	26181	111	23G
0005432984924	26181	112	24A
0005435981672	26181	113	23H
0005435981625	26181	114	24B
0005433753597	26181	115	24D
0005432984930	26181	116	24F
0005435981744	26181	117	24E
0005434731151	26181	118	24H
0005433753330	26181	119	24G
0005433753242	26181	120	25F
0005435981669	26181	121	25E
0005432051113	26181	122	27A
0005433766585	26181	123	27D
0005433753314	26181	124	27F
0005433434546	26181	125	27E
0005433753302	26181	126	27G
0005433434537	26181	127	28A
0005433434529	26181	128	28D
0005432984907	26181	129	28B
0005433753455	26181	130	28E
0005433753356	26181	131	28F
0005433766588	26181	132	29B
0005435981700	26181	133	29A
0005433753237	26181	134	28H
0005432049446	26181	135	29E
0005432984905	26181	136	29G
0005433753459	26181	137	29F
0005433753381	26181	138	29H
0005433753512	26181	139	30B
0005433753350	26181	140	30A
0005433753332	26181	141	30D
0005432984925	26181	142	30G
0005435981529	26181	143	30F
0005432655345	26181	144	30H
0005432984929	26181	145	31B
0005435981528	26181	146	31A
0005435981751	26181	147	31D
0005435981642	26181	148	31F
0005435981783	26181	149	31E
0005435981579	26181	150	31G
0005432655350	26181	151	32A
0005432984921	26181	152	31H
0005435981525	26181	153	32D
0005433434533	26181	154	32B
0005433753301	26181	155	32F
0005433764647	26181	156	32E
0005433434541	26181	157	32H
0005432984919	26181	158	32G
0005433753604	26181	159	33A
0005433753394	26181	160	33D
0005433753311	26181	161	33B
0005435981592	26181	162	33E
0005433753401	26181	163	33F
0005433766589	26181	164	33H
0005433434547	26181	165	33G
0005433753347	26181	166	34A
0005432049445	26181	167	34D
0005433753429	26181	168	34F
0005435981883	26181	169	34E
0005432984918	26181	170	34G
0005433434553	26181	171	34H
0005433434539	26181	172	35B
0005432051114	26181	173	35A
0005435981580	26181	174	35E
0005432869491	26181	175	35F
0005433753580	26181	176	35G
0005435981923	26181	177	36A
0005435981594	26181	178	35H
0005433753434	26181	179	36B
0005433753438	26181	180	36E
0005433753312	26181	181	36D
0005433753430	26181	182	36F
0005432984908	26181	183	36G
0005433753338	26181	184	37A
0005432049447	26181	185	36H
0005433753404	26181	186	37D
0005435981677	26181	187	37B
0005435981601	26181	188	37E
0005435981670	26181	189	37F
0005433753787	26181	190	38A
0005435981598	26181	191	37H
0005433434544	26181	192	38D
0005432984909	26181	193	38B
0005432049449	26181	194	38E
0005435981695	26181	195	38G
0005435981574	26181	196	38F
0005432984928	26181	197	38H
0005432984900	26181	198	39D
0005433753405	26181	199	39F
0005433434540	26181	200	39E
0005434374423	1491	1	1A
0005432267860	1491	2	1C
0005433151044	1491	3	1F
0005434374437	1491	4	1D
0005434374443	1491	5	2A
0005434374454	1491	6	2D
0005434374458	1491	7	2F
0005434374431	1491	8	3C
0005434374438	1491	9	3F
0005434374449	1491	10	4B
0005433151026	1491	11	4D
0005433151091	1491	12	4C
0005434374459	1491	13	4E
0005433460426	1491	14	4F
0005433151041	1491	15	5A
0005432267861	1491	16	5B
0005434374446	1491	17	5D
0005433151022	1491	18	5C
0005433151043	1491	19	5E
0005434374425	1491	20	5F
0005433150962	1491	21	6B
0005434374445	1491	22	6C
0005433150958	1491	23	6D
0005434374453	1491	24	6E
0005432267863	1491	25	7A
0005433150983	1491	26	7C
0005432267864	1491	27	7D
0005434374421	1491	28	7E
0005433151053	1491	29	8B
0005434374442	1491	30	8A
0005434374426	1491	31	8E
0005434374439	1491	32	8F
0005433150920	1491	33	9A
0005433461578	1491	34	9B
0005434374451	1491	35	9C
0005433150991	1491	36	9E
0005432267862	1491	37	9F
0005434374435	1491	38	10C
0005432267859	1491	39	10B
0005433151042	1491	40	10D
0005434374436	1491	41	11A
0005433151004	1491	42	11B
0005433150942	1491	43	11D
0005433150984	1491	44	11E
0005434374432	1491	45	12A
0005434374447	1491	46	12B
0005434374430	1491	47	12C
0005433151024	1491	48	12E
0005433150940	1491	49	12F
0005434374448	1491	50	13C
0005433764650	1491	51	13B
0005433150829	1491	52	13D
0005434374433	1491	53	13F
0005432267858	1491	54	14A
0005433150979	1491	55	14B
0005433150929	1491	56	14D
0005433461579	1491	57	14C
0005433461577	1491	58	14F
0005434029617	1491	59	14E
0005434029616	1491	60	15C
0005433150978	1491	61	15B
0005434374455	1491	62	15F
0005434029614	1491	63	15E
0005433150941	1491	64	16A
0005433150873	1491	65	16C
0005433151013	1491	66	16D
0005433150966	1491	67	16F
0005434029615	1491	68	16E
0005433151156	1491	69	17A
0005433151025	1491	70	17B
0005433151054	1491	71	17D
0005432267865	1491	72	17F
0005434374450	1491	73	18B
0005434374429	1491	74	18D
0005433460424	1491	75	18C
0005433151036	1491	76	18E
0005434374424	1491	77	18F
0005433460425	1491	78	19A
0005434374456	1491	79	19C
0005433150832	1491	80	19B
0005434374440	1491	81	19D
0005433151069	1491	82	19F
0005434374422	1491	83	19E
0005433150844	1491	84	20B
0005433151002	1491	85	20A
0005433151157	1491	86	20C
0005434374441	1491	87	21A
0005434374457	1491	88	20F
0005434374434	1491	89	21C
0005434374428	1491	90	21D
0005434374444	1491	91	21E
0005434029618	1491	92	22A
0005434374452	1491	93	21F
0005433151003	1491	94	22B
0005433150959	1491	95	22C
0005433151092	1491	96	23D
0005434374427	1491	97	23F
0005433151235	20141	1	1A
0005434029643	20141	2	1D
0005433151225	20141	3	1C
0005433151226	20141	4	2A
0005434029644	20141	5	2C
0005433151243	20141	6	2D
0005433151234	20141	7	3C
0005433151224	20141	8	3F
0005433151227	20141	9	4B
0005433151249	20141	10	4D
0005434373863	20141	11	4C
0005433151215	20141	12	4E
0005433931449	20141	13	4F
0005433151218	20141	14	5B
0005433151238	20141	15	5D
0005433151231	20141	16	5F
0005434373929	20141	17	6B
0005433151232	20141	18	6C
0005433151236	20141	19	6E
0005434373862	20141	20	6F
0005433931451	20141	21	7A
0005432056281	20141	22	7C
0005434374058	20141	23	7F
0005434373930	20141	24	8B
0005433151219	20141	25	8C
0005433151217	20141	26	8E
0005433151242	20141	27	8D
0005432056278	20141	28	8F
0005434373957	20141	29	9A
0005434373941	20141	30	9B
0005433151240	20141	31	9D
0005434374036	20141	32	9C
0005433151248	20141	33	10E
0005433461564	20141	34	10D
0005433151216	20141	35	11A
0005433764670	20141	36	11B
0005433151241	20141	37	11C
0005434373934	20141	38	11E
0005433151222	20141	39	11F
0005433151250	20141	40	13A
0005434373901	20141	41	13E
0005433931450	20141	42	14B
0005433463862	20141	43	14A
0005434373902	20141	44	14D
0005433151221	20141	45	14F
0005434374002	20141	46	15A
0005432056280	20141	47	15C
0005434373942	20141	48	15E
0005433151246	20141	49	15F
0005434373933	20141	50	16B
0005433151233	20141	51	16A
0005433461563	20141	52	16D
0005434373963	20141	53	16F
0005433931452	20141	54	17A
0005432056279	20141	55	17F
0005434374008	20141	56	17E
0005433151220	20141	57	18A
0005434374001	20141	58	18C
0005434373932	20141	59	18E
0005433151223	20141	60	19A
0005433151237	20141	61	19B
0005433151247	20141	62	19E
0005433463861	20141	63	20C
0005434374042	20141	64	20E
0005433151244	20141	65	20D
0005434373945	20141	66	20F
0005433151239	20141	67	21C
0005433151228	20141	68	21B
0005433463863	20141	69	21D
0005433151229	20141	70	21F
0005433151245	20141	71	22F
0005434373958	20141	72	23C
0005433151230	20141	73	23E
0005433764669	20141	74	23D
0005434373931	20141	75	23F
0005432424203	505	1	1A
0005432424218	505	2	1D
0005432424208	505	3	2C
0005432424214	505	4	3A
0005432424198	505	5	3F
0005432282826	505	6	4D
0005432424195	505	7	5C
0005432424224	505	8	6D
0005432424229	505	9	7A
0005432282828	505	10	8C
0005432424222	505	11	9B
0005432424202	505	12	9F
0005432424205	505	13	10A
0005432424230	505	14	11E
0005432424226	505	15	12C
0005432424211	505	16	12F
0005432282831	505	17	13B
0005432424213	505	18	14A
0005432424221	505	19	14E
0005432282830	505	20	15A
0005432424210	505	21	15C
0005432424200	505	22	15D
0005432424227	505	23	15F
0005432424199	505	24	15E
0005432424228	505	25	16F
0005432424216	505	26	17C
0005432424220	505	27	18D
0005432424196	505	28	19C
0005432424212	505	29	19E
0005432282829	505	30	21A
0005432424190	505	31	21B
0005432424215	505	32	21C
0005432424192	505	33	21E
0005432424209	505	34	22B
0005432424193	505	35	22C
0005432424206	505	36	23E
0005432424191	505	37	24A
0005432424207	505	38	24D
0005432424217	505	39	25B
0005432424219	505	40	25E
0005432424223	505	41	25D
0005432424197	505	42	26C
0005432424204	505	43	28B
0005432424201	505	44	28F
0005432424189	505	45	29C
0005432424225	505	46	29F
0005432282827	505	47	30C
0005432424194	505	48	31C
0005432302313	12872	1	6A
0005432302311	12872	2	14E
0005432302312	12872	3	14F
0005432302314	12872	4	16E
0005432423605	12867	1	1C
0005432423666	12867	2	2D
0005432423801	12867	3	3A
0005432423805	12867	4	3C
0005432423809	12867	5	4C
0005432423622	12867	6	7D
0005432423667	12867	7	8F
0005432423772	12867	8	9E
0005432423709	12867	9	9D
0005432423683	12867	10	11A
0005432423687	12867	11	11C
0005432423692	12867	12	11B
0005432423800	12867	13	13B
0005432423790	12867	14	13D
0005432423693	12867	15	13C
0005432423782	12867	16	13F
0005432423650	12867	17	15A
0005432423643	12867	18	16A
0005432423791	12867	19	17A
0005432423672	12867	20	17B
0005432423688	12867	21	17C
0005432423702	12867	22	18D
0005432423736	12867	23	19D
0005432423808	12867	24	20E
0005432423738	12867	25	20D
0005432423818	12867	26	21F
0005432423789	12867	27	22D
0005432423630	12867	28	23D
0005432423703	12867	29	23F
0005432423633	12867	30	24A
0005432423737	12867	31	24E
0005432423764	12867	32	25E
0005432423684	12867	33	26B
0005432423691	12867	34	26C
0005432423803	12867	35	27E
0005432423623	12867	36	28E
0005432423629	12867	37	29B
0005432423804	12867	38	30A
0005433057291	441	1	1A
0005433057322	441	2	1C
0005432235596	441	3	1B
0005434028280	441	4	1H
0005433057399	441	5	1G
0005434023400	441	6	2A
0005432235603	441	7	2C
0005434023370	441	8	2F
0005433057483	441	9	2G
0005434028281	441	10	3B
0005434023342	441	11	3C
0005433057458	441	12	4A
0005434023386	441	13	4C
0005433057375	441	14	4G
0005434023339	441	15	5A
0005432235602	441	16	4H
0005433057518	441	17	5B
0005434023353	441	18	5F
0005434023368	441	19	9A
0005434023379	441	20	9B
0005433057359	441	21	11B
0005434023385	441	22	11E
0005434032000	441	23	11G
0005434023396	441	24	11H
0005434023351	441	25	12D
0005434023394	441	26	12E
0005434023375	441	27	12G
0005433057580	441	28	12H
0005434023362	441	29	13A
0005434023350	441	30	13D
0005434023383	441	31	13B
0005434023354	441	32	13F
0005434023347	441	33	13E
0005434023356	441	34	13G
0005434023397	441	35	14B
0005433929550	441	36	14D
0005433057323	441	37	14E
0005434023348	441	38	14H
0005434023345	441	39	14G
0005434023372	441	40	14F
0005433057381	441	41	15D
0005434023390	441	42	15F
0005433929552	441	43	15E
0005434023377	441	44	15H
0005434735599	441	45	15G
0005434023355	441	46	16A
0005432045601	441	47	16E
0005434023334	441	48	16H
0005433057216	441	49	16G
0005434023338	441	50	17D
0005432235598	441	51	17B
0005434023367	441	52	17E
0005434735613	441	53	17G
0005433057591	441	54	17F
0005434023388	441	55	17H
0005434023371	441	56	18B
0005434023389	441	57	18D
0005432045602	441	58	18E
0005433929566	441	59	18H
0005434023401	441	60	19B
0005434023392	441	61	19F
0005433057329	441	62	19E
0005433057515	441	63	19H
0005433057282	441	64	20B
0005434023359	441	65	20E
0005434023380	441	66	20G
0005434023398	441	67	20F
0005434023391	441	68	21B
0005434023374	441	69	21E
0005434735598	441	70	21H
0005433057343	441	71	22B
0005434023365	441	72	22D
0005433057290	441	73	22E
0005434031999	441	74	22G
0005433057321	441	75	23A
0005433057287	441	76	23E
0005434023337	441	77	23D
0005434023341	441	78	23F
0005432235599	441	79	24A
0005434028283	441	80	24E
0005432235597	441	81	24F
0005434023399	441	82	24G
0005434023363	441	83	25D
0005434023369	441	84	27A
0005434031997	441	85	25F
0005433057255	441	86	27E
0005433057484	441	87	27D
0005433057400	441	88	27F
0005434735607	441	89	27G
0005433057296	441	90	28A
0005434023382	441	91	27H
0005433057380	441	92	28G
0005433057457	441	93	28F
0005434023360	441	94	28H
0005434735620	441	95	29A
0005434735603	441	96	29D
0005434023335	441	97	29E
0005434023381	441	98	29F
0005434023336	441	99	29H
0005434023346	441	100	30D
0005433057297	441	101	30G
0005433057364	441	102	31A
0005433057425	441	103	31F
0005433057545	441	104	31G
0005433057415	441	105	32A
0005434023378	441	106	31H
0005434023376	441	107	32B
0005433057254	441	108	32D
0005433057365	441	109	32F
0005434023384	441	110	32H
0005433057448	441	111	32G
0005432045603	441	112	33A
0005433057208	441	113	33D
0005432235600	441	114	33F
0005434023393	441	115	33H
0005434029642	441	116	34A
0005432235601	441	117	34D
0005434023366	441	118	34F
0005434028282	441	119	34G
0005434023358	441	120	34H
0005434031995	441	121	35B
0005434023361	441	122	35A
0005434023352	441	123	35F
0005434023344	441	124	35E
0005433057371	441	125	35G
0005433057217	441	126	36A
0005434029641	441	127	35H
0005434023343	441	128	36B
0005434031996	441	129	36D
0005434023357	441	130	36F
0005433057438	441	131	36E
0005434023349	441	132	36G
0005433057447	441	133	37A
0005434023340	441	134	37E
0005433057459	441	135	37D
0005434031998	441	136	37F
0005433929551	441	137	37H
0005433057517	441	138	37G
0005433057592	441	139	38A
0005433057324	441	140	38B
0005433057358	441	141	38E
0005434023395	441	142	38F
0005433929567	441	143	38H
0005434023364	441	144	38G
0005434023373	441	145	39E
0005434023387	441	146	39D
0005433057401	441	147	39F
0005433057701	12693	1	1F
0005433057679	12693	2	2A
0005434022842	12693	3	1H
0005434022796	12693	4	2C
0005434022574	12693	5	2B
0005433057677	12693	6	2F
0005434735661	12693	7	2G
0005433057695	12693	8	2H
0005434022838	12693	9	3B
0005434022591	12693	10	3F
0005434022723	12693	11	3C
0005434022772	12693	12	3G
0005434031948	12693	13	4C
0005433057689	12693	14	4F
0005433057669	12693	15	5C
0005434022537	12693	16	5G
0005434022817	12693	17	5F
0005433057699	12693	18	5H
0005432156343	12693	19	9B
0005434023130	12693	20	11A
0005433057692	12693	21	11G
0005434022854	12693	22	12A
0005434022881	12693	23	12E
0005432156344	12693	24	12D
0005434022845	12693	25	12F
0005434735663	12693	26	12G
0005433057670	12693	27	13B
0005434023029	12693	28	13D
0005434022935	12693	29	13G
0005434031949	12693	30	13F
0005433057671	12693	31	13H
0005433929592	12693	32	14B
0005434022894	12693	33	14D
0005434022722	12693	34	14F
0005433684411	12693	35	14E
0005434022586	12693	36	14H
0005434022815	12693	37	15A
0005433057664	12693	38	15B
0005434735664	12693	39	15D
0005434022873	12693	40	15H
0005433684410	12693	41	16F
0005433057694	12693	42	16H
0005433057672	12693	43	17D
0005433057662	12693	44	17B
0005433057682	12693	45	17E
0005434022789	12693	46	17G
0005434022766	12693	47	17H
0005434022777	12693	48	18D
0005433057663	12693	49	18G
0005433057691	12693	50	18H
0005433057667	12693	51	19B
0005434022615	12693	52	19D
0005433929590	12693	53	19F
0005434735665	12693	54	20A
0005434022660	12693	55	20D
0005434022846	12693	56	20H
0005433057684	12693	57	20G
0005434023041	12693	58	21D
0005434022765	12693	59	21F
0005434022797	12693	60	21H
0005434031954	12693	61	22D
0005434022738	12693	62	22F
0005433057697	12693	63	22E
0005433057693	12693	64	22G
0005433057700	12693	65	23A
0005433057685	12693	66	23D
0005434022769	12693	67	23B
0005433057673	12693	68	23E
0005434022874	12693	69	23G
0005434022771	12693	70	23F
0005434028254	12693	71	24B
0005433057668	12693	72	24D
0005433684412	12693	73	24E
0005434022661	12693	74	25E
0005434022901	12693	75	27A
0005433057686	12693	76	27D
0005434735662	12693	77	27B
0005434022802	12693	78	27E
0005434022816	12693	79	27F
0005434022720	12693	80	27G
0005434029617	12693	81	28A
0005433057678	12693	82	27H
0005433057661	12693	83	28D
0005433057698	12693	84	28B
0005434022790	12693	85	28E
0005434031955	12693	86	28F
0005434022672	12693	87	28G
0005433057674	12693	88	28H
0005433057680	12693	89	29D
0005433057666	12693	90	30A
0005434022859	12693	91	30D
0005434022737	12693	92	30B
0005434022651	12693	93	30G
0005434022855	12693	94	31A
0005433929593	12693	95	31B
0005433057675	12693	96	31D
0005433057696	12693	97	31F
0005434022895	12693	98	31H
0005434023131	12693	99	32A
0005434022581	12693	100	32B
0005433057681	12693	101	32E
0005434029618	12693	102	32D
0005434029615	12693	103	32F
0005434022673	12693	104	32H
0005433057690	12693	105	33B
0005434022824	12693	106	33E
0005434029614	12693	107	33D
0005434023011	12693	108	33F
0005434022538	12693	109	34A
0005433057676	12693	110	34D
0005434022724	12693	111	34G
0005434022582	12693	112	35A
0005434022869	12693	113	34H
0005433057665	12693	114	35F
0005433057687	12693	115	36A
0005434022875	12693	116	36E
0005434023036	12693	117	36D
0005432157482	12693	118	36F
0005433057688	12693	119	36G
0005434022770	12693	120	37D
0005433057683	12693	121	37H
0005434022827	12693	122	37G
0005434022828	12693	123	38E
0005434022721	12693	124	38H
0005434029616	12693	125	39F
0005433929591	12693	126	39E
0005433922803	2138	1	1A
0005433035577	2138	2	1B
0005433922766	2138	3	1F
0005433922776	2138	4	1C
0005433922769	2138	5	1H
0005433035439	2138	6	2A
0005433922805	2138	7	2C
0005433922786	2138	8	2B
0005433922815	2138	9	2F
0005432749752	2138	10	2G
0005433922846	2138	11	2H
0005433922800	2138	12	3G
0005433035624	2138	13	3H
0005433922794	2138	14	4B
0005433922813	2138	15	4A
0005432231514	2138	16	4F
0005433922782	2138	17	4C
0005433035521	2138	18	4G
0005433922792	2138	19	4H
0005433035675	2138	20	5B
0005432749758	2138	21	5A
0005433922787	2138	22	5C
0005433922829	2138	23	5G
0005433922840	2138	24	9A
0005433035566	2138	25	5H
0005433035536	2138	26	9H
0005433922768	2138	27	9G
0005433922857	2138	28	11A
0005433922772	2138	29	11B
0005433922834	2138	30	11E
0005433035467	2138	31	11F
0005432231509	2138	32	11G
0005433922774	2138	33	12D
0005433035527	2138	34	12E
0005433922812	2138	35	12F
0005433922821	2138	36	12H
0005433922843	2138	37	12G
0005433035502	2138	38	13A
0005433035746	2138	39	13D
0005433922836	2138	40	13B
0005433929592	2138	41	13F
0005433875368	2138	42	13E
0005433922826	2138	43	13G
0005433922809	2138	44	13H
0005433035682	2138	45	14B
0005433922825	2138	46	14A
0005432044511	2138	47	14F
0005433035749	2138	48	14G
0005433035604	2138	49	15A
0005433035687	2138	50	15B
0005433922839	2138	51	15E
0005432044509	2138	52	15D
0005433922788	2138	53	15G
0005433922847	2138	54	15F
0005433035413	2138	55	16E
0005432231506	2138	56	16G
0005433922798	2138	57	16F
0005433035414	2138	58	16H
0005433922818	2138	59	17B
0005433922777	2138	60	17D
0005433922831	2138	61	17F
0005433875369	2138	62	17E
0005433922844	2138	63	17G
0005433922852	2138	64	17H
0005433922827	2138	65	18B
0005433922851	2138	66	18A
0005433922802	2138	67	18D
0005433922791	2138	68	18F
0005433922819	2138	69	18H
0005433922859	2138	70	18G
0005433922795	2138	71	19B
0005433922790	2138	72	19F
0005433922862	2138	73	19E
0005433922804	2138	74	19H
0005433035661	2138	75	19G
0005433035495	2138	76	20D
0005433922767	2138	77	20E
0005433931451	2138	78	20F
0005433922811	2138	79	20G
0005433922780	2138	80	21A
0005433035564	2138	81	21E
0005433035580	2138	82	21D
0005433929593	2138	83	21F
0005433922775	2138	84	21H
0005433922770	2138	85	22A
0005433922773	2138	86	22D
0005433922828	2138	87	22E
0005433931449	2138	88	22G
0005433922850	2138	89	22F
0005433922785	2138	90	23B
0005433922849	2138	91	23D
0005433922838	2138	92	23H
0005433035449	2138	93	24A
0005432231507	2138	94	24B
0005433035664	2138	95	24D
0005432231513	2138	96	24F
0005433922820	2138	97	24E
0005433929591	2138	98	24G
0005433922853	2138	99	25E
0005433035788	2138	100	25F
0005433035662	2138	101	27B
0005433035477	2138	102	27D
0005433922807	2138	103	27F
0005433922817	2138	104	27E
0005433922783	2138	105	27H
0005433922823	2138	106	27G
0005433922858	2138	107	28A
0005433922771	2138	108	28B
0005433035565	2138	109	28E
0005433922832	2138	110	28D
0005433922778	2138	111	28F
0005433922841	2138	112	28G
0005433922793	2138	113	29A
0005433922861	2138	114	28H
0005433035468	2138	115	29B
0005433035586	2138	116	29E
0005433922855	2138	117	29G
0005433922822	2138	118	29F
0005433922816	2138	119	29H
0005433922860	2138	120	30A
0005433922824	2138	121	30D
0005433035522	2138	122	30B
0005433922810	2138	123	30F
0005433035674	2138	124	30G
0005433035613	2138	125	31A
0005433922830	2138	126	30H
0005433922842	2138	127	31B
0005433931450	2138	128	31D
0005433035685	2138	129	31F
0005433035546	2138	130	31E
0005433035651	2138	131	32A
0005433922781	2138	132	32E
0005433035618	2138	133	32F
0005433922799	2138	134	32H
0005432231515	2138	135	32G
0005433922784	2138	136	33A
0005433929590	2138	137	33B
0005432231511	2138	138	33G
0005432231510	2138	139	33F
0005432231512	2138	140	33H
0005432044510	2138	141	34A
0005433035491	2138	142	34B
0005433922835	2138	143	34F
0005433922848	2138	144	34E
0005432231516	2138	145	34H
0005433035598	2138	146	35B
0005433922854	2138	147	35A
0005433922833	2138	148	35D
0005434028254	2138	149	35F
0005433035611	2138	150	35E
0005433922806	2138	151	35G
0005433035581	2138	152	35H
0005433035458	2138	153	36B
0005433922837	2138	154	36A
0005433922845	2138	155	36E
0005433922779	2138	156	36F
0005433035448	2138	157	36G
0005433922796	2138	158	37A
0005433922801	2138	159	36H
0005433931452	2138	160	37B
0005433035599	2138	161	37E
0005432231508	2138	162	37D
0005433922797	2138	163	38A
0005433035612	2138	164	37H
0005433922814	2138	165	38E
0005433922789	2138	166	38D
0005433035740	2138	167	38F
0005433035572	2138	168	38H
0005433035771	2138	169	38G
0005433922808	2138	170	39E
0005433922856	2138	171	39D
0005433035637	2138	172	39F
0005433036027	24109	1	1A
0005433036016	24109	2	1C
0005433922278	24109	3	1B
0005433036043	24109	4	1F
0005433922112	24109	5	1G
0005433922066	24109	6	2A
0005433921640	24109	7	1H
0005433929540	24109	8	2B
0005432206168	24109	9	2F
0005433036056	24109	10	3B
0005433036058	24109	11	3C
0005433921830	24109	12	3G
0005433922138	24109	13	3F
0005433921691	24109	14	4A
0005433922076	24109	15	3H
0005433036032	24109	16	4B
0005433921635	24109	17	4C
0005433036048	24109	18	4G
0005432206165	24109	19	5A
0005433921854	24109	20	5B
0005433922078	24109	21	5C
0005433922098	24109	22	5F
0005433921889	24109	23	5H
0005433929578	24109	24	5G
0005433922503	24109	25	9G
0005433921864	24109	26	9B
0005433921877	24109	27	11A
0005433036045	24109	28	9H
0005433921802	24109	29	11D
0005433875364	24109	30	11B
0005433921604	24109	31	11F
0005433921878	24109	32	11H
0005433921890	24109	33	12B
0005433921879	24109	34	12A
0005433921881	24109	35	12E
0005432206167	24109	36	12G
0005433036049	24109	37	12F
0005433922389	24109	38	12H
0005433922077	24109	39	13B
0005433921983	24109	40	13A
0005433922327	24109	41	13E
0005433922307	24109	42	13F
0005434028286	24109	43	14A
0005432206166	24109	44	13H
0005433036038	24109	45	14B
0005433036014	24109	46	14F
0005433921613	24109	47	14E
0005433922370	24109	48	14H
0005433921935	24109	49	14G
0005433922306	24109	50	15B
0005433922158	24109	51	15A
0005433921936	24109	52	15E
0005433036004	24109	53	15D
0005433921605	24109	54	16D
0005433922364	24109	55	16E
0005433875352	24109	56	16H
0005433036040	24109	57	17A
0005433922250	24109	58	17B
0005433036015	24109	59	17F
0005433922067	24109	60	17E
0005433922059	24109	61	18B
0005433036005	24109	62	18A
0005433036054	24109	63	18D
0005433929562	24109	64	18F
0005433922028	24109	65	18E
0005433921829	24109	66	18H
0005433036052	24109	67	19D
0005433922188	24109	68	19F
0005433921882	24109	69	19G
0005434028287	24109	70	19H
0005433036007	24109	71	20D
0005433922362	24109	72	20F
0005432206163	24109	73	20H
0005433036036	24109	74	20G
0005433922210	24109	75	21A
0005433921865	24109	76	21D
0005433036051	24109	77	21B
0005433921658	24109	78	21E
0005433922111	24109	79	21G
0005433036037	24109	80	21H
0005433922425	24109	81	22D
0005432207648	24109	82	22E
0005433929579	24109	83	23A
0005432207650	24109	84	22H
0005433036009	24109	85	23B
0005433922282	24109	86	23D
0005433921871	24109	87	23E
0005433922453	24109	88	23G
0005433036026	24109	89	23F
0005433036030	24109	90	23H
0005433922298	24109	91	24A
0005433036044	24109	92	24E
0005433921984	24109	93	24D
0005433036034	24109	94	24F
0005433922247	24109	95	25D
0005433036031	24109	96	24H
0005433036033	24109	97	25E
0005433922064	24109	98	27A
0005433922139	24109	99	25F
0005433922005	24109	100	27D
0005433036047	24109	101	27F
0005433922318	24109	102	27G
0005433921598	24109	103	28A
0005433921934	24109	104	27H
0005433922172	24109	105	28B
0005433036039	24109	106	28E
0005433921870	24109	107	28D
0005433036018	24109	108	28G
0005433921603	24109	109	28F
0005433036028	24109	110	28H
0005433036013	24109	111	29A
0005433929541	24109	112	29B
0005433921891	24109	113	29E
0005433921724	24109	114	29G
0005433921803	24109	115	29F
0005433036011	24109	116	29H
0005433036046	24109	117	30A
0005433921762	24109	118	30F
0005433036008	24109	119	30E
0005433036055	24109	120	30H
0005433036021	24109	121	31A
0005433921692	24109	122	31E
0005433921792	24109	123	31D
0005433922283	24109	124	31F
0005432206164	24109	125	31H
0005433036050	24109	126	32B
0005433921959	24109	127	32A
0005433922261	24109	128	32E
0005433036042	24109	129	32F
0005433921614	24109	130	33A
0005433921793	24109	131	33B
0005433921938	24109	132	33E
0005433922004	24109	133	33D
0005433931425	24109	134	33F
0005433922157	24109	135	33G
0005433921937	24109	136	34A
0005433922063	24109	137	34D
0005432207651	24109	138	34B
0005433036025	24109	139	34E
0005433036019	24109	140	34F
0005433922003	24109	141	34H
0005433036020	24109	142	34G
0005434028284	24109	143	35A
0005433036029	24109	144	35D
0005433036041	24109	145	35B
0005433921956	24109	146	35F
0005433036023	24109	147	35E
0005433036006	24109	148	35G
0005433921910	24109	149	36A
0005433036017	24109	150	35H
0005433921851	24109	151	36B
0005432207649	24109	152	36F
0005433036024	24109	153	36E
0005434028285	24109	154	36H
0005433922052	24109	155	37B
0005433036035	24109	156	37A
0005433922295	24109	157	37E
0005433036057	24109	158	37H
0005433922328	24109	159	37G
0005433921717	24109	160	38B
0005433036010	24109	161	38A
0005433036022	24109	162	38E
0005433921821	24109	163	38D
0005433036053	24109	164	38G
0005433036012	24109	165	39D
0005433922329	24109	166	39F
0005433921715	24109	167	39E
0005434724899	265	1	1C
0005434031951	265	2	1A
0005433180828	265	3	1G
0005435142504	265	4	1D
0005434724809	265	5	2A
0005433233263	265	6	1K
0005435142507	265	7	1H
0005434550959	265	8	2D
0005433289738	265	9	2C
0005434724896	265	10	2G
0005434731147	265	11	3A
0005433233307	265	12	2K
0005434724825	265	13	3G
0005434550953	265	14	3D
0005433233371	265	15	3C
0005434724842	265	16	3H
0005434724914	265	17	4C
0005434550954	265	18	4A
0005434724900	265	19	3K
0005434550940	265	20	4G
0005434724901	265	21	4D
0005434724835	265	22	4K
0005433233150	265	23	4H
0005432277739	265	24	5D
0005434550979	265	25	5C
0005434724917	265	26	5A
0005433233306	265	27	5H
0005433180824	265	28	11A
0005433289748	265	29	11D
0005433233288	265	30	11C
0005433180657	265	31	11F
0005434724898	265	32	11E
0005433233093	265	33	11G
0005434550942	265	34	12C
0005435142512	265	35	12E
0005434731144	265	36	12D
0005434302438	265	37	12G
0005434550967	265	38	12F
0005434724887	265	39	12K
0005433233609	265	40	12H
0005434724840	265	41	13C
0005434550941	265	42	13F
0005434724866	265	43	13E
0005432277735	265	44	13D
0005434724808	265	45	13H
0005434724884	265	46	13G
0005434550960	265	47	14A
0005434550946	265	48	13K
0005432277745	265	49	14E
0005434550956	265	50	14D
0005433233294	265	51	14F
0005434550966	265	52	14H
0005435142506	265	53	15C
0005434724908	265	54	15A
0005434724851	265	55	15E
0005433180790	265	56	15D
0005433233622	265	57	15G
0005433289768	265	58	15H
0005434724823	265	59	16D
0005434724846	265	60	16C
0005433233593	265	61	16A
0005434735656	265	62	16F
0005434550968	265	63	16E
0005434731145	265	64	16H
0005434724860	265	65	17C
0005433180768	265	66	17A
0005434550939	265	67	16K
0005434724903	265	68	17E
0005434550955	265	69	17D
0005434724805	265	70	17G
0005433766590	265	71	17K
0005433233368	265	72	17H
0005433289742	265	73	18B
0005432277743	265	74	18A
0005433289736	265	75	18E
0005432277741	265	76	18C
0005434724813	265	77	18H
0005433233268	265	78	18G
0005434724895	265	79	18K
0005434550982	265	80	18J
0005433180732	265	81	19B
0005433233296	265	82	19A
0005433180845	265	83	19D
0005434724889	265	84	19C
0005433233404	265	85	19F
0005434550985	265	86	19E
0005434724874	265	87	19H
0005434724905	265	88	20A
0005435142503	265	89	19K
0005434724839	265	90	19J
0005433233170	265	91	20C
0005434550973	265	92	20B
0005434724861	265	93	20E
0005433180755	265	94	20D
0005434724816	265	95	20G
0005434724855	265	96	20F
0005434724838	265	97	20K
0005433289754	265	98	20J
0005433131635	265	99	21A
0005434724920	265	100	21C
0005434724812	265	101	21B
0005434031975	265	102	21F
0005433233232	265	103	21E
0005434731143	265	104	21J
0005433233367	265	105	21H
0005432277744	265	106	21G
0005434724819	265	107	22A
0005434724910	265	108	22C
0005433180766	265	109	22B
0005434724829	265	110	22F
0005433180748	265	111	22E
0005434724915	265	112	22H
0005433233369	265	113	22G
0005434550937	265	114	22K
0005434724859	265	115	22J
0005434724815	265	116	23A
0005433233114	265	117	23D
0005434724854	265	118	23C
0005433180719	265	119	23F
0005434550970	265	120	23E
0005434724882	265	121	23H
0005434724904	265	122	23G
0005434724872	265	123	24D
0005433233607	265	124	24F
0005433180843	265	125	24E
0005434550963	265	126	25D
0005433180822	265	127	25C
0005434724877	265	128	25F
0005432277738	265	129	25E
0005433180693	265	130	25J
0005433233209	265	131	25H
0005434724848	265	132	25G
0005434724875	265	133	26C
0005434724878	265	134	26B
0005434550977	265	135	26E
0005433233248	265	136	26D
0005434724858	265	137	26G
0005433233444	265	138	26F
0005434550958	265	139	27B
0005433233277	265	140	27A
0005434550936	265	141	27D
0005434724844	265	142	27C
0005433233265	265	143	27E
0005434550951	265	144	27H
0005433289737	265	145	28A
0005434724918	265	146	27J
0005434724820	265	147	28B
0005434550961	265	148	28D
0005434724876	265	149	28G
0005433131639	265	150	28F
0005434724857	265	151	28J
0005434724890	265	152	28H
0005433180733	265	153	29B
0005433233299	265	154	29A
0005433233324	265	155	29D
0005434724799	265	156	29C
0005434550986	265	157	29F
0005434550981	265	158	29E
0005434724909	265	159	29J
0005434724849	265	160	29H
0005434724818	265	161	29G
0005433180761	265	162	30A
0005434724802	265	163	29K
0005434724881	265	164	30B
0005434724798	265	165	30E
0005434550934	265	166	30D
0005433233461	265	167	30C
0005434724824	265	168	30G
0005434724867	265	169	30F
0005434724810	265	170	31A
0005433289755	265	171	30K
0005433233373	265	172	31B
0005435142514	265	173	31F
0005434724873	265	174	31E
0005434302856	265	175	31J
0005434724892	265	176	31G
0005434735658	265	177	31K
0005434302436	265	178	32C
0005434724886	265	179	32B
0005433233491	265	180	32A
0005434724912	265	181	32E
0005434731146	265	182	32D
0005434724868	265	183	32G
0005433766586	265	184	32F
0005434724850	265	185	32J
0005434724831	265	186	32H
0005433233403	265	187	33B
0005433289725	265	188	32K
0005434031958	265	189	33D
0005434550975	265	190	33C
0005433233113	265	191	33F
0005434724817	265	192	33H
0005433233098	265	193	33G
0005434724800	265	194	34A
0005434724856	265	195	33K
0005433233578	265	196	33J
0005435142510	265	197	34C
0005434724830	265	198	34B
0005434550944	265	199	34E
0005434724853	265	200	34D
0005433233292	265	201	34F
0005434550933	265	202	34J
0005433289766	265	203	34H
0005434724897	265	204	35B
0005434550984	265	205	35A
0005433180823	265	206	34K
0005434550972	265	207	35D
0005433180791	265	208	35C
0005434724801	265	209	35F
0005433233372	265	210	35H
0005434550938	265	211	35K
0005434724832	265	212	36C
0005434724811	265	213	36B
0005434724852	265	214	36E
0005434550935	265	215	36D
0005434550980	265	216	36F
0005434724807	265	217	36J
0005434724864	265	218	37B
0005432277734	265	219	37A
0005435142513	265	220	37D
0005434724828	265	221	37G
0005433233466	265	222	37F
0005433180718	265	223	37E
0005434724907	265	224	37H
0005433233330	265	225	38A
0005433289767	265	226	37J
0005432277740	265	227	38B
0005433289726	265	228	38J
0005434302437	265	229	38H
0005434302435	265	230	39B
0005434550983	265	231	39A
0005432277742	265	232	38K
0005434550969	265	233	39D
0005434724894	265	234	39C
0005432277746	265	235	39E
0005433180777	265	236	39H
0005434724826	265	237	39G
0005434724870	265	238	40A
0005433180789	265	239	39K
0005434724871	265	240	39J
0005434724821	265	241	40B
0005434724883	265	242	40F
0005434550978	265	243	40E
0005434550974	265	244	40D
0005434724814	265	245	40H
0005434550976	265	246	40G
0005432277736	265	247	40J
0005434724921	265	248	41B
0005433289735	265	249	41D
0005433113502	265	250	41C
0005433233289	265	251	41G
0005434724879	265	252	41F
0005433180778	265	253	41E
0005433233506	265	254	41J
0005434724911	265	255	41H
0005434724906	265	256	42A
0005435142511	265	257	41K
0005433233097	265	258	42B
0005434724837	265	259	42E
0005434724913	265	260	42D
0005434550965	265	261	42C
0005434724919	265	262	42G
0005433233465	265	263	42F
0005434724888	265	264	42J
0005434550950	265	265	42H
0005435142505	265	266	43B
0005433233608	265	267	43A
0005432277737	265	268	42K
0005433233291	265	269	43D
0005434724803	265	270	43C
0005433180844	265	271	43E
0005433233467	265	272	43H
0005433766597	265	273	43G
0005434724836	265	274	44A
0005434735660	265	275	43K
0005434724902	265	276	43J
0005433233235	265	277	44C
0005434724885	265	278	44B
0005433233287	265	279	44D
0005434550945	265	280	44H
0005435142509	265	281	44G
0005434735659	265	282	45B
0005434724891	265	283	45A
0005434550947	265	284	44K
0005433766582	265	285	45D
0005434550932	265	286	45F
0005434550957	265	287	45H
0005434550943	265	288	45G
0005434550952	265	289	46A
0005434724880	265	290	45K
0005434724841	265	291	45J
0005434724916	265	292	46E
0005434724862	265	293	46D
0005434735657	265	294	46C
0005434724804	265	295	46H
0005434724833	265	296	46G
0005434550964	265	297	47C
0005434724869	265	298	47D
0005434550962	265	299	47G
0005434724865	265	300	47F
0005434724797	265	301	47K
0005433233169	265	302	47H
0005435142508	265	303	48D
0005434550971	265	304	48C
0005434724822	265	305	48F
0005434724843	265	306	48E
0005433233571	265	307	48G
0005434724845	265	308	49C
0005433180751	265	309	49A
0005434724893	265	310	48K
0005433180656	265	311	49D
0005433233267	265	312	49F
0005434724806	265	313	49K
0005433233262	265	314	49H
0005434724834	265	315	49G
0005434724827	265	316	50C
0005433233514	265	317	50A
0005434550948	265	318	50H
0005434724847	265	319	50F
0005433233331	265	320	50K
0005434724863	265	321	51E
0005433233515	265	322	51D
0005434550949	265	323	51G
0005434550414	9869	1	1C
0005433180977	9869	2	1A
0005434724380	9869	3	1G
0005433113524	9869	4	1D
0005434724182	9869	5	2A
0005433233915	9869	6	1K
0005434723921	9869	7	1H
0005432199216	9869	8	2D
0005433233864	9869	9	2C
0005433233870	9869	10	2H
0005434724069	9869	11	2G
0005433233871	9869	12	3A
0005433233911	9869	13	3G
0005434723762	9869	14	3D
0005434723945	9869	15	3C
0005434550317	9869	16	3H
0005433233912	9869	17	4C
0005433233895	9869	18	4A
0005434723504	9869	19	3K
0005434550526	9869	20	4D
0005434550262	9869	21	5A
0005434724073	9869	22	4K
0005433180980	9869	23	4H
0005434550336	9869	24	5D
0005434550448	9869	25	5C
0005434724109	9869	26	5H
0005433233892	9869	27	5G
0005434550463	9869	28	11A
0005434723696	9869	29	5K
0005434550283	9869	30	11D
0005434723818	9869	31	11C
0005434723878	9869	32	11G
0005434724198	9869	33	11F
0005434724104	9869	34	11E
0005434724202	9869	35	11H
0005434723919	9869	36	12A
0005433233910	9869	37	12E
0005433180958	9869	38	12D
0005434723742	9869	39	12H
0005433180968	9869	40	12G
0005434723794	9869	41	12F
0005433233858	9869	42	12K
0005434723563	9869	43	13D
0005433233856	9869	44	13C
0005434723799	9869	45	13E
0005433180971	9869	46	13H
0005433180983	9869	47	14C
0005433180962	9869	48	14A
0005434724342	9869	49	13K
0005434724072	9869	50	14D
0005434723583	9869	51	14F
0005434723609	9869	52	14H
0005434723328	9869	53	15C
0005434731103	9869	54	15A
0005434723577	9869	55	15F
0005434724007	9869	56	15E
0005434723462	9869	57	15G
0005434723846	9869	58	15K
0005433126822	9869	59	15H
0005433233866	9869	60	16D
0005434723796	9869	61	16C
0005433233908	9869	62	16A
0005434724041	9869	63	16F
0005434723937	9869	64	16E
0005433233872	9869	65	16H
0005434724019	9869	66	16G
0005434550417	9869	67	17C
0005432199209	9869	68	17A
0005433233889	9869	69	17E
0005433233863	9869	70	17D
0005434723859	9869	71	17G
0005434550459	9869	72	17F
0005434723860	9869	73	17K
0005433233906	9869	74	17H
0005434723394	9869	75	18A
0005433233859	9869	76	18E
0005433180965	9869	77	18D
0005434550427	9869	78	18C
0005433766619	9869	79	18H
0005434550520	9869	80	18G
0005433289812	9869	81	18K
0005433180964	9869	82	18J
0005433233900	9869	83	19A
0005434550569	9869	84	19D
0005433766620	9869	85	19C
0005434550416	9869	86	19E
0005433180960	9869	87	19H
0005435142381	9869	88	19G
0005433180966	9869	89	19K
0005434723944	9869	90	19J
0005434032001	9869	91	20B
0005434550342	9869	92	20A
0005434724051	9869	93	20E
0005434550572	9869	94	20D
0005433233854	9869	95	20G
0005434724074	9869	96	20K
0005433180961	9869	97	20J
0005434724070	9869	98	21A
0005432199212	9869	99	21C
0005434723681	9869	100	21G
0005433180973	9869	101	21F
0005434723779	9869	102	21E
0005434723463	9869	103	21H
0005434731105	9869	104	22A
0005434550677	9869	105	21K
0005434724194	9869	106	22C
0005434723923	9869	107	22B
0005434723446	9869	108	22F
0005434723895	9869	109	22E
0005434723865	9869	110	22D
0005434550624	9869	111	22G
0005434724229	9869	112	22K
0005434723936	9869	113	22J
0005434550399	9869	114	22H
0005433233901	9869	115	23B
0005434723790	9869	116	23A
0005433233869	9869	117	23D
0005433289809	9869	118	23C
0005434723677	9869	119	23F
0005434550628	9869	120	23E
0005434723727	9869	121	23H
0005434550571	9869	122	23G
0005434723454	9869	123	24D
0005434550503	9869	124	23K
0005434723628	9869	125	24F
0005434724263	9869	126	25A
0005434723829	9869	127	24G
0005434723752	9869	128	25D
0005434550428	9869	129	25C
0005434550418	9869	130	25B
0005434550400	9869	131	25F
0005433233913	9869	132	25E
0005434302386	9869	133	25H
0005434724110	9869	134	25G
0005434302397	9869	135	25K
0005433233887	9869	136	25J
0005434723595	9869	137	26C
0005433233907	9869	138	26B
0005434723788	9869	139	26A
0005433233888	9869	140	26G
0005433180975	9869	141	26F
0005434723819	9869	142	26K
0005434723839	9869	143	26H
0005434550358	9869	144	27A
0005433180982	9869	145	27D
0005434723572	9869	146	27C
0005433233876	9869	147	27B
0005434723800	9869	148	27F
0005435142353	9869	149	27J
0005433233853	9869	150	27H
0005434550529	9869	151	27G
0005434723787	9869	152	28A
0005433233886	9869	153	27K
0005434723943	9869	154	28B
0005435142373	9869	155	28E
0005434723842	9869	156	28C
0005433233868	9869	157	28H
0005432199210	9869	158	28G
0005434723447	9869	159	28F
0005434724322	9869	160	28J
0005434723616	9869	161	29B
0005434723582	9869	162	29A
0005434550341	9869	163	29D
0005434723778	9869	164	29C
0005434550460	9869	165	29F
0005434731102	9869	166	29E
0005434723821	9869	167	29H
0005434550702	9869	168	29G
0005434550434	9869	169	30A
0005434723920	9869	170	29K
0005434550642	9869	171	29J
0005433233877	9869	172	30C
0005434723717	9869	173	30B
0005434723598	9869	174	30E
0005434302396	9869	175	30D
0005433289810	9869	176	30G
0005434723342	9869	177	30F
0005434550479	9869	178	30J
0005434723824	9869	179	31B
0005434550282	9869	180	31A
0005433233881	9869	181	30K
0005432199211	9869	182	31D
0005434550345	9869	183	31C
0005434550701	9869	184	31F
0005434724029	9869	185	31H
0005433233909	9869	186	31G
0005434550553	9869	187	31K
0005433233862	9869	188	31J
0005434724186	9869	189	32B
0005433180979	9869	190	32A
0005434731129	9869	191	32K
0005434723682	9869	192	33A
0005433766622	9869	193	33C
0005433180972	9869	194	33B
0005433129253	9869	195	33F
0005434723728	9869	196	33E
0005434723836	9869	197	33D
0005434550575	9869	198	33G
0005435142379	9869	199	33K
0005434723959	9869	200	33J
0005434723680	9869	201	34B
0005433180976	9869	202	34E
0005434723697	9869	203	34D
0005433126820	9869	204	34G
0005434302394	9869	205	34F
0005434723676	9869	206	34J
0005434723751	9869	207	34H
0005433180969	9869	208	35B
0005434550277	9869	209	35A
0005433233885	9869	210	35D
0005434550415	9869	211	35F
0005434724163	9869	212	35E
0005433180984	9869	213	35J
0005433233890	9869	214	35H
0005434723764	9869	215	35G
0005434724023	9869	216	36A
0005434724169	9869	217	35K
0005434723617	9869	218	36B
0005434724033	9869	219	36E
0005433233894	9869	220	36D
0005433233916	9869	221	36G
0005432199215	9869	222	36F
0005434723867	9869	223	36K
0005434723701	9869	224	36J
0005434550623	9869	225	37B
0005434723538	9869	226	37A
0005434723552	9869	227	37D
0005434550382	9869	228	37C
0005434723593	9869	229	37G
0005434723942	9869	230	37F
0005434723395	9869	231	37E
0005433233860	9869	232	37H
0005434723922	9869	233	37K
0005433233896	9869	234	37J
0005433233891	9869	235	38H
0005434550645	9869	236	38B
0005433180981	9869	237	38A
0005434550435	9869	238	38J
0005434723960	9869	239	39B
0005433180963	9869	240	39A
0005434723891	9869	241	38K
0005434550602	9869	242	39D
0005434723716	9869	243	39C
0005433233867	9869	244	39F
0005433233861	9869	245	39E
0005434550525	9869	246	39J
0005434724101	9869	247	39G
0005435142372	9869	248	40A
0005434550676	9869	249	39K
0005434302387	9869	250	40B
0005433233879	9869	251	40E
0005433233855	9869	252	40D
0005433289811	9869	253	40G
0005433233905	9869	254	40F
0005433233873	9869	255	40K
0005433126821	9869	256	40J
0005434724220	9869	257	41B
0005434723820	9869	258	41A
0005434731128	9869	259	41C
0005434723639	9869	260	41E
0005434724042	9869	261	41J
0005433180974	9869	262	41H
0005434723789	9869	263	41G
0005433180978	9869	264	42A
0005433113525	9869	265	42B
0005434723777	9869	266	42E
0005434723726	9869	267	42D
0005434723700	9869	268	42F
0005434724321	9869	269	42K
0005433233914	9869	270	42J
0005434723594	9869	271	43B
0005434032003	9869	272	43A
0005434723571	9869	273	43C
0005434724091	9869	274	43F
0005433180970	9869	275	43E
0005433233898	9869	276	43H
0005433129252	9869	277	43G
0005435142389	9869	278	43K
0005433233897	9869	279	43J
0005433766621	9869	280	44B
0005434550359	9869	281	44A
0005434724267	9869	282	44E
0005434724050	9869	283	44D
0005434723461	9869	284	44H
0005434724003	9869	285	44G
0005433233899	9869	286	44F
0005434723900	9869	287	44J
0005433233903	9869	288	45B
0005434724454	9869	289	45A
0005434731116	9869	290	44K
0005433233878	9869	291	45D
0005434723729	9869	292	45F
0005434723793	9869	293	45E
0005433233882	9869	294	45H
0005434724020	9869	295	45G
0005433233904	9869	296	46A
0005434723890	9869	297	45K
0005434723695	9869	298	45J
0005434550524	9869	299	46E
0005434724144	9869	300	46D
0005434723596	9869	301	46F
0005434723763	9869	302	46J
0005434723455	9869	303	46H
0005434032002	9869	304	47C
0005433113523	9869	305	47A
0005434550344	9869	306	46K
0005435142397	9869	307	47E
0005434550398	9869	308	47D
0005433233893	9869	309	47F
0005432199213	9869	310	47K
0005433233865	9869	311	47H
0005433233857	9869	312	48C
0005433233874	9869	313	48F
0005435142380	9869	314	48E
0005433180959	9869	315	48H
0005434723537	9869	316	48K
0005433233875	9869	317	49D
0005433233884	9869	318	49C
0005433180967	9869	319	49F
0005433233902	9869	320	49E
0005434550675	9869	321	49K
0005433233880	9869	322	49H
0005434724147	9869	323	50C
0005434723551	9869	324	50E
0005433289808	9869	325	50D
0005434723597	9869	326	50G
0005434550523	9869	327	51D
0005434731101	9869	328	50K
0005433233883	9869	329	51F
0005434723397	9869	330	51E
0005432199214	9869	331	51G
0005434067177	7737	1	1C
0005432527274	7737	2	1A
0005435212717	7737	3	1G
0005435212614	7737	4	1D
0005432535811	7737	5	1K
0005434067211	7737	6	2C
0005435212474	7737	7	2A
0005432150152	7737	8	2G
0005432527327	7737	9	3A
0005432527251	7737	10	2K
0005434067207	7737	11	2H
0005435212471	7737	12	3G
0005435212633	7737	13	3D
0005435212920	7737	14	3C
0005435212743	7737	15	3H
0005435212683	7737	16	4C
0005435212551	7737	17	4A
0005434067195	7737	18	3K
0005435212693	7737	19	4G
0005432527298	7737	20	4D
0005432527285	7737	21	4K
0005432527369	7737	22	4H
0005435212509	7737	23	5C
0005432527303	7737	24	5A
0005435212431	7737	25	5G
0005432069576	7737	26	5D
0005432527314	7737	27	11A
0005434067174	7737	28	5K
0005434067218	7737	29	11D
0005435212692	7737	30	11C
0005434067231	7737	31	11F
0005434067227	7737	32	11K
0005434067168	7737	33	11G
0005432527320	7737	34	12A
0005434067186	7737	35	12E
0005432527335	7737	36	12D
0005432527368	7737	37	12G
0005432527273	7737	38	13A
0005435212813	7737	39	12K
0005432527330	7737	40	12H
0005432527318	7737	41	13D
0005434067198	7737	42	13C
0005432069581	7737	43	13F
0005433656621	7737	44	13E
0005432527355	7737	45	13H
0005432537047	7737	46	14A
0005432527306	7737	47	13K
0005432527347	7737	48	14E
0005432527282	7737	49	14D
0005434067170	7737	50	14C
0005434067202	7737	51	14G
0005432527352	7737	52	14F
0005432527345	7737	53	14K
0005434067215	7737	54	15C
0005434067209	7737	55	15F
0005432428911	7737	56	15E
0005432069587	7737	57	15D
0005435212705	7737	58	15H
0005435212653	7737	59	15G
0005432527377	7737	60	15K
0005434067197	7737	61	16C
0005434067233	7737	62	16A
0005434067237	7737	63	16F
0005432527367	7737	64	16E
0005432527260	7737	65	16K
0005432527305	7737	66	16H
0005432533275	7737	67	16G
0005433656626	7737	68	17A
0005434067169	7737	69	17E
0005435212514	7737	70	17D
0005434067173	7737	71	17C
0005434067224	7737	72	17H
0005432150155	7737	73	17G
0005434067223	7737	74	17F
0005432527295	7737	75	18A
0005432533276	7737	76	18C
0005435212659	7737	77	18E
0005435212599	7737	78	18D
0005435630934	7737	79	18G
0005432527359	7737	80	18J
0005432150150	7737	81	18H
0005432527290	7737	82	19A
0005434067210	7737	83	18K
0005432527257	7737	84	19D
0005434067183	7737	85	19C
0005434067190	7737	86	19B
0005432527315	7737	87	19F
0005432527268	7737	88	19E
0005435725529	7737	89	19H
0005432527343	7737	90	19G
0005435212409	7737	91	20A
0005432527255	7737	92	19K
0005434067196	7737	93	19J
0005435212556	7737	94	20C
0005432150153	7737	95	20B
0005432527337	7737	96	20F
0005432527334	7737	97	20D
0005432527363	7737	98	20H
0005432527322	7737	99	20G
0005434067181	7737	100	20K
0005432527325	7737	101	21D
0005435212445	7737	102	21C
0005432527249	7737	103	21G
0005432527287	7737	104	21E
0005434067213	7737	105	21J
0005435212578	7737	106	21H
0005432527336	7737	107	22A
0005435212760	7737	108	21K
0005432527329	7737	109	22C
0005435212734	7737	110	22B
0005432069575	7737	111	22F
0005432527312	7737	112	22E
0005432428910	7737	113	22H
0005432527373	7737	114	22G
0005432527297	7737	115	22K
0005432527248	7737	116	22J
0005435630937	7737	117	23B
0005432527356	7737	118	23A
0005432069582	7737	119	23E
0005435212684	7737	120	23D
0005432527304	7737	121	23C
0005432150151	7737	122	23G
0005432527245	7737	123	23F
0005435212660	7737	124	23J
0005432527357	7737	125	23H
0005432527307	7737	126	24D
0005432535808	7737	127	23K
0005432069579	7737	128	24F
0005432527263	7737	129	24E
0005432527344	7737	130	25A
0005434067225	7737	131	24G
0005432069583	7737	132	25C
0005432527291	7737	133	25B
0005435212921	7737	134	25F
0005434067238	7737	135	25H
0005432527341	7737	136	25G
0005435212636	7737	137	26A
0005433656618	7737	138	25J
0005432527311	7737	139	26C
0005432527267	7737	140	26E
0005432527375	7737	141	26D
0005435212706	7737	142	26G
0005432527339	7737	143	26F
0005435212710	7737	144	26H
0005432527340	7737	145	27A
0005432527264	7737	146	26K
0005434067212	7737	147	27D
0005432527275	7737	148	27C
0005435212635	7737	149	27B
0005432527280	7737	150	27F
0005432428912	7737	151	27E
0005435212591	7737	152	27H
0005435212553	7737	153	27G
0005432527266	7737	154	27K
0005432527362	7737	155	27J
0005432069577	7737	156	28B
0005435212592	7737	157	28E
0005435212634	7737	158	28D
0005432527326	7737	159	28C
0005435212432	7737	160	28H
0005432527376	7737	161	28G
0005432150158	7737	162	28F
0005434067204	7737	163	28J
0005434067234	7737	164	29B
0005432527258	7737	165	29A
0005434067185	7737	166	28K
0005432069578	7737	167	29D
0005432527247	7737	168	29C
0005432527270	7737	169	29E
0005435212520	7737	170	29G
0005435212523	7737	171	29K
0005435725517	7737	172	30C
0005434067194	7737	173	30E
0005432527374	7737	174	30D
0005432527299	7737	175	30H
0005432535810	7737	176	30G
0005434067217	7737	177	30F
0005435212609	7737	178	30J
0005435212470	7737	179	31A
0005432527346	7737	180	30K
0005434067216	7737	181	31D
0005434067178	7737	182	31C
0005435212707	7737	183	31B
0005435212753	7737	184	31F
0005432069573	7737	185	31E
0005432535809	7737	186	31H
0005432527351	7737	187	31G
0005432527365	7737	188	32A
0005432527252	7737	189	31K
0005432527253	7737	190	31J
0005434067182	7737	191	32B
0005435212694	7737	192	32E
0005432533277	7737	193	32C
0005432527246	7737	194	32G
0005435212563	7737	195	32F
0005435212473	7737	196	32J
0005434067180	7737	197	32H
0005432150154	7737	198	33A
0005435212637	7737	199	32K
0005432069580	7737	200	33D
0005432527316	7737	201	33C
0005434067221	7737	202	33E
0005435212674	7737	203	33J
0005432527358	7737	204	33H
0005434067208	7737	205	34A
0005435630924	7737	206	33K
0005435212358	7737	207	34C
0005432527301	7737	208	34B
0005432527254	7737	209	34E
0005434067167	7737	210	34D
0005434067222	7737	211	34G
0005435212812	7737	212	34F
0005435212557	7737	213	34J
0005432537046	7737	214	34H
0005432527348	7737	215	35B
0005434067189	7737	216	35A
0005435212552	7737	217	34K
0005432527313	7737	218	35D
0005435212434	7737	219	35C
0005432069584	7737	220	35E
0005434067187	7737	221	35H
0005434067201	7737	222	35G
0005432527256	7737	223	36A
0005432527328	7737	224	35K
0005434067193	7737	225	35J
0005434067232	7737	226	36C
0005435212396	7737	227	36B
0005432527350	7737	228	36E
0005432428909	7737	229	36H
0005435212664	7737	230	36G
0005432527333	7737	231	36F
0005432527310	7737	232	36J
0005435212819	7737	233	37A
0005432527324	7737	234	36K
0005432527296	7737	235	37E
0005432527317	7737	236	37D
0005432150157	7737	237	37C
0005432527308	7737	238	37G
0005432527354	7737	239	37F
0005435212354	7737	240	37H
0005435212691	7737	241	38A
0005432527269	7737	242	37K
0005432527293	7737	243	37J
0005432527286	7737	244	38C
0005432527371	7737	245	38B
0005435212757	7737	246	38J
0005435212702	7737	247	38H
0005435212464	7737	248	39B
0005435212332	7737	249	39A
0005435212613	7737	250	38K
0005432527353	7737	251	39D
0005435212555	7737	252	39C
0005435212735	7737	253	39F
0005434067220	7737	254	39E
0005435212589	7737	255	39H
0005432527250	7737	256	39G
0005434067199	7737	257	40A
0005435212736	7737	258	39K
0005435212815	7737	259	39J
0005434067219	7737	260	40E
0005432537045	7737	261	40D
0005432527361	7737	262	40G
0005432527279	7737	263	40F
0005435212598	7737	264	40K
0005434067176	7737	265	40J
0005432527289	7737	266	41D
0005435212521	7737	267	41C
0005435212652	7737	268	41B
0005432150156	7737	269	41F
0005435212510	7737	270	41E
0005432527323	7737	271	41G
0005435212564	7737	272	42A
0005432527372	7737	273	41J
0005432527284	7737	274	42C
0005432533278	7737	275	42B
0005433656623	7737	276	42E
0005434067226	7737	277	42G
0005434067184	7737	278	42F
0005435725518	7737	279	42J
0005432069585	7737	280	43B
0005432527276	7737	281	43A
0005432527300	7737	282	42K
0005435212562	7737	283	43D
0005434067188	7737	284	43C
0005432069586	7737	285	43F
0005432527261	7737	286	43E
0005432527277	7737	287	43H
0005432069574	7737	288	43G
0005434067230	7737	289	44A
0005433656617	7737	290	43K
0005434067192	7737	291	43J
0005435212641	7737	292	44B
0005434067203	7737	293	44D
0005432527278	7737	294	44G
0005435212554	7737	295	44F
0005432527370	7737	296	44J
0005434067214	7737	297	44H
0005432527288	7737	298	45B
0005434067175	7737	299	45C
0005435212818	7737	300	45G
0005432527272	7737	301	45F
0005435212357	7737	302	45E
0005432527294	7737	303	45H
0005434067191	7737	304	45J
0005434067206	7737	305	46C
0005432527259	7737	306	46B
0005432527262	7737	307	46A
0005432527281	7737	308	46E
0005432527309	7737	309	46D
0005432527319	7737	310	46G
0005432527332	7737	311	46F
0005432527331	7737	312	46J
0005432527271	7737	313	46H
0005435212623	7737	314	47A
0005434067200	7737	315	46K
0005435212508	7737	316	47E
0005432527364	7737	317	47D
0005434067171	7737	318	47C
0005434067179	7737	319	47G
0005435212758	7737	320	47F
0005435212408	7737	321	47K
0005434067229	7737	322	47H
0005435212447	7737	323	48A
0005432535807	7737	324	48F
0005432527360	7737	325	48E
0005434067172	7737	326	48H
0005432527244	7737	327	48G
0005434067236	7737	328	49C
0005434067235	7737	329	49A
0005432527349	7737	330	48K
0005434067205	7737	331	49D
0005432527366	7737	332	49F
0005432527342	7737	333	49E
0005432533279	7737	334	49H
0005435212701	7737	335	49G
0005435630925	7737	336	50C
0005435212638	7737	337	50A
0005432527265	7737	338	50E
0005432527338	7737	339	50D
0005434067228	7737	340	50G
0005432527292	7737	341	50F
0005435212759	7737	342	50K
0005432527302	7737	343	51E
0005432527321	7737	344	51D
0005432527283	7737	345	51G
0005434344038	5333	1	1C
0005435423985	5333	2	1A
0005435613028	5333	3	1G
0005432133128	5333	4	1D
0005435613101	5333	5	2A
0005435424021	5333	6	1K
0005435423987	5333	7	1H
0005434244526	5333	8	2C
0005434573275	5333	9	2G
0005435613091	5333	10	3A
0005434573282	5333	11	2K
0005435613108	5333	12	3D
0005435319457	5333	13	3C
0005432133131	5333	14	3K
0005435613033	5333	15	3H
0005434244480	5333	16	3G
0005435613105	5333	17	4C
0005435097164	5333	18	4A
0005435319470	5333	19	4G
0005435423868	5333	20	4D
0005432133127	5333	21	4K
0005435613085	5333	22	4H
0005435302122	5333	23	5D
0005434344041	5333	24	5C
0005434573283	5333	25	5A
0005434344030	5333	26	5H
0005432133135	5333	27	5G
0005433719099	5333	28	5K
0005435613110	5333	29	11D
0005435423653	5333	30	11C
0005435613099	5333	31	11F
0005435424200	5333	32	11E
0005434244598	5333	33	11H
0005435613083	5333	34	11G
0005435423762	5333	35	12C
0005434244635	5333	36	12A
0005435302121	5333	37	11K
0005435613095	5333	38	12E
0005432133141	5333	39	12D
0005435613044	5333	40	12G
0005435423876	5333	41	12F
0005435423763	5333	42	13A
0005435319433	5333	43	12K
0005434244599	5333	44	12H
0005432047529	5333	45	13D
0005435424001	5333	46	13F
0005435423945	5333	47	13E
0005435424017	5333	48	13H
0005435423988	5333	49	13G
0005435613056	5333	50	14A
0005435613076	5333	51	13K
0005434244666	5333	52	14C
0005435423661	5333	53	14G
0005435302123	5333	54	14F
0005434244519	5333	55	14E
0005432363377	5333	56	14H
0005434244620	5333	57	14K
0005435423941	5333	58	15F
0005434244527	5333	59	15D
0005435319460	5333	60	15G
0005435613045	5333	61	15K
0005435555358	5333	62	15H
0005434244625	5333	63	16D
0005434244686	5333	64	16C
0005435423841	5333	65	16F
0005435423758	5333	66	16E
0005434344029	5333	67	16K
0005435613057	5333	68	16H
0005435613063	5333	69	16G
0005435424162	5333	70	17C
0005434244479	5333	71	17A
0005435380232	5333	72	17E
0005434573286	5333	73	17D
0005435319463	5333	74	17F
0005435613097	5333	75	17K
0005435423826	5333	76	17H
0005435613104	5333	77	18A
0005435423654	5333	78	18E
0005435613121	5333	79	18D
0005435302148	5333	80	18C
0005434573285	5333	81	18G
0005432133137	5333	82	18F
0005435423862	5333	83	18J
0005435424037	5333	84	18H
0005435423757	5333	85	19A
0005434244682	5333	86	18K
0005435613020	5333	87	19D
0005435424065	5333	88	19C
0005434244579	5333	89	19B
0005435490209	5333	90	19F
0005432840987	5333	91	19E
0005435319467	5333	92	19G
0005435613122	5333	93	19K
0005435613120	5333	94	19J
0005435613080	5333	95	20C
0005435424040	5333	96	20B
0005432133136	5333	97	20A
0005435424078	5333	98	20E
0005435613062	5333	99	20D
0005435424043	5333	100	20H
0005435423866	5333	101	20G
0005435613092	5333	102	20F
0005434573277	5333	103	20K
0005434344031	5333	104	21D
0005435423744	5333	105	21C
0005435613038	5333	106	21G
0005435613052	5333	107	21F
0005435424029	5333	108	21E
0005435424272	5333	109	21J
0005434244705	5333	110	21H
0005435613087	5333	111	22A
0005434244653	5333	112	21K
0005432133133	5333	113	22D
0005434573274	5333	114	22C
0005435423828	5333	115	22B
0005435423950	5333	116	22F
0005435423702	5333	117	22E
0005434244626	5333	118	22H
0005434573281	5333	119	22K
0005432133139	5333	120	23A
0005434344047	5333	121	23E
0005434344027	5333	122	23D
0005434244516	5333	123	23C
0005435423936	5333	124	23F
0005435380235	5333	125	23H
0005434244547	5333	126	23G
0005434344032	5333	127	24D
0005435613036	5333	128	23K
0005435613106	5333	129	24F
0005435613069	5333	130	24E
0005435423867	5333	131	25B
0005435613111	5333	132	25A
0005434244592	5333	133	24G
0005435423745	5333	134	25C
0005435613077	5333	135	25F
0005435613088	5333	136	25H
0005434344044	5333	137	25G
0005435424038	5333	138	26A
0005435613024	5333	139	25K
0005435423748	5333	140	25J
0005435613064	5333	141	26B
0005434344051	5333	142	26E
0005434244555	5333	143	26D
0005435423848	5333	144	26G
0005435423905	5333	145	26J
0005435613058	5333	146	26H
0005435423939	5333	147	27A
0005435613027	5333	148	26K
0005435613078	5333	149	27D
0005435613103	5333	150	27C
0005434244483	5333	151	27F
0005435097158	5333	152	27E
0005434244515	5333	153	27J
0005434656528	5333	154	27H
0005435613046	5333	155	27G
0005435424234	5333	156	27K
0005435613117	5333	157	28B
0005435423937	5333	158	28A
0005435613030	5333	159	28E
0005435423810	5333	160	28D
0005435097157	5333	161	28G
0005435613089	5333	162	28F
0005435613032	5333	163	28J
0005434344039	5333	164	28H
0005434344056	5333	165	28K
0005435613075	5333	166	29D
0005435423696	5333	167	29B
0005432840979	5333	168	29F
0005435613094	5333	169	29E
0005434244529	5333	170	29H
0005435613100	5333	171	29G
0005435423723	5333	172	29K
0005432133132	5333	173	29J
0005434344042	5333	174	30B
0005435097160	5333	175	30A
0005432133129	5333	176	30E
0005434344059	5333	177	30D
0005435613026	5333	178	30H
0005435097165	5333	179	30K
0005435613041	5333	180	30J
0005434344036	5333	181	31B
0005435380233	5333	182	31A
0005435097161	5333	183	31C
0005434573276	5333	184	31F
0005435424036	5333	185	31E
0005435424060	5333	186	31H
0005434244593	5333	187	31G
0005435613040	5333	188	32A
0005432133140	5333	189	31K
0005435613031	5333	190	32C
0005435613037	5333	191	32B
0005435613034	5333	192	32D
0005435613084	5333	193	32G
0005435613043	5333	194	32F
0005435613113	5333	195	32K
0005435423906	5333	196	32J
0005435613029	5333	197	32H
0005435097162	5333	198	33A
0005435613081	5333	199	33C
0005435424236	5333	200	33B
0005434573278	5333	201	33E
0005435423765	5333	202	33J
0005435613079	5333	203	33H
0005434344046	5333	204	33G
0005435613070	5333	205	34A
0005435555357	5333	206	33K
0005434244482	5333	207	34E
0005435423869	5333	208	34D
0005434344043	5333	209	34G
0005435613114	5333	210	34K
0005435423811	5333	211	34J
0005435613066	5333	212	34H
0005435613023	5333	213	35B
0005435423943	5333	214	35A
0005434244562	5333	215	35D
0005435613116	5333	216	35C
0005435613059	5333	217	35F
0005435423787	5333	218	35E
0005435424201	5333	219	35J
0005434244594	5333	220	35H
0005435613124	5333	221	35G
0005435423984	5333	222	36A
0005435613090	5333	223	35K
0005434344058	5333	224	36C
0005435423741	5333	225	36B
0005435613035	5333	226	36H
0005435613086	5333	227	36G
0005435423910	5333	228	36K
0005435613055	5333	229	36J
0005435424019	5333	230	37B
0005435424209	5333	231	37A
0005435423946	5333	232	37E
0005435613082	5333	233	37D
0005434244619	5333	234	37C
0005435613065	5333	235	37F
0005434244548	5333	236	37H
0005434244622	5333	237	37K
0005434244586	5333	238	37J
0005434344054	5333	239	38C
0005435613096	5333	240	38B
0005435613074	5333	241	38K
0005435613072	5333	242	38J
0005434344045	5333	243	38H
0005435613071	5333	244	39A
0005435319455	5333	245	39D
0005434344053	5333	246	39C
0005432047532	5333	247	39B
0005435319430	5333	248	39F
0005435319434	5333	249	39H
0005435424208	5333	250	40A
0005434344049	5333	251	39K
0005434244523	5333	252	39J
0005435613112	5333	253	40C
0005435423725	5333	254	40E
0005435613049	5333	255	40D
0005435423701	5333	256	40F
0005434344024	5333	257	40J
0005432047530	5333	258	40H
0005435613042	5333	259	41A
0005435613047	5333	260	40K
0005435423847	5333	261	41C
0005434344037	5333	262	41B
0005435302147	5333	263	41F
0005434573280	5333	264	41H
0005435613118	5333	265	41G
0005435613039	5333	266	42A
0005435097163	5333	267	41K
0005435613025	5333	268	41J
0005435424018	5333	269	42C
0005432133126	5333	270	42D
0005435613125	5333	271	42G
0005432133134	5333	272	42F
0005435423935	5333	273	42H
0005435613119	5333	274	43B
0005434344040	5333	275	43A
0005434344048	5333	276	42K
0005435423940	5333	277	43D
0005434344050	5333	278	43F
0005435423825	5333	279	43E
0005435304992	5333	280	43J
0005435423875	5333	281	43H
0005435613067	5333	282	43G
0005435380226	5333	283	43K
0005435319464	5333	284	44C
0005435613022	5333	285	44E
0005435490208	5333	286	44D
0005432133138	5333	287	44G
0005435423827	5333	288	44F
0005435613048	5333	289	44J
0005435613021	5333	290	44H
0005435613109	5333	291	45B
0005434244496	5333	292	45C
0005435490210	5333	293	45F
0005435613051	5333	294	45E
0005435613054	5333	295	45H
0005434573284	5333	296	45G
0005435097159	5333	297	45K
0005434344028	5333	298	45J
0005434244531	5333	299	46B
0005434344025	5333	300	46A
0005435613123	5333	301	46D
0005435613061	5333	302	46C
0005435613068	5333	303	46G
0005435424237	5333	304	46F
0005434344057	5333	305	46J
0005434244687	5333	306	46H
0005434573279	5333	307	47C
0005434344035	5333	308	46K
0005435491430	5333	309	47E
0005435319431	5333	310	47D
0005435423983	5333	311	47G
0005434344034	5333	312	47F
0005434344060	5333	313	47K
0005435613073	5333	314	47H
0005434344033	5333	315	48D
0005435613053	5333	316	48C
0005435613050	5333	317	48F
0005435380236	5333	318	48E
0005434344026	5333	319	48H
0005435613098	5333	320	48G
0005434573288	5333	321	49A
0005432047531	5333	322	48K
0005434244704	5333	323	49E
0005432840988	5333	324	49D
0005434244681	5333	325	49C
0005434573287	5333	326	49F
0005434344052	5333	327	49K
0005435613093	5333	328	49H
0005435613102	5333	329	49G
0005435613107	5333	330	50C
0005435613060	5333	331	50A
0005434344055	5333	332	50F
0005435424039	5333	333	50E
0005435423842	5333	334	50D
0005432133130	5333	335	50G
0005435380234	5333	336	50H
0005435424157	5333	337	51F
0005435613115	5333	338	51E
0005435423749	5333	339	51D
0005435424020	5333	340	51G
0005432841003	10924	1	1C
0005435424431	10924	2	1A
0005435612634	10924	3	1G
0005434244824	10924	4	1D
0005435611777	10924	5	1K
0005435612331	10924	6	1H
0005432164998	10924	7	2D
0005434343683	10924	8	2C
0005435611710	10924	9	2H
0005434573171	10924	10	2G
0005435612300	10924	11	3A
0005435424435	10924	12	2K
0005435612161	10924	13	3D
0005435611748	10924	14	3H
0005435612302	10924	15	3G
0005435611946	10924	16	4G
0005434656545	10924	17	4D
0005435612247	10924	18	5A
0005435490175	10924	19	4K
0005434343590	10924	20	5H
0005435424456	10924	21	5G
0005435424452	10924	22	5D
0005435611907	10924	23	11A
0005434244840	10924	24	5K
0005435380266	10924	25	11C
0005435042847	10924	26	11F
0005435042846	10924	27	11E
0005435612156	10924	28	11K
0005434343687	10924	29	11H
0005435424443	10924	30	12A
0005435612038	10924	31	12C
0005435612023	10924	32	13A
0005435612487	10924	33	12K
0005435424490	10924	34	12H
0005435612350	10924	35	13C
0005435612021	10924	36	13F
0005435424447	10924	37	13E
0005434244838	10924	38	13D
0005435424462	10924	39	13K
0005434573159	10924	40	13H
0005432165001	10924	41	14A
0005435611723	10924	42	14D
0005435555341	10924	43	14C
0005435097067	10924	44	14G
0005432165000	10924	45	14E
0005435612455	10924	46	14H
0005435612498	10924	47	14K
0005434244832	10924	48	15E
0005434573160	10924	49	15D
0005434244821	10924	50	15H
0005435304133	10924	51	15G
0005435424455	10924	52	15F
0005435424472	10924	53	15K
0005435424430	10924	54	16C
0005434343647	10924	55	16F
0005434343711	10924	56	16E
0005434656546	10924	57	16K
0005434244841	10924	58	16H
0005435491416	10924	59	16G
0005435611933	10924	60	17A
0005435612482	10924	61	17D
0005434244837	10924	62	17H
0005435424485	10924	63	18B
0005433719126	10924	64	18E
0005435612355	10924	65	18D
0005435319528	10924	66	18C
0005434343692	10924	67	18G
0005435612414	10924	68	18F
0005434244817	10924	69	18J
0005435424450	10924	70	19B
0005435612030	10924	71	19A
0005435555344	10924	72	19C
0005435319530	10924	73	19F
0005434244826	10924	74	19E
0005435424434	10924	75	19D
0005435612015	10924	76	19H
0005434244842	10924	77	19G
0005435611981	10924	78	19K
0005434244830	10924	79	19J
0005435424476	10924	80	20B
0005435612224	10924	81	20A
0005435612351	10924	82	20E
0005435612050	10924	83	20D
0005435611940	10924	84	20G
0005434244827	10924	85	20J
0005435611724	10924	86	20H
0005435424440	10924	87	21B
0005435612394	10924	88	21A
0005434244845	10924	89	21E
0005432841002	10924	90	21D
0005434343682	10924	91	21C
0005435612494	10924	92	21F
0005434244836	10924	93	21J
0005435612210	10924	94	21H
0005434244818	10924	95	21G
0005434343680	10924	96	22A
0005435612126	10924	97	22C
0005435612378	10924	98	22B
0005435612373	10924	99	22E
0005434343723	10924	100	22D
0005435424436	10924	101	22K
0005435424453	10924	102	22J
0005435424487	10924	103	23B
0005434244835	10924	104	23D
0005435380264	10924	105	23C
0005435097054	10924	106	23G
0005435612406	10924	107	23F
0005435424425	10924	108	23E
0005435424474	10924	109	23J
0005435424463	10924	110	23H
0005435611908	10924	111	24D
0005435611944	10924	112	23K
0005435611960	10924	113	24E
0005434343727	10924	114	25B
0005435612488	10924	115	25A
0005434244834	10924	116	24G
0005435612379	10924	117	25D
0005435611789	10924	118	25C
0005435612138	10924	119	25E
0005435097084	10924	120	25H
0005435097077	10924	121	25G
0005435424469	10924	122	25J
0005434573102	10924	123	26C
0005435424439	10924	124	26A
0005435611915	10924	125	26E
0005435424459	10924	126	26D
0005434573123	10924	127	26G
0005435424475	10924	128	26F
0005435612141	10924	129	26J
0005435612290	10924	130	26H
0005435424454	10924	131	27A
0005435319526	10924	132	27C
0005435305005	10924	133	27F
0005435612162	10924	134	27E
0005434343728	10924	135	27D
0005435424464	10924	136	27H
0005434343714	10924	137	27G
0005435611987	10924	138	28A
0005435612052	10924	139	27K
0005435612280	10924	140	28C
0005435612493	10924	141	28B
0005435611901	10924	142	28E
0005435611961	10924	143	28D
0005435617167	10924	144	28G
0005435304132	10924	145	28F
0005435612246	10924	146	28K
0005435612635	10924	147	28J
0005435424471	10924	148	28H
0005435611888	10924	149	29D
0005435612341	10924	150	29C
0005435424480	10924	151	29F
0005435612299	10924	152	29E
0005435612288	10924	153	29H
0005434343837	10924	154	29G
0005435424486	10924	155	29K
0005435042844	10924	156	29J
0005435611919	10924	157	30C
0005434343623	10924	158	30B
0005435612261	10924	159	30A
0005435424479	10924	160	30E
0005434343697	10924	161	30D
0005432165002	10924	162	30H
0005434244843	10924	163	30G
0005435424437	10924	164	30F
0005432363398	10924	165	30K
0005435424461	10924	166	30J
0005435612435	10924	167	31B
0005434343789	10924	168	31A
0005435424449	10924	169	31D
0005435612392	10924	170	31C
0005435424446	10924	171	31E
0005435611988	10924	172	31H
0005435424428	10924	173	31G
0005435611839	10924	174	31K
0005435612170	10924	175	31J
0005434343747	10924	176	32B
0005435097083	10924	177	32A
0005434343750	10924	178	32E
0005435424441	10924	179	32C
0005435424477	10924	180	32G
0005435611775	10924	181	32F
0005435612171	10924	182	32J
0005435424488	10924	183	32H
0005434343746	10924	184	33A
0005434343783	10924	185	32K
0005435424448	10924	186	33D
0005434343752	10924	187	33C
0005435424432	10924	188	33B
0005435424458	10924	189	33F
0005435612352	10924	190	33E
0005435612009	10924	191	33H
0005435611889	10924	192	33G
0005435304136	10924	193	33K
0005435380269	10924	194	33J
0005435612099	10924	195	34C
0005435612139	10924	196	34B
0005434244831	10924	197	34A
0005435555334	10924	198	34E
0005435097091	10924	199	34F
0005434343665	10924	200	34K
0005435612245	10924	201	34J
0005435424473	10924	202	34H
0005435042845	10924	203	35B
0005435319527	10924	204	35A
0005435612712	10924	205	35D
0005434573161	10924	206	35C
0005432363400	10924	207	35G
0005435612024	10924	208	35F
0005435490184	10924	209	35E
0005432166885	10924	210	35H
0005435424483	10924	211	36A
0005435319524	10924	212	35K
0005433719125	10924	213	35J
0005435611902	10924	214	36B
0005435611725	10924	215	36D
0005435555335	10924	216	36H
0005435611982	10924	217	36G
0005435305006	10924	218	36F
0005435424457	10924	219	36J
0005435612142	10924	220	37B
0005435612319	10924	221	37A
0005435612291	10924	222	37D
0005435611932	10924	223	37C
0005434573101	10924	224	37J
0005434343724	10924	225	37H
0005435424466	10924	226	38A
0005435611762	10924	227	37K
0005434244839	10924	228	38C
0005434343624	10924	229	38B
0005434343748	10924	230	38J
0005435424465	10924	231	38H
0005434244819	10924	232	39A
0005434343835	10924	233	38K
0005434343604	10924	234	39D
0005434343686	10924	235	39C
0005435424433	10924	236	39B
0005435612356	10924	237	39F
0005433719124	10924	238	39E
0005435612039	10924	239	39H
0005434573135	10924	240	39G
0005435319525	10924	241	40A
0005433719122	10924	242	39K
0005432363399	10924	243	40C
0005434343702	10924	244	40B
0005434244816	10924	245	40E
0005435424426	10924	246	40D
0005435424445	10924	247	40G
0005435424429	10924	248	40K
0005435424451	10924	249	40J
0005435611832	10924	250	40H
0005435319529	10924	251	41B
0005435424438	10924	252	41A
0005435612330	10924	253	41C
0005434573120	10924	254	41F
0005432164996	10924	255	41J
0005435490174	10924	256	41H
0005435424482	10924	257	41G
0005435424491	10924	258	41K
0005435612442	10924	259	42B
0005435319531	10924	260	42A
0005434244820	10924	261	42E
0005434343696	10924	262	42D
0005435424492	10924	263	42G
0005435380267	10924	264	42F
0005435424427	10924	265	42J
0005434573103	10924	266	43D
0005435617166	10924	267	43C
0005435304135	10924	268	43B
0005435612248	10924	269	43F
0005435612713	10924	270	43E
0005434343798	10924	271	43H
0005434244828	10924	272	43G
0005432166884	10924	273	43K
0005434343729	10924	274	43J
0005435612164	10924	275	44B
0005434244823	10924	276	44D
0005432164995	10924	277	44H
0005435612181	10924	278	44G
0005435612483	10924	279	44K
0005434573170	10924	280	44J
0005435424484	10924	281	45A
0005434343743	10924	282	45C
0005434343836	10924	283	45B
0005432164999	10924	284	45F
0005434343646	10924	285	45G
0005435424444	10924	286	46A
0005435304134	10924	287	45K
0005435612163	10924	288	45J
0005435611729	10924	289	46B
0005434244844	10924	290	46E
0005434244825	10924	291	46G
0005435424478	10924	292	46J
0005434244833	10924	293	46H
0005435612440	10924	294	47A
0005435612305	10924	295	47E
0005435424489	10924	296	47D
0005435424468	10924	297	47G
0005435612554	10924	298	48A
0005435611938	10924	299	47K
0005435380265	10924	300	47H
0005434573167	10924	301	48D
0005434343691	10924	302	48C
0005435424460	10924	303	48F
0005435424481	10924	304	48E
0005434573104	10924	305	48H
0005435424423	10924	306	48G
0005432164997	10924	307	49A
0005435424424	10924	308	48K
0005432166883	10924	309	49E
0005435424467	10924	310	49G
0005435424470	10924	311	49F
0005435612391	10924	312	49K
0005433719123	10924	313	49H
0005434573172	10924	314	50C
0005434244829	10924	315	50A
0005434343608	10924	316	50E
0005435612016	10924	317	50D
0005435380268	10924	318	50G
0005435612010	10924	319	50F
0005434244822	10924	320	50K
0005435612383	10924	321	51F
0005435612711	10924	322	51E
0005435424442	10924	323	51D
0005435617168	10924	324	51G
0005432181612	3382	1	1A
0005433507088	3382	2	1C
0005432459297	3382	3	1F
0005433507093	3382	4	1D
0005434143724	3382	5	2A
0005432181600	3382	6	2D
0005432459091	3382	7	2C
0005432459115	3382	8	2F
0005433633657	3382	9	3A
0005432181607	3382	10	3C
0005433805187	3382	11	3F
0005433805202	3382	12	3D
0005433633635	3382	13	4A
0005433805207	3382	14	4C
0005433633647	3382	15	4F
0005433805201	3382	16	4D
0005432458995	3382	17	5A
0005433633663	3382	18	5D
0005432459213	3382	19	5C
0005433507097	3382	20	6A
0005433805203	3382	21	5F
0005433805196	3382	22	6C
0005433805197	3382	23	6D
0005434143723	3382	24	7A
0005433805198	3382	25	6F
0005433805192	3382	26	7C
0005432181598	3382	27	7D
0005434143720	3382	28	8A
0005433633652	3382	29	7F
0005432459015	3382	30	8C
0005433633643	3382	31	8B
0005433805168	3382	32	8D
0005433633639	3382	33	8E
0005432459233	3382	34	8F
0005433633650	3382	35	9B
0005433805190	3382	36	9A
0005433507086	3382	37	9C
0005433507081	3382	38	9D
0005432458989	3382	39	9E
0005433507091	3382	40	10A
0005433805183	3382	41	9F
0005432458996	3382	42	10B
0005433805178	3382	43	10C
0005433507094	3382	44	10E
0005433805194	3382	45	10D
0005433633661	3382	46	10F
0005433805205	3382	47	11B
0005433633658	3382	48	11A
0005432459274	3382	49	11C
0005432458961	3382	50	11D
0005433805191	3382	51	11E
0005433805170	3382	52	12A
0005433507092	3382	53	11F
0005433633659	3382	54	12C
0005432459199	3382	55	12D
0005433805208	3382	56	12E
0005433805181	3382	57	12F
0005432181604	3382	58	13B
0005432181601	3382	59	13A
0005433805193	3382	60	13C
0005432459173	3382	61	13D
0005433633656	3382	62	13F
0005432181594	3382	63	13E
0005432458991	3382	64	14A
0005432181596	3382	65	14B
0005432181614	3382	66	14C
0005434143718	3382	67	14E
0005432459141	3382	68	14D
0005433633644	3382	69	15A
0005432458990	3382	70	14F
0005432181599	3382	71	15B
0005433805174	3382	72	15C
0005433633641	3382	73	15F
0005433633660	3382	74	15E
0005432459090	3382	75	16A
0005433633645	3382	76	16C
0005433805199	3382	77	16B
0005432459105	3382	78	16D
0005432181610	3382	79	16E
0005432459216	3382	80	16F
0005433805204	3382	81	17B
0005433507080	3382	82	17A
0005433805188	3382	83	17C
0005433633634	3382	84	17D
0005432459016	3382	85	17F
0005433633642	3382	86	17E
0005433633653	3382	87	18A
0005432459206	3382	88	18B
0005432181595	3382	89	18D
0005433805180	3382	90	18C
0005432181603	3382	91	18E
0005433507096	3382	92	18F
0005433805184	3382	93	19C
0005433805171	3382	94	19B
0005433633662	3382	95	19D
0005432181611	3382	96	19E
0005433633654	3382	97	20B
0005433633636	3382	98	20A
0005432459023	3382	99	20C
0005433633651	3382	100	20D
0005432459382	3382	101	20F
0005432459160	3382	102	20E
0005433805172	3382	103	21A
0005433507095	3382	104	21C
0005432458998	3382	105	21B
0005434143717	3382	106	21D
0005433633638	3382	107	21E
0005433805179	3382	108	22A
0005433507077	3382	109	21F
0005432459207	3382	110	22B
0005433633640	3382	111	22D
0005432459246	3382	112	22C
0005433633646	3382	113	22E
0005432459104	3382	114	22F
0005432459159	3382	115	23A
0005432458997	3382	116	23C
0005432181608	3382	117	23B
0005432459012	3382	118	23D
0005433507082	3382	119	23E
0005432181605	3382	120	24A
0005433805195	3382	121	23F
0005432181613	3382	122	24B
0005433805189	3382	123	24C
0005432181602	3382	124	24E
0005434143722	3382	125	24D
0005433805182	3382	126	24F
0005433805176	3382	127	25A
0005433633648	3382	128	25C
0005433805169	3382	129	25B
0005433633664	3382	130	25D
0005432181592	3382	131	25F
0005433805200	3382	132	25E
0005432181606	3382	133	26A
0005432181597	3382	134	26B
0005433633655	3382	135	26D
0005432459347	3382	136	26C
0005434143721	3382	137	26E
0005432181609	3382	138	26F
0005433633633	3382	139	27A
0005433805175	3382	140	27B
0005432459215	3382	141	27D
0005433507083	3382	142	27C
0005432458979	3382	143	27F
0005433507078	3382	144	27E
0005433507084	3382	145	28A
0005432181593	3382	146	28B
0005433633649	3382	147	28D
0005433805173	3382	148	28C
0005433507085	3382	149	28E
0005433805206	3382	150	28F
0005433507089	3382	151	29B
0005432459243	3382	152	29A
0005433805209	3382	153	29C
0005432459078	3382	154	29D
0005434143719	3382	155	29F
0005432459200	3382	156	29E
0005433633665	3382	157	30A
0005433805177	3382	158	30B
0005433507079	3382	159	30D
0005433633637	3382	160	30C
0005433507087	3382	161	30E
0005433805186	3382	162	30F
0005433633632	3382	163	31A
0005433507090	3382	164	31C
0005433805185	3382	165	31B
0005432459346	3382	166	31E
0005433805210	3382	167	31D
0005433633666	3382	168	31F
0005435884484	3381	1	1C
0005435884551	3381	2	1D
0005435884800	3381	3	2C
0005435884636	3381	4	2F
0005435884455	3381	5	3F
0005435884627	3381	6	4D
0005435884558	3381	7	5A
0005435884602	3381	8	5D
0005435884799	3381	9	6A
0005435884697	3381	10	6D
0005435884623	3381	11	8C
0005435884733	3381	12	9C
0005435884743	3381	13	9E
0005435884601	3381	14	10B
0005435884483	3381	15	11A
0005435884740	3381	16	11C
0005435884454	3381	17	11E
0005435884677	3381	18	12A
0005435884668	3381	19	12B
0005435884638	3381	20	12E
0005435884696	3381	21	15A
0005435884481	3381	22	15E
0005435884658	3381	23	16A
0005435884580	3381	24	16B
0005435884814	3381	25	17A
0005435884535	3381	26	16F
0005435884389	3381	27	18A
0005435884713	3381	28	18C
0005435884698	3381	29	21A
0005435884715	3381	30	21D
0005435884615	3381	31	21C
0005435884460	3381	32	21E
0005435884822	3381	33	22D
0005435884736	3381	34	22F
0005435884734	3381	35	24B
0005435884704	3381	36	24F
0005435884659	3381	37	24E
0005435884739	3381	38	25A
0005435884450	3381	39	25D
0005435884823	3381	40	25C
0005435884596	3381	41	26B
0005435884388	3381	42	27B
0005435884595	3381	43	27A
0005435884579	3381	44	28B
0005435884536	3381	45	29A
0005435884526	3381	46	29D
0005435884605	3381	47	29F
0005435884678	3381	48	31A
0005435884614	3381	49	31D
0005435884976	8202	1	1A
0005432042639	8202	2	1C
0005433506878	8202	3	1F
0005432459645	8202	4	2C
0005435884977	8202	5	2F
0005435884994	8202	6	2D
0005435885000	8202	7	3A
0005435884981	8202	8	3C
0005432459605	8202	9	3F
0005435885019	8202	10	3D
0005434326268	8202	11	4A
0005432459631	8202	12	4C
0005432459633	8202	13	4D
0005432459600	8202	14	4F
0005433506979	8202	15	5D
0005432459619	8202	16	5C
0005435884972	8202	17	6A
0005432459634	8202	18	6C
0005432459624	8202	19	6F
0005435885001	8202	20	6D
0005432459626	8202	21	7A
0005433506888	8202	22	7C
0005432042640	8202	23	7F
0005432459597	8202	24	8A
0005435884996	8202	25	8B
0005432459603	8202	26	8C
0005435884980	8202	27	8D
0005432459625	8202	28	9A
0005432459598	8202	29	9B
0005435885013	8202	30	9C
0005433506990	8202	31	9D
0005435884971	8202	32	9F
0005432459646	8202	33	9E
0005433506975	8202	34	10A
0005435884970	8202	35	10B
0005432459647	8202	36	10D
0005432459623	8202	37	10C
0005435884974	8202	38	10E
0005434312310	8202	39	10F
0005433506931	8202	40	11C
0005432042651	8202	41	11B
0005435884991	8202	42	11E
0005435884983	8202	43	11D
0005432459622	8202	44	12A
0005435885012	8202	45	11F
0005435884979	8202	46	12B
0005435884973	8202	47	12C
0005432459627	8202	48	12E
0005435884995	8202	49	12D
0005433506889	8202	50	12F
0005435884987	8202	51	13B
0005433506860	8202	52	13A
0005432459609	8202	53	13C
0005435884992	8202	54	13F
0005435884968	8202	55	13E
0005432459635	8202	56	14A
0005435884998	8202	57	14C
0005432459617	8202	58	14E
0005432042642	8202	59	15A
0005433506971	8202	60	15C
0005435884985	8202	61	15B
0005435885004	8202	62	15D
0005432459643	8202	63	15F
0005432459618	8202	64	15E
0005432459614	8202	65	16B
0005435885006	8202	66	16A
0005432459641	8202	67	16C
0005432459621	8202	68	16F
0005435884997	8202	69	16E
0005432459642	8202	70	16D
0005432459637	8202	71	17B
0005433506972	8202	72	17A
0005433506877	8202	73	17C
0005432042645	8202	74	17D
0005435884986	8202	75	17F
0005433506970	8202	76	17E
0005432459615	8202	77	18A
0005432042647	8202	78	18C
0005435885002	8202	79	18B
0005434312311	8202	80	18E
0005432459602	8202	81	18D
0005435885014	8202	82	18F
0005432042649	8202	83	19B
0005432459616	8202	84	19D
0005432459613	8202	85	19C
0005432459629	8202	86	20B
0005435885008	8202	87	20A
0005432459638	8202	88	20C
0005434312309	8202	89	20E
0005433506982	8202	90	20D
0005435884969	8202	91	20F
0005435885007	8202	92	21B
0005435884990	8202	93	21D
0005432459648	8202	94	21C
0005435885011	8202	95	21E
0005435884975	8202	96	21F
0005435884993	8202	97	22A
0005433506973	8202	98	22C
0005435885010	8202	99	22E
0005435885009	8202	100	22D
0005432459640	8202	101	22F
0005435885003	8202	102	23B
0005432042644	8202	103	23C
0005432459632	8202	104	23D
0005435885016	8202	105	23E
0005432459628	8202	106	24A
0005432459604	8202	107	24B
0005432459611	8202	108	24E
0005432459607	8202	109	24D
0005432459620	8202	110	24F
0005435884984	8202	111	25B
0005432459608	8202	112	25A
0005435885017	8202	113	25C
0005433506989	8202	114	25D
0005432459644	8202	115	25E
0005432459601	8202	116	26A
0005432459630	8202	117	26C
0005432042646	8202	118	26B
0005435884978	8202	119	26E
0005432459636	8202	120	26D
0005432459650	8202	121	27C
0005432459606	8202	122	27E
0005432459599	8202	123	27D
0005432042650	8202	124	27F
0005432042641	8202	125	28C
0005433506943	8202	126	28B
0005432042648	8202	127	28D
0005432042643	8202	128	28E
0005433506906	8202	129	28F
0005433506907	8202	130	29C
0005435884988	8202	131	29B
0005435885020	8202	132	29D
0005435884982	8202	133	29E
0005432459639	8202	134	30A
0005435885015	8202	135	30B
0005432459612	8202	136	30C
0005432459610	8202	137	30E
0005435884999	8202	138	30F
0005432459649	8202	139	31A
0005435884989	8202	140	31C
0005433506969	8202	141	31B
0005435885005	8202	142	31F
0005435885018	8202	143	31E
0005433633337	8206	1	1A
0005433804997	8206	2	2C
0005433804884	8206	3	2A
0005433633282	8206	4	3C
0005433804860	8206	5	3A
0005433804913	8206	6	3F
0005433633308	8206	7	4A
0005433633372	8206	8	6C
0005433633306	8206	9	6F
0005433633340	8206	10	6D
0005433633281	8206	11	7A
0005433633339	8206	12	7C
0005433633230	8206	13	7D
0005433633398	8206	14	8A
0005434143698	8206	15	7F
0005433633426	8206	16	8B
0005433633318	8206	17	8F
0005433804882	8206	18	9B
0005433633328	8206	19	9A
0005433805038	8206	20	9C
0005433804902	8206	21	10A
0005434271288	8206	22	9F
0005433804874	8206	23	10C
0005435854050	8206	24	10E
0005433804983	8206	25	10F
0005433804820	8206	26	11F
0005433633338	8206	27	12E
0005433804929	8206	28	13C
0005433804900	8206	29	13F
0005433633402	8206	30	14A
0005433804880	8206	31	14C
0005433804898	8206	32	14E
0005433804955	8206	33	14F
0005433804933	8206	34	15A
0005433804971	8206	35	15C
0005433633231	8206	36	15F
0005433804901	8206	37	16E
0005433633305	8206	38	17B
0005433804877	8206	39	17C
0005433804878	8206	40	18E
0005433804904	8206	41	18F
0005435854048	8206	42	19E
0005433633397	8206	43	20F
0005433633458	8206	44	21E
0005433633327	8206	45	21F
0005433633434	8206	46	22C
0005433804903	8206	47	23C
0005433804970	8206	48	24E
0005433804998	8206	49	24D
0005433804982	8206	50	24F
0005433633333	8206	51	25A
0005433804810	8206	52	25C
0005433804885	8206	53	25B
0005433633242	8206	54	25F
0005433633459	8206	55	26C
0005433633383	8206	56	27C
0005433805040	8206	57	27E
0005433804809	8206	58	28A
0005435854049	8206	59	28B
0005433804811	8206	60	28D
0005433633437	8206	61	28F
0005433633286	8206	62	29B
0005433633334	8206	63	29A
0005433804999	8206	64	29D
0005433804883	8206	65	29E
0005433633307	8206	66	30D
0005433633243	8206	67	30E
0005433633235	8206	68	31B
0005433804890	8206	69	31C
0005434183559	8208	1	8D
0005434183551	8208	2	11A
0005434183552	8208	3	15D
0005434183558	8208	4	28B
0005433194845	4668	1	1A
0005432382986	4668	2	1C
0005433454866	4668	3	1D
0005432383009	4668	4	1F
0005432727869	4668	5	2A
0005432727879	4668	6	2C
0005432382974	4668	7	2D
0005432383003	4668	8	3A
0005432383010	4668	9	3F
0005432383005	4668	10	4A
0005432383001	4668	11	4C
0005433722190	4668	12	4E
0005432382993	4668	13	4F
0005433453754	4668	14	5A
0005433194848	4668	15	5D
0005432382985	4668	16	5E
0005432383008	4668	17	5F
0005433453753	4668	18	6A
0005432383012	4668	19	6C
0005432382977	4668	20	6E
0005433722196	4668	21	6F
0005432382997	4668	22	7A
0005433194847	4668	23	7C
0005433722194	4668	24	7D
0005432382981	4668	25	7E
0005432382996	4668	26	7F
0005433722189	4668	27	8C
0005433454865	4668	28	8D
0005433722187	4668	29	8E
0005432382994	4668	30	8F
0005432727874	4668	31	9A
0005432727872	4668	32	9C
0005432727877	4668	33	9D
0005432383011	4668	34	9F
0005432382969	4668	35	10C
0005433194843	4668	36	10D
0005432382970	4668	37	10E
0005432727880	4668	38	10F
0005433454863	4668	39	11A
0005432383006	4668	40	11C
0005432727878	4668	41	11D
0005432383007	4668	42	11E
0005432382982	4668	43	11F
0005432382973	4668	44	12A
0005432383002	4668	45	12E
0005432382984	4668	46	12F
0005432382971	4668	47	13A
0005432383000	4668	48	13C
0005433722188	4668	49	13D
0005432382983	4668	50	13E
0005432382998	4668	51	13F
0005432727873	4668	52	14A
0005432382975	4668	53	14C
0005432382995	4668	54	14D
0005433194849	4668	55	14F
0005432727876	4668	56	15A
0005433194846	4668	57	15C
0005433722192	4668	58	15D
0005432382992	4668	59	15E
0005433194850	4668	60	15F
0005432383004	4668	61	16A
0005432382987	4668	62	16C
0005433722195	4668	63	16D
0005433722191	4668	64	16E
0005433194844	4668	65	16F
0005432382991	4668	66	17A
0005433722193	4668	67	17E
0005432382979	4668	68	17F
0005432382988	4668	69	18A
0005432727871	4668	70	18C
0005432382976	4668	71	18D
0005432382978	4668	72	18E
0005432382980	4668	73	18F
0005432727870	4668	74	19A
0005432382990	4668	75	19C
0005432727882	4668	76	19D
0005432727875	4668	77	19E
0005432382999	4668	78	19F
0005432727881	4668	79	20C
0005432382989	4668	80	20D
0005432382972	4668	81	20E
0005433454864	4668	82	20F
0005432382561	30229	1	1C
0005432727793	30229	2	1D
0005432382581	30229	3	1F
0005432382563	30229	4	3A
0005432727794	30229	5	3F
0005432382512	30229	6	4A
0005432382517	30229	7	4D
0005433453730	30229	8	4F
0005433453739	30229	9	5D
0005432727739	30229	10	5F
0005433194824	30229	11	6A
0005432382502	30229	12	6C
0005432382506	30229	13	6D
0005432382527	30229	14	7A
0005432382558	30229	15	8A
0005432727770	30229	16	9A
0005433451599	30229	17	9D
0005433453738	30229	18	9E
0005432382557	30229	19	9F
0005432382546	30229	20	10A
0005432727776	30229	21	10D
0005432382562	30229	22	10E
0005432382598	30229	23	11D
0005432727735	30229	24	12A
0005432382573	30229	25	12C
0005432382488	30229	26	12F
0005433194822	30229	27	13C
0005432382635	30229	28	13A
0005432382643	30229	29	13E
0005432382597	30229	30	13F
0005432727734	30229	31	14A
0005432382590	30229	32	14C
0005432382497	30229	33	14D
0005432382548	30229	34	15A
0005432382514	30229	35	15C
0005432382489	30229	36	15E
0005432382513	30229	37	16A
0005432727744	30229	38	16C
0005432382605	30229	39	17A
0005433453731	30229	40	17F
0005432382498	30229	41	18A
0005432727736	30229	42	18C
0005432382591	30229	43	18D
0005432382547	30229	44	18E
0005432727756	30229	45	19E
0005432727719	30229	46	19F
0005432382528	30229	47	20A
0005432382504	30229	48	20C
0005433194823	30229	49	20D
0005432382524	30229	50	20E
0005435540898	1723	1	1A
0005435540891	1723	2	1C
0005435540904	1723	3	1D
0005435529146	1723	4	1F
0005435540910	1723	5	2A
0005435529165	1723	6	3D
0005435540902	1723	7	4A
0005433516840	1723	8	4C
0005435529155	1723	9	4F
0005435540906	1723	10	5A
0005435540888	1723	11	5C
0005435540895	1723	12	5D
0005435529166	1723	13	5E
0005432294476	1723	14	5F
0005432294474	1723	15	6A
0005435529151	1723	16	6D
0005433516838	1723	17	6E
0005435529157	1723	18	6F
0005435540899	1723	19	7E
0005435540897	1723	20	7F
0005435529147	1723	21	8C
0005435540901	1723	22	8D
0005435529149	1723	23	9A
0005435529145	1723	24	10A
0005435529153	1723	25	10C
0005433516837	1723	26	10D
0005435529156	1723	27	10E
0005433516842	1723	28	11A
0005435540900	1723	29	11D
0005435529164	1723	30	12A
0005435529159	1723	31	12C
0005432924977	1723	32	12F
0005433516843	1723	33	13A
0005435540903	1723	34	13D
0005435540896	1723	35	13F
0005435540889	1723	36	14A
0005435540908	1723	37	14C
0005435529150	1723	38	14D
0005435529162	1723	39	15C
0005435529148	1723	40	15E
0005435529163	1723	41	15F
0005435540894	1723	42	16D
0005435540905	1723	43	16E
0005435529152	1723	44	16F
0005435540907	1723	45	17A
0005433516839	1723	46	17C
0005435529158	1723	47	17D
0005435540892	1723	48	17E
0005435540909	1723	49	17F
0005433516836	1723	50	18A
0005435529154	1723	51	18C
0005435529144	1723	52	18D
0005432294475	1723	53	18F
0005435540890	1723	54	19A
0005433516844	1723	55	19C
0005435529161	1723	56	19D
0005435529160	1723	57	20A
0005435540893	1723	58	20C
0005433516841	1723	59	20D
0005435540692	21998	1	1A
0005435540710	21998	2	1C
0005435540651	21998	3	1F
0005435517640	21998	4	2A
0005433516762	21998	5	2D
0005435517637	21998	6	3C
0005435540796	21998	7	3D
0005435517649	21998	8	3F
0005435540694	21998	9	4A
0005435540752	21998	10	4C
0005435517641	21998	11	4E
0005435517653	21998	12	4F
0005435517710	21998	13	5C
0005435540719	21998	14	5E
0005432925012	21998	15	5F
0005435517652	21998	16	6A
0005435517655	21998	17	6C
0005432925010	21998	18	6E
0005433516793	21998	19	6F
0005435540795	21998	20	7A
0005433516777	21998	21	7C
0005435540667	21998	22	7E
0005433516752	21998	23	7F
0005435540628	21998	24	8A
0005435540753	21998	25	8D
0005435540759	21998	26	8E
0005435540764	21998	27	8F
0005435540650	21998	28	9D
0005435540718	21998	29	9F
0005435517714	21998	30	11A
0005435540668	21998	31	11D
0005435540769	21998	32	11E
0005435517588	21998	33	11F
0005435540765	21998	34	12A
0005435517594	21998	35	12C
0005435540705	21998	36	12E
0005435517709	21998	37	13A
0005435517596	21998	38	13D
0005435540683	21998	39	13E
0005435540640	21998	40	13F
0005435540682	21998	41	14A
0005432925014	21998	42	14C
0005432925011	21998	43	14F
0005435517648	21998	44	15E
0005433516763	21998	45	16C
0005435517654	21998	46	16E
0005435540760	21998	47	17A
0005435540704	21998	48	17F
0005432925013	21998	49	18C
0005435517620	21998	50	18E
0005435540649	21998	51	19A
0005435540691	21998	52	19E
0005435517633	21998	53	19F
0005435540648	21998	54	20E
0005435517636	21998	55	20F
0005432838876	7362	1	1A
0005434458704	7362	2	1D
0005435252420	7362	3	2A
0005432838870	7362	4	2C
0005434664924	7362	5	2D
0005432823437	7362	6	2F
0005435252430	7362	7	3A
0005432073374	7362	8	3C
0005434458708	7362	9	3D
0005432838867	7362	10	3F
0005432838882	7362	11	4A
0005432838880	7362	12	4C
0005434458707	7362	13	4D
0005434458697	7362	14	4E
0005432838892	7362	15	5A
0005432838863	7362	16	5C
0005432838864	7362	17	5D
0005432073372	7362	18	5E
0005432838890	7362	19	5F
0005434458705	7362	20	6C
0005434458694	7362	21	6D
0005435252431	7362	22	6E
0005434458699	7362	23	6F
0005434458706	7362	24	7A
0005435252487	7362	25	7C
0005434458711	7362	26	7D
0005432838866	7362	27	7E
0005432841001	7362	28	7F
0005434458701	7362	29	8A
0005432838872	7362	30	8C
0005434458693	7362	31	8D
0005434458709	7362	32	8E
0005432838883	7362	33	8F
0005435252426	7362	34	9A
0005434458703	7362	35	9C
0005432838886	7362	36	9E
0005432838878	7362	37	10A
0005432823438	7362	38	10C
0005432838888	7362	39	10D
0005432838868	7362	40	10F
0005434458702	7362	41	11A
0005432838893	7362	42	11C
0005432838884	7362	43	11D
0005435252515	7362	44	11E
0005432073373	7362	45	11F
0005432838891	7362	46	12C
0005434458698	7362	47	12D
0005432838869	7362	48	12F
0005435252429	7362	49	13A
0005432838885	7362	50	13C
0005435252448	7362	51	13E
0005432838875	7362	52	13F
0005432073371	7362	53	14A
0005435252441	7362	54	14C
0005432838889	7362	55	14D
0005432838881	7362	56	14F
0005434458691	7362	57	14E
0005435252440	7362	58	15A
0005432838874	7362	59	15C
0005432840999	7362	60	15D
0005435252511	7362	61	15E
0005434458690	7362	62	16A
0005435491414	7362	63	16C
0005434458692	7362	64	16D
0005432838873	7362	65	16E
0005434458695	7362	66	16F
0005432838871	7362	67	17A
0005432838879	7362	68	17C
0005435252442	7362	69	17D
0005434458710	7362	70	17E
0005432838887	7362	71	17F
0005434664923	7362	72	18A
0005435252439	7362	73	18D
0005434664920	7362	74	18E
0005434458700	7362	75	18F
0005432838865	7362	76	19A
0005432838877	7362	77	19D
0005432841000	7362	78	19E
0005435252462	7362	79	19F
0005435252536	7362	80	20A
0005434458696	7362	81	20C
0005435491413	7362	82	20D
0005432838862	7362	83	20E
0005434458469	28932	1	1A
0005432838579	28932	2	1C
0005432838632	28932	3	1D
0005432838678	28932	4	1F
0005435252612	28932	5	2A
0005432838775	28932	6	2C
0005434458522	28932	7	2F
0005432838537	28932	8	3A
0005432838577	28932	9	3C
0005432838561	28932	10	3D
0005434458494	28932	11	3F
0005432838540	28932	12	4A
0005434458537	28932	13	4C
0005434458565	28932	14	4D
0005435252603	28932	15	4E
0005435252604	28932	16	4F
0005432838578	28932	17	5A
0005434458529	28932	18	5C
0005434458536	28932	19	5D
0005434458530	28932	20	5E
0005435252614	28932	21	5F
0005432838558	28932	22	6A
0005434458496	28932	23	6D
0005435252609	28932	24	6E
0005435252602	28932	25	6F
0005432838654	28932	26	7A
0005432823422	28932	27	7C
0005434458444	28932	28	7D
0005432838709	28932	29	7E
0005435252607	28932	30	7F
0005434458592	28932	31	8A
0005432838622	28932	32	8D
0005435252618	28932	33	8E
0005432838668	28932	34	8F
0005432838652	28932	35	9D
0005432838617	28932	36	9E
0005432840983	28932	37	9F
0005435252619	28932	38	10A
0005435491432	28932	39	10C
0005432838653	28932	40	10D
0005435252613	28932	41	10E
0005435252617	28932	42	10F
0005432838697	28932	43	11A
0005432838643	28932	44	11D
0005432838636	28932	45	11E
0005435252616	28932	46	12C
0005432001012	28932	47	12D
0005434458549	28932	48	12E
0005432838691	28932	49	12F
0005432001013	28932	50	13A
0005434458495	28932	51	13C
0005434458540	28932	52	13D
0005432838644	28932	53	13E
0005435252615	28932	54	13F
0005432823423	28932	55	14C
0005434458538	28932	56	14D
0005435252611	28932	57	14E
0005432823429	28932	58	14F
0005434458566	28932	59	15D
0005434458443	28932	60	15E
0005432838633	28932	61	15F
0005435252610	28932	62	16A
0005434458500	28932	63	16C
0005432838655	28932	64	16D
0005434458442	28932	65	16E
0005432838751	28932	66	16F
0005432838713	28932	67	17C
0005434458445	28932	68	17E
0005432838645	28932	69	17F
0005435252605	28932	70	18A
0005432838755	28932	71	18C
0005435252620	28932	72	18D
0005432838756	28932	73	18E
0005434664949	28932	74	18F
0005432838634	28932	75	19A
0005432838538	28932	76	19C
0005432840984	28932	77	19D
0005432838539	28932	78	19E
0005435252606	28932	79	19F
0005432838562	28932	80	20A
0005435491431	28932	81	20C
0005435252608	28932	82	20D
0005434664950	28932	83	20E
0005432823430	28932	84	20F
0005435990589	8809	1	2C
0005434275965	8809	2	5F
0005434275929	8809	3	7A
0005434275968	8809	4	8C
0005434275958	8809	5	10E
0005435990590	8809	6	11E
0005434275951	8809	7	12D
0005434275928	8809	8	13B
0005434275961	8809	9	14E
0005434275969	8809	10	16D
0005435990586	8809	11	17B
0005435990588	8809	12	20F
0005435990587	8809	13	21C
0005434275997	15765	1	5D
0005434276001	15765	2	6C
0005435990519	15765	3	6F
0005435990504	15765	4	8C
0005435990520	15765	5	9A
0005435990541	15765	6	12D
0005434275995	15765	7	12E
0005435990540	15765	8	14B
0005434275999	15765	9	14D
0005434276000	15765	10	14E
0005435990506	15765	11	19F
0005434275996	15765	12	19E
0005434275998	15765	13	20F
0005434276002	15765	14	21B
0005433468286	2082	1	1A
0005433468290	2082	2	1B
0005433468292	2082	3	1C
0005433468287	2082	4	2A
0005432909220	2082	5	2B
0005433468276	2082	6	2C
0005432909196	2082	7	2D
0005432909203	2082	8	3C
0005433468277	2082	9	3D
0005433468285	2082	10	4A
0005432909211	2082	11	4B
0005432909202	2082	12	4C
0005433468278	2082	13	5A
0005433468288	2082	14	5B
0005432909210	2082	15	5D
0005433468279	2082	16	6A
0005433468289	2082	17	6C
0005433468295	2082	18	6D
0005432909190	2082	19	7A
0005433468291	2082	20	7C
0005433468297	2082	21	7D
0005432909191	2082	22	18A
0005432909195	2082	23	18B
0005433468275	2082	24	18C
0005433468280	2082	25	18D
0005433468294	2082	26	19A
0005433468271	2082	27	19C
0005433468283	2082	28	19D
0005432909219	2082	29	20B
0005433468274	2082	30	20C
0005433468296	2082	31	20D
0005432909189	2082	32	21A
0005433468281	2082	33	21B
0005432909201	2082	34	21C
0005433468272	2082	35	22A
0005433468293	2082	36	22B
0005433468273	2082	37	22C
0005433468284	2082	38	22D
0005433468282	2082	39	23A
0005432909216	2082	40	23B
0005434149598	6398	1	1A
0005434149522	6398	2	1C
0005435176614	6398	3	1F
0005435176595	6398	4	1D
0005432360111	6398	5	2A
0005435176731	6398	6	2C
0005432360145	6398	7	2D
0005432360126	6398	8	2F
0005434149552	6398	9	3A
0005432360129	6398	10	3D
0005432360127	6398	11	3C
0005432360103	6398	12	3F
0005432360109	6398	13	4A
0005432360117	6398	14	4C
0005434149660	6398	15	4B
0005432360130	6398	16	4D
0005435176698	6398	17	4E
0005432335967	6398	18	5A
0005435176693	6398	19	5C
0005432360121	6398	20	5D
0005432360143	6398	21	5E
0005432360101	6398	22	6A
0005432360128	6398	23	5F
0005432062199	6398	24	6C
0005432360108	6398	25	6B
0005434149560	6398	26	6F
0005432360119	6398	27	6E
0005432062203	6398	28	7A
0005432062200	6398	29	7B
0005432335970	6398	30	7C
0005432360141	6398	31	7E
0005434149523	6398	32	7D
0005434149532	6398	33	8A
0005435176664	6398	34	7F
0005432335977	6398	35	8B
0005434149535	6398	36	8C
0005432360099	6398	37	8E
0005432335976	6398	38	8D
0005434149533	6398	39	8F
0005435176746	6398	40	9A
0005432363400	6398	41	9B
0005435490175	6398	42	9D
0005432360105	6398	43	9C
0005432360136	6398	44	9E
0005432335978	6398	45	9F
0005432360134	6398	46	10B
0005435176613	6398	47	10C
0005432360106	6398	48	10D
0005432360142	6398	49	11A
0005432360100	6398	50	10E
0005432360113	6398	51	11C
0005435176671	6398	52	11D
0005432360114	6398	53	11F
0005435176670	6398	54	11E
0005434149524	6398	55	12A
0005435176707	6398	56	12C
0005435176708	6398	57	12B
0005435490174	6398	58	12D
0005432335968	6398	59	12E
0005432360138	6398	60	13A
0005432363399	6398	61	12F
0005432062206	6398	62	13B
0005434149569	6398	63	13F
0005435176776	6398	64	14B
0005435176673	6398	65	14A
0005432360104	6398	66	14D
0005432360115	6398	67	14C
0005435176732	6398	68	14E
0005435176626	6398	69	15B
0005432360123	6398	70	15A
0005432360135	6398	71	15C
0005432062201	6398	72	15D
0005435176745	6398	73	15F
0005432360132	6398	74	15E
0005435176730	6398	75	16A
0005432062204	6398	76	16C
0005432335975	6398	77	16D
0005435490184	6398	78	16E
0005435176837	6398	79	17A
0005432360122	6398	80	16F
0005432363398	6398	81	17B
0005432360098	6398	82	17D
0005432360125	6398	83	17C
0005432360112	6398	84	17E
0005432062205	6398	85	18A
0005435176714	6398	86	18B
0005432360131	6398	87	18D
0005435176712	6398	88	18C
0005432335971	6398	89	18E
0005432360139	6398	90	19A
0005432360120	6398	91	19B
0005435176646	6398	92	19D
0005432335973	6398	93	19C
0005432360137	6398	94	19E
0005435176752	6398	95	19F
0005432360116	6398	96	20A
0005432335972	6398	97	20D
0005432360118	6398	98	20C
0005432360144	6398	99	20E
0005435176596	6398	100	20F
0005432360097	6398	101	21B
0005432335974	6398	102	21D
0005434149586	6398	103	21C
0005432360140	6398	104	21E
0005435176694	6398	105	22A
0005435176814	6398	106	21F
0005434149597	6398	107	22B
0005432360107	6398	108	22C
0005432360133	6398	109	22D
0005432335969	6398	110	22E
0005432360110	6398	111	23A
0005432360102	6398	112	22F
0005432062202	6398	113	23B
0005432360124	6398	114	23C
0005434149568	6398	115	23E
0005432359667	21040	1	1A
0005432359794	21040	2	1C
0005432335843	21040	3	1F
0005432359570	21040	4	2A
0005435176928	21040	5	2D
0005434149672	21040	6	2F
0005432359591	21040	7	3A
0005435176931	21040	8	3D
0005434149668	21040	9	3C
0005432359740	21040	10	3F
0005435176940	21040	11	4B
0005432359612	21040	12	4D
0005432359666	21040	13	4C
0005435176948	21040	14	5B
0005435176943	21040	15	5D
0005432359518	21040	16	5C
0005435176929	21040	17	5E
0005435176941	21040	18	6A
0005432359739	21040	19	5F
0005434149673	21040	20	6C
0005432335857	21040	21	6B
0005435176923	21040	22	6D
0005435176947	21040	23	6F
0005435176938	21040	24	6E
0005432335863	21040	25	7B
0005432359837	21040	26	7C
0005435176925	21040	27	7D
0005432359689	21040	28	7F
0005434149669	21040	29	7E
0005432052731	21040	30	8A
0005432335870	21040	31	8B
0005434149667	21040	32	8C
0005432359694	21040	33	8E
0005432359695	21040	34	8D
0005435176924	21040	35	8F
0005435490213	21040	36	9A
0005434149675	21040	37	9C
0005432359915	21040	38	9B
0005432335876	21040	39	9E
0005432359855	21040	40	9D
0005435490212	21040	41	9F
0005432359651	21040	42	10B
0005432359688	21040	43	10D
0005435176937	21040	44	10C
0005435176945	21040	45	11A
0005435176936	21040	46	11B
0005435176935	21040	47	11C
0005432359664	21040	48	11D
0005432359643	21040	49	11F
0005432359815	21040	50	12A
0005432359652	21040	51	12C
0005435723035	21040	52	12B
0005432335877	21040	53	13B
0005432359514	21040	54	13A
0005434149670	21040	55	13C
0005435176946	21040	56	13D
0005435490214	21040	57	13E
0005432359626	21040	58	13F
0005432359675	21040	59	14A
0005432359859	21040	60	14C
0005434149676	21040	61	14B
0005432359858	21040	62	14D
0005432335929	21040	63	14E
0005435176933	21040	64	15A
0005435176950	21040	65	14F
0005432359687	21040	66	15B
0005432359657	21040	67	15D
0005432335883	21040	68	15E
0005435176932	21040	69	16A
0005432359825	21040	70	16C
0005432359685	21040	71	16E
0005432359521	21040	72	16D
0005432052730	21040	73	17B
0005432359702	21040	74	17A
0005432335856	21040	75	17E
0005432359831	21040	76	18A
0005432359788	21040	77	18B
0005435176944	21040	78	18D
0005435176949	21040	79	18C
0005432359724	21040	80	18E
0005432335842	21040	81	18F
0005432359787	21040	82	19A
0005435490215	21040	83	19B
0005434149674	21040	84	19E
0005432359814	21040	85	19D
0005432359723	21040	86	19F
0005432359520	21040	87	20A
0005432359584	21040	88	20C
0005435176926	21040	89	20B
0005435176930	21040	90	20D
0005432359665	21040	91	20E
0005434149671	21040	92	21B
0005432359936	21040	93	21D
0005432359703	21040	94	22A
0005435176934	21040	95	21F
0005432359793	21040	96	22C
0005434149666	21040	97	22F
0005435723036	21040	98	22E
0005435176927	21040	99	23A
0005432359935	21040	100	23B
0005435176939	21040	101	23C
0005432335872	21040	102	23E
0005435490211	21040	103	23D
0005435176942	21040	104	23F
0005434458579	17699	1	1D
0005434458489	17699	2	2A
0005434458553	17699	3	2B
0005434186183	17699	4	2D
0005434448281	17699	5	3A
0005434448272	17699	6	3D
0005434458535	17699	7	4A
0005434458534	17699	8	4C
0005434463906	17699	9	4D
0005434458528	17699	10	5A
0005434186186	17699	11	5B
0005434458578	17699	12	5D
0005434186185	17699	13	6D
0005434458548	17699	14	7A
0005434458569	17699	15	18A
0005434458623	17699	16	18B
0005434448269	17699	17	19A
0005434448267	17699	18	20A
0005434463904	17699	19	20B
0005434186184	17699	20	21C
0005434458571	17699	21	22B
0005434458570	17699	22	23B
0005434186160	29117	1	1A
0005434458691	29117	2	1C
0005434448295	29117	3	1D
0005434458696	29117	4	2A
0005434462779	29117	5	2B
0005434458698	29117	6	2C
0005434458693	29117	7	2D
0005434458705	29117	8	3A
0005434458702	29117	9	3B
0005434462778	29117	10	4A
0005434462776	29117	11	4B
0005434463915	29117	12	4C
0005434458701	29117	13	4D
0005434448294	29117	14	5A
0005434458710	29117	15	5B
0005434458700	29117	16	5C
0005434458711	29117	17	6B
0005434458704	29117	18	6C
0005434186149	29117	19	6D
0005434448293	29117	20	7A
0005434458709	29117	21	7B
0005434186156	29117	22	18A
0005434458708	29117	23	18B
0005434458690	29117	24	18C
0005434463916	29117	25	19A
0005434458699	29117	26	19B
0005434458703	29117	27	20A
0005434458706	29117	28	20B
0005434458694	29117	29	20C
0005434463917	29117	30	20D
0005434186155	29117	31	21A
0005434462777	29117	32	21C
0005434458707	29117	33	22A
0005434186148	29117	34	22B
0005434458695	29117	35	22D
0005434458697	29117	36	23A
0005434458692	29117	37	23B
0005432604088	21455	1	1A
0005432604097	21455	2	1B
0005432604115	21455	3	1C
0005432604122	21455	4	2A
0005432604103	21455	5	2B
0005432604123	21455	6	2C
0005435218102	21455	7	3A
0005432604104	21455	8	3C
0005432604090	21455	9	4B
0005432604093	21455	10	4C
0005432604124	21455	11	4D
0005432604116	21455	12	5B
0005432604101	21455	13	5C
0005432604091	21455	14	5D
0005432604120	21455	15	6A
0005432604121	21455	16	6B
0005432604098	21455	17	6C
0005432604089	21455	18	6D
0005432604119	21455	19	7A
0005432604095	21455	20	7B
0005432604111	21455	21	7C
0005432604112	21455	22	7D
0005432604127	21455	23	18A
0005432604110	21455	24	18B
0005432604100	21455	25	18C
0005432604113	21455	26	19A
0005432604107	21455	27	19C
0005432604125	21455	28	19D
0005432604099	21455	29	20A
0005432604105	21455	30	20B
0005432604117	21455	31	20C
0005432604108	21455	32	20D
0005432604106	21455	33	21A
0005432604094	21455	34	21B
0005432604096	21455	35	21C
0005432604109	21455	36	21D
0005432604092	21455	37	22A
0005432604102	21455	38	22B
0005435218101	21455	39	22C
0005432604126	21455	40	22D
0005432604114	21455	41	23A
0005432604118	21455	42	23B
0005432603686	31699	1	1A
0005432603774	31699	2	1B
0005435221511	31699	3	1C
0005432603767	31699	4	1D
0005432603718	31699	5	2A
0005432603721	31699	6	2C
0005432603789	31699	7	2D
0005432603717	31699	8	3A
0005432603781	31699	9	3D
0005432603733	31699	10	4A
0005432603752	31699	11	4B
0005432603722	31699	12	5C
0005432603939	31699	13	6B
0005432603912	31699	14	6C
0005432603818	31699	15	6D
0005432603716	31699	16	7B
0005432603817	31699	17	7D
0005432603664	31699	18	18A
0005435221512	31699	19	18B
0005432603841	31699	20	19A
0005435221513	31699	21	19B
0005435221051	31699	22	19C
0005435221050	31699	23	19D
0005432603646	31699	24	20A
0005432603773	31699	25	20B
0005432603732	31699	26	21A
0005432603728	31699	27	21B
0005432603731	31699	28	21D
0005432603911	31699	29	22A
0005432603889	31699	30	22B
0005432603890	31699	31	22D
0005432603891	31699	32	23B
0005435904894	18928	1	2B
0005434606791	18928	2	3B
0005434606766	18928	3	4A
0005434606767	18928	4	5B
0005434604877	22372	1	1A
0005434604879	22372	2	1B
0005434606810	22372	3	2A
0005434606809	22372	4	3A
0005434604875	22372	5	3B
0005434604876	22372	6	4A
0005434606811	22372	7	5A
0005434604878	22372	8	4B
0005434606808	22372	9	5B
0005434606806	22372	10	6A
0005434606807	22372	11	6B
0005432219981	422	1	1A
0005432890717	422	2	1C
0005432747375	422	3	1D
0005433293163	422	4	1F
0005433293158	422	5	2A
0005432747346	422	6	2C
0005432890842	422	7	2D
0005432890695	422	8	2F
0005432890741	422	9	3A
0005432747364	422	10	3C
0005432890802	422	11	3D
0005433293167	422	12	3F
0005432747347	422	13	4A
0005432219978	422	14	4D
0005432747338	422	15	4E
0005432890734	422	16	4F
0005433293149	422	17	5A
0005432747348	422	18	5C
0005432219980	422	19	5D
0005432890764	422	20	5E
0005432747363	422	21	5F
0005432747341	422	22	6A
0005432747339	422	23	6C
0005432747340	422	24	6D
0005432747361	422	25	6E
0005433293148	422	26	6F
0005432890693	422	27	7A
0005432890718	422	28	7C
0005432747344	422	29	7D
0005432747343	422	30	7E
0005433875354	422	31	7F
0005432747349	422	32	8A
0005432753282	422	33	8C
0005432747357	422	34	8D
0005432890774	422	35	8E
0005432219983	422	36	8F
0005432890742	422	37	9A
0005432747359	422	38	9C
0005432747377	422	39	9D
0005432890750	422	40	9E
0005432890749	422	41	9F
0005432747373	422	42	10A
0005433293161	422	43	10C
0005432749772	422	44	10D
0005432749773	422	45	10E
0005432747368	422	46	10F
0005432747371	422	47	11A
0005432747374	422	48	11C
0005432747365	422	49	11D
0005432753283	422	50	11E
0005432890773	422	51	11F
0005432747362	422	52	12A
0005433293166	422	53	12C
0005432753281	422	54	12D
0005432747353	422	55	12E
0005432890801	422	56	12F
0005432753280	422	57	13A
0005432747358	422	58	13C
0005432890755	422	59	13D
0005432747376	422	60	13E
0005432747342	422	61	13F
0005432749774	422	62	14A
0005432747369	422	63	14C
0005432747372	422	64	14D
0005432747367	422	65	14E
0005432890818	422	66	14F
0005432747355	422	67	15A
0005432747360	422	68	15C
0005432747345	422	69	15D
0005432890710	422	70	15E
0005432219979	422	71	15F
0005433293165	422	72	16A
0005432747354	422	73	16C
0005432747356	422	74	16D
0005432753279	422	75	16E
0005432747351	422	76	16F
0005432890765	422	77	17A
0005432751505	422	78	17C
0005432219982	422	79	17D
0005432890692	422	80	17E
0005433875353	422	81	17F
0005432747352	422	82	18A
0005432890763	422	83	18C
0005432747337	422	84	18D
0005432890739	422	85	18E
0005432751507	422	86	18F
0005432749771	422	87	19A
0005432890738	422	88	19C
0005432890756	422	89	19D
0005432890696	422	90	19E
0005432751508	422	91	19F
0005432747370	422	92	20A
0005433293162	422	93	20C
0005432747366	422	94	20D
0005432747350	422	95	20E
0005432751506	422	96	20F
0005432890910	12082	1	1A
0005432214792	12082	2	1C
0005433293215	12082	3	1D
0005432746993	12082	4	1F
0005433293213	12082	5	2A
0005432746995	12082	6	2C
0005432890911	12082	7	2D
0005432890919	12082	8	2F
0005432756804	12082	9	3A
0005433293219	12082	10	3C
0005433293212	12082	11	3D
0005432747121	12082	12	3F
0005433293218	12082	13	4A
0005432890920	12082	14	4C
0005432890915	12082	15	4D
0005432749754	12082	16	4E
0005432756790	12082	17	4F
0005432890922	12082	18	5A
0005432746992	12082	19	5C
0005432747076	12082	20	5D
0005433293214	12082	21	5E
0005432747018	12082	22	5F
0005432890918	12082	23	6A
0005433293222	12082	24	6C
0005432890912	12082	25	6D
0005432746967	12082	26	6E
0005432746947	12082	27	6F
0005432756793	12082	28	7A
0005433293211	12082	29	7C
0005432747203	12082	30	7D
0005432747212	12082	31	7E
0005432747078	12082	32	7F
0005432890917	12082	33	8A
0005432747010	12082	34	8C
0005432746927	12082	35	8E
0005432746966	12082	36	8F
0005432746915	12082	37	9A
0005432747075	12082	38	9C
0005433293221	12082	39	9D
0005432747040	12082	40	9E
0005432746994	12082	41	9F
0005432890921	12082	42	10A
0005432756802	12082	43	10C
0005432747120	12082	44	10D
0005432890916	12082	45	10E
0005432747152	12082	46	10F
0005432747050	12082	47	11A
0005433293216	12082	48	11C
0005432890925	12082	49	11D
0005432749762	12082	50	11E
0005432747123	12082	51	11F
0005433293217	12082	52	12A
0005433293223	12082	53	12C
0005433293210	12082	54	12D
0005432746892	12082	55	12E
0005432747027	12082	56	12F
0005432747145	12082	57	13A
0005432214791	12082	58	13C
0005432756803	12082	59	13D
0005432747194	12082	60	13F
0005432890929	12082	61	14A
0005432746948	12082	62	14C
0005432746996	12082	63	14D
0005432747022	12082	64	14E
0005432747213	12082	65	14F
0005432890913	12082	66	15A
0005432746913	12082	67	15C
0005432747146	12082	68	15D
0005432746986	12082	69	15E
0005432756791	12082	70	15F
0005432746914	12082	71	16A
0005432890930	12082	72	16C
0005432890914	12082	73	16E
0005432747119	12082	74	16F
0005432890927	12082	75	17A
0005432747041	12082	76	17C
0005432746984	12082	77	17E
0005432747077	12082	78	17F
0005433875370	12082	79	18A
0005432890923	12082	80	18C
0005433293220	12082	81	18D
0005432890926	12082	82	18E
0005432746985	12082	83	18F
0005432747153	12082	84	19A
0005432747011	12082	85	19C
0005432753255	12082	86	19D
0005432890928	12082	87	19E
0005432747122	12082	88	19F
0005434153527	12082	89	20A
0005432890924	12082	90	20C
0005432747195	12082	91	20D
0005432753278	12082	92	20E
0005433524971	18984	1	1A
0005433533284	18984	2	1B
0005433531269	18984	3	1C
0005433524977	18984	4	3B
0005432927920	18984	5	4B
0005433524973	18984	6	4C
0005433531271	18984	7	5A
0005433524972	18984	8	5D
0005433531272	18984	9	6B
0005433524978	18984	10	6C
0005432927918	18984	11	7A
0005432927919	18984	12	7B
0005433524974	18984	13	7C
0005433533285	18984	14	18A
0005433531270	18984	15	18B
0005433524975	18984	16	18C
0005433533286	18984	17	19B
0005433524970	18984	18	19C
0005433524976	18984	19	19D
0005433524969	18984	20	20A
0005433533283	18984	21	20C
0005433524968	18984	22	20D
0005432927894	18984	23	22A
0005433524908	32485	1	1C
0005433531230	32485	2	1D
0005432927956	32485	3	2A
0005432927959	32485	4	2B
0005433524925	32485	5	5A
0005432927958	32485	6	5B
0005432927955	32485	7	6D
0005433531243	32485	8	7A
0005433524867	32485	9	7C
0005432927954	32485	10	18D
0005433531237	32485	11	19B
0005433531244	32485	12	20B
0005433527202	32485	13	20D
0005433524926	32485	14	21A
0005432927957	32485	15	22A
0005433524868	32485	16	22B
0005433524869	32485	17	22D
0005432121261	5252	1	1D
0005434822884	5252	2	1C
0005434664947	5252	3	1H
0005432396220	5252	4	1G
0005435372232	5252	5	2A
0005432823426	5252	6	2G
0005434822930	5252	7	2D
0005432121258	5252	8	2K
0005434822877	5252	9	2H
0005434822894	5252	10	3D
0005435661895	5252	11	3H
0005435372416	5252	12	3G
0005435372229	5252	13	4C
0005434822915	5252	14	4G
0005434822939	5252	15	4D
0005435149957	5252	16	4H
0005432121265	5252	17	5D
0005434822931	5252	18	5C
0005434822966	5252	19	5H
0005434822899	5252	20	5G
0005435372156	5252	21	11D
0005434822871	5252	22	11C
0005434822962	5252	23	11F
0005434822986	5252	24	11E
0005434822975	5252	25	11K
0005434822923	5252	26	11H
0005432394083	5252	27	11G
0005434828680	5252	28	12A
0005434822900	5252	29	12E
0005434822874	5252	30	12F
0005434822881	5252	31	12K
0005435149958	5252	32	12H
0005435372202	5252	33	13D
0005435372561	5252	34	13H
0005434822978	5252	35	13G
0005434822932	5252	36	14A
0005435372439	5252	37	13K
0005434822889	5252	38	14D
0005434558227	5252	39	14E
0005435149950	5252	40	14H
0005434822997	5252	41	15A
0005434822907	5252	42	15E
0005435386496	5252	43	15D
0005434822977	5252	44	15G
0005432394081	5252	45	15F
0005434822909	5252	46	16A
0005435735082	5252	47	16D
0005434822906	5252	48	16F
0005434822965	5252	49	16G
0005434822890	5252	50	17A
0005434822998	5252	51	17G
0005434822878	5252	52	17K
0005435372201	5252	53	18C
0005434831121	5252	54	18B
0005432121267	5252	55	18E
0005435299704	5252	56	18D
0005434822960	5252	57	18F
0005434822925	5252	58	18J
0005435386497	5252	59	19B
0005434822872	5252	60	18K
0005432823421	5252	61	19D
0005434822970	5252	62	19F
0005434822898	5252	63	19E
0005434822912	5252	64	19J
0005434822885	5252	65	19K
0005435149951	5252	66	20C
0005434822961	5252	67	20B
0005432121262	5252	68	20G
0005434822926	5252	69	20F
0005434822887	5252	70	20K
0005435372560	5252	71	20J
0005434822927	5252	72	20H
0005434822942	5252	73	21A
0005434822987	5252	74	21D
0005435372369	5252	75	21E
0005434822950	5252	76	21J
0005434822893	5252	77	21H
0005434822968	5252	78	22B
0005435372558	5252	79	22D
0005434822895	5252	80	22G
0005435149955	5252	81	22F
0005435178979	5252	82	22J
0005435372588	5252	83	22H
0005435372509	5252	84	23B
0005434822963	5252	85	23A
0005434822905	5252	86	23D
0005434822951	5252	87	23F
0005434822991	5252	88	23E
0005435372435	5252	89	23H
0005435661894	5252	90	23G
0005432394082	5252	91	24D
0005434822922	5252	92	23K
0005434828679	5252	93	24F
0005434822892	5252	94	24E
0005435149956	5252	95	25B
0005434822917	5252	96	25A
0005435372347	5252	97	24G
0005435149954	5252	98	25D
0005434822959	5252	99	25C
0005435304105	5252	100	25E
0005434822958	5252	101	25G
0005434664946	5252	102	25J
0005432121260	5252	103	26C
0005435372147	5252	104	26B
0005434822979	5252	105	26A
0005435149961	5252	106	26D
0005435372629	5252	107	26G
0005434822941	5252	108	26F
0005432121268	5252	109	26K
0005435372423	5252	110	26H
0005432121263	5252	111	27B
0005434822981	5252	112	27E
0005435386469	5252	113	27G
0005435372593	5252	114	27K
0005435386489	5252	115	27J
0005434822883	5252	116	28B
0005434822918	5252	117	28A
0005432121256	5252	118	28E
0005434822985	5252	119	28C
0005435372236	5252	120	28G
0005434822938	5252	121	28F
0005435372340	5252	122	28H
0005434822873	5252	123	29B
0005434822933	5252	124	29A
0005432823419	5252	125	29C
0005434828681	5252	126	29F
0005434558228	5252	127	29G
0005434822879	5252	128	30A
0005435372228	5252	129	30C
0005435372592	5252	130	30B
0005434822901	5252	131	30F
0005435372540	5252	132	30H
0005434822993	5252	133	31B
0005435372517	5252	134	31A
0005435661884	5252	135	31F
0005435372385	5252	136	31E
0005434822869	5252	137	31K
0005432396223	5252	138	32B
0005434822903	5252	139	32A
0005434822886	5252	140	32E
0005434822924	5252	141	32D
0005435299707	5252	142	32G
0005434822957	5252	143	32J
0005434822949	5252	144	33D
0005434822913	5252	145	33C
0005434822990	5252	146	33B
0005435372504	5252	147	33E
0005434822935	5252	148	33G
0005435372361	5252	149	33J
0005434822982	5252	150	34A
0005434822910	5252	151	34E
0005435386488	5252	152	34D
0005432121269	5252	153	34G
0005434822992	5252	154	34F
0005435372449	5252	155	34K
0005434822967	5252	156	34J
0005434822891	5252	157	34H
0005435372363	5252	158	35B
0005434822902	5252	159	35A
0005435372326	5252	160	35C
0005434822995	5252	161	35G
0005434822911	5252	162	35F
0005434822936	5252	163	35H
0005435372206	5252	164	36A
0005434822994	5252	165	35K
0005434822973	5252	166	36C
0005435372227	5252	167	36E
0005434822929	5252	168	36D
0005435149963	5252	169	36J
0005435372516	5252	170	36K
0005434822921	5252	171	37D
0005435386470	5252	172	37C
0005435372157	5252	173	37F
0005434822904	5252	174	37E
0005435386456	5252	175	37H
0005434822947	5252	176	37G
0005434822969	5252	177	38A
0005434822996	5252	178	37K
0005432823417	5252	179	38B
0005434822984	5252	180	38J
0005435149959	5252	181	38H
0005434822870	5252	182	39A
0005434822916	5252	183	38K
0005435372155	5252	184	39D
0005432396221	5252	185	39F
0005434822964	5252	186	39H
0005434822974	5252	187	39G
0005435372329	5252	188	39K
0005434822988	5252	189	40B
0005434831123	5252	190	40H
0005434822989	5252	191	41B
0005432121266	5252	192	41A
0005435372355	5252	193	41D
0005435149952	5252	194	41C
0005435372330	5252	195	41F
0005435372230	5252	196	41E
0005432121257	5252	197	42A
0005435386457	5252	198	41K
0005435386494	5252	199	41J
0005435372444	5252	200	42C
0005435372384	5252	201	42B
0005434822888	5252	202	42E
0005435372426	5252	203	42D
0005434822937	5252	204	42H
0005434822875	5252	205	42G
0005434822948	5252	206	42J
0005435304106	5252	207	43A
0005434822943	5252	208	42K
0005434822954	5252	209	43D
0005435372597	5252	210	43B
0005435178980	5252	211	43F
0005434822952	5252	212	43E
0005435372263	5252	213	43H
0005435304116	5252	214	43G
0005434822945	5252	215	43K
0005434822972	5252	216	43J
0005434822940	5252	217	44B
0005435299710	5252	218	44E
0005435372240	5252	219	44G
0005434822914	5252	220	44F
0005435149953	5252	221	44K
0005434822880	5252	222	44J
0005434822897	5252	223	44H
0005432394084	5252	224	45A
0005435372598	5252	225	45B
0005434822896	5252	226	45D
0005435149962	5252	227	45G
0005434822955	5252	228	45K
0005435372283	5252	229	45J
0005435372339	5252	230	46B
0005434822983	5252	231	46A
0005434822908	5252	232	46E
0005435149960	5252	233	46D
0005435372233	5252	234	46C
0005434822956	5252	235	46F
0005432121264	5252	236	46H
0005434822882	5252	237	47C
0005434822928	5252	238	46K
0005434822971	5252	239	47E
0005434664948	5252	240	47D
0005432121259	5252	241	47K
0005434831122	5252	242	47H
0005435386495	5252	243	48A
0005435372264	5252	244	48E
0005434822946	5252	245	48H
0005435372362	5252	246	48G
0005434822980	5252	247	49C
0005432396222	5252	248	49A
0005435372539	5252	249	48K
0005434822944	5252	250	49E
0005434822920	5252	251	49D
0005435372453	5252	252	49G
0005432823420	5252	253	49F
0005435386471	5252	254	49K
0005434822953	5252	255	49H
0005435372239	5252	256	50C
0005434822919	5252	257	50F
0005434822934	5252	258	50G
0005434822876	5252	259	51D
0005434822976	5252	260	51E
0005432823439	9938	1	1A
0005434821680	9938	2	1G
0005434821621	9938	3	2H
0005435372932	9938	4	2G
0005434821634	9938	5	3A
0005434828666	9938	6	3D
0005435372940	9938	7	3H
0005434821984	9938	8	4C
0005434821412	9938	9	4A
0005434821683	9938	10	4G
0005434821548	9938	11	4H
0005432400087	9938	12	5D
0005435372907	9938	13	5C
0005434821651	9938	14	5H
0005435372914	9938	15	5G
0005434822259	9938	16	5K
0005434821917	9938	17	11E
0005434821885	9938	18	11D
0005434822232	9938	19	11C
0005434822430	9938	20	11H
0005435372897	9938	21	12C
0005434821411	9938	22	12D
0005434822355	9938	23	12H
0005435372904	9938	24	12G
0005435372941	9938	25	12F
0005435372923	9938	26	13A
0005434821926	9938	27	13D
0005432396182	9938	28	13C
0005434821743	9938	29	13E
0005432400079	9938	30	13H
0005432396186	9938	31	13G
0005435372953	9938	32	14A
0005434821817	9938	33	14D
0005432203028	9938	34	14K
0005435372947	9938	35	14H
0005434822028	9938	36	15C
0005432203026	9938	37	15A
0005435299750	9938	38	15D
0005434821884	9938	39	15G
0005434822104	9938	40	15K
0005435372910	9938	41	15H
0005434821887	9938	42	16C
0005435372922	9938	43	16H
0005435372902	9938	44	16G
0005434821653	9938	45	17A
0005432203029	9938	46	17D
0005435299753	9938	47	17G
0005435372928	9938	48	17F
0005435372913	9938	49	17E
0005434821960	9938	50	17K
0005434831071	9938	51	17H
0005435372930	9938	52	18A
0005434821652	9938	53	18D
0005435149831	9938	54	18G
0005435302175	9938	55	18K
0005434821852	9938	56	19D
0005434821911	9938	57	19H
0005434821848	9938	58	20A
0005434822233	9938	59	19K
0005435386542	9938	60	19J
0005435299752	9938	61	20C
0005434822203	9938	62	20B
0005434822127	9938	63	20D
0005434822040	9938	64	20F
0005434821327	9938	65	20J
0005434558151	9938	66	21A
0005434821868	9938	67	20K
0005434821745	9938	68	21E
0005435372958	9938	69	21G
0005434821483	9938	70	22A
0005435149881	9938	71	22C
0005434821754	9938	72	22B
0005435735117	9938	73	22D
0005435372933	9938	74	22H
0005434821876	9938	75	22G
0005434822258	9938	76	22F
0005435372912	9938	77	22K
0005435386540	9938	78	23B
0005432203022	9938	79	23D
0005435372920	9938	80	23E
0005434822180	9938	81	23J
0005434822279	9938	82	23K
0005435372906	9938	83	24F
0005432400085	9938	84	24E
0005434822429	9938	85	25B
0005435372898	9938	86	24G
0005435149836	9938	87	25F
0005434821860	9938	88	25E
0005435386541	9938	89	25H
0005435302178	9938	90	25G
0005434822240	9938	91	25K
0005435372935	9938	92	26A
0005435179392	9938	93	26E
0005435299751	9938	94	26D
0005435661915	9938	95	26C
0005435149834	9938	96	26G
0005434822463	9938	97	26F
0005434558152	9938	98	26J
0005434821740	9938	99	26H
0005432396181	9938	100	27B
0005434821898	9938	101	27A
0005434822066	9938	102	27H
0005434821763	9938	103	27G
0005434822016	9938	104	28A
0005434821602	9938	105	27K
0005434822245	9938	106	28B
0005435149890	9938	107	28E
0005434558148	9938	108	28D
0005434821328	9938	109	28G
0005435372899	9938	110	28F
0005434821719	9938	111	28J
0005434822050	9938	112	28H
0005434821588	9938	113	29B
0005435372925	9938	114	28K
0005434821878	9938	115	29C
0005434822185	9938	116	29F
0005434821688	9938	117	29J
0005435372895	9938	118	29H
0005434664936	9938	119	29G
0005434822051	9938	120	30C
0005435372934	9938	121	30B
0005435372901	9938	122	30E
0005435372954	9938	123	30D
0005435372943	9938	124	30F
0005434821953	9938	125	31B
0005435372950	9938	126	31A
0005434821598	9938	127	31F
0005434821317	9938	128	31E
0005434821618	9938	129	31H
0005435372919	9938	130	31G
0005432400078	9938	131	32A
0005435372924	9938	132	31J
0005432203023	9938	133	32B
0005434821476	9938	134	32D
0005435149835	9938	135	32G
0005434822280	9938	136	32F
0005434821912	9938	137	32J
0005435372929	9938	138	32K
0005434821547	9938	139	33C
0005434821670	9938	140	33B
0005435661916	9938	141	33F
0005435372957	9938	142	33E
0005434821504	9938	143	33J
0005434822087	9938	144	33H
0005435149815	9938	145	34C
0005434821517	9938	146	34B
0005434821832	9938	147	34E
0005435372917	9938	148	34D
0005434821573	9938	149	34G
0005434821925	9938	150	34F
0005434821716	9938	151	34K
0005435386543	9938	152	34H
0005434821329	9938	153	35B
0005434821999	9938	154	35A
0005434558145	9938	155	35C
0005434821959	9938	156	35F
0005434821635	9938	157	35J
0005434821755	9938	158	35H
0005434821866	9938	159	36C
0005435372938	9938	160	36B
0005434822005	9938	161	36E
0005434821955	9938	162	36H
0005435372931	9938	163	36F
0005434821961	9938	164	36K
0005434821826	9938	165	36J
0005434821646	9938	166	37A
0005434822322	9938	167	37D
0005434821509	9938	168	37C
0005434821991	9938	169	37F
0005434821482	9938	170	37E
0005435302176	9938	171	37H
0005434822126	9938	172	38A
0005434558147	9938	173	37K
0005434822234	9938	174	37J
0005435372905	9938	175	38C
0005434821816	9938	176	38J
0005435372942	9938	177	38K
0005434821668	9938	178	39C
0005435372937	9938	179	39B
0005435149837	9938	180	39F
0005435149830	9938	181	39D
0005435372952	9938	182	39H
0005434821846	9938	183	39K
0005434822086	9938	184	40B
0005435372915	9938	185	40E
0005435735119	9938	186	40D
0005434821511	9938	187	40J
0005435372926	9938	188	40H
0005435372908	9938	189	41B
0005435372918	9938	190	40K
0005434821790	9938	191	41C
0005435372948	9938	192	41F
0005434558150	9938	193	41E
0005435372945	9938	194	41J
0005434821679	9938	195	41H
0005435372911	9938	196	41G
0005435302173	9938	197	42A
0005434821582	9938	198	41K
0005435149889	9938	199	42C
0005432203025	9938	200	42B
0005434821739	9938	201	42D
0005434822054	9938	202	42H
0005435372956	9938	203	42G
0005435372955	9938	204	42F
0005435386545	9938	205	42J
0005435372900	9938	206	43B
0005435149896	9938	207	43D
0005434821484	9938	208	43E
0005435372939	9938	209	43H
0005435735118	9938	210	43K
0005435302177	9938	211	43J
0005435372916	9938	212	44C
0005434821922	9938	213	44B
0005435372960	9938	214	44E
0005434821998	9938	215	44F
0005435372903	9938	216	44J
0005435372936	9938	217	44H
0005432823440	9938	218	45B
0005435372946	9938	219	45A
0005432203024	9938	220	45D
0005434822000	9938	221	45C
0005435372896	9938	222	45F
0005435372921	9938	223	45H
0005432203027	9938	224	46A
0005434821918	9938	225	46C
0005434821601	9938	226	46G
0005435149797	9938	227	46F
0005434822525	9938	228	46J
0005435372909	9938	229	46H
0005432396185	9938	230	47A
0005434822272	9938	231	47E
0005434821558	9938	232	47H
0005435372959	9938	233	48A
0005435386544	9938	234	48D
0005434822358	9938	235	48F
0005435372944	9938	236	48K
0005434822268	9938	237	49E
0005435386539	9938	238	49C
0005435149897	9938	239	49G
0005435302174	9938	240	49K
0005435372927	9938	241	49H
0005434822103	9938	242	50A
0005434821510	9938	243	50F
0005434822024	9938	244	50E
0005434821720	9938	245	50D
0005434822160	9938	246	50G
0005435661917	9938	247	50H
0005435372951	9938	248	51F
0005435372949	9938	249	51E
0005435082742	6996	1	1B
0005435790293	6996	2	1C
0005435082745	6996	3	2B
0005435082747	6996	4	5C
0005435082748	6996	5	6A
0005435790292	6996	6	18A
0005435082743	6996	7	18C
0005435082750	6996	8	19B
0005435082744	6996	9	21A
0005435082746	6996	10	21C
0005435082751	6996	11	21D
0005435082749	6996	12	22B
0005435082709	26015	1	1B
0005435790271	26015	2	1C
0005435082654	26015	3	2B
0005435082662	26015	4	2C
0005435082670	26015	5	2D
0005435082663	26015	6	3B
0005435082676	26015	7	4D
0005435790270	26015	8	5D
0005435082699	26015	9	7C
0005435082668	26015	10	7D
0005435790274	26015	11	18B
0005435082700	26015	12	21A
0005435790275	26015	13	21D
0005434756222	9523	1	1A
0005434213963	9523	2	1C
0005434756208	9523	3	1D
0005434756207	9523	4	2A
0005434756229	9523	5	2C
0005434213861	9523	6	2D
0005434213919	9523	7	2F
0005434756202	9523	8	3A
0005434213802	9523	9	3D
0005434213760	9523	10	3F
0005434756212	9523	11	4A
0005434756230	9523	12	4D
0005434213821	9523	13	4E
0005434213877	9523	14	4F
0005434213759	9523	15	5A
0005434756204	9523	16	5C
0005434213838	9523	17	5D
0005434213837	9523	18	5E
0005434213818	9523	19	5F
0005434213867	9523	20	6A
0005434213858	9523	21	6C
0005434213896	9523	22	6D
0005434756225	9523	23	6E
0005434214048	9523	24	6F
0005434756210	9523	25	7A
0005434213964	9523	26	7C
0005434214014	9523	27	7D
0005434756231	9523	28	7E
0005434213803	9523	29	7F
0005434214003	9523	30	8A
0005434756206	9523	31	8C
0005434756226	9523	32	8F
0005434213839	9523	33	9A
0005434213761	9523	34	9C
0005434214015	9523	35	9D
0005434213996	9523	36	9E
0005434213842	9523	37	9F
0005434756232	9523	38	10A
0005434756228	9523	39	10C
0005434214106	9523	40	10E
0005434213868	9523	41	10F
0005434213779	9523	42	11A
0005434756203	9523	43	11C
0005434213762	9523	44	11D
0005434756215	9523	45	11F
0005434756218	9523	46	12A
0005434756205	9523	47	12C
0005434213795	9523	48	12D
0005434213905	9523	49	12E
0005434214084	9523	50	12F
0005434213948	9523	51	13A
0005434213999	9523	52	13C
0005434756219	9523	53	13D
0005434756209	9523	54	13E
0005434213965	9523	55	13F
0005434756233	9523	56	14A
0005434756223	9523	57	14C
0005434213790	9523	58	14D
0005434213859	9523	59	14E
0005434213820	9523	60	14F
0005434756211	9523	61	15A
0005434756214	9523	62	15C
0005434213894	9523	63	15F
0005434213719	9523	64	16A
0005434756213	9523	65	16D
0005434213918	9523	66	16E
0005434214016	9523	67	16F
0005434213966	9523	68	17A
0005434213812	9523	69	17C
0005434213720	9523	70	17D
0005434756221	9523	71	17E
0005434213804	9523	72	17F
0005434213893	9523	73	18A
0005434213910	9523	74	18D
0005434756224	9523	75	18E
0005434213997	9523	76	18F
0005434213909	9523	77	19A
0005434213904	9523	78	19C
0005434213895	9523	79	19D
0005434756220	9523	80	19E
0005434756227	9523	81	20C
0005434213773	9523	82	20D
0005434756217	9523	83	20E
0005434756216	9523	84	20F
0005434755869	28589	1	1A
0005434214259	28589	2	1C
0005434214262	28589	3	1D
0005434214233	28589	4	2A
0005434214254	28589	5	2D
0005434214244	28589	6	2F
0005434214250	28589	7	3A
0005434214224	28589	8	3C
0005434214249	28589	9	3D
0005434214243	28589	10	4A
0005434755797	28589	11	4C
0005434214260	28589	12	4D
0005434755773	28589	13	4F
0005434214257	28589	14	5A
0005434214231	28589	15	5F
0005434214230	28589	16	6A
0005434214247	28589	17	6D
0005434214222	28589	18	6E
0005434214226	28589	19	6F
0005434755733	28589	20	7A
0005434214248	28589	21	7C
0005434755874	28589	22	7D
0005434214245	28589	23	7E
0005434214242	28589	24	7F
0005434214263	28589	25	8A
0005434214264	28589	26	8C
0005434214221	28589	27	8D
0005434214229	28589	28	8F
0005434755736	28589	29	9A
0005434755839	28589	30	9C
0005434214234	28589	31	9D
0005434755755	28589	32	9F
0005434214256	28589	33	10C
0005434755729	28589	34	10D
0005434755743	28589	35	10E
0005434755790	28589	36	10F
0005434214266	28589	37	11C
0005434214228	28589	38	11D
0005434214267	28589	39	11E
0005434755782	28589	40	12C
0005434214258	28589	41	12D
0005434214255	28589	42	12F
0005434755866	28589	43	13C
0005434214241	28589	44	13D
0005434214236	28589	45	13E
0005434214261	28589	46	13F
0005434755903	28589	47	14A
0005434755818	28589	48	14C
0005434214239	28589	49	14E
0005434755722	28589	50	14F
0005434214240	28589	51	15A
0005434755875	28589	52	15C
0005434214253	28589	53	15E
0005434755800	28589	54	15F
0005434214268	28589	55	16C
0005434755730	28589	56	16D
0005434214235	28589	57	16E
0005434755843	28589	58	16F
0005434214223	28589	59	17A
0005434755870	28589	60	17D
0005434214225	28589	61	17C
0005434214227	28589	62	17F
0005434214246	28589	63	18A
0005434214251	28589	64	18C
0005434214265	28589	65	18D
0005434214238	28589	66	18E
0005434755816	28589	67	18F
0005434755808	28589	68	19A
0005434214252	28589	69	19C
0005434755724	28589	70	19D
0005434755876	28589	71	19E
0005434214237	28589	72	19F
0005434214232	28589	73	20A
0005434755844	28589	74	20C
0005434755838	28589	75	20D
0005434755873	28589	76	20E
0005434755815	28589	77	20F
0005435100106	10818	1	2A
0005435100109	10818	2	3D
0005435100107	10818	3	5A
0005434760174	10818	4	6D
0005435100108	10818	5	20D
0005434760175	10818	6	22A
0005434760186	31828	1	3D
0005435100079	31828	2	7D
0005434760183	31828	3	18B
0005434760184	31828	4	20C
0005434760185	31828	5	21A
0005434760187	31828	6	22D
0005434639196	2007	1	1A
0005434639210	2007	2	1B
0005434639188	2007	3	1C
0005433202151	2007	4	1D
0005434639192	2007	5	2A
0005434639194	2007	6	2B
0005434639209	2007	7	2C
0005434639206	2007	8	2D
0005434639199	2007	9	3A
0005433202117	2007	10	3B
0005434639189	2007	11	3C
0005434639185	2007	12	4A
0005434639200	2007	13	4C
0005434639195	2007	14	4D
0005433202118	2007	15	5C
0005432290617	2007	16	5D
0005433202181	2007	17	6A
0005434639207	2007	18	6B
0005434639202	2007	19	6C
0005434639183	2007	20	6D
0005434639191	2007	21	7B
0005434639190	2007	22	7C
0005434639198	2007	23	7D
0005434639204	2007	24	18A
0005434639186	2007	25	18B
0005435948324	2007	26	18C
0005433202166	2007	27	18D
0005432290618	2007	28	19A
0005433202133	2007	29	19B
0005433202175	2007	30	19C
0005434639187	2007	31	19D
0005434639197	2007	32	20A
0005433202152	2007	33	20C
0005433202150	2007	34	20D
0005434639203	2007	35	21B
0005435948323	2007	36	21A
0005434639205	2007	37	21C
0005434639208	2007	38	21D
0005432290619	2007	39	22A
0005434639201	2007	40	22B
0005433202149	2007	41	22C
0005434639184	2007	42	22D
0005434639193	2007	43	23A
0005435948322	2007	44	23B
0005434638876	23260	1	1A
0005434638860	23260	2	1B
0005434638964	23260	3	1D
0005434638918	23260	4	2A
0005434638945	23260	5	2B
0005434638970	23260	6	2C
0005433202282	23260	7	2D
0005433202268	23260	8	3A
0005433202279	23260	9	3B
0005435948307	23260	10	3C
0005434638911	23260	11	3D
0005433202270	23260	12	4A
0005434638962	23260	13	4B
0005433202280	23260	14	4C
0005434638963	23260	15	4D
0005434638952	23260	16	5A
0005434638949	23260	17	5B
0005433202278	23260	18	5C
0005434638922	23260	19	5D
0005434638940	23260	20	6A
0005433202272	23260	21	6B
0005434638857	23260	22	6C
0005434638953	23260	23	6D
0005433202277	23260	24	7A
0005434638925	23260	25	7B
0005434638944	23260	26	7C
0005434639011	23260	27	7D
0005434639005	23260	28	18A
0005433202273	23260	29	18B
0005434638880	23260	30	18D
0005434638901	23260	31	19A
0005434638956	23260	32	19B
0005434638980	23260	33	19D
0005433202275	23260	34	20A
0005433202281	23260	35	20B
0005434638967	23260	36	20C
0005434638923	23260	37	20D
0005434639059	23260	38	21A
0005434638912	23260	39	21B
0005433202276	23260	40	21C
0005434638877	23260	41	22A
0005434638888	23260	42	21D
0005433202271	23260	43	22B
0005434638948	23260	44	22C
0005433202274	23260	45	22D
0005434638858	23260	46	23A
0005433202269	23260	47	23B
0005435326595	6058	1	1A
0005435326531	6058	2	1D
0005434600679	6058	3	2A
0005435326547	6058	4	2D
0005435326530	6058	5	2F
0005433531275	6058	6	3A
0005433533287	6058	7	3C
0005434600672	6058	8	3D
0005434600658	6058	9	3F
0005434600669	6058	10	4C
0005435326600	6058	11	4D
0005433533289	6058	12	5A
0005434600674	6058	13	5D
0005432111263	6058	14	5F
0005434600682	6058	15	6C
0005434600675	6058	16	6E
0005433533290	6058	17	7A
0005435326597	6058	18	7C
0005434600665	6058	19	7E
0005434600670	6058	20	8A
0005432111264	6058	21	8C
0005435326598	6058	22	8D
0005433531274	6058	23	8E
0005435326614	6058	24	8F
0005434600660	6058	25	9A
0005433531277	6058	26	9E
0005433531273	6058	27	9F
0005435326548	6058	28	10A
0005435326601	6058	29	10E
0005434600680	6058	30	11A
0005435326563	6058	31	11C
0005435326564	6058	32	11D
0005434600681	6058	33	11F
0005434600671	6058	34	12A
0005434600684	6058	35	12C
0005433533288	6058	36	12F
0005434600662	6058	37	13A
0005434600677	6058	38	13D
0005435326596	6058	39	14A
0005435326556	6058	40	14C
0005434600664	6058	41	14D
0005434600668	6058	42	14E
0005435326535	6058	43	15D
0005434600661	6058	44	15F
0005434600673	6058	45	16F
0005435326567	6058	46	17A
0005434600678	6058	47	17E
0005434600666	6058	48	17F
0005434600659	6058	49	18A
0005434600667	6058	50	18D
0005434600683	6058	51	18E
0005434600685	6058	52	18F
0005434600676	6058	53	19A
0005434600663	6058	54	19E
0005435326582	6058	55	19F
0005435326602	6058	56	20A
0005433531276	6058	57	20E
0005435326677	18604	1	1C
0005435326674	18604	2	2A
0005434600480	18604	3	2C
0005434600430	18604	4	2F
0005433527203	18604	5	3C
0005434600428	18604	6	4A
0005435326679	18604	7	4C
0005435326675	18604	8	4D
0005435326672	18604	9	4E
0005435326669	18604	10	4F
0005433531226	18604	11	5C
0005434600398	18604	12	5D
0005435326678	18604	13	6A
0005434600576	18604	14	6D
0005435326670	18604	15	6E
0005434600534	18604	16	6F
0005433531225	18604	17	7C
0005435326668	18604	18	7E
0005434600426	18604	19	8D
0005434600578	18604	20	8F
0005435326671	18604	21	9E
0005435326680	18604	22	9F
0005434600417	18604	23	10A
0005433531241	18604	24	10C
0005434600501	18604	25	10D
0005434600348	18604	26	10F
0005434600427	18604	27	11A
0005435326676	18604	28	12A
0005433531242	18604	29	11F
0005434600503	18604	30	12E
0005433531234	18604	31	12F
0005434600349	18604	32	13D
0005434600429	18604	33	14D
0005434600432	18604	34	14E
0005434600483	18604	35	15A
0005434600410	18604	36	15E
0005434600475	18604	37	15F
0005434600465	18604	38	16C
0005433531239	18604	39	17E
0005435326667	18604	40	18A
0005435326673	18604	41	18C
0005434600422	18604	42	18D
0005434600484	18604	43	18E
0005434600447	18604	44	18F
0005434600577	18604	45	20A
0005434550907	10569	1	1A
0005434550928	10569	2	1D
0005433180688	10569	3	1F
0005433180687	10569	4	2A
0005434550885	10569	5	2C
0005434550922	10569	6	2D
0005434550876	10569	7	2F
0005434550902	10569	8	3A
0005434558219	10569	9	3C
0005434550903	10569	10	3F
0005434558225	10569	11	4A
0005434550905	10569	12	4C
0005433180700	10569	13	4D
0005433180762	10569	14	4E
0005434550910	10569	15	5A
0005434554052	10569	16	5C
0005434554053	10569	17	5D
0005434550890	10569	18	5E
0005433180697	10569	19	5F
0005434558222	10569	20	6A
0005434550923	10569	21	6C
0005434554051	10569	22	6E
0005433180767	10569	23	6F
0005433180699	10569	24	7A
0005434558223	10569	25	7C
0005433180689	10569	26	7D
0005434550929	10569	27	7E
0005434550918	10569	28	7F
0005434550909	10569	29	8A
0005434550878	10569	30	8C
0005434550926	10569	31	8D
0005433180754	10569	32	8E
0005434550901	10569	33	8F
0005434550898	10569	34	9A
0005434550916	10569	35	9C
0005434550892	10569	36	9D
0005434550884	10569	37	9E
0005433180696	10569	38	9F
0005434550919	10569	39	10A
0005434550917	10569	40	10D
0005434550886	10569	41	10E
0005434550900	10569	42	10F
0005434550896	10569	43	11A
0005434550913	10569	44	11C
0005434550925	10569	45	11D
0005433180725	10569	46	11E
0005434550879	10569	47	11F
0005434550893	10569	48	12A
0005434550930	10569	49	12C
0005434550877	10569	50	12D
0005434550914	10569	51	12E
0005434550927	10569	52	12F
0005434550895	10569	53	13A
0005434550881	10569	54	13C
0005434550883	10569	55	13D
0005434558220	10569	56	13E
0005434550911	10569	57	13F
0005434550882	10569	58	14A
0005433180770	10569	59	14C
0005434550897	10569	60	14D
0005433180698	10569	61	14E
0005434550894	10569	62	14F
0005434550889	10569	63	15D
0005433180830	10569	64	15E
0005434550924	10569	65	15F
0005434550888	10569	66	16A
0005434550908	10569	67	16C
0005434550920	10569	68	16D
0005433180763	10569	69	16E
0005434558226	10569	70	16F
0005434554054	10569	71	17A
0005434550899	10569	72	17C
0005434550912	10569	73	17D
0005434550904	10569	74	17E
0005433180798	10569	75	18A
0005434550887	10569	76	18D
0005433180724	10569	77	18E
0005434550915	10569	78	18F
0005434550891	10569	79	19A
0005434550880	10569	80	19C
0005433180736	10569	81	19D
0005433180737	10569	82	19E
0005434550931	10569	83	19F
0005434550906	10569	84	20A
0005434550921	10569	85	20C
0005434558221	10569	86	20D
0005433180717	10569	87	20E
0005434558224	10569	88	20F
0005433180958	27767	1	1C
0005433180959	27767	2	2D
0005433180984	27767	3	3C
0005433180976	27767	4	4D
0005433180964	27767	5	5E
0005433180979	27767	6	5F
0005433180975	27767	7	6A
0005433180972	27767	8	7A
0005433180978	27767	9	7C
0005433180982	27767	10	8C
0005433180970	27767	11	9C
0005433180962	27767	12	9D
0005433180974	27767	13	9F
0005433180969	27767	14	10C
0005433180961	27767	15	10E
0005433180967	27767	16	11A
0005433180965	27767	17	12D
0005433180973	27767	18	13F
0005433180980	27767	19	14C
0005433180977	27767	20	14D
0005433180960	27767	21	16D
0005433180963	27767	22	18C
0005433180966	27767	23	18D
0005433180968	27767	24	18E
0005433180983	27767	25	18F
0005433180971	27767	26	19D
0005433180981	27767	27	20A
0005434550549	27768	1	1A
0005434550567	27768	2	1C
0005434550316	27768	3	1D
0005434558156	27768	4	1F
0005434550502	27768	5	2A
0005434554041	27768	6	2C
0005434550588	27768	7	2D
0005434550300	27768	8	2F
0005434550504	27768	9	3C
0005434550308	27768	10	3D
0005434550322	27768	11	4A
0005434550387	27768	12	4C
0005434550306	27768	13	4D
0005434558165	27768	14	4F
0005434550583	27768	15	5A
0005434550375	27768	16	5D
0005434550444	27768	17	5E
0005434550573	27768	18	5F
0005434550576	27768	19	6A
0005434558159	27768	20	6C
0005434550376	27768	21	6E
0005434558158	27768	22	6F
0005434550505	27768	23	7E
0005434550803	27768	24	7D
0005434550570	27768	25	7F
0005434558164	27768	26	8D
0005434550299	27768	27	8F
0005434550461	27768	28	9C
0005434550374	27768	29	9E
0005434550380	27768	30	9F
0005434550471	27768	31	10A
0005434550330	27768	32	10C
0005434550439	27768	33	10D
0005434550598	27768	34	11A
0005434550451	27768	35	11C
0005434550599	27768	36	11D
0005434550470	27768	37	11F
0005434550568	27768	38	12C
0005434558157	27768	39	12D
0005434550802	27768	40	13A
0005434550589	27768	41	13E
0005434550412	27768	42	13F
0005434550660	27768	43	14A
0005434550472	27768	44	14C
0005434558155	27768	45	14E
0005434550264	27768	46	15A
0005434550637	27768	47	15C
0005434558139	27768	48	16A
0005434550603	27768	49	16C
0005434550438	27768	50	16E
0005434550314	27768	51	16F
0005434550514	27768	52	17A
0005434550469	27768	53	17C
0005434550309	27768	54	17E
0005434550681	27768	55	17F
0005434550638	27768	56	18A
0005434550315	27768	57	18C
0005434550550	27768	58	18E
0005434550468	27768	59	19D
0005434550329	27768	60	19E
0005434550321	27768	61	19F
0005434550462	27768	62	20C
0005434550445	27768	63	20D
0005433459198	6142	1	1A
0005433459197	6142	2	1B
0005435254435	6142	3	2A
0005433459195	6142	4	2B
0005433459196	6142	5	3A
0005435254434	6142	6	4B
0005435254436	6142	7	6A
0005435254462	19300	1	4B
0005433459181	19300	2	5B
0005433459180	19300	3	6A
0005435437727	6720	1	1A
0005435681911	6720	2	1C
0005435437712	6720	3	1D
0005435681918	6720	4	1F
0005435437743	6720	5	2A
0005435681923	6720	6	2C
0005435437741	6720	7	2D
0005435437767	6720	8	2F
0005435437682	6720	9	3C
0005435437683	6720	10	3D
0005435681895	6720	11	3F
0005435681899	6720	12	4A
0005435681915	6720	13	4C
0005435437729	6720	14	4D
0005435681917	6720	15	4E
0005434828651	6720	16	4F
0005435681898	6720	17	5A
0005435437696	6720	18	5C
0005435681912	6720	19	5D
0005435681932	6720	20	5E
0005435437631	6720	21	5F
0005435437728	6720	22	6C
0005435437634	6720	23	6D
0005435681922	6720	24	6E
0005435681920	6720	25	6F
0005435681926	6720	26	7A
0005432136142	6720	27	7C
0005435681929	6720	28	7D
0005432533243	6720	29	7E
0005435220293	6720	30	7F
0005435681907	6720	31	8A
0005435681924	6720	32	8C
0005435437630	6720	33	8D
0005435681905	6720	34	8E
0005435437701	6720	35	8F
0005435681909	6720	36	9A
0005435437572	6720	37	9C
0005435661914	6720	38	9D
0005435681906	6720	39	9E
0005435681921	6720	40	9F
0005435681902	6720	41	10A
0005435661913	6720	42	10C
0005435681925	6720	43	10D
0005435681892	6720	44	10E
0005432136144	6720	45	10F
0005435220291	6720	46	11A
0005435681897	6720	47	11C
0005435681894	6720	48	11D
0005435437633	6720	49	11E
0005435437641	6720	50	11F
0005435681893	6720	51	12A
0005435437670	6720	52	12C
0005435437687	6720	53	12D
0005435681904	6720	54	12E
0005435220289	6720	55	12F
0005432136143	6720	56	13A
0005435681931	6720	57	13C
0005435220294	6720	58	13D
0005435681891	6720	59	13E
0005435437607	6720	60	13F
0005435681901	6720	61	14A
0005435681930	6720	62	14C
0005435437686	6720	63	14D
0005435437769	6720	64	14E
0005435437655	6720	65	14F
0005432533244	6720	66	15A
0005435437768	6720	67	15C
0005432136141	6720	68	15D
0005434828650	6720	69	15E
0005432136140	6720	70	16A
0005435437658	6720	71	16C
0005435681903	6720	72	16D
0005435681928	6720	73	16E
0005435437632	6720	74	16F
0005435681914	6720	75	17A
0005435681927	6720	76	17C
0005435220290	6720	77	17D
0005435681916	6720	78	17E
0005435437656	6720	79	17F
0005435681933	6720	80	18A
0005435437700	6720	81	18C
0005435630948	6720	82	18D
0005435630949	6720	83	18E
0005435437702	6720	84	18F
0005435681900	6720	85	19A
0005435437642	6720	86	19C
0005435681913	6720	87	19D
0005435681910	6720	88	19E
0005434828649	6720	89	19F
0005435437742	6720	90	20A
0005435681908	6720	91	20C
0005435437730	6720	92	20D
0005435681896	6720	93	20E
0005435681919	6720	94	20F
0005435437835	24571	1	1A
0005435681591	24571	2	1C
0005435681419	24571	3	1D
0005435681423	24571	4	1F
0005435437829	24571	5	2A
0005435220306	24571	6	2C
0005435681515	24571	7	2D
0005435681485	24571	8	2F
0005435681590	24571	9	3A
0005435630924	24571	10	3C
0005435681658	24571	11	3D
0005435681547	24571	12	3F
0005435681507	24571	13	4A
0005435437846	24571	14	4C
0005435220307	24571	15	4D
0005435681552	24571	16	4E
0005435437832	24571	17	4F
0005435681659	24571	18	5A
0005435220309	24571	19	5C
0005434828684	24571	20	5D
0005434828683	24571	21	5E
0005435437844	24571	22	5F
0005435681523	24571	23	6A
0005435437845	24571	24	6C
0005435681606	24571	25	6D
0005435681442	24571	26	6F
0005435437825	24571	27	7D
0005432533276	24571	28	7E
0005435681544	24571	29	7F
0005435681443	24571	30	8A
0005435437840	24571	31	8C
0005435437828	24571	32	8D
0005435437841	24571	33	8E
0005435437824	24571	34	8F
0005435681506	24571	35	9A
0005432305737	24571	36	9C
0005434828682	24571	37	9D
0005435681514	24571	38	9E
0005432533279	24571	39	9F
0005435220489	24571	40	10A
0005435681387	24571	41	10C
0005435681662	24571	42	10D
0005435681607	24571	43	10E
0005435437831	24571	44	10F
0005435437843	24571	45	11A
0005435437847	24571	46	11C
0005435437839	24571	47	11D
0005435437826	24571	48	11E
0005435681564	24571	49	11F
0005432305736	24571	50	12A
0005435630925	24571	51	12C
0005435681422	24571	52	12D
0005432533277	24571	53	12F
0005435219190	24571	54	13A
0005435681656	24571	55	13C
0005435219188	24571	56	13D
0005435437827	24571	57	13E
0005435681633	24571	58	13F
0005435681517	24571	59	14A
0005435681484	24571	60	14D
0005435437834	24571	61	14E
0005435220305	24571	62	14F
0005435661885	24571	63	15A
0005435437830	24571	64	15C
0005435681657	24571	65	15D
0005435681605	24571	66	15E
0005435437837	24571	67	15F
0005435630934	24571	68	16C
0005435219187	24571	69	16D
0005435437836	24571	70	16E
0005435661890	24571	71	16F
0005435437838	24571	72	17C
0005435220310	24571	73	17D
0005432533275	24571	74	17F
0005435437842	24571	75	18A
0005432305735	24571	76	18C
0005432533278	24571	77	18D
0005435681508	24571	78	18E
0005435630937	24571	79	18F
0005435219191	24571	80	19A
0005435681486	24571	81	19C
0005435681646	24571	82	19D
0005435220308	24571	83	19E
0005435219189	24571	84	19F
0005435681549	24571	85	20A
0005435681518	24571	86	20C
0005435437833	24571	87	20D
0005435681524	24571	88	20E
0005435126124	11523	1	2A
0005435126117	11523	2	2D
0005435126147	11523	3	2F
0005435126116	11523	4	3A
0005435105963	11523	5	3C
0005435126132	11523	6	3D
0005435126130	11523	7	3F
0005435126136	11523	8	4A
0005435126128	11523	9	4C
0005435126118	11523	10	4E
0005435126133	11523	11	5C
0005435126145	11523	12	5E
0005435126111	11523	13	5F
0005435558055	11523	14	6C
0005435126134	11523	15	6D
0005435558052	11523	16	6F
0005435558057	11523	17	7A
0005435126112	11523	18	7F
0005435126125	11523	19	8A
0005435126107	11523	20	8E
0005435126120	11523	21	8F
0005435126138	11523	22	9A
0005435126119	11523	23	9C
0005435126121	11523	24	9D
0005435126115	11523	25	9F
0005435558058	11523	26	10A
0005435105964	11523	27	11C
0005435126114	11523	28	11E
0005435126109	11523	29	12C
0005435126113	11523	30	12D
0005435126140	11523	31	12E
0005435126146	11523	32	12F
0005435126143	11523	33	13A
0005435126106	11523	34	14A
0005435126110	11523	35	14C
0005435126144	11523	36	14D
0005435126126	11523	37	15F
0005435126135	11523	38	16C
0005435126123	11523	39	16F
0005435126122	11523	40	17A
0005435126131	11523	41	17E
0005435558053	11523	42	17F
0005435126142	11523	43	18A
0005435126137	11523	44	18D
0005435126127	11523	45	19A
0005435126129	11523	46	19C
0005435126139	11523	47	19D
0005435126141	11523	48	20A
0005435126148	11523	49	20C
0005435126108	11523	50	20D
0005435105962	11523	51	20F
0005435098526	31906	1	1C
0005435125876	31906	2	1F
0005435125819	31906	3	2A
0005435098525	31906	4	3D
0005435125866	31906	5	4A
0005435125778	31906	6	4C
0005435125771	31906	7	4F
0005435105933	31906	8	5A
0005435125776	31906	9	6C
0005435125670	31906	10	6D
0005435125814	31906	11	7A
0005435098523	31906	12	7D
0005435125774	31906	13	8A
0005435125831	31906	14	8E
0005435105935	31906	15	8F
0005435125807	31906	16	9D
0005435125828	31906	17	9F
0005435125772	31906	18	10A
0005435125798	31906	19	10E
0005435125773	31906	20	11A
0005435125750	31906	21	11D
0005435558072	31906	22	11F
0005435126053	31906	23	12A
0005435125808	31906	24	12C
0005435125875	31906	25	12D
0005435125787	31906	26	13A
0005435125830	31906	27	13D
0005435125935	31906	28	13E
0005435125820	31906	29	14C
0005435558073	31906	30	14D
0005435126054	31906	31	14E
0005435125775	31906	32	15E
0005435125777	31906	33	16D
0005435125867	31906	34	16E
0005435125818	31906	35	17A
0005435105936	31906	36	17E
0005435125827	31906	37	18E
0005435125765	31906	38	18F
0005435125939	31906	39	19C
0005435125715	31906	40	19D
0005435125934	31906	41	19E
0005435125681	31906	42	20C
0005435098524	31906	43	20F
0005433397824	13540	1	1C
0005433397794	13540	2	1D
0005433397777	13540	3	2A
0005433397812	13540	4	2C
0005435732139	13540	5	2D
0005433397793	13540	6	2F
0005435732125	13540	7	3C
0005433397782	13540	8	3D
0005433397798	13540	9	3F
0005435732135	13540	10	4A
0005433397804	13540	11	4C
0005433397813	13540	12	4D
0005435732195	13540	13	4F
0005433397802	13540	14	5A
0005435732191	13540	15	5C
0005435732179	13540	16	5D
0005433397784	13540	17	5E
0005433397799	13540	18	6A
0005435732157	13540	19	6E
0005433397796	13540	20	7A
0005433397809	13540	21	7D
0005433397808	13540	22	7E
0005433397783	13540	23	8A
0005433397823	13540	24	8C
0005433397820	13540	25	8D
0005433397780	13540	26	8F
0005433397775	13540	27	9A
0005433397801	13540	28	9C
0005433397814	13540	29	9D
0005433397821	13540	30	10A
0005433397822	13540	31	10C
0005433397806	13540	32	10D
0005433397816	13540	33	10F
0005433397792	13540	34	11A
0005435732134	13540	35	11D
0005433397795	13540	36	11F
0005433397791	13540	37	12A
0005435732182	13540	38	12C
0005435732145	13540	39	12D
0005433397811	13540	40	12F
0005433397781	13540	41	13F
0005433397818	13540	42	14A
0005433397810	13540	43	14C
0005433397819	13540	44	15A
0005435732181	13540	45	15C
0005433397786	13540	46	15D
0005433397825	13540	47	15F
0005433397790	13540	48	16C
0005433397805	13540	49	16E
0005433397807	13540	50	17A
0005435732156	13540	51	17C
0005435732188	13540	52	17D
0005433397803	13540	53	17F
0005433397776	13540	54	18A
0005433397815	13540	55	18C
0005433397779	13540	56	18E
0005433397778	13540	57	18F
0005433397787	13540	58	19A
0005433397785	13540	59	19D
0005433397789	13540	60	19E
0005433397797	13540	61	19F
0005433397788	13540	62	20A
0005433397800	13540	63	20C
0005433397817	13540	64	20D
0005433397530	19384	1	1A
0005433397319	19384	2	1D
0005433397448	19384	3	1F
0005433397350	19384	4	2C
0005433397357	19384	5	2D
0005433397354	19384	6	3C
0005433397387	19384	7	3D
0005433397398	19384	8	3F
0005435732277	19384	9	4D
0005433397375	19384	10	4E
0005433397302	19384	11	4F
0005433397239	19384	12	5A
0005433397457	19384	13	5C
0005433397208	19384	14	5E
0005433397352	19384	15	5F
0005433397363	19384	16	6D
0005435732281	19384	17	6F
0005433397218	19384	18	7A
0005433397431	19384	19	7D
0005433397408	19384	20	7F
0005433397342	19384	21	8D
0005432297264	19384	22	8F
0005433397405	19384	23	9A
0005433397467	19384	24	9C
0005433397552	19384	25	9D
0005433397367	19384	26	9E
0005433397388	19384	27	9F
0005435732279	19384	28	10A
0005433397285	19384	29	10C
0005433397533	19384	30	10D
0005433397508	19384	31	11A
0005432297263	19384	32	10F
0005433397353	19384	33	11E
0005433397425	19384	34	11F
0005433397660	19384	35	12A
0005433397332	19384	36	12C
0005432297262	19384	37	12D
0005433397531	19384	38	12E
0005433397356	19384	39	13C
0005435732278	19384	40	13E
0005433397658	19384	41	13F
0005433397289	19384	42	14A
0005433397659	19384	43	14C
0005433397563	19384	44	14D
0005433397199	19384	45	14F
0005433397179	19384	46	15C
0005433397360	19384	47	15F
0005433397564	19384	48	16A
0005433397286	19384	49	16F
0005433397551	19384	50	17A
0005433397374	19384	51	17C
0005433397572	19384	52	17D
0005433397523	19384	53	18D
0005435732280	19384	54	18E
0005433397430	19384	55	18F
0005433397390	19384	56	19C
0005433397207	19384	57	19D
0005433397362	19384	58	19E
0005433397407	19384	59	19F
0005433397236	19384	60	20C
0005433397351	19384	61	20D
0005433397331	19384	62	20E
0005433397534	19384	63	20F
0005435925207	13159	1	1A
0005435068326	13159	2	1C
0005435068347	13159	3	1D
0005435068378	13159	4	1F
0005435068175	13159	5	2C
0005435068417	13159	6	2D
0005435068279	13159	7	2F
0005435068481	13159	8	3A
0005435068324	13159	9	3C
0005435068327	13159	10	3D
0005435068319	13159	11	3F
0005435925216	13159	12	4C
0005435068278	13159	13	4E
0005435068372	13159	14	4F
0005435068247	13159	15	5A
0005435068328	13159	16	5C
0005435068198	13159	17	5D
0005435068300	13159	18	5E
0005435068280	13159	19	5F
0005435068196	13159	20	6A
0005435068242	13159	21	6C
0005435068433	13159	22	6D
0005435068501	13159	23	6E
0005435068400	13159	24	6F
0005435925206	13159	25	7A
0005435925217	13159	26	7C
0005435925213	13159	27	7D
0005435068432	13159	28	7E
0005435068482	13159	29	7F
0005435925215	13159	30	8A
0005435068195	13159	31	8C
0005435068380	13159	32	8D
0005435068246	13159	33	8E
0005435068337	13159	34	8F
0005435068206	13159	35	9C
0005435068168	13159	36	9D
0005435925205	13159	37	9E
0005435068451	13159	38	10A
0005435068313	13159	39	10C
0005435925211	13159	40	10E
0005435068475	13159	41	10F
0005435068412	13159	42	11A
0005435068205	13159	43	11C
0005435068287	13159	44	12A
0005435068393	13159	45	12E
0005435925218	13159	46	13D
0005435925208	13159	47	13E
0005435068283	13159	48	14A
0005435068318	13159	49	14C
0005435925209	13159	50	14E
0005435068476	13159	51	15A
0005435068416	13159	52	15F
0005435068452	13159	53	16A
0005435068243	13159	54	16D
0005435925214	13159	55	16E
0005435068227	13159	56	16F
0005435068293	13159	57	17A
0005435925210	13159	58	17C
0005435068282	13159	59	17E
0005435068250	13159	60	18A
0005435925212	13159	61	18C
0005435068197	13159	62	18E
0005435068377	13159	63	18F
0005435068439	13159	64	19A
0005435068384	13159	65	19C
0005435925204	13159	66	19D
0005435068500	13159	67	19E
0005435068245	13159	68	19F
0005435068274	13159	69	20A
0005435068352	13159	70	20C
0005435068388	13159	71	20D
0005435925085	15473	1	1A
0005435068783	15473	2	1C
0005435925051	15473	3	1D
0005435068770	15473	4	1F
0005435068768	15473	5	2A
0005435068752	15473	6	2D
0005435068741	15473	7	2F
0005435925075	15473	8	3C
0005435068763	15473	9	3D
0005435068755	15473	10	3F
0005435068756	15473	11	4C
0005435068787	15473	12	4D
0005435068788	15473	13	4E
0005435068750	15473	14	5E
0005435068758	15473	15	5F
0005435068785	15473	16	6F
0005435068767	15473	17	7A
0005435068782	15473	18	7C
0005435068778	15473	19	7D
0005435925115	15473	20	7E
0005435068773	15473	21	7F
0005435068759	15473	22	8A
0005435068777	15473	23	8C
0005435068754	15473	24	8E
0005435068774	15473	25	8F
0005435068762	15473	26	9C
0005435925110	15473	27	9D
0005435068780	15473	28	10A
0005435068781	15473	29	10C
0005435925069	15473	30	10D
0005435068789	15473	31	10E
0005435068748	15473	32	10F
0005435068760	15473	33	11C
0005435068775	15473	34	11D
0005435068746	15473	35	12D
0005435068751	15473	36	12E
0005435925120	15473	37	12F
0005435068765	15473	38	13A
0005435068753	15473	39	13C
0005435925072	15473	40	13D
0005435068790	15473	41	13E
0005435068761	15473	42	13F
0005435068743	15473	43	14A
0005435068757	15473	44	14C
0005435925092	15473	45	14E
0005435068771	15473	46	15A
0005435068745	15473	47	15C
0005435068779	15473	48	15E
0005435068776	15473	49	15F
0005435068749	15473	50	16D
0005435068793	15473	51	16E
0005435925111	15473	52	17A
0005435068784	15473	53	17C
0005435925119	15473	54	17D
0005435068772	15473	55	17F
0005435925098	15473	56	18A
0005435925046	15473	57	18D
0005435068764	15473	58	18F
0005435068791	15473	59	19A
0005435068786	15473	60	19C
0005435068792	15473	61	19D
0005435068747	15473	62	19E
0005435925052	15473	63	19F
0005435068769	15473	64	20C
0005435068742	15473	65	20D
0005435068744	15473	66	20E
0005435068766	15473	67	20F
0005434214295	10700	1	1A
0005434755863	10700	2	1C
0005434214289	10700	3	1D
0005434755735	10700	4	1F
0005434755840	10700	5	2A
0005434214281	10700	6	2C
0005434214282	10700	7	2D
0005434755856	10700	8	2F
0005434214274	10700	9	3A
0005434755721	10700	10	3C
0005434755988	10700	11	3D
0005434214276	10700	12	3F
0005434214298	10700	13	4A
0005434214316	10700	14	4C
0005434214300	10700	15	4D
0005434214309	10700	16	4E
0005434755753	10700	17	4F
0005434214312	10700	18	5A
0005434214287	10700	19	5C
0005434755890	10700	20	5D
0005434755791	10700	21	5E
0005434214315	10700	22	5F
0005434214275	10700	23	6A
0005434214284	10700	24	6C
0005434755959	10700	25	6D
0005434214310	10700	26	6E
0005434214273	10700	27	6F
0005434755864	10700	28	7A
0005434214301	10700	29	7C
0005434755780	10700	30	7D
0005434214283	10700	31	7E
0005434214278	10700	32	7F
0005434755887	10700	33	8C
0005434214314	10700	34	8D
0005434214302	10700	35	8E
0005434214272	10700	36	8F
0005434755919	10700	37	9A
0005434214288	10700	38	9C
0005434755922	10700	39	9D
0005434755720	10700	40	9E
0005434755831	10700	41	9F
0005434214280	10700	42	10C
0005434214285	10700	43	10A
0005434755734	10700	44	10D
0005434755905	10700	45	10E
0005434214293	10700	46	10F
0005434214279	10700	47	11A
0005434214306	10700	48	11C
0005434755710	10700	49	11D
0005434755830	10700	50	11E
0005434755793	10700	51	11F
0005434214313	10700	52	12A
0005434755968	10700	53	12C
0005434755806	10700	54	12D
0005434755906	10700	55	12E
0005434755825	10700	56	12F
0005434214296	10700	57	13A
0005434214297	10700	58	13C
0005434755794	10700	59	13D
0005434755954	10700	60	13E
0005434214305	10700	61	13F
0005434755718	10700	62	14A
0005434214299	10700	63	14C
0005434755779	10700	64	14D
0005434214294	10700	65	14E
0005434755802	10700	66	14F
0005434755850	10700	67	15A
0005434755837	10700	68	15C
0005434755752	10700	69	15D
0005434214303	10700	70	15E
0005434755967	10700	71	15F
0005434755942	10700	72	16A
0005434755803	10700	73	16C
0005434755807	10700	74	16D
0005434214286	10700	75	16E
0005434755960	10700	76	16F
0005434214290	10700	77	17A
0005434214308	10700	78	17C
0005434755857	10700	79	17D
0005434214311	10700	80	17F
0005434755852	10700	81	18A
0005434214269	10700	82	18C
0005434755891	10700	83	18D
0005434755767	10700	84	18E
0005434214291	10700	85	18F
0005434214292	10700	86	19A
0005434214271	10700	87	19C
0005434755849	10700	88	19D
0005434755749	10700	89	19E
0005434214277	10700	90	19F
0005434214270	10700	91	20A
0005434214307	10700	92	20C
0005434214304	10700	93	20D
0005434755958	10700	94	20E
0005434755824	10700	95	20F
0005434213952	28660	1	1A
0005434756189	28660	2	1C
0005434213870	28660	3	1D
0005434213805	28660	4	1F
0005434756187	28660	5	2C
0005434213921	28660	6	2D
0005434756201	28660	7	3A
0005434756195	28660	8	3C
0005434756169	28660	9	3F
0005434213736	28660	10	4A
0005434213871	28660	11	4C
0005434213827	28660	12	4E
0005434756178	28660	13	4F
0005434756193	28660	14	5A
0005434213785	28660	15	5C
0005434213751	28660	16	5D
0005434213840	28660	17	5E
0005434213735	28660	18	5F
0005434213721	28660	19	6A
0005434213728	28660	20	6C
0005434213950	28660	21	6E
0005434213925	28660	22	6F
0005434756196	28660	23	7A
0005434756197	28660	24	7C
0005434213953	28660	25	7D
0005434756180	28660	26	7E
0005434756200	28660	27	7F
0005434213826	28660	28	8A
0005434213797	28660	29	8C
0005434756177	28660	30	8D
0005434213922	28660	31	8E
0005434756181	28660	32	8F
0005434756185	28660	33	9C
0005434213926	28660	34	9D
0005434214026	28660	35	9E
0005434756174	28660	36	9F
0005434213951	28660	37	10A
0005434213872	28660	38	10C
0005434756184	28660	39	10D
0005434213746	28660	40	10E
0005434213753	28660	41	10F
0005434756194	28660	42	11C
0005434213796	28660	43	11D
0005434756179	28660	44	11E
0005434213864	28660	45	11F
0005434213874	28660	46	12A
0005434756175	28660	47	12C
0005434756176	28660	48	12F
0005434756170	28660	49	13A
0005434213860	28660	50	13C
0005434213747	28660	51	13D
0005434213758	28660	52	13E
0005434756188	28660	53	13F
0005434213917	28660	54	14C
0005434213798	28660	55	14D
0005434213992	28660	56	14E
0005434213828	28660	57	14F
0005434756190	28660	58	15A
0005434756198	28660	59	15C
0005434756191	28660	60	15E
0005434756172	28660	61	15F
0005434756171	28660	62	16A
0005434756186	28660	63	16C
0005434756173	28660	64	16D
0005434213726	28660	65	16F
0005434756199	28660	66	17A
0005434213739	28660	67	17D
0005434756168	28660	68	17E
0005434213856	28660	69	17F
0005434213875	28660	70	18A
0005434213916	28660	71	18C
0005434213725	28660	72	18D
0005434756182	28660	73	18E
0005434213765	28660	74	18F
0005434213780	28660	75	19A
0005434756183	28660	76	19E
0005434213744	28660	77	19F
0005434213807	28660	78	20A
0005434213806	28660	79	20C
0005434756192	28660	80	20D
0005434214071	28660	81	20E
0005434213729	28660	82	20F
0005435006899	5482	1	1A
0005435006902	5482	2	1D
0005435039447	5482	3	1C
0005435039437	5482	4	1F
0005435039426	5482	5	2C
0005434229037	5482	6	2A
0005432125415	5482	7	2D
0005432125411	5482	8	3A
0005435006897	5482	9	2F
0005434229000	5482	10	3C
0005435006915	5482	11	3D
0005435039425	5482	12	3F
0005434228994	5482	13	4A
0005434229096	5482	14	4D
0005434229095	5482	15	4C
0005435006898	5482	16	4E
0005435039422	5482	17	5A
0005435039423	5482	18	4F
0005435006914	5482	19	5D
0005435039415	5482	20	5C
0005435039403	5482	21	5E
0005435039414	5482	22	5F
0005435039441	5482	23	6B
0005435006910	5482	24	6A
0005435006909	5482	25	6C
0005435039419	5482	26	6D
0005434229049	5482	27	6F
0005435006918	5482	28	6E
0005435039439	5482	29	7B
0005435006896	5482	30	7A
0005435039407	5482	31	7C
0005435039430	5482	32	7E
0005435039435	5482	33	7D
0005435039400	5482	34	7F
0005435039397	5482	35	8A
0005435006911	5482	36	8B
0005435039420	5482	37	8C
0005435039452	5482	38	8E
0005432125416	5482	39	8D
0005435006917	5482	40	9A
0005434229036	5482	41	8F
0005434228982	5482	42	9B
0005435039411	5482	43	9D
0005434229094	5482	44	9C
0005435006905	5482	45	9F
0005435039453	5482	46	9E
0005435039428	5482	47	10C
0005435039433	5482	48	10B
0005435039434	5482	49	10E
0005435039402	5482	50	10D
0005435039409	5482	51	11A
0005435039408	5482	52	11B
0005435006916	5482	53	11D
0005435039418	5482	54	11C
0005435039410	5482	55	11E
0005435006894	5482	56	11F
0005435006903	5482	57	12B
0005435039417	5482	58	12A
0005435006901	5482	59	12D
0005435039445	5482	60	12C
0005435006900	5482	61	12E
0005435039444	5482	62	12F
0005435039440	5482	63	13A
0005435039401	5482	64	13C
0005435039451	5482	65	13B
0005435039412	5482	66	13D
0005435039406	5482	67	13E
0005435042844	5482	68	13F
0005432125412	5482	69	14A
0005435039460	5482	70	14B
0005432125410	5482	71	14D
0005435039404	5482	72	14E
0005435039424	5482	73	15A
0005435039429	5482	74	14F
0005435039449	5482	75	15C
0005435039456	5482	76	15B
0005435039463	5482	77	15D
0005432125414	5482	78	15E
0005434229009	5482	79	16A
0005435039399	5482	80	15F
0005435006907	5482	81	16B
0005432125409	5482	82	16C
0005435039455	5482	83	16E
0005435042845	5482	84	16D
0005434229063	5482	85	17A
0005435039443	5482	86	16F
0005435039431	5482	87	17B
0005435039421	5482	88	17C
0005435039405	5482	89	17E
0005435039438	5482	90	17D
0005435043281	5482	91	17F
0005432125413	5482	92	18A
0005435042846	5482	93	18D
0005435006893	5482	94	18C
0005435006908	5482	95	18F
0005434229083	5482	96	19B
0005435039458	5482	97	19D
0005435039398	5482	98	19C
0005435039461	5482	99	19E
0005435039446	5482	100	19F
0005434229064	5482	101	20B
0005435039416	5482	102	20A
0005435006913	5482	103	20D
0005435006906	5482	104	20C
0005435039448	5482	105	20E
0005435039457	5482	106	20F
0005435039462	5482	107	21A
0005434229118	5482	108	21B
0005435006912	5482	109	21D
0005435006895	5482	110	21C
0005435039459	5482	111	21E
0005435039432	5482	112	21F
0005434229038	5482	113	22B
0005434229082	5482	114	22A
0005435039454	5482	115	22C
0005435042847	5482	116	22D
0005435006904	5482	117	22F
0005435039442	5482	118	22E
0005435039413	5482	119	23A
0005434229092	5482	120	23B
0005435039450	5482	121	23C
0005435039436	5482	122	23E
0005435039427	5482	123	23D
0005435038771	12963	1	1A
0005435038940	12963	2	1C
0005435006759	12963	3	1D
0005435006653	12963	4	1F
0005435039031	12963	5	2C
0005435006688	12963	6	2A
0005435038960	12963	7	2D
0005434229249	12963	8	2F
0005435006608	12963	9	3C
0005435006781	12963	10	3A
0005432304376	12963	11	3F
0005434229243	12963	12	3D
0005435006709	12963	13	4A
0005435038970	12963	14	4C
0005435006691	12963	15	4B
0005432304380	12963	16	4D
0005435038787	12963	17	4E
0005435038768	12963	18	5A
0005435038927	12963	19	4F
0005435038767	12963	20	5C
0005435038778	12963	21	5B
0005434229250	12963	22	5D
0005435038965	12963	23	5E
0005435039174	12963	24	6A
0005435038808	12963	25	5F
0005435038871	12963	26	6B
0005435038710	12963	27	6C
0005434229258	12963	28	6D
0005435038861	12963	29	6E
0005434229260	12963	30	6F
0005435038735	12963	31	7A
0005435038909	12963	32	7D
0005435038882	12963	33	7C
0005435038895	12963	34	7B
0005435038915	12963	35	7E
0005435006712	12963	36	8A
0005435038955	12963	37	7F
0005435038694	12963	38	8B
0005432304378	12963	39	8C
0005434229265	12963	40	8D
0005435006713	12963	41	8F
0005435038662	12963	42	9A
0005435039231	12963	43	9C
0005435038677	12963	44	9B
0005435038705	12963	45	9D
0005435006749	12963	46	9F
0005435038814	12963	47	10C
0005435038877	12963	48	10B
0005435038800	12963	49	10D
0005435038984	12963	50	10E
0005435006741	12963	51	11B
0005435039037	12963	52	11A
0005435038769	12963	53	11C
0005435038748	12963	54	11E
0005434229253	12963	55	11D
0005434229248	12963	56	11F
0005432304377	12963	57	12A
0005435038850	12963	58	12C
0005434229259	12963	59	12B
0005435006810	12963	60	12D
0005435039038	12963	61	12E
0005435006698	12963	62	13A
0005435039000	12963	63	12F
0005435006765	12963	64	13B
0005434229251	12963	65	13D
0005435039191	12963	66	13E
0005435038950	12963	67	13F
0005434229254	12963	68	14A
0005435038817	12963	69	14B
0005435006699	12963	70	14C
0005435006634	12963	71	14F
0005435038945	12963	72	14E
0005435006663	12963	73	15A
0005435038797	12963	74	15B
0005435038875	12963	75	15C
0005435006669	12963	76	15D
0005434229257	12963	77	15F
0005435006676	12963	78	15E
0005435042823	12963	79	16A
0005435006668	12963	80	16C
0005435038815	12963	81	16B
0005435038872	12963	82	16D
0005435039230	12963	83	16E
0005435038883	12963	84	17A
0005435006690	12963	85	16F
0005434229244	12963	86	17B
0005434229246	12963	87	17C
0005435038676	12963	88	17D
0005435038916	12963	89	17F
0005435039175	12963	90	17E
0005434229261	12963	91	18A
0005435038941	12963	92	18B
0005435006722	12963	93	18D
0005435038884	12963	94	18C
0005435038862	12963	95	18E
0005434229256	12963	96	19B
0005435006677	12963	97	19C
0005435038969	12963	98	19D
0005435006689	12963	99	19F
0005435039049	12963	100	19E
0005435038805	12963	101	20B
0005435039021	12963	102	20A
0005434229264	12963	103	20D
0005434229247	12963	104	20C
0005432304379	12963	105	20E
0005435039090	12963	106	20F
0005434229263	12963	107	21C
0005435038788	12963	108	21B
0005435006654	12963	109	21E
0005435038878	12963	110	21F
0005435038899	12963	111	22B
0005435038690	12963	112	22C
0005435038734	12963	113	22D
0005435039113	12963	114	22E
0005435038959	12963	115	22F
0005435039022	12963	116	23B
0005434229255	12963	117	23A
0005434229245	12963	118	23C
0005434229262	12963	119	23D
0005435039050	12963	120	23F
0005434229252	12963	121	23E
0005434426429	14899	1	1A
0005435902415	14899	2	1D
0005435554123	14899	3	1F
0005434426425	14899	4	2A
0005434426428	14899	5	2C
0005434426431	14899	6	2D
0005434426441	14899	7	3A
0005435902446	14899	8	3D
0005435902418	14899	9	3F
0005434411751	14899	10	4E
0005435902417	14899	11	4F
0005434426418	14899	12	5A
0005434426447	14899	13	5C
0005434426434	14899	14	5D
0005434426446	14899	15	6A
0005434426417	14899	16	6C
0005435902486	14899	17	6D
0005434426430	14899	18	6E
0005434426426	14899	19	6F
0005434426440	14899	20	7C
0005435554116	14899	21	7D
0005434411750	14899	22	8E
0005434426444	14899	23	8F
0005434426438	14899	24	10C
0005434426436	14899	25	10E
0005434426433	14899	26	10F
0005434426419	14899	27	11C
0005435902468	14899	28	11D
0005434426439	14899	29	11F
0005432188588	14899	30	12A
0005435554110	14899	31	12C
0005434411753	14899	32	12E
0005432188586	14899	33	12F
0005435902487	14899	34	13C
0005434426432	14899	35	13D
0005434426427	14899	36	13E
0005434426420	14899	37	14A
0005432188587	14899	38	14C
0005434426445	14899	39	14D
0005435902447	14899	40	14E
0005434426435	14899	41	15A
0005434426422	14899	42	15C
0005435902438	14899	43	15D
0005434426416	14899	44	15F
0005434426443	14899	45	16A
0005435902422	14899	46	16C
0005435902439	14899	47	16E
0005435902498	14899	48	16F
0005434411752	14899	49	17C
0005432188589	14899	50	17D
0005435554117	14899	51	17E
0005434426421	14899	52	18D
0005434426437	14899	53	18F
0005434426423	14899	54	19A
0005435902410	14899	55	19C
0005434426424	14899	56	19F
0005435902470	14899	57	20A
0005434426442	14899	58	20F
0005435902614	20184	1	1A
0005434426254	20184	2	2F
0005434426257	20184	3	3C
0005435902611	20184	4	3D
0005434426181	20184	5	4D
0005434426266	20184	6	4E
0005434426316	20184	7	4F
0005434426258	20184	8	5A
0005434426213	20184	9	5C
0005434426229	20184	10	5E
0005435902618	20184	11	5F
0005435902615	20184	12	6C
0005435902619	20184	13	6E
0005434426182	20184	14	7A
0005434426221	20184	15	7C
0005432059494	20184	16	7E
0005435902610	20184	17	7F
0005435902609	20184	18	8C
0005434426196	20184	19	8E
0005434426131	20184	20	8F
0005434426116	20184	21	9F
0005434426183	20184	22	10A
0005434426222	20184	23	10D
0005435902608	20184	24	10E
0005434426117	20184	25	10F
0005435902620	20184	26	11F
0005435902616	20184	27	12A
0005435902606	20184	28	12C
0005434426218	20184	29	13A
0005435554165	20184	30	13C
0005434426255	20184	31	13D
0005434426250	20184	32	13E
0005435902617	20184	33	14D
0005434426345	20184	34	14E
0005435902605	20184	35	14F
0005434426253	20184	36	15C
0005435554166	20184	37	15F
0005434426246	20184	38	16A
0005434426223	20184	39	16C
0005435902607	20184	40	16D
0005434426252	20184	41	16E
0005434411725	20184	42	17A
0005435902613	20184	43	17C
0005435902603	20184	44	17D
0005434426130	20184	45	18A
0005434426197	20184	46	18D
0005434426247	20184	47	18E
0005435902604	20184	48	18F
0005434426251	20184	49	19C
0005434411715	20184	50	19D
0005435554164	20184	51	19E
0005435902612	20184	52	19F
0005434426219	20184	53	20A
0005434426259	20184	54	20C
0005434426248	20184	55	20F
0005435982023	26496	1	1A
0005433434313	26496	2	1C
0005435982032	26496	3	1D
0005433434242	26496	4	1F
0005433434320	26496	5	2A
0005435982043	26496	6	2C
0005435982015	26496	7	2D
0005433434336	26496	8	2F
0005435982020	26496	9	3A
0005433434312	26496	10	3C
0005433434287	26496	11	3D
0005433434315	26496	12	4A
0005433434330	26496	13	4C
0005435982044	26496	14	4D
0005435982018	26496	15	4E
0005435982021	26496	16	4F
0005435982042	26496	17	5A
0005435982034	26496	18	5E
0005435982051	26496	19	5F
0005435982049	26496	20	6A
0005435982030	26496	21	6D
0005435982046	26496	22	6E
0005435982053	26496	23	6F
0005435982040	26496	24	7C
0005435982026	26496	25	7D
0005433434332	26496	26	8A
0005435982025	26496	27	8D
0005435982033	26496	28	8C
0005433434293	26496	29	8E
0005433434331	26496	30	8F
0005435982022	26496	31	9A
0005433434317	26496	32	9C
0005433434316	26496	33	9D
0005433434314	26496	34	9E
0005435982028	26496	35	9F
0005433434216	26496	36	10A
0005435982029	26496	37	10C
0005435982038	26496	38	10D
0005434270177	26496	39	10F
0005433434319	26496	40	11A
0005435982027	26496	41	11C
0005433434275	26496	42	11D
0005432300231	26496	43	11E
0005433434286	26496	44	12C
0005432300229	26496	45	12D
0005435982047	26496	46	12E
0005433434208	26496	47	12F
0005435982045	26496	48	13A
0005433434333	26496	49	13D
0005432300227	26496	50	13E
0005433434241	26496	51	13F
0005435982050	26496	52	14D
0005435982019	26496	53	14E
0005435982037	26496	54	15A
0005433434267	26496	55	15D
0005432300226	26496	56	15E
0005435982035	26496	57	15F
0005433434321	26496	58	16A
0005435982014	26496	59	16D
0005435982036	26496	60	16E
0005435982031	26496	61	16F
0005435982048	26496	62	17A
0005433434276	26496	63	17C
0005432300228	26496	64	17D
0005433434249	26496	65	18A
0005435982039	26496	66	18C
0005433434251	26496	67	18D
0005435982016	26496	68	18E
0005433434250	26496	69	18F
0005435982024	26496	70	19A
0005433434266	26496	71	19C
0005435982052	26496	72	19E
0005433434327	26496	73	19F
0005432300230	26496	74	20A
0005435982017	26496	75	20C
0005435982041	26496	76	20D
0005433434298	26496	77	20E
0005433434335	26496	78	20F
0005432051113	26725	1	1A
0005433434543	26725	2	1C
0005433434525	26725	3	1D
0005433434536	26725	4	1F
0005433434527	26725	5	2A
0005435981695	26725	6	2C
0005435981883	26725	7	2D
0005435981601	26725	8	3A
0005435981661	26725	9	3C
0005433434530	26725	10	3D
0005435981599	26725	11	3F
0005433434534	26725	12	4A
0005435981744	26725	13	4C
0005435981768	26725	14	4D
0005435981580	26725	15	4E
0005435981598	26725	16	4F
0005433434544	26725	17	5A
0005433434526	26725	18	5C
0005435981672	26725	19	5D
0005434270197	26725	20	5E
0005435981609	26725	21	5F
0005432051114	26725	22	6A
0005433434529	26725	23	6C
0005435981579	26725	24	6D
0005433434547	26725	25	6E
0005433434550	26725	26	6F
0005435981793	26725	27	7A
0005433434528	26725	28	7C
0005435981830	26725	29	7D
0005435981783	26725	30	7E
0005435981593	26725	31	7F
0005433434533	26725	32	8A
0005434269092	26725	33	8D
0005435981701	26725	34	8F
0005435981594	26725	35	8E
0005434271303	26725	36	9A
0005433434553	26725	37	9C
0005435981751	26725	38	9D
0005434271301	26725	39	9E
0005435981642	26725	40	9F
0005435981670	26725	41	10C
0005433434537	26725	42	10D
0005433434538	26725	43	10E
0005433434540	26725	44	10F
0005435981660	26725	45	11A
0005434270195	26725	46	11C
0005435981526	26725	47	11D
0005433434535	26725	48	11E
0005433434532	26725	49	11F
0005433434539	26725	50	12A
0005432051112	26725	51	12D
0005433434551	26725	52	12F
0005433434546	26725	53	13C
0005435981625	26725	54	13E
0005435981677	26725	55	13F
0005435981567	26725	56	14A
0005435981623	26725	57	14C
0005433434548	26725	58	14D
0005435981592	26725	59	14E
0005435981923	26725	60	14F
0005435981595	26725	61	15C
0005434270196	26725	62	15D
0005435981566	26725	63	15F
0005434270198	26725	64	16A
0005433434549	26725	65	16C
0005434271302	26725	66	16D
0005435981574	26725	67	16E
0005433434531	26725	68	16F
0005435981707	26725	69	17A
0005433434545	26725	70	17D
0005435981602	26725	71	17F
0005435981525	26725	72	17E
0005434269093	26725	73	18C
0005435981700	26725	74	18D
0005435981611	26725	75	18E
0005435981699	26725	76	18F
0005433434552	26725	77	19A
0005435981528	26725	78	19D
0005435981745	26725	79	19E
0005435981529	26725	80	19F
0005433434541	26725	81	20A
0005435981669	26725	82	20C
0005435981678	26725	83	20D
0005433434542	26725	84	20E
0005435981626	26725	85	20F
0005432583893	3189	1	1A
0005432583892	3189	2	1B
0005432583898	3189	3	1C
0005432583904	3189	4	1D
0005432216258	3189	5	2A
0005432583895	3189	6	2B
0005432857927	3189	7	2D
0005432583896	3189	8	3A
0005432857906	3189	9	3B
0005432583900	3189	10	3D
0005432216257	3189	11	4A
0005432583917	3189	12	4B
0005432857905	3189	13	4C
0005432583913	3189	14	4D
0005432583906	3189	15	5A
0005432857856	3189	16	5B
0005432857891	3189	17	5C
0005432857897	3189	18	5D
0005432583910	3189	19	6A
0005432583894	3189	20	6B
0005432583901	3189	21	6C
0005432583899	3189	22	6D
0005432857901	3189	23	7A
0005432583909	3189	24	7B
0005432583902	3189	25	7D
0005432583907	3189	26	18B
0005432216256	3189	27	18C
0005432583891	3189	28	18D
0005432583914	3189	29	19B
0005432583897	3189	30	19C
0005432583912	3189	31	20A
0005432857880	3189	32	20B
0005432583903	3189	33	20C
0005432857900	3189	34	21A
0005432583911	3189	35	21B
0005432857857	3189	36	21C
0005432583916	3189	37	21D
0005432857879	3189	38	22A
0005432583915	3189	39	22B
0005432857892	3189	40	22D
0005432583908	3189	41	23A
0005432583905	3189	42	23B
0005432858010	31518	1	1C
0005432583733	31518	2	1D
0005432583703	31518	3	2A
0005432583657	31518	4	2B
0005432583746	31518	5	2D
0005432858007	31518	6	3A
0005432583738	31518	7	3C
0005432583756	31518	8	3D
0005432858004	31518	9	4A
0005432858003	31518	10	4C
0005432857998	31518	11	4D
0005432583714	31518	12	5B
0005432858009	31518	13	5D
0005432858001	31518	14	7A
0005432858008	31518	15	7D
0005432583704	31518	16	18B
0005432583688	31518	17	18D
0005432858006	31518	18	19A
0005432583707	31518	19	19C
0005432858000	31518	20	19D
0005432583713	31518	21	20B
0005432583737	31518	22	20C
0005432583757	31518	23	21D
0005432858005	31518	24	22A
0005432857999	31518	25	22D
0005432858002	31518	26	23A
0005434943301	856	1	2B
0005434943299	856	2	2D
0005434943305	856	3	4D
0005434943303	856	4	7B
0005434943307	856	5	7D
0005434943300	856	6	18D
0005434943298	856	7	19A
0005434943306	856	8	19B
0005433255082	856	9	19D
0005433255083	856	10	20C
0005434943302	856	11	21A
0005433255032	856	12	21B
0005434943304	856	13	21C
0005433255081	856	14	21D
0005433255080	856	15	22D
0005433255029	856	16	23B
0005434943263	16226	1	2A
0005433255092	16226	2	4B
0005433255091	16226	3	6D
0005434943216	16226	4	7A
0005434943218	16226	5	7D
0005433255090	16226	6	18C
0005434943208	16226	7	19C
0005434943207	16226	8	20A
0005433255089	16226	9	20D
0005434943262	16226	10	20C
0005434943258	16226	11	21A
0005433255088	16226	12	21B
0005434943225	16226	13	21C
0005434943236	16226	14	21D
0005434943219	16226	15	22B
0005434943239	16226	16	22D
0005434943257	16226	17	23A
0005433811615	14374	1	1A
0005433367366	21723	1	1A
0005433367276	21723	2	1C
0005435652834	21723	3	1D
0005433367306	21723	4	2A
0005435652829	21723	5	2C
0005435652819	21723	6	2D
0005433367382	21723	7	2F
0005433367372	21723	8	3C
0005435652793	21723	9	3D
0005435652806	21723	10	3F
0005433367383	21723	11	4A
0005435652831	21723	12	4C
0005433367557	21723	13	4D
0005435652808	21723	14	4E
0005435652804	21723	15	4F
0005433367239	21723	16	5A
0005435652823	21723	17	5C
0005435652828	21723	18	5D
0005433367311	21723	19	5E
0005433367259	21723	20	6A
0005433367249	21723	21	6C
0005433367559	21723	22	6D
0005435652821	21723	23	6E
0005433367341	21723	24	6F
0005435652810	21723	25	7A
0005435652796	21723	26	7C
0005433367356	21723	27	7F
0005435652817	21723	28	8A
0005435652830	21723	29	8C
0005435652802	21723	30	8D
0005435652825	21723	31	8E
0005435652827	21723	32	8F
0005433367250	21723	33	9A
0005435652811	21723	34	9C
0005435652795	21723	35	9E
0005433367332	21723	36	9F
0005435652824	21723	37	10A
0005435652820	21723	38	10C
0005435652818	21723	39	10D
0005435652790	21723	40	10E
0005433367304	21723	41	10F
0005435652826	21723	42	11A
0005435652812	21723	43	11C
0005435652815	21723	44	11D
0005435652794	21723	45	11E
0005435652814	21723	46	11F
0005435652798	21723	47	12A
0005433367244	21723	48	12C
0005435652799	21723	49	12E
0005435652801	21723	50	12D
0005435652788	21723	51	12F
0005435652809	21723	52	13A
0005435652791	21723	53	13C
0005433367367	21723	54	13E
0005433367238	21723	55	14A
0005433367352	21723	56	14C
0005433367303	21723	57	14D
0005435652822	21723	58	14E
0005433367368	21723	59	15A
0005433367283	21723	60	15C
0005433367318	21723	61	15D
0005435652835	21723	62	15E
0005435652837	21723	63	15F
0005433367360	21723	64	16A
0005435652803	21723	65	16C
0005435652813	21723	66	16D
0005435652836	21723	67	17A
0005435652816	21723	68	17C
0005433367265	21723	69	17D
0005435652787	21723	70	17E
0005435652800	21723	71	17F
0005435652805	21723	72	18A
0005433367312	21723	73	18C
0005435652792	21723	74	18E
0005435652786	21723	75	19A
0005435652797	21723	76	19D
0005435652832	21723	77	19E
0005435652833	21723	78	19F
0005433367387	21723	79	20C
0005433367558	21723	80	20D
0005435652789	21723	81	20E
0005435652807	21723	82	20F
0005433784769	9389	1	1B
0005433805182	9389	2	1F
0005433805179	9389	3	1C
0005433805170	9389	4	1G
0005433805175	9389	5	2A
0005433763133	9389	6	2B
0005432657432	9389	7	2G
0005433805168	9389	8	3A
0005432667442	9389	9	2H
0005433784750	9389	10	3C
0005433805205	9389	11	3F
0005434170880	9389	12	4B
0005433805187	9389	13	4G
0005433805197	9389	14	4F
0005433805201	9389	15	5A
0005433805203	9389	16	4H
0005433784768	9389	17	5B
0005433763132	9389	18	5F
0005434273047	9389	19	9B
0005433784770	9389	20	11E
0005433805210	9389	21	11D
0005434273057	9389	22	11F
0005435269631	9389	23	12A
0005433784743	9389	24	12B
0005433784756	9389	25	12E
0005433805198	9389	26	12F
0005433805169	9389	27	12H
0005432657434	9389	28	12G
0005433805189	9389	29	13B
0005434273058	9389	30	13A
0005433784763	9389	31	13D
0005433805193	9389	32	13E
0005432666377	9389	33	13G
0005434270185	9389	34	14A
0005433784752	9389	35	13H
0005433805204	9389	36	14B
0005433763136	9389	37	14F
0005433763134	9389	38	14G
0005434170839	9389	39	15A
0005434170859	9389	40	15B
0005434270182	9389	41	15E
0005434151665	9389	42	16A
0005433784741	9389	43	16E
0005433784745	9389	44	16G
0005433784744	9389	45	16H
0005433784740	9389	46	17A
0005432667443	9389	47	17D
0005433805196	9389	48	17E
0005435269632	9389	49	17G
0005433784757	9389	50	17F
0005433784755	9389	51	17H
0005433784739	9389	52	18B
0005433763122	9389	53	18A
0005434273053	9389	54	18D
0005433784746	9389	55	18F
0005433763123	9389	56	18G
0005433763126	9389	57	18H
0005433763135	9389	58	19B
0005433805188	9389	59	19E
0005433784742	9389	60	19D
0005433784762	9389	61	19H
0005433805194	9389	62	20D
0005434170881	9389	63	20G
0005433805207	9389	64	21B
0005433784747	9389	65	21A
0005433805200	9389	66	20H
0005434270183	9389	67	21D
0005433763124	9389	68	21F
0005433763131	9389	69	21H
0005433784771	9389	70	21G
0005433805208	9389	71	22A
0005433805199	9389	72	22D
0005434270184	9389	73	22E
0005434270180	9389	74	22H
0005434151678	9389	75	23B
0005434170914	9389	76	23D
0005433784749	9389	77	23F
0005433805183	9389	78	23G
0005432657433	9389	79	23H
0005433784772	9389	80	24B
0005433784765	9389	81	24F
0005433805206	9389	82	24H
0005434273054	9389	83	24G
0005433805195	9389	84	27A
0005433763130	9389	85	25F
0005432665263	9389	86	27E
0005433763129	9389	87	27G
0005433784766	9389	88	28A
0005433805177	9389	89	28B
0005433784764	9389	90	29A
0005434170913	9389	91	28H
0005433784761	9389	92	29E
0005434273051	9389	93	29G
0005433784751	9389	94	29H
0005433763127	9389	95	30A
0005433805202	9389	96	30D
0005434273050	9389	97	30B
0005433784767	9389	98	30E
0005433805174	9389	99	31A
0005434270186	9389	100	30H
0005433805171	9389	101	31B
0005434170887	9389	102	31E
0005433805191	9389	103	31D
0005433784758	9389	104	31F
0005433805178	9389	105	31H
0005433763128	9389	106	32B
0005434170860	9389	107	32E
0005433805192	9389	108	32F
0005433805190	9389	109	32G
0005433784754	9389	110	33B
0005433763125	9389	111	33E
0005432665264	9389	112	33D
0005433784748	9389	113	33G
0005434170852	9389	114	33H
0005434170868	9389	115	34F
0005433805209	9389	116	34E
0005433784753	9389	117	34G
0005434170858	9389	118	35F
0005435269621	9389	119	36B
0005433805184	9389	120	36F
0005434170895	9389	121	36G
0005434170894	9389	122	37A
0005433805181	9389	123	36H
0005433805173	9389	124	37B
0005433784760	9389	125	37E
0005434151664	9389	126	37F
0005433805180	9389	127	37H
0005432666378	9389	128	37G
0005433805172	9389	129	38A
0005433805176	9389	130	38D
0005434170884	9389	131	38G
0005433784759	9389	132	38F
0005434170841	9389	133	38H
0005433805186	9389	134	39D
0005433805185	9389	135	39E
0005434170982	26228	1	1G
0005433804874	26228	2	2A
0005435269717	26228	3	2B
0005433784454	26228	4	2C
0005433763016	26228	5	3A
0005435269714	26228	6	3B
0005433762989	26228	7	3F
0005435269705	26228	8	3C
0005435269723	26228	9	3G
0005433804955	26228	10	4B
0005433804999	26228	11	4C
0005433763035	26228	12	4F
0005433784514	26228	13	5F
0005433762964	26228	14	5C
0005433784337	26228	15	5G
0005433784516	26228	16	5H
0005433784338	26228	17	9B
0005433804877	26228	18	9A
0005435269716	26228	19	11B
0005434170984	26228	20	11A
0005434170977	26228	21	11E
0005433804929	26228	22	11H
0005433784538	26228	23	11G
0005433804878	26228	24	12A
0005435269719	26228	25	12B
0005433784517	26228	26	12E
0005434170978	26228	27	12F
0005433784532	26228	28	13D
0005433784478	26228	29	13E
0005435269720	26228	30	13F
0005434170973	26228	31	14A
0005433804880	26228	32	13H
0005435269709	26228	33	14D
0005433805040	26228	34	14F
0005433804997	26228	35	14E
0005433784422	26228	36	14G
0005433763004	26228	37	15A
0005433804904	26228	38	15E
0005434170987	26228	39	15D
0005433762997	26228	40	15F
0005433763075	26228	41	15H
0005435269715	26228	42	16A
0005433784489	26228	43	16B
0005433784590	26228	44	16E
0005435269708	26228	45	17D
0005433804902	26228	46	17B
0005433784410	26228	47	17E
0005433804820	26228	48	17F
0005433804890	26228	49	17G
0005433784505	26228	50	18B
0005434269090	26228	51	18D
0005435269707	26228	52	18F
0005434270193	26228	53	18E
0005433763034	26228	54	19B
0005433804885	26228	55	19D
0005434270194	26228	56	19F
0005434151689	26228	57	19H
0005433763005	26228	58	19G
0005433763056	26228	59	20A
0005433784346	26228	60	20D
0005433804883	26228	61	20E
0005434170983	26228	62	20H
0005433763045	26228	63	21A
0005433762962	26228	64	21D
0005434170986	26228	65	21B
0005433784539	26228	66	21E
0005433784384	26228	67	21G
0005433784347	26228	68	21F
0005433784453	26228	69	21H
0005433784369	26228	70	22B
0005433804971	26228	71	22A
0005433784371	26228	72	22D
0005433784343	26228	73	22E
0005433763023	26228	74	23B
0005433784459	26228	75	23A
0005433784408	26228	76	23E
0005433784372	26228	77	23H
0005433804809	26228	78	24D
0005433805038	26228	79	24F
0005433784450	26228	80	24H
0005433762976	26228	81	25E
0005435269711	26228	82	27A
0005433762975	26228	83	25F
0005435269710	26228	84	27D
0005433763057	26228	85	27F
0005435269706	26228	86	27G
0005433804898	26228	87	28B
0005433784421	26228	88	28E
0005433804933	26228	89	28F
0005434170985	26228	90	28H
0005434170988	26228	91	29D
0005433763044	26228	92	29B
0005433762963	26228	93	29F
0005433784325	26228	94	30A
0005433784394	26228	95	29H
0005433804810	26228	96	30B
0005434271300	26228	97	30E
0005435269713	26228	98	30F
0005433784455	26228	99	31A
0005434170980	26228	100	30H
0005433804983	26228	101	31B
0005433804882	26228	102	31D
0005434269091	26228	103	31F
0005433784511	26228	104	31E
0005433784438	26228	105	31G
0005434170976	26228	106	32A
0005435269712	26228	107	31H
0005433784525	26228	108	32E
0005433784342	26228	109	32F
0005434271299	26228	110	32H
0005433784548	26228	111	33B
0005434170975	26228	112	33E
0005433804913	26228	113	33F
0005433804900	26228	114	33H
0005433762968	26228	115	34A
0005435269721	26228	116	34D
0005433784398	26228	117	34B
0005433784348	26228	118	34E
0005433804901	26228	119	34F
0005433804998	26228	120	34H
0005433762990	26228	121	35B
0005433804860	26228	122	35D
0005432659671	26228	123	35E
0005433784370	26228	124	35G
0005435269704	26228	125	36B
0005433784481	26228	126	36F
0005434170974	26228	127	36E
0005435269722	26228	128	36G
0005433784407	26228	129	36H
0005433804884	26228	130	37D
0005433804970	26228	131	37B
0005433784349	26228	132	37A
0005433784414	26228	133	37H
0005433804903	26228	134	38A
0005434170981	26228	135	38D
0005435269718	26228	136	38F
0005433804811	26228	137	38G
0005433804982	26228	138	39E
0005435269724	26228	139	39D
0005434170979	26228	140	39F
0005435135644	4927	1	4C
0005435929616	4927	2	4D
0005435135645	4927	3	5D
0005435929600	4927	4	6A
0005435135646	4927	5	6B
0005435929609	4927	6	7A
0005435135642	4927	7	18C
0005435929608	4927	8	20A
0005435135641	4927	9	20B
0005435135643	4927	10	21A
0005435135615	33028	1	2B
0005435135612	33028	2	3B
0005435929629	33028	3	3C
0005435135606	33028	4	4B
0005435135616	33028	5	7A
0005435929628	33028	6	18A
0005435135586	33028	7	18C
0005435135591	33028	8	18D
0005435929630	33028	9	19B
0005434983258	9480	1	2C
0005434983260	9480	2	2D
0005434217896	9480	3	3B
0005434217895	9480	4	4A
0005434217910	9480	5	4D
0005434983262	9480	6	5B
0005434217933	9480	7	6D
0005434983261	9480	8	7A
0005434217909	9480	9	7D
0005434983259	9480	10	18D
0005434217911	9480	11	19D
0005434983257	9480	12	20C
0005434217948	27369	1	2A
0005434217947	27369	2	3A
0005434983227	27369	3	6C
0005434217949	27369	4	7A
0005434983216	27369	5	20A
0005434217945	27369	6	21A
0005434983218	27369	7	21D
0005434217946	27369	8	22A
0005433959971	24242	1	1B
0005433960076	24242	2	2A
0005433985194	24242	3	2F
0005433960028	24242	4	2C
0005433985149	24242	5	2H
0005433985238	24242	6	2G
0005433960073	24242	7	3C
0005433959930	24242	8	3F
0005433985400	24242	9	4A
0005433960051	24242	10	4F
0005433959946	24242	11	4C
0005433959922	24242	12	4G
0005433959917	24242	13	4H
0005433959978	24242	14	5B
0005433960072	24242	15	5A
0005433985435	24242	16	5F
0005433985255	24242	17	5H
0005433959921	24242	18	9B
0005433985240	24242	19	9A
0005433959979	24242	20	11F
0005433960066	24242	21	12D
0005433960034	24242	22	12H
0005433959912	24242	23	12G
0005433985156	24242	24	13A
0005433959931	24242	25	13F
0005433959966	24242	26	13E
0005433985195	24242	27	13G
0005433960071	24242	28	14A
0005433959981	24242	29	14B
0005433959956	24242	30	14G
0005433985313	24242	31	15A
0005433985167	24242	32	15D
0005433985315	24242	33	15F
0005433985349	24242	34	15H
0005433985266	24242	35	16E
0005433985423	24242	36	16H
0005433959925	24242	37	17A
0005433985370	24242	38	17D
0005433985298	24242	39	17E
0005433959898	24242	40	17F
0005433960014	24242	41	18D
0005433959951	24242	42	18E
0005433985265	24242	43	18G
0005433985401	24242	44	19B
0005433985334	24242	45	19A
0005433960038	24242	46	19D
0005433985225	24242	47	19F
0005433985360	24242	48	19H
0005433985239	24242	49	20E
0005433960037	24242	50	21B
0005433960022	24242	51	21H
0005433960075	24242	52	21G
0005433985283	24242	53	22D
0005433985206	24242	54	22F
0005433959967	24242	55	22E
0005433985166	24242	56	22G
0005433960032	24242	57	23A
0005433985533	24242	58	23B
0005433960063	24242	59	23D
0005433985346	24242	60	23E
0005433960006	24242	61	24E
0005433960061	24242	62	24G
0005433985178	24242	63	25D
0005433960068	24242	64	24H
0005433985158	24242	65	27A
0005433985184	24242	66	27D
0005433960031	24242	67	27E
0005433960036	24242	68	28B
0005433959916	24242	69	28E
0005433959923	24242	70	28D
0005433985254	24242	71	29A
0005433960009	24242	72	29B
0005433985318	24242	73	29F
0005433985402	24242	74	29G
0005433985422	24242	75	30B
0005433985333	24242	76	30D
0005433985267	24242	77	30F
0005433959890	24242	78	30E
0005433985354	24242	79	30G
0005433985205	24242	80	31A
0005433985547	24242	81	30H
0005433985345	24242	82	31B
0005433985237	24242	83	31E
0005433985369	24242	84	31G
0005433959995	24242	85	32A
0005433985281	24242	86	32F
0005433960070	24242	87	32H
0005433959970	24242	88	33A
0005433985314	24242	89	34D
0005433985359	24242	90	34B
0005433985332	24242	91	34E
0005433959969	24242	92	35B
0005433960021	24242	93	35A
0005433959957	24242	94	35D
0005433985282	24242	95	36A
0005433959932	24242	96	36D
0005433985433	24242	97	36G
0005433960030	24242	98	37A
0005433959945	24242	99	36H
0005433959891	24242	100	37B
0005433985196	24242	101	37F
0005433985299	24242	102	37H
0005433960033	24242	103	38G
0005433985424	24242	104	39F
0005433960558	25954	1	1C
0005433960571	25954	2	2A
0005433960562	25954	3	1H
0005433960569	25954	4	2B
0005433960524	25954	5	2F
0005433985682	25954	6	2C
0005433960559	25954	7	2G
0005433960560	25954	8	2H
0005433960546	25954	9	4A
0005433960532	25954	10	4F
0005433960550	25954	11	4G
0005433960514	25954	12	5B
0005433985649	25954	13	5A
0005433985664	25954	14	5C
0005433985681	25954	15	9B
0005433960568	25954	16	9H
0005433960499	25954	17	11A
0005433985651	25954	18	11G
0005433985650	25954	19	11F
0005433960508	25954	20	11H
0005433960557	25954	21	12A
0005433985669	25954	22	12D
0005433960533	25954	23	12G
0005433960505	25954	24	13B
0005433960567	25954	25	13D
0005433960539	25954	26	13E
0005433985662	25954	27	14B
0005433960555	25954	28	14F
0005433960517	25954	29	14G
0005433985654	25954	30	15A
0005433985670	25954	31	14H
0005433985686	25954	32	15D
0005433985672	25954	33	15B
0005433985674	25954	34	15F
0005433960506	25954	35	15H
0005433960538	25954	36	16D
0005433985687	25954	37	16F
0005433985656	25954	38	16H
0005433985679	25954	39	17A
0005433985655	25954	40	17E
0005433985688	25954	41	17G
0005433985671	25954	42	17F
0005433960537	25954	43	17H
0005433960535	25954	44	18B
0005433960561	25954	45	18A
0005433985653	25954	46	18D
0005433960547	25954	47	18E
0005433960518	25954	48	19A
0005433985675	25954	49	18H
0005433960513	25954	50	19B
0005433960553	25954	51	19F
0005433960552	25954	52	19E
0005433985684	25954	53	19H
0005433960556	25954	54	19G
0005433960563	25954	55	20A
0005433960521	25954	56	20B
0005433960512	25954	57	20E
0005433960516	25954	58	20D
0005433960566	25954	59	20H
0005433960543	25954	60	21D
0005433985658	25954	61	21G
0005433960509	25954	62	21F
0005433960536	25954	63	22A
0005433960504	25954	64	21H
0005433960500	25954	65	22F
0005433960542	25954	66	22H
0005433960519	25954	67	23D
0005433985685	25954	68	24D
0005433960531	25954	69	24F
0005433960502	25954	70	25D
0005433960503	25954	71	25E
0005433960545	25954	72	27B
0005433960551	25954	73	27F
0005433960525	25954	74	28B
0005433985660	25954	75	28F
0005433985680	25954	76	29D
0005433985677	25954	77	29G
0005433985661	25954	78	30B
0005433960564	25954	79	30E
0005433960540	25954	80	30D
0005433960520	25954	81	30G
0005433985659	25954	82	31B
0005433960526	25954	83	31D
0005433960527	25954	84	31E
0005433985683	25954	85	31H
0005433985648	25954	86	32B
0005433985657	25954	87	32H
0005433960554	25954	88	32G
0005433985665	25954	89	33A
0005433960501	25954	90	33E
0005433960511	25954	91	33D
0005433960529	25954	92	33H
0005433960523	25954	93	34A
0005433985666	25954	94	34D
0005433985663	25954	95	34B
0005433985676	25954	96	34G
0005433960548	25954	97	34H
0005433960549	25954	98	35A
0005433960515	25954	99	35B
0005433960544	25954	100	35G
0005433960510	25954	101	35H
0005433960507	25954	102	36D
0005433960528	25954	103	36E
0005433985673	25954	104	36G
0005433960530	25954	105	37A
0005433985678	25954	106	36H
0005433960565	25954	107	37B
0005433960522	25954	108	37E
0005433960541	25954	109	37F
0005433985652	25954	110	37G
0005433960534	25954	111	38B
0005433960570	25954	112	38D
0005433985668	25954	113	39D
0005433985667	25954	114	39F
0005434480193	975	1	1A
0005433165748	975	2	1B
0005434480203	975	3	1C
0005434480200	975	4	1D
0005433165779	975	5	2A
0005434480202	975	6	2B
0005433165692	975	7	2C
0005434480209	975	8	2D
0005432269481	975	9	3A
0005432269480	975	10	3B
0005434480191	975	11	3C
0005434480189	975	12	4A
0005434480206	975	13	4C
0005434480198	975	14	4D
0005434480186	975	15	5A
0005434480199	975	16	5B
0005434480204	975	17	5C
0005432269482	975	18	5D
0005434480208	975	19	6A
0005434480207	975	20	6C
0005433165778	975	21	7A
0005433165709	975	22	7B
0005433165693	975	23	7C
0005433165757	975	24	7D
0005434480197	975	25	18B
0005434480195	975	26	18C
0005434480201	975	27	18D
0005434480190	975	28	19A
0005434480210	975	29	19B
0005433165712	975	30	19C
0005433165702	975	31	19D
0005433165714	975	32	20A
0005434480205	975	33	20B
0005434480211	975	34	20C
0005433165736	975	35	20D
0005433165749	975	36	21A
0005434480188	975	37	21B
0005433165733	975	38	21D
0005433165711	975	39	22A
0005432269479	975	40	22B
0005434480194	975	41	22C
0005434480192	975	42	22D
0005434480187	975	43	23A
0005434480196	975	44	23B
0005433165832	16584	1	1A
0005433165830	16584	2	1B
0005434480022	16584	3	1D
0005433165837	16584	4	2A
0005434479922	16584	5	2C
0005433165838	16584	6	2D
0005434479985	16584	7	3C
0005434480025	16584	8	4B
0005433165840	16584	9	4C
0005434480000	16584	10	5A
0005433165834	16584	11	5C
0005434480053	16584	12	5D
0005434480089	16584	13	6A
0005433165843	16584	14	7C
0005433165842	16584	15	7D
0005434479989	16584	16	18B
0005433165839	16584	17	18D
0005434480010	16584	18	19A
0005434479938	16584	19	19B
0005433165829	16584	20	19C
0005434479990	16584	21	19D
0005434480009	16584	22	20A
0005433165836	16584	23	20B
0005434480013	16584	24	20D
0005434480039	16584	25	21C
0005433165831	16584	26	22A
0005433165833	16584	27	22B
0005433165835	16584	28	23A
0005433165841	16584	29	23B
0005435386479	10339	1	1A
0005435149938	10339	2	1D
0005435142498	10339	3	2B
0005433289763	10339	4	2C
0005435149940	10339	5	2D
0005435149946	10339	6	3A
0005433289753	10339	7	3B
0005435386454	10339	8	3C
0005435142490	10339	9	3D
0005433289747	10339	10	4A
0005435149949	10339	11	4B
0005435142491	10339	12	4C
0005435149944	10339	13	4D
0005435149945	10339	14	5A
0005435386483	10339	15	5B
0005435386463	10339	16	5C
0005435386480	10339	17	5D
0005435142500	10339	18	6A
0005435142494	10339	19	6B
0005435149947	10339	20	6D
0005435142502	10339	21	7A
0005433289727	10339	22	7B
0005435149943	10339	23	7C
0005435142501	10339	24	7D
0005435149939	10339	25	18A
0005435149937	10339	26	18B
0005435142496	10339	27	18C
0005435142492	10339	28	18D
0005435386466	10339	29	19A
0005435149942	10339	30	19B
0005435386467	10339	31	19C
0005435149941	10339	32	19D
0005435142495	10339	33	20A
0005435149948	10339	34	20C
0005433289762	10339	35	20D
0005435142488	10339	36	21A
0005435386482	10339	37	21B
0005435142493	10339	38	21C
0005435142497	10339	39	21D
0005435142489	10339	40	22C
0005435142499	10339	41	22D
0005435386543	21944	1	1A
0005435149815	21944	2	1B
0005435142351	21944	3	1C
0005435149835	21944	4	1D
0005433289818	21944	5	2A
0005435142407	21944	6	2B
0005435149896	21944	7	2C
0005433289813	21944	8	2D
0005435142359	21944	9	3A
0005435149889	21944	10	3B
0005435142352	21944	11	3D
0005435149837	21944	12	4A
0005435142471	21944	13	4C
0005435149897	21944	14	4D
0005435142406	21944	15	5A
0005435142429	21944	16	5B
0005435149881	21944	17	5C
0005435386544	21944	18	5D
0005435386545	21944	19	6A
0005435142355	21944	20	6B
0005433289817	21944	21	6C
0005435142360	21944	22	7A
0005435142470	21944	23	7B
0005435386542	21944	24	7C
0005435142430	21944	25	7D
0005435386541	21944	26	18A
0005435142348	21944	27	18B
0005435386540	21944	28	18C
0005435149836	21944	29	18D
0005435149890	21944	30	19B
0005435142385	21944	31	19C
0005435386539	21944	32	19D
0005433289819	21944	33	20A
0005433289816	21944	34	20B
0005435149831	21944	35	20C
0005433289815	21944	36	21A
0005435142413	21944	37	21C
0005435142356	21944	38	21D
0005435149834	21944	39	22A
0005435142361	21944	40	22B
0005435149797	21944	41	22C
0005435149830	21944	42	22D
0005433289814	21944	43	23A
0005435142340	21944	44	23B
0005435501992	11217	1	1C
0005435545630	11217	2	1D
0005435501962	11217	3	1F
0005435502021	11217	4	2A
0005435528959	11217	5	2D
0005435501973	11217	6	3A
0005435528933	11217	7	3C
0005435545628	11217	8	3F
0005435502041	11217	9	3D
0005435502028	11217	10	4C
0005435502036	11217	11	4E
0005435502053	11217	12	5A
0005435319482	11217	13	5C
0005435502052	11217	14	5D
0005434573269	11217	15	5E
0005435319484	11217	16	5F
0005435528995	11217	17	6A
0005435502037	11217	18	6E
0005434573273	11217	19	6F
0005434573271	11217	20	7A
0005435501950	11217	21	7C
0005435528965	11217	22	7D
0005435545649	11217	23	7E
0005434573268	11217	24	7F
0005435319462	11217	25	8A
0005434573261	11217	26	8D
0005435528958	11217	27	8E
0005435319450	11217	28	8F
0005435502100	11217	29	9C
0005435528889	11217	30	9E
0005435502040	11217	31	9F
0005435545648	11217	32	10A
0005434573263	11217	33	10C
0005434573267	11217	34	10D
0005435502063	11217	35	10E
0005435528879	11217	36	10F
0005435502067	11217	37	11D
0005435501960	11217	38	11F
0005435528994	11217	39	11E
0005435528973	11217	40	12A
0005435502059	11217	41	12C
0005435502018	11217	42	12D
0005435545625	11217	43	12E
0005435529077	11217	44	12F
0005434573265	11217	45	13A
0005435501984	11217	46	13C
0005435501972	11217	47	13D
0005435319466	11217	48	13F
0005435502101	11217	49	14A
0005435528991	11217	50	14D
0005435502034	11217	51	14E
0005435528981	11217	52	14F
0005434573266	11217	53	15A
0005434573262	11217	54	15C
0005435319442	11217	55	15D
0005435528880	11217	56	15E
0005435528941	11217	57	15F
0005435528972	11217	58	16A
0005435528892	11217	59	16D
0005435502060	11217	60	16E
0005434573270	11217	61	17A
0005435319439	11217	62	17D
0005435319443	11217	63	17E
0005434573264	11217	64	17F
0005435501974	11217	65	18A
0005435529076	11217	66	18C
0005435319465	11217	67	18D
0005435319483	11217	68	18F
0005435501961	11217	69	18E
0005435528966	11217	70	19A
0005435502093	11217	71	19C
0005435319440	11217	72	19D
0005435502062	11217	73	19F
0005434573272	11217	74	20A
0005435528967	11217	75	20D
0005435545629	11217	76	20E
0005435502102	11217	77	20F
0005435502181	20922	1	1A
0005434573115	20922	2	1C
0005435502187	20922	3	1D
0005435517801	20922	4	1F
0005434573105	20922	5	2A
0005435517812	20922	6	2D
0005435502196	20922	7	2F
0005435502190	20922	8	3C
0005435319535	20922	9	3D
0005434573148	20922	10	4C
0005435319537	20922	11	4D
0005435502178	20922	12	4E
0005435517808	20922	13	4F
0005435502175	20922	14	5A
0005435502188	20922	15	5D
0005435517800	20922	16	5E
0005435517802	20922	17	5F
0005435517816	20922	18	6C
0005435502184	20922	19	6D
0005435517807	20922	20	6E
0005435508293	20922	21	6F
0005435517811	20922	22	7A
0005435508291	20922	23	7C
0005435517806	20922	24	7D
0005434573139	20922	25	7F
0005435319532	20922	26	8A
0005435502192	20922	27	8C
0005435508290	20922	28	8D
0005435517804	20922	29	8E
0005435502179	20922	30	8F
0005435502189	20922	31	9C
0005435502177	20922	32	10A
0005435319534	20922	33	10C
0005435508287	20922	34	10D
0005435508292	20922	35	10E
0005435502176	20922	36	11C
0005435508295	20922	37	11D
0005435517813	20922	38	11F
0005435517815	20922	39	12A
0005435508288	20922	40	12C
0005435502195	20922	41	12D
0005435508294	20922	42	12E
0005435502182	20922	43	12F
0005435502191	20922	44	13A
0005435517817	20922	45	13C
0005435319539	20922	46	13D
0005435502180	20922	47	13E
0005435319540	20922	48	13F
0005435517803	20922	49	14A
0005432291915	20922	50	14C
0005435517805	20922	51	14D
0005435502183	20922	52	14E
0005435502185	20922	53	15C
0005435502194	20922	54	16A
0005435502186	20922	55	16E
0005435508286	20922	56	16F
0005435319533	20922	57	17A
0005435508296	20922	58	17C
0005435517810	20922	59	17D
0005432291916	20922	60	17E
0005435517814	20922	61	17F
0005435517809	20922	62	18A
0005435319538	20922	63	19A
0005434573147	20922	64	19C
0005435508289	20922	65	20C
0005435502193	20922	66	20D
0005434573106	20922	67	20E
0005435319536	20922	68	20F
0005432692672	3029	1	1A
0005432692719	3029	2	1C
0005432692550	3029	3	2D
0005432692602	3029	4	3D
0005432692678	3029	5	4A
0005432692706	3029	6	4D
0005432692540	3029	7	5C
0005432692720	3029	8	6C
0005432692735	3029	9	7A
0005432692614	3029	10	7D
0005432692676	3029	11	9C
0005432692588	3029	12	10C
0005432692679	3029	13	10D
0005432692587	3029	14	11D
0005432692704	3029	15	11F
0005432692803	3029	16	12C
0005432692677	3029	17	13C
0005432692667	3029	18	14A
0005432692619	3029	19	15E
0005432692548	3029	20	16C
0005432692668	3029	21	16F
0005432692599	3029	22	17A
0005432692600	3029	23	18E
0005432692736	3029	24	19C
0005432692689	3029	25	19E
0005432692549	3029	26	19F
0005432692673	3029	27	20A
0005432692690	3029	28	20D
0005432692711	3029	29	20E
0005433194830	3031	1	1A
0005432706631	3031	2	1D
0005432217760	3031	3	1F
0005432706647	3031	4	2C
0005432706624	3031	5	3A
0005433123619	3031	6	3C
0005432880676	3031	7	4A
0005432706642	3031	8	4C
0005432706636	3031	9	4D
0005432217761	3031	10	5C
0005433123603	3031	11	5D
0005432706622	3031	12	5E
0005433123684	3031	13	6D
0005432880571	3031	14	7C
0005432706639	3031	15	7D
0005432880626	3031	16	7E
0005432880592	3031	17	7F
0005432706633	3031	18	8C
0005433123611	3031	19	8D
0005432880556	3031	20	8F
0005432706627	3031	21	9A
0005432706623	3031	22	9D
0005432880627	3031	23	9E
0005432706640	3031	24	9F
0005432706644	3031	25	10A
0005433123621	3031	26	10C
0005432217759	3031	27	10D
0005432706643	3031	28	10E
0005432706634	3031	29	10F
0005432706628	3031	30	11A
0005433123615	3031	31	11C
0005432706638	3031	32	12A
0005432706626	3031	33	12C
0005432706629	3031	34	12F
0005432880636	3031	35	13A
0005433123635	3031	36	13C
0005432706641	3031	37	13F
0005432706621	3031	38	14A
0005433123618	3031	39	14C
0005433123634	3031	40	14D
0005433123658	3031	41	14F
0005432880591	3031	42	15A
0005433123620	3031	43	15D
0005433123685	3031	44	16A
0005433123660	3031	45	16C
0005433123650	3031	46	16D
0005432706637	3031	47	16F
0005433194821	3031	48	17D
0005432706632	3031	49	18A
0005433194829	3031	50	18F
0005433123645	3031	51	19C
0005432706646	3031	52	19D
0005432706625	3031	53	19F
0005432880665	3031	54	20A
0005432706635	3031	55	20C
0005432706630	3031	56	20E
0005432706645	3031	57	20F
0005432880735	29996	1	1A
0005433123814	29996	2	1C
0005432706511	29996	3	1D
0005432692923	29996	4	1F
0005433123822	29996	5	2A
0005432880738	29996	6	2C
0005433194845	29996	7	2D
0005432706415	29996	8	2F
0005432692933	29996	9	3A
0005432706461	29996	10	3C
0005433123810	29996	11	3D
0005432706485	29996	12	3F
0005433123817	29996	13	4A
0005432692936	29996	14	4C
0005433123824	29996	15	4D
0005432706385	29996	16	4E
0005433194848	29996	17	4F
0005433123804	29996	18	5A
0005432692928	29996	19	5C
0005433123820	29996	20	5D
0005432880736	29996	21	5E
0005433123806	29996	22	5F
0005432692924	29996	23	6A
0005432880734	29996	24	6C
0005433194846	29996	25	6D
0005432692929	29996	26	6E
0005433123815	29996	27	6F
0005432692931	29996	28	7A
0005433123813	29996	29	7C
0005432706476	29996	30	7D
0005432706474	29996	31	7E
0005432692927	29996	32	7F
0005432706387	29996	33	8A
0005432692921	29996	34	8C
0005432692926	29996	35	8D
0005432880740	29996	36	8E
0005432880744	29996	37	8F
0005432692908	29996	38	9A
0005433123818	29996	39	9C
0005432692907	29996	40	9D
0005432692918	29996	41	9E
0005432692932	29996	42	9F
0005432692917	29996	43	10A
0005432706481	29996	44	10C
0005432880739	29996	45	10D
0005432706322	29996	46	10E
0005432692920	29996	47	10F
0005433123821	29996	48	11A
0005433194844	29996	49	11D
0005432706378	29996	50	11E
0005432692916	29996	51	11F
0005432692935	29996	52	12A
0005432692915	29996	53	12C
0005432706512	29996	54	12D
0005432706337	29996	55	12E
0005433123826	29996	56	12F
0005432692922	29996	57	13A
0005432880742	29996	58	13C
0005432692912	29996	59	13D
0005432706412	29996	60	13E
0005432706366	29996	61	13F
0005432692909	29996	62	14A
0005432706384	29996	63	14C
0005433123811	29996	64	14D
0005432692913	29996	65	14E
0005432880737	29996	66	14F
0005432880741	29996	67	15A
0005433194849	29996	68	15C
0005432692906	29996	69	15D
0005433123823	29996	70	15E
0005433194850	29996	71	15F
0005432880743	29996	72	16A
0005432692934	29996	73	16C
0005432692911	29996	74	16D
0005433123825	29996	75	16E
0005433123812	29996	76	16F
0005433194843	29996	77	17A
0005433123809	29996	78	17C
0005432706454	29996	79	17D
0005433123819	29996	80	17E
0005433123807	29996	81	17F
0005432880732	29996	82	18A
0005432706462	29996	83	18C
0005432692925	29996	84	18D
0005433123816	29996	85	18E
0005433123808	29996	86	18F
0005432692910	29996	87	19A
0005432706429	29996	88	19C
0005432692930	29996	89	19D
0005432692919	29996	90	19E
0005432880733	29996	91	19F
0005433123805	29996	92	20A
0005432880745	29996	93	20C
0005433194847	29996	94	20D
0005432706321	29996	95	20E
0005432692914	29996	96	20F
0005434988669	23650	1	1A
0005434979619	23650	2	1B
0005434979593	23650	3	1C
0005434979620	23650	4	2A
0005434979617	23650	5	2B
0005434988677	23650	6	2D
0005434979608	23650	7	3A
0005434979612	23650	8	3B
0005434988676	23650	9	3C
0005434979610	23650	10	3D
0005434988673	23650	11	4A
0005434979600	23650	12	4C
0005434979611	23650	13	4D
0005434979613	23650	14	5A
0005434979616	23650	15	5B
0005434979609	23650	16	5C
0005434979598	23650	17	5D
0005434988670	23650	18	6A
0005434979594	23650	19	6C
0005434979614	23650	20	7A
0005434979606	23650	21	7B
0005434979618	23650	22	7C
0005434979592	23650	23	7D
0005434979615	23650	24	18A
0005434979604	23650	25	18B
0005434979599	23650	26	18C
0005434979603	23650	27	18D
0005434988675	23650	28	19A
0005434979605	23650	29	19C
0005434988668	23650	30	19D
0005434988671	23650	31	20A
0005434979601	23650	32	20B
0005434979621	23650	33	20D
0005434979602	23650	34	21A
0005434979597	23650	35	21B
0005434988667	23650	36	21C
0005434979596	23650	37	21D
0005434979595	23650	38	22B
0005434979607	23650	39	22C
0005434988674	23650	40	22D
0005434988672	23650	41	23A
0005434988597	27573	1	1A
0005434979287	27573	2	1B
0005434988583	27573	3	1D
0005434979255	27573	4	2B
0005434979486	27573	5	2C
0005434988587	27573	6	2D
0005434988585	27573	7	3A
0005434979261	27573	8	3B
0005434979356	27573	9	3C
0005434988576	27573	10	3D
0005434979368	27573	11	4A
0005434979393	27573	12	4B
0005434988584	27573	13	4C
0005434979262	27573	14	5A
0005434988557	27573	15	5B
0005434988582	27573	16	5D
0005434979330	27573	17	6A
0005434979436	27573	18	6C
0005434979312	27573	19	6D
0005434979377	27573	20	7A
0005434979366	27573	21	7B
0005434979476	27573	22	7C
0005434988594	27573	23	18A
0005434979434	27573	24	18B
0005434988575	27573	25	18C
0005434979435	27573	26	19B
0005434979306	27573	27	19C
0005434988570	27573	28	19D
0005434979350	27573	29	20A
0005434979305	27573	30	20C
0005434979442	27573	31	20D
0005434988571	27573	32	21A
0005434988586	27573	33	21B
0005434979365	27573	34	21C
0005434979311	27573	35	22B
0005434979328	27573	36	22D
0005434988598	27573	37	23A
0005434979477	27573	38	23B
0005434302433	10251	1	2A
0005434302434	10251	2	2B
0005433113501	10251	3	2C
0005434302431	10251	4	5D
0005434302855	10251	5	6D
0005433111473	10251	6	18A
0005434302432	10251	7	21A
0005434302430	10251	8	23A
0005433113525	19624	1	6A
0005434302397	19624	2	7B
0005434302386	19624	3	18C
0005434302394	19624	4	19B
0005433113524	19624	5	19C
0005434302396	19624	6	21D
0005433113523	19624	7	22C
0005434302387	19624	8	23B
0005435925116	3575	1	1A
0005435068813	3575	2	1C
0005435068833	3575	3	1D
0005435068842	3575	4	1F
0005435939858	3575	5	2C
0005435068799	3575	6	2F
0005435068820	3575	7	3A
0005435068807	3575	8	3C
0005435068804	3575	9	3D
0005435068817	3575	10	4D
0005435068800	3575	11	4E
0005435068811	3575	12	5A
0005435068844	3575	13	5C
0005435068816	3575	14	5D
0005435068837	3575	15	5E
0005435068846	3575	16	5F
0005435068808	3575	17	6A
0005435068805	3575	18	6C
0005435068834	3575	19	6D
0005435068798	3575	20	7A
0005435068795	3575	21	7D
0005435068823	3575	22	7E
0005435068827	3575	23	8A
0005435925079	3575	24	8C
0005435068809	3575	25	8F
0005435068821	3575	26	9A
0005435939859	3575	27	9D
0005435925078	3575	28	9E
0005435925087	3575	29	9F
0005435068828	3575	30	10A
0005435068801	3575	31	10C
0005435068824	3575	32	10D
0005435068829	3575	33	10E
0005435925112	3575	34	11A
0005435068819	3575	35	11E
0005435068818	3575	36	11F
0005435068832	3575	37	12A
0005435068845	3575	38	12C
0005435068838	3575	39	12D
0005435068796	3575	40	12E
0005435925057	3575	41	12F
0005435068841	3575	42	13A
0005435925113	3575	43	13C
0005435068830	3575	44	13D
0005435925083	3575	45	13F
0005435068815	3575	46	14A
0005435925058	3575	47	14E
0005435068839	3575	48	15C
0005435068802	3575	49	15D
0005435068810	3575	50	15E
0005435068794	3575	51	16A
0005435068806	3575	52	16C
0005435925122	3575	53	16D
0005435068831	3575	54	16E
0005435718918	3575	55	16F
0005435068822	3575	56	17A
0005435925117	3575	57	17C
0005435068840	3575	58	17D
0005435068825	3575	59	17E
0005435068836	3575	60	17F
0005435068835	3575	61	18A
0005435068843	3575	62	18C
0005435925084	3575	63	18E
0005435718919	3575	64	18F
0005435939860	3575	65	19A
0005435068803	3575	66	19D
0005435068797	3575	67	19E
0005435068826	3575	68	20A
0005435068814	3575	69	20C
0005435068812	3575	70	20F
0005435068327	15331	1	1A
0005435925205	15331	2	1C
0005435925213	15331	3	1D
0005435068388	15331	4	1F
0005435925204	15331	5	2A
0005435068393	15331	6	2C
0005435068400	15331	7	2D
0005435068378	15331	8	2F
0005435068352	15331	9	3C
0005435068280	15331	10	3D
0005435068377	15331	11	3F
0005435068417	15331	12	4A
0005435925217	15331	13	4C
0005435068433	15331	14	4E
0005435925216	15331	15	4F
0005435925209	15331	16	5A
0005435068278	15331	17	5C
0005435068318	15331	18	5D
0005435068324	15331	19	5E
0005435068452	15331	20	5F
0005435068293	15331	21	6A
0005435925210	15331	22	6C
0005435068196	15331	23	6D
0005435068247	15331	24	7A
0005435068242	15331	25	7D
0005435068205	15331	26	8A
0005435925214	15331	27	8C
0005435068439	15331	28	8E
0005435068197	15331	29	8F
0005435068195	15331	30	9C
0005435939871	15331	31	9D
0005435068274	15331	32	9E
0005435068328	15331	33	9F
0005435068198	15331	34	10D
0005435068416	15331	35	10E
0005435068451	15331	36	10F
0005435068243	15331	37	11A
0005435068326	15331	38	11D
0005435925218	15331	39	11E
0005435068206	15331	40	11F
0005435925207	15331	41	12D
0005435068432	15331	42	12E
0005435068300	15331	43	12F
0005435068313	15331	44	13A
0005435068380	15331	45	13C
0005435925206	15331	46	13D
0005435068287	15331	47	13E
0005435068384	15331	48	13F
0005435068501	15331	49	14A
0005435068412	15331	50	14D
0005435925215	15331	51	14E
0005435068482	15331	52	14F
0005435068347	15331	53	15A
0005435925211	15331	54	15C
0005435068481	15331	55	15D
0005435068476	15331	56	15E
0005435068279	15331	57	16C
0005435068475	15331	58	16D
0005435068227	15331	59	16E
0005435068168	15331	60	17A
0005435068246	15331	61	17C
0005435068283	15331	62	17D
0005435068245	15331	63	17E
0005435939872	15331	64	18A
0005435068319	15331	65	18C
0005435068175	15331	66	18D
0005435068337	15331	67	18E
0005435068500	15331	68	19A
0005435068250	15331	69	19D
0005435068372	15331	70	19E
0005435925212	15331	71	20A
0005435925208	15331	72	20C
0005435068282	15331	73	20F
0005432658581	18219	1	1A
0005432659696	18219	2	3A
0005432658579	18219	3	3B
0005432660806	18219	4	4A
0005432658580	18219	5	4B
0005432659695	18219	6	5A
0005432659694	18219	7	5B
0005432660807	18219	8	6A
0005432667421	26370	1	2A
0005432667418	26370	2	2B
0005432667422	26370	3	3A
0005432919571	25	1	1A
0005433101439	25	2	1C
0005433101357	25	3	1F
0005433101389	25	4	1D
0005433101415	25	5	2A
0005432919638	25	6	2F
0005433101292	25	7	2D
0005433101360	25	8	3A
0005433101398	25	9	3C
0005433101335	25	10	3D
0005432919621	25	11	4D
0005432919542	25	12	4F
0005433101387	25	13	5A
0005433101427	25	14	5C
0005433101416	25	15	6A
0005433101457	25	16	6D
0005432901459	25	17	7A
0005433101401	25	18	6F
0005432919518	25	19	7D
0005432919632	25	20	7C
0005433101458	25	21	7F
0005433101409	25	22	8A
0005433101237	25	23	8C
0005433101435	25	24	8E
0005433101177	25	25	8D
0005433101417	25	26	8F
0005432677523	25	27	9E
0005432901414	25	28	9D
0005433101341	25	29	9F
0005433101324	25	30	10B
0005432901412	25	31	10E
0005433101195	25	32	10F
0005433101268	25	33	11B
0005432901401	25	34	11A
0005433101358	25	35	11D
0005432919601	25	36	11E
0005433101399	25	37	12A
0005433101414	25	38	12C
0005433101352	25	39	12B
0005432901399	25	40	12D
0005433101168	25	41	12F
0005433101390	25	42	12E
0005432901376	25	43	13C
0005432901315	25	44	14A
0005432901348	25	45	14B
0005433101421	25	46	14D
0005433101291	25	47	14C
0005432901331	25	48	14F
0005432919631	25	49	14E
0005432901387	25	50	15B
0005433101339	25	51	15A
0005432901400	25	52	15C
0005433101422	25	53	15E
0005432901367	25	54	15D
0005432919554	25	55	15F
0005432919583	25	56	16D
0005433101284	25	57	16E
0005432901349	25	58	17A
0005432901413	25	59	16F
0005433101385	25	60	17D
0005432919576	25	61	17F
0005432919517	25	62	18B
0005432901368	25	63	18C
0005432919618	25	64	18F
0005433101403	25	65	19B
0005433101169	25	66	19E
0005433101446	25	67	20A
0005433101413	25	68	20C
0005432919653	25	69	20E
0005433101375	25	70	20D
0005432919512	25	71	21B
0005432919652	25	72	21A
0005433101426	25	73	21D
0005432919619	25	74	21C
0005433101405	25	75	21F
0005433101382	25	76	22A
0005433101383	25	77	22C
0005433101311	25	78	22D
0005433101365	25	79	22F
0005433101442	25	80	22E
0005433101359	25	81	23B
0005433101312	25	82	23A
0005433101374	25	83	23C
0005432677518	25	84	23D
0005432157482	25	85	23F
0005432919537	25	86	24B
0005433101441	25	87	24C
0005432919538	25	88	24D
0005432901347	25	89	25B
0005433101164	25	90	25A
0005433101430	25	91	25C
0005433101438	25	92	25F
0005433101386	25	93	25E
0005432901391	25	94	26C
0005433101402	25	95	26E
0005433101434	25	96	27A
0005433101334	25	97	27C
0005432901342	25	98	27B
0005433101388	25	99	27D
0005433101325	25	100	27E
0005432919552	25	101	27F
0005433101340	25	102	28B
0005433101242	25	103	28C
0005432901332	25	104	28F
0005433101456	25	105	29A
0005433101342	25	106	29B
0005433101425	25	107	29D
0005433101368	25	108	29C
0005432901408	25	109	29E
0005433101310	25	110	29F
0005432919513	25	111	30F
0005433101455	25	112	31B
0005432919555	25	113	31C
0005433101322	25	114	31D
0005432919511	25	115	31E
0005432261694	38	1	2A
0005432817304	38	2	2D
0005432817324	38	3	3A
0005432261668	38	4	2F
0005432207647	38	5	3C
0005432261674	38	6	5F
0005432817318	38	7	5D
0005432288970	38	8	6F
0005432261651	38	9	7C
0005432261687	38	10	7F
0005432261682	38	11	9A
0005432261660	38	12	9B
0005432817306	38	13	9D
0005432817315	38	14	9E
0005432261662	38	15	10A
0005432817302	38	16	10C
0005432261675	38	17	10D
0005432261661	38	18	10F
0005432817323	38	19	11A
0005432261666	38	20	11E
0005432261659	38	21	12A
0005432817312	38	22	12B
0005432756792	38	23	12C
0005432817311	38	24	12D
0005432261679	38	25	12E
0005432817328	38	26	13C
0005432261683	38	27	13B
0005432288967	38	28	14A
0005432261678	38	29	15B
0005432261656	38	30	15A
0005432207646	38	31	15C
0005432261681	38	32	16A
0005432261691	38	33	16B
0005432261676	38	34	16E
0005432817329	38	35	17A
0005432817309	38	36	16F
0005432817320	38	37	17C
0005432261652	38	38	17E
0005432288968	38	39	18A
0005432288969	38	40	18D
0005432817310	38	41	18C
0005432817316	38	42	18E
0005432261686	38	43	18F
0005432261684	38	44	19C
0005432261688	38	45	19E
0005432261658	38	46	20B
0005432261672	38	47	20A
0005432261673	38	48	20D
0005432817327	38	49	20E
0005432261692	38	50	21B
0005432261665	38	51	21A
0005432817317	38	52	21C
0005432817331	38	53	21E
0005432261657	38	54	22B
0005432261671	38	55	22D
0005432817322	38	56	22E
0005432817330	38	57	23A
0005432817305	38	58	23D
0005432261677	38	59	23F
0005432817325	38	60	24B
0005432817303	38	61	24E
0005432261653	38	62	25B
0005432261669	38	63	25E
0005432817319	38	64	25D
0005432261680	38	65	26A
0005432261693	38	66	25F
0005432817314	38	67	26B
0005432261655	38	68	26C
0005432261649	38	69	26E
0005432817313	38	70	27A
0005432261689	38	71	27B
0005432261650	38	72	27C
0005432817321	38	73	27D
0005432261690	38	74	27F
0005432817307	38	75	28D
0005432817308	38	76	28F
0005432261654	38	77	29B
0005432261667	38	78	30C
0005432261670	38	79	30D
0005432817326	38	80	30F
0005432261685	38	81	31C
0005432261663	38	82	31D
0005432261664	38	83	31E
0005433101897	8031	1	1A
0005432020113	8031	2	1D
0005433101892	8031	3	1C
0005432677554	8031	4	2A
0005432020115	8031	5	2C
0005432020123	8031	6	3A
0005432919759	8031	7	2F
0005432020128	8031	8	3D
0005433101882	8031	9	4C
0005433101858	8031	10	4F
0005432677555	8031	11	5A
0005433101898	8031	12	5D
0005432919756	8031	13	6A
0005433101860	8031	14	6C
0005433101863	8031	15	6D
0005433101870	8031	16	7A
0005433101901	8031	17	7C
0005432919757	8031	18	7F
0005432020119	8031	19	8A
0005433101853	8031	20	8B
0005432391985	8031	21	8E
0005432020116	8031	22	9B
0005433101896	8031	23	9D
0005433101889	8031	24	9F
0005433101873	8031	25	10A
0005433101883	8031	26	10C
0005432751509	8031	27	10E
0005432020122	8031	28	11A
0005432020132	8031	29	11D
0005433101887	8031	30	11F
0005432020120	8031	31	11E
0005433101869	8031	32	12A
0005432044511	8031	33	12B
0005432919753	8031	34	12C
0005432919742	8031	35	12E
0005433101846	8031	36	13A
0005433101876	8031	37	13C
0005433101872	8031	38	13D
0005432919743	8031	39	13E
0005432045604	8031	40	14A
0005432677553	8031	41	14C
0005432919751	8031	42	14B
0005432020111	8031	43	14D
0005433101862	8031	44	14E
0005432020131	8031	45	15B
0005432020130	8031	46	15A
0005433101886	8031	47	15C
0005433101854	8031	48	15D
0005432020112	8031	49	15F
0005432020126	8031	50	15E
0005433101850	8031	51	16A
0005432919755	8031	52	16B
0005432751511	8031	53	16C
0005433101871	8031	54	16E
0005433101865	8031	55	16F
0005433101844	8031	56	17B
0005433101884	8031	57	17A
0005432020118	8031	58	17C
0005433101888	8031	59	17D
0005432919754	8031	60	17E
0005432919752	8031	61	18A
0005433101893	8031	62	17F
0005432919750	8031	63	18C
0005432919739	8031	64	18E
0005432919747	8031	65	18D
0005432020133	8031	66	19B
0005433101864	8031	67	18F
0005433101878	8031	68	19D
0005433101875	8031	69	19E
0005433101895	8031	70	20B
0005432919749	8031	71	20D
0005433101843	8031	72	20E
0005433101879	8031	73	20F
0005433101866	8031	74	21A
0005433101868	8031	75	21C
0005433101851	8031	76	21B
0005432919748	8031	77	21E
0005432753284	8031	78	22A
0005433101894	8031	79	21F
0005433101899	8031	80	22B
0005433101856	8031	81	22E
0005432919738	8031	82	22D
0005433101900	8031	83	23A
0005432753285	8031	84	23B
0005432020110	8031	85	23D
0005433101861	8031	86	23F
0005433101845	8031	87	23E
0005433101881	8031	88	24A
0005432919740	8031	89	24D
0005433101877	8031	90	24C
0005432020121	8031	91	24E
0005433101848	8031	92	24F
0005432044509	8031	93	25B
0005433101855	8031	94	25D
0005433101885	8031	95	25C
0005433101847	8031	96	25E
0005432020109	8031	97	26C
0005432020135	8031	98	26B
0005432391984	8031	99	26D
0005432020125	8031	100	26E
0005432919744	8031	101	27A
0005432020114	8031	102	26F
0005432919745	8031	103	27C
0005433101859	8031	104	27B
0005433101857	8031	105	27D
0005433101849	8031	106	28A
0005433101867	8031	107	27F
0005432020129	8031	108	28B
0005433101852	8031	109	28C
0005432020127	8031	110	28D
0005432751510	8031	111	28F
0005432020134	8031	112	29C
0005432044510	8031	113	29B
0005433101890	8031	114	29D
0005432020124	8031	115	30A
0005432919758	8031	116	29F
0005433101891	8031	117	30B
0005432919746	8031	118	30D
0005433101880	8031	119	30C
0005432020117	8031	120	30F
0005433101874	8031	121	31C
0005432677552	8031	122	31E
0005432020108	8031	123	31D
0005432919741	8031	124	31F
0005432817104	8033	1	1A
0005432817137	8033	2	2A
0005432817085	8033	3	2D
0005432901519	8033	4	2C
0005432901513	8033	5	5A
0005432901517	8033	6	6C
0005432817114	8033	7	8C
0005432901521	8033	8	9B
0005432817151	8033	9	10B
0005432817037	8033	10	12B
0005432817007	8033	11	12E
0005432901514	8033	12	13B
0005432816986	8033	13	14A
0005432901511	8033	14	15C
0005432817172	8033	15	15D
0005432816974	8033	16	15E
0005432901525	8033	17	16B
0005432901512	8033	18	16E
0005432901524	8033	19	17A
0005432817129	8033	20	17C
0005432816985	8033	21	17F
0005432901518	8033	22	18E
0005432901509	8033	23	19C
0005432817016	8033	24	21A
0005432901520	8033	25	21C
0005432901522	8033	26	23D
0005432901516	8033	27	25A
0005432817070	8033	28	25C
0005432817130	8033	29	26E
0005432901523	8033	30	28D
0005432817069	8033	31	28E
0005432817023	8033	32	28F
0005432901510	8033	33	30A
0005432901515	8033	34	31A
0005432901526	8033	35	31D
0005432002065	8033	36	31F
0005434175701	9667	1	1A
0005433870720	9667	2	1B
0005434175697	9667	3	3A
0005433870718	9667	4	3B
0005434175699	9667	5	4A
0005433870719	9667	6	5B
0005434175696	9667	7	6A
0005433870704	32370	1	1A
0005433870703	32370	2	1B
0005433870696	32370	3	2A
0005433870699	32370	4	2B
0005434175731	32370	5	3A
0005434175729	32370	6	3B
0005433870692	32370	7	4A
0005433870697	32370	8	4B
0005433870691	32370	9	5A
0005433870698	32370	10	5B
0005434175732	32370	11	6A
0005434175730	32370	12	6B
0005434877748	3522	1	1A
0005434877741	3522	2	1H
0005435902461	3522	3	2A
0005434877795	3522	4	1K
0005435626086	3522	5	2D
0005435626071	3522	6	2K
0005435626091	3522	7	3C
0005435902460	3522	8	3H
0005434877784	3522	9	3G
0005434877742	3522	10	4A
0005434877738	3522	11	3K
0005435626075	3522	12	4D
0005435626082	3522	13	4K
0005434877763	3522	14	4H
0005434877797	3522	15	5H
0005432799318	3522	16	5G
0005432799303	3522	17	5D
0005435626072	3522	18	11A
0005434877771	3522	19	5K
0005435126167	3522	20	11D
0005434877729	3522	21	11C
0005435902454	3522	22	11F
0005434877785	3522	23	11E
0005435626073	3522	24	11K
0005434426460	3522	25	11H
0005434426457	3522	26	12C
0005435902453	3522	27	12E
0005435626070	3522	28	12D
0005434426467	3522	29	12G
0005435626081	3522	30	12F
0005434877799	3522	31	13D
0005434877726	3522	32	13C
0005435126177	3522	33	13F
0005435626087	3522	34	13E
0005435126178	3522	35	13H
0005434877718	3522	36	13G
0005435126151	3522	37	13K
0005435914682	3522	38	14E
0005434877811	3522	39	14D
0005435126185	3522	40	14G
0005434426474	3522	41	14F
0005432799316	3522	42	14K
0005435126149	3522	43	14H
0005435126176	3522	44	15C
0005434877731	3522	45	15A
0005435902407	3522	46	15E
0005434877761	3522	47	16A
0005434938035	3522	48	15K
0005435126173	3522	49	15H
0005435841810	3522	50	16D
0005432799310	3522	51	16C
0005434877753	3522	52	16F
0005435126179	3522	53	16H
0005435126152	3522	54	16G
0005434877806	3522	55	17A
0005434877788	3522	56	16K
0005432613843	3522	57	17E
0005435914683	3522	58	17D
0005434938044	3522	59	17C
0005434426463	3522	60	17G
0005432188591	3522	61	17K
0005434877756	3522	62	17H
0005434426468	3522	63	18B
0005435126160	3522	64	18A
0005434426461	3522	65	18C
0005435126154	3522	66	18F
0005434877740	3522	67	18J
0005435126180	3522	68	18K
0005432799317	3522	69	19C
0005434877774	3522	70	19B
0005435126184	3522	71	19E
0005434938036	3522	72	19H
0005434877794	3522	73	19G
0005434877749	3522	74	19K
0005434877725	3522	75	19J
0005435126187	3522	76	20C
0005434877781	3522	77	20D
0005434877752	3522	78	20G
0005435902421	3522	79	21B
0005434877758	3522	80	21A
0005434877796	3522	81	20K
0005434877779	3522	82	21C
0005434877773	3522	83	21G
0005434426459	3522	84	21F
0005434426466	3522	85	21E
0005432799321	3522	86	21H
0005434877786	3522	87	21K
0005432613839	3522	88	22E
0005434877717	3522	89	22H
0005434877745	3522	90	22G
0005435126181	3522	91	22J
0005432799315	3522	92	23B
0005435902480	3522	93	23C
0005432183457	3522	94	23F
0005435126174	3522	95	23G
0005434877798	3522	96	24D
0005435126156	3522	97	23K
0005432799302	3522	98	25B
0005434877768	3522	99	24G
0005435126162	3522	100	25D
0005434877770	3522	101	25C
0005434877754	3522	102	25F
0005434877757	3522	103	25E
0005434877776	3522	104	25H
0005434426449	3522	105	25G
0005434938041	3522	106	25K
0005434877723	3522	107	26A
0005434426450	3522	108	26E
0005434877766	3522	109	26D
0005434877765	3522	110	26C
0005435902430	3522	111	26G
0005434877759	3522	112	26K
0005432183455	3522	113	26J
0005434426465	3522	114	26H
0005432799306	3522	115	27D
0005435902455	3522	116	27C
0005435626077	3522	117	27F
0005434938045	3522	118	27E
0005432799323	3522	119	28A
0005434877807	3522	120	27K
0005434426469	3522	121	27J
0005434938051	3522	122	28C
0005432611689	3522	123	28E
0005434877809	3522	124	28D
0005435902424	3522	125	28F
0005434426464	3522	126	28J
0005435126164	3522	127	28H
0005434426456	3522	128	29A
0005435126171	3522	129	28K
0005434877800	3522	130	29D
0005434938042	3522	131	29F
0005434877805	3522	132	29E
0005435126175	3522	133	29G
0005434877735	3522	134	29K
0005435126172	3522	135	30B
0005434938034	3522	136	30E
0005432799324	3522	137	30C
0005434877739	3522	138	30H
0005434877720	3522	139	30G
0005435126169	3522	140	30F
0005435126170	3522	141	30K
0005432799304	3522	142	30J
0005432611692	3522	143	31A
0005435126163	3522	144	31D
0005434877722	3522	145	31C
0005435126150	3522	146	31F
0005432613840	3522	147	31E
0005434877746	3522	148	31H
0005434938046	3522	149	32A
0005432799307	3522	150	31K
0005434877762	3522	151	31J
0005432799325	3522	152	32C
0005434877769	3522	153	32E
0005435902425	3522	154	32D
0005434938048	3522	155	32G
0005434426458	3522	156	32H
0005434877782	3522	157	33A
0005435126183	3522	158	32K
0005434877728	3522	159	33C
0005434426451	3522	160	33F
0005435902482	3522	161	33E
0005432183456	3522	162	33H
0005434877734	3522	163	33G
0005434877727	3522	164	34A
0005434877810	3522	165	33K
0005434426470	3522	166	33J
0005432799313	3522	167	34C
0005435126166	3522	168	34E
0005435902396	3522	169	34D
0005434877780	3522	170	34G
0005434877792	3522	171	34J
0005434938038	3522	172	34H
0005435126168	3522	173	35B
0005434877803	3522	174	35A
0005435626079	3522	175	34K
0005434877751	3522	176	35D
0005434877802	3522	177	35C
0005432613842	3522	178	35F
0005434877815	3522	179	35E
0005434877812	3522	180	35H
0005434938049	3522	181	36A
0005434877743	3522	182	35K
0005434938039	3522	183	35J
0005434426471	3522	184	36C
0005432799320	3522	185	36B
0005434877804	3522	186	36E
0005434938032	3522	187	36H
0005434938047	3522	188	36F
0005435902431	3522	189	37B
0005434877778	3522	190	37A
0005434877814	3522	191	37D
0005434426475	3522	192	37G
0005432188590	3522	193	37F
0005434877733	3522	194	38B
0005435126158	3522	195	38A
0005434877747	3522	196	38J
0005432799305	3522	197	39B
0005434938050	3522	198	39A
0005432188593	3522	199	38K
0005434426454	3522	200	39F
0005435902506	3522	201	39H
0005434938043	3522	202	39G
0005432799308	3522	203	39K
0005434877724	3522	204	39J
0005435126159	3522	205	40C
0005435626083	3522	206	40B
0005434938033	3522	207	40A
0005435626090	3522	208	40E
0005434877790	3522	209	40D
0005434426462	3522	210	40F
0005432799319	3522	211	40J
0005435626076	3522	212	40K
0005434426473	3522	213	41D
0005434426448	3522	214	41F
0005432799326	3522	215	41E
0005434877719	3522	216	41H
0005432799322	3522	217	42A
0005434877736	3522	218	41K
0005435626078	3522	219	41J
0005435902515	3522	220	42B
0005435913852	3522	221	42E
0005434877730	3522	222	42G
0005434877772	3522	223	42F
0005434938037	3522	224	42J
0005432611691	3522	225	42H
0005435126165	3522	226	43A
0005435626074	3522	227	42K
0005432799327	3522	228	43F
0005434877737	3522	229	43E
0005435902408	3522	230	43J
0005434877732	3522	231	43G
0005434877801	3522	232	44B
0005432188592	3522	233	44A
0005435126161	3522	234	44E
0005434877744	3522	235	44H
0005435126157	3522	236	44G
0005434877767	3522	237	44F
0005434877783	3522	238	44K
0005434877793	3522	239	44J
0005435626080	3522	240	45B
0005434877777	3522	241	45A
0005435126186	3522	242	45D
0005432799311	3522	243	45C
0005435902456	3522	244	45F
0005434426453	3522	245	45E
0005434877808	3522	246	45G
0005435626084	3522	247	46B
0005435126182	3522	248	46A
0005434426455	3522	249	46E
0005434877813	3522	250	46G
0005432613841	3522	251	46F
0005432611690	3522	252	46J
0005435626085	3522	253	46H
0005435626088	3522	254	47C
0005432799314	3522	255	47A
0005434426452	3522	256	47F
0005434877775	3522	257	47H
0005432799328	3522	258	48D
0005434877791	3522	259	48C
0005434938040	3522	260	48A
0005434877750	3522	261	48F
0005435902472	3522	262	48E
0005434877789	3522	263	49A
0005434877755	3522	264	48K
0005435626089	3522	265	49D
0005435126153	3522	266	49C
0005435913851	3522	267	49G
0005435902481	3522	268	49E
0005434426472	3522	269	50A
0005435841811	3522	270	50E
0005432799312	3522	271	50D
0005435126155	3522	272	50G
0005432799309	3522	273	50F
0005434877764	3522	274	51D
0005434877721	3522	275	50H
0005434877787	3522	276	51F
0005434877760	3522	277	51G
0005435125834	14584	1	1D
0005432799127	14584	2	1G
0005434877229	14584	3	2A
0005434876907	14584	4	1H
0005434877170	14584	5	2C
0005432798979	14584	6	2H
0005435125752	14584	7	2G
0005435902609	14584	8	2D
0005434876997	14584	9	2K
0005432059494	14584	10	3C
0005435125897	14584	11	3H
0005434877085	14584	12	3G
0005435125863	14584	13	3K
0005434937893	14584	14	4G
0005435125796	14584	15	4D
0005435625875	14584	16	4K
0005434877163	14584	17	4H
0005434876812	14584	18	5C
0005435125793	14584	19	5A
0005435625911	14584	20	11A
0005434876948	14584	21	11D
0005434426259	14584	22	11C
0005434876774	14584	23	11G
0005434937950	14584	24	11F
0005434876889	14584	25	12C
0005434876954	14584	26	12A
0005435125654	14584	27	11K
0005434876842	14584	28	12E
0005434876757	14584	29	12D
0005434876811	14584	30	12G
0005432799050	14584	31	12F
0005434876758	14584	32	13C
0005435125770	14584	33	13A
0005435125761	14584	34	13F
0005434877313	14584	35	13E
0005435125937	14584	36	13K
0005435125742	14584	37	13G
0005435902614	14584	38	14E
0005435902615	14584	39	14D
0005434876663	14584	40	14C
0005434876780	14584	41	14F
0005434426345	14584	42	14K
0005434877026	14584	43	15C
0005435625918	14584	44	15A
0005434876591	14584	45	15G
0005434877044	14584	46	16A
0005435125824	14584	47	15K
0005434876865	14584	48	16F
0005432799082	14584	49	16E
0005435125806	14584	50	16H
0005434877128	14584	51	16G
0005435125667	14584	52	17A
0005435913926	14584	53	16K
0005432798972	14584	54	17E
0005434877445	14584	55	17D
0005434937881	14584	56	17C
0005434426116	14584	57	17F
0005434426117	14584	58	17K
0005434876736	14584	59	17H
0005435902608	14584	60	18H
0005432799083	14584	61	19A
0005434426252	14584	62	19D
0005432799004	14584	63	19C
0005434426257	14584	64	19F
0005435902606	14584	65	19H
0005432798975	14584	66	19K
0005432607496	14584	67	19J
0005432799075	14584	68	20C
0005434426221	14584	69	20B
0005434877171	14584	70	20E
0005434877086	14584	71	20D
0005435625912	14584	72	20F
0005434877083	14584	73	21C
0005434876928	14584	74	21F
0005432607499	14584	75	21E
0005432799154	14584	76	21H
0005434937908	14584	77	21G
0005434876927	14584	78	22A
0005434426253	14584	79	21K
0005435902617	14584	80	22C
0005434877195	14584	81	22B
0005435125805	14584	82	22E
0005435125869	14584	83	22G
0005434877172	14584	84	22F
0005434876590	14584	85	22J
0005434876589	14584	86	22H
0005434877166	14584	87	23B
0005434426130	14584	88	23A
0005432799111	14584	89	23E
0005435902620	14584	90	23D
0005434877024	14584	91	23C
0005435841819	14584	92	23G
0005432799042	14584	93	23F
0005432799149	14584	94	23J
0005435125663	14584	95	23H
0005432799150	14584	96	24D
0005434877010	14584	97	24F
0005434937886	14584	98	25A
0005435625868	14584	99	24G
0005434877165	14584	100	25B
0005435125653	14584	101	25F
0005435841818	14584	102	25E
0005435625905	14584	103	25D
0005434877043	14584	104	25H
0005435625893	14584	105	25J
0005432798998	14584	106	26C
0005434876807	14584	107	26B
0005435125896	14584	108	26G
0005434876926	14584	109	26F
0005434426181	14584	110	26J
0005434876598	14584	111	26H
0005434937990	14584	112	26K
0005435125794	14584	113	27D
0005435125799	14584	114	27C
0005435125760	14584	115	27B
0005434426248	14584	116	27E
0005435902605	14584	117	27H
0005434426254	14584	118	27F
0005434426196	14584	119	27K
0005434876714	14584	120	27J
0005434937960	14584	121	28A
0005434876635	14584	122	28E
0005432799101	14584	123	28D
0005435902612	14584	124	28K
0005434876850	14584	125	28J
0005435125764	14584	126	28H
0005432799051	14584	127	29B
0005434426222	14584	128	29C
0005434876713	14584	129	29F
0005435902603	14584	130	29D
0005434877162	14584	131	29H
0005434937892	14584	132	29K
0005434426255	14584	133	29J
0005432799148	14584	134	30E
0005434876957	14584	135	30D
0005434426197	14584	136	30F
0005435125652	14584	137	30K
0005434876944	14584	138	31D
0005434426251	14584	139	31H
0005434876953	14584	140	31G
0005434876678	14584	141	32A
0005434876904	14584	142	31K
0005435902604	14584	143	31J
0005434877048	14584	144	32C
0005434876999	14584	145	32E
0005434877084	14584	146	32G
0005434426247	14584	147	32F
0005432799126	14584	148	32J
0005435125911	14584	149	32H
0005434876756	14584	150	33B
0005434426246	14584	151	33A
0005434876691	14584	152	32K
0005435625919	14584	153	33C
0005434876998	14584	154	33E
0005434877089	14584	155	33H
0005432607510	14584	156	34A
0005435125913	14584	157	33K
0005434426218	14584	158	34C
0005434937864	14584	159	34F
0005434937961	14584	160	34J
0005432799074	14584	161	34H
0005432799091	14584	162	35B
0005434426182	14584	163	35A
0005434877232	14584	164	34K
0005435125804	14584	165	35E
0005435125912	14584	166	35D
0005435125741	14584	167	35C
0005435902611	14584	168	36A
0005434877064	14584	169	35J
0005434426229	14584	170	36D
0005435125891	14584	171	36F
0005435625894	14584	172	36J
0005434876984	14584	173	37B
0005435913927	14584	174	37A
0005434877025	14584	175	37D
0005432799197	14584	176	37F
0005434877045	14584	177	37E
0005435125841	14584	178	37J
0005432799129	14584	179	37H
0005432799011	14584	180	37G
0005435625916	14584	181	37K
0005432799153	14584	182	38C
0005434877326	14584	183	38A
0005434426219	14584	184	38H
0005432798997	14584	185	39B
0005434877050	14584	186	38K
0005432798973	14584	187	39C
0005435625915	14584	188	39E
0005434876775	14584	189	40A
0005435125704	14584	190	39J
0005434877387	14584	191	40C
0005434937951	14584	192	40B
0005435125795	14584	193	40H
0005435125895	14584	194	40G
0005434937900	14584	195	40K
0005434426316	14584	196	40J
0005434426223	14584	197	41A
0005434876798	14584	198	41D
0005432799052	14584	199	41C
0005434876903	14584	200	41G
0005434937905	14584	201	42C
0005434877363	14584	202	42B
0005435125844	14584	203	42D
0005435902616	14584	204	42G
0005435125710	14584	205	42F
0005434877530	14584	206	42J
0005435125816	14584	207	42K
0005432799110	14584	208	43B
0005432799063	14584	209	43E
0005434426250	14584	210	43J
0005434877002	14584	211	43G
0005435125864	14584	212	43K
0005434877049	14584	213	44B
0005434426131	14584	214	44A
0005432798974	14584	215	44D
0005435902613	14584	216	44C
0005434876947	14584	217	44G
0005435902607	14584	218	44F
0005434876755	14584	219	44J
0005435125894	14584	220	45B
0005434426213	14584	221	45A
0005434876980	14584	222	45C
0005434937887	14584	223	45F
0005434426266	14584	224	45J
0005434876740	14584	225	46A
0005434877386	14584	226	46E
0005434426183	14584	227	46K
0005435902610	14584	228	46H
0005434877159	14584	229	47C
0005432611655	14584	230	47E
0005434876886	14584	231	47H
0005432607495	14584	232	48C
0005434877208	14584	233	48D
0005435902618	14584	234	48H
0005435913924	14584	235	48G
0005434877230	14584	236	49A
0005434876631	14584	237	49E
0005434876779	14584	238	49C
0005432607520	14584	239	49G
0005435125751	14584	240	49F
0005435625904	14584	241	50C
0005434426258	14584	242	50A
0005432799128	14584	243	50E
0005435125910	14584	244	50D
0005435913925	14584	245	50H
0005434877399	14584	246	50F
0005435902619	14584	247	51D
0005435125728	14584	248	50K
0005434876773	14584	249	51F
0005434937812	14584	250	51E
0005434325592	3600	1	1B
0005434325594	3600	2	1C
0005434325589	3600	3	2A
0005434325595	3600	4	2C
0005435889826	3600	5	2D
0005435889822	3600	6	3A
0005434325585	3600	7	3B
0005434325590	3600	8	3C
0005435889808	3600	9	4B
0005435889838	3600	10	4D
0005434325591	3600	11	5C
0005434325588	3600	12	6A
0005434325586	3600	13	6B
0005435889807	3600	14	6C
0005435889837	3600	15	6D
0005434325596	3600	16	19B
0005434325587	3600	17	20A
0005435889795	3600	18	21D
0005434325593	3600	19	22A
0005435889831	3600	20	22D
0005434325543	15642	1	1A
0005435889866	15642	2	1C
0005435889863	15642	3	2B
0005434325505	15642	4	2C
0005435889865	15642	5	3A
0005435889867	15642	6	3D
0005434325549	15642	7	4A
0005434325486	15642	8	4B
0005434325492	15642	9	4C
0005434325493	15642	10	5D
0005434325468	15642	11	6A
0005434325494	15642	12	7A
0005434325524	15642	13	18A
0005434325526	15642	14	18D
0005434325511	15642	15	19C
0005435889868	15642	16	20B
0005434325544	15642	17	20C
0005435889864	15642	18	21A
0005434325512	15642	19	21B
0005434325514	15642	20	21C
0005434325495	15642	21	22B
0005434325525	15642	22	22C
0005435957624	615	1	1A
0005433420306	615	2	1D
0005435957628	615	3	2A
0005435957634	615	4	2B
0005435957633	615	5	2C
0005435957622	615	6	2D
0005433420307	615	7	3C
0005435957625	615	8	4A
0005433420309	615	9	5A
0005435957623	615	10	5C
0005433420285	615	11	6A
0005433420267	615	12	6B
0005435957627	615	13	7D
0005435957631	615	14	18A
0005433420280	615	15	18C
0005435957630	615	16	19A
0005435957632	615	17	19C
0005433420308	615	18	20A
0005435957621	615	19	20C
0005433420278	615	20	20D
0005433420277	615	21	21C
0005435957626	615	22	22A
0005435957629	615	23	21D
0005433420262	615	24	22C
0005433420263	615	25	22D
0005435957548	15212	1	1A
0005435957495	15212	2	1B
0005435957542	15212	3	1D
0005433420360	15212	4	2A
0005433420364	15212	5	2C
0005433420359	15212	6	3A
0005435957547	15212	7	3C
0005433420361	15212	8	3D
0005435957555	15212	9	5B
0005435957493	15212	10	5C
0005435957494	15212	11	6A
0005435957502	15212	12	7A
0005433420362	15212	13	7B
0005435957464	15212	14	18A
0005433420358	15212	15	19A
0005433420357	15212	16	19B
0005435957521	15212	17	19C
0005433420363	15212	18	19D
0005435957468	15212	19	20A
0005433420355	15212	20	20D
0005435957503	15212	21	22A
0005435957543	15212	22	22C
0005433420356	15212	23	23B
0005435629399	8913	1	1A
0005434247113	8913	2	3A
0005434247112	8913	3	2B
0005434247106	8913	4	4B
0005434247134	16014	1	2A
0005434247133	16014	2	3A
0005435629394	16014	3	6A
0005435933435	29527	1	1A
0005435163179	29527	2	1C
0005435163139	29527	3	2A
0005435163161	29527	4	2B
0005435163165	29527	5	2C
0005435933430	29527	6	3C
0005435163151	29527	7	3D
0005435933432	29527	8	4C
0005435163164	29527	9	5B
0005435163149	29527	10	5D
0005435163148	29527	11	6B
0005435163153	29527	12	6C
0005435933437	29527	13	7A
0005435933438	29527	14	18A
0005435163156	29527	15	18B
0005435933429	29527	16	19A
0005435163159	29527	17	19B
0005435933436	29527	18	19D
0005435163160	29527	19	20D
0005435933431	29527	20	21A
0005435933434	29527	21	21D
0005435933433	29527	22	22C
0005435163150	29527	23	23A
0005433404698	2832	1	5A
0005433404720	2832	2	6C
0005435797406	2832	3	7A
0005435797402	2832	4	7C
0005433404694	2832	5	7E
0005435797408	2832	6	8A
0005435797410	2832	7	8D
0005435797405	2832	8	9A
0005435797398	2832	9	10E
0005435797397	2832	10	11A
0005435797401	2832	11	11E
0005435797403	2832	12	11F
0005435797407	2832	13	12F
0005435797409	2832	14	13E
0005433404697	2832	15	14C
0005435797400	2832	16	15C
0005435797399	2832	17	15D
0005433404721	2832	18	16C
0005435797404	2832	19	17E
0005433404703	2832	20	18D
0005433404772	29330	1	2A
0005435797334	29330	2	3A
0005433404773	29330	3	4F
0005435797263	29330	4	6A
0005435797278	29330	5	6C
0005435797262	29330	6	6D
0005435797276	29330	7	8D
0005435797300	29330	8	9A
0005433404774	29330	9	10D
0005435797301	29330	10	16C
0005433404771	29330	11	17C
0005435797279	29330	12	17D
0005433404770	29330	13	19D
0005433404768	29330	14	20D
0005433404769	29330	15	20F
0005434947975	5792	1	1B
0005434947976	5792	2	2B
0005434947981	5792	3	2A
0005434947974	5792	4	3A
0005434947978	5792	5	3B
0005434947983	5792	6	4A
0005434947977	5792	7	4B
0005434947980	5792	8	5A
0005434947979	5792	9	6A
0005434947982	5792	10	6B
0005435376336	16379	1	1A
0005435376338	16379	2	1B
0005434947918	16379	3	2A
0005435376339	16379	4	2B
0005434947919	16379	5	3A
0005434947917	16379	6	3B
0005434947931	16379	7	4A
0005435376337	16379	8	4B
0005435376340	16379	9	5A
0005434947925	16379	10	6A
0005434947916	16379	11	5B
0005433960625	6933	1	1F
0005433960588	6933	2	2A
0005433960579	6933	3	2D
0005433960575	6933	4	3A
0005433960616	6933	5	3C
0005433960586	6933	6	3F
0005433960580	6933	7	4C
0005433960626	6933	8	4D
0005433960578	6933	9	5C
0005433960622	6933	10	5D
0005433960587	6933	11	5F
0005433960590	6933	12	6A
0005433960576	6933	13	6C
0005433960591	6933	14	6D
0005433960583	6933	15	6E
0005433960621	6933	16	6F
0005433960612	6933	17	7A
0005433960597	6933	18	7F
0005433960584	6933	19	8C
0005433960605	6933	20	9A
0005433960585	6933	21	9C
0005433960607	6933	22	9F
0005433960581	6933	23	10A
0005433960615	6933	24	10C
0005433960603	6933	25	10F
0005433960619	6933	26	11A
0005433960595	6933	27	11C
0005433960582	6933	28	11D
0005433960611	6933	29	11F
0005433960601	6933	30	12C
0005433960574	6933	31	12D
0005433960600	6933	32	12E
0005433960617	6933	33	12F
0005433960596	6933	34	13C
0005433960604	6933	35	13D
0005433960623	6933	36	13E
0005433960577	6933	37	13F
0005433960589	6933	38	14A
0005433960627	6933	39	14D
0005433960610	6933	40	14E
0005433960598	6933	41	14F
0005433960620	6933	42	15A
0005433960614	6933	43	15E
0005433960599	6933	44	15F
0005433960624	6933	45	16E
0005433960572	6933	46	16F
0005433960606	6933	47	17F
0005433960592	6933	48	18A
0005433960618	6933	49	18C
0005433960593	6933	50	18D
0005433960594	6933	51	18E
0005433960628	6933	52	19D
0005433960609	6933	53	19E
0005433960573	6933	54	20A
0005433960608	6933	55	20C
0005433960602	6933	56	20D
0005433960613	6933	57	20F
0005433959920	25736	1	1C
0005433959863	25736	2	1D
0005433960002	25736	3	2C
0005433959905	25736	4	3A
0005433959939	25736	5	3F
0005433959977	25736	6	4E
0005433959918	25736	7	5A
0005433959973	25736	8	5D
0005433959910	25736	9	6D
0005433959962	25736	10	6E
0005433959876	25736	11	6F
0005433959864	25736	12	7A
0005433959965	25736	13	7D
0005433959887	25736	14	8C
0005433959974	25736	15	8D
0005433959878	25736	16	8F
0005433959994	25736	17	10D
0005433959976	25736	18	11C
0005433959938	25736	19	11F
0005433959889	25736	20	12A
0005433959875	25736	21	12C
0005433959866	25736	22	12D
0005433959919	25736	23	12E
0005433959953	25736	24	12F
0005433959879	25736	25	13C
0005433959961	25736	26	13F
0005433959862	25736	27	14C
0005433959870	25736	28	15C
0005433959886	25736	29	15D
0005433959993	25736	30	15E
0005433959880	25736	31	16A
0005433959881	25736	32	16C
0005433959964	25736	33	17A
0005433959955	25736	34	17E
0005433960001	25736	35	17F
0005433959982	25736	36	18D
0005433959877	25736	37	18E
0005433959940	25736	38	18F
0005433960000	25736	39	19A
0005433960003	25736	40	19C
0005433959899	25736	41	19E
0005433959954	25736	42	19F
0005433959906	25736	43	20A
0005433959867	25736	44	20E
0005433959927	25736	45	20F
0005435082670	24529	1	1A
0005435082663	24529	2	1B
0005435082676	24529	3	2A
0005435082662	24529	4	2B
0005435082654	24529	5	3B
0005435082699	24529	6	4A
0005435082709	24529	7	5B
0005435082668	24529	8	6A
0005435082700	24529	9	6B
0005435082739	26059	1	2B
0005435082737	26059	2	3A
0005435082736	26059	3	4A
0005435082741	26059	4	5A
0005435082738	26059	5	6A
0005435082740	26059	6	6B
0005435286557	5065	1	2F
0005434244845	5065	2	4F
0005434244825	5065	3	5D
0005434244828	5065	4	6C
0005434244822	5065	5	7F
0005434244818	5065	6	8E
0005434244839	5065	7	9C
0005434244831	5065	8	9F
0005432166884	5065	9	9E
0005434244824	5065	10	11D
0005434244844	5065	11	11E
0005434244820	5065	12	13B
0005434244819	5065	13	15B
0005434244817	5065	14	15C
0005434244835	5065	15	15E
0005434244827	5065	16	16A
0005434244826	5065	17	16B
0005434244832	5065	18	16D
0005434244830	5065	19	16E
0005434244837	5065	20	17B
0005434244834	5065	21	17D
0005434244816	5065	22	19C
0005434244840	5065	23	21B
0005432166883	5065	24	21D
0005434244842	5065	25	21E
0005434244833	5065	26	24B
0005435286545	5065	27	25E
0005435286546	5065	28	26A
0005434244841	5065	29	26E
0005434244843	5065	30	28B
0005434244829	5065	31	28D
0005434244838	5065	32	29A
0005432166885	5065	33	29F
0005434244821	5065	34	29E
0005434244836	5065	35	30F
0005434244823	5065	36	31F
0005433614303	5064	1	1A
0005433614343	5064	2	1C
0005432105349	5064	3	1D
0005432105338	5064	4	2A
0005432105310	5064	5	1F
0005433784753	5064	6	2C
0005433784765	5064	7	2F
0005433614354	5064	8	2D
0005433614350	5064	9	3A
0005433784762	5064	10	3C
0005433784759	5064	11	3D
0005432666378	5064	12	4A
0005433614285	5064	13	3F
0005433614313	5064	14	4C
0005433614302	5064	15	4D
0005433784770	5064	16	5A
0005433614320	5064	17	4F
0005432145103	5064	18	5C
0005433784743	5064	19	5D
0005432105317	5064	20	6A
0005433614339	5064	21	5F
0005433614327	5064	22	6C
0005433614296	5064	23	6D
0005432105302	5064	24	7A
0005433614340	5064	25	6F
0005433784768	5064	26	7C
0005433614335	5064	27	7F
0005433614323	5064	28	7D
0005432105324	5064	29	8A
0005433614305	5064	30	8B
0005433614295	5064	31	8D
0005432105326	5064	32	8C
0005433614326	5064	33	8E
0005433614322	5064	34	8F
0005433614356	5064	35	9A
0005433614358	5064	36	9C
0005432665263	5064	37	9B
0005433784771	5064	38	9D
0005433614329	5064	39	9E
0005433614330	5064	40	10A
0005433784747	5064	41	9F
0005432105300	5064	42	10B
0005432105348	5064	43	10D
0005433784761	5064	44	10C
0005433784772	5064	45	10E
0005433614318	5064	46	10F
0005433784766	5064	47	11B
0005433614333	5064	48	11A
0005432105320	5064	49	11C
0005432105337	5064	50	11D
0005432105314	5064	51	11E
0005433614347	5064	52	12A
0005433614337	5064	53	11F
0005432105299	5064	54	12B
0005433614332	5064	55	12C
0005432105306	5064	56	12D
0005433614328	5064	57	12F
0005432145100	5064	58	12E
0005432145102	5064	59	13B
0005433614319	5064	60	13A
0005432105344	5064	61	13C
0005432665264	5064	62	13D
0005432105330	5064	63	13E
0005433614336	5064	64	14A
0005433614315	5064	65	13F
0005433784745	5064	66	14B
0005433784750	5064	67	14D
0005433784760	5064	68	14C
0005433614304	5064	69	14E
0005432105312	5064	70	14F
0005432105333	5064	71	15B
0005432105325	5064	72	15A
0005433614331	5064	73	15C
0005432105334	5064	74	15D
0005433784758	5064	75	15F
0005432105309	5064	76	15E
0005433614290	5064	77	16A
0005432105313	5064	78	16C
0005433614357	5064	79	16B
0005433614344	5064	80	16D
0005433614301	5064	81	16E
0005432105301	5064	82	16F
0005433784769	5064	83	17B
0005432105347	5064	84	17A
0005432105322	5064	85	17C
0005433784741	5064	86	17E
0005433784754	5064	87	17D
0005433614307	5064	88	17F
0005432105336	5064	89	18A
0005432145101	5064	90	18B
0005433614297	5064	91	18C
0005433784742	5064	92	18E
0005433614312	5064	93	18D
0005433614334	5064	94	19B
0005433614300	5064	95	18F
0005432105340	5064	96	19C
0005433614355	5064	97	19D
0005432105303	5064	98	19E
0005432105311	5064	99	20B
0005433614286	5064	100	20A
0005433784744	5064	101	20C
0005432667442	5064	102	20E
0005433614353	5064	103	20D
0005433784767	5064	104	20F
0005433614294	5064	105	21A
0005432105319	5064	106	21C
0005433784755	5064	107	21B
0005432105316	5064	108	21D
0005433784763	5064	109	21E
0005433614311	5064	110	22A
0005433614316	5064	111	21F
0005433614346	5064	112	22B
0005433614321	5064	113	22C
0005433784740	5064	114	22E
0005432105329	5064	115	22D
0005432105308	5064	116	22F
0005433614298	5064	117	23A
0005433614351	5064	118	23B
0005432666377	5064	119	23D
0005432105304	5064	120	23C
0005432105307	5064	121	23E
0005433614289	5064	122	24A
0005432105341	5064	123	23F
0005433784757	5064	124	24B
0005432105345	5064	125	24C
0005433614314	5064	126	24D
0005432105318	5064	127	24F
0005433614287	5064	128	24E
0005432105305	5064	129	25A
0005432105321	5064	130	25B
0005433614310	5064	131	25D
0005433784739	5064	132	25C
0005432105331	5064	133	25E
0005433614309	5064	134	26A
0005433784748	5064	135	25F
0005433614348	5064	136	26C
0005433784752	5064	137	26B
0005432105328	5064	138	26E
0005432105332	5064	139	26D
0005433784746	5064	140	26F
0005433614299	5064	141	27A
0005433784751	5064	142	27C
0005432105323	5064	143	27D
0005433614308	5064	144	27F
0005433784764	5064	145	27E
0005433614325	5064	146	28A
0005433614288	5064	147	28B
0005433784749	5064	148	28C
0005432105343	5064	149	28D
0005433614292	5064	150	28F
0005432105315	5064	151	28E
0005433614341	5064	152	29B
0005433614291	5064	153	29A
0005432105335	5064	154	29C
0005433614306	5064	155	29D
0005433614352	5064	156	29E
0005433614293	5064	157	30A
0005432105346	5064	158	29F
0005433614342	5064	159	30B
0005433614349	5064	160	30C
0005433784756	5064	161	30E
0005433614345	5064	162	30D
0005433614338	5064	163	31A
0005432105327	5064	164	30F
0005432105339	5064	165	31C
0005433614324	5064	166	31B
0005432105342	5064	167	31D
0005432667443	5064	168	31F
0005433614317	5064	169	31E
0005433688774	5062	1	1D
0005435006765	5062	2	1C
0005434149666	5062	3	2A
0005435006690	5062	4	2D
0005435006689	5062	5	2C
0005434265013	5062	6	3A
0005434229257	5062	7	3D
0005433688775	5062	8	4A
0005434312284	5062	9	3F
0005434265017	5062	10	4F
0005435006676	5062	11	4D
0005434149674	5062	12	5A
0005434229245	5062	13	5D
0005435006722	5062	14	5C
0005433685491	5062	15	5F
0005434229243	5062	16	6A
0005434264993	5062	17	6D
0005434229254	5062	18	7A
0005435006712	5062	19	7C
0005434312289	5062	20	8B
0005435006677	5062	21	8C
0005435006709	5062	22	8D
0005432335872	5062	23	8F
0005434229260	5062	24	9A
0005434229263	5062	25	9C
0005434149673	5062	26	9E
0005434265004	5062	27	9D
0005434229246	5062	28	10A
0005434149668	5062	29	10B
0005434265008	5062	30	10C
0005434311186	5062	31	10E
0005434265006	5062	32	10F
0005434173500	5062	33	11B
0005435006691	5062	34	11A
0005434265001	5062	35	11C
0005432335877	5062	36	11D
0005434149667	5062	37	11F
0005435006653	5062	38	11E
0005432335863	5062	39	12E
0005434312290	5062	40	13A
0005434149669	5062	41	13C
0005432335843	5062	42	13B
0005432335876	5062	43	13D
0005434265000	5062	44	13E
0005434264998	5062	45	14A
0005432335857	5062	46	13F
0005435006810	5062	47	14C
0005434229244	5062	48	14B
0005435006688	5062	49	15C
0005434264995	5062	50	15D
0005434264992	5062	51	15E
0005434229259	5062	52	16A
0005432335870	5062	53	15F
0005435006749	5062	54	16B
0005435006781	5062	55	16C
0005434173498	5062	56	16E
0005434265010	5062	57	16F
0005434265011	5062	58	17A
0005434264999	5062	59	17C
0005435006634	5062	60	17B
0005434265015	5062	61	18C
0005434149676	5062	62	18E
0005434312294	5062	63	18D
0005435006713	5062	64	19D
0005434229248	5062	65	19C
0005434265012	5062	66	20B
0005434229249	5062	67	20C
0005434149671	5062	68	20F
0005434173499	5062	69	21A
0005434229252	5062	70	21B
0005434229247	5062	71	21D
0005433815311	5062	72	21C
0005434265002	5062	73	21E
0005434265014	5062	74	22A
0005434264997	5062	75	22E
0005434229255	5062	76	23A
0005435006663	5062	77	23C
0005435006654	5062	78	24A
0005434229251	5062	79	24D
0005434229250	5062	80	24F
0005432335856	5062	81	24E
0005434229261	5062	82	25A
0005434149672	5062	83	25D
0005432335929	5062	84	25C
0005432335883	5062	85	25E
0005435006698	5062	86	26A
0005434149670	5062	87	26C
0005435006669	5062	88	26D
0005434229256	5062	89	26E
0005434265016	5062	90	26F
0005435006699	5062	91	27C
0005434265018	5062	92	27B
0005432335842	5062	93	27D
0005434149675	5062	94	28A
0005434265009	5062	95	28E
0005435006759	5062	96	28D
0005435269644	5062	97	29A
0005434264996	5062	98	28F
0005435006668	5062	99	29B
0005434265003	5062	100	29D
0005434229262	5062	101	29C
0005434311187	5062	102	29F
0005434229258	5062	103	30B
0005434229264	5062	104	30C
0005434264994	5062	105	30F
0005435006608	5062	106	30E
0005434229265	5062	107	31A
0005435006741	5062	108	31C
0005434265005	5062	109	31D
0005434265007	5062	110	31F
0005434229253	5062	111	31E
0005433784369	8380	1	2A
0005434244671	8380	2	1F
0005434244606	8380	3	2D
0005433784505	8380	4	3A
0005435269724	8380	5	3C
0005433784450	8380	6	3D
0005433784539	8380	7	4A
0005433784343	8380	8	3F
0005434244672	8380	9	4C
0005433784338	8380	10	5A
0005434244561	8380	11	4F
0005434244557	8380	12	5F
0005433784337	8380	13	5D
0005434244612	8380	14	6A
0005435269719	8380	15	6F
0005435269712	8380	16	7C
0005435269711	8380	17	8A
0005433784454	8380	18	7F
0005435269723	8380	19	8F
0005433784422	8380	20	9B
0005435269720	8380	21	9A
0005434244573	8380	22	9E
0005435269706	8380	23	10A
0005433784453	8380	24	10D
0005434244710	8380	25	11B
0005434244578	8380	26	11A
0005433784346	8380	27	12A
0005435269709	8380	28	11F
0005434244711	8380	29	12E
0005434244524	8380	30	12F
0005433784525	8380	31	13A
0005435269705	8380	32	13C
0005433784349	8380	33	13D
0005433784514	8380	34	13F
0005434244709	8380	35	15A
0005433784398	8380	36	14F
0005433784407	8380	37	15B
0005434244517	8380	38	15C
0005435269714	8380	39	15D
0005433784408	8380	40	15F
0005434244649	8380	41	16A
0005434244581	8380	42	16B
0005433784325	8380	43	16D
0005435269716	8380	44	16E
0005434244609	8380	45	17A
0005433784532	8380	46	17C
0005434244634	8380	47	17F
0005435269707	8380	48	17E
0005433784410	8380	49	18A
0005434244558	8380	50	18C
0005433784516	8380	51	18B
0005433784371	8380	52	18D
0005434244720	8380	53	18F
0005435269715	8380	54	20A
0005434244560	8380	55	20B
0005433784459	8380	56	20D
0005433784348	8380	57	20F
0005434244580	8380	58	21C
0005433784478	8380	59	21B
0005433784347	8380	60	21E
0005433784370	8380	61	21D
0005433784590	8380	62	22A
0005435269704	8380	63	22D
0005435269713	8380	64	22C
0005434244670	8380	65	22F
0005435269717	8380	66	23A
0005433784421	8380	67	23B
0005434244613	8380	68	23D
0005434244648	8380	69	23F
0005435269718	8380	70	24B
0005432659671	8380	71	24A
0005433784489	8380	72	24E
0005433784548	8380	73	25A
0005433784394	8380	74	24F
0005434244518	8380	75	25D
0005433784481	8380	76	25F
0005434244584	8380	77	25E
0005435269722	8380	78	26A
0005435269708	8380	79	26B
0005434244608	8380	80	26D
0005433784517	8380	81	26C
0005433784511	8380	82	26E
0005433784438	8380	83	27C
0005434244692	8380	84	27F
0005434244540	8380	85	28B
0005434244563	8380	86	28C
0005434244633	8380	87	28E
0005435269721	8380	88	28F
0005433784538	8380	89	29B
0005433784372	8380	90	29A
0005434244541	8380	91	29C
0005434244645	8380	92	29E
0005433784455	8380	93	30A
0005433784342	8380	94	30B
0005434244640	8380	95	30C
0005434244639	8380	96	30E
0005433784414	8380	97	31A
0005435269710	8380	98	31B
0005433784384	8380	99	31F
0005433613658	8381	1	1A
0005433613537	8381	2	1F
0005433613479	8381	3	1D
0005433613483	8381	4	2F
0005433613702	8381	5	3C
0005433613469	8381	6	3A
0005433613621	8381	7	3F
0005433613713	8381	8	4C
0005433613680	8381	9	5C
0005433613735	8381	10	7D
0005433613466	8381	11	8C
0005433613515	8381	12	9B
0005433613697	8381	13	10A
0005433613677	8381	14	10E
0005433613596	8381	15	10D
0005433613531	8381	16	10F
0005433613705	8381	17	11C
0005433613536	8381	18	11B
0005433613507	8381	19	12F
0005433613468	8381	20	13D
0005433613841	8381	21	13F
0005433613714	8381	22	14C
0005433613725	8381	23	14E
0005433613607	8381	24	15C
0005433613655	8381	25	15D
0005433613636	8381	26	16D
0005433613547	8381	27	18B
0005433613701	8381	28	19B
0005433613673	8381	29	20C
0005433613623	8381	30	22A
0005433613552	8381	31	23D
0005433613605	8381	32	23E
0005433613574	8381	33	24D
0005433613597	8381	34	24E
0005433613497	8381	35	25F
0005433613553	8381	36	26E
0005433613622	8381	37	26D
0005433613598	8381	38	27C
0005433613606	8381	39	27B
0005433613752	8381	40	27D
0005433613482	8381	41	28A
0005433613517	8381	42	28E
0005433613715	8381	43	29A
0005433613555	8381	44	29D
0005433613793	8381	45	30A
0005433613850	8381	46	30B
0005433613690	8381	47	31A
0005433613575	8381	48	31D
0005433613506	8381	49	31F
0005434149552	8382	1	1A
0005435006902	8382	2	1C
0005434149586	8382	3	1F
0005435006916	8382	4	1D
0005433815360	8382	5	2A
0005432047529	8382	6	2C
0005432034810	8382	7	2F
0005432034804	8382	8	2D
0005435286597	8382	9	3A
0005432034792	8382	10	3C
0005434149523	8382	11	3F
0005432034793	8382	12	4A
0005433534488	8382	13	4C
0005433815363	8382	14	4D
0005434149660	8382	15	5A
0005434264729	8382	16	4F
0005432034811	8382	17	5C
0005432034815	8382	18	5F
0005434264802	8382	19	5D
0005434229049	8382	20	6A
0005434229037	8382	21	6D
0005434229038	8382	22	6C
0005435006898	8382	23	6F
0005432034791	8382	24	7A
0005432034806	8382	25	7C
0005434173479	8382	26	7D
0005434229064	8382	27	8A
0005432034805	8382	28	8B
0005432034817	8382	29	8D
0005435006911	8382	30	8C
0005432335974	8382	31	8E
0005434149597	8382	32	8F
0005433688799	8382	33	9B
0005435006914	8382	34	9A
0005432034809	8382	35	9C
0005435006917	8382	36	9E
0005434264745	8382	37	9D
0005434264783	8382	38	10A
0005432034799	8382	39	9F
0005434264838	8382	40	10B
0005435286599	8382	41	10C
0005434228994	8382	42	10E
0005435006907	8382	43	10D
0005434229094	8382	44	10F
0005433815361	8382	45	11A
0005434229083	8382	46	11B
0005432034795	8382	47	11E
0005433534486	8382	48	12A
0005432335971	8382	49	11F
0005432335967	8382	50	12C
0005432335970	8382	51	12B
0005432034798	8382	52	12D
0005434264710	8382	53	13B
0005432034801	8382	54	13C
0005435006912	8382	55	13D
0005435006899	8382	56	13E
0005435006894	8382	57	13F
0005434228982	8382	58	14A
0005434229009	8382	59	14D
0005432335973	8382	60	14E
0005432034803	8382	61	14F
0005434229000	8382	62	15B
0005432047531	8382	63	15C
0005434229082	8382	64	15D
0005435006908	8382	65	15E
0005435286602	8382	66	16A
0005434264775	8382	67	16C
0005435006893	8382	68	16B
0005435006904	8382	69	16E
0005434264821	8382	70	16D
0005434311209	8382	71	17A
0005434149522	8382	72	16F
0005434264865	8382	73	17B
0005435006915	8382	74	17C
0005433689901	8382	75	17F
0005432047530	8382	76	17E
0005432034802	8382	77	18A
0005435006901	8382	78	18C
0005434229092	8382	79	18B
0005432335975	8382	80	18D
0005432034797	8382	81	18E
0005432034816	8382	82	19B
0005434229036	8382	83	19D
0005435286598	8382	84	20B
0005432335978	8382	85	20A
0005435006918	8382	86	20C
0005432034813	8382	87	20D
0005434264784	8382	88	20E
0005434229063	8382	89	21A
0005435006895	8382	90	20F
0005433815362	8382	91	21C
0005434173455	8382	92	21B
0005435006910	8382	93	21D
0005432034812	8382	94	21F
0005435006906	8382	95	21E
0005435286603	8382	96	22A
0005432335969	8382	97	22D
0005434149598	8382	98	22C
0005434149560	8382	99	22E
0005434264730	8382	100	22F
0005434173462	8382	101	23A
0005434264731	8382	102	23C
0005434264721	8382	103	23D
0005432335976	8382	104	23F
0005435006896	8382	105	23E
0005435006913	8382	106	24B
0005434149533	8382	107	24A
0005434229096	8382	108	24D
0005433688798	8382	109	24C
0005432034819	8382	110	24E
0005434173463	8382	111	24F
0005433815359	8382	112	25B
0005435286604	8382	113	25A
0005434149535	8382	114	25C
0005434149524	8382	115	25F
0005432034800	8382	116	25E
0005434264834	8382	117	26A
0005432034794	8382	118	26B
0005434229118	8382	119	26C
0005435286600	8382	120	26E
0005434149532	8382	121	26D
0005435006903	8382	122	26F
0005432047532	8382	123	27B
0005435006897	8382	124	27A
0005435286596	8382	125	27D
0005432034814	8382	126	27F
0005435286601	8382	127	27E
0005435006909	8382	128	28A
0005432335968	8382	129	28B
0005434264785	8382	130	28C
0005434149568	8382	131	28D
0005434264871	8382	132	28F
0005432335977	8382	133	29A
0005435006905	8382	134	29C
0005432034808	8382	135	29B
0005434264698	8382	136	29D
0005434229095	8382	137	29F
0005432034807	8382	138	29E
0005434173464	8382	139	30B
0005434264776	8382	140	30A
0005432034796	8382	141	30D
0005432335972	8382	142	30C
0005435006900	8382	143	30F
0005434149569	8382	144	30E
0005433689900	8382	145	31B
0005434264801	8382	146	31A
0005434264833	8382	147	31C
0005433534487	8382	148	31F
0005432034818	8382	149	31E
0005433202288	12609	1	1A
0005433202285	12609	2	1B
0005434638965	12609	3	1C
0005433202294	12609	4	1D
0005434639035	12609	5	2A
0005434639047	12609	6	2D
0005434639008	12609	7	3A
0005434638966	12609	8	3B
0005434639056	12609	9	3C
0005434638884	12609	10	4A
0005433202292	12609	11	4B
0005433202290	12609	12	4C
0005433202289	12609	13	4D
0005433202283	12609	14	5A
0005433202287	12609	15	5B
0005433202291	12609	16	5C
0005434639075	12609	17	5D
0005433202284	12609	18	6A
0005434638933	12609	19	6B
0005434639055	12609	20	6D
0005434639007	12609	21	7A
0005434639021	12609	22	7B
0005433202296	12609	23	7D
0005433202293	12609	24	18B
0005434639052	12609	25	18C
0005434638977	12609	26	18D
0005434638998	12609	27	19A
0005434638897	12609	28	19B
0005433202295	12609	29	19C
0005434639016	12609	30	19D
0005434638883	12609	31	20A
0005434638865	12609	32	20B
0005434639089	12609	33	20C
0005434639076	12609	34	21A
0005434639036	12609	35	21B
0005434638997	12609	36	21C
0005434639046	12609	37	21D
0005434639074	12609	38	22A
0005434638936	12609	39	22B
0005433202286	12609	40	22C
0005433202297	12609	41	22D
0005434638902	12609	42	23B
0005434639175	23350	1	1A
0005434639164	23350	2	1B
0005433202153	23350	3	1C
0005434639162	23350	4	1D
0005434639171	23350	5	2A
0005434639156	23350	6	2B
0005434639174	23350	7	2D
0005434639173	23350	8	3A
0005433202171	23350	9	3B
0005433202130	23350	10	3C
0005434639176	23350	11	3D
0005434639179	23350	12	4A
0005434639154	23350	13	4B
0005434639161	23350	14	4C
0005434639155	23350	15	4D
0005433202137	23350	16	5A
0005434639166	23350	17	5B
0005433202131	23350	18	5C
0005432290615	23350	19	5D
0005433202190	23350	20	6A
0005433202105	23350	21	6B
0005434639157	23350	22	6C
0005433202104	23350	23	6D
0005434639167	23350	24	7A
0005432290616	23350	25	7B
0005434639159	23350	26	7C
0005434639177	23350	27	7D
0005434639165	23350	28	18A
0005434639168	23350	29	18B
0005434639169	23350	30	18C
0005434639180	23350	31	18D
0005433202173	23350	32	19A
0005433202167	23350	33	19B
0005434639170	23350	34	19C
0005433202138	23350	35	19D
0005433202122	23350	36	20A
0005434639158	23350	37	20B
0005434639163	23350	38	20D
0005434639172	23350	39	21A
0005433202108	23350	40	21B
0005433202157	23350	41	21C
0005434639181	23350	42	21D
0005433202132	23350	43	22A
0005434639178	23350	44	22B
0005434639182	23350	45	22C
0005434639160	23350	46	23A
0005432054290	21068	1	1A
0005432382681	21068	2	1C
0005432382600	21068	3	1D
0005432382644	21068	4	1F
0005432382738	21068	5	2A
0005432328132	21068	6	2C
0005432382525	21068	7	2D
0005432382661	21068	8	2F
0005432382651	21068	9	3A
0005432327960	21068	10	3C
0005432382495	21068	11	3D
0005432328123	21068	12	3F
0005432382500	21068	13	4A
0005432382505	21068	14	4D
0005432328216	21068	15	4E
0005432327926	21068	16	4F
0005432328215	21068	17	5A
0005432382637	21068	18	5C
0005432382624	21068	19	5D
0005432054291	21068	20	5E
0005432327974	21068	21	5F
0005432382496	21068	22	6A
0005432328050	21068	23	6D
0005432382580	21068	24	6E
0005432328122	21068	25	6F
0005432327975	21068	26	7A
0005432328008	21068	27	7C
0005432328007	21068	28	7D
0005432382899	21068	29	7E
0005432054288	21068	30	7F
0005432382534	21068	31	8A
0005432382636	21068	32	8E
0005432382645	21068	33	8F
0005432382680	21068	34	9D
0005432328046	21068	35	9E
0005432382711	21068	36	9F
0005432328041	21068	37	10A
0005432382662	21068	38	10C
0005432382596	21068	39	10D
0005432382613	21068	40	10E
0005432327961	21068	41	10F
0005432382784	21068	42	11A
0005432327927	21068	43	11E
0005432382523	21068	44	11F
0005432328036	21068	45	12A
0005432382712	21068	46	12C
0005432327963	21068	47	12D
0005432328044	21068	48	12E
0005432328016	21068	49	12F
0005432328048	21068	50	13A
0005432382619	21068	51	13C
0005432382776	21068	52	13D
0005432382898	21068	53	13E
0005432382614	21068	54	14A
0005432328207	21068	55	14C
0005432382535	21068	56	14D
0005432382579	21068	57	14E
0005432382656	21068	58	14F
0005432328032	21068	59	15A
0005432382657	21068	60	15C
0005432382708	21068	61	15D
0005432328045	21068	62	15E
0005432382595	21068	63	15F
0005432382629	21068	64	16A
0005432382601	21068	65	16C
0005432327986	21068	66	16D
0005432328042	21068	67	16F
0005432328049	21068	68	17A
0005432328047	21068	69	17C
0005432054289	21068	70	17E
0005432328157	21068	71	18A
0005432382655	21068	72	18C
0005432327987	21068	73	18D
0005432327953	21068	74	18E
0005432382654	21068	75	18F
0005432327988	21068	76	19A
0005432327964	21068	77	19C
0005432382673	21068	78	19D
0005432328017	21068	79	19E
0005432328074	21068	80	19F
0005432327922	21068	81	20A
0005432382625	21068	82	20C
0005432328043	21068	83	20D
0005432382618	21068	84	20E
0005432327976	21068	85	20F
0005432328428	31229	1	1A
0005432287160	31229	2	1C
0005432328409	31229	3	1D
0005432328437	31229	4	1F
0005432382946	31229	5	2C
0005432382945	31229	6	2D
0005432328407	31229	7	2F
0005432382944	31229	8	3A
0005432328413	31229	9	3C
0005432328431	31229	10	3D
0005432382939	31229	11	3F
0005432382952	31229	12	4A
0005432328436	31229	13	4C
0005432382951	31229	14	4D
0005432382955	31229	15	4E
0005432382954	31229	16	4F
0005432328410	31229	17	5A
0005432328451	31229	18	5C
0005432382965	31229	19	5D
0005432382936	31229	20	5E
0005432328443	31229	21	5F
0005432382934	31229	22	6A
0005432382941	31229	23	6C
0005432287159	31229	24	6D
0005432382958	31229	25	6E
0005432382956	31229	26	6F
0005432382960	31229	27	7A
0005432382928	31229	28	7C
0005432328424	31229	29	7D
0005432382948	31229	30	7E
0005432328414	31229	31	7F
0005432328420	31229	32	8A
0005432328425	31229	33	8C
0005432287161	31229	34	8D
0005432328444	31229	35	8E
0005432382963	31229	36	8F
0005432382957	31229	37	9C
0005432328450	31229	38	9D
0005432328435	31229	39	9E
0005432328419	31229	40	9F
0005432328447	31229	41	10A
0005432328433	31229	42	10C
0005432328449	31229	43	10D
0005432382968	31229	44	10E
0005432382967	31229	45	10F
0005432328446	31229	46	11A
0005432328452	31229	47	11C
0005432328448	31229	48	11D
0005432328408	31229	49	11E
0005432328416	31229	50	11F
0005432328415	31229	51	12A
0005432328440	31229	52	12D
0005432328427	31229	53	12C
0005432382947	31229	54	12E
0005432287158	31229	55	12F
0005432382950	31229	56	13A
0005432328434	31229	57	13C
0005432328453	31229	58	13D
0005432382937	31229	59	13E
0005432382932	31229	60	14A
0005432382949	31229	61	14C
0005432382933	31229	62	14E
0005432328423	31229	63	14F
0005432382953	31229	64	15A
0005432382927	31229	65	15C
0005432328417	31229	66	15D
0005432328438	31229	67	15E
0005432328439	31229	68	15F
0005432328430	31229	69	16A
0005432328445	31229	70	16C
0005432382964	31229	71	16D
0005432382935	31229	72	16E
0005432328421	31229	73	16F
0005432328429	31229	74	17A
0005432382940	31229	75	17C
0005432382938	31229	76	17D
0005432382930	31229	77	17E
0005432328441	31229	78	17F
0005432328426	31229	79	18A
0005432328422	31229	80	18C
0005432382959	31229	81	18D
0005432328418	31229	82	18E
0005432382931	31229	83	18F
0005432382929	31229	84	19A
0005432382943	31229	85	19C
0005432382962	31229	86	19D
0005432328411	31229	87	19E
0005432328432	31229	88	19F
0005432382961	31229	89	20A
0005432382966	31229	90	20C
0005432328442	31229	91	20D
0005432382942	31229	92	20E
0005432328412	31229	93	20F
0005432424168	13352	1	2C
0005432424167	13352	2	2F
0005432424173	13352	3	3A
0005432424174	13352	4	3D
0005432424188	13352	5	4C
0005432424169	13352	6	4F
0005432424183	13352	7	5C
0005432424184	13352	8	5F
0005432424161	13352	9	8E
0005432424178	13352	10	8F
0005432424177	13352	11	10D
0005432424170	13352	12	11A
0005432424162	13352	13	11D
0005432424160	13352	14	11F
0005432424187	13352	15	12E
0005432424182	13352	16	12F
0005432424181	13352	17	13A
0005432424176	13352	18	13C
0005432424166	13352	19	14A
0005432424186	13352	20	14D
0005432424165	13352	21	14F
0005432424180	13352	22	15A
0005432424164	13352	23	15E
0005432424175	13352	24	15F
0005432424179	13352	25	16F
0005432424163	13352	26	18D
0005432424172	13352	27	19C
0005432424171	13352	28	20A
0005432424185	13352	29	20C
0005432423738	30763	1	1A
0005432423666	30763	2	1D
0005432423790	30763	3	1F
0005432423772	30763	4	2A
0005432423683	30763	5	2C
0005432423693	30763	6	3D
0005432423801	30763	7	4D
0005432423764	30763	8	5E
0005432423643	30763	9	5F
0005432423789	30763	10	6C
0005432423667	30763	11	6D
0005432423736	30763	12	7A
0005432423630	30763	13	7C
0005432423809	30763	14	7F
0005432423650	30763	15	8A
0005432423808	30763	16	8D
0005432423687	30763	17	8E
0005432423633	30763	18	8F
0005432423672	30763	19	9A
0005432423800	30763	20	9F
0005432423691	30763	21	10F
0005432423709	30763	22	11A
0005432423805	30763	23	12C
0005432423703	30763	24	12E
0005432423737	30763	25	12F
0005432423791	30763	26	13C
0005432423818	30763	27	14A
0005432423688	30763	28	14E
0005432423684	30763	29	14F
0005432423629	30763	30	15A
0005432423605	30763	31	17D
0005432423692	30763	32	17F
0005432423803	30763	33	18D
0005432423782	30763	34	18E
0005432423622	30763	35	19A
0005432423702	30763	36	19F
0005432423804	30763	37	20D
0005432423623	30763	38	20E
0005432822159	9574	1	1A
0005432822165	9574	2	1C
0005432817320	9574	3	1D
0005432817307	9574	4	1F
0005432901374	9574	5	2A
0005432901358	9574	6	2C
0005432817323	9574	7	2D
0005434157399	9574	8	2F
0005432817313	9574	9	3A
0005432288969	9574	10	3C
0005432817318	9574	11	3D
0005432901338	9574	12	3F
0005432901384	9574	13	4A
0005432822160	9574	14	4C
0005432288970	9574	15	4D
0005432817316	9574	16	4E
0005432817306	9574	17	5E
0005434448296	9574	18	5F
0005432822162	9574	19	6A
0005432822163	9574	20	6C
0005432817326	9574	21	6F
0005432817321	9574	22	7C
0005434157377	9574	23	7D
0005432817303	9574	24	7E
0005434448298	9574	25	7F
0005434448297	9574	26	8A
0005432901334	9574	27	8C
0005432822166	9574	28	8E
0005432817315	9574	29	8F
0005432817312	9574	30	9A
0005432817302	9574	31	9C
0005434157376	9574	32	9D
0005434157395	9574	33	9E
0005432817325	9574	34	10A
0005432901330	9574	35	10C
0005432901333	9574	36	10D
0005432817310	9574	37	10E
0005432817305	9574	38	10F
0005434157396	9574	39	11D
0005432817330	9574	40	11E
0005434157384	9574	41	12C
0005432817322	9574	42	12E
0005432901386	9574	43	12F
0005432901385	9574	44	13A
0005434157383	9574	45	13C
0005432817324	9574	46	13D
0005434157385	9574	47	13F
0005432817311	9574	48	14A
0005432817308	9574	49	14C
0005432817304	9574	50	14D
0005434157364	9574	51	14E
0005432817331	9574	52	14F
0005434157414	9574	53	15A
0005432901419	9574	54	15D
0005434157397	9574	55	15E
0005432817319	9574	56	15F
0005432901375	9574	57	16A
0005432817314	9574	58	16C
0005434157363	9574	59	16D
0005432901402	9574	60	16E
0005432817329	9574	61	16F
0005432822161	9574	62	17C
0005432901372	9574	63	17E
0005434157389	9574	64	17F
0005432288968	9574	65	18C
0005432817327	9574	66	18D
0005432288967	9574	67	18E
0005432817328	9574	68	18F
0005434157388	9574	69	19A
0005432817309	9574	70	19C
0005434157378	9574	71	19E
0005434157371	9574	72	19F
0005432817317	9574	73	20A
0005432901341	9574	74	20D
0005432822164	9574	75	20E
0005434157406	9574	76	20F
0005432816985	28964	1	1C
0005432901520	28964	2	2A
0005434157441	28964	3	2C
0005432901522	28964	4	2D
0005432822085	28964	5	3C
0005432901515	28964	6	3F
0005432816974	28964	7	4A
0005434157436	28964	8	4C
0005432901512	28964	9	4D
0005432817016	28964	10	4E
0005434157439	28964	11	5F
0005432822089	28964	12	6A
0005432901523	28964	13	6D
0005432817137	28964	14	6F
0005432817104	28964	15	7D
0005432817007	28964	16	7C
0005434157440	28964	17	8A
0005432817151	28964	18	8D
0005434157442	28964	19	8E
0005432817069	28964	20	8F
0005432901525	28964	21	9E
0005432901516	28964	22	9F
0005432901526	28964	23	10C
0005432816986	28964	24	10D
0005432817129	28964	25	10E
0005434157438	28964	26	12A
0005434448254	28964	27	12C
0005432817114	28964	28	12D
0005432817130	28964	29	12F
0005432002065	28964	30	13A
0005432901511	28964	31	14A
0005432817023	28964	32	14C
0005432822088	28964	33	14D
0005432817172	28964	34	14E
0005434186181	28964	35	14F
0005432901513	28964	36	15A
0005432901521	28964	37	15C
0005434448265	28964	38	15D
0005432901524	28964	39	15E
0005434448256	28964	40	15F
0005432901517	28964	41	16A
0005434448255	28964	42	16D
0005434157437	28964	43	16E
0005432901519	28964	44	16F
0005432817037	28964	45	17D
0005432901514	28964	46	17E
0005432901518	28964	47	18A
0005432901509	28964	48	18C
0005434186182	28964	49	18D
0005432817085	28964	50	19C
0005432901510	28964	51	19F
0005434186180	28964	52	20C
0005432817070	28964	53	20D
0005432822121	28964	54	20E
0005432822086	28964	55	20F
0005435841810	15080	1	1A
0005432613840	15080	2	2A
0005432611691	15080	3	2B
0005432613842	15080	4	3A
0005432613841	15080	5	3B
0005435841811	15080	6	4A
0005432613843	15080	7	4B
0005432611690	15080	8	5A
0005432613839	15080	9	5B
0005432611689	15080	10	6A
0005432611692	15080	11	6B
0005435841819	31553	1	1A
0005432607510	31553	2	2A
0005432607499	31553	3	2B
0005432611655	31553	4	3A
0005432607520	31553	5	4B
0005435841818	31553	6	5A
0005432607496	31553	7	5B
0005432607495	31553	8	6B
0005433568702	11851	1	1C
0005433568704	11851	2	1A
0005433568703	11851	3	1F
0005432947814	11851	4	1D
0005433568724	11851	5	2A
0005432947951	11851	6	2D
0005432947813	11851	7	2C
0005433568717	11851	8	3A
0005432947801	11851	9	2F
0005432947844	11851	10	3D
0005433568720	11851	11	3C
0005433568682	11851	12	4A
0005432947828	11851	13	3F
0005432948009	11851	14	4C
0005433568705	11851	15	4F
0005433568733	11851	16	4D
0005432947924	11851	17	5C
0005433568710	11851	18	5A
0005432947902	11851	19	5F
0005433568688	11851	20	5D
0005433568712	11851	21	6B
0005432947923	11851	22	6A
0005433568735	11851	23	6E
0005433568698	11851	24	6D
0005432947870	11851	25	6F
0005433568721	11851	26	7C
0005432947918	11851	27	7B
0005433568709	11851	28	7D
0005432947848	11851	29	7F
0005433568719	11851	30	7E
0005433568714	11851	31	8C
0005433568731	11851	32	8B
0005433568689	11851	33	8D
0005433568715	11851	34	9A
0005433568728	11851	35	8F
0005432947767	11851	36	9B
0005433568684	11851	37	9C
0005433568706	11851	38	9E
0005433568681	11851	39	9D
0005433568737	11851	40	10B
0005433568695	11851	41	10A
0005432947871	11851	42	9F
0005433568726	11851	43	10C
0005432947904	11851	44	10E
0005432947900	11851	45	10D
0005433568729	11851	46	11A
0005433568716	11851	47	10F
0005433568690	11851	48	11B
0005433568685	11851	49	11D
0005433568730	11851	50	11C
0005432947815	11851	51	11F
0005432947816	11851	52	11E
0005433568697	11851	53	12A
0005432947921	11851	54	12C
0005432947820	11851	55	12B
0005433568722	11851	56	12E
0005432947768	11851	57	12D
0005432947922	11851	58	12F
0005432947831	11851	59	13C
0005433568691	11851	60	13E
0005432947863	11851	61	13D
0005432947929	11851	62	14A
0005432947970	11851	63	13F
0005433568692	11851	64	14B
0005433568718	11851	65	14D
0005433568696	11851	66	14F
0005433568680	11851	67	14E
0005432947766	11851	68	15B
0005432947875	11851	69	15A
0005432947822	11851	70	15C
0005432947845	11851	71	15E
0005433568727	11851	72	15D
0005432947950	11851	73	16A
0005432947780	11851	74	16B
0005433568707	11851	75	16D
0005432947866	11851	76	16C
0005433568723	11851	77	16F
0005432947781	11851	78	16E
0005433568734	11851	79	17C
0005433568736	11851	80	17B
0005433568687	11851	81	17A
0005432947885	11851	82	17D
0005433568732	11851	83	18A
0005433568683	11851	84	18C
0005433568700	11851	85	18B
0005432947969	11851	86	18E
0005433568686	11851	87	18D
0005433568711	11851	88	19A
0005432947901	11851	89	19E
0005433568693	11851	90	19D
0005432948082	11851	91	19C
0005432947782	11851	92	19F
0005432947952	11851	93	20B
0005433568713	11851	94	20A
0005433568708	11851	95	20D
0005433568699	11851	96	20C
0005432947911	11851	97	20F
0005432947802	11851	98	20E
0005433568725	11851	99	21B
0005432948008	11851	100	21A
0005433568701	11851	101	21C
0005433568694	11851	102	21F
0005432947832	11851	103	21E
0005433568046	25269	1	1C
0005432948288	25269	2	1A
0005432948300	25269	3	1D
0005433568291	25269	4	2A
0005433568139	25269	5	2D
0005433568352	25269	6	2C
0005432948297	25269	7	3A
0005432948267	25269	8	2F
0005432948281	25269	9	3D
0005433568311	25269	10	3C
0005432948287	25269	11	4A
0005433568080	25269	12	3F
0005433568246	25269	13	4D
0005433568276	25269	14	4C
0005433568247	25269	15	5C
0005433568116	25269	16	5A
0005433568079	25269	17	5F
0005432948301	25269	18	6B
0005433568208	25269	19	6C
0005432948302	25269	20	6E
0005433568034	25269	21	7A
0005433568223	25269	22	7B
0005432948277	25269	23	7D
0005432948291	25269	24	7F
0005432948275	25269	25	8C
0005433568127	25269	26	8A
0005433568241	25269	27	8F
0005433568308	25269	28	8E
0005433568153	25269	29	9B
0005433568115	25269	30	9A
0005433568164	25269	31	9C
0005433568136	25269	32	9F
0005432948279	25269	33	9E
0005433568245	25269	34	9D
0005432948271	25269	35	10A
0005433568172	25269	36	10C
0005432948294	25269	37	10E
0005433568318	25269	38	10F
0005433568299	25269	39	11B
0005432948286	25269	40	11A
0005433568045	25269	41	11D
0005432948284	25269	42	11C
0005432948283	25269	43	11E
0005433568266	25269	44	12B
0005433568307	25269	45	12A
0005433568351	25269	46	12D
0005433568216	25269	47	12C
0005433568128	25269	48	12E
0005433568090	25269	49	13A
0005432948274	25269	50	12F
0005433568149	25269	51	13C
0005432948295	25269	52	13B
0005433568333	25269	53	13E
0005432948285	25269	54	13D
0005433568129	25269	55	14B
0005432948293	25269	56	14A
0005432948290	25269	57	14D
0005433568057	25269	58	14C
0005432948269	25269	59	14E
0005432948278	25269	60	15B
0005432948268	25269	61	15A
0005433568168	25269	62	15D
0005432948264	25269	63	15C
0005433568154	25269	64	15F
0005432948265	25269	65	15E
0005433568209	25269	66	16A
0005433568047	25269	67	16C
0005432948289	25269	68	16B
0005432948276	25269	69	16E
0005433568171	25269	70	16D
0005433568147	25269	71	17A
0005432948270	25269	72	16F
0005432948266	25269	73	17B
0005432948298	25269	74	17D
0005433568269	25269	75	17F
0005433568239	25269	76	17E
0005432948280	25269	77	18B
0005433568137	25269	78	18A
0005432948304	25269	79	18C
0005433568170	25269	80	18E
0005433568078	25269	81	18D
0005433568221	25269	82	19A
0005433568279	25269	83	18F
0005432948303	25269	84	19B
0005433568306	25269	85	19E
0005433568061	25269	86	19D
0005433568300	25269	87	20A
0005433568062	25269	88	19F
0005433568327	25269	89	20B
0005432948292	25269	90	20D
0005432948299	25269	91	20C
0005433568332	25269	92	20F
0005432948273	25269	93	20E
0005433568356	25269	94	21B
0005433568222	25269	95	21A
0005432948282	25269	96	21C
0005432948296	25269	97	21F
0005432948272	25269	98	21E
0005433568065	25269	99	21D
0005434654538	5421	1	1A
0005434654544	5421	2	1F
0005434654539	5421	3	2A
0005434654521	5421	4	2C
0005434654545	5421	5	3F
0005434654527	5421	6	4C
0005434654536	5421	7	4D
0005435340071	5421	8	5C
0005434654523	5421	9	5D
0005434654534	5421	10	5E
0005434654531	5421	11	6D
0005434654529	5421	12	6E
0005435340075	5421	13	7D
0005434654526	5421	14	7F
0005434654541	5421	15	8A
0005434654533	5421	16	8C
0005435340004	5421	17	8E
0005435340053	5421	18	9A
0005435555341	5421	19	9C
0005435340077	5421	20	9D
0005432114186	5421	21	9F
0005434654543	5421	22	10A
0005434654535	5421	23	10D
0005434654537	5421	24	11E
0005434654542	5421	25	11F
0005435340065	5421	26	12A
0005435340083	5421	27	12C
0005434654522	5421	28	12D
0005434654518	5421	29	13A
0005435340029	5421	30	13C
0005435555334	5421	31	13F
0005435340008	5421	32	14A
0005434654532	5421	33	14C
0005432114187	5421	34	14D
0005435555335	5421	35	14F
0005434656545	5421	36	15A
0005434654528	5421	37	15E
0005434654540	5421	38	16D
0005434656546	5421	39	16E
0005435555344	5421	40	17C
0005434654546	5421	41	17E
0005434654520	5421	42	17F
0005434654547	5421	43	18D
0005435340052	5421	44	18F
0005434654519	5421	45	19A
0005434654530	5421	46	19C
0005434654525	5421	47	19D
0005435340087	5421	48	19F
0005435340007	5421	49	20A
0005432114185	5421	50	20E
0005434654524	5421	51	20F
0005434654418	12536	1	1A
0005435340184	12536	2	1C
0005435340190	12536	3	1D
0005435340176	12536	4	1F
0005434654222	12536	5	2A
0005434656524	12536	6	2D
0005435340179	12536	7	3C
0005434654419	12536	8	3D
0005435340180	12536	9	3F
0005435555360	12536	10	4C
0005434654420	12536	11	4D
0005434654358	12536	12	5A
0005434656530	12536	13	5E
0005434654274	12536	14	5F
0005434654231	12536	15	6A
0005434654173	12536	16	6D
0005434656531	12536	17	7A
0005434654351	12536	18	8A
0005434654394	12536	19	8C
0005434654349	12536	20	8F
0005434654368	12536	21	10A
0005435340182	12536	22	10C
0005435340187	12536	23	10D
0005434654350	12536	24	10E
0005435340189	12536	25	11A
0005434654314	12536	26	11C
0005434654366	12536	27	11D
0005434654167	12536	28	11F
0005434654218	12536	29	12A
0005434654277	12536	30	13E
0005435340183	12536	31	14A
0005435555361	12536	32	14C
0005434654275	12536	33	14E
0005435340181	12536	34	14F
0005434654290	12536	35	15A
0005434654248	12536	36	15E
0005435340178	12536	37	15F
0005435340185	12536	38	16D
0005434654356	12536	39	16F
0005435340177	12536	40	17A
0005434654247	12536	41	17C
0005435340191	12536	42	17E
0005435555359	12536	43	17F
0005434654403	12536	44	18C
0005435340175	12536	45	18D
0005434654357	12536	46	18E
0005434656527	12536	47	19A
0005435340188	12536	48	19F
0005435340186	12536	49	20A
0005434654296	12536	50	20C
0005434654207	12536	51	20D
0005434654172	12536	52	20E
0005432428882	7460	1	1A
0005433715688	7460	2	1C
0005433715722	7460	3	2A
0005433689899	7460	4	2F
0005433715704	7460	5	3A
0005433715718	7460	6	3C
0005433715693	7460	7	3F
0005433719120	7460	8	4B
0005433722182	7460	9	4D
0005432078080	7460	10	4E
0005433722183	7460	11	5A
0005433715697	7460	12	4F
0005433715706	7460	13	5B
0005433715725	7460	14	5D
0005433719121	7460	15	5E
0005433688797	7460	16	6A
0005433715724	7460	17	6B
0005435266097	7460	18	6C
0005433656651	7460	19	6E
0005433715720	7460	20	7A
0005433656650	7460	21	6F
0005433715710	7460	22	7B
0005433690914	7460	23	7E
0005433690915	7460	24	8C
0005433715680	7460	25	8D
0005433715689	7460	26	8F
0005433715717	7460	27	9A
0005433715690	7460	28	9C
0005432428869	7460	29	9F
0005433715683	7460	30	9E
0005433715702	7460	31	10B
0005433715694	7460	32	11A
0005433715723	7460	33	10E
0005433722180	7460	34	11B
0005433715711	7460	35	11C
0005433690916	7460	36	11F
0005433722184	7460	37	12D
0005432428880	7460	38	12C
0005433715721	7460	39	12E
0005433722186	7460	40	12F
0005433715692	7460	41	13C
0005433722185	7460	42	13B
0005433715726	7460	43	13D
0005433715701	7460	44	13E
0005433719119	7460	45	14A
0005432078077	7460	46	14C
0005433715719	7460	47	14B
0005432078081	7460	48	14D
0005433715691	7460	49	14E
0005433715712	7460	50	14F
0005433656652	7460	51	15B
0005433715681	7460	52	15A
0005433715684	7460	53	15C
0005433715700	7460	54	15E
0005433715709	7460	55	16D
0005433722181	7460	56	16F
0005435266093	7460	57	16E
0005433656649	7460	58	17A
0005433715728	7460	59	17B
0005433715713	7460	60	18A
0005432428881	7460	61	17F
0005433715708	7460	62	18E
0005433715686	7460	63	18D
0005435266078	7460	64	18F
0005433715716	7460	65	19B
0005433715682	7460	66	19D
0005433715698	7460	67	20A
0005433715707	7460	68	20C
0005433715703	7460	69	20B
0005433715715	7460	70	20D
0005433689898	7460	71	20E
0005433715727	7460	72	21D
0005433715714	7460	73	21F
0005433715687	7460	74	21E
0005433715699	7460	75	22B
0005432078078	7460	76	22A
0005433715730	7460	77	22C
0005433715695	7460	78	22D
0005433715685	7460	79	22F
0005433722179	7460	80	22E
0005432078079	7460	81	23A
0005433715705	7460	82	23C
0005433715729	7460	83	23E
0005433715696	7460	84	23D
0005433715396	29206	1	1A
0005433715432	29206	2	1C
0005433722124	29206	3	2A
0005433722107	29206	4	2C
0005433715194	29206	5	2D
0005433715246	29206	6	3C
0005435266126	29206	7	3A
0005433715372	29206	8	3D
0005432006745	29206	9	3F
0005433715287	29206	10	4B
0005433715102	29206	11	4A
0005433715176	29206	12	4E
0005433715281	29206	13	5A
0005435266133	29206	14	6B
0005433715458	29206	15	6A
0005433688774	29206	16	6E
0005433719097	29206	17	6F
0005432006744	29206	18	7B
0005435266131	29206	19	7A
0005433715247	29206	20	7C
0005433715127	29206	21	7D
0005433715408	29206	22	7E
0005433719085	29206	23	8A
0005433656617	29206	24	8B
0005435266129	29206	25	8D
0005433722111	29206	26	8F
0005433715266	29206	27	9A
0005433715267	29206	28	9B
0005433688775	29206	29	9F
0005433715406	29206	30	10B
0005433715334	29206	31	10C
0005433722110	29206	32	10E
0005433715250	29206	33	11A
0005433715137	29206	34	11C
0005433715447	29206	35	11F
0005433715317	29206	36	12B
0005433722105	29206	37	12D
0005433715232	29206	38	12F
0005433656623	29206	39	13B
0005433715223	29206	40	13A
0005433715260	29206	41	13D
0005433685491	29206	42	13F
0005433722112	29206	43	13E
0005433715383	29206	44	14A
0005433715299	29206	45	14B
0005435266132	29206	46	14D
0005435266125	29206	47	14E
0005433715395	29206	48	15A
0005432428912	29206	49	14F
0005433722117	29206	50	15C
0005433715294	29206	51	15F
0005433715371	29206	52	16B
0005433715195	29206	53	16A
0005433715394	29206	54	16D
0005433715259	29206	55	16F
0005433656621	29206	56	16E
0005432428910	29206	57	17A
0005433656626	29206	58	17C
0005433722130	29206	59	17D
0005432428909	29206	60	17E
0005435266130	29206	61	18A
0005435266127	29206	62	18E
0005433715471	29206	63	18F
0005433715423	29206	64	19A
0005433715089	29206	65	19C
0005433715405	29206	66	20C
0005433715422	29206	67	20D
0005433715201	29206	68	20E
0005433715268	29206	69	20F
0005432006746	29206	70	21C
0005433722120	29206	71	21E
0005433722109	29206	72	22A
0005432428911	29206	73	22D
0005433715222	29206	74	22E
0005433656618	29206	75	23A
0005433715407	29206	76	23C
0005435266128	29206	77	23F
0005434182019	8703	1	1D
0005434095194	8703	2	2A
0005434184635	8703	3	3A
0005434182022	8703	4	3C
0005434143719	8703	5	3F
0005434095192	8703	6	4C
0005434095205	8703	7	4D
0005434095206	8703	8	5A
0005434095193	8703	9	6A
0005434095202	8703	10	6C
0005434143721	8703	11	6F
0005434143718	8703	12	7D
0005434143720	8703	13	9A
0005434095200	8703	14	9F
0005434095199	8703	15	10A
0005434182050	8703	16	10C
0005434095204	8703	17	11F
0005434143723	8703	18	12E
0005434095203	8703	19	12F
0005434184634	8703	20	13C
0005434181995	8703	21	13D
0005434182021	8703	22	13F
0005434143722	8703	23	15E
0005434182020	8703	24	16A
0005434095198	8703	25	16D
0005434182051	8703	26	16E
0005434095196	8703	27	16F
0005434143724	8703	28	17D
0005434143717	8703	29	18E
0005434095195	8703	30	18F
0005434095201	8703	31	19A
0005434095197	8703	32	19F
0005434182023	8703	33	20D
0005434095054	11674	1	1D
0005434182113	11674	2	1F
0005434182117	11674	3	2D
0005434182114	11674	4	2F
0005434182111	11674	5	3A
0005434183566	11674	6	4C
0005434143698	11674	7	6C
0005434095070	11674	8	6F
0005434182118	11674	9	7E
0005434182121	11674	10	8A
0005434095023	11674	11	8C
0005434095052	11674	12	8D
0005434182116	11674	13	10A
0005434184652	11674	14	12A
0005434182112	11674	15	12F
0005434182119	11674	16	13A
0005434095053	11674	17	15E
0005434182120	11674	18	16A
0005434182122	11674	19	16C
0005434182123	11674	20	16F
0005434095059	11674	21	17A
0005434183567	11674	22	17E
0005434182115	11674	23	19A
0005434184653	11674	24	19C
0005434095044	11674	25	19D
0005433397285	1419	1	1D
0005433397362	1419	2	2D
0005433456947	1419	3	2F
0005433397289	1419	4	3C
0005433397530	1419	5	3D
0005433397207	1419	6	4A
0005433397467	1419	7	4C
0005433397367	1419	8	4D
0005433397431	1419	9	4E
0005433397236	1419	10	4F
0005433397363	1419	11	5A
0005433397660	1419	12	5C
0005433397353	1419	13	5D
0005433397342	1419	14	5E
0005433397405	1419	15	5F
0005433397387	1419	16	6E
0005432297264	1419	17	7A
0005435732279	1419	18	6F
0005433397360	1419	19	7C
0005433456946	1419	20	7D
0005433397208	1419	21	7E
0005435732278	1419	22	7F
0005433397563	1419	23	8A
0005433397408	1419	24	8C
0005433397388	1419	25	8E
0005433397239	1419	26	8F
0005433397374	1419	27	9A
0005432906496	1419	28	9C
0005432297263	1419	29	9D
0005433397357	1419	30	9E
0005433397351	1419	31	10A
0005433397430	1419	32	10D
0005433397523	1419	33	10F
0005433397331	1419	34	11C
0005435732281	1419	35	11D
0005433397286	1419	36	11E
0005433456949	1419	37	12A
0005433397319	1419	38	12C
0005433397508	1419	39	12D
0005433397302	1419	40	12E
0005433397390	1419	41	12F
0005433397659	1419	42	13A
0005433397398	1419	43	13C
0005433397375	1419	44	13D
0005433397407	1419	45	13F
0005433456948	1419	46	14A
0005432297262	1419	47	14C
0005433397552	1419	48	14E
0005433397425	1419	49	14F
0005435732277	1419	50	15D
0005433397533	1419	51	15E
0005433397551	1419	52	15F
0005433397350	1419	53	16A
0005433397332	1419	54	16C
0005433397356	1419	55	16E
0005433397179	1419	56	16F
0005433397448	1419	57	17A
0005433397658	1419	58	17C
0005433397199	1419	59	17E
0005433397534	1419	60	18A
0005433397531	1419	61	18C
0005432906508	1419	62	18D
0005433397352	1419	63	18E
0005433456950	1419	64	18F
0005433397572	1419	65	19A
0005435732280	1419	66	19D
0005433456951	1419	67	19F
0005433397564	1419	68	20A
0005433397354	1419	69	20C
0005433397218	1419	70	20D
0005433397457	1419	71	20F
0005433397804	19228	1	1C
0005433397796	19228	2	1D
0005433397805	19228	3	1F
0005435732181	19228	4	2C
0005433397813	19228	5	2D
0005435732135	19228	6	2F
0005433397824	19228	7	3C
0005433397790	19228	8	3D
0005432906523	19228	9	4A
0005433397783	19228	10	3F
0005433397815	19228	11	4D
0005433397817	19228	12	4E
0005433397784	19228	13	4F
0005433397778	19228	14	5C
0005433397802	19228	15	5E
0005433397779	19228	16	6A
0005433397780	19228	17	6C
0005433397788	19228	18	6D
0005433397808	19228	19	6F
0005433397803	19228	20	7A
0005433397825	19228	21	7C
0005433397814	19228	22	7D
0005435732157	19228	23	7E
0005435732191	19228	24	7F
0005433397811	19228	25	8A
0005433397812	19228	26	8C
0005433397775	19228	27	8D
0005433397785	19228	28	8E
0005433397798	19228	29	9A
0005433456921	19228	30	9D
0005433456915	19228	31	10A
0005433397781	19228	32	10C
0005435732134	19228	33	10E
0005433397776	19228	34	11A
0005433397789	19228	35	11C
0005435732195	19228	36	11D
0005432906522	19228	37	11E
0005433397794	19228	38	11F
0005433397809	19228	39	12A
0005433397786	19228	40	12C
0005433397822	19228	41	12D
0005433397806	19228	42	12E
0005433397820	19228	43	12F
0005433397777	19228	44	13C
0005435732145	19228	45	13D
0005433456922	19228	46	13E
0005433397787	19228	47	13F
0005435732139	19228	48	14E
0005433456917	19228	49	14D
0005433397819	19228	50	15A
0005435732182	19228	51	15C
0005435732125	19228	52	15E
0005435732156	19228	53	15F
0005433397807	19228	54	16A
0005433397791	19228	55	16C
0005433397816	19228	56	16D
0005433397782	19228	57	16E
0005433397821	19228	58	16F
0005435732188	19228	59	17A
0005435732179	19228	60	17C
0005433397799	19228	61	17E
0005433397792	19228	62	18A
0005433397801	19228	63	18C
0005433397823	19228	64	18D
0005433397795	19228	65	18E
0005433397800	19228	66	18F
0005433397810	19228	67	19C
0005433397797	19228	68	20A
0005433397793	19228	69	20C
0005433397818	19228	70	20E
0005434443456	17360	1	1B
0005434443531	17360	2	1C
0005434443445	17360	3	2D
0005434443439	17360	4	3D
0005434443454	17360	5	5C
0005434443503	17360	6	6C
0005434443489	17360	7	6D
0005434443471	17360	8	7B
0005434443532	17360	9	18B
0005434443473	17360	10	18C
0005434443530	17360	11	19A
0005434443538	17360	12	19B
0005434443529	17360	13	19C
0005434443464	17360	14	20D
0005434443490	17360	15	21B
0005434443614	20603	1	1D
0005434443621	20603	2	2B
0005434443609	20603	3	3A
0005434443606	20603	4	3C
0005434443617	20603	5	4A
0005434443615	20603	6	4D
0005434443619	20603	7	5B
0005434443608	20603	8	5D
0005434443612	20603	9	6B
0005434443607	20603	10	7B
0005434443610	20603	11	7D
0005434443616	20603	12	19A
0005434443618	20603	13	20B
0005434443611	20603	14	20C
0005434443605	20603	15	21C
0005434443620	20603	16	23B
0005434443613	20603	17	23A
0005434954589	7248	1	1A
0005434954586	7248	2	1B
0005435377550	7248	3	3A
0005435377552	7248	4	4A
0005434954587	7248	5	4B
0005434954588	7248	6	5A
0005435377551	7248	7	5B
0005434954573	28340	1	1A
0005434954542	28340	2	1B
0005434954570	28340	3	2A
0005435377569	28340	4	2B
0005434954552	28340	5	3B
0005435377566	28340	6	4A
0005434954564	28340	7	5A
0005435377567	28340	8	4B
0005434954553	28340	9	5B
0005435377568	28340	10	6A
0005434954569	28340	11	6B
0005434351631	4489	1	1D
0005435893510	4489	2	2C
0005434351626	4489	3	3A
0005434351630	4489	4	3B
0005434351624	4489	5	3D
0005435893591	4489	6	4D
0005434351625	4489	7	5A
0005434351629	4489	8	5C
0005434351621	4489	9	5D
0005434351628	4489	10	7A
0005434183550	4489	11	19B
0005434326268	4489	12	19C
0005434351627	4489	13	19D
0005434351633	4489	14	20A
0005434351622	4489	15	20B
0005435893592	4489	16	21A
0005434351634	4489	17	22C
0005434351632	4489	18	22D
0005434351623	4489	19	23A
0005435893591	29647	1	2A
0005434351507	29647	2	2C
0005434351509	29647	3	2D
0005434351528	29647	4	3A
0005434351488	29647	5	4B
0005435893596	29647	6	4D
0005434351536	29647	7	6D
0005435893593	29647	8	18C
0005435893595	29647	9	19A
0005435893594	29647	10	19B
0005434351508	29647	11	19C
0005434351550	29647	12	20B
0005434351537	29647	13	20D
0005434351535	29647	14	22C
0005434351538	29647	15	22D
0005434351489	29647	16	23A
0005435893592	29647	17	23B
0005433341903	1065	1	1A
0005433341416	1065	2	1C
0005433341797	1065	3	2A
0005433341633	1065	4	1H
0005433462735	1065	5	2B
0005435092025	1065	6	2C
0005433341592	1065	7	3B
0005433463888	1065	8	3F
0005433341509	1065	9	3C
0005433341598	1065	10	3G
0005435545694	1065	11	4B
0005433341803	1065	12	4G
0005433341889	1065	13	4H
0005433341495	1065	14	5B
0005435092021	1065	15	5A
0005433341593	1065	16	5C
0005433341513	1065	17	5F
0005433341570	1065	18	5H
0005433269649	1065	19	9B
0005433342063	1065	20	9A
0005435545693	1065	21	9H
0005433341698	1065	22	9G
0005435092023	1065	23	11F
0005433341554	1065	24	11H
0005434446511	1065	25	12A
0005433341690	1065	26	12E
0005433341564	1065	27	13E
0005433341545	1065	28	13G
0005433341654	1065	29	14A
0005433341508	1065	30	13H
0005433341459	1065	31	14B
0005433342093	1065	32	14D
0005433342064	1065	33	14F
0005433341380	1065	34	14E
0005435092027	1065	35	14H
0005433341951	1065	36	15B
0005433341615	1065	37	15E
0005434445237	1065	38	15F
0005433342255	1065	39	15G
0005433463889	1065	40	16A
0005433342256	1065	41	16D
0005434446510	1065	42	16B
0005433341544	1065	43	16E
0005433269667	1065	44	16F
0005433341739	1065	45	16H
0005434446508	1065	46	16G
0005433341492	1065	47	17F
0005433341801	1065	48	17G
0005433341594	1065	49	17H
0005435092026	1065	50	19E
0005433341600	1065	51	20A
0005433462734	1065	52	19H
0005433269645	1065	53	20D
0005434446509	1065	54	20B
0005433341458	1065	55	20F
0005435092020	1065	56	20G
0005435092016	1065	57	20H
0005435092024	1065	58	21D
0005433342281	1065	59	21F
0005433341381	1065	60	22B
0005433341606	1065	61	22A
0005435545691	1065	62	22F
0005433341385	1065	63	22E
0005433341716	1065	64	23B
0005433341496	1065	65	23H
0005433341584	1065	66	24B
0005433341867	1065	67	24E
0005433341585	1065	68	24D
0005435092017	1065	69	24G
0005435092019	1065	70	24H
0005433342075	1065	71	27F
0005433341657	1065	72	27E
0005433341713	1065	73	27G
0005433341972	1065	74	28A
0005433341599	1065	75	27H
0005433341597	1065	76	28B
0005433341802	1065	77	28G
0005433341565	1065	78	28F
0005433341589	1065	79	28E
0005433341918	1065	80	28H
0005433341494	1065	81	29B
0005435545695	1065	82	29F
0005433341583	1065	83	29E
0005435545692	1065	84	29G
0005433341553	1065	85	29H
0005433341806	1065	86	30B
0005433342068	1065	87	30A
0005433341740	1065	88	30G
0005433341714	1065	89	31A
0005434445236	1065	90	30H
0005433341722	1065	91	31H
0005433341920	1065	92	32B
0005433341954	1065	93	32D
0005435092015	1065	94	32F
0005433341800	1065	95	32G
0005433341847	1065	96	33D
0005433341848	1065	97	33B
0005433159286	1065	98	33E
0005433158100	1065	99	33H
0005433269653	1065	100	33G
0005433341569	1065	101	34B
0005433341689	1065	102	34G
0005435092018	1065	103	34F
0005433342070	1065	104	34H
0005435545696	1065	105	35F
0005433341573	1065	106	35G
0005433341984	1065	107	35H
0005433269668	1065	108	36B
0005433341950	1065	109	36D
0005433341672	1065	110	36F
0005435092022	1065	111	36H
0005433341846	1065	112	37A
0005433341658	1065	113	37E
0005433341831	1065	114	37D
0005433341921	1065	115	37F
0005433342257	1065	116	37G
0005433341723	1065	117	37H
0005433341527	1065	118	38B
0005433341953	1065	119	38F
0005433342553	17069	1	1A
0005433342509	17069	2	1C
0005435508193	17069	3	1F
0005433342584	17069	4	1G
0005433342520	17069	5	2B
0005433342566	17069	6	2F
0005433342569	17069	7	2C
0005433342519	17069	8	3A
0005435091943	17069	9	3B
0005433342561	17069	10	3H
0005433269688	17069	11	4B
0005435091912	17069	12	4C
0005433342521	17069	13	4H
0005433342578	17069	14	5B
0005433342576	17069	15	5A
0005433342502	17069	16	5F
0005433342512	17069	17	5G
0005433342551	17069	18	5H
0005433342564	17069	19	9B
0005435508184	17069	20	11B
0005435508178	17069	21	11D
0005433269690	17069	22	11F
0005433342514	17069	23	11E
0005433342522	17069	24	11H
0005433342586	17069	25	11G
0005433342537	17069	26	12A
0005433342595	17069	27	12D
0005433342591	17069	28	12B
0005435508209	17069	29	12G
0005435091892	17069	30	13A
0005433342547	17069	31	13B
0005433342498	17069	32	13E
0005433342524	17069	33	14A
0005435508198	17069	34	13H
0005433342560	17069	35	14E
0005435091911	17069	36	14B
0005433342538	17069	37	14G
0005433342513	17069	38	15A
0005433342511	17069	39	15B
0005435508179	17069	40	15F
0005433342507	17069	41	15H
0005433342541	17069	42	15G
0005433342568	17069	43	16A
0005435508172	17069	44	16D
0005433342539	17069	45	16B
0005433342532	17069	46	16E
0005433342534	17069	47	16H
0005433342587	17069	48	17A
0005433342510	17069	49	17D
0005433342571	17069	50	17B
0005433269686	17069	51	17E
0005435508192	17069	52	17H
0005433342526	17069	53	18B
0005433342535	17069	54	18D
0005433342572	17069	55	18E
0005433269687	17069	56	19A
0005433342518	17069	57	18H
0005433342506	17069	58	19B
0005435508196	17069	59	19E
0005433342505	17069	60	19D
0005433159300	17069	61	19F
0005433342581	17069	62	19H
0005435508194	17069	63	20G
0005433342546	17069	64	20F
0005435508230	17069	65	20E
0005433342563	17069	66	20H
0005433269691	17069	67	21D
0005433342557	17069	68	21H
0005433342550	17069	69	22A
0005433342580	17069	70	22D
0005433342588	17069	71	22E
0005433159299	17069	72	22G
0005433342501	17069	73	22F
0005433342567	17069	74	23D
0005433342556	17069	75	23F
0005433342552	17069	76	23G
0005435091947	17069	77	23H
0005433342533	17069	78	24D
0005433342545	17069	79	24B
0005433342543	17069	80	24A
0005433342570	17069	81	24H
0005433342573	17069	82	25E
0005433342583	17069	83	25D
0005433342575	17069	84	25F
0005433342598	17069	85	27B
0005433342528	17069	86	27E
0005433342565	17069	87	27D
0005433342542	17069	88	27F
0005433342530	17069	89	27H
0005433342544	17069	90	28A
0005433342577	17069	91	28B
0005433342596	17069	92	28F
0005433269689	17069	93	28H
0005435508212	17069	94	29B
0005435508185	17069	95	29D
0005433342504	17069	96	29H
0005433342590	17069	97	29G
0005433342517	17069	98	30A
0005433342548	17069	99	30D
0005433342503	17069	100	30E
0005433342594	17069	101	30H
0005433342540	17069	102	31B
0005433342562	17069	103	31A
0005433342549	17069	104	31H
0005433342555	17069	105	32F
0005433342574	17069	106	32E
0005433342593	17069	107	32H
0005433342536	17069	108	33A
0005433342589	17069	109	33B
0005433342592	17069	110	33E
0005433342531	17069	111	33D
0005433342516	17069	112	34A
0005433342585	17069	113	34E
0005433342554	17069	114	34F
0005433342499	17069	115	34H
0005433342527	17069	116	35B
0005433342597	17069	117	35A
0005433342559	17069	118	35F
0005435508197	17069	119	35H
0005433342529	17069	120	35G
0005434445213	17069	121	36A
0005433342579	17069	122	36F
0005433342508	17069	123	36H
0005435508195	17069	124	37B
0005433342523	17069	125	37E
0005435508183	17069	126	37D
0005433342525	17069	127	37F
0005435508208	17069	128	38A
0005433342582	17069	129	37H
0005433342500	17069	130	38D
0005433342515	17069	131	38H
0005433342558	17069	132	38G
0005434081611	12783	1	1C
0005434081551	12783	2	1D
0005434066464	12783	3	1F
0005434066814	12783	4	2A
0005434066404	12783	5	2C
0005432433651	12783	6	2F
0005434066574	12783	7	3C
0005434066484	12783	8	3F
0005434066451	12783	9	3D
0005434081548	12783	10	4B
0005432161140	12783	11	4C
0005434066636	12783	12	4E
0005434066682	12783	13	4D
0005434081560	12783	14	5A
0005434066431	12783	15	5B
0005434066514	12783	16	5C
0005432159835	12783	17	5D
0005433812888	12783	18	5E
0005434066446	12783	19	6A
0005434066580	12783	20	6C
0005434066354	12783	21	6B
0005434066846	12783	22	6D
0005434066372	12783	23	6E
0005434066549	12783	24	6F
0005434066332	12783	25	7B
0005434066519	12783	26	7A
0005434066609	12783	27	7C
0005434066635	12783	28	7D
0005432433648	12783	29	7E
0005434066396	12783	30	8A
0005433989700	12783	31	7F
0005434066570	12783	32	8B
0005434066559	12783	33	8C
0005434081597	12783	34	8E
0005434066347	12783	35	8D
0005434081609	12783	36	8F
0005434066584	12783	37	9A
0005434066573	12783	38	9C
0005432433652	12783	39	9D
0005434066650	12783	40	9E
0005433812889	12783	41	10B
0005434066371	12783	42	10C
0005434066334	12783	43	10D
0005434081582	12783	44	11A
0005432161141	12783	45	11B
0005433989712	12783	46	11C
0005434066402	12783	47	11E
0005432159832	12783	48	11D
0005433989714	12783	49	12A
0005434066681	12783	50	12C
0005434066553	12783	51	12B
0005432159831	12783	52	12E
0005434066627	12783	53	12D
0005434066335	12783	54	12F
0005434081561	12783	55	13A
0005433989693	12783	56	13C
0005434066471	12783	57	13B
0005432433653	12783	58	13E
0005434066847	12783	59	13D
0005433812886	12783	60	13F
0005432433649	12783	61	14B
0005434066746	12783	62	14A
0005432159836	12783	63	14C
0005434081508	12783	64	14E
0005434066582	12783	65	14F
0005432433650	12783	66	15B
0005434066651	12783	67	15A
0005434081502	12783	68	15C
0005434081527	12783	69	15D
0005433989711	12783	70	15E
0005434066680	12783	71	16A
0005434066535	12783	72	15F
0005434066730	12783	73	16B
0005434066608	12783	74	16C
0005434066628	12783	75	16D
0005434066557	12783	76	16E
0005434066845	12783	77	17A
0005434081470	12783	78	16F
0005434066518	12783	79	17B
0005434081549	12783	80	17C
0005434066556	12783	81	17F
0005434081608	12783	82	17E
0005434066333	12783	83	18C
0005434081596	12783	84	18B
0005433989704	12783	85	18E
0005434081598	12783	86	18D
0005434066569	12783	87	18F
0005432159833	12783	88	19A
0005432159834	12783	89	19B
0005434066536	12783	90	19D
0005434081559	12783	91	19C
0005434066581	12783	92	19E
0005433812887	12783	93	19F
0005434066370	12783	94	20C
0005434066600	12783	95	20B
0005434081532	12783	96	20D
0005434066403	12783	97	20F
0005434066534	12783	98	21D
0005434066452	12783	99	21C
0005434066632	12783	100	21F
0005433989694	12783	101	22A
0005434066738	12783	102	22C
0005434066550	12783	103	22B
0005434066416	12783	104	22E
0005434081526	12783	105	22D
0005434066453	12783	106	23A
0005434081509	12783	107	23B
0005434081486	12783	108	23C
0005434066373	12783	109	23F
0005434066541	12783	110	23E
0005434067148	30683	1	1A
0005432150144	30683	2	1D
0005434067106	30683	3	1C
0005434067120	30683	4	1F
0005434067161	30683	5	2C
0005434067137	30683	6	2A
0005434026691	30683	7	2D
0005433812859	30683	8	2F
0005434067095	30683	9	3C
0005434081755	30683	10	3A
0005434067111	30683	11	3F
0005434067108	30683	12	4A
0005432150143	30683	13	4C
0005434067142	30683	14	4B
0005432150145	30683	15	4F
0005434067144	30683	16	4E
0005432433618	30683	17	4D
0005434067107	30683	18	5A
0005434067163	30683	19	5B
0005432433619	30683	20	5C
0005434067138	30683	21	5D
0005434067122	30683	22	5E
0005433812857	30683	23	6A
0005432150149	30683	24	6B
0005434067113	30683	25	6C
0005434067116	30683	26	6D
0005434067139	30683	27	6E
0005434067098	30683	28	6F
0005432150148	30683	29	7B
0005432433601	30683	30	7C
0005434026687	30683	31	7D
0005434067155	30683	32	7E
0005432433617	30683	33	8A
0005434067152	30683	34	7F
0005434026690	30683	35	8D
0005434067136	30683	36	8C
0005434067140	30683	37	8F
0005434067129	30683	38	8E
0005434067128	30683	39	9A
0005434026693	30683	40	9B
0005434067156	30683	41	9C
0005432433613	30683	42	9F
0005434067149	30683	43	9E
0005433812858	30683	44	10B
0005434026689	30683	45	10D
0005434067110	30683	46	10C
0005434067134	30683	47	10E
0005434081754	30683	48	11A
0005434067109	30683	49	11D
0005434026692	30683	50	11C
0005434067121	30683	51	11E
0005434067124	30683	52	12B
0005434067166	30683	53	12A
0005432150146	30683	54	12C
0005434081758	30683	55	12D
0005434067104	30683	56	12E
0005434067151	30683	57	12F
0005433989743	30683	58	13B
0005434067158	30683	59	13A
0005433989740	30683	60	13C
0005434067165	30683	61	13D
0005432150147	30683	62	13E
0005434067127	30683	63	13F
0005434067159	30683	64	14B
0005434081753	30683	65	14C
0005434067150	30683	66	14E
0005434081757	30683	67	14D
0005434067115	30683	68	15A
0005434067164	30683	69	14F
0005434067147	30683	70	15B
0005434067132	30683	71	15C
0005432186847	30683	72	15D
0005432433614	30683	73	15F
0005434067125	30683	74	15E
0005434067135	30683	75	16A
0005433989741	30683	76	16B
0005434067123	30683	77	16D
0005434081749	30683	78	17A
0005434067126	30683	79	16F
0005434067118	30683	80	17B
0005434081750	30683	81	17E
0005434067146	30683	82	18A
0005434026694	30683	83	18B
0005434026688	30683	84	18C
0005434081756	30683	85	18D
0005434067096	30683	86	18F
0005434067153	30683	87	19A
0005434067102	30683	88	19C
0005434067112	30683	89	19B
0005434067141	30683	90	19D
0005434067162	30683	91	19E
0005434067105	30683	92	19F
0005434067119	30683	93	20B
0005434067117	30683	94	20A
0005434067131	30683	95	20E
0005434067133	30683	96	20D
0005434081752	30683	97	20F
0005434067094	30683	98	21B
0005434067157	30683	99	21A
0005434067145	30683	100	21D
0005433812860	30683	101	21C
0005433989742	30683	102	21E
0005434067100	30683	103	21F
0005434081751	30683	104	22B
0005434067160	30683	105	22A
0005434067097	30683	106	22C
0005432186846	30683	107	22D
0005434067154	30683	108	22F
0005434067114	30683	109	22E
0005434067103	30683	110	23A
0005434067101	30683	111	23B
0005434067099	30683	112	23D
0005434067130	30683	113	23C
0005434067143	30683	114	23E
0005432535753	5499	1	1A
0005432535766	5499	2	1F
0005434264742	5499	3	1C
0005435461959	5499	4	1H
0005435765936	5499	5	1G
0005435765895	5499	6	2A
0005435765902	5499	7	2C
0005435765919	5499	8	2F
0005435765905	5499	9	3A
0005435725567	5499	10	2H
0005435722043	5499	11	3C
0005435765873	5499	12	3B
0005435765885	5499	13	3G
0005433529258	5499	14	4A
0005434264714	5499	15	3H
0005435461943	5499	16	4F
0005435765921	5499	17	4C
0005435725570	5499	18	4G
0005435735116	5499	19	5A
0005435461990	5499	20	4H
0005434831096	5499	21	5B
0005435765874	5499	22	5F
0005435765881	5499	23	5C
0005435723034	5499	24	5G
0005433527247	5499	25	9B
0005435735115	5499	26	9A
0005435765934	5499	27	9G
0005432140399	5499	28	11A
0005435765937	5499	29	9H
0005435765894	5499	30	11D
0005435765920	5499	31	11B
0005435461868	5499	32	11F
0005435725572	5499	33	11E
0005435765893	5499	34	11G
0005435765928	5499	35	12A
0005434264732	5499	36	11H
0005435765878	5499	37	12D
0005432140406	5499	38	12B
0005435765883	5499	39	12G
0005435765932	5499	40	13A
0005435765901	5499	41	13D
0005434831084	5499	42	13B
0005435461869	5499	43	13E
0005435461803	5499	44	13H
0005435765897	5499	45	14B
0005434264712	5499	46	14A
0005434264822	5499	47	14D
0005435765898	5499	48	14F
0005434831088	5499	49	14G
0005434264819	5499	50	15A
0005432140407	5499	51	14H
0005435765908	5499	52	15B
0005435461947	5499	53	15E
0005435462014	5499	54	15D
0005435461757	5499	55	15G
0005435735110	5499	56	15F
0005435765929	5499	57	16A
0005432535767	5499	58	15H
0005435765917	5499	59	16B
0005435765918	5499	60	16E
0005432140405	5499	61	16F
0005435765892	5499	62	16H
0005435461775	5499	63	17A
0005433529260	5499	64	17D
0005432140404	5499	65	17B
0005435461946	5499	66	17E
0005435461965	5499	67	17G
0005432140401	5499	68	17H
0005435461836	5499	69	18B
0005435722041	5499	70	18A
0005435765912	5499	71	18F
0005435462023	5499	72	18G
0005434264761	5499	73	18H
0005435461758	5499	74	19A
0005435461998	5499	75	19E
0005435765886	5499	76	19D
0005435735111	5499	77	19F
0005435765914	5499	78	20B
0005434264803	5499	79	20E
0005435723033	5499	80	20F
0005434264754	5499	81	20G
0005434831079	5499	82	21B
0005435725569	5499	83	21A
0005435765933	5499	84	20H
0005435765903	5499	85	21E
0005435461908	5499	86	21G
0005434264837	5499	87	21F
0005435722042	5499	88	21H
0005435461898	5499	89	22A
0005435765938	5499	90	22D
0005435462049	5499	91	22B
0005432140402	5499	92	22F
0005435765922	5499	93	22E
0005434264813	5499	94	22G
0005435461897	5499	95	22H
0005435765931	5499	96	23D
0005435461776	5499	97	23B
0005435765891	5499	98	23F
0005435765915	5499	99	23E
0005435765907	5499	100	24A
0005434831085	5499	101	23H
0005435765926	5499	102	24B
0005434264743	5499	103	24E
0005435735114	5499	104	24H
0005435735113	5499	105	24G
0005435461924	5499	106	25D
0005435765927	5499	107	25E
0005435765890	5499	108	27A
0005435735112	5499	109	27B
0005435720819	5499	110	27F
0005435765899	5499	111	27H
0005434264762	5499	112	28B
0005435765872	5499	113	28E
0005433529259	5499	114	28D
0005433529257	5499	115	28H
0005435043274	5499	116	28G
0005434831077	5499	117	29D
0005434264676	5499	118	29B
0005434264711	5499	119	29E
0005435765904	5499	120	29G
0005435725571	5499	121	29F
0005434831095	5499	122	29H
0005434264808	5499	123	30A
0005432140403	5499	124	30B
0005435462013	5499	125	30F
0005435765935	5499	126	30E
0005435765888	5499	127	30G
0005435765930	5499	128	31B
0005435765884	5499	129	31A
0005435765896	5499	130	31F
0005435765880	5499	131	31E
0005435461835	5499	132	31G
0005435461923	5499	133	32A
0005435461964	5499	134	31H
0005435765879	5499	135	32B
0005432140400	5499	136	32E
0005435765911	5499	137	32H
0005434264815	5499	138	33A
0005435765924	5499	139	33B
0005435765939	5499	140	33E
0005433527250	5499	141	33D
0005435765875	5499	142	33F
0005435461992	5499	143	33H
0005435725568	5499	144	33G
0005435765916	5499	145	34D
0005434264818	5499	146	34F
0005435765910	5499	147	34G
0005435461756	5499	148	34H
0005434831066	5499	149	35D
0005432535754	5499	150	35F
0005435461974	5499	151	35E
0005435462061	5499	152	35G
0005435765909	5499	153	36A
0005435462029	5499	154	35H
0005435461962	5499	155	36B
0005432140408	5499	156	36E
0005435765877	5499	157	36F
0005432535755	5499	158	36H
0005435765889	5499	159	36G
0005435765887	5499	160	37D
0005433527249	5499	161	37B
0005433527248	5499	162	37A
0005435765923	5499	163	37E
0005435043273	5499	164	37F
0005435765906	5499	165	38A
0005435765882	5499	166	38D
0005435765925	5499	167	38E
0005435765900	5499	168	38H
0005435765876	5499	169	39E
0005434264880	5499	170	39D
0005435765913	5499	171	39F
0005435462221	13502	1	1A
0005435722033	13502	2	1F
0005435462248	13502	3	1C
0005435765537	13502	4	2C
0005435735067	13502	5	2B
0005435462228	13502	6	2F
0005435765383	13502	7	3A
0005435462233	13502	8	2H
0005435765412	13502	9	3B
0005434265001	13502	10	3F
0005435765424	13502	11	3C
0005435462220	13502	12	3H
0005435765714	13502	13	3G
0005435765731	13502	14	4B
0005432535810	13502	15	4C
0005435765488	13502	16	4G
0005432535811	13502	17	5A
0005432535809	13502	18	4H
0005435462235	13502	19	5C
0005435765538	13502	20	5F
0005435765431	13502	21	9H
0005434265013	13502	22	9G
0005435462247	13502	23	11B
0005435765217	13502	24	11E
0005435735058	13502	25	11D
0005435765446	13502	26	11H
0005435765349	13502	27	11G
0005435765350	13502	28	12A
0005435765289	13502	29	12D
0005435765591	13502	30	12B
0005435462231	13502	31	12E
0005434831124	13502	32	12G
0005435765267	13502	33	12H
0005434265002	13502	34	13A
0005432194487	13502	35	13D
0005434265018	13502	36	13E
0005434265017	13502	37	13F
0005435462246	13502	38	13H
0005435765382	13502	39	14A
0005435720126	13502	40	14E
0005435462232	13502	41	14B
0005435462253	13502	42	14G
0005435765448	13502	43	15D
0005435765292	13502	44	15B
0005434831125	13502	45	15A
0005435765503	13502	46	15E
0005435462227	13502	47	16A
0005435765522	13502	48	16D
0005435765713	13502	49	16B
0005434265014	13502	50	16E
0005435765579	13502	51	16G
0005434265015	13502	52	16F
0005435765629	13502	53	16H
0005435765379	13502	54	17E
0005435765216	13502	55	17G
0005435462223	13502	56	17F
0005435462236	13502	57	18A
0005435722013	13502	58	17H
0005435462222	13502	59	18B
0005435765268	13502	60	18G
0005435765370	13502	61	19A
0005435725517	13502	62	18H
0005435765125	13502	63	19D
0005434264995	13502	64	19B
0005435765578	13502	65	19F
0005435462251	13502	66	19E
0005435722032	13502	67	20A
0005435765413	13502	68	19H
0005435765122	13502	69	20D
0005432194490	13502	70	20E
0005435765406	13502	71	20G
0005435765201	13502	72	20F
0005435765362	13502	73	20H
0005435735064	13502	74	21B
0005435765246	13502	75	21E
0005435462241	13502	76	21G
0005435462230	13502	77	22D
0005435765628	13502	78	22B
0005434264997	13502	79	22F
0005435765462	13502	80	22E
0005435765608	13502	81	22G
0005435765378	13502	82	22H
0005435765340	13502	83	23B
0005435765427	13502	84	23A
0005435462244	13502	85	23E
0005434265008	13502	86	23D
0005434831126	13502	87	23G
0005435735071	13502	88	24A
0005435765544	13502	89	24D
0005434265004	13502	90	24E
0005434265012	13502	91	24H
0005435462226	13502	92	25F
0005435765342	13502	93	25E
0005435765270	13502	94	27A
0005435765322	13502	95	27B
0005434264992	13502	96	27D
0005435765215	13502	97	27E
0005435725529	13502	98	28A
0005434264994	13502	99	27H
0005435462254	13502	100	28B
0005435725518	13502	101	28D
0005434831127	13502	102	28F
0005435462256	13502	103	28E
0005435462257	13502	104	28G
0005435765269	13502	105	29A
0005435462243	13502	106	29B
0005434265011	13502	107	29E
0005434264993	13502	108	29D
0005435462234	13502	109	29H
0005435765445	13502	110	29G
0005435462237	13502	111	30A
0005434264998	13502	112	30D
0005434265016	13502	113	30B
0005435462229	13502	114	30F
0005432535807	13502	115	30G
0005434265005	13502	116	31A
0005434264996	13502	117	31B
0005434265000	13502	118	31F
0005435462224	13502	119	31G
0005435765597	13502	120	32A
0005435462250	13502	121	31H
0005435720125	13502	122	32B
0005435765381	13502	123	32E
0005434265006	13502	124	32F
0005435765380	13502	125	33A
0005434264999	13502	126	33D
0005435765539	13502	127	33F
0005435765324	13502	128	33H
0005434831128	13502	129	33G
0005435043281	13502	130	34A
0005435462245	13502	131	34D
0005434265003	13502	132	34B
0005435462240	13502	133	34E
0005435765430	13502	134	34F
0005434265007	13502	135	35A
0005435765607	13502	136	34H
0005432535808	13502	137	35B
0005435765512	13502	138	35G
0005432194489	13502	139	35H
0005435765454	13502	140	36B
0005435765712	13502	141	36A
0005435765590	13502	142	36D
0005432194488	13502	143	36E
0005435462242	13502	144	36G
0005435765447	13502	145	37A
0005435765458	13502	146	36H
0005435765363	13502	147	37D
0005434265009	13502	148	37F
0005435462238	13502	149	37E
0005435462252	13502	150	38A
0005435765297	13502	151	37H
0005434265010	13502	152	38D
0005435462255	13502	153	38B
0005435462225	13502	154	38G
0005435462258	13502	155	38F
0005435765344	13502	156	38H
0005435462249	13502	157	39E
0005435462239	13502	158	39D
0005435765300	13502	159	39F
0005434602866	18680	1	1B
0005434602872	18680	2	3A
0005434602867	18680	3	5B
0005434514950	18681	1	1A
0005434604854	18681	2	1B
0005434514953	18681	3	2A
0005434604845	18681	4	4A
0005434514951	18681	5	4B
0005434514952	18681	6	5B
0005434604855	18681	7	6B
0005434602883	19145	1	1A
0005434514929	19145	2	1B
0005434602884	19145	3	3A
0005434602885	19145	4	4A
0005434602880	19145	5	4B
0005434602882	19145	6	5B
0005434602881	19145	7	6A
0005435844284	25099	1	1A
0005435844287	25099	2	1F
0005435846225	25099	3	2D
0005432649300	25099	4	2F
0005435844286	25099	5	3A
0005435846226	25099	6	3D
0005432649338	25099	7	4D
0005432649308	25099	8	4E
0005432632636	25099	9	5C
0005435846228	25099	10	6E
0005432632629	25099	11	7D
0005435844294	25099	12	7E
0005435846227	25099	13	7F
0005435844297	25099	14	8C
0005435846229	25099	15	8D
0005435846230	25099	16	9D
0005435844285	25099	17	10C
0005435844288	25099	18	10E
0005435846232	25099	19	10F
0005435844292	25099	20	11A
0005432649304	25099	21	11C
0005435844293	25099	22	11E
0005435844289	25099	23	12A
0005435844295	25099	24	12D
0005432632640	25099	25	12E
0005435846231	25099	26	12F
0005432632632	25099	27	13C
0005435844290	25099	28	13D
0005432649305	25099	29	13F
0005432649306	25099	30	14D
0005435844298	25099	31	14E
0005432649299	25099	32	15A
0005432649337	25099	33	15E
0005435846234	25099	34	16C
0005435846235	25099	35	16D
0005432632623	25099	36	16F
0005435844296	25099	37	17A
0005432649326	25099	38	17C
0005435846233	25099	39	17F
0005435844283	25099	40	19C
0005435844291	25099	41	19D
0005432649310	25099	42	20F
0005433284861	1809	1	1A
0005433007845	1809	2	1C
0005433284857	1809	3	1F
0005433284894	1809	4	2A
0005433284791	1809	5	2C
0005433007907	1809	6	2D
0005433008142	1809	7	2F
0005433284987	1809	8	3A
0005433284968	1809	9	3C
0005433284885	1809	10	3D
0005433007965	1809	11	4A
0005433007999	1809	12	4C
0005433007846	1809	13	4D
0005433007896	1809	14	4E
0005433008009	1809	15	4F
0005433007945	1809	16	5A
0005433008053	1809	17	5C
0005433008080	1809	18	5D
0005433008162	1809	19	5E
0005433284884	1809	20	6A
0005433284858	1809	21	6D
0005433284984	1809	22	6E
0005433284875	1809	23	6F
0005433810522	1809	24	7C
0005433284887	1809	25	7D
0005433008089	1809	26	8A
0005433007867	1809	27	8C
0005433284988	1809	28	8D
0005433007995	1809	29	8E
0005433284806	1809	30	9C
0005433284939	1809	31	9D
0005433007978	1809	32	9E
0005433007906	1809	33	9F
0005433007963	1809	34	10A
0005433007998	1809	35	10C
0005433008107	1809	36	10D
0005433007866	1809	37	10E
0005433007865	1809	38	10F
0005433007864	1809	39	11D
0005433008173	1809	40	11E
0005432295866	1809	41	11F
0005433284895	1809	42	12A
0005433008161	1809	43	12C
0005433284903	1809	44	12D
0005433284802	1809	45	12F
0005433008056	1809	46	13A
0005433284801	1809	47	13D
0005433007940	1809	48	13F
0005433007966	1809	49	14A
0005433008081	1809	50	14C
0005433008214	1809	51	14D
0005433284974	1809	52	14F
0005433007937	1809	53	15A
0005433284852	1809	54	15C
0005433284868	1809	55	15D
0005433284898	1809	56	15E
0005433008213	1809	57	15F
0005433008008	1809	58	16D
0005433284867	1809	59	16E
0005433284797	1809	60	16F
0005433810521	1809	61	17A
0005432295867	1809	62	17C
0005433008088	1809	63	17D
0005433284870	1809	64	17E
0005433007994	1809	65	17F
0005433284869	1809	66	18A
0005433284897	1809	67	18D
0005433284915	1809	68	18F
0005433284809	1809	69	19C
0005433284952	1809	70	19D
0005433008054	1809	71	19E
0005433008120	1809	72	19F
0005433284941	1809	73	20A
0005433284938	1809	74	20C
0005433810523	1809	75	20D
0005433284982	1809	76	20E
0005433008062	1809	77	20F
0005433008377	22584	1	1A
0005433285106	22584	2	1C
0005433285117	22584	3	1D
0005433008335	22584	4	1F
0005433008362	22584	5	2A
0005433285109	22584	6	2C
0005433285116	22584	7	2D
0005433285114	22584	8	3A
0005433008349	22584	9	2F
0005433285105	22584	10	3C
0005433008361	22584	11	3D
0005433008375	22584	12	4A
0005433008341	22584	13	4C
0005433285120	22584	14	4D
0005433008352	22584	15	4F
0005433285129	22584	16	5A
0005433285130	22584	17	5D
0005433008357	22584	18	5E
0005433285111	22584	19	5F
0005433285125	22584	20	6A
0005433285133	22584	21	6D
0005433008354	22584	22	6E
0005433008367	22584	23	6F
0005433285107	22584	24	7A
0005433008368	22584	25	7C
0005433008345	22584	26	7D
0005433008351	22584	27	7E
0005433008340	22584	28	7F
0005433008365	22584	29	8A
0005433285110	22584	30	8C
0005433285134	22584	31	8D
0005433285123	22584	32	8E
0005433008378	22584	33	8F
0005433008346	22584	34	9A
0005433008337	22584	35	9C
0005433285132	22584	36	9E
0005433008366	22584	37	9F
0005433285108	22584	38	10A
0005433008355	22584	39	10C
0005433008347	22584	40	10D
0005433008336	22584	41	10E
0005433008370	22584	42	10F
0005433008374	22584	43	11A
0005433008343	22584	44	11C
0005433285103	22584	45	11D
0005433285127	22584	46	11E
0005433008350	22584	47	11F
0005433285113	22584	48	12C
0005433008364	22584	49	12D
0005433008363	22584	50	12F
0005433285118	22584	51	13A
0005433008356	22584	52	13C
0005433810488	22584	53	13E
0005433008371	22584	54	13F
0005433008344	22584	55	14A
0005433285126	22584	56	14C
0005433008369	22584	57	14F
0005433008338	22584	58	15C
0005433285128	22584	59	15D
0005433008359	22584	60	15F
0005433008372	22584	61	16A
0005433285122	22584	62	16D
0005433285119	22584	63	16F
0005433285131	22584	64	17A
0005433008339	22584	65	17C
0005433008358	22584	66	17F
0005433285115	22584	67	18A
0005433008348	22584	68	18C
0005433008353	22584	69	18D
0005433285121	22584	70	18E
0005433008360	22584	71	18F
0005433008334	22584	72	19A
0005433008373	22584	73	19D
0005433008376	22584	74	19E
0005433285112	22584	75	20A
0005433285124	22584	76	20C
0005433285104	22584	77	20D
0005433008333	22584	78	20E
0005433008342	22584	79	20F
0005435282145	5575	1	1C
0005433846390	5575	2	1A
0005435282106	5575	3	1D
0005432081474	5575	4	1F
0005435282144	5575	5	2F
0005433846391	5575	6	3D
0005433815357	5575	7	3C
0005435282163	5575	8	4A
0005433815356	5575	9	3F
0005433846417	5575	10	4F
0005433846389	5575	11	4D
0005433846402	5575	12	5A
0005433846422	5575	13	5F
0005435282159	5575	14	5D
0005433846420	5575	15	6A
0005433846439	5575	16	6E
0005433846404	5575	17	6D
0005433846394	5575	18	7A
0005433846424	5575	19	7C
0005433846419	5575	20	7B
0005433846425	5575	21	7E
0005435282158	5575	22	7D
0005435282165	5575	23	8A
0005435282142	5575	24	7F
0005433846407	5575	25	8B
0005435282160	5575	26	8D
0005433846409	5575	27	8C
0005433846434	5575	28	8F
0005433846392	5575	29	9B
0005435282112	5575	30	9A
0005433846415	5575	31	9D
0005433846430	5575	32	9C
0005433846410	5575	33	9E
0005433846380	5575	34	10A
0005435282155	5575	35	9F
0005435282105	5575	36	10C
0005433846418	5575	37	10B
0005433846393	5575	38	10E
0005433846387	5575	39	10D
0005433846432	5575	40	10F
0005433846408	5575	41	11A
0005435282100	5575	42	11D
0005435282091	5575	43	11C
0005433846423	5575	44	11F
0005435282103	5575	45	11E
0005433846386	5575	46	12A
0005435282113	5575	47	12D
0005433846385	5575	48	12E
0005435282166	5575	49	13A
0005435282096	5575	50	12F
0005433846383	5575	51	13C
0005433846414	5575	52	13B
0005433846431	5575	53	13E
0005435282156	5575	54	13D
0005432081478	5575	55	14A
0005433846427	5575	56	13F
0005433846413	5575	57	14C
0005433846435	5575	58	14B
0005433846398	5575	59	14D
0005435282157	5575	60	14F
0005432081476	5575	61	14E
0005433846381	5575	62	15A
0005433846388	5575	63	15D
0005433846416	5575	64	15C
0005435282146	5575	65	15F
0005433846429	5575	66	15E
0005435282099	5575	67	16B
0005433846426	5575	68	16D
0005433815358	5575	69	16C
0005433846384	5575	70	16F
0005435282071	5575	71	16E
0005433846401	5575	72	17C
0005432081473	5575	73	17B
0005435282098	5575	74	17A
0005433846436	5575	75	17D
0005433846395	5575	76	17F
0005433846406	5575	77	17E
0005433846396	5575	78	18B
0005433846405	5575	79	18A
0005435282092	5575	80	18D
0005433846412	5575	81	18E
0005433846411	5575	82	19A
0005433846403	5575	83	18F
0005432081477	5575	84	19B
0005432081479	5575	85	19E
0005432081475	5575	86	19C
0005433846399	5575	87	19F
0005433846400	5575	88	20B
0005433846437	5575	89	20A
0005435282114	5575	90	20D
0005433846382	5575	91	20C
0005435282143	5575	92	20F
0005435282123	5575	93	20E
0005433815355	5575	94	21A
0005433846438	5575	95	21C
0005433846428	5575	96	21B
0005433846397	5575	97	21E
0005433846433	5575	98	21D
0005433846421	5575	99	21F
0005433845817	13831	1	1C
0005433845710	13831	2	1A
0005433846007	13831	3	1F
0005433845876	13831	4	1D
0005433845745	13831	5	2A
0005433845882	13831	6	2F
0005433845907	13831	7	2D
0005433845753	13831	8	3A
0005433845699	13831	9	3D
0005433845894	13831	10	3C
0005433845829	13831	11	3F
0005435282385	13831	12	4C
0005433845850	13831	13	4A
0005435282383	13831	14	4F
0005433845972	13831	15	4D
0005433846138	13831	16	5D
0005435282382	13831	17	5C
0005433845953	13831	18	5A
0005433845788	13831	19	5F
0005435282373	13831	20	6B
0005434173498	13831	21	6A
0005433845924	13831	22	6C
0005433815311	13831	23	6E
0005435282387	13831	24	7A
0005433845949	13831	25	6F
0005433845701	13831	26	7C
0005433845677	13831	27	7B
0005434173500	13831	28	7E
0005435282390	13831	29	7D
0005433845733	13831	30	8A
0005435282386	13831	31	7F
0005435282381	13831	32	8C
0005435282388	13831	33	8B
0005433846021	13831	34	8D
0005433845858	13831	35	8E
0005432003683	13831	36	9D
0005433846260	13831	37	9C
0005434173499	13831	38	9B
0005433845971	13831	39	9E
0005433845867	13831	40	10A
0005433845849	13831	41	9F
0005433845747	13831	42	10C
0005433845676	13831	43	10B
0005435282389	13831	44	10D
0005435282391	13831	45	10F
0005433845831	13831	46	10E
0005435282380	13831	47	11B
0005433845845	13831	48	11A
0005433846006	13831	49	11D
0005433845794	13831	50	11C
0005435282375	13831	51	11F
0005433845987	13831	52	11E
0005433845752	13831	53	12B
0005435282368	13831	54	12A
0005433845729	13831	55	12D
0005433845912	13831	56	12C
0005433845678	13831	57	12E
0005433845724	13831	58	13A
0005433845789	13831	59	12F
0005433845764	13831	60	13B
0005432003685	13831	61	13E
0005433845925	13831	62	14A
0005433846085	13831	63	13F
0005433845973	13831	64	14B
0005433845951	13831	65	14D
0005432003684	13831	66	14C
0005433846024	13831	67	14F
0005433845909	13831	68	14E
0005435282376	13831	69	15A
0005433845883	13831	70	15D
0005435282371	13831	71	15C
0005435282384	13831	72	15B
0005433845732	13831	73	15E
0005433846261	13831	74	16A
0005433845961	13831	75	15F
0005433845851	13831	76	16C
0005432003686	13831	77	16B
0005433845923	13831	78	16D
0005435282392	13831	79	16F
0005433846010	13831	80	17A
0005435282379	13831	81	17D
0005433845746	13831	82	17C
0005433845952	13831	83	17F
0005433845947	13831	84	17E
0005433845703	13831	85	18B
0005433845908	13831	86	18A
0005433846012	13831	87	18D
0005435282374	13831	88	18C
0005433845918	13831	89	19A
0005433845763	13831	90	18F
0005433845997	13831	91	19B
0005433845731	13831	92	19E
0005435282377	13831	93	19D
0005433845868	13831	94	19C
0005433846137	13831	95	19F
0005433845877	13831	96	20B
0005433845702	13831	97	20A
0005433846064	13831	98	20D
0005433845900	13831	99	20C
0005435282378	13831	100	20F
0005435282372	13831	101	21A
0005433845969	13831	102	21C
0005435282369	13831	103	21B
0005435282370	13831	104	21F
0005433845728	13831	105	21D
0005434620479	7809	1	1A
0005435332197	7809	2	1D
0005434620491	7809	3	2B
0005435332196	7809	4	2C
0005434620493	7809	5	3A
0005435332223	7809	6	3B
0005434620485	7809	7	3C
0005434620474	7809	8	3D
0005434620481	7809	9	4A
0005434620492	7809	10	4B
0005432112505	7809	11	4C
0005432112503	7809	12	5B
0005434620484	7809	13	5C
0005434620482	7809	14	6B
0005434620476	7809	15	6C
0005435332222	7809	16	6D
0005434620487	7809	17	18A
0005434620480	7809	18	18D
0005435332205	7809	19	19A
0005434620483	7809	20	19B
0005434620475	7809	21	19C
0005435332198	7809	22	20A
0005435332176	7809	23	20B
0005432112504	7809	24	20C
0005434620490	7809	25	21A
0005434620477	7809	26	21B
0005435332195	7809	27	21C
0005434620486	7809	28	21D
0005434620489	7809	29	22A
0005434620488	7809	30	22D
0005434620494	7809	31	23A
0005434620478	7809	32	23B
0005435332277	32998	1	1A
0005434620264	32998	2	1B
0005434620276	32998	3	1C
0005434620224	32998	4	1D
0005435332281	32998	5	2B
0005434620287	32998	6	2C
0005435332283	32998	7	2D
0005435332275	32998	8	3A
0005434620288	32998	9	3B
0005434620285	32998	10	3C
0005434620275	32998	11	4A
0005435332282	32998	12	4C
0005434620361	32998	13	4D
0005435332276	32998	14	5D
0005434620286	32998	15	6B
0005435332280	32998	16	6D
0005435332274	32998	17	7A
0005435332284	32998	18	7C
0005434620223	32998	19	18A
0005434620360	32998	20	18C
0005435332278	32998	21	19C
0005434620292	32998	22	20A
0005434620341	32998	23	20B
0005434620270	32998	24	20D
0005434620240	32998	25	21C
0005434620336	32998	26	22A
0005434620239	32998	27	22B
0005434620330	32998	28	22C
0005434620329	32998	29	22D
0005435332279	32998	30	23A
0005435918616	4267	1	1C
0005435918577	4267	2	2A
0005435785156	4267	3	2C
0005435785162	4267	4	2D
0005435785159	4267	5	3A
0005435785171	4267	6	3D
0005435785165	4267	7	3F
0005435785177	4267	8	4E
0005435785185	4267	9	4F
0005435787343	4267	10	5A
0005435785174	4267	11	5C
0005434993967	4267	12	5F
0005435918594	4267	13	6A
0005435785184	4267	14	6E
0005434993973	4267	15	6F
0005435785173	4267	16	7A
0005435785155	4267	17	7C
0005435785160	4267	18	7D
0005435787341	4267	19	8A
0005434993974	4267	20	8D
0005435785172	4267	21	8E
0005432190607	4267	22	8F
0005435785163	4267	23	9A
0005432190611	4267	24	9C
0005435785180	4267	25	9D
0005435918578	4267	26	9E
0005432190608	4267	27	9F
0005435785168	4267	28	10A
0005434993970	4267	29	10C
0005435785166	4267	30	10D
0005432190609	4267	31	10F
0005435785181	4267	32	11C
0005435785167	4267	33	11E
0005434993972	4267	34	11F
0005435785157	4267	35	12C
0005435785176	4267	36	12D
0005435785175	4267	37	12F
0005434993965	4267	38	13D
0005435785182	4267	39	14A
0005435785183	4267	40	14C
0005435785164	4267	41	14D
0005435785154	4267	42	14E
0005435787342	4267	43	15A
0005434993969	4267	44	15C
0005435937309	4267	45	15D
0005435785170	4267	46	15E
0005435785161	4267	47	16D
0005435785158	4267	48	16F
0005435785178	4267	49	17D
0005434993968	4267	50	17F
0005435785169	4267	51	18A
0005435785186	4267	52	18D
0005435937312	4267	53	18E
0005434993966	4267	54	19D
0005434993971	4267	55	19F
0005435785153	4267	56	20C
0005432190610	4267	57	20F
0005435785179	4267	58	20E
0005435784744	27329	1	1C
0005435784806	27329	2	1D
0005435784795	27329	3	2C
0005435784783	27329	4	2D
0005435784829	27329	5	4A
0005435784831	27329	6	4D
0005435784777	27329	7	4F
0005434993851	27329	8	5C
0005432195680	27329	9	5D
0005432195681	27329	10	5E
0005435784753	27329	11	6A
0005435784765	27329	12	6C
0005435784900	27329	13	7E
0005434993909	27329	14	7F
0005435784876	27329	15	8A
0005435918631	27329	16	8C
0005435784824	27329	17	8E
0005435784836	27329	18	8F
0005435784760	27329	19	9E
0005435784761	27329	20	9F
0005435784769	27329	21	10C
0005435784778	27329	22	10D
0005435784850	27329	23	10E
0005435918629	27329	24	10F
0005435918627	27329	25	11C
0005434993852	27329	26	11D
0005435784754	27329	27	12A
0005435784870	27329	28	12D
0005434993934	27329	29	12E
0005435784763	27329	30	13A
0005435918630	27329	31	13C
0005435784832	27329	32	14A
0005435784899	27329	33	14C
0005435784779	27329	34	14D
0005435784767	27329	35	14E
0005435784785	27329	36	14F
0005435784766	27329	37	15C
0005435784762	27329	38	15D
0005435784745	27329	39	15E
0005435784828	27329	40	15F
0005435784823	27329	41	16E
0005432195679	27329	42	17A
0005435784890	27329	43	17F
0005435918628	27329	44	17E
0005435784814	27329	45	18C
0005435784730	27329	46	18D
0005435784875	27329	47	18F
0005435784813	27329	48	20C
0005432146186	19893	1	5A
0005432146187	19893	2	20C
0005432567278	4709	1	1B
0005432459596	4709	2	1F
0005432567329	4709	3	1H
0005432459590	4709	4	1G
0005434081771	4709	5	2A
0005432567328	4709	6	2B
0005432459569	4709	7	2F
0005432459547	4709	8	2G
0005434081782	4709	9	3A
0005432459566	4709	10	2H
0005432567322	4709	11	3C
0005433726092	4709	12	3G
0005432567281	4709	13	3H
0005432567315	4709	14	4B
0005432567295	4709	15	4C
0005432459555	4709	16	4F
0005432567318	4709	17	5A
0005432567283	4709	18	4H
0005432186850	4709	19	5B
0005432567279	4709	20	5C
0005434081776	4709	21	5G
0005434081772	4709	22	5H
0005434081784	4709	23	9B
0005432567332	4709	24	9A
0005434081774	4709	25	9G
0005432567293	4709	26	11A
0005432170349	4709	27	9H
0005432170354	4709	28	11D
0005432170348	4709	29	11F
0005434081779	4709	30	11H
0005432567331	4709	31	11G
0005432459570	4709	32	12A
0005434081764	4709	33	12B
0005432567324	4709	34	12E
0005432567317	4709	35	12D
0005432459568	4709	36	12F
0005432459594	4709	37	12H
0005432186851	4709	38	12G
0005432170352	4709	39	13A
0005432459593	4709	40	13D
0005432459574	4709	41	13B
0005432459572	4709	42	13E
0005432567308	4709	43	13H
0005432459567	4709	44	14A
0005433451608	4709	45	14F
0005432459551	4709	46	14G
0005432459564	4709	47	15A
0005432567321	4709	48	14H
0005434081762	4709	49	15E
0005432459565	4709	50	15D
0005432567282	4709	51	15F
0005432567334	4709	52	15H
0005434081780	4709	53	16A
0005434081766	4709	54	16D
0005432567313	4709	55	16G
0005432567307	4709	56	16F
0005432567285	4709	57	16H
0005432567280	4709	58	17B
0005432459582	4709	59	17D
0005432459586	4709	60	17E
0005432567291	4709	61	17G
0005432567327	4709	62	17F
0005432459550	4709	63	17H
0005432567323	4709	64	18A
0005432170350	4709	65	18D
0005434081781	4709	66	18F
0005434081761	4709	67	18G
0005432567319	4709	68	18H
0005432459589	4709	69	19D
0005432459584	4709	70	19F
0005432459576	4709	71	19E
0005432567304	4709	72	19H
0005432459581	4709	73	19G
0005432567302	4709	74	20A
0005432459553	4709	75	20B
0005434081775	4709	76	20D
0005432567276	4709	77	20F
0005432567287	4709	78	21B
0005432459579	4709	79	21A
0005432571301	4709	80	20H
0005432459595	4709	81	21D
0005434081773	4709	82	21E
0005432567338	4709	83	21G
0005432567333	4709	84	22B
0005434081770	4709	85	22A
0005432459561	4709	86	22D
0005432459580	4709	87	22E
0005432459592	4709	88	23A
0005432567309	4709	89	22H
0005433726091	4709	90	23B
0005432567314	4709	91	23E
0005432567288	4709	92	23D
0005434081778	4709	93	23G
0005432459549	4709	94	24A
0005432459548	4709	95	23H
0005432459558	4709	96	24B
0005432567286	4709	97	24D
0005434081768	4709	98	24F
0005432567289	4709	99	24E
0005432459563	4709	100	24G
0005432567296	4709	101	25D
0005432186848	4709	102	24H
0005434081759	4709	103	25E
0005434081788	4709	104	25F
0005432567303	4709	105	27A
0005432567311	4709	106	27E
0005434081763	4709	107	27D
0005432567305	4709	108	27F
0005432459571	4709	109	27H
0005434081765	4709	110	27G
0005432567306	4709	111	28A
0005432567301	4709	112	28B
0005432571302	4709	113	28E
0005432170351	4709	114	28H
0005432567337	4709	115	28G
0005432459546	4709	116	29A
0005432567292	4709	117	29B
0005432567299	4709	118	29F
0005432567298	4709	119	29E
0005434081760	4709	120	29G
0005432459557	4709	121	29H
0005432459573	4709	122	30B
0005433451609	4709	123	30A
0005434081777	4709	124	30E
0005432571300	4709	125	30G
0005432459562	4709	126	30H
0005434081769	4709	127	31B
0005432459585	4709	128	31A
0005432170353	4709	129	31E
0005432459575	4709	130	31F
0005434081767	4709	131	31H
0005432567316	4709	132	31G
0005432567320	4709	133	32A
0005432567300	4709	134	32B
0005432567290	4709	135	32F
0005432567277	4709	136	32H
0005432459556	4709	137	32G
0005434081783	4709	138	33A
0005432459545	4709	139	33D
0005432459554	4709	140	33B
0005434081789	4709	141	33E
0005432567284	4709	142	33F
0005432186849	4709	143	33H
0005432571299	4709	144	33G
0005432459588	4709	145	34A
0005432459577	4709	146	34D
0005434081787	4709	147	34F
0005432567294	4709	148	34G
0005432459591	4709	149	35A
0005432459587	4709	150	35E
0005432567297	4709	151	36B
0005432567325	4709	152	36E
0005432567336	4709	153	36D
0005432567326	4709	154	36H
0005432459560	4709	155	36G
0005432567312	4709	156	37A
0005432459583	4709	157	37B
0005432567339	4709	158	37E
0005434081786	4709	159	37D
0005434081785	4709	160	37H
0005432567335	4709	161	38A
0005432567330	4709	162	38B
0005432459578	4709	163	38D
0005432459559	4709	164	38H
0005432567310	4709	165	39E
0005432459552	4709	166	39D
0005432459315	30549	1	1A
0005432459377	30549	2	1F
0005432459048	30549	3	1H
0005432459320	30549	4	2C
0005432566743	30549	5	2F
0005432459192	30549	6	2G
0005432213584	30549	7	3A
0005432459187	30549	8	2H
0005432459132	30549	9	3F
0005432566960	30549	10	4A
0005434081611	30549	11	4C
0005432459189	30549	12	4H
0005432213586	30549	13	5B
0005434081551	30549	14	5G
0005432458982	30549	15	9A
0005434081486	30549	16	5H
0005432459321	30549	17	9G
0005432566800	30549	18	9H
0005432459070	30549	19	11B
0005432566578	30549	20	11E
0005433452705	30549	21	11F
0005432459083	30549	22	11H
0005432566911	30549	23	11G
0005434081609	30549	24	12A
0005433452701	30549	25	12B
0005432459027	30549	26	12E
0005432459284	30549	27	12D
0005432459237	30549	28	12F
0005434081598	30549	29	12H
0005432566900	30549	30	12G
0005432459266	30549	31	13A
0005432459035	30549	32	13D
0005432566848	30549	33	13E
0005432459092	30549	34	13G
0005434081596	30549	35	13F
0005432566728	30549	36	14A
0005432459241	30549	37	14B
0005432566813	30549	38	14F
0005432459265	30549	39	14E
0005434081470	30549	40	15A
0005434081548	30549	41	15E
0005432566967	30549	42	15H
0005434081532	30549	43	16A
0005432459316	30549	44	16E
0005434081502	30549	45	16D
0005432566872	30549	46	16F
0005432459283	30549	47	16H
0005432459158	30549	48	17B
0005432566809	30549	49	17A
0005434081560	30549	50	17D
0005432566942	30549	51	17F
0005432459127	30549	52	18B
0005432161141	30549	53	18G
0005432566873	30549	54	19B
0005432459081	30549	55	19E
0005432459154	30549	56	19D
0005432459065	30549	57	19F
0005433454848	30549	58	19H
0005432459376	30549	59	20D
0005432459172	30549	60	20B
0005432459144	30549	61	20G
0005432571291	30549	62	20F
0005432566781	30549	63	20E
0005432567032	30549	64	21D
0005432566803	30549	65	21B
0005432566696	30549	66	21E
0005432459082	30549	67	21H
0005432566732	30549	68	22B
0005434081608	30549	69	22D
0005434081509	30549	70	22E
0005432459214	30549	71	22F
0005432566768	30549	72	22H
0005432567034	30549	73	23D
0005432566755	30549	74	23F
0005432459122	30549	75	23E
0005432566907	30549	76	23G
0005432566877	30549	77	23H
0005432566959	30549	78	24F
0005432459185	30549	79	24G
0005432571275	30549	80	24H
0005432213585	30549	81	25E
0005432566916	30549	82	27B
0005432459188	30549	83	27E
0005432566654	30549	84	27F
0005432459064	30549	85	28A
0005433452716	30549	86	27H
0005432459153	30549	87	28B
0005432566899	30549	88	28E
0005432459293	30549	89	28D
0005434081527	30549	90	28F
0005434081582	30549	91	28G
0005432459202	30549	92	28H
0005434081561	30549	93	29B
0005432459279	30549	94	29F
0005432566940	30549	95	29H
0005432459128	30549	96	30E
0005432567152	30549	97	30D
0005432459076	30549	98	30B
0005434081549	30549	99	30F
0005433452704	30549	100	30G
0005432567003	30549	101	31E
0005432566856	30549	102	31H
0005432459234	30549	103	31G
0005432567035	30549	104	32B
0005432459275	30549	105	32E
0005432566733	30549	106	32G
0005432566767	30549	107	32F
0005432459026	30549	108	33A
0005432459080	30549	109	33D
0005432566832	30549	110	33E
0005432459063	30549	111	33G
0005432566943	30549	112	33F
0005432566652	30549	113	34A
0005432566805	30549	114	34D
0005432566994	30549	115	34E
0005432566804	30549	116	34G
0005432213587	30549	117	35A
0005432566917	30549	118	34H
0005432566814	30549	119	35B
0005432566779	30549	120	35D
0005432459183	30549	121	35E
0005432459186	30549	122	35F
0005434081559	30549	123	36A
0005432566799	30549	124	35H
0005432213588	30549	125	36B
0005432566716	30549	126	36E
0005432459178	30549	127	37A
0005432459179	30549	128	37E
0005432567151	30549	129	37D
0005434081526	30549	130	37F
0005432566579	30549	131	37H
0005434081508	30549	132	37G
0005432566986	30549	133	38B
0005432566795	30549	134	38E
0005432161140	30549	135	38F
0005434081597	30549	136	38G
0005432567150	30549	137	39D
0005432566906	30549	138	39F
0005432566812	30549	139	39E
0005435720819	13608	1	1A
0005435722042	13608	2	1B
0005435722043	13608	3	6A
0005435722041	13608	4	6B
0005435722019	21214	1	1B
0005435722017	21214	2	2B
0005435722020	21214	3	3A
0005435722030	21214	4	3B
0005435720121	21214	5	4A
0005435722021	21214	6	5A
0005435722016	21214	7	5B
0005435722018	21214	8	6A
0005432295866	22786	1	4A
0005432295867	22786	2	23B
0005433342626	11077	1	1A
0005433342666	11077	2	1C
0005433342661	11077	3	1D
0005433342599	11077	4	2A
0005433342635	11077	5	1F
0005433342615	11077	6	2C
0005435508177	11077	7	2F
0005433342690	11077	8	3C
0005435097146	11077	9	3A
0005433342611	11077	10	3F
0005433342612	11077	11	3D
0005433342657	11077	12	4A
0005433342619	11077	13	4C
0005433342685	11077	14	4B
0005433342689	11077	15	4D
0005433342606	11077	16	4E
0005433342696	11077	17	4F
0005435097149	11077	18	5B
0005433342600	11077	19	5A
0005433342617	11077	20	5D
0005433342616	11077	21	5C
0005433342658	11077	22	5E
0005433342636	11077	23	6A
0005433342680	11077	24	5F
0005433342624	11077	25	6B
0005433342669	11077	26	6C
0005433342672	11077	27	6D
0005433342651	11077	28	6F
0005433342607	11077	29	6E
0005433342632	11077	30	7A
0005433342698	11077	31	7B
0005433342671	11077	32	7C
0005433342609	11077	33	7E
0005433342625	11077	34	7D
0005433342634	11077	35	7F
0005433342613	11077	36	8B
0005433342622	11077	37	8A
0005435097151	11077	38	8D
0005433342654	11077	39	8C
0005433342673	11077	40	8E
0005435508176	11077	41	9A
0005433342643	11077	42	8F
0005433342679	11077	43	9B
0005433342655	11077	44	9C
0005433342629	11077	45	9E
0005433342623	11077	46	9D
0005435097147	11077	47	9F
0005433342684	11077	48	10B
0005433342653	11077	49	10C
0005433342675	11077	50	10E
0005433342686	11077	51	10D
0005433342641	11077	52	11A
0005435508189	11077	53	11B
0005433342631	11077	54	11C
0005435380247	11077	55	11E
0005433342656	11077	56	11D
0005433342691	11077	57	11F
0005435097148	11077	58	12A
0005433342642	11077	59	12C
0005433342645	11077	60	12B
0005433342677	11077	61	12D
0005433342605	11077	62	12E
0005433342610	11077	63	12F
0005433342637	11077	64	13A
0005433342694	11077	65	13C
0005433342682	11077	66	13B
0005433342627	11077	67	13D
0005433342633	11077	68	13E
0005435508218	11077	69	14A
0005433342662	11077	70	13F
0005433342664	11077	71	14B
0005433342644	11077	72	14C
0005433342668	11077	73	14D
0005433342697	11077	74	14E
0005433342649	11077	75	14F
0005433342603	11077	76	15B
0005433342652	11077	77	15A
0005433342608	11077	78	15D
0005433342676	11077	79	15C
0005435508220	11077	80	15F
0005433342646	11077	81	15E
0005433342620	11077	82	16A
0005433342663	11077	83	16B
0005433342692	11077	84	16C
0005435097153	11077	85	16D
0005435508204	11077	86	16E
0005435097156	11077	87	17A
0005433342640	11077	88	16F
0005433342618	11077	89	17B
0005433342693	11077	90	17C
0005433342639	11077	91	17E
0005433342701	11077	92	17D
0005433342667	11077	93	17F
0005435508166	11077	94	18A
0005433342687	11077	95	18B
0005433342665	11077	96	18D
0005435508186	11077	97	18C
0005433342660	11077	98	18E
0005433342670	11077	99	18F
0005433342638	11077	100	19B
0005433342695	11077	101	19A
0005433342700	11077	102	19D
0005433342688	11077	103	19C
0005433342614	11077	104	19F
0005433342681	11077	105	20A
0005433342604	11077	106	20B
0005433342699	11077	107	20D
0005433342683	11077	108	20C
0005435097150	11077	109	20E
0005435097154	11077	110	20F
0005433342659	11077	111	21B
0005435097155	11077	112	21A
0005435380231	11077	113	21C
0005433342621	11077	114	21D
0005433342674	11077	115	21E
0005433342628	11077	116	21F
0005433342678	11077	117	22A
0005433342601	11077	118	22C
0005433342602	11077	119	22B
0005435508175	11077	120	22D
0005435508190	11077	121	22E
0005433342650	11077	122	23A
0005435097152	11077	123	22F
0005433342630	11077	124	23B
0005433342647	11077	125	23E
0005435508217	11077	126	23D
0005433342648	11077	127	23F
0005433341800	17140	1	1A
0005433341569	17140	2	1D
0005433341527	17140	3	1C
0005433341597	17140	4	2A
0005433342070	17140	5	1F
0005433341802	17140	6	2C
0005433341954	17140	7	2D
0005433341672	17140	8	2F
0005433341848	17140	9	3A
0005433341951	17140	10	3D
0005433341846	17140	11	3C
0005433341723	17140	12	3F
0005433341654	17140	13	4B
0005433341972	17140	14	4D
0005433341565	17140	15	4E
0005433341740	17140	16	4F
0005435097082	17140	17	5A
0005433341584	17140	18	5C
0005435097097	17140	19	5B
0005433341589	17140	20	5D
0005435380270	17140	21	5E
0005433341494	17140	22	5F
0005435380274	17140	23	6B
0005433341458	17140	24	6A
0005433341690	17140	25	6C
0005433341658	17140	26	6E
0005433341716	17140	27	6D
0005433341698	17140	28	7A
0005433341633	17140	29	6F
0005433341689	17140	30	7B
0005435380273	17140	31	7D
0005433341564	17140	32	7C
0005435097080	17140	33	7F
0005435097072	17140	34	8A
0005435097056	17140	35	8B
0005433341495	17140	36	8C
0005435545694	17140	37	8F
0005433342255	17140	38	8E
0005433341508	17140	39	9A
0005435545695	17140	40	9B
0005433341492	17140	41	9C
0005433341554	17140	42	9D
0005433341594	17140	43	9F
0005435097059	17140	44	9E
0005435545696	17140	45	10D
0005433341921	17140	46	10C
0005433341416	17140	47	10E
0005435545692	17140	48	11A
0005433341867	17140	49	11B
0005435545693	17140	50	11C
0005433341545	17140	51	11E
0005433341797	17140	52	11D
0005433341713	17140	53	11F
0005435097081	17140	54	12A
0005433341593	17140	55	12C
0005433341806	17140	56	12B
0005433341831	17140	57	12D
0005433341920	17140	58	12E
0005433341803	17140	59	12F
0005435097057	17140	60	13B
0005433341553	17140	61	13D
0005433341598	17140	62	13E
0005433341801	17140	63	13F
0005435097058	17140	64	14A
0005433341513	17140	65	14C
0005435545691	17140	66	14B
0005435097087	17140	67	14D
0005433341657	17140	68	14E
0005433341509	17140	69	14F
0005433341950	17140	70	15A
0005433341903	17140	71	15C
0005433341600	17140	72	15B
0005433341385	17140	73	15E
0005433341381	17140	74	16A
0005435097085	17140	75	15F
0005433341918	17140	76	16D
0005435380271	17140	77	16E
0005433341459	17140	78	17A
0005433341496	17140	79	17B
0005433342281	17140	80	17C
0005435097061	17140	81	17F
0005433341573	17140	82	17E
0005435097068	17140	83	18A
0005435097066	17140	84	18D
0005433341847	17140	85	18C
0005433341585	17140	86	18F
0005433342068	17140	87	18E
0005433341739	17140	88	19A
0005433342257	17140	89	19B
0005435097060	17140	90	19D
0005433341583	17140	91	19C
0005433341984	17140	92	19E
0005435097049	17140	93	19F
0005435380272	17140	94	20A
0005433341889	17140	95	20C
0005433341599	17140	96	20B
0005433342093	17140	97	20D
0005433341714	17140	98	20E
0005435097051	17140	99	21A
0005433342256	17140	100	20F
0005433341615	17140	101	21D
0005435097048	17140	102	21C
0005433342064	17140	103	21E
0005433342075	17140	104	21F
0005433342063	17140	105	22B
0005433341722	17140	106	22A
0005433341592	17140	107	22C
0005433341570	17140	108	22D
0005433341380	17140	109	22E
0005435097065	17140	110	23A
0005433341544	17140	111	22F
0005433341606	17140	112	23B
0005435097079	17140	113	23C
0005435097086	17140	114	23E
0005433341953	17140	115	23F
0005433507085	9061	1	1C
0005432919545	9061	2	1D
0005433507097	9061	3	2F
0005433507080	9061	4	3A
0005432919629	9061	5	4A
0005432919507	9061	6	4C
0005432919620	9061	7	4E
0005433481128	9061	8	4F
0005433481123	9061	9	5F
0005432919525	9061	10	6A
0005432919595	9061	11	6C
0005432919607	9061	12	6F
0005433507086	9061	13	7A
0005432919508	9061	14	7C
0005433507092	9061	15	8A
0005433507078	9061	16	8D
0005432919510	9061	17	8E
0005433507077	9061	18	8F
0005432919550	9061	19	9A
0005432919605	9061	20	9C
0005433507095	9061	21	9F
0005433481124	9061	22	10A
0005432919586	9061	23	10C
0005433507093	9061	24	10D
0005434158946	9061	25	10E
0005433481130	9061	26	11A
0005432919606	9061	27	11E
0005433507089	9061	28	12A
0005432919587	9061	29	12C
0005433507091	9061	30	13A
0005433481126	9061	31	13D
0005433507094	9061	32	13F
0005433507082	9061	33	14A
0005432919526	9061	34	14C
0005433481125	9061	35	14F
0005433507081	9061	36	15C
0005433507087	9061	37	15F
0005433507088	9061	38	16A
0005433481127	9061	39	16E
0005433481129	9061	40	16F
0005433507096	9061	41	17A
0005432919584	9061	42	17E
0005433507090	9061	43	17F
0005432919585	9061	44	18A
0005432919509	9061	45	18C
0005433507083	9061	46	18D
0005433507079	9061	47	18F
0005433507084	9061	48	19C
0005432919596	9061	49	19E
0005433481131	9061	50	20A
0005432919769	20446	1	1D
0005432919776	20446	2	1F
0005433506974	20446	3	2A
0005433506927	20446	4	2C
0005433481048	20446	5	2F
0005433506964	20446	6	3D
0005433506993	20446	7	3F
0005434158967	20446	8	5E
0005432919765	20446	9	5F
0005433506963	20446	10	6A
0005433506929	20446	11	6D
0005432919761	20446	12	7A
0005432919764	20446	13	7F
0005432919762	20446	14	8C
0005432919777	20446	15	8D
0005433507036	20446	16	8F
0005432919766	20446	17	9C
0005432919779	20446	18	9D
0005433506934	20446	19	9F
0005432919767	20446	20	10C
0005432919775	20446	21	10D
0005433506935	20446	22	10E
0005433506891	20446	23	11C
0005433481070	20446	24	11E
0005434158966	20446	25	12C
0005432919771	20446	26	12D
0005432919780	20446	27	13A
0005433481047	20446	28	13C
0005433481054	20446	29	13D
0005433481081	20446	30	13E
0005433506925	20446	31	13F
0005433481064	20446	32	14A
0005433506932	20446	33	14C
0005432919770	20446	34	14D
0005432919760	20446	35	14E
0005433506920	20446	36	15A
0005432919773	20446	37	15C
0005432919763	20446	38	15D
0005433506915	20446	39	15E
0005432919774	20446	40	16D
0005433506933	20446	41	16F
0005433481098	20446	42	17C
0005433506976	20446	43	17E
0005433481044	20446	44	17F
0005432919778	20446	45	18D
0005432919768	20446	46	18E
0005433481073	20446	47	18F
0005432919772	20446	48	19D
0005433506955	20446	49	19F
0005433481045	20446	50	20A
0005433481065	20446	51	20F
0005432396218	10222	1	1A
0005432394080	10222	2	1B
0005435178978	10222	3	3B
0005432394077	10222	4	4A
0005432396217	10222	5	4B
0005432394078	10222	6	5A
0005432396216	10222	7	5B
0005432394079	10222	8	6A
0005432396219	10222	9	6B
0005432400085	18286	1	1A
0005432400078	18286	2	1B
0005432400087	18286	3	2A
0005432400079	18286	4	3A
0005432396185	18286	5	2B
0005432396182	18286	6	5A
0005435179392	18286	7	5B
0005432396181	18286	8	6A
0005432396186	18286	9	6B
0005435125652	10964	1	1A
0005435125728	10964	2	1C
0005435125912	10964	3	1D
0005434411755	10964	4	1F
0005434411758	10964	5	2A
0005434411754	10964	6	2C
0005435125895	10964	7	2F
0005435625875	10964	8	3A
0005435125794	10964	9	3F
0005435554122	10964	10	4A
0005435125663	10964	11	4C
0005435125841	10964	12	4D
0005435125710	10964	13	4E
0005435125864	10964	14	4F
0005435625911	10964	15	5C
0005435125761	10964	16	5D
0005435625919	10964	17	5E
0005435125805	10964	18	5F
0005435125863	10964	19	6A
0005435125913	10964	20	6C
0005434928284	10964	21	6D
0005435625912	10964	22	7A
0005435125891	10964	23	7C
0005434411759	10964	24	7D
0005435625916	10964	25	7F
0005435625904	10964	26	8A
0005435125760	10964	27	8C
0005435125667	10964	28	8D
0005435125752	10964	29	8F
0005434411756	10964	30	9A
0005435625915	10964	31	9C
0005435125910	10964	32	9D
0005435125770	10964	33	9F
0005435125894	10964	34	10C
0005435125654	10964	35	10D
0005435125804	10964	36	10E
0005435125795	10964	37	10F
0005435125751	10964	38	11A
0005435554112	10964	39	11D
0005435125896	10964	40	11E
0005435125897	10964	41	12A
0005434411757	10964	42	12C
0005435625868	10964	43	12F
0005435125796	10964	44	12E
0005435125741	10964	45	13F
0005435125834	10964	46	14A
0005435554114	10964	47	14C
0005435625905	10964	48	14D
0005435125911	10964	49	14F
0005435125742	10964	50	15D
0005435625894	10964	51	15E
0005435125793	10964	52	15F
0005435125653	10964	53	16A
0005435125764	10964	54	16C
0005434928285	10964	55	17C
0005435625918	10964	56	18A
0005435125799	10964	57	18D
0005435125869	10964	58	19A
0005435125937	10964	59	19C
0005435125806	10964	60	19D
0005435125824	10964	61	19F
0005435625893	10964	62	20A
0005435125704	10964	63	20D
0005435125844	10964	64	20E
0005435125816	10964	65	20F
0005435554159	14744	1	1C
0005435126185	14744	2	1D
0005435626085	14744	3	1F
0005435626084	14744	4	2A
0005435126151	14744	5	2C
0005435126174	14744	6	2D
0005435126154	14744	7	2F
0005435126173	14744	8	3A
0005435126161	14744	9	3C
0005435126163	14744	10	3F
0005435126186	14744	11	4C
0005435126156	14744	12	4D
0005434928261	14744	13	4E
0005435126176	14744	14	4F
0005435626087	14744	15	5A
0005435626080	14744	16	5C
0005434928267	14744	17	5D
0005435126180	14744	18	5E
0005434928264	14744	19	5F
0005435126175	14744	20	6A
0005434411722	14744	21	6C
0005435626078	14744	22	6D
0005435126184	14744	23	6E
0005435126166	14744	24	6F
0005435626075	14744	25	7A
0005434928255	14744	26	7C
0005435626070	14744	27	7D
0005435126160	14744	28	7E
0005435126183	14744	29	7F
0005435126187	14744	30	8A
0005434928257	14744	31	8C
0005435126165	14744	32	8D
0005434411703	14744	33	8E
0005435126164	14744	34	8F
0005435126149	14744	35	9A
0005435126171	14744	36	9C
0005435626074	14744	37	9D
0005435554160	14744	38	9E
0005435126172	14744	39	9F
0005435126170	14744	40	10A
0005435126157	14744	41	10C
0005435126155	14744	42	10E
0005435126181	14744	43	11A
0005435126150	14744	44	11C
0005434411718	14744	45	11D
0005435626089	14744	46	11E
0005434411723	14744	47	12D
0005435554161	14744	48	12E
0005435626090	14744	49	12F
0005435626088	14744	50	13A
0005434411713	14744	51	13D
0005435126178	14744	52	13E
0005435126152	14744	53	13F
0005435554163	14744	54	14A
0005435626076	14744	55	14C
0005435554158	14744	56	14D
0005435126179	14744	57	14E
0005435126162	14744	58	14F
0005435126167	14744	59	15A
0005435626077	14744	60	15C
0005435626091	14744	61	16A
0005435626081	14744	62	16C
0005435626073	14744	63	17A
0005435626079	14744	64	17C
0005435626071	14744	65	17D
0005435126169	14744	66	17E
0005434928256	14744	67	17F
0005434928262	14744	68	18A
0005435126177	14744	69	18C
0005435554162	14744	70	18D
0005435626083	14744	71	18E
0005435626082	14744	72	19A
0005435126153	14744	73	19C
0005435126159	14744	74	19D
0005435126182	14744	75	19E
0005435626086	14744	76	19F
0005435126158	14744	77	20C
0005435126168	14744	78	20D
0005435626072	14744	79	20E
0005434411714	14744	80	20F
0005435715377	7126	1	1A
0005435443192	7126	2	1C
0005435715372	7126	3	1D
0005435715370	7126	4	2F
0005435715385	7126	5	3F
0005432400103	7126	6	4D
0005432400104	7126	7	4F
0005435179384	7126	8	5A
0005435715374	7126	9	5C
0005435715387	7126	10	6D
0005435715378	7126	11	7D
0005435715379	7126	12	7E
0005435715376	7126	13	7F
0005435715375	7126	14	8C
0005435715380	7126	15	8D
0005435443169	7126	16	8F
0005435715382	7126	17	9D
0005435443200	7126	18	9F
0005435715371	7126	19	10D
0005435715373	7126	20	10E
0005435715384	7126	21	11A
0005435715383	7126	22	11D
0005435443215	7126	23	11E
0005435443173	7126	24	12C
0005432398179	7126	25	12D
0005435443193	7126	26	13A
0005435715388	7126	27	13C
0005432398177	7126	28	13D
0005435179383	7126	29	13F
0005435216558	7126	30	14C
0005435715386	7126	31	14E
0005432398176	7126	32	14F
0005435219169	7126	33	15E
0005432400102	7126	34	16D
0005432400101	7126	35	16F
0005435443203	7126	36	17D
0005435443220	7126	37	19D
0005435715381	7126	38	19E
0005432398178	7126	39	19F
0005435443184	7126	40	20D
0005435443201	7126	41	20F
0005435443263	27069	1	1A
0005435715249	27069	2	1D
0005432398154	27069	3	4A
0005435178989	27069	4	5A
0005435715267	27069	5	5D
0005435443268	27069	6	5E
0005435443262	27069	7	6C
0005435715243	27069	8	6E
0005432394048	27069	9	7C
0005435715255	27069	10	7D
0005435715256	27069	11	7F
0005435443261	27069	12	8A
0005435715272	27069	13	8F
0005432394043	27069	14	9D
0005435443265	27069	15	10A
0005435443264	27069	16	10C
0005435715244	27069	17	11C
0005435715232	27069	18	11D
0005435443260	27069	19	12E
0005435178487	27069	20	13D
0005435443266	27069	21	15A
0005435715262	27069	22	15F
0005435715263	27069	23	17A
0005435715242	27069	24	17E
0005435178488	27069	25	18C
0005432394032	27069	26	18E
0005435715241	27069	27	19C
0005435443267	27069	28	20A
0005434084909	2717	1	1B
0005434084907	2717	2	2B
0005434084908	2717	3	5B
0005434084905	2717	4	5A
0005434084906	2717	5	6B
0005433060399	28466	1	1A
0005433060400	28466	2	2A
0005433060401	28466	3	3A
0005433060398	28466	4	6A
0005434084860	28466	5	5B
0005435540675	11391	1	1A
0005435517716	11391	2	1C
0005435517667	11391	3	1D
0005435540711	11391	4	2A
0005435517699	11391	5	3A
0005435517635	11391	6	3F
0005435517656	11391	7	4A
0005435540833	11391	8	4C
0005435517634	11391	9	4E
0005435517659	11391	10	4F
0005435540757	11391	11	5A
0005435517703	11391	12	5D
0005435517688	11391	13	6E
0005435540661	11391	14	6F
0005435540701	11391	15	8A
0005435517675	11391	16	8C
0005435540715	11391	17	8D
0005435517715	11391	18	8F
0005435540772	11391	19	9D
0005435517700	11391	20	9F
0005435540748	11391	21	10D
0005435540749	11391	22	10E
0005435540741	11391	23	11E
0005435517740	11391	24	11F
0005435517597	11391	25	12A
0005435540832	11391	26	12E
0005435540687	11391	27	12F
0005435517658	11391	28	13C
0005435540639	11391	29	14C
0005435517585	11391	30	14D
0005435540690	11391	31	14F
0005435540714	11391	32	15D
0005435517657	11391	33	16A
0005435540653	11391	34	16D
0005435517713	11391	35	16E
0005435540676	11391	36	17D
0005435540660	11391	37	17F
0005435517629	11391	38	18D
0005435540652	11391	39	18F
0005435517698	11391	40	19E
0005435517741	11391	41	20C
0005435540735	11391	42	20E
0005435540877	22248	1	2A
0005435529140	22248	2	2D
0005435540874	22248	3	2F
0005432294473	22248	4	3D
0005435529141	22248	5	4C
0005435540883	22248	6	4E
0005435540872	22248	7	4F
0005435540886	22248	8	5E
0005435529133	22248	9	5F
0005435540875	22248	10	6C
0005435540885	22248	11	6D
0005435529134	22248	12	6F
0005435529137	22248	13	7A
0005435540867	22248	14	7F
0005435529128	22248	15	8D
0005435540871	22248	16	8E
0005435540887	22248	17	9A
0005435529127	22248	18	9F
0005435540866	22248	19	10A
0005435540884	22248	20	10D
0005435540870	22248	21	10F
0005435540876	22248	22	11D
0005435529125	22248	23	12A
0005435529132	22248	24	12C
0005435540881	22248	25	12D
0005435540879	22248	26	12E
0005435529124	22248	27	12F
0005435529123	22248	28	13A
0005435529129	22248	29	14C
0005435529122	22248	30	14F
0005435529143	22248	31	15F
0005435540880	22248	32	16A
0005435529139	22248	33	16D
0005435529136	22248	34	16F
0005435529130	22248	35	17A
0005435540878	22248	36	17C
0005435540868	22248	37	17D
0005435529138	22248	38	17E
0005435529142	22248	39	17F
0005435529135	22248	40	18A
0005435540869	22248	41	18E
0005435540882	22248	42	19C
0005435529131	22248	43	19D
0005435529126	22248	44	20D
0005435540873	22248	45	20E
0005433251108	2262	1	1A
0005434907037	2262	2	1C
0005433251155	2262	3	1D
0005434907024	2262	4	1F
0005433400939	2262	5	2A
0005433251026	2262	6	2C
0005433251077	2262	7	2D
0005433400945	2262	8	2F
0005434907048	2262	9	3A
0005433251208	2262	10	3C
0005434907045	2262	11	3D
0005434907021	2262	12	3F
0005433251152	2262	13	4A
0005433251079	2262	14	4D
0005434907014	2262	15	4E
0005433251114	2262	16	4F
0005433251085	2262	17	5A
0005434907034	2262	18	5C
0005433251055	2262	19	5E
0005434907013	2262	20	5F
0005434907028	2262	21	6A
0005433251123	2262	22	6C
0005434907052	2262	23	6D
0005433400953	2262	24	6E
0005434907044	2262	25	6F
0005434907032	2262	26	7A
0005433251060	2262	27	7C
0005434907050	2262	28	7D
0005433251151	2262	29	7E
0005433251199	2262	30	7F
0005434907035	2262	31	8A
0005434907049	2262	32	8C
0005433251107	2262	33	8D
0005433251102	2262	34	8F
0005433251042	2262	35	9A
0005433400940	2262	36	9C
0005433250994	2262	37	9D
0005434907017	2262	38	9E
0005433251023	2262	39	9F
0005434907019	2262	40	10A
0005434907030	2262	41	10C
0005433251027	2262	42	10D
0005433400952	2262	43	10E
0005433251127	2262	44	10F
0005434907051	2262	45	11A
0005433251134	2262	46	11C
0005434907011	2262	47	11D
0005433400947	2262	48	11E
0005434907040	2262	49	11F
0005434907023	2262	50	12A
0005433400938	2262	51	12C
0005434907033	2262	52	12D
0005433251176	2262	53	12E
0005434907026	2262	54	12F
0005433251089	2262	55	13A
0005434907047	2262	56	13C
0005434907038	2262	57	13D
0005434907018	2262	58	13E
0005434907015	2262	59	13F
0005434907025	2262	60	14A
0005434907022	2262	61	14C
0005433251056	2262	62	14D
0005434907042	2262	63	14E
0005433251097	2262	64	14F
0005433251109	2262	65	15A
0005434907053	2262	66	15C
0005433400944	2262	67	15D
0005434907020	2262	68	15E
0005433251006	2262	69	15F
0005434907046	2262	70	16A
0005433251175	2262	71	16C
0005434907039	2262	72	16D
0005434907036	2262	73	16E
0005434907027	2262	74	16F
0005434907041	2262	75	17A
0005433251024	2262	76	17C
0005434907043	2262	77	17D
0005434907031	2262	78	17E
0005434907016	2262	79	17F
0005433251094	2262	80	18A
0005433250968	2262	81	18C
0005434907029	2262	82	18D
0005433251198	2262	83	18E
0005433251028	2262	84	18F
0005433251156	2262	85	19A
0005434907012	2262	86	19C
0005433251115	2262	87	19D
0005433251078	2262	88	19E
0005433251131	2262	89	19F
0005433251197	2262	90	20A
0005433250940	2262	91	20C
0005433251025	2262	92	20D
0005433251090	2262	93	20E
0005433251057	2262	94	20F
0005433251306	25626	1	1C
0005433251316	25626	2	1F
0005433251321	25626	3	2A
0005434906465	25626	4	2C
0005433251337	25626	5	2D
0005434906491	25626	6	2F
0005433400969	25626	7	3A
0005433251334	25626	8	3C
0005434906592	25626	9	3D
0005433400968	25626	10	3F
0005433251314	25626	11	4A
0005433251310	25626	12	4C
0005434906503	25626	13	4E
0005433251309	25626	14	4F
0005433400966	25626	15	5A
0005434906382	25626	16	5D
0005434906451	25626	17	5F
0005434906783	25626	18	6A
0005433251320	25626	19	6D
0005433251332	25626	20	6E
0005434906614	25626	21	6F
0005433251319	25626	22	7C
0005433251327	25626	23	7D
0005434906472	25626	24	7F
0005434906510	25626	25	8A
0005434906554	25626	26	8C
0005434906797	25626	27	8D
0005433251308	25626	28	8E
0005434906666	25626	29	9C
0005434906440	25626	30	9E
0005434906383	25626	31	9F
0005433251311	25626	32	10A
0005433251315	25626	33	10C
0005434906468	25626	34	10D
0005434906509	25626	35	10E
0005434906467	25626	36	10F
0005434906529	25626	37	11A
0005433251324	25626	38	11C
0005434906450	25626	39	11D
0005434906466	25626	40	12A
0005433251323	25626	41	12D
0005434906439	25626	42	12E
0005433251313	25626	43	12F
0005434906604	25626	44	13A
0005433251317	25626	45	13D
0005433251307	25626	46	13E
0005434906377	25626	47	13F
0005434906384	25626	48	14A
0005433251333	25626	49	14C
0005434906469	25626	50	14D
0005433251325	25626	51	14E
0005434906540	25626	52	14F
0005433251312	25626	53	15C
0005434906396	25626	54	15D
0005434906784	25626	55	16D
0005433251328	25626	56	16E
0005433400967	25626	57	16F
0005433251331	25626	58	17A
0005434906372	25626	59	17C
0005434906563	25626	60	18A
0005433251335	25626	61	18C
0005434906606	25626	62	18D
0005434906612	25626	63	18E
0005434906833	25626	64	18F
0005434906371	25626	65	19A
0005433251326	25626	66	19D
0005434906365	25626	67	19E
0005433251330	25626	68	19F
0005433251329	25626	69	20A
0005433251318	25626	70	20C
0005433251322	25626	71	20D
0005434906471	25626	72	20E
0005433251336	25626	73	20F
0005432620964	2524	1	1B
0005432620967	2524	2	1D
0005432620962	2524	3	2A
0005432620968	2524	4	3A
0005432620966	2524	5	3C
0005432620972	2524	6	4A
0005432862242	2524	7	4B
0005432620970	2524	8	4D
0005432862198	2524	9	6C
0005432620963	2524	10	6D
0005432862195	2524	11	7B
0005432862166	2524	12	7C
0005432620965	2524	13	7D
0005432862185	2524	14	19D
0005432620971	2524	15	20A
0005432620973	2524	16	20B
0005432862199	2524	17	21A
0005432620969	2524	18	21B
0005432620960	2524	19	22B
0005432862238	2524	20	22C
0005432862237	2524	21	23A
0005432620961	2524	22	23B
0005432862259	28031	1	1C
0005432620892	28031	2	2A
0005432862260	28031	3	2C
0005432620857	28031	4	4A
0005432620830	28031	5	4B
0005432862262	28031	6	4C
0005432620877	28031	7	4D
0005432862264	28031	8	5A
0005432620847	28031	9	5B
0005432862261	28031	10	5C
0005432862263	28031	11	5D
0005432620815	28031	12	6B
0005432862265	28031	13	6C
0005432862267	28031	14	6D
0005432620835	28031	15	7A
0005432620848	28031	16	18A
0005432620831	28031	17	18B
0005432620851	28031	18	19B
0005432862266	28031	19	20C
0005432620854	28031	20	21A
0005432620839	28031	21	21B
0005432620853	28031	22	21D
0005432620816	28031	23	23A
0005432620852	28031	24	23B
0005434097468	13081	1	3B
0005434097469	13081	2	4A
0005433451608	31046	1	4A
0005433451609	31046	2	6A
0005433452704	31459	1	1A
0005433452701	31459	2	3A
0005433452716	31459	3	4B
0005433452705	31459	4	5A
0005433454848	31459	5	6B
0005433134086	11973	1	1C
0005433129218	11973	2	2D
0005434142549	11973	3	6A
0005433134085	11973	4	18B
0005433134073	11973	5	19A
0005434142546	11973	6	19B
0005433134088	11973	7	19D
0005433134087	11973	8	20B
0005433129209	11973	9	20D
0005434142545	11973	10	21C
0005433129214	11973	11	22D
0005433134114	29841	1	2B
0005433134113	29841	2	4A
0005434326084	29841	3	4C
0005434184655	29841	4	5B
0005433131686	29841	5	5D
0005434183568	29841	6	6A
0005434183570	29841	7	6B
0005434184654	29841	8	7C
0005434142587	29841	9	7D
0005434142586	29841	10	19A
0005433131685	29841	11	19C
0005434142585	29841	12	20B
0005433131684	29841	13	20D
0005433134115	29841	14	21C
0005434142588	29841	15	21D
0005433134116	29841	16	22A
0005434183569	29841	17	22D
0005433134112	29841	18	23B
0005435697161	16490	1	1A
0005435697187	16490	2	1B
0005435697160	16490	3	1C
0005435697168	16490	4	1D
0005435697169	16490	5	2C
0005435697178	16490	6	3B
0005435697174	16490	7	3C
0005435935007	16490	8	3D
0005435697185	16490	9	4A
0005435697176	16490	10	5A
0005435697159	16490	11	5B
0005435697179	16490	12	5C
0005435697162	16490	13	5D
0005435697180	16490	14	6A
0005435697181	16490	15	6B
0005435697167	16490	16	6C
0005435697165	16490	17	7A
0005435935005	16490	18	7C
0005435697175	16490	19	7D
0005435697171	16490	20	18A
0005435697186	16490	21	18B
0005435697164	16490	22	18C
0005435697172	16490	23	18D
0005435935003	16490	24	19D
0005435697182	16490	25	20A
0005435697177	16490	26	20B
0005435697173	16490	27	20C
0005435697184	16490	28	20D
0005435697163	16490	29	21D
0005435935004	16490	30	22A
0005435697170	16490	31	22C
0005435697166	16490	32	22D
0005435935016	16490	33	23A
0005435697183	16490	34	23B
0005435697026	24693	1	1B
0005435696910	24693	2	1C
0005435696961	24693	3	2A
0005435697038	24693	4	2B
0005435935029	24693	5	2C
0005435697025	24693	6	3A
0005435697031	24693	7	3C
0005435696931	24693	8	4A
0005435697032	24693	9	4C
0005435696936	24693	10	5B
0005435696937	24693	11	5D
0005435697003	24693	12	6A
0005435697024	24693	13	7A
0005435696867	24693	14	7B
0005435696930	24693	15	7D
0005435697014	24693	16	18A
0005435697128	24693	17	18C
0005435697037	24693	18	18D
0005435935028	24693	19	20A
0005435696946	24693	20	21A
0005435697013	24693	21	21B
0005435697004	24693	22	21D
0005435696888	24693	23	22B
0005435696960	24693	24	22C
0005435696868	24693	25	22D
0005435696945	24693	26	23A
0005433724781	18807	1	1A
0005433724779	18807	2	2A
0005432968806	18807	3	2B
0005433724780	18807	4	3A
0005433724777	18807	5	3B
0005433724778	18807	6	5A
0005433724728	21635	1	2A
0005433724735	21635	2	2B
0005433724743	21635	3	3A
0005432968830	21635	4	3B
0005433724732	21635	5	4B
0005433724729	21635	6	5A
0005432968831	21635	7	6B
0005434137742	7333	1	1A
0005434087487	7333	2	1C
0005434137768	7333	3	1D
0005434137753	7333	4	1F
0005434137780	7333	5	2A
0005434137749	7333	6	2D
0005434137725	7333	7	3A
0005434137774	7333	8	3C
0005434137709	7333	9	3D
0005434137737	7333	10	3F
0005434137712	7333	11	4C
0005434137734	7333	12	4A
0005434137755	7333	13	4E
0005434137724	7333	14	4F
0005434087488	7333	15	5A
0005434137746	7333	16	5C
0005434137782	7333	17	5D
0005434137751	7333	18	5E
0005434137722	7333	19	5F
0005434137777	7333	20	6A
0005434137764	7333	21	6C
0005434137769	7333	22	6D
0005434137760	7333	23	6E
0005434137754	7333	24	6F
0005434137747	7333	25	7C
0005434137759	7333	26	7E
0005434137766	7333	27	7F
0005434137741	7333	28	8A
0005434137708	7333	29	8C
0005434137727	7333	30	8D
0005434137783	7333	31	8E
0005434137778	7333	32	8F
0005434137779	7333	33	9C
0005434137731	7333	34	9D
0005434137762	7333	35	9E
0005434137717	7333	36	10A
0005434137781	7333	37	10D
0005434137732	7333	38	10E
0005434137770	7333	39	10F
0005434137744	7333	40	11A
0005434137740	7333	41	11E
0005434137757	7333	42	11F
0005434137773	7333	43	12A
0005434137763	7333	44	12C
0005434137743	7333	45	12D
0005434137730	7333	46	12E
0005434137710	7333	47	12F
0005434137750	7333	48	13D
0005434137748	7333	49	13E
0005434137745	7333	50	13F
0005434137721	7333	51	14A
0005434137729	7333	52	14C
0005434137758	7333	53	14D
0005434137715	7333	54	14E
0005434137720	7333	55	14F
0005434137765	7333	56	15A
0005434137733	7333	57	15C
0005434137756	7333	58	15D
0005434137776	7333	59	15F
0005434137714	7333	60	16A
0005434137767	7333	61	16C
0005434087489	7333	62	16D
0005434137728	7333	63	16F
0005434137771	7333	64	17A
0005434087490	7333	65	17C
0005434137772	7333	66	17D
0005434137761	7333	67	17E
0005434137739	7333	68	17F
0005434137784	7333	69	18A
0005434137716	7333	70	18C
0005434137719	7333	71	18D
0005434137735	7333	72	18E
0005434137752	7333	73	19A
0005434137723	7333	74	19C
0005434137738	7333	75	19D
0005434137718	7333	76	19F
0005434137726	7333	77	20A
0005434137775	7333	78	20C
0005434137713	7333	79	20D
0005434137711	7333	80	20E
0005434137736	7333	81	20F
0005434137006	28575	1	1A
0005434137095	28575	2	1C
0005434137027	28575	3	1D
0005434136837	28575	4	1F
0005434137051	28575	5	2C
0005434137080	28575	6	2D
0005434136941	28575	7	3C
0005434136931	28575	8	3D
0005434137443	28575	9	3F
0005434136845	28575	10	4A
0005434136754	28575	11	4C
0005434137310	28575	12	4D
0005434137094	28575	13	4E
0005434137127	28575	14	4F
0005434136889	28575	15	5A
0005434136980	28575	16	5C
0005434137253	28575	17	5E
0005434137131	28575	18	5F
0005434136826	28575	19	6A
0005434137087	28575	20	6C
0005434137232	28575	21	6D
0005434137332	28575	22	6E
0005434137331	28575	23	6F
0005434087465	28575	24	7A
0005434137075	28575	25	7D
0005434137028	28575	26	7E
0005434136891	28575	27	8A
0005434136976	28575	28	8C
0005434137176	28575	29	8D
0005434136787	28575	30	8E
0005434136979	28575	31	8F
0005434136978	28575	32	9A
0005434087466	28575	33	9C
0005434137242	28575	34	9D
0005434136838	28575	35	9E
0005434087453	28575	36	9F
0005434136968	28575	37	10A
0005434137086	28575	38	10C
0005434136946	28575	39	10D
0005434136818	28575	40	10E
0005434136936	28575	41	10F
0005434136874	28575	42	11D
0005434137153	28575	43	11E
0005434136765	28575	44	11F
0005434136764	28575	45	12A
0005434137140	28575	46	12C
0005434137098	28575	47	12D
0005434137071	28575	48	12F
0005434137165	28575	49	13C
0005434137007	28575	50	13D
0005434137113	28575	51	13E
0005434136682	28575	52	13F
0005434137052	28575	53	14A
0005434136937	28575	54	14C
0005434136977	28575	55	14D
0005434136932	28575	56	14E
0005434087452	28575	57	14F
0005434137128	28575	58	15A
0005434136935	28575	59	15C
0005434136988	28575	60	15D
0005434137241	28575	61	15E
0005434136814	28575	62	16A
0005434136689	28575	63	16C
0005434136725	28575	64	16D
0005434137074	28575	65	16E
0005434137079	28575	66	16F
0005434137122	28575	67	17A
0005434137025	28575	68	17C
0005434136783	28575	69	17D
0005434136813	28575	70	17E
0005434136947	28575	71	17F
0005434137012	28575	72	18A
0005434137193	28575	73	18D
0005434136766	28575	74	18E
0005434137044	28575	75	19A
0005434137081	28575	76	19C
0005434137082	28575	77	19D
0005434137254	28575	78	19E
0005434136956	28575	79	19F
0005434136940	28575	80	20A
0005434087432	28575	81	20D
0005434136724	28575	82	20E
0005434136825	28575	83	20F
0005433407487	1939	1	1A
0005435808182	1939	2	1B
0005435808179	1939	3	2A
0005435808187	1939	4	3D
0005435808177	1939	5	4A
0005433407488	1939	6	4C
0005435808184	1939	7	5A
0005435808185	1939	8	5B
0005435808183	1939	9	5D
0005435808178	1939	10	6C
0005435808181	1939	11	7B
0005435808186	1939	12	18B
0005434610211	1939	13	18C
0005434610212	1939	14	19B
0005435808180	1939	15	19C
0005434610209	1939	16	19D
0005433407486	1939	17	20C
0005434610210	1939	18	21B
0005433407481	1939	19	21C
0005433407494	1939	20	22B
0005434610167	23108	1	1A
0005433407533	23108	2	1D
0005433407536	23108	3	2B
0005433407537	23108	4	2C
0005435808053	23108	5	2D
0005433407532	23108	6	3D
0005433407530	23108	7	4B
0005434610182	23108	8	4C
0005435808072	23108	9	6B
0005435808057	23108	10	6C
0005434610166	23108	11	7A
0005433407531	23108	12	18B
0005433407538	23108	13	18D
0005435808071	23108	14	19A
0005435808063	23108	15	19C
0005435808115	23108	16	20D
0005435808056	23108	17	21A
0005433407534	23108	18	21C
0005433407535	23108	19	22B
0005434610168	23108	20	22C
0005434610183	23108	21	22D
0005434503489	16673	1	1D
0005434503603	16673	2	2A
0005434503624	16673	3	2C
0005434503551	16673	4	3A
0005434503586	16673	5	3B
0005434503577	16673	6	3C
0005434503562	16673	7	4A
0005434503557	16673	8	4C
0005434503473	16673	9	4D
0005434503466	16673	10	5A
0005434503491	16673	11	5B
0005434503587	16673	12	5D
0005434503580	16673	13	6A
0005434503506	16673	14	6B
0005434503797	16673	15	6C
0005434503523	16673	16	7A
0005434503539	16673	17	7B
0005434503581	16673	18	7C
0005434503684	16673	19	18A
0005434503527	16673	20	18B
0005434503556	16673	21	18D
0005434503505	16673	22	19B
0005434503509	16673	23	19D
0005434503579	16673	24	20A
0005434503490	16673	25	20B
0005434503653	16673	26	20C
0005434503522	16673	27	20D
0005434503578	16673	28	21A
0005434503630	16673	29	21C
0005434503531	16673	30	21D
0005434503504	16673	31	22A
0005434503593	16673	32	22B
0005434503524	16673	33	22C
0005434503652	16673	34	22D
0005434503465	16673	35	23B
0005434503904	22932	1	1A
0005434503934	22932	2	1B
0005434503912	22932	3	1C
0005434503925	22932	4	1D
0005434503930	22932	5	2A
0005434503905	22932	6	2B
0005434503917	22932	7	2D
0005434503911	22932	8	3B
0005434503903	22932	9	4C
0005434503919	22932	10	4D
0005434503932	22932	11	5A
0005434503924	22932	12	5B
0005434503908	22932	13	5D
0005434503909	22932	14	6A
0005434503906	22932	15	6B
0005434503902	22932	16	6C
0005434503937	22932	17	6D
0005434503916	22932	18	7B
0005434503929	22932	19	7C
0005434503914	22932	20	7D
0005434503922	22932	21	18A
0005434503938	22932	22	18B
0005434503923	22932	23	18C
0005434503936	22932	24	18D
0005434503933	22932	25	19A
0005434503926	22932	26	19B
0005434503931	22932	27	19D
0005434503901	22932	28	20A
0005434503920	22932	29	20C
0005434503935	22932	30	20D
0005434503921	22932	31	21A
0005434503910	22932	32	21B
0005434503915	22932	33	21C
0005434503907	22932	34	21D
0005434503927	22932	35	22A
0005434503928	22932	36	22B
0005434503918	22932	37	22C
0005434503939	22932	38	22D
0005434503913	22932	39	23A
0005435078268	2211	1	1C
0005433266601	2211	2	2A
0005433266622	2211	3	3A
0005433266574	2211	4	3B
0005435078256	2211	5	3C
0005435078267	2211	6	3D
0005435078261	2211	7	4D
0005435078260	2211	8	5B
0005435078263	2211	9	5C
0005435078264	2211	10	5D
0005433266589	2211	11	6A
0005435078262	2211	12	7C
0005435078259	2211	13	7D
0005435078269	2211	14	18C
0005435078265	2211	15	18D
0005435078258	2211	16	19A
0005435078270	2211	17	19D
0005435078266	2211	18	21A
0005433266592	2211	19	21C
0005433266623	2211	20	22B
0005435078255	2211	21	22C
0005435078257	2211	22	22D
0005435078271	2211	23	23B
0005433266673	24341	1	1A
0005435078153	24341	2	2C
0005435078140	24341	3	3A
0005433266677	24341	4	4A
0005435078139	24341	5	4C
0005433266680	24341	6	6A
0005435078119	24341	7	6B
0005435078173	24341	8	6C
0005433266678	24341	9	6D
0005435078149	24341	10	7D
0005435078124	24341	11	18C
0005435078080	24341	12	19B
0005433266679	24341	13	20A
0005435078141	24341	14	20B
0005433266675	24341	15	20D
0005435078098	24341	16	21A
0005435078148	24341	17	21B
0005435078152	24341	18	21C
0005433266674	24341	19	22B
0005435078099	24341	20	22C
0005433266676	24341	21	22D
0005434988681	6628	1	1A
0005435464480	6628	2	1B
0005434988687	6628	3	1C
0005435803249	6628	4	2A
0005434988682	6628	5	2B
0005434988688	6628	6	3B
0005435803250	6628	7	3D
0005434988679	6628	8	4C
0005434988683	6628	9	5B
0005434988680	6628	10	5C
0005434988678	6628	11	6A
0005435464483	6628	12	6D
0005435803251	6628	13	7A
0005435803248	6628	14	7D
0005434988686	6628	15	18C
0005435464481	6628	16	18D
0005435464487	6628	17	21A
0005434988689	6628	18	21B
0005434988684	6628	19	21C
0005435464488	6628	20	22D
0005434988685	6628	21	23A
0005434988566	23630	1	1C
0005435464496	23630	2	2A
0005434988556	23630	3	2B
0005435803220	23630	4	2D
0005434988572	23630	5	3C
0005435464497	23630	6	3D
0005435803224	23630	7	5A
0005434988563	23630	8	7B
0005434988559	23630	9	19A
0005435803225	23630	10	19B
0005435803221	23630	11	19D
0005435803223	23630	12	20B
0005435803228	23630	13	21B
0005434988569	23630	14	21C
0005434988562	23630	15	22C
0005434988565	23630	16	23B
0005432382981	30463	1	1A
0005432382984	30463	2	1F
0005433453753	30463	3	2A
0005432382977	30463	4	2C
0005432382992	30463	5	2F
0005432382969	30463	6	3C
0005432383012	30463	7	3D
0005432383002	30463	8	3F
0005432383005	30463	9	4A
0005433449854	30463	10	4D
0005432382994	30463	11	4E
0005432382971	30463	12	4F
0005432383009	30463	13	5A
0005433453754	30463	14	5C
0005433449863	30463	15	5D
0005433449870	30463	16	5F
0005432383007	30463	17	6A
0005432382985	30463	18	6D
0005433449853	30463	19	6E
0005433449858	30463	20	7C
0005432382983	30463	21	7D
0005433449859	30463	22	7E
0005432382976	30463	23	8C
0005433449856	30463	24	8E
0005432383004	30463	25	9A
0005432382986	30463	26	9D
0005433449852	30463	27	9E
0005432382979	30463	28	9F
0005432382988	30463	29	10C
0005433454864	30463	30	10D
0005432382990	30463	31	10E
0005432382980	30463	32	10F
0005433449860	30463	33	11A
0005433454866	30463	34	11C
0005433449851	30463	35	11E
0005433449864	30463	36	11F
0005433449866	30463	37	12D
0005432382972	30463	38	12E
0005432383006	30463	39	12F
0005433454865	30463	40	13A
0005433449855	30463	41	13C
0005432383008	30463	42	13D
0005432382982	30463	43	13E
0005432383003	30463	44	13F
0005432382998	30463	45	14C
0005432383010	30463	46	14D
0005432382999	30463	47	14E
0005432382991	30463	48	14F
0005433449862	30463	49	15A
0005433449872	30463	50	15C
0005433449867	30463	51	15E
0005432382997	30463	52	15F
0005432382993	30463	53	16A
0005432383001	30463	54	16D
0005433449857	30463	55	16E
0005433449871	30463	56	16F
0005432382973	30463	57	17C
0005432383000	30463	58	17D
0005432383011	30463	59	17E
0005432382996	30463	60	17F
0005432382975	30463	61	18A
0005432382989	30463	62	18E
0005432382978	30463	63	18F
0005432382974	30463	64	19A
0005432382995	30463	65	19C
0005433449868	30463	66	19D
0005433454863	30463	67	19E
0005433449865	30463	68	19F
0005433449869	30463	69	20A
0005433449861	30463	70	20C
0005432382970	30463	71	20D
0005432382987	30463	72	20E
0005432382570	31298	1	1C
0005432382564	31298	2	1F
0005432382692	31298	3	2A
0005433449732	31298	4	2C
0005433449654	31298	5	3C
0005432382610	31298	6	3F
0005433449731	31298	7	4D
0005432382678	31298	8	4F
0005433449624	31298	9	5A
0005432382802	31298	10	5D
0005432382617	31298	11	5E
0005433449671	31298	12	5F
0005433449608	31298	13	6A
0005433449630	31298	14	6C
0005433449676	31298	15	6D
0005433449656	31298	16	6E
0005432382633	31298	17	6F
0005432382803	31298	18	7F
0005433449674	31298	19	8D
0005432382706	31298	20	9A
0005432382516	31298	21	9D
0005433449745	31298	22	10E
0005433449631	31298	23	10F
0005432382693	31298	24	11C
0005433449658	31298	25	11E
0005433449746	31298	26	11F
0005433449625	31298	27	12A
0005432382622	31298	28	12E
0005433449626	31298	29	12F
0005433449641	31298	30	13F
0005432382609	31298	31	14D
0005433449655	31298	32	14F
0005432382499	31298	33	15C
0005432382707	31298	34	15E
0005433449677	31298	35	15F
0005432382575	31298	36	16A
0005433449638	31298	37	16C
0005433449734	31298	38	16D
0005432382571	31298	39	16F
0005432382515	31298	40	17A
0005432382494	31298	41	17F
0005433449640	31298	42	18C
0005433449809	31298	43	18D
0005433449675	31298	44	18F
0005432382493	31298	45	19A
0005433449735	31298	46	19D
0005432382592	31298	47	19E
0005433453732	31298	48	19F
0005433449680	31298	49	20E
0005432382607	31298	50	20F
0005433131656	10750	1	1C
0005433131631	10750	2	3B
0005433126780	10750	3	4A
0005435299696	10750	4	6B
0005433131655	10750	5	7A
0005435304108	10750	6	20C
0005435299703	10750	7	23B
0005433129258	29724	1	1C
0005435299756	29724	2	2B
0005435299754	29724	3	2C
0005435299755	29724	4	3B
0005435302181	29724	5	3D
0005433129254	29724	6	4B
0005433126826	29724	7	5A
0005433126827	29724	8	5C
0005435299758	29724	9	6A
0005433126823	29724	10	6C
0005435302179	29724	11	6D
0005433129255	29724	12	7B
0005433129259	29724	13	7C
0005433129256	29724	14	18A
0005435302184	29724	15	18B
0005433126824	29724	16	18C
0005433126825	29724	17	18D
0005433129257	29724	18	19B
0005435299757	29724	19	20C
0005435302180	29724	20	21A
0005433126828	29724	21	21B
0005435302182	29724	22	21D
0005435302183	29724	23	23B
0005433109926	2394	1	1B
0005432264462	2394	2	1C
0005433109840	2394	3	1D
0005434287183	2394	4	2B
0005434287179	2394	5	2C
0005434287181	2394	6	2D
0005433109911	2394	7	3B
0005434287186	2394	8	3D
0005434287185	2394	9	4A
0005434287178	2394	10	4B
0005434287182	2394	11	4C
0005434287173	2394	12	5D
0005433109917	2394	13	6A
0005433109920	2394	14	6C
0005433109891	2394	15	6B
0005434287177	2394	16	7B
0005434287169	2394	17	7C
0005434287180	2394	18	7D
0005432264463	2394	19	18A
0005434287187	2394	20	18B
0005434287165	2394	21	18C
0005434287174	2394	22	18D
0005434287166	2394	23	19A
0005434287172	2394	24	19B
0005434287176	2394	25	19C
0005434287170	2394	26	19D
0005433109918	2394	27	20A
0005434287175	2394	28	20B
0005433109905	2394	29	20D
0005434287171	2394	30	21A
0005433109916	2394	31	21B
0005434287184	2394	32	21C
0005434287167	2394	33	21D
0005433109928	2394	34	22A
0005433109855	2394	35	22C
0005433109910	2394	36	22D
0005433109841	2394	37	23A
0005434287168	2394	38	23B
0005433109988	26825	1	1A
0005434286981	26825	2	1B
0005434286920	26825	3	1C
0005433109993	26825	4	1D
0005434287070	26825	5	2A
0005434286982	26825	6	2D
0005434287069	26825	7	3B
0005434286941	26825	8	3C
0005434286990	26825	9	3D
0005434286975	26825	10	4A
0005434286942	26825	11	4B
0005433109991	26825	12	4D
0005433109987	26825	13	5A
0005434286959	26825	14	5B
0005434286939	26825	15	5C
0005433109989	26825	16	5D
0005433109990	26825	17	6A
0005433109994	26825	18	6B
0005433109992	26825	19	6C
0005434287003	26825	20	7A
0005433109996	26825	21	7B
0005434286996	26825	22	7C
0005434286894	26825	23	7D
0005434287034	26825	24	18A
0005434286967	26825	25	18C
0005434286918	26825	26	19A
0005434286966	26825	27	19B
0005434287027	26825	28	19C
0005433109986	26825	29	20A
0005433109997	26825	30	20C
0005434287035	26825	31	21C
0005434286935	26825	32	21D
0005434286962	26825	33	22A
0005434286895	26825	34	22B
0005434286961	26825	35	22C
0005434287036	26825	36	22D
0005434286906	26825	37	23A
0005433109995	26825	38	23B
0005435856182	25483	1	1D
0005435856181	25483	2	2C
0005434269078	25483	3	2D
0005434272168	25483	4	4A
0005434269079	25483	5	5A
0005435856184	25483	6	5B
0005434269067	25483	7	5C
0005434269068	25483	8	20A
0005435856183	25483	9	21A
0005434269069	25483	10	21B
0005434272161	25483	11	23A
0005434272183	26632	1	1B
0005435856136	26632	2	1C
0005434272185	26632	3	2D
0005435856142	26632	4	3C
0005435856137	26632	5	3D
0005434272186	26632	6	4B
0005434273070	26632	7	4D
0005435856130	26632	8	6A
0005434273069	26632	9	7A
0005435856131	26632	10	18A
0005434272184	26632	11	18C
0005435263531	7152	1	1A
0005433650567	7152	2	1D
0005435263500	7152	3	1F
0005435263499	7152	4	2C
0005435263501	7152	5	2D
0005433650541	7152	6	2F
0005433650572	7152	7	3C
0005433650569	7152	8	3D
0005433650542	7152	9	3F
0005433650536	7152	10	4E
0005433650560	7152	11	4F
0005433650566	7152	12	5A
0005433650565	7152	13	5C
0005433650571	7152	14	5D
0005435263507	7152	15	5E
0005433650535	7152	16	5F
0005433650544	7152	17	6A
0005433650528	7152	18	6D
0005433650543	7152	19	6E
0005433650550	7152	20	6F
0005433650575	7152	21	7A
0005433650534	7152	22	7C
0005433650548	7152	23	7D
0005435263513	7152	24	7E
0005433650530	7152	25	8A
0005433650570	7152	26	8C
0005433650549	7152	27	8D
0005433650558	7152	28	8E
0005433650545	7152	29	8F
0005433650533	7152	30	9C
0005433650557	7152	31	9D
0005433650538	7152	32	9E
0005433650574	7152	33	9F
0005433650546	7152	34	10D
0005433650552	7152	35	10E
0005435263534	7152	36	11A
0005433650553	7152	37	11C
0005435263516	7152	38	11D
0005435263492	7152	39	11E
0005433650568	7152	40	11F
0005433650551	7152	41	12A
0005435263504	7152	42	12C
0005433650554	7152	43	12D
0005435263496	7152	44	12F
0005433650563	7152	45	13C
0005433650527	7152	46	13D
0005435263495	7152	47	13F
0005435263483	7152	48	14A
0005433650564	7152	49	14C
0005433650562	7152	50	14D
0005435263530	7152	51	14E
0005433650561	7152	52	15A
0005435263528	7152	53	15C
0005433650556	7152	54	15E
0005433650547	7152	55	15F
0005435263527	7152	56	16D
0005435263517	7152	57	16E
0005433650555	7152	58	17C
0005433650529	7152	59	17D
0005435263503	7152	60	17E
0005433650532	7152	61	18C
0005435263529	7152	62	18E
0005433650559	7152	63	19C
0005433650573	7152	64	19D
0005433650540	7152	65	19F
0005433650531	7152	66	20A
0005435263502	7152	67	20C
0005433650539	7152	68	20D
0005435263514	7152	69	20E
0005433650537	7152	70	20F
0005433868225	4814	1	1A
0005433868227	4814	2	1B
0005433868243	4814	3	1C
0005433868255	4814	4	1D
0005433868244	4814	5	2A
0005433868259	4814	6	2B
0005433868229	4814	7	3A
0005433868249	4814	8	3B
0005433868250	4814	9	3C
0005433868233	4814	10	3D
0005433868231	4814	11	4A
0005435860440	4814	12	4B
0005433868256	4814	13	4C
0005433868239	4814	14	4D
0005433868226	4814	15	5A
0005433868241	4814	16	5B
0005433868253	4814	17	5C
0005433868242	4814	18	5D
0005433868240	4814	19	6A
0005433868223	4814	20	6B
0005433868245	4814	21	6C
0005433868222	4814	22	6D
0005433868236	4814	23	7A
0005433868257	4814	24	7B
0005433868258	4814	25	7C
0005433868246	4814	26	7D
0005433868237	4814	27	18A
0005433868261	4814	28	18B
0005433868254	4814	29	18C
0005433868221	4814	30	18D
0005433868260	4814	31	19A
0005435860441	4814	32	19B
0005433868238	4814	33	19C
0005435860438	4814	34	19D
0005433868232	4814	35	20A
0005433868224	4814	36	20B
0005433868252	4814	37	20D
0005433868235	4814	38	21B
0005433868251	4814	39	21C
0005433868228	4814	40	21D
0005433868234	4814	41	22A
0005433868247	4814	42	22C
0005433868262	4814	43	22D
0005433868230	4814	44	23A
0005433868248	4814	45	23B
0005433867860	32615	1	1B
0005433867940	32615	2	1C
0005433867969	32615	3	1D
0005433867852	32615	4	2B
0005435860474	32615	5	2C
0005433867845	32615	6	2D
0005433867805	32615	7	3A
0005433867965	32615	8	3B
0005433867871	32615	9	3C
0005433867967	32615	10	3D
0005433867811	32615	11	4A
0005435860469	32615	12	4B
0005433867770	32615	13	4C
0005435860471	32615	14	4D
0005433867876	32615	15	5A
0005433867922	32615	16	5B
0005435860468	32615	17	5C
0005433867880	32615	18	5D
0005433867828	32615	19	6A
0005433867964	32615	20	6B
0005433867932	32615	21	6D
0005435860473	32615	22	7A
0005433867782	32615	23	7B
0005433867781	32615	24	7C
0005433867740	32615	25	7D
0005433867934	32615	26	18A
0005433867926	32615	27	18D
0005433867884	32615	28	19A
0005435860472	32615	29	19B
0005433867925	32615	30	20A
0005433867909	32615	31	20C
0005433867974	32615	32	20D
0005433867812	32615	33	21A
0005433867821	32615	34	21B
0005433867923	32615	35	21D
0005433867939	32615	36	22A
0005433867899	32615	37	22B
0005433867844	32615	38	22D
0005433867975	32615	39	22C
0005435860470	32615	40	23A
0005434663341	3421	1	1D
0005435911357	3421	2	3A
0005434461637	3421	3	3B
0005434663338	3421	4	4A
0005434663340	3421	5	4B
0005434663336	3421	6	5A
0005434663346	3421	7	5B
0005435911342	3421	8	5C
0005434461635	3421	9	6A
0005434460495	3421	10	6C
0005435911344	3421	11	6D
0005435911333	3421	12	7B
0005434663345	3421	13	7D
0005434663333	3421	14	19B
0005434663335	3421	15	19D
0005435911343	3421	16	20A
0005434663339	3421	17	20B
0005434663343	3421	18	20C
0005434663344	3421	19	20D
0005434460496	3421	20	21A
0005434663342	3421	21	21B
0005434663334	3421	22	21D
0005434663337	3421	23	23A
0005434461636	3421	24	23B
0005434663208	12486	1	1A
0005434663229	12486	2	2B
0005435911417	12486	3	2D
0005435911412	12486	4	3B
0005434663184	12486	5	3C
0005434663183	12486	6	4B
0005435911418	12486	7	4C
0005434663247	12486	8	4D
0005434663280	12486	9	5B
0005435911415	12486	10	5C
0005435911411	12486	11	6A
0005434663227	12486	12	7C
0005435911413	12486	13	18B
0005435911414	12486	14	18C
0005435911410	12486	15	18D
0005434663230	12486	16	20A
0005435911416	12486	17	20D
0005434663212	12486	18	22C
0005433867812	14504	1	1A
0005433867770	14504	2	1B
0005433867781	14504	3	1C
0005433867845	14504	4	1D
0005433867782	14504	5	2B
0005433867964	14504	6	2C
0005433867880	14504	7	2D
0005433867965	14504	8	3A
0005433867909	14504	9	3B
0005433867871	14504	10	3C
0005433867899	14504	11	3D
0005433867923	14504	12	4A
0005433867821	14504	13	4B
0005435860471	14504	14	4C
0005433867975	14504	15	4D
0005433867940	14504	16	5A
0005435860468	14504	17	5B
0005433867811	14504	18	5C
0005433867805	14504	19	5D
0005433867740	14504	20	6A
0005433867967	14504	21	7A
0005435860474	14504	22	7C
0005433867926	14504	23	7D
0005435860470	14504	24	18A
0005433867932	14504	25	18C
0005433867876	14504	26	19A
0005435860473	14504	27	19B
0005433867939	14504	28	19D
0005433867969	14504	29	20A
0005433867934	14504	30	20B
0005435860469	14504	31	20C
0005433867828	14504	32	21A
0005433867925	14504	33	21B
0005433867844	14504	34	21C
0005433867852	14504	35	21D
0005433867922	14504	36	22A
0005435860472	14504	37	22B
0005433867974	14504	38	22C
0005433867884	14504	39	23A
0005433867860	14504	40	23B
0005433868181	32694	1	1B
0005433868180	32694	2	1C
0005433868210	32694	3	1D
0005433868194	32694	4	2A
0005433868186	32694	5	2B
0005433868196	32694	6	2C
0005433868189	32694	7	2D
0005433868205	32694	8	3B
0005433868191	32694	9	3D
0005433868209	32694	10	4A
0005433868200	32694	11	4B
0005433868215	32694	12	4C
0005433868213	32694	13	5A
0005433868185	32694	14	5B
0005433868220	32694	15	5C
0005433868211	32694	16	5D
0005433868184	32694	17	6A
0005433868179	32694	18	6B
0005433868206	32694	19	6C
0005433868208	32694	20	6D
0005435860432	32694	21	7A
0005433868192	32694	22	7B
0005433868207	32694	23	7C
0005433868198	32694	24	7D
0005433868204	32694	25	18A
0005433868187	32694	26	18B
0005433868193	32694	27	18C
0005433868216	32694	28	18D
0005433868182	32694	29	19A
0005433868195	32694	30	19B
0005433868197	32694	31	19C
0005433868203	32694	32	20A
0005433868214	32694	33	20B
0005433868183	32694	34	20C
0005433868202	32694	35	20D
0005433868188	32694	36	21A
0005433868212	32694	37	21B
0005435860433	32694	38	21C
0005433868218	32694	39	21D
0005433868217	32694	40	22A
0005433868201	32694	41	22B
0005433868199	32694	42	22C
0005433868219	32694	43	22D
0005433868190	32694	44	23A
0005432799050	12151	1	1A
0005432799004	12151	2	1B
0005432799075	12151	3	1C
0005432799082	12151	4	1D
0005432799126	12151	5	2B
0005432799197	12151	6	3A
0005432799148	12151	7	3C
0005432799154	12151	8	3D
0005432799083	12151	9	4B
0005432799051	12151	10	4D
0005432798972	12151	11	5A
0005432799129	12151	12	5B
0005432799063	12151	13	5C
0005432799149	12151	14	6A
0005432799110	12151	15	6B
0005432798973	12151	16	6C
0005432798975	12151	17	6D
0005432798979	12151	18	7A
0005432799128	12151	19	7C
0005432798997	12151	20	18A
0005432799101	12151	21	18B
0005432798974	12151	22	18D
0005432799091	12151	23	19C
0005432799011	12151	24	20B
0005432799150	12151	25	20D
0005432799153	12151	26	21B
0005432799127	12151	27	21C
0005432799111	12151	28	21D
0005432799074	12151	29	22A
0005432799052	12151	30	22C
0005432798998	12151	31	23A
0005432799042	12151	32	23B
0005432799287	14825	1	1A
0005432799292	14825	2	1D
0005432799297	14825	3	2B
0005432799293	14825	4	2C
0005432799275	14825	5	2D
0005432799283	14825	6	3A
0005432799285	14825	7	3B
0005432799286	14825	8	3C
0005432799290	14825	9	3D
0005432799274	14825	10	4A
0005432799288	14825	11	4B
0005432799282	14825	12	4D
0005432799295	14825	13	5A
0005432799298	14825	14	6C
0005432799284	14825	15	7B
0005432799279	14825	16	7C
0005432799289	14825	17	18A
0005432799294	14825	18	18B
0005432799301	14825	19	18D
0005432799272	14825	20	19A
0005432799273	14825	21	19B
0005432799271	14825	22	19C
0005432799280	14825	23	20A
0005432799296	14825	24	20D
0005432799300	14825	25	21B
0005432799299	14825	26	21C
0005432799276	14825	27	21D
0005432799277	14825	28	22A
0005432799278	14825	29	22B
0005432799291	14825	30	22C
0005432799281	14825	31	23B
0005434407432	7042	1	1A
0005435310863	7042	2	1D
0005434407435	7042	3	2A
0005434407422	7042	4	1F
0005434407476	7042	5	2C
0005434299433	7042	6	2D
0005434407416	7042	7	2F
0005435310889	7042	8	3A
0005435310849	7042	9	3C
0005434299434	7042	10	3F
0005434407436	7042	11	4A
0005432153901	7042	12	4C
0005434299447	7042	13	4B
0005434407473	7042	14	4D
0005434299451	7042	15	4E
0005434407447	7042	16	5A
0005434407440	7042	17	4F
0005434407469	7042	18	5B
0005434299445	7042	19	5D
0005434407429	7042	20	5C
0005435310885	7042	21	5E
0005434407431	7042	22	6A
0005434407450	7042	23	5F
0005434407471	7042	24	6B
0005435293115	7042	25	6D
0005434299440	7042	26	6E
0005434299432	7042	27	7A
0005435293095	7042	28	7B
0005434299441	7042	29	7E
0005434299453	7042	30	7D
0005434407437	7042	31	7F
0005434407442	7042	32	8A
0005432108237	7042	33	8B
0005435310847	7042	34	8D
0005434407458	7042	35	8C
0005434299448	7042	36	8E
0005434407433	7042	37	9A
0005434407424	7042	38	8F
0005434407460	7042	39	9B
0005434407472	7042	40	9D
0005432153904	7042	41	9C
0005435310884	7042	42	9E
0005434299439	7042	43	9F
0005434299452	7042	44	10B
0005434407456	7042	45	10C
0005434407475	7042	46	10D
0005434407451	7042	47	11A
0005434407452	7042	48	10E
0005434299442	7042	49	11C
0005435293098	7042	50	11B
0005434407443	7042	51	11D
0005434299455	7042	52	11F
0005434407468	7042	53	11E
0005435310869	7042	54	12A
0005434407434	7042	55	12B
0005434407454	7042	56	12C
0005434407455	7042	57	12E
0005434299443	7042	58	12D
0005434407427	7042	59	12F
0005434407441	7042	60	13C
0005434407445	7042	61	13B
0005434407449	7042	62	13D
0005434299444	7042	63	13E
0005432153899	7042	64	13F
0005434407439	7042	65	14B
0005432153902	7042	66	14A
0005434407463	7042	67	14C
0005435310862	7042	68	14D
0005434407446	7042	69	15A
0005434407457	7042	70	14F
0005434299454	7042	71	15C
0005434407461	7042	72	15D
0005434407421	7042	73	15F
0005434407425	7042	74	15E
0005434407474	7042	75	16A
0005435293080	7042	76	16B
0005434407464	7042	77	16C
0005434407467	7042	78	16E
0005434407462	7042	79	16F
0005434407466	7042	80	17A
0005434299438	7042	81	17B
0005434299436	7042	82	17C
0005435293084	7042	83	17E
0005434407430	7042	84	17D
0005434407448	7042	85	18A
0005434407459	7042	86	18B
0005434407419	7042	87	18C
0005434299435	7042	88	18D
0005434299437	7042	89	18F
0005434407423	7042	90	18E
0005434407470	7042	91	19A
0005434299446	7042	92	19C
0005435293097	7042	93	19B
0005434407413	7042	94	19D
0005434407418	7042	95	19F
0005435293116	7042	96	19E
0005434407426	7042	97	20A
0005434407414	7042	98	20B
0005432153905	7042	99	20D
0005435293103	7042	100	20C
0005434299449	7042	101	20E
0005434407415	7042	102	20F
0005432153900	7042	103	21A
0005434407465	7042	104	21B
0005434407444	7042	105	21D
0005434407417	7042	106	21C
0005435293083	7042	107	21E
0005432108238	7042	108	21F
0005434407453	7042	109	22B
0005435310894	7042	110	22A
0005435293079	7042	111	22C
0005435310837	7042	112	22F
0005432153903	7042	113	23A
0005434299450	7042	114	23B
0005434407428	7042	115	23C
0005434407420	7042	116	23D
0005435310848	7042	117	23F
0005434407438	7042	118	23E
0005434299159	26903	1	1A
0005434299305	26903	2	1C
0005435293190	26903	3	1D
0005434406953	26903	4	1F
0005435311012	26903	5	2D
0005434407017	26903	6	3A
0005434406818	26903	7	3C
0005434299266	26903	8	3D
0005434406820	26903	9	3F
0005434299208	26903	10	4B
0005435293188	26903	11	4C
0005435311007	26903	12	4F
0005435311002	26903	13	5B
0005434299195	26903	14	5A
0005434406931	26903	15	5C
0005434406982	26903	16	5D
0005432058359	26903	17	5E
0005434406851	26903	18	6A
0005434406848	26903	19	5F
0005434406833	26903	20	6C
0005434406706	26903	21	6B
0005434406767	26903	22	6E
0005434299363	26903	23	6D
0005434407078	26903	24	7A
0005434299194	26903	25	6F
0005435311009	26903	26	7C
0005434406806	26903	27	7B
0005435311000	26903	28	7E
0005435293189	26903	29	7D
0005435293183	26903	30	7F
0005434299293	26903	31	8B
0005435293193	26903	32	8A
0005435310998	26903	33	8C
0005434406971	26903	34	8F
0005434406768	26903	35	8E
0005434406785	26903	36	9A
0005432058358	26903	37	9B
0005434406749	26903	38	9D
0005434406803	26903	39	9C
0005434406817	26903	40	9E
0005435311010	26903	41	10B
0005434299246	26903	42	10D
0005432058357	26903	43	10C
0005434406889	26903	44	11A
0005434406787	26903	45	10E
0005434406651	26903	46	11B
0005434407057	26903	47	11C
0005434406756	26903	48	11E
0005435310999	26903	49	11F
0005434406954	26903	50	12A
0005435311014	26903	51	12B
0005435311005	26903	52	12D
0005434406935	26903	53	12F
0005434299301	26903	54	13B
0005434406930	26903	55	13A
0005434407040	26903	56	13C
0005434406766	26903	57	13E
0005434299300	26903	58	14A
0005434406816	26903	59	14B
0005434406804	26903	60	14D
0005434406755	26903	61	15A
0005435311011	26903	62	14F
0005435293191	26903	63	15C
0005435293194	26903	64	15B
0005434406642	26903	65	15D
0005434406869	26903	66	15F
0005434299245	26903	67	16B
0005435311013	26903	68	16A
0005434406802	26903	69	16C
0005435310997	26903	70	16D
0005434299172	26903	71	16E
0005435293182	26903	72	17B
0005434406948	26903	73	17D
0005434406737	26903	74	17F
0005434406782	26903	75	17E
0005434406868	26903	76	18A
0005434406949	26903	77	18B
0005434299265	26903	78	18C
0005435311008	26903	79	18E
0005435311001	26903	80	18F
0005434406819	26903	81	19A
0005435311003	26903	82	19B
0005435293192	26903	83	19D
0005434406805	26903	84	19C
0005434406932	26903	85	19E
0005434406852	26903	86	20A
0005434406866	26903	87	20C
0005435293187	26903	88	20E
0005434406877	26903	89	20F
0005434407047	26903	90	21A
0005434406685	26903	91	21B
0005435311006	26903	92	21D
0005435293185	26903	93	21C
0005434406757	26903	94	21E
0005434299259	26903	95	22A
0005434406764	26903	96	21F
0005434407067	26903	97	22B
0005435293186	26903	98	22C
0005434299294	26903	99	22D
0005434299329	26903	100	22E
0005435293184	26903	101	23A
0005434407018	26903	102	22F
0005434299302	26903	103	23C
0005435311004	26903	104	23D
0005435310996	26903	105	23F
0005434407066	26903	106	23E
0005432604165	6477	1	1A
0005432604155	6477	2	1B
0005432604139	6477	3	1D
0005434512093	6477	4	2A
0005432604146	6477	5	2B
0005432604130	6477	6	2C
0005432604135	6477	7	2D
0005432604153	6477	8	3A
0005434512091	6477	9	3B
0005432604156	6477	10	3C
0005432604148	6477	11	3D
0005432604137	6477	12	4A
0005432604168	6477	13	4B
0005432604151	6477	14	4C
0005432604167	6477	15	4D
0005432604154	6477	16	5A
0005432604149	6477	17	5B
0005432604145	6477	18	5C
0005432604132	6477	19	5D
0005434512092	6477	20	6A
0005432604150	6477	21	6B
0005432604152	6477	22	6C
0005432604128	6477	23	6D
0005432604160	6477	24	7A
0005432604159	6477	25	7B
0005432604138	6477	26	7C
0005432604147	6477	27	7D
0005432604163	6477	28	18A
0005432604143	6477	29	18B
0005432604161	6477	30	18C
0005432604158	6477	31	18D
0005432604142	6477	32	19A
0005432604166	6477	33	19B
0005432604141	6477	34	19C
0005432604129	6477	35	19D
0005434512090	6477	36	20A
0005432604134	6477	37	20B
0005432604133	6477	38	20C
0005432604131	6477	39	20D
0005432604162	6477	40	21C
0005432604164	6477	41	21B
0005432604157	6477	42	21D
0005435218100	6477	43	22A
0005432604140	6477	44	22B
0005432604136	6477	45	22D
0005432604144	6477	46	23B
0005435221513	21382	1	1C
0005432603939	21382	2	2A
0005432603890	21382	3	2B
0005435221050	21382	4	2C
0005432603728	21382	5	2D
0005432603767	21382	6	3B
0005432603717	21382	7	3C
0005434512027	21382	8	4A
0005432603889	21382	9	4B
0005432603664	21382	10	4C
0005432603732	21382	11	5A
0005435221512	21382	12	5B
0005432603912	21382	13	5C
0005434512063	21382	14	5D
0005432603752	21382	15	6A
0005432603789	21382	16	6B
0005432603891	21382	17	6C
0005432603841	21382	18	7A
0005432603733	21382	19	7B
0005432603686	21382	20	7D
0005435221051	21382	21	18A
0005432603721	21382	22	18D
0005432603731	21382	23	19B
0005432603716	21382	24	19C
0005432603774	21382	25	19D
0005432603781	21382	26	20A
0005432603722	21382	27	20C
0005432603646	21382	28	20D
0005432603718	21382	29	21B
0005432603773	21382	30	21C
0005432603817	21382	31	22A
0005432603818	21382	32	22B
0005435221511	21382	33	22C
0005432603911	21382	34	22D
0005434512074	21382	35	23A
0005434512034	21382	36	23B
0005434906468	14996	1	1C
0005434906529	14996	2	1D
0005433251323	14996	3	1F
0005434906365	14996	4	2A
0005434906451	14996	5	2C
0005434906503	14996	6	2F
0005433251331	14996	7	3A
0005433251307	14996	8	3C
0005433251337	14996	9	3D
0005433251327	14996	10	3F
0005434906604	14996	11	4A
0005433251329	14996	12	4C
0005434906372	14996	13	4E
0005434906614	14996	14	4F
0005434906540	14996	15	5A
0005433251328	14996	16	5D
0005433251334	14996	17	5E
0005433251315	14996	18	5F
0005434906666	14996	19	6C
0005434906554	14996	20	6E
0005433251311	14996	21	6F
0005434906509	14996	22	7A
0005433251330	14996	23	7E
0005434906371	14996	24	8F
0005433251321	14996	25	9A
0005433251314	14996	26	9C
0005434906606	14996	27	9D
0005434906469	14996	28	9E
0005433251322	14996	29	9F
0005433251313	14996	30	10C
0005434906465	14996	31	10D
0005434906797	14996	32	10E
0005434906439	14996	33	10F
0005434906563	14996	34	11C
0005433251312	14996	35	11D
0005433251332	14996	36	11E
0005433251326	14996	37	11F
0005433251308	14996	38	12A
0005434906472	14996	39	12C
0005433251333	14996	40	12D
0005433251310	14996	41	12F
0005434906510	14996	42	13A
0005433251319	14996	43	13C
0005434906377	14996	44	13E
0005433251309	14996	45	13F
0005434906784	14996	46	14E
0005434906384	14996	47	14F
0005434906440	14996	48	15A
0005434906592	14996	49	15C
0005434906467	14996	50	15D
0005434906833	14996	51	15E
0005433251324	14996	52	15F
0005433251317	14996	53	16A
0005433251335	14996	54	16E
0005433251336	14996	55	16F
0005433251325	14996	56	17C
0005433251320	14996	57	17E
0005434906450	14996	58	17F
0005434906783	14996	59	18A
0005434906382	14996	60	18C
0005434906383	14996	61	18D
0005434906491	14996	62	18F
0005434906612	14996	63	19A
0005433251316	14996	64	19C
0005434906396	14996	65	19D
0005433251306	14996	66	19E
0005434906466	14996	67	19F
0005434906471	14996	68	20A
0005433251318	14996	69	20E
0005434906995	25839	1	1A
0005434906996	25839	2	1C
0005434906972	25839	3	1D
0005433251215	25839	4	2A
0005434906997	25839	5	2C
0005434907005	25839	6	2D
0005434907001	25839	7	2F
0005433251075	25839	8	3A
0005434906967	25839	9	3C
0005434907000	25839	10	3D
0005434906971	25839	11	3F
0005433251054	25839	12	4A
0005433251021	25839	13	4C
0005433251160	25839	14	4D
0005434906983	25839	15	4E
0005434906986	25839	16	4F
0005434907009	25839	17	5A
0005434906973	25839	18	5C
0005433250998	25839	19	5D
0005433251062	25839	20	5E
0005434906978	25839	21	5F
0005434906969	25839	22	6A
0005434906994	25839	23	6C
0005434906961	25839	24	6D
0005434906955	25839	25	6E
0005433250990	25839	26	6F
0005433251250	25839	27	7A
0005434907002	25839	28	7C
0005433251051	25839	29	7D
0005433250978	25839	30	7F
0005434906954	25839	31	8C
0005434906993	25839	32	8D
0005434907010	25839	33	8E
0005434906977	25839	34	8F
0005434906989	25839	35	9A
0005433251044	25839	36	9C
0005433251020	25839	37	9D
0005434906988	25839	38	9E
0005433251007	25839	39	9F
0005433250976	25839	40	10A
0005434907004	25839	41	10C
0005433251130	25839	42	10E
0005434906991	25839	43	10D
0005433250977	25839	44	10F
0005433251238	25839	45	11A
0005433251039	25839	46	11C
0005434906970	25839	47	11D
0005434906980	25839	48	11E
0005434906968	25839	49	11F
0005434906962	25839	50	12A
0005433251076	25839	51	12C
0005433251000	25839	52	12D
0005434906982	25839	53	12E
0005433251045	25839	54	12F
0005434906981	25839	55	13A
0005434906960	25839	56	13C
0005433251008	25839	57	13D
0005434906958	25839	58	13E
0005433250991	25839	59	13F
0005434906974	25839	60	14C
0005434907008	25839	61	14D
0005434906964	25839	62	14E
0005434906992	25839	63	14F
0005434906984	25839	64	15A
0005434906975	25839	65	15C
0005433251072	25839	66	15D
0005433251158	25839	67	15E
0005433251050	25839	68	15F
0005434907006	25839	69	16A
0005434906959	25839	70	16C
0005434906965	25839	71	16D
0005434906979	25839	72	16E
0005434906951	25839	73	16F
0005434907007	25839	74	17A
0005433251001	25839	75	17C
0005433250944	25839	76	17D
0005434906990	25839	77	17E
0005434906963	25839	78	17F
0005433251129	25839	79	18A
0005434906976	25839	80	18C
0005434906987	25839	81	18D
0005433251014	25839	82	18E
0005434906953	25839	83	18F
0005434906966	25839	84	19A
0005434906985	25839	85	19C
0005434906957	25839	86	19D
0005434906952	25839	87	19F
0005434906956	25839	88	20A
0005434906999	25839	89	20C
0005433250999	25839	90	20D
0005434907003	25839	91	20E
0005434906998	25839	92	20F
0005433008412	14156	1	1A
0005433008408	14156	2	1C
0005433008388	14156	3	1D
0005433008391	14156	4	1F
0005433008406	14156	5	2A
0005433008402	14156	6	2C
0005433008418	14156	7	2F
0005433008379	14156	8	3D
0005433008404	14156	9	3F
0005433008416	14156	10	4C
0005433008422	14156	11	4D
0005433810490	14156	12	4E
0005433008383	14156	13	5D
0005433008385	14156	14	5F
0005433008410	14156	15	6D
0005433008424	14156	16	6E
0005433008423	14156	17	7F
0005433008396	14156	18	8A
0005433008400	14156	19	8C
0005433008405	14156	20	8D
0005433008411	14156	21	9A
0005433008380	14156	22	9C
0005433008415	14156	23	9D
0005433008407	14156	24	9E
0005433008384	14156	25	10C
0005433008419	14156	26	11A
0005433008401	14156	27	11E
0005433008413	14156	28	11F
0005433008421	14156	29	12C
0005433008393	14156	30	12E
0005433008390	14156	31	13A
0005433008409	14156	32	13D
0005433008382	14156	33	14D
0005433008420	14156	34	14E
0005433008387	14156	35	15A
0005433008381	14156	36	16C
0005433008414	14156	37	16E
0005433008395	14156	38	16F
0005433008417	14156	39	17A
0005433008397	14156	40	17C
0005433008389	14156	41	18D
0005433008399	14156	42	18F
0005433008403	14156	43	19A
0005433008398	14156	44	19F
0005433008386	14156	45	20C
0005433008392	14156	46	20D
0005433008394	14156	47	20F
0005433007953	22820	1	1A
0005433007970	22820	2	1D
0005433007972	22820	3	2A
0005433008085	22820	4	2C
0005433007930	22820	5	2D
0005433007917	22820	6	2F
0005433008027	22820	7	4D
0005433007971	22820	8	4E
0005433810519	22820	9	5F
0005433007969	22820	10	7E
0005433007931	22820	11	8A
0005433008028	22820	12	8C
0005433007980	22820	13	8D
0005433008073	22820	14	8E
0005433007979	22820	15	8F
0005433008212	22820	16	10F
0005433008109	22820	17	11A
0005433007925	22820	18	11C
0005433008063	22820	19	11F
0005433008116	22820	20	12A
0005433008016	22820	21	12F
0005433007879	22820	22	13D
0005433007893	22820	23	13E
0005433810518	22820	24	14E
0005433007923	22820	25	15A
0005433008017	22820	26	15E
0005433007943	22820	27	16A
0005433007958	22820	28	16D
0005433007890	22820	29	16F
0005433008038	22820	30	18A
0005433007924	22820	31	17F
0005433007944	22820	32	18C
0005433007959	22820	33	18D
0005433008121	22820	34	18E
0005433007973	22820	35	19A
0005433810520	22820	36	19D
0005433008074	22820	37	19E
0005433007878	22820	38	19F
0005433007841	22820	39	20C
0005434925416	14951	1	1F
0005434925378	14951	2	2C
0005434925465	14951	3	2D
0005434925275	14951	4	2F
0005434925326	14951	5	3C
0005434925490	14951	6	4F
0005434925503	14951	7	5C
0005434925427	14951	8	5E
0005434925285	14951	9	5F
0005434925332	14951	10	6D
0005434925274	14951	11	7C
0005434925390	14951	12	7F
0005434925382	14951	13	8A
0005434925379	14951	14	8C
0005434925339	14951	15	8D
0005434925325	14951	16	9E
0005434925522	14951	17	9F
0005434925296	14951	18	10A
0005434925286	14951	19	10D
0005434925439	14951	20	11C
0005434925280	14951	21	12C
0005434925377	14951	22	13A
0005434925491	14951	23	13E
0005434925347	14951	24	14D
0005434925283	14951	25	15C
0005434925380	14951	26	15D
0005434925489	14951	27	15E
0005434925385	14951	28	16F
0005434925426	14951	29	17D
0005434925362	14951	30	17F
0005434925349	14951	31	18A
0005434925337	14951	32	19F
0005434925338	14951	33	20C
0005434925470	14951	34	20D
0005434925389	14951	35	20E
0005434925348	14951	36	20F
0005434925643	20530	1	1A
0005434925637	20530	2	1F
0005434925642	20530	3	2A
0005434925626	20530	4	3D
0005434925641	20530	5	4D
0005434925623	20530	6	4E
0005434925616	20530	7	5D
0005434925636	20530	8	5E
0005434925615	20530	9	5F
0005434925612	20530	10	7A
0005434925624	20530	11	7D
0005434925639	20530	12	7E
0005434925631	20530	13	7F
0005434925608	20530	14	9A
0005434925617	20530	15	9C
0005434925619	20530	16	9D
0005434925651	20530	17	9F
0005434925649	20530	18	10A
0005434925621	20530	19	10C
0005434925620	20530	20	10D
0005434925638	20530	21	10E
0005434925648	20530	22	10F
0005434925627	20530	23	11A
0005434925633	20530	24	11C
0005434925645	20530	25	12A
0005434925618	20530	26	12D
0005434925646	20530	27	13D
0005434925632	20530	28	13E
0005434925614	20530	29	14D
0005434925647	20530	30	14E
0005434925635	20530	31	15A
0005434925650	20530	32	15D
0005434925609	20530	33	15E
0005434925630	20530	34	16A
0005434925610	20530	35	16D
0005434925629	20530	36	16E
0005434925634	20530	37	17C
0005434925644	20530	38	17D
0005434925611	20530	39	17F
0005434925628	20530	40	18D
0005434925607	20530	41	18E
0005434925622	20530	42	19F
0005434925625	20530	43	20D
0005434925640	20530	44	20E
0005434925613	20530	45	20F
0005435487733	15822	1	1A
0005435487719	15822	2	1B
0005435487723	15822	3	1C
0005435487725	15822	4	1D
0005435999025	15822	5	2A
0005435487724	15822	6	3A
0005435487740	15822	7	3B
0005435999040	15822	8	4B
0005435487739	15822	9	4C
0005435487730	15822	10	4D
0005435487738	15822	11	5A
0005435487734	15822	12	5D
0005435999042	15822	13	6A
0005435998990	15822	14	6B
0005435487737	15822	15	6D
0005435999014	15822	16	7A
0005435999026	15822	17	7D
0005435487735	15822	18	18A
0005435487728	15822	19	18B
0005435487731	15822	20	18D
0005435487732	15822	21	19A
0005435487727	15822	22	19B
0005435998968	15822	23	19C
0005435998975	15822	24	20A
0005435487726	15822	25	20C
0005435998999	15822	26	20D
0005435487736	15822	27	21B
0005435998989	15822	28	21C
0005435487722	15822	29	21D
0005435487720	15822	30	22B
0005435487721	15822	31	22C
0005435999035	15822	32	22D
0005435487729	15822	33	23A
0005435487542	19679	1	1A
0005435999146	19679	2	1B
0005435999170	19679	3	1C
0005435999155	19679	4	1D
0005435999157	19679	5	2A
0005435999148	19679	6	2C
0005435999156	19679	7	3D
0005435999161	19679	8	4A
0005435999169	19679	9	4C
0005435999150	19679	10	4D
0005435999166	19679	11	5D
0005435999158	19679	12	6A
0005435999165	19679	13	6B
0005435999163	19679	14	6D
0005435487507	19679	15	7A
0005435487532	19679	16	7B
0005435999151	19679	17	7C
0005435487506	19679	18	7D
0005435999168	19679	19	18A
0005435999149	19679	20	18B
0005435999162	19679	21	18C
0005435487511	19679	22	18D
0005435999144	19679	23	19A
0005435999172	19679	24	19C
0005435487541	19679	25	19D
0005435999171	19679	26	20A
0005435999159	19679	27	20C
0005435999164	19679	28	20B
0005435487515	19679	29	20D
0005435999153	19679	30	21A
0005435999160	19679	31	21B
0005435999167	19679	32	21C
0005435999145	19679	33	22A
0005435999152	19679	34	22C
0005435999147	19679	35	22D
0005435999154	19679	36	23A
0005435472588	6015	1	1D
0005432537034	6015	2	2A
0005435839318	6015	3	1F
0005435472594	6015	4	2F
0005432537033	6015	5	2D
0005435472581	6015	6	3D
0005435472553	6015	7	4C
0005432537035	6015	8	5C
0005432660809	6015	9	5F
0005435839316	6015	10	5D
0005435472595	6015	11	6A
0005435839325	6015	12	6D
0005435839311	6015	13	6C
0005435472635	6015	14	6F
0005435839320	6015	15	7B
0005435839303	6015	16	8A
0005435839308	6015	17	8D
0005435472634	6015	18	8F
0005435839323	6015	19	9A
0005432658582	6015	20	9F
0005435472601	6015	21	10A
0005435472632	6015	22	10B
0005435839304	6015	23	10D
0005435839321	6015	24	11A
0005435839310	6015	25	11F
0005435472579	6015	26	11E
0005435472552	6015	27	12B
0005435472578	6015	28	12A
0005435472619	6015	29	12D
0005432142235	6015	30	12E
0005435472543	6015	31	13A
0005435839314	6015	32	12F
0005435472587	6015	33	13C
0005435839306	6015	34	13B
0005435472565	6015	35	13D
0005432659698	6015	36	14A
0005435839312	6015	37	14C
0005435472623	6015	38	14E
0005432660810	6015	39	15B
0005435839315	6015	40	15D
0005435839317	6015	41	15C
0005435472542	6015	42	16B
0005435472583	6015	43	16D
0005432142237	6015	44	16F
0005432659697	6015	45	16E
0005432142236	6015	46	17B
0005435839328	6015	47	17A
0005435839319	6015	48	17F
0005435839327	6015	49	17E
0005435472557	6015	50	18E
0005435839329	6015	51	19C
0005435839331	6015	52	19D
0005435472602	6015	53	19F
0005435839330	6015	54	19E
0005435839326	6015	55	20B
0005435472589	6015	56	20C
0005432660808	6015	57	20F
0005435839307	6015	58	20E
0005435839313	6015	59	21B
0005435839309	6015	60	21A
0005435839324	6015	61	21D
0005435472584	6015	62	21C
0005435839305	6015	63	21E
0005435839322	6015	64	21F
0005435472730	18068	1	1A
0005435472726	18068	2	1F
0005435472718	18068	3	2A
0005435838993	18068	4	2D
0005435838997	18068	5	2C
0005435839050	18068	6	3A
0005435839204	18068	7	3F
0005435839039	18068	8	4D
0005435839080	18068	9	5C
0005435839120	18068	10	5F
0005435839051	18068	11	5D
0005435839076	18068	12	6D
0005435839034	18068	13	7C
0005435472717	18068	14	7E
0005435472720	18068	15	7D
0005435472716	18068	16	7F
0005435839064	18068	17	8E
0005435472723	18068	18	9C
0005432660787	18068	19	10B
0005435472728	18068	20	10D
0005435839072	18068	21	11F
0005435839049	18068	22	12D
0005435839112	18068	23	12C
0005435472725	18068	24	12E
0005435472721	18068	25	13B
0005435472727	18068	26	13C
0005435472719	18068	27	14B
0005435839198	18068	28	14D
0005435472722	18068	29	15D
0005432667419	18068	30	15C
0005435472729	18068	31	16C
0005435839098	18068	32	16E
0005435472731	18068	33	16F
0005435838990	18068	34	17B
0005432537049	18068	35	17A
0005435472715	18068	36	17E
0005435839183	18068	37	18A
0005435839053	18068	38	18D
0005435839075	18068	39	19A
0005432537050	18068	40	18F
0005435472724	18068	41	19C
0005435839071	18068	42	19D
0005435472714	18068	43	19F
0005432537048	18068	44	20E
0005432660786	18068	45	21A
0005435839054	18068	46	21C
0005435103879	23049	1	1D
0005433284984	23049	2	2C
0005433284982	23049	3	2F
0005433284861	23049	4	3F
0005433284869	23049	5	4C
0005435103884	23049	6	5A
0005433284802	23049	7	5C
0005435103880	23049	8	5E
0005433284870	23049	9	5F
0005435103885	23049	10	6B
0005433284952	23049	11	6D
0005433284974	23049	12	6E
0005433284987	23049	13	6F
0005433284897	23049	14	7B
0005433284809	23049	15	8F
0005433284988	23049	16	9E
0005433284903	23049	17	10C
0005433284857	23049	18	11A
0005433284852	23049	19	11E
0005433284797	23049	20	12B
0005433284898	23049	21	12D
0005433284895	23049	22	13A
0005433284885	23049	23	13E
0005435103878	23049	24	14C
0005433284806	23049	25	14B
0005435103882	23049	26	14D
0005433284791	23049	27	14E
0005433284915	23049	28	15B
0005433284941	23049	29	15C
0005433284968	23049	30	16D
0005433284884	23049	31	16E
0005433284887	23049	32	18B
0005433284938	23049	33	18D
0005433284858	23049	34	18F
0005433284939	23049	35	19D
0005433284894	23049	36	21D
0005433284875	23049	37	22B
0005433284867	23049	38	22D
0005433284868	23049	39	23A
0005435103883	23049	40	23B
0005435103881	23049	41	23E
0005433284801	23049	42	23F
0005433285159	32048	1	1A
0005433285153	32048	2	1C
0005433285140	32048	3	2C
0005433285142	32048	4	2F
0005433285137	32048	5	3F
0005433285157	32048	6	4D
0005435103818	32048	7	4F
0005433285143	32048	8	5A
0005433285166	32048	9	5F
0005433285151	32048	10	5E
0005433285154	32048	11	6F
0005433285158	32048	12	7B
0005433285138	32048	13	7A
0005433285139	32048	14	8A
0005433285152	32048	15	8E
0005433285161	32048	16	9B
0005433285148	32048	17	9F
0005435103795	32048	18	10B
0005433285144	32048	19	11D
0005433285141	32048	20	12C
0005433285163	32048	21	12F
0005433285145	32048	22	13C
0005435103794	32048	23	15B
0005433285150	32048	24	16B
0005433285146	32048	25	16D
0005433285165	32048	26	17D
0005435103796	32048	27	17E
0005433285149	32048	28	17F
0005433285162	32048	29	18A
0005433285164	32048	30	18E
0005433285155	32048	31	19F
0005433285156	32048	32	20C
0005433285136	32048	33	22A
0005433285160	32048	34	22C
0005433285147	32048	35	22B
0005433285135	32048	36	23C
0005435103809	32048	37	23D
0005435852562	23879	1	1D
0005433475641	23879	2	2C
0005435852561	23879	3	2D
0005433475642	23879	4	3B
0005433475637	23879	5	7B
0005435852563	23879	6	19A
0005435852560	23879	7	19B
0005435852559	23879	8	21D
0005433475643	23879	9	22B
0005433475656	23879	10	22D
0005433475638	23879	11	23A
0005432526390	30581	1	1C
0005432526338	30581	2	1A
0005432526591	30581	3	1G
0005432526073	30581	4	1D
0005432526078	30581	5	1K
0005432526050	30581	6	2D
0005432526049	30581	7	2C
0005432525969	30581	8	2A
0005432526709	30581	9	2H
0005432525949	30581	10	2G
0005434066802	30581	11	3A
0005432526589	30581	12	2K
0005432526334	30581	13	3D
0005432526697	30581	14	4C
0005432526485	30581	15	4A
0005432526212	30581	16	4G
0005434066668	30581	17	4D
0005435213267	30581	18	4K
0005432526072	30581	19	4H
0005435213297	30581	20	5D
0005432526093	30581	21	5A
0005432526795	30581	22	5H
0005435213273	30581	23	5G
0005435213241	30581	24	11A
0005435213262	30581	25	5K
0005432526340	30581	26	11D
0005432526341	30581	27	11C
0005432526454	30581	28	11F
0005432525967	30581	29	11H
0005434066603	30581	30	12C
0005432526590	30581	31	12A
0005432526413	30581	32	12E
0005435213255	30581	33	12D
0005435213293	30581	34	12H
0005434066687	30581	35	12G
0005432526320	30581	36	12F
0005432211472	30581	37	12K
0005432526824	30581	38	13D
0005435213280	30581	39	13C
0005432428884	30581	40	13A
0005432526749	30581	41	13K
0005432159839	30581	42	13H
0005434066567	30581	43	13G
0005435213236	30581	44	14C
0005434066922	30581	45	14A
0005432535780	30581	46	14E
0005432526405	30581	47	14G
0005435213286	30581	48	14F
0005432526382	30581	49	14K
0005434066558	30581	50	14H
0005432525866	30581	51	15A
0005435213285	30581	52	15E
0005434066586	30581	53	15D
0005432159838	30581	54	15G
0005432526080	30581	55	15F
0005434066669	30581	56	16A
0005432526047	30581	57	16D
0005432526862	30581	58	16C
0005432533264	30581	59	16F
0005432526121	30581	60	16E
0005434066326	30581	61	16H
0005435213295	30581	62	16G
0005434066923	30581	63	17A
0005435213278	30581	64	16K
0005434066533	30581	65	17E
0005432526176	30581	66	17D
0005432526700	30581	67	17G
0005434066490	30581	68	17F
0005434066568	30581	69	18A
0005433656658	30581	70	17K
0005432525915	30581	71	17H
0005434066877	30581	72	18C
0005432526248	30581	73	18B
0005435725580	30581	74	18D
0005434066876	30581	75	18G
0005432211469	30581	76	18F
0005435213258	30581	77	18J
0005432526553	30581	78	18H
0005435213268	30581	79	19A
0005434066629	30581	80	18K
0005432535774	30581	81	19C
0005432526441	30581	82	19F
0005435213230	30581	83	19E
0005435213244	30581	84	19J
0005432526189	30581	85	19H
0005432526041	30581	86	19G
0005435213271	30581	87	20A
0005434066787	30581	88	19K
0005432526455	30581	89	20B
0005432526463	30581	90	20E
0005432526228	30581	91	20D
0005434066993	30581	92	20C
0005432526216	30581	93	20G
0005435213288	30581	94	20F
0005434066563	30581	95	20K
0005434066704	30581	96	20J
0005434066527	30581	97	20H
0005432526173	30581	98	21B
0005435213272	30581	99	21A
0005432526197	30581	100	21C
0005432526809	30581	101	21E
0005434066462	30581	102	21H
0005434066512	30581	103	21G
0005435213248	30581	104	22A
0005434066839	30581	105	21J
0005434066547	30581	106	22C
0005432526750	30581	107	22B
0005434066686	30581	108	22F
0005435213289	30581	109	22E
0005432526354	30581	110	22D
0005435213254	30581	111	22G
0005434066587	30581	112	22K
0005432537027	30581	113	22J
0005434066532	30581	114	22H
0005434066428	30581	115	23B
0005435213276	30581	116	23A
0005432533260	30581	117	23E
0005432526757	30581	118	23D
0005432526696	30581	119	23C
0005432526376	30581	120	23G
0005432526149	30581	121	23F
0005432535758	30581	122	23J
0005435725581	30581	123	23H
0005433656657	30581	124	23K
0005432526531	30581	125	24F
0005432526114	30581	126	24G
0005435213237	30581	127	25D
0005434066539	30581	128	25C
0005434066735	30581	129	25H
0005432526465	30581	130	25K
0005435213290	30581	131	25J
0005435213281	30581	132	26C
0005435725579	30581	133	26F
0005435213249	30581	134	26E
0005432526466	30581	135	26G
0005435213243	30581	136	26J
0005432526632	30581	137	26H
0005434066546	30581	138	27A
0005432526878	30581	139	27D
0005432526375	30581	140	27B
0005432526298	30581	141	27E
0005432526552	30581	142	27H
0005434066638	30581	143	27G
0005432526293	30581	144	28A
0005432526374	30581	145	27K
0005435213279	30581	146	27J
0005432526204	30581	147	28C
0005435213298	30581	148	28B
0005432526383	30581	149	28D
0005432526414	30581	150	28G
0005432526091	30581	151	28F
0005432526184	30581	152	28J
0005432526593	30581	153	28H
0005434066657	30581	154	29B
0005434066760	30581	155	29A
0005435213296	30581	156	28K
0005435213246	30581	157	29D
0005432526170	30581	158	29C
0005432526380	30581	159	29F
0005434066594	30581	160	29E
0005432526366	30581	161	29G
0005435213250	30581	162	29K
0005432526187	30581	163	30C
0005432526422	30581	164	30B
0005432526823	30581	165	30D
0005432526530	30581	166	30H
0005434066688	30581	167	30F
0005434066551	30581	168	30J
0005435213251	30581	169	31A
0005432526444	30581	170	30K
0005432526442	30581	171	31C
0005434066905	30581	172	31B
0005434066694	30581	173	31F
0005435213291	30581	174	31E
0005435213263	30581	175	31D
0005432526299	30581	176	31G
0005434066397	30581	177	32A
0005432526048	30581	178	31K
0005434066566	30581	179	32C
0005432526472	30581	180	32B
0005432526116	30581	181	32E
0005432526828	30581	182	32D
0005435213274	30581	183	32F
0005435213253	30581	184	32J
0005432526092	30581	185	32H
0005434066554	30581	186	33B
0005435213238	30581	187	33A
0005432526571	30581	188	33D
0005432526495	30581	189	33C
0005435213260	30581	190	33F
0005432526333	30581	191	33E
0005434066470	30581	192	33H
0005435213245	30581	193	33G
0005435213247	30581	194	33J
0005432526453	30581	195	34B
0005435213240	30581	196	34A
0005432211468	30581	197	34E
0005432533265	30581	198	34D
0005432526061	30581	199	34C
0005435213292	30581	200	34F
0005432525810	30581	201	34H
0005432526106	30581	202	35B
0005434066720	30581	203	35A
0005435213287	30581	204	34K
0005434066625	30581	205	35C
0005432526556	30581	206	35E
0005434066863	30581	207	35J
0005432535773	30581	208	35H
0005434066640	30581	209	35G
0005432159840	30581	210	36C
0005432526319	30581	211	36B
0005434066639	30581	212	36A
0005435213265	30581	213	36E
0005432526174	30581	214	36H
0005432526860	30581	215	36G
0005434066768	30581	216	36F
0005432526188	30581	217	36K
0005435213277	30581	218	36J
0005434066596	30581	219	37B
0005432211471	30581	220	37A
0005432535772	30581	221	37F
0005434066992	30581	222	37E
0005435213269	30581	223	37J
0005435213282	30581	224	37H
0005432526113	30581	225	37G
0005435213259	30581	226	38A
0005434066483	30581	227	37K
0005435213235	30581	228	38C
0005432526283	30581	229	38K
0005432526861	30581	230	38J
0005432526040	30581	231	39A
0005432526400	30581	232	39D
0005432526155	30581	233	39C
0005432537026	30581	234	39F
0005435213232	30581	235	39E
0005434066480	30581	236	39H
0005435213239	30581	237	39G
0005432526089	30581	238	40A
0005435213284	30581	239	39K
0005432159837	30581	240	39J
0005432526359	30581	241	40E
0005435213233	30581	242	40G
0005432526592	30581	243	40F
0005432526337	30581	244	40H
0005434066788	30581	245	41B
0005432526794	30581	246	41A
0005432526452	30581	247	40K
0005434066703	30581	248	41D
0005432526370	30581	249	41C
0005435213252	30581	250	41F
0005435725582	30581	251	41E
0005432526358	30581	252	41H
0005432526829	30581	253	42A
0005434066481	30581	254	41K
0005432525916	30581	255	42E
0005434066552	30581	256	42D
0005435213261	30581	257	42C
0005435213294	30581	258	42G
0005434066488	30581	259	42K
0005432526193	30581	260	42J
0005435725578	30581	261	42H
0005432211467	30581	262	43A
0005432526365	30581	263	43D
0005432526353	30581	264	43F
0005432525944	30581	265	43E
0005434066705	30581	266	43K
0005432526175	30581	267	44A
0005432211470	30581	268	44F
0005434066478	30581	269	44D
0005432526699	30581	270	44K
0005432526122	30581	271	45B
0005435213231	30581	272	45A
0005435213242	30581	273	45D
0005435213257	30581	274	45C
0005435213283	30581	275	45E
0005432526417	30581	276	45H
0005435213275	30581	277	45G
0005432526265	30581	278	45J
0005432525945	30581	279	46B
0005435213256	30581	280	46A
0005432526708	30581	281	46E
0005432537025	30581	282	46D
0005434066482	30581	283	46C
0005435213266	30581	284	46G
0005432526406	30581	285	46F
0005432526524	30581	286	46J
0005432526423	30581	287	46H
0005433656656	30581	288	47A
0005434066803	30581	289	46K
0005434066595	30581	290	47D
0005432526473	30581	291	47C
0005432525968	30581	292	47G
0005435213234	30581	293	47F
0005432526596	30581	294	47K
0005432526381	30581	295	47H
0005432525809	30581	296	48D
0005432526624	30581	297	48C
0005434066904	30581	298	48A
0005434066592	30581	299	48H
0005432526566	30581	300	48G
0005435630955	30581	301	49D
0005435213264	30581	302	49C
0005432526484	30581	303	49F
0005432526335	30581	304	49E
0005434066747	30581	305	49K
0005432526192	30581	306	49H
0005435213270	30581	307	49G
0005432526679	30581	308	50D
0005435630956	30581	309	50A
0005432526953	30581	310	50K
0005434066607	30581	311	50H
0005434066513	30581	312	51F
0005432526332	30581	313	51D
0005434066602	30581	314	51G
0005435652436	24875	1	1C
0005433367754	24875	2	1F
0005435652442	24875	3	2A
0005435652473	24875	4	2D
0005433367735	24875	5	2F
0005435652449	24875	6	3A
0005433367739	24875	7	3C
0005433367742	24875	8	3D
0005433367721	24875	9	3F
0005435652353	24875	10	4A
0005433367723	24875	11	4C
0005435652434	24875	12	4E
0005433367745	24875	13	4F
0005435652305	24875	14	5A
0005435652437	24875	15	5D
0005433367755	24875	16	5E
0005433367731	24875	17	6A
0005435652292	24875	18	6C
0005435652375	24875	19	6D
0005435652403	24875	20	6E
0005435652301	24875	21	6F
0005433367740	24875	22	7A
0005435652404	24875	23	7C
0005435652300	24875	24	7D
0005433367718	24875	25	7E
0005433367717	24875	26	7F
0005433367720	24875	27	8A
0005435652398	24875	28	8D
0005435652339	24875	29	8E
0005435652411	24875	30	9A
0005435652467	24875	31	9C
0005433367724	24875	32	9E
0005435652366	24875	33	9D
0005433367729	24875	34	9F
0005433367752	24875	35	10C
0005435652324	24875	36	10D
0005433367741	24875	37	11A
0005433367727	24875	38	11D
0005435652320	24875	39	11E
0005433367730	24875	40	11F
0005435652412	24875	41	12A
0005433367734	24875	42	12C
0005433367747	24875	43	12D
0005433367743	24875	44	12E
0005435652399	24875	45	13A
0005435652397	24875	46	13C
0005433367726	24875	47	13D
0005433367736	24875	48	13F
0005433367746	24875	49	14C
0005433367738	24875	50	14D
0005433367753	24875	51	14E
0005435652417	24875	52	14F
0005433367748	24875	53	15A
0005435652460	24875	54	15C
0005433367751	24875	55	15E
0005435652405	24875	56	15F
0005435652367	24875	57	16A
0005435652481	24875	58	16C
0005435652299	24875	59	16D
0005433367732	24875	60	16E
0005435652482	24875	61	16F
0005433367744	24875	62	17A
0005435652344	24875	63	17C
0005435652376	24875	64	17D
0005435652338	24875	65	18A
0005433367722	24875	66	18C
0005435652450	24875	67	18D
0005433367725	24875	68	18F
0005433367733	24875	69	19A
0005433367719	24875	70	19C
0005433367750	24875	71	19D
0005435652325	24875	72	19E
0005435652472	24875	73	19F
0005433367749	24875	74	20A
0005435652401	24875	75	20C
0005435652470	24875	76	20D
0005433367728	24875	77	20E
0005433367737	24875	78	20F
0005435949767	6604	1	1C
0005435949768	6604	2	2D
0005435949765	6604	3	5A
0005435949770	6604	4	5C
0005435949766	6604	5	5D
0005435949769	6604	6	6C
0005435949771	6604	7	19C
0005434979670	2015	1	1A
0005435801683	2015	2	1B
0005434979666	2015	3	1C
0005435801682	2015	4	1D
0005434979669	2015	5	2A
0005434979671	2015	6	2B
0005434979664	2015	7	2C
0005434979679	2015	8	2D
0005434979678	2015	9	3B
0005434979653	2015	10	3C
0005434979654	2015	11	4A
0005434979677	2015	12	4C
0005434979655	2015	13	5A
0005434979657	2015	14	5C
0005434979665	2015	15	6D
0005434979681	2015	16	7A
0005434979658	2015	17	7B
0005434979661	2015	18	7D
0005434979672	2015	19	18C
0005434979660	2015	20	18D
0005434979674	2015	21	19A
0005434979676	2015	22	19B
0005434979668	2015	23	19C
0005434979667	2015	24	19D
0005434979662	2015	25	20B
0005434979680	2015	26	20C
0005434979659	2015	27	20D
0005434979673	2015	28	21B
0005435801684	2015	29	21C
0005434979652	2015	30	21D
0005434979656	2015	31	22B
0005434979663	2015	32	22C
0005434979682	2015	33	23A
0005434979675	2015	34	23B
0005434979476	23531	1	1B
0005434979305	23531	2	1C
0005434979486	23531	3	1D
0005434979261	23531	4	2B
0005434979368	23531	5	2D
0005434979311	23531	6	3A
0005434979377	23531	7	3C
0005434979436	23531	8	4B
0005434979435	23531	9	4C
0005434979434	23531	10	4D
0005434979330	23531	11	5A
0005434979366	23531	12	5D
0005434979350	23531	13	6B
0005434979306	23531	14	6D
0005434979328	23531	15	7B
0005434979477	23531	16	7D
0005434979262	23531	17	18D
0005434979442	23531	18	19B
0005434979393	23531	19	20C
0005434979356	23531	20	20D
0005434979255	23531	21	21A
0005434979365	23531	22	21B
0005435801667	23531	23	22D
0005434979287	23531	24	23A
0005434979312	23531	25	23B
0005434952517	2563	1	3A
0005434952515	2563	2	2B
0005434952514	2563	3	5B
0005434952516	2563	4	6B
0005433256394	2564	1	1A
0005433256395	2564	2	2A
0005433256400	2564	3	1B
0005433256399	2564	4	2B
0005433256390	2564	5	5A
0005433256393	2564	6	5B
0005433256389	2564	7	6A
0005433256411	28254	1	1A
0005434952490	28254	2	1B
0005434952478	28254	3	2A
0005434952487	28254	4	2B
0005434952491	28254	5	3A
0005433256412	28254	6	4B
0005434952489	28254	7	5A
0005434952488	28254	8	5B
0005433256413	28254	9	6A
0005434952479	28254	10	6B
0005433111496	19780	1	1A
0005434302853	19780	2	1B
0005433111498	19780	3	3B
0005433112368	19780	4	4B
0005433111497	19780	5	5B
0005433112367	19780	6	6A
0005434137404	11937	1	1A
0005434137017	11937	2	1C
0005434137066	11937	3	1D
0005434137129	11937	4	1F
0005434136741	11937	5	2A
0005434137088	11937	6	2C
0005434136740	11937	7	2D
0005434137277	11937	8	3A
0005434137454	11937	9	3C
0005434137248	11937	10	3D
0005434136895	11937	11	3F
0005434137328	11937	12	4C
0005434136768	11937	13	4D
0005434137067	11937	14	4E
0005434137062	11937	15	4F
0005434137058	11937	16	5A
0005434136999	11937	17	5D
0005434137276	11937	18	5E
0005434137068	11937	19	5F
0005434137142	11937	20	6A
0005434137146	11937	21	6D
0005434137063	11937	22	6E
0005434137383	11937	23	6F
0005434137000	11937	24	7A
0005434137015	11937	25	7C
0005434137001	11937	26	7D
0005434137286	11937	27	7E
0005434137355	11937	28	7F
0005434137141	11937	29	8A
0005434137320	11937	30	8C
0005434137090	11937	31	8D
0005434137217	11937	32	8E
0005434136961	11937	33	8F
0005434136963	11937	34	9A
0005434137278	11937	35	9C
0005434137111	11937	36	9D
0005434137362	11937	37	9E
0005434136769	11937	38	9F
0005434137382	11937	39	10A
0005434137371	11937	40	10C
0005434137115	11937	41	10D
0005434137414	11937	42	10E
0005434137223	11937	43	11A
0005434136812	11937	44	11C
0005434137166	11937	45	11D
0005434137065	11937	46	11E
0005434137099	11937	47	11F
0005434137280	11937	48	12D
0005434136962	11937	49	12E
0005434136896	11937	50	12F
0005434137202	11937	51	13C
0005434136944	11937	52	13D
0005434136770	11937	53	13E
0005434137260	11937	54	13F
0005434137089	11937	55	14A
0005434137192	11937	56	14C
0005434137249	11937	57	14D
0005434137038	11937	58	14F
0005434137318	11937	59	15A
0005434137373	11937	60	15C
0005434137509	11937	61	15D
0005434137191	11937	62	15E
0005434137150	11937	63	15F
0005434137363	11937	64	16A
0005434137130	11937	65	16C
0005434136964	11937	66	16D
0005434137116	11937	67	16E
0005434137208	11937	68	17A
0005434137413	11937	69	17C
0005434137319	11937	70	17D
0005434137405	11937	71	17E
0005434137329	11937	72	17F
0005434137224	11937	73	18A
0005434136943	11937	74	18D
0005434137053	11937	75	18E
0005434136945	11937	76	18F
0005434137072	11937	77	19A
0005434137143	11937	78	19C
0005434137285	11937	79	19D
0005434137356	11937	80	19E
0005434137014	11937	81	19F
0005434137194	11937	82	20C
0005434137091	11937	83	20D
0005434137590	11937	84	20F
0005434137718	28724	1	1C
0005434137767	28724	2	2A
0005434137715	28724	3	2C
0005434137764	28724	4	2D
0005434137720	28724	5	2F
0005434137755	28724	6	3C
0005434137758	28724	7	3D
0005434137776	28724	8	3F
0005434137737	28724	9	4A
0005434137780	28724	10	4C
0005434137738	28724	11	4D
0005434137719	28724	12	4E
0005434137777	28724	13	4F
0005434137724	28724	14	5A
0005434137751	28724	15	5C
0005434137778	28724	16	5D
0005434137729	28724	17	5E
0005434137763	28724	18	5F
0005434137750	28724	19	6D
0005434137762	28724	20	6E
0005434137731	28724	21	6F
0005434137783	28724	22	7A
0005434137736	28724	23	7C
0005434137782	28724	24	7E
0005434137774	28724	25	7F
0005434137722	28724	26	8A
0005434137754	28724	27	8C
0005434137743	28724	28	8D
0005434137714	28724	29	8E
0005434137733	28724	30	8F
0005434137734	28724	31	9A
0005434137711	28724	32	9C
0005434137735	28724	33	9D
0005434137721	28724	34	9E
0005434137725	28724	35	9F
0005434137772	28724	36	10A
0005434137760	28724	37	10C
0005434137756	28724	38	10D
0005434137708	28724	39	10E
0005434137746	28724	40	10F
0005434137770	28724	41	11A
0005434137740	28724	42	11C
0005434137717	28724	43	11D
0005434137726	28724	44	11F
0005434137779	28724	45	12C
0005434137728	28724	46	12E
0005434137739	28724	47	12F
0005434137712	28724	48	13A
0005434137730	28724	49	13D
0005434137766	28724	50	13E
0005434137775	28724	51	13F
0005434137710	28724	52	14A
0005434137713	28724	53	14C
0005434137744	28724	54	14D
0005434137727	28724	55	14F
0005434137747	28724	56	15A
0005434137781	28724	57	15C
0005434137742	28724	58	15D
0005434137709	28724	59	15E
0005434137748	28724	60	15F
0005434137753	28724	61	16A
0005434137757	28724	62	16C
0005434137765	28724	63	16F
0005434137752	28724	64	16E
0005434137761	28724	65	17A
0005434137741	28724	66	17C
0005434137749	28724	67	17D
0005434137769	28724	68	17F
0005434137723	28724	69	18A
0005434137773	28724	70	18D
0005434137784	28724	71	18F
0005434137732	28724	72	19C
0005434137716	28724	73	19D
0005434137771	28724	74	19E
0005434137745	28724	75	20A
0005434137759	28724	76	20E
0005434137768	28724	77	20F
0005435312775	6587	1	1D
0005434466433	6587	2	2D
0005434466441	6587	3	3B
0005434466438	6587	4	3D
0005435312764	6587	5	4B
0005434466439	6587	6	7B
0005435312776	6587	7	7C
0005434466437	6587	8	7D
0005434466440	6587	9	18A
0005434466442	6587	10	20B
0005434466435	6587	11	20C
0005435312770	6587	12	21A
0005434466436	6587	13	22B
0005434466434	6587	14	23A
0005433538837	6797	1	3D
0005433538838	6797	2	4C
0005433538839	6797	3	5D
0005435259699	6797	4	6C
0005433538833	6797	5	7D
0005435259698	6797	6	18B
0005433538836	6797	7	20B
0005433538834	6797	8	20C
0005433534490	6797	9	21A
0005433538835	6797	10	21B
0005433538832	6797	11	21D
0005435259700	6797	12	22B
0005433534489	6797	13	22C
0005435259717	6797	14	23A
0005433538765	24994	1	1A
0005433538784	24994	2	2A
0005433538753	24994	3	2B
0005433538754	24994	4	3A
0005433538737	24994	5	3B
0005433538776	24994	6	4C
0005433538743	24994	7	4D
0005433538770	24994	8	6B
0005433538751	24994	9	6C
0005433538761	24994	10	7A
0005435259740	24994	11	7D
0005433538741	24994	12	18A
0005435259739	24994	13	19A
0005435259738	24994	14	19D
0005433538760	24994	15	20B
0005435259737	24994	16	21A
0005433538769	24994	17	23A
0005433538752	24994	18	23B
0005432922488	829	1	1B
0005432922453	829	2	1C
0005432922477	829	3	2D
0005433511918	829	4	3C
0005433511917	829	5	4D
0005432922469	829	6	5A
0005432922487	829	7	5C
0005433511919	829	8	6C
0005432922454	829	9	6D
0005433511916	829	10	7A
0005432922489	829	11	19B
0005433511915	829	12	19D
0005432922484	829	13	20A
0005433511914	829	14	21A
0005432922466	829	15	21B
0005432922468	829	16	22C
0005433511920	829	17	23A
0005432922510	16148	1	3B
0005432922506	16148	2	5D
0005433511852	16148	3	6A
0005433511870	16148	4	7A
0005432922508	16148	5	7C
0005433511826	16148	6	18C
0005433511877	16148	7	19D
0005432922509	16148	8	20A
0005433511851	16148	9	22A
0005433511876	16148	10	22D
0005432922507	16148	11	23B
0005435697242	3647	1	1D
0005435697221	3647	2	2A
0005435935000	3647	3	2B
0005435697224	3647	4	2C
0005435697226	3647	5	3A
0005435697222	3647	6	2D
0005435697233	3647	7	3B
0005435916131	3647	8	3D
0005435697241	3647	9	4A
0005435916122	3647	10	4B
0005435697217	3647	11	4D
0005435697230	3647	12	5A
0005435697220	3647	13	5C
0005435697235	3647	14	5D
0005434950511	3647	15	6A
0005434950510	3647	16	6B
0005435697243	3647	17	6C
0005435697219	3647	18	6D
0005435697234	3647	19	7A
0005435697232	3647	20	7B
0005435697231	3647	21	7C
0005435697229	3647	22	7D
0005435697239	3647	23	18C
0005435697218	3647	24	18D
0005434950509	3647	25	19A
0005435697228	3647	26	19B
0005435697225	3647	27	19C
0005434950512	3647	28	19D
0005435916136	3647	29	20A
0005435697237	3647	30	20B
0005435697240	3647	31	20D
0005435697223	3647	32	21A
0005435697244	3647	33	21C
0005435697236	3647	34	21D
0005434950513	3647	35	22D
0005435697227	3647	36	23A
0005435697238	3647	37	23B
0005435697031	16297	1	1A
0005435696960	16297	2	1B
0005434950460	16297	3	1C
0005435697003	16297	4	1D
0005435697037	16297	5	2A
0005435697014	16297	6	2C
0005435697013	16297	7	2D
0005435696936	16297	8	3B
0005435916157	16297	9	3C
0005435697032	16297	10	4B
0005435696946	16297	11	4C
0005435697128	16297	12	5A
0005435696910	16297	13	5D
0005435935028	16297	14	6A
0005435696868	16297	15	6C
0005435696945	16297	16	7A
0005435697038	16297	17	7B
0005435696888	16297	18	7C
0005434950461	16297	19	7D
0005435916155	16297	20	18A
0005434950459	16297	21	18B
0005435916156	16297	22	18C
0005435696867	16297	23	19A
0005435696961	16297	24	19B
0005435696931	16297	25	19C
0005435697024	16297	26	19D
0005435697004	16297	27	20A
0005435696930	16297	28	20C
0005434950476	16297	29	20D
0005435697025	16297	30	21C
0005435697026	16297	31	21D
0005434950475	16297	32	22B
0005435696937	16297	33	22D
0005434950468	16297	34	23A
0005435935029	16297	35	23B
0005432609715	3989	1	2A
0005432607552	3989	2	2B
0005432609716	3989	3	2C
0005432609714	3989	4	2D
0005434604882	3989	5	3B
0005434604884	3989	6	3C
0005432607549	3989	7	4A
0005434606816	3989	8	4B
0005432607548	3989	9	4C
0005432607550	3989	10	4D
0005434606818	3989	11	5B
0005433519437	3989	12	5C
0005434604883	3989	13	5D
0005434604885	3989	14	6B
0005434606815	3989	15	6D
0005433519441	3989	16	7B
0005432607551	3989	17	18B
0005433519440	3989	18	18D
0005435841463	3989	19	19A
0005433519438	3989	20	20A
0005433519439	3989	21	23A
0005434606817	3989	22	23B
0005435853606	22085	1	2C
0005435853605	22085	2	3A
0005434606791	22085	3	18A
0005435904894	22085	4	19A
0005434606766	22085	5	20C
0005433519386	22085	6	21C
0005434606767	22085	7	21D
0005433519387	22085	8	22B
0005433519388	22085	9	23A
0005435628712	724	1	2A
0005433348919	724	2	2B
0005435628709	724	3	3A
0005433348929	724	4	3B
0005433348917	724	5	4B
0005435628711	724	6	5A
0005433348920	724	7	5B
0005433348938	724	8	6A
0005435628710	724	9	6B
0005433348967	15914	1	1A
0005433348965	15914	2	2A
0005433348964	15914	3	1B
0005433348966	15914	4	3A
0005433348969	15914	5	3B
0005435628687	15914	6	4B
0005433348968	15914	7	5A
0005435628697	15914	8	6A
0005435628694	15914	9	5B
0005433159286	17222	1	1A
0005433158100	17222	2	1B
0005434446511	17222	3	2A
0005434446508	17222	4	2B
0005434446510	17222	5	3A
0005434446509	17222	6	3B
0005434445237	17222	7	4B
0005434445236	17222	8	5A
0005433159304	17579	1	2A
0005433159305	17579	2	5A
0005435132842	7859	1	1A
0005435383076	7859	2	1B
0005435132835	7859	3	1D
0005435383086	7859	4	2A
0005435383087	7859	5	2B
0005435383085	7859	6	2C
0005435132845	7859	7	3D
0005435383075	7859	8	4C
0005435132840	7859	9	6D
0005435132843	7859	10	7B
0005435383074	7859	11	7C
0005435132837	7859	12	18A
0005435132841	7859	13	18D
0005435132836	7859	14	20D
0005435132838	7859	15	21D
0005435132844	7859	16	22B
0005435132839	7859	17	23A
0005435383131	33103	1	1A
0005435132792	33103	2	1B
0005435132727	33103	3	3B
0005435132763	33103	4	4D
0005435132787	33103	5	5A
0005435383129	33103	6	5B
0005435383127	33103	7	6A
0005435132753	33103	8	6C
0005435383126	33103	9	7A
0005435132780	33103	10	18A
0005435383128	33103	11	20B
0005435132728	33103	12	21A
0005435383130	33103	13	22D
0005435132802	33103	14	23A
0005435811054	4415	1	1F
0005435811049	4415	2	5F
0005435811055	4415	3	6F
0005435938844	4415	4	10C
0005435811050	4415	5	10B
0005435811052	4415	6	10E
0005435811056	4415	7	11F
0005435938851	4415	8	11E
0005435938845	4415	9	12A
0005435811057	4415	10	14E
0005435811048	4415	11	14D
0005435938846	4415	12	18F
0005435811051	4415	13	19E
0005435811053	4415	14	21A
0005435810998	29435	1	1A
0005435810995	29435	2	1D
0005435811017	29435	3	2F
0005435811021	29435	4	4A
0005435811016	29435	5	5A
0005435810996	29435	6	4D
0005435938873	29435	7	5C
0005435938875	29435	8	6E
0005435938876	29435	9	7C
0005435811008	29435	10	7F
0005435811020	29435	11	8F
0005435810999	29435	12	10E
0005435938874	29435	13	11D
0005435810988	29435	14	11E
0005435811003	29435	15	13E
0005435811000	29435	16	13F
0005435938878	29435	17	16B
0005435811009	29435	18	18F
0005435811030	29435	19	19C
0005435938877	29435	20	19B
0005435810997	29435	21	21E
0005435160254	7504	1	2A
0005435390174	7504	2	2B
0005435390161	7504	3	2D
0005435160253	7504	4	3C
0005435160260	7504	5	4C
0005435160257	7504	6	4D
0005435160262	7504	7	6C
0005435390138	7504	8	6D
0005435160263	7504	9	7C
0005435160252	7504	10	18B
0005435390137	7504	11	19A
0005435390171	7504	12	19B
0005435160259	7504	13	19D
0005435160255	7504	14	20C
0005435160258	7504	15	20D
0005435160256	7504	16	21C
0005435390160	7504	17	22A
0005435390173	7504	18	22D
0005435160261	7504	19	23B
0005435160129	29545	1	1B
0005435160178	29545	2	1C
0005435160168	29545	3	3B
0005435390215	29545	4	4B
0005435390211	29545	5	6A
0005435390209	29545	6	6B
0005435390210	29545	7	7A
0005435160166	29545	8	7B
0005435390214	29545	9	7D
0005435160161	29545	10	21D
0005435390212	29545	11	22B
0005435160177	29545	12	22A
0005435160174	29545	13	23A
0005435390213	29545	14	23B
0005432398133	18477	1	1A
0005432398138	18477	2	1B
0005432394054	18477	3	2A
0005432394049	18477	4	2B
0005432398152	18477	5	3A
0005432398137	18477	6	3B
0005432398130	18477	7	4A
0005432398129	18477	8	4B
0005432394040	18477	9	5A
0005432394065	18477	10	5B
0005432394050	18477	11	6A
0005432398134	18477	12	6B
0005432398178	27165	1	1A
0005435179384	27165	2	1B
0005432398179	27165	3	2A
0005432400102	27165	4	2B
0005432398176	27165	5	3A
0005432400103	27165	6	3B
0005432398177	27165	7	4A
0005435179383	27165	8	4B
0005432400104	27165	9	5A
0005432400101	27165	10	5B
0005432865939	2237	1	1C
0005432639089	2237	2	2A
0005432639091	2237	3	2C
0005432639082	2237	4	2F
0005432639073	2237	5	3C
0005432639072	2237	6	4C
0005432639078	2237	7	4E
0005432639071	2237	8	5C
0005432865922	2237	9	6E
0005432639090	2237	10	7C
0005432865924	2237	11	8A
0005432865901	2237	12	8C
0005432639092	2237	13	9A
0005432865925	2237	14	9D
0005432865921	2237	15	10A
0005432865902	2237	16	10D
0005432639076	2237	17	10F
0005432865927	2237	18	11A
0005432865923	2237	19	11D
0005432639079	2237	20	11E
0005432639077	2237	21	11F
0005432639083	2237	22	12A
0005432639080	2237	23	12D
0005432639070	2237	24	13E
0005432639081	2237	25	14C
0005432639069	2237	26	14E
0005432639088	2237	27	15A
0005432639068	2237	28	15C
0005432639084	2237	29	15D
0005432639067	2237	30	16F
0005432865898	2237	31	17C
0005432865926	2237	32	17E
0005432639074	2237	33	18C
0005432639085	2237	34	18E
0005432639075	2237	35	19A
0005432865935	2237	36	19D
0005432865911	2237	37	19E
0005432639086	2237	38	20A
0005432639087	2237	39	20E
0005433811628	24293	1	2F
0005433811623	24293	2	3C
0005433811626	24293	3	4B
0005433811622	24293	4	11A
0005433811629	24293	5	11B
0005433811632	24293	6	13A
0005433811630	24293	7	14B
0005433811621	24293	8	14E
0005433811631	24293	9	15D
0005433811627	24293	10	15F
0005433811625	24293	11	18E
0005433811624	24293	12	23B
0005434191252	9800	1	3A
0005434191257	9800	2	2B
0005434191256	9800	3	4B
0005434191253	9800	4	5A
0005434191251	9800	5	5B
0005434191269	32796	1	1A
0005434191266	32796	2	2A
0005434191267	32796	3	1B
0005434191270	32796	4	2B
0005434191264	32796	5	3A
0005434191273	32796	6	3B
0005434191272	32796	7	4A
0005434191265	32796	8	4B
0005434191268	32796	9	5A
0005434191263	32796	10	5B
0005434191262	32796	11	6A
0005434191271	32796	12	6B
0005432658556	26492	1	3A
0005432658561	26492	2	7E
0005432665242	26492	3	8C
0005432658566	26492	4	9F
0005432665244	26492	5	11A
0005432665250	26492	6	12C
0005432665249	26492	7	12E
0005432665243	26492	8	13A
0005432658567	26492	9	13B
0005432658565	26492	10	15C
0005432665245	26492	11	16B
0005432665238	26492	12	17D
0005432665241	26492	13	19A
0005432665237	26492	14	19B
0005432665239	26492	15	19F
0005432665240	26492	16	21A
0005432658555	26492	17	21C
0005434504006	6538	1	1A
0005434504002	6538	2	1C
0005434504003	6538	3	1D
0005434504001	6538	4	2A
0005434503988	6538	5	2C
0005434503995	6538	6	2D
0005434503994	6538	7	3A
0005434504014	6538	8	3C
0005434503985	6538	9	3D
0005434504004	6538	10	3F
0005434504016	6538	11	4D
0005435103902	6538	12	5D
0005434503986	6538	13	5F
0005435103908	6538	14	6A
0005435103904	6538	15	6D
0005434504019	6538	16	7A
0005435103907	6538	17	7C
0005434504018	6538	18	7E
0005434503993	6538	19	7F
0005434504000	6538	20	8A
0005434504010	6538	21	8D
0005434504021	6538	22	9C
0005434504017	6538	23	9D
0005434503996	6538	24	10A
0005434503991	6538	25	10C
0005434504005	6538	26	10E
0005434503983	6538	27	11F
0005434503992	6538	28	13C
0005434503982	6538	29	13D
0005434504015	6538	30	14E
0005435103903	6538	31	15D
0005434503990	6538	32	15C
0005434504011	6538	33	15E
0005434503998	6538	34	16E
0005435103906	6538	35	16F
0005434503989	6538	36	17C
0005434503984	6538	37	17D
0005435103905	6538	38	17E
0005434503999	6538	39	17F
0005434503987	6538	40	18C
0005434504013	6538	41	18D
0005434503997	6538	42	18E
0005434504007	6538	43	19A
0005434504012	6538	44	19D
0005434504008	6538	45	19E
0005434504009	6538	46	19F
0005434504020	6538	47	20A
0005434503509	22685	1	1C
0005434503652	22685	2	1D
0005434503506	22685	3	2A
0005434503581	22685	4	2C
0005434503587	22685	5	2D
0005434503593	22685	6	2F
0005435103795	22685	7	3C
0005434503523	22685	8	3F
0005434503531	22685	9	4C
0005434503653	22685	10	4D
0005435103796	22685	11	4F
0005434503505	22685	12	5D
0005434503586	22685	13	7C
0005434503473	22685	14	8E
0005434503489	22685	15	9A
0005435103809	22685	16	9E
0005434503797	22685	17	10A
0005434503465	22685	18	10C
0005434503603	22685	19	10F
0005434503539	22685	20	11E
0005434503504	22685	21	11F
0005434503490	22685	22	12E
0005434503579	22685	23	13A
0005434503466	22685	24	13C
0005434503557	22685	25	14F
0005434503491	22685	26	15C
0005435103794	22685	27	15F
0005434503551	22685	28	16A
0005434503580	22685	29	16D
0005435103818	22685	30	17A
0005434503577	22685	31	17E
0005434503522	22685	32	18D
0005434503524	22685	33	18E
0005434503578	22685	34	18F
0005434503562	22685	35	19A
0005434503684	22685	36	19C
0005434503624	22685	37	19D
0005434503556	22685	38	19E
0005434503630	22685	39	20C
0005434503527	22685	40	20F
0005433367444	1681	1	1A
0005433367637	1681	2	1C
0005433367486	1681	3	1D
0005433367343	1681	4	1F
0005433367478	1681	5	2A
0005435652900	1681	6	2C
0005435652882	1681	7	2D
0005433367334	1681	8	2F
0005433367482	1681	9	3A
0005433367524	1681	10	3C
0005435652879	1681	11	3D
0005433367435	1681	12	3F
0005435652911	1681	13	4A
0005435652913	1681	14	4D
0005435652906	1681	15	4F
0005433367369	1681	16	5C
0005433367379	1681	17	5D
0005433367420	1681	18	5E
0005435652901	1681	19	5F
0005435652915	1681	20	6A
0005435652890	1681	21	6C
0005433367591	1681	22	6D
0005433367305	1681	23	6E
0005433367430	1681	24	6F
0005435652905	1681	25	7A
0005435652910	1681	26	7C
0005435652908	1681	27	7E
0005433367268	1681	28	7F
0005433367295	1681	29	8A
0005435652878	1681	30	8C
0005435652891	1681	31	8D
0005435652898	1681	32	8F
0005433367595	1681	33	9C
0005433367579	1681	34	9F
0005435652914	1681	35	10A
0005435652894	1681	36	10C
0005435652896	1681	37	10D
0005433367218	1681	38	10F
0005433367336	1681	39	11A
0005435652912	1681	40	11C
0005435652884	1681	41	11D
0005433367594	1681	42	11F
0005433367551	1681	43	12A
0005435652907	1681	44	12C
0005433367326	1681	45	12D
0005433367518	1681	46	13A
0005433367479	1681	47	13C
0005433367384	1681	48	13E
0005435652888	1681	49	13F
0005435652883	1681	50	14A
0005433367593	1681	51	14C
0005435652909	1681	52	14D
0005433367269	1681	53	14E
0005435652902	1681	54	14F
0005433367335	1681	55	15A
0005433367353	1681	56	15D
0005433367416	1681	57	15E
0005433367224	1681	58	15F
0005435652893	1681	59	16A
0005433367429	1681	60	16C
0005435652899	1681	61	16D
0005435652881	1681	62	16E
0005435652904	1681	63	16F
0005435652895	1681	64	17A
0005433367549	1681	65	17C
0005435652886	1681	66	17D
0005435652903	1681	67	17E
0005433367504	1681	68	17F
0005435652916	1681	69	18A
0005433367325	1681	70	18C
0005433367388	1681	71	18D
0005433367550	1681	72	18E
0005435652885	1681	73	18F
0005435652887	1681	74	19A
0005435652889	1681	75	19C
0005435652880	1681	76	19D
0005433367344	1681	77	19E
0005433367503	1681	78	19F
0005433367592	1681	79	20A
0005435652897	1681	80	20C
0005435652892	1681	81	20E
0005433367401	1681	82	20F
0005435652405	21680	1	1A
0005435652344	21680	2	1F
0005433367721	21680	3	2A
0005433367725	21680	4	2C
0005433367751	21680	5	2D
0005433367731	21680	6	2F
0005435652481	21680	7	3C
0005433367737	21680	8	3D
0005435652472	21680	9	3F
0005435652434	21680	10	4A
0005433367722	21680	11	4C
0005435652399	21680	12	4D
0005433367732	21680	13	4E
0005433367717	21680	14	4F
0005435652292	21680	15	5A
0005435652300	21680	16	5D
0005435652411	21680	17	5E
0005435652412	21680	18	5F
0005435652403	21680	19	6C
0005433367741	21680	20	6D
0005433367733	21680	21	6E
0005433367728	21680	22	7A
0005435652397	21680	23	7C
0005435652450	21680	24	7F
0005435652376	21680	25	8A
0005435652460	21680	26	8C
0005433367730	21680	27	8D
0005435652299	21680	28	8E
0005435652467	21680	29	8F
0005435652436	21680	30	9A
0005435652398	21680	31	9C
0005435652449	21680	32	9D
0005433367747	21680	33	9E
0005433367745	21680	34	9F
0005433367734	21680	35	10A
0005433367718	21680	36	10C
0005435652353	21680	37	10D
0005435652437	21680	38	10E
0005433367736	21680	39	10F
0005433367726	21680	40	11A
0005435652305	21680	41	11E
0005433367752	21680	42	12A
0005433367755	21680	43	12C
0005435652442	21680	44	12D
0005433367743	21680	45	12E
0005435652339	21680	46	12F
0005433367723	21680	47	13A
0005435652320	21680	48	13D
0005435652366	21680	49	13E
0005433367740	21680	50	13F
0005435652367	21680	51	14A
0005435652325	21680	52	14C
0005435652470	21680	53	14D
0005435652404	21680	54	14F
0005433367742	21680	55	15D
0005433367719	21680	56	15E
0005435652482	21680	57	15F
0005433367753	21680	58	16A
0005435652473	21680	59	16C
0005435652301	21680	60	16E
0005433367729	21680	61	17A
0005433367748	21680	62	17C
0005435652338	21680	63	17D
0005435652401	21680	64	17E
0005433367738	21680	65	17F
0005433367727	21680	66	18C
0005433367744	21680	67	18D
0005433367749	21680	68	18E
0005433367750	21680	69	18F
0005435652324	21680	70	19A
0005433367735	21680	71	19C
0005433367754	21680	72	19D
0005435652417	21680	73	19F
0005435652375	21680	74	20A
0005433367739	21680	75	20C
0005433367746	21680	76	20D
0005433367724	21680	77	20E
0005433367720	21680	78	20F
0005434466399	23233	1	2A
0005434466398	23233	2	2C
0005435312798	23233	3	2D
0005434466421	23233	4	3A
0005434466397	23233	5	4D
0005434466393	23233	6	5A
0005434466404	23233	7	6B
0005435312796	23233	8	7A
0005434466388	23233	9	7D
0005434466400	23233	10	19C
0005435312795	23233	11	19D
0005435312794	23233	12	21A
0005434466396	23233	13	22C
0005435312797	23233	14	22D
0005434466384	23233	15	23B
0005433985747	4144	1	1A
0005433985751	4144	2	1C
0005433985780	4144	3	1D
0005433985772	4144	4	1F
0005433985745	4144	5	2C
0005435788762	4144	6	2D
0005433985754	4144	7	3A
0005433985777	4144	8	3C
0005433985752	4144	9	3D
0005433985769	4144	10	4A
0005433985763	4144	11	4C
0005433985790	4144	12	4D
0005433985776	4144	13	5D
0005433985771	4144	14	5E
0005433985746	4144	15	5F
0005433985787	4144	16	6A
0005433985755	4144	17	6C
0005433985779	4144	18	6D
0005433985767	4144	19	6E
0005433985770	4144	20	7D
0005433985741	4144	21	7E
0005433985760	4144	22	7F
0005433985743	4144	23	8D
0005433985782	4144	24	9E
0005433985740	4144	25	10A
0005433985773	4144	26	10E
0005435788760	4144	27	10F
0005433985742	4144	28	11E
0005435788761	4144	29	11F
0005433985750	4144	30	12D
0005433985774	4144	31	12E
0005433985784	4144	32	13C
0005433985744	4144	33	13F
0005433985788	4144	34	14A
0005433985765	4144	35	14E
0005433985739	4144	36	14F
0005433985758	4144	37	15C
0005433985785	4144	38	15D
0005433985748	4144	39	15E
0005433985768	4144	40	15F
0005433985753	4144	41	16C
0005433985775	4144	42	16D
0005433985783	4144	43	17C
0005433985789	4144	44	17D
0005433985756	4144	45	17E
0005433985778	4144	46	17F
0005433985759	4144	47	18D
0005433985766	4144	48	18E
0005433985762	4144	49	18F
0005433985786	4144	50	19A
0005433985757	4144	51	19E
0005433985749	4144	52	19F
0005433985781	4144	53	20A
0005433985761	4144	54	20D
0005433985764	4144	55	20F
0005433985245	25664	1	1C
0005433985296	25664	2	1D
0005433985173	25664	3	1F
0005433985434	25664	4	2A
0005433985217	25664	5	2C
0005433985336	25664	6	3A
0005433985256	25664	7	3D
0005433985306	25664	8	4A
0005433985337	25664	9	4C
0005433985280	25664	10	4F
0005433985449	25664	11	5A
0005433985236	25664	12	5C
0005433985207	25664	13	5E
0005433985302	25664	14	6C
0005433985348	25664	15	7C
0005435788750	25664	16	8C
0005433985275	25664	17	9A
0005433985529	25664	18	10A
0005433985301	25664	19	10D
0005433985208	25664	20	10E
0005433985376	25664	21	10F
0005433985497	25664	22	11A
0005433985317	25664	23	11E
0005433985364	25664	24	11F
0005433985312	25664	25	12A
0005433985329	25664	26	12C
0005433985258	25664	27	12D
0005435788751	25664	28	12E
0005433985365	25664	29	12F
0005433985316	25664	30	13A
0005433985286	25664	31	13C
0005433985514	25664	32	14F
0005433985168	25664	33	15C
0005433985300	25664	34	15E
0005433985169	25664	35	15F
0005433985297	25664	36	16F
0005435788748	25664	37	17A
0005433985137	25664	38	17D
0005433985257	25664	39	18A
0005433985172	25664	40	18C
0005433985188	25664	41	18D
0005433985343	25664	42	18F
0005433985259	25664	43	19A
0005433985189	25664	44	19C
0005433985260	25664	45	19E
0005433985505	25664	46	20A
0005435720811	21284	1	4C
0005435720812	21284	2	5C
0005435719551	21284	3	6C
0005435719550	21284	4	19D
0005434509114	1637	1	1B
0005434509113	1637	2	2A
0005434509112	1637	3	2C
0005433168331	1637	4	3A
0005434509123	1637	5	3D
0005433168330	1637	6	5B
0005433168324	1637	7	6B
0005433168319	1637	8	6C
0005434509117	1637	9	6D
0005433168328	1637	10	7C
0005434509118	1637	11	18A
0005434509108	1637	12	18C
0005434509115	1637	13	18D
0005434509122	1637	14	19A
0005434509120	1637	15	19B
0005434509110	1637	16	19D
0005434509116	1637	17	20C
0005434509119	1637	18	21A
0005434509109	1637	19	21C
0005434509121	1637	20	21D
0005433168323	1637	21	22A
0005433168333	1637	22	22B
0005433168316	1637	23	22C
0005434509111	1637	24	23B
0005434516071	9020	1	2A
0005434190380	9020	2	2D
0005434190371	9020	3	4A
0005434190369	9020	4	4D
0005434516070	9020	5	6B
0005434516069	9020	6	6D
0005434190376	9020	7	7D
0005434516067	9020	8	19A
0005434516072	9020	9	20A
0005434516068	9020	10	20C
0005434190373	9020	11	21B
0005434516073	9020	12	22D
0005434190370	9020	13	23B
0005434151693	17864	1	1C
0005432659673	17864	2	2C
0005432655374	17864	3	2D
0005432869504	17864	4	3D
0005432667423	17864	5	3F
0005432655355	17864	6	4E
0005432659680	17864	7	4F
0005432657422	17864	8	5A
0005432660792	17864	9	5C
0005432659675	17864	10	5F
0005432655356	17864	11	6A
0005432660791	17864	12	6C
0005432655349	17864	13	6E
0005432667425	17864	14	7A
0005432869505	17864	15	8D
0005432657405	17864	16	9F
0005432659676	17864	17	11D
0005432655389	17864	18	12A
0005432657408	17864	19	13E
0005432658568	17864	20	13F
0005432659681	17864	21	14A
0005432869499	17864	22	14C
0005434151694	17864	23	14D
0005432660785	17864	24	14F
0005432655381	17864	25	15A
0005432655395	17864	26	15D
0005432655379	17864	27	15E
0005432869500	17864	28	16D
0005434151695	17864	29	17D
0005432660784	17864	30	18A
0005432869503	17864	31	18D
0005432657406	17864	32	18E
0005432667424	17864	33	18F
0005432869506	17864	34	19A
0005434151697	17864	35	19F
0005432869501	17864	36	20A
0005434151696	17864	37	20D
0005432869502	17864	38	20F
0005432658580	26303	1	1A
0005432655465	26303	2	1D
0005432655468	26303	3	2C
0005432655464	26303	4	3F
0005432655469	26303	5	4A
0005432659694	26303	6	5A
0005432658581	26303	7	5C
0005432869422	26303	8	6E
0005432660807	26303	9	7D
0005432869433	26303	10	7E
0005432655467	26303	11	8C
0005432655466	26303	12	8D
0005432657433	26303	13	9A
0005432667442	26303	14	9C
0005432869413	26303	15	9D
0005432666377	26303	16	9E
0005432655461	26303	17	9F
0005432666378	26303	18	11A
0005432655463	26303	19	11C
0005432655460	26303	20	11D
0005434151664	26303	21	11F
0005432657432	26303	22	12C
0005432665263	26303	23	13D
0005432655471	26303	24	13F
0005434151678	26303	25	14A
0005432659695	26303	26	14C
0005434151665	26303	27	14E
0005432660806	26303	28	16C
0005432655470	26303	29	16D
0005432665264	26303	30	18A
0005432869423	26303	31	18E
0005432667443	26303	32	19A
0005432657434	26303	33	19C
0005432659696	26303	34	19E
0005432658579	26303	35	19F
0005432655462	26303	36	20E
0005432865983	25052	1	2D
0005432865981	25052	2	2F
0005432865987	25052	3	3D
0005432638955	25052	4	3F
0005432865993	25052	5	4A
0005432865986	25052	6	4C
0005432638959	25052	7	4E
0005432865989	25052	8	4F
0005432638961	25052	9	5D
0005432638968	25052	10	5E
0005432865982	25052	11	5F
0005432638990	25052	12	7D
0005432638972	25052	13	7E
0005432865985	25052	14	8F
0005432865991	25052	15	9D
0005432638956	25052	16	9E
0005432638953	25052	17	9F
0005432865984	25052	18	10E
0005432638992	25052	19	10F
0005432865990	25052	20	11D
0005432865992	25052	21	12D
0005432638943	25052	22	12E
0005432638979	25052	23	13D
0005432638957	25052	24	14A
0005432639002	25052	25	14F
0005432638958	25052	26	15D
0005432638930	25052	27	17A
0005432639020	25052	28	17F
0005432865988	25052	29	18A
0005432638954	25052	30	19E
0005432638944	25052	31	20F
0005432328531	3078	1	1A
0005432328547	3078	2	1D
0005432905073	3078	3	1F
0005432328517	3078	4	2A
0005432328546	3078	5	2D
0005432287168	3078	6	3A
0005432328524	3078	7	3C
0005432328525	3078	8	3D
0005432905039	3078	9	3F
0005432328522	3078	10	4A
0005432328507	3078	11	4C
0005432328540	3078	12	4D
0005432328504	3078	13	4E
0005432905065	3078	14	4F
0005432905096	3078	15	5A
0005432328520	3078	16	5C
0005432905037	3078	17	5D
0005432328538	3078	18	5E
0005432328534	3078	19	6A
0005432328503	3078	20	6C
0005432287169	3078	21	6E
0005432328509	3078	22	6F
0005432328530	3078	23	7A
0005432328511	3078	24	7D
0005432328518	3078	25	7E
0005432328527	3078	26	7F
0005432328521	3078	27	8A
0005432328528	3078	28	8C
0005432328549	3078	29	8E
0005432905038	3078	30	9C
0005432328506	3078	31	9D
0005432328548	3078	32	10A
0005432328510	3078	33	10F
0005432905067	3078	34	11A
0005432328508	3078	35	11C
0005432328505	3078	36	11D
0005432328502	3078	37	11E
0005432328535	3078	38	12A
0005432328537	3078	39	12C
0005432905064	3078	40	12D
0005432328523	3078	41	12E
0005432328533	3078	42	12F
0005432328514	3078	43	13A
0005432905049	3078	44	13D
0005432328512	3078	45	13E
0005432328529	3078	46	13F
0005432287171	3078	47	14A
0005433438848	3078	48	14D
0005432905060	3078	49	14E
0005432328519	3078	50	14F
0005432328544	3078	51	15D
0005432328542	3078	52	15E
0005432328513	3078	53	15F
0005432328543	3078	54	16C
0005432328526	3078	55	16D
0005432905095	3078	56	16E
0005432328515	3078	57	16F
0005432328536	3078	58	17A
0005432328539	3078	59	17C
0005432328545	3078	60	17D
0005432287170	3078	61	18A
0005432328532	3078	62	18D
0005432328541	3078	63	19E
0005432328516	3078	64	19F
0005432328501	3078	65	20E
0005432905066	3078	66	20F
0005432328107	31146	1	1A
0005432327908	31146	2	1F
0005432328070	31146	3	2A
0005432328031	31146	4	2C
0005432328116	31146	5	3A
0005432328062	31146	6	3C
0005432328165	31146	7	3D
0005432905104	31146	8	3F
0005433438787	31146	9	4F
0005432328106	31146	10	5A
0005432327994	31146	11	5D
0005432328030	31146	12	5E
0005432328191	31146	13	6C
0005432328040	31146	14	6D
0005432327993	31146	15	6E
0005432328118	31146	16	6F
0005432328271	31146	17	7A
0005432328001	31146	18	7C
0005432328108	31146	19	7D
0005432328091	31146	20	7E
0005432328298	31146	21	7F
0005432328202	31146	22	8A
0005432905107	31146	23	8C
0005433438788	31146	24	8E
0005432327990	31146	25	9A
0005432328183	31146	26	9C
0005432328100	31146	27	9F
0005432328019	31146	28	10A
0005433438778	31146	29	10D
0005432327904	31146	30	10F
0005432327940	31146	31	11A
0005432905108	31146	32	11C
0005432328164	31146	33	11D
0005432054293	31146	34	11F
0005432327933	31146	35	12A
0005432328101	31146	36	12C
0005432328294	31146	37	12D
0005432328210	31146	38	13A
0005433438803	31146	39	13D
0005432328105	31146	40	13E
0005432328092	31146	41	14C
0005432328212	31146	42	14D
0005432328153	31146	43	14E
0005432327941	31146	44	14F
0005432328018	31146	45	15A
0005433438776	31146	46	15C
0005432054292	31146	47	15D
0005432328299	31146	48	15E
0005432328247	31146	49	15F
0005432328192	31146	50	16A
0005432327932	31146	51	16C
0005432328154	31146	52	16E
0005432328331	31146	53	16F
0005432328238	31146	54	17A
0005432328010	31146	55	17C
0005432328029	31146	56	17D
0005432327998	31146	57	17E
0005432327939	31146	58	17F
0005433438777	31146	59	18C
0005432328078	31146	60	18D
0005432328015	31146	61	18E
0005432327907	31146	62	19C
0005432905106	31146	63	19E
0005432327950	31146	64	19F
0005433438802	31146	65	20A
0005432905105	31146	66	20C
0005432327909	31146	67	20D
0005432328039	31146	68	20E
0005432328063	31146	69	20F
0005434309689	6211	1	1F
0005435999192	6211	2	2A
0005432146191	6211	3	2D
0005434309695	6211	4	2F
0005435487566	6211	5	3D
0005435487519	6211	6	4A
0005435999186	6211	7	5A
0005435999188	6211	8	5E
0005435296972	6211	9	6B
0005435487473	6211	10	6C
0005435487606	6211	11	6D
0005434309686	6211	12	7A
0005434309690	6211	13	7D
0005435999184	6211	14	7C
0005435999189	6211	15	7E
0005435999195	6211	16	8B
0005435487518	6211	17	8F
0005435999190	6211	18	8E
0005435296980	6211	19	9C
0005435999187	6211	20	9F
0005435296943	6211	21	10D
0005435296976	6211	22	11A
0005435296987	6211	23	11E
0005435487614	6211	24	11D
0005435999193	6211	25	12A
0005434309693	6211	26	12C
0005435487583	6211	27	12F
0005434309683	6211	28	13A
0005435297000	6211	29	13C
0005434309684	6211	30	13E
0005435999194	6211	31	14A
0005435487608	6211	32	14C
0005435487607	6211	33	14B
0005435487474	6211	34	15B
0005434309685	6211	35	16A
0005435487562	6211	36	16B
0005435999183	6211	37	16E
0005434309688	6211	38	16D
0005435487613	6211	39	16F
0005435487517	6211	40	17A
0005434309691	6211	41	17B
0005435487595	6211	42	17C
0005435487567	6211	43	17F
0005435999182	6211	44	17E
0005434309694	6211	45	18A
0005435999185	6211	46	19A
0005435487481	6211	47	18F
0005435296984	6211	48	19B
0005435487596	6211	49	19D
0005435999191	6211	50	19C
0005435487638	6211	51	19F
0005435487553	6211	52	20A
0005434309687	6211	53	20C
0005435487530	6211	54	22D
0005435487551	6211	55	23B
0005434309692	6211	56	23A
0005435296958	6211	57	23C
0005434309514	19549	1	1A
0005435487727	19549	2	1D
0005435487723	19549	3	2D
0005435487734	19549	4	3A
0005434309597	19549	5	4E
0005435487720	19549	6	5E
0005435487733	19549	7	6E
0005434309590	19549	8	6D
0005435487728	19549	9	7A
0005435999014	19549	10	7F
0005435487739	19549	11	7E
0005435487719	19549	12	8D
0005435487738	19549	13	8F
0005435998975	19549	14	9C
0005435998999	19549	15	9E
0005435487736	19549	16	10D
0005435297034	19549	17	11E
0005435487731	19549	18	11F
0005435999025	19549	19	12E
0005435998989	19549	20	13A
0005435487729	19549	21	15C
0005435297029	19549	22	15D
0005435487722	19549	23	15F
0005435487730	19549	24	16B
0005435297031	19549	25	16E
0005435297033	19549	26	17A
0005435998990	19549	27	17B
0005435999035	19549	28	17D
0005435999042	19549	29	17E
0005434309559	19549	30	18A
0005435998968	19549	31	18E
0005434309516	19549	32	18F
0005435297032	19549	33	19A
0005435487735	19549	34	19B
0005435487721	19549	35	19C
0005435297030	19549	36	19E
0005435487726	19549	37	20E
0005435999026	19549	38	21A
0005435999040	19549	39	21D
0005435487740	19549	40	21E
0005434309558	19549	41	21F
0005435297035	19549	42	22C
0005435487725	19549	43	22D
0005435487737	19549	44	22F
0005434309593	19549	45	23C
0005435487732	19549	46	23D
0005435487724	19549	47	23F
0005434309515	19549	48	23E
0005434565868	1555	1	1A
0005435508313	1555	2	1C
0005433186031	1555	3	1D
0005435517851	1555	4	1F
0005435502222	1555	5	2C
0005435502220	1555	6	2D
0005435508312	1555	7	2F
0005435517847	1555	8	3A
0005434565861	1555	9	3C
0005435502233	1555	10	3D
0005435502241	1555	11	3F
0005434565869	1555	12	4A
0005435508320	1555	13	4D
0005433185994	1555	14	4E
0005433186030	1555	15	4F
0005435517838	1555	16	5A
0005433186021	1555	17	5C
0005435508317	1555	18	5D
0005435502242	1555	19	6A
0005435517842	1555	20	6C
0005433186009	1555	21	6D
0005435517840	1555	22	6E
0005434565860	1555	23	7A
0005435502223	1555	24	7C
0005435502224	1555	25	7F
0005433185997	1555	26	8C
0005435502226	1555	27	8D
0005433186016	1555	28	8E
0005434565867	1555	29	8F
0005435508309	1555	30	9A
0005435508321	1555	31	9C
0005435517849	1555	32	9D
0005434565862	1555	33	9E
0005435502237	1555	34	9F
0005434565865	1555	35	10C
0005435502240	1555	36	10D
0005435517839	1555	37	10E
0005435508311	1555	38	11A
0005435502234	1555	39	11C
0005434565857	1555	40	11D
0005435517844	1555	41	11E
0005435502239	1555	42	11F
0005433185996	1555	43	12A
0005435502229	1555	44	12C
0005435508316	1555	45	12D
0005435502221	1555	46	12E
0005435517843	1555	47	12F
0005435517841	1555	48	13C
0005435508314	1555	49	13D
0005435502235	1555	50	13E
0005435508322	1555	51	14A
0005435517850	1555	52	14C
0005435502236	1555	53	14D
0005434565866	1555	54	15A
0005434565864	1555	55	15C
0005433185993	1555	56	15D
0005435508318	1555	57	15E
0005434565870	1555	58	15F
0005434565859	1555	59	16A
0005435508310	1555	60	16C
0005435502230	1555	61	16D
0005435502219	1555	62	16E
0005434565858	1555	63	16F
0005435508315	1555	64	17C
0005435502231	1555	65	17D
0005433185986	1555	66	17E
0005435502238	1555	67	17F
0005435517837	1555	68	18A
0005435502225	1555	69	18C
0005434565856	1555	70	18D
0005435517848	1555	71	18E
0005435517846	1555	72	18F
0005435502232	1555	73	19C
0005433185985	1555	74	19D
0005435502227	1555	75	19E
0005432291921	1555	76	20A
0005435508319	1555	77	20C
0005435502228	1555	78	20D
0005434565863	1555	79	20E
0005435517845	1555	80	20F
0005434565786	20845	1	1A
0005434565743	20845	2	1C
0005435528966	20845	3	1D
0005435502063	20845	4	1F
0005434565746	20845	5	2A
0005435501973	20845	6	2C
0005435502067	20845	7	2D
0005435545628	20845	8	2F
0005435502100	20845	9	3A
0005435528995	20845	10	3C
0005435502101	20845	11	3D
0005435502018	20845	12	3F
0005433186088	20845	13	4A
0005434565763	20845	14	4C
0005435502040	20845	15	4D
0005435528959	20845	16	4E
0005435528889	20845	17	4F
0005433186089	20845	18	5A
0005435528994	20845	19	5C
0005434565770	20845	20	5D
0005435528965	20845	21	5E
0005435502021	20845	22	6E
0005433186085	20845	23	6F
0005433186083	20845	24	7C
0005435528958	20845	25	7D
0005435545625	20845	26	7F
0005435502028	20845	27	8A
0005435528892	20845	28	8F
0005435501992	20845	29	9A
0005435502036	20845	30	9C
0005435545629	20845	31	9D
0005435528991	20845	32	9E
0005434565783	20845	33	9F
0005435502102	20845	34	10A
0005435545649	20845	35	10C
0005434565695	20845	36	10D
0005435529076	20845	37	10E
0005435528933	20845	38	10F
0005435528941	20845	39	11C
0005433186086	20845	40	11E
0005435528981	20845	41	11F
0005435528967	20845	42	12D
0005435502093	20845	43	12E
0005435528880	20845	44	12F
0005435501961	20845	45	13A
0005435502037	20845	46	13C
0005435502059	20845	47	13D
0005435528973	20845	48	14A
0005434565703	20845	49	14C
0005433186084	20845	50	14D
0005435502062	20845	51	14E
0005435502041	20845	52	15A
0005434565744	20845	53	15C
0005435501950	20845	54	15D
0005435529077	20845	55	15E
0005435545630	20845	56	15F
0005435545648	20845	57	16C
0005435501984	20845	58	17A
0005435501972	20845	59	17C
0005434565753	20845	60	17D
0005434565747	20845	61	17E
0005435501960	20845	62	17F
0005435502052	20845	63	18A
0005435502034	20845	64	18C
0005433186082	20845	65	18D
0005435528879	20845	66	18F
0005434565785	20845	67	19A
0005435501974	20845	68	19C
0005433186087	20845	69	19D
0005435502060	20845	70	19E
0005434565787	20845	71	19F
0005435501962	20845	72	20A
0005435502053	20845	73	20C
0005435528972	20845	74	20D
0005434565784	20845	75	20F
0005435153718	3911	1	1C
0005435153721	3911	2	2B
0005435153713	3911	3	3C
0005435153720	3911	4	3D
0005435153719	3911	5	5B
0005435153717	3911	6	5D
0005435153714	3911	7	7A
0005435153716	3911	8	18B
0005435153722	3911	9	22C
0005435153715	3911	10	22D
0005435931586	21861	1	5A
0005435153640	21861	2	6B
0005435153662	21861	3	7D
0005435931587	21861	4	19D
0005435153663	21861	5	20B
0005435153668	21861	6	21B
0005435931588	21861	7	23B
0005432628789	7200	1	1A
0005435225496	7200	2	2A
0005432628786	7200	3	2B
0005432628793	7200	4	2D
0005432628783	7200	5	3A
0005432628794	7200	6	3C
0005432628787	7200	7	4A
0005435225487	7200	8	4B
0005432628788	7200	9	4C
0005435225472	7200	10	4D
0005432628784	7200	11	5A
0005432628785	7200	12	5C
0005432628795	7200	13	6B
0005435225471	7200	14	6C
0005432628792	7200	15	6D
0005432628791	7200	16	7B
0005435225470	7200	17	7C
0005435225480	7200	18	7D
0005432628790	7200	19	20A
0005432628797	7200	20	20B
0005435225511	7200	21	21B
0005435225481	7200	22	21C
0005432628782	7200	23	21D
0005432628796	7200	24	23A
0005432628677	28129	1	1B
0005432628698	28129	2	1D
0005432628665	28129	3	2A
0005435225555	28129	4	3B
0005432628632	28129	5	3C
0005435225554	28129	6	3D
0005432628646	28129	7	4B
0005435225550	28129	8	4C
0005432628699	28129	9	4D
0005435225557	28129	10	5B
0005432628715	28129	11	6A
0005435225552	28129	12	6C
0005432628645	28129	13	6D
0005432628643	28129	14	7A
0005435225551	28129	15	7B
0005432628701	28129	16	7C
0005435225556	28129	17	18A
0005432628642	28129	18	18B
0005432628655	28129	19	18C
0005435225553	28129	20	18D
0005432628631	28129	21	19B
0005435225558	28129	22	19D
0005432628666	28129	23	20B
0005432628623	28129	24	20D
0005432628747	28129	25	21A
0005432628678	28129	26	21C
0005432628600	28129	27	21D
0005432628697	28129	28	22C
0005435960036	8715	1	3C
0005435960035	8715	2	6D
0005435960034	8715	3	7A
0005434267933	15219	1	1A
0005434267936	15219	2	2D
0005434267934	15219	3	3B
0005434267935	15219	4	3D
0005435960006	15219	5	4C
0005435959983	15219	6	18C
0005435960002	15219	7	20C
0005435960021	15219	8	21B
0005432692928	1209	1	1C
0005432692931	1209	2	2A
0005432692915	1209	3	2F
0005432873181	1209	4	3A
0005432692925	1209	5	3D
0005432692922	1209	6	3C
0005432675077	1209	7	4A
0005432692911	1209	8	3F
0005432677553	1209	9	4C
0005432692929	1209	10	4F
0005432675079	1209	11	4D
0005432692914	1209	12	5A
0005432675078	1209	13	5F
0005432677552	1209	14	6A
0005432873218	1209	15	6F
0005432692908	1209	16	7C
0005432873196	1209	17	7F
0005432873200	1209	18	9C
0005432692921	1209	19	9F
0005432675065	1209	20	10B
0005432692906	1209	21	10E
0005432677555	1209	22	11A
0005432873212	1209	23	10F
0005432692909	1209	24	11B
0005432692910	1209	25	11D
0005432675064	1209	26	11C
0005432692919	1209	27	12B
0005432675069	1209	28	12A
0005432675075	1209	29	12C
0005432873187	1209	30	12E
0005432692934	1209	31	13A
0005432692917	1209	32	12F
0005432692924	1209	33	13B
0005432692935	1209	34	13E
0005432675074	1209	35	14A
0005432692933	1209	36	14C
0005432692936	1209	37	14B
0005432675072	1209	38	14F
0005432677554	1209	39	15A
0005432692916	1209	40	15D
0005432692927	1209	41	15C
0005432692918	1209	42	16A
0005432692920	1209	43	16B
0005432692926	1209	44	16E
0005432692907	1209	45	16D
0005432692930	1209	46	16F
0005432675067	1209	47	17B
0005432675070	1209	48	17D
0005432675071	1209	49	18A
0005432675073	1209	50	18E
0005432873204	1209	51	18D
0005432692923	1209	52	19A
0005432873206	1209	53	18F
0005432675066	1209	54	19C
0005432692913	1209	55	19D
0005432873182	1209	56	19F
0005432675068	1209	57	20B
0005432675076	1209	58	20A
0005432873217	1209	59	20C
0005432692912	1209	60	21B
0005432692932	1209	61	21E
0005432674926	17468	1	1C
0005432692611	17468	2	1F
0005432692657	17468	3	1D
0005432692543	17468	4	2C
0005432674907	17468	5	3A
0005432692609	17468	6	3D
0005432674933	17468	7	3C
0005432674906	17468	8	3F
0005432692709	17468	9	4D
0005432692617	17468	10	4C
0005432674962	17468	11	5A
0005432692745	17468	12	4F
0005432674991	17468	13	5C
0005432692632	17468	14	5F
0005432674990	17468	15	5D
0005432873266	17468	16	6C
0005432677519	17468	17	6D
0005432873263	17468	18	7A
0005432692708	17468	19	6F
0005432692636	17468	20	7C
0005432674940	17468	21	7B
0005432692610	17468	22	8A
0005432692593	17468	23	7F
0005432674908	17468	24	8B
0005432675003	17468	25	8E
0005432692574	17468	26	8C
0005432692589	17468	27	8F
0005432692598	17468	28	9A
0005432674973	17468	29	9D
0005432674930	17468	30	9B
0005432692713	17468	31	9E
0005432873265	17468	32	10A
0005432873261	17468	33	9F
0005432675004	17468	34	10B
0005432873267	17468	35	10E
0005432692616	17468	36	10D
0005432677529	17468	37	11B
0005432674934	17468	38	11A
0005432692705	17468	39	11D
0005432692624	17468	40	11F
0005432692664	17468	41	11E
0005432692575	17468	42	12C
0005432692663	17468	43	12F
0005432692630	17468	44	12E
0005432674939	17468	45	13B
0005432692707	17468	46	13C
0005432692629	17468	47	14C
0005432873264	17468	48	14B
0005432692643	17468	49	14D
0005432692654	17468	50	14F
0005432677528	17468	51	14E
0005432692641	17468	52	15A
0005432692765	17468	53	15D
0005432692658	17468	54	15B
0005432873262	17468	55	15F
0005432692715	17468	56	16C
0005432692652	17468	57	16B
0005432692527	17468	58	16D
0005432674942	17468	59	16F
0005432692655	17468	60	17B
0005432692628	17468	61	18B
0005432692764	17468	62	18D
0005432674929	17468	63	19A
0005432677533	17468	64	18F
0005432873260	17468	65	19B
0005432692625	17468	66	19F
0005432674941	17468	67	20B
0005432692592	17468	68	20A
0005432674951	17468	69	20C
0005432674944	17468	70	20F
0005432674963	17468	71	21B
0005432692623	17468	72	21C
0005433156623	1120	1	2A
0005434435127	1120	2	2C
0005434435121	1120	3	3A
0005433156653	1120	4	3B
0005433156655	1120	5	3D
0005433156632	1120	6	5B
0005433156651	1120	7	5C
0005434435128	1120	8	6A
0005434435120	1120	9	6B
0005434435114	1120	10	7A
0005434435126	1120	11	7C
0005434435115	1120	12	18A
0005434435117	1120	13	18C
0005434435118	1120	14	18D
0005433156624	1120	15	19C
0005434435119	1120	16	19D
0005433156608	1120	17	20A
0005433156682	1120	18	20C
0005434435125	1120	19	20D
0005434435123	1120	20	21D
0005434435124	1120	21	22C
0005434435122	1120	22	22D
0005434435116	1120	23	23A
0005434434999	17297	1	1A
0005434435019	17297	2	1B
0005434434958	17297	3	1C
0005434435007	17297	4	2A
0005434435012	17297	5	2C
0005434434979	17297	6	2D
0005434435013	17297	7	3B
0005434434989	17297	8	3C
0005434435011	17297	9	3D
0005433156718	17297	10	4A
0005434435001	17297	11	4C
0005433156712	17297	12	4D
0005434435018	17297	13	5A
0005433156715	17297	14	5B
0005434434952	17297	15	6A
0005434435042	17297	16	6B
0005434434951	17297	17	6C
0005434434975	17297	18	6D
0005434435006	17297	19	7A
0005434434932	17297	20	7B
0005434435008	17297	21	7C
0005434435014	17297	22	7D
0005434435058	17297	23	18D
0005433156716	17297	24	19A
0005434434987	17297	25	19B
0005433156714	17297	26	19C
0005434435028	17297	27	19D
0005434435027	17297	28	20A
0005434434974	17297	29	20C
0005433156717	17297	30	20D
0005434435043	17297	31	21A
0005434435000	17297	32	21B
0005433156711	17297	33	21C
0005434434978	17297	34	21D
0005433156713	17297	35	22B
0005434434977	17297	36	22C
0005433156719	17297	37	22D
0005434435010	17297	38	23A
0005434434953	17297	39	23B
0005435086801	4098	1	1B
0005435086806	4098	2	1C
0005435928091	4098	3	3A
0005435086803	4098	4	4B
0005435086804	4098	5	7B
0005435086802	4098	6	18A
0005435086805	4098	7	20A
0005435928102	4098	8	20C
0005435086807	4098	9	21A
0005435086808	4098	10	21C
0005435928125	24393	1	4C
0005435928124	24393	2	6A
0005435086700	24393	3	7A
0005435086724	24393	4	7C
0005435086730	24393	5	7D
0005435086729	24393	6	18A
0005435086752	24393	7	18C
0005435928121	24393	8	18D
0005435086726	24393	9	19B
0005435086751	24393	10	22C
0005435928122	24393	11	23A
0005435928123	24393	12	23B
0005435551496	11063	1	4A
0005435098528	11063	2	4H
0005435098526	11063	3	5C
0005435551495	11063	4	5H
0005435551513	11063	5	13D
0005435551497	11063	6	15A
0005435551512	11063	7	20A
0005435098522	11063	8	20E
0005435098524	11063	9	20H
0005435551516	11063	10	21D
0005435551515	11063	11	21F
0005435551505	11063	12	24H
0005435551494	11063	13	27E
0005435551492	11063	14	29D
0005435551522	11063	15	30B
0005435098523	11063	16	33F
0005435551490	11063	17	33H
0005435098525	11063	18	39D
0005435551511	11063	19	39E
0005435706321	2464	1	1C
0005435706312	2464	2	1D
0005433373464	2464	3	1F
0005435706299	2464	4	2A
0005435706327	2464	5	2C
0005435706313	2464	6	2D
0005435706310	2464	7	2F
0005433373410	2464	8	3A
0005433373374	2464	9	3C
0005435706303	2464	10	4C
0005435706301	2464	11	4D
0005435706325	2464	12	4E
0005435706314	2464	13	4F
0005433373375	2464	14	5C
0005433373423	2464	15	5E
0005435706318	2464	16	6F
0005433373398	2464	17	7C
0005435706305	2464	18	7D
0005435706311	2464	19	7F
0005435706319	2464	20	8A
0005433373404	2464	21	8E
0005435706308	2464	22	8F
0005433373425	2464	23	9E
0005435706307	2464	24	10C
0005433373401	2464	25	10D
0005435706300	2464	26	11A
0005435706306	2464	27	11D
0005435706328	2464	28	11F
0005433373409	2464	29	12C
0005433373417	2464	30	12F
0005433373403	2464	31	13A
0005433373435	2464	32	13C
0005433373402	2464	33	13E
0005435706323	2464	34	13F
0005435706326	2464	35	14A
0005433373377	2464	36	14D
0005433373392	2464	37	14E
0005435706297	2464	38	14F
0005435706309	2464	39	15D
0005435706298	2464	40	16C
0005435706304	2464	41	16D
0005435706320	2464	42	16E
0005433373437	2464	43	16F
0005435706324	2464	44	17A
0005433373378	2464	45	17C
0005435706329	2464	46	17E
0005433373424	2464	47	17F
0005435706316	2464	48	18A
0005433373436	2464	49	18C
0005435706302	2464	50	18D
0005435706317	2464	51	18F
0005433373411	2464	52	19C
0005435706322	2464	53	19D
0005433373419	2464	54	19F
0005433373463	2464	55	20E
0005435706315	2464	56	20F
0005433373502	27038	1	1D
0005435706180	27038	2	1F
0005435706141	27038	3	2C
0005435706191	27038	4	2D
0005433373488	27038	5	3A
0005435706150	27038	6	3D
0005433373503	27038	7	3F
0005435706134	27038	8	4A
0005433373487	27038	9	4C
0005433373492	27038	10	4F
0005433373491	27038	11	5D
0005435706205	27038	12	5E
0005433373498	27038	13	6A
0005433373494	27038	14	7E
0005435706193	27038	15	8D
0005435706179	27038	16	8E
0005435706154	27038	17	8F
0005435706123	27038	18	9A
0005435706098	27038	19	9D
0005435706120	27038	20	10C
0005433373486	27038	21	11C
0005433373489	27038	22	11F
0005435706166	27038	23	12C
0005435706278	27038	24	12E
0005433373501	27038	25	12F
0005433373490	27038	26	13A
0005435706130	27038	27	13C
0005435706279	27038	28	13F
0005435706121	27038	29	14A
0005435706118	27038	30	14D
0005435706124	27038	31	15D
0005433373493	27038	32	15E
0005435706190	27038	33	15F
0005433373496	27038	34	16A
0005435706151	27038	35	16E
0005433373497	27038	36	17A
0005435706100	27038	37	17D
0005433373500	27038	38	19A
0005433373499	27038	39	19C
0005435706133	27038	40	19D
0005435706177	27038	41	19F
0005433373495	27038	42	20A
0005435706099	27038	43	20D
0005435706178	27038	44	20E
0005435706189	27038	45	20F
0005433261416	1308	1	1F
0005434964151	1308	2	2A
0005434964149	1308	3	2H
0005434964150	1308	4	3B
0005434964129	1308	5	5A
0005433261411	1308	6	4H
0005434964140	1308	7	5C
0005433261442	1308	8	5F
0005434964157	1308	9	11B
0005434964160	1308	10	12B
0005434964139	1308	11	12E
0005432279262	1308	12	12H
0005434964142	1308	13	13D
0005434964158	1308	14	14E
0005434964147	1308	15	14H
0005434964143	1308	16	15G
0005433261447	1308	17	17D
0005433261448	1308	18	18A
0005433261467	1308	19	18G
0005432279263	1308	20	19D
0005434964130	1308	21	20F
0005433261415	1308	22	21G
0005433261456	1308	23	22B
0005434964162	1308	24	22A
0005434964161	1308	25	22E
0005434964134	1308	26	23D
0005434964146	1308	27	23F
0005434964153	1308	28	24E
0005434964152	1308	29	24D
0005434964137	1308	30	24F
0005434964166	1308	31	27B
0005434964135	1308	32	27G
0005434964155	1308	33	28B
0005434964164	1308	34	28E
0005434964159	1308	35	28H
0005434964138	1308	36	29A
0005434964148	1308	37	29D
0005434964163	1308	38	30B
0005433261480	1308	39	30F
0005434964154	1308	40	31B
0005433261457	1308	41	32B
0005434964165	1308	42	32A
0005433261477	1308	43	33A
0005433261426	1308	44	34A
0005434964136	1308	45	34B
0005434964156	1308	46	34F
0005434964131	1308	47	34H
0005433261468	1308	48	35E
0005434964167	1308	49	35F
0005433261409	1308	50	36D
0005434964141	1308	51	36F
0005433261441	1308	52	36E
0005434964132	1308	53	36G
0005434964144	1308	54	37D
0005434964133	1308	55	38A
0005434964145	1308	56	38E
0005432279264	1308	57	38H
0005433261469	1308	58	39F
0005434964030	18236	1	1F
0005434963922	18236	2	1G
0005433261506	18236	3	2A
0005433261530	18236	4	2H
0005434963957	18236	5	2G
0005434963982	18236	6	3A
0005434964007	18236	7	4F
0005434963902	18236	8	4G
0005434964023	18236	9	5A
0005433261504	18236	10	5G
0005433261529	18236	11	5H
0005433261519	18236	12	9B
0005434963905	18236	13	9H
0005434963993	18236	14	9G
0005434963932	18236	15	11D
0005434963947	18236	16	12D
0005433261523	18236	17	12E
0005434963971	18236	18	12G
0005433261515	18236	19	13B
0005434963941	18236	20	14B
0005433261508	18236	21	14G
0005434964057	18236	22	14H
0005434963981	18236	23	15D
0005434963918	18236	24	16D
0005434963978	18236	25	16E
0005434963962	18236	26	16G
0005433261512	18236	27	17G
0005433261528	18236	28	18B
0005433261522	18236	29	18A
0005433261521	18236	30	19B
0005434963969	18236	31	20A
0005434963973	18236	32	20D
0005434963938	18236	33	20F
0005433261509	18236	34	20H
0005433261514	18236	35	21B
0005433261505	18236	36	21E
0005434963974	18236	37	21D
0005434963916	18236	38	22A
0005433261507	18236	39	22B
0005434963934	18236	40	22E
0005434964039	18236	41	23A
0005433261524	18236	42	23D
0005434963988	18236	43	23G
0005434964064	18236	44	24B
0005434963965	18236	45	24E
0005433261532	18236	46	24F
0005433261513	18236	47	25D
0005433261518	18236	48	25E
0005433261520	18236	49	25F
0005434963929	18236	50	27E
0005434964019	18236	51	28A
0005434963915	18236	52	28E
0005434963991	18236	53	28G
0005433261516	18236	54	29A
0005434964028	18236	55	29E
0005433261517	18236	56	30B
0005434963895	18236	57	30D
0005433261527	18236	58	30G
0005434963935	18236	59	31B
0005434963990	18236	60	31F
0005434963956	18236	61	31E
0005433261526	18236	62	32B
0005434963937	18236	63	32F
0005433261525	18236	64	33A
0005434963904	18236	65	32H
0005434963946	18236	66	34A
0005433261510	18236	67	34B
0005433261533	18236	68	34G
0005434963907	18236	69	35E
0005434964029	18236	70	35D
0005434964010	18236	71	35H
0005433261511	18236	72	36B
0005434963942	18236	73	36F
0005434964011	18236	74	36E
0005434963970	18236	75	37D
0005434963977	18236	76	37H
0005434963989	18236	77	38A
0005433261531	18236	78	38E
0005434963903	18236	79	38G
0005434625927	4823	1	1D
0005435907451	4823	2	1F
0005435907452	4823	3	4A
0005433194830	4823	4	4C
0005434625925	4823	5	5D
0005434625922	4823	6	6F
0005434625929	4823	7	8F
0005434625928	4823	8	9A
0005435907438	4823	9	11D
0005434625921	4823	10	11E
0005434625926	4823	11	17F
0005434625924	4823	12	18A
0005434625923	4823	13	18C
0005433194829	4823	14	18E
0005433194821	4823	15	19A
0005435907440	4823	16	20E
0005434625920	4823	17	20F
0005434625804	32909	1	2D
0005435907489	32909	2	2F
0005434625816	32909	3	4C
0005435907485	32909	4	4F
0005434625847	32909	5	9A
0005435907488	32909	6	11E
0005434625865	32909	7	11F
0005434625871	32909	8	13A
0005435907486	32909	9	14C
0005435907487	32909	10	15E
0005434625848	32909	11	18A
0005434625857	32909	12	19A
0005435907490	32909	13	19C
0005434625870	32909	14	19D
0005432195684	13773	1	1A
0005435937372	13773	2	1B
0005435784914	13773	3	1C
0005435937369	13773	4	1D
0005435784905	13773	5	2A
0005435784884	13773	6	2B
0005435937368	13773	7	2D
0005435784965	13773	8	3A
0005432195685	13773	9	3B
0005435937370	13773	10	3C
0005435784967	13773	11	3D
0005435784861	13773	12	4A
0005435784862	13773	13	4B
0005435785006	13773	14	4C
0005435784752	13773	15	5B
0005435784966	13773	16	5C
0005435784934	13773	17	5D
0005435784962	13773	18	6A
0005435937367	13773	19	6B
0005435784935	13773	20	6C
0005435784946	13773	21	6D
0005435784994	13773	22	7B
0005435784915	13773	23	7C
0005435784842	13773	24	7D
0005435937374	13773	25	18A
0005435784869	13773	26	18B
0005435784999	13773	27	18C
0005435785005	13773	28	18D
0005435937371	13773	29	19A
0005435784910	13773	30	19B
0005435784786	13773	31	19D
0005435784928	13773	32	20C
0005435784751	13773	33	20D
0005435784741	13773	34	21A
0005435785007	13773	35	21B
0005435937373	13773	36	21C
0005435784964	13773	37	21D
0005435784923	13773	38	22A
0005435784883	13773	39	22B
0005435784887	13773	40	23A
0005435784796	13773	41	23B
0005435785159	27455	1	1A
0005432190611	27455	2	1B
0005435785177	27455	3	1C
0005435785170	27455	4	1D
0005435785154	27455	5	2A
0005435785168	27455	6	2B
0005435937309	27455	7	2C
0005435785174	27455	8	3A
0005432190609	27455	9	3B
0005435785156	27455	10	3C
0005432190607	27455	11	3D
0005435785158	27455	12	4A
0005432190610	27455	13	4C
0005435785153	27455	14	4D
0005435785176	27455	15	5A
0005435785185	27455	16	5C
0005435785157	27455	17	5D
0005435785169	27455	18	6B
0005435785183	27455	19	6A
0005435785180	27455	20	6C
0005435785167	27455	21	6D
0005435785181	27455	22	7A
0005435785171	27455	23	7C
0005435785184	27455	24	7D
0005435785165	27455	25	18A
0005435785186	27455	26	18B
0005435787343	27455	27	18D
0005432190608	27455	28	19B
0005435785182	27455	29	19C
0005435787341	27455	30	19D
0005435937312	27455	31	20A
0005435785161	27455	32	20B
0005435785179	27455	33	20C
0005435785173	27455	34	20D
0005435785162	27455	35	21A
0005435785163	27455	36	21B
0005435785178	27455	37	21C
0005435785175	27455	38	21D
0005435787342	27455	39	22A
0005435785164	27455	40	22B
0005435785155	27455	41	22C
0005435785166	27455	42	22D
0005435785160	27455	43	23A
0005435785172	27455	44	23B
0005434406714	20300	1	1A
0005435311032	20300	2	1C
0005434406726	20300	3	1D
0005434406981	20300	4	1F
0005434407162	20300	5	2A
0005434406966	20300	6	2C
0005434406970	20300	7	2F
0005434406964	20300	8	3A
0005434406715	20300	9	3C
0005434406849	20300	10	3F
0005434407022	20300	11	4A
0005434406941	20300	12	4C
0005434406947	20300	13	4D
0005434406721	20300	14	4E
0005435311033	20300	15	4F
0005434406904	20300	16	5A
0005434407324	20300	17	5C
0005435311027	20300	18	5D
0005434406976	20300	19	5F
0005434407001	20300	20	6A
0005434407023	20300	21	6C
0005434406905	20300	22	6D
0005434407043	20300	23	6F
0005434406865	20300	24	7A
0005434406856	20300	25	7C
0005434407280	20300	26	7D
0005434407002	20300	27	7E
0005434406790	20300	28	7F
0005434406798	20300	29	8D
0005434407044	20300	30	8F
0005434407102	20300	31	9C
0005434406841	20300	32	9D
0005434407202	20300	33	9E
0005434406937	20300	34	10C
0005435311029	20300	35	10D
0005434406758	20300	36	10E
0005434406942	20300	37	11A
0005434407024	20300	38	11C
0005434407042	20300	39	11D
0005434406705	20300	40	11E
0005434406854	20300	41	11F
0005434406791	20300	42	12C
0005434406997	20300	43	12D
0005434407323	20300	44	12E
0005432058366	20300	45	12F
0005434407188	20300	46	13A
0005435311026	20300	47	13C
0005434406831	20300	48	14A
0005434406980	20300	49	14C
0005434407027	20300	50	14D
0005434406792	20300	51	14E
0005434406913	20300	52	14F
0005434407239	20300	53	15A
0005434406720	20300	54	15C
0005435311034	20300	55	15D
0005434406974	20300	56	15E
0005434406925	20300	57	16A
0005434406815	20300	58	16C
0005434406836	20300	59	16D
0005434406839	20300	60	16E
0005434407128	20300	61	16F
0005434407028	20300	62	17A
0005434407133	20300	63	17C
0005432058367	20300	64	17D
0005434406940	20300	65	17F
0005434406840	20300	66	18A
0005432058364	20300	67	18D
0005434407012	20300	68	18E
0005434407189	20300	69	18F
0005435311031	20300	70	19A
0005434406944	20300	71	19C
0005434407146	20300	72	19D
0005432058365	20300	73	19E
0005435311030	20300	74	19F
0005434406979	20300	75	20A
0005434406813	20300	76	20C
0005435311028	20300	77	20D
0005434406759	20300	78	20F
0005434407520	27016	1	1A
0005434407490	27016	2	1D
0005435310886	27016	3	1F
0005434407507	27016	4	2A
0005434407512	27016	5	2C
0005434407484	27016	6	2D
0005434407524	27016	7	3A
0005434407477	27016	8	3C
0005434407538	27016	9	3D
0005435310901	27016	10	3F
0005434407498	27016	11	4A
0005434407522	27016	12	4C
0005434407487	27016	13	4D
0005434407495	27016	14	4E
0005434407513	27016	15	4F
0005434407529	27016	16	5A
0005434407530	27016	17	5D
0005434407510	27016	18	5E
0005435310921	27016	19	5F
0005435310910	27016	20	6A
0005434407489	27016	21	6C
0005434407537	27016	22	6D
0005434407499	27016	23	6E
0005432153912	27016	24	7A
0005434407494	27016	25	7D
0005434407511	27016	26	7E
0005434407528	27016	27	7F
0005434407491	27016	28	8A
0005434407482	27016	29	8D
0005434407509	27016	30	8E
0005435310908	27016	31	8F
0005434407501	27016	32	9A
0005434407483	27016	33	9C
0005435310909	27016	34	9D
0005432153906	27016	35	9E
0005435310868	27016	36	9F
0005434407515	27016	37	10A
0005434407532	27016	38	10C
0005432153910	27016	39	10D
0005435310920	27016	40	10E
0005432153909	27016	41	10F
0005434407527	27016	42	11A
0005434407525	27016	43	11C
0005434407485	27016	44	11D
0005435310839	27016	45	11E
0005434407516	27016	46	11F
0005434407506	27016	47	12A
0005434407531	27016	48	12C
0005435310877	27016	49	12D
0005434407521	27016	50	12E
0005435310874	27016	51	12F
0005434407539	27016	52	13A
0005435310906	27016	53	13C
0005434407523	27016	54	13D
0005434407488	27016	55	13E
0005434407496	27016	56	13F
0005432153911	27016	57	14A
0005435310866	27016	58	14C
0005434407540	27016	59	14D
0005434407533	27016	60	14F
0005434407519	27016	61	15A
0005432153907	27016	62	15C
0005434407514	27016	63	15D
0005434407481	27016	64	15E
0005432153908	27016	65	15F
0005434407504	27016	66	16A
0005434407500	27016	67	16C
0005434407536	27016	68	16D
0005434407518	27016	69	16F
0005435310875	27016	70	17A
0005434407535	27016	71	17C
0005434407502	27016	72	17D
0005434407505	27016	73	17F
0005435310890	27016	74	18A
0005435310883	27016	75	18C
0005434407508	27016	76	18D
0005434407534	27016	77	18E
0005434407493	27016	78	18F
0005434407478	27016	79	19A
0005434407479	27016	80	19C
0005434407503	27016	81	19D
0005434407480	27016	82	19E
0005434407492	27016	83	19F
0005434407517	27016	84	20A
0005434407497	27016	85	20C
0005434407486	27016	86	20D
0005435310900	27016	87	20E
0005434407526	27016	88	20F
0005432109691	5698	1	1F
0005434319341	5698	2	3A
0005434319339	5698	3	3C
0005434319332	5698	4	4A
0005433123605	5698	5	5A
0005433123659	5698	6	5D
0005433123688	5698	7	6A
0005433123633	5698	8	6D
0005433123669	5698	9	6E
0005434319340	5698	10	7D
0005434319330	5698	11	7E
0005434311210	5698	12	8C
0005434319337	5698	13	8D
0005433123675	5698	14	8F
0005433123655	5698	15	9D
0005433123668	5698	16	9E
0005433123674	5698	17	10E
0005433123629	5698	18	11A
0005433123680	5698	19	11D
0005433123676	5698	20	11E
0005432109692	5698	21	11F
0005434319336	5698	22	12A
0005433123630	5698	23	12C
0005433123628	5698	24	12F
0005432109693	5698	25	13A
0005434319334	5698	26	13C
0005433123625	5698	27	14E
0005434311211	5698	28	15E
0005434319329	5698	29	16D
0005433123687	5698	30	16E
0005434319333	5698	31	17E
0005433123646	5698	32	18F
0005434319338	5698	33	19F
0005434319335	5698	34	20A
0005434319331	5698	35	20C
0005434319342	5698	36	20E
0005433123854	15667	1	1A
0005434319243	15667	2	1D
0005434319186	15667	3	2A
0005433123848	15667	4	2C
0005433123855	15667	5	3C
0005434319236	15667	6	4D
0005434319224	15667	7	4E
0005433123858	15667	8	5A
0005434319181	15667	9	5E
0005434319232	15667	10	5F
0005434319217	15667	11	6A
0005434319212	15667	12	6D
0005434319220	15667	13	6E
0005434319159	15667	14	6F
0005433123850	15667	15	7F
0005434312291	15667	16	8A
0005434319185	15667	17	8C
0005433123856	15667	18	8D
0005434319216	15667	19	9A
0005433123865	15667	20	9C
0005433123849	15667	21	9D
0005434319201	15667	22	9F
0005434319187	15667	23	9E
0005433123862	15667	24	10A
0005434311181	15667	25	10C
0005433123846	15667	26	11A
0005433123844	15667	27	11D
0005434319219	15667	28	12F
0005433123847	15667	29	13E
0005434319228	15667	30	13F
0005433123863	15667	31	14A
0005433123851	15667	32	14D
0005433123853	15667	33	14E
0005433123857	15667	34	15A
0005433123845	15667	35	15C
0005433123861	15667	36	15D
0005433123860	15667	37	15E
0005433123852	15667	38	16A
0005433123864	15667	39	17E
0005433123859	15667	40	19D
0005434319158	15667	41	19E
0005435220293	24979	1	1C
0005435217683	24979	2	1D
0005435220284	24979	3	3C
0005435220289	24979	4	4A
0005435220294	24979	5	4D
0005435221506	24979	6	7B
0005435220291	24979	7	7D
0005435220285	24979	8	18B
0005435217684	24979	9	21C
0005435221497	24979	10	21D
0005435217678	24979	11	22C
0005435220290	24979	12	23A
0005434189118	8980	1	1A
0005434189088	8980	2	2C
0005434189108	8980	3	3D
0005434484320	8980	4	4C
0005434189117	8980	5	4D
0005434484321	8980	6	6A
0005434484322	8980	7	18C
0005434189101	8980	8	19A
0005434484323	8980	9	19D
0005434189100	8980	10	20D
0005434189090	8980	11	22B
0005434189094	8980	12	22C
0005434484324	8980	13	23B
0005434484278	16668	1	1D
0005434189156	16668	2	3A
0005434484275	16668	3	3C
0005434484268	16668	4	4D
0005434484253	16668	5	5A
0005434189158	16668	6	6B
0005434484270	16668	7	6C
0005434189155	16668	8	6D
0005434189154	16668	9	7C
0005434189153	16668	10	7D
0005434484274	16668	11	19C
0005434484254	16668	12	19D
0005434189157	16668	13	22A
0005433123856	7549	1	1C
0005433123864	7549	2	1D
0005433123846	7549	3	3F
0005433123852	7549	4	4D
0005433123858	7549	5	4F
0005433123854	7549	6	6C
0005433123862	7549	7	7C
0005433123847	7549	8	7E
0005433123857	7549	9	9D
0005433123851	7549	10	11D
0005433722114	7549	11	11E
0005433123850	7549	12	12D
0005433123853	7549	13	13F
0005433123865	7549	14	15A
0005433722108	7549	15	14F
0005433123861	7549	16	15D
0005433123863	7549	17	15F
0005433123845	7549	18	16C
0005433123855	7549	19	16D
0005433123860	7549	20	17A
0005433123844	7549	21	17C
0005433123849	7549	22	17D
0005433123859	7549	23	18C
0005433123848	7549	24	19D
0005433722113	7549	25	20F
0005432720812	7546	1	1A
0005432692968	7546	2	1C
0005433449874	7546	3	1F
0005432720790	7546	4	2A
0005433449890	7546	5	2D
0005432720793	7546	6	2F
0005432720789	7546	7	3A
0005432720804	7546	8	3C
0005432720792	7546	9	3D
0005432720796	7546	10	3F
0005432692955	7546	11	4A
0005432720797	7546	12	4C
0005432720801	7546	13	4D
0005432692940	7546	14	4E
0005432692958	7546	15	4F
0005433449879	7546	16	5A
0005432692966	7546	17	5C
0005432692960	7546	18	5D
0005432720803	7546	19	5F
0005432720800	7546	20	6A
0005433449888	7546	21	6C
0005432692964	7546	22	6D
0005432692963	7546	23	6E
0005433449875	7546	24	6F
0005432720810	7546	25	7A
0005433449893	7546	26	7C
0005432720788	7546	27	7D
0005432720791	7546	28	7E
0005432692946	7546	29	7F
0005433449880	7546	30	8A
0005432692948	7546	31	8C
0005433449873	7546	32	8D
0005433449884	7546	33	8E
0005432692939	7546	34	8F
0005432692961	7546	35	9A
0005432692967	7546	36	9C
0005432692943	7546	37	9D
0005432071560	7546	38	9E
0005433449887	7546	39	9F
0005433449886	7546	40	10A
0005433449885	7546	41	10C
0005432720794	7546	42	10D
0005432692947	7546	43	10F
0005432720809	7546	44	11A
0005432720799	7546	45	11C
0005432720807	7546	46	11D
0005433449877	7546	47	11E
0005432692949	7546	48	11F
0005432692944	7546	49	12A
0005432071562	7546	50	12C
0005432071561	7546	51	12E
0005432720785	7546	52	12F
0005433449878	7546	53	13A
0005432692942	7546	54	13C
0005433449876	7546	55	13D
0005432720808	7546	56	13E
0005432692956	7546	57	13F
0005432720805	7546	58	14A
0005432692954	7546	59	14C
0005433449882	7546	60	14D
0005433449883	7546	61	14E
0005432692953	7546	62	14F
0005433449892	7546	63	15A
0005432692962	7546	64	15C
0005432692951	7546	65	15D
0005432692957	7546	66	15E
0005432692941	7546	67	16A
0005433449889	7546	68	16D
0005432720811	7546	69	16E
0005432692959	7546	70	16F
0005432720806	7546	71	17C
0005432720787	7546	72	17D
0005432692937	7546	73	17E
0005432692950	7546	74	18A
0005432692952	7546	75	18E
0005432720795	7546	76	18F
0005432692945	7546	77	19A
0005432692965	7546	78	19C
0005433449894	7546	79	19D
0005433449881	7546	80	19E
0005433449891	7546	81	19F
0005432720802	7546	82	20A
0005432692938	7546	83	20C
0005432720786	7546	84	20D
0005432720798	7546	85	20F
0005432692625	30340	1	1A
0005433449715	30340	2	1C
0005433449684	30340	3	1D
0005432692764	30340	4	1F
0005433449689	30340	5	2A
0005432692705	30340	6	2C
0005433449589	30340	7	2D
0005433449663	30340	8	2F
0005433449714	30340	9	3A
0005432692623	30340	10	3F
0005432692630	30340	11	4C
0005432692593	30340	12	4D
0005433449690	30340	13	5D
0005433449662	30340	14	5F
0005433449716	30340	15	6C
0005432692765	30340	16	6D
0005432692624	30340	17	6E
0005432692657	30340	18	6F
0005433449764	30340	19	7D
0005432692709	30340	20	7E
0005432692610	30340	21	7F
0005432692641	30340	22	8C
0005432692713	30340	23	8D
0005432692609	30340	24	8E
0005433449736	30340	25	8F
0005432692636	30340	26	9A
0005432692527	30340	27	9D
0005432692543	30340	28	9E
0005432692663	30340	29	10D
0005432692652	30340	30	10E
0005432692643	30340	31	11A
0005433449795	30340	32	12C
0005432692598	30340	33	12E
0005433449686	30340	34	13A
0005432692715	30340	35	13D
0005432692664	30340	36	13E
0005433449727	30340	37	13F
0005432692592	30340	38	14C
0005433449702	30340	39	14D
0005433449697	30340	40	14E
0005432692574	30340	41	14F
0005432692745	30340	42	15C
0005433449706	30340	43	15E
0005432692632	30340	44	15F
0005432692617	30340	45	16C
0005433449685	30340	46	16D
0005432692611	30340	47	16E
0005432692708	30340	48	16F
0005433449698	30340	49	17A
0005432692575	30340	50	17C
0005433449713	30340	51	17E
0005432692655	30340	52	17F
0005432692616	30340	53	18A
0005433449699	30340	54	18D
0005432692654	30340	55	18E
0005432692707	30340	56	18F
0005433449730	30340	57	19A
0005433449647	30340	58	19C
0005432692658	30340	59	19D
0005432692589	30340	60	19F
0005432692629	30340	61	20A
0005432692628	30340	62	20D
0005433449700	30340	63	20E
0005433449679	30340	64	20F
0005433123669	30339	1	1F
0005433123625	30339	2	2A
0005432720644	30339	3	2C
0005433123633	30339	4	2F
0005432720528	30339	5	3A
0005432720645	30339	6	3D
0005433123680	30339	7	3F
0005432720607	30339	8	4A
0005433123605	30339	9	4D
0005433722199	30339	10	5C
0005433722198	30339	11	5E
0005432720585	30339	12	5F
0005433123674	30339	13	6D
0005432720690	30339	14	7A
0005432720649	30339	15	7C
0005432720686	30339	16	7F
0005433123687	30339	17	8C
0005432720527	30339	18	9C
0005432720691	30339	19	9E
0005432720646	30339	20	10D
0005433123668	30339	21	10E
0005433123675	30339	22	11A
0005432720493	30339	23	11F
0005432720660	30339	24	12F
0005433722197	30339	25	13A
0005432720728	30339	26	13C
0005432720699	30339	27	13D
0005433123659	30339	28	13F
0005432720594	30339	29	14A
0005433123655	30339	30	14D
0005433123688	30339	31	14E
0005432720545	30339	32	15A
0005432720544	30339	33	15E
0005433123646	30339	34	16A
0005432720492	30339	35	16C
0005433123676	30339	36	16D
0005432720589	30339	37	16F
0005432720529	30339	38	17C
0005433123629	30339	39	18C
0005433123628	30339	40	18E
0005433123630	30339	41	18F
0005432720593	30339	42	19F
0005432720606	30339	43	19E
0005432720708	30339	44	20A
0005432720540	30339	45	20C
0005433524991	1408	1	1A
0005434586524	1408	2	1C
0005434586500	1408	3	1F
0005434586506	1408	4	2A
0005434586514	1408	5	2C
0005433724788	1408	6	2D
0005433192921	1408	7	3A
0005432270993	1408	8	3C
0005433724789	1408	9	3D
0005432270992	1408	10	3F
0005433724787	1408	11	4A
0005433192920	1408	12	4C
0005434586510	1408	13	4E
0005434513569	1408	14	5A
0005432968819	1408	15	5C
0005434586520	1408	16	5D
0005433192909	1408	17	6C
0005433192922	1408	18	6D
0005432927905	1408	19	6E
0005433524995	1408	20	6F
0005434586513	1408	21	7C
0005434586521	1408	22	7E
0005434586518	1408	23	7F
0005434586517	1408	24	8A
0005432927904	1408	25	8D
0005433525002	1408	26	8E
0005433525000	1408	27	9A
0005434586523	1408	28	9C
0005434586522	1408	29	9D
0005434514958	1408	30	9E
0005434586502	1408	31	9F
0005432927911	1408	32	10A
0005434586519	1408	33	10C
0005433192900	1408	34	10E
0005433524996	1408	35	10D
0005433724790	1408	36	11A
0005432270994	1408	37	11C
0005433192889	1408	38	11D
0005433524994	1408	39	11E
0005432927898	1408	40	11F
0005434586501	1408	41	12C
0005434586508	1408	42	12D
0005433192888	1408	43	12E
0005434586504	1408	44	12F
0005433524999	1408	45	13D
0005433524992	1408	46	13F
0005434514957	1408	47	14C
0005433524993	1408	48	15A
0005434513570	1408	49	15E
0005433524998	1408	50	15F
0005432968815	1408	51	16D
0005433192848	1408	52	16F
0005433524997	1408	53	17D
0005434586516	1408	54	17E
0005434586511	1408	55	17F
0005434586515	1408	56	18A
0005434586525	1408	57	18C
0005434586512	1408	58	18D
0005434586503	1408	59	18E
0005434586505	1408	60	18F
0005433192849	1408	61	19D
0005434586507	1408	62	19F
0005433724791	1408	63	20A
0005433525001	1408	64	20C
0005434586509	1408	65	20E
0005433192994	18520	1	1A
0005433724735	18520	2	1D
0005432968831	18520	3	2A
0005433192999	18520	4	2C
0005434586274	18520	5	3A
0005432927958	18520	6	3C
0005434586340	18520	7	3D
0005434586288	18520	8	3F
0005434586277	18520	9	4C
0005434586324	18520	10	4D
0005433192987	18520	11	4F
0005434586215	18520	12	5C
0005434586297	18520	13	5D
0005434586305	18520	14	5E
0005434586330	18520	15	5F
0005433724729	18520	16	6C
0005433192995	18520	17	6D
0005434586301	18520	18	6E
0005433192992	18520	19	6F
0005434586241	18520	20	7A
0005434586230	18520	21	7C
0005434586231	18520	22	7F
0005434586276	18520	23	8C
0005434586388	18520	24	8E
0005434586273	18520	25	8F
0005434586318	18520	26	9C
0005433192996	18520	27	9D
0005434586342	18520	28	9E
0005434586353	18520	29	10A
0005433524868	18520	30	10C
0005434586308	18520	31	10D
0005434586331	18520	32	10F
0005434586338	18520	33	11C
0005433524925	18520	34	11D
0005433724728	18520	35	11E
0005432927957	18520	36	11F
0005434586339	18520	37	12C
0005434586321	18520	38	12D
0005432927956	18520	39	12E
0005434586310	18520	40	12F
0005434586343	18520	41	13A
0005434586272	18520	42	13D
0005434586304	18520	43	13F
0005433524926	18520	44	14C
0005433192991	18520	45	14D
0005433192997	18520	46	14E
0005433524908	18520	47	14F
0005434586302	18520	48	15A
0005432968830	18520	49	15D
0005433192989	18520	50	15E
0005432927955	18520	51	15F
0005434586404	18520	52	16A
0005434514929	18520	53	16C
0005434586389	18520	54	16F
0005432927959	18520	55	17A
0005433724732	18520	56	17C
0005433192988	18520	57	17D
0005432927954	18520	58	17F
0005433524867	18520	59	18A
0005433524869	18520	60	18F
0005434586461	18520	61	19A
0005434586354	18520	62	19C
0005434586341	18520	63	19D
0005433192990	18520	64	19E
0005433192998	18520	65	20A
0005433192993	18520	66	20E
0005433724743	18520	67	20F
0005435302147	11467	1	1A
0005434344040	11467	2	1B
0005434344044	11467	3	1C
0005434344045	11467	4	1D
0005434344059	11467	5	2A
0005434344026	11467	6	2B
0005434344057	11467	7	2C
0005435302122	11467	8	2D
0005434344055	11467	9	3A
0005435304992	11467	10	3B
0005434344058	11467	11	3C
0005434344051	11467	12	3D
0005434344060	11467	13	4A
0005434344041	11467	14	4B
0005434344036	11467	15	4C
0005434142595	11467	16	4D
0005434344035	11467	17	5A
0005434344043	11467	18	5B
0005434344053	11467	19	5C
0005434344056	11467	20	5D
0005434344034	11467	21	6A
0005434344052	11467	22	6C
0005434344042	11467	23	6D
0005434344032	11467	24	7A
0005435302148	11467	25	7C
0005434344024	11467	26	7D
0005434344025	11467	27	18A
0005435302123	11467	28	18B
0005434344039	11467	29	18C
0005434142594	11467	30	18D
0005434142593	11467	31	19A
0005434344048	11467	32	19B
0005434344037	11467	33	19C
0005434344038	11467	34	19D
0005435302121	11467	35	20A
0005434344029	11467	36	20B
0005434344027	11467	37	20C
0005434344047	11467	38	20D
0005434344028	11467	39	21A
0005434344033	11467	40	21B
0005434344030	11467	41	21C
0005434344054	11467	42	21D
0005434344046	11467	43	22A
0005434344050	11467	44	22B
0005434142596	11467	45	22C
0005434344049	11467	46	22D
0005434344031	11467	47	23B
0005434343618	29752	1	1A
0005435305007	29752	2	1B
0005434343867	29752	3	1C
0005434343713	29752	4	2A
0005434343758	29752	5	2B
0005434343759	29752	6	2C
0005434343797	29752	7	2D
0005434343668	29752	8	3A
0005434343811	29752	9	3B
0005434142549	29752	10	3C
0005435304140	29752	11	4A
0005434343817	29752	12	4C
0005435305009	29752	13	5A
0005435304141	29752	14	5B
0005434343698	29752	15	5C
0005435304143	29752	16	5D
0005435304142	29752	17	6B
0005434142545	29752	18	7B
0005435304144	29752	19	7C
0005434343725	29752	20	7D
0005434343765	29752	21	18A
0005434343796	29752	22	18B
0005435304139	29752	23	18C
0005434343726	29752	24	18D
0005434343781	29752	25	19A
0005434343810	29752	26	19B
0005434343661	29752	27	19C
0005434343807	29752	28	20A
0005434343751	29752	29	20B
0005434343808	29752	30	20C
0005434343601	29752	31	20D
0005434343895	29752	32	21A
0005434343816	29752	33	21B
0005434343731	29752	34	21C
0005434142546	29752	35	21D
0005434343868	29752	36	22A
0005434343778	29752	37	22B
0005434343733	29752	38	22C
0005434343712	29752	39	22D
0005435305008	29752	40	23A
0005434343869	29752	41	23B
0005435824528	1267	1	1A
0005435824523	1267	2	1F
0005435824534	1267	3	2D
0005435824514	1267	4	3C
0005433415489	1267	5	4C
0005435824511	1267	6	5C
0005435824535	1267	7	6A
0005435824519	1267	8	6D
0005435824522	1267	9	6F
0005435824532	1267	10	7C
0005435824516	1267	11	7E
0005435824525	1267	12	7D
0005433415454	1267	13	8C
0005435824520	1267	14	9B
0005433415469	1267	15	9D
0005433415483	1267	16	10C
0005432284546	1267	17	10F
0005435824509	1267	18	11B
0005433415509	1267	19	12A
0005435824513	1267	20	12C
0005432284547	1267	21	12E
0005435824510	1267	22	13A
0005435824531	1267	23	14A
0005435824517	1267	24	14B
0005435824529	1267	25	14D
0005435824530	1267	26	14C
0005435824515	1267	27	14E
0005435824533	1267	28	15B
0005433415523	1267	29	15D
0005435824521	1267	30	15C
0005433415536	1267	31	16A
0005435824526	1267	32	17D
0005435824524	1267	33	18B
0005433415474	1267	34	18D
0005433415482	1267	35	19A
0005433415481	1267	36	19B
0005435824518	1267	37	19D
0005433415473	1267	38	20B
0005435824527	1267	39	20D
0005435824512	1267	40	21F
0005435824266	18014	1	1F
0005435824307	18014	2	1D
0005435824407	18014	3	2C
0005433415598	18014	4	4A
0005433415595	18014	5	5C
0005433415597	18014	6	6B
0005433415603	18014	7	6A
0005435824239	18014	8	6C
0005435824350	18014	9	6F
0005435824280	18014	10	8A
0005433415604	18014	11	8D
0005433415605	18014	12	8F
0005435824410	18014	13	9B
0005433415600	18014	14	9C
0005435824351	18014	15	9F
0005433415602	18014	16	9E
0005435824349	18014	17	10C
0005435824268	18014	18	10D
0005433415593	18014	19	11A
0005435824309	18014	20	11F
0005435824370	18014	21	12A
0005435824248	18014	22	12C
0005435824276	18014	23	13B
0005435824267	18014	24	13A
0005435824225	18014	25	14B
0005435824299	18014	26	14D
0005435824254	18014	27	14E
0005433415592	18014	28	16C
0005435824244	18014	29	16B
0005433415591	18014	30	17D
0005433415596	18014	31	18D
0005435824348	18014	32	19A
0005433415601	18014	33	19E
0005433415594	18014	34	19D
0005435824236	18014	35	19F
0005435824238	18014	36	20B
0005435824199	18014	37	20D
0005435824235	18014	38	20C
0005433415599	18014	39	20E
0005435824243	18014	40	21F
0005434460478	17521	1	1A
0005434460480	17521	2	1B
0005434462765	17521	3	2B
0005434460483	17521	4	3A
0005434462754	17521	5	2D
0005434462760	17521	6	3C
0005434460475	17521	7	4D
0005434462758	17521	8	5A
0005434460471	17521	9	5B
0005434462753	17521	10	5C
0005434462755	17521	11	6C
0005434460474	17521	12	7D
0005434462759	17521	13	18A
0005434462764	17521	14	19A
0005434462756	17521	15	20B
0005434460482	17521	16	21B
0005434460481	17521	17	23B
0005435242447	5651	1	1A
0005435242516	5651	2	1C
0005432783589	5651	3	1D
0005432783578	5651	4	2A
0005432783582	5651	5	2C
0005435242439	5651	6	2D
0005435242528	5651	7	2F
0005432783595	5651	8	3A
0005435242498	5651	9	3C
0005432783574	5651	10	3D
0005432783600	5651	11	3F
0005435476702	5651	12	4A
0005432783594	5651	13	4C
0005432783560	5651	14	4D
0005432783586	5651	15	4E
0005435242473	5651	16	4F
0005435242460	5651	17	5A
0005435242514	5651	18	5C
0005435242574	5651	19	5D
0005435242625	5651	20	5E
0005432783590	5651	21	5F
0005432783584	5651	22	6A
0005435242462	5651	23	6D
0005435476703	5651	24	6E
0005432783604	5651	25	6F
0005435242561	5651	26	7A
0005432783571	5651	27	7C
0005435476700	5651	28	7D
0005432783579	5651	29	7E
0005435242560	5651	30	7F
0005432783562	5651	31	8A
0005432783564	5651	32	8C
0005432783597	5651	33	8D
0005432783566	5651	34	8E
0005432783575	5651	35	8F
0005432783580	5651	36	9A
0005432143975	5651	37	9C
0005435476666	5651	38	9D
0005435242491	5651	39	9F
0005432783563	5651	40	10A
0005432783577	5651	41	10C
0005435242502	5651	42	10D
0005432783581	5651	43	10E
0005432783591	5651	44	10F
0005432783569	5651	45	11A
0005432783554	5651	46	11C
0005432783572	5651	47	11D
0005432783567	5651	48	11E
0005435242537	5651	49	11F
0005435242474	5651	50	12A
0005432143973	5651	51	12C
0005432783568	5651	52	12D
0005435242427	5651	53	12E
0005432783592	5651	54	12F
0005432783556	5651	55	13A
0005432783607	5651	56	13C
0005432783559	5651	57	13D
0005435476678	5651	58	13E
0005435242562	5651	59	13F
0005432783573	5651	60	14A
0005432783565	5651	61	14C
0005432783583	5651	62	14D
0005432783608	5651	63	14E
0005432783558	5651	64	14F
0005432783606	5651	65	15A
0005435242461	5651	66	15C
0005432143974	5651	67	15D
0005435476665	5651	68	15F
0005435242492	5651	69	16A
0005435242538	5651	70	16D
0005432783598	5651	71	16C
0005432783599	5651	72	16E
0005432783605	5651	73	16F
0005435242417	5651	74	17A
0005432783555	5651	75	17C
0005435242463	5651	76	17D
0005432783588	5651	77	17E
0005432783587	5651	78	17F
0005432783576	5651	79	18C
0005432783570	5651	80	18D
0005432783603	5651	81	18E
0005432783601	5651	82	18F
0005432783596	5651	83	19A
0005432783585	5651	84	19C
0005435476667	5651	85	19D
0005435242515	5651	86	19E
0005432783593	5651	87	20A
0005432783602	5651	88	20C
0005432783561	5651	89	20D
0005432783557	5651	90	20E
0005435476677	5651	91	20F
0005432782914	15374	1	1A
0005432783083	15374	2	1C
0005432783218	15374	3	1D
0005432782972	15374	4	1F
0005432783055	15374	5	2A
0005432783177	15374	6	2C
0005432782994	15374	7	2D
0005432783074	15374	8	2F
0005432783187	15374	9	3A
0005432783183	15374	10	3C
0005432782925	15374	11	3D
0005432783105	15374	12	3F
0005432782997	15374	13	4A
0005432782976	15374	14	4C
0005432782913	15374	15	4D
0005432783172	15374	16	4E
0005435242727	15374	17	4F
0005432783048	15374	18	5A
0005432783038	15374	19	5C
0005435242737	15374	20	5D
0005432782965	15374	21	5E
0005432783084	15374	22	5F
0005432783116	15374	23	6A
0005435242721	15374	24	6C
0005435242732	15374	25	6D
0005432782966	15374	26	6E
0005432783139	15374	27	6F
0005435242720	15374	28	7A
0005432783082	15374	29	7C
0005432782861	15374	30	7D
0005432783097	15374	31	7E
0005432783265	15374	32	7F
0005432782912	15374	33	8A
0005432782963	15374	34	8C
0005432782998	15374	35	8D
0005435242736	15374	36	8E
0005432782986	15374	37	8F
0005435242722	15374	38	9A
0005432783035	15374	39	9C
0005435242731	15374	40	9D
0005432783119	15374	41	9E
0005432783065	15374	42	9F
0005432783125	15374	43	10A
0005432782928	15374	44	10C
0005432783037	15374	45	10D
0005435242728	15374	46	10E
0005432782910	15374	47	10F
0005435242734	15374	48	11A
0005435242738	15374	49	11C
0005432782982	15374	50	11D
0005432783004	15374	51	11E
0005432783104	15374	52	11F
0005435242740	15374	53	12A
0005432783129	15374	54	12C
0005435242733	15374	55	12D
0005432782926	15374	56	12E
0005432783036	15374	57	12F
0005435242723	15374	58	13A
0005432783320	15374	59	13C
0005432782945	15374	60	13D
0005435242739	15374	61	13E
0005432783256	15374	62	13F
0005435242735	15374	63	14A
0005432783096	15374	64	14C
0005432783003	15374	65	14D
0005432782915	15374	66	14E
0005432782920	15374	67	14F
0005432782973	15374	68	15A
0005432783095	15374	69	15C
0005432783184	15374	70	15D
0005432783197	15374	71	15E
0005432782977	15374	72	15F
0005432783264	15374	73	16A
0005432783064	15374	74	16C
0005432783219	15374	75	16D
0005432783195	15374	76	16E
0005432782858	15374	77	16F
0005432782927	15374	78	17A
0005432782981	15374	79	17C
0005435242730	15374	80	17D
0005432783270	15374	81	17E
0005432783066	15374	82	17F
0005432782975	15374	83	18A
0005432782974	15374	84	18C
0005432783319	15374	85	18D
0005432783196	15374	86	18E
0005435242726	15374	87	18F
0005432783061	15374	88	19A
0005435242729	15374	89	19C
0005432783081	15374	90	19D
0005435242725	15374	91	19E
0005435242724	15374	92	19F
0005432783171	15374	93	20A
0005432782859	15374	94	20C
0005435242741	15374	95	20D
0005432782903	15374	96	20E
0005432782862	15374	97	20F
0005435850790	4360	1	1A
0005435850795	4360	2	1C
0005434462782	4360	3	2A
0005432848258	4360	4	3A
0005432848256	4360	5	3C
0005434462781	4360	6	3D
0005435850849	4360	7	4A
0005434463920	4360	8	4B
0005432848263	4360	9	4D
0005432848249	4360	10	5A
0005432848251	4360	11	6A
0005432848260	4360	12	6B
0005432848248	4360	13	6C
0005435850819	4360	14	7B
0005432848253	4360	15	7D
0005432848262	4360	16	18A
0005435850820	4360	17	18C
0005432848250	4360	18	18D
0005432848255	4360	19	19A
0005432848257	4360	20	19B
0005435850818	4360	21	19C
0005432848252	4360	22	21A
0005432848259	4360	23	21C
0005432848254	4360	24	21D
0005434463921	4360	25	22A
0005432848261	4360	26	22C
0005435850837	4360	27	22D
0005432848091	28874	1	1A
0005432848174	28874	2	1B
0005432848118	28874	3	1D
0005432848159	28874	4	2B
0005435850877	28874	5	2D
0005432848104	28874	6	3A
0005435850876	28874	7	3B
0005432848094	28874	8	3C
0005432848173	28874	9	3D
0005435850878	28874	10	4A
0005432848184	28874	11	4C
0005432848147	28874	12	4D
0005435850870	28874	13	5A
0005432848102	28874	14	5B
0005432848067	28874	15	5C
0005432848103	28874	16	5D
0005432848124	28874	17	6A
0005435850873	28874	18	6B
0005432848120	28874	19	6D
0005432848155	28874	20	7A
0005432848156	28874	21	7C
0005432848068	28874	22	7D
0005434463906	28874	23	18A
0005435850871	28874	24	18B
0005432848092	28874	25	18D
0005432848123	28874	26	19B
0005435850872	28874	27	19D
0005432848095	28874	28	20C
0005432848117	28874	29	21A
0005432848131	28874	30	21B
0005435850879	28874	31	21C
0005432848119	28874	32	21D
0005435850880	28874	33	22A
0005432848157	28874	34	22B
0005432848075	28874	35	22C
0005434463904	28874	36	22D
0005435850874	28874	37	23A
0005435850875	28874	38	23B
0005434925705	6297	1	1A
0005433496865	6297	2	1C
0005432075216	6297	3	1D
0005434925682	6297	4	1F
0005434443649	6297	5	2A
0005434925685	6297	6	2C
0005434443651	6297	7	2D
0005433496835	6297	8	2F
0005434925713	6297	9	3A
0005434925692	6297	10	3C
0005433496854	6297	11	3D
0005433496857	6297	12	3F
0005434443646	6297	13	4A
0005434925707	6297	14	4C
0005434925704	6297	15	4D
0005433496858	6297	16	4F
0005433496849	6297	17	5A
0005434443640	6297	18	5C
0005434925693	6297	19	5D
0005434925696	6297	20	5E
0005434925712	6297	21	5F
0005434925706	6297	22	6A
0005434925703	6297	23	6C
0005433496839	6297	24	6D
0005433496850	6297	25	6F
0005434925700	6297	26	6E
0005433496842	6297	27	7C
0005434443648	6297	28	7D
0005433496843	6297	29	7E
0005433496860	6297	30	7F
0005434443645	6297	31	8A
0005434925694	6297	32	8C
0005433496848	6297	33	8D
0005434925695	6297	34	8E
0005433496836	6297	35	8F
0005434443641	6297	36	9A
0005434925702	6297	37	9C
0005434443653	6297	38	9D
0005434925711	6297	39	9E
0005434925678	6297	40	9F
0005434443650	6297	41	10A
0005434443642	6297	42	10C
0005433496847	6297	43	10D
0005433496845	6297	44	10E
0005433496844	6297	45	10F
0005434443644	6297	46	11A
0005434925687	6297	47	11C
0005433496837	6297	48	11D
0005434925715	6297	49	11E
0005433496859	6297	50	11F
0005434925691	6297	51	12A
0005434925679	6297	52	12C
0005432075218	6297	53	12D
0005433496852	6297	54	12E
0005433496853	6297	55	12F
0005434443654	6297	56	13C
0005434925689	6297	57	13D
0005434925714	6297	58	13E
0005434925681	6297	59	13F
0005433496861	6297	60	14A
0005433496838	6297	61	14C
0005434925680	6297	62	14D
0005433496840	6297	63	14E
0005434925683	6297	64	14F
0005433496851	6297	65	15A
0005433496856	6297	66	15C
0005432075215	6297	67	15D
0005434925699	6297	68	15E
0005434443638	6297	69	15F
0005434443647	6297	70	16A
0005433496841	6297	71	16D
0005434925701	6297	72	16E
0005434925708	6297	73	16F
0005434925686	6297	74	17A
0005433496864	6297	75	17D
0005434925690	6297	76	17E
0005432075217	6297	77	17F
0005434443652	6297	78	18A
0005434925710	6297	79	18C
0005434443643	6297	80	18D
0005434443639	6297	81	18E
0005433496863	6297	82	18F
0005433496862	6297	83	19A
0005434925709	6297	84	19C
0005434925697	6297	85	19D
0005433496855	6297	86	19E
0005434925684	6297	87	19F
0005434925688	6297	88	20A
0005434925716	6297	89	20C
0005434925698	6297	90	20E
0005433496846	6297	91	20F
0005434443507	20384	1	1A
0005433496680	20384	2	1C
0005434443492	20384	3	1D
0005433496682	20384	4	1F
0005433496626	20384	5	2C
0005434443427	20384	6	2D
0005433496671	20384	7	2F
0005434443506	20384	8	3A
0005434925346	20384	9	3C
0005434925334	20384	10	3D
0005434925316	20384	11	3F
0005434925256	20384	12	4A
0005434443441	20384	13	4C
0005433496686	20384	14	4D
0005434443501	20384	15	4E
0005434925294	20384	16	4F
0005433496519	20384	17	5A
0005433496613	20384	18	5C
0005433496511	20384	19	5D
0005434443485	20384	20	5E
0005433496559	20384	21	5F
0005434925289	20384	22	6A
0005433496547	20384	23	6C
0005433496579	20384	24	6D
0005434443534	20384	25	6E
0005433496627	20384	26	6F
0005433496685	20384	27	7A
0005433496681	20384	28	7C
0005433496570	20384	29	7D
0005434925318	20384	30	7E
0005434443426	20384	31	8A
0005434925345	20384	32	8C
0005434925322	20384	33	8D
0005434925255	20384	34	8E
0005433496512	20384	35	8F
0005434443494	20384	36	9A
0005433496608	20384	37	9C
0005433496553	20384	38	9D
0005434925323	20384	39	9E
0005434443462	20384	40	9F
0005434925298	20384	41	10A
0005434925342	20384	42	10C
0005433496591	20384	43	10E
0005434925258	20384	44	10D
0005433496758	20384	45	10F
0005433496585	20384	46	11A
0005433496675	20384	47	11C
0005434443466	20384	48	11D
0005434925251	20384	49	11E
0005434925259	20384	50	11F
0005434443519	20384	51	12A
0005433496510	20384	52	12C
0005433496714	20384	53	12D
0005434443493	20384	54	12E
0005434925297	20384	55	12F
0005433496676	20384	56	13A
0005433496520	20384	57	13E
0005434443537	20384	58	13F
0005433496455	20384	59	14A
0005433496542	20384	60	14C
0005434443533	20384	61	14D
0005433496560	20384	62	14E
0005433496658	20384	63	14F
0005434443465	20384	64	15D
0005433496739	20384	65	15E
0005433496783	20384	66	15F
0005434443526	20384	67	16A
0005433496580	20384	68	16C
0005434443468	20384	69	16D
0005433496651	20384	70	16E
0005433496607	20384	71	16F
0005433496601	20384	72	17A
0005434925352	20384	73	17C
0005434443505	20384	74	17D
0005433496628	20384	75	17E
0005433496677	20384	76	17F
0005434443474	20384	77	18A
0005433496527	20384	78	18C
0005433496759	20384	79	18D
0005434925288	20384	80	18E
0005433496581	20384	81	18F
0005433496670	20384	82	19A
0005433496578	20384	83	19C
0005434443448	20384	84	19E
0005434925287	20384	85	19F
0005434925333	20384	86	20C
0005434443480	20384	87	20D
0005434443535	20384	88	20E
0005433496733	20384	89	20F
0005432782999	12214	1	1A
0005432783085	12214	2	1C
0005435242746	12214	3	1D
0005432783034	12214	4	1F
0005435242756	12214	5	2A
0005435242760	12214	6	2C
0005432783020	12214	7	2D
0005435242768	12214	8	2F
0005435242754	12214	9	3A
0005432783128	12214	10	3C
0005432783008	12214	11	3D
0005435242751	12214	12	4A
0005432783268	12214	13	4C
0005432783203	12214	14	4D
0005435242767	12214	15	4E
0005432783109	12214	16	4F
0005432783209	12214	17	5A
0005432783049	12214	18	5C
0005432782979	12214	19	5D
0005432783346	12214	20	5E
0005432783150	12214	21	5F
0005432783280	12214	22	6A
0005432783230	12214	23	6C
0005432783541	12214	24	6D
0005435242747	12214	25	6E
0005435242765	12214	26	6F
0005432783149	12214	27	7A
0005432783148	12214	28	7C
0005432783056	12214	29	7D
0005435242750	12214	30	7E
0005435242744	12214	31	7F
0005435242753	12214	32	8A
0005432782985	12214	33	8C
0005432783275	12214	34	8D
0005435242752	12214	35	8E
0005432783267	12214	36	8F
0005432783158	12214	37	9A
0005432783086	12214	38	9C
0005432783007	12214	39	9D
0005435242743	12214	40	9E
0005432782932	12214	41	9F
0005435242762	12214	42	10A
0005432783161	12214	43	10C
0005432783147	12214	44	10D
0005432783067	12214	45	10F
0005435242742	12214	46	11A
0005432783325	12214	47	11C
0005432782996	12214	48	11D
0005432783000	12214	49	11E
0005432783208	12214	50	11F
0005432783050	12214	51	12A
0005435242748	12214	52	12C
0005435242766	12214	53	12D
0005432782933	12214	54	12E
0005432782978	12214	55	12F
0005432782878	12214	56	13A
0005432783210	12214	57	13C
0005432783181	12214	58	13D
0005435242758	12214	59	13E
0005435242764	12214	60	13F
0005435242761	12214	61	14A
0005435242749	12214	62	14C
0005435242763	12214	63	14D
0005432783377	12214	64	14E
0005432783186	12214	65	15A
0005432783146	12214	66	15C
0005432783127	12214	67	15D
0005432783211	12214	68	15E
0005435242745	12214	69	15F
0005432783140	12214	70	16A
0005432783120	12214	71	16C
0005432783540	12214	72	16D
0005432783043	12214	73	16E
0005432783030	12214	74	16F
0005435242755	12214	75	17A
0005432783028	12214	76	17C
0005432783281	12214	77	17D
0005432783163	12214	78	17E
0005432783180	12214	79	17F
0005432782935	12214	80	18A
0005432783199	12214	81	18C
0005432783029	12214	82	18D
0005432782980	12214	83	18E
0005432782958	12214	84	18F
0005432783159	12214	85	19A
0005432783157	12214	86	19C
0005432783058	12214	87	19D
0005435242757	12214	88	19E
0005435242759	12214	89	19F
0005435242769	12214	90	20E
0005432783115	12214	91	20F
0005432783517	15416	1	1C
0005435242486	15416	2	1D
0005435242444	15416	3	1F
0005435242455	15416	4	2A
0005432783547	15416	5	2D
0005432783526	15416	6	2F
0005432783550	15416	7	3A
0005432783540	15416	8	3C
0005435242579	15416	9	3F
0005432783545	15416	10	4A
0005432783546	15416	11	4C
0005432783502	15416	12	4D
0005435242426	15416	13	4E
0005432783501	15416	14	5C
0005435242487	15416	15	5A
0005432783538	15416	16	5D
0005432783544	15416	17	5E
0005435242434	15416	18	5F
0005432783520	15416	19	6A
0005435242610	15416	20	6C
0005435242501	15416	21	6D
0005432783537	15416	22	6E
0005435242608	15416	23	6F
0005435242438	15416	24	7A
0005432783505	15416	25	7C
0005432783548	15416	26	7D
0005432783503	15416	27	7E
0005435242500	15416	28	8A
0005432783521	15416	29	8C
0005432783529	15416	30	8D
0005432783527	15416	31	8E
0005432783533	15416	32	8F
0005432783515	15416	33	9A
0005432783509	15416	34	9D
0005432783541	15416	35	9E
0005432783512	15416	36	9F
0005432783508	15416	37	10C
0005432783504	15416	38	10D
0005432783542	15416	39	10F
0005435242607	15416	40	11A
0005432783525	15416	41	11D
0005432783514	15416	42	11E
0005435242485	15416	43	11F
0005432783543	15416	44	12A
0005435242421	15416	45	12C
0005435242496	15416	46	12D
0005432783516	15416	47	13A
0005432783524	15416	48	13C
0005432783511	15416	49	13D
0005432783551	15416	50	13E
0005432783549	15416	51	13F
0005435242484	15416	52	14A
0005432783531	15416	53	14C
0005432783522	15416	54	14D
0005432783519	15416	55	14E
0005435242420	15416	56	14F
0005432783518	15416	57	15A
0005435242527	15416	58	15C
0005432783513	15416	59	15D
0005432783506	15416	60	15F
0005432783523	15416	61	16A
0005432783536	15416	62	16C
0005435242494	15416	63	16E
0005432783552	15416	64	17A
0005432783528	15416	65	17D
0005432783535	15416	66	17E
0005432783532	15416	67	17F
0005432783510	15416	68	18A
0005432783499	15416	69	18C
0005435242445	15416	70	18D
0005435242521	15416	71	18F
0005432783500	15416	72	19A
0005432783553	15416	73	19C
0005432783534	15416	74	19D
0005435242495	15416	75	19E
0005432783530	15416	76	19F
0005435242609	15416	77	20A
0005432783507	15416	78	20C
0005435242469	15416	79	20D
0005435242419	15416	80	20F
0005432783539	15416	81	20E
0005434877211	10119	1	1A
0005434876816	10119	2	1D
0005434877070	10119	3	1C
0005434877302	10119	4	2A
0005434877068	10119	5	1F
0005434876933	10119	6	2D
0005434876827	10119	7	2C
0005434877140	10119	8	3A
0005434877185	10119	9	2F
0005434876818	10119	10	3D
0005434876749	10119	11	3C
0005434877209	10119	12	4A
0005434877020	10119	13	4C
0005434877430	10119	14	5A
0005434876863	10119	15	4F
0005434876786	10119	16	4D
0005434876762	10119	17	5C
0005434877213	10119	18	5F
0005434877103	10119	19	5D
0005434877119	10119	20	6B
0005434877006	10119	21	6A
0005434877412	10119	22	6D
0005434876955	10119	23	6C
0005434876754	10119	24	6F
0005434877098	10119	25	6E
0005434877034	10119	26	7A
0005434876992	10119	27	7C
0005434876830	10119	28	7B
0005434877393	10119	29	7E
0005434876821	10119	30	7D
0005434876978	10119	31	8A
0005434877347	10119	32	7F
0005434877198	10119	33	8B
0005434877210	10119	34	8E
0005434877073	10119	35	8D
0005434877122	10119	36	8C
0005434876787	10119	37	9A
0005434876558	10119	38	9C
0005434877036	10119	39	9B
0005434876964	10119	40	9F
0005434876856	10119	41	9E
0005434876814	10119	42	9D
0005434877243	10119	43	10A
0005434877177	10119	44	10C
0005434877081	10119	45	10B
0005434877021	10119	46	10D
0005434877104	10119	47	11A
0005434877067	10119	48	10F
0005434876979	10119	49	11B
0005434877189	10119	50	11D
0005434876977	10119	51	11C
0005434876764	10119	52	11F
0005434877301	10119	53	11E
0005434877348	10119	54	12B
0005434877055	10119	55	12A
0005434877355	10119	56	12D
0005434876991	10119	57	12C
0005434877056	10119	58	12E
0005434877194	10119	59	13A
0005434877339	10119	60	12F
0005434877130	10119	61	13D
0005434877139	10119	62	13C
0005434876750	10119	63	13B
0005434877299	10119	64	13E
0005434877019	10119	65	14A
0005434877023	10119	66	13F
0005434877242	10119	67	14B
0005434877190	10119	68	14D
0005434877058	10119	69	14C
0005434876983	10119	70	14F
0005434876917	10119	71	14E
0005434876956	10119	72	15B
0005434877080	10119	73	15A
0005434876993	10119	74	15D
0005434877131	10119	75	15C
0005434877035	10119	76	15E
0005434876763	10119	77	16A
0005434876867	10119	78	15F
0005434877057	10119	79	16C
0005434877132	10119	80	16D
0005434876916	10119	81	17A
0005434877278	10119	82	16F
0005434876971	10119	83	16E
0005434876973	10119	84	17B
0005434876829	10119	85	17D
0005434876855	10119	86	17C
0005434876969	10119	87	17F
0005434876972	10119	88	17E
0005434877178	10119	89	18B
0005434758868	10119	90	18A
0005434877227	10119	91	18D
0005434876834	10119	92	18C
0005434876828	10119	93	18E
0005434876694	10119	94	18F
0005434877373	10119	95	19C
0005434876925	10119	96	19B
0005434877394	10119	97	19A
0005434877255	10119	98	19D
0005434877413	10119	99	20A
0005434877260	10119	100	19F
0005434876974	10119	101	19E
0005434877338	10119	102	20B
0005434877079	10119	103	20D
0005434876815	10119	104	20C
0005434877039	10119	105	20F
0005434877118	10119	106	20E
0005434877292	10119	107	21B
0005434876932	10119	108	21A
0005434877191	10119	109	21C
0005434877123	10119	110	21E
0005434876985	10119	111	21D
0005434876864	10119	112	21F
0005434877867	14634	1	1C
0005434877852	14634	2	1A
0005434877842	14634	3	1F
0005434877906	14634	4	1D
0005434877893	14634	5	2C
0005434877819	14634	6	2A
0005434877877	14634	7	2D
0005435913867	14634	8	3A
0005434877879	14634	9	2F
0005434877858	14634	10	3D
0005434877898	14634	11	3C
0005434877865	14634	12	3F
0005434877887	14634	13	4D
0005434877834	14634	14	4A
0005434877856	14634	15	4F
0005434877826	14634	16	5C
0005434877888	14634	17	5A
0005434877818	14634	18	5F
0005434877904	14634	19	6A
0005434877870	14634	20	6E
0005434877871	14634	21	6D
0005434877881	14634	22	7A
0005434877894	14634	23	6F
0005434877859	14634	24	7C
0005434877885	14634	25	7B
0005434877862	14634	26	7E
0005434877830	14634	27	7F
0005434877882	14634	28	8C
0005434877835	14634	29	8E
0005434877857	14634	30	8D
0005434877838	14634	31	8F
0005434877861	14634	32	9B
0005434877874	14634	33	9A
0005434877841	14634	34	9D
0005434877848	14634	35	9C
0005434877843	14634	36	9E
0005434877850	14634	37	10A
0005434877899	14634	38	9F
0005434877910	14634	39	10C
0005434877889	14634	40	10B
0005434877831	14634	41	10E
0005434877845	14634	42	10D
0005434877901	14634	43	11A
0005434877822	14634	44	10F
0005434877876	14634	45	11B
0005434877897	14634	46	11D
0005434877892	14634	47	11C
0005434877868	14634	48	11F
0005434910074	14634	49	11E
0005434877839	14634	50	12B
0005434877816	14634	51	12A
0005434877828	14634	52	12C
0005434877833	14634	53	12F
0005434877860	14634	54	12E
0005435913863	14634	55	12D
0005434877905	14634	56	13A
0005434877851	14634	57	13B
0005434877875	14634	58	13E
0005435913856	14634	59	13D
0005435913864	14634	60	14A
0005434877825	14634	61	13F
0005434877866	14634	62	14B
0005434877864	14634	63	14D
0005434877854	14634	64	14C
0005434877907	14634	65	15A
0005434877853	14634	66	14F
0005434877873	14634	67	14E
0005434877855	14634	68	15B
0005434877872	14634	69	15D
0005434877886	14634	70	15C
0005434758883	14634	71	15E
0005434877847	14634	72	16A
0005434877820	14634	73	15F
0005434877832	14634	74	16C
0005434877840	14634	75	16B
0005434877890	14634	76	16E
0005434877869	14634	77	16D
0005434877827	14634	78	16F
0005434877896	14634	79	17C
0005434758884	14634	80	17B
0005435913858	14634	81	17A
0005434877902	14634	82	17D
0005434877844	14634	83	17F
0005434877829	14634	84	17E
0005434877849	14634	85	18B
0005434877880	14634	86	18A
0005434877863	14634	87	18D
0005434877823	14634	88	18C
0005434877821	14634	89	18E
0005434877846	14634	90	19A
0005434877878	14634	91	18F
0005434877909	14634	92	19C
0005435913866	14634	93	19B
0005434877837	14634	94	19E
0005434877900	14634	95	19D
0005434877908	14634	96	20A
0005434877895	14634	97	19F
0005434877903	14634	98	20B
0005434877884	14634	99	20D
0005435913865	14634	100	20E
0005434877817	14634	101	21B
0005434877824	14634	102	21A
0005434877883	14634	103	21C
0005434877836	14634	104	21E
0005434877891	14634	105	21F
0005435660092	9226	1	1A
0005434251847	9226	2	1B
0005435660089	9226	3	2A
0005435660090	9226	4	2B
0005434251842	9226	5	3C
0005435660093	9226	6	3D
0005435660094	9226	7	4A
0005434251850	9226	8	4C
0005434251840	9226	9	5A
0005435660091	9226	10	5B
0005434251861	9226	11	6A
0005435660097	9226	12	6C
0005434251823	9226	13	7A
0005434251839	9226	14	18A
0005434251822	9226	15	18B
0005434251849	9226	16	18D
0005434251856	9226	17	20A
0005435660088	9226	18	20B
0005434251855	9226	19	21A
0005434251846	9226	20	21C
0005435660096	9226	21	21D
0005434251860	9226	22	22B
0005435660087	9226	23	22D
0005435660095	9226	24	23A
0005434251931	24666	1	1B
0005435659990	24666	2	1D
0005434251926	24666	3	2D
0005434251927	24666	4	3C
0005434251930	24666	5	4B
0005435659994	24666	6	4C
0005434251923	24666	7	7D
0005434251924	24666	8	19D
0005435659995	24666	9	20A
0005434251928	24666	10	20B
0005435660007	24666	11	21D
0005434251925	24666	12	22A
0005435660008	24666	13	23A
0005434251929	24666	14	23B
0005433680362	2793	1	1A
0005433680359	2793	2	1C
0005433680384	2793	3	1D
0005433680386	2793	4	1F
0005433680369	2793	5	2A
0005432222758	2793	6	2C
0005433680345	2793	7	2D
0005433680355	2793	8	2F
0005433680373	2793	9	3A
0005432966566	2793	10	3D
0005433680357	2793	11	3F
0005433680379	2793	12	4A
0005433680349	2793	13	4C
0005432222763	2793	14	4D
0005433680368	2793	15	4E
0005433680392	2793	16	4F
0005433680352	2793	17	5A
0005433680380	2793	18	5C
0005433680377	2793	19	5D
0005432222762	2793	20	5F
0005433680381	2793	21	6A
0005432222760	2793	22	6C
0005432222759	2793	23	6D
0005433680358	2793	24	6E
0005433680363	2793	25	6F
0005433680356	2793	26	7A
0005432966641	2793	27	7C
0005432966610	2793	28	7D
0005433680382	2793	29	7E
0005432966724	2793	30	7F
0005433680348	2793	31	8A
0005432966587	2793	32	8C
0005433680367	2793	33	8D
0005432966654	2793	34	8E
0005433680353	2793	35	8F
0005433680390	2793	36	9A
0005433680366	2793	37	9C
0005432966711	2793	38	9E
0005432966749	2793	39	9F
0005432966751	2793	40	10A
0005433680376	2793	41	10C
0005433680375	2793	42	10D
0005432966666	2793	43	10E
0005432966509	2793	44	10F
0005433680347	2793	45	11A
0005432966655	2793	46	11C
0005432966573	2793	47	11D
0005433680365	2793	48	11E
0005432222761	2793	49	11F
0005433680378	2793	50	12A
0005433680387	2793	51	12D
0005433684411	2793	52	12E
0005433680346	2793	53	12F
0005432966635	2793	54	13A
0005433680364	2793	55	13C
0005433680372	2793	56	13D
0005433680383	2793	57	13E
0005432966572	2793	58	13F
0005432966598	2793	59	14A
0005432966530	2793	60	14C
0005433680354	2793	61	14D
0005433684412	2793	62	14F
0005433684410	2793	63	15A
0005432966723	2793	64	15C
0005432966638	2793	65	15D
0005432966617	2793	66	15E
0005433680385	2793	67	15F
0005432966661	2793	68	16A
0005432222764	2793	69	16C
0005432966662	2793	70	16D
0005432966750	2793	71	16E
0005433680370	2793	72	16F
0005432966649	2793	73	17A
0005432966565	2793	74	17C
0005432966585	2793	75	17D
0005433680351	2793	76	17E
0005433680361	2793	77	17F
0005432966667	2793	78	18A
0005433680360	2793	79	18C
0005432966611	2793	80	18E
0005433680371	2793	81	19A
0005432966586	2793	82	19C
0005433680350	2793	83	19D
0005433680389	2793	84	19E
0005432966725	2793	85	19F
0005433680374	2793	86	20A
0005433680391	2793	87	20C
0005432966558	2793	88	20D
0005433680388	2793	89	20E
0005432966640	2793	90	20F
0005432966823	29136	1	1A
0005433690905	29136	2	1C
0005433680027	29136	3	1D
0005432966833	29136	4	1F
0005432966843	29136	5	2A
0005433684393	29136	6	2C
0005432966822	29136	7	2D
0005432966834	29136	8	3A
0005433680109	29136	9	3D
0005433679888	29136	10	3F
0005432005201	29136	11	4A
0005433680161	29136	12	4C
0005433680137	29136	13	4D
0005432966839	29136	14	4E
0005433690902	29136	15	4F
0005433680054	29136	16	5C
0005433680150	29136	17	5D
0005433679937	29136	18	5E
0005432966831	29136	19	5F
0005433680235	29136	20	6A
0005432966829	29136	21	6C
0005433680031	29136	22	6D
0005433684397	29136	23	6E
0005433679836	29136	24	6F
0005433680081	29136	25	7A
0005433679909	29136	26	7C
0005432005200	29136	27	7D
0005433679713	29136	28	7E
0005433679959	29136	29	7F
0005433679976	29136	30	8A
0005433680129	29136	31	8C
0005432966826	29136	32	8D
0005433679936	29136	33	8F
0005433680192	29136	34	9A
0005432966841	29136	35	9C
0005433679924	29136	36	9D
0005433679974	29136	37	9E
0005432966830	29136	38	9F
0005432966844	29136	39	10A
0005432966828	29136	40	10C
0005433687686	29136	41	10F
0005432966838	29136	42	11A
0005432966827	29136	43	11C
0005433680139	29136	44	11D
0005433680080	29136	45	11E
0005433684398	29136	46	12A
0005433679984	29136	47	12D
0005432966842	29136	48	12E
0005433680181	29136	49	12F
0005432966837	29136	50	13A
0005433680138	29136	51	13C
0005432966819	29136	52	13D
0005432966836	29136	53	13F
0005432966825	29136	54	14C
0005433680077	29136	55	14D
0005433680046	29136	56	14F
0005432966835	29136	57	15A
0005433690901	29136	58	15C
0005432966832	29136	59	15D
0005432966840	29136	60	15E
0005433679874	29136	61	15F
0005432966820	29136	62	16A
0005433679914	29136	63	16C
0005433680128	29136	64	16E
0005433679835	29136	65	16D
0005433680146	29136	66	17C
0005433687687	29136	67	17D
0005433679821	29136	68	17E
0005433680075	29136	69	17F
0005433680074	29136	70	18A
0005433679837	29136	71	18C
0005433679915	29136	72	18D
0005433680193	29136	73	18E
0005433679975	29136	74	18F
0005433680078	29136	75	19A
0005433680110	29136	76	19C
0005433679960	29136	77	19D
0005432966824	29136	78	19E
0005433679887	29136	79	19F
0005432005202	29136	80	20A
0005433680053	29136	81	20C
0005432966821	29136	82	20D
0005433679925	29136	83	20E
0005433577743	9280	1	1A
0005433633660	9280	2	1F
0005433633665	9280	3	1D
0005433633640	9280	4	2A
0005433614333	9280	5	2C
0005433577752	9280	6	3A
0005433614353	9280	7	2F
0005433614294	9280	8	3C
0005433614315	9280	9	3F
0005433614300	9280	10	3D
0005433633659	9280	11	4A
0005433577755	9280	12	4C
0005433633643	9280	13	4D
0005433614331	9280	14	4F
0005434152752	9280	15	5C
0005433614350	9280	16	5A
0005433614302	9280	17	5D
0005432755060	9280	18	6A
0005433614291	9280	19	5F
0005433633656	9280	20	6C
0005432755063	9280	21	6F
0005433614289	9280	22	7A
0005433633633	9280	23	7F
0005433577749	9280	24	7D
0005432145102	9280	25	8A
0005433614299	9280	26	8B
0005433614337	9280	27	8C
0005433614351	9280	28	8E
0005432756833	9280	29	8D
0005432755059	9280	30	8F
0005433633634	9280	31	9A
0005433577744	9280	32	9C
0005432755062	9280	33	9B
0005434163511	9280	34	9D
0005432145103	9280	35	9F
0005434163512	9280	36	10B
0005433614344	9280	37	10E
0005433633637	9280	38	10D
0005433633657	9280	39	11A
0005433614342	9280	40	10F
0005433614285	9280	41	11C
0005433614296	9280	42	11D
0005433614317	9280	43	12A
0005433614307	9280	44	12B
0005433614304	9280	45	12E
0005433614347	9280	46	12D
0005434163533	9280	47	12F
0005433614297	9280	48	13A
0005433614348	9280	49	13D
0005433614301	9280	50	13E
0005433614292	9280	51	14A
0005433633646	9280	52	13F
0005433614339	9280	53	14B
0005433614336	9280	54	14D
0005433633645	9280	55	14C
0005433633664	9280	56	15A
0005433614320	9280	57	14F
0005433614323	9280	58	15B
0005433614313	9280	59	15C
0005433633655	9280	60	15D
0005433614346	9280	61	15F
0005433614308	9280	62	15E
0005434163523	9280	63	16A
0005432145101	9280	64	16C
0005433633649	9280	65	16D
0005433633652	9280	66	16E
0005433614318	9280	67	17A
0005433614334	9280	68	16F
0005433614321	9280	69	17B
0005433614343	9280	70	17C
0005433614287	9280	71	17E
0005434163513	9280	72	17D
0005433633662	9280	73	18A
0005433614327	9280	74	17F
0005434152771	9280	75	18B
0005433633639	9280	76	18D
0005433614352	9280	77	18C
0005433614349	9280	78	18E
0005433614319	9280	79	18F
0005433614332	9280	80	19B
0005433614290	9280	81	19E
0005433614309	9280	82	19D
0005433614324	9280	83	19C
0005433577748	9280	84	20B
0005432145100	9280	85	20A
0005433614356	9280	86	20C
0005432756834	9280	87	20E
0005433614293	9280	88	20D
0005433633635	9280	89	20F
0005433614303	9280	90	21B
0005433633644	9280	91	21D
0005433633653	9280	92	21C
0005433633663	9280	93	21F
0005433614345	9280	94	21E
0005433633642	9280	95	22B
0005433614288	9280	96	22A
0005433577741	9280	97	22C
0005433614354	9280	98	22F
0005433614286	9280	99	22E
0005433614340	9280	100	23C
0005433614326	9280	101	23B
0005433614358	9280	102	23D
0005433614355	9280	103	23F
0005433614335	9280	104	23E
0005433614295	9280	105	24B
0005433633650	9280	106	24C
0005433614322	9280	107	24E
0005433614310	9280	108	24D
0005433633654	9280	109	24F
0005433614316	9280	110	25B
0005433633661	9280	111	25A
0005433577746	9280	112	25C
0005433614306	9280	113	25F
0005434163524	9280	114	26B
0005433614314	9280	115	26C
0005433577742	9280	116	26D
0005432755061	9280	117	26F
0005433614329	9280	118	26E
0005433614325	9280	119	27B
0005433633638	9280	120	27A
0005433577751	9280	121	27C
0005433577754	9280	122	27E
0005433633636	9280	123	28B
0005433633632	9280	124	28C
0005433614341	9280	125	28E
0005433633651	9280	126	28D
0005434163496	9280	127	28F
0005433614328	9280	128	29A
0005433614305	9280	129	29C
0005433614298	9280	130	29B
0005433577745	9280	131	29D
0005433633647	9280	132	29E
0005433633641	9280	133	30A
0005433577750	9280	134	29F
0005433614357	9280	135	30B
0005433577753	9280	136	30C
0005433633666	9280	137	30D
0005433614311	9280	138	30E
0005433577747	9280	139	31B
0005433633648	9280	140	31A
0005433614312	9280	141	31C
0005433614330	9280	142	31D
0005433614338	9280	143	31E
0005433633658	9280	144	31F
0005433613744	25242	1	1D
0005433633503	25242	2	1F
0005434163589	25242	3	2C
0005435854056	25242	4	2F
0005434163591	25242	5	2D
0005434272183	25242	6	3A
0005434163583	25242	7	3D
0005433613685	25242	8	3F
0005433633353	25242	9	4D
0005433613484	25242	10	4C
0005433613905	25242	11	5C
0005433613530	25242	12	5D
0005433613667	25242	13	6A
0005433613866	25242	14	6C
0005433633332	25242	15	6D
0005434163587	25242	16	6F
0005433613755	25242	17	7C
0005433613508	25242	18	7D
0005433613572	25242	19	8A
0005433577657	25242	20	8B
0005433613925	25242	21	8E
0005433577608	25242	22	9A
0005433577647	25242	23	8F
0005434163581	25242	24	9B
0005434272184	25242	25	9C
0005435854053	25242	26	9D
0005433613592	25242	27	9F
0005433613721	25242	28	9E
0005433633447	25242	29	10A
0005434163584	25242	30	10B
0005433613749	25242	31	10C
0005433613737	25242	32	10F
0005433613872	25242	33	11A
0005433613656	25242	34	11B
0005433613581	25242	35	11F
0005433613915	25242	36	12A
0005434163588	25242	37	12C
0005433577640	25242	38	12F
0005433577584	25242	39	12E
0005433613774	25242	40	13A
0005435854055	25242	41	13C
0005433613587	25242	42	13B
0005434273070	25242	43	13F
0005433577568	25242	44	13E
0005433613795	25242	45	14B
0005434272186	25242	46	14D
0005433613756	25242	47	14C
0005433613727	25242	48	15A
0005433613882	25242	49	15D
0005433613914	25242	50	15F
0005433613620	25242	51	15E
0005433613644	25242	52	16A
0005434163590	25242	53	16B
0005433577656	25242	54	16D
0005433613683	25242	55	16C
0005433633386	25242	56	16F
0005433633371	25242	57	16E
0005433577616	25242	58	17A
0005435854051	25242	59	17B
0005433633359	25242	60	17D
0005433613584	25242	61	17F
0005433613525	25242	62	17E
0005433577583	25242	63	18A
0005433613499	25242	64	18B
0005433613619	25242	65	18D
0005435854054	25242	66	18C
0005434272185	25242	67	18E
0005434163582	25242	68	18F
0005433577672	25242	69	19D
0005433633354	25242	70	19E
0005434163586	25242	71	20B
0005433613524	25242	72	20C
0005434273069	25242	73	21A
0005433613704	25242	74	21B
0005433613772	25242	75	21C
0005433613498	25242	76	21E
0005433613534	25242	77	22C
0005433613585	25242	78	22D
0005433633373	25242	79	22E
0005433577569	25242	80	23A
0005433613485	25242	81	23C
0005433613803	25242	82	23D
0005433577609	25242	83	23F
0005433633352	25242	84	23E
0005433613773	25242	85	24A
0005433613521	25242	86	24B
0005433613529	25242	87	24D
0005433633330	25242	88	24F
0005433613695	25242	89	25C
0005433613877	25242	90	25E
0005433613559	25242	91	25F
0005433577673	25242	92	26B
0005433613822	25242	93	26E
0005433613588	25242	94	26F
0005433633385	25242	95	27A
0005435854052	25242	96	27C
0005433613580	25242	97	27B
0005433613974	25242	98	27D
0005433613686	25242	99	27E
0005433613904	25242	100	28A
0005433633320	25242	101	28B
0005433577607	25242	102	28E
0005433613694	25242	103	28D
0005433613684	25242	104	28F
0005434163592	25242	105	29B
0005433613827	25242	106	29A
0005433577570	25242	107	29C
0005433613527	25242	108	29D
0005433633329	25242	109	30B
0005433633247	25242	110	30A
0005433577658	25242	111	30C
0005433577646	25242	112	30D
0005433613726	25242	113	30F
0005433633448	25242	114	31A
0005433633370	25242	115	31C
0005434163585	25242	116	31B
0005433613414	25242	117	31D
0005433613509	25242	118	31F
0005433613806	25242	119	31E
0005435986732	4196	1	2A
0005435787324	4196	2	2B
0005435986724	4196	3	3F
0005432571275	4196	4	5C
0005432184939	4196	5	5H
0005432184938	4196	6	11A
0005435787326	4196	7	11F
0005432184940	4196	8	12A
0005435986723	4196	9	12F
0005435856147	4196	10	13E
0005435947069	4196	11	14D
0005435986730	4196	12	14F
0005435986721	4196	13	15B
0005435986722	4196	14	17H
0005435947088	4196	15	19G
0005435947070	4196	16	21A
0005435986726	4196	17	21D
0005435947091	4196	18	22B
0005434271288	4196	19	24G
0005435856148	4196	20	27D
0005435854042	4196	21	29A
0005435854043	4196	22	29E
0005435787325	4196	23	29H
0005435947053	4196	24	30B
0005435986729	4196	25	33H
0005432571291	4196	26	34F
0005435986725	4196	27	35D
0005435986727	4196	28	37A
0005435947092	4196	29	38A
0005435947026	4196	30	38B
0005435986731	4196	31	38E
0005435986728	4196	32	38H
0005435787348	26579	1	2H
0005435947194	26579	2	3F
0005435856189	26579	3	5C
0005435986649	26579	4	5G
0005435856185	26579	5	9A
0005435947199	26579	6	9G
0005435947193	26579	7	12D
0005435947203	26579	8	14B
0005432571311	26579	9	15D
0005432571309	26579	10	17A
0005435947202	26579	11	17H
0005435856186	26579	12	18E
0005432571310	26579	13	20G
0005435947191	26579	14	21H
0005435947204	26579	15	22B
0005435856188	26579	16	22D
0005435986665	26579	17	24B
0005435947195	26579	18	27E
0005435986662	26579	19	27D
0005435947200	26579	20	29E
0005432571308	26579	21	30G
0005435787346	26579	22	30F
0005435947197	26579	23	34G
0005435856187	26579	24	35B
0005435986664	26579	25	35D
0005435947190	26579	26	36E
0005435947192	26579	27	37B
0005435787347	26579	28	37H
0005435947198	26579	29	38F
0005435947196	26579	30	38G
0005435947201	26579	31	38H
0005432948012	317	1	1A
0005433129222	317	2	1F
0005433568804	317	3	2A
0005433568858	317	4	2C
0005432238913	317	5	2F
0005433568852	317	6	2D
0005433568861	317	7	3A
0005433074420	317	8	3C
0005433568825	317	9	3D
0005432947862	317	10	4A
0005433568859	317	11	4C
0005432947872	317	12	4F
0005433568850	317	13	4D
0005433129199	317	14	5A
0005432947809	317	15	5D
0005432947811	317	16	5C
0005433568815	317	17	6A
0005433074400	317	18	5F
0005433074268	317	19	6C
0005433568824	317	20	6D
0005433568867	317	21	7A
0005433568838	317	22	6F
0005432238912	317	23	7C
0005433074357	317	24	7F
0005433074222	317	25	7D
0005433134082	317	26	8A
0005433074271	317	27	8C
0005433568813	317	28	8E
0005433568840	317	29	8D
0005432947944	317	30	8F
0005432947877	317	31	9B
0005433568832	317	32	9A
0005432947883	317	33	9C
0005433074314	317	34	9D
0005433568827	317	35	9F
0005432947785	317	36	10B
0005433568860	317	37	10D
0005433568835	317	38	10C
0005433568842	317	39	10E
0005433074344	317	40	11A
0005432947884	317	41	10F
0005433568868	317	42	11C
0005433568866	317	43	11B
0005433568846	317	44	11F
0005433568862	317	45	11E
0005433568809	317	46	12A
0005433568822	317	47	12B
0005432238914	317	48	12C
0005433568863	317	49	12E
0005432947977	317	50	12D
0005433568818	317	51	13A
0005433568826	317	52	12F
0005433568853	317	53	13B
0005433074221	317	54	13C
0005432947867	317	55	13D
0005432948067	317	56	13F
0005433074331	317	57	14C
0005432238909	317	58	14B
0005433074265	317	59	14E
0005433074377	317	60	14D
0005433568810	317	61	14F
0005432947982	317	62	15A
0005433129237	317	63	15C
0005433568831	317	64	15B
0005433568845	317	65	15D
0005433568828	317	66	15E
0005432238910	317	67	16A
0005432947988	317	68	15F
0005433568821	317	69	16C
0005433074316	317	70	16B
0005432947925	317	71	16E
0005433074451	317	72	16D
0005433568811	317	73	16F
0005433134083	317	74	17C
0005433568833	317	75	17B
0005433568844	317	76	17D
0005433568848	317	77	17E
0005433074399	317	78	18A
0005433568864	317	79	17F
0005433074270	317	80	18D
0005433568843	317	81	18C
0005432947898	317	82	19B
0005433568814	317	83	18F
0005433129228	317	84	19E
0005433568839	317	85	20B
0005433129234	317	86	20D
0005432947876	317	87	20F
0005433568803	317	88	20E
0005433568823	317	89	21B
0005433129215	317	90	21A
0005433568856	317	91	21D
0005432947965	317	92	21C
0005433568855	317	93	21E
0005433074500	317	94	22A
0005433129226	317	95	21F
0005433129221	317	96	22E
0005433568819	317	97	22D
0005433568854	317	98	22F
0005433568812	317	99	23A
0005432947945	317	100	23C
0005433568857	317	101	23F
0005433074313	317	102	23E
0005433074388	317	103	23D
0005433568837	317	104	24A
0005433568820	317	105	24B
0005433568847	317	106	24D
0005432948066	317	107	24C
0005432947833	317	108	24E
0005432947897	317	109	24F
0005433568865	317	110	25A
0005433568830	317	111	25C
0005433568808	317	112	25B
0005432238911	317	113	25D
0005432948087	317	114	25E
0005432948131	317	115	25F
0005433074332	317	116	26A
0005432947971	317	117	26C
0005433568834	317	118	26E
0005433568816	317	119	26D
0005433129203	317	120	27A
0005433568829	317	121	27B
0005432948011	317	122	27D
0005432948031	317	123	27C
0005433074312	317	124	27E
0005433568807	317	125	28A
0005432947810	317	126	27F
0005433568817	317	127	28C
0005432947995	317	128	28E
0005433568805	317	129	28D
0005432948032	317	130	28F
0005433568849	317	131	29A
0005432947964	317	132	29C
0005433568836	317	133	29D
0005433568841	317	134	29F
0005433129235	317	135	29E
0005433074452	317	136	30A
0005433568806	317	137	30B
0005433074223	317	138	30D
0005433129198	317	139	30C
0005433134084	317	140	30E
0005433129227	317	141	30F
0005432947843	317	142	31A
0005433074398	317	143	31C
0005432948029	317	144	31D
0005433074335	317	145	31E
0005433568851	317	146	31F
0005433568279	11601	1	1A
0005432948291	11601	2	1C
0005433568079	11601	3	2A
0005432948302	11601	4	1F
0005433074590	11601	5	2C
0005433568170	11601	6	2F
0005433568127	11601	7	3A
0005433568062	11601	8	3F
0005432948280	11601	9	4A
0005432948298	11601	10	4D
0005433568307	11601	11	4C
0005432192305	11601	12	4F
0005433568065	11601	13	5A
0005433568137	11601	14	5F
0005433134119	11601	15	6A
0005433568351	11601	16	6C
0005432948282	11601	17	6F
0005433568299	11601	18	7A
0005433131688	11601	19	7C
0005433568327	11601	20	7F
0005432948300	11601	21	7D
0005433074578	11601	22	8A
0005432948276	11601	23	8C
0005432948293	11601	24	8B
0005433568306	11601	25	8E
0005433074599	11601	26	8D
0005432948266	11601	27	9A
0005433568269	11601	28	8F
0005433568128	11601	29	9B
0005433074604	11601	30	9C
0005433131690	11601	31	9E
0005433134118	11601	32	9D
0005433568241	11601	33	9F
0005432948295	11601	34	10A
0005433568129	11601	35	10B
0005433568222	11601	36	10C
0005432948286	11601	37	10E
0005433074597	11601	38	10D
0005433568332	11601	39	10F
0005433568352	11601	40	11B
0005432948289	11601	41	11A
0005433568300	11601	42	11D
0005433568266	11601	43	11F
0005432948279	11601	44	12B
0005433568139	11601	45	12A
0005432948278	11601	46	12D
0005432948285	11601	47	12C
0005433568057	11601	48	12E
0005433131689	11601	49	12F
0005432192307	11601	50	13B
0005433074576	11601	51	13A
0005432192306	11601	52	13C
0005432948303	11601	53	13E
0005433074600	11601	54	13F
0005432948267	11601	55	14A
0005433568308	11601	56	14B
0005432948271	11601	57	14E
0005433568318	11601	58	14D
0005432948297	11601	59	14F
0005433568223	11601	60	15A
0005433568034	11601	61	15D
0005433568168	11601	62	15F
0005433568171	11601	63	16A
0005432948277	11601	64	16C
0005433074587	11601	65	16B
0005433074589	11601	66	16D
0005432948294	11601	67	16E
0005433568115	11601	68	16F
0005433074598	11601	69	17A
0005433074591	11601	70	17C
0005433074603	11601	71	17E
0005433568333	11601	72	17D
0005433074580	11601	73	17F
0005432192308	11601	74	18A
0005433134117	11601	75	18B
0005433568078	11601	76	18D
0005433568154	11601	77	18C
0005432948292	11601	78	18F
0005433568291	11601	79	19B
0005433568080	11601	80	19D
0005433568245	11601	81	19C
0005432192309	11601	82	19E
0005432948287	11601	83	20B
0005433568045	11601	84	20A
0005433074594	11601	85	20C
0005433074586	11601	86	20D
0005433568047	11601	87	20F
0005433568090	11601	88	20E
0005433074593	11601	89	21B
0005433074602	11601	90	21A
0005432948296	11601	91	21C
0005433568276	11601	92	21D
0005432948304	11601	93	21F
0005432948275	11601	94	21E
0005433074596	11601	95	22A
0005433568247	11601	96	22B
0005433568311	11601	97	22C
0005432948268	11601	98	22F
0005433568246	11601	99	23A
0005432948281	11601	100	23B
0005432948269	11601	101	23C
0005433568209	11601	102	23E
0005432948270	11601	103	24A
0005433568153	11601	104	23F
0005433074585	11601	105	24B
0005433568136	11601	106	24D
0005433074583	11601	107	24C
0005433074588	11601	108	24E
0005433074575	11601	109	24F
0005433568221	11601	110	25B
0005432948301	11601	111	25A
0005433074584	11601	112	25D
0005433568046	11601	113	25C
0005433074581	11601	114	25E
0005433131687	11601	115	26A
0005432948283	11601	116	25F
0005433568061	11601	117	26B
0005432948272	11601	118	26D
0005432948288	11601	119	26C
0005433074595	11601	120	26E
0005433568356	11601	121	27A
0005432948265	11601	122	26F
0005433074582	11601	123	27B
0005433568164	11601	124	27C
0005433568239	11601	125	27D
0005433074577	11601	126	27F
0005432948274	11601	127	28B
0005432948284	11601	128	28D
0005432948273	11601	129	28C
0005432948264	11601	130	28E
0005432948290	11601	131	28F
0005433131691	11601	132	29B
0005433568149	11601	133	29A
0005433568208	11601	134	29D
0005433568216	11601	135	29C
0005433074579	11601	136	30A
0005433568116	11601	137	30B
0005433134121	11601	138	30E
0005433568172	11601	139	30D
0005433074601	11601	140	30F
0005433134120	11601	141	31B
0005433074592	11601	142	31A
0005432948299	11601	143	31C
0005433568147	11601	144	31F
0005434732939	10019	1	1B
0005433817457	10019	2	4A
0005434732951	10019	3	4B
0005434732935	10019	4	5A
0005433817455	10019	5	5B
0005433817456	10019	6	6A
0005434732967	13889	1	1B
0005433817425	13889	2	2A
0005434732968	13889	3	2B
0005433817426	13889	4	3A
0005433817424	13889	5	4A
0005434732966	13889	6	4B
0005433817408	13889	7	5A
0005433817423	13889	8	6A
0005433817409	13889	9	6B
0005433754002	2329	1	1A
0005433754011	2329	2	1B
0005432655493	2329	3	1F
0005432984590	2329	4	1C
0005433434340	2329	5	1G
0005432869445	2329	6	2A
0005435982129	2329	7	1H
0005435982102	2329	8	2B
0005433753983	2329	9	2C
0005432226030	2329	10	2H
0005433754012	2329	11	2G
0005433434280	2329	12	2F
0005433754021	2329	13	3A
0005433754001	2329	14	3C
0005433434353	2329	15	3B
0005435982096	2329	16	3F
0005432984530	2329	17	3G
0005432869444	2329	18	4A
0005435982119	2329	19	3H
0005435982109	2329	20	4B
0005433434397	2329	21	4C
0005433753973	2329	22	4G
0005433434329	2329	23	4F
0005432869454	2329	24	5A
0005432655494	2329	25	5B
0005435982127	2329	26	5F
0005432984693	2329	27	5C
0005432869437	2329	28	5G
0005433753984	2329	29	5H
0005433753994	2329	30	9B
0005432984594	2329	31	9H
0005433753998	2329	32	9G
0005432869432	2329	33	11A
0005433434376	2329	34	11B
0005432226031	2329	35	11E
0005435982121	2329	36	11F
0005433766625	2329	37	11G
0005433753976	2329	38	12A
0005432984748	2329	39	11H
0005433434268	2329	40	12D
0005433434355	2329	41	12B
0005433753985	2329	42	12E
0005432984654	2329	43	12F
0005434731112	2329	44	12H
0005435982116	2329	45	12G
0005433753980	2329	46	13B
0005433764671	2329	47	13A
0005434731109	2329	48	13E
0005433434364	2329	49	13D
0005432984684	2329	50	13G
0005435982098	2329	51	13F
0005432655488	2329	52	14A
0005433753975	2329	53	13H
0005432984696	2329	54	14B
0005435982103	2329	55	14D
0005435982114	2329	56	14F
0005433754005	2329	57	14E
0005433754014	2329	58	14G
0005433434391	2329	59	14H
0005433753993	2329	60	15B
0005435982110	2329	61	15A
0005433434406	2329	62	15E
0005432984639	2329	63	15D
0005434731113	2329	64	15G
0005435982125	2329	65	15F
0005433753977	2329	66	15H
0005433434328	2329	67	16B
0005433754003	2329	68	16A
0005433753999	2329	69	16F
0005432984722	2329	70	16E
0005433764672	2329	71	16D
0005433753987	2329	72	16G
0005432655495	2329	73	16H
0005433434318	2329	74	17B
0005435982100	2329	75	17A
0005435982113	2329	76	17D
0005432984814	2329	77	17F
0005433766623	2329	78	17E
0005432984695	2329	79	17G
0005433753997	2329	80	17H
0005433434285	2329	81	18B
0005433754026	2329	82	18A
0005433434418	2329	83	18D
0005433434344	2329	84	18F
0005432226032	2329	85	18G
0005435982105	2329	86	19A
0005433753970	2329	87	18H
0005433753982	2329	88	19B
0005435982136	2329	89	19D
0005432869441	2329	90	19G
0005432984682	2329	91	19F
0005435982115	2329	92	19E
0005433754025	2329	93	20A
0005432655485	2329	94	19H
0005435982104	2329	95	20B
0005432984644	2329	96	20F
0005435982126	2329	97	20E
0005432655490	2329	98	20H
0005433434365	2329	99	20G
0005433434405	2329	100	21A
0005433434377	2329	101	21D
0005435982122	2329	102	21B
0005433434392	2329	103	21E
0005435982108	2329	104	21F
0005435982135	2329	105	21H
0005432984680	2329	106	21G
0005435982134	2329	107	22B
0005432984757	2329	108	22A
0005432984647	2329	109	22D
0005435982101	2329	110	22F
0005432984595	2329	111	22E
0005435982137	2329	112	22G
0005435982120	2329	113	22H
0005432984756	2329	114	23B
0005433754022	2329	115	23A
0005433753978	2329	116	23D
0005435982133	2329	117	23F
0005435982106	2329	118	23E
0005432300238	2329	119	23G
0005435982124	2329	120	23H
0005432984697	2329	121	24B
0005435982128	2329	122	24A
0005433753995	2329	123	24D
0005432984749	2329	124	24F
0005433434409	2329	125	24E
0005433754010	2329	126	24G
0005433434378	2329	127	25D
0005434731099	2329	128	24H
0005433753988	2329	129	25E
0005433754015	2329	130	25F
0005433753986	2329	131	27B
0005433753989	2329	132	27A
0005432655489	2329	133	27E
0005435982123	2329	134	27D
0005434731110	2329	135	27F
0005432226034	2329	136	27H
0005432869436	2329	137	27G
0005433753972	2329	138	28A
0005433753981	2329	139	28B
0005435982118	2329	140	28E
0005433764673	2329	141	28D
0005432984558	2329	142	28G
0005433753979	2329	143	28F
0005433434396	2329	144	28H
0005433753971	2329	145	29A
0005433754007	2329	146	29B
0005432984640	2329	147	29F
0005433754006	2329	148	29E
0005435982140	2329	149	29D
0005433754019	2329	150	29G
0005432300239	2329	151	29H
0005433754024	2329	152	30A
0005433754023	2329	153	30D
0005435982097	2329	154	30B
0005435982130	2329	155	30E
0005432300241	2329	156	30G
0005433766627	2329	157	30F
0005435982139	2329	158	31A
0005434731111	2329	159	30H
0005432984678	2329	160	31B
0005432226033	2329	161	31E
0005432300240	2329	162	31D
0005432984744	2329	163	31F
0005433434299	2329	164	31H
0005435982112	2329	165	31G
0005432300243	2329	166	32B
0005433754018	2329	167	32A
0005432984550	2329	168	32E
0005435982111	2329	169	32D
0005435982132	2329	170	32F
0005433434217	2329	171	32G
0005433434403	2329	172	33A
0005432300242	2329	173	32H
0005435982099	2329	174	33D
0005432655496	2329	175	33B
0005432984813	2329	176	33E
0005433434278	2329	177	33F
0005432655487	2329	178	33H
0005433753974	2329	179	33G
0005432655492	2329	180	34B
0005435982107	2329	181	34A
0005432984683	2329	182	34D
0005433753992	2329	183	34E
0005433434407	2329	184	34G
0005432984643	2329	185	34F
0005433754017	2329	186	34H
0005432984568	2329	187	35B
0005435982131	2329	188	35A
0005433754020	2329	189	35D
0005433766626	2329	190	35F
0005435982117	2329	191	35E
0005433434354	2329	192	35G
0005433434408	2329	193	35H
0005433753996	2329	194	36B
0005433434352	2329	195	36A
0005433754004	2329	196	36E
0005433753991	2329	197	36D
0005433754009	2329	198	36F
0005433754016	2329	199	36G
0005433766624	2329	200	36H
0005432655486	2329	201	37B
0005432984623	2329	202	37E
0005433754000	2329	203	37D
0005433753990	2329	204	37F
0005432984679	2329	205	37H
0005433754008	2329	206	37G
0005432984551	2329	207	38A
0005433434402	2329	208	38B
0005433754013	2329	209	38E
0005433434279	2329	210	38D
0005434731117	2329	211	38F
0005435982138	2329	212	38H
0005432655491	2329	213	38G
0005433434302	2329	214	39E
0005432984701	2329	215	39D
0005432984747	2329	216	39F
0005433753528	26198	1	1A
0005433434580	26198	2	1B
0005435981654	26198	3	1C
0005435981817	26198	4	1H
0005433434557	26198	5	1G
0005433753519	26198	6	2A
0005432984943	26198	7	2B
0005433434556	26198	8	2F
0005432869492	26198	9	2C
0005435981575	26198	10	2G
0005432655352	26198	11	3A
0005433753729	26198	12	2H
0005434731153	26198	13	3B
0005433766596	26198	14	3C
0005433753640	26198	15	3G
0005432655339	26198	16	3F
0005433753520	26198	17	4A
0005432655330	26198	18	3H
0005433753491	26198	19	4B
0005433753447	26198	20	4F
0005433753599	26198	21	4C
0005432984960	26198	22	4G
0005435981631	26198	23	5A
0005435981576	26198	24	4H
0005433753320	26198	25	5B
0005432984952	26198	26	5C
0005435981577	26198	27	5G
0005433434570	26198	28	9A
0005432984933	26198	29	5H
0005433434567	26198	30	9B
0005435981720	26198	31	9G
0005435981734	26198	32	11B
0005434731152	26198	33	11A
0005432984955	26198	34	11E
0005433753723	26198	35	11D
0005435981841	26198	36	11F
0005432984942	26198	37	11H
0005433764653	26198	38	11G
0005433766599	26198	39	12A
0005432984938	26198	40	12D
0005435981724	26198	41	12B
0005432984941	26198	42	12E
0005432984950	26198	43	12F
0005435981680	26198	44	12H
0005434731155	26198	45	13B
0005433753249	26198	46	13A
0005432655410	26198	47	13D
0005432984935	26198	48	13E
0005433753365	26198	49	13G
0005432984957	26198	50	13F
0005433753482	26198	51	13H
0005433753247	26198	52	14B
0005433764658	26198	53	14A
0005432984964	26198	54	14D
0005433753468	26198	55	14F
0005433766592	26198	56	14E
0005432655338	26198	57	15A
0005432984946	26198	58	14H
0005433753554	26198	59	15B
0005434731154	26198	60	15E
0005433434555	26198	61	15D
0005435981697	26198	62	15F
0005432869495	26198	63	15H
0005435981725	26198	64	15G
0005432655359	26198	65	16A
0005432984958	26198	66	16B
0005433764652	26198	67	16E
0005435981813	26198	68	16G
0005433753669	26198	69	16F
0005432869493	26198	70	16H
0005435981673	26198	71	17B
0005433753518	26198	72	17A
0005433434578	26198	73	17D
0005433753398	26198	74	17E
0005435981718	26198	75	17G
0005433434581	26198	76	17F
0005432984954	26198	77	17H
0005435981757	26198	78	18B
0005433753245	26198	79	18A
0005433753662	26198	80	18D
0005432984963	26198	81	18E
0005435981608	26198	82	18F
0005435981753	26198	83	19A
0005432655334	26198	84	18H
0005433753318	26198	85	19D
0005433434563	26198	86	19E
0005435981756	26198	87	19F
0005433753515	26198	88	19H
0005432655382	26198	89	19G
0005433753497	26198	90	20A
0005433753546	26198	91	20D
0005433753652	26198	92	20B
0005435981588	26198	93	20E
0005433753514	26198	94	20G
0005432655346	26198	95	20F
0005433753469	26198	96	20H
0005433434573	26198	97	21A
0005433753625	26198	98	21D
0005433434574	26198	99	21E
0005435981727	26198	100	21F
0005432655354	26198	101	21H
0005433753622	26198	102	21G
0005435981556	26198	103	22D
0005435981814	26198	104	22B
0005433434572	26198	105	22E
0005433434554	26198	106	22F
0005433753287	26198	107	22H
0005433434566	26198	108	22G
0005432051117	26198	109	23B
0005435981630	26198	110	23A
0005433434568	26198	111	23D
0005435981857	26198	112	23G
0005435981818	26198	113	23F
0005432984931	26198	114	24A
0005435981560	26198	115	23H
0005433753319	26198	116	24B
0005432984953	26198	117	24E
0005433753248	26198	118	24D
0005433434561	26198	119	24F
0005433753375	26198	120	24G
0005432984949	26198	121	24H
0005433434562	26198	122	25F
0005433753317	26198	123	25E
0005433434575	26198	124	25D
0005433753568	26198	125	27A
0005433753547	26198	126	27B
0005432051116	26198	127	27E
0005433434582	26198	128	27D
0005432869494	26198	129	27F
0005432984948	26198	130	27H
0005432984932	26198	131	27G
0005433753410	26198	132	28A
0005435981784	26198	133	28B
0005435981829	26198	134	28E
0005435981721	26198	135	28F
0005435981535	26198	136	28G
0005433434576	26198	137	29A
0005435981705	26198	138	28H
0005435981651	26198	139	29D
0005433753492	26198	140	29B
0005435981561	26198	141	29F
0005433753527	26198	142	29E
0005432655343	26198	143	29H
0005433753614	26198	144	29G
0005433753505	26198	145	30B
0005435981557	26198	146	30A
0005432051115	26198	147	30D
0005435981728	26198	148	30E
0005435981752	26198	149	30G
0005435981696	26198	150	30F
0005433753316	26198	151	30H
0005432984945	26198	152	31B
0005433753540	26198	153	31A
0005433434560	26198	154	31D
0005435981558	26198	155	31F
0005432984956	26198	156	31E
0005433753399	26198	157	31G
0005433753412	26198	158	32A
0005433753493	26198	159	31H
0005433753295	26198	160	32B
0005433753586	26198	161	32E
0005432984962	26198	162	32F
0005433753335	26198	163	32H
0005435981562	26198	164	32G
0005432984937	26198	165	33A
0005432984961	26198	166	33B
0005432869498	26198	167	33E
0005435981589	26198	168	33D
0005435981607	26198	169	33F
0005433434559	26198	170	33H
0005432984939	26198	171	33G
0005432984951	26198	172	34D
0005435981811	26198	173	34B
0005433434571	26198	174	34G
0005433766598	26198	175	34F
0005433753364	26198	176	34H
0005432049450	26198	177	35A
0005433753448	26198	178	35D
0005432655383	26198	179	35B
0005433753587	26198	180	35F
0005432984944	26198	181	35E
0005433766591	26198	182	35G
0005433753417	26198	183	36A
0005432869497	26198	184	36B
0005435981787	26198	185	36F
0005435981788	26198	186	36E
0005435981719	26198	187	36H
0005433434577	26198	188	36G
0005433434569	26198	189	37B
0005432984947	26198	190	37A
0005433753339	26198	191	37E
0005433434558	26198	192	37F
0005432984959	26198	193	37G
0005433434564	26198	194	38A
0005433434579	26198	195	38B
0005432984934	26198	196	38E
0005433434565	26198	197	38D
0005433753589	26198	198	38G
0005433753244	26198	199	38F
0005432869496	26198	200	38H
0005432655329	26198	201	39D
0005432984940	26198	202	39F
0005432984936	26198	203	39E
0005433151000	1501	1	1A
0005434374498	1501	2	1C
0005434374483	1501	3	1D
0005434374492	1501	4	1F
0005433460428	1501	5	2C
0005434374490	1501	6	2A
0005434374475	1501	7	2F
0005433764649	1501	8	3A
0005434374470	1501	9	3D
0005434374491	1501	10	3F
0005433460427	1501	11	4A
0005434374466	1501	12	4D
0005433151062	1501	13	4C
0005433150899	1501	14	4F
0005434374501	1501	15	5B
0005433931425	1501	16	5D
0005433150906	1501	17	5C
0005434374506	1501	18	6A
0005434374505	1501	19	5F
0005433151081	1501	20	6C
0005433764648	1501	21	6D
0005434374461	1501	22	6F
0005434374497	1501	23	7A
0005434374476	1501	24	7C
0005433764647	1501	25	7D
0005434374485	1501	26	7F
0005434374486	1501	27	8A
0005434374508	1501	28	8F
0005433151104	1501	29	8E
0005433150996	1501	30	9A
0005433150953	1501	31	9B
0005433150954	1501	32	9D
0005434374504	1501	33	9F
0005433150969	1501	34	10B
0005433150986	1501	35	10D
0005434374493	1501	36	10C
0005433151011	1501	37	11A
0005433150904	1501	38	11D
0005433150907	1501	39	11C
0005434029619	1501	40	11E
0005434374489	1501	41	11F
0005433151129	1501	42	12B
0005433150908	1501	43	12E
0005433150945	1501	44	12D
0005433150856	1501	45	12F
0005432267869	1501	46	13A
0005434374484	1501	47	13B
0005432267866	1501	48	13E
0005434374469	1501	49	13D
0005433150905	1501	50	13F
0005434374463	1501	51	14C
0005434374495	1501	52	14B
0005433151005	1501	53	14D
0005434374474	1501	54	14E
0005434374460	1501	55	14F
0005432267867	1501	56	15A
0005433151090	1501	57	15C
0005433150985	1501	58	15D
0005433151012	1501	59	15F
0005434374462	1501	60	16B
0005434374496	1501	61	16C
0005434374488	1501	62	16E
0005434029626	1501	63	17A
0005434374503	1501	64	16F
0005433151049	1501	65	17C
0005434374502	1501	66	17D
0005434374464	1501	67	17F
0005434374465	1501	68	17E
0005433151128	1501	69	18A
0005434029631	1501	70	18B
0005434374477	1501	71	18C
0005433150968	1501	72	18D
0005434374487	1501	73	19A
0005434374478	1501	74	19C
0005434374467	1501	75	19B
0005434374482	1501	76	19D
0005433461580	1501	77	19F
0005433151001	1501	78	19E
0005434374473	1501	79	20B
0005433150982	1501	80	20D
0005434374507	1501	81	20C
0005434374509	1501	82	20E
0005434374499	1501	83	21B
0005434374472	1501	84	21A
0005434374481	1501	85	21C
0005432267871	1501	86	21D
0005434374480	1501	87	21E
0005434374471	1501	88	22A
0005434374500	1501	89	21F
0005434374468	1501	90	22C
0005433150903	1501	91	22B
0005433151050	1501	92	22D
0005432267870	1501	93	22F
0005434374494	1501	94	23B
0005434374479	1501	95	23A
0005434029620	1501	96	23C
0005432267868	1501	97	23F
0005433764673	20156	1	1C
0005433151279	20156	2	1F
0005434374029	20156	3	2D
0005434029645	20156	4	3A
0005434374226	20156	5	2F
0005433151281	20156	6	3D
0005434374127	20156	7	3C
0005433151283	20156	8	4A
0005434374048	20156	9	4B
0005433764672	20156	10	4D
0005434374207	20156	11	4C
0005434373921	20156	12	5A
0005434374234	20156	13	4F
0005433151256	20156	14	5B
0005432056282	20156	15	5D
0005434374264	20156	16	5E
0005434374151	20156	17	5F
0005432056284	20156	18	6A
0005433151251	20156	19	7A
0005434374084	20156	20	7B
0005434374014	20156	21	7D
0005434373993	20156	22	7C
0005433151253	20156	23	7F
0005433151276	20156	24	7E
0005433151252	20156	25	8A
0005434374354	20156	26	8C
0005433151267	20156	27	8D
0005434374108	20156	28	8F
0005432056286	20156	29	9C
0005433151263	20156	30	9E
0005434029647	20156	31	9D
0005433151269	20156	32	9F
0005434374150	20156	33	10C
0005434374189	20156	34	10B
0005434374096	20156	35	10E
0005433151268	20156	36	10D
0005434374016	20156	37	11A
0005434374175	20156	38	11E
0005434374130	20156	39	11F
0005434374176	20156	40	12B
0005434029646	20156	41	12D
0005433151254	20156	42	12C
0005434374138	20156	43	13A
0005434374004	20156	44	13D
0005433151277	20156	45	13E
0005433151257	20156	46	13F
0005432056287	20156	47	14C
0005433151271	20156	48	14E
0005434373916	20156	49	14F
0005434374145	20156	50	15B
0005433151255	20156	51	15A
0005434374098	20156	52	15C
0005434374206	20156	53	15D
0005434374154	20156	54	16A
0005434373975	20156	55	15F
0005434373976	20156	56	16B
0005434374132	20156	57	16E
0005433151260	20156	58	17B
0005433151262	20156	59	17A
0005433151259	20156	60	17D
0005433764671	20156	61	17C
0005433151275	20156	62	17F
0005434373920	20156	63	17E
0005433151264	20156	64	18A
0005434374136	20156	65	18C
0005433151273	20156	66	18E
0005434374126	20156	67	18D
0005432056283	20156	68	18F
0005433151274	20156	69	19A
0005434373992	20156	70	19C
0005434374005	20156	71	19E
0005433931455	20156	72	19D
0005433151258	20156	73	19F
0005433931454	20156	74	20A
0005433151280	20156	75	20C
0005433151282	20156	76	20B
0005433151272	20156	77	20D
0005434374030	20156	78	20F
0005434374094	20156	79	21B
0005434374149	20156	80	21C
0005434373971	20156	81	21D
0005434029648	20156	82	21F
0005434374018	20156	83	22A
0005434374191	20156	84	22C
0005433151265	20156	85	22B
0005433151270	20156	86	22D
0005434374109	20156	87	22E
0005433151285	20156	88	22F
0005433151278	20156	89	23B
0005432056285	20156	90	23A
0005433151261	20156	91	23C
0005433151284	20156	92	23E
0005433931453	20156	93	23D
0005433151266	20156	94	23F
0005432424259	582	1	1D
0005432424233	582	2	2D
0005432282835	582	3	4C
0005432424250	582	4	4F
0005432282833	582	5	5C
0005432424266	582	6	5D
0005432424257	582	7	6F
0005432424261	582	8	7D
0005432282839	582	9	8A
0005432424239	582	10	8C
0005432424235	582	11	8F
0005432424231	582	12	9F
0005432424238	582	13	11D
0005432424247	582	14	11F
0005432424263	582	15	12B
0005432424236	582	16	12C
0005432424237	582	17	12E
0005432424240	582	18	13A
0005432424260	582	19	13C
0005432424253	582	20	14B
0005432282836	582	21	14D
0005432282834	582	22	15F
0005432424267	582	23	16A
0005432424241	582	24	16C
0005432282837	582	25	16D
0005432424264	582	26	17C
0005432282840	582	27	18A
0005432424251	582	28	19E
0005432282838	582	29	20B
0005432424245	582	30	20A
0005432424244	582	31	22B
0005432424252	582	32	22D
0005432424242	582	33	22F
0005432424246	582	34	24F
0005432424255	582	35	25D
0005432424234	582	36	26A
0005432424258	582	37	26E
0005432424268	582	38	28A
0005432424256	582	39	29A
0005432424262	582	40	29F
0005432424249	582	41	30A
0005432424243	582	42	30B
0005432424248	582	43	30F
0005432282832	582	44	31B
0005432424232	582	45	31A
0005432424254	582	46	31D
0005432424265	582	47	31F
0005432302317	12876	1	2C
0005432302316	12876	2	25A
0005432302315	12876	3	27F
0005432423780	12847	1	1C
0005432423781	12847	2	3C
0005432423608	12847	3	3A
0005432423858	12847	4	4D
0005432423786	12847	5	8A
0005432423711	12847	6	8D
0005432423696	12847	7	8E
0005432423833	12847	8	8F
0005432423727	12847	9	9F
0005432423857	12847	10	9E
0005432423712	12847	11	10D
0005432423796	12847	12	10C
0005432423771	12847	13	11C
0005432423832	12847	14	11F
0005432423609	12847	15	12D
0005432423647	12847	16	13B
0005432423642	12847	17	14D
0005432423811	12847	18	16B
0005432423670	12847	19	16D
0005432423859	12847	20	17A
0005432423734	12847	21	16F
0005432423812	12847	22	17E
0005432423716	12847	23	18F
0005432423810	12847	24	19B
0005432423766	12847	25	20B
0005432423836	12847	26	20A
0005432423838	12847	27	20C
0005432423739	12847	28	20E
0005432423756	12847	29	21B
0005432423785	12847	30	22A
0005432423856	12847	31	23B
0005432423765	12847	32	23D
0005432423828	12847	33	24A
0005432423768	12847	34	23F
0005432423612	12847	35	24D
0005432423757	12847	36	24F
0005432423775	12847	37	25A
0005432423798	12847	38	25C
0005432423853	12847	39	25F
0005432423713	12847	40	26D
0005432423776	12847	41	26C
0005432423618	12847	42	28A
0005432423795	12847	43	28B
0005432423815	12847	44	29C
0005432423767	12847	45	30A
0005432423728	12847	46	30E
0005432423837	12847	47	31A
0005432423787	12847	48	31D
0005433057552	447	1	1B
0005434023439	447	2	1F
0005434023413	447	3	1H
0005434023430	447	4	2B
0005434023446	447	5	2F
0005432235608	447	6	2H
0005433057462	447	7	3A
0005434023423	447	8	3G
0005434023436	447	9	3F
0005434032003	447	10	4B
0005434032002	447	11	5A
0005434023435	447	12	4H
0005434023416	447	13	5C
0005433057213	447	14	9A
0005434023452	447	15	9G
0005432235605	447	16	9H
0005434023419	447	17	11D
0005433057402	447	18	11B
0005434023428	447	19	11F
0005433057463	447	20	11G
0005434023445	447	21	12A
0005433057437	447	22	12D
0005434023412	447	23	12F
0005434023457	447	24	12H
0005434023417	447	25	13A
0005434023420	447	26	13D
0005434028285	447	27	13B
0005434023415	447	28	13E
0005433057422	447	29	13G
0005433057180	447	30	14A
0005434023431	447	31	14B
0005433057320	447	32	14E
0005434023432	447	33	14D
0005434023459	447	34	14G
0005433057394	447	35	14H
0005432235604	447	36	15B
0005433057377	447	37	15F
0005434023438	447	38	16G
0005434023414	447	39	17A
0005434029644	447	40	17D
0005433929541	447	41	17E
0005434028286	447	42	18A
0005434023406	447	43	17H
0005433057423	447	44	18B
0005433057430	447	45	18D
0005434023405	447	46	18E
0005434023427	447	47	18G
0005434023441	447	48	18F
0005433057439	447	49	18H
0005434032001	447	50	19D
0005434023470	447	51	19H
0005433929562	447	52	20A
0005434028284	447	53	20D
0005434023456	447	54	20B
0005433057305	447	55	20E
0005433057181	447	56	20F
0005434029643	447	57	21A
0005434023433	447	58	21B
0005434023421	447	59	21E
0005434023453	447	60	21H
0005434023466	447	61	22A
0005432045604	447	62	22D
0005434023437	447	63	22B
0005434023403	447	64	22E
0005433057464	447	65	22F
0005432235609	447	66	22H
0005434023442	447	67	22G
0005434023450	447	68	23B
0005432235611	447	69	23E
0005433057461	447	70	23H
0005434023426	447	71	24B
0005434023443	447	72	24F
0005433057414	447	73	24H
0005433057421	447	74	25F
0005434023410	447	75	27A
0005433929578	447	76	27D
0005434023454	447	77	27F
0005433929579	447	78	27G
0005433057431	447	79	28A
0005433057496	447	80	27H
0005433057412	447	81	28D
0005434023460	447	82	28B
0005434023448	447	83	28E
0005434023411	447	84	28H
0005434023407	447	85	29B
0005434023449	447	86	29G
0005433057229	447	87	29F
0005434023440	447	88	30D
0005434023468	447	89	30F
0005434023402	447	90	30G
0005434023434	447	91	30H
0005434023451	447	92	31D
0005434023467	447	93	31G
0005434023425	447	94	31H
0005434023408	447	95	32B
0005433057306	447	96	32E
0005432235606	447	97	32H
0005433057304	447	98	32G
0005433057495	447	99	33D
0005433057487	447	100	33B
0005433057408	447	101	33E
0005434023455	447	102	33G
0005434023424	447	103	33F
0005433057411	447	104	33H
0005434023404	447	105	34B
0005434023469	447	106	34G
0005433929540	447	107	34F
0005434023444	447	108	35B
0005434023465	447	109	35E
0005434028287	447	110	35G
0005434023463	447	111	36H
0005434023447	447	112	36F
0005434023464	447	113	37A
0005432235610	447	114	37B
0005434023422	447	115	37D
0005434023462	447	116	37G
0005432235607	447	117	37F
0005433057413	447	118	37H
0005434023461	447	119	38A
0005434023458	447	120	38B
0005434023409	447	121	38F
0005434023429	447	122	39E
0005433057488	447	123	39D
0005434023418	447	124	39F
0005434022752	12680	1	1A
0005433057716	12680	2	1C
0005434022912	12680	3	1B
0005434023030	12680	4	1H
0005433057741	12680	5	1G
0005434028267	12680	6	2A
0005434735668	12680	7	2C
0005434022719	12680	8	2B
0005434022798	12680	9	2F
0005434022995	12680	10	2G
0005434022948	12680	11	3A
0005434022706	12680	12	3F
0005433057704	12680	13	3G
0005433057736	12680	14	4A
0005434022897	12680	15	3H
0005434022792	12680	16	4F
0005434022583	12680	17	4C
0005434022964	12680	18	4G
0005434022957	12680	19	4H
0005433057738	12680	20	5B
0005434022733	12680	21	5A
0005434022911	12680	22	5C
0005434022907	12680	23	5G
0005434022814	12680	24	5F
0005434023086	12680	25	5H
0005433929598	12680	26	9B
0005434028260	12680	27	9A
0005432156349	12680	28	9H
0005432157484	12680	29	11B
0005434022697	12680	30	11D
0005434022896	12680	31	11G
0005433057727	12680	32	12B
0005433057732	12680	33	12A
0005434023121	12680	34	12G
0005432156347	12680	35	13B
0005434022970	12680	36	13A
0005433057733	12680	37	13E
0005434735671	12680	38	13F
0005433057739	12680	39	14A
0005434022509	12680	40	13H
0005433057724	12680	41	14D
0005432157485	12680	42	14F
0005434022655	12680	43	14H
0005434022972	12680	44	14G
0005433057708	12680	45	15A
0005434023000	12680	46	15B
0005434022985	12680	47	15E
0005433057707	12680	48	15D
0005434735670	12680	49	15H
0005433057711	12680	50	15G
0005433929595	12680	51	16A
0005433057726	12680	52	16B
0005434022906	12680	53	16E
0005434023013	12680	54	16D
0005434022505	12680	55	16G
0005433057710	12680	56	16H
0005434022830	12680	57	17B
0005434022675	12680	58	17A
0005434735667	12680	59	17D
0005434022658	12680	60	17E
0005434029620	12680	61	17G
0005433057712	12680	62	17F
0005434023016	12680	63	18B
0005432156345	12680	64	18D
0005434022716	12680	65	18F
0005433057714	12680	66	18H
0005434022821	12680	67	19B
0005434022718	12680	68	19A
0005434022570	12680	69	19D
0005433057722	12680	70	19E
0005434022865	12680	71	19H
0005433057715	12680	72	19G
0005434029631	12680	73	20A
0005434023006	12680	74	20E
0005434022993	12680	75	20D
0005433057729	12680	76	20F
0005434022565	12680	77	20H
0005434022793	12680	78	20G
0005433057735	12680	79	21A
0005434022744	12680	80	21E
0005434022956	12680	81	21D
0005434022681	12680	82	21G
0005434022566	12680	83	21F
0005433057706	12680	84	21H
0005434029626	12680	85	22B
0005434023044	12680	86	22A
0005434022707	12680	87	22D
0005434022887	12680	88	22E
0005434022510	12680	89	22G
0005433057703	12680	90	22F
0005434022596	12680	91	22H
0005434031957	12680	92	23B
0005434031969	12680	93	23A
0005434028266	12680	94	23D
0005434022822	12680	95	23F
0005434023012	12680	96	23H
0005433057742	12680	97	23G
0005433057725	12680	98	24A
0005434022933	12680	99	24E
0005434022564	12680	100	24D
0005434022546	12680	101	24F
0005434028255	12680	102	24G
0005434029619	12680	103	24H
0005433057730	12680	104	25F
0005433057717	12680	105	25E
0005434022929	12680	106	27A
0005433057705	12680	107	27D
0005434028258	12680	108	27B
0005434022514	12680	109	27F
0005434022649	12680	110	27E
0005434022654	12680	111	27G
0005434023043	12680	112	28A
0005434735666	12680	113	27H
0005434022735	12680	114	28B
0005434022863	12680	115	28E
0005433057728	12680	116	28F
0005434022965	12680	117	28H
0005434022753	12680	118	28G
0005434022734	12680	119	29A
0005434022768	12680	120	29D
0005433057720	12680	121	29B
0005434022648	12680	122	29E
0005434031971	12680	123	29G
0005433929596	12680	124	29F
0005433057740	12680	125	30A
0005433057737	12680	126	30D
0005433057723	12680	127	30B
0005434022813	12680	128	30F
0005434022717	12680	129	30H
0005434022947	12680	130	31B
0005434022908	12680	131	31E
0005434023007	12680	132	31G
0005434028257	12680	133	32B
0005434022971	12680	134	32E
0005434735669	12680	135	32D
0005434022848	12680	136	32G
0005434022934	12680	137	32F
0005434022745	12680	138	33A
0005433057721	12680	139	33B
0005434023122	12680	140	33E
0005434022650	12680	141	33D
0005434022743	12680	142	33F
0005432157483	12680	143	33G
0005434031967	12680	144	34B
0005434022969	12680	145	34E
0005434022973	12680	146	34D
0005433929599	12680	147	34G
0005434022823	12680	148	34H
0005434022756	12680	149	35B
0005433057713	12680	150	35E
0005432156346	12680	151	35H
0005433684413	12680	152	35G
0005432156348	12680	153	36A
0005433057702	12680	154	36E
0005434031961	12680	155	36D
0005434022864	12680	156	36F
0005434022996	12680	157	36H
0005433057718	12680	158	37A
0005433929594	12680	159	37B
0005433929597	12680	160	37E
0005433057731	12680	161	37G
0005434023078	12680	162	37F
0005433057719	12680	163	37H
0005433057734	12680	164	38A
0005434022779	12680	165	38D
0005434023010	12680	166	38B
0005434022966	12680	167	38E
0005434022506	12680	168	38G
0005434022866	12680	169	38F
0005434023158	12680	170	39D
0005433057709	12680	171	39F
0005434022762	12680	172	39E
0005433035705	2166	1	1F
0005432231520	2166	2	1C
0005433922944	2166	3	1H
0005433922930	2166	4	1G
0005433035646	2166	5	2A
0005433922914	2166	6	2B
0005433035537	2166	7	2F
0005433035673	2166	8	2C
0005432231525	2166	9	2H
0005433922899	2166	10	2G
0005433922898	2166	11	3A
0005434028258	2166	12	3B
0005433922947	2166	13	3C
0005433922961	2166	14	3G
0005433922917	2166	15	4A
0005432749754	2166	16	3H
0005433922942	2166	17	4C
0005433035574	2166	18	4G
0005433035595	2166	19	4F
0005433922948	2166	20	5A
0005432231524	2166	21	4H
0005433035501	2166	22	5B
0005433922958	2166	23	5F
0005433922885	2166	24	5C
0005433929594	2166	25	5H
0005433922932	2166	26	9H
0005433035585	2166	27	9G
0005433922895	2166	28	11A
0005433922907	2166	29	11B
0005433922873	2166	30	11D
0005433922904	2166	31	11F
0005433922920	2166	32	11E
0005433922863	2166	33	11G
0005433035615	2166	34	12A
0005433922884	2166	35	11H
0005433922905	2166	36	12D
0005433035868	2166	37	12B
0005433922922	2166	38	12E
0005433922868	2166	39	12G
0005433929595	2166	40	12H
0005433035669	2166	41	13B
0005433035597	2166	42	13D
0005433035584	2166	43	13F
0005433035650	2166	44	13E
0005433035623	2166	45	14A
0005432231521	2166	46	13H
0005433035582	2166	47	14B
0005433922875	2166	48	14E
0005433035446	2166	49	14D
0005433922893	2166	50	14F
0005433922897	2166	51	14G
0005433931454	2166	52	15A
0005433035768	2166	53	14H
0005433922896	2166	54	15D
0005433035605	2166	55	15G
0005432231518	2166	56	15F
0005433922874	2166	57	15H
0005432231526	2166	58	16B
0005433035726	2166	59	16A
0005433922953	2166	60	16D
0005433922946	2166	61	16E
0005433929598	2166	62	16G
0005433922935	2166	63	16F
0005433035529	2166	64	16H
0005433922952	2166	65	17A
0005433922872	2166	66	17B
0005433035494	2166	67	17E
0005433035827	2166	68	17G
0005433922937	2166	69	17H
0005433922957	2166	70	18B
0005433035500	2166	71	18A
0005433922913	2166	72	18F
0005433922877	2166	73	18G
0005433922936	2166	74	19A
0005433035614	2166	75	18H
0005433922894	2166	76	19B
0005433035718	2166	77	19D
0005433035706	2166	78	19E
0005433035734	2166	79	19H
0005433922883	2166	80	19G
0005433922882	2166	81	20B
0005433922876	2166	82	20F
0005433922903	2166	83	20E
0005433922939	2166	84	20G
0005433922933	2166	85	21B
0005433922960	2166	86	21A
0005433035826	2166	87	21D
0005433931455	2166	88	21E
0005432231523	2166	89	21G
0005433035769	2166	90	21F
0005433922912	2166	91	22A
0005433922871	2166	92	22D
0005433035648	2166	93	22B
0005433035553	2166	94	22F
0005433922880	2166	95	22E
0005433922929	2166	96	22G
0005434028255	2166	97	23A
0005434028260	2166	98	22H
0005432044512	2166	99	23E
0005433035867	2166	100	23D
0005433035695	2166	101	23F
0005433922908	2166	102	23G
0005433922916	2166	103	23H
0005433035510	2166	104	24D
0005433922943	2166	105	24F
0005433922950	2166	106	24E
0005433929596	2166	107	24G
0005433922869	2166	108	25D
0005433922915	2166	109	24H
0005432231522	2166	110	25E
0005433922866	2166	111	27B
0005433929597	2166	112	27A
0005433922901	2166	113	27E
0005433922909	2166	114	27D
0005434028257	2166	115	27F
0005433035573	2166	116	27H
0005433035678	2166	117	27G
0005433922949	2166	118	28D
0005433035511	2166	119	28E
0005434028266	2166	120	28G
0005433922940	2166	121	28F
0005433929599	2166	122	29A
0005433035733	2166	123	28H
0005432231517	2166	124	29D
0005433922879	2166	125	29B
0005433035629	2166	126	29E
0005433035679	2166	127	29H
0005433035704	2166	128	30B
0005433035484	2166	129	30A
0005433922923	2166	130	30E
0005433035593	2166	131	30G
0005433922921	2166	132	30H
0005433035486	2166	133	31B
0005433922924	2166	134	31A
0005433922887	2166	135	31D
0005433922870	2166	136	31F
0005433922886	2166	137	31G
0005433922934	2166	138	32A
0005433922902	2166	139	31H
0005433922941	2166	140	32D
0005432749762	2166	141	32B
0005433922918	2166	142	32E
0005433035530	2166	143	32F
0005433035862	2166	144	32H
0005433922954	2166	145	32G
0005433922910	2166	146	33A
0005433035594	2166	147	33B
0005433922951	2166	148	33E
0005433922892	2166	149	33D
0005433922926	2166	150	33F
0005433922945	2166	151	34B
0005433922878	2166	152	34A
0005433922938	2166	153	34D
0005433922890	2166	154	34E
0005433922955	2166	155	34F
0005433922928	2166	156	35A
0005433922927	2166	157	34H
0005433035863	2166	158	35B
0005433035485	2166	159	35D
0005433922891	2166	160	35E
0005433922925	2166	161	35G
0005433922864	2166	162	35F
0005433922881	2166	163	36A
0005433922911	2166	164	35H
0005433922919	2166	165	36B
0005433931453	2166	166	36E
0005434028267	2166	167	36H
0005433922900	2166	168	36G
0005432044514	2166	169	36F
0005432044513	2166	170	37A
0005433922956	2166	171	37D
0005433922889	2166	172	37B
0005433922931	2166	173	37E
0005433035747	2166	174	37F
0005433035785	2166	175	37H
0005433035647	2166	176	37G
0005433922888	2166	177	38A
0005432231519	2166	178	38D
0005433035786	2166	179	38E
0005433922865	2166	180	38G
0005433922906	2166	181	38H
0005433922959	2166	182	39E
0005433875370	2166	183	39D
0005433922867	2166	184	39F
0005433922152	24122	1	1A
0005433922173	24122	2	1C
0005433922114	24122	3	1B
0005433922410	24122	4	1F
0005433921939	24122	5	1G
0005433922009	24122	6	2A
0005433921932	24122	7	1H
0005432206174	24122	8	2C
0005433922036	24122	9	2B
0005433922293	24122	10	2F
0005433922253	24122	11	2G
0005433921678	24122	12	3A
0005433036090	24122	13	2H
0005433036072	24122	14	3B
0005433929564	24122	15	3C
0005433929560	24122	16	3G
0005433922227	24122	17	4A
0005433921997	24122	18	3H
0005433036111	24122	19	4B
0005433922006	24122	20	4G
0005433036077	24122	21	4F
0005433036069	24122	22	4H
0005433922391	24122	23	5B
0005433922127	24122	24	5C
0005433036085	24122	25	5G
0005433922486	24122	26	5F
0005433921996	24122	27	5H
0005433036107	24122	28	9B
0005433922361	24122	29	9A
0005432206172	24122	30	9G
0005433921682	24122	31	11A
0005433921973	24122	32	11D
0005433921911	24122	33	11B
0005433921683	24122	34	11F
0005433922354	24122	35	11E
0005433922522	24122	36	11G
0005433921875	24122	37	12A
0005433922056	24122	38	11H
0005433921949	24122	39	12D
0005433921808	24122	40	12B
0005433922451	24122	41	12E
0005433036061	24122	42	12G
0005433921946	24122	43	12F
0005432207652	24122	44	12H
0005432207653	24122	45	13B
0005433921876	24122	46	13A
0005433922226	24122	47	13D
0005433922150	24122	48	13F
0005433036092	24122	49	13G
0005433922244	24122	50	14A
0005433922017	24122	51	14B
0005433922065	24122	52	14F
0005433921720	24122	53	14E
0005433036071	24122	54	14H
0005433922151	24122	55	14G
0005433922125	24122	56	15A
0005433036112	24122	57	15D
0005433921679	24122	58	15B
0005433921846	24122	59	15E
0005433922545	24122	60	15F
0005433922548	24122	61	15H
0005433922057	24122	62	15G
0005433922071	24122	63	16A
0005432749775	24122	64	16D
0005433036091	24122	65	16B
0005433036098	24122	66	16E
0005433921986	24122	67	16G
0005433922368	24122	68	16F
0005433922286	24122	69	17A
0005432206173	24122	70	17D
0005433922556	24122	71	17B
0005433922357	24122	72	17E
0005433922025	24122	73	17G
0005433921809	24122	74	17F
0005433036079	24122	75	18A
0005433922072	24122	76	17H
0005433922229	24122	77	18B
0005433036066	24122	78	18E
0005433922565	24122	79	18D
0005433036060	24122	80	18F
0005433921591	24122	81	18G
0005433922411	24122	82	18H
0005433036101	24122	83	19E
0005433922113	24122	84	19D
0005433036074	24122	85	19H
0005433036087	24122	86	19G
0005433929569	24122	87	20A
0005433036082	24122	88	20B
0005433922118	24122	89	20E
0005432206171	24122	90	20D
0005433922386	24122	91	20F
0005433922360	24122	92	20H
0005433036070	24122	93	20G
0005433036097	24122	94	21A
0005433922207	24122	95	21D
0005433921837	24122	96	21E
0005433922140	24122	97	21F
0005433922392	24122	98	21H
0005433036062	24122	99	21G
0005433929547	24122	100	22B
0005433922105	24122	101	22A
0005433036106	24122	102	22D
0005433036059	24122	103	22F
0005433036078	24122	104	22E
0005433921695	24122	105	22G
0005433922487	24122	106	23A
0005433922190	24122	107	23D
0005433921971	24122	108	23B
0005433922149	24122	109	23F
0005433921926	24122	110	23E
0005432206169	24122	111	23G
0005433036081	24122	112	23H
0005433922099	24122	113	24D
0005433922450	24122	114	24B
0005433922246	24122	115	24E
0005433922037	24122	116	24H
0005433921963	24122	117	24G
0005433922153	24122	118	25D
0005433922180	24122	119	25E
0005433921684	24122	120	27A
0005433922147	24122	121	25F
0005433921681	24122	122	27B
0005433922075	24122	123	27E
0005433921732	24122	124	27F
0005433036096	24122	125	27H
0005433922128	24122	126	27G
0005432206175	24122	127	28A
0005433036076	24122	128	28B
0005433036064	24122	129	28E
0005433921977	24122	130	28D
0005433922206	24122	131	28F
0005433036110	24122	132	28H
0005433921925	24122	133	28G
0005433922523	24122	134	29A
0005433036080	24122	135	29B
0005433922339	24122	136	29E
0005433922367	24122	137	29G
0005433036108	24122	138	29F
0005433921721	24122	139	29H
0005433922566	24122	140	30A
0005433922126	24122	141	30D
0005433036065	24122	142	30F
0005433036068	24122	143	30E
0005433036099	24122	144	30G
0005433922008	24122	145	30H
0005433036073	24122	146	31B
0005433036104	24122	147	31A
0005433036093	24122	148	31F
0005432206170	24122	149	31E
0005433929563	24122	150	31G
0005433036086	24122	151	32A
0005433922315	24122	152	31H
0005433036109	24122	153	32B
0005433921592	24122	154	32D
0005433921970	24122	155	32F
0005433922345	24122	156	32H
0005433922074	24122	157	32G
0005433036103	24122	158	33A
0005433922544	24122	159	33D
0005433922202	24122	160	33B
0005433921947	24122	161	33E
0005433036075	24122	162	33G
0005433922007	24122	163	33F
0005433036095	24122	164	33H
0005433036100	24122	165	34B
0005432749776	24122	166	34A
0005433922148	24122	167	34F
0005433922038	24122	168	34G
0005433922115	24122	169	35A
0005433036088	24122	170	35B
0005433921952	24122	171	35E
0005433036067	24122	172	35G
0005433921668	24122	173	35F
0005433922524	24122	174	36B
0005432749777	24122	175	36A
0005433922209	24122	176	36D
0005433929561	24122	177	36F
0005433036089	24122	178	36E
0005433875357	24122	179	36G
0005433036094	24122	180	36H
0005433922470	24122	181	37B
0005433922106	24122	182	37E
0005433922245	24122	183	37D
0005433922430	24122	184	37F
0005433036083	24122	185	37H
0005433036084	24122	186	37G
0005433922285	24122	187	38A
0005433922225	24122	188	38D
0005433036063	24122	189	38B
0005433036105	24122	190	38E
0005433036102	24122	191	38G
0005433922177	24122	192	38H
0005433921680	24122	193	39D
0005433036113	24122	194	39F
0005433922567	24122	195	39E
0005434550999	259	1	1C
0005434725025	259	2	1A
0005434725039	259	3	1G
0005434551028	259	4	1D
0005434550995	259	5	2A
0005433233407	259	6	1K
0005434725020	259	7	1H
0005434550994	259	8	2C
0005433233380	259	9	2H
0005432277757	259	10	2G
0005433233399	259	11	3A
0005433180765	259	12	2K
0005434551011	259	13	3D
0005434551021	259	14	3C
0005433180785	259	15	3H
0005434724947	259	16	3G
0005434724967	259	17	4C
0005432277747	259	18	3K
0005434551040	259	19	4G
0005435142525	259	20	4K
0005433233223	259	21	4H
0005434724973	259	22	5D
0005433113508	259	23	5C
0005435142519	259	24	5A
0005434724962	259	25	5G
0005433233532	259	26	11A
0005433766588	259	27	5K
0005433233386	259	28	5H
0005433233438	259	29	11D
0005433233415	259	30	11C
0005433233224	259	31	11F
0005434735665	259	32	11E
0005434724951	259	33	11K
0005433131649	259	34	11H
0005433233321	259	35	12C
0005433233323	259	36	12A
0005434725005	259	37	12E
0005433113509	259	38	12D
0005434724950	259	39	12G
0005434031954	259	40	12F
0005433233339	259	41	13A
0005433233254	259	42	13D
0005434725022	259	43	13C
0005432277750	259	44	13F
0005434724956	259	45	13E
0005434725044	259	46	13H
0005434550993	259	47	13G
0005434551005	259	48	14C
0005434724938	259	49	14A
0005434551036	259	50	13K
0005433233469	259	51	14D
0005433289750	259	52	14F
0005434731149	259	53	14K
0005433180764	259	54	14H
0005434725011	259	55	14G
0005434551033	259	56	15C
0005434551019	259	57	15A
0005433289745	259	58	15E
0005433180704	259	59	15D
0005433180934	259	60	15G
0005434725002	259	61	15F
0005433233713	259	62	16A
0005434725032	259	63	15K
0005433131650	259	64	15H
0005434551037	259	65	16D
0005434724969	259	66	16C
0005434724937	259	67	16F
0005434724977	259	68	16E
0005433180701	259	69	16H
0005434725038	259	70	16G
0005434724985	259	71	17A
0005434724936	259	72	16K
0005434725014	259	73	17E
0005433180781	259	74	17D
0005434725019	259	75	17G
0005434302442	259	76	17F
0005434724933	259	77	17K
0005434724993	259	78	17H
0005434551035	259	79	18B
0005434724999	259	80	18A
0005434550998	259	81	18E
0005432277749	259	82	18D
0005434725037	259	83	18C
0005434725001	259	84	18H
0005434302857	259	85	18F
0005434551030	259	86	18J
0005434724961	259	87	18K
0005434551023	259	88	19C
0005434724935	259	89	19B
0005433233518	259	90	19E
0005433233436	259	91	19D
0005434724930	259	92	19H
0005433180759	259	93	19G
0005433180758	259	94	20A
0005434724952	259	95	19K
0005434724980	259	96	20B
0005433233349	259	97	20E
0005434551008	259	98	20D
0005434724946	259	99	20G
0005434551009	259	100	20J
0005433180821	259	101	20H
0005434551042	259	102	21A
0005434724924	259	103	21D
0005434551043	259	104	21B
0005434724953	259	105	21G
0005434724929	259	106	21F
0005434551006	259	107	21E
0005434302858	259	108	21J
0005433233370	259	109	21H
0005433126812	259	110	22A
0005434725031	259	111	21K
0005433113512	259	112	22C
0005433233457	259	113	22F
0005434724939	259	114	22E
0005433233437	259	115	22D
0005432277756	259	116	22G
0005434724995	259	117	22K
0005434551018	259	118	22J
0005432277751	259	119	23B
0005434724994	259	120	23A
0005434724998	259	121	23D
0005435142520	259	122	23C
0005433131643	259	123	23F
0005434551010	259	124	23E
0005433233338	259	125	23H
0005434725026	259	126	24D
0005434551001	259	127	23K
0005435142522	259	128	23J
0005434550987	259	129	24F
0005433233237	259	130	24E
0005434551016	259	131	25B
0005433131653	259	132	25A
0005433233128	259	133	25D
0005434725041	259	134	25C
0005434302443	259	135	25E
0005433180876	259	136	25H
0005434724974	259	137	25G
0005434724963	259	138	25K
0005433180772	259	139	26C
0005434724932	259	140	26E
0005434725004	259	141	26G
0005432277754	259	142	26F
0005434551014	259	143	26J
0005434551000	259	144	26H
0005434551039	259	145	27A
0005434724945	259	146	26K
0005434725023	259	147	27C
0005434551003	259	148	27B
0005434724934	259	149	27F
0005434735664	259	150	27E
0005434551027	259	151	27H
0005433289775	259	152	27K
0005433233434	259	153	27J
0005434551031	259	154	28B
0005433766589	259	155	28A
0005434724972	259	156	28G
0005434725012	259	157	28E
0005433233411	259	158	28K
0005434551041	259	159	28J
0005434551022	259	160	28H
0005433766585	259	161	29B
0005434550989	259	162	29A
0005434551012	259	163	29D
0005434725015	259	164	29C
0005434550997	259	165	29E
0005434725016	259	166	29J
0005434735662	259	167	29H
0005435142523	259	168	29G
0005434724931	259	169	30A
0005433233497	259	170	29K
0005434724992	259	171	30C
0005433233480	259	172	30E
0005433233520	259	173	30D
0005433180839	259	174	30G
0005434724978	259	175	30F
0005433289746	259	176	30K
0005434724944	259	177	30J
0005434725036	259	178	30H
0005434724954	259	179	31A
0005433180731	259	180	31D
0005433180813	259	181	31C
0005433180786	259	182	31B
0005434725018	259	183	31F
0005434724948	259	184	31E
0005433233417	259	185	31J
0005434725029	259	186	31H
0005433233212	259	187	31G
0005434725013	259	188	32A
0005434725033	259	189	31K
0005434550990	259	190	32C
0005433180753	259	191	32E
0005433126785	259	192	32D
0005433180803	259	193	32G
0005433233722	259	194	32F
0005434731150	259	195	32K
0005434724928	259	196	33D
0005434724927	259	197	33B
0005434550996	259	198	33F
0005434551038	259	199	33E
0005433233255	259	200	33H
0005434725035	259	201	34A
0005433180873	259	202	33K
0005434724971	259	203	33J
0005434724983	259	204	34C
0005434551020	259	205	34B
0005434550991	259	206	34E
0005434551013	259	207	34D
0005434724943	259	208	34G
0005433233280	259	209	34F
0005434725027	259	210	34K
0005435142515	259	211	34J
0005434031949	259	212	35A
0005434031955	259	213	35D
0005433233279	259	214	35B
0005433233375	259	215	35F
0005434724988	259	216	35E
0005434724941	259	217	35H
0005434551007	259	218	36A
0005434724986	259	219	35K
0005433180667	259	220	36C
0005433233479	259	221	36B
0005434724949	259	222	36E
0005434551017	259	223	36D
0005434302440	259	224	36H
0005434551002	259	225	36G
0005434724958	259	226	36F
0005433180703	259	227	36K
0005432277755	259	228	36J
0005435142521	259	229	37B
0005432277748	259	230	37A
0005433233398	259	231	37D
0005433233400	259	232	37F
0005434725010	259	233	37J
0005434725006	259	234	37H
0005433180897	259	235	37G
0005435142518	259	236	38A
0005434724940	259	237	37K
0005433180935	259	238	38C
0005433289774	259	239	38B
0005433233538	259	240	38J
0005434724926	259	241	38H
0005434724975	259	242	39A
0005433233337	259	243	39C
0005434724964	259	244	39B
0005434302441	259	245	39F
0005432277758	259	246	39E
0005433233348	259	247	39D
0005432277760	259	248	39G
0005434724981	259	249	39K
0005433233492	259	250	40C
0005434724991	259	251	40B
0005434725021	259	252	40A
0005433233408	259	253	40D
0005433233468	259	254	40H
0005433180838	259	255	40G
0005433233528	259	256	40F
0005433289758	259	257	40J
0005434724923	259	258	41B
0005434724970	259	259	41A
0005434725034	259	260	40K
0005434725028	259	261	41D
0005433233478	259	262	41F
0005433233475	259	263	41E
0005433180826	259	264	41J
0005433233498	259	265	41H
0005434725024	259	266	41G
0005434735661	259	267	42A
0005434725043	259	268	41K
0005435142528	259	269	42C
0005433233454	259	270	42B
0005435142517	259	271	42E
0005433233322	259	272	42D
0005434551032	259	273	42G
0005434724989	259	274	42F
0005433233721	259	275	42J
0005433180825	259	276	42H
0005432277753	259	277	43A
0005434725030	259	278	42K
0005433233447	259	279	43D
0005434725000	259	280	43C
0005434731151	259	281	43B
0005434725042	259	282	43G
0005433233453	259	283	43F
0005434724990	259	284	43E
0005433233211	259	285	43H
0005433233643	259	286	44A
0005433233298	259	287	43K
0005434551004	259	288	43J
0005434724960	259	289	44B
0005434735663	259	290	44E
0005433233642	259	291	44D
0005433233544	259	292	44G
0005434551034	259	293	44F
0005434724942	259	294	44J
0005433180771	259	295	44H
0005435142526	259	296	45B
0005433233144	259	297	45A
0005434551029	259	298	44K
0005434550992	259	299	45D
0005432277752	259	300	45F
0005433289757	259	301	45E
0005434724982	259	302	45H
0005434724966	259	303	45G
0005434551024	259	304	46A
0005432277759	259	305	45J
0005433233439	259	306	46B
0005434724922	259	307	46E
0005433233712	259	308	46D
0005434725003	259	309	46G
0005434724979	259	310	46F
0005434724996	259	311	46J
0005434724925	259	312	46H
0005433233487	259	313	47A
0005433233376	259	314	46K
0005433180752	259	315	47D
0005434724976	259	316	47C
0005434551026	259	317	47G
0005434724987	259	318	47F
0005434724959	259	319	47E
0005433233723	259	320	47K
0005434724965	259	321	47H
0005433180872	259	322	48D
0005435142529	259	323	48C
0005434550988	259	324	48A
0005434724984	259	325	48F
0005434724997	259	326	48E
0005434724955	259	327	49A
0005434725017	259	328	48K
0005435142516	259	329	49D
0005434724968	259	330	49C
0005435142527	259	331	49G
0005433766601	259	332	49F
0005434725007	259	333	49E
0005434725008	259	334	49K
0005434725009	259	335	49H
0005434725040	259	336	50C
0005435142524	259	337	50A
0005433180827	259	338	50E
0005434302439	259	339	50D
0005434551025	259	340	50H
0005434731148	259	341	50G
0005433233431	259	342	50F
0005434551015	259	343	51E
0005434031948	259	344	51D
0005433233414	259	345	51G
0005434724957	259	346	51F
0005434723603	9820	1	1D
0005433233923	9820	2	1C
0005434735626	9820	3	1A
0005434724127	9820	4	1H
0005434724305	9820	5	1G
0005434032008	9820	6	2A
0005434735638	9820	7	1K
0005434723939	9820	8	2D
0005434724037	9820	9	2C
0005434723940	9820	10	2H
0005434550598	9820	11	2G
0005434724038	9820	12	3A
0005433129254	9820	13	2K
0005433233917	9820	14	3D
0005433233962	9820	15	3C
0005433233960	9820	16	3H
0005433181003	9820	17	3G
0005435142352	9820	18	3K
0005434724126	9820	19	4G
0005434550468	9820	20	4D
0005434550470	9820	21	4H
0005434723327	9820	22	5D
0005433233978	9820	23	5C
0005434550637	9820	24	5H
0005434724129	9820	25	5G
0005433766624	9820	26	11C
0005433126827	9820	27	11A
0005434550603	9820	28	5K
0005434550316	9820	29	11G
0005433181010	9820	30	11F
0005433180994	9820	31	11E
0005433180997	9820	32	12C
0005434550589	9820	33	12A
0005433233967	9820	34	11K
0005433289817	9820	35	12E
0005434723767	9820	36	12H
0005434731113	9820	37	12G
0005434724081	9820	38	12K
0005433233963	9820	39	13D
0005434550573	9820	40	13C
0005433113528	9820	41	13F
0005434550549	9820	42	13E
0005434723401	9820	43	13H
0005433233938	9820	44	13G
0005433766625	9820	45	14A
0005434550444	9820	46	14D
0005433181008	9820	47	14F
0005434724132	9820	48	14E
0005434723971	9820	49	14K
0005433180991	9820	50	14H
0005433181005	9820	51	14G
0005433233922	9820	52	15C
0005434032009	9820	53	15A
0005433233929	9820	54	15E
0005434550376	9820	55	15H
0005433766626	9820	56	15G
0005434550412	9820	57	15K
0005434735636	9820	58	16D
0005434550472	9820	59	16A
0005434731117	9820	60	16F
0005434723614	9820	61	16E
0005433289813	9820	62	16H
0005433126825	9820	63	16G
0005435142470	9820	64	17C
0005434723383	9820	65	17A
0005434724122	9820	66	17E
0005434724030	9820	67	17D
0005433181004	9820	68	17G
0005434724171	9820	69	17F
0005434550329	9820	70	18B
0005433181007	9820	71	18A
0005434731110	9820	72	18E
0005433126824	9820	73	18D
0005434724055	9820	74	18G
0005433180995	9820	75	18F
0005434723877	9820	76	18H
0005434550504	9820	77	19A
0005433233980	9820	78	18K
0005434723815	9820	79	19D
0005434550322	9820	80	19C
0005432199221	9820	81	19B
0005435142413	9820	82	19F
0005433180996	9820	83	19E
0005434550330	9820	84	19H
0005433289814	9820	85	19G
0005433233932	9820	86	19J
0005435142385	9820	87	20C
0005435142406	9820	88	20B
0005433233939	9820	89	20A
0005433233956	9820	90	20E
0005433233934	9820	91	20D
0005435142429	9820	92	20H
0005433233968	9820	93	20K
0005434724161	9820	94	21A
0005434723785	9820	95	21E
0005434550660	9820	96	21D
0005434724304	9820	97	21C
0005434731109	9820	98	21B
0005434723561	9820	99	21F
0005434723605	9820	100	21J
0005434550570	9820	101	21H
0005434724005	9820	102	21G
0005434550514	9820	103	22A
0005434550380	9820	104	21K
0005434550321	9820	105	22C
0005434550550	9820	106	22B
0005433233979	9820	107	22E
0005434724082	9820	108	22D
0005433233933	9820	109	22G
0005433233940	9820	110	22F
0005433233928	9820	111	22K
0005434723843	9820	112	22J
0005433233970	9820	113	22H
0005434550505	9820	114	23A
0005433233982	9820	115	23D
0005434550502	9820	116	23C
0005435142356	9820	117	23G
0005434550314	9820	118	23F
0005434723784	9820	119	23J
0005434724500	9820	120	24D
0005433180989	9820	121	23K
0005434724190	9820	122	24F
0005433233976	9820	123	24E
0005433233918	9820	124	25B
0005433233965	9820	125	25A
0005433233920	9820	126	25C
0005433180987	9820	127	25F
0005433233950	9820	128	25D
0005433233949	9820	129	25H
0005433289816	9820	130	25G
0005433233930	9820	131	25K
0005433233971	9820	132	25J
0005434724191	9820	133	26C
0005434724232	9820	134	26B
0005433180998	9820	135	26E
0005433233981	9820	136	26H
0005434550588	9820	137	26G
0005434731099	9820	138	26F
0005433180999	9820	139	26K
0005434550308	9820	140	26J
0005433289815	9820	141	27B
0005434550471	9820	142	27C
0005434723484	9820	143	27F
0005435142407	9820	144	27E
0005434550374	9820	145	27D
0005433129258	9820	146	27H
0005433766623	9820	147	27K
0005432199218	9820	148	27J
0005435142355	9820	149	28C
0005435142351	9820	150	28B
0005434724398	9820	151	28H
0005434550439	9820	152	29B
0005434731112	9820	153	29A
0005434724043	9820	154	28K
0005434723483	9820	155	29D
0005434723705	9820	156	29C
0005434550462	9820	157	29F
0005434723749	9820	158	29E
0005434724118	9820	159	29H
0005433129257	9820	160	30A
0005433126823	9820	161	29J
0005433233955	9820	162	30B
0005433233966	9820	163	30E
0005434723907	9820	164	30H
0005434550299	9820	165	30G
0005433233943	9820	166	30F
0005433181009	9820	167	30J
0005434723812	9820	168	31D
0005433180985	9820	169	31C
0005434723591	9820	170	31F
0005434731111	9820	171	31E
0005434723786	9820	172	31J
0005433233952	9820	173	31H
0005433181000	9820	174	31G
0005434723987	9820	175	31K
0005433233961	9820	176	32C
0005434550306	9820	177	32B
0005433233974	9820	178	32E
0005432199222	9820	179	32D
0005434550567	9820	180	32F
0005433233935	9820	181	32J
0005434550681	9820	182	32H
0005434723310	9820	183	33A
0005435142348	9820	184	32K
0005434723941	9820	185	33F
0005433180992	9820	186	33E
0005434724039	9820	187	33D
0005434723801	9820	188	33H
0005434723933	9820	189	33G
0005434550568	9820	190	34A
0005433233951	9820	191	33K
0005434550375	9820	192	34C
0005434735624	9820	193	34B
0005433233919	9820	194	34E
0005434735625	9820	195	34D
0005433233975	9820	196	34G
0005433233957	9820	197	34F
0005433233944	9820	198	34K
0005433233925	9820	199	34J
0005433233953	9820	200	34H
0005434032006	9820	201	35B
0005434724536	9820	202	35A
0005434723685	9820	203	35D
0005433233972	9820	204	35C
0005434723970	9820	205	35F
0005434724066	9820	206	35E
0005434723949	9820	207	35H
0005434724006	9820	208	35G
0005434723995	9820	209	36A
0005433289818	9820	210	35K
0005434723992	9820	211	35J
0005434724016	9820	212	36C
0005433766627	9820	213	36B
0005434723864	9820	214	36D
0005435142340	9820	215	36G
0005433233948	9820	216	36K
0005434724265	9820	217	36H
0005433113526	9820	218	37B
0005434550461	9820	219	37A
0005433233926	9820	220	37E
0005434723704	9820	221	37D
0005434723845	9820	222	37C
0005433233959	9820	223	37G
0005434723996	9820	224	37F
0005433181001	9820	225	37J
0005434724068	9820	226	37H
0005434724214	9820	227	38A
0005433180986	9820	228	38C
0005434724107	9820	229	38B
0005432199220	9820	230	38K
0005434550309	9820	231	38J
0005434724192	9820	232	38H
0005433113527	9820	233	39B
0005434724056	9820	234	39A
0005434724537	9820	235	39C
0005433289819	9820	236	39E
0005434550445	9820	237	39J
0005433233942	9820	238	39H
0005434550387	9820	239	39G
0005434723974	9820	240	40A
0005435142430	9820	241	39K
0005434723946	9820	242	40C
0005434723326	9820	243	40D
0005434724431	9820	244	40H
0005435142359	9820	245	40G
0005434550638	9820	246	40F
0005434550469	9820	247	40J
0005434550264	9820	248	41B
0005434724098	9820	249	41A
0005434724162	9820	250	40K
0005434724430	9820	251	41D
0005434724099	9820	252	41C
0005434723604	9820	253	41E
0005433233969	9820	254	41J
0005434032004	9820	255	41H
0005434723759	9820	256	41G
0005433126826	9820	257	42A
0005433233946	9820	258	41K
0005434723703	9820	259	42F
0005434723947	9820	260	42E
0005433129256	9820	261	42D
0005433233954	9820	262	42G
0005433233977	9820	263	42J
0005434724130	9820	264	42H
0005434724026	9820	265	43A
0005434723768	9820	266	42K
0005434724015	9820	267	43D
0005433181002	9820	268	43C
0005433233924	9820	269	43B
0005434032007	9820	270	43E
0005434723935	9820	271	43H
0005434032005	9820	272	43J
0005433233921	9820	273	44C
0005435142361	9820	274	44B
0005434550803	9820	275	44E
0005434723655	9820	276	44D
0005433233964	9820	277	44G
0005434724067	9820	278	44F
0005434550599	9820	279	44J
0005434550438	9820	280	44H
0005434723810	9820	281	45B
0005434550300	9820	282	45A
0005433129259	9820	283	44K
0005434724361	9820	284	45C
0005434724079	9820	285	45F
0005434724119	9820	286	45J
0005433233945	9820	287	45G
0005434723975	9820	288	45K
0005433181006	9820	289	46B
0005434550576	9820	290	46A
0005434550802	9820	291	46E
0005433233947	9820	292	46C
0005433180990	9820	293	46G
0005434723562	9820	294	46F
0005434723932	9820	295	46J
0005433180988	9820	296	46H
0005434723811	9820	297	46K
0005433180993	9820	298	47D
0005433126828	9820	299	47G
0005433233927	9820	300	47F
0005434302398	9820	301	47E
0005434724213	9820	302	47H
0005432199219	9820	303	48D
0005434723699	9820	304	48C
0005435142360	9820	305	48A
0005434724010	9820	306	48E
0005434723908	9820	307	48H
0005434724306	9820	308	48G
0005433233931	9820	309	49A
0005433233936	9820	310	48K
0005433129255	9820	311	49D
0005434550583	9820	312	49F
0005434723964	9820	313	49K
0005433233937	9820	314	50C
0005433233941	9820	315	50A
0005433233973	9820	316	50E
0005432199217	9820	317	50D
0005435142471	9820	318	50H
0005434735637	9820	319	50G
0005434723863	9820	320	50F
0005434550451	9820	321	51D
0005434550315	9820	322	50K
0005434724399	9820	323	51F
0005434723930	9820	324	51E
0005433233958	9820	325	51G
0005432527399	7771	1	1D
0005432527426	7771	2	1C
0005435212537	7771	3	1A
0005432527429	7771	4	1H
0005432527431	7771	5	1G
0005434067253	7771	6	2C
0005432527442	7771	7	2A
0005432535813	7771	8	2H
0005432527428	7771	9	2G
0005432069598	7771	10	2D
0005435212865	7771	11	3A
0005434067295	7771	12	3D
0005432428915	7771	13	3C
0005432527419	7771	14	3K
0005432527434	7771	15	3H
0005435212524	7771	16	3G
0005434067254	7771	17	4C
0005432527451	7771	18	4A
0005432527495	7771	19	4G
0005434067292	7771	20	4D
0005432527457	7771	21	4H
0005432527384	7771	22	5D
0005432527427	7771	23	5C
0005432527441	7771	24	5H
0005434067302	7771	25	11A
0005432527382	7771	26	5K
0005435630920	7771	27	11D
0005432535812	7771	28	11C
0005432069595	7771	29	11F
0005432527463	7771	30	11E
0005434067249	7771	31	11K
0005434067274	7771	32	11H
0005435212604	7771	33	11G
0005435212675	7771	34	12A
0005435212851	7771	35	12E
0005435212489	7771	36	12D
0005432527407	7771	37	13A
0005434067298	7771	38	13D
0005434067248	7771	39	13C
0005432527420	7771	40	13F
0005434067277	7771	41	13E
0005432527416	7771	42	13G
0005434067251	7771	43	13K
0005434067293	7771	44	14E
0005435630923	7771	45	14C
0005432527479	7771	46	14G
0005432527445	7771	47	14K
0005432069589	7771	48	14H
0005432527379	7771	49	15C
0005432527381	7771	50	15F
0005434067282	7771	51	15E
0005432527506	7771	52	15D
0005435212549	7771	53	15G
0005432527511	7771	54	15K
0005432527412	7771	55	16D
0005432527400	7771	56	16C
0005432527447	7771	57	16F
0005435213000	7771	58	16E
0005434067239	7771	59	16H
0005434067303	7771	60	17C
0005432527470	7771	61	17A
0005432527508	7771	62	17E
0005434067284	7771	63	17D
0005434067258	7771	64	17F
0005434067246	7771	65	18A
0005432527388	7771	66	17K
0005432069592	7771	67	17H
0005432527394	7771	68	18C
0005434067241	7771	69	18B
0005432527481	7771	70	18E
0005432527414	7771	71	18D
0005432150165	7771	72	18K
0005432537049	7771	73	18J
0005432527408	7771	74	19B
0005432527489	7771	75	19A
0005435212860	7771	76	19D
0005435212704	7771	77	19C
0005432535814	7771	78	19E
0005435725541	7771	79	19H
0005432527509	7771	80	19K
0005435212580	7771	81	20C
0005432069590	7771	82	20B
0005434067259	7771	83	20A
0005432527477	7771	84	20E
0005435212620	7771	85	20G
0005434067301	7771	86	20F
0005434067289	7771	87	20K
0005434067261	7771	88	20J
0005434067276	7771	89	21A
0005434067299	7771	90	21D
0005432527507	7771	91	21C
0005434067243	7771	92	21G
0005435212688	7771	93	21F
0005432527401	7771	94	21E
0005432527490	7771	95	21H
0005432527460	7771	96	22A
0005432527453	7771	97	21K
0005434067257	7771	98	22D
0005432527455	7771	99	22C
0005432527497	7771	100	22B
0005435212526	7771	101	22F
0005432069599	7771	102	22E
0005432527396	7771	103	22G
0005435212676	7771	104	22K
0005432527387	7771	105	22J
0005434067297	7771	106	22H
0005432527437	7771	107	23B
0005434067244	7771	108	23C
0005432150162	7771	109	23G
0005432527409	7771	110	23F
0005433656622	7771	111	23H
0005432527448	7771	112	24D
0005434067265	7771	113	23K
0005434067269	7771	114	24E
0005432527500	7771	115	24G
0005432527424	7771	116	25C
0005432527486	7771	117	25H
0005434067281	7771	118	25G
0005432527494	7771	119	25K
0005432527478	7771	120	25J
0005435212903	7771	121	26B
0005435212737	7771	122	26A
0005432537050	7771	123	26D
0005432527450	7771	124	26G
0005435212666	7771	125	26F
0005435212798	7771	126	26K
0005434067305	7771	127	26J
0005432150163	7771	128	27B
0005435725539	7771	129	27A
0005432527465	7771	130	27D
0005432527406	7771	131	27C
0005432527491	7771	132	27F
0005434067272	7771	133	27E
0005435212929	7771	134	27K
0005434067275	7771	135	28C
0005434067290	7771	136	28A
0005432069600	7771	137	28D
0005432527473	7771	138	28G
0005434067263	7771	139	28F
0005432527498	7771	140	28E
0005435212603	7771	141	28J
0005432428914	7771	142	28H
0005432527472	7771	143	29A
0005434067310	7771	144	29D
0005432150159	7771	145	29C
0005435212671	7771	146	29B
0005432527397	7771	147	29F
0005432527403	7771	148	29E
0005432069596	7771	149	29H
0005434067252	7771	150	29G
0005432527444	7771	151	29K
0005435630933	7771	152	29J
0005432527496	7771	153	30C
0005434067240	7771	154	30B
0005432527466	7771	155	30A
0005432527386	7771	156	30E
0005435212624	7771	157	30D
0005432527510	7771	158	30H
0005434067271	7771	159	30G
0005432527485	7771	160	30F
0005432527435	7771	161	31B
0005435212579	7771	162	31A
0005432527413	7771	163	30K
0005434067267	7771	164	31C
0005435212525	7771	165	31F
0005435212703	7771	166	31H
0005432069602	7771	167	31G
0005432527482	7771	168	31K
0005432527422	7771	169	32C
0005432527392	7771	170	32E
0005432069597	7771	171	32G
0005434067256	7771	172	32F
0005434067286	7771	173	32J
0005432527502	7771	174	33A
0005432527467	7771	175	33D
0005434067250	7771	176	33B
0005435212794	7771	177	33F
0005435212522	7771	178	33E
0005432069601	7771	179	33J
0005432527503	7771	180	33G
0005432069591	7771	181	34A
0005432527404	7771	182	33K
0005434067283	7771	183	34B
0005434067308	7771	184	34E
0005432527512	7771	185	34D
0005434067242	7771	186	34C
0005432527480	7771	187	34G
0005432527487	7771	188	34F
0005435212582	7771	189	34J
0005432527462	7771	190	34H
0005432527449	7771	191	35A
0005435212904	7771	192	34K
0005432527417	7771	193	35E
0005434067268	7771	194	35C
0005432150160	7771	195	35G
0005432527471	7771	196	36A
0005435212621	7771	197	35J
0005432527456	7771	198	36D
0005432527443	7771	199	36C
0005432527391	7771	200	36B
0005432527484	7771	201	36F
0005432527492	7771	202	36E
0005432527474	7771	203	36G
0005432527476	7771	204	36K
0005435212856	7771	205	36H
0005432535815	7771	206	37B
0005432150161	7771	207	37A
0005435212595	7771	208	37D
0005435212536	7771	209	37F
0005434067262	7771	210	37H
0005435725540	7771	211	38A
0005432527410	7771	212	37K
0005434067307	7771	213	37J
0005435212724	7771	214	38B
0005432527398	7771	215	38J
0005434067288	7771	216	39B
0005432527436	7771	217	38K
0005432527483	7771	218	39D
0005432527464	7771	219	39C
0005434067287	7771	220	39F
0005434067273	7771	221	39E
0005432527438	7771	222	39K
0005434067264	7771	223	40C
0005434067266	7771	224	40B
0005435725547	7771	225	40E
0005434067296	7771	226	40D
0005432527405	7771	227	40G
0005434067279	7771	228	40F
0005432527459	7771	229	40J
0005432069593	7771	230	40H
0005432527383	7771	231	41A
0005432537048	7771	232	40K
0005435212594	7771	233	41C
0005434067300	7771	234	41B
0005435212689	7771	235	41F
0005434067309	7771	236	41E
0005432527499	7771	237	41H
0005432527504	7771	238	42A
0005432527425	7771	239	41K
0005432527458	7771	240	42D
0005432533281	7771	241	42C
0005432533280	7771	242	42H
0005432527461	7771	243	42G
0005432535816	7771	244	42F
0005432527468	7771	245	42K
0005432527501	7771	246	42J
0005435212780	7771	247	43A
0005432527452	7771	248	43D
0005434067278	7771	249	43C
0005432527380	7771	250	43B
0005435212488	7771	251	43J
0005435212655	7771	252	43H
0005434067294	7771	253	43G
0005434067306	7771	254	43K
0005434067247	7771	255	44B
0005432527385	7771	256	44E
0005434067255	7771	257	44C
0005432069594	7771	258	44G
0005432527446	7771	259	44F
0005435212852	7771	260	44K
0005432527395	7771	261	44J
0005432527389	7771	262	45B
0005435212799	7771	263	45A
0005435212725	7771	264	45D
0005434067260	7771	265	45C
0005434067270	7771	266	45F
0005432527439	7771	267	45E
0005435212864	7771	268	45G
0005432527378	7771	269	45J
0005435213001	7771	270	46C
0005432527505	7771	271	46B
0005434067245	7771	272	46E
0005432527415	7771	273	46F
0005435212645	7771	274	46H
0005432527493	7771	275	47A
0005435212605	7771	276	47E
0005434067304	7771	277	47D
0005432527475	7771	278	47C
0005432527390	7771	279	47G
0005435212905	7771	280	47F
0005432527430	7771	281	47K
0005435212938	7771	282	47H
0005432527488	7771	283	48C
0005435212723	7771	284	48H
0005432150164	7771	285	48G
0005435212439	7771	286	49A
0005434067291	7771	287	48K
0005432527440	7771	288	49D
0005432527469	7771	289	49C
0005432527418	7771	290	49G
0005432069588	7771	291	49F
0005432527433	7771	292	49E
0005434067285	7771	293	49K
0005432527454	7771	294	49H
0005432527421	7771	295	50E
0005432527411	7771	296	50D
0005434067280	7771	297	50H
0005432527393	7771	298	50G
0005435212581	7771	299	51D
0005432527402	7771	300	50K
0005432527423	7771	301	51F
0005432527432	7771	302	51E
0005432428913	7771	303	51G
0005432047535	5312	1	1D
0005435423733	5312	2	1G
0005435613186	5312	3	1K
0005434244581	5312	4	1H
0005432133154	5312	5	2C
0005434344080	5312	6	2A
0005435613206	5312	7	2H
0005434573299	5312	8	2G
0005435423727	5312	9	2D
0005435613144	5312	10	3A
0005435424174	5312	11	3G
0005434244557	5312	12	3H
0005435319452	5312	13	4A
0005434573289	5312	14	3K
0005434573297	5312	15	4G
0005435097166	5312	16	4D
0005435424034	5312	17	4K
0005435613164	5312	18	4H
0005434344064	5312	19	5D
0005432133145	5312	20	5C
0005435424138	5312	21	5A
0005435555361	5312	22	5H
0005435613207	5312	23	5G
0005434244633	5312	24	11A
0005435424088	5312	25	5K
0005432047534	5312	26	11D
0005435613234	5312	27	11F
0005435613230	5312	28	11E
0005435613240	5312	29	11H
0005435613151	5312	30	11G
0005435613134	5312	31	12C
0005435491432	5312	32	12E
0005435424032	5312	33	12D
0005435097167	5312	34	12H
0005435613253	5312	35	12G
0005435319473	5312	36	12F
0005435491431	5312	37	12K
0005435423964	5312	38	13D
0005435613251	5312	39	13C
0005435424112	5312	40	13A
0005435613243	5312	41	13F
0005435613159	5312	42	13E
0005434244563	5312	43	13H
0005435613211	5312	44	14C
0005435613208	5312	45	14A
0005435613196	5312	46	14F
0005434344096	5312	47	14K
0005435423852	5312	48	14H
0005434344088	5312	49	15A
0005435424035	5312	50	15E
0005434244709	5312	51	15D
0005435423934	5312	52	15G
0005435319451	5312	53	15F
0005434244710	5312	54	15K
0005434244561	5312	55	15H
0005434573292	5312	56	16D
0005435613249	5312	57	16C
0005435613155	5312	58	16E
0005435613231	5312	59	16H
0005435613135	5312	60	16G
0005434244573	5312	61	17C
0005435424149	5312	62	17A
0005435613255	5312	63	17D
0005434244612	5312	64	17H
0005434573302	5312	65	17F
0005435613172	5312	66	17E
0005435613241	5312	67	18B
0005434244613	5312	68	18A
0005434573293	5312	69	18E
0005435613170	5312	70	18D
0005435613153	5312	71	18C
0005434344075	5312	72	18G
0005434344087	5312	73	18F
0005435613182	5312	74	18K
0005435613226	5312	75	18J
0005435613175	5312	76	19D
0005435423747	5312	77	19C
0005435613133	5312	78	19B
0005434656531	5312	79	19E
0005435613245	5312	80	19H
0005435423878	5312	81	19G
0005435424145	5312	82	19K
0005434573296	5312	83	20B
0005435423717	5312	84	20A
0005435613257	5312	85	20E
0005435613239	5312	86	20D
0005435613143	5312	87	20H
0005435380244	5312	88	20F
0005435613137	5312	89	21B
0005434344092	5312	90	21A
0005435613237	5312	91	20K
0005435613247	5312	92	21D
0005435613188	5312	93	21C
0005435613156	5312	94	21F
0005435613221	5312	95	21E
0005432133152	5312	96	21H
0005432133156	5312	97	21G
0005434244560	5312	98	21K
0005434244649	5312	99	21J
0005435613213	5312	100	22C
0005435613254	5312	101	22B
0005434344078	5312	102	22F
0005435613181	5312	103	22E
0005435423970	5312	104	22D
0005435097171	5312	105	22H
0005435319491	5312	106	22G
0005435423865	5312	107	22K
0005435613217	5312	108	22J
0005435424068	5312	109	23B
0005435613171	5312	110	23A
0005435613236	5312	111	23C
0005435319472	5312	112	23F
0005435613246	5312	113	23E
0005435613205	5312	114	23J
0005435613138	5312	115	23H
0005435302135	5312	116	23G
0005435380240	5312	117	23K
0005435613129	5312	118	24F
0005435423815	5312	119	24E
0005435613190	5312	120	24D
0005435613140	5312	121	25B
0005435490215	5312	122	25A
0005434244541	5312	123	24G
0005435423998	5312	124	25D
0005435613223	5312	125	25C
0005435424121	5312	126	25F
0005433719097	5312	127	25E
0005435613152	5312	128	25H
0005434344068	5312	129	25G
0005435423781	5312	130	25J
0005435319492	5312	131	26B
0005435613183	5312	132	26E
0005434344079	5312	133	26G
0005435613139	5312	134	26F
0005434244645	5312	135	26J
0005434344089	5312	136	26H
0005435613147	5312	137	27A
0005435613214	5312	138	26K
0005434244634	5312	139	27D
0005435042823	5312	140	27B
0005434573300	5312	141	27H
0005434344065	5312	142	27G
0005432047533	5312	143	27F
0005435613161	5312	144	28A
0005435613176	5312	145	27K
0005434244540	5312	146	27J
0005434344073	5312	147	28B
0005434244608	5312	148	28E
0005434573295	5312	149	28D
0005434573290	5312	150	28C
0005435613192	5312	151	28F
0005435613210	5312	152	28K
0005435613203	5312	153	28J
0005435613142	5312	154	28H
0005432133147	5312	155	29B
0005435613235	5312	156	29A
0005435613227	5312	157	29D
0005435613229	5312	158	29C
0005435380251	5312	159	29F
0005435613149	5312	160	29E
0005433719085	5312	161	29H
0005432133150	5312	162	30A
0005434344085	5312	163	29K
0005435613252	5312	164	29J
0005435613163	5312	165	30B
0005435423999	5312	166	30E
0005435613160	5312	167	30D
0005435424111	5312	168	30C
0005435613197	5312	169	30G
0005435319493	5312	170	30F
0005435613244	5312	171	30J
0005434344098	5312	172	30H
0005434244640	5312	173	31B
0005434344072	5312	174	31A
0005435424173	5312	175	30K
0005435423863	5312	176	31D
0005434244711	5312	177	31C
0005435424013	5312	178	31F
0005435423746	5312	179	31E
0005435613225	5312	180	31J
0005432133153	5312	181	31H
0005434344083	5312	182	31G
0005435613127	5312	183	32A
0005434344070	5312	184	31K
0005434244609	5312	185	32C
0005434244639	5312	186	32B
0005432133144	5312	187	32E
0005435424184	5312	188	32D
0005434344097	5312	189	32G
0005434344084	5312	190	32F
0005434244578	5312	191	32K
0005435613219	5312	192	32J
0005435424205	5312	193	32H
0005435424114	5312	194	33D
0005434344074	5312	195	33C
0005435490214	5312	196	33B
0005435490213	5312	197	33F
0005435613215	5312	198	33E
0005435097170	5312	199	33J
0005435424094	5312	200	33H
0005435423930	5312	201	33G
0005435423627	5312	202	34C
0005435613228	5312	203	34B
0005435380242	5312	204	34A
0005435613157	5312	205	34E
0005434244584	5312	206	34D
0005434344071	5312	207	34G
0005435423974	5312	208	34F
0005435613248	5312	209	34K
0005435380241	5312	210	34J
0005434244670	5312	211	34H
0005435423933	5312	212	35B
0005435555359	5312	213	35A
0005435613220	5312	214	35D
0005434344082	5312	215	35C
0005435613179	5312	216	35E
0005435613250	5312	217	35J
0005435424146	5312	218	35H
0005435423854	5312	219	36A
0005435423626	5312	220	36D
0005435319426	5312	221	36C
0005435613209	5312	222	36B
0005432133151	5312	223	36E
0005435613199	5312	224	36G
0005432133142	5312	225	36K
0005434344086	5312	226	36J
0005432133143	5312	227	37B
0005434656524	5312	228	37A
0005435424168	5312	229	37D
0005435613162	5312	230	37C
0005435613146	5312	231	37F
0005434656530	5312	232	37H
0005435613195	5312	233	37G
0005435613178	5312	234	38A
0005435613169	5312	235	37K
0005434344077	5312	236	37J
0005434573294	5312	237	38C
0005435423822	5312	238	38B
0005432133148	5312	239	38H
0005435613224	5312	240	39A
0005432840983	5312	241	38K
0005434344063	5312	242	39D
0005435423780	5312	243	39B
0005435613166	5312	244	39F
0005435613150	5312	245	39E
0005435613202	5312	246	39H
0005435424137	5312	247	39G
0005435424122	5312	248	39K
0005435613126	5312	249	39J
0005435423853	5312	250	40C
0005435613145	5312	251	40B
0005434573298	5312	252	40A
0005434244648	5312	253	40E
0005435613130	5312	254	40D
0005434244692	5312	255	40F
0005435613222	5312	256	40H
0005434344067	5312	257	41B
0005435613132	5312	258	41A
0005434344061	5312	259	40K
0005435613200	5312	260	41D
0005435613168	5312	261	41F
0005435424206	5312	262	41H
0005435613216	5312	263	41G
0005435613204	5312	264	42A
0005434573301	5312	265	41K
0005434344093	5312	266	42C
0005435613191	5312	267	42B
0005435613158	5312	268	42E
0005435613256	5312	269	42D
0005435490211	5312	270	42G
0005435613233	5312	271	42F
0005435613212	5312	272	42J
0005432047536	5312	273	43B
0005434244580	5312	274	43A
0005434344062	5312	275	43D
0005434656527	5312	276	43C
0005435613201	5312	277	43F
0005434244518	5312	278	43E
0005435424089	5312	279	43J
0005432840984	5312	280	43H
0005435097169	5312	281	43G
0005434244606	5312	282	44A
0005435613154	5312	283	43K
0005435613238	5312	284	44B
0005435613141	5312	285	44E
0005435613185	5312	286	44D
0005434344066	5312	287	44C
0005434244517	5312	288	44F
0005435423861	5312	289	44J
0005434573303	5312	290	44H
0005435613174	5312	291	45B
0005435613173	5312	292	45A
0005435302134	5312	293	44K
0005432133149	5312	294	45D
0005435097168	5312	295	45C
0005435613184	5312	296	45F
0005435613167	5312	297	45E
0005434344091	5312	298	45H
0005435424115	5312	299	45G
0005432133146	5312	300	46A
0005434344076	5312	301	45K
0005435613128	5312	302	45J
0005435302133	5312	303	46C
0005435613136	5312	304	46B
0005435613148	5312	305	46E
0005434244524	5312	306	46D
0005434573291	5312	307	46H
0005434344095	5312	308	46G
0005435423971	5312	309	46F
0005435423855	5312	310	46K
0005434344081	5312	311	46J
0005434244672	5312	312	47C
0005435423897	5312	313	47A
0005435555360	5312	314	47D
0005435613198	5312	315	47G
0005434244671	5312	316	47E
0005435613194	5312	317	48A
0005435423986	5312	318	47H
0005435613242	5312	319	48C
0005435380243	5312	320	48E
0005435613232	5312	321	48D
0005432133155	5312	322	48H
0005435613193	5312	323	48G
0005435613165	5312	324	49C
0005435304995	5312	325	49A
0005435613187	5312	326	48K
0005434244720	5312	327	49E
0005435613189	5312	328	49D
0005434344090	5312	329	49G
0005435423899	5312	330	49F
0005435613131	5312	331	49K
0005435613180	5312	332	49H
0005434344069	5312	333	50C
0005435423885	5312	334	50A
0005435423814	5312	335	50F
0005435613177	5312	336	50D
0005435424070	5312	337	50G
0005435424119	5312	338	51D
0005435423960	5312	339	50K
0005434244558	5312	340	50H
0005435490212	5312	341	51E
0005434344094	5312	342	51G
0005435613218	5312	343	51F
0005435611806	10875	1	1C
0005435612117	10875	2	1A
0005435612090	10875	3	1G
0005434343620	10875	4	2A
0005432165011	10875	5	1K
0005435319539	10875	6	1H
0005434244858	10875	7	2C
0005435612236	10875	8	2D
0005435424553	10875	9	3A
0005435424501	10875	10	2K
0005435424540	10875	11	3G
0005432363402	10875	12	3D
0005434656547	10875	13	3C
0005435380271	10875	14	3K
0005432165004	10875	15	3H
0005435612249	10875	16	4A
0005434244862	10875	17	4G
0005435097082	10875	18	4D
0005435612597	10875	19	4K
0005435424506	10875	20	4H
0005435304137	10875	21	5C
0005434343675	10875	22	5H
0005435424526	10875	23	5G
0005435424503	10875	24	11A
0005435424529	10875	25	5K
0005432165005	10875	26	11D
0005435424493	10875	27	11C
0005435611905	10875	28	11F
0005434573106	10875	29	11E
0005433719127	10875	30	11K
0005435319532	10875	31	11H
0005435424532	10875	32	12C
0005435424510	10875	33	12A
0005435424509	10875	34	12F
0005435612088	10875	35	12D
0005435097081	10875	36	12H
0005435319540	10875	37	12G
0005434343637	10875	38	12K
0005433719128	10875	39	13D
0005435097087	10875	40	13C
0005435612354	10875	41	13A
0005435612168	10875	42	13F
0005435612169	10875	43	13H
0005435612466	10875	44	13G
0005435424504	10875	45	14A
0005435611827	10875	46	14D
0005434244866	10875	47	14C
0005434343695	10875	48	14G
0005434343757	10875	49	14F
0005434244873	10875	50	14E
0005435424547	10875	51	14K
0005434343627	10875	52	14H
0005435424497	10875	53	15C
0005435612055	10875	54	15E
0005435612091	10875	55	15D
0005435612195	10875	56	15F
0005435612598	10875	57	15K
0005435612408	10875	58	15H
0005435097057	10875	59	16C
0005435424516	10875	60	16A
0005434343708	10875	61	16F
0005434343644	10875	62	16E
0005435612174	10875	63	16G
0005432165010	10875	64	17C
0005435424528	10875	65	17A
0005435612003	10875	66	16K
0005435097051	10875	67	17E
0005435097048	10875	68	17D
0005435611976	10875	69	17G
0005435612198	10875	70	17F
0005434244874	10875	71	17K
0005434343917	10875	72	17H
0005432166889	10875	73	18B
0005435612119	10875	74	18E
0005435424544	10875	75	18G
0005435612166	10875	76	18F
0005435380270	10875	77	18J
0005435097068	10875	78	19A
0005435612109	10875	79	19D
0005435424533	10875	80	19C
0005435612116	10875	81	19F
0005435612230	10875	82	19E
0005434244863	10875	83	19H
0005435424494	10875	84	19G
0005435424530	10875	85	19K
0005434244872	10875	86	20C
0005434343889	10875	87	20B
0005435611935	10875	88	20A
0005434343613	10875	89	20F
0005432363401	10875	90	20E
0005435611828	10875	91	20D
0005435612465	10875	92	20J
0005434343685	10875	93	20H
0005435424537	10875	94	21B
0005435611854	10875	95	21A
0005435424546	10875	96	20K
0005435612295	10875	97	21D
0005434244852	10875	98	21C
0005435611921	10875	99	21F
0005435424560	10875	100	21G
0005435424518	10875	101	22A
0005434244869	10875	102	21K
0005435612025	10875	103	22E
0005435424551	10875	104	22H
0005434343595	10875	105	22F
0005435097056	10875	106	22K
0005435490190	10875	107	22J
0005435612303	10875	108	23B
0005434343626	10875	109	23D
0005435380274	10875	110	23C
0005432166887	10875	111	23F
0005435424555	10875	112	23H
0005435424556	10875	113	23G
0005435612472	10875	114	24D
0005434244857	10875	115	23K
0005435424527	10875	116	24E
0005435612231	10875	117	25A
0005435612362	10875	118	24G
0005435424500	10875	119	25D
0005435612194	10875	120	25C
0005435612489	10875	121	25B
0005435097080	10875	122	25F
0005435424507	10875	123	25E
0005435611711	10875	124	25H
0005435612357	10875	125	25G
0005435097065	10875	126	25K
0005434343831	10875	127	25J
0005435424512	10875	128	26C
0005435612118	10875	129	26B
0005435424535	10875	130	26A
0005435612211	10875	131	26E
0005435612306	10875	132	26D
0005434343612	10875	133	26J
0005435097049	10875	134	26H
0005434343636	10875	135	27B
0005435424534	10875	136	26K
0005435612344	10875	137	27C
0005435612240	10875	138	27E
0005435424496	10875	139	27D
0005435612069	10875	140	27H
0005435612441	10875	141	27G
0005434244861	10875	142	27F
0005435097085	10875	143	27K
0005435612200	10875	144	27J
0005435424557	10875	145	28A
0005435612360	10875	146	28E
0005434573147	10875	147	28C
0005435611992	10875	148	28F
0005435612196	10875	149	28J
0005435612588	10875	150	28H
0005435424552	10875	151	29B
0005435611991	10875	152	29A
0005435612467	10875	153	29D
0005434244854	10875	154	29C
0005435612503	10875	155	29G
0005435097066	10875	156	30A
0005434244853	10875	157	29K
0005435612212	10875	158	29J
0005434244848	10875	159	30B
0005435612068	10875	160	30D
0005435612146	10875	161	30G
0005435319536	10875	162	30F
0005435097061	10875	163	30J
0005435424495	10875	164	30H
0005434244860	10875	165	31B
0005435424519	10875	166	31A
0005434343690	10875	167	30K
0005435612523	10875	168	31D
0005434244847	10875	169	31G
0005434244871	10875	170	31F
0005435424515	10875	171	31E
0005435319533	10875	172	31J
0005435612081	10875	173	31H
0005435424543	10875	174	32A
0005435612594	10875	175	31K
0005435612217	10875	176	32B
0005435612185	10875	177	32E
0005435424549	10875	178	32D
0005435612084	10875	179	32F
0005434573115	10875	180	32J
0005434244851	10875	181	32H
0005434656548	10875	182	33B
0005434244859	10875	183	33A
0005435612057	10875	184	32K
0005435612033	10875	185	33D
0005435612070	10875	186	33C
0005435097079	10875	187	33F
0005435612029	10875	188	33E
0005435424513	10875	189	34A
0005434343639	10875	190	33K
0005435612287	10875	191	33J
0005435612407	10875	192	34C
0005435612353	10875	193	34B
0005434244870	10875	194	34E
0005434343715	10875	195	34D
0005435612087	10875	196	34G
0005435612325	10875	197	34F
0005432841004	10875	198	34J
0005435612399	10875	199	34H
0005435611792	10875	200	35A
0005434343741	10875	201	34K
0005434343720	10875	202	35D
0005435424559	10875	203	35C
0005432363403	10875	204	35G
0005434244864	10875	205	35F
0005432841005	10875	206	35E
0005432165003	10875	207	36A
0005432165006	10875	208	35K
0005435611904	10875	209	35J
0005435612241	10875	210	36C
0005435424524	10875	211	36B
0005435424541	10875	212	36F
0005435612359	10875	213	36E
0005434244867	10875	214	36D
0005434343772	10875	215	36G
0005435097097	10875	216	36K
0005434343701	10875	217	36J
0005434343643	10875	218	36H
0005435612145	10875	219	37D
0005435424538	10875	220	37C
0005435424558	10875	221	37F
0005435424561	10875	222	37E
0005435424505	10875	223	37G
0005435424545	10875	224	38A
0005435612002	10875	225	37J
0005435612450	10875	226	38C
0005435611920	10875	227	38B
0005435611895	10875	228	38J
0005434343716	10875	229	38H
0005435612401	10875	230	39B
0005434343634	10875	231	39A
0005435612343	10875	232	38K
0005435424531	10875	233	39D
0005434343586	10875	234	39F
0005434244868	10875	235	39E
0005434343633	10875	236	39H
0005434343721	10875	237	39G
0005435424499	10875	238	39K
0005432165008	10875	239	40C
0005435319537	10875	240	40B
0005435424536	10875	241	40E
0005435612130	10875	242	40D
0005435097060	10875	243	40G
0005435424554	10875	244	40H
0005435611826	10875	245	41B
0005434573148	10875	246	41C
0005435612140	10875	247	41F
0005432166888	10875	248	41E
0005435424522	10875	249	41J
0005435424517	10875	250	41H
0005432166886	10875	251	41K
0005435424498	10875	252	42B
0005435380272	10875	253	42A
0005434343655	10875	254	42D
0005435424550	10875	255	42G
0005435424539	10875	256	42F
0005435612172	10875	257	42H
0005435611943	10875	258	42K
0005435612034	10875	259	43C
0005435611903	10875	260	43F
0005434343585	10875	261	43E
0005434244855	10875	262	43G
0005435097086	10875	263	43K
0005435380273	10875	264	44C
0005435304138	10875	265	44B
0005434244846	10875	266	44A
0005434343596	10875	267	44E
0005434343617	10875	268	44D
0005434343656	10875	269	44H
0005435612368	10875	270	44G
0005435424511	10875	271	44J
0005434343773	10875	272	45D
0005434244856	10875	273	45F
0005435097058	10875	274	45E
0005434573105	10875	275	45J
0005432165009	10875	276	45H
0005434244849	10875	277	45G
0005434343625	10875	278	46B
0005435612115	10875	279	46A
0005435612173	10875	280	46E
0005435097059	10875	281	46C
0005435319535	10875	282	46G
0005435319538	10875	283	46K
0005435424508	10875	284	46J
0005435612367	10875	285	47A
0005435612110	10875	286	47D
0005434343614	10875	287	47C
0005434343761	10875	288	47G
0005435424520	10875	289	47F
0005434244865	10875	290	47K
0005435491405	10875	291	47H
0005434343674	10875	292	48D
0005435319534	10875	293	48C
0005434244850	10875	294	48A
0005432363404	10875	295	48E
0005435424523	10875	296	48G
0005435612335	10875	297	49C
0005435424502	10875	298	49A
0005435424525	10875	299	48K
0005435611942	10875	300	49D
0005435424514	10875	301	49G
0005435424542	10875	302	49K
0005434343888	10875	303	49H
0005435424548	10875	304	50C
0005435555355	10875	305	50A
0005435424521	10875	306	50E
0005434573139	10875	307	50D
0005435555354	10875	308	50G
0005434343760	10875	309	50F
0005434343635	10875	310	51D
0005434343638	10875	311	50H
0005432165007	10875	312	51E
0005435097072	10875	313	51G
0005433805217	3367	1	1A
0005433805228	3367	2	1C
0005433805232	3367	3	1D
0005432181625	3367	4	2A
0005432459183	3367	5	1F
0005433805231	3367	6	2D
0005432459092	3367	7	2C
0005433633687	3367	8	2F
0005433507114	3367	9	3A
0005433633689	3367	10	3C
0005432459241	3367	11	3F
0005432459065	3367	12	3D
0005433805229	3367	13	4A
0005432459189	3367	14	4C
0005432459315	3367	15	4D
0005432459265	3367	16	5A
0005433633673	3367	17	4F
0005432181623	3367	18	5D
0005433507108	3367	19	5C
0005433633698	3367	20	5F
0005432459144	3367	21	6C
0005432459320	3367	22	6A
0005432459377	3367	23	6D
0005433805223	3367	24	7A
0005433633691	3367	25	6F
0005433507103	3367	26	7C
0005432181624	3367	27	7D
0005432459214	3367	28	8A
0005432459293	3367	29	7F
0005432459186	3367	30	8B
0005433805236	3367	31	8D
0005433507105	3367	32	8C
0005432181635	3367	33	8E
0005432459070	3367	34	9A
0005433507112	3367	35	9B
0005432181621	3367	36	9C
0005432459321	3367	37	9D
0005433805222	3367	38	9F
0005433633683	3367	39	9E
0005433507109	3367	40	10A
0005433805239	3367	41	10B
0005433633667	3367	42	10D
0005433633685	3367	43	10C
0005433805242	3367	44	10E
0005432181637	3367	45	11B
0005432459081	3367	46	11A
0005432459063	3367	47	11C
0005432459026	3367	48	11E
0005432181615	3367	49	11D
0005432459082	3367	50	11F
0005433805235	3367	51	12A
0005433633672	3367	52	12B
0005432181622	3367	53	12C
0005433507111	3367	54	12D
0005433507101	3367	55	12F
0005432459178	3367	56	12E
0005433805241	3367	57	13B
0005432181617	3367	58	13A
0005432459154	3367	59	13C
0005432459187	3367	60	13E
0005433805240	3367	61	13D
0005433633701	3367	62	13F
0005433633688	3367	63	14B
0005432459027	3367	64	14D
0005433805219	3367	65	14C
0005433805243	3367	66	14E
0005433805226	3367	67	15A
0005433633692	3367	68	14F
0005433633686	3367	69	15B
0005433507100	3367	70	15C
0005432459316	3367	71	15E
0005433633675	3367	72	16A
0005433805225	3367	73	15F
0005432459275	3367	74	16B
0005433507115	3367	75	16D
0005433633669	3367	76	16C
0005433507099	3367	77	16E
0005432459083	3367	78	16F
0005433633676	3367	79	17B
0005433507098	3367	80	17A
0005432459283	3367	81	17C
0005432459234	3367	82	17E
0005432181631	3367	83	17D
0005432459266	3367	84	17F
0005433805244	3367	85	18A
0005432181616	3367	86	18B
0005433805238	3367	87	18D
0005432459080	3367	88	18C
0005432181626	3367	89	18E
0005432459179	3367	90	19B
0005433805224	3367	91	18F
0005432459127	3367	92	19D
0005433633700	3367	93	19C
0005433805245	3367	94	20A
0005433633678	3367	95	19E
0005433633668	3367	96	20B
0005432459172	3367	97	20C
0005433805233	3367	98	20D
0005433633696	3367	99	21A
0005432459132	3367	100	20F
0005433633680	3367	101	21B
0005433633693	3367	102	21D
0005433633682	3367	103	21C
0005432459122	3367	104	21E
0005432181628	3367	105	22A
0005433507104	3367	106	21F
0005433805211	3367	107	22B
0005433633671	3367	108	22D
0005433507102	3367	109	22C
0005433805230	3367	110	22E
0005433507110	3367	111	22F
0005433507106	3367	112	23B
0005432459185	3367	113	23A
0005432459192	3367	114	23C
0005433633697	3367	115	23D
0005432459284	3367	116	23F
0005433805218	3367	117	23E
0005433805216	3367	118	24A
0005432459035	3367	119	24B
0005432181633	3367	120	24C
0005432459076	3367	121	24E
0005433805215	3367	122	24D
0005432181618	3367	123	24F
0005432459237	3367	124	25B
0005432181636	3367	125	25A
0005432459202	3367	126	25C
0005433633679	3367	127	25E
0005432181619	3367	128	25D
0005433805212	3367	129	25F
0005432459158	3367	130	26A
0005432459064	3367	131	26B
0005433633674	3367	132	26C
0005433507117	3367	133	26E
0005432181634	3367	134	26D
0005432459376	3367	135	26F
0005433633690	3367	136	27A
0005433507113	3367	137	27C
0005433633695	3367	138	27B
0005432459128	3367	139	27D
0005432181630	3367	140	27F
0005432459048	3367	141	27E
0005432458982	3367	142	28A
0005433633677	3367	143	28C
0005432459153	3367	144	28B
0005433633684	3367	145	28D
0005432459188	3367	146	28E
0005433805234	3367	147	28F
0005433507107	3367	148	29A
0005433507116	3367	149	29C
0005432181620	3367	150	29B
0005432181632	3367	151	29D
0005433805214	3367	152	29F
0005433805227	3367	153	29E
0005432181627	3367	154	30B
0005432459279	3367	155	30A
0005433805213	3367	156	30C
0005433805220	3367	157	30E
0005433633681	3367	158	30D
0005433805237	3367	159	30F
0005432181629	3367	160	31B
0005433633670	3367	161	31A
0005433805221	3367	162	31C
0005433633694	3367	163	31E
0005433633699	3367	164	31D
0005435884748	3366	1	1A
0005435884630	3366	2	2D
0005435884665	3366	3	3A
0005435884568	3366	4	3D
0005435884653	3366	5	3C
0005435884429	3366	6	3F
0005435884560	3366	7	5C
0005435884693	3366	8	7C
0005435884691	3366	9	8D
0005435884637	3366	10	9D
0005435884635	3366	11	9F
0005435884694	3366	12	11D
0005435884829	3366	13	12A
0005435884754	3366	14	12E
0005435884634	3366	15	12F
0005435884567	3366	16	13C
0005435884682	3366	17	14A
0005435884652	3366	18	14D
0005435884884	3366	19	15F
0005435884589	3366	20	15E
0005435884820	3366	21	16D
0005435884744	3366	22	16E
0005435884687	3366	23	16F
0005435884703	3366	24	17F
0005435884706	3366	25	17E
0005435884544	3366	26	18D
0005435884727	3366	27	18C
0005435884607	3366	28	19C
0005435884795	3366	29	20D
0005435884667	3366	30	20F
0005435884502	3366	31	21A
0005435884531	3366	32	21C
0005435884482	3366	33	21F
0005435884728	3366	34	22C
0005435884732	3366	35	22E
0005435884613	3366	36	23B
0005435884543	3366	37	23F
0005435884619	3366	38	23E
0005435884745	3366	39	24E
0005435884848	3366	40	25A
0005435884666	3366	41	25B
0005435884716	3366	42	25E
0005435884859	3366	43	26E
0005435884612	3366	44	27A
0005435884550	3366	45	27C
0005435884849	3366	46	27E
0005435884765	3366	47	28A
0005435884590	3366	48	28C
0005435884492	3366	49	29C
0005435884674	3366	50	29E
0005435884561	3366	51	30B
0005435884860	3366	52	31B
0005435884593	3366	53	31D
0005435884600	3366	54	31F
0005435885025	8239	1	1A
0005435885057	8239	2	1C
0005432459670	8239	3	1D
0005432459699	8239	4	2C
0005435885052	8239	5	2F
0005432459669	8239	6	2D
0005432459653	8239	7	3A
0005435885049	8239	8	3F
0005432459668	8239	9	4A
0005435885067	8239	10	4D
0005435885051	8239	11	5A
0005435885066	8239	12	5C
0005435885042	8239	13	5F
0005432042654	8239	14	5D
0005434326269	8239	15	6C
0005432459662	8239	16	6A
0005432459701	8239	17	6D
0005435885033	8239	18	7A
0005435885024	8239	19	7D
0005432459700	8239	20	8A
0005435885070	8239	21	7F
0005432042666	8239	22	8B
0005433506929	8239	23	8C
0005433506935	8239	24	8E
0005435885063	8239	25	8D
0005435885030	8239	26	9A
0005435885043	8239	27	8F
0005435885039	8239	28	9B
0005432459655	8239	29	9C
0005432459696	8239	30	9D
0005432459702	8239	31	9F
0005432459689	8239	32	9E
0005432459683	8239	33	10A
0005435885029	8239	34	10C
0005432042661	8239	35	10B
0005435885053	8239	36	10E
0005433506915	8239	37	10D
0005435885069	8239	38	11B
0005435885035	8239	39	11A
0005435885038	8239	40	11C
0005432459690	8239	41	11F
0005435885068	8239	42	11E
0005432459657	8239	43	12A
0005435885056	8239	44	12B
0005432042655	8239	45	12C
0005433506934	8239	46	12E
0005432459673	8239	47	12D
0005432459678	8239	48	13A
0005432459688	8239	49	13C
0005432459691	8239	50	13B
0005432459652	8239	51	13E
0005432459666	8239	52	13D
0005432459687	8239	53	13F
0005432459676	8239	54	14B
0005432042662	8239	55	14C
0005432459659	8239	56	14E
0005435885026	8239	57	14F
0005432042660	8239	58	15A
0005432459677	8239	59	15C
0005432459694	8239	60	15B
0005434312313	8239	61	15E
0005435885055	8239	62	15D
0005435885023	8239	63	16A
0005435885046	8239	64	15F
0005432459680	8239	65	16C
0005435885054	8239	66	16B
0005432459674	8239	67	16F
0005432459675	8239	68	16E
0005432459667	8239	69	17A
0005435885050	8239	70	17C
0005432459661	8239	71	17B
0005432459693	8239	72	17D
0005435885034	8239	73	17F
0005432459664	8239	74	17E
0005432459703	8239	75	18A
0005432459686	8239	76	18B
0005433506891	8239	77	18C
0005432459663	8239	78	18D
0005432459656	8239	79	18F
0005432459684	8239	80	19B
0005435885071	8239	81	19E
0005433506933	8239	82	20C
0005432459660	8239	83	20D
0005432459672	8239	84	20F
0005432042652	8239	85	20E
0005432042657	8239	86	21B
0005435885059	8239	87	21A
0005432042663	8239	88	21D
0005432459698	8239	89	22A
0005435885048	8239	90	22B
0005432459671	8239	91	22C
0005433506963	8239	92	22D
0005434312312	8239	93	22F
0005435885062	8239	94	23A
0005432459695	8239	95	23B
0005433506932	8239	96	23D
0005435885032	8239	97	23E
0005432459681	8239	98	24A
0005433506964	8239	99	24B
0005432459651	8239	100	24F
0005432042656	8239	101	24E
0005432042659	8239	102	25A
0005433506955	8239	103	25C
0005433506925	8239	104	25B
0005432459679	8239	105	25D
0005435885044	8239	106	25E
0005433506993	8239	107	25F
0005433507036	8239	108	26B
0005435885040	8239	109	26D
0005435885022	8239	110	26C
0005435885037	8239	111	26F
0005432459654	8239	112	27A
0005432042664	8239	113	27C
0005435885031	8239	114	27D
0005435885060	8239	115	27E
0005432459682	8239	116	28A
0005433506976	8239	117	27F
0005435885036	8239	118	28B
0005432459697	8239	119	28D
0005432042658	8239	120	28C
0005435885041	8239	121	28F
0005432459658	8239	122	29A
0005432459665	8239	123	29C
0005435885058	8239	124	29B
0005435885045	8239	125	29D
0005435885021	8239	126	29F
0005435885027	8239	127	29E
0005432042653	8239	128	30A
0005432042665	8239	129	30B
0005435885064	8239	130	30C
0005432459685	8239	131	30D
0005435885065	8239	132	30F
0005433506927	8239	133	30E
0005432459692	8239	134	31B
0005435885061	8239	135	31A
0005435885028	8239	136	31C
0005433506974	8239	137	31D
0005435885047	8239	138	31F
0005433506920	8239	139	31E
0005433805110	8258	1	1A
0005433804832	8258	2	1C
0005435854056	8258	3	1F
0005433804886	8258	4	2A
0005433805109	8258	5	2F
0005433633247	8258	6	4F
0005433804987	8258	7	4D
0005433804964	8258	8	5C
0005433633503	8258	9	8A
0005433805090	8258	10	8D
0005433805003	8258	11	9A
0005433804808	8258	12	9C
0005433805002	8258	13	9B
0005433804917	8258	14	9E
0005433804895	8258	15	9D
0005433805058	8258	16	9F
0005433804949	8258	17	10B
0005433805033	8258	18	11A
0005433804972	8258	19	11C
0005433805064	8258	20	11E
0005433805111	8258	21	11D
0005433805057	8258	22	12A
0005435854052	8258	23	12C
0005433804897	8258	24	12D
0005435854053	8258	25	12F
0005433804993	8258	26	13B
0005433804861	8258	27	13A
0005433633373	8258	28	14B
0005433805075	8258	29	15C
0005434143699	8258	30	15F
0005433804859	8258	31	16A
0005433633447	8258	32	16D
0005433633330	8258	33	17B
0005433633385	8258	34	17D
0005433633386	8258	35	18C
0005433633359	8258	36	18B
0005433804936	8258	37	18D
0005433804969	8258	38	18F
0005433633448	8258	39	20F
0005433804887	8258	40	21C
0005433804973	8258	41	21B
0005433804941	8258	42	21F
0005433633352	8258	43	22C
0005433804988	8258	44	22D
0005433633370	8258	45	22F
0005433804858	8258	46	22E
0005433633371	8258	47	23B
0005433804923	8258	48	23D
0005435854055	8258	49	24D
0005433633354	8258	50	25A
0005433633332	8258	51	24E
0005434143708	8258	52	25C
0005433805091	8258	53	25F
0005433633320	8258	54	26B
0005433804918	8258	55	26C
0005435854054	8258	56	27A
0005433805015	8258	57	27B
0005433804920	8258	58	27E
0005433804850	8258	59	28A
0005434143700	8258	60	28E
0005433804863	8258	61	28F
0005433633353	8258	62	29A
0005433805034	8258	63	30B
0005433633329	8258	64	30C
0005435854051	8258	65	30F
0005434143709	8258	66	31C
0005434183555	8276	1	1F
0005432383044	4599	1	1A
0005432383023	4599	2	1C
0005432383016	4599	3	1F
0005433454868	4599	4	2A
0005432383043	4599	5	2D
0005432383050	4599	6	2F
0005432383027	4599	7	3A
0005432383048	4599	8	3C
0005432383056	4599	9	3F
0005432727887	4599	10	4A
0005432383021	4599	11	4C
0005432383026	4599	12	4D
0005432383036	4599	13	4F
0005432383041	4599	14	5A
0005433453757	4599	15	5C
0005432383025	4599	16	5D
0005433722198	4599	17	5E
0005432727893	4599	18	5F
0005432383032	4599	19	6A
0005432383051	4599	20	6C
0005432383028	4599	21	6D
0005432383039	4599	22	6F
0005432383013	4599	23	7A
0005432383047	4599	24	7D
0005432383040	4599	25	7E
0005432383014	4599	26	7F
0005433722197	4599	27	8A
0005432727892	4599	28	8D
0005433722199	4599	29	8E
0005432383020	4599	30	9C
0005432383037	4599	31	9D
0005432383034	4599	32	9E
0005432727883	4599	33	9F
0005432727888	4599	34	10D
0005433454867	4599	35	10E
0005433453756	4599	36	10F
0005432383015	4599	37	11A
0005432727890	4599	38	11C
0005432727891	4599	39	11D
0005432383033	4599	40	11F
0005432383038	4599	41	12A
0005432383018	4599	42	12D
0005432383017	4599	43	13C
0005432383042	4599	44	13D
0005432383045	4599	45	13E
0005432383053	4599	46	14D
0005432383024	4599	47	14E
0005432727885	4599	48	14F
0005432383031	4599	49	15C
0005432727886	4599	50	15D
0005432383049	4599	51	15E
0005433453755	4599	52	16A
0005432383055	4599	53	16C
0005432383019	4599	54	16E
0005432383030	4599	55	17A
0005432383029	4599	56	17D
0005432383022	4599	57	18A
0005432383054	4599	58	18E
0005433454869	4599	59	18F
0005432383052	4599	60	19D
0005432383035	4599	61	19E
0005432727894	4599	62	19F
0005432727884	4599	63	20A
0005432727889	4599	64	20C
0005432383046	4599	65	20D
0005432727816	30103	1	1C
0005433722109	30103	2	1D
0005432382570	30103	3	2A
0005432727813	30103	4	2D
0005433722117	30103	5	3A
0005432727784	30103	6	3C
0005432727811	30103	7	3F
0005432382571	30103	8	4A
0005432382692	30103	9	4C
0005433722130	30103	10	4D
0005432382515	30103	11	5D
0005433194830	30103	12	5F
0005432382693	30103	13	6A
0005432382516	30103	14	6C
0005432382803	30103	15	6E
0005432727841	30103	16	6F
0005432727749	30103	17	7A
0005432382707	30103	18	7C
0005433722112	30103	19	7D
0005433722110	30103	20	7F
0005432382610	30103	21	8C
0005432382802	30103	22	8F
0005432382678	30103	23	9A
0005432727754	30103	24	9D
0005433722105	30103	25	10C
0005433722120	30103	26	11C
0005432382575	30103	27	11F
0005432382622	30103	28	12A
0005432382609	30103	29	12C
0005432382633	30103	30	12D
0005432382617	30103	31	12E
0005432727777	30103	32	13E
0005432727748	30103	33	14C
0005433722107	30103	34	14E
0005432382494	30103	35	14F
0005432727778	30103	36	15A
0005433453732	30103	37	15C
0005432382592	30103	38	16A
0005432727755	30103	39	16C
0005432382607	30103	40	16D
0005433194821	30103	41	16E
0005433722111	30103	42	17C
0005432382499	30103	43	17D
0005432727814	30103	44	17E
0005432382493	30103	45	18A
0005433722124	30103	46	18E
0005432727780	30103	47	18F
0005432382564	30103	48	19A
0005432727781	30103	49	19C
0005432727817	30103	50	19D
0005432727753	30103	51	19F
0005432727782	30103	52	20A
0005432382706	30103	53	20C
0005433194829	30103	54	20F
0005435540932	1733	1	1C
0005435540918	1733	2	1D
0005435529184	1733	3	1F
0005433516850	1733	4	2C
0005435529182	1733	5	2F
0005432924972	1733	6	3A
0005435540914	1733	7	3D
0005435529175	1733	8	3F
0005435540930	1733	9	4C
0005435540917	1733	10	4D
0005435540911	1733	11	4E
0005435529183	1733	12	4F
0005435529174	1733	13	5D
0005433516853	1733	14	5E
0005435540922	1733	15	5F
0005435529167	1733	16	6A
0005435540927	1733	17	6C
0005432924990	1733	18	6D
0005432924973	1733	19	6E
0005433516851	1733	20	7E
0005433516852	1733	21	7F
0005433516845	1733	22	8A
0005435529187	1733	23	8C
0005432924971	1733	24	8D
0005435540926	1733	25	8E
0005435529179	1733	26	8F
0005435529186	1733	27	9A
0005435529170	1733	28	9C
0005435540931	1733	29	9D
0005435529171	1733	30	9F
0005433516847	1733	31	10A
0005435540915	1733	32	10C
0005433516849	1733	33	10D
0005435529185	1733	34	10E
0005435540924	1733	35	10F
0005433516854	1733	36	11C
0005435529173	1733	37	11D
0005433516846	1733	38	12A
0005435540925	1733	39	12E
0005435540921	1733	40	12F
0005435540916	1733	41	13A
0005432924989	1733	42	13C
0005433516848	1733	43	13D
0005435529180	1733	44	13E
0005435540928	1733	45	14D
0005435540912	1733	46	14E
0005435529169	1733	47	14F
0005435529188	1733	48	16C
0005435529168	1733	49	16D
0005432294478	1733	50	17D
0005435540913	1733	51	17E
0005435540929	1733	52	18C
0005435540919	1733	53	18E
0005435540923	1733	54	19A
0005432294477	1733	55	19C
0005435529176	1733	56	19F
0005435529177	1733	57	20A
0005435540920	1733	58	20C
0005435529181	1733	59	20D
0005435529178	1733	60	20E
0005435529172	1733	61	20F
0005435517713	21988	1	1A
0005433516774	21988	2	1D
0005433516755	21988	3	1F
0005435540639	21988	4	2C
0005435540735	21988	5	2D
0005435540676	21988	6	3C
0005435540715	21988	7	3F
0005435517700	21988	8	4A
0005435517688	21988	9	4F
0005435540833	21988	10	5C
0005433516754	21988	11	5F
0005433516784	21988	12	6A
0005433516775	21988	13	6C
0005435540757	21988	14	6E
0005432925015	21988	15	6F
0005435540690	21988	16	7A
0005435540652	21988	17	7D
0005435517698	21988	18	7E
0005435540711	21988	19	8D
0005433516741	21988	20	9A
0005435517675	21988	21	9C
0005435517657	21988	22	10C
0005435517716	21988	23	10D
0005435517658	21988	24	10E
0005435540675	21988	25	11A
0005435517667	21988	26	11C
0005435540748	21988	27	11D
0005435540741	21988	28	11E
0005435517699	21988	29	12D
0005435540772	21988	30	12E
0005435517715	21988	31	12F
0005433516783	21988	32	13C
0005435517597	21988	33	13D
0005435517659	21988	34	13E
0005433516765	21988	35	13F
0005435517703	21988	36	14E
0005435517635	21988	37	15A
0005435540749	21988	38	15C
0005432925017	21988	39	15D
0005435517656	21988	40	15E
0005435517585	21988	41	16A
0005432925016	21988	42	16C
0005433516782	21988	43	16D
0005432925018	21988	44	16E
0005435540661	21988	45	16F
0005435517634	21988	46	17C
0005435540714	21988	47	17D
0005435540687	21988	48	17F
0005433516797	21988	49	18A
0005435540701	21988	50	18C
0005432925019	21988	51	18D
0005435540832	21988	52	18E
0005433516757	21988	53	18F
0005435540660	21988	54	19D
0005435517740	21988	55	19E
0005433516749	21988	56	19F
0005435517629	21988	57	20A
0005433516742	21988	58	20C
0005435517741	21988	59	20D
0005435540653	21988	60	20F
0005432823440	7395	1	1A
0005432838920	7395	2	1D
0005432838899	7395	3	1F
0005435252533	7395	4	2A
0005432838922	7395	5	2C
0005434458717	7395	6	2D
0005435252428	7395	7	2F
0005432838911	7395	8	3A
0005435252469	7395	9	3C
0005432073375	7395	10	3D
0005434458719	7395	11	3F
0005435252483	7395	12	4A
0005432838916	7395	13	4C
0005435252432	7395	14	4D
0005432838905	7395	15	4E
0005434458730	7395	16	4F
0005435252485	7395	17	5A
0005432073377	7395	18	5C
0005435252514	7395	19	5D
0005432823439	7395	20	5E
0005435252540	7395	21	5F
0005435252486	7395	22	6C
0005435252446	7395	23	6D
0005435252484	7395	24	6E
0005435252472	7395	25	7A
0005435252380	7395	26	7C
0005434458720	7395	27	7D
0005432838909	7395	28	7E
0005432838924	7395	29	8A
0005432838919	7395	30	8C
0005435252482	7395	31	8D
0005434458718	7395	32	8F
0005432838908	7395	33	9A
0005435252501	7395	34	9C
0005435252438	7395	35	9D
0005432838904	7395	36	9E
0005434458723	7395	37	10A
0005434458712	7395	38	10C
0005434458729	7395	39	10D
0005432838901	7395	40	10E
0005432838896	7395	41	10F
0005434458721	7395	42	11A
0005432073378	7395	43	11D
0005432841002	7395	44	12A
0005434458713	7395	45	12C
0005434458724	7395	46	12D
0005435252481	7395	47	12E
0005435252419	7395	48	12F
0005434458715	7395	49	13C
0005432838902	7395	50	13D
0005432838903	7395	51	13E
0005432838897	7395	52	13F
0005435252471	7395	53	14A
0005434458726	7395	54	14C
0005435252580	7395	55	14D
0005432838912	7395	56	14E
0005434458716	7395	57	14F
0005432838925	7395	58	15A
0005434664936	7395	59	15C
0005435252381	7395	60	15D
0005432838894	7395	61	15E
0005435491416	7395	62	15F
0005434458722	7395	63	16A
0005432838914	7395	64	16C
0005432838900	7395	65	16D
0005435252500	7395	66	16E
0005434458725	7395	67	16F
0005432838906	7395	68	17A
0005432838895	7395	69	17C
0005432838898	7395	70	17D
0005432838907	7395	71	17E
0005435252447	7395	72	17F
0005434458727	7395	73	18A
0005432838915	7395	74	18C
0005434458728	7395	75	18D
0005432841003	7395	76	18E
0005432838918	7395	77	18F
0005432838923	7395	78	19A
0005435252512	7395	79	19C
0005434458714	7395	80	19D
0005432838921	7395	81	19E
0005432838910	7395	82	19F
0005432838913	7395	83	20A
0005432073376	7395	84	20C
0005432838917	7395	85	20D
0005435252451	7395	86	20E
0005434458489	28949	1	1A
0005432840989	28949	2	1D
0005435252630	28949	3	1F
0005435252625	28949	4	2A
0005434664951	28949	5	2C
0005435252628	28949	6	2D
0005434458570	28949	7	3A
0005435252622	28949	8	3D
0005432838811	28949	9	3F
0005435252636	28949	10	4A
0005435252639	28949	11	4C
0005435252627	28949	12	4D
0005432838658	28949	13	5A
0005435252631	28949	14	5C
0005435252621	28949	15	5D
0005432838754	28949	16	5F
0005435252637	28949	17	6A
0005432001014	28949	18	6C
0005432838700	28949	19	6D
0005432823425	28949	20	6F
0005432838776	28949	21	7A
0005432838597	28949	22	7D
0005432838569	28949	23	8A
0005434458571	28949	24	7F
0005434458569	28949	25	8C
0005432838677	28949	26	8D
0005435252626	28949	27	8E
0005432823424	28949	28	8F
0005432838729	28949	29	9A
0005434458578	28949	30	9C
0005435252633	28949	31	9D
0005432838692	28949	32	9E
0005432838599	28949	33	10A
0005435252641	28949	34	10D
0005432838647	28949	35	10E
0005432838676	28949	36	11A
0005435491434	28949	37	11C
0005435252635	28949	38	11D
0005432838718	28949	39	11E
0005432838581	28949	40	12A
0005432838659	28949	41	12C
0005434458579	28949	42	12D
0005434458534	28949	43	12F
0005432838600	28949	44	13A
0005432838621	28949	45	13C
0005432838781	28949	46	13D
0005435252624	28949	47	13E
0005435252634	28949	48	13F
0005432838708	28949	49	14A
0005432838568	28949	50	14C
0005435252623	28949	51	14D
0005435491433	28949	52	14E
0005432838777	28949	53	14F
0005432838591	28949	54	15A
0005434458548	28949	55	15C
0005434458528	28949	56	15E
0005435252632	28949	57	15F
0005432001015	28949	58	16A
0005432840990	28949	59	16C
0005435252629	28949	60	16E
0005432838660	28949	61	16F
0005434458553	28949	62	17A
0005432838541	28949	63	17C
0005435252640	28949	64	17E
0005434458623	28949	65	17F
0005435252638	28949	66	18A
0005432838648	28949	67	18C
0005432838722	28949	68	18D
0005432838780	28949	69	18E
0005432838779	28949	70	19A
0005432838657	28949	71	19C
0005432838656	28949	72	19D
0005432838699	28949	73	19F
0005434458535	28949	74	20C
0005432838717	28949	75	20D
0005432838628	28949	76	20F
0005434275960	8791	1	4A
0005435990597	8791	2	5A
0005435990595	8791	3	5F
0005435990598	8791	4	11B
0005435990593	8791	5	14F
0005435990592	8791	6	15B
0005434275966	8791	7	16E
0005435990594	8791	8	17E
0005435990596	8791	9	21B
0005435990591	8791	10	21A
0005434275964	8791	11	21C
0005434276004	15746	1	3D
0005435990554	15746	2	4A
0005435990529	15746	3	8D
0005435990543	15746	4	11A
0005435990526	15746	5	13B
0005434276006	15746	6	15D
0005435990525	15746	7	15E
0005435990509	15746	8	15F
0005434276003	15746	9	16F
0005435990528	15746	10	21A
0005434276005	15746	11	21C
0005432427131	20618	1	1D
0005433476860	20618	2	2B
0005433476856	20618	3	2C
0005433476867	20618	4	2D
0005433476866	20618	5	3B
0005433476861	20618	6	3C
0005432427130	20618	7	5B
0005432427132	20618	8	6C
0005432427133	20618	9	18B
0005432427135	20618	10	18C
0005432427134	20618	11	20A
0005433476870	20618	12	22B
0005433476859	20618	13	23A
0005433476884	30852	1	1C
0005433476882	30852	2	1D
0005432427113	30852	3	3C
0005432427110	30852	4	6C
0005433476881	30852	5	7B
0005433476883	30852	6	19C
0005432427116	30852	7	20A
0005433476885	30852	8	22A
0005432427114	30852	9	23B
0005432909255	23851	1	1A
0005433468239	23851	2	1B
0005432909265	23851	3	1C
0005433468227	23851	4	1D
0005433468221	23851	5	2A
0005433468213	23851	6	2B
0005433468196	23851	7	2C
0005433468202	23851	8	3B
0005432909263	23851	9	3C
0005432909259	23851	10	4B
0005433468208	23851	11	4C
0005433468217	23851	12	4D
0005432909264	23851	13	5A
0005432909258	23851	14	5B
0005433468182	23851	15	5D
0005432909260	23851	16	6A
0005432909262	23851	17	6B
0005432909261	23851	18	6C
0005433468201	23851	19	6D
0005433468207	23851	20	7C
0005433468183	23851	21	18A
0005433468197	23851	22	18B
0005433468180	23851	23	18D
0005433468267	23851	24	19B
0005433468245	23851	25	19C
0005433468222	23851	26	20A
0005433468226	23851	27	20C
0005433468225	23851	28	21C
0005433468246	23851	29	21D
0005432909257	23851	30	22A
0005433468191	23851	31	22B
0005432909256	23851	32	22C
0005433468216	23851	33	22D
0005433468190	23851	34	23A
0005433468189	23851	35	23B
0005432360146	6357	1	1D
0005432360162	6357	2	1C
0005432360177	6357	3	1A
0005432360166	6357	4	1F
0005432360178	6357	5	2C
0005435176702	6357	6	2D
0005432360185	6357	7	3A
0005432363401	6357	8	2F
0005432363404	6357	9	3C
0005435176621	6357	10	3D
0005435176703	6357	11	4A
0005432360155	6357	12	4C
0005435176777	6357	13	4B
0005434149600	6357	14	4D
0005432363403	6357	15	4E
0005432360148	6357	16	4F
0005435176618	6357	17	5A
0005434149561	6357	18	5C
0005435723022	6357	19	5B
0005435723021	6357	20	5D
0005434149573	6357	21	5E
0005435176856	6357	22	5F
0005432360187	6357	23	6B
0005434149566	6357	24	6A
0005432335979	6357	25	6C
0005434149619	6357	26	6E
0005432360156	6357	27	6D
0005432360189	6357	28	6F
0005432335982	6357	29	7B
0005435176679	6357	30	7A
0005432335991	6357	31	7C
0005432360161	6357	32	7D
0005432363402	6357	33	7F
0005435723017	6357	34	7E
0005435176778	6357	35	8A
0005435176723	6357	36	8B
0005432360183	6357	37	8C
0005435176658	6357	38	8D
0005432335992	6357	39	8E
0005432360147	6357	40	9A
0005432360151	6357	41	8F
0005432360193	6357	42	9B
0005434149574	6357	43	9E
0005432360179	6357	44	9D
0005432360194	6357	45	9F
0005435176799	6357	46	10B
0005434149575	6357	47	10C
0005435176680	6357	48	11A
0005435176759	6357	49	10E
0005432062209	6357	50	11C
0005432360159	6357	51	11B
0005432360152	6357	52	11D
0005434149584	6357	53	11E
0005432360188	6357	54	12B
0005432360153	6357	55	12A
0005432360181	6357	56	12D
0005432360150	6357	57	12C
0005432335983	6357	58	12E
0005432360191	6357	59	13A
0005432360186	6357	60	12F
0005435176804	6357	61	13C
0005432360180	6357	62	13B
0005435176829	6357	63	13D
0005434149603	6357	64	13E
0005432360192	6357	65	13F
0005435723019	6357	66	14A
0005432360160	6357	67	14C
0005432360172	6357	68	14B
0005434149620	6357	69	14D
0005432335988	6357	70	14F
0005435723018	6357	71	14E
0005432360168	6357	72	15A
0005432360165	6357	73	15C
0005432360190	6357	74	15E
0005432360167	6357	75	15F
0005432360173	6357	76	16B
0005435176828	6357	77	16C
0005432335990	6357	78	16D
0005432335981	6357	79	16F
0005432360175	6357	80	16E
0005435176619	6357	81	17A
0005435176865	6357	82	17B
0005432360169	6357	83	17D
0005432062207	6357	84	17C
0005435176853	6357	85	17E
0005435176650	6357	86	17F
0005432360174	6357	87	18A
0005432360164	6357	88	18B
0005432360163	6357	89	18D
0005435176701	6357	90	18C
0005435176697	6357	91	18F
0005435176763	6357	92	18E
0005432360176	6357	93	19A
0005432335993	6357	94	19B
0005432335987	6357	95	19C
0005432062208	6357	96	19E
0005432335980	6357	97	19F
0005432335986	6357	98	20B
0005435176789	6357	99	20A
0005432360182	6357	100	20C
0005432360170	6357	101	20D
0005434149588	6357	102	20E
0005434149585	6357	103	20F
0005435176645	6357	104	21A
0005432335989	6357	105	21B
0005435490190	6357	106	21D
0005432360154	6357	107	21C
0005432360158	6357	108	22A
0005432335985	6357	109	21F
0005435176649	6357	110	22B
0005432360184	6357	111	22C
0005435176762	6357	112	22D
0005432335984	6357	113	23A
0005432360171	6357	114	23B
0005435176815	6357	115	23C
0005432360157	6357	116	23E
0005435176620	6357	117	23D
0005432360149	6357	118	23F
0005435176978	21027	1	1A
0005434149678	21027	2	1D
0005435176972	21027	3	1C
0005435176966	21027	4	2A
0005435176970	21027	5	1F
0005432363376	21027	6	2D
0005432359638	21027	7	2F
0005434149679	21027	8	3A
0005434149681	21027	9	3D
0005435176959	21027	10	3C
0005432335864	21027	11	3F
0005434149688	21027	12	4A
0005432359922	21027	13	4D
0005432335914	21027	14	4C
0005434149683	21027	15	4E
0005434149687	21027	16	5A
0005435176967	21027	17	4F
0005432359958	21027	18	5B
0005435176975	21027	19	5C
0005435723037	21027	20	5D
0005432359658	21027	21	5E
0005432359578	21027	22	5F
0005432359719	21027	23	6A
0005435490216	21027	24	6C
0005432359564	21027	25	6B
0005432359551	21027	26	6E
0005435490217	21027	27	6D
0005432335879	21027	28	7A
0005432359737	21027	29	6F
0005432335890	21027	30	7B
0005432359738	21027	31	7F
0005432359849	21027	32	7E
0005432359716	21027	33	8A
0005432359903	21027	34	8B
0005432359850	21027	35	8C
0005435723038	21027	36	8D
0005434149684	21027	37	8E
0005432359577	21027	38	9A
0005435176969	21027	39	8F
0005432335880	21027	40	9C
0005432359883	21027	41	9E
0005432359659	21027	42	9D
0005432335882	21027	43	10B
0005432363382	21027	44	10C
0005432359748	21027	45	10E
0005432335849	21027	46	11A
0005435176962	21027	47	11C
0005435176951	21027	48	11B
0005432359848	21027	49	11E
0005432359841	21027	50	11D
0005432359884	21027	51	11F
0005432359715	21027	52	12A
0005432359668	21027	53	12C
0005435176952	21027	54	12E
0005432359840	21027	55	12F
0005432359844	21027	56	13B
0005434149680	21027	57	13A
0005432359698	21027	58	13D
0005432363380	21027	59	13C
0005432359923	21027	60	13F
0005432359562	21027	61	13E
0005432359838	21027	62	14B
0005432359902	21027	63	14D
0005435176957	21027	64	14F
0005432359892	21027	65	14E
0005432359901	21027	66	15B
0005434149682	21027	67	15A
0005432335896	21027	68	15E
0005432359734	21027	69	15D
0005432359904	21027	70	15F
0005435176965	21027	71	16B
0005435176968	21027	72	16A
0005432359563	21027	73	16E
0005434149685	21027	74	16D
0005432359708	21027	75	16F
0005432359561	21027	76	17B
0005432359808	21027	77	17A
0005432335878	21027	78	17E
0005435176974	21027	79	18A
0005435176958	21027	80	18B
0005435176979	21027	81	18D
0005432335852	21027	82	18C
0005432359669	21027	83	18E
0005435176977	21027	84	18F
0005435176954	21027	85	19A
0005435176963	21027	86	19B
0005435176964	21027	87	19C
0005432359714	21027	88	19E
0005435176953	21027	89	19D
0005432363381	21027	90	20B
0005432359718	21027	91	20A
0005432359601	21027	92	20C
0005435176971	21027	93	20D
0005432359537	21027	94	20F
0005435176961	21027	95	21B
0005434149686	21027	96	21A
0005432052734	21027	97	21C
0005432052733	21027	98	21D
0005432052735	21027	99	21F
0005432052732	21027	100	21E
0005435176973	21027	101	22A
0005435176976	21027	102	22B
0005432335897	21027	103	22C
0005432335891	21027	104	22D
0005432359639	21027	105	22E
0005435176955	21027	106	23A
0005435176956	21027	107	22F
0005434149677	21027	108	23B
0005435176960	21027	109	23C
0005432359565	21027	110	23E
0005432359538	21027	111	23D
0005434458478	17711	1	1A
0005434458555	17711	2	1B
0005434458510	17711	3	1D
0005434186187	17711	4	2B
0005434458551	17711	5	2D
0005434458658	17711	6	3B
0005434448276	17711	7	3D
0005434458557	17711	8	4A
0005434458606	17711	9	4C
0005434448285	17711	10	4D
0005434463908	17711	11	5A
0005434448275	17711	12	5B
0005434448286	17711	13	5D
0005434458519	17711	14	6D
0005434448274	17711	15	7B
0005434448266	17711	16	7C
0005434458550	17711	17	7D
0005434458589	17711	18	18A
0005434448273	17711	19	19C
0005434458511	17711	20	19D
0005434186188	17711	21	20A
0005434458575	17711	22	20C
0005434458599	17711	23	21A
0005434458512	17711	24	21B
0005434458556	17711	25	21C
0005434458600	17711	26	21D
0005434458520	17711	27	22B
0005434458573	17711	28	22C
0005434458615	17711	29	22D
0005434458572	17711	30	23B
0005434458715	29082	1	1A
0005434458723	29082	2	1B
0005434458712	29082	3	1D
0005434462780	29082	4	2A
0005434448296	29082	5	2D
0005434458728	29082	6	3B
0005434448297	29082	7	3C
0005434458719	29082	8	3D
0005434458720	29082	9	4D
0005434458718	29082	10	5A
0005434458729	29082	11	5C
0005434458726	29082	12	6C
0005434463919	29082	13	6D
0005434458725	29082	14	7A
0005434458721	29082	15	7B
0005434458717	29082	16	7C
0005434458714	29082	17	18C
0005434458727	29082	18	19D
0005434463918	29082	19	20A
0005434458724	29082	20	20B
0005434448298	29082	21	20C
0005434458716	29082	22	20D
0005434458713	29082	23	21C
0005434458730	29082	24	22A
0005434458722	29082	25	22D
0005432661914	6495	1	1F
0005432664136	6495	2	4A
0005432664130	6495	3	3D
0005432664141	6495	4	4C
0005432661915	6495	5	5C
0005432664134	6495	6	5D
0005432664138	6495	7	6D
0005432663030	6495	8	6F
0005432661917	6495	9	7B
0005432663031	6495	10	7D
0005432663033	6495	11	7F
0005432663029	6495	12	8F
0005432661913	6495	13	9B
0005432663028	6495	14	9E
0005432661923	6495	15	10C
0005432661927	6495	16	10E
0005432663032	6495	17	11A
0005432661922	6495	18	11F
0005432664142	6495	19	11E
0005432663034	6495	20	12A
0005432661924	6495	21	12C
0005432663035	6495	22	12F
0005432661919	6495	23	13A
0005432663038	6495	24	13D
0005432664132	6495	25	14B
0005432664129	6495	26	14D
0005432663027	6495	27	15B
0005432661916	6495	28	15D
0005432664140	6495	29	15F
0005432663040	6495	30	15E
0005432661920	6495	31	16A
0005432663036	6495	32	16E
0005432664133	6495	33	17A
0005432661926	6495	34	17F
0005432661921	6495	35	17E
0005432663037	6495	36	18E
0005432661925	6495	37	18F
0005432664135	6495	38	19F
0005432664139	6495	39	20B
0005432664128	6495	40	20A
0005432664131	6495	41	20C
0005432663039	6495	42	21B
0005432661918	6495	43	21F
0005432664137	6495	44	21E
0005432604149	21434	1	1A
0005432604160	21434	2	1B
0005432604157	21434	3	1C
0005432604166	21434	4	1D
0005432604134	21434	5	2B
0005432604154	21434	6	2A
0005432604147	21434	7	2C
0005432604131	21434	8	3A
0005432604167	21434	9	3C
0005432604140	21434	10	3D
0005432604161	21434	11	4A
0005432604146	21434	12	4C
0005432604145	21434	13	4D
0005432604133	21434	14	5A
0005432604141	21434	15	5B
0005432604159	21434	16	5C
0005432604168	21434	17	5D
0005435218100	21434	18	6A
0005432604162	21434	19	6B
0005432604155	21434	20	6D
0005432604135	21434	21	7C
0005432604151	21434	22	18A
0005432604130	21434	23	18B
0005432604152	21434	24	18C
0005432604128	21434	25	18D
0005432604148	21434	26	19A
0005432604144	21434	27	19B
0005432604165	21434	28	19C
0005432604150	21434	29	19D
0005432604138	21434	30	20A
0005432604143	21434	31	20B
0005432604137	21434	32	20C
0005432604129	21434	33	21A
0005432604142	21434	34	21B
0005432604158	21434	35	21C
0005432604132	21434	36	21D
0005432604153	21434	37	22A
0005432604156	21434	38	22B
0005432604163	21434	39	22C
0005432604164	21434	40	22D
0005432604139	21434	41	23A
0005432604136	21434	42	23B
0005432603798	31679	1	1A
0005432603843	31679	2	1B
0005432603881	31679	3	1C
0005432603946	31679	4	1D
0005432603823	31679	5	2A
0005432603838	31679	6	2B
0005432603805	31679	7	2C
0005432603875	31679	8	2D
0005432603834	31679	9	3A
0005432603771	31679	10	3B
0005432603786	31679	11	3C
0005432603860	31679	12	4A
0005432603745	31679	13	4C
0005432603868	31679	14	4D
0005432603746	31679	15	5A
0005432603824	31679	16	5B
0005432603809	31679	17	5D
0005432603863	31679	18	6A
0005432603796	31679	19	6B
0005432603804	31679	20	6C
0005432603693	31679	21	6D
0005432603770	31679	22	7A
0005432603775	31679	23	7B
0005432603859	31679	24	7C
0005432603901	31679	25	7D
0005432603840	31679	26	18B
0005432603892	31679	27	18C
0005432603806	31679	28	18D
0005432603747	31679	29	19A
0005432603769	31679	30	19B
0005432603839	31679	31	19C
0005432603825	31679	32	19D
0005432603662	31679	33	20A
0005432603810	31679	34	20B
0005432603779	31679	35	20C
0005432603822	31679	36	20D
0005432603903	31679	37	21A
0005432603700	31679	38	21C
0005432603778	31679	39	21D
0005432603951	31679	40	22B
0005432603748	31679	41	22C
0005432603757	31679	42	22D
0005432603865	31679	43	23B
0005433293142	12305	1	1C
0005433293167	12305	2	2A
0005433293173	12305	3	2B
0005435154592	12305	4	2D
0005433293152	12305	5	3A
0005433293163	12305	6	4C
0005433293149	12305	7	4D
0005433293155	12305	8	5B
0005433293146	12305	9	5C
0005433293161	12305	10	5D
0005433293166	12305	11	6A
0005433293158	12305	12	6D
0005435154593	12305	13	7A
0005435154591	12305	14	7C
0005433293147	12305	15	18B
0005433293162	12305	16	18C
0005433293153	12305	17	18D
0005433293145	12305	18	19A
0005433293144	12305	19	19B
0005433293174	12305	20	20D
0005433293159	12305	21	21A
0005433293157	12305	22	21C
0005433293165	12305	23	22A
0005433293148	12305	24	22D
0005433473133	23890	1	1A
0005435257216	23890	2	1C
0005433473125	23890	3	1D
0005435257209	23890	4	2C
0005433473127	23890	5	2D
0005433473126	23890	6	3B
0005435257210	23890	7	3C
0005433473145	23890	8	3D
0005433473151	23890	9	4A
0005435257221	23890	10	4D
0005433473130	23890	11	5D
0005435257219	23890	12	6A
0005435257211	23890	13	6B
0005435257218	23890	14	6D
0005433473134	23890	15	7D
0005435257214	23890	16	18D
0005435257220	23890	17	19B
0005435257212	23890	18	19D
0005433473113	23890	19	20A
0005435257213	23890	20	20D
0005433473114	23890	21	21A
0005435257215	23890	22	21C
0005433473138	23890	23	22A
0005435257217	23890	24	22B
0005433473112	23890	25	23B
0005434606775	18869	1	3B
0005434606782	18869	2	4A
0005434606783	18869	3	5A
0005434606812	22390	1	1A
0005434606813	22390	2	2A
0005434604881	22390	3	3A
0005435904890	22390	4	4A
0005434604880	22390	5	5A
0005434606814	22390	6	6A
0005434602888	3840	1	1A
0005435904373	3840	2	1B
0005434522430	3840	3	1C
0005434522424	3840	4	1D
0005435904371	3840	5	2A
0005434602890	3840	6	2B
0005434522427	3840	7	2D
0005435904372	3840	8	3A
0005434522425	3840	9	3B
0005435904374	3840	10	3C
0005434602893	3840	11	3D
0005434603020	3840	12	6A
0005434522426	3840	13	6C
0005434522428	3840	14	6D
0005434603019	3840	15	7A
0005434522429	3840	16	7B
0005434602891	3840	17	19B
0005434602889	3840	18	19D
0005434602892	3840	19	20B
0005434602886	3840	20	21B
0005434602887	3840	21	22A
0005434604845	19063	1	1C
0005434604854	19063	2	1D
0005434602863	19063	3	2A
0005435904399	19063	4	2C
0005434522403	19063	5	3B
0005434522389	19063	6	4A
0005435904400	19063	7	4B
0005434522414	19063	8	4C
0005434522392	19063	9	5B
0005435904397	19063	10	5D
0005435904398	19063	11	5C
0005434604848	19063	12	6A
0005434602866	19063	13	6C
0005434522379	19063	14	6D
0005434602859	19063	15	7A
0005434602862	19063	16	7B
0005434604855	19063	17	7C
0005434522405	19063	18	18A
0005434522410	19063	19	18B
0005434522388	19063	20	18C
0005434604860	19063	21	18D
0005434522390	19063	22	19D
0005434602872	19063	23	20B
0005434602867	19063	24	20D
0005434602861	19063	25	21B
0005434522413	19063	26	21C
0005434522382	19063	27	21D
0005434522404	19063	28	22A
0005434602858	19063	29	22C
0005435904396	19063	30	22D
0005435904395	19063	31	23A
0005432747387	418	1	1A
0005432747392	418	2	1C
0005432890780	418	3	1D
0005432890785	418	4	2A
0005432890759	418	5	2F
0005432747388	418	6	3A
0005432890752	418	7	3C
0005432747395	418	8	3D
0005432747410	418	9	3F
0005432753284	418	10	4A
0005432890731	418	11	4C
0005432747402	418	12	4E
0005435627116	418	13	4F
0005432747413	418	14	5A
0005432747408	418	15	5C
0005432219986	418	16	5D
0005432219984	418	17	5E
0005433875364	418	18	5F
0005432751511	418	19	6A
0005432747415	418	20	6C
0005432747378	418	21	6D
0005432747383	418	22	7C
0005432890690	418	23	7D
0005432890754	418	24	7F
0005432747382	418	25	8A
0005432747394	418	26	8C
0005432747393	418	27	8E
0005433293150	418	28	9A
0005432890826	418	29	9C
0005432747403	418	30	9D
0005432747404	418	31	9E
0005432751509	418	32	9F
0005432890784	418	33	10A
0005432747386	418	34	10C
0005432747398	418	35	10D
0005435154594	418	36	10E
0005432890777	418	37	10F
0005432747397	418	38	11A
0005432747390	418	39	11C
0005433293151	418	40	11D
0005432753285	418	41	11E
0005435627117	418	42	11F
0005432890827	418	43	12A
0005432219985	418	44	12C
0005432747389	418	45	12D
0005432890716	418	46	12E
0005433875352	418	47	13A
0005433293160	418	48	13D
0005435154595	418	49	13F
0005432890855	418	50	14A
0005432747406	418	51	14C
0005432747405	418	52	14E
0005432747399	418	53	15A
0005432747384	418	54	15C
0005432747411	418	55	15D
0005433293193	418	56	15E
0005432747381	418	57	15F
0005432747379	418	58	16C
0005433293209	418	59	16D
0005432747396	418	60	16E
0005432747400	418	61	16F
0005432747380	418	62	17E
0005432751510	418	63	18A
0005432890691	418	64	18D
0005432747407	418	65	18E
0005432890779	418	66	18F
0005432747409	418	67	19A
0005432747412	418	68	19C
0005432890753	418	69	19D
0005432890813	418	70	19E
0005432747391	418	71	19F
0005432890751	418	72	20A
0005432747414	418	73	20C
0005432890778	418	74	20D
0005432747401	418	75	20E
0005432747385	418	76	20F
0005432753250	12089	1	1A
0005432214793	12089	2	1C
0005432890940	12089	3	1D
0005432747151	12089	4	1F
0005432747141	12089	5	2A
0005432747183	12089	6	2C
0005432747054	12089	7	2F
0005433875371	12089	8	3A
0005432747184	12089	9	4A
0005432890937	12089	10	4C
0005432747177	12089	11	4D
0005432747113	12089	12	4E
0005432890942	12089	13	4F
0005432749755	12089	14	5A
0005432747111	12089	15	5D
0005432747285	12089	16	5F
0005432890936	12089	17	6A
0005432890935	12089	18	6C
0005432747057	12089	19	6D
0005432753256	12089	20	6F
0005432214795	12089	21	6E
0005432747149	12089	22	7A
0005432756806	12089	23	7C
0005432890943	12089	24	7D
0005432749756	12089	25	7E
0005432890939	12089	26	7F
0005432747064	12089	27	8A
0005432747058	12089	28	8C
0005432756805	12089	29	8D
0005432747330	12089	30	8E
0005432890931	12089	31	8F
0005432214794	12089	32	9C
0005432747092	12089	33	9D
0005432747094	12089	34	9F
0005432747179	12089	35	10A
0005432890941	12089	36	10C
0005432747059	12089	37	10D
0005432747286	12089	38	10F
0005432747053	12089	39	11D
0005432747093	12089	40	11E
0005432890945	12089	41	12A
0005432747003	12089	42	12C
0005432747188	12089	43	12D
0005432746945	12089	44	12F
0005432890932	12089	45	13A
0005432747112	12089	46	13C
0005432747004	12089	47	13D
0005432747070	12089	48	13E
0005432890934	12089	49	13F
0005432753257	12089	50	14A
0005432749759	12089	51	14C
0005432890948	12089	52	14D
0005432747230	12089	53	14E
0005432747140	12089	54	15A
0005432749751	12089	55	15C
0005432747110	12089	56	15D
0005432890933	12089	57	15E
0005432747189	12089	58	15F
0005432747069	12089	59	16A
0005432747201	12089	60	16C
0005432746901	12089	61	16E
0005432747051	12089	62	16F
0005432747180	12089	63	17A
0005432746961	12089	64	17D
0005432747187	12089	65	17E
0005432753261	12089	66	18A
0005432747061	12089	67	18D
0005432747060	12089	68	18E
0005432890949	12089	69	18F
0005432747067	12089	70	19A
0005432890946	12089	71	19C
0005432890947	12089	72	19D
0005432747037	12089	73	19E
0005432756809	12089	74	19F
0005432746946	12089	75	20A
0005432890938	12089	76	20D
0005432890944	12089	77	20E
0005432747240	12089	78	20F
0005432927923	18939	1	1B
0005433524987	18939	2	1C
0005433533287	18939	3	2A
0005433524988	18939	4	2C
0005432927922	18939	5	2D
0005433524983	18939	6	3B
0005433524981	18939	7	3D
0005433531275	18939	8	4C
0005433531276	18939	9	4D
0005433524979	18939	10	5A
0005432927909	18939	11	5B
0005433524985	18939	12	6A
0005432927915	18939	13	6B
0005432927914	18939	14	6C
0005433531273	18939	15	6D
0005433531274	18939	16	7A
0005433531277	18939	17	7B
0005433524984	18939	18	7C
0005433524986	18939	19	7D
0005433524989	18939	20	18A
0005433524980	18939	21	18B
0005433524990	18939	22	18C
0005432927916	18939	23	19B
0005433533288	18939	24	20A
0005432927888	18939	25	20C
0005432927950	18939	26	20D
0005433524982	18939	27	21A
0005432927924	18939	28	21B
0005433533290	18939	29	21D
0005433533289	18939	30	22C
0005432927917	18939	31	23A
0005433524913	32501	1	3D
0005432927961	32501	2	4D
0005433524864	32501	3	5B
0005432927960	32501	4	5D
0005433524898	32501	5	6A
0005433524899	32501	6	6C
0005433531261	32501	7	7B
0005433524883	32501	8	18B
0005432927963	32501	9	19B
0005432927962	32501	10	19D
0005433524884	32501	11	20A
0005433531238	32501	12	20C
0005433531262	32501	13	21A
0005433524865	32501	14	21C
0005432927965	32501	15	22A
0005433527221	32501	16	22C
0005432927964	32501	17	23A
0005435372563	5301	1	1C
0005434823033	5301	2	1A
0005435372607	5301	3	1G
0005435372276	5301	4	1K
0005434823078	5301	5	2D
0005435149964	5301	6	2C
0005434823122	5301	7	2A
0005434823072	5301	8	2H
0005434823025	5301	9	2G
0005434823080	5301	10	3A
0005435372438	5301	11	2K
0005435372529	5301	12	3D
0005432394085	5301	13	3K
0005435735058	5301	14	3H
0005435661890	5301	15	4C
0005435178981	5301	16	4K
0005434823038	5301	17	4H
0005434823035	5301	18	5D
0005434828682	5301	19	5G
0005435735071	5301	20	11A
0005434823086	5301	21	5K
0005434823088	5301	22	11D
0005434823054	5301	23	11F
0005434823050	5301	24	11H
0005435386514	5301	25	12A
0005434823034	5301	26	12E
0005435149971	5301	27	12D
0005434823085	5301	28	12F
0005435372238	5301	29	13A
0005435149969	5301	30	12K
0005434823119	5301	31	12H
0005434823024	5301	32	13C
0005435178982	5301	33	13F
0005434823071	5301	34	13E
0005434823019	5301	35	13D
0005435299729	5301	36	13H
0005434823052	5301	37	13G
0005435149976	5301	38	14D
0005435372389	5301	39	14C
0005435372460	5301	40	14F
0005434823017	5301	41	14K
0005434823015	5301	42	14G
0005435372395	5301	43	15A
0005434823124	5301	44	15E
0005435386492	5301	45	15D
0005435386472	5301	46	15G
0005435149974	5301	47	16A
0005434823110	5301	48	15K
0005434823087	5301	49	15H
0005435372335	5301	50	16C
0005434823045	5301	51	16F
0005435735064	5301	52	16E
0005435372295	5301	53	16K
0005434823029	5301	54	17C
0005434823092	5301	55	17A
0005434558231	5301	56	17E
0005434823053	5301	57	17G
0005434823010	5301	58	17F
0005435372498	5301	59	17K
0005434823128	5301	60	17H
0005432394088	5301	61	18B
0005434823108	5301	62	18E
0005435372141	5301	63	18F
0005434823090	5301	64	18K
0005435372324	5301	65	18J
0005432121281	5301	66	19A
0005434823007	5301	67	19D
0005435149966	5301	68	19F
0005434823076	5301	69	19J
0005435372810	5301	70	19K
0005435372138	5301	71	20B
0005435372496	5301	72	20A
0005435372275	5301	73	20E
0005435735067	5301	74	20D
0005434823051	5301	75	20C
0005434823104	5301	76	20G
0005435386459	5301	77	20F
0005434823003	5301	78	20K
0005435149973	5301	79	20J
0005434823126	5301	80	20H
0005435386515	5301	81	21D
0005435372451	5301	82	21C
0005434823096	5301	83	21B
0005434823065	5301	84	22A
0005432121272	5301	85	21K
0005434823113	5301	86	21J
0005434823008	5301	87	22C
0005432121277	5301	88	22B
0005435149965	5301	89	22D
0005432823429	5301	90	22F
0005435304115	5301	91	22J
0005434828684	5301	92	23B
0005434823059	5301	93	22K
0005434823091	5301	94	23C
0005434823009	5301	95	23F
0005435372473	5301	96	23E
0005432396227	5301	97	23H
0005434823127	5301	98	23G
0005435386474	5301	99	24D
0005434823055	5301	100	23K
0005432121278	5301	101	24F
0005435372323	5301	102	25B
0005432121283	5301	103	25A
0005434823040	5301	104	24G
0005434823064	5301	105	25D
0005435372688	5301	106	25C
0005434823107	5301	107	25F
0005434823020	5301	108	25E
0005435372237	5301	109	25H
0005434823121	5301	110	25G
0005434823032	5301	111	25K
0005434828683	5301	112	25J
0005435372261	5301	113	26B
0005434823004	5301	114	26A
0005435372562	5301	115	26E
0005434823060	5301	116	26D
0005434831125	5301	117	26G
0005434831124	5301	118	26H
0005435299728	5301	119	27B
0005434823047	5301	120	27A
0005435386493	5301	121	27D
0005435372723	5301	122	27C
0005435372398	5301	123	27F
0005435372544	5301	124	27E
0005434823036	5301	125	27H
0005434823063	5301	126	28C
0005434823070	5301	127	28B
0005434823039	5301	128	28A
0005434823073	5301	129	28D
0005434823081	5301	130	28G
0005434823112	5301	131	28F
0005432121276	5301	132	28J
0005435372532	5301	133	28H
0005435386484	5301	134	29B
0005434823028	5301	135	29C
0005435149978	5301	136	29F
0005434823023	5301	137	29G
0005435372619	5301	138	30A
0005434823100	5301	139	29K
0005434823095	5301	140	30B
0005434823084	5301	141	30E
0005434823082	5301	142	30D
0005435386458	5301	143	30C
0005432121271	5301	144	30G
0005434823011	5301	145	30K
0005432121274	5301	146	30J
0005434823012	5301	147	30H
0005434823030	5301	148	31C
0005434823013	5301	149	31B
0005434823043	5301	150	31G
0005435372137	5301	151	31E
0005434823117	5301	152	31D
0005432121273	5301	153	31H
0005432394086	5301	154	32A
0005435372311	5301	155	32C
0005432394087	5301	156	32B
0005435372603	5301	157	32D
0005432121280	5301	158	32G
0005435149975	5301	159	32F
0005434823123	5301	160	32J
0005434823001	5301	161	32H
0005434822999	5301	162	33B
0005432823430	5301	163	33A
0005434823018	5301	164	32K
0005434823057	5301	165	33D
0005432396225	5301	166	33C
0005435372427	5301	167	33F
0005435149972	5301	168	33H
0005435372483	5301	169	33G
0005435372458	5301	170	33K
0005434823115	5301	171	34A
0005435372485	5301	172	34E
0005435372390	5301	173	34D
0005435149970	5301	174	34G
0005434664949	5301	175	34F
0005435372474	5301	176	34H
0005434823014	5301	177	35A
0005434558230	5301	178	34K
0005435372415	5301	179	35D
0005435372152	5301	180	35C
0005435149977	5301	181	35B
0005434823105	5301	182	35F
0005435372538	5301	183	35J
0005435372450	5301	184	35K
0005434823098	5301	185	36B
0005434664950	5301	186	36D
0005435386475	5301	187	36G
0005435372717	5301	188	36F
0005435304112	5301	189	36J
0005434823002	5301	190	36H
0005434823111	5301	191	37A
0005432121275	5301	192	36K
0005434823116	5301	193	37D
0005434823026	5301	194	37C
0005432394089	5301	195	37E
0005434823016	5301	196	37G
0005434558229	5301	197	38A
0005434823031	5301	198	38H
0005435372135	5301	199	38C
0005434823048	5301	200	38K
0005434823101	5301	201	38J
0005434823079	5301	202	39A
0005435372396	5301	203	39D
0005434823083	5301	204	39C
0005435149968	5301	205	39F
0005432823422	5301	206	39H
0005434823044	5301	207	39G
0005434823021	5301	208	40A
0005432121270	5301	209	39J
0005434823109	5301	210	40B
0005434823069	5301	211	40E
0005434823103	5301	212	40D
0005435372365	5301	213	40G
0005432121279	5301	214	40F
0005435299727	5301	215	40J
0005435372459	5301	216	40H
0005434823056	5301	217	41B
0005435386460	5301	218	40K
0005434823042	5301	219	41D
0005432396228	5301	220	41E
0005432396226	5301	221	41J
0005435372222	5301	222	41H
0005434558232	5301	223	42A
0005435372428	5301	224	41K
0005434823093	5301	225	42C
0005435149967	5301	226	42B
0005434823106	5301	227	42E
0005434831127	5301	228	42G
0005435372726	5301	229	42F
0005434823067	5301	230	42H
0005434823102	5301	231	43A
0005434823077	5301	232	43C
0005434823118	5301	233	43F
0005435372262	5301	234	43D
0005434831128	5301	235	43H
0005434823027	5301	236	43G
0005434823094	5301	237	43J
0005432396224	5301	238	44B
0005434823000	5301	239	44E
0005434823120	5301	240	44D
0005435304110	5301	241	44C
0005434823061	5301	242	44H
0005435372223	5301	243	45B
0005435372327	5301	244	45D
0005434823062	5301	245	45F
0005434831126	5301	246	45J
0005435372602	5301	247	45G
0005434823049	5301	248	46A
0005434823066	5301	249	45K
0005435372381	5301	250	46D
0005435304109	5301	251	46G
0005434823046	5301	252	46F
0005435661885	5301	253	46K
0005435386513	5301	254	46J
0005435372359	5301	255	46H
0005434823074	5301	256	47A
0005434823041	5301	257	47G
0005434823022	5301	258	47K
0005434823068	5301	259	47H
0005435386486	5301	260	48C
0005435372312	5301	261	48A
0005435372401	5301	262	48F
0005434823099	5301	263	48D
0005435372524	5301	264	48H
0005434823089	5301	265	48G
0005435372328	5301	266	49A
0005434823037	5301	267	49E
0005434823075	5301	268	49D
0005435372497	5301	269	49F
0005435372260	5301	270	49G
0005434823125	5301	271	50C
0005435372360	5301	272	50A
0005434823005	5301	273	50E
0005434823097	5301	274	50D
0005434823058	5301	275	50F
0005432121282	5301	276	51D
0005432823423	5301	277	50K
0005435372442	5301	278	51F
0005434823114	5301	279	51E
0005434823006	5301	280	51G
0005434821440	9925	1	1D
0005434821825	9925	2	1A
0005434822144	9925	3	1H
0005432400088	9925	4	1G
0005435372981	9925	5	1K
0005435373000	9925	6	2C
0005435372962	9925	7	2D
0005434822082	9925	8	2K
0005434822070	9925	9	2H
0005434558159	9925	10	3G
0005434821875	9925	11	3K
0005434821643	9925	12	3H
0005434821330	9925	13	4G
0005435149874	9925	14	4D
0005435149875	9925	15	4K
0005434822094	9925	16	4H
0005434821799	9925	17	5D
0005434821874	9925	18	5A
0005434822136	9925	19	5G
0005434822152	9925	20	11A
0005434822023	9925	21	5K
0005434821879	9925	22	11D
0005434821500	9925	23	11C
0005435735121	9925	24	11G
0005434821933	9925	25	11F
0005435735120	9925	26	11E
0005435661919	9925	27	12C
0005435149876	9925	28	12A
0005434821414	9925	29	12F
0005435373013	9925	30	12D
0005434821909	9925	31	12G
0005434822330	9925	32	12K
0005435372968	9925	33	13D
0005435372967	9925	34	13C
0005435373024	9925	35	13F
0005432396190	9925	36	13E
0005434821986	9925	37	13K
0005435373003	9925	38	13H
0005432396187	9925	39	13G
0005435373017	9925	40	14C
0005435373006	9925	41	14A
0005434821464	9925	42	14D
0005434822129	9925	43	14F
0005434822102	9925	44	14E
0005435372966	9925	45	15C
0005434822216	9925	46	15A
0005434822073	9925	47	15D
0005435372995	9925	48	15G
0005434821856	9925	49	15F
0005435386549	9925	50	16A
0005435299757	9925	51	15K
0005435373021	9925	52	15H
0005432396200	9925	53	16C
0005435149808	9925	54	16F
0005435372991	9925	55	16K
0005435373026	9925	56	16H
0005435372985	9925	57	17A
0005435373009	9925	58	17H
0005434822143	9925	59	17E
0005434822101	9925	60	17K
0005435386547	9925	61	18B
0005435386546	9925	62	18E
0005434821442	9925	63	18D
0005434822323	9925	64	18G
0005432203032	9925	65	18F
0005434822071	9925	66	18J
0005435373020	9925	67	18H
0005434822074	9925	68	19A
0005435302183	9925	69	18K
0005435386553	9925	70	19D
0005435149894	9925	71	19C
0005435149887	9925	72	19B
0005435372965	9925	73	19F
0005434821954	9925	74	19E
0005435149866	9925	75	19H
0005434821553	9925	76	19G
0005435372993	9925	77	19J
0005432396189	9925	78	20B
0005435372988	9925	79	20A
0005435373015	9925	80	20E
0005432400069	9925	81	20G
0005435372972	9925	82	20K
0005434821914	9925	83	20J
0005434822277	9925	84	20H
0005435372961	9925	85	21B
0005434822503	9925	86	21A
0005434831080	9925	87	21D
0005434822218	9925	88	21E
0005432396199	9925	89	21J
0005434821985	9925	90	21H
0005434822125	9925	91	22A
0005432400089	9925	92	21K
0005435373019	9925	93	22B
0005435372973	9925	94	22E
0005432400090	9925	95	22K
0005435372983	9925	96	22J
0005435149817	9925	97	23E
0005434822239	9925	98	23D
0005432823444	9925	99	23F
0005434821862	9925	100	23J
0005434821967	9925	101	24D
0005435386550	9925	102	23K
0005435735123	9925	103	24F
0005435149848	9925	104	25A
0005432823442	9925	105	24G
0005434821538	9925	106	25C
0005435372976	9925	107	25B
0005435373025	9925	108	25F
0005435372982	9925	109	25E
0005435372978	9925	110	25H
0005435372974	9925	111	25G
0005434821867	9925	112	26A
0005434558156	9925	113	26E
0005434821746	9925	114	26D
0005435373022	9925	115	26G
0005435302181	9925	116	26J
0005435372989	9925	117	26H
0005434821783	9925	118	27A
0005434822217	9925	119	26K
0005432396191	9925	120	27D
0005434821810	9925	121	27E
0005435299758	9925	122	27H
0005434822351	9925	123	27K
0005434821809	9925	124	28D
0005434821726	9925	125	28G
0005432203035	9925	126	28F
0005434831081	9925	127	28J
0005434822146	9925	128	28H
0005435373023	9925	129	29F
0005434822031	9925	130	29E
0005434822058	9925	131	29G
0005435372992	9925	132	30A
0005435372969	9925	133	29K
0005434821855	9925	134	30E
0005435302179	9925	135	30C
0005435149847	9925	136	30H
0005432823441	9925	137	30F
0005434822137	9925	138	30K
0005435372971	9925	139	30J
0005434821859	9925	140	31B
0005434822124	9925	141	31C
0005434821571	9925	142	31F
0005434821865	9925	143	31H
0005434822238	9925	144	31G
0005435373004	9925	145	32A
0005435149865	9925	146	31K
0005434822841	9925	147	31J
0005434822581	9925	148	32B
0005434822107	9925	149	32E
0005435149884	9925	150	32H
0005434821708	9925	151	32G
0005432203034	9925	152	32F
0005435149816	9925	153	33A
0005432203030	9925	154	33D
0005435299755	9925	155	33F
0005435372986	9925	156	33E
0005435735122	9925	157	33H
0005434822156	9925	158	33G
0005434822276	9925	159	34A
0005434821650	9925	160	33J
0005434821658	9925	161	34C
0005432823443	9925	162	34E
0005435302182	9925	163	34D
0005435372964	9925	164	34H
0005434821932	9925	165	34G
0005435149872	9925	166	35E
0005435372984	9925	167	35H
0005434821983	9925	168	35K
0005434822314	9925	169	36C
0005434822168	9925	170	36D
0005435373007	9925	171	36G
0005435372997	9925	172	36K
0005434821649	9925	173	36J
0005434831113	9925	174	36H
0005435372979	9925	175	37B
0005434822140	9925	176	37A
0005434821331	9925	177	37D
0005434558165	9925	178	37C
0005434821654	9925	179	37F
0005434821821	9925	180	37E
0005435299754	9925	181	37H
0005435661920	9925	182	37K
0005435661918	9925	183	38C
0005434821536	9925	184	38K
0005435372994	9925	185	38J
0005435372963	9925	186	38H
0005434821769	9925	187	39A
0005435373012	9925	188	39D
0005435372998	9925	189	39C
0005435372970	9925	190	39E
0005434821845	9925	191	39J
0005435372999	9925	192	39H
0005434822169	9925	193	39K
0005434558157	9925	194	40B
0005434822273	9925	195	40A
0005434822132	9925	196	40E
0005435149833	9925	197	40D
0005434821807	9925	198	40H
0005435373016	9925	199	40K
0005434821910	9925	200	40J
0005435302180	9925	201	41A
0005434821721	9925	202	41C
0005434822347	9925	203	41B
0005434822172	9925	204	41E
0005434558164	9925	205	41J
0005434821982	9925	206	41H
0005435373001	9925	207	42A
0005434821657	9925	208	41K
0005435372996	9925	209	42C
0005434822141	9925	210	42E
0005434821572	9925	211	42D
0005435372990	9925	212	42H
0005434822582	9925	213	42G
0005434821864	9925	214	42F
0005434822211	9925	215	43B
0005435386548	9925	216	42K
0005435299756	9925	217	43F
0005434558158	9925	218	43J
0005434822067	9925	219	44C
0005434822320	9925	220	44B
0005434821537	9925	221	44A
0005435373002	9925	222	44E
0005434821981	9925	223	44D
0005434821806	9925	224	44H
0005435372977	9925	225	44G
0005432203036	9925	226	44F
0005434822235	9925	227	45A
0005434821690	9925	228	44K
0005435386551	9925	229	45D
0005434821833	9925	230	45C
0005432203033	9925	231	45B
0005435373014	9925	232	45F
0005434821656	9925	233	45E
0005434821915	9925	234	45J
0005434822206	9925	235	45H
0005434822329	9925	236	45G
0005434822151	9925	237	45K
0005434822091	9925	238	46A
0005434822171	9925	239	46E
0005434822207	9925	240	46D
0005435373005	9925	241	46C
0005434828648	9925	242	46J
0005434821771	9925	243	46H
0005435373008	9925	244	47C
0005434822215	9925	245	47A
0005434558155	9925	246	47E
0005434821441	9925	247	47G
0005434558139	9925	248	47H
0005434821854	9925	249	48A
0005435386552	9925	250	48F
0005432396188	9925	251	48D
0005434831106	9925	252	48H
0005434822319	9925	253	49E
0005434664925	9925	254	49C
0005434821723	9925	255	49G
0005435373018	9925	256	49F
0005432203031	9925	257	49H
0005435373011	9925	258	50C
0005434822352	9925	259	50E
0005435372987	9925	260	50D
0005435373010	9925	261	50G
0005435735124	9925	262	50F
0005435372980	9925	263	51D
0005435372975	9925	264	50H
0005435302184	9925	265	51F
0005434821988	9925	266	51E
0005434821722	9925	267	51G
0005435082762	6975	1	1B
0005435082760	6975	2	1C
0005435082755	6975	3	3A
0005435790295	6975	4	3C
0005435082753	6975	5	5A
0005435082757	6975	6	5B
0005435790294	6975	7	6B
0005435082758	6975	8	7C
0005435082759	6975	9	18D
0005435082752	6975	10	19A
0005435082763	6975	11	19C
0005435082756	6975	12	20A
0005435082754	6975	13	21D
0005435082761	6975	14	22C
0005435082681	25993	1	1A
0005435082655	25993	2	2C
0005435082697	25993	3	3C
0005435790257	25993	4	3D
0005435082682	25993	5	4D
0005435082677	25993	6	6D
0005435790283	25993	7	7B
0005435082694	25993	8	18B
0005435082671	25993	9	18D
0005435082656	25993	10	19C
0005435790282	25993	11	20B
0005435082683	25993	12	21D
0005435082672	25993	13	22B
0005435790278	25993	14	23B
0005434756275	9552	1	1A
0005434756277	9552	2	1C
0005434756270	9552	3	1D
0005434756285	9552	4	1F
0005434213733	9552	5	2A
0005434214006	9552	6	2C
0005434213928	9552	7	2D
0005434756243	9552	8	2F
0005434213853	9552	9	3A
0005434214065	9552	10	3C
0005434756235	9552	11	3D
0005434213902	9552	12	3F
0005434213929	9552	13	4A
0005434756249	9552	14	4C
0005434756237	9552	15	4D
0005434214142	9552	16	4E
0005434213845	9552	17	4F
0005434213913	9552	18	5A
0005434756259	9552	19	5C
0005434756238	9552	20	5D
0005434756282	9552	21	5E
0005434756239	9552	22	5F
0005434756260	9552	23	6A
0005434214024	9552	24	6C
0005434756250	9552	25	6D
0005434214077	9552	26	6E
0005434756272	9552	27	6F
0005434756268	9552	28	7A
0005434756265	9552	29	7C
0005434756255	9552	30	7D
0005434756261	9552	31	7E
0005434756258	9552	32	7F
0005434213748	9552	33	8A
0005434213941	9552	34	8C
0005434213976	9552	35	8D
0005434756241	9552	36	8E
0005434756246	9552	37	8F
0005434756262	9552	38	9A
0005434756264	9552	39	9C
0005434756257	9552	40	9D
0005434213831	9552	41	9E
0005434756267	9552	42	9F
0005434756276	9552	43	10A
0005434756245	9552	44	10C
0005434213970	9552	45	10D
0005434756274	9552	46	10E
0005434756280	9552	47	10F
0005434756278	9552	48	11A
0005434756248	9552	49	11C
0005434214056	9552	50	11D
0005434214023	9552	51	11E
0005434214022	9552	52	11F
0005434213937	9552	53	12A
0005434214055	9552	54	12C
0005434213940	9552	55	12E
0005434213794	9552	56	12F
0005434756271	9552	57	13A
0005434756273	9552	58	13C
0005434214032	9552	59	13D
0005434756256	9552	60	13E
0005434213836	9552	61	13F
0005434213825	9552	62	14A
0005434756269	9552	63	14C
0005434756254	9552	64	14D
0005434213801	9552	65	14E
0005434756284	9552	66	14F
0005434756247	9552	67	15A
0005434214021	9552	68	15C
0005434214088	9552	69	15D
0005434756279	9552	70	15E
0005434756263	9552	71	16A
0005434213945	9552	72	16C
0005434213974	9552	73	16D
0005434213887	9552	74	16F
0005434213912	9552	75	16E
0005434213975	9552	76	17A
0005434213888	9552	77	17C
0005434756266	9552	78	17D
0005434756283	9552	79	17E
0005434756242	9552	80	17F
0005434756253	9552	81	18A
0005434213816	9552	82	18C
0005434756240	9552	83	18D
0005434756251	9552	84	18F
0005434214031	9552	85	19A
0005434756234	9552	86	19C
0005434756252	9552	87	19D
0005434213989	9552	88	19E
0005434756286	9552	89	19F
0005434213968	9552	90	20A
0005434213908	9552	91	20C
0005434756244	9552	92	20D
0005434756281	9552	93	20E
0005434756236	9552	94	20F
0005434755959	28646	1	1A
0005434755825	28646	2	1C
0005434214302	28646	3	1D
0005434755791	28646	4	1F
0005434755890	28646	5	2A
0005434214312	28646	6	2C
0005434755803	28646	7	2D
0005434214301	28646	8	2F
0005434214311	28646	9	3A
0005434755967	28646	10	3C
0005434755922	28646	11	3D
0005434755749	28646	12	3F
0005434214308	28646	13	4A
0005434755958	28646	14	4C
0005434755919	28646	15	4D
0005434755752	28646	16	4E
0005434755850	28646	17	5A
0005434755767	28646	18	5C
0005434214281	28646	19	5D
0005434214298	28646	20	5E
0005434214313	28646	21	5F
0005434214304	28646	22	6A
0005434214287	28646	23	6C
0005434755968	28646	24	6D
0005434755849	28646	25	6E
0005434755721	28646	26	6F
0005434214271	28646	27	7A
0005434214293	28646	28	7C
0005434755753	28646	29	7D
0005434755794	28646	30	7E
0005434755793	28646	31	7F
0005434755891	28646	32	8A
0005434214315	28646	33	8C
0005434755720	28646	34	8D
0005434755806	28646	35	8E
0005434755960	28646	36	8F
0005434755802	28646	37	9A
0005434214289	28646	38	9C
0005434755718	28646	39	9D
0005434214309	28646	40	9E
0005434214286	28646	41	9F
0005434755906	28646	42	10A
0005434214295	28646	43	10C
0005434214296	28646	44	10D
0005434214294	28646	45	10E
0005434214300	28646	46	10F
0005434755863	28646	47	11A
0005434755857	28646	48	11C
0005434214276	28646	49	11D
0005434214299	28646	50	11E
0005434214273	28646	51	11F
0005434755852	28646	52	12A
0005434755837	28646	53	12C
0005434755988	28646	54	12D
0005434214310	28646	55	12E
0005434214279	28646	56	12F
0005434214316	28646	57	13A
0005434755734	28646	58	13C
0005434755710	28646	59	13D
0005434214278	28646	60	13E
0005434214291	28646	61	13F
0005434214283	28646	62	14A
0005434214285	28646	63	14C
0005434755887	28646	64	14D
0005434214288	28646	65	14F
0005434755735	28646	66	14E
0005434214275	28646	67	15A
0005434755856	28646	68	15C
0005434755864	28646	69	15D
0005434214306	28646	70	15E
0005434214290	28646	71	15F
0005434755779	28646	72	16C
0005434214297	28646	73	16D
0005434755824	28646	74	16E
0005434214284	28646	75	16F
0005434214272	28646	76	17A
0005434755830	28646	77	17C
0005434214282	28646	78	17D
0005434214307	28646	79	17E
0005434214277	28646	80	17F
0005434214314	28646	81	18A
0005434755840	28646	82	18C
0005434755954	28646	83	18D
0005434214292	28646	84	18E
0005434755780	28646	85	18F
0005434214270	28646	86	19A
0005434214269	28646	87	19C
0005434214305	28646	88	19D
0005434214280	28646	89	19E
0005434755942	28646	90	19F
0005434214303	28646	91	20A
0005434214274	28646	92	20C
0005434755831	28646	93	20D
0005434755905	28646	94	20E
0005434755807	28646	95	20F
0005434760156	10807	1	2D
0005435100111	10807	2	6C
0005435100110	10807	3	18C
0005435100078	31801	1	1D
0005435100086	31801	2	2D
0005434639221	1972	1	1A
0005433202144	1972	2	1B
0005433202162	1972	3	1C
0005433202206	1972	4	1D
0005434639228	1972	5	2A
0005433202187	1972	6	2B
0005434639234	1972	7	2C
0005434639231	1972	8	2D
0005434639222	1972	9	3A
0005434639223	1972	10	3B
0005432290621	1972	11	3C
0005434639227	1972	12	3D
0005433202154	1972	13	4A
0005434639236	1972	14	4B
0005433202238	1972	15	4C
0005434639226	1972	16	4D
0005433202145	1972	17	5A
0005432290620	1972	18	5B
0005433202155	1972	19	5C
0005434639220	1972	20	5D
0005433202148	1972	21	6B
0005433202161	1972	22	6A
0005434639216	1972	23	6C
0005434639229	1972	24	6D
0005434639215	1972	25	7A
0005434639214	1972	26	7B
0005432290622	1972	27	7D
0005434639235	1972	28	18A
0005434639211	1972	29	18B
0005434639213	1972	30	18C
0005433202147	1972	31	18D
0005434639225	1972	32	19A
0005433202212	1972	33	19B
0005434639212	1972	34	19C
0005433202170	1972	35	19D
0005433202211	1972	36	20A
0005434639230	1972	37	20B
0005433202215	1972	38	20C
0005434639233	1972	39	20D
0005433202189	1972	40	21A
0005434639217	1972	41	21B
0005434639232	1972	42	21C
0005433202237	1972	43	21D
0005433202213	1972	44	22A
0005434639224	1972	45	22B
0005433202188	1972	46	22C
0005434639218	1972	47	22D
0005434639237	1972	48	23A
0005434639219	1972	49	23B
0005434639046	23252	1	1A
0005433202289	23252	2	1C
0005433202290	23252	3	1D
0005433202286	23252	4	2A
0005434638884	23252	5	2C
0005433202288	23252	6	2D
0005434638883	23252	7	3A
0005434638998	23252	8	3B
0005434639052	23252	9	3C
0005433202294	23252	10	3D
0005433202283	23252	11	4A
0005434639056	23252	12	4C
0005435948304	23252	13	4D
0005434639021	23252	14	5A
0005433202284	23252	15	5B
0005434639035	23252	16	5C
0005433202296	23252	17	5D
0005434638902	23252	18	6A
0005433202293	23252	19	6B
0005435948310	23252	20	6C
0005434639016	23252	21	6D
0005434638897	23252	22	7A
0005434639007	23252	23	7B
0005434638966	23252	24	7C
0005433202297	23252	25	7D
0005434639055	23252	26	18A
0005434639075	23252	27	18B
0005434638933	23252	28	18C
0005434639008	23252	29	18D
0005434638977	23252	30	19A
0005434638865	23252	31	19B
0005434639047	23252	32	19D
0005435948315	23252	33	20B
0005434639089	23252	34	20C
0005434639074	23252	35	20D
0005433202295	23252	36	21A
0005433202285	23252	37	21B
0005433202291	23252	38	21C
0005434638936	23252	39	21D
0005434638997	23252	40	22A
0005434638965	23252	41	22B
0005434639076	23252	42	22C
0005433202287	23252	43	22D
0005433202292	23252	44	23A
0005434639036	23252	45	23B
0005434600703	6053	1	1A
0005435326589	6053	2	2D
0005435326573	6053	3	3A
0005433533295	6053	4	3D
0005434600712	6053	5	4A
0005434600697	6053	6	4D
0005435326612	6053	7	5A
0005434600694	6053	8	5C
0005434600690	6053	9	5E
0005434600711	6053	10	5F
0005433533294	6053	11	6D
0005433533293	6053	12	6E
0005434600688	6053	13	6F
0005435326526	6053	14	7A
0005434600700	6053	15	7C
0005435326529	6053	16	7D
0005435326540	6053	17	7E
0005434600710	6053	18	7F
0005433533291	6053	19	8A
0005435326549	6053	20	8C
0005434600686	6053	21	8E
0005435326522	6053	22	8F
0005435326539	6053	23	9A
0005434600708	6053	24	9C
0005435326608	6053	25	9D
0005433531278	6053	26	9E
0005434600704	6053	27	10A
0005435326613	6053	28	10C
0005434600707	6053	29	10D
0005434600702	6053	30	11C
0005433533292	6053	31	11E
0005434600705	6053	32	11F
0005434600699	6053	33	12A
0005435326557	6053	34	12D
0005435326562	6053	35	12E
0005434600692	6053	36	12F
0005435326525	6053	37	13C
0005432111265	6053	38	13D
0005433531279	6053	39	14E
0005435326555	6053	40	14F
0005434600691	6053	41	15A
0005435326536	6053	42	15C
0005434600689	6053	43	15D
0005435326542	6053	44	15E
0005435326576	6053	45	15F
0005435326558	6053	46	16A
0005434600701	6053	47	16C
0005432111267	6053	48	16E
0005434600706	6053	49	17A
0005434600709	6053	50	17C
0005434600698	6053	51	17D
0005432111266	6053	52	17F
0005434600695	6053	53	18A
0005434600693	6053	54	18C
0005435326577	6053	55	19D
0005434600696	6053	56	20C
0005435326574	6053	57	20D
0005434600687	6053	58	20E
0005434600377	18600	1	1A
0005435326693	18600	2	1C
0005434600519	18600	3	1F
0005434600421	18600	4	2C
0005434600543	18600	5	4D
0005434600481	18600	6	4E
0005434600511	18600	7	4F
0005435326694	18600	8	5C
0005434600467	18600	9	5E
0005434600545	18600	10	6A
0005434600544	18600	11	6E
0005435326682	18600	12	6F
0005433531244	18600	13	7A
0005435326687	18600	14	7D
0005434600378	18600	15	7E
0005435326695	18600	16	7F
0005434600431	18600	17	8C
0005434600506	18600	18	8E
0005433531243	18600	19	8D
0005434600404	18600	20	9A
0005434600336	18600	21	9C
0005434600581	18600	22	9D
0005434600459	18600	23	9E
0005434600565	18600	24	10D
0005435326690	18600	25	10F
0005433531237	18600	26	11C
0005435326692	18600	27	11E
0005434600451	18600	28	11F
0005434600399	18600	29	12C
0005435326683	18600	30	12D
0005433527202	18600	31	13D
0005434600505	18600	32	13F
0005435326691	18600	33	14C
0005434600379	18600	34	14E
0005435326685	18600	35	14F
0005435326681	18600	36	15A
0005434600376	18600	37	15D
0005434600533	18600	38	15F
0005434600500	18600	39	16A
0005434600418	18600	40	16D
0005435326686	18600	41	16E
0005435326684	18600	42	16F
0005434600460	18600	43	17C
0005433531230	18600	44	17D
0005434600403	18600	45	17F
0005435326689	18600	46	18C
0005435326688	18600	47	18D
0005434600337	18600	48	18F
0005434600499	18600	49	19C
0005434600381	18600	50	19D
0005434600502	18600	51	20D
0005434600520	18600	52	20E
0005433180844	10654	1	1A
0005434550972	10654	2	1C
0005433180751	10654	3	1D
0005433180824	10654	4	1F
0005434550971	10654	5	2A
0005434550948	10654	6	2C
0005433180791	10654	7	2F
0005434550968	10654	8	3A
0005434550961	10654	9	3C
0005434550947	10654	10	3D
0005434550935	10654	11	3F
0005434550984	10654	12	4A
0005433180719	10654	13	4C
0005434550946	10654	14	4D
0005434550939	10654	15	4E
0005434550938	10654	16	4F
0005433180755	10654	17	5A
0005434550959	10654	18	5D
0005433180789	10654	19	5E
0005434550983	10654	20	5F
0005433180768	10654	21	6A
0005434550970	10654	22	6C
0005434550977	10654	23	6D
0005434550982	10654	24	6E
0005434550975	10654	25	7A
0005434550949	10654	26	7C
0005433180761	10654	27	7D
0005434550933	10654	28	7E
0005434550985	10654	29	7F
0005434550973	10654	30	8A
0005434550979	10654	31	8C
0005434550932	10654	32	8D
0005434550945	10654	33	8E
0005433180766	10654	34	8F
0005434550950	10654	35	9C
0005433180656	10654	36	9D
0005433180822	10654	37	9E
0005434550941	10654	38	9F
0005434550974	10654	39	10A
0005434550944	10654	40	10C
0005433180657	10654	41	10D
0005434550969	10654	42	10F
0005434550978	10654	43	11A
0005434550940	10654	44	11C
0005433180777	10654	45	11E
0005434550953	10654	46	11D
0005434558227	10654	47	11F
0005433180823	10654	48	12A
0005434550981	10654	49	12C
0005433180718	10654	50	12D
0005434550956	10654	51	12E
0005434550954	10654	52	13C
0005434550952	10654	53	13A
0005434550986	10654	54	13D
0005434550955	10654	55	13E
0005434550965	10654	56	13F
0005434550937	10654	57	14A
0005434550967	10654	58	14C
0005433180845	10654	59	14D
0005434550936	10654	60	14E
0005434558228	10654	61	15A
0005433180732	10654	62	15C
0005434550976	10654	63	15D
0005434550957	10654	64	15E
0005434550943	10654	65	15F
0005433180733	10654	66	16A
0005434550966	10654	67	16C
0005434550958	10654	68	16D
0005434550964	10654	69	16E
0005434550942	10654	70	16F
0005434554056	10654	71	17A
0005434554057	10654	72	17C
0005434550962	10654	73	17E
0005433180790	10654	74	17F
0005433180778	10654	75	18C
0005434550960	10654	76	18D
0005434550963	10654	77	18E
0005433180843	10654	78	19A
0005433180748	10654	79	19C
0005434550934	10654	80	19E
0005434554055	10654	81	19F
0005433180693	10654	82	20A
0005433180828	10654	83	20D
0005434550980	10654	84	20E
0005434550951	10654	85	20F
0005433181004	27677	1	1C
0005433181009	27677	2	2F
0005433180987	27677	3	3A
0005433180986	27677	4	4C
0005433180996	27677	5	5E
0005433180992	27677	6	6C
0005433180989	27677	7	7A
0005433181007	27677	8	8C
0005433180998	27677	9	8D
0005433181010	27677	10	8F
0005433180988	27677	11	9C
0005433180985	27677	12	9E
0005433180990	27677	13	10E
0005433181002	27677	14	11A
0005433180997	27677	15	11C
0005433180995	27677	16	11E
0005433181003	27677	17	12E
0005433180993	27677	18	13E
0005433181001	27677	19	14C
0005433180991	27677	20	14E
0005433181006	27677	21	15C
0005433180994	27677	22	17D
0005433180999	27677	23	18A
0005433181005	27677	24	18E
0005433181000	27677	25	19A
0005433181008	27677	26	20E
0005434550452	27676	1	1A
0005434550356	27676	2	1C
0005434550755	27676	3	2A
0005434550610	27676	4	2C
0005434550679	27676	5	2D
0005434558171	27676	6	2F
0005434550467	27676	7	3C
0005434550454	27676	8	3D
0005434550695	27676	9	4C
0005434550545	27676	10	4D
0005434550704	27676	11	4E
0005434550440	27676	12	5A
0005434550611	27676	13	5C
0005434550534	27676	14	5E
0005434550706	27676	15	6A
0005434550510	27676	16	6E
0005434550402	27676	17	7A
0005434550489	27676	18	7C
0005434550594	27676	19	7D
0005434558146	27676	20	7E
0005434554030	27676	21	8C
0005434550604	27676	22	8F
0005434550696	27676	23	9A
0005434550551	27676	24	9C
0005434550433	27676	25	9D
0005434550442	27676	26	9F
0005434550546	27676	27	10A
0005434558153	27676	28	11D
0005434550466	27676	29	11F
0005434550475	27676	30	12A
0005434550593	27676	31	12D
0005434550431	27676	32	12F
0005434550540	27676	33	13C
0005434550436	27676	34	13D
0005434550533	27676	35	13E
0005434550649	27676	36	13F
0005434550705	27676	37	14A
0005434550726	27676	38	14C
0005434550873	27676	39	14D
0005434550651	27676	40	14E
0005434550650	27676	41	15A
0005434558154	27676	42	15C
0005434550385	27676	43	15E
0005434558182	27676	44	15F
0005434558162	27676	45	16A
0005434550487	27676	46	16C
0005434550425	27676	47	16D
0005434550741	27676	48	16E
0005434558172	27676	49	17A
0005434550403	27676	50	17E
0005434550437	27676	51	17F
0005434550636	27676	52	18C
0005434550727	27676	53	18D
0005434550453	27676	54	18F
0005434558173	27676	55	19A
0005434558187	27676	56	19C
0005434550541	27676	57	19E
0005434550535	27676	58	20A
0005434550609	27676	59	20C
0005434558163	27676	60	20D
0005434550441	27676	61	20E
0005434550548	27676	62	20F
0005433459201	6145	1	2A
0005433459203	6145	2	3A
0005433459199	6145	3	4B
0005433459200	6145	4	6A
0005433459202	6145	5	6B
0005433459173	19348	1	2A
0005433459167	19348	2	3A
0005435254465	19348	3	4A
0005435254464	19348	4	4B
0005433459174	19348	5	5B
0005435254463	19348	6	6A
0005435681954	6719	1	1A
0005435681979	6719	2	1C
0005435681938	6719	3	1D
0005435437638	6719	4	2A
0005435681948	6719	5	2C
0005435681974	6719	6	2D
0005435437653	6719	7	2F
0005435437795	6719	8	3A
0005435437692	6719	9	3C
0005435681973	6719	10	3D
0005435681978	6719	11	3F
0005435681946	6719	12	4A
0005435437735	6719	13	4C
0005435681975	6719	14	4D
0005435661916	6719	15	4E
0005435630952	6719	16	4F
0005435437713	6719	17	5A
0005435681968	6719	18	5C
0005435681936	6719	19	5D
0005435681956	6719	20	5E
0005435681955	6719	21	5F
0005435681971	6719	22	6A
0005432136147	6719	23	6C
0005435681976	6719	24	6D
0005435681960	6719	25	6E
0005432533255	6719	26	6F
0005435437672	6719	27	7A
0005435681944	6719	28	7C
0005435681943	6719	29	7D
0005432136148	6719	30	7E
0005435681937	6719	31	7F
0005435681951	6719	32	8A
0005435630951	6719	33	8C
0005435681967	6719	34	8D
0005435437749	6719	35	8E
0005435437739	6719	36	8F
0005435221502	6719	37	9A
0005435681969	6719	38	9C
0005435437745	6719	39	9D
0005435220295	6719	40	9E
0005435681935	6719	41	9F
0005435437744	6719	42	10A
0005435681972	6719	43	10C
0005435437691	6719	44	10E
0005435681959	6719	45	10F
0005434828666	6719	46	11A
0005435681947	6719	47	11C
0005432533251	6719	48	11D
0005435437714	6719	49	11E
0005435681939	6719	50	12A
0005435719565	6719	51	12C
0005435437677	6719	52	12D
0005432136146	6719	53	12E
0005435437750	6719	54	12F
0005435681941	6719	55	13A
0005435681965	6719	56	13C
0005435681961	6719	57	13D
0005435681963	6719	58	13E
0005435681966	6719	59	13F
0005432136150	6719	60	14C
0005435681977	6719	61	14A
0005435681934	6719	62	14D
0005435221501	6719	63	14E
0005435681940	6719	64	14F
0005435681964	6719	65	15A
0005432533249	6719	66	15C
0005435681958	6719	67	15D
0005435437676	6719	68	15F
0005435437651	6719	69	16A
0005435630953	6719	70	16C
0005435681957	6719	71	16F
0005432136145	6719	72	17A
0005435221503	6719	73	17C
0005435661915	6719	74	17D
0005435681953	6719	75	17E
0005435437652	6719	76	17F
0005435681942	6719	77	18A
0005435437671	6719	78	18C
0005435681945	6719	79	18D
0005435630954	6719	80	18E
0005435661917	6719	81	18F
0005432533247	6719	82	19A
0005435681962	6719	83	19C
0005432533248	6719	84	19D
0005435681949	6719	85	19E
0005435681970	6719	86	19F
0005432136149	6719	87	20A
0005435681952	6719	88	20C
0005435681950	6719	89	20D
0005435630950	6719	90	20E
0005435437706	6719	91	20F
0005432305738	24610	1	1A
0005435681609	24610	2	1C
0005435681635	24610	3	1D
0005435681407	24610	4	1F
0005432305739	24610	5	2A
0005435681628	24610	6	2C
0005435681595	24610	7	2D
0005435681615	24610	8	2F
0005435681718	24610	9	3A
0005435681482	24610	10	3C
0005435437854	24610	11	3D
0005435681578	24610	12	3F
0005435681386	24610	13	4A
0005435437850	24610	14	4C
0005435681496	24610	15	4D
0005435681579	24610	16	4E
0005435681608	24610	17	4F
0005435681637	24610	18	5A
0005435437851	24610	19	5C
0005435681570	24610	20	5D
0005435681456	24610	21	5E
0005435437864	24610	22	5F
0005435681519	24610	23	6A
0005435681738	24610	24	6C
0005435661898	24610	25	6D
0005434828687	24610	26	6E
0005435681602	24610	27	6F
0005435681707	24610	28	7A
0005435681629	24610	29	7C
0005435437855	24610	30	7D
0005435437856	24610	31	7E
0005432533281	24610	32	7F
0005435681477	24610	33	8A
0005435437863	24610	34	8C
0005435437857	24610	35	8D
0005435681713	24610	36	8E
0005435437849	24610	37	8F
0005434828685	24610	38	9A
0005435437865	24610	39	9C
0005435681487	24610	40	9D
0005435437869	24610	41	9E
0005435681649	24610	42	9F
0005435437848	24610	43	10A
0005435437868	24610	44	10C
0005435681684	24610	45	10D
0005435681478	24610	46	10E
0005435681714	24610	47	10F
0005435437858	24610	48	11A
0005435681625	24610	49	11C
0005435681689	24610	50	11D
0005435681676	24610	51	11E
0005435681498	24610	52	11F
0005435681596	24610	53	12A
0005435681638	24610	54	12C
0005435681417	24610	55	12D
0005435681706	24610	56	12E
0005432533280	24610	57	12F
0005435681600	24610	58	13A
0005435681673	24610	59	13C
0005435681576	24610	60	13D
0005435681520	24610	61	13E
0005435681466	24610	62	13F
0005435681503	24610	63	14A
0005435681397	24610	64	14C
0005435437860	24610	65	14D
0005435681447	24610	66	14E
0005435681613	24610	67	14F
0005435681500	24610	68	15A
0005435437853	24610	69	15C
0005435681597	24610	70	15D
0005435681614	24610	71	15E
0005435437861	24610	72	15F
0005434828686	24610	73	16A
0005435681717	24610	74	16C
0005435681681	24610	75	16D
0005435681497	24610	76	16E
0005435630923	24610	77	16F
0005435630920	24610	78	17A
0005435437859	24610	79	17C
0005435681594	24610	80	17D
0005435681690	24610	81	17E
0005435681610	24610	82	17F
0005435681418	24610	83	18A
0005435681669	24610	84	18C
0005435437866	24610	85	18D
0005435681491	24610	86	18E
0005435437867	24610	87	18F
0005435681675	24610	88	19A
0005435437862	24610	89	19C
0005435681495	24610	90	19D
0005435661899	24610	91	19E
0005435681584	24610	92	19F
0005435681528	24610	93	20A
0005435437852	24610	94	20C
0005435681567	24610	95	20D
0005435630933	24610	96	20E
0005435681616	24610	97	20F
0005435126174	11557	1	1C
0005435126157	11557	2	1D
0005435126151	11557	3	2D
0005435105965	11557	4	4C
0005435126169	11557	5	4E
0005435126156	11557	6	5D
0005435126184	11557	7	6A
0005435126163	11557	8	6D
0005435126159	11557	9	6E
0005435126153	11557	10	7D
0005435126179	11557	11	8A
0005435126182	11557	12	8D
0005435126165	11557	13	8E
0005435126180	11557	14	8F
0005435126152	11557	15	9A
0005435126172	11557	16	9F
0005435126158	11557	17	11D
0005435126164	11557	18	11F
0005435126161	11557	19	12A
0005435126175	11557	20	12C
0005435126150	11557	21	12D
0005435126177	11557	22	12F
0005435126170	11557	23	13A
0005435126185	11557	24	13C
0005435126166	11557	25	13D
0005435126171	11557	26	13E
0005435105966	11557	27	14A
0005435126181	11557	28	14D
0005435126176	11557	29	15A
0005435126187	11557	30	15C
0005435126186	11557	31	15D
0005435126149	11557	32	16A
0005435126160	11557	33	16D
0005435126183	11557	34	17C
0005435126168	11557	35	17F
0005435126154	11557	36	18A
0005435105967	11557	37	18C
0005435126173	11557	38	18E
0005435126162	11557	39	19F
0005435126155	11557	40	20C
0005435126178	11557	41	20D
0005435126167	11557	42	20F
0005435125790	31884	1	1C
0005435558074	31884	2	2A
0005435558077	31884	3	2C
0005435126021	31884	4	3F
0005435125881	31884	5	4C
0005435105944	31884	6	5A
0005435125915	31884	7	5E
0005435098529	31884	8	5F
0005435125714	31884	9	6A
0005435125909	31884	10	8D
0005435125929	31884	11	8F
0005435125886	31884	12	10A
0005435125833	31884	13	10C
0005435558076	31884	14	10D
0005435125890	31884	15	10E
0005435125813	31884	16	11C
0005435125853	31884	17	11E
0005435125879	31884	18	11F
0005435125887	31884	19	12C
0005435125857	31884	20	12D
0005435125914	31884	21	13A
0005435125854	31884	22	13F
0005435125839	31884	23	14A
0005435125855	31884	24	15E
0005435125840	31884	25	16E
0005435125889	31884	26	17E
0005435125991	31884	27	17F
0005435125856	31884	28	18A
0005435125812	31884	29	18C
0005435125845	31884	30	18E
0005435125908	31884	31	19C
0005435558075	31884	32	20D
0005435732256	13563	1	1A
0005433397862	13563	2	1C
0005433397842	13563	3	1D
0005433397855	13563	4	1F
0005433397839	13563	5	2C
0005433397854	13563	6	2D
0005433397838	13563	7	3A
0005435732155	13563	8	3C
0005433397831	13563	9	3D
0005433397830	13563	10	3F
0005433397845	13563	11	4F
0005433397841	13563	12	5C
0005433397835	13563	13	5D
0005433397865	13563	14	5F
0005433397826	13563	15	6C
0005433397873	13563	16	6E
0005433397858	13563	17	6F
0005433397869	13563	18	7C
0005435732133	13563	19	7D
0005435732164	13563	20	7F
0005433397848	13563	21	8E
0005433397870	13563	22	8F
0005433397867	13563	23	9C
0005433397871	13563	24	9F
0005433397863	13563	25	10A
0005433397834	13563	26	10E
0005433397853	13563	27	10F
0005433397872	13563	28	11A
0005433397866	13563	29	11C
0005435732204	13563	30	11D
0005433397832	13563	31	11F
0005435732129	13563	32	12A
0005433397847	13563	33	12C
0005433397843	13563	34	12E
0005433397861	13563	35	12F
0005435732255	13563	36	13C
0005433397857	13563	37	13F
0005433397868	13563	38	14A
0005433397827	13563	39	14D
0005433397856	13563	40	14E
0005435732170	13563	41	14F
0005433397859	13563	42	15D
0005435732165	13563	43	15E
0005433397844	13563	44	15F
0005433397851	13563	45	16A
0005433397860	13563	46	16D
0005433397833	13563	47	16E
0005433397829	13563	48	16F
0005435732178	13563	49	17A
0005435732175	13563	50	17C
0005433397846	13563	51	17D
0005433397837	13563	52	17E
0005435732187	13563	53	17F
0005433397840	13563	54	18A
0005435732171	13563	55	18D
0005433397836	13563	56	18F
0005433397850	13563	57	19A
0005435732177	13563	58	19C
0005435732119	13563	59	19D
0005433397828	13563	60	19E
0005433397864	13563	61	19F
0005433397849	13563	62	20A
0005433397852	13563	63	20D
0005435732176	13563	64	20E
0005433397506	19401	1	1A
0005435732287	19401	2	1C
0005433397518	19401	3	1D
0005433397373	19401	4	2A
0005433397324	19401	5	2D
0005433397242	19401	6	3A
0005432297265	19401	7	3C
0005433397238	19401	8	3F
0005433397517	19401	9	4A
0005433397343	19401	10	4C
0005433397422	19401	11	4D
0005433397487	19401	12	4E
0005433397416	19401	13	4F
0005433397565	19401	14	5A
0005433397241	19401	15	5C
0005433397335	19401	16	6A
0005433397550	19401	17	6D
0005433397336	19401	18	6E
0005432297266	19401	19	7A
0005433397189	19401	20	8A
0005433397268	19401	21	8C
0005433397368	19401	22	8D
0005433397426	19401	23	8F
0005432297267	19401	24	9A
0005433397338	19401	25	9C
0005433397428	19401	26	9D
0005433397339	19401	27	9E
0005433397507	19401	28	9F
0005435732282	19401	29	10A
0005433397421	19401	30	10C
0005433397446	19401	31	10D
0005433397359	19401	32	11A
0005435732292	19401	33	11E
0005433397501	19401	34	12A
0005433397474	19401	35	12C
0005433397370	19401	36	12D
0005433397267	19401	37	12E
0005435732290	19401	38	12F
0005435732288	19401	39	13A
0005435732284	19401	40	13C
0005433397573	19401	41	13D
0005433397476	19401	42	13F
0005433397445	19401	43	14A
0005433397309	19401	44	14C
0005433397593	19401	45	14D
0005435732285	19401	46	14E
0005433397334	19401	47	14F
0005433397395	19401	48	15A
0005433397502	19401	49	15C
0005433397414	19401	50	15D
0005433397455	19401	51	15E
0005433397562	19401	52	15F
0005433397485	19401	53	16C
0005433397394	19401	54	16D
0005433397369	19401	55	16E
0005435732291	19401	56	18C
0005435732286	19401	57	18D
0005433397372	19401	58	18E
0005433397382	19401	59	19A
0005435732283	19401	60	19E
0005433397415	19401	61	19F
0005433397441	19401	62	20A
0005433397371	19401	63	20C
0005435732289	19401	64	20D
0005433397427	19401	65	20E
0005435068471	13183	1	1A
0005435068537	13183	2	1C
0005435068268	13183	3	1D
0005435068409	13183	4	1F
0005435925229	13183	5	2A
0005435068269	13183	6	2D
0005435068496	13183	7	2F
0005435068404	13183	8	3D
0005435925226	13183	9	3F
0005435068239	13183	10	4A
0005435068499	13183	11	4C
0005435068252	13183	12	4D
0005435925219	13183	13	4E
0005435068310	13183	14	4F
0005435068405	13183	15	5A
0005435925221	13183	16	5D
0005435068526	13183	17	5E
0005435068440	13183	18	6C
0005435925237	13183	19	6E
0005435068497	13183	20	6F
0005435925230	13183	21	7A
0005435068263	13183	22	7D
0005435068428	13183	23	7F
0005435068381	13183	24	8A
0005435068270	13183	25	8C
0005435068335	13183	26	8D
0005435068498	13183	27	8E
0005435068350	13183	28	8F
0005435925239	13183	29	9C
0005435925242	13183	30	9D
0005435068212	13183	31	9E
0005435068429	13183	32	9F
0005435068334	13183	33	10A
0005435925220	13183	34	10C
0005435068265	13183	35	10D
0005435068361	13183	36	10E
0005435068272	13183	37	10F
0005435925232	13183	38	11A
0005435925224	13183	39	11D
0005435925227	13183	40	11E
0005435925240	13183	41	11F
0005435068495	13183	42	12D
0005435925223	13183	43	12E
0005435068343	13183	44	12F
0005435068169	13183	45	13A
0005435925243	13183	46	13C
0005435068271	13183	47	13F
0005435068371	13183	48	14A
0005435925225	13183	49	14C
0005435068446	13183	50	14D
0005435925241	13183	51	14E
0005435925234	13183	52	14F
0005435068448	13183	53	15A
0005435068362	13183	54	15C
0005435068581	13183	55	15D
0005435068447	13183	56	15E
0005435925236	13183	57	15F
0005435925228	13183	58	16C
0005435068221	13183	59	16D
0005435068438	13183	60	16F
0005435925235	13183	61	17A
0005435068311	13183	62	17D
0005435068538	13183	63	17E
0005435925222	13183	64	17F
0005435068251	13183	65	18A
0005435925233	13183	66	18C
0005435925238	13183	67	18D
0005435068536	13183	68	18E
0005435925231	13183	69	18F
0005435068488	13183	70	19F
0005435068406	13183	71	20A
0005435068435	13183	72	20C
0005435068489	13183	73	20F
0005435068825	15482	1	1A
0005435068822	15482	2	1C
0005435068834	15482	3	1D
0005435068830	15482	4	1F
0005435925058	15482	5	2A
0005435068823	15482	6	2D
0005435068843	15482	7	3A
0005435068798	15482	8	3C
0005435068829	15482	9	3F
0005435068819	15482	10	3D
0005435068814	15482	11	4A
0005435068836	15482	12	4D
0005435068804	15482	13	4E
0005435068821	15482	14	5A
0005435925122	15482	15	5C
0005435925084	15482	16	5E
0005435068815	15482	17	5F
0005435068832	15482	18	6A
0005435068794	15482	19	6F
0005435068845	15482	20	7A
0005435068826	15482	21	7C
0005435925057	15482	22	7D
0005435068841	15482	23	7E
0005435068803	15482	24	7F
0005435068817	15482	25	8A
0005435068807	15482	26	8F
0005435925112	15482	27	9C
0005435068837	15482	28	9F
0005435925087	15482	29	10A
0005435068842	15482	30	10C
0005435068808	15482	31	10D
0005435068844	15482	32	10E
0005435068846	15482	33	11A
0005435068799	15482	34	11C
0005435068806	15482	35	11D
0005435068838	15482	36	11E
0005435925116	15482	37	11F
0005435068805	15482	38	12A
0005435068796	15482	39	12D
0005435068818	15482	40	13A
0005435925117	15482	41	13D
0005435068828	15482	42	13F
0005435068827	15482	43	14C
0005435068795	15482	44	14D
0005435068824	15482	45	14E
0005435925079	15482	46	15A
0005435068810	15482	47	15C
0005435068816	15482	48	15E
0005435068802	15482	49	16A
0005435925083	15482	50	16C
0005435068831	15482	51	16E
0005435068833	15482	52	16F
0005435068809	15482	53	17A
0005435925078	15482	54	17D
0005435925113	15482	55	17E
0005435068811	15482	56	17F
0005435068800	15482	57	18A
0005435068812	15482	58	18C
0005435068820	15482	59	18D
0005435068801	15482	60	19C
0005435068797	15482	61	19D
0005435068840	15482	62	19E
0005435068839	15482	63	20C
0005435068813	15482	64	20E
0005435068835	15482	65	20F
0005435808181	23174	1	1A
0005435808182	23174	2	1B
0005435808160	23174	3	1D
0005435808186	23174	4	2A
0005433407487	23174	5	2B
0005433407479	23174	6	2C
0005435808178	23174	7	2D
0005435808173	23174	8	3A
0005435808171	23174	9	3B
0005435808156	23174	10	3C
0005435808167	23174	11	3D
0005433407490	23174	12	4A
0005435808165	23174	13	4B
0005435808163	23174	14	4D
0005435808170	23174	15	5A
0005435808164	23174	16	5B
0005433407481	23174	17	5D
0005435808175	23174	18	6A
0005435808185	23174	19	6B
0005435808176	23174	20	6C
0005435808184	23174	21	7A
0005435808183	23174	22	7B
0005435808174	23174	23	7C
0005435808179	23174	24	7D
0005435808169	23174	25	18A
0005435808177	23174	26	18B
0005433407478	23174	27	18C
0005435808187	23174	28	18D
0005435808157	23174	29	19A
0005433407488	23174	30	19B
0005433407494	23174	31	20A
0005435808166	23174	32	20B
0005433407489	23174	33	20D
0005433407502	23174	34	21A
0005435808168	23174	35	21B
0005435808159	23174	36	21D
0005435808180	23174	37	22A
0005435808161	23174	38	22B
0005435808162	23174	39	22C
0005433407486	23174	40	22D
0005435808158	23174	41	23A
0005435808172	23174	42	23B
0005434214329	10728	1	1A
0005434755918	10728	2	1C
0005434214333	10728	3	1D
0005434755867	10728	4	1F
0005434755851	10728	5	2A
0005434214352	10728	6	2C
0005434755935	10728	7	2D
0005434755847	10728	8	2F
0005434755936	10728	9	3A
0005434214346	10728	10	3C
0005434755789	10728	11	3D
0005434755901	10728	12	3F
0005434214354	10728	13	4A
0005434214327	10728	14	4C
0005434755841	10728	15	4D
0005434214319	10728	16	4E
0005434755716	10728	17	4F
0005434214317	10728	18	5A
0005434214351	10728	19	5C
0005434755775	10728	20	5D
0005434756018	10728	21	5E
0005434214348	10728	22	5F
0005434755784	10728	23	6A
0005434214343	10728	24	6C
0005434214335	10728	25	6D
0005434755917	10728	26	6E
0005434755774	10728	27	6F
0005434214340	10728	28	7A
0005434214336	10728	29	7C
0005434755911	10728	30	7D
0005434214337	10728	31	7E
0005434755827	10728	32	7F
0005434214339	10728	33	8A
0005434214357	10728	34	8E
0005434214362	10728	35	8F
0005434755848	10728	36	9A
0005434756028	10728	37	9C
0005434755715	10728	38	9D
0005434214326	10728	39	9E
0005434214325	10728	40	9F
0005434214338	10728	41	10A
0005434755965	10728	42	10C
0005434214324	10728	43	10E
0005434214359	10728	44	10F
0005434214347	10728	45	11A
0005434214345	10728	46	11C
0005434214320	10728	47	11D
0005434214332	10728	48	11E
0005434214322	10728	49	11F
0005434755751	10728	50	12A
0005434755877	10728	51	12C
0005434214349	10728	52	12D
0005434214330	10728	53	12E
0005434214334	10728	54	12F
0005434755788	10728	55	13C
0005434214361	10728	56	13D
0005434755986	10728	57	13E
0005434214341	10728	58	13F
0005434755714	10728	59	14A
0005434755957	10728	60	14C
0005434755999	10728	61	14D
0005434755828	10728	62	14E
0005434755842	10728	63	14F
0005434214318	10728	64	15A
0005434214321	10728	65	15C
0005434755713	10728	66	15D
0005434755886	10728	67	15E
0005434755826	10728	68	15F
0005434214342	10728	69	16A
0005434214350	10728	70	16C
0005434214360	10728	71	16D
0005434214331	10728	72	16E
0005434755805	10728	73	16F
0005434214323	10728	74	17A
0005434755744	10728	75	17C
0005434214344	10728	76	17D
0005434756019	10728	77	17E
0005434755745	10728	78	17F
0005434755785	10728	79	18A
0005434755821	10728	80	18C
0005434756015	10728	81	18D
0005434214363	10728	82	18E
0005434755885	10728	83	18F
0005434755804	10728	84	19A
0005434214355	10728	85	19D
0005434214328	10728	86	19E
0005434755832	10728	87	19F
0005434755998	10728	88	20A
0005434214353	10728	89	20C
0005434755995	10728	90	20D
0005434214358	10728	91	20E
0005434214356	10728	92	20F
0005434213948	28682	1	1A
0005434214014	28682	2	1C
0005434213910	28682	3	1D
0005434213867	28682	4	1F
0005434213760	28682	5	2A
0005434756217	28682	6	2C
0005434756202	28682	7	2D
0005434756203	28682	8	2F
0005434214084	28682	9	3A
0005434213999	28682	10	3C
0005434756230	28682	11	3D
0005434213761	28682	12	3F
0005434756226	28682	13	4A
0005434756221	28682	14	4C
0005434214015	28682	15	4D
0005434213859	28682	16	4E
0005434213895	28682	17	4F
0005434213904	28682	18	5C
0005434213804	28682	19	5D
0005434213839	28682	20	5E
0005434213719	28682	21	6A
0005434213720	28682	22	6D
0005434213812	28682	23	6E
0005434214003	28682	24	6F
0005434213837	28682	25	7A
0005434214106	28682	26	7C
0005434213963	28682	27	7D
0005434213858	28682	28	7E
0005434213997	28682	29	7F
0005434213821	28682	30	8A
0005434756227	28682	31	8C
0005434756231	28682	32	8D
0005434213802	28682	33	8F
0005434213896	28682	34	9A
0005434756211	28682	35	9C
0005434756210	28682	36	9E
0005434213779	28682	37	9D
0005434213762	28682	38	9F
0005434213795	28682	39	10A
0005434213877	28682	40	10C
0005434213893	28682	41	10D
0005434756223	28682	42	10F
0005434213790	28682	43	11A
0005434213905	28682	44	11C
0005434756209	28682	45	11D
0005434213842	28682	46	11E
0005434756204	28682	47	11F
0005434756205	28682	48	12A
0005434756224	28682	49	12C
0005434213909	28682	50	12D
0005434213818	28682	51	12E
0005434756220	28682	52	12F
0005434756206	28682	53	13A
0005434756212	28682	54	13C
0005434756218	28682	55	13D
0005434756216	28682	56	13E
0005434756228	28682	57	13F
0005434756213	28682	58	14C
0005434756232	28682	59	14D
0005434756214	28682	60	15A
0005434213759	28682	61	15D
0005434756222	28682	62	15E
0005434213964	28682	63	16A
0005434213861	28682	64	16C
0005434756207	28682	65	16D
0005434756233	28682	66	16E
0005434756225	28682	67	16F
0005434213820	28682	68	17A
0005434213966	28682	69	17C
0005434213894	28682	70	17D
0005434213838	28682	71	17E
0005434214048	28682	72	17F
0005434214016	28682	73	18C
0005434756208	28682	74	18D
0005434213773	28682	75	18E
0005434213965	28682	76	19A
0005434213868	28682	77	19C
0005434756215	28682	78	19D
0005434213918	28682	79	19E
0005434756219	28682	80	19F
0005434756229	28682	81	20A
0005434213996	28682	82	20C
0005434213803	28682	83	20D
0005434213919	28682	84	20F
0005435039482	5452	1	1A
0005435006926	5452	2	1C
0005435039529	5452	3	1D
0005435039495	5452	4	2A
0005432125421	5452	5	1F
0005434228974	5452	6	2C
0005435039526	5452	7	2D
0005435039505	5452	8	2F
0005435039525	5452	9	3C
0005435006931	5452	10	3A
0005435006941	5452	11	3D
0005435039473	5452	12	3F
0005435039494	5452	13	4A
0005435039511	5452	14	4C
0005435039527	5452	15	4B
0005435006920	5452	16	4D
0005435039470	5452	17	4E
0005435039514	5452	18	5A
0005435006936	5452	19	4F
0005435006929	5452	20	5B
0005435006922	5452	21	5C
0005435039528	5452	22	5D
0005435039503	5452	23	5E
0005435039472	5452	24	6A
0005435039512	5452	25	5F
0005435039471	5452	26	6C
0005435006921	5452	27	6B
0005435006934	5452	28	6D
0005435039499	5452	29	6E
0005435039464	5452	30	6F
0005435039491	5452	31	7A
0005435039485	5452	32	7C
0005434229077	5452	33	7B
0005435043282	5452	34	7F
0005435039519	5452	35	7E
0005434229046	5452	36	8A
0005434229067	5452	37	8B
0005435039517	5452	38	8C
0005435039524	5452	39	8E
0005434229069	5452	40	8D
0005432125423	5452	41	8F
0005434229057	5452	42	9A
0005435039502	5452	43	9C
0005432125420	5452	44	9B
0005435039487	5452	45	9D
0005434229087	5452	46	9F
0005435039474	5452	47	9E
0005435039507	5452	48	10B
0005435043283	5452	49	10D
0005435039484	5452	50	10C
0005432125418	5452	51	10E
0005434229097	5452	52	11A
0005435006937	5452	53	11B
0005434229012	5452	54	11C
0005435006919	5452	55	11E
0005434229058	5452	56	11D
0005435039516	5452	57	11F
0005435039498	5452	58	12A
0005435039510	5452	59	12C
0005435006930	5452	60	12B
0005435039478	5452	61	12E
0005435039469	5452	62	12D
0005435039496	5452	63	12F
0005434229070	5452	64	13A
0005435039490	5452	65	13C
0005435006943	5452	66	13B
0005435039489	5452	67	13D
0005435039497	5452	68	13E
0005432125422	5452	69	14C
0005435039509	5452	70	14B
0005435006939	5452	71	14F
0005435039515	5452	72	14E
0005435006938	5452	73	15A
0005435039477	5452	74	15B
0005435006935	5452	75	15D
0005434229143	5452	76	15E
0005432125419	5452	77	16A
0005435039513	5452	78	15F
0005435006940	5452	79	16B
0005435039522	5452	80	16C
0005435039479	5452	81	16E
0005435039521	5452	82	16D
0005435039530	5452	83	16F
0005434229147	5452	84	17B
0005435006925	5452	85	17A
0005435039493	5452	86	17C
0005434229078	5452	87	17E
0005435039506	5452	88	17D
0005435039480	5452	89	17F
0005435039467	5452	90	18B
0005435039481	5452	91	18A
0005435006923	5452	92	18C
0005435039520	5452	93	18D
0005435006932	5452	94	18F
0005435039508	5452	95	18E
0005434229076	5452	96	19A
0005434229114	5452	97	19B
0005435039468	5452	98	19D
0005435039488	5452	99	19C
0005435039518	5452	100	19F
0005435006942	5452	101	19E
0005435039465	5452	102	20A
0005435039483	5452	103	20B
0005435006924	5452	104	20D
0005435006927	5452	105	20C
0005435039466	5452	106	20E
0005432125417	5452	107	20F
0005434229113	5452	108	21B
0005435039476	5452	109	21A
0005435039475	5452	110	21C
0005434229023	5452	111	21D
0005435039523	5452	112	21E
0005434229123	5452	113	21F
0005435039501	5452	114	22B
0005434229161	5452	115	22A
0005435039500	5452	116	22C
0005435377900	5452	117	22D
0005435039504	5452	118	22E
0005435039492	5452	119	23A
0005435039531	5452	120	22F
0005435006928	5452	121	23C
0005435039486	5452	122	23B
0005435006933	5452	123	23D
0005434228990	5452	124	23F
0005435006624	12968	1	1C
0005435039161	12968	2	1D
0005435039170	12968	3	1F
0005434229266	12968	4	2C
0005432304381	12968	5	2F
0005435038777	12968	6	3A
0005435038893	12968	7	3D
0005435006757	12968	8	3F
0005435039045	12968	9	4A
0005435006703	12968	10	4B
0005434229284	12968	11	4D
0005435039194	12968	12	4F
0005435038978	12968	13	5B
0005434229273	12968	14	5D
0005434229277	12968	15	5E
0005432304382	12968	16	5F
0005435039173	12968	17	6C
0005435006756	12968	18	6B
0005435038781	12968	19	6D
0005435038917	12968	20	6F
0005434229280	12968	21	6E
0005435039057	12968	22	7A
0005435038876	12968	23	7B
0005435038974	12968	24	7F
0005435038869	12968	25	7E
0005435038904	12968	26	8A
0005434229267	12968	27	8B
0005435039146	12968	28	8C
0005435006704	12968	29	8D
0005435038913	12968	30	8F
0005435038889	12968	31	9A
0005435038932	12968	32	9C
0005435038963	12968	33	9E
0005434229287	12968	34	9D
0005435038848	12968	35	10B
0005435006784	12968	36	10D
0005435038971	12968	37	10E
0005435038958	12968	38	11B
0005435006817	12968	39	11D
0005434229269	12968	40	11C
0005435038849	12968	41	11F
0005435039007	12968	42	12A
0005435038879	12968	43	12B
0005435039044	12968	44	12D
0005435039120	12968	45	12E
0005435006729	12968	46	13B
0005435006793	12968	47	13A
0005435038896	12968	48	13C
0005434229279	12968	49	13D
0005435038929	12968	50	13E
0005435039006	12968	51	14A
0005435039064	12968	52	13F
0005435039040	12968	53	14B
0005435039048	12968	54	14F
0005434229271	12968	55	14E
0005434229286	12968	56	15B
0005435038840	12968	57	15C
0005434229282	12968	58	15D
0005435039105	12968	59	15F
0005435038973	12968	60	16B
0005434229283	12968	61	16A
0005434229272	12968	62	16C
0005434229288	12968	63	16D
0005435039056	12968	64	16E
0005435039193	12968	65	16F
0005434229278	12968	66	17B
0005435039155	12968	67	17C
0005434229275	12968	68	17D
0005435006656	12968	69	17F
0005435039106	12968	70	18A
0005435006623	12968	71	18B
0005434229274	12968	72	18D
0005434229281	12968	73	18C
0005435038776	12968	74	18F
0005435006655	12968	75	19A
0005435043275	12968	76	19B
0005434229276	12968	77	19C
0005435039098	12968	78	19E
0005434229270	12968	79	19D
0005435038841	12968	80	19F
0005435038912	12968	81	20B
0005435039171	12968	82	20A
0005435006683	12968	83	20D
0005435006658	12968	84	20E
0005435039160	12968	85	21A
0005435038842	12968	86	20F
0005435038806	12968	87	21C
0005434229268	12968	88	21D
0005435039217	12968	89	21E
0005435039014	12968	90	21F
0005435006714	12968	91	22C
0005435038870	12968	92	22B
0005435039182	12968	93	23A
0005435006760	12968	94	22F
0005435039039	12968	95	23B
0005434229285	12968	96	23C
0005435039108	12968	97	23D
0005432304383	12968	98	23E
0005435554114	14851	1	1C
0005435554112	14851	2	1D
0005435902456	14851	3	1F
0005434426459	14851	4	2D
0005435902480	14851	5	2F
0005435902396	14851	6	3C
0005432188593	14851	7	3D
0005434426465	14851	8	3F
0005434411758	14851	9	4A
0005435902481	14851	10	4D
0005434426454	14851	11	4E
0005434411755	14851	12	5A
0005434426456	14851	13	5C
0005435902453	14851	14	5D
0005434411754	14851	15	5F
0005435902460	14851	16	6F
0005434411757	14851	17	7A
0005434426472	14851	18	7D
0005434426468	14851	19	7F
0005435902431	14851	20	8D
0005434426462	14851	21	8F
0005434426475	14851	22	9A
0005434426469	14851	23	9D
0005435902430	14851	24	9E
0005435902515	14851	25	9F
0005435902482	14851	26	10C
0005434426466	14851	27	10D
0005435902472	14851	28	10E
0005434426458	14851	29	10F
0005434426473	14851	30	11A
0005434426453	14851	31	11C
0005434426450	14851	32	12E
0005435902408	14851	33	12F
0005434426457	14851	34	13C
0005435554122	14851	35	13E
0005434426474	14851	36	13F
0005434426455	14851	37	14A
0005434426460	14851	38	14C
0005434426463	14851	39	14E
0005435902461	14851	40	15A
0005434426452	14851	41	15D
0005434426448	14851	42	15E
0005432188592	14851	43	16A
0005435902455	14851	44	16C
0005435902425	14851	45	16D
0005435902421	14851	46	16F
0005432188591	14851	47	17A
0005434426471	14851	48	17C
0005435902454	14851	49	17E
0005434426470	14851	50	18A
0005435902424	14851	51	18C
0005434426451	14851	52	18D
0005435902506	14851	53	18E
0005432188590	14851	54	18F
0005434426467	14851	55	19A
0005434426464	14851	56	19C
0005434426449	14851	57	19E
0005434411756	14851	58	19F
0005435902407	14851	59	20A
0005434411759	14851	60	20D
0005434426461	14851	61	20E
0005435554169	20227	1	1C
0005434426303	20227	2	2C
0005435902622	20227	3	2F
0005434426180	20227	4	3C
0005434411716	20227	5	3F
0005435902630	20227	6	4C
0005435902623	20227	7	4D
0005435902621	20227	8	4E
0005435902628	20227	9	4F
0005435902626	20227	10	5D
0005435902625	20227	11	5E
0005434426245	20227	12	6A
0005434411728	20227	13	6C
0005434426312	20227	14	6E
0005435902631	20227	15	6F
0005435902632	20227	16	7C
0005435902637	20227	17	7D
0005435554168	20227	18	7F
0005434426317	20227	19	8A
0005435554167	20227	20	8C
0005434426287	20227	21	8F
0005434426324	20227	22	9C
0005434426288	20227	23	9D
0005432059495	20227	24	9E
0005435902634	20227	25	10D
0005434426159	20227	26	10E
0005435902629	20227	27	10F
0005434426260	20227	28	11E
0005434426204	20227	29	11F
0005434426304	20227	30	12C
0005435902633	20227	31	12E
0005435554171	20227	32	12F
0005435902627	20227	33	13C
0005435554170	20227	34	13D
0005432059496	20227	35	13F
0005434426292	20227	36	14D
0005434411745	20227	37	14E
0005434426275	20227	38	14F
0005434426334	20227	39	15A
0005434426274	20227	40	15C
0005434426209	20227	41	15D
0005434426232	20227	42	15E
0005434411742	20227	43	15F
0005434411717	20227	44	16A
0005434426174	20227	45	16D
0005434426210	20227	46	16E
0005434426158	20227	47	17C
0005435902636	20227	48	17E
0005434411729	20227	49	17F
0005434426325	20227	50	18D
0005434426241	20227	51	18E
0005435902624	20227	52	18F
0005434411730	20227	53	19D
0005434426276	20227	54	19E
0005435902638	20227	55	19F
0005435902635	20227	56	20C
0005435554172	20227	57	20E
0005432462505	28011	1	4A
0005434523739	28011	2	4E
0005432462501	28011	3	5A
0005434523731	28011	4	7A
0005432462500	28011	5	7E
0005432462502	28011	6	7D
0005434523740	28011	7	9B
0005432462503	28011	8	11B
0005434523743	28011	9	13D
0005432462504	28011	10	15A
0005434523744	28011	11	15F
0005434523735	28011	12	18A
0005432462506	28011	13	18E
0005434523732	28011	14	19B
0005434523742	28011	15	22C
0005434523762	30893	1	2F
0005434559089	30893	2	3F
0005434523758	30893	3	4B
0005434523764	30893	4	4D
0005432462491	30893	5	4E
0005434559091	30893	6	5B
0005434523761	30893	7	7B
0005434559090	30893	8	8B
0005432462478	30893	9	8D
0005432462479	30893	10	10B
0005434523765	30893	11	12A
0005432462481	30893	12	13A
0005434523766	30893	13	13B
0005434559088	30893	14	13D
0005434523763	30893	15	17A
0005434523760	30893	16	18B
0005434523759	30893	17	19F
0005433726082	30865	1	4E
0005433726089	30865	2	5D
0005433726076	30865	3	5F
0005433726090	30865	4	6A
0005433726087	30865	5	7E
0005433726091	30865	6	8F
0005433726085	30865	7	11B
0005433726084	30865	8	14E
0005433726079	30865	9	15A
0005433726081	30865	10	15F
0005433726083	30865	11	15E
0005433726078	30865	12	17D
0005433726080	30865	13	19F
0005433726088	30865	14	20E
0005433726086	30865	15	21B
0005433726092	30865	16	22D
0005433726077	30865	17	23A
0005433434288	26531	1	1A
0005435982077	26531	2	1C
0005433434262	26531	3	1D
0005435982066	26531	4	1F
0005435982090	26531	5	2A
0005435982071	26531	6	2C
0005434273053	26531	7	2D
0005435982072	26531	8	2F
0005435982079	26531	9	3C
0005435982064	26531	10	3D
0005435982054	26531	11	3F
0005435982081	26531	12	4A
0005433434373	26531	13	4C
0005434270184	26531	14	4D
0005433434387	26531	15	4E
0005433434233	26531	16	4F
0005435982083	26531	17	5A
0005433434322	26531	18	5C
0005435982062	26531	19	5D
0005433434277	26531	20	5E
0005432300232	26531	21	5F
0005434270186	26531	22	6A
0005435982085	26531	23	6C
0005433434341	26531	24	6D
0005435982095	26531	25	6E
0005434270182	26531	26	6F
0005433434289	26531	27	7A
0005435982073	26531	28	7C
0005433434308	26531	29	7D
0005435982063	26531	30	7E
0005433434247	26531	31	7F
0005435982068	26531	32	8A
0005435982057	26531	33	8C
0005434273047	26531	34	8D
0005434270183	26531	35	8E
0005435982086	26531	36	8F
0005433434291	26531	37	9A
0005433434300	26531	38	9C
0005433434370	26531	39	9D
0005435982091	26531	40	9E
0005434270180	26531	41	9F
0005433434372	26531	42	10A
0005433434301	26531	43	10C
0005433434310	26531	44	10D
0005433434265	26531	45	10E
0005433434231	26531	46	10F
0005434273058	26531	47	11A
0005433434311	26531	48	11C
0005435982070	26531	49	11D
0005435982055	26531	50	11E
0005433434230	26531	51	11F
0005435982088	26531	52	12A
0005433434281	26531	53	12C
0005432300233	26531	54	12D
0005432300236	26531	55	12E
0005433434263	26531	56	12F
0005432300237	26531	57	13A
0005435982061	26531	58	13C
0005435982069	26531	59	13D
0005434273050	26531	60	13E
0005433434211	26531	61	14A
0005433434386	26531	62	14C
0005433434339	26531	63	14D
0005435982059	26531	64	14E
0005435982076	26531	65	14F
0005435982056	26531	66	15A
0005435982067	26531	67	15C
0005433434309	26531	68	15D
0005432300234	26531	69	15E
0005435982065	26531	70	16A
0005433434338	26531	71	15F
0005435982060	26531	72	16C
0005435982078	26531	73	16D
0005433434215	26531	74	16E
0005435982075	26531	75	16F
0005435982058	26531	76	17A
0005433434292	26531	77	17C
0005435982087	26531	78	17D
0005435982092	26531	79	17F
0005433434246	26531	80	18A
0005435982094	26531	81	18C
0005435982082	26531	82	18D
0005435982074	26531	83	18E
0005434273054	26531	84	18F
0005435982093	26531	85	19A
0005435982084	26531	86	19C
0005433434371	26531	87	19D
0005432300235	26531	88	19E
0005435982089	26531	89	19F
0005434270185	26531	90	20A
0005435982080	26531	91	20C
0005434273051	26531	92	20D
0005433434264	26531	93	20E
0005434273057	26531	94	20F
0005435981588	26729	1	1A
0005435981813	26729	2	1D
0005435981757	26729	3	1F
0005435981562	26729	4	2A
0005435981734	26729	5	2C
0005435981724	26729	6	2D
0005435981680	26729	7	2F
0005435981535	26729	8	3A
0005432051117	26729	9	3C
0005435981728	26729	10	3D
0005435981589	26729	11	3F
0005433434566	26729	12	4A
0005433434568	26729	13	4C
0005433434554	26729	14	4E
0005435981817	26729	15	5C
0005435981725	26729	16	5E
0005433434573	26729	17	5F
0005433434557	26729	18	6A
0005435981719	26729	19	6C
0005435981829	26729	20	6D
0005435981857	26729	21	6F
0005435981841	26729	22	7C
0005433434563	26729	23	7D
0005435981705	26729	24	7E
0005433434562	26729	25	7F
0005435981756	26729	26	8C
0005433434581	26729	27	8D
0005435981576	26729	28	8E
0005433434559	26729	29	8F
0005433434575	26729	30	9A
0005433434564	26729	31	9C
0005432051116	26729	32	9E
0005435981557	26729	33	9F
0005433434567	26729	34	10A
0005433434580	26729	35	10C
0005433434555	26729	36	10D
0005434271304	26729	37	10E
0005435981608	26729	38	10F
0005433434569	26729	39	11A
0005435981556	26729	40	11C
0005435981788	26729	41	11D
0005435981811	26729	42	11E
0005433434579	26729	43	11F
0005433434561	26729	44	12A
0005435981654	26729	45	12D
0005433434582	26729	46	12E
0005433434556	26729	47	12F
0005433434558	26729	48	13A
0005435981727	26729	49	13E
0005433434560	26729	50	13F
0005435981630	26729	51	14A
0005434269094	26729	52	14C
0005435981673	26729	53	14E
0005435981697	26729	54	14F
0005433434574	26729	55	15A
0005435981631	26729	56	15C
0005433434577	26729	57	15D
0005435981787	26729	58	15E
0005435981560	26729	59	15F
0005435981575	26729	60	16A
0005435981651	26729	61	16C
0005433434570	26729	62	16D
0005435981753	26729	63	16E
0005432051115	26729	64	16F
0005433434572	26729	65	17A
0005435981577	26729	66	17C
0005433434571	26729	67	17D
0005435981814	26729	68	18A
0005435981784	26729	69	18C
0005435981718	26729	70	18D
0005433434565	26729	71	18E
0005435981558	26729	72	18F
0005435981696	26729	73	19A
0005433434578	26729	74	19C
0005435981752	26729	75	19D
0005434269095	26729	76	19E
0005433434576	26729	77	19F
0005435981561	26729	78	20A
0005435981607	26729	79	20C
0005435981720	26729	80	20D
0005435981818	26729	81	20E
0005435981721	26729	82	20F
0005433689887	29271	1	3C
0005433686609	29271	2	4A
0005433689876	29271	3	19C
0005433689888	29271	4	22C
0005433686614	29271	5	22D
0005432583931	3133	1	1A
0005432583936	3133	2	1B
0005432857928	3133	3	1C
0005432216260	3133	4	1D
0005432583929	3133	5	2A
0005432857982	3133	6	2D
0005432583937	3133	7	3A
0005432583919	3133	8	3B
0005432857954	3133	9	3C
0005432583927	3133	10	4B
0005432857941	3133	11	4C
0005432583920	3133	12	4D
0005432583942	3133	13	5A
0005432583939	3133	14	5D
0005432583932	3133	15	6A
0005432583930	3133	16	6B
0005432583925	3133	17	6C
0005432583928	3133	18	7A
0005432583918	3133	19	7B
0005432857940	3133	20	7C
0005432857948	3133	21	7D
0005432583922	3133	22	18A
0005432583933	3133	23	18D
0005432583935	3133	24	19A
0005432857958	3133	25	19C
0005432583934	3133	26	20A
0005432583938	3133	27	20B
0005432216261	3133	28	20C
0005432583926	3133	29	21A
0005432583940	3133	30	21B
0005432583924	3133	31	21C
0005432583921	3133	32	21D
0005432216259	3133	33	22A
0005432583923	3133	34	22B
0005432583941	3133	35	22C
0005432857930	3133	36	22D
0005432857908	3133	37	23A
0005432857890	3133	38	23B
0005432858019	31506	1	1A
0005432583860	31506	2	1B
0005432583726	31506	3	1C
0005432858022	31506	4	1D
0005432858020	31506	5	2B
0005432583758	31506	6	2D
0005432583793	31506	7	3A
0005432583706	31506	8	3B
0005432858018	31506	9	3C
0005432858011	31506	10	3D
0005432583794	31506	11	4A
0005432858017	31506	12	4C
0005432858016	31506	13	4D
0005432583825	31506	14	5A
0005432583762	31506	15	6A
0005432858021	31506	16	6B
0005432583649	31506	17	7A
0005432583808	31506	18	7B
0005432858012	31506	19	7D
0005432583727	31506	20	18A
0005432583826	31506	21	18C
0005432583732	31506	22	19A
0005432583770	31506	23	19B
0005432858013	31506	24	19D
0005432583614	31506	25	20B
0005432583728	31506	26	20C
0005432583725	31506	27	20D
0005432583613	31506	28	21D
0005432858014	31506	29	22A
0005432858015	31506	30	22B
0005432583765	31506	31	22D
0005433255060	863	1	1B
0005433255044	863	2	1C
0005433255022	863	3	2D
0005434943310	863	4	3D
0005434943314	863	5	4D
0005433255049	863	6	5D
0005434943311	863	7	6A
0005433255050	863	8	6B
0005434943312	863	9	7A
0005434943309	863	10	7B
0005434943315	863	11	7C
0005434943308	863	12	18B
0005434943316	863	13	18D
0005434943313	863	14	19B
0005433255023	863	15	20C
0005433255059	863	16	22A
0005434943201	16217	1	1A
0005434943253	16217	2	1B
0005434943200	16217	3	2B
0005434943256	16217	4	3A
0005434943240	16217	5	3B
0005433255095	16217	6	4B
0005434943241	16217	7	6A
0005433255098	16217	8	19D
0005433255096	16217	9	20D
0005433255093	16217	10	21A
0005433255097	16217	11	21B
0005434943221	16217	12	21D
0005433255094	16217	13	23B
0005435858532	27605	1	1D
0005433654659	27605	2	3A
0005433654676	27605	3	3C
0005433654695	27605	4	4C
0005433654673	27605	5	6A
0005433654696	27605	6	6E
0005433654664	27605	7	7A
0005435858544	27605	8	7F
0005435858534	27605	9	8C
0005435858536	27605	10	8B
0005433654660	27605	11	8E
0005433654651	27605	12	9F
0005433654661	27605	13	10C
0005433654669	27605	14	11B
0005435858540	27605	15	11A
0005435858537	27605	16	11D
0005435858543	27605	17	11C
0005433654654	27605	18	14B
0005435858542	27605	19	15B
0005433654683	27605	20	15A
0005435858539	27605	21	16B
0005433654665	27605	22	16D
0005433654670	27605	23	17D
0005433654666	27605	24	17C
0005435858541	27605	25	18B
0005435858535	27605	26	20B
0005433654675	27605	27	20D
0005435858533	27605	28	20F
0005433654674	27605	29	21A
0005435858538	27605	30	21C
0005433654650	27605	31	21E
0005433811611	14334	1	2B
0005433811610	14334	2	6B
0005435652853	21741	1	1A
0005435652858	21741	2	1C
0005433367400	21741	3	1D
0005433367263	21741	4	1F
0005433367328	21741	5	2A
0005435652874	21741	6	2C
0005435652856	21741	7	2D
0005433367219	21741	8	2F
0005433367396	21741	9	3A
0005433367359	21741	10	3C
0005433367358	21741	11	3D
0005435652863	21741	12	3F
0005435652851	21741	13	4C
0005435652862	21741	14	4D
0005433367351	21741	15	4F
0005435652860	21741	16	4E
0005433367403	21741	17	5C
0005433367347	21741	18	5E
0005433367428	21741	19	5F
0005435652848	21741	20	6C
0005433367468	21741	21	6D
0005433367339	21741	22	6E
0005435652843	21741	23	6F
0005435652855	21741	24	7A
0005435652846	21741	25	7C
0005433367348	21741	26	7E
0005435652839	21741	27	7F
0005433367290	21741	28	8A
0005433367270	21741	29	8C
0005435652857	21741	30	8D
0005435652869	21741	31	8E
0005433367398	21741	32	9A
0005435652852	21741	33	9D
0005435652868	21741	34	9E
0005435652840	21741	35	9F
0005435652867	21741	36	10C
0005433367228	21741	37	10E
0005435652865	21741	38	10F
0005435652842	21741	39	11A
0005435652850	21741	40	11C
0005435652870	21741	41	11D
0005435652845	21741	42	11E
0005435652871	21741	43	11F
0005435652841	21741	44	12A
0005435652859	21741	45	12E
0005435652877	21741	46	13A
0005433367543	21741	47	13D
0005433367338	21741	48	13E
0005433367222	21741	49	13F
0005433367345	21741	50	14C
0005433367327	21741	51	14D
0005433367279	21741	52	14F
0005433367349	21741	53	15A
0005435652875	21741	54	15C
0005433367346	21741	55	15E
0005433367483	21741	56	16A
0005433367405	21741	57	16D
0005435652847	21741	58	16E
0005435652849	21741	59	16F
0005433367329	21741	60	17A
0005435652876	21741	61	17D
0005435652838	21741	62	17E
0005433367237	21741	63	17F
0005433367278	21741	64	18A
0005433367516	21741	65	18C
0005435652854	21741	66	18D
0005433367289	21741	67	18E
0005433367309	21741	68	18F
0005435652872	21741	69	19C
0005435652861	21741	70	19D
0005433367446	21741	71	19E
0005435652844	21741	72	19F
0005433367340	21741	73	20A
0005435652866	21741	74	20D
0005435652864	21741	75	20E
0005435652873	21741	76	20F
0005433784774	9386	1	1F
0005434170851	9386	2	2A
0005433763149	9386	3	2G
0005432665265	9386	4	2H
0005433784813	9386	5	3F
0005433805232	9386	6	3C
0005434273060	9386	7	3G
0005434170916	9386	8	4F
0005433805244	9386	9	4G
0005433784805	9386	10	5A
0005433805240	9386	11	4H
0005433805211	9386	12	5F
0005434170889	9386	13	5C
0005433763146	9386	14	9A
0005433784782	9386	15	9B
0005434170872	9386	16	9H
0005433805238	9386	17	9G
0005433763147	9386	18	11A
0005433805231	9386	19	11B
0005433784779	9386	20	11E
0005433784795	9386	21	11G
0005434151674	9386	22	12D
0005433784792	9386	23	12B
0005433805237	9386	24	12E
0005433805224	9386	25	12G
0005433784809	9386	26	12F
0005433805225	9386	27	13A
0005433784798	9386	28	13D
0005435269644	9386	29	13B
0005433763150	9386	30	13E
0005433784797	9386	31	13G
0005433784788	9386	32	13F
0005433805213	9386	33	13H
0005433805226	9386	34	14D
0005433805243	9386	35	14B
0005433805223	9386	36	14H
0005433784786	9386	37	14G
0005433805230	9386	38	15E
0005433763144	9386	39	15F
0005434170953	9386	40	15H
0005433805239	9386	41	15G
0005434270181	9386	42	16B
0005433784793	9386	43	16D
0005432657437	9386	44	16G
0005433784803	9386	45	16H
0005434273061	9386	46	17B
0005433805218	9386	47	17A
0005433805212	9386	48	17F
0005433805216	9386	49	17E
0005434170909	9386	50	18D
0005433805229	9386	51	18F
0005434170867	9386	52	18E
0005433763145	9386	53	18H
0005433763142	9386	54	18G
0005432657436	9386	55	19B
0005432665266	9386	56	19D
0005434273048	9386	57	19F
0005434170856	9386	58	19E
0005433784775	9386	59	20A
0005434151675	9386	60	20D
0005433805236	9386	61	20B
0005433784812	9386	62	21B
0005433805233	9386	63	21E
0005433784800	9386	64	21G
0005433805215	9386	65	22A
0005433784810	9386	66	22D
0005433784801	9386	67	22E
0005433784773	9386	68	22H
0005433784808	9386	69	23B
0005433805217	9386	70	23A
0005433763141	9386	71	23D
0005434151670	9386	72	23F
0005433763137	9386	73	23E
0005432666380	9386	74	23G
0005432667445	9386	75	24D
0005432666379	9386	76	24G
0005433805245	9386	77	24H
0005433784780	9386	78	27A
0005434151671	9386	79	27B
0005433805221	9386	80	27D
0005433805242	9386	81	27G
0005433784777	9386	82	28A
0005433784784	9386	83	27H
0005433784811	9386	84	28E
0005433784807	9386	85	28G
0005433784790	9386	86	29A
0005433763151	9386	87	29B
0005433784794	9386	88	29E
0005433784781	9386	89	29F
0005433805241	9386	90	29G
0005433763140	9386	91	30D
0005433784776	9386	92	30B
0005433805227	9386	93	30F
0005433784785	9386	94	31A
0005433763148	9386	95	31B
0005433805219	9386	96	31F
0005433805214	9386	97	31G
0005433805222	9386	98	32D
0005434170906	9386	99	32B
0005433784804	9386	100	33E
0005433763138	9386	101	33G
0005433805234	9386	102	33F
0005433805220	9386	103	34A
0005433784787	9386	104	34D
0005433784791	9386	105	34F
0005433763139	9386	106	34E
0005433763143	9386	107	35A
0005433784778	9386	108	34H
0005434170905	9386	109	35B
0005433784783	9386	110	35E
0005433784789	9386	111	36A
0005432667444	9386	112	36G
0005433784799	9386	113	37D
0005434273049	9386	114	37B
0005432667446	9386	115	37E
0005433784806	9386	116	37H
0005432657435	9386	117	38A
0005433805235	9386	118	38B
0005433784802	9386	119	38E
0005434170910	9386	120	39D
0005433784796	9386	121	38H
0005433805228	9386	122	39E
0005433804897	26274	1	1A
0005433784426	26274	2	1B
0005433784549	26274	3	1G
0005434170990	26274	4	2A
0005432657404	26274	5	1H
0005434170997	26274	6	2B
0005433804988	26274	7	2F
0005433804923	26274	8	2C
0005434171000	26274	9	2H
0005434151692	26274	10	2G
0005434170996	26274	11	3A
0005434269092	26274	12	3F
0005434269093	26274	13	3H
0005433762988	26274	14	4C
0005435269726	26274	15	4F
0005433784335	26274	16	4H
0005435269728	26274	17	5C
0005433804863	26274	18	5G
0005433804861	26274	19	5F
0005433784391	26274	20	9A
0005433805033	26274	21	5H
0005433784501	26274	22	9B
0005433804886	26274	23	9H
0005434270195	26274	24	11B
0005433784496	26274	25	11G
0005435269735	26274	26	12A
0005433804832	26274	27	12B
0005433784550	26274	28	12D
0005433804808	26274	29	12H
0005433804949	26274	30	13D
0005432659683	26274	31	13G
0005433784565	26274	32	14E
0005433804918	26274	33	14G
0005432659677	26274	34	14H
0005433804917	26274	35	15D
0005433805003	26274	36	15B
0005432659678	26274	37	15A
0005434170998	26274	38	15E
0005434170993	26274	39	15F
0005434170999	26274	40	15H
0005434151691	26274	41	16B
0005433805075	26274	42	16D
0005433805002	26274	43	16H
0005434270196	26274	44	16G
0005433784445	26274	45	17A
0005433805109	26274	46	17E
0005434170989	26274	47	18B
0005433763013	26274	48	18F
0005434151690	26274	49	19A
0005433762999	26274	50	19B
0005433805064	26274	51	19G
0005435269725	26274	52	20A
0005435269732	26274	53	19H
0005433784373	26274	54	20B
0005433805057	26274	55	20E
0005433804859	26274	56	20D
0005434270198	26274	57	20F
0005435269733	26274	58	21A
0005433804973	26274	59	21B
0005434171001	26274	60	21F
0005433804920	26274	61	22A
0005433784636	26274	62	22D
0005435269727	26274	63	22E
0005432657417	26274	64	22G
0005433784569	26274	65	23A
0005433762943	26274	66	23B
0005433784465	26274	67	23F
0005433784447	26274	68	23G
0005433784486	26274	69	24B
0005433804895	26274	70	24E
0005433763001	26274	71	24D
0005433805090	26274	72	24G
0005433784446	26274	73	25D
0005433805111	26274	74	25F
0005433805110	26274	75	27A
0005433763012	26274	76	27B
0005434270197	26274	77	27E
0005434170995	26274	78	27F
0005433784336	26274	79	28A
0005434170994	26274	80	27H
0005433763000	26274	81	28D
0005433804993	26274	82	28F
0005433805058	26274	83	28G
0005433763055	26274	84	29A
0005434271302	26274	85	28H
0005434170991	26274	86	29E
0005434271303	26274	87	29G
0005435269731	26274	88	30E
0005433784524	26274	89	30G
0005433784564	26274	90	30F
0005432657410	26274	91	31B
0005433784448	26274	92	31A
0005433804964	26274	93	31E
0005433784490	26274	94	31G
0005433804887	26274	95	31H
0005433784635	26274	96	32A
0005433762952	26274	97	32E
0005435269730	26274	98	32F
0005433784470	26274	99	33B
0005433805091	26274	100	33E
0005433804969	26274	101	33D
0005433804972	26274	102	33G
0005433804850	26274	103	33F
0005433784449	26274	104	33H
0005432659682	26274	105	34B
0005433784392	26274	106	35A
0005434170992	26274	107	35B
0005433763054	26274	108	35D
0005433784495	26274	109	35E
0005433762944	26274	110	35H
0005433804858	26274	111	35G
0005433784452	26274	112	36A
0005433804987	26274	113	36B
0005433804941	26274	114	36F
0005434271301	26274	115	36G
0005433784500	26274	116	37A
0005435269729	26274	117	36H
0005433763002	26274	118	37B
0005433784601	26274	119	37E
0005433804936	26274	120	37H
0005433805015	26274	121	37G
0005432659679	26274	122	38B
0005435269734	26274	123	38E
0005433805034	26274	124	38H
0005433762998	26274	125	39F
0005435929613	4886	1	4B
0005435929612	4886	2	5A
0005435135647	4886	3	5C
0005435135650	4886	4	6A
0005435135651	4886	5	6B
0005435135649	4886	6	7A
0005435135648	4886	7	21B
0005435929615	4886	8	23A
0005435135611	33020	1	1A
0005435135608	33020	2	1B
0005435929631	33020	3	2A
0005435135614	33020	4	4C
0005435135610	33020	5	6B
0005435135617	33020	6	18D
0005435135605	33020	7	19C
0005435135618	33020	8	20A
0005435929632	33020	9	20B
0005435929633	33020	10	20C
0005435135604	33020	11	20D
0005435135600	33020	12	21A
0005435135624	33020	13	21B
0005435135592	33020	14	22C
0005435135609	33020	15	22D
0005435135613	33020	16	23A
0005435135601	33020	17	23B
0005434983267	9472	1	1C
0005434983265	9472	2	2A
0005434217904	9472	3	3A
0005434217917	9472	4	3B
0005434983266	9472	5	4A
0005434217918	9472	6	7B
0005434983264	9472	7	18B
0005434217919	9472	8	18C
0005434217908	9472	9	19A
0005434217903	9472	10	20B
0005434217920	9472	11	20D
0005434217916	9472	12	21B
0005434983263	9472	13	22D
0005434983245	27358	1	1A
0005434983246	27358	2	6B
0005434217951	27358	3	7B
0005434217950	27358	4	18B
0005434217952	27358	5	19A
0005433960137	24263	1	1A
0005433985245	24263	2	1G
0005433959941	24263	3	1H
0005433985497	24263	4	2C
0005433960136	24263	5	3A
0005433985365	24263	6	2H
0005433959935	24263	7	3B
0005433985514	24263	8	3G
0005433985336	24263	9	4A
0005433959928	24263	10	4B
0005433959903	24263	11	4C
0005433985317	24263	12	9G
0005433985306	24263	13	11A
0005433959936	24263	14	11D
0005433960050	24263	15	11B
0005433985505	24263	16	11E
0005433985188	24263	17	12D
0005433960023	24263	18	12E
0005433960077	24263	19	12F
0005433960016	24263	20	13E
0005433985302	24263	21	13H
0005433985236	24263	22	14D
0005433985301	24263	23	14E
0005433960105	24263	24	14G
0005433985173	24263	25	15B
0005433985343	24263	26	15G
0005433959902	24263	27	15F
0005433960024	24263	28	16D
0005433960112	24263	29	16F
0005433959859	24263	30	16H
0005433960135	24263	31	17A
0005433960119	24263	32	17D
0005433985275	24263	33	17G
0005433985280	24263	34	18E
0005433985434	24263	35	18D
0005433960087	24263	36	18F
0005433985137	24263	37	18G
0005433959860	24263	38	18H
0005433985217	24263	39	19B
0005433959985	24263	40	19A
0005433960113	24263	41	19D
0005433959888	24263	42	19H
0005433985260	24263	43	20F
0005433960010	24263	44	20H
0005433985169	24263	45	21A
0005433985286	24263	46	21B
0005433985348	24263	47	21H
0005433985172	24263	48	21G
0005433985376	24263	49	22A
0005433960026	24263	50	22D
0005433985312	24263	51	22F
0005433959901	24263	52	23F
0005433960018	24263	53	23E
0005433985329	24263	54	23G
0005433959990	24263	55	24F
0005433985449	24263	56	25E
0005433985189	24263	57	27A
0005433960017	24263	58	25F
0005433985297	24263	59	28A
0005433985300	24263	60	27H
0005433959882	24263	61	28D
0005433960044	24263	62	28B
0005433959937	24263	63	28E
0005433960057	24263	64	28F
0005433959885	24263	65	28H
0005433959883	24263	66	29D
0005433985364	24263	67	29B
0005433960108	24263	68	29E
0005433960124	24263	69	29F
0005433959958	24263	70	29G
0005433960056	24263	71	30B
0005433985259	24263	72	30A
0005433985257	24263	73	30F
0005433960107	24263	74	31A
0005433959968	24263	75	31B
0005433960060	24263	76	31E
0005433960027	24263	77	31D
0005433960083	24263	78	31F
0005433960005	24263	79	32A
0005433985316	24263	80	31H
0005433960059	24263	81	32B
0005433985296	24263	82	32D
0005433960106	24263	83	32G
0005433960131	24263	84	33A
0005433985168	24263	85	33D
0005433985337	24263	86	33G
0005433985207	24263	87	34D
0005433959992	24263	88	34B
0005433985529	24263	89	34E
0005433959896	24263	90	34F
0005433960007	24263	91	34H
0005433959980	24263	92	35A
0005433959884	24263	93	35D
0005433960025	24263	94	36B
0005433985208	24263	95	36F
0005433959911	24263	96	36E
0005433960035	24263	97	36H
0005433959929	24263	98	37D
0005433985258	24263	99	38A
0005433959984	24263	100	38F
0005433985256	24263	101	39E
0005433960605	25943	1	1C
0005433960612	25943	2	2A
0005433960603	25943	3	2G
0005433960590	25943	4	3A
0005433960578	25943	5	3B
0005433985723	25943	6	3G
0005433960614	25943	7	3F
0005433985718	25943	8	3H
0005433985708	25943	9	4B
0005433960602	25943	10	4H
0005433985730	25943	11	5F
0005433960607	25943	12	5C
0005433985733	25943	13	5G
0005433960585	25943	14	9A
0005433985706	25943	15	5H
0005433960604	25943	16	9G
0005433960583	25943	17	9H
0005433985694	25943	18	11F
0005433960584	25943	19	11H
0005433960573	25943	20	12A
0005433960580	25943	21	12B
0005433985720	25943	22	12E
0005433960589	25943	23	13B
0005433985715	25943	24	13G
0005433985729	25943	25	14A
0005433985717	25943	26	13H
0005433985713	25943	27	14B
0005433985703	25943	28	14E
0005433960574	25943	29	14D
0005433985725	25943	30	15D
0005433960577	25943	31	15B
0005433960619	25943	32	15E
0005433985732	25943	33	15F
0005433960618	25943	34	16B
0005433985697	25943	35	16A
0005433985709	25943	36	16E
0005433960579	25943	37	17B
0005433985731	25943	38	17E
0005433960595	25943	39	18B
0005433985699	25943	40	18G
0005433960608	25943	41	19B
0005433960606	25943	42	19D
0005433960613	25943	43	19F
0005433985698	25943	44	19E
0005433960627	25943	45	19G
0005433985704	25943	46	20A
0005433985712	25943	47	19H
0005433960587	25943	48	20D
0005433985719	25943	49	20F
0005433960576	25943	50	20G
0005433960620	25943	51	21B
0005433985735	25943	52	21G
0005433960598	25943	53	21F
0005433985693	25943	54	22B
0005433960591	25943	55	22A
0005433985738	25943	56	22F
0005433960575	25943	57	22G
0005433985727	25943	58	22H
0005433960601	25943	59	23A
0005433960615	25943	60	23H
0005433985728	25943	61	24B
0005433960581	25943	62	24A
0005433985726	25943	63	24E
0005433985689	25943	64	24F
0005433985737	25943	65	25D
0005433985721	25943	66	27D
0005433960628	25943	67	27B
0005433985711	25943	68	27A
0005433985695	25943	69	27G
0005433960610	25943	70	27H
0005433960623	25943	71	28D
0005433960625	25943	72	28G
0005433985724	25943	73	28H
0005433960572	25943	74	29E
0005433960588	25943	75	29D
0005433960600	25943	76	29G
0005433960597	25943	77	30A
0005433960596	25943	78	30E
0005433960617	25943	79	30D
0005433985734	25943	80	31B
0005433985690	25943	81	31E
0005433985736	25943	82	31G
0005433960594	25943	83	31H
0005433985707	25943	84	32A
0005433960593	25943	85	32D
0005433985701	25943	86	32F
0005433985705	25943	87	32H
0005433985702	25943	88	32G
0005433985722	25943	89	33B
0005433985710	25943	90	33E
0005433960616	25943	91	33G
0005433960609	25943	92	33F
0005433985700	25943	93	34A
0005433960592	25943	94	34D
0005433960622	25943	95	34B
0005433985692	25943	96	34F
0005433960621	25943	97	35A
0005433985696	25943	98	36H
0005433985716	25943	99	37A
0005433960626	25943	100	37B
0005433960624	25943	101	37D
0005433985691	25943	102	37F
0005433960611	25943	103	38D
0005433960586	25943	104	38G
0005433985714	25943	105	38F
0005433960599	25943	106	39D
0005433960582	25943	107	39F
0005434480231	925	1	1A
0005434480227	925	2	1B
0005433165716	925	3	1C
0005434480212	925	4	1D
0005433165715	925	5	2A
0005434480229	925	6	2B
0005434480217	925	7	2C
0005434480218	925	8	2D
0005434480214	925	9	3B
0005434480236	925	10	3C
0005434480230	925	11	3D
0005434480223	925	12	4A
0005434480215	925	13	4B
0005434480213	925	14	4C
0005434480226	925	15	4D
0005433165776	925	16	5A
0005432269483	925	17	5B
0005434480224	925	18	5C
0005434480235	925	19	5D
0005433165734	925	20	6A
0005434480233	925	21	6B
0005433165708	925	22	6C
0005434480228	925	23	6D
0005433165703	925	24	7A
0005434480221	925	25	7B
0005433165732	925	26	7C
0005433165673	925	27	7D
0005434480232	925	28	18A
0005433165707	925	29	18C
0005433165811	925	30	18D
0005434480219	925	31	19C
0005434480234	925	32	19D
0005432269484	925	33	20B
0005434480216	925	34	20C
0005433165727	925	35	21A
0005434480220	925	36	21C
0005434480222	925	37	21D
0005434480225	925	38	22A
0005433165754	925	39	22C
0005433165723	925	40	23A
0005434480068	16582	1	1B
0005433165847	16582	2	1C
0005434480043	16582	3	1D
0005433165850	16582	4	2A
0005434479941	16582	5	2C
0005434479973	16582	6	2D
0005434480016	16582	7	3A
0005434480023	16582	8	3B
0005434480015	16582	9	3D
0005434480017	16582	10	4C
0005433165851	16582	11	4D
0005434480005	16582	12	5A
0005433165846	16582	13	5B
0005434480004	16582	14	5C
0005434480026	16582	15	6A
0005433165855	16582	16	6B
0005434479972	16582	17	6C
0005434480127	16582	18	6D
0005434479940	16582	19	7A
0005433165854	16582	20	7B
0005434480044	16582	21	7C
0005433165853	16582	22	7D
0005434480042	16582	23	18A
0005434480045	16582	24	18C
0005433165849	16582	25	18D
0005434479976	16582	26	19A
0005434480027	16582	27	19B
0005434480063	16582	28	19C
0005434480062	16582	29	19D
0005434479943	16582	30	20A
0005434479942	16582	31	20C
0005434480070	16582	32	20D
0005433165856	16582	33	21A
0005433165852	16582	34	21B
0005434479977	16582	35	21C
0005433165848	16582	36	21D
0005434480018	16582	37	22A
0005433165844	16582	38	22B
0005433165845	16582	39	22D
0005434480069	16582	40	23A
0005434479971	16582	41	23B
0005435142504	10319	1	1A
0005433289735	10319	2	1B
0005433289766	10319	3	1C
0005435149951	10319	4	1D
0005435149960	10319	5	2A
0005433289726	10319	6	2B
0005435142511	10319	7	2C
0005435149953	10319	8	2D
0005433289754	10319	9	3A
0005435149962	10319	10	3B
0005435386471	10319	11	3C
0005435149963	10319	12	3D
0005435149950	10319	13	4A
0005435142505	10319	14	4B
0005435149957	10319	15	4C
0005433289767	10319	16	4D
0005433289768	10319	17	5A
0005435386494	10319	18	5B
0005435386489	10319	19	5C
0005435149958	10319	20	5D
0005433289755	10319	21	6A
0005435142509	10319	22	6B
0005435142507	10319	23	6C
0005435149959	10319	24	6D
0005433289742	10319	25	7A
0005435386497	10319	26	7B
0005433289748	10319	27	7C
0005435142503	10319	28	7D
0005435149955	10319	29	18A
0005433289737	10319	30	18B
0005433289725	10319	31	18C
0005435386496	10319	32	18D
0005435149961	10319	33	19A
0005435386469	10319	34	19B
0005435386488	10319	35	19C
0005435142508	10319	36	19D
0005435142513	10319	37	20A
0005433289736	10319	38	20B
0005435149952	10319	39	20C
0005435386470	10319	40	20D
0005435149954	10319	41	21A
0005435142514	10319	42	21B
0005435386495	10319	43	21C
0005433289738	10319	44	21D
0005435142512	10319	45	22A
0005435142506	10319	46	22B
0005435386457	10319	47	22C
0005435142510	10319	48	22D
0005435149956	10319	49	23A
0005435386456	10319	50	23B
0005435149816	21915	1	1A
0005433289825	21915	2	1B
0005433289822	21915	3	1D
0005435142384	21915	4	2A
0005435386552	21915	5	2B
0005435142392	21915	6	2C
0005435149833	21915	7	2D
0005435149848	21915	8	3C
0005435149887	21915	9	3D
0005435149808	21915	10	4A
0005435142432	21915	11	4B
0005435149847	21915	12	4C
0005435149876	21915	13	4D
0005435149884	21915	14	5B
0005435149817	21915	15	5C
0005435149894	21915	16	5D
0005433289823	21915	17	6A
0005433289824	21915	18	6B
0005435142369	21915	19	6C
0005433289821	21915	20	6D
0005433289827	21915	21	7A
0005435142426	21915	22	7B
0005435149866	21915	23	7D
0005435386548	21915	24	18A
0005435142364	21915	25	18B
0005435386550	21915	26	18D
0005435149865	21915	27	19A
0005435142393	21915	28	19B
0005435386553	21915	29	19C
0005433289820	21915	30	19D
0005435386546	21915	31	20A
0005435149874	21915	32	20B
0005433289826	21915	33	20D
0005435149872	21915	34	21A
0005435149875	21915	35	21C
0005435386549	21915	36	21D
0005435142427	21915	37	22A
0005435386547	21915	38	22B
0005435142402	21915	39	22C
0005435142357	21915	40	22D
0005435386551	21915	41	23A
0005435142412	21915	42	23B
0005434573282	11182	1	1A
0005435319470	11182	2	1C
0005435529015	11182	3	1D
0005435528975	11182	4	1F
0005435529043	11182	5	2A
0005435529017	11182	6	2C
0005435528890	11182	7	2D
0005435545623	11182	8	2F
0005435501999	11182	9	3A
0005435528974	11182	10	3C
0005435501988	11182	11	3D
0005434573283	11182	12	4A
0005435502140	11182	13	4C
0005435501987	11182	14	4D
0005434573280	11182	15	4E
0005435529018	11182	16	4F
0005435502133	11182	17	5C
0005435528917	11182	18	5D
0005435502010	11182	19	5E
0005435528997	11182	20	5F
0005435319460	11182	21	6A
0005435502029	11182	22	6C
0005435528910	11182	23	6D
0005434573278	11182	24	6E
0005435319464	11182	25	6F
0005435502126	11182	26	7A
0005435502007	11182	27	7C
0005435319467	11182	28	7D
0005435501983	11182	29	7F
0005435501998	11182	30	8A
0005435528926	11182	31	8F
0005435502011	11182	32	9A
0005435545617	11182	33	9E
0005434573284	11182	34	9F
0005435528953	11182	35	10D
0005435528956	11182	36	10F
0005435319430	11182	37	11A
0005435528927	11182	38	11D
0005435502023	11182	39	11E
0005435528996	11182	40	11F
0005434573285	11182	41	12A
0005435319455	11182	42	12C
0005434573287	11182	43	12D
0005435528989	11182	44	12E
0005435502141	11182	45	12F
0005435502111	11182	46	13C
0005435528993	11182	47	13D
0005435501952	11182	48	13E
0005434573286	11182	49	13F
0005435545613	11182	50	14A
0005435545620	11182	51	14D
0005435528891	11182	52	14E
0005435502099	11182	53	14F
0005434573275	11182	54	15C
0005435528971	11182	55	15E
0005434573276	11182	56	15F
0005435528925	11182	57	16A
0005435319433	11182	58	16C
0005435529044	11182	59	16D
0005435528955	11182	60	16E
0005434573281	11182	61	16F
0005435319457	11182	62	17A
0005434573277	11182	63	17C
0005435545642	11182	64	17D
0005435502008	11182	65	17E
0005435501982	11182	66	17F
0005435528968	11182	67	18A
0005435319463	11182	68	18C
0005435545622	11182	69	18D
0005434573279	11182	70	18E
0005435319434	11182	71	18F
0005435528935	11182	72	19A
0005434573274	11182	73	19C
0005435529010	11182	74	19D
0005434573288	11182	75	19E
0005435319431	11182	76	20A
0005435502084	11182	77	20C
0005435502125	11182	78	20E
0005435508299	20943	1	1A
0005434573150	20943	2	1C
0005435502197	20943	3	1D
0005432291918	20943	4	1F
0005435508306	20943	5	2A
0005435502210	20943	6	2C
0005435502204	20943	7	2D
0005435508305	20943	8	2F
0005435508303	20943	9	3C
0005434573228	20943	10	3D
0005434573152	20943	11	3F
0005435517834	20943	12	4A
0005435319543	20943	13	4C
0005435517827	20943	14	4D
0005435319546	20943	15	4E
0005435517828	20943	16	4F
0005435502215	20943	17	5C
0005435517829	20943	18	5E
0005435319541	20943	19	5F
0005435508304	20943	20	6E
0005435319547	20943	21	6F
0005434573202	20943	22	7A
0005435319549	20943	23	7C
0005434573169	20943	24	7D
0005435319548	20943	25	7E
0005434573233	20943	26	7F
0005434573181	20943	27	8A
0005435517833	20943	28	8C
0005435502203	20943	29	8D
0005435502205	20943	30	8E
0005435502201	20943	31	9A
0005435517830	20943	32	9C
0005435502206	20943	33	9D
0005435517836	20943	34	9E
0005434573143	20943	35	9F
0005435508301	20943	36	10A
0005435502212	20943	37	10C
0005435502202	20943	38	10D
0005435517832	20943	39	10E
0005434573142	20943	40	10F
0005435502218	20943	41	11A
0005434573137	20943	42	11C
0005435502217	20943	43	11D
0005435517821	20943	44	11E
0005435508302	20943	45	11F
0005434573146	20943	46	12A
0005435319545	20943	47	12D
0005435517835	20943	48	12E
0005434573227	20943	49	12F
0005435517819	20943	50	13A
0005435517823	20943	51	13C
0005434573138	20943	52	13D
0005432291917	20943	53	13E
0005435517818	20943	54	13F
0005435517822	20943	55	14A
0005435502199	20943	56	14C
0005434573201	20943	57	14D
0005435517826	20943	58	14E
0005435502214	20943	59	14F
0005435502207	20943	60	15A
0005435502198	20943	61	15D
0005435319542	20943	62	15E
0005435319544	20943	63	15F
0005435517831	20943	64	16A
0005435517825	20943	65	16C
0005434573182	20943	66	16D
0005435508300	20943	67	16F
0005435517824	20943	68	17A
0005435502211	20943	69	17C
0005435517820	20943	70	17D
0005435508297	20943	71	17E
0005435502216	20943	72	17F
0005435508307	20943	73	18C
0005434573149	20943	74	18D
0005435502200	20943	75	18E
0005432291919	20943	76	18F
0005435502213	20943	77	19A
0005435502209	20943	78	19C
0005432291920	20943	79	19D
0005435508298	20943	80	19E
0005435508308	20943	81	19F
0005435502208	20943	82	20A
0005432692610	2951	1	1C
0005432692663	2951	2	2F
0005432692616	2951	3	3A
0005432692574	2951	4	3F
0005432692764	2951	5	4A
0005432692705	2951	6	4D
0005432692624	2951	7	4E
0005432692629	2951	8	5D
0005432692623	2951	9	6A
0005432692657	2951	10	6E
0005432692636	2951	11	8A
0005432692592	2951	12	8D
0005432692630	2951	13	9C
0005432692652	2951	14	9E
0005432692643	2951	15	9F
0005432692658	2951	16	10D
0005432692527	2951	17	11E
0005432692708	2951	18	12D
0005432692707	2951	19	13A
0005432692664	2951	20	13D
0005432692589	2951	21	13E
0005432692715	2951	22	14A
0005432692611	2951	23	14C
0005432692628	2951	24	14F
0005432692709	2951	25	15D
0005432692598	2951	26	15F
0005432692575	2951	27	16E
0005432692609	2951	28	16F
0005432692625	2951	29	17A
0005432692765	2951	30	17F
0005432692641	2951	31	18A
0005432692593	2951	32	18D
0005432692632	2951	33	18E
0005432692617	2951	34	19A
0005432692745	2951	35	19E
0005432692713	2951	36	19F
0005432692543	2951	37	20A
0005432692655	2951	38	20E
0005432692654	2951	39	20F
0005432706659	2952	1	1A
0005433123628	2952	2	1C
0005433123676	2952	3	1D
0005432706664	2952	4	1F
0005433123605	2952	5	2D
0005432880643	2952	6	2F
0005432880624	2952	7	3A
0005433123680	2952	8	3C
0005432706650	2952	9	3D
0005432706655	2952	10	4A
0005432706674	2952	11	4D
0005432880609	2952	12	4E
0005433123668	2952	13	4F
0005432706667	2952	14	5C
0005432706649	2952	15	5D
0005432706651	2952	16	5E
0005432880623	2952	17	5F
0005432880625	2952	18	6A
0005433123675	2952	19	6C
0005432706662	2952	20	6D
0005432880672	2952	21	7A
0005433123625	2952	22	7F
0005432217765	2952	23	8A
0005432706666	2952	24	8C
0005433123633	2952	25	8D
0005433123669	2952	26	8E
0005432706668	2952	27	8F
0005433123687	2952	28	9C
0005432706652	2952	29	9D
0005432880596	2952	30	9E
0005432706654	2952	31	10C
0005433123674	2952	32	10E
0005432880586	2952	33	11A
0005432706663	2952	34	11C
0005433123630	2952	35	12A
0005433123629	2952	36	13A
0005432706661	2952	37	13E
0005432706653	2952	38	13F
0005433123659	2952	39	14C
0005432706656	2952	40	14E
0005432217764	2952	41	14F
0005432706672	2952	42	15A
0005432880644	2952	43	15C
0005432706670	2952	44	15D
0005432706669	2952	45	15F
0005433123688	2952	46	16A
0005432706658	2952	47	16C
0005432706648	2952	48	16E
0005432217762	2952	49	16F
0005432706673	2952	50	17D
0005432706660	2952	51	17E
0005432880610	2952	52	18A
0005432880622	2952	53	18C
0005433123655	2952	54	18D
0005432706657	2952	55	18E
0005432217763	2952	56	19A
0005432706665	2952	57	19C
0005432880637	2952	58	19E
0005432880600	2952	59	20A
0005433123646	2952	60	20D
0005432880646	2952	61	20E
0005432706671	2952	62	20F
0005432880754	30018	1	1A
0005433123838	30018	2	1C
0005432706492	30018	3	1D
0005432880748	30018	4	1F
0005432692949	30018	5	2A
0005432692966	30018	6	2C
0005433123830	30018	7	2D
0005432692937	30018	8	2F
0005432692938	30018	9	3A
0005432692941	30018	10	3C
0005432692960	30018	11	3D
0005432692944	30018	12	3F
0005432880750	30018	13	4A
0005432692945	30018	14	4C
0005432692959	30018	15	4D
0005433123841	30018	16	4E
0005432706458	30018	17	4F
0005432880746	30018	18	5A
0005433123834	30018	19	5C
0005432692939	30018	20	5D
0005433123836	30018	21	5E
0005433123833	30018	22	5F
0005432692950	30018	23	6A
0005432706449	30018	24	6C
0005432706502	30018	25	6D
0005432706500	30018	26	6E
0005432692952	30018	27	6F
0005433123843	30018	28	7A
0005432692958	30018	29	7C
0005433123842	30018	30	7D
0005433123829	30018	31	7E
0005432880749	30018	32	7F
0005432706486	30018	33	8A
0005432706531	30018	34	8C
0005432880755	30018	35	8D
0005432706557	30018	36	8E
0005432880757	30018	37	8F
0005432706478	30018	38	9A
0005432692963	30018	39	9C
0005432880751	30018	40	9D
0005432692957	30018	41	9E
0005432706537	30018	42	9F
0005432706441	30018	43	10A
0005432692954	30018	44	10C
0005432706487	30018	45	10D
0005432880759	30018	46	10E
0005432692968	30018	47	10F
0005432706450	30018	48	11A
0005432706493	30018	49	11C
0005432706536	30018	50	11D
0005433123827	30018	51	11E
0005432706389	30018	52	11F
0005432706510	30018	53	12A
0005432706444	30018	54	12C
0005432706420	30018	55	12D
0005432706496	30018	56	12E
0005433123828	30018	57	12F
0005432706425	30018	58	13A
0005432692965	30018	59	13C
0005432692967	30018	60	13D
0005432692942	30018	61	13E
0005432706491	30018	62	13F
0005432706446	30018	63	14A
0005432706419	30018	64	14C
0005432706507	30018	65	14D
0005432692940	30018	66	14E
0005432706483	30018	67	14F
0005432692956	30018	68	15A
0005432706570	30018	69	15C
0005432880756	30018	70	15D
0005432706503	30018	71	15E
0005432692946	30018	72	15F
0005432706390	30018	73	16A
0005433123831	30018	74	16C
0005432692962	30018	75	16D
0005432692948	30018	76	16E
0005432880752	30018	77	16F
0005432692961	30018	78	17A
0005432692951	30018	79	17C
0005432706501	30018	80	17D
0005432692943	30018	81	17E
0005433123839	30018	82	17F
0005433123840	30018	83	18A
0005432692964	30018	84	18C
0005432880753	30018	85	18D
0005432880747	30018	86	18E
0005432706479	30018	87	18F
0005432706494	30018	88	19A
0005433123837	30018	89	19C
0005432692955	30018	90	19D
0005432880760	30018	91	19E
0005432692947	30018	92	19F
0005432880758	30018	93	20A
0005432692953	30018	94	20C
0005432706530	30018	95	20D
0005433123832	30018	96	20E
0005433123835	30018	97	20F
0005434979627	23671	1	1A
0005434979631	23671	2	1C
0005434988682	23671	3	1D
0005434979633	23671	4	2A
0005434979646	23671	5	2B
0005434988683	23671	6	3A
0005434979636	23671	7	3C
0005434979623	23671	8	3D
0005434979637	23671	9	4A
0005434979649	23671	10	4B
0005434988687	23671	11	4C
0005434979628	23671	12	4D
0005434979644	23671	13	5A
0005434979629	23671	14	5C
0005434988678	23671	15	5D
0005434979635	23671	16	6A
0005434979634	23671	17	6B
0005434988689	23671	18	6C
0005434979641	23671	19	6D
0005434979648	23671	20	7A
0005434979651	23671	21	7B
0005434988684	23671	22	7C
0005434979643	23671	23	7D
0005434979632	23671	24	18A
0005434979645	23671	25	18C
0005434988688	23671	26	18D
0005434988685	23671	27	19A
0005434988681	23671	28	19B
0005434979625	23671	29	20A
0005434979640	23671	30	20B
0005434979647	23671	31	20C
0005434979650	23671	32	20D
0005434988680	23671	33	21A
0005434979642	23671	34	21B
0005434979626	23671	35	21C
0005434979630	23671	36	21D
0005434979639	23671	37	22A
0005434988686	23671	38	22B
0005434979638	23671	39	22C
0005434979622	23671	40	22D
0005434988679	23671	41	23A
0005434979624	23671	42	23B
0005434988578	27523	1	1A
0005434979333	27523	2	1B
0005434979405	27523	3	1C
0005434979402	27523	4	1D
0005434979401	27523	5	2A
0005434979429	27523	6	2B
0005434979340	27523	7	2C
0005434979304	27523	8	2D
0005434988567	27523	9	3A
0005434979371	27523	10	3B
0005434979408	27523	11	3C
0005434979316	27523	12	3D
0005434979364	27523	13	4A
0005434979415	27523	14	4B
0005434988581	27523	15	4C
0005434979386	27523	16	4D
0005434979453	27523	17	5A
0005434979361	27523	18	5B
0005434979461	27523	19	5C
0005434979346	27523	20	5D
0005434979332	27523	21	6A
0005434979404	27523	22	6B
0005434979324	27523	23	6C
0005434979444	27523	24	7A
0005434979409	27523	25	7B
0005434979292	27523	26	7C
0005434988577	27523	27	7D
0005434979339	27523	28	18A
0005434988558	27523	29	18B
0005434979414	27523	30	18D
0005434979460	27523	31	19A
0005434979329	27523	32	19B
0005434979387	27523	33	20A
0005434979326	27523	34	20B
0005434979467	27523	35	20C
0005434979406	27523	36	20D
0005434988579	27523	37	21A
0005434979394	27523	38	21B
0005434979277	27523	39	21C
0005434979315	27523	40	22A
0005434988580	27523	41	22B
0005434979400	27523	42	22C
0005434988568	27523	43	22D
0005434979385	27523	44	23B
0005434302438	10294	1	1C
0005434302436	10294	2	4A
0005434302435	10294	3	5A
0005434302856	10294	4	7A
0005434302437	10294	5	19C
0005433113502	10294	6	21A
0005433113527	19639	1	2C
0005433113526	19639	2	2D
0005434302398	19639	3	5A
0005433113528	19639	4	22B
0005435068865	3548	1	1A
0005435068848	3548	2	1C
0005435068892	3548	3	1F
0005435068861	3548	4	2A
0005435068868	3548	5	2C
0005435068874	3548	6	2D
0005435068851	3548	7	2F
0005435068850	3548	8	3C
0005435068860	3548	9	3F
0005435068863	3548	10	4D
0005435925065	3548	11	4E
0005435068856	3548	12	5A
0005435068847	3548	13	5E
0005435925080	3548	14	6A
0005435068864	3548	15	6C
0005435068889	3548	16	6D
0005435068880	3548	17	6E
0005435068877	3548	18	7D
0005435068888	3548	19	7E
0005435925102	3548	20	7F
0005435068855	3548	21	8A
0005435068872	3548	22	8C
0005435068883	3548	23	8D
0005435068881	3548	24	9A
0005435925095	3548	25	9C
0005435068884	3548	26	9E
0005435068897	3548	27	9F
0005435925062	3548	28	10A
0005435068862	3548	29	10C
0005435068894	3548	30	10D
0005435068867	3548	31	10E
0005435718920	3548	32	10F
0005435068879	3548	33	11C
0005435068891	3548	34	11D
0005435068898	3548	35	11F
0005435068869	3548	36	12C
0005435068858	3548	37	12E
0005435068857	3548	38	12F
0005435068895	3548	39	13A
0005435925107	3548	40	13C
0005435068852	3548	41	13D
0005435068873	3548	42	13E
0005435068885	3548	43	13F
0005435068854	3548	44	14A
0005435068849	3548	45	14C
0005435068890	3548	46	15C
0005435068878	3548	47	15D
0005435068900	3548	48	15E
0005435925103	3548	49	15F
0005435925106	3548	50	16A
0005435068853	3548	51	16E
0005435068866	3548	52	16F
0005435068887	3548	53	17A
0005435068886	3548	54	17C
0005435068896	3548	55	17E
0005435068876	3548	56	17F
0005435068875	3548	57	18C
0005435068871	3548	58	18D
0005435925097	3548	59	18E
0005435068893	3548	60	18F
0005435068882	3548	61	19A
0005435068870	3548	62	19D
0005435925101	3548	63	19E
0005435068899	3548	64	19F
0005435068859	3548	65	20C
0005435925104	3548	66	20D
0005435068362	15275	1	1A
0005435068428	15275	2	1D
0005435925241	15275	3	1F
0005435925238	15275	4	2A
0005435925235	15275	5	2D
0005435925236	15275	6	2F
0005435068252	15275	7	3C
0005435939873	15275	8	3D
0005435925229	15275	9	3F
0005435068429	15275	10	4A
0005435068271	15275	11	4D
0005435068361	15275	12	4F
0005435925224	15275	13	5A
0005435068496	15275	14	5C
0005435068272	15275	15	5D
0005435068497	15275	16	5E
0005435068350	15275	17	5F
0005435068404	15275	18	6C
0005435925233	15275	19	6E
0005435068265	15275	20	7A
0005435068448	15275	21	7C
0005435068447	15275	22	7D
0005435925242	15275	23	7E
0005435068526	15275	24	7F
0005435939874	15275	25	8A
0005435068495	15275	26	8C
0005435068471	15275	27	8D
0005435068446	15275	28	8E
0005435068239	15275	29	8F
0005435068435	15275	30	9A
0005435925225	15275	31	9C
0005435068169	15275	32	9D
0005435068268	15275	33	9E
0005435068335	15275	34	9F
0005435925228	15275	35	10A
0005435068251	15275	36	10D
0005435068438	15275	37	10E
0005435925226	15275	38	10F
0005435068489	15275	39	11C
0005435068498	15275	40	11D
0005435068406	15275	41	11F
0005435068263	15275	42	12A
0005435068311	15275	43	12C
0005435068499	15275	44	12D
0005435068269	15275	45	12F
0005435068440	15275	46	13C
0005435925230	15275	47	13D
0005435925222	15275	48	13F
0005435068310	15275	49	14A
0005435925240	15275	50	14D
0005435068212	15275	51	14E
0005435068537	15275	52	15A
0005435925227	15275	53	15C
0005435068538	15275	54	15D
0005435068270	15275	55	15E
0005435925231	15275	56	16A
0005435925234	15275	57	16C
0005435925223	15275	58	16E
0005435068581	15275	59	16F
0005435068409	15275	60	17A
0005435068221	15275	61	17C
0005435925219	15275	62	17E
0005435925232	15275	63	17F
0005435925237	15275	64	18A
0005435068536	15275	65	18C
0005435068405	15275	66	18D
0005435925220	15275	67	18E
0005435925239	15275	68	19A
0005435068371	15275	69	19C
0005435068381	15275	70	19E
0005435068343	15275	71	19F
0005435925221	15275	72	20A
0005435068488	15275	73	20D
0005435925243	15275	74	20E
0005435068334	15275	75	20F
0005432660808	18213	1	1B
0005432659697	18213	2	2B
0005432660809	18213	3	3A
0005432658582	18213	4	4A
0005432660810	18213	5	6A
0005432659698	18213	6	6B
0005432667427	26426	1	1A
0005432660788	26426	2	1B
0005432660790	26426	3	2A
0005432667428	26426	4	3A
0005432667426	26426	5	3B
0005432660789	26426	6	5A
0005433101490	125	1	1C
0005433101474	125	2	1F
0005433101568	125	3	1D
0005433101483	125	4	2A
0005433101555	125	5	3A
0005433101584	125	6	3D
0005432919591	125	7	3F
0005433101575	125	8	4A
0005433101437	125	9	5A
0005433101547	125	10	6A
0005432919669	125	11	5F
0005433101408	125	12	6C
0005433101469	125	13	6D
0005433101372	125	14	7C
0005433101516	125	15	7D
0005433101564	125	16	8A
0005433101536	125	17	8B
0005432157483	125	18	9B
0005432677519	125	19	9A
0005433101480	125	20	9C
0005433101400	125	21	9D
0005433101299	125	22	10B
0005433101433	125	23	10D
0005433101522	125	24	10C
0005432157485	125	25	10F
0005433101576	125	26	11B
0005433101350	125	27	11A
0005432901379	125	28	11C
0005432901501	125	29	11D
0005432919578	125	30	11E
0005433101371	125	31	12C
0005433101395	125	32	12E
0005432677533	125	33	12D
0005432919643	125	34	13B
0005433101349	125	35	13A
0005433101423	125	36	13E
0005433101245	125	37	13F
0005432677529	125	38	14C
0005432919617	125	39	14B
0005433101556	125	40	14A
0005432901410	125	41	14E
0005433101193	125	42	14F
0005433101192	125	43	15C
0005433101475	125	44	15B
0005433101482	125	45	15E
0005433101361	125	46	15D
0005433101419	125	47	15F
0005433101255	125	48	16A
0005433101492	125	49	16C
0005432901403	125	50	16D
0005432901353	125	51	16F
0005432919710	125	52	17C
0005433101436	125	53	17B
0005433101472	125	54	17D
0005433101407	125	55	18A
0005432919539	125	56	17F
0005432901406	125	57	18C
0005433101470	125	58	18E
0005432919614	125	59	18D
0005433101452	125	60	19C
0005432919615	125	61	19D
0005433101348	125	62	19E
0005432919530	125	63	20B
0005432157484	125	64	20A
0005432901417	125	65	20C
0005433101294	125	66	20D
0005433101510	125	67	20F
0005433101391	125	68	20E
0005433101444	125	69	21B
0005432919549	125	70	21D
0005433101535	125	71	21E
0005433101565	125	72	22C
0005432901418	125	73	22D
0005433101319	125	74	22F
0005432677528	125	75	23A
0005433101558	125	76	23B
0005432919644	125	77	23D
0005433101420	125	78	23C
0005432919628	125	79	23E
0005433101406	125	80	24A
0005433101515	125	81	23F
0005433101481	125	82	24B
0005433101520	125	83	24D
0005433101454	125	84	24C
0005432919577	125	85	24F
0005433101583	125	86	25B
0005433101548	125	87	25D
0005433101585	125	88	25F
0005432919616	125	89	26B
0005432901407	125	90	26D
0005433101373	125	91	26F
0005433101489	125	92	27A
0005432901463	125	93	27D
0005433101297	125	94	27C
0005432901373	125	95	27F
0005433101574	125	96	28A
0005433101354	125	97	28C
0005433101546	125	98	28D
0005433101362	125	99	28F
0005432919654	125	100	29A
0005433101445	125	101	29C
0005433101353	125	102	29D
0005432901366	125	103	29F
0005433101253	125	104	29E
0005433101509	125	105	30A
0005432919711	125	106	30B
0005433101355	125	107	30D
0005433101563	125	108	30E
0005433101379	125	109	31B
0005432919546	125	110	31A
0005432919590	125	111	31C
0005433101511	125	112	31D
0005432919655	125	113	31F
0005433101254	125	114	31E
0005432261733	126	1	1C
0005432817345	126	2	1D
0005432261703	126	3	2A
0005432261717	126	4	2F
0005432756793	126	5	3D
0005432261738	126	6	3C
0005432261705	126	7	4A
0005432817360	126	8	3F
0005432817332	126	9	4D
0005432261697	126	10	4C
0005432817352	126	11	5A
0005432261727	126	12	5C
0005432817336	126	13	5D
0005432261704	126	14	6A
0005432817349	126	15	6D
0005432817351	126	16	7A
0005432817348	126	17	7C
0005432261698	126	18	8C
0005432207651	126	19	8E
0005432817342	126	20	8D
0005432261699	126	21	8F
0005432261710	126	22	9B
0005432756802	126	23	9D
0005432261696	126	24	9F
0005432261702	126	25	9E
0005432261708	126	26	10A
0005432261732	126	27	10B
0005432817362	126	28	10C
0005432817341	126	29	10E
0005432261700	126	30	10F
0005432817347	126	31	11B
0005432817344	126	32	11A
0005432207648	126	33	12B
0005432817346	126	34	12A
0005432753278	126	35	12C
0005432261719	126	36	12F
0005432261731	126	37	13B
0005432288973	126	38	13F
0005432261726	126	39	14B
0005432261722	126	40	14A
0005432261729	126	41	14F
0005432817340	126	42	15A
0005432817357	126	43	15D
0005432817334	126	44	15E
0005432756791	126	45	16C
0005432817335	126	46	16D
0005432817356	126	47	17A
0005432207649	126	48	17B
0005432261736	126	49	17F
0005432261709	126	50	18A
0005432817333	126	51	18C
0005432817338	126	52	18E
0005432756790	126	53	19B
0005432261706	126	54	19C
0005434153527	126	55	19E
0005432261734	126	56	20B
0005432817354	126	57	20C
0005432261741	126	58	20E
0005432817343	126	59	21A
0005432261724	126	60	21D
0005432261715	126	61	22A
0005432261728	126	62	21F
0005432261716	126	63	22C
0005432261720	126	64	22E
0005432817355	126	65	22D
0005432261739	126	66	22F
0005432261712	126	67	23D
0005432261721	126	68	23E
0005432261723	126	69	24B
0005432288972	126	70	24A
0005432753255	126	71	24E
0005432261714	126	72	24F
0005432817358	126	73	25A
0005432261695	126	74	25E
0005432261718	126	75	26A
0005432288971	126	76	26C
0005432261730	126	77	26D
0005432207650	126	78	26F
0005432261713	126	79	27B
0005432261735	126	80	27E
0005432261707	126	81	28A
0005432261740	126	82	28C
0005432817361	126	83	29A
0005432261737	126	84	29C
0005432756803	126	85	29E
0005432756804	126	86	29D
0005432817353	126	87	29F
0005432817339	126	88	30B
0005432261701	126	89	30E
0005432817359	126	90	30D
0005432817350	126	91	31B
0005432817337	126	92	31A
0005432261725	126	93	31D
0005432261742	126	94	31F
0005432261711	126	95	31E
0005433101906	8115	1	1C
0005433101946	8115	2	1F
0005433101954	8115	3	2A
0005432751513	8115	4	2C
0005433101933	8115	5	2F
0005433101960	8115	6	2D
0005432919778	8115	7	3C
0005432020143	8115	8	3F
0005432020145	8115	9	3D
0005433101918	8115	10	4C
0005433101920	8115	11	4F
0005433101941	8115	12	5D
0005432919767	8115	13	5C
0005433101952	8115	14	6A
0005432753286	8115	15	5F
0005432919770	8115	16	6C
0005432677558	8115	17	6D
0005433101964	8115	18	6F
0005433101928	8115	19	7C
0005432919768	8115	20	7D
0005432020148	8115	21	8A
0005433101942	8115	22	7F
0005433101959	8115	23	8B
0005433101932	8115	24	8D
0005433101949	8115	25	8C
0005432919765	8115	26	8E
0005432044513	8115	27	8F
0005433101925	8115	28	9B
0005433101948	8115	29	9D
0005433101937	8115	30	9F
0005432020155	8115	31	9E
0005433101911	8115	32	10A
0005432020159	8115	33	10D
0005432020149	8115	34	10C
0005432020146	8115	35	10F
0005433101947	8115	36	10E
0005432919777	8115	37	11B
0005432919763	8115	38	11A
0005433101902	8115	39	11D
0005432045606	8115	40	11F
0005433101944	8115	41	11E
0005432020158	8115	42	12A
0005433101917	8115	43	12B
0005432020154	8115	44	12E
0005432919760	8115	45	12D
0005433101963	8115	46	12F
0005433101935	8115	47	13B
0005432919774	8115	48	13A
0005432919773	8115	49	13C
0005432919776	8115	50	13D
0005432020153	8115	51	13F
0005433101936	8115	52	14B
0005432919762	8115	53	14D
0005433101938	8115	54	14C
0005433101907	8115	55	14E
0005432020136	8115	56	15A
0005432919769	8115	57	14F
0005433101930	8115	58	15C
0005433101913	8115	59	15E
0005433101912	8115	60	15F
0005433101915	8115	61	16A
0005432391988	8115	62	16C
0005432677556	8115	63	16D
0005433101910	8115	64	17A
0005432391986	8115	65	16F
0005433101909	8115	66	17B
0005433101921	8115	67	17D
0005432919780	8115	68	17E
0005432020160	8115	69	18C
0005432753287	8115	70	18B
0005432020147	8115	71	18D
0005432919766	8115	72	18E
0005433101934	8115	73	18F
0005433101908	8115	74	19B
0005432751514	8115	75	19E
0005432919764	8115	76	19D
0005433101914	8115	77	20A
0005432020151	8115	78	20E
0005433101955	8115	79	21A
0005432020157	8115	80	20F
0005433101926	8115	81	21C
0005433101919	8115	82	21B
0005432020140	8115	83	21D
0005432677559	8115	84	21E
0005432020156	8115	85	22A
0005433101904	8115	86	21F
0005432020152	8115	87	22B
0005432020138	8115	88	22C
0005433101945	8115	89	22D
0005433101924	8115	90	22F
0005432919775	8115	91	22E
0005432751512	8115	92	23B
0005433101931	8115	93	23A
0005433101923	8115	94	23C
0005433101958	8115	95	23D
0005432044512	8115	96	24A
0005432020161	8115	97	23F
0005433101957	8115	98	24D
0005433101905	8115	99	24C
0005433101927	8115	100	25A
0005433101950	8115	101	24F
0005432020150	8115	102	25D
0005432020141	8115	103	26A
0005432020139	8115	104	26C
0005433101929	8115	105	26B
0005433101922	8115	106	26D
0005433101916	8115	107	26F
0005433101961	8115	108	26E
0005432919761	8115	109	27B
0005432753288	8115	110	27C
0005432020162	8115	111	28A
0005432919771	8115	112	28E
0005432044514	8115	113	28D
0005433101951	8115	114	28F
0005433101953	8115	115	29B
0005433101903	8115	116	29A
0005432919772	8115	117	29C
0005432677557	8115	118	29D
0005433101962	8115	119	30A
0005432020144	8115	120	29F
0005432020137	8115	121	30C
0005433101956	8115	122	30B
0005432045607	8115	123	30D
0005432020142	8115	124	30E
0005433101943	8115	125	30F
0005432391987	8115	126	31B
0005433101939	8115	127	31A
0005432045605	8115	128	31D
0005433101940	8115	129	31C
0005432753289	8115	130	31E
0005432919779	8115	131	31F
0005432817046	8114	1	1F
0005432901541	8114	2	2A
0005432817146	8114	3	2C
0005432817161	8114	4	3D
0005432901534	8114	5	4C
0005432817135	8114	6	4F
0005432817109	8114	7	5C
0005432817031	8114	8	6A
0005432817030	8114	9	7A
0005432901540	8114	10	7D
0005432817058	8114	11	7F
0005432901531	8114	12	8E
0005432002067	8114	13	9D
0005432901530	8114	14	9E
0005432901536	8114	15	10B
0005432817038	8114	16	11C
0005432817045	8114	17	11D
0005432816957	8114	18	13A
0005432817120	8114	19	13D
0005432817154	8114	20	15A
0005432901542	8114	21	15D
0005432817118	8114	22	16C
0005432901544	8114	23	16F
0005432817025	8114	24	16E
0005432901545	8114	25	16D
0005432002066	8114	26	17B
0005432817162	8114	27	17D
0005432901528	8114	28	18C
0005432817082	8114	29	20B
0005432817039	8114	30	20E
0005432901533	8114	31	21B
0005432817032	8114	32	21D
0005432901527	8114	33	22D
0005432816965	8114	34	22F
0005432817083	8114	35	22E
0005432817153	8114	36	23C
0005432901538	8114	37	23B
0005432901543	8114	38	24A
0005432817112	8114	39	24D
0005432901537	8114	40	25B
0005432901535	8114	41	25C
0005432901539	8114	42	25D
0005432901532	8114	43	25E
0005432901529	8114	44	26B
0005432817081	8114	45	26F
0005432817012	8114	46	28C
0005432817134	8114	47	29B
0005432817024	8114	48	30A
0005432817013	8114	49	30B
0005432817100	8114	50	31E
0005433870721	9668	1	1B
0005434175704	9668	2	2A
0005433870722	9668	3	4A
0005434175694	9668	4	5B
0005434175698	9668	5	6A
0005434175716	9668	6	6B
0005434175736	32353	1	1A
0005433870701	32353	2	1B
0005433870702	32353	3	2B
0005434175735	32353	4	3B
0005434175734	32353	5	4B
0005434175733	32353	6	6A
0005432188596	3506	1	1C
0005434426492	3506	2	1A
0005435902441	3506	3	1H
0005434877835	3506	4	1G
0005434426476	3506	5	1K
0005434877873	3506	6	2D
0005435126217	3506	7	2A
0005434877817	3506	8	2H
0005435913858	3506	9	3A
0005435626096	3506	10	3D
0005434877869	3506	11	3C
0005434877844	3506	12	3K
0005434426504	3506	13	4C
0005435902449	3506	14	4A
0005434877895	3506	15	4G
0005435902429	3506	16	4D
0005434877857	3506	17	5D
0005432799345	3506	18	5C
0005434877850	3506	19	5A
0005432799341	3506	20	5G
0005434877827	3506	21	5K
0005434877837	3506	22	11C
0005435626093	3506	23	11F
0005434877896	3506	24	11H
0005434877823	3506	25	11G
0005434938063	3506	26	12A
0005434877907	3506	27	12E
0005435126200	3506	28	12G
0005434938066	3506	29	12F
0005434877822	3506	30	12K
0005434877885	3506	31	13C
0005435902440	3506	32	13F
0005435902546	3506	33	13E
0005434426479	3506	34	13H
0005435126214	3506	35	13G
0005435126220	3506	36	14A
0005435126215	3506	37	13K
0005435841082	3506	38	14E
0005434877856	3506	39	14D
0005434938068	3506	40	14C
0005435626097	3506	41	14G
0005435902512	3506	42	15C
0005434877880	3506	43	15E
0005434877821	3506	44	15H
0005434426493	3506	45	16A
0005434877883	3506	46	15K
0005434877881	3506	47	16D
0005435126211	3506	48	16C
0005434877864	3506	49	16F
0005434938056	3506	50	16E
0005434426499	3506	51	16K
0005434877858	3506	52	17C
0005434877900	3506	53	17E
0005434938059	3506	54	17H
0005435126191	3506	55	18B
0005435913863	3506	56	18E
0005434877876	3506	57	18D
0005435126230	3506	58	18C
0005434426498	3506	59	18G
0005434877830	3506	60	18F
0005432799357	3506	61	18K
0005435126229	3506	62	18J
0005432799337	3506	63	18H
0005434877889	3506	64	19A
0005434938065	3506	65	19D
0005434426503	3506	66	19B
0005434877852	3506	67	19E
0005434877887	3506	68	19J
0005434877849	3506	69	19H
0005434877820	3506	70	19G
0005434877819	3506	71	19K
0005435126201	3506	72	20C
0005432799340	3506	73	20B
0005432799343	3506	74	20D
0005435126228	3506	75	20K
0005434426497	3506	76	20J
0005435126225	3506	77	20H
0005435902543	3506	78	21B
0005435126188	3506	79	21A
0005432183458	3506	80	21D
0005435126207	3506	81	21C
0005434938055	3506	82	21G
0005435626094	3506	83	21J
0005434426487	3506	84	21H
0005434938069	3506	85	22A
0005434877863	3506	86	22E
0005435626095	3506	87	22D
0005434877826	3506	88	22K
0005435126199	3506	89	22H
0005432799347	3506	90	23C
0005432611695	3506	91	23F
0005432799336	3506	92	23J
0005435626106	3506	93	23H
0005434877870	3506	94	23G
0005434877855	3506	95	23K
0005434877901	3506	96	24F
0005435626102	3506	97	24E
0005434877872	3506	98	25A
0005434938061	3506	99	24G
0005435126223	3506	100	25C
0005434877908	3506	101	25B
0005435626108	3506	102	25F
0005435126206	3506	103	25E
0005435902387	3506	104	25H
0005432799331	3506	105	25G
0005434938057	3506	106	25K
0005434877847	3506	107	25J
0005435126210	3506	108	26B
0005434877879	3506	109	26A
0005434426501	3506	110	26E
0005432611694	3506	111	26D
0005435126227	3506	112	26F
0005432799346	3506	113	26K
0005434877877	3506	114	26J
0005434938058	3506	115	26H
0005435126198	3506	116	27A
0005434877898	3506	117	27D
0005432799356	3506	118	27C
0005434938072	3506	119	27B
0005434938064	3506	120	27F
0005435126219	3506	121	27H
0005434426488	3506	122	28A
0005434877843	3506	123	27K
0005434938053	3506	124	27J
0005434877838	3506	125	28B
0005434877897	3506	126	28D
0005435126195	3506	127	28G
0005435626101	3506	128	28E
0005434877832	3506	129	28J
0005434877831	3506	130	28H
0005435126189	3506	131	29A
0005432799342	3506	132	28K
0005434877833	3506	133	29D
0005434877845	3506	134	29F
0005434938054	3506	135	29E
0005435626105	3506	136	29H
0005434877899	3506	137	29K
0005432799353	3506	138	30C
0005435902492	3506	139	30B
0005432799339	3506	140	30A
0005435913864	3506	141	30E
0005434877890	3506	142	30D
0005435126208	3506	143	30H
0005434877894	3506	144	30F
0005434938062	3506	145	30K
0005434426505	3506	146	30J
0005434877860	3506	147	31A
0005434426495	3506	148	31C
0005434877867	3506	149	31F
0005435913856	3506	150	31E
0005434877836	3506	151	31J
0005435902491	3506	152	31G
0005435841813	3506	153	32A
0005434938070	3506	154	31K
0005432188597	3506	155	32C
0005435126204	3506	156	32B
0005434877854	3506	157	32D
0005432799330	3506	158	32G
0005434877910	3506	159	32F
0005434877868	3506	160	32J
0005434877875	3506	161	32H
0005434938060	3506	162	33A
0005435902389	3506	163	32K
0005435126190	3506	164	33D
0005434877892	3506	165	33F
0005435126193	3506	166	33E
0005434426484	3506	167	33J
0005434877905	3506	168	33H
0005432799350	3506	169	33G
0005434877859	3506	170	33K
0005435126221	3506	171	34B
0005434877816	3506	172	34A
0005435126196	3506	173	34E
0005434877886	3506	174	34F
0005435902466	3506	175	34J
0005435126209	3506	176	34H
0005434877824	3506	177	35A
0005435913867	3506	178	35C
0005434877878	3506	179	35F
0005434877882	3506	180	35J
0005432799335	3506	181	35H
0005432799329	3506	182	36A
0005432613845	3506	183	35K
0005435913865	3506	184	36C
0005435126218	3506	185	36B
0005432188595	3506	186	36D
0005435126226	3506	187	36G
0005434426494	3506	188	36F
0005434426477	3506	189	36J
0005432799352	3506	190	37B
0005434426478	3506	191	37D
0005435902542	3506	192	37C
0005434426485	3506	193	37G
0005434426491	3506	194	38A
0005432799344	3506	195	38C
0005432799348	3506	196	38J
0005434426500	3506	197	38K
0005434877865	3506	198	39D
0005435626109	3506	199	39C
0005432799354	3506	200	39F
0005432613844	3506	201	39E
0005434877866	3506	202	39H
0005434877884	3506	203	39G
0005435913866	3506	204	40A
0005434877893	3506	205	39K
0005434877906	3506	206	39J
0005435902503	3506	207	40C
0005435902504	3506	208	40D
0005434426490	3506	209	40G
0005434426483	3506	210	40F
0005434877842	3506	211	40J
0005435626098	3506	212	40H
0005432799351	3506	213	41A
0005434877818	3506	214	41D
0005435902386	3506	215	41C
0005435902388	3506	216	41G
0005435902467	3506	217	41F
0005432799338	3506	218	41E
0005434877888	3506	219	41K
0005435902464	3506	220	41J
0005434426489	3506	221	42C
0005435626103	3506	222	42B
0005434877848	3506	223	42E
0005435126194	3506	224	42D
0005434877903	3506	225	42G
0005432188594	3506	226	42K
0005432799333	3506	227	42J
0005434938067	3506	228	42H
0005435126213	3506	229	43B
0005435126192	3506	230	43D
0005435126205	3506	231	43C
0005432799355	3506	232	43F
0005434877871	3506	233	43E
0005434426480	3506	234	44A
0005435626099	3506	235	43K
0005434877828	3506	236	44B
0005435126222	3506	237	44E
0005434877862	3506	238	44C
0005435126224	3506	239	44G
0005435126197	3506	240	44F
0005435126202	3506	241	44K
0005434877839	3506	242	44J
0005434877909	3506	243	45A
0005434877904	3506	244	45D
0005435902516	3506	245	45F
0005435126212	3506	246	45H
0005435626104	3506	247	46A
0005434938071	3506	248	45K
0005434426496	3506	249	46C
0005434877874	3506	250	46B
0005435626107	3506	251	46G
0005435126203	3506	252	46F
0005434877861	3506	253	46J
0005435626100	3506	254	47C
0005435626092	3506	255	47A
0005434877834	3506	256	46K
0005434426486	3506	257	47E
0005435902406	3506	258	47D
0005434877841	3506	259	47G
0005434877840	3506	260	47K
0005432613846	3506	261	47H
0005434426481	3506	262	48D
0005432799334	3506	263	48A
0005434877902	3506	264	48F
0005434877846	3506	265	48H
0005434877825	3506	266	48G
0005434426502	3506	267	49A
0005434877853	3506	268	49E
0005435126216	3506	269	49H
0005434877891	3506	270	50C
0005434938052	3506	271	50G
0005434877829	3506	272	50F
0005434877851	3506	273	50K
0005432611693	3506	274	51F
0005434426482	3506	275	51E
0005432799332	3506	276	51D
0005432799349	3506	277	51G
0005434876750	14591	1	1D
0005435902633	14591	2	1C
0005434937863	14591	3	1A
0005434876992	14591	4	2A
0005435125814	14591	5	1K
0005432799071	14591	6	1H
0005434877338	14591	7	2D
0005435125787	14591	8	2C
0005434877189	14591	9	2G
0005435625914	14591	10	3A
0005435125827	14591	11	2K
0005434876964	14591	12	3D
0005432799003	14591	13	3C
0005432611665	14591	14	4A
0005434877119	14591	15	4D
0005434876932	14591	16	4C
0005434426303	14591	17	4K
0005432799122	14591	18	5H
0005434426260	14591	19	5G
0005432059495	14591	20	5D
0005435125765	14591	21	11A
0005434877020	14591	22	5K
0005434937897	14591	23	11C
0005432799100	14591	24	11F
0005434877067	14591	25	11G
0005434876978	14591	26	12A
0005435625890	14591	27	11K
0005435625920	14591	28	12E
0005435125715	14591	29	12D
0005434877242	14591	30	12C
0005434877140	14591	31	12H
0005434877131	14591	32	12G
0005434877139	14591	33	12F
0005432799187	14591	34	12K
0005434937895	14591	35	13D
0005434877055	14591	36	13F
0005432059496	14591	37	13G
0005435902630	14591	38	14A
0005434877347	14591	39	13K
0005432799125	14591	40	14D
0005434876955	14591	41	14F
0005432799102	14591	42	14G
0005435625941	14591	43	15C
0005434877036	14591	44	15A
0005434426204	14591	45	15D
0005435125750	14591	46	15G
0005434877123	14591	47	15F
0005435625888	14591	48	15K
0005434876821	14591	49	15H
0005435902623	14591	50	16D
0005435625887	14591	51	16A
0005432799020	14591	52	16F
0005434876828	14591	53	16E
0005434877227	14591	54	16H
0005434877185	14591	55	16G
0005434426241	14591	56	17C
0005432799081	14591	57	17A
0005434876983	14591	58	16K
0005434877191	14591	59	17D
0005434876829	14591	60	17K
0005434937907	14591	61	17H
0005434426209	14591	62	18B
0005432611652	14591	63	18E
0005435625903	14591	64	18D
0005432611666	14591	65	18C
0005432799112	14591	66	18G
0005435625945	14591	67	18J
0005434876956	14591	68	18H
0005432799103	14591	69	19A
0005434876974	14591	70	19D
0005432799145	14591	71	19F
0005434877118	14591	72	19E
0005434426288	14591	73	19H
0005434877021	14591	74	20C
0005434877058	14591	75	20B
0005434877177	14591	76	20A
0005435125867	14591	77	20G
0005434937793	14591	78	20K
0005432799093	14591	79	20H
0005432611658	14591	80	21A
0005434877081	14591	81	21D
0005435125828	14591	82	21C
0005432799190	14591	83	21E
0005435902637	14591	84	21J
0005435625924	14591	85	21H
0005434877301	14591	86	22D
0005434877122	14591	87	22C
0005434877070	14591	88	22B
0005434876786	14591	89	22F
0005434877039	14591	90	22E
0005435125818	14591	91	22G
0005434877278	14591	92	22K
0005434876855	14591	93	23A
0005432611642	14591	94	23D
0005432799015	14591	95	23G
0005435902627	14591	96	23H
0005435902635	14591	97	24D
0005435902632	14591	98	23K
0005435125681	14591	99	24F
0005434876787	14591	100	24E
0005434937934	14591	101	25B
0005434877080	14591	102	25D
0005434877132	14591	103	25F
0005434876993	14591	104	25E
0005434937843	14591	105	25H
0005435126054	14591	106	25G
0005434877255	14591	107	25J
0005432799032	14591	108	26C
0005432799096	14591	109	26B
0005432611675	14591	110	26D
0005432799212	14591	111	26J
0005434876979	14591	112	26H
0005434876856	14591	113	26K
0005435625935	14591	114	27D
0005435902622	14591	115	27C
0005434877034	14591	116	27F
0005434937872	14591	117	27E
0005435625940	14591	118	27H
0005435625858	14591	119	27G
0005434876818	14591	120	28A
0005435126053	14591	121	28D
0005434877355	14591	122	28C
0005435125819	14591	123	28G
0005434876972	14591	124	28F
0005434876814	14591	125	28E
0005434877209	14591	126	28J
0005434877211	14591	127	29B
0005434876863	14591	128	29A
0005434426292	14591	129	29F
0005435125773	14591	130	29E
0005434937958	14591	131	29J
0005435625897	14591	132	29G
0005432799113	14591	133	30A
0005435902628	14591	134	30C
0005434877104	14591	135	30B
0005434877413	14591	136	30D
0005434937894	14591	137	30G
0005434937936	14591	138	30F
0005435902621	14591	139	30K
0005434877393	14591	140	30J
0005434877019	14591	141	31B
0005434877006	14591	142	31A
0005434876864	14591	143	31D
0005434876925	14591	144	31C
0005432799142	14591	145	31F
0005434877210	14591	146	31E
0005432799220	14591	147	31H
0005435625946	14591	148	31G
0005435902634	14591	149	32A
0005434937957	14591	150	31J
0005435625891	14591	151	32C
0005434877348	14591	152	32E
0005432799191	14591	153	32D
0005435125775	14591	154	32G
0005432607522	14591	155	32F
0005434877130	14591	156	32J
0005435125670	14591	157	33B
0005435125830	14591	158	33A
0005432799143	14591	159	33D
0005434937898	14591	160	33C
0005435902626	14591	161	33E
0005432799033	14591	162	33J
0005434876558	14591	163	33K
0005434426232	14591	164	34C
0005434877068	14591	165	34B
0005434877299	14591	166	34E
0005435125935	14591	167	34D
0005434876867	14591	168	34H
0005434426210	14591	169	34F
0005434876754	14591	170	34J
0005434876916	14591	171	35B
0005434426245	14591	172	35A
0005434877260	14591	173	35D
0005432799124	14591	174	35C
0005434937920	14591	175	35F
0005434876973	14591	176	35E
0005435625937	14591	177	36A
0005434877073	14591	178	35K
0005435125939	14591	179	35J
0005434876694	14591	180	36D
0005435125776	14591	181	36C
0005434937921	14591	182	36E
0005434426334	14591	183	36G
0005434877194	14591	184	36J
0005435625857	14591	185	37A
0005435125774	14591	186	37D
0005434876991	14591	187	37C
0005434426304	14591	188	37F
0005434877373	14591	189	37J
0005434877213	14591	190	37H
0005434877394	14591	191	37G
0005434876762	14591	192	38A
0005432799019	14591	193	37K
0005434877023	14591	194	38C
0005434426287	14591	195	38H
0005434426180	14591	196	39B
0005432799141	14591	197	39D
0005434426274	14591	198	39H
0005435125934	14591	199	39G
0005434426174	14591	200	40B
0005434937935	14591	201	40E
0005434877103	14591	202	40H
0005434426159	14591	203	40J
0005434877057	14591	204	41B
0005434937945	14591	205	41A
0005434937946	14591	206	41D
0005434877098	14591	207	41C
0005435125866	14591	208	41G
0005434426325	14591	209	41F
0005435125820	14591	210	41E
0005432799017	14591	211	41J
0005434876933	14591	212	42A
0005434937919	14591	213	42B
0005435902638	14591	214	42E
0005434877292	14591	215	42D
0005434877198	14591	216	42G
0005435125798	14591	217	42F
0005434877079	14591	218	42K
0005434877035	14591	219	42J
0005435902631	14591	220	43E
0005434426158	14591	221	43D
0005434877243	14591	222	43H
0005434937880	14591	223	43G
0005435125831	14591	224	43K
0005435902629	14591	225	43J
0005435125778	14591	226	44C
0005434876971	14591	227	44B
0005434877302	14591	228	44A
0005434877178	14591	229	44E
0005434876917	14591	230	44D
0005435125777	14591	231	44G
0005434876985	14591	232	44F
0005434937906	14591	233	45B
0005435125808	14591	234	45A
0005432799095	14591	235	45D
0005435125807	14591	236	45C
0005434877430	14591	237	45E
0005434426317	14591	238	45G
0005435902636	14591	239	46A
0005435125772	14591	240	45J
0005434937845	14591	241	46C
0005434426312	14591	242	46B
0005435902624	14591	243	46E
0005434877056	14591	244	46D
0005434937956	14591	245	46H
0005434877339	14591	246	46F
0005435842325	14591	247	46J
0005435625929	14591	248	47C
0005435125771	14591	249	47A
0005434876969	14591	250	46K
0005432799140	14591	251	47E
0005434876834	14591	252	47D
0005435125876	14591	253	47G
0005434877190	14591	254	47F
0005434426276	14591	255	48A
0005434426324	14591	256	47H
0005434876816	14591	257	48D
0005435902625	14591	258	48C
0005434876830	14591	259	48H
0005434876749	14591	260	49A
0005435625930	14591	261	49D
0005434876764	14591	262	49C
0005435625921	14591	263	49G
0005432799018	14591	264	49F
0005434877412	14591	265	50A
0005432799053	14591	266	50E
0005435125875	14591	267	50D
0005434876815	14591	268	50H
0005434876763	14591	269	50G
0005432799144	14591	270	50F
0005434426275	14591	271	51D
0005434876827	14591	272	50K
0005434876977	14591	273	51F
0005434937792	14591	274	51G
0005434325598	3611	1	1A
0005435889814	3611	2	1C
0005434325604	3611	3	2B
0005435889821	3611	4	2C
0005435889799	3611	5	2D
0005434325608	3611	6	3A
0005435889817	3611	7	3B
0005434325599	3611	8	3C
0005434325601	3611	9	4B
0005434312310	3611	10	5A
0005434325605	3611	11	5D
0005434312309	3611	12	6B
0005434312311	3611	13	6D
0005435889827	3611	14	7B
0005434325607	3611	15	7C
0005434325606	3611	16	7D
0005434325603	3611	17	18D
0005435889823	3611	18	20C
0005434325602	3611	19	21B
0005434325597	3611	20	21C
0005435889815	3611	21	22A
0005434325600	3611	22	22C
0005435889818	3611	23	22D
0005435889871	15638	1	1C
0005434325536	15638	2	1D
0005435889870	15638	3	2A
0005435889874	15638	4	2C
0005434325558	15638	5	2D
0005434325504	15638	6	3D
0005434325564	15638	7	5A
0005435889872	15638	8	5C
0005434325586	15638	9	6B
0005434325534	15638	10	7B
0005435889869	15638	11	18C
0005434325559	15638	12	18D
0005434325515	15638	13	19A
0005434325535	15638	14	19B
0005434325587	15638	15	19C
0005435889873	15638	16	19D
0005435889875	15638	17	21A
0005434325565	15638	18	21C
0005434325539	15638	19	21D
0005434325529	15638	20	22A
0005434325518	15638	21	22C
0005434325530	15638	22	22D
0005434325533	15638	23	23B
0005435957638	651	1	1D
0005435957635	651	2	3C
0005435957640	651	3	3D
0005435957643	651	4	4B
0005433420271	651	5	5A
0005435957644	651	6	5B
0005433420270	651	7	6D
0005435957648	651	8	7A
0005433420294	651	9	7D
0005435957645	651	10	18D
0005435957636	651	11	20A
0005435957637	651	12	20B
0005435957647	651	13	20D
0005435957642	651	14	21A
0005435957646	651	15	22A
0005435957649	651	16	22B
0005435957639	651	17	22C
0005433420320	651	18	22D
0005435957641	651	19	23A
0005435957485	15198	1	1A
0005435957470	15198	2	1B
0005435957515	15198	3	1C
0005435957569	15198	4	1D
0005435957520	15198	5	2A
0005433420365	15198	6	3D
0005433420370	15198	7	4B
0005435957516	15198	8	4C
0005435957498	15198	9	4D
0005435957478	15198	10	5A
0005433420367	15198	11	5B
0005435957518	15198	12	6A
0005433420368	15198	13	6B
0005435957512	15198	14	6C
0005433420369	15198	15	6D
0005435957539	15198	16	7A
0005435957534	15198	17	7B
0005435957559	15198	18	7D
0005435957463	15198	19	18B
0005435957517	15198	20	18A
0005435957481	15198	21	18D
0005435957483	15198	22	18C
0005435957565	15198	23	19A
0005435957540	15198	24	19B
0005435957482	15198	25	19C
0005435957477	15198	26	19D
0005435957570	15198	27	20A
0005435957514	15198	28	20B
0005435957553	15198	29	20C
0005435957484	15198	30	20D
0005433420371	15198	31	21A
0005435957479	15198	32	21B
0005435957486	15198	33	21C
0005435957571	15198	34	22A
0005433420366	15198	35	22B
0005435957492	15198	36	22C
0005435957523	15198	37	22D
0005435957438	15198	38	23B
0005434247120	8950	1	1B
0005434247121	8950	2	5A
0005434247122	8950	3	5B
0005435629391	16020	1	1B
0005435629392	16020	2	3A
0005434247135	16020	3	3B
0005434247138	16020	4	4B
0005434247137	16020	5	5B
0005434247136	16020	6	6B
0005434096717	11828	1	2C
0005434096707	11828	2	4A
0005434096712	11828	3	5C
0005434096713	11828	4	6B
0005434096708	11828	5	7D
0005434096716	11828	6	18D
0005434096733	20165	1	3C
0005434096734	20165	2	7A
0005434096729	20165	3	18A
0005434096732	20165	4	19D
0005434096735	20165	5	20D
0005434096730	20165	6	21B
0005434096731	20165	7	21C
0005435229392	25111	1	1A
0005435229400	25111	2	1D
0005435229387	25111	3	1F
0005432645859	25111	4	2C
0005435229389	25111	5	3A
0005432645840	25111	6	3C
0005432645808	25111	7	3D
0005432645828	25111	8	4E
0005432645794	25111	9	4D
0005432645846	25111	10	4F
0005432645829	25111	11	5E
0005432645781	25111	12	6F
0005432645790	25111	13	7F
0005435229388	25111	14	8C
0005432645780	25111	15	8D
0005435229386	25111	16	8E
0005432645779	25111	17	8F
0005432645782	25111	18	9A
0005435229395	25111	19	9C
0005435229397	25111	20	9D
0005432645785	25111	21	9E
0005432645838	25111	22	9F
0005432645791	25111	23	10A
0005432645858	25111	24	10C
0005432645799	25111	25	10D
0005432645806	25111	26	11C
0005435229405	25111	27	11D
0005432645793	25111	28	11E
0005435229385	25111	29	11F
0005435229402	25111	30	12A
0005435229406	25111	31	12C
0005432645807	25111	32	12D
0005432645778	25111	33	12E
0005432645792	25111	34	12F
0005435229404	25111	35	13A
0005435229403	25111	36	13E
0005435229393	25111	37	13F
0005432645842	25111	38	14A
0005432645786	25111	39	14D
0005432645800	25111	40	14F
0005432645860	25111	41	15C
0005432645784	25111	42	15D
0005432645789	25111	43	15F
0005435229401	25111	44	16A
0005435229396	25111	45	16D
0005432645798	25111	46	16F
0005435229399	25111	47	17D
0005435229384	25111	48	18A
0005435229394	25111	49	18C
0005432645854	25111	50	18F
0005432645777	25111	51	19A
0005435229390	25111	52	19D
0005432645841	25111	53	19E
0005435229398	25111	54	20C
0005435229391	25111	55	20F
0005433404731	2831	1	1A
0005435797418	2831	2	2C
0005433404730	2831	3	2D
0005435797414	2831	4	4D
0005435797415	2831	5	5A
0005435797413	2831	6	5D
0005435797417	2831	7	6C
0005433404732	2831	8	6E
0005435797412	2831	9	6F
0005435797424	2831	10	7A
0005433404709	2831	11	9C
0005435797411	2831	12	10A
0005433404733	2831	13	10D
0005433404734	2831	14	11E
0005435797421	2831	15	12C
0005435797416	2831	16	13A
0005435797419	2831	17	13E
0005435797420	2831	18	14F
0005435797423	2831	19	16D
0005433404700	2831	20	18A
0005433404725	2831	21	18E
0005435797422	2831	22	20F
0005435797337	29340	1	1D
0005435797343	29340	2	2C
0005433404779	29340	3	2D
0005435797321	29340	4	3D
0005435797274	29340	5	3F
0005435797324	29340	6	4E
0005433404783	29340	7	4F
0005435797315	29340	8	6C
0005435797331	29340	9	6E
0005435797308	29340	10	7A
0005435797294	29340	11	7C
0005435797320	29340	12	7D
0005433404777	29340	13	8D
0005433404781	29340	14	8E
0005435797322	29340	15	10C
0005435797314	29340	16	11D
0005435797302	29340	17	11F
0005433404778	29340	18	12C
0005433404780	29340	19	12E
0005435797335	29340	20	13A
0005435797303	29340	21	13C
0005435797325	29340	22	14E
0005433404775	29340	23	15D
0005435797272	29340	24	17D
0005435797336	29340	25	17E
0005435797379	29340	26	18A
0005435797338	29340	27	18E
0005435797286	29340	28	18F
0005433404782	29340	29	19E
0005433404776	29340	30	19F
0005435797304	29340	31	20D
0005435797332	29340	32	20F
0005435376319	5824	1	4A
0005435376332	5824	2	4B
0005435376331	5824	3	6A
0005434947984	5821	1	1A
0005434947990	5821	2	1B
0005434947989	5821	3	2A
0005434947985	5821	4	2B
0005434947991	5821	5	4A
0005434947988	5821	6	4B
0005434947987	5821	7	5A
0005434947986	5821	8	5B
0005434947892	16377	1	1A
0005434947937	16377	2	2A
0005434947906	16377	3	1B
0005434947947	16377	4	3A
0005434947896	16377	5	2B
0005434947963	16377	6	4A
0005435376342	16377	7	3B
0005434947891	16377	8	4B
0005435376341	16377	9	5A
0005434947948	16377	10	5B
0005434947905	16377	11	6A
0005434947910	16377	12	6B
0005433960641	6948	1	1A
0005433960640	6948	2	1C
0005433960658	6948	3	1D
0005433960673	6948	4	1F
0005433960630	6948	5	2C
0005433960660	6948	6	2D
0005433960645	6948	7	3C
0005433960659	6948	8	4A
0005433960633	6948	9	4E
0005433960649	6948	10	4F
0005433960631	6948	11	5D
0005433960672	6948	12	5E
0005433960654	6948	13	5F
0005433960661	6948	14	6A
0005433960632	6948	15	6D
0005433960655	6948	16	6E
0005433960668	6948	17	7C
0005433960629	6948	18	7E
0005433960644	6948	19	8C
0005433960667	6948	20	8F
0005433960656	6948	21	10C
0005433960646	6948	22	10D
0005433960650	6948	23	10E
0005433960637	6948	24	10F
0005433960638	6948	25	11A
0005433960669	6948	26	11D
0005433960639	6948	27	11F
0005433960670	6948	28	12A
0005433960648	6948	29	12C
0005433960665	6948	30	12E
0005433960642	6948	31	12F
0005433960651	6948	32	13C
0005433960671	6948	33	14A
0005433960662	6948	34	14D
0005433960636	6948	35	14E
0005433960643	6948	36	15D
0005433960657	6948	37	15F
0005433960634	6948	38	16A
0005433960635	6948	39	17A
0005433960664	6948	40	17C
0005433960666	6948	41	17D
0005433960647	6948	42	17F
0005433960653	6948	43	19D
0005433960663	6948	44	19E
0005433960652	6948	45	20D
0005433960674	6948	46	20E
0005433959921	25718	1	1A
0005433960071	25718	2	1C
0005433959978	25718	3	1D
0005433959925	25718	4	2C
0005433960066	25718	5	2D
0005433959898	25718	6	3C
0005433959922	25718	7	4A
0005433959981	25718	8	4E
0005433960068	25718	9	4F
0005433959971	25718	10	5C
0005433959931	25718	11	5E
0005433959891	25718	12	6A
0005433960063	25718	13	6C
0005433960033	25718	14	6E
0005433959916	25718	15	6F
0005433959951	25718	16	7A
0005433959967	25718	17	7D
0005433960075	25718	18	7E
0005433960030	25718	19	7F
0005433960061	25718	20	8A
0005433960009	25718	21	8E
0005433960076	25718	22	9A
0005433960006	25718	23	9C
0005433960021	25718	24	9E
0005433959970	25718	25	9F
0005433959946	25718	26	11A
0005433960073	25718	27	11D
0005433960022	25718	28	11E
0005433959956	25718	29	12C
0005433959966	25718	30	12D
0005433960037	25718	31	13C
0005433960036	25718	32	13D
0005433960070	25718	33	13F
0005433959912	25718	34	14A
0005433960038	25718	35	14C
0005433960051	25718	36	15A
0005433959995	25718	37	15D
0005433959930	25718	38	16A
0005433959917	25718	39	16F
0005433959890	25718	40	17C
0005433960014	25718	41	17D
0005433959979	25718	42	17E
0005433959969	25718	43	18A
0005433959932	25718	44	18D
0005433960031	25718	45	18F
0005433959923	25718	46	19C
0005433960032	25718	47	19D
0005433959957	25718	48	19E
0005433960072	25718	49	19F
0005433959945	25718	50	20A
0005433960034	25718	51	20C
0005433960028	25718	52	20F
0005435082677	24541	1	1A
0005435082694	24541	2	2A
0005435082683	24541	3	1B
0005435082671	24541	4	2B
0005435082672	24541	5	3B
0005435082697	24541	6	4A
0005435082682	24541	7	5A
0005435082656	24541	8	5B
0005435082655	24541	9	6A
0005435082681	24541	10	6B
0005435082749	26155	1	1A
0005435082751	26155	2	2A
0005435082748	26155	3	2B
0005435082747	26155	4	3B
0005435082743	26155	5	4A
0005435082746	26155	6	4B
0005435082742	26155	7	5A
0005435082744	26155	8	5B
0005435082745	26155	9	6A
0005435082750	26155	10	6B
0005434244871	4990	1	1C
0005434244867	4990	2	1D
0005434244874	4990	3	2A
0005434244868	4990	4	4A
0005434244854	4990	5	4D
0005432166889	4990	6	5C
0005435286558	4990	7	5D
0005434244847	4990	8	6A
0005434244861	4990	9	6C
0005434244857	4990	10	7A
0005434244851	4990	11	8E
0005435286555	4990	12	10C
0005435286556	4990	13	11B
0005432166887	4990	14	11D
0005434244862	4990	15	12A
0005434244863	4990	16	12D
0005435286559	4990	17	12F
0005434244866	4990	18	14C
0005435286554	4990	19	15C
0005434244865	4990	20	16E
0005434244872	4990	21	16F
0005434244848	4990	22	17E
0005434244853	4990	23	17D
0005434244846	4990	24	19B
0005432166886	4990	25	20E
0005434244858	4990	26	21A
0005435286539	4990	27	21B
0005434244852	4990	28	21E
0005434244873	4990	29	22A
0005434244870	4990	30	22C
0005434244864	4990	31	22E
0005434244869	4990	32	26A
0005435286562	4990	33	25F
0005434244855	4990	34	26B
0005432166888	4990	35	28C
0005434244849	4990	36	28E
0005434244859	4990	37	29D
0005434244850	4990	38	29E
0005434244860	4990	39	30B
0005434244856	4990	40	30E
0005432105355	4989	1	1A
0005433784794	4989	2	1D
0005433784783	4989	3	1C
0005433614417	4989	4	1F
0005433614406	4989	5	2A
0005433614361	4989	6	2C
0005433614426	4989	7	2F
0005433614370	4989	8	2D
0005432666380	4989	9	3A
0005432105353	4989	10	3C
0005432105364	4989	11	3F
0005433614430	4989	12	3D
0005433614387	4989	13	4A
0005433614416	4989	14	4C
0005432105380	4989	15	4F
0005432105365	4989	16	4D
0005432105375	4989	17	5A
0005432667444	4989	18	5D
0005432105366	4989	19	5C
0005433614414	4989	20	5F
0005433614397	4989	21	6A
0005433614428	4989	22	6C
0005432105350	4989	23	6D
0005432105395	4989	24	7A
0005433614422	4989	25	6F
0005432105362	4989	26	7D
0005433614410	4989	27	7C
0005433614366	4989	28	7F
0005433784788	4989	29	8A
0005433614409	4989	30	8B
0005433614419	4989	31	8D
0005433784776	4989	32	8C
0005433614371	4989	33	8E
0005433614394	4989	34	9A
0005433614403	4989	35	8F
0005433784797	4989	36	9B
0005432666379	4989	37	9C
0005433784808	4989	38	9D
0005433614429	4989	39	9E
0005433784780	4989	40	10A
0005433614404	4989	41	9F
0005432105373	4989	42	10B
0005433614411	4989	43	10D
0005432105393	4989	44	10C
0005433614399	4989	45	10E
0005432105378	4989	46	11A
0005432105381	4989	47	10F
0005433614395	4989	48	11C
0005433614418	4989	49	11B
0005432105396	4989	50	11D
0005433614362	4989	51	11F
0005433614421	4989	52	11E
0005433614402	4989	53	12A
0005433614382	4989	54	12B
0005433784796	4989	55	12D
0005433784790	4989	56	12C
0005432665266	4989	57	12E
0005433784799	4989	58	12F
0005433784813	4989	59	13A
0005433784800	4989	60	13C
0005432105369	4989	61	13B
0005432105351	4989	62	13D
0005432105370	4989	63	13F
0005432105360	4989	64	13E
0005433614392	4989	65	14A
0005433614423	4989	66	14B
0005433614420	4989	67	14D
0005433784789	4989	68	14C
0005433614374	4989	69	14E
0005433784802	4989	70	14F
0005433614433	4989	71	15A
0005433784811	4989	72	15C
0005433614386	4989	73	15B
0005433614363	4989	74	15E
0005432665265	4989	75	15D
0005433614372	4989	76	15F
0005433614379	4989	77	16A
0005432105377	4989	78	16B
0005433784792	4989	79	16D
0005433614377	4989	80	16C
0005433614431	4989	81	16E
0005433784810	4989	82	16F
0005433614407	4989	83	17B
0005432667446	4989	84	17A
0005433784779	4989	85	17C
0005433614384	4989	86	17D
0005433614408	4989	87	17E
0005433614385	4989	88	18A
0005432105384	4989	89	17F
0005433614376	4989	90	18B
0005433614427	4989	91	18D
0005433614378	4989	92	18C
0005433614432	4989	93	18E
0005433614396	4989	94	18F
0005433614388	4989	95	19B
0005432667445	4989	96	19D
0005433614375	4989	97	19C
0005433784787	4989	98	20A
0005433614380	4989	99	19E
0005433784809	4989	100	20B
0005433614381	4989	101	20D
0005433784791	4989	102	20C
0005433784786	4989	103	20E
0005433614390	4989	104	20F
0005432105358	4989	105	21B
0005433784778	4989	106	21A
0005432105385	4989	107	21C
0005432105359	4989	108	21D
0005432105356	4989	109	21E
0005432105379	4989	110	21F
0005432105389	4989	111	22B
0005433614413	4989	112	22A
0005432105352	4989	113	22C
0005432105372	4989	114	22D
0005433784798	4989	115	22F
0005433784807	4989	116	22E
0005433784803	4989	117	23A
0005433614425	4989	118	23B
0005432105392	4989	119	23D
0005433784782	4989	120	23C
0005433614383	4989	121	23E
0005433784785	4989	122	24A
0005433614369	4989	123	23F
0005433614424	4989	124	24B
0005433784773	4989	125	24C
0005433614398	4989	126	24E
0005433784795	4989	127	24D
0005432105363	4989	128	24F
0005433614391	4989	129	25B
0005433614415	4989	130	25A
0005433784793	4989	131	25D
0005433614360	4989	132	25C
0005433784775	4989	133	25F
0005432105354	4989	134	25E
0005433614364	4989	135	26A
0005433614393	4989	136	26B
0005432105367	4989	137	26C
0005433784774	4989	138	26E
0005433614405	4989	139	26D
0005433614412	4989	140	26F
0005432105368	4989	141	27B
0005433784777	4989	142	27A
0005432105386	4989	143	27D
0005432105391	4989	144	27C
0005433614359	4989	145	27F
0005432105387	4989	146	27E
0005433784801	4989	147	28A
0005432105390	4989	148	28B
0005432105371	4989	149	28C
0005433614400	4989	150	28E
0005433784806	4989	151	28D
0005432105394	4989	152	28F
0005432105361	4989	153	29B
0005433614373	4989	154	29A
0005433614367	4989	155	29E
0005432105357	4989	156	29D
0005433784781	4989	157	29C
0005433614368	4989	158	30A
0005433784812	4989	159	29F
0005433784805	4989	160	30B
0005433614389	4989	161	30C
0005433784784	4989	162	30E
0005432105382	4989	163	30D
0005432105383	4989	164	30F
0005432105388	4989	165	31B
0005433784804	4989	166	31A
0005433614365	4989	167	31C
0005432105374	4989	168	31D
0005433614401	4989	169	31F
0005432105376	4989	170	31E
0005434229273	4987	1	1A
0005432335896	4987	2	2D
0005433815326	4987	3	3A
0005435269662	4987	4	3C
0005434149682	4987	5	3D
0005434229277	4987	6	4A
0005435269635	4987	7	4D
0005434173502	4987	8	4C
0005435006683	4987	9	5A
0005434149688	4987	10	5F
0005434265021	4987	11	6A
0005434173503	4987	12	6C
0005434229269	4987	13	6D
0005434229284	4987	14	7A
0005434265027	4987	15	6F
0005434265032	4987	16	7D
0005435269661	4987	17	7F
0005434265040	4987	18	8B
0005434265042	4987	19	8D
0005434265035	4987	20	8E
0005434229274	4987	21	8F
0005434149684	4987	22	9B
0005434265039	4987	23	9A
0005434229283	4987	24	9C
0005434311181	4987	25	9E
0005435006760	4987	26	10A
0005435269639	4987	27	10B
0005433815329	4987	28	10D
0005435269636	4987	29	10F
0005434265023	4987	30	11C
0005434229287	4987	31	11D
0005434265028	4987	32	11E
0005434265029	4987	33	12A
0005435269654	4987	34	11F
0005435006729	4987	35	12D
0005435006793	4987	36	12C
0005434229266	4987	37	12E
0005434229267	4987	38	13A
0005434229270	4987	39	12F
0005435006703	4987	40	13C
0005435006714	4987	41	13D
0005434229285	4987	42	13F
0005434173504	4987	43	13E
0005435006704	4987	44	14B
0005434265020	4987	45	14D
0005434149686	4987	46	14C
0005434149679	4987	47	14E
0005435006656	4987	48	15A
0005435269664	4987	49	14F
0005434265022	4987	50	15B
0005435269653	4987	51	15C
0005434265041	4987	52	15D
0005434265024	4987	53	15F
0005434229276	4987	54	16A
0005434265044	4987	55	16D
0005435006757	4987	56	16F
0005434265019	4987	57	17B
0005434149681	4987	58	17A
0005434265038	4987	59	17C
0005435006817	4987	60	17D
0005434229288	4987	61	17F
0005434265025	4987	62	17E
0005435269658	4987	63	18A
0005435006658	4987	64	18C
0005434265037	4987	65	18B
0005434229272	4987	66	19B
0005435006784	4987	67	19E
0005434265034	4987	68	20C
0005434229278	4987	69	20D
0005432335890	4987	70	20E
0005434265043	4987	71	21A
0005432335882	4987	72	21D
0005435269634	4987	73	21E
0005432335897	4987	74	21F
0005434229281	4987	75	22A
0005432335864	4987	76	22C
0005434229286	4987	77	22D
0005435269646	4987	78	23A
0005434149685	4987	79	23C
0005434229268	4987	80	23B
0005434173501	4987	81	23D
0005434229271	4987	82	23E
0005435269663	4987	83	24A
0005432335849	4987	84	24D
0005434265031	4987	85	24C
0005434149687	4987	86	24E
0005435269648	4987	87	25C
0005434149680	4987	88	25B
0005434173505	4987	89	25D
0005434312291	4987	90	25E
0005432335852	4987	91	26A
0005432335914	4987	92	25F
0005435269655	4987	93	26D
0005434229279	4987	94	26E
0005434149683	4987	95	27A
0005435006756	4987	96	27C
0005432335880	4987	97	27B
0005434265036	4987	98	27D
0005435006624	4987	99	27F
0005435006655	4987	100	27E
0005434265033	4987	101	28A
0005435269645	4987	102	28B
0005432335891	4987	103	29A
0005432335878	4987	104	28F
0005434265030	4987	105	29B
0005435269649	4987	106	29F
0005434149677	4987	107	30A
0005432335879	4987	108	30D
0005435006623	4987	109	30E
0005434149678	4987	110	30F
0005434229280	4987	111	31A
0005434229282	4987	112	31C
0005434265026	4987	113	31E
0005434229275	4987	114	31F
0005432659679	8400	1	1C
0005432659683	8400	2	1F
0005434244780	8400	3	2D
0005433784490	8400	4	2F
0005433784500	8400	5	3D
0005433784452	8400	6	4A
0005434244724	8400	7	4C
0005435269729	8400	8	4F
0005435269731	8400	9	5D
0005433784550	8400	10	6C
0005434244760	8400	11	6F
0005435269733	8400	12	8A
0005434244689	8400	13	7F
0005433784635	8400	14	8B
0005433784392	8400	15	8C
0005434244587	8400	16	8D
0005435269730	8400	17	8F
0005434244759	8400	18	9B
0005434244628	8400	19	9A
0005434244506	8400	20	9C
0005433784446	8400	21	9E
0005435269735	8400	22	11A
0005433784564	8400	23	11C
0005434244532	8400	24	12A
0005433784426	8400	25	12F
0005433784447	8400	26	13B
0005433784336	8400	27	13A
0005433784486	8400	28	13E
0005435269726	8400	29	13D
0005434244505	8400	30	14B
0005433784569	8400	31	14E
0005433784524	8400	32	14D
0005433784565	8400	33	15A
0005434244585	8400	34	14F
0005433784449	8400	35	15B
0005434244565	8400	36	16A
0005434244771	8400	37	16C
0005435269734	8400	38	17A
0005433784448	8400	39	17B
0005434244596	8400	40	17E
0005434244655	8400	41	18A
0005434244641	8400	42	17F
0005434244630	8400	43	18C
0005434244600	8400	44	19B
0005434244644	8400	45	18F
0005434244688	8400	46	18E
0005433784636	8400	47	19C
0005433784373	8400	48	19D
0005435269728	8400	49	20B
0005433784549	8400	50	20D
0005434244642	8400	51	21A
0005434244595	8400	52	21C
0005433784501	8400	53	21D
0005434244591	8400	54	22B
0005435269725	8400	55	23A
0005435269727	8400	56	23D
0005433784335	8400	57	23F
0005433784495	8400	58	23E
0005432659678	8400	59	24D
0005434244654	8400	60	24F
0005433784496	8400	61	25C
0005434244631	8400	62	25F
0005434244773	8400	63	26A
0005434244723	8400	64	26D
0005432659677	8400	65	26E
0005434244504	8400	66	27D
0005433784445	8400	67	28A
0005435269732	8400	68	27F
0005434244629	8400	69	28F
0005434244605	8400	70	29B
0005434244621	8400	71	29D
0005433784391	8400	72	29F
0005433784470	8400	73	29E
0005433784601	8400	74	30A
0005432659682	8400	75	30E
0005434244772	8400	76	30D
0005433784465	8400	77	30F
0005434244761	8400	78	31A
0005434244533	8400	79	31C
0005434244499	8400	80	31F
0005433613527	8401	1	1C
0005433613521	8401	2	1D
0005433613694	8401	3	2D
0005433613498	8401	4	3C
0005433613925	8401	5	4C
0005433613587	8401	6	5D
0005433613525	8401	7	5F
0005433613644	8401	8	6D
0005433613683	8401	9	7A
0005433613529	8401	10	8A
0005433613572	8401	11	7F
0005433613773	8401	12	8D
0005433613866	8401	13	8C
0005433613872	8401	14	8E
0005433613588	8401	15	9A
0005433613755	8401	16	9B
0005433613915	8401	17	10B
0005433613905	8401	18	10D
0005433613704	8401	19	10C
0005433613795	8401	20	10F
0005433613686	8401	21	11C
0005433613904	8401	22	11B
0005433613727	8401	23	11D
0005433613882	8401	24	11F
0005433613484	8401	25	11E
0005433613756	8401	26	12D
0005433613695	8401	27	12F
0005433613749	8401	28	13B
0005433613559	8401	29	13D
0005433613822	8401	30	14E
0005433613585	8401	31	14F
0005433613974	8401	32	15A
0005433613667	8401	33	15D
0005433613580	8401	34	16D
0005433613414	8401	35	16C
0005433613772	8401	36	17A
0005433613737	8401	37	18E
0005433613584	8401	38	19C
0005433613803	8401	39	19B
0005433613499	8401	40	19D
0005433613877	8401	41	19E
0005433613744	8401	42	20A
0005433613581	8401	43	21D
0005433613656	8401	44	21E
0005433613914	8401	45	22B
0005433613485	8401	46	22C
0005433613509	8401	47	22E
0005433613508	8401	48	23A
0005433613685	8401	49	22F
0005433613524	8401	50	23E
0005433613534	8401	51	24D
0005433613592	8401	52	24E
0005433613530	8401	53	25C
0005433613806	8401	54	25D
0005433613726	8401	55	26A
0005433613620	8401	56	27B
0005433613774	8401	57	28A
0005433613619	8401	58	29C
0005433613721	8401	59	29E
0005433613684	8401	60	29F
0005433613827	8401	61	31C
0005432335981	8402	1	1C
0005435006931	8402	2	1D
0005432034828	8402	3	2A
0005434173468	8402	4	1F
0005432034846	8402	5	2C
0005432047533	8402	6	2D
0005433690920	8402	7	3A
0005434149584	8402	8	3C
0005434149603	8402	9	3F
0005434229143	8402	10	3D
0005432034836	8402	11	4A
0005432034832	8402	12	4F
0005433815368	8402	13	4D
0005433815366	8402	14	5A
0005433815369	8402	15	5C
0005434149575	8402	16	5D
0005432335990	8402	17	6A
0005432034848	8402	18	6C
0005434149619	8402	19	6D
0005432034837	8402	20	7A
0005434264798	8402	21	6F
0005435006938	8402	22	7D
0005434229057	8402	23	7C
0005435006934	8402	24	7F
0005433690919	8402	25	8A
0005434149561	8402	26	8B
0005434264849	8402	27	8C
0005434149574	8402	28	8E
0005434229078	8402	29	8D
0005432335993	8402	30	9A
0005434264913	8402	31	8F
0005433815364	8402	32	9C
0005434149566	8402	33	9B
0005434229070	8402	34	9E
0005434229069	8402	35	9D
0005433689903	8402	36	10A
0005434229113	8402	37	10B
0005432034838	8402	38	10C
0005434264757	8402	39	10E
0005434264850	8402	40	10D
0005432034820	8402	41	10F
0005432335991	8402	42	11B
0005434173457	8402	43	11A
0005434264861	8402	44	11C
0005434311211	8402	45	11D
0005435006920	8402	46	11E
0005435006937	8402	47	12A
0005432034822	8402	48	11F
0005432335988	8402	49	12B
0005434264858	8402	50	12C
0005434149600	8402	51	12E
0005434264872	8402	52	12D
0005434149573	8402	53	12F
0005433534489	8402	54	13A
0005432034847	8402	55	13C
0005432335983	8402	56	13B
0005434264758	8402	57	13D
0005432335987	8402	58	13F
0005435006932	8402	59	13E
0005435006923	8402	60	14B
0005433815367	8402	61	14D
0005434229046	8402	62	14C
0005434229077	8402	63	14E
0005432034844	8402	64	14F
0005432034825	8402	65	15A
0005434228990	8402	66	15C
0005434149585	8402	67	15B
0005432034842	8402	68	15D
0005432034830	8402	69	15F
0005432034827	8402	70	15E
0005434264873	8402	71	16A
0005435006929	8402	72	16B
0005432034845	8402	73	16D
0005434173480	8402	74	16C
0005434264792	8402	75	16E
0005432034831	8402	76	17A
0005432335992	8402	77	17C
0005435006930	8402	78	17B
0005435006926	8402	79	17D
0005432034833	8402	80	17F
0005434229076	8402	81	17E
0005432034834	8402	82	18A
0005435006919	8402	83	18B
0005434229161	8402	84	18D
0005432034840	8402	85	18C
0005435006936	8402	86	18E
0005433690918	8402	87	19D
0005433688800	8402	88	19C
0005432034829	8402	89	19E
0005434229097	8402	90	20B
0005434229012	8402	91	20A
0005433689904	8402	92	20C
0005434229123	8402	93	20D
0005434264875	8402	94	20F
0005434229147	8402	95	21B
0005433690921	8402	96	21A
0005434229067	8402	97	21C
0005434311210	8402	98	21D
0005432335986	8402	99	21E
0005435006941	8402	100	21F
0005435006925	8402	101	22B
0005435006921	8402	102	22C
0005434264893	8402	103	22E
0005434173469	8402	104	22D
0005432034835	8402	105	22F
0005435006928	8402	106	23A
0005435006927	8402	107	23C
0005432335980	8402	108	23B
0005433690917	8402	109	23D
0005434264848	8402	110	23F
0005432034841	8402	111	23E
0005432034839	8402	112	24A
0005434264912	8402	113	24B
0005432047535	8402	114	24D
0005434149588	8402	115	24C
0005433688801	8402	116	24E
0005435006935	8402	117	24F
0005432034821	8402	118	25B
0005432034826	8402	119	25C
0005433815365	8402	120	25D
0005432047536	8402	121	25E
0005435006942	8402	122	26A
0005434229023	8402	123	25F
0005432335984	8402	124	26B
0005433534490	8402	125	26D
0005435006922	8402	126	26C
0005434264839	8402	127	26F
0005435006939	8402	128	27A
0005435006943	8402	129	27C
0005435006933	8402	130	27B
0005432034823	8402	131	27D
0005434264840	8402	132	27F
0005432034843	8402	133	27E
0005434149620	8402	134	28A
0005432034824	8402	135	28B
0005433689902	8402	136	28C
0005432335979	8402	137	28E
0005434264727	8402	138	28F
0005432335982	8402	139	29A
0005432047534	8402	140	29C
0005434229058	8402	141	29B
0005434264856	8402	142	29D
0005435006924	8402	143	29F
0005434264782	8402	144	29E
0005432335985	8402	145	30A
0005434264887	8402	146	30B
0005434264857	8402	147	30C
0005432034849	8402	148	30E
0005434229114	8402	149	30D
0005434264941	8402	150	31A
0005434228974	8402	151	31B
0005435006940	8402	152	31E
0005434229087	8402	153	31D
0005432335989	8402	154	31C
0005434638926	12600	1	1A
0005434638957	12600	2	1C
0005434639064	12600	3	1D
0005434639015	12600	4	2A
0005434639030	12600	5	2B
0005434638985	12600	6	2C
0005434638961	12600	7	2D
0005433202303	12600	8	3A
0005434639073	12600	9	3B
0005434638909	12600	10	3C
0005433202305	12600	11	3D
0005433202307	12600	12	4A
0005434639013	12600	13	4B
0005434638921	12600	14	4C
0005434639003	12600	15	4D
0005433202309	12600	16	5A
0005434638975	12600	17	5B
0005433202310	12600	18	5C
0005434638958	12600	19	5D
0005433202299	12600	20	6A
0005433202301	12600	21	6B
0005433202306	12600	22	6C
0005434638996	12600	23	6D
0005434638937	12600	24	7A
0005434639038	12600	25	7B
0005433202312	12600	26	7C
0005434638920	12600	27	7D
0005434639029	12600	28	18A
0005433202300	12600	29	18B
0005434638995	12600	30	18C
0005434638960	12600	31	18D
0005434638959	12600	32	19A
0005434639032	12600	33	19B
0005434638919	12600	34	19C
0005433202308	12600	35	19D
0005434638938	12600	36	20A
0005434638939	12600	37	20B
0005434639014	12600	38	20C
0005434638910	12600	39	20D
0005434638981	12600	40	21A
0005434638954	12600	41	21B
0005433202298	12600	42	21C
0005433202311	12600	43	21D
0005434638907	12600	44	22A
0005433202302	12600	45	22B
0005434639031	12600	46	22C
0005433202304	12600	47	22D
0005434639033	12600	48	23A
0005434639206	23358	1	1A
0005434639190	23358	2	1B
0005434639204	23358	3	1C
0005434639209	23358	4	1D
0005434639203	23358	5	2A
0005434639192	23358	6	2B
0005434639196	23358	7	2C
0005434639201	23358	8	2D
0005433202152	23358	9	3A
0005434639193	23358	10	3B
0005433202181	23358	11	3C
0005434639210	23358	12	3D
0005434639194	23358	13	4A
0005434639188	23358	14	4B
0005434639202	23358	15	4C
0005432290617	23358	16	4D
0005432290618	23358	17	5A
0005434639186	23358	18	5B
0005434639195	23358	19	5C
0005433202150	23358	20	6A
0005433202133	23358	21	6B
0005433202175	23358	22	6C
0005434639208	23358	23	6D
0005434639200	23358	24	7A
0005434639198	23358	25	7D
0005434639185	23358	26	18A
0005434639197	23358	27	18B
0005434639205	23358	28	18C
0005434639199	23358	29	19C
0005434639191	23358	30	19D
0005434639184	23358	31	20A
0005434639187	23358	32	20B
0005433202118	23358	33	20C
0005432290619	23358	34	20D
0005434639189	23358	35	21A
0005433202117	23358	36	21B
0005433202166	23358	37	21C
0005434639207	23358	38	21D
0005433202151	23358	39	22C
0005434639183	23358	40	23A
0005433202149	23358	41	23B
0005432328063	21052	1	1A
0005432328108	21052	2	1D
0005432327990	21052	3	1F
0005432327939	21052	4	2A
0005432328191	21052	5	2C
0005432382565	21052	6	2D
0005432328299	21052	7	2F
0005432328153	21052	8	3A
0005432382653	21052	9	3C
0005432382691	21052	10	3D
0005432328039	21052	11	3F
0005432382801	21052	12	4A
0005432054293	21052	13	4C
0005432327940	21052	14	4D
0005432382639	21052	15	4E
0005432328018	21052	16	4F
0005432327932	21052	17	5A
0005432328106	21052	18	5D
0005432382663	21052	19	5E
0005432327908	21052	20	5F
0005432328298	21052	21	6A
0005432327907	21052	22	6C
0005432382797	21052	23	6E
0005432328210	21052	24	7A
0005432328118	21052	25	6F
0005432382640	21052	26	7C
0005432328010	21052	27	7E
0005432328062	21052	28	7F
0005432327909	21052	29	8A
0005432328030	21052	30	8C
0005432328192	21052	31	8D
0005432382626	21052	32	8E
0005432328331	21052	33	8F
0005432382664	21052	34	9A
0005432328100	21052	35	9C
0005432328101	21052	36	9D
0005432328019	21052	37	9E
0005432328070	21052	38	9F
0005432327933	21052	39	10A
0005432382641	21052	40	10C
0005432382690	21052	41	10D
0005432382642	21052	42	10F
0005432382752	21052	43	11D
0005432328107	21052	44	11E
0005432328238	21052	45	11F
0005432382760	21052	46	12A
0005432382700	21052	47	12C
0005432382714	21052	48	12D
0005432327994	21052	49	12F
0005432382746	21052	50	13A
0005432328105	21052	51	13C
0005432328091	21052	52	13D
0005432382753	21052	53	13E
0005432328092	21052	54	13F
0005432382732	21052	55	14A
0005432382698	21052	56	14C
0005432328202	21052	57	14D
0005432328154	21052	58	14E
0005432328212	21052	59	14F
0005432328040	21052	60	15A
0005432382578	21052	61	15D
0005432328031	21052	62	15F
0005432328001	21052	63	16A
0005432328078	21052	64	16C
0005432382720	21052	65	16D
0005432327993	21052	66	16E
0005432327941	21052	67	16F
0005432327998	21052	68	17A
0005432327950	21052	69	17D
0005432382566	21052	70	17E
0005432382800	21052	71	17F
0005432328294	21052	72	18A
0005432382638	21052	73	18C
0005432328247	21052	74	18D
0005432328116	21052	75	18E
0005432328165	21052	76	18F
0005432327904	21052	77	19A
0005432328183	21052	78	19C
0005432328029	21052	79	19D
0005432054292	21052	80	19E
0005432328164	21052	81	19F
0005432328015	21052	82	20A
0005432382715	21052	83	20C
0005432382670	21052	84	20D
0005432328271	21052	85	20E
0005432382726	21052	86	20F
0005432382994	31240	1	1A
0005432382992	31240	2	1C
0005432328482	31240	3	1D
0005432328457	31240	4	1F
0005432383000	31240	5	2A
0005432328472	31240	6	2C
0005432328471	31240	7	2D
0005432328464	31240	8	2F
0005432328488	31240	9	3A
0005432328476	31240	10	3C
0005432382989	31240	11	3D
0005432383012	31240	12	3F
0005432383008	31240	13	4A
0005432328497	31240	14	4C
0005432287163	31240	15	4D
0005432328495	31240	16	4E
0005432287167	31240	17	4F
0005432382981	31240	18	5A
0005432328489	31240	19	5C
0005432383011	31240	20	5D
0005432383006	31240	21	5E
0005432382980	31240	22	5F
0005432382996	31240	23	6A
0005432382997	31240	24	6C
0005432382972	31240	25	6D
0005432383009	31240	26	6E
0005432382977	31240	27	6F
0005432328491	31240	28	7A
0005432382974	31240	29	7C
0005432328492	31240	30	7D
0005432328468	31240	31	7E
0005432328470	31240	32	7F
0005432382998	31240	33	8A
0005432328493	31240	34	8C
0005432287162	31240	35	8D
0005432287164	31240	36	8E
0005432382995	31240	37	8F
0005432382987	31240	38	9A
0005432328496	31240	39	9C
0005432328459	31240	40	9D
0005432328467	31240	41	9E
0005432328473	31240	42	9F
0005432382976	31240	43	10A
0005432382991	31240	44	10C
0005432383005	31240	45	10D
0005432328460	31240	46	10E
0005432328456	31240	47	10F
0005432328458	31240	48	11A
0005432328485	31240	49	11C
0005432382973	31240	50	11D
0005432382978	31240	51	11E
0005432287165	31240	52	11F
0005432382979	31240	53	12A
0005432382993	31240	54	12C
0005432383001	31240	55	12D
0005432328484	31240	56	12E
0005432328500	31240	57	12F
0005432382983	31240	58	13A
0005432328481	31240	59	13C
0005432287166	31240	60	13D
0005432383002	31240	61	13E
0005432328469	31240	62	13F
0005432383007	31240	63	14A
0005432328455	31240	64	14C
0005432328474	31240	65	14D
0005432383004	31240	66	14E
0005432328466	31240	67	14F
0005432382999	31240	68	15A
0005432382975	31240	69	15C
0005432382984	31240	70	15D
0005432328461	31240	71	15E
0005432328498	31240	72	15F
0005432328486	31240	73	16A
0005432383010	31240	74	16C
0005432328499	31240	75	16D
0005432328494	31240	76	16E
0005432328478	31240	77	16F
0005432328465	31240	78	17A
0005432328463	31240	79	17C
0005432382970	31240	80	17D
0005432382986	31240	81	17E
0005432382990	31240	82	17F
0005432328483	31240	83	18A
0005432328462	31240	84	18C
0005432328477	31240	85	18D
0005432328490	31240	86	18E
0005432328487	31240	87	18F
0005432382982	31240	88	19A
0005432382988	31240	89	19C
0005432328454	31240	90	19D
0005432382985	31240	91	19E
0005432328479	31240	92	19F
0005432382971	31240	93	20A
0005432383003	31240	94	20C
0005432328480	31240	95	20D
0005432328475	31240	96	20F
0005432382969	31240	97	20E
0005432953901	27590	1	1C
0005432953891	27590	2	1D
0005433642139	27590	3	1F
0005433642141	27590	4	2C
0005433642153	27590	5	3C
0005433642124	27590	6	3D
0005432953897	27590	7	3F
0005432953898	27590	8	4C
0005432953903	27590	9	5C
0005433642101	27590	10	6E
0005432953902	27590	11	7E
0005433642118	27590	12	8A
0005432953895	27590	13	8D
0005432953893	27590	14	9E
0005432953905	27590	15	10D
0005432953892	27590	16	10F
0005433642091	27590	17	11E
0005432953904	27590	18	12A
0005433642096	27590	19	12E
0005432953900	27590	20	13D
0005432953894	27590	21	13E
0005433642194	27590	22	13F
0005433642199	27590	23	15C
0005433642188	27590	24	15D
0005433642163	27590	25	15E
0005432953890	27590	26	15F
0005433642162	27590	27	16A
0005432953899	27590	28	16D
0005433642138	27590	29	17A
0005433642155	27590	30	17C
0005433642119	27590	31	18A
0005432953906	27590	32	18C
0005433642131	27590	33	18F
0005433642182	27590	34	19A
0005433642132	27590	35	19C
0005433642133	27590	36	19E
0005433642108	27590	37	20A
0005433642164	27590	38	20E
0005432953896	27590	39	20F
0005432424217	13285	1	1A
0005432424196	13285	2	1C
0005432424208	13285	3	1F
0005432424191	13285	4	2D
0005432424227	13285	5	3A
0005432424230	13285	6	3D
0005432424221	13285	7	4C
0005432424210	13285	8	5A
0005432424198	13285	9	5D
0005432424216	13285	10	5F
0005432424201	13285	11	6A
0005432424214	13285	12	6E
0005432424200	13285	13	8C
0005432424190	13285	14	8E
0005432424195	13285	15	9A
0005432424207	13285	16	9D
0005432424212	13285	17	9E
0005432424220	13285	18	10E
0005432424211	13285	19	10F
0005432424219	13285	20	11C
0005432424218	13285	21	11D
0005432424225	13285	22	11E
0005432424229	13285	23	12E
0005432424222	13285	24	12F
0005432424228	13285	25	13D
0005432424204	13285	26	14E
0005432424202	13285	27	15A
0005432424203	13285	28	15D
0005432424224	13285	29	15F
0005432424206	13285	30	16A
0005432424223	13285	31	16D
0005432424209	13285	32	16E
0005432424197	13285	33	17A
0005432424189	13285	34	17D
0005432424199	13285	35	17F
0005432424192	13285	36	18E
0005432424215	13285	37	18F
0005432424193	13285	38	19E
0005432424205	13285	39	19F
0005432424213	13285	40	20A
0005432424194	13285	41	20E
0005432424226	13285	42	20F
0005432423815	30816	1	1D
0005432423780	30816	2	2D
0005432423857	30816	3	2F
0005432423768	30816	4	3A
0005432423775	30816	5	3C
0005432423837	30816	6	3D
0005432423828	30816	7	3F
0005432423798	30816	8	4C
0005432423832	30816	9	4D
0005432423771	30816	10	4E
0005432423609	30816	11	4F
0005432423765	30816	12	5A
0005432423810	30816	13	5C
0005432423856	30816	14	5F
0005432423812	30816	15	6A
0005432423833	30816	16	6C
0005432423766	30816	17	6E
0005432423739	30816	18	7A
0005432423757	30816	19	7C
0005432423796	30816	20	7E
0005432423756	30816	21	8F
0005432423858	30816	22	9D
0005432423859	30816	23	9E
0005432423696	30816	24	9F
0005432423787	30816	25	10E
0005432423727	30816	26	11C
0005432423767	30816	27	12A
0005432423711	30816	28	12D
0005432423786	30816	29	12E
0005432423785	30816	30	13D
0005432423776	30816	31	13E
0005432423853	30816	32	13F
0005432423647	30816	33	14A
0005432423781	30816	34	14C
0005432423838	30816	35	14E
0005432423795	30816	36	14F
0005432423716	30816	37	16A
0005432423811	30816	38	17A
0005432423734	30816	39	17C
0005432423728	30816	40	17E
0005432423608	30816	41	17F
0005432423612	30816	42	18A
0005432423670	30816	43	18C
0005432423642	30816	44	18E
0005432423836	30816	45	18F
0005432423618	30816	46	19C
0005432423713	30816	47	19F
0005432423712	30816	48	20D
0005432817334	9602	1	1A
0005434157357	9602	2	1C
0005432817332	9602	3	1D
0005432817348	9602	4	1F
0005432817355	9602	5	2A
0005432817346	9602	6	2C
0005432817344	9602	7	3A
0005432901401	9602	8	3C
0005432817335	9602	9	3D
0005432817339	9602	10	3F
0005432901331	9602	11	4C
0005432817362	9602	12	4D
0005432822171	9602	13	4E
0005432901414	9602	14	5A
0005434448302	9602	15	5C
0005432901391	9602	16	5D
0005432817352	9602	17	6A
0005432817347	9602	18	6C
0005434448300	9602	19	6D
0005432901412	9602	20	6F
0005432817340	9602	21	7A
0005432817357	9602	22	7C
0005432901315	9602	23	7D
0005432288971	9602	24	7E
0005432817345	9602	25	8A
0005432822173	9602	26	8C
0005432817333	9602	27	8D
0005434448301	9602	28	8E
0005434448303	9602	29	8F
0005432822169	9602	30	9A
0005432817356	9602	31	9C
0005432817350	9602	32	9D
0005432822172	9602	33	9E
0005432817361	9602	34	9F
0005432817338	9602	35	10A
0005432901376	9602	36	10C
0005432817341	9602	37	10D
0005432817337	9602	38	10E
0005432901342	9602	39	10F
0005434186167	9602	40	11A
0005434157422	9602	41	11C
0005432901332	9602	42	11E
0005432817360	9602	43	11F
0005432822170	9602	44	12A
0005434186165	9602	45	12C
0005432288973	9602	46	12F
0005432817359	9602	47	13D
0005432817353	9602	48	13F
0005432817342	9602	49	14A
0005432817336	9602	50	14C
0005432901413	9602	51	14E
0005432901348	9602	52	14F
0005432288972	9602	53	15A
0005432901367	9602	54	15C
0005432817351	9602	55	15D
0005432822175	9602	56	15F
0005434186166	9602	57	16A
0005432901399	9602	58	16E
0005432822168	9602	59	16F
0005434157421	9602	60	17A
0005432817343	9602	61	17C
0005432822174	9602	62	17D
0005432901368	9602	63	17E
0005432901349	9602	64	17F
0005432901387	9602	65	18E
0005432817358	9602	66	19A
0005432817354	9602	67	19C
0005432901408	9602	68	19D
0005432901347	9602	69	19F
0005432822167	9602	70	20A
0005432817349	9602	71	20C
0005432901459	9602	72	20D
0005434448299	9602	73	20E
0005432901400	9602	74	20F
0005434186186	28976	1	1A
0005432901532	28976	2	1C
0005432901530	28976	3	1D
0005434186184	28976	4	2A
0005432817045	28976	5	2C
0005432822120	28976	6	2D
0005434157444	28976	7	2F
0005432901542	28976	8	3A
0005432002067	28976	9	3F
0005432817083	28976	10	4A
0005434448267	28976	11	4D
0005432901545	28976	12	4E
0005434157448	28976	13	4F
0005434157450	28976	14	5D
0005434448272	28976	15	5E
0005432822067	28976	16	5F
0005432901540	28976	17	6A
0005432817135	28976	18	6C
0005432817146	28976	19	6D
0005432901535	28976	20	6E
0005434157451	28976	21	6F
0005434157445	28976	22	7D
0005432002066	28976	23	7F
0005432901531	28976	24	8A
0005432817109	28976	25	8C
0005432822110	28976	26	8E
0005434186185	28976	27	8F
0005432901534	28976	28	9C
0005432822119	28976	29	9E
0005432817039	28976	30	9F
0005432901529	28976	31	10A
0005432822109	28976	32	10C
0005434157443	28976	33	10D
0005434157447	28976	34	10E
0005432817032	28976	35	10F
0005432901538	28976	36	11A
0005432901537	28976	37	11C
0005434186183	28976	38	11D
0005432817024	28976	39	11E
0005432817013	28976	40	11F
0005434448281	28976	41	12A
0005432817012	28976	42	12C
0005432901533	28976	43	12E
0005432901527	28976	44	12F
0005432817081	28976	45	13A
0005432817038	28976	46	13F
0005432817112	28976	47	14A
0005432901541	28976	48	14C
0005432817154	28976	49	15A
0005432901539	28976	50	15C
0005432817058	28976	51	15D
0005432817120	28976	52	15E
0005432817082	28976	53	15F
0005432817031	28976	54	16A
0005434157449	28976	55	16C
0005432817134	28976	56	16E
0005432901543	28976	57	16F
0005432822117	28976	58	17A
0005432817118	28976	59	17D
0005432901544	28976	60	17E
0005432817030	28976	61	17F
0005432816957	28976	62	18A
0005432817161	28976	63	18C
0005432822118	28976	64	18D
0005432817162	28976	65	18E
0005432901536	28976	66	19A
0005432817153	28976	67	19C
0005432817046	28976	68	19E
0005432901528	28976	69	19F
0005432817025	28976	70	20A
0005434448269	28976	71	20C
0005434157446	28976	72	20D
0005432816965	28976	73	20E
0005432817100	28976	74	20F
0005435841813	15127	1	1B
0005432611694	15127	2	2A
0005432611693	15127	3	2B
0005432613846	15127	4	3A
0005432613845	15127	5	4A
0005432613844	15127	6	4B
0005432611695	15127	7	6A
0005435841082	15127	8	6B
0005432611675	31580	1	1A
0005432611658	31580	2	1B
0005432611666	31580	3	2B
0005435842325	31580	4	3A
0005432607522	31580	5	4B
0005432611665	31580	6	5A
0005432611642	31580	7	5B
0005432611652	31580	8	6B
0005432947905	11864	1	1C
0005432947889	11864	2	1A
0005433568741	11864	3	1F
0005432947807	11864	4	1D
0005432947991	11864	5	2C
0005433568793	11864	6	2A
0005433568759	11864	7	2D
0005433568785	11864	8	3A
0005433568757	11864	9	2F
0005432947890	11864	10	3D
0005432947966	11864	11	3C
0005432947806	11864	12	3F
0005433568800	11864	13	4C
0005432947805	11864	14	4A
0005433568781	11864	15	4F
0005433568762	11864	16	5C
0005433568792	11864	17	5A
0005433568791	11864	18	5F
0005433568775	11864	19	5D
0005433568801	11864	20	6B
0005433568753	11864	21	6A
0005432947790	11864	22	6C
0005433568774	11864	23	6F
0005433568787	11864	24	6E
0005433568796	11864	25	6D
0005433568773	11864	26	7A
0005432948001	11864	27	7C
0005432947860	11864	28	7D
0005433568764	11864	29	8A
0005432947913	11864	30	7F
0005433568778	11864	31	8B
0005433568747	11864	32	8D
0005433568763	11864	33	8C
0005433568788	11864	34	8F
0005432947906	11864	35	8E
0005433568766	11864	36	9B
0005432947791	11864	37	9A
0005433568771	11864	38	9C
0005433568744	11864	39	9E
0005433568795	11864	40	9D
0005433568752	11864	41	10A
0005433568740	11864	42	9F
0005433568749	11864	43	10C
0005432948025	11864	44	10B
0005433568765	11864	45	10D
0005433568742	11864	46	10F
0005432947984	11864	47	10E
0005433568746	11864	48	11A
0005433568782	11864	49	11D
0005432947880	11864	50	11C
0005432948102	11864	51	11F
0005433568777	11864	52	11E
0005433568738	11864	53	12B
0005432947914	11864	54	12A
0005433568798	11864	55	12C
0005433568784	11864	56	12E
0005433568769	11864	57	12D
0005432947933	11864	58	13A
0005433568750	11864	59	12F
0005433568783	11864	60	13C
0005432947949	11864	61	13B
0005433568799	11864	62	13E
0005432947879	11864	63	14A
0005432947891	11864	64	13F
0005432947928	11864	65	14C
0005433568743	11864	66	14B
0005432947957	11864	67	14D
0005432948024	11864	68	14F
0005432947983	11864	69	14E
0005432947990	11864	70	15A
0005432947959	11864	71	15C
0005433568760	11864	72	15E
0005433568794	11864	73	15D
0005432947930	11864	74	16A
0005432948055	11864	75	15F
0005433568776	11864	76	16C
0005433568789	11864	77	16B
0005433568755	11864	78	16D
0005432948023	11864	79	16F
0005432947861	11864	80	16E
0005432948026	11864	81	17C
0005432947948	11864	82	17B
0005433568767	11864	83	17A
0005433568802	11864	84	17D
0005432948004	11864	85	17F
0005432947851	11864	86	17E
0005433568779	11864	87	18A
0005433568786	11864	88	18C
0005433568768	11864	89	18B
0005433568751	11864	90	18F
0005432947886	11864	91	18E
0005432947958	11864	92	18D
0005433568761	11864	93	19C
0005433568772	11864	94	19B
0005432947878	11864	95	19E
0005433568748	11864	96	19D
0005433568739	11864	97	19F
0005433568758	11864	98	20C
0005432947778	11864	99	20B
0005433568797	11864	100	20A
0005432947967	11864	101	20D
0005433568790	11864	102	20F
0005433568754	11864	103	20E
0005433568745	11864	104	21B
0005433568780	11864	105	21A
0005432947852	11864	106	21C
0005433568756	11864	107	21E
0005433568770	11864	108	21F
0005433568197	25279	1	1C
0005432948321	25279	2	1A
0005433568284	25279	3	1F
0005433568348	25279	4	1D
0005433568195	25279	5	2C
0005432948327	25279	6	2A
0005432948329	25279	7	2D
0005433568143	25279	8	3A
0005433568126	25279	9	2F
0005433568201	25279	10	3C
0005432948333	25279	11	4A
0005433568020	25279	12	3F
0005433568056	25279	13	3D
0005432948312	25279	14	4C
0005432948324	25279	15	5A
0005433568109	25279	16	4F
0005432948320	25279	17	4D
0005433568313	25279	18	5F
0005433568288	25279	19	5D
0005433568165	25279	20	6B
0005433568252	25279	21	6A
0005432948341	25279	22	6D
0005433568341	25279	23	6C
0005433568231	25279	24	6F
0005432948328	25279	25	6E
0005432948309	25279	26	7B
0005432948314	25279	27	7A
0005432948330	25279	28	7C
0005433568123	25279	29	7E
0005432948306	25279	30	7D
0005433568295	25279	31	7F
0005432948343	25279	32	8C
0005433568312	25279	33	8B
0005433568240	25279	34	8A
0005433568210	25279	35	8D
0005433568202	25279	36	8F
0005433568236	25279	37	8E
0005432948337	25279	38	9A
0005433568142	25279	39	9D
0005433568093	25279	40	9C
0005433568360	25279	41	9B
0005433568358	25279	42	9F
0005433568270	25279	43	9E
0005432948338	25279	44	10A
0005433568092	25279	45	10C
0005433568280	25279	46	10B
0005432948322	25279	47	10E
0005433568294	25279	48	10D
0005433568355	25279	49	11A
0005433568293	25279	50	10F
0005433568199	25279	51	11B
0005433568261	25279	52	11D
0005433568091	25279	53	11C
0005432948325	25279	54	11F
0005432948319	25279	55	11E
0005432948313	25279	56	12B
0005433568251	25279	57	12A
0005433568122	25279	58	12D
0005433568286	25279	59	12C
0005433568036	25279	60	12F
0005432948340	25279	61	13A
0005433568196	25279	62	13C
0005433568296	25279	63	13B
0005433568342	25279	64	13E
0005433568305	25279	65	13D
0005432948318	25279	66	13F
0005433568131	25279	67	14C
0005432948317	25279	68	14B
0005433568361	25279	69	14A
0005432948307	25279	70	14E
0005433568110	25279	71	14D
0005432948342	25279	72	14F
0005432948323	25279	73	15B
0005433568230	25279	74	15A
0005433568289	25279	75	15D
0005433568205	25279	76	15C
0005432948315	25279	77	15F
0005433568259	25279	78	15E
0005432948344	25279	79	16A
0005432948345	25279	80	16B
0005433568237	25279	81	16E
0005433568130	25279	82	16D
0005432948316	25279	83	16F
0005433568250	25279	84	17D
0005433568287	25279	85	17F
0005432948331	25279	86	17E
0005432948335	25279	87	18A
0005432948308	25279	88	18C
0005433568283	25279	89	18E
0005432948332	25279	90	18D
0005433568075	25279	91	19A
0005433568211	25279	92	18F
0005432948346	25279	93	19D
0005432948326	25279	94	19C
0005433568304	25279	95	19F
0005433568035	25279	96	19E
0005432948311	25279	97	20B
0005433568249	25279	98	20A
0005433568260	25279	99	20C
0005433568200	25279	100	20F
0005433568314	25279	101	20E
0005432948310	25279	102	20D
0005432948334	25279	103	21A
0005432948336	25279	104	21C
0005432948339	25279	105	21B
0005433568285	25279	106	21F
0005432948305	25279	107	21E
0005433568074	25279	108	21D
0005434654561	5405	1	1A
0005434656547	5405	2	1D
0005434654558	5405	3	2A
0005435340055	5405	4	2C
0005434654566	5405	5	2D
0005434654576	5405	6	2F
0005435555355	5405	7	3A
0005435555354	5405	8	3C
0005434654548	5405	9	3D
0005434654549	5405	10	5C
0005434654560	5405	11	5E
0005434654575	5405	12	6D
0005434654557	5405	13	6E
0005434654555	5405	14	8A
0005435340064	5405	15	8E
0005434656548	5405	16	9A
0005435340139	5405	17	9C
0005434654550	5405	18	9E
0005434654551	5405	19	10C
0005434654564	5405	20	10E
0005434654554	5405	21	11A
0005434654569	5405	22	11D
0005432114190	5405	23	11E
0005432114188	5405	24	12A
0005434654573	5405	25	13C
0005435340068	5405	26	13E
0005434654570	5405	27	14A
0005434654572	5405	28	14D
0005434654563	5405	29	14F
0005435340067	5405	30	15C
0005435340138	5405	31	15D
0005434654553	5405	32	16A
0005434654556	5405	33	16D
0005434654567	5405	34	16E
0005434654559	5405	35	17D
0005434654562	5405	36	17E
0005434654552	5405	37	18C
0005432114189	5405	38	18D
0005435340069	5405	39	18E
0005434654571	5405	40	19D
0005434654574	5405	41	19E
0005434654568	5405	42	20A
0005434654565	5405	43	20E
0005434654577	5405	44	20F
0005435555362	12549	1	1A
0005435340195	12549	2	1C
0005434654291	12549	3	1F
0005434654292	12549	4	2F
0005434654371	12549	5	3A
0005434654326	12549	6	3C
0005434654252	12549	7	4C
0005435340193	12549	8	4D
0005435340206	12549	9	5C
0005435340200	12549	10	6A
0005435340196	12549	11	6C
0005434654424	12549	12	6E
0005434654317	12549	13	7A
0005435340197	12549	14	8C
0005434656537	12549	15	8E
0005435340192	12549	16	9D
0005434654224	12549	17	11C
0005434656536	12549	18	11D
0005434654295	12549	19	11F
0005434654336	12549	20	12A
0005434654300	12549	21	12E
0005434654423	12549	22	12F
0005435340205	12549	23	13A
0005434656526	12549	24	13D
0005434654318	12549	25	13E
0005434654421	12549	26	14A
0005434654372	12549	27	14C
0005434656535	12549	28	15E
0005435340202	12549	29	15F
0005434654253	12549	30	16A
0005435340204	12549	31	16D
0005434654299	12549	32	16E
0005434654306	12549	33	16F
0005435340194	12549	34	17E
0005434654321	12549	35	18E
0005435340201	12549	36	18F
0005435340199	12549	37	19C
0005434656534	12549	38	19E
0005435340203	12549	39	20A
0005434654223	12549	40	20D
0005435340198	12549	41	20E
0005434654322	12549	42	20F
0005433715753	7450	1	1C
0005433715731	7450	2	1A
0005433715743	7450	3	1D
0005433715749	7450	4	2C
0005433715771	7450	5	2A
0005433715736	7450	6	2F
0005433715770	7450	7	3C
0005433689901	7450	8	3A
0005432428878	7450	9	3F
0005433722194	7450	10	4A
0005433656654	7450	11	4D
0005433715740	7450	12	4C
0005433715776	7450	13	4E
0005433715780	7450	14	4F
0005433715759	7450	15	5B
0005433722189	7450	16	5A
0005432078084	7450	17	5E
0005433688798	7450	18	6A
0005433715765	7450	19	6D
0005433722188	7450	20	6F
0005433715778	7450	21	6E
0005432078087	7450	22	7B
0005433715750	7450	23	7A
0005433715752	7450	24	7F
0005433715739	7450	25	7E
0005433719125	7450	26	8A
0005433722191	7450	27	8B
0005433715755	7450	28	8C
0005433715763	7450	29	8E
0005433715741	7450	30	9B
0005433715745	7450	31	9D
0005433715769	7450	32	9F
0005433715781	7450	33	9E
0005432428875	7450	34	10B
0005433722193	7450	35	10D
0005433715737	7450	36	10C
0005433722190	7450	37	10E
0005433719124	7450	38	11A
0005433715775	7450	39	11B
0005433715746	7450	40	11E
0005433722192	7450	41	11D
0005433719126	7450	42	11F
0005432078086	7450	43	12B
0005433715777	7450	44	12D
0005432428885	7450	45	12C
0005432078082	7450	46	12F
0005433715767	7450	47	13B
0005433715747	7450	48	13D
0005433715760	7450	49	13E
0005433715748	7450	50	14A
0005433715762	7450	51	14C
0005433715738	7450	52	14B
0005433715757	7450	53	14D
0005432428867	7450	54	15A
0005433715732	7450	55	14F
0005433656653	7450	56	15C
0005433722196	7450	57	15F
0005432428877	7450	58	16B
0005433688799	7450	59	16C
0005433715766	7450	60	16E
0005433722195	7450	61	17A
0005433715754	7450	62	17B
0005433715751	7450	63	17C
0005433719123	7450	64	17E
0005432428887	7450	65	17F
0005433715768	7450	66	18A
0005433715764	7450	67	18D
0005432078088	7450	68	18E
0005432078083	7450	69	19C
0005433715779	7450	70	19E
0005433715758	7450	71	19F
0005433715772	7450	72	20A
0005433722187	7450	73	20C
0005432078085	7450	74	20B
0005433715744	7450	75	20D
0005433715742	7450	76	20E
0005432428876	7450	77	20F
0005433715774	7450	78	21A
0005433715773	7450	79	21B
0005433719122	7450	80	21D
0005433715761	7450	81	21F
0005433715733	7450	82	22A
0005433715735	7450	83	22C
0005433656655	7450	84	23A
0005432428886	7450	85	23C
0005433689900	7450	86	23B
0005433715756	7450	87	23E
0005433715734	7450	88	23D
0005433715506	29244	1	1A
0005432428913	29244	2	1D
0005433722114	29244	3	2A
0005433715385	29244	4	2C
0005433719093	29244	5	2D
0005433715357	29244	6	2F
0005433715475	29244	7	3C
0005433715263	29244	8	4A
0005433715265	29244	9	4D
0005433715289	29244	10	4C
0005433715505	29244	11	5E
0005433715360	29244	12	5F
0005433656622	29244	13	6B
0005433719094	29244	14	6A
0005433715284	29244	15	6C
0005433715228	29244	16	6E
0005433715320	29244	17	7B
0005433715308	29244	18	7A
0005433715504	29244	19	7C
0005433715368	29244	20	7D
0005433715381	29244	21	8A
0005433715361	29244	22	7F
0005433719110	29244	23	8B
0005433715276	29244	24	8C
0005433715543	29244	25	8D
0005433719109	29244	26	8E
0005433719092	29244	27	9B
0005433715316	29244	28	9E
0005433715397	29244	29	9D
0005433715373	29244	30	10B
0005433715312	29244	31	10C
0005433715248	29244	32	11B
0005435266135	29244	33	11D
0005433715157	29244	34	11E
0005433719084	29244	35	11F
0005433715507	29244	36	12C
0005433715384	29244	37	12D
0005433715216	29244	38	12E
0005433715101	29244	39	12F
0005433715440	29244	40	13A
0005433715401	29244	41	13B
0005433715285	29244	42	13D
0005433715302	29244	43	13E
0005433722113	29244	44	14D
0005433715300	29244	45	14E
0005433715560	29244	46	14F
0005433715100	29244	47	15D
0005435266134	29244	48	15E
0005433715472	29244	49	16A
0005433715473	29244	50	15F
0005433715321	29244	51	16D
0005432006748	29244	52	16F
0005433715494	29244	53	16E
0005433715337	29244	54	17B
0005433715231	29244	55	17A
0005433715356	29244	56	17C
0005433719108	29244	57	17E
0005432006747	29244	58	18E
0005433715451	29244	59	18D
0005433715374	29244	60	18F
0005433715362	29244	61	19B
0005433715386	29244	62	19C
0005433715359	29244	63	19E
0005432428914	29244	64	19D
0005433715476	29244	65	19F
0005433715303	29244	66	20D
0005432428915	29244	67	20C
0005433715301	29244	68	21D
0005432006749	29244	69	21F
0005433722108	29244	70	22C
0005433715264	29244	71	23B
0005433715295	29244	72	23A
0005433715375	29244	73	23E
0005433719103	29244	74	23F
0005434095218	8660	1	1C
0005434095221	8660	2	4C
0005434182055	8660	3	5C
0005434095220	8660	4	5E
0005434182001	8660	5	5F
0005434095213	8660	6	6D
0005434182040	8660	7	7C
0005434182017	8660	8	7F
0005434095208	8660	9	8A
0005434095219	8660	10	9E
0005434184642	8660	11	10D
0005434182087	8660	12	10E
0005434095209	8660	13	12F
0005434182045	8660	14	13A
0005434095216	8660	15	13C
0005434095217	8660	16	14F
0005434184649	8660	17	15D
0005434182039	8660	18	15F
0005434095212	8660	19	17E
0005434182038	8660	20	18D
0005434095210	8660	21	18E
0005434182056	8660	22	18F
0005434095211	8660	23	19A
0005434184641	8660	24	19F
0005434095214	8660	25	20C
0005434095215	8660	26	20D
0005434095207	8660	27	20E
0005434182125	11650	1	1A
0005434182134	11650	2	1C
0005434182136	11650	3	2C
0005434183568	11650	4	3A
0005434182124	11650	5	3F
0005434183570	11650	6	4A
0005434182128	11650	7	4E
0005434182129	11650	8	5C
0005434095067	11650	9	5E
0005434143708	11650	10	6E
0005434095131	11650	11	6F
0005434095076	11650	12	7A
0005434095110	11650	13	7D
0005434183569	11650	14	8A
0005434184655	11650	15	8F
0005434326084	11650	16	9A
0005434095115	11650	17	9F
0005434095085	11650	18	10E
0005434095116	11650	19	10F
0005434143709	11650	20	11A
0005434095096	11650	21	11E
0005434184654	11650	22	11F
0005434095075	11650	23	12A
0005434182127	11650	24	12F
0005434182126	11650	25	13E
0005434095140	11650	26	13F
0005434182131	11650	27	14A
0005434182133	11650	28	14F
0005434182132	11650	29	15F
0005434182130	11650	30	16A
0005434095111	11650	31	16F
0005434095095	11650	32	17E
0005434095139	11650	33	17F
0005434095066	11650	34	18A
0005434095144	11650	35	18C
0005434095132	11650	36	18D
0005434182135	11650	37	18E
0005434143699	11650	38	19A
0005434095046	11650	39	19D
0005434143700	11650	40	20A
0005435732286	1469	1	1A
0005435732291	1469	2	1D
0005435732287	1469	3	1F
0005433397476	1469	4	2A
0005433397189	1469	5	2C
0005433397372	1469	6	2F
0005433397336	1469	7	3A
0005433397455	1469	8	3C
0005433397446	1469	9	3F
0005433397394	1469	10	4A
0005435732290	1469	11	4C
0005433397422	1469	12	4D
0005433397517	1469	13	4F
0005433397507	1469	14	5A
0005435732289	1469	15	5C
0005433397487	1469	16	5D
0005435732288	1469	17	5E
0005433397573	1469	18	5F
0005433397343	1469	19	6A
0005433397382	1469	20	6C
0005435732283	1469	21	6D
0005433397518	1469	22	6E
0005435732285	1469	23	6F
0005433456953	1469	24	7C
0005433397414	1469	25	7E
0005433397421	1469	26	7F
0005435732284	1469	27	8A
0005433397370	1469	28	8D
0005433397501	1469	29	8E
0005433456952	1469	30	8F
0005433397309	1469	31	9A
0005433397416	1469	32	9C
0005433397506	1469	33	9E
0005432906505	1469	34	9F
0005435732292	1469	35	10A
0005433397238	1469	36	10C
0005432906506	1469	37	10D
0005433397415	1469	38	10F
0005433397241	1469	39	11A
0005432297266	1469	40	11C
0005433397368	1469	41	11F
0005433397338	1469	42	12A
0005433397395	1469	43	12D
0005433397324	1469	44	13C
0005433397371	1469	45	13D
0005432906494	1469	46	13E
0005433397550	1469	47	14A
0005433397441	1469	48	14C
0005432297265	1469	49	14D
0005433397426	1469	50	14E
0005433397474	1469	51	14F
0005433397427	1469	52	15A
0005433397445	1469	53	15C
0005433397565	1469	54	15E
0005433397369	1469	55	15F
0005435732282	1469	56	16A
0005433397268	1469	57	16D
0005433397242	1469	58	16E
0005432297267	1469	59	17C
0005433397485	1469	60	17F
0005433397428	1469	61	18A
0005433397502	1469	62	18D
0005433397373	1469	63	18E
0005432906493	1469	64	18F
0005433397334	1469	65	19A
0005433397335	1469	66	19C
0005433397562	1469	67	19F
0005433397267	1469	68	20A
0005433397593	1469	69	20C
0005433397339	1469	70	20E
0005433397359	1469	71	20F
0005433397829	19266	1	1C
0005433397834	19266	2	2A
0005433456907	19266	3	2C
0005433397841	19266	4	2D
0005435732165	19266	5	3A
0005433397827	19266	6	3D
0005435732256	19266	7	3F
0005433397842	19266	8	4C
0005433397868	19266	9	4D
0005435732255	19266	10	4E
0005435732164	19266	11	4F
0005433397860	19266	12	5A
0005433397843	19266	13	5C
0005433397832	19266	14	5E
0005435732133	19266	15	5F
0005433397854	19266	16	6A
0005433397866	19266	17	6C
0005433397863	19266	18	6E
0005435732204	19266	19	6F
0005433397867	19266	20	7A
0005433397870	19266	21	7C
0005433397845	19266	22	7D
0005435732155	19266	23	7E
0005433397850	19266	24	8C
0005433397861	19266	25	8E
0005433397833	19266	26	8F
0005435732187	19266	27	9A
0005433397848	19266	28	9C
0005433397851	19266	29	9E
0005433397856	19266	30	9F
0005432906524	19266	31	10A
0005433397859	19266	32	10C
0005433397831	19266	33	10D
0005432906525	19266	34	10E
0005433397864	19266	35	10F
0005433397838	19266	36	11A
0005433397835	19266	37	11D
0005433397862	19266	38	11E
0005433397852	19266	39	11F
0005432906526	19266	40	12C
0005433397869	19266	41	12F
0005435732175	19266	42	13A
0005433397844	19266	43	13C
0005435732177	19266	44	13E
0005433397865	19266	45	13F
0005433397828	19266	46	14A
0005433397836	19266	47	14C
0005433397846	19266	48	14F
0005433397873	19266	49	15A
0005433397837	19266	50	15C
0005435732119	19266	51	15D
0005433397853	19266	52	15E
0005433397830	19266	53	16A
0005433397855	19266	54	16D
0005433397840	19266	55	16E
0005433397826	19266	56	17C
0005435732176	19266	57	17D
0005433456908	19266	58	17E
0005433397847	19266	59	17F
0005435732171	19266	60	18A
0005433397839	19266	61	18C
0005435732170	19266	62	18F
0005433397872	19266	63	19C
0005433397849	19266	64	19D
0005435732178	19266	65	19E
0005433397857	19266	66	20A
0005433397871	19266	67	20C
0005435732129	19266	68	20D
0005433397858	19266	69	20E
0005434443462	17358	1	1A
0005434443492	17358	2	1D
0005434443506	17358	3	2B
0005434443494	17358	4	3B
0005434443537	17358	5	3C
0005434443526	17358	6	4D
0005434443480	17358	7	5B
0005434443501	17358	8	5C
0005434443519	17358	9	5D
0005434443507	17358	10	6A
0005434443466	17358	11	6B
0005434443426	17358	12	6D
0005434443533	17358	13	18A
0005434443493	17358	14	18B
0005434443534	17358	15	19A
0005434443441	17358	16	18D
0005434443505	17358	17	19C
0005434443474	17358	18	20A
0005434443535	17358	19	21B
0005434443465	17358	20	21C
0005434443485	17358	21	22A
0005434443427	17358	22	22C
0005434443468	17358	23	22D
0005434443448	17358	24	23A
0005434443626	20571	1	1A
0005434443634	20571	2	1C
0005434443633	20571	3	2D
0005434443637	20571	4	3A
0005434443629	20571	5	3B
0005434443632	20571	6	3D
0005434443623	20571	7	4C
0005434443630	20571	8	4D
0005434443624	20571	9	5D
0005434443636	20571	10	6A
0005434443628	20571	11	7C
0005434443622	20571	12	20A
0005434443625	20571	13	21C
0005434443631	20571	14	21D
0005434443635	20571	15	22C
0005434443627	20571	16	23A
0005434954591	7244	1	1B
0005435377559	7244	2	2A
0005434954592	7244	3	2B
0005435377558	7244	4	3B
0005435377557	7244	5	4A
0005434954590	7244	6	4B
0005434954593	7244	7	6A
0005435377560	7244	8	6B
0005434954558	28351	1	1A
0005434954544	28351	2	2A
0005434954556	28351	3	2B
0005435377570	28351	4	3A
0005434954557	28351	5	4A
0005435377571	28351	6	4B
0005434954545	28351	7	5A
0005434954568	28351	8	5B
0005434954551	28351	9	6A
0005434351643	4482	1	1D
0005434351639	4482	2	2C
0005434351640	4482	3	3A
0005434351637	4482	4	3B
0005434351638	4482	5	3D
0005434326269	4482	6	4C
0005434351645	4482	7	5B
0005434351644	4482	8	5D
0005434183551	4482	9	6B
0005434351636	4482	10	7A
0005434183559	4482	11	7B
0005435893558	4482	12	18B
0005434183552	4482	13	19B
0005434351641	4482	14	20B
0005434351642	4482	15	20D
0005434183558	4482	16	21B
0005434351646	4482	17	22D
0005434351635	4482	18	23A
0005435893602	29658	1	1A
0005434351494	29658	2	1B
0005435893598	29658	3	1D
0005435893601	29658	4	2C
0005435893597	29658	5	3A
0005434351483	29658	6	3B
0005434351478	29658	7	4A
0005434351513	29658	8	7A
0005434351530	29658	9	7B
0005435893600	29658	10	18B
0005434351529	29658	11	18C
0005435893603	29658	12	19A
0005435893599	29658	13	21A
0005434351567	29658	14	21B
0005434351527	29658	15	21C
0005434351545	29658	16	22B
0005435893604	29658	17	22C
0005434351603	29658	18	23A
0005434351604	29658	19	23B
0005433341624	1051	1	1A
0005433342309	1051	2	1C
0005435545710	1051	3	1B
0005435092034	1051	4	1G
0005433341426	1051	5	2B
0005435545711	1051	6	2F
0005433341888	1051	7	2H
0005433342172	1051	8	2G
0005433342177	1051	9	3B
0005433342101	1051	10	3F
0005433341767	1051	11	3G
0005433341728	1051	12	4A
0005433341742	1051	13	4C
0005433342179	1051	14	4G
0005433463892	1051	15	4F
0005433341582	1051	16	4H
0005433342054	1051	17	5A
0005433462738	1051	18	5F
0005433341817	1051	19	5H
0005433341986	1051	20	5G
0005435092028	1051	21	9B
0005433269627	1051	22	11A
0005433341446	1051	23	9H
0005433341489	1051	24	11B
0005433341747	1051	25	11E
0005435092033	1051	26	11D
0005433341632	1051	27	11H
0005433341788	1051	28	12A
0005435545712	1051	29	12D
0005433341849	1051	30	12B
0005433341685	1051	31	12E
0005433341729	1051	32	12F
0005433341726	1051	33	12G
0005435545697	1051	34	13B
0005433341686	1051	35	13A
0005435092035	1051	36	13D
0005433342251	1051	37	13G
0005435545709	1051	38	13F
0005433158096	1051	39	13H
0005433341757	1051	40	14A
0005435092032	1051	41	14D
0005433159276	1051	42	14G
0005433463891	1051	43	15A
0005433341701	1051	44	14H
0005433342189	1051	45	15D
0005435545714	1051	46	15B
0005435545713	1051	47	15E
0005435545700	1051	48	15F
0005432293197	1051	49	15H
0005433342021	1051	50	15G
0005433342072	1051	51	16D
0005433342188	1051	52	16E
0005433341816	1051	53	16G
0005433341844	1051	54	16F
0005433341821	1051	55	17B
0005433341741	1051	56	17D
0005433462736	1051	57	17G
0005433342019	1051	58	18D
0005434445239	1051	59	18E
0005433269643	1051	60	18H
0005433341965	1051	61	18G
0005435545701	1051	62	19A
0005433341572	1051	63	19D
0005433463890	1051	64	19E
0005433341755	1051	65	19F
0005433341581	1051	66	19G
0005433158104	1051	67	20A
0005433341843	1051	68	20D
0005433462737	1051	69	20E
0005435545699	1051	70	20G
0005433341813	1051	71	20F
0005433342337	1051	72	20H
0005435092029	1051	73	21D
0005433342018	1051	74	21B
0005432293198	1051	75	21E
0005433341752	1051	76	21G
0005435545706	1051	77	21F
0005433341390	1051	78	22B
0005433462739	1051	79	22A
0005433342176	1051	80	22E
0005433341766	1051	81	22G
0005433341805	1051	82	23B
0005433269664	1051	83	23F
0005433341675	1051	84	23G
0005433341754	1051	85	23H
0005433269651	1051	86	24B
0005433341447	1051	87	24E
0005433341845	1051	88	24F
0005433341455	1051	89	25D
0005433341389	1051	90	25F
0005435545702	1051	91	27B
0005433342062	1051	92	27D
0005433158105	1051	93	27F
0005435545698	1051	94	28A
0005433342178	1051	95	27H
0005433342017	1051	96	28D
0005435545703	1051	97	28F
0005433341631	1051	98	29F
0005433342250	1051	99	29E
0005433341765	1051	100	29G
0005433341981	1051	101	30D
0005435545704	1051	102	30B
0005433342099	1051	103	30F
0005433341625	1051	104	30G
0005435545707	1051	105	31A
0005433341427	1051	106	31F
0005433342053	1051	107	31E
0005435092030	1051	108	32B
0005433342138	1051	109	32D
0005433342045	1051	110	32F
0005433341413	1051	111	32H
0005433158098	1051	112	32G
0005434445238	1051	113	33A
0005433341966	1051	114	33E
0005433341842	1051	115	33F
0005433341535	1051	116	33H
0005435092031	1051	117	33G
0005433341873	1051	118	34D
0005433341748	1051	119	34E
0005433341655	1051	120	34G
0005433341751	1051	121	35B
0005433341998	1051	122	35A
0005433341623	1051	123	35D
0005433341862	1051	124	35E
0005433341727	1051	125	36A
0005433341490	1051	126	36D
0005432293199	1051	127	36F
0005433158097	1051	128	36G
0005433341949	1051	129	37A
0005433342275	1051	130	37D
0005433341612	1051	131	37F
0005435545705	1051	132	37H
0005433159275	1051	133	37G
0005433342173	1051	134	38A
0005433342044	1051	135	38D
0005433341995	1051	136	38E
0005433341789	1051	137	38G
0005433342182	1051	138	38F
0005435545708	1051	139	38H
0005433341548	1051	140	39E
0005433342617	17050	1	1A
0005433342644	17050	2	1B
0005433342663	17050	3	1F
0005433342648	17050	4	1G
0005433342687	17050	5	2A
0005433342613	17050	6	1H
0005435091950	17050	7	2B
0005433342658	17050	8	2C
0005433342627	17050	9	2G
0005435092010	17050	10	3A
0005434445216	17050	11	2H
0005433342645	17050	12	3F
0005435508190	17050	13	3C
0005433342699	17050	14	3G
0005435091928	17050	15	3H
0005433342700	17050	16	4B
0005433342683	17050	17	4A
0005433342608	17050	18	4C
0005433342649	17050	19	4F
0005433342656	17050	20	4H
0005433342688	17050	21	5F
0005433342684	17050	22	5H
0005435091956	17050	23	9B
0005435508186	17050	24	9A
0005433159303	17050	25	11D
0005433342654	17050	26	11F
0005433342660	17050	27	11G
0005435508176	17050	28	12A
0005433342650	17050	29	12F
0005433342606	17050	30	12H
0005433342599	17050	31	13F
0005435508166	17050	32	13E
0005433342651	17050	33	13G
0005433342652	17050	34	14E
0005433342677	17050	35	14H
0005433342647	17050	36	15E
0005433342653	17050	37	15F
0005433342690	17050	38	15G
0005433342661	17050	39	16B
0005433342625	17050	40	16A
0005433342633	17050	41	16D
0005433342635	17050	42	16H
0005433342665	17050	43	17B
0005433342675	17050	44	17E
0005433269696	17050	45	17F
0005435508220	17050	46	17H
0005433342697	17050	47	18B
0005435508175	17050	48	18A
0005433342671	17050	49	18E
0005435508189	17050	50	18D
0005433342676	17050	51	18F
0005433342618	17050	52	18G
0005433342696	17050	53	18H
0005433342668	17050	54	19D
0005435091948	17050	55	19G
0005433342686	17050	56	19H
0005433342634	17050	57	20A
0005433342692	17050	58	20B
0005433342695	17050	59	20E
0005433342642	17050	60	20D
0005433342637	17050	61	20F
0005433342680	17050	62	20H
0005433342631	17050	63	20G
0005435508204	17050	64	21B
0005433342612	17050	65	21F
0005433342674	17050	66	21G
0005433342609	17050	67	22A
0005433342640	17050	68	22B
0005435091975	17050	69	23A
0005433342639	17050	70	22H
0005435091954	17050	71	23B
0005433342630	17050	72	23D
0005435508218	17050	73	23E
0005433342615	17050	74	23H
0005433342628	17050	75	23G
0005433342636	17050	76	24D
0005433159301	17050	77	24B
0005433342605	17050	78	24F
0005433342669	17050	79	24E
0005433342664	17050	80	24G
0005433342600	17050	81	25D
0005433342620	17050	82	25E
0005433342679	17050	83	27A
0005433342622	17050	84	27D
0005433342604	17050	85	27F
0005433342685	17050	86	27E
0005433342667	17050	87	28A
0005433269692	17050	88	28B
0005433342646	17050	89	28D
0005433342657	17050	90	28F
0005433342694	17050	91	28H
0005433342655	17050	92	29A
0005433342629	17050	93	29D
0005433269697	17050	94	29B
0005433342603	17050	95	29F
0005435508217	17050	96	29H
0005433342643	17050	97	30F
0005433342616	17050	98	30E
0005433342701	17050	99	30H
0005433269694	17050	100	31B
0005433342682	17050	101	31D
0005433342623	17050	102	31G
0005433342698	17050	103	31H
0005433342641	17050	104	32B
0005433342610	17050	105	32G
0005435091986	17050	106	32F
0005433269695	17050	107	32E
0005435091923	17050	108	32H
0005433342621	17050	109	33A
0005433342611	17050	110	33B
0005433342689	17050	111	33E
0005433342662	17050	112	33F
0005433342601	17050	113	33H
0005433269693	17050	114	34B
0005435508177	17050	115	34A
0005433342678	17050	116	34D
0005433342638	17050	117	34F
0005433342672	17050	118	34G
0005435091982	17050	119	35A
0005433342659	17050	120	35D
0005433342666	17050	121	36B
0005433342681	17050	122	36D
0005433342614	17050	123	36H
0005433342607	17050	124	36F
0005433342632	17050	125	37A
0005433342626	17050	126	37F
0005433342602	17050	127	37H
0005433342619	17050	128	37G
0005433342693	17050	129	38E
0005435091922	17050	130	38D
0005433342624	17050	131	38G
0005435092011	17050	132	38F
0005433159302	17050	133	38H
0005433342673	17050	134	39E
0005433342670	17050	135	39D
0005433342691	17050	136	39F
0005432390098	1335	1	1C
0005432851825	1335	2	1A
0005432390094	1335	3	1D
0005432391982	1335	4	2A
0005432851820	1335	5	2D
0005432390066	1335	6	3A
0005432391977	1335	7	3D
0005432390091	1335	8	3C
0005432390055	1335	9	4A
0005432390089	1335	10	3F
0005432390064	1335	11	4D
0005432851837	1335	12	4C
0005432391980	1335	13	4F
0005432390072	1335	14	5C
0005432390062	1335	15	5D
0005432390057	1335	16	6B
0005432390061	1335	17	6A
0005432390084	1335	18	6C
0005432851823	1335	19	6E
0005432390060	1335	20	7B
0005432390073	1335	21	7E
0005432851828	1335	22	7D
0005432390068	1335	23	7F
0005432390080	1335	24	8B
0005432851835	1335	25	8E
0005432390077	1335	26	8D
0005432391973	1335	27	8C
0005432390090	1335	28	8F
0005432390096	1335	29	9A
0005432390075	1335	30	9E
0005432391976	1335	31	9D
0005432390069	1335	32	10E
0005432391975	1335	33	11A
0005432390092	1335	34	11C
0005432851838	1335	35	11D
0005432390058	1335	36	12A
0005432390070	1335	37	12D
0005432390076	1335	38	12C
0005432390056	1335	39	12B
0005432390081	1335	40	12E
0005432851821	1335	41	13A
0005432391978	1335	42	13C
0005432391985	1335	43	13B
0005432390088	1335	44	13D
0005432390065	1335	45	13F
0005432391974	1335	46	14C
0005432390078	1335	47	14D
0005432390085	1335	48	14F
0005432390052	1335	49	14E
0005432390053	1335	50	15C
0005432390097	1335	51	15E
0005432390082	1335	52	16A
0005432391984	1335	53	15F
0005432390059	1335	54	16D
0005432390067	1335	55	17A
0005432391981	1335	56	17D
0005432391979	1335	57	17C
0005432390083	1335	58	17E
0005432390074	1335	59	18B
0005432851826	1335	60	18E
0005432851827	1335	61	19A
0005432390063	1335	62	18F
0005432390093	1335	63	19E
0005432851816	1335	64	19F
0005432391983	1335	65	20B
0005432390087	1335	66	20C
0005432390071	1335	67	20E
0005432390086	1335	68	20F
0005432390054	1335	69	21D
0005432390079	1335	70	21C
0005432851836	1335	71	21B
0005432851829	1335	72	21F
0005432390095	1335	73	21E
0005432159839	12768	1	1A
0005434066488	12768	2	1C
0005434081565	12768	3	1D
0005434066397	12768	4	1F
0005434081471	12768	5	2C
0005434066602	12768	6	2A
0005434066625	12768	7	3A
0005434066629	12768	8	2F
0005433989718	12768	9	3C
0005434081580	12768	10	3D
0005434066478	12768	11	3F
0005434066551	12768	12	4A
0005434081642	12768	13	4B
0005432433658	12768	14	4D
0005434066803	12768	15	4C
0005433989707	12768	16	4E
0005434066720	12768	17	4F
0005434066554	12768	18	5B
0005434066483	12768	19	5A
0005434066905	12768	20	5C
0005434066768	12768	21	5D
0005434066735	12768	22	5F
0005434066687	12768	23	5E
0005434081648	12768	24	6A
0005434081576	12768	25	6B
0005434066558	12768	26	6D
0005434066587	12768	27	6C
0005434066839	12768	28	6E
0005433989695	12768	29	7A
0005434066747	12768	30	6F
0005434066568	12768	31	7B
0005434066993	12768	32	7C
0005434081578	12768	33	7D
0005434081581	12768	34	7F
0005434081610	12768	35	7E
0005434066863	12768	36	8A
0005434066490	12768	37	8B
0005434066992	12768	38	8D
0005434066563	12768	39	8F
0005434066703	12768	40	8E
0005434066552	12768	41	9A
0005434066566	12768	42	9B
0005434081631	12768	43	9C
0005434066788	12768	44	9E
0005432433654	12768	45	9D
0005434081504	12768	46	9F
0005434066595	12768	47	10C
0005434066640	12768	48	10B
0005432159840	12768	49	10D
0005434066704	12768	50	10E
0005433989706	12768	51	11C
0005433812890	12768	52	11E
0005434066922	12768	53	11D
0005433812891	12768	54	11F
0005434066428	12768	55	12A
0005434066787	12768	56	12B
0005434066877	12768	57	12C
0005434066592	12768	58	12E
0005434066546	12768	59	12D
0005432433655	12768	60	12F
0005433989716	12768	61	13B
0005432433656	12768	62	13A
0005434066607	12768	63	13C
0005434066686	12768	64	14A
0005433989696	12768	65	13F
0005434066596	12768	66	14C
0005434081577	12768	67	14D
0005432433657	12768	68	14F
0005434066923	12768	69	14E
0005432159837	12768	70	15B
0005432161142	12768	71	15C
0005434066512	12768	72	15E
0005432159838	12768	73	15D
0005434081564	12768	74	16A
0005434066326	12768	75	15F
0005433989705	12768	76	16B
0005434066470	12768	77	16C
0005434081590	12768	78	16D
0005434066668	12768	79	16F
0005434066586	12768	80	16E
0005434066876	12768	81	17A
0005434066480	12768	82	17B
0005434066533	12768	83	17D
0005433989692	12768	84	17C
0005434066657	12768	85	17E
0005432161143	12768	86	18A
0005433989698	12768	87	18B
0005434066532	12768	88	18F
0005434066513	12768	89	18E
0005434066688	12768	90	19C
0005434081619	12768	91	19B
0005434081553	12768	92	19E
0005434066904	12768	93	19D
0005434066760	12768	94	19F
0005434066527	12768	95	20A
0005434066705	12768	96	20B
0005434026679	12768	97	20E
0005434066694	12768	98	20D
0005434066539	12768	99	20F
0005434066638	12768	100	21B
0005434066802	12768	101	21A
0005433989717	12768	102	21C
0005434026680	12768	103	21D
0005434081632	12768	104	21F
0005434066669	12768	105	22A
0005434066639	12768	106	22C
0005434081518	12768	107	22B
0005434066547	12768	108	22D
0005433989708	12768	109	23A
0005434066594	12768	110	22F
0005434066482	12768	111	23B
0005434066481	12768	112	23C
0005434066603	12768	113	23E
0005434066567	12768	114	23D
0005434066462	12768	115	23F
0005434067215	30668	1	1A
0005434067225	30668	2	1C
0005434067174	30668	3	1D
0005434081759	30668	4	1F
0005433989748	30668	5	2C
0005434067194	30668	6	2A
0005434081781	30668	7	2D
0005434067230	30668	8	3A
0005434081774	30668	9	2F
0005433989744	30668	10	3C
0005434067200	30668	11	3F
0005433989745	30668	12	3D
0005434081786	30668	13	4A
0005434081777	30668	14	4C
0005434067216	30668	15	4B
0005434067218	30668	16	4D
0005434067212	30668	17	4E
0005434081778	30668	18	5A
0005434081773	30668	19	4F
0005434067211	30668	20	5C
0005434067208	30668	21	5B
0005434067213	30668	22	5D
0005434067228	30668	23	5E
0005434067227	30668	24	5F
0005434067204	30668	25	6B
0005434067199	30668	26	6A
0005434081769	30668	27	6C
0005434067226	30668	28	6E
0005434067179	30668	29	6D
0005434067206	30668	30	6F
0005434067203	30668	31	7B
0005434067168	30668	32	7A
0005432150153	30668	33	7C
0005434067201	30668	34	7E
0005434067178	30668	35	7D
0005434067185	30668	36	7F
0005434067170	30668	37	8A
0005434081768	30668	38	8B
0005434067177	30668	39	8C
0005434081776	30668	40	8E
0005434081760	30668	41	8D
0005434067197	30668	42	8F
0005434067237	30668	43	9A
0005434067173	30668	44	9B
0005434081771	30668	45	9C
0005434081763	30668	46	9D
0005432186851	30668	47	9F
0005432150158	30668	48	9E
0005434081788	30668	49	10B
0005434067176	30668	50	10C
0005434081783	30668	51	10E
0005434067222	30668	52	10D
0005432433598	30668	53	11A
0005434067183	30668	54	11C
0005434067229	30668	55	11E
0005434067223	30668	56	11D
0005434067232	30668	57	11F
0005434067192	30668	58	12A
0005432150151	30668	59	12B
0005432433627	30668	60	12D
0005434067180	30668	61	12C
0005434067195	30668	62	12E
0005434067217	30668	63	12F
0005432186849	30668	64	13A
0005433989746	30668	65	13C
0005434067214	30668	66	13B
0005434081780	30668	67	13D
0005434081765	30668	68	13E
0005434067220	30668	69	14A
0005432433603	30668	70	13F
0005434067172	30668	71	14B
0005432150152	30668	72	14C
0005432150157	30668	73	14D
0005434067182	30668	74	14E
0005434067235	30668	75	15A
0005434081779	30668	76	14F
0005434067209	30668	77	15B
0005434067236	30668	78	15E
0005434081785	30668	79	15D
0005434067167	30668	80	15C
0005434067190	30668	81	15F
0005434067233	30668	82	16A
0005432433609	30668	83	16B
0005434067169	30668	84	16C
0005434067184	30668	85	16D
0005434067171	30668	86	16E
0005434067186	30668	87	17A
0005434081761	30668	88	16F
0005434067198	30668	89	17B
0005434067224	30668	90	17D
0005434067188	30668	91	17C
0005434081782	30668	92	17F
0005434081784	30668	93	17E
0005434081787	30668	94	18A
0005432150150	30668	95	18B
0005434081766	30668	96	18C
0005434067207	30668	97	18E
0005434067191	30668	98	18D
0005432433604	30668	99	18F
0005434081762	30668	100	19A
0005434067205	30668	101	19C
0005434067210	30668	102	19B
0005432150154	30668	103	19D
0005434067221	30668	104	19F
0005434081775	30668	105	19E
0005434067187	30668	106	20B
0005434081764	30668	107	20A
0005433989747	30668	108	20D
0005434067193	30668	109	20E
0005434067231	30668	110	20F
0005434067189	30668	111	21A
0005432186850	30668	112	21C
0005432433610	30668	113	21B
0005434067238	30668	114	21D
0005434067181	30668	115	21E
0005434081772	30668	116	21F
0005434067196	30668	117	22B
0005434067234	30668	118	22A
0005432186848	30668	119	22C
0005434081767	30668	120	22D
0005434067202	30668	121	22E
0005432150155	30668	122	23A
0005434067219	30668	123	22F
0005433989749	30668	124	23B
0005432150156	30668	125	23C
0005434081789	30668	126	23E
0005434081770	30668	127	23D
0005434067175	30668	128	23F
0005433687701	9042	1	1A
0005433685517	9042	2	1C
0005433685519	9042	3	2B
0005433686627	9042	4	2D
0005433685520	9042	5	3B
0005433687700	9042	6	3D
0005433685515	9042	7	4B
0005433686626	9042	8	5A
0005433687698	9042	9	5B
0005433687702	9042	10	6B
0005433685518	9042	11	18A
0005433687703	9042	12	18D
0005433686630	9042	13	19B
0005433687699	9042	14	20B
0005433687697	9042	15	20C
0005433685516	9042	16	21B
0005433686625	9042	17	21C
0005433686629	9042	18	21D
0005433686628	9042	19	23B
0005435765948	5527	1	1A
0005435765966	5527	2	1B
0005435765941	5527	3	1F
0005435461887	5527	4	1H
0005435722044	5527	5	1G
0005435765998	5527	6	2A
0005435462002	5527	7	3C
0005435765955	5527	8	4A
0005435765975	5527	9	3H
0005433529261	5527	10	4B
0005435765960	5527	11	4C
0005432140410	5527	12	4H
0005433527252	5527	13	4F
0005435765967	5527	14	5B
0005435461861	5527	15	5A
0005435765940	5527	16	5F
0005434264731	5527	17	5C
0005435765997	5527	18	5G
0005435765969	5527	19	9B
0005435765956	5527	20	11B
0005435765953	5527	21	11A
0005435766003	5527	22	11E
0005435765972	5527	23	12A
0005435765943	5527	24	12D
0005432535768	5527	25	12E
0005435735117	5527	26	12F
0005434264698	5527	27	12G
0005432140409	5527	28	13A
0005435765976	5527	29	13D
0005433529264	5527	30	13G
0005432140413	5527	31	14A
0005435723036	5527	32	13H
0005435462081	5527	33	14B
0005435765989	5527	34	14D
0005434264710	5527	35	15A
0005435617167	5527	36	15E
0005435765994	5527	37	15F
0005435765985	5527	38	15H
0005434264834	5527	39	15G
0005435765987	5527	40	16E
0005435765963	5527	41	16G
0005432140415	5527	42	16H
0005435765978	5527	43	17B
0005435766001	5527	44	17A
0005434264871	5527	45	17G
0005435765999	5527	46	17F
0005434264729	5527	47	18A
0005435765993	5527	48	17H
0005435765958	5527	49	18D
0005435765996	5527	50	18E
0005432535769	5527	51	18G
0005432535745	5527	52	19D
0005435725573	5527	53	19E
0005434264821	5527	54	19F
0005435765974	5527	55	20A
0005435725577	5527	56	20E
0005435765990	5527	57	20D
0005435725575	5527	58	20F
0005435725576	5527	59	20H
0005434264721	5527	60	20G
0005434264783	5527	61	21A
0005435765947	5527	62	21D
0005435617166	5527	63	21E
0005435617168	5527	64	21F
0005435723035	5527	65	21H
0005433527253	5527	66	22A
0005434264784	5527	67	22D
0005434264801	5527	68	22E
0005435461889	5527	69	22G
0005435735118	5527	70	22F
0005435765984	5527	71	22H
0005435765944	5527	72	23E
0005434831071	5527	73	23D
0005435765979	5527	74	23F
0005435462030	5527	75	23H
0005432140411	5527	76	23G
0005435461883	5527	77	24B
0005435765991	5527	78	24F
0005435765992	5527	79	24E
0005435765980	5527	80	25D
0005435766007	5527	81	24H
0005435765986	5527	82	25E
0005435722045	5527	83	27A
0005435765970	5527	84	25F
0005435725574	5527	85	27B
0005434264730	5527	86	27H
0005435766006	5527	87	27G
0005435765965	5527	88	28A
0005435765973	5527	89	28B
0005435461975	5527	90	28E
0005435461936	5527	91	28F
0005435765949	5527	92	29A
0005435765961	5527	93	28H
0005435461812	5527	94	29D
0005435461873	5527	95	29G
0005435462009	5527	96	29F
0005435766002	5527	97	29H
0005434264745	5527	98	30B
0005434264776	5527	99	30A
0005433529263	5527	100	30D
0005435765982	5527	101	30F
0005435765959	5527	102	30G
0005435765981	5527	103	31A
0005435765942	5527	104	30H
0005435766004	5527	105	31E
0005435766000	5527	106	31H
0005435765954	5527	107	32A
0005435765945	5527	108	32D
0005435461972	5527	109	32B
0005435461833	5527	110	32E
0005435461860	5527	111	32G
0005435765964	5527	112	32H
0005434264785	5527	113	33B
0005435462008	5527	114	33D
0005435461969	5527	115	33G
0005435765962	5527	116	34D
0005435765988	5527	117	34E
0005435766005	5527	118	35A
0005435765946	5527	119	35D
0005434264833	5527	120	35B
0005434264838	5527	121	35F
0005433527251	5527	122	35G
0005435765952	5527	123	36A
0005435765995	5527	124	35H
0005435461966	5527	125	36D
0005435765971	5527	126	36G
0005433529262	5527	127	37A
0005435765951	5527	128	36H
0005432140414	5527	129	37D
0005434264775	5527	130	37E
0005432140412	5527	131	37G
0005434264865	5527	132	38A
0005434264802	5527	133	37H
0005435765957	5527	134	38D
0005435765977	5527	135	38B
0005435765968	5527	136	38F
0005435735119	5527	137	38H
0005435765983	5527	138	39E
0005435765950	5527	139	39D
0005435462284	13488	1	1C
0005435765346	13488	2	1B
0005435765584	13488	3	1F
0005435765583	13488	4	1H
0005434265033	13488	5	1G
0005435765134	13488	6	2A
0005435462281	13488	7	2B
0005435462279	13488	8	2F
0005435765337	13488	9	2H
0005435735087	13488	10	2G
0005435765262	13488	11	3A
0005435723021	13488	12	3B
0005435765570	13488	13	3F
0005435462294	13488	14	3G
0005432194491	13488	15	4A
0005434265034	13488	16	3H
0005434265022	13488	17	4B
0005435725540	13488	18	4H
0005434265020	13488	19	4G
0005434265042	13488	20	4F
0005435765501	13488	21	5B
0005434831131	13488	22	5A
0005434831130	13488	23	5C
0005435722017	13488	24	5G
0005434265032	13488	25	5F
0005435462275	13488	26	5H
0005432194492	13488	27	9B
0005435765119	13488	28	9A
0005435765565	13488	29	9G
0005432194493	13488	30	11A
0005435765434	13488	31	9H
0005435765280	13488	32	11D
0005435765532	13488	33	11B
0005435462296	13488	34	11E
0005434265037	13488	35	11F
0005434265026	13488	36	11G
0005435765477	13488	37	12A
0005434831132	13488	38	11H
0005435765528	13488	39	12D
0005435462265	13488	40	12B
0005435765352	13488	41	12E
0005435462269	13488	42	12F
0005432194494	13488	43	12H
0005435462264	13488	44	13B
0005435765207	13488	45	13A
0005435462290	13488	46	13D
0005435043282	13488	47	13E
0005435462263	13488	48	13F
0005435462291	13488	49	13H
0005435765325	13488	50	14B
0005435722020	13488	51	14A
0005435765235	13488	52	14E
0005435765326	13488	53	14G
0005435462289	13488	54	15A
0005434265031	13488	55	15D
0005435765186	13488	56	15B
0005435462293	13488	57	15E
0005435765360	13488	58	15F
0005435462285	13488	59	15H
0005435765351	13488	60	16A
0005435765586	13488	61	16D
0005435462261	13488	62	16B
0005435720121	13488	63	16F
0005435765463	13488	64	16E
0005435765135	13488	65	16H
0005435462295	13488	66	17B
0005435765400	13488	67	17D
0005435765368	13488	68	17F
0005434265030	13488	69	17E
0005435765536	13488	70	17G
0005435723019	13488	71	17H
0005435765500	13488	72	18A
0005435462259	13488	73	18D
0005432535815	13488	74	18B
0005434265025	13488	75	18E
0005435462288	13488	76	18G
0005435462287	13488	77	19E
0005435462273	13488	78	19D
0005434265029	13488	79	19F
0005434265040	13488	80	19G
0005435722016	13488	81	20A
0005435765347	13488	82	19H
0005435722018	13488	83	20B
0005435765641	13488	84	20E
0005435765656	13488	85	20F
0005435765272	13488	86	20G
0005435735080	13488	87	21B
0005435765299	13488	88	21D
0005435765499	13488	89	21E
0005435462270	13488	90	21F
0005434265043	13488	91	21H
0005435765461	13488	92	21G
0005435735072	13488	93	22A
0005435462260	13488	94	22D
0005434265035	13488	95	22E
0005434265039	13488	96	22G
0005435765243	13488	97	22F
0005435765614	13488	98	22H
0005435765640	13488	99	23E
0005435765228	13488	100	23G
0005435765473	13488	101	23F
0005435723018	13488	102	24A
0005435765264	13488	103	23H
0005434265038	13488	104	24B
0005435765535	13488	105	24D
0005435765464	13488	106	24G
0005435765137	13488	107	25D
0005435765176	13488	108	24H
0005434265044	13488	109	25E
0005435765219	13488	110	25F
0005435725539	13488	111	27B
0005435765390	13488	112	27D
0005434265036	13488	113	27E
0005435735070	13488	114	28A
0005435765393	13488	115	28B
0005435722030	13488	116	28E
0005435765359	13488	117	28D
0005434265019	13488	118	28F
0005434265024	13488	119	28H
0005435723017	13488	120	28G
0005435765361	13488	121	29B
0005435765327	13488	122	29A
0005435765478	13488	123	29D
0005435462262	13488	124	29E
0005432535812	13488	125	29F
0005435725547	13488	126	30A
0005435462292	13488	127	29H
0005434265021	13488	128	29G
0005435765208	13488	129	30B
0005435765328	13488	130	30E
0005435765112	13488	131	30G
0005434831129	13488	132	30F
0005435462280	13488	133	30H
0005435462274	13488	134	31B
0005435765277	13488	135	31A
0005435462282	13488	136	31E
0005435765392	13488	137	31F
0005435462271	13488	138	31G
0005435722019	13488	139	32A
0005435765187	13488	140	31H
0005435765136	13488	141	32B
0005435765290	13488	142	32D
0005435462277	13488	143	32F
0005434831133	13488	144	32E
0005435765234	13488	145	32H
0005435765177	13488	146	33A
0005435765113	13488	147	33B
0005432535816	13488	148	33E
0005435462278	13488	149	33D
0005435765233	13488	150	33F
0005435462267	13488	151	33H
0005434265023	13488	152	33G
0005435462266	13488	153	34B
0005435735073	13488	154	34A
0005434265028	13488	155	34E
0005435725541	13488	156	34F
0005435765114	13488	157	34H
0005435765574	13488	158	34G
0005435765369	13488	159	35B
0005435765564	13488	160	35A
0005435462272	13488	161	35D
0005435462276	13488	162	35E
0005435765212	13488	163	35F
0005435765242	13488	164	35H
0005435765345	13488	165	36B
0005435765553	13488	166	36D
0005435462286	13488	167	36E
0005435765218	13488	168	36G
0005432535813	13488	169	36F
0005435462283	13488	170	37B
0005435043283	13488	171	37E
0005434265027	13488	172	37D
0005435765389	13488	173	37F
0005432535814	13488	174	37H
0005435722021	13488	175	37G
0005435765428	13488	176	38A
0005435723022	13488	177	38B
0005435462268	13488	178	38E
0005435765523	13488	179	38G
0005435735079	13488	180	38F
0005434265041	13488	181	38H
0005435765195	13488	182	39D
0005435765367	13488	183	39F
0005435765109	13488	184	39E
0005434514956	18688	1	1A
0005434513565	18688	2	1B
0005434513568	18688	3	2A
0005434604860	18688	4	3B
0005434513566	18688	5	4A
0005434514954	18688	6	5A
0005434604848	18688	7	5B
0005434513567	18688	8	6A
0005434514955	18688	9	6B
0005434514932	19118	1	1A
0005434514933	19118	2	4B
0005434514930	19118	3	5A
0005434514948	19118	4	5B
0005434514942	19118	5	6A
0005435846204	4131	1	1C
0005432649382	4131	2	1D
0005435844266	4131	3	2F
0005435844270	4131	4	3A
0005432632707	4131	5	3D
0005435846198	4131	6	3F
0005435844279	4131	7	5C
0005432649376	4131	8	5D
0005432649375	4131	9	5E
0005432649377	4131	10	5F
0005432649378	4131	11	6D
0005432632718	4131	12	6F
0005435844265	4131	13	7A
0005432632709	4131	14	7F
0005435846201	4131	15	8C
0005432632708	4131	16	8F
0005432632717	4131	17	9F
0005432649373	4131	18	10C
0005435846205	4131	19	11C
0005432632706	4131	20	11D
0005435844280	4131	21	12C
0005435846207	4131	22	12F
0005435846189	4131	23	13C
0005432632711	4131	24	13E
0005432632715	4131	25	13F
0005435846199	4131	26	14E
0005432649381	4131	27	15E
0005435844262	4131	28	15F
0005432649374	4131	29	16A
0005432649370	4131	30	16F
0005432649380	4131	31	17C
0005435844269	4131	32	17F
0005435846206	4131	33	18A
0005432649372	4131	34	18D
0005432632716	4131	35	18E
0005435844264	4131	36	18F
0005432632713	4131	37	19A
0005432649379	4131	38	19C
0005432632710	4131	39	19D
0005432632719	4131	40	19F
0005432649371	4131	41	20D
0005432632712	4131	42	20E
0005432632714	4131	43	20F
0005433008084	1851	1	1A
0005433007984	1851	2	1C
0005433008011	1851	3	1D
0005433008127	1851	4	1F
0005433284904	1851	5	2A
0005433284821	1851	6	2C
0005433007993	1851	7	2D
0005433285029	1851	8	3A
0005433008180	1851	9	2F
0005433284911	1851	10	3C
0005433810527	1851	11	3D
0005433008191	1851	12	4A
0005433008064	1851	13	4C
0005433008067	1851	14	4D
0005433008082	1851	15	4E
0005433284905	1851	16	4F
0005433810528	1851	17	5E
0005433008010	1851	18	5F
0005433007996	1851	19	6A
0005433007955	1851	20	6C
0005433008012	1851	21	6E
0005433008083	1851	22	6F
0005433284935	1851	23	7C
0005433008058	1851	24	7D
0005433008007	1851	25	7E
0005433284928	1851	26	8A
0005433284912	1851	27	8C
0005433007942	1851	28	8D
0005433284822	1851	29	8E
0005433007941	1851	30	8F
0005433007926	1851	31	9C
0005433008179	1851	32	9D
0005433810526	1851	33	9F
0005433284973	1851	34	10A
0005433284992	1851	35	10F
0005433284913	1851	36	11A
0005433008093	1851	37	11D
0005433007903	1851	38	11E
0005433284888	1851	39	11F
0005433284956	1851	40	12A
0005433008059	1851	41	12C
0005433008026	1851	42	12E
0005433008057	1851	43	12F
0005433008254	1851	44	13C
0005433008190	1851	45	13D
0005433008020	1851	46	13F
0005433008075	1851	47	14D
0005433008189	1851	48	14E
0005433008167	1851	49	14F
0005433008040	1851	50	15C
0005433284954	1851	51	15D
0005433284991	1851	52	15E
0005433007922	1851	53	15F
0005433007956	1851	54	16A
0005433008066	1851	55	16C
0005433284777	1851	56	16D
0005433008090	1851	57	16F
0005433007902	1851	58	17C
0005432295868	1851	59	17D
0005433008137	1851	60	17E
0005433008065	1851	61	18A
0005433008105	1851	62	18C
0005433008222	1851	63	18D
0005433008051	1851	64	18E
0005433810524	1851	65	18F
0005433810525	1851	66	19A
0005433008052	1851	67	19C
0005433008086	1851	68	19D
0005433007957	1851	69	19F
0005433008177	1851	70	20A
0005433008070	1851	71	20C
0005433007927	1851	72	20D
0005432295869	1851	73	20E
0005433284955	1851	74	20F
0005433008406	22580	1	1D
0005433008398	22580	2	1F
0005433008421	22580	3	2A
0005433285149	22580	4	2C
0005433008397	22580	5	2D
0005433008412	22580	6	2F
0005433285145	22580	7	3C
0005433008389	22580	8	3D
0005433008401	22580	9	4A
0005433285147	22580	10	4C
0005433008410	22580	11	4D
0005433008409	22580	12	5C
0005433008383	22580	13	5D
0005433008422	22580	14	5E
0005433008379	22580	15	5F
0005433285157	22580	16	6A
0005433008403	22580	17	6C
0005433008411	22580	18	6D
0005433008391	22580	19	6E
0005433008382	22580	20	6F
0005433285146	22580	21	7C
0005433008394	22580	22	7F
0005433285140	22580	23	8A
0005433285142	22580	24	8C
0005433008402	22580	25	8F
0005433285148	22580	26	9C
0005433285138	22580	27	9D
0005433008396	22580	28	9E
0005433008399	22580	29	10A
0005433285144	22580	30	10C
0005433285161	22580	31	10D
0005433285158	22580	32	10E
0005433008395	22580	33	10F
0005433285152	22580	34	11A
0005433285137	22580	35	11C
0005433285159	22580	36	11D
0005433810490	22580	37	11E
0005433285150	22580	38	11F
0005433285164	22580	39	12C
0005433285163	22580	40	12D
0005433008418	22580	41	12E
0005433008408	22580	42	12F
0005433285154	22580	43	13A
0005433285151	22580	44	13C
0005433008414	22580	45	13D
0005433008388	22580	46	13E
0005433008390	22580	47	13F
0005433008423	22580	48	14A
0005433008386	22580	49	14C
0005433008387	22580	50	14D
0005433285139	22580	51	14E
0005433008417	22580	52	14F
0005433285165	22580	53	15A
0005433285160	22580	54	15C
0005433285162	22580	55	15D
0005433285143	22580	56	15E
0005433285153	22580	57	15F
0005433008400	22580	58	16A
0005433008380	22580	59	16C
0005433008420	22580	60	16D
0005433008384	22580	61	16E
0005433285135	22580	62	16F
0005433008424	22580	63	17A
0005433285155	22580	64	17C
0005433008404	22580	65	17D
0005433008416	22580	66	17E
0005433008415	22580	67	17F
0005433285136	22580	68	18A
0005433008413	22580	69	18C
0005433008385	22580	70	18D
0005433008407	22580	71	18E
0005433285156	22580	72	18F
0005433008381	22580	73	19A
0005433008393	22580	74	19C
0005433008419	22580	75	19D
0005433008392	22580	76	19E
0005433285141	22580	77	20D
0005433008405	22580	78	20E
0005433285166	22580	79	20F
0005432755030	12284	1	2C
0005432751473	12284	2	4C
0005432751480	12284	3	5A
0005432755016	12284	4	5E
0005432755020	12284	5	7E
0005432751470	12284	6	9A
0005432751479	12284	7	9C
0005432751493	12284	8	9E
0005432751471	12284	9	10A
0005432751476	12284	10	11C
0005432755017	12284	11	11F
0005432751477	12284	12	12A
0005432751475	12284	13	13D
0005432755025	12284	14	14A
0005432755023	12284	15	18C
0005432751482	12284	16	18D
0005432751472	12284	17	19A
0005432751474	12284	18	19E
0005432755024	12284	19	20C
0005435282094	5552	1	1C
0005433846480	5552	2	1A
0005432081482	5552	3	1D
0005435282074	5552	4	2A
0005435282204	5552	5	1F
0005433846471	5552	6	2C
0005433846453	5552	7	3A
0005433846479	5552	8	2F
0005432081485	5552	9	3C
0005433846456	5552	10	4A
0005433846498	5552	11	3F
0005435282237	5552	12	4C
0005433846470	5552	13	4F
0005433846466	5552	14	4D
0005434173463	5552	15	5C
0005435282153	5552	16	5F
0005435282164	5552	17	5D
0005433846491	5552	18	6B
0005433846486	5552	19	6A
0005432081480	5552	20	6D
0005433846474	5552	21	6C
0005433846494	5552	22	6E
0005435282201	5552	23	7A
0005433846447	5552	24	6F
0005433846476	5552	25	7C
0005433846487	5552	26	7B
0005435282168	5552	27	7D
0005435282233	5552	28	7F
0005433846496	5552	29	8B
0005433846444	5552	30	8A
0005433846451	5552	31	8C
0005433846477	5552	32	8F
0005433846488	5552	33	8E
0005433846450	5552	34	9B
0005432081486	5552	35	9A
0005435282173	5552	36	9C
0005433846472	5552	37	9E
0005432081484	5552	38	9D
0005435282169	5552	39	10A
0005434173455	5552	40	9F
0005435282174	5552	41	10C
0005432081483	5552	42	10B
0005433846440	5552	43	10E
0005435282161	5552	44	10D
0005433846445	5552	45	10F
0005433846460	5552	46	11B
0005433846443	5552	47	11A
0005433815359	5552	48	11C
0005433815361	5552	49	11F
0005433846441	5552	50	12B
0005433846481	5552	51	12A
0005433846495	5552	52	12C
0005433846489	5552	53	12F
0005433846467	5552	54	12E
0005433846482	5552	55	12D
0005433846464	5552	56	13A
0005435282095	5552	57	13C
0005435282236	5552	58	13B
0005433846461	5552	59	13D
0005433846457	5552	60	14A
0005435282186	5552	61	13F
0005433815360	5552	62	13E
0005433846465	5552	63	14B
0005435282187	5552	64	14D
0005434173464	5552	65	14C
0005433815362	5552	66	14F
0005433846449	5552	67	15B
0005433846462	5552	68	15A
0005433846493	5552	69	15C
0005435282117	5552	70	15E
0005433846458	5552	71	15D
0005433846446	5552	72	16A
0005435282270	5552	73	15F
0005433846442	5552	74	16C
0005435282125	5552	75	16E
0005433846455	5552	76	16D
0005433846454	5552	77	17A
0005433846459	5552	78	16F
0005435282089	5552	79	17B
0005433815363	5552	80	17D
0005433846469	5552	81	17C
0005432081481	5552	82	17F
0005433846478	5552	83	17E
0005433846490	5552	84	18B
0005433846492	5552	85	18A
0005433846483	5552	86	18D
0005433846475	5552	87	18C
0005433846473	5552	88	18E
0005434173479	5552	89	18F
0005435282108	5552	90	19C
0005435282269	5552	91	19B
0005433846497	5552	92	19E
0005435282073	5552	93	19D
0005433846484	5552	94	19F
0005433846452	5552	95	20B
0005435282180	5552	96	20C
0005433846463	5552	97	20F
0005433846485	5552	98	20E
0005435282126	5552	99	20D
0005435282205	5552	100	21B
0005433846468	5552	101	21A
0005435282232	5552	102	21C
0005434173462	5552	103	21F
0005433846499	5552	104	21E
0005433846448	5552	105	21D
0005434173503	13847	1	1C
0005433845986	13847	2	1A
0005435282398	13847	3	1F
0005432003689	13847	4	2A
0005435282406	13847	5	2D
0005433846098	13847	6	2C
0005435282416	13847	7	3A
0005435282414	13847	8	3D
0005433846201	13847	9	3C
0005433845846	13847	10	4A
0005433846073	13847	11	3F
0005433845984	13847	12	4D
0005435282417	13847	13	4F
0005433846031	13847	14	5C
0005433845765	13847	15	5A
0005433845797	13847	16	5F
0005433845881	13847	17	5D
0005435282402	13847	18	6B
0005435282410	13847	19	6A
0005435282399	13847	20	6C
0005433846093	13847	21	6E
0005433846158	13847	22	6D
0005433845770	13847	23	7A
0005434173501	13847	24	6F
0005435282397	13847	25	7C
0005435282409	13847	26	7B
0005435282412	13847	27	7E
0005433846029	13847	28	7D
0005433845926	13847	29	8A
0005435282407	13847	30	8B
0005433846001	13847	31	8E
0005435282415	13847	32	8D
0005435282420	13847	33	8C
0005433845967	13847	34	8F
0005433845847	13847	35	9A
0005435282413	13847	36	9D
0005435282393	13847	37	9C
0005435282419	13847	38	9E
0005432003688	13847	39	10A
0005433845919	13847	40	9F
0005433845985	13847	41	10C
0005435282394	13847	42	10B
0005433845796	13847	43	10D
0005433846228	13847	44	11A
0005433846227	13847	45	10F
0005435282404	13847	46	10E
0005433846193	13847	47	11C
0005433845935	13847	48	11B
0005434173505	13847	49	11D
0005435282395	13847	50	11F
0005433846018	13847	51	11E
0005435282400	13847	52	12B
0005433846094	13847	53	12C
0005435282411	13847	54	13A
0005433846095	13847	55	13C
0005435282401	13847	56	13B
0005433845943	13847	57	13E
0005433846202	13847	58	14A
0005433846014	13847	59	13F
0005435282405	13847	60	14C
0005433846017	13847	61	14B
0005433845999	13847	62	14F
0005433845983	13847	63	14E
0005434173502	13847	64	15C
0005433846106	13847	65	15E
0005432003687	13847	66	15D
0005433845998	13847	67	16A
0005433846066	13847	68	16B
0005433846003	13847	69	16E
0005433845860	13847	70	16D
0005433846084	13847	71	16C
0005434173504	13847	72	17B
0005433815326	13847	73	17A
0005435282403	13847	74	17D
0005435282418	13847	75	17F
0005433845890	13847	76	17E
0005433845793	13847	77	18B
0005433845832	13847	78	18C
0005433845946	13847	79	18E
0005433846032	13847	80	18D
0005433845798	13847	81	19A
0005433845801	13847	82	18F
0005435282396	13847	83	19C
0005433845915	13847	84	19B
0005433846150	13847	85	19D
0005435282408	13847	86	19E
0005433845950	13847	87	20C
0005433846002	13847	88	20A
0005433846013	13847	89	20D
0005433845687	13847	90	20F
0005433845920	13847	91	20E
0005433846173	13847	92	21B
0005433815329	13847	93	21D
0005433845994	13847	94	21C
0005433845880	13847	95	21E
0005433845795	13847	96	21F
0005434620499	7810	1	1A
0005435332228	7810	2	1B
0005435332249	7810	3	1C
0005435332210	7810	4	1D
0005434620507	7810	5	2A
0005434620503	7810	6	2B
0005434620495	7810	7	2D
0005434620506	7810	8	3B
0005435332232	7810	9	4B
0005434620505	7810	10	4D
0005432112506	7810	11	5A
0005435332186	7810	12	5D
0005435332185	7810	13	6B
0005434620509	7810	14	6C
0005435332188	7810	15	6D
0005435332208	7810	16	7A
0005434620512	7810	17	7C
0005434620500	7810	18	7D
0005434620504	7810	19	18A
0005434620508	7810	20	18B
0005434620513	7810	21	18C
0005434620502	7810	22	18D
0005434620515	7810	23	19A
0005434620514	7810	24	19C
0005434620501	7810	25	19D
0005434620511	7810	26	20B
0005434620498	7810	27	20C
0005434620510	7810	28	21A
0005435332251	7810	29	21B
0005435332250	7810	30	21C
0005435332181	7810	31	21D
0005434620496	7810	32	22C
0005434620497	7810	33	23B
0005434620278	32996	1	1B
0005435332290	32996	2	2C
0005434620335	32996	3	2D
0005434620405	32996	4	3B
0005435332285	32996	5	4C
0005435332293	32996	6	4D
0005434620344	32996	7	5A
0005434620290	32996	8	5B
0005434620363	32996	9	5D
0005434620358	32996	10	6A
0005435332294	32996	11	6D
0005434620331	32996	12	7A
0005434620414	32996	13	7B
0005435332289	32996	14	7C
0005435332291	32996	15	7D
0005435332288	32996	16	18A
0005434620362	32996	17	18B
0005435332287	32996	18	18C
0005434620386	32996	19	18D
0005435332286	32996	20	19B
0005435332292	32996	21	19C
0005434620345	32996	22	21C
0005434620352	32996	23	22B
0005434620380	32996	24	22D
0005434620376	32996	25	23B
0005435937315	4301	1	1C
0005435937326	4301	2	2C
0005432190612	4301	3	3C
0005435785196	4301	4	3D
0005435787345	4301	5	3F
0005435785211	4301	6	4D
0005435785208	4301	7	4E
0005434993979	4301	8	5A
0005434993976	4301	9	5E
0005434993981	4301	10	5F
0005435785209	4301	11	6C
0005435785201	4301	12	6E
0005435785221	4301	13	6F
0005435785206	4301	14	7A
0005434993982	4301	15	7C
0005435785189	4301	16	7D
0005435918613	4301	17	7E
0005435918618	4301	18	8A
0005435785205	4301	19	8C
0005434993975	4301	20	8D
0005435785195	4301	21	8E
0005435785218	4301	22	9A
0005435785190	4301	23	9C
0005435785217	4301	24	9D
0005434993980	4301	25	10E
0005435785222	4301	26	10F
0005435937313	4301	27	11D
0005434993977	4301	28	12C
0005435785191	4301	29	12D
0005435785188	4301	30	13C
0005435785199	4301	31	13D
0005435785193	4301	32	13E
0005435785220	4301	33	14A
0005435785197	4301	34	14D
0005434993983	4301	35	14E
0005435937325	4301	36	15A
0005435785203	4301	37	15C
0005435785202	4301	38	15D
0005435785215	4301	39	16C
0005435918603	4301	40	16D
0005435785187	4301	41	16E
0005435785216	4301	42	16F
0005435785198	4301	43	17A
0005435918587	4301	44	17C
0005435785204	4301	45	17E
0005435937314	4301	46	17F
0005435785214	4301	47	18A
0005435785200	4301	48	18C
0005435785212	4301	49	18D
0005435785213	4301	50	18F
0005434993978	4301	51	19A
0005435785194	4301	52	19C
0005432190614	4301	53	19D
0005435785207	4301	54	19E
0005434993984	4301	55	19F
0005435785192	4301	56	20A
0005435785210	4301	57	20C
0005435787344	4301	58	20D
0005435785219	4301	59	20E
0005432190613	4301	60	20F
0005435937358	27327	1	1A
0005434993906	27327	2	1C
0005435784771	27327	3	2A
0005435784746	27327	4	3D
0005435784837	27327	5	3F
0005435918637	27327	6	4A
0005435784815	27327	7	4C
0005435784855	27327	8	4F
0005435784860	27327	9	4E
0005434993889	27327	10	5A
0005434993883	27327	11	5C
0005434993922	27327	12	5D
0005435784788	27327	13	6D
0005435784773	27327	14	6E
0005435784732	27327	15	6F
0005435784800	27327	16	7A
0005435784820	27327	17	7D
0005435937362	27327	18	7F
0005435784772	27327	19	8C
0005434993888	27327	20	8D
0005435784818	27327	21	8F
0005435787325	27327	22	9C
0005435918635	27327	23	9D
0005435784805	27327	24	9E
0005435784888	27327	25	10D
0005435784821	27327	26	10E
0005434993891	27327	27	10F
0005435784863	27327	28	11D
0005434993904	27327	29	11E
0005435784886	27327	30	11F
0005435787324	27327	31	12A
0005434993882	27327	32	12C
0005435937359	27327	33	12F
0005435784840	27327	34	13A
0005435918632	27327	35	13C
0005435784822	27327	36	13D
0005435784889	27327	37	13E
0005434993890	27327	38	13F
0005435937366	27327	39	14A
0005435784949	27327	40	14C
0005435784901	27327	41	14F
0005435784918	27327	42	14E
0005435937363	27327	43	15A
0005435784911	27327	44	15C
0005435937365	27327	45	15F
0005432195682	27327	46	16D
0005435937360	27327	47	16E
0005434993895	27327	48	16F
0005435918636	27327	49	17A
0005435784868	27327	50	17C
0005434993905	27327	51	17F
0005435937364	27327	52	18A
0005435918633	27327	53	18C
0005435784794	27327	54	18D
0005435784912	27327	55	18E
0005435787326	27327	56	19A
0005435784917	27327	57	19C
0005432195683	27327	58	20A
0005435918634	27327	59	20C
0005435784731	27327	60	20D
0005435937361	27327	61	20E
0005435784787	27327	62	20F
0005432146189	19884	1	6A
0005432146188	19884	2	21C
0005432146190	19884	3	21D
0005432459604	4751	1	1A
0005434081809	4751	2	1C
0005434081801	4751	3	1B
0005432459647	4751	4	1F
0005432567347	4751	5	1H
0005432459626	4751	6	1G
0005434081804	4751	7	2B
0005432459605	4751	8	2C
0005432186855	4751	9	3A
0005434081818	4751	10	2H
0005432459607	4751	11	3B
0005432567374	4751	12	3C
0005434081815	4751	13	3G
0005432459639	4751	14	3H
0005432571303	4751	15	4B
0005432567343	4751	16	4F
0005432567349	4751	17	4C
0005432459598	4751	18	4H
0005432567352	4751	19	5B
0005432567392	4751	20	5A
0005432567345	4751	21	5C
0005432170361	4751	22	5G
0005432567363	4751	23	5H
0005432459616	4751	24	9B
0005432567377	4751	25	9A
0005434081800	4751	26	9G
0005434081807	4751	27	11A
0005432459600	4751	28	9H
0005432459629	4751	29	11B
0005432459619	4751	30	11H
0005432567355	4751	31	11G
0005432567398	4751	32	12A
0005432567353	4751	33	12B
0005432459597	4751	34	12D
0005432459623	4751	35	12G
0005434081799	4751	36	12F
0005432459620	4751	37	12H
0005432459608	4751	38	13A
0005432567391	4751	39	13D
0005434559092	4751	40	13E
0005432567357	4751	41	13G
0005432567351	4751	42	13F
0005434559094	4751	43	13H
0005432459630	4751	44	14B
0005432567365	4751	45	14A
0005434081798	4751	46	14E
0005432459640	4751	47	14D
0005432567368	4751	48	14G
0005432567385	4751	49	15A
0005433452731	4751	50	14H
0005432567366	4751	51	15B
0005432567375	4751	52	15E
0005434081814	4751	53	15D
0005432459643	4751	54	15F
0005432567388	4751	55	15G
0005432567390	4751	56	16B
0005432567370	4751	57	16A
0005432567382	4751	58	15H
0005432459617	4751	59	16E
0005432567354	4751	60	16D
0005432567384	4751	61	16G
0005432170356	4751	62	16F
0005432567350	4751	63	16H
0005432459625	4751	64	17D
0005433451612	4751	65	17B
0005434081808	4751	66	17E
0005432567394	4751	67	17F
0005432170360	4751	68	17H
0005432567369	4751	69	18B
0005432567381	4751	70	18A
0005432567373	4751	71	18D
0005432567348	4751	72	18F
0005432459603	4751	73	18E
0005434081790	4751	74	19A
0005432459610	4751	75	18H
0005434081817	4751	76	19B
0005432567359	4751	77	19D
0005434081802	4751	78	19E
0005434081796	4751	79	19G
0005432567358	4751	80	20A
0005432567389	4751	81	20B
0005434559093	4751	82	20E
0005432186853	4751	83	20D
0005432459644	4751	84	20F
0005433452729	4751	85	20G
0005434081794	4751	86	21A
0005432567376	4751	87	20H
0005432459646	4751	88	21D
0005432170357	4751	89	21E
0005433726094	4751	90	21G
0005432571304	4751	91	21H
0005432567397	4751	92	22A
0005432567362	4751	93	22D
0005432459631	4751	94	22B
0005432459618	4751	95	22E
0005432459612	4751	96	22G
0005432567372	4751	97	22F
0005432567396	4751	98	23A
0005432459601	4751	99	22H
0005432571307	4751	100	23B
0005432459602	4751	101	23D
0005434081816	4751	102	23F
0005432567387	4751	103	23G
0005434081797	4751	104	24B
0005432567360	4751	105	24G
0005434081791	4751	106	25E
0005432170355	4751	107	25D
0005432459614	4751	108	27A
0005433452732	4751	109	25F
0005432459649	4751	110	27D
0005434081812	4751	111	27B
0005432567378	4751	112	27E
0005432459638	4751	113	28A
0005432459606	4751	114	27H
0005432459622	4751	115	28E
0005432459645	4751	116	28F
0005433451610	4751	117	28G
0005432567361	4751	118	28H
0005432459637	4751	119	29B
0005432567386	4751	120	29E
0005432459650	4751	121	29G
0005432567344	4751	122	29F
0005432186852	4751	123	29H
0005432459628	4751	124	30B
0005432170359	4751	125	30A
0005432459633	4751	126	30D
0005434081795	4751	127	30E
0005432170358	4751	128	30H
0005432567340	4751	129	31B
0005432567399	4751	130	31D
0005432459621	4751	131	31F
0005432567383	4751	132	31E
0005432459613	4751	133	31H
0005432567342	4751	134	31G
0005434081805	4751	135	32B
0005432459636	4751	136	32A
0005432567341	4751	137	32E
0005434081813	4751	138	32D
0005432459627	4751	139	32F
0005432567367	4751	140	32G
0005433452730	4751	141	32H
0005432567395	4751	142	33D
0005432459634	4751	143	33B
0005432459642	4751	144	33E
0005434081806	4751	145	33G
0005433726093	4751	146	33F
0005432459635	4751	147	34A
0005432459611	4751	148	34D
0005432459641	4751	149	34F
0005432459648	4751	150	34G
0005432459609	4751	151	35B
0005432459632	4751	152	35A
0005434559095	4751	153	35D
0005432567380	4751	154	35F
0005432567364	4751	155	35E
0005434081810	4751	156	35G
0005434081811	4751	157	36B
0005432567356	4751	158	36A
0005432459624	4751	159	36F
0005432567379	4751	160	36E
0005434081792	4751	161	36G
0005432567346	4751	162	36H
0005432571305	4751	163	37D
0005432567371	4751	164	37B
0005432571306	4751	165	37G
0005433451611	4751	166	37H
0005434081803	4751	167	38A
0005432459615	4751	168	38D
0005434081793	4751	169	38B
0005432567400	4751	170	38E
0005432186854	4751	171	38G
0005432459599	4751	172	38F
0005432567393	4751	173	38H
0005432459235	30520	1	1C
0005433454847	30520	2	1F
0005432567122	30520	3	2A
0005434081632	30520	4	2F
0005434081565	30520	5	2C
0005432459117	30520	6	2G
0005432459195	30520	7	3A
0005432567088	30520	8	3F
0005432566860	30520	9	3C
0005434081648	30520	10	3H
0005432459485	30520	11	3G
0005432459013	30520	12	4C
0005432459338	30520	13	4G
0005433452711	30520	14	5A
0005432567059	30520	15	4H
0005432459307	30520	16	5F
0005432566839	30520	17	5H
0005432459344	30520	18	9B
0005433452709	30520	19	9A
0005432459252	30520	20	9H
0005432566826	30520	21	11B
0005432567007	30520	22	11E
0005432459251	30520	23	11D
0005432566913	30520	24	12A
0005433454842	30520	25	12D
0005432567073	30520	26	12E
0005432567006	30520	27	12G
0005432567060	30520	28	12F
0005432566843	30520	29	12H
0005432459458	30520	30	13A
0005434081590	30520	31	13D
0005432459432	30520	32	13B
0005432459456	30520	33	13E
0005432566861	30520	34	13G
0005432566851	30520	35	13F
0005434081578	30520	36	14B
0005432459228	30520	37	14D
0005432566793	30520	38	14F
0005432459261	30520	39	14G
0005432459350	30520	40	15A
0005434081581	30520	41	15E
0005432459244	30520	42	15D
0005432566769	30520	43	15H
0005432566914	30520	44	16E
0005432566806	30520	45	16F
0005432459231	30520	46	16H
0005432571278	30520	47	16G
0005432459433	30520	48	17A
0005434081577	30520	49	17B
0005432566655	30520	50	17E
0005432459102	30520	51	17G
0005432459168	30520	52	17H
0005432566990	30520	53	18B
0005432459249	30520	54	18A
0005432566995	30520	55	18D
0005432459313	30520	56	18F
0005432459351	30520	57	18E
0005432567097	30520	58	19D
0005432459349	30520	59	19F
0005432213590	30520	60	19G
0005432459314	30520	61	20A
0005432459236	30520	62	20D
0005434081504	30520	63	20B
0005432566597	30520	64	20E
0005432459319	30520	65	20F
0005432459457	30520	66	21A
0005432458975	30520	67	21B
0005432566735	30520	68	21E
0005432566811	30520	69	21D
0005433454841	30520	70	21F
0005434081576	30520	71	21G
0005432567013	30520	72	22A
0005432567098	30520	73	22D
0005432459116	30520	74	22E
0005432566871	30520	75	22G
0005432459294	30520	76	22F
0005432566563	30520	77	23B
0005432459264	30520	78	23A
0005432566991	30520	79	23D
0005432566816	30520	80	23G
0005432213589	30520	81	23H
0005432459245	30520	82	24A
0005432567044	30520	83	24D
0005432566915	30520	84	24G
0005432566531	30520	85	25D
0005432161143	30520	86	24H
0005434081610	30520	87	25E
0005434081518	30520	88	27F
0005432566841	30520	89	27E
0005432459298	30520	90	27G
0005432161142	30520	91	28A
0005433452702	30520	92	27H
0005434081553	30520	93	28E
0005432566908	30520	94	28H
0005432459337	30520	95	29B
0005432459229	30520	96	29F
0005432566996	30520	97	29G
0005433452710	30520	98	30D
0005432213591	30520	99	30F
0005432459219	30520	100	30H
0005432459343	30520	101	31A
0005432566662	30520	102	31E
0005432459250	30520	103	31F
0005432566857	30520	104	32E
0005432459196	30520	105	33B
0005432459323	30520	106	33F
0005432566744	30520	107	34B
0005434081564	30520	108	34A
0005434081631	30520	109	34D
0005434081619	30520	110	34F
0005432566966	30520	111	34G
0005432459079	30520	112	35B
0005432459306	30520	113	35D
0005432567001	30520	114	35F
0005432459203	30520	115	35E
0005432566810	30520	116	36A
0005434081471	30520	117	35H
0005432566770	30520	118	36D
0005432566982	30520	119	36F
0005432459248	30520	120	36H
0005432567049	30520	121	37A
0005433452703	30520	122	37F
0005432459204	30520	123	38A
0005432566677	30520	124	38E
0005433452708	30520	125	38G
0005432459089	30520	126	39D
0005434081580	30520	127	38H
0005434081642	30520	128	39E
0005435722044	13596	1	2B
0005435722045	13596	2	6A
0005435720122	21231	1	4B
0005435720123	21231	2	5A
0005435722014	21231	3	5B
0005432295869	22767	1	4B
0005432295868	22767	2	19D
0005435508199	11098	1	1C
0005433342759	11098	2	1A
0005433342761	11098	3	2A
0005433342743	11098	4	1F
0005435380232	11098	5	2D
0005433342716	11098	6	2C
0005433342739	11098	7	3A
0005435508205	11098	8	2F
0005433342764	11098	9	3C
0005433342733	11098	10	3D
0005433342803	11098	11	3F
0005433342713	11098	12	4A
0005433342722	11098	13	4C
0005433342800	11098	14	4B
0005433342728	11098	15	4D
0005435097161	11098	16	4E
0005433342751	11098	17	4F
0005433342794	11098	18	5A
0005435097158	11098	19	5C
0005433342737	11098	20	5B
0005435380235	11098	21	5D
0005433342789	11098	22	5E
0005433342750	11098	23	6A
0005433342801	11098	24	5F
0005433342749	11098	25	6C
0005435380236	11098	26	6B
0005433342744	11098	27	6E
0005433342709	11098	28	6D
0005433342765	11098	29	7B
0005433342735	11098	30	7A
0005433342711	11098	31	7C
0005433342776	11098	32	7E
0005433342714	11098	33	7D
0005433342795	11098	34	7F
0005433342786	11098	35	8B
0005435508207	11098	36	8C
0005435097165	11098	37	8E
0005433342704	11098	38	8D
0005433342791	11098	39	8F
0005433342708	11098	40	9A
0005433342729	11098	41	9B
0005433342762	11098	42	9D
0005433342797	11098	43	9C
0005433342771	11098	44	9E
0005435097162	11098	45	10B
0005433342775	11098	46	9F
0005433342745	11098	47	10C
0005435380233	11098	48	10E
0005433342757	11098	49	10D
0005433342730	11098	50	11A
0005433342741	11098	51	11B
0005433342767	11098	52	11D
0005433342780	11098	53	11C
0005433342760	11098	54	11F
0005433342778	11098	55	11E
0005433342756	11098	56	12A
0005435097157	11098	57	12C
0005433342736	11098	58	12B
0005433342747	11098	59	12D
0005433342798	11098	60	12E
0005433342731	11098	61	12F
0005433342792	11098	62	13B
0005433342712	11098	63	13A
0005435508203	11098	64	13C
0005433342755	11098	65	13D
0005433342705	11098	66	13E
0005433342781	11098	67	14A
0005433342782	11098	68	13F
0005433342753	11098	69	14B
0005435097163	11098	70	14C
0005433342732	11098	71	14D
0005433342788	11098	72	14F
0005433342720	11098	73	14E
0005433342715	11098	74	15B
0005433342779	11098	75	15A
0005433342783	11098	76	15D
0005433342719	11098	77	15C
0005433342738	11098	78	15F
0005435097159	11098	79	15E
0005433342726	11098	80	16B
0005433342802	11098	81	16A
0005433342742	11098	82	16C
0005433342773	11098	83	16E
0005433342766	11098	84	17A
0005435508200	11098	85	16F
0005433342796	11098	86	17B
0005433342734	11098	87	17C
0005433342769	11098	88	17E
0005433342740	11098	89	17D
0005433342707	11098	90	18A
0005433342710	11098	91	17F
0005433342790	11098	92	18B
0005435380226	11098	93	18D
0005433342721	11098	94	18C
0005433342748	11098	95	18E
0005433342706	11098	96	18F
0005433342723	11098	97	19A
0005433342774	11098	98	19C
0005433342702	11098	99	19B
0005435508180	11098	100	19D
0005433342727	11098	101	19E
0005433342787	11098	102	19F
0005433342785	11098	103	20A
0005433342763	11098	104	20B
0005433342725	11098	105	20D
0005433342724	11098	106	20C
0005433342758	11098	107	20E
0005435097160	11098	108	21A
0005435380234	11098	109	20F
0005435508210	11098	110	21C
0005433342746	11098	111	21B
0005433342793	11098	112	21D
0005433342777	11098	113	21F
0005433342768	11098	114	21E
0005433342752	11098	115	22B
0005433342784	11098	116	22A
0005433342703	11098	117	22C
0005433342770	11098	118	22D
0005433342804	11098	119	22E
0005433342799	11098	120	23A
0005435097164	11098	121	22F
0005433342754	11098	122	23B
0005435508206	11098	123	23D
0005433342718	11098	124	23C
0005433342717	11098	125	23E
0005433342772	11098	126	23F
0005435545701	17101	1	1A
0005433341726	17101	2	1C
0005435545706	17101	3	1D
0005433341754	17101	4	2A
0005433342182	17101	5	1F
0005433342189	17101	6	2D
0005435545700	17101	7	2C
0005433341535	17101	8	2F
0005435097111	17101	9	3C
0005433341426	17101	10	3A
0005432293197	17101	11	3D
0005433341413	17101	12	3F
0005433341805	17101	13	4A
0005433341623	17101	14	4B
0005433341986	17101	15	4D
0005433341447	17101	16	4E
0005433341631	17101	17	4F
0005433341821	17101	18	5A
0005433341862	17101	19	5C
0005433342177	17101	20	5B
0005432293198	17101	21	5D
0005433341655	17101	22	5E
0005433341572	17101	23	5F
0005435545699	17101	24	6B
0005433342044	17101	25	6A
0005433342337	17101	26	6C
0005433342275	17101	27	6D
0005435380280	17101	28	6F
0005433342309	17101	29	7A
0005433342017	17101	30	7C
0005433341390	17101	31	7D
0005435545713	17101	32	7F
0005433342178	17101	33	7E
0005433341489	17101	34	8A
0005433342176	17101	35	8B
0005435545711	17101	36	8D
0005433341966	17101	37	8C
0005433341675	17101	38	8E
0005435545712	17101	39	9A
0005433341427	17101	40	8F
0005433342250	17101	41	9B
0005435380277	17101	42	9D
0005433341446	17101	43	9C
0005433341624	17101	44	9E
0005433341727	17101	45	9F
0005433341582	17101	46	10B
0005433341888	17101	47	10C
0005435380275	17101	48	10D
0005432293199	17101	49	11A
0005433342172	17101	50	10E
0005433342101	17101	51	11B
0005435380276	17101	52	11C
0005435545714	17101	53	11E
0005433341612	17101	54	11D
0005433341752	17101	55	12A
0005433341995	17101	56	12C
0005433341625	17101	57	12B
0005435545710	17101	58	12D
0005433341490	17101	59	12E
0005433342179	17101	60	13A
0005433342099	17101	61	12F
0005435545697	17101	62	13C
0005435545708	17101	63	13E
0005433342019	17101	64	13D
0005435545709	17101	65	13F
0005433341685	17101	66	14A
0005433342251	17101	67	14C
0005433341981	17101	68	14B
0005433342072	17101	69	14D
0005433341873	17101	70	14F
0005433341755	17101	71	14E
0005435545703	17101	72	15A
0005433341949	17101	73	15B
0005433341686	17101	74	15C
0005433341757	17101	75	15D
0005433341817	17101	76	15F
0005433341751	17101	77	16B
0005433342018	17101	78	16A
0005433341789	17101	79	16D
0005433342021	17101	80	16C
0005433342138	17101	81	16E
0005433341849	17101	82	17A
0005435545707	17101	83	16F
0005433341998	17101	84	17B
0005433341844	17101	85	17C
0005433341813	17101	86	17D
0005433341748	17101	87	17F
0005433341741	17101	88	17E
0005433341842	17101	89	18A
0005433341965	17101	90	18B
0005433342188	17101	91	18C
0005433342045	17101	92	18E
0005435097050	17101	93	18D
0005433341766	17101	94	19B
0005435380278	17101	95	19A
0005435545704	17101	96	18F
0005435545702	17101	97	19D
0005433341816	17101	98	19C
0005433341747	17101	99	20A
0005433342062	17101	100	19F
0005433341632	17101	101	19E
0005433341455	17101	102	20B
0005435545698	17101	103	20D
0005433341581	17101	104	20C
0005435097095	17101	105	20E
0005433341701	17101	106	20F
0005433341548	17101	107	21B
0005435380279	17101	108	21A
0005433341765	17101	109	21D
0005433341728	17101	110	21E
0005435097110	17101	111	22A
0005433341788	17101	112	21F
0005433341843	17101	113	22B
0005433341767	17101	114	22C
0005433341389	17101	115	22D
0005433342054	17101	116	22F
0005435545705	17101	117	22E
0005433341729	17101	118	23A
0005433342173	17101	119	23B
0005433341845	17101	120	23C
0005433341742	17101	121	23D
0005435097043	17101	122	23F
0005433342053	17101	123	23E
0005433507115	9097	1	1A
0005433481138	9097	2	1C
0005432919652	9097	3	1D
0005433507117	9097	4	1F
0005432919511	9097	5	2F
0005432919571	9097	6	3F
0005433481139	9097	7	4C
0005433507107	9097	8	4E
0005433507104	9097	9	4F
0005433507116	9097	10	5A
0005432919542	9097	11	5D
0005433507098	9097	12	5E
0005433507103	9097	13	6E
0005432919583	9097	14	7A
0005433507113	9097	15	7D
0005432919552	9097	16	7E
0005432919621	9097	17	8A
0005432919631	9097	18	8C
0005433507102	9097	19	8D
0005432919554	9097	20	8E
0005433481132	9097	21	8F
0005432919619	9097	22	9A
0005432919513	9097	23	9D
0005432919653	9097	24	10C
0005432919601	9097	25	10D
0005433507099	9097	26	10E
0005433507106	9097	27	11A
0005433507114	9097	28	12A
0005433507110	9097	29	12C
0005433507105	9097	30	13C
0005432919632	9097	31	13D
0005432919638	9097	32	14A
0005433481133	9097	33	14C
0005433481137	9097	34	14E
0005432919518	9097	35	14F
0005432919555	9097	36	15A
0005433507111	9097	37	15D
0005433481135	9097	38	15F
0005432919538	9097	39	16C
0005432919512	9097	40	16E
0005433507100	9097	41	16F
0005432919517	9097	42	17D
0005433481134	9097	43	17F
0005433507112	9097	44	18C
0005432919618	9097	45	18D
0005433507108	9097	46	19A
0005433507109	9097	47	19D
0005432919537	9097	48	19E
0005433507101	9097	49	20D
0005432919576	9097	50	20E
0005433481136	9097	51	20F
0005433506913	20450	1	1A
0005432919791	20450	2	1D
0005433506899	20450	3	2A
0005433506957	20450	4	2F
0005432919800	20450	5	3C
0005433506995	20450	6	3D
0005434158970	20450	7	3F
0005432919794	20450	8	4C
0005433506914	20450	9	4F
0005433506937	20450	10	5E
0005432919784	20450	11	5F
0005433507068	20450	12	6A
0005434158968	20450	13	6C
0005433506926	20450	14	6D
0005433506885	20450	15	7A
0005433507069	20450	16	7D
0005432919798	20450	17	7E
0005433481052	20450	18	7F
0005432919796	20450	19	8C
0005432919783	20450	20	8D
0005433481095	20450	21	8E
0005433506900	20450	22	9D
0005434158972	20450	23	9F
0005433506898	20450	24	10C
0005432919785	20450	25	10D
0005433481066	20450	26	10E
0005433507001	20450	27	10F
0005433481076	20450	28	11A
0005432919795	20450	29	11C
0005433506950	20450	30	11D
0005433506875	20450	31	12C
0005433507014	20450	32	12D
0005432919792	20450	33	12F
0005434158971	20450	34	13C
0005433506936	20450	35	13D
0005432919797	20450	36	13E
0005432919787	20450	37	14D
0005432919786	20450	38	14F
0005433506954	20450	39	15C
0005432919788	20450	40	15D
0005432919793	20450	41	16A
0005434158969	20450	42	16D
0005433506966	20450	43	16F
0005433506960	20450	44	17D
0005432919799	20450	45	17E
0005432919801	20450	46	18C
0005433506951	20450	47	18D
0005432919789	20450	48	18F
0005433506967	20450	49	19A
0005432919781	20450	50	19C
0005433506956	20450	51	19E
0005433481077	20450	52	20A
0005432919782	20450	53	20D
0005432919790	20450	54	20E
0005432396221	10172	1	1A
0005432396220	10172	2	1B
0005432394084	10172	3	2A
0005432394082	10172	4	2B
0005435178980	10172	5	3A
0005432394081	10172	6	4A
0005432396223	10172	7	3B
0005432396222	10172	8	5A
0005435178979	10172	9	4B
0005432394083	10172	10	6A
0005432396188	18357	1	1A
0005432400089	18357	2	1B
0005432400088	18357	3	2A
0005432400090	18357	4	2B
0005432396200	18357	5	3A
0005432396187	18357	6	3B
0005432396191	18357	7	4B
0005432396199	18357	8	5A
0005432396189	18357	9	5B
0005432400069	18357	10	6A
0005432396190	18357	11	6B
0005435625920	10977	1	1D
0005435125818	10977	2	1F
0005435625941	10977	3	2A
0005435125778	10977	4	2C
0005435125808	10977	5	2D
0005434928287	10977	6	2F
0005435125867	10977	7	3A
0005435625929	10977	8	4A
0005434411760	10977	9	4D
0005435625937	10977	10	4F
0005435125777	10977	11	5C
0005435625888	10977	12	5D
0005435125774	10977	13	5E
0005435554129	10977	14	5F
0005435125773	10977	15	6C
0005435625858	10977	16	6D
0005435125807	10977	17	7A
0005435126054	10977	18	7D
0005435125819	10977	19	7E
0005435554125	10977	20	7F
0005434411761	10977	21	8A
0005435125831	10977	22	8D
0005435125875	10977	23	8F
0005435625914	10977	24	9C
0005435554124	10977	25	9D
0005435125750	10977	26	9E
0005435125787	10977	27	9F
0005435625940	10977	28	10A
0005435625930	10977	29	10C
0005435125775	10977	30	10D
0005435125876	10977	31	10F
0005435554121	10977	32	11A
0005435125934	10977	33	11D
0005435125715	10977	34	11E
0005435625897	10977	35	11F
0005435125681	10977	36	12A
0005435625890	10977	37	12D
0005435625921	10977	38	12E
0005435125814	10977	39	13A
0005435125798	10977	40	13C
0005435126053	10977	41	13E
0005435125776	10977	42	13F
0005435625945	10977	43	14C
0005435625891	10977	44	14D
0005435125820	10977	45	14E
0005435125765	10977	46	15A
0005435125830	10977	47	15D
0005435554130	10977	48	15E
0005434411763	10977	49	16A
0005435625946	10977	50	16D
0005435554126	10977	51	16E
0005435125828	10977	52	16F
0005435556659	10977	53	17A
0005435556660	10977	54	17C
0005435125866	10977	55	17D
0005435125827	10977	56	17F
0005435125939	10977	57	18A
0005435125771	10977	58	18C
0005435125670	10977	59	18D
0005435125935	10977	60	18E
0005435625857	10977	61	18F
0005435625887	10977	62	19C
0005434928286	10977	63	19D
0005434928288	10977	64	19E
0005435625924	10977	65	19F
0005435625935	10977	66	20A
0005435125772	10977	67	20D
0005435625903	10977	68	20E
0005434411762	10977	69	20F
0005435126211	14750	1	1A
0005435126199	14750	2	1D
0005435126196	14750	3	1F
0005435126214	14750	4	2A
0005435126222	14750	5	3A
0005435126188	14750	6	3C
0005435626094	14750	7	4A
0005435126197	14750	8	4C
0005435126210	14750	9	4E
0005435126192	14750	10	4F
0005435626101	14750	11	5C
0005435626107	14750	12	5D
0005434928266	14750	13	5E
0005435554164	14750	14	5F
0005435126226	14750	15	6C
0005434928263	14750	16	6D
0005435126195	14750	17	6E
0005435556681	14750	18	7A
0005435626104	14750	19	7D
0005435126202	14750	20	7E
0005435626095	14750	21	7F
0005435626100	14750	22	8A
0005435626099	14750	23	8C
0005435126201	14750	24	8D
0005435126227	14750	25	8F
0005435126224	14750	26	9A
0005435126216	14750	27	9C
0005435626097	14750	28	9E
0005435626108	14750	29	9F
0005435126223	14750	30	10A
0005435126194	14750	31	10C
0005435126220	14750	32	10D
0005435126203	14750	33	10E
0005435126200	14750	34	11A
0005435126213	14750	35	11C
0005435126208	14750	36	11D
0005435126190	14750	37	11F
0005435126189	14750	38	12C
0005435626109	14750	39	12D
0005435126218	14750	40	12E
0005435126191	14750	41	12F
0005434928269	14750	42	13A
0005435626092	14750	43	13C
0005435126219	14750	44	13D
0005435626093	14750	45	13E
0005435626106	14750	46	13F
0005435126217	14750	47	14A
0005435554165	14750	48	14C
0005434928270	14750	49	14D
0005435126230	14750	50	14F
0005435626103	14750	51	15A
0005434411725	14750	52	15C
0005435126212	14750	53	15D
0005435126193	14750	54	15E
0005435556683	14750	55	16A
0005435126204	14750	56	16C
0005435126225	14750	57	16D
0005435126198	14750	58	16F
0005435126215	14750	59	17A
0005435626105	14750	60	17C
0005435126207	14750	61	17D
0005435126228	14750	62	17E
0005435556682	14750	63	17F
0005435556680	14750	64	18A
0005434411715	14750	65	18C
0005435126209	14750	66	18D
0005435126206	14750	67	18E
0005435126205	14750	68	18F
0005435626102	14750	69	19A
0005434928273	14750	70	19C
0005435126229	14750	71	19F
0005435626096	14750	72	20A
0005435626098	14750	73	20C
0005435554166	14750	74	20D
0005435126221	14750	75	20F
0005432400105	7108	1	1A
0005435715393	7108	2	1C
0005435443177	7108	3	1D
0005435219167	7108	4	1F
0005435216565	7108	5	2C
0005435443162	7108	6	2D
0005435443186	7108	7	3D
0005435715389	7108	8	3F
0005435715391	7108	9	4C
0005432400108	7108	10	4E
0005432398180	7108	11	5C
0005435443153	7108	12	6A
0005435216553	7108	13	7C
0005435715392	7108	14	7F
0005435443216	7108	15	8F
0005432398183	7108	16	9A
0005435715397	7108	17	9C
0005435715405	7108	18	9D
0005432400107	7108	19	9F
0005435715400	7108	20	10A
0005432398181	7108	21	10C
0005435443219	7108	22	10D
0005435715398	7108	23	11A
0005435219174	7108	24	10F
0005435715390	7108	25	11F
0005435216554	7108	26	12A
0005435443179	7108	27	12D
0005435178470	7108	28	12E
0005432400106	7108	29	12F
0005435443248	7108	30	13E
0005435715395	7108	31	14C
0005435715404	7108	32	14D
0005435715399	7108	33	14F
0005435443249	7108	34	15A
0005435216564	7108	35	15D
0005435216559	7108	36	15F
0005432400109	7108	37	16C
0005435715403	7108	38	16D
0005435443178	7108	39	16F
0005432398185	7108	40	17A
0005435715396	7108	41	17E
0005435715402	7108	42	18A
0005432398182	7108	43	18D
0005432398184	7108	44	18F
0005435715394	7108	45	19C
0005435443217	7108	46	19E
0005435443227	7108	47	19F
0005435715401	7108	48	20A
0005435219180	7108	49	20E
0005435216566	7108	50	20F
0005432398151	27062	1	1A
0005435715230	27062	2	1C
0005435715219	27062	3	2C
0005435715185	27062	4	2F
0005435715202	27062	5	3C
0005435715284	27062	6	3D
0005435715268	27062	7	4C
0005432394047	27062	8	5D
0005432398146	27062	9	5E
0005432398136	27062	10	6A
0005435178990	27062	11	6F
0005435715215	27062	12	7A
0005435443272	27062	13	7C
0005435178489	27062	14	7E
0005435715231	27062	15	7F
0005432398141	27062	16	9A
0005435715285	27062	17	9F
0005432394059	27062	18	10A
0005435715248	27062	19	11A
0005435443278	27062	20	11C
0005432398140	27062	21	11D
0005435443276	27062	22	12A
0005435443277	27062	23	12C
0005435715205	27062	24	12D
0005432398139	27062	25	12E
0005435443270	27062	26	12F
0005435178490	27062	27	13A
0005435715325	27062	28	13E
0005435715289	27062	29	14C
0005435715203	27062	30	14D
0005435715186	27062	31	14E
0005435715246	27062	32	15A
0005435715209	27062	33	15C
0005435443271	27062	34	17E
0005435715220	27062	35	18C
0005435443269	27062	36	18D
0005435715247	27062	37	19C
0005435443273	27062	38	19D
0005435715210	27062	39	19E
0005435443275	27062	40	20A
0005435443274	27062	41	20E
0005434084912	2743	1	1A
0005434084910	2743	2	2B
0005434084914	2743	3	3B
0005433060385	2743	4	4A
0005434084913	2743	5	4B
0005434084911	2743	6	5B
0005433060386	2743	7	6B
0005433060402	28500	1	2A
0005434084865	28500	2	4B
0005434084871	28500	3	5B
0005434084866	28500	4	6B
0005432632698	25195	1	1A
0005432632697	25195	2	1B
0005432632689	25195	3	1C
0005432632695	25195	4	2B
0005432632703	25195	5	2D
0005432632691	25195	6	3B
0005432632684	25195	7	3C
0005432632694	25195	8	4C
0005432632690	25195	9	4D
0005432632699	25195	10	5C
0005432632685	25195	11	5D
0005432632692	25195	12	6A
0005432632701	25195	13	6B
0005435844260	25195	14	6C
0005432632696	25195	15	6D
0005432632704	25195	16	7C
0005432632688	25195	17	18C
0005432632693	25195	18	18D
0005432632700	25195	19	19A
0005435844261	25195	20	19B
0005432632702	25195	21	21A
0005432632705	25195	22	21B
0005432632686	25195	23	21C
0005432632687	25195	24	23A
0005432632626	28173	1	1B
0005435844305	28173	2	2A
0005432632645	28173	3	2D
0005432632625	28173	4	3A
0005435844300	28173	5	3C
0005435844309	28173	6	3D
0005435844306	28173	7	4A
0005432632637	28173	8	4C
0005432632639	28173	9	5B
0005432632622	28173	10	6B
0005435844312	28173	11	6C
0005435844304	28173	12	7A
0005432632653	28173	13	7B
0005435844301	28173	14	7C
0005432632654	28173	15	7D
0005435844310	28173	16	18B
0005432632638	28173	17	18C
0005435844307	28173	18	19B
0005435844303	28173	19	19D
0005435844308	28173	20	20A
0005432632628	28173	21	20B
0005435844311	28173	22	20C
0005432632621	28173	23	21C
0005432632642	28173	24	22B
0005435844302	28173	25	22C
0005435844299	28173	26	22D
0005432632630	28173	27	23A
0005432632646	28173	28	23B
0005435540849	11380	1	1A
0005435517749	11380	2	1C
0005435517664	11380	3	1D
0005435540738	11380	4	2A
0005435517677	11380	5	3C
0005435540774	11380	6	4E
0005435517788	11380	7	5A
0005435517676	11380	8	5C
0005435540815	11380	9	5E
0005435540634	11380	10	5F
0005435540756	11380	11	6C
0005435540678	11380	12	6F
0005435517724	11380	13	7A
0005435540742	11380	14	8A
0005435540732	11380	15	8C
0005435540635	11380	16	8D
0005435540633	11380	17	8F
0005435517711	11380	18	9A
0005435540696	11380	19	9E
0005435517765	11380	20	10C
0005435540740	11380	21	11A
0005435540768	11380	22	11F
0005435517764	11380	23	12D
0005435517712	11380	24	12F
0005435540679	11380	25	13E
0005435540727	11380	26	14A
0005435517665	11380	27	15F
0005435517689	11380	28	16C
0005435517746	11380	29	16E
0005435517732	11380	30	17A
0005435540677	11380	31	17D
0005435540739	11380	32	17C
0005435517624	11380	33	18C
0005435540733	11380	34	18E
0005435517623	11380	35	18F
0005435540850	11380	36	19C
0005435517683	11380	37	19F
0005435529158	22247	1	1A
0005432294474	22247	2	1D
0005435540900	22247	3	2D
0005435540909	22247	4	4A
0005435529160	22247	5	4C
0005435540910	22247	6	4F
0005435540906	22247	7	5A
0005435540891	22247	8	5D
0005435529157	22247	9	5F
0005435540896	22247	10	6D
0005435529153	22247	11	6E
0005435540890	22247	12	7D
0005435529162	22247	13	8A
0005435529152	22247	14	8C
0005435540902	22247	15	8D
0005432294475	22247	16	8E
0005435529163	22247	17	9C
0005432294476	22247	18	9D
0005435529147	22247	19	9F
0005435529148	22247	20	10A
0005435540897	22247	21	10C
0005435529145	22247	22	11A
0005435540892	22247	23	11D
0005435540903	22247	24	12D
0005435529150	22247	25	12E
0005435529164	22247	26	13A
0005435529159	22247	27	13E
0005435529161	22247	28	13F
0005435540907	22247	29	14A
0005435540898	22247	30	14C
0005435529151	22247	31	14E
0005435540899	22247	32	15E
0005435540888	22247	33	15F
0005435540905	22247	34	16E
0005435540904	22247	35	16F
0005435529166	22247	36	17A
0005435529144	22247	37	17C
0005435540895	22247	38	17D
0005435540893	22247	39	17F
0005435540889	22247	40	18A
0005435529165	22247	41	18C
0005435529149	22247	42	18E
0005435540901	22247	43	19D
0005435529154	22247	44	19E
0005435529146	22247	45	19F
0005435540908	22247	46	20C
0005435540894	22247	47	20D
0005435529156	22247	48	20E
0005435529155	22247	49	20F
0005433250945	2313	1	1A
0005433250946	2313	2	1C
0005433251148	2313	3	1F
0005434907056	2313	4	2C
0005433251106	2313	5	2D
0005434907071	2313	6	2F
0005434907074	2313	7	3C
0005433251178	2313	8	3D
0005434907075	2313	9	3F
0005434907094	2313	10	4C
0005434907091	2313	11	4D
0005434907063	2313	12	4E
0005433251196	2313	13	4F
0005434907055	2313	14	5A
0005433251112	2313	15	5C
0005433251169	2313	16	5D
0005434907102	2313	17	5E
0005433400941	2313	18	5F
0005434907078	2313	19	6A
0005434907081	2313	20	6C
0005433251099	2313	21	6D
0005434907099	2313	22	6E
0005433400943	2313	23	6F
0005434907103	2313	24	7A
0005434907090	2313	25	7C
0005434907060	2313	26	7E
0005434907068	2313	27	7F
0005434907100	2313	28	8A
0005434907088	2313	29	8C
0005433251147	2313	30	8D
0005433250948	2313	31	8F
0005434907070	2313	32	9A
0005433250947	2313	33	9C
0005434907085	2313	34	9D
0005434907080	2313	35	9E
0005434907092	2313	36	9F
0005434907058	2313	37	10C
0005434907093	2313	38	10D
0005434907087	2313	39	10E
0005433251100	2313	40	10F
0005433251168	2313	41	11A
0005433251177	2313	42	11C
0005434907101	2313	43	11D
0005433400949	2313	44	11E
0005433251121	2313	45	11F
0005434907076	2313	46	12A
0005434907067	2313	47	12C
0005434907077	2313	48	12D
0005433400948	2313	49	12E
0005434907095	2313	50	12F
0005434907089	2313	51	13A
0005434907079	2313	52	13C
0005434907061	2313	53	13D
0005434907082	2313	54	13E
0005434907072	2313	55	13F
0005434907066	2313	56	14A
0005434907096	2313	57	14C
0005433251092	2313	58	14D
0005433251137	2313	59	14E
0005433251195	2313	60	15A
0005434907069	2313	61	15C
0005433251273	2313	62	15E
0005433251203	2313	63	15F
0005434907057	2313	64	16A
0005434907097	2313	65	16C
0005434907086	2313	66	16D
0005434907054	2313	67	16E
0005434907062	2313	68	17A
0005434907073	2313	69	17C
0005433251101	2313	70	17D
0005433251207	2313	71	17E
0005433251035	2313	72	17F
0005433400942	2313	73	18A
0005433251046	2313	74	18C
0005433251113	2313	75	18D
0005434907098	2313	76	18E
0005433250961	2313	77	18F
0005434907059	2313	78	19A
0005433251017	2313	79	19C
0005434907084	2313	80	19D
0005434907064	2313	81	19E
0005434907083	2313	82	19F
0005433251034	2313	83	20A
0005434907065	2313	84	20C
0005433250960	2313	85	20E
0005433251359	25577	1	1A
0005433251344	25577	2	1C
0005434906779	25577	3	1D
0005434906487	25577	4	1F
0005433251366	25577	5	2A
0005434906580	25577	6	2C
0005433251345	25577	7	2D
0005433251367	25577	8	2F
0005433251350	25577	9	3A
0005433251362	25577	10	3C
0005433251353	25577	11	3D
0005433251342	25577	12	3F
0005433251365	25577	13	4A
0005434906574	25577	14	4C
0005434906722	25577	15	4D
0005433251363	25577	16	4E
0005434906746	25577	17	4F
0005434906729	25577	18	5A
0005433251369	25577	19	5C
0005434906362	25577	20	5D
0005433251368	25577	21	5E
0005434906571	25577	22	5F
0005434906678	25577	23	6A
0005433251346	25577	24	6C
0005434906679	25577	25	6D
0005434906483	25577	26	6E
0005434906504	25577	27	6F
0005434906799	25577	28	7A
0005433251343	25577	29	7C
0005434906379	25577	30	7D
0005434906406	25577	31	7E
0005434906488	25577	32	7F
0005433251358	25577	33	8A
0005433251364	25577	34	8C
0005434906780	25577	35	8D
0005433251360	25577	36	8E
0005434906617	25577	37	8F
0005434906652	25577	38	9A
0005433251356	25577	39	9C
0005433251357	25577	40	9D
0005433251340	25577	41	9E
0005434906638	25577	42	9F
0005434906794	25577	43	10A
0005434906809	25577	44	10C
0005434906404	25577	45	10D
0005433251341	25577	46	10E
0005434906596	25577	47	10F
0005434906665	25577	48	11A
0005434906579	25577	49	11C
0005433251355	25577	50	11D
0005433251361	25577	51	11E
0005433251354	25577	52	11F
0005434906639	25577	53	12A
0005434906651	25577	54	12C
0005434906611	25577	55	12D
0005434906819	25577	56	12E
0005433251352	25577	57	12F
0005433400970	25577	58	13A
0005433251338	25577	59	13D
0005433251349	25577	60	13E
0005434906489	25577	61	13F
0005434906531	25577	62	14A
0005434906618	25577	63	14C
0005434906429	25577	64	14D
0005434906756	25577	65	14F
0005433251347	25577	66	15A
0005434906793	25577	67	15C
0005433251351	25577	68	15D
0005434906680	25577	69	15E
0005434906623	25577	70	15F
0005434906747	25577	71	16C
0005434906616	25577	72	16D
0005434906380	25577	73	16E
0005433400971	25577	74	16F
0005434906561	25577	75	17A
0005434906408	25577	76	17D
0005434906810	25577	77	17E
0005434906745	25577	78	18A
0005433400972	25577	79	18C
0005433251370	25577	80	18D
0005434906405	25577	81	18E
0005433251348	25577	82	18F
0005434906728	25577	83	19A
0005433251339	25577	84	19C
0005434906494	25577	85	19D
0005434906578	25577	86	19F
0005434906557	25577	87	20A
0005434906564	25577	88	20C
0005434906430	25577	89	20D
0005434906361	25577	90	20E
0005434906501	25577	91	20F
0005432620978	2502	1	1B
0005432620975	2502	2	2A
0005432620980	2502	3	2B
0005432620984	2502	4	2D
0005432862226	2502	5	3C
0005432862197	2502	6	3D
0005432862225	2502	7	4A
0005432620977	2502	8	5C
0005432620985	2502	9	5D
0005432620979	2502	10	6A
0005432862190	2502	11	6C
0005432862224	2502	12	6D
0005432620981	2502	13	7B
0005432862208	2502	14	19A
0005432862196	2502	15	19C
0005432620974	2502	16	19D
0005432620986	2502	17	20A
0005432620982	2502	18	20B
0005432620976	2502	19	20D
0005432620987	2502	20	21A
0005432620988	2502	21	22A
0005432620983	2502	22	22C
0005432862205	2502	23	23B
0005432862268	28036	1	1A
0005432620806	28036	2	1B
0005432620886	28036	3	2D
0005432620850	28036	4	3B
0005432862269	28036	5	3C
0005432620885	28036	6	4C
0005432620884	28036	7	5A
0005432862273	28036	8	7A
0005432620865	28036	9	7C
0005432862272	28036	10	18D
0005432620871	28036	11	19A
0005432620887	28036	12	21C
0005432862271	28036	13	22B
0005432862270	28036	14	22D
0005434097457	11711	1	2B
0005434097465	11711	2	3A
0005434097461	11711	3	3B
0005434097463	11711	4	4B
0005434097462	11711	5	6B
0005434097471	13016	1	3B
0005434097470	13016	2	6A
0005434191272	28026	1	3D
0005434191266	28026	2	4C
0005434191262	28026	3	4D
0005434191271	28026	4	7C
0005434191267	28026	5	13E
0005434191269	28026	6	14C
0005434191265	28026	7	14E
0005434191263	28026	8	15A
0005434191273	28026	9	15D
0005434191264	28026	10	15E
0005434191270	28026	11	18C
0005434191268	28026	12	19C
0005433451610	30987	1	2B
0005433452730	30987	2	3A
0005433452732	30987	3	3B
0005433451612	30987	4	5B
0005433452731	30987	5	5A
0005433452729	30987	6	6B
0005433451611	30987	7	6A
0005433452708	31399	1	2B
0005433452702	31399	2	2A
0005433452709	31399	3	3A
0005433452711	31399	4	3B
0005433454842	31399	5	4A
0005433452703	31399	6	5A
0005433452710	31399	7	5B
0005433454841	31399	8	6A
0005433454847	31399	9	6B
0005433129226	12011	1	1A
0005434184634	12011	2	2A
0005433129203	12011	3	2D
0005433129215	12011	4	3C
0005433134084	12011	5	4A
0005433129235	12011	6	4C
0005434184635	12011	7	4D
0005433129221	12011	8	5A
0005433134083	12011	9	5D
0005434142565	12011	10	6B
0005433129227	12011	11	7A
0005433129199	12011	12	18A
0005433129234	12011	13	19A
0005434142547	12011	14	19D
0005433129228	12011	15	19C
0005433129237	12011	16	21A
0005433134082	12011	17	21B
0005434142561	12011	18	21C
0005434142572	12011	19	21D
0005433129222	12011	20	22A
0005433129198	12011	21	22B
0005434142573	12011	22	22C
0005434142591	29831	1	1A
0005434142590	29831	2	2A
0005433134120	29831	3	2B
0005434184657	29831	4	3A
0005433131688	29831	5	3B
0005434183571	29831	6	3C
0005434142589	29831	7	3D
0005434183572	29831	8	5D
0005433131691	29831	9	6A
0005433131689	29831	10	6B
0005434184656	29831	11	6C
0005433131690	29831	12	7A
0005433134121	29831	13	7C
0005434184658	29831	14	7D
0005433134117	29831	15	19A
0005433134119	29831	16	20D
0005433131687	29831	17	21A
0005434142592	29831	18	23A
0005433134118	29831	19	23B
0005435697199	16493	1	1A
0005435697188	16493	2	1C
0005435697205	16493	3	1D
0005435697216	16493	4	2B
0005435697208	16493	5	2C
0005435697204	16493	6	2D
0005435697201	16493	7	3B
0005435697211	16493	8	3C
0005435697196	16493	9	4A
0005435697190	16493	10	4B
0005435697210	16493	11	4C
0005435697198	16493	12	4D
0005435697192	16493	13	5A
0005435697203	16493	14	5B
0005435697197	16493	15	6A
0005435697206	16493	16	6D
0005435697189	16493	17	7A
0005435697195	16493	18	7B
0005435697191	16493	19	18C
0005435697209	16493	20	18D
0005435697193	16493	21	19B
0005435697212	16493	22	19C
0005435697214	16493	23	19D
0005435697194	16493	24	20A
0005435697200	16493	25	20D
0005435697207	16493	26	21A
0005435697213	16493	27	21B
0005435697215	16493	28	22A
0005435935006	16493	29	22C
0005435697202	16493	30	23B
0005435696980	24692	1	1A
0005435696981	24692	2	1C
0005435696929	24692	3	1D
0005435696917	24692	4	2C
0005435696971	24692	5	4B
0005435697110	24692	6	4D
0005435696939	24692	7	5A
0005435697091	24692	8	5C
0005435935032	24692	9	5D
0005435696862	24692	10	6A
0005435935031	24692	11	6D
0005435696982	24692	12	7A
0005435935030	24692	13	18A
0005435696972	24692	14	18D
0005435696901	24692	15	19A
0005435697083	24692	16	19D
0005435696979	24692	17	20B
0005435696863	24692	18	20D
0005435697076	24692	19	21C
0005435697109	24692	20	22A
0005435697006	24692	21	22B
0005435697075	24692	22	22C
0005435697067	24692	23	22D
0005435697086	24692	24	23B
0005433724783	18766	1	1A
0005433724782	18766	2	2A
0005432968805	18766	3	3B
0005432968804	18766	4	4A
0005432968808	18766	5	4B
0005432968809	18766	6	5A
0005433724784	18766	7	5B
0005433724786	18766	8	6A
0005433724785	18766	9	6B
0005433724731	21645	1	1A
0005432968832	21645	2	1B
0005433724752	21645	3	2B
0005433724751	21645	4	3B
0005432968833	21645	5	4B
0005433724753	21645	6	4A
0005433724754	21645	7	6A
0005434137860	7311	1	1A
0005434137798	7311	2	1C
0005434137870	7311	3	1D
0005434137846	7311	4	1F
0005434137845	7311	5	2A
0005434137865	7311	6	2C
0005434137820	7311	7	2D
0005434137833	7311	8	2F
0005434137832	7311	9	3A
0005434137859	7311	10	3C
0005434137799	7311	11	3D
0005434137817	7311	12	3F
0005434137850	7311	13	4C
0005434137807	7311	14	4D
0005434137797	7311	15	4E
0005434137806	7311	16	4F
0005434087493	7311	17	5A
0005434137855	7311	18	5C
0005434137794	7311	19	5D
0005434137862	7311	20	5E
0005434137813	7311	21	5F
0005434137834	7311	22	6A
0005434137801	7311	23	6C
0005434137809	7311	24	6D
0005434137808	7311	25	6E
0005434137867	7311	26	6F
0005434087491	7311	27	7A
0005434137786	7311	28	7C
0005434137819	7311	29	7D
0005434137803	7311	30	7E
0005434087495	7311	31	7F
0005434137785	7311	32	8A
0005434137792	7311	33	8C
0005434137868	7311	34	8D
0005434137804	7311	35	8E
0005434137790	7311	36	8F
0005434137837	7311	37	9C
0005434137811	7311	38	9D
0005434137821	7311	39	9E
0005434137826	7311	40	9F
0005434137852	7311	41	10A
0005434137829	7311	42	10C
0005434137842	7311	43	10D
0005434087494	7311	44	10E
0005434137800	7311	45	10F
0005434137843	7311	46	11A
0005434137824	7311	47	11C
0005434137793	7311	48	11D
0005434137840	7311	49	11E
0005434137823	7311	50	11F
0005434137858	7311	51	12A
0005434137815	7311	52	12C
0005434137848	7311	53	12D
0005434137866	7311	54	12E
0005434137851	7311	55	12F
0005434137818	7311	56	13A
0005434137789	7311	57	13C
0005434137795	7311	58	13D
0005434137812	7311	59	13E
0005434137791	7311	60	13F
0005434137805	7311	61	14C
0005434137788	7311	62	14D
0005434137825	7311	63	14E
0005434137816	7311	64	14F
0005434137787	7311	65	15A
0005434137856	7311	66	15C
0005434137838	7311	67	15D
0005434137869	7311	68	15E
0005434137835	7311	69	15F
0005434137853	7311	70	16A
0005434137864	7311	71	16C
0005434137847	7311	72	16D
0005434137844	7311	73	16F
0005434137836	7311	74	17C
0005434137861	7311	75	17D
0005434137841	7311	76	17E
0005434137863	7311	77	17F
0005434137839	7311	78	18A
0005434137830	7311	79	18C
0005434137857	7311	80	18D
0005434137822	7311	81	18E
0005434137796	7311	82	18F
0005434137849	7311	83	19A
0005434137810	7311	84	19C
0005434137828	7311	85	19D
0005434137827	7311	86	19E
0005434137854	7311	87	19F
0005434087492	7311	88	20A
0005434137814	7311	89	20C
0005434137831	7311	90	20D
0005434137802	7311	91	20F
0005434136789	28570	1	1A
0005434136790	28570	2	1C
0005434137020	28570	3	1D
0005434136954	28570	4	1F
0005434136782	28570	5	2A
0005434136774	28570	6	2C
0005434136759	28570	7	2D
0005434137055	28570	8	2F
0005434087464	28570	9	3A
0005434137175	28570	10	3C
0005434087449	28570	11	3D
0005434137180	28570	12	3F
0005434137236	28570	13	4A
0005434137137	28570	14	4C
0005434136784	28570	15	4D
0005434137136	28570	16	4E
0005434136985	28570	17	5C
0005434087456	28570	18	5D
0005434137161	28570	19	5E
0005434136892	28570	20	5F
0005434087457	28570	21	6A
0005434137172	28570	22	6C
0005434136991	28570	23	6D
0005434136996	28570	24	6E
0005434136820	28570	25	7A
0005434137163	28570	26	7C
0005434136987	28570	27	7D
0005434137162	28570	28	7E
0005434087438	28570	29	7F
0005434136990	28570	30	8A
0005434137125	28570	31	8C
0005434137126	28570	32	8D
0005434137083	28570	33	8E
0005434136685	28570	34	8F
0005434136696	28570	35	9A
0005434137293	28570	36	9C
0005434137092	28570	37	9D
0005434136695	28570	38	9E
0005434137084	28570	39	9F
0005434087443	28570	40	10A
0005434137047	28570	41	10C
0005434136901	28570	42	10D
0005434137207	28570	43	10E
0005434137292	28570	44	10F
0005434087439	28570	45	11A
0005434137160	28570	46	11C
0005434136952	28570	47	11D
0005434137085	28570	48	11E
0005434136775	28570	49	11F
0005434136847	28570	50	12A
0005434136858	28570	51	12C
0005434136926	28570	52	12D
0005434136705	28570	53	12E
0005434137200	28570	54	12F
0005434136697	28570	55	13C
0005434136833	28570	56	13D
0005434136997	28570	57	13E
0005434137145	28570	58	13F
0005434137308	28570	59	14A
0005434137174	28570	60	14C
0005434136986	28570	61	14D
0005434136953	28570	62	14E
0005434137190	28570	63	14F
0005434137173	28570	64	15A
0005434087454	28570	65	15C
0005434137019	28570	66	15D
0005434136989	28570	67	15E
0005434137029	28570	68	16A
0005434136694	28570	69	16C
0005434087448	28570	70	16D
0005434137252	28570	71	16E
0005434137102	28570	72	16F
0005434136794	28570	73	17A
0005434136824	28570	74	17C
0005434136972	28570	75	17D
0005434136971	28570	76	17E
0005434136927	28570	77	17F
0005434137171	28570	78	18C
0005434136939	28570	79	18E
0005434137211	28570	80	18F
0005434137022	28570	81	19A
0005434137201	28570	82	19C
0005434136706	28570	83	19D
0005434087463	28570	84	19E
0005434136951	28570	85	20A
0005434136923	28570	86	20C
0005434137251	28570	87	20D
0005434136795	28570	88	20E
0005434087455	28570	89	20F
0005435808191	1914	1	2A
0005435808198	1914	2	2B
0005433407482	1914	3	2C
0005434610213	1914	4	5A
0005435808197	1914	5	5B
0005435808190	1914	6	6B
0005434610214	1914	7	6C
0005433407491	1914	8	7A
0005435808193	1914	9	7B
0005435808189	1914	10	7C
0005434610215	1914	11	19D
0005435808199	1914	12	21A
0005435808192	1914	13	21B
0005435808195	1914	14	21C
0005435808188	1914	15	21D
0005435808196	1914	16	23A
0005435808194	1914	17	23B
0005434610188	23103	1	1C
0005434610185	23103	2	4B
0005434610187	23103	3	4D
0005434610186	23103	4	5C
0005434610178	23103	5	6C
0005434610189	23103	6	20B
0005434610179	23103	7	21B
0005434503518	16708	1	1B
0005434503601	16708	2	1C
0005434503672	16708	3	1D
0005434503596	16708	4	2A
0005434503552	16708	5	2B
0005434503861	16708	6	2C
0005434503860	16708	7	2D
0005434503467	16708	8	3A
0005434503764	16708	9	3B
0005434503588	16708	10	3C
0005434503671	16708	11	3D
0005434503553	16708	12	4A
0005434503511	16708	13	4B
0005434503641	16708	14	4C
0005434503590	16708	15	4D
0005434503618	16708	16	5A
0005434503479	16708	17	5B
0005434503459	16708	18	5C
0005434503475	16708	19	5D
0005434503722	16708	20	6A
0005434503519	16708	21	6B
0005434503510	16708	22	6C
0005434503721	16708	23	6D
0005434503664	16708	24	7A
0005434503695	16708	25	7C
0005434503637	16708	26	7B
0005434503599	16708	27	7D
0005434503600	16708	28	18B
0005434503460	16708	29	18C
0005434503567	16708	30	18D
0005434503762	16708	31	19A
0005434503474	16708	32	19B
0005434503468	16708	33	19C
0005434503785	16708	34	19D
0005434503481	16708	35	20A
0005434503707	16708	36	20B
0005434503688	16708	37	20C
0005434503692	16708	38	20D
0005434503765	16708	39	21A
0005434503648	16708	40	21B
0005434503612	16708	41	21C
0005434503484	16708	42	21D
0005434503626	16708	43	22A
0005434503621	16708	44	22C
0005434503480	16708	45	22D
0005434503642	16708	46	23A
0005434503602	16708	47	23B
0005434503959	22923	1	1A
0005434503956	22923	2	1C
0005434503975	22923	3	1D
0005434503976	22923	4	2A
0005434503957	22923	5	2B
0005434503946	22923	6	2C
0005434503954	22923	7	2D
0005434503945	22923	8	3B
0005434503966	22923	9	3C
0005434503970	22923	10	3D
0005434503969	22923	11	4B
0005434503962	22923	12	4C
0005434503978	22923	13	4D
0005434503941	22923	14	5A
0005434503980	22923	15	5B
0005434503949	22923	16	5C
0005434503965	22923	17	5D
0005434503955	22923	18	6A
0005434503948	22923	19	6B
0005434503981	22923	20	6C
0005434503974	22923	21	6D
0005434503953	22923	22	7B
0005434503968	22923	23	7C
0005434503973	22923	24	7D
0005434503942	22923	25	18A
0005434503943	22923	26	18B
0005434503944	22923	27	18C
0005434503972	22923	28	18D
0005434503958	22923	29	19A
0005434503977	22923	30	19B
0005434503950	22923	31	19C
0005434503952	22923	32	19D
0005434503967	22923	33	20A
0005434503979	22923	34	20B
0005434503940	22923	35	20C
0005434503960	22923	36	20D
0005434503951	22923	37	21A
0005434503947	22923	38	21B
0005434503963	22923	39	22B
0005434503961	22923	40	22C
0005434503964	22923	41	23A
0005434503971	22923	42	23B
0005435078276	2173	1	1C
0005433266580	2173	2	2A
0005435078279	2173	3	2B
0005435078274	2173	4	3A
0005435078280	2173	5	3B
0005435078283	2173	6	4A
0005433266567	2173	7	4B
0005435078286	2173	8	4C
0005435078278	2173	9	5B
0005433266609	2173	10	6B
0005435078275	2173	11	7D
0005433266626	2173	12	18C
0005433266625	2173	13	18D
0005435078277	2173	14	19C
0005435078272	2173	15	20A
0005433266603	2173	16	20C
0005435078285	2173	17	21C
0005433266579	2173	18	21D
0005435078282	2173	19	22C
0005435078273	2173	20	22D
0005435078284	2173	21	23A
0005435078281	2173	22	23B
0005435078154	24327	1	1B
0005435078196	24327	2	2C
0005435078090	24327	3	2D
0005433266685	24327	4	3A
0005433266684	24327	5	3B
0005435078111	24327	6	3D
0005435078159	24327	7	4A
0005435078116	24327	8	4D
0005433266683	24327	9	5C
0005433266686	24327	10	5D
0005433266687	24327	11	6A
0005433266688	24327	12	6D
0005433266689	24327	13	7A
0005433266681	24327	14	18A
0005435078176	24327	15	18B
0005435078197	24327	16	18C
0005435078100	24327	17	18D
0005435078113	24327	18	19A
0005435078115	24327	19	19B
0005435078112	24327	20	19C
0005435078137	24327	21	21B
0005435078104	24327	22	21C
0005435078110	24327	23	23A
0005433266682	24327	24	23B
0005434988700	6646	1	1D
0005434988692	6646	2	2D
0005434988701	6646	3	4A
0005434988698	6646	4	5C
0005435803253	6646	5	5D
0005434988696	6646	6	6B
0005434988699	6646	7	18A
0005434988690	6646	8	18C
0005434988691	6646	9	18D
0005434988693	6646	10	19A
0005434988697	6646	11	19D
0005434988694	6646	12	20A
0005434988695	6646	13	20B
0005435803252	6646	14	21A
0005434988575	23645	1	1A
0005434988584	23645	2	1B
0005435803222	23645	3	1C
0005434988557	23645	4	1D
0005435464498	23645	5	2B
0005434988582	23645	6	3B
0005434988587	23645	7	3D
0005434988597	23645	8	4C
0005434988586	23645	9	5A
0005435464500	23645	10	5D
0005434988594	23645	11	6A
0005435803231	23645	12	7A
0005435464499	23645	13	18D
0005435803229	23645	14	19A
0005434988571	23645	15	19B
0005434988598	23645	16	19D
0005434988576	23645	17	21D
0005434988585	23645	18	22B
0005434988570	23645	19	22D
0005434988583	23645	20	23B
0005432383033	30497	1	1A
0005432383018	30497	2	1C
0005433453755	30497	3	1D
0005432383045	30497	4	1F
0005432383014	30497	5	2A
0005433449890	30497	6	2D
0005433449893	30497	7	2C
0005432383020	30497	8	2F
0005432383038	30497	9	3A
0005432383035	30497	10	4A
0005433454869	30497	11	4C
0005433449885	30497	12	4D
0005432383036	30497	13	4E
0005433449891	30497	14	4F
0005432383015	30497	15	5A
0005432383056	30497	16	5E
0005432383034	30497	17	6C
0005432383050	30497	18	6D
0005432383030	30497	19	6E
0005432383016	30497	20	7C
0005433449874	30497	21	7E
0005433449878	30497	22	7F
0005433449886	30497	23	8A
0005433449873	30497	24	8E
0005433449879	30497	25	9A
0005433449889	30497	26	9C
0005433449875	30497	27	9D
0005432383031	30497	28	9E
0005432383027	30497	29	10A
0005432383042	30497	30	10C
0005433449877	30497	31	10D
0005433454868	30497	32	10E
0005432383044	30497	33	10F
0005433449888	30497	34	11C
0005432383054	30497	35	11D
0005432383029	30497	36	11E
0005433449880	30497	37	11F
0005432383017	30497	38	12A
0005433449892	30497	39	12C
0005432383023	30497	40	12D
0005432383053	30497	41	12E
0005432383026	30497	42	13A
0005432383013	30497	43	13D
0005432383019	30497	44	13E
0005432383028	30497	45	13F
0005433449884	30497	46	14C
0005433449876	30497	47	14E
0005432383051	30497	48	15A
0005432383041	30497	49	15C
0005432383049	30497	50	15D
0005432383032	30497	51	15E
0005432383047	30497	52	16C
0005432383043	30497	53	16D
0005432383048	30497	54	16E
0005433449882	30497	55	16F
0005433449881	30497	56	17A
0005432383039	30497	57	17C
0005433449894	30497	58	17D
0005432383055	30497	59	17E
0005433454867	30497	60	17F
0005432383024	30497	61	18A
0005432383021	30497	62	18C
0005433449887	30497	63	18D
0005432383025	30497	64	18E
0005432383046	30497	65	18F
0005432383040	30497	66	19A
0005432383037	30497	67	19D
0005433453756	30497	68	19E
0005433453757	30497	69	20A
0005432383022	30497	70	20C
0005432383052	30497	71	20E
0005433449883	30497	72	20F
0005432382680	31317	1	1C
0005432382505	31317	2	1A
0005432382662	31317	3	1F
0005432382655	31317	4	2D
0005433449764	31317	5	2F
0005432382613	31317	6	3A
0005433449699	31317	7	3D
0005432382601	31317	8	3F
0005433449690	31317	9	4A
0005432382738	31317	10	4C
0005432382656	31317	11	4D
0005432382645	31317	12	4E
0005432382523	31317	13	4F
0005432382898	31317	14	5A
0005433449715	31317	15	5C
0005432382899	31317	16	5D
0005432382595	31317	17	5E
0005433451594	31317	18	5F
0005433449736	31317	19	6A
0005433449684	31317	20	6C
0005432382651	31317	21	6D
0005433449662	31317	22	6F
0005433449689	31317	23	7A
0005432382637	31317	24	7D
0005432382657	31317	25	7E
0005432382624	31317	26	8A
0005432382708	31317	27	8C
0005432382619	31317	28	8E
0005433449663	31317	29	9A
0005432382495	31317	30	9C
0005432382525	31317	31	9E
0005432382496	31317	32	9F
0005433449686	31317	33	10D
0005433451595	31317	34	10E
0005433453733	31317	35	10F
0005432382600	31317	36	11C
0005432382654	31317	37	11D
0005433453734	31317	38	11E
0005433449647	31317	39	11F
0005432382712	31317	40	12A
0005432382776	31317	41	12C
0005433449730	31317	42	12D
0005433449713	31317	43	12E
0005432382644	31317	44	12F
0005432382579	31317	45	13A
0005433449714	31317	46	13C
0005432382625	31317	47	13D
0005433449706	31317	48	13E
0005433449589	31317	49	13F
0005433451596	31317	50	14A
0005432382711	31317	51	14F
0005432382580	31317	52	15A
0005432382535	31317	53	15C
0005432382614	31317	54	15D
0005433449698	31317	55	15E
0005432382534	31317	56	15F
0005433449702	31317	57	16A
0005433449716	31317	58	16C
0005432382681	31317	59	16D
0005433449700	31317	60	16E
0005432382596	31317	61	16F
0005432382784	31317	62	17A
0005432382629	31317	63	17D
0005433453735	31317	64	17E
0005433449679	31317	65	17F
0005433449685	31317	66	18A
0005432382500	31317	67	19A
0005433449795	31317	68	19C
0005432382636	31317	69	19D
0005433449727	31317	70	19E
0005432382618	31317	71	19F
0005432382661	31317	72	20D
0005433449697	31317	73	20E
0005432382673	31317	74	20F
0005435548481	26469	1	2D
0005435548474	26469	2	3D
0005435548480	26469	3	4B
0005435548475	26469	4	4D
0005433788146	26469	5	5B
0005435548483	26469	6	5D
0005435548477	26469	7	6A
0005435548479	26469	8	7A
0005435548482	26469	9	18D
0005433788145	26469	10	19C
0005435548476	26469	11	19D
0005433788147	26469	12	20A
0005435548478	26469	13	23B
0005435304116	10760	1	1B
0005435299710	10760	2	1C
0005435299704	10760	3	2B
0005435304106	10760	4	6A
0005435304105	10760	5	7B
0005433131635	10760	6	19D
0005433131639	10760	7	20C
0005435299707	10760	8	21C
0005433126832	29709	1	1C
0005433129262	29709	2	1D
0005435299759	29709	3	2A
0005433126833	29709	4	2C
0005433126830	29709	5	3B
0005435302185	29709	6	3C
0005435299762	29709	7	4C
0005433129261	29709	8	4D
0005435299761	29709	9	5A
0005433126834	29709	10	5D
0005435302186	29709	11	6A
0005433129260	29709	12	6B
0005435299760	29709	13	7B
0005435299763	29709	14	19B
0005433129263	29709	15	19D
0005433126829	29709	16	20A
0005435302188	29709	17	20C
0005433126831	29709	18	22A
0005435302187	29709	19	22B
0005434287210	2391	1	1A
0005433109880	2391	2	1B
0005434287189	2391	3	1C
0005434287198	2391	4	1D
0005433109908	2391	5	2A
0005433109890	2391	6	2B
0005432264464	2391	7	3A
0005434287194	2391	8	3B
0005434287200	2391	9	3C
0005434287206	2391	10	3D
0005434287197	2391	11	4B
0005434287208	2391	12	4C
0005434287209	2391	13	4D
0005432264466	2391	14	5A
0005433109883	2391	15	5C
0005433109922	2391	16	5B
0005433109907	2391	17	5D
0005434287196	2391	18	6A
0005434287188	2391	19	6B
0005434287199	2391	20	6C
0005434287201	2391	21	7A
0005432264465	2391	22	7B
0005434287203	2391	23	7C
0005433109951	2391	24	7D
0005434287191	2391	25	18A
0005434287195	2391	26	18B
0005434287193	2391	27	18C
0005433109881	2391	28	18D
0005433109854	2391	29	19C
0005434287205	2391	30	19D
0005433109921	2391	31	20A
0005433109912	2391	32	20B
0005433109882	2391	33	20C
0005434287202	2391	34	20D
0005433109927	2391	35	21A
0005433109913	2391	36	21B
0005433109870	2391	37	21C
0005434287204	2391	38	21D
0005433109903	2391	39	22A
0005434287192	2391	40	22B
0005434287190	2391	41	22C
0005433109872	2391	42	22D
0005434287207	2391	43	23A
0005433109853	2391	44	23B
0005433110002	26873	1	1A
0005433110000	26873	2	1B
0005434286977	26873	3	1C
0005433110008	26873	4	1D
0005434286930	26873	5	2A
0005433109998	26873	6	2B
0005434287025	26873	7	3C
0005433110004	26873	8	3D
0005434286946	26873	9	4B
0005433109999	26873	10	4C
0005434287006	26873	11	4D
0005434287038	26873	12	5A
0005434286988	26873	13	5B
0005434287010	26873	14	5D
0005434287004	26873	15	6A
0005434286985	26873	16	6B
0005433110009	26873	17	6C
0005434286944	26873	18	6D
0005433110007	26873	19	7A
0005433110010	26873	20	7B
0005433110003	26873	21	18B
0005433110006	26873	22	18D
0005434286986	26873	23	19A
0005433110005	26873	24	19B
0005434287014	26873	25	19D
0005434286987	26873	26	20A
0005434287037	26873	27	20B
0005434286945	26873	28	20D
0005433110001	26873	29	21A
0005434286978	26873	30	21D
0005434287042	26873	31	23A
0005434286931	26873	32	23B
0005435856186	25502	1	2A
0005434272171	25502	2	3B
0005435856185	25502	3	7B
0005434272166	25502	4	7C
0005435856187	25502	5	7D
0005435856189	25502	6	19A
0005435856188	25502	7	22D
0005435856138	26625	1	3D
0005435856154	26625	2	6C
0005435856139	26625	3	6D
0005435856167	26625	4	7C
0005435856140	26625	5	7D
0005435856141	26625	6	18C
0005435856153	26625	7	21C
0005434520228	6102	1	1A
0005434520238	6102	2	1B
0005434520241	6102	3	1D
0005434520240	6102	4	2A
0005434520244	6102	5	2B
0005435314780	6102	6	2C
0005434520229	6102	7	3B
0005434520218	6102	8	3C
0005434520221	6102	9	3D
0005434520212	6102	10	4A
0005434520235	6102	11	4B
0005435314774	6102	12	4C
0005434520230	6102	13	4D
0005435314772	6102	14	5A
0005435314781	6102	15	5B
0005434520215	6102	16	5C
0005434520214	6102	17	5D
0005434520232	6102	18	6B
0005435314779	6102	19	6C
0005434520231	6102	20	6D
0005434520222	6102	21	7A
0005435314767	6102	22	7B
0005434520220	6102	23	7C
0005434520243	6102	24	7D
0005435314783	6102	25	18A
0005434520234	6102	26	18B
0005434520217	6102	27	18C
0005434520236	6102	28	18D
0005435314785	6102	29	19A
0005434520213	6102	30	19B
0005434520242	6102	31	19C
0005435314786	6102	32	19D
0005434520224	6102	33	20A
0005434520226	6102	34	20B
0005435314773	6102	35	20C
0005434520239	6102	36	20D
0005434520233	6102	37	21A
0005435314768	6102	38	21B
0005434520227	6102	39	21C
0005434520219	6102	40	21D
0005434520216	6102	41	22A
0005434520211	6102	42	22B
0005434520225	6102	43	22C
0005434520237	6102	44	22D
0005434520223	6102	45	23A
0005435314787	6102	46	23B
0005433650410	27635	1	1A
0005433650421	27635	2	1C
0005433650378	27635	3	1D
0005433650413	27635	4	1F
0005435263583	27635	5	2A
0005433650414	27635	6	2C
0005435263577	27635	7	2D
0005433650368	27635	8	3A
0005435263572	27635	9	3D
0005433650403	27635	10	3F
0005435263575	27635	11	4A
0005435263570	27635	12	4E
0005433650438	27635	13	4F
0005435263580	27635	14	5A
0005435263586	27635	15	5D
0005433650372	27635	16	5E
0005433650373	27635	17	5F
0005435263574	27635	18	6A
0005433650382	27635	19	6C
0005435263564	27635	20	6D
0005433650447	27635	21	6E
0005433650393	27635	22	6F
0005435263593	27635	23	7A
0005433650460	27635	24	7C
0005435263565	27635	25	7D
0005435263578	27635	26	7E
0005433650457	27635	27	7F
0005433650402	27635	28	8C
0005435263590	27635	29	8E
0005435263582	27635	30	8F
0005433650418	27635	31	9A
0005433650480	27635	32	9C
0005433650380	27635	33	9D
0005433650399	27635	34	9E
0005435263587	27635	35	9F
0005435263569	27635	36	10D
0005433650458	27635	37	10E
0005435263573	27635	38	10F
0005433650423	27635	39	11D
0005433650417	27635	40	12A
0005435263568	27635	41	12C
0005435263589	27635	42	12D
0005435263567	27635	43	13A
0005433650397	27635	44	13C
0005433650429	27635	45	13D
0005433650379	27635	46	13E
0005433650371	27635	47	13F
0005435263591	27635	48	14C
0005435263594	27635	49	14D
0005433650405	27635	50	14E
0005435263595	27635	51	15A
0005433650440	27635	52	15C
0005433650504	27635	53	15D
0005433650377	27635	54	15F
0005433650425	27635	55	16A
0005433650389	27635	56	16C
0005435263571	27635	57	16E
0005435263585	27635	58	16F
0005435263579	27635	59	17A
0005435263581	27635	60	17C
0005435263566	27635	61	17E
0005435263576	27635	62	17F
0005433650407	27635	63	18A
0005433650459	27635	64	18C
0005433650398	27635	65	18D
0005433650404	27635	66	18E
0005433650383	27635	67	18F
0005435263592	27635	68	19C
0005435263584	27635	69	19D
0005433650439	27635	70	19E
0005433650424	27635	71	19F
0005433650390	27635	72	20A
0005433650452	27635	73	20D
0005433650365	27635	74	20E
0005435263588	27635	75	20F
0005433868266	4790	1	1A
0005433868291	4790	2	1B
0005433868294	4790	3	1C
0005433868273	4790	4	1D
0005433868297	4790	5	2A
0005433868268	4790	6	2B
0005433868284	4790	7	2C
0005433868274	4790	8	2D
0005433868282	4790	9	3A
0005433868277	4790	10	3B
0005433868276	4790	11	3C
0005433868295	4790	12	4A
0005433868298	4790	13	4B
0005433868270	4790	14	4C
0005433868278	4790	15	4D
0005433868265	4790	16	5A
0005433868289	4790	17	5B
0005433868285	4790	18	5C
0005433868264	4790	19	5D
0005433868271	4790	20	6B
0005433868300	4790	21	6C
0005433868304	4790	22	6D
0005433868299	4790	23	7A
0005433868283	4790	24	7B
0005433868286	4790	25	7C
0005433868290	4790	26	7D
0005433868269	4790	27	18A
0005433868263	4790	28	18B
0005433868267	4790	29	18C
0005433868293	4790	30	18D
0005433868301	4790	31	19A
0005433868303	4790	32	19B
0005433868275	4790	33	19D
0005433868288	4790	34	20A
0005433868296	4790	35	20C
0005433868292	4790	36	20D
0005433868279	4790	37	21B
0005433868272	4790	38	21C
0005433868281	4790	39	21D
0005433868287	4790	40	22A
0005433868302	4790	41	22C
0005433868280	4790	42	22D
0005433867938	32577	1	1A
0005433868012	32577	2	1B
0005435860478	32577	3	1D
0005433867908	32577	4	2A
0005433867887	32577	5	2B
0005433867959	32577	6	2C
0005433867870	32577	7	2D
0005435860475	32577	8	3A
0005435860480	32577	9	3B
0005433867753	32577	10	3C
0005433867949	32577	11	3D
0005433867756	32577	12	4B
0005433868093	32577	13	4C
0005433868092	32577	14	5A
0005433867757	32577	15	5C
0005435860477	32577	16	5D
0005433867862	32577	17	6A
0005435860479	32577	18	6B
0005433867972	32577	19	6D
0005433867912	32577	20	7B
0005433867947	32577	21	7C
0005433867806	32577	22	7D
0005433867895	32577	23	18A
0005433867854	32577	24	18B
0005433867920	32577	25	18C
0005433868004	32577	26	18D
0005433867894	32577	27	19A
0005433867867	32577	28	19B
0005433867907	32577	29	19C
0005433868029	32577	30	20B
0005433867981	32577	31	20C
0005433867869	32577	32	21B
0005433867924	32577	33	21C
0005433867868	32577	34	21D
0005435860476	32577	35	22A
0005433867993	32577	36	22B
0005433867911	32577	37	22C
0005433867855	32577	38	23A
0005433867861	32577	39	23B
0005434663354	3457	1	1A
0005434663350	3457	2	1B
0005435911363	3457	3	1C
0005435911327	3457	4	1D
0005434663358	3457	5	2B
0005434663349	3457	6	2D
0005434663355	3457	7	3A
0005435911362	3457	8	3B
0005434663352	3457	9	3D
0005434461639	3457	10	4B
0005435911358	3457	11	4C
0005434461638	3457	12	5A
0005434460497	3457	13	5B
0005435911365	3457	14	6A
0005434663348	3457	15	6B
0005434663353	3457	16	7B
0005435911361	3457	17	18B
0005435911339	3457	18	19A
0005435911337	3457	19	20B
0005434663359	3457	20	20C
0005434663351	3457	21	20D
0005434663347	3457	22	21B
0005434663356	3457	23	21C
0005434663357	3457	24	22A
0005435911338	3457	25	22D
0005434663214	12483	1	1C
0005434663205	12483	2	1D
0005434663295	12483	3	2B
0005434663248	12483	4	2C
0005434663241	12483	5	3B
0005435911425	12483	6	3D
0005434663296	12483	7	4A
0005434663256	12483	8	4B
0005434663249	12483	9	4C
0005434663262	12483	10	4D
0005434663236	12483	11	5D
0005434663289	12483	12	6C
0005434663288	12483	13	7C
0005435911422	12483	14	7D
0005434663255	12483	15	18A
0005435911423	12483	16	19A
0005434663242	12483	17	20C
0005435911421	12483	18	20D
0005435911419	12483	19	21A
0005434663254	12483	20	22A
0005434663258	12483	21	22B
0005435911424	12483	22	22C
0005435911420	12483	23	23B
0005433867938	14478	1	1A
0005433867894	14478	2	1B
0005433867920	14478	3	1C
0005433867854	14478	4	1D
0005433867870	14478	5	2A
0005433867753	14478	6	2B
0005433867911	14478	7	2C
0005433868029	14478	8	3A
0005433867861	14478	9	3B
0005435860476	14478	10	3C
0005435860479	14478	11	4A
0005433867862	14478	12	4C
0005433867806	14478	13	5A
0005433867993	14478	14	5B
0005433868093	14478	15	5D
0005433867949	14478	16	6A
0005433867908	14478	17	6B
0005435860477	14478	18	6D
0005433867912	14478	19	7A
0005435860475	14478	20	7B
0005433867756	14478	21	7C
0005433867867	14478	22	7D
0005433867887	14478	23	18A
0005433867959	14478	24	18B
0005433868004	14478	25	18C
0005433867907	14478	26	18D
0005433867757	14478	27	19B
0005433867947	14478	28	19D
0005433867924	14478	29	20A
0005433868012	14478	30	20B
0005433867981	14478	31	20C
0005435860480	14478	32	20D
0005433867972	14478	33	21C
0005433867855	14478	34	21D
0005435860478	14478	35	22B
0005433867895	14478	36	22C
0005433868092	14478	37	22D
0005433867869	14478	38	23A
0005433867868	14478	39	23B
0005433868234	32684	1	1C
0005433868254	32684	2	1D
0005433868241	32684	3	2A
0005433868242	32684	4	2B
0005433868252	32684	5	2C
0005433868229	32684	6	2D
0005433868223	32684	7	3A
0005435860441	32684	8	3B
0005433868261	32684	9	3C
0005433868226	32684	10	4A
0005433868258	32684	11	3D
0005433868232	32684	12	4B
0005433868245	32684	13	4C
0005433868248	32684	14	4D
0005433868251	32684	15	5A
0005433868257	32684	16	5B
0005433868244	32684	17	5D
0005433868237	32684	18	6A
0005433868256	32684	19	6B
0005433868259	32684	20	6C
0005433868231	32684	21	6D
0005433868243	32684	22	7A
0005433868249	32684	23	7C
0005433868235	32684	24	7B
0005433868221	32684	25	7D
0005433868233	32684	26	18A
0005433868238	32684	27	18B
0005433868250	32684	28	18C
0005435860440	32684	29	18D
0005433868253	32684	30	19A
0005433868224	32684	31	19C
0005433868260	32684	32	19D
0005433868228	32684	33	20A
0005433868262	32684	34	20B
0005433868227	32684	35	20C
0005433868239	32684	36	20D
0005433868240	32684	37	21A
0005433868222	32684	38	21B
0005435860438	32684	39	21C
0005433868236	32684	40	21D
0005433868230	32684	41	22A
0005433868247	32684	42	22B
0005433868225	32684	43	22C
0005433868255	32684	44	22D
0005433868246	32684	45	23A
0005432799112	12146	1	1A
0005432799191	12146	2	1B
0005432799015	12146	3	1C
0005432799093	12146	4	1D
0005432799071	12146	5	2C
0005432799124	12146	6	2D
0005432799017	12146	7	3B
0005432799190	12146	8	3D
0005432799140	12146	9	4A
0005432799003	12146	10	4B
0005432799220	12146	11	4C
0005432799144	12146	12	4D
0005432799145	12146	13	5B
0005432799102	12146	14	5C
0005432799141	12146	15	6B
0005432799187	12146	16	6C
0005432799053	12146	17	7A
0005432799032	12146	18	7B
0005432799125	12146	19	7D
0005432799095	12146	20	18A
0005432799081	12146	21	18B
0005432799103	12146	22	18C
0005432799096	12146	23	18D
0005432799018	12146	24	19A
0005432799100	12146	25	19C
0005432799143	12146	26	20A
0005432799142	12146	27	20D
0005432799020	12146	28	21A
0005432799113	12146	29	21B
0005432799212	12146	30	22A
0005432799019	12146	31	22C
0005432799033	12146	32	22D
0005432799122	12146	33	23A
0005432799315	14812	1	1A
0005432799305	14812	2	1B
0005432799311	14812	3	1C
0005432799309	14812	4	2A
0005432799324	14812	5	2B
0005432799318	14812	6	2C
0005432799319	14812	7	2D
0005432799308	14812	8	3A
0005432799310	14812	9	3D
0005432799323	14812	10	4B
0005432799306	14812	11	5C
0005432799325	14812	12	6B
0005432799302	14812	13	6C
0005432799317	14812	14	7A
0005432799312	14812	15	7B
0005432799316	14812	16	7C
0005432799321	14812	17	7D
0005432799313	14812	18	18B
0005432799314	14812	19	18D
0005432799307	14812	20	18C
0005432799328	14812	21	19A
0005432799327	14812	22	19B
0005432799326	14812	23	21B
0005432799322	14812	24	22B
0005432799304	14812	25	22D
0005432799303	14812	26	23B
0005432799320	14812	27	23A
0005435310874	7040	1	1C
0005434299472	7040	2	1A
0005434407478	7040	3	1F
0005434407523	7040	4	1D
0005434407509	7040	5	2C
0005434407510	7040	6	2A
0005435310920	7040	7	2D
0005434299460	7040	8	2F
0005434407517	7040	9	3A
0005434407499	7040	10	3D
0005434407488	7040	11	3C
0005434407494	7040	12	3F
0005434407534	7040	13	4A
0005434407540	7040	14	4C
0005434407502	7040	15	4B
0005434407526	7040	16	4D
0005435310868	7040	17	4E
0005434407515	7040	18	5A
0005435293059	7040	19	4F
0005434299464	7040	20	5B
0005434407498	7040	21	5C
0005434407529	7040	22	5D
0005435293086	7040	23	5E
0005434407528	7040	24	6A
0005435310839	7040	25	5F
0005434407508	7040	26	6B
0005434407487	7040	27	6C
0005434407537	7040	28	6E
0005434407518	7040	29	6D
0005434299466	7040	30	6F
0005435310910	7040	31	7B
0005434407531	7040	32	7A
0005435293128	7040	33	7C
0005434299471	7040	34	7D
0005434407504	7040	35	7E
0005434407536	7040	36	8A
0005434407493	7040	37	7F
0005434407507	7040	38	8B
0005434299477	7040	39	8D
0005435293105	7040	40	8C
0005434407482	7040	41	8E
0005434407481	7040	42	9A
0005435310875	7040	43	8F
0005434407484	7040	44	9C
0005432108239	7040	45	9B
0005432153910	7040	46	9D
0005434407519	7040	47	9E
0005435310883	7040	48	10C
0005434299456	7040	49	10B
0005434407505	7040	50	10D
0005435310908	7040	51	10E
0005434407485	7040	52	11A
0005434407503	7040	53	11B
0005434407516	7040	54	11C
0005434407489	7040	55	11E
0005435293099	7040	56	11F
0005435310901	7040	57	12A
0005434407532	7040	58	12C
0005434407500	7040	59	12B
0005434299474	7040	60	12E
0005434299458	7040	61	12D
0005434299459	7040	62	12F
0005434407483	7040	63	13B
0005432153909	7040	64	13A
0005434299467	7040	65	13C
0005432153907	7040	66	13D
0005434299469	7040	67	13E
0005434407524	7040	68	14A
0005434299457	7040	69	14C
0005434407490	7040	70	14D
0005435310909	7040	71	14E
0005434407480	7040	72	14F
0005432108240	7040	73	15B
0005434407491	7040	74	15A
0005434407512	7040	75	15C
0005434407495	7040	76	15D
0005435310890	7040	77	15F
0005434407486	7040	78	15E
0005434299462	7040	79	16A
0005435310921	7040	80	16B
0005434407497	7040	81	16C
0005434407506	7040	82	16D
0005432153908	7040	83	16E
0005435293078	7040	84	16F
0005435293114	7040	85	17A
0005435293082	7040	86	17D
0005434407522	7040	87	17C
0005434407501	7040	88	17E
0005434407513	7040	89	18A
0005435310866	7040	90	17F
0005434299476	7040	91	18B
0005434407492	7040	92	18C
0005435293058	7040	93	18E
0005434407538	7040	94	18D
0005434407496	7040	95	19A
0005434407530	7040	96	18F
0005434407477	7040	97	19B
0005435310900	7040	98	19D
0005434407514	7040	99	19C
0005434299475	7040	100	19E
0005434407527	7040	101	19F
0005434299478	7040	102	20B
0005435310906	7040	103	20E
0005434407535	7040	104	20D
0005432153911	7040	105	21A
0005434299461	7040	106	20F
0005434299463	7040	107	21C
0005434407533	7040	108	21B
0005434407521	7040	109	21D
0005434407511	7040	110	21F
0005434299473	7040	111	21E
0005432153906	7040	112	22B
0005435310877	7040	113	22A
0005434407525	7040	114	22C
0005432153912	7040	115	22F
0005434299470	7040	116	22E
0005434407479	7040	117	23A
0005434407539	7040	118	23B
0005434299468	7040	119	23C
0005434407520	7040	120	23D
0005435310886	7040	121	23F
0005434299465	7040	122	23E
0005434299356	26912	1	1A
0005435311015	26912	2	1C
0005434406945	26912	3	2A
0005434406911	26912	4	1F
0005434406909	26912	5	2C
0005434406711	26912	6	2D
0005434406710	26912	7	2F
0005434406983	26912	8	3C
0005435311017	26912	9	3A
0005435311019	26912	10	3F
0005434299339	26912	11	4A
0005434406929	26912	12	4C
0005434406826	26912	13	4B
0005435293201	26912	14	4E
0005434406896	26912	15	4D
0005434406734	26912	16	4F
0005434406875	26912	17	5C
0005434406872	26912	18	5B
0005434407014	26912	19	5D
0005434406741	26912	20	5F
0005434406879	26912	21	6A
0005434407005	26912	22	6C
0005434406763	26912	23	6B
0005434407065	26912	24	6D
0005434406775	26912	25	6F
0005434299306	26912	26	7B
0005434406712	26912	27	7A
0005435293200	26912	28	7C
0005434406916	26912	29	7F
0005434406740	26912	30	8A
0005435311016	26912	31	8B
0005432058361	26912	32	8C
0005435293202	26912	33	8E
0005434406876	26912	34	9A
0005435293204	26912	35	8F
0005434406771	26912	36	9B
0005434406910	26912	37	9D
0005435293199	26912	38	9C
0005432058362	26912	39	9E
0005434406888	26912	40	9F
0005434299355	26912	41	10B
0005434406965	26912	42	10C
0005434407004	26912	43	10E
0005432058360	26912	44	11A
0005434406923	26912	45	11C
0005434407145	26912	46	11E
0005434406934	26912	47	11F
0005434406887	26912	48	12B
0005434406835	26912	49	12A
0005434406992	26912	50	12C
0005434407056	26912	51	12D
0005434299239	26912	52	12E
0005434406643	26912	53	12F
0005434406769	26912	54	13A
0005435311023	26912	55	13B
0005435293198	26912	56	13D
0005434407110	26912	57	13C
0005435311025	26912	58	13E
0005434299335	26912	59	13F
0005434407165	26912	60	14B
0005434406871	26912	61	14A
0005434406772	26912	62	14C
0005434406897	26912	63	14D
0005434406644	26912	64	14E
0005434407144	26912	65	14F
0005434406924	26912	66	15B
0005434406801	26912	67	15A
0005435293203	26912	68	15C
0005435311020	26912	69	15D
0005434406878	26912	70	15E
0005434299250	26912	71	15F
0005434406900	26912	72	16A
0005434406793	26912	73	16C
0005434406830	26912	74	16D
0005435311022	26912	75	16E
0005434406867	26912	76	17A
0005434406735	26912	77	17B
0005434299229	26912	78	17C
0005434406765	26912	79	17D
0005434299325	26912	80	17F
0005434406846	26912	81	17E
0005434406736	26912	82	18B
0005434406652	26912	83	18D
0005434406653	26912	84	18C
0005434406838	26912	85	18E
0005435293197	26912	86	18F
0005434299180	26912	87	19B
0005435293205	26912	88	19A
0005434407143	26912	89	19C
0005434407013	26912	90	19E
0005434406692	26912	91	19D
0005435293196	26912	92	20A
0005432058363	26912	93	20B
0005434407064	26912	94	20D
0005434299230	26912	95	20C
0005435293207	26912	96	20E
0005434406898	26912	97	21A
0005434406719	26912	98	21C
0005435293206	26912	99	21B
0005435311018	26912	100	21D
0005434406873	26912	101	21F
0005435311024	26912	102	21E
0005434406847	26912	103	22B
0005434406786	26912	104	22A
0005434407109	26912	105	22C
0005434299251	26912	106	22D
0005434407019	26912	107	22E
0005435311021	26912	108	23A
0005434406829	26912	109	22F
0005435293195	26912	110	23B
0005434406886	26912	111	23C
0005434406828	26912	112	23E
0005434406832	26912	113	23D
0005434406950	26912	114	23F
0005434512095	6479	1	1A
0005432604195	6479	2	1B
0005432604206	6479	3	1C
0005434512094	6479	4	2A
0005432604209	6479	5	2C
0005432604191	6479	6	2D
0005432604203	6479	7	3A
0005432604199	6479	8	3B
0005432604178	6479	9	3C
0005432604180	6479	10	3D
0005432604169	6479	11	4A
0005432604205	6479	12	4B
0005434512096	6479	13	4C
0005432604172	6479	14	4D
0005432604176	6479	15	5A
0005432604177	6479	16	5B
0005432604207	6479	17	5C
0005432604187	6479	18	5D
0005432604194	6479	19	6A
0005432604196	6479	20	6B
0005432604190	6479	21	6C
0005432604184	6479	22	6D
0005432604175	6479	23	7A
0005432604193	6479	24	7B
0005432604192	6479	25	7C
0005432604173	6479	26	18A
0005432604200	6479	27	18B
0005432604197	6479	28	18C
0005432604174	6479	29	18D
0005432604189	6479	30	19A
0005432604188	6479	31	19B
0005432604183	6479	32	19C
0005432604186	6479	33	19D
0005432604198	6479	34	20A
0005434512097	6479	35	20B
0005432604202	6479	36	20C
0005432604182	6479	37	20D
0005432604204	6479	38	21A
0005432604208	6479	39	21B
0005432604170	6479	40	21C
0005434512098	6479	41	21D
0005432604185	6479	42	22A
0005432604201	6479	43	22B
0005432604171	6479	44	22C
0005432604179	6479	45	22D
0005432604181	6479	46	23A
0005434512099	6479	47	23B
0005432603824	21367	1	1A
0005432603822	21367	2	1B
0005432603903	21367	3	1C
0005432603798	21367	4	1D
0005432603779	21367	5	2A
0005432603868	21367	6	2B
0005432603839	21367	7	2D
0005434512053	21367	8	2C
0005432603746	21367	9	3A
0005434512062	21367	10	3B
0005432603860	21367	11	3C
0005432603825	21367	12	3D
0005432603804	21367	13	4A
0005432603840	21367	14	4B
0005432603875	21367	15	4C
0005432603838	21367	16	4D
0005432603892	21367	17	5A
0005432603757	21367	18	5B
0005432603810	21367	19	5C
0005432603806	21367	20	5D
0005434512045	21367	21	6A
0005432603662	21367	22	6B
0005432603901	21367	23	6C
0005432603775	21367	24	6D
0005434512051	21367	25	7A
0005432603771	21367	26	7B
0005432603823	21367	27	7C
0005432603865	21367	28	7D
0005432603693	21367	29	18A
0005434512049	21367	30	18B
0005432603805	21367	31	18C
0005432603796	21367	32	18D
0005432603843	21367	33	19A
0005432603700	21367	34	19B
0005434512044	21367	35	19C
0005432603786	21367	36	19D
0005432603769	21367	37	20A
0005432603946	21367	38	20B
0005432603745	21367	39	20C
0005432603809	21367	40	20D
0005432603770	21367	41	21A
0005432603778	21367	42	21B
0005432603834	21367	43	21C
0005432603747	21367	44	21D
0005432603881	21367	45	22A
0005432603748	21367	46	22B
0005432603863	21367	47	22C
0005432603951	21367	48	23A
0005434512048	21367	49	22D
0005432603859	21367	50	23B
0005434906809	14972	1	1A
0005433251359	14972	2	1C
0005433251338	14972	3	1D
0005434906746	14972	4	1F
0005434906405	14972	5	2A
0005434906379	14972	6	2D
0005434906810	14972	7	2F
0005434906794	14972	8	3A
0005433251352	14972	9	3C
0005433251347	14972	10	3D
0005433251343	14972	11	3F
0005434906564	14972	12	4A
0005434906596	14972	13	4C
0005433251354	14972	14	4D
0005433251360	14972	15	4E
0005434906651	14972	16	4F
0005434906531	14972	17	5A
0005434906819	14972	18	5C
0005434906793	14972	19	5D
0005434906483	14972	20	5E
0005434906652	14972	21	5F
0005434906747	14972	22	6A
0005434906618	14972	23	6C
0005433251363	14972	24	6D
0005433251362	14972	25	6E
0005433251345	14972	26	7A
0005433251361	14972	27	7C
0005434906574	14972	28	7D
0005434906779	14972	29	7F
0005434906611	14972	30	8A
0005434906406	14972	31	8C
0005434906430	14972	32	8D
0005433251365	14972	33	8E
0005434906489	14972	34	8F
0005434906756	14972	35	9A
0005434906665	14972	36	9C
0005434906504	14972	37	9D
0005433251364	14972	38	9E
0005434906728	14972	39	9F
0005434906571	14972	40	10A
0005434906623	14972	41	10C
0005434906722	14972	42	10E
0005433251340	14972	43	10F
0005433251357	14972	44	11A
0005434906639	14972	45	11C
0005433251367	14972	46	11D
0005434906579	14972	47	11E
0005433251348	14972	48	11F
0005434906745	14972	49	12A
0005433251369	14972	50	12C
0005433251353	14972	51	12D
0005434906488	14972	52	12E
0005434906501	14972	53	13A
0005434906617	14972	54	13C
0005433251358	14972	55	13D
0005434906679	14972	56	13E
0005434906408	14972	57	13F
0005433251350	14972	58	14A
0005434906638	14972	59	14C
0005433251346	14972	60	14D
0005433251339	14972	61	14E
0005434906494	14972	62	14F
0005434906780	14972	63	15D
0005434906680	14972	64	15E
0005433251356	14972	65	15F
0005434906361	14972	66	16A
0005434906404	14972	67	16C
0005433251366	14972	68	16D
0005434906729	14972	69	16F
0005433251344	14972	70	17A
0005434906678	14972	71	17C
0005433251370	14972	72	17D
0005434906362	14972	73	17E
0005433251341	14972	74	17F
0005433251368	14972	75	18A
0005433251355	14972	76	18C
0005434906557	14972	77	18D
0005434906616	14972	78	18E
0005434906799	14972	79	18F
0005433251342	14972	80	19A
0005434906380	14972	81	19C
0005433251349	14972	82	19D
0005434906580	14972	83	19E
0005434906561	14972	84	19F
0005433251351	14972	85	20A
0005434906487	14972	86	20C
0005434906429	14972	87	20E
0005434906578	14972	88	20F
0005434907046	25867	1	1A
0005434907023	25867	2	1C
0005434907031	25867	3	1D
0005433251027	25867	4	1F
0005434907011	25867	5	2A
0005434907033	25867	6	2C
0005433251042	25867	7	2D
0005434907044	25867	8	3A
0005433251085	25867	9	3C
0005434907029	25867	10	3D
0005434907043	25867	11	3F
0005433251079	25867	12	4A
0005434907036	25867	13	4C
0005434907025	25867	14	4D
0005434907021	25867	15	4E
0005434907049	25867	16	4F
0005433251175	25867	17	5A
0005433251134	25867	18	5D
0005434907014	25867	19	5E
0005433251156	25867	20	5F
0005434907019	25867	21	6A
0005434907018	25867	22	6C
0005434907052	25867	23	6D
0005434907035	25867	24	6E
0005434907040	25867	25	6F
0005434907032	25867	26	7A
0005433251198	25867	27	7C
0005434907013	25867	28	7D
0005434907024	25867	29	7E
0005434907048	25867	30	7F
0005434907028	25867	31	8C
0005433251199	25867	32	8D
0005434907042	25867	33	8F
0005434907038	25867	34	9A
0005434907034	25867	35	9C
0005433250940	25867	36	9D
0005433251152	25867	37	9E
0005434907050	25867	38	9F
0005433251197	25867	39	10A
0005434907039	25867	40	10C
0005434907012	25867	41	10D
0005433251127	25867	42	10E
0005434907020	25867	43	10F
0005433251090	25867	44	11A
0005433250968	25867	45	11C
0005433251077	25867	46	11E
0005434907053	25867	47	11F
0005433251123	25867	48	12A
0005434907051	25867	49	12C
0005433251115	25867	50	12D
0005433251056	25867	51	12E
0005433251025	25867	52	12F
0005434907041	25867	53	13A
0005434907015	25867	54	13C
0005433251078	25867	55	13D
0005434907037	25867	56	13E
0005433251060	25867	57	14A
0005434907026	25867	58	14C
0005434907045	25867	59	14F
0005434907017	25867	60	15A
0005433251026	25867	61	15C
0005433251176	25867	62	15D
0005434907016	25867	63	15E
0005434907030	25867	64	15F
0005434907022	25867	65	16A
0005433251097	25867	66	16C
0005434907027	25867	67	16D
0005433251023	25867	68	16E
0005433251094	25867	69	16F
0005433251107	25867	70	17A
0005433251102	25867	71	17D
0005433251108	25867	72	17E
0005433251057	25867	73	17F
0005433251114	25867	74	18A
0005434907047	25867	75	18C
0005433251089	25867	76	18D
0005433251028	25867	77	18E
0005433251131	25867	78	18F
0005433251155	25867	79	19C
0005433251055	25867	80	19D
0005433251024	25867	81	19E
0005433250994	25867	82	19F
0005433251151	25867	83	20A
0005433251006	25867	84	20C
0005433251208	25867	85	20E
0005433251109	25867	86	20F
0005433008458	14160	1	1D
0005433810489	14160	2	2C
0005433008466	14160	3	2D
0005433008432	14160	4	3A
0005433008431	14160	5	3D
0005433008462	14160	6	3F
0005433008453	14160	7	4A
0005433008467	14160	8	4C
0005433008441	14160	9	4D
0005433008444	14160	10	4E
0005433008470	14160	11	5C
0005433008430	14160	12	5D
0005433008461	14160	13	5F
0005433008454	14160	14	6A
0005433008433	14160	15	6C
0005433008452	14160	16	6D
0005433008448	14160	17	6F
0005433008425	14160	18	8D
0005433008446	14160	19	9A
0005433008445	14160	20	9C
0005433008471	14160	21	9D
0005433008438	14160	22	10A
0005433008464	14160	23	10C
0005433008429	14160	24	10D
0005433008459	14160	25	11A
0005433008451	14160	26	11D
0005433008443	14160	27	12A
0005433008442	14160	28	12D
0005433008463	14160	29	12E
0005433008427	14160	30	13A
0005433008436	14160	31	13F
0005433008460	14160	32	14C
0005433008440	14160	33	14E
0005433008435	14160	34	15E
0005433008439	14160	35	16C
0005433008469	14160	36	16F
0005433008456	14160	37	17A
0005433008434	14160	38	17C
0005433008437	14160	39	17D
0005433008450	14160	40	17F
0005433008428	14160	41	18C
0005433008468	14160	42	18D
0005433008465	14160	43	18F
0005433810493	14160	44	19A
0005433008457	14160	45	19C
0005433008455	14160	46	20A
0005433008426	14160	47	20C
0005433008447	14160	48	20E
0005433008449	14160	49	20F
0005433810522	22834	1	1A
0005433008056	22834	2	1D
0005433008080	22834	3	3A
0005433007999	22834	4	3F
0005433007965	22834	5	4A
0005433008120	22834	6	4F
0005433007995	22834	7	5A
0005433008162	22834	8	5F
0005433007865	22834	9	7F
0005433810523	22834	10	8A
0005433007945	22834	11	8D
0005433008214	22834	12	9D
0005433007907	22834	13	9F
0005433007966	22834	14	10C
0005433008054	22834	15	10F
0005433008142	22834	16	11A
0005433007864	22834	17	11C
0005433007978	22834	18	11E
0005433007994	22834	19	12D
0005433007845	22834	20	12E
0005433008009	22834	21	12F
0005433008053	22834	22	13D
0005433008107	22834	23	13F
0005433810521	22834	24	14D
0005433007867	22834	25	14E
0005433008081	22834	26	14F
0005433007940	22834	27	15A
0005433007846	22834	28	15D
0005433008173	22834	29	15F
0005433007896	22834	30	16C
0005433007866	22834	31	16D
0005433007963	22834	32	16F
0005433008062	22834	33	17C
0005433008213	22834	34	17D
0005433007906	22834	35	18A
0005433007937	22834	36	18D
0005433008161	22834	37	19A
0005433008089	22834	38	19D
0005433007998	22834	39	20C
0005433008008	22834	40	20D
0005433008088	22834	41	20F
0005434925334	14919	1	1A
0005434925288	14919	2	2A
0005434925322	14919	3	2F
0005434925255	14919	4	3C
0005434925323	14919	5	3D
0005434925287	14919	6	5A
0005434925251	14919	7	5F
0005434925318	14919	8	6E
0005434925256	14919	9	7C
0005434925297	14919	10	8A
0005434925342	14919	11	9D
0005434925289	14919	12	10A
0005434925346	14919	13	11F
0005434925258	14919	14	14F
0005434925352	14919	15	15A
0005434925316	14919	16	15D
0005434925294	14919	17	15F
0005434925259	14919	18	16C
0005434925333	14919	19	17D
0005434925298	14919	20	18D
0005434925345	14919	21	20C
0005434925662	20529	1	1C
0005434925658	20529	2	1D
0005434925656	20529	3	4C
0005434925661	20529	4	4D
0005434925668	20529	5	6C
0005434925663	20529	6	6D
0005434925655	20529	7	6F
0005434925674	20529	8	7A
0005434925657	20529	9	7E
0005434925667	20529	10	8D
0005434925670	20529	11	8E
0005434925652	20529	12	9A
0005434925672	20529	13	9E
0005434925673	20529	14	9F
0005434925669	20529	15	11A
0005434925660	20529	16	11E
0005434925653	20529	17	13E
0005434925666	20529	18	14E
0005434925654	20529	19	16A
0005434925671	20529	20	16C
0005434925659	20529	21	16D
0005434925664	20529	22	16F
0005434925665	20529	23	17A
0005434925676	20529	24	18F
0005434925675	20529	25	20D
0005434925677	20529	26	20F
0005435487760	15825	1	1A
0005435487761	15825	2	1B
0005435999009	15825	3	1C
0005435487756	15825	4	1D
0005435487747	15825	5	2A
0005435998978	15825	6	2B
0005435999000	15825	7	2C
0005435487755	15825	8	2D
0005435487752	15825	9	3A
0005435487759	15825	10	3B
0005435999013	15825	11	3C
0005435999028	15825	12	3D
0005435999008	15825	13	4B
0005435999041	15825	14	4C
0005435998970	15825	15	4D
0005435487754	15825	16	5A
0005435487746	15825	17	5B
0005435487741	15825	18	5C
0005435487763	15825	19	5D
0005435999004	15825	20	6A
0005435999023	15825	21	6B
0005435999002	15825	22	6C
0005435487748	15825	23	6D
0005435487762	15825	24	7D
0005435999031	15825	25	18C
0005435487744	15825	26	18D
0005435487743	15825	27	19A
0005435487753	15825	28	19B
0005435998980	15825	29	19D
0005435487757	15825	30	20A
0005435998982	15825	31	20C
0005435487749	15825	32	20D
0005435487750	15825	33	21A
0005435487751	15825	34	21B
0005435487745	15825	35	21C
0005435999032	15825	36	21D
0005435487758	15825	37	22A
0005435999027	15825	38	22B
0005435999024	15825	39	22C
0005435999003	15825	40	22D
0005435487742	15825	41	23B
0005435487548	19690	1	1A
0005435487560	19690	2	1B
0005435487570	19690	3	1C
0005435487509	19690	4	1D
0005435487531	19690	5	2D
0005435487558	19690	6	3A
0005435487470	19690	7	3B
0005435487584	19690	8	3C
0005435487543	19690	9	4A
0005435487526	19690	10	4B
0005435487585	19690	11	4C
0005435487563	19690	12	4D
0005435999177	19690	13	5A
0005435487528	19690	14	5B
0005435999173	19690	15	5C
0005435487522	19690	16	5D
0005435487598	19690	17	6A
0005435999174	19690	18	6B
0005435487491	19690	19	6C
0005435999181	19690	20	6D
0005435487576	19690	21	7A
0005435487571	19690	22	7B
0005435487500	19690	23	7C
0005435487597	19690	24	7D
0005435999178	19690	25	18A
0005435487575	19690	26	18B
0005435487476	19690	27	18C
0005435487527	19690	28	18D
0005435999175	19690	29	19A
0005435487499	19690	30	19B
0005435999176	19690	31	19D
0005435487620	19690	32	20A
0005435487544	19690	33	20B
0005435487492	19690	34	20C
0005435999179	19690	35	21A
0005435999180	19690	36	21D
0005435487547	19690	37	22C
0005435487574	19690	38	22D
0005435487490	19690	39	23A
0005435487498	19690	40	23B
0005432660811	6006	1	3A
0005435839345	6006	2	2F
0005435839342	6006	3	3C
0005435839356	6006	4	5F
0005435839334	6006	5	6B
0005435839348	6006	6	6E
0005432658584	6006	7	6D
0005435839339	6006	8	7A
0005435839354	6006	9	7B
0005432537028	6006	10	8A
0005432658583	6006	11	7F
0005435839355	6006	12	7E
0005435472550	6006	13	8E
0005435839336	6006	14	8C
0005435472600	6006	15	8F
0005435472575	6006	16	9A
0005435472590	6006	17	9D
0005435472526	6006	18	9E
0005435839350	6006	19	9F
0005432659700	6006	20	11A
0005432142239	6006	21	10F
0005432537029	6006	22	11B
0005435839332	6006	23	11D
0005432142240	6006	24	11C
0005435839352	6006	25	12A
0005435839351	6006	26	12F
0005435839353	6006	27	13A
0005435839357	6006	28	13E
0005435472596	6006	29	13D
0005435472568	6006	30	14A
0005435839341	6006	31	14C
0005435839335	6006	32	14B
0005435472597	6006	33	14D
0005432659699	6006	34	14F
0005435839347	6006	35	14E
0005435839349	6006	36	15B
0005435839346	6006	37	15C
0005435839340	6006	38	16C
0005432142238	6006	39	16E
0005435472612	6006	40	17A
0005435839359	6006	41	16F
0005435472574	6006	42	17F
0005435472544	6006	43	17E
0005435839337	6006	44	18B
0005432142241	6006	45	18D
0005435839333	6006	46	19A
0005435839360	6006	47	18F
0005435839343	6006	48	19C
0005435839338	6006	49	19D
0005435839358	6006	50	19F
0005435472585	6006	51	20B
0005435839344	6006	52	20D
0005435472658	6006	53	20E
0005435472651	6006	54	21D
0005435472659	6006	55	21F
0005435839099	18034	1	1A
0005435839166	18034	2	2C
0005435472741	18034	3	1F
0005435472747	18034	4	2F
0005435472734	18034	5	3A
0005435839125	18034	6	4F
0005435472746	18034	7	6A
0005435472735	18034	8	5F
0005435839172	18034	9	6C
0005435472738	18034	10	6F
0005435839059	18034	11	7B
0005435839130	18034	12	7D
0005435839031	18034	13	8C
0005432667421	18034	14	8A
0005435839103	18034	15	8F
0005432667418	18034	16	9B
0005435839129	18034	17	9F
0005435839096	18034	18	10C
0005435839134	18034	19	11D
0005435472740	18034	20	11E
0005435839028	18034	21	12D
0005435839095	18034	22	13A
0005432667422	18034	23	12F
0005435839167	18034	24	13E
0005435839121	18034	25	14C
0005435839138	18034	26	14B
0005435839137	18034	27	14F
0005435839007	18034	28	15C
0005435472739	18034	29	15F
0005435472742	18034	30	16C
0005435472743	18034	31	16E
0005435838958	18034	32	17A
0005435839094	18034	33	16F
0005435472733	18034	34	17D
0005435839029	18034	35	17F
0005435472732	18034	36	17E
0005432537052	18034	37	18D
0005435472736	18034	38	19A
0005435839097	18034	39	18F
0005432537051	18034	40	19C
0005435472737	18034	41	20A
0005435839100	18034	42	19F
0005435839084	18034	43	20B
0005435839030	18034	44	20D
0005435472745	18034	45	20F
0005435839085	18034	46	20E
0005435839205	18034	47	21A
0005435472744	18034	48	21B
0005435839209	18034	49	21F
0005433284913	23010	1	1C
0005433284992	23010	2	1D
0005433284935	23010	3	1F
0005435103890	23010	4	3C
0005433284991	23010	5	3D
0005433284912	23010	6	3F
0005435103888	23010	7	4A
0005435103892	23010	8	4E
0005435103893	23010	9	5C
0005433284954	23010	10	5F
0005435103900	23010	11	6F
0005433284777	23010	12	6E
0005435103889	23010	13	7C
0005433284955	23010	14	7E
0005433285029	23010	15	8D
0005433284904	23010	16	8F
0005435103886	23010	17	9B
0005433284928	23010	18	10E
0005433284905	23010	19	11B
0005435103894	23010	20	13D
0005433284956	23010	21	13F
0005435103891	23010	22	15B
0005435103901	23010	23	15C
0005435103898	23010	24	15D
0005435103899	23010	25	16F
0005433284973	23010	26	17A
0005433284822	23010	27	18D
0005433284911	23010	28	19E
0005435103896	23010	29	20C
0005433284821	23010	30	21C
0005435103887	23010	31	22C
0005435103895	23010	32	22F
0005435103897	23010	33	23A
0005433284888	23010	34	23F
0005433285195	32070	1	1D
0005433285176	32070	2	3C
0005433285197	32070	3	3F
0005435103819	32070	4	4E
0005433285167	32070	5	6B
0005433285194	32070	6	6D
0005433285186	32070	7	8E
0005433285168	32070	8	8F
0005435103812	32070	9	9C
0005435103807	32070	10	9F
0005433285169	32070	11	10B
0005435103820	32070	12	10D
0005433285179	32070	13	10C
0005433285173	32070	14	10E
0005433285198	32070	15	11D
0005433285180	32070	16	12A
0005433285185	32070	17	12B
0005433285177	32070	18	12D
0005435103813	32070	19	13B
0005433285181	32070	20	13C
0005433285182	32070	21	13D
0005435103808	32070	22	14C
0005433285193	32070	23	15B
0005433285171	32070	24	16A
0005433285183	32070	25	16C
0005433285191	32070	26	16F
0005433285189	32070	27	17C
0005433285175	32070	28	18C
0005433285192	32070	29	18A
0005433285187	32070	30	18F
0005433285178	32070	31	19A
0005433285196	32070	32	19D
0005433285170	32070	33	20E
0005435103815	32070	34	21A
0005433285190	32070	35	20F
0005433285184	32070	36	22C
0005433285172	32070	37	22E
0005435103814	32070	38	22F
0005433285174	32070	39	23B
0005433285188	32070	40	23C
0005432526445	30592	1	1A
0005432526108	30592	2	1G
0005432526498	30592	3	1D
0005435213355	30592	4	2A
0005435213354	30592	5	1K
0005432526457	30592	6	1H
0005435213320	30592	7	2D
0005432527192	30592	8	2C
0005435213367	30592	9	2H
0005432526620	30592	10	2G
0005434066474	30592	11	3A
0005435213339	30592	12	2K
0005432526902	30592	13	3G
0005432211479	30592	14	3D
0005435213315	30592	15	3C
0005434066364	30592	16	4C
0005432526864	30592	17	4A
0005432526398	30592	18	4G
0005432211474	30592	19	4D
0005435213311	30592	20	4K
0005435630957	30592	21	4H
0005432526508	30592	22	5D
0005432159844	30592	23	5C
0005432526253	30592	24	5H
0005435725584	30592	25	11A
0005435213350	30592	26	11D
0005432526223	30592	27	11C
0005432526681	30592	28	11F
0005432526911	30592	29	11E
0005432526468	30592	30	11K
0005432526565	30592	31	11H
0005435213347	30592	32	12C
0005432526295	30592	33	12A
0005432159841	30592	34	12D
0005434066637	30592	35	12G
0005435213348	30592	36	12F
0005435213319	30592	37	13A
0005434066752	30592	38	12K
0005435213303	30592	39	12H
0005432526892	30592	40	13D
0005434066542	30592	41	13C
0005434066849	30592	42	13F
0005432526787	30592	43	13E
0005434066499	30592	44	13H
0005434066737	30592	45	13G
0005432525829	30592	46	14A
0005435213359	30592	47	13K
0005434066577	30592	48	14D
0005432526274	30592	49	14C
0005435213341	30592	50	14G
0005435213331	30592	51	14F
0005434066338	30592	52	14E
0005432533252	30592	53	15A
0005432526663	30592	54	14K
0005432159842	30592	55	15F
0005435213324	30592	56	15D
0005434066329	30592	57	15G
0005435213305	30592	58	15K
0005435213300	30592	59	15H
0005432526551	30592	60	16D
0005434066711	30592	61	16C
0005434066648	30592	62	16A
0005432526102	30592	63	16E
0005432525960	30592	64	16K
0005432526694	30592	65	16H
0005434066583	30592	66	16G
0005432537036	30592	67	17C
0005432526769	30592	68	17A
0005432526585	30592	69	17D
0005435213316	30592	70	17G
0005435725588	30592	71	17F
0005432525830	30592	72	18A
0005435213334	30592	73	17K
0005432526711	30592	74	17H
0005432526693	30592	75	18C
0005432526250	30592	76	18B
0005435213314	30592	77	18E
0005432537032	30592	78	18D
0005432211473	30592	79	18G
0005434066543	30592	80	18F
0005432526493	30592	81	18H
0005432159843	30592	82	19B
0005432526392	30592	83	19A
0005434066842	30592	84	18K
0005434066325	30592	85	19D
0005434066684	30592	86	19C
0005432526654	30592	87	19E
0005432526607	30592	88	19G
0005432526252	30592	89	19K
0005432526675	30592	90	19J
0005435213352	30592	91	20C
0005434066467	30592	92	20E
0005435213304	30592	93	20D
0005434066808	30592	94	20G
0005434066740	30592	95	20F
0005432526292	30592	96	20J
0005434066966	30592	97	20H
0005435213365	30592	98	21A
0005434066736	30592	99	21D
0005432527065	30592	100	21C
0005434066663	30592	101	21F
0005435213312	30592	102	21E
0005435213344	30592	103	21J
0005435213364	30592	104	21H
0005435213340	30592	105	21G
0005434066700	30592	106	22A
0005432526541	30592	107	21K
0005432526895	30592	108	22C
0005432526181	30592	109	22B
0005435213328	30592	110	22F
0005432526249	30592	111	22E
0005432526569	30592	112	22D
0005434066850	30592	113	22H
0005432525739	30592	114	22G
0005435630959	30592	115	22K
0005434066683	30592	116	22J
0005434066459	30592	117	23A
0005435213353	30592	118	23D
0005434066744	30592	119	23F
0005432526191	30592	120	23E
0005432526494	30592	121	23H
0005432537031	30592	122	24D
0005432535778	30592	123	23K
0005435725586	30592	124	24F
0005435213362	30592	125	24E
0005435213345	30592	126	25B
0005432526535	30592	127	25C
0005432526606	30592	128	25F
0005434066460	30592	129	25E
0005432211480	30592	130	25D
0005434066654	30592	131	25H
0005432527064	30592	132	25G
0005435213317	30592	133	25J
0005432428898	30592	134	26C
0005432526661	30592	135	26B
0005435725583	30592	136	26A
0005435213356	30592	137	26E
0005432537024	30592	138	26D
0005432526788	30592	139	26G
0005434066498	30592	140	26F
0005435213337	30592	141	26K
0005434066860	30592	142	26J
0005432526975	30592	143	27D
0005435213336	30592	144	27C
0005432526891	30592	145	27B
0005435213299	30592	146	27F
0005432526621	30592	147	27E
0005432527051	30592	148	27H
0005434066776	30592	149	28A
0005434066859	30592	150	27K
0005434066395	30592	151	27J
0005435213329	30592	152	28C
0005432526929	30592	153	28F
0005435213357	30592	154	28J
0005432525936	30592	155	28H
0005432525842	30592	156	29A
0005432526617	30592	157	29D
0005432526090	30592	158	29F
0005432526243	30592	159	29E
0005432526608	30592	160	29H
0005432526424	30592	161	30A
0005432211478	30592	162	29K
0005432527035	30592	163	30C
0005432537023	30592	164	30E
0005434066516	30592	165	30D
0005432526284	30592	166	30G
0005432535788	30592	167	30F
0005432526941	30592	168	30K
0005435213309	30592	169	30J
0005433656662	30592	170	30H
0005435213361	30592	171	31A
0005435213332	30592	172	31D
0005435725585	30592	173	31F
0005432533246	30592	174	31E
0005432533253	30592	175	31J
0005432525909	30592	176	31G
0005432525961	30592	177	32A
0005435213306	30592	178	31K
0005434066758	30592	179	32B
0005434066647	30592	180	32E
0005432526662	30592	181	32D
0005435213321	30592	182	32C
0005434066646	30592	183	32G
0005432526342	30592	184	32F
0005435213322	30592	185	32J
0005432526124	30592	186	32H
0005434066804	30592	187	33B
0005432525978	30592	188	33A
0005433656659	30592	189	32K
0005432526064	30592	190	33D
0005433656660	30592	191	33E
0005435213363	30592	192	33J
0005432535759	30592	193	33G
0005432526968	30592	194	33K
0005432526409	30592	195	34B
0005432526235	30592	196	34A
0005432526497	30592	197	34E
0005432526107	30592	198	34C
0005434066515	30592	199	34H
0005434066367	30592	200	34F
0005435213330	30592	201	34J
0005434066576	30592	202	35C
0005432526018	30592	203	35F
0005432526669	30592	204	35E
0005432526161	30592	205	35J
0005435213360	30592	206	35H
0005435213308	30592	207	35K
0005433656661	30592	208	36C
0005434066544	30592	209	36B
0005435725587	30592	210	36A
0005435213351	30592	211	36E
0005432526969	30592	212	36D
0005432526973	30592	213	36H
0005432526103	30592	214	36G
0005434066634	30592	215	36F
0005434066756	30592	216	36K
0005435213342	30592	217	36J
0005432526349	30592	218	37A
0005432526660	30592	219	37D
0005432526520	30592	220	37F
0005432526246	30592	221	37E
0005434066476	30592	222	37J
0005435213313	30592	223	37H
0005432526942	30592	224	37G
0005434066805	30592	225	38A
0005434066753	30592	226	37K
0005435213318	30592	227	38B
0005432526540	30592	228	38J
0005432526584	30592	229	38H
0005435213301	30592	230	39A
0005432428874	30592	231	38K
0005432526285	30592	232	39D
0005435213323	30592	233	39C
0005435213343	30592	234	39F
0005434066670	30592	235	39E
0005434066733	30592	236	39J
0005432526373	30592	237	39H
0005435213302	30592	238	39K
0005432526198	30592	239	40C
0005435213335	30592	240	40B
0005432526959	30592	241	40A
0005434066861	30592	242	40F
0005434066426	30592	243	40E
0005435630958	30592	244	40D
0005434066743	30592	245	40H
0005434066722	30592	246	40G
0005432526469	30592	247	40K
0005432526777	30592	248	41B
0005432211475	30592	249	41A
0005432533266	30592	250	41C
0005432526451	30592	251	41G
0005432526227	30592	252	41F
0005432526076	30592	253	41E
0005432526960	30592	254	41J
0005435213307	30592	255	42A
0005434066725	30592	256	41K
0005432526277	30592	257	42C
0005432211476	30592	258	42B
0005432526218	30592	259	42D
0005432211477	30592	260	42G
0005434066645	30592	261	42F
0005432526863	30592	262	42J
0005435213310	30592	263	42H
0005432526499	30592	264	42K
0005432537037	30592	265	43D
0005435213327	30592	266	43F
0005435213326	30592	267	43J
0005435213333	30592	268	44B
0005434066757	30592	269	44A
0005432526275	30592	270	44E
0005432526974	30592	271	44D
0005432526487	30592	272	44F
0005432526519	30592	273	44K
0005432526348	30592	274	44J
0005434066671	30592	275	44H
0005435213346	30592	276	45C
0005434066930	30592	277	45F
0005432526063	30592	278	45D
0005432526317	30592	279	45H
0005432526134	30592	280	45G
0005432526144	30592	281	46A
0005434066721	30592	282	45K
0005432526549	30592	283	45J
0005432527224	30592	284	46B
0005435213349	30592	285	46E
0005432526668	30592	286	46C
0005434066952	30592	287	46G
0005435213325	30592	288	46F
0005434066497	30592	289	46J
0005434066809	30592	290	46H
0005432526393	30592	291	47C
0005432526778	30592	292	46K
0005434066774	30592	293	47E
0005432525841	30592	294	47D
0005434066745	30592	295	47G
0005432526217	30592	296	47F
0005432526695	30592	297	47K
0005435725589	30592	298	47H
0005434066633	30592	299	48D
0005435213338	30592	300	48C
0005432526180	30592	301	48F
0005434066529	30592	302	48H
0005432526539	30592	303	48G
0005435213366	30592	304	48K
0005434066732	30592	305	49E
0005432526682	30592	306	49C
0005432526605	30592	307	49G
0005432526785	30592	308	49F
0005434066677	30592	309	49K
0005434066575	30592	310	50C
0005432533245	30592	311	50A
0005432526408	30592	312	50E
0005434066775	30592	313	50D
0005434066528	30592	314	50G
0005432526065	30592	315	50F
0005434066662	30592	316	51D
0005432525725	30592	317	50K
0005435213358	30592	318	51F
0005432526786	30592	319	51G
0005433367758	24844	1	1A
0005435652510	24844	2	1C
0005435652390	24844	3	1D
0005433367785	24844	4	1F
0005433367783	24844	5	2A
0005435652428	24844	6	2C
0005433367761	24844	7	2D
0005435652608	24844	8	2F
0005433367782	24844	9	3A
0005435652582	24844	10	3C
0005433367769	24844	11	3D
0005435652505	24844	12	3F
0005433367778	24844	13	4A
0005435652485	24844	14	4C
0005435652391	24844	15	4D
0005435652365	24844	16	4E
0005435652389	24844	17	4F
0005433367774	24844	18	5A
0005435652421	24844	19	5D
0005435652422	24844	20	5E
0005435652490	24844	21	5F
0005433367764	24844	22	6A
0005435652439	24844	23	6C
0005435652423	24844	24	6D
0005435652370	24844	25	6E
0005433367788	24844	26	6F
0005433367791	24844	27	7C
0005435652431	24844	28	7E
0005435652307	24844	29	8A
0005435652597	24844	30	8C
0005433367771	24844	31	8D
0005433367760	24844	32	8E
0005433367784	24844	33	8F
0005435652584	24844	34	9A
0005433367756	24844	35	9C
0005435652589	24844	36	9D
0005435652591	24844	37	9E
0005433367787	24844	38	9F
0005435652532	24844	39	10A
0005433367773	24844	40	10D
0005433367776	24844	41	10F
0005435652609	24844	42	11D
0005435652465	24844	43	11F
0005435652583	24844	44	12A
0005435652560	24844	45	12C
0005435652429	24844	46	12D
0005435652606	24844	47	12E
0005435652515	24844	48	12F
0005433367766	24844	49	13A
0005435652546	24844	50	13C
0005433367765	24844	51	13D
0005435652379	24844	52	13E
0005433367792	24844	53	13F
0005433367757	24844	54	14A
0005433367759	24844	55	14C
0005435652509	24844	56	14D
0005435652508	24844	57	14E
0005435652426	24844	58	14F
0005433367780	24844	59	15A
0005433367763	24844	60	15C
0005433367781	24844	61	15D
0005433367767	24844	62	15E
0005435652598	24844	63	15F
0005435652432	24844	64	16A
0005433367777	24844	65	16C
0005435652551	24844	66	16D
0005433367762	24844	67	16E
0005435652424	24844	68	16F
0005433367775	24844	69	17A
0005435652605	24844	70	17C
0005435652462	24844	71	17E
0005433367768	24844	72	17F
0005435652547	24844	73	18A
0005433367789	24844	74	18C
0005433367770	24844	75	18D
0005435652618	24844	76	18E
0005433367793	24844	77	18F
0005435652306	24844	78	19C
0005433367786	24844	79	19D
0005433367772	24844	80	19E
0005435652258	24844	81	20C
0005433367779	24844	82	20E
0005433367790	24844	83	20F
0005435949751	23309	1	1C
0005435949745	23309	2	4C
0005435949749	23309	3	5A
0005435949740	23309	4	6A
0005435949735	23309	5	18B
0005435949741	23309	6	18C
0005435949739	23309	7	19D
0005434979713	2069	1	1A
0005434979698	2069	2	1B
0005434979699	2069	3	1C
0005434979692	2069	4	2A
0005434979683	2069	5	3A
0005434979684	2069	6	3B
0005434979712	2069	7	3C
0005434979687	2069	8	3D
0005434979696	2069	9	4A
0005434979707	2069	10	4C
0005435801685	2069	11	4D
0005434979710	2069	12	5B
0005434979694	2069	13	5C
0005434979709	2069	14	6A
0005434979706	2069	15	6B
0005434979686	2069	16	6C
0005434979700	2069	17	7C
0005434979689	2069	18	7D
0005434979705	2069	19	18B
0005434979697	2069	20	18A
0005434979685	2069	21	18C
0005435801687	2069	22	19A
0005434979711	2069	23	19B
0005434979701	2069	24	19C
0005434979691	2069	25	20B
0005434979708	2069	26	20C
0005434979695	2069	27	20D
0005434979703	2069	28	21A
0005434979690	2069	29	21B
0005435801686	2069	30	21C
0005434979693	2069	31	22B
0005434979702	2069	32	22C
0005434979688	2069	33	22D
0005434979704	2069	34	23B
0005434979329	23570	1	1A
0005434979415	23570	2	1B
0005434979315	23570	3	1C
0005434979460	23570	4	1D
0005434979404	23570	5	2A
0005434979409	23570	6	2B
0005434979401	23570	7	2C
0005434979346	23570	8	2D
0005435801662	23570	9	3A
0005434979408	23570	10	3B
0005434979394	23570	11	4A
0005434979339	23570	12	4B
0005434979386	23570	13	4C
0005434979304	23570	14	4D
0005435801657	23570	15	5C
0005434979326	23570	16	5D
0005434979406	23570	17	6A
0005434979429	23570	18	6B
0005434979332	23570	19	7A
0005434979361	23570	20	7B
0005434979453	23570	21	7C
0005434979385	23570	22	7D
0005434979364	23570	23	18A
0005434979316	23570	24	18B
0005434979444	23570	25	18C
0005435801656	23570	26	18D
0005434979402	23570	27	19A
0005434979405	23570	28	19B
0005434979371	23570	29	19C
0005434979400	23570	30	19D
0005434979277	23570	31	20B
0005434979461	23570	32	20D
0005434979292	23570	33	21A
0005434979387	23570	34	21B
0005434979333	23570	35	21C
0005434979467	23570	36	21D
0005434979340	23570	37	22B
0005435801663	23570	38	22D
0005434979324	23570	39	23A
0005434979414	23570	40	23B
0005434952520	2638	1	1A
0005434952521	2638	2	2A
0005434952518	2638	3	4A
0005434952519	2638	4	5B
0005434952492	28219	1	1A
0005433256414	28219	2	4B
0005434952496	28219	3	5B
0005433256415	28219	4	6B
0005433111500	19776	1	2A
0005433111499	19776	2	3B
0005433111501	19776	3	4A
0005434136995	11965	1	1A
0005434137050	11965	2	1D
0005434137031	11965	3	1F
0005434136903	11965	4	2A
0005434137147	11965	5	2C
0005434136869	11965	6	2D
0005434137138	11965	7	2F
0005434137205	11965	8	3C
0005434137369	11965	9	3D
0005434137366	11965	10	3F
0005434136788	11965	11	4A
0005434137054	11965	12	4C
0005434137040	11965	13	4D
0005434137264	11965	14	4E
0005434137220	11965	15	4F
0005434137132	11965	16	5A
0005434136981	11965	17	5C
0005434137228	11965	18	5D
0005434136994	11965	19	5E
0005434137275	11965	20	5F
0005434136855	11965	21	6C
0005434137039	11965	22	6A
0005434136957	11965	23	6E
0005434137257	11965	24	6F
0005434137265	11965	25	7A
0005434137009	11965	26	7C
0005434137480	11965	27	7D
0005434137077	11965	28	7E
0005434137049	11965	29	7F
0005434137164	11965	30	8A
0005434137368	11965	31	8C
0005434137365	11965	32	8D
0005434137187	11965	33	8E
0005434137139	11965	34	8F
0005434137170	11965	35	9A
0005434137364	11965	36	9C
0005434137221	11965	37	9D
0005434137076	11965	38	9E
0005434137148	11965	39	9F
0005434136757	11965	40	10A
0005434137250	11965	41	10C
0005434137527	11965	42	10D
0005434136902	11965	43	10E
0005434137274	11965	44	10F
0005434137078	11965	45	11A
0005434137157	11965	46	11C
0005434136883	11965	47	11D
0005434137204	11965	48	11F
0005434137372	11965	49	12A
0005434136868	11965	50	12C
0005434137370	11965	51	12E
0005434137024	11965	52	12F
0005434137149	11965	53	13A
0005434137158	11965	54	13C
0005434137229	11965	55	13D
0005434137325	11965	56	13E
0005434137401	11965	57	13F
0005434136859	11965	58	14A
0005434137159	11965	59	14D
0005434137270	11965	60	14E
0005434137417	11965	61	14F
0005434137036	11965	62	15A
0005434137300	11965	63	15C
0005434137048	11965	64	15E
0005434137114	11965	65	16A
0005434137189	11965	66	16C
0005434136854	11965	67	16D
0005434137273	11965	68	16E
0005434137530	11965	69	16F
0005434137105	11965	70	17A
0005434137121	11965	71	17C
0005434137100	11965	72	17D
0005434137106	11965	73	17E
0005434137133	11965	74	18A
0005434137266	11965	75	18D
0005434136860	11965	76	18E
0005434137004	11965	77	19A
0005434136870	11965	78	19C
0005434137203	11965	79	19D
0005434137003	11965	80	19E
0005434137400	11965	81	19F
0005434137218	11965	82	20A
0005434136955	11965	83	20E
0005434137822	28759	1	1A
0005434137858	28759	2	1C
0005434137829	28759	3	1D
0005434137816	28759	4	1F
0005434137844	28759	5	2A
0005434137838	28759	6	2C
0005434137796	28759	7	2D
0005434137803	28759	8	2F
0005434137827	28759	9	3A
0005434137798	28759	10	3F
0005434137853	28759	11	4A
0005434137800	28759	12	4C
0005434137789	28759	13	4D
0005434137861	28759	14	4E
0005434137866	28759	15	4F
0005434137806	28759	16	5C
0005434137819	28759	17	5D
0005434137821	28759	18	5E
0005434137834	28759	19	6A
0005434137817	28759	20	6C
0005434137859	28759	21	6D
0005434137825	28759	22	6E
0005434137837	28759	23	7A
0005434137809	28759	24	7C
0005434137835	28759	25	7D
0005434137847	28759	26	7E
0005434137852	28759	27	7F
0005434137788	28759	28	8A
0005434137787	28759	29	8C
0005434137856	28759	30	8D
0005434137842	28759	31	8E
0005434137850	28759	32	9A
0005434137799	28759	33	9C
0005434137839	28759	34	9D
0005434137823	28759	35	9E
0005434137864	28759	36	9F
0005434137828	28759	37	10A
0005434137855	28759	38	10C
0005434137846	28759	39	10D
0005434137865	28759	40	10E
0005434137795	28759	41	10F
0005434137792	28759	42	11C
0005434137785	28759	43	11D
0005434137841	28759	44	11E
0005434137863	28759	45	11F
0005434137849	28759	46	12A
0005434137818	28759	47	12C
0005434137851	28759	48	12D
0005434137848	28759	49	12E
0005434137868	28759	50	12F
0005434137805	28759	51	13C
0005434137840	28759	52	13D
0005434137854	28759	53	13E
0005434137860	28759	54	13F
0005434137826	28759	55	14C
0005434137810	28759	56	14E
0005434137801	28759	57	15A
0005434137833	28759	58	15C
0005434137870	28759	59	15D
0005434137791	28759	60	15E
0005434137869	28759	61	15F
0005434137793	28759	62	16A
0005434137814	28759	63	16C
0005434137802	28759	64	16D
0005434137820	28759	65	16E
0005434137831	28759	66	16F
0005434137804	28759	67	17A
0005434137813	28759	68	17C
0005434137845	28759	69	17D
0005434137807	28759	70	17E
0005434137830	28759	71	17F
0005434137824	28759	72	18A
0005434137811	28759	73	18C
0005434137843	28759	74	18D
0005434137812	28759	75	18E
0005434137786	28759	76	18F
0005434137832	28759	77	19A
0005434137857	28759	78	19C
0005434137867	28759	79	19D
0005434137808	28759	80	19E
0005434137815	28759	81	19F
0005434137790	28759	82	20A
0005434137862	28759	83	20C
0005434137794	28759	84	20D
0005434137797	28759	85	20E
0005434137836	28759	86	20F
0005434513544	19095	1	1A
0005434516048	19095	2	2D
0005434516043	19095	3	3D
0005434190394	19095	4	4B
0005434516054	19095	5	5B
0005434190399	19095	6	5D
0005434513541	19095	7	6A
0005434513549	19095	8	6B
0005434190393	19095	9	6C
0005434513548	19095	10	6D
0005434190395	19095	11	7A
0005434190396	19095	12	7B
0005434516045	19095	13	7C
0005434190398	19095	14	7D
0005434516046	19095	15	18D
0005434516053	19095	16	19A
0005434190397	19095	17	19B
0005434513540	19095	18	21B
0005434516044	19095	19	22B
0005434513550	19095	20	22D
0005433534491	6805	1	3A
0005433538841	6805	2	3B
0005433538845	6805	3	6B
0005433538847	6805	4	6D
0005433534492	6805	5	18D
0005433538846	6805	6	19B
0005433538842	6805	7	20D
0005433538843	6805	8	21A
0005433538844	6805	9	21B
0005433538840	6805	10	21C
0005435259713	6805	11	21D
0005433538786	25015	1	1C
0005433538755	25015	2	2A
0005433538767	25015	3	3C
0005433538768	25015	4	6A
0005435259741	25015	5	6B
0005433538756	25015	6	6C
0005435259744	25015	7	7A
0005433534470	25015	8	7D
0005433538764	25015	9	18A
0005435259745	25015	10	18B
0005435259743	25015	11	18D
0005433538763	25015	12	19A
0005433534477	25015	13	21B
0005433538766	25015	14	21C
0005433534473	25015	15	22A
0005435259742	25015	16	22B
0005433538762	25015	17	23A
0005433534471	25015	18	23B
0005432922478	797	1	1B
0005432922463	797	2	2B
0005432922480	797	3	2D
0005433511928	797	4	3C
0005433511923	797	5	4A
0005433511924	797	6	5C
0005433511925	797	7	7A
0005432922479	797	8	7B
0005433511922	797	9	18A
0005433511927	797	10	20A
0005433511926	797	11	20D
0005433511921	797	12	21C
0005433511929	797	13	22B
0005433511863	16177	1	1A
0005433511862	16177	2	1D
0005432922512	16177	3	4A
0005432922513	16177	4	5A
0005433511899	16177	5	5D
0005433511884	16177	6	6C
0005433511879	16177	7	7C
0005432922514	16177	8	18A
0005433511880	16177	9	19A
0005432922511	16177	10	19B
0005433511866	16177	11	21C
0005435852541	4033	1	1B
0005435852538	4033	2	2B
0005435852537	4033	3	2D
0005433475696	4033	4	4A
0005433475693	4033	5	4B
0005435852550	4033	6	5B
0005433475689	4033	7	5D
0005435852534	4033	8	6C
0005435852539	4033	9	6D
0005433475697	4033	10	7B
0005433475694	4033	11	7D
0005433475690	4033	12	18A
0005435852552	4033	13	18B
0005435852536	4033	14	18D
0005433475691	4033	15	19C
0005433475692	4033	16	19D
0005435852535	4033	17	21A
0005435852540	4033	18	21D
0005433475695	4033	19	22B
0005435852551	4033	20	23A
0005435916135	3680	1	1A
0005435697269	3680	2	1B
0005435697263	3680	3	1C
0005434950517	3680	4	2A
0005435697253	3680	5	2B
0005435916143	3680	6	2C
0005435697256	3680	7	2D
0005435935013	3680	8	3B
0005435697274	3680	9	3C
0005435934998	3680	10	3D
0005434950514	3680	11	4A
0005435935012	3680	12	4B
0005435697258	3680	13	4C
0005435697260	3680	14	4D
0005435697252	3680	15	5A
0005435697254	3680	16	5B
0005435697266	3680	17	5C
0005435697273	3680	18	6A
0005435935011	3680	19	6B
0005435697268	3680	20	6C
0005435697246	3680	21	6D
0005435697249	3680	22	7A
0005435916134	3680	23	7B
0005435697245	3680	24	7D
0005435697261	3680	25	18A
0005435697257	3680	26	18B
0005435697272	3680	27	18C
0005435697267	3680	28	19A
0005435697251	3680	29	19B
0005435697262	3680	30	19C
0005435935014	3680	31	19D
0005435697248	3680	32	20A
0005435697271	3680	33	20C
0005435697264	3680	34	20D
0005435697250	3680	35	21A
0005435935015	3680	36	21B
0005434950516	3680	37	21C
0005435697259	3680	38	21D
0005434950515	3680	39	22A
0005435697270	3680	40	22B
0005435697247	3680	41	22C
0005435697265	3680	42	22D
0005435697255	3680	43	23B
0005435697006	16263	1	1A
0005434950466	16263	2	1B
0005435697109	16263	3	2A
0005435696980	16263	4	2C
0005435696979	16263	5	3A
0005435935031	16263	6	3B
0005435696929	16263	7	3D
0005435697075	16263	8	4A
0005435916160	16263	9	4C
0005435697086	16263	10	4D
0005435697110	16263	11	5D
0005435916159	16263	12	6A
0005435916158	16263	13	6B
0005434950455	16263	14	6C
0005435697067	16263	15	7A
0005435697091	16263	16	7C
0005435696917	16263	17	7D
0005435696981	16263	18	18A
0005435697076	16263	19	18B
0005435696971	16263	20	18C
0005434950480	16263	21	19A
0005435935032	16263	22	19B
0005435696901	16263	23	19D
0005435696972	16263	24	20A
0005434950467	16263	25	20B
0005435935030	16263	26	20C
0005435696863	16263	27	20D
0005435696862	16263	28	21B
0005435697083	16263	29	21C
0005435696939	16263	30	22C
0005435696982	16263	31	23B
0005434604887	3942	1	1B
0005435841464	3942	2	2A
0005432607554	3942	3	2B
0005432609717	3942	4	3C
0005432609719	3942	5	4D
0005432607553	3942	6	5B
0005434604886	3942	7	5D
0005432609718	3942	8	6B
0005434606820	3942	9	7B
0005433519444	3942	10	7D
0005433519442	3942	11	18C
0005433519443	3942	12	18D
0005434606819	3942	13	19A
0005432609720	3942	14	19B
0005432607555	3942	15	20A
0005433519446	3942	16	20C
0005433519445	3942	17	21D
0005435853598	3942	18	22C
0005434606782	22067	1	3D
0005433519405	22067	2	4C
0005433519395	22067	3	7B
0005435853607	22067	4	18C
0005434606783	22067	5	19B
0005433519422	22067	6	19C
0005435853608	22067	7	21A
0005433519406	22067	8	21D
0005434606775	22067	9	23A
0005433348916	695	1	1A
0005433348911	695	2	2A
0005435628715	695	3	2B
0005433348936	695	4	3A
0005435628713	695	5	4A
0005433348910	695	6	3B
0005433348891	695	7	4B
0005435628716	695	8	5A
0005433348925	695	9	5B
0005435628714	695	10	6A
0005433348937	695	11	6B
0005433348973	15941	1	1B
0005435628677	15941	2	2B
0005435628678	15941	3	3A
0005433348974	15941	4	3B
0005433348970	15941	5	4A
0005433348972	15941	6	4B
0005433348971	15941	7	5A
0005433348976	15941	8	6A
0005433348975	15941	9	6B
0005433159276	17157	1	2A
0005434445238	17157	2	2B
0005433158096	17157	3	3A
0005434445239	17157	4	3B
0005433158098	17157	5	4A
0005433159275	17157	6	5A
0005433158105	17157	7	5B
0005433158097	17157	8	6A
0005433158104	17157	9	6B
0005433159307	17653	1	3B
0005433159306	17653	2	4B
0005434445215	17653	3	6B
0005435132846	7916	1	1B
0005435132853	7916	2	2B
0005435132855	7916	3	4B
0005435383071	7916	4	5B
0005435132847	7916	5	6D
0005435132851	7916	6	7C
0005435383106	7916	7	18B
0005435132848	7916	8	19B
0005435132854	7916	9	20A
0005435132852	7916	10	20C
0005435132850	7916	11	21C
0005435132849	7916	12	22B
0005435383107	7916	13	22D
0005435383133	33088	1	1A
0005435132807	33088	2	2A
0005435132730	33088	3	2B
0005435383132	33088	4	3A
0005435132762	33088	5	3C
0005435132761	33088	6	3D
0005435132785	33088	7	4A
0005435132786	33088	8	4C
0005435383134	33088	9	5A
0005435132801	33088	10	6C
0005435132779	33088	11	7B
0005435132793	33088	12	7D
0005435132808	33088	13	18B
0005435132757	33088	14	18C
0005435383135	33088	15	18D
0005435383136	33088	16	19B
0005435132790	33088	17	19C
0005435132796	33088	18	20A
0005435132754	33088	19	20C
0005435132795	33088	20	20D
0005435132797	33088	21	21A
0005435132756	33088	22	21C
0005435132716	33088	23	21B
0005435132791	33088	24	21D
0005435132778	33088	25	22B
0005435160268	7491	1	2D
0005435160272	7491	2	3C
0005435160273	7491	3	3D
0005435160265	7491	4	4B
0005435160266	7491	5	5A
0005435160270	7491	6	6A
0005435160271	7491	7	7A
0005435390157	7491	8	7C
0005435160269	7491	9	18C
0005435160267	7491	10	19C
0005435160274	7491	11	20B
0005435160275	7491	12	20C
0005435390142	7491	13	22B
0005435160264	7491	14	22C
0005435390220	29531	1	3A
0005435160230	29531	2	4A
0005435390217	29531	3	5C
0005435160179	29531	4	5D
0005435160195	29531	5	6A
0005435390219	29531	6	6C
0005435160169	29531	7	7B
0005435160194	29531	8	18B
0005435390218	29531	9	18C
0005435390221	29531	10	19A
0005435390222	29531	11	19C
0005435160170	29531	12	19D
0005435390216	29531	13	20B
0005435160171	29531	14	20C
0005432394038	18430	1	1A
0005432394064	18430	2	2A
0005432398148	18430	3	2B
0005432394051	18430	4	3A
0005432394062	18430	5	3B
0005435178492	18430	6	4A
0005432394063	18430	7	4B
0005432398147	18430	8	5A
0005435178491	18430	9	5B
0005432394052	18430	10	6A
0005432394037	18430	11	6B
0005432400107	27163	1	1A
0005432400106	27163	2	1B
0005432398185	27163	3	2A
0005435178470	27163	4	2B
0005432400109	27163	5	3A
0005432398184	27163	6	4A
0005432398182	27163	7	3B
0005432400105	27163	8	4B
0005432400108	27163	9	5A
0005432398180	27163	10	5B
0005432398183	27163	11	6A
0005432398181	27163	12	6B
0005434191255	9772	1	2A
0005434191254	9772	2	2B
0005434191258	9772	3	5A
0005434504056	6557	1	1C
0005434504046	6557	2	2C
0005434504026	6557	3	2D
0005434504054	6557	4	2F
0005434504028	6557	5	3D
0005434504048	6557	6	3F
0005434504034	6557	7	5E
0005434504059	6557	8	5F
0005434504033	6557	9	7A
0005434504050	6557	10	7D
0005434504032	6557	11	7E
0005434504061	6557	12	7F
0005434504053	6557	13	8A
0005434504035	6557	14	8D
0005434504023	6557	15	8F
0005434504027	6557	16	9F
0005434504044	6557	17	10D
0005434504038	6557	18	11A
0005434504039	6557	19	11C
0005434504029	6557	20	11F
0005434504043	6557	21	12C
0005434504051	6557	22	12F
0005434504052	6557	23	13D
0005434504041	6557	24	13E
0005434504024	6557	25	13F
0005434504042	6557	26	14A
0005434504057	6557	27	14E
0005434504031	6557	28	14F
0005434504036	6557	29	15A
0005434504030	6557	30	15C
0005434504055	6557	31	15D
0005434504025	6557	32	16D
0005434504045	6557	33	16E
0005434504037	6557	34	17C
0005434504022	6557	35	18A
0005434504047	6557	36	18D
0005434504049	6557	37	18F
0005434504040	6557	38	20A
0005434504058	6557	39	20C
0005434504060	6557	40	20D
0005434503707	22678	1	1C
0005434503510	22678	2	1D
0005434503588	22678	3	2C
0005434503518	22678	4	2F
0005434503519	22678	5	3A
0005434503553	22678	6	3D
0005434503459	22678	7	4A
0005434503600	22678	8	4C
0005434503785	22678	9	4E
0005434503695	22678	10	4F
0005434503692	22678	11	5A
0005434503688	22678	12	5D
0005434503637	22678	13	5F
0005434503764	22678	14	6A
0005434503468	22678	15	6C
0005434503762	22678	16	7A
0005434503642	22678	17	7C
0005434503664	22678	18	7D
0005434503648	22678	19	7E
0005434503590	22678	20	7F
0005434503467	22678	21	8A
0005434503672	22678	22	8C
0005435103820	22678	23	8D
0005434503671	22678	24	8E
0005434503599	22678	25	8F
0005435103813	22678	26	9F
0005434503618	22678	27	10C
0005434503484	22678	28	10E
0005434503861	22678	29	10F
0005434503480	22678	30	11A
0005434503721	22678	31	11C
0005434503641	22678	32	11E
0005434503474	22678	33	11F
0005435103808	22678	34	12A
0005434503511	22678	35	12D
0005435103807	22678	36	13A
0005434503612	22678	37	13D
0005435103819	22678	38	13F
0005434503596	22678	39	14A
0005435103815	22678	40	14C
0005434503621	22678	41	14D
0005435103812	22678	42	14F
0005434503567	22678	43	15A
0005434503552	22678	44	15D
0005434503860	22678	45	15F
0005434503626	22678	46	16C
0005434503475	22678	47	16D
0005434503765	22678	48	17A
0005435103814	22678	49	17D
0005434503601	22678	50	18C
0005434503722	22678	51	18E
0005434503460	22678	52	18F
0005434503479	22678	53	19A
0005434503481	22678	54	20C
0005434503602	22678	55	20F
0005435652946	1647	1	1D
0005433367500	1647	2	2A
0005435652936	1647	3	2C
0005435652929	1647	4	2F
0005435652953	1647	5	3A
0005435652923	1647	6	3C
0005435652948	1647	7	3D
0005433367495	1647	8	3F
0005433367449	1647	9	4A
0005433367499	1647	10	4D
0005435652917	1647	11	5A
0005433367621	1647	12	5C
0005435652942	1647	13	5D
0005435652920	1647	14	5E
0005433367498	1647	15	5F
0005435652931	1647	16	6A
0005433367390	1647	17	6D
0005435652918	1647	18	6E
0005433367419	1647	19	7A
0005433367565	1647	20	7C
0005433367365	1647	21	7D
0005433367475	1647	22	7E
0005435652922	1647	23	7F
0005435652945	1647	24	8D
0005435652930	1647	25	8F
0005433367539	1647	26	9A
0005435652932	1647	27	9C
0005435652952	1647	28	9E
0005433367376	1647	29	9F
0005435652934	1647	30	10A
0005435652928	1647	31	10C
0005435652943	1647	32	10D
0005433367540	1647	33	10E
0005435652919	1647	34	11A
0005435652940	1647	35	11C
0005433367515	1647	36	11D
0005433367465	1647	37	11F
0005433367381	1647	38	12A
0005433367450	1647	39	12C
0005435652950	1647	40	12D
0005435652933	1647	41	12E
0005433367496	1647	42	12F
0005433367497	1647	43	13A
0005435652949	1647	44	13D
0005435652927	1647	45	13E
0005435652926	1647	46	14A
0005433367563	1647	47	14C
0005433367296	1647	48	14F
0005433367488	1647	49	15A
0005435652937	1647	50	15C
0005433367620	1647	51	15E
0005435652951	1647	52	15F
0005433367418	1647	53	16A
0005433367476	1647	54	16C
0005433367411	1647	55	16E
0005435652954	1647	56	16F
0005433367452	1647	57	17A
0005433367375	1647	58	17C
0005435652947	1647	59	17E
0005435652939	1647	60	17F
0005433367466	1647	61	18A
0005433367448	1647	62	18C
0005435652944	1647	63	18D
0005433367333	1647	64	18E
0005435652924	1647	65	18F
0005433367410	1647	66	19A
0005435652935	1647	67	19C
0005435652938	1647	68	19D
0005433367451	1647	69	19E
0005435652921	1647	70	19F
0005435652941	1647	71	20A
0005435652925	1647	72	20C
0005433367417	1647	73	20D
0005433367538	1647	74	20E
0005433367640	1647	75	20F
0005435652370	21676	1	1A
0005435652421	21676	2	1C
0005433367775	21676	3	1D
0005435652389	21676	4	1F
0005433367778	21676	5	2A
0005435652597	21676	6	2C
0005433367762	21676	7	2D
0005433367789	21676	8	2F
0005435652379	21676	9	3A
0005433367785	21676	10	3C
0005435652515	21676	11	3D
0005435652365	21676	12	3F
0005433367767	21676	13	4A
0005435652391	21676	14	4C
0005433367787	21676	15	4D
0005433367781	21676	16	4E
0005435652582	21676	17	4F
0005433367759	21676	18	5A
0005435652423	21676	19	5C
0005435652608	21676	20	5D
0005435652560	21676	21	5E
0005433367788	21676	22	5F
0005435652591	21676	23	6A
0005435652429	21676	24	6C
0005433367769	21676	25	6D
0005435652307	21676	26	6E
0005435652306	21676	27	7A
0005433367773	21676	28	7C
0005435652618	21676	29	7D
0005433367786	21676	30	7E
0005433367791	21676	31	7F
0005433367777	21676	32	8A
0005433367756	21676	33	8C
0005435652584	21676	34	8D
0005435652589	21676	35	8E
0005433367792	21676	36	8F
0005433367761	21676	37	9D
0005433367770	21676	38	9E
0005435652532	21676	39	9F
0005433367764	21676	40	10D
0005435652485	21676	41	10F
0005435652390	21676	42	11A
0005435652258	21676	43	11D
0005433367758	21676	44	11F
0005435652462	21676	45	12A
0005433367771	21676	46	12C
0005435652505	21676	47	12D
0005433367763	21676	48	12E
0005433367776	21676	49	13A
0005435652551	21676	50	13D
0005433367765	21676	51	13E
0005435652598	21676	52	13F
0005433367757	21676	53	14A
0005435652605	21676	54	14C
0005435652428	21676	55	14D
0005435652490	21676	56	14E
0005435652546	21676	57	14F
0005435652606	21676	58	15A
0005433367780	21676	59	15C
0005433367782	21676	60	15D
0005435652509	21676	61	15E
0005435652431	21676	62	15F
0005433367766	21676	63	16A
0005435652547	21676	64	16C
0005433367772	21676	65	16D
0005435652465	21676	66	16E
0005433367760	21676	67	16F
0005435652422	21676	68	17A
0005435652508	21676	69	17C
0005435652609	21676	70	17D
0005435652426	21676	71	17E
0005433367779	21676	72	18A
0005433367783	21676	73	18C
0005433367774	21676	74	18D
0005435652439	21676	75	18F
0005433367790	21676	76	19D
0005435652583	21676	77	19E
0005433367793	21676	78	19F
0005433367784	21676	79	20A
0005435652432	21676	80	20C
0005433367768	21676	81	20D
0005435652510	21676	82	20E
0005435652424	21676	83	20F
0005435627117	12271	1	4A
0005435627116	12271	2	6B
0005433985800	4148	1	1A
0005433985821	4148	2	1F
0005435788764	4148	3	3A
0005433985819	4148	4	3D
0005433985837	4148	5	3F
0005433985810	4148	6	4A
0005433985803	4148	7	4D
0005433985799	4148	8	4E
0005433985796	4148	9	4F
0005433985808	4148	10	5A
0005433985830	4148	11	5C
0005433985811	4148	12	5F
0005433985833	4148	13	6A
0005433985824	4148	14	6D
0005433985802	4148	15	6F
0005433985792	4148	16	7A
0005433985839	4148	17	7D
0005433985832	4148	18	7E
0005433985827	4148	19	7F
0005433985806	4148	20	8D
0005433985807	4148	21	8E
0005433985826	4148	22	8F
0005433985816	4148	23	9A
0005433985822	4148	24	9F
0005433985809	4148	25	10E
0005433985825	4148	26	10F
0005433985828	4148	27	11E
0005433985797	4148	28	12C
0005433985791	4148	29	12F
0005433985829	4148	30	13C
0005433985836	4148	31	13E
0005433985818	4148	32	13D
0005433985801	4148	33	13F
0005433985805	4148	34	14F
0005433985814	4148	35	15A
0005433985812	4148	36	15D
0005435788763	4148	37	16C
0005433985795	4148	38	16E
0005433985794	4148	39	17C
0005433985813	4148	40	17E
0005433985815	4148	41	17F
0005433985831	4148	42	18A
0005433985793	4148	43	18D
0005433985834	4148	44	18E
0005433985823	4148	45	19C
0005433985835	4148	46	19D
0005433985804	4148	47	19E
0005433985817	4148	48	19F
0005433985820	4148	49	20C
0005433985798	4148	50	20D
0005433985838	4148	51	20E
0005433985361	25648	1	1C
0005433985439	25648	2	1D
0005433985395	25648	3	2D
0005433985413	25648	4	2F
0005435788737	25648	5	3A
0005433985252	25648	6	3C
0005433985407	25648	7	3D
0005433985331	25648	8	3F
0005433985340	25648	9	4A
0005433985330	25648	10	4C
0005433985545	25648	11	4D
0005433985415	25648	12	4F
0005433985393	25648	13	5A
0005433985504	25648	14	5E
0005433985342	25648	15	5F
0005433985181	25648	16	6A
0005433985414	25648	17	6C
0005433985508	25648	18	6E
0005433985515	25648	19	7D
0005435788752	25648	20	7F
0005433985211	25648	21	8A
0005433985308	25648	22	8E
0005433985528	25648	23	9C
0005433985372	25648	24	9D
0005433985290	25648	25	9E
0005433985460	25648	26	10C
0005433985546	25648	27	10D
0005433985284	25648	28	10F
0005433985341	25648	29	11A
0005433985210	25648	30	11C
0005433985235	25648	31	11D
0005433985251	25648	32	11F
0005433985554	25648	33	12A
0005433985539	25648	34	12C
0005433985474	25648	35	12D
0005433985450	25648	36	12E
0005433985289	25648	37	12F
0005433985367	25648	38	13A
0005435788735	25648	39	13C
0005433985392	25648	40	13D
0005433985213	25648	41	14A
0005433985366	25648	42	14C
0005433985263	25648	43	14D
0005433985326	25648	44	14F
0005433985182	25648	45	15A
0005433985219	25648	46	15C
0005433985352	25648	47	15F
0005433985320	25648	48	16A
0005433985179	25648	49	16D
0005433985510	25648	50	16E
0005433985473	25648	51	16F
0005433985279	25648	52	17C
0005433985516	25648	53	17D
0005433985363	25648	54	17F
0005433985305	25648	55	18A
0005433985291	25648	56	18C
0005433985368	25648	57	18D
0005433985264	25648	58	18E
0005433985438	25648	59	18F
0005433985437	25648	60	19E
0005433985561	25648	61	20A
0005433985394	25648	62	20C
0005433985218	25648	63	20D
0005433985491	25648	64	20E
0005433985540	25648	65	20F
0005433461570	20240	1	1A
0005433460415	20240	2	3H
0005433461579	20240	3	4B
0005433461571	20240	4	5B
0005433460418	20240	5	9B
0005433461572	20240	6	12G
0005433461567	20240	7	13A
0005433460419	20240	8	13E
0005433461578	20240	9	14A
0005433460426	20240	10	15A
0005433461580	20240	11	16B
0005433461566	20240	12	16A
0005433461575	20240	13	16D
0005433460420	20240	14	18E
0005433461574	20240	15	20E
0005433461569	20240	16	20D
0005433460423	20240	17	21D
0005433461576	20240	18	21F
0005433461577	20240	19	22B
0005433461573	20240	20	23F
0005433460425	20240	21	23H
0005433460428	20240	22	24F
0005433460422	20240	23	28D
0005433460427	20240	24	29F
0005433460414	20240	25	30F
0005433460416	20240	26	31F
0005433460424	20240	27	32A
0005433460417	20240	28	34D
0005433460421	20240	29	34G
0005433460413	20240	30	35E
0005433461568	20240	31	37G
0005433461565	20240	32	38H
0005435719565	24753	1	21B
0005433168361	21319	1	2A
0005433168359	21319	2	2C
0005434509054	21319	3	2D
0005434509064	21319	4	3A
0005434509066	21319	5	3B
0005434509065	21319	6	4A
0005434509073	21319	7	5A
0005434509069	21319	8	5C
0005433168357	21319	9	6B
0005433168362	21319	10	6C
0005433168356	21319	11	6D
0005434509070	21319	12	7A
0005433168363	21319	13	7C
0005434509074	21319	14	7D
0005434509061	21319	15	18B
0005434509072	21319	16	18D
0005434509067	21319	17	19B
0005434509076	21319	18	21B
0005433168358	21319	19	21C
0005434509043	21319	20	21D
0005434509044	21319	21	22A
0005434509060	21319	22	22B
0005433168360	21319	23	22C
0005434509055	21319	24	23B
0005432655434	17873	1	1C
0005432658564	17873	2	2C
0005434151698	17873	3	3C
0005432665247	17873	4	3D
0005432655333	17873	5	3F
0005432869509	17873	6	5D
0005432665246	17873	7	6E
0005432655391	17873	8	7D
0005432655332	17873	9	7E
0005432667430	17873	10	8D
0005432658562	17873	11	8F
0005432869511	17873	12	9A
0005432869508	17873	13	9C
0005432657402	17873	14	10C
0005432665248	17873	15	10D
0005432655377	17873	16	13A
0005432655380	17873	17	13E
0005432869510	17873	18	14E
0005432869507	17873	19	15A
0005432655433	17873	20	15E
0005432665251	17873	21	15F
0005432657395	17873	22	16A
0005432655378	17873	23	16C
0005432657421	17873	24	16F
0005432655429	17873	25	17C
0005432667431	17873	26	17D
0005432657403	17873	27	18A
0005432660794	17873	28	18C
0005432655435	17873	29	20A
0005432655475	26286	1	1A
0005432659697	26286	2	1C
0005432655480	26286	3	1F
0005432657435	26286	4	2A
0005432657437	26286	5	2F
0005432658582	26286	6	3F
0005434151675	26286	7	4D
0005432869459	26286	8	4E
0005432655481	26286	9	5C
0005432869414	26286	10	5F
0005432660810	26286	11	6A
0005432657436	26286	12	7D
0005432655478	26286	13	7E
0005432660809	26286	14	8E
0005432869460	26286	15	9C
0005432665266	26286	16	10C
0005432869428	26286	17	10D
0005432660808	26286	18	10F
0005432655482	26286	19	11F
0005432655472	26286	20	13E
0005432659698	26286	21	14D
0005432655474	26286	22	14E
0005432869455	26286	23	14F
0005432655473	26286	24	15A
0005434151670	26286	25	15C
0005432869435	26286	26	15E
0005432667446	26286	27	16C
0005432655476	26286	28	16D
0005432655483	26286	29	17A
0005432665265	26286	30	17E
0005432666379	26286	31	17F
0005432666380	26286	32	18A
0005432655484	26286	33	18D
0005432655477	26286	34	19C
0005432667445	26286	35	19D
0005432667444	26286	36	19E
0005432655479	26286	37	20D
0005434151671	26286	38	20E
0005434151674	26286	39	20F
0005432328550	3072	1	1A
0005432328560	3072	2	1C
0005433438857	3072	3	1F
0005432328573	3072	4	2C
0005432328565	3072	5	2F
0005432287174	3072	6	3C
0005432328558	3072	7	3D
0005432328569	3072	8	3F
0005432328552	3072	9	4A
0005432328581	3072	10	4E
0005432287177	3072	11	4F
0005433438858	3072	12	5A
0005432328592	3072	13	5C
0005432905088	3072	14	5D
0005432328577	3072	15	5E
0005432848836	3072	16	5F
0005433438851	3072	17	6A
0005432328572	3072	18	6C
0005432328582	3072	19	6E
0005432328563	3072	20	6F
0005432328562	3072	21	7C
0005432328587	3072	22	7D
0005432328556	3072	23	7E
0005433438849	3072	24	7F
0005433438855	3072	25	8A
0005432328553	3072	26	8C
0005432328554	3072	27	8E
0005432328589	3072	28	8F
0005432328575	3072	29	9A
0005432905090	3072	30	9D
0005432328551	3072	31	9E
0005432905053	3072	32	10D
0005432328586	3072	33	10F
0005432328567	3072	34	11A
0005432328564	3072	35	11D
0005432328580	3072	36	12A
0005433438854	3072	37	12C
0005432328591	3072	38	12E
0005432328588	3072	39	12F
0005433438850	3072	40	13C
0005432328594	3072	41	13D
0005432328576	3072	42	13E
0005432328583	3072	43	13F
0005432328584	3072	44	14A
0005432328574	3072	45	14F
0005432328570	3072	46	15A
0005432328593	3072	47	15C
0005432328559	3072	48	15D
0005433438856	3072	49	15E
0005432328590	3072	50	15F
0005432328579	3072	51	16A
0005432328585	3072	52	16C
0005432287176	3072	53	16D
0005432328555	3072	54	17C
0005432287173	3072	55	17D
0005432328571	3072	56	17E
0005432287175	3072	57	17F
0005432328578	3072	58	18C
0005433438852	3072	59	18D
0005432328568	3072	60	18E
0005432287172	3072	61	18F
0005432905089	3072	62	19E
0005432328561	3072	63	19F
0005432328566	3072	64	20D
0005433438853	3072	65	20E
0005432328557	3072	66	20F
0005432328093	31099	1	1C
0005432328114	31099	2	1D
0005432054294	31099	3	1F
0005432328098	31099	4	3D
0005432328246	31099	5	4A
0005432327942	31099	6	4C
0005432328115	31099	7	4D
0005433438806	31099	8	4E
0005432328037	31099	9	4F
0005432328125	31099	10	5E
0005432328295	31099	11	5F
0005432905113	31099	12	6C
0005433438810	31099	13	6D
0005432328038	31099	14	6E
0005432328059	31099	15	7C
0005432328245	31099	16	7D
0005432328250	31099	17	7E
0005432905111	31099	18	7F
0005432905112	31099	19	8A
0005432328069	31099	20	8D
0005432328148	31099	21	8E
0005432328248	31099	22	8F
0005432328163	31099	23	9A
0005432327947	31099	24	9E
0005432905109	31099	25	9F
0005432328367	31099	26	10D
0005432328249	31099	27	10E
0005432054295	31099	28	10F
0005432905110	31099	29	11D
0005432328182	31099	30	12A
0005432328127	31099	31	12D
0005432328141	31099	32	12E
0005432328142	31099	33	12F
0005432328145	31099	34	13A
0005432327985	31099	35	13D
0005432328068	31099	36	13F
0005432328087	31099	37	14A
0005433438804	31099	38	14F
0005433438809	31099	39	15C
0005432905114	31099	40	16A
0005432328150	31099	41	16C
0005432328085	31099	42	16D
0005433438796	31099	43	16E
0005432328309	31099	44	17C
0005432328144	31099	45	17D
0005432327943	31099	46	17F
0005432328211	31099	47	18C
0005432328149	31099	48	18D
0005432328316	31099	49	18E
0005432328269	31099	50	19A
0005432327996	31099	51	19E
0005432054296	31099	52	19F
0005433438779	31099	53	20A
0005432328126	31099	54	20C
0005432328099	31099	55	20E
0005432328218	31099	56	20F
0005435999207	6228	1	1A
0005435999201	6228	2	2A
0005434309709	6228	3	2D
0005435487634	6228	4	3A
0005435487495	6228	5	3C
0005435296989	6228	6	3F
0005435999217	6228	7	4C
0005435487637	6228	8	4B
0005435487550	6228	9	4E
0005435999208	6228	10	4D
0005435999199	6228	11	4F
0005432146193	6228	12	5A
0005435296988	6228	13	5F
0005435487577	6228	14	6D
0005435487520	6228	15	7A
0005435999210	6228	16	6F
0005435999209	6228	17	7C
0005434309707	6228	18	7D
0005435999214	6228	19	7E
0005435999212	6228	20	8B
0005435487501	6228	21	8E
0005435999196	6228	22	9C
0005434309702	6228	23	9E
0005435487538	6228	24	9D
0005435296973	6228	25	9F
0005434309697	6228	26	10C
0005432146192	6228	27	11A
0005435296965	6228	28	11D
0005435487564	6228	29	11F
0005435487557	6228	30	11E
0005435296985	6228	31	12A
0005435999200	6228	32	12C
0005434309706	6228	33	13A
0005435487516	6228	34	13C
0005434309703	6228	35	13B
0005435487619	6228	36	13D
0005435487565	6228	37	13E
0005435999213	6228	38	14B
0005434309701	6228	39	14C
0005435487540	6228	40	14F
0005435487549	6228	41	15B
0005435487539	6228	42	15C
0005434309698	6228	43	15D
0005435487494	6228	44	15F
0005434309705	6228	45	16C
0005435487578	6228	46	16F
0005434309700	6228	47	17B
0005435999205	6228	48	17C
0005434309708	6228	49	17E
0005435999216	6228	50	18E
0005435999215	6228	51	19A
0005434309696	6228	52	19D
0005435999211	6228	53	19E
0005435296986	6228	54	19F
0005435487469	6228	55	20A
0005435999202	6228	56	20D
0005435999206	6228	57	20E
0005435999197	6228	58	21A
0005435296974	6228	59	21B
0005435296975	6228	60	21D
0005435999204	6228	61	21C
0005435999198	6228	62	21F
0005435296966	6228	63	22C
0005432146194	6228	64	22E
0005434309699	6228	65	22D
0005435487568	6228	66	23B
0005435999203	6228	67	23D
0005434309704	6228	68	23F
0005435487502	6228	69	23E
0005435999000	19578	1	1A
0005435999004	19578	2	1F
0005435487763	19578	3	2C
0005435487747	19578	4	2A
0005434309575	19578	5	2D
0005435297036	19578	6	2F
0005434309547	19578	7	3C
0005435487752	19578	8	3A
0005435487754	19578	9	4A
0005435999041	19578	10	4C
0005434309576	19578	11	4F
0005435487745	19578	12	5C
0005435999027	19578	13	5B
0005435999009	19578	14	5D
0005435297038	19578	15	5E
0005434309607	19578	16	6B
0005434309545	19578	17	7C
0005434309602	19578	18	7E
0005435487757	19578	19	8A
0005435998970	19578	20	8B
0005435487746	19578	21	8D
0005434309618	19578	22	8F
0005435487761	19578	23	9A
0005434309581	19578	24	9C
0005434309560	19578	25	9B
0005434309610	19578	26	10D
0005435487759	19578	27	11B
0005434309611	19578	28	11F
0005434309571	19578	29	12A
0005434309546	19578	30	12D
0005435487758	19578	31	13B
0005435297041	19578	32	13A
0005435487762	19578	33	13F
0005435998982	19578	34	14A
0005435487743	19578	35	14C
0005434309577	19578	36	14B
0005435487744	19578	37	14E
0005435297039	19578	38	15A
0005435487742	19578	39	15E
0005434309629	19578	40	16A
0005435998980	19578	41	16D
0005435487753	19578	42	16E
0005435297040	19578	43	17A
0005435487751	19578	44	16F
0005435999002	19578	45	17B
0005435998978	19578	46	17C
0005435297042	19578	47	17F
0005435999008	19578	48	18A
0005434309572	19578	49	18B
0005435999032	19578	50	18D
0005435999023	19578	51	19A
0005435999031	19578	52	19D
0005435487748	19578	53	19F
0005435999028	19578	54	19E
0005435999003	19578	55	20B
0005435487741	19578	56	20C
0005435999013	19578	57	21A
0005435487756	19578	58	20F
0005435487750	19578	59	21B
0005434309530	19578	60	21C
0005435999024	19578	61	21F
0005434309636	19578	62	22B
0005435487760	19578	63	22F
0005435297037	19578	64	22E
0005435487755	19578	65	23A
0005435487749	19578	66	23F
0005433158123	17558	1	1C
0005434446495	17558	2	1D
0005433158120	17558	3	2D
0005433158124	17558	4	6A
0005433158125	17558	5	7A
0005434446485	17558	6	7B
0005434446491	17558	7	18B
0005434446488	17558	8	18C
0005433158122	17558	9	19B
0005434446486	17558	10	21B
0005433158121	17558	11	21C
0005433158126	17558	12	22A
0005434446487	17558	13	22D
0005433158127	17558	14	23A
0005435508330	1592	1	1A
0005434565871	1592	2	1C
0005432291924	1592	3	1D
0005435517857	1592	4	1F
0005435502249	1592	5	2A
0005435508325	1592	6	2C
0005435502246	1592	7	2D
0005435508323	1592	8	2F
0005435502250	1592	9	3A
0005435502251	1592	10	3C
0005434565876	1592	11	3D
0005435502264	1592	12	3F
0005435508324	1592	13	4A
0005434565875	1592	14	4C
0005435517856	1592	15	4D
0005434565884	1592	16	4F
0005435502261	1592	17	5C
0005435508329	1592	18	5D
0005435517852	1592	19	5E
0005435517865	1592	20	6A
0005433186028	1592	21	6C
0005435502257	1592	22	6D
0005434565879	1592	23	6E
0005433186004	1592	24	6F
0005435517858	1592	25	7C
0005435502245	1592	26	7D
0005434565874	1592	27	7E
0005435517868	1592	28	7F
0005435517859	1592	29	8D
0005435502258	1592	30	8F
0005435502248	1592	31	9A
0005435517854	1592	32	9C
0005435517872	1592	33	9D
0005435502263	1592	34	9E
0005435517862	1592	35	9F
0005435517861	1592	36	10A
0005434565878	1592	37	10C
0005434565881	1592	38	10D
0005435502253	1592	39	10E
0005432291922	1592	40	10F
0005435508333	1592	41	11A
0005435508327	1592	42	11C
0005434565883	1592	43	11E
0005435502255	1592	44	11F
0005435502262	1592	45	12A
0005434565877	1592	46	12C
0005435517860	1592	47	12D
0005435502243	1592	48	12E
0005435508336	1592	49	12F
0005435502247	1592	50	13C
0005434565882	1592	51	13A
0005435502254	1592	52	13E
0005435508331	1592	53	13F
0005435508335	1592	54	14D
0005435517855	1592	55	14E
0005435502256	1592	56	15C
0005435508326	1592	57	15D
0005435517864	1592	58	15E
0005434565880	1592	59	16A
0005432291923	1592	60	16C
0005435502252	1592	61	16E
0005435508328	1592	62	16F
0005435517871	1592	63	17A
0005435517853	1592	64	17D
0005435502259	1592	65	17E
0005435508332	1592	66	17F
0005435517869	1592	67	18A
0005435517867	1592	68	18C
0005434565872	1592	69	18D
0005433186029	1592	70	18E
0005435502260	1592	71	18F
0005435508334	1592	72	19A
0005433186015	1592	73	19D
0005435517866	1592	74	19E
0005433186036	1592	75	19F
0005435517863	1592	76	20C
0005435517870	1592	77	20D
0005435502244	1592	78	20E
0005434565873	1592	79	20F
0005435502125	20842	1	1C
0005433186099	20842	2	1D
0005434565769	20842	3	1F
0005435528926	20842	4	2A
0005433186094	20842	5	2C
0005434565736	20842	6	2D
0005435501982	20842	7	3A
0005435528997	20842	8	3C
0005433186090	20842	9	3D
0005435528975	20842	10	3F
0005434565715	20842	11	4A
0005435502126	20842	12	4C
0005435528927	20842	13	4D
0005435528993	20842	14	4E
0005435502099	20842	15	4F
0005435545642	20842	16	5C
0005435529015	20842	17	5D
0005435501988	20842	18	5E
0005433186093	20842	19	5F
0005434565735	20842	20	6A
0005435545617	20842	21	6C
0005434565717	20842	22	6D
0005435528917	20842	23	6F
0005435545620	20842	24	7A
0005435502133	20842	25	7C
0005435529043	20842	26	7E
0005435528955	20842	27	7F
0005435502140	20842	28	8A
0005435502010	20842	29	8C
0005434565756	20842	30	8E
0005435528953	20842	31	9A
0005435529017	20842	32	9E
0005435528890	20842	33	9F
0005434565716	20842	34	10C
0005435528956	20842	35	10D
0005435528891	20842	36	10E
0005434565721	20842	37	10F
0005435502084	20842	38	11A
0005435501999	20842	39	11C
0005435528989	20842	40	11D
0005435528968	20842	41	11F
0005435528974	20842	42	12A
0005434565718	20842	43	12C
0005435502141	20842	44	12D
0005435528935	20842	45	12E
0005435528910	20842	46	12F
0005435502023	20842	47	13A
0005435528925	20842	48	13C
0005435528971	20842	49	13D
0005435502008	20842	50	13E
0005434565775	20842	51	14A
0005433186095	20842	52	14C
0005435501952	20842	53	14E
0005435502011	20842	54	14F
0005435528996	20842	55	15A
0005434565768	20842	56	15C
0005434565709	20842	57	15D
0005434565762	20842	58	15E
0005433186092	20842	59	15F
0005435502007	20842	60	16A
0005435545623	20842	61	16C
0005433186097	20842	62	16E
0005434565742	20842	63	16F
0005433186091	20842	64	17A
0005433186096	20842	65	17C
0005435502111	20842	66	17D
0005433186098	20842	67	17F
0005435502029	20842	68	18A
0005434565759	20842	69	18C
0005435545613	20842	70	18D
0005434565708	20842	71	18F
0005435529010	20842	72	19A
0005434565719	20842	73	19C
0005435501987	20842	74	19E
0005435529018	20842	75	19F
0005435501998	20842	76	20C
0005435545622	20842	77	20D
0005435529044	20842	78	20E
0005435501983	20842	79	20F
0005435153725	3932	1	1C
0005435153723	3932	2	2B
0005435931562	3932	3	4C
0005435153724	3932	4	5A
0005435931564	3932	5	6B
0005435153726	3932	6	7B
0005435931563	3932	7	22C
0005435931561	3932	8	23B
0005435153687	21862	1	4A
0005435931591	21862	2	4B
0005435931589	21862	3	5D
0005435153661	21862	4	6D
0005435153686	21862	5	7B
0005435931590	21862	6	7D
0005435153667	21862	7	20A
0005435931592	21862	8	21A
0005435225478	7212	1	1A
0005432628809	7212	2	1B
0005432628811	7212	3	2D
0005432628812	7212	4	3A
0005435225486	7212	5	3C
0005432628804	7212	6	4D
0005435225533	7212	7	5B
0005432628807	7212	8	6B
0005432628802	7212	9	6C
0005435225534	7212	10	6D
0005432628801	7212	11	7D
0005432628813	7212	12	18A
0005435225532	7212	13	18B
0005432628808	7212	14	18C
0005432628798	7212	15	19A
0005432628803	7212	16	19C
0005432628800	7212	17	19D
0005435225506	7212	18	20A
0005432628805	7212	19	20D
0005435225502	7212	20	21A
0005432628799	7212	21	21B
0005432628806	7212	22	21C
0005432628810	7212	23	23A
0005435225485	7212	24	23B
0005432628667	28092	1	1C
0005432628745	28092	2	1D
0005435225559	28092	3	2B
0005432628658	28092	4	3C
0005435225562	28092	5	3D
0005435225563	28092	6	4C
0005432628641	28092	7	4D
0005432628700	28092	8	5A
0005432628722	28092	9	5D
0005432628612	28092	10	6D
0005432628694	28092	11	7C
0005432628688	28092	12	7D
0005435225565	28092	13	18B
0005432628723	28092	14	18D
0005432628746	28092	15	19A
0005435225561	28092	16	19B
0005435225560	28092	17	19D
0005435225566	28092	18	20B
0005432628659	28092	19	20C
0005432628611	28092	20	20D
0005432628695	28092	21	21A
0005435225564	28092	22	22A
0005432628627	28092	23	22B
0005432628689	28092	24	22D
0005432628708	28092	25	23A
0005434267905	8734	1	1B
0005435960039	8734	2	1C
0005434267909	8734	3	3D
0005435960040	8734	4	5C
0005434267910	8734	5	6D
0005434267919	8734	6	18B
0005434267904	8734	7	19C
0005435960037	8734	8	19D
0005435960038	8734	9	20A
0005434267901	8734	10	23B
0005435960026	15263	1	1B
0005434267937	15263	2	6C
0005434267938	15263	3	20A
0005434267940	15263	4	21A
0005434267939	15263	5	22C
0005432675096	1220	1	1C
0005432692968	1220	2	1A
0005432692956	1220	3	1D
0005432873201	1220	4	2A
0005432675081	1220	5	2C
0005432873211	1220	6	3A
0005432692947	1220	7	2F
0005432692943	1220	8	3D
0005432873195	1220	9	4A
0005432692951	1220	10	4D
0005432692962	1220	11	4C
0005432675082	1220	12	4F
0005432692960	1220	13	5C
0005432873191	1220	14	5A
0005432675083	1220	15	5F
0005432692953	1220	16	6B
0005432675085	1220	17	6A
0005432692958	1220	18	6E
0005432692944	1220	19	6D
0005432675080	1220	20	8A
0005432675088	1220	21	7F
0005432692966	1220	22	7E
0005432692950	1220	23	8B
0005432675084	1220	24	8E
0005432675095	1220	25	9A
0005432692952	1220	26	9D
0005432677556	1220	27	9C
0005432677557	1220	28	9B
0005432692965	1220	29	10A
0005432873210	1220	30	11A
0005432692940	1220	31	11E
0005432692967	1220	32	12A
0005432675094	1220	33	12C
0005432692939	1220	34	12E
0005432675091	1220	35	13A
0005432692961	1220	36	13E
0005432873215	1220	37	13D
0005432873194	1220	38	13F
0005432675086	1220	39	14B
0005432692946	1220	40	14D
0005432692964	1220	41	14F
0005432692949	1220	42	15B
0005432873203	1220	43	15E
0005432677559	1220	44	15D
0005432692957	1220	45	16A
0005432692955	1220	46	16B
0005432675092	1220	47	16E
0005432675089	1220	48	17A
0005432677558	1220	49	16F
0005432675087	1220	50	17B
0005432692941	1220	51	17F
0005432692959	1220	52	17E
0005432692942	1220	53	18B
0005432692954	1220	54	18C
0005432692938	1220	55	18E
0005432692945	1220	56	18D
0005432692948	1220	57	19A
0005432692963	1220	58	18F
0005432873202	1220	59	19B
0005432675093	1220	60	19F
0005432692937	1220	61	20D
0005432675090	1220	62	20F
0005432692605	17474	1	1C
0005432692665	17474	2	1A
0005432675021	17474	3	1D
0005432692651	17474	4	2D
0005432692743	17474	5	2C
0005432692613	17474	6	2F
0005432692716	17474	7	3D
0005432674913	17474	8	4A
0005432677527	17474	9	3F
0005432677526	17474	10	4C
0005432677542	17474	11	4F
0005432692698	17474	12	4D
0005432873273	17474	13	5C
0005432692775	17474	14	5F
0005432692724	17474	15	5D
0005432873272	17474	16	6B
0005432692662	17474	17	6A
0005432674914	17474	18	6D
0005432692739	17474	19	7C
0005432692661	17474	20	7F
0005432873270	17474	21	8C
0005432692585	17474	22	8B
0005432692862	17474	23	8A
0005432692685	17474	24	8D
0005432677517	17474	25	8E
0005432692738	17474	26	9F
0005432692686	17474	27	9E
0005432692751	17474	28	9D
0005432692753	17474	29	10A
0005432692756	17474	30	10B
0005432873274	17474	31	10D
0005432692714	17474	32	11A
0005432692777	17474	33	10F
0005432692752	17474	34	11B
0005432674893	17474	35	12A
0005432674920	17474	36	12C
0005432675000	17474	37	12E
0005432692577	17474	38	12F
0005432692583	17474	39	13E
0005432692606	17474	40	13D
0005432692684	17474	41	14A
0005432692601	17474	42	14E
0005432674921	17474	43	14C
0005432692607	17474	44	14F
0005432692576	17474	45	15D
0005432692681	17474	46	16C
0005432692744	17474	47	16B
0005432692612	17474	48	16E
0005432692586	17474	49	17B
0005432674974	17474	50	17D
0005432692640	17474	51	17F
0005432873269	17474	52	18B
0005432674905	17474	53	18C
0005432873268	17474	54	18E
0005432677543	17474	55	18F
0005432692659	17474	56	19C
0005432692680	17474	57	19D
0005432692778	17474	58	20A
0005432692584	17474	59	20B
0005432674975	17474	60	20C
0005432674904	17474	61	21A
0005432692660	17474	62	21C
0005432692863	17474	63	21D
0005432873271	17474	64	21F
0005434435129	1130	1	2A
0005434435140	1130	2	2D
0005433156615	1130	3	3A
0005433156683	1130	4	3B
0005433156656	1130	5	3C
0005434435137	1130	6	3D
0005434435143	1130	7	4A
0005433156616	1130	8	4B
0005433156613	1130	9	4C
0005434435134	1130	10	4D
0005433156652	1130	11	5A
0005434435131	1130	12	5B
0005434435144	1130	13	5C
0005434435138	1130	14	5D
0005433156642	1130	15	6A
0005434435133	1130	16	6B
0005433156668	1130	17	6C
0005433156681	1130	18	7C
0005433156662	1130	19	18B
0005433156684	1130	20	18C
0005433156643	1130	21	18D
0005434435141	1130	22	19C
0005434435139	1130	23	19D
0005434435142	1130	24	20A
0005433156669	1130	25	20B
0005434435130	1130	26	20C
0005433156690	1130	27	20D
0005433156680	1130	28	21A
0005434435135	1130	29	22C
0005433156622	1130	30	22D
0005434435136	1130	31	23A
0005434435132	1130	32	23B
0005434435017	17308	1	1C
0005433156728	17308	2	2C
0005433156723	17308	3	2D
0005434434941	17308	4	4A
0005433156724	17308	5	4C
0005434435016	17308	6	4D
0005434434950	17308	7	5A
0005433156722	17308	8	5D
0005433156725	17308	9	6A
0005433156727	17308	10	6B
0005434434949	17308	11	6C
0005434434942	17308	12	7A
0005434434995	17308	13	18A
0005433156726	17308	14	19A
0005434435045	17308	15	22A
0005433156721	17308	16	22B
0005433156720	17308	17	23B
0005435086809	4049	1	2A
0005435928080	4049	2	3B
0005435928081	4049	3	3D
0005435928092	4049	4	4B
0005435928089	4049	5	5B
0005435086811	4049	6	6A
0005435086815	4049	7	6B
0005435086812	4049	8	7B
0005435928086	4049	9	7D
0005435928084	4049	10	18D
0005435086813	4049	11	20B
0005435928085	4049	12	20D
0005435086814	4049	13	21A
0005435928093	4049	14	22C
0005435086810	4049	15	23B
0005435086770	24385	1	1C
0005435086760	24385	2	1D
0005435928127	24385	3	2D
0005435086756	24385	4	3D
0005435928131	24385	5	5B
0005435928126	24385	6	5D
0005435086748	24385	7	6A
0005435928128	24385	8	6D
0005435086714	24385	9	7C
0005435928130	24385	10	19C
0005435086753	24385	11	19D
0005435928129	24385	12	21C
0005435086754	24385	13	22B
0005435086737	24385	14	22C
0005435086747	24385	15	23A
0005435086715	24385	16	23B
0005435551578	17016	1	4B
0005435098549	17016	2	5G
0005435551571	17016	3	9H
0005435551573	17016	4	11B
0005435551561	17016	5	12B
0005435551572	17016	6	13G
0005435551576	17016	7	14E
0005435551562	17016	8	15B
0005435551567	17016	9	16H
0005435098547	17016	10	17B
0005435551563	17016	11	17D
0005435098546	17016	12	18A
0005435551558	17016	13	17H
0005435098550	17016	14	19B
0005435098545	17016	15	19E
0005435551560	17016	16	20A
0005435098551	17016	17	20G
0005435551569	17016	18	21A
0005435551556	17016	19	23B
0005435551575	17016	20	24A
0005435098544	17016	21	29B
0005435551577	17016	22	29F
0005435098548	17016	23	31A
0005435551574	17016	24	31E
0005435551568	17016	25	33B
0005435551557	17016	26	34A
0005435551570	17016	27	34E
0005435551565	17016	28	34G
0005435551566	17016	29	35D
0005435551564	17016	30	36A
0005435551559	17016	31	37B
0005434625932	4854	1	1A
0005435907443	4854	2	1C
0005434625933	4854	3	3C
0005434625931	4854	4	6A
0005435907442	4854	5	7D
0005434625936	4854	6	7E
0005434625938	4854	7	8F
0005434625930	4854	8	10C
0005435907441	4854	9	10E
0005434625934	4854	10	13C
0005434625935	4854	11	13F
0005434625937	4854	12	17E
0005435907494	32890	1	1F
0005435907492	32890	2	2C
0005434625873	32890	3	3F
0005433194854	32890	4	4A
0005433194852	32890	5	7A
0005435907495	32890	6	11C
0005434625893	32890	7	13A
0005435907491	32890	8	13C
0005433194851	32890	9	15A
0005434625841	32890	10	15C
0005434625910	32890	11	16D
0005434625891	32890	12	17E
0005434625869	32890	13	18A
0005433194855	32890	14	18C
0005433194853	32890	15	18E
0005434625842	32890	16	19D
0005435907493	32890	17	20A
0005435784784	13786	1	1A
0005435784803	13786	2	1B
0005435784948	13786	3	1C
0005432195687	13786	4	1D
0005435784897	13786	5	2A
0005435784973	13786	6	2B
0005435784845	13786	7	2C
0005435785028	13786	8	2D
0005435785000	13786	9	3A
0005435784898	13786	10	3B
0005435784908	13786	11	3C
0005435784894	13786	12	3D
0005435784816	13786	13	4A
0005435784924	13786	14	4B
0005435784933	13786	15	4C
0005435784969	13786	16	4D
0005435784968	13786	17	5A
0005435784921	13786	18	5B
0005435784854	13786	19	5C
0005435784804	13786	20	5D
0005435784802	13786	21	6A
0005435784983	13786	22	6B
0005435784846	13786	23	6C
0005435784893	13786	24	6D
0005435784872	13786	25	7A
0005432195686	13786	26	7B
0005435784880	13786	27	7C
0005435784907	13786	28	7D
0005435784906	13786	29	18A
0005435785097	13786	30	18B
0005435784987	13786	31	18C
0005435784857	13786	32	18D
0005435784988	13786	33	19A
0005435784913	13786	34	19B
0005435784909	13786	35	19C
0005435784950	13786	36	20A
0005435784881	13786	37	20B
0005435785032	13786	38	20C
0005435784891	13786	39	20D
0005435784971	13786	40	21A
0005435784932	13786	41	21B
0005435784972	13786	42	21C
0005435785004	13786	43	21D
0005435784947	13786	44	22A
0005435784896	13786	45	22B
0005435784936	13786	46	22C
0005435784960	13786	47	22D
0005435784954	13786	48	23A
0005435784953	13786	49	23B
0005435785197	27439	1	1A
0005435785193	27439	2	1B
0005435785192	27439	3	1C
0005435785202	27439	4	1D
0005435937315	27439	5	2A
0005435785219	27439	6	2B
0005435785221	27439	7	2C
0005435785211	27439	8	3A
0005435785215	27439	9	3B
0005435785201	27439	10	3C
0005435785199	27439	11	3D
0005435785212	27439	12	4A
0005435785210	27439	13	4B
0005435785187	27439	14	4C
0005435787345	27439	15	4D
0005435785194	27439	16	5A
0005435785207	27439	17	5B
0005435785220	27439	18	5C
0005435785206	27439	19	5D
0005435785222	27439	20	6A
0005435785214	27439	21	6B
0005435787344	27439	22	6C
0005435937314	27439	23	6D
0005435785213	27439	24	7A
0005435785204	27439	25	7B
0005435785190	27439	26	7C
0005435785191	27439	27	18A
0005432190614	27439	28	18C
0005435785209	27439	29	18D
0005435785189	27439	30	19A
0005435785200	27439	31	19B
0005435785195	27439	32	19C
0005435937313	27439	33	19D
0005435937325	27439	34	20A
0005435785196	27439	35	20B
0005435785205	27439	36	20C
0005435785208	27439	37	20D
0005435937326	27439	38	21B
0005435785198	27439	39	21C
0005435785216	27439	40	21D
0005435785218	27439	41	22A
0005435785188	27439	42	22B
0005435785203	27439	43	22C
0005435785217	27439	44	22D
0005432190613	27439	45	23A
0005432190612	27439	46	23B
0005432058369	20287	1	1A
0005434407161	20287	2	1C
0005434406956	20287	3	1D
0005434407149	20287	4	1F
0005434406837	20287	5	2A
0005434406789	20287	6	2C
0005434407003	20287	7	2F
0005434407177	20287	8	3D
0005432058370	20287	9	3F
0005434407021	20287	10	4C
0005434406988	20287	11	4D
0005434407229	20287	12	4E
0005434406857	20287	13	4F
0005434406884	20287	14	5A
0005434406955	20287	15	5C
0005432058371	20287	16	5E
0005434407106	20287	17	5F
0005434406987	20287	18	6A
0005434407200	20287	19	6C
0005434407201	20287	20	6E
0005434407270	20287	21	6F
0005434407105	20287	22	7C
0005434406863	20287	23	7E
0005434407008	20287	24	7F
0005434407111	20287	25	8A
0005434406912	20287	26	8C
0005434407112	20287	27	8D
0005434407179	20287	28	8E
0005432058368	20287	29	8F
0005434407093	20287	30	9A
0005434406885	20287	31	9C
0005434407199	20287	32	9D
0005434406927	20287	33	9E
0005434407060	20287	34	9F
0005434406870	20287	35	10A
0005434406864	20287	36	10D
0005434407167	20287	37	10F
0005434406939	20287	38	11A
0005434407134	20287	39	11C
0005435311035	20287	40	12A
0005434406938	20287	41	12C
0005434407107	20287	42	12D
0005434406861	20287	43	12E
0005434407103	20287	44	12F
0005434406788	20287	45	13A
0005434407180	20287	46	13C
0005434407198	20287	47	13D
0005434407077	20287	48	13F
0005434406903	20287	49	14C
0005434406902	20287	50	14D
0005434407117	20287	51	14E
0005434407125	20287	52	14F
0005434407101	20287	53	15A
0005434407058	20287	54	15C
0005434406858	20287	55	15D
0005434407271	20287	56	15E
0005434406926	20287	57	15F
0005434407222	20287	58	16A
0005434407269	20287	59	16D
0005434406946	20287	60	16E
0005434407038	20287	61	16F
0005434407305	20287	62	17A
0005434407094	20287	63	17C
0005434407160	20287	64	17E
0005434406928	20287	65	18A
0005434407051	20287	66	18C
0005434407148	20287	67	18D
0005434406972	20287	68	18F
0005434406957	20287	69	19C
0005434406990	20287	70	19F
0005434407181	20287	71	20A
0005434406996	20287	72	20D
0005434406995	20287	73	20F
0005434407569	26986	1	1C
0005434407581	26986	2	1D
0005434407584	26986	3	1F
0005434407585	26986	4	2A
0005434407568	26986	5	2C
0005434407603	26986	6	2F
0005434407546	26986	7	3C
0005434407574	26986	8	3D
0005434407557	26986	9	3F
0005434407593	26986	10	4A
0005434407575	26986	11	4C
0005434407544	26986	12	4D
0005434407599	26986	13	4F
0005434407560	26986	14	5A
0005434407596	26986	15	5C
0005434407567	26986	16	5D
0005434407549	26986	17	5E
0005434407600	26986	18	5F
0005434407583	26986	19	6C
0005434407573	26986	20	6A
0005432153918	26986	21	6D
0005435310854	26986	22	6E
0005434407591	26986	23	6F
0005434407551	26986	24	7A
0005435310902	26986	25	7C
0005434407545	26986	26	7D
0005432153913	26986	27	7F
0005434407556	26986	28	8A
0005435310893	26986	29	8D
0005434407586	26986	30	8C
0005432153914	26986	31	8E
0005434407547	26986	32	8F
0005435310897	26986	33	9A
0005435310898	26986	34	9C
0005434407579	26986	35	9D
0005435310903	26986	36	9E
0005434407576	26986	37	9F
0005434407588	26986	38	10C
0005434407570	26986	39	10D
0005434407589	26986	40	10E
0005434407565	26986	41	10F
0005434407572	26986	42	11A
0005434407571	26986	43	11C
0005434407563	26986	44	11E
0005434407564	26986	45	11F
0005434407582	26986	46	12A
0005434407587	26986	47	12C
0005432153916	26986	48	12D
0005434407542	26986	49	12E
0005432153919	26986	50	12F
0005434407601	26986	51	13A
0005435310896	26986	52	13C
0005434407597	26986	53	13D
0005435310843	26986	54	13F
0005434407590	26986	55	14A
0005434407550	26986	56	14C
0005434407604	26986	57	14D
0005432153920	26986	58	14E
0005434407555	26986	59	14F
0005434407595	26986	60	15C
0005434407554	26986	61	15D
0005434407553	26986	62	15E
0005435310904	26986	63	15F
0005434407562	26986	64	16A
0005434407559	26986	65	16C
0005432153915	26986	66	16D
0005434407541	26986	67	16E
0005434407602	26986	68	17A
0005434407577	26986	69	17D
0005435310914	26986	70	17E
0005434407594	26986	71	17F
0005434407558	26986	72	18C
0005434407578	26986	73	18D
0005434407592	26986	74	18E
0005434407561	26986	75	18F
0005434407598	26986	76	19A
0005434407552	26986	77	19C
0005434407548	26986	78	19D
0005434407566	26986	79	19F
0005435310844	26986	80	20A
0005434407543	26986	81	20C
0005434407605	26986	82	20D
0005432153917	26986	83	20E
0005434407580	26986	84	20F
0005433123767	5669	1	1D
0005433123706	5669	2	2D
0005433123707	5669	3	2F
0005432109696	5669	4	3D
0005434319351	5669	5	4A
0005434319344	5669	6	4C
0005433123661	5669	7	4E
0005433123697	5669	8	4F
0005434319358	5669	9	5E
0005433123588	5669	10	5F
0005434319346	5669	11	6E
0005434319363	5669	12	6F
0005433123636	5669	13	7A
0005433123671	5669	14	7C
0005432109695	5669	15	7E
0005434319348	5669	16	7F
0005434319359	5669	17	8C
0005434319349	5669	18	9C
0005433123724	5669	19	9D
0005434319350	5669	20	9E
0005434311213	5669	21	9F
0005434319362	5669	22	10A
0005432109694	5669	23	10F
0005433123725	5669	24	11D
0005434319360	5669	25	11E
0005434319347	5669	26	12A
0005433123670	5669	27	12E
0005434319356	5669	28	13A
0005433123654	5669	29	13D
0005434319345	5669	30	13F
0005434319355	5669	31	14C
0005433123695	5669	32	14D
0005433123683	5669	33	14E
0005434319361	5669	34	16D
0005433123698	5669	35	16E
0005434319357	5669	36	17A
0005434319354	5669	37	17C
0005433123696	5669	38	17F
0005433123693	5669	39	18A
0005434319352	5669	40	18D
0005434319343	5669	41	19D
0005433123653	5669	42	19E
0005434319353	5669	43	19F
0005434311212	5669	44	20E
0005433123879	15708	1	1A
0005434319161	15708	2	2C
0005433123878	15708	3	3A
0005433123871	15708	4	3C
0005433123880	15708	5	5F
0005433123877	15708	6	6C
0005433123887	15708	7	6D
0005433123883	15708	8	6E
0005433123873	15708	9	7D
0005434312292	15708	10	8A
0005434319162	15708	11	8E
0005434319160	15708	12	9A
0005433123881	15708	13	10A
0005433123875	15708	14	10C
0005433123886	15708	15	10D
0005433123876	15708	16	11D
0005433123882	15708	17	12A
0005434319199	15708	18	13A
0005434319188	15708	19	14A
0005433123885	15708	20	14C
0005433123866	15708	21	15C
0005433123870	15708	22	15D
0005433123874	15708	23	16A
0005433123872	15708	24	16F
0005433123867	15708	25	17A
0005434319200	15708	26	18E
0005433123884	15708	27	18F
0005433123869	15708	28	19D
0005434319179	15708	29	19F
0005433123868	15708	30	20C
0005434311202	15708	31	20D
0005435220312	31741	1	2C
0005435220314	31741	2	3D
0005435219192	31741	3	4D
0005435220311	31741	4	6A
0005435219194	31741	5	6D
0005435220313	31741	6	19A
0005435219196	31741	7	19D
0005435220315	31741	8	20A
0005435219195	31741	9	20B
0005435219193	31741	10	21D
0005435220490	31741	11	22B
0005434189095	9012	1	1C
0005434484330	9012	2	3C
0005434484325	9012	3	3D
0005434484331	9012	4	4D
0005434484326	9012	5	6A
0005434484328	9012	6	6C
0005434484327	9012	7	18C
0005434189146	9012	8	18D
0005434189104	9012	9	21B
0005434484329	9012	10	22A
0005434189160	16660	1	2C
0005434484271	16660	2	3C
0005434189162	16660	3	4B
0005434484299	16660	4	4C
0005434484298	16660	5	7B
0005434484265	16660	6	7C
0005434189163	16660	7	18C
0005434189159	16660	8	19D
0005434484258	16660	9	20A
0005434484242	16660	10	20D
0005434189161	16660	11	21B
0005434189164	16660	12	23A
0005433123868	7694	1	1A
0005433123869	7694	2	1D
0005433722126	7694	3	1F
0005433722129	7694	4	2C
0005433123872	7694	5	3A
0005433722104	7694	6	4A
0005433722119	7694	7	4E
0005433123887	7694	8	5A
0005433123867	7694	9	5F
0005433722141	7694	10	6C
0005433722127	7694	11	6E
0005433722125	7694	12	7A
0005433722143	7694	13	7C
0005433722144	7694	14	8D
0005433722163	7694	15	8E
0005433722118	7694	16	8F
0005433123880	7694	17	9C
0005433123871	7694	18	10A
0005433123875	7694	19	10E
0005433123877	7694	20	11A
0005433123876	7694	21	12C
0005433123882	7694	22	12E
0005433123873	7694	23	13E
0005433123886	7694	24	15A
0005433123866	7694	25	15C
0005433123884	7694	26	16A
0005433722142	7694	27	17A
0005433123881	7694	28	17C
0005433722140	7694	29	17E
0005433722146	7694	30	18D
0005433123874	7694	31	18F
0005433123883	7694	32	19A
0005433123878	7694	33	19D
0005433123885	7694	34	19E
0005433123870	7694	35	19F
0005433722145	7694	36	20E
0005433123879	7694	37	20F
0005433449911	7695	1	1C
0005432720818	7695	2	1D
0005432720834	7695	3	1F
0005432692994	7695	4	2A
0005432692996	7695	5	2C
0005433449897	7695	6	2D
0005432692970	7695	7	2F
0005432720831	7695	8	3A
0005432692997	7695	9	3C
0005432071565	7695	10	3D
0005432720826	7695	11	3F
0005432720822	7695	12	4A
0005432692975	7695	13	4E
0005432692982	7695	14	4F
0005432692973	7695	15	5A
0005432692972	7695	16	5C
0005432720838	7695	17	5E
0005432692971	7695	18	5F
0005432692985	7695	19	6A
0005432692983	7695	20	6C
0005432692979	7695	21	6D
0005433449916	7695	22	6E
0005432692978	7695	23	7A
0005433449905	7695	24	7C
0005432720832	7695	25	7D
0005432720817	7695	26	7E
0005432692981	7695	27	7F
0005432720827	7695	28	8A
0005432720820	7695	29	8C
0005433449895	7695	30	8E
0005432692974	7695	31	8F
0005432720830	7695	32	9A
0005432720821	7695	33	9C
0005432720823	7695	34	9D
0005433449910	7695	35	9E
0005433449914	7695	36	9F
0005432720835	7695	37	10A
0005432692988	7695	38	10C
0005432693000	7695	39	10D
0005432692995	7695	40	10E
0005433449899	7695	41	10F
0005432720833	7695	42	11A
0005432720813	7695	43	11C
0005433449912	7695	44	11D
0005432692993	7695	45	11E
0005433449906	7695	46	11F
0005433449902	7695	47	12A
0005433449901	7695	48	12C
0005432692969	7695	49	12D
0005432720816	7695	50	12E
0005432071563	7695	51	12F
0005432692977	7695	52	13A
0005432720824	7695	53	13C
0005432720829	7695	54	13E
0005432692976	7695	55	14C
0005433449903	7695	56	14A
0005432692991	7695	57	14D
0005432692984	7695	58	14E
0005432692987	7695	59	15A
0005432720837	7695	60	15C
0005432692998	7695	61	15D
0005433449908	7695	62	15E
0005432720814	7695	63	15F
0005432692999	7695	64	16A
0005432720839	7695	65	16D
0005432692990	7695	66	16E
0005433449900	7695	67	16F
0005432692986	7695	68	17A
0005433449898	7695	69	17C
0005433449907	7695	70	17E
0005433449913	7695	71	17F
0005433449915	7695	72	18A
0005432071564	7695	73	18C
0005433449909	7695	74	18D
0005432720819	7695	75	18E
0005432692989	7695	76	18F
0005432720836	7695	77	19A
0005432692980	7695	78	19C
0005432720828	7695	79	19E
0005432692992	7695	80	19F
0005433449917	7695	81	20A
0005432720815	7695	82	20C
0005433449896	7695	83	20D
0005432720825	7695	84	20E
0005433449904	7695	85	20F
0005433449681	30332	1	1C
0005432692601	30332	2	1D
0005432692744	30332	3	2A
0005432692585	30332	4	2C
0005432692686	30332	5	2F
0005432692778	30332	6	3A
0005432692681	30332	7	4A
0005432692738	30332	8	5A
0005432692576	30332	9	5C
0005432692680	30332	10	5D
0005433449811	30332	11	5E
0005432692659	30332	12	5F
0005432692605	30332	13	6D
0005432692665	30332	14	6E
0005432692862	30332	15	6F
0005432692662	30332	16	7A
0005432692651	30332	17	7E
0005433449682	30332	18	8D
0005432692753	30332	19	8E
0005432692577	30332	20	9C
0005432692714	30332	21	9D
0005433449743	30332	22	9F
0005432692661	30332	23	10C
0005432692752	30332	24	10D
0005433449744	30332	25	10E
0005432692698	30332	26	11A
0005432692613	30332	27	11D
0005432692716	30332	28	11E
0005432692685	30332	29	11F
0005432692756	30332	30	12A
0005432692863	30332	31	12C
0005432692584	30332	32	12E
0005433449738	30332	33	12F
0005432692660	30332	34	13D
0005432692612	30332	35	13F
0005432692684	30332	36	14A
0005433449787	30332	37	14E
0005433449724	30332	38	14F
0005433449696	30332	39	15A
0005433449816	30332	40	15D
0005432692777	30332	41	15F
0005433449665	30332	42	16A
0005433449707	30332	43	16C
0005433449737	30332	44	16D
0005432692586	30332	45	17A
0005432692739	30332	46	17C
0005432692606	30332	47	17E
0005432692724	30332	48	17F
0005432692751	30332	49	18D
0005432692583	30332	50	18F
0005433449721	30332	51	19A
0005432692607	30332	52	19E
0005432692640	30332	53	19F
0005432692743	30332	54	20C
0005432692775	30332	55	20E
0005433449652	30332	56	20F
0005432720718	30331	1	1A
0005433722208	30331	2	1C
0005433722204	30331	3	1D
0005433722200	30331	4	2A
0005432720629	30331	5	2C
0005432720658	30331	6	2F
0005433123695	30331	7	3A
0005432720657	30331	8	3D
0005432720635	30331	9	3F
0005432720623	30331	10	4A
0005432720617	30331	11	4F
0005432720643	30331	12	5C
0005432720611	30331	13	5D
0005432720616	30331	14	5F
0005433722201	30331	15	6A
0005432720713	30331	16	6C
0005433722206	30331	17	6D
0005433123654	30331	18	6F
0005432720676	30331	19	7A
0005433123670	30331	20	7C
0005432720652	30331	21	7D
0005432720672	30331	22	7E
0005432720553	30331	23	7F
0005432720535	30331	24	8A
0005432720518	30331	25	8C
0005432720496	30331	26	8E
0005433123725	30331	27	8F
0005432720717	30331	28	9C
0005433123588	30331	29	9D
0005433123707	30331	30	9F
0005433722205	30331	31	10A
0005432720615	30331	32	10C
0005433123636	30331	33	10D
0005433123698	30331	34	10E
0005433123696	30331	35	11A
0005433123724	30331	36	11C
0005432720592	30331	37	11D
0005432720517	30331	38	11E
0005432720719	30331	39	12A
0005432720641	30331	40	12E
0005432720638	30331	41	13A
0005432720495	30331	42	13C
0005433722202	30331	43	13D
0005432720516	30331	44	13E
0005432720613	30331	45	13F
0005432720642	30331	46	14C
0005432720650	30331	47	14E
0005432720604	30331	48	14F
0005432720624	30331	49	15A
0005433123767	30331	50	15C
0005432720612	30331	51	15D
0005432720636	30331	52	15E
0005433123706	30331	53	16A
0005432720534	30331	54	16C
0005433722207	30331	55	16D
0005433123653	30331	56	16F
0005432720603	30331	57	17D
0005432720716	30331	58	17E
0005433123661	30331	59	17F
0005432720673	30331	60	18C
0005433123671	30331	61	18D
0005433123693	30331	62	18F
0005432720549	30331	63	19C
0005433123683	30331	64	19D
0005432720550	30331	65	19E
0005432720552	30331	66	19F
0005432720712	30331	67	20A
0005433722203	30331	68	20C
0005433123697	30331	69	20D
0005432720683	30331	70	20E
0005433525005	1374	1	1A
0005434586549	1374	2	1D
0005433192881	1374	3	1F
0005432927908	1374	4	2A
0005434586538	1374	5	3A
0005434586531	1374	6	2F
0005434586542	1374	7	3F
0005433724792	1374	8	4C
0005433192882	1374	9	4D
0005433724793	1374	10	4E
0005434586529	1374	11	5A
0005434586548	1374	12	5C
0005433192883	1374	13	5D
0005434513573	1374	14	5E
0005433525010	1374	15	5F
0005434586551	1374	16	6A
0005434586540	1374	17	6C
0005433192898	1374	18	6D
0005433192904	1374	19	6E
0005433525013	1374	20	6F
0005434514960	1374	21	7A
0005433192934	1374	22	7C
0005434514961	1374	23	7E
0005434586550	1374	24	7F
0005433192869	1374	25	8A
0005434586526	1374	26	8C
0005434586541	1374	27	8E
0005433192935	1374	28	8F
0005433192923	1374	29	9A
0005434586530	1374	30	9C
0005434586545	1374	31	9E
0005433525006	1374	32	9F
0005434586543	1374	33	10C
0005433192899	1374	34	10D
0005434586534	1374	35	10E
0005433525011	1374	36	10F
0005433192903	1374	37	11C
0005433525004	1374	38	12A
0005434586533	1374	39	12C
0005434586537	1374	40	12E
0005434586532	1374	41	13C
0005434586539	1374	42	13D
0005433724794	1374	43	14C
0005433525008	1374	44	14D
0005434514959	1374	45	14E
0005434513572	1374	46	15C
0005433525012	1374	47	15A
0005433724795	1374	48	15D
0005432270995	1374	49	15E
0005434513571	1374	50	15F
0005433525003	1374	51	16A
0005434586546	1374	52	16C
0005432927907	1374	53	16D
0005432968814	1374	54	16F
0005434586536	1374	55	17A
0005434586527	1374	56	17C
0005433192936	1374	57	17D
0005433525007	1374	58	17F
0005434586547	1374	59	18D
0005433525009	1374	60	18E
0005434586535	1374	61	19A
0005434586544	1374	62	19D
0005432270996	1374	63	19E
0005432968813	1374	64	19F
0005434586528	1374	65	20E
0005433724753	18546	1	1D
0005433724751	18546	2	1F
0005433193004	18546	3	2A
0005433193009	18546	4	2C
0005432927963	18546	5	2F
0005432968832	18546	6	3A
0005433193006	18546	7	3C
0005433524865	18546	8	3D
0005433193002	18546	9	4C
0005433193013	18546	10	4D
0005434586355	18546	11	4E
0005434586359	18546	12	5A
0005434586296	18546	13	5C
0005433524864	18546	14	5D
0005433724754	18546	15	6A
0005433524898	18546	16	7A
0005434514933	18546	17	7C
0005433524883	18546	18	8A
0005434586295	18546	19	8D
0005434586209	18546	20	8E
0005434586400	18546	21	8F
0005434514930	18546	22	9A
0005434586271	18546	23	9D
0005434586367	18546	24	9E
0005432968833	18546	25	9F
0005434586309	18546	26	10A
0005433193011	18546	27	10D
0005434514948	18546	28	10F
0005432927964	18546	29	11D
0005433724731	18546	30	11F
0005433193007	18546	31	12A
0005433193003	18546	32	12D
0005433193010	18546	33	12F
0005433524884	18546	34	13A
0005434586332	18546	35	13C
0005433193012	18546	36	13F
0005434586294	18546	37	14A
0005433193000	18546	38	14F
0005434586311	18546	39	15A
0005434586351	18546	40	15C
0005432927965	18546	41	15D
0005432927960	18546	42	15E
0005434586213	18546	43	15F
0005433193001	18546	44	16A
0005434586214	18546	45	16D
0005434586365	18546	46	16E
0005434514942	18546	47	16F
0005434586270	18546	48	17A
0005434586333	18546	49	17D
0005433524913	18546	50	17E
0005432927962	18546	51	17F
0005434514932	18546	52	18A
0005433193008	18546	53	18C
0005433524899	18546	54	18D
0005433193005	18546	55	18F
0005432927961	18546	56	19A
0005433724752	18546	57	19C
0005434586268	18546	58	19D
0005434586366	18546	59	19E
0005434586293	18546	60	20E
0005434586267	18546	61	20F
0005434344096	11463	1	1A
0005434344092	11463	2	1B
0005434344093	11463	3	1D
0005434344078	11463	4	1C
0005434344076	11463	5	2B
0005434344064	11463	6	2C
0005434142598	11463	7	2D
0005434344070	11463	8	3A
0005434344095	11463	9	3C
0005434344062	11463	10	3D
0005435302135	11463	11	4A
0005434344084	11463	12	4B
0005434344067	11463	13	4C
0005434344077	11463	14	4D
0005434344089	11463	15	5A
0005434344079	11463	16	5B
0005434344088	11463	17	5C
0005435304995	11463	18	5D
0005434344091	11463	19	6A
0005434344063	11463	20	6B
0005434344097	11463	21	6C
0005434344086	11463	22	6D
0005434142599	11463	23	7A
0005434344068	11463	24	7B
0005434344075	11463	25	7C
0005434142597	11463	26	7D
0005434344071	11463	27	18A
0005434344066	11463	28	18B
0005434344090	11463	29	18C
0005434344065	11463	30	18D
0005434344061	11463	31	19A
0005434344069	11463	32	19B
0005434344098	11463	33	19C
0005434344094	11463	34	19D
0005434344080	11463	35	20A
0005434344087	11463	36	20B
0005434344072	11463	37	20C
0005434344083	11463	38	20D
0005434344073	11463	39	21A
0005434142600	11463	40	21B
0005434344082	11463	41	21C
0005434344081	11463	42	21D
0005434142602	11463	43	22A
0005435302134	11463	44	22B
0005434142601	11463	45	22C
0005434344085	11463	46	22D
0005435302133	11463	47	23A
0005434344074	11463	48	23B
0005434343660	29773	1	1A
0005434142547	29773	2	1B
0005434343652	29773	3	1C
0005434343629	29773	4	1D
0005434343755	29773	5	2A
0005434343845	29773	6	2C
0005434343749	29773	7	2D
0005434343952	29773	8	3B
0005435305011	29773	9	3A
0005434343849	29773	10	3C
0005434343848	29773	11	3D
0005435304146	29773	12	4A
0005434343887	29773	13	4C
0005435304147	29773	14	4D
0005434343863	29773	15	5A
0005434343719	29773	16	5B
0005434142565	29773	17	5C
0005434343951	29773	18	5D
0005434343718	29773	19	6A
0005434142572	29773	20	6B
0005434343694	29773	21	6C
0005434343846	29773	22	6D
0005434343677	29773	23	7A
0005434343982	29773	24	7B
0005434343734	29773	25	7C
0005434142561	29773	26	7D
0005435305010	29773	27	18A
0005434343659	29773	28	18B
0005434343704	29773	29	18C
0005434343662	29773	30	18D
0005434343787	29773	31	19A
0005434343800	29773	32	19B
0005434343983	29773	33	19C
0005435304145	29773	34	19D
0005434343870	29773	35	20A
0005434343809	29773	36	20B
0005434343871	29773	37	20C
0005434343738	29773	38	20D
0005434343739	29773	39	21A
0005434343754	29773	40	21B
0005434343788	29773	41	21C
0005434343735	29773	42	21D
0005434343839	29773	43	22A
0005434343818	29773	44	22B
0005434343693	29773	45	22C
0005434343669	29773	46	22D
0005434343864	29773	47	23A
0005434142573	29773	48	23B
0005435824558	1284	1	1C
0005433415462	1284	2	1D
0005433415488	1284	3	2A
0005432284548	1284	4	2D
0005433415550	1284	5	4C
0005433415437	1284	6	5F
0005435824541	1284	7	6B
0005433415461	1284	8	6A
0005435824556	1284	9	6C
0005435824549	1284	10	6E
0005435824552	1284	11	7A
0005435824560	1284	12	6F
0005435824544	1284	13	7C
0005433415521	1284	14	7F
0005433415460	1284	15	8C
0005435824537	1284	16	9A
0005433415491	1284	17	9F
0005435824545	1284	18	9E
0005433415487	1284	19	9D
0005433415551	1284	20	10A
0005435824538	1284	21	10E
0005435824553	1284	22	10F
0005433415510	1284	23	11A
0005435824536	1284	24	11D
0005432284550	1284	25	11C
0005435824562	1284	26	12E
0005433415511	1284	27	12F
0005433415526	1284	28	13E
0005435824557	1284	29	13F
0005433415486	1284	30	14F
0005435824546	1284	31	14E
0005435824542	1284	32	15B
0005435824551	1284	33	15A
0005435824548	1284	34	15D
0005435824543	1284	35	15F
0005433415497	1284	36	15E
0005433415495	1284	37	16A
0005435824550	1284	38	16C
0005435824540	1284	39	16E
0005432284549	1284	40	16F
0005435824561	1284	41	17B
0005435824539	1284	42	17E
0005435824555	1284	43	18A
0005433415476	1284	44	18C
0005435824554	1284	45	18B
0005433415527	1284	46	19A
0005435824547	1284	47	19D
0005435824559	1284	48	19F
0005433415438	1284	49	21C
0005433415453	1284	50	21E
0005435824391	17991	1	1C
0005435824373	17991	2	2A
0005435824344	17991	3	2D
0005435824341	17991	4	2F
0005433415616	17991	5	3D
0005433415619	17991	6	4D
0005435824398	17991	7	5C
0005435824298	17991	8	5A
0005435824292	17991	9	5D
0005435824289	17991	10	6D
0005435824277	17991	11	6B
0005435824328	17991	12	8C
0005435824340	17991	13	9B
0005433415611	17991	14	10A
0005435824291	17991	15	11A
0005433415622	17991	16	10F
0005433415615	17991	17	11B
0005435824374	17991	18	12C
0005433415610	17991	19	13B
0005433415617	17991	20	14B
0005435824399	17991	21	14D
0005435824322	17991	22	14F
0005433415612	17991	23	14E
0005433415618	17991	24	15B
0005433415607	17991	25	15D
0005435824404	17991	26	15F
0005433415608	17991	27	16C
0005433415614	17991	28	16E
0005433415613	17991	29	17F
0005433415606	17991	30	19B
0005433415620	17991	31	19E
0005433415609	17991	32	19C
0005433415621	17991	33	19F
0005435824392	17991	34	20B
0005435824278	17991	35	20C
0005435824343	17991	36	20E
0005435824397	17991	37	21B
0005435824323	17991	38	21D
0005432783648	5643	1	1A
0005435476689	5643	2	1C
0005435242479	5643	3	1D
0005435242436	5643	4	1F
0005435476657	5643	5	2A
0005435242525	5643	6	2C
0005432783645	5643	7	2D
0005432783651	5643	8	2F
0005435242423	5643	9	3A
0005435242566	5643	10	3C
0005435242440	5643	11	3D
0005432783650	5643	12	3F
0005432783625	5643	13	4A
0005435476662	5643	14	4C
0005432783610	5643	15	4D
0005435242503	5643	16	4E
0005432783611	5643	17	4F
0005435242569	5643	18	5A
0005432783663	5643	19	5C
0005432143979	5643	20	5D
0005432783619	5643	21	5E
0005432783634	5643	22	5F
0005432783655	5643	23	6A
0005435476649	5643	24	6C
0005432783656	5643	25	6D
0005435242493	5643	26	6E
0005432783616	5643	27	6F
0005435242531	5643	28	7A
0005432783609	5643	29	7C
0005432783637	5643	30	7D
0005435476669	5643	31	7E
0005435242504	5643	32	7F
0005432783643	5643	33	8A
0005432143976	5643	34	8C
0005432783654	5643	35	8D
0005432783620	5643	36	8E
0005435242519	5643	37	8F
0005432783631	5643	38	9A
0005432783649	5643	39	9C
0005435476656	5643	40	9D
0005432783662	5643	41	9E
0005432783614	5643	42	9F
0005435242532	5643	43	10A
0005435476652	5643	44	10C
0005435476661	5643	45	10D
0005432783639	5643	46	10E
0005432783623	5643	47	10F
0005432783612	5643	48	11A
0005432783627	5643	49	11C
0005432783652	5643	50	11D
0005432143977	5643	51	11E
0005435242482	5643	52	11F
0005432783638	5643	53	12A
0005435242563	5643	54	12C
0005435242435	5643	55	12D
0005432783647	5643	56	12E
0005435242422	5643	57	12F
0005432783660	5643	58	13A
0005432783657	5643	59	13C
0005432783636	5643	60	13D
0005435242570	5643	61	13E
0005435242465	5643	62	13F
0005432783635	5643	63	14A
0005432783653	5643	64	14C
0005435242564	5643	65	14D
0005432783633	5643	66	14E
0005432783664	5643	67	14F
0005432783646	5643	68	15A
0005435476653	5643	69	15C
0005432783640	5643	70	15D
0005435242565	5643	71	15E
0005432783632	5643	72	16A
0005432783613	5643	73	15F
0005432783630	5643	74	16C
0005432783642	5643	75	16D
0005432783641	5643	76	16E
0005432783644	5643	77	16F
0005435242526	5643	78	17A
0005432783621	5643	79	17C
0005432783659	5643	80	17D
0005435476671	5643	81	17E
0005432783624	5643	82	17F
0005435476683	5643	83	18A
0005435476670	5643	84	18C
0005432783626	5643	85	18D
0005435242568	5643	86	18E
0005432143978	5643	87	18F
0005432783628	5643	88	19A
0005432783618	5643	89	19C
0005435242449	5643	90	19D
0005435242518	5643	91	19E
0005432783629	5643	92	19F
0005432783661	5643	93	20A
0005432783617	5643	94	20C
0005432783615	5643	95	20D
0005432783658	5643	96	20E
0005432783622	5643	97	20F
0005432783159	15385	1	1A
0005432783050	15385	2	1C
0005435476735	15385	3	1D
0005435242748	15385	4	1F
0005432783056	15385	5	2A
0005432783127	15385	6	2C
0005435242747	15385	7	2D
0005432782878	15385	8	2F
0005432782932	15385	9	3A
0005432783109	15385	10	3C
0005435242768	15385	11	3D
0005432783209	15385	12	3F
0005435242754	15385	13	4A
0005432783275	15385	14	4C
0005432783181	15385	15	4D
0005432783049	15385	16	4E
0005432783281	15385	17	4F
0005435476733	15385	18	5A
0005432782958	15385	19	5C
0005435242751	15385	20	5D
0005432783280	15385	21	5E
0005432783067	15385	22	5F
0005432783028	15385	23	6A
0005432783140	15385	24	6C
0005432783186	15385	25	6D
0005432783268	15385	26	6E
0005432783210	15385	27	7A
0005432783007	15385	28	7C
0005432782978	15385	29	7D
0005435242745	15385	30	7E
0005432782980	15385	31	7F
0005432782996	15385	32	8C
0005435242750	15385	33	8D
0005432783008	15385	34	8E
0005432783157	15385	35	8F
0005432783058	15385	36	9A
0005435242746	15385	37	9C
0005432783150	15385	38	9D
0005435242752	15385	39	9E
0005432783115	15385	40	9F
0005435242760	15385	41	10A
0005432783180	15385	42	10C
0005432783199	15385	43	10D
0005435242762	15385	44	10E
0005432783267	15385	45	10F
0005435476732	15385	46	11A
0005432783203	15385	47	11C
0005432783030	15385	48	11D
0005435242742	15385	49	11E
0005432783230	15385	50	11F
0005432783000	15385	51	12A
0005432783043	15385	52	12C
0005435476734	15385	53	12D
0005432783158	15385	54	12E
0005432783034	15385	55	12F
0005432783208	15385	56	13A
0005435242766	15385	57	13C
0005435242756	15385	58	13D
0005435242767	15385	59	13E
0005432782999	15385	60	13F
0005432783211	15385	61	14A
0005435242764	15385	62	14C
0005435242769	15385	63	14D
0005432783161	15385	64	14E
0005432783120	15385	65	14F
0005432782979	15385	66	15A
0005432783128	15385	67	15C
0005432782985	15385	68	15D
0005432783148	15385	69	15E
0005435242757	15385	70	15F
0005432783325	15385	71	16A
0005432782933	15385	72	16C
0005432783146	15385	73	16D
0005432783346	15385	74	16E
0005435242743	15385	75	16F
0005432783149	15385	76	17A
0005432783163	15385	77	17C
0005432783147	15385	78	17D
0005435242759	15385	79	17E
0005432783540	15385	80	17F
0005432783377	15385	81	18A
0005435242763	15385	82	18C
0005435242758	15385	83	18D
0005432782935	15385	84	18F
0005435242761	15385	85	18E
0005435242749	15385	86	19A
0005432783029	15385	87	19C
0005435242753	15385	88	19D
0005432783020	15385	89	19E
0005432783086	15385	90	19F
0005432783541	15385	91	20A
0005435242765	15385	92	20C
0005435242744	15385	93	20D
0005432783085	15385	94	20E
0005435242755	15385	95	20F
0005435850797	4390	1	1B
0005432848273	4390	2	1D
0005432848274	4390	3	2B
0005435850811	4390	4	2C
0005432848277	4390	5	3C
0005432848265	4390	6	3D
0005432848267	4390	7	4C
0005432848271	4390	8	4D
0005432848275	4390	9	5B
0005432848266	4390	10	5C
0005432848270	4390	11	5D
0005432848276	4390	12	6A
0005434462783	4390	13	6B
0005432848264	4390	14	7A
0005432848272	4390	15	7B
0005432848268	4390	16	7C
0005435850801	4390	17	7D
0005435850800	4390	18	18B
0005435850836	4390	19	18C
0005434463922	4390	20	19A
0005434463923	4390	21	19D
0005435850799	4390	22	21A
0005434462784	4390	23	21D
0005435850826	4390	24	22A
0005435850839	4390	25	22C
0005435850806	4390	26	22D
0005432848269	4390	27	23B
0005432848133	28869	1	1A
0005434463908	28869	2	2A
0005435850884	28869	3	3A
0005432848122	28869	4	3B
0005435850882	28869	5	5A
0005432848121	28869	6	5C
0005432848171	28869	7	6B
0005432848132	28869	8	18B
0005435850887	28869	9	19A
0005435850886	28869	10	19B
0005435850883	28869	11	19D
0005432848166	28869	12	20C
0005435850881	28869	13	20D
0005432848143	28869	14	22C
0005435850885	28869	15	23A
0005434443660	6342	1	1A
0005433496888	6342	2	1C
0005434925728	6342	3	1F
0005434925720	6342	4	2A
0005434443661	6342	5	2C
0005433496898	6342	6	2D
0005434925736	6342	7	2F
0005434925740	6342	8	3A
0005434925723	6342	9	3D
0005433496871	6342	10	3F
0005433496884	6342	11	4A
0005433496867	6342	12	4C
0005434925745	6342	13	4D
0005433496877	6342	14	4E
0005434925734	6342	15	4F
0005432075220	6342	16	5C
0005433496881	6342	17	5D
0005433496891	6342	18	5E
0005433496866	6342	19	5F
0005434925724	6342	20	6A
0005434925748	6342	21	6E
0005433496893	6342	22	6F
0005434925733	6342	23	7A
0005434925739	6342	24	7C
0005432075219	6342	25	7E
0005434925746	6342	26	7F
0005434925732	6342	27	8A
0005433496896	6342	28	8C
0005433496885	6342	29	8D
0005432075221	6342	30	8E
0005434443670	6342	31	8F
0005434925721	6342	32	9A
0005433496894	6342	33	9C
0005433496879	6342	34	9D
0005434925731	6342	35	9E
0005434925737	6342	36	9F
0005434925729	6342	37	10A
0005433496876	6342	38	10C
0005433496880	6342	39	10D
0005434443669	6342	40	10E
0005433496889	6342	41	10F
0005434925725	6342	42	11A
0005434925747	6342	43	11C
0005433496874	6342	44	11D
0005433496872	6342	45	11E
0005434443665	6342	46	11F
0005433496895	6342	47	12A
0005434925726	6342	48	12C
0005434443657	6342	49	12D
0005433496869	6342	50	12E
0005433496887	6342	51	12F
0005434443667	6342	52	13A
0005434443662	6342	53	13C
0005434925719	6342	54	13E
0005434443664	6342	55	13F
0005434925738	6342	56	14C
0005434925717	6342	57	14E
0005433496897	6342	58	14D
0005433496868	6342	59	14F
0005434925744	6342	60	15A
0005433496873	6342	61	15D
0005434443668	6342	62	15E
0005434925735	6342	63	15F
0005434443659	6342	64	16A
0005434443666	6342	65	16D
0005433496886	6342	66	16F
0005433496878	6342	67	17A
0005433496870	6342	68	17C
0005434925722	6342	69	17D
0005433496892	6342	70	17E
0005434925749	6342	71	17F
0005433496890	6342	72	18A
0005434443656	6342	73	18C
0005434925727	6342	74	18D
0005434925742	6342	75	18E
0005434925730	6342	76	18F
0005434925741	6342	77	19A
0005433496883	6342	78	19C
0005434443663	6342	79	19D
0005433496882	6342	80	19F
0005434925718	6342	81	20A
0005434925743	6342	82	20C
0005434443655	6342	83	20D
0005434443658	6342	84	20E
0005433496875	6342	85	20F
0005433496549	20389	1	1A
0005433496612	20389	2	1C
0005434925444	20389	3	1F
0005434925248	20389	4	2A
0005433496709	20389	5	2C
0005433496729	20389	6	2D
0005434443542	20389	7	2F
0005434925300	20389	8	3A
0005434925467	20389	9	3C
0005433496548	20389	10	3F
0005433496577	20389	11	4C
0005434443483	20389	12	4D
0005434925371	20389	13	4E
0005434925421	20389	14	4F
0005434925383	20389	15	5A
0005433496779	20389	16	5C
0005433496583	20389	17	5D
0005433496701	20389	18	5E
0005434925391	20389	19	5F
0005433496731	20389	20	6A
0005434925402	20389	21	6E
0005434925449	20389	22	6F
0005433496691	20389	23	7A
0005434443502	20389	24	7C
0005434443524	20389	25	7F
0005433496609	20389	26	8A
0005434443496	20389	27	8C
0005434925423	20389	28	8D
0005434925388	20389	29	8E
0005433496642	20389	30	8F
0005434443484	20389	31	9A
0005434925466	20389	32	9F
0005433496735	20389	33	9E
0005434925433	20389	34	10A
0005434443481	20389	35	10C
0005434443567	20389	36	10D
0005433496700	20389	37	10E
0005433496595	20389	38	10F
0005434443510	20389	39	11A
0005434925418	20389	40	11C
0005433496611	20389	41	11D
0005434443562	20389	42	11E
0005433496730	20389	43	12A
0005434443521	20389	44	12D
0005433496649	20389	45	12E
0005433496756	20389	46	12F
0005433496576	20389	47	13A
0005433496792	20389	48	13D
0005434443568	20389	49	13E
0005434925370	20389	50	13F
0005434925461	20389	51	14A
0005433496575	20389	52	14C
0005434925264	20389	53	14D
0005434925403	20389	54	14E
0005434925451	20389	55	14F
0005434925452	20389	56	15C
0005434925293	20389	57	15D
0005433496643	20389	58	15E
0005434925462	20389	59	15F
0005433496619	20389	60	16A
0005434925369	20389	61	16D
0005433496710	20389	62	16E
0005433496620	20389	63	16F
0005434925273	20389	64	17A
0005434925453	20389	65	17C
0005434925455	20389	66	17D
0005433496530	20389	67	17E
0005433496832	20389	68	17F
0005433496648	20389	69	18A
0005433496610	20389	70	18E
0005433496656	20389	71	18F
0005434443574	20389	72	19C
0005433496596	20389	73	19E
0005434925443	20389	74	19F
0005434925424	20389	75	20A
0005434925344	20389	76	20D
0005434925299	20389	77	20E
0005434925425	20389	78	20F
0005432783418	12189	1	1A
0005432783333	12189	2	1C
0005432783272	12189	3	1D
0005435242795	12189	4	2A
0005432783279	12189	5	2C
0005432783274	12189	6	2D
0005432783078	12189	7	2F
0005432783144	12189	8	3A
0005435242773	12189	9	3C
0005435242787	12189	10	3D
0005432783114	12189	11	3F
0005435242781	12189	12	4A
0005432783111	12189	13	4C
0005432783123	12189	14	4D
0005432783250	12189	15	4E
0005432783145	12189	16	4F
0005435242780	12189	17	5A
0005432783191	12189	18	5C
0005432783382	12189	19	5D
0005432783343	12189	20	5E
0005435242789	12189	21	5F
0005435242784	12189	22	6A
0005432783342	12189	23	6D
0005432783341	12189	24	6C
0005432783334	12189	25	6E
0005432782971	12189	26	6F
0005435242785	12189	27	7A
0005435242775	12189	28	7C
0005435242796	12189	29	7D
0005435242778	12189	30	7E
0005432783380	12189	31	8A
0005432783215	12189	32	8C
0005432783340	12189	33	8E
0005432783321	12189	34	8F
0005432783204	12189	35	9A
0005432783012	12189	36	9D
0005435242771	12189	37	9E
0005435242783	12189	38	9F
0005432783355	12189	39	10C
0005432783433	12189	40	10D
0005435242786	12189	41	10E
0005432783236	12189	42	10F
0005435242792	12189	43	11C
0005435242788	12189	44	11E
0005435242770	12189	45	12C
0005432783287	12189	46	12E
0005432783372	12189	47	12F
0005432783205	12189	48	13A
0005435242790	12189	49	13D
0005435242779	12189	50	13E
0005432783101	12189	51	14C
0005432783286	12189	52	14D
0005435242774	12189	53	14E
0005432783100	12189	54	14F
0005432783124	12189	55	15A
0005432783076	12189	56	15C
0005432783027	12189	57	15D
0005432783383	12189	58	15E
0005432783235	12189	59	15F
0005432783278	12189	60	16A
0005435242794	12189	61	16C
0005432783206	12189	62	16D
0005432783258	12189	63	17A
0005432783216	12189	64	17C
0005432783179	12189	65	17E
0005435242777	12189	66	17F
0005432783266	12189	67	18C
0005432783122	12189	68	18D
0005435242791	12189	69	18E
0005435242776	12189	70	18F
0005432783113	12189	71	19A
0005435242772	12189	72	19C
0005432783381	12189	73	19D
0005432783273	12189	74	19E
0005435242793	12189	75	19F
0005435242782	12189	76	20C
0005432783075	12189	77	20D
0005432783021	12189	78	20E
0005432783088	12189	79	20F
0005432783557	15418	1	1A
0005435242502	15418	2	1C
0005432783571	15418	3	1D
0005432783598	15418	4	1F
0005432783556	15418	5	2A
0005432783595	15418	6	2C
0005432783577	15418	7	2D
0005435242447	15418	8	3A
0005432783574	15418	9	3C
0005432783563	15418	10	3D
0005435242528	15418	11	3F
0005432783590	15418	12	4A
0005432783599	15418	13	4C
0005432783604	15418	14	4D
0005432783591	15418	15	4E
0005432783575	15418	16	4F
0005432783581	15418	17	5A
0005435242537	15418	18	5C
0005435242473	15418	19	5D
0005432783565	15418	20	5E
0005432783603	15418	21	5F
0005435242515	15418	22	6A
0005432783584	15418	23	6C
0005435242574	15418	24	6D
0005432783570	15418	25	6E
0005435242461	15418	26	6F
0005432783607	15418	27	7A
0005435242560	15418	28	7C
0005435242460	15418	29	7D
0005432783597	15418	30	7F
0005432783555	15418	31	8A
0005432783554	15418	32	8C
0005432783586	15418	33	8E
0005432783606	15418	34	8F
0005432783560	15418	35	9C
0005432783601	15418	36	9D
0005432783605	15418	37	9E
0005432783569	15418	38	9F
0005432783559	15418	39	10C
0005435242498	15418	40	11C
0005435242463	15418	41	11D
0005432783573	15418	42	11E
0005435242491	15418	43	11F
0005435242625	15418	44	12A
0005432783564	15418	45	12C
0005432783587	15418	46	12E
0005432783592	15418	47	13A
0005432783583	15418	48	13C
0005432783588	15418	49	13E
0005432783567	15418	50	14A
0005432783593	15418	51	14C
0005432783562	15418	52	14D
0005432783602	15418	53	14E
0005432783558	15418	54	14F
0005435242562	15418	55	15A
0005432783594	15418	56	15C
0005432783578	15418	57	15D
0005435242439	15418	58	15E
0005432783585	15418	59	15F
0005435242492	15418	60	16A
0005432783600	15418	61	16C
0005435242516	15418	62	16E
0005432783582	15418	63	16F
0005432783580	15418	64	17C
0005435242427	15418	65	17D
0005432783579	15418	66	17F
0005435242417	15418	67	18C
0005432783566	15418	68	18D
0005432783561	15418	69	18E
0005432783589	15418	70	18F
0005432783608	15418	71	19A
0005432783568	15418	72	19C
0005435242538	15418	73	19D
0005435242474	15418	74	19E
0005435242514	15418	75	19F
0005432783576	15418	76	20A
0005432783596	15418	77	20C
0005432783572	15418	78	20D
0005435242561	15418	79	20E
0005435242462	15418	80	20F
0005434877094	10070	1	1A
0005434876990	10070	2	1F
0005434877212	10070	3	1D
0005434910102	10070	4	1C
0005434877286	10070	5	2A
0005434877391	10070	6	2D
0005434877245	10070	7	3A
0005434877116	10070	8	2F
0005434877096	10070	9	3D
0005434877603	10070	10	3C
0005434877296	10070	11	4A
0005434876919	10070	12	3F
0005434877233	10070	13	4C
0005434877022	10070	14	4F
0005434877236	10070	15	4D
0005434877051	10070	16	5D
0005434877157	10070	17	5C
0005434877047	10070	18	5A
0005434876906	10070	19	5F
0005434877270	10070	20	6B
0005434876882	10070	21	6A
0005434877121	10070	22	6C
0005434877290	10070	23	6E
0005434877655	10070	24	6D
0005434877175	10070	25	7A
0005434877091	10070	26	6F
0005434877427	10070	27	7C
0005434877439	10070	28	7B
0005434877176	10070	29	7D
0005434877225	10070	30	7F
0005434877295	10070	31	7E
0005434877406	10070	32	8B
0005434876832	10070	33	8A
0005434877291	10070	34	8D
0005434876808	10070	35	8C
0005434877168	10070	36	8F
0005434910103	10070	37	8E
0005434876795	10070	38	9B
0005434877160	10070	39	9A
0005434877008	10070	40	9C
0005434876871	10070	41	9E
0005434877321	10070	42	9D
0005434877267	10070	43	10A
0005434876770	10070	44	10C
0005434877106	10070	45	10B
0005434876859	10070	46	10E
0005434877161	10070	47	10D
0005434876988	10070	48	11A
0005434877062	10070	49	10F
0005434877390	10070	50	11B
0005434876848	10070	51	11E
0005434876881	10070	52	11D
0005434877266	10070	53	11C
0005434876847	10070	54	12B
0005434877320	10070	55	12A
0005435913929	10070	56	12D
0005434877063	10070	57	12C
0005434877288	10070	58	12F
0005434876874	10070	59	12E
0005434876833	10070	60	13A
0005434877677	10070	61	13C
0005434877120	10070	62	13B
0005434877174	10070	63	13E
0005434877467	10070	64	13D
0005434876950	10070	65	14A
0005434876989	10070	66	13F
0005434877424	10070	67	14B
0005434877037	10070	68	14D
0005434877463	10070	69	14C
0005434877090	10070	70	14F
0005434877311	10070	71	14E
0005434877334	10070	72	15A
0005434876945	10070	73	15D
0005434877264	10070	74	15C
0005434758871	10070	75	15B
0005434877088	10070	76	15E
0005434910104	10070	77	15F
0005434877099	10070	78	16C
0005434877415	10070	79	16B
0005434877111	10070	80	16D
0005434876831	10070	81	16F
0005434758869	10070	82	17B
0005434758870	10070	83	17A
0005434877414	10070	84	17D
0005435913928	10070	85	17C
0005434877038	10070	86	17F
0005434876849	10070	87	17E
0005434876880	10070	88	18B
0005434876771	10070	89	18A
0005434876982	10070	90	18C
0005434877374	10070	91	18E
0005434876858	10070	92	18D
0005434877107	10070	93	19A
0005434877110	10070	94	18F
0005434877009	10070	95	19C
0005434877095	10070	96	19B
0005434877100	10070	97	19D
0005434877200	10070	98	19F
0005434877615	10070	99	19E
0005434877215	10070	100	20B
0005434877285	10070	101	20A
0005434876905	10070	102	20D
0005434877271	10070	103	20C
0005434877226	10070	104	20F
0005434877287	10070	105	20E
0005434877404	10070	106	21A
0005434877071	10070	107	21C
0005434877105	10070	108	21B
0005434877234	10070	109	21E
0005434876902	10070	110	21D
0005434877214	10070	111	21F
0005434878007	14641	1	1A
0005434877942	14641	2	1F
0005434910090	14641	3	1D
0005434877996	14641	4	1C
0005434878000	14641	5	2A
0005434877982	14641	6	2D
0005435913862	14641	7	2C
0005434878005	14641	8	3C
0005435913873	14641	9	3A
0005434877962	14641	10	2F
0005434877912	14641	11	3D
0005434758887	14641	12	4A
0005434877955	14641	13	3F
0005435913884	14641	14	4C
0005434877997	14641	15	5A
0005434877972	14641	16	4F
0005434877984	14641	17	4D
0005434877931	14641	18	5C
0005434878001	14641	19	5F
0005434877930	14641	20	5D
0005434877968	14641	21	6B
0005434877943	14641	22	6A
0005434877925	14641	23	6C
0005434877995	14641	24	6E
0005434877914	14641	25	6D
0005434877988	14641	26	7A
0005434877935	14641	27	6F
0005434877922	14641	28	7C
0005434877969	14641	29	7B
0005434877957	14641	30	7E
0005434877963	14641	31	7D
0005434877966	14641	32	8A
0005434877975	14641	33	8B
0005434878003	14641	34	8E
0005435913859	14641	35	8D
0005434877924	14641	36	8C
0005434910076	14641	37	9A
0005434877998	14641	38	8F
0005434877999	14641	39	9B
0005434877944	14641	40	9D
0005434877956	14641	41	9C
0005434877952	14641	42	9F
0005434877976	14641	43	9E
0005434877954	14641	44	10A
0005434877938	14641	45	10C
0005434877932	14641	46	10B
0005434877964	14641	47	10E
0005434877933	14641	48	10D
0005434877992	14641	49	11A
0005434877970	14641	50	10F
0005434878002	14641	51	11C
0005435913869	14641	52	11B
0005434877971	14641	53	11D
0005434877911	14641	54	11F
0005435913879	14641	55	11E
0005434877927	14641	56	12A
0005434878004	14641	57	12D
0005434877989	14641	58	12C
0005435913860	14641	59	12B
0005434877917	14641	60	12F
0005434877965	14641	61	12E
0005434877946	14641	62	13A
0005434877947	14641	63	13C
0005434877916	14641	64	13B
0005434877960	14641	65	13E
0005434758886	14641	66	13D
0005434877994	14641	67	13F
0005434878006	14641	68	14B
0005434877973	14641	69	14A
0005434877936	14641	70	14D
0005434877977	14641	71	14C
0005434877978	14641	72	14F
0005435913883	14641	73	14E
0005434877991	14641	74	15B
0005434877961	14641	75	15A
0005435913861	14641	76	15D
0005434877990	14641	77	15C
0005434877958	14641	78	15F
0005434877950	14641	79	15E
0005434877921	14641	80	16A
0005434877945	14641	81	16C
0005434877918	14641	82	16B
0005434877967	14641	83	16D
0005434758885	14641	84	17A
0005434877980	14641	85	16F
0005434877928	14641	86	16E
0005434877987	14641	87	17C
0005434877974	14641	88	17B
0005434877951	14641	89	17D
0005434877981	14641	90	18A
0005434877949	14641	91	17F
0005435913876	14641	92	18D
0005434877979	14641	93	18C
0005434877919	14641	94	18B
0005434877915	14641	95	18E
0005434877986	14641	96	19A
0005434877926	14641	97	18F
0005434877920	14641	98	19C
0005434877937	14641	99	19B
0005434877953	14641	100	19E
0005434877940	14641	101	19D
0005434877959	14641	102	20A
0005434877913	14641	103	19F
0005434877923	14641	104	20B
0005435913882	14641	105	20C
0005434877929	14641	106	20E
0005434877934	14641	107	21B
0005434877993	14641	108	21A
0005434877983	14641	109	20F
0005434877939	14641	110	21C
0005434877985	14641	111	21E
0005434877948	14641	112	21D
0005434877941	14641	113	21F
0005434251843	9253	1	1B
0005434251872	9253	2	1C
0005435660104	9253	3	1D
0005435660102	9253	4	2A
0005434251813	9253	5	2C
0005435660103	9253	6	2D
0005435660105	9253	7	3A
0005434251841	9253	8	3C
0005434251818	9253	9	4C
0005435660110	9253	10	4D
0005434251848	9253	11	6C
0005435660101	9253	12	6D
0005435660107	9253	13	7A
0005435660106	9253	14	7D
0005434251881	9253	15	18A
0005435660108	9253	16	18B
0005434251800	9253	17	18C
0005434251801	9253	18	19A
0005435660099	9253	19	19B
0005435660109	9253	20	20A
0005434251871	9253	21	20C
0005435660100	9253	22	22A
0005434251857	9253	23	22C
0005435660098	9253	24	22D
0005434251870	9253	25	23B
0005435660012	24630	1	1C
0005434251934	24630	2	1D
0005434251933	24630	3	2A
0005435659970	24630	4	2B
0005435660006	24630	5	2C
0005434251935	24630	6	3A
0005434251932	24630	7	3D
0005435660021	24630	8	4A
0005435659963	24630	9	4B
0005435660050	24630	10	5A
0005435660037	24630	11	5B
0005435660014	24630	12	5C
0005435660020	24630	13	6B
0005434251939	24630	14	6C
0005434251937	24630	15	7A
0005435659989	24630	16	7B
0005435659964	24630	17	7D
0005435659988	24630	18	18A
0005435660051	24630	19	18B
0005434251940	24630	20	18C
0005434251941	24630	21	20B
0005435659996	24630	22	20C
0005435660019	24630	23	21A
0005434251938	24630	24	21C
0005435660013	24630	25	22A
0005435659974	24630	26	22C
0005435660015	24630	27	23A
0005434251936	24630	28	23B
0005433680408	2807	1	1A
0005432966605	2807	2	1C
0005432966694	2807	3	1D
0005432966675	2807	4	1F
0005432222769	2807	5	2A
0005433680412	2807	6	2D
0005433680424	2807	7	2F
0005432966696	2807	8	3A
0005432966539	2807	9	3C
0005433684413	2807	10	3D
0005433680413	2807	11	3F
0005432966507	2807	12	4A
0005433680393	2807	13	4C
0005432966663	2807	14	4D
0005433680422	2807	15	4E
0005433680436	2807	16	4F
0005433680420	2807	17	5A
0005433680441	2807	18	5C
0005432966701	2807	19	5D
0005433680431	2807	20	5F
0005433680394	2807	21	6A
0005432966670	2807	22	6C
0005432966588	2807	23	6D
0005433680417	2807	24	6E
0005432222765	2807	25	6F
0005432222766	2807	26	7A
0005432966591	2807	27	7C
0005433680427	2807	28	7D
0005432966668	2807	29	7E
0005432222767	2807	30	7F
0005433680438	2807	31	8A
0005433680428	2807	32	8C
0005432966679	2807	33	8D
0005433680429	2807	34	8E
0005432966695	2807	35	8F
0005432966657	2807	36	9A
0005433680405	2807	37	9C
0005432222768	2807	38	9D
0005432966660	2807	39	9E
0005432966677	2807	40	9F
0005432966607	2807	41	10D
0005433680399	2807	42	10E
0005433680423	2807	43	10F
0005433680433	2807	44	11A
0005432966554	2807	45	11C
0005433680439	2807	46	11D
0005433680416	2807	47	11E
0005432966642	2807	48	11F
0005433680418	2807	49	12A
0005433680409	2807	50	12C
0005433680421	2807	51	12D
0005433680419	2807	52	12E
0005433680411	2807	53	12F
0005433680437	2807	54	13A
0005433680398	2807	55	13C
0005432966658	2807	56	13D
0005433680396	2807	57	13E
0005433680432	2807	58	13F
0005433680415	2807	59	14A
0005433680403	2807	60	14C
0005432966693	2807	61	14E
0005433680397	2807	62	14F
0005433680426	2807	63	15A
0005432966664	2807	64	15C
0005433680435	2807	65	15D
0005432966659	2807	66	15E
0005433680395	2807	67	15F
0005433680434	2807	68	16A
0005433680410	2807	69	16C
0005433680401	2807	70	16D
0005432966529	2807	71	16E
0005432966669	2807	72	16F
0005432966645	2807	73	17C
0005432966574	2807	74	17D
0005432966700	2807	75	17E
0005433680404	2807	76	17F
0005432966582	2807	77	18A
0005433680402	2807	78	18C
0005433680407	2807	79	18D
0005432966581	2807	80	18E
0005432966540	2807	81	18F
0005433680414	2807	82	19A
0005432966678	2807	83	19C
0005433680400	2807	84	19D
0005432966702	2807	85	19E
0005432966768	2807	86	19F
0005433680430	2807	87	20A
0005433680440	2807	88	20C
0005433680425	2807	89	20D
0005433680406	2807	90	20E
0005433680010	29149	1	1A
0005432966855	29149	2	1C
0005433680051	29149	3	1F
0005432966845	29149	4	2A
0005433687680	29149	5	2C
0005432966850	29149	6	3A
0005432966861	29149	7	3C
0005432966852	29149	8	3D
0005433679996	29149	9	4A
0005433679968	29149	10	4C
0005433680021	29149	11	4D
0005432966869	29149	12	4E
0005432966868	29149	13	4F
0005432966860	29149	14	5A
0005433679954	29149	15	5C
0005432966859	29149	16	5D
0005433679997	29149	17	5E
0005432966867	29149	18	5F
0005433680131	29149	19	6A
0005433680029	29149	20	6D
0005432966848	29149	21	6E
0005432005204	29149	22	7D
0005433680064	29149	23	7E
0005433680121	29149	24	8A
0005433680145	29149	25	8C
0005433680087	29149	26	8D
0005433680030	29149	27	8E
0005432966849	29149	28	8F
0005432966853	29149	29	9A
0005433684391	29149	30	9C
0005432966865	29149	31	9D
0005432005203	29149	32	9E
0005433679951	29149	33	9F
0005433680123	29149	34	10C
0005432966846	29149	35	10D
0005433679964	29149	36	10E
0005433679999	29149	37	10F
0005433680050	29149	38	11A
0005433680022	29149	39	11C
0005432005206	29149	40	11D
0005433680012	29149	41	11E
0005433679994	29149	42	11F
0005433680086	29149	43	12A
0005433679948	29149	44	12C
0005432966851	29149	45	12D
0005433680147	29149	46	12E
0005433680111	29149	47	12F
0005433680260	29149	48	13A
0005433680096	29149	49	13C
0005433680009	29149	50	13D
0005433679972	29149	51	13E
0005433680130	29149	52	13F
0005433680097	29149	53	14A
0005433680168	29149	54	14C
0005433680218	29149	55	14D
0005433680144	29149	56	14E
0005433680190	29149	57	14F
0005433679995	29149	58	15A
0005432966870	29149	59	15C
0005433679947	29149	60	15D
0005433680122	29149	61	15E
0005433690906	29149	62	15F
0005432966847	29149	63	16A
0005433679971	29149	64	16C
0005433690903	29149	65	16D
0005432966866	29149	66	16E
0005433680167	29149	67	16F
0005432005205	29149	68	17A
0005433680112	29149	69	17C
0005432966864	29149	70	17D
0005433680011	29149	71	17E
0005433680194	29149	72	18A
0005433680124	29149	73	18C
0005433687688	29149	74	18D
0005433679910	29149	75	18E
0005433679998	29149	76	18F
0005432966856	29149	77	19A
0005432966858	29149	78	19C
0005433680201	29149	79	19D
0005432966863	29149	80	19E
0005433680184	29149	81	20A
0005432966862	29149	82	20C
0005432966854	29149	83	20D
0005432966857	29149	84	20F
0005433614362	9295	1	1A
0005433614379	9295	2	2A
0005433614411	9295	3	1F
0005433614427	9295	4	2C
0005433614430	9295	5	2D
0005434153523	9295	6	3A
0005433614403	9295	7	2F
0005433614361	9295	8	3C
0005433633680	9295	9	3F
0005433614423	9295	10	3D
0005433614425	9295	11	4A
0005433614409	9295	12	4C
0005433614408	9295	13	4F
0005433614413	9295	14	4D
0005434272165	9295	15	5A
0005433633679	9295	16	5C
0005433614399	9295	17	5D
0005433614366	9295	18	6A
0005434152756	9295	19	5F
0005433633677	9295	20	6C
0005433633672	9295	21	6D
0005432756836	9295	22	7A
0005434163501	9295	23	6F
0005433633669	9295	24	7C
0005434163460	9295	25	7F
0005433633675	9295	26	7D
0005433633701	9295	27	8A
0005434163531	9295	28	8B
0005433614378	9295	29	8D
0005433577759	9295	30	8C
0005433614400	9295	31	9A
0005433614432	9295	32	8F
0005433577761	9295	33	9B
0005433614394	9295	34	9C
0005433614429	9295	35	9E
0005433614404	9295	36	9D
0005433614415	9295	37	10A
0005433633700	9295	38	9F
0005433614407	9295	39	10B
0005433614375	9295	40	10D
0005433614368	9295	41	10C
0005433633678	9295	42	10E
0005434272175	9295	43	11A
0005433614414	9295	44	11C
0005433614385	9295	45	11B
0005433614386	9295	46	11D
0005434272174	9295	47	11F
0005433633686	9295	48	11E
0005433614380	9295	49	12A
0005434152764	9295	50	12C
0005433577764	9295	51	12E
0005433633667	9295	52	12D
0005433614422	9295	53	12F
0005433633683	9295	54	13A
0005433633699	9295	55	13C
0005433633694	9295	56	13B
0005433633695	9295	57	13D
0005433633689	9295	58	13F
0005433614391	9295	59	13E
0005433633696	9295	60	14A
0005433614424	9295	61	14B
0005433614384	9295	62	14D
0005433614401	9295	63	14C
0005432756838	9295	64	14F
0005433614360	9295	65	15A
0005433614398	9295	66	15C
0005433577762	9295	67	15D
0005433614359	9295	68	16A
0005434163458	9295	69	15F
0005433614433	9295	70	16C
0005433614383	9295	71	16B
0005433614393	9295	72	16D
0005433614406	9295	73	16F
0005433614390	9295	74	16E
0005433633685	9295	75	17B
0005433633671	9295	76	17A
0005433633668	9295	77	17C
0005432756837	9295	78	17E
0005433614363	9295	79	17D
0005433614374	9295	80	17F
0005433614381	9295	81	18A
0005433633687	9295	82	18B
0005433633692	9295	83	18D
0005433614412	9295	84	18C
0005433614392	9295	85	18E
0005433614410	9295	86	18F
0005433614417	9295	87	19C
0005433577767	9295	88	19B
0005433577756	9295	89	19D
0005433577758	9295	90	19E
0005432755064	9295	91	20B
0005433577766	9295	92	20A
0005433614370	9295	93	20C
0005433633670	9295	94	20E
0005433614426	9295	95	20D
0005433614402	9295	96	20F
0005432755065	9295	97	21A
0005434163500	9295	98	21B
0005433633674	9295	99	21C
0005433633688	9295	100	22A
0005434152763	9295	101	21F
0005433614387	9295	102	22B
0005433614365	9295	103	22C
0005433614372	9295	104	22E
0005433614421	9295	105	22D
0005434163535	9295	106	22F
0005433614405	9295	107	23B
0005433614419	9295	108	23A
0005434163502	9295	109	23D
0005433614382	9295	110	23C
0005433614420	9295	111	23E
0005432756835	9295	112	24A
0005433614395	9295	113	23F
0005433614396	9295	114	24B
0005433614369	9295	115	24D
0005433633697	9295	116	24C
0005433633673	9295	117	24E
0005433614397	9295	118	24F
0005433633681	9295	119	25A
0005434163522	9295	120	25B
0005434152757	9295	121	25D
0005433633690	9295	122	25C
0005433633691	9295	123	25E
0005433614364	9295	124	26A
0005433614373	9295	125	25F
0005433633684	9295	126	26B
0005433577757	9295	127	26D
0005433614389	9295	128	26C
0005433633698	9295	129	26E
0005433633693	9295	130	26F
0005433614418	9295	131	27B
0005433577763	9295	132	27A
0005433614371	9295	133	27C
0005433577768	9295	134	27D
0005434163546	9295	135	27E
0005433614367	9295	136	28A
0005433614428	9295	137	27F
0005434153516	9295	138	28C
0005433614416	9295	139	28B
0005434163474	9295	140	28E
0005434163525	9295	141	28D
0005433614377	9295	142	28F
0005433633682	9295	143	29B
0005433577760	9295	144	29A
0005434152767	9295	145	29C
0005433614388	9295	146	29D
0005434163495	9295	147	29E
0005434153519	9295	148	29F
0005433577765	9295	149	30B
0005434152766	9295	150	30A
0005432756839	9295	151	30C
0005433614431	9295	152	30E
0005434272172	9295	153	31A
0005433633676	9295	154	31D
0005434163545	9295	155	31C
0005433614376	9295	156	31F
0005432751475	25234	1	1C
0005433633345	25234	2	1A
0005433614024	25234	3	1D
0005433613842	25234	4	2A
0005432751480	25234	5	2C
0005433577661	25234	6	2F
0005433633287	25234	7	3C
0005433613911	25234	8	3F
0005433613583	25234	9	4A
0005433633253	25234	10	4C
0005433613838	25234	11	4F
0005433613612	25234	12	4D
0005432755017	25234	13	5A
0005432755016	25234	14	5C
0005433577636	25234	15	5D
0005433613844	25234	16	6A
0005432751474	25234	17	6C
0005433613802	25234	18	6F
0005433613811	25234	19	6D
0005433613927	25234	20	7A
0005432751476	25234	21	7C
0005433613867	25234	22	7D
0005433613739	25234	23	8A
0005433613977	25234	24	7F
0005433613675	25234	25	8B
0005433633474	25234	26	8C
0005433613928	25234	27	8E
0005433633252	25234	28	8F
0005433613554	25234	29	9A
0005433613761	25234	30	9C
0005433633452	25234	31	9B
0005433633357	25234	32	9D
0005433633301	25234	33	9F
0005433613436	25234	34	10A
0005433633288	25234	35	10B
0005433613478	25234	36	10C
0005433613963	25234	37	10E
0005433613745	25234	38	10D
0005433614025	25234	39	11A
0005433633291	25234	40	10F
0005433613729	25234	41	11B
0005433633479	25234	42	11C
0005433633313	25234	43	11E
0005433633218	25234	44	11D
0005433613600	25234	45	11F
0005433613944	25234	46	12A
0005433633270	25234	47	12C
0005432751472	25234	48	12B
0005433577620	25234	49	12F
0005433577628	25234	50	12E
0005433613631	25234	51	13A
0005433613935	25234	52	13C
0005433633415	25234	53	13B
0005433613812	25234	54	13E
0005433613934	25234	55	13D
0005433613544	25234	56	14A
0005433613805	25234	57	14B
0005433633473	25234	58	14C
0005432751493	25234	59	14E
0005433613728	25234	60	14D
0005433613969	25234	61	14F
0005433613785	25234	62	15B
0005433613571	25234	63	15A
0005433577675	25234	64	15E
0005433613589	25234	65	16A
0005433613758	25234	66	15F
0005433633347	25234	67	16D
0005433613764	25234	68	16C
0005433613661	25234	69	16F
0005433613978	25234	70	16E
0005433613813	25234	71	17B
0005432751471	25234	72	17C
0005432751479	25234	73	17E
0005433613801	25234	74	17D
0005433613870	25234	75	17F
0005432751470	25234	76	18A
0005433614020	25234	77	18C
0005433577634	25234	78	18B
0005433577676	25234	79	18E
0005433633510	25234	80	18D
0005432751482	25234	81	18F
0005432755030	25234	82	19B
0005433613845	25234	83	19D
0005433613837	25234	84	19C
0005433613810	25234	85	19E
0005433633324	25234	86	20B
0005433577666	25234	87	20A
0005433613831	25234	88	20C
0005433613820	25234	89	20E
0005433633342	25234	90	20D
0005433614098	25234	91	20F
0005433613828	25234	92	21A
0005433614026	25234	93	21C
0005433633396	25234	94	21B
0005432755020	25234	95	21D
0005433613936	25234	96	21E
0005433613570	25234	97	21F
0005432751477	25234	98	22B
0005433633219	25234	99	22A
0005433577662	25234	100	22C
0005433633480	25234	101	22E
0005433613889	25234	102	22D
0005433613738	25234	103	23A
0005433633346	25234	104	23B
0005433614033	25234	105	23D
0005433613611	25234	106	23C
0005433613599	25234	107	23F
0005433613526	25234	108	24B
0005433614134	25234	109	24A
0005433614133	25234	110	24E
0005433633374	25234	111	24D
0005433613839	25234	112	25B
0005433613671	25234	113	25A
0005433613962	25234	114	25C
0005433613410	25234	115	25D
0005433613868	25234	116	25E
0005433633444	25234	117	26A
0005432755023	25234	118	25F
0005432755024	25234	119	26B
0005433577691	25234	120	26D
0005433633413	25234	121	26C
0005433577619	25234	122	26F
0005433613674	25234	123	27A
0005433577642	25234	124	27C
0005433633269	25234	125	27B
0005433613467	25234	126	27D
0005432755025	25234	127	27E
0005433577654	25234	128	28A
0005433613879	25234	129	27F
0005433614032	25234	130	28C
0005433577645	25234	131	28B
0005433613668	25234	132	28D
0005433633414	25234	133	28E
0005433613590	25234	134	29A
0005433613740	25234	135	29C
0005433613632	25234	136	29B
0005433613878	25234	137	29D
0005433613616	25234	138	30A
0005433613818	25234	139	29F
0005433633344	25234	140	30D
0005432751473	25234	141	30C
0005433613886	25234	142	30E
0005433613617	25234	143	30F
0005433633312	25234	144	31A
0005433613926	25234	145	31C
0005433633455	25234	146	31B
0005433613691	25234	147	31D
0005433613743	25234	148	31F
0005433614097	25234	149	31E
0005435856163	4206	1	1H
0005435947126	4206	2	2F
0005432184941	4206	3	3G
0005435947110	4206	4	5G
0005435947108	4206	5	9B
0005435856149	4206	6	9H
0005435856155	4206	7	13A
0005435856157	4206	8	14E
0005435856168	4206	9	17A
0005435856135	4206	10	17H
0005435947077	4206	11	18A
0005435947027	4206	12	19A
0005435947090	4206	13	19D
0005435947079	4206	14	23A
0005432571278	4206	15	25D
0005435947109	4206	16	27H
0005435856156	4206	17	29D
0005435947111	4206	18	29B
0005435947067	4206	19	31F
0005432184942	4206	20	32A
0005435854047	4206	21	32F
0005435947043	4206	22	34G
0005435947060	4206	23	35E
0005435947073	4206	24	36B
0005435947127	4206	25	36F
0005435856132	4206	26	36H
0005435947066	4206	27	37B
0005435856164	4206	28	37E
0005435856160	4206	29	37F
0005435947104	4206	30	38D
0005435947061	4206	31	38F
0005435856165	4206	32	39E
0005435947212	26573	1	2F
0005435986671	26573	2	5B
0005435947208	26573	3	12A
0005435947207	26573	4	12D
0005435947209	26573	5	13G
0005435787349	26573	6	14D
0005432571313	26573	7	14F
0005435947206	26573	8	14H
0005435947215	26573	9	17D
0005435947211	26573	10	20H
0005435856191	26573	11	21A
0005435947216	26573	12	21H
0005435856192	26573	13	23B
0005432571314	26573	14	28G
0005435856190	26573	15	29A
0005435986677	26573	16	29B
0005432571312	26573	17	30D
0005435947210	26573	18	31G
0005432571315	26573	19	32G
0005435947217	26573	20	33A
0005435947214	26573	21	33D
0005435986673	26573	22	35D
0005435947213	26573	23	36B
0005435947219	26573	24	36F
0005435947205	26573	25	37F
0005435947218	26573	26	38H
0005435856193	26573	27	39F
0005433568878	321	1	1A
0005433568927	321	2	1C
0005433568891	321	3	1F
0005433568917	321	4	1D
0005433568898	321	5	2A
0005433074385	321	6	2D
0005432948065	321	7	2C
0005433568873	321	8	2F
0005433568935	321	9	3A
0005433568902	321	10	3C
0005432947987	321	11	3F
0005433074346	321	12	3D
0005433074520	321	13	4A
0005433074419	321	14	4C
0005433568931	321	15	4F
0005433568928	321	16	4D
0005432948084	321	17	5A
0005432947943	321	18	5C
0005433129229	321	19	5F
0005432947893	321	20	5D
0005433568895	321	21	6A
0005432947792	321	22	6D
0005433568922	321	23	6C
0005433568942	321	24	6F
0005433568894	321	25	7C
0005432947837	321	26	7A
0005433568945	321	27	7D
0005433074423	321	28	8A
0005433074259	321	29	7F
0005433568884	321	30	8C
0005432238922	321	31	8B
0005433568937	321	32	8D
0005432238916	321	33	8E
0005433568924	321	34	9A
0005433568883	321	35	8F
0005433568932	321	36	9B
0005433568916	321	37	9C
0005433568905	321	38	9D
0005433568874	321	39	9F
0005432948060	321	40	9E
0005432947927	321	41	10A
0005432238918	321	42	10B
0005433568881	321	43	10D
0005433074418	321	44	10C
0005433074490	321	45	10E
0005433568896	321	46	11B
0005433568869	321	47	11A
0005433568900	321	48	11C
0005432947789	321	49	11E
0005433134079	321	50	11D
0005433074339	321	51	11F
0005433074521	321	52	12A
0005432238919	321	53	12C
0005433568936	321	54	12E
0005433568879	321	55	12D
0005432948064	321	56	13A
0005433568930	321	57	13D
0005432948119	321	58	13E
0005433568877	321	59	14A
0005433568908	321	60	13F
0005433129233	321	61	14B
0005433568910	321	62	14D
0005432238921	321	63	14F
0005432238920	321	64	14E
0005432948059	321	65	15B
0005432947980	321	66	15C
0005433568872	321	67	15E
0005433568926	321	68	15D
0005433568892	321	69	16A
0005433568920	321	70	15F
0005433129232	321	71	16C
0005433568933	321	72	16B
0005433568875	321	73	16E
0005433568912	321	74	16D
0005433568921	321	75	16F
0005433568888	321	76	17B
0005432947847	321	77	17A
0005433568904	321	78	17C
0005433568903	321	79	17F
0005433568887	321	80	18A
0005433568934	321	81	18B
0005433568897	321	82	18C
0005433568939	321	83	18D
0005432947846	321	84	18F
0005433074424	321	85	18E
0005432947920	321	86	19C
0005433074235	321	87	19B
0005433568940	321	88	19D
0005432947926	321	89	20A
0005432948014	321	90	20B
0005433568870	321	91	20E
0005432948039	321	92	20D
0005432238917	321	93	20F
0005433074422	321	94	21A
0005432947788	321	95	21C
0005432948013	321	96	21D
0005433134081	321	97	21E
0005433568880	321	98	22A
0005433568893	321	99	22B
0005433568889	321	100	22C
0005433568923	321	101	22E
0005433074437	321	102	22D
0005433129219	321	103	22F
0005433568886	321	104	23A
0005433568943	321	105	23C
0005433568907	321	106	23B
0005433568941	321	107	23D
0005433074436	321	108	23E
0005433074425	321	109	23F
0005433568906	321	110	24B
0005433074258	321	111	24A
0005433074290	321	112	24C
0005433568899	321	113	24F
0005432947981	321	114	25C
0005433074347	321	115	25B
0005433568918	321	116	25F
0005433568919	321	117	25E
0005433568909	321	118	26A
0005433074397	321	119	26B
0005433568929	321	120	26D
0005433568913	321	121	26C
0005432947986	321	122	26F
0005433568914	321	123	27A
0005433074375	321	124	27C
0005433074247	321	125	27D
0005433568938	321	126	27F
0005433074276	321	127	27E
0005433568925	321	128	28A
0005432238915	321	129	28B
0005433074443	321	130	28D
0005433129202	321	131	28C
0005432947908	321	132	28F
0005433074321	321	133	29B
0005433568890	321	134	29A
0005433568944	321	135	29D
0005433134070	321	136	29F
0005433568871	321	137	29E
0005433568901	321	138	30A
0005433568911	321	139	30D
0005433568915	321	140	30C
0005432947907	321	141	30E
0005433074444	321	142	30F
0005432947978	321	143	31B
0005433568876	321	144	31A
0005433568885	321	145	31C
0005432947985	321	146	31D
0005433568882	321	147	31E
0005433568360	11580	1	1A
0005433568261	11580	2	1C
0005433568314	11580	3	1D
0005433568202	11580	4	1F
0005432948318	11580	5	2C
0005433568250	11580	6	3A
0005432948311	11580	7	2F
0005433074618	11580	8	3C
0005432948314	11580	9	3F
0005433074617	11580	10	3D
0005432192310	11580	11	4A
0005433568143	11580	12	4D
0005433568304	11580	13	5A
0005433568284	11580	14	4F
0005432948322	11580	15	5F
0005433568035	11580	16	5D
0005433568294	11580	17	6A
0005433568197	11580	18	6C
0005433568109	11580	19	6F
0005433568270	11580	20	6D
0005433074622	11580	21	7A
0005433568252	11580	22	7F
0005433074620	11580	23	7D
0005433074615	11580	24	8A
0005433568126	11580	25	8B
0005432948325	11580	26	8C
0005433568196	11580	27	8E
0005433074609	11580	28	8F
0005433074632	11580	29	9A
0005432948334	11580	30	9B
0005433074629	11580	31	9D
0005433074619	11580	32	9F
0005433074623	11580	33	9E
0005432948339	11580	34	10A
0005433568195	11580	35	10B
0005433568355	11580	36	10D
0005432948327	11580	37	10E
0005433568312	11580	38	10F
0005432948343	11580	39	11B
0005433568251	11580	40	11A
0005433568358	11580	41	11D
0005433074608	11580	42	12A
0005433074613	11580	43	11F
0005432948321	11580	44	12C
0005433568130	11580	45	12B
0005432948313	11580	46	12E
0005433074624	11580	47	12D
0005433074611	11580	48	12F
0005432948330	11580	49	13B
0005433568240	11580	50	13A
0005432948326	11580	51	13C
0005433074605	11580	52	13E
0005433568230	11580	53	13D
0005432948338	11580	54	13F
0005433568237	11580	55	14A
0005432948333	11580	56	14B
0005433568020	11580	57	14C
0005433074612	11580	58	14E
0005432948324	11580	59	14D
0005433568201	11580	60	14F
0005433568231	11580	61	15B
0005433568200	11580	62	15A
0005433131693	11580	63	15C
0005433568211	11580	64	15D
0005433568361	11580	65	15F
0005433074626	11580	66	15E
0005433568249	11580	67	16A
0005433568342	11580	68	16B
0005433131695	11580	69	16D
0005433074607	11580	70	16C
0005433131694	11580	71	16E
0005433568287	11580	72	16F
0005433074630	11580	73	17B
0005432948329	11580	74	17A
0005433568286	11580	75	17C
0005433568295	11580	76	17E
0005433568296	11580	77	17D
0005433568305	11580	78	17F
0005433568093	11580	79	18A
0005432948346	11580	80	18B
0005433131692	11580	81	18D
0005433568122	11580	82	18C
0005432948340	11580	83	18F
0005433074625	11580	84	19C
0005433568289	11580	85	19B
0005432948344	11580	86	19D
0005432948306	11580	87	20A
0005433074631	11580	88	20C
0005433568348	11580	89	20B
0005433568288	11580	90	20D
0005433568131	11580	91	20E
0005432948335	11580	92	21B
0005432948342	11580	93	21D
0005433568205	11580	94	21C
0005432192311	11580	95	21E
0005432948312	11580	96	22A
0005432948328	11580	97	21F
0005432948323	11580	98	22C
0005432948309	11580	99	22E
0005432948315	11580	100	23B
0005432948316	11580	101	23A
0005433568259	11580	102	23D
0005432948308	11580	103	23C
0005433568341	11580	104	23E
0005433074627	11580	105	24A
0005433568091	11580	106	23F
0005433568293	11580	107	24D
0005433568123	11580	108	24C
0005433074616	11580	109	25A
0005433074621	11580	110	25D
0005433568280	11580	111	25C
0005432948320	11580	112	26A
0005433568260	11580	113	25F
0005433134124	11580	114	26B
0005432948319	11580	115	26D
0005433074633	11580	116	26C
0005433134125	11580	117	26E
0005433134123	11580	118	26F
0005433074606	11580	119	27A
0005433568210	11580	120	27B
0005432948305	11580	121	27D
0005433568165	11580	122	27C
0005433568283	11580	123	27E
0005432948336	11580	124	28A
0005433074610	11580	125	27F
0005432948341	11580	126	28B
0005432948337	11580	127	28D
0005433568142	11580	128	28C
0005432948307	11580	129	28E
0005433568313	11580	130	28F
0005433568074	11580	131	29A
0005433568075	11580	132	29C
0005433568110	11580	133	29D
0005433074614	11580	134	29E
0005432948331	11580	135	30A
0005433568236	11580	136	29F
0005433074628	11580	137	30B
0005433568092	11580	138	30D
0005433134122	11580	139	30C
0005432948332	11580	140	30E
0005432948345	11580	141	31A
0005433568199	11580	142	30F
0005432948310	11580	143	31C
0005433568036	11580	144	31B
0005432948317	11580	145	31E
0005433568056	11580	146	31D
0005433568285	11580	147	31F
0005433817458	10040	1	1A
0005434732937	10040	2	1B
0005434732938	10040	3	2A
0005433817459	10040	4	3A
0005434732941	10040	5	3B
0005433817460	10040	6	4A
0005434732936	10040	7	5A
0005434732921	10040	8	5B
0005434732950	10040	9	6A
0005434732946	10040	10	6B
0005434732969	13964	1	1A
0005434732971	13964	2	2A
0005433817433	13964	3	2B
0005434732972	13964	4	3A
0005433817414	13964	5	4A
0005433817434	13964	6	3B
0005433817435	13964	7	4B
0005434732970	13964	8	6A
0005432984664	2349	1	1A
0005433754042	2349	2	1C
0005433434323	2349	3	1B
0005432984719	2349	4	1F
0005432655498	2349	5	1H
0005433434274	2349	6	1G
0005435982148	2349	7	2A
0005433434337	2349	8	2B
0005432984745	2349	9	2C
0005433754072	2349	10	2H
0005433434368	2349	11	3B
0005434731127	2349	12	3A
0005432869462	2349	13	3F
0005433434248	2349	14	3C
0005433434324	2349	15	3G
0005433754065	2349	16	4B
0005433754038	2349	17	4A
0005433434273	2349	18	4F
0005433754052	2349	19	4C
0005435982183	2349	20	4G
0005433754067	2349	21	5A
0005432300249	2349	22	4H
0005432655505	2349	23	5B
0005433754074	2349	24	5F
0005433754081	2349	25	5C
0005433754053	2349	26	5H
0005432984717	2349	27	9B
0005433766628	2349	28	9A
0005432226037	2349	29	9G
0005433754040	2349	30	11A
0005435982147	2349	31	9H
0005433754064	2349	32	11D
0005433434212	2349	33	11B
0005433754037	2349	34	11E
0005433754071	2349	35	11F
0005433754062	2349	36	11G
0005435982172	2349	37	12A
0005434731138	2349	38	11H
0005435982157	2349	39	12D
0005432655507	2349	40	12B
0005434731118	2349	41	12E
0005435982193	2349	42	12G
0005433754082	2349	43	12F
0005434731107	2349	44	12H
0005433434400	2349	45	13A
0005433764674	2349	46	13B
0005433434303	2349	47	13F
0005435982180	2349	48	13E
0005432984665	2349	49	13G
0005432655504	2349	50	13H
0005433434343	2349	51	14A
0005433754051	2349	52	14D
0005435982141	2349	53	14B
0005435982174	2349	54	14F
0005435982154	2349	55	14E
0005432226036	2349	56	14H
0005433754041	2349	57	14G
0005433754073	2349	58	15D
0005433434304	2349	59	15B
0005432226038	2349	60	15G
0005432984736	2349	61	15F
0005435982150	2349	62	15H
0005432226040	2349	63	16B
0005433754054	2349	64	16A
0005433754028	2349	65	16D
0005433754055	2349	66	16E
0005434731126	2349	67	16G
0005435982195	2349	68	16F
0005435982169	2349	69	16H
0005432984666	2349	70	17A
0005432300247	2349	71	17D
0005432226035	2349	72	17B
0005432655502	2349	73	17E
0005432984574	2349	74	17F
0005435982151	2349	75	17H
0005435982166	2349	76	18B
0005435982143	2349	77	18A
0005435982189	2349	78	18D
0005432984706	2349	79	18E
0005432984731	2349	80	18G
0005433754076	2349	81	18H
0005433766630	2349	82	19B
0005432984519	2349	83	19A
0005432869463	2349	84	19D
0005433754033	2349	85	19F
0005433754080	2349	86	19E
0005432984718	2349	87	19G
0005435982191	2349	88	20A
0005433754039	2349	89	19H
0005433754043	2349	90	20B
0005432984648	2349	91	20E
0005435982173	2349	92	20D
0005432869426	2349	93	20F
0005433434451	2349	94	20H
0005433434342	2349	95	20G
0005432226041	2349	96	21A
0005433754061	2349	97	21B
0005432869448	2349	98	21F
0005433754083	2349	99	21E
0005433434334	2349	100	21D
0005433434399	2349	101	21H
0005432984651	2349	102	22A
0005432984691	2349	103	22D
0005433754079	2349	104	22B
0005435982163	2349	105	22F
0005435982187	2349	106	22E
0005435982175	2349	107	22G
0005432300245	2349	108	23A
0005433754036	2349	109	22H
0005433754050	2349	110	23B
0005433754068	2349	111	23D
0005432869452	2349	112	23E
0005432655508	2349	113	23G
0005433754048	2349	114	24A
0005435982167	2349	115	23H
0005433754075	2349	116	24B
0005435982153	2349	117	24E
0005432300248	2349	118	24D
0005432984634	2349	119	24F
0005433754031	2349	120	24H
0005432984772	2349	121	24G
0005432984694	2349	122	25D
0005435982178	2349	123	25E
0005434731125	2349	124	25F
0005432984789	2349	125	27B
0005435982190	2349	126	27E
0005433754070	2349	127	27D
0005433754060	2349	128	27G
0005432984707	2349	129	27F
0005435982156	2349	130	27H
0005435982192	2349	131	28A
0005433434369	2349	132	28D
0005435982159	2349	133	28B
0005433754032	2349	134	28E
0005432869447	2349	135	28F
0005432984690	2349	136	28H
0005435982158	2349	137	28G
0005435982171	2349	138	29A
0005433754056	2349	139	29B
0005435982142	2349	140	29E
0005433754078	2349	141	29D
0005433766629	2349	142	29F
0005435982165	2349	143	29H
0005433754063	2349	144	29G
0005433754029	2349	145	30A
0005435982194	2349	146	30D
0005432655506	2349	147	30B
0005433434388	2349	148	30F
0005435982161	2349	149	30G
0005435982186	2349	150	30H
0005433754077	2349	151	31B
0005435982146	2349	152	31D
0005433754034	2349	153	31E
0005433754049	2349	154	31F
0005435982184	2349	155	32A
0005435982149	2349	156	31H
0005432655500	2349	157	32D
0005435982162	2349	158	32B
0005433754059	2349	159	32F
0005433754035	2349	160	32E
0005432984698	2349	161	32H
0005432984729	2349	162	32G
0005432984728	2349	163	33A
0005435982168	2349	164	33D
0005432984621	2349	165	33B
0005435982176	2349	166	33E
0005435982145	2349	167	33F
0005433754045	2349	168	33H
0005433754066	2349	169	33G
0005435982188	2349	170	34A
0005432984824	2349	171	34D
0005433754058	2349	172	34B
0005433754030	2349	173	34F
0005432226039	2349	174	34E
0005432300246	2349	175	34G
0005435982182	2349	176	34H
0005435982164	2349	177	35B
0005435982160	2349	178	35A
0005433754044	2349	179	35D
0005433434345	2349	180	35E
0005433754047	2349	181	35G
0005433754057	2349	182	35F
0005435982144	2349	183	35H
0005433434349	2349	184	36B
0005435982170	2349	185	36D
0005432655497	2349	186	36F
0005432984689	2349	187	36E
0005432300244	2349	188	36H
0005433754027	2349	189	36G
0005432869461	2349	190	37A
0005435982177	2349	191	37D
0005433434401	2349	192	37B
0005433434389	2349	193	37E
0005432655503	2349	194	37G
0005433754046	2349	195	37F
0005435982155	2349	196	37H
0005434731122	2349	197	38A
0005432655501	2349	198	38B
0005435982152	2349	199	38E
0005435982181	2349	200	38D
0005435982185	2349	201	38F
0005432984692	2349	202	38H
0005433754069	2349	203	38G
0005432655499	2349	204	39D
0005435982179	2349	205	39E
0005435981795	26200	1	1A
0005432984979	26200	2	1F
0005433434610	26200	3	1C
0005433434590	26200	4	1G
0005435981852	26200	5	2A
0005433766614	26200	6	1H
0005432984992	26200	7	2B
0005433753292	26200	8	2F
0005432051118	26200	9	2C
0005435981804	26200	10	2G
0005435981836	26200	11	3A
0005433434592	26200	12	2H
0005432655381	26200	13	3B
0005433764654	26200	14	3F
0005432984991	26200	15	3C
0005432869500	26200	16	3G
0005433753642	26200	17	4A
0005435981851	26200	18	3H
0005432869502	26200	19	4B
0005432984985	26200	20	4F
0005433434595	26200	21	4C
0005433434606	26200	22	4G
0005433764666	26200	23	4H
0005432984972	26200	24	5B
0005432984997	26200	25	5A
0005432869499	26200	26	5F
0005433753359	26200	27	5C
0005433753575	26200	28	5G
0005432984966	26200	29	5H
0005435981775	26200	30	9A
0005432049453	26200	31	9H
0005434731158	26200	32	9G
0005433753577	26200	33	11A
0005433753893	26200	34	11B
0005435981702	26200	35	11E
0005433753866	26200	36	11D
0005435981776	26200	37	11F
0005433434593	26200	38	11H
0005433753353	26200	39	11G
0005433753476	26200	40	12A
0005432984976	26200	41	12D
0005433753291	26200	42	12F
0005433434608	26200	43	12E
0005433753362	26200	44	12H
0005433753452	26200	45	12G
0005433434602	26200	46	13B
0005433753576	26200	47	13D
0005432984996	26200	48	13E
0005433753504	26200	49	14A
0005433753700	26200	50	13H
0005433753559	26200	51	13G
0005432869501	26200	52	14B
0005433753413	26200	53	14D
0005433434583	26200	54	14F
0005435981880	26200	55	14E
0005434731160	26200	56	15A
0005435981805	26200	57	14H
0005433753633	26200	58	15D
0005433753641	26200	59	15B
0005435981770	26200	60	15E
0005433753608	26200	61	15F
0005435981911	26200	62	15H
0005432984971	26200	63	15G
0005435981796	26200	64	16A
0005433753377	26200	65	16D
0005435981682	26200	66	16B
0005432984990	26200	67	16E
0005433753423	26200	68	16G
0005433434594	26200	69	16H
0005433753352	26200	70	17B
0005433753435	26200	71	17A
0005432984975	26200	72	17D
0005433434584	26200	73	17F
0005433753477	26200	74	17H
0005432984984	26200	75	17G
0005433434589	26200	76	18A
0005435981633	26200	77	18D
0005433764663	26200	78	18B
0005433434604	26200	79	18E
0005433753865	26200	80	18F
0005433766602	26200	81	18H
0005435981902	26200	82	19B
0005435981634	26200	83	19A
0005433753628	26200	84	19D
0005433434586	26200	85	19F
0005433753376	26200	86	20A
0005432984973	26200	87	20B
0005435981643	26200	88	20E
0005433434599	26200	89	20D
0005434731157	26200	90	20F
0005432984969	26200	91	20H
0005432869504	26200	92	20G
0005435981764	26200	93	21A
0005433753471	26200	94	21B
0005432869506	26200	95	21E
0005433434600	26200	96	21G
0005432984974	26200	97	21F
0005432984968	26200	98	21H
0005433753627	26200	99	22A
0005433753730	26200	100	22D
0005435981737	26200	101	22B
0005433753699	26200	102	22F
0005433766593	26200	103	22E
0005433753688	26200	104	22G
0005432984989	26200	105	23A
0005432984987	26200	106	22H
0005433434611	26200	107	23B
0005432655374	26200	108	23D
0005433434587	26200	109	23E
0005432655395	26200	110	23F
0005433753610	26200	111	23H
0005432869503	26200	112	24B
0005433753626	26200	113	24D
0005432049451	26200	114	24F
0005435981644	26200	115	24E
0005433434596	26200	116	24H
0005432984995	26200	117	24G
0005433753485	26200	118	25F
0005432051120	26200	119	25D
0005433753607	26200	120	27A
0005432655355	26200	121	27B
0005435981624	26200	122	27E
0005433753361	26200	123	27D
0005433753360	26200	124	27F
0005432984967	26200	125	27H
0005433434603	26200	126	27G
0005432049454	26200	127	28A
0005432984978	26200	128	28D
0005433753541	26200	129	28B
0005433766618	26200	130	28F
0005433754011	26200	131	28H
0005432049455	26200	132	28G
0005432655379	26200	133	29A
0005435981897	26200	134	29B
0005433434605	26200	135	29F
0005433753422	26200	136	29E
0005432984981	26200	137	29D
0005432984977	26200	138	29G
0005433434585	26200	139	29H
0005434731156	26200	140	30B
0005432984965	26200	141	30A
0005435981722	26200	142	30E
0005432984986	26200	143	30G
0005433753581	26200	144	30F
0005432984983	26200	145	30H
0005432984993	26200	146	31B
0005432984970	26200	147	31A
0005433764665	26200	148	31D
0005435981828	26200	149	31E
0005433753588	26200	150	31H
0005432984988	26200	151	31G
0005433753550	26200	152	31F
0005435981769	26200	153	32A
0005433753436	26200	154	32B
0005435981766	26200	155	32D
0005433434591	26200	156	32G
0005435981748	26200	157	32F
0005432984994	26200	158	32E
0005433434601	26200	159	32H
0005433753441	26200	160	33E
0005433753644	26200	161	33D
0005433753551	26200	162	33F
0005435981767	26200	163	33H
0005435981723	26200	164	33G
0005435981635	26200	165	34D
0005435981706	26200	166	34B
0005433753549	26200	167	34E
0005435981692	26200	168	34G
0005432869505	26200	169	34F
0005433753582	26200	170	34H
0005432049452	26200	171	35A
0005433434609	26200	172	35D
0005433753689	26200	173	35B
0005432655349	26200	174	35E
0005433434607	26200	175	35G
0005432051119	26200	176	35F
0005432984980	26200	177	36A
0005433753414	26200	178	35H
0005435981803	26200	179	36B
0005433434588	26200	180	36D
0005435981736	26200	181	36F
0005435981879	26200	182	36G
0005435981765	26200	183	37A
0005433753592	26200	184	36H
0005433753557	26200	185	37D
0005435981652	26200	186	37B
0005433753490	26200	187	37F
0005432655389	26200	188	37G
0005435981898	26200	189	38A
0005433753624	26200	190	37H
0005434731159	26200	191	38D
0005432984982	26200	192	38B
0005433434597	26200	193	38E
0005433434598	26200	194	38F
0005433753591	26200	195	38H
0005432655356	26200	196	39E
0005433753650	26200	197	39D
0005433753333	26200	198	39F
0005434374545	1539	1	1A
0005434374541	1539	2	1C
0005434374546	1539	3	1D
0005434374511	1539	4	2A
0005434374524	1539	5	1F
0005434374529	1539	6	2C
0005432267874	1539	7	2F
0005433764652	1539	8	3A
0005433151110	1539	9	4A
0005433151172	1539	10	4C
0005433460429	1539	11	4B
0005434374514	1539	12	4D
0005434374563	1539	13	4E
0005434374554	1539	14	5A
0005434374521	1539	15	4F
0005432267879	1539	16	5B
0005434374555	1539	17	5D
0005433151007	1539	18	5C
0005434374522	1539	19	5E
0005433151173	1539	20	6A
0005434374562	1539	21	5F
0005434374558	1539	22	6C
0005434374544	1539	23	6D
0005433151051	1539	24	6E
0005434374512	1539	25	6F
0005434374549	1539	26	7B
0005433151060	1539	27	7C
0005434374518	1539	28	7E
0005434374530	1539	29	7D
0005433151105	1539	30	7F
0005434374540	1539	31	8B
0005434374520	1539	32	8C
0005433151067	1539	33	8F
0005433151106	1539	34	8E
0005434374557	1539	35	9A
0005432267875	1539	36	9D
0005433151064	1539	37	9F
0005433151052	1539	38	10B
0005432267878	1539	39	10D
0005433151118	1539	40	10C
0005433151103	1539	41	11C
0005434374552	1539	42	11B
0005433151056	1539	43	11E
0005433151008	1539	44	11D
0005433150967	1539	45	11F
0005434374536	1539	46	12A
0005433151061	1539	47	12B
0005434374566	1539	48	12D
0005434374559	1539	49	12C
0005434374553	1539	50	12E
0005434374527	1539	51	12F
0005434374510	1539	52	13B
0005433151055	1539	53	13A
0005433461581	1539	54	13D
0005432267872	1539	55	13E
0005433151031	1539	56	14A
0005434374534	1539	57	14C
0005432267877	1539	58	14B
0005434374537	1539	59	14D
0005433461582	1539	60	14E
0005434374517	1539	61	14F
0005434374526	1539	62	15A
0005434374513	1539	63	15C
0005434374535	1539	64	15D
0005433151009	1539	65	15E
0005434374565	1539	66	16A
0005434374528	1539	67	15F
0005433150851	1539	68	16B
0005434374538	1539	69	16D
0005434374525	1539	70	16C
0005433150919	1539	71	16F
0005433151078	1539	72	17B
0005432267876	1539	73	17D
0005433151074	1539	74	17C
0005433150987	1539	75	17E
0005434374560	1539	76	18A
0005434374519	1539	77	18B
0005433151006	1539	78	18D
0005434374516	1539	79	19A
0005434374539	1539	80	18F
0005433764658	1539	81	19B
0005434374533	1539	82	19C
0005434374523	1539	83	19E
0005433764653	1539	84	19D
0005434374542	1539	85	19F
0005434374515	1539	86	20C
0005434374564	1539	87	20E
0005434374543	1539	88	20F
0005434374548	1539	89	21B
0005433151035	1539	90	21A
0005433150913	1539	91	21C
0005434374550	1539	92	21E
0005433460430	1539	93	22A
0005434374561	1539	94	21F
0005434374551	1539	95	22B
0005432267873	1539	96	22D
0005433151057	1539	97	22E
0005434374531	1539	98	23A
0005434374556	1539	99	23B
0005434374547	1539	100	23C
0005433151171	1539	101	23E
0005434374532	1539	102	23F
0005434374085	20160	1	1A
0005433764674	20160	2	1C
0005433931459	20160	3	1D
0005433151320	20160	4	2A
0005434374025	20160	5	1F
0005434374249	20160	6	2D
0005433151304	20160	7	2F
0005434374304	20160	8	3C
0005433931456	20160	9	3D
0005434373910	20160	10	3F
0005433931457	20160	11	4B
0005434374106	20160	12	4A
0005434374152	20160	13	4C
0005433151313	20160	14	4D
0005434374196	20160	15	4F
0005434374224	20160	16	5A
0005434373935	20160	17	5C
0005433151319	20160	18	5B
0005434374248	20160	19	5D
0005434374156	20160	20	5E
0005433151314	20160	21	6A
0005434373909	20160	22	5F
0005434374100	20160	23	6B
0005433151292	20160	24	6C
0005434374099	20160	25	6D
0005434374061	20160	26	6F
0005434374246	20160	27	6E
0005434374329	20160	28	7A
0005433151290	20160	29	7C
0005434374116	20160	30	7D
0005433151296	20160	31	7F
0005434374144	20160	32	7E
0005433151294	20160	33	8B
0005434374247	20160	34	8A
0005434374093	20160	35	8D
0005432056288	20160	36	8F
0005433151302	20160	37	9A
0005433151293	20160	38	9B
0005434374105	20160	39	9D
0005433151300	20160	40	9E
0005433151286	20160	41	9F
0005434374131	20160	42	10B
0005433151289	20160	43	10C
0005433151312	20160	44	10E
0005433151310	20160	45	10D
0005434374083	20160	46	11A
0005434374157	20160	47	11E
0005432056289	20160	48	11F
0005434029649	20160	49	12A
0005434373959	20160	50	12D
0005434374305	20160	51	12C
0005434374111	20160	52	12F
0005433151307	20160	53	13B
0005434373956	20160	54	13D
0005433931458	20160	55	13C
0005433151303	20160	56	13E
0005434373908	20160	57	14A
0005433151291	20160	58	13F
0005434374023	20160	59	14C
0005434373955	20160	60	14E
0005434374227	20160	61	14F
0005433151297	20160	62	15C
0005434374419	20160	63	15D
0005433151299	20160	64	16B
0005434373888	20160	65	16C
0005433151306	20160	66	16D
0005433151308	20160	67	16F
0005434374296	20160	68	16E
0005433151287	20160	69	17B
0005434374112	20160	70	17C
0005433151315	20160	71	17E
0005433151298	20160	72	18A
0005434374113	20160	73	17F
0005434374297	20160	74	18B
0005433151311	20160	75	18F
0005434374240	20160	76	19A
0005434374174	20160	77	19B
0005434374137	20160	78	19C
0005433151295	20160	79	19E
0005433151305	20160	80	19D
0005434373981	20160	81	19F
0005433151318	20160	82	20A
0005434374062	20160	83	20D
0005434374214	20160	84	20F
0005432056290	20160	85	21B
0005433151288	20160	86	21C
0005434374086	20160	87	21D
0005434374115	20160	88	21E
0005434373996	20160	89	21F
0005434374223	20160	90	22B
0005433151309	20160	91	22A
0005434374215	20160	92	22E
0005433151301	20160	93	22D
0005434374082	20160	94	23A
0005434029650	20160	95	23C
0005434374306	20160	96	23E
0005433151316	20160	97	23D
0005433151317	20160	98	23F
0005432424275	526	1	1A
0005432424294	526	2	1F
0005432424292	526	3	2D
0005432424273	526	4	3A
0005432424287	526	5	2F
0005432424290	526	6	3D
0005432424304	526	7	4C
0005432424297	526	8	4F
0005432424303	526	9	4D
0005432424318	526	10	5F
0005432424269	526	11	5D
0005432424315	526	12	6A
0005432424288	526	13	6D
0005432424281	526	14	7A
0005432424317	526	15	6F
0005432424323	526	16	7C
0005432282842	526	17	7F
0005432282841	526	18	8E
0005432424316	526	19	8D
0005432424289	526	20	9D
0005432424295	526	21	10D
0005432424305	526	22	10E
0005432282845	526	23	11A
0005432424311	526	24	11F
0005432424282	526	25	13C
0005432424308	526	26	13B
0005432424285	526	27	13E
0005432424271	526	28	13D
0005432424314	526	29	13F
0005432424299	526	30	14C
0005432424319	526	31	14F
0005432424302	526	32	15A
0005432424283	526	33	15D
0005432424274	526	34	16E
0005432424279	526	35	17A
0005432424270	526	36	16F
0005432424307	526	37	17C
0005432424322	526	38	17D
0005432424280	526	39	18E
0005432424301	526	40	19D
0005432424272	526	41	19E
0005432424277	526	42	20A
0005432424313	526	43	20D
0005432282847	526	44	20F
0005432424312	526	45	21D
0005432424320	526	46	22E
0005432424296	526	47	23D
0005432424309	526	48	23E
0005432424286	526	49	25D
0005432424293	526	50	26E
0005432424300	526	51	26D
0005432282844	526	52	26F
0005432424284	526	53	27B
0005432424306	526	54	28D
0005432424310	526	55	28F
0005432282843	526	56	29C
0005432424276	526	57	29E
0005432424321	526	58	30A
0005432282846	526	59	30F
0005432424291	526	60	31B
0005432424278	526	61	31A
0005432424298	526	62	31E
0005434446491	12885	1	1F
0005434446495	12885	2	2A
0005433158123	12885	3	4C
0005433158124	12885	4	8E
0005432302321	12885	5	10A
0005434446487	12885	6	11A
0005433158120	12885	7	12C
0005433158127	12885	8	13A
0005432302319	12885	9	13F
0005433158121	12885	10	14A
0005432302318	12885	11	14F
0005433158122	12885	12	16B
0005433158126	12885	13	19B
0005434446485	12885	14	20D
0005434446488	12885	15	21D
0005433158125	12885	16	23B
0005432302320	12885	17	24A
0005434446486	12885	18	24D
0005432423913	12874	1	1D
0005432423867	12874	2	1F
0005432423848	12874	3	2F
0005432423835	12874	4	6A
0005432423849	12874	5	6C
0005432423883	12874	6	6F
0005432423889	12874	7	7A
0005432423885	12874	8	7C
0005432423924	12874	9	7D
0005432423793	12874	10	8A
0005432423839	12874	11	8C
0005432423906	12874	12	8D
0005432423905	12874	13	9B
0005432423886	12874	14	9D
0005432423925	12874	15	10E
0005432423890	12874	16	10D
0005432423829	12874	17	11A
0005432423847	12874	18	11D
0005432423676	12874	19	12D
0005432423887	12874	20	12C
0005432423841	12874	21	13D
0005432423888	12874	22	14A
0005432423807	12874	23	14B
0005432423862	12874	24	15A
0005432423891	12874	25	16B
0005432423931	12874	26	16C
0005432423926	12874	27	16E
0005432423882	12874	28	16F
0005432423834	12874	29	17B
0005432423868	12874	30	17F
0005432423935	12874	31	18B
0005432423923	12874	32	19B
0005432423948	12874	33	19D
0005432423830	12874	34	21D
0005432423820	12874	35	21E
0005432423806	12874	36	22A
0005432423842	12874	37	22D
0005432423840	12874	38	23B
0005432423821	12874	39	23C
0005432423825	12874	40	24A
0005432423685	12874	41	24C
0005432423927	12874	42	24D
0005432423794	12874	43	24F
0005432423742	12874	44	25D
0005432423792	12874	45	25C
0005432423715	12874	46	26F
0005432423704	12874	47	27B
0005432423822	12874	48	27D
0005432423823	12874	49	27F
0005432423904	12874	50	28B
0005432423797	12874	51	28E
0005432423892	12874	52	29B
0005432423907	12874	53	29E
0005432423863	12874	54	31B
0005434023523	476	1	1A
0005434735625	476	2	1C
0005433057529	476	3	1G
0005433057493	476	4	2C
0005434023480	476	5	2F
0005434029646	476	6	2G
0005434023490	476	7	3A
0005433057451	476	8	2H
0005434029647	476	9	3B
0005433057456	476	10	3F
0005434023471	476	11	3G
0005434023500	476	12	4A
0005434029645	476	13	3H
0005434023534	476	14	4B
0005432045607	476	15	4F
0005433057370	476	16	4G
0005434023499	476	17	5G
0005434023516	476	18	5F
0005433057351	476	19	9B
0005432235614	476	20	9A
0005434023530	476	21	9G
0005433057339	476	22	9H
0005432045605	476	23	11B
0005433057475	476	24	11D
0005434023484	476	25	11G
0005434023483	476	26	11F
0005434023507	476	27	11H
0005433057334	476	28	12B
0005434023498	476	29	12E
0005434023492	476	30	12F
0005434023518	476	31	12H
0005432235619	476	32	12G
0005433057454	476	33	13A
0005433057263	476	34	13D
0005433684397	476	35	13E
0005433929561	476	36	13F
0005432045606	476	37	13H
0005434023535	476	38	14B
0005434032008	476	39	14A
0005434023531	476	40	14D
0005434023526	476	41	14G
0005434032004	476	42	14H
0005434023519	476	43	15D
0005433057508	476	44	15H
0005434023482	476	45	16B
0005434023474	476	46	16G
0005433057474	476	47	16H
0005434023487	476	48	17B
0005434023514	476	49	17A
0005434023486	476	50	17E
0005432235616	476	51	17G
0005434023524	476	52	18A
0005434023540	476	53	17H
0005434023538	476	54	18B
0005433057429	476	55	18D
0005434023528	476	56	18E
0005434023502	476	57	18H
0005433057460	476	58	18G
0005433057403	476	59	18F
0005433057292	476	60	19A
0005434023506	476	61	19E
0005434032007	476	62	19H
0005434023489	476	63	19G
0005434735636	476	64	20A
0005434023503	476	65	20D
0005433057392	476	66	20B
0005434023520	476	67	20E
0005433057265	476	68	20G
0005433684398	476	69	20F
0005434735626	476	70	20H
0005434735624	476	71	21A
0005434023478	476	72	21D
0005434023495	476	73	21B
0005433057472	476	74	21E
0005434023536	476	75	21G
0005432235617	476	76	21H
0005434023533	476	77	22D
0005434023473	476	78	22F
0005432235620	476	79	22E
0005434023477	476	80	23B
0005434023532	476	81	23E
0005434023479	476	82	23G
0005434023539	476	83	24A
0005434023508	476	84	24D
0005433057264	476	85	24F
0005434023510	476	86	24E
0005433684393	476	87	24G
0005434023505	476	88	24H
0005434023522	476	89	27B
0005433057410	476	90	27A
0005432235618	476	91	27F
0005432235613	476	92	27G
0005433057360	476	93	28B
0005434023491	476	94	28E
0005433057338	476	95	28D
0005433057335	476	96	28H
0005434023485	476	97	28G
0005434735637	476	98	29A
0005432235612	476	99	29D
0005433057398	476	100	29B
0005434023525	476	101	29E
0005434023493	476	102	29F
0005434023521	476	103	30A
0005434023513	476	104	29H
0005434023517	476	105	30D
0005434032006	476	106	30B
0005433057409	476	107	30E
0005433057453	476	108	30G
0005434023494	476	109	30F
0005433057333	476	110	30H
0005434023476	476	111	31B
0005434032005	476	112	31A
0005433929560	476	113	31D
0005433057354	476	114	31E
0005433929569	476	115	32A
0005434023497	476	116	32D
0005433057498	476	117	32F
0005433057479	476	118	32E
0005434023509	476	119	32H
0005434023529	476	120	32G
0005433057452	476	121	33A
0005433057482	476	122	33B
0005434023501	476	123	33F
0005434023511	476	124	33H
0005434023504	476	125	34A
0005434023475	476	126	34E
0005433929563	476	127	34G
0005433057471	476	128	34H
0005434029648	476	129	35B
0005434023527	476	130	35D
0005434023488	476	131	35F
0005433057497	476	132	36A
0005434023515	476	133	36B
0005434023472	476	134	36E
0005433929564	476	135	36H
0005434023496	476	136	37B
0005434735638	476	137	37D
0005433057404	476	138	37F
0005433057549	476	139	37G
0005433057344	476	140	38A
0005434032009	476	141	38E
0005433929547	476	142	38F
0005433057337	476	143	38H
0005434023512	476	144	38G
0005434023481	476	145	39E
0005434023537	476	146	39D
0005432235615	476	147	39F
0005434022764	12692	1	1A
0005433057747	12692	2	1F
0005434023063	12692	3	2B
0005434022857	12692	4	2C
0005434022891	12692	5	2F
0005433057763	12692	6	3A
0005434022767	12692	7	3H
0005434023004	12692	8	3G
0005434023112	12692	9	4A
0005433057753	12692	10	4B
0005433057751	12692	11	4C
0005434022916	12692	12	4G
0005434735677	12692	13	5A
0005434023199	12692	14	4H
0005434735676	12692	15	5C
0005433057768	12692	16	5G
0005434023070	12692	17	5H
0005434735674	12692	18	9H
0005433057746	12692	19	11B
0005434031950	12692	20	11A
0005434023088	12692	21	11D
0005434022774	12692	22	11F
0005433057745	12692	23	12B
0005434023208	12692	24	11H
0005433057777	12692	25	12E
0005433057775	12692	26	12G
0005432156353	12692	27	12F
0005434022994	12692	28	12H
0005433057758	12692	29	13A
0005434022780	12692	30	13B
0005434022915	12692	31	13F
0005434735675	12692	32	13G
0005433057769	12692	33	14A
0005433057765	12692	34	14D
0005434023069	12692	35	14F
0005433057783	12692	36	14E
0005433057774	12692	37	14G
0005434022910	12692	38	14H
0005433057760	12692	39	15G
0005434022943	12692	40	16A
0005434023080	12692	41	16B
0005434023075	12692	42	16E
0005434022839	12692	43	16F
0005434022775	12692	44	17B
0005434022856	12692	45	17D
0005434023229	12692	46	18B
0005433057782	12692	47	18A
0005434028274	12692	48	18F
0005433057748	12692	49	18G
0005434022949	12692	50	18H
0005434022858	12692	51	19B
0005434023005	12692	52	19A
0005434023064	12692	53	19H
0005434023087	12692	54	20D
0005434022962	12692	55	20E
0005433057778	12692	56	21D
0005434031985	12692	57	21B
0005433057771	12692	58	21F
0005434023009	12692	59	21G
0005434023198	12692	60	22A
0005433057756	12692	61	22G
0005433057759	12692	62	22F
0005434022812	12692	63	23F
0005433057754	12692	64	24A
0005434023045	12692	65	23H
0005433057761	12692	66	24E
0005433057776	12692	67	24D
0005434022688	12692	68	25D
0005434023233	12692	69	24H
0005433057752	12692	70	27A
0005433057781	12692	71	25F
0005433929602	12692	72	27D
0005434022920	12692	73	27E
0005433057755	12692	74	27G
0005433057757	12692	75	27F
0005433057773	12692	76	27H
0005434022787	12692	77	28A
0005433929601	12692	78	28B
0005434022979	12692	79	28E
0005433057767	12692	80	28D
0005433057780	12692	81	28G
0005433057749	12692	82	28H
0005434022892	12692	83	29B
0005432156354	12692	84	29E
0005434023032	12692	85	29F
0005434022760	12692	86	29G
0005434022687	12692	87	30D
0005433057779	12692	88	30B
0005434023232	12692	89	30H
0005434022963	12692	90	31A
0005434022782	12692	91	31D
0005432156351	12692	92	31F
0005434023081	12692	93	31G
0005434022656	12692	94	31H
0005433057770	12692	95	32D
0005434735672	12692	96	32B
0005434735673	12692	97	32F
0005433057772	12692	98	32E
0005434022986	12692	99	32H
0005433929600	12692	100	33G
0005434022840	12692	101	33F
0005434028262	12692	102	34A
0005432157486	12692	103	34D
0005433057764	12692	104	34F
0005433684414	12692	105	34E
0005432156350	12692	106	34G
0005432156352	12692	107	35A
0005433057766	12692	108	35D
0005433684415	12692	109	36B
0005434022923	12692	110	36E
0005433057762	12692	111	36F
0005433057743	12692	112	36G
0005434022781	12692	113	37E
0005433057744	12692	114	37F
0005434023021	12692	115	37H
0005434023197	12692	116	38A
0005434028273	12692	117	38E
0005433057750	12692	118	38F
0005433529260	13814	1	1C
0005433529252	13814	2	2D
0005433529253	13814	3	4C
0005433527244	13814	4	4F
0005433529255	13814	5	6C
0005433527247	13814	6	6F
0005433527253	13814	7	7D
0005433527251	13814	8	8B
0005433527243	13814	9	8F
0005433527241	13814	10	8E
0005433527242	13814	11	9A
0005433527252	13814	12	9F
0005433529261	13814	13	10B
0005433529262	13814	14	10D
0005433529257	13814	15	12E
0005433529250	13814	16	13E
0005433529263	13814	17	13D
0005433529249	13814	18	14A
0005433529264	13814	19	14F
0005433527249	13814	20	14E
0005433527250	13814	21	16D
0005433527239	13814	22	17D
0005433529254	13814	23	17E
0005433527246	13814	24	18B
0005433529258	13814	25	18A
0005433529259	13814	26	19B
0005433527240	13814	27	19F
0005433527248	13814	28	20D
0005433529251	13814	29	20C
0005433527245	13814	30	21B
0005433529256	13814	31	20F
0005433529220	32448	1	4D
0005433533275	32448	2	5C
0005433529219	32448	3	6B
0005433533248	32448	4	6D
0005433529213	32448	5	7E
0005433529222	32448	6	8C
0005433529227	32448	7	8D
0005433533249	32448	8	8E
0005433529226	32448	9	9B
0005433533270	32448	10	9D
0005433529211	32448	11	9E
0005433533274	32448	12	10C
0005433529221	32448	13	11B
0005433529214	32448	14	12B
0005433533261	32448	15	12C
0005433529218	32448	16	12D
0005433529212	32448	17	13B
0005433529244	32448	18	14E
0005433533250	32448	19	15F
0005433529217	32448	20	16E
0005433533254	32448	21	17A
0005433533247	32448	22	17C
0005433533260	32448	23	17F
0005433533251	32448	24	19C
0005433533253	32448	25	19E
0005433533252	32448	26	20B
0005433533262	32448	27	21F
0005433923009	2130	1	1A
0005433923022	2130	2	1C
0005433922997	2130	3	1B
0005433035631	2130	4	1F
0005433035672	2130	5	1H
0005433923025	2130	6	2B
0005433922963	2130	7	2G
0005433923039	2130	8	2F
0005433923042	2130	9	3A
0005433922999	2130	10	2H
0005433922974	2130	11	4A
0005432231530	2130	12	4G
0005433929600	2130	13	4F
0005433923008	2130	14	4H
0005434028274	2130	15	5B
0005433922996	2130	16	5A
0005433923019	2130	17	5F
0005433923053	2130	18	5C
0005433923018	2130	19	5G
0005433923021	2130	20	9A
0005433922984	2130	21	5H
0005433922986	2130	22	9B
0005432044516	2130	23	9H
0005433922983	2130	24	9G
0005432231528	2130	25	11A
0005433923027	2130	26	11E
0005433922981	2130	27	11D
0005433923052	2130	28	11F
0005433929601	2130	29	11H
0005433923012	2130	30	11G
0005433923010	2130	31	12A
0005433035632	2130	32	12E
0005433035635	2130	33	12F
0005433929602	2130	34	12H
0005433922994	2130	35	12G
0005433922966	2130	36	13D
0005433035792	2130	37	13B
0005433035677	2130	38	13E
0005433922967	2130	39	13F
0005433035710	2130	40	13H
0005433923055	2130	41	13G
0005433923034	2130	42	14B
0005433931458	2130	43	14D
0005433922992	2130	44	14F
0005432231527	2130	45	14G
0005433923013	2130	46	14H
0005433922995	2130	47	15A
0005433923037	2130	48	15D
0005433923028	2130	49	15G
0005433035475	2130	50	16A
0005432044517	2130	51	16B
0005433923007	2130	52	16E
0005433922989	2130	53	16D
0005433923035	2130	54	16H
0005433923003	2130	55	17B
0005433923056	2130	56	17A
0005433923029	2130	57	17F
0005433035694	2130	58	17E
0005433035720	2130	59	17G
0005433922998	2130	60	18B
0005433922975	2130	61	18A
0005433035681	2130	62	18D
0005433035896	2130	63	18E
0005433922987	2130	64	18G
0005432231534	2130	65	18F
0005433923014	2130	66	19A
0005433931457	2130	67	18H
0005433923033	2130	68	19B
0005433923006	2130	69	19F
0005433923001	2130	70	19H
0005433923016	2130	71	19G
0005433923048	2130	72	20A
0005433035634	2130	73	20D
0005433922982	2130	74	20B
0005433923054	2130	75	20E
0005433923049	2130	76	20H
0005433923041	2130	77	20G
0005433035879	2130	78	21A
0005433922973	2130	79	21D
0005433923017	2130	80	21F
0005433035671	2130	81	21H
0005433035556	2130	82	21G
0005433923036	2130	83	22A
0005433035778	2130	84	22D
0005433923059	2130	85	22B
0005433922978	2130	86	22E
0005433035713	2130	87	22G
0005433922964	2130	88	22F
0005432231531	2130	89	22H
0005433922971	2130	90	23B
0005432231535	2130	91	23A
0005433923038	2130	92	23E
0005433035702	2130	93	23D
0005433875371	2130	94	23G
0005432044515	2130	95	24B
0005433035730	2130	96	24D
0005433923044	2130	97	24E
0005433923046	2130	98	24H
0005433923015	2130	99	24G
0005433035739	2130	100	25D
0005433035878	2130	101	25E
0005433922969	2130	102	27A
0005433035895	2130	103	27D
0005433922988	2130	104	27G
0005433922970	2130	105	28B
0005433923020	2130	106	28E
0005433923032	2130	107	28D
0005433035370	2130	108	28F
0005433923058	2130	109	28G
0005433035590	2130	110	29A
0005433931456	2130	111	29D
0005433922980	2130	112	29B
0005433922993	2130	113	29F
0005434028273	2130	114	29H
0005433922991	2130	115	30B
0005433923040	2130	116	30A
0005432231532	2130	117	30D
0005432749755	2130	118	30E
0005433923023	2130	119	30G
0005433923045	2130	120	30H
0005433035371	2130	121	31B
0005433922968	2130	122	31A
0005433922962	2130	123	31E
0005433923031	2130	124	31D
0005433035692	2130	125	31F
0005433922965	2130	126	32A
0005433931459	2130	127	31H
0005433035700	2130	128	32B
0005433923051	2130	129	32E
0005433035712	2130	130	32D
0005433922972	2130	131	32F
0005433035633	2130	132	32G
0005433923002	2130	133	32H
0005433035777	2130	134	33E
0005432749756	2130	135	33D
0005432231536	2130	136	33G
0005432749759	2130	137	33H
0005433922990	2130	138	34B
0005433923004	2130	139	34A
0005433035693	2130	140	34D
0005433922976	2130	141	34F
0005433035731	2130	142	34G
0005433923047	2130	143	34H
0005433923030	2130	144	35B
0005433923050	2130	145	35A
0005433922979	2130	146	35D
0005433922985	2130	147	35F
0005433923024	2130	148	35E
0005433923000	2130	149	36A
0005433035369	2130	150	35H
0005433923011	2130	151	36B
0005433035701	2130	152	36E
0005432749751	2130	153	36D
0005433035622	2130	154	36H
0005432231529	2130	155	36G
0005433923043	2130	156	37A
0005433922977	2130	157	37E
0005434028262	2130	158	37G
0005433035538	2130	159	37H
0005433035690	2130	160	38B
0005433923057	2130	161	38E
0005433923026	2130	162	38H
0005433923005	2130	163	39E
0005432231533	2130	164	39F
0005433036114	24086	1	1B
0005433036127	24086	2	1F
0005432206181	24086	3	1H
0005433036160	24086	4	2B
0005433036119	24086	5	2C
0005433922291	24086	6	2G
0005433922543	24086	7	3A
0005433922032	24086	8	2H
0005433922061	24086	9	3B
0005433922607	24086	10	3G
0005433036152	24086	11	3F
0005433036146	24086	12	4A
0005433922129	24086	13	4F
0005433922134	24086	14	5A
0005433036139	24086	15	5B
0005433921799	24086	16	5C
0005433922268	24086	17	5H
0005433922055	24086	18	5G
0005433036143	24086	19	9B
0005433922359	24086	20	9A
0005433921798	24086	21	9H
0005433922457	24086	22	9G
0005433921923	24086	23	11A
0005433922254	24086	24	11B
0005433922324	24086	25	11E
0005433036163	24086	26	11D
0005433036162	24086	27	11G
0005432206182	24086	28	11F
0005433922423	24086	29	11H
0005433921998	24086	30	12B
0005433036154	24086	31	12E
0005433036122	24086	32	12D
0005433036155	24086	33	12G
0005434028289	24086	34	12F
0005433922256	24086	35	12H
0005433921758	24086	36	13B
0005433922358	24086	37	13A
0005433922058	24086	38	13D
0005433922200	24086	39	13E
0005433036150	24086	40	13F
0005434028288	24086	41	13H
0005433922489	24086	42	13G
0005433922133	24086	43	14B
0005433036149	24086	44	14D
0005432206177	24086	45	14F
0005433922255	24086	46	14E
0005433922231	24086	47	14G
0005433036131	24086	48	15A
0005433922164	24086	49	14H
0005433036142	24086	50	15B
0005433922162	24086	51	15D
0005433036159	24086	52	15G
0005434028290	24086	53	16B
0005433929555	24086	54	16A
0005433921955	24086	55	16D
0005433922347	24086	56	16E
0005432749778	24086	57	16G
0005433036121	24086	58	16F
0005433036140	24086	59	16H
0005433922045	24086	60	17D
0005433922353	24086	61	17B
0005433922416	24086	62	17E
0005433036164	24086	63	17G
0005433922203	24086	64	17F
0005433922015	24086	65	17H
0005433922053	24086	66	18B
0005433922204	24086	67	18E
0005433036145	24086	68	18G
0005433921922	24086	69	18F
0005433922233	24086	70	19A
0005433922577	24086	71	18H
0005433922541	24086	72	19E
0005433036151	24086	73	19D
0005433922079	24086	74	19F
0005433921743	24086	75	20A
0005433921999	24086	76	19H
0005433922183	24086	77	20B
0005433922711	24086	78	20D
0005433922014	24086	79	20G
0005432206176	24086	80	21A
0005433036148	24086	81	21B
0005432207654	24086	82	21E
0005433922046	24086	83	21F
0005433922160	24086	84	21H
0005433036165	24086	85	21G
0005434028291	24086	86	22A
0005433036153	24086	87	22D
0005433922132	24086	88	22B
0005432206178	24086	89	22E
0005433922163	24086	90	22G
0005432206179	24086	91	22F
0005433922212	24086	92	22H
0005433922604	24086	93	23B
0005433036126	24086	94	23E
0005432206180	24086	95	23F
0005432207656	24086	96	23G
0005433922516	24086	97	23H
0005433036120	24086	98	24A
0005433922135	24086	99	24D
0005433922346	24086	100	24F
0005433922080	24086	101	24E
0005433875358	24086	102	24G
0005433922232	24086	103	25E
0005433036117	24086	104	25D
0005433036156	24086	105	27A
0005433922257	24086	106	25F
0005432749780	24086	107	27B
0005433036147	24086	108	27E
0005433922182	24086	109	27D
0005433036125	24086	110	28A
0005433922426	24086	111	28B
0005433922427	24086	112	28D
0005433922060	24086	113	28F
0005433922235	24086	114	28G
0005432207655	24086	115	29A
0005433036138	24086	116	29D
0005433922000	24086	117	29B
0005433036129	24086	118	29E
0005433922146	24086	119	29G
0005433922205	24086	120	29F
0005433922236	24086	121	30A
0005433922542	24086	122	29H
0005433922189	24086	123	30B
0005433036135	24086	124	30G
0005433036123	24086	125	30H
0005433921718	24086	126	31B
0005433921927	24086	127	31A
0005433922344	24086	128	31D
0005433922224	24086	129	31H
0005433036128	24086	130	31G
0005433922275	24086	131	32A
0005433921831	24086	132	32D
0005433875360	24086	133	32B
0005433922415	24086	134	32E
0005433921685	24086	135	32F
0005433036137	24086	136	32G
0005433036157	24086	137	33A
0005433922029	24086	138	32H
0005433922104	24086	139	33E
0005433921924	24086	140	33F
0005433922130	24086	141	33H
0005433036136	24086	142	33G
0005433036134	24086	143	34A
0005433922230	24086	144	34D
0005433922167	24086	145	34B
0005433921834	24086	146	34E
0005433036118	24086	147	34G
0005433922031	24086	148	34F
0005433036144	24086	149	35A
0005433922458	24086	150	34H
0005433921941	24086	151	35B
0005433922412	24086	152	35D
0005433922305	24086	153	35F
0005433922030	24086	154	35E
0005433036133	24086	155	35G
0005433922084	24086	156	35H
0005433036158	24086	157	36B
0005433036124	24086	158	36D
0005433922201	24086	159	36F
0005433036141	24086	160	36E
0005433036130	24086	161	36G
0005433922515	24086	162	37B
0005433036115	24086	163	37E
0005433921930	24086	164	37H
0005432749779	24086	165	37G
0005433036132	24086	166	38A
0005433922578	24086	167	38G
0005433922161	24086	168	38F
0005433036161	24086	169	38H
0005433036116	24086	170	39D
0005433922234	24086	171	39E
0005434725077	282	1	1C
0005434725105	282	2	1G
0005433233218	282	3	1D
0005433180800	282	4	1K
0005433233566	282	5	1H
0005434725164	282	6	2D
0005434725060	282	7	2C
0005434725145	282	8	2A
0005434302861	282	9	2H
0005433766592	282	10	2G
0005433233351	282	11	3A
0005433233660	282	12	2K
0005432277763	282	13	3C
0005433233228	282	14	3K
0005434725146	282	15	3H
0005435142531	282	16	3G
0005432277772	282	17	4C
0005434725084	282	18	4A
0005434551055	282	19	4G
0005434725144	282	20	4D
0005434735671	282	21	4K
0005434551057	282	22	4H
0005433233365	282	23	5C
0005433233510	282	24	5A
0005434725121	282	25	5H
0005434551093	282	26	11A
0005434725117	282	27	5K
0005434725135	282	28	11D
0005434725062	282	29	11C
0005433113505	282	30	11F
0005433180852	282	31	11H
0005433180880	282	32	11G
0005433233258	282	33	12C
0005434725111	282	34	12A
0005434725101	282	35	11K
0005434302445	282	36	12D
0005433233556	282	37	12G
0005433289786	282	38	12K
0005434725054	282	39	12H
0005433766596	282	40	13D
0005434551061	282	41	13C
0005433233360	282	42	13A
0005435142539	282	43	13F
0005434551069	282	44	13E
0005433180858	282	45	13K
0005434551074	282	46	13H
0005434725074	282	47	13G
0005435142542	282	48	14A
0005435142538	282	49	14D
0005432277771	282	50	14G
0005434725048	282	51	14F
0005434725113	282	52	14E
0005434725100	282	53	14K
0005433289776	282	54	14H
0005433233430	282	55	15A
0005434725081	282	56	15E
0005434551050	282	57	15D
0005434725158	282	58	15H
0005433180792	282	59	15G
0005433180730	282	60	15F
0005432277764	282	61	16A
0005432277769	282	62	16D
0005433131628	282	63	16C
0005433180783	282	64	16G
0005434551051	282	65	16F
0005434725096	282	66	16E
0005434725123	282	67	16H
0005434725057	282	68	17C
0005433233839	282	69	17A
0005433233222	282	70	16K
0005434551068	282	71	17E
0005434725140	282	72	17D
0005434735669	282	73	17G
0005434725147	282	74	17F
0005434725139	282	75	18A
0005434551092	282	76	17K
0005433233405	282	77	17H
0005432277762	282	78	18B
0005434725136	282	79	18E
0005433233688	282	80	18D
0005434725045	282	81	18C
0005433233219	282	82	18F
0005434725076	282	83	18J
0005434725093	282	84	18H
0005435142532	282	85	19B
0005434725114	282	86	19A
0005433766599	282	87	18K
0005433233428	282	88	19D
0005434551076	282	89	19C
0005434725090	282	90	19F
0005434551073	282	91	19E
0005433233602	282	92	19H
0005434302862	282	93	19K
0005434725131	282	94	19J
0005434725051	282	95	20C
0005434725166	282	96	20B
0005433180723	282	97	20A
0005434551045	282	98	20E
0005434031967	282	99	20D
0005433233285	282	100	20G
0005434725159	282	101	20K
0005434031961	282	102	20J
0005433180780	282	103	20H
0005434725075	282	104	21B
0005434725127	282	105	21A
0005434725167	282	106	21D
0005434551067	282	107	21C
0005434725132	282	108	21F
0005433233672	282	109	21E
0005433233163	282	110	21H
0005434551059	282	111	22A
0005434725089	282	112	21K
0005434551047	282	113	21J
0005434725141	282	114	22D
0005433113500	282	115	22C
0005434302444	282	116	22B
0005434725110	282	117	22E
0005434725129	282	118	22F
0005434551071	282	119	22J
0005433233590	282	120	22H
0005434725160	282	121	23B
0005434725118	282	122	23A
0005434725154	282	123	23D
0005434725155	282	124	23C
0005434551083	282	125	23G
0005433180749	282	126	23F
0005433233396	282	127	23E
0005434735667	282	128	23J
0005433233568	282	129	23H
0005434725072	282	130	24D
0005434725052	282	131	23K
0005434725092	282	132	24F
0005434725082	282	133	24E
0005434725163	282	134	25A
0005434731155	282	135	24G
0005434551095	282	136	25C
0005433233678	282	137	25B
0005434725149	282	138	25E
0005434725098	282	139	25D
0005434551052	282	140	25H
0005434725079	282	141	25G
0005434725085	282	142	25F
0005433233401	282	143	25K
0005433233709	282	144	25J
0005434725161	282	145	26C
0005434725112	282	146	26E
0005434725128	282	147	26D
0005433233354	282	148	26G
0005433233419	282	149	26F
0005433233129	282	150	26J
0005433233340	282	151	26H
0005433233350	282	152	27B
0005433233397	282	153	26K
0005433180782	282	154	27D
0005433233589	282	155	27C
0005433233229	282	156	27F
0005433233435	282	157	27E
0005432277766	282	158	27H
0005434551072	282	159	27G
0005432277775	282	160	28A
0005434725087	282	161	27K
0005434725086	282	162	28C
0005432277770	282	163	28B
0005434735666	282	164	28E
0005434725137	282	165	28G
0005434551064	282	166	28F
0005433180850	282	167	28J
0005433126779	282	168	29A
0005434302860	282	169	29D
0005434725130	282	170	29C
0005433126791	282	171	29F
0005433180849	282	172	29E
0005433126787	282	173	29H
0005434725142	282	174	29G
0005434725094	282	175	30A
0005433233220	282	176	29K
0005434725156	282	177	29J
0005434551066	282	178	30C
0005434735668	282	179	30E
0005433131646	282	180	30D
0005433233420	282	181	30H
0005434551098	282	182	30G
0005432277768	282	183	30F
0005434551049	282	184	30J
0005433233286	282	185	31A
0005434725115	282	186	30K
0005433233522	282	187	31D
0005433111482	282	188	31C
0005434725065	282	189	31B
0005433289756	282	190	31F
0005434725050	282	191	31E
0005434551058	282	192	31H
0005434551075	282	193	31G
0005433233353	282	194	31K
0005434725133	282	195	31J
0005434731152	282	196	32C
0005434551085	282	197	32B
0005433131647	282	198	32A
0005433233551	282	199	32D
0005434725124	282	200	32H
0005433233710	282	201	32G
0005433233356	282	202	32F
0005434551048	282	203	32K
0005433180801	282	204	33A
0005434551060	282	205	33D
0005433766598	282	206	33E
0005433113507	282	207	33H
0005434551080	282	208	33G
0005434725157	282	209	33K
0005434031969	282	210	33J
0005433180882	282	211	34B
0005434725168	282	212	34A
0005434551046	282	213	34E
0005433233357	282	214	34D
0005433233260	282	215	34C
0005432277765	282	216	34G
0005434551089	282	217	34F
0005433233257	282	218	34K
0005434551063	282	219	34J
0005434551053	282	220	34H
0005434725069	282	221	35B
0005433180816	282	222	35A
0005433126778	282	223	35D
0005433233427	282	224	35C
0005434725116	282	225	35G
0005433233458	282	226	35F
0005434725083	282	227	35E
0005434551056	282	228	35H
0005432277767	282	229	35K
0005433233352	282	230	35J
0005435142540	282	231	36C
0005434551044	282	232	36B
0005434725106	282	233	36E
0005433233567	282	234	36D
0005434551070	282	235	36H
0005434031971	282	236	36G
0005434725152	282	237	36F
0005434551077	282	238	36K
0005433180898	282	239	36J
0005433233341	282	240	37B
0005435142536	282	241	37A
0005434725047	282	242	37E
0005434725150	282	243	37D
0005434725063	282	244	37C
0005434725125	282	245	37F
0005433233547	282	246	37J
0005434551062	282	247	37H
0005434551082	282	248	38A
0005433180851	282	249	37K
0005434725104	282	250	38C
0005434725103	282	251	38B
0005433233402	282	252	38J
0005434551065	282	253	38H
0005435142537	282	254	39B
0005433233509	282	255	38K
0005433131648	282	256	39D
0005434725046	282	257	39C
0005433180779	282	258	39F
0005434551097	282	259	39E
0005435142533	282	260	39H
0005433233596	282	261	39G
0005434725091	282	262	39K
0005434725097	282	263	39J
0005434725058	282	264	40C
0005434031957	282	265	40B
0005433233281	282	266	40E
0005433180853	282	267	40D
0005434725109	282	268	40H
0005434725070	282	269	40G
0005434725134	282	270	40F
0005434725102	282	271	40K
0005434551088	282	272	40J
0005434302447	282	273	41B
0005433180881	282	274	41A
0005434725151	282	275	41D
0005432277761	282	276	41C
0005434725099	282	277	41G
0005434725068	282	278	41F
0005434725143	282	279	41E
0005434551091	282	280	41J
0005434725153	282	281	41H
0005433180899	282	282	42A
0005433766591	282	283	41K
0005434725122	282	284	42E
0005434725073	282	285	42D
0005434551096	282	286	42C
0005434725148	282	287	42G
0005434725064	282	288	42F
0005434725126	282	289	42K
0005433233221	282	290	42J
0005433233687	282	291	42H
0005432277774	282	292	43A
0005435142530	282	293	43C
0005434725120	282	294	43F
0005434725053	282	295	43D
0005434725119	282	296	43H
0005433180833	282	297	43K
0005434731154	282	298	44C
0005434725071	282	299	44B
0005433233174	282	300	44A
0005434725078	282	301	44E
0005434725095	282	302	44D
0005434725055	282	303	44G
0005433233261	282	304	44F
0005435142534	282	305	44J
0005433233603	282	306	44H
0005434725049	282	307	45A
0005434725138	282	308	44K
0005434725108	282	309	45D
0005434725066	282	310	45B
0005434551054	282	311	45F
0005433233318	282	312	45E
0005433180750	282	313	45H
0005434725107	282	314	45G
0005434551078	282	315	46A
0005433233198	282	316	45K
0005434551094	282	317	45J
0005434725080	282	318	46C
0005433126801	282	319	46B
0005434551086	282	320	46D
0005433289777	282	321	46G
0005433126786	282	322	46F
0005434731153	282	323	46J
0005433180857	282	324	47C
0005433233423	282	325	47A
0005434725162	282	326	46K
0005434302446	282	327	47E
0005434725067	282	328	47D
0005434725165	282	329	47G
0005433233364	282	330	47F
0005433233595	282	331	48A
0005435142541	282	332	47K
0005434725056	282	333	47H
0005434735670	282	334	48D
0005434551084	282	335	48C
0005433233276	282	336	48E
0005434551079	282	337	48H
0005435142535	282	338	48G
0005433233588	282	339	49D
0005433233359	282	340	49C
0005434551081	282	341	49G
0005433233355	282	342	49F
0005433233456	282	343	49E
0005432277773	282	344	49H
0005434551090	282	345	50C
0005434551087	282	346	50A
0005434725061	282	347	49K
0005433233838	282	348	50E
0005433126800	282	349	50D
0005434725059	282	350	50G
0005433233462	282	351	50K
0005434725088	282	352	50H
0005434302859	282	353	51E
0005433233406	282	354	51D
0005433113506	282	355	51G
0005434550442	9862	1	1A
0005435142427	9862	2	1D
0005434723989	9862	3	2A
0005434724175	9862	4	1H
0005433233995	9862	5	2C
0005433234038	9862	6	2H
0005434723720	9862	7	2G
0005434724377	9862	8	3A
0005434724531	9862	9	2K
0005434724028	9862	10	3D
0005433233997	9862	11	3C
0005433234009	9862	12	3H
0005434731122	9862	13	4C
0005434550594	9862	14	4A
0005434731107	9862	15	3K
0005433234024	9862	16	4G
0005433234000	9862	17	4D
0005434731125	9862	18	5A
0005433181017	9862	19	4K
0005433289821	9862	20	4H
0005433181023	9862	21	5C
0005433233998	9862	22	5H
0005434550548	9862	23	11A
0005434724490	9862	24	5K
0005433234008	9862	25	11E
0005434550755	9862	26	11D
0005433234017	9862	27	11G
0005434724208	9862	28	11F
0005434550541	9862	29	11K
0005433234015	9862	30	11H
0005433233989	9862	31	12C
0005434550611	9862	32	12A
0005433234006	9862	33	12G
0005434550727	9862	34	13A
0005433126830	9862	35	12K
0005433181025	9862	36	13D
0005434723994	9862	37	13F
0005435142402	9862	38	13H
0005433181035	9862	39	14A
0005434550402	9862	40	13K
0005434724062	9862	41	14D
0005433234020	9862	42	14G
0005433234007	9862	43	14E
0005433233985	9862	44	14H
0005434723545	9862	45	15C
0005434724155	9862	46	15E
0005433233983	9862	47	15D
0005434302403	9862	48	15K
0005433289825	9862	49	15H
0005432199224	9862	50	16D
0005433289820	9862	51	16C
0005434724259	9862	52	16E
0005434723623	9862	53	16G
0005433234002	9862	54	17C
0005433181012	9862	55	17A
0005434724278	9862	56	17E
0005434724040	9862	57	17D
0005434723408	9862	58	17G
0005434724218	9862	59	17F
0005433181020	9862	60	17K
0005433181013	9862	61	18B
0005434724203	9862	62	18A
0005434724346	9862	63	18E
0005434724170	9862	64	18D
0005434724137	9862	65	18G
0005433181015	9862	66	18F
0005433129262	9862	67	18K
0005434723648	9862	68	19B
0005434550453	9862	69	19A
0005434724057	9862	70	19D
0005434724177	9862	71	19F
0005434723991	9862	72	19E
0005433233991	9862	73	19H
0005434724336	9862	74	20A
0005434724239	9862	75	19K
0005434724285	9862	76	19J
0005434550425	9862	77	20B
0005434550706	9862	78	20E
0005433233996	9862	79	20D
0005433181033	9862	80	20C
0005433233990	9862	81	20F
0005433289823	9862	82	20J
0005433181029	9862	83	20H
0005434723885	9862	84	21B
0005433126833	9862	85	21A
0005433289826	9862	86	21D
0005435142384	9862	87	21C
0005434724240	9862	88	21F
0005433234018	9862	89	21E
0005434735629	9862	90	21J
0005434032010	9862	91	21H
0005434550873	9862	92	21G
0005434723911	9862	93	22A
0005433233993	9862	94	21K
0005434723888	9862	95	22C
0005434550551	9862	96	22D
0005434724139	9862	97	22H
0005434724012	9862	98	22G
0005433181027	9862	99	22F
0005434550609	9862	100	22J
0005434724128	9862	101	23B
0005433234031	9862	102	23A
0005433181028	9862	103	23D
0005433234044	9862	104	23C
0005433181026	9862	105	23E
0005434724484	9862	106	23J
0005434550651	9862	107	23H
0005434550695	9862	108	23G
0005434723917	9862	109	24D
0005434723600	9862	110	23K
0005433233999	9862	111	24F
0005433289827	9862	112	25A
0005434731118	9862	113	25C
0005433181021	9862	114	25F
0005433234030	9862	115	25D
0005434032013	9862	116	25H
0005434550440	9862	117	25G
0005433234001	9862	118	25J
0005434550385	9862	119	26C
0005433234042	9862	120	26B
0005433234025	9862	121	26A
0005435142369	9862	122	26E
0005433126834	9862	123	26D
0005434735631	9862	124	26G
0005433233988	9862	125	26J
0005434550610	9862	126	26H
0005434550636	9862	127	27A
0005434723948	9862	128	26K
0005433234034	9862	129	27D
0005434724206	9862	130	27C
0005433234040	9862	131	27B
0005434724173	9862	132	27F
0005434550489	9862	133	27E
0005433234013	9862	134	27H
0005433234021	9862	135	28A
0005434724277	9862	136	27K
0005434723828	9862	137	27J
0005434724174	9862	138	28B
0005433181014	9862	139	28C
0005433234028	9862	140	28J
0005434735602	9862	141	28H
0005434724138	9862	142	29A
0005434731126	9862	143	29D
0005433766630	9862	144	29C
0005434550534	9862	145	29B
0005434724286	9862	146	29E
0005434724607	9862	147	30A
0005434724396	9862	148	29K
0005434550356	9862	149	29J
0005434550705	9862	150	30B
0005434550533	9862	151	30E
0005434550452	9862	152	30D
0005434723621	9862	153	30C
0005434724004	9862	154	30G
0005434550650	9862	155	30J
0005433234026	9862	156	30H
0005434723967	9862	157	31B
0005433234033	9862	158	31D
0005434723972	9862	159	31C
0005432199225	9862	160	31G
0005433234029	9862	161	31E
0005434724179	9862	162	31H
0005434724470	9862	163	31K
0005434724089	9862	164	31J
0005433234005	9862	165	32C
0005434724236	9862	166	32B
0005434724258	9862	167	32A
0005434724467	9862	168	32E
0005434731138	9862	169	32D
0005435142426	9862	170	32G
0005434724445	9862	171	32F
0005434550696	9862	172	32K
0005433181019	9862	173	32J
0005434723771	9862	174	33A
0005434723620	9862	175	33D
0005434724204	9862	176	33C
0005434723854	9862	177	33F
0005434550726	9862	178	33J
0005434724599	9862	179	33H
0005434550437	9862	180	33G
0005434723546	9862	181	34C
0005434723566	9862	182	34B
0005433234016	9862	183	34A
0005434723999	9862	184	34D
0005434724337	9862	185	34H
0005433126829	9862	186	34G
0005433181022	9862	187	34F
0005434723804	9862	188	34K
0005433234011	9862	189	35B
0005433766629	9862	190	35A
0005434723889	9862	191	35C
0005433233986	9862	192	35F
0005433233987	9862	193	35E
0005434723910	9862	194	35H
0005433234010	9862	195	35G
0005434550704	9862	196	36A
0005433129260	9862	197	35K
0005433234035	9862	198	35J
0005434302402	9862	199	36C
0005434550436	9862	200	36E
0005434723998	9862	201	36H
0005433234023	9862	202	36G
0005433234045	9862	203	36F
0005434550545	9862	204	36K
0005434723844	9862	205	36J
0005434723715	9862	206	37B
0005434302400	9862	207	37A
0005434724241	9862	208	37D
0005434723624	9862	209	37C
0005433234039	9862	210	37F
0005434302399	9862	211	37G
0005433181024	9862	212	37K
0005434723873	9862	213	37J
0005434032012	9862	214	38C
0005434550454	9862	215	38A
0005434550546	9862	216	38J
0005434550467	9862	217	38H
0005434550475	9862	218	39A
0005433129261	9862	219	39D
0005433234037	9862	220	39C
0005433234012	9862	221	39B
0005434724207	9862	222	39F
0005434724257	9862	223	39E
0005434723837	9862	224	39H
0005434723599	9862	225	39G
0005433181031	9862	226	40A
0005433234036	9862	227	39K
0005434724148	9862	228	39J
0005434032011	9862	229	40C
0005434302381	9862	230	40B
0005434723532	9862	231	40E
0005434724172	9862	232	40D
0005435142432	9862	233	40F
0005434731127	9862	234	40K
0005434723976	9862	235	40J
0005433129263	9862	236	40H
0005434735632	9862	237	41A
0005434550649	9862	238	41D
0005434723973	9862	239	41C
0005435142392	9862	240	41G
0005433181018	9862	241	41H
0005434550535	9862	242	41K
0005432199229	9862	243	41J
0005433181011	9862	244	42C
0005433234004	9862	245	42B
0005434723587	9862	246	42E
0005433234043	9862	247	42D
0005434550593	9862	248	42G
0005432199226	9862	249	42F
0005433234041	9862	250	42K
0005434724345	9862	251	42J
0005434550431	9862	252	43A
0005434550466	9862	253	43D
0005433766628	9862	254	43C
0005433234014	9862	255	43B
0005433181034	9862	256	43E
0005433289822	9862	257	43H
0005434550679	9862	258	43K
0005433126832	9862	259	43J
0005433233994	9862	260	44C
0005434723886	9862	261	44B
0005433233984	9862	262	44H
0005434550510	9862	263	44G
0005434550741	9862	264	44F
0005434724661	9862	265	45A
0005433181032	9862	266	44K
0005434724397	9862	267	45D
0005434724145	9862	268	45C
0005435142357	9862	269	45F
0005433126831	9862	270	45E
0005434724176	9862	271	45H
0005432199223	9862	272	45G
0005433289824	9862	273	45K
0005433234027	9862	274	45J
0005435142364	9862	275	46C
0005433234022	9862	276	46B
0005434723698	9862	277	46E
0005434550441	9862	278	46D
0005434723988	9862	279	46G
0005434724378	9862	280	46H
0005434724573	9862	281	47C
0005434724662	9862	282	47A
0005434724008	9862	283	46K
0005432199228	9862	284	47G
0005433234046	9862	285	47F
0005434724314	9862	286	47K
0005433234003	9862	287	47H
0005434723872	9862	288	48E
0005434550433	9862	289	48H
0005433234019	9862	290	48G
0005432199227	9862	291	48K
0005433181016	9862	292	49D
0005434550403	9862	293	49C
0005434723753	9862	294	49F
0005433113529	9862	295	49H
0005435142393	9862	296	50C
0005434724379	9862	297	50E
0005434723853	9862	298	50D
0005433233992	9862	299	50G
0005435142412	9862	300	50F
0005434550487	9862	301	51D
0005434550540	9862	302	50K
0005433181030	9862	303	50H
0005434724280	9862	304	51F
0005433234032	9862	305	51E
0005434550604	9862	306	51G
0005432527643	7769	1	1D
0005435725545	7769	2	1C
0005434067321	7769	3	1G
0005432527590	7769	4	1K
0005432527600	7769	5	2C
0005435212469	7769	6	2G
0005434067328	7769	7	3A
0005435212716	7769	8	2K
0005432527596	7769	9	3D
0005432527541	7769	10	3C
0005432527540	7769	11	3H
0005432527606	7769	12	4C
0005432527551	7769	13	4A
0005434067322	7769	14	4G
0005434067366	7769	15	4D
0005432527529	7769	16	4K
0005432527537	7769	17	4H
0005434067341	7769	18	5D
0005434067312	7769	19	5C
0005435212677	7769	20	5A
0005432527571	7769	21	5G
0005435212840	7769	22	5K
0005432527602	7769	23	11D
0005435213151	7769	24	11C
0005435213005	7769	25	11F
0005432527538	7769	26	11H
0005434067334	7769	27	11G
0005432527615	7769	28	12C
0005432069612	7769	29	12A
0005434067325	7769	30	11K
0005434067365	7769	31	12E
0005432527545	7769	32	12D
0005435212720	7769	33	12H
0005432527638	7769	34	12F
0005432527562	7769	35	13A
0005432527539	7769	36	12K
0005432527526	7769	37	13C
0005434067332	7769	38	13F
0005434067352	7769	39	13E
0005432527593	7769	40	13D
0005434067329	7769	41	13G
0005435212820	7769	42	14A
0005432535818	7769	43	13K
0005434067330	7769	44	14D
0005434067380	7769	45	14C
0005432535820	7769	46	14G
0005432527574	7769	47	14F
0005435212893	7769	48	14K
0005434067353	7769	49	14H
0005434067317	7769	50	15C
0005434067344	7769	51	15A
0005432527635	7769	52	15D
0005434067315	7769	53	15G
0005432527565	7769	54	15F
0005434067348	7769	55	16A
0005435725522	7769	56	15K
0005432527560	7769	57	15H
0005432527613	7769	58	16D
0005435212807	7769	59	16C
0005434067331	7769	60	16E
0005432527575	7769	61	16K
0005435630932	7769	62	16H
0005432527522	7769	63	17E
0005432533284	7769	64	17D
0005435212749	7769	65	17C
0005435212741	7769	66	17G
0005434067333	7769	67	17F
0005432535821	7769	68	18A
0005434067357	7769	69	17K
0005435212454	7769	70	17H
0005432527644	7769	71	18C
0005435212499	7769	72	18B
0005434067360	7769	73	18E
0005432527616	7769	74	18D
0005432150168	7769	75	18F
0005432527548	7769	76	19A
0005435212721	7769	77	18K
0005435212631	7769	78	19D
0005434067375	7769	79	19G
0005432069610	7769	80	19F
0005432527612	7769	81	19E
0005434067374	7769	82	19H
0005434067356	7769	83	20A
0005432527557	7769	84	19K
0005434067316	7769	85	19J
0005435212616	7769	86	20C
0005435212915	7769	87	20B
0005432527520	7769	88	20E
0005432527516	7769	89	20D
0005432527598	7769	90	20H
0005432527561	7769	91	20G
0005432069608	7769	92	20F
0005432527605	7769	93	21A
0005432527618	7769	94	20K
0005432527589	7769	95	21D
0005434067338	7769	96	21C
0005432527599	7769	97	21F
0005432527597	7769	98	21E
0005432069614	7769	99	21K
0005434067355	7769	100	21J
0005434067363	7769	101	22C
0005434067358	7769	102	22B
0005432527634	7769	103	22E
0005432527519	7769	104	22D
0005432527611	7769	105	22G
0005435212632	7769	106	22J
0005432527591	7769	107	22H
0005432527514	7769	108	23B
0005435630930	7769	109	23A
0005432527627	7769	110	23E
0005435212570	7769	111	23D
0005432527534	7769	112	23C
0005432527521	7769	113	23G
0005432527633	7769	114	23F
0005435630931	7769	115	23J
0005434067340	7769	116	23H
0005434067351	7769	117	24D
0005432537052	7769	118	24F
0005434067349	7769	119	25A
0005432527576	7769	120	24G
0005432533282	7769	121	25C
0005435212748	7769	122	25B
0005432527536	7769	123	25F
0005432527604	7769	124	25H
0005432527553	7769	125	25G
0005432527566	7769	126	26A
0005432069611	7769	127	26C
0005432527573	7769	128	26B
0005432150169	7769	129	26E
0005432527577	7769	130	26D
0005435212455	7769	131	26H
0005432537051	7769	132	26G
0005432527595	7769	133	26F
0005434067350	7769	134	26J
0005435212742	7769	135	27D
0005432527586	7769	136	27C
0005434067311	7769	137	27B
0005435212949	7769	138	27F
0005435212615	7769	139	27E
0005434067347	7769	140	27J
0005432527547	7769	141	27H
0005434067370	7769	142	27G
0005435212795	7769	143	27K
0005435725525	7769	144	28B
0005432527631	7769	145	28A
0005435212806	7769	146	28D
0005432527552	7769	147	28C
0005434067382	7769	148	28F
0005432527601	7769	149	28K
0005432527625	7769	150	28J
0005432527609	7769	151	28H
0005432527531	7769	152	29A
0005432527583	7769	153	29D
0005432428919	7769	154	29B
0005432527617	7769	155	29F
0005433656624	7769	156	29E
0005432527549	7769	157	29H
0005432150167	7769	158	30A
0005435212848	7769	159	29K
0005432527581	7769	160	29J
0005434067314	7769	161	30B
0005432150173	7769	162	30E
0005432527630	7769	163	30D
0005432527542	7769	164	30H
0005435212651	7769	165	30G
0005435212809	7769	166	30F
0005435212690	7769	167	31A
0005432527568	7769	168	30K
0005435212494	7769	169	31D
0005434067371	7769	170	31C
0005435212783	7769	171	31B
0005435212739	7769	172	31F
0005432069615	7769	173	31E
0005434067369	7769	174	31H
0005434067368	7769	175	31J
0005435212811	7769	176	32C
0005435212506	7769	177	32B
0005435212682	7769	178	32E
0005434067367	7769	179	32G
0005432527523	7769	180	32F
0005432527528	7769	181	32H
0005432527620	7769	182	33A
0005432527624	7769	183	32K
0005435212495	7769	184	33D
0005432527642	7769	185	33C
0005432428918	7769	186	33F
0005435212885	7769	187	33E
0005432527515	7769	188	33J
0005434067354	7769	189	33H
0005432069603	7769	190	33G
0005435212654	7769	191	33K
0005435212850	7769	192	34C
0005432527550	7769	193	34B
0005432527628	7769	194	34E
0005432069613	7769	195	34D
0005432069606	7769	196	34H
0005432527632	7769	197	34G
0005432527544	7769	198	34F
0005432527636	7769	199	34J
0005432527546	7769	200	34K
0005432527559	7769	201	35E
0005435212765	7769	202	35D
0005435212545	7769	203	35F
0005432527543	7769	204	35J
0005434067339	7769	205	36A
0005432527556	7769	206	35K
0005432527530	7769	207	36B
0005432527570	7769	208	36E
0005434067318	7769	209	36D
0005432527579	7769	210	36F
0005434067335	7769	211	36J
0005432527641	7769	212	37B
0005432527645	7769	213	37A
0005432527558	7769	214	37D
0005434067359	7769	215	37G
0005435212802	7769	216	37F
0005432535817	7769	217	37H
0005435212505	7769	218	38A
0005435212425	7769	219	38C
0005432527585	7769	220	38B
0005432533283	7769	221	38K
0005432069605	7769	222	38J
0005435212740	7769	223	38H
0005434067336	7769	224	39D
0005435212789	7769	225	39F
0005432527587	7769	226	39E
0005432150174	7769	227	39J
0005434067361	7769	228	39H
0005435212546	7769	229	39G
0005432527588	7769	230	40A
0005435212948	7769	231	40C
0005432527564	7769	232	40B
0005435212808	7769	233	40E
0005435725546	7769	234	40D
0005435212569	7769	235	40G
0005434067323	7769	236	40K
0005435212849	7769	237	40J
0005435725526	7769	238	41A
0005432527619	7769	239	41D
0005434067377	7769	240	41C
0005432527608	7769	241	41B
0005434067362	7769	242	41G
0005434067313	7769	243	41F
0005432527535	7769	244	41E
0005432527582	7769	245	41H
0005434067383	7769	246	42A
0005432150166	7769	247	41J
0005434067324	7769	248	42C
0005434067327	7769	249	42B
0005432527572	7769	250	42D
0005435630943	7769	251	42H
0005434067364	7769	252	42G
0005432527555	7769	253	42F
0005434067372	7769	254	42J
0005434067345	7769	255	42K
0005434067379	7769	256	43F
0005432069604	7769	257	43E
0005435212424	7769	258	43J
0005432150171	7769	259	43H
0005432069609	7769	260	43G
0005435212764	7769	261	44C
0005434067346	7769	262	44B
0005435212426	7769	263	44E
0005432527640	7769	264	44D
0005434067320	7769	265	44H
0005435213101	7769	266	44G
0005432527626	7769	267	44F
0005434067343	7769	268	44K
0005432527563	7769	269	45A
0005432527629	7769	270	45D
0005432527532	7769	271	45C
0005432527594	7769	272	45B
0005432527603	7769	273	45F
0005432527637	7769	274	45E
0005432527584	7769	275	45H
0005432428916	7769	276	45K
0005435630919	7769	277	45J
0005432527622	7769	278	46A
0005432527623	7769	279	46E
0005434067373	7769	280	46D
0005432527621	7769	281	46F
0005432527554	7769	282	46J
0005432527607	7769	283	46H
0005432527592	7769	284	47C
0005432069617	7769	285	47A
0005432527518	7769	286	46K
0005434067342	7769	287	47E
0005432535819	7769	288	47D
0005435212468	7769	289	47G
0005434067319	7769	290	47F
0005432428917	7769	291	47K
0005432527533	7769	292	47H
0005432527525	7769	293	48C
0005434067326	7769	294	48A
0005432527517	7769	295	48F
0005435212678	7769	296	48E
0005432527639	7769	297	48D
0005434067378	7769	298	48G
0005432069607	7769	299	49A
0005434067337	7769	300	48K
0005432527524	7769	301	49E
0005432069616	7769	302	49D
0005432150170	7769	303	49C
0005432527513	7769	304	49F
0005432527527	7769	305	49K
0005435212763	7769	306	49H
0005432527578	7769	307	49G
0005435212983	7769	308	50C
0005432527567	7769	309	50A
0005432150172	7769	310	50F
0005432527580	7769	311	50E
0005435212738	7769	312	50D
0005434067381	7769	313	50H
0005435212878	7769	314	51D
0005432527610	7769	315	50K
0005432527569	7769	316	51F
0005434067376	7769	317	51E
0005432527614	7769	318	51G
0005432363380	5356	1	1C
0005434344103	5356	2	1H
0005435423944	5356	3	1G
0005434344106	5356	4	1D
0005434573315	5356	5	2A
0005435613268	5356	6	1K
0005435424182	5356	7	2D
0005434344120	5356	8	2C
0005435613300	5356	9	2H
0005435613272	5356	10	2G
0005435613351	5356	11	3A
0005432133170	5356	12	2K
0005435613366	5356	13	3D
0005435555362	5356	14	3C
0005432133158	5356	15	3K
0005435613313	5356	16	3H
0005435613273	5356	17	3G
0005432047537	5356	18	4C
0005435613345	5356	19	4A
0005434344117	5356	20	4G
0005435302163	5356	21	4D
0005435319501	5356	22	5A
0005434344101	5356	23	4K
0005435613357	5356	24	4H
0005434573308	5356	25	5C
0005435613317	5356	26	5G
0005435424096	5356	27	5D
0005434344116	5356	28	11A
0005435613270	5356	29	5K
0005434244595	5356	30	5H
0005434344104	5356	31	11D
0005435613323	5356	32	11C
0005435613286	5356	33	11G
0005435423959	5356	34	11F
0005435613304	5356	35	11H
0005434656537	5356	36	12C
0005434244628	5356	37	12A
0005434244565	5356	38	11K
0005435613294	5356	39	12E
0005435613353	5356	40	12D
0005433719092	5356	41	12H
0005435613285	5356	42	12G
0005434573317	5356	43	12F
0005434656535	5356	44	12K
0005435613314	5356	45	13D
0005435302162	5356	46	13C
0005435424055	5356	47	13F
0005434344130	5356	48	13E
0005435613335	5356	49	13H
0005435424082	5356	50	13G
0005435613336	5356	51	14C
0005435613275	5356	52	14A
0005432133173	5356	53	13K
0005435613258	5356	54	14D
0005435613292	5356	55	14F
0005435424383	5356	56	14E
0005435319490	5356	57	14K
0005435613289	5356	58	14H
0005435613348	5356	59	15C
0005435613309	5356	60	15A
0005435424079	5356	61	15E
0005434344110	5356	62	15D
0005432047541	5356	63	15G
0005432133161	5356	64	15F
0005435097175	5356	65	16A
0005435097176	5356	66	15H
0005434344123	5356	67	16C
0005432133169	5356	68	16F
0005434244641	5356	69	16E
0005435613261	5356	70	16H
0005435423957	5356	71	17C
0005435613338	5356	72	17A
0005435613341	5356	73	16K
0005435380256	5356	74	17E
0005435424382	5356	75	17D
0005434244759	5356	76	17H
0005435613355	5356	77	17G
0005433719084	5356	78	17F
0005434344126	5356	79	18A
0005434244644	5356	80	17K
0005435424454	5356	81	18C
0005435319437	5356	82	18B
0005435423962	5356	83	18D
0005435490216	5356	84	18G
0005435380239	5356	85	18F
0005435424150	5356	86	18J
0005432840989	5356	87	19A
0005435613260	5356	88	18K
0005432840990	5356	89	19D
0005435423993	5356	90	19C
0005435613344	5356	91	19B
0005435613277	5356	92	19F
0005435613361	5356	93	19E
0005434344099	5356	94	19H
0005435424025	5356	95	19G
0005435613346	5356	96	20A
0005435423832	5356	97	19K
0005435613274	5356	98	19J
0005435613278	5356	99	20C
0005435424188	5356	100	20B
0005432133163	5356	101	20E
0005435613282	5356	102	20D
0005435424259	5356	103	20H
0005434244760	5356	104	20G
0005435424015	5356	105	20F
0005435613310	5356	106	20J
0005435319469	5356	107	21D
0005435613329	5356	108	21C
0005435613297	5356	109	21F
0005435613298	5356	110	21H
0005433719110	5356	111	21G
0005432363376	5356	112	22A
0005435613354	5356	113	21K
0005434244723	5356	114	21J
0005434344119	5356	115	22D
0005435097172	5356	116	22C
0005435423928	5356	117	22B
0005435424044	5356	118	22E
0005435097178	5356	119	22G
0005434656536	5356	120	22F
0005435424371	5356	121	22J
0005434244772	5356	122	22H
0005435613307	5356	123	23B
0005435424196	5356	124	23A
0005434344124	5356	125	23E
0005435423949	5356	126	23D
0005434244630	5356	127	23C
0005435097177	5356	128	23G
0005434344127	5356	129	23F
0005432133165	5356	130	23H
0005432047542	5356	131	24D
0005435613372	5356	132	23K
0005435613271	5356	133	24F
0005434573304	5356	134	24E
0005435613365	5356	135	25B
0005435613362	5356	136	25A
0005435613290	5356	137	24G
0005434344131	5356	138	25D
0005435424463	5356	139	25C
0005434244629	5356	140	25F
0005434573307	5356	141	25E
0005435613305	5356	142	25J
0005434244585	5356	143	25H
0005435613259	5356	144	25G
0005435613267	5356	145	25K
0005435613358	5356	146	26C
0005434573311	5356	147	26B
0005432047538	5356	148	26A
0005434344111	5356	149	26E
0005434244533	5356	150	26G
0005434244499	5356	151	26J
0005434344135	5356	152	26H
0005435613320	5356	153	27B
0005435424230	5356	154	27A
0005435613319	5356	155	26K
0005435613343	5356	156	27D
0005435423882	5356	157	27F
0005435423871	5356	158	27H
0005434244596	5356	159	27G
0005435613308	5356	160	27K
0005435613303	5356	161	27J
0005435424396	5356	162	28C
0005434573306	5356	163	28B
0005432133172	5356	164	28A
0005435613279	5356	165	28E
0005435613359	5356	166	28D
0005435613333	5356	167	28G
0005435302137	5356	168	28F
0005435613302	5356	169	28K
0005435424099	5356	170	28J
0005432133168	5356	171	28H
0005434573309	5356	172	29B
0005432047540	5356	173	29A
0005434244688	5356	174	29D
0005435613364	5356	175	29C
0005434573314	5356	176	29F
0005435423777	5356	177	29E
0005435302149	5356	178	29H
0005435424059	5356	179	29G
0005434244587	5356	180	30A
0005434244724	5356	181	29K
0005435423961	5356	182	29J
0005434344112	5356	183	30E
0005434244655	5356	184	30D
0005435613371	5356	185	30C
0005434244773	5356	186	30H
0005434244505	5356	187	30G
0005435613360	5356	188	30F
0005434344121	5356	189	30K
0005435423607	5356	190	31B
0005435613291	5356	191	31D
0005434244591	5356	192	31C
0005435424125	5356	193	31F
0005435613296	5356	194	31H
0005435613340	5356	195	31G
0005432133171	5356	196	32A
0005434344128	5356	197	31J
0005435424014	5356	198	32C
0005435423958	5356	199	32B
0005434244761	5356	200	32E
0005435613315	5356	201	32D
0005435613265	5356	202	32G
0005435424081	5356	203	32F
0005435424058	5356	204	32K
0005435424232	5356	205	32J
0005435613306	5356	206	32H
0005434573310	5356	207	33B
0005435613266	5356	208	33D
0005432133157	5356	209	33C
0005435424129	5356	210	33G
0005434344113	5356	211	33E
0005434344133	5356	212	33H
0005435613311	5356	213	34A
0005435613368	5356	214	33K
0005434244506	5356	215	33J
0005435613283	5356	216	34C
0005435424142	5356	217	34B
0005434244642	5356	218	34E
0005434344100	5356	219	34D
0005435613332	5356	220	34F
0005433719108	5356	221	34J
0005435613264	5356	222	34H
0005432133167	5356	223	35B
0005435613325	5356	224	35A
0005434344108	5356	225	35D
0005434244654	5356	226	35C
0005434344118	5356	227	35G
0005435613367	5356	228	35F
0005435302140	5356	229	35E
0005434573313	5356	230	35J
0005435319436	5356	231	36B
0005432363382	5356	232	36E
0005435424395	5356	233	36D
0005435423675	5356	234	36G
0005435613326	5356	235	36J
0005434344107	5356	236	37B
0005435613293	5356	237	37A
0005435613263	5356	238	37D
0005435424203	5356	239	37C
0005435613356	5356	240	37G
0005435424302	5356	241	37F
0005435613349	5356	242	37H
0005434573312	5356	243	38A
0005435424095	5356	244	37K
0005432047539	5356	245	38H
0005433719094	5356	246	38C
0005435613280	5356	247	38B
0005434344129	5356	248	38J
0005435613331	5356	249	39A
0005434344125	5356	250	38K
0005435613276	5356	251	39D
0005435424128	5356	252	39F
0005435613321	5356	253	39E
0005435424080	5356	254	39J
0005435613350	5356	255	39H
0005435613301	5356	256	39G
0005435613288	5356	257	40A
0005435424141	5356	258	39K
0005435613299	5356	259	40C
0005435424189	5356	260	40B
0005435097174	5356	261	40E
0005434244600	5356	262	40D
0005433719093	5356	263	40F
0005434344114	5356	264	40J
0005435380255	5356	265	40H
0005434244631	5356	266	41B
0005435302152	5356	267	41A
0005435613328	5356	268	40K
0005435424204	5356	269	41D
0005434656526	5356	270	41C
0005434244689	5356	271	41F
0005435613281	5356	272	41E
0005435423994	5356	273	41J
0005435424370	5356	274	41H
0005434244771	5356	275	41G
0005435424271	5356	276	42A
0005435097173	5356	277	41K
0005435613337	5356	278	42C
0005435613295	5356	279	42B
0005435424086	5356	280	42E
0005435423792	5356	281	42D
0005432133159	5356	282	42G
0005434244532	5356	283	42F
0005434244504	5356	284	42K
0005435424303	5356	285	42J
0005432133166	5356	286	42H
0005434344109	5356	287	43B
0005435424169	5356	288	43A
0005435423770	5356	289	43D
0005435302139	5356	290	43C
0005435491433	5356	291	43F
0005435613269	5356	292	43E
0005434344105	5356	293	43H
0005435491434	5356	294	44A
0005435424026	5356	295	43J
0005434344115	5356	296	44B
0005432133160	5356	297	44E
0005435319441	5356	298	44D
0005435424153	5356	299	44G
0005434573305	5356	300	44F
0005435613352	5356	301	44J
0005435613262	5356	302	44H
0005435613363	5356	303	45B
0005435613342	5356	304	45A
0005434344122	5356	305	44K
0005432133162	5356	306	45D
0005435423915	5356	307	45C
0005435613334	5356	308	45F
0005433719103	5356	309	45E
0005434656534	5356	310	45H
0005435424455	5356	311	45K
0005435097180	5356	312	46B
0005435613318	5356	313	46E
0005434244605	5356	314	46D
0005435423881	5356	315	46H
0005435302161	5356	316	46G
0005435613327	5356	317	46F
0005435424231	5356	318	46J
0005434344132	5356	319	47A
0005435490217	5356	320	47E
0005435613322	5356	321	47D
0005435302141	5356	322	47F
0005434344134	5356	323	47K
0005435613287	5356	324	47H
0005435613370	5356	325	48E
0005432363381	5356	326	48D
0005435424181	5356	327	48H
0005435613316	5356	328	48G
0005434573316	5356	329	48F
0005432133164	5356	330	49F
0005435613324	5356	331	49E
0005435424183	5356	332	49K
0005435613312	5356	333	49H
0005435097179	5356	334	49G
0005434344102	5356	335	50C
0005435613330	5356	336	50A
0005433719109	5356	337	50E
0005435613284	5356	338	50D
0005435613347	5356	339	50H
0005435423956	5356	340	50G
0005435613339	5356	341	50F
0005434244780	5356	342	51D
0005434244621	5356	343	50K
0005435613369	5356	344	51G
0005435305009	10929	1	1C
0005435611910	10929	2	1G
0005432363406	10929	3	1D
0005435424612	10929	4	1K
0005435612127	10929	5	1H
0005435424576	10929	6	2A
0005434244886	10929	7	2G
0005435424584	10929	8	2D
0005434244889	10929	9	3A
0005435612582	10929	10	2H
0005435612724	10929	11	3D
0005435612155	10929	12	3C
0005434244897	10929	13	3K
0005435380280	10929	14	3H
0005435612318	10929	15	3G
0005435424606	10929	16	4C
0005435612179	10929	17	4G
0005435612505	10929	18	4D
0005435424570	10929	19	4K
0005435612333	10929	20	4H
0005435612591	10929	21	5D
0005435424567	10929	22	5C
0005435424597	10929	23	5A
0005433719131	10929	24	5H
0005435490180	10929	25	5G
0005435424596	10929	26	11A
0005435612478	10929	27	5K
0005434343668	10929	28	11D
0005435490179	10929	29	11C
0005435424581	10929	30	11F
0005435380275	10929	31	11E
0005435319549	10929	32	11K
0005434343869	10929	33	12C
0005435424564	10929	34	12D
0005434244877	10929	35	12H
0005435611797	10929	36	12G
0005435490188	10929	37	12F
0005435612670	10929	38	12K
0005434343758	10929	39	13D
0005435424568	10929	40	13C
0005435424607	10929	41	13F
0005435097110	10929	42	13E
0005435612364	10929	43	13K
0005435612178	10929	44	13H
0005434244900	10929	45	13G
0005434343618	10929	46	14A
0005435424587	10929	47	14E
0005434244876	10929	48	14F
0005435611782	10929	49	14H
0005435612286	10929	50	14G
0005435612189	10929	51	15C
0005435612397	10929	52	15F
0005434573202	10929	53	15E
0005432165016	10929	54	15G
0005432841008	10929	55	16A
0005435042850	10929	56	15K
0005435424627	10929	57	15H
0005434343895	10929	58	16D
0005435424580	10929	59	16C
0005435612507	10929	60	16F
0005434343759	10929	61	16E
0005435097095	10929	62	16H
0005435612112	10929	63	16G
0005432363407	10929	64	17A
0005434244883	10929	65	16K
0005432841006	10929	66	17E
0005435424594	10929	67	17D
0005435424566	10929	68	17C
0005434244881	10929	69	17F
0005434244895	10929	70	18A
0005435612510	10929	71	17K
0005435424590	10929	72	18C
0005435319548	10929	73	18B
0005434244894	10929	74	18E
0005432166891	10929	75	18D
0005435424632	10929	76	18G
0005435424578	10929	77	18F
0005435424609	10929	78	18K
0005435612204	10929	79	18J
0005435612566	10929	80	18H
0005435424572	10929	81	19B
0005435424614	10929	82	19A
0005435424575	10929	83	19D
0005435424600	10929	84	19C
0005434573152	10929	85	19F
0005435555348	10929	86	19E
0005435611956	10929	87	19J
0005433719133	10929	88	19H
0005434244901	10929	89	19G
0005435424608	10929	90	20A
0005434573137	10929	91	19K
0005435612180	10929	92	20C
0005435424602	10929	93	20B
0005435612402	10929	94	20E
0005434343765	10929	95	20D
0005435424563	10929	96	20F
0005434244899	10929	97	20J
0005435424573	10929	98	20H
0005434656549	10929	99	21B
0005435612534	10929	100	21D
0005435612366	10929	101	21C
0005435612165	10929	102	21F
0005435424623	10929	103	21E
0005434343713	10929	104	21J
0005435612527	10929	105	21H
0005435424595	10929	106	21G
0005435612469	10929	107	22A
0005434244887	10929	108	22C
0005435612416	10929	109	22B
0005434573149	10929	110	22E
0005435612053	10929	111	22D
0005434244882	10929	112	22F
0005432165015	10929	113	22K
0005435612186	10929	114	22J
0005435424574	10929	115	22H
0005432165014	10929	116	23B
0005434244879	10929	117	23A
0005435612464	10929	118	23D
0005435612037	10929	119	23C
0005435612462	10929	120	23F
0005434244905	10929	121	23E
0005435612063	10929	122	23J
0005435612301	10929	123	23H
0005435424626	10929	124	23G
0005435304142	10929	125	24D
0005435424622	10929	126	23K
0005435612403	10929	127	24F
0005435612188	10929	128	24E
0005435424613	10929	129	25A
0005435424617	10929	130	24G
0005435304139	10929	131	25C
0005435612384	10929	132	25F
0005435612338	10929	133	25E
0005435424611	10929	134	25D
0005435612192	10929	135	25H
0005434343726	10929	136	25G
0005435612705	10929	137	25K
0005435424583	10929	138	25J
0005434244898	10929	139	26C
0005434244891	10929	140	26A
0005435424631	10929	141	26E
0005435042848	10929	142	26D
0005435612281	10929	143	26J
0005435424621	10929	144	26H
0005435612358	10929	145	26K
0005435424625	10929	146	27C
0005434244878	10929	147	27F
0005435319543	10929	148	27D
0005435424629	10929	149	27H
0005434343712	10929	150	27G
0005435611947	10929	151	28A
0005434343751	10929	152	27K
0005435424562	10929	153	27J
0005435612036	10929	154	28D
0005435612413	10929	155	28C
0005434244875	10929	156	28G
0005434573182	10929	157	28F
0005434244884	10929	158	28E
0005435612443	10929	159	28J
0005435319542	10929	160	28H
0005435490178	10929	161	29B
0005435612114	10929	162	29A
0005434244903	10929	163	28K
0005435319547	10929	164	29F
0005435319546	10929	165	29E
0005435380277	10929	166	29J
0005435612528	10929	167	29H
0005435612422	10929	168	30A
0005434343807	10929	169	29K
0005435612592	10929	170	30B
0005435612439	10929	171	30E
0005434343781	10929	172	30D
0005435612111	10929	173	30G
0005435612062	10929	174	30F
0005434244896	10929	175	30K
0005435612725	10929	176	30J
0005435304143	10929	177	30H
0005435612317	10929	178	31B
0005432166890	10929	179	31D
0005435612581	10929	180	31C
0005434573233	10929	181	31F
0005435611733	10929	182	31E
0005435424598	10929	183	31H
0005435491415	10929	184	31G
0005434244880	10929	185	32A
0005434244902	10929	186	31K
0005433719129	10929	187	31J
0005434573227	10929	188	32C
0005434343733	10929	189	32B
0005434573142	10929	190	32E
0005435612061	10929	191	32D
0005435380279	10929	192	32H
0005435305007	10929	193	32G
0005435612113	10929	194	32F
0005435612154	10929	195	32J
0005435612460	10929	196	33D
0005435491419	10929	197	33C
0005435612530	10929	198	33H
0005432165013	10929	199	33G
0005435305008	10929	200	34A
0005434573138	10929	201	33J
0005434343778	10929	202	34C
0005434573169	10929	203	34B
0005435612782	10929	204	34E
0005435612618	10929	205	34D
0005435612533	10929	206	34G
0005435612457	10929	207	34F
0005434343867	10929	208	34K
0005435097050	10929	209	34H
0005434573228	10929	210	35B
0005435424615	10929	211	35C
0005435424571	10929	212	35F
0005435612349	10929	213	35E
0005434343811	10929	214	35H
0005435319541	10929	215	36A
0005435612444	10929	216	35J
0005434343725	10929	217	36B
0005435612704	10929	218	36E
0005435612128	10929	219	36D
0005435612404	10929	220	36H
0005435612463	10929	221	36G
0005434573143	10929	222	36F
0005433719132	10929	223	36K
0005435304144	10929	224	36J
0005435424593	10929	225	37C
0005435424585	10929	226	37A
0005435424630	10929	227	37D
0005434656551	10929	228	37F
0005435612243	10929	229	37E
0005435612304	10929	230	37J
0005434343796	10929	231	37H
0005435612197	10929	232	38C
0005435424586	10929	233	38H
0005435424616	10929	234	39B
0005435380278	10929	235	38K
0005435612390	10929	236	39D
0005435424610	10929	237	39E
0005435042851	10929	238	39H
0005435612365	10929	239	39G
0005435424601	10929	240	40A
0005435612511	10929	241	40C
0005435612565	10929	242	40B
0005435319545	10929	243	40F
0005434244893	10929	244	40E
0005435611983	10929	245	40D
0005432166892	10929	246	40G
0005435424589	10929	247	40K
0005435424619	10929	248	40J
0005435612298	10929	249	41B
0005434244892	10929	250	41A
0005434343868	10929	251	41D
0005432841007	10929	252	41C
0005435612445	10929	253	41F
0005435612334	10929	254	41J
0005435424582	10929	255	41H
0005435097111	10929	256	41G
0005434343661	10929	257	42A
0005435319544	10929	258	41K
0005435612448	10929	259	42C
0005435424618	10929	260	42B
0005435612008	10929	261	42D
0005435612535	10929	262	42G
0005434244904	10929	263	42F
0005435424565	10929	264	42J
0005435612691	10929	265	42H
0005435612129	10929	266	42K
0005435612242	10929	267	43D
0005434343817	10929	268	43C
0005435612564	10929	269	43H
0005435612451	10929	270	43G
0005434656550	10929	271	43K
0005435424605	10929	272	43J
0005435424579	10929	273	44C
0005435424588	10929	274	44B
0005434573146	10929	275	44A
0005434343810	10929	276	44E
0005434343698	10929	277	44D
0005435424628	10929	278	44G
0005435612150	10929	279	44F
0005435424569	10929	280	44J
0005434343816	10929	281	44H
0005435042849	10929	282	44K
0005435612282	10929	283	45C
0005434573201	10929	284	45B
0005435612160	10929	285	45F
0005435612051	10929	286	45E
0005435612421	10929	287	45D
0005435304141	10929	288	45H
0005434343808	10929	289	45G
0005434343601	10929	290	45K
0005435380276	10929	291	45J
0005434244890	10929	292	46B
0005434573181	10929	293	46A
0005435612763	10929	294	46D
0005435097043	10929	295	46C
0005435611906	10929	296	46G
0005434244885	10929	297	46J
0005432363405	10929	298	46H
0005435612244	10929	299	47C
0005434244888	10929	300	47A
0005435612575	10929	301	46K
0005435424577	10929	302	47E
0005435490183	10929	303	47G
0005435304140	10929	304	47F
0005435612264	10929	305	47K
0005435612611	10929	306	48C
0005435424599	10929	307	48A
0005433719130	10929	308	48F
0005432165012	10929	309	48E
0005435424604	10929	310	48H
0005435424591	10929	311	48G
0005435424603	10929	312	49A
0005435424592	10929	313	48K
0005435612420	10929	314	49D
0005435424620	10929	315	49F
0005434343797	10929	316	50A
0005434343731	10929	317	50F
0005435612337	10929	318	50E
0005432165017	10929	319	50D
0005435612551	10929	320	50G
0005435612219	10929	321	51D
0005434573150	10929	322	50H
0005432363408	10929	323	51E
0005435424624	10929	324	51G
0005432459249	3358	1	1C
0005433805266	3358	2	1A
0005433805259	3358	3	1F
0005432459261	3358	4	1D
0005433633716	3358	5	2A
0005432181639	3358	6	2C
0005433507134	3358	7	2F
0005433805274	3358	8	2D
0005433507119	3358	9	3A
0005433805252	3358	10	3C
0005432459089	3358	11	3F
0005432459432	3358	12	3D
0005432459235	3358	13	4A
0005432459229	3358	14	4C
0005432459323	3358	15	4F
0005433805264	3358	16	4D
0005432459458	3358	17	5A
0005433507126	3358	18	5D
0005433805269	3358	19	5C
0005432459349	3358	20	6A
0005433633723	3358	21	5F
0005433633710	3358	22	6C
0005432459244	3358	23	6D
0005432459219	3358	24	7A
0005432459350	3358	25	6F
0005432459338	3358	26	7C
0005433507123	3358	27	7F
0005433633736	3358	28	7D
0005433633735	3358	29	8A
0005432459314	3358	30	8C
0005433633702	3358	31	8B
0005433805272	3358	32	8D
0005432181659	3358	33	8E
0005432459457	3358	34	9A
0005433805276	3358	35	8F
0005433633712	3358	36	9C
0005432181657	3358	37	9B
0005432181647	3358	38	9E
0005432181644	3358	39	9D
0005433633720	3358	40	9F
0005432459079	3358	41	10A
0005432459116	3358	42	10B
0005433633732	3358	43	10C
0005433805257	3358	44	10E
0005433633724	3358	45	10D
0005433805267	3358	46	10F
0005432181654	3358	47	11B
0005433507128	3358	48	11A
0005432459236	3358	49	11D
0005433633726	3358	50	11C
0005432181641	3358	51	11F
0005433805280	3358	52	11E
0005432181648	3358	53	12A
0005432459117	3358	54	12B
0005433633730	3358	55	12C
0005433507118	3358	56	12E
0005433805255	3358	57	12D
0005433633707	3358	58	12F
0005433633722	3358	59	13B
0005433805271	3358	60	13A
0005432181656	3358	61	13C
0005432459319	3358	62	13D
0005433633705	3358	63	13E
0005432459013	3358	64	14A
0005433507121	3358	65	13F
0005433805251	3358	66	14B
0005433633703	3358	67	14C
0005432459298	3358	68	14E
0005433805283	3358	69	14D
0005433805265	3358	70	14F
0005433507124	3358	71	15B
0005432181661	3358	72	15A
0005433633714	3358	73	15C
0005433805249	3358	74	15D
0005432181645	3358	75	15F
0005433633709	3358	76	15E
0005433805253	3358	77	16A
0005432181655	3358	78	16C
0005432181643	3358	79	16B
0005433507135	3358	80	16E
0005432181658	3358	81	16D
0005433507139	3358	82	16F
0005433805258	3358	83	17B
0005432459245	3358	84	17A
0005432459252	3358	85	17C
0005432459337	3358	86	17D
0005433633733	3358	87	17E
0005433633711	3358	88	18A
0005433633731	3358	89	17F
0005432459195	3358	90	18C
0005432459168	3358	91	18B
0005433507129	3358	92	18D
0005432458975	3358	93	18E
0005433633727	3358	94	18F
0005433805281	3358	95	19B
0005433805282	3358	96	19E
0005433633725	3358	97	19D
0005433805248	3358	98	19C
0005433805260	3358	99	20A
0005432459344	3358	100	20C
0005433805285	3358	101	20B
0005432459313	3358	102	20E
0005433805250	3358	103	20D
0005432459248	3358	104	20F
0005432459231	3358	105	21A
0005433805277	3358	106	21C
0005433633729	3358	107	21B
0005433633708	3358	108	21D
0005432181640	3358	109	21E
0005433633715	3358	110	22A
0005433633717	3358	111	21F
0005432181646	3358	112	22B
0005433633706	3358	113	22C
0005433805270	3358	114	22D
0005433805247	3358	115	22F
0005433805256	3358	116	22E
0005433805263	3358	117	23A
0005433805262	3358	118	23C
0005433633721	3358	119	23B
0005433507122	3358	120	23D
0005433805278	3358	121	23E
0005433633704	3358	122	23F
0005432181653	3358	123	24B
0005433805254	3358	124	24A
0005433805273	3358	125	24C
0005433633713	3358	126	24D
0005433805261	3358	127	24F
0005433507127	3358	128	24E
0005433507120	3358	129	25A
0005432459294	3358	130	25C
0005433633719	3358	131	25B
0005432181660	3358	132	25D
0005433805284	3358	133	25E
0005433507136	3358	134	26A
0005432181642	3358	135	25F
0005433507130	3358	136	26B
0005433805279	3358	137	26C
0005432181652	3358	138	26E
0005432181638	3358	139	26D
0005432459102	3358	140	26F
0005433805246	3358	141	27A
0005432459456	3358	142	27C
0005432459228	3358	143	27B
0005432459306	3358	144	27D
0005433805275	3358	145	27F
0005432459204	3358	146	27E
0005432459485	3358	147	28A
0005432459343	3358	148	28C
0005433633728	3358	149	28B
0005432459203	3358	150	28D
0005432459264	3358	151	28E
0005432181651	3358	152	29A
0005432459307	3358	153	28F
0005433507133	3358	154	29B
0005433507125	3358	155	29D
0005433507138	3358	156	29C
0005432181650	3358	157	29E
0005433507140	3358	158	30A
0005433507137	3358	159	29F
0005433805268	3358	160	30B
0005433507132	3358	161	30D
0005433507131	3358	162	30C
0005432459250	3358	163	30E
0005432459433	3358	164	31A
0005432459251	3358	165	30F
0005432181649	3358	166	31C
0005432459196	3358	167	31B
0005432459351	3358	168	31E
0005433633718	3358	169	31D
0005433633734	3358	170	31F
0005435884802	3357	1	1C
0005435884725	3357	2	2A
0005435884782	3357	3	1F
0005435884746	3357	4	3C
0005435884726	3357	5	3D
0005435884386	3357	6	4C
0005435884611	3357	7	5A
0005435884764	3357	8	6A
0005435884803	3357	9	6D
0005435884918	3357	10	6F
0005435884749	3357	11	7F
0005435884628	3357	12	8D
0005435884741	3357	13	9C
0005435884939	3357	14	9B
0005435884933	3357	15	9F
0005435884806	3357	16	10B
0005435884591	3357	17	11D
0005435884835	3357	18	11E
0005435884831	3357	19	12C
0005435884688	3357	20	12F
0005435884724	3357	21	13F
0005435884582	3357	22	13E
0005435884747	3357	23	14B
0005435884681	3357	24	15A
0005435884836	3357	25	15C
0005435884813	3357	26	15E
0005435884811	3357	27	18D
0005435884819	3357	28	19D
0005435884622	3357	29	20C
0005435884592	3357	30	21A
0005435884583	3357	31	22C
0005435884934	3357	32	23F
0005435884758	3357	33	26B
0005435884940	3357	34	26C
0005435884402	3357	35	26E
0005435884932	3357	36	27B
0005435884757	3357	37	28C
0005435884770	3357	38	28B
0005435884692	3357	39	28E
0005435884673	3357	40	29B
0005435884766	3357	41	29F
0005435884780	3357	42	30B
0005435884783	3357	43	30E
0005435884938	3357	44	31A
0005435884842	3357	45	31E
0005433506936	8335	1	1A
0005432042669	8335	2	1D
0005433506950	8335	3	2A
0005432459741	8335	4	1F
0005432459704	8335	5	2C
0005435885078	8335	6	2F
0005435885102	8335	7	3A
0005435885100	8335	8	3C
0005435885124	8335	9	3D
0005435885094	8335	10	4A
0005435885093	8335	11	3F
0005432459732	8335	12	4C
0005435885098	8335	13	4F
0005432459706	8335	14	4D
0005435885074	8335	15	5A
0005432459752	8335	16	5F
0005435885075	8335	17	5D
0005435885111	8335	18	6A
0005432042679	8335	19	6C
0005432459744	8335	20	6F
0005432042678	8335	21	6D
0005435885106	8335	22	7A
0005435885118	8335	23	7D
0005432459708	8335	24	7F
0005432459757	8335	25	8A
0005432042667	8335	26	8B
0005432459731	8335	27	8D
0005432459739	8335	28	8C
0005433506937	8335	29	8E
0005433506967	8335	30	8F
0005433506957	8335	31	9B
0005432042670	8335	32	9C
0005432459735	8335	33	9D
0005433507014	8335	34	9F
0005435885108	8335	35	9E
0005432459736	8335	36	10A
0005435885087	8335	37	10B
0005435885107	8335	38	10C
0005432459747	8335	39	10E
0005432459755	8335	40	10D
0005435885072	8335	41	11B
0005435885091	8335	42	11A
0005432459753	8335	43	11D
0005432042677	8335	44	11F
0005432459726	8335	45	11E
0005435885079	8335	46	12C
0005432459724	8335	47	12B
0005433507069	8335	48	12D
0005435885116	8335	49	12E
0005432459707	8335	50	12F
0005432459746	8335	51	13B
0005432459714	8335	52	13A
0005435885113	8335	53	13C
0005435885104	8335	54	13D
0005432459727	8335	55	13E
0005432459750	8335	56	14A
0005432459709	8335	57	13F
0005432459711	8335	58	14B
0005435885090	8335	59	14C
0005435885085	8335	60	14E
0005432459722	8335	61	14D
0005435885117	8335	62	14F
0005435885084	8335	63	15A
0005435885082	8335	64	15C
0005435885083	8335	65	15B
0005432459734	8335	66	15D
0005432459705	8335	67	16B
0005433506875	8335	68	16E
0005435885086	8335	69	16D
0005435885105	8335	70	17A
0005432042676	8335	71	16F
0005432459720	8335	72	17B
0005432459745	8335	73	17C
0005435885120	8335	74	17E
0005435885112	8335	75	18A
0005435885081	8335	76	17F
0005433506960	8335	77	18B
0005435885097	8335	78	18C
0005432459737	8335	79	18E
0005435885099	8335	80	18D
0005432459712	8335	81	18F
0005435885096	8335	82	19C
0005433507068	8335	83	19D
0005432459733	8335	84	20B
0005432459717	8335	85	20D
0005435885076	8335	86	20F
0005432459729	8335	87	20E
0005433506885	8335	88	21A
0005435885115	8335	89	21C
0005432459751	8335	90	21B
0005435885080	8335	91	21D
0005432459723	8335	92	21E
0005433506926	8335	93	22B
0005435885125	8335	94	22A
0005432459754	8335	95	22C
0005432459743	8335	96	22E
0005432042671	8335	97	22D
0005432459710	8335	98	22F
0005435885114	8335	99	23A
0005433506900	8335	100	23B
0005435885101	8335	101	23D
0005435885092	8335	102	23F
0005432042672	8335	103	23E
0005432042675	8335	104	24A
0005432042674	8335	105	24B
0005432459716	8335	106	24D
0005432042680	8335	107	24C
0005435885077	8335	108	24E
0005435885119	8335	109	25B
0005432459713	8335	110	25A
0005433506899	8335	111	25C
0005432459719	8335	112	25D
0005435885123	8335	113	25F
0005432042668	8335	114	25E
0005432459756	8335	115	26A
0005433506913	8335	116	26B
0005432459749	8335	117	26C
0005432042673	8335	118	26D
0005435885109	8335	119	26F
0005434312314	8335	120	27A
0005435885089	8335	121	27C
0005432459721	8335	122	27B
0005435885103	8335	123	27D
0005435885122	8335	124	27F
0005433506995	8335	125	27E
0005433506951	8335	126	28A
0005435885110	8335	127	28B
0005432459728	8335	128	28C
0005432459742	8335	129	28E
0005432459730	8335	130	29A
0005432459715	8335	131	28F
0005434312315	8335	132	29E
0005432459718	8335	133	29D
0005432459738	8335	134	29C
0005435885088	8335	135	30A
0005435885121	8335	136	29F
0005433507001	8335	137	30B
0005435885095	8335	138	30C
0005433506914	8335	139	30E
0005432459748	8335	140	30D
0005433506954	8335	141	31A
0005432459725	8335	142	30F
0005435885073	8335	143	31B
0005433506898	8335	144	31C
0005433506956	8335	145	31D
0005433506966	8335	146	31E
0005432459740	8335	147	31F
0005433633415	8255	1	1A
0005433633269	8255	2	1C
0005433805098	8255	3	1F
0005433804870	8255	4	3C
0005433633479	8255	5	3D
0005433633474	8255	6	4A
0005433805060	8255	7	4C
0005433805008	8255	8	4F
0005434143704	8255	9	4D
0005433804935	8255	10	5C
0005433805046	8255	11	6C
0005433633357	8255	12	6D
0005433805097	8255	13	7F
0005433804906	8255	14	8A
0005433633347	8255	15	8B
0005433805130	8255	16	8D
0005433633510	8255	17	8E
0005433633444	8255	18	8F
0005433633312	8255	19	9D
0005433633301	8255	20	9F
0005433804916	8255	21	10B
0005433633219	8255	22	10C
0005433633473	8255	23	11C
0005433804989	8255	24	11D
0005433633324	8255	25	12A
0005433633313	8255	26	11F
0005433633253	8255	27	12C
0005433804908	8255	28	12E
0005433805077	8255	29	13D
0005433805059	8255	30	14A
0005433805029	8255	31	15D
0005433633413	8255	32	15F
0005433805041	8255	33	15E
0005434143705	8255	34	16B
0005433804924	8255	35	16D
0005433804912	8255	36	16C
0005433804934	8255	37	16F
0005434271286	8255	38	17B
0005433633288	8255	39	17C
0005433633344	8255	40	17E
0005433804990	8255	41	18F
0005433805026	8255	42	19D
0005433804907	8255	43	19E
0005433633291	8255	44	20B
0005433804985	8255	45	20E
0005433633342	8255	46	21A
0005433804865	8255	47	21B
0005433804994	8255	48	22A
0005434271290	8255	49	22C
0005433633414	8255	50	22F
0005433804947	8255	51	23C
0005433633374	8255	52	23B
0005433805025	8255	53	23D
0005433804940	8255	54	24B
0005433805007	8255	55	24C
0005433804957	8255	56	24E
0005433804986	8255	57	24D
0005433805074	8255	58	24F
0005433804956	8255	59	25C
0005433633455	8255	60	25D
0005433633270	8255	61	26B
0005433804871	8255	62	26C
0005433805024	8255	63	26F
0005433633396	8255	64	27B
0005433804984	8255	65	27D
0005433633287	8255	66	27F
0005433804869	8255	67	27E
0005433804995	8255	68	28A
0005433633480	8255	69	28B
0005433804948	8255	70	28D
0005433633252	8255	71	28F
0005433633218	8255	72	29B
0005433633345	8255	73	29A
0005433633452	8255	74	30A
0005433805028	8255	75	29F
0005434143703	8255	76	30B
0005433804911	8255	77	30C
0005433805045	8255	78	30E
0005433804796	8255	79	31A
0005433633346	8255	80	31D
0005432383075	4517	1	1A
0005432383089	4517	2	1D
0005432727902	4517	3	1F
0005432727903	4517	4	2C
0005432383094	4517	5	2D
0005432383086	4517	6	2F
0005432727897	4517	7	3A
0005432383074	4517	8	3C
0005432727901	4517	9	3D
0005432383088	4517	10	3F
0005432727896	4517	11	4C
0005432383066	4517	12	4F
0005432383079	4517	13	5A
0005432383072	4517	14	5C
0005432383073	4517	15	5E
0005432383059	4517	16	6C
0005432727907	4517	17	6D
0005432383063	4517	18	6E
0005432383076	4517	19	6F
0005432383061	4517	20	7A
0005432727904	4517	21	7D
0005432383084	4517	22	7F
0005432383067	4517	23	8C
0005432383057	4517	24	8E
0005433722206	4517	25	8F
0005432727906	4517	26	9A
0005432383064	4517	27	9C
0005432383082	4517	28	9D
0005432383068	4517	29	9F
0005432727905	4517	30	10C
0005433722203	4517	31	10E
0005433722204	4517	32	10F
0005432383078	4517	33	11C
0005432383070	4517	34	11E
0005432383081	4517	35	11F
0005432383091	4517	36	12D
0005432383065	4517	37	12E
0005433722208	4517	38	12F
0005432383092	4517	39	13C
0005433722202	4517	40	13D
0005432383077	4517	41	13F
0005432383093	4517	42	14D
0005432383085	4517	43	14E
0005433722200	4517	44	14F
0005432383080	4517	45	15A
0005432383060	4517	46	15C
0005433453758	4517	47	15E
0005432383071	4517	48	15F
0005432727900	4517	49	16A
0005432383087	4517	50	16C
0005432383083	4517	51	16D
0005433722207	4517	52	16F
0005432727898	4517	53	17A
0005432727899	4517	54	17C
0005432727895	4517	55	17D
0005432383090	4517	56	17E
0005433722201	4517	57	17F
0005432383058	4517	58	19A
0005433722205	4517	59	19E
0005432383062	4517	60	19F
0005432383069	4517	61	20A
0005432382784	30094	1	1A
0005432727801	30094	2	1F
0005432727812	30094	3	2D
0005432382535	30094	4	2F
0005432382661	30094	5	3C
0005432382595	30094	6	3D
0005432382495	30094	7	3F
0005432382534	30094	8	4A
0005432382579	30094	9	4C
0005432382712	30094	10	4D
0005432382601	30094	11	4E
0005432382738	30094	12	4F
0005432382637	30094	13	5A
0005432382657	30094	14	5D
0005433722114	30094	15	5E
0005432382625	30094	16	6C
0005432382651	30094	17	6D
0005432727771	30094	18	6E
0005432382708	30094	19	7A
0005432382662	30094	20	7C
0005432382624	30094	21	7D
0005433451594	30094	22	8A
0005432382644	30094	23	8D
0005432382711	30094	24	8E
0005432727821	30094	25	8F
0005432382673	30094	26	9A
0005432382681	30094	27	9C
0005432382629	30094	28	9D
0005432382614	30094	29	9F
0005432382505	30094	30	10A
0005432382776	30094	31	10F
0005432382654	30094	32	11A
0005432382496	30094	33	11D
0005432382523	30094	34	11E
0005432382680	30094	35	11F
0005432727853	30094	36	12D
0005433451596	30094	37	13A
0005432382619	30094	38	13C
0005432382580	30094	39	13D
0005432727772	30094	40	14A
0005432382656	30094	41	14E
0005432727832	30094	42	14F
0005432727802	30094	43	15A
0005433453735	30094	44	15C
0005432382645	30094	45	15D
0005432382613	30094	46	16A
0005432382618	30094	47	16D
0005432382600	30094	48	16E
0005432382899	30094	49	16F
0005432727773	30094	50	17C
0005432382636	30094	51	17D
0005433453734	30094	52	17E
0005432727788	30094	53	18A
0005433453733	30094	54	18C
0005432382655	30094	55	18F
0005432382596	30094	56	19C
0005432382500	30094	57	19D
0005433722108	30094	58	19F
0005433451595	30094	59	20A
0005432382898	30094	60	20C
0005433722113	30094	61	20E
0005432382525	30094	62	20F
0005435529206	1741	1	1C
0005435529204	1741	2	1D
0005435529191	1741	3	2D
0005435529196	1741	4	2F
0005435529210	1741	5	3A
0005433516860	1741	6	3C
0005435540945	1741	7	3D
0005435529209	1741	8	3F
0005433516855	1741	9	4A
0005435540941	1741	10	4C
0005435540954	1741	11	4E
0005435540953	1741	12	4F
0005435529198	1741	13	5D
0005435540937	1741	14	5C
0005435529201	1741	15	5E
0005435529193	1741	16	6A
0005435529197	1741	17	6C
0005435529199	1741	18	6D
0005435540952	1741	19	7E
0005432924968	1741	20	7F
0005435540935	1741	21	8A
0005433516859	1741	22	8C
0005435540934	1741	23	8D
0005435529192	1741	24	8E
0005435540940	1741	25	8F
0005435529205	1741	26	9A
0005432924981	1741	27	9D
0005435529208	1741	28	9E
0005433516856	1741	29	10A
0005435529189	1741	30	10C
0005433516858	1741	31	10D
0005435540950	1741	32	10E
0005435540946	1741	33	11A
0005435540948	1741	34	11E
0005433516862	1741	35	11F
0005433516857	1741	36	12D
0005435529207	1741	37	12F
0005435540949	1741	38	13A
0005433516863	1741	39	14C
0005432294479	1741	40	14D
0005435540938	1741	41	14E
0005435529202	1741	42	15A
0005435540936	1741	43	15C
0005435529203	1741	44	15D
0005435540944	1741	45	15F
0005435529195	1741	46	16A
0005435540942	1741	47	16C
0005432294480	1741	48	16D
0005435540947	1741	49	16F
0005432294481	1741	50	17C
0005432924969	1741	51	18A
0005435540933	1741	52	18D
0005435540939	1741	53	18E
0005432924980	1741	54	18F
0005435529190	1741	55	19A
0005435529200	1741	56	19C
0005433516861	1741	57	19D
0005435529194	1741	58	19E
0005435540943	1741	59	19F
0005435540951	1741	60	20C
0005432925023	21991	1	1C
0005435540742	21991	2	1F
0005435517665	21991	3	2A
0005435517689	21991	4	2D
0005435540678	21991	5	2F
0005435540849	21991	6	3A
0005435540679	21991	7	4A
0005435540740	21991	8	4E
0005432925021	21991	9	4F
0005435517749	21991	10	5D
0005433516792	21991	11	6C
0005435540634	21991	12	7A
0005432925022	21991	13	7E
0005433516791	21991	14	8C
0005435540850	21991	15	8D
0005435517724	21991	16	9A
0005435517624	21991	17	9D
0005433516766	21991	18	9E
0005435517746	21991	19	9F
0005435540677	21991	20	10D
0005435517683	21991	21	10E
0005435517711	21991	22	10F
0005435517764	21991	23	11A
0005435540732	21991	24	11C
0005435517664	21991	25	12A
0005435540774	21991	26	12D
0005435540727	21991	27	12E
0005435517677	21991	28	12F
0005435517765	21991	29	13C
0005435540739	21991	30	13D
0005435517732	21991	31	13E
0005435517712	21991	32	14D
0005435517788	21991	33	15A
0005433516758	21991	34	15D
0005435540738	21991	35	15F
0005435517676	21991	36	16C
0005435540696	21991	37	16D
0005435540756	21991	38	17A
0005435517623	21991	39	17C
0005432925024	21991	40	17D
0005435540815	21991	41	17F
0005432925020	21991	42	18A
0005435540768	21991	43	18C
0005435540633	21991	44	18E
0005435540733	21991	45	19A
0005433516771	21991	46	20A
0005435540635	21991	47	20C
0005433516767	21991	48	20D
0005434458749	7372	1	1A
0005435252460	7372	2	1C
0005432823444	7372	3	1D
0005434458739	7372	4	1F
0005432838937	7372	5	2A
0005432838944	7372	6	2C
0005435252445	7372	7	2D
0005434458747	7372	8	2F
0005432838953	7372	9	3A
0005435252510	7372	10	3C
0005432838938	7372	11	3D
0005435252509	7372	12	3F
0005432838936	7372	13	4A
0005435252383	7372	14	4C
0005432838946	7372	15	4D
0005432838943	7372	16	4E
0005432073381	7372	17	4F
0005432838958	7372	18	5A
0005432838931	7372	19	5C
0005435252582	7372	20	5D
0005434458748	7372	21	5E
0005432838927	7372	22	5F
0005434458732	7372	23	6A
0005435252494	7372	24	6C
0005435252384	7372	25	6D
0005435252525	7372	26	6E
0005435252400	7372	27	6F
0005435252583	7372	28	7A
0005432823441	7372	29	7C
0005435252444	7372	30	7D
0005432838933	7372	31	7E
0005434458746	7372	32	7F
0005432838929	7372	33	8A
0005434458736	7372	34	8C
0005435252526	7372	35	8D
0005432838930	7372	36	8E
0005434458737	7372	37	8F
0005432838951	7372	38	9A
0005435252503	7372	39	9C
0005435252459	7372	40	9D
0005432823442	7372	41	9E
0005432838926	7372	42	9F
0005432073379	7372	43	10A
0005434458750	7372	44	10C
0005434458742	7372	45	10D
0005435252495	7372	46	10E
0005432838952	7372	47	11C
0005435252452	7372	48	11D
0005434458744	7372	49	11E
0005434458751	7372	50	11F
0005432838957	7372	51	12A
0005432838939	7372	52	12C
0005435252496	7372	53	12D
0005435252476	7372	54	12E
0005432838948	7372	55	12F
0005434458743	7372	56	13A
0005432838950	7372	57	13C
0005434458734	7372	58	13D
0005432838941	7372	59	13E
0005434458731	7372	60	13F
0005432838955	7372	61	14A
0005435252560	7372	62	14C
0005435252497	7372	63	14D
0005432841004	7372	64	14E
0005435252539	7372	65	14F
0005432838940	7372	66	15A
0005432838956	7372	67	15C
0005435252563	7372	68	15D
0005435252581	7372	69	15E
0005432838949	7372	70	15F
0005435491405	7372	71	16A
0005434664925	7372	72	16C
0005435252538	7372	73	16D
0005434458745	7372	74	16E
0005434458740	7372	75	16F
0005432841005	7372	76	17A
0005434458738	7372	77	17D
0005434458752	7372	78	17C
0005432838928	7372	79	17E
0005435252537	7372	80	17F
0005432838934	7372	81	18A
0005434458733	7372	82	18C
0005434458735	7372	83	18D
0005432838947	7372	84	18E
0005432838945	7372	85	18F
0005435252502	7372	86	19A
0005432073380	7372	87	19C
0005432823443	7372	88	19D
0005435252461	7372	89	19E
0005432838935	7372	90	19F
0005435252492	7372	91	20A
0005432838954	7372	92	20C
0005432838932	7372	93	20D
0005432838942	7372	94	20E
0005434458741	7372	95	20F
0005434458555	28919	1	1A
0005434458478	28919	2	1C
0005432838748	28919	3	1D
0005432838611	28919	4	1F
0005435491435	28919	5	2A
0005432838888	28919	6	2D
0005432838711	28919	7	2F
0005432001016	28919	8	3A
0005435252650	28919	9	3D
0005435491437	28919	10	3F
0005432840992	28919	11	4A
0005434458575	28919	12	4C
0005434458557	28919	13	4D
0005435252642	28919	14	4E
0005432838739	28919	15	4F
0005434458589	28919	16	5C
0005434458573	28919	17	5D
0005432838671	28919	18	5E
0005435252645	28919	19	5F
0005432838724	28919	20	6A
0005432838710	28919	21	6C
0005432838712	28919	22	6E
0005434458511	28919	23	7A
0005432838635	28919	24	7C
0005434458510	28919	25	7D
0005434458615	28919	26	7E
0005435252646	28919	27	8A
0005432838727	28919	28	8C
0005432838703	28919	29	8D
0005432838623	28919	30	9A
0005432838586	28919	31	9C
0005435252657	28919	32	9D
0005434458550	28919	33	9E
0005435252643	28919	34	9F
0005432838687	28919	35	10A
0005432838646	28919	36	10C
0005434458512	28919	37	10D
0005432838747	28919	38	10E
0005432838670	28919	39	10F
0005434458606	28919	40	11A
0005435252648	28919	41	11C
0005432838721	28919	42	11D
0005432838889	28919	43	11E
0005434458520	28919	44	11F
0005432838698	28919	45	12A
0005432838669	28919	46	12C
0005435252652	28919	47	12D
0005434458556	28919	48	12E
0005432823433	28919	49	13A
0005432838738	28919	50	13C
0005435252656	28919	51	13D
0005435252651	28919	52	13E
0005435252655	28919	53	14A
0005435252653	28919	54	14C
0005435252644	28919	55	14D
0005432838650	28919	56	14E
0005432838728	28919	57	14F
0005432838686	28919	58	15A
0005432838763	28919	59	15C
0005432838609	28919	60	15D
0005432838598	28919	61	16A
0005435252647	28919	62	16C
0005432838706	28919	63	16D
0005435491438	28919	64	16E
0005432838585	28919	65	16F
0005432838651	28919	66	17A
0005434458551	28919	67	17C
0005434458572	28919	68	17D
0005434458599	28919	69	17E
0005434458519	28919	70	17F
0005435252649	28919	71	18A
0005432838610	28919	72	18C
0005434458600	28919	73	18D
0005432001017	28919	74	18E
0005434664953	28919	75	18F
0005435252654	28919	76	19A
0005435491436	28919	77	19C
0005434664952	28919	78	19D
0005432838675	28919	79	19E
0005432838624	28919	80	19F
0005434458658	28919	81	20A
0005435252658	28919	82	20C
0005432838761	28919	83	20E
0005432838625	28919	84	20F
0005434275955	8807	1	4C
0005435990605	8807	2	6E
0005434275977	8807	3	7C
0005435990602	8807	4	9D
0005435990603	8807	5	11D
0005434275978	8807	6	13B
0005434275954	8807	7	13A
0005435990604	8807	8	14C
0005435990599	8807	9	14B
0005435990600	8807	10	17A
0005435990601	8807	11	17C
0005434275953	8807	12	19D
0005434275984	8807	13	20E
0005435990552	15737	1	3C
0005435990534	15737	2	3F
0005434276012	15737	3	4C
0005435990565	15737	4	5F
0005435990562	15737	5	6C
0005435990551	15737	6	6F
0005434276007	15737	7	7D
0005435990553	15737	8	8C
0005434276010	15737	9	9B
0005435990535	15737	10	10B
0005435990545	15737	11	11D
0005434276008	15737	12	11F
0005434276009	15737	13	12F
0005435990544	15737	14	14D
0005434276013	15737	15	16C
0005435990561	15737	16	16B
0005435990559	15737	17	16D
0005435990560	15737	18	17A
0005435990533	15737	19	17E
0005435990539	15737	20	18B
0005434276011	15737	21	20C
0005433468305	2098	1	1A
0005432909218	2098	2	1C
0005433468308	2098	3	1D
0005432909217	2098	4	2A
0005432909204	2098	5	2C
0005432909224	2098	6	3A
0005433468302	2098	7	3B
0005433468314	2098	8	3D
0005433468307	2098	9	4A
0005433468312	2098	10	4C
0005433468303	2098	11	4D
0005433468300	2098	12	5A
0005432909212	2098	13	5C
0005433468306	2098	14	6C
0005433468310	2098	15	6D
0005432909193	2098	16	7B
0005433468299	2098	17	7C
0005433468304	2098	18	18B
0005433468311	2098	19	18C
0005432909238	2098	20	18D
0005433468315	2098	21	19A
0005432909213	2098	22	19B
0005432909194	2098	23	19C
0005433468313	2098	24	20A
0005433468309	2098	25	20B
0005432909225	2098	26	20C
0005433468316	2098	27	21B
0005433468298	2098	28	21C
0005432909223	2098	29	22C
0005432909230	2098	30	22B
0005432909222	2098	31	22D
0005433468301	2098	32	23B
0005432335995	6417	1	1A
0005432360198	6417	2	1C
0005432360207	6417	3	1D
0005434149591	6417	4	2A
0005432336000	6417	5	1F
0005435176736	6417	6	2C
0005434149604	6417	7	2D
0005435176768	6417	8	2F
0005432360227	6417	9	3C
0005432360233	6417	10	3A
0005432360216	6417	11	3D
0005432360202	6417	12	3F
0005434149608	6417	13	4B
0005435176766	6417	14	4A
0005432360225	6417	15	4C
0005435176677	6417	16	4D
0005432360228	6417	17	4E
0005434149647	6417	18	4F
0005435176737	6417	19	5B
0005435176787	6417	20	5A
0005435176893	6417	21	5D
0005432360245	6417	22	5E
0005435176678	6417	23	6A
0005435176782	6417	24	6C
0005432360197	6417	25	6B
0005432335997	6417	26	6D
0005435723028	6417	27	6E
0005432360205	6417	28	7A
0005435490183	6417	29	6F
0005432360221	6417	30	7B
0005432360232	6417	31	7C
0005432360212	6417	32	7E
0005434149601	6417	33	7D
0005432336001	6417	34	7F
0005432360218	6417	35	8A
0005435176796	6417	36	8B
0005435176760	6417	37	8D
0005432363406	6417	38	8C
0005435176761	6417	39	8E
0005432062211	6417	40	9A
0005432363405	6417	41	9C
0005432360242	6417	42	9B
0005432360226	6417	43	9D
0005435176889	6417	44	9E
0005432360223	6417	45	9F
0005432360240	6417	46	10B
0005432360214	6417	47	10C
0005432363408	6417	48	10D
0005432360209	6417	49	11A
0005435176676	6417	50	10E
0005432360215	6417	51	11B
0005434149570	6417	52	11C
0005435176797	6417	53	11E
0005435723029	6417	54	11D
0005432360239	6417	55	11F
0005435176811	6417	56	12A
0005435723013	6417	57	12B
0005432360235	6417	58	12C
0005432360195	6417	59	12D
0005432360204	6417	60	12F
0005432336003	6417	61	13D
0005435176842	6417	62	13C
0005432360217	6417	63	13E
0005435176781	6417	64	13F
0005432062212	6417	65	14B
0005432360241	6417	66	14A
0005432360201	6417	67	14D
0005432360236	6417	68	14C
0005435490178	6417	69	14E
0005432360238	6417	70	15A
0005432360230	6417	71	14F
0005435176847	6417	72	15B
0005435176851	6417	73	15C
0005432336002	6417	74	15E
0005432360210	6417	75	15F
0005435176652	6417	76	16B
0005434149544	6417	77	16A
0005432360243	6417	78	16C
0005432336004	6417	79	16D
0005432360208	6417	80	16E
0005435176767	6417	81	17A
0005432360234	6417	82	16F
0005432363407	6417	83	17C
0005432360222	6417	84	17E
0005432360231	6417	85	17D
0005435490180	6417	86	17F
0005435176827	6417	87	18A
0005432360206	6417	88	18B
0005432360244	6417	89	18D
0005432360237	6417	90	18C
0005432360229	6417	91	18F
0005435490179	6417	92	18E
0005432360220	6417	93	19A
0005432360224	6417	94	19B
0005432062210	6417	95	19D
0005435176738	6417	96	19C
0005432360219	6417	97	19E
0005434149631	6417	98	19F
0005432360203	6417	99	20A
0005435176812	6417	100	20B
0005435176790	6417	101	20C
0005432335994	6417	102	20E
0005432360200	6417	103	20D
0005432360211	6417	104	20F
0005435176841	6417	105	21A
0005432360196	6417	106	21C
0005432335996	6417	107	21B
0005432360199	6417	108	21D
0005432062213	6417	109	21E
0005432062214	6417	110	21F
0005435490188	6417	111	22B
0005434149546	6417	112	22A
0005434149545	6417	113	22C
0005432335999	6417	114	22E
0005432360213	6417	115	23A
0005432335998	6417	116	23B
0005434149602	6417	117	23C
0005435176855	6417	118	23E
0005434149554	6417	119	23D
0005434149592	6417	120	23F
0005432359686	21028	1	1C
0005432363367	21028	2	1A
0005432359745	21028	3	1D
0005432359854	21028	4	2A
0005435723039	21028	5	1F
0005432052739	21028	6	2C
0005432359640	21028	7	2F
0005435176990	21028	8	2D
0005435176985	21028	9	3C
0005432359882	21028	10	3A
0005432359893	21028	11	3D
0005435176995	21028	12	3F
0005432359911	21028	13	4C
0005435176982	21028	14	4B
0005432359891	21028	15	4D
0005434149697	21028	16	4E
0005432359937	21028	17	4F
0005435176981	21028	18	5B
0005432359875	21028	19	5A
0005432335903	21028	20	5D
0005432359796	21028	21	5C
0005432335921	21028	22	5E
0005432359767	21028	23	6A
0005432052738	21028	24	5F
0005435177006	21028	25	6B
0005435177007	21028	26	6C
0005432359683	21028	27	6D
0005432359874	21028	28	6E
0005432359800	21028	29	6F
0005432359992	21028	30	7B
0005435176994	21028	31	7A
0005435723040	21028	32	7C
0005434149700	21028	33	7D
0005435176996	21028	34	7E
0005435177005	21028	35	8A
0005432359847	21028	36	7F
0005435176991	21028	37	8B
0005432359869	21028	38	8C
0005432359616	21028	39	8D
0005432335934	21028	40	8F
0005432360004	21028	41	8E
0005432335933	21028	42	9A
0005432359615	21028	43	9B
0005432359980	21028	44	9C
0005432359780	21028	45	9D
0005432363385	21028	46	9F
0005435176984	21028	47	10C
0005434149691	21028	48	10B
0005435177003	21028	49	10D
0005435176993	21028	50	10E
0005432359597	21028	51	11B
0005432359786	21028	52	11C
0005432335884	21028	53	11E
0005432335904	21028	54	11F
0005432363378	21028	55	12A
0005434149696	21028	56	12B
0005432359681	21028	57	12D
0005432359799	21028	58	12C
0005434149692	21028	59	12F
0005432359819	21028	60	13A
0005432359835	21028	61	13C
0005432359807	21028	62	13B
0005435176983	21028	63	13D
0005434149699	21028	64	13E
0005432359766	21028	65	13F
0005432359731	21028	66	14A
0005435176987	21028	67	14C
0005432359881	21028	68	14B
0005432359746	21028	69	14D
0005435176988	21028	70	14E
0005435177004	21028	71	15A
0005435176998	21028	72	14F
0005432359823	21028	73	15B
0005434149698	21028	74	15C
0005432359782	21028	75	15D
0005432359556	21028	76	15F
0005432359836	21028	77	15E
0005432359913	21028	78	16B
0005432359677	21028	79	16A
0005432359768	21028	80	16D
0005432359818	21028	81	16C
0005432052737	21028	82	16E
0005434149689	21028	83	17A
0005432360005	21028	84	16F
0005432359846	21028	85	17B
0005432359672	21028	86	17C
0005432359912	21028	87	17E
0005435176992	21028	88	17D
0005435176980	21028	89	18A
0005434149694	21028	90	17F
0005434149693	21028	91	18B
0005435176997	21028	92	18D
0005432359870	21028	93	18C
0005432052736	21028	94	18E
0005432359682	21028	95	18F
0005432359691	21028	96	19A
0005432359822	21028	97	19C
0005432359845	21028	98	19B
0005435490218	21028	99	19E
0005435176989	21028	100	19D
0005435490221	21028	101	19F
0005435177001	21028	102	20A
0005432335922	21028	103	20B
0005432359654	21028	104	20D
0005432359806	21028	105	20C
0005435177002	21028	106	20E
0005435490220	21028	107	20F
0005432359692	21028	108	21B
0005432359747	21028	109	21A
0005434149695	21028	110	21C
0005432359700	21028	111	21D
0005432335932	21028	112	21F
0005435177000	21028	113	22A
0005432359757	21028	114	22B
0005432359798	21028	115	22C
0005432359795	21028	116	22D
0005432335902	21028	117	22F
0005432359783	21028	118	22E
0005432359758	21028	119	23A
0005435490219	21028	120	23B
0005434149690	21028	121	23C
0005435176986	21028	122	23E
0005432335862	21028	123	23D
0005435176999	21028	124	23F
0005434458612	17718	1	1A
0005434448283	17718	2	1B
0005434458639	17718	3	1C
0005434458621	17718	4	2A
0005434458559	17718	5	2B
0005434458614	17718	6	2C
0005434458492	17718	7	2D
0005434458648	17718	8	3B
0005434458607	17718	9	4D
0005434458554	17718	10	5A
0005434458524	17718	11	5B
0005434458622	17718	12	5C
0005434458602	17718	13	6A
0005434458613	17718	14	6C
0005434458567	17718	15	7A
0005434186190	17718	16	7B
0005434458625	17718	17	7C
0005434458493	17718	18	18A
0005434458558	17718	19	18B
0005434458545	17718	20	18C
0005434458543	17718	21	18D
0005434458577	17718	22	19A
0005434458514	17718	23	19B
0005434458562	17718	24	19D
0005434186189	17718	25	20A
0005434458544	17718	26	20C
0005434458601	17718	27	21B
0005434458552	17718	28	21C
0005434186191	17718	29	21D
0005434458610	17718	30	22A
0005434458603	17718	31	22B
0005434458576	17718	32	22C
0005434458751	29135	1	1B
0005434186167	29135	2	1C
0005434448303	29135	3	2A
0005434458733	29135	4	2B
0005434458738	29135	5	3C
0005434458750	29135	6	3D
0005434458739	29135	7	4A
0005434458749	29135	8	4B
0005434458752	29135	9	4C
0005434463921	29135	10	4D
0005434458731	29135	11	5A
0005434462782	29135	12	5B
0005434458748	29135	13	5D
0005434186165	29135	14	6A
0005434463920	29135	15	6B
0005434462781	29135	16	6C
0005434448299	29135	17	6D
0005434458746	29135	18	7A
0005434458740	29135	19	7B
0005434458743	29135	20	7C
0005434458737	29135	21	18A
0005434458747	29135	22	18B
0005434186166	29135	23	19C
0005434458742	29135	24	19D
0005434458741	29135	25	20A
0005434458745	29135	26	20C
0005434458735	29135	27	20D
0005434458736	29135	28	21A
0005434448301	29135	29	21C
0005434458734	29135	30	21D
0005434458732	29135	31	22C
0005434458744	29135	32	22D
0005434448302	29135	33	23A
0005434448300	29135	34	23B
0005432604197	21457	1	1A
0005432604177	21457	2	1B
0005432604202	21457	3	1C
0005432604182	21457	4	1D
0005432604189	21457	5	2B
0005432604206	21457	6	2C
0005432604194	21457	7	2D
0005432604179	21457	8	3A
0005432604203	21457	9	3B
0005432604191	21457	10	3C
0005432604207	21457	11	4B
0005432604200	21457	12	4C
0005432604180	21457	13	5A
0005432604169	21457	14	5C
0005432604188	21457	15	6A
0005432604184	21457	16	6B
0005432604196	21457	17	6C
0005432604173	21457	18	6D
0005432604187	21457	19	7A
0005432604198	21457	20	7B
0005432604178	21457	21	7C
0005432604201	21457	22	7D
0005432604176	21457	23	18A
0005432604199	21457	24	18B
0005432604186	21457	25	18C
0005432604209	21457	26	18D
0005432604208	21457	27	19A
0005432604192	21457	28	19B
0005432604195	21457	29	19C
0005432604172	21457	30	19D
0005432604190	21457	31	20A
0005432604171	21457	32	20C
0005432604204	21457	33	20D
0005432604174	21457	34	21A
0005432604205	21457	35	21B
0005432604181	21457	36	21C
0005432604175	21457	37	22A
0005432604183	21457	38	22B
0005432604193	21457	39	22D
0005432604170	21457	40	23A
0005432604185	21457	41	23B
0005432603795	31684	1	1B
0005432603782	31684	2	1D
0005432603726	31684	3	2A
0005432603923	31684	4	3A
0005432603780	31684	5	3B
0005432603753	31684	6	3C
0005432603857	31684	7	3D
0005432603751	31684	8	4A
0005432603787	31684	9	4B
0005432603971	31684	10	4C
0005432603758	31684	11	4D
0005432603816	31684	12	5C
0005432603791	31684	13	5B
0005432603902	31684	14	5D
0005432603811	31684	15	6B
0005432603725	31684	16	6C
0005432603989	31684	17	6D
0005432603788	31684	18	7A
0005432603928	31684	19	7B
0005432603929	31684	20	7C
0005432603754	31684	21	7D
0005432604000	31684	22	18B
0005432603999	31684	23	18C
0005432603835	31684	24	18D
0005432603836	31684	25	19A
0005432603858	31684	26	19B
0005432603917	31684	27	19C
0005432603724	31684	28	19D
0005432603842	31684	29	20A
0005432603844	31684	30	20B
0005432603898	31684	31	20C
0005432603744	31684	32	20D
0005432603820	31684	33	21B
0005432603790	31684	34	21C
0005432603910	31684	35	21D
0005432603879	31684	36	22A
0005432603880	31684	37	22B
0005432603990	31684	38	22C
0005432603864	31684	39	22D
0005433293233	29606	1	1A
0005433293228	29606	2	1B
0005433293227	29606	3	6A
0005433293232	29606	4	6B
0005433293230	29606	5	7B
0005433293225	29606	6	7D
0005433293234	29606	7	18B
0005433293235	29606	8	18C
0005433293238	29606	9	19A
0005433293240	29606	10	19B
0005433293229	29606	11	21A
0005433293226	29606	12	21B
0005433293239	29606	13	21D
0005433293231	29606	14	22A
0005433293224	29606	15	22B
0005433293236	29606	16	23A
0005433293237	29606	17	23B
0005433473224	6696	1	1A
0005435257168	6696	2	1B
0005435257159	6696	3	1C
0005435257173	6696	4	1D
0005435257187	6696	5	2A
0005433473231	6696	6	2B
0005433473219	6696	7	2C
0005433473241	6696	8	2D
0005433473235	6696	9	3A
0005433473230	6696	10	3B
0005433473222	6696	11	3C
0005433473237	6696	12	3D
0005433473228	6696	13	4A
0005433473229	6696	14	4B
0005433473233	6696	15	4C
0005435257145	6696	16	5A
0005435257177	6696	17	5B
0005433473239	6696	18	5C
0005433473232	6696	19	6A
0005433473240	6696	20	6B
0005435257178	6696	21	6C
0005433473227	6696	22	6D
0005433473214	6696	23	7A
0005433473234	6696	24	7B
0005433473221	6696	25	7C
0005435257185	6696	26	7D
0005435257176	6696	27	18A
0005435257161	6696	28	18B
0005435257172	6696	29	18C
0005435257188	6696	30	18D
0005433473213	6696	31	19A
0005435257160	6696	32	19B
0005435257171	6696	33	19C
0005433473218	6696	34	19D
0005435257152	6696	35	20A
0005435257194	6696	36	20B
0005433473226	6696	37	20C
0005433473220	6696	38	20D
0005433473236	6696	39	21A
0005433473225	6696	40	21B
0005435257158	6696	41	21D
0005433473238	6696	42	22B
0005433473217	6696	43	22C
0005433473223	6696	44	22D
0005433473215	6696	45	23A
0005433473216	6696	46	23B
0005434606763	18906	1	4A
0005434606762	18906	2	5A
0005434606764	18906	3	6A
0005434606765	18906	4	6B
0005434606817	22285	1	1A
0005434604884	22285	2	1B
0005434604882	22285	3	2B
0005434606816	22285	4	3A
0005434606818	22285	5	3B
0005434604885	22285	6	4A
0005434604883	22285	7	4B
0005434606815	22285	8	5B
0005432747443	414	1	1A
0005432747441	414	2	1D
0005432747434	414	3	1F
0005432747437	414	4	2A
0005432890800	414	5	2D
0005432890834	414	6	3F
0005432747452	414	7	4C
0005432747438	414	8	4D
0005432747422	414	9	4E
0005432747429	414	10	4F
0005432747453	414	11	5A
0005432749777	414	12	5C
0005432747436	414	13	5D
0005432753289	414	14	5E
0005433293175	414	15	5F
0005432890698	414	16	6A
0005432890798	414	17	6C
0005432747449	414	18	6D
0005432747421	414	19	6E
0005432747450	414	20	6F
0005432890743	414	21	7A
0005432747435	414	22	7C
0005432890767	414	23	7D
0005432747426	414	24	7E
0005432747448	414	25	7F
0005432747442	414	26	8C
0005432747451	414	27	8D
0005432890848	414	28	8E
0005432747428	414	29	8F
0005432219987	414	30	9A
0005432747424	414	31	9C
0005432749775	414	32	9D
0005432747431	414	33	9E
0005432747447	414	34	10A
0005432753287	414	35	10C
0005432747445	414	36	10D
0005433875357	414	37	10E
0005432747416	414	38	10F
0005433293154	414	39	11A
0005432890766	414	40	11C
0005432753286	414	41	11D
0005432890815	414	42	11E
0005432747446	414	43	11F
0005432747423	414	44	12C
0005432890880	414	45	12E
0005432751512	414	46	12F
0005432747420	414	47	13C
0005432890830	414	48	13D
0005432890796	414	49	14A
0005432219989	414	50	14D
0005432747433	414	51	14E
0005432747439	414	52	14F
0005432219990	414	53	15A
0005432751513	414	54	15D
0005432747430	414	55	15E
0005432890729	414	56	15F
0005432747440	414	57	16A
0005432890768	414	58	16C
0005432890847	414	59	16D
0005432890846	414	60	16E
0005432890699	414	61	16F
0005432747417	414	62	17A
0005432747425	414	63	17C
0005432890797	414	64	17D
0005432753288	414	65	17E
0005432890810	414	66	17F
0005432890814	414	67	18A
0005433293176	414	68	18C
0005432219988	414	69	18D
0005433293177	414	70	18E
0005432747427	414	71	18F
0005432747455	414	72	19A
0005432747444	414	73	19C
0005432751514	414	74	19D
0005432747418	414	75	19E
0005432747454	414	76	19F
0005432747419	414	77	20A
0005432890809	414	78	20D
0005432747432	414	79	20E
0005432749776	414	80	20F
0005432749763	12080	1	1F
0005432747220	12080	2	2A
0005432890963	12080	3	2D
0005432890966	12080	4	2F
0005432747087	12080	5	3A
0005432746989	12080	6	3C
0005432746997	12080	7	3D
0005432747034	12080	8	3F
0005432747208	12080	9	4A
0005432746988	12080	10	4C
0005432753248	12080	11	4D
0005432890968	12080	12	4E
0005432890956	12080	13	5A
0005432747171	12080	14	5C
0005432890951	12080	15	5E
0005432747207	12080	16	5F
0005432747214	12080	17	6D
0005432747035	12080	18	6E
0005432756787	12080	19	6F
0005432890965	12080	20	7A
0005432747339	12080	21	7D
0005432890953	12080	22	7E
0005432890960	12080	23	7F
0005434153528	12080	24	8A
0005432753249	12080	25	8D
0005432749765	12080	26	8C
0005432747225	12080	27	8E
0005432890954	12080	28	9A
0005432749766	12080	29	9C
0005432747223	12080	30	9D
0005432890950	12080	31	9E
0005432890957	12080	32	10A
0005432890969	12080	33	10D
0005432746963	12080	34	10E
0005432753246	12080	35	10F
0005432890955	12080	36	11A
0005434153529	12080	37	11C
0005432890967	12080	38	11D
0005432747334	12080	39	11F
0005432890970	12080	40	12A
0005433875372	12080	41	12D
0005432747175	12080	42	12E
0005432747185	12080	43	13C
0005432890961	12080	44	13D
0005432890952	12080	45	13E
0005432747036	12080	46	14A
0005432747160	12080	47	14C
0005433875373	12080	48	14E
0005432747276	12080	49	14F
0005432747063	12080	50	15A
0005432747086	12080	51	15C
0005432747176	12080	52	15D
0005432746983	12080	53	15E
0005432890962	12080	54	15F
0005432747186	12080	55	16C
0005432747166	12080	56	16D
0005432747226	12080	57	16E
0005432214797	12080	58	17A
0005432756800	12080	59	17C
0005432747068	12080	60	17E
0005432747221	12080	61	18A
0005432214796	12080	62	18C
0005432747172	12080	63	18E
0005434153530	12080	64	18F
0005432890959	12080	65	19C
0005432753263	12080	66	19D
0005432753247	12080	67	19E
0005432890958	12080	68	20A
0005432890964	12080	69	20D
0005432747045	12080	70	20E
0005432749764	12080	71	20F
0005433531279	18942	1	1A
0005433524997	18942	2	1B
0005433524999	18942	3	2B
0005433533291	18942	4	3A
0005433524991	18942	5	3D
0005433533294	18942	6	4A
0005432927898	18942	7	4B
0005433525000	18942	8	4D
0005433533295	18942	9	5A
0005433524994	18942	10	5C
0005433525002	18942	11	5D
0005433524998	18942	12	6D
0005433524993	18942	13	7B
0005433525001	18942	14	7C
0005433524996	18942	15	7D
0005433533293	18942	16	18C
0005432927904	18942	17	19C
0005432927911	18942	18	19D
0005433524995	18942	19	21A
0005433524992	18942	20	21B
0005432927905	18942	21	22A
0005433531278	18942	22	22C
0005433533292	18942	23	22D
0005433524889	32515	1	1C
0005433527211	32515	2	1D
0005433524887	32515	3	2B
0005432927971	32515	4	2C
0005433524929	32515	5	3A
0005433531251	32515	6	3B
0005432927969	32515	7	4A
0005433524888	32515	8	4B
0005433527200	32515	9	4C
0005432927968	32515	10	5A
0005433524924	32515	11	5C
0005432927966	32515	12	5D
0005433524914	32515	13	6A
0005433524915	32515	14	7A
0005433527199	32515	15	7B
0005433524938	32515	16	18A
0005433527213	32515	17	7D
0005433527217	32515	18	18B
0005432927967	32515	19	18D
0005433524923	32515	20	19A
0005433527212	32515	21	19B
0005433524916	32515	22	19C
0005433524937	32515	23	19D
0005433527218	32515	24	20C
0005432927970	32515	25	21A
0005433524932	32515	26	21B
0005433524910	32515	27	21C
0005433524911	32515	28	21D
0005434823190	5270	1	1C
0005435372582	5270	2	1A
0005432121284	5270	3	1D
0005432121296	5270	4	1K
0005435372370	5270	5	2D
0005434823130	5270	6	2C
0005434823185	5270	7	2A
0005435372580	5270	8	2H
0005435386534	5270	9	2G
0005434823182	5270	10	3A
0005434823233	5270	11	2K
0005434823175	5270	12	3D
0005434558234	5270	13	3C
0005435372411	5270	14	3K
0005434823179	5270	15	3H
0005432121291	5270	16	3G
0005434823220	5270	17	4C
0005434823141	5270	18	4A
0005432121287	5270	19	4G
0005435735072	5270	20	4D
0005432121295	5270	21	5A
0005434823138	5270	22	5C
0005435372410	5270	23	5H
0005434823253	5270	24	5G
0005435149989	5270	25	5D
0005432396232	5270	26	11A
0005434823229	5270	27	5K
0005434823129	5270	28	11E
0005432823424	5270	29	11D
0005434823198	5270	30	12A
0005434823132	5270	31	12E
0005434823221	5270	32	12D
0005434823231	5270	33	12G
0005435372526	5270	34	12F
0005434558239	5270	35	12K
0005434823214	5270	36	12H
0005434823211	5270	37	13D
0005435372484	5270	38	13C
0005434823257	5270	39	13F
0005435386508	5270	40	13E
0005434823236	5270	41	13H
0005435372391	5270	42	13G
0005434823173	5270	43	14C
0005434558237	5270	44	14A
0005435149984	5270	45	13K
0005434823212	5270	46	14D
0005434823222	5270	47	14E
0005434823234	5270	48	14H
0005434823227	5270	49	15C
0005435372352	5270	50	15A
0005435149979	5270	51	15F
0005435661899	5270	52	15E
0005434823197	5270	53	15D
0005435299713	5270	54	15G
0005435372476	5270	55	16A
0005434823204	5270	56	15K
0005435372267	5270	57	16D
0005435304114	5270	58	16C
0005432823425	5270	59	16F
0005434823162	5270	60	16K
0005435372610	5270	61	16G
0005434823215	5270	62	17A
0005435372165	5270	63	17E
0005434823154	5270	64	17D
0005434823250	5270	65	17H
0005434823238	5270	66	17G
0005435372733	5270	67	17F
0005434823161	5270	68	18A
0005434823142	5270	69	17K
0005435372463	5270	70	18C
0005432121294	5270	71	18B
0005434823225	5270	72	18E
0005434823163	5270	73	18F
0005434823202	5270	74	18H
0005434823210	5270	75	19B
0005432121292	5270	76	19A
0005435372611	5270	77	19C
0005434823251	5270	78	19F
0005434823217	5270	79	19E
0005434823207	5270	80	19H
0005434823258	5270	81	19G
0005434823177	5270	82	19K
0005432121285	5270	83	20C
0005434823174	5270	84	20A
0005434823131	5270	85	20D
0005432396230	5270	86	20H
0005435372386	5270	87	20J
0005435149991	5270	88	21B
0005432121297	5270	89	21A
0005434823139	5270	90	21C
0005435299712	5270	91	21G
0005434823167	5270	92	21K
0005435149985	5270	93	22C
0005434823228	5270	94	22B
0005435735087	5270	95	22F
0005435372095	5270	96	22H
0005434828686	5270	97	22G
0005434831133	5270	98	22K
0005435372543	5270	99	22J
0005435149987	5270	100	23B
0005435372404	5270	101	23A
0005432394091	5270	102	23F
0005432394092	5270	103	23J
0005434823242	5270	104	24D
0005435372456	5270	105	23K
0005434823203	5270	106	24F
0005435372394	5270	107	24E
0005435372367	5270	108	25A
0005435372429	5270	109	25E
0005434823199	5270	110	25H
0005434831131	5270	111	26A
0005434558240	5270	112	25K
0005434823241	5270	113	25J
0005435304113	5270	114	26B
0005434823152	5270	115	26E
0005435149993	5270	116	26D
0005434823223	5270	117	26F
0005434823193	5270	118	26J
0005434823209	5270	119	26H
0005435661898	5270	120	27B
0005434823159	5270	121	27A
0005434823194	5270	122	26K
0005435372421	5270	123	27F
0005435372333	5270	124	27E
0005435372306	5270	125	27D
0005434823216	5270	126	27H
0005434828687	5270	127	27K
0005434823148	5270	128	27J
0005435372351	5270	129	28B
0005434558235	5270	130	28E
0005435372508	5270	131	28C
0005435372288	5270	132	28G
0005435372405	5270	133	28H
0005434823235	5270	134	29B
0005434823186	5270	135	29F
0005435372440	5270	136	29E
0005434823232	5270	137	29K
0005435372308	5270	138	29J
0005434823147	5270	139	30B
0005434823181	5270	140	30E
0005435372425	5270	141	30G
0005434823237	5270	142	30F
0005434823168	5270	143	30J
0005434823200	5270	144	31A
0005435149992	5270	145	31C
0005432396229	5270	146	31G
0005435372507	5270	147	31F
0005434831129	5270	148	31E
0005432396231	5270	149	31H
0005434558236	5270	150	32A
0005434823136	5270	151	31K
0005435372296	5270	152	31J
0005435372309	5270	153	32B
0005434823243	5270	154	32E
0005435372277	5270	155	32D
0005435372366	5270	156	32G
0005435372259	5270	157	32K
0005435372338	5270	158	32J
0005435372266	5270	159	33A
0005435735079	5270	160	33C
0005434823143	5270	161	33F
0005434558241	5270	162	33K
0005434823213	5270	163	33J
0005435372231	5270	164	34C
0005434823149	5270	165	34A
0005434823240	5270	166	34E
0005435372310	5270	167	34G
0005434823244	5270	168	34F
0005434823165	5270	169	34K
0005434823247	5270	170	34H
0005434823176	5270	171	35B
0005435372424	5270	172	35A
0005435386510	5270	173	35D
0005434823192	5270	174	35C
0005434823188	5270	175	35G
0005434823191	5270	176	35F
0005434823160	5270	177	35E
0005434823172	5270	178	35J
0005434664951	5270	179	35H
0005435149982	5270	180	35K
0005434823189	5270	181	36C
0005434823157	5270	182	36B
0005434823205	5270	183	36F
0005434823206	5270	184	36H
0005434823169	5270	185	36K
0005434823178	5270	186	37B
0005434823195	5270	187	37D
0005434823208	5270	188	37C
0005434823150	5270	189	37G
0005434823219	5270	190	37F
0005434823260	5270	191	37E
0005435372594	5270	192	37K
0005435372243	5270	193	37J
0005435372515	5270	194	38C
0005434823135	5270	195	38J
0005434823249	5270	196	39B
0005434823224	5270	197	39A
0005435372533	5270	198	39D
0005435372614	5270	199	39F
0005434823252	5270	200	39E
0005435386465	5270	201	39H
0005434823183	5270	202	39G
0005435372823	5270	203	39K
0005434823246	5270	204	39J
0005434823239	5270	205	40C
0005435386481	5270	206	40B
0005435372354	5270	207	40E
0005434831132	5270	208	40F
0005435149981	5270	209	40J
0005434558242	5270	210	40H
0005434823230	5270	211	41A
0005435372477	5270	212	40K
0005435372542	5270	213	41G
0005432121286	5270	214	41F
0005435299714	5270	215	41J
0005435149980	5270	216	42A
0005434823187	5270	217	41K
0005435372669	5270	218	42C
0005435372576	5270	219	42E
0005434823196	5270	220	42D
0005435372675	5270	221	42H
0005434828685	5270	222	42F
0005435149983	5270	223	42J
0005432121289	5270	224	43A
0005435372581	5270	225	42K
0005435372591	5270	226	43D
0005434823180	5270	227	43B
0005434558243	5270	228	43F
0005432121288	5270	229	43E
0005434823144	5270	230	43H
0005434823153	5270	231	43G
0005435372278	5270	232	44A
0005432394093	5270	233	44C
0005434823255	5270	234	44B
0005434823201	5270	235	44E
0005435149990	5270	236	44D
0005434823134	5270	237	44F
0005434823171	5270	238	44J
0005435735070	5270	239	44H
0005435372713	5270	240	45B
0005435372337	5270	241	45A
0005435149988	5270	242	44K
0005435372419	5270	243	45C
0005435735080	5270	244	45F
0005434823245	5270	245	45E
0005432121293	5270	246	45H
0005434823146	5270	247	45G
0005434831130	5270	248	46A
0005432121290	5270	249	46C
0005434823170	5270	250	46D
0005434823218	5270	251	46G
0005434823133	5270	252	46F
0005434823156	5270	253	46K
0005432394090	5270	254	46J
0005435299715	5270	255	47A
0005434823254	5270	256	47D
0005434823184	5270	257	47E
0005434823145	5270	258	47K
0005435372289	5270	259	47H
0005434823256	5270	260	48D
0005434823248	5270	261	48C
0005434823155	5270	262	48A
0005434558238	5270	263	48E
0005435735073	5270	264	48G
0005434823137	5270	265	49D
0005435372478	5270	266	49C
0005434823151	5270	267	49F
0005434823140	5270	268	49H
0005434558233	5270	269	49G
0005435372307	5270	270	50C
0005435372457	5270	271	50A
0005434823226	5270	272	50E
0005434823259	5270	273	50D
0005435372420	5270	274	50G
0005434823158	5270	275	50F
0005435386509	5270	276	51D
0005434823164	5270	277	50K
0005435149986	5270	278	50H
0005434823166	5270	279	51E
0005435372620	5270	280	51G
0005435386559	9889	1	1A
0005434821944	9889	2	1H
0005435299762	9889	3	1G
0005434822109	9889	4	1D
0005434822039	9889	5	2D
0005434822155	9889	6	2C
0005434822093	9889	7	2H
0005435373086	9889	8	3A
0005435373042	9889	9	3C
0005434821979	9889	10	3K
0005434558154	9889	11	3H
0005434822188	9889	12	3G
0005435373083	9889	13	4C
0005435373032	9889	14	4G
0005435735127	9889	15	4D
0005434821703	9889	16	4K
0005434822044	9889	17	5D
0005434821709	9889	18	11A
0005435373061	9889	19	5K
0005435373035	9889	20	11D
0005434821929	9889	21	11F
0005435373041	9889	22	11E
0005435386561	9889	23	11H
0005434822110	9889	24	12C
0005434821849	9889	25	12E
0005434822250	9889	26	12D
0005434828660	9889	27	12G
0005434822078	9889	28	12F
0005434822030	9889	29	13A
0005435661923	9889	30	12K
0005434821839	9889	31	13D
0005435373076	9889	32	13C
0005434828658	9889	33	13F
0005434828665	9889	34	13H
0005434822495	9889	35	13G
0005435373047	9889	36	14A
0005434822282	9889	37	13K
0005434822013	9889	38	14E
0005435149900	9889	39	14D
0005435373074	9889	40	14C
0005432203037	9889	41	14F
0005435735128	9889	42	14H
0005434822029	9889	43	14G
0005435179691	9889	44	15C
0005435373094	9889	45	15A
0005434822099	9889	46	15D
0005434822325	9889	47	16D
0005434822153	9889	48	16E
0005434822265	9889	49	16K
0005434822450	9889	50	16H
0005435373039	9889	51	16G
0005434821819	9889	52	17C
0005434821701	9889	53	17G
0005434821900	9889	54	17F
0005435386558	9889	55	17K
0005434822464	9889	56	17H
0005434664935	9889	57	18E
0005435373070	9889	58	18D
0005435373052	9889	59	18G
0005434822106	9889	60	18F
0005434822053	9889	61	18J
0005435302188	9889	62	18H
0005434828657	9889	63	19B
0005434558153	9889	64	19A
0005434822646	9889	65	19C
0005434822645	9889	66	19F
0005435373030	9889	67	19E
0005434822281	9889	68	19H
0005434821660	9889	69	19G
0005434822105	9889	70	20A
0005435299760	9889	71	20B
0005434821921	9889	72	20E
0005434822045	9889	73	20D
0005435373077	9889	74	20G
0005435373081	9889	75	20K
0005434822376	9889	76	20H
0005434822113	9889	77	21B
0005435373088	9889	78	21A
0005435373040	9889	79	21D
0005434821584	9889	80	21C
0005435386560	9889	81	21G
0005434821978	9889	82	21F
0005435373080	9889	83	21E
0005434831082	9889	84	21J
0005434821770	9889	85	22B
0005434822114	9889	86	22E
0005434822299	9889	87	22D
0005434822448	9889	88	22G
0005434828659	9889	89	22F
0005435373072	9889	90	22K
0005435149873	9889	91	22J
0005434822022	9889	92	22H
0005434822283	9889	93	23B
0005435299763	9889	94	23A
0005435149868	9889	95	23D
0005434821713	9889	96	23C
0005435149869	9889	97	23F
0005435373034	9889	98	23E
0005434822167	9889	99	23H
0005434822098	9889	100	23G
0005434558172	9889	101	23J
0005435149811	9889	102	24F
0005435373053	9889	103	24E
0005434822440	9889	104	24D
0005435299759	9889	105	25B
0005435373043	9889	106	25A
0005434821561	9889	107	24G
0005434822095	9889	108	25D
0005435373045	9889	109	25H
0005434821835	9889	110	25G
0005434822266	9889	111	25K
0005435373082	9889	112	25J
0005434822354	9889	113	26B
0005435373048	9889	114	26A
0005435373029	9889	115	26E
0005434822478	9889	116	26D
0005434821811	9889	117	26G
0005434822112	9889	118	26F
0005434822076	9889	119	26K
0005435735129	9889	120	26J
0005434821919	9889	121	27A
0005434822324	9889	122	27D
0005435373091	9889	123	27C
0005434831090	9889	124	27B
0005434558162	9889	125	27F
0005432400065	9889	126	27H
0005435373084	9889	127	27G
0005435373071	9889	128	28A
0005435373067	9889	129	27K
0005432203040	9889	130	27J
0005435373092	9889	131	28E
0005434828655	9889	132	28D
0005434822014	9889	133	28G
0005434821836	9889	134	28F
0005434821782	9889	135	28K
0005434821467	9889	136	29B
0005434822284	9889	137	29A
0005434821613	9889	138	29D
0005434831083	9889	139	29H
0005432203038	9889	140	29G
0005434822577	9889	141	29J
0005434822122	9889	142	30C
0005434822158	9889	143	30B
0005435373059	9889	144	30E
0005434822209	9889	145	30D
0005435149812	9889	146	30F
0005435373062	9889	147	30K
0005434822292	9889	148	30J
0005435373064	9889	149	30H
0005434664922	9889	150	31B
0005435735126	9889	151	31D
0005435302185	9889	152	31C
0005434821750	9889	153	31F
0005434831099	9889	154	31E
0005434822205	9889	155	31H
0005432203044	9889	156	31G
0005434822486	9889	157	32A
0005434822092	9889	158	31K
0005435373057	9889	159	32C
0005434558173	9889	160	32B
0005432396201	9889	161	32E
0005435373073	9889	162	32D
0005434822362	9889	163	32G
0005434831098	9889	164	32F
0005434822249	9889	165	32J
0005435386556	9889	166	33B
0005435373069	9889	167	33A
0005432203043	9889	168	32K
0005434821840	9889	169	33D
0005435149882	9889	170	33C
0005434822077	9889	171	33E
0005435373028	9889	172	33H
0005434822177	9889	173	33G
0005434821975	9889	174	34A
0005435735130	9889	175	33K
0005434822108	9889	176	34B
0005434821710	9889	177	34E
0005434558187	9889	178	34D
0005434821564	9889	179	34G
0005434822291	9889	180	34F
0005435373068	9889	181	34K
0005434821989	9889	182	35B
0005434822062	9889	183	35A
0005435386555	9889	184	35D
0005434822121	9889	185	35E
0005434828662	9889	186	35H
0005435373049	9889	187	35G
0005434822166	9889	188	36A
0005434821841	9889	189	35J
0005435373089	9889	190	36D
0005435373066	9889	191	36G
0005434822159	9889	192	36K
0005435373036	9889	193	36J
0005435373044	9889	194	36H
0005434822479	9889	195	37B
0005434821363	9889	196	37A
0005435373079	9889	197	37D
0005435373055	9889	198	37F
0005434822701	9889	199	37E
0005435373037	9889	200	37H
0005434558182	9889	201	38A
0005435373046	9889	202	38C
0005434822246	9889	203	38B
0005434821947	9889	204	38J
0005434822247	9889	205	39A
0005435373058	9889	206	39D
0005434828656	9889	207	39B
0005434821812	9889	208	39F
0005434558146	9889	209	39E
0005434821737	9889	210	39J
0005435373054	9889	211	39H
0005434821920	9889	212	39K
0005435373065	9889	213	40C
0005435149855	9889	214	40B
0005435661922	9889	215	40D
0005434822278	9889	216	40G
0005434821818	9889	217	40K
0005435299761	9889	218	40J
0005435373078	9889	219	41B
0005434822377	9889	220	41D
0005434822494	9889	221	41C
0005434821583	9889	222	41F
0005434822447	9889	223	41E
0005435373033	9889	224	41H
0005434558163	9889	225	42A
0005434822115	9889	226	41K
0005435302187	9889	227	42C
0005435373051	9889	228	42B
0005435661921	9889	229	42D
0005434821943	9889	230	42F
0005434822061	9889	231	42K
0005434821930	9889	232	42J
0005434822063	9889	233	42H
0005434828654	9889	234	43B
0005435302186	9889	235	43D
0005432203042	9889	236	43C
0005435373063	9889	237	43F
0005434822361	9889	238	43E
0005434664932	9889	239	43J
0005435373031	9889	240	44A
0005435373038	9889	241	44C
0005434822715	9889	242	44E
0005435149785	9889	243	44D
0005434822248	9889	244	44G
0005434822508	9889	245	44H
0005435373060	9889	246	44K
0005434821562	9889	247	45D
0005435373056	9889	248	45F
0005434822714	9889	249	45E
0005434821738	9889	250	45G
0005432203041	9889	251	46A
0005435373075	9889	252	45J
0005434821899	9889	253	46C
0005435386557	9889	254	46B
0005435149786	9889	255	46G
0005432203039	9889	256	46F
0005434821803	9889	257	46J
0005434822088	9889	258	46H
0005434821977	9889	259	47E
0005435373093	9889	260	47G
0005434822465	9889	261	47F
0005435373050	9889	262	48A
0005435373085	9889	263	47H
0005435735125	9889	264	48D
0005434822154	9889	265	48H
0005434821714	9889	266	49A
0005434821853	9889	267	48K
0005434822485	9889	268	49E
0005435373087	9889	269	49D
0005435373090	9889	270	49F
0005434822449	9889	271	49G
0005434821702	9889	272	50A
0005435386554	9889	273	50E
0005434821781	9889	274	50G
0005434821834	9889	275	51D
0005435373027	9889	276	50K
0005434821901	9889	277	50H
0005434822100	9889	278	51E
0005434558171	9889	279	51G
0005435082768	6987	1	3A
0005435790297	6987	2	4D
0005435082765	6987	3	5A
0005435082766	6987	4	7C
0005435082767	6987	5	7D
0005435082764	6987	6	18A
0005435082770	6987	7	19A
0005435790298	6987	8	20C
0005435790296	6987	9	22B
0005435082769	6987	10	23A
0005435082692	25989	1	1D
0005435082702	25989	2	5C
0005435082703	25989	3	6A
0005435082679	25989	4	18C
0005435082691	25989	5	19B
0005435082701	25989	6	19D
0005435082693	25989	7	20D
0005435082690	25989	8	22C
0005435082678	25989	9	22D
0005434213899	9559	1	1A
0005434213885	9559	2	1C
0005434756308	9559	3	1D
0005434756311	9559	4	1F
0005434756292	9559	5	2A
0005434213985	9559	6	2C
0005434756324	9559	7	2D
0005434756306	9559	8	2F
0005434756295	9559	9	3A
0005434213889	9559	10	3C
0005434213907	9559	11	3D
0005434756319	9559	12	3F
0005434756312	9559	13	4A
0005434213817	9559	14	4C
0005434756328	9559	15	4D
0005434214036	9559	16	4E
0005434213833	9559	17	4F
0005434213984	9559	18	5A
0005434756325	9559	19	5C
0005434756322	9559	20	5D
0005434756310	9559	21	5E
0005434756299	9559	22	5F
0005434213862	9559	23	6A
0005434756304	9559	24	6C
0005434213942	9559	25	6D
0005434213824	9559	26	6F
0005434214104	9559	27	7A
0005434756291	9559	28	7C
0005434756293	9559	29	7D
0005434756318	9559	30	7E
0005434756313	9559	31	7F
0005434213935	9559	32	8A
0005434756289	9559	33	8C
0005434756300	9559	34	8D
0005434756309	9559	35	8F
0005434213914	9559	36	9A
0005434213878	9559	37	9C
0005434214019	9559	38	9D
0005434213988	9559	39	9E
0005434214057	9559	40	10A
0005434213834	9559	41	10C
0005434214025	9559	42	10D
0005434756290	9559	43	10E
0005434756288	9559	44	10F
0005434213994	9559	45	11A
0005434756307	9559	46	11C
0005434213943	9559	47	11D
0005434756298	9559	48	11E
0005434213932	9559	49	11F
0005434756321	9559	50	12A
0005434213782	9559	51	12C
0005434213957	9559	52	12D
0005434214004	9559	53	12E
0005434756315	9559	54	12F
0005434756287	9559	55	13A
0005434213971	9559	56	13C
0005434756327	9559	57	13D
0005434756317	9559	58	13E
0005434756316	9559	59	13F
0005434213955	9559	60	14A
0005434213848	9559	61	14C
0005434213931	9559	62	14D
0005434213986	9559	63	14E
0005434213781	9559	64	14F
0005434214047	9559	65	15A
0005434213924	9559	66	15C
0005434213852	9559	67	15D
0005434213915	9559	68	15E
0005434756296	9559	69	15F
0005434213939	9559	70	16A
0005434213987	9559	71	16C
0005434213954	9559	72	16D
0005434756314	9559	73	16E
0005434756320	9559	74	16F
0005434756305	9559	75	17A
0005434214109	9559	76	17C
0005434756303	9559	77	17D
0005434213823	9559	78	17E
0005434213995	9559	79	17F
0005434756326	9559	80	18A
0005434214046	9559	81	18C
0005434213830	9559	82	18D
0005434756301	9559	83	18E
0005434756297	9559	84	18F
0005434756294	9559	85	19A
0005434214029	9559	86	19C
0005434214059	9559	87	19D
0005434756323	9559	88	19E
0005434213956	9559	89	20A
0005434213944	9559	90	20C
0005434756302	9559	91	20D
0005434214108	9559	92	20E
0005434213993	9559	93	20F
0005434755847	28595	1	1A
0005434755789	28595	2	1C
0005434755851	28595	3	1D
0005434755999	28595	4	1F
0005434755751	28595	5	2A
0005434214359	28595	6	2C
0005434214347	28595	7	2D
0005434214348	28595	8	2F
0005434755715	28595	9	3A
0005434756015	28595	10	3C
0005434756019	28595	11	3D
0005434755901	28595	12	3F
0005434755775	28595	13	4A
0005434214327	28595	14	4C
0005434755805	28595	15	4D
0005434214346	28595	16	4E
0005434214340	28595	17	4F
0005434755995	28595	18	5A
0005434755965	28595	19	5C
0005434214342	28595	20	5D
0005434755827	28595	21	5E
0005434214337	28595	22	5F
0005434214336	28595	23	6A
0005434755821	28595	24	6C
0005434755986	28595	25	6D
0005434214354	28595	26	6E
0005434214335	28595	27	6F
0005434214344	28595	28	7A
0005434755918	28595	29	7C
0005434755842	28595	30	7D
0005434755745	28595	31	7E
0005434755826	28595	32	7F
0005434755716	28595	33	8A
0005434214351	28595	34	8C
0005434214332	28595	35	8D
0005434214333	28595	36	8E
0005434755788	28595	37	8F
0005434214324	28595	38	9A
0005434214352	28595	39	9C
0005434755957	28595	40	9D
0005434755804	28595	41	9E
0005434214322	28595	42	9F
0005434214363	28595	43	10A
0005434755713	28595	44	10C
0005434214343	28595	45	10D
0005434214353	28595	46	10E
0005434214338	28595	47	10F
0005434214330	28595	48	11A
0005434214356	28595	49	11C
0005434755832	28595	50	11E
0005434755935	28595	51	11F
0005434214349	28595	52	12A
0005434755744	28595	53	12C
0005434214345	28595	54	12D
0005434755885	28595	55	12E
0005434214325	28595	56	12F
0005434214318	28595	57	13A
0005434214329	28595	58	13C
0005434755714	28595	59	13E
0005434755998	28595	60	13F
0005434755828	28595	61	14A
0005434755867	28595	62	14C
0005434214358	28595	63	14D
0005434755936	28595	64	14F
0005434755848	28595	65	15A
0005434755785	28595	66	15D
0005434756018	28595	67	15C
0005434214362	28595	68	15E
0005434214360	28595	69	16A
0005434214326	28595	70	16D
0005434755877	28595	71	16C
0005434214331	28595	72	16E
0005434214357	28595	73	16F
0005434755917	28595	74	17A
0005434755841	28595	75	17C
0005434214355	28595	76	17D
0005434755911	28595	77	17E
0005434214341	28595	78	17F
0005434756028	28595	79	18A
0005434755784	28595	80	18C
0005434214339	28595	81	18D
0005434214317	28595	82	18E
0005434214319	28595	83	19A
0005434755774	28595	84	19C
0005434214323	28595	85	19D
0005434755886	28595	86	19E
0005434214334	28595	87	19F
0005434214321	28595	88	20A
0005434214350	28595	89	20C
0005434214320	28595	90	20D
0005434214361	28595	91	20E
0005434214328	28595	92	20F
0005435100113	10813	1	1A
0005435100114	10813	2	1D
0005434760162	10813	3	7B
0005435100112	10813	4	18C
0005434760161	10813	5	19C
0005434760171	10813	6	21C
0005435100093	31797	1	2A
0005434760189	31797	2	2B
0005435100074	31797	3	3A
0005435100096	31797	4	3B
0005434760188	31797	5	3C
0005435100094	31797	6	6A
0005434760190	31797	7	23A
0005434639258	1976	1	1A
0005434639264	1976	2	1B
0005433202240	1976	3	1C
0005433202219	1976	4	2A
0005434639248	1976	5	2B
0005433202141	1976	6	2C
0005434639259	1976	7	2D
0005433202221	1976	8	3A
0005434639246	1976	9	3B
0005434639261	1976	10	3C
0005433202164	1976	11	3D
0005434639263	1976	12	4B
0005434639250	1976	13	4C
0005432290625	1976	14	5A
0005432290624	1976	15	5C
0005435948325	1976	16	5D
0005432290623	1976	17	6A
0005433202156	1976	18	6B
0005434639241	1976	19	6C
0005433202205	1976	20	6D
0005434639256	1976	21	7A
0005434639262	1976	22	7B
0005434639244	1976	23	7C
0005434639255	1976	24	7D
0005434639254	1976	25	18A
0005434639247	1976	26	18B
0005434639240	1976	27	18D
0005433202202	1976	28	19A
0005434639251	1976	29	19B
0005433202182	1976	30	19C
0005434639242	1976	31	19D
0005434639260	1976	32	20A
0005433202142	1976	33	20B
0005434639245	1976	34	20C
0005433202220	1976	35	20D
0005434639257	1976	36	21A
0005434639252	1976	37	21B
0005434639253	1976	38	21C
0005435948326	1976	39	21D
0005434639243	1976	40	22A
0005434639249	1976	41	22B
0005434639238	1976	42	22C
0005434639239	1976	43	22D
0005433202203	1976	44	23A
0005433202204	1976	45	23B
0005433202300	23304	1	1A
0005434639033	23304	2	1B
0005433202301	23304	3	1C
0005434638985	23304	4	1D
0005434639031	23304	5	2A
0005434638958	23304	6	2B
0005433202310	23304	7	2C
0005433202311	23304	8	2D
0005434638938	23304	9	3A
0005434638975	23304	10	3B
0005433202307	23304	11	3C
0005434639038	23304	12	4A
0005434638954	23304	13	4B
0005434639029	23304	14	4C
0005434638909	23304	15	4D
0005434638995	23304	16	5A
0005434638907	23304	17	5B
0005434639073	23304	18	5C
0005434638996	23304	19	5D
0005434639013	23304	20	6A
0005433202309	23304	21	6B
0005433202305	23304	22	6C
0005434638910	23304	23	6D
0005434638937	23304	24	7B
0005434638926	23304	25	7C
0005434638957	23304	26	7D
0005434638919	23304	27	18A
0005434638921	23304	28	18B
0005434639015	23304	29	18C
0005434639030	23304	30	18D
0005434639032	23304	31	19A
0005434638959	23304	32	19B
0005433202298	23304	33	19C
0005433202312	23304	34	19D
0005434638981	23304	35	20A
0005434639014	23304	36	20B
0005433202302	23304	37	20C
0005433202299	23304	38	21A
0005434638939	23304	39	20D
0005434638920	23304	40	21B
0005434639064	23304	41	21C
0005433202308	23304	42	21D
0005433202303	23304	43	22A
0005434639003	23304	44	22B
0005433202306	23304	45	22C
0005434638961	23304	46	22D
0005433202304	23304	47	23A
0005434638960	23304	48	23B
0005435326583	6065	1	1A
0005435326553	6065	2	1D
0005434600739	6065	3	2C
0005434600727	6065	4	2D
0005434600730	6065	5	3A
0005434600732	6065	6	3D
0005435326585	6065	7	4C
0005434600721	6065	8	4D
0005433533299	6065	9	4E
0005433531281	6065	10	5C
0005433531283	6065	11	5E
0005434600724	6065	12	5F
0005435326575	6065	13	6C
0005432111270	6065	14	6D
0005434600722	6065	15	6F
0005434600740	6065	16	7A
0005434600734	6065	17	7D
0005434600713	6065	18	8A
0005434600714	6065	19	8C
0005434600737	6065	20	8D
0005434600738	6065	21	8E
0005435326591	6065	22	8F
0005434600731	6065	23	9A
0005434600735	6065	24	9C
0005435326609	6065	25	9F
0005434600718	6065	26	10A
0005432111269	6065	27	10D
0005435326560	6065	28	10E
0005434600736	6065	29	10F
0005434600719	6065	30	11C
0005434600723	6065	31	11E
0005433533296	6065	32	12A
0005435326579	6065	33	13A
0005435326584	6065	34	13D
0005433533298	6065	35	14D
0005435326599	6065	36	15A
0005435326578	6065	37	15C
0005433531282	6065	38	15D
0005435326590	6065	39	15E
0005433531280	6065	40	15F
0005434600733	6065	41	16D
0005433533297	6065	42	17A
0005434600725	6065	43	17D
0005434600726	6065	44	18A
0005434600728	6065	45	18C
0005432111268	6065	46	18D
0005435326561	6065	47	18E
0005434600729	6065	48	18F
0005434600720	6065	49	19F
0005434600715	6065	50	20A
0005434600716	6065	51	20D
0005435326623	6065	52	20E
0005434600717	6065	53	20F
0005435326699	18594	1	1A
0005434600522	18594	2	1C
0005433531262	18594	3	1F
0005434600392	18594	4	2C
0005435326704	18594	5	3A
0005435326698	18594	6	3C
0005435326700	18594	7	3F
0005435326696	18594	8	4F
0005434600437	18594	9	5C
0005434600556	18594	10	5D
0005434600530	18594	11	6D
0005434600557	18594	12	6E
0005434600504	18594	13	6F
0005435326707	18594	14	7E
0005435326702	18594	15	7F
0005434600555	18594	16	8A
0005434600532	18594	17	8D
0005434600327	18594	18	8E
0005434600453	18594	19	8F
0005434600561	18594	20	9A
0005434600406	18594	21	9D
0005434600562	18594	22	10C
0005435326701	18594	23	10E
0005433531261	18594	24	10F
0005435326697	18594	25	11A
0005434600508	18594	26	11E
0005434600537	18594	27	11F
0005435326706	18594	28	12F
0005434600494	18594	29	13A
0005434600328	18594	30	13F
0005434600476	18594	31	14A
0005434600489	18594	32	14C
0005434600526	18594	33	14D
0005434600563	18594	34	14E
0005434600478	18594	35	14F
0005435326708	18594	36	15A
0005435326709	18594	37	15D
0005435326705	18594	38	15E
0005434600568	18594	39	16D
0005435326703	18594	40	17D
0005434600486	18594	41	17E
0005434600487	18594	42	17F
0005434600490	18594	43	18D
0005434600517	18594	44	18E
0005434600497	18594	45	18F
0005433527221	18594	46	19C
0005435326710	18594	47	19D
0005434600488	18594	48	19E
0005434600461	18594	49	19F
0005434600531	18594	50	20A
0005434600535	18594	51	20C
0005433531238	18594	52	20E
0005434551024	10662	1	1A
0005434551025	10662	2	1C
0005434558230	10662	3	1D
0005433180872	10662	4	1F
0005434551034	10662	5	2A
0005434550991	10662	6	2C
0005434550988	10662	7	2D
0005434551042	10662	8	2F
0005434550987	10662	9	3A
0005434550993	10662	10	3C
0005433180667	10662	11	3D
0005433180781	10662	12	3F
0005434551003	10662	13	4A
0005434551016	10662	14	4C
0005433180825	10662	15	4D
0005434550989	10662	16	4E
0005434550996	10662	17	4F
0005434554058	10662	18	5A
0005433180876	10662	19	5C
0005434551017	10662	20	5D
0005433180765	10662	21	5E
0005434551002	10662	22	5F
0005433180731	10662	23	6A
0005434551018	10662	24	6C
0005434551007	10662	25	6D
0005433180934	10662	26	6E
0005433180764	10662	27	6F
0005433180897	10662	28	7C
0005434551022	10662	29	7D
0005433180813	10662	30	7E
0005433180803	10662	31	7F
0005433180704	10662	32	8A
0005433180935	10662	33	8C
0005434550990	10662	34	8D
0005434551000	10662	35	8E
0005434558231	10662	36	8F
0005434551021	10662	37	9A
0005434551020	10662	38	9C
0005434551030	10662	39	9D
0005434550997	10662	40	9E
0005434551015	10662	41	9F
0005434551001	10662	42	10A
0005434551032	10662	43	10C
0005434551038	10662	44	10D
0005434551028	10662	45	10E
0005434558229	10662	46	10F
0005434550994	10662	47	11A
0005434550995	10662	48	11C
0005433180839	10662	49	11D
0005434551023	10662	50	11E
0005433180701	10662	51	11F
0005434550999	10662	52	12C
0005434551040	10662	53	12D
0005433180758	10662	54	12E
0005434550992	10662	55	12F
0005433180785	10662	56	13A
0005433180826	10662	57	13C
0005434551029	10662	58	13D
0005433180703	10662	59	13E
0005433180759	10662	60	13F
0005434551013	10662	61	14A
0005434551012	10662	62	14C
0005433180873	10662	63	14D
0005434551004	10662	64	14E
0005434551019	10662	65	14F
0005434551008	10662	66	15A
0005434558232	10662	67	15C
0005433180838	10662	68	15D
0005433180771	10662	69	15E
0005434551031	10662	70	15F
0005434551014	10662	71	16A
0005434551041	10662	72	16C
0005433180752	10662	73	16D
0005434551035	10662	74	16E
0005434551026	10662	75	16F
0005434551037	10662	76	17C
0005434551010	10662	77	17D
0005434551033	10662	78	17E
0005433180786	10662	79	17F
0005434550998	10662	80	18A
0005433180821	10662	81	18C
0005434551039	10662	82	18D
0005433180772	10662	83	18E
0005434551005	10662	84	18F
0005433180753	10662	85	19A
0005434551006	10662	86	19C
0005434551027	10662	87	19D
0005434551036	10662	88	19F
0005434551043	10662	89	20C
0005434551009	10662	90	20D
0005434551011	10662	91	20E
0005433180827	10662	92	20F
0005433181020	27752	1	1A
0005433181035	27752	2	4D
0005433181029	27752	3	4E
0005433181013	27752	4	5E
0005433181015	27752	5	6D
0005433181030	27752	6	6E
0005433181026	27752	7	7F
0005433181022	27752	8	9C
0005433181028	27752	9	9D
0005433181024	27752	10	9F
0005433181016	27752	11	10A
0005433181031	27752	12	10C
0005433181032	27752	13	12D
0005433181025	27752	14	13A
0005433181033	27752	15	14C
0005433181018	27752	16	14F
0005433181027	27752	17	16A
0005433181019	27752	18	16D
0005433181017	27752	19	17F
0005433181023	27752	20	18D
0005433181011	27752	21	18F
0005433181021	27752	22	19D
0005433181014	27752	23	19E
0005433181034	27752	24	20D
0005433181012	27752	25	20F
0005434550626	27751	1	1A
0005434550663	27751	2	1C
0005434558183	27751	3	1F
0005434550791	27751	4	2A
0005434550752	27751	5	2D
0005434550673	27751	6	2F
0005434550555	27751	7	3A
0005434550801	27751	8	3D
0005434550607	27751	9	3F
0005434550556	27751	10	4A
0005434550720	27751	11	4C
0005434550669	27751	12	4D
0005434554034	27751	13	4E
0005434550536	27751	14	4F
0005434550657	27751	15	5A
0005434550722	27751	16	5C
0005434550455	27751	17	6A
0005434550585	27751	18	6C
0005434550625	27751	19	6E
0005434550574	27751	20	7A
0005434554046	27751	21	7C
0005434550671	27751	22	7D
0005434550597	27751	23	7E
0005434550754	27751	24	8A
0005434550608	27751	25	8D
0005434558178	27751	26	8F
0005434550465	27751	27	9A
0005434550338	27751	28	9C
0005434558161	27751	29	9D
0005434554045	27751	30	9E
0005434550499	27751	31	9F
0005434550521	27751	32	10A
0005434550751	27751	33	10C
0005434550756	27751	34	10D
0005434550490	27751	35	10E
0005434550662	27751	36	11A
0005434558176	27751	37	11D
0005434550656	27751	38	11E
0005434550456	27751	39	11F
0005434558160	27751	40	12A
0005434554035	27751	41	12C
0005434558141	27751	42	12D
0005434550287	27751	43	13C
0005434550595	27751	44	13D
0005434550633	27751	45	13E
0005434550476	27751	46	13F
0005434558179	27751	47	14A
0005434550464	27751	48	14D
0005434550538	27751	49	14E
0005434550286	27751	50	14F
0005434550426	27751	51	15A
0005434550552	27751	52	15C
0005434550659	27751	53	15D
0005434550600	27751	54	16C
0005434558170	27751	55	16D
0005434550537	27751	56	16F
0005434550721	27751	57	17A
0005434550497	27751	58	17C
0005434550750	27751	59	17D
0005434550719	27751	60	17F
0005434550716	27751	61	18C
0005434558174	27751	62	18D
0005434558177	27751	63	18F
0005434550670	27751	64	19A
0005434550601	27751	65	19C
0005434550745	27751	66	19D
0005434550674	27751	67	19E
0005434554039	27751	68	20A
0005434550596	27751	69	20C
0005434550582	27751	70	20D
0005434550539	27751	71	20E
0005434550496	27751	72	20F
0005433459208	6124	1	1A
0005435254444	6124	2	2A
0005435254449	6124	3	1B
0005433459204	6124	4	2B
0005435254448	6124	5	3A
0005435254450	6124	6	3B
0005435254443	6124	7	4B
0005433459205	6124	8	4A
0005433459206	6124	9	5A
0005435254442	6124	10	5B
0005433459207	6124	11	6B
0005435254467	19292	1	1A
0005433459188	19292	2	2A
0005433459165	19292	3	2B
0005433459187	19292	4	3A
0005433459189	19292	5	3B
0005435254466	19292	6	4A
0005433459166	19292	7	5A
0005433459170	19292	8	5B
0005433459169	19292	9	6B
0005432533260	6758	1	1A
0005432533264	6758	2	1C
0005435437781	6758	3	1D
0005435719566	6758	4	1F
0005435681986	6758	5	2A
0005435681980	6758	6	2C
0005435682026	6758	7	2D
0005435682022	6758	8	2F
0005435437821	6758	9	3A
0005434828648	6758	10	3C
0005435681983	6758	11	3D
0005435720130	6758	12	3F
0005435682017	6758	13	4A
0005435437773	6758	14	4C
0005435661918	6758	15	4D
0005435437794	6758	16	4E
0005435681997	6758	17	4F
0005435682005	6758	18	5A
0005435681990	6758	19	5C
0005435681982	6758	20	5D
0005435682007	6758	21	5E
0005435437738	6758	22	5F
0005435682000	6758	23	6A
0005432136154	6758	24	6C
0005435437657	6758	25	6D
0005435217685	6758	26	6E
0005435681992	6758	27	6F
0005435681993	6758	28	7A
0005435437815	6758	29	7C
0005435437662	6758	30	7D
0005435681995	6758	31	7E
0005435681994	6758	32	8A
0005435682016	6758	33	7F
0005435437585	6758	34	8C
0005435719568	6758	35	8D
0005435437793	6758	36	8E
0005435682006	6758	37	8F
0005435437685	6758	38	9A
0005435682018	6758	39	9C
0005432136153	6758	40	9D
0005435437599	6758	41	9E
0005435437814	6758	42	9F
0005435682009	6758	43	10A
0005435437740	6758	44	10C
0005435437709	6758	45	10D
0005435682012	6758	46	10E
0005435682015	6758	47	10F
0005435437689	6758	48	11A
0005435682004	6758	49	11C
0005435682011	6758	50	11D
0005435720131	6758	51	11E
0005435682002	6758	52	11F
0005435682025	6758	53	12A
0005435437731	6758	54	12C
0005435682013	6758	55	12D
0005435682001	6758	56	12E
0005435437779	6758	57	12F
0005435681999	6758	58	13A
0005435437643	6758	59	13C
0005435682014	6758	60	13D
0005435437688	6758	61	13E
0005432136151	6758	62	13F
0005435681985	6758	63	14A
0005435437660	6758	64	14C
0005435437661	6758	65	14D
0005432533265	6758	66	14E
0005435682019	6758	67	14F
0005435437780	6758	68	15A
0005435682023	6758	69	15C
0005435681998	6758	70	15D
0005435682003	6758	71	15E
0005435719567	6758	72	15F
0005435437584	6758	73	16A
0005435682010	6758	74	16C
0005435630956	6758	75	16D
0005435661919	6758	76	16E
0005435220288	6758	77	16F
0005435681996	6758	78	17A
0005435630955	6758	79	17C
0005435681988	6758	80	17D
0005435681981	6758	81	17E
0005435681991	6758	82	17F
0005435682021	6758	83	18A
0005435682008	6758	84	18C
0005432136152	6758	85	18D
0005435682024	6758	86	18E
0005435661920	6758	87	18F
0005435437710	6758	88	19A
0005435437732	6758	89	19C
0005435681989	6758	90	19D
0005435682020	6758	91	19E
0005435437620	6758	92	19F
0005435437663	6758	93	20A
0005435681984	6758	94	20C
0005435220286	6758	95	20D
0005435681987	6758	96	20E
0005435220287	6758	97	20F
0005435681776	24568	1	1A
0005434828690	24568	2	1C
0005435681560	24568	3	1D
0005435681766	24568	4	1F
0005435437883	24568	5	2A
0005435437887	24568	6	2C
0005435681586	24568	7	2D
0005435681565	24568	8	2F
0005435437875	24568	9	3C
0005435681652	24568	10	3D
0005435661896	24568	11	3F
0005435437871	24568	12	4A
0005435681581	24568	13	4C
0005435681726	24568	14	4D
0005432305741	24568	15	4E
0005435437892	24568	16	4F
0005435437882	24568	17	5A
0005435681561	24568	18	5C
0005435681753	24568	19	5D
0005435437872	24568	20	5E
0005435681790	24568	21	5F
0005435437877	24568	22	6A
0005435681696	24568	23	6C
0005435681460	24568	24	6D
0005435437890	24568	25	6E
0005434828689	24568	26	6F
0005435661882	24568	27	7A
0005435630932	24568	28	7C
0005435437876	24568	29	7D
0005435720811	24568	30	7E
0005435437870	24568	31	7F
0005435437889	24568	32	8C
0005435630919	24568	33	8D
0005435681716	24568	34	8E
0005435681651	24568	35	9A
0005435661892	24568	36	9C
0005435661893	24568	37	9D
0005435681679	24568	38	9E
0005435719550	24568	39	9F
0005435630930	24568	40	10A
0005435681562	24568	41	10C
0005435437886	24568	42	10D
0005435437880	24568	43	10E
0005432305742	24568	44	10F
0005435681667	24568	45	11A
0005435437874	24568	46	11C
0005435681678	24568	47	11D
0005432533284	24568	48	11E
0005435681645	24568	49	11F
0005435661883	24568	50	12A
0005435681459	24568	51	12D
0005435630931	24568	52	12E
0005435681742	24568	53	12F
0005435681653	24568	54	13A
0005435681666	24568	55	13C
0005435437891	24568	56	13F
0005432533283	24568	57	14A
0005434828688	24568	58	14C
0005435681525	24568	59	14D
0005435437878	24568	60	14E
0005435681764	24568	61	14F
0005435719551	24568	62	15A
0005435681824	24568	63	15D
0005435681566	24568	64	15E
0005435437885	24568	65	15F
0005435681697	24568	66	16A
0005435681723	24568	67	16C
0005435630943	24568	68	16D
0005435437879	24568	69	16E
0005435681743	24568	70	17A
0005435681680	24568	71	16F
0005435681664	24568	72	17C
0005432305740	24568	73	17D
0005435437888	24568	74	17E
0005435681636	24568	75	17F
0005435681543	24568	76	18A
0005435437873	24568	77	18C
0005435681765	24568	78	18D
0005435437881	24568	79	18E
0005435681665	24568	80	18F
0005435681821	24568	81	19A
0005435681686	24568	82	19C
0005432533282	24568	83	19D
0005435681559	24568	84	19E
0005435437884	24568	85	19F
0005435681593	24568	86	20A
0005435720812	24568	87	20C
0005435681626	24568	88	20D
0005435681860	24568	89	20E
0005435681475	24568	90	20F
0005435126191	11536	1	1C
0005435126208	11536	2	1F
0005435126204	11536	3	2C
0005435126193	11536	4	2D
0005435126223	11536	5	2F
0005435126192	11536	6	4C
0005435126195	11536	7	4D
0005435126188	11536	8	5A
0005435126189	11536	9	5F
0005435126218	11536	10	6A
0005435126207	11536	11	6E
0005435126205	11536	12	6F
0005435126213	11536	13	7A
0005435126226	11536	14	8F
0005435126211	11536	15	9D
0005435126209	11536	16	9E
0005435126199	11536	17	10C
0005435558054	11536	18	10D
0005435126215	11536	19	10E
0005435126202	11536	20	11C
0005435126219	11536	21	11D
0005435126201	11536	22	11E
0005435126222	11536	23	11F
0005435126216	11536	24	12A
0005435126206	11536	25	13A
0005435126190	11536	26	13C
0005435126220	11536	27	14C
0005435126197	11536	28	14E
0005435126203	11536	29	15A
0005435126214	11536	30	15E
0005435126212	11536	31	15F
0005435126230	11536	32	16D
0005435126228	11536	33	16F
0005435126227	11536	34	17A
0005435126217	11536	35	17C
0005435126224	11536	36	17D
0005435126210	11536	37	17E
0005435126200	11536	38	17F
0005435126221	11536	39	18C
0005435126196	11536	40	18D
0005435105970	11536	41	18E
0005435126229	11536	42	19A
0005435126225	11536	43	19D
0005435558043	11536	44	19E
0005435126194	11536	45	19F
0005435105968	11536	46	20C
0005435105969	11536	47	20D
0005435126198	11536	48	20E
0005435125901	31862	1	1A
0005435125732	31862	2	1C
0005435126005	31862	3	1D
0005435125822	31862	4	1F
0005435125871	31862	5	2C
0005435125832	31862	6	2D
0005435125843	31862	7	2F
0005435125861	31862	8	3A
0005435125810	31862	9	3C
0005435125972	31862	10	3D
0005435125779	31862	11	3F
0005435125900	31862	12	4A
0005435125904	31862	13	4D
0005435125957	31862	14	5D
0005435125730	31862	15	5C
0005435126007	31862	16	5E
0005435125947	31862	17	6A
0005435125797	31862	18	6E
0005435125862	31862	19	7C
0005435105942	31862	20	7E
0005435125745	31862	21	8A
0005435126077	31862	22	8C
0005435125731	31862	23	8E
0005435125930	31862	24	9A
0005435558080	31862	25	9C
0005435125973	31862	26	9E
0005435125815	31862	27	9F
0005435125878	31862	28	10A
0005435126033	31862	29	10C
0005435125938	31862	30	10E
0005435125780	31862	31	10F
0005435125873	31862	32	11D
0005435105938	31862	33	11E
0005435125992	31862	34	11F
0005435126006	31862	35	12D
0005435125769	31862	36	12E
0005435126042	31862	37	13A
0005435105941	31862	38	13C
0005435558078	31862	39	13F
0005435098527	31862	40	14C
0005435125823	31862	41	14D
0005435125811	31862	42	14F
0005435126076	31862	43	15C
0005435125921	31862	44	15D
0005435126004	31862	45	16A
0005435125874	31862	46	16C
0005435125927	31862	47	16E
0005435125959	31862	48	16F
0005435105943	31862	49	17A
0005435125703	31862	50	17C
0005435125958	31862	51	17D
0005435125791	31862	52	17E
0005435125872	31862	53	17F
0005435098531	31862	54	18D
0005435126034	31862	55	18F
0005435558079	31862	56	19D
0005435098534	31862	57	19F
0005435125755	31862	58	20C
0005435125786	31862	59	20F
0005435732211	13531	1	1A
0005433397909	13531	2	1D
0005433397889	13531	3	1F
0005433397899	13531	4	2C
0005433397916	13531	5	2D
0005433397923	13531	6	3A
0005433397877	13531	7	4A
0005435732168	13531	8	4D
0005435732270	13531	9	4E
0005435732162	13531	10	4F
0005433397875	13531	11	5A
0005433397911	13531	12	5C
0005433397913	13531	13	5E
0005435732216	13531	14	5D
0005433397893	13531	15	5F
0005433397879	13531	16	6C
0005435732169	13531	17	6D
0005433397919	13531	18	6F
0005433397914	13531	19	7C
0005435732222	13531	20	7D
0005433397912	13531	21	7E
0005435732205	13531	22	7F
0005433397908	13531	23	8A
0005435732166	13531	24	8C
0005433397876	13531	25	8D
0005435732220	13531	26	8F
0005433397901	13531	27	9A
0005433397904	13531	28	9C
0005435732197	13531	29	9E
0005433397918	13531	30	11A
0005433397878	13531	31	11C
0005433397924	13531	32	11D
0005433397891	13531	33	11E
0005433397882	13531	34	12A
0005433397895	13531	35	12D
0005433397917	13531	36	12E
0005433397883	13531	37	13A
0005433397903	13531	38	13C
0005433397922	13531	39	13E
0005433397885	13531	40	13F
0005433397881	13531	41	14A
0005433397890	13531	42	14E
0005433397910	13531	43	15C
0005435732163	13531	44	15D
0005433397902	13531	45	15E
0005433397894	13531	46	15F
0005435732208	13531	47	16A
0005433397892	13531	48	16D
0005433397898	13531	49	16E
0005433397880	13531	50	17A
0005433397920	13531	51	17C
0005435732167	13531	52	17D
0005433397897	13531	53	17E
0005433397888	13531	54	18A
0005433397884	13531	55	18C
0005433397921	13531	56	18D
0005433397874	13531	57	18E
0005433397896	13531	58	18F
0005433397907	13531	59	19A
0005433397905	13531	60	19D
0005433397886	13531	61	19E
0005433397900	13531	62	20A
0005433397915	13531	63	20C
0005435732207	13531	64	20D
0005433397906	13531	65	20E
0005433397887	13531	66	20F
0005433397486	19405	1	1D
0005433397402	19405	2	1F
0005433397460	19405	3	2C
0005433397515	19405	4	2D
0005433397438	19405	5	2F
0005433397587	19405	6	3C
0005433397249	19405	7	3F
0005433397602	19405	8	4D
0005433397601	19405	9	4F
0005433397597	19405	10	5A
0005433397391	19405	11	5C
0005433397216	19405	12	5E
0005433397404	19405	13	5F
0005433397736	19405	14	6A
0005433397637	19405	15	6C
0005433397584	19405	16	6D
0005433397385	19405	17	7A
0005433397588	19405	18	7D
0005433397346	19405	19	7E
0005433397583	19405	20	8A
0005433397386	19405	21	8C
0005433397314	19405	22	8D
0005433397439	19405	23	8E
0005433397452	19405	24	8F
0005433397713	19405	25	9A
0005432297268	19405	26	10A
0005433397423	19405	27	10C
0005433397461	19405	28	10D
0005433397680	19405	29	10F
0005433397636	19405	30	11C
0005433397462	19405	31	11D
0005433397440	19405	32	11F
0005433397556	19405	33	12E
0005433397479	19405	34	12F
0005433397279	19405	35	13A
0005433397679	19405	36	13D
0005433397341	19405	37	13E
0005433397424	19405	38	13F
0005433397525	19405	39	14A
0005432297270	19405	40	14D
0005433397478	19405	41	14E
0005433397315	19405	42	14F
0005433397570	19405	43	15A
0005433397516	19405	44	15C
0005433397340	19405	45	15D
0005433397482	19405	46	16C
0005433397543	19405	47	16E
0005433397401	19405	48	16F
0005433397670	19405	49	17A
0005433397278	19405	50	17C
0005433397678	19405	51	17E
0005432297269	19405	52	18A
0005433397471	19405	53	18D
0005433397345	19405	54	18E
0005433397470	19405	55	18F
0005433397494	19405	56	19A
0005433397480	19405	57	19D
0005433397444	19405	58	19E
0005433397524	19405	59	19F
0005433397316	19405	60	20A
0005433397582	19405	61	20C
0005433397384	19405	62	20D
0005433397581	19405	63	20E
0005435925262	13170	1	1A
0005435068480	13170	2	1D
0005435925247	13170	3	1F
0005435068474	13170	4	2D
0005435068341	13170	5	2F
0005435068492	13170	6	3C
0005435068183	13170	7	3D
0005435925266	13170	8	3F
0005435925265	13170	9	4A
0005435925253	13170	10	4C
0005435068359	13170	11	4E
0005435068430	13170	12	4F
0005435068683	13170	13	5C
0005435068216	13170	14	5D
0005435068472	13170	15	5E
0005435068228	13170	16	5F
0005435068473	13170	17	6A
0005435068370	13170	18	6C
0005435925261	13170	19	6D
0005435925263	13170	20	6E
0005435068233	13170	21	7C
0005435925268	13170	22	7D
0005435068374	13170	23	8C
0005435068408	13170	24	8D
0005435068351	13170	25	8E
0005435925259	13170	26	8F
0005435925248	13170	27	9A
0005435925267	13170	28	9D
0005435925255	13170	29	9E
0005435925264	13170	30	9F
0005435925251	13170	31	10A
0005435925260	13170	32	10F
0005435068610	13170	33	11C
0005435068420	13170	34	11D
0005435068292	13170	35	11E
0005435068531	13170	36	11F
0005435068340	13170	37	12A
0005435925250	13170	38	12C
0005435068609	13170	39	12D
0005435068373	13170	40	12E
0005435068487	13170	41	12F
0005435068558	13170	42	13A
0005435068421	13170	43	13C
0005435925258	13170	44	13E
0005435068419	13170	45	13F
0005435068542	13170	46	14D
0005435925252	13170	47	14E
0005435068369	13170	48	15C
0005435068422	13170	49	15D
0005435925256	13170	50	15E
0005435925246	13170	51	15F
0005435068401	13170	52	16A
0005435068684	13170	53	16C
0005435068229	13170	54	16D
0005435068541	13170	55	16E
0005435068599	13170	56	17D
0005435068456	13170	57	17E
0005435925244	13170	58	17F
0005435068284	13170	59	18A
0005435925257	13170	60	18D
0005435925249	13170	61	18E
0005435068518	13170	62	19C
0005435068441	13170	63	19D
0005435068232	13170	64	19E
0005435925254	13170	65	20C
0005435068455	13170	66	20D
0005435925245	13170	67	20E
0005435068214	13170	68	20F
0005435068847	15495	1	1A
0005435068896	15495	2	1C
0005435068899	15495	3	1D
0005435068860	15495	4	1F
0005435068881	15495	5	2F
0005435068900	15495	6	3A
0005435068875	15495	7	3C
0005435068895	15495	8	4A
0005435925065	15495	9	4E
0005435068868	15495	10	4F
0005435925104	15495	11	5A
0005435068889	15495	12	5C
0005435068861	15495	13	5D
0005435925103	15495	14	5E
0005435068883	15495	15	6C
0005435068879	15495	16	6E
0005435068893	15495	17	7D
0005435068878	15495	18	7E
0005435068891	15495	19	7F
0005435925080	15495	20	8A
0005435068898	15495	21	8C
0005435068865	15495	22	8D
0005435068884	15495	23	8F
0005435068886	15495	24	9A
0005435068866	15495	25	9F
0005435068892	15495	26	10A
0005435068870	15495	27	10C
0005435068858	15495	28	10D
0005435068885	15495	29	10E
0005435068877	15495	30	10F
0005435068855	15495	31	11C
0005435068863	15495	32	11E
0005435925097	15495	33	11F
0005435068867	15495	34	12A
0005435068873	15495	35	12D
0005435068882	15495	36	12E
0005435068887	15495	37	12F
0005435068848	15495	38	13D
0005435068874	15495	39	13F
0005435068888	15495	40	14A
0005435068851	15495	41	14E
0005435925062	15495	42	14F
0005435068869	15495	43	15C
0005435068852	15495	44	15D
0005435925107	15495	45	15E
0005435068894	15495	46	15F
0005435925095	15495	47	16C
0005435068854	15495	48	16D
0005435068849	15495	49	16E
0005435068862	15495	50	16F
0005435068856	15495	51	17A
0005435068850	15495	52	17C
0005435068876	15495	53	17E
0005435068871	15495	54	17F
0005435925106	15495	55	18C
0005435068872	15495	56	18D
0005435068890	15495	57	18F
0005435068859	15495	58	19A
0005435068880	15495	59	19C
0005435925102	15495	60	19D
0005435068853	15495	61	19F
0005435068864	15495	62	20A
0005435068897	15495	63	20C
0005435068857	15495	64	20E
0005435925101	15495	65	20F
0005435808075	29483	1	1A
0005433407554	29483	2	1B
0005435808130	29483	3	1C
0005435808081	29483	4	1D
0005435808110	29483	5	2A
0005433407544	29483	6	2D
0005435808098	29483	7	3A
0005435808106	29483	8	3B
0005433407549	29483	9	3C
0005433407548	29483	10	3D
0005435808074	29483	11	4B
0005435808108	29483	12	4A
0005435808134	29483	13	4D
0005433407552	29483	14	5A
0005433407551	29483	15	5B
0005435808109	29483	16	5C
0005433407543	29483	17	5D
0005435808135	29483	18	6A
0005435808103	29483	19	6B
0005433407542	29483	20	6C
0005435808105	29483	21	6D
0005435808155	29483	22	7A
0005433407541	29483	23	7B
0005435808101	29483	24	7C
0005433407539	29483	25	7D
0005435808125	29483	26	18A
0005435808086	29483	27	18B
0005435808078	29483	28	18C
0005435808154	29483	29	18D
0005435808080	29483	30	19A
0005435808107	29483	31	19B
0005433407546	29483	32	19C
0005433407547	29483	33	19D
0005433407553	29483	34	20A
0005433407550	29483	35	20B
0005433407545	29483	36	20C
0005435808049	29483	37	20D
0005435808129	29483	38	21A
0005435808112	29483	39	21B
0005435808133	29483	40	21C
0005435808079	29483	41	21D
0005433407540	29483	42	22B
0005435808095	29483	43	22C
0005435808068	29483	44	23A
0005435808124	29483	45	23B
0005434214409	10725	1	1A
0005434756062	10725	2	1C
0005434214389	10725	3	1D
0005434214402	10725	4	1F
0005434214410	10725	5	2C
0005434755859	10725	6	2D
0005434755963	10725	7	2F
0005434214393	10725	8	3A
0005434755944	10725	9	3C
0005434214399	10725	10	3D
0005434214387	10725	11	3F
0005434755904	10725	12	4A
0005434214376	10725	13	4C
0005434755902	10725	14	4D
0005434755915	10725	15	4E
0005434755768	10725	16	4F
0005434214367	10725	17	5A
0005434214408	10725	18	5C
0005434214411	10725	19	5D
0005434214394	10725	20	5E
0005434755943	10725	21	5F
0005434214371	10725	22	6A
0005434755987	10725	23	6C
0005434755930	10725	24	6E
0005434214404	10725	25	6F
0005434214377	10725	26	7A
0005434756035	10725	27	7C
0005434214378	10725	28	7E
0005434214395	10725	29	7F
0005434214379	10725	30	8A
0005434214386	10725	31	8C
0005434214374	10725	32	8D
0005434755940	10725	33	8E
0005434755829	10725	34	8F
0005434214380	10725	35	9A
0005434214401	10725	36	9C
0005434214365	10725	37	9E
0005434214375	10725	38	10C
0005434214364	10725	39	10A
0005434214385	10725	40	10D
0005434755812	10725	41	10E
0005434214388	10725	42	10F
0005434755817	10725	43	11A
0005434755884	10725	44	11C
0005434214373	10725	45	11D
0005434755989	10725	46	11E
0005434214370	10725	47	11F
0005434214405	10725	48	12A
0005434755820	10725	49	12C
0005434756049	10725	50	12D
0005434214398	10725	51	12E
0005434755860	10725	52	12F
0005434756034	10725	53	13C
0005434214372	10725	54	13D
0005434756020	10725	55	13E
0005434214366	10725	56	13F
0005434214406	10725	57	14A
0005434755747	10725	58	14C
0005434756050	10725	59	14D
0005434214368	10725	60	14E
0005434214392	10725	61	14F
0005434214382	10725	62	15A
0005434755931	10725	63	15C
0005434756012	10725	64	15D
0005434755914	10725	65	15E
0005434755941	10725	66	15F
0005434214369	10725	67	16A
0005434214412	10725	68	16C
0005434755951	10725	69	16D
0005434755952	10725	70	16E
0005434214384	10725	71	16F
0005434214407	10725	72	17A
0005434756036	10725	73	17C
0005434755929	10725	74	17D
0005434755937	10725	75	17E
0005434214400	10725	76	17F
0005434755953	10725	77	18A
0005434214397	10725	78	18C
0005434214390	10725	79	18D
0005434214403	10725	80	18E
0005434755878	10725	81	18F
0005434756030	10725	82	19A
0005434214381	10725	83	19C
0005434214396	10725	84	19D
0005434214383	10725	85	19F
0005434755798	10725	86	20A
0005434755819	10725	87	20C
0005434756063	10725	88	20D
0005434756021	10725	89	20E
0005434214391	10725	90	20F
0005434756263	28668	1	1A
0005434756253	28668	2	1C
0005434756280	28668	3	1D
0005434213976	28668	4	1F
0005434756252	28668	5	2A
0005434756282	28668	6	2C
0005434756278	28668	7	2D
0005434756265	28668	8	2F
0005434756238	28668	9	3A
0005434756241	28668	10	3C
0005434756272	28668	11	3D
0005434756242	28668	12	3F
0005434756256	28668	13	4A
0005434213831	28668	14	4C
0005434214032	28668	15	4D
0005434756261	28668	16	4E
0005434214142	28668	17	4F
0005434213929	28668	18	5A
0005434213974	28668	19	5C
0005434213908	28668	20	5D
0005434213940	28668	21	5E
0005434213941	28668	22	5F
0005434756285	28668	23	6A
0005434756270	28668	24	6C
0005434756235	28668	25	6D
0005434756251	28668	26	6F
0005434756250	28668	27	7C
0005434213733	28668	28	7D
0005434214055	28668	29	7E
0005434756244	28668	30	7F
0005434756243	28668	31	8A
0005434213968	28668	32	8C
0005434756271	28668	33	8D
0005434756267	28668	34	8E
0005434213912	28668	35	8F
0005434213970	28668	36	9A
0005434214021	28668	37	9C
0005434756234	28668	38	9D
0005434756266	28668	39	9E
0005434756245	28668	40	9F
0005434756257	28668	41	10A
0005434756255	28668	42	10C
0005434214088	28668	43	10D
0005434214077	28668	44	10E
0005434756248	28668	45	10F
0005434214006	28668	46	11A
0005434213902	28668	47	11C
0005434756279	28668	48	11D
0005434756274	28668	49	11E
0005434213801	28668	50	11F
0005434756283	28668	51	12A
0005434213853	28668	52	12C
0005434756262	28668	53	12D
0005434214056	28668	54	12E
0005434213913	28668	55	12F
0005434213748	28668	56	13A
0005434213836	28668	57	13C
0005434756239	28668	58	13D
0005434756240	28668	59	13E
0005434756246	28668	60	13F
0005434213945	28668	61	14A
0005434213989	28668	62	14C
0005434756254	28668	63	14D
0005434756247	28668	64	14E
0005434756284	28668	65	14F
0005434213937	28668	66	15A
0005434756273	28668	67	15C
0005434214023	28668	68	15D
0005434756281	28668	69	15F
0005434213888	28668	70	16A
0005434756264	28668	71	16C
0005434756276	28668	72	16D
0005434756236	28668	73	16E
0005434756277	28668	74	16F
0005434756258	28668	75	17A
0005434756249	28668	76	17C
0005434756268	28668	77	17D
0005434214031	28668	78	17E
0005434213816	28668	79	17F
0005434756286	28668	80	18A
0005434213928	28668	81	18C
0005434214022	28668	82	18D
0005434213825	28668	83	18E
0005434756259	28668	84	18F
0005434756269	28668	85	19A
0005434214024	28668	86	19C
0005434214065	28668	87	19D
0005434213887	28668	88	19E
0005434756260	28668	89	19F
0005434213845	28668	90	20A
0005434213794	28668	91	20C
0005434756275	28668	92	20D
0005434213975	28668	93	20E
0005434756237	28668	94	20F
0005435006952	5428	1	1C
0005435039565	5428	2	1A
0005435039556	5428	3	1D
0005435039542	5428	4	2A
0005435039577	5428	5	1F
0005435039535	5428	6	2D
0005435006962	5428	7	2C
0005434229068	5428	8	2F
0005435039534	5428	9	3A
0005435039558	5428	10	3D
0005435006946	5428	11	3C
0005435039566	5428	12	3F
0005435039549	5428	13	4A
0005435042849	5428	14	4C
0005435039557	5428	15	4B
0005435039594	5428	16	4E
0005435039540	5428	17	4D
0005435039533	5428	18	5A
0005435039563	5428	19	5C
0005435039579	5428	20	5B
0005435039551	5428	21	5D
0005432125425	5428	22	5E
0005435006964	5428	23	5F
0005435039541	5428	24	6B
0005434229117	5428	25	6A
0005435039545	5428	26	6C
0005432125424	5428	27	6D
0005434229127	5428	28	6F
0005435006947	5428	29	6E
0005435039575	5428	30	7B
0005435039572	5428	31	7A
0005435039537	5428	32	7C
0005435006957	5428	33	7E
0005435006955	5428	34	7D
0005435042848	5428	35	7F
0005432125431	5428	36	8B
0005435039586	5428	37	8A
0005435039559	5428	38	8D
0005434229085	5428	39	8C
0005434229195	5428	40	8E
0005432125426	5428	41	9A
0005434229051	5428	42	8F
0005435039585	5428	43	9C
0005435006950	5428	44	9B
0005435006963	5428	45	9E
0005435039554	5428	46	9D
0005435039588	5428	47	9F
0005435039546	5428	48	10B
0005435039584	5428	49	10D
0005435006944	5428	50	10C
0005434229019	5428	51	10E
0005435039560	5428	52	11A
0005435039582	5428	53	11C
0005435039599	5428	54	11B
0005435039550	5428	55	11E
0005435039562	5428	56	11D
0005434229150	5428	57	11F
0005435039597	5428	58	12A
0005434229086	5428	59	12C
0005435039583	5428	60	12B
0005434229084	5428	61	12D
0005434229050	5428	62	12E
0005435006961	5428	63	12F
0005435039574	5428	64	13A
0005435039532	5428	65	13B
0005435039543	5428	66	13D
0005435006951	5428	67	13C
0005435039547	5428	68	13E
0005435039590	5428	69	13F
0005435039548	5428	70	14A
0005435006965	5428	71	14D
0005435039569	5428	72	14C
0005434229098	5428	73	14F
0005435006958	5428	74	14E
0005434229116	5428	75	15B
0005435039587	5428	76	15A
0005435006966	5428	77	15C
0005434229017	5428	78	15D
0005435006945	5428	79	15E
0005435039536	5428	80	15F
0005434229112	5428	81	16B
0005435039596	5428	82	16A
0005435006949	5428	83	16D
0005435039553	5428	84	16C
0005435039568	5428	85	16E
0005435039580	5428	86	16F
0005434229018	5428	87	17A
0005434229059	5428	88	17B
0005432125428	5428	89	17C
0005435039598	5428	90	17E
0005435006954	5428	91	17D
0005435042850	5428	92	17F
0005435006956	5428	93	18A
0005435039561	5428	94	18B
0005432125429	5428	95	18C
0005435039571	5428	96	18E
0005435039552	5428	97	18D
0005435006959	5428	98	18F
0005435039578	5428	99	19A
0005435006967	5428	100	19B
0005435039591	5428	101	19D
0005435006960	5428	102	19C
0005435039538	5428	103	19E
0005435039589	5428	104	19F
0005435039539	5428	105	20A
0005434229132	5428	106	20C
0005435039592	5428	107	20B
0005435042851	5428	108	20D
0005432125430	5428	109	20E
0005434229099	5428	110	20F
0005434229105	5428	111	21A
0005435039593	5428	112	21B
0005435039567	5428	113	21D
0005435006948	5428	114	21C
0005435039570	5428	115	21E
0005434229111	5428	116	21F
0005435039595	5428	117	22A
0005435039576	5428	118	22C
0005435039564	5428	119	22B
0005435006953	5428	120	22D
0005435043284	5428	121	22F
0005435006968	5428	122	22E
0005435039581	5428	123	23A
0005435039544	5428	124	23B
0005435039555	5428	125	23C
0005432125427	5428	126	23E
0005435039573	5428	127	23D
0005435039122	13005	1	1A
0005435038989	13005	2	1C
0005435038977	13005	3	1F
0005435038811	13005	4	1D
0005435006673	13005	5	2A
0005435038846	13005	6	2D
0005432304384	13005	7	2C
0005435006735	13005	8	2F
0005435006771	13005	9	3C
0005435039147	13005	10	3A
0005434229298	13005	11	3D
0005435038986	13005	12	3F
0005435038898	13005	13	4A
0005435038901	13005	14	4C
0005435038845	13005	15	4B
0005434229308	13005	16	4D
0005434229299	13005	17	4E
0005435006715	13005	18	4F
0005435039055	13005	19	5B
0005435039028	13005	20	5A
0005435038976	13005	21	5C
0005435006840	13005	22	5D
0005435038949	13005	23	6A
0005435038816	13005	24	5F
0005435039004	13005	25	6C
0005435006889	13005	26	6B
0005435038859	13005	27	6D
0005435038948	13005	28	6E
0005435039019	13005	29	7A
0005435038903	13005	30	6F
0005435038802	13005	31	7C
0005435006783	13005	32	7B
0005435039213	13005	33	7E
0005435006790	13005	34	7D
0005435006616	13005	35	8A
0005435039047	13005	36	7F
0005435039159	13005	37	8C
0005435038921	13005	38	8E
0005435039005	13005	39	8D
0005435038856	13005	40	8F
0005435039300	13005	41	9A
0005435038729	13005	42	9B
0005435006770	13005	43	9C
0005435038855	13005	44	9D
0005435006785	13005	45	9F
0005434229297	13005	46	9E
0005434229290	13005	47	10B
0005435006733	13005	48	10D
0005435038813	13005	49	10C
0005435038988	13005	50	10E
0005434229294	13005	51	11A
0005435038922	13005	52	11B
0005434229307	13005	53	11C
0005434229291	13005	54	11F
0005434229303	13005	55	11E
0005434229309	13005	56	12B
0005435038812	13005	57	12A
0005435039015	13005	58	12C
0005435006841	13005	59	12D
0005435039097	13005	60	12E
0005435006736	13005	61	12F
0005435038858	13005	62	13A
0005435006734	13005	63	13C
0005435006751	13005	64	13D
0005435038937	13005	65	13E
0005435006846	13005	66	14A
0005435039003	13005	67	14C
0005435038730	13005	68	14B
0005434229293	13005	69	14D
0005435039104	13005	70	14E
0005434229302	13005	71	14F
0005435038982	13005	72	15C
0005435006732	13005	73	15B
0005435006617	13005	74	15D
0005434229311	13005	75	15E
0005435038914	13005	76	15F
0005435006707	13005	77	16A
0005434229305	13005	78	16C
0005435006711	13005	79	16B
0005435039023	13005	80	16D
0005435039027	13005	81	16E
0005434229310	13005	82	17A
0005432304385	13005	83	16F
0005435038934	13005	84	17B
0005435006763	13005	85	17C
0005435038700	13005	86	17E
0005434229295	13005	87	17D
0005434229296	13005	88	17F
0005434229306	13005	89	18B
0005435038713	13005	90	18D
0005435038990	13005	91	18C
0005435038701	13005	92	18E
0005435038810	13005	93	19A
0005435006687	13005	94	19B
0005435039072	13005	95	19E
0005435006731	13005	96	19F
0005435039046	13005	97	20A
0005435039148	13005	98	20C
0005435006791	13005	99	20E
0005435038902	13005	100	20D
0005435006716	13005	101	21A
0005435039124	13005	102	20F
0005435039071	13005	103	21B
0005434229312	13005	104	21D
0005435038809	13005	105	21C
0005432304387	13005	106	21F
0005432304386	13005	107	21E
0005435006786	13005	108	22A
0005435039030	13005	109	22C
0005435039024	13005	110	22B
0005434229289	13005	111	22D
0005434229301	13005	112	22E
0005434229304	13005	113	23A
0005434229300	13005	114	22F
0005435039010	13005	115	23B
0005434229292	13005	116	23E
0005435039066	13005	117	23D
0005435038857	13005	118	23F
0005435902467	14869	1	1A
0005435902386	14869	2	1C
0005435902406	14869	3	1D
0005435902440	14869	4	1F
0005434426481	14869	5	2A
0005434426487	14869	6	2C
0005434426489	14869	7	2F
0005434411762	14869	8	3A
0005434426499	14869	9	3C
0005435902449	14869	10	3F
0005435902512	14869	11	4A
0005435554129	14869	12	4C
0005434426498	14869	13	4F
0005434426486	14869	14	5D
0005434426483	14869	15	5E
0005434426501	14869	16	5F
0005434426492	14869	17	6C
0005435902503	14869	18	6D
0005435902466	14869	19	6E
0005434426482	14869	20	6F
0005435902546	14869	21	7A
0005434426490	14869	22	7C
0005434426500	14869	23	7D
0005434411760	14869	24	7E
0005434411761	14869	25	7F
0005434426480	14869	26	8E
0005434426484	14869	27	8F
0005435902516	14869	28	9F
0005434426477	14869	29	10A
0005435554130	14869	30	10D
0005435902387	14869	31	10F
0005434426505	14869	32	11C
0005432188594	14869	33	11D
0005435902429	14869	34	11F
0005432188597	14869	35	12A
0005434426479	14869	36	12C
0005434426494	14869	37	12D
0005434426503	14869	38	12E
0005435554125	14869	39	13A
0005434426495	14869	40	13C
0005435902542	14869	41	13F
0005434426502	14869	42	14A
0005435554124	14869	43	14D
0005435902464	14869	44	14E
0005434426476	14869	45	14F
0005434426504	14869	46	15A
0005434426491	14869	47	15D
0005434426493	14869	48	15E
0005434426478	14869	49	15F
0005435554121	14869	50	16A
0005434426497	14869	51	16C
0005434426496	14869	52	16D
0005432188595	14869	53	16F
0005434411763	14869	54	17A
0005435902543	14869	55	17D
0005434426485	14869	56	17E
0005435902491	14869	57	17F
0005435902389	14869	58	18A
0005435902504	14869	59	18C
0005435554126	14869	60	18D
0005432188596	14869	61	19E
0005434426488	14869	62	20A
0005435902388	14869	63	20C
0005435902492	14869	64	20D
0005435902441	14869	65	20E
0005434426256	20225	1	1C
0005434426148	20225	2	1D
0005434426264	20225	3	2D
0005435902647	20225	4	3C
0005434411724	20225	5	3D
0005434411719	20225	6	3F
0005434426189	20225	7	4A
0005434411707	20225	8	4C
0005434426402	20225	9	4E
0005434426261	20225	10	4F
0005434426216	20225	11	5E
0005435902651	20225	12	5F
0005435554175	20225	13	6A
0005435902641	20225	14	6C
0005435902654	20225	15	6D
0005434426295	20225	16	6E
0005434426280	20225	17	6F
0005435554173	20225	18	7C
0005434426332	20225	19	7D
0005434426293	20225	20	7E
0005434426149	20225	21	7F
0005435902643	20225	22	8C
0005434426285	20225	23	8E
0005434426342	20225	24	8F
0005434426277	20225	25	9A
0005435902646	20225	26	9F
0005434426147	20225	27	10A
0005434426240	20225	28	10C
0005435902655	20225	29	10D
0005434426263	20225	30	10E
0005434426331	20225	31	10F
0005434426262	20225	32	11A
0005434426199	20225	33	11C
0005434426323	20225	34	11D
0005435902640	20225	35	11F
0005434426302	20225	36	12A
0005434426178	20225	37	12C
0005435554176	20225	38	12D
0005435902649	20225	39	12E
0005435902652	20225	40	13A
0005434411721	20225	41	13C
0005434426201	20225	42	13F
0005432059497	20225	43	14A
0005434411720	20225	44	14C
0005435902645	20225	45	14D
0005434426124	20225	46	14E
0005434426200	20225	47	14F
0005434426249	20225	48	15A
0005434426294	20225	49	15C
0005434426318	20225	50	16A
0005435554174	20225	51	16C
0005434426179	20225	52	16D
0005435902639	20225	53	16F
0005435902642	20225	54	17A
0005432059498	20225	55	17C
0005434426163	20225	56	17D
0005435902653	20225	57	17E
0005434426217	20225	58	18C
0005434426301	20225	59	18D
0005435902650	20225	60	18E
0005434426271	20225	61	19C
0005434426202	20225	62	19D
0005435902644	20225	63	19E
0005434426190	20225	64	19F
0005434426401	20225	65	20A
0005435902656	20225	66	20C
0005435902648	20225	67	20F
0005433434278	26544	1	1A
0005435982128	26544	2	1C
0005435982125	26544	3	1D
0005432300241	26544	4	1F
0005433434354	26544	5	2A
0005433434352	26544	6	2C
0005435982138	26544	7	2D
0005433434328	26544	8	2F
0005433434407	26544	9	3A
0005433434406	26544	10	3C
0005435982131	26544	11	3D
0005433434353	26544	12	3F
0005433434279	26544	13	4A
0005435982120	26544	14	4C
0005435982123	26544	15	4D
0005433434268	26544	16	4E
0005433434408	26544	17	4F
0005435982112	26544	18	5A
0005435982126	26544	19	5C
0005435982101	26544	20	5D
0005433434391	26544	21	5E
0005432300238	26544	22	5F
0005435982118	26544	23	6A
0005435982098	26544	24	6D
0005433434377	26544	25	6E
0005435982134	26544	26	6F
0005435982097	26544	27	7A
0005435982122	26544	28	7C
0005435982111	26544	29	7D
0005434273060	26544	30	7E
0005435982106	26544	31	7F
0005435982116	26544	32	8A
0005433434329	26544	33	8C
0005433434378	26544	34	8D
0005435982132	26544	35	8E
0005435982096	26544	36	8F
0005433434365	26544	37	9A
0005433434299	26544	38	9C
0005432300243	26544	39	9D
0005435982117	26544	40	9E
0005435982114	26544	41	9F
0005433434285	26544	42	10A
0005435982110	26544	43	10C
0005435982113	26544	44	10D
0005435982109	26544	45	10E
0005433434280	26544	46	10F
0005435982136	26544	47	11A
0005433434344	26544	48	11C
0005435982102	26544	49	11D
0005432300242	26544	50	11E
0005435982133	26544	51	11F
0005435982137	26544	52	12A
0005432300239	26544	53	12C
0005433434403	26544	54	12D
0005435982119	26544	55	12E
0005433434397	26544	56	12F
0005433434340	26544	57	13A
0005434273048	26544	58	13E
0005435982121	26544	59	13F
0005433434418	26544	60	14A
0005435982124	26544	61	14C
0005435982139	26544	62	14D
0005435982130	26544	63	14E
0005433434302	26544	64	14F
0005434273061	26544	65	15A
0005435982107	26544	66	15C
0005435982099	26544	67	15D
0005435982108	26544	68	15E
0005435982127	26544	69	16A
0005432300240	26544	70	15F
0005435982103	26544	71	16C
0005435982140	26544	72	16D
0005435982100	26544	73	16E
0005433434405	26544	74	16F
0005435982115	26544	75	17D
0005433434217	26544	76	17E
0005434273049	26544	77	17F
0005433434376	26544	78	18A
0005433434318	26544	79	18C
0005433434364	26544	80	18D
0005433434409	26544	81	18E
0005433434392	26544	82	19A
0005435982105	26544	83	19C
0005435982135	26544	84	19D
0005433434355	26544	85	19E
0005434270181	26544	86	19F
0005435982104	26544	87	20A
0005435982129	26544	88	20C
0005433434402	26544	89	20E
0005433434396	26544	90	20F
0005433434609	26717	1	1A
0005435981635	26717	2	1C
0005435981775	26717	3	1D
0005434271305	26717	4	2A
0005432051118	26717	5	2C
0005435981898	26717	6	2D
0005435981643	26717	7	2F
0005432051119	26717	8	3A
0005435981765	26717	9	3F
0005435981828	26717	10	3D
0005435981769	26717	11	4A
0005435981804	26717	12	4D
0005435981624	26717	13	4E
0005433434608	26717	14	4F
0005433434604	26717	15	5D
0005433434592	26717	16	5E
0005433434600	26717	17	6A
0005435981652	26717	18	6C
0005434271306	26717	19	6D
0005434269098	26717	20	6F
0005435981836	26717	21	6E
0005435981723	26717	22	7A
0005435981770	26717	23	7D
0005435981737	26717	24	7E
0005433434594	26717	25	7F
0005435981692	26717	26	8A
0005433434591	26717	27	8C
0005435981722	26717	28	8D
0005435981634	26717	29	8E
0005433434599	26717	30	8F
0005433434585	26717	31	9A
0005435981706	26717	32	9C
0005433434590	26717	33	9D
0005435981702	26717	34	9F
0005435981767	26717	35	10C
0005433434611	26717	36	10D
0005433434589	26717	37	10E
0005435981803	26717	38	11A
0005434270199	26717	39	11C
0005435981644	26717	40	11D
0005435981766	26717	41	11E
0005432051120	26717	42	11F
0005433434610	26717	43	12A
0005435981851	26717	44	12C
0005434269097	26717	45	12D
0005435981879	26717	46	12E
0005435981902	26717	47	12F
0005433434596	26717	48	13D
0005433434598	26717	49	13F
0005435981633	26717	50	14C
0005433434602	26717	51	14D
0005434269096	26717	52	14E
0005433434603	26717	53	14F
0005433434583	26717	54	15A
0005434270202	26717	55	15C
0005433434597	26717	56	15D
0005433434607	26717	57	15E
0005435981897	26717	58	15F
0005435981805	26717	59	16A
0005435981764	26717	60	16C
0005434270200	26717	61	16D
0005435981880	26717	62	16E
0005435981776	26717	63	16F
0005433434605	26717	64	17A
0005433434586	26717	65	17C
0005435981911	26717	66	17D
0005435981736	26717	67	17E
0005435981795	26717	68	18A
0005433434606	26717	69	18C
0005433434601	26717	70	18D
0005433434595	26717	71	18E
0005435981796	26717	72	19A
0005433434588	26717	73	19C
0005433434593	26717	74	19D
0005435981682	26717	75	19F
0005433434587	26717	76	20A
0005435981852	26717	77	20C
0005435981748	26717	78	20D
0005434270201	26717	79	20E
0005433434584	26717	80	20F
0005433687689	19511	1	1A
0005433685514	19511	2	1B
0005433687696	19511	3	1C
0005433687703	19511	4	1D
0005433687690	19511	5	2A
0005433686621	19511	6	2B
0005433685518	19511	7	2C
0005433686625	19511	8	2D
0005433687695	19511	9	3A
0005433686629	19511	10	3C
0005433686617	19511	11	4A
0005433685513	19511	12	4B
0005433686623	19511	13	4C
0005433685516	19511	14	4D
0005433687697	19511	15	5A
0005433687691	19511	16	5B
0005433685509	19511	17	5C
0005433687700	19511	18	5D
0005433687694	19511	19	6A
0005433687701	19511	20	6B
0005433686618	19511	21	6C
0005433687698	19511	22	6D
0005433687699	19511	23	7A
0005433686619	19511	24	7B
0005433686620	19511	25	7C
0005433685517	19511	26	7D
0005433685507	19511	27	18A
0005433686626	19511	28	18B
0005433685508	19511	29	18C
0005433685511	19511	30	19A
0005433687702	19511	31	19C
0005433685512	19511	32	19D
0005433685515	19511	33	20B
0005433686628	19511	34	20C
0005433685519	19511	35	20D
0005433686622	19511	36	21A
0005433686624	19511	37	21B
0005433687692	19511	38	21C
0005433686627	19511	39	22A
0005433686630	19511	40	22C
0005433685510	19511	41	22D
0005433687693	19511	42	23A
0005433685520	19511	43	23B
0005432857935	3148	1	1C
0005432583957	3148	2	1B
0005432583952	3148	3	1D
0005432583947	3148	4	2A
0005432583959	3148	5	2B
0005432583968	3148	6	2D
0005432583950	3148	7	3A
0005432857933	3148	8	3B
0005432583965	3148	9	3C
0005432583967	3148	10	4A
0005432583964	3148	11	4C
0005432583961	3148	12	4D
0005432583958	3148	13	5A
0005432857904	3148	14	5D
0005432583943	3148	15	6C
0005432583954	3148	16	7A
0005432583953	3148	17	7B
0005432583951	3148	18	7C
0005432583944	3148	19	7D
0005432857934	3148	20	18A
0005432583962	3148	21	18B
0005432583945	3148	22	18C
0005432216263	3148	23	18D
0005432583946	3148	24	19A
0005432857874	3148	25	19B
0005432583960	3148	26	19D
0005432583949	3148	27	20A
0005432583948	3148	28	20B
0005432583966	3148	29	20C
0005432583956	3148	30	20D
0005432857922	3148	31	21B
0005432216264	3148	32	21C
0005432216262	3148	33	21D
0005432857875	3148	34	22A
0005432857960	3148	35	22B
0005432583955	3148	36	22C
0005432583963	3148	37	23A
0005432857910	3148	38	23B
0005432583683	31493	1	1A
0005432583788	31493	2	1C
0005432858025	31493	3	2A
0005432583759	31493	4	2B
0005432858031	31493	5	2C
0005432583819	31493	6	2D
0005432583817	31493	7	3A
0005432583772	31493	8	3B
0005432858026	31493	9	3C
0005432583712	31493	10	3D
0005432858023	31493	11	4A
0005432583653	31493	12	4B
0005432583827	31493	13	4C
0005432583742	31493	14	5A
0005432583783	31493	15	5B
0005432583812	31493	16	5C
0005432583721	31493	17	5D
0005432583760	31493	18	6B
0005432858030	31493	19	6A
0005432583784	31493	20	6C
0005432583744	31493	21	6D
0005432583809	31493	22	7A
0005432583694	31493	23	7B
0005432858027	31493	24	7C
0005432858034	31493	25	7D
0005432583743	31493	26	18C
0005432858035	31493	27	18D
0005432858032	31493	28	19C
0005432583771	31493	29	19D
0005432583818	31493	30	20A
0005432858029	31493	31	20B
0005432583781	31493	32	20D
0005432858028	31493	33	21A
0005432583720	31493	34	21B
0005432583782	31493	35	21C
0005432583774	31493	36	22A
0005432583764	31493	37	22B
0005432858024	31493	38	22C
0005432858033	31493	39	23A
0005432583761	31493	40	23B
0005433255038	910	1	1B
0005433255070	910	2	2A
0005433255046	910	3	2B
0005434943318	910	4	3C
0005434943326	910	5	5A
0005434943321	910	6	6B
0005433255053	910	7	6D
0005433255045	910	8	7D
0005434943319	910	9	18A
0005433255052	910	10	18C
0005434943322	910	11	19A
0005433255071	910	12	19C
0005434943324	910	13	20A
0005433255063	910	14	20C
0005433255048	910	15	20D
0005434943320	910	16	21B
0005434943325	910	17	22A
0005434943323	910	18	22B
0005434943317	910	19	23A
0005434943228	16208	1	2A
0005434943199	16208	2	2C
0005434943254	16208	3	3A
0005433255103	16208	4	3C
0005433255102	16208	5	3D
0005434943246	16208	6	4C
0005433255100	16208	7	4D
0005433255099	16208	8	5A
0005434943229	16208	9	6B
0005433255101	16208	10	6D
0005434943226	16208	11	18C
0005434943255	16208	12	19C
0005434943247	16208	13	21A
0005433255104	16208	14	21C
0005434943227	16208	15	22B
0005433654742	4327	1	1C
0005435858513	4327	2	1F
0005433654749	4327	3	1D
0005433654755	4327	4	2C
0005435858499	4327	5	2F
0005433654745	4327	6	3C
0005433654741	4327	7	4F
0005435858494	4327	8	6A
0005433654753	4327	9	6C
0005433654746	4327	10	7A
0005435858514	4327	11	7C
0005433654747	4327	12	7E
0005435858509	4327	13	7D
0005435858512	4327	14	8D
0005435858504	4327	15	8F
0005435858515	4327	16	9C
0005433654757	4327	17	10B
0005433654737	4327	18	11A
0005433654756	4327	19	11B
0005433654751	4327	20	11F
0005433654739	4327	21	12E
0005433654752	4327	22	13A
0005433654748	4327	23	13B
0005433654754	4327	24	14A
0005435858511	4327	25	14C
0005433654743	4327	26	14F
0005435858506	4327	27	15B
0005433654758	4327	28	16D
0005433654738	4327	29	17D
0005433654759	4327	30	18B
0005433654744	4327	31	18F
0005435858505	4327	32	19F
0005433654750	4327	33	20D
0005433654740	4327	34	20C
0005433811614	14399	1	3A
0005433811613	14399	2	2B
0005433811612	14399	3	3B
0005433811628	27871	1	1A
0005433811631	27871	2	2A
0005433811629	27871	3	1B
0005433811625	27871	4	3A
0005433811630	27871	5	2B
0005433811632	27871	6	3B
0005433811627	27871	7	4A
0005433811626	27871	8	4B
0005433811621	27871	9	5A
0005433811624	27871	10	5B
0005433811623	27871	11	6A
0005433811622	27871	12	6B
0005433367549	21730	1	1A
0005433367218	21730	2	1C
0005435652905	21730	3	1D
0005435652888	21730	4	1F
0005433367504	21730	5	2A
0005433367637	21730	6	2C
0005435652896	21730	7	2D
0005433367344	21730	8	2F
0005433367479	21730	9	3A
0005435652910	21730	10	3C
0005433367429	21730	11	3D
0005435652906	21730	12	3F
0005433367420	21730	13	4A
0005433367593	21730	14	4C
0005435652901	21730	15	4D
0005433367269	21730	16	4E
0005433367305	21730	17	4F
0005435652916	21730	18	5A
0005433367401	21730	19	5C
0005435652894	21730	20	5D
0005435652887	21730	21	5E
0005433367268	21730	22	5F
0005433367482	21730	23	6C
0005433367518	21730	24	6D
0005435652903	21730	25	6E
0005435652899	21730	26	7A
0005433367430	21730	27	7C
0005433367388	21730	28	7D
0005433367326	21730	29	7E
0005433367369	21730	30	7F
0005433367343	21730	31	8C
0005435652884	21730	32	8E
0005435652881	21730	33	8F
0005433367224	21730	34	9A
0005433367335	21730	35	9D
0005433367325	21730	36	9E
0005433367592	21730	37	10A
0005435652882	21730	38	10C
0005433367486	21730	39	10D
0005433367334	21730	40	10E
0005435652895	21730	41	10F
0005435652902	21730	42	11A
0005435652893	21730	43	11C
0005435652880	21730	44	11D
0005433367435	21730	45	11E
0005433367379	21730	46	11F
0005435652891	21730	47	12A
0005433367444	21730	48	12C
0005435652914	21730	49	12D
0005435652909	21730	50	12F
0005435652886	21730	51	13A
0005433367595	21730	52	13C
0005435652898	21730	53	13D
0005433367579	21730	54	13E
0005433367550	21730	55	13F
0005433367384	21730	56	14A
0005435652900	21730	57	14D
0005433367353	21730	58	14E
0005435652908	21730	59	15C
0005433367594	21730	60	15D
0005433367336	21730	61	15E
0005433367524	21730	62	15F
0005435652907	21730	63	16A
0005433367295	21730	64	16C
0005433367478	21730	65	16D
0005433367503	21730	66	16E
0005435652883	21730	67	16F
0005435652904	21730	68	17A
0005435652912	21730	69	17C
0005433367416	21730	70	17D
0005435652890	21730	71	17E
0005435652878	21730	72	17F
0005435652897	21730	73	18A
0005435652885	21730	74	18C
0005435652915	21730	75	18D
0005435652911	21730	76	18F
0005435652889	21730	77	19A
0005433367551	21730	78	19C
0005435652913	21730	79	19D
0005435652879	21730	80	19E
0005435652892	21730	81	20A
0005433367591	21730	82	20E
0005433784833	9388	1	1A
0005434170901	9388	2	1C
0005433805252	9388	3	1F
0005432657438	9388	4	1H
0005433784837	9388	5	1G
0005434170900	9388	6	2A
0005433784841	9388	7	2C
0005433805276	9388	8	2G
0005433805269	9388	9	2H
0005433784845	9388	10	3C
0005433784832	9388	11	3F
0005433763160	9388	12	3G
0005434170845	9388	13	3H
0005433805275	9388	14	4B
0005433784836	9388	15	4A
0005433805277	9388	16	4F
0005433805249	9388	17	4G
0005434170871	9388	18	4H
0005433784827	9388	19	5B
0005433805279	9388	20	5C
0005435269648	9388	21	5H
0005433784821	9388	22	9B
0005433805246	9388	23	11D
0005434170933	9388	24	11B
0005433784850	9388	25	11F
0005433805266	9388	26	12A
0005433763158	9388	27	12D
0005435269663	9388	28	12E
0005433784847	9388	29	12F
0005434170941	9388	30	12G
0005433763157	9388	31	13H
0005433805260	9388	32	14B
0005433784831	9388	33	14A
0005432666382	9388	34	14D
0005434170886	9388	35	14H
0005433805265	9388	36	14G
0005433763159	9388	37	15A
0005433805257	9388	38	15B
0005433784814	9388	39	15F
0005435269653	9388	40	15H
0005433784823	9388	41	16A
0005435269664	9388	42	16D
0005433805278	9388	43	16G
0005433805267	9388	44	16F
0005434170911	9388	45	16H
0005433805268	9388	46	17B
0005432657439	9388	47	17A
0005434170876	9388	48	17G
0005433805274	9388	49	17F
0005433784825	9388	50	17H
0005433805280	9388	51	18A
0005432665267	9388	52	18D
0005433805250	9388	53	18F
0005435269635	9388	54	18G
0005433763163	9388	55	19A
0005433805254	9388	56	19B
0005433784839	9388	57	19E
0005433805281	9388	58	19F
0005435269634	9388	59	19H
0005433763156	9388	60	19G
0005433805258	9388	61	20E
0005433784828	9388	62	20G
0005433784843	9388	63	20F
0005433784826	9388	64	21D
0005433805282	9388	65	21F
0005433763152	9388	66	22A
0005433805271	9388	67	22D
0005433763161	9388	68	22B
0005433784829	9388	69	22E
0005433784842	9388	70	22G
0005435269649	9388	71	22F
0005434170877	9388	72	23A
0005433805285	9388	73	22H
0005433784822	9388	74	23B
0005433784834	9388	75	23D
0005433784819	9388	76	23G
0005433784844	9388	77	24A
0005433805262	9388	78	24D
0005433763164	9388	79	24F
0005433805248	9388	80	25F
0005434151684	9388	81	27G
0005435269639	9388	82	27F
0005433805284	9388	83	27H
0005433784816	9388	84	28A
0005433805259	9388	85	28D
0005433784830	9388	86	28B
0005433763165	9388	87	28E
0005432667447	9388	88	28F
0005433805272	9388	89	28G
0005433805273	9388	90	29A
0005433805255	9388	91	29E
0005433784815	9388	92	29F
0005433784824	9388	93	29H
0005433784835	9388	94	29G
0005433805270	9388	95	30D
0005433784838	9388	96	30B
0005433784818	9388	97	30F
0005434170912	9388	98	30H
0005434170902	9388	99	31A
0005433805263	9388	100	31E
0005433784820	9388	101	31D
0005435269658	9388	102	31F
0005435269645	9388	103	31G
0005433763166	9388	104	32E
0005433784817	9388	105	32G
0005433763155	9388	106	33A
0005433805253	9388	107	33D
0005433805247	9388	108	33B
0005435269646	9388	109	33G
0005433763154	9388	110	33F
0005433805264	9388	111	34A
0005434170870	9388	112	34D
0005434170927	9388	113	34B
0005435269655	9388	114	34F
0005433805283	9388	115	34E
0005434170940	9388	116	34G
0005432666381	9388	117	34H
0005433784849	9388	118	35A
0005434170885	9388	119	35D
0005435269661	9388	120	35B
0005433805261	9388	121	35E
0005433763153	9388	122	35H
0005433784846	9388	123	35G
0005433805251	9388	124	36B
0005434170931	9388	125	36E
0005432657440	9388	126	36H
0005435269662	9388	127	37D
0005433805256	9388	128	37G
0005433784840	9388	129	37F
0005433763162	9388	130	38A
0005435269654	9388	131	37H
0005435269636	9388	132	38D
0005433784848	9388	133	38E
0005432665268	9388	134	38F
0005434170942	9388	135	38H
0005433805046	26249	1	1B
0005433784460	26249	2	1F
0005433784518	26249	3	1C
0005435269743	26249	4	1H
0005433784468	26249	5	2C
0005433784662	26249	6	2B
0005433784554	26249	7	2H
0005433763102	26249	8	2G
0005433763065	26249	9	3B
0005432659673	26249	10	3F
0005433805028	26249	11	3C
0005433805041	26249	12	3H
0005433784631	26249	13	4B
0005435269745	26249	14	4G
0005435269738	26249	15	5A
0005433763039	26249	16	4H
0005433784620	26249	17	5B
0005433805025	26249	18	5G
0005433804947	26249	19	5F
0005433763053	26249	20	9A
0005433763101	26249	21	5H
0005434151696	26249	22	9B
0005433784571	26249	23	9G
0005433763020	26249	24	9H
0005433805060	26249	25	11B
0005433804907	26249	26	11A
0005432659676	26249	27	11D
0005434171007	26249	28	11F
0005435269739	26249	29	12A
0005433805007	26249	30	11H
0005433784622	26249	31	12B
0005435269736	26249	32	12D
0005433763040	26249	33	12F
0005433805026	26249	34	12G
0005433763058	26249	35	13D
0005433784467	26249	36	13F
0005433784621	26249	37	13E
0005433784451	26249	38	14A
0005433784697	26249	39	14B
0005433784466	26249	40	14D
0005433784639	26249	41	14H
0005433804906	26249	42	14G
0005434171009	26249	43	15B
0005433784533	26249	44	15A
0005433804796	26249	45	15E
0005434171002	26249	46	15G
0005433784471	26249	47	15F
0005433804990	26249	48	15H
0005434171006	26249	49	16D
0005433804957	26249	50	16B
0005434151693	26249	51	16E
0005434171005	26249	52	16F
0005433804985	26249	53	16H
0005433784542	26249	54	16G
0005434269094	26249	55	17A
0005435269742	26249	56	17F
0005433784520	26249	57	17E
0005432657406	26249	58	17H
0005435269744	26249	59	18B
0005433804870	26249	60	18A
0005433784529	26249	61	18D
0005434271304	26249	62	18F
0005433762974	26249	63	18G
0005433804948	26249	64	19A
0005434171003	26249	65	18H
0005433805130	26249	66	19F
0005433784519	26249	67	19E
0005433763032	26249	68	19H
0005433763031	26249	69	19G
0005433784399	26249	70	20D
0005433784499	26249	71	20E
0005434151695	26249	72	20G
0005434151697	26249	73	21D
0005433762957	26249	74	21B
0005433784567	26249	75	21E
0005433804869	26249	76	21H
0005433763087	26249	77	22B
0005432659681	26249	78	22E
0005433805029	26249	79	22G
0005433784576	26249	80	22F
0005433784556	26249	81	22H
0005434171016	26249	82	23A
0005435269740	26249	83	23E
0005433805097	26249	84	23D
0005433784661	26249	85	23B
0005433784566	26249	86	23F
0005433805098	26249	87	23G
0005435269737	26249	88	24A
0005433804956	26249	89	23H
0005433784484	26249	90	24F
0005432659675	26249	91	24E
0005433804995	26249	92	24H
0005432657422	26249	93	24G
0005433805059	26249	94	25D
0005433784469	26249	95	27A
0005433804940	26249	96	27B
0005435269741	26249	97	27D
0005433784406	26249	98	27F
0005433784638	26249	99	27E
0005433784503	26249	100	27H
0005433804908	26249	101	27G
0005434151694	26249	102	28A
0005433784605	26249	103	28D
0005433804984	26249	104	28B
0005433762973	26249	105	28E
0005433784528	26249	106	28H
0005433784461	26249	107	29B
0005433804989	26249	108	29A
0005434171012	26249	109	29D
0005433804994	26249	110	29E
0005433784568	26249	111	30A
0005434171011	26249	112	29H
0005433763017	26249	113	30B
0005433805045	26249	114	30H
0005434269095	26249	115	30G
0005433804986	26249	116	31B
0005434171010	26249	117	31A
0005433804911	26249	118	31E
0005432657408	26249	119	31G
0005433804916	26249	120	32A
0005434171015	26249	121	31H
0005433784477	26249	122	32G
0005433804934	26249	123	33B
0005433784551	26249	124	33E
0005433784581	26249	125	33F
0005434171014	26249	126	34A
0005433805074	26249	127	34B
0005433763092	26249	128	34E
0005433804935	26249	129	34H
0005434171013	26249	130	35B
0005434171004	26249	131	35A
0005432659680	26249	132	35F
0005433784572	26249	133	35H
0005433804912	26249	134	36B
0005432657405	26249	135	36D
0005433784573	26249	136	36F
0005433784340	26249	137	36E
0005433784630	26249	138	36H
0005433763060	26249	139	37A
0005433804924	26249	140	37D
0005433804871	26249	141	37E
0005433805077	26249	142	37H
0005433805008	26249	143	37G
0005433763033	26249	144	38A
0005433805024	26249	145	38D
0005433763059	26249	146	38B
0005433763010	26249	147	38E
0005433804865	26249	148	38F
0005433784428	26249	149	39D
0005434171008	26249	150	39F
0005433763043	26249	151	39E
0005435929614	4903	1	1D
0005435929617	4903	2	2B
0005435135653	4903	3	2C
0005435135654	4903	4	2D
0005435929607	4903	5	4D
0005435135655	4903	6	6D
0005435135652	4903	7	19A
0005435135656	4903	8	19B
0005435929603	4903	9	19D
0005435929606	4903	10	20C
0005435135603	33005	1	1A
0005435135602	33005	2	3A
0005435929634	33005	3	4C
0005435929637	33005	4	4D
0005435135598	33005	5	5B
0005435929636	33005	6	19A
0005435929635	33005	7	22C
0005434983270	9493	1	2B
0005434983271	9493	2	4C
0005434983272	9493	3	5B
0005434983268	9493	4	5C
0005434983269	9493	5	20A
0005434217925	9493	6	22A
0005434217902	9493	7	23A
0005434983239	27363	1	1A
0005434217953	27363	2	3D
0005434983226	27363	3	4A
0005434217954	27363	4	7A
0005434217955	27363	5	18C
0005434217956	27363	6	20A
0005434983215	27363	7	21A
0005434983225	27363	8	23B
0005433960116	24288	1	1B
0005433985392	24288	2	1F
0005433985252	24288	3	2C
0005433960141	24288	4	2B
0005433985460	24288	5	2F
0005433960043	24288	6	2G
0005433985407	24288	7	3C
0005433985393	24288	8	3H
0005433959926	24288	9	4C
0005433985366	24288	10	4G
0005433960080	24288	11	4H
0005433960011	24288	12	5B
0005433960177	24288	13	5C
0005433960074	24288	14	9B
0005433985510	24288	15	9A
0005433985320	24288	16	9H
0005433985284	24288	17	11A
0005433985361	24288	18	11D
0005433985235	24288	19	11F
0005433985363	24288	20	11H
0005433985368	24288	21	12B
0005433960140	24288	22	12E
0005433985372	24288	23	12D
0005433960053	24288	24	12H
0005433985540	24288	25	13D
0005433960096	24288	26	13G
0005433960191	24288	27	14B
0005433985181	24288	28	14A
0005433960118	24288	29	14D
0005433960090	24288	30	14E
0005433959988	24288	31	14H
0005433985218	24288	32	15F
0005433985210	24288	33	16B
0005433960101	24288	34	16A
0005433985554	24288	35	16D
0005433985474	24288	36	16E
0005433985291	24288	37	16G
0005433985539	24288	38	16H
0005433985415	24288	39	17A
0005433985326	24288	40	17D
0005433985491	24288	41	17G
0005433960235	24288	42	17F
0005433985352	24288	43	18A
0005433985289	24288	44	17H
0005433985394	24288	45	18D
0005433985561	24288	46	18G
0005433985546	24288	47	19A
0005433960212	24288	48	19G
0005433960128	24288	49	20A
0005433985263	24288	50	19H
0005433960234	24288	51	20B
0005433959972	24288	52	20E
0005433985439	24288	53	20G
0005433960233	24288	54	20H
0005433960102	24288	55	21A
0005433960015	24288	56	21B
0005433960041	24288	57	21F
0005433985264	24288	58	21E
0005433985414	24288	59	21H
0005433959989	24288	60	22B
0005433985515	24288	61	22G
0005433985290	24288	62	22F
0005433985395	24288	63	23D
0005433960223	24288	64	23F
0005433985504	24288	65	23H
0005433960095	24288	66	24D
0005433960089	24288	67	24G
0005433985179	24288	68	25F
0005433985219	24288	69	27E
0005433960213	24288	70	27F
0005433960180	24288	71	27G
0005433960204	24288	72	28A
0005433960192	24288	73	28D
0005433960013	24288	74	28B
0005433985545	24288	75	28G
0005433985516	24288	76	28H
0005433985331	24288	77	29A
0005433960122	24288	78	29B
0005433985413	24288	79	29G
0005433985340	24288	80	30B
0005433985528	24288	81	30E
0005433960042	24288	82	30G
0005433960114	24288	83	30F
0005433985211	24288	84	31A
0005433959948	24288	85	31D
0005433985450	24288	86	31E
0005433985438	24288	87	31H
0005433985341	24288	88	32B
0005433959942	24288	89	32E
0005433985367	24288	90	32D
0005433960267	24288	91	32F
0005433985182	24288	92	32G
0005433985279	24288	93	33D
0005433985213	24288	94	33B
0005433985342	24288	95	33E
0005433985437	24288	96	33G
0005433960012	24288	97	33F
0005433959949	24288	98	33H
0005433960121	24288	99	34F
0005433960237	24288	100	34H
0005433985308	24288	101	35A
0005433960227	24288	102	35F
0005433985473	24288	103	36D
0005433985330	24288	104	36F
0005433985305	24288	105	36H
0005433960176	24288	106	37F
0005433960240	24288	107	37G
0005433960115	24288	108	38D
0005433985508	24288	109	38B
0005433960243	24288	110	38E
0005433985251	24288	111	38G
0005433960656	25944	1	1A
0005433985785	25944	2	1B
0005433960652	25944	3	2C
0005433960672	25944	4	3A
0005433985761	25944	5	3B
0005433960653	25944	6	3G
0005433960636	25944	7	4F
0005433985769	25944	8	4C
0005433960674	25944	9	4H
0005433985743	25944	10	5C
0005433985790	25944	11	5F
0005433985752	25944	12	9B
0005433985780	25944	13	11A
0005433985755	25944	14	9H
0005433960635	25944	15	11D
0005433985745	25944	16	11G
0005433985778	25944	17	12A
0005433985748	25944	18	12H
0005433985787	25944	19	13E
0005433960642	25944	20	14A
0005433960643	25944	21	13H
0005433960644	25944	22	14D
0005433985760	25944	23	14F
0005433985754	25944	24	15E
0005433960651	25944	25	15F
0005433960630	25944	26	15H
0005433985770	25944	27	16D
0005433960655	25944	28	16H
0005433960663	25944	29	17D
0005433985749	25944	30	17E
0005433985775	25944	31	17H
0005433985765	25944	32	18A
0005433985779	25944	33	18E
0005433985763	25944	34	19D
0005433960657	25944	35	19F
0005433985766	25944	36	19G
0005433985744	25944	37	20G
0005433960641	25944	38	20F
0005433985742	25944	39	20H
0005433985747	25944	40	21B
0005433985772	25944	41	21E
0005433960669	25944	42	21F
0005433985771	25944	43	21H
0005433960666	25944	44	22D
0005433985776	25944	45	22F
0005433985750	25944	46	22E
0005433985753	25944	47	22H
0005433960645	25944	48	23B
0005433985739	25944	49	23A
0005433985759	25944	50	23F
0005433960670	25944	51	23E
0005433960647	25944	52	23H
0005433960654	25944	53	24F
0005433960639	25944	54	24H
0005433985767	25944	55	24G
0005433985782	25944	56	25D
0005433960665	25944	57	27B
0005433960658	25944	58	27H
0005433960664	25944	59	28E
0005433960660	25944	60	29A
0005433985746	25944	61	28H
0005433985777	25944	62	29B
0005433985756	25944	63	29E
0005433960632	25944	64	29D
0005433985788	25944	65	30A
0005433985781	25944	66	29H
0005433985751	25944	67	30E
0005433960633	25944	68	30G
0005433985762	25944	69	30F
0005433960668	25944	70	31B
0005433960650	25944	71	31A
0005433985757	25944	72	32A
0005433985764	25944	73	32B
0005433985783	25944	74	32F
0005433985786	25944	75	33A
0005433960634	25944	76	33D
0005433985740	25944	77	33G
0005433960673	25944	78	33F
0005433960659	25944	79	33H
0005433960646	25944	80	34A
0005433960637	25944	81	35A
0005433960667	25944	82	34H
0005433960638	25944	83	35B
0005433985774	25944	84	35D
0005433960671	25944	85	35G
0005433960648	25944	86	35F
0005433960631	25944	87	36A
0005433960662	25944	88	35H
0005433985758	25944	89	36H
0005433985768	25944	90	36G
0005433960629	25944	91	37B
0005433985773	25944	92	37H
0005433985784	25944	93	37G
0005433960640	25944	94	38B
0005433960661	25944	95	38E
0005433960649	25944	96	38H
0005433985741	25944	97	39E
0005433985789	25944	98	39D
0005432269485	966	1	1A
0005434480238	966	2	1B
0005434480256	966	3	1C
0005434480246	966	4	1D
0005434480248	966	5	2A
0005434480244	966	6	2B
0005433165746	966	7	2C
0005434480252	966	8	2D
0005434480242	966	9	3A
0005434480247	966	10	3C
0005432269486	966	11	3B
0005434480258	966	12	3D
0005434480254	966	13	4A
0005434480253	966	14	4B
0005434480237	966	15	4D
0005434480250	966	16	5A
0005433165750	966	17	5B
0005434480241	966	18	5C
0005433165738	966	19	5D
0005433165704	966	20	6A
0005434480257	966	21	6B
0005434480239	966	22	6C
0005433165744	966	23	6D
0005434480251	966	24	7A
0005433165751	966	25	7C
0005433165756	966	26	7D
0005433165774	966	27	18A
0005433165737	966	28	18B
0005434480249	966	29	18C
0005434480261	966	30	19A
0005432269487	966	31	19B
0005434480243	966	32	19C
0005433165743	966	33	19D
0005434480240	966	34	20A
0005434480255	966	35	20B
0005433165755	966	36	20C
0005434480245	966	37	20D
0005433165745	966	38	21A
0005433165775	966	39	21B
0005434480259	966	40	21C
0005434480262	966	41	21D
0005434480260	966	42	22A
0005433165793	966	43	22B
0005433165815	966	44	22C
0005434479949	16554	1	1A
0005434479959	16554	2	1B
0005433165864	16554	3	1D
0005433165862	16554	4	2A
0005434479962	16554	5	2B
0005434479993	16554	6	3A
0005433165869	16554	7	3B
0005434480065	16554	8	3C
0005433165857	16554	9	3D
0005433165868	16554	10	4C
0005434480024	16554	11	5A
0005433165863	16554	12	5B
0005433165859	16554	13	5C
0005434480085	16554	14	5D
0005434480036	16554	15	6A
0005434479998	16554	16	6C
0005434480035	16554	17	6D
0005434480087	16554	18	7A
0005434479948	16554	19	7B
0005434480049	16554	20	7C
0005434479956	16554	21	18B
0005433165867	16554	22	18C
0005434479945	16554	23	19B
0005434479918	16554	24	19C
0005434479961	16554	25	19D
0005434480076	16554	26	20A
0005433165860	16554	27	20B
0005434479955	16554	28	20C
0005433165858	16554	29	20D
0005434480037	16554	30	21A
0005434479994	16554	31	21C
0005434480050	16554	32	21D
0005433165866	16554	33	22A
0005434479957	16554	34	22B
0005433165861	16554	35	22C
0005433165865	16554	36	23A
0005433872471	3217	1	4A
0005433872472	3217	2	6A
0005433872473	3217	3	6B
0005433872467	3217	4	6C
0005433872475	3217	5	7A
0005433872474	3217	6	7D
0005433872477	3217	7	18C
0005433872468	3217	8	18D
0005433872476	3217	9	21B
0005433872469	3217	10	22B
0005433872470	3217	11	23A
0005433872455	32539	1	1B
0005433872454	32539	2	1C
0005433872437	32539	3	4A
0005433872440	32539	4	4C
0005433872433	32539	5	5B
0005433872443	32539	6	6A
0005433872436	32539	7	20A
0005433872429	32539	8	20B
0005433872448	32539	9	22B
0005433872432	32539	10	22C
0005433872441	32539	11	22D
0005433872449	32539	12	23A
0005435142522	10345	1	1A
0005433289774	10345	2	1B
0005435149966	10345	3	1C
0005435149975	10345	4	1D
0005435386486	10345	5	2A
0005435149976	10345	6	2B
0005433289775	10345	7	2C
0005435142524	10345	8	2D
0005435142518	10345	9	3A
0005435149967	10345	10	3B
0005435149968	10345	11	3C
0005435142520	10345	12	3D
0005435142517	10345	13	4A
0005435386458	10345	14	4B
0005435386515	10345	15	4C
0005433289745	10345	16	4D
0005435149964	10345	17	5A
0005435386472	10345	18	5B
0005433289758	10345	19	5C
0005435386514	10345	20	5D
0005435142523	10345	21	6A
0005435386459	10345	22	6B
0005435142516	10345	23	6C
0005435149974	10345	24	6D
0005435386513	10345	25	7A
0005433289757	10345	26	7B
0005435149971	10345	27	7C
0005435149977	10345	28	7D
0005435386484	10345	29	18A
0005435149965	10345	30	18B
0005435142519	10345	31	18C
0005435386493	10345	32	18D
0005435149978	10345	33	19A
0005435386475	10345	34	19B
0005433289746	10345	35	19C
0005435149972	10345	36	19D
0005435142521	10345	37	20A
0005435142529	10345	38	20B
0005435142525	10345	39	20C
0005435142515	10345	40	20D
0005433289750	10345	41	21A
0005435142527	10345	42	21B
0005435149969	10345	43	21C
0005435386492	10345	44	22A
0005435386474	10345	45	21D
0005435142526	10345	46	22B
0005435149973	10345	47	22C
0005435149970	10345	48	22D
0005435386460	10345	49	23A
0005435142528	10345	50	23B
0005435142398	21939	1	1A
0005435149868	21939	2	1B
0005433289830	21939	3	1C
0005435386554	21939	4	1D
0005435149869	21939	5	2A
0005435386560	21939	6	2B
0005433289834	21939	7	2C
0005435142376	21939	8	2D
0005435149812	21939	9	3B
0005435386557	21939	10	3C
0005435386558	21939	11	3D
0005435142395	21939	12	4A
0005433289828	21939	13	4B
0005435142456	21939	14	4C
0005435386561	21939	15	4D
0005435142396	21939	16	5A
0005435386559	21939	17	5B
0005435149873	21939	18	5C
0005435142349	21939	19	6A
0005435142423	21939	20	6B
0005435142434	21939	21	6C
0005435149811	21939	22	6D
0005435142451	21939	23	7A
0005435149786	21939	24	7B
0005435142424	21939	25	7C
0005435142391	21939	26	7D
0005435142390	21939	27	18B
0005435142419	21939	28	18A
0005433289833	21939	29	18C
0005435386555	21939	30	18D
0005435142370	21939	31	19A
0005435142350	21939	32	19C
0005435149900	21939	33	19B
0005435386556	21939	34	19D
0005435142418	21939	35	20A
0005433289829	21939	36	20B
0005435149785	21939	37	20D
0005433289831	21939	38	21B
0005435149882	21939	39	21D
0005433289832	21939	40	22A
0005435142383	21939	41	22B
0005435142371	21939	42	22C
0005435149855	21939	43	22D
0005435142375	21939	44	23A
0005435142382	21939	45	23B
0005434573291	11191	1	1A
0005435502044	11191	2	1C
0005435545637	11191	3	1F
0005435529032	11191	4	2A
0005435529030	11191	5	2C
0005434573293	11191	6	2D
0005435502139	11191	7	2F
0005435319493	11191	8	3A
0005435502097	11191	9	3C
0005434573299	11191	10	3D
0005434573294	11191	11	4A
0005435502027	11191	12	4D
0005435502120	11191	13	6A
0005435502074	11191	14	6C
0005435528940	11191	15	6D
0005435545633	11191	16	7A
0005435501944	11191	17	7C
0005435319491	11191	18	7D
0005435529079	11191	19	7F
0005434573300	11191	20	8A
0005435502075	11191	21	8C
0005435529005	11191	22	8F
0005435502061	11191	23	9A
0005435528907	11191	24	9C
0005435319426	11191	25	9D
0005435529033	11191	26	9E
0005435502005	11191	27	9F
0005435529003	11191	28	10C
0005435529021	11191	29	10D
0005435502138	11191	30	10E
0005435528895	11191	31	10F
0005435319473	11191	32	11A
0005435529020	11191	33	11C
0005435319472	11191	34	11E
0005434573289	11191	35	11F
0005435502079	11191	36	12E
0005435319451	11191	37	12F
0005435502026	11191	38	13A
0005435502022	11191	39	13C
0005434573295	11191	40	13D
0005435529078	11191	41	13E
0005435502025	11191	42	13F
0005435502043	11191	43	14A
0005435502085	11191	44	14E
0005434573298	11191	45	14F
0005435502137	11191	46	15C
0005435502051	11191	47	15D
0005434573303	11191	48	15E
0005435502045	11191	49	15F
0005435545627	11191	50	16A
0005434573302	11191	51	16C
0005435529004	11191	52	16E
0005435545626	11191	53	16F
0005434573296	11191	54	17A
0005435528901	11191	55	17C
0005435545636	11191	56	17D
0005435502096	11191	57	17E
0005435319492	11191	58	17F
0005435319452	11191	59	18A
0005435502042	11191	60	18C
0005434573292	11191	61	18D
0005434573290	11191	62	18F
0005434573301	11191	63	19A
0005435502006	11191	64	19C
0005435502050	11191	65	19D
0005435529027	11191	66	19E
0005435502024	11191	67	20C
0005435502121	11191	68	20E
0005434573297	11191	69	20F
0005435502221	20957	1	1A
0005435517851	20957	2	1D
0005434573216	20957	3	1F
0005434573131	20957	4	2A
0005435508311	20957	5	2C
0005435502224	20957	6	2D
0005434573230	20957	7	2F
0005434573190	20957	8	3A
0005435517849	20957	9	3C
0005434573231	20957	10	3D
0005435502236	20957	11	3F
0005435508314	20957	12	4A
0005435508319	20957	13	4C
0005435508312	20957	14	4D
0005434573188	20957	15	4E
0005435508310	20957	16	4F
0005435502233	20957	17	5A
0005435517847	20957	18	5C
0005435517843	20957	19	5D
0005435517838	20957	20	5E
0005435508309	20957	21	5F
0005435517848	20957	22	6A
0005435502241	20957	23	6C
0005434573176	20957	24	6D
0005435502220	20957	25	6E
0005435502228	20957	26	6F
0005434573132	20957	27	7A
0005434573179	20957	28	7C
0005434573144	20957	29	7D
0005435502239	20957	30	7E
0005435502232	20957	31	7F
0005435502225	20957	32	8C
0005435502235	20957	33	8D
0005435508322	20957	34	8F
0005435508313	20957	35	9A
0005435502229	20957	36	9C
0005435502237	20957	37	9E
0005434573162	20957	38	9F
0005435319551	20957	39	10A
0005434573177	20957	40	10D
0005435502242	20957	41	10E
0005432291921	20957	42	10F
0005435319555	20957	43	11A
0005435502231	20957	44	11C
0005435502234	20957	45	11E
0005435517850	20957	46	12A
0005435517842	20957	47	12C
0005435517844	20957	48	12E
0005434573207	20957	49	12F
0005435319557	20957	50	13A
0005435502226	20957	51	13D
0005435517837	20957	52	13E
0005435502223	20957	53	13F
0005435508321	20957	54	14A
0005435517839	20957	55	14D
0005435502227	20957	56	14E
0005435502240	20957	57	14F
0005435502238	20957	58	15A
0005435508315	20957	59	15C
0005434573186	20957	60	15D
0005435319556	20957	61	15E
0005435319554	20957	62	16A
0005435517840	20957	63	16C
0005435502222	20957	64	16D
0005435508316	20957	65	16E
0005434573192	20957	66	16F
0005435517841	20957	67	17A
0005435502230	20957	68	17D
0005435319553	20957	69	17F
0005435508317	20957	70	18A
0005434573189	20957	71	18C
0005434573197	20957	72	18D
0005435502219	20957	73	18E
0005435508318	20957	74	18F
0005435319558	20957	75	19A
0005434573191	20957	76	19C
0005435319552	20957	77	19D
0005435517846	20957	78	19E
0005435517845	20957	79	19F
0005434573178	20957	80	20A
0005435319550	20957	81	20D
0005435508320	20957	82	20E
0005433683330	24313	1	2D
0005433927399	24313	2	3A
0005433927416	24313	3	4C
0005433683320	24313	4	5B
0005433927405	24313	5	6A
0005433927404	24313	6	6C
0005433927410	24313	7	7A
0005433683325	24313	8	7B
0005433927398	24313	9	18B
0005433683324	24313	10	19A
0005433683329	24313	11	19B
0005433683326	24313	12	20A
0005433683331	24313	13	20B
0005433683328	24313	14	20D
0005433927402	24313	15	21A
0005433683327	24313	16	22A
0005433683323	24313	17	22C
0005433683321	24313	18	22D
0005433683322	24313	19	23A
0005433683294	29276	1	2D
0005433683295	29276	2	3A
0005433927432	29276	3	3D
0005433927425	29276	4	4A
0005433683315	29276	5	4B
0005433683305	29276	6	4C
0005433683311	29276	7	4D
0005433683306	29276	8	5B
0005433927426	29276	9	5C
0005433927429	29276	10	6B
0005433927433	29276	11	7B
0005433683309	29276	12	7C
0005433927427	29276	13	7D
0005433927431	29276	14	18B
0005433683310	29276	15	19C
0005433683302	29276	16	20A
0005433683308	29276	17	20D
0005433927430	29276	18	21A
0005433927428	29276	19	21C
0005433683297	29276	20	21D
0005433927434	29276	21	22A
0005433683296	29276	22	22C
0005432692756	3059	1	1A
0005432692698	3059	2	1D
0005432692577	3059	3	1F
0005432692605	3059	4	2A
0005432692684	3059	5	2C
0005432692777	3059	6	2F
0005432692661	3059	7	3A
0005432692862	3059	8	3D
0005432692662	3059	9	4C
0005432692585	3059	10	4D
0005432692576	3059	11	5F
0005432692685	3059	12	6A
0005432692640	3059	13	6C
0005432692607	3059	14	6E
0005432692753	3059	15	7A
0005432692612	3059	16	7E
0005432692665	3059	17	8D
0005432692724	3059	18	8E
0005432692586	3059	19	10C
0005432692775	3059	20	10D
0005432692752	3059	21	10E
0005432692680	3059	22	11D
0005432692601	3059	23	12C
0005432692584	3059	24	12F
0005432692681	3059	25	13C
0005432692738	3059	26	14D
0005432692716	3059	27	14E
0005432692606	3059	28	15F
0005432692651	3059	29	16E
0005432692686	3059	30	16F
0005432692739	3059	31	17D
0005432692659	3059	32	17E
0005432692660	3059	33	17F
0005432692863	3059	34	18C
0005432692751	3059	35	18D
0005432692714	3059	36	18E
0005432692583	3059	37	18F
0005432692613	3059	38	19A
0005432692743	3059	39	19C
0005432692778	3059	40	20D
0005432692744	3059	41	20E
0005432217768	3058	1	1A
0005433123588	3058	2	1C
0005432706683	3058	3	1F
0005433123707	3058	4	2D
0005432706692	3058	5	2F
0005432706696	3058	6	3A
0005432880593	3058	7	3D
0005432880605	3058	8	3F
0005432706694	3058	9	4D
0005433194826	3058	10	4E
0005432706684	3058	11	5C
0005432706698	3058	12	5D
0005432706697	3058	13	5E
0005432217766	3058	14	5F
0005432706682	3058	15	6A
0005432880607	3058	16	6C
0005432880618	3058	17	6E
0005432217767	3058	18	6F
0005432880630	3058	19	7C
0005433123695	3058	20	7D
0005432706675	3058	21	7E
0005433123636	3058	22	7F
0005432880655	3058	23	8D
0005432706677	3058	24	8F
0005432706687	3058	25	9C
0005432880604	3058	26	9D
0005432706690	3058	27	9F
0005432706695	3058	28	10D
0005433123670	3058	29	10E
0005433123653	3058	30	10F
0005432880654	3058	31	11A
0005432880651	3058	32	11D
0005433123706	3058	33	11E
0005432706680	3058	34	12A
0005432706686	3058	35	12C
0005432706679	3058	36	12D
0005432706681	3058	37	12E
0005432706693	3058	38	13A
0005432706689	3058	39	13C
0005432706685	3058	40	13D
0005433123671	3058	41	13E
0005432880647	3058	42	13F
0005433123654	3058	43	14A
0005432880619	3058	44	14D
0005433194835	3058	45	14E
0005433123696	3058	46	14F
0005433123724	3058	47	15A
0005432706691	3058	48	15E
0005432880699	3058	49	16A
0005433123693	3058	50	16D
0005433123725	3058	51	16F
0005433123767	3058	52	17C
0005433123697	3058	53	17D
0005432880631	3058	54	17F
0005433123698	3058	55	18A
0005432880632	3058	56	18C
0005432880700	3058	57	18D
0005433123683	3058	58	18F
0005432880653	3058	59	19C
0005432706699	3058	60	19D
0005433123661	3058	61	19E
0005432706688	3058	62	20D
0005432706678	3058	63	20E
0005432706676	3058	64	20F
0005432706515	29914	1	1A
0005433123854	29914	2	1C
0005433123861	29914	3	1D
0005432706551	29914	4	1F
0005432706514	29914	5	2A
0005432706438	29914	6	2C
0005433123851	29914	7	2D
0005432692989	29914	8	2F
0005433123844	29914	9	3A
0005433123846	29914	10	3C
0005432706513	29914	11	3D
0005432692975	29914	12	3F
0005432692993	29914	13	4A
0005433123855	29914	14	4C
0005433123860	29914	15	4D
0005432706516	29914	16	4E
0005432692998	29914	17	4F
0005432880775	29914	18	5A
0005433123850	29914	19	5C
0005432880767	29914	20	5D
0005432706411	29914	21	5E
0005432706416	29914	22	5F
0005432692988	29914	23	6A
0005432692986	29914	24	6C
0005432880761	29914	25	6D
0005433123862	29914	26	6E
0005432692990	29914	27	6F
0005433123845	29914	28	7A
0005432706370	29914	29	7C
0005432692970	29914	30	7D
0005432692978	29914	31	7E
0005432880769	29914	32	7F
0005432693000	29914	33	8A
0005433123859	29914	34	8C
0005433123848	29914	35	8D
0005432692995	29914	36	8E
0005432880771	29914	37	8F
0005432706391	29914	38	9A
0005432706428	29914	39	9C
0005432692994	29914	40	9D
0005432706405	29914	41	9E
0005432706504	29914	42	9F
0005432692999	29914	43	10A
0005432880770	29914	44	10C
0005432706578	29914	45	10D
0005432706495	29914	46	10E
0005433123852	29914	47	10F
0005432706406	29914	48	11A
0005432692984	29914	49	11C
0005432692974	29914	50	11D
0005432692979	29914	51	11E
0005432880772	29914	52	11F
0005432692997	29914	53	12A
0005432880768	29914	54	12C
0005432706371	29914	55	12D
0005432692972	29914	56	12E
0005432706364	29914	57	12F
0005432706376	29914	58	13A
0005433123856	29914	59	13C
0005432706445	29914	60	13D
0005432692973	29914	61	13E
0005432706517	29914	62	13F
0005432692996	29914	63	14A
0005432880765	29914	64	14C
0005433123858	29914	65	14D
0005432880762	29914	66	14E
0005433123865	29914	67	14F
0005433123853	29914	68	15C
0005432692991	29914	69	15A
0005433123864	29914	70	15D
0005432692969	29914	71	15E
0005432692980	29914	72	15F
0005432706392	29914	73	16A
0005433123847	29914	74	16C
0005432706465	29914	75	16D
0005433123849	29914	76	16E
0005433123857	29914	77	16F
0005432692983	29914	78	17A
0005432692982	29914	79	17C
0005432692992	29914	80	17D
0005432692971	29914	81	17E
0005432692976	29914	82	17F
0005432880763	29914	83	18A
0005432706451	29914	84	18C
0005432706482	29914	85	18D
0005432880766	29914	86	18E
0005432880773	29914	87	18F
0005432692987	29914	88	19A
0005432706377	29914	89	19C
0005432706414	29914	90	19D
0005432692977	29914	91	19E
0005433123863	29914	92	19F
0005432880764	29914	93	20A
0005432880774	29914	94	20C
0005432692985	29914	95	20D
0005432692981	29914	96	20E
0005432706499	29914	97	20F
0005434979679	23661	1	1A
0005434988698	23661	2	1B
0005434988694	23661	3	1C
0005434979676	23661	4	2A
0005434979674	23661	5	2B
0005434979671	23661	6	2C
0005434979659	23661	7	2D
0005434979658	23661	8	3B
0005434979652	23661	9	3D
0005434988692	23661	10	4A
0005434979668	23661	11	4B
0005434979666	23661	12	4C
0005434988690	23661	13	4D
0005434979673	23661	14	5A
0005434988701	23661	15	5B
0005434979667	23661	16	5C
0005434988699	23661	17	5D
0005434979656	23661	18	6B
0005434979654	23661	19	6C
0005434979663	23661	20	6D
0005434988700	23661	21	7A
0005434979665	23661	22	7B
0005434979680	23661	23	7C
0005434979670	23661	24	7D
0005434979657	23661	25	18A
0005434979662	23661	26	18B
0005434979681	23661	27	18C
0005434988691	23661	28	18D
0005434979660	23661	29	19A
0005434979664	23661	30	19B
0005434988695	23661	31	19C
0005434979675	23661	32	19D
0005434979672	23661	33	20A
0005434979661	23661	34	20B
0005434988693	23661	35	20C
0005434979678	23661	36	20D
0005434988696	23661	37	21A
0005434979655	23661	38	21B
0005434979682	23661	39	21D
0005434979669	23661	40	22B
0005434979653	23661	41	22C
0005434979677	23661	42	22D
0005434988697	23661	43	23B
0005434988591	27544	1	1A
0005434988599	27544	2	1B
0005434988555	27544	3	1C
0005434979344	27544	4	1D
0005434979375	27544	5	2A
0005434988601	27544	6	2B
0005434979274	27544	7	2C
0005434979482	27544	8	3A
0005434988592	27544	9	3B
0005434979438	27544	10	3C
0005434979378	27544	11	3D
0005434979347	27544	12	4A
0005434979392	27544	13	4B
0005434979270	27544	14	4C
0005434979411	27544	15	4D
0005434988600	27544	16	5B
0005434979317	27544	17	5C
0005434979445	27544	18	5D
0005434979417	27544	19	6B
0005434979432	27544	20	6D
0005434988574	27544	21	7A
0005434988590	27544	22	7B
0005434979343	27544	23	7C
0005434979275	27544	24	7D
0005434979327	27544	25	18A
0005434979412	27544	26	18B
0005434979379	27544	27	18D
0005434979437	27544	28	19A
0005434979425	27544	29	19B
0005434979487	27544	30	19C
0005434979418	27544	31	19D
0005434979484	27544	32	20A
0005434979446	27544	33	20B
0005434988593	27544	34	20D
0005434979354	27544	35	21A
0005434979353	27544	36	21B
0005434979483	27544	37	21C
0005434979303	27544	38	21D
0005434979281	27544	39	22A
0005434979424	27544	40	22B
0005434979397	27544	41	22C
0005434979433	27544	42	22D
0005434988602	27544	43	23A
0005434988573	27544	44	23B
0005434302858	10304	1	3C
0005434302440	10304	2	4C
0005434302443	10304	3	4D
0005434302442	10304	4	5C
0005434302439	10304	5	19C
0005434302441	10304	6	21A
0005433113509	10304	7	22A
0005433113508	10304	8	22B
0005433113512	10304	9	22C
0005434302857	10304	10	23A
0005433113529	19601	1	2B
0005434302399	19601	2	2C
0005434302381	19601	3	2D
0005434302400	19601	4	4A
0005434302402	19601	5	19B
0005434302403	19601	6	21A
0005435925114	3529	1	1A
0005435068932	3529	2	1C
0005435068945	3529	3	1F
0005435068901	3529	4	2F
0005435068931	3529	5	3A
0005435068924	3529	6	3C
0005435925109	3529	7	3F
0005435068934	3529	8	4A
0005435068918	3529	9	4D
0005435068949	3529	10	4E
0005435068941	3529	11	4F
0005435068910	3529	12	5A
0005435068920	3529	13	5C
0005435925126	3529	14	5D
0005435068917	3529	15	5F
0005435068940	3529	16	6C
0005435068904	3529	17	6D
0005435068937	3529	18	6F
0005435068921	3529	19	7C
0005435939865	3529	20	7F
0005435068926	3529	21	8C
0005435068948	3529	22	8D
0005435068936	3529	23	8E
0005435068928	3529	24	8F
0005435068913	3529	25	9D
0005435068902	3529	26	9E
0005435068915	3529	27	10C
0005435068933	3529	28	10D
0005435068938	3529	29	10E
0005435068943	3529	30	10F
0005435925169	3529	31	11A
0005435068912	3529	32	11C
0005435068906	3529	33	11D
0005435925146	3529	34	11F
0005435068919	3529	35	12C
0005435068950	3529	36	12D
0005435068923	3529	37	12E
0005435939862	3529	38	12F
0005435068903	3529	39	13A
0005435925073	3529	40	13E
0005435068935	3529	41	13F
0005435068907	3529	42	14A
0005435068922	3529	43	14C
0005435068951	3529	44	14D
0005435068927	3529	45	14E
0005435068939	3529	46	14F
0005435068942	3529	47	15A
0005435068908	3529	48	15C
0005435068914	3529	49	15D
0005435068944	3529	50	15E
0005435068905	3529	51	16A
0005435068952	3529	52	16C
0005435925061	3529	53	16D
0005435068946	3529	54	16E
0005435068916	3529	55	16F
0005435068947	3529	56	17A
0005435068925	3529	57	17E
0005435925148	3529	58	17F
0005435925147	3529	59	18D
0005435925142	3529	60	19A
0005435925127	3529	61	20A
0005435068930	3529	62	20C
0005435068929	3529	63	20D
0005435068911	3529	64	20E
0005435068909	3529	65	20F
0005435925264	15286	1	1A
0005435068441	15286	2	1C
0005435068542	15286	3	1D
0005435068473	15286	4	1F
0005435068455	15286	5	2A
0005435068599	15286	6	2C
0005435068374	15286	7	2F
0005435068401	15286	8	3A
0005435925248	15286	9	3C
0005435068531	15286	10	3F
0005435068609	15286	11	4C
0005435068228	15286	12	4D
0005435925267	15286	13	4E
0005435068480	15286	14	4F
0005435068373	15286	15	5A
0005435068359	15286	16	5C
0005435068232	15286	17	5E
0005435068340	15286	18	5F
0005435068214	15286	19	6A
0005435925261	15286	20	6C
0005435068420	15286	21	6D
0005435925262	15286	22	6E
0005435925250	15286	23	6F
0005435068421	15286	24	7A
0005435925245	15286	25	7C
0005435068369	15286	26	7D
0005435939876	15286	27	8A
0005435925259	15286	28	8D
0005435925252	15286	29	8E
0005435925244	15286	30	9C
0005435068610	15286	31	9D
0005435068474	15286	32	9E
0005435925263	15286	33	9F
0005435068292	15286	34	10A
0005435925258	15286	35	10C
0005435068487	15286	36	10D
0005435068408	15286	37	10F
0005435068183	15286	38	11A
0005435925249	15286	39	11C
0005435939875	15286	40	11F
0005435925256	15286	41	12A
0005435068430	15286	42	12E
0005435068216	15286	43	12F
0005435068456	15286	44	13A
0005435068541	15286	45	13D
0005435925266	15286	46	13F
0005435925255	15286	47	14A
0005435068684	15286	48	14C
0005435925246	15286	49	14E
0005435925265	15286	50	14F
0005435068472	15286	51	15A
0005435068492	15286	52	15C
0005435925251	15286	53	15D
0005435068233	15286	54	16A
0005435925268	15286	55	16C
0005435068370	15286	56	16D
0005435068351	15286	57	16F
0005435068683	15286	58	17A
0005435068422	15286	59	17D
0005435068229	15286	60	17E
0005435925257	15286	61	17F
0005435068341	15286	62	18A
0005435925247	15286	63	18D
0005435068558	15286	64	18E
0005435925260	15286	65	18F
0005435068284	15286	66	19A
0005435068518	15286	67	19E
0005435925254	15286	68	20A
0005435925253	15286	69	20D
0005435068419	15286	70	20E
0005432658583	18142	1	2A
0005432658584	18142	2	2B
0005432659699	18142	3	3A
0005432660811	18142	4	3B
0005432659700	18142	5	4A
0005432667423	26384	1	1B
0005432667424	26384	2	2A
0005432660784	26384	3	3B
0005432660785	26384	4	5A
0005432667425	26384	5	5B
0005432660791	26384	6	6B
0005432660792	26384	7	6A
0005432919598	141	1	1A
0005433101448	141	2	1C
0005433101579	141	3	1F
0005432919558	141	4	1D
0005433101394	141	5	2A
0005432919705	141	6	2C
0005433101337	141	7	2F
0005432391964	141	8	3C
0005432677517	141	9	4A
0005432391945	141	10	4C
0005432919626	141	11	4F
0005432919582	141	12	4D
0005432919636	141	13	5A
0005433101542	141	14	5C
0005432919580	141	15	5F
0005433101476	141	16	5D
0005432919640	141	17	6C
0005433101493	141	18	6F
0005432901405	141	19	6D
0005433101338	141	20	7C
0005432919689	141	21	7F
0005432391957	141	22	8D
0005433101424	141	23	8C
0005433101453	141	24	8E
0005432919680	141	25	9C
0005432391954	141	26	9D
0005433101213	141	27	9F
0005433101505	141	28	10A
0005433101393	141	29	10C
0005432901431	141	30	10B
0005432919604	141	31	10D
0005432901437	141	32	11A
0005433101317	141	33	11C
0005432919581	141	34	11F
0005432391955	141	35	11E
0005432919627	141	36	12A
0005432919612	141	37	12C
0005432901383	141	38	12F
0005433101318	141	39	12E
0005433101432	141	40	13A
0005433101508	141	41	13C
0005432919639	141	42	13D
0005432677527	141	43	14A
0005433101581	141	44	13F
0005433101431	141	45	14B
0005433101527	141	46	14D
0005433101462	141	47	14E
0005433101447	141	48	14F
0005432391948	141	49	15A
0005432677526	141	50	15B
0005433101586	141	51	15D
0005432391952	141	52	15F
0005433101495	141	53	15E
0005432677542	141	54	16E
0005432901411	141	55	16D
0005432919611	141	56	16F
0005432901382	141	57	17A
0005433101572	141	58	17C
0005433101366	141	59	17F
0005432901439	141	60	17E
0005432919560	141	61	18A
0005432919610	141	62	18C
0005432901390	141	63	18E
0005432919579	141	64	19B
0005432391949	141	65	19D
0005433101502	141	66	20A
0005433101463	141	67	20B
0005433101450	141	68	20C
0005433101541	141	69	20F
0005432391953	141	70	21B
0005432919679	141	71	21A
0005432901438	141	72	21D
0005432677543	141	73	21E
0005433101543	141	74	21F
0005432919635	141	75	22B
0005433101293	141	76	22C
0005433101461	141	77	22D
0005432901432	141	78	23A
0005433101566	141	79	23C
0005433101378	141	80	23D
0005433101411	141	81	24A
0005432919660	141	82	23F
0005432391958	141	83	24B
0005433101486	141	84	24C
0005432919678	141	85	24E
0005432391962	141	86	24D
0005432919599	141	87	24F
0005433101286	141	88	25A
0005432919559	141	89	25C
0005432919575	141	90	25E
0005432919685	141	91	25F
0005432919681	141	92	26D
0005433101544	141	93	26C
0005433101507	141	94	26F
0005433101449	141	95	27B
0005433101429	141	96	27A
0005433101451	141	97	27C
0005432901365	141	98	28A
0005432391961	141	99	27F
0005433101478	141	100	28B
0005433101567	141	101	28F
0005432157486	141	102	29B
0005432901421	141	103	29C
0005433101506	141	104	29D
0005433101580	141	105	29E
0005433101323	141	106	30B
0005433101392	141	107	30A
0005432919634	141	108	30D
0005432391963	141	109	30E
0005433101364	141	110	31A
0005432919597	141	111	31C
0005432919718	141	112	31D
0005433101549	141	113	31E
0005432817376	142	1	1A
0005432817385	142	2	2A
0005432261756	142	3	2D
0005432261770	142	4	2F
0005432261760	142	5	4F
0005432817382	142	6	4D
0005432817368	142	7	5A
0005432261753	142	8	5F
0005432261774	142	9	5D
0005432817369	142	10	6C
0005432261769	142	11	7A
0005432756809	142	12	8B
0005432261766	142	13	8C
0005432261754	142	14	8E
0005432261768	142	15	8F
0005432753261	142	16	9B
0005432261785	142	17	9C
0005432288975	142	18	10A
0005432261762	142	19	10B
0005432261749	142	20	10D
0005432261750	142	21	10C
0005432261773	142	22	10E
0005432817389	142	23	10F
0005432261761	142	24	11B
0005432817363	142	25	11A
0005432261751	142	26	11D
0005432817379	142	27	11F
0005432817374	142	28	12B
0005432817364	142	29	12D
0005432817393	142	30	12F
0005432753256	142	31	12E
0005432261744	142	32	13B
0005432817392	142	33	13C
0005433687686	142	34	13F
0005432207652	142	35	14A
0005433690905	142	36	14B
0005432261755	142	37	14C
0005432261765	142	38	14E
0005432817386	142	39	15A
0005432261775	142	40	15B
0005432261777	142	41	16A
0005432753250	142	42	15F
0005432817372	142	43	16C
0005432817378	142	44	16B
0005432817381	142	45	17B
0005432261776	142	46	17D
0005432817373	142	47	17F
0005432817387	142	48	18A
0005432261763	142	49	18B
0005432756805	142	50	18C
0005432817380	142	51	18E
0005432817377	142	52	18F
0005432756806	142	53	19C
0005432261780	142	54	19E
0005432817388	142	55	20B
0005432817383	142	56	20E
0005432207653	142	57	20D
0005432261782	142	58	21A
0005432261771	142	59	21C
0005432261772	142	60	21B
0005432817391	142	61	21D
0005432288977	142	62	22A
0005432261788	142	63	22B
0005432288978	142	64	22D
0005432261767	142	65	23C
0005432261784	142	66	23E
0005432817365	142	67	24B
0005432261783	142	68	24D
0005432261752	142	69	24C
0005432261758	142	70	24E
0005432817375	142	71	25D
0005432817384	142	72	25F
0005432261779	142	73	26A
0005432817366	142	74	26B
0005432288974	142	75	26D
0005433687687	142	76	26E
0005432261781	142	77	27B
0005432261789	142	78	27A
0005433690902	142	79	27C
0005432261748	142	80	27D
0005432261747	142	81	27F
0005432288976	142	82	27E
0005432753257	142	83	28A
0005432817390	142	84	28B
0005432817371	142	85	28D
0005432817367	142	86	28C
0005432261787	142	87	28F
0005432261743	142	88	29A
0005432261746	142	89	29B
0005433690901	142	90	29D
0005432261786	142	91	29F
0005432817370	142	92	31B
0005432261745	142	93	31A
0005432261764	142	94	31C
0005432261759	142	95	31D
0005432261757	142	96	31F
0005432261778	142	97	31E
0005432919781	7935	1	1A
0005433101993	7935	2	1C
0005432753290	7935	3	1D
0005432020181	7935	4	2A
0005433102014	7935	5	2C
0005433102007	7935	6	2F
0005432919788	7935	7	2D
0005432751517	7935	8	3A
0005433101991	7935	9	3D
0005433101968	7935	10	3F
0005433101985	7935	11	4A
0005432045609	7935	12	4D
0005433101967	7935	13	5C
0005432044517	7935	14	5F
0005432919785	7935	15	5D
0005433101966	7935	16	6C
0005432020172	7935	17	6F
0005432020180	7935	18	7A
0005432919800	7935	19	7D
0005432020184	7935	20	7C
0005432919794	7935	21	8A
0005432919782	7935	22	8B
0005433101978	7935	23	8D
0005433102003	7935	24	8E
0005432919784	7935	25	9C
0005433101988	7935	26	9B
0005433102002	7935	27	9F
0005432919795	7935	28	10A
0005433101986	7935	29	10B
0005433102009	7935	30	10D
0005432020178	7935	31	10F
0005433101999	7935	32	11A
0005432020174	7935	33	11C
0005432020179	7935	34	11D
0005432020177	7935	35	11F
0005432391989	7935	36	11E
0005432919790	7935	37	12A
0005433101973	7935	38	12B
0005433101976	7935	39	12D
0005432919797	7935	40	13A
0005432020170	7935	41	12F
0005432919796	7935	42	13C
0005433101977	7935	43	13D
0005433102013	7935	44	13F
0005432919793	7935	45	13E
0005432020173	7935	46	14A
0005432751515	7935	47	14C
0005432020186	7935	48	14B
0005432020176	7935	49	14F
0005432020167	7935	50	15B
0005432020175	7935	51	15A
0005432020189	7935	52	15F
0005432919792	7935	53	15E
0005433101969	7935	54	16A
0005432020169	7935	55	16C
0005432020164	7935	56	16B
0005432020163	7935	57	16D
0005432919787	7935	58	16E
0005433101981	7935	59	17A
0005432677560	7935	60	16F
0005433101997	7935	61	17C
0005432919789	7935	62	17B
0005432020168	7935	63	17D
0005433101998	7935	64	17E
0005433101992	7935	65	18C
0005433102015	7935	66	18D
0005433101974	7935	67	18F
0005432677563	7935	68	19B
0005432919791	7935	69	19E
0005433101983	7935	70	20C
0005432753291	7935	71	20D
0005432919798	7935	72	20E
0005433101970	7935	73	21C
0005433102001	7935	74	21B
0005432919801	7935	75	21D
0005433101980	7935	76	22A
0005433101995	7935	77	22C
0005433101990	7935	78	22E
0005432020166	7935	79	22D
0005432919783	7935	80	23A
0005432919786	7935	81	23C
0005432753292	7935	82	24A
0005433102011	7935	83	23F
0005433101994	7935	84	24B
0005433101984	7935	85	24C
0005433102000	7935	86	24F
0005432020171	7935	87	24E
0005433101979	7935	88	25B
0005432020165	7935	89	25A
0005433101971	7935	90	25F
0005432677562	7935	91	25E
0005433101996	7935	92	26A
0005432044515	7935	93	26B
0005433101975	7935	94	26E
0005433101972	7935	95	26D
0005433101965	7935	96	26F
0005432020185	7935	97	27A
0005433101987	7935	98	27E
0005433102006	7935	99	27D
0005433102010	7935	100	27F
0005432391991	7935	101	28B
0005432919799	7935	102	28D
0005433101989	7935	103	28C
0005432020188	7935	104	28E
0005432391990	7935	105	28F
0005432044516	7935	106	29A
0005433102005	7935	107	29C
0005433101982	7935	108	30A
0005432020182	7935	109	30D
0005433102012	7935	110	30C
0005433102004	7935	111	30F
0005432677561	7935	112	31A
0005432020187	7935	113	31C
0005432045608	7935	114	31B
0005432020183	7935	115	31D
0005432751516	7935	116	31F
0005433102008	7935	117	31E
0005432817089	7936	1	1C
0005432901551	7936	2	2F
0005432817219	7936	3	3D
0005432817101	7936	4	4A
0005432817110	7936	5	4C
0005432817197	7936	6	5F
0005432817273	7936	7	6C
0005432002069	7936	8	6F
0005432817077	7936	9	7C
0005432901561	7936	10	8B
0005432901556	7936	11	8C
0005432817080	7936	12	8D
0005432817075	7936	13	9A
0005432817105	7936	14	8F
0005432901560	7936	15	9E
0005432901562	7936	16	10C
0005432817198	7936	17	10E
0005432817076	7936	18	10D
0005432817245	7936	19	11B
0005434513544	7936	20	11E
0005434513541	7936	21	12C
0005432901548	7936	22	12B
0005432817274	7936	23	12E
0005432901552	7936	24	12F
0005432817246	7936	25	14C
0005432817119	7936	26	15A
0005432817113	7936	27	14F
0005432901557	7936	28	15C
0005432817036	7936	29	15E
0005432901554	7936	30	16D
0005432817244	7936	31	16F
0005432817074	7936	32	17B
0005432817078	7936	33	17F
0005432817117	7936	34	18B
0005434513540	7936	35	20F
0005432002068	7936	36	21E
0005432901549	7936	37	22D
0005432901553	7936	38	22F
0005432901559	7936	39	23B
0005432002070	7936	40	23D
0005432901547	7936	41	24E
0005434513549	7936	42	26A
0005432901546	7936	43	26E
0005432901555	7936	44	26F
0005432817103	7936	45	27D
0005432901558	7936	46	28B
0005432817079	7936	47	28C
0005434513548	7936	48	28E
0005434513550	7936	49	28F
0005432817106	7936	50	29D
0005432901563	7936	51	29F
0005432817138	7936	52	30A
0005432817102	7936	53	30C
0005432901550	7936	54	31D
0005433870723	9679	1	2A
0005433870724	9679	2	4B
0005434175688	9679	3	5B
0005434175714	9679	4	6A
0005433870705	32359	1	1A
0005433870706	32359	2	2A
0005434175737	32359	3	3A
0005433870710	32359	4	3B
0005434175738	32359	5	5A
0005434175739	32359	6	4B
0005434175740	32359	7	5B
0005434175741	32359	8	6B
0005434877951	3496	1	1C
0005434938088	3496	2	1D
0005434877966	3496	3	2D
0005434877926	3496	4	2C
0005434877954	3496	5	2H
0005432611699	3496	6	2K
0005434426506	3496	7	3G
0005434426514	3496	8	3C
0005435626134	3496	9	4A
0005435626132	3496	10	4G
0005434877914	3496	11	4D
0005432183461	3496	12	5D
0005434877929	3496	13	5H
0005435126259	3496	14	5G
0005434938083	3496	15	11A
0005434878005	3496	16	11D
0005434877996	3496	17	11C
0005434877927	3496	18	11G
0005434877978	3496	19	11F
0005434877952	3496	20	11E
0005434877983	3496	21	11K
0005434938092	3496	22	11H
0005432799366	3496	23	12C
0005434877938	3496	24	12A
0005435126254	3496	25	12E
0005435913884	3496	26	12D
0005434426525	3496	27	12G
0005435126238	3496	28	12F
0005434877919	3496	29	12K
0005435626124	3496	30	12H
0005435126253	3496	31	13A
0005434877936	3496	32	13D
0005435902526	3496	33	13H
0005434426512	3496	34	14A
0005434877917	3496	35	13K
0005435126270	3496	36	14E
0005435626110	3496	37	14D
0005434426528	3496	38	14C
0005432799362	3496	39	14G
0005434426513	3496	40	14F
0005435902485	3496	41	15E
0005434938078	3496	42	15D
0005434877955	3496	43	15G
0005434426533	3496	44	15K
0005435126241	3496	45	16D
0005435902513	3496	46	16C
0005435913859	3496	47	16G
0005434877974	3496	48	16F
0005434877911	3496	49	16E
0005435126235	3496	50	16K
0005434938086	3496	51	16H
0005434938073	3496	52	17A
0005432799361	3496	53	17E
0005434877963	3496	54	17D
0005434877915	3496	55	17H
0005434877959	3496	56	17G
0005434426523	3496	57	17F
0005434877947	3496	58	18B
0005432799358	3496	59	18A
0005434877995	3496	60	18C
0005435126265	3496	61	18F
0005434877962	3496	62	18J
0005434877933	3496	63	19B
0005432799375	3496	64	19D
0005435902450	3496	65	19C
0005432799386	3496	66	19H
0005432799359	3496	67	19G
0005435626120	3496	68	20A
0005434877992	3496	69	19K
0005434938090	3496	70	19J
0005434877979	3496	71	20B
0005432799384	3496	72	20E
0005434878007	3496	73	20D
0005434426508	3496	74	20F
0005432613847	3496	75	20J
0005434426517	3496	76	20H
0005435126266	3496	77	21B
0005434877922	3496	78	20K
0005434426509	3496	79	21D
0005434877999	3496	80	21C
0005434938089	3496	81	21G
0005434878004	3496	82	21E
0005435913879	3496	83	21J
0005434877976	3496	84	21H
0005435126250	3496	85	21K
0005435626127	3496	86	22E
0005435626114	3496	87	22D
0005435126248	3496	88	22H
0005434938082	3496	89	22G
0005434877975	3496	90	22F
0005435902497	3496	91	22J
0005432799368	3496	92	23B
0005434877918	3496	93	23A
0005435626128	3496	94	23E
0005434877971	3496	95	23D
0005434877985	3496	96	23C
0005434877930	3496	97	23G
0005434426530	3496	98	23F
0005435126255	3496	99	23H
0005435902514	3496	100	24F
0005434877945	3496	101	24G
0005434426515	3496	102	25C
0005434426518	3496	103	25F
0005434938084	3496	104	25E
0005435126245	3496	105	25D
0005432799374	3496	106	25H
0005435126237	3496	107	25G
0005435126231	3496	108	26C
0005435902525	3496	109	26E
0005432799376	3496	110	26D
0005434877970	3496	111	26H
0005434877931	3496	112	26F
0005434426519	3496	113	26J
0005434877935	3496	114	27B
0005432799382	3496	115	27A
0005434877934	3496	116	26K
0005432188599	3496	117	27E
0005432799372	3496	118	27G
0005435126261	3496	119	27K
0005434938074	3496	120	27J
0005434426531	3496	121	28B
0005435126247	3496	122	28A
0005432799364	3496	123	28E
0005434877997	3496	124	28D
0005434878000	3496	125	28C
0005432188598	3496	126	28H
0005435902465	3496	127	28G
0005434877950	3496	128	28F
0005435126251	3496	129	28J
0005434877967	3496	130	29A
0005435626136	3496	131	29D
0005435626121	3496	132	29B
0005435126252	3496	133	29F
0005434877994	3496	134	29E
0005435126263	3496	135	29J
0005432799373	3496	136	29H
0005435626126	3496	137	29K
0005434877973	3496	138	30C
0005434877925	3496	139	30A
0005432799383	3496	140	30E
0005432799367	3496	141	30D
0005432611698	3496	142	30G
0005434877987	3496	143	30F
0005435626125	3496	144	30J
0005435626111	3496	145	31D
0005434877965	3496	146	31C
0005434426516	3496	147	31B
0005435902479	3496	148	31F
0005434877953	3496	149	31E
0005435126256	3496	150	31H
0005432799379	3496	151	32A
0005435626137	3496	152	31K
0005434426527	3496	153	31J
0005435626113	3496	154	32B
0005435126260	3496	155	32G
0005434426526	3496	156	32F
0005435626118	3496	157	32K
0005432799385	3496	158	32J
0005435126264	3496	159	32H
0005434877980	3496	160	33B
0005434877921	3496	161	33A
0005434877912	3496	162	33F
0005435126257	3496	163	33D
0005434877923	3496	164	33H
0005432613850	3496	165	33K
0005434877958	3496	166	33J
0005435913860	3496	167	34C
0005435626117	3496	168	34E
0005435913862	3496	169	34D
0005434877960	3496	170	34H
0005432799369	3496	171	34G
0005435626116	3496	172	34F
0005435126262	3496	173	34J
0005435126243	3496	174	35B
0005435126271	3496	175	35A
0005434426521	3496	176	34K
0005434938087	3496	177	35D
0005434877990	3496	178	35C
0005432799377	3496	179	35F
0005434877932	3496	180	35E
0005434877939	3496	181	35J
0005435626131	3496	182	35H
0005434877969	3496	183	35G
0005434878006	3496	184	36A
0005435126244	3496	185	35K
0005435913861	3496	186	36C
0005435902478	3496	187	36B
0005434877977	3496	188	36F
0005434426510	3496	189	36E
0005434426535	3496	190	36D
0005434877988	3496	191	36H
0005432613849	3496	192	36G
0005435626119	3496	193	37B
0005432799378	3496	194	37A
0005435126258	3496	195	37C
0005432799370	3496	196	37F
0005435126242	3496	197	37J
0005435902490	3496	198	37G
0005435626122	3496	199	37K
0005435126239	3496	200	38H
0005434877940	3496	201	38B
0005434426536	3496	202	38J
0005434877924	3496	203	39B
0005434426537	3496	204	39A
0005434938085	3496	205	38K
0005435626135	3496	206	39D
0005434877948	3496	207	39C
0005434877986	3496	208	39E
0005435126249	3496	209	39J
0005434877968	3496	210	39H
0005434877982	3496	211	39G
0005434877946	3496	212	40A
0005434877998	3496	213	39K
0005434877913	3496	214	40C
0005432799363	3496	215	40B
0005434426511	3496	216	40D
0005435913873	3496	217	40G
0005435626115	3496	218	40J
0005435902494	3496	219	40H
0005432183459	3496	220	41B
0005434877957	3496	221	40K
0005434877956	3496	222	41D
0005434426532	3496	223	41C
0005435126233	3496	224	41E
0005435126232	3496	225	41H
0005434938081	3496	226	41G
0005434426520	3496	227	42A
0005434877944	3496	228	41J
0005435902527	3496	229	42B
0005435913869	3496	230	42E
0005434877961	3496	231	42D
0005434877981	3496	232	42K
0005435626123	3496	233	42J
0005434877984	3496	234	42H
0005434877964	3496	235	43A
0005434426507	3496	236	43D
0005432799381	3496	237	43C
0005432183460	3496	238	43B
0005434877920	3496	239	43G
0005434877993	3496	240	43F
0005435902518	3496	241	43H
0005434877949	3496	242	44C
0005435902496	3496	243	44B
0005434878003	3496	244	44A
0005434938075	3496	245	44E
0005435913882	3496	246	44H
0005435626130	3496	247	44G
0005434877972	3496	248	44K
0005432611696	3496	249	44J
0005434877942	3496	250	45B
0005435126269	3496	251	45D
0005432799360	3496	252	45C
0005435626112	3496	253	45F
0005435126267	3496	254	45E
0005432799371	3496	255	45H
0005435626133	3496	256	45G
0005435126246	3496	257	46C
0005435902509	3496	258	46B
0005435126236	3496	259	46A
0005435126234	3496	260	46E
0005432799365	3496	261	46D
0005434426522	3496	262	46G
0005434877916	3496	263	46F
0005434426529	3496	264	46J
0005434938079	3496	265	47A
0005434877941	3496	266	46K
0005435126240	3496	267	47E
0005434426534	3496	268	47D
0005434938080	3496	269	47G
0005434877937	3496	270	47F
0005435913883	3496	271	48A
0005434878001	3496	272	47K
0005435902511	3496	273	47H
0005434938077	3496	274	48C
0005434877989	3496	275	48F
0005432613848	3496	276	48H
0005434877991	3496	277	49A
0005435902510	3496	278	49E
0005432611697	3496	279	49C
0005434426524	3496	280	49K
0005435913876	3496	281	49H
0005434938091	3496	282	49G
0005434938076	3496	283	50C
0005434877928	3496	284	50A
0005434877943	3496	285	50E
0005435626129	3496	286	50H
0005435126268	3496	287	51D
0005432799380	3496	288	51F
0005434878002	3496	289	51G
0005432799076	14581	1	1A
0005434877677	14581	2	1C
0005434937926	14581	3	1D
0005435902643	14581	4	2A
0005434426148	14581	5	1H
0005435125854	14581	6	2C
0005434426202	14581	7	2H
0005434877088	14581	8	2G
0005434426295	14581	9	3A
0005432607521	14581	10	3K
0005434937940	14581	11	3H
0005434426323	14581	12	3G
0005434937914	14581	13	4H
0005434877334	14581	14	4G
0005432799162	14581	15	4D
0005434877288	14581	16	5A
0005434937943	14581	17	5H
0005435902652	14581	18	5D
0005432799089	14581	19	11A
0005432607518	14581	20	11C
0005434426318	14581	21	11E
0005434937927	14581	22	11K
0005434877174	14581	23	11H
0005434877099	14581	24	11G
0005434877047	14581	25	12C
0005434426189	14581	26	12A
0005435902651	14581	27	12D
0005435625959	14581	28	12H
0005434877038	14581	29	12G
0005435625978	14581	30	13C
0005434877071	14581	31	13F
0005435125845	14581	32	13E
0005434876770	14581	33	13K
0005434877091	14581	34	13G
0005432799062	14581	35	14C
0005432799092	14581	36	14A
0005435902654	14581	37	14E
0005432799147	14581	38	14D
0005434877271	14581	39	14G
0005432799218	14581	40	14F
0005434877390	14581	41	14H
0005434426256	14581	42	15C
0005435125991	14581	43	15A
0005434426200	14581	44	15F
0005434426149	14581	45	15E
0005434877374	14581	46	15G
0005435625927	14581	47	16A
0005432799012	14581	48	15K
0005434877090	14581	49	16D
0005434877266	14581	50	16F
0005434877245	14581	51	16E
0005432059497	14581	52	16H
0005434876832	14581	53	17E
0005432611688	14581	54	17H
0005434426179	14581	55	18A
0005434877404	14581	56	17K
0005434877311	14581	57	18B
0005434876858	14581	58	18F
0005435902645	14581	59	18K
0005434426331	14581	60	19C
0005434877295	14581	61	19F
0005434877094	14581	62	19H
0005434877022	14581	63	19G
0005435125857	14581	64	19K
0005434877655	14581	65	20B
0005434877467	14581	66	20A
0005434877414	14581	67	20E
0005434877226	14581	68	20D
0005434876831	14581	69	20G
0005434877107	14581	70	20F
0005434877161	14581	71	20K
0005434426190	14581	72	20J
0005435125929	14581	73	20H
0005434876989	14581	74	21A
0005434877110	14581	75	21C
0005434426178	14581	76	21E
0005434877427	14581	77	21H
0005435125909	14581	78	22A
0005435902648	14581	79	22C
0005434877175	14581	80	22F
0005434876881	14581	81	22E
0005434877121	14581	82	22D
0005432799204	14581	83	22H
0005434877615	14581	84	22J
0005434937913	14581	85	23B
0005434937909	14581	86	23A
0005435914694	14581	87	23D
0005432799061	14581	88	23C
0005434877264	14581	89	23F
0005435625965	14581	90	23J
0005435625910	14581	91	23H
0005435625957	14581	92	23G
0005434426201	14581	93	24E
0005434877234	14581	94	25C
0005432799118	14581	95	25B
0005434937941	14581	96	25F
0005434426342	14581	97	25E
0005434877120	14581	98	25H
0005435625962	14581	99	25G
0005435125915	14581	100	26A
0005434426301	14581	101	25K
0005434876906	14581	102	25J
0005435125840	14581	103	26C
0005432799073	14581	104	26D
0005434877168	14581	105	26J
0005432799099	14581	106	26H
0005434877233	14581	107	27A
0005432607507	14581	108	26K
0005434876847	14581	109	27D
0005432799114	14581	110	27B
0005432611657	14581	111	27F
0005434876859	14581	112	27E
0005435625909	14581	113	27H
0005434877100	14581	114	27G
0005434877270	14581	115	27K
0005434876871	14581	116	27J
0005434937955	14581	117	28C
0005434876988	14581	118	28D
0005435902644	14581	119	28G
0005435125879	14581	120	28H
0005434877200	14581	121	29B
0005435625923	14581	122	29A
0005434877037	14581	123	29J
0005434426240	14581	124	29H
0005434876945	14581	125	30A
0005434877415	14581	126	29K
0005434877111	14581	127	30E
0005434877463	14581	128	30D
0005435125833	14581	129	30G
0005432611659	14581	130	30H
0005434876833	14581	131	31D
0005434877291	14581	132	31F
0005435125889	14581	133	31H
0005434426147	14581	134	31G
0005435625922	14581	135	32A
0005434937899	14581	136	31K
0005434877267	14581	137	32C
0005434877391	14581	138	32B
0005434876990	14581	139	32E
0005434877236	14581	140	32D
0005434937942	14581	141	32G
0005434426302	14581	142	32F
0005434426285	14581	143	32K
0005434426294	14581	144	32J
0005432799160	14581	145	33A
0005434426280	14581	146	33D
0005435125881	14581	147	33F
0005435902640	14581	148	33J
0005432799164	14581	149	33H
0005435902655	14581	150	33K
0005434877157	14581	151	34C
0005434426261	14581	152	34B
0005434876902	14581	153	34D
0005434877320	14581	154	34K
0005434876808	14581	155	34J
0005435625956	14581	156	34H
0005434426293	14581	157	35B
0005434877286	14581	158	35A
0005434876982	14581	159	35D
0005435902649	14581	160	35C
0005434877116	14581	161	35G
0005434937933	14581	162	35K
0005432799192	14581	163	35J
0005435125714	14581	164	36C
0005432611673	14581	165	36B
0005434877603	14581	166	36E
0005434426124	14581	167	36D
0005435902653	14581	168	36H
0005434877095	14581	169	36K
0005434937915	14581	170	36J
0005434876848	14581	171	37B
0005434876905	14581	172	37F
0005434877439	14581	173	37H
0005434876919	14581	174	37K
0005432799088	14581	175	38C
0005435125855	14581	176	38H
0005435125890	14581	177	39B
0005435625977	14581	178	38K
0005435125853	14581	179	39C
0005434877214	14581	180	39E
0005435902641	14581	181	39D
0005434876849	14581	182	39J
0005434876880	14581	183	39G
0005434877176	14581	184	40A
0005432059498	14581	185	40C
0005432611660	14581	186	40E
0005434877009	14581	187	40H
0005432607508	14581	188	40G
0005434426249	14581	189	40F
0005435902647	14581	190	40J
0005435913929	14581	191	41B
0005435125886	14581	192	41A
0005434876882	14581	193	41D
0005435125812	14581	194	41E
0005432799193	14581	195	41J
0005434877105	14581	196	42A
0005435125887	14581	197	41K
0005434877215	14581	198	42C
0005434426163	14581	199	42B
0005434877212	14581	200	42G
0005434877225	14581	201	42J
0005435125914	14581	202	42H
0005435126021	14581	203	43B
0005435902650	14581	204	43A
0005432799146	14581	205	42K
0005434877106	14581	206	43D
0005434426199	14581	207	43C
0005432611674	14581	208	43F
0005435125908	14581	209	43H
0005435902639	14581	210	43G
0005435902642	14581	211	43K
0005434877062	14581	212	44B
0005434426402	14581	213	44A
0005435125856	14581	214	44D
0005432611654	14581	215	44F
0005435125839	14581	216	44H
0005434426262	14581	217	45B
0005434877160	14581	218	45D
0005435913928	14581	219	45C
0005434426263	14581	220	45F
0005434876874	14581	221	45E
0005435902646	14581	222	45G
0005434877296	14581	223	45K
0005435125813	14581	224	45J
0005434426332	14581	225	46B
0005434426277	14581	226	46E
0005434877290	14581	227	46G
0005432607509	14581	228	47A
0005435625952	14581	229	46K
0005434877406	14581	230	47E
0005434426271	14581	231	47D
0005434876950	14581	232	47G
0005435625908	14581	233	47F
0005434877287	14581	234	47K
0005434877424	14581	235	48D
0005434877096	14581	236	48C
0005432799038	14581	237	48A
0005432799121	14581	238	48H
0005434426216	14581	239	48F
0005434877321	14581	240	49A
0005434877008	14581	241	48K
0005434876795	14581	242	49E
0005434876771	14581	243	49G
0005434426401	14581	244	49K
0005434937904	14581	245	49H
0005434877063	14581	246	50C
0005435125790	14581	247	50A
0005434426217	14581	248	50F
0005434877051	14581	249	50E
0005434426264	14581	250	50D
0005432799085	14581	251	50G
0005434877285	14581	252	51D
0005435902656	14581	253	51F
0005434937928	14581	254	51G
0005434325612	3613	1	2A
0005435889809	3613	2	2B
0005434325613	3613	3	2C
0005434325616	3613	4	2D
0005434325618	3613	5	3D
0005435889803	3613	6	4A
0005434312313	3613	7	4C
0005435889828	3613	8	5C
0005434312312	3613	9	5D
0005434325610	3613	10	6A
0005435889816	3613	11	6B
0005434325614	3613	12	6C
0005434325617	3613	13	7B
0005435889810	3613	14	18B
0005434325609	3613	15	18D
0005434325619	3613	16	19C
0005434325611	3613	17	20B
0005434325615	3613	18	22C
0005434325496	15632	1	1B
0005434325508	15632	2	2D
0005434325481	15632	3	3C
0005435889877	15632	4	3D
0005434325519	15632	5	5A
0005434325523	15632	6	5B
0005435889879	15632	7	5C
0005434325520	15632	8	6C
0005435889878	15632	9	7B
0005434325551	15632	10	18A
0005435889880	15632	11	18D
0005435889876	15632	12	19C
0005434325509	15632	13	20A
0005434325517	15632	14	20B
0005434325560	15632	15	20D
0005434325497	15632	16	21B
0005434325470	15632	17	22C
0005435957654	623	1	2A
0005435957664	623	2	2B
0005435957657	623	3	2D
0005435957662	623	4	3B
0005433420284	623	5	4A
0005435957651	623	6	4B
0005433420297	623	7	5A
0005435957652	623	8	5B
0005435957660	623	9	5C
0005435957650	623	10	5D
0005435957661	623	11	6A
0005435957663	623	12	7A
0005433420313	623	13	7B
0005435957658	623	14	7D
0005435957659	623	15	18A
0005433420302	623	16	18D
0005433420301	623	17	19A
0005435957656	623	18	19D
0005433420317	623	19	20B
0005433420283	623	20	20C
0005433420298	623	21	20D
0005435957653	623	22	21A
0005435957655	623	23	22A
0005435957549	15195	1	1A
0005433420376	15195	2	1B
0005435957554	15195	3	2A
0005433420374	15195	4	2D
0005435957536	15195	5	3C
0005433420378	15195	6	3D
0005433420372	15195	7	4B
0005433420377	15195	8	4C
0005433420373	15195	9	5A
0005435957577	15195	10	5D
0005435957584	15195	11	6C
0005435957525	15195	12	7A
0005433420379	15195	13	7C
0005435957531	15195	14	18A
0005435957476	15195	15	18B
0005435957474	15195	16	18D
0005433420375	15195	17	19C
0005435957532	15195	18	20D
0005435957551	15195	19	21A
0005435957583	15195	20	21C
0005435957475	15195	21	22B
0005435957473	15195	22	22D
0005435219174	27262	1	2A
0005435216566	27262	2	3B
0005435216553	27262	3	4A
0005435216564	27262	4	6D
0005435219180	27262	5	7B
0005435216558	27262	6	18B
0005435216555	27262	7	18D
0005435219169	27262	8	19A
0005435216554	27262	9	19D
0005435219167	27262	10	21A
0005435216559	27262	11	22D
0005435216565	27262	12	23A
0005435216578	31778	1	2A
0005435217706	31778	2	2C
0005435217705	31778	3	2D
0005435217701	31778	4	3A
0005435216576	31778	5	3B
0005435217703	31778	6	3D
0005435216580	31778	7	4B
0005435218111	31778	8	4C
0005435217708	31778	9	5B
0005435217704	31778	10	5C
0005435216581	31778	11	6B
0005435218110	31778	12	6C
0005435217702	31778	13	7A
0005435217707	31778	14	7C
0005435217700	31778	15	18A
0005435216584	31778	16	20B
0005435218112	31778	17	20D
0005435216583	31778	18	21A
0005435216577	31778	19	21C
0005435216579	31778	20	22A
0005435216582	31778	21	23B
0005435629401	8881	1	3A
0005435629400	8881	2	3B
0005434247140	16029	1	3B
0005434247139	16029	2	6B
0005434467753	4019	1	1A
0005434467751	4019	2	6B
0005434467757	4019	3	7D
0005434467752	4019	4	18B
0005434467749	4019	5	18C
0005434467755	4019	6	19A
0005434467750	4019	7	19B
0005434467756	4019	8	19D
0005434467754	4019	9	20D
0005434467728	23206	1	4A
0005434467725	23206	2	5D
0005434467731	23206	3	6C
0005434467726	23206	4	19C
0005434467727	23206	5	20A
0005434467736	23206	6	22B
0005434467730	23206	7	22D
0005434467729	23206	8	23A
0005435933404	4439	1	1A
0005435163207	4439	2	1B
0005435933407	4439	3	2A
0005435163219	4439	4	2B
0005435933427	4439	5	2D
0005435163209	4439	6	3B
0005435933418	4439	7	3C
0005435163208	4439	8	4B
0005435933409	4439	9	5B
0005435933416	4439	10	5C
0005435933417	4439	11	5D
0005435933414	4439	12	6B
0005435933415	4439	13	6D
0005435163212	4439	14	7A
0005435933405	4439	15	7C
0005435163210	4439	16	18A
0005435163217	4439	17	18B
0005435933408	4439	18	18D
0005435163218	4439	19	19A
0005435163205	4439	20	19B
0005435163216	4439	21	19C
0005435163206	4439	22	19D
0005435933406	4439	23	20B
0005435163213	4439	24	21A
0005435163211	4439	25	21D
0005435163215	4439	26	22B
0005435163214	4439	27	22C
0005435163157	29516	1	3C
0005435163177	29516	2	3D
0005435163190	29516	3	4A
0005435163152	29516	4	4D
0005435933439	29516	5	5A
0005435163191	29516	6	5C
0005435933441	29516	7	5D
0005435163167	29516	8	6B
0005435933445	29516	9	7B
0005435163176	29516	10	7D
0005435933442	29516	11	19A
0005435933444	29516	12	20D
0005435163154	29516	13	21B
0005435933443	29516	14	22A
0005435933440	29516	15	22C
0005435163158	29516	16	22D
0005432645943	6830	1	1C
0005432645955	6830	2	1D
0005432645949	6830	3	1F
0005432645946	6830	4	2A
0005432645948	6830	5	2C
0005432645914	6830	6	2D
0005435229316	6830	7	3A
0005435229315	6830	8	3C
0005435229306	6830	9	3D
0005432645906	6830	10	4A
0005432645907	6830	11	3F
0005432645957	6830	12	4C
0005435229328	6830	13	4D
0005432645930	6830	14	4E
0005432645934	6830	15	4F
0005432645919	6830	16	5A
0005435229337	6830	17	5C
0005435229327	6830	18	5E
0005432645922	6830	19	5F
0005432645952	6830	20	6C
0005435229338	6830	21	6D
0005432645910	6830	22	6E
0005432645921	6830	23	6F
0005432645945	6830	24	7A
0005435229320	6830	25	7D
0005432645939	6830	26	7F
0005432645956	6830	27	8A
0005432645932	6830	28	8C
0005432645928	6830	29	8E
0005432645916	6830	30	9A
0005432645933	6830	31	9C
0005432645911	6830	32	9D
0005432645947	6830	33	9E
0005432645929	6830	34	10A
0005432645936	6830	35	10D
0005435229304	6830	36	10E
0005432645912	6830	37	10F
0005432645926	6830	38	11A
0005435229333	6830	39	11C
0005432645944	6830	40	11D
0005432645920	6830	41	11E
0005432645935	6830	42	12A
0005432645950	6830	43	12C
0005432645927	6830	44	12D
0005432645937	6830	45	12E
0005432645931	6830	46	12F
0005432645951	6830	47	13A
0005432645908	6830	48	13C
0005435229302	6830	49	13D
0005435229317	6830	50	13E
0005432645925	6830	51	14A
0005435229334	6830	52	14C
0005432645924	6830	53	14E
0005435229335	6830	54	14F
0005432645958	6830	55	15A
0005435229329	6830	56	15C
0005432645941	6830	57	15F
0005432645938	6830	58	16A
0005432645923	6830	59	16C
0005435229347	6830	60	16E
0005432645953	6830	61	16F
0005435229313	6830	62	17A
0005432645917	6830	63	17C
0005432645913	6830	64	17D
0005435229312	6830	65	17E
0005435229311	6830	66	18A
0005435229351	6830	67	18C
0005435229301	6830	68	18D
0005432645915	6830	69	18E
0005432645940	6830	70	18F
0005432645909	6830	71	19C
0005435229314	6830	72	19E
0005432645954	6830	73	19F
0005435229340	6830	74	20A
0005435229336	6830	75	20C
0005432645918	6830	76	20E
0005432645942	6830	77	20F
0005433404710	2876	1	1C
0005435797432	2876	2	2C
0005435797427	2876	3	3C
0005433404696	2876	4	3F
0005433404717	2876	5	4D
0005435797439	2876	6	4E
0005435797437	2876	7	4F
0005435797425	2876	8	6E
0005433404711	2876	9	9C
0005435797435	2876	10	9D
0005435797426	2876	11	10F
0005435797428	2876	12	12E
0005433404728	2876	13	14A
0005435797433	2876	14	15D
0005433404695	2876	15	15F
0005435797429	2876	16	16A
0005433404718	2876	17	17C
0005435797431	2876	18	18D
0005435797438	2876	19	18E
0005435797436	2876	20	19A
0005435797430	2876	21	19C
0005433404705	2876	22	19E
0005435797434	2876	23	19F
0005435797311	29331	1	1C
0005435797299	29331	2	1F
0005433404790	29331	3	2C
0005435797318	29331	4	2D
0005435797319	29331	5	3A
0005435797360	29331	6	3F
0005435797317	29331	7	5D
0005435797361	29331	8	5F
0005433404791	29331	9	6C
0005435797345	29331	10	6D
0005435797374	29331	11	6F
0005433404786	29331	12	7A
0005435797373	29331	13	8A
0005433404788	29331	14	8D
0005433404787	29331	15	8E
0005435797312	29331	16	9A
0005435797327	29331	17	9C
0005435797307	29331	18	9D
0005435797270	29331	19	10A
0005435797349	29331	20	11E
0005435797269	29331	21	12D
0005435797310	29331	22	13C
0005435797316	29331	23	13E
0005433404785	29331	24	14F
0005435797326	29331	25	15F
0005435797387	29331	26	16A
0005435797344	29331	27	16C
0005435797255	29331	28	16D
0005433404784	29331	29	16E
0005435797388	29331	30	17F
0005435797309	29331	31	18D
0005433404789	29331	32	19D
0005435797306	29331	33	20C
0005435797254	29331	34	20F
0005435376328	5761	1	2B
0005434947992	5767	1	1B
0005434947994	5767	2	2B
0005434947996	5767	3	3A
0005434947993	5767	4	4A
0005434947997	5767	5	4B
0005434947999	5767	6	5B
0005434947995	5767	7	6A
0005434947998	5767	8	6B
0005434947934	16371	1	1A
0005434947928	16371	2	1B
0005434947907	16371	3	2A
0005434947930	16371	4	3A
0005434947936	16371	5	2B
0005434947926	16371	6	3B
0005434947869	16371	7	4A
0005434947940	16371	8	4B
0005434947913	16371	9	5B
0005434947908	16371	10	5A
0005434947935	16371	11	6A
0005434947929	16371	12	6B
0005433960733	6883	1	1A
0005433960705	6883	2	1C
0005433960677	6883	3	1D
0005433960732	6883	4	1F
0005433960723	6883	5	2A
0005433960704	6883	6	2C
0005433960690	6883	7	3A
0005433960692	6883	8	3C
0005433960722	6883	9	4C
0005433960711	6883	10	4E
0005433960709	6883	11	4F
0005433960721	6883	12	5A
0005433960680	6883	13	5C
0005433960702	6883	14	5F
0005433960736	6883	15	6A
0005433960694	6883	16	6D
0005433960738	6883	17	6E
0005433960712	6883	18	6F
0005433960725	6883	19	7A
0005433960707	6883	20	7D
0005433960700	6883	21	7F
0005433960718	6883	22	8A
0005433960730	6883	23	8C
0005433960731	6883	24	8D
0005433960695	6883	25	8E
0005433960717	6883	26	8F
0005433960683	6883	27	9A
0005433960701	6883	28	9C
0005433960685	6883	29	9F
0005433960713	6883	30	10A
0005433960678	6883	31	10C
0005433960698	6883	32	10D
0005433960708	6883	33	10E
0005433960724	6883	34	11E
0005433960726	6883	35	12C
0005433960729	6883	36	12E
0005433960684	6883	37	12F
0005433960716	6883	38	13A
0005433960679	6883	39	13C
0005433960735	6883	40	13D
0005433960737	6883	41	13E
0005433960714	6883	42	13F
0005433960715	6883	43	14A
0005433960706	6883	44	14C
0005433960689	6883	45	14D
0005433960681	6883	46	14E
0005433960688	6883	47	15A
0005433960734	6883	48	15C
0005433960719	6883	49	15D
0005433960728	6883	50	15F
0005433960687	6883	51	16A
0005433960693	6883	52	16D
0005433960675	6883	53	16F
0005433960676	6883	54	17C
0005433960699	6883	55	17D
0005433960710	6883	56	17E
0005433960682	6883	57	17F
0005433960691	6883	58	18C
0005433960720	6883	59	18D
0005433960696	6883	60	18E
0005433960703	6883	61	18F
0005433960727	6883	62	19F
0005433960697	6883	63	20D
0005433960686	6883	64	20F
0005433960106	25753	1	1A
0005433960007	25753	2	2C
0005433960056	25753	3	2D
0005433959980	25753	4	2F
0005433960018	25753	5	3A
0005433959984	25753	6	3D
0005433959928	25753	7	3F
0005433960077	25753	8	4A
0005433960044	25753	9	4C
0005433960112	25753	10	4D
0005433959896	25753	11	5D
0005433959936	25753	12	6A
0005433960137	25753	13	6C
0005433960083	25753	14	6F
0005433960035	25753	15	7A
0005433959985	25753	16	7C
0005433959902	25753	17	7D
0005433960087	25753	18	8A
0005433960050	25753	19	8C
0005433959860	25753	20	8D
0005433959968	25753	21	8F
0005433960135	25753	22	9D
0005433959903	25753	23	9E
0005433959958	25753	24	9F
0005433960059	25753	25	10D
0005433959990	25753	26	10E
0005433960136	25753	27	10F
0005433960060	25753	28	11C
0005433960025	25753	29	11D
0005433960023	25753	30	12A
0005433959992	25753	31	12C
0005433960026	25753	32	12E
0005433959884	25753	33	12F
0005433959911	25753	34	13C
0005433960131	25753	35	13D
0005433960107	25753	36	13F
0005433960010	25753	37	14A
0005433960016	25753	38	14C
0005433960113	25753	39	14D
0005433960105	25753	40	14F
0005433959935	25753	41	15A
0005433959859	25753	42	15C
0005433960119	25753	43	16C
0005433959888	25753	44	16D
0005433960057	25753	45	16E
0005433959885	25753	46	17A
0005433959937	25753	47	17C
0005433960005	25753	48	17E
0005433959901	25753	49	17F
0005433959941	25753	50	18C
0005433959882	25753	51	18E
0005433959883	25753	52	19D
0005433959929	25753	53	19E
0005433960027	25753	54	20A
0005433960124	25753	55	20C
0005433960108	25753	56	20D
0005433960017	25753	57	20E
0005433960024	25753	58	20F
0005435082691	24560	1	1A
0005435082703	24560	2	1B
0005435082693	24560	3	2A
0005435082702	24560	4	2B
0005435082692	24560	5	3A
0005435082690	24560	6	4A
0005435082701	24560	7	3B
0005435082678	24560	8	5A
0005435082679	24560	9	6B
0005435082755	26049	1	1A
0005435082761	26049	2	1B
0005435082757	26049	3	2A
0005435082752	26049	4	2B
0005435082759	26049	5	3A
0005435082762	26049	6	4A
0005435082758	26049	7	3B
0005435082753	26049	8	4B
0005435082760	26049	9	5A
0005435082754	26049	10	5B
0005435082763	26049	11	6A
0005435082756	26049	12	6B
0005434244901	4961	1	3D
0005434244884	4961	2	8A
0005432166892	4961	3	7F
0005434244880	4961	4	8C
0005435286565	4961	5	8D
0005435286564	4961	6	9A
0005434244893	4961	7	9E
0005434244891	4961	8	9D
0005434244881	4961	9	10A
0005434244897	4961	10	10B
0005434244882	4961	11	12D
0005434244905	4961	12	14D
0005434244875	4961	13	15A
0005434244886	4961	14	15C
0005434244887	4961	15	15F
0005434244883	4961	16	16E
0005434244903	4961	17	17B
0005434244904	4961	18	17A
0005434244890	4961	19	18A
0005434244885	4961	20	18B
0005432166890	4961	21	19C
0005434244894	4961	22	19E
0005433534473	4961	23	20C
0005434244900	4961	24	21D
0005434244878	4961	25	21E
0005434244898	4961	26	21F
0005434244879	4961	27	22C
0005434244895	4961	28	22E
0005434244902	4961	29	23A
0005434244892	4961	30	23D
0005432166891	4961	31	23F
0005434244889	4961	32	24C
0005434244899	4961	33	25E
0005433534471	4961	34	26D
0005434244877	4961	35	30D
0005433534477	4961	36	30C
0005433534470	4961	37	30F
0005434244896	4961	38	31D
0005434244876	4961	39	31F
0005434244888	4961	40	31E
0005433784849	4962	1	1D
0005433614475	4962	2	1C
0005433614454	4962	3	1A
0005433614462	4962	4	1F
0005433784822	4962	5	2A
0005432105443	4962	6	2C
0005432105413	4962	7	2F
0005433614447	4962	8	2D
0005432105434	4962	9	3A
0005433614466	4962	10	3C
0005432667447	4962	11	3F
0005433614495	4962	12	3D
0005433614501	4962	13	4A
0005433614445	4962	14	4D
0005433784840	4962	15	4C
0005433784821	4962	16	4F
0005432105404	4962	17	5A
0005432105444	4962	18	5D
0005433784843	4962	19	5C
0005432105425	4962	20	5F
0005433614504	4962	21	6A
0005433784830	4962	22	6C
0005433614458	4962	23	6D
0005433614485	4962	24	7A
0005433784831	4962	25	6F
0005432145105	4962	26	7C
0005432105418	4962	27	7F
0005433784826	4962	28	7D
0005433614491	4962	29	8A
0005432105405	4962	30	8B
0005433614455	4962	31	8D
0005432105431	4962	32	8C
0005433614500	4962	33	8E
0005433614483	4962	34	9A
0005433614481	4962	35	8F
0005433784825	4962	36	9B
0005433784817	4962	37	9C
0005433784835	4962	38	9E
0005433614497	4962	39	9D
0005433614438	4962	40	10A
0005432145104	4962	41	9F
0005433614459	4962	42	10C
0005433784827	4962	43	10B
0005433614465	4962	44	10E
0005433784823	4962	45	10D
0005432105446	4962	46	11A
0005433614496	4962	47	10F
0005433784820	4962	48	11C
0005433614437	4962	49	11B
0005433784841	4962	50	11D
0005433614469	4962	51	11E
0005432105410	4962	52	12A
0005432105398	4962	53	11F
0005433614479	4962	54	12B
0005432105438	4962	55	12D
0005433614443	4962	56	12C
0005433784828	4962	57	12F
0005432105409	4962	58	12E
0005432665268	4962	59	13B
0005432105436	4962	60	13A
0005433614471	4962	61	13C
0005433614449	4962	62	13D
0005432105406	4962	63	13E
0005433784845	4962	64	14A
0005433614482	4962	65	13F
0005433614441	4962	66	14B
0005433784838	4962	67	14C
0005432105435	4962	68	14E
0005432105430	4962	69	14D
0005433784836	4962	70	14F
0005432105415	4962	71	15B
0005432105401	4962	72	15A
0005433784818	4962	73	15C
0005433614507	4962	74	15D
0005433614440	4962	75	15F
0005432105403	4962	76	15E
0005433784816	4962	77	16A
0005433784837	4962	78	16B
0005432105437	4962	79	16D
0005432105407	4962	80	16C
0005433614480	4962	81	16E
0005432105412	4962	82	17A
0005433784814	4962	83	16F
0005433614463	4962	84	17C
0005433614486	4962	85	17B
0005433614457	4962	86	17E
0005433614499	4962	87	17D
0005433614448	4962	88	18A
0005433614435	4962	89	17F
0005432105411	4962	90	18B
0005432105422	4962	91	18D
0005433784819	4962	92	18C
0005433614464	4962	93	18E
0005433784832	4962	94	18F
0005432105423	4962	95	19C
0005433614450	4962	96	19B
0005433614442	4962	97	19D
0005432105428	4962	98	19E
0005433614488	4962	99	20B
0005433614444	4962	100	20A
0005433614493	4962	101	20C
0005432105419	4962	102	20D
0005432105439	4962	103	20E
0005433614492	4962	104	21A
0005433614468	4962	105	20F
0005433614506	4962	106	21B
0005433614461	4962	107	21D
0005433614505	4962	108	21C
0005433614439	4962	109	21E
0005432105433	4962	110	21F
0005433614456	4962	111	22B
0005432105420	4962	112	22A
0005432105429	4962	113	22C
0005432105424	4962	114	22E
0005433614478	4962	115	22D
0005432105421	4962	116	22F
0005432105408	4962	117	23A
0005432105397	4962	118	23C
0005432105427	4962	119	23B
0005432105441	4962	120	23D
0005433614446	4962	121	23E
0005433784833	4962	122	24A
0005432665267	4962	123	23F
0005432105400	4962	124	24B
0005433614476	4962	125	24D
0005432105442	4962	126	24C
0005433784850	4962	127	24E
0005433784848	4962	128	24F
0005432105440	4962	129	25B
0005432105402	4962	130	25A
0005433614452	4962	131	25C
0005433784829	4962	132	25D
0005433614508	4962	133	25F
0005433614474	4962	134	25E
0005433614489	4962	135	26B
0005433614490	4962	136	26A
0005433784842	4962	137	26D
0005432105426	4962	138	26C
0005433614467	4962	139	26F
0005433614453	4962	140	26E
0005432105414	4962	141	27B
0005432105416	4962	142	27A
0005433784846	4962	143	27C
0005432105399	4962	144	27E
0005432145106	4962	145	27D
0005433784815	4962	146	27F
0005433614451	4962	147	28A
0005433784834	4962	148	28B
0005432105417	4962	149	28C
0005433614460	4962	150	28E
0005432105432	4962	151	28D
0005433784847	4962	152	28F
0005433614470	4962	153	29B
0005433614472	4962	154	29A
0005433614436	4962	155	29C
0005433614487	4962	156	29E
0005433614503	4962	157	29D
0005433614498	4962	158	30A
0005433784824	4962	159	29F
0005432105445	4962	160	30B
0005433614434	4962	161	30D
0005433614477	4962	162	30C
0005433614473	4962	163	30E
0005433614494	4962	164	30F
0005433784844	4962	165	31B
0005433784839	4962	166	31A
0005433614484	4962	167	31C
0005432666381	4962	168	31D
0005433614502	4962	169	31F
0005432666382	4962	170	31E
0005434265049	4964	1	1A
0005434149700	4964	2	1D
0005435006731	4964	3	1F
0005434229295	4964	4	2A
0005435006770	4964	5	2C
0005434265072	4964	6	2D
0005434149695	4964	7	3A
0005435006687	4964	8	2F
0005434229297	4964	9	3C
0005432335921	4964	10	3F
0005435269656	4964	11	4D
0005435269652	4964	12	5A
0005434265053	4964	13	5C
0005434265047	4964	14	6A
0005435006846	4964	15	5F
0005434265061	4964	16	6D
0005434149693	4964	17	7A
0005435006790	4964	18	7C
0005435006786	4964	19	7D
0005434265064	4964	20	8A
0005435269670	4964	21	7F
0005434265062	4964	22	8D
0005434265046	4964	23	8C
0005432335922	4964	24	8E
0005432335932	4964	25	8F
0005434229309	4964	26	9B
0005433688782	4964	27	9C
0005434229296	4964	28	9E
0005435006707	4964	29	10A
0005434149689	4964	30	10B
0005434265068	4964	31	10C
0005434229307	4964	32	10E
0005434265059	4964	33	11B
0005434265055	4964	34	11A
0005434265057	4964	35	11D
0005435006715	4964	36	11C
0005432335904	4964	37	11F
0005435006791	4964	38	12B
0005434265054	4964	39	12C
0005434149697	4964	40	12E
0005434149694	4964	41	12F
0005434229293	4964	42	13A
0005434229292	4964	43	13C
0005434173508	4964	44	13D
0005434229310	4964	45	13F
0005434265048	4964	46	13E
0005434229290	4964	47	14A
0005434265045	4964	48	14C
0005434149699	4964	49	14B
0005434265070	4964	50	14F
0005435269669	4964	51	15B
0005434173509	4964	52	15A
0005432335934	4964	53	15C
0005434265065	4964	54	15F
0005434149690	4964	55	16B
0005434265056	4964	56	16D
0005434265071	4964	57	16E
0005435006673	4964	58	16F
0005434311202	4964	59	17A
0005435006735	4964	60	17C
0005433685498	4964	61	17B
0005435269657	4964	62	17D
0005432335902	4964	63	17F
0005435006733	4964	64	18A
0005434229301	4964	65	18B
0005435006763	4964	66	18D
0005434149698	4964	67	18C
0005434229305	4964	68	18E
0005434265069	4964	69	18F
0005433685493	4964	70	19C
0005433688783	4964	71	19B
0005434265050	4964	72	19D
0005432335862	4964	73	19E
0005434265058	4964	74	20A
0005435006783	4964	75	20D
0005434229300	4964	76	20C
0005434312292	4964	77	20F
0005434229289	4964	78	20E
0005434229311	4964	79	21A
0005432335903	4964	80	21B
0005435006771	4964	81	21D
0005435006751	4964	82	22C
0005434229302	4964	83	22D
0005434149691	4964	84	22F
0005434229291	4964	85	23A
0005434173506	4964	86	23C
0005435006617	4964	87	23D
0005434149692	4964	88	23F
0005435006785	4964	89	24C
0005434173507	4964	90	24E
0005433815346	4964	91	24F
0005434149696	4964	92	25A
0005434229308	4964	93	25C
0005435006736	4964	94	25B
0005434229312	4964	95	25D
0005433815345	4964	96	25E
0005435006732	4964	97	26A
0005434229306	4964	98	26B
0005435006616	4964	99	26D
0005434265060	4964	100	26E
0005435006716	4964	101	26F
0005432335933	4964	102	27D
0005435006841	4964	103	27C
0005434229303	4964	104	28A
0005434265051	4964	105	27F
0005434265052	4964	106	28B
0005434229299	4964	107	28E
0005432335884	4964	108	28D
0005434265063	4964	109	29E
0005433685499	4964	110	30A
0005434229298	4964	111	29F
0005434229294	4964	112	30B
0005435006840	4964	113	30E
0005434229304	4964	114	30D
0005434265066	4964	115	30F
0005435006711	4964	116	31B
0005435006734	4964	117	31C
0005434265067	4964	118	31E
0005435006889	4964	119	31F
0005434244617	8415	1	2A
0005434244582	8415	2	2C
0005435269740	8415	3	2F
0005434244680	8415	4	2D
0005433784573	8415	5	3A
0005433784340	8415	6	3C
0005432659673	8415	7	3F
0005433784556	8415	8	3D
0005434244782	8415	9	4F
0005433784529	8415	10	5F
0005433784621	8415	11	5D
0005433784528	8415	12	6A
0005433784622	8415	13	6C
0005434244632	8415	14	7A
0005433784567	8415	15	7D
0005434244722	8415	16	7F
0005433784571	8415	17	8B
0005433784542	8415	18	8D
0005433784639	8415	19	8F
0005433784451	8415	20	9C
0005434244530	8415	21	9B
0005435269742	8415	22	9E
0005434244651	8415	23	10A
0005434244700	8415	24	10B
0005433784467	8415	25	10D
0005433784568	8415	26	10C
0005432659681	8415	27	11D
0005434244590	8415	28	11E
0005433784638	8415	29	12B
0005434244503	8415	30	12C
0005434244677	8415	31	12E
0005434244813	8415	32	13A
0005434244781	8415	33	13C
0005433784399	8415	34	13E
0005433784551	8415	35	13D
0005433784499	8415	36	13F
0005435269736	8415	37	14A
0005433784566	8415	38	14C
0005433784662	8415	39	14F
0005433784697	8415	40	15A
0005433784468	8415	41	15C
0005433784518	8415	42	15F
0005435269744	8415	43	16E
0005434244570	8415	44	17A
0005434244656	8415	45	17C
0005433784630	8415	46	17B
0005433784460	8415	47	18A
0005432659680	8415	48	18B
0005433784661	8415	49	18D
0005433784461	8415	50	18E
0005433784503	8415	51	19B
0005433784520	8415	52	19C
0005435269741	8415	53	20A
0005434244616	8415	54	19E
0005433784519	8415	55	20B
0005434244559	8415	56	20D
0005435269743	8415	57	20F
0005434244787	8415	58	21B
0005433784477	8415	59	21D
0005432659676	8415	60	21C
0005434244774	8415	61	22A
0005433784406	8415	62	22B
0005434244665	8415	63	22D
0005434244611	8415	64	23A
0005433784484	8415	65	23D
0005435269739	8415	66	23E
0005434244618	8415	67	23F
0005434244610	8415	68	24B
0005433784466	8415	69	24A
0005434244646	8415	70	24E
0005433784620	8415	71	25A
0005435269738	8415	72	25C
0005433784576	8415	73	25D
0005434244712	8415	74	25F
0005433784533	8415	75	25E
0005433784631	8415	76	26B
0005433784572	8415	77	26F
0005434244721	8415	78	27B
0005435269745	8415	79	27D
0005433784428	8415	80	28C
0005433784581	8415	81	29B
0005434244786	8415	82	29E
0005434244627	8415	83	30C
0005434244699	8415	84	30D
0005433784605	8415	85	30F
0005433784554	8415	86	31B
0005435269737	8415	87	31C
0005433784469	8415	88	31D
0005433784471	8415	89	31F
0005432659675	8415	90	31E
0005433613600	8416	1	1A
0005433614020	8416	2	2C
0005433613870	8416	3	2A
0005433613879	8416	4	3A
0005433613526	8416	5	2F
0005433613738	8416	6	3C
0005433613889	8416	7	3F
0005433614098	8416	8	3D
0005433613963	8416	9	4A
0005433613810	8416	10	4D
0005433613743	8416	11	5C
0005433613962	8416	12	5F
0005433613544	8416	13	6D
0005433613934	8416	14	7A
0005433613729	8416	15	7C
0005433613927	8416	16	7F
0005433613675	8416	17	7D
0005433613831	8416	18	8A
0005433613878	8416	19	8B
0005433614133	8416	20	8C
0005433613668	8416	21	8D
0005433613764	8416	22	8F
0005433613758	8416	23	9E
0005433613599	8416	24	10C
0005433613812	8416	25	10B
0005433613944	8416	26	10E
0005433613745	8416	27	11F
0005433613936	8416	28	12C
0005433613837	8416	29	12B
0005433613867	8416	30	12D
0005433613838	8416	31	12F
0005433613839	8416	32	13C
0005433613805	8416	33	13E
0005433613811	8416	34	13D
0005433613467	8416	35	14A
0005433613818	8416	36	14E
0005433613820	8416	37	15A
0005433613661	8416	38	14F
0005433614024	8416	39	15C
0005433613978	8416	40	15D
0005433613977	8416	41	16A
0005433613583	8416	42	16B
0005433613886	8416	43	16D
0005433613631	8416	44	16C
0005433613570	8416	45	17B
0005433614134	8416	46	17C
0005433613969	8416	47	17D
0005433613589	8416	48	17E
0005433613868	8416	49	18A
0005433614026	8416	50	18E
0005433613478	8416	51	18F
0005433613436	8416	52	19B
0005433614025	8416	53	19C
0005433613554	8416	54	20B
0005433613616	8416	55	20A
0005433613828	8416	56	20F
0005433613617	8416	57	21A
0005433613802	8416	58	21D
0005433613590	8416	59	21C
0005433613739	8416	60	21E
0005433613813	8416	61	22B
0005433613612	8416	62	22A
0005433613761	8416	63	22D
0005433613674	8416	64	22F
0005433614033	8416	65	22E
0005433613671	8416	66	23C
0005433614032	8416	67	23E
0005433613785	8416	68	25A
0005433613410	8416	69	25C
0005433613801	8416	70	26C
0005433613842	8416	71	26D
0005433613844	8416	72	26F
0005433613571	8416	73	27F
0005433613728	8416	74	27E
0005433613611	8416	75	28B
0005433613911	8416	76	28E
0005433613935	8416	77	28D
0005433613632	8416	78	29A
0005433613926	8416	79	29D
0005433613928	8416	80	29F
0005433613845	8416	81	30D
0005433613740	8416	82	31A
0005433614097	8416	83	30F
0005433613691	8416	84	31B
0005434264868	8417	1	1C
0005434149546	8417	2	1F
0005432034872	8417	3	1D
0005434229017	8417	4	2A
0005434173465	8417	5	2C
0005435006955	8417	6	2D
0005432047538	8417	7	2F
0005434264886	8417	8	3C
0005434264854	8417	9	3F
0005432034870	8417	10	3D
0005432034861	8417	11	4A
0005432047542	8417	12	4F
0005434229116	8417	13	4D
0005435006967	8417	14	5A
0005434264763	8417	15	5C
0005432047539	8417	16	5F
0005434229099	8417	17	5D
0005434149601	8417	18	6A
0005435006962	8417	19	6C
0005435006957	8417	20	6D
0005434229059	8417	21	7A
0005432034853	8417	22	6F
0005432034859	8417	23	7C
0005435006953	8417	24	7F
0005434149647	8417	25	7D
0005433688802	8417	26	8A
0005435286609	8417	27	8D
0005434229084	8417	28	8C
0005435006952	8417	29	8E
0005434229086	8417	30	8F
0005432034855	8417	31	9B
0005434229018	8417	32	9A
0005433689905	8417	33	9C
0005432034854	8417	34	9E
0005435006960	8417	35	10A
0005434264790	8417	36	10B
0005435006945	8417	37	10C
0005434264747	8417	38	10E
0005434229117	8417	39	10F
0005432034871	8417	40	11B
0005435006961	8417	41	11A
0005434264824	8417	42	11C
0005434264899	8417	43	11D
0005432034868	8417	44	11E
0005434149604	8417	45	12A
0005434229112	8417	46	11F
0005435006964	8417	47	12B
0005432336004	8417	48	12D
0005432034873	8417	49	12C
0005434229132	8417	50	12E
0005433815370	8417	51	13A
0005435006965	8417	52	12F
0005434264883	8417	53	13B
0005434229068	8417	54	13C
0005435006947	8417	55	13D
0005432034850	8417	56	13F
0005434264855	8417	57	13E
0005434229111	8417	58	14A
0005434173461	8417	59	14B
0005432047540	8417	60	14D
0005434264874	8417	61	14E
0005435006950	8417	62	15A
0005434229085	8417	63	15B
0005434264820	8417	64	15C
0005432335996	8417	65	15D
0005432034862	8417	66	15E
0005434149592	8417	67	16A
0005432047537	8417	68	16C
0005432034857	8417	69	16B
0005435006951	8417	70	16E
0005433815372	8417	71	16D
0005434264832	8417	72	16F
0005434173474	8417	73	17B
0005432336001	8417	74	17A
0005434264799	8417	75	17E
0005432034852	8417	76	17D
0005434264844	8417	77	17F
0005433688803	8417	78	18B
0005434264800	8417	79	18C
0005434149554	8417	80	18E
0005435006946	8417	81	18D
0005434264885	8417	82	18F
0005434149591	8417	83	19D
0005435286608	8417	84	20A
0005434149570	8417	85	19E
0005434149602	8417	86	20D
0005433815371	8417	87	20C
0005432034851	8417	88	20B
0005434229098	8417	89	20E
0005432335998	8417	90	20F
0005434149545	8417	91	21A
0005432034860	8417	92	21C
0005432336002	8417	93	21D
0005435286611	8417	94	21F
0005434149631	8417	95	21E
0005434264823	8417	96	22A
0005435006958	8417	97	22B
0005432335999	8417	98	22D
0005435006949	8417	99	22C
0005435286606	8417	100	22E
0005434229050	8417	101	23A
0005434229127	8417	102	23C
0005435006948	8417	103	23B
0005432034864	8417	104	23D
0005432034856	8417	105	23E
0005435286614	8417	106	24A
0005435006959	8417	107	24B
0005434229105	8417	108	24E
0005434229051	8417	109	24D
0005432335994	8417	110	24F
0005434264889	8417	111	25B
0005434229150	8417	112	25A
0005435006966	8417	113	25D
0005432034875	8417	114	25E
0005434311212	8417	115	26A
0005432034867	8417	116	25F
0005434149544	8417	117	26B
0005435286613	8417	118	26C
0005432047541	8417	119	26E
0005432034863	8417	120	26D
0005435286607	8417	121	27A
0005434229195	8417	122	26F
0005435006963	8417	123	27C
0005432034858	8417	124	27B
0005432335995	8417	125	27D
0005435286612	8417	126	27E
0005435006954	8417	127	27F
0005434264869	8417	128	28B
0005434229019	8417	129	28A
0005432336003	8417	130	28D
0005435006956	8417	131	28C
0005434173460	8417	132	28E
0005433815373	8417	133	29A
0005434311213	8417	134	28F
0005435006944	8417	135	29C
0005432034865	8417	136	29B
0005435286610	8417	137	29D
0005434264907	8417	138	29F
0005433534492	8417	139	29E
0005434264826	8417	140	30A
0005432034866	8417	141	30C
0005432335997	8417	142	30B
0005432336000	8417	143	30E
0005433534491	8417	144	30D
0005432034874	8417	145	30F
0005432034869	8417	146	31B
0005434149608	8417	147	31A
0005435006968	8417	148	31C
0005434173466	8417	149	31E
0005435286605	8417	150	31D
0005433202325	12620	1	1A
0005434638928	12620	2	1B
0005434638986	12620	3	1D
0005434639000	12620	4	2A
0005434638993	12620	5	2B
0005433202320	12620	6	2C
0005434638987	12620	7	2D
0005434639066	12620	8	3A
0005433202321	12620	9	3B
0005434638990	12620	10	3C
0005434639072	12620	11	3D
0005434638942	12620	12	4A
0005434638946	12620	13	4B
0005434639065	12620	14	4C
0005433202316	12620	15	5A
0005433202322	12620	16	5B
0005433202318	12620	17	5C
0005434638979	12620	18	5D
0005434638889	12620	19	6A
0005434638943	12620	20	6B
0005434638978	12620	21	6D
0005434639001	12620	22	7A
0005434639099	12620	23	7C
0005433202328	12620	24	7D
0005434638929	12620	25	18B
0005434639119	12620	26	18C
0005433202313	12620	27	19B
0005434639057	12620	28	19C
0005434639019	12620	29	19D
0005434639034	12620	30	20A
0005433202319	12620	31	20B
0005434639010	12620	32	20C
0005433202324	12620	33	20D
0005433202326	12620	34	21A
0005433202323	12620	35	21B
0005434639027	12620	36	21C
0005433202327	12620	37	21D
0005433202317	12620	38	22A
0005433202315	12620	39	22B
0005434639120	12620	40	22C
0005433202314	12620	41	22D
0005434639049	12620	42	23A
0005434639234	23398	1	1A
0005433202154	23398	2	1B
0005433202162	23398	3	1C
0005434639215	23398	4	1D
0005434639223	23398	5	2A
0005434639227	23398	6	2B
0005433202213	23398	7	2C
0005434639213	23398	8	2D
0005432290621	23398	9	3A
0005434639218	23398	10	3B
0005433202188	23398	11	3C
0005434639236	23398	12	3D
0005433202147	23398	13	4A
0005434639231	23398	14	4B
0005433202187	23398	15	4C
0005433202215	23398	16	4D
0005434639217	23398	17	5A
0005434639224	23398	18	5B
0005434639214	23398	19	5C
0005434639219	23398	20	5D
0005432290622	23398	21	6B
0005433202155	23398	22	6C
0005434639233	23398	23	6D
0005434639225	23398	24	7A
0005434639221	23398	25	7B
0005434639229	23398	26	7C
0005434639235	23398	27	7D
0005433202144	23398	28	18A
0005432290620	23398	29	18B
0005434639237	23398	30	18C
0005434639228	23398	31	18D
0005433202189	23398	32	19A
0005434639232	23398	33	19B
0005433202238	23398	34	19C
0005433202206	23398	35	19D
0005434639211	23398	36	20A
0005434639226	23398	37	20B
0005433202237	23398	38	20C
0005434639230	23398	39	20D
0005433202170	23398	40	21A
0005433202211	23398	41	21B
0005434639222	23398	42	21C
0005433202212	23398	43	21D
0005434639220	23398	44	22A
0005433202148	23398	45	22B
0005434639216	23398	46	22C
0005433202145	23398	47	22D
0005433202161	23398	48	23A
0005434639212	23398	49	23B
0005432327985	21057	1	1A
0005432328218	21057	2	1C
0005432382574	21057	3	1D
0005432328142	21057	4	2A
0005432382841	21057	5	2C
0005432328127	21057	6	2D
0005432382701	21057	7	2F
0005432328295	21057	8	3A
0005432382569	21057	9	3C
0005432328367	21057	10	3D
0005432382604	21057	11	3F
0005432328087	21057	12	4A
0005432382659	21057	13	4C
0005432328145	21057	14	4D
0005432382554	21057	15	4E
0005432382737	21057	16	4F
0005432054295	21057	17	5A
0005432382819	21057	18	5C
0005432382552	21057	19	5D
0005432382723	21057	20	5E
0005432328316	21057	21	5F
0005432328269	21057	22	6A
0005432328125	21057	23	6C
0005432382630	21057	24	6D
0005432382716	21057	25	6E
0005432328037	21057	26	6F
0005432327943	21057	27	7A
0005432328038	21057	28	7D
0005432328093	21057	29	7C
0005432382660	21057	30	7F
0005432382542	21057	31	8A
0005432382553	21057	32	8C
0005432382717	21057	33	8D
0005432328059	21057	34	8F
0005432328211	21057	35	9A
0005432328115	21057	36	9C
0005432328309	21057	37	9D
0005432054294	21057	38	9E
0005432382758	21057	39	9F
0005432328085	21057	40	10A
0005432328250	21057	41	10C
0005432382623	21057	42	10D
0005432382840	21057	43	10F
0005432382675	21057	44	11A
0005432382839	21057	45	11C
0005432382679	21057	46	11D
0005432382674	21057	47	11E
0005432382627	21057	48	11F
0005432328069	21057	49	12A
0005432328150	21057	50	12C
0005432382836	21057	51	12D
0005432382632	21057	52	12E
0005432328098	21057	53	12F
0005432328068	21057	54	13A
0005432328248	21057	55	13C
0005432328126	21057	56	13D
0005432382650	21057	57	13F
0005432328148	21057	58	14C
0005432382727	21057	59	14D
0005432327996	21057	60	14E
0005432382774	21057	61	14F
0005432382631	21057	62	15A
0005432382543	21057	63	15C
0005432328163	21057	64	15D
0005432382871	21057	65	15F
0005432328149	21057	66	16A
0005432054296	21057	67	16C
0005432328182	21057	68	16D
0005432382658	21057	69	16E
0005432382686	21057	70	16F
0005432328246	21057	71	17A
0005432328245	21057	72	17C
0005432382540	21057	73	17D
0005432382703	21057	74	17E
0005432328114	21057	75	17F
0005432382685	21057	76	18A
0005432382568	21057	77	18C
0005432327942	21057	78	18D
0005432382697	21057	79	18E
0005432382603	21057	80	18F
0005432382608	21057	81	19A
0005432382704	21057	82	19C
0005432328144	21057	83	19D
0005432382602	21057	84	19E
0005432328099	21057	85	19F
0005432328141	21057	86	20A
0005432327947	21057	87	20C
0005432382628	21057	88	20D
0005432382705	21057	89	20E
0005432328249	21057	90	20F
0005432328504	31241	1	1A
0005432383028	31241	2	1C
0005432383048	31241	3	1D
0005432383044	31241	4	1F
0005432383042	31241	5	2A
0005432328542	31241	6	2C
0005432383017	31241	7	2D
0005432328518	31241	8	3A
0005432328543	31241	9	2F
0005432328514	31241	10	3C
0005432383029	31241	11	3D
0005432328531	31241	12	3F
0005432383050	31241	13	4A
0005432328524	31241	14	4C
0005432328527	31241	15	4D
0005432328517	31241	16	4F
0005432328544	31241	17	4E
0005432328526	31241	18	5A
0005432383019	31241	19	5C
0005432328511	31241	20	5D
0005432328536	31241	21	5E
0005432328523	31241	22	5F
0005432328509	31241	23	6A
0005432328530	31241	24	6C
0005432287171	31241	25	6D
0005432383052	31241	26	6E
0005432287170	31241	27	6F
0005432328503	31241	28	7A
0005432328529	31241	29	7C
0005432328501	31241	30	7D
0005432328548	31241	31	7E
0005432383013	31241	32	7F
0005432383025	31241	33	8A
0005432383024	31241	34	8C
0005432328535	31241	35	8D
0005432328513	31241	36	8E
0005432383056	31241	37	8F
0005432383016	31241	38	9A
0005432383040	31241	39	9C
0005432328515	31241	40	9D
0005432383047	31241	41	9E
0005432328521	31241	42	9F
0005432328505	31241	43	10A
0005432328547	31241	44	10C
0005432328528	31241	45	10D
0005432383053	31241	46	10E
0005432383035	31241	47	10F
0005432328520	31241	48	11A
0005432328533	31241	49	11C
0005432383037	31241	50	11D
0005432328510	31241	51	11E
0005432383027	31241	52	11F
0005432383045	31241	53	12A
0005432328532	31241	54	12C
0005432328537	31241	55	12D
0005432383034	31241	56	12E
0005432383033	31241	57	12F
0005432383036	31241	58	13A
0005432287168	31241	59	13C
0005432383026	31241	60	13D
0005432328540	31241	61	13E
0005432383023	31241	62	13F
0005432328541	31241	63	14A
0005432383038	31241	64	14C
0005432383046	31241	65	14D
0005432383051	31241	66	14E
0005432383041	31241	67	14F
0005432383022	31241	68	15A
0005432328516	31241	69	15C
0005432328519	31241	70	15D
0005432328507	31241	71	15E
0005432383043	31241	72	15F
0005432328506	31241	73	16A
0005432383054	31241	74	16C
0005432383039	31241	75	16D
0005432383055	31241	76	16E
0005432383049	31241	77	16F
0005432383031	31241	78	17A
0005432287169	31241	79	17C
0005432328525	31241	80	17D
0005432383032	31241	81	17E
0005432328546	31241	82	17F
0005432383030	31241	83	18A
0005432328522	31241	84	18C
0005432328534	31241	85	18D
0005432328508	31241	86	18E
0005432383020	31241	87	18F
0005432328549	31241	88	19A
0005432328545	31241	89	19C
0005432383014	31241	90	19D
0005432383018	31241	91	19E
0005432328502	31241	92	19F
0005432383015	31241	93	20A
0005432328512	31241	94	20C
0005432328538	31241	95	20D
0005432383021	31241	96	20F
0005432328539	31241	97	20E
0005433642279	2479	1	1A
0005433642286	2479	2	1D
0005432953840	2479	3	2A
0005433642275	2479	4	2D
0005433642265	2479	5	2F
0005433642291	2479	6	4A
0005433642273	2479	7	4D
0005433642276	2479	8	5C
0005433642267	2479	9	5D
0005432953863	2479	10	5E
0005433642274	2479	11	5F
0005433642294	2479	12	6A
0005433642295	2479	13	6D
0005433642302	2479	14	6E
0005433642280	2479	15	7A
0005432953827	2479	16	7C
0005433642290	2479	17	7D
0005433642293	2479	18	7E
0005432953822	2479	19	7F
0005433642297	2479	20	8A
0005433642287	2479	21	8D
0005432953862	2479	22	8E
0005433642260	2479	23	9A
0005433642269	2479	24	9C
0005433642261	2479	25	9D
0005432953830	2479	26	9F
0005433642300	2479	27	10D
0005433642292	2479	28	10E
0005433642284	2479	29	10F
0005432953823	2479	30	11A
0005433642282	2479	31	11E
0005433642289	2479	32	12A
0005432953841	2479	33	12D
0005433642278	2479	34	12F
0005433642271	2479	35	13A
0005432953836	2479	36	13C
0005433642283	2479	37	13D
0005433642301	2479	38	13E
0005433642296	2479	39	14A
0005432953834	2479	40	14D
0005432953829	2479	41	14E
0005433642303	2479	42	14F
0005432953832	2479	43	15A
0005433642285	2479	44	15C
0005433642264	2479	45	15D
0005433642270	2479	46	15E
0005432953818	2479	47	16A
0005433642268	2479	48	16C
0005432953835	2479	49	16D
0005433642299	2479	50	16F
0005433642277	2479	51	17A
0005433642258	2479	52	17C
0005432953828	2479	53	17D
0005432953821	2479	54	17E
0005433642266	2479	55	17F
0005433642263	2479	56	18A
0005432953849	2479	57	18C
0005433642281	2479	58	18F
0005433642288	2479	59	19A
0005433642272	2479	60	19D
0005433642262	2479	61	19E
0005433642298	2479	62	19F
0005433642259	2479	63	20F
0005432424263	13277	1	1A
0005432424235	13277	2	1D
0005432424232	13277	3	1F
0005432424250	13277	4	2A
0005432424234	13277	5	2F
0005432424268	13277	6	3D
0005432424237	13277	7	5D
0005432424242	13277	8	5E
0005432424245	13277	9	6A
0005432424258	13277	10	6C
0005432424248	13277	11	7C
0005432424261	13277	12	8A
0005432424255	13277	13	8C
0005432424256	13277	14	8F
0005432424231	13277	15	9A
0005432424247	13277	16	9D
0005432424238	13277	17	10A
0005432424241	13277	18	10C
0005432424260	13277	19	11D
0005432424252	13277	20	12C
0005432424239	13277	21	13C
0005432424251	13277	22	13D
0005432424253	13277	23	13E
0005432424266	13277	24	14F
0005432424265	13277	25	16D
0005432424262	13277	26	16E
0005432424233	13277	27	17C
0005432424243	13277	28	17E
0005432424249	13277	29	17F
0005432424244	13277	30	18C
0005432424259	13277	31	18D
0005432424236	13277	32	18E
0005432424267	13277	33	18F
0005432424246	13277	34	19A
0005432424264	13277	35	19F
0005432424257	13277	36	20A
0005432424240	13277	37	20E
0005432424254	13277	38	20F
0005432423923	30756	1	1D
0005432423841	30756	2	1F
0005432423825	30756	3	2C
0005432423839	30756	4	2D
0005432423792	30756	5	3A
0005432423849	30756	6	3C
0005432423742	30756	7	3D
0005432423887	30756	8	3F
0005432423797	30756	9	4A
0005432423847	30756	10	4E
0005432423890	30756	11	4F
0005432423891	30756	12	5A
0005432423913	30756	13	5C
0005432423715	30756	14	5D
0005432423927	30756	15	5E
0005432423882	30756	16	5F
0005432423842	30756	17	6A
0005432423886	30756	18	6D
0005432423888	30756	19	6E
0005432423862	30756	20	6F
0005432423821	30756	21	7A
0005432423806	30756	22	7C
0005432423793	30756	23	7E
0005432423840	30756	24	8A
0005432423676	30756	25	8E
0005432423868	30756	26	8F
0005432423835	30756	27	9D
0005432423935	30756	28	9E
0005432423848	30756	29	9F
0005432423867	30756	30	10F
0005432423822	30756	31	11E
0005432423834	30756	32	11F
0005432423892	30756	33	13A
0005432423820	30756	34	13C
0005432423905	30756	35	13E
0005432423807	30756	36	14D
0005432423823	30756	37	14E
0005432423794	30756	38	14F
0005432423685	30756	39	15A
0005432423907	30756	40	15C
0005432423924	30756	41	16A
0005432423830	30756	42	16C
0005432423926	30756	43	16D
0005432423889	30756	44	16E
0005432423863	30756	45	16F
0005432423704	30756	46	17C
0005432423883	30756	47	17D
0005432423948	30756	48	17E
0005432423925	30756	49	17F
0005432423904	30756	50	18A
0005432423931	30756	51	18C
0005432423906	30756	52	18E
0005432423829	30756	53	18F
0005432423885	30756	54	19C
0005434157367	9580	1	1C
0005432901410	9580	2	1D
0005432901353	9580	3	1F
0005432817364	9580	4	2C
0005432817372	9580	5	2D
0005432817379	9580	6	2F
0005432822181	9580	7	3A
0005432817384	9580	8	3C
0005432288976	9580	9	3D
0005434157420	9580	10	4A
0005434186168	9580	11	4E
0005434448305	9580	12	4F
0005432817381	9580	13	5C
0005432822177	9580	14	5D
0005434157365	9580	15	5F
0005432822182	9580	16	7A
0005432817369	9580	17	7C
0005432901501	9580	18	7D
0005432817378	9580	19	7E
0005432817374	9580	20	7F
0005432901407	9580	21	8A
0005434448306	9580	22	8D
0005432817392	9580	23	8F
0005432817393	9580	24	9A
0005432817375	9580	25	9C
0005432817377	9580	26	9E
0005432288978	9580	27	9F
0005434157391	9580	28	10A
0005432817385	9580	29	10C
0005432817386	9580	30	10D
0005432288974	9580	31	10F
0005432817387	9580	32	11C
0005432817388	9580	33	11E
0005432817363	9580	34	11F
0005432817383	9580	35	12A
0005434157387	9580	36	12C
0005432288975	9580	37	12E
0005432817391	9580	38	13A
0005432817365	9580	39	13C
0005432822176	9580	40	13D
0005434157375	9580	41	13E
0005432817390	9580	42	13F
0005432288977	9580	43	14C
0005432817368	9580	44	14E
0005432901373	9580	45	14F
0005432817380	9580	46	15C
0005432822179	9580	47	15D
0005432822180	9580	48	15E
0005432817367	9580	49	15F
0005434157390	9580	50	16A
0005432901463	9580	51	16C
0005432901417	9580	52	16D
0005434157366	9580	53	17A
0005432817376	9580	54	17C
0005432901406	9580	55	17D
0005432901379	9580	56	17E
0005432817382	9580	57	17F
0005434157398	9580	58	18A
0005432901403	9580	59	18C
0005432901418	9580	60	18D
0005432817373	9580	61	18E
0005432901366	9580	62	18F
0005432822178	9580	63	19D
0005432817371	9580	64	19F
0005432817370	9580	65	20A
0005432817389	9580	66	20C
0005434448304	9580	67	20E
0005432817366	9580	68	20F
0005434157460	28990	1	1C
0005432822095	28990	2	1D
0005434186188	28990	3	1F
0005432817244	28990	4	2A
0005432817274	28990	5	2F
0005432901547	28990	6	3C
0005432817077	28990	7	3D
0005434157459	28990	8	4A
0005432817079	28990	9	4C
0005432817089	28990	10	4E
0005432817102	28990	11	4F
0005432901557	28990	12	5A
0005432901553	28990	13	5C
0005432901554	28990	14	5D
0005434157454	28990	15	5E
0005434157456	28990	16	5F
0005432817273	28990	17	6D
0005432901562	28990	18	6E
0005432817080	28990	19	6F
0005434157453	28990	20	7A
0005432817110	28990	21	7C
0005432817101	28990	22	7D
0005432002068	28990	23	7E
0005432817036	28990	24	7F
0005432901560	28990	25	8A
0005432901548	28990	26	8C
0005432822111	28990	27	8D
0005432817197	28990	28	8E
0005434448285	28990	29	8F
0005432822108	28990	30	9A
0005432822112	28990	31	9C
0005432817117	28990	32	10A
0005432817198	28990	33	10C
0005432817106	28990	34	10F
0005432817246	28990	35	11A
0005432817219	28990	36	11C
0005434157457	28990	37	11D
0005432901551	28990	38	11E
0005434157458	28990	39	11F
0005432822130	28990	40	12A
0005432817076	28990	41	12C
0005432901550	28990	42	12D
0005432817138	28990	43	12E
0005432817105	28990	44	12F
0005432817075	28990	45	13A
0005432901559	28990	46	13D
0005432822097	28990	47	13E
0005432817119	28990	48	13F
0005432817245	28990	49	14A
0005432002069	28990	50	14C
0005434448266	28990	51	14D
0005432822096	28990	52	14E
0005434186187	28990	53	14F
0005432817074	28990	54	15A
0005432901563	28990	55	15C
0005434448275	28990	56	15D
0005432822114	28990	57	15E
0005434157455	28990	58	15F
0005432901552	28990	59	16A
0005434157452	28990	60	16C
0005432901561	28990	61	16D
0005432901549	28990	62	17A
0005432901558	28990	63	17C
0005432901546	28990	64	17D
0005434448273	28990	65	17E
0005434448276	28990	66	17F
0005432822113	28990	67	18A
0005434448286	28990	68	18C
0005432901555	28990	69	18D
0005432901556	28990	70	18E
0005432822140	28990	71	18F
0005432822080	28990	72	19A
0005432822115	28990	73	19C
0005432002070	28990	74	19D
0005434448274	28990	75	19F
0005432817103	28990	76	20A
0005432817113	28990	77	20C
0005432817078	28990	78	20D
0005432822116	28990	79	20E
0005432611697	15089	1	1A
0005432611699	15089	2	2A
0005432613848	15089	3	3A
0005432611696	15089	4	2B
0005432613849	15089	5	4B
0005432611698	15089	6	5A
0005432613847	15089	7	5B
0005432613850	15089	8	6A
0005432611674	31618	1	1A
0005432607508	31618	2	1B
0005432611654	31618	3	2B
0005432611660	31618	4	2A
0005432607521	31618	5	3B
0005432611673	31618	6	3A
0005432607518	31618	7	4A
0005432611657	31618	8	4B
0005432607509	31618	9	5A
0005432607507	31618	10	5B
0005432611688	31618	11	6A
0005432611659	31618	12	6B
0005432947945	11877	1	1D
0005433568848	11877	2	1C
0005433568866	11877	3	2A
0005433568809	11877	4	1F
0005433568836	11877	5	2D
0005433568847	11877	6	2C
0005433568857	11877	7	3A
0005433568867	11877	8	2F
0005433568859	11877	9	3D
0005433568807	11877	10	3C
0005433568821	11877	11	4A
0005433568808	11877	12	3F
0005433568823	11877	13	4C
0005433568863	11877	14	5A
0005432948131	11877	15	4F
0005432947897	11877	16	4D
0005433568840	11877	17	5D
0005432947944	11877	18	5C
0005432947982	11877	19	5F
0005433568829	11877	20	6A
0005433568819	11877	21	6C
0005433568814	11877	22	6B
0005433568851	11877	23	6E
0005432948031	11877	24	7A
0005432948066	11877	25	6F
0005433568835	11877	26	7C
0005433568854	11877	27	7B
0005432948087	11877	28	7E
0005432947898	11877	29	7D
0005432947809	11877	30	8A
0005433568838	11877	31	7F
0005432947964	11877	32	8B
0005433568842	11877	33	8D
0005433568844	11877	34	8C
0005432947877	11877	35	9A
0005432947872	11877	36	9D
0005433568813	11877	37	9C
0005433568817	11877	38	9F
0005433568864	11877	39	9E
0005433568826	11877	40	10C
0005433568810	11877	41	10B
0005432947965	11877	42	10E
0005433568815	11877	43	10D
0005433568856	11877	44	11A
0005433568803	11877	45	10F
0005433568849	11877	46	11B
0005433568839	11877	47	11D
0005432947843	11877	48	11C
0005432947977	11877	49	11F
0005433568811	11877	50	11E
0005433568827	11877	51	12B
0005433568828	11877	52	12A
0005432948012	11877	53	12D
0005433568846	11877	54	12E
0005433568850	11877	55	13A
0005433568834	11877	56	12F
0005433568862	11877	57	13C
0005433568806	11877	58	13B
0005433568861	11877	59	13E
0005433568832	11877	60	13D
0005432947862	11877	61	14A
0005432947876	11877	62	13F
0005432947810	11877	63	14D
0005433568858	11877	64	14C
0005433568818	11877	65	14F
0005432947883	11877	66	15A
0005433568852	11877	67	15C
0005433568822	11877	68	15F
0005432947867	11877	69	15E
0005433568833	11877	70	15D
0005433568845	11877	71	16A
0005433568831	11877	72	16D
0005432948011	11877	73	16C
0005432947988	11877	74	17A
0005433568853	11877	75	16E
0005432947925	11877	76	17B
0005432947833	11877	77	17D
0005432948029	11877	78	17C
0005433568841	11877	79	17F
0005433568824	11877	80	17E
0005433568855	11877	81	18A
0005432947811	11877	82	18B
0005433568865	11877	83	18E
0005433568860	11877	84	18D
0005433568816	11877	85	19A
0005432948067	11877	86	18F
0005432948032	11877	87	19B
0005432947971	11877	88	19E
0005433568804	11877	89	19D
0005433568820	11877	90	19C
0005432947785	11877	91	19F
0005433568830	11877	92	20B
0005433568825	11877	93	20A
0005432947884	11877	94	20D
0005433568805	11877	95	20C
0005433568837	11877	96	20F
0005433568843	11877	97	20E
0005433568868	11877	98	21C
0005432947995	11877	99	21E
0005433568812	11877	100	21F
0005432948367	25295	1	1F
0005432948352	25295	2	1D
0005433568377	25295	3	2A
0005433568233	25295	4	2D
0005432948363	25295	5	3A
0005433568405	25295	6	2F
0005433568234	25295	7	3D
0005433568366	25295	8	3C
0005433568040	25295	9	4A
0005433568243	25295	10	3F
0005433568235	25295	11	4C
0005432948387	25295	12	5A
0005432948376	25295	13	4F
0005433568345	25295	14	4D
0005432948382	25295	15	5C
0005433568418	25295	16	5D
0005432948373	25295	17	6B
0005433568133	25295	18	6A
0005432948347	25295	19	6E
0005433568430	25295	20	7A
0005432948388	25295	21	7C
0005432948364	25295	22	7B
0005432948366	25295	23	7E
0005433568085	25295	24	7D
0005433568353	25295	25	8A
0005433568374	25295	26	7F
0005433568370	25295	27	8C
0005432948385	25295	28	8B
0005432948369	25295	29	8D
0005433568378	25295	30	8F
0005432948351	25295	31	8E
0005432948365	25295	32	9B
0005432948348	25295	33	9A
0005433568253	25295	34	9C
0005433568316	25295	35	9E
0005432948356	25295	36	10A
0005433568483	25295	37	10C
0005432948354	25295	38	10B
0005433568420	25295	39	10E
0005433568060	25295	40	10D
0005433568292	25295	41	11A
0005433568338	25295	42	10F
0005432948355	25295	43	11B
0005433568187	25295	44	11D
0005433568262	25295	45	11F
0005433568044	25295	46	11E
0005432948371	25295	47	12B
0005433568402	25295	48	12A
0005432948375	25295	49	12D
0005433568365	25295	50	12C
0005432948368	25295	51	12E
0005432948358	25295	52	13A
0005433568181	25295	53	12F
0005433568163	25295	54	13C
0005433568298	25295	55	13E
0005433568448	25295	56	13D
0005433568478	25295	57	13F
0005432948350	25295	58	14B
0005433568476	25295	59	14A
0005432948359	25295	60	14D
0005433568371	25295	61	14C
0005432948374	25295	62	14F
0005432948384	25295	63	14E
0005433568043	25295	64	15B
0005433568521	25295	65	15A
0005433568364	25295	66	15C
0005433568350	25295	67	15F
0005432948370	25295	68	15E
0005433568335	25295	69	15D
0005433568446	25295	70	16A
0005432948381	25295	71	16C
0005432948380	25295	72	16B
0005432948353	25295	73	16E
0005433568401	25295	74	16D
0005432948357	25295	75	17B
0005432948386	25295	76	17C
0005433568447	25295	77	18B
0005432948361	25295	78	18C
0005433568464	25295	79	18D
0005433568336	25295	80	19A
0005432948377	25295	81	18F
0005432948379	25295	82	19C
0005432948362	25295	83	19B
0005432948349	25295	84	19E
0005432948360	25295	85	19D
0005433568167	25295	86	19F
0005433568429	25295	87	20B
0005432948372	25295	88	20A
0005433568461	25295	89	20D
0005432948378	25295	90	20C
0005433568533	25295	91	20F
0005433568337	25295	92	20E
0005433568367	25295	93	21A
0005432948383	25295	94	21C
0005433568135	25295	95	21B
0005433568297	25295	96	21E
0005433568150	25295	97	21D
0005433568421	25295	98	21F
0005433808326	14460	1	1A
0005432430851	14460	2	1D
0005433812870	14460	3	2C
0005432430855	14460	4	3A
0005432430847	14460	5	3D
0005432430846	14460	6	4C
0005433812871	14460	7	5D
0005434026696	14460	8	6D
0005433808320	14460	9	6C
0005433808329	14460	10	6E
0005433812869	14460	11	7B
0005433808312	14460	12	8C
0005434026699	14460	13	8A
0005433808335	14460	14	8D
0005432430856	14460	15	8F
0005432430852	14460	16	9C
0005432430850	14460	17	9F
0005433812863	14460	18	10C
0005434026698	14460	19	11C
0005434026700	14460	20	11B
0005433808316	14460	21	13E
0005432430849	14460	22	14A
0005433808334	14460	23	14C
0005432430848	14460	24	14E
0005434026695	14460	25	15E
0005432430845	14460	26	16A
0005433808315	14460	27	17A
0005433812862	14460	28	16F
0005433808314	14460	29	17C
0005433808327	14460	30	18B
0005432430853	14460	31	18C
0005433808323	14460	32	19D
0005433812866	14460	33	19F
0005433812868	14460	34	20C
0005434026697	14460	35	21A
0005432430854	14460	36	21B
0005433808313	14460	37	21E
0005433812881	30827	1	2F
0005432430829	30827	2	3C
0005433812891	30827	3	4D
0005433808358	30827	4	4C
0005434026675	30827	5	4A
0005432430805	30827	6	5A
0005433808359	30827	7	4F
0005432430817	30827	8	5C
0005432430800	30827	9	5F
0005432430825	30827	10	6C
0005433812885	30827	11	6F
0005432430810	30827	12	7A
0005432430815	30827	13	7B
0005432430806	30827	14	7F
0005432430818	30827	15	8B
0005433808363	30827	16	8F
0005432430804	30827	17	9B
0005433808348	30827	18	9D
0005433812890	30827	19	9E
0005433808351	30827	20	9F
0005433808353	30827	21	10E
0005433808357	30827	22	10F
0005433812887	30827	23	11D
0005432430812	30827	24	11F
0005432430811	30827	25	11E
0005432430824	30827	26	12D
0005433808362	30827	27	12C
0005433812888	30827	28	13B
0005433808356	30827	29	12F
0005432430801	30827	30	13C
0005434026674	30827	31	14A
0005433812886	30827	32	13E
0005433808352	30827	33	14D
0005433812882	30827	34	15B
0005434026676	30827	35	15A
0005433812884	30827	36	15C
0005432430842	30827	37	16A
0005433812889	30827	38	16C
0005433812883	30827	39	16B
0005433808360	30827	40	17A
0005433808349	30827	41	16F
0005432430814	30827	42	17B
0005433808354	30827	43	18B
0005432430822	30827	44	18C
0005433808355	30827	45	18E
0005433808350	30827	46	20A
0005434026679	30827	47	20C
0005433808361	30827	48	20F
0005432430816	30827	49	20E
0005434026680	30827	50	21B
0005432430823	30827	51	21D
0005435340057	5423	1	1A
0005434654607	5423	2	1C
0005434654605	5423	3	1D
0005432114194	5423	4	2A
0005434654608	5423	5	2D
0005434654595	5423	6	2F
0005434654604	5423	7	3C
0005435340058	5423	8	3D
0005434654594	5423	9	3F
0005435340036	5423	10	4E
0005435555348	5423	11	5C
0005434654598	5423	12	5E
0005434654582	5423	13	6C
0005434656549	5423	14	6E
0005434654602	5423	15	6F
0005434654583	5423	16	7F
0005434654578	5423	17	8A
0005434654592	5423	18	8C
0005435340085	5423	19	8D
0005435340056	5423	20	9A
0005434654580	5423	21	9D
0005434654603	5423	22	9E
0005434654600	5423	23	10F
0005435340084	5423	24	11D
0005434654581	5423	25	11F
0005435340054	5423	26	12A
0005434656551	5423	27	13D
0005434654585	5423	28	13E
0005434654591	5423	29	14A
0005434654588	5423	30	14C
0005434654584	5423	31	14D
0005434654596	5423	32	14E
0005432114193	5423	33	14F
0005434654601	5423	34	15A
0005435340037	5423	35	15C
0005434654599	5423	36	15E
0005434654590	5423	37	15F
0005434656550	5423	38	16A
0005435340088	5423	39	16F
0005434654597	5423	40	17A
0005434654606	5423	41	17D
0005434654589	5423	42	17E
0005434654587	5423	43	17F
0005435340086	5423	44	18D
0005435340089	5423	45	18E
0005432114191	5423	46	18F
0005434654579	5423	47	19C
0005434654586	5423	48	19E
0005435340096	5423	49	19F
0005435340074	5423	50	20A
0005434654593	5423	51	20C
0005432114192	5423	52	20D
0005435340070	5423	53	20E
0005435340207	12543	1	1A
0005435340214	12543	2	1D
0005435340217	12543	3	2A
0005434654221	12543	4	2D
0005434654364	12543	5	2F
0005434654463	12543	6	4A
0005434654249	12543	7	4D
0005434654378	12543	8	5A
0005434654309	12543	9	5D
0005435340220	12543	10	5E
0005434654293	12543	11	5F
0005434654446	12543	12	6A
0005434654311	12543	13	7E
0005435340218	12543	14	8D
0005435340210	12543	15	8F
0005434654250	12543	16	9A
0005434654310	12543	17	9E
0005434654286	12543	18	9F
0005435340213	12543	19	10C
0005434654375	12543	20	10E
0005434654426	12543	21	11A
0005435340208	12543	22	11E
0005435555364	12543	23	11F
0005435340221	12543	24	12C
0005434654367	12543	25	12D
0005434654266	12543	26	12E
0005435340209	12543	27	12F
0005434654303	12543	28	13A
0005435340215	12543	29	13D
0005435340216	12543	30	14D
0005434654239	12543	31	15A
0005434654234	12543	32	15D
0005434654294	12543	33	15F
0005434654516	12543	34	16E
0005434654374	12543	35	17A
0005435340212	12543	36	17D
0005434654344	12543	37	18C
0005435555363	12543	38	18D
0005434654481	12543	39	18E
0005434654379	12543	40	19C
0005435340211	12543	41	19D
0005435340222	12543	42	19F
0005435340219	12543	43	20C
0005434654312	12543	44	20E
0005433715817	7430	1	1A
0005433690917	7430	2	1C
0005435266079	7430	3	1D
0005433715784	7430	4	1F
0005433656656	7430	5	2D
0005433715789	7430	6	2F
0005433690920	7430	7	3A
0005433715820	7430	8	3D
0005433722197	7430	9	3C
0005433715796	7430	10	4B
0005433715829	7430	11	4D
0005433719128	7430	12	4C
0005433715816	7430	13	4F
0005433715788	7430	14	5B
0005433656658	7430	15	5A
0005433715783	7430	16	5C
0005435266088	7430	17	6A
0005435266094	7430	18	6B
0005433715826	7430	19	6C
0005433715791	7430	20	6D
0005433715797	7430	21	6E
0005433715825	7430	22	6F
0005433715821	7430	23	7A
0005433715827	7430	24	7C
0005433715807	7430	25	7D
0005433688800	7430	26	7F
0005433715832	7430	27	7E
0005433715782	7430	28	8B
0005433715811	7430	29	8D
0005433689902	7430	30	9A
0005433715810	7430	31	8F
0005433715814	7430	32	9B
0005435266086	7430	33	9C
0005433715819	7430	34	9D
0005433715822	7430	35	9E
0005433722198	7430	36	10B
0005433688801	7430	37	10E
0005433715833	7430	38	10D
0005433715793	7430	39	11C
0005432078092	7430	40	11D
0005433715831	7430	41	12C
0005433715785	7430	42	12B
0005433715800	7430	43	12E
0005433715790	7430	44	12F
0005433715809	7430	45	13A
0005435266076	7430	46	13B
0005433715808	7430	47	13D
0005433690921	7430	48	13C
0005433722199	7430	49	13F
0005433656657	7430	50	14B
0005433715802	7430	51	14A
0005435266080	7430	52	14C
0005433715813	7430	53	14E
0005433689904	7430	54	15B
0005432078090	7430	55	15E
0005435266087	7430	56	16A
0005433690918	7430	57	16C
0005433715805	7430	58	16D
0005433715806	7430	59	16F
0005433715787	7430	60	17B
0005433715798	7430	61	17D
0005433715799	7430	62	17C
0005433715795	7430	63	17E
0005435266077	7430	64	18A
0005435266085	7430	65	17F
0005432078089	7430	66	18B
0005433715794	7430	67	18C
0005433715818	7430	68	19A
0005433715815	7430	69	19C
0005433715824	7430	70	19B
0005433719127	7430	71	19D
0005433690919	7430	72	19E
0005433715801	7430	73	19F
0005433689903	7430	74	20B
0005433715828	7430	75	20A
0005433715804	7430	76	20D
0005433715830	7430	77	21A
0005435266081	7430	78	21C
0005433715803	7430	79	21E
0005433715786	7430	80	22A
0005433715823	7430	81	22B
0005432428884	7430	82	22E
0005432078091	7430	83	22D
0005433715792	7430	84	22F
0005433715812	7430	85	23B
0005435266096	7430	86	23D
0005433715426	29221	1	1C
0005433715379	29221	2	1D
0005433722125	29221	3	2A
0005433715370	29221	4	1F
0005432006751	29221	5	2C
0005433715286	29221	6	2D
0005433722118	29221	7	3C
0005432428916	29221	8	3A
0005433685498	29221	9	3D
0005433688782	29221	10	4D
0005433715338	29221	11	4F
0005433715293	29221	12	5A
0005435266136	29221	13	5C
0005433688783	29221	14	5B
0005433715292	29221	15	5D
0005433715413	29221	16	5E
0005433715420	29221	17	6A
0005433685499	29221	18	5F
0005433715454	29221	19	6C
0005433715500	29221	20	6B
0005433715351	29221	21	6F
0005432428918	29221	22	7A
0005433715343	29221	23	7B
0005433715256	29221	24	7E
0005433685493	29221	25	7D
0005433715342	29221	26	7F
0005433722142	29221	27	8A
0005433715243	29221	28	8B
0005433722145	29221	29	8E
0005433715389	29221	30	8D
0005432428917	29221	31	9B
0005433722127	29221	32	9C
0005433715540	29221	33	9F
0005433715459	29221	34	9E
0005435266137	29221	35	10D
0005433715344	29221	36	10C
0005433715322	29221	37	11A
0005433722129	29221	38	10E
0005433715542	29221	39	11B
0005432006750	29221	40	11C
0005435266139	29221	41	11E
0005433715202	29221	42	11F
0005433715352	29221	43	12B
0005433715233	29221	44	12A
0005433715390	29221	45	12C
0005433715237	29221	46	12F
0005433715307	29221	47	13A
0005433715460	29221	48	13C
0005433715328	29221	49	13B
0005435266140	29221	50	13F
0005433722140	29221	51	13E
0005433715280	29221	52	14B
0005433722119	29221	53	14D
0005433722146	29221	54	14E
0005433715251	29221	55	14F
0005433715387	29221	56	15B
0005433715455	29221	57	15A
0005433715391	29221	58	15C
0005433719088	29221	59	15E
0005433715562	29221	60	16A
0005433656624	29221	61	15F
0005433715399	29221	62	16D
0005433715239	29221	63	16F
0005433722143	29221	64	17B
0005433715341	29221	65	17C
0005433715376	29221	66	17D
0005433715388	29221	67	17F
0005433715315	29221	68	18A
0005433715421	29221	69	18C
0005433715257	29221	70	18E
0005433715252	29221	71	18D
0005432006752	29221	72	19C
0005433722141	29221	73	19B
0005433715339	29221	74	19E
0005433722144	29221	75	19D
0005433715541	29221	76	20A
0005433715340	29221	77	20B
0005435266138	29221	78	20C
0005433722126	29221	79	21A
0005433715234	29221	80	20F
0005433722163	29221	81	21B
0005433715502	29221	82	21E
0005433722104	29221	83	22B
0005432428919	29221	84	22A
0005433715546	29221	85	22D
0005433715314	29221	86	22E
0005433715323	29221	87	23A
0005433715273	29221	88	23B
0005433715236	29221	89	23C
0005433715499	29221	90	23D
0005433715367	29221	91	23F
0005434095222	8690	1	1F
0005434095232	8690	2	2A
0005434182072	8690	3	2F
0005434095231	8690	4	3A
0005434095228	8690	5	3C
0005434095236	8690	6	3F
0005434182054	8690	7	4A
0005434095233	8690	8	4C
0005434182025	8690	9	4D
0005434095226	8690	10	4E
0005434182024	8690	11	5A
0005434182044	8690	12	5C
0005434184639	8690	13	6A
0005434182081	8690	14	6E
0005434184637	8690	15	6F
0005434182071	8690	16	7C
0005434182080	8690	17	7D
0005434182070	8690	18	7E
0005434184640	8690	19	7F
0005434181975	8690	20	9A
0005434095229	8690	21	9C
0005434095224	8690	22	9F
0005434182053	8690	23	10A
0005434182031	8690	24	10D
0005434182079	8690	25	10F
0005434184650	8690	26	11A
0005434182075	8690	27	11C
0005434182073	8690	28	11E
0005434182030	8690	29	12E
0005434095234	8690	30	13E
0005434095230	8690	31	13F
0005434182084	8690	32	15C
0005434182043	8690	33	15D
0005434182068	8690	34	15E
0005434095235	8690	35	15F
0005434095223	8690	36	16F
0005434182032	8690	37	17D
0005434095227	8690	38	17E
0005434182018	8690	39	18E
0005434095225	8690	40	18F
0005434184651	8690	41	19A
0005434095237	8690	42	19D
0005434182095	8690	43	19F
0005434184638	8690	44	20D
0005434182074	8690	45	20F
0005434095145	11661	1	1A
0005434095124	11661	2	1C
0005434182148	11661	3	3F
0005434095092	11661	4	4C
0005434182149	11661	5	4D
0005434095080	11661	6	4E
0005434095100	11661	7	5D
0005434182142	11661	8	5E
0005434095094	11661	9	6A
0005434183571	11661	10	6D
0005434143704	11661	11	7F
0005434184657	11661	12	8D
0005434182141	11661	13	8E
0005434095047	11661	14	9A
0005434095102	11661	15	9C
0005434095057	11661	16	9D
0005434182144	11661	17	9F
0005434095081	11661	18	10D
0005434095091	11661	19	10E
0005434095104	11661	20	11A
0005434143703	11661	21	11C
0005434183572	11661	22	11D
0005434182146	11661	23	11E
0005434182139	11661	24	11F
0005434095171	11661	25	12A
0005434182140	11661	26	13A
0005434182145	11661	27	13E
0005434095056	11661	28	14A
0005434095045	11661	29	14D
0005434182137	11661	30	16A
0005434095120	11661	31	16D
0005434184658	11661	32	16E
0005434095101	11661	33	17A
0005434095127	11661	34	17C
0005434095099	11661	35	17D
0005434182138	11661	36	17F
0005434095082	11661	37	18A
0005434143705	11661	38	18C
0005434184656	11661	39	18F
0005434182143	11661	40	19F
0005434182147	11661	41	20A
0005434095055	11661	42	20C
0005433397670	1442	1	1A
0005433397478	1442	2	1C
0005433397587	1442	3	1D
0005433456955	1442	4	2A
0005432297268	1442	5	2C
0005433397736	1442	6	2D
0005433397461	1442	7	3C
0005433397680	1442	8	3D
0005433397386	1442	9	3F
0005433397452	1442	10	4F
0005432906507	1442	11	5A
0005433397479	1442	12	5C
0005433397581	1442	13	5D
0005433397543	1442	14	5E
0005433397384	1442	15	5F
0005433397470	1442	16	6C
0005433397316	1442	17	6F
0005433397460	1442	18	7C
0005433397391	1442	19	7D
0005432906512	1442	20	8A
0005433397346	1442	21	7F
0005433397385	1442	22	8C
0005433397486	1442	23	8D
0005433397515	1442	24	8F
0005433397524	1442	25	9A
0005433397345	1442	26	9C
0005433397480	1442	27	9E
0005433397439	1442	28	9F
0005433397278	1442	29	10A
0005433397556	1442	30	10C
0005433397462	1442	31	10D
0005433456957	1442	32	10F
0005433397315	1442	33	11A
0005433397601	1442	34	11D
0005433397314	1442	35	11E
0005433397249	1442	36	11F
0005433397424	1442	37	12A
0005433397713	1442	38	12C
0005433397401	1442	39	12D
0005432297270	1442	40	12E
0005433397494	1442	41	12F
0005433397279	1442	42	13A
0005433397516	1442	43	13C
0005433397582	1442	44	14A
0005433456956	1442	45	14D
0005433397679	1442	46	14E
0005433397588	1442	47	14F
0005433397597	1442	48	15C
0005432906504	1442	49	15D
0005433397341	1442	50	15E
0005433456954	1442	51	16A
0005432297269	1442	52	16C
0005433397583	1442	53	16D
0005433397471	1442	54	16E
0005433397438	1442	55	16F
0005432906500	1442	56	17A
0005433397636	1442	57	17C
0005433397584	1442	58	17D
0005433397678	1442	59	17E
0005432906510	1442	60	18A
0005433397570	1442	61	18C
0005433397482	1442	62	18D
0005433397440	1442	63	18E
0005433397444	1442	64	18F
0005433397525	1442	65	19A
0005433397340	1442	66	19C
0005433397404	1442	67	19F
0005433397602	1442	68	20A
0005433397216	1442	69	20C
0005433397637	1442	70	20D
0005433397402	1442	71	20E
0005433397423	1442	72	20F
0005433397875	19241	1	1A
0005435732222	19241	2	1C
0005433397898	19241	3	1D
0005433397894	19241	4	1F
0005433397913	19241	5	2A
0005433397921	19241	6	2F
0005435732167	19241	7	3A
0005433397903	19241	8	3C
0005433397892	19241	9	3F
0005433397889	19241	10	4A
0005433397907	19241	11	4D
0005432906527	19241	12	4E
0005435732207	19241	13	4F
0005433397888	19241	14	5A
0005433397908	19241	15	5C
0005433456929	19241	16	5D
0005433397897	19241	17	5E
0005433397902	19241	18	5F
0005433397884	19241	19	6A
0005432906528	19241	20	6F
0005435732162	19241	21	7A
0005433456914	19241	22	7D
0005433397890	19241	23	7E
0005435732168	19241	24	7F
0005433397895	19241	25	8A
0005433397916	19241	26	8C
0005433456944	19241	27	8E
0005435732270	19241	28	9A
0005433397906	19241	29	9C
0005433397891	19241	30	9D
0005433397881	19241	31	9E
0005433456930	19241	32	10A
0005433397904	19241	33	10C
0005433397874	19241	34	10D
0005433397880	19241	35	10E
0005433397879	19241	36	10F
0005433397911	19241	37	11C
0005433397878	19241	38	11D
0005433397887	19241	39	11E
0005433397877	19241	40	11F
0005433397918	19241	41	12A
0005435732208	19241	42	12C
0005435732211	19241	43	12D
0005433397886	19241	44	12E
0005433397920	19241	45	12F
0005433397914	19241	46	13A
0005433397912	19241	47	13D
0005433397882	19241	48	14A
0005435732163	19241	49	14E
0005433397910	19241	50	14D
0005433397893	19241	51	14F
0005433456932	19241	52	15C
0005435732220	19241	53	15D
0005433397901	19241	54	15E
0005435732205	19241	55	15F
0005433397883	19241	56	16C
0005433397909	19241	57	16D
0005433397876	19241	58	16F
0005435732169	19241	59	17A
0005433397923	19241	60	17C
0005433397905	19241	61	17D
0005433397917	19241	62	17E
0005433397915	19241	63	17F
0005433397919	19241	64	18C
0005433397896	19241	65	18D
0005435732216	19241	66	18F
0005433397924	19241	67	19A
0005433397900	19241	68	19D
0005433397885	19241	69	19E
0005433397922	19241	70	19F
0005435732197	19241	71	20A
0005433397899	19241	72	20C
0005435732166	19241	73	20E
0005434443524	17393	1	1B
0005434443481	17393	2	2B
0005434443542	17393	3	4B
0005434443502	17393	4	4D
0005434443567	17393	5	6B
0005434443496	17393	6	18A
0005434443574	17393	7	18D
0005434443510	17393	8	18C
0005434443484	17393	9	19B
0005434443521	17393	10	19C
0005434443483	17393	11	20C
0005434443568	17393	12	20D
0005434443562	17393	13	22B
0005434443641	20579	1	1A
0005434443640	20579	2	1B
0005434443638	20579	3	2B
0005434443649	20579	4	4D
0005434443648	20579	5	5C
0005434443644	20579	6	5D
0005434443653	20579	7	6C
0005434443651	20579	8	7B
0005434443639	20579	9	7C
0005434443654	20579	10	7D
0005434443643	20579	11	18A
0005434443645	20579	12	18C
0005434443646	20579	13	19D
0005434443647	20579	14	21B
0005434443650	20579	15	22C
0005434443642	20579	16	23A
0005434443652	20579	17	23B
0005434954597	7257	1	1B
0005434954596	7257	2	2B
0005434954594	7257	3	3A
0005434954595	7257	4	5A
0005435377554	7257	5	6A
0005434954561	28313	1	1A
0005435377572	28313	2	3B
0005435377573	28313	3	4A
0005434954565	28313	4	6B
0005435893563	4472	1	1B
0005434351654	4472	2	1D
0005435893546	4472	3	2A
0005435893543	4472	4	2B
0005435893554	4472	5	2C
0005434351659	4472	6	2D
0005434183555	4472	7	3A
0005434351653	4472	8	3D
0005435893544	4472	9	5A
0005434351658	4472	10	5B
0005434351649	4472	11	5D
0005434351656	4472	12	7B
0005434351655	4472	13	18B
0005434351650	4472	14	18D
0005435893545	4472	15	20B
0005435893562	4472	16	20D
0005434351657	4472	17	21A
0005434351648	4472	18	21C
0005434351647	4472	19	22B
0005434351651	4472	20	22D
0005434351652	4472	21	23A
0005434351485	29626	1	1D
0005434351523	29626	2	2B
0005435893611	29626	3	2D
0005434351569	29626	4	3A
0005434351517	29626	5	4A
0005434351522	29626	6	5D
0005434351516	29626	7	6D
0005435893605	29626	8	7A
0005435893610	29626	9	7C
0005435893607	29626	10	18A
0005434351524	29626	11	19C
0005435893612	29626	12	20A
0005435893609	29626	13	20C
0005434351511	29626	14	20D
0005434351502	29626	15	22A
0005435893608	29626	16	22C
0005434351534	29626	17	22D
0005435893606	29626	18	23A
0005435092044	1045	1	1A
0005433341946	1045	2	1B
0005433341673	1045	3	1F
0005435545715	1045	4	1C
0005433341470	1045	5	2A
0005433342029	1045	6	1H
0005433341578	1045	7	2B
0005433342102	1045	8	2F
0005435545719	1045	9	2G
0005433341852	1045	10	2H
0005433342026	1045	11	3B
0005435545721	1045	12	3F
0005433269652	1045	13	3C
0005433159287	1045	14	3H
0005433269642	1045	15	4B
0005433342004	1045	16	4F
0005433342485	1045	17	4C
0005433342205	1045	18	4G
0005433462741	1045	19	4H
0005433269665	1045	20	5A
0005433342012	1045	21	5C
0005433341656	1045	22	5G
0005433341760	1045	23	5F
0005435545716	1045	24	9A
0005433341647	1045	25	5H
0005433341536	1045	26	9B
0005433341786	1045	27	9G
0005433341618	1045	28	11A
0005433341646	1045	29	9H
0005433341899	1045	30	11D
0005433341856	1045	31	11H
0005433159288	1045	32	12A
0005433341987	1045	33	12D
0005433269648	1045	34	12E
0005433341945	1045	35	12G
0005435092037	1045	36	12H
0005433341665	1045	37	13B
0005433341602	1045	38	13A
0005433342080	1045	39	13E
0005433341743	1045	40	13G
0005433159292	1045	41	13H
0005434445242	1045	42	14A
0005433341948	1045	43	14E
0005433341992	1045	44	14D
0005433342074	1045	45	14B
0005433341988	1045	46	14G
0005433342339	1045	47	14H
0005434446512	1045	48	15B
0005433342158	1045	49	15E
0005433341872	1045	50	15F
0005434445240	1045	51	15H
0005433463894	1045	52	16A
0005433342222	1045	53	16E
0005433341825	1045	54	16H
0005432293200	1045	55	17B
0005433342385	1045	56	17G
0005435092040	1045	57	18A
0005433269625	1045	58	17H
0005433341702	1045	59	18B
0005433341471	1045	60	18D
0005433341679	1045	61	18E
0005435092039	1045	62	18G
0005433341983	1045	63	18H
0005433341818	1045	64	19B
0005433462740	1045	65	19A
0005433341785	1045	66	19E
0005433342221	1045	67	19D
0005433341604	1045	68	19H
0005433342036	1045	69	20A
0005433342055	1045	70	20D
0005433463893	1045	71	20B
0005433341808	1045	72	20E
0005435092045	1045	73	20F
0005433341692	1045	74	21A
0005433342076	1045	75	21D
0005433341484	1045	76	21B
0005433341661	1045	77	21E
0005433342254	1045	78	21G
0005433341971	1045	79	21H
0005433342294	1045	80	22A
0005435092041	1045	81	22D
0005433342057	1045	82	22H
0005433341917	1045	83	23A
0005433159278	1045	84	23F
0005433342079	1045	85	24A
0005433341731	1045	86	24E
0005433342056	1045	87	24D
0005433342081	1045	88	24F
0005433341664	1045	89	24G
0005433341566	1045	90	25E
0005433342338	1045	91	27A
0005433342175	1045	92	25F
0005433342486	1045	93	27F
0005433342103	1045	94	27G
0005435092042	1045	95	28A
0005433342193	1045	96	28B
0005435545720	1045	97	28F
0005433342024	1045	98	28H
0005433342439	1045	99	29D
0005433341719	1045	100	29B
0005434445241	1045	101	29E
0005435092043	1045	102	29H
0005435545722	1045	103	30B
0005433158095	1045	104	30D
0005435092038	1045	105	30E
0005433269661	1045	106	30G
0005433341974	1045	107	30H
0005433341938	1045	108	31E
0005433341790	1045	109	32A
0005433341807	1045	110	31H
0005433269641	1045	111	32B
0005433341861	1045	112	32D
0005433269662	1045	113	32F
0005434446513	1045	114	32G
0005433342046	1045	115	33A
0005433158106	1045	116	33B
0005433341900	1045	117	33D
0005433341630	1045	118	33F
0005433342438	1045	119	33H
0005435545718	1045	120	33G
0005433342194	1045	121	34E
0005433341605	1045	122	35D
0005433341693	1045	123	35F
0005433341577	1045	124	35E
0005433341469	1045	125	35G
0005433341810	1045	126	35H
0005433342096	1045	127	36B
0005433341826	1045	128	36A
0005433341537	1045	129	36E
0005433341485	1045	130	36D
0005432293201	1045	131	36H
0005433341720	1045	132	36G
0005435545717	1045	133	37A
0005433341871	1045	134	37B
0005433341855	1045	135	37E
0005433341619	1045	136	37D
0005433341969	1045	137	37H
0005435092036	1045	138	38D
0005433269640	1045	139	38B
0005433341691	1045	140	38E
0005433342011	1045	141	38F
0005433342462	1045	142	39D
0005433341550	1045	143	38H
0005433341414	1045	144	38G
0005433341730	1045	145	39E
0005433341634	1045	146	39F
0005433342721	17062	1	1B
0005433342710	17062	2	1C
0005433342730	17062	3	1H
0005433342791	17062	4	2C
0005433342787	17062	5	2H
0005433342739	17062	6	2G
0005433342802	17062	7	3C
0005433342751	17062	8	4B
0005433342705	17062	9	4A
0005433342768	17062	10	4F
0005433342745	17062	11	4C
0005433342742	17062	12	5A
0005433342717	17062	13	4H
0005433342723	17062	14	5B
0005433342736	17062	15	9A
0005433342763	17062	16	5H
0005433342738	17062	17	5G
0005435508200	17062	18	9G
0005433342767	17062	19	11A
0005435092016	17062	20	11B
0005433342804	17062	21	11F
0005433342750	17062	22	11H
0005433342780	17062	23	11G
0005433342778	17062	24	12A
0005433342770	17062	25	12D
0005433342703	17062	26	12B
0005433342772	17062	27	12E
0005433342775	17062	28	13A
0005433342792	17062	29	13D
0005433269700	17062	30	13E
0005433342803	17062	31	13G
0005433342735	17062	32	14A
0005433342756	17062	33	14B
0005433342707	17062	34	14E
0005433342733	17062	35	14F
0005433342771	17062	36	14H
0005433342711	17062	37	15E
0005433342795	17062	38	15F
0005435091941	17062	39	15H
0005433342741	17062	40	16E
0005433342704	17062	41	16F
0005433342719	17062	42	16H
0005433342757	17062	43	17A
0005433159304	17062	44	17G
0005433269699	17062	45	17H
0005433342788	17062	46	18A
0005433342713	17062	47	18D
0005433342790	17062	48	18E
0005435091960	17062	49	18F
0005435091969	17062	50	19B
0005433342754	17062	51	19A
0005433342765	17062	52	19F
0005433342725	17062	53	20A
0005433342758	17062	54	20D
0005433342744	17062	55	20B
0005433342715	17062	56	21D
0005433342728	17062	57	21B
0005433342743	17062	58	21G
0005433342762	17062	59	21F
0005433342726	17062	60	21H
0005433342801	17062	61	22B
0005433342794	17062	62	22A
0005433342755	17062	63	23B
0005433342714	17062	64	23D
0005433269701	17062	65	23F
0005433342781	17062	66	23G
0005433342793	17062	67	23H
0005433342747	17062	68	24B
0005433342784	17062	69	24E
0005433342776	17062	70	24D
0005435508206	17062	71	24G
0005433342785	17062	72	25D
0005433342796	17062	73	24H
0005433342708	17062	74	27E
0005433342798	17062	75	27D
0005433342769	17062	76	27F
0005433342782	17062	77	27H
0005433342722	17062	78	27G
0005433342727	17062	79	28A
0005435508205	17062	80	28E
0005435508207	17062	81	28H
0005433342764	17062	82	29A
0005433342799	17062	83	29F
0005435508203	17062	84	30D
0005433342732	17062	85	30F
0005433342752	17062	86	30E
0005433342731	17062	87	31A
0005433342759	17062	88	31D
0005435092017	17062	89	31E
0005433342749	17062	90	31G
0005435091942	17062	91	31H
0005433342718	17062	92	32B
0005435508210	17062	93	32E
0005433342706	17062	94	32D
0005433342760	17062	95	33A
0005433342709	17062	96	33B
0005433342746	17062	97	33E
0005433342777	17062	98	33G
0005433342766	17062	99	33F
0005433342702	17062	100	33H
0005433342786	17062	101	34D
0005433342712	17062	102	34E
0005433342800	17062	103	34G
0005433342716	17062	104	34H
0005433159305	17062	105	35B
0005433342789	17062	106	35A
0005433342748	17062	107	35D
0005433269702	17062	108	35F
0005433342729	17062	109	35E
0005433342797	17062	110	36D
0005433342737	17062	111	36F
0005433342761	17062	112	36G
0005433342779	17062	113	37A
0005433342783	17062	114	37B
0005433342773	17062	115	37D
0005433342734	17062	116	37F
0005433342724	17062	117	37H
0005433269698	17062	118	38B
0005433342753	17062	119	38E
0005433342720	17062	120	38F
0005435091961	17062	121	38H
0005435508180	17062	122	38G
0005433342740	17062	123	39D
0005433342774	17062	124	39F
0005435508199	17062	125	39E
0005432851899	18270	1	1C
0005432851906	18270	2	1D
0005432390007	18270	3	3C
0005432389979	18270	4	3A
0005432851885	18270	5	3D
0005432391945	18270	6	4A
0005432389992	18270	7	4D
0005432390009	18270	8	4C
0005432389990	18270	9	4F
0005432851894	18270	10	5C
0005432389962	18270	11	5D
0005432389942	18270	12	6D
0005432390004	18270	13	6B
0005432391963	18270	14	6E
0005432391958	18270	15	7A
0005432389998	18270	16	6F
0005432389999	18270	17	7C
0005432389989	18270	18	7B
0005432391949	18270	19	7E
0005432389953	18270	20	7D
0005432389958	18270	21	7F
0005432389964	18270	22	8B
0005432851901	18270	23	8D
0005432389948	18270	24	8C
0005432389987	18270	25	8F
0005432851904	18270	26	8E
0005432851905	18270	27	9A
0005432389944	18270	28	9C
0005432390051	18270	29	9B
0005432390003	18270	30	9E
0005432389959	18270	31	10A
0005432851887	18270	32	9F
0005432389982	18270	33	10C
0005432389994	18270	34	10B
0005432851890	18270	35	10E
0005432389981	18270	36	10D
0005432391955	18270	37	10F
0005432391948	18270	38	11B
0005432851886	18270	39	11A
0005432389997	18270	40	11D
0005432390010	18270	41	11C
0005432389965	18270	42	11E
0005432391954	18270	43	12C
0005432851895	18270	44	12B
0005432851902	18270	45	12F
0005432390026	18270	46	12E
0005432851896	18270	47	12D
0005432389985	18270	48	13C
0005432389966	18270	49	13E
0005432389970	18270	50	13F
0005432851891	18270	51	14B
0005432389988	18270	52	14D
0005432851884	18270	53	14F
0005432851883	18270	54	15B
0005432390025	18270	55	15D
0005432391952	18270	56	15C
0005432389995	18270	57	15E
0005432389949	18270	58	16A
0005432389986	18270	59	15F
0005432389996	18270	60	16B
0005432390029	18270	61	16D
0005432851893	18270	62	17A
0005432391961	18270	63	16F
0005432391964	18270	64	17B
0005432851897	18270	65	17D
0005432389938	18270	66	17E
0005432389983	18270	67	18A
0005432390002	18270	68	17F
0005432851889	18270	69	18D
0005432389957	18270	70	18C
0005432851903	18270	71	18F
0005432389967	18270	72	19C
0005432391953	18270	73	19B
0005432390006	18270	74	19D
0005432389969	18270	75	20A
0005432851888	18270	76	19F
0005432389956	18270	77	19E
0005432851898	18270	78	20B
0005432389993	18270	79	20C
0005432391957	18270	80	20F
0005432390008	18270	81	20E
0005432851892	18270	82	21B
0005432391962	18270	83	21E
0005432851900	18270	84	21D
0005434066528	12778	1	1A
0005434066804	12778	2	1C
0005434066460	12778	3	2A
0005432159842	12778	4	1F
0005434066637	12778	5	2C
0005434081547	12778	6	2D
0005434066737	12778	7	3A
0005434066663	12778	8	2F
0005434066544	12778	9	3D
0005433989715	12778	10	3F
0005432433660	12778	11	4B
0005434081673	12778	12	4D
0005434081624	12778	13	4C
0005433812893	12778	14	4E
0005434066809	12778	15	4F
0005432161144	12778	16	5A
0005434081528	12778	17	5C
0005434066654	12778	18	5B
0005434066645	12778	19	5D
0005434081546	12778	20	5E
0005434066861	12778	21	5F
0005432433659	12778	22	6B
0005434066732	12778	23	6A
0005434066774	12778	24	6C
0005434066543	12778	25	6D
0005434081556	12778	26	7B
0005434066842	12778	27	7A
0005432161145	12778	28	7C
0005434066671	12778	29	7D
0005434066733	12778	30	7F
0005434066338	12778	31	7E
0005434066662	12778	32	8C
0005434066367	12778	33	8E
0005432433662	12778	34	8D
0005434081552	12778	35	8F
0005434066966	12778	36	9A
0005434066325	12778	37	9B
0005434066426	12778	38	9C
0005434066808	12778	39	9E
0005433989710	12778	40	9D
0005434066849	12778	41	9F
0005434081588	12778	42	10B
0005434066516	12778	43	10D
0005434066670	12778	44	10C
0005432433663	12778	45	10E
0005434066725	12778	46	11A
0005434066499	12778	47	11B
0005434066721	12778	48	11D
0005434066740	12778	49	11C
0005434066859	12778	50	11F
0005434066395	12778	51	11E
0005434081625	12778	52	12B
0005434066476	12778	53	12D
0005434066529	12778	54	12C
0005434066542	12778	55	12E
0005432433664	12778	56	13A
0005434066683	12778	57	12F
0005434066757	12778	58	13B
0005434081488	12778	59	13D
0005434066722	12778	60	13C
0005434066329	12778	61	13E
0005434066677	12778	62	13F
0005432159844	12778	63	14B
0005434066647	12778	64	14A
0005434081644	12778	65	14D
0005434066583	12778	66	14C
0005434066648	12778	67	14E
0005434066634	12778	68	15A
0005434081522	12778	69	14F
0005434066930	12778	70	15C
0005434066515	12778	71	15B
0005434066498	12778	72	15E
0005434066711	12778	73	15D
0005434066467	12778	74	15F
0005434066805	12778	75	16A
0005434066633	12778	76	16B
0005434066576	12778	77	16C
0005434066646	12778	78	16D
0005434066776	12778	79	16E
0005432433661	12778	80	17A
0005434081589	12778	81	16F
0005434066744	12778	82	17C
0005434066459	12778	83	17D
0005434066474	12778	84	17E
0005434066775	12778	85	18A
0005434066700	12778	86	17F
0005434066758	12778	87	18B
0005434026673	12778	88	18C
0005434066497	12778	89	18D
0005434066745	12778	90	19A
0005433989701	12778	91	18F
0005434066952	12778	92	19C
0005434081617	12778	93	19B
0005434066743	12778	94	19D
0005433989699	12778	95	19E
0005432159841	12778	96	19F
0005434066684	12778	97	20A
0005432433665	12778	98	20C
0005434066753	12778	99	20B
0005434081618	12778	100	20E
0005434066860	12778	101	21A
0005434066752	12778	102	20F
0005434066756	12778	103	21B
0005434066736	12778	104	21E
0005434066850	12778	105	21F
0005434066364	12778	106	22B
0005434066577	12778	107	22A
0005432159843	12778	108	22C
0005434066575	12778	109	22F
0005434081600	12778	110	22E
0005434081523	12778	111	23A
0005433812892	12778	112	23C
0005434081586	12778	113	23D
0005434081587	12778	114	23F
0005434067306	30649	1	1A
0005434081804	30649	2	1C
0005434067263	30649	3	1D
0005432186854	30649	4	2A
0005434067241	30649	5	1F
0005434067285	30649	6	2C
0005434067250	30649	7	2D
0005434067297	30649	8	3D
0005434081805	30649	9	3F
0005434067242	30649	10	4B
0005434081806	30649	11	4A
0005434067272	30649	12	4C
0005434067277	30649	13	4F
0005434081816	30649	14	5B
0005434081794	30649	15	5A
0005434067255	30649	16	5C
0005434067298	30649	17	5D
0005434067269	30649	18	5E
0005434067264	30649	19	6A
0005434081807	30649	20	5F
0005434081818	30649	21	6C
0005434081808	30649	22	6B
0005432150165	30649	23	6D
0005434067244	30649	24	6E
0005432186852	30649	25	6F
0005434067248	30649	26	7B
0005432150160	30649	27	7A
0005434081799	30649	28	7D
0005434067290	30649	29	7C
0005434067275	30649	30	7E
0005434067247	30649	31	7F
0005434067309	30649	32	8A
0005434081801	30649	33	8B
0005434067257	30649	34	8D
0005434067303	30649	35	8C
0005434067270	30649	36	8F
0005434067261	30649	37	9A
0005434067295	30649	38	9C
0005434081815	30649	39	9E
0005432433640	30649	40	9D
0005434081803	30649	41	9F
0005434067249	30649	42	10B
0005434081812	30649	43	10D
0005434067308	30649	44	10C
0005434067293	30649	45	10E
0005433989753	30649	46	11A
0005432150159	30649	47	11B
0005434067305	30649	48	11D
0005432150164	30649	49	11C
0005434067296	30649	50	11E
0005434067278	30649	51	11F
0005434067258	30649	52	12B
0005434067256	30649	53	12A
0005434067271	30649	54	12D
0005434067291	30649	55	12C
0005434067273	30649	56	12E
0005434067254	30649	57	12F
0005433989752	30649	58	13B
0005432150162	30649	59	13A
0005434067300	30649	60	13C
0005434067284	30649	61	13D
0005432186853	30649	62	13E
0005434067253	30649	63	14A
0005432186855	30649	64	13F
0005434081790	30649	65	14B
0005434067267	30649	66	14C
0005434067301	30649	67	14D
0005434081798	30649	68	14E
0005434067302	30649	69	15A
0005434067251	30649	70	14F
0005434067283	30649	71	15B
0005434067260	30649	72	15C
0005434067292	30649	73	15E
0005434067279	30649	74	15F
0005434067286	30649	75	16B
0005432150163	30649	76	16A
0005434081810	30649	77	16C
0005434067268	30649	78	16E
0005434067246	30649	79	17A
0005434067245	30649	80	17B
0005434067307	30649	81	17C
0005434081795	30649	82	17D
0005434081802	30649	83	17E
0005434081813	30649	84	18A
0005433989751	30649	85	17F
0005434067266	30649	86	18B
0005434081809	30649	87	18E
0005434081792	30649	88	18D
0005434067280	30649	89	18F
0005434081811	30649	90	19A
0005434081817	30649	91	19B
0005434067287	30649	92	19C
0005434067299	30649	93	19E
0005434067304	30649	94	19D
0005434067239	30649	95	19F
0005434067240	30649	96	20B
0005434067262	30649	97	20A
0005434081793	30649	98	20C
0005434067252	30649	99	20D
0005433989754	30649	100	20E
0005434081797	30649	101	20F
0005434081800	30649	102	21A
0005434067265	30649	103	21B
0005434067276	30649	104	21D
0005434081791	30649	105	21C
0005434067259	30649	106	21E
0005434067310	30649	107	21F
0005433989750	30649	108	22A
0005434067289	30649	109	22C
0005434081814	30649	110	22B
0005434067274	30649	111	22E
0005434067288	30649	112	22D
0005434067282	30649	113	22F
0005434081796	30649	114	23B
0005434067243	30649	115	23C
0005434067281	30649	116	23D
0005434067294	30649	117	23F
0005432150161	30649	118	23E
0005433689887	19362	1	2A
0005433686614	19362	2	4C
0005433689888	19362	3	5A
0005433689876	19362	4	18D
0005433686609	19362	5	19C
0005432140420	5492	1	1F
0005435722046	5492	2	1C
0005433527257	5492	3	1H
0005435461989	5492	4	1G
0005435725579	5492	5	2C
0005435766033	5492	6	2B
0005434264913	5492	7	2G
0005432140423	5492	8	2F
0005435766046	5492	9	3C
0005435766063	5492	10	3B
0005435735122	5492	11	3A
0005435766038	5492	12	3G
0005435766029	5492	13	3F
0005435461957	5492	14	3H
0005434264840	5492	15	4B
0005434264872	5492	16	4F
0005435461875	5492	17	4C
0005435766064	5492	18	4G
0005435766044	5492	19	5A
0005435766024	5492	20	4H
0005434264850	5492	21	5F
0005432140417	5492	22	5H
0005435462026	5492	23	9A
0005435766032	5492	24	9G
0005433527259	5492	25	11A
0005435461876	5492	26	9H
0005435766052	5492	27	11B
0005434831080	5492	28	11E
0005435766040	5492	29	11D
0005435766020	5492	30	11F
0005435766048	5492	31	11G
0005434264849	5492	32	12B
0005434264858	5492	33	12A
0005434264757	5492	34	12D
0005435766059	5492	35	12E
0005434264887	5492	36	12H
0005434831106	5492	37	13A
0005435766067	5492	38	13D
0005435462058	5492	39	13B
0005435461805	5492	40	13E
0005435766071	5492	41	13H
0005433529265	5492	42	14B
0005435766016	5492	43	14A
0005435725578	5492	44	14E
0005435766013	5492	45	14D
0005435462001	5492	46	14F
0005433529267	5492	47	14H
0005434264798	5492	48	14G
0005434264727	5492	49	15B
0005434264873	5492	50	15E
0005432140419	5492	51	15F
0005432140418	5492	52	15H
0005434831081	5492	53	16A
0005435766066	5492	54	16D
0005435725580	5492	55	16G
0005435462059	5492	56	16F
0005432535773	5492	57	16H
0005435735120	5492	58	17B
0005435766050	5492	59	17A
0005432535772	5492	60	17D
0005435766049	5492	61	17E
0005435461954	5492	62	17F
0005435462042	5492	63	17H
0005435461963	5492	64	17G
0005435461960	5492	65	18B
0005435462043	5492	66	18A
0005435766023	5492	67	18D
0005435766045	5492	68	18F
0005434264782	5492	69	18E
0005435766035	5492	70	18G
0005435461988	5492	71	18H
0005434264792	5492	72	19B
0005433527254	5492	73	19A
0005434264856	5492	74	19E
0005433527256	5492	75	19D
0005435462197	5492	76	19G
0005435766027	5492	77	20A
0005435461831	5492	78	20D
0005434264912	5492	79	20B
0005435461877	5492	80	20F
0005435766018	5492	81	20G
0005435766056	5492	82	20H
0005435766015	5492	83	21B
0005435766014	5492	84	21D
0005435766065	5492	85	21G
0005435461874	5492	86	21F
0005435766037	5492	87	22B
0005435462025	5492	88	22A
0005434831113	5492	89	22D
0005435462050	5492	90	22E
0005435766061	5492	91	22H
0005432140416	5492	92	23A
0005435461864	5492	93	23D
0005435766042	5492	94	23F
0005435043275	5492	95	23E
0005432535780	5492	96	23G
0005435723038	5492	97	24B
0005435766026	5492	98	24D
0005435766025	5492	99	24F
0005435766031	5492	100	24H
0005435766034	5492	101	25E
0005435766070	5492	102	25D
0005432140424	5492	103	25F
0005433527258	5492	104	27B
0005435461900	5492	105	27E
0005435735121	5492	106	27D
0005435766009	5492	107	27F
0005435766041	5492	108	28A
0005435462053	5492	109	27H
0005435461911	5492	110	28D
0005432140421	5492	111	28B
0005435766062	5492	112	28E
0005435766051	5492	113	28G
0005435766039	5492	114	29A
0005435462017	5492	115	29E
0005435725582	5492	116	29D
0005434264857	5492	117	29F
0005435766012	5492	118	29H
0005435766069	5492	119	30A
0005435722048	5492	120	30B
0005435766017	5492	121	30F
0005435766055	5492	122	30G
0005435766030	5492	123	30H
0005435766060	5492	124	31A
0005435766021	5492	125	31E
0005435766058	5492	126	31D
0005435722047	5492	127	31B
0005432140422	5492	128	31F
0005432535758	5492	129	31G
0005435461932	5492	130	31H
0005434264861	5492	131	32E
0005435461894	5492	132	32D
0005435461991	5492	133	32F
0005434264941	5492	134	32H
0005435766028	5492	135	33F
0005433527255	5492	136	33H
0005435735124	5492	137	33G
0005435766008	5492	138	34B
0005435766043	5492	139	34D
0005435766036	5492	140	34E
0005435766022	5492	141	34G
0005435461945	5492	142	34F
0005435462045	5492	143	34H
0005435461955	5492	144	35B
0005435766019	5492	145	35A
0005435462110	5492	146	35D
0005435766047	5492	147	35E
0005435766072	5492	148	35G
0005435461944	5492	149	35F
0005435723037	5492	150	35H
0005434264848	5492	151	36B
0005435766053	5492	152	36E
0005435766057	5492	153	36D
0005435461899	5492	154	36H
0005435766054	5492	155	36G
0005433529268	5492	156	37A
0005435735123	5492	157	37D
0005435725581	5492	158	37B
0005434264893	5492	159	37E
0005434264839	5492	160	37F
0005435766010	5492	161	38A
0005434264758	5492	162	38D
0005435461832	5492	163	38B
0005435461846	5492	164	38F
0005433529266	5492	165	38E
0005435766068	5492	166	38G
0005432535774	5492	167	38H
0005435766011	5492	168	39E
0005434264875	5492	169	39D
0005435461870	5492	170	39F
0005435735078	13491	1	1A
0005435462303	13491	2	1B
0005435462316	13491	3	1F
0005435765474	13491	4	1C
0005435765296	13491	5	1G
0005434265050	13491	6	2A
0005432194496	13491	7	2B
0005434265069	13491	8	2F
0005435462332	13491	9	2C
0005435765563	13491	10	2H
0005435765306	13491	11	2G
0005435765612	13491	12	3A
0005435765613	13491	13	3B
0005434265048	13491	14	3F
0005434265067	13491	15	3H
0005434831134	13491	16	3G
0005435765626	13491	17	4A
0005434265062	13491	18	4F
0005435765358	13491	19	4C
0005435043284	13491	20	4G
0005434265072	13491	21	4H
0005435765680	13491	22	5B
0005435462297	13491	23	5A
0005435725546	13491	24	5C
0005434265058	13491	25	5G
0005435765426	13491	26	5F
0005435462311	13491	27	9B
0005435462319	13491	28	9G
0005435725526	13491	29	11A
0005434831135	13491	30	9H
0005434265046	13491	31	11B
0005435735069	13491	32	11E
0005435462325	13491	33	11D
0005435462307	13491	34	11F
0005435765472	13491	35	11H
0005434265055	13491	36	11G
0005434265060	13491	37	12A
0005435765450	13491	38	12B
0005435765401	13491	39	12F
0005435765260	13491	40	12D
0005435765653	13491	41	12G
0005434265051	13491	42	13B
0005435765291	13491	43	13G
0005435462328	13491	44	14B
0005434831138	13491	45	14A
0005435765339	13491	46	14D
0005435765505	13491	47	14F
0005435765354	13491	48	14E
0005434265063	13491	49	14G
0005435462298	13491	50	15A
0005435765504	13491	51	15B
0005435765471	13491	52	15E
0005434831137	13491	53	15H
0005435765387	13491	54	15G
0005435462318	13491	55	16A
0005435765386	13491	56	16B
0005435462309	13491	57	16E
0005434265064	13491	58	16F
0005435722014	13491	59	16H
0005434265070	13491	60	16G
0005435462323	13491	61	17B
0005435462333	13491	62	17A
0005435723013	13491	63	17E
0005435723028	13491	64	17G
0005434265066	13491	65	17F
0005435765485	13491	66	17H
0005435765402	13491	67	18D
0005435462324	13491	68	18B
0005435765753	13491	69	18E
0005435765353	13491	70	18G
0005435765625	13491	71	19B
0005435765729	13491	72	19D
0005435765524	13491	73	19F
0005434265045	13491	74	19E
0005435462315	13491	75	20A
0005435765307	13491	76	19H
0005435765425	13491	77	20D
0005435765581	13491	78	20B
0005435765796	13491	79	20E
0005435765585	13491	80	20H
0005435462331	13491	81	21A
0005435735068	13491	82	21F
0005435462329	13491	83	21D
0005435723029	13491	84	21H
0005435462299	13491	85	22A
0005435765437	13491	86	22D
0005435765196	13491	87	22B
0005435462321	13491	88	22G
0005434265052	13491	89	22F
0005434265047	13491	90	22H
0005435765681	13491	91	23B
0005435765486	13491	92	23E
0005435765627	13491	93	23D
0005435735091	13491	94	23F
0005435765442	13491	95	23H
0005435765439	13491	96	24B
0005432535821	13491	97	24D
0005435765487	13491	98	24F
0005435725525	13491	99	24E
0005435765511	13491	100	24G
0005435462300	13491	101	25D
0005435462330	13491	102	25E
0005435765197	13491	103	25F
0005435462327	13491	104	27B
0005434265059	13491	105	27A
0005435720122	13491	106	27D
0005434265053	13491	107	27H
0005435765599	13491	108	27G
0005432194497	13491	109	28A
0005434265071	13491	110	28B
0005434265065	13491	111	28E
0005435462308	13491	112	28D
0005435462302	13491	113	28F
0005435765407	13491	114	28H
0005432535819	13491	115	28G
0005435765438	13491	116	29A
0005435462317	13491	117	29D
0005435765577	13491	118	29B
0005435462313	13491	119	29E
0005435765453	13491	120	29F
0005432535820	13491	121	29H
0005435765441	13491	122	30B
0005435462320	13491	123	30A
0005435735076	13491	124	30G
0005435462310	13491	125	31A
0005435462335	13491	126	31B
0005435765575	13491	127	31E
0005435720123	13491	128	31D
0005435765589	13491	129	31F
0005435765338	13491	130	32A
0005435765357	13491	131	31H
0005432194498	13491	132	32B
0005435765418	13491	133	32F
0005435462304	13491	134	32E
0005435462301	13491	135	32H
0005435765388	13491	136	32G
0005434265049	13491	137	33B
0005435725545	13491	138	33F
0005435462312	13491	139	33G
0005435765403	13491	140	34A
0005432194495	13491	141	34B
0005435765728	13491	142	34G
0005435765582	13491	143	34F
0005435765309	13491	144	34H
0005432535817	13491	145	35A
0005434265061	13491	146	35D
0005435765576	13491	147	35E
0005435765652	13491	148	35G
0005435462305	13491	149	36B
0005434265057	13491	150	36A
0005435735101	13491	151	36E
0005435462334	13491	152	36D
0005435765580	13491	153	36F
0005435735075	13491	154	36G
0005435765752	13491	155	37A
0005435765421	13491	156	37E
0005434265054	13491	157	37D
0005435765492	13491	158	37F
0005434265056	13491	159	37H
0005435462314	13491	160	38A
0005434265068	13491	161	38D
0005432535818	13491	162	38B
0005435725522	13491	163	38E
0005435462306	13491	164	38G
0005434831136	13491	165	38H
0005435462322	13491	166	39E
0005435462326	13491	167	39F
0005434602869	18748	1	4B
0005434602868	18748	2	5A
0005434514957	18677	1	1A
0005434604857	18677	2	3A
0005434514958	18677	3	3B
0005434604858	18677	4	4A
0005434513569	18677	5	4B
0005434513570	18677	6	5A
0005434604856	18677	7	5B
0005434602888	19107	1	1A
0005434602887	19107	2	1B
0005434602892	19107	3	2A
0005434602886	19107	4	2B
0005434602891	19107	5	3B
0005434603019	19107	6	4A
0005434602889	19107	7	4B
0005434602893	19107	8	5A
0005434602890	19107	9	6A
0005434603020	19107	10	6B
0005432649321	25087	1	1A
0005435844305	25087	2	1D
0005435844302	25087	3	2A
0005435846237	25087	4	2F
0005435844308	25087	5	3F
0005432649311	25087	6	4A
0005432649340	25087	7	4F
0005432649316	25087	8	5A
0005432632654	25087	9	5D
0005432649331	25087	10	5E
0005435844303	25087	11	5F
0005435844309	25087	12	6C
0005432632637	25087	13	7A
0005435846239	25087	14	7C
0005432649341	25087	15	7D
0005435844301	25087	16	7E
0005435846242	25087	17	7F
0005435844304	25087	18	8A
0005432649324	25087	19	8E
0005432632625	25087	20	8F
0005435844306	25087	21	9F
0005432649317	25087	22	10A
0005435846241	25087	23	10D
0005432632638	25087	24	10F
0005432632628	25087	25	11A
0005432649339	25087	26	11C
0005432632646	25087	27	11D
0005432632626	25087	28	11F
0005435844299	25087	29	12A
0005435846243	25087	30	12C
0005432649313	25087	31	12D
0005435846236	25087	32	12E
0005432632645	25087	33	13A
0005435844311	25087	34	13C
0005432649314	25087	35	13D
0005432649318	25087	36	13F
0005432632621	25087	37	14A
0005432632639	25087	38	14C
0005435846240	25087	39	14D
0005435844312	25087	40	14F
0005432649336	25087	41	15E
0005432649332	25087	42	15F
0005432632653	25087	43	16C
0005432649312	25087	44	16E
0005432632622	25087	45	16F
0005435844300	25087	46	17D
0005435844310	25087	47	17E
0005432632630	25087	48	17F
0005432649315	25087	49	18A
0005432649322	25087	50	18C
0005435846238	25087	51	18D
0005432649329	25087	52	18E
0005432649325	25087	53	19C
0005435844307	25087	54	19D
0005432632642	25087	55	20A
0005432649309	25087	56	20E
0005432649343	25087	57	20F
0005433284958	1793	1	1A
0005433284961	1793	2	1C
0005433008186	1793	3	1D
0005433008102	1793	4	1F
0005433008103	1793	5	2A
0005433284950	1793	6	2C
0005433008234	1793	7	2D
0005433284947	1793	8	2F
0005432295872	1793	9	3A
0005433008092	1793	10	3D
0005433008015	1793	11	3F
0005433008138	1793	12	4A
0005433810530	1793	13	4D
0005433008136	1793	14	4E
0005433008117	1793	15	5D
0005433008004	1793	16	5E
0005433285014	1793	17	6A
0005433284866	1793	18	6C
0005433008224	1793	19	6D
0005433284914	1793	20	6E
0005433284967	1793	21	6F
0005433008145	1793	22	7A
0005433008005	1793	23	7D
0005433008140	1793	24	8A
0005433008139	1793	25	8C
0005433284949	1793	26	8D
0005433284930	1793	27	8E
0005433008021	1793	28	8F
0005433284781	1793	29	9A
0005433008183	1793	30	9C
0005433008078	1793	31	9D
0005433008087	1793	32	9E
0005433008091	1793	33	9F
0005433285003	1793	34	10A
0005433284925	1793	35	10D
0005433284966	1793	36	10E
0005433008211	1793	37	11A
0005433008100	1793	38	11D
0005433284945	1793	39	11E
0005433285061	1793	40	11F
0005433008024	1793	41	12A
0005433008014	1793	42	12C
0005433008210	1793	43	12D
0005433810533	1793	44	12E
0005433008123	1793	45	12F
0005433810529	1793	46	13A
0005433285036	1793	47	13C
0005433008134	1793	48	13D
0005433284923	1793	49	13E
0005433008141	1793	50	13F
0005433810531	1793	51	14A
0005433008217	1793	52	14C
0005432295870	1793	53	14D
0005433008242	1793	54	14F
0005433284933	1793	55	15A
0005433284924	1793	56	15C
0005433285060	1793	57	15D
0005433008219	1793	58	15E
0005433008184	1793	59	15F
0005433285030	1793	60	16A
0005433284780	1793	61	16C
0005433285035	1793	62	16E
0005433285062	1793	63	16F
0005433008101	1793	64	17A
0005433008203	1793	65	17C
0005433284946	1793	66	17D
0005433810532	1793	67	17E
0005432295871	1793	68	17F
0005433008135	1793	69	18A
0005433008104	1793	70	18C
0005433008124	1793	71	18D
0005433008003	1793	72	18E
0005433008002	1793	73	18F
0005433008146	1793	74	19A
0005433284944	1793	75	19D
0005433285015	1793	76	19E
0005433008055	1793	77	20A
0005433008233	1793	78	20C
0005433810534	1793	79	20E
0005433285197	22564	1	1A
0005433008462	22564	2	1C
0005433008451	22564	3	1D
0005433008439	22564	4	1F
0005433285192	22564	5	2A
0005433285169	22564	6	2C
0005433008443	22564	7	2D
0005433285196	22564	8	3A
0005433008435	22564	9	3D
0005433008463	22564	10	3F
0005433008446	22564	11	4A
0005433008442	22564	12	4C
0005433008425	22564	13	4E
0005433285187	22564	14	4F
0005433285167	22564	15	5A
0005433008426	22564	16	5C
0005433008458	22564	17	5D
0005433285168	22564	18	5F
0005433008471	22564	19	6A
0005433008445	22564	20	6D
0005433285182	22564	21	6E
0005433285191	22564	22	6F
0005433008434	22564	23	7A
0005433285198	22564	24	7C
0005433008448	22564	25	7D
0005433285177	22564	26	7E
0005433008438	22564	27	7F
0005433008457	22564	28	8A
0005433008456	22564	29	8C
0005433008440	22564	30	8D
0005433008436	22564	31	8E
0005433285180	22564	32	9A
0005433008450	22564	33	9C
0005433285178	22564	34	9D
0005433285189	22564	35	9E
0005433008464	22564	36	9F
0005433285183	22564	37	10A
0005433810493	22564	38	10D
0005433285181	22564	39	10E
0005433008444	22564	40	10F
0005433285190	22564	41	11A
0005433285194	22564	42	11C
0005433008431	22564	43	11F
0005433285170	22564	44	12A
0005433285172	22564	45	12C
0005433008430	22564	46	12D
0005433285186	22564	47	12E
0005433008452	22564	48	12F
0005433008437	22564	49	13A
0005433810489	22564	50	13D
0005433008469	22564	51	13E
0005433008429	22564	52	13F
0005433008433	22564	53	14A
0005433008449	22564	54	14C
0005433285171	22564	55	14D
0005433285195	22564	56	14E
0005433008466	22564	57	15A
0005433008468	22564	58	14F
0005433285173	22564	59	15C
0005433285174	22564	60	15D
0005433008460	22564	61	15F
0005433008454	22564	62	16A
0005433285184	22564	63	16C
0005433008447	22564	64	16D
0005433008467	22564	65	16F
0005433285179	22564	66	17C
0005433008432	22564	67	17D
0005433285188	22564	68	17E
0005433285175	22564	69	17F
0005433285185	22564	70	18D
0005433008427	22564	71	18F
0005433008461	22564	72	19A
0005433285193	22564	73	19C
0005433008455	22564	74	19D
0005433008470	22564	75	19E
0005433008441	22564	76	19F
0005433008465	22564	77	20A
0005433008459	22564	78	20C
0005433285176	22564	79	20D
0005433008453	22564	80	20E
0005433008428	22564	81	20F
0005432756829	25346	1	1A
0005434152752	25346	2	1D
0005432756826	25346	3	1F
0005432755063	25346	4	3C
0005434153517	25346	5	3D
0005432755051	25346	6	4D
0005434153515	25346	7	4F
0005434152771	25346	8	5C
0005432756827	25346	9	5F
0005432756834	25346	10	6E
0005432755059	25346	11	6F
0005432755060	25346	12	7C
0005432756832	25346	13	7F
0005432755057	25346	14	8A
0005432755058	25346	15	8D
0005432756830	25346	16	9C
0005432756822	25346	17	9D
0005432755062	25346	18	9F
0005432756824	25346	19	11D
0005432755054	25346	20	12A
0005432756821	25346	21	12E
0005432755052	25346	22	12F
0005434153526	25346	23	13D
0005434152754	25346	24	13E
0005432755056	25346	25	14C
0005434152753	25346	26	15D
0005434152759	25346	27	15F
0005432756825	25346	28	16E
0005432756828	25346	29	16F
0005434152765	25346	30	17C
0005432755049	25346	31	17F
0005432756831	25346	32	18A
0005432755055	25346	33	18C
0005434152751	25346	34	18D
0005434152758	25346	35	18E
0005432755053	25346	36	19F
0005432755061	25346	37	20A
0005432755050	25346	38	20C
0005432756823	25346	39	20D
0005432756833	25346	40	20E
0005433846548	5574	1	1C
0005433846534	5574	2	1A
0005432081489	5574	3	1F
0005433846537	5574	4	1D
0005433846518	5574	5	2C
0005433846539	5574	6	2A
0005433846555	5574	7	3A
0005433846500	5574	8	3D
0005433846535	5574	9	3C
0005433815369	5574	10	4A
0005433846501	5574	11	3F
0005433846558	5574	12	4C
0005434173468	5574	13	5A
0005433846503	5574	14	4D
0005433846551	5574	15	5C
0005435282303	5574	16	5F
0005432081490	5574	17	5D
0005435282290	5574	18	6B
0005433846510	5574	19	6A
0005433846516	5574	20	6E
0005433846532	5574	21	6D
0005433846521	5574	22	7A
0005433846526	5574	23	6F
0005433846517	5574	24	7C
0005434173480	5574	25	7B
0005433846547	5574	26	7E
0005434173457	5574	27	7D
0005433846550	5574	28	8A
0005433846506	5574	29	8B
0005433846524	5574	30	8D
0005435282137	5574	31	8C
0005433846515	5574	32	8F
0005434173469	5574	33	8E
0005435282206	5574	34	9B
0005433846540	5574	35	9A
0005433815366	5574	36	9C
0005433846504	5574	37	9E
0005433815368	5574	38	9D
0005435282273	5574	39	10A
0005435282279	5574	40	9F
0005435282150	5574	41	10C
0005432081492	5574	42	10E
0005435282178	5574	43	11A
0005433815364	5574	44	10F
0005432081488	5574	45	11B
0005435282136	5574	46	11C
0005432081491	5574	47	11F
0005433846559	5574	48	11E
0005433846523	5574	49	12B
0005433846511	5574	50	12A
0005433846507	5574	51	12C
0005435282199	5574	52	12E
0005435282135	5574	53	12D
0005433815365	5574	54	13B
0005433846546	5574	55	13A
0005433846525	5574	56	12F
0005433815367	5574	57	13C
0005433846543	5574	58	13E
0005433846553	5574	59	13D
0005433846552	5574	60	13F
0005435282139	5574	61	14B
0005433846522	5574	62	14A
0005433846536	5574	63	14D
0005433846512	5574	64	14C
0005433846545	5574	65	14E
0005433846502	5574	66	15B
0005435282245	5574	67	15A
0005433846531	5574	68	15D
0005433846554	5574	69	15C
0005433846529	5574	70	15F
0005435282265	5574	71	15E
0005435282227	5574	72	16A
0005435282272	5574	73	16C
0005435282207	5574	74	16B
0005433846557	5574	75	16E
0005433846527	5574	76	16D
0005435282302	5574	77	17B
0005433846505	5574	78	17A
0005435282177	5574	79	17D
0005433846542	5574	80	17C
0005433846508	5574	81	17F
0005433846520	5574	82	17E
0005433846530	5574	83	18B
0005433846519	5574	84	18A
0005435282214	5574	85	18D
0005435282198	5574	86	19A
0005433846513	5574	87	18F
0005433846549	5574	88	19D
0005432081487	5574	89	19C
0005433846514	5574	90	19F
0005433846538	5574	91	20A
0005433846528	5574	92	20D
0005435282162	5574	93	20C
0005435282247	5574	94	20E
0005433846556	5574	95	21B
0005433846533	5574	96	21A
0005433846509	5574	97	20F
0005433846541	5574	98	21C
0005435282289	5574	99	21D
0005433846544	5574	100	21F
0005433845917	13875	1	1C
0005433846027	13875	2	1A
0005432003690	13875	3	1D
0005433845932	13875	4	2C
0005435282428	13875	5	2A
0005432003691	13875	6	1F
0005433846011	13875	7	2D
0005433846119	13875	8	3A
0005435282448	13875	9	2F
0005433846176	13875	10	3D
0005435282425	13875	11	3C
0005435282432	13875	12	4A
0005435282436	13875	13	3F
0005433846044	13875	14	4C
0005433815346	13875	15	5A
0005434173506	13875	16	4F
0005433846037	13875	17	5C
0005433845905	13875	18	5F
0005433845962	13875	19	5D
0005433846082	13875	20	6A
0005433845948	13875	21	6D
0005435282434	13875	22	6B
0005433846068	13875	23	6E
0005433845690	13875	24	7A
0005435282422	13875	25	6F
0005433846178	13875	26	7C
0005433846015	13875	27	7B
0005433845844	13875	28	7E
0005433845936	13875	29	7F
0005433846247	13875	30	8B
0005433845684	13875	31	8A
0005433846071	13875	32	8C
0005433845887	13875	33	8F
0005434173508	13875	34	8E
0005433845691	13875	35	9B
0005435282423	13875	36	9C
0005433845933	13875	37	9F
0005433845692	13875	38	9E
0005435282444	13875	39	9D
0005435282438	13875	40	10A
0005433845913	13875	41	10C
0005435282435	13875	42	10B
0005433846061	13875	43	10E
0005433845682	13875	44	10D
0005433845906	13875	45	10F
0005433845717	13875	46	11C
0005435282443	13875	47	11A
0005435282442	13875	48	11D
0005432003692	13875	49	11F
0005433846146	13875	50	11E
0005435282433	13875	51	12D
0005433846159	13875	52	12C
0005435282431	13875	53	12B
0005433846050	13875	54	12E
0005433846103	13875	55	13A
0005433845843	13875	56	12F
0005435282427	13875	57	13C
0005433846194	13875	58	13B
0005435282445	13875	59	13E
0005435282447	13875	60	13D
0005435282437	13875	61	13F
0005433846235	13875	62	14B
0005433845773	13875	63	14A
0005433846239	13875	64	14E
0005433845940	13875	65	14D
0005433846120	13875	66	14C
0005433845888	13875	67	14F
0005433845716	13875	68	15B
0005435282426	13875	69	15A
0005435282429	13875	70	15D
0005433815345	13875	71	15C
0005435282439	13875	72	15F
0005433846229	13875	73	15E
0005434173507	13875	74	16B
0005434173509	13875	75	16A
0005433846069	13875	76	16C
0005435282421	13875	77	16E
0005433846099	13875	78	16D
0005433846287	13875	79	16F
0005433845693	13875	80	17B
0005433846046	13875	81	17C
0005433845968	13875	82	17F
0005435282446	13875	83	17E
0005435282430	13875	84	18A
0005433846079	13875	85	18C
0005433846177	13875	86	18B
0005433845799	13875	87	18E
0005433846195	13875	88	19A
0005433846023	13875	89	18F
0005433846126	13875	90	19C
0005433846038	13875	91	19B
0005433846045	13875	92	19D
0005433846127	13875	93	19F
0005433845685	13875	94	19E
0005433845964	13875	95	20C
0005433846145	13875	96	20B
0005433846016	13875	97	20A
0005435282440	13875	98	20F
0005433846197	13875	99	20E
0005433846196	13875	100	20D
0005433845886	13875	101	21A
0005433846062	13875	102	21C
0005433846028	13875	103	21E
0005435282441	13875	104	21D
0005435282424	13875	105	21F
0005435332260	7837	1	1A
0005435332231	7837	2	1B
0005432112507	7837	3	1C
0005434620533	7837	4	1D
0005434620520	7837	5	2A
0005434620517	7837	6	2D
0005434620537	7837	7	2C
0005434620518	7837	8	3C
0005434620523	7837	9	3D
0005434620528	7837	10	4A
0005434620535	7837	11	4B
0005434620524	7837	12	4D
0005435332216	7837	13	5A
0005434620519	7837	14	5B
0005435332194	7837	15	5C
0005434620529	7837	16	6A
0005435332244	7837	17	6B
0005434620521	7837	18	6C
0005434620522	7837	19	6D
0005434620516	7837	20	7A
0005434620531	7837	21	7B
0005435332243	7837	22	7C
0005432112509	7837	23	18A
0005434620530	7837	24	18B
0005434620525	7837	25	18C
0005432112508	7837	26	18D
0005434620532	7837	27	19B
0005434620526	7837	28	19D
0005434620527	7837	29	20A
0005435332229	7837	30	20B
0005435332225	7837	31	20C
0005435332242	7837	32	20D
0005435332183	7837	33	21C
0005434620536	7837	34	21D
0005435332217	7837	35	22A
0005434620534	7837	36	22B
0005435332193	7837	37	22D
0005435332178	7837	38	23B
0005435332299	32980	1	1A
0005434620370	32980	2	1B
0005434620271	32980	3	2B
0005434620349	32980	4	2D
0005435332298	32980	5	3B
0005434620384	32980	6	3A
0005435332306	32980	7	3C
0005435332300	32980	8	4B
0005435332304	32980	9	4C
0005435332295	32980	10	5A
0005434620328	32980	11	5B
0005434620332	32980	12	5C
0005434620379	32980	13	5D
0005435332296	32980	14	6A
0005434620374	32980	15	6B
0005434620351	32980	16	6C
0005434620348	32980	17	6D
0005434620368	32980	18	7A
0005435332303	32980	19	7B
0005434620369	32980	20	7D
0005435332305	32980	21	18B
0005435332302	32980	22	18D
0005434620355	32980	23	19A
0005434620378	32980	24	19C
0005434620306	32980	25	20C
0005435332297	32980	26	21C
0005434620307	32980	27	22A
0005435332301	32980	28	22C
0005434620385	32980	29	23A
0005434620364	32980	30	23B
0005434993993	4298	1	1F
0005435918606	4298	2	2C
0005435785232	4298	3	2F
0005435785228	4298	4	3A
0005434993994	4298	5	3C
0005435785254	4298	6	3D
0005435918605	4298	7	3F
0005435785253	4298	8	4A
0005435785248	4298	9	4C
0005435787346	4298	10	4E
0005435785250	4298	11	4F
0005434993996	4298	12	5A
0005435785257	4298	13	5C
0005432190615	4298	14	5F
0005434993988	4298	15	6A
0005435785225	4298	16	6C
0005435937318	4298	17	6D
0005434993987	4298	18	6E
0005435785226	4298	19	7C
0005435785239	4298	20	8A
0005435785247	4298	21	8D
0005434993989	4298	22	8E
0005435785258	4298	23	8F
0005435785234	4298	24	9A
0005435785249	4298	25	9C
0005435785235	4298	26	9E
0005435785241	4298	27	9F
0005435785242	4298	28	10C
0005434993990	4298	29	10D
0005432190617	4298	30	10E
0005435785230	4298	31	10F
0005435785240	4298	32	11A
0005435787347	4298	33	11E
0005435785251	4298	34	11F
0005434993992	4298	35	12A
0005435785236	4298	36	12D
0005434993991	4298	37	12F
0005435785244	4298	38	13A
0005435785237	4298	39	13C
0005435785229	4298	40	13D
0005435785233	4298	41	13E
0005434993995	4298	42	14C
0005432190616	4298	43	14D
0005435785252	4298	44	14E
0005435937328	4298	45	15D
0005435785238	4298	46	15E
0005435785245	4298	47	15F
0005435785231	4298	48	16C
0005435785256	4298	49	16D
0005435785223	4298	50	16E
0005435918600	4298	51	16F
0005435787348	4298	52	17C
0005435918599	4298	53	17D
0005434993985	4298	54	17E
0005435918614	4298	55	18D
0005435785224	4298	56	18E
0005432190618	4298	57	19D
0005435785243	4298	58	19E
0005435785255	4298	59	19F
0005435785246	4298	60	20D
0005435785227	4298	61	20E
0005434993986	4298	62	20F
0005435937372	27308	1	1A
0005435784741	27308	2	1C
0005435937374	27308	3	1F
0005435784915	27308	4	2A
0005434993893	27308	5	2C
0005435918639	27308	6	2D
0005432195684	27308	7	2F
0005434993894	27308	8	3A
0005435784946	27308	9	3C
0005435784796	27308	10	3F
0005435937367	27308	11	4C
0005435784884	27308	12	4E
0005435785005	27308	13	4F
0005434993897	27308	14	5A
0005434993908	27308	15	5C
0005434993913	27308	16	5F
0005435937370	27308	17	6A
0005435784905	27308	18	6C
0005435784965	27308	19	6D
0005435784887	27308	20	8D
0005435784923	27308	21	8F
0005435918640	27308	22	9C
0005435784842	27308	23	9E
0005435937369	27308	24	9F
0005435784962	27308	25	10C
0005435785007	27308	26	10D
0005435937368	27308	27	10F
0005434993912	27308	28	11F
0005434993907	27308	29	12A
0005435784966	27308	30	12C
0005435784883	27308	31	12D
0005435784967	27308	32	12E
0005435937371	27308	33	13A
0005435784964	27308	34	13D
0005435918638	27308	35	13F
0005435784786	27308	36	14A
0005434993915	27308	37	14D
0005435784994	27308	38	14F
0005435784861	27308	39	15A
0005435784934	27308	40	15C
0005432195685	27308	41	15F
0005435784928	27308	42	16C
0005434993940	27308	43	16D
0005434993896	27308	44	16E
0005434993917	27308	45	16F
0005434993880	27308	46	17A
0005435785006	27308	47	17D
0005435784935	27308	48	17E
0005435784751	27308	49	17F
0005435784910	27308	50	18C
0005435937373	27308	51	18E
0005435784862	27308	52	18F
0005435918641	27308	53	19E
0005435784752	27308	54	19F
0005435784869	27308	55	20C
0005435784914	27308	56	20D
0005435784999	27308	57	20E
0005432146191	19875	1	1D
0005432567440	4727	1	1A
0005432459687	4727	2	1F
0005432459671	4727	3	1C
0005432567452	4727	4	1G
0005434081830	4727	5	2A
0005432567451	4727	6	2B
0005432459672	4727	7	2F
0005432459688	4727	8	2G
0005432567435	4727	9	3A
0005432459700	4727	10	3B
0005432567433	4727	11	3C
0005432459693	4727	12	3H
0005432567425	4727	13	4B
0005432459663	4727	14	4C
0005432567461	4727	15	4G
0005432459702	4727	16	5B
0005432567424	4727	17	5A
0005432459660	4727	18	5C
0005433451615	4727	19	5F
0005432567419	4727	20	5H
0005432571310	4727	21	9B
0005432567408	4727	22	9H
0005432459662	4727	23	9G
0005432567421	4727	24	11A
0005432571311	4727	25	11B
0005432459670	4727	26	11E
0005432459678	4727	27	11D
0005432567459	4727	28	11F
0005432459685	4727	29	12A
0005432567414	4727	30	11H
0005432567402	4727	31	12E
0005432567409	4727	32	12F
0005432459690	4727	33	12H
0005432567436	4727	34	13A
0005432567437	4727	35	13D
0005432567462	4727	36	13B
0005433726095	4727	37	13E
0005432459697	4727	38	13G
0005432571309	4727	39	14B
0005432567443	4727	40	14A
0005434081827	4727	41	14D
0005433726097	4727	42	14F
0005432567411	4727	43	14G
0005434081834	4727	44	15A
0005432459683	4727	45	14H
0005432567427	4727	46	15B
0005432459666	4727	47	15E
0005432170362	4727	48	15D
0005432567448	4727	49	15H
0005432459691	4727	50	16D
0005432567441	4727	51	16B
0005432459676	4727	52	16E
0005432571308	4727	53	16F
0005432567401	4727	54	17A
0005432567412	4727	55	17B
0005432186857	4727	56	17E
0005432459667	4727	57	17H
0005432567463	4727	58	17G
0005432459698	4727	59	18D
0005432459669	4727	60	18F
0005432459701	4727	61	18G
0005433452734	4727	62	19A
0005432459658	4727	63	18H
0005434081836	4727	64	19B
0005432459692	4727	65	19E
0005432459661	4727	66	19D
0005432567434	4727	67	19F
0005434081829	4727	68	20A
0005432170369	4727	69	19H
0005432459689	4727	70	20B
0005433452733	4727	71	20D
0005432567429	4727	72	20F
0005432567418	4727	73	20E
0005432459673	4727	74	20H
0005432459677	4727	75	20G
0005432567428	4727	76	21A
0005434081823	4727	77	21D
0005434081826	4727	78	21E
0005432567426	4727	79	21F
0005433451614	4727	80	21H
0005432567455	4727	81	22B
0005432567456	4727	82	22A
0005432186859	4727	83	22D
0005432459659	4727	84	22E
0005432459653	4727	85	22H
0005432170368	4727	86	23A
0005434081822	4727	87	23B
0005432567404	4727	88	23E
0005432459694	4727	89	23H
0005432567442	4727	90	23G
0005432459681	4727	91	24A
0005432567405	4727	92	24F
0005432459655	4727	93	24H
0005432459696	4727	94	25D
0005434081824	4727	95	25E
0005432567460	4727	96	27A
0005432186858	4727	97	27D
0005434081833	4727	98	27F
0005432567432	4727	99	27E
0005432567417	4727	100	27H
0005432459686	4727	101	27G
0005432459656	4727	102	28A
0005432459703	4727	103	28D
0005432459652	4727	104	28G
0005432567454	4727	105	28F
0005432459679	4727	106	29A
0005432567439	4727	107	29B
0005434081825	4727	108	29E
0005432567420	4727	109	29G
0005432459654	4727	110	29F
0005432170365	4727	111	29H
0005432170366	4727	112	30B
0005432170367	4727	113	30A
0005434081821	4727	114	30D
0005432459668	4727	115	30E
0005432170364	4727	116	30G
0005432459651	4727	117	30F
0005432567403	4727	118	30H
0005432567406	4727	119	31D
0005432459695	4727	120	31F
0005432567416	4727	121	31E
0005432459665	4727	122	31G
0005432567431	4727	123	31H
0005432459699	4727	124	32B
0005432567422	4727	125	32A
0005434081832	4727	126	32D
0005433451613	4727	127	32F
0005432459682	4727	128	32E
0005434081819	4727	129	32G
0005432567450	4727	130	33A
0005432459657	4727	131	33B
0005434081820	4727	132	33E
0005432567438	4727	133	33H
0005432170363	4727	134	34A
0005432567453	4727	135	34D
0005432567447	4727	136	34E
0005432567458	4727	137	34F
0005432459664	4727	138	35A
0005434081835	4727	139	34H
0005432567457	4727	140	35B
0005432459674	4727	141	35E
0005432459684	4727	142	35F
0005432567407	4727	143	36A
0005432567446	4727	144	35H
0005432567413	4727	145	36E
0005434081831	4727	146	36D
0005432459680	4727	147	36F
0005432186856	4727	148	36H
0005432567445	4727	149	36G
0005432567410	4727	150	37A
0005432567423	4727	151	37B
0005432567430	4727	152	37E
0005434081828	4727	153	37G
0005432567444	4727	154	38E
0005432567415	4727	155	38F
0005433726096	4727	156	38H
0005432459675	4727	157	38G
0005432567449	4727	158	39E
0005432567138	30543	1	1A
0005434081522	30543	2	1B
0005432459014	30543	3	1F
0005434081586	30543	4	1G
0005432566627	30543	5	2A
0005432459289	30543	6	2B
0005434081547	30543	7	2C
0005432571267	30543	8	2G
0005432213596	30543	9	3A
0005432566922	30543	10	3B
0005432213594	30543	11	3F
0005432459171	30543	12	3C
0005432459125	30543	13	3G
0005432567214	30543	14	3H
0005432571285	30543	15	4C
0005434081617	30543	16	5A
0005432459126	30543	17	4H
0005434081624	30543	18	5C
0005432566807	30543	19	5G
0005432459210	30543	20	9A
0005432459309	30543	21	9G
0005432566952	30543	22	11A
0005432566853	30543	23	9H
0005432459436	30543	24	11B
0005432459191	30543	25	11F
0005432459341	30543	26	11H
0005432213592	30543	27	12B
0005432566644	30543	28	12A
0005432459484	30543	29	12D
0005432459198	30543	30	12F
0005432567084	30543	31	12H
0005432567141	30543	32	13B
0005434081644	30543	33	13A
0005432459253	30543	34	13D
0005432459162	30543	35	13F
0005432459161	30543	36	13E
0005432161144	30543	37	14D
0005434081556	30543	38	14G
0005432566754	30543	39	14F
0005432571286	30543	40	15A
0005432566973	30543	41	14H
0005432566975	30543	42	15D
0005432459209	30543	43	15B
0005432459291	30543	44	15G
0005434081523	30543	45	15E
0005432566978	30543	46	15H
0005432567119	30543	47	16B
0005432566962	30543	48	16A
0005432566710	30543	49	16D
0005433452720	30543	50	16G
0005432566794	30543	51	16F
0005432459325	30543	52	16H
0005432213595	30543	53	17B
0005432566926	30543	54	17A
0005432567137	30543	55	17D
0005434081589	30543	56	17E
0005432567048	30543	57	17G
0005432459278	30543	58	17F
0005432459145	30543	59	18A
0005432566854	30543	60	18D
0005432566963	30543	61	18F
0005432213593	30543	62	18H
0005432566792	30543	63	19B
0005432459277	30543	64	19E
0005432567096	30543	65	19G
0005432459373	30543	66	19H
0005432459299	30543	67	20B
0005432566658	30543	68	20G
0005432566753	30543	69	20H
0005432459290	30543	70	21B
0005432459435	30543	71	21F
0005432566598	30543	72	21G
0005432459465	30543	73	22B
0005432459267	30543	74	22A
0005432566953	30543	75	22D
0005432567139	30543	76	22E
0005434081552	30543	77	23A
0005432459469	30543	78	23D
0005432459374	30543	79	23E
0005434081600	30543	80	23G
0005432459190	30543	81	23H
0005432566927	30543	82	24E
0005432567083	30543	83	24D
0005432566866	30543	84	24F
0005432566958	30543	85	24G
0005432567147	30543	86	24H
0005432567040	30543	87	25F
0005432459119	30543	88	25E
0005432567172	30543	89	27A
0005432459380	30543	90	27B
0005432459308	30543	91	27D
0005432567110	30543	92	27F
0005432566904	30543	93	28A
0005434081587	30543	94	27H
0005433452714	30543	95	28D
0005432459329	30543	96	28B
0005432566961	30543	97	28E
0005432459262	30543	98	28F
0005432459368	30543	99	28H
0005432567105	30543	100	28G
0005432567111	30543	101	29D
0005432566965	30543	102	29B
0005432566791	30543	103	29E
0005432566790	30543	104	29G
0005432567022	30543	105	30B
0005432459340	30543	106	30D
0005432566988	30543	107	30E
0005432567037	30543	108	30G
0005432567016	30543	109	30F
0005434081528	30543	110	31B
0005432571279	30543	111	31D
0005432566956	30543	112	31F
0005432567144	30543	113	31E
0005432459263	30543	114	31G
0005432566950	30543	115	31H
0005432459372	30543	116	32D
0005434081618	30543	117	32A
0005432459496	30543	118	32F
0005432566883	30543	119	32E
0005432459470	30543	120	32H
0005432459208	30543	121	33A
0005434081625	30543	122	33B
0005432161145	30543	123	33H
0005434081673	30543	124	34B
0005432566898	30543	125	34D
0005432566957	30543	126	34F
0005432566969	30543	127	35A
0005432459326	30543	128	35E
0005432566709	30543	129	35D
0005432571281	30543	130	35F
0005432459331	30543	131	35G
0005432459072	30543	132	36A
0005432571282	30543	133	35H
0005434081546	30543	134	36B
0005434081488	30543	135	36E
0005434081588	30543	136	36D
0005432459335	30543	137	36F
0005432459318	30543	138	37A
0005432566897	30543	139	36H
0005432566999	30543	140	37D
0005432459124	30543	141	37F
0005432566974	30543	142	37E
0005432566928	30543	143	38A
0005432567118	30543	144	38D
0005432459254	30543	145	38B
0005432567164	30543	146	38E
0005432567140	30543	147	39D
0005432567005	30543	148	38G
0005432459381	30543	149	39F
0005435722048	13576	1	1B
0005435722046	13576	2	4A
0005435722047	13576	3	6A
0005435722025	21122	1	1B
0005435722024	21122	2	3A
0005435722029	21122	3	3B
0005435722012	21122	4	4B
0005432295871	22758	1	5D
0005432295870	22758	2	6D
0005432295872	22758	3	20D
0005433342899	11103	1	1A
0005433342874	11103	2	1C
0005433342900	11103	3	1D
0005433342875	11103	4	2A
0005433342842	11103	5	1F
0005433342857	11103	6	2D
0005433342814	11103	7	2C
0005433342907	11103	8	2F
0005435097168	11103	9	3C
0005433342823	11103	10	3A
0005433342830	11103	11	3D
0005433342894	11103	12	3F
0005433342854	11103	13	4A
0005433342821	11103	14	4B
0005433342877	11103	15	4D
0005433342859	11103	16	4E
0005433342885	11103	17	4F
0005433342850	11103	18	5A
0005433342848	11103	19	5B
0005435380243	11103	20	5D
0005433342846	11103	21	5C
0005435508224	11103	22	5E
0005433342904	11103	23	6C
0005433342906	11103	24	6B
0005433342887	11103	25	6D
0005433342825	11103	26	6F
0005433342896	11103	27	6E
0005433342892	11103	28	7B
0005433342832	11103	29	7C
0005433342805	11103	30	7D
0005433342836	11103	31	7F
0005435097170	11103	32	7E
0005433342843	11103	33	8B
0005433342867	11103	34	8A
0005435508191	11103	35	8C
0005433342837	11103	36	8D
0005433342898	11103	37	8F
0005433342868	11103	38	8E
0005433342905	11103	39	9A
0005433342886	11103	40	9D
0005433342839	11103	41	9C
0005433342807	11103	42	9F
0005433342889	11103	43	9E
0005433342826	11103	44	10B
0005433342851	11103	45	10C
0005433342806	11103	46	10E
0005433342852	11103	47	10D
0005433342828	11103	48	11A
0005433342864	11103	49	11B
0005433342880	11103	50	11D
0005433342847	11103	51	11C
0005433342845	11103	52	11E
0005433342869	11103	53	11F
0005433342865	11103	54	12A
0005433342871	11103	55	12C
0005433342827	11103	56	12E
0005433342833	11103	57	12D
0005433342882	11103	58	12F
0005433342831	11103	59	13B
0005433342809	11103	60	13A
0005433342844	11103	61	13C
0005435380251	11103	62	13F
0005433342891	11103	63	13E
0005433342819	11103	64	14A
0005433342893	11103	65	14C
0005433342902	11103	66	14B
0005433342872	11103	67	14D
0005433342856	11103	68	14E
0005433342873	11103	69	14F
0005433342841	11103	70	15B
0005433342870	11103	71	15A
0005433342824	11103	72	15C
0005433342838	11103	73	15D
0005435097166	11103	74	15E
0005433342860	11103	75	16A
0005435380241	11103	76	15F
0005433342903	11103	77	16B
0005433342876	11103	78	16C
0005433342895	11103	79	16D
0005433342866	11103	80	16F
0005433342878	11103	81	16E
0005433342820	11103	82	17A
0005435097171	11103	83	17B
0005433342816	11103	84	17C
0005433342881	11103	85	17D
0005433342858	11103	86	17F
0005433342888	11103	87	17E
0005433342863	11103	88	18A
0005433342813	11103	89	18B
0005433342901	11103	90	18D
0005433342861	11103	91	18C
0005433342883	11103	92	18E
0005435380242	11103	93	18F
0005433342890	11103	94	19B
0005433342811	11103	95	19A
0005435097167	11103	96	19D
0005433342834	11103	97	19C
0005433342853	11103	98	19E
0005433342884	11103	99	19F
0005433342810	11103	100	20A
0005433342862	11103	101	20C
0005433342822	11103	102	20B
0005435380240	11103	103	20E
0005435508223	11103	104	20D
0005433342817	11103	105	20F
0005433342812	11103	106	21B
0005433342835	11103	107	21A
0005435097169	11103	108	21C
0005433342879	11103	109	21D
0005435380244	11103	110	21E
0005435508211	11103	111	21F
0005435508219	11103	112	22B
0005433342855	11103	113	22A
0005435508222	11103	114	22C
0005435508216	11103	115	22D
0005435508221	11103	116	22F
0005433342840	11103	117	22E
0005433342897	11103	118	23B
0005433342815	11103	119	23A
0005433342808	11103	120	23C
0005433342849	11103	121	23D
0005433342818	11103	122	23F
0005433342829	11103	123	23E
0005433341484	17122	1	1A
0005433341790	17122	2	1C
0005435380281	17122	3	1D
0005433341856	17122	4	2A
0005435545721	17122	5	2C
0005433341945	17122	6	3A
0005435545717	17122	7	2F
0005433341786	17122	8	3C
0005433341619	17122	9	3D
0005433342076	17122	10	3F
0005433341414	17122	11	4B
0005433341485	17122	12	4A
0005433341988	17122	13	4C
0005433342294	17122	14	4D
0005435545719	17122	15	4E
0005433341855	17122	16	4F
0005433341702	17122	17	5B
0005433342102	17122	18	5A
0005433341992	17122	19	5C
0005433341471	17122	20	5D
0005433342221	17122	21	5F
0005433342029	17122	22	5E
0005433342011	17122	23	6A
0005433341647	17122	24	6C
0005433342096	17122	25	6B
0005433341673	17122	26	6D
0005435380282	17122	27	6F
0005433342194	17122	28	6E
0005433341917	17122	29	7A
0005433341808	17122	30	7C
0005433341826	17122	31	7D
0005433341578	17122	32	7E
0005435545720	17122	33	8A
0005433342103	17122	34	7F
0005433341679	17122	35	8B
0005433341948	17122	36	8C
0005433341537	17122	37	8E
0005433341810	17122	38	8D
0005433342004	17122	39	9A
0005433341899	17122	40	9B
0005433342057	17122	41	9C
0005433341646	17122	42	9E
0005433341872	17122	43	9D
0005433342081	17122	44	10B
0005433342056	17122	45	9F
0005433341987	17122	46	10C
0005433341719	17122	47	10E
0005433341825	17122	48	10D
0005433342036	17122	49	11A
0005433341536	17122	50	11C
0005433342438	17122	51	11B
0005433341983	17122	52	11E
0005435545722	17122	53	11D
0005433341731	17122	54	11F
0005433341861	17122	55	12A
0005435097078	17122	56	12B
0005433342485	17122	57	12D
0005433342026	17122	58	12C
0005433341785	17122	59	12E
0005433341760	17122	60	12F
0005433341743	17122	61	13A
0005433341946	17122	62	13C
0005433342012	17122	63	13B
0005433342024	17122	64	13D
0005433341818	17122	65	13F
0005433342339	17122	66	13E
0005433341692	17122	67	14A
0005433342439	17122	68	14B
0005432293201	17122	69	14C
0005433341630	17122	70	14D
0005433341720	17122	71	14E
0005433341634	17122	72	14F
0005433342046	17122	73	15A
0005433341807	17122	74	15C
0005433341577	17122	75	15B
0005433342158	17122	76	15D
0005433342074	17122	77	15E
0005433341852	17122	78	16A
0005435097109	17122	79	15F
0005435380284	17122	80	16B
0005433342222	17122	81	16C
0005433341604	17122	82	16D
0005435380283	17122	83	16F
0005433341871	17122	84	16E
0005435097053	17122	85	17A
0005435545716	17122	86	17B
0005433342205	17122	87	17C
0005435097064	17122	88	17D
0005435380285	17122	89	17F
0005435380287	17122	90	17E
0005435545718	17122	91	18A
0005435545715	17122	92	18B
0005433341566	17122	93	18D
0005435097070	17122	94	18C
0005433342193	17122	95	18E
0005433341469	17122	96	18F
0005433342462	17122	97	19A
0005435380286	17122	98	19B
0005433341971	17122	99	19C
0005433341693	17122	100	19E
0005433342055	17122	101	19D
0005433341969	17122	102	19F
0005433341691	17122	103	20A
0005433342486	17122	104	20C
0005432293200	17122	105	20B
0005433341900	17122	106	20E
0005433341974	17122	107	20D
0005435097052	17122	108	21A
0005433341656	17122	109	20F
0005433341665	17122	110	21B
0005433342338	17122	111	21C
0005433342254	17122	112	21D
0005433341470	17122	113	21E
0005433341602	17122	114	21F
0005433341605	17122	115	22B
0005433341938	17122	116	22A
0005433341664	17122	117	22C
0005433342385	17122	118	22D
0005433342079	17122	119	22F
0005433341618	17122	120	22E
0005433342175	17122	121	23B
0005433341550	17122	122	23A
0005433341661	17122	123	23D
0005433342080	17122	124	23C
0005435097071	17122	125	23E
0005433341730	17122	126	23F
0005433507122	9063	1	1A
0005433507139	9063	2	1D
0005432919615	9063	3	1F
0005432919530	9063	4	2A
0005433507136	9063	5	2F
0005434158953	9063	6	3D
0005433481141	9063	7	4C
0005433507127	9063	8	4E
0005434158958	9063	9	4F
0005433507134	9063	10	5C
0005433507138	9063	11	6E
0005433507135	9063	12	6F
0005433481143	9063	13	7A
0005432919591	9063	14	7C
0005433507125	9063	15	7F
0005433507119	9063	16	8A
0005433507129	9063	17	8D
0005433507126	9063	18	8E
0005432919578	9063	19	9A
0005432919654	9063	20	9C
0005433507124	9063	21	9E
0005432919617	9063	22	10A
0005433507130	9063	23	10F
0005432919616	9063	24	11A
0005433481140	9063	25	11C
0005432919546	9063	26	11E
0005433507123	9063	27	11F
0005432919590	9063	28	12A
0005433507131	9063	29	12C
0005433507128	9063	30	12D
0005432919577	9063	31	12E
0005433507140	9063	32	12F
0005432919549	9063	33	13C
0005432919711	9063	34	13D
0005432919669	9063	35	13E
0005433507133	9063	36	13F
0005433481146	9063	37	14E
0005434158951	9063	38	15A
0005432919628	9063	39	15C
0005432919614	9063	40	15D
0005432919643	9063	41	16A
0005433507121	9063	42	16D
0005433481145	9063	43	16E
0005433481144	9063	44	17A
0005433481142	9063	45	17D
0005433507118	9063	46	18A
0005432919644	9063	47	18E
0005433507137	9063	48	18F
0005433507120	9063	49	19A
0005433507132	9063	50	19C
0005432919710	9063	51	19D
0005432919655	9063	52	20C
0005432919539	9063	53	20E
0005432919808	20454	1	1C
0005432919821	20454	2	1F
0005433507037	20454	3	3D
0005432919819	20454	4	4C
0005432919818	20454	5	5C
0005432919822	20454	6	5E
0005432919807	20454	7	5F
0005433481061	20454	8	7C
0005433506944	20454	9	7D
0005432919806	20454	10	7F
0005433506958	20454	11	8A
0005433506949	20454	12	8F
0005433507019	20454	13	9A
0005432919820	20454	14	9C
0005432919811	20454	15	9E
0005433507045	20454	16	9F
0005432919813	20454	17	10E
0005432919802	20454	18	11A
0005433507020	20454	19	11D
0005432919817	20454	20	12A
0005432919804	20454	21	12F
0005432919823	20454	22	13D
0005433507035	20454	23	13F
0005432919812	20454	24	14C
0005433506994	20454	25	14D
0005432919809	20454	26	14F
0005433481072	20454	27	15F
0005432919816	20454	28	16C
0005433481060	20454	29	16D
0005433506977	20454	30	16E
0005433506997	20454	31	17C
0005432919805	20454	32	17D
0005432919810	20454	33	18A
0005433506998	20454	34	18D
0005433506996	20454	35	18F
0005432919814	20454	36	20C
0005432919803	20454	37	20D
0005432919815	20454	38	20E
0005432396225	10190	1	1A
0005432394085	10190	2	1B
0005432394087	10190	3	2A
0005435178982	10190	4	2B
0005432396226	10190	5	3A
0005432394086	10190	6	3B
0005432394089	10190	7	4A
0005432394088	10190	8	4B
0005435178981	10190	9	5A
0005432396227	10190	10	5B
0005432396228	10190	11	6A
0005432396224	10190	12	6B
0005432396201	18395	1	1B
0005432400065	18395	2	2A
0005435179691	18395	3	4A
0005435554108	11029	1	1D
0005435556665	11029	2	1F
0005435554107	11029	3	2D
0005435125915	11029	4	3A
0005435125889	11029	5	3C
0005435554119	11029	6	3D
0005435125840	11029	7	3F
0005435554120	11029	8	4E
0005435556663	11029	9	4F
0005434928290	11029	10	5A
0005435125855	11029	11	5C
0005434411764	11029	12	5D
0005435125839	11029	13	5F
0005434411766	11029	14	6A
0005435125881	11029	15	6E
0005435625952	11029	16	6F
0005434928291	11029	17	7A
0005435125886	11029	18	7C
0005434411765	11029	19	7E
0005435625977	11029	20	7F
0005435625908	11029	21	8C
0005435125790	11029	22	8D
0005435554135	11029	23	8E
0005434411767	11029	24	9C
0005435554113	11029	25	9D
0005435625959	11029	26	9E
0005435625962	11029	27	9F
0005435125813	11029	28	10A
0005435625910	11029	29	10C
0005435125857	11029	30	10D
0005435125914	11029	31	11A
0005435125856	11029	32	11E
0005435125908	11029	33	11F
0005435625956	11029	34	12C
0005434928289	11029	35	13A
0005435125929	11029	36	13C
0005435554106	11029	37	13E
0005435556664	11029	38	13F
0005435125812	11029	39	14C
0005435625923	11029	40	14E
0005435554131	11029	41	14F
0005435125845	11029	42	15D
0005435125991	11029	43	15F
0005435625957	11029	44	16A
0005435625922	11029	45	16D
0005435125909	11029	46	16F
0005435625965	11029	47	17A
0005435125890	11029	48	17E
0005435125879	11029	49	18A
0005435125833	11029	50	18D
0005435625909	11029	51	18E
0005435125853	11029	52	18F
0005435625927	11029	53	19C
0005435125854	11029	54	19D
0005435126021	11029	55	19E
0005435125887	11029	56	20A
0005435125714	11029	57	20C
0005435625978	11029	58	20D
0005435126253	14657	1	1A
0005435626110	14657	2	1C
0005435126238	14657	3	1D
0005434928268	14657	4	1F
0005435126232	14657	5	2A
0005435126261	14657	6	2C
0005435626118	14657	7	2D
0005435626128	14657	8	2F
0005435626126	14657	9	3A
0005435126257	14657	10	3C
0005435554172	14657	11	3F
0005435126252	14657	12	4A
0005435126245	14657	13	4C
0005434411729	14657	14	4D
0005435626119	14657	15	4E
0005435626132	14657	16	4F
0005435626114	14657	17	5A
0005435554171	14657	18	5C
0005435126265	14657	19	5D
0005435626135	14657	20	5E
0005435126254	14657	21	5F
0005435126259	14657	22	6A
0005435554167	14657	23	6C
0005435126251	14657	24	6D
0005435126241	14657	25	6E
0005435626127	14657	26	6F
0005435126248	14657	27	7A
0005435126233	14657	28	7C
0005435126269	14657	29	7D
0005435554170	14657	30	7E
0005435626111	14657	31	8C
0005435126256	14657	32	8D
0005435126240	14657	33	8E
0005435626125	14657	34	8F
0005434411717	14657	35	9C
0005435626131	14657	36	9D
0005435126258	14657	37	9E
0005435626123	14657	38	9F
0005435126237	14657	39	10A
0005435126247	14657	40	10C
0005435626136	14657	41	10E
0005435554168	14657	42	10F
0005435626120	14657	43	11C
0005435126267	14657	44	11D
0005434411745	14657	45	11E
0005435126264	14657	46	11F
0005435556684	14657	47	12A
0005435556685	14657	48	12C
0005434411742	14657	49	12D
0005435126231	14657	50	12E
0005435126239	14657	51	12F
0005435626112	14657	52	13A
0005435126263	14657	53	13C
0005435126260	14657	54	13E
0005435626116	14657	55	13F
0005435626133	14657	56	14A
0005435126243	14657	57	14D
0005435626137	14657	58	14E
0005435126244	14657	59	14F
0005435126270	14657	60	15C
0005435626129	14657	61	15D
0005435126235	14657	62	15E
0005435126266	14657	63	16A
0005435126262	14657	64	16C
0005435626121	14657	65	16D
0005434411728	14657	66	16F
0005435126255	14657	67	17A
0005435126271	14657	68	17C
0005435126268	14657	69	17D
0005435126234	14657	70	17E
0005435626130	14657	71	17F
0005435626117	14657	72	18A
0005435126250	14657	73	18C
0005435626134	14657	74	18D
0005435554169	14657	75	18E
0005434411716	14657	76	18F
0005435626122	14657	77	19A
0005435126236	14657	78	19C
0005434411730	14657	79	19D
0005435626113	14657	80	19E
0005435126242	14657	81	19F
0005435126249	14657	82	20C
0005435626124	14657	83	20D
0005435626115	14657	84	20E
0005435126246	14657	85	20F
0005434928280	14656	1	10C
0005434928281	14656	2	12A
0005432400112	7120	1	1A
0005432400113	7120	2	1D
0005435216555	7120	3	1F
0005435715409	7120	4	2C
0005435443191	7120	5	2F
0005435715407	7120	6	3A
0005435443212	7120	7	4A
0005435178475	7120	8	4C
0005435715411	7120	9	4D
0005432400110	7120	10	5F
0005432398186	7120	11	7A
0005435715416	7120	12	8C
0005435443195	7120	13	8D
0005435715413	7120	14	8E
0005432398187	7120	15	9A
0005435178474	7120	16	9C
0005435715410	7120	17	9D
0005435715412	7120	18	9E
0005435178479	7120	19	9F
0005435443183	7120	20	10C
0005435443194	7120	21	10D
0005435443174	7120	22	11D
0005435715421	7120	23	11E
0005435715408	7120	24	12A
0005435715418	7120	25	12C
0005435715415	7120	26	12D
0005435443176	7120	27	12F
0005435443211	7120	28	13D
0005435443197	7120	29	13E
0005432400111	7120	30	13F
0005435443218	7120	31	14D
0005435715420	7120	32	15D
0005435715419	7120	33	16E
0005435178478	7120	34	17D
0005435715417	7120	35	17E
0005435715406	7120	36	18A
0005435443196	7120	37	18F
0005435443210	7120	38	19E
0005435715414	7120	39	19F
0005435715422	7120	40	20E
0005435715260	27051	1	1A
0005435443285	27051	2	2D
0005432398133	27051	3	3C
0005435443286	27051	4	4C
0005435715280	27051	5	4E
0005432394040	27051	6	5C
0005432398138	27051	7	5D
0005435715225	27051	8	5E
0005435443283	27051	9	6E
0005435715254	27051	10	7C
0005435715323	27051	11	7E
0005435715224	27051	12	8D
0005432394050	27051	13	8F
0005435715314	27051	14	9C
0005435443279	27051	15	9D
0005435715315	27051	16	9F
0005435443289	27051	17	10D
0005435715228	27051	18	10F
0005435443281	27051	19	11D
0005435715281	27051	20	11F
0005435715292	27051	21	12C
0005435715269	27051	22	12D
0005435443280	27051	23	13A
0005435443287	27051	24	13C
0005432394049	27051	25	13E
0005432398152	27051	26	13F
0005435715294	27051	27	14A
0005432398137	27051	28	14D
0005435443284	27051	29	14E
0005432394065	27051	30	15A
0005435443282	27051	31	16A
0005432394054	27051	32	16C
0005435715306	27051	33	16F
0005435715293	27051	34	17E
0005432398134	27051	35	18F
0005435715307	27051	36	19C
0005432398130	27051	37	19D
0005432398129	27051	38	19E
0005435443288	27051	39	20E
0005433060382	2753	1	1A
0005433060371	2753	2	1B
0005433060380	2753	3	2A
0005433060387	2753	4	2B
0005434084916	2753	5	3B
0005434084915	2753	6	4A
0005434084917	2753	7	4B
0005433060381	2753	8	6B
0005434084882	28495	1	1A
0005433060404	28495	2	1B
0005433060406	28495	3	2A
0005433060403	28495	4	2B
0005434084861	28495	5	3A
0005434084909	28495	6	4A
0005434084883	28495	7	3B
0005434084870	28495	8	4B
0005433060405	28495	9	5A
0005434084908	28495	10	6B
0005435517785	11367	1	2A
0005435540776	11367	2	2C
0005435540755	11367	3	2D
0005435517678	11367	4	2F
0005435540834	11367	5	3A
0005435540725	11367	6	4C
0005435517739	11367	7	4D
0005435517729	11367	8	4E
0005435517784	11367	9	6A
0005435517704	11367	10	6C
0005435540709	11367	11	6F
0005435540777	11367	12	7A
0005435540797	11367	13	8A
0005435540754	11367	14	8E
0005435540746	11367	15	9A
0005435540761	11367	16	9C
0005435540724	11367	17	9D
0005435540778	11367	18	9F
0005435517646	11367	19	11C
0005435540707	11367	20	11E
0005435540775	11367	21	12A
0005435517747	11367	22	13C
0005435540743	11367	23	13D
0005435540762	11367	24	13E
0005435517632	11367	25	13F
0005435517800	11367	26	14C
0005435540716	11367	27	14E
0005435517754	11367	28	15A
0005435540708	11367	29	16A
0005435517705	11367	30	16C
0005435540827	11367	31	17A
0005435517647	11367	32	17D
0005435540717	11367	33	17E
0005435517733	11367	34	17F
0005435540766	11367	35	18D
0005435517706	11367	36	19A
0005435540670	11367	37	20C
0005435540706	11367	38	20E
0005435540918	22223	1	1C
0005435529173	22223	2	1F
0005435540931	22223	3	2A
0005435540927	22223	4	2D
0005435529171	22223	5	2F
0005435540928	22223	6	3A
0005435540932	22223	7	3C
0005435529172	22223	8	4A
0005435529186	22223	9	4C
0005435529187	22223	10	5D
0005435529184	22223	11	5F
0005435540915	22223	12	6D
0005432294478	22223	13	6F
0005435540920	22223	14	7C
0005435529177	22223	15	7E
0005435529183	22223	16	8A
0005435540924	22223	17	8E
0005435529180	22223	18	8F
0005435540914	22223	19	9A
0005435529185	22223	20	9D
0005435540922	22223	21	9E
0005435540923	22223	22	9F
0005435529178	22223	23	10D
0005435540919	22223	24	10F
0005435529179	22223	25	11D
0005435529176	22223	26	11F
0005435529188	22223	27	12A
0005435540917	22223	28	12C
0005435540921	22223	29	13A
0005435529181	22223	30	13D
0005435540913	22223	31	14A
0005435529182	22223	32	14D
0005435540926	22223	33	15C
0005432294477	22223	34	15F
0005435529169	22223	35	16C
0005435529170	22223	36	16E
0005435529168	22223	37	17D
0005435540930	22223	38	17E
0005435540911	22223	39	18C
0005435540916	22223	40	18D
0005435540925	22223	41	18E
0005435529174	22223	42	19A
0005435529175	22223	43	19C
0005435529167	22223	44	19D
0005435540912	22223	45	19F
0005435540929	22223	46	20D
0005434907122	2300	1	1A
0005434907135	2300	2	1C
0005434907153	2300	3	1D
0005434907144	2300	4	2A
0005433251163	2300	5	2C
0005434907139	2300	6	2D
0005434907132	2300	7	2F
0005434907151	2300	8	3A
0005434907126	2300	9	3C
0005433400956	2300	10	3D
0005434907155	2300	11	3F
0005434907160	2300	12	4A
0005433251173	2300	13	4C
0005433251162	2300	14	4E
0005434907118	2300	15	4F
0005433251037	2300	16	5A
0005433251164	2300	17	5C
0005434907148	2300	18	5D
0005434907136	2300	19	5E
0005433400951	2300	20	5F
0005433251132	2300	21	6C
0005433251153	2300	22	6D
0005434907129	2300	23	6E
0005433251165	2300	24	6F
0005434907137	2300	25	7C
0005434907104	2300	26	7D
0005434907140	2300	27	7F
0005434907154	2300	28	8A
0005433400958	2300	29	8C
0005433251133	2300	30	8D
0005433251146	2300	31	8E
0005434907138	2300	32	9C
0005433400957	2300	33	9E
0005433251255	2300	34	9F
0005434907146	2300	35	10C
0005434907116	2300	36	10D
0005434907107	2300	37	10E
0005434907119	2300	38	10F
0005434907128	2300	39	11E
0005434907143	2300	40	11F
0005434907141	2300	41	12A
0005434907133	2300	42	12C
0005434907110	2300	43	12D
0005434907114	2300	44	12E
0005434907150	2300	45	13A
0005434907123	2300	46	13C
0005434907115	2300	47	13E
0005434907158	2300	48	13F
0005434907111	2300	49	14A
0005434907157	2300	50	14C
0005434907106	2300	51	14D
0005433251036	2300	52	14E
0005433251174	2300	53	14F
0005433251256	2300	54	15A
0005434907112	2300	55	15C
0005434907159	2300	56	15D
0005433251082	2300	57	15E
0005434907121	2300	58	15F
0005434907147	2300	59	16A
0005434907124	2300	60	16C
0005434907127	2300	61	16D
0005434907152	2300	62	16E
0005434907142	2300	63	16F
0005434907149	2300	64	17A
0005433400955	2300	65	17C
0005434907105	2300	66	17D
0005434907109	2300	67	17E
0005433251254	2300	68	17F
0005433251081	2300	69	18A
0005433251154	2300	70	18C
0005434907130	2300	71	18D
0005434907131	2300	72	18E
0005434907125	2300	73	18F
0005434907134	2300	74	19A
0005434907108	2300	75	19C
0005434907113	2300	76	19E
0005433251080	2300	77	19F
0005434907120	2300	78	20A
0005434907117	2300	79	20D
0005434907156	2300	80	20E
0005434907145	2300	81	20F
0005434906630	25601	1	1C
0005434906424	25601	2	1D
0005433251399	25601	3	1F
0005433251395	25601	4	2A
0005434906786	25601	5	2D
0005434906581	25601	6	2F
0005433251400	25601	7	3A
0005434906685	25601	8	3C
0005434906637	25601	9	3D
0005434906629	25601	10	3F
0005434906570	25601	11	4A
0005433251393	25601	12	4C
0005434906569	25601	13	4D
0005433251379	25601	14	4E
0005434906565	25601	15	4F
0005433251394	25601	16	5A
0005433251390	25601	17	5C
0005433251388	25601	18	5D
0005434906751	25601	19	5E
0005434906657	25601	20	5F
0005434906394	25601	21	6A
0005433251375	25601	22	6C
0005434906712	25601	23	6D
0005434906615	25601	24	6E
0005434906567	25601	25	6F
0005434906765	25601	26	7A
0005434906568	25601	27	7C
0005434906457	25601	28	7D
0005434906566	25601	29	7E
0005433251378	25601	30	7F
0005434906584	25601	31	8A
0005433251391	25601	32	8C
0005433251371	25601	33	8D
0005434906667	25601	34	8E
0005434906492	25601	35	8F
0005433251383	25601	36	9A
0005434906715	25601	37	9D
0005434906711	25601	38	9E
0005434906750	25601	39	9F
0005433251380	25601	40	10A
0005434906486	25601	41	10C
0005433251392	25601	42	10D
0005434906601	25601	43	10E
0005433251382	25601	44	10F
0005433251384	25601	45	11A
0005433251381	25601	46	11C
0005434906572	25601	47	11D
0005433251372	25601	48	11E
0005434906628	25601	49	11F
0005433251397	25601	50	12A
0005434906702	25601	51	12C
0005434906704	25601	52	12D
0005434906454	25601	53	12E
0005433251386	25601	54	12F
0005433251387	25601	55	13A
0005434906418	25601	56	13C
0005433251389	25601	57	13D
0005434906648	25601	58	13E
0005433400973	25601	59	13F
0005433400974	25601	60	14A
0005434906726	25601	61	14C
0005433251385	25601	62	14D
0005433251374	25601	63	14F
0005433251398	25601	64	15A
0005434906463	25601	65	15C
0005434906703	25601	66	15D
0005434906787	25601	67	15E
0005434906683	25601	68	16A
0005434906502	25601	69	16C
0005434906552	25601	70	16D
0005434906684	25601	71	16E
0005434906727	25601	72	16F
0005434906693	25601	73	17C
0005434906658	25601	74	17D
0005433251396	25601	75	17E
0005434906549	25601	76	17F
0005434906655	25601	77	18A
0005433251377	25601	78	18C
0005433251373	25601	79	18D
0005434906695	25601	80	18E
0005434906587	25601	81	18F
0005434906462	25601	82	19A
0005433400975	25601	83	19C
0005434906456	25601	84	19D
0005434906425	25601	85	19F
0005433251376	25601	86	20A
0005434906826	25601	87	20C
0005434906473	25601	88	20D
0005434906511	25601	89	20E
0005434906694	25601	90	20F
0005432621002	2534	1	1D
0005432862229	2534	2	2A
0005432620997	2534	3	2B
0005432620998	2534	4	3C
0005432862220	2534	5	3D
0005432620992	2534	6	4B
0005432862194	2534	7	4D
0005432620991	2534	8	5B
0005432620993	2534	9	6B
0005432862246	2534	10	6C
0005432862221	2534	11	6D
0005432862187	2534	12	7A
0005432862231	2534	13	7C
0005432621000	2534	14	18B
0005432620999	2534	15	18D
0005432621001	2534	16	19B
0005432862193	2534	17	19C
0005432862233	2534	18	19D
0005432620990	2534	19	20C
0005432862230	2534	20	20D
0005432862210	2534	21	21A
0005432862201	2534	22	21D
0005432620996	2534	23	22A
0005432620994	2534	24	22B
0005432620995	2534	25	22D
0005432620989	2534	26	23A
0005432862219	2534	27	23B
0005432862274	28061	1	2A
0005432862276	28061	2	2B
0005432620891	28061	3	2D
0005432862279	28061	4	3B
0005432620900	28061	5	3C
0005432862278	28061	6	4A
0005432862275	28061	7	4B
0005432862280	28061	8	5A
0005432620915	28061	9	5D
0005432620863	28061	10	6B
0005432620925	28061	11	6C
0005432862277	28061	12	6D
0005432862282	28061	13	7C
0005432620794	28061	14	18D
0005432862281	28061	15	19C
0005432862283	28061	16	20B
0005434097464	11685	1	1B
0005434097472	13079	1	1B
0005434097473	13079	2	5B
0005434191252	32874	1	4A
0005434191261	32874	2	7A
0005434191260	32874	3	10A
0005434191253	32874	4	11D
0005434191251	32874	5	12C
0005434191256	32874	6	12E
0005434191257	32874	7	15C
0005433451613	31004	1	2A
0005433452734	31004	2	2B
0005433451614	31004	3	3A
0005433451615	31004	4	3B
0005433452733	31004	5	6B
0005433452720	31383	1	1B
0005433452714	31383	2	6B
0005433134081	12024	1	1C
0005434142569	12024	2	1D
0005434184649	12024	3	2A
0005434142570	12024	4	2B
0005434142555	12024	5	2D
0005434142563	12024	6	3C
0005433129202	12024	7	4A
0005433129232	12024	8	4B
0005434142567	12024	9	4C
0005434142576	12024	10	4D
0005433129219	12024	11	5B
0005434184641	12024	12	5C
0005433129229	12024	13	6C
0005434142562	12024	14	6D
0005434142560	12024	15	7A
0005434142554	12024	16	7C
0005433134070	12024	17	18B
0005434184642	12024	18	19D
0005434142564	12024	19	20B
0005434142559	12024	20	20C
0005433134079	12024	21	21A
0005433129233	12024	22	21D
0005434142558	12024	23	22C
0005433134122	29862	1	2A
0005434183575	29862	2	2B
0005434326265	29862	3	2C
0005433131695	29862	4	2D
0005434142594	29862	5	3A
0005434142596	29862	6	4A
0005433134124	29862	7	4C
0005434183574	29862	8	5D
0005434326261	29862	9	6A
0005433134123	29862	10	7C
0005434183573	29862	11	7D
0005434326264	29862	12	18A
0005433131693	29862	13	18D
0005434142593	29862	14	19C
0005434184659	29862	15	20A
0005434142595	29862	16	20B
0005433131692	29862	17	20C
0005433131694	29862	18	21B
0005433134125	29862	19	21D
0005435798936	1605	1	1D
0005435798943	1605	2	2B
0005435798932	1605	3	2D
0005435798942	1605	4	3A
0005435798944	1605	5	3B
0005435798945	1605	6	3D
0005435798934	1605	7	4A
0005435798938	1605	8	4B
0005435798939	1605	9	5B
0005435798937	1605	10	6B
0005435798941	1605	11	6C
0005435798931	1605	12	18D
0005435798933	1605	13	21A
0005435798935	1605	14	21C
0005435798940	1605	15	23B
0005435697224	16492	1	1A
0005435697242	16492	2	1B
0005435697244	16492	3	1C
0005435697240	16492	4	2A
0005435697229	16492	5	2B
0005435697222	16492	6	3B
0005435697228	16492	7	3C
0005435697230	16492	8	4B
0005435697220	16492	9	5A
0005435697232	16492	10	5B
0005435697241	16492	11	5C
0005435697226	16492	12	5D
0005435697233	16492	13	6C
0005435697237	16492	14	7A
0005435697238	16492	15	7D
0005435697218	16492	16	18A
0005435697219	16492	17	18C
0005435697217	16492	18	19A
0005435697227	16492	19	19C
0005435697225	16492	20	19D
0005435697221	16492	21	20B
0005435697231	16492	22	20C
0005435697243	16492	23	20D
0005435697235	16492	24	21A
0005435697223	16492	25	21B
0005435935000	16492	26	22B
0005435697239	16492	27	22C
0005435697236	16492	28	23A
0005435697234	16492	29	23B
0005435697035	24703	1	1A
0005435697020	24703	2	2B
0005435697021	24703	3	2C
0005435697071	24703	4	2D
0005435697066	24703	5	3A
0005435696923	24703	6	3B
0005435696990	24703	7	3D
0005435935037	24703	8	4A
0005435697099	24703	9	4D
0005435697059	24703	10	4C
0005435696988	24703	11	5A
0005435696914	24703	12	5B
0005435697028	24703	13	5D
0005435697065	24703	14	6A
0005435935033	24703	15	6B
0005435935036	24703	16	6C
0005435697072	24703	17	7B
0005435697012	24703	18	7C
0005435935035	24703	19	7D
0005435697098	24703	20	19A
0005435696989	24703	21	19B
0005435697061	24703	22	19C
0005435696996	24703	23	20A
0005435697015	24703	24	20C
0005435696995	24703	25	21A
0005435696919	24703	26	21B
0005435697034	24703	27	21C
0005435696953	24703	28	21D
0005435696964	24703	29	22A
0005435696974	24703	30	22C
0005435696954	24703	31	23A
0005435935034	24703	32	23B
0005433724790	18798	1	1B
0005433724789	18798	2	3A
0005433724791	18798	3	3B
0005433724788	18798	4	5A
0005432968819	18798	5	5B
0005432968815	18798	6	6A
0005433724787	18798	7	6B
0005433724744	21646	1	1A
0005433724767	21646	2	2A
0005432968835	21646	3	2B
0005433724781	21646	4	3A
0005433724746	21646	5	4A
0005433724762	21646	6	3B
0005433724761	21646	7	4B
0005432968834	21646	8	5A
0005433724745	21646	9	6A
0005433724766	21646	10	5B
0005432968836	21646	11	6B
0005434137934	7331	1	1A
0005434137903	7331	2	1C
0005434137923	7331	3	1F
0005434137949	7331	4	2A
0005434137945	7331	5	2C
0005434137896	7331	6	2D
0005434137902	7331	7	2F
0005434137904	7331	8	3A
0005434137931	7331	9	3D
0005434137950	7331	10	3F
0005434137940	7331	11	4A
0005434137935	7331	12	4C
0005434137917	7331	13	4D
0005434137906	7331	14	4E
0005434137893	7331	15	4F
0005434137947	7331	16	5A
0005434137912	7331	17	5C
0005434087498	7331	18	5D
0005434137891	7331	19	5E
0005434137938	7331	20	5F
0005434137890	7331	21	6A
0005434137886	7331	22	6C
0005434137901	7331	23	6D
0005434137924	7331	24	6E
0005434137930	7331	25	6F
0005434137919	7331	26	7A
0005434137898	7331	27	7C
0005434137918	7331	28	7D
0005434137905	7331	29	7E
0005434137942	7331	30	7F
0005434137926	7331	31	8A
0005434137921	7331	32	8D
0005434137887	7331	33	8E
0005434137871	7331	34	8F
0005434137911	7331	35	9A
0005434137881	7331	36	9C
0005434137914	7331	37	9D
0005434137875	7331	38	9E
0005434137908	7331	39	9F
0005434137878	7331	40	10A
0005434137907	7331	41	10D
0005434137874	7331	42	10E
0005434137915	7331	43	11A
0005434137876	7331	44	10F
0005434137895	7331	45	11C
0005434137927	7331	46	11D
0005434137939	7331	47	11E
0005434137885	7331	48	11F
0005434087500	7331	49	12A
0005434137943	7331	50	12C
0005434137913	7331	51	12D
0005434137882	7331	52	12F
0005434137877	7331	53	13A
0005434137894	7331	54	13C
0005434137872	7331	55	13D
0005434137880	7331	56	13E
0005434137946	7331	57	13F
0005434137899	7331	58	14A
0005434137873	7331	59	14C
0005434137929	7331	60	14D
0005434137937	7331	61	14E
0005434137892	7331	62	14F
0005434137948	7331	63	15A
0005434087499	7331	64	15C
0005434137941	7331	65	15D
0005434137884	7331	66	15E
0005434137920	7331	67	15F
0005434137909	7331	68	16A
0005434137951	7331	69	16C
0005434137883	7331	70	16D
0005434137888	7331	71	16E
0005434087497	7331	72	16F
0005434137916	7331	73	17C
0005434087496	7331	74	17D
0005434137910	7331	75	17E
0005434137900	7331	76	17F
0005434137932	7331	77	18A
0005434137897	7331	78	18D
0005434137928	7331	79	18E
0005434137952	7331	80	19D
0005434137879	7331	81	19C
0005434137889	7331	82	19E
0005434137933	7331	83	19F
0005434137922	7331	84	20A
0005434137936	7331	85	20C
0005434137944	7331	86	20D
0005434137925	7331	87	20F
0005434136945	28563	1	1A
0005434137320	28563	2	1C
0005434137355	28563	3	1D
0005434137356	28563	4	1F
0005434137224	28563	5	2A
0005434137404	28563	6	2C
0005434136740	28563	7	2D
0005434087458	28563	8	2F
0005434137062	28563	9	3A
0005434136768	28563	10	3C
0005434136943	28563	11	3D
0005434137277	28563	12	3F
0005434137208	28563	13	4A
0005434136741	28563	14	4C
0005434136999	28563	15	4E
0005434137166	28563	16	4F
0005434137146	28563	17	5C
0005434136895	28563	18	5D
0005434137319	28563	19	5E
0005434137115	28563	20	5F
0005434137363	28563	21	6A
0005434136963	28563	22	6D
0005434137099	28563	23	6E
0005434137142	28563	24	7C
0005434137058	28563	25	7E
0005434137280	28563	26	7F
0005434137329	28563	27	8A
0005434137090	28563	28	8C
0005434137413	28563	29	8D
0005434136812	28563	30	8E
0005434137111	28563	31	8F
0005434137088	28563	32	9C
0005434137192	28563	33	9D
0005434137130	28563	34	9E
0005434137141	28563	35	9F
0005434137191	28563	36	10A
0005434137014	28563	37	10D
0005434137286	28563	38	10F
0005434137129	28563	39	11C
0005434137278	28563	40	11D
0005434136896	28563	41	11E
0005434137285	28563	42	11F
0005434137318	28563	43	12A
0005434137017	28563	44	12C
0005434137150	28563	45	12D
0005434136770	28563	46	12E
0005434137202	28563	47	12F
0005434137509	28563	48	13A
0005434137143	28563	49	13C
0005434137371	28563	50	13D
0005434137089	28563	51	13E
0005434137382	28563	52	13F
0005434136944	28563	53	14A
0005434137454	28563	54	14C
0005434137276	28563	55	14D
0005434137072	28563	56	14E
0005434137066	28563	57	14F
0005434137001	28563	58	15A
0005434137067	28563	59	15C
0005434137249	28563	60	15D
0005434137063	28563	61	15E
0005434137116	28563	62	16A
0005434137223	28563	63	16D
0005434137217	28563	64	16C
0005434137248	28563	65	16E
0005434137065	28563	66	16F
0005434136962	28563	67	17A
0005434137260	28563	68	17C
0005434137373	28563	69	17D
0005434137015	28563	70	17E
0005434137414	28563	71	17F
0005434137383	28563	72	18A
0005434136961	28563	73	18C
0005434137362	28563	74	18D
0005434136964	28563	75	18F
0005434137091	28563	76	18E
0005434137053	28563	77	19A
0005434137194	28563	78	19D
0005434136769	28563	79	19E
0005434137038	28563	80	19F
0005434137328	28563	81	20A
0005434137405	28563	82	20C
0005434137590	28563	83	20D
0005434137000	28563	84	20E
0005434137068	28563	85	20F
0005435808205	1928	1	2A
0005433407496	1928	2	3C
0005435808203	1928	3	3D
0005435808204	1928	4	4A
0005434610219	1928	5	4B
0005435808206	1928	6	4C
0005434610218	1928	7	6A
0005433407505	1928	8	6B
0005435808200	1928	9	7A
0005435808207	1928	10	19C
0005433407506	1928	11	19D
0005433407495	1928	12	20A
0005435808201	1928	13	21B
0005434610216	1928	14	21C
0005435808208	1928	15	21D
0005434610217	1928	16	22A
0005435808202	1928	17	23A
0005434610184	23104	1	7C
0005434610198	23104	2	23A
0005434503754	16717	1	1B
0005434503665	16717	2	1D
0005434503585	16717	3	2C
0005434503680	16717	4	3A
0005434503773	16717	5	3B
0005434503775	16717	6	3C
0005434503625	16717	7	3D
0005434503705	16717	8	4A
0005434503543	16717	9	4B
0005434503537	16717	10	4C
0005434503755	16717	11	5B
0005434503780	16717	12	5D
0005434503669	16717	13	6B
0005434503673	16717	14	6C
0005434503717	16717	15	7A
0005434503679	16717	16	7B
0005434503677	16717	17	18C
0005434503779	16717	18	18D
0005434503736	16717	19	19A
0005434503589	16717	20	19B
0005434503766	16717	21	19C
0005434503515	16717	22	19D
0005434503778	16717	23	20D
0005434503636	16717	24	21B
0005434503683	16717	25	21C
0005434503716	16717	26	21D
0005434503516	16717	27	22B
0005434504021	22934	1	1A
0005434504014	22934	2	1D
0005434504004	22934	3	2A
0005434504001	22934	4	2B
0005434503990	22934	5	2C
0005434503983	22934	6	2D
0005434504008	22934	7	3A
0005434504000	22934	8	3B
0005434503986	22934	9	3C
0005434503982	22934	10	3D
0005434504015	22934	11	4A
0005434504011	22934	12	4B
0005434503987	22934	13	4C
0005434503994	22934	14	4D
0005434503998	22934	15	5A
0005434504019	22934	16	5B
0005434503995	22934	17	5C
0005434503989	22934	18	5D
0005434504013	22934	19	6A
0005434504002	22934	20	6B
0005434503997	22934	21	6D
0005434503985	22934	22	7A
0005434504018	22934	23	7B
0005434503988	22934	24	7C
0005434504017	22934	25	7D
0005434504012	22934	26	18A
0005434504005	22934	27	18B
0005434504020	22934	28	18D
0005434503996	22934	29	19A
0005434503999	22934	30	19B
0005434503992	22934	31	19C
0005434504010	22934	32	19D
0005434504003	22934	33	20A
0005434504009	22934	34	20C
0005434504007	22934	35	20D
0005434503991	22934	36	21A
0005434503984	22934	37	21B
0005434504016	22934	38	22B
0005434503993	22934	39	22D
0005434504006	22934	40	23B
0005434608300	6497	1	2B
0005434608316	6497	2	2D
0005434608306	6497	3	4C
0005434608309	6497	4	4D
0005434608314	6497	5	5A
0005434608305	6497	6	5B
0005434608302	6497	7	6A
0005434608310	6497	8	6B
0005434608311	6497	9	7A
0005434608312	6497	10	7B
0005434608313	6497	11	7C
0005434608317	6497	12	18A
0005434608307	6497	13	19B
0005434608304	6497	14	19C
0005434608303	6497	15	20C
0005434608299	6497	16	21B
0005434608301	6497	17	22A
0005434608315	6497	18	22C
0005434608308	6497	19	23B
0005434608277	22498	1	3B
0005434608278	22498	2	3D
0005434608294	22498	3	5A
0005434608287	22498	4	6A
0005434608280	22498	5	19C
0005434608276	22498	6	20A
0005434608279	22498	7	21B
0005434608286	22498	8	22A
0005433266641	2201	1	1A
0005433266608	2201	2	1D
0005433266631	2201	3	2B
0005435078294	2201	4	2C
0005435078299	2201	5	2D
0005433266632	2201	6	3D
0005435078287	2201	7	4D
0005435078288	2201	8	5A
0005433266593	2201	9	6A
0005435078290	2201	10	6C
0005435078289	2201	11	7A
0005435078295	2201	12	7B
0005435078303	2201	13	7D
0005435078292	2201	14	18A
0005435078302	2201	15	18B
0005435078301	2201	16	18D
0005433266612	2201	17	19B
0005435078298	2201	18	19D
0005435078291	2201	19	20B
0005433266595	2201	20	20C
0005435078300	2201	21	21A
0005433266639	2201	22	21B
0005435078293	2201	23	21C
0005433266613	2201	24	21D
0005435078297	2201	25	22A
0005435078296	2201	26	23A
0005433266698	24352	1	1A
0005435078155	24352	2	1B
0005435078151	24352	3	1C
0005433266692	24352	4	1D
0005435078121	24352	5	2B
0005435078130	24352	6	3B
0005435078076	24352	7	5A
0005435078179	24352	8	5B
0005435078120	24352	9	5C
0005435078171	24352	10	6C
0005433266700	24352	11	6D
0005435078170	24352	12	7A
0005433266690	24352	13	7B
0005433266694	24352	14	7C
0005435078178	24352	15	18C
0005435078212	24352	16	18D
0005435078131	24352	17	19A
0005433266695	24352	18	19B
0005433266699	24352	19	19D
0005433266691	24352	20	20B
0005435078203	24352	21	21B
0005433266693	24352	22	21D
0005433266697	24352	23	22B
0005435078077	24352	24	22C
0005433266696	24352	25	23B
0005435464491	6668	1	1B
0005435464490	6668	2	1C
0005434988705	6668	3	3B
0005434988708	6668	4	3C
0005434988707	6668	5	5A
0005434988706	6668	6	5B
0005435464482	6668	7	18A
0005435803257	6668	8	18C
0005434988704	6668	9	18D
0005434988703	6668	10	19C
0005435464489	6668	11	20B
0005435803256	6668	12	20C
0005434988702	6668	13	21C
0005434988709	6668	14	21D
0005435803255	6668	15	22A
0005435803254	6668	16	23B
0005434988581	23637	1	2A
0005435803235	23637	2	3A
0005434988568	23637	3	3D
0005434988579	23637	4	5A
0005435803230	23637	5	7A
0005435803233	23637	6	19A
0005434988558	23637	7	19B
0005435803234	23637	8	19D
0005434988580	23637	9	19C
0005434988578	23637	10	20A
0005435464501	23637	11	20B
0005434988577	23637	12	21B
0005434988567	23637	13	21C
0005432383080	30472	1	1C
0005432383062	30472	2	2C
0005433449900	30472	3	2D
0005433449896	30472	4	2F
0005432383057	30472	5	3A
0005432383091	30472	6	3C
0005432383079	30472	7	3D
0005432383066	30472	8	3F
0005433449906	30472	9	4A
0005432383068	30472	10	4C
0005432383076	30472	11	4E
0005433449917	30472	12	5A
0005432383073	30472	13	5C
0005433449907	30472	14	5D
0005433449897	30472	15	5E
0005432383063	30472	16	5F
0005432383078	30472	17	6A
0005432383094	30472	18	6C
0005432383090	30472	19	6F
0005432383085	30472	20	7A
0005433453758	30472	21	7C
0005432383064	30472	22	7E
0005433449905	30472	23	7F
0005433449895	30472	24	8D
0005433449901	30472	25	8E
0005432383086	30472	26	8F
0005432383060	30472	27	9C
0005432383077	30472	28	9D
0005432383069	30472	29	9E
0005433449904	30472	30	9F
0005433449915	30472	31	10A
0005433449913	30472	32	10C
0005433449912	30472	33	10F
0005432383058	30472	34	11A
0005433449899	30472	35	11C
0005432383074	30472	36	11E
0005433449909	30472	37	11F
0005432383071	30472	38	12C
0005432383081	30472	39	12D
0005433449908	30472	40	12E
0005432383089	30472	41	12F
0005432383075	30472	42	13D
0005433449914	30472	43	13E
0005432383059	30472	44	13F
0005432383070	30472	45	14C
0005432383087	30472	46	14D
0005433449898	30472	47	14F
0005433449910	30472	48	15A
0005432383072	30472	49	15C
0005432383088	30472	50	16A
0005432383082	30472	51	16C
0005432383067	30472	52	17C
0005433449903	30472	53	17D
0005433449902	30472	54	18A
0005433449911	30472	55	18D
0005432383065	30472	56	18F
0005432383093	30472	57	19C
0005432383083	30472	58	19E
0005433449916	30472	59	19F
0005432383061	30472	60	20C
0005432383092	30472	61	20D
0005432383084	30472	62	20E
0005433451587	31285	1	1C
0005433449707	31285	2	1D
0005432382663	31285	3	1F
0005432382691	31285	4	2A
0005432382653	31285	5	3C
0005432382640	31285	6	3F
0005432382565	31285	7	4C
0005432382566	31285	8	4D
0005432382760	31285	9	4E
0005432382642	31285	10	4F
0005432382753	31285	11	5A
0005433449665	31285	12	5D
0005432382690	31285	13	5E
0005433449787	31285	14	6D
0005433451600	31285	15	7A
0005432382714	31285	16	8A
0005432382797	31285	17	8C
0005433449811	31285	18	8D
0005433449743	31285	19	8F
0005433449696	31285	20	9F
0005432382720	31285	21	10D
0005432382578	31285	22	11A
0005432382800	31285	23	11C
0005433449682	31285	24	11E
0005433449738	31285	25	12A
0005432382726	31285	26	12C
0005432382752	31285	27	12D
0005432382670	31285	28	12F
0005432382638	31285	29	13C
0005433449721	31285	30	14A
0005432382698	31285	31	14F
0005433449652	31285	32	15C
0005432382700	31285	33	15D
0005433449744	31285	34	15E
0005432382639	31285	35	15F
0005433449681	31285	36	16C
0005433449724	31285	37	16D
0005432382715	31285	38	17A
0005433449737	31285	39	17D
0005432382732	31285	40	18C
0005432382641	31285	41	18D
0005432382664	31285	42	19A
0005432382746	31285	43	19C
0005432382801	31285	44	19E
0005433449816	31285	45	20C
0005432382626	31285	46	20D
0005433788181	20820	1	1A
0005435548435	20820	2	1D
0005435548422	20820	3	2A
0005433788180	20820	4	2B
0005433788188	20820	5	2C
0005433788185	20820	6	3C
0005433788187	20820	7	3D
0005435548423	20820	8	4B
0005433788182	20820	9	5C
0005435548436	20820	10	5D
0005435548434	20820	11	6B
0005433788186	20820	12	7D
0005435548433	20820	13	18A
0005433788179	20820	14	18C
0005433788183	20820	15	20A
0005433788178	20820	16	21A
0005433788189	20820	17	21D
0005433788184	20820	18	22B
0005433131649	10799	1	1C
0005435299727	10799	2	3B
0005435299728	10799	3	3D
0005435299729	10799	4	4D
0005433126785	10799	5	6A
0005435304115	10799	6	6C
0005435304110	10799	7	7A
0005433131643	10799	8	7C
0005433126812	10799	9	18D
0005433131650	10799	10	19D
0005435304109	10799	11	20A
0005435304112	10799	12	20C
0005433131653	10799	13	22C
0005433129265	29733	1	1A
0005433126836	29733	2	1D
0005433126835	29733	3	3C
0005435302190	29733	4	3D
0005433129267	29733	5	4B
0005435299767	29733	6	4C
0005435299766	29733	7	5D
0005433129266	29733	8	6B
0005435299765	29733	9	18D
0005435302189	29733	10	19B
0005435299764	29733	11	22A
0005433129264	29733	12	22B
0005434287233	2404	1	1A
0005434287224	2404	2	1B
0005434287227	2404	3	1D
0005432264468	2404	4	3B
0005434287217	2404	5	3C
0005432264467	2404	6	4A
0005433109967	2404	7	4D
0005434287223	2404	8	5A
0005434287231	2404	9	5D
0005434287215	2404	10	6B
0005434287229	2404	11	6C
0005434287214	2404	12	6D
0005434287216	2404	13	7A
0005434287230	2404	14	7B
0005434287220	2404	15	7C
0005434287225	2404	16	18A
0005434287218	2404	17	18B
0005433109941	2404	18	18C
0005434287228	2404	19	18D
0005434287211	2404	20	19C
0005434287213	2404	21	19D
0005433109929	2404	22	20A
0005434287212	2404	23	20B
0005434287226	2404	24	20C
0005434287232	2404	25	21D
0005434287222	2404	26	22A
0005434287221	2404	27	22C
0005434287219	2404	28	22D
0005433109930	2404	29	23B
0005434286973	26861	1	1A
0005434287045	26861	2	1C
0005433110011	26861	3	2B
0005433110021	26861	4	2C
0005434287044	26861	5	2D
0005434287029	26861	6	3C
0005434287039	26861	7	3D
0005434287064	26861	8	4A
0005433110019	26861	9	4B
0005433110012	26861	10	4D
0005433110016	26861	11	6B
0005434287105	26861	12	6D
0005433110014	26861	13	7A
0005434287104	26861	14	7C
0005433110015	26861	15	18D
0005433110022	26861	16	19A
0005433110020	26861	17	19B
0005434286974	26861	18	19C
0005434286926	26861	19	19D
0005433110017	26861	20	20A
0005434286998	26861	21	20D
0005434286927	26861	22	21A
0005433110018	26861	23	21B
0005434287026	26861	24	22A
0005433110013	26861	25	22D
0005434287043	26861	26	23A
0005434286940	26861	27	23B
0005435856191	25467	1	1A
0005435856192	25467	2	3B
0005435856193	25467	3	4C
0005435856190	25467	4	23A
0005434272188	26678	1	2B
0005435856146	26678	2	2C
0005435856159	26678	3	3A
0005434273071	26678	4	4A
0005435856150	26678	5	4B
0005435856152	26678	6	4D
0005434272187	26678	7	7B
0005435854044	26678	8	7D
0005434273073	26678	9	18C
0005435854041	26678	10	19C
0005434273072	26678	11	19D
0005434520163	19082	1	1A
0005435314815	19082	2	1D
0005435314818	19082	3	2A
0005434520130	19082	4	2C
0005434520158	19082	5	2D
0005435314824	19082	6	3A
0005435314822	19082	7	3B
0005434520202	19082	8	3D
0005434520143	19082	9	4A
0005434520152	19082	10	4B
0005434520176	19082	11	4C
0005434520177	19082	12	5A
0005435314826	19082	13	5D
0005434520180	19082	14	6A
0005435314820	19082	15	6B
0005435314821	19082	16	6C
0005435314819	19082	17	7A
0005434520175	19082	18	7B
0005434520206	19082	19	7C
0005434520159	19082	20	7D
0005434520184	19082	21	18A
0005435314827	19082	22	18C
0005434520154	19082	23	18D
0005435314823	19082	24	19A
0005435314816	19082	25	19C
0005434520164	19082	26	20A
0005435314828	19082	27	20B
0005434520171	19082	28	20C
0005434520207	19082	29	21B
0005435314825	19082	30	21C
0005434520135	19082	31	22B
0005434520185	19082	32	22A
0005435314817	19082	33	22D
0005434520153	19082	34	23A
0005433874335	7779	1	4B
0005433874337	7779	2	4C
0005433874341	7779	3	5C
0005433874338	7779	4	5D
0005433874336	7779	5	6B
0005433874339	7779	6	6C
0005433874342	7779	7	18B
0005433874343	7779	8	20D
0005433874340	7779	9	23A
0005433874301	32624	1	1A
0005433874315	32624	2	3A
0005433874317	32624	3	3B
0005433874296	32624	4	18D
0005433874300	32624	5	19C
0005433874316	32624	6	22A
0005433874299	32624	7	23A
0005433868312	4778	1	1A
0005433868322	4778	2	1B
0005433868330	4778	3	1C
0005433868328	4778	4	1D
0005435860442	4778	5	2A
0005433868306	4778	6	2C
0005433868345	4778	7	3A
0005433868341	4778	8	3B
0005433868315	4778	9	3C
0005433868326	4778	10	3D
0005433868310	4778	11	4A
0005433868325	4778	12	4B
0005433868319	4778	13	4C
0005433868338	4778	14	4D
0005433868305	4778	15	5A
0005433868314	4778	16	5B
0005433868313	4778	17	5C
0005435860444	4778	18	6C
0005433868332	4778	19	6D
0005433868320	4778	20	7A
0005433868329	4778	21	7B
0005433868335	4778	22	7C
0005433868344	4778	23	7D
0005433868317	4778	24	18A
0005433868340	4778	25	18B
0005433868342	4778	26	18C
0005433868334	4778	27	19A
0005433868316	4778	28	19B
0005433868333	4778	29	19C
0005433868308	4778	30	19D
0005433868307	4778	31	20A
0005433868309	4778	32	20B
0005433868339	4778	33	20C
0005435860443	4778	34	20D
0005433868321	4778	35	21A
0005433868324	4778	36	21B
0005433868323	4778	37	21C
0005433868311	4778	38	21D
0005433868327	4778	39	22A
0005433868331	4778	40	22B
0005433868336	4778	41	22C
0005433868318	4778	42	22D
0005433868343	4778	43	23A
0005433868337	4778	44	23B
0005433867866	32605	1	1A
0005433867814	32605	2	1B
0005433867834	32605	3	1C
0005433867961	32605	4	1D
0005433868188	32605	5	2A
0005433867980	32605	6	2B
0005433867979	32605	7	2D
0005433867809	32605	8	3A
0005433868086	32605	9	3B
0005433867796	32605	10	3C
0005433867956	32605	11	3D
0005433867774	32605	12	4A
0005433867997	32605	13	4B
0005433868037	32605	14	4C
0005433868065	32605	15	4D
0005433867882	32605	16	5A
0005433867905	32605	17	5B
0005433867942	32605	18	5C
0005433867853	32605	19	5D
0005433867797	32605	20	6A
0005433867833	32605	21	6B
0005433867957	32605	22	6C
0005433867881	32605	23	6D
0005433867953	32605	24	7A
0005433867865	32605	25	7B
0005433867864	32605	26	7D
0005433867958	32605	27	18A
0005433867747	32605	28	18B
0005433868022	32605	29	18C
0005433867948	32605	30	19A
0005433867748	32605	31	18D
0005433867919	32605	32	19B
0005433867906	32605	33	19C
0005433868091	32605	34	19D
0005433867886	32605	35	20A
0005433867803	32605	36	20B
0005433867931	32605	37	20C
0005433867891	32605	38	20D
0005433868081	32605	39	21A
0005433867863	32605	40	21B
0005433867815	32605	41	21C
0005433867918	32605	42	21D
0005433867941	32605	43	22A
0005433867983	32605	44	22B
0005433867775	32605	45	22D
0005433867982	32605	46	23A
0005433867848	32605	47	23B
0005434663362	3444	1	1D
0005434461641	3444	2	2A
0005435911334	3444	3	2B
0005435911348	3444	4	2C
0005435911359	3444	5	2D
0005434663372	3444	6	3A
0005435911384	3444	7	3B
0005434663363	3444	8	4B
0005435911349	3444	9	4C
0005434460498	3444	10	5A
0005435911383	3444	11	5B
0005434663374	3444	12	6A
0005434663370	3444	13	6B
0005434663364	3444	14	6C
0005434461640	3444	15	7A
0005434663361	3444	16	7B
0005434663371	3444	17	7C
0005434663375	3444	18	18A
0005434663360	3444	19	18B
0005434460499	3444	20	18D
0005435911369	3444	21	19A
0005435911360	3444	22	19C
0005434663366	3444	23	19D
0005434663368	3444	24	20C
0005434663367	3444	25	21A
0005434663365	3444	26	21B
0005434663369	3444	27	21C
0005434663373	3444	28	23A
0005434460471	12482	1	1A
0005434460475	12482	2	1B
0005434460478	12482	3	1C
0005434462755	12482	4	1D
0005434663281	12482	5	2A
0005434663166	12482	6	2B
0005434460474	12482	7	2C
0005435911430	12482	8	2D
0005434663252	12482	9	3A
0005434663282	12482	10	3B
0005434663221	12482	11	3C
0005434460480	12482	12	3D
0005434462753	12482	13	4A
0005434462756	12482	14	4B
0005434663276	12482	15	4C
0005434462759	12482	16	4D
0005435911428	12482	17	5A
0005434663265	12482	18	5C
0005434462754	12482	19	5D
0005435911427	12482	20	6B
0005435911431	12482	21	6C
0005434462758	12482	22	6D
0005434462760	12482	23	7B
0005434460482	12482	24	7C
0005434462764	12482	25	18B
0005434462765	12482	26	18A
0005434663220	12482	27	18C
0005434663213	12482	28	18D
0005434460483	12482	29	19B
0005434663259	12482	30	19C
0005434663240	12482	31	19D
0005434663261	12482	32	20A
0005434663226	12482	33	20B
0005435911429	12482	34	20C
0005434663264	12482	35	20D
0005434663225	12482	36	21A
0005434663277	12482	37	22A
0005434663239	12482	38	21D
0005434663283	12482	39	22C
0005435911426	12482	40	23A
0005434460481	12482	41	22D
0005435911432	12482	42	23B
0005433868037	14521	1	1A
0005433867942	14521	2	1C
0005433867980	14521	3	1D
0005433867886	14521	4	2A
0005433867905	14521	5	2B
0005433868188	14521	6	2C
0005433867881	14521	7	3A
0005433868081	14521	8	3B
0005433867961	14521	9	3C
0005433867882	14521	10	3D
0005433867815	14521	11	4A
0005433868065	14521	12	4B
0005433867956	14521	13	4C
0005433867953	14521	14	4D
0005433867834	14521	15	5A
0005433867931	14521	16	5B
0005433867948	14521	17	5C
0005433867833	14521	18	5D
0005433868086	14521	19	6A
0005433868022	14521	20	6B
0005433867983	14521	21	6D
0005433867919	14521	22	7A
0005433867774	14521	23	7B
0005433867747	14521	24	7C
0005433867906	14521	25	7D
0005433868091	14521	26	18A
0005433867982	14521	27	18B
0005433867796	14521	28	18C
0005433867866	14521	29	18D
0005433867918	14521	30	19A
0005433867957	14521	31	19B
0005433867891	14521	32	19C
0005433867814	14521	33	19D
0005433867997	14521	34	20A
0005433867941	14521	35	20B
0005433867863	14521	36	20C
0005433867775	14521	37	20D
0005433867958	14521	38	21A
0005433867864	14521	39	21C
0005433867979	14521	40	21B
0005433867797	14521	41	21D
0005433867748	14521	42	22A
0005433867809	14521	43	22B
0005433867803	14521	44	22C
0005433867853	14521	45	22D
0005433867848	14521	46	23A
0005433867865	14521	47	23B
0005433868289	32689	1	1A
0005433868279	32689	2	1D
0005433868280	32689	3	2A
0005433868286	32689	4	2B
0005433868290	32689	5	3A
0005433868273	32689	6	3B
0005433868301	32689	7	3C
0005433868295	32689	8	3D
0005433868287	32689	9	4A
0005433868268	32689	10	4C
0005433868265	32689	11	4D
0005433868285	32689	12	5B
0005433868284	32689	13	5C
0005433868276	32689	14	5D
0005433868288	32689	15	6A
0005433868293	32689	16	6B
0005433868278	32689	17	6C
0005433868264	32689	18	6D
0005433868304	32689	19	7A
0005433868272	32689	20	7B
0005433868303	32689	21	7C
0005433868291	32689	22	7D
0005433868269	32689	23	18A
0005433868281	32689	24	18B
0005433868270	32689	25	18C
0005433868297	32689	26	18D
0005433868302	32689	27	19A
0005433868283	32689	28	19C
0005433868294	32689	29	20A
0005433868292	32689	30	20B
0005433868263	32689	31	20C
0005433868266	32689	32	20D
0005433868271	32689	33	21A
0005433868277	32689	34	21B
0005433868298	32689	35	21C
0005433868299	32689	36	21D
0005433868274	32689	37	22A
0005433868300	32689	38	22B
0005433868275	32689	39	22C
0005433868282	32689	40	22D
0005433868296	32689	41	23A
0005433868267	32689	42	23B
0005432799012	12137	1	1B
0005432799147	12137	2	2B
0005432799118	12137	3	2D
0005432799162	12137	4	3A
0005432799099	12137	5	3C
0005432799164	12137	6	4A
0005432799114	12137	7	4B
0005432799038	12137	8	4C
0005432799121	12137	9	5D
0005432799062	12137	10	6B
0005432799076	12137	11	7A
0005432799204	12137	12	7B
0005432799092	12137	13	7C
0005432799218	12137	14	7D
0005432799193	12137	15	18A
0005432799088	12137	16	18B
0005432799146	12137	17	18D
0005432799073	12137	18	19D
0005432799160	12137	19	20C
0005432799061	12137	20	21A
0005432799085	12137	21	21B
0005432799089	12137	22	21D
0005432799192	12137	23	23B
0005432799355	14818	1	1A
0005432799330	14818	2	1C
0005432799331	14818	3	1D
0005432799335	14818	4	2B
0005432799341	14818	5	2D
0005432799333	14818	6	3B
0005432799339	14818	7	4B
0005432799334	14818	8	4D
0005432799356	14818	9	5B
0005432799354	14818	10	6A
0005432799351	14818	11	6B
0005432799348	14818	12	6D
0005432799349	14818	13	7A
0005432799346	14818	14	7D
0005432799353	14818	15	18A
0005432799350	14818	16	18D
0005432799352	14818	17	19A
0005432799337	14818	18	19C
0005432799357	14818	19	19D
0005432799344	14818	20	20A
0005432799336	14818	21	20C
0005432799347	14818	22	21A
0005432799345	14818	23	21B
0005432799338	14818	24	21C
0005432799342	14818	25	22B
0005432799340	14818	26	22C
0005432799343	14818	27	22D
0005432799332	14818	28	23A
0005432799329	14818	29	23B
0005435293137	7078	1	1A
0005434407588	7078	2	1C
0005434407589	7078	3	1D
0005434407583	7078	4	2A
0005434299494	7078	5	1F
0005434299498	7078	6	2C
0005435293091	7078	7	2D
0005434299501	7078	8	3A
0005435310902	7078	9	2F
0005434407564	7078	10	3C
0005434407561	7078	11	3F
0005434407559	7078	12	3D
0005432153914	7078	13	4A
0005434407549	7078	14	4B
0005435293053	7078	15	4D
0005434407584	7078	16	4C
0005434407594	7078	17	4E
0005434407604	7078	18	4F
0005434299492	7078	19	5B
0005435310898	7078	20	5A
0005434407544	7078	21	5D
0005434407596	7078	22	5C
0005434299491	7078	23	5F
0005434407558	7078	24	5E
0005434407585	7078	25	6A
0005434407576	7078	26	6B
0005434299484	7078	27	6C
0005434407548	7078	28	6D
0005434299487	7078	29	6F
0005432153919	7078	30	6E
0005434407566	7078	31	7B
0005434299500	7078	32	7A
0005434299486	7078	33	7C
0005434407545	7078	34	7E
0005434299490	7078	35	7D
0005434407599	7078	36	8A
0005435310893	7078	37	7F
0005434407562	7078	38	8B
0005432153918	7078	39	8D
0005434407556	7078	40	8C
0005434407551	7078	41	8F
0005434407542	7078	42	8E
0005434407572	7078	43	9B
0005434299495	7078	44	9C
0005432153920	7078	45	9D
0005435293051	7078	46	9F
0005434299489	7078	47	9E
0005434407602	7078	48	10B
0005435310844	7078	49	10D
0005432108242	7078	50	10C
0005434299496	7078	51	11A
0005434407595	7078	52	11C
0005434299502	7078	53	11B
0005434407574	7078	54	11D
0005432153915	7078	55	11F
0005434407571	7078	56	11E
0005434407575	7078	57	12A
0005434299483	7078	58	12B
0005435310854	7078	59	12D
0005435310903	7078	60	12C
0005434407546	7078	61	12E
0005434299485	7078	62	12F
0005432108243	7078	63	13B
0005434407591	7078	64	13A
0005435310896	7078	65	13D
0005434407590	7078	66	13C
0005434407579	7078	67	13E
0005434407587	7078	68	13F
0005435293052	7078	69	14A
0005434299497	7078	70	14B
0005435293108	7078	71	14D
0005434407543	7078	72	14C
0005434407557	7078	73	14F
0005434407554	7078	74	14E
0005435310897	7078	75	15A
0005434407567	7078	76	15C
0005434407552	7078	77	15B
0005434407582	7078	78	15D
0005435293120	7078	79	15F
0005434299493	7078	80	15E
0005432153916	7078	81	16A
0005435293104	7078	82	16B
0005434407577	7078	83	16D
0005434407568	7078	84	16C
0005435293136	7078	85	16F
0005434407578	7078	86	16E
0005434407593	7078	87	17B
0005435293113	7078	88	17A
0005434407555	7078	89	17D
0005434407586	7078	90	17C
0005434299480	7078	91	17E
0005434407605	7078	92	18A
0005434407560	7078	93	17F
0005434299481	7078	94	18C
0005434407603	7078	95	18B
0005434299499	7078	96	18D
0005434407592	7078	97	18E
0005432153913	7078	98	18F
0005434407550	7078	99	19A
0005434407581	7078	100	19B
0005434407580	7078	101	19D
0005435310843	7078	102	19C
0005435293129	7078	103	19F
0005435293134	7078	104	19E
0005435293067	7078	105	20A
0005434407541	7078	106	20C
0005434299482	7078	107	20E
0005435293090	7078	108	20F
0005434407570	7078	109	21B
0005432153917	7078	110	21A
0005434407553	7078	111	21D
0005434407547	7078	112	21C
0005434407600	7078	113	21F
0005434299479	7078	114	21E
0005434407563	7078	115	22A
0005434407569	7078	116	22B
0005435293066	7078	117	22C
0005432108241	7078	118	22D
0005434407565	7078	119	22E
0005435310904	7078	120	22F
0005434407597	7078	121	23A
0005435310914	7078	122	23C
0005434407598	7078	123	23B
0005434407601	7078	124	23D
0005434407573	7078	125	23F
0005434299488	7078	126	23E
0005435293213	26939	1	1C
0005434406791	26939	2	1D
0005434406815	26939	3	2A
0005434407162	26939	4	1F
0005434299343	26939	5	2C
0005434407001	26939	6	2D
0005434299328	26939	7	2F
0005435311028	26939	8	3A
0005434407043	26939	9	3D
0005435293209	26939	10	3C
0005434407323	26939	11	3F
0005434407012	26939	12	4B
0005434407188	26939	13	4A
0005434406966	26939	14	4C
0005434406759	26939	15	4D
0005434407189	26939	16	4F
0005432058364	26939	17	5C
0005435293210	26939	18	5B
0005434299228	26939	19	5D
0005434406836	26939	20	6A
0005434406790	26939	21	5F
0005434406941	26939	22	6C
0005434406840	26939	23	6B
0005434406831	26939	24	6D
0005434406758	26939	25	6E
0005435311026	26939	26	6F
0005434406944	26939	27	7B
0005434299299	26939	28	7A
0005434299350	26939	29	7D
0005434407239	26939	30	7C
0005434299362	26939	31	7F
0005434407102	26939	32	7E
0005432058365	26939	33	8A
0005432058367	26939	34	8B
0005434406854	26939	35	8C
0005434406947	26939	36	8E
0005434406856	26939	37	8D
0005434406997	26939	38	8F
0005434299341	26939	39	9A
0005434406942	26939	40	9B
0005434407324	26939	41	9C
0005434407133	26939	42	9E
0005434299211	26939	43	9F
0005435293220	26939	44	10B
0005435311032	26939	45	10D
0005434299289	26939	46	10C
0005434406720	26939	47	10E
0005434406813	26939	48	11A
0005434299321	26939	49	11B
0005434299263	26939	50	11D
0005434406705	26939	51	11C
0005434407042	26939	52	11E
0005434406976	26939	53	11F
0005434406792	26939	54	12B
0005434406798	26939	55	12A
0005434406849	26939	56	12C
0005435293212	26939	57	12D
0005434407146	26939	58	12E
0005434299298	26939	59	12F
0005434406714	26939	60	13B
0005434406839	26939	61	13A
0005434407027	26939	62	13C
0005434407128	26939	63	13D
0005434407044	26939	64	13F
0005434407280	26939	65	14B
0005434406970	26939	66	14A
0005435293219	26939	67	14C
0005435311029	26939	68	14D
0005434299379	26939	69	14F
0005434299242	26939	70	15A
0005434299349	26939	71	15E
0005434406979	26939	72	16A
0005435293215	26939	73	15F
0005434406841	26939	74	16C
0005434407024	26939	75	16B
0005434406904	26939	76	16D
0005434406721	26939	77	17A
0005434406980	26939	78	16F
0005434406913	26939	79	17B
0005434299378	26939	80	17E
0005434407002	26939	81	18A
0005435311033	26939	82	17F
0005434407023	26939	83	18B
0005434299290	26939	84	18D
0005434407028	26939	85	18E
0005434407022	26939	86	19A
0005435311027	26939	87	18F
0005435293216	26939	88	19C
0005432058366	26939	89	19D
0005435311034	26939	90	19E
0005434406964	26939	91	19F
0005435311031	26939	92	20B
0005435293221	26939	93	20A
0005434406905	26939	94	20C
0005435293214	26939	95	20E
0005434406974	26939	96	20F
0005435293217	26939	97	21B
0005434406937	26939	98	21A
0005435311030	26939	99	21C
0005434299342	26939	100	21E
0005434407202	26939	101	22A
0005435293211	26939	102	21F
0005434406981	26939	103	22B
0005434406865	26939	104	22C
0005434406726	26939	105	22E
0005434406715	26939	106	22D
0005435293208	26939	107	23A
0005434299243	26939	108	23B
0005435293218	26939	109	23C
0005434406940	26939	110	23E
0005434406925	26939	111	23F
0005432604247	6441	1	1A
0005432604237	6441	2	1B
0005432604230	6441	3	1C
0005432604227	6441	4	1D
0005432604218	6441	5	2A
0005432604231	6441	6	2B
0005432604248	6441	7	2C
0005432604243	6441	8	2D
0005432604238	6441	9	3B
0005432604224	6441	10	3C
0005432604229	6441	11	3D
0005432604222	6441	12	4B
0005432604244	6441	13	4C
0005434512100	6441	14	4D
0005432604226	6441	15	5A
0005432604212	6441	16	5B
0005434512102	6441	17	5C
0005432604220	6441	18	5D
0005432604236	6441	19	6A
0005434512103	6441	20	6B
0005432604225	6441	21	6C
0005432604216	6441	22	6D
0005432604210	6441	23	7A
0005432604213	6441	24	7B
0005432604240	6441	25	7C
0005432604246	6441	26	7D
0005432604217	6441	27	18A
0005432604239	6441	28	18B
0005432604245	6441	29	18C
0005432604215	6441	30	19A
0005432604223	6441	31	19B
0005432604234	6441	32	19C
0005432604235	6441	33	19D
0005435218103	6441	34	20A
0005432604228	6441	35	20B
0005435220488	6441	36	20C
0005432604241	6441	37	20D
0005432604249	6441	38	21A
0005432604233	6441	39	21B
0005432604219	6441	40	21C
0005432604242	6441	41	21D
0005432604221	6441	42	22A
0005434512101	6441	43	22B
0005432604214	6441	44	22C
0005432604211	6441	45	22D
0005432604232	6441	46	23A
0005435218107	6441	47	23B
0005434512054	21393	1	1A
0005432603910	21393	2	1B
0005432603780	21393	3	1C
0005432603820	21393	4	1D
0005432603917	21393	5	2A
0005432603990	21393	6	2B
0005432603835	21393	7	2C
0005432603864	21393	8	2D
0005432603787	21393	9	3A
0005432603726	21393	10	3B
0005432603923	21393	11	3C
0005434512055	21393	12	3D
0005434512052	21393	13	4A
0005432603858	21393	14	4C
0005432603811	21393	15	4D
0005432603795	21393	16	5A
0005432603754	21393	17	5B
0005432603842	21393	18	5C
0005432604000	21393	19	5D
0005432603928	21393	20	6A
0005432603879	21393	21	6B
0005432603753	21393	22	6C
0005432603880	21393	23	6D
0005432603791	21393	24	7B
0005434512066	21393	25	7A
0005432603836	21393	26	7C
0005432603724	21393	27	7D
0005432603989	21393	28	18A
0005432603744	21393	29	18B
0005432603758	21393	30	18C
0005434512065	21393	31	18D
0005432603782	21393	32	19A
0005432603902	21393	33	19C
0005432603790	21393	34	20A
0005432603844	21393	35	20B
0005432603929	21393	36	20C
0005432603725	21393	37	21A
0005434512071	21393	38	21B
0005432603971	21393	39	21C
0005432603788	21393	40	21D
0005434512064	21393	41	22A
0005432603999	21393	42	22C
0005432603898	21393	43	22B
0005432603751	21393	44	22D
0005432603816	21393	45	23A
0005432603857	21393	46	23B
0005434906601	14994	1	1D
0005434906454	14994	2	1F
0005434906572	14994	3	2A
0005434906463	14994	4	2C
0005433251385	14994	5	2F
0005434906667	14994	6	2D
0005433251377	14994	7	3A
0005434906418	14994	8	3C
0005434906492	14994	9	3D
0005433251375	14994	10	4A
0005434906567	14994	11	4C
0005433251396	14994	12	4D
0005434906424	14994	13	4E
0005434906569	14994	14	4F
0005434906787	14994	15	5A
0005434906683	14994	16	5C
0005434906655	14994	17	5D
0005433251394	14994	18	5E
0005433251392	14994	19	5F
0005434906715	14994	20	6A
0005434906726	14994	21	6C
0005434906702	14994	22	6D
0005434906457	14994	23	6E
0005433251389	14994	24	6F
0005434906637	14994	25	7A
0005434906566	14994	26	7C
0005433251379	14994	27	7D
0005433251391	14994	28	7E
0005434906685	14994	29	7F
0005433251381	14994	30	8A
0005434906456	14994	31	8C
0005434906648	14994	32	8D
0005434906565	14994	33	8E
0005433251373	14994	34	9A
0005433251380	14994	35	9C
0005434906826	14994	36	9D
0005434906549	14994	37	9E
0005433251390	14994	38	9F
0005434906473	14994	39	10A
0005434906552	14994	40	10C
0005433251397	14994	41	10D
0005433251388	14994	42	10E
0005434906628	14994	43	11A
0005434906502	14994	44	11C
0005433251393	14994	45	11E
0005434906694	14994	46	12A
0005434906695	14994	47	12C
0005434906658	14994	48	12D
0005433251378	14994	49	12E
0005434906703	14994	50	12F
0005433251382	14994	51	13A
0005434906630	14994	52	13C
0005434906568	14994	53	13D
0005434906581	14994	54	13E
0005433251387	14994	55	14C
0005433251398	14994	56	14D
0005434906587	14994	57	14E
0005434906570	14994	58	14F
0005434906425	14994	59	15A
0005433251400	14994	60	15C
0005434906394	14994	61	15D
0005433251384	14994	62	15E
0005434906751	14994	63	15F
0005434906727	14994	64	16C
0005434906486	14994	65	16D
0005434906704	14994	66	16E
0005434906712	14994	67	16F
0005434906584	14994	68	17A
0005434906693	14994	69	17C
0005434906462	14994	70	17D
0005433251372	14994	71	17E
0005433251399	14994	72	17F
0005434906711	14994	73	18A
0005434906765	14994	74	18D
0005434906511	14994	75	18C
0005434906657	14994	76	18E
0005434906615	14994	77	18F
0005433251383	14994	78	19A
0005433251376	14994	79	19C
0005434906629	14994	80	19D
0005433251395	14994	81	19E
0005433251386	14994	82	19F
0005433251371	14994	83	20A
0005434906750	14994	84	20C
0005434906684	14994	85	20D
0005433251374	14994	86	20E
0005434906786	14994	87	20F
0005433251034	25840	1	1A
0005433251148	25840	2	1C
0005434907103	25840	3	1D
0005434907082	25840	4	1F
0005433250960	25840	5	2A
0005433250948	25840	6	2C
0005434907096	25840	7	2D
0005434907074	25840	8	2F
0005433250961	25840	9	3A
0005434907098	25840	10	3C
0005434907101	25840	11	3F
0005434907062	25840	12	4A
0005434907055	25840	13	4C
0005433251168	25840	14	4D
0005434907061	25840	15	4E
0005433251273	25840	16	5A
0005434907067	25840	17	5D
0005434907078	25840	18	5E
0005433251099	25840	19	5F
0005434907079	25840	20	6A
0005434907077	25840	21	6C
0005434907085	25840	22	6D
0005434907094	25840	23	6E
0005434907054	25840	24	6F
0005434907070	25840	25	7C
0005434907066	25840	26	7D
0005433251177	25840	27	7E
0005434907075	25840	28	7F
0005433251178	25840	29	8C
0005434907072	25840	30	8F
0005434907080	25840	31	9A
0005433251207	25840	32	9C
0005433251101	25840	33	9D
0005434907071	25840	34	9F
0005434907093	25840	35	10A
0005434907090	25840	36	10C
0005433251017	25840	37	10D
0005433251137	25840	38	10E
0005434907102	25840	39	10F
0005433250946	25840	40	11A
0005434907092	25840	41	11C
0005433251147	25840	42	11D
0005434907087	25840	43	11E
0005433251112	25840	44	11F
0005433251092	25840	45	12A
0005434907057	25840	46	12D
0005434907073	25840	47	12F
0005434907099	25840	48	13A
0005434907091	25840	49	13C
0005434907084	25840	50	13D
0005433250947	25840	51	13E
0005434907056	25840	52	13F
0005433251035	25840	53	14A
0005434907065	25840	54	14C
0005434907076	25840	55	14D
0005433251203	25840	56	14E
0005433251100	25840	57	14F
0005433251106	25840	58	15A
0005433250945	25840	59	15C
0005433251121	25840	60	15E
0005434907089	25840	61	15F
0005433251196	25840	62	16A
0005434907064	25840	63	16C
0005434907069	25840	64	16D
0005434907083	25840	65	16E
0005434907097	25840	66	17A
0005434907068	25840	67	17D
0005433251195	25840	68	17E
0005434907100	25840	69	17F
0005434907063	25840	70	18D
0005434907060	25840	71	18E
0005434907058	25840	72	19A
0005433251113	25840	73	19C
0005434907059	25840	74	19D
0005434907081	25840	75	19E
0005434907095	25840	76	19F
0005434907088	25840	77	20A
0005433251046	25840	78	20D
0005433251169	25840	79	20E
0005434907086	25840	80	20F
0005432609713	22482	1	1A
0005432607542	22482	2	1B
0005432607548	22482	3	1D
0005435842318	22482	4	2A
0005432607547	22482	5	2C
0005432609716	22482	6	3A
0005432607537	22482	7	3C
0005432607552	22482	8	3D
0005432609711	22482	9	4A
0005432607551	22482	10	4C
0005432609704	22482	11	5A
0005432607550	22482	12	5B
0005432607543	22482	13	5C
0005432609714	22482	14	5D
0005432607546	22482	15	6A
0005432607549	22482	16	6B
0005432607535	22482	17	6C
0005432609703	22482	18	7A
0005432607540	22482	19	7B
0005432609712	22482	20	7C
0005432607536	22482	21	7D
0005432609707	22482	22	18A
0005432609706	22482	23	18C
0005432607541	22482	24	18D
0005432609710	22482	25	19B
0005435842314	22482	26	19C
0005432609715	22482	27	20A
0005432609708	22482	28	20B
0005432607545	22482	29	20C
0005432609705	22482	30	20D
0005435841463	22482	31	21A
0005432609709	22482	32	21B
0005432607539	22482	33	21C
0005432607544	22482	34	22A
0005435842319	22482	35	22B
0005432607538	22482	36	22C
0005432609702	22482	37	23B
0005432609669	31722	1	1A
0005432609681	31722	2	1D
0005432609677	31722	3	2A
0005432609661	31722	4	2B
0005432613791	31722	5	3B
0005432613824	31722	6	3C
0005432609674	31722	7	4A
0005432613802	31722	8	4D
0005432613811	31722	9	5A
0005432609675	31722	10	5C
0005432609660	31722	11	5D
0005432613806	31722	12	6A
0005432613793	31722	13	6B
0005432609676	31722	14	6D
0005432613792	31722	15	7A
0005432609670	31722	16	7B
0005432613809	31722	17	7C
0005432613810	31722	18	18B
0005432613801	31722	19	18C
0005432613814	31722	20	18D
0005432613803	31722	21	19A
0005432613831	31722	22	19B
0005432613805	31722	23	19C
0005432613815	31722	24	19D
0005432613804	31722	25	20A
0005432609692	31722	26	20B
0005432613813	31722	27	20D
0005432613832	31722	28	21A
0005432609671	31722	29	21B
0005435841093	31722	30	21C
0005432609659	31722	31	21D
0005432613798	31722	32	22A
0005432613790	31722	33	22B
0005432609658	31722	34	22C
0005432613812	31722	35	22D
0005433008475	14207	1	1D
0005433008490	14207	2	1F
0005433008487	14207	3	2A
0005433008517	14207	4	2D
0005433008507	14207	5	3A
0005433810492	14207	6	3C
0005433008480	14207	7	3F
0005433008489	14207	8	4A
0005433008481	14207	9	4C
0005433008502	14207	10	4D
0005433008488	14207	11	4E
0005433008516	14207	12	4F
0005433008495	14207	13	6C
0005433008497	14207	14	6F
0005433008494	14207	15	7C
0005433008474	14207	16	7D
0005433008483	14207	17	8A
0005433008505	14207	18	8C
0005433008514	14207	19	8D
0005433008478	14207	20	8E
0005433008477	14207	21	9E
0005433008492	14207	22	10E
0005433008472	14207	23	11A
0005433008515	14207	24	11E
0005433008485	14207	25	12A
0005433008479	14207	26	12C
0005433008509	14207	27	12E
0005433008501	14207	28	13A
0005433008493	14207	29	13E
0005433008500	14207	30	13F
0005433008503	14207	31	14A
0005433008486	14207	32	14C
0005433008512	14207	33	14E
0005433008484	14207	34	15D
0005433008498	14207	35	15E
0005433008510	14207	36	16A
0005433810491	14207	37	16D
0005433008504	14207	38	16E
0005433008473	14207	39	17D
0005433008496	14207	40	17E
0005433008506	14207	41	18A
0005433008482	14207	42	18D
0005433008508	14207	43	18E
0005433008476	14207	44	18F
0005433008513	14207	45	19A
0005433008491	14207	46	19C
0005433008499	14207	47	19D
0005433008511	14207	48	20D
0005433810527	22846	1	1A
0005433008127	22846	2	1F
0005433008051	22846	3	2A
0005433810526	22846	4	2C
0005433008083	22846	5	2F
0005433810525	22846	6	3A
0005433008057	22846	7	3D
0005433007957	22846	8	4C
0005433008059	22846	9	4D
0005433008012	22846	10	4F
0005433008040	22846	11	5C
0005433007942	22846	12	5D
0005433008058	22846	13	6E
0005433008189	22846	14	6F
0005433008026	22846	15	7D
0005433007926	22846	16	7E
0005433008067	22846	17	7F
0005433008222	22846	18	8A
0005433008052	22846	19	8C
0005433008137	22846	20	8D
0005433008179	22846	21	8E
0005433008082	22846	22	8F
0005433008064	22846	23	9A
0005433008093	22846	24	9C
0005433008070	22846	25	9D
0005433007922	22846	26	9E
0005433008086	22846	27	9F
0005433008177	22846	28	10A
0005433008066	22846	29	10C
0005433008007	22846	30	11C
0005433008010	22846	31	11E
0005433008190	22846	32	12A
0005433007941	22846	33	12D
0005433008090	22846	34	12E
0005433008180	22846	35	13A
0005433810524	22846	36	13D
0005433008020	22846	37	14D
0005433008065	22846	38	14F
0005433007984	22846	39	15D
0005433007927	22846	40	16A
0005433007902	22846	41	16C
0005433008191	22846	42	16D
0005433008011	22846	43	16E
0005433007903	22846	44	17A
0005433007955	22846	45	17D
0005433008167	22846	46	17E
0005433007993	22846	47	17F
0005433008105	22846	48	19A
0005433007996	22846	49	19C
0005433008075	22846	50	19D
0005433008084	22846	51	19F
0005433008254	22846	52	20D
0005433810528	22846	53	20E
0005433007956	22846	54	20F
0005434925248	14932	1	3A
0005434925466	14932	2	3C
0005434925391	14932	3	4A
0005434925370	14932	4	4E
0005434925403	14932	5	5A
0005434925424	14932	6	5F
0005434925461	14932	7	7F
0005434925452	14932	8	8F
0005434925273	14932	9	9A
0005434925451	14932	10	9D
0005434925421	14932	11	9F
0005434925299	14932	12	10A
0005434925455	14932	13	10D
0005434925444	14932	14	10E
0005434925344	14932	15	10F
0005434925369	14932	16	11E
0005434925433	14932	17	13D
0005434925418	14932	18	15C
0005434925462	14932	19	15F
0005434925449	14932	20	16C
0005434925425	14932	21	16D
0005434925300	14932	22	16F
0005434925453	14932	23	17A
0005434925383	14932	24	17D
0005434925293	14932	25	17F
0005434925388	14932	26	18A
0005434925423	14932	27	18D
0005434925402	14932	28	18E
0005434925371	14932	29	19C
0005434925467	14932	30	19E
0005434925443	14932	31	20C
0005434925264	14932	32	20D
0005434925679	20505	1	1F
0005434925697	20505	2	2A
0005434925678	20505	3	2F
0005434925702	20505	4	3A
0005434925708	20505	5	3C
0005434925703	20505	6	4C
0005434925698	20505	7	5D
0005434925701	20505	8	5F
0005434925713	20505	9	6C
0005434925690	20505	10	6D
0005434925716	20505	11	7A
0005434925689	20505	12	8D
0005434925700	20505	13	8F
0005434925714	20505	14	9A
0005434925687	20505	15	9D
0005434925680	20505	16	10A
0005434925709	20505	17	10F
0005434925693	20505	18	11A
0005434925705	20505	19	11E
0005434925696	20505	20	12C
0005434925694	20505	21	12E
0005434925682	20505	22	13A
0005434925711	20505	23	14E
0005434925692	20505	24	14F
0005434925715	20505	25	15A
0005434925710	20505	26	16D
0005434925688	20505	27	16E
0005434925691	20505	28	16F
0005434925686	20505	29	17A
0005434925712	20505	30	17C
0005434925681	20505	31	17E
0005434925684	20505	32	17F
0005434925707	20505	33	18E
0005434925685	20505	34	19C
0005434925699	20505	35	19D
0005434925683	20505	36	19E
0005434925704	20505	37	20C
0005434925706	20505	38	20E
0005434925695	20505	39	20F
0005435998971	15789	1	1A
0005435487776	15789	2	1B
0005435487773	15789	3	1C
0005435487785	15789	4	1D
0005435487768	15789	5	2A
0005435999047	15789	6	2B
0005435487783	15789	7	2C
0005435999048	15789	8	2D
0005435999018	15789	9	3A
0005435999052	15789	10	3B
0005435487784	15789	11	3C
0005435999021	15789	12	3D
0005435999053	15789	13	4A
0005435999083	15789	14	4C
0005435487774	15789	15	4B
0005435487766	15789	16	4D
0005435999088	15789	17	5A
0005435999036	15789	18	5B
0005435999066	15789	19	5C
0005435999063	15789	20	5D
0005435999067	15789	21	6A
0005435999059	15789	22	6B
0005435999077	15789	23	6C
0005435999050	15789	24	7A
0005435487765	15789	25	6D
0005435999001	15789	26	7B
0005435999049	15789	27	7C
0005435487770	15789	28	18A
0005435998988	15789	29	18B
0005435487782	15789	30	18C
0005435487779	15789	31	18D
0005435487764	15789	32	19B
0005435999070	15789	33	19C
0005435487769	15789	34	19D
0005435999058	15789	35	20A
0005435999064	15789	36	20B
0005435487778	15789	37	20C
0005435487781	15789	38	20D
0005435999022	15789	39	21A
0005435487777	15789	40	21B
0005435487780	15789	41	21C
0005435487771	15789	42	21D
0005435487772	15789	43	22A
0005435998972	15789	44	22B
0005435999019	15789	45	22C
0005435999020	15789	46	22D
0005435487767	15789	47	23A
0005435487775	15789	48	23B
0005435487517	19670	1	1B
0005435487551	19670	2	1C
0005435487530	19670	3	1D
0005435487519	19670	4	2A
0005435487567	19670	5	2C
0005435487518	19670	6	2D
0005435999184	19670	7	3A
0005435999190	19670	8	3B
0005435999186	19670	9	3D
0005435487614	19670	10	4A
0005435487638	19670	11	4B
0005435487607	19670	12	5A
0005435487474	19670	13	5C
0005435487481	19670	14	6B
0005435487613	19670	15	6C
0005435999194	19670	16	6D
0005435487608	19670	17	7A
0005435487562	19670	18	7B
0005435999183	19670	19	7D
0005435999188	19670	20	18B
0005435999193	19670	21	18C
0005435487595	19670	22	18D
0005435999187	19670	23	19A
0005435999191	19670	24	19B
0005435999192	19670	25	19C
0005435999189	19670	26	20B
0005435999182	19670	27	20C
0005435487553	19670	28	21A
0005435999195	19670	29	21B
0005435487566	19670	30	22A
0005435487473	19670	31	22B
0005435487583	19670	32	22C
0005435999185	19670	33	22D
0005435487596	19670	34	23A
0005435487606	19670	35	23B
0005435839367	5979	1	1C
0005435839380	5979	2	1F
0005435472593	5979	3	2D
0005435839371	5979	4	2C
0005435472620	5979	5	3C
0005432537026	5979	6	3F
0005435472607	5979	7	4C
0005435839381	5979	8	4A
0005432537027	5979	9	4D
0005435839363	5979	10	5C
0005435839365	5979	11	5A
0005435839370	5979	12	6C
0005432658587	5979	13	7A
0005435839383	5979	14	6F
0005432142244	5979	15	7C
0005435472576	5979	16	7B
0005435839377	5979	17	7E
0005432660813	5979	18	7F
0005435839387	5979	19	8B
0005432658585	5979	20	8D
0005435472614	5979	21	8C
0005432142243	5979	22	9B
0005432660814	5979	23	9A
0005435839388	5979	24	9D
0005435472609	5979	25	9E
0005432142242	5979	26	9F
0005435472650	5979	27	10D
0005435839364	5979	28	10C
0005435839385	5979	29	10B
0005432659701	5979	30	10E
0005435839389	5979	31	11A
0005435839369	5979	32	10F
0005435472656	5979	33	11B
0005435472643	5979	34	11D
0005432537025	5979	35	11C
0005435839372	5979	36	11F
0005435839373	5979	37	11E
0005435472615	5979	38	12F
0005435839386	5979	39	13D
0005435839368	5979	40	14A
0005435839366	5979	41	13F
0005435839382	5979	42	14B
0005435839374	5979	43	14D
0005432659702	5979	44	14C
0005435839361	5979	45	15D
0005435839362	5979	46	15C
0005432660812	5979	47	16C
0005435472577	5979	48	16B
0005435839384	5979	49	17A
0005435472649	5979	50	18C
0005435472644	5979	51	18E
0005435839379	5979	52	18F
0005435472608	5979	53	20A
0005435839378	5979	54	19F
0005435472598	5979	55	20F
0005435472642	5979	56	21B
0005435839376	5979	57	21A
0005435839375	5979	58	21C
0005432658586	5979	59	21D
0005435839216	18066	1	2C
0005435472748	18066	2	2A
0005435839164	18066	3	3C
0005435472764	18066	4	3D
0005435839182	18066	5	4F
0005435839162	18066	6	4D
0005435839066	18066	7	6B
0005432667428	18066	8	6A
0005435472759	18066	9	7A
0005435472763	18066	10	7B
0005435839142	18066	11	7D
0005432660788	18066	12	7F
0005435472753	18066	13	8C
0005435472758	18066	14	8A
0005435472756	18066	15	8F
0005435839052	18066	16	9A
0005435839255	18066	17	10C
0005435472755	18066	18	10B
0005435839004	18066	19	10E
0005435839082	18066	20	10D
0005435839005	18066	21	11D
0005435839151	18066	22	11C
0005435839133	18066	23	11E
0005432537053	18066	24	12C
0005432660789	18066	25	12F
0005435472760	18066	26	13B
0005432660790	18066	27	13E
0005435839062	18066	28	13D
0005435839143	18066	29	14A
0005435839063	18066	30	14D
0005435472761	18066	31	14F
0005435472762	18066	32	15B
0005435839148	18066	33	15D
0005435839144	18066	34	16B
0005435839217	18066	35	16A
0005435839163	18066	36	16C
0005435472754	18066	37	16E
0005435839190	18066	38	16F
0005435472751	18066	39	17B
0005435472757	18066	40	17D
0005435839083	18066	41	17F
0005435839147	18066	42	17E
0005435839169	18066	43	18C
0005435839127	18066	44	18E
0005432667427	18066	45	18D
0005435839081	18066	46	19B
0005435839170	18066	47	19D
0005435839065	18066	48	20B
0005432667426	18066	49	20C
0005435472749	18066	50	20F
0005435839145	18066	51	20E
0005435472752	18066	52	21D
0005435839161	18066	53	21B
0005435472750	18066	54	21E
0005433462733	17266	1	1A
0005433462735	17266	2	3C
0005433463884	17266	3	4F
0005433462731	17266	4	9H
0005433462736	17266	5	11B
0005433463894	17266	6	11F
0005433463882	17266	7	14G
0005433463892	17266	8	15D
0005433463885	17266	9	15F
0005433463888	17266	10	15H
0005433462725	17266	11	16G
0005433463891	17266	12	17A
0005433462739	17266	13	17E
0005433462734	17266	14	18D
0005433462729	17266	15	19D
0005433462730	17266	16	20B
0005433463881	17266	17	20H
0005433463887	17266	18	21E
0005433463893	17266	19	21G
0005433463883	17266	20	22B
0005433462732	17266	21	22F
0005433463889	17266	22	23A
0005433462737	17266	23	24A
0005433462741	17266	24	24B
0005433463890	17266	25	27E
0005433463886	17266	26	28B
0005433462738	17266	27	28D
0005433462727	17266	28	29H
0005433462740	17266	29	31E
0005433462728	17266	30	31G
0005433463880	17266	31	34B
0005433462726	17266	32	37E
0005433463879	17266	33	38B
0005433284780	23046	1	2C
0005433284947	23046	2	4F
0005433284946	23046	3	5B
0005433285030	23046	4	5C
0005435103905	23046	5	5F
0005433284944	23046	6	6D
0005433284923	23046	7	7E
0005433285015	23046	8	9C
0005435103904	23046	9	11A
0005433284967	23046	10	11C
0005433285062	23046	11	12C
0005433285035	23046	12	12E
0005433284958	23046	13	12F
0005433285003	23046	14	14A
0005433285036	23046	15	14E
0005435103908	23046	16	15B
0005433284961	23046	17	15D
0005435103907	23046	18	15E
0005433284950	23046	19	16C
0005433284866	23046	20	16D
0005433284914	23046	21	17A
0005433285014	23046	22	18A
0005435103906	23046	23	18B
0005433284945	23046	24	18D
0005433284925	23046	25	18E
0005433285060	23046	26	19B
0005433284781	23046	27	19E
0005433284924	23046	28	20D
0005433284966	23046	29	20C
0005433284930	23046	30	20E
0005435103903	23046	31	21A
0005433284933	23046	32	21E
0005433284949	23046	33	21F
0005435103902	23046	34	22B
0005433285061	23046	35	22F
0005433285223	32063	1	2A
0005435103822	32063	2	3D
0005433285230	32063	3	4A
0005433285226	32063	4	4E
0005435103798	32063	5	5C
0005433285218	32063	6	5D
0005433285221	32063	7	5E
0005433285209	32063	8	5F
0005433285204	32063	9	7A
0005433285215	32063	10	8D
0005435103801	32063	11	9E
0005433285216	32063	12	9F
0005433285229	32063	13	10B
0005433285231	32063	14	11A
0005433285222	32063	15	11D
0005433285225	32063	16	12B
0005433285212	32063	17	13B
0005433285203	32063	18	13D
0005433285205	32063	19	13E
0005433285206	32063	20	13F
0005433285224	32063	21	14B
0005433285211	32063	22	14F
0005433285219	32063	23	15A
0005433285217	32063	24	16C
0005435103805	32063	25	16F
0005433285227	32063	26	17C
0005435103821	32063	27	17D
0005435103824	32063	28	18A
0005433285213	32063	29	18B
0005433285202	32063	30	19E
0005433285207	32063	31	20B
0005435103804	32063	32	20D
0005433285210	32063	33	20C
0005433285199	32063	34	21A
0005435103825	32063	35	21E
0005433285208	32063	36	21F
0005433285201	32063	37	22A
0005433285214	32063	38	22B
0005433285220	32063	39	22D
0005433285228	32063	40	22E
0005433285200	32063	41	23B
0005432533262	30628	1	1C
0005433656665	30628	2	1A
0005435213430	30628	3	1G
0005435213411	30628	4	1D
0005435213373	30628	5	1K
0005432527033	30628	6	1H
0005432525772	30628	7	2D
0005432526649	30628	8	2H
0005435725592	30628	9	2G
0005432526685	30628	10	3D
0005432526074	30628	11	3C
0005432526950	30628	12	3H
0005434066591	30628	13	4C
0005432526546	30628	14	4A
0005432525876	30628	15	4G
0005432526242	30628	16	4D
0005432526583	30628	17	4K
0005432526655	30628	18	4H
0005432526751	30628	19	5C
0005432526431	30628	20	5A
0005432428895	30628	21	5H
0005432211486	30628	22	5G
0005432526053	30628	23	11A
0005432526211	30628	24	5K
0005435213422	30628	25	11C
0005434066540	30628	26	11F
0005434066618	30628	27	11E
0005432526045	30628	28	11H
0005435213369	30628	29	11G
0005434066982	30628	30	12A
0005432526534	30628	31	12D
0005435213421	30628	32	12K
0005432526435	30628	33	13D
0005435213418	30628	34	13A
0005435213385	30628	35	13E
0005432525998	30628	36	13K
0005434066944	30628	37	13H
0005432428888	30628	38	13G
0005435213396	30628	39	14A
0005434066661	30628	40	14E
0005434066874	30628	41	14K
0005432526793	30628	42	14H
0005432526803	30628	43	14G
0005435283408	30628	44	15C
0005434066834	30628	45	15A
0005432211487	30628	46	15E
0005434066942	30628	47	15D
0005432526471	30628	48	15G
0005434066500	30628	49	15F
0005432526923	30628	50	16A
0005434066643	30628	51	15K
0005435213432	30628	52	16D
0005434066841	30628	53	16C
0005435213427	30628	54	16G
0005432428889	30628	55	16F
0005435213402	30628	56	16H
0005432526133	30628	57	17C
0005435213372	30628	58	17A
0005432526715	30628	59	16K
0005435213391	30628	60	17E
0005432535787	30628	61	17D
0005432527242	30628	62	17H
0005434066975	30628	63	17G
0005435213383	30628	64	18B
0005432526790	30628	65	18A
0005434066727	30628	66	18F
0005432526475	30628	67	18J
0005432526160	30628	68	18H
0005434066479	30628	69	18K
0005432526412	30628	70	19D
0005432526210	30628	71	19F
0005435213413	30628	72	19E
0005432525983	30628	73	19H
0005432526310	30628	74	19G
0005434066666	30628	75	19K
0005435213420	30628	76	19J
0005434066924	30628	77	20C
0005435213368	30628	78	20B
0005432526326	30628	79	20A
0005432527288	30628	80	20E
0005432537030	30628	81	20D
0005432526548	30628	82	20G
0005435213415	30628	83	20F
0005435213436	30628	84	20J
0005434066578	30628	85	20H
0005435213410	30628	86	21A
0005434066457	30628	87	21D
0005432526330	30628	88	21C
0005435213425	30628	89	21F
0005434066943	30628	90	21H
0005432526840	30628	91	22A
0005435213400	30628	92	21K
0005435213433	30628	93	22C
0005434066765	30628	94	22B
0005434066754	30628	95	22F
0005435630962	30628	96	22D
0005432526656	30628	97	22G
0005434066555	30628	98	22H
0005432526527	30628	99	23B
0005434066511	30628	100	23A
0005432526634	30628	101	23E
0005434066719	30628	102	23D
0005435213387	30628	103	23C
0005435213416	30628	104	23G
0005435213412	30628	105	23F
0005432526635	30628	106	23J
0005432526533	30628	107	23H
0005435213401	30628	108	24E
0005432526735	30628	109	24D
0005432159850	30628	110	25A
0005432535760	30628	111	24G
0005432527054	30628	112	25D
0005434066590	30628	113	25C
0005432526269	30628	114	25B
0005435213408	30628	115	25F
0005432526516	30628	116	25E
0005435213395	30628	117	25H
0005432526479	30628	118	25K
0005434066522	30628	119	25J
0005432526932	30628	120	26C
0005435213379	30628	121	26B
0005432526322	30628	122	26A
0005435213404	30628	123	26G
0005432211488	30628	124	26F
0005432526562	30628	125	26J
0005435213394	30628	126	26H
0005434066723	30628	127	27B
0005432527218	30628	128	26K
0005435213438	30628	129	27C
0005432526046	30628	130	27F
0005434066561	30628	131	27G
0005432526492	30628	132	27K
0005432211482	30628	133	27J
0005434066560	30628	134	28C
0005435213389	30628	135	28A
0005435213382	30628	136	28E
0005432535775	30628	137	28G
0005435213388	30628	138	28F
0005432533259	30628	139	28J
0005435213429	30628	140	28H
0005432526429	30628	141	29B
0005434066763	30628	142	29A
0005432526722	30628	143	28K
0005432526272	30628	144	29C
0005435213370	30628	145	29F
0005432526671	30628	146	29E
0005434066851	30628	147	29H
0005432428899	30628	148	29J
0005435213384	30628	149	30C
0005432526993	30628	150	30B
0005435213390	30628	151	30A
0005432527043	30628	152	30E
0005435213380	30628	153	30D
0005432526949	30628	154	30G
0005435630961	30628	155	30J
0005434066456	30628	156	31A
0005434066875	30628	157	31C
0005432211481	30628	158	31F
0005435725591	30628	159	31E
0005432535761	30628	160	31H
0005432526517	30628	161	31G
0005434066649	30628	162	31K
0005432526704	30628	163	31J
0005432526506	30628	164	32C
0005434066726	30628	165	32B
0005432526419	30628	166	32A
0005432526532	30628	167	32E
0005435213398	30628	168	32G
0005435213409	30628	169	32F
0005434066644	30628	170	32J
0005434066667	30628	171	33B
0005433656663	30628	172	33A
0005432526731	30628	173	33C
0005435213424	30628	174	33F
0005435213419	30628	175	33E
0005434066995	30628	176	33H
0005432526705	30628	177	34A
0005434066588	30628	178	33K
0005435213393	30628	179	33J
0005432526346	30628	180	34C
0005434066604	30628	181	34B
0005434066835	30628	182	34E
0005432527053	30628	183	34D
0005434066673	30628	184	34H
0005435213426	30628	185	34G
0005432525773	30628	186	34F
0005435213371	30628	187	34K
0005432527044	30628	188	34J
0005434066710	30628	189	35D
0005432526268	30628	190	35C
0005432526701	30628	191	35B
0005432526740	30628	192	35F
0005435213417	30628	193	35J
0005432159846	30628	194	35H
0005435213381	30628	195	35G
0005432159845	30628	196	36A
0005434066672	30628	197	35K
0005432527034	30628	198	36C
0005432526738	30628	199	36F
0005432526645	30628	200	36E
0005432526260	30628	201	36D
0005432527095	30628	202	36H
0005432211485	30628	203	36G
0005432211483	30628	204	37B
0005434066918	30628	205	37A
0005432526831	30628	206	36K
0005432159849	30628	207	37E
0005432526464	30628	208	37D
0005432526599	30628	209	37C
0005432526062	30628	210	37F
0005432526730	30628	211	37H
0005435213423	30628	212	37G
0005434066685	30628	213	38A
0005435213397	30628	214	37K
0005432526905	30628	215	37J
0005432525814	30628	216	38C
0005434066406	30628	217	38B
0005432159847	30628	218	38J
0005434066928	30628	219	38H
0005434066523	30628	220	39A
0005432527098	30628	221	38K
0005432428883	30628	222	39D
0005434066407	30628	223	39C
0005435213375	30628	224	39F
0005432527219	30628	225	39E
0005432526271	30628	226	39H
0005432526723	30628	227	39G
0005435213399	30628	228	40A
0005434066626	30628	229	39K
0005434066833	30628	230	39J
0005432526588	30628	231	40C
0005432526323	30628	232	40B
0005435213378	30628	233	40E
0005432526893	30628	234	40D
0005434066840	30628	235	40H
0005432526558	30628	236	40F
0005432525934	30628	237	40J
0005432526610	30628	238	41D
0005434066884	30628	239	41C
0005432526825	30628	240	41B
0005432526430	30628	241	41F
0005432526518	30628	242	41E
0005435213406	30628	243	41J
0005434066764	30628	244	41H
0005432526600	30628	245	42A
0005434066858	30628	246	42C
0005434066463	30628	247	42B
0005432526371	30628	248	42D
0005434067015	30628	249	42G
0005432527197	30628	250	42F
0005435213405	30628	251	42H
0005434066613	30628	252	43B
0005432526564	30628	253	43D
0005434066759	30628	254	43C
0005432159848	30628	255	43E
0005434066807	30628	256	43J
0005434066755	30628	257	43H
0005432526258	30628	258	43G
0005432526680	30628	259	44A
0005432533261	30628	260	43K
0005432527094	30628	261	44E
0005435630960	30628	262	44C
0005435725590	30628	263	44G
0005432526706	30628	264	44F
0005432526670	30628	265	44J
0005434066959	30628	266	45A
0005432526214	30628	267	44K
0005432526311	30628	268	45D
0005435213377	30628	269	45B
0005435213428	30628	270	45F
0005432526734	30628	271	45E
0005433656666	30628	272	45G
0005432526261	30628	273	46A
0005432526052	30628	274	45K
0005432535786	30628	275	46C
0005434067086	30628	276	46B
0005432525813	30628	277	46E
0005435213376	30628	278	46D
0005432535793	30628	279	46G
0005434066589	30628	280	46F
0005435213414	30628	281	46K
0005432527196	30628	282	46J
0005432526789	30628	283	46H
0005432526707	30628	284	47D
0005435213431	30628	285	47C
0005434066655	30628	286	47G
0005435213407	30628	287	47F
0005433656664	30628	288	47E
0005435213392	30628	289	47K
0005432527078	30628	290	47H
0005435213437	30628	291	48D
0005432526763	30628	292	48A
0005432526082	30628	293	48F
0005432526528	30628	294	48E
0005432526774	30628	295	48H
0005435213435	30628	296	48G
0005435213403	30628	297	49A
0005432527050	30628	298	48K
0005434066521	30628	299	49D
0005434066921	30628	300	49F
0005432526266	30628	301	49E
0005434066606	30628	302	49K
0005432526837	30628	303	49H
0005435213434	30628	304	49G
0005432526594	30628	305	50D
0005435213386	30628	306	50C
0005432526633	30628	307	50A
0005434066724	30628	308	50E
0005432211484	30628	309	50G
0005432526951	30628	310	50F
0005432526826	30628	311	50K
0005435213374	30628	312	51F
0005432527287	30628	313	51D
0005432526636	30628	314	51G
0005435652592	24859	1	1A
0005433367816	24859	2	1C
0005433367823	24859	3	1D
0005433367796	24859	4	1F
0005433367799	24859	5	2A
0005435652430	24859	6	2C
0005435652528	24859	7	2D
0005433367801	24859	8	2F
0005433367800	24859	9	3A
0005435652629	24859	10	3C
0005433367815	24859	11	3D
0005435652542	24859	12	4C
0005433367827	24859	13	4D
0005433367805	24859	14	4E
0005435652400	24859	15	4F
0005435652489	24859	16	5C
0005435652661	24859	17	5D
0005435652396	24859	18	5F
0005433367794	24859	19	6A
0005433367831	24859	20	6C
0005435652620	24859	21	6D
0005435652539	24859	22	6F
0005435652537	24859	23	7A
0005435652443	24859	24	7D
0005435652531	24859	25	7E
0005435652533	24859	26	7F
0005433367811	24859	27	8A
0005433367826	24859	28	8C
0005435652562	24859	29	8D
0005435652529	24859	30	8F
0005435652493	24859	31	8E
0005433367828	24859	32	9A
0005433367813	24859	33	9C
0005433367817	24859	34	9D
0005435652662	24859	35	10A
0005435652607	24859	36	10E
0005433367824	24859	37	10F
0005435652484	24859	38	11C
0005435652630	24859	39	11E
0005435652385	24859	40	11D
0005435652541	24859	41	11F
0005435652447	24859	42	12A
0005435652548	24859	43	12C
0005435652555	24859	44	12D
0005433367832	24859	45	12E
0005433367814	24859	46	12F
0005433367806	24859	47	13A
0005433367802	24859	48	13C
0005433367818	24859	49	13D
0005433367795	24859	50	13E
0005433367830	24859	51	13F
0005435652459	24859	52	14A
0005433367822	24859	53	14D
0005433367804	24859	54	14C
0005433367808	24859	55	14E
0005435652471	24859	56	14F
0005433367820	24859	57	15A
0005435652448	24859	58	15C
0005435652497	24859	59	15D
0005433367819	24859	60	15E
0005433367821	24859	61	15F
0005435652563	24859	62	16A
0005435652517	24859	63	16C
0005433367807	24859	64	16E
0005433367810	24859	65	16F
0005433367829	24859	66	17A
0005435652492	24859	67	17C
0005435652360	24859	68	17D
0005433367797	24859	69	17E
0005433367809	24859	70	18A
0005435652534	24859	71	18C
0005433367798	24859	72	18D
0005435652483	24859	73	18E
0005433367812	24859	74	18F
0005435652660	24859	75	19A
0005435652458	24859	76	19C
0005435652359	24859	77	19D
0005435652554	24859	78	19E
0005433367825	24859	79	19F
0005435652516	24859	80	20A
0005435652518	24859	81	20C
0005435652395	24859	82	20E
0005433367803	24859	83	20F
0005434979733	2072	1	1A
0005434979729	2072	2	1B
0005434979718	2072	3	1C
0005434979741	2072	4	1D
0005434979726	2072	5	2B
0005434979737	2072	6	2C
0005434979716	2072	7	2D
0005435801690	2072	8	3B
0005434979724	2072	9	3C
0005434979743	2072	10	4A
0005434979734	2072	11	4B
0005434979714	2072	12	4D
0005434979720	2072	13	5C
0005434979742	2072	14	6A
0005434979722	2072	15	6B
0005434979731	2072	16	6C
0005434979715	2072	17	7B
0005434979723	2072	18	7C
0005434979721	2072	19	7D
0005434979717	2072	20	18D
0005434979739	2072	21	19A
0005434979738	2072	22	19B
0005434979736	2072	23	19C
0005434979735	2072	24	20B
0005434979740	2072	25	20C
0005434979730	2072	26	20D
0005435801688	2072	27	21B
0005435801689	2072	28	21C
0005434979725	2072	29	21D
0005434979727	2072	30	22B
0005434979728	2072	31	22D
0005434979732	2072	32	23A
0005434979719	2072	33	23B
0005434979411	23568	1	1A
0005434979438	23568	2	1B
0005434979487	23568	3	1C
0005434979354	23568	4	1D
0005434979484	23568	5	2B
0005434979425	23568	6	2A
0005434979446	23568	7	2C
0005434979275	23568	8	2D
0005435801672	23568	9	3A
0005434979417	23568	10	3B
0005434979412	23568	11	3C
0005434979379	23568	12	3D
0005434979270	23568	13	4A
0005434979418	23568	14	4D
0005434979317	23568	15	5A
0005434979353	23568	16	5B
0005435801673	23568	17	5C
0005434979303	23568	18	5D
0005434979432	23568	19	6A
0005434979375	23568	20	6D
0005434979327	23568	21	7C
0005434979343	23568	22	7B
0005434979392	23568	23	18C
0005435801658	23568	24	18D
0005434979483	23568	25	19A
0005434979344	23568	26	19B
0005434979424	23568	27	19D
0005434979445	23568	28	20B
0005434979347	23568	29	21A
0005434979482	23568	30	21B
0005434979274	23568	31	21C
0005434979397	23568	32	21D
0005434979378	23568	33	22A
0005434979281	23568	34	22C
0005434979433	23568	35	22D
0005435801659	23568	36	23A
0005434979437	23568	37	23B
0005434952525	2557	1	2B
0005434952524	2557	2	3B
0005434952522	2557	3	5A
0005434952523	2557	4	6A
0005434952526	2557	5	6B
0005433256402	2558	1	3A
0005433256409	2558	2	3B
0005433256408	2558	3	5B
0005433256416	28197	1	1B
0005434952480	28197	2	2A
0005433256417	28197	3	3A
0005434952494	28197	4	4B
0005434952493	28197	5	5B
0005433112370	19772	1	3B
0005433112369	19772	2	4A
0005433111502	19772	3	6A
0005434137402	11943	1	1C
0005434137438	11943	2	1D
0005434137181	11943	3	1F
0005434137526	11943	4	2D
0005434137392	11943	5	2F
0005434137059	11943	6	3C
0005434137537	11943	7	3D
0005434137185	11943	8	3F
0005434137177	11943	9	4C
0005434137529	11943	10	4D
0005434137466	11943	11	4E
0005434137227	11943	12	4F
0005434137351	11943	13	5A
0005434137287	11943	14	5D
0005434137005	11943	15	5E
0005434137256	11943	16	5F
0005434137239	11943	17	6A
0005434137152	11943	18	6C
0005434137597	11943	19	6D
0005434136969	11943	20	6F
0005434137354	11943	21	7A
0005434137579	11943	22	7C
0005434137197	11943	23	7D
0005434137151	11943	24	7E
0005434137118	11943	25	7F
0005434137350	11943	26	8A
0005434137233	11943	27	8C
0005434137472	11943	28	8D
0005434137439	11943	29	8E
0005434137353	11943	30	8F
0005434137403	11943	31	9A
0005434136970	11943	32	9C
0005434137408	11943	33	9D
0005434137346	11943	34	10A
0005434137347	11943	35	10C
0005434137178	11943	36	10D
0005434137591	11943	37	10E
0005434137279	11943	38	10F
0005434137117	11943	39	11A
0005434137490	11943	40	11C
0005434137155	11943	41	11D
0005434137240	11943	42	11E
0005434137512	11943	43	11F
0005434136873	11943	44	12A
0005434136777	11943	45	12C
0005434137349	11943	46	12D
0005434137539	11943	47	12E
0005434137238	11943	48	12F
0005434137437	11943	49	13A
0005434137738	11943	50	13C
0005434137144	11943	51	13D
0005434137391	11943	52	13F
0005434137426	11943	53	14A
0005434137520	11943	54	14C
0005434137230	11943	55	14D
0005434137196	11943	56	14E
0005434137473	11943	57	14F
0005434137225	11943	58	15A
0005434137195	11943	59	15C
0005434137528	11943	60	15D
0005434137589	11943	61	15E
0005434137398	11943	62	15F
0005434137471	11943	63	16C
0005434137231	11943	64	16D
0005434137553	11943	65	16F
0005434137536	11943	66	16E
0005434137182	11943	67	17A
0005434137491	11943	68	17C
0005434137222	11943	69	17D
0005434137198	11943	70	17E
0005434136942	11943	71	17F
0005434137525	11943	72	18A
0005434137407	11943	73	18C
0005434137255	11943	74	18D
0005434137673	11943	75	18E
0005434136840	11943	76	18F
0005434137422	11943	77	19A
0005434137057	11943	78	19C
0005434137596	11943	79	19D
0005434137737	11943	80	19E
0005434137554	11943	81	19F
0005434137330	11943	82	20A
0005434137226	11943	83	20C
0005434137492	11943	84	20D
0005434137033	11943	85	20E
0005434137915	28744	1	1A
0005434137921	28744	2	1D
0005434137911	28744	3	1F
0005434137906	28744	4	2A
0005434137924	28744	5	2C
0005434137903	28744	6	2D
0005434137893	28744	7	2F
0005434137894	28744	8	3A
0005434137885	28744	9	3C
0005434137923	28744	10	3D
0005434137933	28744	11	4A
0005434137897	28744	12	4C
0005434137886	28744	13	4E
0005434137908	28744	14	5A
0005434137937	28744	15	5C
0005434137905	28744	16	5D
0005434137891	28744	17	5E
0005434137880	28744	18	5F
0005434137887	28744	19	6A
0005434137948	28744	20	6C
0005434137930	28744	21	6D
0005434137878	28744	22	6E
0005434137936	28744	23	6F
0005434137890	28744	24	7A
0005434137940	28744	25	7D
0005434137879	28744	26	7E
0005434137895	28744	27	7F
0005434137952	28744	28	8A
0005434137872	28744	29	8C
0005434137950	28744	30	8D
0005434137938	28744	31	8E
0005434137909	28744	32	9C
0005434137896	28744	33	9A
0005434137901	28744	34	9F
0005434137913	28744	35	10A
0005434137902	28744	36	10C
0005434137931	28744	37	10D
0005434137926	28744	38	10F
0005434137934	28744	39	11A
0005434137946	28744	40	11C
0005434137883	28744	41	11D
0005434137928	28744	42	11E
0005434137917	28744	43	12A
0005434137939	28744	44	12C
0005434137945	28744	45	12D
0005434137892	28744	46	12E
0005434137919	28744	47	12F
0005434137907	28744	48	13A
0005434137874	28744	49	13C
0005434137927	28744	50	13D
0005434137910	28744	51	13E
0005434137947	28744	52	13F
0005434137904	28744	53	14A
0005434137912	28744	54	14C
0005434137925	28744	55	14D
0005434137932	28744	56	14E
0005434137875	28744	57	14F
0005434137899	28744	58	15A
0005434137914	28744	59	15C
0005434137944	28744	60	15D
0005434137900	28744	61	15F
0005434137881	28744	62	16C
0005434137951	28744	63	16E
0005434137949	28744	64	16F
0005434137877	28744	65	17A
0005434137941	28744	66	17C
0005434137898	28744	67	17D
0005434137942	28744	68	17E
0005434137922	28744	69	17F
0005434137935	28744	70	18A
0005434137871	28744	71	18C
0005434137882	28744	72	18E
0005434137873	28744	73	18F
0005434137876	28744	74	19A
0005434137920	28744	75	19C
0005434137888	28744	76	19D
0005434137889	28744	77	19E
0005434137918	28744	78	19F
0005434137929	28744	79	20A
0005434137943	28744	80	20D
0005434137884	28744	81	20E
0005434137916	28744	82	20F
0005433538852	6827	1	2B
0005433538851	6827	2	2C
0005433538854	6827	3	3B
0005435259703	6827	4	4B
0005433538848	6827	5	4C
0005433538853	6827	6	5A
0005433534494	6827	7	5D
0005433538855	6827	8	6A
0005435259709	6827	9	7A
0005433538849	6827	10	7C
0005435259702	6827	11	18A
0005433538856	6827	12	18D
0005435259688	6827	13	21A
0005433538850	6827	14	22A
0005433534493	6827	15	22C
0005435259714	6827	16	22D
0005435259749	24997	1	1A
0005435259748	24997	2	2A
0005433534479	24997	3	2C
0005435259747	24997	4	3A
0005433538771	24997	5	6D
0005433538775	24997	6	7D
0005433534480	24997	7	18A
0005433538745	24997	8	18B
0005433538796	24997	9	18D
0005435259746	24997	10	19A
0005433538795	24997	11	19C
0005433538780	24997	12	19D
0005433538797	24997	13	20B
0005433538781	24997	14	21A
0005433538744	24997	15	21C
0005433538785	24997	16	22B
0005433534478	24997	17	22C
0005433511932	840	1	1C
0005432922465	840	2	2A
0005433511933	840	3	2B
0005432922471	840	4	2C
0005433511934	840	5	3C
0005433511936	840	6	4B
0005433511937	840	7	5C
0005433511931	840	8	7B
0005433511938	840	9	7C
0005433511935	840	10	19B
0005432922481	840	11	19C
0005432922470	840	12	20A
0005432922491	840	13	20B
0005433511930	840	14	21B
0005432922474	840	15	22A
0005432922492	840	16	22B
0005433511939	840	17	23B
0005433511882	16163	1	1A
0005433511842	16163	2	1D
0005433511878	16163	3	2D
0005432922516	16163	4	3A
0005432922517	16163	5	3C
0005433511856	16163	6	4A
0005432922519	16163	7	4B
0005432922515	16163	8	4D
0005433511854	16163	9	5B
0005433511865	16163	10	6D
0005433511859	16163	11	7B
0005433511855	16163	12	7C
0005433511888	16163	13	7D
0005433511853	16163	14	18B
0005433511875	16163	15	19A
0005433511864	16163	16	19B
0005432922518	16163	17	20A
0005433511843	16163	18	20B
0005433511881	16163	19	21B
0005433511860	16163	20	21C
0005435697300	3705	1	1C
0005435697287	3705	2	1D
0005435697276	3705	3	2C
0005435935017	3705	4	3A
0005435697284	3705	5	3C
0005434950519	3705	6	3D
0005435697288	3705	7	4A
0005435697282	3705	8	4B
0005435697295	3705	9	4C
0005435697302	3705	10	4D
0005435697289	3705	11	5A
0005435697279	3705	12	5B
0005435935010	3705	13	5D
0005435697294	3705	14	6B
0005435697298	3705	15	6C
0005435916132	3705	16	6D
0005435697301	3705	17	7A
0005435697292	3705	18	7C
0005435697283	3705	19	7D
0005435697280	3705	20	18A
0005435697299	3705	21	18B
0005435697286	3705	22	18C
0005435916133	3705	23	18D
0005434950522	3705	24	19A
0005435697277	3705	25	19B
0005434950520	3705	26	19C
0005435697290	3705	27	20A
0005435697296	3705	28	20B
0005435697293	3705	29	20C
0005434950518	3705	30	20D
0005435697297	3705	31	21B
0005435697275	3705	32	21C
0005435697285	3705	33	21D
0005435697281	3705	34	22B
0005434950521	3705	35	22C
0005435697291	3705	36	22D
0005435697278	3705	37	23A
0005435696996	16277	1	1A
0005435696914	16277	2	1C
0005435697034	16277	3	1D
0005435697072	16277	4	2A
0005435696953	16277	5	2B
0005435916162	16277	6	2C
0005434950464	16277	7	2D
0005435935035	16277	8	3A
0005435696989	16277	9	3B
0005435697061	16277	10	3C
0005435697028	16277	11	3D
0005435697035	16277	12	4A
0005435916163	16277	13	4B
0005435935033	16277	14	4C
0005435696954	16277	15	4D
0005434950495	16277	16	5A
0005435697020	16277	17	5B
0005434950474	16277	18	5C
0005435935036	16277	19	6A
0005435696988	16277	20	6C
0005435696923	16277	21	6D
0005435696919	16277	22	7C
0005435696974	16277	23	7D
0005435697066	16277	24	18A
0005435697071	16277	25	18B
0005435697065	16277	26	18C
0005435697015	16277	27	19A
0005435935034	16277	28	19B
0005434950471	16277	29	19D
0005435916161	16277	30	20B
0005435696990	16277	31	20C
0005435696964	16277	32	20D
0005435697012	16277	33	21A
0005435697098	16277	34	21B
0005435696995	16277	35	21D
0005435935037	16277	36	22A
0005435697059	16277	37	22C
0005435697099	16277	38	22D
0005435697021	16277	39	23A
0005434604891	3986	1	1C
0005433519447	3986	2	2A
0005432607557	3986	3	2B
0005432609723	3986	4	2C
0005432609725	3986	5	2D
0005432609724	3986	6	3A
0005434604888	3986	7	3B
0005434604889	3986	8	4B
0005432609721	3986	9	4C
0005434606821	3986	10	5B
0005433519450	3986	11	5D
0005432607560	3986	12	6B
0005434604890	3986	13	7A
0005433519448	3986	14	18A
0005432607556	3986	15	18B
0005433519449	3986	16	19A
0005434606822	3986	17	19D
0005432607558	3986	18	20D
0005432607559	3986	19	21B
0005432609722	3986	20	21C
0005432613824	22075	1	1A
0005433519411	22075	2	1C
0005434606762	22075	3	1B
0005432613803	22075	4	1D
0005432613832	22075	5	2A
0005432613792	22075	6	2B
0005432609677	22075	7	2C
0005432609658	22075	8	2D
0005433519407	22075	9	3A
0005432609661	22075	10	3B
0005432613815	22075	11	3C
0005432613810	22075	12	3D
0005433519404	22075	13	4A
0005432609676	22075	14	4B
0005432613793	22075	15	4C
0005432613809	22075	16	4D
0005432613831	22075	17	5B
0005434606765	22075	18	5C
0005432609659	22075	19	6A
0005433519419	22075	20	6B
0005432613813	22075	21	6C
0005432609675	22075	22	6D
0005432613798	22075	23	7A
0005432613811	22075	24	7B
0005432613805	22075	25	7C
0005433519408	22075	26	7D
0005432609669	22075	27	18A
0005432609692	22075	28	18B
0005432613804	22075	29	18C
0005434606764	22075	30	18D
0005433519403	22075	31	19A
0005432613814	22075	32	19B
0005432613791	22075	33	19C
0005435841093	22075	34	19D
0005433519425	22075	35	20A
0005432609681	22075	36	20C
0005432613802	22075	37	20D
0005432609660	22075	38	21A
0005432613812	22075	39	21B
0005432613801	22075	40	21C
0005432609670	22075	41	21D
0005432609674	22075	42	22B
0005432613806	22075	43	22A
0005433519426	22075	44	22C
0005432609671	22075	45	22D
0005432613790	22075	46	23A
0005434606763	22075	47	23B
0005433348963	737	1	1A
0005433348939	737	2	1B
0005433348935	737	3	2A
0005433348921	737	4	2B
0005435628717	737	5	3B
0005433348962	737	6	4A
0005433348922	737	7	4B
0005433348924	737	8	5A
0005433348941	737	9	5B
0005433348931	737	10	6A
0005433348940	737	11	6B
0005433348979	15969	1	1A
0005435628704	15969	2	1B
0005433348978	15969	3	2A
0005435628699	15969	4	3A
0005433348980	15969	5	3B
0005433348981	15969	6	4B
0005435628691	15969	7	5A
0005433348977	15969	8	5B
0005435628696	15969	9	6B
0005433159278	17166	1	1A
0005433158106	17166	2	1B
0005434445242	17166	3	2A
0005433159292	17166	4	2B
0005433159288	17166	5	3A
0005434446512	17166	6	3B
0005434445240	17166	7	4A
0005434446513	17166	8	4B
0005433159287	17166	9	5A
0005433158095	17166	10	6A
0005434445241	17166	11	6B
0005433159308	17634	1	1A
0005434445218	17634	2	2B
0005433159309	17634	3	3B
0005434445214	17634	4	4A
0005434445223	17634	5	6A
0005434445217	17634	6	6B
0005435132861	7887	1	1B
0005435383103	7887	2	2B
0005435132862	7887	3	2D
0005435383082	7887	4	3A
0005435132865	7887	5	4C
0005435132863	7887	6	4D
0005435383084	7887	7	6B
0005435132866	7887	8	6C
0005435132859	7887	9	7A
0005435132864	7887	10	7D
0005435132857	7887	11	18B
0005435132858	7887	12	18A
0005435132856	7887	13	18D
0005435383083	7887	14	19A
0005435132860	7887	15	20A
0005435383091	7887	16	21B
0005435383094	7887	17	22C
0005435383095	7887	18	22D
0005435383092	7887	19	23B
0005435383137	33089	1	1C
0005435132822	33089	2	2B
0005435132789	33089	3	2C
0005435383142	33089	4	4D
0005435383139	33089	5	5D
0005435132821	33089	6	6C
0005435383138	33089	7	7C
0005435383140	33089	8	7D
0005435383141	33089	9	18B
0005435132774	33089	10	19C
0005435132811	33089	11	20B
0005435132773	33089	12	20C
0005435938859	4421	1	2F
0005435811068	4421	2	2D
0005435938849	4421	3	3A
0005435811063	4421	4	4D
0005435811058	4421	5	6A
0005435938850	4421	6	8C
0005435938862	4421	7	8B
0005435938858	4421	8	8F
0005435938854	4421	9	12A
0005435811061	4421	10	13C
0005435938856	4421	11	13B
0005435938853	4421	12	13D
0005435938852	4421	13	14B
0005435811067	4421	14	15A
0005435811059	4421	15	15F
0005435811064	4421	16	16E
0005435938861	4421	17	16F
0005435811065	4421	18	18B
0005435938848	4421	19	18E
0005435811060	4421	20	19B
0005435811062	4421	21	19F
0005435811066	4421	22	21A
0005435938882	29436	1	6A
0005435811006	29436	2	7A
0005435811019	29436	3	6F
0005435811036	29436	4	8E
0005435811035	29436	5	8F
0005435938883	29436	6	9C
0005435811018	29436	7	11C
0005435938879	29436	8	12F
0005435938881	29436	9	14D
0005435811037	29436	10	15A
0005435938884	29436	11	16B
0005435938880	29436	12	20C
0005435811015	29436	13	20F
0005435160277	7475	1	2D
0005435160281	7475	2	3A
0005435160285	7475	3	5C
0005435160282	7475	4	5D
0005435160280	7475	5	7A
0005435160276	7475	6	7D
0005435160283	7475	7	18B
0005435390199	7475	8	18C
0005435160284	7475	9	19B
0005435390148	7475	10	20A
0005435390165	7475	11	21A
0005435390166	7475	12	21B
0005435390196	7475	13	22A
0005435160279	7475	14	22C
0005435390164	7475	15	22D
0005435160278	7475	16	23B
0005435390227	29566	1	1A
0005435390225	29566	2	2A
0005435160204	29566	3	2B
0005435160215	29566	4	2C
0005435160207	29566	5	3D
0005435390223	29566	6	4A
0005435160180	29566	7	4B
0005435390226	29566	8	4D
0005435160165	29566	9	5A
0005435390229	29566	10	6B
0005435160152	29566	11	6C
0005435160216	29566	12	7A
0005435160176	29566	13	7B
0005435160155	29566	14	7D
0005435160138	29566	15	18B
0005435390228	29566	16	19B
0005435390224	29566	17	20A
0005435160175	29566	18	20B
0005435160167	29566	19	21C
0005435160206	29566	20	22A
0005435160239	29566	21	23B
0005432398159	18433	1	1B
0005432398166	18433	2	1A
0005432398158	18433	3	2A
0005432394060	18433	4	3A
0005432398153	18433	5	4A
0005432394061	18433	6	4B
0005435178991	18433	7	5A
0005432398167	18433	8	5B
0005435178493	18433	9	6A
0005432398150	18433	10	6B
0005432400112	27124	1	1A
0005432398187	27124	2	1B
0005435178474	27124	3	2A
0005432400111	27124	4	2B
0005435178479	27124	5	3B
0005435178475	27124	6	4A
0005432400113	27124	7	4B
0005432398186	27124	8	5B
0005435178478	27124	9	6A
0005432400110	27124	10	6B
0005434504098	6511	1	1A
0005434504062	6511	2	1D
0005434504064	6511	3	1F
0005434504082	6511	4	2C
0005434504099	6511	5	2D
0005434504075	6511	6	3C
0005434504103	6511	7	3F
0005434504084	6511	8	4A
0005434504066	6511	9	4D
0005434504095	6511	10	4F
0005435103919	6511	11	5E
0005435103910	6511	12	5F
0005434504080	6511	13	6E
0005434504076	6511	14	6F
0005434504074	6511	15	7A
0005434504067	6511	16	7C
0005434504097	6511	17	7D
0005435103916	6511	18	7E
0005434504083	6511	19	8A
0005434504087	6511	20	8C
0005434504070	6511	21	8E
0005434504073	6511	22	8F
0005434504100	6511	23	9A
0005434504102	6511	24	9F
0005435103914	6511	25	10D
0005434504094	6511	26	10E
0005434504090	6511	27	10F
0005434504089	6511	28	11A
0005434504071	6511	29	11C
0005435103911	6511	30	11E
0005434504086	6511	31	11F
0005434504065	6511	32	12A
0005435103918	6511	33	13A
0005435103917	6511	34	13C
0005434504078	6511	35	13D
0005434504091	6511	36	13F
0005435103912	6511	37	14A
0005434504096	6511	38	14C
0005434504068	6511	39	14D
0005434504079	6511	40	14E
0005435103921	6511	41	15A
0005434504101	6511	42	15D
0005434504077	6511	43	16A
0005434504069	6511	44	16D
0005434504088	6511	45	16E
0005434504093	6511	46	16F
0005434504081	6511	47	17A
0005435103913	6511	48	17C
0005434504063	6511	49	17D
0005434504072	6511	50	17F
0005435103915	6511	51	18A
0005434504092	6511	52	18C
0005435103909	6511	53	19A
0005434504085	6511	54	20D
0005435103920	6511	55	20E
0005434503673	22656	1	1F
0005435103798	22656	2	3C
0005434503680	22656	3	3D
0005434503669	22656	4	4A
0005435103824	22656	5	4D
0005435103821	22656	6	5C
0005434503636	22656	7	6A
0005434503543	22656	8	6D
0005434503516	22656	9	7A
0005434503589	22656	10	7D
0005434503665	22656	11	9C
0005434503755	22656	12	9D
0005434503736	22656	13	9F
0005434503515	22656	14	10D
0005434503679	22656	15	10E
0005434503705	22656	16	11C
0005434503773	22656	17	11F
0005434503677	22656	18	12D
0005435103804	22656	19	12F
0005434503717	22656	20	13A
0005434503683	22656	21	13E
0005434503780	22656	22	14D
0005434503625	22656	23	14E
0005434503778	22656	24	14F
0005434503779	22656	25	15D
0005435103825	22656	26	16D
0005434503537	22656	27	16E
0005435103801	22656	28	17A
0005434503754	22656	29	17F
0005434503716	22656	30	18A
0005434503585	22656	31	18C
0005434503775	22656	32	19A
0005435103822	22656	33	19E
0005435103805	22656	34	19F
0005434503766	22656	35	20E
0005435800089	21311	1	4C
0005435800080	21311	2	5D
0005435800087	21311	3	6D
0005435800088	21311	4	19C
0005435800079	21311	5	20D
0005435652988	1656	1	1A
0005433367636	1656	2	1C
0005433367421	1656	3	1D
0005433367454	1656	4	1F
0005435652980	1656	5	2A
0005435652973	1656	6	2C
0005435652966	1656	7	2D
0005435652976	1656	8	2F
0005433367380	1656	9	3A
0005433367414	1656	10	3C
0005435652984	1656	11	3D
0005433367307	1656	12	3F
0005433367541	1656	13	4C
0005435652962	1656	14	4D
0005433367453	1656	15	4E
0005433367442	1656	16	5A
0005433367342	1656	17	5C
0005435652956	1656	18	5D
0005435652961	1656	19	5E
0005433367394	1656	20	5F
0005433367616	1656	21	6C
0005433367512	1656	22	6D
0005435652983	1656	23	6E
0005433367531	1656	24	6F
0005435652991	1656	25	7C
0005435652957	1656	26	7D
0005435652987	1656	27	7E
0005433367575	1656	28	7F
0005435652990	1656	29	8A
0005433367426	1656	30	8C
0005433367457	1656	31	8D
0005433367519	1656	32	8E
0005433367653	1656	33	8F
0005435652974	1656	34	9A
0005435652989	1656	35	9C
0005435652960	1656	36	9E
0005433367510	1656	37	10A
0005433367437	1656	38	10C
0005435652982	1656	39	10D
0005435652986	1656	40	10E
0005435652971	1656	41	10F
0005435652969	1656	42	11A
0005435652978	1656	43	11C
0005433367441	1656	44	11D
0005435652958	1656	45	11E
0005433367462	1656	46	11F
0005433367275	1656	47	12A
0005435652975	1656	48	12C
0005433367485	1656	49	12D
0005435652965	1656	50	12E
0005433367308	1656	51	12F
0005433367525	1656	52	13A
0005433367511	1656	53	13C
0005433367464	1656	54	13D
0005435652959	1656	55	13E
0005433367484	1656	56	13F
0005435652967	1656	57	14A
0005433367460	1656	58	14C
0005435652970	1656	59	14D
0005433367570	1656	60	14E
0005435652981	1656	61	14F
0005433367470	1656	62	15A
0005435652955	1656	63	15C
0005433367590	1656	64	15D
0005435652964	1656	65	15E
0005433367413	1656	66	15F
0005433367523	1656	67	16A
0005435652979	1656	68	16C
0005433367654	1656	69	16D
0005433367584	1656	70	16E
0005435652977	1656	71	16F
0005433367527	1656	72	17A
0005435652972	1656	73	17C
0005433367374	1656	74	17D
0005433367373	1656	75	17E
0005435652963	1656	76	17F
0005433367530	1656	77	18A
0005433367436	1656	78	18C
0005433367425	1656	79	18D
0005433367415	1656	80	18E
0005435652968	1656	81	18F
0005433367463	1656	82	19A
0005435652985	1656	83	19C
0005433367404	1656	84	19D
0005433367461	1656	85	19E
0005433367655	1656	86	19F
0005433367445	1656	87	20A
0005433367507	1656	88	20C
0005433367443	1656	89	20E
0005435652483	21686	1	1C
0005433367830	21686	2	1D
0005435652489	21686	3	1F
0005433367807	21686	4	2A
0005433367796	21686	5	2D
0005433367826	21686	6	2F
0005433367794	21686	7	3A
0005433367813	21686	8	3C
0005433367819	21686	9	3D
0005435652497	21686	10	3F
0005433367798	21686	11	4A
0005435652459	21686	12	4C
0005435652396	21686	13	4D
0005435652629	21686	14	4E
0005433367828	21686	15	4F
0005433367802	21686	16	5A
0005433367816	21686	17	5C
0005433367809	21686	18	5D
0005433367822	21686	19	5E
0005433367831	21686	20	6A
0005435652548	21686	21	6D
0005435652484	21686	22	6E
0005435652359	21686	23	6F
0005433367821	21686	24	7A
0005435652555	21686	25	7C
0005433367804	21686	26	7D
0005435652554	21686	27	7E
0005435652516	21686	28	7F
0005433367803	21686	29	8A
0005433367827	21686	30	8C
0005435652493	21686	31	8D
0005433367829	21686	32	8E
0005435652607	21686	33	9A
0005433367805	21686	34	9D
0005433367815	21686	35	9E
0005433367825	21686	36	10A
0005433367810	21686	37	10C
0005435652443	21686	38	10D
0005433367823	21686	39	10E
0005435652448	21686	40	10F
0005435652400	21686	41	11A
0005435652660	21686	42	11C
0005435652395	21686	43	11D
0005435652539	21686	44	11E
0005433367797	21686	45	12C
0005435652517	21686	46	12D
0005435652529	21686	47	12E
0005433367801	21686	48	12F
0005435652492	21686	49	13A
0005433367820	21686	50	13C
0005435652542	21686	51	13D
0005435652662	21686	52	13F
0005435652385	21686	53	14A
0005433367817	21686	54	14C
0005433367806	21686	55	14E
0005435652430	21686	56	15A
0005433367799	21686	57	15C
0005435652563	21686	58	15D
0005433367808	21686	59	15E
0005435652533	21686	60	15F
0005435652360	21686	61	16C
0005433367832	21686	62	16D
0005435652620	21686	63	16E
0005435652518	21686	64	16F
0005435652458	21686	65	17A
0005435652534	21686	66	17C
0005435652562	21686	67	17D
0005435652528	21686	68	17E
0005435652447	21686	69	17F
0005433367824	21686	70	18A
0005435652630	21686	71	18C
0005435652537	21686	72	18D
0005433367818	21686	73	18F
0005435652592	21686	74	19A
0005433367795	21686	75	19C
0005433367814	21686	76	19D
0005433367811	21686	77	19E
0005435652541	21686	78	19F
0005435652471	21686	79	20A
0005433367800	21686	80	20C
0005433367812	21686	81	20D
0005435652661	21686	82	20E
0005435652531	21686	83	20F
0005433985871	4164	1	1A
0005433985872	4164	2	1D
0005433985844	4164	3	1F
0005433985873	4164	4	3D
0005433985876	4164	5	3F
0005433985843	4164	6	4C
0005433985845	4164	7	4D
0005433985853	4164	8	4E
0005433985867	4164	9	4F
0005433985842	4164	10	5C
0005433985860	4164	11	5D
0005433985859	4164	12	5E
0005433985863	4164	13	6A
0005433985848	4164	14	6C
0005433985856	4164	15	6D
0005435788767	4164	16	6F
0005433985850	4164	17	7C
0005433985849	4164	18	9A
0005433985865	4164	19	9C
0005433985870	4164	20	11D
0005433985847	4164	21	11C
0005433985869	4164	22	11F
0005433985840	4164	23	12D
0005433985846	4164	24	12F
0005433985857	4164	25	13C
0005433985858	4164	26	13D
0005433985852	4164	27	13F
0005435788766	4164	28	14C
0005433985874	4164	29	15E
0005433985875	4164	30	15F
0005433985877	4164	31	16C
0005433985861	4164	32	16E
0005433985851	4164	33	17A
0005433985854	4164	34	17E
0005435788765	4164	35	17F
0005433985866	4164	36	18C
0005433985841	4164	37	18E
0005433985862	4164	38	18F
0005433985868	4164	39	19A
0005433985855	4164	40	19C
0005433985864	4164	41	20F
0005433985358	25642	1	1C
0005433985311	25642	2	1D
0005433985405	25642	3	1F
0005433985380	25642	4	2C
0005435788745	25642	5	2D
0005433985417	25642	6	2F
0005433985544	25642	7	3C
0005433985246	25642	8	3D
0005433985378	25642	9	3F
0005433985404	25642	10	4D
0005433985338	25642	11	5D
0005433985443	25642	12	5E
0005433985389	25642	13	6E
0005433985426	25642	14	7D
0005433985321	25642	15	7E
0005433985408	25642	16	7F
0005435788742	25642	17	8A
0005433985507	25642	18	8C
0005433985524	25642	19	9C
0005433985523	25642	20	9F
0005433985410	25642	21	10A
0005433985492	25642	22	10C
0005433985399	25642	23	10E
0005433985350	25642	24	11C
0005433985268	25642	25	11E
0005433985294	25642	26	12A
0005433985322	25642	27	12C
0005433985396	25642	28	12D
0005433985493	25642	29	12F
0005433985458	25642	30	13A
0005433985323	25642	31	13E
0005433985526	25642	32	13F
0005433985307	25642	33	14C
0005435788747	25642	34	14D
0005435788744	25642	35	15C
0005433985409	25642	36	15D
0005433985531	25642	37	15F
0005435788746	25642	38	16F
0005433985559	25642	39	17A
0005433985261	25642	40	17C
0005433985379	25642	41	18A
0005433985398	25642	42	18C
0005433985599	25642	43	18F
0005433985397	25642	44	19A
0005433985335	25642	45	19D
0005433985525	25642	46	19E
0005433985339	25642	47	19F
0005433985411	25642	48	20A
0005433985309	25642	49	20D
0005433985511	25642	50	20E
0005433985600	25642	51	20F
0005435720808	21294	1	2A
0005435719553	21294	2	4D
0005435719555	21294	3	7C
0005435720816	21294	4	7D
0005435719554	21294	5	20B
0005435720815	21294	6	22D
0005435719567	24804	1	4B
0005435719568	24804	2	4D
0005435720131	24804	3	5A
0005435720130	24804	4	5C
0005435719566	24804	5	7C
0005433168318	1629	1	2C
0005434509125	1629	2	3A
0005433168313	1629	3	3C
0005434509136	1629	4	3D
0005434509134	1629	5	4A
0005434509132	1629	6	4B
0005434509126	1629	7	4C
0005434509133	1629	8	5A
0005434509137	1629	9	5C
0005434509124	1629	10	5D
0005433168332	1629	11	6C
0005434509138	1629	12	6D
0005433168312	1629	13	7D
0005434509131	1629	14	18B
0005433168317	1629	15	18D
0005434509129	1629	16	19C
0005434509128	1629	17	20C
0005434509127	1629	18	21B
0005434509130	1629	19	21D
0005433168320	1629	20	22A
0005434509135	1629	21	22B
0005433168307	1629	22	22C
0005432655414	17872	1	1A
0005432657407	17872	2	1F
0005432657413	17872	3	2A
0005432663019	17872	4	2C
0005432655397	17872	5	2D
0005432659686	17872	6	2F
0005432869516	17872	7	3F
0005432657411	17872	8	4C
0005432659688	17872	9	5D
0005434151699	17872	10	6A
0005432659684	17872	11	6D
0005432657409	17872	12	6E
0005434151700	17872	13	7A
0005432667432	17872	14	8E
0005432655357	17872	15	9C
0005432869514	17872	16	9F
0005432655396	17872	17	10A
0005432655420	17872	18	10C
0005432657412	17872	19	10E
0005432655348	17872	20	11A
0005432657414	17872	21	11E
0005432869518	17872	22	12E
0005432658557	17872	23	13A
0005432869512	17872	24	13C
0005432869517	17872	25	13D
0005432667433	17872	26	13F
0005432659687	17872	27	14C
0005432660795	17872	28	14D
0005432666365	17872	29	14E
0005432657419	17872	30	14F
0005432665254	17872	31	15D
0005432655413	17872	32	15F
0005432655347	17872	33	16A
0005432665253	17872	34	17C
0005432655385	17872	35	17F
0005432655358	17872	36	18A
0005432869515	17872	37	19A
0005432657420	17872	38	19D
0005434151701	17872	39	19F
0005432869513	17872	40	20A
0005432655386	17872	41	20D
0005432655384	17872	42	20E
0005432869437	26293	1	1D
0005432655488	26293	2	2F
0005432655496	26293	3	4A
0005432655492	26293	4	4C
0005432665267	26293	5	4D
0005432869445	26293	6	4E
0005432657440	26293	7	4F
0005432655487	26293	8	5E
0005432655489	26293	9	6C
0005432660811	26293	10	6D
0005432657439	26293	11	7A
0005432659700	26293	12	8C
0005432667447	26293	13	8E
0005432655485	26293	14	10A
0005432658584	26293	15	10D
0005432869432	26293	16	11A
0005432869441	26293	17	11E
0005432666382	26293	18	13D
0005432869454	26293	19	13E
0005432655491	26293	20	14C
0005432657438	26293	21	14E
0005432655495	26293	22	15A
0005432666381	26293	23	15C
0005434151684	26293	24	15D
0005432655490	26293	25	16F
0005432655494	26293	26	17C
0005432665268	26293	27	17E
0005432658583	26293	28	17F
0005432655486	26293	29	18F
0005432659699	26293	30	19C
0005432655493	26293	31	19E
0005432869444	26293	32	19F
0005432869436	26293	33	20F
0005432638984	25065	1	1F
0005432638983	25065	2	2C
0005432638945	25065	3	3A
0005432866000	25065	4	3D
0005432638966	25065	5	3F
0005432866003	25065	6	4A
0005432865995	25065	7	4C
0005432638987	25065	8	4E
0005432866002	25065	9	4F
0005432639008	25065	10	5A
0005432866005	25065	11	5D
0005432638986	25065	12	5E
0005432638921	25065	13	5F
0005432865997	25065	14	6C
0005432639010	25065	15	6F
0005432639054	25065	16	7D
0005432638923	25065	17	7F
0005432866004	25065	18	8C
0005432866008	25065	19	8F
0005432638931	25065	20	9C
0005432638967	25065	21	9E
0005432638924	25065	22	10A
0005432638982	25065	23	10C
0005432638999	25065	24	11A
0005432638925	25065	25	11E
0005432866007	25065	26	11F
0005432865999	25065	27	12C
0005432638980	25065	28	12D
0005432639033	25065	29	12E
0005432638981	25065	30	12F
0005432639045	25065	31	13E
0005432865994	25065	32	14D
0005432865998	25065	33	15D
0005432638929	25065	34	16C
0005432638970	25065	35	16E
0005432866006	25065	36	17C
0005432638985	25065	37	17D
0005432638922	25065	38	17E
0005432639053	25065	39	17F
0005432638946	25065	40	18D
0005432866001	25065	41	18F
0005432638996	25065	42	19C
0005432638960	25065	43	19F
0005432639001	25065	44	20C
0005432865996	25065	45	20D
0005432638932	25065	46	20F
0005432328638	3076	1	1A
0005433438861	3076	2	1C
0005432328632	3076	3	1D
0005433438870	3076	4	1F
0005432287179	3076	5	2A
0005433438859	3076	6	2C
0005432328627	3076	7	2D
0005432328641	3076	8	3A
0005432328597	3076	9	3C
0005432905052	3076	10	4A
0005432328629	3076	11	4C
0005433438860	3076	12	4D
0005432328603	3076	13	5C
0005433438867	3076	14	5D
0005432328608	3076	15	5F
0005433438868	3076	16	6D
0005432328614	3076	17	6E
0005432328625	3076	18	7A
0005432328619	3076	19	6F
0005432287183	3076	20	7C
0005432328640	3076	21	7E
0005432328617	3076	22	8D
0005433438866	3076	23	8F
0005432328599	3076	24	9A
0005433438862	3076	25	9C
0005432328607	3076	26	9D
0005432328596	3076	27	9E
0005432328618	3076	28	9F
0005432328606	3076	29	10A
0005432287180	3076	30	10E
0005432328609	3076	31	10F
0005432328634	3076	32	11A
0005432328611	3076	33	11E
0005432328621	3076	34	11F
0005433438863	3076	35	12A
0005432328601	3076	36	12C
0005432328635	3076	37	12D
0005432328620	3076	38	12E
0005432328626	3076	39	12F
0005432328610	3076	40	13C
0005432328637	3076	41	13E
0005432328623	3076	42	13F
0005432328622	3076	43	14A
0005432328602	3076	44	14D
0005432287178	3076	45	14E
0005432328639	3076	46	15A
0005432328612	3076	47	15C
0005432328613	3076	48	15D
0005432328605	3076	49	15E
0005433438864	3076	50	15F
0005432287181	3076	51	16A
0005433438865	3076	52	16C
0005432328630	3076	53	16D
0005432328616	3076	54	16E
0005432328628	3076	55	17D
0005432328631	3076	56	18D
0005432328624	3076	57	18E
0005432287182	3076	58	18F
0005433438869	3076	59	19A
0005432328633	3076	60	19C
0005432328615	3076	61	19D
0005432328598	3076	62	19F
0005432328595	3076	63	20A
0005432328604	3076	64	20C
0005432328636	3076	65	20D
0005432905048	3076	66	20E
0005432328600	3076	67	20F
0005432328179	31121	1	1C
0005432054298	31121	2	1D
0005432328220	31121	3	2A
0005432328120	31121	4	2C
0005432327995	31121	5	2F
0005432328254	31121	6	3A
0005432328067	31121	7	3C
0005432328112	31121	8	3D
0005432328195	31121	9	4A
0005432328311	31121	10	4C
0005432328189	31121	11	4D
0005432054297	31121	12	4F
0005432328131	31121	13	5C
0005432328147	31121	14	5D
0005432327916	31121	15	5E
0005432328391	31121	16	5F
0005432328151	31121	17	7A
0005432328186	31121	18	7C
0005432328130	31121	19	7E
0005432328262	31121	20	7F
0005432328353	31121	21	8A
0005432328094	31121	22	8D
0005432328357	31121	23	8E
0005432328188	31121	24	8F
0005432328396	31121	25	9C
0005432328121	31121	26	9D
0005432328261	31121	27	9F
0005432328075	31121	28	10A
0005432054299	31121	29	10C
0005432328209	31121	30	10D
0005432328082	31121	31	10E
0005432328312	31121	32	10F
0005432328204	31121	33	11A
0005432905116	31121	34	11C
0005432328170	31121	35	11D
0005432328168	31121	36	11F
0005432905115	31121	37	12A
0005432328097	31121	38	12C
0005432328095	31121	39	12F
0005432328166	31121	40	13A
0005432328435	31121	41	13C
0005432328128	31121	42	13D
0005432328181	31121	43	13E
0005432328196	31121	44	13F
0005432328146	31121	45	14A
0005432328197	31121	46	14C
0005432328358	31121	47	14D
0005432328113	31121	48	14F
0005432328073	31121	49	15C
0005432328096	31121	50	15D
0005432328237	31121	51	16A
0005432328080	31121	52	16C
0005432328363	31121	53	17A
0005432328226	31121	54	17C
0005432328058	31121	55	17D
0005432328180	31121	56	18A
0005432328310	31121	57	17F
0005432328227	31121	58	18C
0005432328193	31121	59	18D
0005432328124	31121	60	18E
0005432328076	31121	61	18F
0005432328140	31121	62	19A
0005432327921	31121	63	19C
0005432328308	31121	64	19E
0005432328239	31121	65	19F
0005432328194	31121	66	20A
0005432328152	31121	67	20C
0005432328052	31121	68	20E
0005432327915	31121	69	20F
0005435296961	6175	1	1F
0005434309713	6175	2	1D
0005435296990	6175	3	2C
0005435999230	6175	4	2A
0005435999222	6175	5	2D
0005434309710	6175	6	2F
0005435487504	6175	7	3F
0005435296995	6175	8	4A
0005435999218	6175	9	4D
0005435296947	6175	10	5C
0005435487533	6175	11	5F
0005434309719	6175	12	6D
0005435999234	6175	13	6F
0005434309722	6175	14	7A
0005435999221	6175	15	7C
0005435999219	6175	16	7E
0005434309718	6175	17	7D
0005435487714	6175	18	8A
0005435999224	6175	19	8D
0005434309714	6175	20	9D
0005435487482	6175	21	9C
0005435487642	6175	22	9F
0005435487621	6175	23	10B
0005434309724	6175	24	11A
0005435999228	6175	25	11B
0005435999229	6175	26	11D
0005435296960	6175	27	11F
0005435487559	6175	28	12C
0005435999232	6175	29	13A
0005435999233	6175	30	12F
0005435487523	6175	31	13B
0005435296991	6175	32	13F
0005435487534	6175	33	14A
0005435999225	6175	34	14B
0005434309716	6175	35	14E
0005435999223	6175	36	15D
0005434309720	6175	37	15F
0005434309723	6175	38	16C
0005434309711	6175	39	16D
0005435487671	6175	40	17F
0005434309712	6175	41	17E
0005434309721	6175	42	18C
0005435999226	6175	43	19A
0005435487643	6175	44	18F
0005435999220	6175	45	19B
0005435487510	6175	46	19E
0005435487609	6175	47	19F
0005435296954	6175	48	20B
0005435487622	6175	49	20A
0005435487529	6175	50	20C
0005434309717	6175	51	20D
0005435999231	6175	52	20F
0005435487699	6175	53	21C
0005432146195	6175	54	21B
0005435999227	6175	55	21D
0005435487700	6175	56	21E
0005434309715	6175	57	21F
0005435487610	6175	58	22B
0005435296996	6175	59	22C
0005435487588	6175	60	22E
0005435487503	6175	61	23A
0005435999235	6175	62	23B
0005435296942	6175	63	23D
0005435487649	6175	64	23C
0005435487636	6175	65	23F
0005435297046	19571	1	1A
0005435487777	19571	2	1D
0005435999053	19571	3	1F
0005435999077	19571	4	2F
0005435999018	19571	5	3D
0005435487765	19571	6	4C
0005434309561	19571	7	4F
0005435487770	19571	8	5A
0005435297049	19571	9	5E
0005435487768	19571	10	6B
0005434309580	19571	11	6A
0005435487785	19571	12	6D
0005435487778	19571	13	6F
0005435999022	19571	14	7E
0005435998972	19571	15	7F
0005435999063	19571	16	8B
0005435487767	19571	17	8A
0005435999047	19571	18	9A
0005435999050	19571	19	8F
0005434309562	19571	20	9C
0005435999052	19571	21	10B
0005435999066	19571	22	10C
0005434309613	19571	23	10D
0005435999048	19571	24	11B
0005435297043	19571	25	11D
0005435487780	19571	26	11F
0005434309523	19571	27	12A
0005435999067	19571	28	12C
0005435297045	19571	29	12D
0005435487773	19571	30	12F
0005435999058	19571	31	13E
0005435487764	19571	32	14C
0005435487775	19571	33	15D
0005435297048	19571	34	16A
0005435487766	19571	35	16C
0005435487771	19571	36	16E
0005435487779	19571	37	16F
0005435999036	19571	38	17C
0005435999088	19571	39	17D
0005435999021	19571	40	18B
0005435487781	19571	41	18E
0005435999049	19571	42	18D
0005435999083	19571	43	18F
0005435487776	19571	44	19C
0005435999019	19571	45	19B
0005434309556	19571	46	19D
0005435487772	19571	47	19E
0005435998988	19571	48	19F
0005435999020	19571	49	20A
0005435999064	19571	50	20C
0005435999070	19571	51	20F
0005435999001	19571	52	21C
0005435998971	19571	53	21D
0005435999059	19571	54	21E
0005435487782	19571	55	21F
0005435487783	19571	56	22A
0005435487774	19571	57	22B
0005434309525	19571	58	22E
0005434309524	19571	59	23A
0005434309612	19571	60	23B
0005435487784	19571	61	23C
0005435487769	19571	62	23E
0005435297044	19571	63	23D
0005435297047	19571	64	23F
0005435502285	1553	1	1A
0005435517887	1553	2	1C
0005435502280	1553	3	1D
0005434565896	1553	4	1F
0005435502271	1553	5	2C
0005435508339	1553	6	2D
0005435517880	1553	7	2F
0005435502283	1553	8	3A
0005435508342	1553	9	3C
0005434565892	1553	10	3D
0005433186017	1553	11	3F
0005435517878	1553	12	4A
0005432291926	1553	13	4C
0005435517889	1553	14	4D
0005435508343	1553	15	4E
0005435508344	1553	16	4F
0005434565893	1553	17	5C
0005435517888	1553	18	5E
0005435502265	1553	19	5F
0005435502284	1553	20	6A
0005435517895	1553	21	6D
0005434565898	1553	22	6C
0005435502270	1553	23	6E
0005432291927	1553	24	6F
0005435502281	1553	25	7A
0005435517890	1553	26	7C
0005435517877	1553	27	7D
0005435517875	1553	28	7E
0005434565886	1553	29	7F
0005434565890	1553	30	8A
0005435517893	1553	31	8C
0005435517885	1553	32	8E
0005435508341	1553	33	9C
0005435508337	1553	34	9D
0005435517892	1553	35	9E
0005435517876	1553	36	9F
0005435517884	1553	37	10A
0005433186020	1553	38	10E
0005432291925	1553	39	11A
0005433186024	1553	40	11C
0005435508346	1553	41	11D
0005435502273	1553	42	11E
0005435502268	1553	43	12A
0005433186022	1553	44	12E
0005435517882	1553	45	12F
0005433186019	1553	46	13A
0005435502277	1553	47	13C
0005435517874	1553	48	13D
0005434565897	1553	49	13E
0005433186023	1553	50	14A
0005435502267	1553	51	14C
0005435517894	1553	52	14D
0005434565889	1553	53	14E
0005435502276	1553	54	15A
0005435502278	1553	55	15C
0005435508348	1553	56	15D
0005435508345	1553	57	15E
0005434565885	1553	58	15F
0005435517881	1553	59	16A
0005435508347	1553	60	16C
0005434565888	1553	61	16D
0005435502275	1553	62	16E
0005435517883	1553	63	16F
0005434565891	1553	64	17A
0005435517873	1553	65	17C
0005435502266	1553	66	17D
0005435502279	1553	67	17E
0005434565895	1553	68	17F
0005435508350	1553	69	18A
0005435517886	1553	70	18C
0005435508340	1553	71	18D
0005435517879	1553	72	18E
0005435502272	1553	73	18F
0005435508338	1553	74	19A
0005435517891	1553	75	19D
0005434565894	1553	76	19E
0005435502269	1553	77	19F
0005434565887	1553	78	20A
0005435508349	1553	79	20C
0005435502282	1553	80	20D
0005435502274	1553	81	20E
0005435508351	1553	82	20F
0005435529003	20849	1	1A
0005435502137	20849	2	1F
0005435529032	20849	3	2C
0005435545627	20849	4	2D
0005433186103	20849	5	3A
0005435502044	20849	6	3C
0005433186105	20849	7	3D
0005434565779	20849	8	4A
0005434565739	20849	9	4C
0005435502074	20849	10	4D
0005435502096	20849	11	4F
0005435529004	20849	12	5A
0005435529020	20849	13	5C
0005434565778	20849	14	5D
0005435502026	20849	15	5F
0005435502085	20849	16	6C
0005435528907	20849	17	6D
0005435529027	20849	18	6E
0005435502061	20849	19	6F
0005435502120	20849	20	7A
0005435502024	20849	21	7C
0005435502051	20849	22	7D
0005435502097	20849	23	7E
0005435502075	20849	24	8A
0005435502027	20849	25	8C
0005435529079	20849	26	8D
0005435502043	20849	27	8F
0005435545626	20849	28	9F
0005435502121	20849	29	10A
0005434565766	20849	30	10D
0005435502042	20849	31	10F
0005433186100	20849	32	11A
0005435545637	20849	33	11C
0005434565777	20849	34	12C
0005435502045	20849	35	12E
0005433186101	20849	36	12F
0005435502025	20849	37	13A
0005435529030	20849	38	13F
0005435502050	20849	39	14C
0005435502079	20849	40	14E
0005435529005	20849	41	15A
0005435502022	20849	42	15D
0005433186106	20849	43	15E
0005435501944	20849	44	15F
0005435545633	20849	45	16A
0005435529033	20849	46	16C
0005435502139	20849	47	16D
0005433186102	20849	48	16E
0005435529078	20849	49	16F
0005435528901	20849	50	17A
0005433186107	20849	51	17C
0005435502138	20849	52	17E
0005435502005	20849	53	17F
0005433186104	20849	54	18C
0005435528895	20849	55	18E
0005434565738	20849	56	18F
0005435528940	20849	57	19C
0005435502006	20849	58	19E
0005435529021	20849	59	19F
0005435545636	20849	60	20D
0005434565767	20849	61	20F
0005435153727	3872	1	2D
0005435153730	3872	2	3A
0005435931553	3872	3	3C
0005435153728	3872	4	5A
0005435931552	3872	5	6D
0005435153732	3872	6	7C
0005435931554	3872	7	7D
0005435153733	3872	8	18A
0005435153731	3872	9	19B
0005435153729	3872	10	22C
0005435153678	21863	1	1A
0005435153685	21863	2	3A
0005435153684	21863	3	3D
0005435153683	21863	4	4A
0005435153669	21863	5	18A
0005435153679	21863	6	18D
0005435931595	21863	7	19C
0005435931593	21863	8	21B
0005435153677	21863	9	23A
0005435931594	21863	10	23B
0005432628816	7224	1	1A
0005435225512	7224	2	3A
0005435225489	7224	3	3B
0005432628823	7224	4	3C
0005432628822	7224	5	4A
0005432628821	7224	6	4B
0005432628824	7224	7	4C
0005435225469	7224	8	5A
0005432628814	7224	9	5B
0005432628827	7224	10	5C
0005432628819	7224	11	5D
0005432628826	7224	12	18B
0005432628825	7224	13	19A
0005432628817	7224	14	19B
0005432628818	7224	15	21A
0005435225524	7224	16	22A
0005435225491	7224	17	22C
0005432628815	7224	18	22D
0005432628820	7224	19	23A
0005432628725	28101	1	1A
0005432628748	28101	2	1B
0005432628721	28101	3	1D
0005432628718	28101	4	2D
0005435225567	28101	5	3D
0005432628706	28101	6	4C
0005435225568	28101	7	4D
0005432628726	28101	8	5C
0005432628712	28101	9	6B
0005432628749	28101	10	6C
0005435225570	28101	11	6D
0005432628717	28101	12	7A
0005435225571	28101	13	18C
0005435225572	28101	14	19C
0005432628686	28101	15	20C
0005432628693	28101	16	21B
0005432628713	28101	17	22A
0005432628707	28101	18	22B
0005435225573	28101	19	22C
0005435225569	28101	20	22D
0005435960044	8712	1	3A
0005435960046	8712	2	3D
0005435960042	8712	3	4D
0005434267914	8712	4	5A
0005435960045	8712	5	5D
0005435960041	8712	6	19C
0005435960043	8712	7	22B
0005435960022	15238	1	2D
0005434267945	15238	2	3D
0005434267944	15238	3	5A
0005434267943	15238	4	5D
0005435959997	15238	5	18A
0005434267942	15238	6	18B
0005434267941	15238	7	18D
0005435960020	15238	8	20B
0005435959996	15238	9	22A
0005432675110	1197	1	1D
0005432692981	1197	2	2D
0005432692991	1197	3	2C
0005432675103	1197	4	3A
0005432675105	1197	5	2F
0005432692987	1197	6	3C
0005432692971	1197	7	3F
0005432692985	1197	8	3D
0005432692989	1197	9	5A
0005432873227	1197	10	4F
0005432692993	1197	11	4D
0005432692986	1197	12	5C
0005432692997	1197	13	5D
0005432675100	1197	14	6A
0005432692979	1197	15	6B
0005432692974	1197	16	7A
0005432692976	1197	17	7C
0005432677560	1197	18	7D
0005432692996	1197	19	7F
0005432677561	1197	20	8C
0005432692984	1197	21	9A
0005432675104	1197	22	9C
0005432677563	1197	23	9B
0005432692992	1197	24	9F
0005432692975	1197	25	9E
0005432675099	1197	26	10C
0005432692983	1197	27	10E
0005432693000	1197	28	10D
0005432675109	1197	29	11D
0005432692969	1197	30	11C
0005432677562	1197	31	11F
0005432873192	1197	32	12D
0005432692982	1197	33	12F
0005432692990	1197	34	12E
0005432675108	1197	35	13A
0005432873225	1197	36	13B
0005432692994	1197	37	13F
0005432692998	1197	38	14C
0005432692970	1197	39	14B
0005432873229	1197	40	15A
0005432692988	1197	41	15D
0005432692972	1197	42	15C
0005432692995	1197	43	16C
0005432675097	1197	44	16B
0005432675106	1197	45	16E
0005432873226	1197	46	17B
0005432873193	1197	47	17A
0005432692978	1197	48	17D
0005432692980	1197	49	18A
0005432692999	1197	50	18B
0005432675098	1197	51	18E
0005432675102	1197	52	18D
0005432873224	1197	53	20A
0005432873222	1197	54	19F
0005432873223	1197	55	20D
0005432675107	1197	56	20C
0005432692977	1197	57	20F
0005432692973	1197	58	21A
0005432675101	1197	59	21D
0005432692808	17498	1	1F
0005432674972	17498	2	2C
0005432873280	17498	3	2A
0005432692626	17498	4	3A
0005432674959	17498	5	2F
0005432873275	17498	6	3F
0005432692637	17498	7	4D
0005432692842	17498	8	4C
0005432692653	17498	9	5A
0005432674989	17498	10	5F
0005432692688	17498	11	6B
0005432692817	17498	12	6C
0005432692650	17498	13	6E
0005432692821	17498	14	7A
0005432873276	17498	15	6F
0005432692731	17498	16	8C
0005432674937	17498	17	8F
0005432692710	17498	18	9A
0005432692570	17498	19	9B
0005432674925	17498	20	9E
0005432674936	17498	21	9D
0005432692880	17498	22	10C
0005432873279	17498	23	10E
0005432692841	17498	24	10F
0005432692774	17498	25	12A
0005432692649	17498	26	12C
0005432692809	17498	27	12F
0005432692578	17498	28	12E
0005432873281	17498	29	13A
0005432692750	17498	30	13C
0005432675029	17498	31	13D
0005432674950	17498	32	15A
0005432692621	17498	33	14F
0005432692740	17498	34	15B
0005432674949	17498	35	15E
0005432692879	17498	36	16A
0005432692701	17498	37	15F
0005432677530	17498	38	16B
0005432873277	17498	39	16E
0005432692620	17498	40	17B
0005432692697	17498	41	17D
0005432692703	17498	42	17F
0005432677516	17498	43	18B
0005432677515	17498	44	18A
0005432674958	17498	45	18C
0005432674982	17498	46	18E
0005432674993	17498	47	19A
0005432674994	17498	48	19B
0005432873278	17498	49	19D
0005432674971	17498	50	20E
0005432674988	17498	51	21D
0005432692820	17498	52	21C
0005432692696	17498	53	21B
0005432692670	17498	54	21F
0005433156667	1131	1	1B
0005433156659	1131	2	1C
0005434435154	1131	3	2A
0005433156663	1131	4	2C
0005434435149	1131	5	3C
0005434435153	1131	6	3D
0005433156645	1131	7	4C
0005434435156	1131	8	5C
0005434435148	1131	9	6A
0005434435145	1131	10	6B
0005434435160	1131	11	18B
0005434435151	1131	12	19B
0005433156699	1131	13	19C
0005433156679	1131	14	20A
0005434435157	1131	15	20C
0005433156700	1131	16	20D
0005434435146	1131	17	21A
0005434435155	1131	18	21C
0005434435147	1131	19	21D
0005434435159	1131	20	22A
0005434435150	1131	21	22B
0005434435158	1131	22	22C
0005433156676	1131	23	23A
0005434435152	1131	24	23B
0005434434966	17281	1	1A
0005434434944	17281	2	1D
0005433156735	17281	3	3A
0005433156731	17281	4	3D
0005433156736	17281	5	4B
0005434435044	17281	6	4C
0005434435022	17281	7	4D
0005433156730	17281	8	5A
0005433156734	17281	9	5D
0005434434965	17281	10	6B
0005434435005	17281	11	6C
0005433156732	17281	12	7A
0005434435020	17281	13	7B
0005434435073	17281	14	7D
0005433156729	17281	15	18C
0005434435021	17281	16	20A
0005434435098	17281	17	20C
0005434434964	17281	18	21A
0005434435097	17281	19	21B
0005433156738	17281	20	21D
0005433156733	17281	21	22C
0005433156737	17281	22	23B
0005435928075	4061	1	1A
0005435928078	4061	2	1B
0005435086820	4061	3	2D
0005435086816	4061	4	3C
0005435928077	4061	5	6A
0005435086823	4061	6	6B
0005435928100	4061	7	7B
0005435086817	4061	8	7C
0005435928103	4061	9	18A
0005435928076	4061	10	18B
0005435086818	4061	11	18D
0005435086821	4061	12	20D
0005435086822	4061	13	21A
0005435086819	4061	14	21B
0005435928104	4061	15	21C
0005435928079	4061	16	22B
0005435928071	4061	17	22D
0005435086757	24428	1	4B
0005435086781	24428	2	5D
0005435928134	24428	3	6A
0005435086759	24428	4	6C
0005435928135	24428	5	18D
0005435086746	24428	6	19A
0005435086782	24428	7	19B
0005435928132	24428	8	20C
0005435086768	24428	9	21A
0005435086769	24428	10	21C
0005435928133	24428	11	21D
0005432279266	1314	1	1B
0005434964179	1314	2	2B
0005434964193	1314	3	2F
0005434964171	1314	4	2C
0005434964180	1314	5	2G
0005434964176	1314	6	3B
0005433261449	1314	7	4C
0005433261438	1314	8	5C
0005433261461	1314	9	5H
0005434964199	1314	10	9A
0005434964189	1314	11	11E
0005434964186	1314	12	11G
0005433261424	1314	13	12A
0005434964192	1314	14	12B
0005434964169	1314	15	12F
0005434964207	1314	16	13B
0005432279265	1314	17	13G
0005434964168	1314	18	14B
0005434964203	1314	19	14G
0005434964206	1314	20	16D
0005433261425	1314	21	17E
0005434964196	1314	22	17G
0005434964195	1314	23	18E
0005434964191	1314	24	19B
0005433261454	1314	25	19H
0005434964183	1314	26	19G
0005434964187	1314	27	20A
0005432279267	1314	28	20B
0005434964204	1314	29	20E
0005434964202	1314	30	20G
0005433261452	1314	31	20F
0005433261478	1314	32	21E
0005433261445	1314	33	21G
0005433261431	1314	34	22B
0005434964198	1314	35	22A
0005434964205	1314	36	22E
0005434964177	1314	37	22H
0005434964178	1314	38	24D
0005433261436	1314	39	28F
0005434964197	1314	40	28E
0005433261475	1314	41	29A
0005434964201	1314	42	29B
0005434964182	1314	43	29D
0005434964175	1314	44	30E
0005434964184	1314	45	31B
0005434964190	1314	46	31E
0005434964185	1314	47	31D
0005434964188	1314	48	31G
0005434964174	1314	49	32B
0005433261476	1314	50	32E
0005433261479	1314	51	32G
0005434964172	1314	52	33H
0005433261459	1314	53	34A
0005433261460	1314	54	34G
0005433261482	1314	55	34H
0005434964200	1314	56	35A
0005434964173	1314	57	35D
0005434964181	1314	58	36D
0005434964194	1314	59	37B
0005433261453	1314	60	37F
0005434964170	1314	61	37G
0005433261435	1314	62	38E
0005432279268	1314	63	38F
0005434964016	18247	1	1A
0005433261534	18247	2	1F
0005433261546	18247	3	2G
0005433261543	18247	4	3B
0005434964020	18247	5	4H
0005434963976	18247	6	5C
0005434964079	18247	7	5G
0005434963896	18247	8	11D
0005434963983	18247	9	11B
0005434964059	18247	10	11H
0005434963960	18247	11	12D
0005433261536	18247	12	13B
0005433261542	18247	13	13D
0005434964054	18247	14	13F
0005433261540	18247	15	14A
0005434964109	18247	16	14H
0005434963951	18247	17	15B
0005433261538	18247	18	16D
0005434963987	18247	19	16B
0005434964004	18247	20	17H
0005434964024	18247	21	18A
0005434964042	18247	22	18G
0005434963953	18247	23	19A
0005434963975	18247	24	19E
0005434963943	18247	25	20B
0005434964025	18247	26	21B
0005434964002	18247	27	21A
0005434964035	18247	28	22D
0005433261544	18247	29	22B
0005433261545	18247	30	23F
0005434963985	18247	31	24D
0005434964005	18247	32	25F
0005433261550	18247	33	27B
0005433261552	18247	34	27E
0005433261548	18247	35	28D
0005434964021	18247	36	28G
0005434964110	18247	37	28F
0005433261554	18247	38	29B
0005434964009	18247	39	30B
0005434963952	18247	40	30F
0005434963959	18247	41	31A
0005433261535	18247	42	31F
0005433261537	18247	43	32A
0005433261541	18247	44	33A
0005434964034	18247	45	33E
0005434964008	18247	46	34G
0005433261551	18247	47	36G
0005434963986	18247	48	37A
0005434963972	18247	49	37F
0005434964053	18247	50	37H
0005433261549	18247	51	38B
0005433261553	18247	52	38D
0005433261539	18247	53	38E
0005433261547	18247	54	38G
0005434625940	4870	1	2A
0005434625939	4870	2	4A
0005435907465	4870	3	5A
0005435907450	4870	4	6E
0005434625942	4870	5	7C
0005435907463	4870	6	9A
0005434625941	4870	7	9D
0005434625944	4870	8	11A
0005434625947	4870	9	11D
0005433194835	4870	10	14F
0005434625946	4870	11	15C
0005433194826	4870	12	15F
0005434625948	4870	13	19A
0005435907464	4870	14	19E
0005434625945	4870	15	19F
0005434625943	4870	16	20F
0005434625843	32918	1	2F
0005435907496	32918	2	3D
0005434625868	32918	3	4C
0005434625882	32918	4	7A
0005434625846	32918	5	8A
0005434625898	32918	6	8F
0005434625897	32918	7	10A
0005434625888	32918	8	10C
0005435907497	32918	9	11F
0005435907498	32918	10	12C
0005434625883	32918	11	12E
0005434625864	32918	12	13A
0005435907500	32918	13	14A
0005435907501	32918	14	15A
0005434625894	32918	15	17C
0005435907499	32918	16	17D
0005434625833	32918	17	18F
0005433194856	32918	18	19C
0005433194857	32918	19	20E
0005435784916	13776	1	1A
0005435784980	13776	2	1B
0005435784937	13776	3	1C
0005435785037	13776	4	1D
0005435784729	13776	5	2A
0005435785018	13776	6	2B
0005435784809	13776	7	2C
0005435784941	13776	8	2D
0005435937375	13776	9	3A
0005435937382	13776	10	3B
0005435937381	13776	11	3C
0005435784930	13776	12	3D
0005435784835	13776	13	4A
0005435784849	13776	14	4B
0005435785008	13776	15	4C
0005435784955	13776	16	4D
0005435784834	13776	17	5A
0005435784927	13776	18	5B
0005435784926	13776	19	5C
0005435784957	13776	20	5D
0005435784956	13776	21	6A
0005435937379	13776	22	6B
0005435784841	13776	23	6C
0005435784981	13776	24	6D
0005435937376	13776	25	7A
0005435784895	13776	26	7B
0005435937378	13776	27	7C
0005432195690	13776	28	7D
0005435784851	13776	29	18A
0005435784992	13776	30	18B
0005435784847	13776	31	18C
0005435937380	13776	32	18D
0005432195689	13776	33	19A
0005435784819	13776	34	19B
0005435785017	13776	35	19C
0005435784929	13776	36	19D
0005435785009	13776	37	20A
0005435784852	13776	38	20C
0005435785027	13776	39	20D
0005435785010	13776	40	21A
0005435784938	13776	41	21B
0005435784940	13776	42	21C
0005432195691	13776	43	21D
0005432195688	13776	44	22A
0005435784871	13776	45	22B
0005435937377	13776	46	22D
0005435784848	13776	47	23A
0005435785036	13776	48	23B
0005435785223	27402	1	1A
0005435785247	27402	2	1B
0005435785235	27402	3	1C
0005435785232	27402	4	1D
0005432190616	27402	5	2A
0005435785228	27402	6	2B
0005435785233	27402	7	2C
0005435785250	27402	8	2D
0005432190618	27402	9	3A
0005435937318	27402	10	3C
0005435785254	27402	11	3D
0005432190615	27402	12	4A
0005435785242	27402	13	4C
0005435785231	27402	14	4D
0005435785237	27402	15	5A
0005432190617	27402	16	5B
0005435785256	27402	17	5C
0005435785251	27402	18	5D
0005435785224	27402	19	6A
0005435785226	27402	20	6B
0005435785246	27402	21	6D
0005435785248	27402	22	7A
0005435785227	27402	23	7B
0005435785244	27402	24	7C
0005435787346	27402	25	18A
0005435785258	27402	26	7D
0005435785243	27402	27	18B
0005435785253	27402	28	18D
0005435937328	27402	29	19A
0005435785225	27402	30	19B
0005435787348	27402	31	19C
0005435785241	27402	32	19D
0005435785238	27402	33	20A
0005435785236	27402	34	20B
0005435785252	27402	35	20C
0005435785234	27402	36	20D
0005435785245	27402	37	21A
0005435785255	27402	38	21B
0005435787347	27402	39	21C
0005435785240	27402	40	21D
0005435785257	27402	41	22A
0005435785229	27402	42	22C
0005435785249	27402	43	22D
0005435785239	27402	44	23A
0005435785230	27402	45	23B
0005434407063	20299	1	1A
0005434407223	20299	2	1C
0005435311050	20299	3	1D
0005435311038	20299	4	1F
0005434406951	20299	5	2A
0005434407296	20299	6	2C
0005434406960	20299	7	2F
0005434406796	20299	8	3A
0005435311043	20299	9	3C
0005435311036	20299	10	3D
0005434406999	20299	11	3F
0005434407135	20299	12	4A
0005434407174	20299	13	4C
0005434406952	20299	14	4D
0005434406991	20299	15	4E
0005434407122	20299	16	4F
0005434407226	20299	17	5C
0005434407054	20299	18	5D
0005434407086	20299	19	5E
0005435311048	20299	20	5F
0005434407243	20299	21	6A
0005434407090	20299	22	6C
0005434407099	20299	23	6D
0005434407100	20299	24	6E
0005434406908	20299	25	6F
0005434407376	20299	26	7A
0005434406827	20299	27	7C
0005432058372	20299	28	7D
0005434407225	20299	29	7F
0005434407150	20299	30	8A
0005434407126	20299	31	8C
0005435311037	20299	32	8D
0005432058374	20299	33	8E
0005434407240	20299	34	8F
0005434407248	20299	35	9C
0005434407337	20299	36	9D
0005435311049	20299	37	9E
0005434407344	20299	38	9F
0005434407000	20299	39	10A
0005434407055	20299	40	10C
0005434406933	20299	41	10D
0005434407151	20299	42	10E
0005435311041	20299	43	11C
0005435311039	20299	44	11E
0005434407029	20299	45	11F
0005432058373	20299	46	12C
0005435311040	20299	47	12D
0005435311047	20299	48	12E
0005434407249	20299	49	12F
0005434407114	20299	50	13A
0005434406961	20299	51	13C
0005434407247	20299	52	13E
0005435311046	20299	53	13F
0005434406962	20299	54	14A
0005434407115	20299	55	14C
0005434407173	20299	56	14D
0005435311044	20299	57	14E
0005434407216	20299	58	14F
0005434407224	20299	59	15A
0005434407153	20299	60	15C
0005435311042	20299	61	15D
0005434407136	20299	62	15F
0005434406969	20299	63	16A
0005435311051	20299	64	16C
0005434407037	20299	65	16D
0005434406795	20299	66	16E
0005434406919	20299	67	16F
0005434407154	20299	68	17A
0005434406998	20299	69	17C
0005434407089	20299	70	17D
0005434407242	20299	71	17E
0005434406918	20299	72	17F
0005434406958	20299	73	18A
0005434407036	20299	74	18D
0005434407026	20299	75	18E
0005434407011	20299	76	18F
0005435311045	20299	77	19A
0005432058375	20299	78	19C
0005434407097	20299	79	19D
0005434407081	20299	80	19F
0005434407007	20299	81	20A
0005434407152	20299	82	20D
0005434407113	20299	83	20E
0005434407613	26970	1	1C
0005435310895	26970	2	1D
0005434407609	26970	3	1F
0005434407652	26970	4	2A
0005434407661	26970	5	2C
0005434407660	26970	6	2D
0005434407647	26970	7	2F
0005434407623	26970	8	3A
0005434407621	26970	9	3C
0005434407656	26970	10	3D
0005434407666	26970	11	3F
0005434407663	26970	12	4A
0005434407622	26970	13	4D
0005434407634	26970	14	4E
0005434407648	26970	15	4F
0005434407620	26970	16	5A
0005434407654	26970	17	5C
0005434407664	26970	18	5F
0005434407651	26970	19	6A
0005434407644	26970	20	6C
0005434407640	26970	21	6D
0005434407670	26970	22	6E
0005435310923	26970	23	6F
0005434407610	26970	24	7C
0005432153924	26970	25	7D
0005435310865	26970	26	7E
0005434407669	26970	27	7F
0005434407639	26970	28	8A
0005434407632	26970	29	8C
0005434407637	26970	30	8D
0005434407614	26970	31	8F
0005434407617	26970	32	8E
0005434407641	26970	33	9A
0005434407650	26970	34	9C
0005434407659	26970	35	9D
0005434407625	26970	36	9F
0005434407665	26970	37	10A
0005434407607	26970	38	10D
0005434407611	26970	39	10E
0005435310916	26970	40	10F
0005434407624	26970	41	11A
0005434407635	26970	42	11D
0005432153927	26970	43	11E
0005434407658	26970	44	12A
0005434407615	26970	45	11F
0005435310907	26970	46	12C
0005435310918	26970	47	12E
0005434407630	26970	48	12F
0005434407667	26970	49	13C
0005435310925	26970	50	13D
0005434407671	26970	51	13E
0005434407636	26970	52	13F
0005432153922	26970	53	14A
0005434407616	26970	54	14C
0005434407629	26970	55	14D
0005435310915	26970	56	14E
0005434407649	26970	57	14F
0005434407618	26970	58	15A
0005432153926	26970	59	15C
0005434407646	26970	60	15D
0005432153921	26970	61	15E
0005434407662	26970	62	15F
0005434407642	26970	63	16A
0005434407657	26970	64	16C
0005434407631	26970	65	16D
0005434407627	26970	66	16E
0005434407628	26970	67	16F
0005434407606	26970	68	17D
0005432153925	26970	69	17E
0005434407655	26970	70	17F
0005434407626	26970	71	18A
0005434407643	26970	72	18C
0005435310930	26970	73	18D
0005434407633	26970	74	18E
0005435310864	26970	75	18F
0005434407653	26970	76	19A
0005435310929	26970	77	19C
0005434407668	26970	78	19D
0005432153923	26970	79	19F
0005434407608	26970	80	20A
0005434407638	26970	81	20C
0005434407645	26970	82	20D
0005434407619	26970	83	20E
0005434407612	26970	84	20F
0005433123714	5701	1	1A
0005433123789	5701	2	1C
0005434319376	5701	3	1D
0005433123692	5701	4	2A
0005433123590	5701	5	2F
0005434319370	5701	6	3A
0005433123591	5701	7	3D
0005434319377	5701	8	4D
0005432109697	5701	9	4E
0005433123721	5701	10	5A
0005433123689	5701	11	5D
0005433123785	5701	12	5F
0005433123702	5701	13	6F
0005433123720	5701	14	8A
0005433123596	5701	15	9A
0005433123790	5701	16	9D
0005432109699	5701	17	9E
0005434319382	5701	18	9F
0005434319365	5701	19	10A
0005434319381	5701	20	10C
0005432109698	5701	21	10D
0005434319378	5701	22	10E
0005434319366	5701	23	11A
0005433123663	5701	24	11C
0005434319371	5701	25	12A
0005434311214	5701	26	12D
0005434319367	5701	27	12E
0005434319373	5701	28	13A
0005434319375	5701	29	13C
0005434319364	5701	30	13F
0005434319374	5701	31	14D
0005433123656	5701	32	15A
0005433123761	5701	33	15C
0005433123577	5701	34	15D
0005434319368	5701	35	16A
0005434319383	5701	36	16E
0005434311215	5701	37	18A
0005434319380	5701	38	19C
0005434319372	5701	39	19D
0005434319369	5701	40	19E
0005433123694	5701	41	19F
0005434319379	5701	42	20E
0005434319151	15651	1	2C
0005433123892	15651	2	2D
0005434319251	15651	3	2F
0005433123903	15651	4	4A
0005433123898	15651	5	4C
0005434312298	15651	6	5A
0005433123910	15651	7	5D
0005433123890	15651	8	5E
0005434319271	15651	9	5F
0005433123900	15651	10	6C
0005434319230	15651	11	6D
0005433123895	15651	12	7C
0005433123906	15651	13	7F
0005433123897	15651	14	8A
0005433123899	15651	15	8E
0005433123894	15651	16	9A
0005433123907	15651	17	9D
0005434319270	15651	18	10A
0005433123888	15651	19	10C
0005434319226	15651	20	10F
0005433123905	15651	21	11A
0005434319229	15651	22	11D
0005433123902	15651	23	12C
0005434319225	15651	24	12F
0005434319241	15651	25	13A
0005433123891	15651	26	13D
0005433123908	15651	27	14D
0005434319272	15651	28	15A
0005433123909	15651	29	15D
0005433123896	15651	30	16D
0005434311191	15651	31	17C
0005434312296	15651	32	17F
0005433123889	15651	33	18C
0005433123893	15651	34	19D
0005434319211	15651	35	19E
0005433123901	15651	36	19F
0005433123904	15651	37	20C
0005434319256	15651	38	20E
0005435221502	24980	1	2B
0005435217685	24980	2	2C
0005435220286	24980	3	3A
0005435220288	24980	4	5C
0005435220287	24980	5	6C
0005435220295	24980	6	7C
0005435221503	24980	7	18B
0005435221501	24980	8	21D
0005434189136	9013	1	2D
0005434484336	9013	2	4B
0005434189135	9013	3	4D
0005434484333	9013	4	6C
0005434484337	9013	5	7D
0005434484332	9013	6	19B
0005434484338	9013	7	20A
0005434484334	9013	8	21B
0005434189109	9013	9	21C
0005434484335	9013	10	23B
0005434484277	16624	1	1A
0005434484284	16624	2	3A
0005434189169	16624	3	5D
0005434189166	16624	4	7A
0005434484292	16624	5	7D
0005434484283	16624	6	18B
0005434189165	16624	7	19A
0005434189168	16624	8	20A
0005434484293	16624	9	21C
0005434189167	16624	10	22D
0005433123909	7581	1	1C
0005433123903	7581	2	1D
0005433123898	7581	3	1F
0005433123910	7581	4	2D
0005433123908	7581	5	5A
0005433123899	7581	6	5C
0005433123905	7581	7	7A
0005433123893	7581	8	7E
0005433722139	7581	9	8C
0005433123894	7581	10	9A
0005433722138	7581	11	9C
0005433123888	7581	12	9D
0005433123889	7581	13	10C
0005433123897	7581	14	10F
0005433123895	7581	15	11A
0005433123896	7581	16	11D
0005433123901	7581	17	11E
0005433123907	7581	18	11F
0005433123891	7581	19	13F
0005433722122	7581	20	14A
0005433123904	7581	21	14D
0005433123906	7581	22	14F
0005433722135	7581	23	15E
0005433722134	7581	24	16A
0005433722132	7581	25	16C
0005433123900	7581	26	16F
0005433722133	7581	27	17A
0005433123892	7581	28	19D
0005433722102	7581	29	19E
0005433123890	7581	30	19F
0005433123902	7581	31	20D
0005432693015	7578	1	1A
0005432693029	7578	2	1C
0005432693028	7578	3	1D
0005432720850	7578	4	1F
0005432693031	7578	5	2A
0005432071567	7578	6	2D
0005432720843	7578	7	2F
0005433449932	7578	8	3A
0005433449927	7578	9	3C
0005432693019	7578	10	3D
0005433449930	7578	11	3F
0005432720841	7578	12	4A
0005433449929	7578	13	4C
0005432720846	7578	14	4F
0005432693006	7578	15	5A
0005433449918	7578	16	5C
0005432720859	7578	17	5D
0005433449935	7578	18	5E
0005433449923	7578	19	5F
0005432693023	7578	20	6A
0005433449926	7578	21	6D
0005432720848	7578	22	6E
0005433449921	7578	23	6F
0005432693010	7578	24	7A
0005433449928	7578	25	7C
0005432720849	7578	26	7D
0005432693024	7578	27	7E
0005432720842	7578	28	7F
0005432720853	7578	29	8A
0005432720863	7578	30	8C
0005432693016	7578	31	8D
0005432720864	7578	32	8E
0005432693030	7578	33	8F
0005432693009	7578	34	9A
0005433449933	7578	35	9C
0005433449931	7578	36	9D
0005432720852	7578	37	9E
0005432693012	7578	38	9F
0005432693004	7578	39	10A
0005432693003	7578	40	10C
0005432693007	7578	41	10D
0005432693014	7578	42	10E
0005433449925	7578	43	10F
0005432693005	7578	44	11A
0005432693020	7578	45	11C
0005433449936	7578	46	11D
0005433449937	7578	47	11E
0005432720857	7578	48	11F
0005432720856	7578	49	12A
0005432720865	7578	50	12C
0005432720847	7578	51	12D
0005432720845	7578	52	12F
0005432693026	7578	53	13C
0005432720861	7578	54	13D
0005433449939	7578	55	13E
0005432720858	7578	56	13F
0005432720851	7578	57	14C
0005432693022	7578	58	14A
0005432720866	7578	59	14D
0005432720855	7578	60	14E
0005432693002	7578	61	14F
0005432693027	7578	62	15C
0005432693018	7578	63	15E
0005432071568	7578	64	15F
0005432693021	7578	65	16A
0005432720862	7578	66	16C
0005432693017	7578	67	16D
0005432720854	7578	68	16E
0005433449920	7578	69	16F
0005432693001	7578	70	17C
0005432693011	7578	71	17D
0005432693025	7578	72	17E
0005432693008	7578	73	17F
0005433449922	7578	74	18A
0005433449924	7578	75	18C
0005433449940	7578	76	18E
0005432720860	7578	77	18F
0005433449938	7578	78	19A
0005432071566	7578	79	19C
0005432693013	7578	80	19D
0005432720840	7578	81	19F
0005433449934	7578	82	20A
0005433449919	7578	83	20C
0005432720844	7578	84	20F
0005432692653	30323	1	1A
0005432692688	30323	2	1D
0005433449728	30323	3	2A
0005432692697	30323	4	3A
0005432692731	30323	5	3F
0005433449729	30323	6	4A
0005432692880	30323	7	4C
0005433449768	30323	8	4E
0005433449609	30323	9	5A
0005432692620	30323	10	5D
0005432692670	30323	11	5E
0005432692750	30323	12	6A
0005432692821	30323	13	6C
0005432692696	30323	14	6D
0005432692703	30323	15	6F
0005432692879	30323	16	7D
0005432692626	30323	17	7F
0005432692570	30323	18	8A
0005433449748	30323	19	8C
0005432692774	30323	20	8F
0005433449635	30323	21	9C
0005433449619	30323	22	9E
0005432692701	30323	23	9F
0005432692621	30323	24	10E
0005433449733	30323	25	10F
0005433449747	30323	26	11A
0005432692809	30323	27	11E
0005433449754	30323	28	11F
0005433449637	30323	29	12C
0005432692740	30323	30	12F
0005433449777	30323	31	13C
0005433449770	30323	32	13F
0005432692817	30323	33	14C
0005432692820	30323	34	14D
0005433449844	30323	35	14E
0005432692649	30323	36	14F
0005433449683	30323	37	15A
0005433449634	30323	38	15C
0005432692841	30323	39	15E
0005432692710	30323	40	16C
0005433449794	30323	41	16D
0005433449758	30323	42	16E
0005432692842	30323	43	17A
0005433449769	30323	44	17C
0005432692578	30323	45	17E
0005432692637	30323	46	18A
0005432692808	30323	47	18F
0005433449797	30323	48	19E
0005432692650	30323	49	19F
0005433449618	30323	50	20C
0005433449753	30323	51	20D
0005433449636	30323	52	20E
0005432720494	30322	1	1A
0005432720599	30322	2	1C
0005433123702	30322	3	1D
0005433123694	30322	4	2C
0005433123689	30322	5	3A
0005433722213	30322	6	3C
0005433123714	30322	7	3D
0005433123721	30322	8	4A
0005433123785	30322	9	4E
0005432720600	30322	10	5A
0005433722216	30322	11	5F
0005433123789	30322	12	6A
0005432720559	30322	13	6C
0005432720668	30322	14	6D
0005432720689	30322	15	7C
0005432720703	30322	16	7D
0005432720704	30322	17	8D
0005433123596	30322	18	8E
0005432720637	30322	19	9D
0005433123761	30322	20	10A
0005433123720	30322	21	10D
0005432720733	30322	22	10E
0005433722209	30322	23	10F
0005433123591	30322	24	11A
0005433722210	30322	25	11C
0005432720687	30322	26	11D
0005432720558	30322	27	11F
0005432720656	30322	28	12D
0005433722215	30322	29	12E
0005432720688	30322	30	12F
0005432720621	30322	31	13C
0005432720582	30322	32	13E
0005433722212	30322	33	13F
0005432720620	30322	34	14A
0005432720666	30322	35	15A
0005433123692	30322	36	15E
0005433123577	30322	37	15F
0005432720601	30322	38	16A
0005432720732	30322	39	16C
0005432720724	30322	40	16D
0005433123656	30322	41	16E
0005433123590	30322	42	18A
0005433123790	30322	43	18D
0005432720539	30322	44	18F
0005433722211	30322	45	19D
0005432720655	30322	46	19E
0005432720560	30322	47	19F
0005433123663	30322	48	20A
0005433722214	30322	49	20C
0005432720710	30322	50	20F
0005433724796	1372	1	1A
0005433192884	1372	2	2C
0005433724800	1372	3	2F
0005434514962	1372	4	3A
0005434586552	1372	5	3C
0005434586560	1372	6	3D
0005433192885	1372	7	3F
0005434586563	1372	8	4C
0005434514964	1372	9	4E
0005434586564	1372	10	4F
0005433192901	1372	11	5C
0005434586553	1372	12	5E
0005434586576	1372	13	5F
0005433525020	1372	14	6A
0005433724797	1372	15	6C
0005432968812	1372	16	6D
0005433525019	1372	17	6E
0005432270997	1372	18	6F
0005433192914	1372	19	7A
0005434514963	1372	20	7D
0005434586577	1372	21	7E
0005433724799	1372	22	8C
0005432927935	1372	23	8D
0005432270999	1372	24	8F
0005434586562	1372	25	9A
0005432927921	1372	26	9C
0005434586561	1372	27	9D
0005434586556	1372	28	9E
0005433192907	1372	29	10A
0005434513574	1372	30	10C
0005433525015	1372	31	10E
0005434586566	1372	32	10F
0005433192915	1372	33	11C
0005434586575	1372	34	11D
0005433525021	1372	35	11E
0005434586555	1372	36	11F
0005434586567	1372	37	12A
0005432270998	1372	38	12C
0005433192977	1372	39	12D
0005434586565	1372	40	12E
0005433192931	1372	41	12F
0005433192911	1372	42	13C
0005433724798	1372	43	13E
0005434586559	1372	44	13F
0005432927932	1372	45	14A
0005434586558	1372	46	14C
0005433192986	1372	47	14D
0005433192948	1372	48	14E
0005433192947	1372	49	14F
0005433192930	1372	50	15A
0005433192928	1372	51	15D
0005434586557	1372	52	15E
0005434586572	1372	53	15F
0005434586574	1372	54	16A
0005434586571	1372	55	16C
0005434586570	1372	56	16D
0005432927931	1372	57	16E
0005433525017	1372	58	16F
0005433525016	1372	59	17A
0005434586569	1372	60	17C
0005433192985	1372	61	17D
0005434586568	1372	62	17F
0005433192906	1372	63	18A
0005434586573	1372	64	18C
0005433525023	1372	65	18D
0005433724801	1372	66	19A
0005433525022	1372	67	19C
0005433525014	1372	68	19D
0005434586554	1372	69	19E
0005433525018	1372	70	19F
0005432968810	1372	71	20C
0005433192929	1372	72	20D
0005433192913	1372	73	20E
0005434513575	1372	74	20F
0005434586419	18503	1	1A
0005432927971	18503	2	1C
0005434586379	18503	3	1D
0005433193016	18503	4	1F
0005434586392	18503	5	2A
0005433193022	18503	6	2C
0005434586471	18503	7	2D
0005434586477	18503	8	2F
0005433524888	18503	9	3A
0005433524924	18503	10	3C
0005433193023	18503	11	4A
0005434586279	18503	12	4E
0005433193014	18503	13	4F
0005433724746	18503	14	5A
0005434586346	18503	15	5C
0005432927970	18503	16	5D
0005432968836	18503	17	5E
0005433724781	18503	18	5F
0005432927968	18503	19	6A
0005433724744	18503	20	6C
0005433524923	18503	21	6D
0005432927969	18503	22	6F
0005434586182	18503	23	7A
0005433524916	18503	24	7C
0005433524911	18503	25	7D
0005433524938	18503	26	8C
0005433724767	18503	27	8F
0005433524932	18503	28	9C
0005434586394	18503	29	9E
0005434586393	18503	30	9F
0005432927967	18503	31	10A
0005433724745	18503	32	10C
0005433193026	18503	33	10D
0005434586239	18503	34	10E
0005433724761	18503	35	10F
0005434586287	18503	36	11C
0005433193019	18503	37	11D
0005434586371	18503	38	11E
0005433524915	18503	39	12D
0005433193027	18503	40	12E
0005432927966	18503	41	12F
0005432968834	18503	42	13A
0005434586325	18503	43	13C
0005434586397	18503	44	13E
0005433524910	18503	45	13F
0005433724766	18503	46	14E
0005434586312	18503	47	14F
0005434586300	18503	48	15A
0005434586364	18503	49	15C
0005432968835	18503	50	15E
0005434586240	18503	51	15F
0005433524937	18503	52	16A
0005433193020	18503	53	16D
0005433193017	18503	54	16E
0005433524889	18503	55	16F
0005433193021	18503	56	17A
0005433524887	18503	57	17C
0005434586303	18503	58	17D
0005434586378	18503	59	17E
0005433524914	18503	60	17F
0005433524929	18503	61	18A
0005433193024	18503	62	18C
0005434586352	18503	63	18D
0005433724762	18503	64	18E
0005433193018	18503	65	18F
0005433193015	18503	66	19A
0005433193025	18503	67	19C
0005434586411	18503	68	19D
0005434586315	18503	69	19E
0005434586286	18503	70	19F
0005434586262	18503	71	20A
0005434586336	18503	72	20E
0005434586420	18503	73	20F
0005434344103	11443	1	1A
0005434344107	11443	2	1B
0005434344114	11443	3	1C
0005434344113	11443	4	1D
0005434344110	11443	5	2A
0005434344122	11443	6	2B
0005434344118	11443	7	2C
0005434344131	11443	8	2D
0005434344104	11443	9	3A
0005434344126	11443	10	3B
0005434344119	11443	11	3C
0005435302139	11443	12	3D
0005434344102	11443	13	4A
0005434344127	11443	14	4B
0005435302149	11443	15	4C
0005434344099	11443	16	4D
0005434344106	11443	17	5A
0005435302161	11443	18	5B
0005434344124	11443	19	5C
0005434344108	11443	20	5D
0005434344129	11443	21	6A
0005434344120	11443	22	6B
0005434142603	11443	23	6C
0005435302141	11443	24	6D
0005434344116	11443	25	7A
0005434344134	11443	26	7B
0005435302140	11443	27	7C
0005434344101	11443	28	7D
0005434344133	11443	29	18A
0005434344109	11443	30	18B
0005434344123	11443	31	18C
0005434344130	11443	32	18D
0005434344121	11443	33	19A
0005435302137	11443	34	19C
0005435302162	11443	35	19D
0005434344125	11443	36	20A
0005434344117	11443	37	20B
0005435302163	11443	38	20D
0005434344105	11443	39	21A
0005434344111	11443	40	21B
0005434344112	11443	41	21C
0005434344132	11443	42	21D
0005434344128	11443	43	22A
0005434344115	11443	44	22B
0005434344100	11443	45	22C
0005434344135	11443	46	22D
0005435302152	11443	47	23A
0005434142604	11443	48	23B
0005434343769	29791	1	1A
0005434343753	29791	2	1B
0005434343666	29791	3	1C
0005434343892	29791	4	1D
0005434343795	29791	5	2A
0005434343812	29791	6	2B
0005434142555	29791	7	2C
0005435304148	29791	8	2D
0005434343793	29791	9	3A
0005434343803	29791	10	3B
0005434343838	29791	11	3C
0005434142560	29791	12	3D
0005434142558	29791	13	4A
0005435304149	29791	14	4B
0005434142559	29791	15	4C
0005434343722	29791	16	4D
0005434343770	29791	17	5A
0005434142567	29791	18	5D
0005434343813	29791	19	6A
0005434343651	29791	20	6B
0005434343894	29791	21	6C
0005435304154	29791	22	6D
0005434343893	29791	23	7A
0005434343802	29791	24	7B
0005434343688	29791	25	7C
0005434343840	29791	26	7D
0005434142576	29791	27	18A
0005434142563	29791	28	18B
0005434343756	29791	29	18C
0005434343909	29791	30	18D
0005434343689	29791	31	19A
0005434343910	29791	32	19B
0005434343821	29791	33	19C
0005434142570	29791	34	19D
0005435304153	29791	35	20A
0005434142564	29791	36	20B
0005435304152	29791	37	20C
0005434343768	29791	38	20D
0005435304150	29791	39	21A
0005434343794	29791	40	21B
0005434142554	29791	41	21C
0005434343904	29791	42	21D
0005435304151	29791	43	22A
0005434343906	29791	44	22B
0005434343667	29791	45	22C
0005434142562	29791	46	22D
0005434142569	29791	47	23A
0005434343866	29791	48	23B
0005435824575	1262	1	1D
0005435824576	1262	2	2A
0005433415501	1262	3	2F
0005435824578	1262	4	2C
0005435824584	1262	5	3A
0005435824582	1262	6	4D
0005435824564	1262	7	4C
0005435824577	1262	8	5C
0005433415519	1262	9	5A
0005433415520	1262	10	5F
0005435824566	1262	11	6D
0005432284551	1262	12	6C
0005433415522	1262	13	7E
0005435824569	1262	14	7D
0005433415502	1262	15	8B
0005435824573	1262	16	8F
0005435824572	1262	17	8E
0005433415475	1262	18	9A
0005435824563	1262	19	9D
0005435824565	1262	20	9C
0005435824581	1262	21	9B
0005433415542	1262	22	10A
0005433415498	1262	23	11A
0005435824588	1262	24	10F
0005433415512	1262	25	11C
0005435824590	1262	26	12C
0005435824574	1262	27	13C
0005435824589	1262	28	14A
0005435824585	1262	29	14C
0005433415518	1262	30	14B
0005435824567	1262	31	15E
0005435824571	1262	32	16B
0005432284552	1262	33	16E
0005435824580	1262	34	17D
0005435824579	1262	35	18A
0005435824570	1262	36	18B
0005433415541	1262	37	18E
0005435824568	1262	38	19C
0005435824586	1262	39	19B
0005433415500	1262	40	19E
0005435824587	1262	41	20A
0005432284553	1262	42	20E
0005435824583	1262	43	21E
0005433415623	17982	1	1A
0005435824338	17982	2	1D
0005435824279	17982	3	2A
0005435824451	17982	4	2D
0005433415624	17982	5	2C
0005435824301	17982	6	4A
0005433415628	17982	7	3F
0005435824375	17982	8	4D
0005435824353	17982	9	5D
0005435824424	17982	10	5F
0005435824252	17982	11	7A
0005433415633	17982	12	6F
0005435824274	17982	13	7C
0005433415637	17982	14	7F
0005435824319	17982	15	8E
0005433415631	17982	16	8C
0005433415638	17982	17	8F
0005435824372	17982	18	9A
0005435824376	17982	19	9D
0005435824288	17982	20	9C
0005433415626	17982	21	10A
0005435824251	17982	22	10E
0005433415635	17982	23	10D
0005435824527	17982	24	10F
0005435824294	17982	25	11B
0005435824339	17982	26	11D
0005435824324	17982	27	11C
0005435824447	17982	28	12A
0005435824263	17982	29	12D
0005433415634	17982	30	12E
0005435824386	17982	31	13C
0005435824265	17982	32	13E
0005435824425	17982	33	13D
0005433415627	17982	34	14B
0005433415625	17982	35	15A
0005435824216	17982	36	15C
0005435824273	17982	37	15E
0005435824257	17982	38	16C
0005435824215	17982	39	16B
0005435824262	17982	40	16D
0005435824320	17982	41	17A
0005435824443	17982	42	17C
0005435824478	17982	43	17E
0005435824382	17982	44	18B
0005433415636	17982	45	17F
0005435824395	17982	46	18C
0005435824264	17982	47	18D
0005435824336	17982	48	18F
0005435824390	17982	49	19C
0005433415632	17982	50	19B
0005433415630	17982	51	19E
0005435824325	17982	52	19F
0005435824381	17982	53	21A
0005433415629	17982	54	21D
0005435824394	17982	55	21C
0005435824371	17982	56	21E
0005434461637	12575	1	1D
0005434460495	12575	2	2A
0005434461636	12575	3	3B
0005434460498	12575	4	3C
0005434461641	12575	5	4A
0005434461638	12575	6	6A
0005434460496	12575	7	7A
0005434460499	12575	8	18C
0005434461635	12575	9	19C
0005434460497	12575	10	19D
0005434461640	12575	11	21A
0005434461639	12575	12	23A
0005435242454	5665	1	1A
0005432783689	5665	2	1C
0005432783674	5665	3	1D
0005432783676	5665	4	1F
0005432783672	5665	5	2A
0005432783718	5665	6	2C
0005432783711	5665	7	2D
0005432783714	5665	8	2F
0005432783670	5665	9	3A
0005432783706	5665	10	3C
0005435242543	5665	11	3D
0005432783699	5665	12	3F
0005432143982	5665	13	4C
0005432783667	5665	14	4D
0005435242541	5665	15	4E
0005435242551	5665	16	4F
0005435242433	5665	17	5A
0005432783681	5665	18	5C
0005435242511	5665	19	5D
0005432783683	5665	20	5E
0005435242542	5665	21	5F
0005432783669	5665	22	6A
0005435242520	5665	23	6C
0005435242483	5665	24	6D
0005432783673	5665	25	6E
0005435242567	5665	26	6F
0005432783712	5665	27	7A
0005432783702	5665	28	7C
0005432783713	5665	29	7D
0005432783700	5665	30	7E
0005435242548	5665	31	7F
0005435242522	5665	32	8A
0005432783704	5665	33	8C
0005432783665	5665	34	8D
0005432783719	5665	35	8E
0005432783692	5665	36	8F
0005432783691	5665	37	9A
0005432143981	5665	38	9C
0005435242547	5665	39	9D
0005435476674	5665	40	9E
0005432783701	5665	41	9F
0005435242451	5665	42	10A
0005432783715	5665	43	10C
0005432143980	5665	44	10D
0005432783693	5665	45	10E
0005432783679	5665	46	10F
0005435242605	5665	47	11A
0005432783717	5665	48	11C
0005432783686	5665	49	11D
0005435242510	5665	50	11E
0005435242394	5665	51	11F
0005435242684	5665	52	12A
0005432783709	5665	53	12C
0005432783685	5665	54	12D
0005432783678	5665	55	12E
0005432783690	5665	56	12F
0005435242549	5665	57	13A
0005432783708	5665	58	13C
0005432783684	5665	59	13D
0005432783710	5665	60	13E
0005432783703	5665	61	13F
0005432783675	5665	62	14A
0005432783671	5665	63	14C
0005435242636	5665	64	14D
0005432783687	5665	65	14E
0005432783705	5665	66	14F
0005435242523	5665	67	15A
0005435476675	5665	68	15C
0005432783694	5665	69	15D
0005432783707	5665	70	15E
0005432143983	5665	71	15F
0005432783668	5665	72	16A
0005435476676	5665	73	16C
0005435242554	5665	74	16D
0005432783697	5665	75	16E
0005432783696	5665	76	16F
0005432783716	5665	77	17A
0005432783682	5665	78	17C
0005435242467	5665	79	17D
0005432783695	5665	80	17E
0005435242602	5665	81	17F
0005432783688	5665	82	18A
0005435476672	5665	83	18C
0005435242604	5665	84	18D
0005435476680	5665	85	18E
0005435242685	5665	86	18F
0005435242478	5665	87	19A
0005432783666	5665	88	19C
0005435476673	5665	89	19D
0005432783680	5665	90	19E
0005432783698	5665	91	19F
0005432783677	5665	92	20A
0005435242393	5665	93	20C
0005435242466	5665	94	20D
0005435242524	5665	95	20E
0005435476679	5665	96	20F
0005432783343	15367	1	1A
0005435476745	15367	2	1C
0005435242793	15367	3	1D
0005432783250	15367	4	1F
0005432783258	15367	5	2A
0005432783123	15367	6	2C
0005432783382	15367	7	2D
0005435242771	15367	8	2F
0005432783341	15367	9	3A
0005432783145	15367	10	3D
0005432783433	15367	11	3F
0005432783027	15367	12	4C
0005435242794	15367	13	4E
0005432783205	15367	14	4F
0005435242789	15367	15	5A
0005432783216	15367	16	5C
0005432783272	15367	17	5D
0005432783179	15367	18	5F
0005432783101	15367	19	6A
0005432783021	15367	20	6C
0005435242781	15367	21	6D
0005435242786	15367	22	6F
0005435476741	15367	23	7A
0005432783321	15367	24	7C
0005435476738	15367	25	7E
0005432783355	15367	26	7F
0005432783334	15367	27	8A
0005435242796	15367	28	8C
0005435242785	15367	29	8D
0005435476740	15367	30	8E
0005435476737	15367	31	8F
0005435476744	15367	32	9A
0005435242792	15367	33	9C
0005432783372	15367	34	9D
0005432783333	15367	35	9E
0005435242774	15367	36	9F
0005435242790	15367	37	10A
0005432783124	15367	38	10C
0005432783278	15367	39	10D
0005435242778	15367	40	10E
0005435242770	15367	41	10F
0005432783266	15367	42	11A
0005432783012	15367	43	11C
0005435242772	15367	44	11D
0005435242795	15367	45	11E
0005432783122	15367	46	11F
0005432783286	15367	47	12A
0005432783111	15367	48	12C
0005432783204	15367	49	12D
0005432783340	15367	50	12E
0005432783206	15367	51	12F
0005435242791	15367	52	13A
0005432783113	15367	53	13C
0005432783381	15367	54	13D
0005432783383	15367	55	13E
0005432783076	15367	56	13F
0005435476739	15367	57	14A
0005435242773	15367	58	14C
0005432783342	15367	59	14D
0005435242780	15367	60	14E
0005435242788	15367	61	14F
0005432783380	15367	62	15A
0005432783235	15367	63	15C
0005435476743	15367	64	15D
0005432783418	15367	65	15F
0005432782971	15367	66	16C
0005432783215	15367	67	16D
0005435242776	15367	68	16E
0005435242777	15367	69	16F
0005432783273	15367	70	17A
0005435242783	15367	71	17C
0005435242775	15367	72	17D
0005435242779	15367	73	17E
0005435242782	15367	74	17F
0005432783114	15367	75	18A
0005432783191	15367	76	18C
0005435476736	15367	77	18D
0005432783088	15367	78	18E
0005435242787	15367	79	18F
0005432783075	15367	80	19A
0005432783100	15367	81	19C
0005432783274	15367	82	19D
0005435242784	15367	83	19E
0005435476742	15367	84	19F
0005432783279	15367	85	20A
0005432783078	15367	86	20C
0005432783144	15367	87	20D
0005432783236	15367	88	20E
0005432783287	15367	89	20F
0005432848284	4336	1	1B
0005432848288	4336	2	1C
0005435850823	4336	3	1D
0005432848292	4336	4	2A
0005432848291	4336	5	2D
0005435850824	4336	6	3A
0005435850841	4336	7	3C
0005432848279	4336	8	3D
0005432848280	4336	9	4A
0005434462785	4336	10	4B
0005432848281	4336	11	4C
0005435850840	4336	12	4D
0005435850822	4336	13	5B
0005435850825	4336	14	5C
0005434463925	4336	15	5D
0005432848287	4336	16	6B
0005432848289	4336	17	6D
0005435850862	4336	18	7D
0005434463924	4336	19	18A
0005432848290	4336	20	18B
0005432848283	4336	21	19A
0005432848278	4336	22	19C
0005435850796	4336	23	19D
0005435850827	4336	24	20B
0005435850833	4336	25	20C
0005435850813	4336	26	20D
0005435850814	4336	27	21A
0005435850863	4336	28	21B
0005432848285	4336	29	21D
0005432848282	4336	30	22A
0005434462786	4336	31	22B
0005432848286	4336	32	22C
0005435850830	4336	33	23B
0005435850889	28852	1	1A
0005432848114	28852	2	1B
0005432848161	28852	3	2D
0005432848158	28852	4	3A
0005435850893	28852	5	3C
0005432848098	28852	6	3D
0005432848178	28852	7	4A
0005432848172	28852	8	4C
0005432848177	28852	9	5A
0005432848188	28852	10	5B
0005435850897	28852	11	6B
0005432848182	28852	12	6A
0005435850891	28852	13	7A
0005432848097	28852	14	7B
0005432848146	28852	15	7C
0005432848115	28852	16	18D
0005432848169	28852	17	19B
0005432848116	28852	18	19C
0005435850890	28852	19	19D
0005432848170	28852	20	20A
0005435850892	28852	21	20B
0005435850896	28852	22	20C
0005432848229	28852	23	20D
0005432848191	28852	24	21A
0005435850895	28852	25	21B
0005432848128	28852	26	21C
0005435850898	28852	27	22A
0005435850888	28852	28	22B
0005435850894	28852	29	22D
0005434925770	6246	1	2A
0005434443686	6246	2	1F
0005434443674	6246	3	2C
0005434925750	6246	4	2D
0005433496916	6246	5	2F
0005434925760	6246	6	3C
0005433496914	6246	7	3D
0005433496924	6246	8	3F
0005433496912	6246	9	4A
0005434925773	6246	10	4E
0005434443680	6246	11	5A
0005433496909	6246	12	5C
0005433496911	6246	13	5D
0005433496923	6246	14	5F
0005434925772	6246	15	6A
0005433496917	6246	16	6C
0005433496907	6246	17	6D
0005433496928	6246	18	6E
0005434443675	6246	19	6F
0005433496915	6246	20	7C
0005434925753	6246	21	7D
0005434925755	6246	22	7E
0005434443679	6246	23	7F
0005433496904	6246	24	8A
0005434925754	6246	25	8C
0005434925775	6246	26	8D
0005432075225	6246	27	8F
0005434925757	6246	28	9A
0005433496910	6246	29	9C
0005434925767	6246	30	9D
0005433496921	6246	31	9F
0005433496927	6246	32	10A
0005434443681	6246	33	10D
0005434443676	6246	34	10E
0005434925758	6246	35	10F
0005433496925	6246	36	11A
0005434443684	6246	37	11C
0005433496900	6246	38	11D
0005434443685	6246	39	11E
0005434443683	6246	40	12D
0005433496908	6246	41	12E
0005434925764	6246	42	12F
0005433496899	6246	43	13A
0005434925774	6246	44	13C
0005434925762	6246	45	13D
0005434925751	6246	46	13E
0005434443682	6246	47	13F
0005433496929	6246	48	14A
0005433496919	6246	49	14C
0005433496902	6246	50	14D
0005432075222	6246	51	14E
0005434443687	6246	52	14F
0005432075224	6246	53	15A
0005433496906	6246	54	15C
0005433496922	6246	55	15D
0005434925769	6246	56	15E
0005433496903	6246	57	15F
0005434443671	6246	58	16A
0005433496905	6246	59	16C
0005434925752	6246	60	16D
0005433496913	6246	61	16E
0005434925765	6246	62	17A
0005434443673	6246	63	17C
0005434925768	6246	64	17D
0005434925756	6246	65	17E
0005434925763	6246	66	17F
0005434925771	6246	67	18A
0005434925766	6246	68	18C
0005434443677	6246	69	18D
0005433496920	6246	70	18E
0005433496901	6246	71	18F
0005432075223	6246	72	19A
0005434925761	6246	73	19D
0005434443678	6246	74	19E
0005434443672	6246	75	20A
0005433496926	6246	76	20C
0005433496918	6246	77	20E
0005434925759	6246	78	20F
0005434925529	20362	1	1A
0005433496748	20362	2	1C
0005434925594	20362	3	1D
0005434925448	20362	4	2A
0005433496593	20362	5	2D
0005434925482	20362	6	2F
0005434925355	20362	7	3A
0005434925350	20362	8	3C
0005433496813	20362	9	3D
0005434443554	20362	10	3F
0005434443520	20362	11	4A
0005434443482	20362	12	4D
0005434925384	20362	13	4E
0005433496711	20362	14	4F
0005434925511	20362	15	5A
0005434925394	20362	16	5C
0005433496689	20362	17	5D
0005434925485	20362	18	5F
0005434443564	20362	19	6A
0005433496757	20362	20	6C
0005433496718	20362	21	6D
0005433496791	20362	22	6E
0005434925365	20362	23	6F
0005434925428	20362	24	7A
0005434925472	20362	25	7D
0005434925480	20362	26	7E
0005434925372	20362	27	7F
0005434443540	20362	28	8D
0005434925357	20362	29	8E
0005434925366	20362	30	8F
0005434925429	20362	31	9A
0005433496662	20362	32	9C
0005433496842	20362	33	9D
0005433496661	20362	34	9F
0005434443551	20362	35	10A
0005433496634	20362	36	10C
0005433496720	20362	37	10D
0005434925476	20362	38	10E
0005434925471	20362	39	10F
0005434925447	20362	40	11A
0005434443561	20362	41	11C
0005434925356	20362	42	11D
0005433496645	20362	43	11E
0005434925260	20362	44	11F
0005434443523	20362	45	12D
0005433496602	20362	46	12E
0005434443555	20362	47	13A
0005434925393	20362	48	13C
0005434443517	20362	49	13D
0005434925282	20362	50	13E
0005433496747	20362	51	13F
0005434925593	20362	52	14C
0005434925373	20362	53	14D
0005434925493	20362	54	14E
0005433496707	20362	55	15A
0005434443476	20362	56	15C
0005434925386	20362	57	15F
0005434925431	20362	58	16A
0005434925508	20362	59	16D
0005434925445	20362	60	16E
0005433496663	20362	61	17A
0005433496732	20362	62	17C
0005434443457	20362	63	17D
0005434925413	20362	64	17E
0005433496644	20362	65	18A
0005434443475	20362	66	18C
0005434925479	20362	67	18D
0005433496749	20362	68	18E
0005434925354	20362	69	18F
0005434925415	20362	70	19A
0005434925281	20362	71	19C
0005433496633	20362	72	19D
0005433496592	20362	73	19E
0005434925473	20362	74	19F
0005434443601	20362	75	20A
0005433496719	20362	76	20D
0005434443587	20362	77	20E
0005434925446	20362	78	20F
0005432783292	12194	1	1A
0005432783263	12194	2	1C
0005432783252	12194	3	1D
0005432783162	12194	4	1F
0005432783368	12194	5	2A
0005435242806	12194	6	2C
0005432783200	12194	7	2D
0005432783261	12194	8	2F
0005432783194	12194	9	3A
0005435242797	12194	10	3C
0005432783188	12194	11	3D
0005432783151	12194	12	3F
0005435242823	12194	13	4A
0005432783117	12194	14	4C
0005432783138	12194	15	4D
0005435242815	12194	16	4E
0005432783121	12194	17	4F
0005432783153	12194	18	5A
0005435242811	12194	19	5C
0005435242810	12194	20	5D
0005435242804	12194	21	5E
0005435242799	12194	22	5F
0005432783302	12194	23	6A
0005432783170	12194	24	6C
0005435242818	12194	25	6D
0005432783396	12194	26	6E
0005432783350	12194	27	6F
0005435242824	12194	28	7A
0005432783307	12194	29	7D
0005432783301	12194	30	7E
0005432783425	12194	31	7F
0005432783353	12194	32	8A
0005432783131	12194	33	8C
0005432783387	12194	34	8D
0005435242812	12194	35	8E
0005432783405	12194	36	8F
0005435242809	12194	37	9A
0005435242821	12194	38	9C
0005432783241	12194	39	9D
0005435242801	12194	40	9E
0005435242814	12194	41	9F
0005432783032	12194	42	10A
0005432783309	12194	43	10C
0005435242816	12194	44	10D
0005435242819	12194	45	10E
0005432783282	12194	46	10F
0005435242808	12194	47	11A
0005435242805	12194	48	11D
0005432783185	12194	49	11C
0005432783248	12194	50	11E
0005432783260	12194	51	11F
0005432783453	12194	52	12A
0005432783249	12194	53	12C
0005435242822	12194	54	12D
0005432783033	12194	55	12E
0005432783283	12194	56	12F
0005432783297	12194	57	13A
0005435242800	12194	58	13C
0005432783239	12194	59	13D
0005432783432	12194	60	13E
0005432783118	12194	61	13F
0005432783251	12194	62	14A
0005432783071	12194	63	14C
0005435242807	12194	64	14D
0005432783434	12194	65	14E
0005432783169	12194	66	14F
0005432783293	12194	67	15C
0005432783394	12194	68	15D
0005432783152	12194	69	15E
0005432783240	12194	70	15F
0005432783316	12194	71	16C
0005435242802	12194	72	16D
0005432783300	12194	73	16E
0005432783257	12194	74	16F
0005432783253	12194	75	17A
0005435242820	12194	76	17D
0005432783259	12194	77	17C
0005432783133	12194	78	17E
0005432783395	12194	79	17F
0005432783291	12194	80	18A
0005432783220	12194	81	18C
0005435242803	12194	82	18D
0005432783262	12194	83	18E
0005435242798	12194	84	18F
0005432783421	12194	85	19A
0005435242813	12194	86	19C
0005432783229	12194	87	19D
0005432783189	12194	88	19E
0005432783308	12194	89	19F
0005432783132	12194	90	20A
0005432783406	12194	91	20C
0005432783369	12194	92	20D
0005435242817	12194	93	20E
0005432783367	12194	94	20F
0005435242526	15420	1	1A
0005432783620	15420	2	1C
0005432783613	15420	3	1D
0005432783614	15420	4	2C
0005432783636	15420	5	2D
0005435242422	15420	6	3A
0005432783634	15420	7	3D
0005432783625	15420	8	4A
0005432783647	15420	9	4C
0005435242449	15420	10	4D
0005432783659	15420	11	4F
0005432783628	15420	12	5C
0005435242569	15420	13	5A
0005432783623	15420	14	5D
0005432783631	15420	15	5E
0005432783646	15420	16	5F
0005432783637	15420	17	6A
0005432783630	15420	18	6C
0005435242435	15420	19	6D
0005432783652	15420	20	6E
0005435242525	15420	21	6F
0005432783619	15420	22	7C
0005432783654	15420	23	7D
0005432783639	15420	24	7E
0005432783640	15420	25	7F
0005435242518	15420	26	8A
0005435242465	15420	27	8C
0005432783622	15420	28	8D
0005432783611	15420	29	8E
0005432783617	15420	30	8F
0005435242532	15420	31	9A
0005432783633	15420	32	9C
0005432783651	15420	33	9D
0005435242570	15420	34	9E
0005432783627	15420	35	9F
0005435242563	15420	36	10C
0005435242423	15420	37	10D
0005432783615	15420	38	10E
0005432783635	15420	39	10F
0005435242493	15420	40	11A
0005432783638	15420	41	11C
0005432783616	15420	42	11D
0005432783618	15420	43	12A
0005432783653	15420	44	12D
0005432783656	15420	45	12E
0005432783661	15420	46	12F
0005432783650	15420	47	13A
0005432783660	15420	48	13C
0005432783612	15420	49	13D
0005435242482	15420	50	13F
0005432783610	15420	51	14A
0005432783629	15420	52	14C
0005432783649	15420	53	14D
0005432783641	15420	54	14E
0005432783658	15420	55	15A
0005435242566	15420	56	15C
0005432783663	15420	57	15D
0005435242531	15420	58	15E
0005435242565	15420	59	15F
0005432783621	15420	60	16A
0005432783642	15420	61	16D
0005435242564	15420	62	16E
0005432783626	15420	63	16F
0005432783644	15420	64	17A
0005435242519	15420	65	17C
0005435242503	15420	66	17D
0005432783632	15420	67	17E
0005432783662	15420	68	17F
0005432783655	15420	69	18A
0005432783624	15420	70	18D
0005435242568	15420	71	18E
0005432783657	15420	72	18F
0005432783643	15420	73	19A
0005432783664	15420	74	19C
0005435242479	15420	75	19E
0005432783645	15420	76	19F
0005435242504	15420	77	20A
0005432783648	15420	78	20C
0005435242436	15420	79	20D
0005432783609	15420	80	20E
0005435242440	15420	81	20F
0005434876951	10117	1	1C
0005434877256	10117	2	1A
0005434876769	10117	3	1F
0005434877419	10117	4	2C
0005434876952	10117	5	2A
0005434877377	10117	6	2F
0005434876962	10117	7	2D
0005434877297	10117	8	3A
0005434877420	10117	9	3C
0005434877201	10117	10	4A
0005434876609	10117	11	3F
0005434877060	10117	12	3D
0005434877380	10117	13	4C
0005434877202	10117	14	4F
0005434876970	10117	15	4D
0005434877135	10117	16	5C
0005434877108	10117	17	5D
0005434876961	10117	18	6A
0005434876841	10117	19	6D
0005434877272	10117	20	6C
0005434877274	10117	21	6E
0005434877196	10117	22	7A
0005434877330	10117	23	6F
0005434877580	10117	24	7B
0005434876659	10117	25	7D
0005434877327	10117	26	8A
0005434877549	10117	27	7F
0005434877155	10117	28	8C
0005434876742	10117	29	8F
0005434877521	10117	30	8E
0005434877138	10117	31	9B
0005434877206	10117	32	9A
0005434877379	10117	33	9C
0005434877346	10117	34	9F
0005434877134	10117	35	9E
0005434877220	10117	36	9D
0005434877437	10117	37	10A
0005434876660	10117	38	10C
0005434876604	10117	39	10B
0005434876605	10117	40	10E
0005434877167	10117	41	10D
0005434877438	10117	42	11A
0005434876898	10117	43	10F
0005434876701	10117	44	11B
0005434877059	10117	45	11D
0005434877054	10117	46	11C
0005434877032	10117	47	11F
0005434877329	10117	48	11E
0005434877356	10117	49	12A
0005434758864	10117	50	12C
0005434877500	10117	51	12F
0005434877306	10117	52	12E
0005434877184	10117	53	12D
0005434877221	10117	54	13A
0005434876884	10117	55	13C
0005434877522	10117	56	13B
0005434877307	10117	57	13E
0005434877074	10117	58	13D
0005434876987	10117	59	14A
0005434877109	10117	60	13F
0005434877133	10117	61	14B
0005434877033	10117	62	14D
0005434877460	10117	63	14F
0005434877192	10117	64	14E
0005434876744	10117	65	15A
0005434877417	10117	66	15D
0005434876741	10117	67	15C
0005434876700	10117	68	15B
0005434877145	10117	69	16C
0005434877040	10117	70	16B
0005434876661	10117	71	16D
0005434758866	10117	72	16F
0005434758865	10117	73	16E
0005434910106	10117	74	17B
0005434876963	10117	75	17A
0005434877614	10117	76	17D
0005434877811	10117	77	17C
0005434910105	10117	78	17F
0005434877328	10117	79	17E
0005434877154	10117	80	18B
0005434877262	10117	81	18A
0005434876743	10117	82	18C
0005434877188	10117	83	18D
0005434877156	10117	84	19A
0005434877117	10117	85	18F
0005434876662	10117	86	19B
0005434877061	10117	87	19D
0005434877273	10117	88	20A
0005434877113	10117	89	19F
0005434876883	10117	90	19E
0005434876986	10117	91	20B
0005434877254	10117	92	20D
0005434877440	10117	93	20C
0005434877491	10117	94	20E
0005434877340	10117	95	21A
0005434877550	10117	96	21C
0005434877378	10117	97	21B
0005434877207	10117	98	21E
0005434876899	10117	99	21D
0005434877305	10117	100	21F
0005434878091	14618	1	1C
0005434878010	14618	2	1A
0005434878028	14618	3	1F
0005434878097	14618	4	1D
0005434758889	14618	5	2A
0005434878022	14618	6	2D
0005434878048	14618	7	2C
0005434878027	14618	8	3A
0005434878053	14618	9	2F
0005434878012	14618	10	3D
0005434878100	14618	11	3C
0005434878071	14618	12	4A
0005434878073	14618	13	3F
0005434878037	14618	14	4C
0005434878081	14618	15	4F
0005434878093	14618	16	4D
0005434878095	14618	17	5C
0005434878045	14618	18	5A
0005434878102	14618	19	5F
0005434878090	14618	20	5D
0005434878087	14618	21	6B
0005434878098	14618	22	6A
0005434878105	14618	23	6D
0005434878059	14618	24	6F
0005434878078	14618	25	7A
0005434878084	14618	26	7C
0005434878009	14618	27	7B
0005434910075	14618	28	7D
0005434878029	14618	29	8A
0005434878031	14618	30	7F
0005434878086	14618	31	8B
0005434878047	14618	32	8C
0005434878065	14618	33	8F
0005434878076	14618	34	8E
0005434878026	14618	35	9A
0005434878046	14618	36	9D
0005434878079	14618	37	9C
0005434878040	14618	38	9F
0005434878013	14618	39	9E
0005434758890	14618	40	10A
0005434878089	14618	41	10C
0005434878099	14618	42	10B
0005434878017	14618	43	10E
0005434878060	14618	44	10D
0005434878069	14618	45	11A
0005434878085	14618	46	10F
0005434878075	14618	47	11C
0005434878044	14618	48	11B
0005434878082	14618	49	11D
0005434878072	14618	50	11F
0005434878080	14618	51	11E
0005434878043	14618	52	12A
0005434878023	14618	53	12C
0005434878092	14618	54	12F
0005434878042	14618	55	12E
0005434878014	14618	56	12D
0005434878077	14618	57	13A
0005434878057	14618	58	13C
0005434910083	14618	59	13B
0005434878025	14618	60	13E
0005434878030	14618	61	13D
0005434878019	14618	62	13F
0005434878096	14618	63	14C
0005434878070	14618	64	14B
0005434878101	14618	65	14A
0005434878021	14618	66	14D
0005434878041	14618	67	14F
0005434878062	14618	68	14E
0005434878066	14618	69	15B
0005434878033	14618	70	15A
0005434878055	14618	71	15D
0005434878052	14618	72	15C
0005434910082	14618	73	15E
0005434878103	14618	74	16B
0005434878074	14618	75	16A
0005434878067	14618	76	16E
0005434878061	14618	77	16D
0005434878063	14618	78	16C
0005434878008	14618	79	17A
0005434878054	14618	80	16F
0005434878051	14618	81	17B
0005434878049	14618	82	17D
0005434758888	14618	83	17C
0005434878094	14618	84	17F
0005434878032	14618	85	18B
0005434878035	14618	86	18A
0005434878039	14618	87	18C
0005434878068	14618	88	18E
0005434878018	14618	89	18D
0005434878016	14618	90	19A
0005434878064	14618	91	19B
0005434878058	14618	92	19E
0005434878036	14618	93	19D
0005434878038	14618	94	19F
0005434878015	14618	95	20B
0005434878104	14618	96	20D
0005434878083	14618	97	20C
0005434878050	14618	98	20F
0005434878011	14618	99	20E
0005434878024	14618	100	21B
0005434878020	14618	101	21A
0005434878034	14618	102	21C
0005434878056	14618	103	21F
0005434878088	14618	104	21E
0005434758891	14618	105	21D
0005435660114	9258	1	1B
0005434251835	9258	2	1C
0005434251852	9258	3	2D
0005434251890	9258	4	3A
0005434251886	9258	5	3D
0005435660112	9258	6	4B
0005435660116	9258	7	5A
0005434251889	9258	8	6B
0005435660113	9258	9	6D
0005435660119	9258	10	7D
0005435660120	9258	11	19A
0005434251891	9258	12	19B
0005435660117	9258	13	20A
0005435660115	9258	14	20B
0005435660111	9258	15	21B
0005435660118	9258	16	23B
0005435660045	24655	1	1A
0005434251949	24655	2	1C
0005435660044	24655	3	2B
0005435660010	24655	4	2C
0005434251943	24655	5	2D
0005434251950	24655	6	3B
0005435660070	24655	7	3D
0005434251946	24655	8	4B
0005435660069	24655	9	5A
0005435660011	24655	10	5D
0005435660066	24655	11	6A
0005435660023	24655	12	6C
0005435660022	24655	13	6D
0005435659977	24655	14	18A
0005434251947	24655	15	18B
0005435660067	24655	16	19A
0005434251945	24655	17	19B
0005435659993	24655	18	19D
0005435660024	24655	19	20C
0005434251948	24655	20	21A
0005434251951	24655	21	21C
0005434251944	24655	22	22A
0005434251942	24655	23	23A
0005433680469	2770	1	1C
0005433680474	2770	2	1D
0005433680470	2770	3	1F
0005432966637	2770	4	2A
0005433680466	2770	5	2C
0005433680447	2770	6	2F
0005433680452	2770	7	3A
0005432222772	2770	8	3C
0005433680483	2770	9	3D
0005433680468	2770	10	3F
0005433680485	2770	11	4A
0005432966732	2770	12	4C
0005433680476	2770	13	4D
0005433680463	2770	14	4E
0005433680480	2770	15	4F
0005432966687	2770	16	5A
0005433680456	2770	17	5C
0005432966683	2770	18	5D
0005433680446	2770	19	5E
0005433680454	2770	20	5F
0005432966698	2770	21	6A
0005433684415	2770	22	6C
0005433680465	2770	23	6D
0005433680461	2770	24	6E
0005433680453	2770	25	6F
0005432966577	2770	26	7A
0005432966606	2770	27	7C
0005432222774	2770	28	7D
0005433680487	2770	29	7E
0005432966773	2770	30	7F
0005432966631	2770	31	8A
0005432966699	2770	32	8C
0005432966625	2770	33	8D
0005433680486	2770	34	8E
0005432966636	2770	35	8F
0005433680475	2770	36	9A
0005433680491	2770	37	9C
0005433680449	2770	38	9E
0005432966639	2770	39	9F
0005433680471	2770	40	10C
0005432966672	2770	41	10E
0005433680472	2770	42	10F
0005433680477	2770	43	11A
0005433680478	2770	44	11C
0005433680467	2770	45	11D
0005433684414	2770	46	11E
0005433680460	2770	47	12A
0005432966632	2770	48	12C
0005432966812	2770	49	12D
0005432222773	2770	50	13A
0005432966578	2770	51	13C
0005433680490	2770	52	13D
0005433680458	2770	53	13E
0005433680451	2770	54	13F
0005433680459	2770	55	14A
0005433680455	2770	56	14D
0005433680444	2770	57	14E
0005432222770	2770	58	14F
0005433680481	2770	59	15A
0005432966684	2770	60	15C
0005432966741	2770	61	15D
0005433680482	2770	62	15E
0005433680462	2770	63	15F
0005433680464	2770	64	16A
0005433680457	2770	65	16C
0005432966633	2770	66	16D
0005432222771	2770	67	16E
0005433680443	2770	68	16F
0005432966692	2770	69	17A
0005432966623	2770	70	17C
0005433680473	2770	71	17D
0005433680450	2770	72	17E
0005433680488	2770	73	18A
0005433680489	2770	74	18C
0005432966622	2770	75	18D
0005433680479	2770	76	18F
0005433680445	2770	77	19A
0005432966624	2770	78	19C
0005432966744	2770	79	20A
0005432966608	2770	80	19F
0005433680442	2770	81	20C
0005433680448	2770	82	20D
0005433680484	2770	83	20E
0005433680169	29160	1	1A
0005433679935	29160	2	1C
0005433680165	29160	3	1D
0005432966871	29160	4	1F
0005433680082	29160	5	2A
0005432966894	29160	6	2D
0005433680041	29160	7	2F
0005433680164	29160	8	3A
0005433680153	29160	9	3C
0005433680132	29160	10	3D
0005432966872	29160	11	3F
0005433680286	29160	12	4D
0005433680040	29160	13	4E
0005433680163	29160	14	5A
0005433680083	29160	15	5D
0005433680383	29160	16	5E
0005433680143	29160	17	5F
0005432966884	29160	18	6A
0005433680220	29160	19	6C
0005432966886	29160	20	6D
0005433679827	29160	21	6E
0005433680162	29160	22	7A
0005432966882	29160	23	7C
0005432966888	29160	24	7E
0005432966873	29160	25	7F
0005433680025	29160	26	8A
0005433680068	29160	27	8C
0005433680211	29160	28	8D
0005432966889	29160	29	8E
0005432966890	29160	30	8F
0005433680098	29160	31	9A
0005432966875	29160	32	9C
0005433680166	29160	33	9D
0005433680038	29160	34	9E
0005433679967	29160	35	9F
0005433679946	29160	36	10A
0005433680219	29160	37	10C
0005433680039	29160	38	10D
0005432966893	29160	39	10E
0005432966895	29160	40	10F
0005433680210	29160	41	11A
0005433680099	29160	42	11C
0005432005207	29160	43	11D
0005433680084	29160	44	11E
0005432966883	29160	45	11F
0005432966892	29160	46	12A
0005433680196	29160	47	12C
0005433680272	29160	48	12D
0005433679934	29160	49	12E
0005433680240	29160	50	12F
0005432966896	29160	51	13A
0005433680271	29160	52	13C
0005433680241	29160	53	13D
0005432966879	29160	54	13E
0005432966881	29160	55	13F
0005433680287	29160	56	14A
0005432966885	29160	57	14C
0005433680242	29160	58	14D
0005433680195	29160	59	14E
0005433680037	29160	60	14F
0005432005208	29160	61	15C
0005432966876	29160	62	15D
0005432966874	29160	63	15E
0005433680170	29160	64	15F
0005432966878	29160	65	16A
0005432966877	29160	66	16C
0005433680095	29160	67	16D
0005433680106	29160	68	16E
0005433680091	29160	69	16F
0005433680032	29160	70	17A
0005433680070	29160	71	17C
0005433680107	29160	72	17D
0005433679815	29160	73	17E
0005433680198	29160	74	17F
0005433680015	29160	75	18D
0005433680094	29160	76	18E
0005433680274	29160	77	18F
0005433680071	29160	78	19C
0005432966891	29160	79	19A
0005433680275	29160	80	19D
0005433679892	29160	81	19E
0005432966880	29160	82	19F
0005432966887	29160	83	20C
0005433680069	29160	84	20D
0005433690908	29160	85	20E
0005433680226	29160	86	20F
0005433633714	9310	1	1A
0005433577783	9310	2	1C
0005433614436	9310	3	1F
0005433633716	9310	4	1D
0005433614449	9310	5	2A
0005433614473	9310	6	2C
0005433614481	9310	7	2D
0005434153522	9310	8	3A
0005433577774	9310	9	3C
0005433614468	9310	10	3F
0005433614434	9310	11	3D
0005433633711	9310	12	4A
0005433614508	9310	13	4D
0005433614462	9310	14	4C
0005432755066	9310	15	4F
0005434152768	9310	16	5A
0005433614452	9310	17	5C
0005433614451	9310	18	5F
0005433614447	9310	19	5D
0005433633709	9310	20	6A
0005433614480	9310	21	6D
0005433614437	9310	22	6C
0005433633722	9310	23	6F
0005434269075	9310	24	7A
0005434269076	9310	25	7C
0005433614438	9310	26	7F
0005433614485	9310	27	7D
0005433614448	9310	28	8A
0005433633704	9310	29	8C
0005433614498	9310	30	8E
0005433614492	9310	31	8D
0005433633720	9310	32	8F
0005433633707	9310	33	9A
0005433614478	9310	34	9C
0005433614460	9310	35	9B
0005434152760	9310	36	9D
0005433614483	9310	37	9E
0005433633727	9310	38	10A
0005433614455	9310	39	10B
0005433614472	9310	40	10D
0005433633731	9310	41	10C
0005432145104	9310	42	10F
0005433614463	9310	43	10E
0005433614442	9310	44	11B
0005432755069	9310	45	11A
0005433633719	9310	46	11D
0005433614504	9310	47	11F
0005433577773	9310	48	11E
0005433633702	9310	49	12A
0005433633712	9310	50	12C
0005433577780	9310	51	12B
0005433633726	9310	52	12D
0005433577771	9310	53	12E
0005434163544	9310	54	12F
0005433633708	9310	55	13B
0005434153518	9310	56	13A
0005433614464	9310	57	13C
0005433614489	9310	58	13D
0005433633732	9310	59	14A
0005433633734	9310	60	13F
0005433614502	9310	61	14C
0005433614476	9310	62	14B
0005433577779	9310	63	14D
0005433614441	9310	64	14E
0005433633729	9310	65	15A
0005433614475	9310	66	14F
0005433614497	9310	67	15C
0005433614450	9310	68	15B
0005432756840	9310	69	15E
0005433614507	9310	70	15F
0005432145105	9310	71	16C
0005434152769	9310	72	16B
0005433614453	9310	73	16D
0005433577778	9310	74	16E
0005433614474	9310	75	16F
0005433614496	9310	76	17B
0005433633735	9310	77	17A
0005433614500	9310	78	17C
0005433577772	9310	79	17D
0005433614506	9310	80	18A
0005433577777	9310	81	17F
0005433633725	9310	82	18B
0005433614467	9310	83	18D
0005433614484	9310	84	18C
0005433614494	9310	85	18F
0005433633710	9310	86	19B
0005433614505	9310	87	19D
0005433614479	9310	88	19C
0005433614486	9310	89	19E
0005433614439	9310	90	20B
0005433614444	9310	91	20A
0005433614501	9310	92	20C
0005434163530	9310	93	20D
0005434152770	9310	94	20F
0005433614461	9310	95	20E
0005433633713	9310	96	21B
0005434153521	9310	97	21D
0005434163529	9310	98	21C
0005433633721	9310	99	21E
0005433614446	9310	100	21F
0005433614491	9310	101	22A
0005433614454	9310	102	22D
0005433614456	9310	103	22F
0005433614469	9310	104	22E
0005432145106	9310	105	23B
0005433633728	9310	106	23A
0005433614440	9310	107	23C
0005433614435	9310	108	23E
0005433633718	9310	109	24A
0005434163514	9310	110	23F
0005433633703	9310	111	24B
0005433614495	9310	112	24C
0005434153520	9310	113	24D
0005433633733	9310	114	24F
0005433614443	9310	115	25C
0005432755070	9310	116	25B
0005433614499	9310	117	25E
0005434269074	9310	118	25F
0005433614470	9310	119	26B
0005432755067	9310	120	26A
0005433614488	9310	121	26C
0005433614482	9310	122	26E
0005433614459	9310	123	26D
0005433614471	9310	124	26F
0005433577782	9310	125	27A
0005433633730	9310	126	27D
0005433614457	9310	127	27C
0005433614466	9310	128	27E
0005433614445	9310	129	28A
0005433577769	9310	130	27F
0005433614493	9310	131	28B
0005433577770	9310	132	28D
0005433633705	9310	133	28C
0005432755068	9310	134	28E
0005433633736	9310	135	28F
0005434163528	9310	136	29A
0005433614465	9310	137	29C
0005433577781	9310	138	29B
0005432756841	9310	139	29D
0005433633715	9310	140	29E
0005433577776	9310	141	30B
0005433614490	9310	142	30C
0005433633724	9310	143	30E
0005433633717	9310	144	30D
0005433614477	9310	145	31A
0005433577775	9310	146	30F
0005433614503	9310	147	31C
0005433633706	9310	148	31B
0005433614458	9310	149	31D
0005433614487	9310	150	31F
0005433633723	9310	151	31E
0005433613609	25212	1	1C
0005434163593	25212	2	1F
0005433577655	25212	3	1D
0005433613693	25212	4	2D
0005433633381	25212	5	2F
0005433613908	25212	6	3A
0005433633509	25212	7	3D
0005433614057	25212	8	3C
0005433633358	25212	9	3F
0005433614035	25212	10	4A
0005433633369	25212	11	4C
0005433613730	25212	12	4D
0005433613975	25212	13	5A
0005433613973	25212	14	4F
0005433614270	25212	15	5D
0005433577660	25212	16	5C
0005433613919	25212	17	5F
0005433613763	25212	18	6A
0005433577659	25212	19	6C
0005433633380	25212	20	7A
0005433577677	25212	21	6F
0005433613787	25212	22	7D
0005433613954	25212	23	7C
0005433577681	25212	24	7F
0005434163604	25212	25	8A
0005433577736	25212	26	8B
0005433613997	25212	27	8D
0005433633395	25212	28	8C
0005433613953	25212	29	8E
0005433613780	25212	30	8F
0005433613807	25212	31	9A
0005433613829	25212	32	9C
0005433613651	25212	33	9B
0005433613582	25212	34	9D
0005434163597	25212	35	9E
0005433613551	25212	36	10A
0005434273073	25212	37	9F
0005433613716	25212	38	10B
0005433577651	25212	39	10C
0005433613665	25212	40	10E
0005433613808	25212	41	10D
0005433613881	25212	42	10F
0005433577650	25212	43	11B
0005433613998	25212	44	11C
0005433633483	25212	45	11D
0005433613856	25212	46	11F
0005433577615	25212	47	11E
0005433633390	25212	48	12A
0005433633629	25212	49	12B
0005433614036	25212	50	12C
0005433613645	25212	51	12E
0005433633405	25212	52	12F
0005433633518	25212	53	13B
0005433613666	25212	54	13A
0005433613741	25212	55	13C
0005433613980	25212	56	13D
0005433613891	25212	57	13E
0005433633408	25212	58	14A
0005433613719	25212	59	13F
0005433613817	25212	60	14B
0005433633476	25212	61	14C
0005433614123	25212	62	14E
0005433614021	25212	63	15A
0005433613782	25212	64	14F
0005434163599	25212	65	15B
0005434163595	25212	66	15C
0005433613789	25212	67	15E
0005433613852	25212	68	15D
0005433613486	25212	69	15F
0005433577663	25212	70	16A
0005433633393	25212	71	16C
0005433633404	25212	72	16B
0005434163594	25212	73	16D
0005433614068	25212	74	17A
0005433613846	25212	75	16F
0005434163601	25212	76	17C
0005433613909	25212	77	17D
0005433613809	25212	78	17F
0005433613917	25212	79	17E
0005433614242	25212	80	18A
0005433614037	25212	81	18B
0005433613830	25212	82	18D
0005433613981	25212	83	18C
0005433613945	25212	84	18E
0005433613853	25212	85	18F
0005434163602	25212	86	19C
0005433633529	25212	87	19B
0005433613731	25212	88	19D
0005433613646	25212	89	20A
0005433633392	25212	90	19E
0005433613573	25212	91	20B
0005433633528	25212	92	20E
0005433613796	25212	93	20F
0005433613888	25212	94	21A
0005433613700	25212	95	21C
0005433577690	25212	96	21B
0005433613920	25212	97	21E
0005433613762	25212	98	21D
0005433613900	25212	99	21F
0005434272187	25212	100	22B
0005433614072	25212	101	22A
0005433613432	25212	102	22C
0005433613910	25212	103	22E
0005433613890	25212	104	22D
0005433613781	25212	105	23B
0005433633341	25212	106	23A
0005433614073	25212	107	22F
0005434273071	25212	108	23C
0005433613855	25212	109	23D
0005433633302	25212	110	23E
0005433613950	25212	111	24A
0005433577688	25212	112	24B
0005433613742	25212	113	24C
0005433633391	25212	114	24E
0005433633355	25212	115	24D
0005433577667	25212	116	24F
0005433577680	25212	117	25B
0005433613880	25212	118	25A
0005433577683	25212	119	25D
0005433633420	25212	120	25C
0005433633628	25212	121	25E
0005433613676	25212	122	26A
0005434273072	25212	123	25F
0005433613734	25212	124	26B
0005433613779	25212	125	26D
0005433613797	25212	126	26C
0005433613833	25212	127	26F
0005433633368	25212	128	26E
0005434163600	25212	129	27A
0005433614271	25212	130	27C
0005433633535	25212	131	27B
0005433613608	25212	132	27D
0005433613786	25212	133	27F
0005433613692	25212	134	27E
0005433613834	25212	135	28A
0005433613770	25212	136	28B
0005433614124	25212	137	28D
0005433633403	25212	138	28C
0005433633519	25212	139	28E
0005433633409	25212	140	29A
0005433613918	25212	141	28F
0005433613790	25212	142	29B
0005433633544	25212	143	29D
0005434272188	25212	144	29F
0005433613696	25212	145	29E
0005433633536	25212	146	30A
0005434163603	25212	147	30C
0005433614058	25212	148	30B
0005433613647	25212	149	30E
0005434163598	25212	150	30D
0005433613736	25212	151	30F
0005433613876	25212	152	31A
0005433613720	25212	153	31C
0005434163596	25212	154	31B
0005434163605	25212	155	31D
0005433577664	25212	156	31F
0005433633410	25212	157	31E
0005435947085	4213	1	1B
0005435947057	4213	2	2C
0005435986742	4213	3	3H
0005432571286	4213	4	4A
0005435947065	4213	5	9A
0005435947084	4213	6	11H
0005435947058	4213	7	14A
0005435986739	4213	8	14B
0005435986740	4213	9	14D
0005432184945	4213	10	14F
0005435947155	4213	11	14H
0005434271290	4213	12	16H
0005435947072	4213	13	18F
0005435947154	4213	14	18H
0005432184944	4213	15	19D
0005432571279	4213	16	19F
0005435986733	4213	17	20B
0005435947045	4213	18	20E
0005432571281	4213	19	22A
0005432184946	4213	20	24A
0005435986734	4213	21	25D
0005435947089	4213	22	27B
0005435986738	4213	23	28F
0005432571267	4213	24	29H
0005432571282	4213	25	31A
0005435947101	4213	26	33E
0005434271286	4213	27	34H
0005435947100	4213	28	35A
0005435986735	4213	29	35E
0005435947071	4213	30	35F
0005432571285	4213	31	35G
0005432184947	4213	32	36B
0005435947046	4213	33	36D
0005435986737	4213	34	37A
0005435986736	4213	35	38B
0005435947059	4213	36	38A
0005432184943	4213	37	38G
0005435986741	4213	38	39F
0005435947230	26605	1	2A
0005435947226	26605	2	2B
0005435986687	26605	3	3B
0005435986679	26605	4	3C
0005432571316	26605	5	3F
0005435947225	26605	6	3H
0005435986676	26605	7	5F
0005435787353	26605	8	9B
0005435947227	26605	9	12A
0005435986690	26605	10	12B
0005435856195	26605	11	12G
0005435986675	26605	12	13G
0005435947233	26605	13	14B
0005435947220	26605	14	17F
0005432571318	26605	15	17H
0005435947221	26605	16	18G
0005435856194	26605	17	19D
0005435986686	26605	18	20F
0005435947234	26605	19	21G
0005435947229	26605	20	21H
0005435947228	26605	21	22D
0005435947224	26605	22	22H
0005435986674	26605	23	23E
0005435856197	26605	24	24A
0005435986666	26605	25	24F
0005435947231	26605	26	24E
0005435947232	26605	27	27F
0005435986655	26605	28	28D
0005435856196	26605	29	28F
0005432571317	26605	30	28G
0005432571319	26605	31	30H
0005435947223	26605	32	33B
0005435986672	26605	33	35A
0005435787351	26605	34	35F
0005435787350	26605	35	36D
0005435787352	26605	36	36F
0005435947222	26605	37	38B
0005435986678	26605	38	39D
0005433568949	324	1	1A
0005433074428	324	2	1D
0005433074360	324	3	1C
0005433568987	324	4	1F
0005432948120	324	5	2A
0005432238926	324	6	2C
0005432947963	324	7	2F
0005433568971	324	8	2D
0005432238925	324	9	3A
0005432947888	324	10	3C
0005432238924	324	11	3F
0005432948016	324	12	4A
0005433568981	324	13	4C
0005432948100	324	14	5A
0005433568988	324	15	4F
0005433568974	324	16	5D
0005433129220	324	17	5C
0005433568991	324	18	5F
0005433568980	324	19	6D
0005433568951	324	20	6C
0005433568966	324	21	7A
0005433074362	324	22	6F
0005433074261	324	23	7D
0005432948033	324	24	7C
0005432947940	324	25	8A
0005433568967	324	26	7F
0005433074386	324	27	8C
0005432948054	324	28	8E
0005433568955	324	29	8D
0005432948000	324	30	9A
0005433568972	324	31	9C
0005432948061	324	32	9D
0005432947942	324	33	9E
0005432947770	324	34	10A
0005433568961	324	35	10B
0005432948072	324	36	10C
0005432948015	324	37	10E
0005433568986	324	38	10D
0005432947800	324	39	10F
0005433568975	324	40	11A
0005433568989	324	41	11C
0005432948020	324	42	11B
0005433129208	324	43	11D
0005433568957	324	44	12B
0005432947998	324	45	12C
0005432947829	324	46	12E
0005433568977	324	47	12D
0005433568978	324	48	13A
0005433074484	324	49	12F
0005433074387	324	50	13D
0005432947799	324	51	13E
0005433568968	324	52	14A
0005433568950	324	53	13F
0005433074492	324	54	14B
0005433568983	324	55	14D
0005432947903	324	56	14E
0005433074396	324	57	15B
0005432947935	324	58	15A
0005432948021	324	59	15C
0005433074361	324	60	15E
0005432947859	324	61	15F
0005433568992	324	62	16C
0005433134091	324	63	16F
0005433568952	324	64	17A
0005433568984	324	65	17C
0005432948022	324	66	17D
0005433568958	324	67	17E
0005433568947	324	68	18A
0005433568970	324	69	18C
0005433568965	324	70	18E
0005432948056	324	71	18D
0005433568954	324	72	18F
0005432947947	324	73	19C
0005433074341	324	74	19B
0005433074476	324	75	19D
0005432947968	324	76	20A
0005432948062	324	77	19E
0005433074421	324	78	20B
0005433074315	324	79	20E
0005433074379	324	80	20F
0005433074391	324	81	21A
0005433568946	324	82	21B
0005432947941	324	83	21D
0005432948086	324	84	21C
0005432947999	324	85	21E
0005433568993	324	86	21F
0005433074353	324	87	22B
0005433568960	324	88	22D
0005432238927	324	89	22C
0005433568979	324	90	22F
0005432947858	324	91	22E
0005433568985	324	92	23D
0005433568959	324	93	23E
0005433568964	324	94	24A
0005433129207	324	95	24B
0005432948018	324	96	24C
0005433074493	324	97	24E
0005432947939	324	98	25B
0005433074279	324	99	25A
0005432948070	324	100	25C
0005432947934	324	101	25D
0005433568990	324	102	25E
0005433074336	324	103	26A
0005433568982	324	104	25F
0005433074497	324	105	26B
0005432947997	324	106	26D
0005432238923	324	107	26E
0005432948035	324	108	26F
0005433568962	324	109	27A
0005432947896	324	110	27C
0005433074376	324	111	27E
0005432947962	324	112	27D
0005433074483	324	113	27F
0005433568953	324	114	28A
0005432947771	324	115	28B
0005432948108	324	116	29A
0005433568963	324	117	28F
0005432948030	324	118	29B
0005432948003	324	119	29C
0005432947804	324	120	29D
0005432947919	324	121	29F
0005432948109	324	122	29E
0005433568969	324	123	30A
0005433074477	324	124	30D
0005432948017	324	125	30C
0005433568956	324	126	30F
0005432948044	324	127	31A
0005433568948	324	128	31C
0005432947887	324	129	31B
0005433568973	324	130	31D
0005433074319	324	131	31E
0005433568976	324	132	31F
0005433568350	11616	1	1A
0005433568243	11616	2	1C
0005433074663	11616	3	1F
0005432948383	11616	4	1D
0005433568420	11616	5	2D
0005433074650	11616	6	2C
0005432192314	11616	7	2F
0005433568234	11616	8	3A
0005433568429	11616	9	3C
0005433568167	11616	10	3D
0005433074641	11616	11	4A
0005432948378	11616	12	3F
0005432948375	11616	13	4C
0005433074647	11616	14	4F
0005433074660	11616	15	4D
0005432948351	11616	16	5A
0005433074638	11616	17	5C
0005433131699	11616	18	5D
0005433568364	11616	19	6A
0005433074657	11616	20	5F
0005432948377	11616	21	6C
0005432948360	11616	22	6D
0005432948353	11616	23	7A
0005433568461	11616	24	7C
0005433074635	11616	25	7D
0005432948380	11616	26	8A
0005433568378	11616	27	8B
0005432948364	11616	28	8C
0005433568335	11616	29	8E
0005433074648	11616	30	8D
0005432948371	11616	31	8F
0005433568345	11616	32	9B
0005432948361	11616	33	9C
0005433134126	11616	34	9E
0005432948357	11616	35	9D
0005433134127	11616	36	10A
0005432948368	11616	37	9F
0005433568464	11616	38	10B
0005433074662	11616	39	10E
0005432948352	11616	40	10D
0005433568253	11616	41	10F
0005432948348	11616	42	11A
0005432948379	11616	43	11C
0005433568367	11616	44	11B
0005433074658	11616	45	11D
0005433568430	11616	46	11F
0005433074639	11616	47	11E
0005433131698	11616	48	12A
0005433134128	11616	49	12B
0005432948376	11616	50	12D
0005433568418	11616	51	12C
0005433131697	11616	52	12E
0005433568135	11616	53	12F
0005433568150	11616	54	13A
0005433568377	11616	55	13C
0005433929857	11616	56	13B
0005433568365	11616	57	13D
0005432948387	11616	58	13F
0005433074661	11616	59	14A
0005433074654	11616	60	14C
0005433568085	11616	61	14E
0005432948381	11616	62	14D
0005433568521	11616	63	14F
0005432948367	11616	64	15C
0005432948374	11616	65	15D
0005433568187	11616	66	15F
0005433568133	11616	67	16A
0005433568262	11616	68	16C
0005433134130	11616	69	16B
0005433568044	11616	70	16D
0005433074646	11616	71	16E
0005432948355	11616	72	17A
0005433568421	11616	73	16F
0005433568043	11616	74	17E
0005433568338	11616	75	17D
0005433568446	11616	76	18A
0005433568298	11616	77	17F
0005433568370	11616	78	18C
0005433568447	11616	79	18D
0005433074640	11616	80	19B
0005433568533	11616	81	18F
0005433074642	11616	82	18E
0005432192315	11616	83	19C
0005432948362	11616	84	19D
0005433131700	11616	85	19E
0005433568448	11616	86	20A
0005433568402	11616	87	20C
0005432948386	11616	88	20B
0005433568235	11616	89	20F
0005432948384	11616	90	20E
0005432948382	11616	91	21B
0005433568316	11616	92	21C
0005433074636	11616	93	21E
0005433074659	11616	94	21D
0005432948373	11616	95	22A
0005433568181	11616	96	21F
0005433568405	11616	97	22B
0005432948354	11616	98	22C
0005433568371	11616	99	22D
0005433568292	11616	100	22F
0005433074643	11616	101	23A
0005433131696	11616	102	23C
0005433074637	11616	103	23B
0005433568353	11616	104	23D
0005432948370	11616	105	23E
0005433568297	11616	106	24A
0005432948347	11616	107	23F
0005433074644	11616	108	24B
0005433134129	11616	109	24C
0005433074652	11616	110	24E
0005433568060	11616	111	24F
0005432948363	11616	112	25A
0005432948372	11616	113	25C
0005432948366	11616	114	25D
0005433568366	11616	115	25E
0005433568374	11616	116	25F
0005433568401	11616	117	26D
0005433074651	11616	118	26C
0005433568476	11616	119	26E
0005432192313	11616	120	26F
0005432948359	11616	121	27B
0005433074634	11616	122	27A
0005433568336	11616	123	27D
0005433074653	11616	124	27C
0005433074656	11616	125	27F
0005433568478	11616	126	27E
0005432948358	11616	127	28A
0005432948350	11616	128	28B
0005433568163	11616	129	28D
0005432948356	11616	130	28E
0005433568040	11616	131	28F
0005432948365	11616	132	29B
0005433568233	11616	133	29D
0005432948388	11616	134	29F
0005433074655	11616	135	30B
0005433568483	11616	136	30D
0005432948385	11616	137	30C
0005432948369	11616	138	30F
0005432948349	11616	139	30E
0005433074649	11616	140	31B
0005433074645	11616	141	31E
0005432192312	11616	142	31D
0005433568337	11616	143	31F
0005434732967	10043	1	1B
0005433817464	10043	2	2A
0005433817463	10043	3	3A
0005433817461	10043	4	2B
0005433817462	10043	5	3B
0005434732959	10043	6	5B
0005434732960	10043	7	6A
0005434732974	13951	1	2B
0005434732975	13951	2	4A
0005434732976	13951	3	6A
0005434732973	13951	4	6B
0005435982209	2355	1	1A
0005435982226	2355	2	1C
0005433754115	2355	3	1B
0005435982208	2355	4	1F
0005433754134	2355	5	1H
0005433754122	2355	6	1G
0005432300250	2355	7	2A
0005433754095	2355	8	2B
0005434731120	2355	9	2F
0005432226046	2355	10	2C
0005432984924	2355	11	3A
0005433754100	2355	12	3B
0005435982230	2355	13	3F
0005432984758	2355	14	3C
0005433754128	2355	15	3G
0005432984704	2355	16	4A
0005432984720	2355	17	3H
0005433434374	2355	18	4B
0005432300251	2355	19	4F
0005432984809	2355	20	4C
0005435982228	2355	21	4G
0005433754097	2355	22	4H
0005435982237	2355	23	5B
0005433434351	2355	24	5C
0005433754110	2355	25	5G
0005433434384	2355	26	5F
0005433434359	2355	27	9B
0005432984739	2355	28	9A
0005433434390	2355	29	9G
0005433764675	2355	30	11A
0005432655519	2355	31	9H
0005433754125	2355	32	11B
0005433754120	2355	33	11E
0005435982227	2355	34	11D
0005432655516	2355	35	11F
0005432655514	2355	36	11G
0005432869418	2355	37	12A
0005432984674	2355	38	11H
0005433754111	2355	39	12D
0005435982229	2355	40	12B
0005433754109	2355	41	12E
0005433434415	2355	42	12F
0005433754133	2355	43	12H
0005432226043	2355	44	12G
0005433434306	2355	45	13A
0005433754087	2355	46	13D
0005432984705	2355	47	13B
0005433434469	2355	48	13E
0005432984703	2355	49	13G
0005435982217	2355	50	13F
0005432984781	2355	51	13H
0005432984681	2355	52	14A
0005433754141	2355	53	14E
0005433434305	2355	54	14B
0005433434385	2355	55	14F
0005433754104	2355	56	14H
0005435982211	2355	57	14G
0005432984792	2355	58	15A
0005432984777	2355	59	15B
0005432984760	2355	60	15E
0005433766634	2355	61	15D
0005433754106	2355	62	15F
0005435982234	2355	63	15G
0005432984816	2355	64	16A
0005433434438	2355	65	15H
0005435982210	2355	66	16D
0005433434484	2355	67	16B
0005432984783	2355	68	16F
0005432226045	2355	69	16E
0005433754138	2355	70	16G
0005432984610	2355	71	16H
0005435982214	2355	72	17A
0005432984746	2355	73	17D
0005435982196	2355	74	17B
0005433754140	2355	75	17F
0005435982201	2355	76	17E
0005433766631	2355	77	17H
0005432984676	2355	78	17G
0005433754118	2355	79	18B
0005433754139	2355	80	18A
0005433434489	2355	81	18D
0005432655517	2355	82	18E
0005433754085	2355	83	18H
0005435982238	2355	84	19B
0005435982213	2355	85	19A
0005433754113	2355	86	19E
0005433754116	2355	87	19D
0005432984793	2355	88	19H
0005433764676	2355	89	19G
0005433754089	2355	90	20A
0005433754103	2355	91	20B
0005433434271	2355	92	20D
0005432984823	2355	93	20F
0005435982207	2355	94	20E
0005433434398	2355	95	20G
0005433754132	2355	96	21A
0005432869449	2355	97	20H
0005433434437	2355	98	21D
0005435982216	2355	99	21B
0005435982240	2355	100	21E
0005435982198	2355	101	21G
0005433754129	2355	102	21F
0005435982220	2355	103	21H
0005432984921	2355	104	22B
0005433754137	2355	105	22A
0005433754127	2355	106	22D
0005433754086	2355	107	22F
0005432984815	2355	108	22E
0005435982239	2355	109	22G
0005432984765	2355	110	23A
0005435982199	2355	111	22H
0005432984802	2355	112	23B
0005435982212	2355	113	23E
0005434731121	2355	114	23D
0005432984808	2355	115	23F
0005433754130	2355	116	23G
0005433434393	2355	117	23H
0005433754117	2355	118	24A
0005435982200	2355	119	24E
0005433754084	2355	120	24D
0005432984804	2355	121	24F
0005433754123	2355	122	24G
0005433434488	2355	123	25D
0005432655510	2355	124	24H
0005435982225	2355	125	25E
0005432984723	2355	126	27A
0005432226042	2355	127	25F
0005435982215	2355	128	27B
0005433434473	2355	129	27E
0005433754099	2355	130	27D
0005433434472	2355	131	27G
0005433754093	2355	132	27F
0005432984764	2355	133	27H
0005435982236	2355	134	28A
0005435982206	2355	135	28D
0005433754092	2355	136	28B
0005432984782	2355	137	28E
0005433754126	2355	138	28F
0005432655518	2355	139	28H
0005433754135	2355	140	28G
0005432300252	2355	141	29A
0005435982232	2355	142	29B
0005435982224	2355	143	29F
0005433766633	2355	144	29H
0005435982197	2355	145	29G
0005433434456	2355	146	30A
0005435982222	2355	147	30D
0005432984810	2355	148	30B
0005435982231	2355	149	30F
0005432984794	2355	150	30E
0005434731140	2355	151	30G
0005433754088	2355	152	31A
0005433754101	2355	153	30H
0005432655520	2355	154	31B
0005433754131	2355	155	31D
0005433754090	2355	156	31F
0005433766632	2355	157	31E
0005432984713	2355	158	31G
0005435982205	2355	159	32A
0005433754108	2355	160	31H
0005435982223	2355	161	32D
0005435982233	2355	162	32B
0005432984737	2355	163	32F
0005433754121	2355	164	32E
0005433434435	2355	165	32H
0005432869451	2355	166	32G
0005435982235	2355	167	33A
0005433754119	2355	168	33B
0005432655515	2355	169	33E
0005433434307	2355	170	33D
0005432869450	2355	171	33F
0005433754102	2355	172	33H
0005433754107	2355	173	33G
0005433754096	2355	174	34A
0005433754091	2355	175	34D
0005432655513	2355	176	34E
0005432226044	2355	177	34G
0005432300254	2355	178	34F
0005433754112	2355	179	35A
0005433434457	2355	180	34H
0005433754136	2355	181	35B
0005435982203	2355	182	35D
0005432226047	2355	183	35F
0005432300253	2355	184	35G
0005432655511	2355	185	35H
0005433434416	2355	186	36B
0005433434358	2355	187	36A
0005435982218	2355	188	36E
0005432984637	2355	189	36D
0005432984773	2355	190	36F
0005432226048	2355	191	36H
0005435982202	2355	192	36G
0005432984750	2355	193	37A
0005432984778	2355	194	37E
0005435982219	2355	195	37D
0005433754114	2355	196	37F
0005433754124	2355	197	37H
0005432984803	2355	198	37G
0005433754098	2355	199	38A
0005434731119	2355	200	38D
0005433754094	2355	201	38B
0005432655509	2355	202	38E
0005432984738	2355	203	38G
0005432655512	2355	204	38F
0005433754105	2355	205	38H
0005435982204	2355	206	39E
0005432984763	2355	207	39D
0005435982221	2355	208	39F
0005433766604	26172	1	1A
0005433434628	26172	2	1C
0005433753567	26172	3	1B
0005433753682	26172	4	1F
0005433753890	26172	5	1G
0005433434623	26172	6	2A
0005432985016	26172	7	1H
0005432655333	26172	8	2C
0005433434619	26172	9	2B
0005432869508	26172	10	2H
0005433753687	26172	11	2G
0005435981614	26172	12	2F
0005432985003	26172	13	3A
0005433753516	26172	14	3C
0005433753542	26172	15	3H
0005435981872	26172	16	4B
0005433753659	26172	17	4A
0005432984999	26172	18	4F
0005435981740	26172	19	4C
0005432985010	26172	20	4G
0005432869509	26172	21	4H
0005432869507	26172	22	5B
0005433753851	26172	23	5A
0005433753566	26172	24	5C
0005432985004	26172	25	5G
0005432985011	26172	26	5F
0005432985018	26172	27	9A
0005435981708	26172	28	5H
0005433753616	26172	29	9B
0005433753392	26172	30	9G
0005433434633	26172	31	11A
0005433753762	26172	32	11B
0005433753670	26172	33	11D
0005432985007	26172	34	11F
0005432869510	26172	35	11E
0005433434621	26172	36	11G
0005433434627	26172	37	12B
0005433434617	26172	38	12A
0005433766579	26172	39	11H
0005432985008	26172	40	12E
0005432985014	26172	41	12D
0005435981801	26172	42	12F
0005435981790	26172	43	12H
0005432985005	26172	44	12G
0005433753661	26172	45	13B
0005432655435	26172	46	13A
0005433753634	26172	47	13D
0005433753605	26172	48	13E
0005435981847	26172	49	13G
0005433434614	26172	50	13F
0005433753702	26172	51	13H
0005433753543	26172	52	14B
0005433434613	26172	53	14A
0005433753693	26172	54	14E
0005432985017	26172	55	14D
0005433753465	26172	56	14F
0005433434637	26172	57	14G
0005433753583	26172	58	14H
0005435981716	26172	59	15B
0005433753666	26172	60	15A
0005434731161	26172	61	15E
0005433434639	26172	62	15D
0005433753635	26172	63	15F
0005432985000	26172	64	15H
0005433434624	26172	65	15G
0005435981778	26172	66	16A
0005433753555	26172	67	16D
0005432985027	26172	68	16B
0005433434634	26172	69	16F
0005432985020	26172	70	16E
0005433766581	26172	71	16G
0005433753676	26172	72	16H
0005432655380	26172	73	17B
0005433753556	26172	74	17A
0005432655433	26172	75	17F
0005432049456	26172	76	17E
0005435981870	26172	77	17G
0005433753780	26172	78	17H
0005433753736	26172	79	18A
0005435981610	26172	80	18D
0005433434626	26172	81	18B
0005432985009	26172	82	18F
0005432985025	26172	83	18E
0005433753466	26172	84	18G
0005433434620	26172	85	19A
0005435981789	26172	86	18H
0005435981712	26172	87	19B
0005433434631	26172	88	19D
0005435981798	26172	89	19F
0005433434635	26172	90	19E
0005432985002	26172	91	19H
0005433753573	26172	92	19G
0005435981741	26172	93	20A
0005433753525	26172	94	20D
0005432985019	26172	95	20B
0005433753483	26172	96	20E
0005435981754	26172	97	20F
0005435981822	26172	98	20H
0005435981613	26172	99	20G
0005433753655	26172	100	21A
0005434731165	26172	101	21D
0005433434638	26172	102	21E
0005433753617	26172	103	21G
0005435981690	26172	104	21F
0005433753373	26172	105	21H
0005432985024	26172	106	22A
0005433753606	26172	107	22D
0005433753590	26172	108	22B
0005433753690	26172	109	22F
0005433434622	26172	110	22E
0005432049458	26172	111	22G
0005433753660	26172	112	22H
0005435981840	26172	113	23A
0005433753403	26172	114	23D
0005432985030	26172	115	23F
0005433434612	26172	116	23E
0005433753665	26172	117	23H
0005434731163	26172	118	23G
0005433766603	26172	119	24B
0005435981802	26172	120	24A
0005433766595	26172	121	24D
0005433753574	26172	122	24F
0005432655391	26172	123	24E
0005432985012	26172	124	24G
0005432051121	26172	125	25D
0005433753698	26172	126	24H
0005433753763	26172	127	25E
0005433753727	26172	128	27A
0005435981779	26172	129	25F
0005433753620	26172	130	27B
0005435981823	26172	131	27D
0005435981877	26172	132	27F
0005435981786	26172	133	27E
0005433753772	26172	134	27G
0005434731164	26172	135	28A
0005435981726	26172	136	27H
0005433766605	26172	137	28B
0005435981825	26172	138	28E
0005434731162	26172	139	28D
0005432985006	26172	140	28F
0005435981794	26172	141	28G
0005432984998	26172	142	29A
0005435981780	26172	143	29D
0005433753808	26172	144	29B
0005433753456	26172	145	29G
0005432655429	26172	146	29F
0005432655378	26172	147	29H
0005433753532	26172	148	30B
0005432985015	26172	149	30A
0005435981777	26172	150	30D
0005432985028	26172	151	30F
0005433753457	26172	152	30E
0005432985023	26172	153	30H
0005435981871	26172	154	30G
0005432985021	26172	155	31B
0005433753526	26172	156	31A
0005433753701	26172	157	31E
0005433753649	26172	158	31D
0005435981742	26172	159	31F
0005435981839	26172	160	31G
0005435981824	26172	161	32B
0005435981782	26172	162	32A
0005432655377	26172	163	32E
0005435981653	26172	164	32D
0005432655434	26172	165	32G
0005435981665	26172	166	32F
0005433753462	26172	167	33A
0005433753798	26172	168	32H
0005435981664	26172	169	33B
0005432049457	26172	170	33E
0005432985026	26172	171	33F
0005435981711	26172	172	33H
0005433753501	26172	173	34A
0005432051122	26172	174	34D
0005433753529	26172	175	34F
0005435981791	26172	176	34E
0005432985022	26172	177	34G
0005435981674	26172	178	35B
0005433434615	26172	179	35A
0005435981729	26172	180	35E
0005433753534	26172	181	35D
0005433753733	26172	182	35F
0005433753602	26172	183	35G
0005432051123	26172	184	36A
0005433434629	26172	185	35H
0005433753603	26172	186	36B
0005433753544	26172	187	36D
0005433434630	26172	188	36F
0005433434616	26172	189	36G
0005433753664	26172	190	37A
0005432985029	26172	191	36H
0005432869511	26172	192	37D
0005433434618	26172	193	37B
0005433753694	26172	194	37E
0005433753891	26172	195	37F
0005435981785	26172	196	37H
0005433434636	26172	197	37G
0005432655332	26172	198	38A
0005432985001	26172	199	38D
0005433753672	26172	200	38B
0005433753734	26172	201	38E
0005433434625	26172	202	38F
0005432985013	26172	203	38H
0005433766580	26172	204	38G
0005433764659	26172	205	39D
0005433434632	26172	206	39F
0005433753395	26172	207	39E
0005433151047	1540	1	1C
0005433150917	1540	2	1A
0005434374591	1540	3	2A
0005433151028	1540	4	2D
0005434374599	1540	5	2C
0005433151070	1540	6	2F
0005434029632	1540	7	3C
0005433461583	1540	8	3A
0005434374590	1540	9	3F
0005433151145	1540	10	3D
0005433150999	1540	11	4A
0005433460432	1540	12	4C
0005434374573	1540	13	4B
0005434374574	1540	14	4D
0005433764654	1540	15	4E
0005433151077	1540	16	4F
0005434374593	1540	17	5C
0005433151223	1540	18	5B
0005433150911	1540	19	5D
0005433151048	1540	20	5E
0005434374604	1540	21	5F
0005433150970	1540	22	6B
0005433151199	1540	23	7A
0005433461584	1540	24	6F
0005433151139	1540	25	7B
0005434374585	1540	26	7C
0005433151238	1540	27	7E
0005434374577	1540	28	7D
0005433151063	1540	29	8A
0005434374592	1540	30	8B
0005434374595	1540	31	8E
0005433151170	1540	32	8F
0005432267881	1540	33	9A
0005433151125	1540	34	9B
0005434374588	1540	35	9D
0005434374598	1540	36	9F
0005433150973	1540	37	10B
0005434374602	1540	38	10C
0005434374584	1540	39	10D
0005432267880	1540	40	11A
0005434374572	1540	41	11B
0005433151020	1540	42	11D
0005434374571	1540	43	11E
0005432267883	1540	44	11F
0005433151177	1540	45	12B
0005433151246	1540	46	12D
0005433150918	1540	47	12C
0005434374569	1540	48	12E
0005434374581	1540	49	13A
0005434374600	1540	50	13B
0005434374568	1540	51	13D
0005434374570	1540	52	13F
0005433764666	1540	53	14B
0005433150934	1540	54	14C
0005434374578	1540	55	14D
0005434374603	1540	56	14F
0005434374580	1540	57	15B
0005433151176	1540	58	15D
0005433151207	1540	59	15E
0005433151093	1540	60	16A
0005434374586	1540	61	15F
0005434374582	1540	62	16C
0005433151098	1540	63	16B
0005433151146	1540	64	16E
0005432267884	1540	65	16D
0005432267885	1540	66	16F
0005433151071	1540	67	17B
0005433150972	1540	68	17C
0005434374579	1540	69	17F
0005433151027	1540	70	17E
0005434374567	1540	71	18A
0005432267882	1540	72	18B
0005433764665	1540	73	18D
0005433151130	1540	74	18C
0005433151114	1540	75	18E
0005433151131	1540	76	19A
0005433460431	1540	77	19C
0005434374601	1540	78	19B
0005433151099	1540	79	19D
0005433151193	1540	80	19E
0005433150910	1540	81	19F
0005434374576	1540	82	20A
0005434374575	1540	83	20B
0005433151119	1540	84	20D
0005434374596	1540	85	20E
0005433764663	1540	86	20F
0005433151016	1540	87	21B
0005433150975	1540	88	21D
0005433151190	1540	89	21C
0005433151021	1540	90	21F
0005433151111	1540	91	21E
0005433151198	1540	92	22A
0005434374589	1540	93	22E
0005434374583	1540	94	22D
0005434374587	1540	95	23A
0005434374594	1540	96	22F
0005434374597	1540	97	23B
0005433151214	1540	98	23C
0005433151237	1540	99	23D
0005433150974	1540	100	23F
0005433151324	20151	1	1A
0005433151346	20151	2	1C
0005433151355	20151	3	1D
0005434374148	20151	4	1F
0005433151352	20151	5	2F
0005434374013	20151	6	3D
0005434374107	20151	7	3C
0005434374092	20151	8	3F
0005433151321	20151	9	4A
0005433151356	20151	10	4C
0005433151322	20151	11	4B
0005434374028	20151	12	4E
0005434374133	20151	13	5A
0005434374165	20151	14	4F
0005434029652	20151	15	6D
0005433764676	20151	16	6C
0005434374118	20151	17	6E
0005433151342	20151	18	7A
0005434374125	20151	19	6F
0005434374121	20151	20	7B
0005434374241	20151	21	7D
0005434374135	20151	22	7C
0005434374181	20151	23	7F
0005434374375	20151	24	8B
0005433151347	20151	25	8A
0005434374124	20151	26	8C
0005434374160	20151	27	8D
0005433151326	20151	28	8F
0005433151349	20151	29	8E
0005434374077	20151	30	9A
0005433151329	20151	31	9C
0005433151323	20151	32	9E
0005434374153	20151	33	9D
0005434374162	20151	34	10B
0005434374068	20151	35	10D
0005433151328	20151	36	11A
0005433151341	20151	37	11B
0005434374087	20151	38	11D
0005434374281	20151	39	11F
0005433151340	20151	40	11E
0005434373883	20151	41	12A
0005433151327	20151	42	12B
0005434374070	20151	43	12C
0005433151350	20151	44	12E
0005434374134	20151	45	12D
0005433151331	20151	46	13A
0005433151338	20151	47	13C
0005434374091	20151	48	13D
0005434029651	20151	49	13E
0005434374355	20151	50	14A
0005432056292	20151	51	14C
0005433151337	20151	52	14D
0005433151348	20151	53	14E
0005434374198	20151	54	14F
0005434029653	20151	55	15A
0005434374089	20151	56	15C
0005434374239	20151	57	15D
0005434374182	20151	58	15E
0005433151354	20151	59	16A
0005434374317	20151	60	15F
0005434374161	20151	61	16B
0005434374088	20151	62	16C
0005433151344	20151	63	16D
0005434374164	20151	64	16F
0005433151339	20151	65	16E
0005433151336	20151	66	17A
0005434374340	20151	67	17C
0005433151335	20151	68	17E
0005434374073	20151	69	17D
0005434374193	20151	70	18A
0005433151345	20151	71	17F
0005432056291	20151	72	18B
0005433764675	20151	73	18C
0005434374208	20151	74	18E
0005434374147	20151	75	19B
0005434374258	20151	76	19D
0005434374238	20151	77	19C
0005433151343	20151	78	19E
0005434374069	20151	79	19F
0005434374349	20151	80	20A
0005433151332	20151	81	20D
0005434374291	20151	82	20C
0005434374180	20151	83	20E
0005433151333	20151	84	20F
0005434374197	20151	85	21C
0005434374357	20151	86	21B
0005434374103	20151	87	21E
0005434374146	20151	88	22A
0005433151334	20151	89	21F
0005434374442	20151	90	22B
0005433151330	20151	91	22D
0005434374114	20151	92	23B
0005433151353	20151	93	23A
0005433151351	20151	94	23D
0005434374356	20151	95	23E
0005433151325	20151	96	23F
0005432424359	512	1	1A
0005432424366	512	2	2C
0005432424371	512	3	2D
0005432424369	512	4	3A
0005432282850	512	5	3F
0005432424355	512	6	4C
0005432424337	512	7	6C
0005432282849	512	8	7A
0005432282851	512	9	6F
0005432424333	512	10	7D
0005432424346	512	11	7C
0005432424362	512	12	8C
0005432424374	512	13	8D
0005432424357	512	14	9C
0005432424375	512	15	10A
0005432424365	512	16	11D
0005432282848	512	17	11E
0005432424345	512	18	12F
0005432424368	512	19	13B
0005432424324	512	20	13E
0005432424372	512	21	13F
0005432424373	512	22	14D
0005432424353	512	23	14C
0005432424330	512	24	15B
0005432424363	512	25	15C
0005432424342	512	26	15D
0005432424348	512	27	16A
0005432282853	512	28	16B
0005432424339	512	29	16E
0005432424350	512	30	17A
0005432424358	512	31	17C
0005432424370	512	32	17D
0005432424328	512	33	19E
0005432424351	512	34	20B
0005432424340	512	35	20E
0005432424338	512	36	20F
0005432424347	512	37	21C
0005432424349	512	38	21D
0005432424334	512	39	21E
0005432424326	512	40	22A
0005432424360	512	41	22F
0005432424354	512	42	23D
0005432424331	512	43	23F
0005432424352	512	44	24A
0005432424356	512	45	25E
0005432424329	512	46	25D
0005432424335	512	47	26A
0005432424341	512	48	26C
0005432424336	512	49	26E
0005432282852	512	50	28A
0005432424361	512	51	28F
0005432424344	512	52	29A
0005432424332	512	53	29F
0005432424343	512	54	30A
0005432424325	512	55	30B
0005432424364	512	56	30C
0005432424327	512	57	30E
0005432424367	512	58	31B
0005432302322	12940	1	8C
0005432302323	12940	2	25B
0005432302324	12940	3	31C
0005432423912	12895	1	1D
0005432423799	12895	2	2C
0005432423819	12895	3	2D
0005432423915	12895	4	2F
0005432423778	12895	5	3C
0005432423899	12895	6	4A
0005432423769	12895	7	6C
0005432423710	12895	8	7C
0005432423877	12895	9	8A
0005432423879	12895	10	8C
0005432423813	12895	11	9A
0005432423898	12895	12	9F
0005432423914	12895	13	10E
0005432423788	12895	14	10D
0005432423714	12895	15	10F
0005432423751	12895	16	11E
0005432423763	12895	17	12B
0005432423895	12895	18	13A
0005432423814	12895	19	12F
0005432423850	12895	20	12E
0005432423897	12895	21	13B
0005432423875	12895	22	13C
0005432423826	12895	23	13D
0005432423880	12895	24	14B
0005432423852	12895	25	14E
0005432423686	12895	26	14D
0005432423870	12895	27	15E
0005432423878	12895	28	16A
0005432423827	12895	29	15F
0005432423708	12895	30	16B
0005432423607	12895	31	16C
0005432423929	12895	32	16E
0005432423911	12895	33	17A
0005432423802	12895	34	18F
0005432423750	12895	35	19D
0005432423851	12895	36	20C
0005432423872	12895	37	20F
0005432423921	12895	38	21B
0005432423760	12895	39	21D
0005432423869	12895	40	23C
0005432423824	12895	41	23B
0005432423752	12895	42	23D
0005432423817	12895	43	24B
0005432423773	12895	44	24F
0005432423777	12895	45	25C
0005432423749	12895	46	25F
0005432423908	12895	47	26C
0005432423871	12895	48	27A
0005432423652	12895	49	27F
0005432423774	12895	50	28D
0005432423779	12895	51	29A
0005432423861	12895	52	29D
0005432423894	12895	53	29E
0005432423761	12895	54	30A
0005432423910	12895	55	31C
0005432423876	12895	56	31D
0005434028289	430	1	1A
0005434023552	430	2	1B
0005434023593	430	3	1G
0005434023590	430	4	2A
0005432235621	430	5	2B
0005434023587	430	6	2C
0005433057426	430	7	3A
0005434023551	430	8	3B
0005434028290	430	9	3F
0005434023609	430	10	3C
0005434023589	430	11	4A
0005433057574	430	12	4C
0005434023604	430	13	4G
0005433057624	430	14	5A
0005433057427	430	15	5B
0005434023545	430	16	5F
0005434023548	430	17	5C
0005434023559	430	18	5G
0005433057541	430	19	5H
0005433057332	430	20	9B
0005434032010	430	21	9A
0005434028288	430	22	9G
0005434735632	430	23	11A
0005433057481	430	24	11B
0005433057570	430	25	11E
0005434023598	430	26	11D
0005433057499	430	27	11F
0005434023576	430	28	12B
0005434023568	430	29	12E
0005434023547	430	30	12H
0005434023577	430	31	12G
0005434028291	430	32	13D
0005434023586	430	33	13B
0005434023546	430	34	13G
0005433057510	430	35	13H
0005433057328	430	36	14D
0005434023572	430	37	14E
0005434735602	430	38	14G
0005433057396	430	39	14F
0005434023571	430	40	15D
0005433057466	430	41	15B
0005433057473	430	42	15G
0005434023553	430	43	15F
0005433057502	430	44	15E
0005434032012	430	45	15H
0005434023608	430	46	16A
0005434023560	430	47	16B
0005434023606	430	48	16F
0005432235624	430	49	16G
0005433057327	430	50	16H
0005434023556	430	51	17B
0005434023600	430	52	17D
0005434023602	430	53	17F
0005433057566	430	54	17G
0005434023595	430	55	17H
0005434023561	430	56	18A
0005434023542	430	57	18D
0005433057434	430	58	18B
0005434735629	430	59	18G
0005433057539	430	60	19A
0005434735631	430	61	19B
0005433057577	430	62	19D
0005433057514	430	63	19F
0005434023544	430	64	19E
0005433057548	430	65	19H
0005433929555	430	66	19G
0005434023596	430	67	20D
0005434023558	430	68	20G
0005433057569	430	69	20H
0005432235622	430	70	21B
0005434029649	430	71	21E
0005434023555	430	72	21D
0005433057621	430	73	21F
0005433057575	430	74	21H
0005434023578	430	75	22E
0005434023583	430	76	22G
0005432235623	430	77	23A
0005434023579	430	78	22H
0005434023584	430	79	23B
0005433057478	430	80	23D
0005432235625	430	81	23F
0005433057622	430	82	23G
0005433057604	430	83	23H
0005433057374	430	84	24A
0005434023580	430	85	24E
0005433057576	430	86	24D
0005434023599	430	87	24F
0005433057385	430	88	24H
0005433057601	430	89	24G
0005434023569	430	90	25D
0005432045609	430	91	25F
0005434023581	430	92	27B
0005433057538	430	93	27F
0005434023567	430	94	27G
0005434023573	430	95	28A
0005433057572	430	96	28E
0005434023588	430	97	28D
0005433057652	430	98	28G
0005433057465	430	99	28F
0005433057627	430	100	28H
0005434023597	430	101	29D
0005433057540	430	102	29B
0005434029650	430	103	29G
0005434023557	430	104	29H
0005434023574	430	105	30B
0005434023607	430	106	30A
0005433057469	430	107	30D
0005433057501	430	108	30E
0005434023601	430	109	30G
0005433057468	430	110	30H
0005434023563	430	111	31A
0005433684391	430	112	31E
0005434023541	430	113	31G
0005434023570	430	114	32A
0005432235626	430	115	31H
0005434023554	430	116	32B
0005433057525	430	117	32E
0005433057571	430	118	32D
0005434023543	430	119	32H
0005433057567	430	120	32G
0005432045608	430	121	33E
0005434023562	430	122	34B
0005434023564	430	123	34E
0005434023566	430	124	35A
0005433057532	430	125	35D
0005434023603	430	126	35B
0005434032011	430	127	35F
0005434023575	430	128	35E
0005434023605	430	129	35G
0005434023585	430	130	36B
0005434023550	430	131	36D
0005433057406	430	132	36E
0005434023594	430	133	36G
0005433057397	430	134	37A
0005434023582	430	135	36H
0005434032013	430	136	37D
0005434023591	430	137	37G
0005434023549	430	138	38A
0005433057607	430	139	38G
0005434023565	430	140	38H
0005434023592	430	141	39F
0005434735678	12642	1	1A
0005434735682	12642	2	1B
0005434023116	12642	3	1C
0005434031978	12642	4	1H
0005434023239	12642	5	2A
0005433057796	12642	6	2F
0005432157488	12642	7	2C
0005433684418	12642	8	3A
0005433057803	12642	9	3F
0005433057805	12642	10	3C
0005434022886	12642	11	3H
0005434022616	12642	12	3G
0005434022811	12642	13	4H
0005433057786	12642	14	5C
0005434022755	12642	15	9A
0005433057784	12642	16	9B
0005433929603	12642	17	9G
0005433057810	12642	18	9H
0005433057811	12642	19	11D
0005433057799	12642	20	11B
0005434022937	12642	21	11E
0005434023125	12642	22	11F
0005434022829	12642	23	12A
0005434023193	12642	24	12B
0005432156358	12642	25	12E
0005434031980	12642	26	12F
0005434023259	12642	27	12G
0005433057801	12642	28	13B
0005433057806	12642	29	13E
0005434022987	12642	30	13G
0005434022959	12642	31	13H
0005433057798	12642	32	14B
0005433057791	12642	33	14A
0005432156356	12642	34	14D
0005434735680	12642	35	14E
0005433057802	12642	36	14G
0005434022853	12642	37	15A
0005434022810	12642	38	15D
0005434023267	12642	39	15B
0005432156355	12642	40	15H
0005433057818	12642	41	16B
0005433929607	12642	42	16E
0005433057807	12642	43	16G
0005433057797	12642	44	16F
0005434031964	12642	45	17G
0005433057795	12642	46	18F
0005434735681	12642	47	18G
0005432157487	12642	48	18H
0005434023194	12642	49	19B
0005433057812	12642	50	19D
0005434023223	12642	51	19F
0005434022977	12642	52	19G
0005433929604	12642	53	20B
0005433057808	12642	54	20D
0005432156357	12642	55	20F
0005433057794	12642	56	20H
0005434022960	12642	57	20G
0005434022990	12642	58	21A
0005434023104	12642	59	21B
0005433057788	12642	60	21F
0005434023255	12642	61	21H
0005434029632	12642	62	21G
0005433684417	12642	63	22B
0005434022991	12642	64	22A
0005434022983	12642	65	22G
0005434023020	12642	66	22F
0005433057819	12642	67	23B
0005434022844	12642	68	23D
0005433057793	12642	69	23H
0005433057813	12642	70	24B
0005434023260	12642	71	24D
0005433057814	12642	72	24H
0005434023106	12642	73	24G
0005434023014	12642	74	25D
0005433057809	12642	75	27A
0005434023185	12642	76	27B
0005434023107	12642	77	27E
0005434023120	12642	78	27D
0005433057823	12642	79	27H
0005434023019	12642	80	28A
0005434022905	12642	81	28E
0005434023124	12642	82	28G
0005433057825	12642	83	29A
0005433057821	12642	84	29F
0005434022725	12642	85	29G
0005434023115	12642	86	30B
0005434023117	12642	87	30A
0005433057785	12642	88	30E
0005433057822	12642	89	30D
0005433057789	12642	90	30F
0005433057815	12642	91	31B
0005434735679	12642	92	31A
0005434022803	12642	93	31E
0005434022938	12642	94	31D
0005433929606	12642	95	31F
0005433057826	12642	96	32A
0005434023072	12642	97	32B
0005433057804	12642	98	32F
0005434022976	12642	99	32E
0005434022885	12642	100	32H
0005433057787	12642	101	32G
0005433057820	12642	102	33B
0005434022909	12642	103	33A
0005433057824	12642	104	33G
0005434031979	12642	105	33F
0005434023018	12642	106	34A
0005433057790	12642	107	34D
0005434023211	12642	108	34E
0005434023017	12642	109	34G
0005434022693	12642	110	35A
0005433057800	12642	111	35F
0005434023033	12642	112	35E
0005433057817	12642	113	35G
0005433057816	12642	114	36B
0005434022726	12642	115	36E
0005434022936	12642	116	37B
0005433057792	12642	117	38A
0005433929605	12642	118	38D
0005433684416	12642	119	38F
0005434022913	12642	120	38E
0005433035689	2169	1	1A
0005433923128	2169	2	1C
0005433035707	2169	3	1B
0005433035799	2169	4	1F
0005433923118	2169	5	1G
0005433035639	2169	6	1H
0005433035800	2169	7	2B
0005433929607	2169	8	2F
0005433923143	2169	9	2C
0005433035699	2169	10	2G
0005433923063	2169	11	3A
0005433923112	2169	12	2H
0005433035665	2169	13	3C
0005433923076	2169	14	3B
0005433923069	2169	15	3F
0005433035688	2169	16	3H
0005432749763	2169	17	3G
0005433035654	2169	18	4A
0005433035715	2169	19	4B
0005433923086	2169	20	4F
0005433923077	2169	21	4C
0005433923087	2169	22	4G
0005432231547	2169	23	4H
0005433923136	2169	24	5B
0005433035830	2169	25	5A
0005433923148	2169	26	5C
0005433923138	2169	27	5G
0005433923105	2169	28	5F
0005433035696	2169	29	5H
0005432231539	2169	30	9B
0005433035737	2169	31	9A
0005433035845	2169	32	9G
0005433923082	2169	33	11A
0005433923068	2169	34	9H
0005432749764	2169	35	11B
0005433923155	2169	36	11D
0005433923129	2169	37	11H
0005433923089	2169	38	11G
0005433923114	2169	39	12A
0005433923085	2169	40	12E
0005433035848	2169	41	12D
0005433923121	2169	42	12G
0005433035824	2169	43	12F
0005433035708	2169	44	12H
0005432231542	2169	45	13B
0005433035801	2169	46	13A
0005433929606	2169	47	13D
0005433923117	2169	48	13F
0005433035640	2169	49	14A
0005433923080	2169	50	13H
0005433923065	2169	51	14B
0005433923101	2169	52	14E
0005433035841	2169	53	14D
0005433035847	2169	54	14H
0005433035429	2169	55	14G
0005433923156	2169	56	14F
0005433923151	2169	57	15A
0005433923146	2169	58	15B
0005433923147	2169	59	15E
0005433923091	2169	60	15D
0005433923135	2169	61	15F
0005433923079	2169	62	15H
0005433923102	2169	63	15G
0005433035503	2169	64	16A
0005433923137	2169	65	16D
0005433035698	2169	66	16B
0005433923103	2169	67	16F
0005433035558	2169	68	16E
0005433875373	2169	69	16G
0005433923154	2169	70	16H
0005433035660	2169	71	17B
0005433923122	2169	72	17A
0005433923094	2169	73	17D
0005433035872	2169	74	17E
0005433923126	2169	75	17G
0005433035459	2169	76	17F
0005433923139	2169	77	17H
0005433035666	2169	78	18B
0005433923062	2169	79	18A
0005433035806	2169	80	18D
0005433923123	2169	81	18E
0005433035805	2169	82	18G
0005433035752	2169	83	18F
0005433923134	2169	84	19A
0005433035820	2169	85	18H
0005433035884	2169	86	19B
0005433923131	2169	87	19E
0005433035732	2169	88	19D
0005433035741	2169	89	19F
0005433035655	2169	90	20A
0005433035790	2169	91	20B
0005433035532	2169	92	20E
0005433923075	2169	93	20D
0005433923140	2169	94	20G
0005433035490	2169	95	20F
0005432231537	2169	96	21A
0005433929603	2169	97	21D
0005433923071	2169	98	21B
0005433035645	2169	99	21E
0005433923113	2169	100	21F
0005433035913	2169	101	21H
0005433035649	2169	102	21G
0005433035670	2169	103	22A
0005433923060	2169	104	22D
0005433035489	2169	105	22B
0005433035653	2169	106	22F
0005433035638	2169	107	22E
0005433035609	2169	108	22G
0005433923110	2169	109	22H
0005433035508	2169	110	23D
0005433035748	2169	111	23B
0005432231543	2169	112	23F
0005433923084	2169	113	23E
0005432231541	2169	114	23G
0005433923093	2169	115	23H
0005433035559	2169	116	24B
0005432044518	2169	117	24A
0005433036003	2169	118	24E
0005433923067	2169	119	24D
0005433923061	2169	120	24F
0005433923120	2169	121	24G
0005433035504	2169	122	25D
0005432749766	2169	123	24H
0005432231538	2169	124	25F
0005433923153	2169	125	25E
0005433035697	2169	126	27A
0005433923149	2169	127	27E
0005433923095	2169	128	27D
0005433923145	2169	129	28B
0005433923152	2169	130	28E
0005433035488	2169	131	28D
0005433923090	2169	132	28F
0005433923144	2169	133	28H
0005433923142	2169	134	28G
0005433923078	2169	135	29D
0005433923081	2169	136	29B
0005433923083	2169	137	29E
0005433923132	2169	138	29G
0005433035823	2169	139	29H
0005433035808	2169	140	30B
0005433923115	2169	141	30A
0005433923092	2169	142	30D
0005433035846	2169	143	30E
0005432231546	2169	144	30G
0005433035435	2169	145	30F
0005432231544	2169	146	30H
0005433035865	2169	147	31A
0005433035942	2169	148	31D
0005433035802	2169	149	31B
0005433923099	2169	150	31F
0005433923098	2169	151	31E
0005433923106	2169	152	31G
0005433923111	2169	153	32A
0005433035765	2169	154	31H
0005433035818	2169	155	32B
0005433035909	2169	156	32D
0005433923074	2169	157	32G
0005433875372	2169	158	32F
0005433035722	2169	159	32E
0005433923096	2169	160	33A
0005433923150	2169	161	32H
0005433929605	2169	162	33D
0005432231545	2169	163	33B
0005433923073	2169	164	33E
0005433035756	2169	165	33F
0005433035764	2169	166	33H
0005433923127	2169	167	33G
0005433035880	2169	168	34B
0005433923066	2169	169	34A
0005433923107	2169	170	34D
0005433923097	2169	171	34F
0005433923100	2169	172	34E
0005433923141	2169	173	34G
0005432044519	2169	174	34H
0005433929604	2169	175	35B
0005432749765	2169	176	35A
0005433923104	2169	177	35D
0005433923072	2169	178	35F
0005433035810	2169	179	35E
0005433035543	2169	180	35G
0005433923116	2169	181	36A
0005433923157	2169	182	35H
0005433923064	2169	183	36B
0005433035758	2169	184	36D
0005433923108	2169	185	36F
0005432231540	2169	186	36E
0005433035776	2169	187	36G
0005433035744	2169	188	36H
0005433923109	2169	189	37B
0005433035428	2169	190	37D
0005433923125	2169	191	37F
0005433035789	2169	192	37E
0005433923088	2169	193	37H
0005433035667	2169	194	37G
0005433923124	2169	195	38A
0005433035743	2169	196	38D
0005433035819	2169	197	38B
0005433923119	2169	198	38E
0005433035507	2169	199	38F
0005433923070	2169	200	38H
0005433923130	2169	201	38G
0005433923133	2169	202	39D
0005433035822	2169	203	39F
0005432206186	24096	1	1A
0005433036166	24096	2	1B
0005433922096	24096	3	1C
0005433922215	24096	4	1H
0005433922350	24096	5	2B
0005433036200	24096	6	2F
0005433922174	24096	7	3A
0005433922270	24096	8	3B
0005433922165	24096	9	3C
0005433922272	24096	10	3G
0005433036185	24096	11	3F
0005433922342	24096	12	4B
0005433922280	24096	13	4F
0005433922222	24096	14	4C
0005433036186	24096	15	4H
0005433922396	24096	16	4G
0005433922533	24096	17	5A
0005433036199	24096	18	5C
0005433036180	24096	19	5G
0005433922384	24096	20	5F
0005433922435	24096	21	9A
0005433036215	24096	22	5H
0005433922538	24096	23	9B
0005433036168	24096	24	9G
0005433921975	24096	25	9H
0005433036172	24096	26	11B
0005433036217	24096	27	11E
0005433921716	24096	28	11D
0005433036216	24096	29	11H
0005433921823	24096	30	11G
0005433921987	24096	31	12D
0005433036208	24096	32	12E
0005433036219	24096	33	12F
0005433036170	24096	34	12H
0005433036214	24096	35	13A
0005433922021	24096	36	13D
0005433036194	24096	37	13B
0005433922107	24096	38	13E
0005433922239	24096	39	13H
0005433875361	24096	40	14B
0005433929554	24096	41	14A
0005433931437	24096	42	14F
0005433922184	24096	43	14E
0005433922669	24096	44	14H
0005433922267	24096	45	14G
0005433922352	24096	46	15A
0005433922262	24096	47	15B
0005433036181	24096	48	15E
0005433921815	24096	49	15D
0005432206185	24096	50	15F
0005433922338	24096	51	15G
0005433922012	24096	52	16A
0005433922593	24096	53	15H
0005433036195	24096	54	16D
0005433922136	24096	55	16B
0005433922334	24096	56	16E
0005433922219	24096	57	16F
0005433036204	24096	58	16H
0005434028293	24096	59	16G
0005433922093	24096	60	17A
0005433036218	24096	61	17D
0005433922020	24096	62	17F
0005433922422	24096	63	17H
0005433922696	24096	64	18E
0005433922137	24096	65	18G
0005433036196	24096	66	18H
0005433922192	24096	67	19D
0005433922249	24096	68	19F
0005433922385	24096	69	19E
0005433922372	24096	70	19H
0005433036187	24096	71	20A
0005433036184	24096	72	20B
0005433921933	24096	73	20E
0005433922333	24096	74	20D
0005433922216	24096	75	20F
0005433922213	24096	76	21B
0005433922517	24096	77	21A
0005433922044	24096	78	20H
0005433921888	24096	79	21E
0005433922649	24096	80	21H
0005433922518	24096	81	21G
0005433036173	24096	82	22A
0005433922445	24096	83	22D
0005433036209	24096	84	22B
0005433875363	24096	85	22F
0005433036201	24096	86	22E
0005433922488	24096	87	22G
0005433036211	24096	88	22H
0005433036220	24096	89	23B
0005433922611	24096	90	23A
0005433036197	24096	91	23D
0005433922560	24096	92	23E
0005433036189	24096	93	24A
0005432207658	24096	94	23H
0005433036174	24096	95	24B
0005433036210	24096	96	24D
0005433922191	24096	97	24E
0005433922013	24096	98	24G
0005433921784	24096	99	24H
0005433922217	24096	100	27A
0005433922092	24096	101	25F
0005433921994	24096	102	27B
0005433922023	24096	103	27E
0005433036207	24096	104	27G
0005433922181	24096	105	27F
0005433036179	24096	106	27H
0005433036190	24096	107	28D
0005433922090	24096	108	28E
0005433036177	24096	109	28G
0005433921976	24096	110	28F
0005433922027	24096	111	29A
0005433921988	24096	112	28H
0005433036175	24096	113	29D
0005433922532	24096	114	29B
0005433036198	24096	115	29E
0005433875366	24096	116	29G
0005433931432	24096	117	30B
0005433922024	24096	118	30D
0005433036193	24096	119	30E
0005433922335	24096	120	30G
0005433036213	24096	121	30H
0005433036176	24096	122	31B
0005433922506	24096	123	31E
0005433036203	24096	124	31D
0005433036212	24096	125	31H
0005432206183	24096	126	31G
0005433922371	24096	127	31F
0005433036182	24096	128	32A
0005432206184	24096	129	32B
0005433921785	24096	130	32E
0005434028294	24096	131	32F
0005433875362	24096	132	32G
0005433922089	24096	133	33A
0005433931428	24096	134	33D
0005433036171	24096	135	33B
0005433922263	24096	136	33F
0005433922095	24096	137	33H
0005433922094	24096	138	34B
0005433036205	24096	139	34A
0005433922289	24096	140	34D
0005433036183	24096	141	34E
0005433036192	24096	142	34H
0005433036188	24096	143	34G
0005433931429	24096	144	35B
0005433036191	24096	145	35A
0005433921887	24096	146	35D
0005433922475	24096	147	35F
0005433036167	24096	148	35G
0005433036206	24096	149	36A
0005433922468	24096	150	35H
0005433036178	24096	151	36B
0005432749781	24096	152	36E
0005433036202	24096	153	36F
0005433921915	24096	154	36G
0005433922185	24096	155	37A
0005433922351	24096	156	37B
0005433922474	24096	157	37D
0005433921995	24096	158	37H
0005433922403	24096	159	37G
0005433931438	24096	160	38D
0005433922650	24096	161	38B
0005434028292	24096	162	38G
0005433922290	24096	163	38F
0005432207657	24096	164	39D
0005433922091	24096	165	38H
0005433922373	24096	166	39E
0005433036169	24096	167	39F
0005434725235	305	1	1C
0005434725183	305	2	1A
0005433180867	305	3	1G
0005433233443	305	4	1D
0005434551132	305	5	1H
0005433180807	305	6	2D
0005434735677	305	7	2C
0005435142544	305	8	2A
0005433180928	305	9	2H
0005434551145	305	10	2G
0005435142548	305	11	3A
0005434725201	305	12	2K
0005433289751	305	13	3G
0005433126794	305	14	3D
0005433233526	305	15	3C
0005434735675	305	16	3K
0005434725285	305	17	3H
0005433766618	305	18	4C
0005433111486	305	19	4A
0005433180885	305	20	4G
0005434302864	305	21	4D
0005434551152	305	22	4K
0005433233555	305	23	4H
0005434725211	305	24	5C
0005433233631	305	25	5A
0005434551141	305	26	5H
0005433233630	305	27	5G
0005434725232	305	28	11A
0005432277779	305	29	5K
0005433289764	305	30	11D
0005434551125	305	31	11C
0005434725243	305	32	11F
0005433233525	305	33	11E
0005433233629	305	34	11K
0005434725238	305	35	11H
0005434551112	305	36	11G
0005434551139	305	37	12A
0005434725220	305	38	12E
0005434735676	305	39	12D
0005434551114	305	40	12H
0005434725254	305	41	12G
0005433289795	305	42	12F
0005433233470	305	43	12K
0005434725263	305	44	13C
0005433180794	305	45	13A
0005434725271	305	46	13F
0005435142553	305	47	13H
0005433233572	305	48	13G
0005434725221	305	49	14C
0005433131682	305	50	14A
0005434725229	305	51	13K
0005434725269	305	52	14E
0005433233302	305	53	14D
0005433180747	305	54	14G
0005433233425	305	55	14F
0005434731159	305	56	14K
0005432277783	305	57	14H
0005434735672	305	58	15C
0005434551126	305	59	15A
0005433180856	305	60	15E
0005433233689	305	61	15D
0005434551118	305	62	15H
0005434725198	305	63	15F
0005433180889	305	64	15K
0005434551130	305	65	16D
0005433111485	305	66	16C
0005433233956	305	67	16F
0005433233658	305	68	16E
0005434725249	305	69	16G
0005435142554	305	70	17C
0005434725213	305	71	17A
0005434551129	305	72	16K
0005434551128	305	73	17E
0005433289788	305	74	17D
0005433233527	305	75	17F
0005433233505	305	76	18A
0005434551137	305	77	17K
0005434725208	305	78	17H
0005434725173	305	79	18C
0005433111476	305	80	18B
0005433131683	305	81	18E
0005434551155	305	82	18D
0005434551133	305	83	18G
0005434725233	305	84	18F
0005434551113	305	85	18J
0005433131657	305	86	18H
0005434725217	305	87	19A
0005434725260	305	88	18K
0005434302863	305	89	19D
0005432277789	305	90	19C
0005434551135	305	91	19B
0005433289765	305	92	19F
0005433131654	305	93	19E
0005434725256	305	94	19J
0005435142546	305	95	19G
0005435142545	305	96	19K
0005433180940	305	97	20C
0005433233464	305	98	20B
0005433233412	305	99	20A
0005434725270	305	100	20D
0005433111487	305	101	20H
0005433233394	305	102	20G
0005434725283	305	103	20F
0005434302452	305	104	20K
0005434725196	305	105	20J
0005434725230	305	106	21B
0005434551138	305	107	21A
0005434725264	305	108	21D
0005434725242	305	109	21C
0005433233511	305	110	21F
0005433233714	305	111	21E
0005433233413	305	112	21J
0005434725248	305	113	21H
0005432277780	305	114	21G
0005434551150	305	115	22A
0005434551105	305	116	21K
0005434551151	305	117	22D
0005432277778	305	118	22C
0005433233390	305	119	22B
0005434302448	305	120	22E
0005434725265	305	121	22H
0005433233504	305	122	22G
0005433233785	305	123	22F
0005434725177	305	124	22K
0005435142552	305	125	22J
0005434725218	305	126	23B
0005434725227	305	127	23A
0005433766614	305	128	23C
0005434725178	305	129	23G
0005433233620	305	130	23F
0005433233363	305	131	23E
0005433111488	305	132	23J
0005434725276	305	133	24D
0005434551124	305	134	23K
0005433180746	305	135	24E
0005433289796	305	136	25A
0005434725292	305	137	24G
0005434551131	305	138	25C
0005434551108	305	139	25B
0005434725184	305	140	25F
0005434725280	305	141	25D
0005433180805	305	142	25H
0005434551147	305	143	25K
0005434725180	305	144	25J
0005434725279	305	145	26C
0005434725181	305	146	26B
0005434725273	305	147	26A
0005433233463	305	148	26E
0005434551146	305	149	26D
0005434725245	305	150	26G
0005433233626	305	151	26F
0005433180793	305	152	26J
0005433233240	305	153	26H
0005433233612	305	154	27A
0005434725261	305	155	26K
0005434725194	305	156	27D
0005435142551	305	157	27C
0005434725189	305	158	27B
0005433233615	305	159	27F
0005434725257	305	160	27E
0005434725172	305	161	27H
0005434725289	305	162	27G
0005434551117	305	163	28A
0005433233535	305	164	27K
0005434551100	305	165	27J
0005433233704	305	166	28C
0005433233573	305	167	28B
0005434725262	305	168	28E
0005434725237	305	169	28D
0005435142547	305	170	28G
0005434725250	305	171	28F
0005434735673	305	172	28K
0005433180929	305	173	28J
0005433180924	305	174	28H
0005434302449	305	175	29B
0005434725252	305	176	29D
0005433233358	305	177	29F
0005434551136	305	178	29E
0005434551107	305	179	29H
0005434725170	305	180	29G
0005434725176	305	181	29K
0005434725244	305	182	29J
0005434725286	305	183	30B
0005433233245	305	184	30A
0005433233542	305	185	30E
0005434031950	305	186	30D
0005433233275	305	187	30C
0005434551142	305	188	30G
0005433233482	305	189	30F
0005434725171	305	190	30J
0005433233735	305	191	30H
0005433233650	305	192	31A
0005434551122	305	193	30K
0005434725216	305	194	31D
0005434725169	305	195	31C
0005433233316	305	196	31F
0005434735674	305	197	31E
0005434725200	305	198	31H
0005434725215	305	199	31G
0005434725188	305	200	32A
0005434725204	305	201	31K
0005434725190	305	202	31J
0005434551134	305	203	32C
0005434725247	305	204	32B
0005433233387	305	205	32E
0005432277785	305	206	32D
0005434551101	305	207	32G
0005433233816	305	208	32F
0005434725187	305	209	32J
0005433111478	305	210	32H
0005433180855	305	211	33B
0005434725214	305	212	32K
0005433113503	305	213	33D
0005434725182	305	214	33F
0005434551123	305	215	33E
0005433180868	305	216	33J
0005435142549	305	217	33H
0005435142543	305	218	33G
0005434725175	305	219	34A
0005434725219	305	220	33K
0005434302866	305	221	34C
0005433233416	305	222	34H
0005433233513	305	223	34G
0005434725206	305	224	34F
0005434725282	305	225	34K
0005434725288	305	226	34J
0005434725193	305	227	35B
0005434725278	305	228	35D
0005434725174	305	229	35C
0005432277784	305	230	35G
0005434551148	305	231	35F
0005434725251	305	232	35H
0005434725240	305	233	35K
0005434551110	305	234	36C
0005432277786	305	235	36B
0005434731156	305	236	36E
0005432277776	305	237	36D
0005433113504	305	238	36H
0005434725195	305	239	36G
0005433233455	305	240	36F
0005433131651	305	241	36J
0005432277787	305	242	37B
0005434551121	305	243	37A
0005434725259	305	244	36K
0005434725223	305	245	37E
0005433233317	305	246	37D
0005433113511	305	247	37C
0005433180722	305	248	37J
0005433233362	305	249	37H
0005433180814	305	250	37G
0005434551116	305	251	38A
0005434551127	305	252	37K
0005434725197	305	253	38C
0005434725246	305	254	38B
0005433233493	305	255	38J
0005433233659	305	256	38H
0005433233647	305	257	38K
0005434731158	305	258	39D
0005434725228	305	259	39C
0005434725231	305	260	39B
0005434302868	305	261	39F
0005434725239	305	262	39E
0005434725281	305	263	39H
0005434731157	305	264	39G
0005433233389	305	265	39K
0005433233512	305	266	39J
0005433233543	305	267	40C
0005432277782	305	268	40B
0005434725287	305	269	40A
0005434725199	305	270	40E
0005434725255	305	271	40D
0005434725186	305	272	40H
0005433233604	305	273	40G
0005434725234	305	274	40F
0005433233619	305	275	40K
0005432277777	305	276	41B
0005433180787	305	277	41A
0005434725267	305	278	41D
0005434725222	305	279	41C
0005434725290	305	280	41F
0005434551143	305	281	41E
0005433233574	305	282	41J
0005433233374	305	283	41H
0005434551119	305	284	41G
0005434302451	305	285	42A
0005434725291	305	286	41K
0005434725268	305	287	42C
0005434551115	305	288	42B
0005434551154	305	289	42E
0005433131667	305	290	42D
0005434725258	305	291	42G
0005434725209	305	292	42F
0005433233521	305	293	42K
0005434725224	305	294	42J
0005433233605	305	295	43B
0005433180847	305	296	43A
0005433233424	305	297	43D
0005434725226	305	298	43C
0005434725236	305	299	43F
0005434725185	305	300	43E
0005435142555	305	301	43H
0005433233651	305	302	43G
0005434551120	305	303	43K
0005434551149	305	304	43J
0005434551104	305	305	44B
0005434551153	305	306	44A
0005433180930	305	307	44E
0005433289778	305	308	44C
0005434551144	305	309	44H
0005434302450	305	310	44G
0005434551140	305	311	44F
0005434725203	305	312	44J
0005434302867	305	313	45B
0005434551109	305	314	45A
0005433111477	305	315	44K
0005433766602	305	316	45D
0005433233784	305	317	45C
0005433233483	305	318	45F
0005433111481	305	319	45H
0005435142556	305	320	45G
0005434725192	305	321	46A
0005434725272	305	322	45K
0005433180760	305	323	45J
0005434725179	305	324	46B
0005434725191	305	325	46E
0005433233552	305	326	46D
0005435142550	305	327	46C
0005434551111	305	328	46F
0005434031985	305	329	46J
0005434725210	305	330	46H
0005434551099	305	331	47C
0005433766593	305	332	47A
0005434725274	305	333	46K
0005433233519	305	334	47D
0005434725212	305	335	47G
0005434725225	305	336	47F
0005434725277	305	337	47E
0005433233955	305	338	47K
0005434725202	305	339	47H
0005433233625	305	340	48D
0005432277781	305	341	48C
0005433131681	305	342	48A
0005433233516	305	343	48F
0005434725205	305	344	48E
0005432277788	305	345	48H
0005433233241	305	346	48G
0005433131652	305	347	49C
0005433180939	305	348	49A
0005434551106	305	349	48K
0005434302865	305	350	49D
0005434551102	305	351	49F
0005433289749	305	352	49E
0005434725207	305	353	49K
0005434731160	305	354	49H
0005434725275	305	355	49G
0005434725253	305	356	50C
0005434551103	305	357	50A
0005433233613	305	358	50F
0005433233618	305	359	50E
0005434725241	305	360	50D
0005433180806	305	361	50H
0005433289787	305	362	51D
0005433233541	305	363	50K
0005434725266	305	364	51F
0005434725284	305	365	51G
0005435142456	9872	1	1C
0005435142424	9872	2	1A
0005434724120	9872	3	1G
0005435142371	9872	4	1D
0005434550722	9872	5	2A
0005433181059	9872	6	1K
0005435142423	9872	7	1H
0005433234058	9872	8	2D
0005433126836	9872	9	2C
0005434724633	9872	10	2H
0005433234102	9872	11	3A
0005434550752	9872	12	2K
0005434724124	9872	13	3D
0005434724480	9872	14	3K
0005434735633	9872	15	3H
0005434724058	9872	16	4C
0005433234063	9872	17	4A
0005432199235	9872	18	4G
0005434724641	9872	19	4D
0005434724372	9872	20	5A
0005434724370	9872	21	4K
0005433181051	9872	22	5C
0005433234104	9872	23	5H
0005434550657	9872	24	5G
0005434550497	9872	25	5K
0005434724153	9872	26	11D
0005434550750	9872	27	11C
0005433234069	9872	28	11F
0005434723981	9872	29	11E
0005434724212	9872	30	11K
0005434724356	9872	31	11H
0005433234110	9872	32	11G
0005434550662	9872	33	12C
0005434724373	9872	34	12A
0005434724534	9872	35	12D
0005434724735	9872	36	12G
0005434550601	9872	37	12F
0005435142390	9872	38	12K
0005434724583	9872	39	12H
0005432199233	9872	40	13D
0005433234080	9872	41	13C
0005435142434	9872	42	13A
0005434724460	9872	43	13F
0005433234109	9872	44	13H
0005434550286	9872	45	13K
0005433234077	9872	46	14E
0005433113531	9872	47	14D
0005433234105	9872	48	14G
0005433289829	9872	49	14F
0005433234068	9872	50	14H
0005434724001	9872	51	15D
0005435142375	9872	52	15C
0005434723902	9872	53	15A
0005433234056	9872	54	14K
0005434550669	9872	55	15E
0005433129266	9872	56	15H
0005433289833	9872	57	15G
0005434723641	9872	58	15F
0005434724187	9872	59	15K
0005435142396	9872	60	16D
0005433234099	9872	61	16A
0005434302431	9872	62	16G
0005434724516	9872	63	16F
0005434724210	9872	64	16E
0005434724750	9872	65	16H
0005434724159	9872	66	17A
0005434724371	9872	67	17E
0005434724715	9872	68	17G
0005434550582	9872	69	17K
0005434723857	9872	70	17H
0005434032017	9872	71	18C
0005434724017	9872	72	18B
0005434724560	9872	73	18A
0005434724918	9872	74	18E
0005434723776	9872	75	18G
0005433234067	9872	76	18F
0005433234085	9872	77	18J
0005433181061	9872	78	19B
0005433181044	9872	79	19A
0005433234100	9872	80	18K
0005433234081	9872	81	19C
0005434723979	9872	82	19F
0005434724394	9872	83	19H
0005434724410	9872	84	19G
0005434550426	9872	85	20A
0005434724529	9872	86	19K
0005433234050	9872	87	19J
0005432199236	9872	88	20C
0005434724763	9872	89	20B
0005433234055	9872	90	20E
0005434724677	9872	91	20G
0005434550595	9872	92	20F
0005434550490	9872	93	20K
0005434724018	9872	94	20J
0005433234053	9872	95	21B
0005433234048	9872	96	21A
0005434550673	9872	97	21D
0005434723817	9872	98	21C
0005434723962	9872	99	21F
0005434723918	9872	100	21E
0005434550607	9872	101	21H
0005433234062	9872	102	21G
0005433181037	9872	103	22A
0005434550608	9872	104	22C
0005434032016	9872	105	22B
0005433181047	9872	106	22F
0005434724243	9872	107	22E
0005434724188	9872	108	22K
0005433181054	9872	109	23B
0005434550455	9872	110	23A
0005435142419	9872	111	23E
0005435142349	9872	112	23D
0005434550574	9872	113	23C
0005433234052	9872	114	23F
0005435142383	9872	115	23G
0005434723773	9872	116	24D
0005433126835	9872	117	23K
0005434723938	9872	118	24F
0005433129267	9872	119	24E
0005434550552	9872	120	25B
0005432199230	9872	121	25A
0005433234071	9872	122	25C
0005434724917	9872	123	25F
0005434550597	9872	124	25E
0005433234101	9872	125	25D
0005433181052	9872	126	25G
0005434724154	9872	127	26A
0005434724121	9872	128	25K
0005434731140	9872	129	25J
0005434550719	9872	130	26C
0005434550721	9872	131	26B
0005433181058	9872	132	26E
0005434550465	9872	133	26D
0005432199232	9872	134	26G
0005435142418	9872	135	26F
0005434724471	9872	136	26K
0005435142398	9872	137	26J
0005434724485	9872	138	26H
0005434724080	9872	139	27B
0005434735623	9872	140	27A
0005433234087	9872	141	27D
0005434724085	9872	142	27C
0005434550521	9872	143	27F
0005434550720	9872	144	27E
0005434550626	9872	145	27G
0005434723861	9872	146	27K
0005434724244	9872	147	27J
0005433234082	9872	148	28B
0005434724151	9872	149	28A
0005434723980	9872	150	28E
0005434723862	9872	151	28D
0005434735608	9872	152	28C
0005434723915	9872	153	28G
0005433234108	9872	154	28F
0005433181056	9872	155	28H
0005434724242	9872	156	29A
0005433181045	9872	157	28K
0005434724451	9872	158	29D
0005434723881	9872	159	29C
0005434725027	9872	160	29B
0005434724143	9872	161	29F
0005434550801	9872	162	29H
0005433234093	9872	163	29G
0005434723882	9872	164	29K
0005434550671	9872	165	29J
0005433181041	9872	166	30C
0005434550751	9872	167	30D
0005433234106	9872	168	30G
0005434723324	9872	169	30F
0005434724496	9872	170	30K
0005433234096	9872	171	30H
0005435142395	9872	172	31B
0005434735634	9872	173	31A
0005434724635	9872	174	31D
0005433234060	9872	175	31C
0005434724185	9872	176	31F
0005434724000	9872	177	31E
0005433234094	9872	178	31H
0005433234059	9872	179	31G
0005433181055	9872	180	32A
0005434735611	9872	181	31K
0005434724444	9872	182	32C
0005433234072	9872	183	32B
0005433181043	9872	184	32E
0005434725026	9872	185	32D
0005434723978	9872	186	32G
0005434550716	9872	187	32F
0005433289834	9872	188	32K
0005435142451	9872	189	32J
0005433181053	9872	190	32H
0005434723869	9872	191	33A
0005434724045	9872	192	33C
0005433289831	9872	193	33G
0005434723856	9872	194	33F
0005435142350	9872	195	33E
0005435142391	9872	196	33H
0005434724287	9872	197	33K
0005433234089	9872	198	33J
0005433113530	9872	199	34C
0005434723879	9872	200	34B
0005433234047	9872	201	34A
0005433181040	9872	202	34E
0005434550633	9872	203	34D
0005434550287	9872	204	34G
0005434724046	9872	205	34F
0005434724183	9872	206	34J
0005434550476	9872	207	34H
0005434723772	9872	208	35B
0005433234049	9872	209	35A
0005434724224	9872	210	34K
0005434735609	9872	211	35D
0005433113532	9872	212	35F
0005434724561	9872	213	35E
0005433129264	9872	214	35J
0005434550756	9872	215	35H
0005434724640	9872	216	35G
0005434724919	9872	217	36A
0005433234107	9872	218	35K
0005433181038	9872	219	36C
0005433289828	9872	220	36B
0005434032018	9872	221	36F
0005435142376	9872	222	36E
0005433234066	9872	223	36D
0005434724083	9872	224	36H
0005433234064	9872	225	36K
0005434723841	9872	226	36J
0005434724355	9872	227	37B
0005434723713	9872	228	37A
0005434724291	9872	229	37E
0005433181042	9872	230	37D
0005434550464	9872	231	37F
0005434550674	9872	232	37J
0005434550538	9872	233	37H
0005433181036	9872	234	37G
0005434724228	9872	235	38A
0005434735610	9872	236	37K
0005435142370	9872	237	38C
0005433766631	9872	238	38J
0005433234075	9872	239	38H
0005434735635	9872	240	39B
0005434724077	9872	241	39A
0005434724184	9872	242	39D
0005433234092	9872	243	39C
0005434550596	9872	244	39F
0005434731121	9872	245	39E
0005433234091	9872	246	39J
0005433766632	9872	247	39H
0005433234073	9872	248	39G
0005434723808	9872	249	40A
0005434550338	9872	250	39K
0005434723901	9872	251	40B
0005433234095	9872	252	40E
0005434550539	9872	253	40D
0005434724301	9872	254	40F
0005434550659	9872	255	40K
0005434550537	9872	256	41B
0005434550536	9872	257	41C
0005433181049	9872	258	41G
0005434032014	9872	259	41F
0005434724481	9872	260	41E
0005433234078	9872	261	41H
0005434724450	9872	262	41K
0005434724125	9872	263	41J
0005434724142	9872	264	42C
0005434550656	9872	265	42B
0005433234086	9872	266	42A
0005433181060	9872	267	42E
0005434550745	9872	268	42H
0005434550625	9872	269	42G
0005434550555	9872	270	42J
0005434731120	9872	271	43B
0005434724309	9872	272	43A
0005434550670	9872	273	42K
0005434724793	9872	274	43C
0005434724250	9872	275	43F
0005434550499	9872	276	43E
0005434724395	9872	277	43D
0005434724411	9872	278	43H
0005433766633	9872	279	43G
0005433234074	9872	280	44A
0005434724279	9872	281	43K
0005433234061	9872	282	43J
0005434724676	9872	283	44C
0005432199231	9872	284	44B
0005434723710	9872	285	44E
0005433234079	9872	286	44D
0005433181048	9872	287	44G
0005432199234	9872	288	44J
0005434550585	9872	289	44H
0005433234054	9872	290	45A
0005434724211	9872	291	44K
0005434550456	9872	292	45D
0005433129265	9872	293	45C
0005433234076	9872	294	45B
0005433234097	9872	295	45F
0005433234088	9872	296	45E
0005433181057	9872	297	45J
0005434731119	9872	298	45H
0005434724160	9872	299	46A
0005433181039	9872	300	45K
0005434724225	9872	301	46C
0005434550496	9872	302	46B
0005434724209	9872	303	46E
0005434550556	9872	304	46D
0005434723880	9872	305	46G
0005433289830	9872	306	46K
0005434723963	9872	307	46J
0005434723868	9872	308	46H
0005433289832	9872	309	47A
0005434550663	9872	310	47D
0005434724054	9872	311	47C
0005435142382	9872	312	47G
0005434724227	9872	313	47F
0005434724086	9872	314	47E
0005433234065	9872	315	48A
0005433766634	9872	316	47K
0005434724189	9872	317	48C
0005434723712	9872	318	48F
0005433234083	9872	319	48E
0005433181046	9872	320	48D
0005434724238	9872	321	48H
0005433234084	9872	322	48G
0005433234057	9872	323	49A
0005433234051	9872	324	48K
0005433234070	9872	325	49D
0005434302410	9872	326	49C
0005434724634	9872	327	49G
0005433234098	9872	328	49F
0005434032015	9872	329	49K
0005434302407	9872	330	50C
0005434735612	9872	331	50A
0005434723870	9872	332	50D
0005433234090	9872	333	50G
0005434550600	9872	334	51D
0005433181050	9872	335	50K
0005434724749	9872	336	50H
0005433234103	9872	337	51F
0005434550754	9872	338	51E
0005434550791	9872	339	51G
0005435212542	7736	1	1G
0005432527697	7736	2	1D
0005432069626	7736	3	1K
0005432428922	7736	4	1H
0005432150176	7736	5	2C
0005434067393	7736	6	2A
0005432527653	7736	7	2H
0005433656628	7736	8	2G
0005434067452	7736	9	2D
0005432527721	7736	10	3A
0005432527772	7736	11	2K
0005434067427	7736	12	3D
0005435212831	7736	13	3C
0005432527673	7736	14	3H
0005432527712	7736	15	3G
0005432527656	7736	16	4C
0005434067422	7736	17	4A
0005435212777	7736	18	3K
0005435213099	7736	19	4G
0005432527726	7736	20	4D
0005432428920	7736	21	4K
0005432428921	7736	22	4H
0005432527703	7736	23	5H
0005435213136	7736	24	5G
0005434067456	7736	25	11A
0005432527757	7736	26	5K
0005435212548	7736	27	11D
0005435212891	7736	28	11C
0005435212766	7736	29	11F
0005432527749	7736	30	11K
0005432527702	7736	31	11H
0005435212790	7736	32	11G
0005432527681	7736	33	12A
0005432527707	7736	34	12E
0005432527775	7736	35	12D
0005432527746	7736	36	12G
0005433656632	7736	37	12K
0005435212880	7736	38	12H
0005435213140	7736	39	13C
0005432069621	7736	40	13A
0005432527738	7736	41	13F
0005434067390	7736	42	13E
0005432535822	7736	43	13D
0005432527668	7736	44	13H
0005435212665	7736	45	13G
0005434067445	7736	46	14A
0005435213141	7736	47	13K
0005435212681	7736	48	14D
0005432527666	7736	49	14C
0005432527685	7736	50	14E
0005433656639	7736	51	14K
0005432527737	7736	52	14H
0005434067391	7736	53	15D
0005435212995	7736	54	15C
0005432527760	7736	55	15A
0005432527724	7736	56	15E
0005432527670	7736	57	15H
0005432527722	7736	58	15F
0005432527682	7736	59	16A
0005432527751	7736	60	15K
0005434067453	7736	61	16F
0005432150175	7736	62	16E
0005434067409	7736	63	16H
0005435212827	7736	64	16K
0005432527657	7736	65	17E
0005432527701	7736	66	17D
0005435212650	7736	67	17C
0005434067446	7736	68	17H
0005432527674	7736	69	17G
0005434067394	7736	70	17F
0005434067385	7736	71	17K
0005432527654	7736	72	18C
0005432527718	7736	73	18B
0005434067431	7736	74	18A
0005435212627	7736	75	18E
0005434067403	7736	76	18D
0005434067395	7736	77	18G
0005435212884	7736	78	18F
0005435213142	7736	79	18H
0005435212890	7736	80	19A
0005435212892	7736	81	19D
0005432527736	7736	82	19C
0005434067440	7736	83	19E
0005435212745	7736	84	19J
0005435212989	7736	85	19H
0005435630929	7736	86	19G
0005432527731	7736	87	20A
0005435212646	7736	88	19K
0005434067388	7736	89	20B
0005434067420	7736	90	20D
0005432527658	7736	91	20C
0005434067402	7736	92	20G
0005432527767	7736	93	20F
0005434067411	7736	94	20K
0005432527747	7736	95	20J
0005435212994	7736	96	20H
0005432527678	7736	97	21B
0005432069624	7736	98	21A
0005434067386	7736	99	21D
0005432527742	7736	100	21C
0005435212943	7736	101	21F
0005435213074	7736	102	21E
0005435212869	7736	103	21H
0005435212622	7736	104	21G
0005432069620	7736	105	22A
0005432527652	7736	106	21K
0005435212680	7736	107	22C
0005435212744	7736	108	22B
0005432527665	7736	109	22D
0005432527713	7736	110	22G
0005434067430	7736	111	22F
0005435212841	7736	112	22K
0005432527693	7736	113	22J
0005432527686	7736	114	22H
0005432527773	7736	115	23D
0005435212747	7736	116	23G
0005434067416	7736	117	23F
0005432150179	7736	118	23E
0005434067438	7736	119	23H
0005434067414	7736	120	24D
0005432527663	7736	121	23K
0005432527704	7736	122	24G
0005432527744	7736	123	24F
0005432069627	7736	124	24E
0005434067396	7736	125	25D
0005432150177	7736	126	25C
0005435212560	7736	127	25B
0005435212686	7736	128	25F
0005432527672	7736	129	25H
0005435212832	7736	130	25G
0005435212872	7736	131	26A
0005432527752	7736	132	25K
0005432527664	7736	133	26B
0005432527679	7736	134	26E
0005432527732	7736	135	26D
0005435212559	7736	136	26C
0005434067454	7736	137	26G
0005432069623	7736	138	26J
0005434067389	7736	139	26H
0005434067417	7736	140	27A
0005434067400	7736	141	27C
0005435212746	7736	142	27B
0005432527761	7736	143	27F
0005432527766	7736	144	27E
0005434067401	7736	145	27D
0005434067433	7736	146	27J
0005432527745	7736	147	27H
0005432069619	7736	148	27G
0005435212718	7736	149	28A
0005432527694	7736	150	27K
0005435212767	7736	151	28C
0005432527776	7736	152	28B
0005432527683	7736	153	28E
0005434067423	7736	154	28D
0005434067455	7736	155	28G
0005435212729	7736	156	28F
0005432527763	7736	157	28K
0005435212687	7736	158	28J
0005432535824	7736	159	28H
0005435213137	7736	160	29A
0005432527669	7736	161	29D
0005434067428	7736	162	29E
0005432150180	7736	163	29H
0005435212867	7736	164	29G
0005435212647	7736	165	30A
0005434067441	7736	166	29K
0005432527692	7736	167	29J
0005434067387	7736	168	30C
0005434067399	7736	169	30E
0005434067442	7736	170	30D
0005432527730	7736	171	30G
0005432527677	7736	172	30J
0005432527774	7736	173	31A
0005432527675	7736	174	30K
0005432069630	7736	175	31C
0005435212941	7736	176	31B
0005432527690	7736	177	31E
0005434067397	7736	178	31H
0005434067415	7736	179	31G
0005432527769	7736	180	32A
0005432527700	7736	181	31K
0005435212626	7736	182	32B
0005434067384	7736	183	32E
0005434067398	7736	184	32D
0005432527740	7736	185	32G
0005434067407	7736	186	32F
0005435212731	7736	187	33B
0005434067435	7736	188	33A
0005432527778	7736	189	32K
0005434067444	7736	190	33D
0005432069622	7736	191	33F
0005434067448	7736	192	33E
0005435212612	7736	193	33H
0005432527750	7736	194	33G
0005432527659	7736	195	33K
0005435212540	7736	196	34C
0005432527714	7736	197	34B
0005435212611	7736	198	34A
0005434067425	7736	199	34E
0005434067450	7736	200	34G
0005432527755	7736	201	34F
0005433656641	7736	202	34J
0005432527764	7736	203	34H
0005435212541	7736	204	35B
0005435212768	7736	205	34K
0005434067439	7736	206	35D
0005432150182	7736	207	35C
0005432527691	7736	208	35F
0005432535823	7736	209	35E
0005432527777	7736	210	35J
0005435212346	7736	211	35H
0005432527753	7736	212	35G
0005433656640	7736	213	36A
0005432527706	7736	214	35K
0005434067436	7736	215	36C
0005435212993	7736	216	36B
0005435212781	7736	217	36E
0005432527758	7736	218	36H
0005432069618	7736	219	36G
0005432527698	7736	220	36F
0005434067412	7736	221	36K
0005435212776	7736	222	37B
0005432527688	7736	223	37A
0005432069629	7736	224	37D
0005432527711	7736	225	37C
0005435212902	7736	226	37F
0005432527689	7736	227	37E
0005434067406	7736	228	37H
0005434067426	7736	229	37G
0005432527779	7736	230	38A
0005432527715	7736	231	37K
0005432527705	7736	232	37J
0005432527743	7736	233	38C
0005432527660	7736	234	38B
0005432527770	7736	235	38K
0005432527648	7736	236	38J
0005433656631	7736	237	38H
0005435212830	7736	238	39B
0005432527756	7736	239	39A
0005432527687	7736	240	39D
0005435212825	7736	241	39C
0005433656625	7736	242	39E
0005432527696	7736	243	39J
0005432527710	7736	244	39H
0005434067437	7736	245	39G
0005434067413	7736	246	39K
0005434067410	7736	247	40C
0005435212899	7736	248	40E
0005432533285	7736	249	40D
0005432527680	7736	250	40G
0005432527708	7736	251	40F
0005432527762	7736	252	40K
0005432069625	7736	253	40J
0005435212719	7736	254	41B
0005432527717	7736	255	41A
0005434067405	7736	256	41C
0005434067434	7736	257	41F
0005432527646	7736	258	41H
0005435212679	7736	259	41G
0005434067432	7736	260	41K
0005432527695	7736	261	41J
0005432527650	7736	262	42C
0005432527739	7736	263	42E
0005432527661	7736	264	42D
0005434067429	7736	265	42F
0005432527662	7736	266	42K
0005434067443	7736	267	42J
0005435212606	7736	268	42H
0005435213039	7736	269	43A
0005432527728	7736	270	43B
0005434067408	7736	271	43E
0005435212861	7736	272	43G
0005434067424	7736	273	43K
0005434067447	7736	274	43J
0005432527709	7736	275	44C
0005432527734	7736	276	44B
0005435212828	7736	277	44A
0005432527733	7736	278	44E
0005432527684	7736	279	44G
0005435212871	7736	280	44K
0005432533286	7736	281	44J
0005432527768	7736	282	44H
0005432527699	7736	283	45B
0005432527735	7736	284	45A
0005432527741	7736	285	45D
0005434067392	7736	286	45C
0005435212847	7736	287	45E
0005434067421	7736	288	45H
0005432527754	7736	289	45G
0005432069628	7736	290	45K
0005432527765	7736	291	45J
0005434067418	7736	292	46B
0005432150181	7736	293	46A
0005434067451	7736	294	46E
0005435212879	7736	295	46D
0005432527748	7736	296	46C
0005432527759	7736	297	46G
0005434067404	7736	298	46K
0005432537053	7736	299	46J
0005435212873	7736	300	46H
0005435212608	7736	301	47A
0005432527719	7736	302	47D
0005435212583	7736	303	47G
0005432535825	7736	304	47F
0005435212942	7736	305	47E
0005435212940	7736	306	47K
0005432527649	7736	307	48D
0005434067449	7736	308	48E
0005432527655	7736	309	48H
0005432527727	7736	310	48G
0005432527723	7736	311	48F
0005432527725	7736	312	49A
0005432150178	7736	313	48K
0005432527647	7736	314	49E
0005432527771	7736	315	49D
0005435212990	7736	316	49C
0005435212870	7736	317	49F
0005432527729	7736	318	49K
0005434067419	7736	319	49H
0005432069631	7736	320	49G
0005432535826	7736	321	50C
0005432527651	7736	322	50A
0005432527671	7736	323	50E
0005432527676	7736	324	50G
0005432527716	7736	325	50K
0005432527667	7736	326	50H
0005435212930	7736	327	51F
0005432527720	7736	328	51D
0005435212857	7736	329	51G
0005435319468	5314	1	1A
0005435424297	5314	2	1H
0005434244616	5314	3	1D
0005435613449	5314	4	2A
0005435613414	5314	5	1K
0005432133177	5314	6	2C
0005435613477	5314	7	2G
0005435613474	5314	8	3A
0005435097187	5314	9	2K
0005435424442	5314	10	3D
0005435613413	5314	11	3C
0005435424103	5314	12	3G
0005435613468	5314	13	4A
0005435613475	5314	14	3K
0005435613415	5314	15	4G
0005435423965	5314	16	4D
0005434244610	5314	17	4C
0005435097188	5314	18	4K
0005435613461	5314	19	4H
0005435424190	5314	20	5C
0005435613471	5314	21	5A
0005435613404	5314	22	5H
0005435302158	5314	23	5G
0005435613464	5314	24	5K
0005432133176	5314	25	11D
0005435613450	5314	26	11C
0005435613476	5314	27	11F
0005435613427	5314	28	11H
0005435424381	5314	29	11G
0005434573324	5314	30	12C
0005435424048	5314	31	12A
0005432133179	5314	32	11K
0005434344168	5314	33	12E
0005435613480	5314	34	12D
0005434244722	5314	35	12G
0005435613463	5314	36	12K
0005435613383	5314	37	12H
0005435613434	5314	38	13D
0005435613441	5314	39	13C
0005435319488	5314	40	13A
0005435302165	5314	41	13F
0005432363378	5314	42	13H
0005435613408	5314	43	13G
0005435613444	5314	44	14A
0005435423908	5314	45	14D
0005435613429	5314	46	14C
0005434244774	5314	47	14F
0005434344171	5314	48	14E
0005434344165	5314	49	14K
0005435613406	5314	50	14H
0005435613447	5314	51	15C
0005434344154	5314	52	15F
0005435424050	5314	53	15H
0005435424023	5314	54	15G
0005435490219	5314	55	16A
0005435423917	5314	56	15K
0005435423975	5314	57	16D
0005434344170	5314	58	16C
0005435613392	5314	59	16F
0005435613405	5314	60	16E
0005435097186	5314	61	16H
0005435424010	5314	62	16G
0005434244721	5314	63	17C
0005435613459	5314	64	17A
0005435613412	5314	65	16K
0005435613387	5314	66	17D
0005432133186	5314	67	17G
0005435613440	5314	68	17F
0005434344155	5314	69	17K
0005435613375	5314	70	17H
0005434344158	5314	71	18E
0005435555364	5314	72	18D
0005435097189	5314	73	18G
0005435097182	5314	74	18F
0005435613381	5314	75	18J
0005435613377	5314	76	18H
0005435613430	5314	77	19D
0005434244677	5314	78	19C
0005435613423	5314	79	19B
0005434573327	5314	80	19F
0005435423969	5314	81	19E
0005435424328	5314	82	19H
0005435613410	5314	83	20A
0005435613451	5314	84	19K
0005435491435	5314	85	19J
0005435613388	5314	86	20B
0005435424400	5314	87	20D
0005435424401	5314	88	20C
0005435613397	5314	89	20G
0005435613379	5314	90	20J
0005434344150	5314	91	21B
0005435613438	5314	92	21A
0005435491437	5314	93	20K
0005435424436	5314	94	21D
0005434344167	5314	95	21C
0005435613395	5314	96	21F
0005435613374	5314	97	21E
0005434244617	5314	98	22A
0005434573326	5314	99	21K
0005434244782	5314	100	22C
0005435613439	5314	101	22E
0005434344136	5314	102	22D
0005434244582	5314	103	22G
0005434244656	5314	104	22F
0005435424144	5314	105	22J
0005434573321	5314	106	23B
0005435613445	5314	107	23E
0005434344139	5314	108	23D
0005435613453	5314	109	23C
0005435319505	5314	110	23F
0005434244787	5314	111	23H
0005435613409	5314	112	23K
0005434244680	5314	113	23J
0005435302144	5314	114	24F
0005435613467	5314	115	24E
0005434244786	5314	116	25A
0005434344138	5314	117	24G
0005434244632	5314	118	25C
0005435424334	5314	119	25B
0005435319512	5314	120	25F
0005434244665	5314	121	25E
0005435613478	5314	122	25G
0005435613428	5314	123	25J
0005434244618	5314	124	26B
0005435424008	5314	125	26A
0005435613376	5314	126	26E
0005435380248	5314	127	26C
0005434244590	5314	128	26G
0005435613462	5314	129	26F
0005435613465	5314	130	26K
0005435613472	5314	131	27C
0005435424335	5314	132	27B
0005435424325	5314	133	27F
0005435613470	5314	134	27E
0005435424222	5314	135	27H
0005435490221	5314	136	27J
0005434344142	5314	137	28C
0005434573323	5314	138	28B
0005435423870	5314	139	28A
0005435613452	5314	140	28D
0005435424316	5314	141	28G
0005434344160	5314	142	28F
0005434244646	5314	143	28E
0005435613432	5314	144	28K
0005434244699	5314	145	28J
0005435613385	5314	146	28H
0005435319487	5314	147	29A
0005435424009	5314	148	29D
0005435423976	5314	149	29C
0005435613418	5314	150	29B
0005434344145	5314	151	29F
0005435423954	5314	152	29E
0005435304999	5314	153	30A
0005435319506	5314	154	29K
0005435613400	5314	155	29J
0005434344147	5314	156	30C
0005435319478	5314	157	30B
0005435613378	5314	158	30E
0005435424275	5314	159	30D
0005435424211	5314	160	30G
0005434244611	5314	161	30F
0005435613389	5314	162	30J
0005435424228	5314	163	30H
0005435613479	5314	164	30K
0005435097185	5314	165	31F
0005435424258	5314	166	31E
0005435555363	5314	167	31H
0005434344146	5314	168	31G
0005432840992	5314	169	32A
0005435613442	5314	170	31K
0005434344140	5314	171	32C
0005435424257	5314	172	32G
0005432133181	5314	173	32J
0005432133180	5314	174	32H
0005434344156	5314	175	33A
0005434344166	5314	176	33D
0005435423992	5314	177	33C
0005435613455	5314	178	33B
0005435613473	5314	179	33F
0005435319504	5314	180	33E
0005434244712	5314	181	33H
0005432133184	5314	182	33G
0005435613402	5314	183	34A
0005435097184	5314	184	33K
0005435424049	5314	185	33J
0005435613433	5314	186	34B
0005434244651	5314	187	34E
0005435613399	5314	188	34D
0005432133187	5314	189	34G
0005435613420	5314	190	34F
0005435613443	5314	191	34K
0005435613456	5314	192	34J
0005435613380	5314	193	34H
0005435613396	5314	194	35B
0005435423989	5314	195	35A
0005432047543	5314	196	35D
0005435613436	5314	197	35C
0005435613483	5314	198	35F
0005435613384	5314	199	35E
0005435424152	5314	200	35J
0005434244530	5314	201	35H
0005434244781	5314	202	36A
0005434344137	5314	203	36C
0005435613419	5314	204	36B
0005435613426	5314	205	36E
0005434344162	5314	206	36H
0005434244813	5314	207	36G
0005435424269	5314	208	36F
0005435613437	5314	209	36J
0005435097181	5314	210	37B
0005432133174	5314	211	37A
0005435424052	5314	212	36K
0005434573330	5314	213	37D
0005434344157	5314	214	37C
0005435424279	5314	215	37G
0005434344152	5314	216	37F
0005435424166	5314	217	37E
0005435613454	5314	218	37H
0005435319481	5314	219	37K
0005434573322	5314	220	37J
0005435380249	5314	221	38C
0005435613403	5314	222	38B
0005434344161	5314	223	38H
0005434344169	5314	224	39B
0005435613425	5314	225	39A
0005435613394	5314	226	39C
0005435319474	5314	227	39E
0005432133185	5314	228	39D
0005432133175	5314	229	39H
0005434244559	5314	230	39G
0005435424147	5314	231	40A
0005435613448	5314	232	39K
0005435424283	5314	233	39J
0005433719088	5314	234	40C
0005435613422	5314	235	40E
0005435424148	5314	236	40D
0005434344148	5314	237	40H
0005435613460	5314	238	40G
0005435424054	5314	239	40F
0005435613484	5314	240	40J
0005434344144	5314	241	41A
0005435613373	5314	242	40K
0005435613485	5314	243	41D
0005435304998	5314	244	41C
0005432363367	5314	245	41E
0005434344143	5314	246	41J
0005435490218	5314	247	41H
0005432133183	5314	248	42A
0005435613416	5314	249	41K
0005434344151	5314	250	42C
0005435613398	5314	251	42B
0005435424399	5314	252	42E
0005434573320	5314	253	42D
0005434344163	5314	254	42H
0005435424529	5314	255	42G
0005435613469	5314	256	42F
0005434344164	5314	257	42K
0005435613401	5314	258	42J
0005435613431	5314	259	43A
0005434573328	5314	260	43D
0005435097183	5314	261	43C
0005435613386	5314	262	43B
0005435613435	5314	263	43F
0005432133182	5314	264	43E
0005435613407	5314	265	43H
0005435424274	5314	266	43G
0005435613481	5314	267	44A
0005435613482	5314	268	43J
0005434244700	5314	269	44C
0005434344153	5314	270	44E
0005435613446	5314	271	44H
0005435319511	5314	272	44G
0005435613390	5314	273	44F
0005435613411	5314	274	44J
0005434573331	5314	275	45A
0005435424075	5314	276	44K
0005435424191	5314	277	45D
0005434244627	5314	278	45B
0005432363385	5314	279	45F
0005435613393	5314	280	45E
0005434344173	5314	281	45J
0005432047544	5314	282	45H
0005435491438	5314	283	45G
0005435424053	5314	284	46B
0005435613421	5314	285	46E
0005434344141	5314	286	46D
0005434573318	5314	287	46G
0005434573325	5314	288	46K
0005434344159	5314	289	46J
0005435613417	5314	290	46H
0005435423893	5314	291	47A
0005435490220	5314	292	47E
0005435613458	5314	293	47D
0005434244503	5314	294	47C
0005435424076	5314	295	47K
0005435613382	5314	296	47H
0005435613486	5314	297	48D
0005435491436	5314	298	48C
0005435424333	5314	299	48E
0005434344172	5314	300	48G
0005435424022	5314	301	48F
0005435613391	5314	302	49A
0005435424324	5314	303	48K
0005435613466	5314	304	49E
0005435613457	5314	305	49K
0005435424074	5314	306	49G
0005434244570	5314	307	50C
0005435423795	5314	308	50A
0005434344149	5314	309	50F
0005432133178	5314	310	50E
0005434573319	5314	311	50D
0005435302166	5314	312	50G
0005435613424	5314	313	50K
0005435424233	5314	314	50H
0005435424530	5314	315	51F
0005434573329	5314	316	51E
0005435424047	5314	317	51D
0005435380268	5314	318	51G
0005435319551	10916	1	1C
0005434244911	10916	2	1A
0005434343704	10916	3	1G
0005435097071	10916	4	1D
0005435611978	10916	5	2A
0005435612476	10916	6	1K
0005435424701	10916	7	1H
0005435612544	10916	8	2D
0005434244917	10916	9	2C
0005435612770	10916	10	2H
0005435611818	10916	11	2G
0005435319553	10916	12	3A
0005434343887	10916	13	2K
0005435424691	10916	14	3D
0005435612501	10916	15	3C
0005435612638	10916	16	3K
0005434343719	10916	17	3H
0005435424680	10916	18	4C
0005432363411	10916	19	4A
0005434343735	10916	20	4G
0005435424696	10916	21	4D
0005435491421	10916	22	4K
0005434244927	10916	23	4H
0005435424669	10916	24	5D
0005435380281	10916	25	5C
0005435612819	10916	26	5A
0005435555347	10916	27	5H
0005435612619	10916	28	5G
0005435491420	10916	29	11A
0005435611879	10916	30	5K
0005434244914	10916	31	11D
0005434343800	10916	32	11C
0005435612559	10916	33	11G
0005435424670	10916	34	11F
0005435424676	10916	35	11E
0005435424653	10916	36	11H
0005432841009	10916	37	12C
0005434343754	10916	38	12A
0005434573178	10916	39	11K
0005435612765	10916	40	12E
0005434343693	10916	41	12D
0005435612296	10916	42	12F
0005435612590	10916	43	12K
0005435612405	10916	44	13C
0005434244925	10916	45	13A
0005435612589	10916	46	13F
0005435424644	10916	47	13E
0005435042854	10916	48	13D
0005435424650	10916	49	13H
0005432166895	10916	50	13G
0005435612322	10916	51	14A
0005435424675	10916	52	14D
0005435097078	10916	53	14C
0005435424662	10916	54	14F
0005434343662	10916	55	14E
0005435424700	10916	56	14K
0005435612518	10916	57	14G
0005435612626	10916	58	15C
0005435424666	10916	59	15A
0005435380286	10916	60	15D
0005434244908	10916	61	15G
0005435612499	10916	62	15F
0005435042852	10916	63	15K
0005435612630	10916	64	15H
0005435612524	10916	65	16D
0005435424677	10916	66	16C
0005435612602	10916	67	16A
0005435612492	10916	68	16F
0005434244926	10916	69	16E
0005435424633	10916	70	16H
0005435612480	10916	71	16G
0005434244918	10916	72	17A
0005435612274	10916	73	16K
0005435424688	10916	74	17E
0005434343818	10916	75	17C
0005435612675	10916	76	17G
0005434244920	10916	77	17F
0005434343951	10916	78	18A
0005434244923	10916	79	17K
0005435319555	10916	80	18C
0005435612385	10916	81	18B
0005435612721	10916	82	18E
0005435612328	10916	83	18D
0005435424684	10916	84	18H
0005434573192	10916	85	18G
0005434244909	10916	86	18F
0005435612733	10916	87	18J
0005435612452	10916	88	19B
0005435555345	10916	89	18K
0005435612525	10916	90	19D
0005434343848	10916	91	19C
0005435097053	10916	92	19E
0005435424656	10916	93	19H
0005435612449	10916	94	20C
0005435424643	10916	95	20B
0005433719134	10916	96	20A
0005435612732	10916	97	20E
0005435611963	10916	98	20D
0005435424672	10916	99	20G
0005435612751	10916	100	20F
0005435424673	10916	101	20K
0005434244928	10916	102	20J
0005432165025	10916	103	20H
0005435612456	10916	104	21B
0005434343659	10916	105	21A
0005435380283	10916	106	21D
0005435612515	10916	107	21C
0005435612560	10916	108	21F
0005434343738	10916	109	21E
0005435612502	10916	110	21H
0005435491422	10916	111	21G
0005434244922	10916	112	22A
0005432165023	10916	113	21K
0005435424667	10916	114	21J
0005435490192	10916	115	22C
0005434573144	10916	116	22B
0005435612585	10916	117	22E
0005435612382	10916	118	22D
0005435612671	10916	119	22G
0005434573176	10916	120	22F
0005434343846	10916	121	22K
0005435424641	10916	122	23B
0005434573207	10916	123	23A
0005435424651	10916	124	23C
0005435612395	10916	125	23G
0005432166897	10916	126	23F
0005435612812	10916	127	23E
0005435612558	10916	128	23H
0005434343669	10916	129	24D
0005435304146	10916	130	24F
0005435097109	10916	131	24E
0005435305011	10916	132	25B
0005435424652	10916	133	25A
0005435612400	10916	134	24G
0005435424697	10916	135	25D
0005434343694	10916	136	25C
0005435424637	10916	137	25H
0005434343755	10916	138	25G
0005435319556	10916	139	25F
0005435424664	10916	140	26A
0005435424663	10916	141	25K
0005434244919	10916	142	25J
0005435612424	10916	143	26B
0005435424683	10916	144	26E
0005435424659	10916	145	26D
0005432166896	10916	146	26C
0005435424634	10916	147	26G
0005435424661	10916	148	26J
0005435424692	10916	149	26H
0005432165024	10916	150	27B
0005435612203	10916	151	27A
0005434343660	10916	152	27C
0005435612603	10916	153	27E
0005435097064	10916	154	27D
0005434573132	10916	155	27H
0005435319558	10916	156	28A
0005435612500	10916	157	27K
0005435424665	10916	158	27J
0005434343734	10916	159	28C
0005435612047	10916	160	28B
0005435612628	10916	161	28E
0005434343788	10916	162	28D
0005435424682	10916	163	28G
0005432363409	10916	164	28K
0005435424689	10916	165	28J
0005435612579	10916	166	28H
0005435424686	10916	167	29D
0005434573162	10916	168	29C
0005434573131	10916	169	29F
0005435612386	10916	170	29E
0005434244912	10916	171	29H
0005435304147	10916	172	30A
0005434573190	10916	173	29J
0005435612669	10916	174	30B
0005435612684	10916	175	30D
0005434343809	10916	176	30C
0005435611880	10916	177	30G
0005435612361	10916	178	30J
0005435612430	10916	179	30H
0005435097052	10916	180	31A
0005435424648	10916	181	30K
0005434656553	10916	182	31D
0005435612543	10916	183	31C
0005434573177	10916	184	31B
0005435424679	10916	185	31F
0005435612011	10916	186	31E
0005434573186	10916	187	31J
0005435424654	10916	188	31H
0005435612622	10916	189	31G
0005434573189	10916	190	32C
0005434573231	10916	191	32B
0005434244906	10916	192	32A
0005434343629	10916	193	32E
0005435612567	10916	194	32D
0005435380284	10916	195	32F
0005435612177	10916	196	32K
0005434343787	10916	197	32J
0005432165019	10916	198	32H
0005435424646	10916	199	33B
0005435380282	10916	200	33A
0005435612201	10916	201	33D
0005434573230	10916	202	33C
0005434343839	10916	203	33F
0005432841010	10916	204	33E
0005435424693	10916	205	33J
0005434343982	10916	206	33H
0005435612393	10916	207	33G
0005435612813	10916	208	33K
0005435612398	10916	209	34C
0005435612666	10916	210	34B
0005435612606	10916	211	34E
0005435612529	10916	212	34D
0005435612655	10916	213	34G
0005435612516	10916	214	34F
0005434244907	10916	215	34K
0005434343749	10916	216	34J
0005435319554	10916	217	34H
0005434244916	10916	218	35A
0005434244931	10916	219	35D
0005435612627	10916	220	35C
0005435380285	10916	221	35G
0005435612459	10916	222	35F
0005435612336	10916	223	35E
0005435424636	10916	224	35J
0005435612307	10916	225	35H
0005435612629	10916	226	36A
0005435424658	10916	227	35K
0005435612454	10916	228	36C
0005435319550	10916	229	36E
0005435612514	10916	230	36G
0005435612256	10916	231	36J
0005434244915	10916	232	36H
0005435612388	10916	233	37B
0005434343849	10916	234	37A
0005435612587	10916	235	37E
0005435424674	10916	236	37D
0005435319557	10916	237	37G
0005435424681	10916	238	37F
0005434244913	10916	239	37H
0005435424635	10916	240	37K
0005435612048	10916	241	38C
0005435612569	10916	242	38B
0005434573197	10916	243	38J
0005435380287	10916	244	38H
0005432165022	10916	245	39B
0005435424698	10916	246	39A
0005434244910	10916	247	38K
0005435611878	10916	248	39F
0005434656554	10916	249	39J
0005435612672	10916	250	39H
0005435097070	10916	251	39G
0005435305010	10916	252	39K
0005435612202	10916	253	40C
0005435424685	10916	254	40B
0005435612253	10916	255	40G
0005435042855	10916	256	40F
0005435424657	10916	257	40J
0005435612321	10916	258	41B
0005434244929	10916	259	41A
0005435424647	10916	260	40K
0005432363410	10916	261	41D
0005434343845	10916	262	41C
0005434343983	10916	263	41F
0005435490181	10916	264	41E
0005435612216	10916	265	41H
0005434244921	10916	266	41G
0005435424687	10916	267	41J
0005433719135	10916	268	42C
0005434573188	10916	269	42B
0005435424690	10916	270	42A
0005435612578	10916	271	42E
0005435612257	10916	272	42D
0005435612667	10916	273	42G
0005435424699	10916	274	42F
0005435612654	10916	275	42J
0005435612458	10916	276	43B
0005434573191	10916	277	43A
0005435612191	10916	278	42K
0005435612479	10916	279	43D
0005434244930	10916	280	43C
0005435612485	10916	281	43E
0005434244932	10916	282	43H
0005434343952	10916	283	43G
0005435612557	10916	284	43J
0005435319552	10916	285	44C
0005435424645	10916	286	44B
0005435555346	10916	287	44A
0005432166894	10916	288	44E
0005434343718	10916	289	44D
0005435612453	10916	290	44F
0005435612158	10916	291	44J
0005435424695	10916	292	45A
0005434656552	10916	293	44K
0005435611962	10916	294	45D
0005435612513	10916	295	45C
0005435424649	10916	296	45B
0005435424668	10916	297	45F
0005432166893	10916	298	45E
0005435612512	10916	299	45H
0005435612637	10916	300	45G
0005434343652	10916	301	46A
0005434343864	10916	302	45K
0005435612377	10916	303	45J
0005435612752	10916	304	46B
0005435042853	10916	305	46E
0005435612043	10916	306	46C
0005435424671	10916	307	46G
0005434573216	10916	308	46J
0005434343863	10916	309	46H
0005434343870	10916	310	47A
0005435612690	10916	311	46K
0005435424642	10916	312	47E
0005435612699	10916	313	47D
0005435424660	10916	314	47C
0005435612604	10916	315	47F
0005434343871	10916	316	47K
0005435424702	10916	317	47H
0005435612650	10916	318	48C
0005435424694	10916	319	48A
0005434343677	10916	320	48F
0005435612745	10916	321	48E
0005435304145	10916	322	48H
0005435612252	10916	323	48G
0005435612387	10916	324	49A
0005435424678	10916	325	48K
0005434244933	10916	326	49D
0005432165018	10916	327	49G
0005434573179	10916	328	49F
0005435424640	10916	329	49E
0005435612615	10916	330	49K
0005435424639	10916	331	49H
0005434244934	10916	332	50C
0005435612722	10916	333	50F
0005435424638	10916	334	50E
0005434343739	10916	335	50D
0005432165020	10916	336	50H
0005435611909	10916	337	50G
0005432165021	10916	338	51D
0005434244924	10916	339	50K
0005435424655	10916	340	51F
0005435612477	10916	341	51E
0005435612561	10916	342	51G
0005432459263	3349	1	1A
0005432181675	3349	2	1D
0005432459335	3349	3	1C
0005433507155	3349	4	2A
0005433507151	3349	5	1F
0005432459209	3349	6	2C
0005432181663	3349	7	2F
0005433633745	3349	8	2D
0005433805302	3349	9	3A
0005432459435	3349	10	3C
0005433633749	3349	11	3D
0005432459208	3349	12	4A
0005432459373	3349	13	3F
0005433805320	3349	14	4C
0005433633738	3349	15	4F
0005433633762	3349	16	4D
0005433805310	3349	17	5A
0005433805289	3349	18	5C
0005433633758	3349	19	5D
0005432459119	3349	20	6A
0005433507145	3349	21	5F
0005432459368	3349	22	6C
0005433633752	3349	23	6D
0005432459372	3349	24	7A
0005433633754	3349	25	7C
0005432181672	3349	26	7D
0005433805291	3349	27	8A
0005432459210	3349	28	8B
0005433805288	3349	29	8D
0005432181680	3349	30	8C
0005433507147	3349	31	8F
0005433633739	3349	32	8E
0005433633747	3349	33	9A
0005432459125	3349	34	9B
0005433633742	3349	35	9C
0005432459190	3349	36	9E
0005433633763	3349	37	9D
0005433805300	3349	38	9F
0005432181669	3349	39	10A
0005432459191	3349	40	10B
0005432459161	3349	41	10D
0005432459290	3349	42	10C
0005433633770	3349	43	10E
0005433805307	3349	44	10F
0005432459380	3349	45	11A
0005432181681	3349	46	11C
0005433633743	3349	47	11B
0005432459124	3349	48	11D
0005432459072	3349	49	11E
0005432181665	3349	50	12A
0005432459308	3349	51	11F
0005432459171	3349	52	12C
0005433633755	3349	53	12E
0005433805304	3349	54	12D
0005433633766	3349	55	12F
0005432459374	3349	56	13A
0005433805297	3349	57	13C
0005433805290	3349	58	13B
0005433805308	3349	59	13E
0005433805325	3349	60	13F
0005433633748	3349	61	14B
0005433805292	3349	62	14A
0005433633760	3349	63	14C
0005433805296	3349	64	14D
0005433633744	3349	65	14F
0005433805305	3349	66	14E
0005433507146	3349	67	15A
0005432459253	3349	68	15C
0005432459299	3349	69	15B
0005433805294	3349	70	15D
0005432459145	3349	71	15E
0005432459340	3349	72	16A
0005432181678	3349	73	15F
0005433805309	3349	74	16B
0005433805298	3349	75	16C
0005432181670	3349	76	16E
0005433805321	3349	77	16D
0005433633768	3349	78	16F
0005432181662	3349	79	17B
0005432459262	3349	80	17A
0005433805319	3349	81	17C
0005433805318	3349	82	17D
0005432459126	3349	83	17E
0005432459309	3349	84	18A
0005433633761	3349	85	17F
0005433507153	3349	86	18B
0005432459254	3349	87	18C
0005433805299	3349	88	18D
0005433633737	3349	89	18F
0005433633757	3349	90	18E
0005433507156	3349	91	19B
0005432459496	3349	92	19D
0005433633750	3349	93	19C
0005433507154	3349	94	19E
0005433507148	3349	95	20A
0005433633741	3349	96	20C
0005432181682	3349	97	20B
0005433805315	3349	98	20D
0005432459198	3349	99	20F
0005433805306	3349	100	20E
0005432181677	3349	101	21A
0005433633769	3349	102	21C
0005433633765	3349	103	21B
0005432459465	3349	104	21D
0005433805326	3349	105	21E
0005433805313	3349	106	22A
0005432459484	3349	107	21F
0005433805293	3349	108	22B
0005433805316	3349	109	22C
0005433633756	3349	110	22E
0005432181667	3349	111	22D
0005433805311	3349	112	22F
0005433507144	3349	113	23B
0005432459014	3349	114	23A
0005433633767	3349	115	23D
0005432459470	3349	116	23C
0005432181668	3349	117	23F
0005432459381	3349	118	23E
0005433507150	3349	119	24A
0005433805317	3349	120	24B
0005432459329	3349	121	24C
0005432181673	3349	122	24D
0005432459318	3349	123	24F
0005432459162	3349	124	24E
0005432459341	3349	125	25A
0005433633751	3349	126	25C
0005433805327	3349	127	25B
0005432459436	3349	128	25D
0005432181664	3349	129	25E
0005432459289	3349	130	26A
0005432459325	3349	131	26B
0005433633740	3349	132	26D
0005432181683	3349	133	26C
0005433507152	3349	134	26F
0005433805312	3349	135	26E
0005433507142	3349	136	27B
0005433805287	3349	137	27A
0005432459331	3349	138	27C
0005432181674	3349	139	27D
0005433805303	3349	140	27E
0005432181679	3349	141	27F
0005433507141	3349	142	28B
0005432459326	3349	143	28A
0005432181671	3349	144	28D
0005432181666	3349	145	28C
0005433507149	3349	146	28E
0005432459278	3349	147	29A
0005433633746	3349	148	28F
0005432459291	3349	149	29C
0005432459267	3349	150	29E
0005433633764	3349	151	29D
0005433805323	3349	152	30A
0005433633753	3349	153	29F
0005433805314	3349	154	30B
0005432181676	3349	155	30C
0005433805301	3349	156	30E
0005432459277	3349	157	30D
0005433805286	3349	158	31A
0005433805322	3349	159	30F
0005433507143	3349	160	31C
0005433805295	3349	161	31B
0005433805324	3349	162	31D
0005433633759	3349	163	31F
0005432459469	3349	164	31E
0005435884708	3348	1	2A
0005435884904	3348	2	2C
0005435884882	3348	3	3C
0005435884649	3348	4	5F
0005435884787	3348	5	6D
0005435884818	3348	6	7C
0005435884897	3348	7	8A
0005435884951	3348	8	8B
0005435884828	3348	9	8E
0005435884689	3348	10	8D
0005435884798	3348	11	9B
0005435884990	3348	12	9A
0005435884797	3348	13	9C
0005435884616	3348	14	9F
0005435884759	3348	15	10B
0005435884889	3348	16	10C
0005435884617	3348	17	10F
0005435884826	3348	18	11A
0005435884808	3348	19	11B
0005435884958	3348	20	11D
0005435884751	3348	21	12C
0005435884629	3348	22	12E
0005435884756	3348	23	13C
0005435884676	3348	24	14B
0005435884832	3348	25	14D
0005435884707	3348	26	15C
0005435884847	3348	27	15E
0005435884711	3348	28	15D
0005435884491	3348	29	16A
0005435884712	3348	30	15F
0005435884807	3348	31	16C
0005435884631	3348	32	16D
0005435884768	3348	33	17C
0005435884824	3348	34	18A
0005435884648	3348	35	18D
0005435884538	3348	36	20B
0005435884680	3348	37	20D
0005435884772	3348	38	20E
0005435884905	3348	39	21E
0005435884618	3348	40	22D
0005435884767	3348	41	22C
0005435884856	3348	42	23B
0005435884825	3348	43	23E
0005435884773	3348	44	24A
0005435884662	3348	45	23F
0005435884737	3348	46	25B
0005435884720	3348	47	25E
0005435884642	3348	48	25F
0005435884752	3348	49	26B
0005435884855	3348	50	26D
0005435884714	3348	51	27B
0005435884641	3348	52	28E
0005435884679	3348	53	28F
0005435884786	3348	54	29A
0005435884771	3348	55	29E
0005435884843	3348	56	29F
0005435884755	3348	57	30B
0005435884490	3348	58	30D
0005435884735	3348	59	31E
0005435885180	8201	1	1A
0005432459792	8201	2	1C
0005432459761	8201	3	1F
0005432459769	8201	4	1D
0005433506996	8201	5	2A
0005435885179	8201	6	2C
0005432459801	8201	7	2F
0005435885149	8201	8	2D
0005433507019	8201	9	3A
0005432459762	8201	10	3D
0005435885135	8201	11	3C
0005435885159	8201	12	4A
0005432042681	8201	13	3F
0005433507045	8201	14	4C
0005435885174	8201	15	4D
0005435885137	8201	16	5C
0005432459775	8201	17	5D
0005434312317	8201	18	6A
0005432459772	8201	19	5F
0005432459791	8201	20	6C
0005432459770	8201	21	6F
0005435885143	8201	22	7A
0005435885126	8201	23	7C
0005435885131	8201	24	7F
0005432459800	8201	25	8A
0005435885169	8201	26	8D
0005432459781	8201	27	8C
0005432459764	8201	28	8E
0005432459776	8201	29	8F
0005432459788	8201	30	9B
0005435885152	8201	31	9A
0005432459768	8201	32	9C
0005435885171	8201	33	9F
0005432459763	8201	34	10B
0005435885162	8201	35	10D
0005432459786	8201	36	10C
0005432042694	8201	37	10E
0005432042689	8201	38	10F
0005435885168	8201	39	11B
0005433507037	8201	40	11C
0005435885170	8201	41	11D
0005432459787	8201	42	11E
0005435885142	8201	43	12A
0005432459773	8201	44	11F
0005432042683	8201	45	12B
0005435885155	8201	46	12D
0005432459783	8201	47	12E
0005432042686	8201	48	12F
0005435885146	8201	49	13B
0005432459759	8201	50	13A
0005435885141	8201	51	13C
0005435885140	8201	52	13F
0005435885127	8201	53	14D
0005435885175	8201	54	14C
0005432459798	8201	55	14E
0005432459810	8201	56	15A
0005432459790	8201	57	14F
0005435885164	8201	58	15B
0005435885129	8201	59	15D
0005432459808	8201	60	15E
0005433506998	8201	61	16A
0005432459799	8201	62	15F
0005432042692	8201	63	16B
0005435885157	8201	64	16D
0005433506977	8201	65	16C
0005435885133	8201	66	16E
0005432459802	8201	67	17A
0005435885176	8201	68	16F
0005435885167	8201	69	17B
0005432459805	8201	70	17C
0005432459782	8201	71	17D
0005435885156	8201	72	17F
0005435885145	8201	73	17E
0005435885177	8201	74	18A
0005432459774	8201	75	18B
0005435885148	8201	76	18D
0005432042690	8201	77	18E
0005435885139	8201	78	18F
0005432042691	8201	79	19B
0005433506994	8201	80	19D
0005432459785	8201	81	19C
0005435885150	8201	82	19E
0005432042688	8201	83	20B
0005432459771	8201	84	20A
0005432459780	8201	85	20E
0005432459767	8201	86	20D
0005433506997	8201	87	21B
0005432459806	8201	88	21A
0005435885130	8201	89	21C
0005433507035	8201	90	21D
0005433506958	8201	91	21E
0005432459793	8201	92	22A
0005435885132	8201	93	21F
0005432459778	8201	94	22D
0005435885173	8201	95	22E
0005432459795	8201	96	22F
0005435885181	8201	97	23B
0005435885134	8201	98	23A
0005432459794	8201	99	23C
0005435885165	8201	100	23D
0005433506944	8201	101	23E
0005432042682	8201	102	24A
0005432042684	8201	103	23F
0005434312316	8201	104	24B
0005432459809	8201	105	24D
0005432042687	8201	106	24C
0005432042685	8201	107	24E
0005435885182	8201	108	25B
0005435885158	8201	109	25C
0005432459766	8201	110	25D
0005432459760	8201	111	25F
0005435885128	8201	112	25E
0005435885153	8201	113	26A
0005432459758	8201	114	26B
0005432459796	8201	115	26D
0005435885136	8201	116	26E
0005435885138	8201	117	27A
0005432459784	8201	118	27B
0005432459803	8201	119	27F
0005432459811	8201	120	27E
0005435885172	8201	121	28A
0005435885178	8201	122	28B
0005432459777	8201	123	28D
0005432042693	8201	124	28C
0005435885144	8201	125	28F
0005435885161	8201	126	28E
0005435885163	8201	127	29B
0005433507020	8201	128	29C
0005432459807	8201	129	29D
0005435885160	8201	130	29F
0005433506949	8201	131	29E
0005432459804	8201	132	30B
0005432459765	8201	133	30A
0005435885147	8201	134	30C
0005432459812	8201	135	30E
0005435885154	8201	136	30D
0005435885151	8201	137	30F
0005432459797	8201	138	31A
0005432459789	8201	139	31C
0005435885166	8201	140	31B
0005432459779	8201	141	31F
0005433805001	8225	1	1A
0005433804926	8225	2	4F
0005433805076	8225	3	4D
0005433633529	8225	4	5A
0005434143702	8225	5	6A
0005433633528	8225	6	6F
0005433804976	8225	7	7F
0005433633420	8225	8	8C
0005433633483	8225	9	8D
0005433633518	8225	10	9A
0005433633408	8225	11	8F
0005433805071	8225	12	9C
0005433633476	8225	13	9F
0005433805106	8225	14	10A
0005433633393	8225	15	11E
0005433633395	8225	16	12C
0005433633509	8225	17	12D
0005433805032	8225	18	12F
0005433805070	8225	19	13D
0005433804939	8225	20	14C
0005433633409	8225	21	14F
0005433633403	8225	22	15C
0005433805017	8225	23	15B
0005433633410	8225	24	15D
0005433805086	8225	25	16D
0005433804978	8225	26	17C
0005433633404	8225	27	17E
0005433633519	8225	28	18A
0005433633368	8225	29	18C
0005433804967	8225	30	18E
0005433804977	8225	31	18F
0005433805099	8225	32	19C
0005433805047	8225	33	20C
0005433633628	8225	34	20F
0005433633358	8225	35	21A
0005433805069	8225	36	21D
0005433633390	8225	37	21F
0005433633380	8225	38	22B
0005433633341	8225	39	22A
0005433633392	8225	40	22C
0005433805016	8225	41	22D
0005433633535	8225	42	22F
0005433633405	8225	43	23D
0005433804965	8225	44	23F
0005433633536	8225	45	24C
0005433633369	8225	46	25D
0005433633355	8225	47	25F
0005433633544	8225	48	26E
0005433804991	8225	49	28B
0005433805013	8225	50	28E
0005433633381	8225	51	28D
0005433633391	8225	52	29A
0005433804927	8225	53	30D
0005433804966	8225	54	30E
0005433633302	8225	55	30F
0005433805012	8225	56	31A
0005433633629	8225	57	31F
0005434183563	8301	1	21F
0005434183553	8301	2	23B
0005434183554	8301	3	26E
0005432383100	4580	1	1A
0005432727909	4580	2	1C
0005432727919	4580	3	1D
0005432383103	4580	4	1F
0005433194855	4580	5	2A
0005433722210	4580	6	2C
0005432383116	4580	7	2D
0005432383119	4580	8	2F
0005432383117	4580	9	3D
0005432383098	4580	10	3F
0005432727918	4580	11	4A
0005432727916	4580	12	4C
0005432383115	4580	13	4D
0005432383102	4580	14	4E
0005433722211	4580	15	4F
0005432383111	4580	16	5A
0005432727911	4580	17	5C
0005433454870	4580	18	5D
0005432383105	4580	19	5E
0005432383114	4580	20	5F
0005433194854	4580	21	6A
0005433453759	4580	22	6D
0005432383110	4580	23	7A
0005433722216	4580	24	7E
0005433722209	4580	25	8A
0005432383123	4580	26	8C
0005433454872	4580	27	8D
0005432383108	4580	28	8E
0005432383127	4580	29	8F
0005432383126	4580	30	9A
0005432383124	4580	31	9C
0005432383097	4580	32	9E
0005432727913	4580	33	10A
0005433194851	4580	34	10C
0005432727921	4580	35	10D
0005432383120	4580	36	10E
0005432727908	4580	37	11C
0005432727917	4580	38	11F
0005432383109	4580	39	12A
0005432727912	4580	40	12C
0005432383112	4580	41	12E
0005433453760	4580	42	12F
0005432727914	4580	43	13A
0005432383128	4580	44	13F
0005432383118	4580	45	14A
0005432383095	4580	46	14F
0005433722212	4580	47	15A
0005432383096	4580	48	15C
0005432383121	4580	49	15D
0005433194852	4580	50	15F
0005433722215	4580	51	16A
0005433194853	4580	52	16F
0005433454871	4580	53	17C
0005432727910	4580	54	17E
0005432383107	4580	55	17F
0005432383106	4580	56	18A
0005432383122	4580	57	18C
0005432383101	4580	58	18D
0005432727920	4580	59	18E
0005433722213	4580	60	19A
0005433722214	4580	61	19C
0005432383125	4580	62	19D
0005432383099	4580	63	19F
0005432383104	4580	64	20C
0005432383113	4580	65	20D
0005432727915	4580	66	20F
0005432382663	30212	1	1C
0005432727763	30212	2	1D
0005432382642	30212	3	1F
0005432382638	30212	4	2C
0005432382732	30212	5	2D
0005432382578	30212	6	3C
0005433722129	30212	7	3F
0005432727785	30212	8	4A
0005433722104	30212	9	4C
0005432382715	30212	10	4D
0005433722126	30212	11	5A
0005433722145	30212	12	5D
0005433722140	30212	13	5E
0005433722142	30212	14	6A
0005432382700	30212	15	6C
0005433722118	30212	16	6D
0005432382801	30212	17	6F
0005432382797	30212	18	7D
0005433194826	30212	19	7F
0005432727779	30212	20	8A
0005432382698	30212	21	8D
0005433722141	30212	22	8E
0005433451587	30212	23	8F
0005433722127	30212	24	9D
0005433722163	30212	25	9E
0005432727737	30212	26	9F
0005432382566	30212	27	10A
0005432727787	30212	28	11D
0005433722125	30212	29	11F
0005432382639	30212	30	12A
0005432727786	30212	31	12C
0005432382664	30212	32	12D
0005432382714	30212	33	12E
0005432382726	30212	34	12F
0005433451600	30212	35	13D
0005432382720	30212	36	13E
0005433194835	30212	37	14A
0005432382690	30212	38	14C
0005432382752	30212	39	14D
0005432382653	30212	40	14F
0005432382753	30212	41	15A
0005432382626	30212	42	15C
0005432382746	30212	43	15F
0005432382565	30212	44	16A
0005432727792	30212	45	16F
0005433722146	30212	46	17A
0005432382760	30212	47	17C
0005433722144	30212	48	17D
0005432382641	30212	49	17E
0005432382691	30212	50	18A
0005432727842	30212	51	18C
0005432382640	30212	52	18D
0005433722119	30212	53	19A
0005433722143	30212	54	19E
0005432382800	30212	55	19F
0005432727835	30212	56	20A
0005432382670	30212	57	20C
0005435540966	1749	1	1C
0005433516872	1749	2	1F
0005435540962	1749	3	2A
0005435529213	1749	4	2C
0005433516871	1749	5	2D
0005435529220	1749	6	2F
0005432925005	1749	7	3A
0005435540970	1749	8	3D
0005433516866	1749	9	4A
0005432924998	1749	10	4C
0005435529217	1749	11	4F
0005435540958	1749	12	5A
0005435540963	1749	13	5C
0005435529221	1749	14	5D
0005435529214	1749	15	5E
0005435540960	1749	16	5F
0005435540969	1749	17	6A
0005435540965	1749	18	6C
0005435540976	1749	19	6D
0005435529233	1749	20	6F
0005435540973	1749	21	7D
0005435529223	1749	22	7E
0005432924992	1749	23	7F
0005433516865	1749	24	8C
0005432924986	1749	25	8D
0005433516870	1749	26	8E
0005432294482	1749	27	8F
0005435540972	1749	28	9D
0005435529227	1749	29	9E
0005435540961	1749	30	9F
0005433516864	1749	31	10A
0005435529231	1749	32	10E
0005435529215	1749	33	10F
0005435529212	1749	34	11C
0005435529216	1749	35	11D
0005435540975	1749	36	11F
0005435540964	1749	37	12C
0005433516874	1749	38	12D
0005432924995	1749	39	12E
0005433516868	1749	40	13E
0005432924997	1749	41	13F
0005435540977	1749	42	14A
0005435529232	1749	43	14C
0005435540971	1749	44	14E
0005433516873	1749	45	14F
0005435529224	1749	46	15A
0005435540974	1749	47	15C
0005432924974	1749	48	15D
0005432924991	1749	49	15E
0005435529225	1749	50	15F
0005435529230	1749	51	16C
0005435540968	1749	52	16D
0005433516867	1749	53	16E
0005435529226	1749	54	16F
0005432294483	1749	55	17A
0005435540957	1749	56	17C
0005435529229	1749	57	17D
0005435540967	1749	58	17E
0005435540956	1749	59	17F
0005432924970	1749	60	18A
0005435529211	1749	61	18C
0005432924985	1749	62	18D
0005435529218	1749	63	18E
0005432924996	1749	64	18F
0005435529228	1749	65	19A
0005435540959	1749	66	19F
0005435540955	1749	67	19E
0005435529219	1749	68	20A
0005433516869	1749	69	20D
0005435529222	1749	70	20E
0005432924987	1749	71	20F
0005435540746	22003	1	1C
0005435540743	22003	2	2A
0005433516807	22003	3	2C
0005432925029	22003	4	2D
0005435540716	22003	5	2F
0005433516813	22003	6	3A
0005432925025	22003	7	3F
0005435540778	22003	8	4A
0005435517733	22003	9	4C
0005435517704	22003	10	4E
0005435517800	22003	11	5A
0005435540708	22003	12	5C
0005435540761	22003	13	5D
0005433516803	22003	14	5F
0005435540797	22003	15	6A
0005435540724	22003	16	6C
0005435540827	22003	17	6F
0005432925027	22003	18	7C
0005435517646	22003	19	7E
0005433516808	22003	20	8A
0005435517647	22003	21	8D
0005435540834	22003	22	9A
0005435540775	22003	23	9C
0005435540670	22003	24	9D
0005433516789	22003	25	9F
0005435517739	22003	26	9E
0005435540725	22003	27	10C
0005433516810	22003	28	10E
0005435540766	22003	29	11E
0005435517705	22003	30	12A
0005435540717	22003	31	12C
0005433516809	22003	32	12F
0005435540709	22003	33	13A
0005433516750	22003	34	13D
0005433516761	22003	35	13E
0005433516744	22003	36	13F
0005435517706	22003	37	14A
0005433516814	22003	38	14D
0005435540776	22003	39	14F
0005433516760	22003	40	15A
0005433516768	22003	41	15C
0005435540755	22003	42	15D
0005435540777	22003	43	15F
0005432925028	22003	44	16C
0005435540762	22003	45	16D
0005435540754	22003	46	16E
0005435517678	22003	47	17A
0005435517747	22003	48	17C
0005435540707	22003	49	18E
0005435517784	22003	50	18F
0005435517632	22003	51	19A
0005433516746	22003	52	19C
0005432925026	22003	53	19D
0005435517754	22003	54	19E
0005435517729	22003	55	19F
0005435540706	22003	56	20C
0005433516788	22003	57	20D
0005435517785	22003	58	20F
0005435252587	7401	1	1A
0005434458762	7401	2	1C
0005434458758	7401	3	1D
0005432838975	7401	4	1F
0005435252505	7401	5	2A
0005432838988	7401	6	2D
0005435252504	7401	7	2F
0005432073386	7401	8	3A
0005432838970	7401	9	3D
0005432838961	7401	10	3F
0005434458754	7401	11	4A
0005435252456	7401	12	4C
0005434458764	7401	13	4E
0005434458769	7401	14	4F
0005432838965	7401	15	5C
0005432838982	7401	16	5E
0005434458768	7401	17	5F
0005432838962	7401	18	6A
0005435252470	7401	19	6C
0005432838985	7401	20	6D
0005434458766	7401	21	6E
0005432838986	7401	22	7A
0005432838981	7401	23	7D
0005432838977	7401	24	7E
0005432073385	7401	25	7F
0005432838980	7401	26	8A
0005432073384	7401	27	8C
0005435252455	7401	28	8D
0005432838964	7401	29	8E
0005432841007	7401	30	8F
0005432838976	7401	31	9D
0005432838987	7401	32	9E
0005434458767	7401	33	9F
0005435252522	7401	34	10A
0005435252506	7401	35	10C
0005435252478	7401	36	10D
0005434664932	7401	37	10E
0005432838972	7401	38	10F
0005432838969	7401	39	11C
0005435252513	7401	40	11D
0005432838984	7401	41	11E
0005434458755	7401	42	11F
0005432838971	7401	43	12A
0005434458770	7401	44	12E
0005432841008	7401	45	12F
0005434458759	7401	46	13A
0005432838978	7401	47	13C
0005435252521	7401	48	13D
0005434458765	7401	49	13E
0005434458761	7401	50	13F
0005432838968	7401	51	14A
0005432838967	7401	52	14C
0005432838974	7401	53	14D
0005434664922	7401	54	14E
0005432838983	7401	55	14F
0005432838966	7401	56	15A
0005434458756	7401	57	15C
0005432838960	7401	58	15D
0005432838989	7401	59	15E
0005434458757	7401	60	15F
0005434458771	7401	61	16A
0005432838979	7401	62	16C
0005432073383	7401	63	16E
0005435252435	7401	64	16F
0005434458773	7401	65	17D
0005434664935	7401	66	17E
0005435252436	7401	67	17F
0005432838973	7401	68	18A
0005432838959	7401	69	18C
0005434458772	7401	70	18E
0005434458753	7401	71	18F
0005432841006	7401	72	19A
0005435491419	7401	73	19C
0005434458763	7401	74	19E
0005434458760	7401	75	19F
0005432073382	7401	76	20A
0005435491415	7401	77	20D
0005432838963	7401	78	20E
0005435252491	7401	79	20F
0005432838567	28940	1	1A
0005434458610	28940	2	1C
0005432838641	28940	3	1D
0005434664954	28940	4	1F
0005434458603	28940	5	2A
0005432838716	28940	6	2C
0005432838684	28940	7	2D
0005434458567	28940	8	2F
0005432838833	28940	9	3D
0005432001019	28940	10	3F
0005432838731	28940	11	4A
0005432838837	28940	12	4C
0005434458614	28940	13	4D
0005432840997	28940	14	4E
0005434458576	28940	15	4F
0005432838566	28940	16	5A
0005432838661	28940	17	5C
0005434458621	28940	18	5D
0005434664955	28940	19	5E
0005435252662	28940	20	5F
0005435252673	28940	21	6A
0005432838829	28940	22	6C
0005435252670	28940	23	6D
0005435252676	28940	24	6E
0005434458639	28940	25	6F
0005432001018	28940	26	7A
0005434458493	28940	27	7C
0005435252663	28940	28	7E
0005432838783	28940	29	7F
0005435252667	28940	30	8A
0005432838841	28940	31	8C
0005432838778	28940	32	8D
0005434458622	28940	33	8E
0005434664956	28940	34	8F
0005432838852	28940	35	9A
0005434458544	28940	36	9C
0005434458648	28940	37	9D
0005434458577	28940	38	9E
0005435252666	28940	39	10A
0005434458554	28940	40	10D
0005434458625	28940	41	11C
0005434458559	28940	42	11D
0005435252660	28940	43	11E
0005432838814	28940	44	11F
0005432838771	28940	45	12D
0005435252675	28940	46	12E
0005435252661	28940	47	12F
0005434458524	28940	48	13A
0005432840998	28940	49	13C
0005432838732	28940	50	13D
0005435252672	28940	51	13F
0005435252664	28940	52	14C
0005434458492	28940	53	14E
0005434458562	28940	54	14F
0005435252671	28940	55	15A
0005432838707	28940	56	15C
0005432838830	28940	57	15D
0005434458514	28940	58	15E
0005434458602	28940	59	15F
0005434458545	28940	60	16A
0005435252669	28940	61	16C
0005435252659	28940	62	16D
0005432838782	28940	63	16E
0005432838607	28940	64	16F
0005432838765	28940	65	17A
0005432838506	28940	66	17C
0005432838792	28940	67	17D
0005435252668	28940	68	17E
0005434458612	28940	69	17F
0005435252674	28940	70	18A
0005434458552	28940	71	18C
0005432838784	28940	72	18E
0005432838664	28940	73	18F
0005434458558	28940	74	19A
0005434458601	28940	75	19C
0005434458613	28940	76	19D
0005434458543	28940	77	19F
0005435491439	28940	78	20A
0005435252665	28940	79	20D
0005432838851	28940	80	20E
0005434458607	28940	81	20F
0005434275976	8794	1	3C
0005434275975	8794	2	5F
0005434275981	8794	3	6D
0005434275973	8794	4	7B
0005435990612	8794	5	8D
0005434275970	8794	6	8F
0005435990609	8794	7	9B
0005434275963	8794	8	10C
0005434275982	8794	9	13C
0005435990611	8794	10	14A
0005435990607	8794	11	15C
0005435990608	8794	12	15E
0005435990606	8794	13	16D
0005434275974	8794	14	19B
0005435990610	8794	15	19D
0005434275994	8794	16	20F
0005435990590	15724	1	3D
0005435990497	15724	2	8F
0005435990584	15724	3	9A
0005434276017	15724	4	9E
0005434276014	15724	5	10E
0005435990522	15724	6	13D
0005435990546	15724	7	14A
0005435990589	15724	8	16C
0005435990547	15724	9	17B
0005435990583	15724	10	17C
0005435990548	15724	11	19A
0005434276015	15724	12	19B
0005435990585	15724	13	20D
0005434276016	15724	14	21C
0005432427138	20625	1	2B
0005432427139	20625	2	7D
0005432427136	20625	3	19A
0005433476872	20625	4	19C
0005432427137	20625	5	20D
0005433476873	20625	6	21C
0005433476888	30861	1	2A
0005433476887	30861	2	4D
0005433476890	30861	3	5D
0005433476889	30861	4	7A
0005433476886	30861	5	18C
0005432427120	30861	6	20A
0005432360285	6399	1	1C
0005432360290	6399	2	1D
0005435176791	6399	3	2A
0005432360287	6399	4	1F
0005435176740	6399	5	2C
0005432360247	6399	6	2D
0005434149609	6399	7	2F
0005432360272	6399	8	3A
0005432360261	6399	9	3D
0005432336007	6399	10	3F
0005435176744	6399	11	4B
0005432363411	6399	12	4A
0005432062215	6399	13	4C
0005432062220	6399	14	4E
0005435176835	6399	15	4D
0005435176818	6399	16	4F
0005432336012	6399	17	5A
0005435176976	6399	18	5C
0005435176852	6399	19	5B
0005432360267	6399	20	5D
0005432363410	6399	21	5E
0005434149625	6399	22	6A
0005435176813	6399	23	6C
0005435176975	6399	24	6D
0005432336009	6399	25	6F
0005432062219	6399	26	6E
0005432360268	6399	27	7A
0005432360273	6399	28	7B
0005432360284	6399	29	7C
0005435490192	6399	30	7D
0005432336006	6399	31	7E
0005435176793	6399	32	8A
0005432360259	6399	33	7F
0005434149610	6399	34	8B
0005432360289	6399	35	8C
0005432360246	6399	36	8E
0005432062217	6399	37	8F
0005435176816	6399	38	9A
0005432360262	6399	39	9B
0005432360257	6399	40	9D
0005432360249	6399	41	9C
0005432336013	6399	42	9E
0005435176838	6399	43	10B
0005435176826	6399	44	10C
0005432360251	6399	45	10E
0005435176885	6399	46	11A
0005432360263	6399	47	11B
0005435176819	6399	48	11C
0005435176840	6399	49	11D
0005432360280	6399	50	11F
0005432336010	6399	51	12A
0005432360269	6399	52	12B
0005435176792	6399	53	12D
0005435176839	6399	54	12C
0005432360283	6399	55	12E
0005432360265	6399	56	12F
0005435176775	6399	57	13B
0005432360291	6399	58	13A
0005434149578	6399	59	13C
0005435176850	6399	60	13D
0005434149579	6399	61	13E
0005432062216	6399	62	13F
0005432360270	6399	63	14B
0005432360288	6399	64	14A
0005432360277	6399	65	14C
0005432360254	6399	66	14D
0005435176824	6399	67	14E
0005435176675	6399	68	14F
0005432360275	6399	69	15A
0005432360276	6399	70	15D
0005432360260	6399	71	15E
0005434149645	6399	72	16A
0005432360264	6399	73	16B
0005432360281	6399	74	16D
0005432360253	6399	75	16C
0005432360256	6399	76	16E
0005432360255	6399	77	16F
0005435176834	6399	78	17B
0005432360278	6399	79	17D
0005435176888	6399	80	17C
0005435176810	6399	81	17F
0005435176960	6399	82	17E
0005432336015	6399	83	18A
0005432360266	6399	84	18B
0005435176911	6399	85	18C
0005432360282	6399	86	18E
0005432062218	6399	87	18D
0005434149646	6399	88	19A
0005432363409	6399	89	19B
0005432336014	6399	90	19C
0005435176794	6399	91	19E
0005435176809	6399	92	19D
0005435490181	6399	93	19F
0005432336011	6399	94	20B
0005435176749	6399	95	20A
0005432336008	6399	96	20C
0005432360286	6399	97	20E
0005432336005	6399	98	21A
0005435176692	6399	99	20F
0005435176769	6399	100	21B
0005435176750	6399	101	21C
0005435176807	6399	102	21D
0005432360250	6399	103	21E
0005432360279	6399	104	22A
0005432360252	6399	105	21F
0005435176739	6399	106	22B
0005432360258	6399	107	22C
0005435176961	6399	108	22D
0005435176770	6399	109	22F
0005432360248	6399	110	22E
0005432360271	6399	111	23A
0005432360292	6399	112	23B
0005435176674	6399	113	23D
0005432360274	6399	114	23E
0005432359729	21000	1	1A
0005435177009	21000	2	1C
0005435177019	21000	3	1D
0005435177033	21000	4	1F
0005432359826	21000	5	2C
0005432335940	21000	6	2A
0005432359801	21000	7	2D
0005432052740	21000	8	2F
0005432359827	21000	9	3A
0005432335941	21000	10	3D
0005432363383	21000	11	3C
0005435177021	21000	12	3F
0005435177028	21000	13	4A
0005432359784	21000	14	4B
0005432359917	21000	15	4E
0005432359709	21000	16	5B
0005432359802	21000	17	5A
0005432335945	21000	18	5E
0005435490224	21000	19	5F
0005432359663	21000	20	6B
0005435177022	21000	21	6A
0005432335916	21000	22	6D
0005432359987	21000	23	6C
0005434149704	21000	24	6F
0005435723041	21000	25	6E
0005434149707	21000	26	7B
0005435177034	21000	27	7A
0005434149701	21000	28	7C
0005435177024	21000	29	7D
0005432359690	21000	30	7E
0005432360025	21000	31	8A
0005432363374	21000	32	7F
0005434149708	21000	33	8B
0005432335873	21000	34	8D
0005432359886	21000	35	8C
0005435177036	21000	36	8E
0005434149705	21000	37	9A
0005435177027	21000	38	9B
0005435177010	21000	39	9D
0005432359878	21000	40	9C
0005432359730	21000	41	9E
0005432359895	21000	42	9F
0005432359771	21000	43	10D
0005435177030	21000	44	10C
0005432359785	21000	45	10E
0005434149711	21000	46	11A
0005432359853	21000	47	11B
0005435177012	21000	48	11D
0005432335960	21000	49	11C
0005432360026	21000	50	11F
0005432359769	21000	51	11E
0005435177016	21000	52	12C
0005432363375	21000	53	12B
0005435490223	21000	54	12E
0005435177035	21000	55	13A
0005432359710	21000	56	13C
0005434149710	21000	57	13B
0005435490222	21000	58	13F
0005435177008	21000	59	14B
0005432335946	21000	60	14A
0005435177017	21000	61	14E
0005435177031	21000	62	15A
0005432335930	21000	63	15B
0005432360028	21000	64	15C
0005435177011	21000	65	15D
0005432359650	21000	66	15F
0005434149702	21000	67	16A
0005435177020	21000	68	16C
0005432359899	21000	69	16D
0005435177026	21000	70	16E
0005435490226	21000	71	17A
0005435177023	21000	72	16F
0005432359851	21000	73	17B
0005432335912	21000	74	17C
0005435723042	21000	75	17E
0005432359880	21000	76	17D
0005432359973	21000	77	17F
0005435177025	21000	78	18B
0005432359833	21000	79	18A
0005435177014	21000	80	18D
0005435177029	21000	81	18C
0005432359817	21000	82	18F
0005435490225	21000	83	19A
0005432359676	21000	84	19B
0005435177013	21000	85	19C
0005432359803	21000	86	19D
0005434149709	21000	87	19F
0005432335915	21000	88	19E
0005432335947	21000	89	20A
0005432359804	21000	90	20C
0005432359972	21000	91	20B
0005432359896	21000	92	20E
0005432359871	21000	93	20F
0005435177018	21000	94	21A
0005432359879	21000	95	21C
0005434149712	21000	96	21B
0005432359929	21000	97	21E
0005432359887	21000	98	22A
0005432359809	21000	99	21F
0005432359986	21000	100	22C
0005432359753	21000	101	22E
0005434149706	21000	102	23A
0005435177015	21000	103	22F
0005432052741	21000	104	23D
0005432359852	21000	105	23C
0005435177032	21000	106	23B
0005434149703	21000	107	23E
0005434458643	17684	1	1A
0005434458581	17684	2	1B
0005434458653	17684	3	1C
0005434458561	17684	4	1D
0005434186193	17684	5	2A
0005434186194	17684	6	2B
0005434448301	17684	7	2C
0005434458685	17684	8	2D
0005434458585	17684	9	3A
0005434458684	17684	10	3B
0005434458635	17684	11	3C
0005434458644	17684	12	3D
0005434458582	17684	13	4B
0005434458651	17684	14	4C
0005434458560	17684	15	4D
0005434458580	17684	16	5A
0005434463909	17684	17	5C
0005434461622	17684	18	6B
0005434458596	17684	19	6C
0005434458593	17684	20	7A
0005434461623	17684	21	7B
0005434458660	17684	22	7D
0005434458652	17684	23	18A
0005434448303	17684	24	18B
0005434458683	17684	25	18C
0005434186192	17684	26	18D
0005434458659	17684	27	19A
0005434458637	17684	28	19B
0005434186195	17684	29	19C
0005434448302	17684	30	20A
0005434458649	17684	31	20B
0005434458584	17684	32	20D
0005434458594	17684	33	21B
0005434463899	17684	34	21C
0005434463910	17684	35	22A
0005434458650	17684	36	22B
0005434458595	17684	37	22C
0005434458574	17684	38	23A
0005434458642	17684	39	23B
0005434458756	29126	1	1A
0005434458766	29126	2	1C
0005434448305	29126	3	1D
0005434463922	29126	4	2A
0005434458763	29126	5	2B
0005434458757	29126	6	2D
0005434458773	29126	7	3B
0005434462784	29126	8	3C
0005434186168	29126	9	3D
0005434458764	29126	10	4A
0005434458772	29126	11	4C
0005434458768	29126	12	4D
0005434463923	29126	13	5C
0005434458761	29126	14	5D
0005434458754	29126	15	6D
0005434458767	29126	16	7A
0005434458765	29126	17	7B
0005434458758	29126	18	18A
0005434458771	29126	19	19C
0005434462783	29126	20	19D
0005434458770	29126	21	20B
0005434458759	29126	22	20D
0005434448306	29126	23	21A
0005434458753	29126	24	21D
0005434458760	29126	25	22A
0005434458755	29126	26	22C
0005434458762	29126	27	22D
0005434448304	29126	28	23A
0005434458769	29126	29	23B
0005432604232	21451	1	1A
0005432604233	21451	2	1B
0005432604246	21451	3	1C
0005432604214	21451	4	1D
0005435220488	21451	5	2A
0005432604247	21451	6	2B
0005432604244	21451	7	2C
0005432604236	21451	8	2D
0005432604243	21451	9	3A
0005432604223	21451	10	3C
0005432604216	21451	11	3D
0005435218103	21451	12	4A
0005432604228	21451	13	4B
0005432604222	21451	14	4C
0005432604239	21451	15	5A
0005432604245	21451	16	5B
0005432604229	21451	17	5C
0005435218107	21451	18	5D
0005432604234	21451	19	6A
0005432604226	21451	20	6B
0005432604224	21451	21	6C
0005432604210	21451	22	6D
0005432604249	21451	23	7A
0005432604221	21451	24	7B
0005432604241	21451	25	7C
0005432604230	21451	26	7D
0005432604235	21451	27	18A
0005432604213	21451	28	18B
0005432604218	21451	29	18D
0005432604227	21451	30	19A
0005432604238	21451	31	19C
0005432604231	21451	32	20A
0005432604217	21451	33	20B
0005432604248	21451	34	20C
0005432604242	21451	35	20D
0005432604237	21451	36	21B
0005432604220	21451	37	21D
0005432604240	21451	38	22A
0005432604219	21451	39	22B
0005432604215	21451	40	22C
0005432604212	21451	41	22D
0005432604225	21451	42	23A
0005432604211	21451	43	23B
0005432603785	31711	1	1A
0005432603846	31711	2	1B
0005432603877	31711	3	1C
0005432604062	31711	4	2A
0005432603888	31711	5	2B
0005432603906	31711	6	2C
0005432604033	31711	7	2D
0005432603845	31711	8	3A
0005432603924	31711	9	3B
0005432603837	31711	10	3D
0005432603897	31711	11	4A
0005432604021	31711	12	4C
0005432603950	31711	13	4D
0005432603935	31711	14	5A
0005432603945	31711	15	5B
0005432603867	31711	16	5C
0005432603925	31711	17	5D
0005432603830	31711	18	6A
0005432604026	31711	19	6B
0005432604023	31711	20	6D
0005432604027	31711	21	7A
0005432604064	31711	22	7B
0005432603768	31711	23	7C
0005432603876	31711	24	7D
0005432603784	31711	25	18A
0005432603812	31711	26	18B
0005432604063	31711	27	18C
0005432604019	31711	28	18D
0005432603886	31711	29	19A
0005432603831	31711	30	19B
0005432603949	31711	31	19C
0005432604013	31711	32	20A
0005432603907	31711	33	20B
0005432603878	31711	34	20C
0005432603761	31711	35	20D
0005432604020	31711	36	21A
0005432604094	31711	37	21C
0005432604022	31711	38	21B
0005432603887	31711	39	21D
0005432603904	31711	40	22A
0005432603895	31711	41	22B
0005432603866	31711	42	22C
0005432603936	31711	43	23A
0005432603832	31711	44	23B
0005433293209	12299	1	1A
0005433293150	12299	2	1D
0005435154595	12299	3	3A
0005435154594	12299	4	4C
0005433293176	12299	5	5B
0005433293193	12299	6	7A
0005433293177	12299	7	18B
0005433293160	12299	8	18D
0005433293154	12299	9	20C
0005433293175	12299	10	21A
0005433293151	12299	11	22A
0005434606776	18845	1	1A
0005434606774	18845	2	2B
0005434606786	18845	3	3B
0005434606769	18845	4	4A
0005434606787	18845	5	5A
0005434606768	18845	6	6B
0005434606819	22288	1	3B
0005434604887	22288	2	4A
0005434604886	22288	3	5A
0005434606820	22288	4	5B
0005433293191	412	1	1A
0005432747487	412	2	1C
0005432890817	412	3	1D
0005432890781	412	4	1F
0005432747470	412	5	2A
0005432890804	412	6	2C
0005432890825	412	7	2D
0005432890740	412	8	2F
0005432747476	412	9	3A
0005433293190	412	10	3C
0005432747459	412	11	3D
0005432890806	412	12	3F
0005432747469	412	13	4C
0005432890803	412	14	4D
0005432890854	412	15	4E
0005432890783	412	16	4F
0005432747471	412	17	5A
0005432890844	412	18	5C
0005432747473	412	19	5D
0005432890821	412	20	5E
0005433875358	412	21	6A
0005432747493	412	22	5F
0005432890835	412	23	6C
0005432747489	412	24	6D
0005432749779	412	25	6E
0005432749778	412	26	6F
0005432747465	412	27	7A
0005432747477	412	28	7C
0005432747479	412	29	7D
0005432753290	412	30	7E
0005432747478	412	31	7F
0005432219994	412	32	8A
0005432747486	412	33	8C
0005432890772	412	34	8D
0005432890735	412	35	8E
0005432890816	412	36	8F
0005432219991	412	37	9A
0005432890820	412	38	9C
0005432749780	412	39	9D
0005432747488	412	40	9F
0005432747460	412	41	10A
0005432753291	412	42	10C
0005432890782	412	43	10D
0005432890761	412	44	10E
0005432219995	412	45	10F
0005432747484	412	46	11A
0005432751515	412	47	11D
0005432747480	412	48	11E
0005432747483	412	49	11F
0005432747496	412	50	12C
0005432747464	412	51	12A
0005432753292	412	52	12D
0005432890807	412	53	12E
0005432747494	412	54	12F
0005432751516	412	55	13A
0005432747458	412	56	13C
0005432747468	412	57	13D
0005432747463	412	58	13E
0005433293180	412	59	13F
0005432747495	412	60	14A
0005432890861	412	61	14C
0005432890824	412	62	14D
0005432890843	412	63	14E
0005432747456	412	64	14F
0005432751517	412	65	15A
0005433293192	412	66	15C
0005432890828	412	67	15D
0005432747474	412	68	15E
0005432890775	412	69	15F
0005432890819	412	70	16A
0005432747457	412	71	16D
0005432219993	412	72	16E
0005432747475	412	73	16F
0005432747481	412	74	17A
0005432890748	412	75	17C
0005432890845	412	76	17D
0005432747490	412	77	17E
0005432747491	412	78	17F
0005432890787	412	79	18A
0005432747492	412	80	18C
0005432747466	412	81	18D
0005432747467	412	82	18E
0005432890904	412	83	18F
0005432747462	412	84	19A
0005432747485	412	85	19C
0005432747461	412	86	19D
0005432219992	412	87	19E
0005432747482	412	88	19F
0005433875360	412	89	20A
0005432747472	412	90	20C
0005432890771	412	91	20D
0005432890736	412	92	20E
0005432890760	412	93	20F
0005433293225	12060	1	1A
0005433293237	12060	2	1C
0005432890972	12060	3	1D
0005432890977	12060	4	1F
0005432890986	12060	5	2A
0005433293232	12060	6	2C
0005433293224	12060	7	2D
0005433293239	12060	8	2F
0005432747136	12060	9	3A
0005433293227	12060	10	3C
0005432747163	12060	11	3F
0005432890975	12060	12	4A
0005432753252	12060	13	4C
0005432747218	12060	14	4D
0005432890976	12060	15	4E
0005432747115	12060	16	4F
0005433293230	12060	17	5A
0005432749757	12060	18	5C
0005432747280	12060	19	5D
0005432747178	12060	20	5E
0005432753262	12060	21	5F
0005432747234	12060	22	6C
0005432747229	12060	23	6D
0005432747126	12060	24	6E
0005432747278	12060	25	6F
0005432747173	12060	26	7A
0005432890973	12060	27	7C
0005433875374	12060	28	7D
0005433293228	12060	29	7E
0005432747029	12060	30	7F
0005432890974	12060	31	8A
0005432749761	12060	32	8C
0005432747169	12060	33	8D
0005432747012	12060	34	8E
0005433875376	12060	35	9A
0005432747335	12060	36	9C
0005432890979	12060	37	9D
0005432747312	12060	38	9E
0005433293234	12060	39	9F
0005432747167	12060	40	10A
0005433293233	12060	41	10C
0005433293238	12060	42	10D
0005432890981	12060	43	10E
0005432747157	12060	44	10F
0005432747375	12060	45	11A
0005432747161	12060	46	11C
0005432747137	12060	47	11D
0005432747107	12060	48	11E
0005432747279	12060	49	11F
0005433293231	12060	50	12A
0005432890989	12060	51	12C
0005433293236	12060	52	12D
0005432890988	12060	53	12E
0005432747253	12060	54	13A
0005432749760	12060	55	13C
0005432756799	12060	56	13D
0005433293226	12060	57	13E
0005432890978	12060	58	13F
0005432747156	12060	59	14A
0005432214798	12060	60	14C
0005433293240	12060	61	14D
0005432747170	12060	62	14E
0005432890984	12060	63	15A
0005432890971	12060	64	15C
0005432214799	12060	65	15D
0005432747168	12060	66	15E
0005432756797	12060	67	16A
0005433875375	12060	68	16C
0005432890987	12060	69	16E
0005432747273	12060	70	16F
0005432747143	12060	71	17C
0005432890985	12060	72	17D
0005432890982	12060	73	17E
0005432756810	12060	74	17F
0005432747235	12060	75	18A
0005432747314	12060	76	18C
0005432890980	12060	77	18D
0005432747216	12060	78	18E
0005432747125	12060	79	18F
0005432747148	12060	80	19A
0005432747191	12060	81	19C
0005433293235	12060	82	19D
0005432747313	12060	83	19E
0005433293229	12060	84	19F
0005432747217	12060	85	20A
0005432747144	12060	86	20C
0005432747174	12060	87	20D
0005432756798	12060	88	20E
0005432890983	12060	89	20F
0005432927908	18954	1	1B
0005433525012	18954	2	2D
0005432927907	18954	3	3B
0005433531281	18954	4	3C
0005433525010	18954	5	3D
0005433525003	18954	6	4A
0005433525004	18954	7	4B
0005433531282	18954	8	5D
0005433525008	18954	9	6A
0005433525006	18954	10	6C
0005433533297	18954	11	6D
0005433531283	18954	12	18B
0005433525013	18954	13	18D
0005433525005	18954	14	19C
0005433533298	18954	15	20A
0005433531280	18954	16	20B
0005433525011	18954	17	20D
0005433533296	18954	18	21D
0005433525009	18954	19	22D
0005433525007	18954	20	23A
0005433533299	18954	21	23B
0005433524942	32510	1	1B
0005433524904	32510	2	2A
0005433524956	32510	3	2D
0005433531246	32510	4	3C
0005432927973	32510	5	3D
0005433524935	32510	6	4A
0005432927972	32510	7	5B
0005433527201	32510	8	5C
0005433524949	32510	9	5D
0005433531245	32510	10	6A
0005432927976	32510	11	6B
0005432927975	32510	12	6D
0005433524897	32510	13	7A
0005433524978	32510	14	7B
0005432927974	32510	15	7C
0005433524948	32510	16	7D
0005433524905	32510	17	18A
0005433531250	32510	18	18B
0005433524941	32510	19	19B
0005433524934	32510	20	20A
0005433524933	32510	21	20B
0005433531249	32510	22	20C
0005432121298	5283	1	1A
0005435372522	5283	2	1H
0005434823351	5283	3	1G
0005434823379	5283	4	1D
0005434823315	5283	5	1K
0005434831136	5283	6	2D
0005434823377	5283	7	2C
0005432121302	5283	8	2H
0005434823334	5283	9	2G
0005434823350	5283	10	3A
0005434823281	5283	11	3C
0005435304136	5283	12	3H
0005434823308	5283	13	4A
0005434823358	5283	14	3K
0005435299750	5283	15	4G
0005435372634	5283	16	4D
0005435372712	5283	17	4C
0005435299743	5283	18	5A
0005435661896	5283	19	4K
0005435372551	5283	20	4H
0005435372569	5283	21	5D
0005435661882	5283	22	5G
0005434823383	5283	23	11A
0005434823288	5283	24	5K
0005434823376	5283	25	11E
0005435299717	5283	26	11C
0005432121305	5283	27	11K
0005434823387	5283	28	11H
0005435150004	5283	29	12C
0005435372492	5283	30	12A
0005434823352	5283	31	12E
0005434823290	5283	32	12D
0005435299716	5283	33	12H
0005434823276	5283	34	12K
0005432121311	5283	35	13D
0005435149994	5283	36	13C
0005434823365	5283	37	13F
0005434823291	5283	38	13E
0005435661883	5283	39	13H
0005434823307	5283	40	13G
0005434823337	5283	41	14E
0005434823384	5283	42	14D
0005434823341	5283	43	14G
0005435150001	5283	44	14F
0005434828688	5283	45	14H
0005434823374	5283	46	15C
0005435372546	5283	47	15A
0005432394094	5283	48	15E
0005434823382	5283	49	15D
0005434823345	5283	50	15G
0005435372535	5283	51	15F
0005434831138	5283	52	16A
0005434823385	5283	53	15K
0005434823305	5283	54	16D
0005434823388	5283	55	16C
0005434823302	5283	56	16F
0005432394096	5283	57	16K
0005435372780	5283	58	16H
0005434823267	5283	59	16G
0005434823361	5283	60	17A
0005432823433	5283	61	17E
0005435372455	5283	62	17C
0005434823344	5283	63	17F
0005434823293	5283	64	17H
0005434823363	5283	65	18A
0005434823321	5283	66	18E
0005434831137	5283	67	18C
0005434823311	5283	68	18K
0005435149997	5283	69	19A
0005432121300	5283	70	19B
0005434823355	5283	71	19F
0005434823326	5283	72	20A
0005434831134	5283	73	19K
0005434823380	5283	74	20G
0005434823313	5283	75	20J
0005434823348	5283	76	20H
0005434823356	5283	77	21B
0005434558248	5283	78	20K
0005435372454	5283	79	21C
0005435149999	5283	80	21F
0005435372568	5283	81	21J
0005434823347	5283	82	21H
0005435386503	5283	83	21G
0005434823304	5283	84	22A
0005435150000	5283	85	21K
0005435372570	5283	86	22C
0005435372447	5283	87	22B
0005432121310	5283	88	22E
0005435372822	5283	89	22D
0005434823295	5283	90	22H
0005434823318	5283	91	22K
0005435372559	5283	92	23A
0005434823282	5283	93	23D
0005432394097	5283	94	23C
0005435299730	5283	95	23F
0005434823357	5283	96	23E
0005434823303	5283	97	23J
0005435150005	5283	98	23H
0005435372639	5283	99	24D
0005434823289	5283	100	23K
0005434823306	5283	101	24F
0005434558253	5283	102	25B
0005435372285	5283	103	25A
0005434823359	5283	104	24G
0005434823320	5283	105	25C
0005435372371	5283	106	25F
0005434823268	5283	107	25E
0005434823378	5283	108	25H
0005434823323	5283	109	25G
0005434823324	5283	110	26A
0005434823312	5283	111	25K
0005435372536	5283	112	25J
0005435372488	5283	113	26B
0005434823297	5283	114	26D
0005435304135	5283	115	26G
0005434558249	5283	116	26F
0005434823261	5283	117	26J
0005434558254	5283	118	27A
0005432121308	5283	119	26K
0005434823367	5283	120	27B
0005435372689	5283	121	27F
0005435372514	5283	122	27E
0005435372709	5283	123	27H
0005432121304	5283	124	27G
0005432396234	5283	125	27K
0005434823298	5283	126	27J
0005435304104	5283	127	28B
0005434823286	5283	128	28A
0005435149995	5283	129	28E
0005434823287	5283	130	28C
0005435150002	5283	131	28F
0005434558246	5283	132	28J
0005435372589	5283	133	28H
0005434823330	5283	134	29A
0005434823275	5283	135	28K
0005434823389	5283	136	29B
0005434558247	5283	137	29F
0005434664952	5283	138	29H
0005435372550	5283	139	29K
0005434823309	5283	140	30C
0005434828689	5283	141	30B
0005435372821	5283	142	30A
0005435372445	5283	143	30E
0005434558255	5283	144	30D
0005435735075	5283	145	30H
0005432396235	5283	146	30G
0005435372555	5283	147	30K
0005432396236	5283	148	30J
0005435372500	5283	149	31B
0005435372372	5283	150	31A
0005432121309	5283	151	31D
0005435735076	5283	152	31C
0005434823375	5283	153	31F
0005434823299	5283	154	31E
0005435386502	5283	155	31H
0005435150007	5283	156	31G
0005435149996	5283	157	32A
0005434823333	5283	158	31K
0005434823317	5283	159	31J
0005435372487	5283	160	32E
0005432394095	5283	161	32D
0005434823278	5283	162	32C
0005434823327	5283	163	32G
0005434823271	5283	164	32F
0005434823292	5283	165	32J
0005434823274	5283	166	32H
0005435372779	5283	167	33B
0005434558244	5283	168	32K
0005434823381	5283	169	33C
0005434823316	5283	170	33F
0005435386537	5283	171	33E
0005434823284	5283	172	33J
0005434823272	5283	173	33H
0005434823266	5283	174	33K
0005434823279	5283	175	34C
0005435735091	5283	176	34B
0005434823329	5283	177	34A
0005435372567	5283	178	34G
0005435735068	5283	179	34F
0005435372446	5283	180	34K
0005435149998	5283	181	34H
0005432121303	5283	182	35B
0005432121299	5283	183	35D
0005434823360	5283	184	35F
0005435150003	5283	185	35E
0005434823386	5283	186	35J
0005435372511	5283	187	35H
0005434831135	5283	188	35G
0005434823263	5283	189	36A
0005434823285	5283	190	36E
0005434823346	5283	191	36D
0005434823335	5283	192	36H
0005435372373	5283	193	36G
0005434823264	5283	194	37B
0005434823336	5283	195	37A
0005435372430	5283	196	37E
0005435372778	5283	197	37C
0005435372448	5283	198	37J
0005434823262	5283	199	37G
0005435372601	5283	200	38A
0005434823362	5283	201	37K
0005434823371	5283	202	38H
0005435372618	5283	203	38C
0005432121306	5283	204	38B
0005434823353	5283	205	38J
0005434823343	5283	206	38K
0005435372676	5283	207	39C
0005435372633	5283	208	39F
0005435735078	5283	209	39E
0005434823340	5283	210	39J
0005435372499	5283	211	39H
0005434823301	5283	212	39G
0005435372452	5283	213	40A
0005435386538	5283	214	39K
0005434558245	5283	215	40C
0005434823310	5283	216	40B
0005434664953	5283	217	40E
0005435661892	5283	218	40D
0005434823294	5283	219	40H
0005435661893	5283	220	40G
0005434823342	5283	221	40J
0005435372548	5283	222	41B
0005434823364	5283	223	41A
0005435372286	5283	224	41C
0005435735101	5283	225	41J
0005435372493	5283	226	41K
0005434823369	5283	227	42C
0005435386473	5283	228	42B
0005435150006	5283	229	42E
0005434823332	5283	230	42G
0005432396233	5283	231	42F
0005434823283	5283	232	42K
0005434828690	5283	233	42J
0005435372549	5283	234	42H
0005435372579	5283	235	43A
0005435372512	5283	236	43D
0005434823319	5283	237	43C
0005434823368	5283	238	43E
0005434823314	5283	239	43G
0005434823372	5283	240	44A
0005435178977	5283	241	43K
0005435372501	5283	242	44E
0005435735069	5283	243	44D
0005435372590	5283	244	44G
0005434823328	5283	245	44F
0005434823265	5283	246	44H
0005434823338	5283	247	45B
0005434823339	5283	248	45A
0005434823325	5283	249	45D
0005432121312	5283	250	45C
0005434823270	5283	251	45F
0005434823366	5283	252	45G
0005435372434	5283	253	45J
0005434558250	5283	254	46C
0005434823277	5283	255	46B
0005434558256	5283	256	46E
0005435372648	5283	257	46D
0005435372640	5283	258	46G
0005434823300	5283	259	46F
0005434823373	5283	260	46H
0005434823280	5283	261	47C
0005434823273	5283	262	47E
0005432121307	5283	263	47D
0005435372584	5283	264	47H
0005434823354	5283	265	48F
0005434558257	5283	266	48E
0005434823370	5283	267	48H
0005434823331	5283	268	48G
0005435372431	5283	269	49A
0005432394098	5283	270	49F
0005435299720	5283	271	49H
0005434823322	5283	272	50A
0005432121301	5283	273	50E
0005434823269	5283	274	50G
0005434558251	5283	275	50F
0005434823349	5283	276	50H
0005435372422	5283	277	51E
0005434558252	5283	278	51G
0005434823296	5283	279	51F
0005435373108	9932	1	1C
0005434822343	9932	2	1A
0005434558161	9932	3	1G
0005434822305	9932	4	1D
0005435373130	9932	5	1K
0005434821907	9932	6	2C
0005435149871	9932	7	2A
0005434821990	9932	8	2H
0005435373149	9932	9	2G
0005432823445	9932	10	2D
0005432396220	9932	11	3A
0005434822326	9932	12	3K
0005435373103	9932	13	3H
0005435299767	9932	14	3G
0005434822573	9932	15	4C
0005434822230	9932	16	4A
0005435373102	9932	17	4G
0005434822571	9932	18	4K
0005434822081	9932	19	5H
0005435373123	9932	20	5D
0005434558160	9932	21	11A
0005435149841	9932	22	5K
0005434821972	9932	23	11D
0005434822327	9932	24	11C
0005435373105	9932	25	11F
0005434822476	9932	26	11E
0005434822123	9932	27	11G
0005434822120	9932	28	12C
0005434664931	9932	29	12A
0005434822213	9932	30	11K
0005434558177	9932	31	12F
0005435373150	9932	32	12K
0005435373153	9932	33	12H
0005435373141	9932	34	13D
0005432823447	9932	35	13A
0005432400067	9932	36	13F
0005434821956	9932	37	13H
0005435373160	9932	38	13G
0005434822519	9932	39	14A
0005434822012	9932	40	13K
0005434821936	9932	41	14D
0005434821779	9932	42	14F
0005434822286	9932	43	14H
0005434822442	9932	44	14G
0005434822271	9932	45	14K
0005432400074	9932	46	15E
0005434558141	9932	47	15H
0005434664930	9932	48	15G
0005434822572	9932	49	15F
0005435149883	9932	50	16A
0005435373161	9932	51	15K
0005435149832	9932	52	16D
0005434822350	9932	53	16F
0005435373118	9932	54	16H
0005434822547	9932	55	16G
0005435302190	9932	56	17C
0005434822565	9932	57	17A
0005434558176	9932	58	16K
0005434822526	9932	59	17F
0005434831100	9932	60	17K
0005434558170	9932	61	17H
0005434822752	9932	62	18A
0005432823446	9932	63	18D
0005434822470	9932	64	18C
0005434822596	9932	65	18G
0005435149877	9932	66	18F
0005434822372	9932	67	18E
0005435386564	9932	68	18K
0005434822371	9932	69	18J
0005435661926	9932	70	19B
0005435149888	9932	71	19C
0005435373095	9932	72	19F
0005432203049	9932	73	19E
0005435661925	9932	74	19D
0005434822270	9932	75	19J
0005432396192	9932	76	19H
0005432203050	9932	77	19G
0005435373159	9932	78	20A
0005434822679	9932	79	19K
0005435373121	9932	80	20C
0005434822717	9932	81	20B
0005435373113	9932	82	20E
0005434822761	9932	83	21B
0005434821788	9932	84	21A
0005435149859	9932	85	21D
0005435149892	9932	86	21C
0005434822835	9932	87	21F
0005435373155	9932	88	21J
0005434822079	9932	89	21H
0005432203048	9932	90	21G
0005434822222	9932	91	22A
0005434822570	9932	92	21K
0005434822312	9932	93	22C
0005435373129	9932	94	22F
0005434821851	9932	95	22E
0005435373132	9932	96	22K
0005435373109	9932	97	22J
0005434822458	9932	98	22H
0005434822173	9932	99	23B
0005435299766	9932	100	23A
0005435373107	9932	101	23C
0005434822196	9932	102	23F
0005434822475	9932	103	23H
0005432396195	9932	104	23G
0005434822365	9932	105	24D
0005435149902	9932	106	23K
0005435302189	9932	107	23J
0005435373101	9932	108	24G
0005434822223	9932	109	24F
0005434822551	9932	110	25B
0005434822164	9932	111	25A
0005435149854	9932	112	25C
0005434822550	9932	113	25E
0005434821970	9932	114	25H
0005434558183	9932	115	25G
0005435373147	9932	116	25K
0005435373145	9932	117	25J
0005435149846	9932	118	26C
0005435149870	9932	119	26B
0005434821831	9932	120	26D
0005432203045	9932	121	26G
0005434821696	9932	122	26F
0005434822471	9932	123	26J
0005434822097	9932	124	27B
0005434822441	9932	125	27A
0005435149822	9932	126	26K
0005435149842	9932	127	27C
0005435149845	9932	128	27E
0005435386562	9932	129	27J
0005435735131	9932	130	27G
0005432203051	9932	131	27K
0005435373136	9932	132	28C
0005435373110	9932	133	28B
0005434821581	9932	134	28A
0005434821886	9932	135	28E
0005434822135	9932	136	28G
0005434822445	9932	137	28F
0005435373100	9932	138	28J
0005434822697	9932	139	29B
0005434822462	9932	140	29A
0005434822413	9932	141	28K
0005434822474	9932	142	29J
0005434821892	9932	143	30A
0005434822303	9932	144	29K
0005434558178	9932	145	30C
0005434822366	9932	146	30B
0005434822507	9932	147	30F
0005435735132	9932	148	30K
0005435735133	9932	149	30J
0005432396198	9932	150	31A
0005434821416	9932	151	31F
0005435373117	9932	152	31E
0005435373111	9932	153	31G
0005435149864	9932	154	32A
0005434822628	9932	155	31K
0005435373097	9932	156	31J
0005434822176	9932	157	32C
0005435373138	9932	158	32B
0005435373120	9932	159	32E
0005434821937	9932	160	32D
0005432203047	9932	161	32G
0005434821468	9932	162	32K
0005435299764	9932	163	32J
0005434822563	9932	164	32H
0005434822514	9932	165	33B
0005434822389	9932	166	33D
0005432400068	9932	167	33C
0005435149829	9932	168	33F
0005435661924	9932	169	33K
0005435149860	9932	170	33J
0005434822564	9932	171	34C
0005435373140	9932	172	34E
0005434822214	9932	173	34G
0005434822751	9932	174	34K
0005435149885	9932	175	34J
0005434822469	9932	176	35B
0005435373146	9932	177	35A
0005432400073	9932	178	35F
0005435373157	9932	179	35H
0005435373143	9932	180	35G
0005434822461	9932	181	35K
0005435373099	9932	182	36C
0005435149901	9932	183	36E
0005434831101	9932	184	36D
0005435373122	9932	185	36H
0005435373156	9932	186	36G
0005435373148	9932	187	36K
0005434821830	9932	188	37B
0005435373116	9932	189	37A
0005435373142	9932	190	37D
0005435373133	9932	191	37F
0005434558174	9932	192	37H
0005435373098	9932	193	37G
0005434821827	9932	194	38A
0005434821891	9932	195	37K
0005434821908	9932	196	37J
0005435373124	9932	197	38C
0005434822342	9932	198	38B
0005434558179	9932	199	39B
0005435373104	9932	200	39A
0005432396194	9932	201	39D
0005434821697	9932	202	39J
0005432203046	9932	203	39H
0005434822285	9932	204	39G
0005434822080	9932	205	40A
0005435373114	9932	206	39K
0005434822482	9932	207	40C
0005435373125	9932	208	40B
0005435373154	9932	209	40D
0005435373151	9932	210	40K
0005434821958	9932	211	40J
0005435373115	9932	212	41B
0005434821492	9932	213	41A
0005434821992	9932	214	41D
0005435373137	9932	215	41C
0005434821828	9932	216	41F
0005434822569	9932	217	41E
0005434822296	9932	218	41G
0005434821971	9932	219	42A
0005434821938	9932	220	41J
0005434822562	9932	221	42C
0005434822995	9932	222	42B
0005434822304	9932	223	42F
0005435149828	9932	224	42E
0005434823033	9932	225	42G
0005434822165	9932	226	42J
0005435373139	9932	227	42H
0005434828670	9932	228	43A
0005434822149	9932	229	43C
0005434822357	9932	230	43B
0005435373096	9932	231	43F
0005435373158	9932	232	43E
0005435299765	9932	233	43D
0005435373112	9932	234	43H
0005435373126	9932	235	43G
0005434822049	9932	236	43J
0005434822488	9932	237	44D
0005434664942	9932	238	44H
0005435373134	9932	239	44G
0005434831089	9932	240	44F
0005434822147	9932	241	44J
0005435149886	9932	242	45B
0005435373152	9932	243	45A
0005435373106	9932	244	44K
0005435373131	9932	245	45C
0005434822629	9932	246	45F
0005434821957	9932	247	45E
0005434822504	9932	248	45K
0005435373135	9932	249	45J
0005434822243	9932	250	46C
0005435373128	9932	251	46D
0005435373144	9932	252	46H
0005434822698	9932	253	46F
0005435373127	9932	254	47C
0005435149893	9932	255	47G
0005434823034	9932	256	47F
0005434822735	9932	257	47K
0005435373119	9932	258	48C
0005434822264	9932	259	48E
0005435149821	9932	260	48H
0005434822958	9932	261	49A
0005434822483	9932	262	48K
0005434822446	9932	263	49C
0005434822337	9932	264	49E
0005435149867	9932	265	49H
0005435386563	9932	266	50C
0005434822568	9932	267	50A
0005434821924	9932	268	50F
0005434821842	9932	269	50E
0005434822313	9932	270	50D
0005434821780	9932	271	50G
0005434822349	9932	272	51D
0005435149929	9932	273	50K
0005434822360	9932	274	50H
0005434822805	9932	275	51F
0005434822242	9932	276	51G
0005435082775	7017	1	2C
0005435082771	7017	2	3A
0005435082776	7017	3	3C
0005435082773	7017	4	5B
0005435790300	7017	5	5C
0005435082777	7017	6	6D
0005435790301	7017	7	7B
0005435082774	7017	8	7C
0005435790299	7017	9	23A
0005435082772	7017	10	23B
0005435082705	25997	1	3C
0005435082696	25997	2	5C
0005435082695	25997	3	6A
0005435082698	25997	4	7D
0005435790273	25997	5	18A
0005435082704	25997	6	20A
0005435082721	25997	7	21A
0005435790277	25997	8	22B
0005434756349	9545	1	1A
0005434756347	9545	2	1C
0005434756339	9545	3	1D
0005434214085	9545	4	1F
0005434213809	9545	5	2A
0005434214000	9545	6	2C
0005434756345	9545	7	2D
0005434756358	9545	8	2F
0005434756354	9545	9	3A
0005434756343	9545	10	3C
0005434213883	9545	11	3D
0005434214114	9545	12	3F
0005434756356	9545	13	4A
0005434756336	9545	14	4C
0005434756359	9545	15	4D
0005434213998	9545	16	4E
0005434756329	9545	17	4F
0005434214184	9545	18	5A
0005434213927	9545	19	5C
0005434756334	9545	20	5D
0005434213949	9545	21	5E
0005434214218	9545	22	5F
0005434214009	9545	23	6A
0005434756342	9545	24	6C
0005434214219	9545	25	6D
0005434756338	9545	26	6E
0005434214152	9545	27	6F
0005434214008	9545	28	7A
0005434756353	9545	29	7C
0005434214045	9545	30	7E
0005434756348	9545	31	7F
0005434756351	9545	32	8A
0005434214124	9545	33	8C
0005434214043	9545	34	8D
0005434214044	9545	35	8F
0005434756340	9545	36	9A
0005434214115	9545	37	9C
0005434214075	9545	38	9D
0005434756333	9545	39	9E
0005434214105	9545	40	9F
0005434756331	9545	41	10C
0005434214034	9545	42	10D
0005434756337	9545	43	10E
0005434756360	9545	44	10F
0005434214040	9545	45	11C
0005434214037	9545	46	11E
0005434213799	9545	47	11F
0005434214186	9545	48	12A
0005434214160	9545	49	12C
0005434214018	9545	50	12D
0005434214007	9545	51	12E
0005434213936	9545	52	13A
0005434213923	9545	53	13C
0005434756352	9545	54	13D
0005434214103	9545	55	13E
0005434756350	9545	56	13F
0005434214020	9545	57	14A
0005434213903	9545	58	14C
0005434756335	9545	59	14D
0005434213977	9545	60	14E
0005434214035	9545	61	14F
0005434756355	9545	62	15A
0005434214225	9545	63	15C
0005434213800	9545	64	15D
0005434214074	9545	65	15E
0005434756332	9545	66	15F
0005434214033	9545	67	16A
0005434214042	9545	68	16C
0005434213972	9545	69	16D
0005434756330	9545	70	16E
0005434214185	9545	71	16F
0005434214175	9545	72	17C
0005434213884	9545	73	17D
0005434756346	9545	74	17F
0005434214017	9545	75	17E
0005434214213	9545	76	18A
0005434213978	9545	77	18C
0005434213855	9545	78	18D
0005434213832	9545	79	18E
0005434214076	9545	80	18F
0005434214102	9545	81	19A
0005434214159	9545	82	19C
0005434756357	9545	83	19D
0005434756344	9545	84	19E
0005434214101	9545	85	19F
0005434756341	9545	86	20A
0005434214010	9545	87	20C
0005434213819	9545	88	20D
0005434756361	9545	89	20F
0005434214364	28632	1	1A
0005434214383	28632	2	1D
0005434755929	28632	3	1F
0005434214397	28632	4	2A
0005434755817	28632	5	2C
0005434756062	28632	6	2D
0005434755747	28632	7	2F
0005434214369	28632	8	3A
0005434755963	28632	9	3D
0005434214407	28632	10	3F
0005434214378	28632	11	4A
0005434755943	28632	12	4C
0005434214384	28632	13	4D
0005434755902	28632	14	4E
0005434755914	28632	15	4F
0005434214385	28632	16	5A
0005434755953	28632	17	5C
0005434214375	28632	18	5D
0005434756034	28632	19	5F
0005434755904	28632	20	6A
0005434214372	28632	21	6C
0005434756049	28632	22	6D
0005434755812	28632	23	6E
0005434755941	28632	24	6F
0005434214386	28632	25	7A
0005434214389	28632	26	7C
0005434214396	28632	27	7D
0005434214388	28632	28	7E
0005434756035	28632	29	7F
0005434756021	28632	30	8A
0005434214373	28632	31	8C
0005434214398	28632	32	8D
0005434214365	28632	33	8E
0005434755859	28632	34	8F
0005434755829	28632	35	9A
0005434214403	28632	36	9C
0005434755798	28632	37	9D
0005434755989	28632	38	9E
0005434755951	28632	39	9F
0005434755768	28632	40	10A
0005434214412	28632	41	10C
0005434755937	28632	42	10D
0005434214411	28632	43	10E
0005434756050	28632	44	10F
0005434755940	28632	45	11A
0005434214381	28632	46	11C
0005434755884	28632	47	11D
0005434214387	28632	48	11E
0005434214395	28632	49	11F
0005434214367	28632	50	12A
0005434214394	28632	51	12C
0005434756063	28632	52	12E
0005434214366	28632	53	12F
0005434214371	28632	54	13A
0005434214400	28632	55	13C
0005434755878	28632	56	13D
0005434755952	28632	57	13E
0005434214408	28632	58	13F
0005434755987	28632	59	14A
0005434755860	28632	60	14C
0005434214390	28632	61	14D
0005434214393	28632	62	14E
0005434214379	28632	63	14F
0005434755915	28632	64	15C
0005434756036	28632	65	15D
0005434214392	28632	66	15E
0005434214391	28632	67	15F
0005434214399	28632	68	16A
0005434214404	28632	69	16C
0005434214370	28632	70	16D
0005434755820	28632	71	16E
0005434756012	28632	72	16F
0005434214409	28632	73	17A
0005434755944	28632	74	17C
0005434214401	28632	75	17D
0005434756030	28632	76	17E
0005434214374	28632	77	17F
0005434214382	28632	78	18A
0005434755819	28632	79	18C
0005434214410	28632	80	18D
0005434214377	28632	81	18F
0005434214405	28632	82	19A
0005434214406	28632	83	19C
0005434214402	28632	84	19D
0005434756020	28632	85	19E
0005434214368	28632	86	19F
0005434214376	28632	87	20A
0005434755930	28632	88	20C
0005434755931	28632	89	20E
0005434214380	28632	90	20F
0005435100117	10820	1	1B
0005434760167	10820	2	1D
0005434760182	10820	3	5B
0005434760166	10820	4	5C
0005434760169	10820	5	6A
0005434760163	10820	6	7A
0005434760164	10820	7	19C
0005434760165	10820	8	19D
0005434760170	10820	9	20A
0005435100116	10820	10	21C
0005435100115	10820	11	21D
0005434760193	31845	1	1D
0005435100100	31845	2	3C
0005435100090	31845	3	4A
0005435100088	31845	4	6D
0005434760191	31845	5	7B
0005435100087	31845	6	19C
0005434760192	31845	7	20D
0005435100101	31845	8	21A
0005433202177	2000	1	1A
0005432290627	2000	2	1B
0005433202165	2000	3	1C
0005433202168	2000	4	1D
0005433202191	2000	5	2A
0005434639286	2000	6	2B
0005434639287	2000	7	2C
0005434639278	2000	8	2D
0005433202186	2000	9	3A
0005433202227	2000	10	3C
0005434639267	2000	11	3D
0005433202160	2000	12	4A
0005434639277	2000	13	4B
0005433202136	2000	14	4C
0005433202207	2000	15	4D
0005433202217	2000	16	5A
0005434639270	2000	17	5C
0005434639285	2000	18	5D
0005433202178	2000	19	6B
0005433202135	2000	20	6C
0005433202236	2000	21	7A
0005433202218	2000	22	7B
0005434639271	2000	23	7C
0005433202174	2000	24	7D
0005433202159	2000	25	18A
0005434639274	2000	26	18B
0005433202123	2000	27	18C
0005434639280	2000	28	18D
0005434639284	2000	29	19A
0005434639283	2000	30	19C
0005434639273	2000	31	19D
0005434639272	2000	32	20A
0005434639275	2000	33	20B
0005434639265	2000	34	20C
0005432290626	2000	35	20D
0005434639269	2000	36	21A
0005434639266	2000	37	21B
0005434639268	2000	38	21D
0005433202169	2000	39	21C
0005434639276	2000	40	22A
0005433202183	2000	41	22B
0005434639282	2000	42	22C
0005434639279	2000	43	22D
0005434639281	2000	44	23A
0005432290628	2000	45	23B
0005434639034	23303	1	1A
0005434639000	23303	2	1B
0005434639065	23303	3	1C
0005433202322	23303	4	1D
0005434638979	23303	5	2A
0005435948316	23303	6	2B
0005434638978	23303	7	2C
0005435948314	23303	8	2D
0005434638987	23303	9	3A
0005433202319	23303	10	3C
0005433202314	23303	11	3D
0005434638986	23303	12	4A
0005433202316	23303	13	4B
0005434639057	23303	14	4C
0005434639072	23303	15	4D
0005433202315	23303	16	5A
0005433202324	23303	17	5B
0005433202326	23303	18	5C
0005434638943	23303	19	5D
0005433202325	23303	20	6A
0005433202320	23303	21	6B
0005434639066	23303	22	6C
0005433202327	23303	23	6D
0005433202328	23303	24	7A
0005434638889	23303	25	7B
0005434638928	23303	26	7C
0005434639099	23303	27	7D
0005434639027	23303	28	18A
0005434638942	23303	29	18B
0005433202317	23303	30	18C
0005434639119	23303	31	19A
0005434638993	23303	32	19B
0005434639001	23303	33	19C
0005433202318	23303	34	19D
0005434639019	23303	35	20A
0005433202323	23303	36	20B
0005434639120	23303	37	20C
0005434639010	23303	38	20D
0005434639049	23303	39	21A
0005434638990	23303	40	21B
0005434638946	23303	41	22A
0005433202321	23303	42	22C
0005433202313	23303	43	22D
0005434638929	23303	44	23A
0005435948317	23303	45	23B
0005435326572	6075	1	1C
0005435326570	6075	2	1D
0005434600748	6075	3	1F
0005434600756	6075	4	2D
0005435326603	6075	5	2F
0005434600757	6075	6	3A
0005434600763	6075	7	3D
0005433531286	6075	8	4C
0005433531284	6075	9	4E
0005432111273	6075	10	4F
0005434600749	6075	11	5D
0005432111271	6075	12	5E
0005434600761	6075	13	5F
0005435326652	6075	14	7A
0005433533300	6075	15	7C
0005435326518	6075	16	7D
0005433533302	6075	17	7E
0005434600760	6075	18	7F
0005435326566	6075	19	9A
0005435326565	6075	20	9D
0005434600742	6075	21	9E
0005433531285	6075	22	10C
0005432111274	6075	23	10D
0005435326653	6075	24	10E
0005434600758	6075	25	10F
0005434600764	6075	26	11D
0005435326622	6075	27	11E
0005435326661	6075	28	11F
0005434600759	6075	29	12A
0005432111272	6075	30	12C
0005434600741	6075	31	12F
0005434600751	6075	32	13E
0005434600767	6075	33	14A
0005434600754	6075	34	14E
0005435326571	6075	35	14F
0005434600765	6075	36	15E
0005435326644	6075	37	16C
0005434600744	6075	38	16E
0005434600766	6075	39	17A
0005434600750	6075	40	17C
0005434600747	6075	41	17D
0005434600745	6075	42	17E
0005434600752	6075	43	18A
0005434600746	6075	44	18C
0005435326639	6075	45	18D
0005433533301	6075	46	18F
0005434600762	6075	47	19C
0005434600755	6075	48	19D
0005435326638	6075	49	20C
0005434600743	6075	50	20D
0005434600753	6075	51	20E
0005434600482	18589	1	1D
0005434600444	18589	2	2A
0005435326716	18589	3	2D
0005434600493	18589	4	3A
0005434600491	18589	5	3F
0005433527217	18589	6	4C
0005434600536	18589	7	4E
0005434600579	18589	8	7A
0005435326717	18589	9	7C
0005435326723	18589	10	7D
0005434600496	18589	11	7E
0005434600560	18589	12	7F
0005435326714	18589	13	8C
0005434600553	18589	14	8D
0005435326721	18589	15	8E
0005434600518	18589	16	8F
0005433527212	18589	17	9F
0005435326718	18589	18	10E
0005434600492	18589	19	11F
0005435326713	18589	20	12E
0005433527200	18589	21	12F
0005434600433	18589	22	13A
0005434600470	18589	23	13F
0005434600527	18589	24	14C
0005434600507	18589	25	14D
0005434600510	18589	26	14F
0005435326711	18589	27	15A
0005435326720	18589	28	15D
0005433531251	18589	29	16A
0005434600479	18589	30	16E
0005433527199	18589	31	16F
0005433527218	18589	32	17A
0005434600580	18589	33	17E
0005435326722	18589	34	18C
0005434600411	18589	35	18D
0005433527211	18589	36	19C
0005435326719	18589	37	19D
0005434600559	18589	38	20A
0005435326712	18589	39	20C
0005433527213	18589	40	20D
0005435326715	18589	41	20E
0005433180749	10665	1	1A
0005434551064	10665	2	1C
0005434551049	10665	3	1D
0005434551090	10665	4	1F
0005434551082	10665	5	2A
0005433180849	10665	6	2C
0005434551046	10665	7	2D
0005434551084	10665	8	2F
0005433180723	10665	9	3A
0005434551098	10665	10	3C
0005434551055	10665	11	3D
0005433180792	10665	12	3F
0005433180833	10665	13	4A
0005434551048	10665	14	4C
0005434551062	10665	15	4D
0005434558236	10665	16	4E
0005434551047	10665	17	4F
0005434551072	10665	18	5A
0005434551051	10665	19	5C
0005434551061	10665	20	5D
0005434551068	10665	21	5E
0005434551065	10665	22	5F
0005434551044	10665	23	6A
0005434551091	10665	24	6C
0005434551069	10665	25	6D
0005434551075	10665	26	6E
0005433180851	10665	27	6F
0005433180857	10665	28	7A
0005434558238	10665	29	7C
0005434551097	10665	30	7D
0005434551076	10665	31	7E
0005434551053	10665	32	7F
0005434551057	10665	33	8A
0005434558240	10665	34	8D
0005434551045	10665	35	8F
0005434558239	10665	36	9A
0005434551050	10665	37	9C
0005434551081	10665	38	9D
0005433180882	10665	39	9E
0005434551078	10665	40	9F
0005434558234	10665	41	10A
0005433180730	10665	42	10C
0005434551060	10665	43	10D
0005434551071	10665	44	10E
0005434551059	10665	45	10F
0005434551054	10665	46	11A
0005434558237	10665	47	11C
0005434551085	10665	48	11D
0005434551089	10665	49	11E
0005434551079	10665	50	12A
0005434551070	10665	51	12C
0005434551096	10665	52	12D
0005433180852	10665	53	12E
0005434558241	10665	54	12F
0005433180881	10665	55	13A
0005433180779	10665	56	13C
0005434558235	10665	57	13D
0005434554060	10665	58	13E
0005433180858	10665	59	13F
0005434551083	10665	60	14A
0005434551092	10665	61	14C
0005433180853	10665	62	14D
0005434551093	10665	63	14E
0005434551067	10665	64	14F
0005434551094	10665	65	15A
0005434554059	10665	66	15C
0005433180780	10665	67	15D
0005434551073	10665	68	15E
0005433180898	10665	69	15F
0005433180816	10665	70	16A
0005434551095	10665	71	16C
0005433180850	10665	72	16D
0005434551052	10665	73	16E
0005434551056	10665	74	16F
0005433180800	10665	75	17A
0005434558242	10665	76	17C
0005434551074	10665	77	17D
0005433180782	10665	78	17E
0005434558233	10665	79	18A
0005434551063	10665	80	17F
0005434551058	10665	81	18C
0005434551066	10665	82	18D
0005434551086	10665	83	18E
0005433180783	10665	84	18F
0005434551088	10665	85	19A
0005434558243	10665	86	19D
0005433180801	10665	87	19C
0005433180750	10665	88	19E
0005434551087	10665	89	19F
0005434551077	10665	90	20A
0005433180880	10665	91	20C
0005433180899	10665	92	20D
0005434551080	10665	93	20F
0005433181041	27708	1	2A
0005433181058	27708	2	3A
0005433181059	27708	3	5C
0005433181055	27708	4	5F
0005433181040	27708	5	6E
0005433181049	27708	6	6F
0005433181046	27708	7	7A
0005433181056	27708	8	7C
0005433181060	27708	9	7E
0005433181061	27708	10	7F
0005433181057	27708	11	8F
0005433181042	27708	12	9D
0005433181050	27708	13	9E
0005433181052	27708	14	10F
0005433181054	27708	15	11A
0005433181038	27708	16	12C
0005433181048	27708	17	13A
0005433181053	27708	18	13C
0005433181044	27708	19	13D
0005433181051	27708	20	16D
0005433181039	27708	21	16E
0005433181037	27708	22	18D
0005433181036	27708	23	18E
0005433181043	27708	24	19C
0005433181047	27708	25	19F
0005433181045	27708	26	20E
0005434550682	27707	1	1C
0005434558166	27707	2	1D
0005434550612	27707	3	1F
0005434550672	27707	4	2A
0005434550728	27707	5	2C
0005434550847	27707	6	2D
0005434550443	27707	7	3A
0005434550512	27707	8	3C
0005434550780	27707	9	3D
0005434550779	27707	10	3F
0005434550652	27707	11	4A
0005434550668	27707	12	4C
0005434558184	27707	13	4D
0005434550513	27707	14	4E
0005434550667	27707	15	5A
0005434550758	27707	16	5C
0005434550613	27707	17	5E
0005434554037	27707	18	5F
0005434550683	27707	19	6E
0005434550789	27707	20	7A
0005434554036	27707	21	7D
0005434550666	27707	22	7E
0005434550482	27707	23	7F
0005434554033	27707	24	8A
0005434550371	27707	25	8D
0005434550717	27707	26	8E
0005434550725	27707	27	8F
0005434550759	27707	28	9A
0005434554032	27707	29	9D
0005434550926	27707	30	9E
0005434550694	27707	31	9F
0005434550641	27707	32	10C
0005434550621	27707	33	10E
0005434550769	27707	34	11A
0005434550715	27707	35	11C
0005434554038	27707	36	11E
0005434550614	27707	37	11F
0005434550544	27707	38	12A
0005434550729	27707	39	12C
0005434550770	27707	40	13C
0005434558185	27707	41	13D
0005434558167	27707	42	13E
0005434550654	27707	43	13F
0005434550622	27707	44	14F
0005434550393	27707	45	15D
0005434550852	27707	46	16A
0005434550653	27707	47	16C
0005434550684	27707	48	16D
0005434550790	27707	49	16F
0005434550474	27707	50	17E
0005434550447	27707	51	18A
0005434550591	27707	52	18D
0005434550753	27707	53	18E
0005434550635	27707	54	18F
0005434550665	27707	55	19A
0005434550815	27707	56	19C
0005434558149	27707	57	20A
0005434550269	27707	58	20D
0005434550771	27707	59	20E
0005434550800	27707	60	20F
0005433459209	6164	1	1A
0005433459212	6164	2	3B
0005433459211	6164	3	4A
0005433459213	6164	4	5B
0005433459210	6164	5	6A
0005435254469	19339	1	1A
0005435254468	19339	2	2A
0005433459177	19339	3	3A
0005435254470	19339	4	4B
0005433459172	19339	5	5B
0005433459176	19339	6	6A
0005435437659	6728	1	1A
0005435437772	6728	2	1C
0005432136159	6728	3	1D
0005435437697	6728	4	1F
0005432136158	6728	5	2A
0005435682042	6728	6	2C
0005435217694	6728	7	2D
0005435437719	6728	8	2F
0005435682064	6728	9	3A
0005435682033	6728	10	3F
0005435682061	6728	11	4A
0005435682055	6728	12	4C
0005434828660	6728	13	4D
0005435437673	6728	14	4F
0005435682035	6728	15	5A
0005435682062	6728	16	5C
0005435682048	6728	17	5D
0005435661922	6728	18	5E
0005435437674	6728	19	5F
0005435682058	6728	20	6A
0005435682038	6728	21	6C
0005432533245	6728	22	6D
0005434828657	6728	23	6E
0005435437726	6728	24	6F
0005435682063	6728	25	7A
0005435682043	6728	26	7C
0005435217681	6728	27	7D
0005432136155	6728	28	7E
0005435682059	6728	29	7F
0005435682053	6728	30	8A
0005435682041	6728	31	8C
0005434828662	6728	32	8D
0005432136157	6728	33	8E
0005435682037	6728	34	8F
0005435437708	6728	35	9C
0005435437722	6728	36	9D
0005435682044	6728	37	9E
0005434828656	6728	38	9F
0005435630957	6728	39	10A
0005434828665	6728	40	10C
0005435682027	6728	41	10D
0005435217679	6728	42	10E
0005435217693	6728	43	10F
0005435630958	6728	44	11C
0005435682036	6728	45	11D
0005435630959	6728	46	11E
0005435682039	6728	47	11F
0005435217680	6728	48	12A
0005435682056	6728	49	12C
0005435682045	6728	50	12D
0005435682034	6728	51	12E
0005435437721	6728	52	12F
0005435661921	6728	53	13A
0005435682032	6728	54	13C
0005435437703	6728	55	13D
0005435437723	6728	56	13E
0005435682030	6728	57	13F
0005434828655	6728	58	14A
0005435217692	6728	59	14C
0005435682031	6728	60	14D
0005435437777	6728	61	14E
0005435437783	6728	62	14F
0005435661923	6728	63	15C
0005435682049	6728	64	15D
0005435682046	6728	65	15E
0005435682057	6728	66	15F
0005435682028	6728	67	16A
0005435682047	6728	68	16C
0005435682029	6728	69	16D
0005435682040	6728	70	16E
0005435682060	6728	71	16F
0005434828658	6728	72	17A
0005432533252	6728	73	17C
0005435682050	6728	74	17D
0005435220292	6728	75	17E
0005435682054	6728	76	17F
0005435217691	6728	77	18A
0005435437778	6728	78	18C
0005434828659	6728	79	18D
0005435437720	6728	80	18E
0005434828654	6728	81	18F
0005435682051	6728	82	19A
0005435682052	6728	83	19C
0005435437693	6728	84	19D
0005432533266	6728	85	19E
0005435437698	6728	86	20C
0005432136156	6728	87	20D
0005432533246	6728	88	20E
0005432533253	6728	89	20F
0005435681452	24573	1	1A
0005435437894	24573	2	1C
0005432305743	24573	3	1F
0005435681749	24573	4	2A
0005435681756	24573	5	2C
0005435661891	24573	6	2D
0005435681780	24573	7	2F
0005435220313	24573	8	3A
0005435219194	24573	9	3C
0005434828692	24573	10	3D
0005435681788	24573	11	3F
0005435220311	24573	12	4A
0005435681787	24573	13	4C
0005435681617	24573	14	4D
0005432533286	24573	15	4E
0005435437901	24573	16	5A
0005435681558	24573	17	5C
0005435681747	24573	18	5D
0005435681568	24573	19	5E
0005435681585	24573	20	5F
0005435681767	24573	21	6C
0005435437908	24573	22	6D
0005435681642	24573	23	6E
0005435437898	24573	24	6F
0005435437907	24573	25	7A
0005435437911	24573	26	7C
0005435219195	24573	27	7D
0005435437910	24573	28	7E
0005435681598	24573	29	7F
0005435437909	24573	30	8C
0005435681740	24573	31	8D
0005435437900	24573	32	8E
0005435681604	24573	33	8F
0005435681634	24573	34	9A
0005435681755	24573	35	9C
0005435681757	24573	36	9D
0005435630929	24573	37	9E
0005434828693	24573	38	9F
0005435681758	24573	39	10A
0005435220312	24573	40	10C
0005435437893	24573	41	10D
0005435437903	24573	42	10E
0005435220315	24573	43	10F
0005435681445	24573	44	11A
0005435681644	24573	45	11C
0005435681655	24573	46	11D
0005435681722	24573	47	11E
0005435219192	24573	48	12A
0005435220490	24573	49	12D
0005435437895	24573	50	12E
0005435681748	24573	51	12F
0005435681687	24573	52	13A
0005435681510	24573	53	13C
0005432533285	24573	54	13D
0005435681741	24573	55	13E
0005435681599	24573	56	13F
0005435437897	24573	57	14A
0005435681641	24573	58	14C
0005435681793	24573	59	14D
0005435437904	24573	60	14E
0005435681554	24573	61	14F
0005435681623	24573	62	15A
0005435681789	24573	63	15C
0005435437902	24573	64	15D
0005435437899	24573	65	15E
0005435681538	24573	66	15F
0005435437913	24573	67	16A
0005435681746	24573	68	16C
0005435437914	24573	69	16D
0005432305744	24573	70	16E
0005435661880	24573	71	16F
0005435219193	24573	72	17A
0005435681654	24573	73	17C
0005435681734	24573	74	17D
0005435437896	24573	75	17E
0005434828691	24573	76	17F
0005435681603	24573	77	18C
0005435220314	24573	78	18D
0005435681569	24573	79	18E
0005435681792	24573	80	19A
0005435437905	24573	81	18F
0005435681719	24573	82	19C
0005435681446	24573	83	19D
0005435437912	24573	84	19E
0005435681693	24573	85	19F
0005435681720	24573	86	20A
0005435681773	24573	87	20D
0005435437906	24573	88	20E
0005435219196	24573	89	20F
0005435126232	11524	1	1D
0005435126240	11524	2	1F
0005435126257	11524	3	2A
0005435126233	11524	4	2D
0005435126261	11524	5	2F
0005435126241	11524	6	3C
0005435126250	11524	7	3F
0005435126269	11524	8	4E
0005435126243	11524	9	4D
0005435126231	11524	10	5C
0005435126265	11524	11	5D
0005435098547	11524	12	5E
0005435105971	11524	13	6A
0005435098548	11524	14	6C
0005435126239	11524	15	6D
0005435126259	11524	16	6E
0005435126238	11524	17	7A
0005435098544	11524	18	7D
0005435105974	11524	19	8C
0005435126242	11524	20	8D
0005435126256	11524	21	9C
0005435126264	11524	22	9D
0005435126236	11524	23	9E
0005435126235	11524	24	10A
0005435126263	11524	25	10C
0005435105972	11524	26	10D
0005435098545	11524	27	11E
0005435105973	11524	28	12A
0005435126270	11524	29	12E
0005435126255	11524	30	13D
0005435126247	11524	31	13E
0005435126237	11524	32	13F
0005435126262	11524	33	14D
0005435126245	11524	34	14E
0005435126248	11524	35	15A
0005435098551	11524	36	15D
0005435126244	11524	37	15E
0005435126251	11524	38	16C
0005435098546	11524	39	16D
0005435126246	11524	40	16E
0005435126268	11524	41	17A
0005435098550	11524	42	17C
0005435126266	11524	43	17D
0005435126234	11524	44	18A
0005435126252	11524	45	19A
0005435126254	11524	46	19D
0005435126271	11524	47	19E
0005435126260	11524	48	19F
0005435126267	11524	49	20A
0005435126258	11524	50	20C
0005435126249	11524	51	20D
0005435126253	11524	52	20E
0005435098549	11524	53	20F
0005435125838	31855	1	1A
0005435125858	31855	2	1C
0005435125975	31855	3	2D
0005435125951	31855	4	3C
0005435125976	31855	5	3D
0005435098530	31855	6	4A
0005435126012	31855	7	4C
0005435125868	31855	8	4D
0005435126041	31855	9	4E
0005435126030	31855	10	4F
0005435125961	31855	11	5A
0005435126013	31855	12	5D
0005435125944	31855	13	6A
0005435125978	31855	14	6C
0005435126037	31855	15	6D
0005435125826	31855	16	7A
0005435126101	31855	17	7C
0005435126112	31855	18	7D
0005435125829	31855	19	7E
0005435125942	31855	20	8C
0005435125902	31855	21	8D
0005435558082	31855	22	9A
0005435125970	31855	23	9C
0005435125837	31855	24	9E
0005435125903	31855	25	10D
0005435126035	31855	26	10F
0005435125989	31855	27	11A
0005435126014	31855	28	11D
0005435125880	31855	29	11E
0005435125865	31855	30	12D
0005435125848	31855	31	12E
0005435125946	31855	32	12F
0005435125960	31855	33	13A
0005435125859	31855	34	13C
0005435125977	31855	35	13D
0005435126060	31855	36	13E
0005435098537	31855	37	14A
0005435126061	31855	38	14C
0005435126100	31855	39	14D
0005435125996	31855	40	14E
0005435126074	31855	41	15F
0005435126036	31855	42	16E
0005435098536	31855	43	17D
0005435125964	31855	44	17E
0005435126116	31855	45	18E
0005435126079	31855	46	19A
0005435125990	31855	47	19C
0005435126001	31855	48	19E
0005435558081	31855	49	20A
0005435125888	31855	50	20C
0005435125945	31855	51	20D
0005435126018	31855	52	20F
0005433397953	13535	1	1A
0005433397931	13535	2	1D
0005433397955	13535	3	1F
0005435732223	13535	4	2A
0005433397928	13535	5	2C
0005435732184	13535	6	2D
0005433397942	13535	7	2F
0005435732183	13535	8	3D
0005433397925	13535	9	4C
0005433397945	13535	10	4D
0005433397933	13535	11	4E
0005433397943	13535	12	4F
0005433397957	13535	13	5A
0005433397950	13535	14	5C
0005435732190	13535	15	5D
0005433397926	13535	16	6C
0005433397930	13535	17	6E
0005433397939	13535	18	6F
0005433397959	13535	19	7A
0005433397971	13535	20	7E
0005433397929	13535	21	7F
0005435732230	13535	22	8C
0005433397936	13535	23	8E
0005433397973	13535	24	8F
0005433397972	13535	25	9A
0005433397946	13535	26	9C
0005433397952	13535	27	9D
0005433397960	13535	28	9E
0005433397948	13535	29	10A
0005433397937	13535	30	10D
0005433397944	13535	31	11A
0005435732229	13535	32	11D
0005433397951	13535	33	11E
0005433397947	13535	34	12A
0005433397954	13535	35	12C
0005433397970	13535	36	12F
0005433397935	13535	37	13A
0005433397927	13535	38	13D
0005435732185	13535	39	13E
0005433397934	13535	40	14D
0005433397966	13535	41	14E
0005433397968	13535	42	14F
0005433397932	13535	43	15D
0005435732224	13535	44	15C
0005433397963	13535	45	15F
0005435732210	13535	46	16C
0005433397940	13535	47	16D
0005433397969	13535	48	16E
0005433397938	13535	49	16F
0005433397961	13535	50	17D
0005433397974	13535	51	18C
0005435732231	13535	52	18D
0005433397949	13535	53	18F
0005433397962	13535	54	19A
0005433397967	13535	55	19C
0005433397964	13535	56	19D
0005435732209	13535	57	19F
0005433397956	13535	58	20A
0005433397965	13535	59	20C
0005433397941	13535	60	20E
0005433397958	13535	61	20F
0005433397454	19391	1	1A
0005433397723	19391	2	1C
0005433397606	19391	3	1F
0005435732294	19391	4	2A
0005433397365	19391	5	2C
0005433397475	19391	6	2D
0005435732300	19391	7	2F
0005433397393	19391	8	3A
0005433397484	19391	9	3C
0005433397379	19391	10	3D
0005433397607	19391	11	3F
0005435732295	19391	12	4A
0005432297273	19391	13	4C
0005435732301	19391	14	4D
0005433397449	19391	15	5A
0005433397310	19391	16	5C
0005435732298	19391	17	5F
0005435732310	19391	18	6D
0005433397561	19391	19	6E
0005435732299	19391	20	6F
0005433397392	19391	21	7C
0005435732293	19391	22	7D
0005435732311	19391	23	7E
0005433397412	19391	24	8A
0005433397649	19391	25	8C
0005435732314	19391	26	8E
0005435732296	19391	27	8F
0005435732297	19391	28	9C
0005433397513	19391	29	9D
0005432297272	19391	30	9E
0005433397615	19391	31	10A
0005433397711	19391	32	10C
0005435732313	19391	33	10D
0005435732303	19391	34	10F
0005433397710	19391	35	11F
0005435732302	19391	36	12D
0005435732315	19391	37	12E
0005435732308	19391	38	12F
0005435732305	19391	39	13F
0005435732312	19391	40	14C
0005433397451	19391	41	14D
0005433397499	19391	42	14E
0005433397464	19391	43	14F
0005433397483	19391	44	15A
0005435732309	19391	45	15F
0005433397406	19391	46	16A
0005435732307	19391	47	16D
0005433397560	19391	48	16F
0005432297271	19391	49	17A
0005433397599	19391	50	17C
0005435732304	19391	51	17D
0005435732316	19391	52	17E
0005433397358	19391	53	17F
0005433397442	19391	54	18A
0005433397538	19391	55	18C
0005433397364	19391	56	18D
0005433397616	19391	57	18E
0005435732306	19391	58	18F
0005433397559	19391	59	19A
0005433397450	19391	60	19C
0005433397409	19391	61	19D
0005433397549	19391	62	19E
0005433397463	19391	63	20A
0005433397514	19391	64	20C
0005433397712	19391	65	20F
0005435068469	13178	1	1A
0005435925272	13178	2	1D
0005435068396	13178	3	1F
0005435068625	13178	4	2A
0005435925275	13178	5	2C
0005435068308	13178	6	2D
0005435068573	13178	7	3A
0005435068510	13178	8	3C
0005435068555	13178	9	4C
0005435925271	13178	10	4A
0005435068375	13178	11	4D
0005435068423	13178	12	4F
0005435068288	13178	13	5C
0005435068345	13178	14	5D
0005435068534	13178	15	5F
0005435068376	13178	16	6D
0005435925277	13178	17	6E
0005435068571	13178	18	6F
0005435925269	13178	19	7A
0005435068203	13178	20	7C
0005435068478	13178	21	7D
0005435068464	13178	22	7F
0005435068655	13178	23	8A
0005435068732	13178	24	8C
0005435068204	13178	25	8D
0005435068304	13178	26	8E
0005435068570	13178	27	8F
0005435068605	13178	28	9A
0005435068392	13178	29	9C
0005435068443	13178	30	9D
0005435068395	13178	31	9F
0005435068585	13178	32	10C
0005435068450	13178	33	10D
0005435068654	13178	34	10E
0005435068616	13178	35	11C
0005435068437	13178	36	11D
0005435068479	13178	37	11F
0005435068554	13178	38	12A
0005435068309	13178	39	12C
0005435068460	13178	40	12E
0005435068525	13178	41	13D
0005435068574	13178	42	13F
0005435068511	13178	43	14A
0005435068548	13178	44	14C
0005435068379	13178	45	14D
0005435068577	13178	46	14E
0005435068572	13178	47	15A
0005435068344	13178	48	15D
0005435068427	13178	49	15F
0005435925276	13178	50	16A
0005435068660	13178	51	16C
0005435068576	13178	52	16D
0005435925270	13178	53	16F
0005435068661	13178	54	17A
0005435068459	13178	55	17C
0005435068604	13178	56	17D
0005435925273	13178	57	17E
0005435068330	13178	58	17F
0005435068325	13178	59	18A
0005435068590	13178	60	18E
0005435068545	13178	61	19D
0005435068566	13178	62	19F
0005435068320	13178	63	20A
0005435068353	13178	64	20C
0005435925274	13178	65	20D
0005435068431	13178	66	20E
0005435068584	13178	67	20F
0005435068932	15511	1	1A
0005435068918	15511	2	1D
0005435068940	15511	3	1F
0005435925148	15511	4	2A
0005435068927	15511	5	2D
0005435925109	15511	6	3A
0005435068928	15511	7	3F
0005435068916	15511	8	4D
0005435068933	15511	9	4E
0005435068939	15511	10	4F
0005435068944	15511	11	5A
0005435068917	15511	12	5D
0005435068921	15511	13	5E
0005435068906	15511	14	5F
0005435068929	15511	15	6A
0005435068934	15511	16	6C
0005435068952	15511	17	6F
0005435068931	15511	18	7A
0005435068913	15511	19	7D
0005435068946	15511	20	7F
0005435068951	15511	21	8A
0005435068920	15511	22	8C
0005435068949	15511	23	8D
0005435068945	15511	24	9A
0005435068907	15511	25	9C
0005435068903	15511	26	9D
0005435068926	15511	27	10A
0005435068915	15511	28	10C
0005435068948	15511	29	10E
0005435068909	15511	30	11A
0005435068910	15511	31	11C
0005435068950	15511	32	11D
0005435068914	15511	33	11E
0005435925147	15511	34	11F
0005435068901	15511	35	12A
0005435925073	15511	36	12C
0005435068935	15511	37	12D
0005435068923	15511	38	12F
0005435068919	15511	39	13A
0005435068922	15511	40	13C
0005435925142	15511	41	13D
0005435925126	15511	42	14C
0005435068908	15511	43	14E
0005435068942	15511	44	15A
0005435925146	15511	45	15D
0005435068941	15511	46	15F
0005435068925	15511	47	16A
0005435068936	15511	48	16C
0005435068905	15511	49	16D
0005435068938	15511	50	16F
0005435068912	15511	51	17D
0005435068924	15511	52	17E
0005435068902	15511	53	17F
0005435068904	15511	54	18A
0005435925114	15511	55	18C
0005435068911	15511	56	18D
0005435068930	15511	57	18E
0005435925169	15511	58	19A
0005435068943	15511	59	19D
0005435925127	15511	60	20A
0005435068947	15511	61	20C
0005435068937	15511	62	20D
0005435925061	15511	63	20E
0005435808194	23188	1	1C
0005433407491	23188	2	1D
0005435808208	23188	3	2B
0005435808203	23188	4	2D
0005433407505	23188	5	4A
0005435808201	23188	6	4C
0005435808205	23188	7	4D
0005435808190	23188	8	5B
0005435808189	23188	9	5C
0005435808200	23188	10	5D
0005435808188	23188	11	6A
0005435808207	23188	12	6C
0005435808191	23188	13	6D
0005435808195	23188	14	7B
0005435808197	23188	15	7C
0005433407506	23188	16	18A
0005435808192	23188	17	18C
0005435808193	23188	18	18D
0005435808206	23188	19	19A
0005433407496	23188	20	20A
0005435808199	23188	21	20B
0005435808202	23188	22	20D
0005435808204	23188	23	21B
0005435808196	23188	24	21C
0005433407482	23188	25	21D
0005433407495	23188	26	22C
0005435808198	23188	27	22D
0005434755920	10703	1	1A
0005434214456	10703	2	1C
0005434755991	10703	3	1D
0005434214447	10703	4	1F
0005434214438	10703	5	2C
0005434755956	10703	6	2D
0005434214437	10703	7	2F
0005434214440	10703	8	3A
0005434755796	10703	9	3C
0005434755855	10703	10	3D
0005434214439	10703	11	3F
0005434755977	10703	12	4A
0005434214419	10703	13	4C
0005434214441	10703	14	4D
0005434214452	10703	15	4F
0005434214434	10703	16	5A
0005434755881	10703	17	5C
0005434214420	10703	18	5D
0005434214425	10703	19	5E
0005434214422	10703	20	5F
0005434214423	10703	21	6A
0005434755910	10703	22	6C
0005434214444	10703	23	6D
0005434755909	10703	24	6F
0005434755980	10703	25	7A
0005434755990	10703	26	7C
0005434214415	10703	27	7D
0005434214445	10703	28	7E
0005434214429	10703	29	7F
0005434755865	10703	30	8A
0005434755845	10703	31	8C
0005434214457	10703	32	8D
0005434755997	10703	33	8E
0005434214451	10703	34	8F
0005434214443	10703	35	9A
0005434214418	10703	36	9C
0005434755880	10703	37	9D
0005434214421	10703	38	9E
0005434214435	10703	39	9F
0005434214417	10703	40	10A
0005434214428	10703	41	10C
0005434755854	10703	42	10D
0005434755950	10703	43	10E
0005434214454	10703	44	10F
0005434755949	10703	45	11A
0005434214416	10703	46	11C
0005434755973	10703	47	11D
0005434755853	10703	48	11E
0005434755861	10703	49	11F
0005434214413	10703	50	12A
0005434214436	10703	51	12C
0005434755925	10703	52	12D
0005434214426	10703	53	12E
0005434755795	10703	54	12F
0005434755862	10703	55	13A
0005434214449	10703	56	13C
0005434214432	10703	57	13D
0005434755996	10703	58	13E
0005434756004	10703	59	13F
0005434214430	10703	60	14A
0005434214453	10703	61	14C
0005434214450	10703	62	14D
0005434755921	10703	63	14E
0005434755939	10703	64	14F
0005434214427	10703	65	15A
0005434755994	10703	66	15C
0005434755709	10703	67	15D
0005434214433	10703	68	15E
0005434755868	10703	69	15F
0005434214442	10703	70	16A
0005434755938	10703	71	16D
0005434755846	10703	72	16E
0005434214424	10703	73	16F
0005434755872	10703	74	17A
0005434214448	10703	75	17C
0005434214446	10703	76	17D
0005434214431	10703	77	17E
0005434756005	10703	78	18A
0005434756006	10703	79	18C
0005434214414	10703	80	18D
0005434755783	10703	81	18E
0005434755926	10703	82	18F
0005434755955	10703	83	19A
0005434214458	10703	84	19C
0005434755879	10703	85	19D
0005434755871	10703	86	19E
0005434755976	10703	87	19F
0005434755892	10703	88	20A
0005434755912	10703	89	20C
0005434755899	10703	90	20D
0005434214455	10703	91	20E
0005434755981	10703	92	20F
0005434213899	28708	1	1A
0005434214059	28708	2	1C
0005434213885	28708	3	1D
0005434213830	28708	4	1F
0005434756299	28708	5	2A
0005434756311	28708	6	2C
0005434756313	28708	7	2D
0005434213833	28708	8	2F
0005434213915	28708	9	3A
0005434756289	28708	10	3C
0005434214047	28708	11	3D
0005434214004	28708	12	3F
0005434756315	28708	13	4A
0005434756292	28708	14	4C
0005434214036	28708	15	4D
0005434756308	28708	16	4E
0005434756326	28708	17	4F
0005434213985	28708	18	5A
0005434213995	28708	19	5C
0005434214104	28708	20	5D
0005434756295	28708	21	5E
0005434756323	28708	22	5F
0005434756317	28708	23	6A
0005434214019	28708	24	6D
0005434756328	28708	25	6C
0005434213935	28708	26	6E
0005434213986	28708	27	6F
0005434756327	28708	28	7C
0005434213954	28708	29	7D
0005434213993	28708	30	7F
0005434756319	28708	31	8A
0005434756301	28708	32	8C
0005434756302	28708	33	8D
0005434756306	28708	34	8E
0005434756298	28708	35	8F
0005434756318	28708	36	9A
0005434756293	28708	37	9C
0005434213782	28708	38	9D
0005434213984	28708	39	9E
0005434213852	28708	40	9F
0005434213944	28708	41	10A
0005434756321	28708	42	10C
0005434756294	28708	43	10D
0005434213862	28708	44	10E
0005434213987	28708	45	10F
0005434756304	28708	46	11A
0005434213924	28708	47	11C
0005434756297	28708	48	11D
0005434756303	28708	49	11E
0005434213942	28708	50	11F
0005434756322	28708	51	12A
0005434213889	28708	52	12C
0005434214109	28708	53	12D
0005434756316	28708	54	12E
0005434756320	28708	55	12F
0005434213988	28708	56	13A
0005434213914	28708	57	13C
0005434214108	28708	58	13D
0005434213834	28708	59	13E
0005434756305	28708	60	13F
0005434213781	28708	61	14A
0005434756310	28708	62	14C
0005434213824	28708	63	14D
0005434213823	28708	64	14E
0005434756324	28708	65	14F
0005434756325	28708	66	15A
0005434756287	28708	67	15C
0005434756300	28708	68	15D
0005434213943	28708	69	15E
0005434214029	28708	70	15F
0005434213878	28708	71	16A
0005434756309	28708	72	16C
0005434756312	28708	73	16D
0005434213907	28708	74	16E
0005434756314	28708	75	16F
0005434213939	28708	76	17A
0005434213971	28708	77	17C
0005434213931	28708	78	17D
0005434756290	28708	79	17E
0005434214046	28708	80	17F
0005434213956	28708	81	18A
0005434756288	28708	82	18C
0005434756291	28708	83	18D
0005434213848	28708	84	18F
0005434213955	28708	85	19A
0005434756296	28708	86	19C
0005434756307	28708	87	19D
0005434213957	28708	88	19E
0005434214057	28708	89	19F
0005434214025	28708	90	20A
0005434213994	28708	91	20C
0005434213817	28708	92	20E
0005434213932	28708	93	20F
0005435039604	5427	1	1A
0005435039627	5427	2	1C
0005435039609	5427	3	1D
0005435006978	5427	4	1F
0005435039606	5427	5	2C
0005435039605	5427	6	2D
0005435042855	5427	7	2F
0005435039641	5427	8	3A
0005435039644	5427	9	3D
0005435039646	5427	10	3F
0005435039658	5427	11	4A
0005435039600	5427	12	4C
0005435039614	5427	13	4B
0005435039653	5427	14	4E
0005435039659	5427	15	4D
0005435039610	5427	16	5A
0005432125438	5427	17	4F
0005435039620	5427	18	5B
0005434229088	5427	19	5C
0005434229151	5427	20	5D
0005435039639	5427	21	5E
0005435039602	5427	22	5F
0005434229089	5427	23	6B
0005435006980	5427	24	6A
0005435006985	5427	25	6D
0005432125434	5427	26	6E
0005435039626	5427	27	7B
0005435039636	5427	28	7A
0005435042853	5427	29	7C
0005435006975	5427	30	7D
0005435039603	5427	31	7E
0005434229115	5427	32	8A
0005435039632	5427	33	7F
0005432125437	5427	34	8B
0005435039608	5427	35	8D
0005435039628	5427	36	8C
0005435039635	5427	37	8F
0005435039650	5427	38	8E
0005435039655	5427	39	9A
0005435006990	5427	40	9B
0005432125435	5427	41	9C
0005435006989	5427	42	9E
0005435039652	5427	43	9D
0005434229181	5427	44	9F
0005435039645	5427	45	10B
0005435006974	5427	46	10D
0005435039657	5427	47	10C
0005435039622	5427	48	10E
0005435039647	5427	49	11A
0005435039630	5427	50	11B
0005435039617	5427	51	11D
0005434228993	5427	52	11C
0005435039623	5427	53	11E
0005435006994	5427	54	11F
0005435039634	5427	55	12B
0005435039667	5427	56	12A
0005434229137	5427	57	12D
0005435006984	5427	58	12C
0005435006969	5427	59	12E
0005435039662	5427	60	12F
0005435039624	5427	61	13B
0005435039668	5427	62	13A
0005435006987	5427	63	13D
0005435006976	5427	64	13C
0005435006982	5427	65	13E
0005435039607	5427	66	13F
0005435039642	5427	67	14B
0005435039663	5427	68	14C
0005435006992	5427	69	14E
0005435039612	5427	70	15A
0005435039615	5427	71	14F
0005435039665	5427	72	15C
0005434229152	5427	73	15B
0005434229066	5427	74	15D
0005435039618	5427	75	15F
0005434229110	5427	76	15E
0005434229081	5427	77	16A
0005435006973	5427	78	16B
0005435006979	5427	79	16C
0005435039651	5427	80	16D
0005432125436	5427	81	16E
0005435006986	5427	82	17A
0005435039616	5427	83	16F
0005435039633	5427	84	17B
0005432125432	5427	85	17C
0005435039654	5427	86	17D
0005435039643	5427	87	17F
0005435006981	5427	88	17E
0005435006983	5427	89	18A
0005435006977	5427	90	18B
0005435039613	5427	91	18C
0005435006993	5427	92	18E
0005435039649	5427	93	18D
0005435006972	5427	94	18F
0005435039666	5427	95	19A
0005435039601	5427	96	19B
0005435006970	5427	97	19D
0005435039625	5427	98	19C
0005435039660	5427	99	19E
0005432125433	5427	100	19F
0005434229216	5427	101	20A
0005434229125	5427	102	20C
0005435039631	5427	103	20B
0005435039621	5427	104	20D
0005435039664	5427	105	20E
0005434229189	5427	106	20F
0005435006991	5427	107	21A
0005435039638	5427	108	21B
0005435006988	5427	109	21D
0005435039656	5427	110	21C
0005435039640	5427	111	21F
0005435039629	5427	112	21E
0005434229160	5427	113	22B
0005435043285	5427	114	22A
0005435039637	5427	115	22C
0005435039611	5427	116	22D
0005435039661	5427	117	22F
0005435042852	5427	118	22E
0005434229103	5427	119	23B
0005435039648	5427	120	23D
0005435042854	5427	121	23C
0005435006971	5427	122	23F
0005435039619	5427	123	23E
0005435039377	13007	1	1A
0005435038714	13007	2	1C
0005435038791	13007	3	1D
0005434229320	13007	4	1F
0005434229326	13007	5	2C
0005435006739	13007	6	2A
0005435042833	13007	7	2F
0005435039318	13007	8	3D
0005435042835	13007	9	3F
0005435039002	13007	10	4B
0005434229321	13007	11	4C
0005435039248	13007	12	4E
0005435039077	13007	13	4D
0005434229324	13007	14	5B
0005435038946	13007	15	5A
0005435006852	13007	16	5D
0005435006776	13007	17	5C
0005435038972	13007	18	5E
0005435006738	13007	19	6A
0005432304391	13007	20	6C
0005435039078	13007	21	6B
0005435006798	13007	22	6D
0005435006815	13007	23	6E
0005435006737	13007	24	7A
0005435039168	13007	25	7C
0005434229327	13007	26	7E
0005435038885	13007	27	7D
0005434229334	13007	28	8A
0005435039076	13007	29	7F
0005435006723	13007	30	8B
0005435039110	13007	31	8C
0005435006705	13007	32	8E
0005435039059	13007	33	8D
0005435039026	13007	34	8F
0005435038790	13007	35	9A
0005435006823	13007	36	9B
0005435039063	13007	37	9D
0005434229325	13007	38	9E
0005435006794	13007	39	9F
0005434229316	13007	40	10B
0005435006753	13007	41	10E
0005435038892	13007	42	11A
0005435039279	13007	43	11B
0005435038924	13007	44	11D
0005434229332	13007	45	11E
0005434229336	13007	46	11F
0005435038928	13007	47	12A
0005435039061	13007	48	12B
0005434229313	13007	49	12D
0005435038985	13007	50	12E
0005435006726	13007	51	13A
0005435042826	13007	52	12F
0005435039117	13007	53	13B
0005435006818	13007	54	13D
0005435038956	13007	55	13C
0005435006730	13007	56	13F
0005434229328	13007	57	13E
0005435038827	13007	58	14B
0005435039297	13007	59	14D
0005435006745	13007	60	14C
0005435006799	13007	61	14E
0005435039084	13007	62	14F
0005434229317	13007	63	15B
0005435038792	13007	64	15A
0005435039167	13007	65	15C
0005435006752	13007	66	15D
0005435039109	13007	67	15E
0005434229333	13007	68	15F
0005435039118	13007	69	16B
0005434229315	13007	70	16A
0005434229330	13007	71	16D
0005435038994	13007	72	16F
0005435042828	13007	73	17A
0005435039116	13007	74	17B
0005435006706	13007	75	17C
0005435006816	13007	76	17E
0005432304389	13007	77	17D
0005434229335	13007	78	17F
0005434229318	13007	79	18C
0005435039237	13007	80	18B
0005435038935	13007	81	18E
0005435039062	13007	82	18D
0005435006750	13007	83	19B
0005435039079	13007	84	19D
0005435006800	13007	85	19C
0005432304390	13007	86	19E
0005435039323	13007	87	19F
0005434229323	13007	88	20B
0005435006740	13007	89	20D
0005432304388	13007	90	20C
0005435042836	13007	91	20F
0005435038894	13007	92	21B
0005434229329	13007	93	21A
0005435038999	13007	94	21D
0005435006725	13007	95	21C
0005435039317	13007	96	21E
0005435038938	13007	97	21F
0005435038907	13007	98	22B
0005434229331	13007	99	22A
0005435039081	13007	100	22D
0005434229319	13007	101	22F
0005435042827	13007	102	23A
0005435039080	13007	103	23B
0005434229314	13007	104	23C
0005435038995	13007	105	23E
0005434229322	13007	106	23F
0005435902497	14868	1	1A
0005434426528	14868	2	1D
0005434426531	14868	3	2A
0005434426512	14868	4	2C
0005435554113	14868	5	2F
0005434426532	14868	6	3A
0005435902478	14868	7	3C
0005434426519	14868	8	3F
0005435902518	14868	9	4A
0005435554120	14868	10	4C
0005435902526	14868	11	4D
0005432188599	14868	12	4E
0005434426522	14868	13	5A
0005434426521	14868	14	5C
0005434411766	14868	15	5E
0005435902510	14868	16	5F
0005434426511	14868	17	6A
0005434426526	14868	18	6C
0005435902485	14868	19	6D
0005435902496	14868	20	6E
0005435554131	14868	21	6F
0005435902494	14868	22	7A
0005434426533	14868	23	7D
0005434426510	14868	24	7F
0005434426509	14868	25	8A
0005434426534	14868	26	8C
0005434426516	14868	27	8E
0005434426523	14868	28	8F
0005435554135	14868	29	9C
0005434426513	14868	30	9D
0005434426537	14868	31	9E
0005435902511	14868	32	10A
0005434426520	14868	33	10C
0005435902527	14868	34	10D
0005434411764	14868	35	11C
0005435554106	14868	36	11D
0005434426517	14868	37	11E
0005434426508	14868	38	12A
0005434426506	14868	39	12C
0005435902479	14868	40	12E
0005434426515	14868	41	12F
0005434411767	14868	42	13A
0005435554119	14868	43	13C
0005434426525	14868	44	13D
0005434426518	14868	45	13F
0005435902514	14868	46	14C
0005435902450	14868	47	15A
0005434426514	14868	48	15C
0005435902465	14868	49	15D
0005435902490	14868	50	15F
0005435902525	14868	51	16C
0005434426524	14868	52	16D
0005435554107	14868	53	16F
0005434426527	14868	54	17A
0005432188598	14868	55	17C
0005434426536	14868	56	17E
0005434426530	14868	57	18C
0005435554108	14868	58	18F
0005434426535	14868	59	19C
0005435902513	14868	60	19D
0005434426507	14868	61	19E
0005434426529	14868	62	20D
0005435902509	14868	63	20E
0005434411765	14868	64	20F
0005434426226	20228	1	1F
0005435902661	20228	2	2C
0005432059500	20228	3	2D
0005434426364	20228	4	2F
0005435902673	20228	5	3A
0005434426298	20228	6	3C
0005434426208	20228	7	4A
0005434426299	20228	8	4C
0005434426354	20228	9	4E
0005434411705	20228	10	4F
0005434426203	20228	11	5A
0005432059499	20228	12	5C
0005435554178	20228	13	5D
0005434426225	20228	14	5E
0005435902671	20228	15	6F
0005434426330	20228	16	7C
0005434411706	20228	17	7D
0005434426320	20228	18	7E
0005434426340	20228	19	8D
0005434411727	20228	20	9C
0005434426404	20228	21	9E
0005434426234	20228	22	9F
0005435902667	20228	23	10C
0005434426291	20228	24	10D
0005435902669	20228	25	10F
0005434426423	20228	26	11A
0005435902660	20228	27	11C
0005434426121	20228	28	11D
0005434426235	20228	29	11E
0005435902662	20228	30	11F
0005435902666	20228	31	12D
0005434426353	20228	32	12F
0005434411736	20228	33	13C
0005434426341	20228	34	13D
0005435902659	20228	35	13F
0005435902674	20228	36	14A
0005434426415	20228	37	14C
0005435554179	20228	38	14D
0005435902665	20228	39	15A
0005434426314	20228	40	15C
0005434426355	20228	41	15D
0005434426414	20228	42	15E
0005435902668	20228	43	16D
0005434426309	20228	44	16E
0005435902670	20228	45	16F
0005435902663	20228	46	17D
0005434426297	20228	47	17E
0005435902658	20228	48	17F
0005434426405	20228	49	18A
0005434411735	20228	50	18C
0005434411737	20228	51	18D
0005434426176	20228	52	18E
0005435554181	20228	53	19D
0005434426313	20228	54	19E
0005435902672	20228	55	19F
0005435554177	20228	56	20C
0005435902664	20228	57	20D
0005435554180	20228	58	20E
0005435902657	20228	59	20F
0005433726070	21655	1	3D
0005433726072	21655	2	7A
0005433726069	21655	3	10D
0005433726066	21655	4	12F
0005433726067	21655	5	14D
0005433726071	21655	6	15C
0005433726063	21655	7	15E
0005433726068	21655	8	17D
0005435982187	26522	1	1A
0005435982159	26522	2	1C
0005435982149	26522	3	1D
0005433434212	26522	4	1F
0005433434451	26522	5	2A
0005435982168	26522	6	2C
0005433434401	26522	7	2D
0005435982147	26522	8	2F
0005433434400	26522	9	3A
0005435982146	26522	10	3C
0005435982179	26522	11	3D
0005435982165	26522	12	3F
0005433434349	26522	13	4A
0005435982167	26522	14	4D
0005433434369	26522	15	4E
0005435982184	26522	16	4F
0005435982182	26522	17	5A
0005435982186	26522	18	5C
0005435982183	26522	19	5D
0005435982155	26522	20	5E
0005435982188	26522	21	5F
0005435982157	26522	22	6A
0005435982142	26522	23	6C
0005435982152	26522	24	6D
0005433434274	26522	25	6E
0005433434273	26522	26	6F
0005435982177	26522	27	7A
0005433434324	26522	28	7C
0005435982174	26522	29	7D
0005435982141	26522	30	7E
0005435982176	26522	31	7F
0005435982148	26522	32	8C
0005435982164	26522	33	8D
0005433434337	26522	34	8F
0005435982170	26522	35	9A
0005435982145	26522	36	9D
0005432300248	26522	37	9E
0005435982163	26522	38	9F
0005435982172	26522	39	10A
0005433434388	26522	40	10C
0005433434334	26522	41	10E
0005435982175	26522	42	10F
0005435982166	26522	43	11A
0005435982178	26522	44	11C
0005435982173	26522	45	11D
0005433434343	26522	46	11E
0005433434368	26522	47	12A
0005435982160	26522	48	12C
0005435982169	26522	49	12D
0005435982180	26522	50	12E
0005435982153	26522	51	12F
0005433434345	26522	52	13A
0005432300244	26522	53	13D
0005435982162	26522	54	13E
0005435982194	26522	55	14A
0005433434248	26522	56	14C
0005433434303	26522	57	14E
0005433434323	26522	58	14F
0005435982181	26522	59	15A
0005433434399	26522	60	15C
0005435982161	26522	61	15D
0005433434389	26522	62	15F
0005433434304	26522	63	15E
0005435982150	26522	64	16A
0005435982158	26522	65	16C
0005435982156	26522	66	16D
0005433434342	26522	67	16E
0005435982189	26522	68	16F
0005435982190	26522	69	17C
0005432300245	26522	70	17D
0005435982192	26522	71	17E
0005435982151	26522	72	17F
0005432300246	26522	73	18C
0005435982185	26522	74	18E
0005435982143	26522	75	18F
0005435982171	26522	76	19A
0005432300247	26522	77	19C
0005435982144	26522	78	19D
0005435982193	26522	79	19F
0005435982191	26522	80	20A
0005432300249	26522	81	20C
0005435982195	26522	82	20E
0005435982154	26522	83	20F
0005435981653	26722	1	1A
0005435981664	26722	2	1C
0005435981729	26722	3	1D
0005435981780	26722	4	1F
0005433434613	26722	5	2A
0005435981823	26722	6	2C
0005433434637	26722	7	2D
0005435981790	26722	8	2F
0005433434633	26722	9	3A
0005433434616	26722	10	3C
0005432051122	26722	11	3D
0005435981708	26722	12	4A
0005435981741	26722	13	4C
0005435981674	26722	14	4D
0005435981777	26722	15	4E
0005435981754	26722	16	4F
0005434271308	26722	17	5A
0005432051123	26722	18	5D
0005433434636	26722	19	5E
0005433434639	26722	20	5F
0005433434627	26722	21	6A
0005433434620	26722	22	6C
0005435981840	26722	23	6D
0005435981712	26722	24	6E
0005435981822	26722	25	6F
0005435981801	26722	26	7A
0005433434619	26722	27	7C
0005433434618	26722	28	7E
0005435981716	26722	29	7F
0005433434632	26722	30	8C
0005435981610	26722	31	8D
0005434271307	26722	32	8E
0005435981690	26722	33	8F
0005433434612	26722	34	9D
0005435981839	26722	35	9E
0005433434631	26722	36	9F
0005433434638	26722	37	10C
0005433434615	26722	38	10D
0005433434622	26722	39	10E
0005433434634	26722	40	10F
0005435981742	26722	41	11A
0005433434629	26722	42	11C
0005435981613	26722	43	11D
0005435981614	26722	44	11E
0005433434630	26722	45	11F
0005435981789	26722	46	12A
0005435981785	26722	47	12F
0005433434626	26722	48	13C
0005435981726	26722	49	13D
0005435981778	26722	50	13F
0005435981798	26722	51	14A
0005435981711	26722	52	14C
0005433434625	26722	53	14D
0005435981847	26722	54	14E
0005435981779	26722	55	15A
0005433434628	26722	56	15D
0005434269099	26722	57	15E
0005435981791	26722	58	16A
0005435981824	26722	59	16C
0005433434623	26722	60	16D
0005435981740	26722	61	16E
0005435981877	26722	62	16F
0005435981871	26722	63	17C
0005432051121	26722	64	17D
0005435981782	26722	65	17F
0005435981825	26722	66	18A
0005433434614	26722	67	18C
0005433434635	26722	68	18D
0005433434621	26722	69	18E
0005434270203	26722	70	18F
0005433434617	26722	71	19A
0005433434624	26722	72	19C
0005435981794	26722	73	19D
0005435981665	26722	74	19E
0005435981786	26722	75	19F
0005435981802	26722	76	20A
0005435981872	26722	77	20D
0005435981870	26722	78	20E
0005432857969	3146	1	1A
0005432583990	3146	2	1B
0005432583993	3146	3	1C
0005432857973	3146	4	1D
0005432857924	3146	5	2A
0005432583972	3146	6	2B
0005432583984	3146	7	2C
0005432583971	3146	8	2D
0005432583992	3146	9	3A
0005432857938	3146	10	3B
0005432857957	3146	11	3C
0005432216266	3146	12	3D
0005432583991	3146	13	4A
0005432857902	3146	14	4C
0005432857942	3146	15	4D
0005432583970	3146	16	5A
0005432583983	3146	17	5B
0005432583982	3146	18	5C
0005432857911	3146	19	5D
0005432216265	3146	20	6A
0005432583978	3146	21	6C
0005432583973	3146	22	6B
0005432583986	3146	23	6D
0005432857939	3146	24	7A
0005432583988	3146	25	7B
0005432583976	3146	26	7C
0005432583994	3146	27	7D
0005432583985	3146	28	18B
0005432583974	3146	29	18C
0005432857967	3146	30	18D
0005432857946	3146	31	19A
0005432857953	3146	32	19B
0005432583981	3146	33	19C
0005432857945	3146	34	19D
0005432583987	3146	35	20A
0005432583969	3146	36	20B
0005432857950	3146	37	20C
0005432216267	3146	38	20D
0005432857952	3146	39	21A
0005432583975	3146	40	21B
0005432583977	3146	41	21C
0005432857915	3146	42	21D
0005432583980	3146	43	22A
0005432583979	3146	44	22B
0005432857949	3146	45	22C
0005432857968	3146	46	22D
0005432583989	3146	47	23A
0005432857937	3146	48	23B
0005432583671	31476	1	1A
0005432583836	31476	2	1B
0005432858038	31476	3	1C
0005432583805	31476	4	1D
0005432858039	31476	5	2A
0005432583837	31476	6	2B
0005432858045	31476	7	2C
0005432583755	31476	8	2D
0005432583773	31476	9	3A
0005432583811	31476	10	3B
0005432858046	31476	11	3C
0005432858043	31476	12	3D
0005432583815	31476	13	4A
0005432583717	31476	14	4B
0005432583747	31476	15	4C
0005432583663	31476	16	4D
0005432583715	31476	17	5A
0005432583857	31476	18	5B
0005432583834	31476	19	5C
0005432583741	31476	20	5D
0005432583858	31476	21	6B
0005432583936	31476	22	6D
0005432858040	31476	23	7B
0005432858037	31476	24	7C
0005432583835	31476	25	7D
0005432583935	31476	26	18A
0005432858036	31476	27	18B
0005432583804	31476	28	18C
0005432583888	31476	29	18D
0005432583662	31476	30	19B
0005432858047	31476	31	19C
0005432858044	31476	32	19D
0005432583887	31476	33	20A
0005432583780	31476	34	20C
0005432583816	31476	35	20D
0005432858041	31476	36	21A
0005432583806	31476	37	22A
0005432583833	31476	38	22B
0005432583807	31476	39	22C
0005432858042	31476	40	22D
0005432583695	31476	41	23A
0005432583814	31476	42	23B
0005434943334	893	1	1A
0005433255074	893	2	1C
0005433255062	893	3	1D
0005433255065	893	4	2A
0005434943327	893	5	2D
0005434943333	893	6	3D
0005433255058	893	7	4A
0005433255073	893	8	4C
0005434943336	893	9	4D
0005433255056	893	10	5B
0005434943331	893	11	5D
0005433255061	893	12	6A
0005434943332	893	13	6B
0005433255067	893	14	6C
0005433255066	893	15	7A
0005434943330	893	16	7B
0005434943329	893	17	7D
0005433255055	893	18	18B
0005433255076	893	19	18C
0005433255064	893	20	19B
0005433255054	893	21	20A
0005433255069	893	22	20C
0005434943328	893	23	20D
0005433255068	893	24	21C
0005434943335	893	25	22C
0005434943233	16248	1	1A
0005433255108	16248	2	1D
0005434943269	16248	3	2A
0005433255105	16248	4	2B
0005434943252	16248	5	2C
0005434943291	16248	6	2D
0005434943232	16248	7	6B
0005433255109	16248	8	6C
0005434943234	16248	9	18A
0005434943242	16248	10	7D
0005434943223	16248	11	18D
0005434943222	16248	12	19C
0005433255107	16248	13	19D
0005434943290	16248	14	20A
0005434943273	16248	15	20B
0005434943292	16248	16	20C
0005433255106	16248	17	21D
0005434943224	16248	18	22B
0005435652937	21752	1	1C
0005433367448	21752	2	1F
0005435652945	21752	3	2A
0005433367499	21752	4	2D
0005435652944	21752	5	2F
0005433367476	21752	6	3F
0005435652939	21752	7	4A
0005433367496	21752	8	4C
0005435652933	21752	9	4D
0005433367475	21752	10	4E
0005433367565	21752	11	4F
0005433367418	21752	12	5A
0005433367465	21752	13	5C
0005435652930	21752	14	5E
0005433367539	21752	15	6A
0005435652952	21752	16	6D
0005433367488	21752	17	6E
0005435652924	21752	18	6F
0005433367452	21752	19	7A
0005435652954	21752	20	7C
0005433367620	21752	21	7F
0005433367417	21752	22	8A
0005433367451	21752	23	8C
0005433367540	21752	24	8F
0005435652938	21752	25	9A
0005435652921	21752	26	9D
0005433367449	21752	27	9C
0005435652928	21752	28	9E
0005435652948	21752	29	10A
0005433367375	21752	30	10C
0005435652920	21752	31	10D
0005433367563	21752	32	10F
0005433367296	21752	33	11A
0005433367515	21752	34	11D
0005433367640	21752	35	11E
0005435652951	21752	36	11F
0005435652943	21752	37	12A
0005433367498	21752	38	12C
0005433367365	21752	39	12D
0005435652917	21752	40	12E
0005435652950	21752	41	12F
0005433367500	21752	42	13C
0005433367466	21752	43	13D
0005433367495	21752	44	13E
0005433367376	21752	45	13F
0005435652934	21752	46	14A
0005435652926	21752	47	14C
0005435652947	21752	48	14E
0005435652925	21752	49	14F
0005433367381	21752	50	15A
0005435652940	21752	51	15C
0005435652927	21752	52	15E
0005433367621	21752	53	15F
0005435652941	21752	54	16A
0005435652953	21752	55	16C
0005433367419	21752	56	16D
0005433367450	21752	57	16E
0005433367333	21752	58	16F
0005435652932	21752	59	17A
0005435652929	21752	60	17C
0005435652946	21752	61	17D
0005435652936	21752	62	17E
0005435652931	21752	63	17F
0005435652949	21752	64	18A
0005433367410	21752	65	18C
0005435652935	21752	66	18E
0005433367497	21752	67	19A
0005435652923	21752	68	19C
0005433367390	21752	69	19D
0005433367538	21752	70	19E
0005433367411	21752	71	19F
0005435652919	21752	72	20A
0005435652942	21752	73	20D
0005435652918	21752	74	20E
0005435652922	21752	75	20F
0005433784873	9333	1	1B
0005433784876	9333	2	1H
0005433784872	9333	3	1G
0005432666383	9333	4	2A
0005434170898	9333	5	2B
0005434170922	9333	6	2F
0005434170928	9333	7	2C
0005433805313	9333	8	2G
0005435269656	9333	9	3F
0005434170943	9333	10	4A
0005433805293	9333	11	3H
0005433805324	9333	12	4B
0005433805287	9333	13	4C
0005432665270	9333	14	4G
0005433805320	9333	15	4H
0005434170908	9333	16	5B
0005433784854	9333	17	5A
0005434151672	9333	18	5F
0005433805326	9333	19	5C
0005433805315	9333	20	5H
0005433763174	9333	21	9B
0005433784859	9333	22	9A
0005433784870	9333	23	9G
0005433784868	9333	24	11A
0005433763181	9333	25	11D
0005433805307	9333	26	12A
0005433805305	9333	27	11H
0005434170919	9333	28	12D
0005433784881	9333	29	12B
0005433784852	9333	30	12E
0005433784869	9333	31	12F
0005433784862	9333	32	13D
0005433784851	9333	33	13F
0005433784878	9333	34	14B
0005434170983	9333	35	14A
0005434170920	9333	36	14D
0005433784856	9333	37	14E
0005433805301	9333	38	14G
0005433805304	9333	39	15D
0005432666384	9333	40	15E
0005433805312	9333	41	15G
0005433784855	9333	42	15H
0005433763171	9333	43	16F
0005433805317	9333	44	16E
0005434151667	9333	45	16G
0005432657443	9333	46	16H
0005433805310	9333	47	17B
0005433784858	9333	48	17A
0005433805291	9333	49	17E
0005432665269	9333	50	17H
0005433784882	9333	51	18B
0005433763169	9333	52	18E
0005433763173	9333	53	18D
0005433784886	9333	54	18G
0005432657442	9333	55	18H
0005433784875	9333	56	19G
0005433805297	9333	57	20B
0005432667450	9333	58	20E
0005434273062	9333	59	20F
0005433763177	9333	60	20G
0005435269669	9333	61	21A
0005433784857	9333	62	21H
0005433784865	9333	63	22B
0005433784863	9333	64	22E
0005435269670	9333	65	22G
0005433805286	9333	66	22H
0005433784879	9333	67	23A
0005433805308	9333	68	23D
0005433784864	9333	69	23E
0005432665271	9333	70	23G
0005433763170	9333	71	24B
0005433763167	9333	72	24E
0005433784860	9333	73	24F
0005434151673	9333	74	24G
0005433805323	9333	75	25F
0005432667448	9333	76	25E
0005433763168	9333	77	25D
0005433805327	9333	78	27E
0005433805289	9333	79	27H
0005434170934	9333	80	28E
0005433805302	9333	81	28D
0005433805295	9333	82	28F
0005432657444	9333	83	29A
0005433805300	9333	84	29E
0005435269652	9333	85	29D
0005434170939	9333	86	29H
0005433784885	9333	87	29G
0005433805322	9333	88	30E
0005433805321	9333	89	30D
0005434170935	9333	90	31A
0005432667449	9333	91	30H
0005434170938	9333	92	31B
0005433805306	9333	93	31F
0005434170879	9333	94	31H
0005434170907	9333	95	31G
0005433805296	9333	96	32B
0005433763175	9333	97	32D
0005435269657	9333	98	32F
0005433805318	9333	99	32E
0005433805314	9333	100	32H
0005433784874	9333	101	32G
0005433784880	9333	102	33A
0005433763180	9333	103	33D
0005433805292	9333	104	33B
0005433784877	9333	105	33F
0005434170954	9333	106	34A
0005433784884	9333	107	34E
0005433784861	9333	108	35A
0005433784871	9333	109	34H
0005433805309	9333	110	34G
0005433763172	9333	111	35B
0005433763176	9333	112	35D
0005433805325	9333	113	35E
0005433784866	9333	114	35G
0005433805298	9333	115	35F
0005433805311	9333	116	36B
0005433763178	9333	117	36A
0005433805294	9333	118	36D
0005433784883	9333	119	36F
0005433763179	9333	120	36E
0005433784853	9333	121	37A
0005434170915	9333	122	36H
0005433805316	9333	123	37E
0005433784867	9333	124	37G
0005433805290	9333	125	37F
0005433805288	9333	126	37H
0005433805299	9333	127	38B
0005434170944	9333	128	38D
0005432657441	9333	129	38H
0005433805319	9333	130	38G
0005434170893	9333	131	39F
0005433805303	9333	132	39E
0005433784458	26234	1	1C
0005433784504	26234	2	2G
0005433763074	26234	3	3B
0005432657402	26234	4	3C
0005433784560	26234	5	3G
0005433805001	26234	6	4A
0005433805071	26234	7	4C
0005432657395	26234	8	4G
0005434271306	26234	9	5B
0005433784732	26234	10	5C
0005435269746	26234	11	5F
0005434269097	26234	12	9A
0005433784509	26234	13	9G
0005433763008	26234	14	11A
0005433784502	26234	15	9H
0005433763098	26234	16	11E
0005434171030	26234	17	11D
0005433784677	26234	18	12A
0005433784593	26234	19	12D
0005433784479	26234	20	12B
0005433763073	26234	21	12F
0005434171017	26234	22	12G
0005434171026	26234	23	13A
0005433784678	26234	24	13G
0005433784733	26234	25	14B
0005434171020	26234	26	14D
0005434171023	26234	27	14G
0005433805017	26234	28	15G
0005433805013	26234	29	15H
0005433784587	26234	30	16D
0005433763024	26234	31	16B
0005433784656	26234	32	17D
0005433763062	26234	33	17G
0005433804927	26234	34	18A
0005434171027	26234	35	18B
0005433763038	26234	36	18D
0005432657421	26234	37	18F
0005433805076	26234	38	19B
0005433784442	26234	39	19E
0005434171025	26234	40	19F
0005434270202	26234	41	19G
0005433784693	26234	42	20B
0005434171022	26234	43	20F
0005433763021	26234	44	20H
0005433784679	26234	45	21D
0005433804926	26234	46	21B
0005434270201	26234	47	21E
0005433805012	26234	48	21H
0005433805086	26234	49	21G
0005433763029	26234	50	22B
0005433763072	26234	51	22H
0005433763030	26234	52	23B
0005433763046	26234	53	23A
0005433784655	26234	54	23D
0005433784588	26234	55	23F
0005433784629	26234	56	24A
0005433763061	26234	57	24F
0005433805070	26234	58	24G
0005433804978	26234	59	24H
0005433804976	26234	60	25F
0005433805099	26234	61	27B
0005433784491	26234	62	27A
0005434171021	26234	63	27D
0005434171024	26234	64	27E
0005434171019	26234	65	28E
0005432657403	26234	66	28F
0005434171031	26234	67	29A
0005433763026	26234	68	29B
0005433784583	26234	69	29E
0005433784441	26234	70	29F
0005433784592	26234	71	30D
0005433784699	26234	72	30E
0005434270199	26234	73	30G
0005433805032	26234	74	30F
0005434171018	26234	75	30H
0005433804965	26234	76	31B
0005433763037	26234	77	31E
0005434151698	26234	78	31D
0005433763052	26234	79	31H
0005434269096	26234	80	31G
0005433805047	26234	81	32D
0005433804966	26234	82	32G
0005433804991	26234	83	33E
0005433784654	26234	84	33D
0005434171029	26234	85	33G
0005434270200	26234	86	34A
0005433763036	26234	87	34E
0005433784561	26234	88	34G
0005434269098	26234	89	34F
0005434171028	26234	90	34H
0005434271305	26234	91	36A
0005435269747	26234	92	35H
0005433784397	26234	93	36E
0005433784570	26234	94	36D
0005433805016	26234	95	36F
0005433804967	26234	96	36H
0005433804939	26234	97	36G
0005433784589	26234	98	37A
0005433763009	26234	99	37B
0005433805106	26234	100	37E
0005433784480	26234	101	37D
0005433763025	26234	102	38D
0005433804977	26234	103	38H
0005433784474	26234	104	39F
0005433805069	26234	105	39E
0005435929622	4902	1	2B
0005435135657	4902	2	2C
0005435135658	4902	3	2D
0005435135660	4902	4	6D
0005435135659	4902	5	19B
0005435135661	4902	6	20C
0005435135634	33010	1	5B
0005435929638	33010	2	6D
0005435135594	33010	3	7D
0005435135630	33010	4	20A
0005435135625	33010	5	21B
0005434983277	9470	1	1B
0005434983273	9470	2	3B
0005434983276	9470	3	6B
0005434983278	9470	4	19A
0005434983275	9470	5	19D
0005434983274	9470	6	21C
0005434217957	27372	1	1C
0005434217960	27372	2	2C
0005434217961	27372	3	6A
0005434983223	27372	4	19D
0005434983237	27372	5	21A
0005434217959	27372	6	21C
0005434217958	27372	7	22A
0005434983244	27372	8	23B
0005433960202	24282	1	1A
0005433960199	24282	2	1G
0005433985408	24282	3	2A
0005433985526	24282	4	2C
0005433985559	24282	5	2B
0005433985511	24282	6	2F
0005433960172	24282	7	3A
0005433960117	24282	8	3C
0005433985524	24282	9	3B
0005433985335	24282	10	3F
0005433960049	24282	11	3H
0005433960097	24282	12	4F
0005433985339	24282	13	4C
0005433960123	24282	14	4H
0005433960082	24282	15	5F
0005433985294	24282	16	5G
0005433985380	24282	17	5H
0005433985378	24282	18	9A
0005433960218	24282	19	9G
0005433960091	24282	20	9H
0005433960194	24282	21	11E
0005433959983	24282	22	11D
0005433985358	24282	23	11F
0005433960098	24282	24	12A
0005433960133	24282	25	11H
0005433959892	24282	26	12B
0005433960100	24282	27	12H
0005433985379	24282	28	13B
0005433960174	24282	29	13A
0005433960164	24282	30	13F
0005433960052	24282	31	13E
0005433960181	24282	32	13G
0005433985309	24282	33	14A
0005433960065	24282	34	14B
0005433960139	24282	35	14E
0005433985268	24282	36	15A
0005433985600	24282	37	14H
0005433960205	24282	38	15D
0005433960196	24282	39	15F
0005433960047	24282	40	16A
0005433960126	24282	41	15H
0005433960085	24282	42	16D
0005433959998	24282	43	16E
0005433960062	24282	44	16G
0005433960162	24282	45	17A
0005433985396	24282	46	17D
0005433960203	24282	47	17E
0005433959857	24282	48	18B
0005433985398	24282	49	19D
0005433960081	24282	50	19B
0005433985544	24282	51	19H
0005433960222	24282	52	20A
0005433960134	24282	53	20B
0005433960127	24282	54	20E
0005433960064	24282	55	20H
0005433960168	24282	56	21B
0005433960211	24282	57	21E
0005433985404	24282	58	21H
0005433985410	24282	59	22D
0005433985523	24282	60	22F
0005433960008	24282	61	22E
0005433960198	24282	62	22G
0005433960048	24282	63	23A
0005433985411	24282	64	23D
0005433959991	24282	65	23B
0005433985426	24282	66	23F
0005433960153	24282	67	23G
0005433960173	24282	68	24A
0005433985261	24282	69	23H
0005433985323	24282	70	24G
0005433985417	24282	71	25E
0005433960193	24282	72	25D
0005433960178	24282	73	27D
0005433985458	24282	74	27F
0005433985307	24282	75	27H
0005433985492	24282	76	27G
0005433960086	24282	77	28B
0005433960120	24282	78	28E
0005433985397	24282	79	28F
0005433960132	24282	80	28H
0005433960184	24282	81	28G
0005433985311	24282	82	29B
0005433985338	24282	83	29E
0005433985322	24282	84	29D
0005433960055	24282	85	30A
0005433960088	24282	86	30E
0005433960029	24282	87	30H
0005433959997	24282	88	31B
0005433960161	24282	89	31A
0005433960054	24282	90	31G
0005433985599	24282	91	31F
0005433985399	24282	92	31H
0005433985525	24282	93	32A
0005433960099	24282	94	32E
0005433960175	24282	95	32F
0005433960169	24282	96	32G
0005433985389	24282	97	33A
0005433985507	24282	98	33D
0005433985350	24282	99	33G
0005433985246	24282	100	33F
0005433960183	24282	101	33H
0005433985405	24282	102	34A
0005433985531	24282	103	34E
0005433959856	24282	104	35G
0005433960221	24282	105	36B
0005433985493	24282	106	36A
0005433960179	24282	107	36D
0005433960207	24282	108	36G
0005433985409	24282	109	37E
0005433960154	24282	110	37D
0005433959858	24282	111	37G
0005433985443	24282	112	38D
0005433960206	24282	113	38G
0005433985321	24282	114	38F
0005433960067	24282	115	38H
0005433985837	25922	1	1C
0005433960700	25922	2	1B
0005433960713	25922	3	1F
0005433985820	25922	4	2A
0005433985799	25922	5	2C
0005433985832	25922	6	2B
0005433985834	25922	7	2G
0005433985835	25922	8	3A
0005433960675	25922	9	3G
0005433960734	25922	10	3F
0005433985802	25922	11	4G
0005433985803	25922	12	4H
0005433960694	25922	13	5A
0005433960685	25922	14	5F
0005433960709	25922	15	5C
0005433960695	25922	16	5G
0005433960707	25922	17	5H
0005433985810	25922	18	9B
0005433985838	25922	19	9A
0005433960681	25922	20	9G
0005433985815	25922	21	11A
0005433960696	25922	22	9H
0005433985805	25922	23	11B
0005433960720	25922	24	12B
0005433960711	25922	25	12F
0005433985804	25922	26	12G
0005433960729	25922	27	14B
0005433985828	25922	28	14A
0005433960698	25922	29	14D
0005433960717	25922	30	14H
0005433960722	25922	31	15E
0005433960699	25922	32	15D
0005433960703	25922	33	15F
0005433960725	25922	34	16A
0005433985818	25922	35	16D
0005433985825	25922	36	16E
0005433985821	25922	37	16F
0005433960687	25922	38	16G
0005433960721	25922	39	17D
0005433960686	25922	40	17E
0005433960684	25922	41	18A
0005433985823	25922	42	17H
0005433960676	25922	43	18D
0005433985826	25922	44	18F
0005433985811	25922	45	19A
0005433985836	25922	46	19B
0005433960705	25922	47	19E
0005433960682	25922	48	19G
0005433985822	25922	49	20A
0005433960693	25922	50	20B
0005433960691	25922	51	20E
0005433985795	25922	52	20H
0005433960688	25922	53	21A
0005433960724	25922	54	21E
0005433960730	25922	55	21H
0005433960738	25922	56	22B
0005433960718	25922	57	22E
0005433960692	25922	58	22G
0005433985829	25922	59	22H
0005433960708	25922	60	23D
0005433985817	25922	61	23F
0005433960736	25922	62	23E
0005433985814	25922	63	23G
0005433960728	25922	64	24B
0005433960727	25922	65	24A
0005433960678	25922	66	24F
0005433960706	25922	67	24H
0005433960712	25922	68	25E
0005433985833	25922	69	25D
0005433985819	25922	70	27A
0005433985813	25922	71	27H
0005433960680	25922	72	28E
0005433960723	25922	73	29A
0005433985791	25922	74	28H
0005433960704	25922	75	29G
0005433960679	25922	76	29H
0005433960731	25922	77	30B
0005433985839	25922	78	30F
0005433985794	25922	79	30E
0005433985831	25922	80	30G
0005433985824	25922	81	31A
0005433960697	25922	82	31D
0005433985792	25922	83	31G
0005433985800	25922	84	31F
0005433985809	25922	85	32A
0005433960710	25922	86	32E
0005433985806	25922	87	32F
0005433985830	25922	88	32H
0005433960677	25922	89	33A
0005433960735	25922	90	33B
0005433985801	25922	91	33D
0005433985812	25922	92	33H
0005433960683	25922	93	34A
0005433985807	25922	94	34E
0005433985808	25922	95	35A
0005433960716	25922	96	34H
0005433985798	25922	97	35D
0005433960726	25922	98	35F
0005433960690	25922	99	35E
0005433960689	25922	100	35G
0005433985793	25922	101	35H
0005433960737	25922	102	36D
0005433960719	25922	103	36F
0005433960714	25922	104	36H
0005433960732	25922	105	37D
0005433985827	25922	106	37E
0005433960701	25922	107	37G
0005433985797	25922	108	38A
0005433985816	25922	109	37H
0005433960715	25922	110	38E
0005433960702	25922	111	38G
0005433985796	25922	112	38F
0005433960733	25922	113	39F
0005434480273	943	1	1A
0005434480274	943	2	1B
0005433165795	943	3	1C
0005433165728	943	4	1D
0005433165735	943	5	2A
0005434480284	943	6	2B
0005432269489	943	7	2C
0005433165758	943	8	2D
0005434480277	943	9	3A
0005433165804	943	10	3B
0005434480271	943	11	3C
0005434480286	943	12	3D
0005433165789	943	13	4A
0005433165790	943	14	4B
0005434480283	943	15	4C
0005434480285	943	16	4D
0005434480267	943	17	5A
0005434480265	943	18	5B
0005434480276	943	19	5C
0005433165772	943	20	5D
0005433165771	943	21	6A
0005434480287	943	22	6B
0005433165760	943	23	6C
0005434480279	943	24	6D
0005432269488	943	25	7A
0005434480288	943	26	7B
0005434480268	943	27	7C
0005434480269	943	28	7D
0005434480280	943	29	18A
0005434480266	943	30	18B
0005433165794	943	31	18C
0005434480270	943	32	18D
0005434480281	943	33	19A
0005433165769	943	34	19B
0005433165784	943	35	19C
0005433165799	943	36	19D
0005434480263	943	37	20A
0005433165739	943	38	20B
0005433165801	943	39	20C
0005434480272	943	40	20D
0005434480278	943	41	21A
0005433165788	943	42	21B
0005433165802	943	43	21C
0005434480264	943	44	21D
0005433165770	943	45	22A
0005434480275	943	46	22B
0005434480282	943	47	22C
0005433165785	943	48	22D
0005433165717	943	49	23A
0005432269490	943	50	23B
0005434480014	16603	1	1A
0005434480172	16603	2	1B
0005434479986	16603	3	1D
0005434480119	16603	4	2A
0005434480112	16603	5	2B
0005434480040	16603	6	2C
0005433165871	16603	7	2D
0005434479981	16603	8	3A
0005433165881	16603	9	3B
0005434480046	16603	10	3C
0005434480056	16603	11	3D
0005434480096	16603	12	4A
0005434479982	16603	13	4B
0005434480057	16603	14	4C
0005433165880	16603	15	4D
0005433165879	16603	16	5A
0005433165882	16603	17	5B
0005434480041	16603	18	5C
0005434480145	16603	19	5D
0005434480020	16603	20	6A
0005434480055	16603	21	6B
0005434480171	16603	22	6C
0005433165877	16603	23	6D
0005434479927	16603	24	7B
0005434480034	16603	25	7C
0005433165873	16603	26	7D
0005434479914	16603	27	18A
0005433165874	16603	28	18B
0005434480094	16603	29	18D
0005434479913	16603	30	19A
0005433165878	16603	31	19B
0005434480021	16603	32	19C
0005434480092	16603	33	19D
0005434480103	16603	34	20A
0005433165875	16603	35	20C
0005433165872	16603	36	20D
0005434480118	16603	37	21B
0005434480052	16603	38	21C
0005433165876	16603	39	21D
0005433165870	16603	40	22A
0005434479965	16603	41	22B
0005433165883	16603	42	22C
0005434480051	16603	43	23A
0005435142542	10351	1	1A
0005435142541	10351	2	1B
0005435149990	10351	3	2B
0005435386510	10351	4	2C
0005435149985	10351	5	2D
0005435386509	10351	6	3A
0005435386465	10351	7	3B
0005435149983	10351	8	3C
0005435386534	10351	9	4A
0005435142540	10351	10	4D
0005435149989	10351	11	5B
0005435149992	10351	12	5C
0005433289776	10351	13	5D
0005435386508	10351	14	6A
0005435386481	10351	15	6C
0005435142531	10351	16	7A
0005435149991	10351	17	7B
0005435149984	10351	18	7C
0005435149979	10351	19	7D
0005435142535	10351	20	18A
0005435149981	10351	21	18B
0005433289786	10351	22	18C
0005435149980	10351	23	18D
0005433289756	10351	24	19A
0005435149988	10351	25	19B
0005435142536	10351	26	19C
0005435142539	10351	27	19D
0005435149987	10351	28	20A
0005435142538	10351	29	20B
0005435142534	10351	30	20C
0005435142532	10351	31	20D
0005435142530	10351	32	21A
0005435142533	10351	33	21C
0005435149986	10351	34	22B
0005433289777	10351	35	22C
0005435149993	10351	36	22D
0005435142537	10351	37	23A
0005435149982	10351	38	23B
0005435149929	21964	1	1A
0005435149902	21964	2	1B
0005435386562	21964	3	1C
0005435149901	21964	4	1D
0005433289842	21964	5	2A
0005433289837	21964	6	2B
0005435142436	21964	7	2C
0005433289835	21964	8	2D
0005435142454	21964	9	3A
0005435142405	21964	10	3B
0005435149828	21964	11	3C
0005433289843	21964	12	4A
0005433289838	21964	13	4B
0005435149867	21964	14	4C
0005433289841	21964	15	4D
0005435149860	21964	16	5A
0005435149832	21964	17	5B
0005435149859	21964	18	5C
0005435142445	21964	19	5D
0005435149886	21964	20	6A
0005435149888	21964	21	6B
0005435142374	21964	22	6C
0005435149883	21964	23	6D
0005435149829	21964	24	7A
0005435142443	21964	25	7B
0005435142425	21964	26	7C
0005435149846	21964	27	18A
0005435142433	21964	28	7D
0005435149870	21964	29	18B
0005433289836	21964	30	18C
0005435149871	21964	31	18D
0005435149864	21964	32	19A
0005435149892	21964	33	19B
0005435142420	21964	34	19C
0005433289840	21964	35	19D
0005433289839	21964	36	20A
0005435149893	21964	37	20B
0005435149877	21964	38	20C
0005435149854	21964	39	20D
0005435149842	21964	40	21A
0005435142455	21964	41	21B
0005435386563	21964	42	21C
0005435149841	21964	43	21D
0005435149845	21964	44	22A
0005435149822	21964	45	22B
0005435149885	21964	46	22C
0005435149821	21964	47	22D
0005435386564	21964	48	23A
0005435142446	21964	49	23B
0005435502104	11234	1	1C
0005435545641	11234	2	1D
0005435529024	11234	3	2A
0005435545624	11234	4	2D
0005435502076	11234	5	2F
0005435501994	11234	6	3C
0005435502038	11234	7	3D
0005435502056	11234	8	4A
0005435529074	11234	9	4C
0005435319469	11234	10	4D
0005435528905	11234	11	4E
0005435501993	11234	12	4F
0005434573314	11234	13	5A
0005435502077	11234	14	5D
0005435502153	11234	15	6C
0005435502078	11234	16	6D
0005435319441	11234	17	6E
0005435502030	11234	18	6F
0005435502087	11234	19	7A
0005434573311	11234	20	7C
0005434573310	11234	21	7F
0005435529068	11234	22	8A
0005435502058	11234	23	8C
0005435319490	11234	24	8D
0005435502082	11234	25	8E
0005435502147	11234	26	8F
0005435529082	11234	27	9A
0005435502095	11234	28	9C
0005434573306	11234	29	9D
0005435528906	11234	30	9F
0005435502064	11234	31	10A
0005435502103	11234	32	10C
0005435529025	11234	33	10D
0005435529026	11234	34	10E
0005435502031	11234	35	11A
0005435502032	11234	36	11C
0005435319436	11234	37	11D
0005435528960	11234	38	11E
0005435528992	11234	39	12D
0005435502086	11234	40	12E
0005435502073	11234	41	13A
0005435529002	11234	42	13C
0005435528957	11234	43	13E
0005434573316	11234	44	13F
0005434573315	11234	45	14C
0005435529008	11234	46	14D
0005435502152	11234	47	14F
0005435502151	11234	48	15A
0005435528998	11234	49	15C
0005434573304	11234	50	15D
0005435502057	11234	51	15E
0005435502055	11234	52	15F
0005435528976	11234	53	16A
0005435319437	11234	54	16C
0005435528977	11234	55	16D
0005435529016	11234	56	16E
0005435319501	11234	57	16F
0005435528904	11234	58	17D
0005435502054	11234	59	17E
0005434573313	11234	60	18A
0005434573312	11234	61	18C
0005435545639	11234	62	18E
0005435545638	11234	63	19A
0005434573308	11234	64	19C
0005434573305	11234	65	19D
0005435502017	11234	66	19E
0005434573317	11234	67	19F
0005434573307	11234	68	20A
0005435502174	11234	69	20C
0005434573309	11234	70	20D
0005435502039	11234	71	20E
0005435517865	20953	1	1A
0005434573236	20953	2	1C
0005435319562	20953	3	1D
0005435319560	20953	4	1F
0005435502262	20953	5	2A
0005432291922	20953	6	2C
0005435319563	20953	7	2D
0005434573145	20953	8	2F
0005435319566	20953	9	3A
0005435517872	20953	10	3C
0005434573206	20953	11	3F
0005435502259	20953	12	4A
0005435502252	20953	13	4C
0005434573185	20953	14	4D
0005435517858	20953	15	4E
0005435508331	20953	16	4F
0005434573180	20953	17	5A
0005434573151	20953	18	5C
0005434573193	20953	19	5D
0005435502246	20953	20	5E
0005434573174	20953	21	5F
0005434573156	20953	22	6A
0005432291924	20953	23	6C
0005435502254	20953	24	6D
0005435508329	20953	25	6E
0005435502243	20953	26	6F
0005435508325	20953	27	7A
0005435517854	20953	28	7C
0005435508330	20953	29	7D
0005435508334	20953	30	7E
0005435319567	20953	31	7F
0005435319564	20953	32	8A
0005435517857	20953	33	8C
0005435502255	20953	34	8E
0005434573166	20953	35	8F
0005435508333	20953	36	9A
0005434573211	20953	37	9C
0005435502258	20953	38	9D
0005435517867	20953	39	9E
0005435517863	20953	40	10A
0005435517870	20953	41	10C
0005435502251	20953	42	10D
0005435502247	20953	43	10E
0005435517862	20953	44	10F
0005435517869	20953	45	11A
0005435508327	20953	46	11C
0005435502250	20953	47	11D
0005434573205	20953	48	11E
0005435319559	20953	49	12A
0005435502253	20953	50	12D
0005435502256	20953	51	12E
0005434573173	20953	52	12F
0005435517864	20953	53	13A
0005435508332	20953	54	13C
0005435508326	20953	55	13D
0005435517868	20953	56	13E
0005435502261	20953	57	14A
0005435517853	20953	58	14C
0005435502260	20953	59	14D
0005435517855	20953	60	14E
0005435517861	20953	61	14F
0005435508336	20953	62	15A
0005435517859	20953	63	15C
0005435502264	20953	64	15D
0005435508324	20953	65	15E
0005435502248	20953	66	15F
0005435319561	20953	67	16C
0005435517856	20953	68	16D
0005435508335	20953	69	16E
0005434573223	20953	70	16F
0005435508323	20953	71	17A
0005435319565	20953	72	17E
0005435502257	20953	73	17F
0005434573198	20953	74	18A
0005434573240	20953	75	18C
0005435517871	20953	76	18D
0005435502263	20953	77	18E
0005432291923	20953	78	18F
0005435517866	20953	79	19A
0005435502244	20953	80	19D
0005434573184	20953	81	19E
0005435508328	20953	82	19F
0005434573165	20953	83	20A
0005435517860	20953	84	20C
0005435502245	20953	85	20D
0005435502249	20953	86	20E
0005435517852	20953	87	20F
0005432692740	2997	1	1C
0005432692637	2997	2	2A
0005432692820	2997	3	2F
0005432692570	2997	4	3F
0005432692649	2997	5	4D
0005432692626	2997	6	5C
0005432692650	2997	7	5A
0005432692578	2997	8	6A
0005432692809	2997	9	9C
0005432692703	2997	10	9D
0005432692774	2997	11	10F
0005432692821	2997	12	11C
0005432692879	2997	13	11D
0005432692817	2997	14	11E
0005432692710	2997	15	12A
0005432692841	2997	16	14A
0005432692842	2997	17	14D
0005432692750	2997	18	14E
0005432692696	2997	19	15D
0005432692688	2997	20	16A
0005432692620	2997	21	16C
0005432692621	2997	22	16E
0005432692697	2997	23	16F
0005432692670	2997	24	17C
0005432692653	2997	25	17F
0005432692701	2997	26	18D
0005432692731	2997	27	19D
0005432692808	2997	28	19E
0005432692880	2997	29	20E
0005432706703	2996	1	1D
0005432880670	2996	2	2A
0005433123689	2996	3	2D
0005432706723	2996	4	2C
0005432706709	2996	5	2F
0005432706712	2996	6	3D
0005432880649	2996	7	3F
0005433123714	2996	8	4A
0005432706721	2996	9	4C
0005433123721	2996	10	4D
0005433123702	2996	11	4E
0005432706708	2996	12	4F
0005432880705	2996	13	5A
0005433123590	2996	14	5C
0005433123694	2996	15	5D
0005432880640	2996	16	5F
0005432706715	2996	17	6A
0005433123663	2996	18	6C
0005432706701	2996	19	6D
0005432880581	2996	20	6F
0005432706705	2996	21	7A
0005432880669	2996	22	7C
0005432880574	2996	23	7D
0005432706714	2996	24	7E
0005433123789	2996	25	7F
0005432880735	2996	26	8A
0005432880673	2996	27	8C
0005432880685	2996	28	8E
0005432706710	2996	29	9A
0005432706704	2996	30	9D
0005432706718	2996	31	9E
0005432706713	2996	32	9F
0005432880668	2996	33	10A
0005433123692	2996	34	10C
0005432880614	2996	35	10D
0005432706711	2996	36	10E
0005433123656	2996	37	10F
0005432217769	2996	38	11A
0005432880675	2996	39	11C
0005433123790	2996	40	11D
0005433123761	2996	41	11E
0005432706726	2996	42	11F
0005433123591	2996	43	12A
0005432706702	2996	44	12C
0005432880706	2996	45	12D
0005433123785	2996	46	12F
0005432880583	2996	47	13C
0005432706700	2996	48	13D
0005432880641	2996	49	13E
0005432706724	2996	50	13F
0005432706720	2996	51	14A
0005432880612	2996	52	14C
0005432706707	2996	53	14D
0005432706717	2996	54	14E
0005432706706	2996	55	15C
0005432880613	2996	56	15D
0005432880584	2996	57	16A
0005432880594	2996	58	16C
0005433123720	2996	59	16D
0005432217770	2996	60	17A
0005432706722	2996	61	17D
0005432880582	2996	62	17E
0005433123577	2996	63	17F
0005432880642	2996	64	18D
0005432880648	2996	65	18F
0005432706725	2996	66	19A
0005432880634	2996	67	19D
0005433123596	2996	68	19E
0005432880650	2996	69	19F
0005432706716	2996	70	20A
0005432880723	2996	71	20C
0005432706719	2996	72	20D
0005432880674	2996	73	20E
0005432880661	2996	74	20F
0005433123870	30017	1	1A
0005432706566	30017	2	1C
0005433123880	30017	3	1D
0005432693018	30017	4	1F
0005432693021	30017	5	2A
0005432693016	30017	6	2C
0005432706421	30017	7	2D
0005432693024	30017	8	2F
0005432706535	30017	9	3A
0005433123879	30017	10	3C
0005433194853	30017	11	3D
0005432693010	30017	12	3F
0005432706360	30017	13	4A
0005433123878	30017	14	4C
0005432693029	30017	15	4D
0005432693004	30017	16	4E
0005432880778	30017	17	4F
0005432693026	30017	18	5A
0005432693011	30017	19	5C
0005432706555	30017	20	5D
0005433123869	30017	21	5E
0005432693023	30017	22	5F
0005432693027	30017	23	6A
0005432693017	30017	24	6C
0005432693006	30017	25	6D
0005432706533	30017	26	6E
0005433123882	30017	27	6F
0005432706523	30017	28	7A
0005432880790	30017	29	7C
0005433123873	30017	30	7D
0005432693022	30017	31	7E
0005433123866	30017	32	7F
0005432693009	30017	33	8A
0005432706560	30017	34	8C
0005432706590	30017	35	8D
0005432706567	30017	36	8E
0005432693003	30017	37	8F
0005432880782	30017	38	9A
0005432706519	30017	39	9C
0005432706424	30017	40	9D
0005432880780	30017	41	9E
0005432693002	30017	42	9F
0005433123887	30017	43	10A
0005433123881	30017	44	10C
0005432693025	30017	45	10E
0005433123884	30017	46	10D
0005432693007	30017	47	10F
0005432880781	30017	48	11A
0005432693012	30017	49	11C
0005433123874	30017	50	11D
0005433123885	30017	51	11E
0005432880784	30017	52	11F
0005433194854	30017	53	12A
0005432693005	30017	54	12D
0005432693014	30017	55	12E
0005433194852	30017	56	12F
0005432880788	30017	57	13A
0005432693019	30017	58	13C
0005433194855	30017	59	13D
0005432880785	30017	60	13E
0005432706542	30017	61	13F
0005432706561	30017	62	14A
0005433123876	30017	63	14C
0005432880786	30017	64	14D
0005433123871	30017	65	14E
0005433123883	30017	66	14F
0005432706603	30017	67	15A
0005432706423	30017	68	15C
0005432880779	30017	69	15E
0005432706521	30017	70	15D
0005433123867	30017	71	15F
0005432880783	30017	72	16A
0005432693001	30017	73	16C
0005432706313	30017	74	16D
0005433123886	30017	75	16E
0005432693031	30017	76	16F
0005432693028	30017	77	17A
0005432706467	30017	78	17C
0005432880789	30017	79	17D
0005433123872	30017	80	17E
0005432693015	30017	81	17F
0005432693008	30017	82	18A
0005432706518	30017	83	18C
0005432880776	30017	84	18D
0005432693030	30017	85	18E
0005433123868	30017	86	18F
0005432706524	30017	87	19A
0005432706466	30017	88	19C
0005432693013	30017	89	19D
0005433194851	30017	90	19E
0005432880777	30017	91	19F
0005433123877	30017	92	20A
0005432706534	30017	93	20C
0005432880787	30017	94	20D
0005432693020	30017	95	20E
0005433123875	30017	96	20F
0005434979698	23662	1	1A
0005434979696	23662	2	1B
0005434988704	23662	3	1C
0005434988707	23662	4	1D
0005434979685	23662	5	2A
0005434979700	23662	6	2B
0005434988705	23662	7	2C
0005434979693	23662	8	2D
0005434988702	23662	9	3A
0005434979692	23662	10	3B
0005434979710	23662	11	3D
0005434979697	23662	12	4A
0005434979703	23662	13	4C
0005434979690	23662	14	4D
0005434988708	23662	15	5B
0005434979687	23662	16	5C
0005434979707	23662	17	5D
0005434979686	23662	18	6A
0005434979683	23662	19	6B
0005434979694	23662	20	6C
0005434988703	23662	21	6D
0005434979695	23662	22	7A
0005434979709	23662	23	7B
0005434979691	23662	24	7C
0005434979699	23662	25	7D
0005434979705	23662	26	18A
0005434988706	23662	27	18D
0005434979688	23662	28	19B
0005434988709	23662	29	19A
0005434979704	23662	30	19C
0005434979711	23662	31	20B
0005434979713	23662	32	20C
0005434979702	23662	33	20D
0005434979712	23662	34	21A
0005434979701	23662	35	21B
0005434979706	23662	36	21C
0005434979708	23662	37	22A
0005434979684	23662	38	22C
0005434979689	23662	39	22D
0005434979373	27545	1	1A
0005434988612	27545	2	1B
0005434988605	27545	3	1C
0005434979485	27545	4	2B
0005434988651	27545	5	3B
0005434979426	27545	6	3C
0005434988614	27545	7	4B
0005434988638	27545	8	4D
0005434979416	27545	9	5B
0005434979475	27545	10	5D
0005434979358	27545	11	6C
0005434988606	27545	12	6B
0005434988609	27545	13	7B
0005434988652	27545	14	7C
0005434979410	27545	15	7D
0005434979374	27545	16	18B
0005434988610	27545	17	19A
0005434979413	27545	18	19C
0005434988595	27545	19	20B
0005434979559	27545	20	20C
0005434988611	27545	21	20D
0005434979421	27545	22	21B
0005434979567	27545	23	21C
0005434979474	27545	24	23B
0005434302860	10250	1	1A
0005434302445	10250	2	1B
0005434302861	10250	3	2B
0005434302862	10250	4	2C
0005433111482	10250	5	3B
0005434302447	10250	6	4B
0005433113506	10250	7	4C
0005433113500	10250	8	5A
0005434302446	10250	9	7B
0005433113507	10250	10	7D
0005433113505	10250	11	18B
0005434302444	10250	12	19D
0005434302859	10250	13	20D
0005434302410	19600	1	2B
0005434302407	19600	2	5D
0005434302431	19600	3	7A
0005433113530	19600	4	18D
0005433113532	19600	5	21B
0005433113531	19600	6	21C
0005435939861	3581	1	1A
0005435068961	3581	2	1D
0005435068976	3581	3	1F
0005435068985	3581	4	2A
0005435069003	3581	5	2C
0005435068964	3581	6	2D
0005435068974	3581	7	3A
0005435925136	3581	8	3C
0005435718925	3581	9	3D
0005435925152	3581	10	4A
0005435925139	3581	11	4C
0005435068967	3581	12	4D
0005435925129	3581	13	4F
0005435068953	3581	14	5A
0005435068988	3581	15	5C
0005435068987	3581	16	5D
0005435068995	3581	17	6A
0005435068993	3581	18	6C
0005435068984	3581	19	6D
0005435718921	3581	20	6E
0005435069000	3581	21	6F
0005435718927	3581	22	7A
0005435925144	3581	23	7E
0005435068972	3581	24	7F
0005435068963	3581	25	8A
0005435925121	3581	26	8C
0005435068966	3581	27	8D
0005435925124	3581	28	8F
0005435068983	3581	29	9A
0005435718923	3581	30	9C
0005435068971	3581	31	9D
0005435068959	3581	32	9F
0005435925145	3581	33	9E
0005435069004	3581	34	10A
0005435068965	3581	35	10D
0005435925125	3581	36	10E
0005435068968	3581	37	11A
0005435068981	3581	38	11C
0005435068962	3581	39	11D
0005435068999	3581	40	11E
0005435068997	3581	41	11F
0005435069005	3581	42	12A
0005435068969	3581	43	12C
0005435069002	3581	44	12D
0005435925123	3581	45	12E
0005435718922	3581	46	12F
0005435068955	3581	47	13A
0005435718924	3581	48	13C
0005435718926	3581	49	13D
0005435068980	3581	50	13E
0005435069006	3581	51	14C
0005435068991	3581	52	14D
0005435068982	3581	53	14E
0005435069001	3581	54	14F
0005435068956	3581	55	15A
0005435068958	3581	56	15C
0005435068990	3581	57	15D
0005435068994	3581	58	15E
0005435068954	3581	59	16A
0005435925140	3581	60	16C
0005435068992	3581	61	16D
0005435068957	3581	62	16E
0005435068977	3581	63	16F
0005435068960	3581	64	17A
0005435068975	3581	65	17C
0005435068970	3581	66	17D
0005435925141	3581	67	17F
0005435068996	3581	68	18C
0005435068978	3581	69	18D
0005435068986	3581	70	18E
0005435925143	3581	71	18F
0005435718928	3581	72	19A
0005435068989	3581	73	19C
0005435068979	3581	74	19D
0005435068998	3581	75	19E
0005435068973	3581	76	20C
0005435925100	3581	77	20E
0005435068570	15284	1	1A
0005435068353	15284	2	1C
0005435068204	15284	3	1F
0005435068308	15284	4	2A
0005435068571	15284	5	2C
0005435068330	15284	6	2F
0005435068574	15284	7	3A
0005435068534	15284	8	3C
0005435068576	15284	9	3D
0005435068654	15284	10	4D
0005435925269	15284	11	4F
0005435068427	15284	12	5C
0005435068660	15284	13	5D
0005435068573	15284	14	5E
0005435925276	15284	15	5F
0005435068376	15284	16	6A
0005435068320	15284	17	6C
0005435068655	15284	18	7A
0005435068304	15284	19	7C
0005435925275	15284	20	7F
0005435068584	15284	21	8A
0005435925270	15284	22	8C
0005435068309	15284	23	8D
0005435068392	15284	24	8E
0005435068464	15284	25	8F
0005435068437	15284	26	9A
0005435068459	15284	27	9C
0005435068423	15284	28	9E
0005435068443	15284	29	9F
0005435068431	15284	30	10A
0005435068548	15284	31	10C
0005435068555	15284	32	10D
0005435068510	15284	33	10E
0005435068661	15284	34	10F
0005435068525	15284	35	11A
0005435068572	15284	36	11D
0005435068566	15284	37	11F
0005435068396	15284	38	12A
0005435068625	15284	39	12C
0005435068203	15284	40	12D
0005435925271	15284	41	12E
0005435068511	15284	42	12F
0005435068478	15284	43	13E
0005435925277	15284	44	13F
0005435068585	15284	45	14C
0005435068450	15284	46	15E
0005435925274	15284	47	15F
0005435068460	15284	48	16A
0005435068732	15284	49	16C
0005435068344	15284	50	16E
0005435068469	15284	51	16F
0005435068545	15284	52	17A
0005435068479	15284	53	17C
0005435068379	15284	54	17D
0005435068395	15284	55	17E
0005435068325	15284	56	17F
0005435068345	15284	57	18A
0005435068375	15284	58	18C
0005435925272	15284	59	18D
0005435925273	15284	60	18F
0005435068616	15284	61	19A
0005435068605	15284	62	19E
0005435068590	15284	63	19F
0005435068288	15284	64	20A
0005435068604	15284	65	20C
0005435068577	15284	66	20D
0005435068554	15284	67	20F
0005432659702	18132	1	2A
0005432659701	18132	2	2B
0005432658586	18132	3	3B
0005432660814	18132	4	4B
0005432660812	18132	5	4A
0005432658585	18132	6	5A
0005432658587	18132	7	5B
0005432660813	18132	8	6A
0005432667430	26396	1	1A
0005432667431	26396	2	1B
0005432660794	26396	3	6B
0005432157488	159	1	1A
0005433101609	159	2	1C
0005432901430	159	3	1D
0005433101485	159	4	1F
0005432919646	159	5	2F
0005432919670	159	6	3A
0005432919713	159	7	3C
0005433101494	159	8	4A
0005433101573	159	9	4F
0005433101467	159	10	4D
0005433101540	159	11	5C
0005433101466	159	12	6A
0005433101601	159	13	6C
0005432919613	159	14	7C
0005432901450	159	15	7F
0005432919630	159	16	8C
0005432901495	159	17	8D
0005433101604	159	18	8F
0005433101523	159	19	9C
0005432901446	159	20	9E
0005433101496	159	21	9D
0005433101344	159	22	10A
0005432919648	159	23	10D
0005433101592	159	24	10C
0005433101562	159	25	10E
0005433101526	159	26	11B
0005432919668	159	27	11C
0005433101539	159	28	11D
0005432901468	159	29	11E
0005433101532	159	30	12B
0005432919682	159	31	12C
0005432901396	159	32	12F
0005432901451	159	33	13A
0005433101404	159	34	13C
0005432901467	159	35	13E
0005433101582	159	36	13D
0005433101603	159	37	14B
0005432157487	159	38	14D
0005433101397	159	39	14E
0005432901394	159	40	15C
0005432901493	159	41	15B
0005433101460	159	42	15E
0005432919649	159	43	15D
0005432919698	159	44	16B
0005432677530	159	45	16C
0005432919574	159	46	16E
0005432919650	159	47	17A
0005432919505	159	48	17C
0005433101521	159	49	17D
0005432919693	159	50	18A
0005433101503	159	51	18B
0005432677516	159	52	18D
0005433101477	159	53	18F
0005433101418	159	54	20B
0005432919712	159	55	20A
0005433101356	159	56	20C
0005432919651	159	57	20E
0005432919703	159	58	20D
0005432901479	159	59	21A
0005433101545	159	60	21C
0005433101499	159	61	21D
0005432919683	159	62	21F
0005432901448	159	63	23A
0005433101552	159	64	23B
0005433101351	159	65	23D
0005432901541	159	66	23E
0005432901461	159	67	24A
0005432901436	159	68	24D
0005433101459	159	69	24C
0005433101468	159	70	24E
0005432901392	159	71	25B
0005432901507	159	72	25C
0005433101443	159	73	25E
0005432901464	159	74	25D
0005433101612	159	75	25F
0005433101596	159	76	26B
0005433101613	159	77	26A
0005433101377	159	78	26D
0005433101608	159	79	26C
0005432919637	159	80	26E
0005432901478	159	81	26F
0005432901435	159	82	27B
0005432919532	159	83	27C
0005432677515	159	84	27D
0005433101410	159	85	28A
0005433101551	159	86	28D
0005432901404	159	87	28E
0005432901449	159	88	29A
0005432919719	159	89	29C
0005433101396	159	90	29B
0005432901447	159	91	29D
0005433101504	159	92	29F
0005432901395	159	93	29E
0005432919706	159	94	30D
0005432919603	159	95	31A
0005432919625	159	96	30F
0005432901458	159	97	31B
0005432919647	159	98	31C
0005433101533	159	99	31F
0005433101345	159	100	31E
0005432261830	160	1	1F
0005432261802	160	2	2C
0005432817399	160	3	2D
0005432261806	160	4	3A
0005432261805	160	5	2F
0005432817397	160	6	3D
0005432817418	160	7	3C
0005432817400	160	8	3F
0005432753246	160	9	4C
0005432261809	160	10	4D
0005434153528	160	11	5A
0005432207656	160	12	4F
0005432261834	160	13	5C
0005432261822	160	14	5F
0005433687680	160	15	5D
0005432261807	160	16	6A
0005432817419	160	17	6D
0005432753248	160	18	7A
0005432817407	160	19	7D
0005432261791	160	20	8A
0005432817423	160	21	8B
0005432261829	160	22	8D
0005432261798	160	23	8E
0005432261825	160	24	9B
0005432261808	160	25	9C
0005432261821	160	26	9D
0005432261833	160	27	9E
0005432261816	160	28	10C
0005432753249	160	29	10E
0005432288979	160	30	11C
0005432261794	160	31	11D
0005432261804	160	32	11E
0005432261799	160	33	12A
0005432817417	160	34	11F
0005432817401	160	35	12D
0005432261818	160	36	12F
0005432261820	160	37	13B
0005432817422	160	38	13D
0005432817416	160	39	13F
0005432261800	160	40	14A
0005432261827	160	41	14C
0005432261797	160	42	14E
0005432261801	160	43	14D
0005432261828	160	44	14F
0005432817394	160	45	16C
0005432261815	160	46	16D
0005433690906	160	47	16F
0005434153530	160	48	17B
0005432261792	160	49	17D
0005432261832	160	50	17F
0005432207655	160	51	18C
0005432261831	160	52	18B
0005432817420	160	53	19B
0005432261835	160	54	20A
0005432817405	160	55	20B
0005433687688	160	56	20C
0005433690903	160	57	20D
0005432817415	160	58	21A
0005432817404	160	59	21C
0005432261836	160	60	21D
0005432261814	160	61	22A
0005432817406	160	62	22C
0005432261795	160	63	22E
0005432261803	160	64	22D
0005432261796	160	65	23B
0005432817403	160	66	23D
0005432817411	160	67	23F
0005432261826	160	68	23E
0005432817402	160	69	24B
0005432817412	160	70	24A
0005432261819	160	71	24C
0005432817395	160	72	24E
0005432288980	160	73	24F
0005432753247	160	74	25B
0005432261823	160	75	25D
0005432261793	160	76	25F
0005432753263	160	77	26A
0005432817398	160	78	26B
0005432817396	160	79	27B
0005432261810	160	80	27A
0005432817424	160	81	27C
0005432261813	160	82	27D
0005432756800	160	83	27E
0005432817408	160	84	27F
0005432817409	160	85	28C
0005432261817	160	86	28D
0005432261790	160	87	28F
0005434153529	160	88	29C
0005432817410	160	89	29D
0005432261811	160	90	29F
0005432817414	160	91	30B
0005432817413	160	92	30D
0005432261812	160	93	30C
0005432817421	160	94	31A
0005432261824	160	95	31C
0005432756787	160	96	31D
0005432207654	160	97	31F
0005433102023	8128	1	1A
0005432020211	8128	2	1C
0005433102045	8128	3	1F
0005432919817	8128	4	1D
0005432020208	8128	5	2A
0005432020192	8128	6	2C
0005432020212	8128	7	2F
0005433102040	8128	8	2D
0005432919809	8128	9	3C
0005433102017	8128	10	3D
0005433102046	8128	11	4A
0005432919815	8128	12	3F
0005433102044	8128	13	4C
0005432919808	8128	14	4D
0005433102016	8128	15	5C
0005433102029	8128	16	5F
0005433102025	8128	17	6A
0005432020217	8128	18	6F
0005432751522	8128	19	6D
0005432020216	8128	20	7A
0005432020191	8128	21	7C
0005433102056	8128	22	7D
0005432020190	8128	23	8A
0005432020199	8128	24	7F
0005432020205	8128	25	8C
0005432020215	8128	26	8E
0005433102052	8128	27	8F
0005432919814	8128	28	9A
0005432919822	8128	29	9C
0005432020195	8128	30	9D
0005432919818	8128	31	9F
0005432020210	8128	32	9E
0005433102050	8128	33	10A
0005433102028	8128	34	10B
0005433102035	8128	35	10E
0005432020194	8128	36	11A
0005433102027	8128	37	10F
0005433102049	8128	38	11C
0005432919812	8128	39	11D
0005432919803	8128	40	11F
0005432919823	8128	41	12B
0005433102059	8128	42	12D
0005432919820	8128	43	13C
0005433102019	8128	44	13B
0005433102020	8128	45	13D
0005432020200	8128	46	14B
0005433102024	8128	47	14A
0005432020209	8128	48	14C
0005432919810	8128	49	14E
0005432919807	8128	50	14D
0005432751521	8128	51	14F
0005433102041	8128	52	15A
0005433102034	8128	53	15C
0005432020207	8128	54	15B
0005433102053	8128	55	15F
0005432391994	8128	56	15E
0005433102030	8128	57	16A
0005432677565	8128	58	16B
0005432919819	8128	59	16C
0005433102033	8128	60	16D
0005433102036	8128	61	17A
0005432753293	8128	62	16F
0005433102048	8128	63	17C
0005432391993	8128	64	17D
0005432677564	8128	65	18A
0005432020193	8128	66	18D
0005433102058	8128	67	18C
0005432020206	8128	68	19C
0005432677566	8128	69	19B
0005432020198	8128	70	20A
0005432020202	8128	71	20B
0005433102021	8128	72	20F
0005432044518	8128	73	21A
0005433102057	8128	74	21C
0005432020213	8128	75	21F
0005432751519	8128	76	21E
0005433102060	8128	77	21D
0005432919813	8128	78	22A
0005433102032	8128	79	22C
0005433102022	8128	80	22D
0005433102039	8128	81	22F
0005432020204	8128	82	23B
0005432919821	8128	83	23C
0005433102038	8128	84	23D
0005432045610	8128	85	23F
0005432020201	8128	86	23E
0005433102043	8128	87	24A
0005433102047	8128	88	24B
0005432919811	8128	89	24D
0005432751520	8128	90	24E
0005432919805	8128	91	24F
0005433102051	8128	92	25A
0005433102055	8128	93	25D
0005432753296	8128	94	25E
0005433102062	8128	95	26A
0005433102054	8128	96	26B
0005432751518	8128	97	26C
0005432020214	8128	98	26E
0005433102018	8128	99	26D
0005432753295	8128	100	27C
0005432919804	8128	101	27D
0005432919806	8128	102	27E
0005433102061	8128	103	28A
0005432020203	8128	104	28E
0005433102031	8128	105	29B
0005432391992	8128	106	29C
0005433102037	8128	107	29E
0005432919802	8128	108	29F
0005432753294	8128	109	30A
0005432677567	8128	110	30C
0005432020197	8128	111	30D
0005433102042	8128	112	31A
0005433102026	8128	113	31B
0005432020196	8128	114	31C
0005432044519	8128	115	31E
0005432919816	8128	116	31F
0005432817204	8129	1	2D
0005432817237	8129	2	3A
0005432901576	8129	3	5A
0005432901575	8129	4	5C
0005432817060	8129	5	5F
0005432901566	8129	6	6A
0005432817203	8129	7	6F
0005432817189	8129	8	7D
0005432817229	8129	9	9A
0005432817059	8129	10	8F
0005432817191	8129	11	9B
0005432817115	8129	12	9F
0005432817116	8129	13	10D
0005432817261	8129	14	12B
0005432817192	8129	15	12F
0005432901569	8129	16	13D
0005432901564	8129	17	14A
0005432901573	8129	18	15D
0005432817150	8129	19	16A
0005432901565	8129	20	16E
0005432817186	8129	21	16F
0005432817111	8129	22	17F
0005432817044	8129	23	18E
0005432817238	8129	24	20C
0005432817202	8129	25	21B
0005432817124	8129	26	21D
0005432817140	8129	27	22A
0005432817152	8129	28	23A
0005432817139	8129	29	23D
0005432817228	8129	30	23E
0005432901571	8129	31	24A
0005432901572	8129	32	25B
0005432901579	8129	33	25E
0005432901578	8129	34	26A
0005432817141	8129	35	26C
0005432901580	8129	36	27A
0005432901574	8129	37	27D
0005432817207	8129	38	28C
0005432817165	8129	39	28E
0005432901577	8129	40	29A
0005432002071	8129	41	29C
0005432901570	8129	42	29D
0005432901567	8129	43	30B
0005432817248	8129	44	30C
0005432817190	8129	45	30E
0005432901568	8129	46	30F
0005432817194	8129	47	31B
0005433870725	9644	1	1B
0005434175703	9644	2	3A
0005434175726	9644	3	3B
0005433870726	9644	4	4A
0005434175724	9644	5	5B
0005434175689	9644	6	6B
0005434175745	32350	1	1A
0005434175743	32350	2	2A
0005433870709	32350	3	3A
0005433870715	32350	4	3B
0005434175744	32350	5	4B
0005433870714	32350	6	5A
0005434175742	32350	7	6A
0005434878101	3480	1	1C
0005435126297	3480	2	1G
0005434426544	3480	3	1K
0005434878068	3480	4	2C
0005434426565	3480	5	2A
0005434878105	3480	6	2H
0005434878040	3480	7	2G
0005432799388	3480	8	2D
0005434878096	3480	9	3A
0005435126290	3480	10	2K
0005434878008	3480	11	3D
0005435126275	3480	12	3C
0005434878023	3480	13	3H
0005434878048	3480	14	3G
0005434878044	3480	15	4C
0005434426566	3480	16	4A
0005434878097	3480	17	3K
0005435126276	3480	18	4D
0005434878032	3480	19	4K
0005434878064	3480	20	5C
0005432799415	3480	21	5A
0005434878067	3480	22	5D
0005432799410	3480	23	5K
0005434878016	3480	24	11C
0005432799398	3480	25	11F
0005434878009	3480	26	11E
0005434938109	3480	27	11H
0005432799394	3480	28	12C
0005432799401	3480	29	12A
0005435902619	3480	30	12H
0005435126289	3480	31	12F
0005434878025	3480	32	13A
0005435126305	3480	33	13D
0005435126298	3480	34	13F
0005434938098	3480	35	13H
0005434938106	3480	36	14C
0005434426538	3480	37	13K
0005435126296	3480	38	14G
0005432613852	3480	39	14F
0005434878091	3480	40	14H
0005434878059	3480	41	15D
0005434426551	3480	42	15C
0005434938105	3480	43	15A
0005434878035	3480	44	15G
0005432611703	3480	45	15F
0005432613854	3480	46	15K
0005432183462	3480	47	15H
0005434878086	3480	48	16D
0005435902471	3480	49	16C
0005434878058	3480	50	16F
0005435126281	3480	51	16H
0005434426562	3480	52	16G
0005434878031	3480	53	17C
0005434878029	3480	54	17E
0005435126278	3480	55	17D
0005434938100	3480	56	17G
0005434938110	3480	57	17F
0005434426547	3480	58	17K
0005434426557	3480	59	18C
0005434878087	3480	60	18B
0005432799405	3480	61	18A
0005432611704	3480	62	18G
0005434878094	3480	63	18K
0005434878012	3480	64	18J
0005434878054	3480	65	19B
0005434426548	3480	66	19D
0005435902564	3480	67	19C
0005434938102	3480	68	19F
0005435902568	3480	69	19H
0005435126309	3480	70	19K
0005432799391	3480	71	19J
0005434878072	3480	72	20B
0005434426552	3480	73	20A
0005435126291	3480	74	20E
0005434938096	3480	75	20D
0005432611702	3480	76	20F
0005434426558	3480	77	20K
0005432799403	3480	78	20H
0005434878069	3480	79	21A
0005435126277	3480	80	21D
0005435126274	3480	81	21G
0005432188601	3480	82	21E
0005434878017	3480	83	21J
0005434878071	3480	84	21H
0005434878090	3480	85	22A
0005434878098	3480	86	21K
0005434426561	3480	87	22C
0005435626142	3480	88	22F
0005434426540	3480	89	22E
0005434878033	3480	90	22D
0005434938099	3480	91	22H
0005434426539	3480	92	22G
0005434878100	3480	93	22K
0005434938112	3480	94	22J
0005434878083	3480	95	23B
0005435126295	3480	96	23A
0005434878038	3480	97	23F
0005434938097	3480	98	23E
0005434938111	3480	99	23G
0005435902588	3480	100	23K
0005434878037	3480	101	24E
0005435126287	3480	102	25D
0005434878065	3480	103	25C
0005432799392	3480	104	25F
0005432613851	3480	105	25E
0005434878078	3480	106	25G
0005434878061	3480	107	25K
0005435126273	3480	108	25J
0005434878047	3480	109	26C
0005434426541	3480	110	26A
0005435914687	3480	111	26D
0005435126288	3480	112	26J
0005434878036	3480	113	26H
0005434878026	3480	114	26K
0005434878057	3480	115	27D
0005434878104	3480	116	27C
0005435902426	3480	117	27B
0005432799393	3480	118	27E
0005435126300	3480	119	27J
0005435126294	3480	120	28C
0005435126308	3480	121	28B
0005435126301	3480	122	28E
0005434878076	3480	123	28D
0005432799408	3480	124	28G
0005434878030	3480	125	28F
0005434878075	3480	126	28K
0005432613855	3480	127	28J
0005432799409	3480	128	28H
0005432799413	3480	129	29B
0005434878052	3480	130	29A
0005432613853	3480	131	29C
0005434426546	3480	132	29F
0005435902557	3480	133	29E
0005434878085	3480	134	29H
0005432183463	3480	135	30A
0005435902499	3480	136	29K
0005435126292	3480	137	30B
0005434878089	3480	138	30E
0005434878034	3480	139	30H
0005434878070	3480	140	30G
0005432799404	3480	141	30F
0005434426563	3480	142	30J
0005435902507	3480	143	31A
0005432799411	3480	144	30K
0005435626143	3480	145	31D
0005434878021	3480	146	31C
0005432799390	3480	147	31B
0005434878027	3480	148	31E
0005434878045	3480	149	31H
0005432799402	3480	150	31G
0005434878039	3480	151	31J
0005432799407	3480	152	32C
0005434938101	3480	153	32B
0005434878024	3480	154	32A
0005434426553	3480	155	32D
0005435126282	3480	156	32G
0005435626140	3480	157	32F
0005434878042	3480	158	32K
0005435126303	3480	159	32J
0005432799389	3480	160	32H
0005435126307	3480	161	33B
0005435902495	3480	162	33D
0005434426550	3480	163	33C
0005432799387	3480	164	33F
0005434878046	3480	165	33E
0005435126310	3480	166	33K
0005434426542	3480	167	34C
0005435126284	3480	168	34A
0005434878074	3480	169	34E
0005434938095	3480	170	34D
0005432611701	3480	171	34G
0005434878080	3480	172	34K
0005434938108	3480	173	34J
0005434878073	3480	174	34H
0005434878022	3480	175	35A
0005434878063	3480	176	35B
0005435126311	3480	177	35J
0005434426549	3480	178	35H
0005434938093	3480	179	36C
0005434426556	3480	180	36G
0005435126304	3480	181	36J
0005434878084	3480	182	37B
0005434878056	3480	183	37F
0005435902474	3480	184	37E
0005434878099	3480	185	37G
0005434878093	3480	186	38A
0005432799399	3480	187	37K
0005435626138	3480	188	38C
0005432188600	3480	189	38B
0005434426555	3480	190	38J
0005434878020	3480	191	38H
0005435626141	3480	192	39B
0005432799395	3480	193	39A
0005434878013	3480	194	38K
0005435902505	3480	195	39C
0005434878010	3480	196	39F
0005432799414	3480	197	39G
0005434426559	3480	198	40A
0005434878014	3480	199	39K
0005432799412	3480	200	40C
0005434878043	3480	201	40B
0005434878082	3480	202	40D
0005434878062	3480	203	40F
0005434878050	3480	204	40H
0005432188602	3480	205	41A
0005434878088	3480	206	41C
0005434426554	3480	207	41F
0005434938113	3480	208	41E
0005435126312	3480	209	41J
0005435126279	3480	210	41H
0005432799396	3480	211	41G
0005435126286	3480	212	41K
0005435126299	3480	213	42A
0005435126293	3480	214	42E
0005434878041	3480	215	42D
0005434426543	3480	216	42G
0005432799397	3480	217	42F
0005435126306	3480	218	43G
0005434878019	3480	219	43J
0005434938104	3480	220	44B
0005434878015	3480	221	44D
0005434878079	3480	222	44G
0005434878028	3480	223	44F
0005434426560	3480	224	44J
0005435902502	3480	225	44H
0005435126283	3480	226	45B
0005434426564	3480	227	45C
0005434878077	3480	228	45E
0005435126285	3480	229	45G
0005434878018	3480	230	45K
0005434938107	3480	231	46B
0005434878092	3480	232	46A
0005434878011	3480	233	46E
0005434878081	3480	234	46J
0005434938094	3480	235	46H
0005434878055	3480	236	46K
0005434878053	3480	237	47D
0005435126313	3480	238	47K
0005435126280	3480	239	47H
0005434878095	3480	240	48D
0005435126272	3480	241	48A
0005435902558	3480	242	48H
0005435626144	3480	243	48G
0005432799406	3480	244	48F
0005435126302	3480	245	49G
0005435626139	3480	246	49F
0005434878103	3480	247	49E
0005432611700	3480	248	49K
0005434878049	3480	249	49H
0005434938103	3480	250	50C
0005434878051	3480	251	50D
0005434878066	3480	252	50H
0005434878060	3480	253	50G
0005434878102	3480	254	50F
0005434426545	3480	255	50K
0005432799400	3480	256	51F
0005435902665	14561	1	1D
0005435625907	14561	2	1C
0005434426203	14561	3	1A
0005432799183	14561	4	1G
0005434876963	14561	5	1H
0005434426234	14561	6	2D
0005435125874	14561	7	2H
0005432799119	14561	8	2K
0005435625942	14561	9	3G
0005434877550	14561	10	3C
0005434876986	14561	11	3H
0005434877113	14561	12	4C
0005434877438	14561	13	4A
0005434426404	14561	14	3K
0005432799079	14561	15	4G
0005435902671	14561	16	5A
0005435126077	14561	17	5D
0005434877155	14561	18	5K
0005434877521	14561	19	11C
0005434426423	14561	20	11E
0005435125811	14561	21	11K
0005434877329	14561	22	11H
0005434877440	14561	23	11G
0005435125957	14561	24	12A
0005434877549	14561	25	12F
0005434876952	14561	26	12E
0005435125872	14561	27	12D
0005435125900	14561	28	12G
0005434426299	14561	29	13A
0005434877167	14561	30	12K
0005434877054	14561	31	13C
0005434877109	14561	32	13F
0005434937870	14561	33	13H
0005435902662	14561	34	13G
0005435125992	14561	35	14C
0005435842326	14561	36	14E
0005434937952	14561	37	14K
0005435625934	14561	38	14H
0005434877307	14561	39	14G
0005434426353	14561	40	15C
0005432799115	14561	41	15A
0005434937917	14561	42	15F
0005435902670	14561	43	15K
0005434426354	14561	44	16D
0005434876898	14561	45	16F
0005434877184	14561	46	16E
0005435125878	14561	47	16G
0005434876604	14561	48	17A
0005434877380	14561	49	16K
0005434877060	14561	50	17E
0005434877196	14561	51	17D
0005434426291	14561	52	17F
0005434877207	14561	53	18A
0005435625931	14561	54	17K
0005434877154	14561	55	17H
0005434877356	14561	56	18C
0005434426414	14561	57	18B
0005434877117	14561	58	18E
0005434937968	14561	59	18G
0005434426225	14561	60	19B
0005435125822	14561	61	19A
0005434876961	14561	62	19C
0005434876605	14561	63	19F
0005434877074	14561	64	19D
0005434876883	14561	65	19H
0005434426313	14561	66	20A
0005434876951	14561	67	19K
0005432799215	14561	68	20B
0005435126033	14561	69	20E
0005432059499	14561	70	20D
0005434877040	14561	71	20G
0005434877522	14561	72	20J
0005434876962	14561	73	20H
0005435902668	14561	74	21B
0005435902658	14561	75	21A
0005432799165	14561	76	21G
0005435125732	14561	77	21F
0005435125873	14561	78	21H
0005432799182	14561	79	22B
0005434877460	14561	80	22C
0005435125755	14561	81	22F
0005432799136	14561	82	22G
0005435125958	14561	83	22K
0005435902669	14561	84	22H
0005435125921	14561	85	23C
0005434876841	14561	86	23F
0005435126005	14561	87	23H
0005435125862	14561	88	24D
0005434877340	14561	89	23J
0005434876899	14561	90	24E
0005435902674	14561	91	25A
0005434877419	14561	92	25C
0005435126076	14561	93	25F
0005435625925	14561	94	25H
0005434876884	14561	95	25G
0005432799255	14561	96	25K
0005434877420	14561	97	26B
0005434426309	14561	98	26D
0005434426176	14561	99	26C
0005434877221	14561	100	26G
0005434426298	14561	101	26H
0005434876970	14561	102	27A
0005435625947	14561	103	26K
0005434876987	14561	104	27C
0005434877188	14561	105	27B
0005434877437	14561	106	27E
0005434877614	14561	107	27G
0005434876660	14561	108	28A
0005434876744	14561	109	27K
0005435125901	14561	110	28E
0005435902673	14561	111	28G
0005434877156	14561	112	28J
0005435625943	14561	113	28H
0005434877254	14561	114	29B
0005435125871	14561	115	28K
0005434877305	14561	116	29D
0005434876700	14561	117	29C
0005434877327	14561	118	29F
0005434426208	14561	119	29H
0005435125786	14561	120	30A
0005435125779	14561	121	29J
0005434426226	14561	122	30B
0005434877032	14561	123	30E
0005435125947	14561	124	30G
0005435125832	14561	125	31B
0005434877202	14561	126	31A
0005435625944	14561	127	30K
0005435125930	14561	128	31C
0005434877262	14561	129	31E
0005432799107	14561	130	31H
0005435902664	14561	131	32A
0005435125731	14561	132	31K
0005435125927	14561	133	31J
0005434426364	14561	134	32B
0005434877491	14561	135	32H
0005434877811	14561	136	32K
0005435126004	14561	137	33F
0005435625969	14561	138	33E
0005435625913	14561	139	33D
0005432799181	14561	140	33H
0005434877108	14561	141	33K
0005435126042	14561	142	34C
0005434877256	14561	143	34B
0005434877033	14561	144	34D
0005432059500	14561	145	34E
0005434877145	14561	146	34J
0005434877220	14561	147	34H
0005434876701	14561	148	35B
0005435902657	14561	149	34K
0005435902667	14561	150	35D
0005435625933	14561	151	35G
0005434426405	14561	152	36A
0005434877377	14561	153	35K
0005434937868	14561	154	36E
0005434877500	14561	155	36D
0005435902659	14561	156	36G
0005434937925	14561	157	36K
0005434426235	14561	158	37B
0005435125843	14561	159	37D
0005434426297	14561	160	37G
0005434877328	14561	161	37E
0005435625906	14561	162	37J
0005434876743	14561	163	38A
0005434877273	14561	164	38B
0005434877274	14561	165	38J
0005435125730	14561	166	38H
0005434876661	14561	167	39B
0005435902660	14561	168	39A
0005435125810	14561	169	39C
0005435125703	14561	170	39H
0005434877272	14561	171	39K
0005434877297	14561	172	39J
0005432799080	14561	173	40B
0005435625961	14561	174	40E
0005434426121	14561	175	40D
0005434877346	14561	176	40H
0005435902663	14561	177	40F
0005434877135	14561	178	40K
0005435902666	14561	179	41A
0005434426355	14561	180	41C
0005434876659	14561	181	41B
0005434937869	14561	182	41G
0005432799234	14561	183	41F
0005434426340	14561	184	41E
0005435125791	14561	185	41K
0005434938031	14561	186	42C
0005435125959	14561	187	42B
0005432799166	14561	188	42E
0005434877059	14561	189	42D
0005435125823	14561	190	42G
0005432799106	14561	191	42F
0005435625932	14561	192	42K
0005432607506	14561	193	42J
0005434938010	14561	194	42H
0005432799211	14561	195	43A
0005434877134	14561	196	43C
0005434876741	14561	197	43B
0005435126006	14561	198	43F
0005434426314	14561	199	43H
0005435125745	14561	200	44A
0005435625970	14561	201	43J
0005434877133	14561	202	44C
0005435125973	14561	203	44B
0005435125861	14561	204	44E
0005432799167	14561	205	44G
0005435125769	14561	206	44F
0005435126007	14561	207	45B
0005434877379	14561	208	45D
0005434937972	14561	209	45E
0005435125797	14561	210	45H
0005434877378	14561	211	45G
0005435902672	14561	212	45K
0005434877306	14561	213	46B
0005434937903	14561	214	46E
0005434877580	14561	215	46C
0005434877061	14561	216	46H
0005434876662	14561	217	47A
0005434877417	14561	218	46K
0005434876769	14561	219	47C
0005434877330	14561	220	47G
0005435125938	14561	221	47F
0005435625948	14561	222	47H
0005434426330	14561	223	48D
0005434877138	14561	224	48C
0005434938011	14561	225	48H
0005435125815	14561	226	48G
0005435625964	14561	227	49A
0005432799214	14561	228	49D
0005434877192	14561	229	49C
0005434876609	14561	230	49G
0005432799117	14561	231	49E
0005434877201	14561	232	49K
0005434877206	14561	233	49H
0005434426341	14561	234	50C
0005432799135	14561	235	50A
0005435841820	14561	236	50E
0005435125904	14561	237	50D
0005435125972	14561	238	50H
0005434426320	14561	239	50G
0005435902661	14561	240	50F
0005435125780	14561	241	51D
0005435126034	14561	242	51F
0005434876742	14561	243	51E
0005434426415	14561	244	51G
0005435889842	3593	1	1B
0005434312315	3593	2	1D
0005435889843	3593	3	2B
0005435889853	3593	4	2C
0005435889833	3593	5	3B
0005435889852	3593	6	3D
0005435889841	3593	7	4A
0005434325624	3593	8	4B
0005434325626	3593	9	4D
0005434312314	3593	10	5C
0005434325631	3593	11	6A
0005434325620	3593	12	6B
0005434325628	3593	13	7A
0005434325623	3593	14	7D
0005434325630	3593	15	18B
0005434325625	3593	16	18D
0005434325621	3593	17	19D
0005434325627	3593	18	20C
0005434325629	3593	19	21D
0005435889836	3593	20	22C
0005434325622	3593	21	22D
0005434325528	15627	1	1A
0005435889885	15627	2	1C
0005434325502	15627	3	2C
0005434325547	15627	4	3A
0005435889881	15627	5	3D
0005434325527	15627	6	4A
0005434325501	15627	7	4B
0005434325513	15627	8	5A
0005434325546	15627	9	5B
0005434325503	15627	10	6D
0005434325553	15627	11	18B
0005435889886	15627	12	20C
0005434325585	15627	13	21B
0005435889884	15627	14	22A
0005435889882	15627	15	22B
0005435889883	15627	16	22C
0005435957670	644	1	1A
0005435957667	644	2	1B
0005435957674	644	3	2B
0005433420326	644	4	4B
0005435957673	644	5	4D
0005435957669	644	6	5A
0005435957668	644	7	5B
0005433420327	644	8	5C
0005433420346	644	9	6C
0005435957679	644	10	18D
0005433420300	644	11	19A
0005435957665	644	12	19B
0005435957676	644	13	20A
0005433420325	644	14	21A
0005435957677	644	15	21C
0005435957666	644	16	21D
0005435957671	644	17	22A
0005435957675	644	18	22C
0005435957672	644	19	23A
0005435957678	644	20	23B
0005433420380	15152	1	1B
0005433420388	15152	2	1C
0005435957576	15152	3	1D
0005435957487	15152	4	2B
0005435957597	15152	5	2D
0005433420381	15152	6	3A
0005435957627	15152	7	3C
0005435957626	15152	8	3D
0005433420382	15152	9	4C
0005433420387	15152	10	5A
0005435957488	15152	11	5B
0005433420386	15152	12	5D
0005435957544	15152	13	6A
0005435957598	15152	14	6C
0005435957546	15152	15	6D
0005435957599	15152	16	7B
0005435957617	15152	17	7C
0005435957530	15152	18	7D
0005435957575	15152	19	18A
0005433420385	15152	20	19A
0005435957491	15152	21	19B
0005433420383	15152	22	19C
0005435957604	15152	23	19D
0005433420384	15152	24	20A
0005433420389	15152	25	20B
0005435957600	15152	26	20C
0005435957601	15152	27	21C
0005435957529	15152	28	22C
0005435957545	15152	29	23A
0005435957628	15152	30	23B
0005434995277	24003	1	3D
0005434995282	24003	2	9C
0005434995280	24003	3	10C
0005434995275	24003	4	12C
0005434995276	24003	5	15E
0005434995279	24003	6	18B
0005434995278	24003	7	18D
0005434995281	24003	8	19A
0005434247114	8841	1	1A
0005434247115	8841	2	3B
0005435629402	8841	3	4A
0005434247142	16039	1	1A
0005434247141	16039	2	6B
0005433404716	2833	1	1D
0005435797447	2833	2	2C
0005435797450	2833	3	4C
0005435797440	2833	4	4D
0005433404715	2833	5	4F
0005435797446	2833	6	6A
0005435797444	2833	7	6C
0005435797449	2833	8	6E
0005435797443	2833	9	8F
0005435797445	2833	10	10C
0005433404719	2833	11	11C
0005435797441	2833	12	11F
0005435797451	2833	13	12D
0005433404727	2833	14	13D
0005435797452	2833	15	13E
0005435797448	2833	16	15C
0005435797442	2833	17	16A
0005433404723	2833	18	16C
0005433404726	2833	19	18E
0005433404704	2833	20	20C
0005433404712	2833	21	20F
0005435797313	29299	1	1C
0005435797390	29299	2	4C
0005433404792	29299	3	7A
0005433404794	29299	4	7D
0005433404795	29299	5	11C
0005435797354	29299	6	11F
0005435797366	29299	7	13C
0005435797372	29299	8	13D
0005433404797	29299	9	14C
0005435797391	29299	10	15A
0005435797341	29299	11	15D
0005433404796	29299	12	16A
0005435797329	29299	13	16F
0005433404793	29299	14	17C
0005435797352	29299	15	19C
0005435376322	5755	1	2B
0005435376337	5755	2	4A
0005435376338	5755	3	4B
0005435376339	5755	4	5A
0005434948003	5754	1	1A
0005434948006	5754	2	2A
0005434948004	5754	3	3A
0005434948000	5754	4	2B
0005434948002	5754	5	4A
0005434948001	5754	6	3B
0005434948007	5754	7	4B
0005434948008	5754	8	5B
0005434948005	5754	9	6B
0005435376344	16367	1	1A
0005434947967	16367	2	1B
0005435376345	16367	3	2A
0005434947942	16367	4	3A
0005435376343	16367	5	3B
0005434947941	16367	6	4A
0005435376346	16367	7	5A
0005435376347	16367	8	6A
0005434947962	16367	9	6B
0005433960781	6850	1	1C
0005433960757	6850	2	1D
0005433960758	6850	3	2A
0005433960786	6850	4	3D
0005433960784	6850	5	3F
0005433960742	6850	6	4A
0005433960777	6850	7	4C
0005433960775	6850	8	4F
0005433960746	6850	9	5C
0005433960751	6850	10	5D
0005433960778	6850	11	5E
0005433960765	6850	12	5F
0005433960779	6850	13	6E
0005433960771	6850	14	7C
0005433960782	6850	15	7D
0005433960761	6850	16	7E
0005433960743	6850	17	7F
0005433960750	6850	18	8D
0005433960755	6850	19	8F
0005433960790	6850	20	9A
0005433960767	6850	21	9D
0005433960766	6850	22	9E
0005433960744	6850	23	10A
0005433960762	6850	24	10D
0005433960760	6850	25	10E
0005433960740	6850	26	10F
0005433960752	6850	27	11D
0005433960745	6850	28	11E
0005433960788	6850	29	11F
0005433960774	6850	30	12A
0005433960763	6850	31	12D
0005433960749	6850	32	12E
0005433960748	6850	33	13A
0005433960764	6850	34	13C
0005433960792	6850	35	13D
0005433960756	6850	36	13E
0005433960768	6850	37	13F
0005433960739	6850	38	14A
0005433960770	6850	39	15C
0005433960785	6850	40	15D
0005433960780	6850	41	15F
0005433960759	6850	42	16D
0005433960783	6850	43	16E
0005433960754	6850	44	16F
0005433960787	6850	45	17A
0005433960791	6850	46	17D
0005433960769	6850	47	17E
0005433960747	6850	48	18A
0005433960772	6850	49	18C
0005433960741	6850	50	18D
0005433960776	6850	51	18E
0005433960789	6850	52	19A
0005433960773	6850	53	19D
0005433960753	6850	54	19E
0005433960191	25708	1	1A
0005433960043	25708	2	1F
0005433960096	25708	3	2A
0005433960227	25708	4	3A
0005433960121	25708	5	3D
0005433960234	25708	6	3F
0005433960101	25708	7	4A
0005433960118	25708	8	4C
0005433960180	25708	9	4F
0005433960235	25708	10	5E
0005433960267	25708	11	6A
0005433960140	25708	12	6C
0005433960114	25708	13	6D
0005433959972	25708	14	6F
0005433960141	25708	15	7A
0005433960223	25708	16	7C
0005433960122	25708	17	7E
0005433960204	25708	18	8A
0005433959926	25708	19	8C
0005433959948	25708	20	8F
0005433960116	25708	21	9A
0005433959988	25708	22	9C
0005433960102	25708	23	9E
0005433959942	25708	24	10C
0005433960177	25708	25	10E
0005433960192	25708	26	11C
0005433960042	25708	27	11E
0005433959949	25708	28	12A
0005433960011	25708	29	12E
0005433960013	25708	30	12F
0005433960212	25708	31	13C
0005433960041	25708	32	13D
0005433960080	25708	33	14A
0005433960243	25708	34	14C
0005433960115	25708	35	14E
0005433960090	25708	36	14F
0005433960237	25708	37	15D
0005433960240	25708	38	15E
0005433960128	25708	39	16C
0005433960233	25708	40	16D
0005433960176	25708	41	16E
0005433959989	25708	42	17C
0005433960012	25708	43	17D
0005433960015	25708	44	18C
0005433960213	25708	45	19A
0005433960074	25708	46	19D
0005433960095	25708	47	19F
0005433960089	25708	48	20C
0005433960053	25708	49	20D
0005435082696	24548	1	2A
0005435082705	24548	2	2B
0005435082704	24548	3	3B
0005435082695	24548	4	4A
0005435082721	24548	5	4B
0005435082698	24548	6	5B
0005435082770	26144	1	2B
0005435082766	26144	2	3B
0005435082767	26144	3	4B
0005435082769	26144	4	5A
0005435082764	26144	5	5B
0005435082768	26144	6	6A
0005435082765	26144	7	6B
0005434244911	5052	1	1A
0005433534478	5052	2	3D
0005435286566	5052	3	5D
0005434244926	5052	4	5F
0005434244923	5052	5	6D
0005434244931	5052	6	7C
0005434244919	5052	7	8F
0005432166894	5052	8	9C
0005434244934	5052	9	10C
0005433534480	5052	10	11A
0005434244913	5052	11	11B
0005434244928	5052	12	12C
0005434244924	5052	13	13A
0005435286560	5052	14	13C
0005434244918	5052	15	15C
0005435286567	5052	16	15D
0005434244912	5052	17	16D
0005434244927	5052	18	17B
0005434244930	5052	19	17A
0005434244929	5052	20	17F
0005434244921	5052	21	18E
0005432166896	5052	22	19C
0005435286561	5052	23	19D
0005432166895	5052	24	19E
0005435286569	5052	25	20B
0005434244908	5052	26	20C
0005434244933	5052	27	20D
0005434244910	5052	28	22B
0005432166897	5052	29	22D
0005433534479	5052	30	23B
0005434244909	5052	31	24A
0005434244925	5052	32	24E
0005434244916	5052	33	25E
0005434244920	5052	34	26A
0005434244915	5052	35	26B
0005434244907	5052	36	26D
0005432166893	5052	37	26F
0005434244932	5052	38	27C
0005434244917	5052	39	27B
0005435286553	5052	40	28B
0005434244906	5052	41	30C
0005434244914	5052	42	31A
0005434244922	5052	43	31F
0005433614513	5053	1	1A
0005433784856	5053	2	1C
0005432105488	5053	3	1F
0005433784851	5053	4	1D
0005433784883	5053	5	2A
0005432105448	5053	6	2C
0005433614548	5053	7	2F
0005433784882	5053	8	2D
0005432105450	5053	9	3A
0005432667448	5053	10	3C
0005433614531	5053	11	3F
0005433614577	5053	12	3D
0005432105451	5053	13	4C
0005432105491	5053	14	4A
0005433614560	5053	15	4F
0005433614583	5053	16	4D
0005432105449	5053	17	5A
0005433614517	5053	18	5C
0005432666383	5053	19	5F
0005433614575	5053	20	5D
0005433614565	5053	21	6A
0005432105494	5053	22	6C
0005433784866	5053	23	6F
0005433614522	5053	24	6D
0005432667449	5053	25	7A
0005433614541	5053	26	7C
0005432105486	5053	27	7F
0005432105477	5053	28	7D
0005433614514	5053	29	8A
0005433784873	5053	30	8B
0005433614561	5053	31	8D
0005432105461	5053	32	8C
0005432105453	5053	33	8E
0005432105456	5053	34	9A
0005432105475	5053	35	8F
0005433784885	5053	36	9B
0005433614567	5053	37	9C
0005432105459	5053	38	9D
0005433614533	5053	39	9F
0005433784871	5053	40	9E
0005432105476	5053	41	10A
0005433784853	5053	42	10B
0005433614516	5053	43	10D
0005432105464	5053	44	10C
0005432145109	5053	45	10E
0005432105487	5053	46	10F
0005433784875	5053	47	11A
0005433784878	5053	48	11C
0005433614518	5053	49	11B
0005432105455	5053	50	11D
0005433614540	5053	51	11F
0005433614562	5053	52	11E
0005432105479	5053	53	12A
0005433614556	5053	54	12B
0005433614520	5053	55	12C
0005433784859	5053	56	12E
0005433614574	5053	57	12D
0005433614521	5053	58	13A
0005432105468	5053	59	12F
0005433614538	5053	60	13B
0005433614532	5053	61	13C
0005433614564	5053	62	13D
0005433614523	5053	63	13F
0005432105478	5053	64	13E
0005433784872	5053	65	14A
0005433614515	5053	66	14C
0005433784863	5053	67	14B
0005432665269	5053	68	14D
0005433614534	5053	69	14E
0005433784861	5053	70	14F
0005433614529	5053	71	15A
0005433784886	5053	72	15C
0005433614578	5053	73	15B
0005433614551	5053	74	15E
0005432105467	5053	75	15D
0005433614547	5053	76	15F
0005433614512	5053	77	16A
0005432105466	5053	78	16B
0005433614568	5053	79	16D
0005432105483	5053	80	16C
0005432105458	5053	81	16E
0005433614544	5053	82	17A
0005433614509	5053	83	16F
0005432105465	5053	84	17B
0005433614573	5053	85	17C
0005433614543	5053	86	17E
0005433614552	5053	87	17D
0005433784877	5053	88	17F
0005433614554	5053	89	18A
0005432665270	5053	90	18B
0005432105489	5053	91	18C
0005433784857	5053	92	18E
0005433614530	5053	93	18D
0005433784858	5053	94	18F
0005432105472	5053	95	19C
0005432665271	5053	96	19B
0005433784876	5053	97	19D
0005433614511	5053	98	19E
0005432105493	5053	99	20B
0005433614557	5053	100	20A
0005433614579	5053	101	20C
0005433784881	5053	102	20D
0005433784874	5053	103	20E
0005433784880	5053	104	21A
0005432105457	5053	105	20F
0005432145107	5053	106	21C
0005433614519	5053	107	21B
0005433784867	5053	108	21D
0005433614570	5053	109	21F
0005432105484	5053	110	21E
0005433614539	5053	111	22B
0005433614542	5053	112	22A
0005432105490	5053	113	22D
0005433784860	5053	114	22C
0005432105480	5053	115	22E
0005433784870	5053	116	22F
0005432105447	5053	117	23B
0005432105469	5053	118	23A
0005432105470	5053	119	23C
0005432666384	5053	120	23D
0005433614527	5053	121	23E
0005433784869	5053	122	24A
0005433614536	5053	123	23F
0005433784868	5053	124	24B
0005433614572	5053	125	24D
0005432105471	5053	126	24C
0005433614569	5053	127	24E
0005432667450	5053	128	24F
0005433614582	5053	129	25B
0005433784865	5053	130	25A
0005433614553	5053	131	25C
0005432105463	5053	132	25E
0005433614546	5053	133	25D
0005433614535	5053	134	25F
0005433614563	5053	135	26A
0005433614555	5053	136	26B
0005433614526	5053	137	26C
0005432105452	5053	138	26E
0005433614537	5053	139	26D
0005433784879	5053	140	27A
0005433614545	5053	141	26F
0005432105481	5053	142	27B
0005432105492	5053	143	27C
0005432105485	5053	144	27D
0005433614524	5053	145	27E
0005432105454	5053	146	27F
0005433784884	5053	147	28B
0005432105462	5053	148	28A
0005433614549	5053	149	28D
0005433784852	5053	150	28C
0005433614566	5053	151	28E
0005433614550	5053	152	28F
0005433614528	5053	153	29A
0005432105474	5053	154	29C
0005432105473	5053	155	29B
0005433784864	5053	156	29D
0005433614525	5053	157	29E
0005433784855	5053	158	30A
0005433614576	5053	159	29F
0005433614580	5053	160	30B
0005432105482	5053	161	30C
0005433614581	5053	162	30E
0005433614558	5053	163	30D
0005433614571	5053	164	30F
0005433614510	5053	165	31A
0005433784862	5053	166	31C
0005432145108	5053	167	31B
0005433614559	5053	168	31E
0005433784854	5053	169	31D
0005432105460	5053	170	31F
0005435269660	5060	1	1A
0005434312298	5060	2	1C
0005434229313	5060	3	1F
0005435006800	5060	4	1D
0005434265095	5060	5	2A
0005434149704	5060	6	2D
0005432335946	5060	7	3A
0005434265098	5060	8	2F
0005434265081	5060	9	3C
0005432335915	5060	10	4D
0005435006823	5060	11	4C
0005434229322	5060	12	4F
0005435269666	5060	13	5A
0005435006799	5060	14	5C
0005435006798	5060	15	5D
0005434265094	5060	16	6A
0005434312296	5060	17	5F
0005433815328	5060	18	6C
0005432335916	5060	19	6F
0005435006730	5060	20	6D
0005434265082	5060	21	7C
0005434173512	5060	22	7F
0005433815336	5060	23	7D
0005434229325	5060	24	8A
0005435006753	5060	25	8D
0005432335930	5060	26	8C
0005434229314	5060	27	8E
0005434229334	5060	28	8F
0005434265093	5060	29	9A
0005434149707	5060	30	9C
0005434265089	5060	31	9B
0005434265077	5060	32	9E
0005435006815	5060	33	9D
0005434229332	5060	34	9F
0005434265075	5060	35	10D
0005434149708	5060	36	11A
0005434149710	5060	37	10F
0005434265078	5060	38	11C
0005432335960	5060	39	12B
0005434265080	5060	40	12E
0005434229330	5060	41	12D
0005434265079	5060	42	12F
0005434149712	5060	43	13B
0005435006852	5060	44	13A
0005433815335	5060	45	13C
0005434311191	5060	46	13D
0005432335947	5060	47	13E
0005434265085	5060	48	14A
0005435006706	5060	49	13F
0005434229318	5060	50	14C
0005435006725	5060	51	14E
0005435006816	5060	52	14F
0005434149701	5060	53	15C
0005432335940	5060	54	15B
0005434149711	5060	55	15E
0005433685492	5060	56	15D
0005433815333	5060	57	15F
0005435269650	5060	58	16A
0005434149705	5060	59	16C
0005434265073	5060	60	16E
0005434229335	5060	61	16F
0005435006794	5060	62	17C
0005434173510	5060	63	17D
0005435006818	5060	64	17E
0005435006738	5060	65	18A
0005434265096	5060	66	18C
0005433685500	5060	67	18B
0005432335945	5060	68	18D
0005434229333	5060	69	18E
0005434229326	5060	70	19B
0005434265088	5060	71	19D
0005434265086	5060	72	19C
0005434173511	5060	73	20B
0005434229328	5060	74	20C
0005435006705	5060	75	20F
0005435006739	5060	76	20E
0005434229324	5060	77	21A
0005434265087	5060	78	21C
0005434229327	5060	79	21D
0005434229315	5060	80	21E
0005434265097	5060	81	22A
0005433815334	5060	82	21F
0005434229316	5060	83	22B
0005432335912	5060	84	22C
0005434149703	5060	85	22F
0005434229331	5060	86	22E
0005434229336	5060	87	23A
0005434265092	5060	88	23D
0005434265076	5060	89	23E
0005434149709	5060	90	23F
0005434265083	5060	91	24B
0005435269671	5060	92	24D
0005432335873	5060	93	24C
0005434265090	5060	94	24E
0005435006726	5060	95	25D
0005435006752	5060	96	25F
0005435006723	5060	97	26A
0005434149702	5060	98	26B
0005435269651	5060	99	26D
0005435006776	5060	100	26C
0005435006750	5060	101	26E
0005434265084	5060	102	26F
0005435006740	5060	103	27B
0005434265074	5060	104	27D
0005433815327	5060	105	27E
0005435006745	5060	106	28B
0005434229321	5060	107	28C
0005434265091	5060	108	28E
0005432335941	5060	109	29A
0005434229329	5060	110	29C
0005434173513	5060	111	29D
0005434229320	5060	112	29F
0005434229323	5060	113	30B
0005435269665	5060	114	30C
0005434149706	5060	115	31A
0005434229319	5060	116	31C
0005435269659	5060	117	31B
0005435006737	5060	118	31D
0005434229317	5060	119	31E
0005434244807	8430	1	1A
0005433784677	8430	2	1D
0005433784654	8430	3	3A
0005433784593	8430	4	3D
0005434244663	8430	5	4A
0005433784474	8430	6	3F
0005434244752	8430	7	5A
0005433784480	8430	8	6C
0005434244661	8430	9	7C
0005433784491	8430	10	7F
0005433784441	8430	11	8A
0005434244806	8430	12	8C
0005434244660	8430	13	8E
0005433784732	8430	14	8F
0005433784561	8430	15	9E
0005434244824	8430	16	10E
0005433784656	8430	17	11B
0005434244679	8430	18	11A
0005433784693	8430	19	11F
0005434244823	8430	20	11E
0005433784588	8430	21	12A
0005433784560	8430	22	12C
0005433784570	8430	23	13A
0005434244624	8430	24	13D
0005434244735	8430	25	13F
0005433784699	8430	26	14B
0005435269746	8430	27	14F
0005433784679	8430	28	15B
0005435269747	8430	29	15E
0005433784592	8430	30	16A
0005434244676	8430	31	15F
0005433784587	8430	32	16C
0005433784733	8430	33	16E
0005434244668	8430	34	16D
0005433784678	8430	35	16F
0005434244697	8430	36	17E
0005434244690	8430	37	18A
0005434244623	8430	38	18D
0005433784458	8430	39	18E
0005434244674	8430	40	20A
0005434244662	8430	41	20C
0005433784442	8430	42	20B
0005433784504	8430	43	21C
0005434244730	8430	44	22B
0005434244691	8430	45	22D
0005434244667	8430	46	22C
0005434244675	8430	47	22F
0005433784583	8430	48	23A
0005433784397	8430	49	26B
0005434244731	8430	50	26C
0005433784629	8430	51	26D
0005433784589	8430	52	26F
0005434244673	8430	53	27A
0005433784502	8430	54	27C
0005434244604	8430	55	28B
0005433784509	8430	56	28C
0005434244716	8430	57	28F
0005433784655	8430	58	30C
0005434244719	8430	59	30B
0005434244693	8430	60	30A
0005433784479	8430	61	30D
0005434244664	8430	62	30E
0005434244615	8430	63	30F
0005434244736	8430	64	31A
0005433613980	8431	1	1A
0005433613716	8431	2	1C
0005433614037	8431	3	1D
0005433613573	8431	4	2A
0005433613852	8431	5	1F
0005433613981	8431	6	3A
0005433613666	8431	7	3F
0005433613780	8431	8	4D
0005433613954	8431	9	4F
0005433613782	8431	10	5C
0005433614124	8431	11	5F
0005433613846	8431	12	6D
0005433613808	8431	13	6C
0005433613609	8431	14	6F
0005433613920	8431	15	7A
0005433613731	8431	16	7C
0005433614035	8431	17	7F
0005433613646	8431	18	8B
0005433613736	8431	19	8D
0005433613779	8431	20	8C
0005433613953	8431	21	9C
0005433613796	8431	22	9B
0005433613762	8431	23	9D
0005433613742	8431	24	9E
0005433614068	8431	25	10E
0005433613608	8431	26	11A
0005433613830	8431	27	10F
0005433613647	8431	28	11B
0005433613770	8431	29	11C
0005433614073	8431	30	11D
0005433613696	8431	31	11E
0005433613918	8431	32	12A
0005433614271	8431	33	12B
0005433613807	8431	34	12C
0005433613880	8431	35	12D
0005433613693	8431	36	12E
0005433613876	8431	37	13C
0005433613486	8431	38	13D
0005433613975	8431	39	14A
0005433613856	8431	40	13F
0005433613432	8431	41	14D
0005433613719	8431	42	14C
0005433613973	8431	43	15A
0005433613781	8431	44	15D
0005433613582	8431	45	15F
0005433614057	8431	46	15E
0005433613881	8431	47	16B
0005433613829	8431	48	16C
0005433613790	8431	49	16E
0005433613786	8431	50	17C
0005433613910	8431	51	17D
0005433613645	8431	52	17F
0005433613817	8431	53	18C
0005433613908	8431	54	18F
0005433614242	8431	55	19C
0005433613651	8431	56	19E
0005433613855	8431	57	20B
0005433613834	8431	58	20A
0005433613692	8431	59	20C
0005433614058	8431	60	20E
0005433613998	8431	61	21A
0005433613797	8431	62	21B
0005433613888	8431	63	21F
0005433613891	8431	64	22B
0005433613665	8431	65	22C
0005433614036	8431	66	22D
0005433613917	8431	67	22F
0005433614021	8431	68	24B
0005433613909	8431	69	24E
0005433613787	8431	70	24F
0005433613919	8431	71	25A
0005433613734	8431	72	25C
0005433613676	8431	73	26A
0005433613853	8431	74	26F
0005433613763	8431	75	27A
0005433613700	8431	76	27C
0005433614270	8431	77	27D
0005433613730	8431	78	28A
0005433614072	8431	79	27F
0005433613997	8431	80	28F
0005433613809	8431	81	29B
0005433613720	8431	82	29A
0005433613950	8431	83	29D
0005433613945	8431	84	29C
0005433613890	8431	85	29F
0005433613551	8431	86	30B
0005433614123	8431	87	30C
0005433613833	8431	88	30F
0005433613789	8431	89	31A
0005433613900	8431	90	31F
0005433613741	8431	91	31E
0005434229137	8432	1	1A
0005434264898	8432	2	1C
0005435286615	8432	3	1F
0005435006991	8432	4	2C
0005432336006	8432	5	2D
0005433688806	8432	6	3A
0005435006972	8432	7	2F
0005435006981	8432	8	3C
0005435286619	8432	9	3D
0005433690923	8432	10	4A
0005434173473	8432	11	3F
0005432034881	8432	12	4C
0005435006979	8432	13	5A
0005434229066	8432	14	4F
0005434149645	8432	15	5C
0005435006980	8432	16	5F
0005435006987	8432	17	5D
0005435286616	8432	18	6A
0005434229160	8432	19	6C
0005433690922	8432	20	6F
0005433688805	8432	21	6D
0005432034901	8432	22	7D
0005434264796	8432	23	7C
0005434264765	8432	24	7F
0005432034902	8432	25	8A
0005432034896	8432	26	8B
0005435286623	8432	27	8D
0005433534494	8432	28	8C
0005432336007	8432	29	8E
0005434264846	8432	30	9A
0005434264862	8432	31	8F
0005432034900	8432	32	9B
0005434265027	8432	33	9C
0005432336009	8432	34	9D
0005434173471	8432	35	9F
0005434149579	8432	36	9E
0005435006969	8432	37	10A
0005434149610	8432	38	10D
0005434228993	8432	39	10C
0005432034878	8432	40	10F
0005434264810	8432	41	10E
0005435286617	8432	42	11B
0005432034890	8432	43	11D
0005435006977	8432	44	11F
0005432336005	8432	45	11E
0005434229216	8432	46	12A
0005432047543	8432	47	12C
0005434229088	8432	48	12E
0005432034892	8432	49	12D
0005432034876	8432	50	12F
0005434264940	8432	51	13B
0005434264863	8432	52	13C
0005433688804	8432	53	13D
0005432034884	8432	54	13F
0005432336008	8432	55	13E
0005432336012	8432	56	14A
0005435006994	8432	57	14B
0005435006974	8432	58	14C
0005433815379	8432	59	14E
0005434264847	8432	60	14D
0005432034894	8432	61	15A
0005432034888	8432	62	14F
0005434264845	8432	63	15C
0005435006971	8432	64	15B
0005435006976	8432	65	15D
0005434264807	8432	66	15F
0005434149578	8432	67	16A
0005432034885	8432	68	16C
0005435006982	8432	69	16B
0005435006978	8432	70	16E
0005434229089	8432	71	16F
0005435006983	8432	72	17B
0005435286618	8432	73	17A
0005434229189	8432	74	17C
0005432336010	8432	75	17D
0005432336011	8432	76	17F
0005434311214	8432	77	17E
0005432034899	8432	78	18A
0005434264829	8432	79	18B
0005432336014	8432	80	18C
0005435006992	8432	81	18E
0005434264771	8432	82	18D
0005434229151	8432	83	18F
0005433690924	8432	84	19C
0005434264916	8432	85	19B
0005432034903	8432	86	19D
0005434149625	8432	87	20A
0005432034891	8432	88	19E
0005434264806	8432	89	20B
0005434229181	8432	90	20C
0005434264772	8432	91	20E
0005434264920	8432	92	20D
0005432034895	8432	93	21A
0005434229152	8432	94	21C
0005432034904	8432	95	21B
0005434229110	8432	96	21D
0005434173470	8432	97	21E
0005432034880	8432	98	22A
0005433689906	8432	99	21F
0005432034898	8432	100	22C
0005433815375	8432	101	22D
0005432034877	8432	102	22F
0005434311215	8432	103	22E
0005435006989	8432	104	23A
0005435006988	8432	105	23C
0005433534493	8432	106	23D
0005434264804	8432	107	23E
0005432336013	8432	108	23F
0005434149646	8432	109	24B
0005434264867	8432	110	24A
0005432047544	8432	111	24D
0005435286622	8432	112	24C
0005435006985	8432	113	24E
0005435006986	8432	114	24F
0005435006970	8432	115	25B
0005434264791	8432	116	25A
0005433815374	8432	117	25D
0005434149609	8432	118	25C
0005435286620	8432	119	25E
0005434264769	8432	120	26A
0005434264809	8432	121	25F
0005434264939	8432	122	26B
0005434264764	8432	123	26C
0005434264814	8432	124	26D
0005435006975	8432	125	26F
0005435006990	8432	126	26E
0005435006993	8432	127	27B
0005432034879	8432	128	27A
0005433815378	8432	129	27D
0005435286621	8432	130	27C
0005435006973	8432	131	27E
0005434229081	8432	132	28A
0005433815376	8432	133	27F
0005432034897	8432	134	28B
0005433689907	8432	135	28C
0005432034887	8432	136	28E
0005432034882	8432	137	28D
0005435006984	8432	138	28F
0005434229115	8432	139	29A
0005434264830	8432	140	29C
0005434264805	8432	141	29B
0005434264774	8432	142	29E
0005433688807	8432	143	30A
0005432034889	8432	144	30B
0005432034893	8432	145	30D
0005434264926	8432	146	30C
0005433815377	8432	147	30E
0005434264986	8432	148	30F
0005432336015	8432	149	31A
0005432034883	8432	150	31C
0005434229103	8432	151	31D
0005434229125	8432	152	31E
0005432034886	8432	153	31F
0005434639091	12621	1	1A
0005434639105	12621	2	1B
0005434639108	12621	3	1C
0005433202332	12621	4	1D
0005434638930	12621	5	2B
0005433202331	12621	6	2C
0005433202333	12621	7	3A
0005433202338	12621	8	3C
0005434639063	12621	9	4B
0005434639095	12621	10	4A
0005433202329	12621	11	4C
0005433202337	12621	12	5A
0005434639020	12621	13	5B
0005433202340	12621	14	5C
0005433202342	12621	15	5D
0005433202339	12621	16	6A
0005434639012	12621	17	6B
0005434639040	12621	18	6D
0005433202334	12621	19	7A
0005434639039	12621	20	7B
0005434639086	12621	21	18B
0005433202336	12621	22	18C
0005434639079	12621	23	18D
0005434639045	12621	24	19A
0005433202330	12621	25	19B
0005433202341	12621	26	19C
0005434639097	12621	27	19D
0005434639026	12621	28	20B
0005434639025	12621	29	20D
0005434639112	12621	30	21A
0005434639087	12621	31	21B
0005434639096	12621	32	21C
0005434639107	12621	33	21D
0005434639106	12621	34	22A
0005434639022	12621	35	22B
0005434639113	12621	36	22C
0005434639080	12621	37	22D
0005434639044	12621	38	23A
0005433202335	12621	39	23B
0005432290625	23378	1	1A
0005433202141	23378	2	1C
0005434639243	23378	3	1D
0005433202164	23378	4	2A
0005434639248	23378	5	2C
0005434639238	23378	6	2D
0005434639260	23378	7	3A
0005434639261	23378	8	3B
0005434639245	23378	9	3C
0005433202156	23378	10	3D
0005433202219	23378	11	4B
0005434639262	23378	12	4C
0005433202221	23378	13	4D
0005434639241	23378	14	5A
0005433202202	23378	15	5B
0005433202240	23378	16	5C
0005433202203	23378	17	6A
0005434639251	23378	18	6B
0005434639250	23378	19	6C
0005434639255	23378	20	7A
0005433202142	23378	21	7B
0005434639247	23378	22	7D
0005434639242	23378	23	18A
0005432290624	23378	24	18B
0005434639252	23378	25	18C
0005433202204	23378	26	19A
0005434639258	23378	27	19B
0005432290623	23378	28	19C
0005434639259	23378	29	19D
0005434639263	23378	30	20A
0005434639254	23378	31	20B
0005433202205	23378	32	20C
0005433202182	23378	33	20D
0005434639240	23378	34	21A
0005434639244	23378	35	21B
0005434639257	23378	36	21C
0005434639253	23378	37	21D
0005434639249	23378	38	22A
0005433202220	23378	39	22B
0005434639246	23378	40	22C
0005434639264	23378	41	22D
0005434639256	23378	42	23A
0005434639239	23378	43	23B
0005432328193	21060	1	1A
0005432328095	21060	2	1C
0005432382683	21060	3	1D
0005432328204	21060	4	1F
0005432328073	21060	5	2A
0005432328261	21060	6	2C
0005432382751	21060	7	2D
0005432382749	21060	8	2F
0005432328082	21060	9	3A
0005432328194	21060	10	3C
0005432328124	21060	11	3D
0005432054297	21060	12	3F
0005432328075	21060	13	4A
0005432328151	21060	14	4C
0005432328140	21060	15	4D
0005432328168	21060	16	4E
0005432328196	21060	17	4F
0005432328052	21060	18	5A
0005432328121	21060	19	5C
0005432382750	21060	20	5D
0005432328130	21060	21	5E
0005432382526	21060	22	5F
0005432328113	21060	23	6A
0005432328396	21060	24	6C
0005432328435	21060	25	6D
0005432328076	21060	26	6E
0005432328353	21060	27	7A
0005432328067	21060	28	6F
0005432054299	21060	29	7C
0005432328308	21060	30	7D
0005432382616	21060	31	7E
0005432328195	21060	32	7F
0005432328146	21060	33	8A
0005432382687	21060	34	8C
0005432328262	21060	35	8D
0005432328120	21060	36	8E
0005432328179	21060	37	9A
0005432328181	21060	38	8F
0005432382676	21060	39	9C
0005432328186	21060	40	9D
0005432328128	21060	41	9E
0005432054298	21060	42	9F
0005432328131	21060	43	10A
0005432328391	21060	44	10C
0005432382589	21060	45	10D
0005432382672	21060	46	10E
0005432382606	21060	47	10F
0005432382576	21060	48	11A
0005432328188	21060	49	11C
0005432328254	21060	50	11D
0005432328166	21060	51	11E
0005432327921	21060	52	11F
0005432382722	21060	53	12A
0005432328358	21060	54	12D
0005432328189	21060	55	12C
0005432382621	21060	56	12E
0005432328220	21060	57	12F
0005432382587	21060	58	13A
0005432328363	21060	59	13C
0005432328112	21060	60	13D
0005432382689	21060	61	13E
0005432328096	21060	62	13F
0005432328058	21060	63	14A
0005432382652	21060	64	14C
0005432382677	21060	65	14D
0005432382671	21060	66	14E
0005432328226	21060	67	14F
0005432328094	21060	68	15A
0005432382649	21060	69	15C
0005432382688	21060	70	15D
0005432382615	21060	71	15E
0005432382742	21060	72	15F
0005432382721	21060	73	16A
0005432327916	21060	74	16D
0005432328239	21060	75	16C
0005432328180	21060	76	16E
0005432382611	21060	77	16F
0005432328357	21060	78	17A
0005432328310	21060	79	17C
0005432327995	21060	80	17D
0005432327915	21060	81	17E
0005432328209	21060	82	17F
0005432328152	21060	83	18A
0005432328237	21060	84	18C
0005432328147	21060	85	18D
0005432328227	21060	86	18E
0005432382682	21060	87	18F
0005432328311	21060	88	19A
0005432382588	21060	89	19C
0005432382684	21060	90	19D
0005432328312	21060	91	19E
0005432328080	21060	92	19F
0005432382577	21060	93	20A
0005432382748	21060	94	20C
0005432328170	21060	95	20D
0005432328097	21060	96	20E
0005432328197	21060	97	20F
0005432328590	31224	1	1A
0005432383080	31224	2	1C
0005432383089	31224	3	1D
0005432383085	31224	4	1F
0005432328578	31224	5	2A
0005432383060	31224	6	2C
0005432328567	31224	7	2D
0005432383074	31224	8	2F
0005432328553	31224	9	3A
0005432383071	31224	10	3C
0005432328570	31224	11	3D
0005432328587	31224	12	3F
0005432383091	31224	13	4A
0005432383087	31224	14	4C
0005432383082	31224	15	4D
0005432328592	31224	16	4E
0005432328584	31224	17	4F
0005432383076	31224	18	5A
0005432328582	31224	19	5C
0005432328591	31224	20	5D
0005432328589	31224	21	5E
0005432383066	31224	22	5F
0005432383065	31224	23	6A
0005432328594	31224	24	6D
0005432328566	31224	25	6E
0005432383093	31224	26	6F
0005432328576	31224	27	7A
0005432287177	31224	28	7C
0005432383090	31224	29	7D
0005432328557	31224	30	7E
0005432383063	31224	31	7F
0005432383057	31224	32	8A
0005432328574	31224	33	8C
0005432328559	31224	34	8D
0005432383058	31224	35	9A
0005432328558	31224	36	9C
0005432383075	31224	37	9D
0005432383068	31224	38	9E
0005432383062	31224	39	9F
0005432383083	31224	40	10A
0005432383070	31224	41	10C
0005432383081	31224	42	10D
0005432383078	31224	43	10E
0005432328585	31224	44	10F
0005432287172	31224	45	11A
0005432328551	31224	46	11C
0005432328550	31224	47	11D
0005432328552	31224	48	11E
0005432328583	31224	49	11F
0005432328563	31224	50	12A
0005432383086	31224	51	12C
0005432383092	31224	52	12D
0005432383084	31224	53	12E
0005432328586	31224	54	12F
0005432383077	31224	55	13A
0005432383064	31224	56	13C
0005432328556	31224	57	13D
0005432383069	31224	58	13E
0005432383088	31224	59	13F
0005432328581	31224	60	14A
0005432328579	31224	61	14C
0005432287173	31224	62	14D
0005432383061	31224	63	14E
0005432383067	31224	64	14F
0005432328577	31224	65	15C
0005432328554	31224	66	15D
0005432383059	31224	67	15E
0005432287175	31224	68	15F
0005432328555	31224	69	16A
0005432328580	31224	70	16C
0005432328565	31224	71	16D
0005432328571	31224	72	16E
0005432383073	31224	73	16F
0005432383079	31224	74	17A
0005432328572	31224	75	17D
0005432328573	31224	76	17E
0005432328588	31224	77	17F
0005432383072	31224	78	18A
0005432848836	31224	79	18C
0005432287176	31224	80	18D
0005432328562	31224	81	18E
0005432328575	31224	82	18F
0005432328564	31224	83	19C
0005432328569	31224	84	19E
0005432328593	31224	85	19F
0005432328568	31224	86	20A
0005432328561	31224	87	20C
0005432287174	31224	88	20D
0005432328560	31224	89	20E
0005432383094	31224	90	20F
0005432424295	13298	1	1A
0005432424285	13298	2	1D
0005432424300	13298	3	1F
0005432424273	13298	4	2A
0005432424293	13298	5	2D
0005432424297	13298	6	2F
0005432424296	13298	7	3A
0005432424307	13298	8	3C
0005432424283	13298	9	3D
0005432424308	13298	10	4A
0005432424312	13298	11	4E
0005432424291	13298	12	4F
0005432424305	13298	13	5A
0005432424317	13298	14	5C
0005432424279	13298	15	6D
0005432424276	13298	16	6E
0005432424303	13298	17	6F
0005432424311	13298	18	7D
0005432424294	13298	19	8D
0005432424302	13298	20	9A
0005432424320	13298	21	9C
0005432424292	13298	22	9F
0005432424316	13298	23	10A
0005432424277	13298	24	10C
0005432424280	13298	25	10D
0005432424275	13298	26	10E
0005432424284	13298	27	10F
0005432424289	13298	28	11A
0005432424319	13298	29	11D
0005432424287	13298	30	11E
0005432424274	13298	31	11F
0005432424269	13298	32	12A
0005432424270	13298	33	12C
0005432424313	13298	34	12E
0005432424310	13298	35	13E
0005432424306	13298	36	14A
0005432424309	13298	37	15A
0005432424271	13298	38	15F
0005432424299	13298	39	16A
0005432424286	13298	40	16D
0005432424314	13298	41	16E
0005432424288	13298	42	16F
0005432424282	13298	43	17C
0005432424281	13298	44	17D
0005432424272	13298	45	17E
0005432424278	13298	46	17F
0005432424323	13298	47	18A
0005432424321	13298	48	18D
0005432424298	13298	49	18E
0005432424301	13298	50	19A
0005432424304	13298	51	19D
0005432424290	13298	52	19F
0005432424318	13298	53	20D
0005432424315	13298	54	20E
0005432424322	13298	55	20F
0005432423751	30700	1	1A
0005432423898	30700	2	1C
0005432423652	30700	3	1D
0005432423878	30700	4	1F
0005432423929	30700	5	2C
0005432423752	30700	6	2D
0005432423779	30700	7	3D
0005432423827	30700	8	4A
0005432423876	30700	9	4C
0005432423851	30700	10	4E
0005432423852	30700	11	5A
0005432423773	30700	12	4F
0005432423899	30700	13	5C
0005432423912	30700	14	5E
0005432423861	30700	15	5F
0005432423908	30700	16	6A
0005432423921	30700	17	6C
0005432423714	30700	18	7C
0005432423763	30700	19	7D
0005432423607	30700	20	7E
0005432423880	30700	21	8C
0005432423871	30700	22	8F
0005432423813	30700	23	9C
0005432423897	30700	24	9D
0005432423799	30700	25	9F
0005432423814	30700	26	10A
0005432423850	30700	27	10D
0005432423777	30700	28	10F
0005432423894	30700	29	11A
0005432423760	30700	30	11C
0005432423872	30700	31	11F
0005432423915	30700	32	12C
0005432423750	30700	33	12D
0005432423910	30700	34	12E
0005432423877	30700	35	13A
0005432423761	30700	36	12F
0005432423686	30700	37	13D
0005432423824	30700	38	13E
0005432423870	30700	39	14C
0005432423875	30700	40	14D
0005432423819	30700	41	14E
0005432423774	30700	42	14F
0005432423778	30700	43	15C
0005432423749	30700	44	16C
0005432423802	30700	45	16D
0005432423708	30700	46	17A
0005432423826	30700	47	17C
0005432423914	30700	48	17E
0005432423788	30700	49	18E
0005432423911	30700	50	18F
0005432423710	30700	51	19A
0005432423769	30700	52	19C
0005432423879	30700	53	19D
0005432423869	30700	54	19E
0005432423895	30700	55	19F
0005432423817	30700	56	20A
0005432822184	9613	1	1A
0005432901432	9613	2	1D
0005432817407	9613	3	1F
0005434157416	9613	4	2D
0005432817400	9613	5	2F
0005432822186	9613	6	3A
0005432822188	9613	7	4C
0005432817417	9613	8	4D
0005432817422	9613	9	4E
0005432822187	9613	10	4F
0005432817405	9613	11	5A
0005432822189	9613	12	5D
0005432901365	9613	13	5F
0005434157403	9613	14	6A
0005432817409	9613	15	6C
0005432817418	9613	16	6D
0005432817420	9613	17	6F
0005432817401	9613	18	7C
0005434448308	9613	19	7D
0005432817424	9613	20	8A
0005432822185	9613	21	8C
0005432817421	9613	22	8E
0005432901411	9613	23	8F
0005432817412	9613	24	9A
0005434157430	9613	25	9E
0005432817411	9613	26	9F
0005432817423	9613	27	10C
0005432901383	9613	28	10D
0005432901390	9613	29	10E
0005432817419	9613	30	10F
0005434186177	9613	31	11C
0005432822191	9613	32	11D
0005434157423	9613	33	11E
0005432817410	9613	34	12A
0005432901438	9613	35	12C
0005432288979	9613	36	12E
0005432288980	9613	37	13C
0005432817394	9613	38	13D
0005434157402	9613	39	13E
0005432822183	9613	40	13F
0005432901382	9613	41	14D
0005434448307	9613	42	14F
0005432822190	9613	43	15C
0005434157419	9613	44	15D
0005432901431	9613	45	15E
0005432817397	9613	46	16A
0005432817402	9613	47	16D
0005432817399	9613	48	16E
0005432817404	9613	49	16F
0005432817413	9613	50	17A
0005432901439	9613	51	17C
0005432901421	9613	52	17D
0005432817414	9613	53	17E
0005432817415	9613	54	17F
0005432817408	9613	55	18A
0005432901437	9613	56	18C
0005432817416	9613	57	18D
0005432817396	9613	58	18E
0005432817395	9613	59	18F
0005434186176	9613	60	19A
0005432817406	9613	61	19C
0005432817403	9613	62	20A
0005432901405	9613	63	20C
0005432817398	9613	64	20D
0005434448309	9613	65	20F
0005432817165	28962	1	1A
0005432901566	28962	2	1C
0005432822142	28962	3	1F
0005434157461	28962	4	2A
0005432817237	28962	5	2C
0005434157465	28962	6	2D
0005432822123	28962	7	2F
0005432817044	28962	8	3D
0005432817186	28962	9	4C
0005432817203	28962	10	4D
0005432901568	28962	11	4E
0005432002071	28962	12	5A
0005432901574	28962	13	5C
0005432901573	28962	14	5D
0005432817116	28962	15	5E
0005432901577	28962	16	6A
0005432817152	28962	17	6C
0005432817060	28962	18	6D
0005432901565	28962	19	6E
0005432901579	28962	20	6F
0005432822122	28962	21	7C
0005432817111	28962	22	7D
0005434157462	28962	23	7F
0005432817140	28962	24	8A
0005432901580	28962	25	8C
0005432901564	28962	26	8E
0005432822087	28962	27	8F
0005432817228	28962	28	9A
0005432817059	28962	29	9C
0005434448283	28962	30	9D
0005432817190	28962	31	10A
0005434157463	28962	32	10F
0005432817248	28962	33	11A
0005432817191	28962	34	11E
0005432901569	28962	35	11F
0005432822091	28962	36	12A
0005432817115	28962	37	12C
0005432901572	28962	38	12D
0005432817150	28962	39	12E
0005432817141	28962	40	12F
0005432822107	28962	41	13A
0005434186190	28962	42	13C
0005432901571	28962	43	13D
0005432822082	28962	44	13E
0005432817192	28962	45	13F
0005434186189	28962	46	14C
0005432817202	28962	47	14E
0005432817189	28962	48	15A
0005432901575	28962	49	15C
0005434186191	28962	50	15D
0005432901570	28962	51	15E
0005432817207	28962	52	15F
0005432817261	28962	53	16A
0005434157464	28962	54	16D
0005432817204	28962	55	16E
0005432817238	28962	56	16F
0005432901578	28962	57	17A
0005434157466	28962	58	17C
0005432817194	28962	59	17F
0005432901576	28962	60	18E
0005432901567	28962	61	19A
0005432822092	28962	62	19C
0005432822098	28962	63	19D
0005432817229	28962	64	20A
0005432817124	28962	65	20C
0005432822106	28962	66	20E
0005432817139	28962	67	20F
0005432613853	15124	1	1A
0005432611702	15124	2	1B
0005432613855	15124	3	2B
0005432613852	15124	4	3A
0005432611701	15124	5	3B
0005432613854	15124	6	4A
0005432611704	15124	7	5A
0005432611703	15124	8	5B
0005432611700	15124	9	6A
0005432613851	15124	10	6B
0005435841820	31561	1	1B
0005432607506	31561	2	3B
0005435842326	31561	3	6A
0005433568922	11865	1	1C
0005432947920	11865	2	1A
0005433568871	11865	3	1D
0005433568894	11865	4	2C
0005433568904	11865	5	2A
0005433568935	11865	6	1F
0005433568943	11865	7	2F
0005433568880	11865	8	2D
0005433568945	11865	9	3A
0005433568905	11865	10	3D
0005433568944	11865	11	4A
0005432947926	11865	12	3F
0005433568934	11865	13	4C
0005432947927	11865	14	5A
0005432947981	11865	15	4F
0005433568898	11865	16	4D
0005433568942	11865	17	5C
0005433568917	11865	18	5F
0005432948039	11865	19	5D
0005432948119	11865	20	6B
0005433568878	11865	21	6A
0005433568883	11865	22	6C
0005433568888	11865	23	6F
0005432948060	11865	24	6E
0005433568900	11865	25	6D
0005432947907	11865	26	7A
0005433568939	11865	27	7B
0005432947978	11865	28	7E
0005433568892	11865	29	7D
0005433568918	11865	30	8A
0005433568931	11865	31	7F
0005433568906	11865	32	8C
0005433568930	11865	33	8B
0005432947788	11865	34	8D
0005433568872	11865	35	8F
0005433568938	11865	36	8E
0005433568912	11865	37	9B
0005433568875	11865	38	9A
0005433568940	11865	39	9C
0005433568881	11865	40	9F
0005433568913	11865	41	9E
0005433568882	11865	42	10B
0005433568933	11865	43	10A
0005432947847	11865	44	10C
0005433568911	11865	45	10E
0005432948064	11865	46	10D
0005433568874	11865	47	10F
0005433568893	11865	48	11B
0005432947987	11865	49	11A
0005432948059	11865	50	11D
0005433568908	11865	51	11C
0005433568936	11865	52	11F
0005433568929	11865	53	11E
0005432947985	11865	54	12A
0005433568924	11865	55	12C
0005433568907	11865	56	12F
0005432947837	11865	57	12D
0005432947846	11865	58	13A
0005433568890	11865	59	13C
0005433568903	11865	60	13E
0005432947908	11865	61	13D
0005433568915	11865	62	14A
0005433568932	11865	63	13F
0005433568895	11865	64	14B
0005433568899	11865	65	14D
0005433568941	11865	66	14C
0005432947943	11865	67	14E
0005433568884	11865	68	15B
0005433568910	11865	69	15A
0005433568916	11865	70	15D
0005432947980	11865	71	15C
0005433568887	11865	72	15E
0005433568928	11865	73	15F
0005433568885	11865	74	16C
0005433568902	11865	75	16E
0005433568897	11865	76	16D
0005433568914	11865	77	16F
0005433568889	11865	78	17B
0005433568923	11865	79	17A
0005433568927	11865	80	17D
0005433568921	11865	81	17C
0005433568877	11865	82	17F
0005432947789	11865	83	17E
0005432947986	11865	84	18A
0005432948013	11865	85	18C
0005433568879	11865	86	18B
0005432948014	11865	87	18F
0005433568925	11865	88	18E
0005433568873	11865	89	18D
0005433568891	11865	90	19A
0005433568869	11865	91	19B
0005432947893	11865	92	19D
0005432948065	11865	93	19C
0005433568876	11865	94	19F
0005432947792	11865	95	19E
0005433568919	11865	96	20B
0005432948084	11865	97	20D
0005433568870	11865	98	20C
0005433568926	11865	99	20F
0005433568937	11865	100	20E
0005433568901	11865	101	21A
0005433568909	11865	102	21D
0005433568886	11865	103	21C
0005433568920	11865	104	21B
0005433568896	11865	105	21F
0005433568144	25293	1	1C
0005432948425	25293	2	1A
0005432948411	25293	3	1F
0005433568388	25293	4	1D
0005432948391	25293	5	2C
0005432948431	25293	6	2A
0005432948407	25293	7	2F
0005433568411	25293	8	2D
0005433568398	25293	9	3A
0005433568408	25293	10	3D
0005432948430	25293	11	3C
0005433568220	25293	12	4A
0005432948392	25293	13	3F
0005432948398	25293	14	4D
0005433568409	25293	15	4C
0005433568399	25293	16	5C
0005432948416	25293	17	5F
0005433568309	25293	18	5D
0005432948408	25293	19	6B
0005432948419	25293	20	6F
0005433568339	25293	21	6E
0005433568391	25293	22	7A
0005433568117	25293	23	7B
0005433568310	25293	24	7E
0005432948399	25293	25	7D
0005432948428	25293	26	8A
0005432948406	25293	27	8C
0005433568326	25293	28	8B
0005432948400	25293	29	8D
0005433568320	25293	30	8F
0005433568340	25293	31	8E
0005433568390	25293	32	9B
0005432948405	25293	33	9A
0005432948420	25293	34	9D
0005433568389	25293	35	9C
0005433568244	25293	36	9F
0005433568275	25293	37	10A
0005432948390	25293	38	10C
0005433568124	25293	39	10B
0005432948395	25293	40	10E
0005433568282	25293	41	10D
0005433568146	25293	42	11A
0005432948415	25293	43	10F
0005432948401	25293	44	11B
0005432948422	25293	45	11D
0005433568329	25293	46	11C
0005432948414	25293	47	11F
0005433568386	25293	48	12B
0005433568357	25293	49	12A
0005433568369	25293	50	12D
0005433568412	25293	51	12C
0005432948409	25293	52	12F
0005432948389	25293	53	12E
0005433568278	25293	54	13A
0005433568281	25293	55	13C
0005433568141	25293	56	13D
0005433568317	25293	57	13F
0005433568125	25293	58	14C
0005432948429	25293	59	14F
0005433568330	25293	60	14E
0005433568032	25293	61	15B
0005432948418	25293	62	15A
0005432948423	25293	63	15D
0005432948410	25293	64	15F
0005433568349	25293	65	15E
0005432948412	25293	66	16A
0005433568263	25293	67	16B
0005432948421	25293	68	16D
0005432948397	25293	69	17A
0005432948424	25293	70	16F
0005433568301	25293	71	16E
0005433568264	25293	72	17B
0005432948394	25293	73	17D
0005433568331	25293	74	17C
0005432948396	25293	75	17E
0005433568277	25293	76	18B
0005432948393	25293	77	18A
0005433568138	25293	78	18C
0005433568145	25293	79	18E
0005432948402	25293	80	18D
0005433568328	25293	81	19A
0005432948413	25293	82	18F
0005433568426	25293	83	19C
0005433568100	25293	84	19B
0005433568410	25293	85	19D
0005432948417	25293	86	19F
0005433568387	25293	87	19E
0005432948404	25293	88	20A
0005433568148	25293	89	20D
0005432948426	25293	90	20F
0005432948427	25293	91	20E
0005433568274	25293	92	21B
0005433568315	25293	93	21A
0005432948403	25293	94	21D
0005433568255	25293	95	21C
0005433568267	25293	96	21F
0005433568303	25293	97	21E
0005433811614	27935	1	4E
0005433811613	27935	2	8B
0005433811615	27935	3	10E
0005433811612	27935	4	18F
0005433811611	27935	5	22B
0005433811610	27935	6	22F
0005434654618	5424	1	1D
0005434654620	5424	2	1F
0005434654622	5424	3	2A
0005434654619	5424	4	2C
0005434654617	5424	5	2D
0005434654633	5424	6	2F
0005434656553	5424	7	3D
0005434654625	5424	8	3F
0005432114197	5424	9	4A
0005434654609	5424	10	4C
0005435555347	5424	11	4D
0005434654614	5424	12	4E
0005435555346	5424	13	5C
0005434654626	5424	14	5D
0005435340164	5424	15	5F
0005435340051	5424	16	6C
0005435340106	5424	17	6D
0005435340153	5424	18	7A
0005434654627	5424	19	7C
0005434654631	5424	20	8A
0005434654621	5424	21	8D
0005434654632	5424	22	8E
0005434656552	5424	23	9E
0005435555345	5424	24	10D
0005432114195	5424	25	10F
0005434654629	5424	26	11C
0005434656554	5424	27	11E
0005434654612	5424	28	12A
0005432114196	5424	29	12C
0005434654630	5424	30	12D
0005434654615	5424	31	12E
0005434654636	5424	32	13C
0005434654635	5424	33	13D
0005434654610	5424	34	13E
0005434654639	5424	35	13F
0005434654637	5424	36	14D
0005434654624	5424	37	15A
0005435340105	5424	38	15D
0005434654638	5424	39	16E
0005434654611	5424	40	16F
0005434654640	5424	41	17C
0005434654613	5424	42	17E
0005434654616	5424	43	17F
0005434654623	5424	44	18A
0005434654634	5424	45	19D
0005435340113	5424	46	19F
0005434654628	5424	47	19E
0005435340170	5424	48	20C
0005434654334	12547	1	1A
0005434654395	12547	2	2C
0005435340225	12547	3	2D
0005434654289	12547	4	2F
0005434654315	12547	5	3D
0005435340227	12547	6	4A
0005434654389	12547	7	4C
0005435340230	12547	8	5E
0005434654388	12547	9	6C
0005434654331	12547	10	6D
0005434654332	12547	11	6F
0005434654302	12547	12	7C
0005434654335	12547	13	7D
0005435340235	12547	14	8A
0005435340231	12547	15	8F
0005434654259	12547	16	9A
0005434654467	12547	17	9C
0005435340234	12547	18	9E
0005434654510	12547	19	9F
0005434654452	12547	20	10A
0005434656546	12547	21	10D
0005434654279	12547	22	10E
0005434654401	12547	23	10F
0005435555367	12547	24	11C
0005435340229	12547	25	11D
0005435340226	12547	26	11E
0005435340228	12547	27	11F
0005434654278	12547	28	12E
0005434654390	12547	29	12F
0005434654360	12547	30	13A
0005435340236	12547	31	13C
0005434654258	12547	32	13D
0005434654280	12547	33	14A
0005435555365	12547	34	14C
0005434656541	12547	35	14D
0005434654333	12547	36	14E
0005435340223	12547	37	14F
0005434654353	12547	38	15C
0005434654387	12547	39	16A
0005434654361	12547	40	16D
0005434654466	12547	41	16E
0005435340237	12547	42	16F
0005434654341	12547	43	17A
0005434654232	12547	44	17D
0005435340233	12547	45	17F
0005434654352	12547	46	18A
0005435340232	12547	47	18D
0005434654316	12547	48	18F
0005434654402	12547	49	19A
0005434654453	12547	50	19C
0005434654373	12547	51	19D
0005434654385	12547	52	19E
0005435340224	12547	53	19F
0005434654282	12547	54	20A
0005434654384	12547	55	20D
0005435555366	12547	56	20F
0005433656660	7428	1	1C
0005432078097	7428	2	1D
0005432078098	7428	3	1F
0005433722207	7428	4	2D
0005432078093	7428	5	2C
0005433715868	7428	6	2F
0005432428898	7428	7	3C
0005433715850	7428	8	3F
0005433715842	7428	9	3D
0005433715854	7428	10	4B
0005433719131	7428	11	4D
0005432428874	7428	12	4E
0005433715857	7428	13	5A
0005433722204	7428	14	5E
0005433715875	7428	15	6A
0005433715879	7428	16	5F
0005433715867	7428	17	6B
0005433715881	7428	18	6E
0005433715865	7428	19	7A
0005433656662	7428	20	6F
0005433715839	7428	21	7F
0005433689905	7428	22	8A
0005435266082	7428	23	8B
0005432078096	7428	24	8C
0005433715882	7428	25	8D
0005433722208	7428	26	8E
0005433715873	7428	27	9A
0005435266098	7428	28	9B
0005433715874	7428	29	9E
0005433715843	7428	30	9D
0005433656661	7428	31	9F
0005433722202	7428	32	10C
0005433715838	7428	33	10D
0005433715870	7428	34	10E
0005433715845	7428	35	11B
0005433715878	7428	36	11C
0005433715835	7428	37	11E
0005433722201	7428	38	11F
0005433715862	7428	39	12A
0005433715834	7428	40	12D
0005433715869	7428	41	12E
0005435266084	7428	42	13A
0005433715849	7428	43	13C
0005433715876	7428	44	13D
0005435266089	7428	45	13E
0005435266102	7428	46	13F
0005433722200	7428	47	14A
0005433715866	7428	48	14C
0005433715844	7428	49	14D
0005433715846	7428	50	14F
0005433715837	7428	51	15C
0005433722206	7428	52	15B
0005433715853	7428	53	15F
0005433715858	7428	54	15E
0005433715841	7428	55	16A
0005433715880	7428	56	16B
0005433715861	7428	57	16D
0005433719132	7428	58	16F
0005433715864	7428	59	16E
0005433715863	7428	60	17A
0005433715877	7428	61	17C
0005435266083	7428	62	17B
0005433715847	7428	63	17D
0005433688802	7428	64	17F
0005433715836	7428	65	17E
0005433688803	7428	66	18C
0005433715871	7428	67	18F
0005433715851	7428	68	19C
0005433715856	7428	69	19B
0005433722203	7428	70	19E
0005433715852	7428	71	19F
0005433715883	7428	72	20A
0005433719133	7428	73	20B
0005433715840	7428	74	20F
0005433656659	7428	75	21B
0005433715855	7428	76	21D
0005433722205	7428	77	21E
0005432078095	7428	78	22A
0005433715860	7428	79	22B
0005433719130	7428	80	22C
0005433715848	7428	81	22D
0005433719129	7428	82	22F
0005433715872	7428	83	23B
0005433715859	7428	84	23F
0005432078094	7428	85	23E
0005433715433	29247	1	1A
0005433685500	29247	2	1F
0005432428922	29247	3	2F
0005433719096	29247	4	2D
0005433656639	29247	5	3A
0005433656640	29247	6	3C
0005433715620	29247	7	3D
0005433715290	29247	8	4D
0005433715329	29247	9	4F
0005433715378	29247	10	5B
0005433715521	29247	11	5A
0005433719106	29247	12	5E
0005433715355	29247	13	6A
0005433715333	29247	14	6C
0005433719104	29247	15	6D
0005433715565	29247	16	6E
0005433722135	29247	17	6F
0005433685492	29247	18	7D
0005433715558	29247	19	7C
0005433722134	29247	20	8A
0005433722102	29247	21	8C
0005433715380	29247	22	8E
0005432006753	29247	23	9A
0005433656625	29247	24	9D
0005433656641	29247	25	9F
0005433715072	29247	26	9E
0005435266141	29247	27	10B
0005433715466	29247	28	10C
0005432428921	29247	29	10D
0005433719095	29247	30	11A
0005433715353	29247	31	11C
0005432428920	29247	32	11E
0005433715354	29247	33	12A
0005433715666	29247	34	12C
0005433715621	29247	35	12D
0005433715291	29247	36	12E
0005433715403	29247	37	12F
0005433715369	29247	38	13D
0005432006754	29247	39	13C
0005433715515	29247	40	13F
0005433715465	29247	41	14B
0005432006755	29247	42	14C
0005433656632	29247	43	14E
0005433722133	29247	44	15A
0005433715514	29247	45	14F
0005433715327	29247	46	15C
0005433715442	29247	47	15E
0005433715609	29247	48	16A
0005435266143	29247	49	16B
0005433715332	29247	50	16C
0005433715309	29247	51	16F
0005433722139	29247	52	17B
0005433715073	29247	53	17A
0005433715366	29247	54	17C
0005433715665	29247	55	17E
0005433715443	29247	56	17D
0005433715358	29247	57	18A
0005433722138	29247	58	18B
0005433715238	29247	59	18E
0005433715622	29247	60	18D
0005433715431	29247	61	18F
0005433715519	29247	62	19D
0005433715441	29247	63	20D
0005433715330	29247	64	21D
0005433722122	29247	65	21E
0005433715528	29247	66	21F
0005433722132	29247	67	22B
0005433656628	29247	68	22C
0005433656631	29247	69	22D
0005433715402	29247	70	23A
0005435266142	29247	71	23B
0005433715554	29247	72	23D
0005433715444	29247	73	23E
0005434184644	8707	1	1F
0005434182067	8707	2	2A
0005434182016	8707	3	4A
0005434182065	8707	4	4C
0005434095244	8707	5	4F
0005434095239	8707	6	5F
0005434095246	8707	7	7E
0005434182076	8707	8	9E
0005434095245	8707	9	10A
0005434095240	8707	10	10C
0005434095243	8707	11	10E
0005434095241	8707	12	10F
0005434095249	8707	13	11A
0005434095238	8707	14	11F
0005434182066	8707	15	12D
0005434095247	8707	16	12F
0005434095250	8707	17	14D
0005434095248	8707	18	14E
0005434184636	8707	19	15C
0005434182036	8707	20	16D
0005434181996	8707	21	16F
0005434182009	8707	22	17D
0005434182091	8707	23	17F
0005434095242	8707	24	18C
0005434184643	8707	25	18D
0005434182028	8707	26	19C
0005434183574	11629	1	1D
0005434095161	11629	2	2A
0005434095088	11629	3	2C
0005434095079	11629	4	3C
0005434183575	11629	5	3D
0005434182158	11629	6	4D
0005434143702	11629	7	4E
0005434182153	11629	8	4F
0005434182152	11629	9	5C
0005434182159	11629	10	5E
0005434095074	11629	11	6A
0005434095090	11629	12	7A
0005434182150	11629	13	7D
0005434095163	11629	14	8C
0005434183573	11629	15	8E
0005434095106	11629	16	8F
0005434095158	11629	17	9E
0005434095093	11629	18	9F
0005434095058	11629	19	10A
0005434095179	11629	20	10D
0005434182161	11629	21	11A
0005434095123	11629	22	11D
0005434095126	11629	23	12A
0005434095071	11629	24	12E
0005434326264	11629	25	12F
0005434182151	11629	26	13D
0005434182154	11629	27	13E
0005434095089	11629	28	13F
0005434095087	11629	29	14A
0005434184659	11629	30	14D
0005434095150	11629	31	15D
0005434095160	11629	32	16A
0005434095108	11629	33	17A
0005434095086	11629	34	17C
0005434326265	11629	35	17E
0005434326261	11629	36	17F
0005434182160	11629	37	18A
0005434095125	11629	38	18C
0005434095105	11629	39	18F
0005434182162	11629	40	19A
0005434182157	11629	41	19D
0005434095180	11629	42	20A
0005434182155	11629	43	20D
0005434182156	11629	44	20E
0005434182163	11629	45	20F
0005433397392	1424	1	1A
0005433397561	1424	2	1C
0005435732294	1424	3	1D
0005433397412	1424	4	1F
0005433397449	1424	5	2A
0005435732308	1424	6	2C
0005435732312	1424	7	2F
0005433397538	1424	8	3A
0005435732304	1424	9	3C
0005435732302	1424	10	4A
0005433456961	1424	11	4D
0005433397364	1424	12	4C
0005433397606	1424	13	4E
0005435732315	1424	14	4F
0005433456960	1424	15	5A
0005433397450	1424	16	5E
0005433397723	1424	17	5F
0005433456962	1424	18	6A
0005433397310	1424	19	6D
0005433397513	1424	20	6E
0005433397549	1424	21	6F
0005435732296	1424	22	7A
0005433397599	1424	23	7C
0005433397483	1424	24	7D
0005433397379	1424	25	7E
0005433397406	1424	26	7F
0005435732310	1424	27	8C
0005435732305	1424	28	8D
0005435732295	1424	29	8E
0005433397559	1424	30	8F
0005433397365	1424	31	9A
0005432297271	1424	32	9C
0005433397358	1424	33	9E
0005433397484	1424	34	9F
0005435732299	1424	35	10A
0005435732316	1424	36	10C
0005435732313	1424	37	10D
0005433397464	1424	38	10E
0005433397454	1424	39	10F
0005433397560	1424	40	11A
0005433397475	1424	41	11D
0005435732314	1424	42	11F
0005433397607	1424	43	12A
0005435732300	1424	44	12C
0005435732306	1424	45	12D
0005433397711	1424	46	12F
0005435732301	1424	47	13A
0005433397451	1424	48	13C
0005432297272	1424	49	13D
0005433397616	1424	50	13E
0005435732307	1424	51	13F
0005435732309	1424	52	14A
0005432906509	1424	53	14D
0005435732311	1424	54	14E
0005435732293	1424	55	14F
0005432297273	1424	56	15D
0005433397442	1424	57	16D
0005433397514	1424	58	17A
0005433397409	1424	59	17C
0005435732298	1424	60	17D
0005433397393	1424	61	17E
0005435732297	1424	62	17F
0005435732303	1424	63	18A
0005433397499	1424	64	18C
0005433456959	1424	65	18E
0005433397712	1424	66	18F
0005433397463	1424	67	19A
0005432906518	1424	68	19C
0005433397615	1424	69	19D
0005433397649	1424	70	19E
0005433456958	1424	71	19F
0005433397710	1424	72	20A
0005433397971	19245	1	1A
0005433397931	19245	2	1C
0005433397964	19245	3	1D
0005433397970	19245	4	1F
0005433397927	19245	5	2A
0005433397974	19245	6	2C
0005435732185	19245	7	2F
0005435732229	19245	8	3A
0005433397960	19245	9	3D
0005433397953	19245	10	3F
0005433397933	19245	11	4C
0005433397950	19245	12	4D
0005433397948	19245	13	4E
0005432906529	19245	14	4F
0005432906530	19245	15	5A
0005435732231	19245	16	5C
0005433397973	19245	17	6C
0005435732223	19245	18	6E
0005433397958	19245	19	7A
0005433397962	19245	20	7C
0005435732190	19245	21	7D
0005433397952	19245	22	7E
0005433397951	19245	23	7F
0005435732224	19245	24	8A
0005433456923	19245	25	8F
0005433456928	19245	26	9A
0005433397926	19245	27	9E
0005433397940	19245	28	10A
0005433397965	19245	29	10F
0005433397967	19245	30	11A
0005433397949	19245	31	11C
0005433397955	19245	32	11D
0005433397941	19245	33	11E
0005435732210	19245	34	11F
0005435732230	19245	35	12A
0005433397939	19245	36	12D
0005433397959	19245	37	12E
0005433397956	19245	38	12F
0005433397943	19245	39	13A
0005435732183	19245	40	13C
0005433397947	19245	41	13D
0005435732209	19245	42	14C
0005433397936	19245	43	14F
0005435732184	19245	44	15C
0005433397937	19245	45	15E
0005433397944	19245	46	16A
0005433397963	19245	47	16C
0005433397945	19245	48	16D
0005433397961	19245	49	16F
0005433397932	19245	50	17A
0005433397925	19245	51	17C
0005433397929	19245	52	17D
0005433397938	19245	53	17E
0005433397968	19245	54	18A
0005433397930	19245	55	18C
0005433397946	19245	56	18D
0005433397972	19245	57	18F
0005432906531	19245	58	19A
0005433397934	19245	59	19C
0005433397942	19245	60	19D
0005433397966	19245	61	19E
0005433397935	19245	62	19F
0005433397928	19245	63	20A
0005433397954	19245	64	20C
0005433397957	19245	65	20E
0005433397969	19245	66	20F
0005434443551	17367	1	2B
0005434443587	17367	2	3A
0005434443554	17367	3	3C
0005434443561	17367	4	4C
0005434443520	17367	5	5D
0005434443540	17367	6	6A
0005434443517	17367	7	6B
0005434443555	17367	8	7A
0005434443523	17367	9	7C
0005434443476	17367	10	18B
0005434443601	17367	11	18D
0005434443564	17367	12	19C
0005434443457	17367	13	21C
0005434443482	17367	14	22A
0005434443475	17367	15	23B
0005434443661	20565	1	2B
0005434443663	20565	2	3A
0005434443655	20565	3	3C
0005434443670	20565	4	4A
0005434443664	20565	5	5C
0005434443668	20565	6	6B
0005434443667	20565	7	6C
0005434443666	20565	8	7B
0005434443660	20565	9	18A
0005434443665	20565	10	18C
0005434443656	20565	11	18D
0005434443657	20565	12	19A
0005434443669	20565	13	20C
0005434443658	20565	14	21A
0005434443659	20565	15	21D
0005434443662	20565	16	23A
0005435377547	7234	1	1A
0005434954600	7234	2	1B
0005435377556	7234	3	2B
0005434954598	7234	4	3A
0005435377548	7234	5	3B
0005434954601	7234	6	4A
0005435377549	7234	7	5B
0005435377562	7234	8	5A
0005434954599	7234	9	6A
0005434954560	28342	1	1A
0005435377575	28342	2	2A
0005434954578	28342	3	3A
0005434954567	28342	4	4A
0005435377574	28342	5	4B
0005434954579	28342	6	6A
0005434954559	28342	7	6B
0005434351663	4466	1	1D
0005434351671	4466	2	2A
0005435893572	4466	3	3A
0005435893550	4466	4	3B
0005434351664	4466	5	3C
0005435893549	4466	6	3D
0005435893540	4466	7	4A
0005435893570	4466	8	5A
0005434351668	4466	9	5B
0005434351669	4466	10	5C
0005434351672	4466	11	7D
0005435893569	4466	12	18B
0005434351673	4466	13	18C
0005434351665	4466	14	18D
0005434351667	4466	15	19A
0005434351661	4466	16	19B
0005434351666	4466	17	19C
0005435893585	4466	18	19D
0005434351662	4466	19	20C
0005434351670	4466	20	21B
0005435893580	4466	21	21C
0005435893582	4466	22	22A
0005435893548	4466	23	22B
0005435893564	4466	24	22C
0005434351660	4466	25	23A
0005434351576	29643	1	1A
0005435893616	29643	2	1D
0005434351552	29643	3	4A
0005434351521	29643	4	4C
0005434351587	29643	5	5A
0005434351588	29643	6	5C
0005434351503	29643	7	6C
0005434351570	29643	8	6D
0005434351520	29643	9	7C
0005435893618	29643	10	18B
0005434351540	29643	11	18C
0005434351562	29643	12	19A
0005434351551	29643	13	19C
0005434351565	29643	14	19D
0005435893615	29643	15	20A
0005434351586	29643	16	21B
0005435893613	29643	17	21C
0005434351525	29643	18	22A
0005435893617	29643	19	22B
0005434351563	29643	20	22D
0005435893614	29643	21	23A
0005434351518	29643	22	23B
0005433341892	1089	1	1A
0005433342248	1089	2	1F
0005433341832	1089	3	1C
0005433341957	1089	4	1G
0005433342066	1089	5	2A
0005433341891	1089	6	1H
0005433342078	1089	7	2C
0005433341860	1089	8	2F
0005434446515	1089	9	2H
0005435092054	1089	10	2G
0005433342048	1089	11	3B
0005433341982	1089	12	3C
0005433342035	1089	13	3G
0005433341904	1089	14	4A
0005434445243	1089	15	3H
0005433341863	1089	16	4G
0005435092055	1089	17	4F
0005433342159	1089	18	5B
0005433341518	1089	19	5C
0005433342020	1089	20	9H
0005433159285	1089	21	11A
0005433341915	1089	22	11B
0005433342034	1089	23	11F
0005433341858	1089	24	11E
0005433341460	1089	25	11H
0005433341905	1089	26	11G
0005433342065	1089	27	12E
0005433341627	1089	28	12G
0005433341994	1089	29	13A
0005433341866	1089	30	13D
0005433462742	1089	31	13B
0005435092051	1089	32	13E
0005433342032	1089	33	13G
0005433342236	1089	34	13H
0005433341828	1089	35	14A
0005433342271	1089	36	14B
0005433342061	1089	37	14E
0005433341963	1089	38	14G
0005433342087	1089	39	15A
0005433341869	1089	40	14H
0005433342042	1089	41	15E
0005433341996	1089	42	15D
0005433341796	1089	43	15H
0005433341850	1089	44	15G
0005433342384	1089	45	16A
0005433342141	1089	46	16D
0005433341774	1089	47	16E
0005433341990	1089	48	16F
0005433341895	1089	49	16G
0005433341749	1089	50	17B
0005433341833	1089	51	17A
0005435092053	1089	52	17F
0005433341880	1089	53	17H
0005433341859	1089	54	18B
0005433342028	1089	55	18A
0005433342214	1089	56	18D
0005433342100	1089	57	18E
0005433342280	1089	58	18G
0005433341975	1089	59	19A
0005433342185	1089	60	18H
0005433341993	1089	61	19B
0005433341997	1089	62	19D
0005433341964	1089	63	19F
0005433269670	1089	64	19H
0005435092050	1089	65	20D
0005433341943	1089	66	20B
0005433342195	1089	67	20E
0005433341961	1089	68	20F
0005433341628	1089	69	21B
0005433269669	1089	70	21E
0005433341991	1089	71	21G
0005433342249	1089	72	21F
0005433159283	1089	73	21H
0005433342025	1089	74	22D
0005433159284	1089	75	22B
0005433463896	1089	76	22F
0005433342129	1089	77	22E
0005432293203	1089	78	22H
0005433341897	1089	79	23B
0005433463895	1089	80	23A
0005433342115	1089	81	23D
0005433341773	1089	82	23G
0005433341814	1089	83	23F
0005433342033	1089	84	23H
0005433341629	1089	85	24B
0005433341721	1089	86	24D
0005433341827	1089	87	24F
0005433342353	1089	88	24H
0005433341558	1089	89	24G
0005433342067	1089	90	27A
0005433342052	1089	91	27E
0005433342130	1089	92	27D
0005433342245	1089	93	28A
0005433342131	1089	94	28E
0005433341929	1089	95	28F
0005433341896	1089	96	28G
0005433341792	1089	97	28H
0005433341756	1089	98	29D
0005433341959	1089	99	29B
0005434446514	1089	100	29F
0005433342334	1089	101	29G
0005433341989	1089	102	30A
0005433341962	1089	103	29H
0005432293202	1089	104	30B
0005435092046	1089	105	30G
0005433342150	1089	106	31E
0005432293204	1089	107	31G
0005433341877	1089	108	31H
0005433341967	1089	109	32E
0005434446516	1089	110	32D
0005433341401	1089	111	32F
0005435092047	1089	112	32H
0005433342060	1089	113	33D
0005433269666	1089	114	33H
0005433341776	1089	115	34B
0005433342041	1089	116	34A
0005435092052	1089	117	34D
0005433342244	1089	118	34E
0005433341787	1089	119	34G
0005435092048	1089	120	34H
0005433341977	1089	121	35D
0005435092049	1089	122	35G
0005434446517	1089	123	35F
0005433342086	1089	124	36A
0005433341976	1089	125	36B
0005433342040	1089	126	36E
0005433341968	1089	127	36D
0005433342049	1089	128	36G
0005433341901	1089	129	37A
0005433341876	1089	130	37B
0005433341890	1089	131	37D
0005433342073	1089	132	37F
0005433341791	1089	133	37E
0005433342499	1089	134	37H
0005433341851	1089	135	38A
0005433342199	1089	136	38D
0005433341643	1089	137	38B
0005433342110	1089	138	38E
0005433341811	1089	139	38G
0005433341793	1089	140	38H
0005433342383	1089	141	39D
0005433341958	1089	142	39F
0005433342857	17044	1	1A
0005435091958	17044	2	1F
0005433342813	17044	3	2A
0005433342899	17044	4	1H
0005435091980	17044	5	2B
0005433342861	17044	6	2F
0005433342887	17044	7	3G
0005433342808	17044	8	4A
0005435091904	17044	9	3H
0005433342886	17044	10	4F
0005433342852	17044	11	4G
0005433342832	17044	12	5A
0005433342907	17044	13	4H
0005433342896	17044	14	5F
0005433342833	17044	15	5G
0005433342878	17044	16	9A
0005433342884	17044	17	11A
0005433342831	17044	18	9H
0005433269703	17044	19	11B
0005433342894	17044	20	11D
0005435508211	17044	21	11F
0005433342876	17044	22	11H
0005433342817	17044	23	11G
0005433342836	17044	24	12B
0005433342898	17044	25	12F
0005433342890	17044	26	12H
0005433269704	17044	27	12G
0005433342824	17044	28	13B
0005433342901	17044	29	13D
0005433342868	17044	30	13G
0005433342826	17044	31	13F
0005433342897	17044	32	14A
0005433342851	17044	33	13H
0005433342850	17044	34	14B
0005433342875	17044	35	14E
0005433342838	17044	36	14G
0005433269705	17044	37	14F
0005433342860	17044	38	15A
0005433342825	17044	39	14H
0005435508219	17044	40	15B
0005433342820	17044	41	15G
0005433342880	17044	42	15F
0005433269708	17044	43	15E
0005433159306	17044	44	15H
0005433342835	17044	45	16A
0005435091957	17044	46	16E
0005433342854	17044	47	16G
0005433342828	17044	48	16F
0005435091985	17044	49	16H
0005433342811	17044	50	17B
0005433342882	17044	51	17D
0005433342842	17044	52	17F
0005433342902	17044	53	17G
0005433269707	17044	54	17H
0005435091931	17044	55	18B
0005433342862	17044	56	18A
0005435508222	17044	57	18F
0005435091984	17044	58	18H
0005433342863	17044	59	19D
0005433342904	17044	60	19G
0005433342849	17044	61	20A
0005433342885	17044	62	19H
0005435091966	17044	63	20D
0005433342809	17044	64	20F
0005433342874	17044	65	21A
0005433342853	17044	66	21D
0005433342879	17044	67	21B
0005433342867	17044	68	21F
0005433269706	17044	69	22A
0005435508223	17044	70	22D
0005433342858	17044	71	22B
0005433342892	17044	72	23A
0005433342843	17044	73	22H
0005433342805	17044	74	23B
0005433342827	17044	75	23D
0005433342893	17044	76	23E
0005435508224	17044	77	23G
0005433342871	17044	78	23H
0005433342845	17044	79	24B
0005433342869	17044	80	24E
0005433342877	17044	81	24H
0005433342903	17044	82	25F
0005433159307	17044	83	27A
0005433342818	17044	84	27E
0005435091934	17044	85	27D
0005433342906	17044	86	27F
0005433342848	17044	87	27G
0005433342866	17044	88	27H
0005435091965	17044	89	28B
0005433342823	17044	90	28E
0005433342900	17044	91	28F
0005433342891	17044	92	28H
0005433342883	17044	93	29D
0005433342822	17044	94	29B
0005433342895	17044	95	29H
0005435091978	17044	96	30B
0005435091983	17044	97	30A
0005433342816	17044	98	30F
0005433342847	17044	99	30E
0005433342834	17044	100	30G
0005435508216	17044	101	30H
0005433342814	17044	102	31B
0005433342837	17044	103	31E
0005433342905	17044	104	31D
0005433342839	17044	105	31H
0005433342810	17044	106	31G
0005435091967	17044	107	32D
0005433342855	17044	108	32E
0005433342840	17044	109	32H
0005433342873	17044	110	32G
0005433342856	17044	111	33A
0005433342870	17044	112	33D
0005433342844	17044	113	33B
0005433342806	17044	114	33E
0005433342865	17044	115	33G
0005433342872	17044	116	33F
0005433342859	17044	117	33H
0005433342881	17044	118	34B
0005433342821	17044	119	34D
0005433342812	17044	120	34F
0005433342846	17044	121	35A
0005435508191	17044	122	35D
0005433342819	17044	123	35G
0005433342841	17044	124	35H
0005435091930	17044	125	36E
0005435091979	17044	126	36G
0005435091959	17044	127	37B
0005435091955	17044	128	37E
0005433342830	17044	129	37F
0005435508221	17044	130	37H
0005434445215	17044	131	37G
0005433342864	17044	132	38B
0005433342815	17044	133	38A
0005433342829	17044	134	38E
0005433342888	17044	135	38H
0005435091991	17044	136	39E
0005433342807	17044	137	39D
0005433342889	17044	138	39F
0005432433667	12813	1	1A
0005434066928	12813	2	1C
0005433812895	12813	3	1D
0005434081633	12813	4	2A
0005434066521	12813	5	1F
0005434081691	12813	6	2C
0005434081662	12813	7	2F
0005434066710	12813	8	3A
0005434081568	12813	9	3F
0005434066807	12813	10	3D
0005434066858	12813	11	4B
0005434081651	12813	12	4A
0005434066456	12813	13	4C
0005434066841	12813	14	4E
0005432159850	12813	15	4D
0005434066764	12813	16	5A
0005434081496	12813	17	4F
0005434081634	12813	18	5C
0005434066643	12813	19	5B
0005434081614	12813	20	5D
0005434066588	12813	21	6A
0005434066924	12813	22	5F
0005432433666	12813	23	6B
0005435283408	12813	24	6C
0005432159847	12813	25	6D
0005434081567	12813	26	6E
0005434066944	12813	27	6F
0005434081599	12813	28	7B
0005434066626	12813	29	7A
0005434066959	12813	30	7D
0005434066560	12813	31	7E
0005434066613	12813	32	8A
0005434081720	12813	33	7F
0005434066759	12813	34	8B
0005434081663	12813	35	8C
0005434066457	12813	36	8D
0005434066765	12813	37	8F
0005434066666	12813	38	8E
0005434066921	12813	39	9A
0005432161148	12813	40	9B
0005434066463	12813	41	9C
0005434066511	12813	42	9D
0005434066840	12813	43	9F
0005434081612	12813	44	10B
0005434066618	12813	45	10D
0005434081613	12813	46	10C
0005434066591	12813	47	10E
0005434066523	12813	48	11B
0005434081747	12813	49	11C
0005434081620	12813	50	11E
0005434066975	12813	51	11F
0005434066540	12813	52	12A
0005434081562	12813	53	12C
0005432161147	12813	54	12D
0005434066589	12813	55	12E
0005434066918	12813	56	12F
0005434067086	12813	57	13A
0005434066555	12813	58	13B
0005434066942	12813	59	13C
0005434066754	12813	60	13F
0005434066649	12813	61	13E
0005434081566	12813	62	13D
0005434026681	12813	63	14A
0005432433669	12813	64	14C
0005434066943	12813	65	14B
0005434081563	12813	66	14D
0005434066500	12813	67	14F
0005434066407	12813	68	14E
0005434081646	12813	69	15A
0005434066982	12813	70	15B
0005434066685	12813	71	15C
0005434066406	12813	72	15D
0005432159845	12813	73	15F
0005434066995	12813	74	15E
0005434026672	12813	75	16B
0005434081647	12813	76	16A
0005434066727	12813	77	16C
0005434066763	12813	78	16D
0005434066673	12813	79	16F
0005434066884	12813	80	16E
0005434066726	12813	81	17B
0005432161146	12813	82	17A
0005434066672	12813	83	17C
0005434066522	12813	84	17E
0005434066851	12813	85	17D
0005434066644	12813	86	18A
0005434081661	12813	87	17F
0005434081621	12813	88	18B
0005434066834	12813	89	18C
0005434066578	12813	90	18E
0005432159849	12813	91	18D
0005434066719	12813	92	18F
0005434066661	12813	93	19B
0005434081721	12813	94	19D
0005434081746	12813	95	19C
0005434066755	12813	96	19E
0005434026682	12813	97	19F
0005432159846	12813	98	20B
0005434081650	12813	99	20A
0005434066606	12813	100	20C
0005434067015	12813	101	20E
0005434066874	12813	102	20D
0005434066724	12813	103	21A
0005432159848	12813	104	20F
0005432433668	12813	105	21C
0005434066655	12813	106	21D
0005433812894	12813	107	21E
0005434066723	12813	108	22A
0005434066561	12813	109	21F
0005434066667	12813	110	22E
0005434066833	12813	111	23A
0005434081641	12813	112	22F
0005434066590	12813	113	23B
0005434066479	12813	114	23C
0005434066835	12813	115	23E
0005434066875	12813	116	23D
0005434066604	12813	117	23F
0005434081822	30681	1	1A
0005434067352	30681	2	1C
0005433989755	30681	3	1D
0005434067327	30681	4	2A
0005434067340	30681	5	1F
0005434067350	30681	6	2C
0005433989757	30681	7	2D
0005433989758	30681	8	2F
0005434067376	30681	9	3C
0005432433625	30681	10	3A
0005432186858	30681	11	3D
0005434026700	30681	12	3F
0005434081825	30681	13	4A
0005434067364	30681	14	4B
0005434067315	30681	15	4E
0005434081829	30681	16	5A
0005434067332	30681	17	4F
0005434026699	30681	18	5B
0005434067359	30681	19	5C
0005434067345	30681	20	5D
0005432433630	30681	21	5E
0005433812868	30681	22	6A
0005434067366	30681	23	5F
0005434026697	30681	24	6B
0005434067372	30681	25	6C
0005433989756	30681	26	6D
0005434067357	30681	27	6E
0005434067343	30681	28	6F
0005434067311	30681	29	7B
0005434067346	30681	30	7A
0005432186859	30681	31	7C
0005434067333	30681	32	7D
0005433812870	30681	33	7E
0005434081833	30681	34	8A
0005434067368	30681	35	7F
0005432150167	30681	36	8B
0005432433638	30681	37	8C
0005434081820	30681	38	8E
0005434067377	30681	39	8D
0005432186857	30681	40	8F
0005434067378	30681	41	9A
0005434067341	30681	42	9B
0005434067328	30681	43	9D
0005434067318	30681	44	9C
0005434067374	30681	45	9E
0005434081824	30681	46	9F
0005434067382	30681	47	10B
0005434026695	30681	48	10C
0005432150173	30681	49	10E
0005434067363	30681	50	10D
0005433812866	30681	51	11A
0005434067317	30681	52	11B
0005434067381	30681	53	11C
0005433812869	30681	54	11E
0005434067365	30681	55	11D
0005434067337	30681	56	11F
0005432150171	30681	57	12B
0005432433620	30681	58	12A
0005434026698	30681	59	12C
0005434067361	30681	60	12D
0005434067344	30681	61	12E
0005434067313	30681	62	12F
0005434067314	30681	63	13A
0005434067316	30681	64	13B
0005432150166	30681	65	13D
0005434067324	30681	66	13E
0005434081827	30681	67	13F
0005434067347	30681	68	14B
0005434081836	30681	69	14A
0005434067349	30681	70	14D
0005434067334	30681	71	14C
0005434067380	30681	72	14E
0005434067373	30681	73	14F
0005433812863	30681	74	15B
0005434067331	30681	75	15A
0005434067369	30681	76	15C
0005434067358	30681	77	15D
0005434081828	30681	78	15F
0005434067330	30681	79	15E
0005434067342	30681	80	16A
0005433812862	30681	81	16B
0005432186856	30681	82	16C
0005434067353	30681	83	16D
0005434067383	30681	84	16F
0005432150172	30681	85	16E
0005434067351	30681	86	17A
0005434067335	30681	87	17B
0005434067367	30681	88	17C
0005434081830	30681	89	17D
0005434067339	30681	90	17E
0005433812871	30681	91	18A
0005434081821	30681	92	17F
0005434081823	30681	93	18C
0005434067326	30681	94	18B
0005434067321	30681	95	18E
0005434067370	30681	96	18D
0005434067338	30681	97	18F
0005434067336	30681	98	19A
0005434067323	30681	99	19B
0005434026696	30681	100	19D
0005434081832	30681	101	19C
0005434081826	30681	102	19E
0005434067356	30681	103	19F
0005434067348	30681	104	20A
0005434081834	30681	105	20B
0005432150168	30681	106	20D
0005434081819	30681	107	20C
0005434067312	30681	108	20E
0005434067320	30681	109	20F
0005434067355	30681	110	21B
0005434067362	30681	111	21A
0005432433634	30681	112	21C
0005434067360	30681	113	21D
0005434067322	30681	114	21E
0005432150170	30681	115	22A
0005434081831	30681	116	21F
0005434067319	30681	117	22C
0005434067325	30681	118	22B
0005434067375	30681	119	22D
0005432433637	30681	120	22E
0005434067329	30681	121	23A
0005434067379	30681	122	22F
0005434067371	30681	123	23B
0005432150174	30681	124	23C
0005434081835	30681	125	23D
0005432150169	30681	126	23F
0005434067354	30681	127	23E
0005435735126	5514	1	1A
0005435461940	5514	2	1B
0005435462079	5514	3	1F
0005432140431	5514	4	1C
0005435766075	5514	5	1H
0005435766094	5514	6	1G
0005434831082	5514	7	2A
0005435462090	5514	8	2B
0005435720820	5514	9	2F
0005435725585	5514	10	2C
0005434264800	5514	11	2G
0005434831083	5514	12	3A
0005435725586	5514	13	3B
0005432140430	5514	14	3F
0005434831090	5514	15	3C
0005435766077	5514	16	3G
0005435766102	5514	17	3H
0005435723040	5514	18	4B
0005435766105	5514	19	4A
0005435766128	5514	20	4F
0005435462012	5514	21	5A
0005435461980	5514	22	5F
0005435462075	5514	23	5C
0005435462119	5514	24	5H
0005432535759	5514	25	9A
0005435735125	5514	26	9G
0005432140432	5514	27	9B
0005434264874	5514	28	11A
0005435462092	5514	29	11B
0005435766090	5514	30	11D
0005435462085	5514	31	11F
0005435461987	5514	32	11E
0005435766109	5514	33	11G
0005435766073	5514	34	11H
0005435766134	5514	35	12D
0005435461986	5514	36	12B
0005432140425	5514	37	12E
0005435766088	5514	38	12F
0005435462175	5514	39	12H
0005435766138	5514	40	12G
0005435766086	5514	41	13A
0005435461982	5514	42	13D
0005434831099	5514	43	13B
0005435462047	5514	44	13F
0005435766112	5514	45	13E
0005435766087	5514	46	13H
0005435766121	5514	47	14D
0005435766091	5514	48	14F
0005434264885	5514	49	14E
0005435461862	5514	50	14G
0005435766113	5514	51	15A
0005433529270	5514	52	14H
0005435766116	5514	53	15B
0005434264889	5514	54	15E
0005434264747	5514	55	15D
0005435725587	5514	56	15F
0005435462118	5514	57	15G
0005435766107	5514	58	16B
0005435725588	5514	59	16A
0005435461928	5514	60	16D
0005434264763	5514	61	16E
0005435462051	5514	62	16G
0005435766103	5514	63	16F
0005435462018	5514	64	16H
0005435766130	5514	65	17B
0005432140426	5514	66	17F
0005435766118	5514	67	17E
0005435461981	5514	68	17G
0005435766076	5514	69	17H
0005435720821	5514	70	18D
0005435462164	5514	71	18E
0005435766133	5514	72	18G
0005435766119	5514	73	19A
0005434264790	5514	74	19B
0005435461848	5514	75	19E
0005435766093	5514	76	19D
0005435461999	5514	77	19F
0005435722049	5514	78	19H
0005433529271	5514	79	19G
0005435723039	5514	80	20A
0005434264886	5514	81	20B
0005432140427	5514	82	20D
0005434264883	5514	83	20F
0005435766089	5514	84	20G
0005435766120	5514	85	21B
0005435766083	5514	86	21A
0005435766124	5514	87	20H
0005435766100	5514	88	21D
0005434264832	5514	89	21E
0005435462136	5514	90	22A
0005435766123	5514	91	21H
0005435735127	5514	92	21G
0005435735128	5514	93	22B
0005435766099	5514	94	22D
0005432535778	5514	95	22E
0005435766096	5514	96	22G
0005435461855	5514	97	22F
0005435766135	5514	98	22H
0005433527260	5514	99	23B
0005435462091	5514	100	23A
0005434831098	5514	101	23D
0005435766084	5514	102	23F
0005435766114	5514	103	23E
0005435766122	5514	104	24A
0005435766136	5514	105	24D
0005434264820	5514	106	24E
0005435461950	5514	107	24G
0005435462135	5514	108	25D
0005435735130	5514	109	24H
0005435766127	5514	110	25F
0005435766080	5514	111	27B
0005435462080	5514	112	27A
0005435462095	5514	113	27F
0005435461985	5514	114	27H
0005435766137	5514	115	27G
0005435462011	5514	116	28A
0005435766126	5514	117	28E
0005435766131	5514	118	28D
0005435461967	5514	119	28F
0005434264799	5514	120	28H
0005435462174	5514	121	28G
0005435462069	5514	122	29B
0005435766106	5514	123	29E
0005435766125	5514	124	29F
0005435461949	5514	125	29H
0005435766095	5514	126	30B
0005434264855	5514	127	30A
0005434264844	5514	128	30E
0005432140429	5514	129	30G
0005434264823	5514	130	30H
0005435766097	5514	131	31B
0005435462062	5514	132	31E
0005435462052	5514	133	31D
0005435462289	5514	134	31H
0005435462063	5514	135	31G
0005435766081	5514	136	32B
0005432535788	5514	137	32E
0005435462010	5514	138	32D
0005435462046	5514	139	32G
0005435766078	5514	140	32F
0005432140428	5514	141	32H
0005434264854	5514	142	33A
0005435462048	5514	143	33B
0005434264899	5514	144	33F
0005435766111	5514	145	33H
0005435462070	5514	146	34A
0005435462076	5514	147	34D
0005435766132	5514	148	34G
0005435766110	5514	149	34F
0005435462057	5514	150	34H
0005435766101	5514	151	35D
0005434264869	5514	152	35B
0005435766085	5514	153	35F
0005435766079	5514	154	35E
0005435766098	5514	155	35H
0005435725583	5514	156	36A
0005434264824	5514	157	36E
0005435766092	5514	158	36F
0005435725589	5514	159	36H
0005435766082	5514	160	36G
0005435766074	5514	161	37A
0005435766108	5514	162	37D
0005435722050	5514	163	37B
0005434264826	5514	164	37E
0005435766117	5514	165	37H
0005435735129	5514	166	37G
0005435766115	5514	167	38B
0005434264868	5514	168	38D
0005435766129	5514	169	38F
0005435725584	5514	170	38G
0005433529269	5514	171	39D
0005435766104	5514	172	39F
0005434264907	5514	173	39E
0005435765639	13464	1	1A
0005432194499	13464	2	1C
0005435462373	13464	3	1B
0005433533270	13464	4	1F
0005435735108	13464	5	1H
0005434265096	13464	6	1G
0005435765518	13464	7	2A
0005435765643	13464	8	2B
0005434265088	13464	9	2C
0005435765409	13464	10	2H
0005435765615	13464	11	2G
0005432194503	13464	12	3A
0005435765391	13464	13	3C
0005434265080	13464	14	3F
0005434265089	13464	15	4A
0005435765521	13464	16	3H
0005432194501	13464	17	4B
0005435462344	13464	18	4C
0005435462338	13464	19	4F
0005435765467	13464	20	5B
0005435765561	13464	21	5A
0005432535822	13464	22	5F
0005432535824	13464	23	5C
0005433529244	13464	24	5G
0005435462360	13464	25	9B
0005435765566	13464	26	9G
0005433533247	13464	27	11D
0005434265092	13464	28	11B
0005434265078	13464	29	11E
0005434265087	13464	30	11G
0005435462351	13464	31	12A
0005434265073	13464	32	11H
0005433533262	13464	33	12D
0005435462336	13464	34	12B
0005433533249	13464	35	12E
0005433533250	13464	36	12F
0005435462364	13464	37	12H
0005433529213	13464	38	13D
0005432194504	13464	39	13B
0005433533252	13464	40	13E
0005435722025	13464	41	13G
0005434265082	13464	42	13H
0005435462368	13464	43	14B
0005435462361	13464	44	14D
0005434265079	13464	45	14E
0005435765661	13464	46	14G
0005435765659	13464	47	14F
0005435462352	13464	48	15A
0005435765449	13464	49	15B
0005435765364	13464	50	15E
0005432535826	13464	51	15D
0005435735109	13464	52	15F
0005433533260	13464	53	16E
0005435722024	13464	54	16F
0005434265085	13464	55	16H
0005435462337	13464	56	17A
0005433529217	13464	57	17D
0005433529211	13464	58	17B
0005435735077	13464	59	17F
0005435462370	13464	60	17E
0005435462355	13464	61	17G
0005432194502	13464	62	18A
0005435765657	13464	63	17H
0005435765645	13464	64	18B
0005434831142	13464	65	18E
0005435462359	13464	66	18D
0005433533248	13464	67	18F
0005433529226	13464	68	18G
0005435765644	13464	69	18H
0005434265093	13464	70	19B
0005435765573	13464	71	19F
0005433533251	13464	72	19E
0005435462345	13464	73	19G
0005435765470	13464	74	20A
0005434831143	13464	75	20B
0005434265083	13464	76	20D
0005433533274	13464	77	20F
0005435765410	13464	78	20E
0005432535823	13464	79	21A
0005433533275	13464	80	20H
0005435462372	13464	81	21D
0005433529221	13464	82	21B
0005435462366	13464	83	21E
0005435462341	13464	84	21F
0005435765520	13464	85	21G
0005435462339	13464	86	22B
0005435765638	13464	87	22D
0005435462349	13464	88	22E
0005435765319	13464	89	22H
0005435765515	13464	90	23A
0005435765519	13464	91	23D
0005434265075	13464	92	23B
0005434265084	13464	93	23H
0005435765348	13464	94	23F
0005435462348	13464	95	24A
0005435765601	13464	96	24B
0005435462354	13464	97	24E
0005435462353	13464	98	24D
0005435462371	13464	99	24F
0005435765516	13464	100	24H
0005434265077	13464	101	24G
0005435462346	13464	102	25D
0005435765595	13464	103	25E
0005435765567	13464	104	27D
0005435765422	13464	105	27F
0005435765320	13464	106	27E
0005433529212	13464	107	27H
0005435765616	13464	108	27G
0005435765423	13464	109	28A
0005434265074	13464	110	28E
0005435462374	13464	111	28F
0005433529220	13464	112	28G
0005435462365	13464	113	29A
0005435462350	13464	114	29B
0005434265086	13464	115	29E
0005434265091	13464	116	29G
0005435765572	13464	117	29F
0005435765444	13464	118	29H
0005435765562	13464	119	30B
0005434265081	13464	120	30A
0005434265076	13464	121	30D
0005435765483	13464	122	30F
0005433533253	13464	123	30E
0005433529222	13464	124	30G
0005433533261	13464	125	30H
0005434265090	13464	126	31B
0005434831139	13464	127	31A
0005435765560	13464	128	31D
0005435462357	13464	129	31F
0005435765660	13464	130	31G
0005434265094	13464	131	32A
0005435765514	13464	132	32D
0005435462369	13464	133	32F
0005435765482	13464	134	32G
0005435765596	13464	135	33A
0005433529227	13464	136	32H
0005435765617	13464	137	33D
0005433529214	13464	138	33B
0005435765443	13464	139	33H
0005435462367	13464	140	33G
0005434831140	13464	141	34B
0005435462358	13464	142	34A
0005435765466	13464	143	34F
0005434831141	13464	144	34E
0005435462363	13464	145	34G
0005433529219	13464	146	35A
0005432535825	13464	147	34H
0005435462340	13464	148	35D
0005435735074	13464	149	35F
0005433529218	13464	150	35G
0005435462347	13464	151	35H
0005432194500	13464	152	36B
0005435462356	13464	153	36D
0005435722029	13464	154	36F
0005435765232	13464	155	36E
0005433533254	13464	156	36H
0005434265098	13464	157	37A
0005435462343	13464	158	37B
0005434265097	13464	159	38A
0005434265095	13464	160	38B
0005435765397	13464	161	38E
0005435043285	13464	162	38D
0005435765213	13464	163	38F
0005435462362	13464	164	38G
0005435722012	13464	165	39E
0005435462342	13464	166	39D
0005434602871	18675	1	5A
0005434602870	18675	2	5B
0005434514960	18676	1	1A
0005434604843	18676	2	1B
0005434604859	18676	3	2A
0005434513571	18676	4	2B
0005434514961	18676	5	3A
0005434513573	18676	6	3B
0005434513572	18676	7	4A
0005434514959	18676	8	4B
0005434604849	18676	9	5A
0005434604850	18676	10	5B
0005434604844	18676	11	6A
0005434604863	18676	12	6B
0005434514939	19117	1	2A
0005434514943	19117	2	3A
0005434514937	19117	3	3B
0005434514938	19117	4	4B
0005434514950	19117	5	5A
0005435846211	4114	1	2C
0005432632731	4114	2	2F
0005432649388	4114	3	3C
0005435844282	4114	4	3D
0005435846212	4114	5	4F
0005432649392	4114	6	5C
0005432632729	4114	7	6D
0005435844267	4114	8	6E
0005432649386	4114	9	7A
0005432649385	4114	10	7C
0005432632725	4114	11	7E
0005432632730	4114	12	7F
0005432649394	4114	13	8D
0005435846192	4114	14	9C
0005435844263	4114	15	10A
0005432649389	4114	16	10D
0005432649391	4114	17	10F
0005432632724	4114	18	11A
0005435846202	4114	19	11D
0005435844273	4114	20	12A
0005432632732	4114	21	12E
0005432649387	4114	22	13D
0005435846221	4114	23	13F
0005432632722	4114	24	15A
0005432632721	4114	25	15C
0005432632720	4114	26	16A
0005435846219	4114	27	16C
0005435846210	4114	28	16F
0005432632728	4114	29	17A
0005432632723	4114	30	17E
0005432649384	4114	31	18A
0005432649383	4114	32	18C
0005432632727	4114	33	18D
0005435844272	4114	34	18F
0005435844268	4114	35	19A
0005432632726	4114	36	19C
0005432649390	4114	37	20C
0005432649393	4114	38	20F
0005433008061	1884	1	1A
0005433285004	1884	2	1C
0005433008125	1884	3	1D
0005433008128	1884	4	1F
0005433810537	1884	5	2C
0005433284820	1884	6	2D
0005433284994	1884	7	2F
0005433284978	1884	8	3A
0005433284906	1884	9	3D
0005433285107	1884	10	3F
0005433284957	1884	11	4A
0005433284931	1884	12	4C
0005432295873	1884	13	4D
0005433810536	1884	14	4E
0005433008235	1884	15	4F
0005433285069	1884	16	5A
0005433285034	1884	17	5C
0005433008274	1884	18	5E
0005433008185	1884	19	5F
0005433284995	1884	20	6D
0005433285109	1884	21	6E
0005433284879	1884	22	6F
0005433008060	1884	23	7A
0005432295874	1884	24	7C
0005433008039	1884	25	7D
0005433284907	1884	26	7E
0005433285051	1884	27	7F
0005433008258	1884	28	8A
0005433285005	1884	29	8C
0005433285118	1884	30	8D
0005433008209	1884	31	8E
0005433008108	1884	32	8F
0005433285050	1884	33	9C
0005433285021	1884	34	9D
0005433008225	1884	35	9E
0005433008169	1884	36	9F
0005433284996	1884	37	10A
0005433285027	1884	38	10C
0005433284963	1884	39	10D
0005433284902	1884	40	10E
0005433284976	1884	41	11A
0005433284929	1884	42	11C
0005433285059	1884	43	11D
0005433285006	1884	44	11E
0005433285108	1884	45	11F
0005433284977	1884	46	12A
0005433008240	1884	47	12C
0005433008229	1884	48	12D
0005433008230	1884	49	12E
0005433285002	1884	50	12F
0005433007962	1884	51	13A
0005433285009	1884	52	13D
0005433008228	1884	53	13E
0005433285161	1884	54	13F
0005433285162	1884	55	14A
0005433284986	1884	56	14C
0005433285022	1884	57	14D
0005433284916	1884	58	14E
0005433284899	1884	59	14F
0005433285073	1884	60	15A
0005433008259	1884	61	15C
0005433008182	1884	62	15D
0005433284893	1884	63	15E
0005433008170	1884	64	16A
0005433008359	1884	65	16D
0005433008025	1884	66	16E
0005433008126	1884	67	16F
0005433285001	1884	68	17A
0005433284962	1884	69	17C
0005433008168	1884	70	17D
0005433008226	1884	71	17E
0005433008227	1884	72	17F
0005433285017	1884	73	18A
0005433284838	1884	74	18C
0005433008110	1884	75	18D
0005433285137	1884	76	18E
0005433284932	1884	77	18F
0005433284979	1884	78	19A
0005433284886	1884	79	19C
0005433284942	1884	80	19D
0005433284964	1884	81	19E
0005433284918	1884	82	19F
0005433285013	1884	83	20C
0005433810535	1884	84	20D
0005433007961	1884	85	20F
0005433008505	22560	1	1A
0005433285221	22560	2	1C
0005433285211	22560	3	1D
0005433008499	22560	4	1F
0005433285219	22560	5	2A
0005433008485	22560	6	2D
0005433008501	22560	7	2F
0005433008476	22560	8	3A
0005433285217	22560	9	3C
0005433008504	22560	10	3F
0005433008516	22560	11	4A
0005433008473	22560	12	4C
0005433285203	22560	13	4D
0005433008509	22560	14	4E
0005433008513	22560	15	5A
0005433008483	22560	16	5C
0005433008510	22560	17	5F
0005433008475	22560	18	6A
0005433008492	22560	19	6C
0005433008493	22560	20	6D
0005433008479	22560	21	6E
0005433008500	22560	22	6F
0005433008490	22560	23	7D
0005433008502	22560	24	7E
0005433008497	22560	25	7F
0005433285226	22560	26	8A
0005433008482	22560	27	8C
0005433285227	22560	28	8E
0005433285216	22560	29	8F
0005433008494	22560	30	9C
0005433285199	22560	31	9D
0005433008474	22560	32	9E
0005433008498	22560	33	9F
0005433810491	22560	34	10A
0005433008491	22560	35	10C
0005433285207	22560	36	10D
0005433285214	22560	37	10F
0005433285212	22560	38	11C
0005433285231	22560	39	11D
0005433008486	22560	40	11E
0005433008507	22560	41	11F
0005433008488	22560	42	12A
0005433008481	22560	43	12C
0005433285205	22560	44	12D
0005433285228	22560	45	12E
0005433008489	22560	46	12F
0005433285210	22560	47	13A
0005433008512	22560	48	13C
0005433008517	22560	49	13D
0005433285230	22560	50	13F
0005433285215	22560	51	14A
0005433008478	22560	52	14C
0005433285223	22560	53	14D
0005433008487	22560	54	14E
0005433810492	22560	55	14F
0005433008503	22560	56	15A
0005433008514	22560	57	15C
0005433008495	22560	58	15D
0005433008484	22560	59	15F
0005433285200	22560	60	16A
0005433285209	22560	61	16C
0005433008477	22560	62	16D
0005433008472	22560	63	16E
0005433285202	22560	64	16F
0005433008515	22560	65	17A
0005433285218	22560	66	17C
0005433008511	22560	67	17D
0005433008506	22560	68	17F
0005433285229	22560	69	18A
0005433285220	22560	70	18C
0005433285201	22560	71	18D
0005433285206	22560	72	18E
0005433285222	22560	73	18F
0005433008480	22560	74	19A
0005433285208	22560	75	19C
0005433008496	22560	76	19E
0005433285225	22560	77	19F
0005433285204	22560	78	20C
0005433285213	22560	79	20D
0005433285224	22560	80	20E
0005433008508	22560	81	20F
0005433846602	5595	1	1A
0005433846580	5595	2	1F
0005433846572	5595	3	1D
0005433846569	5595	4	2C
0005433846614	5595	5	2A
0005433846599	5595	6	2D
0005435282276	5595	7	3A
0005435282267	5595	8	2F
0005435282191	5595	9	3D
0005433846613	5595	10	3C
0005433846592	5595	11	4A
0005435282210	5595	12	4D
0005433846608	5595	13	4C
0005435282266	5595	14	4F
0005433846584	5595	15	5C
0005433846579	5595	16	5A
0005433846586	5595	17	5F
0005433846576	5595	18	5D
0005433846604	5595	19	6A
0005433846574	5595	20	6C
0005433846588	5595	21	6E
0005433846566	5595	22	6D
0005432081493	5595	23	7A
0005433846596	5595	24	6F
0005433846570	5595	25	7C
0005433846607	5595	26	7B
0005435282264	5595	27	7E
0005433846587	5595	28	7D
0005433846575	5595	29	7F
0005433846565	5595	30	8B
0005433846598	5595	31	8A
0005435282250	5595	32	8E
0005434173460	5595	33	8D
0005435282356	5595	34	8C
0005433846595	5595	35	8F
0005434173466	5595	36	9B
0005433846561	5595	37	9A
0005435282182	5595	38	9D
0005433846573	5595	39	9C
0005435282249	5595	40	9E
0005433846606	5595	41	9F
0005432081496	5595	42	10C
0005433846615	5595	43	10B
0005433815372	5595	44	10E
0005433815370	5595	45	10D
0005434173461	5595	46	10F
0005433846593	5595	47	11C
0005433846578	5595	48	11B
0005433846611	5595	49	11A
0005435282183	5595	50	11D
0005435282234	5595	51	11F
0005433846617	5595	52	12B
0005432081494	5595	53	12A
0005433846564	5595	54	12C
0005433846605	5595	55	12F
0005435282223	5595	56	12E
0005433846594	5595	57	12D
0005433846585	5595	58	13A
0005433846567	5595	59	13C
0005433846571	5595	60	13B
0005433846618	5595	61	13E
0005435282263	5595	62	13D
0005433815373	5595	63	14A
0005435282190	5595	64	13F
0005433846563	5595	65	14B
0005435282354	5595	66	14D
0005433846616	5595	67	14C
0005435282148	5595	68	14F
0005432081495	5595	69	14E
0005433846560	5595	70	15B
0005435282151	5595	71	15A
0005435282209	5595	72	15D
0005433846590	5595	73	15C
0005435282212	5595	74	15F
0005434173474	5595	75	15E
0005433846577	5595	76	16A
0005435282224	5595	77	16C
0005435282222	5595	78	16B
0005432081498	5595	79	16E
0005433846583	5595	80	16D
0005435282386	5595	81	16F
0005435282244	5595	82	17B
0005433846603	5595	83	17C
0005435282219	5595	84	17F
0005433846562	5595	85	17E
0005435282220	5595	86	18B
0005433846581	5595	87	18A
0005435282194	5595	88	18C
0005433846568	5595	89	18D
0005435282243	5595	90	19A
0005433846582	5595	91	18F
0005433846597	5595	92	19C
0005435282120	5595	93	19B
0005433846601	5595	94	19D
0005432081497	5595	95	19F
0005433846610	5595	96	19E
0005433815371	5595	97	20B
0005435282179	5595	98	20A
0005433846600	5595	99	20D
0005433846609	5595	100	20E
0005434173465	5595	101	21B
0005433846612	5595	102	21A
0005433846589	5595	103	20F
0005435282195	5595	104	21D
0005433846591	5595	105	21C
0005435282355	5595	106	21E
0005435282221	5595	107	21F
0005435282454	13855	1	1C
0005433846102	13855	2	1A
0005433846164	13855	3	1D
0005433845941	13855	4	1F
0005432003694	13855	5	2D
0005435282469	13855	6	2C
0005435282459	13855	7	3A
0005433846060	13855	8	2F
0005434173512	13855	9	3C
0005433846133	13855	10	4A
0005433845862	13855	11	4C
0005433846052	13855	12	4F
0005433846123	13855	13	5C
0005435282464	13855	14	5A
0005433846153	13855	15	5D
0005435282472	13855	16	6B
0005433846163	13855	17	6A
0005433846009	13855	18	6D
0005435282475	13855	19	6C
0005433846234	13855	20	6E
0005435282467	13855	21	7A
0005433845942	13855	22	6F
0005435282462	13855	23	7D
0005433846092	13855	24	8A
0005433846200	13855	25	7F
0005433845921	13855	26	8B
0005433815335	13855	27	8D
0005433846104	13855	28	8C
0005433815328	13855	29	8F
0005433846131	13855	30	8E
0005433846125	13855	31	9B
0005433846112	13855	32	9A
0005435282470	13855	33	9D
0005432003695	13855	34	9C
0005433846208	13855	35	9E
0005433846238	13855	36	10B
0005433845955	13855	37	10A
0005433846288	13855	38	9F
0005435282450	13855	39	10C
0005435282453	13855	40	10D
0005433846086	13855	41	10F
0005433846198	13855	42	11B
0005433846337	13855	43	11A
0005435282460	13855	44	11D
0005433846258	13855	45	11C
0005433815333	13855	46	11F
0005435282452	13855	47	11E
0005433845991	13855	48	12B
0005433846467	13855	49	12A
0005435282466	13855	50	12D
0005435282474	13855	51	12C
0005433846255	13855	52	12F
0005433846043	13855	53	12E
0005433846345	13855	54	13B
0005433845848	13855	55	13A
0005433815336	13855	56	13C
0005433846121	13855	57	13E
0005433845977	13855	58	13D
0005433845939	13855	59	13F
0005435282451	13855	60	14A
0005433846132	13855	61	14D
0005435282477	13855	62	14C
0005433846134	13855	63	14F
0005433845937	13855	64	14E
0005433846019	13855	65	15B
0005432003693	13855	66	15A
0005435282465	13855	67	15D
0005435282449	13855	68	15C
0005435282463	13855	69	15F
0005435282455	13855	70	16A
0005435282468	13855	71	16B
0005433845980	13855	72	16E
0005433846172	13855	73	16D
0005433846020	13855	74	16C
0005433845875	13855	75	17B
0005434173513	13855	76	17A
0005433846199	13855	77	17D
0005433846143	13855	78	17C
0005433846051	13855	79	17F
0005435282476	13855	80	17E
0005433846129	13855	81	18A
0005433846122	13855	82	18C
0005433815334	13855	83	18B
0005433845863	13855	84	18E
0005433846256	13855	85	19A
0005433845963	13855	86	18F
0005433846183	13855	87	19D
0005435282458	13855	88	19C
0005435282473	13855	89	19F
0005435282457	13855	90	19E
0005433846030	13855	91	20B
0005433846111	13855	92	20A
0005434173511	13855	93	20F
0005435282471	13855	94	20E
0005434173510	13855	95	21A
0005433815327	13855	96	21C
0005433846130	13855	97	21B
0005435282456	13855	98	21E
0005435282461	13855	99	21D
0005433846207	13855	100	21F
0005434620539	7856	1	1A
0005434620542	7856	2	1B
0005434620553	7856	3	1D
0005434620557	7856	4	2A
0005434620555	7856	5	2D
0005434620551	7856	6	3A
0005435332236	7856	7	3B
0005435332192	7856	8	3C
0005434620552	7856	9	4A
0005434620548	7856	10	4B
0005434620543	7856	11	5A
0005435332233	7856	12	5B
0005434620545	7856	13	5D
0005434620554	7856	14	6A
0005434620549	7856	15	6C
0005432112511	7856	16	6D
0005434620547	7856	17	7A
0005434620540	7856	18	7B
0005434620541	7856	19	7C
0005435332261	7856	20	18A
0005434620556	7856	21	18B
0005434620550	7856	22	18C
0005432112512	7856	23	18D
0005432112510	7856	24	19A
0005435332248	7856	25	20A
0005435332220	7856	26	20B
0005434620544	7856	27	20D
0005434620538	7856	28	21A
0005435332237	7856	29	22C
0005435332219	7856	30	23A
0005434620546	7856	31	23B
0005435332310	32982	1	1C
0005434620298	32982	2	2B
0005434620410	32982	3	3A
0005434620443	32982	4	3B
0005434620353	32982	5	3D
0005434620309	32982	6	4A
0005435332309	32982	7	4B
0005434620382	32982	8	4D
0005435332308	32982	9	5A
0005435332315	32982	10	5C
0005434620383	32982	11	5D
0005434620308	32982	12	6D
0005434620377	32982	13	18A
0005434620417	32982	14	18B
0005435332314	32982	15	18C
0005434620354	32982	16	18D
0005434620356	32982	17	19A
0005435332311	32982	18	19B
0005435332307	32982	19	19D
0005434620375	32982	20	20B
0005434620387	32982	21	20D
0005435332312	32982	22	21A
0005434620413	32982	23	21B
0005434620359	32982	24	22A
0005434620316	32982	25	22B
0005434620412	32982	26	22D
0005435332313	32982	27	23A
0005435785275	4262	1	1C
0005434994001	4262	2	2A
0005435785268	4262	3	2C
0005435785273	4262	4	2F
0005435785288	4262	5	3A
0005435785284	4262	6	3C
0005435785277	4262	7	4A
0005434993999	4262	8	4D
0005434993998	4262	9	4E
0005435785276	4262	10	4F
0005435785265	4262	11	5A
0005435785290	4262	12	5D
0005435785286	4262	13	5E
0005435785280	4262	14	5F
0005434994004	4262	15	6A
0005435785259	4262	16	6C
0005432190621	4262	17	6D
0005435918596	4262	18	7A
0005435785266	4262	19	7C
0005435785272	4262	20	7E
0005435785270	4262	21	7F
0005432190620	4262	22	8A
0005435785264	4262	23	8D
0005435785282	4262	24	8F
0005435918609	4262	25	9A
0005435918604	4262	26	9C
0005435785262	4262	27	9D
0005435918622	4262	28	9E
0005434994002	4262	29	10A
0005435785283	4262	30	10C
0005435785285	4262	31	10D
0005435785271	4262	32	10F
0005435785291	4262	33	11A
0005434994000	4262	34	11C
0005435785293	4262	35	11F
0005434993997	4262	36	12C
0005432190619	4262	37	12D
0005435785274	4262	38	12F
0005434994005	4262	39	13A
0005435785278	4262	40	13C
0005435785279	4262	41	13D
0005435785263	4262	42	14A
0005435785269	4262	43	14C
0005435785292	4262	44	14F
0005435785267	4262	45	15D
0005435785261	4262	46	15E
0005435785289	4262	47	15F
0005435785260	4262	48	16A
0005435918608	4262	49	16C
0005435918615	4262	50	16E
0005434994003	4262	51	16F
0005435785281	4262	52	17A
0005435787349	4262	53	18C
0005435918626	4262	54	18D
0005435918595	4262	55	18F
0005432190623	4262	56	19C
0005435785287	4262	57	20D
0005432190622	4262	58	20F
0005435784988	27305	1	1A
0005435784898	27305	2	1D
0005435784973	27305	3	1F
0005435785004	27305	4	2C
0005435784891	27305	5	2D
0005435784784	27305	6	2F
0005432195687	27305	7	3A
0005435784960	27305	8	3C
0005435918642	27305	9	4A
0005435784802	27305	10	4C
0005435784936	27305	11	4D
0005434993963	27305	12	4F
0005435784872	27305	13	5A
0005435784880	27305	14	5C
0005434993960	27305	15	5D
0005435784950	27305	16	5E
0005434993898	27305	17	5F
0005435784971	27305	18	6A
0005435785028	27305	19	6C
0005435784845	27305	20	6D
0005435918644	27305	21	6E
0005435784897	27305	22	6F
0005435784857	27305	23	7C
0005435784908	27305	24	7D
0005435784987	27305	25	7E
0005435784893	27305	26	7F
0005434993914	27305	27	8A
0005435784933	27305	28	8E
0005435784803	27305	29	8F
0005435784921	27305	30	9A
0005435784846	27305	31	9F
0005435784953	27305	32	10F
0005434993933	27305	33	11A
0005435784954	27305	34	11D
0005435785000	27305	35	11F
0005434993962	27305	36	12A
0005432195686	27305	37	12F
0005434993930	27305	38	13A
0005435784947	27305	39	13C
0005435784907	27305	40	13D
0005434993959	27305	41	13E
0005435784816	27305	42	13F
0005435784972	27305	43	14A
0005435785097	27305	44	14E
0005435784983	27305	45	15A
0005435784896	27305	46	15D
0005435784913	27305	47	15F
0005435918646	27305	48	16A
0005435784969	27305	49	16C
0005434993961	27305	50	16E
0005435784932	27305	51	16F
0005434993964	27305	52	17A
0005435785032	27305	53	17C
0005435784924	27305	54	17D
0005435784894	27305	55	17E
0005435784804	27305	56	18A
0005435784948	27305	57	18C
0005435784968	27305	58	19A
0005435918645	27305	59	19C
0005435784854	27305	60	19E
0005435784906	27305	61	19F
0005435918643	27305	62	20A
0005434993892	27305	63	20C
0005435784881	27305	64	20D
0005435784909	27305	65	20F
0005432146193	19846	1	7D
0005432146194	19846	2	19B
0005432146192	19846	3	22A
0005434081840	4742	1	1B
0005432170373	4742	2	1C
0005434081852	4742	3	1G
0005432567473	4742	4	2A
0005432567508	4742	5	1H
0005432567472	4742	6	2C
0005432459757	4742	7	2F
0005432567497	4742	8	2G
0005434081851	4742	9	3A
0005434081845	4742	10	3B
0005432459745	4742	11	3C
0005432459715	4742	12	3G
0005434081853	4742	13	3F
0005432567471	4742	14	4A
0005432186860	4742	15	3H
0005432459719	4742	16	4B
0005432459746	4742	17	4C
0005432567501	4742	18	4G
0005432567509	4742	19	5B
0005432459744	4742	20	5C
0005432459743	4742	21	5H
0005432459748	4742	22	9B
0005432567488	4742	23	9A
0005432567523	4742	24	9H
0005434081847	4742	25	9G
0005432567506	4742	26	11A
0005432567490	4742	27	11E
0005432567524	4742	28	11F
0005432571313	4742	29	11G
0005432567479	4742	30	12A
0005432459751	4742	31	12B
0005432567507	4742	32	12F
0005432567465	4742	33	12H
0005434081844	4742	34	13A
0005432567516	4742	35	13B
0005432567496	4742	36	13F
0005432567486	4742	37	13E
0005434081858	4742	38	13D
0005433726100	4742	39	13G
0005432459734	4742	40	13H
0005432186862	4742	41	14B
0005434081849	4742	42	14D
0005432567518	4742	43	15A
0005432567470	4742	44	14H
0005432459756	4742	45	15D
0005434081843	4742	46	15F
0005432567489	4742	47	15H
0005433726099	4742	48	15G
0005432459710	4742	49	16E
0005432459716	4742	50	16D
0005432567519	4742	51	16F
0005432459726	4742	52	16G
0005432567514	4742	53	17B
0005432459754	4742	54	17D
0005432567510	4742	55	17E
0005432567498	4742	56	17H
0005432567525	4742	57	18B
0005432459732	4742	58	18A
0005432567504	4742	59	18E
0005432567468	4742	60	18D
0005434081838	4742	61	18F
0005432571314	4742	62	18H
0005434081857	4742	63	19B
0005432567511	4742	64	19E
0005432459723	4742	65	19D
0005432567478	4742	66	19F
0005432567477	4742	67	19H
0005432567521	4742	68	20D
0005432567517	4742	69	20B
0005432459712	4742	70	21B
0005432459727	4742	71	21A
0005432459737	4742	72	21D
0005432567466	4742	73	21E
0005432459729	4742	74	21H
0005432459749	4742	75	21G
0005432567494	4742	76	22B
0005432459731	4742	77	22D
0005432170371	4742	78	22H
0005432459717	4742	79	23A
0005433452735	4742	80	23D
0005432459720	4742	81	23F
0005432459704	4742	82	23G
0005432567480	4742	83	24A
0005432567469	4742	84	23H
0005432567520	4742	85	24B
0005432459753	4742	86	24D
0005432459718	4742	87	24F
0005432567474	4742	88	24H
0005434081841	4742	89	25D
0005432459735	4742	90	27A
0005432567484	4742	91	25F
0005432571312	4742	92	27B
0005432459705	4742	93	27E
0005432567500	4742	94	27D
0005432170372	4742	95	27H
0005434081837	4742	96	27G
0005432459707	4742	97	28E
0005432567522	4742	98	28G
0005432459706	4742	99	29A
0005432459739	4742	100	29E
0005432567482	4742	101	29G
0005432567495	4742	102	29F
0005434081855	4742	103	30A
0005432567483	4742	104	29H
0005434081850	4742	105	30B
0005432459752	4742	106	30D
0005432170374	4742	107	30F
0005432571315	4742	108	30G
0005432567487	4742	109	31B
0005432459750	4742	110	31A
0005432459713	4742	111	31D
0005432567464	4742	112	31F
0005432459714	4742	113	31E
0005432186861	4742	114	31G
0005432567515	4742	115	32A
0005432459742	4742	116	31H
0005432459722	4742	117	32B
0005432567505	4742	118	32E
0005432567485	4742	119	32H
0005432459721	4742	120	32G
0005432459711	4742	121	33A
0005434081848	4742	122	33B
0005432567492	4742	123	33E
0005432459740	4742	124	33D
0005432567502	4742	125	33F
0005434081854	4742	126	33G
0005434081856	4742	127	34A
0005432567491	4742	128	34D
0005432459725	4742	129	34B
0005432459728	4742	130	34G
0005432567503	4742	131	34F
0005432459738	4742	132	34H
0005432459747	4742	133	35A
0005434081842	4742	134	35E
0005432567512	4742	135	35D
0005432567475	4742	136	35F
0005432567493	4742	137	35G
0005432459724	4742	138	36A
0005432459755	4742	139	35H
0005432567499	4742	140	36D
0005432459709	4742	141	36F
0005433726098	4742	142	36E
0005432459736	4742	143	36H
0005432567467	4742	144	36G
0005432459733	4742	145	37B
0005432186863	4742	146	37E
0005432170370	4742	147	37H
0005432567481	4742	148	37G
0005432567476	4742	149	38B
0005434081846	4742	150	38E
0005432459730	4742	151	38D
0005432459741	4742	152	38H
0005434081839	4742	153	38G
0005432567513	4742	154	39E
0005432459708	4742	155	39D
0005432567095	30563	1	1A
0005432571283	30563	2	1B
0005432567061	30563	3	1F
0005432459260	30563	4	1H
0005432566784	30563	5	1G
0005432161148	30563	6	2A
0005432566998	30563	7	2B
0005432567015	30563	8	2F
0005432459404	30563	9	2C
0005432566921	30563	10	2H
0005432566997	30563	11	2G
0005432459304	30563	12	3A
0005432459405	30563	13	3B
0005432566891	30563	14	3C
0005432567158	30563	15	3G
0005434081746	30563	16	3H
0005434081720	30563	17	4C
0005432566859	30563	18	4G
0005432571270	30563	19	4H
0005432459472	30563	20	5C
0005432459136	30563	21	5G
0005434081647	30563	22	5F
0005434081721	30563	23	9A
0005432459301	30563	24	9B
0005433454858	30563	25	9G
0005432567194	30563	26	11A
0005432566924	30563	27	11B
0005432571271	30563	28	11F
0005434081634	30563	29	11H
0005432459362	30563	30	12A
0005432567077	30563	31	12B
0005432459425	30563	32	12E
0005433452715	30563	33	12H
0005432459149	30563	34	12G
0005432459180	30563	35	13A
0005432566894	30563	36	13D
0005434081646	30563	37	13F
0005432459434	30563	38	13E
0005432459358	30563	39	13H
0005432459174	30563	40	14B
0005432567160	30563	41	14E
0005434081567	30563	42	14D
0005434081650	30563	43	14F
0005432459230	30563	44	14H
0005432459342	30563	45	15A
0005432567149	30563	46	15D
0005432567232	30563	47	15G
0005432161147	30563	48	15F
0005432459242	30563	49	16A
0005432459408	30563	50	16D
0005432566817	30563	51	16B
0005432566789	30563	52	16E
0005432567000	30563	53	16F
0005432567058	30563	54	16H
0005432459588	30563	55	17A
0005432567045	30563	56	17D
0005432459430	30563	57	17B
0005432567120	30563	58	17E
0005432459431	30563	59	17G
0005432459467	30563	60	17F
0005434081633	30563	61	18A
0005434081620	30563	62	17H
0005432566932	30563	63	18B
0005432567161	30563	64	18E
0005432459272	30563	65	18D
0005432459352	30563	66	18H
0005432459322	30563	67	18G
0005432566980	30563	68	18F
0005432567057	30563	69	19A
0005432571288	30563	70	19D
0005432567336	30563	71	19B
0005434081599	30563	72	19F
0005432566918	30563	73	19G
0005432567014	30563	74	20A
0005432567143	30563	75	20B
0005432459143	30563	76	20F
0005434081566	30563	77	20E
0005432459353	30563	78	20H
0005432567086	30563	79	20G
0005432567078	30563	80	21A
0005432459175	30563	81	21D
0005432566923	30563	82	21B
0005434081621	30563	83	21G
0005432459538	30563	84	21H
0005432459369	30563	85	22B
0005432566827	30563	86	22A
0005434081747	30563	87	22D
0005432213599	30563	88	22F
0005434081661	30563	89	22G
0005432566933	30563	90	23B
0005432459473	30563	91	23A
0005432566818	30563	92	23F
0005432567069	30563	93	23E
0005432459225	30563	94	24E
0005432567206	30563	95	24D
0005432459281	30563	96	24G
0005432567027	30563	97	25D
0005434081612	30563	98	25E
0005432566934	30563	99	25F
0005434081562	30563	100	27B
0005432567230	30563	101	27E
0005432566653	30563	102	27D
0005432566919	30563	103	27F
0005432459330	30563	104	27G
0005432566964	30563	105	28A
0005432459586	30563	106	27H
0005432161146	30563	107	28D
0005432566738	30563	108	28F
0005432566892	30563	109	28E
0005432459148	30563	110	28H
0005434081496	30563	111	28G
0005434081662	30563	112	29B
0005432459218	30563	113	29A
0005434081568	30563	114	29E
0005432459259	30563	115	29D
0005432567070	30563	116	29G
0005434081641	30563	117	29F
0005432566977	30563	118	30A
0005432459302	30563	119	30B
0005434081663	30563	120	30F
0005432459459	30563	121	30E
0005432459570	30563	122	30G
0005432567207	30563	123	30H
0005434081651	30563	124	31B
0005432567025	30563	125	31E
0005432459569	30563	126	31G
0005432567193	30563	127	31F
0005432459255	30563	128	32A
0005432567249	30563	129	32B
0005432567335	30563	130	32E
0005432459176	30563	131	32D
0005432459359	30563	132	32H
0005432566737	30563	133	32G
0005432459167	30563	134	33A
0005432459303	30563	135	33E
0005432566639	30563	136	33F
0005432459327	30563	137	34B
0005432459221	30563	138	34A
0005432213598	30563	139	34D
0005432459587	30563	140	34F
0005434081613	30563	141	34E
0005432459137	30563	142	34G
0005432567125	30563	143	35A
0005432571290	30563	144	35D
0005432459506	30563	145	35F
0005434081691	30563	146	36A
0005432566979	30563	147	35H
0005432459220	30563	148	36B
0005432213597	30563	149	36E
0005432566863	30563	150	36D
0005432459062	30563	151	36G
0005432567085	30563	152	37A
0005432567198	30563	153	36H
0005432459273	30563	154	37D
0005432459367	30563	155	37B
0005432459247	30563	156	37E
0005432566920	30563	157	37F
0005432459300	30563	158	37G
0005432567021	30563	159	38A
0005434081563	30563	160	38D
0005432459222	30563	161	38B
0005432567142	30563	162	38E
0005434081614	30563	163	38F
0005432459043	30563	164	38H
0005432459537	30563	165	39D
0005432567121	30563	166	39F
0005435722050	13573	1	2B
0005435720821	13573	2	3B
0005435720820	13573	3	4A
0005435722049	13573	4	4B
0005435722028	21179	1	1B
0005435722023	21179	2	5B
0005435722027	21179	3	6B
0005432295873	22769	1	2B
0005432295874	22769	2	21C
0005433342940	11121	1	1A
0005433342967	11121	2	1C
0005433342997	11121	3	2A
0005433342937	11121	4	1F
0005435097175	11121	5	2C
0005433342953	11121	6	2D
0005433342963	11121	7	3A
0005433342915	11121	8	2F
0005433342928	11121	9	3C
0005433342944	11121	10	4A
0005433342976	11121	11	3F
0005435508296	11121	12	3D
0005433342975	11121	13	4C
0005433342938	11121	14	4B
0005433342973	11121	15	4D
0005433342995	11121	16	4E
0005433343008	11121	17	4F
0005433342946	11121	18	5A
0005435508229	11121	19	5B
0005433342977	11121	20	5D
0005433342914	11121	21	5C
0005433342991	11121	22	5E
0005433342923	11121	23	5F
0005433342948	11121	24	6A
0005433342994	11121	25	6C
0005435097174	11121	26	6B
0005433342956	11121	27	6D
0005435097179	11121	28	6F
0005433342981	11121	29	6E
0005435508290	11121	30	7A
0005433342985	11121	31	7B
0005435508214	11121	32	7C
0005435508291	11121	33	7D
0005433342941	11121	34	7E
0005435097177	11121	35	8A
0005435508273	11121	36	7F
0005433342945	11121	37	8B
0005433342924	11121	38	8C
0005433342943	11121	39	8D
0005435380239	11121	40	8E
0005433342908	11121	41	9A
0005433342999	11121	42	8F
0005435097180	11121	43	9B
0005433342929	11121	44	9D
0005433342962	11121	45	9C
0005435097176	11121	46	9E
0005433342926	11121	47	9F
0005433342960	11121	48	10B
0005435097178	11121	49	10C
0005435097172	11121	50	10D
0005433342986	11121	51	10E
0005433342950	11121	52	11B
0005433342958	11121	53	11D
0005433342988	11121	54	11C
0005435380256	11121	55	11E
0005433343007	11121	56	11F
0005433342979	11121	57	12A
0005433342951	11121	58	12C
0005433342998	11121	59	12B
0005433342911	11121	60	12D
0005433342947	11121	61	12E
0005433342990	11121	62	12F
0005435508213	11121	63	13A
0005433342972	11121	64	13B
0005433342912	11121	65	13C
0005433342932	11121	66	13E
0005433342961	11121	67	13D
0005435508234	11121	68	13F
0005433342909	11121	69	14A
0005433342920	11121	70	14B
0005433342974	11121	71	14D
0005433342918	11121	72	14C
0005433342913	11121	73	14E
0005433342942	11121	74	14F
0005433342933	11121	75	15B
0005433342917	11121	76	15A
0005433342957	11121	77	15C
0005435508255	11121	78	15D
0005433342939	11121	79	15F
0005435508269	11121	80	15E
0005433342934	11121	81	16A
0005433342964	11121	82	16B
0005433342927	11121	83	16C
0005433343000	11121	84	16D
0005435508240	11121	85	16F
0005433342993	11121	86	16E
0005433342959	11121	87	17B
0005435508268	11121	88	17A
0005433342996	11121	89	17C
0005433342989	11121	90	17D
0005433342916	11121	91	17F
0005433342965	11121	92	17E
0005433342931	11121	93	18A
0005433342982	11121	94	18B
0005433342954	11121	95	18C
0005433342987	11121	96	18E
0005433342968	11121	97	18D
0005433342966	11121	98	18F
0005433343001	11121	99	19A
0005433342969	11121	100	19B
0005433342919	11121	101	19D
0005433342978	11121	102	19C
0005433342935	11121	103	19E
0005433343004	11121	104	19F
0005433342949	11121	105	20B
0005435380255	11121	106	20A
0005433342952	11121	107	20C
0005433342936	11121	108	20D
0005433342970	11121	109	20E
0005433342980	11121	110	20F
0005433342930	11121	111	21A
0005433342971	11121	112	21B
0005433342910	11121	113	21C
0005433342984	11121	114	21F
0005433342922	11121	115	21E
0005433342955	11121	116	22B
0005435508254	11121	117	22A
0005433342921	11121	118	22C
0005433343005	11121	119	22D
0005433343003	11121	120	22F
0005433342925	11121	121	22E
0005435097173	11121	122	23A
0005433343006	11121	123	23B
0005433342992	11121	124	23C
0005433342983	11121	125	23D
0005435508241	11121	126	23F
0005433343002	11121	127	23E
0005433341774	17137	1	1A
0005433341814	17137	2	1C
0005435097046	17137	3	1D
0005433341994	17137	4	1F
0005433341962	17137	5	2C
0005433341943	17137	6	2A
0005433342248	17137	7	2D
0005433342271	17137	8	2F
0005433341891	17137	9	3A
0005433342049	17137	10	3D
0005433342048	17137	11	3C
0005433342236	17137	12	3F
0005433341859	17137	13	4B
0005433342100	17137	14	4A
0005433341792	17137	15	4C
0005433341990	17137	16	4D
0005433341904	17137	17	4E
0005433341791	17137	18	4F
0005433341627	17137	19	5A
0005433342078	17137	20	5C
0005433342065	17137	21	5B
0005433341629	17137	22	5D
0005433342383	17137	23	5F
0005433342130	17137	24	5E
0005433341977	17137	25	6A
0005433342028	17137	26	6B
0005433342141	17137	27	6C
0005433342110	17137	28	6D
0005433341756	17137	29	6F
0005433341876	17137	30	6E
0005433341964	17137	31	7A
0005433342087	17137	32	7B
0005433341958	17137	33	7C
0005432293202	17137	34	7D
0005433342073	17137	35	7F
0005433342086	17137	36	7E
0005433341993	17137	37	8A
0005433342033	17137	38	8B
0005433342159	17137	39	8C
0005433341982	17137	40	8E
0005433341892	17137	41	8D
0005435097108	17137	42	8F
0005433341957	17137	43	9A
0005433341721	17137	44	9B
0005433341877	17137	45	9C
0005435097075	17137	46	9D
0005435097047	17137	47	9F
0005433341896	17137	48	9E
0005433341975	17137	49	10B
0005433341828	17137	50	10D
0005433341749	17137	51	10C
0005433342020	17137	52	10E
0005433341976	17137	53	11A
0005433341869	17137	54	11C
0005433342040	17137	55	11B
0005435097076	17137	56	11D
0005433342042	17137	57	11F
0005433342131	17137	58	11E
0005433342041	17137	59	12A
0005433342060	17137	60	12B
0005433341832	17137	61	12D
0005433341929	17137	62	12C
0005433342185	17137	63	12E
0005433341860	17137	64	13A
0005433341811	17137	65	12F
0005433341895	17137	66	13C
0005433342035	17137	67	13E
0005433342032	17137	68	13D
0005433341905	17137	69	13F
0005433341460	17137	70	14B
0005433341967	17137	71	14A
0005433341858	17137	72	14C
0005433342025	17137	73	14D
0005433341787	17137	74	14E
0005433342245	17137	75	14F
0005433342353	17137	76	15B
0005433341643	17137	77	15A
0005433342334	17137	78	15D
0005433341776	17137	79	15C
0005433342195	17137	80	15E
0005435097103	17137	81	15F
0005432293204	17137	82	16B
0005433342067	17137	83	16D
0005432293203	17137	84	16C
0005433341628	17137	85	16F
0005433342214	17137	86	16E
0005433341850	17137	87	17A
0005433341793	17137	88	17B
0005433341959	17137	89	17C
0005435097104	17137	90	17D
0005433342052	17137	91	17F
0005433341558	17137	92	17E
0005433342129	17137	93	18A
0005433341880	17137	94	18B
0005433341961	17137	95	18D
0005433341518	17137	96	18C
0005433342384	17137	97	18F
0005433341997	17137	98	18E
0005433341991	17137	99	19B
0005433341866	17137	100	19A
0005433341827	17137	101	19C
0005433341773	17137	102	19D
0005433342244	17137	103	19F
0005435097101	17137	104	19E
0005433342066	17137	105	20A
0005433342034	17137	106	20C
0005433342150	17137	107	20B
0005433342115	17137	108	20D
0005433342280	17137	109	20E
0005433341915	17137	110	21A
0005433341863	17137	111	20F
0005433341401	17137	112	21C
0005433341833	17137	113	21B
0005433341901	17137	114	21D
0005433341996	17137	115	21E
0005435097069	17137	116	21F
0005433341989	17137	117	22A
0005433341851	17137	118	22C
0005433341968	17137	119	22B
0005435097102	17137	120	22D
0005433342061	17137	121	22E
0005433342499	17137	122	22F
0005433341796	17137	123	23B
0005433342199	17137	124	23A
0005433342249	17137	125	23C
0005433341890	17137	126	23E
0005433341897	17137	127	23D
0005433341963	17137	128	23F
0005432919597	9100	1	1C
0005432919660	9100	2	1D
0005432919558	9100	3	1F
0005433507145	9100	4	2C
0005432919635	9100	5	2D
0005432919598	9100	6	2F
0005433507141	9100	7	3A
0005433481151	9100	8	3C
0005432919689	9100	9	4C
0005433481149	9100	10	4E
0005433507144	9100	11	4F
0005432919610	9100	12	5A
0005432919681	9100	13	5C
0005432919679	9100	14	5D
0005433481147	9100	15	5E
0005432919599	9100	16	6A
0005432919559	9100	17	6C
0005432919612	9100	18	6D
0005433507147	9100	19	7C
0005432919581	9100	20	7E
0005432919626	9100	21	7F
0005432919611	9100	22	8E
0005432919640	9100	23	9C
0005433507146	9100	24	9E
0005433507142	9100	25	10A
0005433507152	9100	26	10D
0005432919604	9100	27	10F
0005432919678	9100	28	11D
0005432919582	9100	29	11F
0005432919580	9100	30	12A
0005433507155	9100	31	12C
0005433481154	9100	32	12D
0005432919634	9100	33	13A
0005433481150	9100	34	14C
0005433507143	9100	35	14D
0005433507156	9100	36	14E
0005432919685	9100	37	14F
0005432919560	9100	38	15C
0005433507149	9100	39	15D
0005433507154	9100	40	15F
0005432919639	9100	41	16C
0005432919718	9100	42	16F
0005433507150	9100	43	17A
0005432919627	9100	44	17C
0005433481148	9100	45	17D
0005432919579	9100	46	17F
0005433507153	9100	47	18C
0005432919636	9100	48	18E
0005432919680	9100	49	18F
0005433507148	9100	50	19C
0005433507151	9100	51	19F
0005433481152	9100	52	20A
0005432919705	9100	53	20C
0005433481153	9100	54	20E
0005432919575	9100	55	20F
0005432919841	20458	1	1A
0005432919836	20458	2	1C
0005433481080	20458	3	1F
0005432919826	20458	4	2A
0005433481103	20458	5	2D
0005433506987	20458	6	2F
0005433506999	20458	7	3D
0005432919835	20458	8	3F
0005433506961	20458	9	4A
0005433506985	20458	10	4F
0005433506962	20458	11	5A
0005433481089	20458	12	5C
0005433506980	20458	13	5E
0005433507022	20458	14	5F
0005433506991	20458	15	6C
0005432919842	20458	16	6F
0005433481082	20458	17	7D
0005433481090	20458	18	7F
0005433481079	20458	19	8D
0005432919839	20458	20	8E
0005433506953	20458	21	8F
0005433507021	20458	22	9F
0005432919833	20458	23	11A
0005432919844	20458	24	11D
0005433506924	20458	25	11E
0005433481056	20458	26	12A
0005433506923	20458	27	12E
0005433481096	20458	28	12F
0005433481102	20458	29	13D
0005432919837	20458	30	13F
0005432919828	20458	31	14A
0005433506983	20458	32	14F
0005432919825	20458	33	14E
0005432919832	20458	34	15A
0005433506986	20458	35	15D
0005432919831	20458	36	15E
0005432919834	20458	37	15F
0005433507000	20458	38	16D
0005432919843	20458	39	16F
0005433481092	20458	40	17A
0005432919829	20458	41	17E
0005433506984	20458	42	18C
0005432919830	20458	43	18E
0005433506952	20458	44	18F
0005432919827	20458	45	19A
0005433506939	20458	46	19C
0005433481057	20458	47	19E
0005432919838	20458	48	19F
0005432919824	20458	49	20A
0005432919840	20458	50	20E
0005432396232	10181	1	1A
0005432394092	10181	2	1B
0005432394090	10181	3	2A
0005432394091	10181	4	3B
0005432396229	10181	5	3A
0005432396231	10181	6	4A
0005432394093	10181	7	5A
0005432396230	10181	8	6A
0005432400074	18356	1	1A
0005432396192	18356	2	1B
0005432396220	18356	3	2A
0005432396194	18356	4	2B
0005432396198	18356	5	4A
0005432400068	18356	6	4B
0005432396195	18356	7	5B
0005432400067	18356	8	5A
0005432400073	18356	9	6B
0005434411769	10974	1	1C
0005435554127	10974	2	1D
0005435125769	10974	3	1F
0005435125872	10974	4	2A
0005435125947	10974	5	2D
0005435625970	10974	6	3C
0005435125927	10974	7	3D
0005435125730	10974	8	3F
0005435125797	10974	9	4C
0005435625933	10974	10	4D
0005435125732	10974	11	4E
0005435125815	10974	12	4F
0005435126006	10974	13	5C
0005435554132	10974	14	5D
0005435625925	10974	15	5E
0005434928294	10974	16	5F
0005434928292	10974	17	6C
0005435125731	10974	18	6D
0005434928293	10974	19	6E
0005435625932	10974	20	6F
0005435125755	10974	21	7C
0005435625934	10974	22	7D
0005435125823	10974	23	7E
0005435126077	10974	24	7F
0005435126034	10974	25	8A
0005435625944	10974	26	8C
0005435125901	10974	27	8D
0005435125930	10974	28	8E
0005435125862	10974	29	8F
0005435125780	10974	30	9A
0005434411770	10974	31	9C
0005435625907	10974	32	9E
0005435125878	10974	33	9D
0005435125957	10974	34	9F
0005435625906	10974	35	10C
0005435125822	10974	36	10D
0005435125958	10974	37	10E
0005435625947	10974	38	10F
0005435625942	10974	39	11A
0005435125810	10974	40	11C
0005435126033	10974	41	11F
0005435554128	10974	42	12A
0005434411768	10974	43	12C
0005434411771	10974	44	12D
0005435554141	10974	45	12E
0005435125811	10974	46	12F
0005435554143	10974	47	13A
0005435126004	10974	48	13C
0005435125921	10974	49	13D
0005435125874	10974	50	13E
0005435125904	10974	51	14A
0005435125973	10974	52	13F
0005435625913	10974	53	14C
0005435125832	10974	54	14D
0005435125703	10974	55	14E
0005435625964	10974	56	14F
0005435125938	10974	57	15A
0005435125900	10974	58	15C
0005435125786	10974	59	15D
0005435126076	10974	60	15E
0005435125959	10974	61	15F
0005435625961	10974	62	16A
0005435125779	10974	63	16D
0005435125843	10974	64	16E
0005435126005	10974	65	16F
0005435625943	10974	66	17A
0005435625931	10974	67	17C
0005435554138	10974	68	17D
0005435554142	10974	69	17F
0005435625948	10974	70	18A
0005435125745	10974	71	18C
0005435126042	10974	72	18D
0005435125791	10974	73	19A
0005435125972	10974	74	19C
0005435125873	10974	75	19D
0005435125871	10974	76	19E
0005435625969	10974	77	20A
0005435126007	10974	78	20D
0005435125992	10974	79	20E
0005435125861	10974	80	20F
0005435126282	14769	1	1A
0005435126273	14769	2	1D
0005435126275	14769	3	1F
0005435126272	14769	4	2A
0005435554173	14769	5	2C
0005435126296	14769	6	2F
0005435126277	14769	7	3A
0005435126306	14769	8	3C
0005435126278	14769	9	4A
0005435626144	14769	10	4C
0005435126307	14769	11	4E
0005435126285	14769	12	4F
0005435126292	14769	13	5C
0005435126291	14769	14	5E
0005435126301	14769	15	6A
0005435626142	14769	16	6C
0005435556686	14769	17	6D
0005435126294	14769	18	6F
0005435126304	14769	19	7C
0005434411724	14769	20	7D
0005435126305	14769	21	7E
0005434411719	14769	22	7F
0005435554176	14769	23	8D
0005435556687	14769	24	9A
0005434411720	14769	25	9C
0005435554174	14769	26	9F
0005435126274	14769	27	10A
0005435126279	14769	28	10C
0005434411721	14769	29	10E
0005435126295	14769	30	11C
0005435626138	14769	31	11E
0005434411707	14769	32	11F
0005435126281	14769	33	12A
0005435126308	14769	34	12C
0005435554175	14769	35	12E
0005435126313	14769	36	12F
0005435126309	14769	37	13E
0005435126283	14769	38	13F
0005435126310	14769	39	14C
0005435626143	14769	40	14D
0005435126311	14769	41	14E
0005435126297	14769	42	14F
0005435126288	14769	43	15A
0005435626139	14769	44	15C
0005435126303	14769	45	15D
0005435126302	14769	46	16A
0005435126289	14769	47	16C
0005435126276	14769	48	16D
0005435126298	14769	49	16E
0005435626140	14769	50	17D
0005435126290	14769	51	17E
0005435126312	14769	52	17F
0005435126280	14769	53	18A
0005435126293	14769	54	18C
0005435126284	14769	55	18E
0005435126287	14769	56	19A
0005435126286	14769	57	19D
0005435626141	14769	58	19E
0005435126300	14769	59	19F
0005435126299	14769	60	20A
0005435715430	7110	1	1D
0005435715436	7110	2	1F
0005435216561	7110	3	2C
0005435443214	7110	4	3A
0005435221043	7110	5	3C
0005435715427	7110	6	3F
0005432400115	7110	7	4E
0005432398190	7110	8	4F
0005432400117	7110	9	5A
0005435219166	7110	10	5E
0005432398188	7110	11	6A
0005435178477	7110	12	6D
0005435715431	7110	13	6F
0005432400116	7110	14	7A
0005435221041	7110	15	7D
0005435443185	7110	16	7F
0005435715429	7110	17	8D
0005435715438	7110	18	8E
0005435715426	7110	19	8F
0005435179386	7110	20	9A
0005435443213	7110	21	9D
0005435715424	7110	22	9E
0005435715434	7110	23	10C
0005435715439	7110	24	10F
0005435443209	7110	25	11A
0005435443207	7110	26	11C
0005432398191	7110	27	13E
0005435715435	7110	28	14E
0005435443182	7110	29	15A
0005432398189	7110	30	15E
0005432400114	7110	31	16A
0005435715433	7110	32	16E
0005435443208	7110	33	17C
0005435715440	7110	34	17D
0005435219170	7110	35	17E
0005435221042	7110	36	17F
0005435715437	7110	37	18C
0005435715423	7110	38	19A
0005435179385	7110	39	19C
0005435715432	7110	40	19E
0005435216562	7110	41	19F
0005435715428	7110	42	20A
0005435715425	7110	43	20D
0005435217705	27064	1	1C
0005435715295	27064	2	1D
0005435217701	27064	3	1F
0005432394063	27064	4	2A
0005435218111	27064	5	2C
0005435217700	27064	6	2D
0005435715321	27064	7	3D
0005435715261	27064	8	3F
0005435217703	27064	9	4C
0005435216577	27064	10	4D
0005435216578	27064	11	4E
0005435217707	27064	12	4F
0005435216582	27064	13	5A
0005435218110	27064	14	5C
0005435715319	27064	15	5D
0005435715327	27064	16	5E
0005432394038	27064	17	6A
0005435443293	27064	18	6C
0005432394062	27064	19	6D
0005435715217	27064	20	6E
0005435715297	27064	21	6F
0005432398148	27064	22	7D
0005435218112	27064	23	7E
0005435178491	27064	24	8A
0005432394064	27064	25	8C
0005435217704	27064	26	8D
0005435443296	27064	27	8F
0005435216583	27064	28	9A
0005435715320	27064	29	9D
0005435715227	27064	30	10A
0005435216576	27064	31	10C
0005435443290	27064	32	11C
0005435443295	27064	33	11D
0005435443291	27064	34	11F
0005435715362	27064	35	12A
0005435715229	27064	36	12C
0005435443292	27064	37	12D
0005432398147	27064	38	13A
0005435715304	27064	39	13D
0005435715296	27064	40	13F
0005432394051	27064	41	14C
0005435715266	27064	42	14D
0005435217706	27064	43	14E
0005435443298	27064	44	14F
0005435216580	27064	45	15A
0005435216581	27064	46	15C
0005435217702	27064	47	16C
0005435178492	27064	48	16D
0005435443297	27064	49	16E
0005432394052	27064	50	17C
0005432394037	27064	51	17D
0005435715275	27064	52	18C
0005435216584	27064	53	18D
0005435217708	27064	54	18F
0005435715265	27064	55	19A
0005435443294	27064	56	19C
0005435715276	27064	57	19D
0005435715326	27064	58	20D
0005435216579	27064	59	20E
0005434084919	2746	1	1A
0005433060378	2746	2	2A
0005434084922	2746	3	2B
0005434084923	2746	4	3A
0005434084918	2746	5	3B
0005433060379	2746	6	4B
0005434084921	2746	7	5A
0005434084920	2746	8	5B
0005433060408	28494	1	1A
0005434084890	28494	2	1B
0005434084873	28494	3	2A
0005433060407	28494	4	4A
0005434084878	28494	5	4B
0005434084884	28494	6	6A
0005435548419	11162	1	1A
0005435548446	11162	2	1C
0005435548442	11162	3	1D
0005433788200	11162	4	2A
0005435548439	11162	5	2C
0005435548417	11162	6	2D
0005433788203	11162	7	3A
0005433788204	11162	8	3B
0005433788195	11162	9	3C
0005433788196	11162	10	4A
0005435548430	11162	11	4B
0005433788194	11162	12	4C
0005435548418	11162	13	5A
0005435548420	11162	14	5B
0005435548429	11162	15	5C
0005435548447	11162	16	6B
0005433788193	11162	17	6C
0005435548438	11162	18	6D
0005435548431	11162	19	7A
0005433788192	11162	20	7B
0005435548443	11162	21	7C
0005435548424	11162	22	7D
0005433788202	11162	23	18A
0005435548425	11162	24	18C
0005435548432	11162	25	19A
0005433788198	11162	26	19B
0005433788190	11162	27	19D
0005435548445	11162	28	20A
0005435548437	11162	29	20B
0005433788197	11162	30	20D
0005435548421	11162	31	21C
0005433788199	11162	32	21D
0005433788201	11162	33	22A
0005433788191	11162	34	22B
0005433788205	11162	35	22C
0005435548441	11162	36	22D
0005435548426	11162	37	23B
0005435548481	20668	1	1D
0005435548477	20668	2	2A
0005435548476	20668	3	3B
0005433788146	20668	4	4A
0005435548482	20668	5	4D
0005433788147	20668	6	7A
0005435548480	20668	7	18D
0005435548478	20668	8	19A
0005435548479	20668	9	19B
0005435548474	20668	10	20D
0005433788145	20668	11	22C
0005435548483	20668	12	23A
0005435548475	20668	13	23B
0005435517757	11421	1	1A
0005435540878	11421	2	1C
0005435540779	11421	3	1F
0005435517737	11421	4	2D
0005435517730	11421	5	2F
0005435517670	11421	6	3C
0005435540808	11421	7	4F
0005435517693	11421	8	5C
0005435517731	11421	9	5D
0005435517782	11421	10	5E
0005435540734	11421	11	6C
0005435517671	11421	12	6E
0005435517735	11421	13	6F
0005435517690	11421	14	7E
0005435540877	11421	15	7F
0005435540689	11421	16	8A
0005435517695	11421	17	8C
0005435540688	11421	18	8E
0005435540736	11421	19	9A
0005435540767	11421	20	9D
0005435540792	11421	21	9F
0005435517694	11421	22	10D
0005435540770	11421	23	10E
0005435517697	11421	24	11C
0005435540807	11421	25	11F
0005435540860	11421	26	12A
0005435540818	11421	27	12D
0005435540787	11421	28	13A
0005435540788	11421	29	13E
0005435540789	11421	30	13F
0005435540786	11421	31	14C
0005435540785	11421	32	14D
0005435517760	11421	33	15A
0005435517701	11421	34	15C
0005435540771	11421	35	15D
0005435517721	11421	36	15E
0005435517783	11421	37	16C
0005435517717	11421	38	16D
0005435540720	11421	39	16E
0005435540744	11421	40	17C
0005435517682	11421	41	17E
0005435517691	11421	42	18A
0005435540745	11421	43	18C
0005435517702	11421	44	18E
0005435517696	11421	45	19A
0005435517692	11421	46	19E
0005435540773	11421	47	19F
0005435540809	11421	48	20A
0005435540857	11421	49	20E
0005435517663	11421	50	20F
0005435529190	22236	1	1C
0005435529191	22236	2	1D
0005435529203	22236	3	1F
0005435540938	22236	4	2A
0005435540943	22236	5	2C
0005435540942	22236	6	2D
0005435529205	22236	7	3C
0005435529204	22236	8	4A
0005435540940	22236	9	4E
0005435540950	22236	10	5F
0005435529210	22236	11	6C
0005435540951	22236	12	6D
0005435529202	22236	13	6E
0005435529193	22236	14	6F
0005435540954	22236	15	7C
0005435540946	22236	16	7D
0005435540937	22236	17	7E
0005435529200	22236	18	8C
0005435529207	22236	19	8D
0005435529199	22236	20	8F
0005435529197	22236	21	9A
0005435540949	22236	22	9C
0005435540941	22236	23	10D
0005435540935	22236	24	11A
0005435540953	22236	25	11C
0005435540948	22236	26	11D
0005435540945	22236	27	11F
0005435529201	22236	28	12D
0005435529195	22236	29	12E
0005435529189	22236	30	13C
0005435540939	22236	31	13D
0005432294480	22236	32	13F
0005435540934	22236	33	14A
0005435529206	22236	34	14D
0005435529198	22236	35	14E
0005435529194	22236	36	15A
0005435529208	22236	37	15C
0005435540947	22236	38	15F
0005435540933	22236	39	16F
0005435540952	22236	40	17F
0005435540936	22236	41	18C
0005435529209	22236	42	18D
0005435529196	22236	43	18E
0005435540944	22236	44	19A
0005435529192	22236	45	20C
0005432294479	22236	46	20E
0005432294481	22236	47	20F
0005433251224	2283	1	1A
0005434907187	2283	2	1C
0005433251167	2283	3	1D
0005434907186	2283	4	1F
0005434907170	2283	5	2A
0005433251139	2283	6	2C
0005434907199	2283	7	2D
0005433400962	2283	8	2F
0005433251291	2283	9	3A
0005433251022	2283	10	3C
0005434907204	2283	11	3D
0005433251084	2283	12	3F
0005433251271	2283	13	4A
0005434907177	2283	14	4D
0005434907195	2283	15	4E
0005434907168	2283	16	4F
0005433250981	2283	17	5A
0005434907178	2283	18	5C
0005434907189	2283	19	5E
0005434907188	2283	20	5D
0005433251159	2283	21	5F
0005433400959	2283	22	6A
0005434907181	2283	23	6C
0005433251262	2283	24	6D
0005433251231	2283	25	6E
0005434907164	2283	26	6F
0005434907167	2283	27	7A
0005434907180	2283	28	7E
0005434907202	2283	29	7F
0005434907193	2283	30	8C
0005434907165	2283	31	8D
0005433251188	2283	32	8E
0005433400961	2283	33	8F
0005433251166	2283	34	9A
0005434907209	2283	35	9C
0005434907207	2283	36	9D
0005434907173	2283	37	9E
0005434907171	2283	38	9F
0005433251110	2283	39	10A
0005434907197	2283	40	10C
0005434907179	2283	41	10D
0005434907203	2283	42	10E
0005433251232	2283	43	11A
0005433251194	2283	44	11C
0005434907213	2283	45	11D
0005433400933	2283	46	11E
0005433251223	2283	47	11F
0005434907172	2283	48	12C
0005434907192	2283	49	12D
0005433251212	2283	50	12E
0005434907191	2283	51	12F
0005433251187	2283	52	13A
0005434907206	2283	53	13C
0005434907208	2283	54	13D
0005434907201	2283	55	13E
0005433251242	2283	56	13F
0005434907162	2283	57	14A
0005434907196	2283	58	14C
0005434907190	2283	59	14D
0005434907166	2283	60	14E
0005433251136	2283	61	14F
0005434907183	2283	62	15E
0005434907211	2283	63	15D
0005434907176	2283	64	15F
0005434907212	2283	65	16A
0005434907184	2283	66	16C
0005433251200	2283	67	16D
0005434907194	2283	68	16E
0005433251257	2283	69	16F
0005434907163	2283	70	17A
0005434907169	2283	71	17C
0005434907174	2283	72	17D
0005434907182	2283	73	17E
0005434907175	2283	74	17F
0005433251189	2283	75	18A
0005434907205	2283	76	18C
0005433251135	2283	77	18D
0005434907185	2283	78	18E
0005434907161	2283	79	19A
0005433251122	2283	80	19C
0005434907210	2283	81	19D
0005434907198	2283	82	19E
0005433250980	2283	83	19F
0005433251119	2283	84	20A
0005433251261	2283	85	20C
0005433251111	2283	86	20D
0005434907200	2283	87	20E
0005433251118	2283	88	20F
0005433251423	25576	1	1A
0005434906724	25576	2	1C
0005434906369	25576	3	1D
0005434906659	25576	4	2A
0005434906507	25576	5	1F
0005434906625	25576	6	2C
0005433251408	25576	7	2D
0005434906497	25576	8	2F
0005434906755	25576	9	3A
0005433251421	25576	10	3C
0005433251401	25576	11	3D
0005433251428	25576	12	3F
0005434906513	25576	13	4C
0005433251402	25576	14	4D
0005434906737	25576	15	4E
0005434906595	25576	16	4F
0005434906664	25576	17	5A
0005433251422	25576	18	5C
0005434906386	25576	19	5D
0005434906650	25576	20	5E
0005434906634	25576	21	5F
0005434906620	25576	22	6A
0005433251429	25576	23	6C
0005434906631	25576	24	6D
0005434906686	25576	25	6E
0005433251404	25576	26	6F
0005433251409	25576	27	7A
0005434906547	25576	28	7D
0005434906656	25576	29	7E
0005434906610	25576	30	7F
0005434906719	25576	31	8A
0005434906761	25576	32	8C
0005434906649	25576	33	8D
0005433251417	25576	34	8E
0005434906385	25576	35	8F
0005433251403	25576	36	9C
0005434906720	25576	37	9D
0005433251418	25576	38	9E
0005434906642	25576	39	9F
0005434906662	25576	40	10A
0005434906537	25576	41	10C
0005434906589	25576	42	10D
0005433400978	25576	43	10E
0005434906527	25576	44	10F
0005434906672	25576	45	11A
0005433251426	25576	46	11C
0005433251419	25576	47	11D
0005433400977	25576	48	11E
0005433251415	25576	49	11F
0005434906475	25576	50	12A
0005434906498	25576	51	12D
0005433251407	25576	52	12E
0005433251405	25576	53	12F
0005433251427	25576	54	13A
0005434906661	25576	55	13C
0005434906714	25576	56	13D
0005434906641	25576	57	13E
0005434906660	25576	58	13F
0005434906593	25576	59	14A
0005434906608	25576	60	14C
0005434906627	25576	61	14D
0005433400976	25576	62	14E
0005434906723	25576	63	14F
0005433251424	25576	64	15A
0005433251431	25576	65	15C
0005433251406	25576	66	15D
0005434906626	25576	67	15E
0005434906499	25576	68	15F
0005433251432	25576	69	16D
0005434906588	25576	70	16E
0005433251412	25576	71	16F
0005434906806	25576	72	17A
0005434906609	25576	73	17C
0005433251420	25576	74	17D
0005434906546	25576	75	17E
0005433251410	25576	76	17F
0005434906594	25576	77	18A
0005434906713	25576	78	18C
0005434906548	25576	79	18D
0005434906710	25576	80	18E
0005434906500	25576	81	18F
0005433251416	25576	82	19A
0005433251425	25576	83	19C
0005433251414	25576	84	19D
0005433251430	25576	85	19E
0005434906813	25576	86	19F
0005433251411	25576	87	20A
0005434906622	25576	88	20C
0005434906485	25576	89	20D
0005433251413	25576	90	20E
0005434906801	25576	91	20F
0005432621010	2500	1	1D
0005432621016	2500	2	2B
0005432621015	2500	3	2C
0005432621006	2500	4	2D
0005432621009	2500	5	3C
0005432621008	2500	6	4B
0005432621003	2500	7	5B
0005432621013	2500	8	5C
0005432862215	2500	9	6C
0005432621011	2500	10	6D
0005432862214	2500	11	18C
0005432621007	2500	12	19D
0005432621012	2500	13	20A
0005432621005	2500	14	20B
0005432621004	2500	15	22A
0005432862241	2500	16	22B
0005432862240	2500	17	22C
0005432621014	2500	18	23A
0005432862284	28082	1	1B
0005432620927	28082	2	1C
0005432620838	28082	3	1D
0005432620950	28082	4	2C
0005432620916	28082	5	3B
0005432620860	28082	6	3C
0005432620980	28082	7	3D
0005432620874	28082	8	4A
0005432620868	28082	9	4C
0005432620866	28082	10	4D
0005432862288	28082	11	5C
0005432862287	28082	12	6A
0005432620873	28082	13	6B
0005432620928	28082	14	6C
0005432862286	28082	15	6D
0005432620859	28082	16	7A
0005432620906	28082	17	19A
0005432620837	28082	18	19C
0005432620917	28082	19	19D
0005432620869	28082	20	20B
0005432620849	28082	21	21A
0005432620897	28082	22	21C
0005432620949	28082	23	21D
0005432862285	28082	24	22C
0005432862289	28082	25	22D
0005432620896	28082	26	23B
0005434097460	11694	1	1B
0005433452735	31086	1	5A
0005433454858	31403	1	2A
0005433452715	31403	2	4A
0005434142566	11983	1	1A
0005434184639	11983	2	2C
0005433129220	11983	3	3B
0005433129207	11983	4	5D
0005434184637	11983	5	19A
0005434184640	11983	6	20A
0005434184651	11983	7	20B
0005433129208	11983	8	20C
0005434184650	11983	9	20D
0005433134091	11983	10	21D
0005434142568	11983	11	22A
0005434184638	11983	12	23B
0005433131697	29811	1	1A
0005433131699	29811	2	1B
0005434184660	29811	3	1D
0005434142602	29811	4	2B
0005434142599	29811	5	2C
0005433134126	29811	6	3A
0005433134130	29811	7	4A
0005433134128	29811	8	4C
0005434326263	29811	9	7B
0005434142601	29811	10	18A
0005433131696	29811	11	18B
0005434142597	29811	12	18D
0005434183576	29811	13	19A
0005434184661	29811	14	19C
0005434326262	29811	15	20A
0005433134127	29811	16	20C
0005433131698	29811	17	21C
0005433131700	29811	18	22A
0005433134129	29811	19	22B
0005434142600	29811	20	22D
0005434142598	29811	21	23B
0005435798922	21299	1	2D
0005435798925	21299	2	7B
0005435798927	21299	3	19B
0005435798919	21299	4	20A
0005435798926	21299	5	20B
0005435798930	21299	6	21C
0005435798923	21299	7	21D
0005435697258	16486	1	1B
0005435697263	16486	2	1C
0005435697260	16486	3	1D
0005435697274	16486	4	2A
0005435697264	16486	5	2C
0005435697247	16486	6	2D
0005435697267	16486	7	3C
0005435697261	16486	8	3D
0005435697254	16486	9	4A
0005435935012	16486	10	4D
0005435697251	16486	11	5A
0005435697273	16486	12	5B
0005435697270	16486	13	5C
0005435935015	16486	14	6A
0005435697253	16486	15	6B
0005435697266	16486	16	6C
0005435697245	16486	17	6D
0005435935014	16486	18	7A
0005435697255	16486	19	7B
0005435935013	16486	20	7C
0005435697252	16486	21	18A
0005435697272	16486	22	18D
0005435697268	16486	23	19B
0005435697256	16486	24	19C
0005435697249	16486	25	19D
0005435697262	16486	26	20A
0005435697269	16486	27	20B
0005435697248	16486	28	21A
0005435934998	16486	29	21B
0005435697246	16486	30	21C
0005435697271	16486	31	21D
0005435697265	16486	32	22A
0005435697250	16486	33	22B
0005435935011	16486	34	22C
0005435697259	16486	35	22D
0005435697257	16486	36	23A
0005435696994	24735	1	1A
0005435697068	24735	2	1C
0005435697193	24735	3	1D
0005435697069	24735	4	2A
0005435697017	24735	5	2B
0005435697118	24735	6	2C
0005435697143	24735	7	3A
0005435697057	24735	8	3C
0005435697055	24735	9	4A
0005435697175	24735	10	4C
0005435697002	24735	11	4D
0005435696993	24735	12	5B
0005435696921	24735	13	5C
0005435935039	24735	14	5D
0005435696879	24735	15	6A
0005435697039	24735	16	6B
0005435697001	24735	17	6D
0005435697103	24735	18	7B
0005435697054	24735	19	7C
0005435697056	24735	20	7D
0005435935040	24735	21	18A
0005435697194	24735	22	18B
0005435696944	24735	23	18C
0005435697158	24735	24	19A
0005435697070	24735	25	19B
0005435696920	24735	26	19C
0005435696878	24735	27	19D
0005435696986	24735	28	20A
0005435697022	24735	29	20B
0005435696991	24735	30	20C
0005435697018	24735	31	20D
0005435697121	24735	32	21A
0005435697176	24735	33	21B
0005435697116	24735	34	21C
0005435935038	24735	35	22A
0005435935041	24735	36	22B
0005435696938	24735	37	22C
0005435697016	24735	38	23A
0005435697119	24735	39	23B
0005433724792	18785	1	1A
0005433724795	18785	2	1B
0005432968813	18785	3	2A
0005433724793	18785	4	4A
0005432968814	18785	5	6A
0005433724794	18785	6	6B
0005433724741	21632	1	1A
0005433724748	21632	2	2A
0005433724742	21632	3	2B
0005432968838	21632	4	3A
0005433724757	21632	5	5A
0005433724758	21632	6	6A
0005432968837	21632	7	5B
0005434137988	7291	1	1A
0005434138004	7291	2	1C
0005434137992	7291	3	1D
0005434137987	7291	4	1F
0005434138031	7291	5	2A
0005434087505	7291	6	2C
0005434138034	7291	7	2D
0005434138000	7291	8	2F
0005434137984	7291	9	3A
0005434137980	7291	10	3C
0005434137998	7291	11	3D
0005434138026	7291	12	3F
0005434137965	7291	13	4A
0005434087502	7291	14	4C
0005434137983	7291	15	4E
0005434137961	7291	16	5C
0005434138016	7291	17	5E
0005434137994	7291	18	5D
0005434138011	7291	19	5F
0005434137972	7291	20	6A
0005434137955	7291	21	6C
0005434137971	7291	22	6D
0005434137966	7291	23	6E
0005434138015	7291	24	6F
0005434138024	7291	25	7A
0005434138001	7291	26	7C
0005434137970	7291	27	7D
0005434138029	7291	28	7E
0005434138010	7291	29	7F
0005434137995	7291	30	8A
0005434137982	7291	31	8C
0005434138023	7291	32	8D
0005434138021	7291	33	8E
0005434138032	7291	34	8F
0005434137989	7291	35	9A
0005434137973	7291	36	9C
0005434137997	7291	37	9E
0005434137985	7291	38	9F
0005434138017	7291	39	10A
0005434138009	7291	40	10C
0005434138014	7291	41	10D
0005434137954	7291	42	10E
0005434137976	7291	43	10F
0005434138013	7291	44	11A
0005434137957	7291	45	11C
0005434137990	7291	46	11D
0005434137964	7291	47	11E
0005434138019	7291	48	11F
0005434137960	7291	49	12A
0005434138012	7291	50	12C
0005434138007	7291	51	12D
0005434138006	7291	52	12E
0005434138005	7291	53	12F
0005434138027	7291	54	13A
0005434137977	7291	55	13C
0005434137968	7291	56	13D
0005434137993	7291	57	13E
0005434087501	7291	58	13F
0005434137953	7291	59	14A
0005434137991	7291	60	14C
0005434087504	7291	61	14E
0005434138008	7291	62	14D
0005434087503	7291	63	15A
0005434137975	7291	64	15D
0005434137978	7291	65	15E
0005434137986	7291	66	15F
0005434138018	7291	67	16A
0005434138030	7291	68	16C
0005434137996	7291	69	16E
0005434137999	7291	70	16F
0005434138020	7291	71	17A
0005434137956	7291	72	17C
0005434138025	7291	73	17D
0005434138002	7291	74	17E
0005434138033	7291	75	17F
0005434137981	7291	76	18C
0005434137979	7291	77	18D
0005434137974	7291	78	18E
0005434138028	7291	79	18F
0005434137962	7291	80	19A
0005434137969	7291	81	19D
0005434137963	7291	82	19F
0005434138022	7291	83	20A
0005434137959	7291	84	20C
0005434138003	7291	85	20D
0005434137967	7291	86	20E
0005434137958	7291	87	20F
0005434137257	28557	1	1A
0005434136902	28557	2	1C
0005434137220	28557	3	1D
0005434137265	28557	4	1F
0005434137164	28557	5	2A
0005434137273	28557	6	2D
0005434137048	28557	7	2F
0005434137139	28557	8	3A
0005434137527	28557	9	3C
0005434136981	28557	10	3D
0005434136868	28557	11	3F
0005434136883	28557	12	4A
0005434136859	28557	13	4C
0005434136955	28557	14	4D
0005434137401	28557	15	4E
0005434136855	28557	16	4F
0005434137009	28557	17	5A
0005434136995	28557	18	5C
0005434137221	28557	19	5D
0005434137250	28557	20	5F
0005434137157	28557	21	6A
0005434137003	28557	22	6C
0005434136854	28557	23	6D
0005434136870	28557	24	6E
0005434137266	28557	25	7A
0005434137049	28557	26	7C
0005434136757	28557	27	7D
0005434137138	28557	28	7E
0005434137417	28557	29	7F
0005434137004	28557	30	8A
0005434137036	28557	31	8C
0005434137274	28557	32	8D
0005434137205	28557	33	8E
0005434087470	28557	34	8F
0005434137400	28557	35	9A
0005434137159	28557	36	9C
0005434137050	28557	37	9D
0005434137106	28557	38	9E
0005434137370	28557	39	10A
0005434137170	28557	40	10C
0005434137121	28557	41	10D
0005434136903	28557	42	10E
0005434087461	28557	43	10F
0005434087462	28557	44	11A
0005434137264	28557	45	11C
0005434136869	28557	46	11D
0005434087459	28557	47	11F
0005434137024	28557	48	12A
0005434137218	28557	49	12C
0005434137077	28557	50	12D
0005434137149	28557	51	12F
0005434137133	28557	52	13A
0005434137204	28557	53	13C
0005434137114	28557	54	13D
0005434137148	28557	55	13E
0005434137132	28557	56	13F
0005434137189	28557	57	14A
0005434137054	28557	58	14C
0005434137369	28557	59	14D
0005434137530	28557	60	14E
0005434137270	28557	61	14F
0005434137031	28557	62	15A
0005434136860	28557	63	15C
0005434137203	28557	64	15D
0005434137364	28557	65	15E
0005434137480	28557	66	15F
0005434137300	28557	67	16A
0005434087471	28557	68	16C
0005434087460	28557	69	16D
0005434137187	28557	70	16E
0005434137228	28557	71	16F
0005434137366	28557	72	17A
0005434137365	28557	73	17C
0005434137039	28557	74	17D
0005434137275	28557	75	17E
0005434137100	28557	76	17F
0005434137368	28557	77	18A
0005434137158	28557	78	18C
0005434136788	28557	79	18D
0005434137040	28557	80	18E
0005434137147	28557	81	19A
0005434137078	28557	82	19C
0005434137325	28557	83	19D
0005434137229	28557	84	19E
0005434137372	28557	85	19F
0005434136994	28557	86	20C
0005434137105	28557	87	20D
0005434136957	28557	88	20E
0005434137076	28557	89	20F
0005435808219	1934	1	1A
0005435808210	1934	2	1D
0005435808212	1934	3	2B
0005435808209	1934	4	2C
0005434610223	1934	5	3A
0005433407499	1934	6	4A
0005433407517	1934	7	4D
0005435808216	1934	8	5A
0005435808215	1934	9	5B
0005434610220	1934	10	6D
0005433407493	1934	11	7B
0005433407500	1934	12	7C
0005435808218	1934	13	18B
0005434610221	1934	14	18A
0005433407498	1934	15	19A
0005435808211	1934	16	20A
0005433407492	1934	17	20C
0005434610222	1934	18	20D
0005435808217	1934	19	21A
0005435808214	1934	20	22A
0005435808220	1934	21	22D
0005435808213	1934	22	23A
0005433407552	23114	1	1A
0005435808110	23114	2	1B
0005435808129	23114	3	1C
0005434610193	23114	4	1D
0005433407542	23114	5	2A
0005433407545	23114	6	2B
0005435808107	23114	7	2C
0005435808101	23114	8	2D
0005435808109	23114	9	3A
0005433407546	23114	10	3B
0005434610208	23114	11	3C
0005435808105	23114	12	3D
0005435808086	23114	13	4A
0005435808068	23114	14	4B
0005433407549	23114	15	4C
0005435808078	23114	16	4D
0005433407540	23114	17	5A
0005435808098	23114	18	5C
0005433407553	23114	19	5B
0005434610200	23114	20	5D
0005433407550	23114	21	6A
0005433407544	23114	22	6B
0005435808080	23114	23	6D
0005435808081	23114	24	7A
0005435808155	23114	25	7B
0005433407554	23114	26	7C
0005435808125	23114	27	7D
0005435808133	23114	28	18A
0005433407543	23114	29	18B
0005433407551	23114	30	18C
0005435808106	23114	31	18D
0005435808049	23114	32	19A
0005435808130	23114	33	19B
0005435808112	23114	34	19C
0005433407547	23114	35	19D
0005435808074	23114	36	20A
0005435808124	23114	37	20B
0005435808135	23114	38	20C
0005435808103	23114	39	20D
0005435808108	23114	40	21A
0005435808154	23114	41	21B
0005435808079	23114	42	21C
0005433407539	23114	43	21D
0005435808134	23114	44	22A
0005433407541	23114	45	22B
0005434610191	23114	46	22C
0005433407548	23114	47	22D
0005435808095	23114	48	23A
0005435808075	23114	49	23B
0005434503757	16679	1	1A
0005434503715	16679	2	1B
0005434503674	16679	3	1C
0005434503711	16679	4	1D
0005434503681	16679	5	2A
0005434503622	16679	6	2B
0005434503487	16679	7	2C
0005434503619	16679	8	2D
0005434503714	16679	9	3C
0005434503759	16679	10	3D
0005434503726	16679	11	4A
0005434503645	16679	12	4B
0005434503667	16679	13	4D
0005434503545	16679	14	5A
0005434503644	16679	15	5B
0005434503846	16679	16	5C
0005434503710	16679	17	5D
0005434503811	16679	18	6A
0005434503745	16679	19	6B
0005434503662	16679	20	6C
0005434503718	16679	21	6D
0005434503533	16679	22	7A
0005434503854	16679	23	7B
0005434503584	16679	24	7C
0005434503554	16679	25	7D
0005434503544	16679	26	18A
0005434503827	16679	27	18B
0005434503500	16679	28	18C
0005434503546	16679	29	18D
0005434503651	16679	30	19B
0005434503733	16679	31	19C
0005434503767	16679	32	19D
0005434503661	16679	33	20A
0005434503744	16679	34	20B
0005434503702	16679	35	20C
0005434503812	16679	36	20D
0005434503697	16679	37	21A
0005434503701	16679	38	21B
0005434503768	16679	39	21C
0005434503847	16679	40	21D
0005434503501	16679	41	22A
0005434503574	16679	42	22B
0005434503712	16679	43	22C
0005434503620	16679	44	22D
0005434503670	16679	45	23A
0005434503732	16679	46	23B
0005434504046	22933	1	1A
0005434504043	22933	2	1B
0005434504036	22933	3	1C
0005434504032	22933	4	1D
0005434504047	22933	5	2A
0005434504050	22933	6	2B
0005434504049	22933	7	2D
0005434504027	22933	8	3A
0005434504034	22933	9	3B
0005434504052	22933	10	3C
0005434504028	22933	11	3D
0005434504040	22933	12	4A
0005434504026	22933	13	4B
0005434504053	22933	14	4D
0005434504039	22933	15	5A
0005434504023	22933	16	5B
0005434504024	22933	17	5C
0005434504061	22933	18	6A
0005434504056	22933	19	6B
0005434504029	22933	20	6C
0005434504022	22933	21	7A
0005434504033	22933	22	7B
0005434504060	22933	23	7D
0005434504042	22933	24	18A
0005434504025	22933	25	18C
0005434504058	22933	26	18D
0005434504044	22933	27	19A
0005434504045	22933	28	19B
0005434504059	22933	29	19C
0005434504054	22933	30	19D
0005434504055	22933	31	20B
0005434504030	22933	32	20C
0005434504041	22933	33	20D
0005434504037	22933	34	21A
0005434504038	22933	35	21D
0005434504057	22933	36	22A
0005434504048	22933	37	22B
0005434504035	22933	38	22C
0005434504051	22933	39	22D
0005434504031	22933	40	23B
0005435078310	2213	1	1A
0005433266597	2213	2	1D
0005433266604	2213	3	2B
0005433266620	2213	4	2D
0005435078315	2213	5	3B
0005435078314	2213	6	3D
0005433266611	2213	7	4A
0005435078304	2213	8	4D
0005433266657	2213	9	5A
0005435078311	2213	10	5B
0005433266610	2213	11	5C
0005435078309	2213	12	6C
0005433266605	2213	13	7A
0005435078305	2213	14	7B
0005435078316	2213	15	7C
0005435078308	2213	16	18B
0005433266591	2213	17	18C
0005433266590	2213	18	18D
0005433266627	2213	19	19A
0005433266642	2213	20	19B
0005435078312	2213	21	19C
0005435078317	2213	22	20D
0005435078307	2213	23	21A
0005433266618	2213	24	21C
0005435078313	2213	25	22A
0005435078306	2213	26	22D
0005433266638	2213	27	23A
0005433266616	2213	28	23B
0005435078220	24339	1	1D
0005435078134	24339	2	2A
0005435078175	24339	3	2C
0005435078210	24339	4	2D
0005433266701	24339	5	3A
0005433266705	24339	6	3B
0005435078118	24339	7	4A
0005435078239	24339	8	5B
0005435078117	24339	9	5D
0005435078211	24339	10	6B
0005433266702	24339	11	7B
0005433266704	24339	12	18D
0005435078133	24339	13	19B
0005433266707	24339	14	19C
0005433266703	24339	15	19D
0005435078189	24339	16	20A
0005435078177	24339	17	20B
0005435078158	24339	18	21A
0005433266706	24339	19	21B
0005435078237	24339	20	21C
0005435078174	24339	21	22A
0005435078219	24339	22	22B
0005433266708	24339	23	22C
0005434988712	6609	1	1C
0005434988714	6609	2	5C
0005434988713	6609	3	5D
0005434988720	6609	4	6B
0005434988721	6609	5	6C
0005435464486	6609	6	7D
0005434988711	6609	7	18D
0005434988719	6609	8	19A
0005434988718	6609	9	19B
0005435464485	6609	10	20A
0005435803258	6609	11	20B
0005434988715	6609	12	20C
0005435464484	6609	13	20D
0005435803259	6609	14	21D
0005434988717	6609	15	22B
0005434988710	6609	16	22C
0005434988716	6609	17	22D
0005434988591	23585	1	2B
0005434988601	23585	2	4B
0005434988593	23585	3	5A
0005435464502	23585	4	5B
0005434988592	23585	5	7B
0005434988573	23585	6	18D
0005434988600	23585	7	20B
0005434988602	23585	8	21B
0005434988555	23585	9	21D
0005434988590	23585	10	22A
0005435464503	23585	11	22D
0005434988599	23585	12	23A
0005434988574	23585	13	23B
0005433449922	30509	1	1C
0005432383097	30509	2	2C
0005433449933	30509	3	2D
0005433449937	30509	4	2F
0005433449923	30509	5	3C
0005432383107	30509	6	3F
0005433449928	30509	7	4A
0005432383122	30509	8	4D
0005433454870	30509	9	4F
0005433449929	30509	10	5A
0005433449938	30509	11	5C
0005433449919	30509	12	6A
0005432383114	30509	13	6D
0005432383115	30509	14	6F
0005432383112	30509	15	7A
0005432383126	30509	16	7D
0005433449934	30509	17	7E
0005432383125	30509	18	8C
0005432383123	30509	19	8D
0005433453760	30509	20	8F
0005432383119	30509	21	9D
0005432383124	30509	22	9F
0005432383128	30509	23	10A
0005432383109	30509	24	10C
0005432383096	30509	25	10D
0005433449939	30509	26	10E
0005432383101	30509	27	11F
0005432383118	30509	28	12A
0005433449930	30509	29	12C
0005433449921	30509	30	12E
0005432383102	30509	31	13A
0005433449935	30509	32	13C
0005433449932	30509	33	13D
0005432383120	30509	34	13F
0005432383103	30509	35	14A
0005433449940	30509	36	14E
0005433454871	30509	37	14F
0005433449924	30509	38	15A
0005432383106	30509	39	15C
0005433449927	30509	40	15D
0005432383108	30509	41	15E
0005432383127	30509	42	15F
0005433449926	30509	43	16A
0005432383113	30509	44	16C
0005432383095	30509	45	16E
0005432383099	30509	46	16F
0005433449936	30509	47	17A
0005432383111	30509	48	17C
0005432383117	30509	49	17D
0005433453759	30509	50	17F
0005432383105	30509	51	18A
0005432383100	30509	52	18C
0005432383110	30509	53	18D
0005432383104	30509	54	18E
0005433449920	30509	55	19A
0005432383098	30509	56	19C
0005433454872	30509	57	19D
0005433449918	30509	58	19E
0005433449931	30509	59	20C
0005432383116	30509	60	20D
0005432383121	30509	61	20E
0005433449925	30509	62	20F
0005432382758	31341	1	1A
0005432382554	31341	2	1C
0005432382569	31341	3	1D
0005432382675	31341	4	2A
0005432382727	31341	5	2C
0005432382839	31341	6	2F
0005432382679	31341	7	3A
0005433449635	31341	8	3C
0005432382543	31341	9	3D
0005432382723	31341	10	3F
0005433451597	31341	11	4A
0005432382623	31341	12	4C
0005432382650	31341	13	4E
0005432382540	31341	14	4F
0005432382608	31341	15	5A
0005432382685	31341	16	5C
0005432382697	31341	17	5D
0005432382703	31341	18	5E
0005433449844	31341	19	6A
0005433449683	31341	20	6C
0005433449733	31341	21	6D
0005432382659	31341	22	6F
0005432382674	31341	23	7A
0005432382628	31341	24	7C
0005433449758	31341	25	7D
0005433449753	31341	26	7E
0005433449794	31341	27	7F
0005433449770	31341	28	8C
0005432382553	31341	29	8D
0005432382836	31341	30	8F
0005432382841	31341	31	9A
0005432382630	31341	32	9D
0005433449777	31341	33	10A
0005432382632	31341	34	10D
0005433453737	31341	35	10F
0005432382660	31341	36	11C
0005433449769	31341	37	11D
0005432382701	31341	38	11F
0005433449729	31341	39	12A
0005433449619	31341	40	12E
0005432382840	31341	41	12F
0005432382631	31341	42	13A
0005433449637	31341	43	13C
0005432382603	31341	44	13D
0005432382704	31341	45	13E
0005433449618	31341	46	13F
0005432382716	31341	47	14A
0005433449634	31341	48	14D
0005432382627	31341	49	14E
0005432382568	31341	50	15A
0005433449754	31341	51	15C
0005432382819	31341	52	15D
0005433449636	31341	53	15E
0005432382871	31341	54	15F
0005433451589	31341	55	16A
0005433449728	31341	56	16C
0005433449748	31341	57	16E
0005432382542	31341	58	16F
0005432382658	31341	59	17A
0005432382552	31341	60	17C
0005432382705	31341	61	17D
0005432382574	31341	62	17E
0005433449768	31341	63	17F
0005432382717	31341	64	18A
0005432382737	31341	65	18C
0005433449747	31341	66	18D
0005433449609	31341	67	18E
0005432382774	31341	68	19A
0005432382604	31341	69	19D
0005433453746	31341	70	20A
0005432382686	31341	71	20C
0005432382602	31341	72	20D
0005433453745	31341	73	20E
0005433449797	31341	74	20F
0005433126791	10791	1	1C
0005435304114	10791	2	3A
0005435304113	10791	3	4B
0005433126779	10791	4	5B
0005435299714	10791	5	6A
0005433131646	10791	6	6B
0005433126787	10791	7	6D
0005433131628	10791	8	7A
0005433126800	10791	9	18B
0005435299712	10791	10	18D
0005433131648	10791	11	19A
0005435299715	10791	12	19B
0005433126801	10791	13	19D
0005433131647	10791	14	20A
0005435299713	10791	15	21A
0005433126778	10791	16	21B
0005433126786	10791	17	23B
0005435302191	29721	1	1B
0005433129269	29721	2	1C
0005433129270	29721	3	1D
0005435299768	29721	4	2A
0005433126841	29721	5	2C
0005433129272	29721	6	3C
0005433126839	29721	7	4A
0005435302192	29721	8	4B
0005435302194	29721	9	4C
0005433129268	29721	10	5B
0005435299772	29721	11	5D
0005435299770	29721	12	6B
0005435299769	29721	13	7B
0005433129271	29721	14	18D
0005435299773	29721	15	19C
0005433126837	29721	16	20B
0005435302193	29721	17	20D
0005435299771	29721	18	21B
0005433126840	29721	19	21D
0005433126838	29721	20	22C
0005434287250	2420	1	1B
0005434287239	2420	2	1C
0005434287254	2420	3	1D
0005434287242	2420	4	2A
0005434287236	2420	5	2B
0005434287243	2420	6	2C
0005434287255	2420	7	2D
0005434287252	2420	8	3A
0005434287247	2420	9	3B
0005432264470	2420	10	3C
0005434287235	2420	11	3D
0005434287241	2420	12	4A
0005432264469	2420	13	4C
0005433109958	2420	14	5A
0005434287244	2420	15	5C
0005434287246	2420	16	5D
0005433109952	2420	17	6A
0005434287251	2420	18	7A
0005433109963	2420	19	7B
0005434287237	2420	20	7D
0005434287234	2420	21	18A
0005434287253	2420	22	18C
0005434287238	2420	23	18D
0005434287249	2420	24	19A
0005432264471	2420	25	19B
0005433109953	2420	26	19C
0005433109962	2420	27	20A
0005434287248	2420	28	20C
0005433109933	2420	29	21B
0005434287245	2420	30	22C
0005434287240	2420	31	23B
0005434287050	26841	1	1A
0005433110024	26841	2	1B
0005434287115	26841	3	1C
0005433110027	26841	4	2A
0005434287033	26841	5	2B
0005433110032	26841	6	2D
0005433110031	26841	7	3B
0005434287009	26841	8	3C
0005434287084	26841	9	3D
0005434287052	26841	10	4A
0005434287054	26841	11	4B
0005434286991	26841	12	4C
0005434287137	26841	13	5B
0005434287060	26841	14	5C
0005434287007	26841	15	6B
0005434287056	26841	16	6C
0005433110028	26841	17	6D
0005434287015	26841	18	7A
0005433110026	26841	19	7B
0005433110025	26841	20	7C
0005434287136	26841	21	7D
0005434287095	26841	22	18A
0005434287068	26841	23	18B
0005433110029	26841	24	18D
0005434287108	26841	25	19A
0005434287008	26841	26	19B
0005434287138	26841	27	19C
0005433110034	26841	28	19D
0005434287030	26841	29	20A
0005433110023	26841	30	20B
0005434286983	26841	31	20D
0005434287049	26841	32	21A
0005434287089	26841	33	21B
0005433110030	26841	34	21C
0005434287061	26841	35	21D
0005434287051	26841	36	22C
0005433110033	26841	37	23A
0005434287053	26841	38	23B
0005434272175	25477	1	1D
0005434272165	25477	2	3D
0005435856194	25477	3	5B
0005434272174	25477	4	6A
0005434272172	25477	5	6D
0005435856195	25477	6	19C
0005435856196	25477	7	21B
0005435856197	25477	8	23B
0005435856148	26629	1	2A
0005435856147	26629	2	2B
0005434273074	26629	3	2D
0005434272190	26629	4	3D
0005434272191	26629	5	4B
0005434272189	26629	6	6C
0005435854042	26629	7	19B
0005435854043	26629	8	20A
0005433868378	4770	1	1A
0005433868366	4770	2	1B
0005433868368	4770	3	1D
0005433868346	4770	4	2A
0005433868347	4770	5	2B
0005433868349	4770	6	2C
0005433868358	4770	7	2D
0005433868361	4770	8	3B
0005433868381	4770	9	3C
0005433868365	4770	10	3D
0005433868370	4770	11	4A
0005433868357	4770	12	4B
0005433868384	4770	13	4C
0005433868375	4770	14	4D
0005435860449	4770	15	5A
0005433868387	4770	16	5B
0005433868350	4770	17	5C
0005433868353	4770	18	5D
0005433868380	4770	19	6A
0005433868383	4770	20	6B
0005433868385	4770	21	6C
0005433868374	4770	22	6D
0005433868351	4770	23	7A
0005433868371	4770	24	7B
0005433868372	4770	25	7C
0005433868355	4770	26	18A
0005433868354	4770	27	18B
0005433868386	4770	28	18C
0005435860448	4770	29	18D
0005433868364	4770	30	19A
0005433868382	4770	31	19B
0005433868348	4770	32	19C
0005433868379	4770	33	19D
0005433868376	4770	34	20A
0005433868360	4770	35	20B
0005433868363	4770	36	20C
0005433868367	4770	37	20D
0005433868369	4770	38	21A
0005433868359	4770	39	21B
0005433868356	4770	40	21D
0005433868362	4770	41	22A
0005435860447	4770	42	22B
0005433868352	4770	43	22C
0005433868377	4770	44	22D
0005433868373	4770	45	23A
0005433867892	32621	1	1A
0005433868100	32621	2	1B
0005435860482	32621	3	1C
0005433867976	32621	4	1D
0005433867903	32621	5	2A
0005433867933	32621	6	2C
0005435860483	32621	7	2D
0005433867987	32621	8	3C
0005433867936	32621	9	3D
0005435860485	32621	10	4A
0005435860481	32621	11	4C
0005433868098	32621	12	4D
0005433867904	32621	13	5A
0005433867793	32621	14	5B
0005433868162	32621	15	5C
0005435860484	32621	16	5D
0005433867898	32621	17	6A
0005433867991	32621	18	6C
0005433867858	32621	19	6D
0005433867930	32621	20	7B
0005433868164	32621	21	7C
0005433867893	32621	22	7D
0005433867992	32621	23	18A
0005433868094	32621	24	18B
0005433867989	32621	25	19A
0005433867910	32621	26	19B
0005433868123	32621	27	19C
0005433867988	32621	28	20A
0005433868099	32621	29	20B
0005433867921	32621	30	21A
0005433867986	32621	31	21B
0005433867962	32621	32	21D
0005433867902	32621	33	22A
0005433868059	32621	34	22C
0005433868163	32621	35	22D
0005433867937	32621	36	23A
0005433868060	32621	37	23B
0005434461643	3458	1	1B
0005434663378	3458	2	1D
0005434461644	3458	3	2B
0005434460503	3458	4	2A
0005435911385	3458	5	2C
0005435911368	3458	6	2D
0005434663377	3458	7	3A
0005434460501	3458	8	3B
0005434663379	3458	9	3C
0005434663383	3458	10	3D
0005435911396	3458	11	5A
0005434663382	3458	12	5C
0005435911356	3458	13	5D
0005434663387	3458	14	6A
0005435911354	3458	15	7C
0005434460500	3458	16	7D
0005434663386	3458	17	18A
0005435911374	3458	18	18B
0005435911324	3458	19	18C
0005435911364	3458	20	19A
0005434663376	3458	21	19B
0005434663381	3458	22	20A
0005434663384	3458	23	20B
0005434663380	3458	24	20D
0005434663385	3458	25	21A
0005434460502	3458	26	21B
0005435911375	3458	27	21D
0005435911355	3458	28	22A
0005434461642	3458	29	23A
0005435911376	3458	30	23B
0005434663201	12447	1	1C
0005434663272	12447	2	1D
0005435911438	12447	3	2B
0005434663269	12447	4	2C
0005434663271	12447	5	3D
0005434663279	12447	6	4D
0005434663270	12447	7	5C
0005435911435	12447	8	6B
0005434663278	12447	9	6D
0005435911439	12447	10	7C
0005434663200	12447	11	7D
0005435911437	12447	12	19B
0005434663257	12447	13	20B
0005434663234	12447	14	20C
0005434663224	12447	15	21A
0005434663268	12447	16	21B
0005435911436	12447	17	22A
0005434663300	12447	18	22B
0005435911433	12447	19	22D
0005435911434	12447	20	23B
0005433867936	14491	1	1A
0005433867910	14491	2	1B
0005433867962	14491	3	1C
0005433867987	14491	4	1D
0005433867893	14491	5	2B
0005433867986	14491	6	2C
0005435860481	14491	7	2D
0005433867991	14491	8	3A
0005433867793	14491	9	3B
0005433867921	14491	10	3D
0005433868094	14491	11	4B
0005433868123	14491	12	4C
0005433868060	14491	13	5B
0005433867892	14491	14	6A
0005435860483	14491	15	6B
0005433867976	14491	16	6C
0005433867988	14491	17	6D
0005433867992	14491	18	7A
0005433867858	14491	19	7B
0005433867989	14491	20	7C
0005433867903	14491	21	7D
0005433867902	14491	22	18C
0005433867930	14491	23	18D
0005433868164	14491	24	19A
0005433868163	14491	25	19B
0005433868098	14491	26	19C
0005435860485	14491	27	19D
0005433868059	14491	28	20A
0005435860482	14491	29	20B
0005433867937	14491	30	21A
0005435860484	14491	31	21B
0005433867933	14491	32	21C
0005433867904	14491	33	22A
0005433868162	14491	34	22B
0005433867898	14491	35	22D
0005433868099	14491	36	23A
0005433868100	14491	37	23B
0005433868322	32642	1	1A
0005433868321	32642	2	1B
0005433868337	32642	3	1D
0005433868331	32642	4	2B
0005433868310	32642	5	2C
0005433868328	32642	6	2D
0005433868335	32642	7	3A
0005433868309	32642	8	3B
0005433868314	32642	9	3C
0005433868344	32642	10	3D
0005433868340	32642	11	4A
0005433868339	32642	12	4B
0005433868318	32642	13	4C
0005433868319	32642	14	4D
0005435860443	32642	15	5A
0005435860444	32642	16	5B
0005433868315	32642	17	5C
0005433868316	32642	18	5D
0005433868326	32642	19	6A
0005433868313	32642	20	6B
0005433868317	32642	21	6C
0005433868308	32642	22	7A
0005433868341	32642	23	6D
0005433868329	32642	24	7B
0005433868311	32642	25	7C
0005433868327	32642	26	7D
0005433868336	32642	27	18A
0005433868323	32642	28	18C
0005433868343	32642	29	18D
0005433868307	32642	30	19C
0005433868324	32642	31	19D
0005435860442	32642	32	20A
0005433868305	32642	33	20B
0005433868330	32642	34	20C
0005433868332	32642	35	21A
0005433868338	32642	36	21B
0005433868342	32642	37	21C
0005433868334	32642	38	21D
0005433868345	32642	39	22A
0005433868320	32642	40	22B
0005433868325	32642	41	22C
0005433868312	32642	42	22D
0005433868306	32642	43	23A
0005433868333	32642	44	23B
0005432799166	12132	1	1C
0005432799115	12132	2	2D
0005432799167	12132	3	3A
0005432799215	12132	4	3B
0005432799080	12132	5	4A
0005432799136	12132	6	4D
0005432799135	12132	7	5B
0005432799211	12132	8	5D
0005432799255	12132	9	6A
0005432799106	12132	10	6C
0005432799117	12132	11	7A
0005432799214	12132	12	7C
0005432799079	12132	13	18A
0005432799119	12132	14	19D
0005432799107	12132	15	20A
0005432799182	12132	16	20B
0005432799165	12132	17	20D
0005432799234	12132	18	21A
0005432799183	12132	19	21B
0005432799181	12132	20	21D
0005432799371	14830	1	1C
0005432799360	14830	2	1D
0005432799374	14830	3	2A
0005432799386	14830	4	3B
0005432799381	14830	5	4A
0005432799379	14830	6	4B
0005432799378	14830	7	5C
0005432799366	14830	8	6C
0005432799359	14830	9	6B
0005432799384	14830	10	6D
0005432799365	14830	11	7B
0005432799377	14830	12	7C
0005432799383	14830	13	7D
0005432799368	14830	14	18A
0005432799385	14830	15	18B
0005432799375	14830	16	18C
0005432799380	14830	17	18D
0005432799369	14830	18	19A
0005432799364	14830	19	19B
0005432799361	14830	20	19C
0005432799373	14830	21	20A
0005432799370	14830	22	20B
0005432799358	14830	23	20D
0005432799362	14830	24	21B
0005432799363	14830	25	21C
0005432799382	14830	26	22A
0005432799367	14830	27	22B
0005432799376	14830	28	22C
0005432799372	14830	29	23B
0005434407634	7034	1	1C
0005434299514	7034	2	1D
0005434407638	7034	3	2A
0005434407662	7034	4	1F
0005434407607	7034	5	2C
0005432153922	7034	6	2D
0005434407665	7034	7	2F
0005434299520	7034	8	3A
0005434407669	7034	9	3C
0005434407627	7034	10	3F
0005434407611	7034	11	4A
0005432108244	7034	12	4D
0005434407608	7034	13	4C
0005434407666	7034	14	4E
0005434407617	7034	15	4F
0005434299512	7034	16	5A
0005432153925	7034	17	5C
0005434407670	7034	18	5B
0005434407610	7034	19	5E
0005435293132	7034	20	6A
0005432108245	7034	21	5F
0005434407661	7034	22	6C
0005435293133	7034	23	6B
0005434299517	7034	24	6D
0005434407667	7034	25	6F
0005434407659	7034	26	6E
0005435310925	7034	27	7A
0005434299513	7034	28	7B
0005434407642	7034	29	7C
0005434407671	7034	30	7D
0005434299523	7034	31	7E
0005434407619	7034	32	8A
0005434407649	7034	33	7F
0005434407631	7034	34	8B
0005432153921	7034	35	8C
0005434407655	7034	36	8D
0005434407606	7034	37	8F
0005434299522	7034	38	8E
0005434407625	7034	39	9A
0005434299526	7034	40	9C
0005432153927	7034	41	9B
0005434299521	7034	42	9D
0005434407615	7034	43	9F
0005435310864	7034	44	9E
0005434407614	7034	45	10B
0005435310916	7034	46	10C
0005435293162	7034	47	10E
0005434407624	7034	48	10D
0005435310895	7034	49	11B
0005435293130	7034	50	11D
0005434299518	7034	51	11C
0005434407647	7034	52	11E
0005432153926	7034	53	11F
0005434299524	7034	54	12B
0005434299506	7034	55	12A
0005434299525	7034	56	12C
0005434407626	7034	57	12E
0005434407612	7034	58	12D
0005434407641	7034	59	13A
0005434407643	7034	60	12F
0005434407621	7034	61	13C
0005434407628	7034	62	13B
0005434407630	7034	63	13D
0005435310865	7034	64	13F
0005434407632	7034	65	14B
0005434407652	7034	66	14A
0005434407653	7034	67	14D
0005435310930	7034	68	14C
0005435310929	7034	69	15A
0005432153924	7034	70	15B
0005434299503	7034	71	15C
0005434407654	7034	72	15D
0005434407609	7034	73	15E
0005432153923	7034	74	16A
0005434407658	7034	75	15F
0005434407639	7034	76	16B
0005434407648	7034	77	16C
0005434407622	7034	78	16D
0005435293139	7034	79	16E
0005435293121	7034	80	17A
0005434407633	7034	81	16F
0005434407620	7034	82	17B
0005434407660	7034	83	17C
0005435293138	7034	84	17E
0005434299508	7034	85	17D
0005434407635	7034	86	18A
0005434407616	7034	87	17F
0005434407629	7034	88	18B
0005434407644	7034	89	18C
0005434299507	7034	90	18E
0005434407650	7034	91	19A
0005434299510	7034	92	18F
0005434299505	7034	93	19C
0005434407668	7034	94	19B
0005434407618	7034	95	19E
0005435293092	7034	96	19D
0005434407663	7034	97	19F
0005434407645	7034	98	20A
0005434299504	7034	99	20B
0005434407664	7034	100	20D
0005434299516	7034	101	20E
0005434299511	7034	102	20F
0005434407636	7034	103	21A
0005434407613	7034	104	21C
0005434407646	7034	105	21B
0005434299509	7034	106	21D
0005434407640	7034	107	21E
0005434407637	7034	108	22A
0005434407651	7034	109	21F
0005435310918	7034	110	22B
0005435310923	7034	111	22C
0005435310907	7034	112	22D
0005434299519	7034	113	22F
0005435293122	7034	114	23A
0005434407623	7034	115	23C
0005434299515	7034	116	23B
0005435310915	7034	117	23D
0005434407656	7034	118	23F
0005434407657	7034	119	23E
0005435293234	26934	1	1A
0005434407229	26934	2	1C
0005434299273	26934	3	1D
0005434407134	26934	4	1F
0005434406837	26934	5	2C
0005434299318	26934	6	2A
0005434406926	26934	7	2D
0005434299331	26934	8	3A
0005434299314	26934	9	2F
0005434406858	26934	10	3C
0005434299292	26934	11	3D
0005434299323	26934	12	3F
0005434299398	26934	13	4A
0005434407149	26934	14	4B
0005434407269	26934	15	4D
0005434299319	26934	16	4C
0005434299197	26934	17	4E
0005435293224	26934	18	5A
0005434406927	26934	19	4F
0005434407112	26934	20	5C
0005434406912	26934	21	5B
0005434299256	26934	22	5D
0005434407305	26934	23	5F
0005434406990	26934	24	5E
0005434407198	26934	25	6A
0005434299200	26934	26	6C
0005432058369	26934	27	6B
0005432058368	26934	28	6D
0005432058370	26934	29	6E
0005434299233	26934	30	6F
0005434299198	26934	31	7B
0005434406870	26934	32	7A
0005434299316	26934	33	7D
0005434299376	26934	34	7C
0005434407060	26934	35	7E
0005434406788	26934	36	7F
0005434407271	26934	37	8A
0005434407148	26934	38	8B
0005434299407	26934	39	8C
0005434407270	26934	40	8E
0005434299374	26934	41	8D
0005434407003	26934	42	8F
0005434406988	26934	43	9A
0005435293225	26934	44	9C
0005434299403	26934	45	9B
0005434407038	26934	46	9D
0005434407058	26934	47	9E
0005434299254	26934	48	9F
0005434299281	26934	49	10B
0005434299375	26934	50	10C
0005434407180	26934	51	10D
0005434299257	26934	52	11A
0005434407179	26934	53	10E
0005434299276	26934	54	11B
0005434406938	26934	55	11D
0005434299315	26934	56	11C
0005434406972	26934	57	11E
0005434407161	26934	58	11F
0005434407111	26934	59	12A
0005434406789	26934	60	12B
0005435293232	26934	61	12D
0005434407200	26934	62	12C
0005434407181	26934	63	12E
0005434407051	26934	64	12F
0005434407201	26934	65	13B
0005432058371	26934	66	13A
0005434406884	26934	67	13C
0005434299383	26934	68	13D
0005435293226	26934	69	13E
0005434406955	26934	70	13F
0005434407177	26934	71	14A
0005435293223	26934	72	14C
0005434299324	26934	73	14B
0005434406864	26934	74	14D
0005434407021	26934	75	14E
0005434406956	26934	76	14F
0005434299271	26934	77	15A
0005434407107	26934	78	15C
0005435293233	26934	79	15B
0005434406995	26934	80	15D
0005435293228	26934	81	15E
0005434299272	26934	82	15F
0005434299396	26934	83	16A
0005434299255	26934	84	16C
0005434406946	26934	85	16B
0005434407093	26934	86	16D
0005434407160	26934	87	16E
0005435293222	26934	88	17A
0005434299309	26934	89	16F
0005435311035	26934	90	17B
0005435293230	26934	91	17D
0005435293231	26934	92	17C
0005434299253	26934	93	17F
0005434299320	26934	94	17E
0005435293229	26934	95	18A
0005434407222	26934	96	18B
0005434406987	26934	97	18C
0005434299280	26934	98	18E
0005434407106	26934	99	18D
0005434407167	26934	100	18F
0005434299397	26934	101	19A
0005434406863	26934	102	19C
0005434299201	26934	103	19B
0005434407199	26934	104	19D
0005434299313	26934	105	19E
0005434299270	26934	106	20A
0005434407125	26934	107	19F
0005434407008	26934	108	20B
0005434406903	26934	109	20C
0005434299367	26934	110	20D
0005434407103	26934	111	20E
0005434299352	26934	112	20F
0005434407094	26934	113	21B
0005434406939	26934	114	21A
0005435293227	26934	115	21C
0005434407105	26934	116	21D
0005434406885	26934	117	21E
0005434407117	26934	118	22A
0005434299351	26934	119	21F
0005434406996	26934	120	22B
0005434299368	26934	121	22C
0005434299312	26934	122	22D
0005434299277	26934	123	22E
0005434406861	26934	124	23A
0005434406857	26934	125	22F
0005434407101	26934	126	23B
0005434406928	26934	127	23D
0005434406902	26934	128	23C
0005434407077	26934	129	23E
0005434406957	26934	130	23F
0005432604286	6470	1	1A
0005432604254	6470	2	1B
0005432604275	6470	3	1C
0005432604280	6470	4	1D
0005432604269	6470	5	2A
0005432604263	6470	6	2B
0005432604261	6470	7	2C
0005434512108	6470	8	2D
0005432604271	6470	9	3A
0005432604278	6470	10	3B
0005432604260	6470	11	3C
0005432604287	6470	12	3D
0005432604267	6470	13	4A
0005432604288	6470	14	4B
0005434512106	6470	15	4C
0005432604264	6470	16	4D
0005432604276	6470	17	5A
0005432604277	6470	18	5B
0005432604268	6470	19	5C
0005432604283	6470	20	5D
0005432604289	6470	21	6A
0005432604256	6470	22	6B
0005432604284	6470	23	6C
0005432604266	6470	24	6D
0005432604253	6470	25	7A
0005434512104	6470	26	7B
0005434512111	6470	27	7C
0005432604250	6470	28	7D
0005432604257	6470	29	18A
0005432604274	6470	30	18B
0005432604273	6470	31	18C
0005432604285	6470	32	18D
0005432604251	6470	33	19A
0005434512107	6470	34	19B
0005432604252	6470	35	19C
0005432604282	6470	36	19D
0005434512109	6470	37	20A
0005432604281	6470	38	20B
0005432604270	6470	39	20C
0005432604265	6470	40	20D
0005432604290	6470	41	21A
0005434512105	6470	42	21B
0005432604272	6470	43	21C
0005432604262	6470	44	21D
0005432604259	6470	45	22A
0005432604279	6470	46	22B
0005432604258	6470	47	22C
0005434512110	6470	48	22D
0005432604255	6470	49	23B
0005432604063	21376	1	1A
0005432604026	21376	2	1B
0005432603784	21376	3	1C
0005432603832	21376	4	1D
0005432604064	21376	5	2A
0005432603761	21376	6	2B
0005432604033	21376	7	2C
0005432603878	21376	8	2D
0005432604013	21376	9	3A
0005432603768	21376	10	3B
0005434512059	21376	11	3C
0005432603866	21376	12	3D
0005432603936	21376	13	4A
0005434512085	21376	14	4B
0005432603785	21376	15	4C
0005432603904	21376	16	4D
0005432603876	21376	17	5A
0005432604094	21376	18	5B
0005432603812	21376	19	5C
0005432603846	21376	20	5D
0005432603949	21376	21	6A
0005432604020	21376	22	6B
0005432603886	21376	23	6C
0005432603845	21376	24	6D
0005432603950	21376	25	7A
0005432603897	21376	26	7B
0005432603887	21376	27	7C
0005432604021	21376	28	7D
0005432603877	21376	29	18A
0005432603907	21376	30	18B
0005432604019	21376	31	18C
0005432603935	21376	32	18D
0005432603837	21376	33	19A
0005432603831	21376	34	19B
0005432604027	21376	35	19C
0005432603924	21376	36	19D
0005432603888	21376	37	20A
0005432604062	21376	38	20B
0005434512070	21376	39	20C
0005432603925	21376	40	20D
0005434512069	21376	41	21A
0005434512046	21376	42	21B
0005432604023	21376	43	21C
0005432604022	21376	44	21D
0005432603867	21376	45	22A
0005432603945	21376	46	22B
0005432603830	21376	47	22C
0005432603895	21376	48	22D
0005434512092	21376	49	23A
0005432603906	21376	50	23B
0005434906719	14983	1	1A
0005433251427	14983	2	1C
0005434906650	14983	3	1D
0005433251432	14983	4	1F
0005434906686	14983	5	2A
0005433251406	14983	6	2D
0005434906813	14983	7	2C
0005434906656	14983	8	2F
0005434906594	14983	9	3A
0005433251402	14983	10	3C
0005434906513	14983	11	3D
0005433251411	14983	12	3F
0005434906369	14983	13	4A
0005433251423	14983	14	4C
0005434906659	14983	15	4D
0005434906649	14983	16	4E
0005434906660	14983	17	4F
0005434906546	14983	18	5A
0005433251431	14983	19	5C
0005433251401	14983	20	5D
0005434906547	14983	21	5F
0005433251424	14983	22	6A
0005434906609	14983	23	6C
0005433251429	14983	24	6D
0005433251419	14983	25	6F
0005434906720	14983	26	7A
0005434906622	14983	27	7C
0005433251425	14983	28	7D
0005433251421	14983	29	7E
0005433251415	14983	30	7F
0005434906588	14983	31	8A
0005434906631	14983	32	8E
0005434906672	14983	33	8F
0005434906641	14983	34	9A
0005434906664	14983	35	9C
0005433251407	14983	36	9D
0005434906608	14983	37	9E
0005434906642	14983	38	9F
0005433251412	14983	39	10A
0005434906527	14983	40	10C
0005434906625	14983	41	10D
0005434906610	14983	42	10E
0005434906737	14983	43	11A
0005434906713	14983	44	11C
0005433251422	14983	45	11D
0005433251409	14983	46	11F
0005433251405	14983	47	12A
0005433251426	14983	48	12C
0005434906589	14983	49	12E
0005434906710	14983	50	12F
0005434906500	14983	51	13A
0005434906627	14983	52	13C
0005434906595	14983	53	13D
0005433251420	14983	54	13E
0005433251404	14983	55	13F
0005433251418	14983	56	14A
0005434906497	14983	57	14C
0005433251413	14983	58	14D
0005434906761	14983	59	14E
0005433251428	14983	60	14F
0005434906661	14983	61	15A
0005433251416	14983	62	15C
0005433251403	14983	63	15D
0005434906485	14983	64	15E
0005434906507	14983	65	15F
0005434906537	14983	66	16A
0005434906806	14983	67	16C
0005434906475	14983	68	16D
0005434906714	14983	69	16E
0005433251417	14983	70	16F
0005434906634	14983	71	17A
0005434906755	14983	72	17C
0005434906662	14983	73	17D
0005434906723	14983	74	17E
0005434906548	14983	75	17F
0005434906385	14983	76	18A
0005433251414	14983	77	18C
0005434906593	14983	78	18E
0005433251430	14983	79	18F
0005433251408	14983	80	19A
0005433251410	14983	81	19C
0005434906620	14983	82	19D
0005434906801	14983	83	19E
0005434906626	14983	84	20A
0005434906498	14983	85	20C
0005434906386	14983	86	20D
0005434906499	14983	87	20E
0005434906724	14983	88	20F
0005433251154	25838	1	1A
0005434907134	25838	2	1D
0005434907120	25838	3	2A
0005434907137	25838	4	2D
0005433251162	25838	5	2F
0005433251081	25838	6	3A
0005434907132	25838	7	3C
0005434907147	25838	8	3D
0005434907107	25838	9	3F
0005434907133	25838	10	4C
0005433251164	25838	11	4D
0005434907110	25838	12	4E
0005434907160	25838	13	4F
0005433251173	25838	14	5A
0005433251165	25838	15	5C
0005434907130	25838	16	5E
0005434907158	25838	17	5D
0005433251133	25838	18	5F
0005433251037	25838	19	6A
0005434907113	25838	20	6C
0005434907150	25838	21	6D
0005434907151	25838	22	6E
0005434907108	25838	23	6F
0005434907124	25838	24	7A
0005434907116	25838	25	7C
0005433251256	25838	26	7F
0005434907142	25838	27	7E
0005433251080	25838	28	8A
0005434907145	25838	29	8C
0005433251174	25838	30	8D
0005434907118	25838	31	8E
0005434907114	25838	32	8F
0005434907112	25838	33	9C
0005434907135	25838	34	9D
0005434907153	25838	35	9E
0005434907111	25838	36	9F
0005434907119	25838	37	10A
0005434907144	25838	38	10C
0005434907159	25838	39	10D
0005434907109	25838	40	11A
0005434907152	25838	41	10F
0005434907121	25838	42	11C
0005434907140	25838	43	11D
0005434907128	25838	44	11E
0005434907149	25838	45	11F
0005434907154	25838	46	12A
0005433251146	25838	47	12C
0005434907148	25838	48	12D
0005433251163	25838	49	12E
0005434907156	25838	50	12F
0005434907131	25838	51	13A
0005434907141	25838	52	13C
0005433251082	25838	53	13D
0005434907146	25838	54	13E
0005434907104	25838	55	13F
0005434907117	25838	56	14A
0005434907126	25838	57	14C
0005434907106	25838	58	14E
0005434907139	25838	59	14F
0005434907155	25838	60	15A
0005434907123	25838	61	15C
0005433251036	25838	62	15E
0005434907105	25838	63	15F
0005434907115	25838	64	16C
0005434907138	25838	65	16D
0005434907122	25838	66	16E
0005434907125	25838	67	16F
0005433251153	25838	68	17A
0005433251255	25838	69	18A
0005434907127	25838	70	18C
0005434907157	25838	71	18E
0005433251132	25838	72	19D
0005433251254	25838	73	19E
0005434907143	25838	74	19F
0005434907129	25838	75	20D
0005434907136	25838	76	20E
0005433008560	14188	1	1A
0005433810495	14188	2	2A
0005433008530	14188	3	2D
0005433008558	14188	4	3D
0005433008528	14188	5	4A
0005433008556	14188	6	4D
0005433008540	14188	7	4E
0005433008533	14188	8	4F
0005433008525	14188	9	5A
0005433008519	14188	10	5F
0005433008555	14188	11	6A
0005433008522	14188	12	6D
0005433008518	14188	13	6E
0005433008547	14188	14	6F
0005433008550	14188	15	7A
0005433008542	14188	16	7C
0005433008563	14188	17	7D
0005433008520	14188	18	7E
0005433008561	14188	19	8C
0005433008548	14188	20	8F
0005433008554	14188	21	9A
0005433008529	14188	22	9C
0005433008536	14188	23	10D
0005433810503	14188	24	11E
0005433008538	14188	25	11F
0005433008535	14188	26	12A
0005433008532	14188	27	12C
0005433008534	14188	28	12D
0005433008562	14188	29	12F
0005433008549	14188	30	13D
0005433008552	14188	31	13F
0005433008546	14188	32	14D
0005433008559	14188	33	14E
0005433008544	14188	34	15C
0005433008521	14188	35	15E
0005433008543	14188	36	15F
0005433008551	14188	37	16E
0005433008553	14188	38	17A
0005433008545	14188	39	17C
0005433008527	14188	40	18E
0005433008526	14188	41	19A
0005433008537	14188	42	19C
0005433008524	14188	43	19D
0005433008557	14188	44	19E
0005433008531	14188	45	20A
0005433008539	14188	46	20C
0005433008523	14188	47	20D
0005433008541	14188	48	20F
0005433810532	22840	1	1D
0005433008117	22840	2	2A
0005433008138	22840	3	2F
0005433008224	22840	4	3C
0005433810530	22840	5	3D
0005433008145	22840	6	3F
0005433008124	22840	7	4C
0005433008135	22840	8	4D
0005433008004	22840	9	4E
0005433008005	22840	10	5D
0005433008233	22840	11	5E
0005433810534	22840	12	6C
0005433008184	22840	13	6D
0005433008234	22840	14	6E
0005433008100	22840	15	6F
0005433008203	22840	16	7E
0005433008136	22840	17	7F
0005433008014	22840	18	8C
0005433008102	22840	19	8F
0005433008123	22840	20	9A
0005433810533	22840	21	10A
0005433008146	22840	22	10C
0005433008103	22840	23	10D
0005433008101	22840	24	11E
0005433008092	22840	25	12A
0005433810531	22840	26	12D
0005433008141	22840	27	12E
0005433008021	22840	28	13F
0005433008183	22840	29	14C
0005433008003	22840	30	14E
0005433008134	22840	31	14F
0005433008078	22840	32	15A
0005433008186	22840	33	15C
0005433008219	22840	34	15E
0005433008002	22840	35	16A
0005433008104	22840	36	16C
0005433008015	22840	37	16D
0005433008140	22840	38	16E
0005433008217	22840	39	16F
0005433008242	22840	40	17A
0005433008087	22840	41	17E
0005433008024	22840	42	17F
0005433008211	22840	43	18A
0005433810529	22840	44	18E
0005433008055	22840	45	19D
0005433008091	22840	46	19E
0005433008139	22840	47	19F
0005433008210	22840	48	20C
0005435718886	15526	1	1A
0005435718891	15526	2	1D
0005435718915	15526	3	1F
0005435718907	15526	4	3F
0005435718903	15526	5	4A
0005435718917	15526	6	4C
0005435718918	15526	7	5D
0005435718888	15526	8	6C
0005435718901	15526	9	7A
0005435718906	15526	10	7D
0005435718902	15526	11	7F
0005435718894	15526	12	8E
0005435718896	15526	13	9A
0005435718909	15526	14	9D
0005435718885	15526	15	10C
0005435718897	15526	16	10F
0005435718916	15526	17	11C
0005435718900	15526	18	12E
0005435718895	15526	19	13C
0005435718892	15526	20	13D
0005435718893	15526	21	13E
0005435718890	15526	22	14A
0005435718899	15526	23	14F
0005435718912	15526	24	15A
0005435718904	15526	25	15E
0005435718898	15526	26	15F
0005435718887	15526	27	16D
0005435718910	15526	28	16E
0005435718905	15526	29	17C
0005435718914	15526	30	18D
0005435718913	15526	31	18E
0005435718911	15526	32	19C
0005435718919	15526	33	19E
0005435718889	15526	34	20A
0005435718920	15526	35	20D
0005435718908	15526	36	20F
0005434925429	14966	1	1C
0005434925471	14966	2	1F
0005434925413	14966	3	2C
0005434925511	14966	4	2F
0005434925393	14966	5	3A
0005434925431	14966	6	3C
0005434925445	14966	7	4E
0005434925447	14966	8	5A
0005434925386	14966	9	5E
0005434925394	14966	10	6C
0005434925281	14966	11	6F
0005434925485	14966	12	7C
0005434925365	14966	13	7E
0005434925357	14966	14	8D
0005434925356	14966	15	8F
0005434925373	14966	16	9E
0005434925479	14966	17	10D
0005434925482	14966	18	10F
0005434925372	14966	19	11C
0005434925480	14966	20	11D
0005434925472	14966	21	11F
0005434925476	14966	22	12A
0005434925415	14966	23	12C
0005434925282	14966	24	12F
0005434925594	14966	25	13A
0005434925384	14966	26	13D
0005434925593	14966	27	13F
0005434925493	14966	28	14D
0005434925448	14966	29	14E
0005434925529	14966	30	15A
0005434925260	14966	31	15C
0005434925355	14966	32	15E
0005434925354	14966	33	16C
0005434925508	14966	34	16D
0005434925473	14966	35	17A
0005434925350	14966	36	17E
0005434925428	14966	37	18A
0005434925366	14966	38	19F
0005434925446	14966	39	20D
0005434925735	20501	1	1F
0005434925725	20501	2	2A
0005434925733	20501	3	2C
0005434925736	20501	4	3D
0005434925742	20501	5	4A
0005434925718	20501	6	4C
0005434925723	20501	7	4E
0005434925717	20501	8	5A
0005434925740	20501	9	5C
0005434925749	20501	10	5D
0005434925741	20501	11	5E
0005434925746	20501	12	7D
0005434925745	20501	13	7E
0005434925726	20501	14	8C
0005434925747	20501	15	10C
0005434925731	20501	16	10F
0005434925722	20501	17	11C
0005434925744	20501	18	11A
0005434925734	20501	19	11E
0005434925729	20501	20	11F
0005434925748	20501	21	12A
0005434925730	20501	22	12E
0005434925727	20501	23	13A
0005434925739	20501	24	15A
0005434925719	20501	25	15D
0005434925738	20501	26	15E
0005434925743	20501	27	16F
0005434925728	20501	28	17C
0005434925724	20501	29	18C
0005434925720	20501	30	18E
0005434925732	20501	31	19C
0005434925737	20501	32	19F
0005434925721	20501	33	20E
0005435999072	15830	1	1A
0005435999043	15830	2	1B
0005435999033	15830	3	1C
0005435487791	15830	4	2A
0005435487804	15830	5	2B
0005435487788	15830	6	2C
0005435999084	15830	7	3A
0005435487807	15830	8	3B
0005435487786	15830	9	3C
0005435487803	15830	10	3D
0005435999071	15830	11	4A
0005435487802	15830	12	4B
0005435487799	15830	13	4C
0005435487787	15830	14	4D
0005435999029	15830	15	5A
0005435487806	15830	16	5C
0005435999007	15830	17	6A
0005435487795	15830	18	6C
0005435487794	15830	19	6B
0005435999012	15830	20	6D
0005435999030	15830	21	7A
0005435999011	15830	22	7B
0005435487801	15830	23	7C
0005435487796	15830	24	18A
0005435999046	15830	25	18B
0005435487798	15830	26	18C
0005435487800	15830	27	18D
0005435999062	15830	28	19A
0005435999056	15830	29	19B
0005435487790	15830	30	19C
0005435487805	15830	31	19D
0005435999061	15830	32	20A
0005435998984	15830	33	20B
0005435999085	15830	34	20C
0005435487792	15830	35	20D
0005435999068	15830	36	21A
0005435999005	15830	37	21B
0005435487793	15830	38	21D
0005435487797	15830	39	22A
0005435999060	15830	40	22B
0005435999076	15830	41	22C
0005435999034	15830	42	22D
0005435487789	15830	43	23A
0005435999006	15830	44	23B
0005435999208	19705	1	1A
0005435487516	19705	2	1B
0005435487578	19705	3	2A
0005435999216	19705	4	1D
0005435487577	19705	5	2B
0005435999201	19705	6	2C
0005435487549	19705	7	2D
0005435487619	19705	8	3A
0005435999197	19705	9	3B
0005435487564	19705	10	3C
0005435487550	19705	11	3D
0005435487540	19705	12	4A
0005435999198	19705	13	4B
0005435487494	19705	14	4C
0005435487568	19705	15	4D
0005435999215	19705	16	5A
0005435999212	19705	17	5B
0005435999205	19705	18	5C
0005435487565	19705	19	5D
0005435999210	19705	20	6B
0005435487520	19705	21	6C
0005435487501	19705	22	6D
0005435487538	19705	23	7A
0005435999203	19705	24	7B
0005435999209	19705	25	7C
0005435999206	19705	26	7D
0005435999213	19705	27	18A
0005435487637	19705	28	18B
0005435999207	19705	29	18C
0005435999199	19705	30	18D
0005435487495	19705	31	19A
0005435487502	19705	32	19C
0005435999217	19705	33	19D
0005435999196	19705	34	20B
0005435487557	19705	35	20C
0005435999202	19705	36	20D
0005435999204	19705	37	21A
0005435487634	19705	38	21B
0005435999200	19705	39	21D
0005435999214	19705	40	22A
0005435999211	19705	41	22B
0005435487539	19705	42	22C
0005435487469	19705	43	23A
0005432142247	6003	1	1C
0005435472617	6003	2	1A
0005432537032	6003	3	1D
0005432658588	6003	4	2C
0005432142245	6003	5	3D
0005435839408	6003	6	4A
0005435839412	6003	7	4F
0005435472629	6003	8	5D
0005435472591	6003	9	6A
0005432537023	6003	10	6D
0005435472653	6003	11	6C
0005435839405	6003	12	6E
0005435839409	6003	13	7A
0005435839395	6003	14	6F
0005435472639	6003	15	7C
0005435472628	6003	16	7B
0005435472622	6003	17	7E
0005435472701	6003	18	7D
0005432658589	6003	19	8A
0005432142246	6003	20	8C
0005435472621	6003	21	8D
0005435472641	6003	22	8E
0005435839413	6003	23	10A
0005435472630	6003	24	10C
0005435472640	6003	25	10B
0005435839398	6003	26	10E
0005435839392	6003	27	11A
0005435839393	6003	28	11B
0005435839415	6003	29	11D
0005432537031	6003	30	11C
0005432537036	6003	31	12B
0005435839399	6003	32	12E
0005435472700	6003	33	13B
0005435839416	6003	34	13C
0005435839397	6003	35	13E
0005435839406	6003	36	14A
0005435839414	6003	37	14B
0005435839391	6003	38	14D
0005432660815	6003	39	14C
0005435839417	6003	40	14F
0005435472652	6003	41	14E
0005435839390	6003	42	15E
0005435839407	6003	43	16B
0005432537024	6003	44	16A
0005432659704	6003	45	15F
0005435839394	6003	46	16E
0005435472627	6003	47	16C
0005432659703	6003	48	16F
0005435839402	6003	49	17B
0005435472586	6003	50	17A
0005435839410	6003	51	17C
0005432537037	6003	52	17E
0005435472592	6003	53	17F
0005435839400	6003	54	18F
0005435839396	6003	55	19E
0005435839403	6003	56	19D
0005435839404	6003	57	20A
0005435472654	6003	58	20C
0005435839401	6003	59	20E
0005432660816	6003	60	20D
0005435472616	6003	61	21D
0005435839411	6003	62	21C
0005435839185	18038	1	1D
0005435839264	18038	2	2C
0005432660791	18038	3	2A
0005435839247	18038	4	1F
0005435472769	18038	5	2D
0005435839124	18038	6	2F
0005435839122	18038	7	3D
0005435839109	18038	8	3C
0005435839214	18038	9	4A
0005435472779	18038	10	4D
0005432660784	18038	11	4C
0005435839037	18038	12	4F
0005435839299	18038	13	5A
0005435839300	18038	14	6A
0005435839113	18038	15	6E
0005435472773	18038	16	7A
0005435839196	18038	17	6F
0005435839036	18038	18	7C
0005435839224	18038	19	7B
0005435472772	18038	20	7E
0005435839093	18038	21	8B
0005435839262	18038	22	8D
0005435472766	18038	23	8C
0005435472774	18038	24	8F
0005435839265	18038	25	9C
0005435839186	18038	26	9E
0005432667423	18038	27	9D
0005435839123	18038	28	10C
0005435839102	18038	29	10B
0005435839263	18038	30	10E
0005432537056	18038	31	10D
0005435839116	18038	32	10F
0005435472770	18038	33	11A
0005435839110	18038	34	11F
0005435472781	18038	35	11E
0005435839115	18038	36	12B
0005435839048	18038	37	12C
0005435839146	18038	38	12E
0005435472777	18038	39	12D
0005435839187	18038	40	13A
0005435839088	18038	41	13C
0005435839035	18038	42	13D
0005435839197	18038	43	14A
0005432537055	18038	44	13F
0005435472780	18038	45	14B
0005435839074	18038	46	14D
0005435472778	18038	47	14C
0005435839089	18038	48	15B
0005435839260	18038	49	15D
0005432660792	18038	50	15C
0005435839175	18038	51	15F
0005435839159	18038	52	16A
0005435839301	18038	53	16B
0005435839225	18038	54	16D
0005435839168	18038	55	16F
0005435839213	18038	56	17B
0005435839090	18038	57	17A
0005435472768	18038	58	17F
0005435839207	18038	59	17E
0005435839184	18038	60	18A
0005435839261	18038	61	18E
0005435839181	18038	62	18D
0005432667425	18038	63	18F
0005435839150	18038	64	19C
0005435472776	18038	65	19B
0005435472775	18038	66	19D
0005435839156	18038	67	20C
0005432667424	18038	68	20B
0005432660785	18038	69	20A
0005435839149	18038	70	20D
0005435472767	18038	71	20F
0005435839038	18038	72	21A
0005435472771	18038	73	21F
0005432537054	18038	74	21E
0005435472765	18038	75	21D
0005433285069	23031	1	1F
0005433284931	23031	2	2C
0005433285022	23031	3	2D
0005433285108	23031	4	3C
0005433284929	23031	5	3F
0005433284918	23031	6	5B
0005433285137	23031	7	5A
0005433285001	23031	8	5D
0005433284899	23031	9	5F
0005433284957	23031	10	7A
0005433284886	23031	11	6F
0005433284932	23031	12	7D
0005433285017	23031	13	8A
0005433284994	23031	14	8B
0005433284964	23031	15	9B
0005433285162	23031	16	10B
0005433285021	23031	17	11A
0005433285059	23031	18	12B
0005433284916	23031	19	12E
0005433284979	23031	20	13A
0005433284820	23031	21	13B
0005433285009	23031	22	13D
0005433284906	23031	23	13C
0005433284962	23031	24	14D
0005433284978	23031	25	14F
0005433285109	23031	26	15B
0005433284976	23031	27	15C
0005433285006	23031	28	15D
0005433285034	23031	29	16B
0005433285027	23031	30	16A
0005433284838	23031	31	16D
0005433285073	23031	32	17B
0005433284942	23031	33	17D
0005433284879	23031	34	17F
0005433284977	23031	35	18B
0005433285107	23031	36	18C
0005433285002	23031	37	18E
0005433285118	23031	38	19B
0005433285013	23031	39	19A
0005433285004	23031	40	19C
0005433284996	23031	41	20A
0005433284893	23031	42	20D
0005433284963	23031	43	21A
0005433285050	23031	44	20F
0005433285005	23031	45	21C
0005433285051	23031	46	21E
0005433285161	23031	47	22A
0005433284907	23031	48	22E
0005433284995	23031	49	22D
0005433284986	23031	50	23A
0005433284902	23031	51	23B
0005433285244	32097	1	1D
0005433285236	32097	2	2C
0005433285262	32097	3	3C
0005433285253	32097	4	3A
0005433285247	32097	5	4F
0005433285238	32097	6	6B
0005433285259	32097	7	6E
0005433285251	32097	8	7C
0005433285242	32097	9	7E
0005433285235	32097	10	8C
0005433285240	32097	11	8E
0005433285255	32097	12	8D
0005433285233	32097	13	9A
0005433285257	32097	14	9C
0005433285261	32097	15	9E
0005433285256	32097	16	10B
0005433285243	32097	17	10E
0005433285252	32097	18	12B
0005433285263	32097	19	14E
0005433285249	32097	20	15A
0005433285250	32097	21	16D
0005433285245	32097	22	17B
0005433285258	32097	23	17E
0005433285248	32097	24	18C
0005433285241	32097	25	18A
0005433285237	32097	26	19D
0005433285232	32097	27	19E
0005433285239	32097	28	20D
0005433285254	32097	29	21C
0005433285246	32097	30	21D
0005433285234	32097	31	23B
0005433285260	32097	32	23E
0005432802472	1474	1	1D
0005432802471	1474	2	2C
0005432892729	1474	3	3A
0005432802496	1474	4	4C
0005432802488	1474	5	4A
0005432802479	1474	6	4F
0005432802469	1474	7	5C
0005432802468	1474	8	5F
0005432802494	1474	9	6A
0005432802493	1474	10	7F
0005432802485	1474	11	8F
0005432892721	1474	12	8E
0005432802487	1474	13	9C
0005432802473	1474	14	9F
0005432892725	1474	15	10D
0005432802476	1474	16	11B
0005432892722	1474	17	11D
0005432802470	1474	18	12E
0005432892723	1474	19	13B
0005432802477	1474	20	13D
0005432802499	1474	21	14A
0005432802475	1474	22	13F
0005432802492	1474	23	14B
0005432802478	1474	24	14D
0005432802489	1474	25	14E
0005432802484	1474	26	15C
0005432802500	1474	27	15E
0005432802490	1474	28	16A
0005432802480	1474	29	16B
0005433112350	1474	30	16F
0005432892720	1474	31	16E
0005432802491	1474	32	17B
0005432802474	1474	33	17C
0005432802497	1474	34	17F
0005432802495	1474	35	18D
0005432802486	1474	36	19A
0005432892724	1474	37	18F
0005432802481	1474	38	19C
0005432802498	1474	39	19B
0005432802483	1474	40	20C
0005432802482	1474	41	20E
0005435852566	23862	1	1A
0005433475666	23862	2	2A
0005433475650	23862	3	2B
0005433475661	23862	4	2C
0005435852571	23862	5	2D
0005433475644	23862	6	3A
0005433475651	23862	7	3C
0005435852567	23862	8	3D
0005433475645	23862	9	4B
0005433475654	23862	10	5B
0005433475662	23862	11	5C
0005435852568	23862	12	5D
0005433475672	23862	13	6A
0005435852573	23862	14	18C
0005433475678	23862	15	19A
0005435852564	23862	16	20B
0005435852565	23862	17	20D
0005435852569	23862	18	21D
0005433475646	23862	19	22A
0005435852570	23862	20	22B
0005433475655	23862	21	22D
0005435852572	23862	22	23A
0005432535771	30631	1	1C
0005432526846	30631	2	1G
0005432535785	30631	3	1D
0005432526756	30631	4	1K
0005435630966	30631	5	1H
0005432535789	30631	6	2C
0005434067181	30631	7	2A
0005432526816	30631	8	2H
0005432526486	30631	9	2G
0005432526935	30631	10	2D
0005434066917	30631	11	3C
0005435213451	30631	12	2K
0005432526501	30631	13	3G
0005435725598	30631	14	4C
0005435213471	30631	15	4A
0005435213464	30631	16	3K
0005432526280	30631	17	4G
0005434066597	30631	18	4D
0005432526720	30631	19	4K
0005432537043	30631	20	4H
0005432526307	30631	21	5A
0005434066658	30631	22	5H
0005435213447	30631	23	5G
0005435213496	30631	24	5D
0005432526209	30631	25	11C
0005432428903	30631	26	11G
0005435213504	30631	27	11E
0005432527216	30631	28	11K
0005432527234	30631	29	12C
0005434066887	30631	30	12A
0005432527093	30631	31	12E
0005432527354	30631	32	12D
0005432211494	30631	33	12G
0005434066919	30631	34	12K
0005435213501	30631	35	12H
0005432527235	30631	36	13D
0005434066530	30631	37	13C
0005435213467	30631	38	13F
0005432526815	30631	39	13E
0005435213444	30631	40	13H
0005432526567	30631	41	13G
0005435213473	30631	42	14A
0005432527082	30631	43	13K
0005435213469	30631	44	14E
0005434066953	30631	45	14D
0005435213462	30631	46	14C
0005434066794	30631	47	14G
0005432526256	30631	48	14F
0005433656667	30631	49	14K
0005432526761	30631	50	15A
0005432159853	30631	51	15E
0005435213502	30631	52	15D
0005432526877	30631	53	15F
0005434067054	30631	54	15K
0005432527215	30631	55	15H
0005434066939	30631	56	16D
0005435213506	30631	57	16C
0005434066797	30631	58	16F
0005432526625	30631	59	16E
0005434066780	30631	60	16H
0005434066624	30631	61	16G
0005432526420	30631	62	17A
0005434067001	30631	63	16K
0005434066598	30631	64	17D
0005432526379	30631	65	17C
0005432526934	30631	66	18A
0005435213485	30631	67	17K
0005435213477	30631	68	17H
0005432526477	30631	69	18C
0005432211489	30631	70	18B
0005432526658	30631	71	18E
0005434066856	30631	72	18F
0005432526581	30631	73	18K
0005432159852	30631	74	18J
0005432526833	30631	75	18H
0005434066855	30631	76	19B
0005435213465	30631	77	19A
0005432159854	30631	78	19C
0005432526595	30631	79	19D
0005432527229	30631	80	19H
0005432526936	30631	81	19G
0005434066837	30631	82	20A
0005432526937	30631	83	19K
0005432526425	30631	84	19J
0005432526820	30631	85	20D
0005432526278	30631	86	20C
0005435213455	30631	87	20F
0005434066895	30631	88	20H
0005434066526	30631	89	21B
0005435213463	30631	90	21A
0005432527008	30631	91	20K
0005434066871	30631	92	21C
0005434066894	30631	93	21F
0005435213460	30631	94	21H
0005432526762	30631	95	21G
0005432526521	30631	96	22A
0005434066796	30631	97	21K
0005434066525	30631	98	22C
0005432526817	30631	99	22B
0005434066806	30631	100	22D
0005435213454	30631	101	22H
0005435725595	30631	102	22G
0005435213458	30631	103	22K
0005434066706	30631	104	22J
0005435213481	30631	105	23B
0005434066866	30631	106	23A
0005434066954	30631	107	23D
0005434066676	30631	108	23C
0005434066674	30631	109	23F
0005432526363	30631	110	23E
0005435725597	30631	111	23H
0005435213490	30631	112	23G
0005432526798	30631	113	24D
0005434066695	30631	114	23K
0005435213441	30631	115	23J
0005435213480	30631	116	24F
0005434066611	30631	117	25A
0005434066824	30631	118	25C
0005432527369	30631	119	25E
0005432526648	30631	120	25D
0005432526752	30631	121	25H
0005432527077	30631	122	25G
0005435213491	30631	123	25J
0005432526355	30631	124	26C
0005434066938	30631	125	26B
0005432527104	30631	126	26D
0005432526480	30631	127	26H
0005432526657	30631	128	26F
0005434066873	30631	129	26K
0005435725596	30631	130	27A
0005435630965	30631	131	27D
0005432526279	30631	132	27C
0005435213442	30631	133	27B
0005435630964	30631	134	27F
0005432526259	30631	135	27E
0005432526344	30631	136	27H
0005435725593	30631	137	27G
0005432526748	30631	138	27J
0005435213500	30631	139	28C
0005434066795	30631	140	28B
0005432526972	30631	141	28D
0005432526799	30631	142	28G
0005432527423	30631	143	28J
0005435213493	30631	144	29B
0005432526890	30631	145	29A
0005434066339	30631	146	29D
0005432527368	30631	147	29C
0005432526306	30631	148	29F
0005433656669	30631	149	29G
0005434066999	30631	150	30A
0005435213448	30631	151	29K
0005432526618	30631	152	30C
0005434066854	30631	153	30B
0005432159851	30631	154	30E
0005435213489	30631	155	30D
0005432527227	30631	156	30G
0005432526410	30631	157	30F
0005434067000	30631	158	30K
0005432526148	30631	159	30J
0005434066485	30631	160	30H
0005432526345	30631	161	31B
0005435213459	30631	162	31C
0005432526714	30631	163	31F
0005434066892	30631	164	31E
0005432526547	30631	165	31H
0005434066766	30631	166	31K
0005435213505	30631	167	31J
0005434066531	30631	168	32C
0005432526952	30631	169	32B
0005434066838	30631	170	32A
0005435213452	30631	171	32E
0005435213478	30631	172	32D
0005434066853	30631	173	32H
0005435213474	30631	174	32G
0005432526876	30631	175	32F
0005434067182	30631	176	32J
0005432526386	30631	177	33B
0005434066916	30631	178	33A
0005435213456	30631	179	33D
0005432526717	30631	180	33C
0005435213503	30631	181	33E
0005435725594	30631	182	33J
0005434066829	30631	183	33H
0005432211490	30631	184	33G
0005434066893	30631	185	34A
0005434067134	30631	186	33K
0005435213483	30631	187	34B
0005432526448	30631	188	34E
0005432527007	30631	189	34D
0005432526747	30631	190	34C
0005432526391	30631	191	34G
0005432527014	30631	192	34J
0005432527187	30631	193	34H
0005432526153	30631	194	35B
0005432526351	30631	195	35A
0005432526755	30631	196	35E
0005432527247	30631	197	35D
0005435213479	30631	198	35C
0005435213450	30631	199	35H
0005432526689	30631	200	36A
0005434067055	30631	201	35K
0005435213439	30631	202	35J
0005434066656	30631	203	36C
0005435213449	30631	204	36B
0005435213486	30631	205	36E
0005432526646	30631	206	36D
0005434066769	30631	207	36G
0005432526726	30631	208	36F
0005432526637	30631	209	36K
0005435213475	30631	210	36J
0005432526627	30631	211	37B
0005432526647	30631	212	37D
0005435213492	30631	213	37C
0005434066900	30631	214	37F
0005435213484	30631	215	37E
0005434066678	30631	216	37J
0005432526201	30631	217	37H
0005432526421	30631	218	37G
0005434066948	30631	219	38A
0005435213497	30631	220	37K
0005432526930	30631	221	38H
0005435213488	30631	222	38B
0005434066872	30631	223	38J
0005435213476	30631	224	39A
0005432526470	30631	225	39D
0005432526378	30631	226	39C
0005435630963	30631	227	39B
0005432526666	30631	228	39F
0005432527015	30631	229	39E
0005435213461	30631	230	39J
0005435213499	30631	231	39G
0005432526939	30631	232	40A
0005435213453	30631	233	39K
0005434067111	30631	234	40E
0005433656668	30631	235	40D
0005435213498	30631	236	40G
0005434066823	30631	237	40F
0005432527330	30631	238	40H
0005434066798	30631	239	40K
0005432526364	30631	240	41D
0005432526245	30631	241	41C
0005434066949	30631	242	41B
0005434066652	30631	243	41F
0005435213494	30631	244	41E
0005432526954	30631	245	41G
0005432526626	30631	246	41K
0005432526522	30631	247	42B
0005432211492	30631	248	42A
0005434066709	30631	249	42E
0005432526955	30631	250	42D
0005432526845	30631	251	42H
0005432526835	30631	252	42G
0005432526933	30631	253	42F
0005432535770	30631	254	42J
0005432211491	30631	255	43B
0005432526623	30631	256	43A
0005432526478	30631	257	43F
0005432526667	30631	258	43J
0005432526202	30631	259	43G
0005434066718	30631	260	43K
0005435213487	30631	261	44C
0005435213457	30631	262	44B
0005432527355	30631	263	44A
0005432211495	30631	264	44E
0005435213445	30631	265	44F
0005432526971	30631	266	44J
0005434066852	30631	267	45B
0005434066599	30631	268	44K
0005434066810	30631	269	45D
0005432526456	30631	270	45E
0005434066748	30631	271	45H
0005435213470	30631	272	45G
0005435630967	30631	273	46B
0005435213468	30631	274	46A
0005432526931	30631	275	46E
0005434066612	30631	276	46C
0005432526721	30631	277	46G
0005435213466	30631	278	46F
0005432211493	30631	279	46J
0005432526577	30631	280	47C
0005435213443	30631	281	47A
0005434066623	30631	282	47E
0005432527080	30631	283	47D
0005434066610	30631	284	47G
0005435213482	30631	285	47F
0005432526152	30631	286	47K
0005432526575	30631	287	47H
0005435213472	30631	288	48D
0005432527066	30631	289	48C
0005432526619	30631	290	48A
0005432526698	30631	291	48F
0005432526883	30631	292	48E
0005434066445	30631	293	48H
0005432526834	30631	294	48G
0005432526797	30631	295	49A
0005435213495	30631	296	49E
0005432537042	30631	297	49C
0005432428894	30631	298	49G
0005434066836	30631	299	49F
0005435213446	30631	300	49K
0005432527081	30631	301	49H
0005432526515	30631	302	50C
0005432526782	30631	303	50A
0005432526305	30631	304	50E
0005432526343	30631	305	50D
0005435213440	30631	306	50G
0005432526488	30631	307	50F
0005432526678	30631	308	51D
0005432526779	30631	309	50K
0005432526739	30631	310	50H
0005434066675	30631	311	51F
0005432526389	30631	312	51E
0005435652642	24867	1	1A
0005435652656	24867	2	1D
0005433367863	24867	3	1F
0005433367861	24867	4	2A
0005433367853	24867	5	2C
0005435652569	24867	6	2D
0005435652663	24867	7	2F
0005435652575	24867	8	3A
0005435652639	24867	9	3C
0005435652477	24867	10	3D
0005433367862	24867	11	3F
0005433367843	24867	12	4A
0005433367839	24867	13	4C
0005433367867	24867	14	4D
0005435652487	24867	15	4E
0005433367840	24867	16	4F
0005435652640	24867	17	5A
0005433367849	24867	18	5D
0005433367868	24867	19	5C
0005435652549	24867	20	5E
0005435652438	24867	21	6A
0005435652638	24867	22	6C
0005435652451	24867	23	6D
0005435652527	24867	24	6E
0005435652407	24867	25	6F
0005433367860	24867	26	7A
0005433367870	24867	27	7D
0005435652511	24867	28	8A
0005433367846	24867	29	8C
0005433367858	24867	30	8D
0005435652406	24867	31	8F
0005435652486	24867	32	9C
0005435652494	24867	33	9D
0005433367864	24867	34	9F
0005433367845	24867	35	10C
0005435652572	24867	36	10D
0005433367844	24867	37	10F
0005435652617	24867	38	11A
0005433367850	24867	39	11C
0005433367836	24867	40	11D
0005433367852	24867	41	11E
0005433367842	24867	42	11F
0005433367859	24867	43	12C
0005433367851	24867	44	12D
0005435652476	24867	45	12E
0005435652658	24867	46	12F
0005433367838	24867	47	13A
0005433367835	24867	48	13C
0005435652576	24867	49	13F
0005433367865	24867	50	14A
0005433367834	24867	51	14C
0005435652498	24867	52	14E
0005435652496	24867	53	14F
0005435652503	24867	54	15A
0005435652512	24867	55	15C
0005435652402	24867	56	15D
0005433367833	24867	57	15E
0005433367869	24867	58	15F
0005435652499	24867	59	16C
0005433367856	24867	60	16E
0005435652603	24867	61	16F
0005433367857	24867	62	17A
0005435652568	24867	63	17C
0005433367855	24867	64	17D
0005433367847	24867	65	17E
0005435652502	24867	66	17F
0005433367866	24867	67	18A
0005433367854	24867	68	18C
0005435652504	24867	69	18D
0005433367848	24867	70	18E
0005435652671	24867	71	18F
0005435652530	24867	72	19A
0005435652604	24867	73	19C
0005435652500	24867	74	19D
0005435652522	24867	75	19F
0005435652587	24867	76	20A
0005433367841	24867	77	20C
0005433367837	24867	78	20F
0005434979744	2016	1	1A
0005434979746	2016	2	1B
0005434979765	2016	3	1C
0005434979766	2016	4	1D
0005434979767	2016	5	2A
0005434979754	2016	6	2B
0005434979762	2016	7	2D
0005434979751	2016	8	3B
0005434979755	2016	9	3C
0005435801691	2016	10	3D
0005434979750	2016	11	5B
0005434979772	2016	12	5C
0005434979774	2016	13	5D
0005435801692	2016	14	6B
0005434979771	2016	15	7A
0005434979760	2016	16	7C
0005434979761	2016	17	7D
0005434979752	2016	18	18A
0005434979745	2016	19	18B
0005434979763	2016	20	18C
0005434979757	2016	21	18D
0005435801693	2016	22	19A
0005434979768	2016	23	19B
0005434979764	2016	24	19C
0005434979759	2016	25	19D
0005434979756	2016	26	20A
0005434979749	2016	27	20B
0005434979753	2016	28	20C
0005434979748	2016	29	20D
0005435801694	2016	30	21B
0005434979747	2016	31	21C
0005434979773	2016	32	22B
0005434979770	2016	33	22C
0005434979758	2016	34	23A
0005434979769	2016	35	23B
0005434979559	23567	1	2C
0005434979485	23567	2	3A
0005434979416	23567	3	3B
0005434979410	23567	4	3D
0005434979421	23567	5	4A
0005434979474	23567	6	4B
0005434979374	23567	7	4D
0005434979426	23567	8	18C
0005434979475	23567	9	19A
0005434979373	23567	10	20D
0005434979358	23567	11	21C
0005435801664	23567	12	22A
0005434979567	23567	13	22B
0005435801661	23567	14	22D
0005434979413	23567	15	23A
0005434952528	2613	1	3B
0005434952527	2613	2	6B
0005433256407	2614	1	1A
0005433256411	2614	2	2A
0005433256406	2614	3	2B
0005434952495	28259	1	2A
0005433256418	28259	2	2B
0005433256419	28259	3	3A
0005434952513	28259	4	3B
0005433256420	28259	5	5B
0005433111504	19766	1	1B
0005433111503	19766	2	2A
0005433111505	19766	3	2B
0005433112371	19766	4	3A
0005433112372	19766	5	6A
0005433112350	20029	1	1A
0005434137167	11916	1	1A
0005434137110	11916	2	1C
0005434136876	11916	3	1D
0005434137010	11916	4	1F
0005434137435	11916	5	2A
0005434137436	11916	6	2C
0005434137104	11916	7	2D
0005434137124	11916	8	3D
0005434137465	11916	9	4A
0005434137416	11916	10	4C
0005434137386	11916	11	4D
0005434137323	11916	12	4E
0005434137283	11916	13	4F
0005434137013	11916	14	5A
0005434137284	11916	15	5C
0005434137290	11916	16	5D
0005434137460	11916	17	5E
0005434137433	11916	18	6C
0005434137282	11916	19	6D
0005434137246	11916	20	6E
0005434137324	11916	21	6F
0005434137215	11916	22	7A
0005434137384	11916	23	7C
0005434137458	11916	24	7D
0005434137339	11916	25	7E
0005434137352	11916	26	7F
0005434137463	11916	27	8A
0005434137424	11916	28	8C
0005434137107	11916	29	8D
0005434137340	11916	30	8E
0005434137011	11916	31	8F
0005434137502	11916	32	9A
0005434137263	11916	33	9C
0005434137016	11916	34	9D
0005434137385	11916	35	9E
0005434137206	11916	36	9F
0005434137326	11916	37	10A
0005434137169	11916	38	10C
0005434137247	11916	39	10E
0005434137456	11916	40	10F
0005434137557	11916	41	11A
0005434137479	11916	42	11C
0005434137488	11916	43	11D
0005434137335	11916	44	11E
0005434137018	11916	45	11F
0005434137484	11916	46	12A
0005434136875	11916	47	12F
0005434137269	11916	48	13A
0005434137093	11916	49	13C
0005434137464	11916	50	13D
0005434137551	11916	51	13E
0005434137312	11916	52	13F
0005434137103	11916	53	14A
0005434137327	11916	54	14C
0005434137261	11916	55	14D
0005434137301	11916	56	14E
0005434137216	11916	57	14F
0005434137459	11916	58	15A
0005434137457	11916	59	15C
0005434137434	11916	60	15D
0005434137219	11916	61	15E
0005434137168	11916	62	15F
0005434137538	11916	63	16C
0005434137461	11916	64	16D
0005434137552	11916	65	16E
0005434137381	11916	66	16F
0005434137109	11916	67	17A
0005434137281	11916	68	17C
0005434137032	11916	69	17D
0005434137448	11916	70	17E
0005434137425	11916	71	18A
0005434137154	11916	72	18C
0005434137259	11916	73	18D
0005434137455	11916	74	18F
0005434137334	11916	75	19A
0005434137501	11916	76	19C
0005434137289	11916	77	19E
0005434137341	11916	78	19F
0005434137487	11916	79	20A
0005434137268	11916	80	20C
0005434137462	11916	81	20D
0005434137267	11916	82	20F
0005434137955	28725	1	1A
0005434138021	28725	2	1C
0005434137961	28725	3	1D
0005434137992	28725	4	1F
0005434138033	28725	5	2A
0005434138004	28725	6	2C
0005434138031	28725	7	3A
0005434138017	28725	8	3C
0005434137971	28725	9	3D
0005434138016	28725	10	3F
0005434138026	28725	11	4A
0005434137974	28725	12	4C
0005434138034	28725	13	4D
0005434138028	28725	14	4F
0005434138029	28725	15	5A
0005434137988	28725	16	5C
0005434137993	28725	17	5D
0005434138018	28725	18	5E
0005434137999	28725	19	5F
0005434137962	28725	20	6A
0005434137970	28725	21	6C
0005434137994	28725	22	6D
0005434137958	28725	23	6E
0005434138030	28725	24	6F
0005434137996	28725	25	7A
0005434138027	28725	26	7C
0005434137997	28725	27	8A
0005434138032	28725	28	8C
0005434137989	28725	29	8D
0005434137965	28725	30	8E
0005434137985	28725	31	8F
0005434137959	28725	32	9A
0005434137960	28725	33	9D
0005434137978	28725	34	9E
0005434137973	28725	35	10A
0005434137981	28725	36	10C
0005434138013	28725	37	10D
0005434137969	28725	38	10E
0005434137990	28725	39	10F
0005434138011	28725	40	11A
0005434137954	28725	41	11C
0005434138003	28725	42	11D
0005434137976	28725	43	11F
0005434137977	28725	44	12A
0005434137987	28725	45	12C
0005434138012	28725	46	12D
0005434137983	28725	47	12E
0005434137967	28725	48	12F
0005434138002	28725	49	13A
0005434138000	28725	50	13C
0005434138022	28725	51	13D
0005434138007	28725	52	13F
0005434138025	28725	53	14A
0005434138001	28725	54	14C
0005434138020	28725	55	14D
0005434138014	28725	56	14E
0005434138008	28725	57	15A
0005434137975	28725	58	15C
0005434138010	28725	59	15D
0005434138015	28725	60	15E
0005434137972	28725	61	15F
0005434138019	28725	62	16A
0005434137982	28725	63	16D
0005434137963	28725	64	16E
0005434138023	28725	65	16F
0005434137979	28725	66	17C
0005434138005	28725	67	17D
0005434137956	28725	68	17E
0005434138024	28725	69	17F
0005434137953	28725	70	18A
0005434137966	28725	71	18C
0005434138009	28725	72	18D
0005434137998	28725	73	18F
0005434137964	28725	74	19A
0005434137957	28725	75	19C
0005434137991	28725	76	19D
0005434137968	28725	77	19E
0005434138006	28725	78	20A
0005434137984	28725	79	20C
0005434137986	28725	80	20D
0005434137980	28725	81	20E
0005434137995	28725	82	20F
0005434466450	6573	1	1A
0005434466447	6573	2	1B
0005434466451	6573	3	2A
0005434466443	6573	4	2B
0005434466446	6573	5	3B
0005434466449	6573	6	4A
0005435312780	6573	7	4B
0005434466454	6573	8	4C
0005435312785	6573	9	5A
0005434466452	6573	10	5B
0005434466457	6573	11	6D
0005435312772	6573	12	7A
0005434466455	6573	13	7B
0005434466444	6573	14	7C
0005434466456	6573	15	7D
0005435312783	6573	16	18C
0005434466453	6573	17	18D
0005435312777	6573	18	19A
0005435312773	6573	19	19B
0005435312784	6573	20	20B
0005435312781	6573	21	22A
0005434466448	6573	22	22D
0005435312782	6573	23	23A
0005434466445	6573	24	23B
0005433534496	6826	1	1B
0005433538864	6826	2	1D
0005433534495	6826	3	2C
0005433538863	6826	4	3A
0005433538857	6826	5	4C
0005435259725	6826	6	5B
0005435259724	6826	7	6A
0005433538865	6826	8	6D
0005435259715	6826	9	7C
0005435259720	6826	10	19B
0005433538859	6826	11	19D
0005435259716	6826	12	20D
0005433538862	6826	13	21C
0005433538860	6826	14	21D
0005433538858	6826	15	22C
0005433538861	6826	16	23A
0005433538806	25012	1	1A
0005435259752	25012	2	3B
0005433538779	25012	3	5A
0005433538778	25012	4	5C
0005433538807	25012	5	6C
0005435259751	25012	6	7A
0005435259750	25012	7	7D
0005433538818	25012	8	19A
0005433534485	25012	9	19B
0005435259753	25012	10	20C
0005435259754	25012	11	21B
0005433534472	25012	12	22B
0005433538794	25012	13	22D
0005432922472	837	1	3A
0005433511944	837	2	3D
0005432922485	837	3	5B
0005432922486	837	4	6A
0005433511940	837	5	7A
0005433511946	837	6	7B
0005433511943	837	7	18A
0005432922482	837	8	18C
0005432922501	837	9	19A
0005433511945	837	10	19D
0005433511941	837	11	21B
0005433511942	837	12	21C
0005433511868	16166	1	2A
0005433511873	16166	2	2C
0005433511891	16166	3	3D
0005433511867	16166	4	4A
0005432922520	16166	5	4C
0005433511872	16166	6	4D
0005433511886	16166	7	5D
0005432922522	16166	8	6D
0005432922521	16166	9	7A
0005433511871	16166	10	18B
0005433511903	16166	11	18C
0005432922523	16166	12	19B
0005433511885	16166	13	19D
0005433511883	16166	14	21B
0005433511897	16166	15	22B
0005433475701	4025	1	1C
0005433475703	4025	2	1D
0005433475705	4025	3	3B
0005435852546	4025	4	5D
0005433475704	4025	5	6C
0005433475706	4025	6	6D
0005433475699	4025	7	7D
0005433475698	4025	8	20B
0005433475702	4025	9	21B
0005433475700	4025	10	21D
0005435852544	4025	11	22C
0005434950525	3682	1	1B
0005435697312	3682	2	1D
0005435916141	3682	3	1C
0005434950524	3682	4	2A
0005434950527	3682	5	2B
0005435935019	3682	6	2C
0005435697324	3682	7	3A
0005435697311	3682	8	3B
0005435697310	3682	9	3C
0005435697318	3682	10	3D
0005435697319	3682	11	4A
0005435697327	3682	12	4C
0005435697303	3682	13	4D
0005435935024	3682	14	5A
0005435935023	3682	15	5B
0005435697330	3682	16	5D
0005435697306	3682	17	6A
0005435697321	3682	18	6B
0005435697305	3682	19	6C
0005435697328	3682	20	6D
0005434950526	3682	21	7A
0005435935031	3682	22	7C
0005435697316	3682	23	7D
0005435697308	3682	24	18A
0005435697313	3682	25	18D
0005435697326	3682	26	19A
0005434950523	3682	27	19B
0005435697315	3682	28	20A
0005435697314	3682	29	20B
0005435935022	3682	30	20C
0005435697307	3682	31	20D
0005435935032	3682	32	21A
0005435697325	3682	33	21B
0005435697322	3682	34	21C
0005435697317	3682	35	21D
0005435697304	3682	36	22A
0005435697323	3682	37	22B
0005435697320	3682	38	22C
0005435697309	3682	39	22D
0005435697329	3682	40	23A
0005435697068	16278	1	1A
0005435696878	16278	2	1B
0005434950473	16278	3	1C
0005435697057	16278	4	1D
0005435697158	16278	5	2B
0005435697119	16278	6	2C
0005435916165	16278	7	2D
0005435696991	16278	8	3A
0005435696920	16278	9	3B
0005435935039	16278	10	3C
0005435697016	16278	11	4A
0005435697001	16278	12	4B
0005434950472	16278	13	4C
0005435697039	16278	14	4D
0005435697175	16278	15	5A
0005435935038	16278	16	5B
0005435697018	16278	17	5D
0005435696921	16278	18	6A
0005435697069	16278	19	6B
0005435697143	16278	20	6C
0005435696879	16278	21	6D
0005435697055	16278	22	7A
0005435697116	16278	23	7B
0005435935040	16278	24	7C
0005435697103	16278	25	7D
0005435696986	16278	26	18A
0005435697022	16278	27	18B
0005435696993	16278	28	18C
0005435697176	16278	29	18D
0005435696994	16278	30	19A
0005435696938	16278	31	19B
0005435916166	16278	32	19C
0005435697054	16278	33	19D
0005435697121	16278	34	20A
0005435697070	16278	35	20B
0005435697194	16278	36	20C
0005435935041	16278	37	20D
0005435916164	16278	38	21A
0005435697118	16278	39	21B
0005435697193	16278	40	21C
0005435697017	16278	41	21D
0005434950500	16278	42	22A
0005435697056	16278	43	22C
0005434950488	16278	44	22D
0005435697002	16278	45	23A
0005435696944	16278	46	23B
0005434606823	3934	1	1A
0005432609728	3934	2	1B
0005434606825	3934	3	1C
0005434604892	3934	4	1D
0005432607561	3934	5	2B
0005433519453	3934	6	2D
0005434604895	3934	7	3A
0005434606824	3934	8	3C
0005432607564	3934	9	4A
0005434606827	3934	10	4C
0005434606826	3934	11	5A
0005435841470	3934	12	5B
0005432609729	3934	13	5C
0005432609726	3934	14	5D
0005433519455	3934	15	6A
0005434604896	3934	16	6B
0005432607562	3934	17	7A
0005433519452	3934	18	7C
0005433519454	3934	19	18D
0005433519451	3934	20	19A
0005435841461	3934	21	19B
0005434604893	3934	22	20A
0005432609727	3934	23	20C
0005432607565	3934	24	21A
0005435842317	3934	25	21D
0005434604894	3934	26	22D
0005432607563	3934	27	23A
0005433519402	22049	1	1A
0005433519424	22049	2	2A
0005434606774	22049	3	2B
0005433519410	22049	4	2C
0005435853610	22049	5	3C
0005434606787	22049	6	4B
0005434606768	22049	7	5A
0005434606786	22049	8	6C
0005433519409	22049	9	7D
0005435853609	22049	10	19B
0005435853611	22049	11	20A
0005434606769	22049	12	21A
0005434606776	22049	13	21B
0005433519401	22049	14	21D
0005433348926	718	1	1A
0005435628719	718	2	1B
0005433348927	718	3	2A
0005435628723	718	4	2B
0005433348923	718	5	3A
0005435628720	718	6	3B
0005433348942	718	7	4B
0005435628722	718	8	5A
0005433348947	718	9	5B
0005435628721	718	10	6A
0005435628718	718	11	6B
0005435628690	15995	1	1B
0005433348985	15995	2	2A
0005433348984	15995	3	2B
0005435628685	15995	4	3A
0005433348988	15995	5	3B
0005433348986	15995	6	4A
0005435628686	15995	7	4B
0005433348982	15995	8	5B
0005433348983	15995	9	6A
0005433348987	15995	10	6B
0005434446515	17205	1	1A
0005433159283	17205	2	1B
0005434446517	17205	3	2A
0005434445243	17205	4	2B
0005433159284	17205	5	4B
0005434446514	17205	6	5A
0005434446516	17205	7	6A
0005433159285	17205	8	6B
0005433159312	17561	1	1A
0005433159310	17561	2	2A
0005434445222	17561	3	2B
0005434445219	17561	4	3A
0005434445221	17561	5	3B
0005433159313	17561	6	5A
0005433159311	17561	7	5B
0005434445220	17561	8	6B
0005435383088	7882	1	1B
0005435383097	7882	2	1D
0005435132871	7882	3	2A
0005435132868	7882	4	2C
0005435383079	7882	5	2D
0005435132876	7882	6	4B
0005435383081	7882	7	4C
0005435383078	7882	8	4D
0005435132875	7882	9	5B
0005435383080	7882	10	6A
0005435132877	7882	11	6B
0005435383077	7882	12	6D
0005435383096	7882	13	7A
0005435132867	7882	14	7B
0005435132873	7882	15	18A
0005435132869	7882	16	18C
0005435383110	7882	17	18D
0005435383099	7882	18	19B
0005435132872	7882	19	20B
0005435383098	7882	20	20C
0005435132874	7882	21	20D
0005435383104	7882	22	21A
0005435132870	7882	23	21B
0005435383143	33120	1	3D
0005435132823	33120	2	4C
0005435132746	33120	3	5A
0005435132810	33120	4	6D
0005435132747	33120	5	7D
0005435132824	33120	6	18C
0005435132806	33120	7	18D
0005435383144	33120	8	19A
0005435383145	33120	9	19D
0005435383146	33120	10	20C
0005435383147	33120	11	21C
0005435132770	33120	12	22C
0005435132777	33120	13	23B
0005435160292	7490	1	1B
0005435160294	7490	2	1C
0005435390183	7490	3	2A
0005435390185	7490	4	2C
0005435160288	7490	5	2D
0005435160297	7490	6	3B
0005435390190	7490	7	3C
0005435160298	7490	8	4B
0005435160287	7490	9	5B
0005435160291	7490	10	7C
0005435160289	7490	11	18B
0005435160290	7490	12	18C
0005435390197	7490	13	18D
0005435160295	7490	14	19B
0005435390170	7490	15	19C
0005435390168	7490	16	19D
0005435160286	7490	17	20A
0005435160296	7490	18	21A
0005435390167	7490	19	21C
0005435160293	7490	20	21D
0005435390169	7490	21	22B
0005435390230	29546	1	1C
0005435160185	29546	2	1B
0005435390236	29546	3	1D
0005435160196	29546	4	2A
0005435160225	29546	5	2C
0005435390235	29546	6	3C
0005435160154	29546	7	4A
0005435160234	29546	8	4B
0005435390234	29546	9	4C
0005435160153	29546	10	4D
0005435160208	29546	11	5B
0005435390237	29546	12	5C
0005435160266	29546	13	6A
0005435390231	29546	14	6B
0005435160147	29546	15	6D
0005435160210	29546	16	18B
0005435160209	29546	17	19A
0005435160191	29546	18	19B
0005435160186	29546	19	19C
0005435160148	29546	20	20A
0005435160246	29546	21	20B
0005435160238	29546	22	20C
0005435390233	29546	23	21B
0005435390232	29546	24	21D
0005435160211	29546	25	22A
0005435160149	29546	26	23A
0005435178494	18459	1	1A
0005432398155	18459	2	1B
0005432398168	18459	3	2A
0005432398162	18459	4	2B
0005432394053	18459	5	3A
0005432398161	18459	6	3B
0005432398172	18459	7	4A
0005432398160	18459	8	4B
0005432394068	18459	9	5A
0005432398157	18459	10	5B
0005432398171	18459	11	6A
0005432398156	18459	12	6B
0005435179386	27161	1	1A
0005432400116	27161	2	2A
0005435179385	27161	3	2B
0005432398190	27161	4	3A
0005432400117	27161	5	4A
0005432398189	27161	6	3B
0005432400115	27161	7	4B
0005432398191	27161	8	5A
0005435178477	27161	9	5B
0005432400114	27161	10	6A
0005432398188	27161	11	6B
0005432639101	2248	1	1A
0005432639099	2248	2	1C
0005432639131	2248	3	1F
0005432639107	2248	4	2A
0005432865916	2248	5	2C
0005432639094	2248	6	3A
0005432639097	2248	7	3D
0005432639096	2248	8	3F
0005432639106	2248	9	4A
0005432639123	2248	10	4C
0005432865942	2248	11	4F
0005432639114	2248	12	5A
0005432639130	2248	13	5C
0005432865955	2248	14	5D
0005432639105	2248	15	6C
0005432865941	2248	16	6D
0005432639119	2248	17	6E
0005432639110	2248	18	7C
0005432865940	2248	19	7E
0005432639108	2248	20	7F
0005432865931	2248	21	8A
0005432639117	2248	22	8C
0005432865949	2248	23	8F
0005432865956	2248	24	9A
0005432639102	2248	25	9C
0005432865933	2248	26	9D
0005432865918	2248	27	10A
0005432639104	2248	28	10D
0005432865938	2248	29	10F
0005432639116	2248	30	11A
0005432639125	2248	31	11C
0005432639122	2248	32	12C
0005432639115	2248	33	12D
0005432639127	2248	34	12E
0005432639109	2248	35	12F
0005432639112	2248	36	13A
0005432639120	2248	37	13C
0005432639098	2248	38	13E
0005432639111	2248	39	13F
0005432865929	2248	40	14A
0005432865919	2248	41	14C
0005432865920	2248	42	14D
0005432865937	2248	43	14F
0005432639103	2248	44	15A
0005432639129	2248	45	15D
0005432865934	2248	46	16A
0005432639121	2248	47	16D
0005432639093	2248	48	16E
0005432639100	2248	49	17A
0005432865908	2248	50	17D
0005432639118	2248	51	17E
0005432865932	2248	52	17F
0005432639124	2248	53	18C
0005432639113	2248	54	18E
0005432639128	2248	55	18F
0005432865944	2248	56	19A
0005432639126	2248	57	19E
0005432865930	2248	58	19F
0005432865915	2248	59	20A
0005432639095	2248	60	20D
0005432865907	2248	61	20E
0005432865950	2248	62	20F
0005434504104	6560	1	1A
0005435103922	6560	2	1D
0005434504108	6560	3	2A
0005434504117	6560	4	2F
0005434504134	6560	5	3C
0005434504143	6560	6	4A
0005434504105	6560	7	4C
0005434504124	6560	8	4E
0005434504133	6560	9	5A
0005434504137	6560	10	5C
0005434504123	6560	11	5D
0005434504106	6560	12	6C
0005434504125	6560	13	6E
0005434504116	6560	14	6F
0005435103931	6560	15	7D
0005435103930	6560	16	7E
0005434504109	6560	17	7F
0005434504135	6560	18	8C
0005435103929	6560	19	8D
0005434504113	6560	20	8F
0005435103928	6560	21	9E
0005434504111	6560	22	10A
0005435103925	6560	23	10C
0005435103927	6560	24	10D
0005434504128	6560	25	10E
0005434504132	6560	26	10F
0005435103923	6560	27	11D
0005434504136	6560	28	11F
0005434504138	6560	29	12D
0005434504129	6560	30	12E
0005434504130	6560	31	12F
0005434504141	6560	32	14A
0005434504118	6560	33	14C
0005434504120	6560	34	14D
0005434504140	6560	35	14F
0005434504131	6560	36	15A
0005434504127	6560	37	15F
0005435103932	6560	38	16C
0005434504107	6560	39	17A
0005434504142	6560	40	17C
0005434504121	6560	41	17D
0005435103926	6560	42	17E
0005434504139	6560	43	18A
0005434504122	6560	44	18D
0005434504126	6560	45	18E
0005435103924	6560	46	19A
0005434504119	6560	47	19E
0005434504112	6560	48	19F
0005434504114	6560	49	20A
0005434504115	6560	50	20D
0005434504110	6560	51	20E
0005434503662	22679	1	4C
0005434503701	22679	2	4E
0005434503715	22679	3	5A
0005434503554	22679	4	5D
0005434503745	22679	5	5E
0005434503847	22679	6	6D
0005434503714	22679	7	7A
0005434503711	22679	8	7C
0005434503712	22679	9	7D
0005434503546	22679	10	7E
0005434503726	22679	11	7F
0005434503674	22679	12	8F
0005434503768	22679	13	9C
0005434503544	22679	14	9E
0005434503812	22679	15	10A
0005434503622	22679	16	10D
0005434503584	22679	17	10E
0005434503733	22679	18	10F
0005434503767	22679	19	11E
0005434503681	22679	20	11F
0005434503545	22679	21	12A
0005434503854	22679	22	12D
0005434503667	22679	23	12E
0005434503574	22679	24	13D
0005434503644	22679	25	14A
0005434503811	22679	26	14E
0005434503759	22679	27	14F
0005434503619	22679	28	15D
0005434503500	22679	29	15F
0005434503702	22679	30	16A
0005434503651	22679	31	16D
0005434503533	22679	32	16E
0005434503827	22679	33	16F
0005434503645	22679	34	17A
0005434503744	22679	35	17C
0005434503620	22679	36	17E
0005434503718	22679	37	17F
0005434503501	22679	38	18A
0005434503757	22679	39	18D
0005434503846	22679	40	18E
0005434503710	22679	41	19A
0005434503670	22679	42	19E
0005434503697	22679	43	19F
0005434503487	22679	44	20A
0005434503732	22679	45	20D
0005434503661	22679	46	20E
0005435800098	6422	1	1D
0005435800105	6422	2	4D
0005435800099	6422	3	5A
0005435800102	6422	4	5C
0005435800111	6422	5	5D
0005435800101	6422	6	7A
0005435800106	6422	7	7B
0005435800110	6422	8	18C
0005435800108	6422	9	18D
0005435800103	6422	10	19D
0005435800100	6422	11	20B
0005435800107	6422	12	20D
0005435800112	6422	13	21D
0005435800109	6422	14	22C
0005435800104	6422	15	22D
0005433367542	1641	1	1A
0005433367522	1641	2	1C
0005435653011	1641	3	1D
0005433367490	1641	4	1F
0005435653014	1641	5	2C
0005433367494	1641	6	2D
0005433367639	1641	7	2F
0005435653016	1641	8	3A
0005435653015	1641	9	3C
0005435652995	1641	10	3D
0005433367596	1641	11	4A
0005435653003	1641	12	4C
0005435653034	1641	13	4D
0005433367455	1641	14	4E
0005435653040	1641	15	4F
0005435653020	1641	16	5C
0005435652992	1641	17	5D
0005435653017	1641	18	5E
0005433367544	1641	19	6A
0005435653033	1641	20	6C
0005435653005	1641	21	6D
0005435653028	1641	22	6E
0005435653039	1641	23	6F
0005435653002	1641	24	7A
0005433367481	1641	25	7C
0005433367402	1641	26	7D
0005435653009	1641	27	7E
0005435653008	1641	28	7F
0005433367480	1641	29	8A
0005435652998	1641	30	8C
0005433367492	1641	31	8D
0005435653026	1641	32	8E
0005433367427	1641	33	8F
0005433367363	1641	34	9A
0005433367521	1641	35	9C
0005433367573	1641	36	9D
0005433367533	1641	37	9E
0005433367597	1641	38	9F
0005433367493	1641	39	10C
0005433367458	1641	40	10D
0005435653022	1641	41	10E
0005433367508	1641	42	10F
0005435653036	1641	43	11A
0005435652996	1641	44	11C
0005435653013	1641	45	11D
0005433367561	1641	46	11E
0005433367395	1641	47	11F
0005433367545	1641	48	12A
0005433367532	1641	49	12C
0005433367520	1641	50	12D
0005435653010	1641	51	12E
0005435653021	1641	52	12F
0005433367547	1641	53	13A
0005433367509	1641	54	13C
0005435653035	1641	55	13D
0005433367459	1641	56	13E
0005435653007	1641	57	13F
0005433367546	1641	58	14A
0005435653023	1641	59	14C
0005435653029	1641	60	14D
0005435653038	1641	61	14E
0005433367364	1641	62	14F
0005435653037	1641	63	15A
0005433367662	1641	64	15D
0005433367562	1641	65	15E
0005433367663	1641	66	15F
0005435652994	1641	67	16A
0005435653027	1641	68	16C
0005435653004	1641	69	16D
0005435653018	1641	70	16E
0005435652997	1641	71	16F
0005435653000	1641	72	17A
0005433367598	1641	73	17C
0005435653019	1641	74	17D
0005435653006	1641	75	17E
0005433367386	1641	76	17F
0005433367548	1641	77	18A
0005435653032	1641	78	18C
0005435653025	1641	79	18D
0005435652993	1641	80	18E
0005435653001	1641	81	18F
0005435653012	1641	82	19A
0005435653030	1641	83	19C
0005435653031	1641	84	19D
0005433367412	1641	85	19E
0005435653024	1641	86	20C
0005433367489	1641	87	20D
0005435652999	1641	88	20E
0005433367491	1641	89	20F
0005435652477	21699	1	1A
0005435652502	21699	2	1D
0005435652604	21699	3	1F
0005435652402	21699	4	2A
0005433367842	21699	5	2C
0005433367850	21699	6	2D
0005433367841	21699	7	2F
0005435652587	21699	8	3A
0005433367862	21699	9	3F
0005435652572	21699	10	3D
0005435652575	21699	11	4A
0005435652451	21699	12	4C
0005435652503	21699	13	4D
0005435652487	21699	14	4F
0005435652638	21699	15	5A
0005433367857	21699	16	5C
0005435652569	21699	17	5D
0005433367856	21699	18	5E
0005435652476	21699	19	6A
0005433367854	21699	20	6C
0005435652512	21699	21	6D
0005433367837	21699	22	6E
0005433367847	21699	23	6F
0005435652498	21699	24	7A
0005433367838	21699	25	7C
0005435652486	21699	26	7D
0005433367869	21699	27	7E
0005435652438	21699	28	7F
0005433367852	21699	29	8A
0005435652549	21699	30	8C
0005433367846	21699	31	8D
0005433367835	21699	32	8F
0005433367844	21699	33	9A
0005435652527	21699	34	9C
0005433367859	21699	35	9D
0005433367860	21699	36	9E
0005435652504	21699	37	10A
0005435652406	21699	38	10C
0005433367855	21699	39	10D
0005433367868	21699	40	10F
0005433367839	21699	41	11A
0005433367858	21699	42	11C
0005433367836	21699	43	11D
0005433367845	21699	44	11F
0005435652603	21699	45	12A
0005433367870	21699	46	12C
0005435652663	21699	47	12D
0005435652671	21699	48	12E
0005435652500	21699	49	12F
0005435652658	21699	50	13A
0005435652511	21699	51	13C
0005433367843	21699	52	13E
0005433367865	21699	53	13F
0005435652639	21699	54	14C
0005433367853	21699	55	14D
0005435652522	21699	56	14E
0005435652496	21699	57	15A
0005435652407	21699	58	15C
0005435652656	21699	59	15E
0005433367867	21699	60	15F
0005433367840	21699	61	16A
0005435652576	21699	62	16C
0005435652568	21699	63	16D
0005433367848	21699	64	16E
0005433367849	21699	65	16F
0005435652640	21699	66	17C
0005435652530	21699	67	17D
0005433367863	21699	68	17E
0005435652617	21699	69	17F
0005433367864	21699	70	18C
0005435652494	21699	71	18D
0005433367866	21699	72	18F
0005433367834	21699	73	19A
0005435652499	21699	74	19C
0005433367851	21699	75	19E
0005435652642	21699	76	20A
0005433367861	21699	77	20E
0005433367833	21699	78	20F
0005435627113	23806	1	4A
0005435312806	23234	1	1A
0005434466427	23234	2	1D
0005435312804	23234	3	2D
0005434466402	23234	4	3D
0005434466426	23234	5	4B
0005435312802	23234	6	4C
0005434466401	23234	7	5A
0005434466415	23234	8	5B
0005435312805	23234	9	6C
0005434466419	23234	10	6D
0005435312800	23234	11	7B
0005434466416	23234	12	7C
0005435312803	23234	13	7D
0005434466414	23234	14	18C
0005435312801	23234	15	19C
0005434466410	23234	16	20B
0005435312799	23234	17	21C
0005434466429	23234	18	21D
0005434466409	23234	19	22A
0005433985878	4160	1	1A
0005433985909	4160	2	1D
0005433985907	4160	3	1F
0005433985915	4160	4	2A
0005433985895	4160	5	2F
0005433985898	4160	6	3A
0005433985881	4160	7	3C
0005433985890	4160	8	3F
0005433985884	4160	9	4A
0005433985879	4160	10	4D
0005433985889	4160	11	4E
0005433985914	4160	12	4F
0005433985924	4160	13	5A
0005433985901	4160	14	5C
0005433985920	4160	15	5D
0005433985897	4160	16	5E
0005433985888	4160	17	5F
0005435788768	4160	18	6A
0005433985926	4160	19	6C
0005433985925	4160	20	6F
0005433985880	4160	21	7A
0005433985885	4160	22	7E
0005433985908	4160	23	7F
0005433985904	4160	24	8D
0005433985922	4160	25	8F
0005433985917	4160	26	9C
0005433985899	4160	27	9E
0005433985894	4160	28	9F
0005433985918	4160	29	10E
0005433985891	4160	30	11A
0005433985893	4160	31	11E
0005433985916	4160	32	13A
0005433985896	4160	33	13D
0005433985923	4160	34	13E
0005433985883	4160	35	13F
0005433985913	4160	36	14A
0005433985921	4160	37	14C
0005433985905	4160	38	14E
0005433985887	4160	39	15C
0005433985912	4160	40	15F
0005433985886	4160	41	16A
0005433985882	4160	42	17A
0005435788769	4160	43	17F
0005433985902	4160	44	18E
0005433985892	4160	45	19A
0005433985911	4160	46	19E
0005433985910	4160	47	19F
0005433985906	4160	48	20A
0005433985903	4160	49	20C
0005433985900	4160	50	20D
0005433985919	4160	51	20E
0005433985445	25676	1	1A
0005433985483	25676	2	1D
0005433985480	25676	3	1F
0005433985446	25676	4	2A
0005433985262	25676	5	2C
0005433985436	25676	6	3A
0005433985375	25676	7	3F
0005433985412	25676	8	4C
0005433985517	25676	9	4D
0005433985430	25676	10	4F
0005433985324	25676	11	5C
0005435788757	25676	12	5D
0005435788756	25676	13	6E
0005433985490	25676	14	7A
0005433985325	25676	15	7C
0005433985552	25676	16	7D
0005433985572	25676	17	7E
0005433985499	25676	18	7F
0005433985269	25676	19	8A
0005433985586	25676	20	8C
0005433985171	25676	21	8D
0005433985442	25676	22	8E
0005433985420	25676	23	8F
0005433985454	25676	24	9C
0005433985589	25676	25	9D
0005433985482	25676	26	9E
0005433985461	25676	27	10C
0005433985440	25676	28	10D
0005433985465	25676	29	10E
0005433985500	25676	30	11A
0005433985377	25676	31	11D
0005433985441	25676	32	11E
0005433985481	25676	33	11F
0005433985587	25676	34	12D
0005433985214	25676	35	13A
0005433985462	25676	36	13D
0005433985568	25676	37	14A
0005433985576	25676	38	14F
0005433985553	25676	39	15D
0005433985351	25676	40	16A
0005433985421	25676	41	16D
0005433985453	25676	42	16F
0005433985463	25676	43	17A
0005435788739	25676	44	17C
0005433985592	25676	45	17E
0005433985583	25676	46	18A
0005433985383	25676	47	18D
0005433985464	25676	48	19A
0005435788741	25676	49	19C
0005433168364	21317	1	1A
0005434509071	21317	2	1C
0005434509057	21317	3	2A
0005434509085	21317	4	2C
0005433168365	21317	5	3B
0005434509080	21317	6	3C
0005433168370	21317	7	4B
0005434509051	21317	8	5D
0005434509050	21317	9	6A
0005434509099	21317	10	6B
0005434509068	21317	11	6C
0005434509095	21317	12	7A
0005433168369	21317	13	7C
0005433168366	21317	14	18B
0005433168368	21317	15	18C
0005434509105	21317	16	19A
0005434509100	21317	17	19B
0005433168367	21317	18	19D
0005434509056	21317	19	22A
0005434509113	21317	20	22C
0005434509089	21317	21	22D
0005434509079	21317	22	23A
0005433168371	21317	23	23B
0005432658559	17865	1	1C
0005432658569	17865	2	1D
0005434151704	17865	3	1F
0005432661912	17865	4	2A
0005434151706	17865	5	2C
0005432655419	17865	6	2F
0005432660798	17865	7	3A
0005432658571	17865	8	3D
0005432655418	17865	9	3C
0005432655470	17865	10	4D
0005432655371	17865	11	4F
0005432655417	17865	12	5A
0005432869521	17865	13	5C
0005432663014	17865	14	5D
0005432655362	17865	15	5E
0005432655406	17865	16	5F
0005432665252	17865	17	6A
0005432655361	17865	18	6C
0005432664127	17865	19	6E
0005432655431	17865	20	6F
0005432655390	17865	21	7A
0005432869525	17865	22	7C
0005432655393	17865	23	7E
0005432665255	17865	24	7F
0005432658558	17865	25	8C
0005432663013	17865	26	8D
0005432665257	17865	27	10A
0005432658570	17865	28	10C
0005432655360	17865	29	10F
0005432655405	17865	30	11C
0005432655469	17865	31	11D
0005432658573	17865	32	11E
0005434151705	17865	33	11F
0005432869522	17865	34	12E
0005432666370	17865	35	12F
0005432658575	17865	36	14A
0005432655370	17865	37	14C
0005432869524	17865	38	14D
0005432869519	17865	39	14E
0005432658574	17865	40	15C
0005432655452	17865	41	15E
0005432667429	17865	42	15F
0005434151703	17865	43	16A
0005432664113	17865	44	16C
0005432661909	17865	45	16D
0005432665256	17865	46	17C
0005432666371	17865	47	17D
0005432869523	17865	48	17E
0005432655430	17865	49	17F
0005432655394	17865	50	18E
0005434151702	17865	51	19E
0005432869520	17865	52	20C
0005432655432	17865	53	20E
0005434151673	26297	1	1F
0005434151672	26297	2	3C
0005432657443	26297	3	4A
0005432666384	26297	4	4C
0005432869461	26297	5	4D
0005432655499	26297	6	4F
0005432665270	26297	7	5C
0005434151667	26297	8	5E
0005432657442	26297	9	6A
0005432869447	26297	10	6C
0005432655504	26297	11	6D
0005432667450	26297	12	6E
0005432655506	26297	13	7A
0005432655503	26297	14	7E
0005432667449	26297	15	8F
0005432665269	26297	16	9C
0005432655505	26297	17	9D
0005432655497	26297	18	9E
0005432658586	26297	19	9F
0005432655501	26297	20	10D
0005432655507	26297	21	10F
0005432658585	26297	22	11D
0005432660813	26297	23	11E
0005432657444	26297	24	11F
0005432869426	26297	25	12C
0005432660812	26297	26	12D
0005432655508	26297	27	12E
0005432658587	26297	28	14A
0005432869462	26297	29	14C
0005432869463	26297	30	14E
0005432660814	26297	31	14F
0005432655500	26297	32	15C
0005432667448	26297	33	15E
0005432659701	26297	34	16A
0005432659702	26297	35	16C
0005432666383	26297	36	16E
0005432655498	26297	37	17C
0005432657441	26297	38	17E
0005432655502	26297	39	18A
0005432869452	26297	40	19A
0005432665271	26297	41	19D
0005432869448	26297	42	19F
0005432328667	3087	1	1A
0005432328671	3087	2	1C
0005433438874	3087	3	1F
0005432328664	3087	4	2A
0005432287186	3087	5	2D
0005432328642	3087	6	2F
0005433438875	3087	7	3D
0005432905087	3087	8	3F
0005432905092	3087	9	4A
0005432328643	3087	10	4C
0005432328666	3087	11	4D
0005432328668	3087	12	4E
0005432328660	3087	13	4F
0005432328682	3087	14	5D
0005432328678	3087	15	5E
0005432328654	3087	16	6A
0005432905069	3087	17	6C
0005432328674	3087	18	6D
0005432328677	3087	19	6E
0005432328645	3087	20	6F
0005432905040	3087	21	7A
0005432328657	3087	22	7E
0005432287185	3087	23	7F
0005432328665	3087	24	8C
0005432328679	3087	25	8D
0005432328655	3087	26	8E
0005432328662	3087	27	9C
0005432905055	3087	28	10C
0005433438877	3087	29	10E
0005432287184	3087	30	11A
0005432328652	3087	31	11D
0005432328644	3087	32	11E
0005432328670	3087	33	12D
0005432287187	3087	34	12E
0005433438871	3087	35	12F
0005432328683	3087	36	13A
0005432328663	3087	37	13C
0005432328681	3087	38	13D
0005432328651	3087	39	13F
0005432328656	3087	40	14C
0005432328686	3087	41	14D
0005432328661	3087	42	14E
0005432328687	3087	43	14F
0005432328647	3087	44	15A
0005433438873	3087	45	15C
0005433438876	3087	46	15E
0005432905068	3087	47	16A
0005432328653	3087	48	16C
0005432328649	3087	49	16D
0005432328675	3087	50	16F
0005432328646	3087	51	17A
0005432328648	3087	52	17E
0005433438872	3087	53	17F
0005432328673	3087	54	18A
0005432328676	3087	55	18C
0005432328680	3087	56	18D
0005432328672	3087	57	19A
0005432328650	3087	58	19D
0005432328669	3087	59	19E
0005432328684	3087	60	19F
0005432328659	3087	61	20A
0005432328688	3087	62	20C
0005432328685	3087	63	20D
0005432905091	3087	64	20F
0005432328658	3087	65	20E
0005432905118	31123	1	1A
0005432054302	31123	2	1C
0005432328229	31123	3	1D
0005432905124	31123	4	1F
0005433438813	31123	5	2A
0005432328187	31123	6	2C
0005432328306	31123	7	3D
0005432905120	31123	8	3F
0005432905123	31123	9	4C
0005432905117	31123	10	4E
0005433438814	31123	11	4F
0005432328384	31123	12	5A
0005432905121	31123	13	5D
0005432328102	31123	14	5E
0005432328139	31123	15	5F
0005432328173	31123	16	6A
0005432328304	31123	17	6E
0005432328199	31123	18	7D
0005432328288	31123	19	7C
0005433438792	31123	20	7E
0005432328200	31123	21	7F
0005432054300	31123	22	8C
0005433438831	31123	23	8D
0005432328138	31123	24	8E
0005432328305	31123	25	9A
0005432328171	31123	26	9C
0005432905122	31123	27	9E
0005432328198	31123	28	10C
0005432054301	31123	29	10F
0005432328315	31123	30	11A
0005432328214	31123	31	11D
0005432328119	31123	32	11E
0005432328244	31123	33	12A
0005433438822	31123	34	12D
0005432328159	31123	35	12E
0005433438793	31123	36	12F
0005432328286	31123	37	13C
0005433438835	31123	38	13E
0005432328158	31123	39	13F
0005432328177	31123	40	14D
0005432328208	31123	41	14E
0005432328243	31123	42	15C
0005432328172	31123	43	16A
0005432328160	31123	44	16C
0005432328201	31123	45	16F
0005432328203	31123	46	17A
0005432328178	31123	47	17C
0005432328205	31123	48	17D
0005432328176	31123	49	17E
0005433438818	31123	50	17F
0005432328213	31123	51	18C
0005433438772	31123	52	18F
0005432328303	31123	53	19C
0005432328285	31123	54	20A
0005432905119	31123	55	20D
0005432328329	31123	56	20E
0005432327920	31123	57	20F
0005435487612	6213	1	1D
0005434309731	6213	2	2A
0005435296982	6213	3	2C
0005432146198	6213	4	2D
0005435487590	6213	5	3A
0005434309725	6213	6	3C
0005435999246	6213	7	4A
0005435487587	6213	8	4B
0005435487611	6213	9	4D
0005435487658	6213	10	5C
0005434309728	6213	11	5E
0005435999240	6213	12	6A
0005435487554	6213	13	6B
0005435487657	6213	14	7C
0005435487505	6213	15	7E
0005435487656	6213	16	8A
0005435487647	6213	17	8C
0005435487632	6213	18	8B
0005435296979	6213	19	8F
0005435296981	6213	20	9A
0005432146197	6213	21	9B
0005434309730	6213	22	9E
0005435999243	6213	23	10B
0005435487581	6213	24	10D
0005434309736	6213	25	11B
0005434309726	6213	26	11C
0005435999248	6213	27	11F
0005435297003	6213	28	12B
0005435999239	6213	29	12F
0005432146196	6213	30	13B
0005435487582	6213	31	13A
0005435487625	6213	32	13C
0005435487639	6213	33	13E
0005435487580	6213	34	14A
0005435487650	6213	35	14C
0005435487604	6213	36	14D
0005435999237	6213	37	15A
0005435487555	6213	38	15C
0005435487605	6213	39	15B
0005435296983	6213	40	15D
0005435999238	6213	41	15F
0005435999244	6213	42	15E
0005434309729	6213	43	16A
0005435487626	6213	44	16C
0005434309735	6213	45	16D
0005435297002	6213	46	16E
0005435487624	6213	47	17C
0005434309733	6213	48	18C
0005435999236	6213	49	18E
0005434309727	6213	50	18D
0005435487556	6213	51	19B
0005434309732	6213	52	19C
0005435487600	6213	53	19E
0005435999242	6213	54	19F
0005435999245	6213	55	20A
0005435487586	6213	56	20E
0005435487683	6213	57	20F
0005435999241	6213	58	21B
0005435487631	6213	59	21A
0005435487579	6213	60	22A
0005435487552	6213	61	22C
0005434309737	6213	62	22B
0005435999247	6213	63	23E
0005434309734	6213	64	23F
0005435999011	19555	1	1A
0005435487789	19555	2	1D
0005435999006	19555	3	2A
0005435999029	19555	4	2C
0005435487802	19555	5	2F
0005435487805	19555	6	3C
0005434309598	19555	7	3D
0005435487804	19555	8	3F
0005435999043	19555	9	4A
0005434309620	19555	10	4E
0005435297053	19555	11	5A
0005435487803	19555	12	5C
0005435487793	19555	13	5D
0005435487788	19555	14	5F
0005435487786	19555	15	6A
0005435999071	19555	16	7B
0005434309621	19555	17	7C
0005434309634	19555	18	7E
0005434309592	19555	19	8C
0005435487794	19555	20	9A
0005435999072	19555	21	9D
0005435487795	19555	22	9F
0005435487792	19555	23	11A
0005435297056	19555	24	11B
0005435487801	19555	25	11C
0005435297054	19555	26	11E
0005434309622	19555	27	12B
0005435999033	19555	28	12C
0005435999034	19555	29	12E
0005435999084	19555	30	12F
0005435999076	19555	31	13B
0005435999012	19555	32	13A
0005435487796	19555	33	13C
0005435487806	19555	34	13F
0005435999061	19555	35	14B
0005435487799	19555	36	14C
0005434309594	19555	37	14E
0005435487807	19555	38	14F
0005435999030	19555	39	16C
0005435999068	19555	40	16F
0005434309591	19555	41	17D
0005435297051	19555	42	17E
0005435999085	19555	43	18B
0005435487787	19555	44	18D
0005434309557	19555	45	19A
0005435487790	19555	46	19B
0005435297055	19555	47	19C
0005435487800	19555	48	20A
0005435487797	19555	49	20C
0005435999005	19555	50	20B
0005435297050	19555	51	20D
0005435999056	19555	52	20E
0005435297052	19555	53	20F
0005435487791	19555	54	21B
0005435999007	19555	55	21D
0005435998984	19555	56	21E
0005434309635	19555	57	22A
0005435999060	19555	58	22B
0005434309624	19555	59	22C
0005434309595	19555	60	22D
0005435487798	19555	61	23A
0005434309573	19555	62	23C
0005434309651	19555	63	23B
0005435999046	19555	64	23D
0005435999062	19555	65	23F
0005433158129	17549	1	1B
0005433158130	17549	2	5A
0005434446490	17549	3	5B
0005434446501	17549	4	7C
0005433158128	17549	5	18A
0005435502295	1585	1	1A
0005432291928	1585	2	1C
0005435502301	1585	3	1D
0005435508362	1585	4	1F
0005435517912	1585	5	2A
0005433186046	1585	6	2C
0005433186043	1585	7	2D
0005433186069	1585	8	2F
0005434565904	1585	9	3C
0005435517906	1585	10	3F
0005435517914	1585	11	4A
0005434565910	1585	12	4D
0005435502300	1585	13	4E
0005435502293	1585	14	4F
0005432291929	1585	15	5A
0005435508363	1585	16	5C
0005435508361	1585	17	5D
0005435502304	1585	18	5E
0005433186027	1585	19	5F
0005433186045	1585	20	6A
0005435502292	1585	21	6C
0005435502291	1585	22	6D
0005433186042	1585	23	6E
0005435508366	1585	24	6F
0005435502303	1585	25	7A
0005435508355	1585	26	7C
0005435517903	1585	27	7D
0005435508364	1585	28	7E
0005435517908	1585	29	7F
0005435517902	1585	30	8A
0005434565900	1585	31	8C
0005435502302	1585	32	8D
0005435508354	1585	33	8F
0005435517910	1585	34	9A
0005435517911	1585	35	9C
0005435502298	1585	36	9D
0005435517899	1585	37	9E
0005435502287	1585	38	10A
0005435517916	1585	39	10C
0005435517901	1585	40	10E
0005434565901	1585	41	10F
0005435502299	1585	42	11A
0005435508352	1585	43	11D
0005435517904	1585	44	11E
0005435508356	1585	45	11F
0005435502307	1585	46	12A
0005435508360	1585	47	12C
0005435508358	1585	48	12D
0005435517915	1585	49	12F
0005434565907	1585	50	13A
0005433186038	1585	51	13C
0005435502289	1585	52	13D
0005434565903	1585	53	14A
0005435517917	1585	54	14C
0005434565909	1585	55	14D
0005435517898	1585	56	14E
0005433186070	1585	57	14F
0005435502294	1585	58	15A
0005433186068	1585	59	15C
0005434565899	1585	60	15D
0005435508353	1585	61	15E
0005435502286	1585	62	15F
0005435502305	1585	63	16C
0005434565908	1585	64	16D
0005435517909	1585	65	16E
0005435508357	1585	66	16F
0005435508359	1585	67	17A
0005435517905	1585	68	17D
0005435517900	1585	69	17E
0005434565902	1585	70	17F
0005435517907	1585	71	18A
0005435502297	1585	72	18C
0005434565906	1585	73	18D
0005434565905	1585	74	18E
0005435508365	1585	75	19A
0005435502288	1585	76	19C
0005435502290	1585	77	19D
0005433186037	1585	78	19E
0005435517897	1585	79	19F
0005435517913	1585	80	20A
0005435502296	1585	81	20C
0005435502306	1585	82	20D
0005435517896	1585	83	20F
0005435528998	20866	1	1A
0005433186111	20866	2	1D
0005435502077	20866	3	1F
0005435501993	20866	4	2A
0005435502104	20866	5	2C
0005435502039	20866	6	2F
0005435501994	20866	7	3A
0005435545641	20866	8	3C
0005434565781	20866	9	3D
0005435502086	20866	10	3F
0005434565816	20866	11	4A
0005435529002	20866	12	4C
0005435502058	20866	13	4F
0005435528992	20866	14	5A
0005435502082	20866	15	5C
0005434565817	20866	16	5D
0005435528905	20866	17	5E
0005435502174	20866	18	5F
0005433186116	20866	19	6C
0005435529016	20866	20	6D
0005435502073	20866	21	6E
0005435529026	20866	22	6F
0005434565774	20866	23	7C
0005435502076	20866	24	7D
0005435545639	20866	25	7E
0005435528960	20866	26	7F
0005434565815	20866	27	8C
0005434565833	20866	28	8D
0005434565818	20866	29	8E
0005434565773	20866	30	8F
0005435502055	20866	31	9A
0005435529025	20866	32	9C
0005435502038	20866	33	9D
0005434565839	20866	34	9E
0005435502147	20866	35	9F
0005435528976	20866	36	10A
0005434565771	20866	37	10E
0005435545624	20866	38	10F
0005434565782	20866	39	11A
0005433186112	20866	40	11C
0005434565834	20866	41	11D
0005435528957	20866	42	11E
0005435529082	20866	43	11F
0005434565854	20866	44	12A
0005435502032	20866	45	12C
0005435502152	20866	46	12E
0005434565820	20866	47	12F
0005435502054	20866	48	13A
0005433186113	20866	49	13C
0005435528906	20866	50	13E
0005435529068	20866	51	13F
0005435528904	20866	52	14A
0005435528977	20866	53	14C
0005435545638	20866	54	14D
0005434565734	20866	55	14E
0005433186114	20866	56	15A
0005433186115	20866	57	15C
0005434565780	20866	58	15D
0005434565754	20866	59	15E
0005433186110	20866	60	15F
0005434565792	20866	61	16A
0005435502030	20866	62	16C
0005433186109	20866	63	16E
0005435502017	20866	64	16F
0005434565800	20866	65	17A
0005435502095	20866	66	17C
0005435502103	20866	67	17D
0005435502031	20866	68	17E
0005435502151	20866	69	17F
0005435502064	20866	70	18C
0005433186108	20866	71	18E
0005435502087	20866	72	18F
0005435502078	20866	73	19A
0005435502153	20866	74	19C
0005435502056	20866	75	19D
0005435529024	20866	76	19E
0005434565791	20866	77	19F
0005434565819	20866	78	20A
0005435529074	20866	79	20C
0005435529008	20866	80	20D
0005435502057	20866	81	20E
0005435931571	3897	1	1C
0005435153736	3897	2	2B
0005435931572	3897	3	2C
0005435931577	3897	4	2D
0005435153739	3897	5	3B
0005435931576	3897	6	5C
0005435153737	3897	7	5D
0005435931556	3897	8	6B
0005435931569	3897	9	7B
0005435931570	3897	10	7C
0005435153735	3897	11	19B
0005435153734	3897	12	20A
0005435153738	3897	13	22B
0005435931575	3897	14	23B
0005435931599	21864	1	2D
0005435153676	21864	2	3A
0005435931596	21864	3	4A
0005435931597	21864	4	4D
0005435153671	21864	5	6B
0005435153674	21864	6	6C
0005435931598	21864	7	7C
0005435153701	21864	8	18A
0005435153680	21864	9	19C
0005435153665	21864	10	19D
0005435153675	21864	11	20A
0005432628838	7227	1	1A
0005432628829	7227	2	1C
0005432628832	7227	3	1D
0005435225520	7227	4	2D
0005435225550	7227	5	3A
0005432628830	7227	6	3B
0005432628834	7227	7	3C
0005435225501	7227	8	4A
0005435225500	7227	9	4B
0005432628833	7227	10	4C
0005432628841	7227	11	4D
0005432628835	7227	12	5A
0005432628837	7227	13	5B
0005435225482	7227	14	5C
0005432628836	7227	15	6A
0005435225528	7227	16	6B
0005432628840	7227	17	6C
0005435225488	7227	18	6D
0005435225513	7227	19	7A
0005435225503	7227	20	7B
0005435225523	7227	21	7C
0005435225494	7227	22	7D
0005435225519	7227	23	18B
0005432628842	7227	24	18C
0005432628828	7227	25	18D
0005435225551	7227	26	19B
0005435225552	7227	27	19C
0005435225484	7227	28	19D
0005432628831	7227	29	20B
0005435225527	7227	30	20C
0005435225522	7227	31	20D
0005432628843	7227	32	21A
0005435225497	7227	33	21C
0005435225515	7227	34	21D
0005435225495	7227	35	22A
0005435225504	7227	36	22C
0005432628839	7227	37	23A
0005435225580	28123	1	1B
0005432628767	28123	2	2B
0005435225579	28123	3	2D
0005435225577	28123	4	3A
0005432628685	28123	5	4A
0005435225576	28123	6	6B
0005432628702	28123	7	6C
0005435225575	28123	8	7A
0005432628679	28123	9	7C
0005432628768	28123	10	7D
0005432628744	28123	11	18A
0005432628703	28123	12	19C
0005435225578	28123	13	20A
0005432628743	28123	14	20B
0005435225574	28123	15	21D
0005435225581	28123	16	22A
0005432628687	28123	17	22B
0005434267903	8755	1	1A
0005434267926	8755	2	2A
0005434267911	8755	3	4B
0005435960047	8755	4	5A
0005434267893	8755	5	6A
0005435960048	8755	6	6C
0005434267927	8755	7	18D
0005434267902	8755	8	21A
0005434267912	8755	9	22D
0005434267947	15239	1	1D
0005435960023	15239	2	2D
0005435960017	15239	3	5A
0005435960018	15239	4	5D
0005434267946	15239	5	18A
0005434267948	15239	6	19C
0005435960010	15239	7	19D
0005435960024	15239	8	20D
0005435960019	15239	9	23B
0005432675123	1182	1	1F
0005432693005	1182	2	2F
0005432873232	1182	3	3D
0005432873230	1182	4	3C
0005432675112	1182	5	4D
0005432693031	1182	6	5C
0005432693006	1182	7	5A
0005432693021	1182	8	5F
0005432693018	1182	9	6A
0005432693017	1182	10	7A
0005432675118	1182	11	7B
0005432693014	1182	12	7E
0005432675115	1182	13	8B
0005432675111	1182	14	8A
0005432675116	1182	15	8E
0005432693027	1182	16	9B
0005432693002	1182	17	9A
0005432873240	1182	18	9D
0005432675126	1182	19	9E
0005432693022	1182	20	9F
0005432675114	1182	21	11A
0005432693028	1182	22	10F
0005432873239	1182	23	11D
0005432675124	1182	24	11C
0005432677565	1182	25	11F
0005432693026	1182	26	12D
0005432675117	1182	27	12C
0005432873209	1182	28	12F
0005432693009	1182	29	13B
0005432677567	1182	30	13F
0005432693008	1182	31	14B
0005432677566	1182	32	14A
0005432693019	1182	33	14D
0005432675125	1182	34	15D
0005432693030	1182	35	15F
0005432693004	1182	36	15E
0005432693016	1182	37	16C
0005432693025	1182	38	16D
0005432693013	1182	39	17B
0005432693015	1182	40	17A
0005432675119	1182	41	17D
0005432693001	1182	42	18A
0005432693007	1182	43	18B
0005432675122	1182	44	18E
0005432693024	1182	45	18D
0005432693010	1182	46	19B
0005432693029	1182	47	19F
0005432693003	1182	48	19E
0005432873233	1182	49	20A
0005432693020	1182	50	20D
0005432675121	1182	51	20C
0005432693023	1182	52	20F
0005432675113	1182	53	20E
0005432675120	1182	54	21B
0005432677564	1182	55	21F
0005432693011	1182	56	21E
0005432693012	1182	57	21D
0005432692794	17492	1	1C
0005432692729	17492	2	1F
0005432692804	17492	3	2A
0005432677540	17492	4	2D
0005432692755	17492	5	3A
0005432674953	17492	6	2F
0005432692768	17492	7	3C
0005432674969	17492	8	4F
0005432675014	17492	9	5A
0005432692737	17492	10	5F
0005432692734	17492	11	6A
0005432873289	17492	12	6C
0005432692836	17492	13	6E
0005432692847	17492	14	8A
0005432675008	17492	15	8D
0005432675013	17492	16	9B
0005432692759	17492	17	9A
0005432873284	17492	18	9C
0005432677534	17492	19	10A
0005432674968	17492	20	9F
0005432675012	17492	21	10C
0005432873288	17492	22	10E
0005432692718	17492	23	10F
0005432674947	17492	24	11B
0005432692793	17492	25	11E
0005432873286	17492	26	11D
0005432692695	17492	27	11F
0005432692741	17492	28	12B
0005432692730	17492	29	13A
0005432692726	17492	30	13B
0005432674932	17492	31	13E
0005432692792	17492	32	13D
0005432873282	17492	33	13F
0005432692868	17492	34	14C
0005432692770	17492	35	14F
0005432873290	17492	36	15A
0005432873285	17492	37	16A
0005432675009	17492	38	16C
0005432692760	17492	39	16B
0005432692772	17492	40	16F
0005432692776	17492	41	16E
0005432692869	17492	42	17C
0005432674927	17492	43	17B
0005432692810	17492	44	17A
0005432692727	17492	45	17F
0005432692671	17492	46	17E
0005432692757	17492	47	18C
0005432692754	17492	48	18E
0005432674952	17492	49	19A
0005432692788	17492	50	18F
0005432692767	17492	51	19D
0005432692687	17492	52	19F
0005432873287	17492	53	20B
0005432692769	17492	54	20D
0005432677541	17492	55	20C
0005432692771	17492	56	20F
0005432677520	17492	57	20E
0005432692725	17492	58	21A
0005432873283	17492	59	21D
0005434435175	1147	1	1A
0005433156672	1147	2	2B
0005434435161	1147	3	3B
0005434435174	1147	4	3C
0005433156671	1147	5	3D
0005434435167	1147	6	4C
0005434435168	1147	7	4D
0005434435162	1147	8	5A
0005434435171	1147	9	5C
0005434435173	1147	10	6A
0005434435166	1147	11	6C
0005433156677	1147	12	7A
0005434435164	1147	13	7D
0005434435165	1147	14	18D
0005434435163	1147	15	19D
0005433156675	1147	16	20A
0005434435170	1147	17	20B
0005433156670	1147	18	20D
0005434435169	1147	19	21C
0005434435172	1147	20	22B
0005433156707	1147	21	22C
0005434435176	1147	22	22D
0005433156692	1147	23	23B
0005433156741	17292	1	1A
0005433156744	17292	2	2B
0005433156742	17292	3	2C
0005434435039	17292	4	2D
0005433156739	17292	5	3B
0005434435040	17292	6	3D
0005434434992	17292	7	4B
0005434435035	17292	8	4A
0005434435041	17292	9	5D
0005434435036	17292	10	6A
0005434435054	17292	11	6C
0005434434993	17292	12	6D
0005433156746	17292	13	7A
0005433156740	17292	14	7B
0005434435059	17292	15	7C
0005433156745	17292	16	18B
0005434435033	17292	17	18A
0005434435050	17292	18	19A
0005434435049	17292	19	19B
0005434435056	17292	20	20A
0005434435055	17292	21	20B
0005434435037	17292	22	21A
0005434435062	17292	23	21C
0005434435064	17292	24	21D
0005433156743	17292	25	22B
0005433156747	17292	26	22C
0005434434991	17292	27	23B
0005435086824	4055	1	1A
0005435928108	4055	2	2A
0005435086826	4055	3	2C
0005435086831	4055	4	2D
0005435928109	4055	5	5B
0005435086830	4055	6	18B
0005435928094	4055	7	19A
0005435086829	4055	8	19D
0005435928110	4055	9	20B
0005435086828	4055	10	22A
0005435086825	4055	11	22C
0005435086827	4055	12	22D
0005435086755	24392	1	1B
0005435086773	24392	2	2A
0005435086772	24392	3	3A
0005435086731	24392	4	5A
0005435928136	24392	5	5B
0005435086732	24392	6	5C
0005435086765	24392	7	5D
0005435086736	24392	8	6A
0005435086758	24392	9	6C
0005435086764	24392	10	7A
0005435086741	24392	11	7D
0005435928137	24392	12	18A
0005435086740	24392	13	18D
0005435086735	24392	14	19B
0005435928139	24392	15	19D
0005435928138	24392	16	20A
0005435086787	24392	17	20C
0005435928140	24392	18	21A
0005435706362	2448	1	1C
0005433373427	2448	2	1D
0005435706364	2448	3	1F
0005433373459	2448	4	2A
0005433373448	2448	5	2C
0005433373422	2448	6	2F
0005435706359	2448	7	3A
0005435706335	2448	8	3C
0005433373484	2448	9	3D
0005433373430	2448	10	3F
0005435706356	2448	11	4A
0005435706372	2448	12	4C
0005435706363	2448	13	4D
0005433373449	2448	14	4F
0005433373420	2448	15	5A
0005435706340	2448	16	5D
0005433373434	2448	17	5F
0005435706366	2448	18	6A
0005435706361	2448	19	6C
0005435706375	2448	20	6D
0005435706355	2448	21	6E
0005435706368	2448	22	6F
0005433373379	2448	23	7A
0005435706351	2448	24	7D
0005435706334	2448	25	7E
0005435706369	2448	26	7F
0005433373453	2448	27	8A
0005435706367	2448	28	8C
0005435706330	2448	29	8E
0005435706333	2448	30	8F
0005435706379	2448	31	9A
0005435706376	2448	32	9C
0005435706358	2448	33	9D
0005433373400	2448	34	9F
0005435706352	2448	35	10A
0005435706360	2448	36	10C
0005435706332	2448	37	10D
0005433373468	2448	38	10E
0005433373440	2448	39	10F
0005435706345	2448	40	11C
0005433373385	2448	41	11D
0005435706339	2448	42	11E
0005435706337	2448	43	11F
0005433373416	2448	44	12E
0005435706336	2448	45	12F
0005435706380	2448	46	13A
0005435706331	2448	47	13C
0005435706370	2448	48	13D
0005435706343	2448	49	13E
0005435706378	2448	50	13F
0005435706349	2448	51	14A
0005435706344	2448	52	14C
0005433373461	2448	53	14D
0005435706338	2448	54	14E
0005435706347	2448	55	14F
0005435706357	2448	56	15A
0005433373460	2448	57	15C
0005433373433	2448	58	15D
0005433373431	2448	59	15E
0005435706371	2448	60	15F
0005433373428	2448	61	16A
0005433373450	2448	62	16C
0005435706342	2448	63	16D
0005435706346	2448	64	16E
0005433373466	2448	65	16F
0005433373469	2448	66	17A
0005435706354	2448	67	17C
0005435706373	2448	68	17D
0005435706348	2448	69	17E
0005433373467	2448	70	17F
0005433373399	2448	71	18A
0005433373387	2448	72	18C
0005433373454	2448	73	18D
0005433373442	2448	74	18E
0005435706341	2448	75	18F
0005435706350	2448	76	19A
0005433373445	2448	77	19C
0005435706353	2448	78	19D
0005433373421	2448	79	19E
0005435706365	2448	80	20A
0005435706377	2448	81	20C
0005435706374	2448	82	20D
0005433373386	2448	83	20E
0005433373438	2448	84	20F
0005435706235	27037	1	1A
0005433373515	27037	2	1C
0005435706161	27037	3	1D
0005435706194	27037	4	1F
0005433373511	27037	5	2A
0005433373524	27037	6	2C
0005435706225	27037	7	2F
0005435706138	27037	8	3A
0005433373513	27037	9	3C
0005435706262	27037	10	3D
0005433373506	27037	11	3F
0005435706239	27037	12	4A
0005433373505	27037	13	4C
0005435706222	27037	14	4D
0005435706174	27037	15	4E
0005435706215	27037	16	4F
0005435706157	27037	17	5A
0005435706249	27037	18	5C
0005435706227	27037	19	5D
0005433373529	27037	20	5F
0005435706213	27037	21	6A
0005435706185	27037	22	6D
0005435706203	27037	23	6F
0005433373530	27037	24	7A
0005433373531	27037	25	7C
0005433373508	27037	26	7D
0005435706256	27037	27	7E
0005433373509	27037	28	7F
0005435706224	27037	29	8A
0005435706199	27037	30	8C
0005435706173	27037	31	8D
0005435706214	27037	32	8E
0005435706188	27037	33	8F
0005435706148	27037	34	9A
0005435706238	27037	35	9C
0005435706250	27037	36	9D
0005435706226	27037	37	9E
0005433373527	27037	38	9F
0005433373516	27037	39	10A
0005435706158	27037	40	10C
0005435706206	27037	41	10D
0005435706176	27037	42	10E
0005433373504	27037	43	10F
0005433373528	27037	44	11D
0005435706160	27037	45	11E
0005433373512	27037	46	12A
0005435706236	27037	47	12C
0005433373518	27037	48	12D
0005435706163	27037	49	12E
0005435706184	27037	50	12F
0005433373520	27037	51	13A
0005435706192	27037	52	13C
0005435706197	27037	53	13D
0005433373523	27037	54	13E
0005435706202	27037	55	13F
0005435706255	27037	56	14C
0005433373507	27037	57	14D
0005435706149	27037	58	14E
0005433373510	27037	59	15A
0005435706283	27037	60	15C
0005435706164	27037	61	15D
0005433373514	27037	62	15E
0005435706198	27037	63	15F
0005433373519	27037	64	16A
0005435706159	27037	65	16C
0005435706207	27037	66	16D
0005435706196	27037	67	16E
0005433373526	27037	68	16F
0005435706183	27037	69	17A
0005435706210	27037	70	17C
0005433373517	27037	71	17D
0005435706247	27037	72	17E
0005433373521	27037	73	17F
0005435706212	27037	74	18A
0005433373522	27037	75	18E
0005435706223	27037	76	18F
0005435706162	27037	77	19A
0005435706201	27037	78	19D
0005433373525	27037	79	19E
0005435706204	27037	80	20A
0005435706167	27037	81	20E
0005435907461	4842	1	2A
0005435907456	4842	2	2D
0005435907457	4842	3	3A
0005434625952	4842	4	3F
0005435907427	4842	5	4C
0005434625955	4842	6	5A
0005434625957	4842	7	6D
0005435907435	4842	8	7D
0005434625953	4842	9	8E
0005434625951	4842	10	10C
0005435907455	4842	11	11C
0005435907434	4842	12	14F
0005434625950	4842	13	15D
0005435907472	4842	14	16C
0005435907454	4842	15	17F
0005434625954	4842	16	18A
0005435907426	4842	17	19A
0005434625956	4842	18	19E
0005434625949	4842	19	20C
0005435907504	32894	1	2A
0005435907505	32894	2	2F
0005434625876	32894	3	3D
0005434625878	32894	4	6A
0005435907503	32894	5	6E
0005434625920	32894	6	7D
0005434625877	32894	7	9C
0005434625874	32894	8	10D
0005434625885	32894	9	13C
0005434625886	32894	10	13E
0005435907502	32894	11	14A
0005434625879	32894	12	14C
0005434625921	32894	13	15E
0005435785081	13753	1	1A
0005435784882	13753	2	1B
0005435937388	13753	3	1C
0005435784801	13753	4	2A
0005435937387	13753	5	2B
0005435787329	13753	6	2C
0005435784843	13753	7	2D
0005435784866	13753	8	3A
0005435784939	13753	9	3B
0005435784959	13753	10	3C
0005435784865	13753	11	3D
0005435784867	13753	12	4A
0005435785065	13753	13	4B
0005435784864	13753	14	4D
0005435784764	13753	15	5A
0005435937384	13753	16	5C
0005435785021	13753	17	5B
0005435784974	13753	18	5D
0005435784827	13753	19	6A
0005435937383	13753	20	6B
0005435937385	13753	21	6C
0005435785020	13753	22	6D
0005435784942	13753	23	7A
0005435785115	13753	24	7B
0005435785019	13753	25	7C
0005435785082	13753	26	18A
0005435784976	13753	27	18B
0005435784977	13753	28	18C
0005435785016	13753	29	18D
0005435785002	13753	30	19A
0005435785033	13753	31	19B
0005435937386	13753	32	19C
0005435784985	13753	33	19D
0005435784963	13753	34	20A
0005435784978	13753	35	20B
0005435785077	13753	36	20C
0005435784839	13753	37	20D
0005435784975	13753	38	21A
0005435784998	13753	39	21B
0005435784958	13753	40	21D
0005435785011	13753	41	22D
0005435784922	13753	42	23B
0005435785292	27408	1	1A
0005435787349	27408	2	1B
0005435785259	27408	3	1D
0005435785288	27408	4	2A
0005435785270	27408	5	2C
0005435785265	27408	6	2D
0005435785262	27408	7	3A
0005432190619	27408	8	3B
0005435785287	27408	9	4A
0005435785263	27408	10	4C
0005432190620	27408	11	4D
0005435785282	27408	12	5A
0005435785291	27408	13	5B
0005435785264	27408	14	5C
0005435785275	27408	15	5D
0005435785278	27408	16	6A
0005435785285	27408	17	6B
0005432190621	27408	18	6C
0005435785289	27408	19	6D
0005435785268	27408	20	7A
0005435785261	27408	21	7B
0005435785273	27408	22	7C
0005435785266	27408	23	7D
0005435785277	27408	24	18A
0005435785290	27408	25	18B
0005435785279	27408	26	18D
0005435785260	27408	27	19A
0005435785276	27408	28	19B
0005435785272	27408	29	19C
0005435785283	27408	30	20A
0005435785271	27408	31	20B
0005435785280	27408	32	20C
0005435785269	27408	33	21A
0005435785281	27408	34	21B
0005435785293	27408	35	21C
0005432190622	27408	36	21D
0005435785284	27408	37	22A
0005432190623	27408	38	22B
0005435785267	27408	39	22C
0005435785286	27408	40	22D
0005435785274	27408	41	23A
0005435311054	20288	1	1A
0005435311059	20288	2	1C
0005434407183	20288	3	1D
0005434407400	20288	4	1F
0005435311057	20288	5	2A
0005434406850	20288	6	2C
0005434407080	20288	7	2D
0005434407347	20288	8	3C
0005434407277	20288	9	3D
0005434406973	20288	10	4A
0005434407156	20288	11	4E
0005435311061	20288	12	4F
0005434407062	20288	13	5A
0005434407095	20288	14	5E
0005434407288	20288	15	5F
0005434407262	20288	16	6A
0005434407108	20288	17	6C
0005434406975	20288	18	6D
0005434407287	20288	19	6E
0005434407275	20288	20	6F
0005434407046	20288	21	7D
0005434407423	20288	22	7E
0005434407182	20288	23	7F
0005432058377	20288	24	8E
0005434407132	20288	25	8F
0005434407184	20288	26	9A
0005434407342	20288	27	9C
0005434407098	20288	28	9E
0005434407244	20288	29	10C
0005434407059	20288	30	10D
0005435311053	20288	31	10F
0005434407401	20288	32	11A
0005434407461	20288	33	11C
0005434407039	20288	34	11D
0005435311052	20288	35	11E
0005434407298	20288	36	12C
0005434407460	20288	37	12D
0005434407341	20288	38	12E
0005435311060	20288	39	12F
0005434407422	20288	40	13C
0005434407025	20288	41	13D
0005434407260	20288	42	13E
0005435311055	20288	43	13F
0005434407079	20288	44	14A
0005435311056	20288	45	14C
0005434407061	20288	46	14D
0005434407074	20288	47	14E
0005435311062	20288	48	14F
0005435311058	20288	49	15C
0005434407348	20288	50	15D
0005434406963	20288	51	15E
0005434407053	20288	52	15F
0005434407346	20288	53	16A
0005434407045	20288	54	16C
0005432058376	20288	55	16D
0005434407006	20288	56	16E
0005434407155	20288	57	16F
0005434407261	20288	58	17A
0005434407172	20288	59	17D
0005434407281	20288	60	17E
0005434407049	20288	61	17F
0005434407278	20288	62	18C
0005432058379	20288	63	18D
0005434407137	20288	64	19E
0005434407276	20288	65	20C
0005432058380	20288	66	20D
0005432058378	20288	67	20E
0005434407689	27014	1	1A
0005434407710	27014	2	1C
0005434407705	27014	3	1D
0005434407690	27014	4	2A
0005434407686	27014	5	2C
0005434407679	27014	6	2F
0005435310870	27014	7	2D
0005434407715	27014	8	3A
0005434407721	27014	9	3C
0005434407712	27014	10	3D
0005432153930	27014	11	3F
0005432153933	27014	12	4A
0005434407691	27014	13	4D
0005434407719	27014	14	4E
0005434407708	27014	15	4F
0005434407709	27014	16	5A
0005434407724	27014	17	5C
0005435310931	27014	18	5F
0005434407672	27014	19	6A
0005434407722	27014	20	6C
0005434407692	27014	21	6D
0005434407682	27014	22	6E
0005434407676	27014	23	6F
0005435310937	27014	24	7A
0005434407717	27014	25	7C
0005434407699	27014	26	7D
0005434407729	27014	27	7F
0005434407687	27014	28	7E
0005434407683	27014	29	8A
0005435310938	27014	30	8D
0005434407726	27014	31	8E
0005435310917	27014	32	8F
0005434407727	27014	33	9A
0005434407704	27014	34	9C
0005434407700	27014	35	9D
0005434407698	27014	36	9F
0005434407688	27014	37	10A
0005434407718	27014	38	10C
0005434407731	27014	39	10D
0005434407713	27014	40	10E
0005434407695	27014	41	10F
0005434407707	27014	42	11A
0005434407702	27014	43	11C
0005434407735	27014	44	11D
0005435310887	27014	45	11E
0005434407677	27014	46	11F
0005434407734	27014	47	12A
0005434407716	27014	48	12C
0005434407732	27014	49	12D
0005434407675	27014	50	12E
0005434407728	27014	51	12F
0005434407733	27014	52	13A
0005434407714	27014	53	13C
0005434407711	27014	54	13D
0005434407730	27014	55	14A
0005434407696	27014	56	14C
0005432153929	27014	57	14D
0005434407693	27014	58	14E
0005434407720	27014	59	14F
0005434407703	27014	60	15D
0005432153928	27014	61	15F
0005432153934	27014	62	16A
0005434407706	27014	63	16C
0005434407680	27014	64	16D
0005434407697	27014	65	16F
0005434407694	27014	66	17A
0005432153931	27014	67	17C
0005435310919	27014	68	17D
0005434407701	27014	69	18A
0005434407674	27014	70	18C
0005434407673	27014	71	18E
0005435310891	27014	72	18F
0005435310871	27014	73	19A
0005434407725	27014	74	19C
0005434407678	27014	75	19D
0005434407684	27014	76	19E
0005434407685	27014	77	19F
0005432153932	27014	78	20A
0005434407723	27014	79	20C
0005434407681	27014	80	20D
0005435310892	27014	81	20E
0005433123682	5703	1	1A
0005434319386	5703	2	1D
0005433123726	5703	3	2C
0005432109701	5703	4	2D
0005433123727	5703	5	2F
0005434319390	5703	6	3A
0005433123792	5703	7	3D
0005433123665	5703	8	4A
0005433123760	5703	9	4C
0005432109700	5703	10	4D
0005433123756	5703	11	4E
0005434319393	5703	12	5F
0005434319384	5703	13	6A
0005433123678	5703	14	6C
0005434319385	5703	15	7A
0005434319391	5703	16	7E
0005433123716	5703	17	7F
0005433123738	5703	18	8A
0005433123667	5703	19	8C
0005433123773	5703	20	9E
0005434319389	5703	21	9F
0005433123739	5703	22	10A
0005433123679	5703	23	10E
0005433123708	5703	24	11A
0005433123722	5703	25	11D
0005434319392	5703	26	13D
0005433123742	5703	27	13E
0005433123672	5703	28	14A
0005433123638	5703	29	14E
0005434311217	5703	30	15A
0005433123700	5703	31	15F
0005433123666	5703	32	16A
0005434311216	5703	33	17F
0005433123786	5703	34	18D
0005434319387	5703	35	18E
0005433123677	5703	36	19C
0005433123791	5703	37	20A
0005434319388	5703	38	20E
0005433123924	15668	1	2A
0005433123920	15668	2	2C
0005434311201	15668	3	2F
0005433123926	15668	4	3F
0005434319233	15668	5	4E
0005434311195	15668	6	5A
0005434319253	15668	7	5E
0005434319240	15668	8	6D
0005433123912	15668	9	6F
0005433123918	15668	10	7C
0005434319292	15668	11	7D
0005434319257	15668	12	7E
0005434319221	15668	13	8C
0005433123929	15668	14	8D
0005433123914	15668	15	9A
0005433123921	15668	16	9C
0005433123917	15668	17	9F
0005434319234	15668	18	10D
0005433123911	15668	19	10E
0005433123930	15668	20	10F
0005433123925	15668	21	11A
0005433123923	15668	22	11C
0005433123928	15668	23	11E
0005434319238	15668	24	12D
0005433123913	15668	25	13A
0005434319311	15668	26	13C
0005434319314	15668	27	13F
0005433123915	15668	28	14C
0005434319235	15668	29	14F
0005434319248	15668	30	15D
0005434319239	15668	31	15E
0005433123916	15668	32	16D
0005434319313	15668	33	17A
0005433123922	15668	34	17C
0005434311196	15668	35	17E
0005434319222	15668	36	18A
0005433123919	15668	37	18C
0005434319223	15668	38	18D
0005434319177	15668	39	18E
0005434319237	15668	40	18F
0005433123927	15668	41	20A
0005434319291	15668	42	20D
0005434311194	15668	43	20F
0005435220317	31735	1	2C
0005435219199	31735	2	3A
0005435219197	31735	3	4D
0005435220319	31735	4	7D
0005435220318	31735	5	18D
0005435219200	31735	6	19D
0005435220316	31735	7	22B
0005435219198	31735	8	23B
0005434484345	8970	1	1A
0005434484339	8970	2	2B
0005434484342	8970	3	2D
0005434189121	8970	4	18B
0005434189119	8970	5	19D
0005434484340	8970	6	20B
0005434189120	8970	7	20C
0005434484341	8970	8	20D
0005434484343	8970	9	22D
0005434484344	8970	10	23A
0005434484285	16646	1	1A
0005434484308	16646	2	2B
0005434189176	16646	3	2D
0005434189173	16646	4	4B
0005434189177	16646	5	6B
0005434189174	16646	6	7A
0005434484269	16646	7	18A
0005434484279	16646	8	18B
0005434189172	16646	9	18C
0005434484311	16646	10	20A
0005434189175	16646	11	21A
0005434484294	16646	12	21C
0005434484295	16646	13	22B
0005434189170	16646	14	22C
0005434189171	16646	15	23A
0005433123922	7568	1	2A
0005433123924	7568	2	2D
0005433123919	7568	3	5E
0005433123925	7568	4	6A
0005433123915	7568	5	6E
0005433123920	7568	6	7D
0005433123923	7568	7	8A
0005433123917	7568	8	8C
0005433123921	7568	9	8D
0005433123918	7568	10	11C
0005433722131	7568	11	12F
0005433123913	7568	12	13A
0005433123926	7568	13	13E
0005433722128	7568	14	13F
0005433123928	7568	15	14E
0005433722121	7568	16	15F
0005433123914	7568	17	16C
0005433123927	7568	18	17D
0005433123930	7568	19	18C
0005433123911	7568	20	19C
0005433123929	7568	21	19E
0005433123912	7568	22	20C
0005433123916	7568	23	20F
0005432693054	7569	1	1A
0005432693060	7569	2	1C
0005433449951	7569	3	1D
0005433449950	7569	4	1F
0005432720867	7569	5	2C
0005432693036	7569	6	2D
0005432693048	7569	7	2F
0005433449956	7569	8	3A
0005432693043	7569	9	3C
0005432720887	7569	10	3D
0005433449942	7569	11	3F
0005433449954	7569	12	4A
0005432720893	7569	13	4C
0005432071571	7569	14	4D
0005432720892	7569	15	4E
0005432693047	7569	16	4F
0005432693034	7569	17	5A
0005432720873	7569	18	5C
0005432693063	7569	19	5D
0005433449946	7569	20	5E
0005432071569	7569	21	5F
0005433449952	7569	22	6C
0005432693057	7569	23	6D
0005433449943	7569	24	6E
0005432720894	7569	25	6F
0005432693053	7569	26	7A
0005432720872	7569	27	7C
0005432693039	7569	28	7D
0005432720876	7569	29	7E
0005432720884	7569	30	7F
0005432071570	7569	31	8A
0005433449945	7569	32	8C
0005433449953	7569	33	8D
0005432720868	7569	34	8E
0005432720890	7569	35	8F
0005432720871	7569	36	9A
0005433449955	7569	37	9C
0005433449941	7569	38	9F
0005432693051	7569	39	10A
0005432693050	7569	40	10C
0005433449961	7569	41	10D
0005432693052	7569	42	10E
0005432693038	7569	43	10F
0005432693032	7569	44	11A
0005432720885	7569	45	11C
0005432693046	7569	46	11D
0005433449959	7569	47	11E
0005433449948	7569	48	12A
0005432693041	7569	49	12C
0005432720869	7569	50	12D
0005432720886	7569	51	12E
0005432720875	7569	52	12F
0005432720880	7569	53	13A
0005432693058	7569	54	13C
0005432693044	7569	55	13E
0005432720874	7569	56	13F
0005432693042	7569	57	14A
0005432720878	7569	58	14C
0005432693055	7569	59	14D
0005432693059	7569	60	14E
0005432693037	7569	61	14F
0005432693049	7569	62	15C
0005432720879	7569	63	15E
0005433449957	7569	64	15F
0005432693061	7569	65	16A
0005432720877	7569	66	16C
0005432693045	7569	67	16D
0005433449947	7569	68	16E
0005433449949	7569	69	16F
0005432720883	7569	70	17C
0005432720881	7569	71	17E
0005432720888	7569	72	17F
0005433449960	7569	73	18A
0005432693062	7569	74	18C
0005432693035	7569	75	18D
0005432693056	7569	76	18E
0005432693033	7569	77	19A
0005432720870	7569	78	19C
0005432720891	7569	79	19E
0005432720889	7569	80	19F
0005432720882	7569	81	20A
0005433449944	7569	82	20C
0005432693040	7569	83	20D
0005433449958	7569	84	20F
0005433449687	30314	1	1A
0005433449849	30314	2	1C
0005432692671	30314	3	1D
0005432692769	30314	4	1F
0005432692847	30314	5	2A
0005432692869	30314	6	2C
0005433449711	30314	7	2D
0005432692695	30314	8	2F
0005432692792	30314	9	3C
0005432692687	30314	10	3D
0005432692726	30314	11	3F
0005432692734	30314	12	4A
0005432692868	30314	13	4C
0005433449710	30314	14	4D
0005433449705	30314	15	4E
0005433449802	30314	16	5A
0005432692836	30314	17	5D
0005433449726	30314	18	6A
0005432692737	30314	19	6C
0005433449701	30314	20	6F
0005432692804	30314	21	7C
0005432692729	30314	22	7E
0005432692741	30314	23	7F
0005432692772	30314	24	8A
0005432692754	30314	25	8C
0005432692760	30314	26	8D
0005433449651	30314	27	8E
0005433449712	30314	28	8F
0005432692759	30314	29	9A
0005433449750	30314	30	9D
0005433449806	30314	31	9E
0005432692788	30314	32	10A
0005433449783	30314	33	10C
0005432692794	30314	34	10E
0005433449704	30314	35	10F
0005433449751	30314	36	11C
0005432692757	30314	37	11A
0005433449749	30314	38	11D
0005432692771	30314	39	11E
0005432692718	30314	40	12A
0005433449650	30314	41	13A
0005433449830	30314	42	13C
0005433449742	30314	43	13D
0005432692770	30314	44	13E
0005432692730	30314	45	13F
0005432692793	30314	46	14A
0005433449688	30314	47	14E
0005432692755	30314	48	15C
0005432692767	30314	49	15E
0005433449848	30314	50	15F
0005433449799	30314	51	16D
0005433449767	30314	52	16F
0005433449784	30314	53	17A
0005432692727	30314	54	17C
0005433449793	30314	55	18D
0005432692810	30314	56	18E
0005433449775	30314	57	18F
0005432692768	30314	58	19F
0005433449752	30314	59	20C
0005432692776	30314	60	20A
0005433449709	30314	61	20D
0005432692725	30314	62	20F
0005432720679	30313	1	1D
0005432720738	30313	2	3C
0005433123727	30313	3	3D
0005432720693	30313	4	3F
0005433123672	30313	5	4C
0005432720665	30313	6	4D
0005433123773	30313	7	4E
0005433123722	30313	8	4F
0005433123786	30313	9	5E
0005433722224	30313	10	6C
0005433123700	30313	11	6E
0005433123638	30313	12	7A
0005432720767	30313	13	8E
0005433123679	30313	14	8F
0005433123742	30313	15	9E
0005432720800	30313	16	9F
0005433123738	30313	17	10D
0005433722218	30313	18	10E
0005432720574	30313	19	10F
0005433123760	30313	20	11A
0005433722219	30313	21	11D
0005432720631	30313	22	11E
0005433123667	30313	23	12D
0005433123739	30313	24	12E
0005433123666	30313	25	13A
0005433123665	30313	26	13C
0005433123677	30313	27	13D
0005433123682	30313	28	13F
0005433123791	30313	29	14A
0005433123756	30313	30	14E
0005433722223	30313	31	14F
0005432720715	30313	32	15D
0005433722221	30313	33	16A
0005432720573	30313	34	16C
0005433123716	30313	35	16D
0005433722220	30313	36	16F
0005433123708	30313	37	17C
0005432720737	30313	38	17E
0005433123792	30313	39	18D
0005433123726	30313	40	18E
0005433722217	30313	41	18F
0005433722222	30313	42	19F
0005432720768	30313	43	20A
0005433123678	30313	44	20D
0005432720622	30313	45	20E
0005433525030	1409	1	1A
0005434586604	1409	2	1C
0005433192840	1409	3	1D
0005433525024	1409	4	1F
0005433724802	1409	5	2C
0005433192910	1409	6	2D
0005432968824	1409	7	2F
0005433192940	1409	8	3A
0005434586601	1409	9	3C
0005433192950	1409	10	3D
0005433525029	1409	11	3F
0005433525033	1409	12	4A
0005434514966	1409	13	4C
0005433724803	1409	14	4E
0005432927929	1409	15	4F
0005433192941	1409	16	5D
0005433724804	1409	17	5E
0005432968823	1409	18	5F
0005434586589	1409	19	6A
0005434586583	1409	20	6C
0005433192961	1409	21	6D
0005434586585	1409	22	6E
0005434513576	1409	23	6F
0005433525026	1409	24	7A
0005433192872	1409	25	7C
0005432271000	1409	26	7D
0005434586595	1409	27	7E
0005433724805	1409	28	8C
0005434514967	1409	29	8D
0005432271001	1409	30	8E
0005433192905	1409	31	8F
0005433525031	1409	32	9A
0005433192962	1409	33	9C
0005434586599	1409	34	9E
0005433192976	1409	35	10A
0005433192908	1409	36	10D
0005433525027	1409	37	10F
0005434586588	1409	38	11A
0005434513578	1409	39	11C
0005434586579	1409	40	11D
0005434586582	1409	41	11E
0005432271002	1409	42	11F
0005434586584	1409	43	12A
0005434586600	1409	44	12C
0005434586580	1409	45	12E
0005434586596	1409	46	13A
0005434586587	1409	47	13C
0005433192967	1409	48	13D
0005433525032	1409	49	13E
0005432927930	1409	50	13F
0005432927945	1409	51	14A
0005434586586	1409	52	14C
0005434586603	1409	53	14D
0005433192993	1409	54	14E
0005434513577	1409	55	14F
0005433192949	1409	56	15A
0005432968827	1409	57	15C
0005433192992	1409	58	16A
0005434586598	1409	59	16C
0005433192933	1409	60	16D
0005434514965	1409	61	16E
0005433192912	1409	62	17C
0005433525025	1409	63	17D
0005434586594	1409	64	17E
0005433525034	1409	65	18A
0005432927944	1409	66	18C
0005434586593	1409	67	18D
0005434586592	1409	68	18E
0005433192944	1409	69	18F
0005433192974	1409	70	19C
0005434586597	1409	71	19D
0005434586590	1409	72	19E
0005434586602	1409	73	19F
0005434586591	1409	74	20A
0005434586578	1409	75	20C
0005433192975	1409	76	20D
0005434586581	1409	77	20E
0005433525028	1409	78	20F
0005433193036	18513	1	1A
0005433524897	18513	2	1D
0005434586255	18513	3	2A
0005432927974	18513	4	2F
0005433193032	18513	5	3C
0005433524935	18513	6	3F
0005433193037	18513	7	4C
0005434586368	18513	8	4D
0005432927973	18513	9	4E
0005433193030	18513	10	4F
0005433524949	18513	11	5D
0005433193029	18513	12	5E
0005433193028	18513	13	5F
0005434514943	18513	14	6A
0005434586436	18513	15	6C
0005434586409	18513	16	6D
0005433524948	18513	17	6E
0005433724741	18513	18	6F
0005434586370	18513	19	7A
0005433724748	18513	20	7C
0005433524905	18513	21	7F
0005433724742	18513	22	8A
0005434586348	18513	23	9A
0005433724758	18513	24	9C
0005433193031	18513	25	9F
0005434586285	18513	26	10C
0005433524978	18513	27	10E
0005434586369	18513	28	11A
0005434586347	18513	29	11C
0005434514937	18513	30	11D
0005432968837	18513	31	11E
0005432927975	18513	32	12E
0005434586306	18513	33	12F
0005432968838	18513	34	13D
0005434586465	18513	35	13E
0005432927976	18513	36	13F
0005434586358	18513	37	14A
0005434586384	18513	38	14D
0005434514938	18513	39	14E
0005433524933	18513	40	15A
0005433193040	18513	41	15C
0005433193041	18513	42	15E
0005434586410	18513	43	16A
0005433524942	18513	44	16C
0005433524904	18513	45	16F
0005432927972	18513	46	16E
0005433724757	18513	47	17D
0005434586337	18513	48	17E
0005433524956	18513	49	18A
0005433193033	18513	50	18C
0005433524934	18513	51	18D
0005434586349	18513	52	18E
0005434586442	18513	53	18F
0005434586408	18513	54	19A
0005433193038	18513	55	19C
0005433524941	18513	56	19D
0005433193035	18513	57	19E
0005433193039	18513	58	19F
0005434586216	18513	59	20A
0005434514939	18513	60	20C
0005433193034	18513	61	20D
0005434514950	18513	62	20F
0005434344157	11434	1	1A
0005434344153	11434	2	1B
0005434344171	11434	3	1C
0005434142606	11434	4	1D
0005434344136	11434	5	2B
0005434344146	11434	6	2C
0005434344151	11434	7	2D
0005435304998	11434	8	3A
0005435302165	11434	9	3B
0005434344149	11434	10	3C
0005434142608	11434	11	3D
0005434344137	11434	12	4A
0005434344163	11434	13	4B
0005434344166	11434	14	4C
0005434344161	11434	15	4D
0005434344162	11434	16	5A
0005434344160	11434	17	5B
0005434344164	11434	18	5C
0005434344150	11434	19	5D
0005434344140	11434	20	6A
0005434344152	11434	21	6B
0005434344144	11434	22	6C
0005434344154	11434	23	6D
0005434142605	11434	24	7A
0005434344173	11434	25	7B
0005434344145	11434	26	7C
0005434344168	11434	27	7D
0005435302166	11434	28	18A
0005434344148	11434	29	18B
0005434344159	11434	30	18C
0005434344139	11434	31	18D
0005434344142	11434	32	19A
0005434344165	11434	33	19B
0005434344141	11434	34	19C
0005434344167	11434	35	19D
0005435302144	11434	36	20A
0005434344155	11434	37	20B
0005434142607	11434	38	20C
0005435304999	11434	39	20D
0005434344156	11434	40	21B
0005434344169	11434	41	21C
0005434344172	11434	42	21D
0005435302158	11434	43	22A
0005434344158	11434	44	22B
0005434344147	11434	45	22C
0005434344138	11434	46	22D
0005434344170	11434	47	23A
0005434344143	11434	48	23B
0005434343950	29799	1	1A
0005435305015	29799	2	1B
0005434343763	29799	3	1C
0005434343732	29799	4	1D
0005434343880	29799	5	2B
0005434142566	29799	6	2C
0005434343834	29799	7	2D
0005434343901	29799	8	3A
0005434343899	29799	9	3B
0005435304156	29799	10	3C
0005434343946	29799	11	3D
0005435304155	29799	12	4B
0005434343827	29799	13	4C
0005434343903	29799	14	5A
0005435305014	29799	15	5B
0005434142568	29799	16	5C
0005434343826	29799	17	5D
0005434343833	29799	18	6A
0005434343940	29799	19	6C
0005434343806	29799	20	6D
0005434343841	29799	21	7A
0005434343779	29799	22	7B
0005434343762	29799	23	7C
0005434343774	29799	24	7D
0005434343790	29799	25	18A
0005435305012	29799	26	18C
0005434343777	29799	27	18D
0005434343900	29799	28	19A
0005435304157	29799	29	19B
0005434343908	29799	30	19C
0005434343828	29799	31	19D
0005434343832	29799	32	20A
0005434343805	29799	33	20B
0005434343853	29799	34	20C
0005434343879	29799	35	20D
0005434343924	29799	36	21A
0005434343854	29799	37	21B
0005434343847	29799	38	21C
0005434344009	29799	39	21D
0005434343804	29799	40	22A
0005434343764	29799	41	22B
0005434343823	29799	42	22C
0005434343938	29799	43	22D
0005434343907	29799	44	23A
0005435305013	29799	45	23B
0005435824595	1272	1	1A
0005435824606	1272	2	2A
0005433415496	1272	3	3D
0005435824608	1272	4	4A
0005435824593	1272	5	3F
0005435824594	1272	6	4D
0005435824619	1272	7	4F
0005435824600	1272	8	5C
0005433415480	1272	9	5F
0005433415554	1272	10	6B
0005433415537	1272	11	6D
0005433415540	1272	12	7A
0005433415553	1272	13	7C
0005435824602	1272	14	7F
0005435824592	1272	15	8C
0005432284555	1272	16	8B
0005433415543	1272	17	8D
0005433415544	1272	18	9C
0005435824615	1272	19	9B
0005435824604	1272	20	9F
0005432284554	1272	21	9D
0005435824591	1272	22	10E
0005435824596	1272	23	10D
0005432284556	1272	24	10F
0005433415445	1272	25	11F
0005433415531	1272	26	12B
0005435824598	1272	27	12A
0005435824611	1272	28	13B
0005435824603	1272	29	14A
0005435824618	1272	30	14C
0005435824605	1272	31	14E
0005433415547	1272	32	14F
0005435824612	1272	33	15B
0005433415505	1272	34	15A
0005435824613	1272	35	15E
0005433415538	1272	36	16B
0005435824597	1272	37	16C
0005435824617	1272	38	17B
0005435824609	1272	39	17D
0005433415532	1272	40	18B
0005435824607	1272	41	18A
0005433415517	1272	42	18D
0005435824610	1272	43	18C
0005433415548	1272	44	19A
0005435824614	1272	45	19E
0005435824599	1272	46	19D
0005435824616	1272	47	19F
0005435824601	1272	48	20A
0005433415479	1272	49	21C
0005433415506	1272	50	21F
0005435824337	17994	1	2C
0005433415639	17994	2	2F
0005433415648	17994	3	3C
0005433415655	17994	4	5C
0005433415647	17994	5	8A
0005433415651	17994	6	7F
0005435824354	17994	7	8D
0005433415641	17994	8	8E
0005433415654	17994	9	10B
0005435824342	17994	10	10E
0005435824283	17994	11	11C
0005435824420	17994	12	11D
0005433415640	17994	13	11F
0005435824369	17994	14	12D
0005433415652	17994	15	13C
0005433415646	17994	16	13B
0005435824471	17994	17	13E
0005433415645	17994	18	13F
0005433415653	17994	19	14B
0005433415649	17994	20	15C
0005435824355	17994	21	16A
0005433415650	17994	22	16F
0005433415643	17994	23	18C
0005433415644	17994	24	19C
0005433415642	17994	25	19E
0005435824293	17994	26	19D
0005435824470	17994	27	20C
0005435824368	17994	28	21A
0005435476699	5664	1	1A
0005435476664	5664	2	1C
0005435242536	5664	3	1F
0005435242621	5664	4	2A
0005435242497	5664	5	2C
0005432783729	5664	6	2D
0005432783769	5664	7	2F
0005432783761	5664	8	3A
0005432783754	5664	9	3C
0005435242748	5664	10	3D
0005435476706	5664	11	3F
0005432783728	5664	12	4A
0005435242488	5664	13	4C
0005432783760	5664	14	4D
0005435242682	5664	15	4E
0005432783770	5664	16	4F
0005432783750	5664	17	5A
0005432783764	5664	18	5C
0005432783739	5664	19	5D
0005432783732	5664	20	5E
0005432783775	5664	21	5F
0005432783766	5664	22	6A
0005435242558	5664	23	6C
0005432143985	5664	24	6D
0005432783724	5664	25	6E
0005432783756	5664	26	6F
0005432783722	5664	27	7A
0005432783755	5664	28	7C
0005432783731	5664	29	7D
0005432783723	5664	30	7E
0005432783762	5664	31	7F
0005435242589	5664	32	8A
0005435242683	5664	33	8D
0005432783763	5664	34	8E
0005432783725	5664	35	8F
0005432783746	5664	36	9A
0005432783751	5664	37	9C
0005432783758	5664	38	9D
0005435242719	5664	39	9E
0005432143984	5664	40	9F
0005432783736	5664	41	10A
0005432783733	5664	42	10C
0005432783759	5664	43	10D
0005435242674	5664	44	10E
0005435476686	5664	45	10F
0005435476697	5664	46	11A
0005432783734	5664	47	11C
0005432783765	5664	48	11D
0005432783735	5664	49	11E
0005432783745	5664	50	11F
0005432783747	5664	51	12A
0005432783771	5664	52	12C
0005435242622	5664	53	12D
0005435476684	5664	54	12E
0005435242615	5664	55	12F
0005435242749	5664	56	13A
0005432783721	5664	57	13C
0005435242669	5664	58	13D
0005435242614	5664	59	13E
0005432783757	5664	60	13F
0005432783752	5664	61	14A
0005432783742	5664	62	14C
0005435242593	5664	63	14D
0005432783773	5664	64	14E
0005435242627	5664	65	14F
0005432783767	5664	66	15A
0005435242662	5664	67	15C
0005435476708	5664	68	15D
0005435242660	5664	69	15E
0005435242659	5664	70	15F
0005435476690	5664	71	16A
0005435242597	5664	72	16C
0005435242629	5664	73	16D
0005432783740	5664	74	16E
0005432783774	5664	75	17A
0005435242586	5664	76	17C
0005435242585	5664	77	17D
0005432783768	5664	78	17E
0005432783727	5664	79	17F
0005432783720	5664	80	18A
0005432783749	5664	81	18C
0005432783737	5664	82	18D
0005432783772	5664	83	18E
0005432783753	5664	84	18F
0005432783744	5664	85	19A
0005432783738	5664	86	19C
0005432783730	5664	87	19D
0005432783748	5664	88	19E
0005435242592	5664	89	19F
0005432783741	5664	90	20A
0005432783726	5664	91	20C
0005435476685	5664	92	20D
0005435476663	5664	93	20E
0005432783743	5664	94	20F
0005432783421	15387	1	1A
0005435242822	15387	2	1C
0005435242808	15387	3	1D
0005435242823	15387	4	1F
0005432783252	15387	5	2A
0005432783368	15387	6	2C
0005435476748	15387	7	2D
0005432783153	15387	8	2F
0005435242824	15387	9	3A
0005432783151	15387	10	3C
0005432783249	15387	11	3D
0005432783261	15387	12	3F
0005432783248	15387	13	4A
0005435242818	15387	14	4C
0005435242800	15387	15	4D
0005432783259	15387	16	4E
0005432783293	15387	17	4F
0005432783118	15387	18	5A
0005435242807	15387	19	5C
0005435242802	15387	20	5D
0005432783117	15387	21	5E
0005432783309	15387	22	5F
0005432783032	15387	23	6A
0005432783189	15387	24	6C
0005432783395	15387	25	6D
0005432783132	15387	26	6E
0005435242809	15387	27	6F
0005432783071	15387	28	7A
0005432783300	15387	29	7C
0005432783170	15387	30	7D
0005432783301	15387	31	7E
0005432783432	15387	32	7F
0005432783033	15387	33	8A
0005432783251	15387	34	8C
0005435242815	15387	35	8D
0005435242817	15387	36	8E
0005435242797	15387	37	8F
0005432783257	15387	38	9A
0005435242803	15387	39	9C
0005432783240	15387	40	9D
0005432783316	15387	41	9E
0005435242810	15387	42	9F
0005435242801	15387	43	10A
0005432783406	15387	44	10C
0005432783291	15387	45	10D
0005432783394	15387	46	10E
0005432783188	15387	47	10F
0005435242798	15387	48	11A
0005432783367	15387	49	11C
0005432783396	15387	50	11D
0005432783353	15387	51	11E
0005432783200	15387	52	11F
0005432783220	15387	53	12A
0005432783138	15387	54	12C
0005432783425	15387	55	12D
0005432783292	15387	56	12E
0005432783194	15387	57	12F
0005432783434	15387	58	13A
0005432783387	15387	59	13C
0005432783369	15387	60	13D
0005435242819	15387	61	13E
0005432783262	15387	62	13F
0005435242820	15387	63	14A
0005432783253	15387	64	14C
0005435242816	15387	65	14D
0005432783162	15387	66	14E
0005432783297	15387	67	14F
0005435242814	15387	68	15A
0005435242805	15387	69	15C
0005435242821	15387	70	15D
0005432783121	15387	71	15E
0005435476747	15387	72	15F
0005435242813	15387	73	16A
0005432783169	15387	74	16C
0005432783282	15387	75	16D
0005435242811	15387	76	16E
0005432783133	15387	77	16F
0005432783229	15387	78	17A
0005432783308	15387	79	17C
0005432783350	15387	80	17D
0005432783152	15387	81	17E
0005435476746	15387	82	17F
0005432783241	15387	83	18A
0005432783131	15387	84	18C
0005435242804	15387	85	18D
0005432783283	15387	86	18E
0005432783263	15387	87	18F
0005432783185	15387	88	19A
0005432783302	15387	89	19C
0005435242806	15387	90	19D
0005435242799	15387	91	19E
0005432783260	15387	92	19F
0005432783239	15387	93	20A
0005432783453	15387	94	20C
0005432783307	15387	95	20D
0005432783405	15387	96	20E
0005435242812	15387	97	20F
0005432848307	4352	1	1A
0005435850874	4352	2	1D
0005432848299	4352	3	1C
0005434463926	4352	4	2D
0005432848304	4352	5	3A
0005432848293	4352	6	3B
0005432848298	4352	7	4B
0005434463928	4352	8	4C
0005432848296	4352	9	4D
0005435850843	4352	10	5B
0005432848303	4352	11	6A
0005432848295	4352	12	7A
0005432848306	4352	13	7B
0005432848301	4352	14	18B
0005434463927	4352	15	20A
0005435850844	4352	16	20D
0005434462787	4352	17	21A
0005432848297	4352	18	21B
0005432848300	4352	19	21C
0005434462789	4352	20	21D
0005434462788	4352	21	22A
0005432848302	4352	22	22B
0005432848305	4352	23	22D
0005432848294	4352	24	23A
0005432848154	28889	1	1D
0005435850904	28889	2	2A
0005434461623	28889	3	2B
0005432848152	28889	4	4D
0005434463909	28889	5	5B
0005434463910	28889	6	5D
0005432848179	28889	7	6A
0005432848145	28889	8	6C
0005435850903	28889	9	7A
0005435850905	28889	10	7B
0005432848153	28889	11	7C
0005435850900	28889	12	7D
0005434463899	28889	13	18B
0005435850906	28889	14	19A
0005432848151	28889	15	19B
0005434461622	28889	16	19D
0005435850901	28889	17	20C
0005435850902	28889	18	21B
0005432848144	28889	19	21D
0005435850899	28889	20	22C
0005432848175	28889	21	23B
0005434925783	6267	1	1A
0005434443699	6267	2	1D
0005433496942	6267	3	1F
0005434443688	6267	4	2A
0005434443690	6267	5	2C
0005434443692	6267	6	2D
0005433496943	6267	7	2F
0005434925794	6267	8	3A
0005434925776	6267	9	3C
0005434443701	6267	10	3F
0005432075226	6267	11	4A
0005433496953	6267	12	4C
0005433496954	6267	13	4E
0005434925786	6267	14	4F
0005433496947	6267	15	5C
0005433496957	6267	16	5D
0005433496951	6267	17	5E
0005433496930	6267	18	5F
0005434925795	6267	19	6A
0005434443700	6267	20	6C
0005434925790	6267	21	6D
0005434925793	6267	22	6E
0005434925792	6267	23	7A
0005434925780	6267	24	7C
0005434443698	6267	25	7F
0005433496941	6267	26	8A
0005433496961	6267	27	8C
0005433496935	6267	28	8E
0005433496958	6267	29	8F
0005434925782	6267	30	9A
0005433496944	6267	31	9C
0005434925798	6267	32	9D
0005434925799	6267	33	9F
0005434443702	6267	34	10A
0005434925797	6267	35	10C
0005433496949	6267	36	10D
0005434925778	6267	37	10E
0005433496955	6267	38	10F
0005433496938	6267	39	11C
0005434443695	6267	40	11D
0005433496931	6267	41	11F
0005433496948	6267	42	12A
0005433496933	6267	43	12D
0005432075227	6267	44	12E
0005434443703	6267	45	12F
0005434443696	6267	46	13A
0005434925796	6267	47	13C
0005433496960	6267	48	13D
0005433496945	6267	49	13F
0005434443691	6267	50	14A
0005434925785	6267	51	14C
0005434925789	6267	52	14D
0005432075228	6267	53	14E
0005433496939	6267	54	14F
0005434925779	6267	55	15C
0005434443704	6267	56	15D
0005434925788	6267	57	15E
0005433496959	6267	58	15F
0005434925791	6267	59	16A
0005434925777	6267	60	16C
0005434443694	6267	61	16D
0005434925781	6267	62	16E
0005434925787	6267	63	16F
0005433496956	6267	64	17A
0005433496940	6267	65	17C
0005434443697	6267	66	17D
0005434443693	6267	67	17F
0005433496952	6267	68	18A
0005434443689	6267	69	18C
0005433496937	6267	70	18D
0005433496934	6267	71	18E
0005434925784	6267	72	19D
0005433496932	6267	73	20A
0005433496950	6267	74	20C
0005433496946	6267	75	20D
0005433496936	6267	76	20E
0005433496622	20323	1	1A
0005433496632	20323	2	1C
0005433496853	20323	3	1D
0005434925395	20323	4	1F
0005433496704	20323	5	2C
0005433496697	20323	6	2D
0005434443604	20323	7	2F
0005433496706	20323	8	3A
0005434925376	20323	9	3C
0005433496741	20323	10	3F
0005433496668	20323	11	4A
0005434443603	20323	12	4C
0005433496563	20323	13	4D
0005434925450	20323	14	4E
0005434443527	20323	15	4F
0005433496654	20323	16	5A
0005434925290	20323	17	5D
0005434925295	20323	18	5E
0005434925434	20323	19	6A
0005434925398	20323	20	6C
0005434443499	20323	21	6D
0005434443544	20323	22	7A
0005434925351	20323	23	7C
0005433496561	20323	24	7E
0005433496705	20323	25	7F
0005433496811	20323	26	8A
0005433496734	20323	27	8C
0005434925302	20323	28	8D
0005434443541	20323	29	8E
0005434925321	20323	30	9A
0005433496624	20323	31	9C
0005434925375	20323	32	9D
0005434443536	20323	33	9E
0005434925343	20323	34	9F
0005433496715	20323	35	10A
0005434925392	20323	36	10C
0005433496647	20323	37	10D
0005434443528	20323	38	10E
0005433496716	20323	39	10F
0005434925363	20323	40	11A
0005434925484	20323	41	11C
0005434925442	20323	42	11E
0005434925364	20323	43	11F
0005433496687	20323	44	12D
0005433496703	20323	45	12E
0005434925303	20323	46	13A
0005434925414	20323	47	13D
0005434925404	20323	48	13E
0005433496713	20323	49	13F
0005433496836	20323	50	14A
0005434925331	20323	51	14C
0005434925468	20323	52	14D
0005433496623	20323	53	14E
0005434925330	20323	54	15A
0005433496655	20323	55	15C
0005434443634	20323	56	15D
0005434443578	20323	57	16A
0005434443600	20323	58	16C
0005433496722	20323	59	16D
0005434925399	20323	60	16E
0005434443509	20323	61	16F
0005434925460	20323	62	17A
0005433496621	20323	63	17D
0005434443559	20323	64	18A
0005433496699	20323	65	18C
0005433496562	20323	66	18D
0005433496631	20323	67	18E
0005434925396	20323	68	18F
0005433496723	20323	69	19C
0005433496688	20323	70	19F
0005433496812	20323	71	20A
0005434443508	20323	72	20D
0005433496790	20323	73	20E
0005434443560	20323	74	20F
0005432783173	12215	1	1C
0005432783288	12215	2	1D
0005435242839	12215	3	2C
0005435242842	12215	4	2D
0005432783348	12215	5	3C
0005435242850	12215	6	3D
0005432783469	12215	7	3F
0005432783384	12215	8	4A
0005432783326	12215	9	4C
0005432783423	12215	10	4D
0005435242832	12215	11	4E
0005432783500	12215	12	4F
0005432783166	12215	13	5A
0005432782989	12215	14	5C
0005432783298	12215	15	5D
0005432783299	12215	16	5F
0005435242843	12215	17	6C
0005435242826	12215	18	6D
0005432783566	12215	19	6E
0005432783386	12215	20	6F
0005432783213	12215	21	7A
0005435242848	12215	22	7C
0005432783441	12215	23	7D
0005435242838	12215	24	7E
0005435242836	12215	25	7F
0005432783427	12215	26	8C
0005432783440	12215	27	8E
0005432783156	12215	28	8F
0005432783565	12215	29	9C
0005432783313	12215	30	9D
0005432783385	12215	31	9F
0005432783344	12215	32	10A
0005435242827	12215	33	10C
0005435242840	12215	34	10F
0005432783017	12215	35	11A
0005435242845	12215	36	11C
0005432783424	12215	37	11F
0005435242829	12215	38	12D
0005435242847	12215	39	12E
0005435242831	12215	40	12F
0005435242849	12215	41	13C
0005432783254	12215	42	13D
0005435242833	12215	43	13F
0005435242825	12215	44	14C
0005432783175	12215	45	14D
0005432783506	12215	46	14E
0005435242830	12215	47	15A
0005435242835	12215	48	15C
0005435242851	12215	49	15D
0005432783567	12215	50	15E
0005432783060	12215	51	15F
0005432783176	12215	52	16A
0005435242834	12215	53	16C
0005432783499	12215	54	16D
0005432783212	12215	55	16F
0005432783202	12215	56	17A
0005432783167	12215	57	17C
0005432783456	12215	58	17D
0005435242844	12215	59	17E
0005432783345	12215	60	17F
0005435242846	12215	61	18A
0005435242828	12215	62	18C
0005432783470	12215	63	18F
0005435242841	12215	64	19C
0005432783225	12215	65	19D
0005432783479	12215	66	19E
0005432783400	12215	67	20A
0005432783168	12215	68	20D
0005432783426	12215	69	20E
0005435242837	12215	70	20F
0005432783674	15421	1	1C
0005435242466	15421	2	1D
0005432783690	15421	3	1F
0005432783697	15421	4	2A
0005432783717	15421	5	2D
0005432783696	15421	6	2F
0005432783666	15421	7	3A
0005432783670	15421	8	3C
0005432783708	15421	9	3D
0005432783711	15421	10	3F
0005432783671	15421	11	4A
0005435242394	15421	12	4C
0005432783679	15421	13	4D
0005435242685	15421	14	4E
0005432783677	15421	15	4F
0005432783707	15421	16	5A
0005432783692	15421	17	5D
0005432783688	15421	18	5E
0005435242542	15421	19	5F
0005432783703	15421	20	6A
0005435242547	15421	21	6C
0005435242636	15421	22	6D
0005435242523	15421	23	6E
0005432783678	15421	24	7C
0005435242567	15421	25	7D
0005432783682	15421	26	7E
0005432783695	15421	27	7F
0005435242543	15421	28	8A
0005435242393	15421	29	8E
0005432783667	15421	30	8F
0005432783683	15421	31	9A
0005432783684	15421	32	9C
0005432783706	15421	33	9D
0005432783705	15421	34	9E
0005435242604	15421	35	9F
0005432783669	15421	36	10A
0005432783681	15421	37	10C
0005435242467	15421	38	10D
0005432783718	15421	39	10E
0005432783716	15421	40	10F
0005435242548	15421	41	11A
0005432783691	15421	42	11C
0005435242522	15421	43	11D
0005432783675	15421	44	11E
0005435242433	15421	45	11F
0005432783665	15421	46	12A
0005432783676	15421	47	12C
0005432783713	15421	48	12D
0005432783686	15421	49	12F
0005432783712	15421	50	13C
0005435242684	15421	51	13D
0005435242520	15421	52	13E
0005435242483	15421	53	13F
0005435242510	15421	54	14C
0005432783699	15421	55	14D
0005435242524	15421	56	14E
0005435242549	15421	57	14F
0005432783700	15421	58	15A
0005432783701	15421	59	15D
0005435242554	15421	60	15C
0005435242605	15421	61	15E
0005432783719	15421	62	15F
0005432783698	15421	63	16A
0005435242478	15421	64	16C
0005435242454	15421	65	16D
0005432783685	15421	66	16E
0005435242541	15421	67	16F
0005432783673	15421	68	17A
0005432783704	15421	69	17C
0005432783715	15421	70	17D
0005435242451	15421	71	17E
0005432783710	15421	72	17F
0005432783689	15421	73	18A
0005432783668	15421	74	18C
0005435242511	15421	75	18D
0005432783693	15421	76	18E
0005432783680	15421	77	18F
0005432783694	15421	78	19A
0005435242602	15421	79	19D
0005432783687	15421	80	19E
0005435242551	15421	81	19F
0005432783714	15421	82	20A
0005432783672	15421	83	20C
0005432783702	15421	84	20D
0005432783709	15421	85	20E
0005434877125	10087	1	1C
0005434876666	10087	2	1A
0005434877687	10087	3	1F
0005434877158	10087	4	1D
0005434877408	10087	5	2A
0005435913931	10087	6	2D
0005434877538	10087	7	2C
0005434877324	10087	8	3A
0005434877300	10087	9	3D
0005434877432	10087	10	4A
0005434877562	10087	11	3F
0005434877304	10087	12	4D
0005434877042	10087	13	4C
0005434877834	10087	14	4F
0005434877124	10087	15	5C
0005434877279	10087	16	5A
0005434877428	10087	17	5F
0005434877218	10087	18	5D
0005434877808	10087	19	6B
0005434877310	10087	20	6A
0005434877382	10087	21	6D
0005434877224	10087	22	6C
0005434877588	10087	23	6E
0005434876960	10087	24	7A
0005434877187	10087	25	6F
0005434877657	10087	26	7C
0005434877701	10087	27	7B
0005434877638	10087	28	7E
0005434876976	10087	29	7D
0005434910107	10087	30	8A
0005434877509	10087	31	7F
0005434877516	10087	32	8C
0005434877011	10087	33	8B
0005435913930	10087	34	8D
0005434877639	10087	35	8F
0005435913932	10087	36	8E
0005434877640	10087	37	9B
0005434877411	10087	38	9C
0005434877431	10087	39	9E
0005434877457	10087	40	9D
0005434877235	10087	41	9F
0005434877261	10087	42	10C
0005434910109	10087	43	10B
0005434877488	10087	44	10E
0005434877833	10087	45	10D
0005434877303	10087	46	11B
0005434910110	10087	47	11A
0005434877217	10087	48	11D
0005434877325	10087	49	11C
0005434877093	10087	50	11F
0005434877179	10087	51	11E
0005434877494	10087	52	12B
0005434877013	10087	53	12A
0005434877298	10087	54	12C
0005434877388	10087	55	12F
0005434877126	10087	56	12E
0005434877281	10087	57	12D
0005434877675	10087	58	13B
0005434877456	10087	59	13A
0005434877351	10087	60	13C
0005434877459	10087	61	13D
0005434877809	10087	62	14A
0005434877247	10087	63	13F
0005434877473	10087	64	14D
0005434877376	10087	65	14C
0005434877352	10087	66	14F
0005434877519	10087	67	14E
0005434877517	10087	68	15A
0005434877606	10087	69	15C
0005434877472	10087	70	15B
0005434877389	10087	71	15F
0005434877539	10087	72	15E
0005434877702	10087	73	15D
0005434877309	10087	74	16A
0005434877832	10087	75	16C
0005434877508	10087	76	16B
0005434877510	10087	77	16E
0005434910108	10087	78	16D
0005434877314	10087	79	17A
0005434877418	10087	80	16F
0005434877566	10087	81	17B
0005434877710	10087	82	17D
0005434877223	10087	83	17C
0005434877246	10087	84	18A
0005434877331	10087	85	17F
0005434877479	10087	86	18C
0005434877674	10087	87	18B
0005434877518	10087	88	18E
0005434877724	10087	89	18D
0005434877442	10087	90	19A
0005434877333	10087	91	18F
0005434877219	10087	92	19B
0005434877186	10087	93	19E
0005434877490	10087	94	19D
0005434877082	10087	95	19C
0005434877030	10087	96	20A
0005434877216	10087	97	19F
0005434877012	10087	98	20B
0005434877375	10087	99	20D
0005434877403	10087	100	20C
0005434877688	10087	101	20F
0005434877616	10087	102	21B
0005434877222	10087	103	21A
0005434877280	10087	104	21C
0005434877092	10087	105	21E
0005434877398	10087	106	21D
0005434877041	10087	107	21F
0005434878164	14625	1	1C
0005434878131	14625	2	1A
0005434878195	14625	3	1F
0005434878148	14625	4	1D
0005434878190	14625	5	2C
0005434878110	14625	6	2A
0005434878175	14625	7	2D
0005434878170	14625	8	3A
0005434878126	14625	9	2F
0005434878145	14625	10	3C
0005434878124	14625	11	4A
0005434878154	14625	12	3D
0005434878200	14625	13	4C
0005434910080	14625	14	4F
0005434878186	14625	15	4D
0005434878181	14625	16	5C
0005435913875	14625	17	5F
0005434878128	14625	18	5D
0005434878144	14625	19	6B
0005434878156	14625	20	6A
0005434878166	14625	21	6D
0005434878178	14625	22	6C
0005434878113	14625	23	6E
0005434878159	14625	24	7A
0005434878118	14625	25	6F
0005434878169	14625	26	7C
0005434878116	14625	27	7B
0005434878125	14625	28	7E
0005434878123	14625	29	7D
0005434878160	14625	30	8A
0005434878134	14625	31	7F
0005434878133	14625	32	8B
0005434878108	14625	33	8D
0005434878114	14625	34	8C
0005434878149	14625	35	8F
0005434878172	14625	36	9B
0005434878106	14625	37	9E
0005434878137	14625	38	9D
0005434878121	14625	39	10A
0005434910084	14625	40	10C
0005434878191	14625	41	10B
0005434878119	14625	42	10E
0005434878130	14625	43	10D
0005434878199	14625	44	10F
0005434878179	14625	45	11B
0005434878151	14625	46	11A
0005434878147	14625	47	11D
0005435913870	14625	48	11C
0005434878168	14625	49	11F
0005434878171	14625	50	11E
0005434878182	14625	51	12B
0005434878173	14625	52	12A
0005435913889	14625	53	12C
0005435913877	14625	54	12F
0005434878180	14625	55	12E
0005435913878	14625	56	13A
0005434878196	14625	57	13C
0005434878142	14625	58	13B
0005435913890	14625	59	13E
0005434878155	14625	60	14A
0005434878129	14625	61	13F
0005434878115	14625	62	14B
0005434878111	14625	63	14D
0005434878109	14625	64	14C
0005434878162	14625	65	14F
0005434878174	14625	66	14E
0005434878152	14625	67	15B
0005434878127	14625	68	15A
0005434878187	14625	69	15D
0005434878136	14625	70	15C
0005434878197	14625	71	15E
0005434878135	14625	72	16A
0005434878146	14625	73	15F
0005434878153	14625	74	16C
0005434878185	14625	75	16B
0005434878177	14625	76	16D
0005434878189	14625	77	17A
0005434878122	14625	78	16F
0005434878112	14625	79	16E
0005434878198	14625	80	17C
0005434878161	14625	81	17B
0005434878158	14625	82	17D
0005434878140	14625	83	17F
0005434878163	14625	84	17E
0005434878188	14625	85	18A
0005434910085	14625	86	18D
0005434878132	14625	87	18C
0005434878139	14625	88	18B
0005434878150	14625	89	18E
0005435913871	14625	90	18F
0005434878165	14625	91	19C
0005434878120	14625	92	19B
0005434878138	14625	93	19A
0005434878157	14625	94	19D
0005434878184	14625	95	20A
0005434878183	14625	96	19F
0005434910081	14625	97	19E
0005434878141	14625	98	20B
0005434910079	14625	99	20D
0005434878167	14625	100	20C
0005434878192	14625	101	20F
0005434878107	14625	102	20E
0005434878143	14625	103	21A
0005434878117	14625	104	21C
0005434878176	14625	105	21B
0005434878201	14625	106	21E
0005434878194	14625	107	21D
0005434878193	14625	108	21F
0005435660127	9239	1	1A
0005434251878	9239	2	1B
0005434251821	9239	3	2A
0005434251880	9239	4	2B
0005434251819	9239	5	3A
0005434251862	9239	6	3C
0005435660130	9239	7	3D
0005435660122	9239	8	4A
0005435660123	9239	9	4D
0005435660121	9239	10	5A
0005434251879	9239	11	5B
0005435660131	9239	12	5C
0005434251820	9239	13	6B
0005434251826	9239	14	18A
0005435660128	9239	15	18B
0005435660125	9239	16	19A
0005435660126	9239	17	20A
0005435660124	9239	18	21C
0005434251911	9239	19	21D
0005435660129	9239	20	22B
0005435660132	9239	21	23A
0005435660049	24642	1	1B
0005434251960	24642	2	2D
0005434251954	24642	3	3A
0005435660027	24642	4	3B
0005434251955	24642	5	3D
0005435659987	24642	6	4B
0005435660032	24642	7	5A
0005434251956	24642	8	5D
0005435660026	24642	9	6A
0005435660043	24642	10	6B
0005434251953	24642	11	6D
0005434251952	24642	12	7A
0005435660002	24642	13	7B
0005435659986	24642	14	19C
0005434251959	24642	15	20A
0005434251958	24642	16	20C
0005434251957	24642	17	21A
0005435660025	24642	18	21C
0005435660028	24642	19	21D
0005435660033	24642	20	22B
0005435660062	24642	21	23B
0005432966745	2792	1	1A
0005433680510	2792	2	1C
0005432966792	2792	3	1D
0005433680524	2792	4	1F
0005433680532	2792	5	2A
0005432966801	2792	6	2C
0005433680501	2792	7	2D
0005433680529	2792	8	2F
0005433680495	2792	9	3C
0005433680507	2792	10	3D
0005432966686	2792	11	4A
0005433680503	2792	12	4C
0005433680536	2792	13	4E
0005432966817	2792	14	4F
0005433680539	2792	15	5D
0005433680500	2792	16	5F
0005433680508	2792	17	6A
0005432222776	2792	18	6C
0005432966629	2792	19	6D
0005433680502	2792	20	6E
0005433680504	2792	21	6F
0005433680535	2792	22	7A
0005433680512	2792	23	7E
0005433680531	2792	24	8A
0005433680521	2792	25	8C
0005432966653	2792	26	8D
0005433680530	2792	27	8F
0005433680537	2792	28	9A
0005433684417	2792	29	9C
0005433680523	2792	30	9D
0005432222778	2792	31	9E
0005433680525	2792	32	9F
0005433680494	2792	33	10A
0005433680514	2792	34	10C
0005433680505	2792	35	10E
0005433680533	2792	36	10F
0005432966740	2792	37	11A
0005433684416	2792	38	11E
0005433680492	2792	39	11F
0005433680534	2792	40	12A
0005433680511	2792	41	12C
0005432966706	2792	42	12D
0005432966648	2792	43	12E
0005433680526	2792	44	12F
0005432966665	2792	45	13A
0005433680517	2792	46	13C
0005433680538	2792	47	13D
0005432966705	2792	48	13E
0005433680527	2792	49	13F
0005433680520	2792	50	14A
0005433680522	2792	51	14C
0005433680516	2792	52	14D
0005433680518	2792	53	14E
0005433680498	2792	54	14F
0005432966685	2792	55	15A
0005432222777	2792	56	15C
0005433680493	2792	57	15D
0005432966628	2792	58	15F
0005433680499	2792	59	16C
0005432966802	2792	60	16D
0005432966712	2792	61	16E
0005433680509	2792	62	17A
0005433680513	2792	63	17C
0005433680515	2792	64	17D
0005433680528	2792	65	17F
0005432966619	2792	66	18C
0005432222775	2792	67	18D
0005433680506	2792	68	18E
0005433680519	2792	69	19A
0005432966647	2792	70	19E
0005433680496	2792	71	20A
0005432966704	2792	72	19F
0005432966716	2792	73	20C
0005433684418	2792	74	20D
0005433680497	2792	75	20E
0005432005209	29164	1	1A
0005433680120	29164	2	1C
0005432966906	29164	3	2A
0005432966910	29164	4	2C
0005433680179	29164	5	2D
0005433684400	29164	6	2F
0005432966918	29164	7	3C
0005432966901	29164	8	3D
0005432966897	29164	9	3F
0005432966915	29164	10	4A
0005432966904	29164	11	4C
0005433680100	29164	12	4D
0005432966919	29164	13	4F
0005432005211	29164	14	5A
0005433680055	29164	15	5C
0005432966911	29164	16	5E
0005433680180	29164	17	5F
0005433680288	29164	18	6A
0005433680178	29164	19	6C
0005433680415	29164	20	6D
0005433680076	29164	21	6E
0005433680089	29164	22	7A
0005433680221	29164	23	7D
0005433680312	29164	24	7E
0005433680388	29164	25	8A
0005433679882	29164	26	8C
0005433680172	29164	27	8D
0005433679766	29164	28	8E
0005432966917	29164	29	8F
0005432966902	29164	30	9A
0005433680142	29164	31	9D
0005433684406	29164	32	9E
0005432966920	29164	33	9F
0005433680175	29164	34	10A
0005433680202	29164	35	10C
0005433680059	29164	36	10D
0005432966922	29164	37	10F
0005432966899	29164	38	11A
0005433679928	29164	39	11C
0005432966905	29164	40	11D
0005433680262	29164	41	11E
0005433680174	29164	42	12A
0005433690898	29164	43	12D
0005432966903	29164	44	12F
0005433680224	29164	45	13A
0005433680239	29164	46	13C
0005433680199	29164	47	13D
0005432966908	29164	48	13E
0005433680088	29164	49	13F
0005433680151	29164	50	14A
0005433687675	29164	51	14C
0005433680060	29164	52	14D
0005432966898	29164	53	14E
0005432966900	29164	54	15A
0005433680223	29164	55	15C
0005433680090	29164	56	15D
0005433680056	29164	57	15F
0005433679765	29164	58	16A
0005432966912	29164	59	16C
0005432966909	29164	60	16E
0005433690897	29164	61	16F
0005433680330	29164	62	17A
0005432966914	29164	63	17C
0005432966916	29164	64	17E
0005432966921	29164	65	18C
0005433680028	29164	66	18D
0005433680416	29164	67	18E
0005432966913	29164	68	18F
0005432966907	29164	69	19A
0005433687677	29164	70	19D
0005433680261	29164	71	19E
0005433687676	29164	72	19F
0005433679884	29164	73	20C
0005433680061	29164	74	20D
0005433684403	29164	75	20E
0005432005210	29164	76	20F
0005432145109	9318	1	1A
0005433614509	9318	2	1C
0005433614544	9318	3	1D
0005433614550	9318	4	2A
0005433614527	9318	5	1F
0005433614571	9318	6	2C
0005433577786	9318	7	2D
0005433614561	9318	8	3A
0005433614534	9318	9	3D
0005434152762	9318	10	3C
0005433633740	9318	11	4A
0005433614526	9318	12	3F
0005433577793	9318	13	4F
0005433614574	9318	14	4D
0005433633764	9318	15	5A
0005433577784	9318	16	5C
0005433633763	9318	17	5F
0005433614515	9318	18	5D
0005434269080	9318	19	6A
0005433633743	9318	20	6C
0005434163556	9318	21	6F
0005433614535	9318	22	6D
0005433614554	9318	23	7A
0005433577791	9318	24	7D
0005433633751	9318	25	7C
0005432755072	9318	26	8B
0005433614538	9318	27	8D
0005433614542	9318	28	8C
0005433614522	9318	29	8F
0005433614583	9318	30	9A
0005432756842	9318	31	9C
0005433633745	9318	32	9B
0005434272176	9318	33	9D
0005433614529	9318	34	9F
0005433614517	9318	35	10B
0005433577785	9318	36	10D
0005433614557	9318	37	10F
0005433614552	9318	38	11B
0005433614536	9318	39	11D
0005433614537	9318	40	11F
0005433614556	9318	41	12A
0005434163507	9318	42	12B
0005432756844	9318	43	12D
0005433633754	9318	44	12E
0005433614569	9318	45	12F
0005433633750	9318	46	13B
0005433614563	9318	47	13A
0005433614564	9318	48	13E
0005433577787	9318	49	13D
0005433614512	9318	50	13F
0005433577795	9318	51	14B
0005433614543	9318	52	14A
0005433633755	9318	53	14D
0005433614577	9318	54	14C
0005433614531	9318	55	14E
0005433614510	9318	56	15A
0005433614582	9318	57	14F
0005433614520	9318	58	15C
0005433614511	9318	59	15B
0005433633762	9318	60	15D
0005433614533	9318	61	15F
0005433614549	9318	62	15E
0005433614528	9318	63	16A
0005434269071	9318	64	16C
0005433614519	9318	65	16B
0005433614547	9318	66	16D
0005433614553	9318	67	16F
0005433577792	9318	68	16E
0005434163515	9318	69	17A
0005433633737	9318	70	17C
0005433577789	9318	71	17D
0005433633757	9318	72	17F
0005434163538	9318	73	17E
0005433577788	9318	74	18A
0005433614518	9318	75	18B
0005433614567	9318	76	18D
0005433614578	9318	77	18C
0005433614560	9318	78	18E
0005433633760	9318	79	18F
0005434269081	9318	80	19C
0005433614525	9318	81	19B
0005433614513	9318	82	19D
0005432145107	9318	83	19E
0005434269082	9318	84	20A
0005433614558	9318	85	20C
0005433633767	9318	86	20B
0005433614523	9318	87	20D
0005433633768	9318	88	20F
0005434163557	9318	89	21A
0005433633744	9318	90	21C
0005432755071	9318	91	21B
0005433633749	9318	92	21D
0005433633741	9318	93	21E
0005433614575	9318	94	21F
0005434272177	9318	95	22B
0005434163494	9318	96	22A
0005433614521	9318	97	22C
0005434163519	9318	98	22E
0005433633758	9318	99	22F
0005433633756	9318	100	23A
0005433614572	9318	101	23D
0005433614540	9318	102	23C
0005433633746	9318	103	23E
0005432756843	9318	104	24A
0005433614566	9318	105	23F
0005433614576	9318	106	24B
0005433614559	9318	107	24C
0005433577797	9318	108	24E
0005433633769	9318	109	24D
0005433614548	9318	110	24F
0005433614565	9318	111	25B
0005432145108	9318	112	25A
0005433614570	9318	113	25D
0005433614524	9318	114	25C
0005434163516	9318	115	25F
0005433614541	9318	116	25E
0005433633753	9318	117	26A
0005433633759	9318	118	26B
0005433633766	9318	119	26D
0005433614580	9318	120	26C
0005433577794	9318	121	26F
0005433633770	9318	122	26E
0005433614568	9318	123	27B
0005433614530	9318	124	27A
0005433614516	9318	125	27C
0005433633748	9318	126	27F
0005433614545	9318	127	27E
0005433614546	9318	128	28A
0005434269077	9318	129	28C
0005434152761	9318	130	28B
0005433633765	9318	131	28E
0005433633738	9318	132	28D
0005433614555	9318	133	28F
0005433614573	9318	134	29A
0005433614551	9318	135	29C
0005433577796	9318	136	29B
0005433633742	9318	137	29D
0005433633747	9318	138	29F
0005434163574	9318	139	30B
0005433614562	9318	140	30A
0005433614579	9318	141	30C
0005433614581	9318	142	30E
0005433614514	9318	143	30D
0005433614539	9318	144	30F
0005433633739	9318	145	31B
0005433633752	9318	146	31A
0005433614532	9318	147	31E
0005433633761	9318	148	31C
0005433577790	9318	149	31F
0005433613902	25250	1	1A
0005433614003	25250	2	1F
0005433633377	25250	3	1D
0005433577625	25250	4	2A
0005433633422	25250	5	2D
0005433613901	25250	6	2C
0005433633460	25250	7	3A
0005434163606	25250	8	2F
0005434163609	25250	9	3C
0005433633376	25250	10	3F
0005433614005	25250	11	3D
0005433633366	25250	12	4A
0005434163614	25250	13	4C
0005433614144	25250	14	5A
0005433633461	25250	15	4F
0005433614131	25250	16	5C
0005433633482	25250	17	5D
0005433614063	25250	18	6A
0005433633464	25250	19	5F
0005433577726	25250	20	6C
0005434163613	25250	21	6F
0005433633450	25250	22	6D
0005433613951	25250	23	7A
0005433613989	25250	24	7C
0005433613930	25250	25	7D
0005433613591	25250	26	8A
0005433614056	25250	27	8C
0005433633512	25250	28	8B
0005433633309	25250	29	8D
0005433613899	25250	30	8E
0005434163615	25250	31	8F
0005433614126	25250	32	9A
0005433614042	25250	33	9B
0005433613638	25250	34	9F
0005433613614	25250	35	9E
0005433633515	25250	36	10A
0005433614010	25250	37	10B
0005433633419	25250	38	10C
0005433633597	25250	39	10E
0005433614199	25250	40	11A
0005433613613	25250	41	10F
0005433633468	25250	42	11B
0005433614426	25250	43	11C
0005433613706	25250	44	11D
0005433577729	25250	45	12A
0005434272191	25250	46	12C
0005433633323	25250	47	12B
0005433613626	25250	48	12D
0005433633471	25250	49	12E
0005433614145	25250	50	12F
0005434163610	25250	51	13B
0005433613903	25250	52	13A
0005433613847	25250	53	13C
0005433633379	25250	54	13E
0005434163611	25250	55	13D
0005433633491	25250	56	13F
0005433614043	25250	57	14B
0005433614004	25250	58	14C
0005433577641	25250	59	14E
0005434163607	25250	60	14F
0005433614009	25250	61	15B
0005433633592	25250	62	15A
0005433633522	25250	63	15C
0005433633546	25250	64	15D
0005433613938	25250	65	15F
0005433633292	25250	66	15E
0005433577709	25250	67	16A
0005433633443	25250	68	16C
0005433577734	25250	69	16B
0005433613929	25250	70	16D
0005433633451	25250	71	16E
0005433613874	25250	72	17A
0005433613794	25250	73	17B
0005433633367	25250	74	17E
0005433633436	25250	75	17D
0005433613987	25250	76	18A
0005434163612	25250	77	18B
0005433633416	25250	78	18C
0005433633446	25250	79	18E
0005433614173	25250	80	18D
0005433613984	25250	81	18F
0005433613940	25250	82	19C
0005433577665	25250	83	19B
0005434163608	25250	84	19D
0005433614016	25250	85	20A
0005433633469	25250	86	20C
0005433577698	25250	87	20F
0005433633421	25250	88	20E
0005433613869	25250	89	21A
0005433633554	25250	90	21C
0005433577725	25250	91	21B
0005433613798	25250	92	21D
0005433613922	25250	93	22A
0005433613819	25250	94	21F
0005433633316	25250	95	22B
0005433613859	25250	96	22C
0005434272190	25250	97	22E
0005433614146	25250	98	22D
0005433613912	25250	99	22F
0005433613913	25250	100	23B
0005433614172	25250	101	23C
0005433613939	25250	102	23D
0005433613627	25250	103	23F
0005433633591	25250	104	23E
0005433613748	25250	105	24B
0005433633596	25250	106	24A
0005433613407	25250	107	24F
0005433613444	25250	108	24E
0005433613835	25250	109	25B
0005433633365	25250	110	25A
0005433613747	25250	111	25C
0005433614114	25250	112	25D
0005433633472	25250	113	25E
0005433633481	25250	114	26A
0005433613887	25250	115	25F
0005433577724	25250	116	26B
0005433633547	25250	117	26D
0005433614054	25250	118	26F
0005433613443	25250	119	26E
0005433613840	25250	120	27A
0005433613958	25250	121	27C
0005433613937	25250	122	27D
0005433613898	25250	123	27E
0005434272189	25250	124	28A
0005433633433	25250	125	28B
0005433613854	25250	126	28D
0005433633598	25250	127	28C
0005433633445	25250	128	28E
0005433613776	25250	129	28F
0005434273074	25250	130	29A
0005433613952	25250	131	29C
0005433613960	25250	132	29B
0005433613746	25250	133	29D
0005433633378	25250	134	29E
0005433613875	25250	135	30A
0005433577697	25250	136	30B
0005433613955	25250	137	30D
0005433633417	25250	138	30F
0005433613637	25250	139	30E
0005433613885	25250	140	31A
0005433633303	25250	141	31C
0005433614044	25250	142	31B
0005433633511	25250	143	31D
0005433633498	25250	144	31E
0005433614110	25250	145	31F
0005435947116	4222	1	1C
0005435947147	4222	2	2F
0005435947123	4222	3	4B
0005435947135	4222	4	9H
0005435947176	4222	5	12F
0005435986743	4222	6	13E
0005435986752	4222	7	13H
0005435947096	4222	8	14F
0005432571283	4222	9	18A
0005435947146	4222	10	18G
0005435986756	4222	11	19D
0005435947132	4222	12	19F
0005435947117	4222	13	20H
0005435986747	4222	14	21F
0005435986749	4222	15	21H
0005435986745	4222	16	22F
0005435986744	4222	17	23D
0005435947141	4222	18	24B
0005432571290	4222	19	24F
0005432571270	4222	20	24E
0005435986755	4222	21	27G
0005435856161	4222	22	28G
0005435947097	4222	23	30B
0005432571271	4222	24	30D
0005432184948	4222	25	30H
0005435856182	4222	26	31E
0005435947080	4222	27	31D
0005435947115	4222	28	31F
0005435986757	4222	29	31H
0005435856162	4222	30	32D
0005435986750	4222	31	34F
0005435986753	4222	32	35D
0005432571288	4222	33	35H
0005435986748	4222	34	36F
0005435986751	4222	35	36G
0005435986746	4222	36	37G
0005435986754	4222	37	38B
0005435986758	4222	38	38F
0005435947082	4222	39	39F
0005435947081	4222	40	39E
0005435947243	26614	1	1F
0005435947246	26614	2	2A
0005435986685	26614	3	2B
0005435986694	26614	4	2C
0005435947249	26614	5	2H
0005435947240	26614	6	3F
0005435986699	26614	7	4A
0005435947248	26614	8	5B
0005435986711	26614	9	5C
0005432571322	26614	10	11A
0005435856199	26614	11	11E
0005435947250	26614	12	11G
0005432571321	26614	13	12H
0005435856200	26614	14	12G
0005435947244	26614	15	13H
0005435947236	26614	16	14A
0005435986681	26614	17	16E
0005435986693	26614	18	16G
0005435856203	26614	19	18D
0005435947245	26614	20	19A
0005432571323	26614	21	19G
0005435986710	26614	22	20F
0005435986691	26614	23	22F
0005435787354	26614	24	22H
0005435986682	26614	25	24E
0005435947241	26614	26	24G
0005435947247	26614	27	25D
0005435856198	26614	28	27G
0005435947242	26614	29	28B
0005435986670	26614	30	28H
0005435947238	26614	31	29H
0005435856201	26614	32	32F
0005435947237	26614	33	32G
0005435986703	26614	34	33A
0005435986695	26614	35	33D
0005432571324	26614	36	36A
0005432571320	26614	37	36D
0005435856202	26614	38	37A
0005435947239	26614	39	38D
0005435986692	26614	40	38B
0005435947235	26614	41	39F
0005433569048	328	1	1A
0005433074371	328	2	1C
0005432947994	328	3	1F
0005433074489	328	4	1D
0005433569031	328	5	2D
0005433569030	328	6	3A
0005433568998	328	7	2F
0005432947834	328	8	3C
0005432948002	328	9	3F
0005432947873	328	10	3D
0005432948141	328	11	4F
0005432948114	328	12	5A
0005433074389	328	13	5C
0005432948051	328	14	5F
0005433569005	328	15	5D
0005433569036	328	16	6C
0005433569038	328	17	6A
0005432948034	328	18	6F
0005433074574	328	19	6D
0005433569037	328	20	7A
0005432948139	328	21	7C
0005432948140	328	22	7F
0005433074307	328	23	7D
0005433569044	328	24	8C
0005432948135	328	25	8B
0005432948077	328	26	8D
0005433074417	328	27	8E
0005432947836	328	28	8F
0005432947912	328	29	9B
0005433569046	328	30	9C
0005433569020	328	31	9E
0005433074323	328	32	9D
0005432948113	328	33	10A
0005433569006	328	34	9F
0005433569040	328	35	10C
0005433569001	328	36	10E
0005433129236	328	37	10D
0005433134101	328	38	10F
0005433569025	328	39	11A
0005432948101	328	40	11C
0005432948058	328	41	11B
0005432947835	328	42	11D
0005433074506	328	43	11E
0005433074405	328	44	12A
0005433569027	328	45	12B
0005433569008	328	46	12C
0005432948097	328	47	12E
0005433569032	328	48	12D
0005433074402	328	49	12F
0005433569015	328	50	13B
0005433074488	328	51	13A
0005433569035	328	52	13C
0005433074445	328	53	13D
0005433569009	328	54	13E
0005432947992	328	55	13F
0005432948184	328	56	14B
0005433569043	328	57	14D
0005433569011	328	58	14C
0005433074372	328	59	14F
0005432948036	328	60	15B
0005433569007	328	61	15A
0005433074533	328	62	15C
0005432948134	328	63	15D
0005433134100	328	64	15E
0005432947841	328	65	16A
0005432238929	328	66	16C
0005432947993	328	67	17A
0005432948138	328	68	16F
0005433568997	328	69	17B
0005433569000	328	70	17E
0005432238931	328	71	17D
0005433569047	328	72	17F
0005433074373	328	73	18C
0005433569014	328	74	18B
0005433569003	328	75	18D
0005432948198	328	76	18E
0005433569010	328	77	19B
0005433569021	328	78	18F
0005433569029	328	79	19C
0005433074478	328	80	19E
0005432948185	328	81	20B
0005433568994	328	82	20C
0005433074447	328	83	20D
0005433074468	328	84	20F
0005432948078	328	85	21B
0005433569017	328	86	21D
0005432947946	328	87	21C
0005433569042	328	88	21E
0005432948195	328	89	22A
0005433569034	328	90	21F
0005432947909	328	91	22B
0005433568999	328	92	22C
0005433074473	328	93	22E
0005432238933	328	94	22D
0005433569028	328	95	22F
0005433074507	328	96	23B
0005433074390	328	97	23A
0005433568995	328	98	23D
0005433569022	328	99	23C
0005433134102	328	100	23F
0005433569002	328	101	23E
0005432948048	328	102	24B
0005433569024	328	103	24A
0005432947874	328	104	24D
0005433569018	328	105	24F
0005433569045	328	106	24E
0005433074446	328	107	25B
0005433569026	328	108	25A
0005433074322	328	109	25C
0005433074308	328	110	25D
0005433569033	328	111	25E
0005433569019	328	112	26A
0005432948037	328	113	26B
0005433074532	328	114	26E
0005433074498	328	115	26D
0005432948041	328	116	26F
0005433074370	328	117	27C
0005432948063	328	118	27B
0005433569023	328	119	27D
0005433569041	328	120	27F
0005432948038	328	121	28A
0005432238930	328	122	28B
0005433569013	328	123	28D
0005433569016	328	124	28E
0005433074491	328	125	28F
0005432947975	328	126	29B
0005432238928	328	127	29D
0005432947976	328	128	29C
0005432948074	328	129	29E
0005433569012	328	130	30B
0005433568996	328	131	30E
0005432948047	328	132	30D
0005433569004	328	133	30F
0005432948112	328	134	31B
0005432238932	328	135	31C
0005433569039	328	136	31D
0005432948075	328	137	31E
0005433568309	11600	1	1C
0005433568412	11600	2	1F
0005433568320	11600	3	1D
0005433074668	11600	4	2D
0005433568409	11600	5	2C
0005432948395	11600	6	2F
0005433134132	11600	7	3D
0005433568255	11600	8	3A
0005432192316	11600	9	4A
0005432948422	11600	10	4D
0005433568277	11600	11	5A
0005433568386	11600	12	5F
0005433568317	11600	13	5D
0005433568329	11600	14	6C
0005433568339	11600	15	6F
0005432948429	11600	16	6D
0005433568144	11600	17	7A
0005433568124	11600	18	7D
0005432948409	11600	19	7C
0005433568390	11600	20	7F
0005432948394	11600	21	8C
0005433568138	11600	22	8B
0005433074679	11600	23	8D
0005433074689	11600	24	8E
0005433568349	11600	25	8F
0005432948408	11600	26	9B
0005432948391	11600	27	9A
0005433074671	11600	28	9C
0005433134135	11600	29	9D
0005433074664	11600	30	9F
0005432948400	11600	31	9E
0005433568330	11600	32	10A
0005433074688	11600	33	10B
0005433568331	11600	34	10C
0005432948420	11600	35	10D
0005433568032	11600	36	10F
0005433568244	11600	37	11B
0005432948406	11600	38	11A
0005432948389	11600	39	11D
0005433074681	11600	40	11C
0005433568369	11600	41	12A
0005432948418	11600	42	11F
0005432948419	11600	43	12C
0005432948390	11600	44	12D
0005433568100	11600	45	12E
0005432948407	11600	46	12F
0005432948416	11600	47	13B
0005432948405	11600	48	13A
0005433568389	11600	49	13C
0005433568399	11600	50	13D
0005432948431	11600	51	13F
0005433568141	11600	52	13E
0005433568303	11600	53	14A
0005433568145	11600	54	14D
0005432948414	11600	55	14C
0005433568282	11600	56	14E
0005433074667	11600	57	15A
0005432948417	11600	58	15C
0005433568410	11600	59	15D
0005433074672	11600	60	15F
0005432948397	11600	61	15E
0005433568387	11600	62	16C
0005432948424	11600	63	16B
0005433568264	11600	64	16D
0005433568340	11600	65	16E
0005433568391	11600	66	16F
0005433568326	11600	67	17E
0005433568148	11600	68	17D
0005433074677	11600	69	17F
0005432948393	11600	70	18A
0005433131705	11600	71	18B
0005433074684	11600	72	18D
0005433568267	11600	73	19B
0005432948415	11600	74	18F
0005432948410	11600	75	19D
0005433568117	11600	76	19C
0005432948401	11600	77	20A
0005432948396	11600	78	19E
0005432948430	11600	79	20B
0005433074678	11600	80	20C
0005432948428	11600	81	20E
0005433568310	11600	82	20D
0005432948399	11600	83	20F
0005433131703	11600	84	21A
0005432948412	11600	85	21B
0005433568315	11600	86	21C
0005433074669	11600	87	21D
0005432948425	11600	88	22A
0005432948413	11600	89	21F
0005432948403	11600	90	22B
0005432948402	11600	91	22D
0005433074680	11600	92	22C
0005433568328	11600	93	22F
0005433568388	11600	94	22E
0005433568411	11600	95	23A
0005432948392	11600	96	23C
0005433074670	11600	97	23B
0005432948426	11600	98	23F
0005433074676	11600	99	23E
0005433074673	11600	100	24B
0005433074682	11600	101	24A
0005433568357	11600	102	24C
0005433568408	11600	103	24E
0005433568398	11600	104	24D
0005433074687	11600	105	25A
0005433568274	11600	106	25B
0005433131702	11600	107	25D
0005433074686	11600	108	25C
0005433568281	11600	109	25E
0005433568301	11600	110	26A
0005433134133	11600	111	25F
0005433568278	11600	112	26B
0005433074685	11600	113	26C
0005432948421	11600	114	26F
0005433568263	11600	115	27A
0005433134131	11600	116	27D
0005433074690	11600	117	27C
0005433568220	11600	118	27E
0005433568275	11600	119	28A
0005433131704	11600	120	27F
0005433074675	11600	121	28B
0005433568426	11600	122	28C
0005433074665	11600	123	28E
0005432948427	11600	124	28F
0005433074674	11600	125	29B
0005433074683	11600	126	29A
0005432948423	11600	127	29D
0005433568125	11600	128	29E
0005433074666	11600	129	30A
0005432192318	11600	130	29F
0005432948404	11600	131	30B
0005433134134	11600	132	30C
0005433568146	11600	133	30E
0005432948398	11600	134	30D
0005433131701	11600	135	31A
0005432948411	11600	136	30F
0005433074691	11600	137	31D
0005432192317	11600	138	31F
0005433817468	10004	1	1A
0005433817466	10004	2	3A
0005434732954	10004	3	2B
0005433817465	10004	4	4A
0005434732956	10004	5	5B
0005433817469	10004	6	6A
0005433817467	10004	7	6B
0005434732978	13985	1	1A
0005433817422	13985	2	2A
0005433817450	13985	3	2B
0005433817451	13985	4	3A
0005433817432	13985	5	3B
0005433817428	13985	6	4B
0005434732979	13985	7	5A
0005434732977	13985	8	5B
0005433817431	13985	9	6B
0005435982243	2338	1	1A
0005433754197	2338	2	1B
0005433754183	2338	3	1F
0005435982279	2338	4	1C
0005434731133	2338	5	1G
0005432300256	2338	6	2A
0005432984862	2338	7	1H
0005432984672	2338	8	2C
0005432984641	2338	9	2B
0005433754152	2338	10	2G
0005433434452	2338	11	2F
0005435982287	2338	12	3A
0005433434367	2338	13	2H
0005433754149	2338	14	3C
0005435982259	2338	15	3B
0005435982290	2338	16	3F
0005433754179	2338	17	3G
0005433434363	2338	18	4A
0005432984671	2338	19	4B
0005432655525	2338	20	4C
0005435982269	2338	21	4G
0005433754176	2338	22	4F
0005433754164	2338	23	4H
0005433754182	2338	24	5B
0005435982268	2338	25	5A
0005432869438	2338	26	5C
0005432300258	2338	27	5G
0005435982284	2338	28	5F
0005435982257	2338	29	9A
0005432655527	2338	30	5H
0005433434490	2338	31	9B
0005432869457	2338	32	9G
0005432869458	2338	33	11B
0005434731145	2338	34	11E
0005433764679	2338	35	11D
0005433434549	2338	36	11F
0005433754143	2338	37	11G
0005435982253	2338	38	12A
0005432655528	2338	39	12D
0005433434297	2338	40	12B
0005435982258	2338	41	12E
0005433754146	2338	42	12G
0005433434413	2338	43	12F
0005435982246	2338	44	12H
0005433754150	2338	45	13A
0005433434425	2338	46	13D
0005432226051	2338	47	13B
0005433754195	2338	48	13E
0005433754169	2338	49	13G
0005433434440	2338	50	13F
0005432300259	2338	51	13H
0005433434557	2338	52	14A
0005432869442	2338	53	14D
0005435982266	2338	54	14F
0005433434357	2338	55	14E
0005432984801	2338	56	14H
0005433754172	2338	57	14G
0005433754160	2338	58	15A
0005435982264	2338	59	15B
0005433754189	2338	60	15E
0005433754155	2338	61	15D
0005432655532	2338	62	15F
0005432655522	2338	63	15H
0005432655531	2338	64	15G
0005433754174	2338	65	16A
0005432226054	2338	66	16D
0005432984755	2338	67	16B
0005433754194	2338	68	16E
0005435982282	2338	69	16F
0005432226049	2338	70	16H
0005435982247	2338	71	16G
0005435982252	2338	72	17F
0005435982263	2338	73	17E
0005432655529	2338	74	17D
0005433754192	2338	75	17G
0005435982256	2338	76	18B
0005433764677	2338	77	18A
0005432984667	2338	78	18D
0005433434381	2338	79	18E
0005432869443	2338	80	18G
0005435982289	2338	81	18F
0005435982273	2338	82	18H
0005432984895	2338	83	19B
0005432984787	2338	84	19A
0005433754166	2338	85	19D
0005432300260	2338	86	19F
0005433764678	2338	87	19E
0005435982274	2338	88	19H
0005435982276	2338	89	19G
0005433434491	2338	90	20A
0005433754165	2338	91	20D
0005432226050	2338	92	20B
0005435982249	2338	93	20E
0005433434427	2338	94	20F
0005433754144	2338	95	20H
0005435982244	2338	96	20G
0005433754163	2338	97	21A
0005435982280	2338	98	21D
0005432984894	2338	99	21B
0005435982250	2338	100	21E
0005433766635	2338	101	21G
0005433754187	2338	102	21F
0005433754148	2338	103	21H
0005432655521	2338	104	22A
0005435982277	2338	105	22D
0005432300255	2338	106	22B
0005433754180	2338	107	22E
0005435982262	2338	108	22G
0005433434296	2338	109	22F
0005435982291	2338	110	22H
0005433434556	2338	111	23B
0005433754188	2338	112	23A
0005435982278	2338	113	23D
0005433754162	2338	114	23E
0005433434442	2338	115	23G
0005435982281	2338	116	23F
0005435982270	2338	117	24A
0005432655523	2338	118	23H
0005432869468	2338	119	24B
0005433754178	2338	120	24E
0005432300261	2338	121	24D
0005432984668	2338	122	24F
0005432655526	2338	123	24H
0005435982265	2338	124	24G
0005433754186	2338	125	25D
0005432984677	2338	126	27A
0005435982260	2338	127	25F
0005433754198	2338	128	27B
0005432300262	2338	129	27D
0005433754161	2338	130	27F
0005435982285	2338	131	27E
0005433434439	2338	132	27H
0005432984655	2338	133	27G
0005435982275	2338	134	28A
0005432984724	2338	135	28D
0005432984759	2338	136	28B
0005435982272	2338	137	28E
0005433754157	2338	138	28G
0005432869439	2338	139	28F
0005435982241	2338	140	29A
0005433754173	2338	141	28H
0005433434375	2338	142	29D
0005435982271	2338	143	29B
0005433434380	2338	144	29E
0005432869446	2338	145	29G
0005432655530	2338	146	29F
0005433754191	2338	147	29H
0005433434366	2338	148	30B
0005433754154	2338	149	30A
0005432984741	2338	150	30D
0005433754181	2338	151	30F
0005433754153	2338	152	30E
0005435982255	2338	153	30G
0005433754199	2338	154	30H
0005435982283	2338	155	31B
0005433434412	2338	156	31A
0005433434419	2338	157	31D
0005432984714	2338	158	31F
0005433754142	2338	159	31E
0005433754170	2338	160	31G
0005433754184	2338	161	32A
0005432300257	2338	162	32D
0005433434550	2338	163	32B
0005435982251	2338	164	32E
0005435982261	2338	165	32F
0005433766637	2338	166	32H
0005433434350	2338	167	32G
0005432984715	2338	168	33A
0005432226056	2338	169	33D
0005433754167	2338	170	33B
0005433434420	2338	171	33E
0005433434356	2338	172	33F
0005433754168	2338	173	33H
0005432869440	2338	174	33G
0005433434432	2338	175	34B
0005434731123	2338	176	34A
0005435982286	2338	177	34D
0005435982288	2338	178	34F
0005433754158	2338	179	34G
0005432226053	2338	180	34H
0005435982254	2338	181	35A
0005435982267	2338	182	35D
0005433766636	2338	183	35B
0005432984820	2338	184	35F
0005435982242	2338	185	35E
0005432984860	2338	186	35G
0005432226052	2338	187	36B
0005434731124	2338	188	36A
0005433754175	2338	189	36E
0005433754171	2338	190	36D
0005433754151	2338	191	36F
0005433754193	2338	192	36G
0005432984725	2338	193	37A
0005432226055	2338	194	36H
0005435982245	2338	195	37B
0005435982248	2338	196	37E
0005434731134	2338	197	37D
0005433754196	2338	198	37F
0005433754177	2338	199	37H
0005433754145	2338	200	37G
0005432655533	2338	201	38A
0005432655524	2338	202	38D
0005433754159	2338	203	38B
0005432984863	2338	204	38F
0005433754185	2338	205	38E
0005433434426	2338	206	38H
0005433754156	2338	207	39D
0005433754147	2338	208	39F
0005433754190	2338	209	39E
0005434731168	26204	1	1A
0005433753753	26204	2	1B
0005433754008	26204	3	1F
0005433753832	26204	4	1C
0005433753475	26204	5	1G
0005435981944	26204	6	2A
0005432985061	26204	7	1H
0005432655414	26204	8	2B
0005433434663	26204	9	2F
0005435981543	26204	10	2G
0005433434651	26204	11	3A
0005433754007	26204	12	2H
0005433753713	26204	13	3F
0005435981868	26204	14	3G
0005433753522	26204	15	4A
0005435981832	26204	16	3H
0005433753654	26204	17	4B
0005433764655	26204	18	4F
0005432985031	26204	19	4C
0005433753671	26204	20	4G
0005432985064	26204	21	5A
0005432985056	26204	22	4H
0005432985054	26204	23	5B
0005433753879	26204	24	5C
0005432655420	26204	25	5G
0005435981874	26204	26	5F
0005435981694	26204	27	5H
0005432655397	26204	28	9B
0005433753793	26204	29	9A
0005432655385	26204	30	9G
0005435981688	26204	31	9H
0005433434643	26204	32	11B
0005433753569	26204	33	11A
0005435981668	26204	34	11E
0005432869512	26204	35	11D
0005432655384	26204	36	11G
0005435981731	26204	37	11F
0005435981717	26204	38	12A
0005432985034	26204	39	11H
0005435981686	26204	40	12D
0005433434640	26204	41	12B
0005433753612	26204	42	12E
0005432051124	26204	43	12G
0005433753397	26204	44	12F
0005433753680	26204	45	12H
0005432985032	26204	46	13A
0005433434657	26204	47	13B
0005432869515	26204	48	13E
0005432985053	26204	49	13D
0005433753611	26204	50	13G
0005435981687	26204	51	13F
0005433753784	26204	52	14A
0005433753521	26204	53	13H
0005433753814	26204	54	14B
0005435981650	26204	55	14D
0005432985057	26204	56	14F
0005432869518	26204	57	14G
0005435981771	26204	58	15A
0005433753756	26204	59	14H
0005433434662	26204	60	15B
0005432869516	26204	61	15E
0005435981732	26204	62	15D
0005432985035	26204	63	15F
0005433434645	26204	64	15G
0005433434650	26204	65	16A
0005435981994	26204	66	15H
0005433753773	26204	67	16B
0005433434654	26204	68	16F
0005433753786	26204	69	16E
0005433753494	26204	70	16D
0005433434648	26204	71	16H
0005432985047	26204	72	16G
0005433434655	26204	73	17D
0005433753789	26204	74	17B
0005435981679	26204	75	17E
0005432049461	26204	76	17G
0005433753714	26204	77	17F
0005432655357	26204	78	18A
0005432051125	26204	79	17H
0005432655348	26204	80	18B
0005432985051	26204	81	18D
0005435981913	26204	82	18F
0005433434659	26204	83	18E
0005435981985	26204	84	18H
0005432985046	26204	85	18G
0005433753749	26204	86	19A
0005433434667	26204	87	19B
0005432985059	26204	88	19D
0005435981826	26204	89	19G
0005432655358	26204	90	20A
0005432869514	26204	91	19H
0005432985055	26204	92	20D
0005433753564	26204	93	20B
0005432985042	26204	94	20E
0005435981799	26204	95	20F
0005432869517	26204	96	20H
0005432985048	26204	97	20G
0005433434644	26204	98	21A
0005433753598	26204	99	21B
0005434731167	26204	100	21E
0005433753677	26204	101	21D
0005432049460	26204	102	21F
0005432051126	26204	103	21G
0005435981833	26204	104	22A
0005435981667	26204	105	22D
0005435981733	26204	106	22B
0005433434658	26204	107	22F
0005433753708	26204	108	22E
0005432655413	26204	109	22G
0005433434666	26204	110	22H
0005433434646	26204	111	23B
0005432985040	26204	112	23A
0005433753621	26204	113	23E
0005433753771	26204	114	23D
0005432869513	26204	115	23F
0005433753539	26204	116	23G
0005432985049	26204	117	23H
0005435981761	26204	118	24B
0005432985037	26204	119	24A
0005435981945	26204	120	24D
0005433753643	26204	121	24F
0005435981693	26204	122	24E
0005433753790	26204	123	24H
0005435981797	26204	124	24G
0005435981544	26204	125	25E
0005433753759	26204	126	27A
0005433753651	26204	127	25F
0005433434649	26204	128	27B
0005433753899	26204	129	27E
0005435981980	26204	130	27D
0005433434668	26204	131	27F
0005433434642	26204	132	27G
0005433434656	26204	133	28A
0005433434660	26204	134	27H
0005435981875	26204	135	28D
0005435981876	26204	136	28B
0005432985062	26204	137	28E
0005433753721	26204	138	28G
0005435981730	26204	139	28F
0005433753889	26204	140	28H
0005432985041	26204	141	29A
0005433753747	26204	142	29D
0005435981781	26204	143	29B
0005432985033	26204	144	29G
0005435981986	26204	145	29F
0005433753613	26204	146	29H
0005433753511	26204	147	30B
0005432985060	26204	148	30A
0005432985039	26204	149	30D
0005433434661	26204	150	30E
0005433753788	26204	151	30G
0005433753709	26204	152	30F
0005434731166	26204	153	30H
0005433434665	26204	154	31B
0005432985038	26204	155	31E
0005432985050	26204	156	31D
0005433434647	26204	157	31F
0005433753907	26204	158	31G
0005433753631	26204	159	32A
0005432655396	26204	160	31H
0005433753794	26204	161	32B
0005432985043	26204	162	32E
0005435981946	26204	163	32D
0005433753731	26204	164	32F
0005435981914	26204	165	33A
0005432655347	26204	166	32H
0005433434652	26204	167	33B
0005432985058	26204	168	33G
0005432985052	26204	169	33F
0005435981831	26204	170	33H
0005433753970	26204	171	34A
0005433434641	26204	172	34D
0005433753563	26204	173	34E
0005433753748	26204	174	34G
0005433753760	26204	175	34H
0005432985036	26204	176	35B
0005433753770	26204	177	35A
0005433753795	26204	178	35D
0005433753615	26204	179	35E
0005432655386	26204	180	35F
0005432985063	26204	181	36A
0005432049459	26204	182	35H
0005435981659	26204	183	36B
0005435981896	26204	184	36D
0005433753396	26204	185	36F
0005432985045	26204	186	36E
0005433753732	26204	187	36H
0005433753653	26204	188	36G
0005435981869	26204	189	37B
0005435981551	26204	190	37A
0005432985044	26204	191	37D
0005433753902	26204	192	37G
0005433753728	26204	193	37E
0005433753461	26204	194	37H
0005433753746	26204	195	38A
0005435981710	26204	196	38B
0005435981760	26204	197	38E
0005432985065	26204	198	38D
0005435981685	26204	199	38G
0005433753720	26204	200	38F
0005433434664	26204	201	38H
0005433753783	26204	202	39D
0005433434653	26204	203	39F
0005433753761	26204	204	39E
0005432267892	1487	1	1A
0005434374632	1487	2	1C
0005433151136	1487	3	2C
0005434374619	1487	4	2A
0005434374631	1487	5	2F
0005434374610	1487	6	3A
0005433151221	1487	7	3D
0005434374617	1487	8	3C
0005434374611	1487	9	3F
0005433151032	1487	10	4A
0005434374627	1487	11	4B
0005434374623	1487	12	4C
0005433151164	1487	13	4E
0005432267886	1487	14	4F
0005434374628	1487	15	5B
0005433151033	1487	16	5A
0005433461586	1487	17	5D
0005433151232	1487	18	5E
0005433151096	1487	19	5F
0005434374629	1487	20	6B
0005433151149	1487	21	6C
0005433151161	1487	22	7A
0005434374613	1487	23	6F
0005434029621	1487	24	7B
0005434374622	1487	25	7E
0005433931428	1487	26	7F
0005433151089	1487	27	8A
0005433151109	1487	28	8B
0005433151120	1487	29	8C
0005434374620	1487	30	8E
0005433151121	1487	31	8D
0005432267889	1487	32	8F
0005433931437	1487	33	9B
0005434374605	1487	34	9D
0005432267887	1487	35	9C
0005433151163	1487	36	9E
0005433151159	1487	37	9F
0005434374626	1487	38	10C
0005433151046	1487	39	10B
0005433461587	1487	40	10D
0005433151108	1487	41	11A
0005433151117	1487	42	10E
0005434374616	1487	43	11C
0005433460433	1487	44	11D
0005433151162	1487	45	12A
0005434374615	1487	46	11F
0005433151113	1487	47	11E
0005433151082	1487	48	12C
0005434374630	1487	49	12D
0005433151030	1487	50	12F
0005434029622	1487	51	13C
0005433151029	1487	52	13B
0005433151194	1487	53	13D
0005433151141	1487	54	13E
0005433151122	1487	55	13F
0005433931438	1487	56	14A
0005434374612	1487	57	14D
0005434029629	1487	58	14C
0005433151222	1487	59	14E
0005433151112	1487	60	15A
0005433151158	1487	61	14F
0005433151140	1487	62	15B
0005433151068	1487	63	15C
0005433151135	1487	64	15D
0005434374609	1487	65	15E
0005434374614	1487	66	16A
0005433151212	1487	67	15F
0005433151142	1487	68	16C
0005434374621	1487	69	16D
0005434374607	1487	70	17A
0005433151160	1487	71	17D
0005433151224	1487	72	17C
0005433151097	1487	73	17F
0005434374608	1487	74	18B
0005434029624	1487	75	18A
0005432267888	1487	76	18C
0005434374618	1487	77	18E
0005433764659	1487	78	18F
0005433151165	1487	79	19A
0005433151174	1487	80	19C
0005433151205	1487	81	19D
0005433151015	1487	82	19F
0005434374625	1487	83	19E
0005433461585	1487	84	20A
0005434374606	1487	85	20B
0005434374633	1487	86	20D
0005432267890	1487	87	20E
0005434029623	1487	88	20F
0005433151034	1487	89	21A
0005434374624	1487	90	21B
0005433151095	1487	91	21E
0005433931432	1487	92	22A
0005433151087	1487	93	22C
0005433460434	1487	94	22B
0005433151014	1487	95	22D
0005433151088	1487	96	22E
0005433151269	1487	97	22F
0005434029625	1487	98	23B
0005432267891	1487	99	23A
0005434029628	1487	100	23F
0005433931429	1487	101	23E
0005434374119	20149	1	1A
0005434374045	20149	2	1C
0005433151372	20149	3	1D
0005434374250	20149	4	1F
0005433151389	20149	5	2C
0005434374232	20149	6	2D
0005434374163	20149	7	2F
0005433151357	20149	8	3A
0005434374169	20149	9	3D
0005433151359	20149	10	4A
0005433151362	20149	11	4C
0005434374351	20149	12	5B
0005433151381	20149	13	5A
0005433151383	20149	14	6B
0005434374090	20149	15	6A
0005434374325	20149	16	6C
0005433151366	20149	17	6D
0005433151371	20149	18	6E
0005433151363	20149	19	7A
0005434374205	20149	20	6F
0005434374283	20149	21	7B
0005433931461	20149	22	7C
0005434374361	20149	23	7D
0005433931463	20149	24	7E
0005434374275	20149	25	7F
0005434029656	20149	26	8D
0005433151379	20149	27	8C
0005434374233	20149	28	9A
0005433151365	20149	29	9B
0005434374352	20149	30	9E
0005433151364	20149	31	9D
0005433151370	20149	32	10E
0005434374128	20149	33	11A
0005434374065	20149	34	11B
0005434374129	20149	35	11C
0005433151376	20149	36	11E
0005434374172	20149	37	11F
0005434374251	20149	38	12B
0005434374190	20149	39	12D
0005434374003	20149	40	12C
0005433151375	20149	41	12F
0005433151373	20149	42	13B
0005434374284	20149	43	13A
0005432056294	20149	44	13D
0005433151386	20149	45	13C
0005434374274	20149	46	13F
0005433931460	20149	47	13E
0005434374095	20149	48	14A
0005433151385	20149	49	14C
0005433151369	20149	50	14B
0005433764677	20149	51	14F
0005433151368	20149	52	14E
0005434374216	20149	53	15B
0005433151388	20149	54	15A
0005433151377	20149	55	15E
0005434029655	20149	56	15D
0005433151360	20149	57	15C
0005434374120	20149	58	15F
0005433151361	20149	59	16A
0005434374204	20149	60	16E
0005433764678	20149	61	16F
0005433151367	20149	62	17B
0005433151380	20149	63	17D
0005433151390	20149	64	17E
0005434029654	20149	65	18A
0005434374287	20149	66	18C
0005434374244	20149	67	18D
0005432056293	20149	68	18F
0005434374203	20149	69	18E
0005432056295	20149	70	19C
0005434374339	20149	71	19B
0005433151387	20149	72	19F
0005433764679	20149	73	19E
0005433151374	20149	74	20A
0005434374285	20149	75	20C
0005434374255	20149	76	20D
0005434374212	20149	77	21A
0005434374229	20149	78	21C
0005433151382	20149	79	21B
0005434374256	20149	80	21F
0005432056296	20149	81	21E
0005433151358	20149	82	22B
0005433151378	20149	83	22A
0005434374282	20149	84	22C
0005434374228	20149	85	22D
0005434374307	20149	86	22E
0005434374139	20149	87	23B
0005434374362	20149	88	23A
0005434374360	20149	89	23C
0005433931462	20149	90	23F
0005433151384	20149	91	23E
0005432424388	491	1	2D
0005432282857	491	2	3C
0005432424380	491	3	3F
0005432424401	491	4	4C
0005432424405	491	5	4F
0005432424393	491	6	5F
0005432424404	491	7	5D
0005432424386	491	8	7D
0005432424398	491	9	8A
0005432424378	491	10	8B
0005432424418	491	11	8D
0005432282860	491	12	9D
0005432424409	491	13	10A
0005432424383	491	14	10E
0005432424379	491	15	10D
0005432424407	491	16	10F
0005432424419	491	17	11E
0005432424397	491	18	12A
0005432282859	491	19	11F
0005432424408	491	20	12B
0005432424390	491	21	13A
0005432424396	491	22	15E
0005432424384	491	23	15D
0005432424410	491	24	16B
0005432424413	491	25	16F
0005432282854	491	26	17A
0005432424402	491	27	18A
0005432424421	491	28	18C
0005432424381	491	29	18E
0005432424416	491	30	19E
0005432424395	491	31	20E
0005432424392	491	32	20F
0005432424377	491	33	21D
0005432282856	491	34	22C
0005432424406	491	35	22E
0005432424403	491	36	22D
0005432424417	491	37	23C
0005432424400	491	38	24E
0005432424411	491	39	25A
0005432282858	491	40	25F
0005432424382	491	41	26A
0005432424414	491	42	26B
0005432282855	491	43	26E
0005432424420	491	44	27B
0005432424415	491	45	27A
0005432424376	491	46	28E
0005432424412	491	47	28D
0005432424385	491	48	28F
0005432424387	491	49	30B
0005432424389	491	50	30E
0005432424394	491	51	30F
0005432424399	491	52	31E
0005432424391	491	53	31F
0005434446501	12845	1	1F
0005432302325	12845	2	7A
0005433158128	12845	3	10D
0005432302327	12845	4	13D
0005434446490	12845	5	14F
0005433158130	12845	6	19B
0005433158129	12845	7	23F
0005432302328	12845	8	27D
0005432302326	12845	9	30F
0005432423705	12923	1	1A
0005432424024	12923	2	1D
0005432423998	12923	3	2D
0005432423951	12923	4	3C
0005432424001	12923	5	4A
0005432423816	12923	6	5D
0005432423952	12923	7	6D
0005432423969	12923	8	8D
0005432423930	12923	9	8E
0005432423845	12923	10	9C
0005432423997	12923	11	9F
0005432423881	12923	12	9E
0005432423831	12923	13	10C
0005432423990	12923	14	11C
0005432423843	12923	15	11D
0005432423954	12923	16	12B
0005432423746	12923	17	12D
0005432423950	12923	18	12F
0005432423946	12923	19	13D
0005432423784	12923	20	13F
0005432424002	12923	21	14A
0005432423864	12923	22	14C
0005432423719	12923	23	14E
0005432424003	12923	24	15C
0005432423928	12923	25	15D
0005432424010	12923	26	16C
0005432423953	12923	27	16B
0005432423936	12923	28	16D
0005432423854	12923	29	16F
0005432423770	12923	30	17A
0005432423860	12923	31	17C
0005432424009	12923	32	17B
0005432423755	12923	33	18A
0005432423949	12923	34	18C
0005432423944	12923	35	18E
0005432424007	12923	36	19E
0005432423893	12923	37	20F
0005432423747	12923	38	21A
0005432423783	12923	39	21C
0005432423945	12923	40	22D
0005432423844	12923	41	23A
0005432423965	12923	42	24D
0005432423940	12923	43	25B
0005432423976	12923	44	25D
0005432423745	12923	45	25F
0005432423720	12923	46	27B
0005432423987	12923	47	28A
0005432423980	12923	48	29C
0005432423884	12923	49	29B
0005432423966	12923	50	29E
0005432423941	12923	51	29F
0005432423999	12923	52	30E
0005432423717	12923	53	31E
0005434023622	442	1	1B
0005434023624	442	2	1A
0005434029652	442	3	2C
0005433057711	442	4	2F
0005434023628	442	5	2H
0005434023661	442	6	3A
0005434023648	442	7	3B
0005434023653	442	8	3C
0005433057312	442	9	3G
0005434023675	442	10	3F
0005434032014	442	11	3H
0005434029651	442	12	4B
0005433057568	442	13	4F
0005434023634	442	14	4C
0005434023646	442	15	4G
0005434028293	442	16	4H
0005434023662	442	17	5F
0005433057378	442	18	5C
0005433057494	442	19	5G
0005434023614	442	20	5H
0005434023627	442	21	9G
0005434023641	442	22	11A
0005433057379	442	23	9H
0005433057542	442	24	11E
0005433057589	442	25	11G
0005434023667	442	26	11F
0005432235634	442	27	12A
0005433057563	442	28	11H
0005434029653	442	29	12D
0005433057751	442	30	12G
0005434023632	442	31	12H
0005433057547	442	32	13B
0005434023636	442	33	13A
0005434023630	442	34	13E
0005433057435	442	35	13H
0005434032017	442	36	14B
0005434023651	442	37	14D
0005434023647	442	38	14E
0005434023635	442	39	14G
0005434023664	442	40	14F
0005434023658	442	41	14H
0005434023655	442	42	15D
0005434023665	442	43	15B
0005433057557	442	44	15E
0005434735611	442	45	15F
0005434023676	442	46	15G
0005434023629	442	47	16A
0005433057446	442	48	16D
0005434023672	442	49	16G
0005432235630	442	50	16H
0005434023649	442	51	17B
0005434023652	442	52	17A
0005433057710	442	53	17D
0005434735608	442	54	17G
0005434023645	442	55	17F
0005434032018	442	56	18A
0005434023621	442	57	17H
0005433057386	442	58	18B
0005432235631	442	59	18E
0005434023650	442	60	18G
0005434023625	442	61	19A
0005434023679	442	62	19D
0005433057416	442	63	20F
0005434023674	442	64	20H
0005434023615	442	65	20G
0005434023659	442	66	21F
0005432235632	442	67	21E
0005433057695	442	68	21D
0005434735609	442	69	21H
0005434023678	442	70	22B
0005434032015	442	71	22A
0005434023620	442	72	22G
0005432235633	442	73	22H
0005434735633	442	74	23A
0005433057664	442	75	23E
0005434023612	442	76	23D
0005432045610	442	77	23G
0005433057449	442	78	23F
0005433057564	442	79	24A
0005434023669	442	80	24E
0005434023610	442	81	24D
0005434023657	442	82	24F
0005434023638	442	83	24G
0005433057663	442	84	24H
0005433929554	442	85	25F
0005434023626	442	86	27A
0005433057387	442	87	27B
0005434023670	442	88	27E
0005433057543	442	89	27D
0005433057512	442	90	27F
0005434023613	442	91	27G
0005433057445	442	92	28D
0005434023660	442	93	28B
0005434023656	442	94	28E
0005434028292	442	95	28F
0005434735612	442	96	29B
0005433057588	442	97	29E
0005433057480	442	98	29D
0005434735635	442	99	29G
0005434023618	442	100	29H
0005434023654	442	101	30A
0005432235627	442	102	30D
0005433057593	442	103	30F
0005434023671	442	104	30G
0005434023677	442	105	30H
0005433057752	442	106	31E
0005434023644	442	107	31D
0005434023617	442	108	31F
0005434023619	442	109	31G
0005434735623	442	110	31H
0005434023637	442	111	32E
0005433057648	442	112	32G
0005433057647	442	113	32F
0005433057546	442	114	32H
0005434023663	442	115	33B
0005434023616	442	116	33F
0005433057519	442	117	33H
0005434023673	442	118	33G
0005434023611	442	119	34B
0005434023642	442	120	34A
0005434735634	442	121	34D
0005434023643	442	122	34E
0005433057310	442	123	34H
0005433057595	442	124	35E
0005434023639	442	125	35B
0005433057594	442	126	36A
0005434023640	442	127	35H
0005433057520	442	128	36B
0005434032016	442	129	36D
0005434735610	442	130	36F
0005433057467	442	131	36E
0005433057450	442	132	36G
0005434023623	442	133	36H
0005433057628	442	134	37D
0005433057521	442	135	37B
0005432235629	442	136	37E
0005434023631	442	137	37F
0005434023668	442	138	38A
0005432235628	442	139	38D
0005434023633	442	140	38E
0005434023666	442	141	39E
0005434028294	442	142	39D
0005433057565	442	143	39F
0005434022968	12657	1	1B
0005434023092	12657	2	1G
0005434023218	12657	3	2A
0005434023270	12657	4	1H
0005434022961	12657	5	2C
0005434735683	12657	6	2B
0005433057855	12657	7	2F
0005433057846	12657	8	2G
0005434031986	12657	9	2H
0005433929608	12657	10	3B
0005434023306	12657	11	3A
0005434022950	12657	12	3C
0005434023323	12657	13	3G
0005433057866	12657	14	3H
0005434023364	12657	15	4B
0005434022899	12657	16	4A
0005434023055	12657	17	4C
0005434023048	12657	18	4G
0005434031973	12657	19	5A
0005434023108	12657	20	4H
0005433929610	12657	21	5C
0005434023235	12657	22	5G
0005434023147	12657	23	5F
0005433057840	12657	24	9A
0005433057851	12657	25	5H
0005434023247	12657	26	9B
0005434735686	12657	27	9G
0005434022946	12657	28	9H
0005434023027	12657	29	11B
0005434023050	12657	30	11E
0005433057849	12657	31	11G
0005434023025	12657	32	11F
0005434023180	12657	33	12B
0005434029624	12657	34	12E
0005434023109	12657	35	12G
0005434022927	12657	36	12F
0005434031976	12657	37	12H
0005434023240	12657	38	13A
0005433057836	12657	39	13D
0005434023132	12657	40	13B
0005434023129	12657	41	13E
0005434023278	12657	42	13G
0005433057848	12657	43	14B
0005434735685	12657	44	14A
0005434022801	12657	45	14D
0005434023179	12657	46	14F
0005434022967	12657	47	14E
0005434022951	12657	48	14H
0005434022918	12657	49	14G
0005434028263	12657	50	15D
0005434023008	12657	51	15B
0005433057828	12657	52	15F
0005434022998	12657	53	15G
0005433057857	12657	54	16B
0005433057863	12657	55	16A
0005434023099	12657	56	15H
0005434023399	12657	57	16D
0005434023200	12657	58	16E
0005434023114	12657	59	16G
0005433057845	12657	60	16F
0005433057832	12657	61	16H
0005434023028	12657	62	17B
0005434022944	12657	63	17D
0005434023236	12657	64	17F
0005434023133	12657	65	17H
0005434023110	12657	66	18F
0005434022926	12657	67	18G
0005434023089	12657	68	19D
0005434023093	12657	69	19B
0005434022759	12657	70	19A
0005434022758	12657	71	19E
0005434023227	12657	72	19G
0005434023094	12657	73	20A
0005434022919	12657	74	20D
0005433057837	12657	75	20B
0005433057847	12657	76	20E
0005433057843	12657	77	20F
0005434028268	12657	78	21A
0005434023303	12657	79	21D
0005433057829	12657	80	21G
0005433929609	12657	81	21F
0005434028269	12657	82	21H
0005434023023	12657	83	22A
0005433057853	12657	84	22B
0005434031977	12657	85	22E
0005434022879	12657	86	22G
0005434023042	12657	87	22F
0005434735687	12657	88	23A
0005432157489	12657	89	22H
0005434029621	12657	90	23D
0005432157490	12657	91	23F
0005433057842	12657	92	23E
0005433057831	12657	93	23G
0005432156361	12657	94	23H
0005433684420	12657	95	24E
0005434023140	12657	96	24D
0005433057835	12657	97	24F
0005434023398	12657	98	24G
0005434023226	12657	99	24H
0005434023105	12657	100	25F
0005434022958	12657	101	27B
0005434022945	12657	102	27D
0005433057852	12657	103	27F
0005433057827	12657	104	27E
0005434023163	12657	105	27H
0005434023056	12657	106	28G
0005432156363	12657	107	28H
0005434023305	12657	108	29D
0005434022809	12657	109	29B
0005433057859	12657	110	29E
0005434022799	12657	111	29H
0005434023195	12657	112	29G
0005434022878	12657	113	30A
0005433057841	12657	114	30D
0005432156362	12657	115	30B
0005434029629	12657	116	30F
0005433057830	12657	117	30E
0005434022800	12657	118	30G
0005433057860	12657	119	31A
0005433057833	12657	120	30H
0005433057838	12657	121	31B
0005434023237	12657	122	31F
0005434031970	12657	123	31E
0005434023077	12657	124	31G
0005434029622	12657	125	32A
0005432156359	12657	126	31H
0005433057854	12657	127	32B
0005434023024	12657	128	32D
0005434022783	12657	129	32F
0005434022625	12657	130	32E
0005434023241	12657	131	32H
0005434023049	12657	132	32G
0005434031972	12657	133	33A
0005434029625	12657	134	33D
0005433057864	12657	135	33G
0005434029628	12657	136	33H
0005433684419	12657	137	34A
0005433057850	12657	138	34D
0005434031962	12657	139	34B
0005434031963	12657	140	34F
0005434022784	12657	141	34G
0005433057865	12657	142	35A
0005433057834	12657	143	34H
0005434022939	12657	144	35B
0005434029623	12657	145	35D
0005434023034	12657	146	35F
0005433057862	12657	147	35G
0005434022818	12657	148	35H
0005434023246	12657	149	36B
0005434023279	12657	150	36A
0005432156360	12657	151	36F
0005434028270	12657	152	36E
0005433057844	12657	153	36H
0005433057839	12657	154	36G
0005434023026	12657	155	37B
0005434023148	12657	156	37D
0005434735684	12657	157	37F
0005434022992	12657	158	37H
0005433057856	12657	159	38D
0005434023100	12657	160	38B
0005434031959	12657	161	38E
0005434023145	12657	162	38G
0005434023146	12657	163	38F
0005433057867	12657	164	38H
0005433057858	12657	165	39F
0005433057861	12657	166	39E
0005433923159	2168	1	1A
0005433923174	2168	2	1C
0005433035750	2168	3	1B
0005433923195	2168	4	1F
0005433923243	2168	5	1H
0005433923223	2168	6	1G
0005433923241	2168	7	2A
0005433035578	2168	8	2C
0005433923247	2168	9	2F
0005433923197	2168	10	3A
0005432231552	2168	11	2H
0005433923235	2168	12	3B
0005433923192	2168	13	3F
0005433923217	2168	14	3C
0005433035719	2168	15	3G
0005433035767	2168	16	4A
0005433035794	2168	17	4B
0005433035979	2168	18	4C
0005433923218	2168	19	4G
0005433931462	2168	20	5A
0005433035763	2168	21	4H
0005433923181	2168	22	5B
0005433923178	2168	23	5F
0005433035996	2168	24	5C
0005433035766	2168	25	5G
0005433035772	2168	26	9A
0005433923176	2168	27	5H
0005433923163	2168	28	9B
0005432231550	2168	29	9H
0005433923175	2168	30	9G
0005433923171	2168	31	11A
0005433923216	2168	32	11B
0005432231555	2168	33	11D
0005433035843	2168	34	11F
0005433923188	2168	35	11E
0005433923252	2168	36	11H
0005433923189	2168	37	11G
0005433035709	2168	38	12B
0005433929609	2168	39	12A
0005432231557	2168	40	12E
0005433035760	2168	41	12D
0005433923211	2168	42	12G
0005433875374	2168	43	12F
0005433923201	2168	44	12H
0005433036019	2168	45	13B
0005433923215	2168	46	13A
0005433923224	2168	47	13F
0005432231548	2168	48	13E
0005433923182	2168	49	14A
0005433035798	2168	50	13H
0005433923209	2168	51	13G
0005433923203	2168	52	14B
0005432231559	2168	53	14E
0005433923239	2168	54	14F
0005433931461	2168	55	14H
0005433036020	2168	56	14G
0005433923242	2168	57	15A
0005433035729	2168	58	15D
0005433923158	2168	59	15B
0005434028270	2168	60	15E
0005433923212	2168	61	15G
0005434028268	2168	62	15F
0005433923199	2168	63	15H
0005433923236	2168	64	16A
0005433923214	2168	65	16D
0005433923190	2168	66	16F
0005433923226	2168	67	16E
0005433923238	2168	68	16H
0005433923177	2168	69	16G
0005433923196	2168	70	17A
0005433035833	2168	71	17D
0005433923254	2168	72	17E
0005433923250	2168	73	17G
0005433035815	2168	74	17F
0005433923164	2168	75	17H
0005433923173	2168	76	18A
0005433923167	2168	77	18D
0005433035644	2168	78	18B
0005433035813	2168	79	18F
0005432231549	2168	80	18G
0005433931463	2168	81	18H
0005433035796	2168	82	19A
0005432044521	2168	83	19D
0005433931460	2168	84	19F
0005433035890	2168	85	19G
0005433035652	2168	86	20A
0005434028269	2168	87	20B
0005433929857	2168	88	20E
0005433923244	2168	89	20F
0005433035751	2168	90	20H
0005433923245	2168	91	20G
0005433923183	2168	92	21A
0005432231556	2168	93	21D
0005433035934	2168	94	21B
0005433929610	2168	95	21E
0005433923210	2168	96	21F
0005433923230	2168	97	22A
0005433923185	2168	98	21H
0005433035642	2168	99	21G
0005433923207	2168	100	22B
0005433923253	2168	101	22F
0005433923255	2168	102	22E
0005433923234	2168	103	22H
0005433923172	2168	104	23B
0005433923198	2168	105	23A
0005432231551	2168	106	23E
0005433875376	2168	107	23F
0005433923219	2168	108	23G
0005433923162	2168	109	24A
0005433035831	2168	110	23H
0005432749760	2168	111	24B
0005433923200	2168	112	24E
0005432044522	2168	113	24F
0005433923246	2168	114	24H
0005433923240	2168	115	24G
0005433923233	2168	116	25D
0005433035783	2168	117	25E
0005433035811	2168	118	27A
0005433035761	2168	119	27D
0005433923229	2168	120	27B
0005433923161	2168	121	27E
0005433923204	2168	122	27F
0005432749757	2168	123	27G
0005433035579	2168	124	28A
0005433035935	2168	125	27H
0005433035773	2168	126	28D
0005433035836	2168	127	28B
0005433035795	2168	128	28E
0005433035742	2168	129	28F
0005433035620	2168	130	28H
0005433923160	2168	131	28G
0005433035787	2168	132	29B
0005433923168	2168	133	29D
0005433929608	2168	134	29E
0005433035684	2168	135	29F
0005433035723	2168	136	29H
0005432231558	2168	137	29G
0005434028263	2168	138	30A
0005433923225	2168	139	30D
0005433875375	2168	140	30E
0005433923231	2168	141	30G
0005433923170	2168	142	30F
0005433035866	2168	143	30H
0005433035869	2168	144	31B
0005433923187	2168	145	31A
0005433035814	2168	146	31D
0005433923249	2168	147	31F
0005433036070	2168	148	31E
0005432749761	2168	149	31H
0005433923205	2168	150	32A
0005433923179	2168	151	32D
0005432231554	2168	152	32F
0005432231553	2168	153	32E
0005433035870	2168	154	32H
0005433035721	2168	155	32G
0005433035812	2168	156	33A
0005433923220	2168	157	33B
0005433035619	2168	158	33E
0005433923221	2168	159	33D
0005433035724	2168	160	33G
0005433035992	2168	161	33F
0005433923213	2168	162	33H
0005432044520	2168	163	34A
0005433923186	2168	164	34D
0005433923237	2168	165	34E
0005433035857	2168	166	34G
0005433035781	2168	167	35A
0005433923193	2168	168	34H
0005433036105	2168	169	35B
0005433923166	2168	170	35D
0005433923208	2168	171	35E
0005433035825	2168	172	35G
0005433035643	2168	173	35F
0005433923180	2168	174	35H
0005433923191	2168	175	36B
0005433923251	2168	176	36D
0005433923228	2168	177	36F
0005433923222	2168	178	36E
0005433923165	2168	179	36G
0005433035871	2168	180	37A
0005433923227	2168	181	37B
0005433923194	2168	182	37E
0005433923206	2168	183	37F
0005433035829	2168	184	37H
0005433923202	2168	185	38B
0005433035832	2168	186	38A
0005433035641	2168	187	38D
0005433923232	2168	188	38E
0005433923184	2168	189	38F
0005433035683	2168	190	38H
0005433923169	2168	191	39E
0005433035914	2168	192	39D
0005433923248	2168	193	39F
0005433922169	24103	1	1A
0005433922716	24103	2	1C
0005433036247	24103	3	1G
0005433036232	24103	4	2A
0005433922499	24103	5	1H
0005433036228	24103	6	2B
0005432206191	24103	7	2F
0005433036226	24103	8	2C
0005433036257	24103	9	2G
0005433922330	24103	10	3A
0005433922897	24103	11	2H
0005433922303	24103	12	3B
0005433922444	24103	13	3F
0005432207659	24103	14	3G
0005433875369	24103	15	4A
0005433922652	24103	16	4B
0005432206188	24103	17	4C
0005433922740	24103	18	4G
0005433922300	24103	19	4F
0005433036251	24103	20	5A
0005433922110	24103	21	4H
0005433922627	24103	22	5B
0005433921880	24103	23	5C
0005433922600	24103	24	5G
0005433922393	24103	25	5F
0005433036238	24103	26	9A
0005433922276	24103	27	9B
0005433922480	24103	28	11A
0005433036221	24103	29	9H
0005433922605	24103	30	11B
0005433922377	24103	31	11E
0005433922443	24103	32	11H
0005433922297	24103	33	11G
0005433922465	24103	34	12B
0005433036233	24103	35	12A
0005433922309	24103	36	12F
0005433921982	24103	37	12E
0005433036258	24103	38	12D
0005433036224	24103	39	12H
0005433922197	24103	40	13B
0005433922304	24103	41	13D
0005433922356	24103	42	13G
0005433929574	24103	43	13H
0005432206189	24103	44	14B
0005433922829	24103	45	14A
0005433036262	24103	46	14E
0005433036225	24103	47	14G
0005433036227	24103	48	14F
0005433922413	24103	49	15A
0005433922018	24103	50	14H
0005433922299	24103	51	15D
0005433036240	24103	52	15G
0005433922648	24103	53	15F
0005433922558	24103	54	15E
0005433922170	24103	55	15H
0005433922580	24103	56	16B
0005433922011	24103	57	16A
0005433922394	24103	58	16D
0005433921796	24103	59	16F
0005433922666	24103	60	16E
0005433922198	24103	61	16G
0005432749783	24103	62	16H
0005433036263	24103	63	17B
0005433922421	24103	64	17A
0005433922481	24103	65	17D
0005433922390	24103	66	17F
0005432206187	24103	67	17E
0005433929588	24103	68	17G
0005433922271	24103	69	17H
0005433922266	24103	70	18B
0005433036223	24103	71	18A
0005433922582	24103	72	18D
0005433922642	24103	73	18F
0005433036268	24103	74	18E
0005433922512	24103	75	18G
0005433036264	24103	76	18H
0005433036273	24103	77	19B
0005433036267	24103	78	19A
0005433921795	24103	79	19F
0005433922725	24103	80	19E
0005433922581	24103	81	19G
0005433922366	24103	82	20A
0005433036242	24103	83	19H
0005433922448	24103	84	20B
0005432206190	24103	85	20D
0005433036249	24103	86	20F
0005433036231	24103	87	20E
0005433922308	24103	88	20H
0005432207660	24103	89	20G
0005433922331	24103	90	21B
0005433922109	24103	91	21A
0005433922376	24103	92	21D
0005433036252	24103	93	21E
0005433036253	24103	94	21G
0005433921819	24103	95	21F
0005433922626	24103	96	21H
0005433922896	24103	97	22A
0005433921820	24103	98	22D
0005432749782	24103	99	22B
0005433922483	24103	100	22F
0005433922482	24103	101	22E
0005433922610	24103	102	22G
0005433922665	24103	103	23A
0005433922559	24103	104	23E
0005433922156	24103	105	23D
0005433036236	24103	106	23B
0005433922673	24103	107	23F
0005433922708	24103	108	24A
0005433922355	24103	109	24B
0005433036248	24103	110	24D
0005433036241	24103	111	24F
0005433922579	24103	112	24G
0005433922707	24103	113	24H
0005433922054	24103	114	25E
0005433922196	24103	115	27A
0005433036239	24103	116	25F
0005433036269	24103	117	27B
0005433036235	24103	118	27D
0005433922828	24103	119	27F
0005433036245	24103	120	27G
0005433922424	24103	121	28D
0005433922672	24103	122	28B
0005433036243	24103	123	28F
0005433922647	24103	124	28G
0005433922562	24103	125	29A
0005433036230	24103	126	28H
0005433922199	24103	127	29B
0005433036266	24103	128	29E
0005433922168	24103	129	29F
0005433922341	24103	130	29H
0005433036234	24103	131	30B
0005433921914	24103	132	30A
0005433922599	24103	133	30D
0005433922409	24103	134	30F
0005433036271	24103	135	30E
0005433922294	24103	136	30G
0005433922214	24103	137	30H
0005433922019	24103	138	31B
0005433036261	24103	139	31A
0005433036259	24103	140	31D
0005433036237	24103	141	31F
0005433929573	24103	142	31E
0005433922047	24103	143	31H
0005433922714	24103	144	32A
0005433036244	24103	145	32E
0005433922644	24103	146	32F
0005433036270	24103	147	32G
0005433921778	24103	148	33A
0005433922715	24103	149	32H
0005433036222	24103	150	33D
0005433922302	24103	151	33B
0005433922528	24103	152	33E
0005433036254	24103	153	33F
0005433922041	24103	154	33H
0005433875368	24103	155	33G
0005433922452	24103	156	34A
0005433036250	24103	157	34D
0005433922296	24103	158	34F
0005433036272	24103	159	34E
0005433922332	24103	160	34G
0005433922340	24103	161	34H
0005433922466	24103	162	35B
0005433922484	24103	163	35A
0005433931436	24103	164	35D
0005433036255	24103	165	35F
0005433922248	24103	166	35E
0005433922277	24103	167	35G
0005433922252	24103	168	35H
0005433036229	24103	169	36B
0005432206192	24103	170	36A
0005433922265	24103	171	36D
0005433036246	24103	172	36F
0005433036256	24103	173	36E
0005433922695	24103	174	36G
0005433922479	24103	175	37A
0005433922369	24103	176	36H
0005433922363	24103	177	37B
0005433922383	24103	178	37E
0005433922401	24103	179	37D
0005433921766	24103	180	37F
0005433922531	24103	181	37H
0005433922496	24103	182	38A
0005433922437	24103	183	38D
0005433036265	24103	184	38B
0005433922402	24103	185	38E
0005433036260	24103	186	38F
0005433922336	24103	187	39D
0005433922378	24103	188	39E
0005433111474	273	1	1A
0005434551176	273	2	1C
0005433233361	273	3	1H
0005433233677	273	4	1G
0005434725395	273	5	2A
0005433233765	273	6	1K
0005434725374	273	7	2D
0005433233565	273	8	2C
0005434725386	273	9	2H
0005434725311	273	10	2G
0005434725367	273	11	3A
0005433233655	273	12	2K
0005433126788	273	13	3D
0005433180911	273	14	3C
0005434725379	273	15	3H
0005434725318	273	16	4A
0005433233445	273	17	3K
0005434725296	273	18	4G
0005434725349	273	19	4D
0005434725414	273	20	5A
0005435142560	273	21	4K
0005433180820	273	22	4H
0005433233813	273	23	5G
0005433111475	273	24	5D
0005434551207	273	25	11A
0005434725415	273	26	5K
0005434725335	273	27	11C
0005433233422	273	28	11F
0005433233644	273	29	11E
0005434551182	273	30	11H
0005434725305	273	31	11G
0005434551194	273	32	12C
0005434725327	273	33	12H
0005434725371	273	34	12G
0005434551156	273	35	12K
0005433233779	273	36	13D
0005434551192	273	37	13A
0005433126772	273	38	13F
0005434551197	273	39	13K
0005434725389	273	40	13H
0005434551169	273	41	13G
0005434551191	273	42	14A
0005433766580	273	43	14D
0005434031978	273	44	14F
0005433111480	273	45	14E
0005433233172	273	46	14K
0005434725337	273	47	14H
0005434725322	273	48	14G
0005433131678	273	49	15C
0005434725397	273	50	15A
0005433180804	273	51	15F
0005434725294	273	52	15E
0005434725364	273	53	15D
0005433233778	273	54	15H
0005434551178	273	55	15G
0005432277792	273	56	16A
0005433233691	273	57	15K
0005434725406	273	58	16C
0005434725340	273	59	16G
0005434731164	273	60	16F
0005433233494	273	61	16E
0005434725336	273	62	16D
0005434725295	273	63	16H
0005434551203	273	64	17A
0005434551208	273	65	16K
0005434725410	273	66	17E
0005434551211	273	67	17D
0005434551189	273	68	17C
0005434725383	273	69	17G
0005433126790	273	70	17F
0005434725344	273	71	17K
0005434735682	273	72	17H
0005434551166	273	73	18B
0005434731162	273	74	18A
0005432277790	273	75	18E
0005435142559	273	76	18D
0005433180893	273	77	18C
0005433180788	273	78	18H
0005433233569	273	79	18G
0005434725408	273	80	18F
0005434725315	273	81	18K
0005433233679	273	82	19B
0005434725307	273	83	19D
0005433131679	273	84	19C
0005434725357	273	85	19F
0005433233773	273	86	19E
0005433113510	273	87	19J
0005434551209	273	88	19H
0005433233656	273	89	19G
0005434725332	273	90	19K
0005433233500	273	91	20B
0005432277799	273	92	20A
0005433766595	273	93	20E
0005434725323	273	94	20D
0005434551162	273	95	20C
0005433233594	273	96	20G
0005434551198	273	97	20F
0005434725393	273	98	20K
0005433233570	273	99	20J
0005433180829	273	100	20H
0005434725331	273	101	21A
0005434725369	273	102	21D
0005434725330	273	103	21C
0005434551186	273	104	21B
0005433180817	273	105	21F
0005433233531	273	106	21E
0005432277791	273	107	21G
0005434725366	273	108	22A
0005434735680	273	109	21J
0005434551175	273	110	22C
0005434725350	273	111	22B
0005434551157	273	112	22E
0005433233496	273	113	22D
0005434735679	273	114	22G
0005432277794	273	115	22F
0005434725301	273	116	22J
0005434725299	273	117	23B
0005434725302	273	118	23A
0005435142557	273	119	22K
0005434731163	273	120	23E
0005433126789	273	121	23C
0005434725400	273	122	23F
0005434725300	273	123	23J
0005434551173	273	124	23G
0005434735678	273	125	23K
0005434725308	273	126	24E
0005434725298	273	127	25A
0005434551190	273	128	24G
0005434725413	273	129	25C
0005434725319	273	130	25E
0005433180834	273	131	25D
0005434725351	273	132	25H
0005435142568	273	133	25G
0005434725362	273	134	25F
0005434725325	273	135	26A
0005433233418	273	136	25K
0005434725378	273	137	25J
0005433766604	273	138	26C
0005434725380	273	139	26B
0005434725382	273	140	26E
0005434725398	273	141	26D
0005434735681	273	142	26H
0005434551165	273	143	26G
0005433180837	273	144	26F
0005434551185	273	145	27B
0005434551167	273	146	27A
0005434725358	273	147	26K
0005433180894	273	148	27D
0005435142565	273	149	27F
0005434031979	273	150	27E
0005433233342	273	151	27J
0005433233499	273	152	27H
0005432277797	273	153	27G
0005433233536	273	154	27K
0005434725412	273	155	28C
0005434551204	273	156	28B
0005435142567	273	157	28A
0005434302869	273	158	28E
0005434725297	273	159	28G
0005433233692	273	160	28F
0005434725329	273	161	28J
0005435142569	273	162	28H
0005434725333	273	163	29A
0005434725338	273	164	28K
0005434551177	273	165	29D
0005434551205	273	166	29C
0005433233742	273	167	29B
0005434725399	273	168	29F
0005433180912	273	169	29E
0005434731161	273	170	29J
0005433233481	273	171	29H
0005434302453	273	172	29G
0005434725370	273	173	30A
0005433233913	273	174	29K
0005433233841	273	175	30B
0005433233835	273	176	30E
0005432277802	273	177	30D
0005433233559	273	178	30G
0005434031964	273	179	30F
0005433233495	273	180	30K
0005434551159	273	181	30J
0005434725328	273	182	30H
0005432277798	273	183	31D
0005434725416	273	184	31B
0005434725341	273	185	31F
0005434551206	273	186	31E
0005433233451	273	187	31J
0005435142558	273	188	31H
0005434302456	273	189	31G
0005434551170	273	190	32A
0005434725403	273	191	31K
0005432277795	273	192	32C
0005433180819	273	193	32B
0005433111479	273	194	32E
0005433233621	273	195	32D
0005434551158	273	196	32G
0005435142561	273	197	32F
0005433766579	273	198	32K
0005434725377	273	199	32J
0005433180784	273	200	32H
0005433126793	273	201	33A
0005434725381	273	202	33D
0005433126773	273	203	33C
0005433766603	273	204	33B
0005433233614	273	205	33F
0005435142566	273	206	33E
0005434725372	273	207	33J
0005433233912	273	208	33H
0005434725347	273	209	33G
0005433233579	273	210	34B
0005434551164	273	211	34A
0005433233645	273	212	34E
0005434725396	273	213	34D
0005435142563	273	214	34G
0005433233586	273	215	34J
0005434725365	273	216	34H
0005434725317	273	217	35B
0005434551193	273	218	35A
0005434551200	273	219	34K
0005433233530	273	220	35C
0005434725376	273	221	35F
0005434551184	273	222	35E
0005434731165	273	223	35G
0005434725343	273	224	36A
0005434302872	273	225	35K
0005433233741	273	226	36D
0005434725355	273	227	36C
0005434302457	273	228	36B
0005434725368	273	229	36E
0005434551199	273	230	36G
0005434302455	273	231	36F
0005434725404	273	232	36J
0005434725409	273	233	36H
0005434725304	273	234	36K
0005434551168	273	235	37D
0005435142570	273	236	37C
0005433233632	273	237	37G
0005434725405	273	238	37F
0005434725361	273	239	37E
0005433233842	273	240	37J
0005433233343	273	241	37H
0005434725401	273	242	37K
0005434725314	273	243	38H
0005434551196	273	244	38C
0005434725390	273	245	38B
0005434551172	273	246	38J
0005434551180	273	247	39A
0005433180773	273	248	38K
0005433180841	273	249	39D
0005433126792	273	250	39E
0005434725356	273	251	39J
0005433233537	273	252	39H
0005434551161	273	253	39G
0005433233749	273	254	40A
0005434725342	273	255	40C
0005433233508	273	256	40B
0005433233557	273	257	40D
0005434551210	273	258	40H
0005433233674	273	259	40G
0005434725363	273	260	40F
0005434551171	273	261	40K
0005434551163	273	262	40J
0005434725313	273	263	41B
0005433233639	273	264	41A
0005434725384	273	265	41D
0005434725392	273	266	41C
0005434302454	273	267	41F
0005434725359	273	268	41E
0005433233379	273	269	41G
0005434551181	273	270	41K
0005434551202	273	271	41J
0005434725321	273	272	42B
0005432277801	273	273	42A
0005434725303	273	274	42E
0005434725324	273	275	42C
0005434725352	273	276	42F
0005434551195	273	277	42H
0005433233560	273	278	43A
0005433180818	273	279	42K
0005434725310	273	280	43D
0005432277800	273	281	43C
0005434725326	273	282	43H
0005433233638	273	283	44A
0005434302871	273	284	43J
0005434725345	273	285	44C
0005435142562	273	286	44B
0005432277796	273	287	44E
0005434031980	273	288	44G
0005434551174	273	289	44F
0005434725346	273	290	44J
0005434725353	273	291	44H
0005434725316	273	292	45B
0005434551188	273	293	45D
0005433233814	273	294	45F
0005433180883	273	295	45E
0005434725334	273	296	45H
0005434725388	273	297	45G
0005433766581	273	298	46C
0005434725387	273	299	46B
0005433233473	273	300	46E
0005433766605	273	301	46D
0005433233705	273	302	46G
0005434551179	273	303	46F
0005434551201	273	304	46J
0005434725339	273	305	46H
0005434551183	273	306	47C
0005433180836	273	307	47A
0005433180835	273	308	47E
0005433180886	273	309	47D
0005434725312	273	310	47G
0005434725391	273	311	47F
0005435142564	273	312	47K
0005433180840	273	313	48D
0005434725385	273	314	48C
0005433233789	273	315	48A
0005433233558	273	316	48E
0005432277793	273	317	48H
0005434725293	273	318	48G
0005434725411	273	319	48F
0005433180799	273	320	49A
0005434725360	273	321	49E
0005434725394	273	322	49D
0005434725407	273	323	49C
0005434551187	273	324	49K
0005434725375	273	325	49H
0005434725373	273	326	49G
0005434725306	273	327	50C
0005434725309	273	328	50E
0005434551160	273	329	50D
0005433131645	273	330	50G
0005434725402	273	331	50F
0005434725354	273	332	50K
0005434302870	273	333	50H
0005434725348	273	334	51F
0005434725320	273	335	51G
0005433234157	9821	1	1C
0005434550512	9821	2	1A
0005434724402	9821	3	1H
0005433234138	9821	4	1G
0005434724092	9821	5	1D
0005433181075	9821	6	2D
0005434724351	9821	7	2C
0005433181066	9821	8	2A
0005434550779	9821	9	2H
0005434724626	9821	10	3A
0005434723769	9821	11	2K
0005434724200	9821	12	3D
0005433234152	9821	13	3C
0005434724409	9821	14	3K
0005433181069	9821	15	3H
0005434550770	9821	16	3G
0005434725012	9821	17	4C
0005433289840	9821	18	4A
0005433181062	9821	19	4G
0005433234129	9821	20	5A
0005434724093	9821	21	4K
0005434724293	9821	22	4H
0005434724071	9821	23	5C
0005434550789	9821	24	5H
0005433181073	9821	25	5G
0005434735630	9821	26	5D
0005433181081	9821	27	11A
0005433234128	9821	28	5K
0005434724307	9821	29	11C
0005433129268	9821	30	11F
0005434724318	9821	31	11E
0005434550653	9821	32	11K
0005434724608	9821	33	11G
0005434724284	9821	34	12C
0005433234113	9821	35	12A
0005434724557	9821	36	12E
0005434724344	9821	37	12H
0005433234150	9821	38	12F
0005434550847	9821	39	12K
0005434032020	9821	40	13D
0005434724268	9821	41	13F
0005434723734	9821	42	13E
0005435142443	9821	43	13H
0005434724146	9821	44	13K
0005433766635	9821	45	14D
0005434723893	9821	46	14C
0005433234162	9821	47	14G
0005434724114	9821	48	14F
0005434724059	9821	49	14E
0005434724508	9821	50	14H
0005434724494	9821	51	15C
0005434724720	9821	52	15A
0005433234164	9821	53	14K
0005434550443	9821	54	15E
0005434724223	9821	55	15D
0005434724103	9821	56	15H
0005433181064	9821	57	15G
0005434724611	9821	58	15F
0005434550815	9821	59	16A
0005434724754	9821	60	15K
0005433181076	9821	61	16D
0005433234169	9821	62	16F
0005434724958	9821	63	16E
0005435142455	9821	64	16H
0005433234173	9821	65	16G
0005434724718	9821	66	17A
0005435142446	9821	67	16K
0005434550544	9821	68	17E
0005433234130	9821	69	17D
0005433234134	9821	70	17F
0005434550771	9821	71	17K
0005434550684	9821	72	17H
0005433126839	9821	73	18C
0005433234167	9821	74	18B
0005433234137	9821	75	18A
0005434735617	9821	76	18E
0005433181070	9821	77	18D
0005434731123	9821	78	18G
0005433129269	9821	79	18F
0005434724478	9821	80	18J
0005434724421	9821	81	18H
0005434723740	9821	82	19B
0005435142405	9821	83	18K
0005434302408	9821	84	19D
0005434724354	9821	85	19C
0005434550635	9821	86	19F
0005434032022	9821	87	19E
0005434550665	9821	88	19J
0005434550759	9821	89	19H
0005434724100	9821	90	19G
0005433181078	9821	91	20A
0005434550852	9821	92	19K
0005433234140	9821	93	20C
0005434724112	9821	94	20B
0005434550668	9821	95	20E
0005433129272	9821	96	20D
0005434550614	9821	97	20G
0005433234122	9821	98	20K
0005434550672	9821	99	20J
0005434735622	9821	100	20H
0005434550447	9821	101	21B
0005434724044	9821	102	21A
0005434550694	9821	103	21D
0005434724960	9821	104	21F
0005434550641	9821	105	21E
0005434724299	9821	106	21H
0005434724102	9821	107	21G
0005434724332	9821	108	21K
0005434724422	9821	109	21J
0005434724927	9821	110	22C
0005434724272	9821	111	22B
0005435142454	9821	112	22E
0005434550667	9821	113	22D
0005434724406	9821	114	22H
0005433234121	9821	115	22G
0005433234171	9821	116	22F
0005435142420	9821	117	22K
0005434724457	9821	118	22J
0005432199241	9821	119	23B
0005434723798	9821	120	23A
0005434724115	9821	121	23D
0005434724292	9821	122	23C
0005434735641	9821	123	23F
0005434724612	9821	124	23E
0005434724417	9821	125	23J
0005433181067	9821	126	23H
0005434724230	9821	127	24D
0005434724598	9821	128	23K
0005434724696	9821	129	24G
0005434724168	9821	130	24F
0005432199243	9821	131	24E
0005433181084	9821	132	25A
0005434724298	9821	133	25D
0005434724330	9821	134	25C
0005432199244	9821	135	25B
0005433234160	9821	136	25F
0005435142445	9821	137	25J
0005433234135	9821	138	25H
0005432199242	9821	139	25G
0005432199237	9821	140	25K
0005434550683	9821	141	26C
0005433234141	9821	142	26B
0005434724053	9821	143	26A
0005433234155	9821	144	26E
0005434724488	9821	145	26D
0005434724404	9821	146	26G
0005433234125	9821	147	26J
0005433181068	9821	148	27A
0005434550758	9821	149	27C
0005434724648	9821	150	27B
0005433181079	9821	151	27E
0005434724247	9821	152	27D
0005433234114	9821	153	27G
0005434724667	9821	154	27F
0005434724095	9821	155	28A
0005433126840	9821	156	27K
0005434550393	9821	157	27J
0005434724275	9821	158	28C
0005434724027	9821	159	28B
0005434550482	9821	160	28E
0005434723731	9821	161	28D
0005433234156	9821	162	28G
0005433234116	9821	163	28F
0005434724499	9821	164	28J
0005432199238	9821	165	28H
0005433181077	9821	166	29C
0005433289837	9821	167	29E
0005434550926	9821	168	29D
0005433126841	9821	169	29J
0005434724368	9821	170	29H
0005433234165	9821	171	29G
0005433289836	9821	172	30A
0005433234149	9821	173	29K
0005433234142	9821	174	30C
0005434724384	9821	175	30B
0005433289843	9821	176	30E
0005434723951	9821	177	30D
0005434724273	9821	178	30H
0005434723688	9821	179	30G
0005434724324	9821	180	30F
0005434724269	9821	181	30J
0005434731124	9821	182	31B
0005433234170	9821	183	30K
0005433181071	9821	184	31C
0005433126838	9821	185	31F
0005434724469	9821	186	31E
0005434724197	9821	187	31H
0005433234161	9821	188	31G
0005434724352	9821	189	31K
0005434724390	9821	190	31J
0005434724437	9821	191	32C
0005434724319	9821	192	32A
0005434550612	9821	193	32E
0005434724205	9821	194	32D
0005433181086	9821	195	32G
0005434032021	9821	196	32F
0005433181080	9821	197	32K
0005434724449	9821	198	32J
0005433234147	9821	199	32H
0005432199239	9821	200	33B
0005434724666	9821	201	33A
0005433234174	9821	202	33C
0005434724350	9821	203	33E
0005433181063	9821	204	33H
0005433181083	9821	205	34A
0005434724246	9821	206	33J
0005434731133	9821	207	34C
0005434724166	9821	208	34B
0005433766636	9821	209	34E
0005433234139	9821	210	34D
0005433234145	9821	211	34G
0005434731145	9821	212	34F
0005433234115	9821	213	34K
0005434550769	9821	214	34J
0005434724141	9821	215	34H
0005433234123	9821	216	35A
0005434724642	9821	217	35D
0005434724959	9821	218	35C
0005434724408	9821	219	35B
0005434723736	9821	220	35G
0005433234175	9821	221	35F
0005434724572	9821	222	35E
0005434550654	9821	223	35J
0005434724418	9821	224	35K
0005434724297	9821	225	36C
0005434550790	9821	226	36B
0005434724630	9821	227	36F
0005434723892	9821	228	36E
0005434550666	9821	229	36D
0005433234120	9821	230	36H
0005434724296	9821	231	36G
0005433289842	9821	232	36J
0005434550780	9821	233	37B
0005434724075	9821	234	36K
0005433234112	9821	235	37E
0005434724632	9821	236	37D
0005433289835	9821	237	37C
0005433234126	9821	238	37J
0005434724405	9821	239	38A
0005433234158	9821	240	37K
0005434032019	9821	241	38C
0005434724140	9821	242	38B
0005433181072	9821	243	38K
0005435142436	9821	244	38J
0005434724047	9821	245	38H
0005433181065	9821	246	39B
0005434550715	9821	247	39A
0005434550728	9821	248	39D
0005434550753	9821	249	39C
0005434724957	9821	250	39F
0005434724096	9821	251	39E
0005434550682	9821	252	39H
0005433234148	9821	253	39G
0005434550622	9821	254	39K
0005433766637	9821	255	39J
0005434550652	9821	256	40C
0005433181074	9821	257	40B
0005433234117	9821	258	40A
0005434724270	9821	259	40E
0005433234143	9821	260	40D
0005434735616	9821	261	40H
0005433234124	9821	262	40G
0005433234111	9821	263	40F
0005433289841	9821	264	40K
0005434724609	9821	265	40J
0005434724369	9821	266	41B
0005434550269	9821	267	41A
0005433234127	9821	268	41C
0005434724578	9821	269	41F
0005432199240	9821	270	41J
0005434724215	9821	271	41H
0005434550371	9821	272	41G
0005433289838	9821	273	41K
0005434731134	9821	274	42C
0005434724391	9821	275	42B
0005434724048	9821	276	42A
0005434724094	9821	277	42D
0005433113533	9821	278	42H
0005433181082	9821	279	42G
0005434723741	9821	280	42J
0005434550621	9821	281	43A
0005433129270	9821	282	42K
0005434724491	9821	283	43B
0005434550474	9821	284	43F
0005435142425	9821	285	43E
0005434724308	9821	286	43D
0005434550591	9821	287	43H
0005434724113	9821	288	43G
0005434724108	9821	289	44A
0005433234132	9821	290	43K
0005433234168	9821	291	43J
0005433289839	9821	292	44B
0005433129271	9821	293	44E
0005434724199	9821	294	44D
0005434550729	9821	295	44C
0005434724646	9821	296	44H
0005435142374	9821	297	44G
0005433234131	9821	298	44F
0005434724631	9821	299	44J
0005435142433	9821	300	45B
0005433234133	9821	301	45A
0005434724294	9821	302	45C
0005434550717	9821	303	45F
0005433234153	9821	304	45E
0005434550613	9821	305	45H
0005433234119	9821	306	46A
0005434550725	9821	307	45K
0005434550800	9821	308	45J
0005433234172	9821	309	46B
0005434724657	9821	310	46D
0005434724495	9821	311	46H
0005434735615	9821	312	46G
0005434723990	9821	313	47C
0005434724721	9821	314	47A
0005433234163	9821	315	46K
0005433234136	9821	316	47D
0005434302401	9821	317	47G
0005434724436	9821	318	47F
0005434735621	9821	319	48A
0005434724568	9821	320	47K
0005433181085	9821	321	47H
0005434724178	9821	322	48D
0005434724226	9821	323	48C
0005434724597	9821	324	48E
0005434724167	9821	325	48H
0005433234154	9821	326	48G
0005433234146	9821	327	49A
0005433234118	9821	328	48K
0005434724196	9821	329	49E
0005434724320	9821	330	49C
0005434725013	9821	331	49G
0005434550513	9821	332	49F
0005434724274	9821	333	49K
0005433234166	9821	334	49H
0005434724264	9821	335	50C
0005434724052	9821	336	50A
0005434724613	9821	337	50E
0005433234159	9821	338	50G
0005434724647	9821	339	50F
0005434724435	9821	340	51D
0005433234144	9821	341	50K
0005433113534	9821	342	50H
0005434724331	9821	343	51F
0005433126837	9821	344	51E
0005433234151	9821	345	51G
0005435212805	7773	1	1A
0005432527836	7773	2	1G
0005435212843	7773	3	1D
0005434067507	7773	4	2A
0005434067521	7773	5	1K
0005435212974	7773	6	1H
0005435212914	7773	7	2C
0005432527812	7773	8	2H
0005432533289	7773	9	2D
0005434067524	7773	10	3A
0005432527889	7773	11	3D
0005432527893	7773	12	3C
0005432069633	7773	13	3G
0005432527831	7773	14	4A
0005434067470	7773	15	4G
0005432527787	7773	16	4D
0005435212788	7773	17	5A
0005435212992	7773	18	4K
0005434067487	7773	19	5G
0005434067504	7773	20	11A
0005435212782	7773	21	5K
0005435212844	7773	22	5H
0005435213009	7773	23	11D
0005432527826	7773	24	11C
0005434067499	7773	25	11F
0005432527802	7773	26	11E
0005434067506	7773	27	11K
0005432527870	7773	28	11H
0005432150183	7773	29	11G
0005434067460	7773	30	12C
0005432527854	7773	31	12A
0005435212821	7773	32	12D
0005432069642	7773	33	12G
0005434067501	7773	34	13A
0005432527910	7773	35	12H
0005432527817	7773	36	13D
0005435212755	7773	37	13C
0005435725561	7773	38	13F
0005435213061	7773	39	13H
0005435212913	7773	40	13G
0005432527903	7773	41	14C
0005432527861	7773	42	13K
0005434067469	7773	43	14E
0005434067519	7773	44	14D
0005432527900	7773	45	14F
0005434067472	7773	46	14K
0005434067461	7773	47	14H
0005434067459	7773	48	14G
0005432150185	7773	49	15C
0005435213037	7773	50	15A
0005432527905	7773	51	15E
0005434067476	7773	52	15G
0005434067462	7773	53	15K
0005432527842	7773	54	16D
0005435213107	7773	55	16C
0005434067473	7773	56	16A
0005432069632	7773	57	16F
0005432527819	7773	58	16E
0005432527793	7773	59	16H
0005432150187	7773	60	16G
0005434067508	7773	61	17A
0005435212496	7773	62	16K
0005432069636	7773	63	17D
0005435212854	7773	64	17G
0005434067495	7773	65	17K
0005432527782	7773	66	17H
0005432527912	7773	67	18C
0005432527803	7773	68	18B
0005432527828	7773	69	18A
0005435213046	7773	70	18E
0005435213225	7773	71	18D
0005432535830	7773	72	18F
0005432527901	7773	73	18H
0005435213108	7773	74	19A
0005433656629	7773	75	19D
0005432527868	7773	76	19C
0005434067477	7773	77	19F
0005432527823	7773	78	19E
0005432069638	7773	79	19H
0005432527852	7773	80	19G
0005435213068	7773	81	20A
0005435212497	7773	82	19K
0005432527791	7773	83	20C
0005432527884	7773	84	20B
0005435212845	7773	85	20D
0005432527838	7773	86	20F
0005434067468	7773	87	20K
0005435212896	7773	88	20J
0005434067496	7773	89	21B
0005432527863	7773	90	21A
0005434067525	7773	91	21D
0005435213191	7773	92	21C
0005435212618	7773	93	21G
0005434067498	7773	94	21F
0005435212804	7773	95	21H
0005432527805	7773	96	22A
0005432069643	7773	97	21K
0005432527849	7773	98	22B
0005432527816	7773	99	22E
0005435725532	7773	100	22G
0005435213150	7773	101	22F
0005434067474	7773	102	22K
0005435212696	7773	103	22J
0005432527873	7773	104	22H
0005435212836	7773	105	23B
0005432527797	7773	106	23D
0005432069635	7773	107	23C
0005432537055	7773	108	23F
0005432527913	7773	109	23J
0005434067467	7773	110	23H
0005434067518	7773	111	23G
0005432527847	7773	112	24D
0005432527890	7773	113	23K
0005434067486	7773	114	24F
0005432537056	7773	115	24E
0005435213154	7773	116	25A
0005432527810	7773	117	25D
0005434067520	7773	118	25C
0005434067493	7773	119	25B
0005435630926	7773	120	25F
0005432527850	7773	121	25E
0005434067494	7773	122	25H
0005432527825	7773	123	25G
0005433656648	7773	124	26A
0005434067515	7773	125	25K
0005434067503	7773	126	26E
0005432527897	7773	127	26D
0005434067527	7773	128	26F
0005432527796	7773	129	26J
0005432527855	7773	130	26H
0005432069634	7773	131	27B
0005434067517	7773	132	27A
0005435212823	7773	133	26K
0005432527909	7773	134	27D
0005432527902	7773	135	27C
0005432069646	7773	136	27F
0005435212796	7773	137	27E
0005432535827	7773	138	27H
0005432150189	7773	139	27G
0005435213066	7773	140	27K
0005432527786	7773	141	27J
0005434067490	7773	142	28B
0005432527869	7773	143	28A
0005435213125	7773	144	28E
0005432527874	7773	145	28D
0005432527785	7773	146	28C
0005432527906	7773	147	28G
0005434067483	7773	148	28F
0005432527891	7773	149	28K
0005434067502	7773	150	28J
0005432527837	7773	151	29A
0005435212750	7773	152	29D
0005432527871	7773	153	29B
0005434067500	7773	154	29F
0005432527814	7773	155	29E
0005432527806	7773	156	29H
0005434067522	7773	157	29G
0005434067484	7773	158	30A
0005432150184	7773	159	29K
0005432069639	7773	160	29J
0005432527887	7773	161	30B
0005434067466	7773	162	30E
0005432527911	7773	163	30D
0005432428924	7773	164	30G
0005432150190	7773	165	30H
0005432527859	7773	166	31A
0005432527820	7773	167	31D
0005432527907	7773	168	31F
0005434067516	7773	169	31E
0005432527875	7773	170	31J
0005432527856	7773	171	31H
0005435630941	7773	172	32C
0005434067491	7773	173	32B
0005434067510	7773	174	32E
0005432527866	7773	175	32D
0005432535829	7773	176	32G
0005432527800	7773	177	32F
0005434067509	7773	178	32J
0005435213018	7773	179	33B
0005432150186	7773	180	33A
0005432527899	7773	181	33D
0005432527846	7773	182	33F
0005432527886	7773	183	33E
0005432527824	7773	184	33H
0005432533288	7773	185	33K
0005432527862	7773	186	33J
0005432150188	7773	187	34E
0005432537054	7773	188	34D
0005432527841	7773	189	34G
0005432527857	7773	190	34K
0005432527807	7773	191	34H
0005432527798	7773	192	35B
0005432527872	7773	193	35A
0005432527829	7773	194	35C
0005432527843	7773	195	35G
0005432527848	7773	196	35E
0005435212932	7773	197	35J
0005432527881	7773	198	35H
0005432527801	7773	199	36A
0005433656630	7773	200	35K
0005434067480	7773	201	36C
0005435212756	7773	202	36B
0005432527815	7773	203	36F
0005434067481	7773	204	36E
0005432527784	7773	205	36D
0005432527839	7773	206	36G
0005432527809	7773	207	36K
0005435212695	7773	208	36J
0005432527864	7773	209	37B
0005432527876	7773	210	37A
0005435212709	7773	211	37D
0005435213156	7773	212	37C
0005432527830	7773	213	37F
0005432527808	7773	214	37E
0005434067511	7773	215	37J
0005432527858	7773	216	37H
0005434067526	7773	217	37G
0005435212952	7773	218	38A
0005432527821	7773	219	37K
0005432527898	7773	220	38H
0005432069640	7773	221	38K
0005432527867	7773	222	38J
0005434067475	7773	223	39A
0005432527878	7773	224	39C
0005435212754	7773	225	39B
0005432527794	7773	226	39H
0005432527895	7773	227	39G
0005432527790	7773	228	40A
0005432069645	7773	229	39K
0005435213112	7773	230	39J
0005432527894	7773	231	40C
0005432428923	7773	232	40B
0005434067471	7773	233	40E
0005432527865	7773	234	40D
0005432527888	7773	235	40H
0005432428926	7773	236	40G
0005435212708	7773	237	40F
0005432527781	7773	238	40K
0005435212730	7773	239	40J
0005434067488	7773	240	41B
0005435213167	7773	241	41A
0005432527896	7773	242	41D
0005434067528	7773	243	41C
0005432527853	7773	244	41G
0005432527883	7773	245	41F
0005432527879	7773	246	41E
0005432527880	7773	247	41H
0005432527851	7773	248	41K
0005434067497	7773	249	41J
0005434067463	7773	250	42C
0005432527904	7773	251	42B
0005432527827	7773	252	42A
0005432533290	7773	253	42D
0005432527860	7773	254	42H
0005432527780	7773	255	42G
0005432527885	7773	256	42K
0005432527788	7773	257	42J
0005432527795	7773	258	43B
0005432527818	7773	259	43A
0005435213166	7773	260	43F
0005432535828	7773	261	43E
0005432527844	7773	262	43D
0005432527845	7773	263	43H
0005435212881	7773	264	43K
0005435213100	7773	265	43J
0005435212855	7773	266	44C
0005435213155	7773	267	44A
0005432527908	7773	268	44E
0005432527882	7773	269	44G
0005432527804	7773	270	44F
0005435725542	7773	271	44K
0005434067482	7773	272	44J
0005434067478	7773	273	44H
0005432428925	7773	274	45A
0005435213062	7773	275	45D
0005435212697	7773	276	45C
0005435213019	7773	277	45B
0005434067514	7773	278	45F
0005432069647	7773	279	45E
0005435212837	7773	280	45H
0005435213067	7773	281	45G
0005432527832	7773	282	46A
0005434067513	7773	283	45K
0005432527833	7773	284	46C
0005435213126	7773	285	46B
0005435212842	7773	286	46E
0005435212933	7773	287	46D
0005432527835	7773	288	46G
0005432069637	7773	289	46F
0005432527834	7773	290	46K
0005435212778	7773	291	46J
0005434067457	7773	292	46H
0005435212956	7773	293	47A
0005432533287	7773	294	47E
0005432527822	7773	295	47D
0005432527783	7773	296	47G
0005432527811	7773	297	47K
0005434067512	7773	298	47H
0005434067492	7773	299	48D
0005432527792	7773	300	48E
0005432527799	7773	301	48H
0005435213026	7773	302	48G
0005435212824	7773	303	49A
0005432069641	7773	304	48K
0005434067523	7773	305	49D
0005432069644	7773	306	49C
0005432527813	7773	307	49G
0005432527789	7773	308	49F
0005434067465	7773	309	49E
0005435213047	7773	310	49K
0005434067479	7773	311	49H
0005435213038	7773	312	50D
0005432527840	7773	313	50C
0005434067489	7773	314	50E
0005434067485	7773	315	50G
0005435725533	7773	316	50F
0005434067458	7773	317	51D
0005432527892	7773	318	50K
0005434067505	7773	319	51F
0005434067464	7773	320	51E
0005432527877	7773	321	51G
0005435424296	5317	1	1D
0005434244604	5317	2	1C
0005435613499	5317	3	1A
0005435613492	5317	4	2A
0005434344201	5317	5	1H
0005432133200	5317	6	2C
0005435613536	5317	7	2G
0005435613562	5317	8	3A
0005435424362	5317	9	2K
0005434573343	5317	10	2H
0005435380230	5317	11	3D
0005434344196	5317	12	3C
0005435424064	5317	13	3H
0005435424198	5317	14	3G
0005435613528	5317	15	4A
0005434244693	5317	16	4G
0005434244660	5317	17	4D
0005434573338	5317	18	4K
0005432133198	5317	19	4H
0005435613526	5317	20	5D
0005435490223	5317	21	5C
0005435613489	5317	22	5A
0005435097195	5317	23	5G
0005435042828	5317	24	11A
0005435613560	5317	25	5K
0005434244731	5317	26	11D
0005435424176	5317	27	11C
0005435424632	5317	28	11G
0005435613502	5317	29	11K
0005435613520	5317	30	11H
0005435613551	5317	31	12A
0005435423997	5317	32	12F
0005435613507	5317	33	12E
0005435424429	5317	34	12C
0005435097197	5317	35	12G
0005434344183	5317	36	12K
0005432133194	5317	37	12H
0005435424315	5317	38	13D
0005435424124	5317	39	13C
0005432840997	5317	40	13A
0005435613538	5317	41	13F
0005434344199	5317	42	13H
0005434244691	5317	43	14C
0005435613575	5317	44	14A
0005433719106	5317	45	14D
0005435424199	5317	46	14G
0005434244675	5317	47	14F
0005435424045	5317	48	14E
0005435613516	5317	49	14H
0005435319495	5317	50	15C
0005435424223	5317	51	14K
0005435424487	5317	52	15E
0005435097196	5317	53	15G
0005434344175	5317	54	16A
0005434344197	5317	55	15K
0005435424402	5317	56	15H
0005432363383	5317	57	16D
0005435613547	5317	58	16C
0005435424214	5317	59	16F
0005435555367	5317	60	16E
0005435424139	5317	61	16H
0005435613577	5317	62	16G
0005435613553	5317	63	17C
0005435424159	5317	64	17A
0005435424452	5317	65	17G
0005434573340	5317	66	17F
0005435613500	5317	67	18A
0005434344209	5317	68	17K
0005435424261	5317	69	17H
0005432133191	5317	70	18E
0005435097192	5317	71	18D
0005435424425	5317	72	18C
0005435613504	5317	73	18G
0005435613580	5317	74	18F
0005435613498	5317	75	18K
0005435319494	5317	76	18J
0005435424248	5317	77	18H
0005435424363	5317	78	19A
0005434573334	5317	79	19C
0005435424260	5317	80	19G
0005435613496	5317	81	19F
0005434573341	5317	82	19E
0005435613537	5317	83	19H
0005435424083	5317	84	20A
0005435613558	5317	85	19K
0005435613501	5317	86	19J
0005435424331	5317	87	20B
0005435424158	5317	88	20E
0005434344208	5317	89	20G
0005435424360	5317	90	20F
0005435424295	5317	91	20J
0005434244697	5317	92	20H
0005435097191	5317	93	21B
0005435613564	5317	94	21A
0005435613512	5317	95	20K
0005435042826	5317	96	21D
0005435613546	5317	97	21C
0005435423947	5317	98	21F
0005435613505	5317	99	21E
0005435424251	5317	100	21J
0005435042835	5317	101	21H
0005435613555	5317	102	21G
0005434244736	5317	103	22A
0005435424151	5317	104	21K
0005435613511	5317	105	22C
0005435613533	5317	106	22B
0005435424403	5317	107	22E
0005435424330	5317	108	22D
0005434344191	5317	109	22H
0005434344185	5317	110	22G
0005435424027	5317	111	22F
0005432840998	5317	112	22K
0005434344177	5317	113	22J
0005434244662	5317	114	23B
0005435613574	5317	115	23A
0005434344205	5317	116	23C
0005435424479	5317	117	23G
0005434344184	5317	118	23E
0005432133190	5317	119	23H
0005434573345	5317	120	24D
0005435613493	5317	121	23K
0005434244673	5317	122	24E
0005435613494	5317	123	25A
0005433719096	5317	124	24G
0005434573337	5317	125	25D
0005435302143	5317	126	25B
0005434573335	5317	127	25F
0005434344194	5317	128	25E
0005435424314	5317	129	25G
0005433719095	5317	130	26A
0005434244624	5317	131	25K
0005435613532	5317	132	25J
0005435613556	5317	133	26B
0005435555366	5317	134	26E
0005434244668	5317	135	26D
0005434244679	5317	136	26H
0005435490225	5317	137	26G
0005435302145	5317	138	26F
0005435613518	5317	139	26J
0005433719104	5317	140	27A
0005434344193	5317	141	26K
0005435613521	5317	142	27D
0005435097193	5317	143	27C
0005435424097	5317	144	27B
0005435319486	5317	145	27F
0005432133192	5317	146	27E
0005434244807	5317	147	27G
0005432363375	5317	148	27J
0005435613583	5317	149	28C
0005434244663	5317	150	28B
0005434344180	5317	151	28A
0005435613573	5317	152	28E
0005435613548	5317	153	28G
0005435613519	5317	154	28F
0005435491439	5317	155	28J
0005435613569	5317	156	29B
0005435319485	5317	157	28K
0005435613508	5317	158	29D
0005435302154	5317	159	29C
0005435613525	5317	160	29F
0005434344203	5317	161	29E
0005432363374	5317	162	29J
0005434244664	5317	163	29H
0005435613566	5317	164	30A
0005434573339	5317	165	29K
0005435613510	5317	166	30C
0005432133188	5317	167	30B
0005435613571	5317	168	30E
0005435613515	5317	169	30D
0005435424322	5317	170	30G
0005435424426	5317	171	30H
0005434573342	5317	172	31A
0005435424130	5317	173	31C
0005435490222	5317	174	31F
0005435613514	5317	175	31E
0005434344202	5317	176	31H
0005434244615	5317	177	31G
0005435613543	5317	178	31K
0005434244674	5317	179	31J
0005435424384	5317	180	32C
0005435380258	5317	181	32B
0005435613535	5317	182	32E
0005435424392	5317	183	32D
0005432133196	5317	184	32G
0005435424294	5317	185	32F
0005435424179	5317	186	32K
0005435424143	5317	187	32H
0005435319514	5317	188	33B
0005435613554	5317	189	33A
0005432047547	5317	190	33D
0005435319489	5317	191	33C
0005435613490	5317	192	33G
0005434573346	5317	193	33F
0005435613517	5317	194	33H
0005434344192	5317	195	33K
0005434344200	5317	196	33J
0005434244623	5317	197	34A
0005432133189	5317	198	34E
0005434344207	5317	199	34D
0005434656541	5317	200	34C
0005435424194	5317	201	34G
0005435613524	5317	202	34K
0005435424423	5317	203	34J
0005435613584	5317	204	34H
0005435097198	5317	205	35B
0005435613550	5317	206	35A
0005434244667	5317	207	35C
0005435424408	5317	208	35G
0005434244676	5317	209	35E
0005434344181	5317	210	35H
0005435613523	5317	211	36A
0005435424090	5317	212	35K
0005435042827	5317	213	35J
0005435097190	5317	214	36C
0005435380257	5317	215	36B
0005432047546	5317	216	36D
0005435302151	5317	217	36G
0005435613487	5317	218	36F
0005434344178	5317	219	36K
0005435424028	5317	220	36J
0005435424226	5317	221	37B
0005435613531	5317	222	37A
0005434344179	5317	223	37D
0005434344187	5317	224	37G
0005434344206	5317	225	37F
0005435319503	5317	226	37E
0005435613582	5317	227	37J
0005435424542	5317	228	37H
0005435613570	5317	229	38A
0005435424377	5317	230	38C
0005435613506	5317	231	38B
0005435424391	5317	232	39B
0005434244823	5317	233	39A
0005434344176	5317	234	38K
0005435613565	5317	235	39D
0005434344210	5317	236	39C
0005435613578	5317	237	39F
0005435302150	5317	238	39E
0005435424424	5317	239	39H
0005434656546	5317	240	39G
0005434244806	5317	241	39K
0005435424407	5317	242	40C
0005434344204	5317	243	40B
0005435424133	5317	244	40E
0005434244824	5317	245	40D
0005435490224	5317	246	40G
0005435613561	5317	247	40F
0005434573333	5317	248	40J
0005434344195	5317	249	40H
0005432047545	5317	250	41B
0005435613544	5317	251	41A
0005432133193	5317	252	40K
0005435613572	5317	253	41D
0005435423948	5317	254	41C
0005435424281	5317	255	41F
0005434573336	5317	256	41E
0005434244730	5317	257	41J
0005435613542	5317	258	41H
0005434573344	5317	259	42A
0005432133199	5317	260	41K
0005435302153	5317	261	42C
0005432133201	5317	262	42B
0005434344182	5317	263	42E
0005434244735	5317	264	42G
0005435424046	5317	265	42F
0005435424282	5317	266	42J
0005435613557	5317	267	42H
0005435424416	5317	268	43B
0005435613529	5317	269	43A
0005435613559	5317	270	42K
0005435613495	5317	271	43C
0005435424175	5317	272	43F
0005435613513	5317	273	43E
0005435613549	5317	274	43H
0005434344174	5317	275	43G
0005435424263	5317	276	43K
0005432133202	5317	277	43J
0005435097194	5317	278	44B
0005434344188	5317	279	44E
0005435302142	5317	280	44D
0005435424253	5317	281	44C
0005435380259	5317	282	44G
0005435424390	5317	283	44F
0005435613509	5317	284	44K
0005435042833	5317	285	44J
0005434244661	5317	286	44H
0005435424084	5317	287	45A
0005435424123	5317	288	45D
0005435613576	5317	289	45C
0005435613540	5317	290	45F
0005435424293	5317	291	45E
0005435613497	5317	292	45H
0005435424427	5317	293	45G
0005435424415	5317	294	45K
0005435613545	5317	295	45J
0005435490226	5317	296	46A
0005435613534	5317	297	46E
0005435613579	5317	298	46D
0005435613541	5317	299	46C
0005434244752	5317	300	46G
0005435424098	5317	301	46F
0005432133195	5317	302	46J
0005435555365	5317	303	46H
0005434344186	5317	304	47A
0005435613539	5317	305	47E
0005434573332	5317	306	47D
0005435042836	5317	307	47C
0005435319496	5317	308	47G
0005435424135	5317	309	47F
0005435424085	5317	310	48A
0005434244716	5317	311	47K
0005435424254	5317	312	47H
0005435613581	5317	313	48F
0005435613567	5317	314	48E
0005435613530	5317	315	48D
0005435613563	5317	316	48H
0005435424252	5317	317	48G
0005434344190	5317	318	49A
0005435613491	5317	319	49D
0005435613522	5317	320	49C
0005434244719	5317	321	49F
0005435613488	5317	322	49E
0005434244690	5317	323	49K
0005432133197	5317	324	50C
0005435613527	5317	325	50A
0005434344189	5317	326	50E
0005435613568	5317	327	50D
0005435613552	5317	328	50G
0005435613503	5317	329	50F
0005432133203	5317	330	51D
0005434344198	5317	331	50H
0005435424193	5317	332	51F
0005435424235	5317	333	51E
0005435424451	5317	334	51G
0005434244954	10931	1	1G
0005435612794	10931	2	1D
0005435424725	10931	3	1K
0005435612409	10931	4	1H
0005435424707	10931	5	2C
0005435612830	10931	6	2A
0005435319565	10931	7	2H
0005435612778	10931	8	2G
0005434343770	10931	9	2D
0005435612701	10931	10	3A
0005434244955	10931	11	2K
0005435304148	10931	12	3D
0005434244959	10931	13	3H
0005435097104	10931	14	3G
0005432841011	10931	15	4C
0005434244939	10931	16	4A
0005435612232	10931	17	3K
0005435424763	10931	18	4G
0005435612702	10931	19	4D
0005435491417	10931	20	4H
0005434244946	10931	21	5G
0005432165029	10931	22	5D
0005435097075	10931	23	11A
0005435304151	10931	24	5K
0005433719139	10931	25	11D
0005435612680	10931	26	11F
0005435424748	10931	27	11K
0005435319560	10931	28	11H
0005435612206	10931	29	11G
0005435424757	10931	30	12A
0005435612831	10931	31	12E
0005435319566	10931	32	12D
0005435612624	10931	33	12H
0005435424751	10931	34	12G
0005435304153	10931	35	12F
0005435612865	10931	36	12K
0005435612934	10931	37	13C
0005435612491	10931	38	13F
0005434343753	10931	39	13E
0005435424766	10931	40	13H
0005434244962	10931	41	13G
0005435042856	10931	42	14A
0005435424756	10931	43	14E
0005435424743	10931	44	14D
0005435612889	10931	45	14C
0005432165033	10931	46	14G
0005434573205	10931	47	14H
0005435612434	10931	48	15C
0005435612623	10931	49	14K
0005435612226	10931	50	15E
0005435424709	10931	51	15G
0005435612225	10931	52	15K
0005435424758	10931	53	16D
0005434244956	10931	54	16C
0005435424759	10931	55	16A
0005434573236	10931	56	16G
0005434244958	10931	57	16F
0005435612490	10931	58	16H
0005435424746	10931	59	17C
0005435424721	10931	60	16K
0005435304150	10931	61	17D
0005435097047	10931	62	17G
0005435612900	10931	63	17F
0005434244947	10931	64	18A
0005435424745	10931	65	17K
0005434573184	10931	66	17H
0005435424723	10931	67	18B
0005435612562	10931	68	18E
0005435612509	10931	69	18D
0005435612521	10931	70	18C
0005435612536	10931	71	18G
0005435424735	10931	72	18F
0005435424772	10931	73	18J
0005434343894	10931	74	18H
0005435612071	10931	75	19B
0005434343838	10931	76	19A
0005435612376	10931	77	19D
0005435612522	10931	78	19F
0005435612653	10931	79	19E
0005435612647	10931	80	19J
0005434244952	10931	81	19H
0005434573193	10931	82	19G
0005434573151	10931	83	20B
0005435424730	10931	84	20A
0005435612700	10931	85	20D
0005435612549	10931	86	20C
0005435612572	10931	87	20G
0005435424750	10931	88	20J
0005435612311	10931	89	21B
0005435612419	10931	90	21A
0005435612824	10931	91	20K
0005435612841	10931	92	21D
0005435424753	10931	93	21C
0005435424760	10931	94	21G
0005435097102	10931	95	21F
0005435612886	10931	96	21E
0005434343756	10931	97	21H
0005432165026	10931	98	21K
0005435424729	10931	99	22C
0005435424720	10931	100	22B
0005435612389	10931	101	22E
0005434343793	10931	102	22D
0005435490189	10931	103	22H
0005432165027	10931	104	22G
0005435612646	10931	105	22F
0005435613020	10931	106	22J
0005434343769	10931	107	23A
0005434343892	10931	108	23D
0005435304154	10931	109	23C
0005435042857	10931	110	23G
0005435424761	10931	111	23F
0005434343802	10931	112	23E
0005435612251	10931	113	24D
0005435612496	10931	114	23K
0005435491425	10931	115	24E
0005435424715	10931	116	25B
0005434573165	10931	117	25A
0005435424765	10931	118	24G
0005435424736	10931	119	25D
0005434573198	10931	120	25C
0005434244949	10931	121	25E
0005435424755	10931	122	25J
0005435424770	10931	123	25H
0005435612935	10931	124	26A
0005435424716	10931	125	25K
0005435424724	10931	126	26C
0005433719137	10931	127	26B
0005434244951	10931	128	26E
0005434573206	10931	129	26D
0005433719138	10931	130	26G
0005435612215	10931	131	26F
0005435424754	10931	132	26J
0005434573174	10931	133	26H
0005435612956	10931	134	27B
0005435612532	10931	135	27A
0005435612861	10931	136	26K
0005434573173	10931	137	27C
0005435491418	10931	138	27F
0005435097103	10931	139	27E
0005435097046	10931	140	27H
0005435097076	10931	141	27G
0005435613010	10931	142	28A
0005435424732	10931	143	27K
0005435611819	10931	144	27J
0005435424726	10931	145	28C
0005435612890	10931	146	28E
0005435612550	10931	147	28D
0005434343795	10931	148	28G
0005435424718	10931	149	28K
0005435424767	10931	150	28J
0005434343667	10931	151	28H
0005435612417	10931	152	29A
0005435612583	10931	153	29C
0005435612883	10931	154	29G
0005435304149	10931	155	29F
0005433719136	10931	156	29J
0005435424710	10931	157	30B
0005435424734	10931	158	30A
0005435424740	10931	159	30E
0005432363413	10931	160	30C
0005435424719	10931	161	30G
0005435424768	10931	162	30F
0005435612205	10931	163	30J
0005435424771	10931	164	30H
0005434244963	10931	165	31B
0005435491423	10931	166	30K
0005435612605	10931	167	31D
0005435612470	10931	168	31C
0005434343688	10931	169	31F
0005435612976	10931	170	31H
0005435424738	10931	171	31G
0005435613008	10931	172	31K
0005435612375	10931	173	31J
0005435613021	10931	174	32C
0005434244960	10931	175	32A
0005435319559	10931	176	32D
0005435424711	10931	177	32G
0005435424752	10931	178	32J
0005435612823	10931	179	32H
0005434343813	10931	180	33A
0005435424713	10931	181	32K
0005435612632	10931	182	33D
0005435555340	10931	183	33C
0005435612789	10931	184	33F
0005435491424	10931	185	33H
0005435424712	10931	186	34A
0005434573211	10931	187	33K
0005435612370	10931	188	33J
0005434343666	10931	189	34C
0005434343906	10931	190	34B
0005435612804	10931	191	34E
0005434244953	10931	192	34D
0005435612369	10931	193	34G
0005435612973	10931	194	34F
0005435424747	10931	195	34J
0005434244942	10931	196	35B
0005435612960	10931	197	35A
0005434343803	10931	198	34K
0005435612884	10931	199	35C
0005434343910	10931	200	35F
0005435612004	10931	201	35E
0005435424722	10931	202	35J
0005434343840	10931	203	35H
0005435424717	10931	204	36A
0005434573180	10931	205	35K
0005434343893	10931	206	36D
0005435612531	10931	207	36C
0005435424744	10931	208	36B
0005435304152	10931	209	36E
0005434244937	10931	210	36G
0005434573240	10931	211	36F
0005435612199	10931	212	36K
0005432165031	10931	213	36J
0005435612410	10931	214	36H
0005432166899	10931	215	37B
0005435424737	10931	216	37A
0005435612648	10931	217	37D
0005435424706	10931	218	37G
0005435612207	10931	219	37F
0005434244957	10931	220	37E
0005434343904	10931	221	38A
0005435424727	10931	222	37K
0005434343909	10931	223	37J
0005435612633	10931	224	38C
0005435612866	10931	225	38B
0005435424708	10931	226	38K
0005434244938	10931	227	38J
0005435612190	10931	228	38H
0005434343722	10931	229	39A
0005435612977	10931	230	39D
0005435612601	10931	231	39B
0005435424764	10931	232	39F
0005435491409	10931	233	39E
0005432166898	10931	234	39H
0005434343866	10931	235	39G
0005434343768	10931	236	40A
0005434244945	10931	237	40C
0005435612497	10931	238	40B
0005434244943	10931	239	40F
0005435612437	10931	240	40E
0005434244940	10931	241	40D
0005432165032	10931	242	40H
0005435424705	10931	243	40G
0005435424749	10931	244	40J
0005435613054	10931	245	40K
0005434244936	10931	246	41D
0005435612436	10931	247	41C
0005435424774	10931	248	41G
0005435612808	10931	249	41K
0005435097069	10931	250	41J
0005434244961	10931	251	42C
0005435424769	10931	252	42G
0005432363412	10931	253	42F
0005435097108	10931	254	42J
0005435612953	10931	255	42H
0005435612832	10931	256	43B
0005435612584	10931	257	43A
0005435612133	10931	258	42K
0005435612263	10931	259	43D
0005432165030	10931	260	43C
0005434343689	10931	261	43E
0005434573166	10931	262	43J
0005434573185	10931	263	43H
0005432165028	10931	264	43G
0005435612955	10931	265	43K
0005435319564	10931	266	44C
0005435319563	10931	267	44D
0005435613053	10931	268	44F
0005435612614	10931	269	44K
0005435555339	10931	270	45B
0005434343821	10931	271	45A
0005435097101	10931	272	45D
0005435612438	10931	273	45C
0005435424742	10931	274	45E
0005435612423	10931	275	45J
0005435424762	10931	276	45H
0005435319562	10931	277	45G
0005435319567	10931	278	45K
0005434244950	10931	279	46B
0005434244941	10931	280	46E
0005435612222	10931	281	46G
0005435319561	10931	282	46K
0005434573145	10931	283	46J
0005435424703	10931	284	46H
0005434244964	10931	285	47C
0005434343812	10931	286	47A
0005435612345	10931	287	47E
0005434244944	10931	288	47D
0005435424733	10931	289	47G
0005435424731	10931	290	47H
0005435612371	10931	291	48C
0005434343651	10931	292	48A
0005435424773	10931	293	48D
0005435612795	10931	294	48G
0005435424739	10931	295	49A
0005435612250	10931	296	49D
0005435612132	10931	297	49E
0005435424714	10931	298	49K
0005434573156	10931	299	49H
0005435424741	10931	300	49G
0005434244948	10931	301	50C
0005434573223	10931	302	50A
0005435424704	10931	303	50F
0005435424775	10931	304	50E
0005435555349	10931	305	50D
0005435612687	10931	306	50G
0005435424728	10931	307	51D
0005434343794	10931	308	50K
0005435612649	10931	309	51F
0005434244935	10931	310	51E
0005435612952	10931	311	51G
0005432459137	3334	1	1C
0005433507170	3334	2	1A
0005432459327	3334	3	1F
0005432459220	3334	4	1D
0005433633781	3334	5	2A
0005432459330	3334	6	2C
0005432459149	3334	7	2D
0005433633785	3334	8	3A
0005432459342	3334	9	2F
0005432459222	3334	10	3C
0005432459408	3334	11	3D
0005432459569	3334	12	4A
0005432181705	3334	13	3F
0005433633774	3334	14	4C
0005433633792	3334	15	4D
0005433633798	3334	16	5A
0005433507174	3334	17	5C
0005433805349	3334	18	5F
0005433633783	3334	19	5D
0005433805352	3334	20	6A
0005433507160	3334	21	6C
0005433805336	3334	22	6D
0005433805348	3334	23	7A
0005433633803	3334	24	6F
0005432459467	3334	25	7C
0005432181687	3334	26	7D
0005432181685	3334	27	8A
0005432459043	3334	28	7F
0005432459358	3334	29	8C
0005433633777	3334	30	8B
0005433507157	3334	31	8D
0005433507171	3334	32	8F
0005433633790	3334	33	9A
0005433633776	3334	34	9C
0005433507172	3334	35	9B
0005432459367	3334	36	9D
0005433633791	3334	37	9F
0005432459167	3334	38	9E
0005433805356	3334	39	10A
0005433805350	3334	40	10B
0005432459148	3334	41	10C
0005433507165	3334	42	10E
0005432459304	3334	43	10D
0005432459218	3334	44	10F
0005432459588	3334	45	11B
0005433507168	3334	46	11A
0005432181692	3334	47	11C
0005433805340	3334	48	11D
0005432181703	3334	49	11F
0005432459255	3334	50	11E
0005432459259	3334	51	12A
0005433633801	3334	52	12B
0005432459221	3334	53	12D
0005433805334	3334	54	12C
0005432459174	3334	55	12E
0005433805343	3334	56	12F
0005433633793	3334	57	13A
0005433633775	3334	58	13C
0005433633782	3334	59	13B
0005432181690	3334	60	13D
0005432181689	3334	61	13F
0005432459434	3334	62	13E
0005432459281	3334	63	14B
0005433805342	3334	64	14A
0005433633779	3334	65	14D
0005433507173	3334	66	14C
0005432459175	3334	67	14E
0005433805331	3334	68	14F
0005433633795	3334	69	15B
0005433805333	3334	70	15A
0005433633800	3334	71	15D
0005433633799	3334	72	15C
0005433805338	3334	73	15F
0005433805347	3334	74	15E
0005433805337	3334	75	16A
0005433805329	3334	76	16B
0005433633796	3334	77	16D
0005432181688	3334	78	16C
0005432181696	3334	79	16E
0005432459352	3334	80	16F
0005432459369	3334	81	17B
0005433805346	3334	82	17A
0005432181695	3334	83	17C
0005432181701	3334	84	17E
0005433805354	3334	85	17D
0005432459570	3334	86	18A
0005433633797	3334	87	17F
0005433507175	3334	88	18B
0005433805345	3334	89	18D
0005432459353	3334	90	18C
0005432459362	3334	91	18E
0005432459303	3334	92	19B
0005433507163	3334	93	18F
0005432181698	3334	94	19C
0005433633805	3334	95	19D
0005432459322	3334	96	20A
0005433507159	3334	97	19E
0005432459472	3334	98	20B
0005433805330	3334	99	20C
0005432459587	3334	100	20E
0005432459431	3334	101	20D
0005433633778	3334	102	21A
0005432459176	3334	103	20F
0005433633784	3334	104	21B
0005432459062	3334	105	21D
0005432181700	3334	106	21C
0005433507158	3334	107	21E
0005433507169	3334	108	22A
0005432459260	3334	109	21F
0005433633787	3334	110	22B
0005433633804	3334	111	22D
0005432459404	3334	112	22C
0005433633789	3334	113	22F
0005432459430	3334	114	22E
0005432459538	3334	115	23A
0005433805341	3334	116	23C
0005432181686	3334	117	23B
0005432181694	3334	118	23D
0005433633780	3334	119	23E
0005433805355	3334	120	24A
0005433507162	3334	121	23F
0005432459180	3334	122	24C
0005432459586	3334	123	24B
0005433805353	3334	124	24D
0005432181691	3334	125	24F
0005433507164	3334	126	24E
0005433507167	3334	127	25A
0005432459247	3334	128	25C
0005433805335	3334	129	25B
0005432459242	3334	130	25D
0005433633806	3334	131	25F
0005432181702	3334	132	25E
0005433805351	3334	133	26A
0005432459136	3334	134	26C
0005433507166	3334	135	26B
0005433805344	3334	136	26D
0005433507176	3334	137	26E
0005433507161	3334	138	26F
0005432459143	3334	139	27B
0005432181704	3334	140	27A
0005432181697	3334	141	27C
0005432181693	3334	142	27D
0005432459300	3334	143	27E
0005432459459	3334	144	28A
0005433633794	3334	145	27F
0005432459405	3334	146	28C
0005432459425	3334	147	28B
0005432181699	3334	148	28E
0005432459230	3334	149	28D
0005433805339	3334	150	29A
0005433633771	3334	151	28F
0005433633786	3334	152	29B
0005433805332	3334	153	29D
0005433633788	3334	154	29C
0005432459273	3334	155	29E
0005432459302	3334	156	30A
0005432459473	3334	157	29F
0005433633802	3334	158	30B
0005433633773	3334	159	30C
0005433633772	3334	160	30D
0005432459272	3334	161	30F
0005432459225	3334	162	30E
0005432459301	3334	163	31A
0005432181684	3334	164	31C
0005432459537	3334	165	31B
0005433805328	3334	166	31E
0005432459506	3334	167	31D
0005432459359	3334	168	31F
0005435884903	3333	1	1D
0005435884886	3333	2	1F
0005435884924	3333	3	3C
0005435884775	3333	4	3F
0005435884585	3333	5	4C
0005435884909	3333	6	4D
0005435884893	3333	7	6A
0005435884738	3333	8	6F
0005435884528	3333	9	7D
0005435884880	3333	10	8A
0005435884586	3333	11	8B
0005435884858	3333	12	8C
0005435884584	3333	13	8E
0005435884899	3333	14	9D
0005435884817	3333	15	10B
0005435884922	3333	16	10E
0005435884964	3333	17	10F
0005435884910	3333	18	11C
0005435884875	3333	19	12B
0005435884594	3333	20	12C
0005435884598	3333	21	13E
0005435884809	3333	22	14B
0005435884722	3333	23	14A
0005435884838	3333	24	14D
0005435885130	3333	25	14E
0005435884853	3333	26	15B
0005435885000	3333	27	15A
0005435884776	3333	28	15E
0005435884863	3333	29	16A
0005435884979	3333	30	16D
0005435884900	3333	31	16F
0005435884778	3333	32	17A
0005435884943	3333	33	17D
0005435884881	3333	34	17F
0005435884920	3333	35	18C
0005435884777	3333	36	18E
0005435884721	3333	37	18D
0005435884562	3333	38	19C
0005435884750	3333	39	19B
0005435884908	3333	40	19E
0005435884669	3333	41	20C
0005435884877	3333	42	20F
0005435884686	3333	43	20E
0005435884461	3333	44	21C
0005435884862	3333	45	21F
0005435884854	3333	46	22F
0005435884930	3333	47	24A
0005435884861	3333	48	23F
0005435884684	3333	49	24B
0005435885016	3333	50	24D
0005435884931	3333	51	25B
0005435884869	3333	52	26A
0005435884885	3333	53	26B
0005435884950	3333	54	26D
0005435884774	3333	55	26E
0005435884723	3333	56	28B
0005435884857	3333	57	28F
0005435884923	3333	58	29E
0005435884942	3333	59	30D
0005435884921	3333	60	30C
0005435885001	3333	61	30F
0005435884870	3333	62	31C
0005435884685	3333	63	31F
0005432042697	8218	1	1A
0005435885189	8218	2	1C
0005432459819	8218	3	1F
0005432459862	8218	4	1D
0005435885203	8218	5	2C
0005432459858	8218	6	2D
0005435885238	8218	7	3C
0005435885202	8218	8	3A
0005435885231	8218	9	3D
0005432459848	8218	10	4A
0005432459851	8218	11	3F
0005432459855	8218	12	4D
0005435885183	8218	13	4C
0005435885209	8218	14	4F
0005432459843	8218	15	5A
0005432459817	8218	16	5C
0005432459837	8218	17	5F
0005432459820	8218	18	5D
0005432459844	8218	19	6A
0005435885230	8218	20	6C
0005435885193	8218	21	6F
0005432459860	8218	22	6D
0005432459838	8218	23	7A
0005435885190	8218	24	7D
0005435885208	8218	25	7C
0005433506961	8218	26	7F
0005435885185	8218	27	8A
0005435885198	8218	28	8B
0005434312319	8218	29	8E
0005435885191	8218	30	8D
0005435885207	8218	31	9A
0005432459813	8218	32	9B
0005435885197	8218	33	9C
0005435885205	8218	34	9D
0005435885195	8218	35	9E
0005432459821	8218	36	10A
0005432459832	8218	37	10B
0005432459839	8218	38	10D
0005435885188	8218	39	10C
0005433506984	8218	40	10E
0005433506985	8218	41	11A
0005433507000	8218	42	10F
0005435885221	8218	43	11B
0005435885211	8218	44	11D
0005432459818	8218	45	11C
0005435885214	8218	46	11E
0005433506952	8218	47	12A
0005435885222	8218	48	12D
0005432042703	8218	49	12C
0005435885210	8218	50	12E
0005432459836	8218	51	12F
0005435885215	8218	52	13B
0005432459840	8218	53	13A
0005433506983	8218	54	13D
0005433506939	8218	55	13E
0005435885223	8218	56	14A
0005435885186	8218	57	14B
0005435885226	8218	58	14D
0005435885194	8218	59	14C
0005432459831	8218	60	14E
0005432459830	8218	61	15A
0005435885228	8218	62	14F
0005432459827	8218	63	15C
0005432459845	8218	64	15E
0005435885201	8218	65	15D
0005432042699	8218	66	16A
0005435885206	8218	67	15F
0005435885224	8218	68	16B
0005435885204	8218	69	16C
0005432042695	8218	70	16D
0005433506962	8218	71	17B
0005435885192	8218	72	17E
0005433506999	8218	73	17D
0005435885212	8218	74	17F
0005433506924	8218	75	18A
0005435885241	8218	76	18B
0005435885227	8218	77	18D
0005432459841	8218	78	18C
0005432459846	8218	79	18E
0005432459847	8218	80	19C
0005435885233	8218	81	19B
0005432042701	8218	82	19D
0005433506986	8218	83	19E
0005433506980	8218	84	20B
0005432459814	8218	85	20E
0005435885236	8218	86	20F
0005432459835	8218	87	21A
0005432459822	8218	88	21B
0005435885237	8218	89	21D
0005432459842	8218	90	21C
0005435885219	8218	91	21E
0005432459849	8218	92	22A
0005432459833	8218	93	22C
0005432042696	8218	94	22D
0005435885220	8218	95	22F
0005433506987	8218	96	22E
0005432459850	8218	97	23A
0005435885240	8218	98	23C
0005432042700	8218	99	23D
0005433507022	8218	100	23E
0005435885216	8218	101	24A
0005435885218	8218	102	23F
0005432459861	8218	103	24C
0005435885225	8218	104	24D
0005432459857	8218	105	24F
0005432459853	8218	106	24E
0005432459852	8218	107	25A
0005435885213	8218	108	25C
0005434312318	8218	109	25B
0005433506953	8218	110	25F
0005432459825	8218	111	25E
0005435885217	8218	112	26A
0005432042698	8218	113	26B
0005432042705	8218	114	26C
0005435885234	8218	115	26D
0005433506991	8218	116	26F
0005432459863	8218	117	26E
0005432042707	8218	118	27B
0005433507021	8218	119	27A
0005435885235	8218	120	27E
0005432459856	8218	121	27D
0005432459829	8218	122	27C
0005435885196	8218	123	27F
0005435885239	8218	124	28A
0005432459826	8218	125	28B
0005432042702	8218	126	28D
0005432459824	8218	127	28C
0005435885229	8218	128	28E
0005435885200	8218	129	29A
0005432459815	8218	130	29C
0005433506923	8218	131	29B
0005432459854	8218	132	29D
0005432459816	8218	133	29F
0005432459823	8218	134	29E
0005432042706	8218	135	30B
0005435885184	8218	136	30C
0005432459834	8218	137	30D
0005432042704	8218	138	30F
0005432459859	8218	139	31A
0005432042708	8218	140	31C
0005432459828	8218	141	31B
0005435885199	8218	142	31D
0005435885187	8218	143	31E
0005435885232	8218	144	31F
0005433804961	8216	1	1C
0005433633445	8216	2	2F
0005433633446	8216	3	3A
0005433805005	8216	4	3D
0005433804958	8216	5	4D
0005433805053	8216	6	7C
0005433633377	8216	7	7F
0005433804981	8216	8	8A
0005433633522	8216	9	8D
0005433633460	8216	10	8E
0005433805020	8216	11	8F
0005433633421	8216	12	9B
0005433633546	8216	13	9A
0005433633419	8216	14	9D
0005433633554	8216	15	9F
0005434143712	8216	16	10B
0005433633376	8216	17	10F
0005433804980	8216	18	11A
0005433633316	8216	19	11C
0005433633443	8216	20	11B
0005433633596	8216	21	12A
0005433633592	8216	22	12C
0005433805055	8216	23	12B
0005434271292	8216	24	12E
0005433633436	8216	25	13A
0005433633498	8216	26	13B
0005433633468	8216	27	14B
0005433633481	8216	28	14E
0005433633450	8216	29	15B
0005433805049	8216	30	15A
0005433633464	8216	31	15C
0005433805067	8216	32	16A
0005433805056	8216	33	16B
0005433633482	8216	34	16C
0005433805068	8216	35	16F
0005433804919	8216	36	17C
0005433805066	8216	37	17E
0005433633303	8216	38	17F
0005433805078	8216	39	18A
0005433804960	8216	40	18C
0005433633365	8216	41	18D
0005433805021	8216	42	19B
0005433633461	8216	43	20A
0005433805035	8216	44	19E
0005433805104	8216	45	20C
0005433805052	8216	46	20E
0005433633491	8216	47	21B
0005433805036	8216	48	21D
0005433633292	8216	49	21C
0005433633472	8216	50	21E
0005433805114	8216	51	21F
0005434271289	8216	52	22B
0005433805117	8216	53	22D
0005433805010	8216	54	22F
0005433633309	8216	55	23A
0005433805118	8216	56	23B
0005433633422	8216	57	23D
0005433633378	8216	58	23F
0005433633512	8216	59	24D
0005433805116	8216	60	25A
0005433633598	8216	61	25D
0005433804959	8216	62	25C
0005433633366	8216	63	25E
0005433633515	8216	64	26A
0005433633591	8216	65	26B
0005433805048	8216	66	26C
0005433633451	8216	67	27B
0005433633379	8216	68	27A
0005433805004	8216	69	27C
0005433805065	8216	70	27D
0005433633367	8216	71	27E
0005433633433	8216	72	28B
0005433633469	8216	73	28F
0005433633471	8216	74	29C
0005433805131	8216	75	29D
0005433633323	8216	76	30B
0005433633597	8216	77	30D
0005433633511	8216	78	30E
0005433633547	8216	79	30F
0005433633416	8216	80	31C
0005433805137	8216	81	31B
0005433805009	8216	82	31D
0005433633417	8216	83	31E
0005434183561	8213	1	19C
0005434183562	8213	2	30B
0005432727926	4618	1	1A
0005432383149	4618	2	1C
0005432727924	4618	3	1D
0005433194857	4618	4	1F
0005433454873	4618	5	2A
0005432727922	4618	6	2D
0005432383131	4618	7	3A
0005433722224	4618	8	3C
0005432383152	4618	9	3D
0005432383133	4618	10	4A
0005432383144	4618	11	4C
0005432383135	4618	12	5D
0005432383151	4618	13	5E
0005432383156	4618	14	6C
0005432383146	4618	15	6D
0005432383160	4618	16	6F
0005432727929	4618	17	7A
0005433722221	4618	18	7C
0005432383148	4618	19	7E
0005433722220	4618	20	7F
0005432383137	4618	21	8D
0005433194856	4618	22	8E
0005432727925	4618	23	8F
0005432383154	4618	24	9D
0005433454874	4618	25	9F
0005432383158	4618	26	10C
0005432383129	4618	27	10E
0005432727930	4618	28	10F
0005432727932	4618	29	11A
0005432383141	4618	30	11C
0005433722217	4618	31	11E
0005432383155	4618	32	11F
0005432383159	4618	33	12A
0005432383166	4618	34	12C
0005433722219	4618	35	12D
0005432383157	4618	36	12E
0005432383145	4618	37	12F
0005432383136	4618	38	13F
0005432383138	4618	39	14A
0005433453761	4618	40	14C
0005432383163	4618	41	14D
0005433453763	4618	42	15C
0005432727923	4618	43	15D
0005433453762	4618	44	15E
0005433454875	4618	45	16A
0005433722218	4618	46	16C
0005432383139	4618	47	16E
0005433722222	4618	48	16F
0005432727931	4618	49	17A
0005432383161	4618	50	17C
0005432383134	4618	51	17D
0005432383140	4618	52	17F
0005432383132	4618	53	18C
0005432383153	4618	54	18D
0005432383165	4618	55	18E
0005432383147	4618	56	18F
0005432383130	4618	57	19A
0005432383150	4618	58	19D
0005433722223	4618	59	19E
0005432383162	4618	60	19F
0005432383143	4618	61	20A
0005432383142	4618	62	20C
0005432727927	4618	63	20D
0005432727928	4618	64	20E
0005432383164	4618	65	20F
0005433722132	30158	1	1C
0005432382697	30158	2	1D
0005432727775	30158	3	1F
0005432727799	30158	4	2A
0005432382554	30158	5	2C
0005432382774	30158	6	2F
0005432727856	30158	7	3A
0005433722134	30158	8	3C
0005432382675	30158	9	3D
0005432382705	30158	10	3F
0005432382608	30158	11	4A
0005432382727	30158	12	4C
0005432382819	30158	13	4E
0005432727800	30158	14	5A
0005433453746	30158	15	5C
0005433722138	30158	16	5F
0005432382723	30158	17	6A
0005432382552	30158	18	6C
0005432382603	30158	19	6D
0005432382602	30158	20	6E
0005432382871	30158	21	6F
0005433722122	30158	22	7A
0005432727867	30158	23	7C
0005432382679	30158	24	7D
0005432727806	30158	25	8A
0005432382574	30158	26	8C
0005433722133	30158	27	8D
0005432382627	30158	28	9A
0005432382650	30158	29	9C
0005432382658	30158	30	9E
0005432382737	30158	31	9F
0005432382630	30158	32	10A
0005432382717	30158	33	10C
0005433453745	30158	34	10E
0005432382553	30158	35	10F
0005432382840	30158	36	11A
0005432382568	30158	37	11C
0005432727774	30158	38	11D
0005432382542	30158	39	12A
0005432382758	30158	40	12C
0005432727866	30158	41	12F
0005432382686	30158	42	13A
0005432382659	30158	43	13C
0005433722135	30158	44	13D
0005433451597	30158	45	13E
0005432382674	30158	46	14C
0005432382701	30158	47	14D
0005433451589	30158	48	14E
0005432382540	30158	49	14F
0005432727810	30158	50	15D
0005432382631	30158	51	15E
0005432382704	30158	52	15F
0005432727783	30158	53	16A
0005432727740	30158	54	16C
0005432382569	30158	55	16D
0005433722139	30158	56	16E
0005432382839	30158	57	16F
0005432382716	30158	58	17A
0005432382841	30158	59	17C
0005432382623	30158	60	17E
0005432382604	30158	61	17F
0005432382660	30158	62	18A
0005432382543	30158	63	18C
0005432382628	30158	64	18E
0005432727803	30158	65	18F
0005432382836	30158	66	19C
0005432382685	30158	67	19E
0005432382703	30158	68	19F
0005433722102	30158	69	20A
0005432382632	30158	70	20D
0005433453737	30158	71	20F
0005433516882	1756	1	1C
0005435540989	1756	2	1D
0005435540995	1756	3	2C
0005435540982	1756	4	3C
0005435529254	1756	5	3D
0005433516877	1756	6	3F
0005435529239	1756	7	4E
0005435529237	1756	8	4F
0005435540979	1756	9	5A
0005435540987	1756	10	5D
0005432294484	1756	11	5F
0005433516880	1756	12	6A
0005435529238	1756	13	6C
0005435529240	1756	14	6D
0005435540988	1756	15	6E
0005435540983	1756	16	6F
0005435529246	1756	17	7A
0005435529251	1756	18	7D
0005433516878	1756	19	7F
0005435529235	1756	20	8D
0005435529253	1756	21	8F
0005433516879	1756	22	9C
0005435529247	1756	23	9D
0005435540978	1756	24	9E
0005432294486	1756	25	10A
0005433516881	1756	26	11C
0005435529241	1756	27	11D
0005435540992	1756	28	11E
0005432924984	1756	29	11F
0005435540980	1756	30	12A
0005432924988	1756	31	12C
0005433516883	1756	32	12E
0005432924979	1756	33	12F
0005432294485	1756	34	13A
0005435529234	1756	35	13C
0005435540993	1756	36	13F
0005435540998	1756	37	14A
0005435529244	1756	38	14C
0005433516876	1756	39	15A
0005435540990	1756	40	14F
0005435529248	1756	41	15D
0005435540986	1756	42	15F
0005435529252	1756	43	16D
0005435540981	1756	44	17A
0005435540994	1756	45	17D
0005435540991	1756	46	17E
0005435529255	1756	47	17F
0005435540985	1756	48	18A
0005435540997	1756	49	18D
0005435529250	1756	50	18E
0005435529249	1756	51	18F
0005435540984	1756	52	19C
0005435529243	1756	53	19D
0005435540996	1756	54	19F
0005433516875	1756	55	20A
0005435529242	1756	56	20D
0005435529236	1756	57	20E
0005435529245	1756	58	20F
0005435540770	22001	1	1C
0005435540792	22001	2	1F
0005433516795	22001	3	1D
0005435540807	22001	4	2A
0005435517697	22001	5	2C
0005433516753	22001	6	2D
0005433516786	22001	7	2F
0005435517671	22001	8	3C
0005435517693	22001	9	3D
0005433516781	22001	10	3F
0005432925032	22001	11	4C
0005433516799	22001	12	4D
0005435517782	22001	13	4F
0005435540744	22001	14	5A
0005435517695	22001	15	5D
0005435517696	22001	16	5F
0005435517730	22001	17	6A
0005435517692	22001	18	6C
0005435540789	22001	19	6E
0005435517701	22001	20	6F
0005435517721	22001	21	7A
0005435517663	22001	22	7C
0005435540773	22001	23	7D
0005435540808	22001	24	7E
0005433516794	22001	25	8A
0005432925031	22001	26	9A
0005433516802	22001	27	9C
0005435540771	22001	28	9D
0005433516798	22001	29	9F
0005435517757	22001	30	10C
0005433516780	22001	31	10D
0005435517760	22001	32	10E
0005435517702	22001	33	10F
0005435540877	22001	34	11A
0005435517691	22001	35	11C
0005435540787	22001	36	11D
0005433516785	22001	37	11E
0005435540860	22001	38	11F
0005435517735	22001	39	12A
0005432925034	22001	40	12E
0005433516790	22001	41	12F
0005435517690	22001	42	13C
0005432925030	22001	43	13D
0005435517737	22001	44	13E
0005433516778	22001	45	13F
0005435517783	22001	46	14C
0005435517731	22001	47	14F
0005435540767	22001	48	15C
0005435517717	22001	49	15D
0005435540818	22001	50	15E
0005435540779	22001	51	15F
0005435517694	22001	52	16E
0005435540736	22001	53	16F
0005433516806	22001	54	17C
0005435540745	22001	55	17D
0005435540785	22001	56	17E
0005435540734	22001	57	17F
0005435540786	22001	58	18A
0005435540688	22001	59	18E
0005435517670	22001	60	18F
0005435540857	22001	61	19D
0005435540809	22001	62	19C
0005435540689	22001	63	19F
0005435540878	22001	64	20A
0005435517682	22001	65	20C
0005432925033	22001	66	20D
0005435540720	22001	67	20E
0005435540788	22001	68	20F
0005432838994	7383	1	1A
0005434458792	7383	2	1D
0005432838997	7383	3	1F
0005432839014	7383	4	2A
0005435252571	7383	5	2C
0005434458794	7383	6	2F
0005434458793	7383	7	3A
0005432839003	7383	8	3D
0005434458788	7383	9	3F
0005432838996	7383	10	4A
0005435252530	7383	11	4C
0005434458782	7383	12	4E
0005432839002	7383	13	4D
0005434458774	7383	14	4F
0005432839021	7383	15	5A
0005432839017	7383	16	5C
0005435252565	7383	17	5D
0005434458780	7383	18	5E
0005434458779	7383	19	5F
0005432839018	7383	20	6A
0005434664942	7383	21	6C
0005432839004	7383	22	6D
0005432839000	7383	23	6E
0005432073387	7383	24	6F
0005432073388	7383	25	7A
0005435252596	7383	26	7C
0005435252634	7383	27	7D
0005432839005	7383	28	7F
0005432841009	7383	29	8A
0005434458776	7383	30	8D
0005435252453	7383	31	8E
0005435491422	7383	32	8F
0005435252552	7383	33	9A
0005432838991	7383	34	9C
0005435252597	7383	35	9D
0005432838995	7383	36	9E
0005434458778	7383	37	9F
0005432839013	7383	38	10A
0005434458777	7383	39	10C
0005434458775	7383	40	10D
0005435252549	7383	41	10F
0005432839008	7383	42	11A
0005435252499	7383	43	11D
0005432839009	7383	44	11E
0005435252458	7383	45	12A
0005434458790	7383	46	12C
0005434458784	7383	47	12D
0005432839006	7383	48	12E
0005435252555	7383	49	12F
0005435252454	7383	50	13A
0005432839015	7383	51	13C
0005432839001	7383	52	13E
0005435491421	7383	53	13F
0005432839012	7383	54	14A
0005432838998	7383	55	14C
0005432823445	7383	56	14D
0005435491420	7383	57	14E
0005432841010	7383	58	14F
0005434664930	7383	59	15A
0005432839016	7383	60	15C
0005434664931	7383	61	15E
0005434458785	7383	62	15F
0005432839007	7383	63	16A
0005435252553	7383	64	16C
0005432839011	7383	65	16D
0005432839019	7383	66	16E
0005434458783	7383	67	16F
0005432838992	7383	68	17A
0005432823447	7383	69	17C
0005432839020	7383	70	17D
0005434458781	7383	71	17E
0005435252635	7383	72	17F
0005432838990	7383	73	18A
0005432823446	7383	74	18D
0005434458787	7383	75	18E
0005432838993	7383	76	18F
0005432839010	7383	77	19A
0005434458791	7383	78	19C
0005435252498	7383	79	19D
0005435252468	7383	80	19E
0005434458789	7383	81	19F
0005435252529	7383	82	20A
0005434458786	7383	83	20C
0005432838999	7383	84	20D
0005435252554	7383	85	20F
0005435252692	28926	1	1A
0005432838854	28926	2	1C
0005432838604	28926	3	1D
0005434458596	28926	4	1F
0005434664959	28926	5	2A
0005432838704	28926	6	2C
0005434458593	28926	7	2D
0005435252686	28926	8	2F
0005432838836	28926	9	3A
0005432838855	28926	10	3C
0005432838807	28926	11	3D
0005434458643	28926	12	3F
0005434458683	28926	13	4A
0005434458649	28926	14	4C
0005432838733	28926	15	4D
0005432838757	28926	16	4E
0005432838834	28926	17	4F
0005434458585	28926	18	5A
0005435252682	28926	19	5C
0005432838742	28926	20	5D
0005432838824	28926	21	5E
0005432838734	28926	22	5F
0005432001020	28926	23	6A
0005434458582	28926	24	6C
0005434458581	28926	25	6D
0005432838696	28926	26	6E
0005432838901	28926	27	6F
0005435252681	28926	28	7A
0005432838831	28926	29	7C
0005432838674	28926	30	7D
0005434458660	28926	31	7E
0005434458659	28926	32	7F
0005432838689	28926	33	8A
0005435252694	28926	34	8C
0005434458644	28926	35	8D
0005432838907	28926	36	8E
0005434458652	28926	37	8F
0005435252684	28926	38	9A
0005432838736	28926	39	9C
0005432001021	28926	40	9D
0005432838667	28926	41	9E
0005434458635	28926	42	9F
0005432838606	28926	43	10A
0005434458650	28926	44	10C
0005434458684	28926	45	10D
0005435252679	28926	46	10E
0005432838801	28926	47	10F
0005434458594	28926	48	11A
0005432838672	28926	49	11C
0005434458595	28926	50	11D
0005432838723	28926	51	11E
0005432838825	28926	52	11F
0005432838766	28926	53	12A
0005434458653	28926	54	12C
0005434458642	28926	55	12D
0005432838773	28926	56	12E
0005434458561	28926	57	12F
0005434458685	28926	58	13A
0005432838642	28926	59	13C
0005435252689	28926	60	13D
0005434458584	28926	61	13E
0005435252685	28926	62	13F
0005435252695	28926	63	14A
0005435252677	28926	64	14C
0005432838906	28926	65	14D
0005434664958	28926	66	14E
0005435252680	28926	67	14F
0005432838666	28926	68	15A
0005432838758	28926	69	15C
0005435252687	28926	70	15D
0005432838835	28926	71	15E
0005432838764	28926	72	15F
0005432838832	28926	73	16A
0005435252690	28926	74	16C
0005432838767	28926	75	16D
0005432838705	28926	76	16E
0005434458560	28926	77	16F
0005432838673	28926	78	17A
0005435252693	28926	79	17C
0005432840991	28926	80	17D
0005435252691	28926	81	17E
0005432838772	28926	82	17F
0005432838688	28926	83	18A
0005435252688	28926	84	18C
0005432838844	28926	85	18D
0005434458637	28926	86	18E
0005435252678	28926	87	18F
0005434458580	28926	88	19A
0005432840996	28926	89	19C
0005432838802	28926	90	19D
0005435252683	28926	91	19E
0005432838735	28926	92	19F
0005434458651	28926	93	20A
0005432838812	28926	94	20C
0005432838605	28926	95	20D
0005434664957	28926	96	20E
0005434458574	28926	97	20F
0005435990617	8806	1	2D
0005435990619	8806	2	3A
0005435990616	8806	3	5D
0005434275989	8806	4	8A
0005434275990	8806	5	8B
0005434275998	8806	6	12E
0005434275992	8806	7	14D
0005435990614	8806	8	14F
0005434275988	8806	9	15C
0005435990615	8806	10	15F
0005435990613	8806	11	16B
0005434275991	8806	12	16F
0005435990618	8806	13	19F
0005435990550	15718	1	1A
0005435990542	15718	2	3F
0005434276021	15718	3	6D
0005434276018	15718	4	7E
0005435990523	15718	5	8A
0005434276020	15718	6	8F
0005434276019	15718	7	9E
0005435990570	15718	8	12C
0005434276022	15718	9	13C
0005435990530	15718	10	13B
0005434276023	15718	11	15A
0005434276024	15718	12	15C
0005435990531	15718	13	19A
0005435990575	15718	14	20B
0005433468319	2085	1	1A
0005432909226	2085	2	1C
0005433468325	2085	3	2A
0005433468332	2085	4	3A
0005433468333	2085	5	3B
0005433468334	2085	6	3C
0005433468321	2085	7	3D
0005432909207	2085	8	4D
0005432909214	2085	9	5A
0005432909209	2085	10	5B
0005433468328	2085	11	6A
0005433468326	2085	12	6B
0005433468331	2085	13	6C
0005432909208	2085	14	7B
0005432909232	2085	15	7D
0005432909229	2085	16	18A
0005433468322	2085	17	18B
0005433468323	2085	18	18D
0005433468318	2085	19	18C
0005433468329	2085	20	19B
0005433468330	2085	21	19D
0005432909215	2085	22	20B
0005433468320	2085	23	20C
0005433468324	2085	24	20D
0005433468335	2085	25	21C
0005433468317	2085	26	22D
0005433468327	2085	27	23A
0005433468253	23844	1	1A
0005433468212	23844	2	1B
0005432909281	23844	3	1C
0005433468275	23844	4	1D
0005433468230	23844	5	2A
0005433468244	23844	6	2B
0005433468255	23844	7	2C
0005432909266	23844	8	2D
0005433468242	23844	9	3A
0005433468231	23844	10	3B
0005433468248	23844	11	3C
0005433468251	23844	12	3D
0005432909279	23844	13	4A
0005432909273	23844	14	4B
0005433468209	23844	15	4C
0005433468204	23844	16	4D
0005432909282	23844	17	5A
0005433468274	23844	18	5B
0005433468210	23844	19	5C
0005433468232	23844	20	5D
0005433468252	23844	21	6A
0005432909270	23844	22	6B
0005433468261	23844	23	6C
0005433468228	23844	24	6D
0005433468249	23844	25	7A
0005432909274	23844	26	7B
0005432909272	23844	27	7C
0005433468243	23844	28	7D
0005432909271	23844	29	18A
0005433468235	23844	30	18B
0005433468211	23844	31	18C
0005433468247	23844	32	18D
0005433468254	23844	33	19A
0005433468236	23844	34	19B
0005433468266	23844	35	19D
0005433468224	23844	36	20A
0005432909268	23844	37	20B
0005433468229	23844	38	20C
0005432909275	23844	39	20D
0005433468240	23844	40	21A
0005432909276	23844	41	21B
0005432909269	23844	42	21C
0005433468234	23844	43	21D
0005433468259	23844	44	22A
0005432909267	23844	45	22B
0005432909278	23844	46	22C
0005432909277	23844	47	23A
0005432909280	23844	48	22D
0005435176921	6413	1	1A
0005432360329	6413	2	1D
0005435176800	6413	3	1C
0005432360298	6413	4	1F
0005435176788	6413	5	2C
0005432360296	6413	6	2A
0005435176944	6413	7	2D
0005435176898	6413	8	2F
0005435176907	6413	9	3C
0005434149618	6413	10	3A
0005432336020	6413	11	3D
0005435176846	6413	12	3F
0005435176801	6413	13	4B
0005432062225	6413	14	4A
0005432360326	6413	15	4C
0005432360335	6413	16	4D
0005432360341	6413	17	4F
0005432360322	6413	18	5A
0005432360312	6413	19	5B
0005432336017	6413	20	5D
0005432360302	6413	21	5E
0005435176906	6413	22	6A
0005434149643	6413	23	5F
0005434149656	6413	24	6B
0005432360301	6413	25	6D
0005435723020	6413	26	6E
0005435176942	6413	27	7A
0005432360297	6413	28	6F
0005435176901	6413	29	7B
0005432363413	6413	30	7E
0005432360330	6413	31	7D
0005432360317	6413	32	7F
0005432360320	6413	33	8B
0005434149664	6413	34	8A
0005435176784	6413	35	8D
0005432360313	6413	36	8C
0005435176897	6413	37	8E
0005432360325	6413	38	8F
0005432360328	6413	39	9A
0005432360327	6413	40	9B
0005432360305	6413	41	9D
0005432360334	6413	42	9C
0005432360340	6413	43	9E
0005432336023	6413	44	9F
0005435176727	6413	45	10B
0005432360299	6413	46	10C
0005434149596	6413	47	10E
0005435176783	6413	48	10D
0005432363412	6413	49	11A
0005432360308	6413	50	11B
0005432336024	6413	51	11C
0005435176795	6413	52	11E
0005434149612	6413	53	11D
0005432062224	6413	54	11F
0005432360303	6413	55	12B
0005432360331	6413	56	12A
0005432336026	6413	57	12C
0005432360295	6413	58	12E
0005434149622	6413	59	12D
0005435176808	6413	60	12F
0005432360337	6413	61	13A
0005432062222	6413	62	13B
0005432360293	6413	63	13D
0005432360300	6413	64	13C
0005432336022	6413	65	13E
0005434149599	6413	66	13F
0005435176884	6413	67	14A
0005434149642	6413	68	14B
0005434149663	6413	69	14D
0005432360342	6413	70	14F
0005432336019	6413	71	14E
0005435176941	6413	72	15B
0005432360310	6413	73	15A
0005435176943	6413	74	15C
0005432336027	6413	75	15D
0005432360332	6413	76	15E
0005434149595	6413	77	15F
0005435176871	6413	78	16B
0005432360304	6413	79	16A
0005432360318	6413	80	16C
0005432360315	6413	81	16D
0005435176891	6413	82	16F
0005435176833	6413	83	16E
0005435490189	6413	84	17A
0005432336018	6413	85	17B
0005435176798	6413	86	17C
0005432336021	6413	87	17E
0005432062221	6413	88	18A
0005432360323	6413	89	17F
0005432336025	6413	90	18B
0005435176902	6413	91	18D
0005432360338	6413	92	18C
0005435176771	6413	93	18E
0005432360309	6413	94	19A
0005432360307	6413	95	19B
0005435176905	6413	96	19C
0005434149665	6413	97	19D
0005435176883	6413	98	19F
0005432360324	6413	99	19E
0005432360319	6413	100	20C
0005432360321	6413	101	20E
0005432336016	6413	102	21A
0005432336028	6413	103	20F
0005432360333	6413	104	21B
0005434149621	6413	105	21C
0005432062223	6413	106	21D
0005432360314	6413	107	21E
0005432360316	6413	108	22A
0005435176920	6413	109	21F
0005432360294	6413	110	22B
0005435176896	6413	111	22C
0005432360311	6413	112	22E
0005432360336	6413	113	22D
0005432062226	6413	114	23B
0005435176706	6413	115	23C
0005432360339	6413	116	23F
0005432360306	6413	117	23E
0005435177043	21022	1	1A
0005435177038	21022	2	1C
0005435177050	21022	3	1D
0005434149721	21022	4	2A
0005432360069	21022	5	1F
0005432052742	21022	6	2C
0005432359775	21022	7	2D
0005432363379	21022	8	2F
0005435177055	21022	9	3A
0005432359857	21022	10	3D
0005432359866	21022	11	3C
0005432359761	21022	12	3F
0005432359760	21022	13	4B
0005432359978	21022	14	4A
0005432360018	21022	15	4D
0005435177052	21022	16	4E
0005432359797	21022	17	4F
0005435177037	21022	18	5B
0005432335901	21022	19	5A
0005435490229	21022	20	5C
0005432359943	21022	21	5D
0005432360009	21022	22	5F
0005432335907	21022	23	5E
0005435177044	21022	24	6A
0005432363386	21022	25	6C
0005432360030	21022	26	6D
0005435177061	21022	27	6F
0005432359813	21022	28	6E
0005435177042	21022	29	7B
0005432360016	21022	30	7A
0005432335861	21022	31	7C
0005432359988	21022	32	7D
0005435177056	21022	33	7E
0005432335913	21022	34	7F
0005432360040	21022	35	8B
0005432335988	21022	36	8A
0005432360074	21022	37	8C
0005435177045	21022	38	8D
0005432359860	21022	39	8F
0005432359776	21022	40	8E
0005435177051	21022	41	9A
0005432335924	21022	42	9C
0005435177063	21022	43	9B
0005432335900	21022	44	9D
0005432359981	21022	45	9F
0005432359834	21022	46	10B
0005432359732	21022	47	10D
0005432363387	21022	48	10C
0005432359989	21022	49	10E
0005432359756	21022	50	11A
0005432359832	21022	51	11B
0005435723043	21022	52	11C
0005435177039	21022	53	11E
0005435177062	21022	54	11D
0005432335956	21022	55	11F
0005432335923	21022	56	12B
0005435177054	21022	57	12A
0005435177060	21022	58	12C
0005432360057	21022	59	12E
0005432359950	21022	60	12D
0005432359868	21022	61	12F
0005434149713	21022	62	13B
0005434149719	21022	63	13A
0005432360029	21022	64	13C
0005435490227	21022	65	13D
0005432359711	21022	66	13E
0005432359976	21022	67	13F
0005432335888	21022	68	14B
0005434149723	21022	69	14A
0005434149724	21022	70	14C
0005432359820	21022	71	14D
0005435177047	21022	72	14E
0005435177064	21022	73	15A
0005432359977	21022	74	14F
0005432359928	21022	75	15C
0005432359872	21022	76	15B
0005432335887	21022	77	15E
0005432359856	21022	78	15D
0005435177046	21022	79	16A
0005432360037	21022	80	16B
0005434149714	21022	81	16C
0005432359867	21022	82	16D
0005432052743	21022	83	16E
0005435177049	21022	84	16F
0005434149722	21022	85	17B
0005432359759	21022	86	17A
0005435177053	21022	87	17C
0005434149717	21022	88	17E
0005432359942	21022	89	17D
0005432335906	21022	90	18A
0005432359812	21022	91	17F
0005432359861	21022	92	18B
0005434149715	21022	93	18C
0005432335905	21022	94	18E
0005432335942	21022	95	18D
0005434149720	21022	96	18F
0005432359925	21022	97	19A
0005435177058	21022	98	19B
0005434149716	21022	99	19C
0005435177041	21022	100	19E
0005432359877	21022	101	19D
0005432335909	21022	102	19F
0005432359862	21022	103	20A
0005432359824	21022	104	20C
0005432359966	21022	105	20B
0005432359725	21022	106	20D
0005435177059	21022	107	20E
0005434149718	21022	108	20F
0005435177057	21022	109	21B
0005432359900	21022	110	21A
0005435723044	21022	111	21C
0005432359933	21022	112	21D
0005432335889	21022	113	21F
0005435177048	21022	114	21E
0005435177040	21022	115	22A
0005432359940	21022	116	22C
0005432052744	21022	117	22B
0005432360079	21022	118	22E
0005432359916	21022	119	22D
0005435490228	21022	120	22F
0005432359941	21022	121	23A
0005432359905	21022	122	23B
0005432363388	21022	123	23D
0005432335895	21022	124	23C
0005432359733	21022	125	23E
0005432360006	21022	126	23F
0005434463902	17712	1	1B
0005434458618	17712	2	1C
0005434461630	17712	3	1D
0005434186196	17712	4	2C
0005434458587	17712	5	2D
0005434458665	17712	6	3A
0005434458664	17712	7	3B
0005434461627	17712	8	3D
0005434458675	17712	9	4A
0005434458676	17712	10	4B
0005434463905	17712	11	4C
0005434458656	17712	12	4D
0005434458674	17712	13	5B
0005434461625	17712	14	5C
0005434458616	17712	15	6A
0005434458588	17712	16	6D
0005434461626	17712	17	7A
0005434458663	17712	18	7D
0005434448270	17712	19	18A
0005434458617	17712	20	18B
0005434186197	17712	21	19C
0005434448277	17712	22	20B
0005434461629	17712	23	20C
0005434458647	17712	24	21A
0005434458634	17712	25	21B
0005434458673	17712	26	22A
0005434458695	17712	27	22D
0005434463901	17712	28	23B
0005434458792	29084	1	1C
0005434458784	29084	2	2A
0005434458781	29084	3	2B
0005434458785	29084	4	2C
0005434458776	29084	5	2D
0005434458791	29084	6	3A
0005434458793	29084	7	3B
0005434458774	29084	8	3D
0005434463924	29084	9	4A
0005434458778	29084	10	4C
0005434458780	29084	11	4D
0005434462785	29084	12	5A
0005434458787	29084	13	5C
0005434458794	29084	14	5D
0005434458779	29084	15	6C
0005434448309	29084	16	6D
0005434462786	29084	17	7A
0005434458789	29084	18	7D
0005434186176	29084	19	18B
0005434458782	29084	20	18C
0005434458788	29084	21	18D
0005434458775	29084	22	19C
0005434458783	29084	23	20D
0005434458777	29084	24	21A
0005434458790	29084	25	21B
0005434186177	29084	26	22A
0005434448308	29084	27	22B
0005434458786	29084	28	22C
0005434463925	29084	29	22D
0005434448307	29084	30	23B
0005432604251	21448	1	1A
0005432604284	21448	2	1B
0005432604289	21448	3	1C
0005432604288	21448	4	1D
0005432604286	21448	5	2A
0005432604279	21448	6	3A
0005432604281	21448	7	2D
0005432604280	21448	8	3B
0005432604278	21448	9	3C
0005432604255	21448	10	3D
0005432604259	21448	11	4A
0005432604260	21448	12	4B
0005432604257	21448	13	4C
0005432604252	21448	14	4D
0005432604282	21448	15	5A
0005432604271	21448	16	5C
0005432604258	21448	17	5B
0005432604269	21448	18	5D
0005432604270	21448	19	6A
0005432604283	21448	20	6B
0005432604253	21448	21	6D
0005432604273	21448	22	7A
0005432604263	21448	23	7B
0005432604287	21448	24	7C
0005432604290	21448	25	7D
0005432604268	21448	26	18A
0005432604264	21448	27	18C
0005432604272	21448	28	18D
0005432604274	21448	29	19A
0005432604250	21448	30	19B
0005432604256	21448	31	19D
0005432604262	21448	32	19C
0005432604276	21448	33	20B
0005432604277	21448	34	20C
0005432604267	21448	35	21A
0005432604285	21448	36	21B
0005432604275	21448	37	21D
0005432604266	21448	38	22A
0005432604265	21448	39	22B
0005432604261	21448	40	22C
0005432604254	21448	41	23B
0005432603861	31674	1	1A
0005432603965	31674	2	1B
0005432604038	31674	3	1C
0005432604069	31674	4	1D
0005432603870	31674	5	2A
0005432603948	31674	6	2B
0005432603970	31674	7	2D
0005432603813	31674	8	3A
0005432603862	31674	9	3B
0005432604119	31674	10	3C
0005432604120	31674	11	3D
0005432603932	31674	12	4A
0005432603964	31674	13	4B
0005432603942	31674	14	4C
0005432603941	31674	15	4D
0005432603826	31674	16	5A
0005432603852	31674	17	5B
0005432603872	31674	18	5C
0005432603819	31674	19	5D
0005432603952	31674	20	6B
0005432604090	31674	21	6A
0005432603943	31674	22	6C
0005432603972	31674	23	6D
0005432603883	31674	24	7A
0005432603900	31674	25	7C
0005432603899	31674	26	18A
0005432603982	31674	27	18B
0005432603944	31674	28	18C
0005432603921	31674	29	18D
0005432603953	31674	30	19A
0005432603874	31674	31	19B
0005432603851	31674	32	19C
0005432604091	31674	33	19D
0005432603850	31674	34	20A
0005432603799	31674	35	20B
0005432603873	31674	36	20C
0005432603922	31674	37	20D
0005432603961	31674	38	21A
0005432603882	31674	39	21B
0005432603933	31674	40	21C
0005432603963	31674	41	21D
0005432603979	31674	42	22A
0005432603802	31674	43	22B
0005432603978	31674	44	22C
0005432603814	31674	45	22D
0005432603931	31674	46	23A
0005432603871	31674	47	23B
0005435154584	29602	1	1D
0005433293246	29602	2	2C
0005433293248	29602	3	2D
0005435154585	29602	4	3B
0005435154589	29602	5	3D
0005433293243	29602	6	4A
0005435154586	29602	7	5D
0005433293247	29602	8	6A
0005433293244	29602	9	6D
0005433293251	29602	10	7A
0005435154590	29602	11	7C
0005433293250	29602	12	18B
0005435154581	29602	13	18C
0005433293245	29602	14	18D
0005433293241	29602	15	19B
0005435154580	29602	16	19C
0005435154587	29602	17	19D
0005433293242	29602	18	20B
0005433293249	29602	19	20D
0005435154583	29602	20	22B
0005435154582	29602	21	22D
0005435154588	29602	22	23A
0005433473254	6670	1	1D
0005433473258	6670	2	2B
0005435257200	6670	3	2C
0005433473243	6670	4	3A
0005433473248	6670	5	3B
0005435257180	6670	6	3D
0005435257189	6670	7	4C
0005433473256	6670	8	5A
0005433473252	6670	9	5C
0005435257150	6670	10	5D
0005433473250	6670	11	6A
0005433473259	6670	12	6B
0005433473251	6670	13	6C
0005433473244	6670	14	6D
0005435257157	6670	15	7A
0005435257181	6670	16	7C
0005433473246	6670	17	18A
0005433473245	6670	18	18B
0005435257199	6670	19	18D
0005433473260	6670	20	19C
0005433473242	6670	21	19D
0005433473253	6670	22	20A
0005435257179	6670	23	20B
0005433473257	6670	24	20D
0005433473247	6670	25	21B
0005433473249	6670	26	21D
0005435257174	6670	27	22A
0005435257216	6670	28	22B
0005433473255	6670	29	22C
0005433473188	23881	1	1A
0005435257226	23881	2	1B
0005435257228	23881	3	1C
0005435257222	23881	4	1D
0005433473160	23881	5	2A
0005435257234	23881	6	2B
0005435257233	23881	7	2C
0005435257223	23881	8	2D
0005435257227	23881	9	3A
0005433473176	23881	10	3B
0005433473140	23881	11	3D
0005433473139	23881	12	4A
0005433473208	23881	13	4B
0005433473158	23881	14	4C
0005433473168	23881	15	4D
0005433473161	23881	16	5A
0005433473189	23881	17	5B
0005433473165	23881	18	5D
0005433473184	23881	19	6A
0005433473149	23881	20	6C
0005435257230	23881	21	6D
0005433473186	23881	22	7A
0005435257232	23881	23	7B
0005433473173	23881	24	7C
0005433473159	23881	25	18A
0005435257235	23881	26	18B
0005435257225	23881	27	18C
0005435257224	23881	28	18D
0005433473175	23881	29	19A
0005433473152	23881	30	19B
0005433473137	23881	31	19C
0005433473183	23881	32	20B
0005435257229	23881	33	20C
0005433473164	23881	34	20D
0005433473136	23881	35	21B
0005433473187	23881	36	21D
0005433473170	23881	37	21C
0005435257231	23881	38	22A
0005433473154	23881	39	22B
0005433473157	23881	40	22C
0005433473169	23881	41	22D
0005433473163	23881	42	23A
0005434606793	18866	1	1A
0005434606784	18866	2	2A
0005434606790	18866	3	2B
0005434606781	18866	4	3A
0005434606798	18866	5	3B
0005434606788	18866	6	4A
0005434606780	18866	7	5A
0005434606779	18866	8	5B
0005434606785	18866	9	6A
0005434606799	18866	10	6B
0005434606822	22382	1	1A
0005434606821	22382	2	2B
0005434604890	22382	3	4A
0005434604889	22382	4	3B
0005434604888	22382	5	5A
0005434604891	22382	6	6B
0005434522434	3846	1	1B
0005434602899	3846	2	1C
0005434522436	3846	3	2A
0005435904394	3846	4	2B
0005434522443	3846	5	2D
0005434522441	3846	6	3A
0005435904382	3846	7	3B
0005435904365	3846	8	3D
0005434522438	3846	9	3C
0005435904383	3846	10	4C
0005434602896	3846	11	5A
0005435904381	3846	12	5C
0005435904390	3846	13	5D
0005434602894	3846	14	6A
0005434522437	3846	15	6C
0005434522442	3846	16	6D
0005434522439	3846	17	7A
0005434602898	3846	18	18C
0005434522432	3846	19	18D
0005434602897	3846	20	19A
0005435904388	3846	21	19C
0005434602895	3846	22	20A
0005434522433	3846	23	20C
0005434522431	3846	24	20D
0005435904389	3846	25	21A
0005434522435	3846	26	21B
0005434522440	3846	27	21C
0005434604850	19067	1	1B
0005434522412	19067	2	1C
0005434522391	19067	3	2A
0005434604863	19067	4	2B
0005434604846	19067	5	2C
0005435904405	19067	6	2D
0005434522411	19067	7	3A
0005434522402	19067	8	3B
0005435904403	19067	9	3D
0005434522401	19067	10	4A
0005434522400	19067	11	4B
0005434602868	19067	12	4D
0005434604844	19067	13	5B
0005434604868	19067	14	5D
0005434604856	19067	15	6B
0005434522387	19067	16	6C
0005434602869	19067	17	6D
0005434604843	19067	18	7B
0005434522399	19067	19	7C
0005434604859	19067	20	7D
0005434522393	19067	21	18A
0005434604858	19067	22	18B
0005435904404	19067	23	18D
0005435904406	19067	24	19A
0005434604849	19067	25	19C
0005434604847	19067	26	19D
0005434602871	19067	27	20A
0005435904402	19067	28	20B
0005434522408	19067	29	20C
0005434602870	19067	30	20D
0005434604857	19067	31	21A
0005434522407	19067	32	22A
0005434522394	19067	33	22C
0005434522396	19067	34	22D
0005435904401	19067	35	23A
0005432751522	409	1	1A
0005432753293	409	2	1C
0005432747523	409	3	1D
0005433293202	409	4	1F
0005432753295	409	5	2A
0005432747515	409	6	2C
0005432747502	409	7	2F
0005432751519	409	8	3A
0005432753296	409	9	3C
0005432890832	409	10	3F
0005432890805	409	11	4A
0005432747526	409	12	4C
0005432890879	409	13	4D
0005432890878	409	14	4E
0005432747506	409	15	4F
0005432890858	409	16	5C
0005432751518	409	17	5D
0005432747513	409	18	5E
0005432747497	409	19	5F
0005432751520	409	20	6A
0005433293207	409	21	6C
0005432890914	409	22	6D
0005432749781	409	23	6F
0005433293156	409	24	7A
0005432890860	409	25	7C
0005432219996	409	26	7D
0005432747533	409	27	7E
0005432751521	409	28	8A
0005432890831	409	29	8C
0005432747508	409	30	8E
0005432747499	409	31	9A
0005432747504	409	32	9C
0005432747522	409	33	9D
0005432747518	409	34	9E
0005432219997	409	35	9F
0005433293183	409	36	10C
0005432747514	409	37	10D
0005432219998	409	38	10F
0005433293184	409	39	11A
0005432747534	409	40	11C
0005433875361	409	41	11D
0005432747531	409	42	11E
0005432747520	409	43	12A
0005432890776	409	44	12C
0005432747517	409	45	12D
0005432747532	409	46	12E
0005433875363	409	47	12F
0005433293164	409	48	13C
0005432747501	409	49	13D
0005432890859	409	50	13F
0005433875366	409	51	14A
0005432890913	409	52	14D
0005432747511	409	53	14E
0005432747510	409	54	14F
0005432747528	409	55	15D
0005432747525	409	56	15E
0005432747498	409	57	15F
0005435627118	409	58	16A
0005433293188	409	59	16C
0005432219999	409	60	16D
0005432747524	409	61	17A
0005432890799	409	62	17C
0005432747527	409	63	17D
0005432753294	409	64	17E
0005432747507	409	65	17F
0005432747529	409	66	18A
0005433293189	409	67	18C
0005432747519	409	68	18D
0005432747530	409	69	18E
0005432747516	409	70	18F
0005432747500	409	71	19A
0005432747512	409	72	19C
0005432747505	409	73	19E
0005432747503	409	74	19F
0005432747521	409	75	20A
0005433875362	409	76	20C
0005432747509	409	77	20D
0005432891006	12035	1	1A
0005432747165	12035	2	1C
0005432890997	12035	3	2A
0005432747298	12035	4	2C
0005432747261	12035	5	2D
0005432747202	12035	6	2F
0005432747287	12035	7	3A
0005433875377	12035	8	3C
0005432747198	12035	9	3F
0005432891009	12035	10	4A
0005432891002	12035	11	4D
0005432747162	12035	12	4E
0005432747196	12035	13	4F
0005432747007	12035	14	5A
0005432747085	12035	15	5C
0005432747267	12035	16	5D
0005432890992	12035	17	5E
0005432890999	12035	18	5F
0005432747197	12035	19	6A
0005432891005	12035	20	6C
0005435627113	12035	21	6F
0005432890994	12035	22	7C
0005432214800	12035	23	8A
0005432747299	12035	24	8D
0005432747106	12035	25	8E
0005432747108	12035	26	8F
0005432891004	12035	27	9A
0005432756808	12035	28	9C
0005432747118	12035	29	9D
0005432747251	12035	30	9E
0005432747139	12035	31	9F
0005432890998	12035	32	10D
0005432749753	12035	33	10E
0005432891001	12035	34	10F
0005434153533	12035	35	11A
0005434153531	12035	36	11D
0005432756801	12035	37	11E
0005432753259	12035	38	12D
0005432753260	12035	39	12E
0005432747257	12035	40	12F
0005432891008	12035	41	13C
0005434153532	12035	42	13D
0005432747288	12035	43	13E
0005432891003	12035	44	13F
0005432747250	12035	45	14C
0005432747100	12035	46	14F
0005432747105	12035	47	15A
0005432747210	12035	48	15D
0005432747006	12035	49	15E
0005432749767	12035	50	15F
0005434153534	12035	51	16A
0005432890991	12035	52	16D
0005432890993	12035	53	17A
0005432747232	12035	54	17C
0005432747155	12035	55	17D
0005432890995	12035	56	17E
0005432214802	12035	57	17F
0005432747215	12035	58	18A
0005432747268	12035	59	18C
0005432214801	12035	60	18E
0005432747091	12035	61	18F
0005432890990	12035	62	19A
0005432891000	12035	63	19D
0005432890996	12035	64	19E
0005432747090	12035	65	19F
0005432747154	12035	66	20A
0005432891007	12035	67	20C
0005432747150	12035	68	20D
0005432747246	12035	69	20F
0005433531286	18998	1	1A
0005433525015	18998	2	2A
0005432927931	18998	3	2C
0005433525021	18998	4	4A
0005433533300	18998	5	5A
0005433533302	18998	6	5D
0005433525018	18998	7	6A
0005433531284	18998	8	6B
0005433525016	18998	9	6D
0005433525017	18998	10	7B
0005432927921	18998	11	7C
0005433525022	18998	12	18A
0005433525019	18998	13	18C
0005433525023	18998	14	18D
0005432927935	18998	15	19A
0005433525014	18998	16	20C
0005433531285	18998	17	20D
0005432927932	18998	18	21C
0005433533301	18998	19	22D
0005433525020	18998	20	23B
0005432927978	32487	1	1A
0005433524970	32487	2	1C
0005433524944	32487	3	2A
0005433524900	32487	4	2B
0005433524955	32487	5	3A
0005433531257	32487	6	3C
0005432927982	32487	7	4B
0005433527234	32487	8	5B
0005433524957	32487	9	7C
0005433524927	32487	10	18A
0005432927977	32487	11	18D
0005433524950	32487	12	19A
0005433524980	32487	13	19C
0005433524928	32487	14	19D
0005433527215	32487	15	20A
0005433524951	32487	16	20B
0005433524912	32487	17	21A
0005432927980	32487	18	21D
0005432927981	32487	19	22A
0005432927979	32487	20	22C
0005433531266	32487	21	23A
0005432121314	5250	1	1C
0005432121316	5250	2	1D
0005434823514	5250	3	1K
0005435372735	5250	4	1H
0005434823464	5250	5	2C
0005435372677	5250	6	2G
0005434823426	5250	7	3A
0005434823466	5250	8	3D
0005434823511	5250	9	3C
0005434823405	5250	10	3G
0005434823470	5250	11	4G
0005434823425	5250	12	4D
0005435386529	5250	13	4H
0005434823448	5250	14	5D
0005435372587	5250	15	5C
0005434823491	5250	16	5H
0005435372799	5250	17	5G
0005434823512	5250	18	11A
0005435386524	5250	19	5K
0005434831140	5250	20	11C
0005435372806	5250	21	11G
0005434823445	5250	22	11F
0005434828693	5250	23	11H
0005435372807	5250	24	12A
0005434558265	5250	25	11K
0005435150020	5250	26	12E
0005434823497	5250	27	12D
0005435150018	5250	28	12G
0005434823461	5250	29	13A
0005432121324	5250	30	12K
0005434823488	5250	31	12H
0005434823398	5250	32	13D
0005434823441	5250	33	13E
0005434823468	5250	34	13H
0005434823438	5250	35	13G
0005435372510	5250	36	14C
0005435372554	5250	37	14A
0005435372644	5250	38	13K
0005435372745	5250	39	14E
0005434823455	5250	40	14D
0005434823453	5250	41	14G
0005434823407	5250	42	14F
0005435372656	5250	43	15C
0005435372815	5250	44	15A
0005434823502	5250	45	15E
0005432121320	5250	46	15D
0005435304122	5250	47	15G
0005435372697	5250	48	15F
0005435372627	5250	49	16A
0005434823499	5250	50	15K
0005434831143	5250	51	15H
0005434823409	5250	52	16D
0005435299726	5250	53	16E
0005435372805	5250	54	16H
0005434558264	5250	55	16G
0005434823476	5250	56	17C
0005435372379	5250	57	17D
0005434823462	5250	58	17G
0005435372670	5250	59	17F
0005434823505	5250	60	18A
0005434823508	5250	61	17K
0005435372465	5250	62	18C
0005434831141	5250	63	18B
0005432394099	5250	64	18E
0005434823391	5250	65	18D
0005434823518	5250	66	18G
0005434558266	5250	67	18F
0005435372693	5250	68	18J
0005435150014	5250	69	18H
0005435372344	5250	70	18K
0005432121318	5250	71	19C
0005434823427	5250	72	19H
0005434823506	5250	73	19G
0005435150016	5250	74	20A
0005432121321	5250	75	19K
0005435372247	5250	76	20B
0005435299736	5250	77	20E
0005434823477	5250	78	20D
0005434823474	5250	79	20G
0005434558260	5250	80	20F
0005434823509	5250	81	20K
0005435150009	5250	82	21A
0005434823454	5250	83	21D
0005434823489	5250	84	21C
0005435372736	5250	85	21E
0005434828691	5250	86	21G
0005432394101	5250	87	22A
0005435372766	5250	88	21K
0005434823501	5250	89	21J
0005435150011	5250	90	22D
0005434831139	5250	91	22C
0005434823510	5250	92	22B
0005434823481	5250	93	22E
0005434823399	5250	94	22H
0005434823483	5250	95	22G
0005435372475	5250	96	22K
0005435372650	5250	97	23A
0005435372346	5250	98	23D
0005435372519	5250	99	23C
0005434823434	5250	100	23G
0005435304129	5250	101	23H
0005432396238	5250	102	23K
0005434823395	5250	103	24G
0005435299724	5250	104	24F
0005435299723	5250	105	24D
0005435735109	5250	106	25A
0005435372556	5250	107	25C
0005435372468	5250	108	25B
0005434823479	5250	109	25E
0005435372643	5250	110	25H
0005434823410	5250	111	25G
0005435372541	5250	112	25K
0005435372744	5250	113	26C
0005435372577	5250	114	26B
0005434823471	5250	115	26E
0005434823515	5250	116	26G
0005434558258	5250	117	26F
0005434664955	5250	118	26J
0005434823519	5250	119	27A
0005434823516	5250	120	26K
0005434823419	5250	121	27D
0005434823463	5250	122	27C
0005434823390	5250	123	27B
0005435372469	5250	124	27F
0005435372870	5250	125	27E
0005435372798	5250	126	27J
0005435372691	5250	127	27H
0005435372816	5250	128	28C
0005435372665	5250	129	28G
0005435661880	5250	130	28F
0005435150019	5250	131	28E
0005435150010	5250	132	28K
0005435150008	5250	133	28H
0005434823447	5250	134	29B
0005432394100	5250	135	29A
0005434823449	5250	136	29D
0005434664956	5250	137	29C
0005435386523	5250	138	29F
0005435372345	5250	139	29E
0005435372527	5250	140	29H
0005435372626	5250	141	29G
0005435178983	5250	142	29J
0005435304103	5250	143	30B
0005435372537	5250	144	30A
0005434823403	5250	145	30E
0005434823496	5250	146	30D
0005434823443	5250	147	30C
0005434823459	5250	148	30G
0005434831142	5250	149	30J
0005434823418	5250	150	30H
0005435372772	5250	151	31B
0005432396240	5250	152	31A
0005435304123	5250	153	30K
0005435735077	5250	154	31C
0005432121315	5250	155	31F
0005434558259	5250	156	31E
0005435372892	5250	157	31J
0005434823406	5250	158	31H
0005434823393	5250	159	31G
0005434823493	5250	160	32E
0005435372759	5250	161	32D
0005432121313	5250	162	32G
0005434823450	5250	163	32J
0005435372839	5250	164	32H
0005432121323	5250	165	32K
0005435386504	5250	166	33D
0005434823408	5250	167	33C
0005435150017	5250	168	33B
0005434823440	5250	169	33F
0005435372625	5250	170	33H
0005434823480	5250	171	33G
0005434823469	5250	172	34A
0005435372613	5250	173	33K
0005434823411	5250	174	34C
0005434823486	5250	175	34E
0005435150012	5250	176	34D
0005434823423	5250	177	34G
0005434823392	5250	178	34H
0005434823475	5250	179	35B
0005435150021	5250	180	35D
0005434823394	5250	181	35F
0005434823504	5250	182	35J
0005434823442	5250	183	35H
0005434823485	5250	184	36D
0005434823415	5250	185	36C
0005434823451	5250	186	36B
0005434823433	5250	187	36F
0005434823487	5250	188	36E
0005434823495	5250	189	36H
0005435372436	5250	190	36G
0005434823467	5250	191	36K
0005434823424	5250	192	36J
0005434823420	5250	193	37C
0005435386498	5250	194	37B
0005434823414	5250	195	37D
0005434823498	5250	196	37F
0005435372437	5250	197	37E
0005434823478	5250	198	37H
0005434823400	5250	199	37J
0005434823444	5250	200	38C
0005434664954	5250	201	38B
0005434823452	5250	202	38J
0005434823422	5250	203	38H
0005435150015	5250	204	39B
0005434823404	5250	205	39C
0005435299738	5250	206	39G
0005434558263	5250	207	39E
0005434823413	5250	208	39D
0005435372534	5250	209	39H
0005435372604	5250	210	39K
0005435372792	5250	211	40C
0005434823484	5250	212	40D
0005435150013	5250	213	40H
0005435661891	5250	214	40F
0005434823436	5250	215	40J
0005435372624	5250	216	41B
0005434823437	5250	217	41A
0005434823402	5250	218	40K
0005432121326	5250	219	41C
0005435372724	5250	220	41F
0005434823500	5250	221	41E
0005434823492	5250	222	41H
0005434823396	5250	223	41G
0005434823456	5250	224	42A
0005434823432	5250	225	41K
0005435372605	5250	226	41J
0005434558261	5250	227	42B
0005434823473	5250	228	42E
0005434823513	5250	229	42D
0005432121325	5250	230	42F
0005434823517	5250	231	42J
0005434823465	5250	232	42H
0005434558262	5250	233	43B
0005434823429	5250	234	42K
0005434823457	5250	235	43D
0005434823435	5250	236	43C
0005435372383	5250	237	43F
0005434823482	5250	238	43E
0005434823430	5250	239	43H
0005435372692	5250	240	43G
0005432396241	5250	241	43K
0005432121317	5250	242	43J
0005435386490	5250	243	44B
0005435372722	5250	244	44D
0005432121319	5250	245	44H
0005434558267	5250	246	44G
0005434823417	5250	247	44K
0005435372871	5250	248	44J
0005434823431	5250	249	45C
0005435372573	5250	250	45B
0005434823439	5250	251	45E
0005434823416	5250	252	45J
0005435372647	5250	253	45G
0005435372380	5250	254	45K
0005435304119	5250	255	46B
0005435735074	5250	256	46A
0005435304128	5250	257	46E
0005435372838	5250	258	46D
0005434823458	5250	259	46G
0005432396239	5250	260	46F
0005434823507	5250	261	46K
0005434823421	5250	262	46J
0005434823397	5250	263	46H
0005434823494	5250	264	47C
0005432121322	5250	265	47K
0005434823428	5250	266	47H
0005434823460	5250	267	48D
0005435735108	5250	268	48C
0005435372575	5250	269	48F
0005434823446	5250	270	48E
0005435372621	5250	271	48G
0005434823490	5250	272	49A
0005435372615	5250	273	48K
0005432396237	5250	274	49E
0005435386491	5250	275	49F
0005434823412	5250	276	49K
0005435304111	5250	277	49H
0005434823503	5250	278	50C
0005435372530	5250	279	50A
0005434823401	5250	280	50G
0005434828692	5250	281	50K
0005435178984	5250	282	51F
0005434823472	5250	283	51E
0005435304132	5250	284	51G
0005434558167	9917	1	1D
0005434822008	9917	2	1C
0005435299769	9917	3	1A
0005434822690	9917	4	1G
0005435373196	9917	5	2A
0005432400075	9917	6	1H
0005434821593	9917	7	2C
0005434821976	9917	8	2H
0005432203056	9917	9	2G
0005435373177	9917	10	3A
0005434822734	9917	11	2K
0005434822231	9917	12	3C
0005435386565	9917	13	3K
0005435373185	9917	14	3H
0005435373194	9917	15	4C
0005432400095	9917	16	4A
0005435373167	9917	17	4D
0005434822668	9917	18	4K
0005434822439	9917	19	4H
0005435735134	9917	20	5D
0005435179692	9917	21	5C
0005435386567	9917	22	5A
0005434831111	9917	23	5H
0005434828661	9917	24	5G
0005434822434	9917	25	11E
0005434823023	9917	26	11G
0005434821994	9917	27	11K
0005434822402	9917	28	11H
0005435373184	9917	29	12C
0005434822226	9917	30	12E
0005435373198	9917	31	12D
0005434822566	9917	32	12G
0005435386568	9917	33	12F
0005434822174	9917	34	12K
0005434558185	9917	35	12H
0005432400091	9917	36	13D
0005435661929	9917	37	13C
0005434822026	9917	38	13H
0005434822669	9917	39	13G
0005432400080	9917	40	14A
0005434822346	9917	41	13K
0005434822241	9917	42	14D
0005434822477	9917	43	14C
0005434822328	9917	44	14G
0005434822614	9917	45	14F
0005434821948	9917	46	14E
0005434822181	9917	47	14K
0005435373199	9917	48	15D
0005435149931	9917	49	15H
0005434822388	9917	50	15K
0005434822227	9917	51	16D
0005435373210	9917	52	16C
0005434821945	9917	53	16F
0005435373163	9917	54	16E
0005435373183	9917	55	16K
0005435373197	9917	56	16H
0005434822393	9917	57	17A
0005435373191	9917	58	17C
0005435373180	9917	59	17H
0005435373200	9917	60	17G
0005434822178	9917	61	17K
0005435735135	9917	62	18C
0005434822606	9917	63	18A
0005432400094	9917	64	18E
0005434822770	9917	65	18G
0005434822521	9917	66	18H
0005434822706	9917	67	19B
0005435661927	9917	68	19A
0005435373170	9917	69	19C
0005435373181	9917	70	19F
0005435149916	9917	71	19E
0005435149844	9917	72	19H
0005435373216	9917	73	19G
0005434822300	9917	74	20A
0005434822576	9917	75	19K
0005432203059	9917	76	20B
0005434664940	9917	77	20E
0005435373215	9917	78	20D
0005434822225	9917	79	20F
0005434822397	9917	80	20J
0005434822034	9917	81	21B
0005432203055	9917	82	21A
0005434828671	9917	83	20K
0005434822289	9917	84	21D
0005434821974	9917	85	21C
0005434822386	9917	86	22A
0005434822522	9917	87	21J
0005432823449	9917	88	22C
0005434821965	9917	89	22D
0005435373222	9917	90	22F
0005435302194	9917	91	23C
0005434822567	9917	92	23G
0005434821869	9917	93	23J
0005435373193	9917	94	24D
0005435373206	9917	95	24F
0005435386571	9917	96	24E
0005434822428	9917	97	25B
0005435373174	9917	98	25D
0005434822438	9917	99	25F
0005435302191	9917	100	25E
0005435735136	9917	101	25G
0005434822785	9917	102	26B
0005434822398	9917	103	26E
0005435373164	9917	104	26D
0005434822648	9917	105	26C
0005432400077	9917	106	26G
0005434821796	9917	107	26F
0005435373166	9917	108	26J
0005434822175	9917	109	27B
0005434822620	9917	110	27A
0005434822179	9917	111	27D
0005434823119	9917	112	27C
0005434822001	9917	113	27F
0005432203052	9917	114	27E
0005434822705	9917	115	27H
0005434822363	9917	116	27G
0005434821949	9917	117	27J
0005435373192	9917	118	28C
0005434558184	9917	119	28B
0005434821966	9917	120	28A
0005432203058	9917	121	28G
0005435373204	9917	122	28J
0005434822747	9917	123	29B
0005434821765	9917	124	29A
0005435373227	9917	125	29C
0005434822803	9917	126	29F
0005434822615	9917	127	29H
0005434821870	9917	128	30A
0005434822793	9917	129	29K
0005434558149	9917	130	29J
0005434822309	9917	131	30C
0005434822401	9917	132	30B
0005435373171	9917	133	30E
0005434821632	9917	134	30D
0005435373219	9917	135	30G
0005434828674	9917	136	30F
0005434822290	9917	137	30K
0005434822085	9917	138	30J
0005434821951	9917	139	31B
0005434822119	9917	140	31A
0005435373190	9917	141	31D
0005434822499	9917	142	31E
0005434822387	9917	143	31H
0005435299771	9917	144	31G
0005435299768	9917	145	31K
0005435149827	9917	146	32B
0005435302192	9917	147	32A
0005435386570	9917	148	32E
0005435149927	9917	149	32G
0005435299772	9917	150	32F
0005432400076	9917	151	32J
0005435661930	9917	152	33A
0005435373178	9917	153	32K
0005435373207	9917	154	33C
0005435373211	9917	155	33F
0005434822846	9917	156	33E
0005435373165	9917	157	33K
0005434822015	9917	158	34C
0005434823118	9917	159	34A
0005434822344	9917	160	34E
0005435149933	9917	161	34D
0005434822406	9917	162	34G
0005434821964	9917	163	34F
0005432400081	9917	164	34K
0005432203053	9917	165	34H
0005434822938	9917	166	35B
0005435386569	9917	167	35A
0005434822424	9917	168	35D
0005434822460	9917	169	35G
0005434822691	9917	170	35F
0005434822396	9917	171	35E
0005434558166	9917	172	35K
0005435302193	9917	173	35J
0005434822212	9917	174	36B
0005434823022	9917	175	36E
0005435386566	9917	176	36D
0005434821931	9917	177	36H
0005434664939	9917	178	37B
0005434822523	9917	179	37A
0005435373223	9917	180	36K
0005434821950	9917	181	37G
0005434822007	9917	182	37F
0005434822301	9917	183	37E
0005434822804	9917	184	37H
0005434821913	9917	185	37J
0005434822687	9917	186	38C
0005435373182	9917	187	38H
0005434822385	9917	188	39B
0005432203057	9917	189	39A
0005434822587	9917	190	39C
0005435299773	9917	191	39F
0005434822511	9917	192	39H
0005435373203	9917	193	39G
0005434822308	9917	194	40A
0005434822407	9917	195	39K
0005434822647	9917	196	39J
0005435373173	9917	197	40B
0005434822939	9917	198	40D
0005434822170	9917	199	40H
0005435373202	9917	200	40G
0005434828672	9917	201	40F
0005434828675	9917	202	40K
0005435373205	9917	203	41B
0005435373224	9917	204	41A
0005435373209	9917	205	41D
0005432400093	9917	206	41C
0005435373226	9917	207	41F
0005434822195	9917	208	41E
0005434822316	9917	209	41K
0005434822676	9917	210	42C
0005434822718	9917	211	42B
0005435373188	9917	212	42E
0005434822588	9917	213	42G
0005434822684	9917	214	42F
0005435149911	9917	215	42J
0005434822435	9917	216	42H
0005434822487	9917	217	43B
0005434822194	9917	218	43D
0005434822345	9917	219	43C
0005435373221	9917	220	43F
0005434822111	9917	221	43E
0005434822530	9917	222	43J
0005435373225	9917	223	43G
0005434822027	9917	224	43K
0005435373212	9917	225	44C
0005434822353	9917	226	44B
0005434822847	9917	227	44E
0005434822219	9917	228	44F
0005434822297	9917	229	44J
0005432823448	9917	230	44H
0005434822400	9917	231	45B
0005435373168	9917	232	44K
0005434822145	9917	233	45F
0005434822187	9917	234	45E
0005435373172	9917	235	45J
0005435373208	9917	236	45H
0005435373189	9917	237	46C
0005435373220	9917	238	46G
0005434822667	9917	239	46F
0005435373179	9917	240	46K
0005435373186	9917	241	46J
0005435373214	9917	242	46H
0005435373201	9917	243	47A
0005434831092	9917	244	47E
0005435373169	9917	245	47C
0005435373187	9917	246	47G
0005434822921	9917	247	47F
0005434822059	9917	248	48C
0005435149914	9917	249	48E
0005435373162	9917	250	48D
0005432203054	9917	251	48H
0005435373175	9917	252	48G
0005434828673	9917	253	49A
0005434822699	9917	254	48K
0005435299770	9917	255	49D
0005435373213	9917	256	49E
0005434822748	9917	257	49K
0005435661928	9917	258	49H
0005435373195	9917	259	50E
0005435373176	9917	260	50D
0005434822459	9917	261	50F
0005435373217	9917	262	50K
0005434822364	9917	263	50H
0005435373218	9917	264	51E
0005435082778	7022	1	1B
0005435082783	7022	2	1D
0005435082781	7022	3	2B
0005435790302	7022	4	2D
0005435082779	7022	5	4D
0005435790303	7022	6	5D
0005435082782	7022	7	7B
0005435082780	7022	8	19A
0005435790304	7022	9	21C
0005435082688	26016	1	2B
0005435082714	26016	2	3A
0005435082708	26016	3	3D
0005435790279	26016	4	6B
0005435790285	26016	5	18C
0005435082706	26016	6	19B
0005435082689	26016	7	21A
0005435790280	26016	8	21B
0005435082707	26016	9	21D
0005435790284	26016	10	22A
0005435082722	26016	11	22B
0005435790276	26016	12	22C
0005435082684	26016	13	23A
0005435790286	26016	14	23B
0005434756375	9519	1	1A
0005434214098	9519	2	1C
0005434756392	9519	3	1D
0005434214209	9519	4	1F
0005434756378	9519	5	2A
0005434756362	9519	6	2C
0005434213873	9519	7	2D
0005434213881	9519	8	2F
0005434756406	9519	9	3A
0005434756366	9519	10	3C
0005434214053	9519	11	3D
0005434214145	9519	12	3F
0005434756386	9519	13	4A
0005434756399	9519	14	4C
0005434213990	9519	15	4E
0005434214090	9519	16	4F
0005434213973	9519	17	5A
0005434756371	9519	18	5C
0005434756364	9519	19	5D
0005434756389	9519	20	5E
0005434213930	9519	21	5F
0005434756370	9519	22	6C
0005434214253	9519	23	6D
0005434214091	9519	24	6E
0005434756395	9519	25	7A
0005434214146	9519	26	7C
0005434756384	9519	27	7D
0005434214207	9519	28	7E
0005434756365	9519	29	7F
0005434756380	9519	30	8A
0005434213886	9519	31	8C
0005434756407	9519	32	8D
0005434213967	9519	33	8E
0005434214070	9519	34	9A
0005434756373	9519	35	9D
0005434756367	9519	36	9E
0005434214252	9519	37	9F
0005434756402	9519	38	10A
0005434214260	9519	39	10C
0005434214148	9519	40	10D
0005434213892	9519	41	10E
0005434756396	9519	42	10F
0005434756397	9519	43	11A
0005434756393	9519	44	11C
0005434756369	9519	45	11D
0005434756381	9519	46	11E
0005434213882	9519	47	11F
0005434213920	9519	48	12A
0005434756374	9519	49	12C
0005434214100	9519	50	12D
0005434213890	9519	51	12E
0005434213901	9519	52	12F
0005434756403	9519	53	13A
0005434756400	9519	54	13C
0005434214144	9519	55	13D
0005434214210	9519	56	13F
0005434756388	9519	57	14A
0005434756390	9519	58	14C
0005434213891	9519	59	14D
0005434214028	9519	60	14E
0005434756379	9519	61	14F
0005434756394	9519	62	15A
0005434214261	9519	63	15C
0005434756382	9519	64	15D
0005434756376	9519	65	15E
0005434213983	9519	66	15F
0005434214094	9519	67	16A
0005434213857	9519	68	16C
0005434756383	9519	69	16D
0005434756401	9519	70	16E
0005434756404	9519	71	16F
0005434213906	9519	72	17A
0005434756372	9519	73	17C
0005434213851	9519	74	17E
0005434214149	9519	75	17F
0005434214137	9519	76	18A
0005434756387	9519	77	18C
0005434756398	9519	78	18D
0005434756368	9519	79	18E
0005434214095	9519	80	18F
0005434756385	9519	81	19A
0005434756391	9519	82	19C
0005434213991	9519	83	19D
0005434756377	9519	84	19E
0005434756405	9519	85	19F
0005434214049	9519	86	20A
0005434214208	9519	87	20C
0005434756363	9519	88	20D
0005434214005	9519	89	20E
0005434213900	9519	90	20F
0005434214426	28626	1	1A
0005434214448	28626	2	1D
0005434214444	28626	3	1F
0005434755976	28626	4	2A
0005434755709	28626	5	2C
0005434214419	28626	6	2D
0005434214423	28626	7	2F
0005434214415	28626	8	3A
0005434755862	28626	9	3C
0005434214450	28626	10	3D
0005434214442	28626	11	3F
0005434755910	28626	12	4A
0005434755899	28626	13	4C
0005434755939	28626	14	4D
0005434214458	28626	15	4E
0005434214453	28626	16	4F
0005434755990	28626	17	5A
0005434214457	28626	18	5C
0005434214413	28626	19	5E
0005434214422	28626	20	5F
0005434214431	28626	21	6A
0005434755868	28626	22	6C
0005434755892	28626	23	6D
0005434214443	28626	24	6E
0005434755865	28626	25	6F
0005434214433	28626	26	7A
0005434755981	28626	27	7C
0005434755881	28626	28	7D
0005434755950	28626	29	7E
0005434755994	28626	30	7F
0005434214439	28626	31	8A
0005434755783	28626	32	8C
0005434214429	28626	33	8E
0005434214437	28626	34	8D
0005434214432	28626	35	8F
0005434755973	28626	36	9A
0005434755854	28626	37	9D
0005434755977	28626	38	9E
0005434214455	28626	39	9F
0005434755861	28626	40	10A
0005434214451	28626	41	10C
0005434214424	28626	42	10D
0005434756004	28626	43	10E
0005434755853	28626	44	10F
0005434214449	28626	45	11A
0005434214420	28626	46	11C
0005434756005	28626	47	11D
0005434755909	28626	48	11E
0005434755846	28626	49	12A
0005434755955	28626	50	12C
0005434214441	28626	51	12D
0005434755921	28626	52	12E
0005434214440	28626	53	12F
0005434214436	28626	54	13A
0005434755872	28626	55	13C
0005434214427	28626	56	13D
0005434214425	28626	57	13E
0005434755796	28626	58	13F
0005434755845	28626	59	14A
0005434214418	28626	60	14C
0005434755879	28626	61	14D
0005434214447	28626	62	14E
0005434214416	28626	63	14F
0005434755795	28626	64	15A
0005434214417	28626	65	15C
0005434214446	28626	66	15D
0005434214445	28626	67	15E
0005434755938	28626	68	15F
0005434756006	28626	69	16A
0005434214428	28626	70	16C
0005434755920	28626	71	16D
0005434214452	28626	72	16E
0005434755871	28626	73	16F
0005434214438	28626	74	17A
0005434755949	28626	75	17D
0005434214456	28626	76	17E
0005434214421	28626	77	17F
0005434755925	28626	78	18A
0005434755980	28626	79	18C
0005434214434	28626	80	18D
0005434755912	28626	81	18E
0005434755855	28626	82	18F
0005434214414	28626	83	19A
0005434214454	28626	84	19C
0005434755997	28626	85	19E
0005434755991	28626	86	19D
0005434755956	28626	87	19F
0005434214435	28626	88	20A
0005434214430	28626	89	20C
0005434755996	28626	90	20D
0005434755926	28626	91	20E
0005434755880	28626	92	20F
0005435100119	10835	1	3A
0005435100118	10835	2	18C
0005435100120	10835	3	22D
0005435100085	31800	1	2D
0005435100091	31800	2	7A
0005435100080	31800	3	18A
0005434760195	31800	4	18C
0005434760194	31800	5	19B
0005434760196	31800	6	21D
0005435100092	31800	7	22D
0005433202244	1986	1	1A
0005433202251	1986	2	1B
0005433202180	1986	3	1C
0005434639306	1986	4	1D
0005432290630	1986	5	2A
0005434639289	1986	6	2B
0005434639288	1986	7	2C
0005434639309	1986	8	2D
0005433202112	1986	9	3A
0005433202179	1986	10	3B
0005434639291	1986	11	3C
0005433202234	1986	12	3D
0005432290632	1986	13	4A
0005433202252	1986	14	4B
0005434639307	1986	15	4C
0005433202200	1986	16	4D
0005434639290	1986	17	5A
0005434639301	1986	18	5B
0005433202235	1986	19	5C
0005433202250	1986	20	5D
0005433202242	1986	21	6A
0005432290629	1986	22	6B
0005434639303	1986	23	6C
0005434639304	1986	24	6D
0005433202233	1986	25	7A
0005434639293	1986	26	7B
0005434639308	1986	27	7C
0005432290631	1986	28	7D
0005434639294	1986	29	18A
0005433202275	1986	30	18B
0005434639302	1986	31	18C
0005434639297	1986	32	18D
0005433202247	1986	33	19A
0005433202249	1986	34	19B
0005433202222	1986	35	19C
0005434639300	1986	36	19D
0005434639305	1986	37	20A
0005433202199	1986	38	20B
0005433202246	1986	39	20C
0005433202143	1986	40	20D
0005433202243	1986	41	21A
0005434639299	1986	42	21B
0005434639298	1986	43	21C
0005434639292	1986	44	21D
0005433202224	1986	45	22A
0005433202158	1986	46	22B
0005434639296	1986	47	22C
0005433202297	1986	48	22D
0005434639295	1986	49	23A
0005433202296	1986	50	23B
0005434639022	23258	1	1A
0005434639106	23258	2	1B
0005433202342	23258	3	1D
0005434639045	23258	4	2B
0005434639112	23258	5	2C
0005434639025	23258	6	2D
0005433202337	23258	7	3B
0005433202338	23258	8	3C
0005434639020	23258	9	3D
0005433202336	23258	10	4A
0005434639091	23258	11	4B
0005433202341	23258	12	4C
0005434639105	23258	13	4D
0005434639044	23258	14	5A
0005434639080	23258	15	5B
0005433202333	23258	16	5C
0005434639026	23258	17	5D
0005434639097	23258	18	6A
0005434639086	23258	19	6B
0005433202330	23258	20	6C
0005434639012	23258	21	7B
0005433202335	23258	22	7C
0005433202334	23258	23	7D
0005434639040	23258	24	18A
0005434638930	23258	25	18C
0005433202331	23258	26	18D
0005434639108	23258	27	19B
0005434639063	23258	28	19C
0005434639039	23258	29	19D
0005433202340	23258	30	20A
0005434639107	23258	31	20C
0005434639113	23258	32	20D
0005434639087	23258	33	21C
0005434639095	23258	34	21D
0005434639079	23258	35	22A
0005433202329	23258	36	22B
0005433202339	23258	37	22C
0005433202332	23258	38	23A
0005434639096	23258	39	23B
0005435326569	6047	1	1C
0005435326616	6047	2	1D
0005433533304	6047	3	2A
0005434600789	6047	4	2C
0005434600772	6047	5	3A
0005435326605	6047	6	3D
0005434600771	6047	7	4C
0005433531288	6047	8	4E
0005433531290	6047	9	5C
0005434600790	6047	10	5E
0005434600768	6047	11	6A
0005433531287	6047	12	6C
0005434600794	6047	13	6D
0005432111277	6047	14	7A
0005435326635	6047	15	7C
0005435326634	6047	16	7F
0005435326657	6047	17	8C
0005433531289	6047	18	8E
0005434600776	6047	19	8F
0005434600779	6047	20	9A
0005435326624	6047	21	9E
0005435326615	6047	22	9F
0005434600769	6047	23	10A
0005435326627	6047	24	10C
0005433533305	6047	25	10D
0005432111275	6047	26	11D
0005433533306	6047	27	11E
0005434600792	6047	28	12A
0005434600775	6047	29	12D
0005434600773	6047	30	13C
0005434600791	6047	31	13F
0005434600793	6047	32	14D
0005434600795	6047	33	14F
0005434600784	6047	34	15E
0005434600786	6047	35	15F
0005434600774	6047	36	16C
0005434600770	6047	37	16D
0005433533303	6047	38	16E
0005434600781	6047	39	17A
0005435326629	6047	40	17C
0005435326568	6047	41	17F
0005434600778	6047	42	18A
0005434600782	6047	43	18D
0005434600783	6047	44	18E
0005435326628	6047	45	18F
0005434600787	6047	46	19C
0005434600777	6047	47	19A
0005432111276	6047	48	20C
0005434600785	6047	49	20D
0005434600788	6047	50	20E
0005434600780	6047	51	20F
0005435326732	18587	1	1A
0005434600538	18587	2	1C
0005434600631	18587	3	1F
0005434600623	18587	4	2D
0005434600613	18587	5	3A
0005435326728	18587	6	3D
0005434600614	18587	7	3F
0005434600473	18587	8	4C
0005434600528	18587	9	4D
0005434600632	18587	10	5E
0005434600619	18587	11	6A
0005434600495	18587	12	6E
0005434600456	18587	13	7A
0005434600472	18587	14	8A
0005435326731	18587	15	8C
0005434600464	18587	16	8D
0005434600448	18587	17	8F
0005434600612	18587	18	9C
0005433531246	18587	19	9D
0005435326729	18587	20	10C
0005434600595	18587	21	10D
0005434600539	18587	22	11F
0005435326734	18587	23	12A
0005434600523	18587	24	12C
0005434600474	18587	25	12D
0005435326735	18587	26	12F
0005434600657	18587	27	13A
0005434600615	18587	28	13C
0005435326725	18587	29	13E
0005434600529	18587	30	14A
0005435326733	18587	31	14C
0005433531249	18587	32	14E
0005435326730	18587	33	14F
0005434600550	18587	34	15D
0005435326726	18587	35	15E
0005435326727	18587	36	16A
0005435326736	18587	37	17E
0005434600646	18587	38	17F
0005435326737	18587	39	18A
0005433527201	18587	40	18D
0005434600449	18587	41	18E
0005433531245	18587	42	18F
0005435326724	18587	43	19A
0005433531250	18587	44	19F
0005434551146	10588	1	1A
0005434551113	10588	2	1C
0005434551124	10588	3	1D
0005433180787	10588	4	2A
0005434558254	10588	5	1F
0005434551133	10588	6	2C
0005434551105	10588	7	2D
0005433180939	10588	8	2F
0005434551129	10588	9	3A
0005434551137	10588	10	3C
0005434551136	10588	11	3D
0005434551119	10588	12	3F
0005433180746	10588	13	4A
0005434551123	10588	14	4C
0005434558251	10588	15	4D
0005434558246	10588	16	4E
0005434551108	10588	17	4F
0005433180814	10588	18	5A
0005433180929	10588	19	5C
0005434554062	10588	20	5D
0005434551103	10588	21	5E
0005434551107	10588	22	5F
0005433180868	10588	23	6A
0005433180867	10588	24	6C
0005434551143	10588	25	6D
0005434558249	10588	26	6E
0005433180747	10588	27	6F
0005434551153	10588	28	7A
0005434551127	10588	29	7C
0005433180928	10588	30	7D
0005434551147	10588	31	7E
0005433180807	10588	32	7F
0005434551135	10588	33	8A
0005434551131	10588	34	8C
0005434551142	10588	35	8D
0005433180924	10588	36	8E
0005433180930	10588	37	8F
0005434551155	10588	38	9A
0005434558245	10588	39	9C
0005434551104	10588	40	9D
0005433180889	10588	41	9E
0005434551144	10588	42	9F
0005434558244	10588	43	10A
0005434551116	10588	44	10C
0005434551110	10588	45	10D
0005434551138	10588	46	10E
0005434551125	10588	47	10F
0005434551106	10588	48	11A
0005434551139	10588	49	11D
0005434551100	10588	50	11C
0005434558252	10588	51	11E
0005433180855	10588	52	11F
0005434551132	10588	53	12A
0005434551102	10588	54	12C
0005433180856	10588	55	12D
0005434551117	10588	56	12E
0005434551152	10588	57	12F
0005434551099	10588	58	13A
0005434551128	10588	59	13C
0005433180885	10588	60	13D
0005434558256	10588	61	13E
0005434554061	10588	62	13F
0005434558253	10588	63	14A
0005434551109	10588	64	14C
0005433180806	10588	65	14D
0005433180847	10588	66	14E
0005434551140	10588	67	14F
0005434551120	10588	68	15A
0005434551114	10588	69	15C
0005433180794	10588	70	15D
0005434551111	10588	71	15E
0005434558250	10588	72	15F
0005433180722	10588	73	16A
0005434551112	10588	74	16C
0005433180793	10588	75	16D
0005434551154	10588	76	16E
0005434551121	10588	77	16F
0005434558255	10588	78	17A
0005434551118	10588	79	17C
0005434551150	10588	80	17D
0005434551134	10588	81	17E
0005434551101	10588	82	17F
0005433180760	10588	83	18A
0005434551126	10588	84	18C
0005434551141	10588	85	18D
0005434551130	10588	86	18E
0005434551145	10588	87	18F
0005434551149	10588	88	19A
0005434551148	10588	89	19C
0005434558247	10588	90	19D
0005434558257	10588	91	19E
0005434558248	10588	92	19F
0005434551115	10588	93	20A
0005434551122	10588	94	20C
0005433180940	10588	95	20D
0005434551151	10588	96	20E
0005433180805	10588	97	20F
0005433181062	27716	1	1A
0005433181083	27716	2	4A
0005433181080	27716	3	4C
0005433181074	27716	4	4D
0005433181078	27716	5	6E
0005433181086	27716	6	7A
0005433181068	27716	7	7C
0005433181073	27716	8	9D
0005433181072	27716	9	9E
0005433181085	27716	10	11A
0005433181079	27716	11	11C
0005433181064	27716	12	11D
0005433181081	27716	13	11F
0005433181082	27716	14	13D
0005433181070	27716	15	13E
0005433181067	27716	16	13F
0005433181084	27716	17	14D
0005433181065	27716	18	14E
0005433181063	27716	19	15A
0005433181075	27716	20	15C
0005433181076	27716	21	18A
0005433181077	27716	22	19C
0005433181066	27716	23	19D
0005433181071	27716	24	19E
0005433181069	27716	25	20E
0005434550580	27713	1	1A
0005434550874	27713	2	1C
0005434550592	27713	3	1F
0005434550542	27713	4	2D
0005434550853	27713	5	2F
0005434558195	27713	6	3C
0005434550693	27713	7	3D
0005434550786	27713	8	3F
0005434558193	27713	9	4A
0005434550950	27713	10	4C
0005434550559	27713	11	4F
0005434550861	27713	12	5C
0005434550688	27713	13	5D
0005434550617	27713	14	5E
0005434550527	27713	15	5F
0005434550804	27713	16	6A
0005434550859	27713	17	6C
0005434550785	27713	18	6D
0005434550561	27713	19	6E
0005434558180	27713	20	6F
0005434558188	27713	21	7A
0005434550930	27713	22	7E
0005434558190	27713	23	8C
0005434558194	27713	24	8D
0005434558169	27713	25	8E
0005434550708	27713	26	8F
0005434550419	27713	27	9C
0005434550808	27713	28	9D
0005434550760	27713	29	10D
0005434550509	27713	30	10E
0005434550757	27713	31	10F
0005434558192	27713	32	11A
0005434550562	27713	33	11C
0005434550615	27713	34	11D
0005434550689	27713	35	11F
0005434550655	27713	36	12C
0005434550784	27713	37	12D
0005434550862	27713	38	12E
0005434558168	27713	39	12F
0005434550680	27713	40	13C
0005434558204	27713	41	13E
0005434550733	27713	42	13F
0005434550547	27713	43	14A
0005434550812	27713	44	14D
0005434550690	27713	45	14E
0005434550579	27713	46	14F
0005434554040	27713	47	15A
0005434550709	27713	48	15C
0005434550810	27713	49	15D
0005434550819	27713	50	15E
0005434550811	27713	51	15F
0005434550806	27713	52	16A
0005434550718	27713	53	16C
0005434550404	27713	54	16D
0005434558181	27713	55	16E
0005434550558	27713	56	16F
0005434558189	27713	57	17A
0005434550736	27713	58	17C
0005434550735	27713	59	17D
0005434550875	27713	60	17F
0005434550710	27713	61	18A
0005434550854	27713	62	18C
0005434550931	27713	63	18D
0005434550519	27713	64	18F
0005434550616	27713	65	19D
0005434550781	27713	66	19E
0005434558196	27713	67	20A
0005434550640	27713	68	20D
0005433459217	6152	1	1B
0005433459214	6152	2	2A
0005433459216	6152	3	2B
0005433459215	6152	4	3A
0005435254440	6152	5	6B
0005433459182	19345	1	1A
0005433459171	19345	2	1B
0005433459178	19345	3	2A
0005433459153	19345	4	3A
0005435254472	19345	5	3B
0005433459175	19345	6	5A
0005433459179	19345	7	6B
0005435254471	19345	8	6A
0005435682097	6739	1	1A
0005435682101	6739	2	1C
0005435682083	6739	3	1D
0005435682078	6739	4	1F
0005435682071	6739	5	2A
0005435682069	6739	6	2C
0005435682068	6739	7	2D
0005435682094	6739	8	3A
0005435682093	6739	9	3C
0005435682080	6739	10	3D
0005435661926	6739	11	4A
0005435682076	6739	12	4C
0005435682082	6739	13	4D
0005434828670	6739	14	4E
0005435682108	6739	15	4F
0005435682075	6739	16	5A
0005435437752	6739	17	5C
0005435437788	6739	18	5D
0005435437776	6739	19	5E
0005435630962	6739	20	5F
0005435682092	6739	21	6A
0005435682103	6739	22	6C
0005435682067	6739	23	6D
0005432533262	6739	24	6E
0005435437785	6739	25	6F
0005435682070	6739	26	7A
0005432136163	6739	27	7C
0005435682072	6739	28	7D
0005432136162	6739	29	7E
0005435437707	6739	30	7F
0005435682085	6739	31	8A
0005435682098	6739	32	8C
0005435437681	6739	33	8D
0005435437715	6739	34	8E
0005435682087	6739	35	8F
0005435220304	6739	36	9A
0005435437812	6739	37	9C
0005435437705	6739	38	9D
0005435437804	6739	39	9E
0005435437678	6739	40	9F
0005435682088	6739	41	10A
0005435682086	6739	42	10C
0005435437751	6739	43	10D
0005435217688	6739	44	10F
0005435217687	6739	45	11A
0005435437763	6739	46	11C
0005435437792	6739	47	11D
0005435661924	6739	48	11E
0005435682106	6739	49	11F
0005435437615	6739	50	12A
0005435682066	6739	51	12C
0005435437614	6739	52	12D
0005435682104	6739	53	12E
0005435630960	6739	54	12F
0005435437746	6739	55	13A
0005432533259	6739	56	13C
0005435437679	6739	57	13D
0005435437737	6739	58	13E
0005435682089	6739	59	13F
0005435682081	6739	60	14A
0005435661925	6739	61	14C
0005435437704	6739	62	14D
0005435437760	6739	63	14E
0005435682099	6739	64	14F
0005435630961	6739	65	15A
0005435437775	6739	66	15C
0005435437766	6739	67	15D
0005435682100	6739	68	15E
0005432136166	6739	69	15F
0005432533261	6739	70	16A
0005435682079	6739	71	16C
0005435682096	6739	72	16D
0005435437846	6739	73	16E
0005432136164	6739	74	16F
0005435682107	6739	75	17C
0005435682090	6739	76	17A
0005435682095	6739	77	17D
0005435682065	6739	78	17E
0005435437847	6739	79	17F
0005432136161	6739	80	18A
0005435217686	6739	81	18C
0005435437680	6739	82	18D
0005435682077	6739	83	18E
0005435682105	6739	84	18F
0005435682084	6739	85	19A
0005435437784	6739	86	19C
0005432136160	6739	87	19D
0005435682073	6739	88	19E
0005432136165	6739	89	19F
0005435682102	6739	90	20A
0005435682091	6739	91	20C
0005435682074	6739	92	20D
0005435437774	6739	93	20E
0005435437789	6739	94	20F
0005435437932	24591	1	1A
0005435437916	24591	2	1C
0005435681612	24591	3	1D
0005432533288	24591	4	1F
0005435437934	24591	5	2A
0005435681571	24591	6	2C
0005435437926	24591	7	2D
0005435681700	24591	8	2F
0005435681692	24591	9	3C
0005435681705	24591	10	3F
0005435661910	24591	11	4A
0005435681691	24591	12	4C
0005435720808	24591	13	4D
0005435437915	24591	14	4E
0005435681709	24591	15	4F
0005435681632	24591	16	5A
0005435437936	24591	17	5C
0005435681516	24591	18	5D
0005435719554	24591	19	5F
0005435681735	24591	20	6A
0005435681884	24591	21	6C
0005435681650	24591	22	6E
0005432533290	24591	23	6F
0005435681694	24591	24	7A
0005432533287	24591	25	7C
0005434828695	24591	26	7D
0005434828694	24591	27	7E
0005435437924	24591	28	7F
0005435681739	24591	29	8A
0005435720815	24591	30	8E
0005435437933	24591	31	8F
0005435681683	24591	32	9A
0005435437928	24591	33	9C
0005435681729	24591	34	9D
0005435681823	24591	35	9E
0005435681695	24591	36	9F
0005435437931	24591	37	10A
0005435661911	24591	38	10C
0005435681847	24591	39	10D
0005435681828	24591	40	10E
0005435681704	24591	41	10F
0005435437925	24591	42	11A
0005435437927	24591	43	11C
0005435630941	24591	44	11E
0005435681557	24591	45	11F
0005435437930	24591	46	12A
0005435681798	24591	47	12C
0005435661912	24591	48	12D
0005435681728	24591	49	12E
0005435437935	24591	50	12F
0005435437937	24591	51	13A
0005435681699	24591	52	13C
0005435437919	24591	53	13D
0005435681661	24591	54	13E
0005435681572	24591	55	13F
0005432305746	24591	56	14A
0005432305745	24591	57	14C
0005435681589	24591	58	14D
0005435719553	24591	59	14F
0005435437922	24591	60	15A
0005435437920	24591	61	15C
0005435681660	24591	62	15E
0005435681830	24591	63	16A
0005435437918	24591	64	16C
0005435681682	24591	65	16E
0005435437917	24591	66	16F
0005435681542	24591	67	17C
0005435681867	24591	68	17D
0005435720816	24591	69	17E
0005435681727	24591	70	17F
0005435681846	24591	71	18A
0005435681844	24591	72	18E
0005435437921	24591	73	18F
0005435681698	24591	74	19A
0005432533289	24591	75	19C
0005435681903	24591	76	19D
0005435681797	24591	77	19E
0005435437929	24591	78	19F
0005435681754	24591	79	20A
0005435719555	24591	80	20C
0005435661905	24591	81	20D
0005435630926	24591	82	20E
0005435437923	24591	83	20F
0005435105976	11560	1	1A
0005435126301	11560	2	1C
0005435126277	11560	3	1D
0005435126298	11560	4	2A
0005435126284	11560	5	2C
0005435126278	11560	6	3A
0005435126292	11560	7	3C
0005435126285	11560	8	3D
0005435126302	11560	9	3F
0005435126304	11560	10	4A
0005435126307	11560	11	4E
0005435126274	11560	12	4F
0005435126280	11560	13	5A
0005435126311	11560	14	5E
0005435126296	11560	15	6A
0005435126289	11560	16	6D
0005435126308	11560	17	6F
0005435126294	11560	18	7A
0005435126297	11560	19	8A
0005435126276	11560	20	8D
0005435126300	11560	21	8F
0005435126272	11560	22	9A
0005435126306	11560	23	9F
0005435126290	11560	24	10C
0005435126275	11560	25	11A
0005435126293	11560	26	11C
0005435126303	11560	27	11D
0005435126299	11560	28	12D
0005435105975	11560	29	13C
0005435126281	11560	30	13D
0005435126273	11560	31	13F
0005435126286	11560	32	14C
0005435126288	11560	33	14F
0005435126305	11560	34	15F
0005435558060	11560	35	16A
0005435126291	11560	36	16E
0005435126287	11560	37	17C
0005435126313	11560	38	17D
0005435126295	11560	39	17F
0005435126282	11560	40	18C
0005435105977	11560	41	18E
0005435126310	11560	42	18F
0005435126309	11560	43	19A
0005435126312	11560	44	19F
0005435126283	11560	45	20C
0005435126279	11560	46	20F
0005435558083	31875	1	1D
0005435125748	31875	2	2A
0005435105961	31875	3	2F
0005435125932	31875	4	3F
0005435125928	31875	5	4D
0005435125802	31875	6	4F
0005435126124	31875	7	5A
0005435098532	31875	8	5C
0005435098533	31875	9	5D
0005435105958	31875	10	5E
0005435126080	31875	11	6C
0005435125803	31875	12	6D
0005435126031	31875	13	6E
0005435126092	31875	14	7C
0005435125849	31875	15	7E
0005435125821	31875	16	8A
0005435125986	31875	17	8D
0005435125980	31875	18	8E
0005435098535	31875	19	8F
0005435105965	31875	20	9C
0005435126051	31875	21	9D
0005435558084	31875	22	9E
0005435125749	31875	23	10C
0005435125943	31875	24	10E
0005435126123	31875	25	11A
0005435126045	31875	26	11C
0005435126111	31875	27	11D
0005435125860	31875	28	11F
0005435125950	31875	29	12A
0005435125899	31875	30	12C
0005435125850	31875	31	12D
0005435125931	31875	32	12E
0005435105948	31875	33	13A
0005435126120	31875	34	13C
0005435126022	31875	35	13D
0005435105967	31875	36	13E
0005435126103	31875	37	13F
0005435125907	31875	38	14C
0005435125963	31875	39	14D
0005435126134	31875	40	15A
0005435126038	31875	41	15D
0005435105960	31875	42	15E
0005435126052	31875	43	15F
0005435105957	31875	44	16A
0005435126091	31875	45	16C
0005435125994	31875	46	16D
0005435125985	31875	47	16E
0005435125917	31875	48	17A
0005435105959	31875	49	17E
0005435126081	31875	50	18C
0005435125967	31875	51	18D
0005435126156	31875	52	19A
0005435126043	31875	53	19C
0005435125747	31875	54	19D
0005435125870	31875	55	19E
0005435126032	31875	56	19F
0005435126016	31875	57	20C
0005435126017	31875	58	20D
0005435126044	31875	59	20E
0005435105966	31875	60	20F
0005433397985	13509	1	1C
0005433398017	13509	2	2D
0005433397995	13509	3	2F
0005435732265	13509	4	3A
0005433398013	13509	5	3D
0005435732266	13509	6	3F
0005435732225	13509	7	4A
0005433397986	13509	8	4D
0005433397978	13509	9	4F
0005433397988	13509	10	5A
0005435732241	13509	11	5D
0005433398014	13509	12	5E
0005433397989	13509	13	6A
0005433397991	13509	14	6E
0005433397983	13509	15	6F
0005433398021	13509	16	7A
0005433397997	13509	17	7E
0005433397990	13509	18	7F
0005433398001	13509	19	8D
0005433398009	13509	20	8E
0005433397979	13509	21	9A
0005433398020	13509	22	9C
0005433398002	13509	23	9D
0005433398007	13509	24	9E
0005433398015	13509	25	10C
0005433398010	13509	26	10D
0005433397981	13509	27	10E
0005433398003	13509	28	10F
0005435732186	13509	29	11A
0005433397975	13509	30	11C
0005433397992	13509	31	11D
0005435732232	13509	32	12A
0005433398011	13509	33	12C
0005433397977	13509	34	12D
0005435732242	13509	35	12E
0005433398018	13509	36	13C
0005433397982	13509	37	13F
0005435732228	13509	38	14A
0005433398022	13509	39	14C
0005433397994	13509	40	14D
0005433397980	13509	41	14E
0005433397984	13509	42	14F
0005433398008	13509	43	15A
0005433398016	13509	44	15D
0005433397998	13509	45	16A
0005433398012	13509	46	16D
0005433397976	13509	47	16F
0005433397987	13509	48	17A
0005433398019	13509	49	17C
0005433398023	13509	50	17F
0005433397993	13509	51	18A
0005435732200	13509	52	18C
0005433397999	13509	53	18D
0005433398004	13509	54	18E
0005433397996	13509	55	19D
0005435732206	13509	56	19E
0005433398006	13509	57	20A
0005433398005	13509	58	20E
0005433398000	13509	59	20F
0005433397437	19379	1	1A
0005433397617	19379	2	1D
0005433397589	19379	3	1F
0005433397511	19379	4	2C
0005433397557	19379	5	2D
0005433397677	19379	6	3A
0005433397738	19379	7	3C
0005432297274	19379	8	3D
0005432297275	19379	9	4A
0005433397852	19379	10	4C
0005433397247	19379	11	4D
0005433397429	19379	12	4E
0005433397510	19379	13	4F
0005433397664	19379	14	5A
0005433397698	19379	15	5C
0005433397619	19379	16	5F
0005433397575	19379	17	6D
0005433397665	19379	18	7C
0005433397433	19379	19	7E
0005433397473	19379	20	7F
0005433397640	19379	21	8D
0005433397839	19379	22	8F
0005433397574	19379	23	9A
0005433397624	19379	24	9E
0005433397603	19379	25	9F
0005433397503	19379	26	10A
0005433397661	19379	27	10C
0005433397689	19379	28	10D
0005433397717	19379	29	10F
0005433397629	19379	30	11A
0005433397614	19379	31	11C
0005433397576	19379	32	11D
0005433397755	19379	33	11E
0005433397436	19379	34	12A
0005433397432	19379	35	12E
0005433397555	19379	36	13D
0005433397403	19379	37	13F
0005433397595	19379	38	14A
0005433397620	19379	39	14C
0005433397806	19379	40	14D
0005433397453	19379	41	14E
0005433397585	19379	42	14F
0005433397613	19379	43	15A
0005433397542	19379	44	15C
0005433397571	19379	45	15D
0005433397591	19379	46	15F
0005433397623	19379	47	16C
0005433397434	19379	48	16D
0005433397739	19379	49	16F
0005433397631	19379	50	17A
0005433397477	19379	51	17C
0005433397526	19379	52	17D
0005433397592	19379	53	17F
0005433397641	19379	54	18A
0005433397666	19379	55	18C
0005433397630	19379	56	18D
0005433397604	19379	57	18F
0005433397718	19379	58	19C
0005433397722	19379	59	19F
0005433397435	19379	60	20A
0005433397554	19379	61	20C
0005433397491	19379	62	20D
0005433397558	19379	63	20F
0005435068668	13132	1	1A
0005435925284	13132	2	1C
0005435068546	13132	3	1D
0005435068611	13132	4	2A
0005435925283	13132	5	2C
0005435068386	13132	6	3A
0005435925294	13132	7	3C
0005435068445	13132	8	3F
0005435068543	13132	9	4A
0005435068444	13132	10	4D
0005435068442	13132	11	4E
0005435068346	13132	12	5A
0005435068552	13132	13	5C
0005435068714	13132	14	5D
0005435068615	13132	15	6A
0005435068713	13132	16	6D
0005435068564	13132	17	6F
0005435068390	13132	18	7A
0005435925281	13132	19	7C
0005435925278	13132	20	7D
0005435068387	13132	21	7E
0005435068449	13132	22	7F
0005435925279	13132	23	8A
0005435068634	13132	24	8C
0005435068391	13132	25	8D
0005435068559	13132	26	8E
0005435068560	13132	27	8F
0005435925280	13132	28	9A
0005435068600	13132	29	9C
0005435925286	13132	30	9D
0005435068633	13132	31	9E
0005435068389	13132	32	9F
0005435925291	13132	33	10A
0005435068549	13132	34	10D
0005435068786	13132	35	10E
0005435925289	13132	36	10F
0005435068639	13132	37	11A
0005435068561	13132	38	11C
0005435068529	13132	39	11D
0005435068544	13132	40	11E
0005435068477	13132	41	11F
0005435068711	13132	42	12A
0005435068418	13132	43	12C
0005435068397	13132	44	12D
0005435068493	13132	45	12F
0005435925290	13132	46	13C
0005435068494	13132	47	13D
0005435068627	13132	48	13E
0005435068550	13132	49	13F
0005435925293	13132	50	14A
0005435068504	13132	51	14C
0005435925292	13132	52	14D
0005435068321	13132	53	14E
0005435068505	13132	54	14F
0005435068745	13132	55	15A
0005435068601	13132	56	15C
0005435068640	13132	57	15D
0005435925285	13132	58	15E
0005435068530	13132	59	15F
0005435068562	13132	60	16A
0005435068509	13132	61	16C
0005435068744	13132	62	16D
0005435068565	13132	63	16E
0005435068563	13132	64	17A
0005435925282	13132	65	17C
0005435068462	13132	66	17D
0005435068630	13132	67	17E
0005435068582	13132	68	17F
0005435925287	13132	69	18A
0005435068508	13132	70	18C
0005435925288	13132	71	18E
0005435068490	13132	72	19C
0005435068551	13132	73	19D
0005435068463	13132	74	19F
0005435068305	13132	75	20A
0005435068703	13132	76	20D
0005435068535	13132	77	20F
0005435925140	15516	1	1A
0005435068970	15516	2	1C
0005435068961	15516	3	1D
0005435068955	15516	4	1F
0005435068957	15516	5	2A
0005435068988	15516	6	2C
0005435925139	15516	7	2D
0005435068971	15516	8	2F
0005435068976	15516	9	3D
0005435068997	15516	10	4A
0005435925121	15516	11	4C
0005435068959	15516	12	5A
0005435069003	15516	13	5C
0005435068962	15516	14	5D
0005435925145	15516	15	6A
0005435925152	15516	16	6D
0005435069004	15516	17	6F
0005435068996	15516	18	7A
0005435068969	15516	19	7C
0005435068954	15516	20	7D
0005435068977	15516	21	7E
0005435068980	15516	22	7F
0005435068993	15516	23	8A
0005435068965	15516	24	8C
0005435068992	15516	25	8E
0005435068960	15516	26	9C
0005435068983	15516	27	9F
0005435068991	15516	28	10A
0005435069001	15516	29	10C
0005435068982	15516	30	10E
0005435068975	15516	31	10F
0005435068999	15516	32	11A
0005435925129	15516	33	11E
0005435925143	15516	34	11F
0005435068986	15516	35	12A
0005435068989	15516	36	12C
0005435068987	15516	37	12E
0005435925124	15516	38	13C
0005435069000	15516	39	13E
0005435925100	15516	40	13F
0005435925141	15516	41	14A
0005435068978	15516	42	14C
0005435068985	15516	43	14E
0005435068979	15516	44	14F
0005435069006	15516	45	15A
0005435068973	15516	46	15C
0005435925123	15516	47	15D
0005435068967	15516	48	15E
0005435925125	15516	49	15F
0005435068964	15516	50	16A
0005435068974	15516	51	16C
0005435068984	15516	52	16D
0005435068972	15516	53	16F
0005435069002	15516	54	17A
0005435069005	15516	55	17D
0005435068968	15516	56	17E
0005435068963	15516	57	17F
0005435925144	15516	58	18C
0005435068995	15516	59	18E
0005435068956	15516	60	18F
0005435068981	15516	61	19A
0005435068994	15516	62	19C
0005435068998	15516	63	19D
0005435068953	15516	64	19E
0005435068966	15516	65	19F
0005435068958	15516	66	20C
0005435925136	15516	67	20D
0005435068990	15516	68	20E
0005435808083	29502	1	1A
0005435808121	29502	2	1C
0005433407557	29502	3	1D
0005433407563	29502	4	2A
0005433407561	29502	5	2D
0005435808092	29502	6	3A
0005433407560	29502	7	3C
0005433407556	29502	8	3D
0005433407564	29502	9	4A
0005435808084	29502	10	4C
0005435808148	29502	11	4D
0005435808163	29502	12	5B
0005435808127	29502	13	5C
0005435808096	29502	14	6B
0005435808082	29502	15	6C
0005433407558	29502	16	6D
0005435808145	29502	17	7A
0005435808077	29502	18	7C
0005435808076	29502	19	7D
0005433407559	29502	20	18A
0005435808147	29502	21	18C
0005435808120	29502	22	19A
0005435808104	29502	23	19D
0005433407562	29502	24	20C
0005435808146	29502	25	20D
0005435808091	29502	26	21B
0005435808116	29502	27	21D
0005435808094	29502	28	22A
0005433407555	29502	29	22B
0005435808093	29502	30	22D
0005434755895	10715	1	1A
0005434755934	10715	2	1C
0005434214459	10715	3	1D
0005434756032	10715	4	2C
0005434755923	10715	5	2D
0005434214498	10715	6	2F
0005434214467	10715	7	3A
0005434755896	10715	8	3C
0005434755933	10715	9	3D
0005434755971	10715	10	3F
0005434755978	10715	11	4A
0005434755900	10715	12	4C
0005434214486	10715	13	4D
0005434214502	10715	14	4E
0005434214501	10715	15	4F
0005434755882	10715	16	5A
0005434755894	10715	17	5C
0005434756075	10715	18	5D
0005434214461	10715	19	5E
0005434755979	10715	20	5F
0005434214466	10715	21	6A
0005434756076	10715	22	6C
0005434214474	10715	23	6D
0005434214484	10715	24	6E
0005434214476	10715	25	6F
0005434214499	10715	26	7A
0005434214496	10715	27	7C
0005434214468	10715	28	7D
0005434756064	10715	29	7E
0005434755889	10715	30	7F
0005434214494	10715	31	8A
0005434214472	10715	32	8D
0005434756000	10715	33	8E
0005434755781	10715	34	8F
0005434756059	10715	35	9A
0005434756065	10715	36	9C
0005434755992	10715	37	9D
0005434756040	10715	38	9E
0005434214479	10715	39	9F
0005434214487	10715	40	10A
0005434214507	10715	41	10C
0005434755814	10715	42	10D
0005434214500	10715	43	10E
0005434214506	10715	44	10F
0005434756008	10715	45	11A
0005434755786	10715	46	11C
0005434214470	10715	47	11D
0005434214478	10715	48	11E
0005434214480	10715	49	11F
0005434214481	10715	50	12A
0005434214483	10715	51	12C
0005434214462	10715	52	12D
0005434214491	10715	53	12E
0005434214490	10715	54	12F
0005434755969	10715	55	13A
0005434755833	10715	56	13C
0005434214504	10715	57	13E
0005434214471	10715	58	13F
0005434214492	10715	59	14A
0005434214475	10715	60	14C
0005434214477	10715	61	14D
0005434756072	10715	62	14E
0005434214473	10715	63	14F
0005434755970	10715	64	15A
0005434756013	10715	65	15C
0005434214503	10715	66	15D
0005434755972	10715	67	15E
0005434755813	10715	68	15F
0005434214505	10715	69	16A
0005434755834	10715	70	16C
0005434214493	10715	71	16D
0005434214497	10715	72	16E
0005434756061	10715	73	16F
0005434214463	10715	74	17C
0005434214469	10715	75	17D
0005434214485	10715	76	17E
0005434214464	10715	77	17F
0005434755924	10715	78	18A
0005434214482	10715	79	18C
0005434755983	10715	80	18D
0005434214489	10715	81	18E
0005434755932	10715	82	18F
0005434214465	10715	83	19A
0005434214460	10715	84	19C
0005434755893	10715	85	19D
0005434755888	10715	86	19E
0005434214495	10715	87	19F
0005434755836	10715	88	20A
0005434214488	10715	89	20C
0005434756031	10715	90	20D
0005434756060	10715	91	20F
0005434756345	28661	1	1A
0005434756331	28661	2	1C
0005434214103	28661	3	1D
0005434214159	28661	4	1F
0005434756349	28661	5	2A
0005434213903	28661	6	2C
0005434213972	28661	7	2D
0005434213799	28661	8	2F
0005434214000	28661	9	3A
0005434214076	28661	10	3C
0005434756356	28661	11	3D
0005434214010	28661	12	3F
0005434214114	28661	13	4A
0005434756343	28661	14	4C
0005434214160	28661	15	4D
0005434213800	28661	16	4E
0005434756339	28661	17	4F
0005434214115	28661	18	5A
0005434756361	28661	19	5C
0005434214105	28661	20	5D
0005434214101	28661	21	5E
0005434214044	28661	22	5F
0005434214218	28661	23	6C
0005434214040	28661	24	6D
0005434214152	28661	25	6E
0005434214085	28661	26	7A
0005434756344	28661	27	7C
0005434214018	28661	28	7E
0005434214009	28661	29	7F
0005434756360	28661	30	8A
0005434756336	28661	31	8C
0005434214213	28661	32	8D
0005434214033	28661	33	8E
0005434756341	28661	34	8F
0005434756340	28661	35	9A
0005434214225	28661	36	9D
0005434214186	28661	37	9E
0005434213855	28661	38	9F
0005434213923	28661	39	10A
0005434756342	28661	40	10C
0005434756358	28661	41	10E
0005434756352	28661	42	10D
0005434756348	28661	43	10F
0005434214124	28661	44	11A
0005434756354	28661	45	11C
0005434756337	28661	46	11D
0005434756334	28661	47	11E
0005434214175	28661	48	11F
0005434213883	28661	49	12A
0005434213936	28661	50	12C
0005434756355	28661	51	12D
0005434756357	28661	52	12E
0005434213809	28661	53	12F
0005434756350	28661	54	13A
0005434214219	28661	55	13C
0005434214184	28661	56	13D
0005434213978	28661	57	13E
0005434214017	28661	58	14A
0005434756346	28661	59	14C
0005434756338	28661	60	14E
0005434213927	28661	61	14F
0005434756353	28661	62	15A
0005434214102	28661	63	15C
0005434756351	28661	64	15D
0005434214020	28661	65	15E
0005434756333	28661	66	15F
0005434213998	28661	67	16A
0005434756332	28661	68	16C
0005434213832	28661	69	16D
0005434214185	28661	70	16E
0005434214075	28661	71	16F
0005434756359	28661	72	17C
0005434214007	28661	73	17D
0005434214034	28661	74	17E
0005434214037	28661	75	17F
0005434213884	28661	76	18A
0005434213949	28661	77	18D
0005434756329	28661	78	18E
0005434214042	28661	79	18F
0005434214045	28661	80	19A
0005434756330	28661	81	19C
0005434213819	28661	82	19D
0005434214074	28661	83	19E
0005434214035	28661	84	19F
0005434214008	28661	85	20A
0005434756335	28661	86	20C
0005434756347	28661	87	20D
0005434214043	28661	88	20E
0005434213977	28661	89	20F
0005434229136	5470	1	1A
0005435039718	5470	2	1C
0005435039699	5470	3	1D
0005435007019	5470	4	1F
0005435039678	5470	5	2C
0005434229235	5470	6	2A
0005435039727	5470	7	2D
0005435039669	5470	8	2F
0005435039723	5470	9	3C
0005434229041	5470	10	3A
0005434229062	5470	11	3F
0005435039683	5470	12	3D
0005432125444	5470	13	4A
0005434229170	5470	14	4B
0005435042857	5470	15	4D
0005432125439	5470	16	4C
0005435039709	5470	17	4E
0005435007014	5470	18	5A
0005435039716	5470	19	4F
0005435039674	5470	20	5B
0005435039721	5470	21	5C
0005435039708	5470	22	5D
0005434229191	5470	23	5E
0005435039710	5470	24	5F
0005434229162	5470	25	6B
0005435007005	5470	26	6A
0005435039733	5470	27	6C
0005435039685	5470	28	6D
0005434229149	5470	29	6F
0005435039714	5470	30	6E
0005435039735	5470	31	7B
0005435007013	5470	32	7A
0005435039691	5470	33	7C
0005434229042	5470	34	7D
0005434229172	5470	35	7F
0005432125443	5470	36	7E
0005435039715	5470	37	8A
0005435007006	5470	38	8B
0005435007008	5470	39	8C
0005435039704	5470	40	8E
0005435007007	5470	41	8D
0005432125445	5470	42	8F
0005435039697	5470	43	9B
0005435039698	5470	44	9A
0005435007000	5470	45	9D
0005435039696	5470	46	9C
0005435039732	5470	47	9E
0005434229130	5470	48	9F
0005435039720	5470	49	10B
0005435007012	5470	50	10C
0005435039689	5470	51	10E
0005435006999	5470	52	10D
0005435039712	5470	53	11A
0005435039706	5470	54	11B
0005435039688	5470	55	11D
0005435039679	5470	56	11E
0005435042856	5470	57	12B
0005435007004	5470	58	12A
0005435039690	5470	59	12C
0005435007003	5470	60	12E
0005435039681	5470	61	12D
0005435039731	5470	62	13A
0005435039694	5470	63	12F
0005435006995	5470	64	13C
0005435039703	5470	65	13B
0005434229208	5470	66	13D
0005435007015	5470	67	13E
0005435039670	5470	68	13F
0005434229155	5470	69	14A
0005434229260	5470	70	14C
0005435039717	5470	71	14B
0005434229148	5470	72	14D
0005434229173	5470	73	14E
0005435039713	5470	74	14F
0005435039707	5470	75	15B
0005435007016	5470	76	15A
0005435039705	5470	77	15C
0005435039676	5470	78	15D
0005435039682	5470	79	15E
0005435039728	5470	80	15F
0005435039734	5470	81	16B
0005435039671	5470	82	16A
0005435039673	5470	83	16C
0005435039702	5470	84	16D
0005434229108	5470	85	16E
0005435007001	5470	86	17A
0005435039725	5470	87	16F
0005435039724	5470	88	17B
0005435039675	5470	89	17C
0005435039695	5470	90	17E
0005435039722	5470	91	17D
0005435007011	5470	92	17F
0005434229156	5470	93	18A
0005435039680	5470	94	18B
0005435006997	5470	95	18C
0005434229186	5470	96	18D
0005432125447	5470	97	18F
0005432125446	5470	98	18E
0005432125441	5470	99	19A
0005435039684	5470	100	19C
0005435039686	5470	101	19B
0005434229259	5470	102	19D
0005435039672	5470	103	19E
0005435007002	5470	104	19F
0005435039693	5470	105	20A
0005435039730	5470	106	20C
0005435039700	5470	107	20B
0005435039711	5470	108	20D
0005434229121	5470	109	20E
0005434229157	5470	110	20F
0005435039677	5470	111	21A
0005434229203	5470	112	21C
0005435007017	5470	113	21B
0005432125442	5470	114	21D
0005435039719	5470	115	21F
0005435006998	5470	116	21E
0005435039687	5470	117	22A
0005435007009	5470	118	22C
0005435039701	5470	119	22B
0005432125440	5470	120	22D
0005434229159	5470	121	22F
0005435039729	5470	122	22E
0005435039726	5470	123	23A
0005435007020	5470	124	23C
0005435006996	5470	125	23B
0005435007010	5470	126	23D
0005435007018	5470	127	23F
0005435039692	5470	128	23E
0005435006937	12977	1	1C
0005435006934	12977	2	1A
0005435038837	12977	3	1F
0005435006938	12977	4	1D
0005435006710	12977	5	2A
0005435006742	12977	6	2D
0005435039370	12977	7	2F
0005434229340	12977	8	3C
0005435006812	12977	9	3A
0005435039135	12977	10	3D
0005435006747	12977	11	3F
0005435006838	12977	12	4A
0005435039036	12977	13	4B
0005435006869	12977	14	4C
0005435006772	12977	15	4E
0005435006717	12977	16	4D
0005435006782	12977	17	5A
0005435038993	12977	18	4F
0005435038991	12977	19	5C
0005435039069	12977	20	5B
0005435006945	12977	21	5D
0005435039089	12977	22	5E
0005434229358	12977	23	5F
0005435039085	12977	24	6B
0005435039371	12977	25	6A
0005435038980	12977	26	6C
0005435039243	12977	27	6D
0005434229338	12977	28	6E
0005434229342	12977	29	7A
0005435039206	12977	30	6F
0005435006853	12977	31	7B
0005435006904	12977	32	7C
0005435039262	12977	33	7D
0005434229348	12977	34	7F
0005435006779	12977	35	7E
0005435039361	12977	36	8A
0005435038911	12977	37	8B
0005435039017	12977	38	8D
0005435006879	12977	39	8C
0005432304395	12977	40	8F
0005435039136	12977	41	8E
0005435038789	12977	42	9A
0005435039086	12977	43	9C
0005435006773	12977	44	9B
0005432304393	12977	45	9D
0005435039180	12977	46	9F
0005435038785	12977	47	9E
0005435039286	12977	48	10B
0005435039362	12977	49	10C
0005434229339	12977	50	10D
0005435039138	12977	51	10E
0005435039087	12977	52	11B
0005435039149	12977	53	11A
0005434229352	12977	54	11C
0005435039186	12977	55	11E
0005435006780	12977	56	11D
0005434229354	12977	57	11F
0005435038860	12977	58	12A
0005435039372	12977	59	12B
0005435039265	12977	60	12D
0005435039216	12977	61	12C
0005435039137	12977	62	12E
0005435039025	12977	63	13A
0005435038807	12977	64	12F
0005435006708	12977	65	13C
0005435039274	12977	66	13B
0005435039261	12977	67	13D
0005435006805	12977	68	13E
0005435038821	12977	69	14A
0005435039082	12977	70	13F
0005435039060	12977	71	14B
0005435039293	12977	72	14C
0005435039016	12977	73	14D
0005435039316	12977	74	14E
0005435006748	12977	75	15A
0005435038851	12977	76	14F
0005435038779	12977	77	15C
0005435006811	12977	78	15B
0005435039203	12977	79	15D
0005434229347	12977	80	15E
0005435039144	12977	81	16A
0005435006820	12977	82	15F
0005434229351	12977	83	16B
0005435039325	12977	84	16C
0005435039088	12977	85	16D
0005435039294	12977	86	16E
0005434229355	12977	87	17A
0005435038786	12977	88	16F
0005435039143	12977	89	17B
0005435006797	12977	90	17D
0005434229345	12977	91	17C
0005435039020	12977	92	17F
0005435039034	12977	93	17E
0005432304392	12977	94	18A
0005435039035	12977	95	18B
0005434229357	12977	96	18C
0005435039242	12977	97	18D
0005434229356	12977	98	18F
0005435006746	12977	99	18E
0005435006870	12977	100	19A
0005435039140	12977	101	19B
0005435039139	12977	102	19D
0005435039260	12977	103	19C
0005435006801	12977	104	19E
0005435039215	12977	105	19F
0005435006804	12977	106	20A
0005435038981	12977	107	20B
0005434229349	12977	108	20D
0005435039123	12977	109	20C
0005435006839	12977	110	20E
0005432304394	12977	111	21A
0005435006766	12977	112	20F
0005435039151	12977	113	21B
0005435006819	12977	114	21D
0005435006903	12977	115	21C
0005434229343	12977	116	21E
0005435039315	12977	117	21F
0005434229344	12977	118	22B
0005434229353	12977	119	22A
0005434229341	12977	120	22C
0005435038966	12977	121	22D
0005435039268	12977	122	22F
0005435039187	12977	123	22E
0005434229337	12977	124	23B
0005435039179	12977	125	23A
0005434229350	12977	126	23D
0005434229346	12977	127	23C
0005435038939	12977	128	23E
0005435039267	12977	129	23F
0005435554143	14883	1	1D
0005434426542	14883	2	1F
0005434411771	14883	3	2A
0005434426547	14883	4	2C
0005434426561	14883	5	2D
0005435902474	14883	6	3A
0005435902558	14883	7	3C
0005435554128	14883	8	3D
0005435902564	14883	9	3F
0005435554141	14883	10	4C
0005435554142	14883	11	4D
0005434426556	14883	12	4E
0005435902507	14883	13	4F
0005435902499	14883	14	5A
0005435554127	14883	15	5D
0005435554132	14883	16	5E
0005434426557	14883	17	5F
0005435554138	14883	18	6A
0005434426559	14883	19	6D
0005434426555	14883	20	7A
0005434426540	14883	21	7C
0005435902568	14883	22	7D
0005434426566	14883	23	7E
0005435902426	14883	24	7F
0005434426550	14883	25	8E
0005435902619	14883	26	10A
0005434426551	14883	27	10C
0005434426553	14883	28	10E
0005434426541	14883	29	10F
0005434426563	14883	30	11A
0005434426544	14883	31	11C
0005435902471	14883	32	11E
0005434411770	14883	33	11F
0005434426545	14883	34	12C
0005432188602	14883	35	12F
0005434426554	14883	36	13C
0005434411768	14883	37	13D
0005435902502	14883	38	14A
0005434426539	14883	39	14C
0005434426543	14883	40	14E
0005434426549	14883	41	14F
0005434426558	14883	42	15A
0005434426546	14883	43	15D
0005435902588	14883	44	16A
0005434426565	14883	45	16D
0005434426560	14883	46	17A
0005432188601	14883	47	17C
0005434426538	14883	48	17E
0005435902557	14883	49	17F
0005434411769	14883	50	18D
0005434426548	14883	51	18E
0005435902505	14883	52	18F
0005434426562	14883	53	19C
0005432188600	14883	54	20A
0005434426552	14883	55	19F
0005435902495	14883	56	20D
0005434426564	14883	57	20F
0005435554187	20212	1	1A
0005434426162	20212	2	1F
0005435902693	20212	3	2A
0005435902680	20212	4	2F
0005435902687	20212	5	3A
0005434411731	20212	6	3C
0005434426383	20212	7	3D
0005435902686	20212	8	4A
0005435554185	20212	9	4C
0005434426327	20212	10	4D
0005434426300	20212	11	4E
0005435902685	20212	12	4F
0005435902676	20212	13	5C
0005434426466	20212	14	5D
0005434426338	20212	15	5E
0005435902691	20212	16	5F
0005434426290	20212	17	6A
0005434426393	20212	18	6C
0005434411734	20212	19	6D
0005434426410	20212	20	6F
0005434426236	20212	21	7A
0005435902683	20212	22	7C
0005434426284	20212	23	7D
0005434426386	20212	24	7E
0005434426321	20212	25	8F
0005434426326	20212	26	9A
0005432059503	20212	27	9C
0005434426230	20212	28	9D
0005434426387	20212	29	9E
0005434426344	20212	30	10A
0005434426394	20212	31	10C
0005435554186	20212	32	10D
0005434426367	20212	33	10E
0005435554184	20212	34	10F
0005435902684	20212	35	11A
0005432059501	20212	36	11C
0005435902689	20212	37	11D
0005435902692	20212	38	11E
0005434426419	20212	39	11F
0005435902679	20212	40	12A
0005432059502	20212	41	12D
0005434411740	20212	42	12E
0005435902688	20212	43	12F
0005434426406	20212	44	13A
0005434426281	20212	45	13C
0005434426347	20212	46	13D
0005434426346	20212	47	13E
0005435902681	20212	48	13F
0005434426381	20212	49	14A
0005434426205	20212	50	14C
0005434411746	20212	51	14D
0005435554182	20212	52	14E
0005435902682	20212	53	15A
0005434426283	20212	54	15C
0005434426420	20212	55	15D
0005434426427	20212	56	15F
0005434426311	20212	57	16C
0005434426307	20212	58	16D
0005434426270	20212	59	16E
0005434426365	20212	60	16F
0005435902690	20212	61	17A
0005435554183	20212	62	17C
0005434426228	20212	63	17D
0005434411743	20212	64	17E
0005435902675	20212	65	17F
0005434426418	20212	66	18A
0005434426411	20212	67	18C
0005434426310	20212	68	18D
0005434426206	20212	69	18E
0005434426282	20212	70	18F
0005434426308	20212	71	19A
0005434411739	20212	72	19C
0005434426368	20212	73	19E
0005434426207	20212	74	20C
0005435902677	20212	75	20D
0005434426380	20212	76	20E
0005435902678	20212	77	20F
0005432462507	28020	1	4C
0005434523741	28020	2	5B
0005432462513	28020	3	6B
0005432462511	28020	4	8A
0005434523738	28020	5	8D
0005432462509	28020	6	11E
0005432462510	28020	7	15B
0005432462512	28020	8	15C
0005434523734	28020	9	16F
0005434523745	28020	10	17B
0005434523746	28020	11	20C
0005432462508	28020	12	20B
0005435982240	26556	1	1A
0005435982202	26556	2	1C
0005433434456	26556	3	1D
0005433434472	26556	4	1F
0005435982201	26556	5	2A
0005435982206	26556	6	2C
0005433434307	26556	7	2D
0005435982238	26556	8	3A
0005435982232	26556	9	3C
0005433434271	26556	10	3D
0005435982199	26556	11	3F
0005432300250	26556	12	4A
0005433434415	26556	13	4D
0005433434306	26556	14	4E
0005433434385	26556	15	4F
0005433434358	26556	16	5A
0005435982220	26556	17	5C
0005433434473	26556	18	5F
0005434273062	26556	19	6A
0005435982213	26556	20	6C
0005433434351	26556	21	6D
0005432300253	26556	22	6E
0005433434435	26556	23	6F
0005433434390	26556	24	7C
0005435982235	26556	25	7D
0005435982231	26556	26	7E
0005433434437	26556	27	7F
0005435982236	26556	28	8A
0005435982229	26556	29	8C
0005433434374	26556	30	8E
0005435982198	26556	31	9C
0005435982214	26556	32	9D
0005432300252	26556	33	9E
0005433434305	26556	34	9F
0005435982205	26556	35	10C
0005433434488	26556	36	10D
0005433434416	26556	37	10E
0005435982219	26556	38	10F
0005435982217	26556	39	11A
0005433434489	26556	40	11C
0005432300254	26556	41	11D
0005435982226	26556	42	11E
0005433434469	26556	43	11F
0005435982216	26556	44	12C
0005435982215	26556	45	12F
0005435982228	26556	46	13A
0005435982218	26556	47	13C
0005435982237	26556	48	13D
0005435982239	26556	49	13E
0005433434384	26556	50	13F
0005433434393	26556	51	14A
0005435982196	26556	52	14D
0005435982203	26556	53	14E
0005432300251	26556	54	14F
0005433434484	26556	55	15C
0005435982225	26556	56	15E
0005435982234	26556	57	15F
0005435982210	26556	58	16A
0005435982212	26556	59	16C
0005435982200	26556	60	16F
0005435982197	26556	61	17C
0005433434457	26556	62	17D
0005435982211	26556	63	17E
0005435982227	26556	64	17F
0005435982230	26556	65	18A
0005435982223	26556	66	18C
0005435982222	26556	67	18E
0005435982233	26556	68	18F
0005433434398	26556	69	19A
0005435982208	26556	70	19D
0005435982221	26556	71	19E
0005435982209	26556	72	19F
0005433434438	26556	73	20C
0005435982204	26556	74	20A
0005435982224	26556	75	20D
0005435982207	26556	76	20E
0005433434359	26556	77	20F
0005435981833	26706	1	1A
0005435981731	26706	2	1C
0005433434658	26706	3	1D
0005433434662	26706	4	1F
0005433434652	26706	5	2A
0005435981687	26706	6	2C
0005435981781	26706	7	2F
0005435981826	26706	8	3A
0005435981679	26706	9	3C
0005433434644	26706	10	3D
0005435981551	26706	11	4C
0005435981688	26706	12	4A
0005433434668	26706	13	4D
0005435981650	26706	14	4E
0005433434646	26706	15	4F
0005435981543	26706	16	5A
0005435981875	26706	17	5C
0005433434653	26706	18	5E
0005433434650	26706	19	5F
0005435981913	26706	20	6A
0005433434660	26706	21	6C
0005432051125	26706	22	6D
0005432051124	26706	23	6E
0005435981946	26706	24	6F
0005435981668	26706	25	7A
0005435981944	26706	26	7C
0005435981799	26706	27	7D
0005435981659	26706	28	7E
0005435981686	26706	29	7F
0005433434656	26706	30	8A
0005435981685	26706	31	8C
0005433434647	26706	32	8F
0005435981914	26706	33	9A
0005433434661	26706	34	9C
0005435981667	26706	35	9D
0005435981874	26706	36	9E
0005433434659	26706	37	9F
0005435981732	26706	38	10A
0005433434648	26706	39	10C
0005433434641	26706	40	10E
0005433434642	26706	41	10F
0005433434643	26706	42	11A
0005435981761	26706	43	11C
0005435981710	26706	44	11D
0005435981869	26706	45	11E
0005433434665	26706	46	11F
0005435981760	26706	47	12A
0005434270204	26706	48	12C
0005435981832	26706	49	12D
0005434269101	26706	50	12E
0005435981986	26706	51	12F
0005435981945	26706	52	13A
0005435981985	26706	53	13C
0005432051126	26706	54	13D
0005433434655	26706	55	13E
0005435981876	26706	56	13F
0005433434640	26706	57	14A
0005433434657	26706	58	14D
0005435981771	26706	59	14E
0005435981733	26706	60	14F
0005435981980	26706	61	15A
0005434271310	26706	62	15C
0005435981896	26706	63	15E
0005435981717	26706	64	15D
0005435981868	26706	65	16A
0005435981693	26706	66	16C
0005433434649	26706	67	16D
0005435981797	26706	68	16E
0005435981730	26706	69	16F
0005435981544	26706	70	17A
0005433434666	26706	71	17D
0005433434645	26706	72	17E
0005433434663	26706	73	17F
0005434271309	26706	74	18A
0005434269100	26706	75	18C
0005435981831	26706	76	18D
0005433434664	26706	77	18E
0005433434651	26706	78	19A
0005434270205	26706	79	19C
0005433434654	26706	80	19E
0005435981994	26706	81	19F
0005435981694	26706	82	20D
0005433434667	26706	83	20E
0005433686604	29262	1	1C
0005433686605	29262	2	2C
0005433689889	29262	3	7B
0005433689885	29262	4	18B
0005433689886	29262	5	18D
0005433686606	29262	6	19B
0005433686602	29262	7	22A
0005433686607	29262	8	22B
0005432584013	3176	1	1A
0005432857878	3176	2	1B
0005432857914	3176	3	1C
0005432857965	3176	4	1D
0005432584005	3176	5	2A
0005432857956	3176	6	2B
0005432584016	3176	7	2C
0005432584006	3176	8	2D
0005432857961	3176	9	3A
0005432857877	3176	10	3B
0005432216270	3176	11	3C
0005432584002	3176	12	3D
0005432583996	3176	13	4C
0005432584012	3176	14	5A
0005432584000	3176	15	4D
0005432857981	3176	16	5C
0005432583998	3176	17	5B
0005432216269	3176	18	6A
0005432584003	3176	19	6B
0005432584019	3176	20	6D
0005432857963	3176	21	6C
0005432584015	3176	22	7A
0005432584014	3176	23	7B
0005432583997	3176	24	7C
0005432584009	3176	25	7D
0005432584007	3176	26	18A
0005432584008	3176	27	18C
0005432584011	3176	28	18D
0005432216268	3176	29	19A
0005432584010	3176	30	19C
0005432857991	3176	31	19D
0005432584018	3176	32	20A
0005432857962	3176	33	20B
0005432857955	3176	34	20C
0005432857974	3176	35	20D
0005432583999	3176	36	21A
0005432584004	3176	37	21B
0005432584017	3176	38	21C
0005432857964	3176	39	21D
0005432583995	3176	40	22A
0005432584020	3176	41	22B
0005432584001	3176	42	23A
0005432583850	31499	1	1A
0005432583787	31499	2	1B
0005432858048	31499	3	1C
0005432583864	31499	4	1D
0005432858058	31499	5	2B
0005432583776	31499	6	2C
0005432583785	31499	7	3A
0005432583839	31499	8	3B
0005432583775	31499	9	4B
0005432583878	31499	10	4C
0005432583777	31499	11	5A
0005432583789	31499	12	5B
0005432583838	31499	13	5C
0005432858050	31499	14	5D
0005432583823	31499	15	6A
0005432858057	31499	16	6B
0005432583863	31499	17	7A
0005432583792	31499	18	7C
0005432583797	31499	19	7D
0005432583791	31499	20	18A
0005432583786	31499	21	18C
0005432583750	31499	22	18D
0005432858051	31499	23	19A
0005432583751	31499	24	19B
0005432583822	31499	25	19C
0005432583873	31499	26	19D
0005432858054	31499	27	20A
0005432858049	31499	28	20B
0005432583795	31499	29	20C
0005432583849	31499	30	20D
0005432858053	31499	31	21A
0005432858059	31499	32	21B
0005432858055	31499	33	21C
0005432858052	31499	34	21D
0005432858056	31499	35	22A
0005432583768	31499	36	22B
0005432583790	31499	37	22C
0005432583796	31499	38	22D
0005432858060	31499	39	23A
0005434943340	878	1	1A
0005433255057	878	2	1B
0005433255088	878	3	2D
0005434943345	878	4	3C
0005434943344	878	5	4C
0005434943343	878	6	6B
0005434943338	878	7	6C
0005434943342	878	8	7B
0005434943341	878	9	18B
0005434943337	878	10	18C
0005434943339	878	11	20B
0005434943287	16232	1	2C
0005434943300	16232	2	3B
0005434943267	16232	3	3C
0005433255112	16232	4	3D
0005433255114	16232	5	4B
0005434943313	16232	6	4C
0005434943266	16232	7	5B
0005434943270	16232	8	5C
0005434943284	16232	9	5D
0005434943301	16232	10	6A
0005433255111	16232	11	6B
0005434943315	16232	12	7D
0005433255115	16232	13	18A
0005434943280	16232	14	18D
0005434943314	16232	15	19D
0005434943286	16232	16	20B
0005433255113	16232	17	20C
0005433255110	16232	18	20D
0005434943217	16232	19	21D
0005434943285	16232	20	22D
0005434943265	16232	21	23A
0005435652975	21759	1	1A
0005433367655	21759	2	1C
0005433367453	21759	3	1D
0005433367507	21759	4	1F
0005433367414	21759	5	2A
0005433367531	21759	6	2C
0005433367457	21759	7	2D
0005435652972	21759	8	2F
0005435652968	21759	9	3A
0005435652965	21759	10	3C
0005435652960	21759	11	3D
0005433367575	21759	12	3F
0005435652970	21759	13	4A
0005435652982	21759	14	4C
0005433367512	21759	15	4D
0005435652963	21759	16	4E
0005433367530	21759	17	4F
0005433367425	21759	18	5A
0005435652969	21759	19	5C
0005433367527	21759	20	5D
0005435652979	21759	21	5E
0005433367525	21759	22	5F
0005435652983	21759	23	6A
0005433367437	21759	24	6C
0005433367380	21759	25	6D
0005435652976	21759	26	6E
0005435652988	21759	27	6F
0005433367275	21759	28	7A
0005433367374	21759	29	7C
0005433367523	21759	30	7D
0005435652974	21759	31	7E
0005433367394	21759	32	7F
0005435652964	21759	33	8A
0005435652973	21759	34	8C
0005433367441	21759	35	8D
0005435652985	21759	36	8E
0005435652961	21759	37	8F
0005433367470	21759	38	9A
0005433367541	21759	39	9D
0005433367461	21759	40	9F
0005433367421	21759	41	10A
0005433367413	21759	42	10C
0005433367454	21759	43	10D
0005433367485	21759	44	10E
0005433367436	21759	45	11A
0005435652987	21759	46	11C
0005433367584	21759	47	11D
0005435652978	21759	48	11F
0005433367570	21759	49	12C
0005435652957	21759	50	12D
0005433367464	21759	51	12E
0005433367443	21759	52	13A
0005433367404	21759	53	13C
0005435652971	21759	54	13D
0005435652981	21759	55	13E
0005433367462	21759	56	13F
0005435652977	21759	57	14A
0005433367373	21759	58	14C
0005433367653	21759	59	14E
0005435652956	21759	60	14D
0005433367510	21759	61	14F
0005433367519	21759	62	15A
0005433367308	21759	63	15C
0005433367307	21759	64	15D
0005435652955	21759	65	15E
0005435652980	21759	66	15F
0005435652984	21759	67	16A
0005435652958	21759	68	16C
0005433367636	21759	69	16D
0005435652967	21759	70	16E
0005433367484	21759	71	16F
0005433367616	21759	72	17A
0005435652962	21759	73	17C
0005435652990	21759	74	17D
0005435652986	21759	75	17E
0005433367415	21759	76	17F
0005433367342	21759	77	18A
0005433367590	21759	78	18C
0005435652989	21759	79	18D
0005433367511	21759	80	18E
0005433367442	21759	81	19A
0005433367463	21759	82	19C
0005433367460	21759	83	19D
0005433367445	21759	84	19E
0005433367426	21759	85	19F
0005435652959	21759	86	20A
0005435652991	21759	87	20C
0005435652966	21759	88	20D
0005433367654	21759	89	20F
0005433805353	9341	1	1A
0005433805336	9341	2	1C
0005433805340	9341	3	1F
0005433784892	9341	4	1H
0005433784917	9341	5	1G
0005433784913	9341	6	2H
0005433784897	9341	7	3B
0005433763198	9341	8	3A
0005433805350	9341	9	3F
0005433784894	9341	10	3C
0005434170896	9341	11	4A
0005433763195	9341	12	4G
0005433784891	9341	13	5A
0005433763197	9341	14	5B
0005433784904	9341	15	5G
0005434170918	9341	16	5H
0005433805341	9341	17	9A
0005433784896	9341	18	9H
0005432657445	9341	19	11A
0005433784916	9341	20	11E
0005433805348	9341	21	11F
0005433784902	9341	22	12A
0005433784893	9341	23	12F
0005433805342	9341	24	12H
0005434170926	9341	25	12G
0005433784905	9341	26	13A
0005433805346	9341	27	13D
0005433784923	9341	28	13E
0005433805343	9341	29	14D
0005432665272	9341	30	15A
0005433784910	9341	31	15B
0005433805339	9341	32	15E
0005432666387	9341	33	15D
0005433784915	9341	34	15H
0005433784900	9341	35	16B
0005433763196	9341	36	16E
0005433805355	9341	37	16D
0005434151677	9341	38	16H
0005433805331	9341	39	16G
0005435269659	9341	40	17A
0005433763192	9341	41	17D
0005433805335	9341	42	17E
0005434170936	9341	43	17H
0005432666386	9341	44	18B
0005433784888	9341	45	18A
0005433784890	9341	46	18D
0005432657446	9341	47	18G
0005433805344	9341	48	19D
0005433784901	9341	49	19E
0005434270188	9341	50	19G
0005435269660	9341	51	20D
0005433784920	9341	52	20F
0005433763185	9341	53	21A
0005434151681	9341	54	20H
0005433784914	9341	55	21D
0005433805330	9341	56	21F
0005433784921	9341	57	21E
0005433784911	9341	58	21G
0005433784909	9341	59	22A
0005434170897	9341	60	22D
0005433784906	9341	61	22B
0005433784903	9341	62	22E
0005435269665	9341	63	23A
0005433784918	9341	64	22H
0005433805356	9341	65	23D
0005433763188	9341	66	23E
0005433805349	9341	67	23G
0005435269650	9341	68	23H
0005433784889	9341	69	24B
0005435269651	9341	70	24F
0005432667451	9341	71	24G
0005433805328	9341	72	27A
0005433763194	9341	73	27B
0005433805334	9341	74	27E
0005433784895	9341	75	27D
0005434170888	9341	76	28D
0005433784908	9341	77	28B
0005433784919	9341	78	28E
0005433763189	9341	79	28F
0005434170921	9341	80	29A
0005433805352	9341	81	28H
0005433763186	9341	82	29B
0005433763182	9341	83	29F
0005433805345	9341	84	30A
0005435269666	9341	85	30B
0005432666385	9341	86	30F
0005433763191	9341	87	30E
0005433763183	9341	88	30H
0005434270187	9341	89	31B
0005433763193	9341	90	31E
0005433805337	9341	91	32A
0005433805347	9341	92	32B
0005434170949	9341	93	32E
0005433805329	9341	94	32G
0005434170866	9341	95	32F
0005433805332	9341	96	33E
0005434151680	9341	97	34D
0005432667452	9341	98	34E
0005433784912	9341	99	34G
0005434170937	9341	100	34F
0005433805351	9341	101	35A
0005433763190	9341	102	35G
0005433784922	9341	103	36B
0005433784907	9341	104	36E
0005434151682	9341	105	36D
0005433763187	9341	106	36F
0005435269671	9341	107	36H
0005433763184	9341	108	37A
0005433784887	9341	109	37F
0005433784898	9341	110	37H
0005433784899	9341	111	38B
0005433805338	9341	112	38A
0005434170947	9341	113	38G
0005433805354	9341	114	38F
0005434170865	9341	115	38H
0005434151676	9341	116	39D
0005433805333	9341	117	39F
0005432657413	26226	1	1A
0005433763028	26226	2	1C
0005433784691	26226	3	1F
0005433784700	26226	4	1H
0005433763089	26226	5	2B
0005433805114	26226	6	2F
0005433805118	26226	7	2G
0005433784707	26226	8	3A
0005433805005	26226	9	3B
0005433763067	26226	10	3F
0005433805066	26226	11	4A
0005433784735	26226	12	3H
0005433805078	26226	13	4B
0005433784609	26226	14	4C
0005433763064	26226	15	4F
0005433763130	26226	16	4H
0005434171044	26226	17	5B
0005434271307	26226	18	5A
0005432659687	26226	19	5C
0005433805021	26226	20	5F
0005434171035	26226	21	5H
0005433804960	26226	22	9H
0005433805052	26226	23	9G
0005433784530	26226	24	11A
0005433805137	26226	25	11D
0005433804980	26226	26	11G
0005433784591	26226	27	12D
0005433784579	26226	28	12E
0005433784658	26226	29	12F
0005434171033	26226	30	12H
0005433763071	26226	31	12G
0005433805055	26226	32	13A
0005432666365	26226	33	13G
0005433805049	26226	34	13F
0005433805048	26226	35	14A
0005434171037	26226	36	13H
0005433784553	26226	37	14F
0005432657409	26226	38	14E
0005433763027	26226	39	15A
0005433805020	26226	40	14H
0005432657411	26226	41	15B
0005433805068	26226	42	15F
0005434171043	26226	43	15G
0005432659686	26226	44	16A
0005433805053	26226	45	16D
0005433763068	26226	46	16B
0005433805010	26226	47	16F
0005433763069	26226	48	16E
0005433784582	26226	49	16H
0005434151701	26226	50	16G
0005433763048	26226	51	17B
0005433804919	26226	52	17D
0005432657419	26226	53	17F
0005434171036	26226	54	17E
0005432657407	26226	55	17G
0005433804981	26226	56	18A
0005433784736	26226	57	18B
0005433784626	26226	58	18F
0005433784637	26226	59	18E
0005434269099	26226	60	18G
0005433784562	26226	61	18H
0005432657412	26226	62	19F
0005433805116	26226	63	19H
0005433805067	26226	64	20A
0005433784613	26226	65	20D
0005433763047	26226	66	20B
0005433784731	26226	67	20E
0005433805036	26226	68	20F
0005433805035	26226	69	20H
0005433784563	26226	70	21B
0005433784488	26226	71	21D
0005433784600	26226	72	21E
0005433805009	26226	73	21F
0005433804958	26226	74	22A
0005433784497	26226	75	22H
0005433763049	26226	76	23B
0005433784508	26226	77	23A
0005433805004	26226	78	23D
0005433805065	26226	79	23G
0005433762977	26226	80	24A
0005433805104	26226	81	23H
0005432663019	26226	82	25E
0005432657414	26226	83	25F
0005433805117	26226	84	27B
0005433784594	26226	85	27E
0005433805131	26226	86	27G
0005433784485	26226	87	28A
0005433784642	26226	88	28D
0005433784706	26226	89	28G
0005433763080	26226	90	28F
0005433784456	26226	91	28H
0005433784607	26226	92	29D
0005434270203	26226	93	29B
0005434171041	26226	94	29E
0005433784595	26226	95	30B
0005434171034	26226	96	30A
0005432657420	26226	97	30D
0005434171040	26226	98	30E
0005433763070	26226	99	30F
0005433784608	26226	100	31B
0005433784690	26226	101	31E
0005434271308	26226	102	31D
0005433784507	26226	103	31G
0005433784739	26226	104	32B
0005433805056	26226	105	32E
0005434151700	26226	106	32G
0005433784577	26226	107	33A
0005433784506	26226	108	32H
0005433784584	26226	109	33F
0005433763088	26226	110	33H
0005433784671	26226	111	34A
0005433763079	26226	112	34F
0005433804959	26226	113	34E
0005433784734	26226	114	35A
0005433784531	26226	115	34H
0005433804961	26226	116	35B
0005433784657	26226	117	35E
0005433784643	26226	118	35G
0005432659684	26226	119	35H
0005434171032	26226	120	36B
0005433784659	26226	121	36E
0005434171045	26226	122	36F
0005433763078	26226	123	37A
0005434151699	26226	124	36H
0005434171038	26226	125	37D
0005433784580	26226	126	37E
0005433763095	26226	127	37G
0005434171039	26226	128	38A
0005432659688	26226	129	38B
0005433784606	26226	130	38E
0005434171042	26226	131	38H
0005433784692	26226	132	39D
0005433784664	26226	133	39E
0005435135664	4887	1	1C
0005435135663	4887	2	3D
0005435135662	4887	3	4C
0005435135666	4887	4	6B
0005435135665	4887	5	18D
0005435929611	4887	6	22A
0005435929641	33031	1	1A
0005435929639	33031	2	1D
0005435135619	33031	3	20A
0005435929640	33031	4	22C
0005434983279	9490	1	2B
0005434983280	9490	2	2C
0005434983281	9490	3	2D
0005434983283	9490	4	4A
0005434983282	9490	5	5C
0005434217927	9490	6	23B
0005434983260	27392	1	1A
0005434983221	27392	2	2A
0005434217963	27392	3	4A
0005434983222	27392	4	4C
0005434983242	27392	5	5A
0005434217964	27392	6	5D
0005434983243	27392	7	7A
0005434217962	27392	8	7C
0005434983256	27392	9	7D
0005434983247	27392	10	18C
0005434983234	27392	11	19D
0005434983240	27392	12	20A
0005434983241	27392	13	22B
0005434217965	27392	14	22C
0005434983233	27392	15	23B
0005433985500	24251	1	1A
0005433985553	24251	2	1C
0005433985420	24251	3	1G
0005433960147	24251	4	2A
0005433960255	24251	5	2C
0005433985441	24251	6	2G
0005433959908	24251	7	3A
0005433985171	24251	8	3C
0005433959909	24251	9	4A
0005433960215	24251	10	4C
0005433960216	24251	11	4B
0005433960264	24251	12	4F
0005433985583	24251	13	4H
0005433960263	24251	14	5B
0005433985499	24251	15	5A
0005433985375	24251	16	5F
0005433985552	24251	17	5C
0005433985465	24251	18	9G
0005433985440	24251	19	9B
0005433960186	24251	20	11A
0005433960143	24251	21	9H
0005433985377	24251	22	11B
0005433985325	24251	23	11F
0005433985436	24251	24	11E
0005433985461	24251	25	12A
0005433960306	24251	26	12B
0005433985446	24251	27	12E
0005433960158	24251	28	12D
0005433960302	24251	29	12G
0005433960093	24251	30	12F
0005433960188	24251	31	13B
0005433960241	24251	32	14A
0005433985490	24251	33	14D
0005433960092	24251	34	14F
0005433985586	24251	35	14G
0005433960138	24251	36	14H
0005433985482	24251	37	15B
0005433985412	24251	38	15F
0005433960321	24251	39	15G
0005433960170	24251	40	16F
0005433960285	24251	41	16G
0005433960244	24251	42	17D
0005433960248	24251	43	17B
0005433985445	24251	44	17F
0005433960142	24251	45	18E
0005433960261	24251	46	18G
0005433960275	24251	47	19B
0005433960284	24251	48	19D
0005433960159	24251	49	19F
0005433960256	24251	50	19E
0005433960272	24251	51	19G
0005433960167	24251	52	20D
0005433960298	24251	53	20B
0005433960262	24251	54	20F
0005433985463	24251	55	20H
0005433985592	24251	56	21A
0005433960214	24251	57	21B
0005433960277	24251	58	21G
0005433960247	24251	59	21F
0005433985421	24251	60	21H
0005433960265	24251	61	22B
0005433985589	24251	62	22E
0005433960230	24251	63	23E
0005433985480	24251	64	23H
0005433960129	24251	65	24D
0005433960160	24251	66	24G
0005433959999	24251	67	25D
0005433960045	24251	68	24H
0005433985383	24251	69	27A
0005433985572	24251	70	25F
0005433985576	24251	71	27D
0005433960307	24251	72	28D
0005433960334	24251	73	28E
0005433960280	24251	74	28F
0005433960249	24251	75	28H
0005433960232	24251	76	29A
0005433960046	24251	77	29B
0005433960301	24251	78	29E
0005433985430	24251	79	29G
0005433985464	24251	80	29F
0005433960084	24251	81	29H
0005433985483	24251	82	30D
0005433960297	24251	83	30H
0005433985324	24251	84	30G
0005433960166	24251	85	31D
0005433960149	24251	86	31F
0005433985442	24251	87	31G
0005433985568	24251	88	32B
0005433960242	24251	89	32D
0005433960187	24251	90	32H
0005433985587	24251	91	32G
0005433960290	24251	92	33A
0005433985517	24251	93	33B
0005433960058	24251	94	33F
0005433960305	24251	95	34A
0005433960231	24251	96	34D
0005433960146	24251	97	34B
0005433960316	24251	98	34F
0005433960245	24251	99	34H
0005433960020	24251	100	35D
0005433985214	24251	101	35E
0005433985262	24251	102	35G
0005433985462	24251	103	36B
0005433960250	24251	104	36E
0005433985454	24251	105	36F
0005433985351	24251	106	36G
0005433985481	24251	107	37E
0005433960130	24251	108	37D
0005433960019	24251	109	37G
0005433960335	24251	110	37F
0005433985453	24251	111	38D
0005433985269	24251	112	38E
0005433960320	24251	113	38F
0005433985857	25933	1	1B
0005433960776	25933	2	1C
0005433985867	25933	3	2B
0005433960739	25933	4	2C
0005433960754	25933	5	2G
0005433960740	25933	6	3A
0005433960745	25933	7	3C
0005433985853	25933	8	4B
0005433985846	25933	9	4F
0005433960774	25933	10	5F
0005433985856	25933	11	5C
0005433960749	25933	12	9A
0005433985866	25933	13	9G
0005433985868	25933	14	9H
0005433985873	25933	15	11B
0005433960778	25933	16	11A
0005433960752	25933	17	11E
0005433960750	25933	18	12F
0005433960763	25933	19	12H
0005433960791	25933	20	13B
0005433960742	25933	21	13F
0005433960771	25933	22	14A
0005433960744	25933	23	13G
0005433960746	25933	24	14B
0005433960772	25933	25	14E
0005433985855	25933	26	15G
0005433960786	25933	27	16A
0005433985847	25933	28	16B
0005433985849	25933	29	16E
0005433985863	25933	30	16F
0005433985864	25933	31	16H
0005433985876	25933	32	17B
0005433960792	25933	33	17D
0005433960751	25933	34	17F
0005433960758	25933	35	17E
0005433985874	25933	36	17G
0005433960755	25933	37	18B
0005433985871	25933	38	18D
0005433960741	25933	39	18E
0005433960759	25933	40	19D
0005433985850	25933	41	19F
0005433985843	25933	42	19E
0005433960766	25933	43	20E
0005433985861	25933	44	20H
0005433960790	25933	45	22D
0005433985845	25933	46	23B
0005433960773	25933	47	23A
0005433960767	25933	48	23D
0005433960762	25933	49	23E
0005433960768	25933	50	24A
0005433985841	25933	51	24G
0005433960765	25933	52	27A
0005433960780	25933	53	25F
0005433960787	25933	54	27G
0005433960747	25933	55	27H
0005433985872	25933	56	28B
0005433960761	25933	57	28E
0005433985851	25933	58	28D
0005433985860	25933	59	28G
0005433985875	25933	60	29D
0005433985862	25933	61	29B
0005433985858	25933	62	29G
0005433960779	25933	63	29H
0005433985869	25933	64	30D
0005433960769	25933	65	30B
0005433985844	25933	66	30G
0005433985870	25933	67	31E
0005433960775	25933	68	31D
0005433960783	25933	69	32A
0005433960788	25933	70	31H
0005433960756	25933	71	32E
0005433960770	25933	72	32G
0005433960784	25933	73	33A
0005433985852	25933	74	33F
0005433960748	25933	75	33G
0005433985842	25933	76	34F
0005433960760	25933	77	34G
0005433960753	25933	78	35B
0005433985877	25933	79	35A
0005433985859	25933	80	35F
0005433985865	25933	81	35E
0005433960789	25933	82	35G
0005433985854	25933	83	36A
0005433985840	25933	84	36D
0005433985848	25933	85	36E
0005433960764	25933	86	36G
0005433960782	25933	87	37D
0005433960743	25933	88	37B
0005433960785	25933	89	37H
0005433960757	25933	90	38D
0005433960777	25933	91	38B
0005433960781	25933	92	38H
0005433165764	932	1	1A
0005433165821	932	2	1B
0005433165742	932	3	1C
0005434480289	932	4	1D
0005434480306	932	5	2A
0005434480305	932	6	2B
0005434480296	932	7	2C
0005433165782	932	8	2D
0005434480300	932	9	3A
0005434480315	932	10	3B
0005433165765	932	11	3C
0005434480294	932	12	3D
0005433165841	932	13	4A
0005434480312	932	14	4B
0005434480307	932	15	4C
0005434480290	932	16	4D
0005433165839	932	17	5A
0005434480297	932	18	5B
0005434480310	932	19	5C
0005433165725	932	20	5D
0005433165783	932	21	6A
0005434480302	932	22	6B
0005434480293	932	23	6C
0005434480298	932	24	6D
0005434480304	932	25	7A
0005434480291	932	26	7B
0005434480314	932	27	7C
0005434480309	932	28	7D
0005433165766	932	29	18A
0005434480311	932	30	18B
0005433165840	932	31	18C
0005434480292	932	32	18D
0005434480301	932	33	19A
0005433165724	932	34	19B
0005433165786	932	35	19C
0005434480299	932	36	19D
0005434480303	932	37	20A
0005434480313	932	38	20B
0005434480308	932	39	20C
0005432269492	932	40	20D
0005433165767	932	41	21A
0005432269491	932	42	21B
0005432269493	932	43	21C
0005434480295	932	44	21D
0005433165730	932	45	22A
0005433165791	932	46	22B
0005433165792	932	47	22C
0005433165787	932	48	22D
0005433165763	932	49	23A
0005432269494	932	50	23B
0005433165889	16597	1	1A
0005434480077	16597	2	1B
0005434480067	16597	3	1C
0005434480179	16597	4	1D
0005434480206	16597	5	2A
0005433165884	16597	6	2B
0005434480152	16597	7	2C
0005434480071	16597	8	2D
0005434480148	16597	9	3A
0005433165886	16597	10	3B
0005434480064	16597	11	3C
0005434480113	16597	12	3D
0005434480007	16597	13	4A
0005434480090	16597	14	4B
0005434480008	16597	15	4C
0005434480183	16597	16	4D
0005433165887	16597	17	5A
0005434480151	16597	18	5B
0005434480097	16597	19	5C
0005434480032	16597	20	5D
0005434480066	16597	21	6A
0005434480167	16597	22	6B
0005434480006	16597	23	6C
0005434479934	16597	24	6D
0005434480091	16597	25	7A
0005434480048	16597	26	7B
0005434480120	16597	27	7C
0005434480031	16597	28	7D
0005434480033	16597	29	18A
0005434480137	16597	30	18B
0005434480136	16597	31	18C
0005433165893	16597	32	18D
0005433165892	16597	33	19A
0005434480135	16597	34	19B
0005434480078	16597	35	19D
0005434480072	16597	36	20A
0005434480168	16597	37	20B
0005434480047	16597	38	20C
0005433165890	16597	39	20D
0005433165888	16597	40	21A
0005434480106	16597	41	21B
0005434480058	16597	42	21C
0005433165894	16597	43	21D
0005434480123	16597	44	22A
0005434480147	16597	45	22B
0005433165885	16597	46	22C
0005433165895	16597	47	22D
0005434480105	16597	48	23A
0005433165891	16597	49	23B
0005433872481	3215	1	1D
0005433872482	3215	2	2B
0005433872479	3215	3	2D
0005433872480	3215	4	3D
0005433872483	3215	5	5C
0005433872478	3215	6	21A
0005433872452	32562	1	2D
0005433872450	32562	2	3B
0005433872451	32562	3	4D
0005433872453	32562	4	19C
0005433872444	32562	5	19D
0005435149995	10324	1	1A
0005435142550	10324	2	1B
0005433289751	10324	3	1C
0005435142549	10324	4	2A
0005435150002	10324	5	2C
0005433289764	10324	6	2D
0005435149999	10324	7	3A
0005435386538	10324	8	3B
0005433289788	10324	9	3C
0005435150006	10324	10	3D
0005435142544	10324	11	4A
0005435150001	10324	12	4B
0005435142554	10324	13	4C
0005435386537	10324	14	4D
0005433289795	10324	15	5B
0005435142543	10324	16	5C
0005435149994	10324	17	5D
0005435142546	10324	18	6A
0005435142553	10324	19	6B
0005435142547	10324	20	6D
0005435142548	10324	21	7A
0005435142551	10324	22	7B
0005435149997	10324	23	7C
0005435150007	10324	24	7D
0005433289749	10324	25	18A
0005435386502	10324	26	18C
0005435150005	10324	27	18D
0005435142545	10324	28	19A
0005435142556	10324	29	19B
0005435386473	10324	30	19C
0005433289787	10324	31	19D
0005435150003	10324	32	20A
0005435150004	10324	33	20B
0005433289778	10324	34	21A
0005435150000	10324	35	21B
0005435386503	10324	36	21C
0005433289765	10324	37	22A
0005435142555	10324	38	22B
0005435149996	10324	39	22C
0005435142552	10324	40	22D
0005435149998	10324	41	23A
0005433289796	10324	42	23B
0005433289844	21959	1	1A
0005435386570	21959	2	1C
0005435149931	21959	3	1D
0005433289848	21959	4	2A
0005435386565	21959	5	2B
0005435386569	21959	6	2C
0005435149827	21959	7	2D
0005435142431	21959	8	3A
0005435142368	21959	9	3D
0005435142400	21959	10	4A
0005435149844	21959	11	4B
0005435149914	21959	12	4D
0005435142492	21959	13	5B
0005435149927	21959	14	5C
0005433289847	21959	15	6B
0005435386566	21959	16	6C
0005435149916	21959	17	6D
0005435142367	21959	18	7B
0005433289845	21959	19	7C
0005435142399	21959	20	7D
0005433289846	21959	21	18A
0005435386568	21959	22	18D
0005435386567	21959	23	19A
0005435149911	21959	24	19C
0005435142450	21959	25	20D
0005435142449	21959	26	21A
0005435149933	21959	27	21D
0005435386571	21959	28	22D
0005433289849	21959	29	23B
0005435529041	11206	1	1A
0005435529113	11206	2	1C
0005435545614	11206	3	1D
0005435528985	11206	4	1F
0005435502080	11206	5	2A
0005435529023	11206	6	2C
0005435319504	11206	7	2D
0005435545640	11206	8	3A
0005435529038	11206	9	3D
0005435502105	11206	10	3F
0005435529065	11206	11	4A
0005435545651	11206	12	4C
0005434573323	11206	13	4E
0005435529085	11206	14	4F
0005435502072	11206	15	5D
0005435502081	11206	16	5E
0005435319468	11206	17	5F
0005435502131	11206	18	6A
0005435545643	11206	19	6C
0005435502149	11206	20	6D
0005434573319	11206	21	6E
0005435319481	11206	22	7A
0005435529022	11206	23	7C
0005435502033	11206	24	7E
0005435502169	11206	25	7F
0005435529086	11206	26	8C
0005435502071	11206	27	8D
0005435529028	11206	28	9A
0005435502094	11206	29	9C
0005435529001	11206	30	9E
0005434573328	11206	31	9F
0005435502171	11206	32	10A
0005435529084	11206	33	10D
0005435502114	11206	34	10F
0005435502070	11206	35	11A
0005434573329	11206	36	11C
0005435545662	11206	37	11D
0005435502170	11206	38	11E
0005435545615	11206	39	11F
0005435545660	11206	40	12A
0005434573318	11206	41	12C
0005435545661	11206	42	12D
0005435529057	11206	43	12E
0005435528983	11206	44	12F
0005435529112	11206	45	13C
0005435319488	11206	46	13D
0005435529062	11206	47	13E
0005435319487	11206	48	13F
0005435528986	11206	49	14A
0005434573326	11206	50	14C
0005435319478	11206	51	14D
0005435502161	11206	52	14F
0005434573327	11206	53	15A
0005435545669	11206	54	15D
0005435529083	11206	55	15E
0005435529064	11206	56	15F
0005435502046	11206	57	16A
0005434573325	11206	58	16C
0005435529000	11206	59	16D
0005434573324	11206	60	17A
0005435529019	11206	61	17C
0005435528947	11206	62	17D
0005434573331	11206	63	17E
0005434573320	11206	64	17F
0005435319505	11206	65	18A
0005435319474	11206	66	18C
0005435319512	11206	67	18D
0005435502167	11206	68	18F
0005435529040	11206	69	19C
0005434573321	11206	70	19D
0005435528984	11206	71	19E
0005435319511	11206	72	19F
0005434573322	11206	73	20A
0005435502130	11206	74	20D
0005434573330	11206	75	20E
0005435319506	11206	76	20F
0005435319575	20906	1	1A
0005435502277	20906	2	1C
0005435508349	20906	3	1F
0005434573187	20906	4	2A
0005435502281	20906	5	2C
0005435508337	20906	6	2D
0005435517895	20906	7	2F
0005435517892	20906	8	3C
0005435517881	20906	9	3D
0005434573253	20906	10	3F
0005435517889	20906	11	4A
0005432291925	20906	12	4C
0005435319571	20906	13	4F
0005435517882	20906	14	4E
0005435517884	20906	15	5A
0005434573213	20906	16	5C
0005435508343	20906	17	5E
0005435508344	20906	18	5F
0005435502283	20906	19	6A
0005435502270	20906	20	6D
0005435502265	20906	21	6E
0005435517890	20906	22	6F
0005432291927	20906	23	7A
0005435517886	20906	24	7C
0005434573134	20906	25	7D
0005435502275	20906	26	7E
0005435508351	20906	27	8A
0005435508345	20906	28	8C
0005435502269	20906	29	8D
0005435319568	20906	30	8E
0005435508342	20906	31	8F
0005435502267	20906	32	9A
0005435508347	20906	33	9C
0005434573215	20906	34	9D
0005435517873	20906	35	9E
0005434573266	20906	36	9F
0005435502278	20906	37	10A
0005435517879	20906	38	10C
0005435517883	20906	39	10D
0005435319576	20906	40	10E
0005435517885	20906	41	10F
0005434573214	20906	42	11A
0005435508338	20906	43	11C
0005435502268	20906	44	11D
0005434573254	20906	45	11E
0005435319574	20906	46	11F
0005435517888	20906	47	12A
0005435517878	20906	48	12D
0005435319569	20906	49	12E
0005435319572	20906	50	12F
0005435508346	20906	51	13C
0005435508339	20906	52	13D
0005435517880	20906	53	13E
0005435517891	20906	54	13F
0005435502279	20906	55	14C
0005435502274	20906	56	14E
0005434573258	20906	57	14F
0005435502282	20906	58	15A
0005435517893	20906	59	15C
0005435502271	20906	60	15E
0005435502266	20906	61	15F
0005435319570	20906	62	16A
0005435517874	20906	63	16C
0005435502280	20906	64	16D
0005435502273	20906	65	16E
0005435508340	20906	66	16F
0005435517877	20906	67	17A
0005435517894	20906	68	17C
0005434573140	20906	69	17E
0005435502272	20906	70	17F
0005435502284	20906	71	18A
0005435508341	20906	72	18E
0005435502285	20906	73	19A
0005435517875	20906	74	19C
0005435502276	20906	75	19D
0005435508348	20906	76	19E
0005435508350	20906	77	19F
0005435319573	20906	78	20A
0005435517887	20906	79	20C
0005434573248	20906	80	20D
0005435517876	20906	81	20E
0005432291926	20906	82	20F
0005432692687	3051	1	1D
0005432692757	3051	2	1F
0005432692695	3051	3	2A
0005432692741	3051	4	2C
0005432692869	3051	5	2F
0005432692737	3051	6	3A
0005432692769	3051	7	3D
0005432692760	3051	8	4C
0005432692771	3051	9	4D
0005432692868	3051	10	5D
0005432692770	3051	11	5E
0005432692729	3051	12	5F
0005432692847	3051	13	6A
0005432692776	3051	14	6C
0005432692767	3051	15	7A
0005432692759	3051	16	7C
0005432692755	3051	17	7D
0005432692792	3051	18	8A
0005432692794	3051	19	9C
0005432692772	3051	20	9D
0005432692718	3051	21	10A
0005432692730	3051	22	11D
0005432692836	3051	23	11E
0005432692754	3051	24	13C
0005432692725	3051	25	13F
0005432692726	3051	26	14F
0005432692671	3051	27	15A
0005432692727	3051	28	15E
0005432692804	3051	29	15F
0005432692793	3051	30	18A
0005432692768	3051	31	18C
0005432692734	3051	32	18D
0005432692810	3051	33	20E
0005432692788	3051	34	20F
0005432880667	3056	1	1C
0005432706746	3056	2	1D
0005433123773	3056	3	2A
0005432706734	3056	4	2C
0005433194832	3056	5	2D
0005433194841	3056	6	3A
0005432880681	3056	7	3C
0005433123638	3056	8	3D
0005432706742	3056	9	4C
0005433123682	3056	10	4A
0005432880628	3056	11	4D
0005432217772	3056	12	4E
0005433123678	3056	13	4F
0005432706741	3056	14	5C
0005433123700	3056	15	5E
0005432217771	3056	16	6A
0005432706733	3056	17	6C
0005432706727	3056	18	6F
0005433123792	3056	19	7A
0005432706736	3056	20	7C
0005432706738	3056	21	7D
0005433123716	3056	22	7F
0005433123786	3056	23	8A
0005433123726	3056	24	8C
0005433123665	3056	25	8D
0005432706730	3056	26	8E
0005433123679	3056	27	8F
0005432706735	3056	28	9C
0005433123722	3056	29	9D
0005432880616	3056	30	9E
0005432880707	3056	31	10C
0005432880677	3056	32	10D
0005432706729	3056	33	10E
0005433123727	3056	34	11A
0005433123667	3056	35	11C
0005432880656	3056	36	11D
0005433123739	3056	37	11E
0005432217773	3056	38	11F
0005432880660	3056	39	12A
0005432706743	3056	40	12C
0005433123677	3056	41	12D
0005432706744	3056	42	13C
0005432880638	3056	43	13D
0005432706752	3056	44	13E
0005433123760	3056	45	13F
0005432706740	3056	46	14A
0005432706745	3056	47	14D
0005432880666	3056	48	14C
0005432706751	3056	49	14E
0005432880683	3056	50	14F
0005432706732	3056	51	15C
0005433123738	3056	52	15D
0005433194842	3056	53	16C
0005432880629	3056	54	16D
0005432706748	3056	55	16E
0005433123672	3056	56	16F
0005433123742	3056	57	17A
0005432706731	3056	58	17C
0005432706739	3056	59	17D
0005432706737	3056	60	18A
0005432706749	3056	61	18C
0005433123791	3056	62	18E
0005432706747	3056	63	18F
0005432880617	3056	64	19C
0005433123756	3056	65	19D
0005432217774	3056	66	19E
0005433123708	3056	67	19F
0005432706750	3056	68	20A
0005433123666	3056	69	20C
0005432706728	3056	70	20E
0005432880682	3056	71	20F
0005432880805	30084	1	1A
0005432693039	30084	2	1C
0005432706498	30084	3	1D
0005433123888	30084	4	1F
0005432880796	30084	5	2A
0005433123901	30084	6	2C
0005432693059	30084	7	2D
0005432706490	30084	8	2F
0005432706460	30084	9	3A
0005432706422	30084	10	3C
0005433123894	30084	11	3D
0005432706545	30084	12	3F
0005432693042	30084	13	4A
0005433123896	30084	14	4C
0005432693041	30084	15	4D
0005432706633	30084	16	4E
0005433123897	30084	17	4F
0005432693035	30084	18	5A
0005432880800	30084	19	5C
0005433123909	30084	20	5D
0005433123889	30084	21	5E
0005432706527	30084	22	5F
0005432706539	30084	23	6A
0005432693033	30084	24	6C
0005432706586	30084	25	6D
0005433123892	30084	26	6E
0005433123908	30084	27	6F
0005433194857	30084	28	7A
0005433123902	30084	29	7C
0005433123904	30084	30	7D
0005433123899	30084	31	7E
0005432706563	30084	32	7F
0005432706585	30084	33	8A
0005432880795	30084	34	8C
0005432706529	30084	35	8D
0005432693060	30084	36	8E
0005432706584	30084	37	8F
0005432693048	30084	38	9A
0005432706593	30084	39	9C
0005432880798	30084	40	9D
0005432706562	30084	41	9E
0005432693052	30084	42	9F
0005432880793	30084	43	10A
0005432693037	30084	44	10C
0005432706480	30084	45	10D
0005433123893	30084	46	10E
0005432693050	30084	47	10F
0005432880794	30084	48	11A
0005432693043	30084	49	11C
0005432693040	30084	50	11D
0005432693055	30084	51	11E
0005432693058	30084	52	11F
0005433123907	30084	53	12A
0005432693053	30084	54	12C
0005432880801	30084	55	12D
0005433123903	30084	56	12E
0005432880792	30084	57	12F
0005432706404	30084	58	13A
0005432693057	30084	59	13C
0005432880799	30084	60	13D
0005432706632	30084	61	13E
0005432693051	30084	62	13F
0005432693062	30084	63	14A
0005432706497	30084	64	14C
0005432693063	30084	65	14D
0005433123905	30084	66	14E
0005432706594	30084	67	14F
0005432693054	30084	68	15A
0005432693056	30084	69	15C
0005432693036	30084	70	15D
0005433194856	30084	71	15E
0005432693032	30084	72	15F
0005433123890	30084	73	16A
0005433123906	30084	74	16C
0005432880804	30084	75	16D
0005433123910	30084	76	16E
0005432706528	30084	77	16F
0005432693046	30084	78	17A
0005432693047	30084	79	17C
0005432706543	30084	80	17D
0005433123895	30084	81	17E
0005432693038	30084	82	17F
0005432706587	30084	83	18A
0005432880791	30084	84	18C
0005432693044	30084	85	18D
0005432693034	30084	86	18E
0005433123891	30084	87	18F
0005432693045	30084	88	19A
0005432880797	30084	89	19C
0005432880802	30084	90	19D
0005433123900	30084	91	19E
0005432706538	30084	92	19F
0005433123898	30084	93	20A
0005432880803	30084	94	20C
0005432706544	30084	95	20D
0005432693061	30084	96	20E
0005432693049	30084	97	20F
0005434979737	23690	1	1B
0005434979733	23690	2	1D
0005434979717	23690	3	2A
0005434988720	23690	4	2B
0005434979739	23690	5	2D
0005434979730	23690	6	3A
0005434979740	23690	7	3B
0005434979736	23690	8	3C
0005434988721	23690	9	3D
0005434979722	23690	10	4A
0005434979723	23690	11	4B
0005434988715	23690	12	4C
0005434979726	23690	13	4D
0005434979718	23690	14	5A
0005434979743	23690	15	5B
0005434988714	23690	16	5C
0005434988713	23690	17	6A
0005434979738	23690	18	6B
0005434979719	23690	19	6C
0005434988711	23690	20	6D
0005434979725	23690	21	7A
0005434979727	23690	22	7B
0005434979742	23690	23	7C
0005434979714	23690	24	7D
0005434988710	23690	25	18A
0005434988712	23690	26	18B
0005434979720	23690	27	18C
0005434979731	23690	28	18D
0005434988718	23690	29	19A
0005434979734	23690	30	19B
0005434979729	23690	31	19C
0005434979715	23690	32	20A
0005434979732	23690	33	20B
0005434988717	23690	34	20D
0005434979728	23690	35	21B
0005434988719	23690	36	21C
0005434979721	23690	37	21D
0005434979724	23690	38	22A
0005434979735	23690	39	22B
0005434988716	23690	40	22C
0005434979741	23690	41	22D
0005434979716	23690	42	23A
0005434979431	27517	1	1A
0005434979388	27517	2	1B
0005434979441	27517	3	1C
0005434988589	27517	4	1D
0005434979561	27517	5	2A
0005434979506	27517	6	2B
0005434988629	27517	7	2C
0005434979560	27517	8	2D
0005434988588	27517	9	3A
0005434979575	27517	10	3B
0005434988631	27517	11	3C
0005434979512	27517	12	3D
0005434988632	27517	13	4A
0005434979574	27517	14	4B
0005434979576	27517	15	4C
0005434979502	27517	16	5A
0005434979291	27517	17	5B
0005434979395	27517	18	5D
0005434979383	27517	19	6A
0005434988603	27517	20	6B
0005434979384	27517	21	6C
0005434979471	27517	22	6D
0005434988630	27517	23	7A
0005434979389	27517	24	7B
0005434988608	27517	25	7C
0005434979553	27517	26	7D
0005434988604	27517	27	18A
0005434988596	27517	28	18C
0005434979422	27517	29	18D
0005434979505	27517	30	19A
0005434979464	27517	31	19B
0005434979504	27517	32	19C
0005434979470	27517	33	19D
0005434979462	27517	34	20A
0005434979547	27517	35	20B
0005434979423	27517	36	20C
0005434988607	27517	37	21A
0005434979521	27517	38	21B
0005434979463	27517	39	22A
0005434979511	27517	40	22D
0005434979403	27517	41	23A
0005434979440	27517	42	23B
0005434302865	10295	1	1D
0005433113511	10295	2	2D
0005434302448	10295	3	3A
0005434302864	10295	4	3C
0005433111486	10295	5	4B
0005433113504	10295	6	5A
0005433111476	10295	7	5B
0005434302866	10295	8	5D
0005434302868	10295	9	6B
0005434302867	10295	10	6C
0005434302449	10295	11	6D
0005433111485	10295	12	7D
0005434302451	10295	13	18A
0005433111481	10295	14	18C
0005433111478	10295	15	19A
0005433111488	10295	16	19C
0005434302450	10295	17	19D
0005433111487	10295	18	20B
0005434302863	10295	19	21A
0005433111477	10295	20	21D
0005434302452	10295	21	22D
0005433113503	10295	22	23B
0005433113533	19612	1	3C
0005434302408	19612	2	5D
0005433113534	19612	3	21A
0005434302401	19612	4	22C
0005435069032	3538	1	1A
0005435718935	3538	2	1C
0005435069009	3538	3	1D
0005435069047	3538	4	1F
0005435069023	3538	5	2C
0005435069026	3538	6	2D
0005435925170	3538	7	3A
0005435925130	3538	8	3C
0005435069049	3538	9	3F
0005435925096	3538	10	4C
0005435069054	3538	11	4D
0005435069056	3538	12	4E
0005435069022	3538	13	5A
0005435069048	3538	14	5C
0005435069025	3538	15	5E
0005435069046	3538	16	5F
0005435069014	3538	17	6A
0005435069043	3538	18	6D
0005435069010	3538	19	6E
0005435069028	3538	20	6F
0005435069016	3538	21	7A
0005435069017	3538	22	7E
0005435925118	3538	23	7F
0005435069034	3538	24	8A
0005435069007	3538	25	8D
0005435069052	3538	26	8E
0005435925162	3538	27	8F
0005435069051	3538	28	9A
0005435069033	3538	29	9C
0005435069058	3538	30	9D
0005435069021	3538	31	9E
0005435069044	3538	32	9F
0005435069013	3538	33	10A
0005435069031	3538	34	10C
0005435925173	3538	35	10E
0005435925099	3538	36	11A
0005435925178	3538	37	11C
0005435925156	3538	38	11D
0005435069050	3538	39	11E
0005435925172	3538	40	11F
0005435069041	3538	41	12C
0005435069035	3538	42	12A
0005435069018	3538	43	12D
0005435069042	3538	44	12E
0005435718932	3538	45	12F
0005435925163	3538	46	13A
0005435718934	3538	47	13C
0005435069055	3538	48	13D
0005435718930	3538	49	14A
0005435069015	3538	50	14C
0005435069037	3538	51	14D
0005435925155	3538	52	14E
0005435069019	3538	53	15A
0005435069040	3538	54	15C
0005435069030	3538	55	15E
0005435069039	3538	56	16A
0005435069029	3538	57	16C
0005435069012	3538	58	16D
0005435069053	3538	59	16E
0005435069020	3538	60	16F
0005435069008	3538	61	17A
0005435925161	3538	62	17C
0005435069024	3538	63	17D
0005435925149	3538	64	17F
0005435925159	3538	65	18A
0005435069038	3538	66	18D
0005435069057	3538	67	18E
0005435718929	3538	68	18F
0005435069045	3538	69	19A
0005435718936	3538	70	19C
0005435925154	3538	71	19D
0005435718931	3538	72	19E
0005435718937	3538	73	19F
0005435069036	3538	74	20A
0005435069011	3538	75	20C
0005435718938	3538	76	20D
0005435069027	3538	77	20E
0005435718933	3538	78	20F
0005435925282	15274	1	1A
0005435068391	15274	2	1D
0005435925290	15274	3	1F
0005435068387	15274	4	2C
0005435068551	15274	5	2D
0005435925285	15274	6	2F
0005435925287	15274	7	3A
0005435068559	15274	8	3C
0005435068711	15274	9	3D
0005435068600	15274	10	3F
0005435068493	15274	11	4A
0005435068529	15274	12	4C
0005435925281	15274	13	4E
0005435068508	15274	14	4F
0005435068530	15274	15	5A
0005435925279	15274	16	5C
0005435925293	15274	17	5D
0005435068477	15274	18	5E
0005435068535	15274	19	5F
0005435068639	15274	20	6A
0005435068389	15274	21	6D
0005435068565	15274	22	6F
0005435068640	15274	23	7A
0005435068745	15274	24	7D
0005435068615	15274	25	7E
0005435068549	15274	26	7F
0005435068346	15274	27	8A
0005435068509	15274	28	8C
0005435068490	15274	29	8E
0005435068504	15274	30	8F
0005435068582	15274	31	9A
0005435068668	15274	32	9C
0005435068305	15274	33	9F
0005435068544	15274	34	10A
0005435068703	15274	35	10C
0005435068633	15274	36	10D
0005435925291	15274	37	10E
0005435068449	15274	38	10F
0005435068552	15274	39	11A
0005435068505	15274	40	11D
0005435068444	15274	41	11E
0005435068321	15274	42	11F
0005435925283	15274	43	12A
0005435068561	15274	44	12C
0005435068601	15274	45	12D
0005435068390	15274	46	12E
0005435068550	15274	47	12F
0005435068445	15274	48	13A
0005435068714	15274	49	13C
0005435068462	15274	50	13D
0005435925294	15274	51	13F
0005435925284	15274	52	14D
0005435925292	15274	53	14E
0005435068713	15274	54	14F
0005435068543	15274	55	15C
0005435068463	15274	56	15D
0005435068611	15274	57	15E
0005435068442	15274	58	16A
0005435068560	15274	59	16C
0005435925288	15274	60	16D
0005435925286	15274	61	16E
0005435068630	15274	62	16F
0005435068627	15274	63	17A
0005435068564	15274	64	17D
0005435068563	15274	65	17E
0005435068386	15274	66	17F
0005435925289	15274	67	18C
0005435068397	15274	68	18D
0005435068634	15274	69	18E
0005435068744	15274	70	19A
0005435068546	15274	71	19D
0005435925280	15274	72	19E
0005435068494	15274	73	19F
0005435068562	15274	74	20C
0005435068418	15274	75	20D
0005435925278	15274	76	20E
0005435068786	15274	77	20F
0005432660815	18180	1	1A
0005432659704	18180	2	1B
0005432659703	18180	3	2A
0005432658588	18180	4	2B
0005432658589	18180	5	3B
0005432660816	18180	6	5B
0005432667433	26394	1	3B
0005432667432	26394	2	5A
0005432660795	26394	3	5B
0005433101561	175	1	1C
0005433101559	175	2	2A
0005432919666	175	3	1F
0005432901440	175	4	2F
0005433101487	175	5	3A
0005432919609	175	6	3D
0005432677520	175	7	4C
0005433101440	175	8	4F
0005433101642	175	9	5C
0005433101621	175	10	5D
0005432157489	175	11	6C
0005433101650	175	12	6A
0005433101643	175	13	6F
0005432919674	175	14	6D
0005432901398	175	15	7A
0005432919673	175	16	8C
0005432901531	175	17	8B
0005433101560	175	18	9A
0005432919690	175	19	9B
0005432901473	175	20	9C
0005433101428	175	21	9E
0005433101653	175	22	9D
0005433101501	175	23	9F
0005433101525	175	24	10A
0005433101531	175	25	10B
0005433101471	175	26	10C
0005433101640	175	27	10D
0005433101557	175	28	11A
0005432919645	175	29	11D
0005432901530	175	30	12B
0005433101678	175	31	12D
0005432919593	175	32	12C
0005433101589	175	33	12E
0005433101623	175	34	12F
0005433101634	175	35	13C
0005433101638	175	36	14B
0005433101667	175	37	14A
0005433101473	175	38	14C
0005432901441	175	39	14E
0005432919700	175	40	14F
0005433101690	175	41	15A
0005432901535	175	42	15C
0005432901393	175	43	15B
0005433101644	175	44	15E
0005433101491	175	45	15D
0005433101691	175	46	15F
0005433101529	175	47	16A
0005432157490	175	48	16B
0005433101652	175	49	16D
0005433101588	175	50	16C
0005432901420	175	51	16E
0005432677540	175	52	16F
0005432677541	175	53	17B
0005433101637	175	54	17A
0005433101412	175	55	17C
0005433101618	175	56	17D
0005432919592	175	57	17F
0005433101649	175	58	18A
0005433101639	175	59	18C
0005433101488	175	60	18E
0005433101677	175	61	18D
0005433101682	175	62	18F
0005433101597	175	63	19C
0005432919727	175	64	19B
0005432901537	175	65	19E
0005432919665	175	66	20A
0005433101624	175	67	21A
0005432919633	175	68	21C
0005433101668	175	69	21F
0005433101636	175	70	21E
0005433101657	175	71	22A
0005433101619	175	72	22B
0005433101693	175	73	22C
0005432901397	175	74	22D
0005433101669	175	75	23B
0005432919724	175	76	23A
0005433101611	175	77	23C
0005433101587	175	78	23D
0005432919708	175	79	23F
0005433101656	175	80	23E
0005433101534	175	81	24B
0005433101666	175	82	24E
0005432919697	175	83	24D
0005432919726	175	84	24F
0005432919699	175	85	25B
0005433101615	175	86	25E
0005433101610	175	87	25C
0005432919691	175	88	26B
0005432901472	175	89	26D
0005432677534	175	90	26C
0005433101683	175	91	26E
0005433101530	175	92	27B
0005432919659	175	93	27D
0005432901456	175	94	27E
0005433101500	175	95	28B
0005433101598	175	96	28C
0005433101550	175	97	28E
0005433101692	175	98	28F
0005432901409	175	99	29B
0005432901471	175	100	29D
0005432901457	175	101	29E
0005432919608	175	102	30A
0005432901433	175	103	30D
0005432901434	175	104	30C
0005433101686	175	105	30E
0005432901492	175	106	30F
0005432919671	175	107	31A
0005432901536	175	108	31D
0005433101620	175	109	31E
0005432817445	176	1	1C
0005432261872	176	2	1D
0005433690908	176	3	1F
0005432288981	176	4	2C
0005432261868	176	5	2F
0005432261845	176	6	3C
0005432817443	176	7	4A
0005432261879	176	8	4D
0005432817430	176	9	4F
0005432817432	176	10	5A
0005432261847	176	11	6A
0005432261842	176	12	5F
0005432261866	176	13	6C
0005432756797	176	14	6F
0005432261865	176	15	7D
0005432817449	176	16	8A
0005432261877	176	17	7F
0005432261844	176	18	8B
0005432261871	176	19	9A
0005432261876	176	20	10C
0005432261859	176	21	10E
0005432817436	176	22	10F
0005432817446	176	23	11B
0005432261880	176	24	11A
0005432261840	176	25	11C
0005432261849	176	26	11E
0005432817426	176	27	11D
0005432817451	176	28	11F
0005432817444	176	29	12B
0005432261841	176	30	12D
0005432817448	176	31	12C
0005432756798	176	32	12F
0005432261874	176	33	13A
0005432817447	176	34	13D
0005432817427	176	35	13E
0005432288983	176	36	14B
0005432261881	176	37	14E
0005432261838	176	38	16B
0005432753262	176	39	16E
0005432817425	176	40	17A
0005432261864	176	41	16F
0005432817440	176	42	17B
0005432261862	176	43	17C
0005432261873	176	44	17E
0005432817442	176	45	18A
0005432261846	176	46	18B
0005432756810	176	47	18D
0005432261850	176	48	18E
0005432261855	176	49	19E
0005432261837	176	50	20B
0005432261854	176	51	20C
0005432261861	176	52	20D
0005432261853	176	53	20F
0005432261851	176	54	21A
0005432261856	176	55	21C
0005432261848	176	56	21E
0005432817452	176	57	21F
0005432756799	176	58	23B
0005432261875	176	59	23A
0005432261858	176	60	23C
0005432817429	176	61	23D
0005432261839	176	62	24A
0005432261869	176	63	23F
0005432207657	176	64	24D
0005432817453	176	65	25B
0005432288982	176	66	26A
0005432261867	176	67	26D
0005432207658	176	68	26C
0005432817439	176	69	26E
0005432817450	176	70	26F
0005432261860	176	71	27B
0005432817428	176	72	27A
0005432261843	176	73	27C
0005432817431	176	74	27E
0005432753252	176	75	28D
0005432261852	176	76	28E
0005432817441	176	77	29A
0005432261878	176	78	29B
0005432817438	176	79	29E
0005432817435	176	80	29F
0005432817437	176	81	30D
0005432261863	176	82	30C
0005432261857	176	83	31A
0005432817433	176	84	31B
0005432261870	176	85	31D
0005432817434	176	86	31E
0005433102110	8082	1	1A
0005432020237	8082	2	1C
0005433102084	8082	3	1F
0005433102108	8082	4	1D
0005432020231	8082	5	2A
0005433102067	8082	6	2C
0005432919824	8082	7	2F
0005433102063	8082	8	2D
0005432753299	8082	9	3A
0005432020227	8082	10	3C
0005433102111	8082	11	3F
0005432020222	8082	12	4A
0005432919844	8082	13	4C
0005433102109	8082	14	4F
0005432919830	8082	15	5A
0005433102079	8082	16	5C
0005432020233	8082	17	5D
0005432919836	8082	18	6F
0005432044520	8082	19	6D
0005433102065	8082	20	7A
0005432020219	8082	21	7D
0005432020228	8082	22	7C
0005432391995	8082	23	8A
0005432919829	8082	24	7F
0005433102114	8082	25	8C
0005433102089	8082	26	8D
0005432919842	8082	27	9C
0005433102104	8082	28	9B
0005432020243	8082	29	9F
0005432020229	8082	30	10A
0005432751523	8082	31	10D
0005432020234	8082	32	10C
0005432020244	8082	33	10E
0005433102118	8082	34	10F
0005433102121	8082	35	11A
0005432020240	8082	36	11C
0005432020236	8082	37	11B
0005433102074	8082	38	11D
0005432919841	8082	39	11F
0005432020225	8082	40	12A
0005433102082	8082	41	12B
0005432020218	8082	42	12D
0005433102099	8082	43	12C
0005433102070	8082	44	12F
0005433102105	8082	45	13B
0005432919835	8082	46	13A
0005433102088	8082	47	13C
0005432919826	8082	48	13E
0005433102117	8082	49	14A
0005432020232	8082	50	13F
0005433102073	8082	51	14D
0005433102086	8082	52	14C
0005432753300	8082	53	14E
0005433102077	8082	54	14F
0005433102066	8082	55	15C
0005433102092	8082	56	15E
0005433102081	8082	57	15F
0005433102097	8082	58	16A
0005432919840	8082	59	16B
0005433102103	8082	60	16D
0005432020239	8082	61	16C
0005432020221	8082	62	16E
0005432919827	8082	63	16F
0005433102078	8082	64	17C
0005433102123	8082	65	17E
0005432045611	8082	66	17D
0005432020230	8082	67	18A
0005432020238	8082	68	18B
0005433102096	8082	69	18C
0005432020241	8082	70	18E
0005432677568	8082	71	19C
0005433102102	8082	72	19D
0005432753297	8082	73	20A
0005432919843	8082	74	19E
0005432044521	8082	75	20B
0005433102076	8082	76	20C
0005432020220	8082	77	20D
0005432753298	8082	78	20F
0005433102101	8082	79	20E
0005432919839	8082	80	21A
0005432020224	8082	81	21B
0005432045612	8082	82	21D
0005432677570	8082	83	21F
0005432919837	8082	84	22B
0005432919828	8082	85	22D
0005433102072	8082	86	22C
0005432919834	8082	87	22E
0005433102119	8082	88	22F
0005432044522	8082	89	23C
0005432020226	8082	90	23D
0005432391997	8082	91	23E
0005432020235	8082	92	23F
0005432020242	8082	93	24A
0005432020223	8082	94	24E
0005433102069	8082	95	24F
0005433102071	8082	96	25C
0005433102120	8082	97	25B
0005433102093	8082	98	25E
0005433102083	8082	99	26A
0005433102098	8082	100	25F
0005433102116	8082	101	26B
0005432919825	8082	102	26C
0005432919833	8082	103	26E
0005432677569	8082	104	26F
0005432751524	8082	105	27B
0005433102113	8082	106	27A
0005433102115	8082	107	27C
0005433102087	8082	108	27D
0005432677571	8082	109	28A
0005433102068	8082	110	28B
0005432919832	8082	111	28D
0005433102124	8082	112	28C
0005432919831	8082	113	28E
0005433102090	8082	114	28F
0005433102107	8082	115	29B
0005433102091	8082	116	29A
0005433102064	8082	117	29C
0005433102075	8082	118	29D
0005433102122	8082	119	29E
0005432391996	8082	120	30A
0005433102095	8082	121	30B
0005433102080	8082	122	30E
0005433102112	8082	123	30F
0005433102100	8082	124	31C
0005433102085	8082	125	31B
0005433102106	8082	126	31D
0005433102094	8082	127	31E
0005432919838	8082	128	31F
0005432901596	8081	1	1C
0005432817317	8081	2	1F
0005432901593	8081	3	1D
0005432817218	8081	4	2A
0005432817325	8081	5	3A
0005432901586	8081	6	3C
0005432901584	8081	7	5A
0005432817263	8081	8	4F
0005432817163	8081	9	6A
0005432817258	8081	10	6F
0005432901583	8081	11	7A
0005432901582	8081	12	7F
0005432901585	8081	13	8C
0005432901589	8081	14	8E
0005432817201	8081	15	8F
0005432817299	8081	16	9B
0005432817217	8081	17	9E
0005432817227	8081	18	9D
0005432901592	8081	19	10A
0005432901587	8081	20	11B
0005432817226	8081	21	11D
0005432002073	8081	22	11F
0005432002074	8081	23	12B
0005432901591	8081	24	12C
0005432002072	8081	25	13D
0005432817132	8081	26	13F
0005432817212	8081	27	14B
0005432817173	8081	28	14E
0005432901598	8081	29	15B
0005432817235	8081	30	15C
0005432901588	8081	31	15E
0005432817184	8081	32	18B
0005432817176	8081	33	19B
0005432817086	8081	34	18E
0005432817123	8081	35	19E
0005432817188	8081	36	20C
0005432817174	8081	37	20B
0005432817066	8081	38	20E
0005432817178	8081	39	21A
0005432817068	8081	40	21B
0005432817175	8081	41	22A
0005432817200	8081	42	22E
0005432817108	8081	43	23A
0005432817316	8081	44	23C
0005432817136	8081	45	23D
0005432901597	8081	46	23F
0005432817224	8081	47	26A
0005432817234	8081	48	26B
0005432901590	8081	49	26E
0005432817090	8081	50	26F
0005432817131	8081	51	27B
0005432817164	8081	52	27C
0005432817243	8081	53	27D
0005432901581	8081	54	29B
0005432817107	8081	55	30A
0005432817264	8081	56	30B
0005432901595	8081	57	30E
0005432901594	8081	58	30F
0005433870729	9685	1	1B
0005434175708	9685	2	2A
0005433870727	9685	3	3A
0005433870730	9685	4	2B
0005434175695	9685	5	4A
0005434175709	9685	6	4B
0005434175713	9685	7	5A
0005434175712	9685	8	5B
0005433870728	9685	9	6A
0005434175702	9685	10	6B
0005433870712	32332	1	1B
0005433870707	32332	2	2A
0005434175747	32332	3	2B
0005434175748	32332	4	3A
0005434175749	32332	5	4B
0005433870711	32332	6	5B
0005433870708	32332	7	6A
0005434175746	32332	8	6B
0005435902405	3502	1	1C
0005434878136	3502	2	1A
0005432188605	3502	3	1G
0005432799431	3502	4	1D
0005432799442	3502	5	2A
0005434878171	3502	6	1K
0005435913870	3502	7	1H
0005434878178	3502	8	2D
0005434878191	3502	9	2C
0005435126353	3502	10	2H
0005434426589	3502	11	2G
0005432799417	3502	12	3A
0005434878193	3502	13	3C
0005435902522	3502	14	3G
0005434878155	3502	15	4C
0005434878133	3502	16	4A
0005434878112	3502	17	3K
0005434878121	3502	18	4G
0005435902541	3502	19	4D
0005435902536	3502	20	5A
0005434426579	3502	21	4H
0005434878159	3502	22	5D
0005435902573	3502	23	5C
0005435626153	3502	24	5H
0005434878177	3502	25	5K
0005435902519	3502	26	11D
0005432799430	3502	27	11F
0005432799433	3502	28	11K
0005434878197	3502	29	11H
0005434878165	3502	30	11G
0005434878111	3502	31	12A
0005435126344	3502	32	12F
0005434938114	3502	33	13A
0005432799440	3502	34	12H
0005435126354	3502	35	13C
0005434426585	3502	36	13F
0005435126349	3502	37	13H
0005434878189	3502	38	13G
0005434878109	3502	39	14A
0005434878137	3502	40	14C
0005435902547	3502	41	14G
0005434878190	3502	42	14F
0005435126341	3502	43	14E
0005435913875	3502	44	14K
0005435902476	3502	45	14H
0005434878175	3502	46	15C
0005434426571	3502	47	15E
0005432799420	3502	48	15D
0005435626163	3502	49	15H
0005434426577	3502	50	15G
0005435841812	3502	51	15F
0005434426596	3502	52	15K
0005434878156	3502	53	16D
0005435126317	3502	54	16E
0005434878139	3502	55	16H
0005434878151	3502	56	17A
0005434878110	3502	57	16K
0005434878142	3502	58	17D
0005435626148	3502	59	17G
0005432188603	3502	60	17F
0005435626157	3502	61	18A
0005435126330	3502	62	17K
0005434938130	3502	63	17H
0005435126350	3502	64	18C
0005434938132	3502	65	18D
0005434938123	3502	66	18G
0005434878141	3502	67	18F
0005435902553	3502	68	18E
0005435626146	3502	69	18K
0005434878140	3502	70	18J
0005434878154	3502	71	18H
0005434878115	3502	72	19A
0005434878114	3502	73	19C
0005432799436	3502	74	19B
0005435902462	3502	75	19F
0005434938115	3502	76	19E
0005432799428	3502	77	19H
0005435902552	3502	78	19G
0005435626160	3502	79	19K
0005434878153	3502	80	20C
0005435126336	3502	81	20B
0005435902550	3502	82	20E
0005435902459	3502	83	20D
0005432799421	3502	84	21B
0005434878122	3502	85	20K
0005435126316	3502	86	21C
0005435126326	3502	87	21G
0005434426595	3502	88	21H
0005435913877	3502	89	22A
0005432799427	3502	90	21K
0005434878172	3502	91	21J
0005434878123	3502	92	22D
0005434878150	3502	93	22C
0005434426593	3502	94	22H
0005435902404	3502	95	22G
0005435126351	3502	96	22F
0005432799424	3502	97	22J
0005435126331	3502	98	23B
0005435126342	3502	99	23A
0005434878173	3502	100	23C
0005434426567	3502	101	23E
0005435626145	3502	102	23J
0005435626161	3502	103	23H
0005435626159	3502	104	23G
0005432183466	3502	105	24D
0005434878146	3502	106	23K
0005435626164	3502	107	24F
0005434878166	3502	108	24E
0005434878130	3502	109	25A
0005434878179	3502	110	24G
0005435126345	3502	111	25D
0005435902500	3502	112	25E
0005432799435	3502	113	25H
0005434878148	3502	114	26A
0005435126319	3502	115	25K
0005435902574	3502	116	25J
0005434878161	3502	117	26C
0005434426581	3502	118	26B
0005435126320	3502	119	26F
0005435126348	3502	120	26E
0005435126325	3502	121	26D
0005434878199	3502	122	26H
0005434938126	3502	123	26G
0005434938127	3502	124	27B
0005434878116	3502	125	27A
0005434426582	3502	126	27D
0005434878198	3502	127	27J
0005434878135	3502	128	27H
0005435902508	3502	129	27G
0005435913878	3502	130	28A
0005434878188	3502	131	27K
0005435126332	3502	132	28B
0005432799443	3502	133	28E
0005434938129	3502	134	28D
0005432799418	3502	135	28C
0005434426575	3502	136	28G
0005435902475	3502	137	28K
0005435126334	3502	138	28J
0005434878160	3502	139	28H
0005432613858	3502	140	29A
0005435126339	3502	141	29D
0005432799426	3502	142	29C
0005435126352	3502	143	29B
0005434426584	3502	144	29E
0005432611707	3502	145	29H
0005435902545	3502	146	29G
0005434878174	3502	147	29K
0005435626162	3502	148	29J
0005434878113	3502	149	30B
0005434878180	3502	150	30A
0005435626152	3502	151	30D
0005434878107	3502	152	30C
0005434426580	3502	153	30G
0005435126321	3502	154	30H
0005434938117	3502	155	31B
0005434938124	3502	156	31A
0005435626156	3502	157	31D
0005434878125	3502	158	31C
0005432799432	3502	159	31F
0005435126343	3502	160	31E
0005434938131	3502	161	31H
0005435126335	3502	162	32C
0005432799416	3502	163	32G
0005434878152	3502	164	32F
0005434878194	3502	165	32J
0005434878163	3502	166	32H
0005434878128	3502	167	33A
0005434426569	3502	168	33D
0005434878170	3502	169	33C
0005432799429	3502	170	33B
0005435126333	3502	171	33F
0005435126315	3502	172	33E
0005432613857	3502	173	33H
0005434426592	3502	174	34A
0005434878192	3502	175	33K
0005432613856	3502	176	34B
0005434426597	3502	177	34E
0005435626147	3502	178	34D
0005432799438	3502	179	34C
0005435902457	3502	180	34F
0005432188604	3502	181	34J
0005435126340	3502	182	34H
0005434878127	3502	183	35B
0005434878129	3502	184	35G
0005435126328	3502	185	35F
0005435626155	3502	186	35J
0005434426573	3502	187	36C
0005434878126	3502	188	36B
0005435126338	3502	189	36F
0005435126329	3502	190	36E
0005434878119	3502	191	36D
0005435841092	3502	192	36H
0005435902585	3502	193	36J
0005432799437	3502	194	37A
0005434878184	3502	195	36K
0005434878164	3502	196	37E
0005432799425	3502	197	37D
0005434426576	3502	198	37C
0005432611706	3502	199	37G
0005432183465	3502	200	37J
0005434426578	3502	201	37H
0005432799422	3502	202	38A
0005435902477	3502	203	37K
0005434878143	3502	204	38C
0005434938122	3502	205	38J
0005432613859	3502	206	39B
0005435626158	3502	207	38K
0005434878176	3502	208	39D
0005434878120	3502	209	39F
0005434878181	3502	210	39E
0005435902586	3502	211	39J
0005434426570	3502	212	39H
0005434878147	3502	213	39G
0005432611705	3502	214	40A
0005434426583	3502	215	39K
0005434878157	3502	216	40C
0005434878106	3502	217	40B
0005435626151	3502	218	40E
0005434426594	3502	219	40D
0005435902458	3502	220	40G
0005434878149	3502	221	40J
0005435902544	3502	222	40H
0005434878196	3502	223	41B
0005434878169	3502	224	41A
0005435913889	3502	225	40K
0005434878167	3502	226	41C
0005434878118	3502	227	41F
0005434878108	3502	228	41G
0005434426590	3502	229	42A
0005432799434	3502	230	41K
0005435126318	3502	231	41J
0005434878132	3502	232	42C
0005434938125	3502	233	42B
0005434426574	3502	234	42E
0005432183464	3502	235	42D
0005434878124	3502	236	42G
0005434878183	3502	237	42F
0005434878145	3502	238	42J
0005435126323	3502	239	42H
0005435626149	3502	240	43B
0005434938120	3502	241	43A
0005435902528	3502	242	43H
0005435126346	3502	243	43K
0005435913890	3502	244	43J
0005434878162	3502	245	44C
0005432799423	3502	246	44B
0005435126327	3502	247	44A
0005435902493	3502	248	44E
0005432611708	3502	249	44G
0005434878187	3502	250	44F
0005432611709	3502	251	45B
0005434938116	3502	252	45C
0005435902572	3502	253	45F
0005434878131	3502	254	45E
0005435902548	3502	255	45H
0005435913871	3502	256	45G
0005435626154	3502	257	46A
0005435126314	3502	258	45J
0005432799439	3502	259	46C
0005432799441	3502	260	46B
0005434938118	3502	261	46G
0005435126322	3502	262	46F
0005434426591	3502	263	47A
0005434426568	3502	264	47E
0005434426587	3502	265	47D
0005434426572	3502	266	47G
0005434878186	3502	267	47K
0005432799419	3502	268	48D
0005434878195	3502	269	48C
0005435626150	3502	270	48A
0005434878138	3502	271	48F
0005434878117	3502	272	48H
0005434878144	3502	273	48G
0005434878200	3502	274	48K
0005434938119	3502	275	49D
0005434426588	3502	276	49C
0005434938121	3502	277	49F
0005434878201	3502	278	49K
0005434938128	3502	279	49G
0005434426586	3502	280	50C
0005435126337	3502	281	50A
0005434878168	3502	282	50E
0005434878134	3502	283	50H
0005434878158	3502	284	50G
0005435126324	3502	285	50F
0005435126347	3502	286	50K
0005434878182	3502	287	51F
0005434878185	3502	288	51G
0005435125942	14559	1	1D
0005434877246	14559	2	1H
0005435902690	14559	3	2A
0005432799158	14559	4	2G
0005434877833	14559	5	2D
0005432799159	14559	6	2K
0005435625949	14559	7	3G
0005434877418	14559	8	3D
0005434877093	14559	9	3C
0005434426207	14559	10	3K
0005434877639	14559	11	3H
0005434877314	14559	12	4C
0005435125964	14559	13	4A
0005435125961	14559	14	4D
0005435125989	14559	15	5A
0005435126035	14559	16	4K
0005434937901	14559	17	5D
0005434426406	14559	18	5C
0005435625982	14559	19	5H
0005434877092	14559	20	5G
0005434877223	14559	21	11C
0005434937991	14559	22	11A
0005435625988	14559	23	5K
0005434426228	14559	24	11D
0005435125946	14559	25	11E
0005434877303	14559	26	11K
0005434877687	14559	27	11G
0005435126100	14559	28	12F
0005435625963	14559	29	12E
0005435625991	14559	30	12D
0005434877516	14559	31	13A
0005434426420	14559	32	12H
0005434877562	14559	33	13C
0005434426311	14559	34	13G
0005435625966	14559	35	13F
0005432799084	14559	36	13E
0005434877638	14559	37	13D
0005434938017	14559	38	14A
0005434937986	14559	39	13K
0005435125944	14559	40	14D
0005432799298	14559	41	14G
0005435125977	14559	42	14F
0005434877012	14559	43	14K
0005435902678	14559	44	14H
0005435125848	14559	45	15D
0005435902688	14559	46	15C
0005434877300	14559	47	15A
0005434877222	14559	48	15E
0005435125837	14559	49	15H
0005434877280	14559	50	15G
0005434877082	14559	51	15F
0005435902679	14559	52	16A
0005435625955	14559	53	15K
0005434877324	14559	54	16C
0005432799170	14559	55	16G
0005432799259	14559	56	16F
0005434426368	14559	57	16E
0005434426307	14559	58	16H
0005434426236	14559	59	17C
0005434877309	14559	60	17E
0005434877126	14559	61	17D
0005434426326	14559	62	17G
0005435126037	14559	63	17F
0005435125868	14559	64	18C
0005434937902	14559	65	18B
0005434877013	14559	66	18E
0005434877389	14559	67	18D
0005434877490	14559	68	18H
0005434877518	14559	69	18G
0005435125960	14559	70	18F
0005434877331	14559	71	19A
0005435125990	14559	72	18K
0005434877724	14559	73	19D
0005434877675	14559	74	19C
0005434877606	14559	75	19B
0005435126112	14559	76	19E
0005435126061	14559	77	19J
0005434937948	14559	78	19H
0005432611668	14559	79	19G
0005435125888	14559	80	19K
0005434877351	14559	81	20C
0005435913930	14559	82	20B
0005434937962	14559	83	20H
0005434426162	14559	84	20G
0005434877588	14559	85	20J
0005434937939	14559	86	21D
0005432611671	14559	87	21C
0005435902684	14559	88	21H
0005435902691	14559	89	21G
0005434877310	14559	90	22C
0005434877281	14559	91	22F
0005434426365	14559	92	22E
0005434877832	14559	93	22H
0005434877459	14559	94	22G
0005432611669	14559	95	22K
0005435902676	14559	96	23B
0005434877431	14559	97	23A
0005434938002	14559	98	23C
0005434426411	14559	99	23G
0005434877674	14559	100	23F
0005434426410	14559	101	23E
0005434426270	14559	102	23J
0005434426347	14559	103	23H
0005434877030	14559	104	24D
0005435902685	14559	105	24F
0005435625990	14559	106	24E
0005432799133	14559	107	25A
0005435126041	14559	108	25D
0005432611667	14559	109	25C
0005434426230	14559	110	25B
0005432799207	14559	111	25E
0005432607533	14559	112	25H
0005432799210	14559	113	25G
0005434877352	14559	114	25K
0005432799217	14559	115	25J
0005435902682	14559	116	26C
0005434426283	14559	117	26B
0005434426281	14559	118	26A
0005435625936	14559	119	26E
0005434877403	14559	120	26D
0005435902680	14559	121	26H
0005432059503	14559	122	26F
0005434877298	14559	123	26K
0005434877235	14559	124	26J
0005434937970	14559	125	27A
0005432799209	14559	126	27D
0005435126101	14559	127	27C
0005434937992	14559	128	27B
0005434877217	14559	129	27F
0005434877247	14559	130	27E
0005432607529	14559	131	27H
0005435125880	14559	132	27G
0005434877517	14559	133	28A
0005434877216	14559	134	28C
0005432607534	14559	135	28B
0005435902675	14559	136	28D
0005434876666	14559	137	28H
0005434877261	14559	138	28G
0005435625928	14559	139	28F
0005434426206	14559	140	28J
0005434426205	14559	141	29B
0005434877702	14559	142	28K
0005434877488	14559	143	29D
0005434877566	14559	144	29C
0005432799109	14559	145	29G
0005435126036	14559	146	29F
0005434877218	14559	147	29E
0005434937987	14559	148	29H
0005435125976	14559	149	29K
0005434426419	14559	150	30B
0005434877124	14559	151	30A
0005435902692	14559	152	30D
0005435902693	14559	153	30C
0005434877479	14559	154	30G
0005434877428	14559	155	30K
0005434877219	14559	156	30H
0005435625986	14559	157	31A
0005435902686	14559	158	31B
0005434937997	14559	159	31G
0005434426338	14559	160	31E
0005434937969	14559	161	31K
0005434426344	14559	162	31J
0005432799161	14559	163	32E
0005434877509	14559	164	32D
0005434877325	14559	165	32G
0005434877186	14559	166	32F
0005432611670	14559	167	32K
0005435625983	14559	168	32J
0005432799321	14559	169	32H
0005434877279	14559	170	33B
0005432799157	14559	171	33A
0005435625992	14559	172	33D
0005435125996	14559	173	33C
0005432799178	14559	174	33G
0005435913932	14559	175	33F
0005434937998	14559	176	33E
0005434426346	14559	177	33J
0005435126018	14559	178	33H
0005434877158	14559	179	33K
0005435126060	14559	180	34B
0005434426393	14559	181	34A
0005434426327	14559	182	34E
0005435126030	14559	183	34G
0005432799185	14559	184	34F
0005434426282	14559	185	34K
0005434426321	14559	186	34J
0005434426290	14559	187	34H
0005434877519	14559	188	35B
0005434426418	14559	189	35A
0005432607511	14559	190	35D
0005435126079	14559	191	35C
0005435125859	14559	192	35E
0005434426310	14559	193	35J
0005434877809	14559	194	35H
0005434877011	14559	195	35K
0005434938018	14559	196	36C
0005435842327	14559	197	36B
0005434877388	14559	198	36A
0005434877494	14559	199	36D
0005434876976	14559	200	36G
0005432799156	14559	201	36F
0005435625939	14559	202	36K
0005432799244	14559	203	36H
0005434937947	14559	204	37A
0005434877657	14559	205	37D
0005435125829	14559	206	37C
0005434877457	14559	207	37F
0005434937971	14559	208	37J
0005434426383	14559	209	37H
0005434937963	14559	210	37K
0005435125903	14559	211	38C
0005435126013	14559	212	38B
0005434877510	14559	213	38A
0005435902683	14559	214	38H
0005434426466	14559	215	39B
0005432799087	14559	216	39D
0005434937993	14559	217	39C
0005434877179	14559	218	39E
0005432799045	14559	219	39G
0005434877473	14559	220	39K
0005434938001	14559	221	39J
0005434877398	14559	222	40C
0005434877382	14559	223	40B
0005435125975	14559	224	40D
0005435902681	14559	225	40H
0005434877304	14559	226	41A
0005435625987	14559	227	41D
0005435902687	14559	228	41C
0005434877508	14559	229	41F
0005434877041	14559	230	41E
0005435625892	14559	231	41H
0005434877042	14559	232	41K
0005434938035	14559	233	42B
0005435126074	14559	234	42A
0005435125838	14559	235	42E
0005434426381	14559	236	42D
0005432799208	14559	237	42C
0005434426380	14559	238	42G
0005435625984	14559	239	42F
0005434877432	14559	240	42K
0005434877442	14559	241	42J
0005435625967	14559	242	42H
0005435126014	14559	243	43B
0005434877808	14559	244	43A
0005434877834	14559	245	43D
0005435902677	14559	246	43C
0005435125978	14559	247	43F
0005434877125	14559	248	43E
0005435125970	14559	249	43G
0005435125945	14559	250	43K
0005435913931	14559	251	43J
0005435125826	14559	252	44C
0005434426284	14559	253	44B
0005434877411	14559	254	44A
0005434877616	14559	255	44E
0005435625938	14559	256	44H
0005435625950	14559	257	44F
0005434937994	14559	258	44J
0005434876960	14559	259	45B
0005434877710	14559	260	45A
0005434877456	14559	261	45D
0005435125858	14559	262	45C
0005434877538	14559	263	45F
0005432607528	14559	264	45E
0005432059502	14559	265	45J
0005432799320	14559	266	45H
0005434877472	14559	267	45G
0005435126001	14559	268	46A
0005434877408	14559	269	46C
0005434426394	14559	270	46B
0005435126012	14559	271	46D
0005434426387	14559	272	46F
0005434426427	14559	273	46J
0005434877333	14559	274	46H
0005435125865	14559	275	47A
0005434877539	14559	276	47G
0005434426386	14559	277	47K
0005435125951	14559	278	47H
0005435126116	14559	279	48C
0005434426367	14559	280	48F
0005434877376	14559	281	49C
0005435125902	14559	282	49A
0005435625968	14559	283	48K
0005432059501	14559	284	49D
0005434877224	14559	285	49G
0005434877701	14559	286	49E
0005434426300	14559	287	49K
0005434877375	14559	288	50C
0005434937929	14559	289	50A
0005434877688	14559	290	50E
0005434877640	14559	291	50D
0005434877187	14559	292	50G
0005434426308	14559	293	51D
0005435902689	14559	294	51G
0005434325639	3587	1	1B
0005434312317	3587	2	1C
0005434312316	3587	3	2A
0005434325641	3587	4	2B
0005435889847	3587	5	3C
0005434325635	3587	6	4B
0005434325643	3587	7	4C
0005435889819	3587	8	4D
0005434325642	3587	9	5C
0005434325638	3587	10	6A
0005435889848	3587	11	6B
0005434325633	3587	12	6C
0005434325640	3587	13	7B
0005434325632	3587	14	19A
0005435889820	3587	15	20B
0005435889834	3587	16	20C
0005434325637	3587	17	21A
0005434325636	3587	18	21B
0005435889829	3587	19	21C
0005434325634	3587	20	21D
0005434325571	15621	1	1A
0005434325562	15621	2	1D
0005435889891	15621	3	2C
0005434325567	15621	4	3D
0005435889888	15621	5	4B
0005434325591	15621	6	4C
0005434325572	15621	7	4D
0005434325540	15621	8	5A
0005434325569	15621	9	6B
0005434325590	15621	10	7D
0005435889887	15621	11	18D
0005434325566	15621	12	19C
0005435889890	15621	13	20A
0005434325570	15621	14	20D
0005434325537	15621	15	21A
0005434325516	15621	16	21B
0005435889889	15621	17	21D
0005434325589	15621	18	22A
0005435889892	15621	19	22D
0005435957693	625	1	1B
0005435957687	625	2	1C
0005433420304	625	3	1D
0005435957681	625	4	2B
0005433420342	625	5	2D
0005433420305	625	6	3A
0005435957692	625	7	3B
0005433420350	625	8	4C
0005435957683	625	9	5B
0005435957680	625	10	5D
0005435957686	625	11	6A
0005435957684	625	12	6C
0005435957696	625	13	6D
0005433420348	625	14	7A
0005435957688	625	15	19A
0005435957682	625	16	19C
0005433420287	625	17	19D
0005433420349	625	18	20D
0005435957689	625	19	21A
0005435957690	625	20	21B
0005435957695	625	21	21D
0005435957694	625	22	22A
0005435957685	625	23	22B
0005435957691	625	24	23A
0005433420339	625	25	23B
0005435957500	15201	1	1A
0005435957538	15201	2	1C
0005435957605	15201	3	1D
0005435957550	15201	4	2D
0005433420396	15201	5	3A
0005435957533	15201	6	3C
0005433420392	15201	7	4A
0005433420395	15201	8	4B
0005435957606	15201	9	4C
0005435957564	15201	10	4D
0005435957578	15201	11	5B
0005435957552	15201	12	5D
0005435957603	15201	13	6D
0005435957528	15201	14	7A
0005435957522	15201	15	7C
0005433420391	15201	16	7D
0005435957541	15201	17	18B
0005435957614	15201	18	18C
0005435957634	15201	19	18D
0005435957557	15201	20	19B
0005435957566	15201	21	19C
0005435957527	15201	22	19D
0005435957499	15201	23	20A
0005435957558	15201	24	20B
0005433420394	15201	25	20C
0005433420397	15201	26	20D
0005435957556	15201	27	21A
0005435957501	15201	28	21D
0005433420393	15201	29	22C
0005433420390	15201	30	22D
0005435957602	15201	31	23B
0005434247118	8851	1	2A
0005434247116	8851	2	4B
0005434247119	8851	3	5B
0005434247144	16050	1	1A
0005434247145	16050	2	2A
0005434247143	16050	3	3B
0005435629397	16050	4	6A
0005434096719	11822	1	1D
0005434096724	11822	2	2D
0005434096714	11822	3	4B
0005434096711	11822	4	4C
0005434096720	11822	5	5B
0005434096718	11822	6	18B
0005434096715	11822	7	21B
0005434096710	11822	8	21D
0005434096709	11822	9	22D
0005435163224	4443	1	1D
0005435163229	4443	2	2A
0005435163230	4443	3	2B
0005435163225	4443	4	2C
0005435933411	4443	5	3A
0005435163227	4443	6	4A
0005435163228	4443	7	4B
0005435163226	4443	8	5C
0005435933428	4443	9	5D
0005435933420	4443	10	6C
0005435163220	4443	11	7D
0005435163222	4443	12	18A
0005435933426	4443	13	19C
0005435163223	4443	14	20A
0005435933412	4443	15	21B
0005435933413	4443	16	21D
0005435933419	4443	17	22B
0005435163221	4443	18	22D
0005435933432	4443	19	23B
0005435163168	29525	1	1A
0005435163163	29525	2	1B
0005435933450	29525	3	3B
0005435933453	29525	4	4C
0005435933449	29525	5	5A
0005435163172	29525	6	5B
0005435933447	29525	7	5D
0005435163170	29525	8	6C
0005435163184	29525	9	6D
0005435163199	29525	10	7A
0005435163175	29525	11	7C
0005435163192	29525	12	18A
0005435163193	29525	13	18D
0005435163189	29525	14	19A
0005435933446	29525	15	19B
0005435163162	29525	16	19C
0005435163173	29525	17	19D
0005435163174	29525	18	20C
0005435163171	29525	19	20D
0005435163169	29525	20	21A
0005435163181	29525	21	21C
0005435933452	29525	22	22B
0005435163180	29525	23	22C
0005435933451	29525	24	22D
0005435163198	29525	25	23A
0005435933448	29525	26	23B
0005435797463	2884	1	1A
0005433404774	2884	2	1F
0005435797467	2884	3	3A
0005435797453	2884	4	3F
0005435797464	2884	5	4F
0005433404762	2884	6	5D
0005435797458	2884	7	6E
0005435797454	2884	8	7C
0005435797457	2884	9	7E
0005433404754	2884	10	9A
0005433404753	2884	11	10E
0005435797462	2884	12	11F
0005435797461	2884	13	12D
0005433404729	2884	14	14D
0005435797456	2884	15	14E
0005435797459	2884	16	16A
0005435797466	2884	17	16C
0005435797455	2884	18	18D
0005433404722	2884	19	18E
0005435797465	2884	20	19C
0005435797460	2884	21	19E
0005435797364	29337	1	2F
0005433404798	29337	2	4F
0005435797348	29337	3	5F
0005433404799	29337	4	6E
0005435797339	29337	5	8F
0005435797378	29337	6	9F
0005435797370	29337	7	11A
0005433404803	29337	8	11C
0005433404800	29337	9	11D
0005435797346	29337	10	11E
0005433404802	29337	11	12F
0005435797389	29337	12	13A
0005435797365	29337	13	15C
0005435797271	29337	14	16C
0005435797371	29337	15	16D
0005435797350	29337	16	18C
0005433404805	29337	17	19C
0005433404801	29337	18	19D
0005433404804	29337	19	19E
0005435797351	29337	20	20F
0005435376334	5799	1	1A
0005435376330	5799	2	1B
0005435376329	5799	3	5B
0005435376335	5799	4	5A
0005435376333	5799	5	6A
0005434948011	5800	1	1B
0005434948015	5800	2	2A
0005434948016	5800	3	2B
0005434948017	5800	4	4A
0005434948012	5800	5	3B
0005434948009	5800	6	4B
0005434948010	5800	7	5A
0005434948014	5800	8	5B
0005434948013	5800	9	6A
0005434948018	5800	10	6B
0005434947950	16361	1	1A
0005434947938	16361	2	1B
0005434947953	16361	3	2B
0005434947951	16361	4	3B
0005434947915	16361	5	4A
0005434947945	16361	6	4B
0005434947952	16361	7	5A
0005434947946	16361	8	5B
0005434947924	16361	9	6A
0005434947949	16361	10	6B
0005433960831	6861	1	1C
0005433960813	6861	2	1D
0005433960803	6861	3	2A
0005433960799	6861	4	2C
0005433960842	6861	5	2D
0005433960840	6861	6	3A
0005433960819	6861	7	3D
0005433960795	6861	8	3F
0005433960802	6861	9	4A
0005433960843	6861	10	4E
0005433960797	6861	11	4F
0005433960821	6861	12	5C
0005433960793	6861	13	5D
0005433960814	6861	14	5E
0005433960841	6861	15	6A
0005433960838	6861	16	6C
0005433960844	6861	17	6E
0005433960800	6861	18	7E
0005433960829	6861	19	7F
0005433960807	6861	20	8A
0005433960805	6861	21	8C
0005433960836	6861	22	8D
0005433960818	6861	23	8E
0005433960804	6861	24	8F
0005433960822	6861	25	9A
0005433960848	6861	26	9C
0005433960826	6861	27	9D
0005433960794	6861	28	9F
0005433960833	6861	29	10A
0005433960832	6861	30	10F
0005433960849	6861	31	11A
0005433960816	6861	32	11E
0005433960809	6861	33	12A
0005433960827	6861	34	12E
0005433960806	6861	35	12F
0005433960815	6861	36	13A
0005433960846	6861	37	13C
0005433960828	6861	38	13D
0005433960837	6861	39	14A
0005433960817	6861	40	14D
0005433960839	6861	41	14E
0005433960811	6861	42	15A
0005433960812	6861	43	15C
0005433960808	6861	44	15D
0005433960796	6861	45	15F
0005433960820	6861	46	16A
0005433960825	6861	47	16E
0005433960830	6861	48	16F
0005433960824	6861	49	17D
0005433960834	6861	50	18A
0005433960798	6861	51	18D
0005433960823	6861	52	18E
0005433960801	6861	53	19A
0005433960810	6861	54	19D
0005433960835	6861	55	19F
0005433960847	6861	56	20A
0005433960850	6861	57	20D
0005433960845	6861	58	20E
0005433960203	25734	1	1A
0005433960081	25734	2	1C
0005433960194	25734	3	1D
0005433960062	25734	4	1F
0005433960132	25734	5	2D
0005433959856	25734	6	3C
0005433960161	25734	7	3D
0005433959983	25734	8	3F
0005433960064	25734	9	4A
0005433960065	25734	10	4D
0005433959998	25734	11	4F
0005433960097	25734	12	5A
0005433960175	25734	13	5D
0005433960047	25734	14	5F
0005433959858	25734	15	6A
0005433960169	25734	16	6D
0005433960052	25734	17	6E
0005433960221	25734	18	6F
0005433960126	25734	19	7A
0005433960184	25734	20	7C
0005433960218	25734	21	7D
0005433960207	25734	22	7F
0005433960181	25734	23	8A
0005433960164	25734	24	8C
0005433960133	25734	25	8E
0005433960205	25734	26	8F
0005433960154	25734	27	9A
0005433960202	25734	28	9C
0005433960008	25734	29	9D
0005433960183	25734	30	9F
0005433959991	25734	31	10C
0005433960029	25734	32	10D
0005433960048	25734	33	10F
0005433960123	25734	34	11A
0005433960085	25734	35	11C
0005433960206	25734	36	11D
0005433960091	25734	37	11E
0005433960086	25734	38	11F
0005433960049	25734	39	12A
0005433960198	25734	40	12D
0005433960099	25734	41	12E
0005433960174	25734	42	12F
0005433960098	25734	43	13A
0005433960139	25734	44	13C
0005433960067	25734	45	13D
0005433960054	25734	46	13E
0005433960088	25734	47	13F
0005433960127	25734	48	14A
0005433959997	25734	49	14C
0005433960196	25734	50	14D
0005433960100	25734	51	14E
0005433960153	25734	52	14F
0005433960178	25734	53	15A
0005433960117	25734	54	15C
0005433960199	25734	55	15D
0005433960211	25734	56	15F
0005433960055	25734	57	16F
0005433959857	25734	58	17E
0005433959892	25734	59	17F
0005433960193	25734	60	18A
0005433960173	25734	61	18C
0005433960120	25734	62	18D
0005433960082	25734	63	18E
0005433960172	25734	64	19C
0005433960168	25734	65	19D
0005433960179	25734	66	19E
0005433960162	25734	67	20A
0005433960222	25734	68	20D
0005433960134	25734	69	20E
0005435082714	24524	1	1A
0005435082684	24524	2	1B
0005435082688	24524	3	3B
0005435082689	24524	4	4A
0005435082708	24524	5	5A
0005435082706	24524	6	6A
0005435082722	24524	7	5B
0005435082707	24524	8	6B
0005435082774	26066	1	1A
0005435082777	26066	2	2A
0005435082772	26066	3	2B
0005435082771	26066	4	3A
0005435082773	26066	5	3B
0005435082776	26066	6	4B
0005435082775	26066	7	5B
0005434244946	5143	1	1A
0005434244962	5143	2	1F
0005435286578	5143	3	2D
0005434244942	5143	4	3C
0005434244938	5143	5	6D
0005434244935	5143	6	7C
0005434244944	5143	7	8C
0005434244952	5143	8	9A
0005434244958	5143	9	9C
0005434244964	5143	10	9D
0005434244936	5143	11	10B
0005434244950	5143	12	10C
0005433534472	5143	13	10E
0005434244945	5143	14	10F
0005434244940	5143	15	12E
0005434244954	5143	16	12F
0005434244953	5143	17	14B
0005434244939	5143	18	15A
0005434244960	5143	19	15D
0005434244955	5143	20	16D
0005434244948	5143	21	16F
0005434244943	5143	22	17C
0005434244956	5143	23	18A
0005433534485	5143	24	18B
0005434244941	5143	25	20C
0005434244947	5143	26	20E
0005434244951	5143	27	21B
0005435286572	5143	28	21A
0005434244963	5143	29	23A
0005432166899	5143	30	24B
0005434244961	5143	31	24E
0005432166898	5143	32	25C
0005434244937	5143	33	25E
0005435286571	5143	34	26D
0005434244957	5143	35	27F
0005434244959	5143	36	28A
0005434244949	5143	37	29D
0005432105543	5146	1	1C
0005432667451	5146	2	1A
0005432105499	5146	3	1D
0005432105501	5146	4	1F
0005433614654	5146	5	2C
0005433614589	5146	6	2A
0005433784904	5146	7	2F
0005432105530	5146	8	2D
0005432105527	5146	9	3A
0005433784901	5146	10	3C
0005433614642	5146	11	3D
0005433614626	5146	12	4A
0005432105523	5146	13	3F
0005433614623	5146	14	4D
0005433614611	5146	15	4C
0005432105503	5146	16	4F
0005432105540	5146	17	5A
0005433614634	5146	18	5C
0005432105537	5146	19	5D
0005432105502	5146	20	6A
0005433614639	5146	21	5F
0005433614644	5146	22	6D
0005433784921	5146	23	6C
0005433614635	5146	24	6F
0005432105519	5146	25	7A
0005433614649	5146	26	7D
0005433614601	5146	27	7C
0005433614641	5146	28	7F
0005433784891	5146	29	8A
0005432105500	5146	30	8B
0005433614625	5146	31	8D
0005433784905	5146	32	8C
0005433614620	5146	33	8E
0005433784907	5146	34	9A
0005433614610	5146	35	8F
0005432105528	5146	36	9B
0005433784908	5146	37	9C
0005432666385	5146	38	9D
0005433614621	5146	39	9F
0005432105541	5146	40	9E
0005432105522	5146	41	10A
0005432667452	5146	42	10C
0005432105532	5146	43	10B
0005433614616	5146	44	10D
0005433614657	5146	45	10E
0005433614658	5146	46	10F
0005433784896	5146	47	11B
0005433614614	5146	48	11A
0005432105507	5146	49	11C
0005432105514	5146	50	11D
0005432105533	5146	51	11E
0005433784897	5146	52	12A
0005433614608	5146	53	11F
0005433614655	5146	54	12B
0005433614653	5146	55	12D
0005433784893	5146	56	12C
0005433614619	5146	57	12F
0005433614650	5146	58	12E
0005432105531	5146	59	13A
0005433784915	5146	60	13C
0005433614640	5146	61	13B
0005433614651	5146	62	13D
0005433784913	5146	63	13E
0005433784898	5146	64	14A
0005432105498	5146	65	13F
0005433614631	5146	66	14B
0005433614637	5146	67	14C
0005433614613	5146	68	14E
0005432105520	5146	69	14D
0005433784912	5146	70	15A
0005432105497	5146	71	14F
0005432105512	5146	72	15C
0005433784894	5146	73	15B
0005432145110	5146	74	15D
0005433614606	5146	75	15E
0005433784892	5146	76	16A
0005432665272	5146	77	15F
0005433784916	5146	78	16B
0005433614648	5146	79	16C
0005433614590	5146	80	16E
0005433784887	5146	81	16D
0005433614587	5146	82	16F
0005432105529	5146	83	17B
0005433614603	5146	84	17A
0005433614617	5146	85	17C
0005433614607	5146	86	17D
0005433614598	5146	87	17E
0005433614638	5146	88	18A
0005432105510	5146	89	17F
0005433614596	5146	90	18B
0005433614647	5146	91	18C
0005432105509	5146	92	18E
0005433614594	5146	93	18D
0005432105521	5146	94	18F
0005433784919	5146	95	19B
0005432105524	5146	96	19D
0005433784911	5146	97	19C
0005433614609	5146	98	19E
0005433784922	5146	99	20B
0005433614602	5146	100	20A
0005433784900	5146	101	20C
0005432105518	5146	102	20D
0005432105536	5146	103	20E
0005432105504	5146	104	21A
0005432105517	5146	105	20F
0005433614627	5146	106	21B
0005433614605	5146	107	21C
0005433614604	5146	108	21E
0005432105496	5146	109	21D
0005432105542	5146	110	21F
0005433784923	5146	111	22B
0005433614656	5146	112	22A
0005432105508	5146	113	22C
0005432105513	5146	114	22E
0005432105538	5146	115	22F
0005433784917	5146	116	23B
0005433614618	5146	117	23A
0005433614629	5146	118	23D
0005433614652	5146	119	23C
0005432105539	5146	120	23E
0005433614588	5146	121	24A
0005433614628	5146	122	23F
0005433614643	5146	123	24B
0005433614630	5146	124	24C
0005433614595	5146	125	24E
0005432666386	5146	126	24D
0005433784903	5146	127	24F
0005432105526	5146	128	25A
0005433784890	5146	129	25C
0005433614636	5146	130	25B
0005433614624	5146	131	25D
0005433614646	5146	132	25F
0005433614599	5146	133	25E
0005433614593	5146	134	26B
0005433614591	5146	135	26A
0005432105505	5146	136	26C
0005432666387	5146	137	26E
0005433614586	5146	138	26D
0005433614600	5146	139	26F
0005433614622	5146	140	27A
0005433784888	5146	141	27C
0005433784914	5146	142	27B
0005432105544	5146	143	27D
0005432105506	5146	144	27F
0005433784895	5146	145	27E
0005433784902	5146	146	28A
0005433614597	5146	147	28C
0005433784910	5146	148	28B
0005433784920	5146	149	28E
0005433784899	5146	150	28D
0005432105534	5146	151	29A
0005433614612	5146	152	28F
0005433784889	5146	153	29B
0005432105515	5146	154	29C
0005433614615	5146	155	29D
0005432105516	5146	156	29F
0005433614633	5146	157	29E
0005433784918	5146	158	30A
0005433614585	5146	159	30B
0005432105525	5146	160	30D
0005433784906	5146	161	30C
0005433784909	5146	162	30E
0005433614584	5146	163	30F
0005432105495	5146	164	31A
0005433614632	5146	165	31C
0005432105511	5146	166	31B
0005433614645	5146	167	31D
0005432105535	5146	168	31F
0005433614592	5146	169	31E
0005435006742	5149	1	1C
0005434265105	5149	2	1F
0005435006773	5149	3	2A
0005434265108	5149	4	2C
0005435006903	5149	5	2F
0005434265118	5149	6	3A
0005434265120	5149	7	3C
0005435006839	5149	8	3F
0005433688794	5149	9	4A
0005432335900	5149	10	4C
0005434265112	5149	11	4F
0005435006934	5149	12	4D
0005434149718	5149	13	5F
0005434229341	5149	14	5D
0005435006766	5149	15	6C
0005432335907	5149	16	6A
0005434229353	5149	17	6F
0005434149723	5149	18	6D
0005435006838	5149	19	7A
0005434229340	5149	20	7D
0005434265100	5149	21	7C
0005434265115	5149	22	7F
0005432335956	5149	23	8A
0005434173517	5149	24	8B
0005432335924	5149	25	8C
0005434229342	5149	26	8E
0005434311196	5149	27	8F
0005434229346	5149	28	9A
0005434229356	5149	29	9B
0005434229338	5149	30	9D
0005433688793	5149	31	9E
0005434265099	5149	32	10B
0005432335988	5149	33	10D
0005433815339	5149	34	10E
0005433688786	5149	35	10F
0005432335888	5149	36	11B
0005434229345	5149	37	11D
0005435006812	5149	38	11F
0005433685497	5149	39	11E
0005434265110	5149	40	12A
0005434229355	5149	41	12B
0005434149713	5149	42	12D
0005434311195	5149	43	12C
0005432335923	5149	44	12E
0005435006945	5149	45	13A
0005435006746	5149	46	13D
0005434265124	5149	47	13F
0005434229350	5149	48	13E
0005434265123	5149	49	14B
0005434149715	5149	50	14D
0005432335895	5149	51	14C
0005434149714	5149	52	14E
0005433685496	5149	53	15B
0005434265101	5149	54	15A
0005432335887	5149	55	15C
0005434229337	5149	56	15E
0005434265102	5149	57	15D
0005434265114	5149	58	16A
0005435006710	5149	59	16B
0005432335905	5149	60	17A
0005434173515	5149	61	16F
0005434149717	5149	62	17B
0005435006782	5149	63	17C
0005432335901	5149	64	17D
0005435006797	5149	65	17F
0005432335913	5149	66	17E
0005434149722	5149	67	18A
0005435006853	5149	68	18D
0005434265104	5149	69	18E
0005432335889	5149	70	18F
0005433815324	5149	71	19C
0005434265122	5149	72	19B
0005434265109	5149	73	19D
0005434229339	5149	74	20B
0005435006801	5149	75	20C
0005434229357	5149	76	20F
0005434229349	5149	77	21B
0005434229348	5149	78	21A
0005434229351	5149	79	21C
0005435006779	5149	80	21D
0005435006747	5149	81	21F
0005432335909	5149	82	21E
0005435006820	5149	83	22B
0005435006717	5149	84	22A
0005434229358	5149	85	22D
0005435006819	5149	86	22F
0005435006811	5149	87	23A
0005434265107	5149	88	23B
0005434265117	5149	89	23D
0005433688788	5149	90	23C
0005434265116	5149	91	23E
0005434265121	5149	92	24A
0005435006869	5149	93	23F
0005433815313	5149	94	24B
0005433688789	5149	95	24C
0005435006780	5149	96	24E
0005432335861	5149	97	24D
0005435006748	5149	98	25A
0005435006904	5149	99	25B
0005435006879	5149	100	25D
0005434149716	5149	101	25F
0005434229344	5149	102	25E
0005434265113	5149	103	26B
0005434149719	5149	104	26D
0005434149724	5149	105	26F
0005432335942	5149	106	26E
0005434229354	5149	107	27A
0005433685495	5149	108	27C
0005434173514	5149	109	27D
0005433815312	5149	110	27F
0005434229352	5149	111	27E
0005434311201	5149	112	28A
0005435006937	5149	113	28B
0005435006772	5149	114	28D
0005434265103	5149	115	28C
0005434229347	5149	116	28E
0005434173516	5149	117	29A
0005434149720	5149	118	28F
0005435006870	5149	119	29C
0005432335906	5149	120	29B
0005435006708	5149	121	29D
0005434229343	5149	122	29E
0005435006804	5149	123	30C
0005435006805	5149	124	30D
0005434311194	5149	125	30F
0005434265111	5149	126	31A
0005434265106	5149	127	31C
0005435006938	5149	128	31D
0005434265119	5149	129	31F
0005434149721	5149	130	31E
0005433784735	8445	1	1A
0005433784609	8445	2	1F
0005433784497	8445	3	1D
0005433784739	8445	4	2A
0005433784657	8445	5	2D
0005433784736	8445	6	4A
0005433784707	8445	7	4C
0005433784594	8445	8	5C
0005433784706	8445	9	6F
0005433784613	8445	10	7A
0005433784690	8445	11	7C
0005434244652	8445	12	7D
0005434244732	8445	13	8B
0005434244800	8445	14	8C
0005433784658	8445	15	9B
0005433784456	8445	16	10A
0005433784530	8445	17	10B
0005434244799	8445	18	10C
0005434244839	8445	19	10E
0005433784600	8445	20	10F
0005433784692	8445	21	11B
0005433784591	8445	22	11C
0005433784691	8445	23	11D
0005433784607	8445	24	11F
0005433784582	8445	25	12C
0005433784553	8445	26	12D
0005434244669	8445	27	12F
0005434244769	8445	28	13C
0005432663019	8445	29	13D
0005433784671	8445	30	13E
0005432659687	8445	31	14B
0005433784485	8445	32	14C
0005433784508	8445	33	14D
0005433784606	8445	34	15A
0005433784664	8445	35	15E
0005433784577	8445	36	16A
0005433784659	8445	37	16D
0005432659684	8445	38	17A
0005433784643	8445	39	17C
0005434244803	8445	40	17E
0005433784562	8445	41	18D
0005433784580	8445	42	19D
0005432659686	8445	43	20B
0005433784731	8445	44	20D
0005433784642	8445	45	21A
0005433784637	8445	46	21C
0005434244678	8445	47	21E
0005434244658	8445	48	22C
0005432659688	8445	49	22D
0005434244884	8445	50	22F
0005433784608	8445	51	23B
0005433784506	8445	52	23A
0005433784507	8445	53	24C
0005434244657	8445	54	24E
0005434244659	8445	55	25B
0005433784734	8445	56	26A
0005433784584	8445	57	26B
0005433784531	8445	58	26E
0005433784595	8445	59	27C
0005433784488	8445	60	27B
0005433784626	8445	61	27D
0005434244755	8445	62	28C
0005433784700	8445	63	29F
0005434244765	8445	64	29E
0005433784563	8445	65	30A
0005434244766	8445	66	30D
0005434244733	8445	67	30F
0005432666365	8445	68	31D
0005433784579	8445	69	31F
0005433613937	8446	1	1C
0005433613987	8446	2	1A
0005433613614	8446	3	2A
0005433613903	8446	4	3A
0005433613637	8446	5	3C
0005433614003	8446	6	4C
0005433613798	8446	7	5A
0005433613747	8446	8	5F
0005433613958	8446	9	7F
0005433614054	8446	10	8A
0005433614199	8446	11	8C
0005433613869	8446	12	8F
0005433613951	8446	13	9F
0005433613939	8446	14	10D
0005433614114	8446	15	10F
0005433614004	8446	16	11D
0005433613748	8446	17	11F
0005433613952	8446	18	12B
0005433613885	8446	19	12F
0005433613746	8446	20	13C
0005433613706	8446	21	14A
0005433613955	8446	22	15A
0005433614144	8446	23	14F
0005433613443	8446	24	15D
0005433614426	8446	25	15F
0005433614043	8446	26	16B
0005433613626	8446	27	16D
0005433614126	8446	28	16C
0005433614044	8446	29	16E
0005433613913	8446	30	16F
0005433613859	8446	31	17C
0005433613819	8446	32	18A
0005433613887	8446	33	18B
0005433613840	8446	34	18D
0005433613940	8446	35	18F
0005433613922	8446	36	19C
0005433614010	8446	37	19E
0005433613930	8446	38	20C
0005433613898	8446	39	20D
0005433613989	8446	40	20F
0005433613899	8446	41	21B
0005433613912	8446	42	21C
0005433613874	8446	43	21E
0005433614005	8446	44	22A
0005433614173	8446	45	21F
0005433613847	8446	46	22D
0005433613835	8446	47	23D
0005433613938	8446	48	23E
0005433613875	8446	49	24A
0005433614016	8446	50	23F
0005433614146	8446	51	24B
0005433613854	8446	52	24E
0005433613591	8446	53	24F
0005433613960	8446	54	25C
0005433614063	8446	55	26A
0005433614145	8446	56	25F
0005433613902	8446	57	26B
0005433613613	8446	58	26D
0005433614056	8446	59	26F
0005433614009	8446	60	27A
0005433613901	8446	61	27C
0005433613794	8446	62	27B
0005433613444	8446	63	28A
0005433614110	8446	64	27F
0005433613407	8446	65	28B
0005433614131	8446	66	28C
0005433613627	8446	67	28E
0005433614172	8446	68	29B
0005433613776	8446	69	29F
0005433613638	8446	70	30E
0005433613929	8446	71	30D
0005433614042	8446	72	30F
0005433613984	8446	73	31E
0005434264930	8447	1	1C
0005432034925	8447	2	1D
0005432336018	8447	3	2A
0005434264906	8447	4	1F
0005434149622	8447	5	2C
0005432034930	8447	6	2F
0005432336016	8447	7	2D
0005432047547	8447	8	3A
0005435007015	8447	9	3C
0005434264853	8447	10	3F
0005435007002	8447	11	3D
0005435006997	8447	12	4A
0005432336025	8447	13	4C
0005434229172	8447	14	4F
0005435007012	8447	15	4D
0005435007011	8447	16	5A
0005432034931	8447	17	5F
0005434229191	8447	18	5D
0005434173481	8447	19	6A
0005432034921	8447	20	6F
0005434149612	8447	21	6D
0005434229149	8447	22	7A
0005435286627	8447	23	7C
0005434229159	8447	24	7F
0005433689909	8447	25	7D
0005433815383	8447	26	8A
0005434264881	8447	27	8C
0005432034917	8447	28	8B
0005434149621	8447	29	8E
0005434264882	8447	30	8D
0005434229148	8447	31	8F
0005432034922	8447	32	9B
0005435007014	8447	33	9A
0005432034906	8447	34	9C
0005435007004	8447	35	9D
0005434173484	8447	36	9F
0005432034907	8447	37	9E
0005433534495	8447	38	10A
0005434311217	8447	39	10B
0005435007017	8447	40	10D
0005433689908	8447	41	10C
0005434229162	8447	42	10F
0005434264786	8447	43	11A
0005434264921	8447	44	11C
0005432336026	8447	45	11B
0005434229108	8447	46	11D
0005434229186	8447	47	11E
0005432034927	8447	48	12A
0005432034929	8447	49	12B
0005434173467	8447	50	12D
0005432336020	8447	51	12C
0005434229203	8447	52	12E
0005432336022	8447	53	12F
0005434265007	8447	54	13B
0005434229136	8447	55	13A
0005432034915	8447	56	13C
0005432034918	8447	57	13D
0005434149664	8447	58	13F
0005435007018	8447	59	13E
0005433688808	8447	60	14A
0005434229157	8447	61	14C
0005432336017	8447	62	14B
0005435007006	8447	63	14D
0005435006996	8447	64	14E
0005435007001	8447	65	14F
0005434149595	8447	66	15B
0005433815382	8447	67	15A
0005432034912	8447	68	15C
0005432034926	8447	69	15E
0005434149643	8447	70	15D
0005432047545	8447	71	15F
0005435007008	8447	72	16A
0005434264755	8447	73	16B
0005433688809	8447	74	16D
0005433815380	8447	75	16F
0005434149663	8447	76	16E
0005435007013	8447	77	17B
0005434229208	8447	78	17A
0005432034910	8447	79	17C
0005432336021	8447	80	17D
0005432034916	8447	81	17E
0005434229062	8447	82	18A
0005433815381	8447	83	17F
0005434229155	8447	84	18B
0005434311216	8447	85	18D
0005434264901	8447	86	18E
0005434264902	8447	87	18F
0005432034905	8447	88	19B
0005434149618	8447	89	19D
0005434229173	8447	90	19C
0005432336023	8447	91	19E
0005434229130	8447	92	20B
0005434149656	8447	93	20A
0005434149599	8447	94	20C
0005432336027	8447	95	20D
0005433689910	8447	96	20F
0005435006998	8447	97	20E
0005434149665	8447	98	21B
0005434264825	8447	99	21A
0005434264836	8447	100	21D
0005435286625	8447	101	21F
0005435007003	8447	102	21E
0005435286626	8447	103	22A
0005434229121	8447	104	22B
0005433690926	8447	105	22D
0005432034909	8447	106	22C
0005434264905	8447	107	22E
0005432034924	8447	108	22F
0005432034919	8447	109	23A
0005432336019	8447	110	23B
0005434173482	8447	111	23D
0005434229156	8447	112	23E
0005435007019	8447	113	23F
0005434264955	8447	114	24B
0005434149642	8447	115	24A
0005433690925	8447	116	24C
0005432034928	8447	117	24D
0005432047546	8447	118	24E
0005435286624	8447	119	25B
0005434264851	8447	120	25A
0005434264904	8447	121	25D
0005435007010	8447	122	25C
0005432034923	8447	123	25E
0005432034908	8447	124	26A
0005435007016	8447	125	25F
0005435006999	8447	126	26B
0005434229041	8447	127	26D
0005432336024	8447	128	26C
0005434229260	8447	129	26F
0005435007007	8447	130	26E
0005433534496	8447	131	27A
0005432034913	8447	132	27B
0005434264852	8447	133	27D
0005434264917	8447	134	27C
0005432034911	8447	135	27E
0005434264931	8447	136	28A
0005432034920	8447	137	27F
0005435007000	8447	138	28B
0005432034914	8447	139	28C
0005434149596	8447	140	28E
0005434229259	8447	141	28D
0005434264922	8447	142	29A
0005434229170	8447	143	28F
0005435007009	8447	144	29B
0005432336028	8447	145	29D
0005435006995	8447	146	29C
0005435007020	8447	147	29F
0005434265008	8447	148	30B
0005432034933	8447	149	30A
0005432034932	8447	150	30C
0005434229042	8447	151	30E
0005435007005	8447	152	30D
0005434229235	8447	153	31B
0005434264831	8447	154	31A
0005434264934	8447	155	31E
0005434264866	8447	156	31D
0005434639161	12641	1	1A
0005433202351	12641	2	1B
0005433202348	12641	3	1D
0005434639048	12641	4	2C
0005433202346	12641	5	2D
0005434639041	12641	6	3A
0005434639042	12641	7	3B
0005433202352	12641	8	3C
0005433202347	12641	9	3D
0005433202354	12641	10	4A
0005434639009	12641	11	4B
0005434639160	12641	12	4C
0005434638974	12641	13	4D
0005433202349	12641	14	5A
0005434639182	12641	15	5B
0005433202357	12641	16	5C
0005434638955	12641	17	6A
0005434639002	12641	18	6C
0005433202344	12641	19	7A
0005433202345	12641	20	7B
0005434639133	12641	21	7C
0005434639006	12641	22	7D
0005434638994	12641	23	18A
0005433202356	12641	24	18B
0005434639150	12641	25	19A
0005434638972	12641	26	19C
0005433202350	12641	27	19D
0005434639043	12641	28	20A
0005434638941	12641	29	20B
0005433202343	12641	30	20C
0005434638999	12641	31	20D
0005434638906	12641	32	21B
0005434638973	12641	33	21C
0005434639085	12641	34	21D
0005433202353	12641	35	22A
0005434639151	12641	36	22C
0005434638890	12641	37	22D
0005434639050	12641	38	23A
0005433202355	12641	39	23B
0005434639287	23351	1	1A
0005434639284	23351	2	1B
0005434639270	23351	3	1C
0005432290627	23351	4	2A
0005434639285	23351	5	2B
0005433202135	23351	6	2C
0005434639282	23351	7	2D
0005434639267	23351	8	3A
0005434639266	23351	9	3B
0005434639272	23351	10	3C
0005434639269	23351	11	3D
0005433202218	23351	12	4A
0005433202183	23351	13	4B
0005433202159	23351	14	5A
0005433202217	23351	15	5B
0005433202178	23351	16	5C
0005433202174	23351	17	5D
0005434639273	23351	18	6A
0005434639283	23351	19	6B
0005433202123	23351	20	6C
0005433202168	23351	21	6D
0005433202236	23351	22	7A
0005433202207	23351	23	7B
0005434639271	23351	24	7C
0005433202186	23351	25	7D
0005432290628	23351	26	18B
0005433202227	23351	27	18C
0005434639274	23351	28	18D
0005434639275	23351	29	19A
0005433202169	23351	30	19B
0005434639278	23351	31	19C
0005434639265	23351	32	19D
0005434639268	23351	33	20A
0005434639276	23351	34	20B
0005434639279	23351	35	20C
0005434639286	23351	36	20D
0005434639281	23351	37	21B
0005433202177	23351	38	21C
0005434639280	23351	39	21D
0005434639277	23351	40	22A
0005433202191	23351	41	22B
0005433202160	23351	42	22C
0005433202165	23351	43	22D
0005432290626	23351	44	23A
0005433202136	23351	45	23B
0005432327920	21067	1	1A
0005432382812	21067	2	1C
0005432382874	21067	3	1D
0005432382876	21067	4	1F
0005432382734	21067	5	2A
0005432328138	21067	6	2C
0005432382702	21067	7	2D
0005432328199	21067	8	2F
0005432382785	21067	9	3A
0005432382719	21067	10	3C
0005432382798	21067	11	3D
0005432328172	21067	12	3F
0005432382695	21067	13	4A
0005432382792	21067	14	4C
0005432328214	21067	15	4D
0005432382794	21067	16	4F
0005432382713	21067	17	5A
0005432328315	21067	18	5D
0005432382878	21067	19	5F
0005432328243	21067	20	6A
0005432382782	21067	21	6D
0005432382880	21067	22	6E
0005432328306	21067	23	6F
0005432328159	21067	24	7A
0005432328305	21067	25	7C
0005432382815	21067	26	7D
0005432382811	21067	27	7E
0005432382783	21067	28	7F
0005432382718	21067	29	8A
0005432328208	21067	30	8D
0005432328304	21067	31	8F
0005432328205	21067	32	9A
0005432382799	21067	33	9C
0005432328171	21067	34	9D
0005432328176	21067	35	9E
0005432328286	21067	36	10A
0005432382910	21067	37	10C
0005432328158	21067	38	10D
0005432382875	21067	39	10E
0005432382666	21067	40	10F
0005432328173	21067	41	11A
0005432382906	21067	42	11C
0005432328285	21067	43	11D
0005432382837	21067	44	11F
0005432382786	21067	45	12A
0005432328119	21067	46	12C
0005432382709	21067	47	12D
0005432382793	21067	48	12E
0005432328303	21067	49	12F
0005432382757	21067	50	13A
0005432382710	21067	51	13C
0005432382694	21067	52	13D
0005432382865	21067	53	13E
0005432382647	21067	54	13F
0005432382696	21067	55	14C
0005432382741	21067	56	14D
0005432382877	21067	57	14E
0005432054302	21067	58	14F
0005432382584	21067	59	15A
0005432328200	21067	60	15C
0005432328244	21067	61	15D
0005432328288	21067	62	15E
0005432382735	21067	63	15F
0005432382646	21067	64	16A
0005432328229	21067	65	16D
0005432382665	21067	66	16C
0005432054300	21067	67	16E
0005432054301	21067	68	16F
0005432382818	21067	69	17A
0005432328177	21067	70	17C
0005432382740	21067	71	17D
0005432382767	21067	72	17E
0005432328139	21067	73	18A
0005432328160	21067	74	18C
0005432328384	21067	75	18D
0005432328178	21067	76	18E
0005432382731	21067	77	18F
0005432328213	21067	78	19A
0005432328198	21067	79	19C
0005432382739	21067	80	19D
0005432328329	21067	81	19E
0005432328187	21067	82	19F
0005432382857	21067	83	20A
0005432328201	21067	84	20C
0005432328102	21067	85	20D
0005432328203	21067	86	20F
0005432383124	31237	1	1A
0005432383105	31237	2	1C
0005432328638	31237	3	1D
0005432383117	31237	4	1F
0005432383123	31237	5	2C
0005432328617	31237	6	2D
0005432328608	31237	7	3C
0005432328603	31237	8	3D
0005432383109	31237	9	3F
0005432383102	31237	10	4A
0005432328598	31237	11	4C
0005432328627	31237	12	4D
0005432328602	31237	13	4E
0005432328630	31237	14	4F
0005432383098	31237	15	5A
0005432328614	31237	16	5C
0005432287181	31237	17	5D
0005432383114	31237	18	5E
0005432383106	31237	19	5F
0005432328609	31237	20	6D
0005432328625	31237	21	6E
0005432383115	31237	22	6F
0005432328641	31237	23	7A
0005432328619	31237	24	7C
0005432328624	31237	25	7D
0005432383127	31237	26	7E
0005432287179	31237	27	7F
0005432328632	31237	28	8A
0005432383120	31237	29	8C
0005432328636	31237	30	8E
0005432383126	31237	31	8F
0005432383122	31237	32	9A
0005432383096	31237	33	9C
0005432383112	31237	34	9D
0005432328596	31237	35	9E
0005432328597	31237	36	9F
0005432328611	31237	37	10A
0005432383118	31237	38	10C
0005432328623	31237	39	10D
0005432383103	31237	40	10E
0005432328595	31237	41	10F
0005432328634	31237	42	11A
0005432287182	31237	43	11C
0005432328600	31237	44	11D
0005432383099	31237	45	11E
0005432328640	31237	46	12A
0005432328616	31237	47	12C
0005432328612	31237	48	12D
0005432383128	31237	49	12E
0005432328613	31237	50	12F
0005432328605	31237	51	13A
0005432328604	31237	52	13C
0005432328618	31237	53	13D
0005432383104	31237	54	13E
0005432287183	31237	55	13F
0005432328610	31237	56	14A
0005432328639	31237	57	14C
0005432328635	31237	58	14D
0005432383116	31237	59	14E
0005432328606	31237	60	14F
0005432328599	31237	61	15A
0005432383095	31237	62	15D
0005432328620	31237	63	15E
0005432328637	31237	64	15F
0005432383121	31237	65	16A
0005432328631	31237	66	16C
0005432383125	31237	67	16D
0005432383113	31237	68	16E
0005432328622	31237	69	16F
0005432383119	31237	70	17A
0005432287180	31237	71	17C
0005432287178	31237	72	17D
0005432383111	31237	73	17E
0005432328633	31237	74	17F
0005432383100	31237	75	18C
0005432328628	31237	76	18D
0005432328601	31237	77	18F
0005432328629	31237	78	19A
0005432383107	31237	79	19C
0005432383101	31237	80	19D
0005432328626	31237	81	19E
0005432383110	31237	82	19F
0005432383097	31237	83	20A
0005432328615	31237	84	20C
0005432328621	31237	85	20D
0005432328607	31237	86	20E
0005432383108	31237	87	20F
0005433642308	2477	1	1A
0005433642319	2477	2	2A
0005433642326	2477	3	2C
0005433642306	2477	4	3D
0005432953815	2477	5	3F
0005432953817	2477	6	4C
0005433642312	2477	7	4D
0005432953812	2477	8	4E
0005432953848	2477	9	4F
0005432953839	2477	10	5A
0005433642314	2477	11	5C
0005432953846	2477	12	5D
0005433642317	2477	13	6A
0005432953788	2477	14	6D
0005433642305	2477	15	6E
0005432953838	2477	16	6F
0005432953820	2477	17	7A
0005433642320	2477	18	7F
0005432953867	2477	19	8A
0005433642316	2477	20	8D
0005432953796	2477	21	8F
0005432953825	2477	22	9C
0005432953842	2477	23	9D
0005432953831	2477	24	9F
0005432953843	2477	25	10A
0005433642332	2477	26	10C
0005432953869	2477	27	10D
0005433642309	2477	28	10E
0005433642324	2477	29	10F
0005432953814	2477	30	11A
0005433642310	2477	31	11D
0005433642318	2477	32	11E
0005433642333	2477	33	11F
0005433642323	2477	34	12C
0005433642304	2477	35	12E
0005433642327	2477	36	12F
0005432953866	2477	37	13A
0005433642311	2477	38	13D
0005432953787	2477	39	13F
0005433642321	2477	40	14C
0005432953795	2477	41	14D
0005433642329	2477	42	14E
0005432953816	2477	43	15C
0005432953868	2477	44	15D
0005433642322	2477	45	15E
0005433642334	2477	46	16A
0005433642313	2477	47	16D
0005433642330	2477	48	16F
0005433642315	2477	49	17A
0005432953826	2477	50	17C
0005433642328	2477	51	17E
0005432953844	2477	52	19C
0005433642307	2477	53	19D
0005432953845	2477	54	19E
0005432953824	2477	55	19F
0005433642325	2477	56	20A
0005432953847	2477	57	20C
0005433642331	2477	58	20D
0005432953813	2477	59	20F
0005433642122	27588	1	1A
0005433642176	27588	2	1C
0005433642146	27588	3	1D
0005433642193	27588	4	1F
0005433642154	27588	5	2A
0005433642235	27588	6	2C
0005432953917	27588	7	2D
0005433642195	27588	8	2F
0005433642231	27588	9	3A
0005433642104	27588	10	3C
0005432953912	27588	11	3D
0005433642219	27588	12	3F
0005432953914	27588	13	4A
0005433642178	27588	14	4D
0005433642170	27588	15	4E
0005433642238	27588	16	4F
0005433642237	27588	17	5A
0005432953927	27588	18	5C
0005433642183	27588	19	5D
0005433642220	27588	20	5E
0005432953923	27588	21	5F
0005433642186	27588	22	6C
0005433642254	27588	23	6D
0005432953907	27588	24	6E
0005433642137	27588	25	6F
0005433642169	27588	26	7A
0005433642215	27588	27	7D
0005432953930	27588	28	7F
0005432953916	27588	29	8A
0005432953932	27588	30	8C
0005433642177	27588	31	8D
0005433642192	27588	32	8E
0005433642218	27588	33	8F
0005432953926	27588	34	9A
0005433642207	27588	35	9C
0005433642174	27588	36	9D
0005432953913	27588	37	9E
0005433642159	27588	38	9F
0005432953909	27588	39	10A
0005432953922	27588	40	10C
0005433642179	27588	41	10D
0005432953920	27588	42	10E
0005433642136	27588	43	11A
0005432953910	27588	44	11C
0005433642184	27588	45	11E
0005432953933	27588	46	11F
0005433642196	27588	47	12A
0005433642168	27588	48	12C
0005433642152	27588	49	12D
0005433642197	27588	50	12E
0005433642134	27588	51	12F
0005433642216	27588	52	13A
0005432953911	27588	53	13C
0005433642161	27588	54	13D
0005433642232	27588	55	13E
0005433642151	27588	56	13F
0005433642234	27588	57	14C
0005433642190	27588	58	14D
0005433642203	27588	59	14F
0005433642191	27588	60	15A
0005433642103	27588	61	15C
0005432953929	27588	62	15D
0005433642107	27588	63	15E
0005433642189	27588	64	16A
0005433642208	27588	65	15F
0005433642173	27588	66	16C
0005432953908	27588	67	16D
0005432953924	27588	68	16F
0005432953925	27588	69	17A
0005432953918	27588	70	17C
0005433642150	27588	71	17F
0005433642167	27588	72	18A
0005433642095	27588	73	18C
0005432953919	27588	74	18D
0005433642214	27588	75	18E
0005432953931	27588	76	19A
0005433642135	27588	77	19C
0005432953921	27588	78	19D
0005432953915	27588	79	19E
0005433642156	27588	80	19F
0005432953928	27588	81	20A
0005433642175	27588	82	20D
0005433642140	27588	83	20E
0005432424329	13376	1	1A
0005432424332	13376	2	1F
0005432424348	13376	3	2A
0005432424330	13376	4	2C
0005432424363	13376	5	2D
0005432424361	13376	6	3A
0005432424357	13376	7	3C
0005432424331	13376	8	3F
0005432424347	13376	9	4D
0005432424342	13376	10	4E
0005432424368	13376	11	4F
0005432424366	13376	12	5C
0005432424351	13376	13	6E
0005432424333	13376	14	7A
0005432424359	13376	15	7E
0005432424341	13376	16	7F
0005432424370	13376	17	8D
0005432424326	13376	18	8F
0005432424340	13376	19	9A
0005432424345	13376	20	9F
0005432424335	13376	21	10A
0005432424375	13376	22	10E
0005432424324	13376	23	10F
0005432424354	13376	24	11A
0005432424369	13376	25	11E
0005432424362	13376	26	12A
0005432424334	13376	27	12D
0005432424356	13376	28	12E
0005432424336	13376	29	12F
0005432424350	13376	30	13D
0005432424328	13376	31	13E
0005432424325	13376	32	13F
0005432424327	13376	33	14C
0005432424371	13376	34	14E
0005432424360	13376	35	15A
0005432424367	13376	36	15C
0005432424365	13376	37	15D
0005432424344	13376	38	15F
0005432424358	13376	39	16A
0005432424346	13376	40	16D
0005432424355	13376	41	16F
0005432424337	13376	42	17C
0005432424349	13376	43	17D
0005432424373	13376	44	18D
0005432424338	13376	45	18E
0005432424364	13376	46	18F
0005432424343	13376	47	19A
0005432424372	13376	48	19D
0005432424374	13376	49	19F
0005432424353	13376	50	20A
0005432424352	13376	51	20E
0005432424339	13376	52	20F
0005432423980	30710	1	1F
0005432423893	30710	2	2D
0005432423884	30710	3	2F
0005432423987	30710	4	3D
0005432423843	30710	5	3F
0005432423946	30710	6	4A
0005432423945	30710	7	4D
0005432424024	30710	8	4E
0005432423941	30710	9	5A
0005432424002	30710	10	5C
0005432423770	30710	11	5E
0005432423864	30710	12	6A
0005432424001	30710	13	6D
0005432423966	30710	14	7A
0005432423717	30710	15	7C
0005432423940	30710	16	7D
0005432423783	30710	17	8A
0005432423954	30710	18	8C
0005432424003	30710	19	8D
0005432423953	30710	20	8E
0005432423747	30710	21	8F
0005432423950	30710	22	9D
0005432423949	30710	23	9F
0005432424007	30710	24	10F
0005432423745	30710	25	11D
0005432423965	30710	26	11E
0005432423952	30710	27	12A
0005432423784	30710	28	12C
0005432423816	30710	29	12F
0005432423999	30710	30	13A
0005432423928	30710	31	14C
0005432423976	30710	32	14E
0005432423944	30710	33	15A
0005432423831	30710	34	15C
0005432423951	30710	35	15D
0005432423930	30710	36	15E
0005432423997	30710	37	15F
0005432423854	30710	38	16A
0005432423705	30710	39	16C
0005432423844	30710	40	16D
0005432423998	30710	41	16E
0005432423746	30710	42	17C
0005432423845	30710	43	17E
0005432423990	30710	44	17F
0005432423755	30710	45	18C
0005432423719	30710	46	19A
0005432423881	30710	47	19C
0005432423860	30710	48	19E
0005432424010	30710	49	19F
0005432423720	30710	50	20A
0005432423936	30710	51	20C
0005432423969	30710	52	20D
0005432424009	30710	53	20F
0005432817433	9615	1	1A
0005434448310	9615	2	1C
0005434157392	9615	3	1D
0005432901458	9615	4	1F
0005432817442	9615	5	2A
0005432817443	9615	6	2C
0005432901446	9615	7	3A
0005432817447	9615	8	3C
0005434186173	9615	9	3F
0005432817429	9615	10	4A
0005432822193	9615	11	4C
0005432817436	9615	12	4E
0005432901447	9615	13	4F
0005432901478	9615	14	5A
0005432288982	9615	15	5C
0005432901464	9615	16	5D
0005432901448	9615	17	5E
0005432288981	9615	18	6A
0005432901495	9615	19	6C
0005432901394	9615	20	6F
0005432901451	9615	21	7A
0005432817440	9615	22	7C
0005434157401	9615	23	7D
0005432817432	9615	24	7E
0005432901468	9615	25	7F
0005432817426	9615	26	8A
0005432822192	9615	27	8C
0005432817427	9615	28	8D
0005432817453	9615	29	8E
0005432901507	9615	30	8F
0005432817445	9615	31	9A
0005432817441	9615	32	9D
0005434448311	9615	33	9F
0005432817438	9615	34	10A
0005432817448	9615	35	10C
0005432817431	9615	36	10D
0005432901479	9615	37	10E
0005434157418	9615	38	10F
0005432901467	9615	39	11A
0005432901541	9615	40	11C
0005432288983	9615	41	11E
0005432817446	9615	42	12A
0005434448312	9615	43	12C
0005432817428	9615	44	12D
0005434186171	9615	45	12E
0005432817452	9615	46	12F
0005432901430	9615	47	13C
0005432817439	9615	48	13D
0005432901461	9615	49	13E
0005432901493	9615	50	13F
0005432817450	9615	51	14A
0005432817451	9615	52	14C
0005434186170	9615	53	14D
0005432901392	9615	54	14E
0005434157409	9615	55	14F
0005432817444	9615	56	15A
0005432901404	9615	57	15C
0005432817434	9615	58	15D
0005432822197	9615	59	15E
0005432901395	9615	60	15F
0005432817437	9615	61	16C
0005432817449	9615	62	16E
0005432822195	9615	63	16F
0005432901436	9615	64	17A
0005432822196	9615	65	17C
0005432901450	9615	66	17D
0005434448313	9615	67	17E
0005432901435	9615	68	17F
0005432901396	9615	69	18A
0005434157417	9615	70	18C
0005432817425	9615	71	18E
0005432822194	9615	72	19A
0005432822198	9615	73	18F
0005434186174	9615	74	19C
0005432817430	9615	75	19D
0005432817435	9615	76	19E
0005432901449	9615	77	20A
0005432817299	28985	1	1A
0005432817258	28985	2	1D
0005432817068	28985	3	1F
0005432901583	28985	4	2A
0005432901588	28985	5	2C
0005432817316	28985	6	2D
0005432901592	28985	7	2F
0005434157470	28985	8	3C
0005432817188	28985	9	3D
0005432817090	28985	10	4A
0005434157474	28985	11	4C
0005432817163	28985	12	4E
0005432822148	28985	13	4F
0005432817108	28985	14	5A
0005432901593	28985	15	5C
0005432817178	28985	16	5D
0005434448301	28985	17	5E
0005434157472	28985	18	5F
0005432901589	28985	19	6A
0005432817212	28985	20	6C
0005432817174	28985	21	6D
0005434448303	28985	22	6E
0005432817175	28985	23	6F
0005432901595	28985	24	7A
0005432817136	28985	25	7C
0005432822136	28985	26	7D
0005434186194	28985	27	7F
0005432817243	28985	28	8A
0005432817184	28985	29	8C
0005432817235	28985	30	8D
0005432002074	28985	31	8E
0005432822147	28985	32	9C
0005432817200	28985	33	9E
0005432817066	28985	34	9F
0005432901590	28985	35	10A
0005432901591	28985	36	10C
0005432901597	28985	37	10D
0005432901582	28985	38	10E
0005434186195	28985	39	10F
0005432822146	28985	40	11C
0005432817218	28985	41	11D
0005432817317	28985	42	11E
0005432817176	28985	43	11F
0005432817234	28985	44	12A
0005432901585	28985	45	12C
0005432901594	28985	46	12D
0005432817217	28985	47	12E
0005432817224	28985	48	12F
0005432822135	28985	49	13A
0005434186193	28985	50	13C
0005434157473	28985	51	13D
0005432817086	28985	52	13E
0005432901584	28985	53	14C
0005432901596	28985	54	14D
0005434157469	28985	55	14E
0005432002072	28985	56	14F
0005434186192	28985	57	15A
0005432901598	28985	58	15D
0005432901586	28985	59	15F
0005432817226	28985	60	16A
0005432817325	28985	61	16C
0005432817201	28985	62	16D
0005434157468	28985	63	16E
0005432901581	28985	64	16F
0005432817132	28985	65	17A
0005432002073	28985	66	17E
0005432817164	28985	67	17F
0005432817123	28985	68	18A
0005432817263	28985	69	18D
0005432901587	28985	70	18E
0005432817173	28985	71	18F
0005432817107	28985	72	19A
0005434157467	28985	73	19C
0005432817264	28985	74	19F
0005434157471	28985	75	20C
0005432817131	28985	76	20D
0005434448302	28985	77	20E
0005432817227	28985	78	20F
0005432613859	15143	1	1A
0005432611707	15143	2	1B
0005432611706	15143	3	2B
0005435841812	15143	4	2A
0005432611705	15143	5	3A
0005432611709	15143	6	3B
0005432613856	15143	7	4B
0005432611708	15143	8	5A
0005432613858	15143	9	5B
0005435841092	15143	10	6A
0005432613857	15143	11	6B
0005432611667	31576	1	1A
0005432607511	31576	2	1B
0005432611669	31576	3	2B
0005435842327	31576	4	2A
0005432607533	31576	5	3A
0005432611670	31576	6	3B
0005432611671	31576	7	4A
0005432607528	31576	8	5A
0005432611668	31576	9	6A
0005432607534	31576	10	5B
0005432607529	31576	11	6B
0005433568976	11874	1	1C
0005433568952	11874	2	1A
0005432948030	11874	3	1D
0005433568964	11874	4	2A
0005433568990	11874	5	1F
0005433568965	11874	6	2C
0005433568959	11874	7	3A
0005433568980	11874	8	2F
0005432947829	11874	9	3D
0005432947968	11874	10	3C
0005433568972	11874	11	4A
0005432948054	11874	12	3F
0005432948100	11874	13	4C
0005433568961	11874	14	4F
0005432947799	11874	15	4D
0005432947770	11874	16	5C
0005433568954	11874	17	5A
0005433568968	11874	18	5D
0005433568948	11874	19	6A
0005433568981	11874	20	5F
0005433568950	11874	21	6C
0005432948003	11874	22	6B
0005433568979	11874	23	6D
0005432948056	11874	24	7A
0005433568949	11874	25	6F
0005432948017	11874	26	7C
0005432947887	11874	27	8A
0005432947963	11874	28	7F
0005433568993	11874	29	8B
0005432948035	11874	30	8D
0005432947997	11874	31	8C
0005433568946	11874	32	9A
0005432947804	11874	33	9D
0005432947998	11874	34	9C
0005432947903	11874	35	9E
0005433568960	11874	36	10A
0005432947947	11874	37	10C
0005432947919	11874	38	10B
0005432947800	11874	39	10E
0005432947999	11874	40	10D
0005433568967	11874	41	11A
0005432948109	11874	42	10F
0005433568987	11874	43	11B
0005432948061	11874	44	11D
0005433568970	11874	45	11C
0005433568986	11874	46	11F
0005432948062	11874	47	11E
0005432947935	11874	48	12B
0005432947888	11874	49	12A
0005432948108	11874	50	12D
0005432948015	11874	51	13A
0005432948018	11874	52	12F
0005433568957	11874	53	13D
0005432948000	11874	54	13C
0005433568971	11874	55	13B
0005433568962	11874	56	13E
0005432948021	11874	57	14A
0005433568982	11874	58	14B
0005432948120	11874	59	14D
0005433568992	11874	60	14C
0005432947942	11874	61	14F
0005432947859	11874	62	14E
0005432948022	11874	63	15C
0005432947934	11874	64	15D
0005433568989	11874	65	16A
0005432947939	11874	66	16C
0005432948070	11874	67	16B
0005433568955	11874	68	16D
0005433568983	11874	69	17A
0005432947962	11874	70	16F
0005432948016	11874	71	16E
0005432947771	11874	72	17B
0005432948086	11874	73	17C
0005433568991	11874	74	17F
0005432948044	11874	75	17E
0005433568953	11874	76	18A
0005433568985	11874	77	18D
0005432947940	11874	78	18C
0005433568974	11874	79	18B
0005433568988	11874	80	18E
0005432948020	11874	81	19A
0005433568975	11874	82	18F
0005433568969	11874	83	19C
0005432947896	11874	84	19B
0005433568977	11874	85	19D
0005433568963	11874	86	20A
0005432947858	11874	87	19F
0005433568978	11874	88	19E
0005433568958	11874	89	20C
0005433568973	11874	90	20F
0005432948072	11874	91	20E
0005433568984	11874	92	20D
0005432948033	11874	93	21B
0005433568947	11874	94	21A
0005433568966	11874	95	21C
0005433568956	11874	96	21E
0005432947941	11874	97	21D
0005433568951	11874	98	21F
0005432948456	25274	1	1C
0005433568470	25274	2	1A
0005433568431	25274	3	1F
0005433568591	25274	4	1D
0005432948466	25274	5	2C
0005433568272	25274	6	2A
0005432948436	25274	7	2D
0005433568463	25274	8	3A
0005433568570	25274	9	2F
0005432948461	25274	10	3D
0005433568437	25274	11	3C
0005432948435	25274	12	4A
0005432948457	25274	13	3F
0005433568517	25274	14	4D
0005433568379	25274	15	4C
0005433568265	25274	16	5A
0005433568455	25274	17	4F
0005433568504	25274	18	5C
0005433568273	25274	19	6B
0005433568323	25274	20	6A
0005433568393	25274	21	6D
0005433568232	25274	22	6C
0005433568544	25274	23	6E
0005433568436	25274	24	6F
0005432948444	25274	25	7C
0005432948442	25274	26	7B
0005432948441	25274	27	7E
0005432948451	25274	28	7D
0005433568456	25274	29	8A
0005433568592	25274	30	7F
0005432948449	25274	31	8C
0005433568271	25274	32	8B
0005432948467	25274	33	8D
0005432948440	25274	34	9B
0005432948468	25274	35	9A
0005433568444	25274	36	9C
0005433568512	25274	37	9E
0005432948454	25274	38	10A
0005432948433	25274	39	9F
0005433568501	25274	40	10C
0005432948469	25274	41	10B
0005433568534	25274	42	10E
0005433568682	25274	43	10D
0005433568468	25274	44	11A
0005433568610	25274	45	11B
0005432948464	25274	46	11D
0005432948446	25274	47	11C
0005433568569	25274	48	11F
0005433568496	25274	49	11E
0005433568385	25274	50	12A
0005433568319	25274	51	12D
0005433568375	25274	52	12C
0005433568362	25274	53	12E
0005433568376	25274	54	13B
0005433568716	25274	55	13A
0005432948450	25274	56	12F
0005433568513	25274	57	13C
0005433568343	25274	58	13E
0005433568599	25274	59	13F
0005433568474	25274	60	14B
0005433568434	25274	61	14A
0005432948438	25274	62	14D
0005432948445	25274	63	14C
0005432948471	25274	64	14F
0005432948432	25274	65	14E
0005432948459	25274	66	15B
0005433568497	25274	67	15C
0005433568679	25274	68	15F
0005432948439	25274	69	15E
0005433568445	25274	70	15D
0005433568290	25274	71	16A
0005433568417	25274	72	16C
0005433568484	25274	73	16B
0005432948447	25274	74	16D
0005433568462	25274	75	17A
0005433568413	25274	76	16F
0005433568485	25274	77	16E
0005433568397	25274	78	17B
0005433568543	25274	79	17D
0005432948452	25274	80	17C
0005432948434	25274	81	17E
0005433568542	25274	82	18B
0005432948470	25274	83	18A
0005433568457	25274	84	17F
0005433568509	25274	85	18C
0005433568435	25274	86	18E
0005433568229	25274	87	18D
0005432948455	25274	88	18F
0005432948460	25274	89	19C
0005432948465	25274	90	19B
0005432948453	25274	91	19E
0005432948437	25274	92	19D
0005433568701	25274	93	19F
0005432948448	25274	94	20B
0005433568645	25274	95	20A
0005433568469	25274	96	20D
0005432948463	25274	97	20C
0005433568424	25274	98	20F
0005432948458	25274	99	20E
0005433568433	25274	100	21B
0005433568194	25274	101	21A
0005433568416	25274	102	21C
0005433568344	25274	103	21E
0005432948462	25274	104	21D
0005432948443	25274	105	21F
0005435340021	5378	1	1C
0005435340042	5378	2	1D
0005432114198	5378	3	1F
0005434654650	5378	4	2A
0005434654657	5378	5	2C
0005435340154	5378	6	3A
0005434654659	5378	7	3D
0005435340041	5378	8	3F
0005435340022	5378	9	4A
0005435555339	5378	10	4C
0005434654665	5378	11	4D
0005435340040	5378	12	5E
0005435340063	5378	13	5F
0005434654662	5378	14	6C
0005435555349	5378	15	6D
0005435340094	5378	16	6E
0005435340148	5378	17	6F
0005435340076	5378	18	7A
0005434654642	5378	19	7F
0005435340126	5378	20	7E
0005434654649	5378	21	8C
0005435340162	5378	22	8D
0005434654648	5378	23	8E
0005434654647	5378	24	9A
0005435340043	5378	25	9C
0005434654643	5378	26	9F
0005434654653	5378	27	10A
0005434654646	5378	28	10C
0005435340123	5378	29	10D
0005435340047	5378	30	10F
0005435340110	5378	31	11C
0005434654663	5378	32	11D
0005434654652	5378	33	11E
0005435340163	5378	34	12A
0005432114199	5378	35	12D
0005434654644	5378	36	13A
0005435340131	5378	37	13C
0005435340132	5378	38	14A
0005434654664	5378	39	14C
0005435555340	5378	40	14D
0005434654645	5378	41	14E
0005434654658	5378	42	14F
0005435340119	5378	43	16A
0005435340136	5378	44	16C
0005434654661	5378	45	16D
0005435340109	5378	46	16E
0005434654656	5378	47	17C
0005435340167	5378	48	17D
0005434654654	5378	49	17F
0005434654651	5378	50	18A
0005434654660	5378	51	18C
0005434654655	5378	52	19C
0005434654641	5378	53	19E
0005435340095	5378	54	19F
0005432114200	5378	55	20A
0005434654667	5378	56	20C
0005434654666	5378	57	20D
0005435340100	5378	58	20F
0005435340250	12539	1	1A
0005434654288	12539	2	1C
0005435340241	12539	3	1F
0005434654381	12539	4	2A
0005434654393	12539	5	2C
0005434654392	12539	6	2D
0005434654441	12539	7	2F
0005434654408	12539	8	3A
0005434654399	12539	9	3D
0005434654433	12539	10	4A
0005435340239	12539	11	4E
0005434654339	12539	12	4F
0005434654456	12539	13	5C
0005435340249	12539	14	5E
0005435340253	12539	15	6D
0005434654320	12539	16	6E
0005435340246	12539	17	7C
0005434654454	12539	18	7E
0005434654369	12539	19	7F
0005435340252	12539	20	8C
0005435340240	12539	21	8D
0005434654425	12539	22	8E
0005435340247	12539	23	9A
0005435340244	12539	24	9D
0005434654514	12539	25	10C
0005434654380	12539	26	10D
0005435340238	12539	27	10E
0005435340242	12539	28	11A
0005434654355	12539	29	11C
0005434654354	12539	30	11D
0005434654405	12539	31	11F
0005434654415	12539	32	12D
0005434656538	12539	33	12E
0005435555369	12539	34	13E
0005434654330	12539	35	13F
0005434654370	12539	36	14A
0005434654432	12539	37	14C
0005434654457	12539	38	14D
0005435340248	12539	39	14E
0005434654513	12539	40	14F
0005435555368	12539	41	15A
0005434654455	12539	42	16A
0005435340243	12539	43	17A
0005434654391	12539	44	17E
0005434656539	12539	45	18A
0005434654406	12539	46	18C
0005435340251	12539	47	18E
0005434654386	12539	48	18F
0005435340245	12539	49	19C
0005434654427	12539	50	19D
0005434654209	12539	51	20A
0005434654515	12539	52	20D
0005434654470	12539	53	20F
0005433688806	7449	1	1A
0005432428888	7449	2	1C
0005433715891	7449	3	1D
0005433715906	7449	4	2A
0005433722213	7449	5	1F
0005433715926	7449	6	2F
0005433715929	7449	7	3A
0005433722211	7449	8	3D
0005433715923	7449	9	3C
0005432428889	7449	10	4A
0005433715912	7449	11	4B
0005433722214	7449	12	4C
0005433715925	7449	13	4E
0005433715908	7449	14	4F
0005433715934	7449	15	5A
0005433656666	7449	16	5D
0005433715887	7449	17	5C
0005433722216	7449	18	5E
0005433715901	7449	19	6A
0005433715896	7449	20	6B
0005433656663	7449	21	6D
0005433715917	7449	22	6E
0005433715892	7449	23	7B
0005433689907	7449	24	7E
0005433715921	7449	25	7F
0005433715907	7449	26	8B
0005433715904	7449	27	8E
0005433719135	7449	28	8D
0005433715895	7449	29	8F
0005433715903	7449	30	9E
0005433715890	7449	31	9F
0005432428883	7449	32	10B
0005433715893	7449	33	10C
0005433715915	7449	34	10E
0005433690924	7449	35	11A
0005433715933	7449	36	11E
0005433715902	7449	37	11F
0005433715918	7449	38	13B
0005433689906	7449	39	13A
0005433715884	7449	40	13C
0005433715927	7449	41	14A
0005433715898	7449	42	13F
0005432078099	7449	43	14C
0005433715928	7449	44	14D
0005432078103	7449	45	14E
0005433715914	7449	46	14F
0005433715894	7449	47	15A
0005433715931	7449	48	15C
0005433656664	7449	49	15D
0005433715909	7449	50	15F
0005433715888	7449	51	15E
0005433715910	7449	52	16A
0005433715889	7449	53	16B
0005433722215	7449	54	16C
0005432428895	7449	55	16E
0005433715922	7449	56	16D
0005432078105	7449	57	16F
0005433688804	7449	58	17A
0005433715930	7449	59	17C
0005432078104	7449	60	17D
0005433715899	7449	61	17F
0005432078100	7449	62	17E
0005433715886	7449	63	18B
0005432428899	7449	64	18D
0005433722212	7449	65	18F
0005433715905	7449	66	18E
0005433715919	7449	67	19A
0005433715932	7449	68	19B
0005433722209	7449	69	19C
0005433715897	7449	70	19D
0005433715900	7449	71	19E
0005433715920	7449	72	20C
0005433715911	7449	73	20B
0005432078102	7449	74	20E
0005433715885	7449	75	21B
0005433690922	7449	76	21A
0005433715924	7449	77	21F
0005433715935	7449	78	21E
0005433715916	7449	79	22A
0005433690923	7449	80	22D
0005433719134	7449	81	22F
0005433656665	7449	82	22E
0005432078101	7449	83	23A
0005433688807	7449	84	23C
0005433688805	7449	85	23E
0005433722210	7449	86	23D
0005433715913	7449	87	23F
0005433715491	29208	1	1A
0005433715522	29208	2	1C
0005433656630	29208	3	1D
0005433685496	29208	4	2A
0005433715489	29208	5	2C
0005433688789	29208	6	2F
0005433722128	29208	7	3C
0005433715679	29208	8	3D
0005433715411	29208	9	4A
0005435266144	29208	10	4E
0005433715125	29208	11	5C
0005433715482	29208	12	5D
0005433722121	29208	13	5F
0005433715538	29208	14	6A
0005433685497	29208	15	6C
0005433719090	29208	16	6D
0005433715424	29208	17	6F
0005433719091	29208	18	7A
0005433715617	29208	19	7B
0005433656629	29208	20	7C
0005433715568	29208	21	7F
0005433688788	29208	22	8A
0005432428925	29208	23	8C
0005433715450	29208	24	8E
0005433715488	29208	25	9F
0005433715639	29208	26	9E
0005435266145	29208	27	10D
0005433715437	29208	28	11A
0005433715638	29208	29	11C
0005433715523	29208	30	12A
0005432428924	29208	31	12B
0005433715310	29208	32	12D
0005433715409	29208	33	12C
0005433715532	29208	34	12E
0005433715483	29208	35	13A
0005433715537	29208	36	13C
0005433688794	29208	37	13F
0005432006757	29208	38	14D
0005433715586	29208	39	14E
0005433722131	29208	40	14F
0005433715616	29208	41	15C
0005433715412	29208	42	15D
0005433715311	29208	43	15F
0005433715277	29208	44	15E
0005433715484	29208	45	16B
0005432428923	29208	46	16C
0005433715278	29208	47	16D
0005433715438	29208	48	17A
0005433715436	29208	49	17E
0005433715569	29208	50	17D
0005433715474	29208	51	17F
0005433715818	29208	52	18A
0005433715610	29208	53	18B
0005433685495	29208	54	18C
0005433715576	29208	55	18D
0005433688786	29208	56	19B
0005433715449	29208	57	19C
0005433715418	29208	58	19E
0005432428926	29208	59	19D
0005433715481	29208	60	19F
0005433715126	29208	61	20A
0005433715509	29208	62	20E
0005433715448	29208	63	20D
0005435266146	29208	64	20F
0005433715410	29208	65	21A
0005432006756	29208	66	21C
0005433688793	29208	67	21B
0005432006758	29208	68	21F
0005433719107	29208	69	22B
0005433715480	29208	70	22A
0005433715400	29208	71	23B
0005433656648	29208	72	23D
0005433715533	29208	73	23E
0005433715611	29208	74	23F
0005434095253	8653	1	1A
0005434182097	8653	2	1F
0005434182026	8653	3	2A
0005434182102	8653	4	2D
0005434182060	8653	5	3A
0005434095260	8653	6	3F
0005434095263	8653	7	5C
0005434095264	8653	8	5D
0005434095259	8653	9	6D
0005434095265	8653	10	8D
0005434095255	8653	11	8E
0005434095258	8653	12	8F
0005434182134	8653	13	9A
0005434184655	8653	14	9D
0005434182052	8653	15	12A
0005434095257	8653	16	12D
0005434095254	8653	17	13A
0005434182098	8653	18	13C
0005434184654	8653	19	13D
0005434095262	8653	20	14C
0005434182035	8653	21	14F
0005434182108	8653	22	17A
0005434182042	8653	23	17F
0005434095251	8653	24	18A
0005434182088	8653	25	18C
0005434095256	8653	26	19C
0005434095252	8653	27	20A
0005434095261	8653	28	20C
0005434182168	11649	1	1A
0005434143712	11649	2	1C
0005434095156	11649	3	2F
0005434326262	11649	4	3F
0005434182176	11649	5	5C
0005434182164	11649	6	7A
0005434184661	11649	7	7E
0005434095154	11649	8	8D
0005434095146	11649	9	10F
0005434182170	11649	10	11D
0005434183576	11649	11	11F
0005434182172	11649	12	13A
0005434095153	11649	13	13D
0005434182175	11649	14	14C
0005434184660	11649	15	14E
0005434095134	11649	16	15A
0005434182169	11649	17	15D
0005434182165	11649	18	15F
0005434182174	11649	19	16A
0005434182171	11649	20	16C
0005434182167	11649	21	16D
0005434095122	11649	22	16F
0005434095135	11649	23	17A
0005434182166	11649	24	17C
0005434095155	11649	25	17F
0005434095097	11649	26	18E
0005434326263	11649	27	18F
0005434182173	11649	28	19F
0005433397664	1451	1	1D
0005433397557	1451	2	1F
0005433397437	1451	3	2C
0005433397491	1451	4	2D
0005433397613	1451	5	2F
0005433456968	1451	6	3A
0005433397433	1451	7	3D
0005433397629	1451	8	3F
0005433456967	1451	9	4A
0005433397432	1451	10	4C
0005433397619	1451	11	4D
0005433397585	1451	12	4E
0005433397641	1451	13	5A
0005433456966	1451	14	5C
0005432906521	1451	15	5D
0005433397589	1451	16	5F
0005433397624	1451	17	6A
0005433397429	1451	18	6E
0005433397595	1451	19	7A
0005433397592	1451	20	7D
0005433397554	1451	21	7E
0005433397436	1451	22	7F
0005432906511	1451	23	8A
0005433397473	1451	24	8C
0005433397640	1451	25	8D
0005433397806	1451	26	8E
0005433397435	1451	27	8F
0005433397665	1451	28	9A
0005433397630	1451	29	9F
0005433397722	1451	30	10C
0005433397614	1451	31	10E
0005432906503	1451	32	10F
0005433397247	1451	33	11A
0005433397510	1451	34	11C
0005433397503	1451	35	11E
0005433397718	1451	36	11F
0005433397434	1451	37	12A
0005433397661	1451	38	12C
0005432906502	1451	39	12D
0005433397542	1451	40	12E
0005433397738	1451	41	13A
0005433397623	1451	42	13C
0005433397689	1451	43	13D
0005433397477	1451	44	13E
0005433397604	1451	45	13F
0005433397453	1451	46	14D
0005433456963	1451	47	14F
0005433397717	1451	48	15A
0005433397617	1451	49	15D
0005433397839	1451	50	15E
0005433397591	1451	51	15F
0005433397739	1451	52	16A
0005433456965	1451	53	16C
0005433397575	1451	54	16D
0005433397666	1451	55	16E
0005433397403	1451	56	16F
0005432297274	1451	57	17A
0005433397852	1451	58	17C
0005433397603	1451	59	17D
0005433397574	1451	60	17F
0005433397558	1451	61	18C
0005433397526	1451	62	18D
0005433397511	1451	63	18E
0005433397620	1451	64	18F
0005433456964	1451	65	19A
0005433397677	1451	66	19D
0005433397631	1451	67	19E
0005433397698	1451	68	19F
0005433397571	1451	69	20A
0005433397755	1451	70	20C
0005432297275	1451	71	20D
0005433397576	1451	72	20E
0005433397555	1451	73	20F
0005433397975	19262	1	1A
0005432906532	19262	2	1C
0005433398004	19262	3	1F
0005433398007	19262	4	2A
0005435732241	19262	5	2F
0005433398008	19262	6	3A
0005433398001	19262	7	4D
0005433397990	19262	8	4E
0005433397980	19262	9	4F
0005433398013	19262	10	5C
0005433397989	19262	11	5D
0005433397994	19262	12	5E
0005433397983	19262	13	6A
0005433398002	19262	14	6D
0005433397993	19262	15	6E
0005433397979	19262	16	6F
0005433456931	19262	17	7A
0005433398020	19262	18	7D
0005433397978	19262	19	7E
0005435732186	19262	20	7F
0005435732265	19262	21	8C
0005433398012	19262	22	8F
0005433397985	19262	23	9A
0005433397977	19262	24	9E
0005435732228	19262	25	9F
0005433397981	19262	26	10A
0005433456935	19262	27	10D
0005435732225	19262	28	10E
0005435732242	19262	29	11A
0005433398014	19262	30	11C
0005433397991	19262	31	11E
0005433398016	19262	32	11F
0005433397987	19262	33	12A
0005433397976	19262	34	12C
0005433398006	19262	35	12D
0005433398003	19262	36	12E
0005433398023	19262	37	13A
0005433398011	19262	38	13C
0005433398005	19262	39	13D
0005433398021	19262	40	13E
0005433397995	19262	41	13F
0005435732206	19262	42	14A
0005433398010	19262	43	14C
0005433398019	19262	44	14E
0005433397992	19262	45	14F
0005433398018	19262	46	15A
0005433397997	19262	47	15C
0005435732266	19262	48	15D
0005433397999	19262	49	15E
0005432906533	19262	50	15F
0005433397996	19262	51	16E
0005433398009	19262	52	17A
0005433397998	19262	53	18A
0005435732232	19262	54	18D
0005433397984	19262	55	18E
0005433397982	19262	56	18F
0005433398015	19262	57	19A
0005433398017	19262	58	19C
0005433397986	19262	59	19F
0005433398022	19262	60	20C
0005435732200	19262	61	20D
0005433398000	19262	62	20E
0005433397988	19262	63	20F
0005434443536	17352	1	1D
0005434443578	17352	2	2D
0005434443499	17352	3	3A
0005434443527	17352	4	4A
0005434443634	17352	5	4B
0005434443600	17352	6	6A
0005434443604	17352	7	6C
0005434443544	17352	8	7B
0005434443508	17352	9	18D
0005434443509	17352	10	19B
0005434443528	17352	11	20B
0005434443559	17352	12	21B
0005434443560	17352	13	22A
0005434443541	17352	14	22C
0005434443603	17352	15	23B
0005434443675	20602	1	3C
0005434443671	20602	2	4B
0005434443677	20602	3	4A
0005434443678	20602	4	5A
0005434443673	20602	5	5B
0005434443672	20602	6	6D
0005434443684	20602	7	7A
0005434443674	20602	8	7B
0005434443676	20602	9	7D
0005434443679	20602	10	18A
0005434443683	20602	11	20C
0005434443680	20602	12	20D
0005434443681	20602	13	21C
0005434443686	20602	14	21D
0005434443687	20602	15	22C
0005434443682	20602	16	22D
0005434443685	20602	17	23B
0005435377555	7274	1	1A
0005435377564	7274	2	1B
0005434954604	7274	3	2A
0005434954603	7274	4	2B
0005434954605	7274	5	3A
0005435377563	7274	6	4A
0005435377565	7274	7	4B
0005435377561	7274	8	6A
0005434954602	7274	9	6B
0005434954572	28353	1	2B
0005435377577	28353	2	3A
0005435377578	28353	3	3B
0005434954571	28353	4	5A
0005435377576	28353	5	6B
0005434183553	4457	1	1B
0005435893556	4457	2	1D
0005434351676	4457	3	2B
0005435893533	4457	4	2C
0005435893557	4457	5	3A
0005434351682	4457	6	3D
0005434351683	4457	7	4B
0005434183563	4457	8	4D
0005434351678	4457	9	5A
0005435893559	4457	10	5C
0005434351680	4457	11	5D
0005434351681	4457	12	6D
0005434351677	4457	13	7B
0005434351685	4457	14	7D
0005434351679	4457	15	18A
0005434351675	4457	16	18C
0005434351684	4457	17	19A
0005435893560	4457	18	19B
0005434351674	4457	19	19C
0005434183554	4457	20	21C
0005434351561	29634	1	1D
0005435893624	29634	2	2A
0005434351571	29634	3	2B
0005434351578	29634	4	2C
0005435893620	29634	5	3B
0005435893625	29634	6	3C
0005434351623	29634	7	3D
0005435893622	29634	8	4B
0005435893626	29634	9	4D
0005434351577	29634	10	5B
0005434351566	29634	11	5D
0005434351624	29634	12	6A
0005434351600	29634	13	6D
0005434351546	29634	14	7A
0005434351541	29634	15	7B
0005434351543	29634	16	7C
0005435893621	29634	17	18D
0005435893619	29634	18	19B
0005434351564	29634	19	20C
0005434351573	29634	20	21B
0005435893623	29634	21	21C
0005434351572	29634	22	21D
0005434351547	29634	23	22D
0005433342114	1068	1	1C
0005433269682	1068	2	1F
0005433342168	1068	3	1H
0005432293205	1068	4	2B
0005433342397	1068	5	3C
0005435092063	1068	6	3B
0005433342345	1068	7	3F
0005435092060	1068	8	3H
0005435092065	1068	9	4A
0005433341529	1068	10	4F
0005433158108	1068	11	4C
0005433341780	1068	12	5B
0005435092064	1068	13	5A
0005433342351	1068	14	5F
0005435545735	1068	15	5C
0005433341955	1068	16	5G
0005435545732	1068	17	5H
0005433342200	1068	18	9B
0005433342147	1068	19	9A
0005435092066	1068	20	9G
0005433342186	1068	21	11A
0005435545734	1068	22	11D
0005433342112	1068	23	11E
0005433462743	1068	24	11F
0005433341884	1068	25	12A
0005433342233	1068	26	12B
0005433342089	1068	27	12E
0005433342132	1068	28	12F
0005435545727	1068	29	13G
0005433341735	1068	30	14E
0005433342398	1068	31	14H
0005433341708	1068	32	14G
0005433159289	1068	33	14F
0005435545726	1068	34	15D
0005433342006	1068	35	15F
0005433342007	1068	36	16B
0005433342119	1068	37	16E
0005433341472	1068	38	16D
0005433342090	1068	39	16H
0005435545728	1068	40	17A
0005433342416	1068	41	17D
0005433342153	1068	42	17E
0005433342117	1068	43	17F
0005433462744	1068	44	17H
0005433341778	1068	45	18D
0005433342154	1068	46	18G
0005433342293	1068	47	18F
0005435545733	1068	48	18H
0005435092056	1068	49	19B
0005433342170	1068	50	19E
0005433341736	1068	51	19D
0005433341928	1068	52	19F
0005433269654	1068	53	20A
0005433342134	1068	54	19H
0005433463897	1068	55	20B
0005433342146	1068	56	20E
0005433341775	1068	57	20D
0005433341608	1068	58	20F
0005433342268	1068	59	20H
0005433341878	1068	60	21A
0005433342091	1068	61	21B
0005433342289	1068	62	21G
0005435545724	1068	63	21H
0005433342113	1068	64	22B
0005433342386	1068	65	22E
0005433341879	1068	66	22D
0005432293206	1068	67	22F
0005433342267	1068	68	23B
0005435092059	1068	69	23E
0005433342169	1068	70	23G
0005433342069	1068	71	24B
0005433342253	1068	72	24E
0005433342252	1068	73	24H
0005433342092	1068	74	24G
0005433342008	1068	75	25E
0005433463898	1068	76	25D
0005435545729	1068	77	25F
0005435545731	1068	78	27B
0005433342266	1068	79	27A
0005435092061	1068	80	27E
0005433341642	1068	81	27G
0005433342137	1068	82	28B
0005433342009	1068	83	28D
0005434445244	1068	84	28F
0005433341822	1068	85	28E
0005433341528	1068	86	29A
0005433159296	1068	87	28H
0005433342128	1068	88	29B
0005433342387	1068	89	29G
0005433342350	1068	90	29F
0005435545730	1068	91	29H
0005433342201	1068	92	30A
0005435092057	1068	93	30E
0005433342148	1068	94	30G
0005434445246	1068	95	30H
0005433342135	1068	96	31E
0005433341924	1068	97	31D
0005433342136	1068	98	31F
0005433342247	1068	99	32B
0005433342123	1068	100	32E
0005433342227	1068	101	32G
0005433159297	1068	102	32F
0005433341590	1068	103	32H
0005433342389	1068	104	33B
0005435092058	1068	105	33E
0005433342234	1068	106	33D
0005434445245	1068	107	33G
0005433342015	1068	108	34A
0005433342235	1068	109	33H
0005433342279	1068	110	34D
0005433342352	1068	111	34G
0005433342292	1068	112	34F
0005433342005	1068	113	35A
0005434446518	1068	114	34H
0005433269683	1068	115	35B
0005435092062	1068	116	35G
0005435545723	1068	117	36A
0005433342344	1068	118	35H
0005435545725	1068	119	36B
0005433341758	1068	120	36H
0005433342166	1068	121	36G
0005433342010	1068	122	37H
0005433342027	1068	123	38A
0005433342396	1068	124	38B
0005433342140	1068	125	38H
0005433341960	1068	126	39E
0005433158107	1068	127	39F
0005435508269	17055	1	1A
0005435092018	17055	2	1C
0005433342964	17055	3	1B
0005433342950	17055	4	2A
0005433342926	17055	5	2F
0005433342931	17055	6	2C
0005433342989	17055	7	2G
0005433342993	17055	8	3A
0005433342985	17055	9	3B
0005433342980	17055	10	3F
0005433342976	17055	11	3C
0005433159308	17055	12	4A
0005433269713	17055	13	3H
0005433342965	17055	14	4B
0005433342974	17055	15	4G
0005433342956	17055	16	4H
0005433342943	17055	17	5A
0005435508213	17055	18	5C
0005434445223	17055	19	9B
0005435091944	17055	20	9G
0005433342934	17055	21	11E
0005433342981	17055	22	11H
0005433342958	17055	23	11G
0005433342960	17055	24	12A
0005433342971	17055	25	12E
0005433342930	17055	26	12G
0005433342938	17055	27	12F
0005435091997	17055	28	12H
0005433342913	17055	29	13B
0005433342944	17055	30	13A
0005435508273	17055	31	13E
0005434445217	17055	32	13G
0005435092004	17055	33	13F
0005435508234	17055	34	14A
0005433269714	17055	35	13H
0005435508240	17055	36	14B
0005433342919	17055	37	14D
0005433342925	17055	38	14E
0005433269712	17055	39	14F
0005433342990	17055	40	14H
0005435508268	17055	41	15D
0005433342921	17055	42	15B
0005433342968	17055	43	15H
0005435091974	17055	44	16A
0005433342983	17055	45	16D
0005433342933	17055	46	16E
0005433342984	17055	47	16G
0005433342987	17055	48	16H
0005433342929	17055	49	17B
0005433342973	17055	50	17D
0005433342945	17055	51	17F
0005435508254	17055	52	17G
0005433342911	17055	53	17H
0005433342972	17055	54	18B
0005433159309	17055	55	18D
0005433342948	17055	56	18F
0005433342914	17055	57	18G
0005433269709	17055	58	19A
0005433342988	17055	59	19E
0005433342998	17055	60	19D
0005433342917	17055	61	19G
0005433342909	17055	62	20D
0005433342978	17055	63	20F
0005433343001	17055	64	20G
0005433342923	17055	65	21D
0005435508241	17055	66	21F
0005433342970	17055	67	22G
0005433342961	17055	68	22F
0005435508229	17055	69	22H
0005433342939	17055	70	23A
0005433342936	17055	71	23E
0005435508296	17055	72	23D
0005433342977	17055	73	23B
0005433342922	17055	74	23F
0005435091998	17055	75	23G
0005435508255	17055	76	24A
0005434445218	17055	77	23H
0005433342996	17055	78	24B
0005433342952	17055	79	24D
0005433342920	17055	80	24F
0005433342994	17055	81	24E
0005433343000	17055	82	24H
0005435091999	17055	83	24G
0005433342918	17055	84	25F
0005433342942	17055	85	25E
0005433343003	17055	86	27B
0005433342924	17055	87	27E
0005433342912	17055	88	27D
0005433342959	17055	89	28A
0005435508291	17055	90	27H
0005433342969	17055	91	28D
0005433342999	17055	92	28E
0005435508290	17055	93	29A
0005433342957	17055	94	29D
0005433342997	17055	95	29G
0005433343002	17055	96	29F
0005433342953	17055	97	30B
0005433342995	17055	98	30D
0005433342928	17055	99	30F
0005433342949	17055	100	30E
0005433342982	17055	101	31A
0005433342979	17055	102	31E
0005433343005	17055	103	31D
0005433342966	17055	104	31F
0005435091987	17055	105	32D
0005433342962	17055	106	32E
0005433342916	17055	107	32G
0005434445214	17055	108	33B
0005433342986	17055	109	33E
0005433342941	17055	110	33D
0005433342947	17055	111	33F
0005433342951	17055	112	33H
0005435092005	17055	113	33G
0005435508214	17055	114	34A
0005433342915	17055	115	34B
0005433342955	17055	116	34G
0005433343004	17055	117	34F
0005433342935	17055	118	34H
0005433342967	17055	119	35D
0005433342963	17055	120	35F
0005433342932	17055	121	35G
0005433342940	17055	122	35H
0005433343007	17055	123	36E
0005433342992	17055	124	36D
0005433342927	17055	125	37A
0005433342991	17055	126	37B
0005433342910	17055	127	37H
0005433342946	17055	128	38A
0005433342954	17055	129	38D
0005433342937	17055	130	38E
0005433342975	17055	131	38G
0005433269710	17055	132	38F
0005433269711	17055	133	38H
0005433342908	17055	134	39E
0005433343006	17055	135	39D
0005433343008	17055	136	39F
0005432851859	1339	1	1C
0005432391986	1339	2	1A
0005432390130	1339	3	1D
0005432851852	1339	4	2A
0005432391987	1339	5	1F
0005432851854	1339	6	2C
0005432390103	1339	7	3D
0005432390134	1339	8	3C
0005432390106	1339	9	4A
0005432390122	1339	10	4D
0005432390119	1339	11	4F
0005432391989	1339	12	5A
0005432851874	1339	13	5F
0005432390107	1339	14	5D
0005432390125	1339	15	6A
0005432390126	1339	16	6B
0005432390101	1339	17	6F
0005432391992	1339	18	6E
0005432390127	1339	19	7B
0005432390099	1339	20	7D
0005432390129	1339	21	8C
0005432390118	1339	22	8B
0005432390133	1339	23	8F
0005432390108	1339	24	9B
0005432391991	1339	25	9D
0005432390104	1339	26	10B
0005432390121	1339	27	10D
0005432390112	1339	28	10F
0005432851849	1339	29	11B
0005432851840	1339	30	11A
0005432851841	1339	31	11D
0005432851851	1339	32	11C
0005432391994	1339	33	11E
0005432851853	1339	34	12B
0005432390116	1339	35	12A
0005432851839	1339	36	12C
0005432390117	1339	37	12F
0005432851824	1339	38	12E
0005432390115	1339	39	13C
0005432390113	1339	40	13B
0005432390100	1339	41	13D
0005432390120	1339	42	14E
0005432391990	1339	43	15A
0005432851875	1339	44	15F
0005432390124	1339	45	16A
0005432390109	1339	46	16E
0005432391988	1339	47	16D
0005432851857	1339	48	16F
0005432851850	1339	49	17B
0005432851855	1339	50	17C
0005432851873	1339	51	17F
0005432851872	1339	52	18E
0005432390114	1339	53	18D
0005432390131	1339	54	19A
0005432390128	1339	55	19D
0005432390123	1339	56	19F
0005432851860	1339	57	20B
0005432390132	1339	58	20D
0005432390110	1339	59	20F
0005432390102	1339	60	20E
0005432390111	1339	61	21A
0005432390105	1339	62	21D
0005432391993	1339	63	21F
0005434066900	12814	1	1A
0005434081585	12814	2	1D
0005434081630	12814	3	1F
0005434081675	12814	4	2C
0005432159851	12814	5	2D
0005434066871	12814	6	2F
0005434066656	12814	7	3C
0005432433676	12814	8	3A
0005434081672	12814	9	3D
0005434066794	12814	10	3F
0005434066887	12814	11	4A
0005432159853	12814	12	4C
0005434066824	12814	13	4B
0005434066853	12814	14	4D
0005432433672	12814	15	4E
0005434066748	12814	16	5A
0005433989725	12814	17	4F
0005434067111	12814	18	5B
0005434066829	12814	19	5C
0005434081683	12814	20	5D
0005434066836	12814	21	5E
0005432159854	12814	22	6A
0005434067001	12814	23	5F
0005433812898	12814	24	6B
0005432433674	12814	25	6C
0005434066892	12814	26	6D
0005434066999	12814	27	6E
0005434066612	12814	28	6F
0005434066658	12814	29	7B
0005434066823	12814	30	7A
0005432433675	12814	31	7C
0005434081660	12814	32	7E
0005434081652	12814	33	7D
0005434081705	12814	34	7F
0005434081595	12814	35	8B
0005434081709	12814	36	8A
0005434067000	12814	37	8C
0005434066806	12814	38	8E
0005434066695	12814	39	8D
0005434066939	12814	40	8F
0005433989713	12814	41	9A
0005434066954	12814	42	9B
0005434066676	12814	43	9C
0005434066795	12814	44	9E
0005434066674	12814	45	9D
0005434066531	12814	46	9F
0005432161149	12814	47	10B
0005434066530	12814	48	10C
0005434066766	12814	49	10E
0005434066652	12814	50	10D
0005434081531	12814	51	11A
0005434067182	12814	52	11B
0005434066797	12814	53	11C
0005434066895	12814	54	11E
0005434066718	12814	55	11D
0005434081584	12814	56	11F
0005434066866	12814	57	12A
0005432161150	12814	58	12C
0005434066611	12814	59	12B
0005434066485	12814	60	12D
0005434066949	12814	61	12E
0005434066597	12814	62	12F
0005434081591	12814	63	13A
0005432433673	12814	64	13C
0005433812897	12814	65	13B
0005434081537	12814	66	13D
0005434066796	12814	67	13E
0005434066678	12814	68	13F
0005434066894	12814	69	14B
0005434081649	12814	70	14A
0005434066854	12814	71	14D
0005434081718	12814	72	14E
0005434066526	12814	73	15A
0005434081659	12814	74	14F
0005434081699	12814	75	15B
0005434066706	12814	76	15E
0005434066599	12814	77	15D
0005434067054	12814	78	15C
0005434066953	12814	79	16A
0005434066709	12814	80	15F
0005432433670	12814	81	16B
0005434067181	12814	82	16C
0005434066675	12814	83	16D
0005434066916	12814	84	16F
0005434081674	12814	85	16E
0005432433671	12814	86	17A
0005434081703	12814	87	17B
0005434026684	12814	88	17D
0005434081668	12814	89	17C
0005434081635	12814	90	17F
0005434066838	12814	91	17E
0005434066810	12814	92	18A
0005433812896	12814	93	18C
0005434066525	12814	94	18B
0005434066919	12814	95	18D
0005434081543	12814	96	18E
0005434066938	12814	97	18F
0005434066917	12814	98	19A
0005434081629	12814	99	19B
0005434066624	12814	100	19D
0005434066623	12814	101	19C
0005434066598	12814	102	19F
0005434081704	12814	103	19E
0005434066610	12814	104	20B
0005434066837	12814	105	20A
0005434066893	12814	106	20C
0005434066872	12814	107	20D
0005434066780	12814	108	20E
0005434081583	12814	109	20F
0005434081698	12814	110	21B
0005434066445	12814	111	21A
0005434067055	12814	112	21C
0005434081671	12814	113	21D
0005434081701	12814	114	21F
0005434066769	12814	115	21E
0005434066873	12814	116	22B
0005434066856	12814	117	22A
0005434067134	12814	118	22C
0005432159852	12814	119	22D
0005434081700	12814	120	22E
0005434066339	12814	121	23A
0005434081592	12814	122	22F
0005434066948	12814	123	23B
0005434066798	12814	124	23C
0005434066852	12814	125	23E
0005433989735	12814	126	23D
0005434066855	12814	127	23F
0005434067452	30677	1	1A
0005433989762	30677	2	1C
0005434081849	30677	3	1D
0005433989759	30677	4	2A
0005434067416	30677	5	1F
0005434067437	30677	6	2D
0005432186862	30677	7	2C
0005434081854	30677	8	2F
0005434067448	30677	9	3A
0005432150179	30677	10	3D
0005434081851	30677	11	3C
0005434067447	30677	12	3F
0005434067453	30677	13	4A
0005434081848	30677	14	4C
0005432433623	30677	15	4E
0005434081845	30677	16	4F
0005434067421	30677	17	5B
0005434067426	30677	18	5C
0005432186861	30677	19	5D
0005434067444	30677	20	5F
0005434067427	30677	21	5E
0005434067430	30677	22	6A
0005434067413	30677	23	6C
0005434067449	30677	24	6B
0005434067440	30677	25	6E
0005434067445	30677	26	7A
0005434067417	30677	27	6F
0005434067395	30677	28	7B
0005434067410	30677	29	7C
0005434067412	30677	30	7F
0005434067399	30677	31	7E
0005434067425	30677	32	8A
0005434067419	30677	33	8B
0005434081855	30677	34	8C
0005434067392	30677	35	8D
0005434067454	30677	36	8F
0005434067385	30677	37	8E
0005434067406	30677	38	9A
0005432150176	30677	39	9B
0005434067409	30677	40	9D
0005434067423	30677	41	9E
0005434067394	30677	42	9F
0005434067408	30677	43	10B
0005434067434	30677	44	10C
0005434067422	30677	45	11A
0005434067402	30677	46	11B
0005434067390	30677	47	11C
0005434081847	30677	48	11E
0005434067438	30677	49	11D
0005432433624	30677	50	11F
0005434067446	30677	51	12B
0005434067400	30677	52	12A
0005434067428	30677	53	12D
0005434067433	30677	54	12C
0005432186863	30677	55	12E
0005432186860	30677	56	12F
0005434067429	30677	57	13B
0005432433631	30677	58	13A
0005434081856	30677	59	13D
0005434067420	30677	60	13C
0005434067443	30677	61	13E
0005434067387	30677	62	13F
0005434081846	30677	63	14A
0005434067397	30677	64	14B
0005434067455	30677	65	14D
0005432150177	30677	66	14C
0005432433616	30677	67	14F
0005434081852	30677	68	15B
0005434081841	30677	69	15A
0005434081853	30677	70	15C
0005432433615	30677	71	15D
0005434081838	30677	72	15F
0005434081840	30677	73	15E
0005434067411	30677	74	16A
0005434067398	30677	75	16B
0005434067431	30677	76	16C
0005434067389	30677	77	16D
0005434081837	30677	78	16E
0005434067424	30677	79	17A
0005434067435	30677	80	16F
0005434067414	30677	81	17B
0005434067456	30677	82	17C
0005433989763	30677	83	17D
0005434067388	30677	84	17F
0005432150182	30677	85	18A
0005434081839	30677	86	18C
0005434067405	30677	87	18B
0005434067404	30677	88	18D
0005433989761	30677	89	18E
0005434067418	30677	90	19C
0005434067432	30677	91	19B
0005434067403	30677	92	19E
0005434067450	30677	93	19D
0005434067451	30677	94	19F
0005434067407	30677	95	20A
0005434067391	30677	96	20B
0005434067396	30677	97	20C
0005434067441	30677	98	20E
0005434067384	30677	99	20F
0005434067415	30677	100	21B
0005434081843	30677	101	21A
0005434067442	30677	102	21C
0005434067393	30677	103	21D
0005434067401	30677	104	21E
0005432150178	30677	105	22A
0005434081844	30677	106	21F
0005432150180	30677	107	22B
0005432150181	30677	108	22C
0005434081850	30677	109	22D
0005434081857	30677	110	22E
0005434067439	30677	111	23A
0005433989760	30677	112	22F
0005432150175	30677	113	23B
0005434081842	30677	114	23C
0005434067436	30677	115	23D
0005434081858	30677	116	23F
0005434067386	30677	117	23E
0005435461942	5523	1	1C
0005435723042	5523	2	1B
0005435766173	5523	3	1F
0005435462212	5523	4	1H
0005435461929	5523	5	1G
0005435462019	5523	6	2C
0005435766172	5523	7	2B
0005435723041	5523	8	2F
0005433529275	5523	9	2G
0005435462031	5523	10	3A
0005435462003	5523	11	3G
0005435462032	5523	12	3F
0005435722052	5523	13	3H
0005435766143	5523	14	4A
0005435462016	5523	15	4C
0005435766163	5523	16	4G
0005432535787	5523	17	4H
0005434264926	5523	18	5B
0005435462082	5523	19	5F
0005435766171	5523	20	5C
0005435735131	5523	21	5G
0005435462035	5523	22	9B
0005433529273	5523	23	9H
0005435766181	5523	24	9G
0005433527262	5523	25	11A
0005432140439	5523	26	11B
0005435462208	5523	27	11E
0005435462022	5523	28	11D
0005434264771	5523	29	11G
0005433527263	5523	30	11F
0005435766154	5523	31	12B
0005435462107	5523	32	12D
0005434264940	5523	33	12G
0005435766142	5523	34	12F
0005435766160	5523	35	12H
0005433527264	5523	36	13A
0005434264814	5523	37	13D
0005432535775	5523	38	13B
0005435461951	5523	39	13E
0005435725592	5523	40	13F
0005435461952	5523	41	14A
0005432140442	5523	42	14D
0005435462093	5523	43	14B
0005433529274	5523	44	14F
0005435766152	5523	45	15A
0005434264986	5523	46	15B
0005435462153	5523	47	15D
0005435735133	5523	48	15G
0005435766187	5523	49	15F
0005435766150	5523	50	16A
0005435766162	5523	51	15H
0005434265027	5523	52	16D
0005432535786	5523	53	16E
0005435766169	5523	54	16F
0005434264806	5523	55	16H
0005435766174	5523	56	17A
0005434264796	5523	57	17B
0005435766147	5523	58	17E
0005435766186	5523	59	17G
0005435462033	5523	60	17H
0005435461958	5523	61	18A
0005434264862	5523	62	18D
0005435735132	5523	63	18F
0005434264830	5523	64	18G
0005434264829	5523	65	18H
0005435766146	5523	66	19B
0005434264845	5523	67	19E
0005435766182	5523	68	19F
0005433529276	5523	69	19H
0005435766167	5523	70	19G
0005435766141	5523	71	20A
0005434264809	5523	72	20B
0005433527261	5523	73	20E
0005435462034	5523	74	20D
0005432140440	5523	75	20F
0005435462122	5523	76	20H
0005432140435	5523	77	21A
0005434831089	5523	78	21B
0005435766161	5523	79	21F
0005435462005	5523	80	21D
0005434264764	5523	81	21H
0005435766145	5523	82	21G
0005435462109	5523	83	22D
0005434264863	5523	84	22E
0005434264807	5523	85	22G
0005435462155	5523	86	22F
0005432140433	5523	87	23B
0005432140441	5523	88	23A
0005435766168	5523	89	23D
0005435766177	5523	90	23F
0005435766148	5523	91	23G
0005435462021	5523	92	24A
0005435725591	5523	93	23H
0005435462116	5523	94	24B
0005435462004	5523	95	24D
0005435766165	5523	96	24F
0005434264867	5523	97	24E
0005435461978	5523	98	24G
0005434264939	5523	99	25D
0005432535793	5523	100	24H
0005435766176	5523	101	25E
0005435766178	5523	102	27B
0005435766166	5523	103	27D
0005432535760	5523	104	27H
0005435462055	5523	105	27G
0005435766183	5523	106	28B
0005435722053	5523	107	28A
0005435766185	5523	108	28E
0005435766179	5523	109	28F
0005435766139	5523	110	28G
0005435462083	5523	111	28H
0005435725590	5523	112	29B
0005432535761	5523	113	29E
0005434264772	5523	114	29G
0005432140434	5523	115	30B
0005435766164	5523	116	30A
0005435461948	5523	117	30D
0005435766144	5523	118	30E
0005434264920	5523	119	30G
0005435461939	5523	120	30F
0005435766140	5523	121	31A
0005435722051	5523	122	30H
0005435461953	5523	123	31B
0005435766153	5523	124	31E
0005434264916	5523	125	31D
0005435766151	5523	126	31F
0005434831100	5523	127	31H
0005435462094	5523	128	31G
0005435461941	5523	129	32A
0005435462196	5523	130	32D
0005435462077	5523	131	32B
0005435462100	5523	132	32E
0005435766170	5523	133	32H
0005435766184	5523	134	33B
0005435766159	5523	135	33E
0005435766175	5523	136	33D
0005434264791	5523	137	33F
0005435766155	5523	138	33G
0005434264847	5523	139	34B
0005435461979	5523	140	34A
0005435462154	5523	141	34F
0005432140436	5523	142	34G
0005435766157	5523	143	34H
0005435766149	5523	144	35B
0005434264846	5523	145	35A
0005435766180	5523	146	35D
0005435461961	5523	147	35F
0005435462213	5523	148	35E
0005433529272	5523	149	35G
0005434264769	5523	150	36A
0005434831101	5523	151	35H
0005434264810	5523	152	36F
0005435766156	5523	153	36E
0005435462020	5523	154	36G
0005432140438	5523	155	37B
0005434264804	5523	156	37D
0005435766188	5523	157	37F
0005434264765	5523	158	37G
0005435462015	5523	159	38B
0005435462207	5523	160	38E
0005435766158	5523	161	38D
0005434264774	5523	162	38F
0005434264805	5523	163	38H
0005434264898	5523	164	39E
0005432140437	5523	165	39D
0005435462084	5523	166	39F
0005435765619	13468	1	1A
0005434831148	13468	2	1B
0005435765377	13468	3	1F
0005434831145	13468	4	1C
0005435462375	13468	5	1G
0005434265100	13468	6	2A
0005435765685	13468	7	2C
0005435765263	13468	8	2B
0005435765432	13468	9	2F
0005435765436	13468	10	2G
0005435462406	13468	11	2H
0005435725532	13468	12	3B
0005434265113	13468	13	3F
0005434265123	13468	14	3C
0005434265109	13468	15	3H
0005435765720	13468	16	3G
0005435462405	13468	17	4A
0005435765604	13468	18	4C
0005435462397	13468	19	4G
0005435462387	13468	20	5A
0005435462411	13468	21	5B
0005434265120	13468	22	5G
0005435725561	13468	23	9A
0005435765558	13468	24	9B
0005435617169	13468	25	11A
0005435765372	13468	26	11B
0005435462379	13468	27	11F
0005432535828	13468	28	11E
0005435765669	13468	29	11H
0005435765932	13468	30	12A
0005435765278	13468	31	12D
0005435765376	13468	32	12B
0005435462412	13468	33	12E
0005435765668	13468	34	12H
0005435462382	13468	35	12G
0005435765670	13468	36	13A
0005435765721	13468	37	13D
0005435765429	13468	38	13B
0005435765373	13468	39	13E
0005435765237	13468	40	13G
0005435462376	13468	41	13F
0005435765435	13468	42	13H
0005434265112	13468	43	14A
0005435765606	13468	44	14D
0005435765527	13468	45	14F
0005432194506	13468	46	14E
0005435765687	13468	47	14G
0005435765633	13468	48	15A
0005435462385	13468	49	14H
0005435462394	13468	50	15E
0005435462401	13468	51	15G
0005435765716	13468	52	15F
0005435765469	13468	53	15H
0005435462391	13468	54	16A
0005435765468	13468	55	16D
0005434265101	13468	56	16B
0005435765618	13468	57	16E
0005435765526	13468	58	16G
0005432535827	13468	59	16F
0005435765156	13468	60	16H
0005435462392	13468	61	17B
0005435462396	13468	62	17A
0005435462388	13468	63	17D
0005432194507	13468	64	17F
0005434265104	13468	65	17G
0005432535829	13468	66	18B
0005435765885	13468	67	18F
0005434831150	13468	68	18H
0005435765371	13468	69	19B
0005434265121	13468	70	19F
0005432194505	13468	71	19H
0005434831144	13468	72	20A
0005435765722	13468	73	20B
0005435735106	13468	74	20D
0005435765480	13468	75	20F
0005435462410	13468	76	20H
0005434265116	13468	77	20G
0005434831146	13468	78	21A
0005435765155	13468	79	21D
0005435722023	13468	80	21B
0005435765457	13468	81	21F
0005434265107	13468	82	21H
0005435765513	13468	83	22A
0005435462378	13468	84	22F
0005435765497	13468	85	22H
0005435765460	13468	86	23A
0005434265099	13468	87	23D
0005435765398	13468	88	23B
0005435617170	13468	89	23F
0005434265114	13468	90	23G
0005435462393	13468	91	24A
0005435765717	13468	92	23H
0005435462408	13468	93	24B
0005435765706	13468	94	24E
0005435723020	13468	95	24D
0005435765498	13468	96	24F
0005435462390	13468	97	24G
0005435765666	13468	98	25D
0005435765540	13468	99	25F
0005435462407	13468	100	27A
0005434831149	13468	101	27D
0005435765672	13468	102	27G
0005435462409	13468	103	27E
0005435765620	13468	104	28A
0005435765375	13468	105	28B
0005435765733	13468	106	28E
0005434265119	13468	107	28H
0005435765548	13468	108	29A
0005435765559	13468	109	29B
0005434265105	13468	110	29D
0005434265108	13468	111	29H
0005435765884	13468	112	30A
0005434265117	13468	113	30B
0005434831147	13468	114	30E
0005435735088	13468	115	30G
0005435462404	13468	116	30F
0005435722027	13468	117	31E
0005435462384	13468	118	31D
0005434265111	13468	119	31F
0005435765770	13468	120	31H
0005434265106	13468	121	31G
0005435462386	13468	122	32A
0005434265118	13468	123	32D
0005435765374	13468	124	32E
0005435765600	13468	125	32F
0005435462402	13468	126	32G
0005435765481	13468	127	33A
0005432535830	13468	128	32H
0005435765459	13468	129	33D
0005434265124	13468	130	33E
0005435462400	13468	131	33F
0005435462383	13468	132	33H
0005435765736	13468	133	33G
0005435462398	13468	134	34B
0005435462381	13468	135	34A
0005435765671	13468	136	34D
0005435765707	13468	137	34E
0005435765710	13468	138	34G
0005435462399	13468	139	34F
0005434265103	13468	140	34H
0005435765541	13468	141	35A
0005435765568	13468	142	35D
0005435735105	13468	143	35B
0005435765479	13468	144	35F
0005435462389	13468	145	35E
0005435725533	13468	146	36B
0005434265115	13468	147	36A
0005435462377	13468	148	36E
0005435462380	13468	149	36D
0005435462395	13468	150	36G
0005435735084	13468	151	37A
0005435765663	13468	152	36H
0005435722028	13468	153	37D
0005435765433	13468	154	37B
0005435765525	13468	155	37E
0005434265110	13468	156	37F
0005435462403	13468	157	37H
0005434265102	13468	158	37G
0005435735089	13468	159	38B
0005435765569	13468	160	38A
0005434265122	13468	161	38E
0005435735085	13468	162	38H
0005435735096	13468	163	39E
0005435725542	13468	164	39D
0005434513575	18636	1	1A
0005434604868	18636	2	2A
0005434513574	18636	3	2B
0005434514962	18636	4	3A
0005434514964	18636	5	3B
0005434604846	18636	6	4B
0005434604847	18636	7	5A
0005434514963	18636	8	6A
0005434514947	19139	1	3A
0005434514936	19139	2	4B
0005432649323	25084	1	1C
0005432649382	25084	2	3A
0005432649344	25084	3	3C
0005432649345	25084	4	3D
0005432649349	25084	5	4E
0005432649320	25084	6	7A
0005432649319	25084	7	7D
0005432649346	25084	8	8F
0005435846247	25084	9	9F
0005435846245	25084	10	10A
0005435846249	25084	11	10D
0005435846244	25084	12	11C
0005435846250	25084	13	11D
0005432649327	25084	14	12D
0005435846248	25084	15	12E
0005432649333	25084	16	13C
0005432649381	25084	17	14D
0005432649334	25084	18	18A
0005432649335	25084	19	18E
0005432649363	25084	20	18F
0005432649328	25084	21	19C
0005432649330	25084	22	19D
0005435846246	25084	23	19E
0005433008201	1814	1	1A
0005433008365	1814	2	1D
0005433285072	1814	3	2A
0005433008047	1814	4	2C
0005433008181	1814	5	2D
0005433008032	1814	6	2F
0005433008122	1814	7	3A
0005433008163	1814	8	3C
0005433008357	1814	9	3D
0005433008031	1814	10	3F
0005433008198	1814	11	4A
0005432295876	1814	12	4E
0005433008300	1814	13	4F
0005433284999	1814	14	5A
0005433008019	1814	15	5C
0005433008399	1814	16	5D
0005432295877	1814	17	5F
0005433008280	1814	18	6C
0005433285037	1814	19	6D
0005433008272	1814	20	6E
0005433810541	1814	21	6F
0005433810545	1814	22	7A
0005433008164	1814	23	7C
0005433008033	1814	24	7D
0005433008403	1814	25	7E
0005433008202	1814	26	7F
0005433285186	1814	27	8A
0005433008243	1814	28	8C
0005433008356	1814	29	8D
0005433007921	1814	30	8E
0005433008273	1814	31	8F
0005433008154	1814	32	9A
0005433008157	1814	33	9C
0005433285012	1814	34	9E
0005433285071	1814	35	10A
0005433284936	1814	36	10C
0005432295875	1814	37	10D
0005433008018	1814	38	10E
0005433285056	1814	39	11A
0005433285043	1814	40	11C
0005433008279	1814	41	11D
0005433008046	1814	42	11E
0005433810542	1814	43	12A
0005433810540	1814	44	12C
0005433810543	1814	45	12D
0005433285087	1814	46	12E
0005433008404	1814	47	13C
0005433285024	1814	48	13D
0005433008175	1814	49	14A
0005433008030	1814	50	14C
0005433008172	1814	51	14D
0005433008343	1814	52	15C
0005433284919	1814	53	15D
0005433284981	1814	54	15E
0005433008364	1814	55	16A
0005433810544	1814	56	16D
0005433285095	1814	57	16E
0005433284985	1814	58	16F
0005433008344	1814	59	17A
0005433810538	1814	60	17C
0005433008199	1814	61	17D
0005433285031	1814	62	17E
0005433810539	1814	63	17F
0005433008231	1814	64	18A
0005433008277	1814	65	18C
0005433008402	1814	66	18D
0005433008260	1814	67	18E
0005433008223	1814	68	18F
0005433008354	1814	69	19A
0005433007920	1814	70	19C
0005433284951	1814	71	19D
0005433285094	1814	72	19E
0005433008278	1814	73	20C
0005433284969	1814	74	20E
0005433008041	1814	75	20F
0005433008542	22552	1	1A
0005433008562	22552	2	1C
0005433285238	22552	3	1D
0005433810503	22552	4	1F
0005433285239	22552	5	2A
0005433285258	22552	6	2C
0005433008540	22552	7	2D
0005433008544	22552	8	3A
0005433008538	22552	9	3C
0005433008519	22552	10	4A
0005433285253	22552	11	4C
0005433008557	22552	12	4D
0005433285252	22552	13	4E
0005433008558	22552	14	4F
0005433008531	22552	15	5C
0005433285255	22552	16	5D
0005433008555	22552	17	5E
0005433008539	22552	18	5F
0005433008543	22552	19	6A
0005433008560	22552	20	6D
0005433285245	22552	21	6E
0005433285262	22552	22	6F
0005433008563	22552	23	7C
0005433285243	22552	24	7D
0005433285241	22552	25	7F
0005433008556	22552	26	7E
0005433008520	22552	27	8A
0005433285236	22552	28	8D
0005433008550	22552	29	8F
0005433285244	22552	30	9A
0005433285257	22552	31	9C
0005433285246	22552	32	9D
0005433008551	22552	33	9E
0005433008518	22552	34	9F
0005433008534	22552	35	10A
0005433285248	22552	36	10C
0005433008525	22552	37	10D
0005433008546	22552	38	10E
0005433285232	22552	39	10F
0005433008559	22552	40	11A
0005433285233	22552	41	11E
0005433285256	22552	42	11F
0005433008528	22552	43	12A
0005433008553	22552	44	12C
0005433285247	22552	45	12E
0005433810495	22552	46	13A
0005433008521	22552	47	13C
0005433008561	22552	48	13D
0005433008529	22552	49	13E
0005433285240	22552	50	13F
0005433008535	22552	51	14A
0005433008552	22552	52	14C
0005433008547	22552	53	14D
0005433285242	22552	54	14E
0005433285234	22552	55	14F
0005433008536	22552	56	15A
0005433285254	22552	57	15C
0005433285249	22552	58	15D
0005433008545	22552	59	15E
0005433008533	22552	60	15F
0005433008537	22552	61	16A
0005433285250	22552	62	16D
0005433285263	22552	63	16E
0005433008524	22552	64	17A
0005433008523	22552	65	17C
0005433008532	22552	66	17D
0005433008526	22552	67	17E
0005433008554	22552	68	17F
0005433008530	22552	69	18A
0005433285259	22552	70	18D
0005433008522	22552	71	18E
0005433008541	22552	72	18F
0005433008548	22552	73	19A
0005433285260	22552	74	19E
0005433008527	22552	75	19F
0005433285237	22552	76	20A
0005433285261	22552	77	20C
0005433285235	22552	78	20D
0005433285251	22552	79	20E
0005433008549	22552	80	20F
0005432755035	12290	1	1C
0005432751483	12290	2	1D
0005434152781	12290	3	2F
0005432751481	12290	4	3D
0005432755034	12290	5	4E
0005432755033	12290	6	6E
0005432751484	12290	7	7A
0005432755027	12290	8	7C
0005432751485	12290	9	8A
0005432751494	12290	10	9A
0005432751492	12290	11	9C
0005432751486	12290	12	10C
0005432751487	12290	13	10F
0005432755028	12290	14	11D
0005432755031	12290	15	11F
0005432755047	12290	16	12A
0005432751508	12290	17	16D
0005432755038	12290	18	16F
0005432751502	12290	19	18C
0005432751507	12290	20	18F
0005432755026	12290	21	19A
0005432751478	12290	22	19C
0005432755032	12290	23	19D
0005432751495	12290	24	19E
0005432755036	12290	25	20D
0005433846673	5564	1	1C
0005433846642	5564	2	1A
0005435282192	5564	3	1F
0005433846626	5564	4	1D
0005433846638	5564	5	2A
0005435282274	5564	6	3A
0005435282309	5564	7	2F
0005434173471	5564	8	3D
0005433815378	5564	9	3C
0005433846633	5564	10	4A
0005433846666	5564	11	3F
0005433846674	5564	12	4D
0005433815379	5564	13	4C
0005433846635	5564	14	4F
0005435282229	5564	15	5C
0005433846619	5564	16	5A
0005435282111	5564	17	5F
0005433846624	5564	18	5D
0005435282333	5564	19	6A
0005435282286	5564	20	6D
0005433846658	5564	21	6C
0005433815374	5564	22	6B
0005433846637	5564	23	6E
0005433846639	5564	24	7A
0005432081502	5564	25	7C
0005433846640	5564	26	7B
0005433846676	5564	27	7E
0005432081503	5564	28	7D
0005433846668	5564	29	7F
0005433846654	5564	30	8C
0005433846651	5564	31	8B
0005433846649	5564	32	8A
0005433846665	5564	33	8D
0005432081499	5564	34	8F
0005435282200	5564	35	8E
0005435282231	5564	36	9B
0005433846644	5564	37	9A
0005433846660	5564	38	9C
0005433846661	5564	39	9E
0005435282230	5564	40	9D
0005435282184	5564	41	10A
0005435282246	5564	42	9F
0005433846656	5564	43	10C
0005433846629	5564	44	10B
0005433846659	5564	45	10F
0005435282378	5564	46	11C
0005433846622	5564	47	11B
0005435282185	5564	48	11D
0005433846679	5564	49	11F
0005433846620	5564	50	11E
0005432081504	5564	51	12B
0005433846653	5564	52	12A
0005433846663	5564	53	12C
0005432081505	5564	54	12E
0005433846645	5564	55	13B
0005433846646	5564	56	13A
0005433846677	5564	57	12F
0005433846669	5564	58	13D
0005433846643	5564	59	13F
0005432081501	5564	60	14B
0005433846664	5564	61	14A
0005433846670	5564	62	14E
0005435282271	5564	63	14D
0005433846675	5564	64	14C
0005433846631	5564	65	15A
0005433846655	5564	66	15D
0005433846671	5564	67	16A
0005435282238	5564	68	15F
0005433846621	5564	69	16C
0005433846652	5564	70	16B
0005435282235	5564	71	16D
0005434173470	5564	72	17A
0005433846623	5564	73	16F
0005433846636	5564	74	16E
0005433846632	5564	75	17B
0005435282387	5564	76	17C
0005433846667	5564	77	17F
0005435282352	5564	78	17E
0005433846662	5564	79	18B
0005433846650	5564	80	18A
0005433846630	5564	81	18D
0005433846647	5564	82	18C
0005435282262	5564	83	18E
0005433846625	5564	84	18F
0005434173473	5564	85	19B
0005433846672	5564	86	19A
0005433846657	5564	87	19D
0005432081500	5564	88	19F
0005433846648	5564	89	19E
0005433815375	5564	90	20B
0005433846641	5564	91	20A
0005433846678	5564	92	20D
0005433846628	5564	93	20F
0005433846634	5564	94	20E
0005433815377	5564	95	21B
0005433815376	5564	96	21E
0005433846627	5564	97	21F
0005433845864	13845	1	1C
0005433815312	13845	2	1F
0005433846167	13845	3	1D
0005435282493	13845	4	2C
0005433846148	13845	5	2A
0005433846272	13845	6	2D
0005433846466	13845	7	3A
0005433846147	13845	8	2F
0005433846250	13845	9	3C
0005433846295	13845	10	4A
0005433845865	13845	11	3F
0005433846034	13845	12	4D
0005433846047	13845	13	4C
0005433846179	13845	14	5A
0005433846154	13845	15	4F
0005433846033	13845	16	5F
0005433845992	13845	17	5D
0005433846320	13845	18	6A
0005433846319	13845	19	6D
0005433846109	13845	20	6C
0005433846089	13845	21	6E
0005433845871	13845	22	7A
0005433846072	13845	23	6F
0005433815313	13845	24	7C
0005435282484	13845	25	7B
0005435282492	13845	26	7E
0005433846139	13845	27	7D
0005435282499	13845	28	8A
0005433846241	13845	29	7F
0005433815324	13845	30	8C
0005435282495	13845	31	8B
0005433845869	13845	32	8D
0005435282478	13845	33	8F
0005435282485	13845	34	8E
0005433846273	13845	35	9B
0005433845982	13845	36	9A
0005433846244	13845	37	9D
0005432003698	13845	38	9E
0005433845870	13845	39	10A
0005432003697	13845	40	9F
0005433846312	13845	41	10C
0005433846142	13845	42	10B
0005433846375	13845	43	10E
0005435282482	13845	44	10D
0005433815339	13845	45	10F
0005435282491	13845	46	11B
0005435282483	13845	47	11A
0005435282487	13845	48	11C
0005433845866	13845	49	11F
0005433846181	13845	50	11E
0005433846078	13845	51	12B
0005433846081	13845	52	12A
0005433846214	13845	53	12C
0005433846182	13845	54	12F
0005433845931	13845	55	12E
0005433846090	13845	56	12D
0005435282494	13845	57	13C
0005434173516	13845	58	13B
0005434173517	13845	59	13E
0005433846088	13845	60	13D
0005435282480	13845	61	14A
0005433846465	13845	62	13F
0005435282481	13845	63	14D
0005434173515	13845	64	14C
0005433846206	13845	65	14F
0005433845903	13845	66	14E
0005435282489	13845	67	15B
0005433845993	13845	68	15C
0005435282498	13845	69	15F
0005433846140	13845	70	15E
0005432003696	13845	71	15D
0005433846220	13845	72	16A
0005435282490	13845	73	16C
0005433846187	13845	74	16B
0005433845965	13845	75	16E
0005433846149	13845	76	16D
0005433846372	13845	77	16F
0005433846117	13845	78	17B
0005433846022	13845	79	17A
0005433846110	13845	80	17D
0005435282488	13845	81	17C
0005433846141	13845	82	17F
0005435282496	13845	83	17E
0005435282486	13845	84	18B
0005433846087	13845	85	18A
0005435282479	13845	86	18C
0005433846118	13845	87	18D
0005433845981	13845	88	19A
0005433846035	13845	89	18F
0005433846091	13845	90	19B
0005433846116	13845	91	19D
0005433846036	13845	92	19C
0005433846083	13845	93	19F
0005435282497	13845	94	19E
0005433846108	13845	95	20B
0005433846168	13845	96	20D
0005433846296	13845	97	20C
0005434173514	13845	98	20F
0005433846157	13845	99	21C
0005433846237	13845	100	21B
0005433845904	13845	101	21E
0005433846251	13845	102	21F
0005434620563	7845	1	1B
0005435332256	7845	2	1C
0005434620573	7845	3	1D
0005434620567	7845	4	2A
0005435332211	7845	5	2C
0005434620571	7845	6	2D
0005434620566	7845	7	3C
0005434620559	7845	8	4A
0005434620578	7845	9	4C
0005432112513	7845	10	5A
0005434620570	7845	11	5B
0005434620560	7845	12	5C
0005434620579	7845	13	5D
0005435332201	7845	14	6A
0005434620558	7845	15	6D
0005434620565	7845	16	7B
0005435332289	7845	17	7C
0005434620562	7845	18	7D
0005434620561	7845	19	18C
0005435332224	7845	20	19A
0005435332227	7845	21	19B
0005435332221	7845	22	20B
0005434620569	7845	23	20D
0005434620576	7845	24	21A
0005434620577	7845	25	21B
0005435332214	7845	26	21C
0005434620572	7845	27	21D
0005434620568	7845	28	22A
0005434620574	7845	29	22B
0005434620564	7845	30	22C
0005434620575	7845	31	23A
0005435332215	7845	32	23B
0005434620403	32974	1	1C
0005434620317	32974	2	1D
0005434620333	32974	3	2A
0005434620337	32974	4	2B
0005434620424	32974	5	2D
0005434620425	32974	6	3A
0005434620404	32974	7	3B
0005435332326	32974	8	3C
0005435332324	32974	9	4B
0005435332322	32974	10	4C
0005434620397	32974	11	4D
0005435332317	32974	12	5A
0005435332327	32974	13	5B
0005434620409	32974	14	5C
0005434620429	32974	15	5D
0005435332316	32974	16	6A
0005434620394	32974	17	7B
0005434620421	32974	18	7C
0005434620478	32974	19	7D
0005435332319	32974	20	18A
0005434620477	32974	21	18B
0005434620503	32974	22	18D
0005434620408	32974	23	19A
0005435332320	32974	24	19B
0005434620372	32974	25	19D
0005434620327	32974	26	20A
0005434620272	32974	27	20B
0005435332321	32974	28	20C
0005435332318	32974	29	20D
0005434620411	32974	30	21A
0005434620334	32974	31	21B
0005434620350	32974	32	21C
0005434620398	32974	33	22B
0005435332323	32974	34	22C
0005434620401	32974	35	22D
0005435332325	32974	36	23A
0005434620371	32974	37	23B
0005435937321	4284	1	1A
0005435785294	4284	2	1D
0005435787352	4284	3	1F
0005434994007	4284	4	2C
0005435785302	4284	5	3C
0005432190624	4284	6	3D
0005435785301	4284	7	3F
0005435785303	4284	8	4C
0005435785298	4284	9	4F
0005434994006	4284	10	5A
0005435785310	4284	11	5E
0005435785326	4284	12	6A
0005435785320	4284	13	6C
0005434994009	4284	14	6F
0005435785314	4284	15	7A
0005432190627	4284	16	8C
0005435785329	4284	17	8D
0005435918607	4284	18	8E
0005434994008	4284	19	8F
0005435785330	4284	20	9A
0005434994014	4284	21	9C
0005435785311	4284	22	9F
0005435787353	4284	23	10A
0005435785299	4284	24	10E
0005435785300	4284	25	10F
0005435785327	4284	26	11C
0005432190625	4284	27	11D
0005435787351	4284	28	11E
0005435785306	4284	29	11F
0005435785297	4284	30	12A
0005435785328	4284	31	12C
0005432190626	4284	32	12D
0005435937327	4284	33	12E
0005435785309	4284	34	12F
0005435785312	4284	35	13A
0005435785316	4284	36	13C
0005435785322	4284	37	13E
0005435785317	4284	38	13F
0005435937320	4284	39	14A
0005434994011	4284	40	14F
0005435785313	4284	41	15C
0005434994012	4284	42	15D
0005435785319	4284	43	15E
0005435785318	4284	44	15F
0005435785308	4284	45	16A
0005434994013	4284	46	16D
0005435785295	4284	47	17D
0005435785323	4284	48	17F
0005435785315	4284	49	18A
0005435785321	4284	50	18C
0005435785305	4284	51	18E
0005435785304	4284	52	18F
0005435785296	4284	53	19A
0005435785325	4284	54	19E
0005435787350	4284	55	19F
0005435785324	4284	56	20A
0005434994010	4284	57	20E
0005435785307	4284	58	20F
0005435784940	27314	1	1A
0005434993942	27314	2	1C
0005435784895	27314	3	2C
0005435784852	27314	4	2D
0005434993943	27314	5	2F
0005435785017	27314	6	3A
0005435784729	27314	7	3C
0005434993931	27314	8	4A
0005435937379	27314	9	4C
0005432195688	27314	10	4D
0005435785010	27314	11	4E
0005435937382	27314	12	4F
0005434993945	27314	13	5A
0005435784941	27314	14	5C
0005435784841	27314	15	5D
0005432195689	27314	16	5F
0005435937381	27314	17	6A
0005435784851	27314	18	6C
0005435937377	27314	19	6D
0005435785027	27314	20	6E
0005435784926	27314	21	6F
0005435784849	27314	22	7A
0005435784916	27314	23	7E
0005435784955	27314	24	7F
0005434993916	27314	25	8A
0005435918648	27314	26	8D
0005432195691	27314	27	8E
0005435784956	27314	28	8F
0005435784834	27314	29	9A
0005435785009	27314	30	9C
0005434993932	27314	31	10D
0005435937380	27314	32	10E
0005435918649	27314	33	10F
0005434993944	27314	34	11C
0005435784981	27314	35	12C
0005435784930	27314	36	12D
0005432195690	27314	37	12E
0005434993918	27314	38	13A
0005435784835	27314	39	13D
0005434993949	27314	40	13E
0005435784847	27314	41	14A
0005435784809	27314	42	14E
0005435784848	27314	43	15A
0005435784929	27314	44	15E
0005435785018	27314	45	15F
0005435784957	27314	46	16A
0005435918650	27314	47	16C
0005435784927	27314	48	16D
0005435784980	27314	49	16E
0005435785037	27314	50	16F
0005435784819	27314	51	17A
0005435937378	27314	52	17C
0005435784992	27314	53	17D
0005435784938	27314	54	17E
0005435785036	27314	55	17F
0005435784871	27314	56	18A
0005435918651	27314	57	18D
0005435937376	27314	58	18E
0005435918647	27314	59	18F
0005435785008	27314	60	19A
0005435784937	27314	61	19E
0005435937375	27314	62	20A
0005434993925	27314	63	20D
0005432146195	19890	1	20C
0005432459794	4723	1	1A
0005432459772	4723	2	1B
0005432567568	4723	3	1F
0005432567552	4723	4	1H
0005434081888	4723	5	1G
0005434081879	4723	6	2A
0005432567542	4723	7	2B
0005434081878	4723	8	2C
0005432567578	4723	9	2G
0005432567565	4723	10	2F
0005432170375	4723	11	2H
0005434081887	4723	12	3B
0005434081875	4723	13	3A
0005432459793	4723	14	3C
0005432567589	4723	15	3G
0005432567548	4723	16	3F
0005434081872	4723	17	4A
0005434081865	4723	18	3H
0005432459800	4723	19	4B
0005434081860	4723	20	4C
0005432459758	4723	21	4G
0005432459764	4723	22	4F
0005432170378	4723	23	5A
0005432459760	4723	24	5C
0005432459765	4723	25	5F
0005434081885	4723	26	5H
0005432571316	4723	27	9B
0005432459804	4723	28	9A
0005432459780	4723	29	9G
0005432459776	4723	30	11A
0005432459805	4723	31	9H
0005432567538	4723	32	11D
0005434081877	4723	33	11F
0005432567572	4723	34	11H
0005434081861	4723	35	11G
0005432459811	4723	36	12A
0005432567549	4723	37	12B
0005432567574	4723	38	12D
0005432170380	4723	39	12G
0005433451616	4723	40	12H
0005434081884	4723	41	13A
0005432459796	4723	42	13D
0005432567579	4723	43	13B
0005434081864	4723	44	14B
0005432567560	4723	45	14A
0005432186865	4723	46	14D
0005432567580	4723	47	14F
0005432567553	4723	48	15A
0005432567530	4723	49	14H
0005432459763	4723	50	15D
0005432567536	4723	51	15E
0005432567550	4723	52	15H
0005432459812	4723	53	15G
0005432571317	4723	54	16A
0005432459768	4723	55	16D
0005434081866	4723	56	16B
0005432567570	4723	57	16E
0005432567556	4723	58	16F
0005434081869	4723	59	16H
0005432459783	4723	60	17G
0005434081883	4723	61	17F
0005432170377	4723	62	17H
0005432459786	4723	63	18D
0005432459789	4723	64	18F
0005432459785	4723	65	18E
0005432567581	4723	66	18G
0005434081881	4723	67	19E
0005432567567	4723	68	19F
0005432567546	4723	69	19H
0005432459801	4723	70	19G
0005433726102	4723	71	20A
0005434081862	4723	72	20B
0005433451617	4723	73	20E
0005432186864	4723	74	20D
0005432459809	4723	75	20F
0005432459803	4723	76	20H
0005432459782	4723	77	20G
0005432459773	4723	78	21B
0005432459784	4723	79	21A
0005434081870	4723	80	21D
0005433452736	4723	81	21E
0005434081863	4723	82	21G
0005432170376	4723	83	21F
0005432571318	4723	84	21H
0005434081889	4723	85	22B
0005432567534	4723	86	22A
0005432459808	4723	87	22D
0005434081859	4723	88	22E
0005434081891	4723	89	22G
0005432567575	4723	90	22F
0005432459799	4723	91	22H
0005432567587	4723	92	23A
0005432459777	4723	93	23D
0005432567563	4723	94	23B
0005432459781	4723	95	23F
0005432567577	4723	96	23G
0005432571319	4723	97	24A
0005432459771	4723	98	23H
0005432567547	4723	99	24B
0005432459767	4723	100	24D
0005432567566	4723	101	24G
0005434081880	4723	102	25D
0005432567561	4723	103	25F
0005432567533	4723	104	27A
0005432567584	4723	105	27E
0005432186866	4723	106	27D
0005432567576	4723	107	27G
0005432459791	4723	108	27F
0005433452737	4723	109	28A
0005432459790	4723	110	28E
0005434081873	4723	111	28D
0005432567557	4723	112	28G
0005432567571	4723	113	28F
0005432567564	4723	114	28H
0005432567526	4723	115	29A
0005432459761	4723	116	29D
0005432567543	4723	117	29B
0005432459810	4723	118	29E
0005432567555	4723	119	29F
0005432567558	4723	120	29H
0005432567569	4723	121	30D
0005432567541	4723	122	30F
0005432459770	4723	123	30G
0005434081882	4723	124	31A
0005432567545	4723	125	31B
0005432459766	4723	126	31E
0005432459792	4723	127	31D
0005432567588	4723	128	31F
0005434081867	4723	129	31H
0005432567539	4723	130	31G
0005432567540	4723	131	32A
0005432567586	4723	132	32F
0005432459779	4723	133	32H
0005432459788	4723	134	32G
0005432459762	4723	135	33A
0005434081886	4723	136	33B
0005432567544	4723	137	33E
0005432567562	4723	138	33G
0005432567583	4723	139	33F
0005432170381	4723	140	33H
0005432459774	4723	141	34A
0005432567531	4723	142	34D
0005432567551	4723	143	34E
0005432567535	4723	144	34F
0005432459802	4723	145	34H
0005432459798	4723	146	35B
0005432459769	4723	147	35A
0005432459795	4723	148	35D
0005432459759	4723	149	35G
0005432567528	4723	150	35F
0005434081874	4723	151	35H
0005432567554	4723	152	36B
0005432459778	4723	153	36A
0005432567573	4723	154	36F
0005432567529	4723	155	36E
0005432459807	4723	156	36H
0005432459797	4723	157	36G
0005432459806	4723	158	37A
0005433726101	4723	159	37B
0005434081876	4723	160	37E
0005432567585	4723	161	37D
0005432459775	4723	162	37F
0005432459787	4723	163	37H
0005432567537	4723	164	37G
0005434081871	4723	165	38A
0005432567582	4723	166	38B
0005434081890	4723	167	38F
0005432567527	4723	168	38G
0005432170379	4723	169	38H
0005434081868	4723	170	39E
0005432567559	4723	171	39D
0005432567532	4723	172	39F
0005434081583	30555	1	1C
0005432566941	30555	2	1F
0005432566981	30555	3	1H
0005432567080	30555	4	2A
0005434081592	30555	5	2C
0005432459386	30555	6	2G
0005432459375	30555	7	2H
0005432459487	30555	8	3B
0005432566971	30555	9	3A
0005432567106	30555	10	3F
0005432567124	30555	11	3C
0005434081659	30555	12	3H
0005432459258	30555	13	3G
0005432566976	30555	14	4A
0005432567345	30555	15	4B
0005434081537	30555	16	4C
0005432459134	30555	17	4G
0005432567176	30555	18	5B
0005432567153	30555	19	5A
0005432567100	30555	20	5C
0005434081699	30555	21	9A
0005432459365	30555	22	9B
0005432459305	30555	23	9G
0005432459357	30555	24	11B
0005434081718	30555	25	11E
0005433726066	30555	26	11D
0005432459421	30555	27	11F
0005432459312	30555	28	11G
0005432567076	30555	29	11H
0005432566782	30555	30	12D
0005432459356	30555	31	12B
0005434081668	30555	32	12E
0005432459445	30555	33	12G
0005432567004	30555	34	12F
0005432567081	30555	35	13A
0005432567023	30555	36	12H
0005432567092	30555	37	13B
0005432213602	30555	38	13D
0005432567425	30555	39	13E
0005434081672	30555	40	13G
0005433726068	30555	41	13F
0005432567126	30555	42	13H
0005434081698	30555	43	14B
0005432567134	30555	44	14D
0005432459238	30555	45	14G
0005432566983	30555	46	15A
0005432459427	30555	47	14H
0005432567115	30555	48	15B
0005434081630	30555	49	15D
0005433726069	30555	50	15F
0005432567075	30555	51	15H
0005432566772	30555	52	16E
0005432566796	30555	53	16D
0005434081683	30555	54	16G
0005434081700	30555	55	16F
0005432459390	30555	56	16H
0005434081703	30555	57	17A
0005432566864	30555	58	17D
0005432459557	30555	59	17B
0005432566783	30555	60	17E
0005432213600	30555	61	17F
0005432567042	30555	62	18A
0005432567038	30555	63	17H
0005432567132	30555	64	17G
0005432459507	30555	65	18B
0005432213603	30555	66	18D
0005432459311	30555	67	18E
0005432213601	30555	68	18G
0005432459583	30555	69	18F
0005434081584	30555	70	19A
0005432567117	30555	71	18H
0005432567030	30555	72	19D
0005432459585	30555	73	19B
0005432459388	30555	74	19F
0005432567229	30555	75	19E
0005432567342	30555	76	19H
0005434081675	30555	77	20D
0005432566822	30555	78	20B
0005434081629	30555	79	20E
0005432459560	30555	80	20F
0005434081660	30555	81	20H
0005433452719	30555	82	20G
0005432567053	30555	83	21A
0005432459397	30555	84	21D
0005432567338	30555	85	21F
0005432161149	30555	86	21E
0005432567056	30555	87	21G
0005434081705	30555	88	21H
0005432566987	30555	89	22D
0005432566938	30555	90	22E
0005432566945	30555	91	22G
0005432567159	30555	92	23B
0005434081649	30555	93	23A
0005432459087	30555	94	23E
0005432459354	30555	95	23G
0005432567029	30555	96	23F
0005432567131	30555	97	23H
0005432459257	30555	98	24B
0005432459584	30555	99	24A
0005432567420	30555	100	24F
0005432567154	30555	101	24G
0005432567426	30555	102	24H
0005432459310	30555	103	25E
0005432567397	30555	104	27A
0005432567046	30555	105	27B
0005434081652	30555	106	27F
0005432567174	30555	107	27H
0005432567093	30555	108	27G
0005434081704	30555	109	28A
0005434081709	30555	110	28D
0005433726071	30555	111	28B
0005432459559	30555	112	28F
0005432567008	30555	113	28G
0005433726072	30555	114	29A
0005432459488	30555	115	29D
0005432459385	30555	116	29H
0005432567260	30555	117	30D
0005432459366	30555	118	30B
0005433726067	30555	119	30F
0005432567197	30555	120	30E
0005432459444	30555	121	30G
0005432459439	30555	122	30H
0005432567384	30555	123	31B
0005434081531	30555	124	31A
0005432459446	30555	125	31E
0005433726063	30555	126	31F
0005432567116	30555	127	31G
0005432567107	30555	128	32B
0005432459532	30555	129	32E
0005432566970	30555	130	32D
0005432567079	30555	131	32F
0005432571269	30555	132	32G
0005433452721	30555	133	33A
0005432566865	30555	134	32H
0005433726070	30555	135	33B
0005432567024	30555	136	33E
0005432566939	30555	137	33D
0005434081543	30555	138	33F
0005432567099	30555	139	33H
0005432567339	30555	140	33G
0005432566951	30555	141	34A
0005434081591	30555	142	34E
0005432567087	30555	143	34G
0005432567239	30555	144	34F
0005432567047	30555	145	34H
0005432566878	30555	146	35A
0005432459268	30555	147	35D
0005432459561	30555	148	35B
0005434081671	30555	149	35E
0005432567012	30555	150	35G
0005434081595	30555	151	35F
0005434081674	30555	152	35H
0005432161150	30555	153	36B
0005432567240	30555	154	36D
0005432459426	30555	155	36F
0005432459453	30555	156	36E
0005434081585	30555	157	36H
0005432571280	30555	158	37A
0005434081635	30555	159	37B
0005432566946	30555	160	37E
0005432459389	30555	161	37D
0005432459355	30555	162	37F
0005432566797	30555	163	37G
0005432567145	30555	164	38A
0005432459384	30555	165	38D
0005432459489	30555	166	38G
0005432567259	30555	167	38F
0005434081701	30555	168	38H
0005432567009	30555	169	39D
0005432567026	30555	170	39F
0005432567343	30555	171	39E
0005435722051	13632	1	2A
0005435722052	13632	2	3A
0005435722053	13632	3	4B
0005435720120	21221	1	2A
0005435722038	21221	2	5A
0005432295877	22789	1	5C
0005432295875	22789	2	19C
0005432295876	22789	3	21D
0005433343085	11125	1	1A
0005433343043	11125	2	1C
0005433343057	11125	3	1D
0005435097183	11125	4	1F
0005433343078	11125	5	2A
0005433343019	11125	6	2D
0005435508239	11125	7	2C
0005435508242	11125	8	2F
0005433343016	11125	9	3A
0005433343039	11125	10	3C
0005433343106	11125	11	3F
0005435508236	11125	12	3D
0005433343041	11125	13	4A
0005433343093	11125	14	4B
0005435097188	11125	15	4C
0005433343071	11125	16	4E
0005433343046	11125	17	4D
0005433343033	11125	18	4F
0005435380249	11125	19	5A
0005433343075	11125	20	5C
0005433343050	11125	21	5B
0005433343099	11125	22	5D
0005433343091	11125	23	5F
0005433343088	11125	24	5E
0005433343030	11125	25	6A
0005433343068	11125	26	6C
0005433343083	11125	27	6B
0005433343084	11125	28	6D
0005433343074	11125	29	6E
0005435508228	11125	30	6F
0005433343103	11125	31	7B
0005433343015	11125	32	7A
0005433343060	11125	33	7C
0005433343026	11125	34	7E
0005433343102	11125	35	7D
0005433343038	11125	36	7F
0005433343087	11125	37	8A
0005433343051	11125	38	8B
0005433343025	11125	39	8C
0005435097184	11125	40	8D
0005433343020	11125	41	8F
0005433343082	11125	42	8E
0005433343032	11125	43	9A
0005433343086	11125	44	9B
0005435508243	11125	45	9C
0005435508261	11125	46	9E
0005433343053	11125	47	9D
0005435097189	11125	48	9F
0005433343077	11125	49	10B
0005433343065	11125	50	10C
0005435508227	11125	51	10D
0005433343076	11125	52	11A
0005433343049	11125	53	10E
0005433343067	11125	54	11B
0005433343061	11125	55	11E
0005433343042	11125	56	11D
0005433343012	11125	57	11F
0005433343063	11125	58	12A
0005433343100	11125	59	12B
0005435380268	11125	60	12D
0005433343052	11125	61	12C
0005433343014	11125	62	12E
0005433343048	11125	63	12F
0005433343080	11125	64	13A
0005435097185	11125	65	13B
0005433343011	11125	66	13D
0005433343104	11125	67	13C
0005433343031	11125	68	14A
0005433343079	11125	69	14B
0005433343024	11125	70	14C
0005433343107	11125	71	14D
0005433343017	11125	72	14E
0005435097186	11125	73	15A
0005433343072	11125	74	14F
0005433343029	11125	75	15C
0005433343037	11125	76	15B
0005433343094	11125	77	15D
0005433343073	11125	78	15E
0005433343090	11125	79	16A
0005433343047	11125	80	15F
0005435508260	11125	81	16B
0005433343069	11125	82	16C
0005435508271	11125	83	16D
0005433343045	11125	84	16E
0005433343108	11125	85	17A
0005433343035	11125	86	16F
0005435508258	11125	87	17D
0005433343056	11125	88	17C
0005433343070	11125	89	17E
0005433343064	11125	90	17F
0005433343055	11125	91	18A
0005433343066	11125	92	18C
0005433343092	11125	93	18B
0005435508272	11125	94	18E
0005433343023	11125	95	18D
0005435097181	11125	96	18F
0005433343097	11125	97	19A
0005433343054	11125	98	19B
0005433343081	11125	99	19C
0005433343036	11125	100	19E
0005433343059	11125	101	19D
0005433343010	11125	102	19F
0005433343095	11125	103	20B
0005433343058	11125	104	20A
0005433343040	11125	105	20C
0005433343096	11125	106	20D
0005433343034	11125	107	20E
0005433343022	11125	108	21A
0005433343109	11125	109	20F
0005433343018	11125	110	21B
0005435097187	11125	111	21C
0005433343098	11125	112	21D
0005433343089	11125	113	21E
0005433343021	11125	114	22A
0005435508257	11125	115	21F
0005433343062	11125	116	22C
0005433343044	11125	117	22B
0005433343101	11125	118	22E
0005435380248	11125	119	22D
0005433343110	11125	120	23A
0005433343105	11125	121	22F
0005433343028	11125	122	23B
0005435097182	11125	123	23D
0005433343027	11125	124	23C
0005433343009	11125	125	23F
0005433343013	11125	126	23E
0005435380292	17087	1	1A
0005433342253	17087	2	1C
0005433342268	17087	3	1F
0005435380289	17087	4	1D
0005433342069	17087	5	2C
0005433342091	17087	6	2A
0005433342292	17087	7	2F
0005433342005	17087	8	2D
0005433342345	17087	9	3A
0005435097096	17087	10	3D
0005433342092	17087	11	3C
0005435097074	17087	12	3F
0005435545723	17087	13	4B
0005433341758	17087	14	4A
0005435545724	17087	15	4C
0005435545728	17087	16	4D
0005433342007	17087	17	4F
0005435380291	17087	18	5B
0005433342153	17087	19	5A
0005435545732	17087	20	5C
0005433341822	17087	21	5F
0005433342233	17087	22	5E
0005433341736	17087	23	6B
0005433342267	17087	24	6A
0005433342350	17087	25	6C
0005435097114	17087	26	6D
0005433342344	17087	27	6E
0005433342266	17087	28	7A
0005433342279	17087	29	6F
0005433341778	17087	30	7B
0005433342169	17087	31	7C
0005433341884	17087	32	7D
0005433342134	17087	33	7F
0005433342200	17087	34	7E
0005433342352	17087	35	8B
0005433341608	17087	36	8A
0005433342119	17087	37	8D
0005433342010	17087	38	8C
0005433342389	17087	39	8F
0005433342293	17087	40	8E
0005433341780	17087	41	9B
0005435545730	17087	42	9C
0005433342089	17087	43	9D
0005433342387	17087	44	9F
0005435097107	17087	45	9E
0005435380290	17087	46	10C
0005433342148	17087	47	10B
0005433342416	17087	48	10D
0005435097092	17087	49	10E
0005435097073	17087	50	11A
0005435097093	17087	51	11C
0005435545726	17087	52	11B
0005433342090	17087	53	11E
0005433341955	17087	54	11D
0005433341879	17087	55	11F
0005433341735	17087	56	12A
0005433341642	17087	57	12B
0005433341960	17087	58	12C
0005433342123	17087	59	12E
0005435380293	17087	60	12D
0005433341528	17087	61	12F
0005433342113	17087	62	13A
0005433342015	17087	63	13B
0005433342117	17087	64	13D
0005435097106	17087	65	13C
0005433342252	17087	66	13E
0005433342027	17087	67	13F
0005433342397	17087	68	14B
0005433342114	17087	69	14A
0005433342132	17087	70	14C
0005433341708	17087	71	14D
0005435097105	17087	72	15A
0005433342147	17087	73	15C
0005433342247	17087	74	15B
0005433342137	17087	75	15D
0005433342112	17087	76	15E
0005435097112	17087	77	16A
0005433342009	17087	78	16C
0005433342227	17087	79	16D
0005433342128	17087	80	16E
0005433342006	17087	81	16F
0005435545734	17087	82	17A
0005433342289	17087	83	17C
0005435545733	17087	84	17E
0005433342351	17087	85	17D
0005435545725	17087	86	18A
0005433342154	17087	87	17F
0005433341472	17087	88	18B
0005435380288	17087	89	18C
0005433341529	17087	90	18F
0005433342168	17087	91	18E
0005433342008	17087	92	19A
0005432293206	17087	93	19B
0005433342166	17087	94	19C
0005435097115	17087	95	19E
0005435097094	17087	96	19D
0005433341590	17087	97	19F
0005433342170	17087	98	20A
0005433342135	17087	99	20B
0005435545731	17087	100	20C
0005433342396	17087	101	20E
0005433342234	17087	102	20F
0005433341775	17087	103	21A
0005433342386	17087	104	21C
0005435545735	17087	105	21B
0005433342235	17087	106	21D
0005433342201	17087	107	21E
0005433342136	17087	108	22A
0005433342146	17087	109	21F
0005435545729	17087	110	22C
0005433341924	17087	111	22B
0005432293205	17087	112	22D
0005433342398	17087	113	22F
0005433341928	17087	114	22E
0005435545727	17087	115	23A
0005433342140	17087	116	23B
0005435097113	17087	117	23E
0005433342186	17087	118	23D
0005433341878	17087	119	23F
0005433507159	9068	1	1A
0005432919703	9068	2	1C
0005432919505	9068	3	2A
0005432919650	9068	4	3A
0005433507161	9068	5	3D
0005433507170	9068	6	3F
0005433507169	9068	7	4A
0005432919613	9068	8	4C
0005433481159	9068	9	4F
0005433481155	9068	10	5A
0005433481163	9068	11	5F
0005433507164	9068	12	6C
0005433481158	9068	13	6D
0005433481156	9068	14	6E
0005432919532	9068	15	7C
0005433507171	9068	16	7D
0005433507163	9068	17	7E
0005433507167	9068	18	8A
0005432919625	9068	19	8E
0005433507165	9068	20	9C
0005433507174	9068	21	9D
0005432919651	9068	22	10A
0005432919647	9068	23	10E
0005433507166	9068	24	10F
0005433481160	9068	25	11C
0005432919683	9068	26	11D
0005433507160	9068	27	11E
0005432919637	9068	28	12A
0005432919630	9068	29	12C
0005432919682	9068	30	12D
0005432919649	9068	31	12E
0005432919713	9068	32	13A
0005433507162	9068	33	13C
0005433507172	9068	34	13D
0005432919706	9068	35	14A
0005433507173	9068	36	14D
0005432919693	9068	37	14E
0005433507158	9068	38	14F
0005432919712	9068	39	15C
0005432919719	9068	40	15D
0005433481162	9068	41	16A
0005432919646	9068	42	16D
0005432919603	9068	43	16E
0005433507175	9068	44	16F
0005432919670	9068	45	17D
0005433507176	9068	46	17E
0005432919574	9068	47	17F
0005432919648	9068	48	18C
0005432919668	9068	49	19A
0005433507168	9068	50	19D
0005433481161	9068	51	19F
0005433481157	9068	52	20A
0005433507157	9068	53	20C
0005432919698	9068	54	20D
0005433507002	20465	1	1A
0005433506948	20465	2	1D
0005433507003	20465	3	1F
0005432919851	20465	4	2A
0005432919859	20465	5	2C
0005433507041	20465	6	2F
0005433507054	20465	7	3C
0005432919857	20465	8	3D
0005433507042	20465	9	5A
0005433507040	20465	10	5C
0005434158973	20465	11	5D
0005432919856	20465	12	5E
0005434158974	20465	13	5F
0005433481094	20465	14	6A
0005432919863	20465	15	6C
0005433507015	20465	16	6D
0005432919865	20465	17	6E
0005433506968	20465	18	6F
0005432919850	20465	19	7D
0005433481121	20465	20	7E
0005432919866	20465	21	8E
0005432919855	20465	22	9A
0005432919845	20465	23	9C
0005433507016	20465	24	9D
0005433481106	20465	25	9E
0005432919867	20465	26	10A
0005432919854	20465	27	10E
0005433481114	20465	28	10F
0005433507026	20465	29	11C
0005433506940	20465	30	11D
0005433481105	20465	31	12A
0005433506945	20465	32	12F
0005432919852	20465	33	13A
0005432919847	20465	34	13D
0005433507071	20465	35	13E
0005433507072	20465	36	13F
0005433507053	20465	37	14A
0005432919862	20465	38	14E
0005433507004	20465	39	15F
0005433481088	20465	40	16A
0005433481126	20465	41	16C
0005433506941	20465	42	16D
0005432919849	20465	43	16E
0005433506946	20465	44	17C
0005432919861	20465	45	17D
0005432919848	20465	46	18A
0005432919860	20465	47	18C
0005432919858	20465	48	18D
0005432919846	20465	49	18E
0005433481104	20465	50	18F
0005433506978	20465	51	19D
0005433507025	20465	52	19E
0005433481113	20465	53	19F
0005433507058	20465	54	20A
0005432919853	20465	55	20D
0005432919864	20465	56	20F
0005432396233	10212	1	1B
0005432394097	10212	2	2A
0005432396236	10212	3	2B
0005432394096	10212	4	3A
0005435178977	10212	5	4A
0005432396234	10212	6	4B
0005432394095	10212	7	5A
0005432396235	10212	8	6A
0005432394094	10212	9	5B
0005432394098	10212	10	6B
0005432400076	18312	1	1A
0005432400081	18312	2	1B
0005432400094	18312	3	2B
0005432400091	18312	4	3A
0005432400093	18312	5	3B
0005432400077	18312	6	4B
0005432400080	18312	7	5B
0005432400075	18312	8	5A
0005435179692	18312	9	6A
0005432400095	18312	10	6B
0005435625988	10934	1	1A
0005435126100	10934	2	1C
0005435126060	10934	3	1D
0005434411775	10934	4	1F
0005435125945	10934	5	2A
0005435125888	10934	6	2C
0005435625949	10934	7	2D
0005435554146	10934	8	2F
0005435125960	10934	9	3A
0005435126061	10934	10	3C
0005435126101	10934	11	3D
0005435625963	10934	12	3F
0005435126014	10934	13	4A
0005435126035	10934	14	4D
0005435125961	10934	15	4F
0005435125975	10934	16	5A
0005434928298	10934	17	5C
0005435625928	10934	18	5D
0005435125902	10934	19	5E
0005435126018	10934	20	5F
0005435125944	10934	21	6A
0005435554139	10934	22	6C
0005434411774	10934	23	6D
0005435625983	10934	24	6E
0005435125951	10934	25	7C
0005435625955	10934	26	7D
0005435126013	10934	27	7E
0005435625982	10934	28	8A
0005435625967	10934	29	8C
0005435556667	10934	30	8D
0005435625939	10934	31	8E
0005435125848	10934	32	8F
0005435125996	10934	33	9A
0005434928295	10934	34	9C
0005435125826	10934	35	9D
0005435556666	10934	36	9E
0005435125942	10934	37	9F
0005435126037	10934	38	10A
0005435625992	10934	39	10C
0005435126030	10934	40	10D
0005435126041	10934	41	10E
0005435125977	10934	42	11C
0005435126074	10934	43	11D
0005435125838	10934	44	11E
0005435126012	10934	45	12A
0005435125865	10934	46	12C
0005435625991	10934	47	12D
0005435125868	10934	48	12E
0005435125946	10934	49	12F
0005435125859	10934	50	13A
0005435625990	10934	51	13C
0005435125964	10934	52	13D
0005434928296	10934	53	13E
0005435625950	10934	54	14A
0005435125989	10934	55	14C
0005435625968	10934	56	14E
0005435126036	10934	57	14F
0005435125903	10934	58	15A
0005435126001	10934	59	15C
0005434411772	10934	60	15D
0005435125829	10934	61	15E
0005435125976	10934	62	15F
0005435126079	10934	63	16A
0005435126112	10934	64	16C
0005435125858	10934	65	16D
0005435125990	10934	66	16E
0005435125880	10934	67	16F
0005435625936	10934	68	17C
0005435625892	10934	69	17D
0005435125978	10934	70	17F
0005435625966	10934	71	18A
0005435625938	10934	72	18D
0005435554134	10934	73	18E
0005435625984	10934	74	18F
0005434928299	10934	75	19A
0005434411773	10934	76	19C
0005435126116	10934	77	19D
0005435625987	10934	78	19E
0005434928297	10934	79	20A
0005435125837	10934	80	20C
0005435554133	10934	81	20D
0005435625986	10934	82	20E
0005435125970	10934	83	20F
0005434928272	14688	1	1A
0005435126350	14688	2	1C
0005435626154	14688	3	1F
0005435126348	14688	4	1D
0005435126317	14688	5	2A
0005435626150	14688	6	2D
0005434411706	14688	7	2F
0005434928274	14688	8	3A
0005435626164	14688	9	3C
0005434411727	14688	10	3D
0005435126316	14688	11	3F
0005435626145	14688	12	4A
0005435626153	14688	13	4C
0005435126326	14688	14	4D
0005435126340	14688	15	4E
0005435126323	14688	16	4F
0005435126329	14688	17	5A
0005435126354	14688	18	5E
0005435626149	14688	19	5F
0005435556689	14688	20	6D
0005435626148	14688	21	7A
0005435126330	14688	22	7D
0005435126324	14688	23	7E
0005435126341	14688	24	8A
0005435626159	14688	25	8C
0005435126331	14688	26	8D
0005435626160	14688	27	8E
0005435126318	14688	28	9A
0005435626152	14688	29	9C
0005435126332	14688	30	9D
0005435126319	14688	31	9E
0005435126327	14688	32	9F
0005435126351	14688	33	10A
0005434411705	14688	34	10C
0005435626155	14688	35	10E
0005435626147	14688	36	11A
0005435126334	14688	37	11C
0005435554178	14688	38	11D
0005435126349	14688	39	11E
0005435126342	14688	40	11F
0005434928275	14688	41	12A
0005435126315	14688	42	12C
0005435126338	14688	43	12D
0005435126353	14688	44	12E
0005434928276	14688	45	12F
0005435556690	14688	46	13A
0005435126343	14688	47	13C
0005435626157	14688	48	13D
0005435554177	14688	49	13E
0005435126337	14688	50	13F
0005434411736	14688	51	14A
0005435126320	14688	52	14C
0005435126333	14688	53	14D
0005435126346	14688	54	14E
0005435126335	14688	55	14F
0005434411737	14688	56	15C
0005435554179	14688	57	15E
0005435626151	14688	58	15D
0005435626158	14688	59	15F
0005435126314	14688	60	16A
0005435626162	14688	61	16C
0005435626146	14688	62	16D
0005435626163	14688	63	16E
0005435554181	14688	64	17A
0005435126336	14688	65	17C
0005434928271	14688	66	17D
0005435626161	14688	67	17F
0005435556688	14688	68	18A
0005435126321	14688	69	18C
0005435126345	14688	70	18D
0005435126344	14688	71	18E
0005435126339	14688	72	18F
0005434411735	14688	73	19A
0005435126325	14688	74	19C
0005435126347	14688	75	19D
0005435126328	14688	76	19F
0005435626156	14688	77	20A
0005435554180	14688	78	20C
0005435126352	14688	79	20D
0005435126322	14688	80	20E
0005435715446	7136	1	1A
0005435715447	7136	2	1D
0005435715444	7136	3	2F
0005435216563	7136	4	3C
0005435443255	7136	5	3D
0005432400118	7136	6	3F
0005435715456	7136	7	4A
0005432400119	7136	8	4C
0005435221049	7136	9	5C
0005435443202	7136	10	5D
0005435219179	7136	11	5F
0005435216571	7136	12	6E
0005435715455	7136	13	6F
0005435715457	7136	14	7A
0005432398194	7136	15	7F
0005435715448	7136	16	8C
0005435715454	7136	17	8E
0005435715445	7136	18	9E
0005435443256	7136	19	10C
0005435221048	7136	20	10D
0005432400120	7136	21	11C
0005435443198	7136	22	11D
0005435715450	7136	23	12A
0005435216567	7136	24	12C
0005435715443	7136	25	12E
0005435443231	7136	26	12F
0005432400121	7136	27	13D
0005432398195	7136	28	14C
0005435443233	7136	29	14D
0005435179388	7136	30	14E
0005435715442	7136	31	14F
0005435443199	7136	32	15C
0005435443242	7136	33	15E
0005435715449	7136	34	16E
0005432398192	7136	35	16F
0005435715453	7136	36	17C
0005432398193	7136	37	17D
0005435216568	7136	38	18A
0005435443232	7136	39	19A
0005435178490	7136	40	19C
0005435178480	7136	41	19E
0005435715452	7136	42	19F
0005435715451	7136	43	20C
0005435715441	7136	44	20E
0005435715234	27070	1	2A
0005435715282	27070	2	2C
0005432394060	27070	3	3A
0005432398167	27070	4	3D
0005435715257	27070	5	4A
0005435715359	27070	6	4C
0005435715368	27070	7	4D
0005432398159	27070	8	4E
0005435715290	27070	9	5A
0005435715334	27070	10	5C
0005435443307	27070	11	5D
0005435715358	27070	12	5F
0005435715283	27070	13	6A
0005435443302	27070	14	6C
0005432398166	27070	15	6D
0005435715333	27070	16	6E
0005432398150	27070	17	6F
0005435443304	27070	18	7A
0005435178991	27070	19	7E
0005435715236	27070	20	8D
0005432394061	27070	21	8F
0005435443303	27070	22	9A
0005435443301	27070	23	9D
0005435715403	27070	24	9E
0005435443299	27070	25	11C
0005435443300	27070	26	11D
0005435443306	27070	27	12A
0005435715332	27070	28	12C
0005435715369	27070	29	13A
0005435715308	27070	30	14A
0005435715235	27070	31	14C
0005435715233	27070	32	14F
0005435715347	27070	33	16A
0005435715252	27070	34	16C
0005432398158	27070	35	17A
0005432398153	27070	36	17C
0005435715404	27070	37	17E
0005435715402	27070	38	17F
0005435715291	27070	39	18A
0005435443305	27070	40	18E
0005435178493	27070	41	19A
0005435715356	27070	42	20F
0005434084926	2705	1	1A
0005434084925	2705	2	2A
0005433060393	2705	3	2B
0005434084927	2705	4	5A
0005434084924	2705	5	5B
0005433060391	2705	6	6A
0005433060392	2705	7	6B
0005433060411	28481	1	1B
0005433060410	28481	2	4B
0005433060409	28481	3	6B
0005435540731	11365	1	1F
0005435540783	11365	2	3C
0005435517734	11365	3	3D
0005435517723	11365	4	3F
0005435540805	11365	5	4A
0005435517672	11365	6	5C
0005435517673	11365	7	6D
0005435517674	11365	8	7A
0005435540804	11365	9	8D
0005435540784	11365	10	8E
0005435517602	11365	11	8F
0005435540751	11365	12	9A
0005435517789	11365	13	9D
0005435517718	11365	14	9E
0005435517722	11365	15	11A
0005435517669	11365	16	12A
0005435517727	11365	17	12E
0005435540820	11365	18	13E
0005435540730	11365	19	14F
0005435540794	11365	20	16D
0005435540817	11365	21	17A
0005435540763	11365	22	17C
0005435540793	11365	23	17D
0005435540819	11365	24	18E
0005435540851	11365	25	18F
0005435517603	11365	26	19A
0005435517726	11365	27	19F
0005435517736	11365	28	20E
0005435517728	11365	29	20F
0005435540966	22258	1	1F
0005435529212	22258	2	2D
0005432294483	22258	3	3A
0005435540972	22258	4	3D
0005435529218	22258	5	3F
0005435540968	22258	6	4A
0005432294482	22258	7	4D
0005435529213	22258	8	4E
0005435540975	22258	9	5E
0005435540971	22258	10	5F
0005435540974	22258	11	6D
0005435529223	22258	12	6F
0005435529231	22258	13	7E
0005435540961	22258	14	7F
0005435529229	22258	15	8A
0005435529215	22258	16	8C
0005435540960	22258	17	8D
0005435540962	22258	18	8F
0005435540956	22258	19	9C
0005435540976	22258	20	9D
0005435540973	22258	21	9E
0005435540967	22258	22	9F
0005435540970	22258	23	10A
0005435529232	22258	24	10C
0005435529224	22258	25	10D
0005435529211	22258	26	10E
0005435540957	22258	27	11E
0005435529220	22258	28	11F
0005435540965	22258	29	12A
0005435529217	22258	30	12D
0005435529228	22258	31	12F
0005435540964	22258	32	13E
0005435540959	22258	33	13F
0005435529222	22258	34	14D
0005435540963	22258	35	14E
0005435529233	22258	36	14F
0005435529216	22258	37	15F
0005435529230	22258	38	16C
0005435540977	22258	39	16F
0005435529227	22258	40	17D
0005435540955	22258	41	17E
0005435540969	22258	42	17F
0005435529221	22258	43	18A
0005435529226	22258	44	18E
0005435529214	22258	45	19A
0005435540958	22258	46	19E
0005435529225	22258	47	20C
0005435529219	22258	48	20F
0005433251145	2265	1	1A
0005434907233	2265	2	1C
0005433251140	2265	3	1D
0005434907262	2265	4	2A
0005434907223	2265	5	2C
0005434907259	2265	6	2D
0005433251191	2265	7	2F
0005434907260	2265	8	3A
0005434907234	2265	9	3C
0005433400967	2265	10	3D
0005434907230	2265	11	3F
0005434907225	2265	12	4A
0005433251281	2265	13	4C
0005433251192	2265	14	4D
0005434907239	2265	15	4E
0005434907253	2265	16	4F
0005434907229	2265	17	5A
0005433251246	2265	18	5D
0005434907216	2265	19	5C
0005434907257	2265	20	5E
0005433251359	2265	21	5F
0005434907221	2265	22	6A
0005433251226	2265	23	6C
0005433251357	2265	24	6D
0005434907248	2265	25	6E
0005434907215	2265	26	6F
0005434907245	2265	27	7A
0005434907255	2265	28	7C
0005433251219	2265	29	7D
0005434907252	2265	30	7E
0005434907231	2265	31	7F
0005433251091	2265	32	8D
0005434907246	2265	33	8E
0005434907254	2265	34	8F
0005433251225	2265	35	9C
0005434907235	2265	36	9D
0005434907237	2265	37	9E
0005433251209	2265	38	9F
0005433251322	2265	39	10C
0005433400960	2265	40	10D
0005434907249	2265	41	10E
0005433251218	2265	42	10F
0005434907251	2265	43	11A
0005433251144	2265	44	11C
0005433400968	2265	45	11D
0005434907217	2265	46	11E
0005434907241	2265	47	12A
0005433251245	2265	48	12C
0005433251293	2265	49	12D
0005433251190	2265	50	12E
0005433251150	2265	51	12F
0005434907258	2265	52	13A
0005434907232	2265	53	13C
0005434907250	2265	54	13D
0005433251120	2265	55	13E
0005434907214	2265	56	13F
0005434907218	2265	57	14A
0005433251193	2265	58	14C
0005434907244	2265	59	14E
0005433251179	2265	60	14F
0005433251211	2265	61	15A
0005434907228	2265	62	15C
0005434907240	2265	63	15D
0005434907226	2265	64	15E
0005433251161	2265	65	15F
0005433251323	2265	66	16A
0005434907243	2265	67	16C
0005433251306	2265	68	16D
0005434907256	2265	69	16E
0005433251358	2265	70	16F
0005434907220	2265	71	17A
0005434907247	2265	72	17D
0005434907224	2265	73	17E
0005433251307	2265	74	17F
0005433251228	2265	75	18A
0005433251210	2265	76	18C
0005434907236	2265	77	18D
0005433251292	2265	78	18E
0005434907242	2265	79	18F
0005433251227	2265	80	19A
0005433251172	2265	81	19C
0005434907219	2265	82	19D
0005434907227	2265	83	19E
0005434907238	2265	84	19F
0005434907261	2265	85	20A
0005433251264	2265	86	20C
0005433251234	2265	87	20D
0005434907222	2265	88	20E
0005433251233	2265	89	20F
0005434906771	25618	1	1A
0005434906792	25618	2	1C
0005433251443	25618	3	1D
0005434906749	25618	4	1F
0005434906705	25618	5	2A
0005433251444	25618	6	2C
0005434906479	25618	7	2D
0005434906624	25618	8	2F
0005434906613	25618	9	3A
0005434906674	25618	10	3C
0005434906470	25618	11	3D
0005433251434	25618	12	3F
0005434906508	25618	13	4A
0005433251455	25618	14	4C
0005434906478	25618	15	4E
0005434906583	25618	16	4F
0005434906698	25618	17	5A
0005433251442	25618	18	5C
0005434906706	25618	19	5D
0005434906707	25618	20	5E
0005433251439	25618	21	5F
0005434906653	25618	22	6A
0005433251453	25618	23	6C
0005434906740	25618	24	6D
0005433251460	25618	25	6E
0005434906582	25618	26	6F
0005434906542	25618	27	7A
0005434906730	25618	28	7C
0005434906767	25618	29	7D
0005433251450	25618	30	7E
0005433400979	25618	31	7F
0005433251447	25618	32	8A
0005433251448	25618	33	8C
0005434906739	25618	34	8D
0005434906782	25618	35	8E
0005433400980	25618	36	9A
0005433251451	25618	37	9C
0005434906541	25618	38	9D
0005434906673	25618	39	9E
0005434906530	25618	40	9F
0005433251461	25618	41	10A
0005433251436	25618	42	10C
0005433251462	25618	43	10E
0005434906598	25618	44	11A
0005434906544	25618	45	10F
0005434906776	25618	46	11C
0005434906696	25618	47	11D
0005434906736	25618	48	11E
0005434906754	25618	49	11F
0005433251456	25618	50	12A
0005434906741	25618	51	12C
0005433251459	25618	52	12D
0005434906586	25618	53	12E
0005434906777	25618	54	12F
0005433251441	25618	55	13A
0005434906378	25618	56	13C
0005433251437	25618	57	13D
0005434906576	25618	58	13E
0005434906577	25618	59	13F
0005434906738	25618	60	14A
0005433251454	25618	61	14C
0005434906708	25618	62	14D
0005434906535	25618	63	14E
0005434906709	25618	64	14F
0005433251433	25618	65	15A
0005434906663	25618	66	15C
0005433251449	25618	67	15D
0005433251463	25618	68	15E
0005433251438	25618	69	16A
0005434906766	25618	70	16C
0005433251446	25618	71	16D
0005434906654	25618	72	16E
0005434906798	25618	73	16F
0005434906675	25618	74	17A
0005434906597	25618	75	17C
0005433251458	25618	76	17D
0005434906599	25618	77	17E
0005433251445	25618	78	17F
0005434906748	25618	79	18A
0005434906785	25618	80	18C
0005433400981	25618	81	18E
0005434906775	25618	82	18F
0005433251464	25618	83	19C
0005434906573	25618	84	19D
0005433251457	25618	85	19E
0005434906768	25618	86	19F
0005434906732	25618	87	20A
0005433251452	25618	88	20C
0005433251440	25618	89	20D
0005433251435	25618	90	20E
0005434906773	25618	91	20F
0005432621028	2495	1	1A
0005432862250	2495	2	2A
0005432621018	2495	3	2B
0005432621019	2495	4	2D
0005432621017	2495	5	3C
0005432862264	2495	6	4B
0005432621030	2495	7	5C
0005432621031	2495	8	6C
0005432621021	2495	9	7C
0005432621027	2495	10	18B
0005432621029	2495	11	18C
0005432862227	2495	12	19A
0005432621025	2495	13	19B
0005432862204	2495	14	20A
0005432621024	2495	15	20C
0005432621026	2495	16	20D
0005432621020	2495	17	21A
0005432621022	2495	18	21D
0005432621023	2495	19	23A
0005432620878	28080	1	1A
0005432862297	28080	2	2A
0005432620882	28080	3	2B
0005432862294	28080	4	2C
0005432620966	28080	5	2D
0005432620880	28080	6	3C
0005432862292	28080	7	3D
0005432620840	28080	8	4B
0005432862291	28080	9	4D
0005432620844	28080	10	5B
0005432862295	28080	11	5C
0005432620913	28080	12	5D
0005432862293	28080	13	6C
0005432620883	28080	14	7A
0005432862296	28080	15	7C
0005432620888	28080	16	7D
0005432620964	28080	17	19B
0005432620836	28080	18	20A
0005432620881	28080	19	20C
0005432620862	28080	20	21B
0005432620965	28080	21	21D
0005432620858	28080	22	22A
0005432620861	28080	23	22C
0005432620846	28080	24	23A
0005432862290	28080	25	23B
0005434097474	13031	1	2B
0005434097475	13031	2	3B
0005433451616	31040	1	3A
0005433452737	31040	2	4A
0005433451617	31040	3	5B
0005433452736	31040	4	6B
0005433452721	31347	1	1A
0005433452719	31347	2	6B
0005434184643	11975	1	1D
0005434142582	11975	2	4D
0005434142579	11975	3	6A
0005433134101	11975	4	6C
0005434142556	11975	5	7D
0005433129236	11975	6	18A
0005434184644	11975	7	19A
0005433134102	11975	8	20C
0005433134100	11975	9	22C
0005434142571	11975	10	23A
0005434184636	11975	11	23B
0005433134133	29859	1	1B
0005433134132	29859	2	1C
0005434142603	29859	3	2D
0005433134134	29859	4	3A
0005434183578	29859	5	5D
0005433134135	29859	6	6B
0005433131704	29859	7	6C
0005433131703	29859	8	7B
0005434183577	29859	9	7C
0005433131701	29859	10	18A
0005434184663	29859	11	18D
0005434184662	29859	12	19A
0005433131705	29859	13	19B
0005433131702	29859	14	20C
0005434326085	29859	15	21D
0005434142604	29859	16	23A
0005433134131	29859	17	23B
0005435697285	16499	1	1A
0005435697293	16499	2	1D
0005435697287	16499	3	2A
0005435697296	16499	4	2C
0005435697279	16499	5	2D
0005435697301	16499	6	3A
0005435697300	16499	7	3D
0005435697299	16499	8	4A
0005435697276	16499	9	4C
0005435697281	16499	10	5A
0005435697291	16499	11	5B
0005435697295	16499	12	5C
0005435697275	16499	13	6A
0005435697294	16499	14	6C
0005435697286	16499	15	7C
0005435697298	16499	16	18A
0005435697277	16499	17	18B
0005435697284	16499	18	18C
0005435697282	16499	19	19A
0005435697290	16499	20	19B
0005435697297	16499	21	19C
0005435697302	16499	22	19D
0005435697280	16499	23	20A
0005435697289	16499	24	20C
0005435935010	16499	25	20D
0005435697288	16499	26	21A
0005435935017	16499	27	21C
0005435697292	16499	28	22A
0005435697283	16499	29	22C
0005435697278	16499	30	22D
0005435935044	24734	1	1A
0005435697183	24734	2	1B
0005435697073	24734	3	2A
0005435697048	24734	4	2C
0005435697009	24734	5	2D
0005435697005	24734	6	3A
0005435697049	24734	7	3B
0005435697094	24734	8	3D
0005435935042	24734	9	4A
0005435697063	24734	10	4C
0005435697042	24734	11	4D
0005435697125	24734	12	5B
0005435697088	24734	13	5C
0005435697100	24734	14	6A
0005435935043	24734	15	6B
0005435697090	24734	16	6C
0005435697081	24734	17	6D
0005435697101	24734	18	7A
0005435697046	24734	19	7B
0005435696983	24734	20	7C
0005435697184	24734	21	7D
0005435697126	24734	22	18A
0005435697138	24734	23	18B
0005435697043	24734	24	18C
0005435697045	24734	25	19A
0005435697095	24734	26	19B
0005435696973	24734	27	19C
0005435697040	24734	28	19D
0005435697044	24734	29	20A
0005435697139	24734	30	20C
0005435697047	24734	31	20D
0005435696950	24734	32	21B
0005435697010	24734	33	21C
0005435697064	24734	34	22A
0005435696951	24734	35	22C
0005435697011	24734	36	22D
0005435697082	24734	37	23B
0005433724800	18775	1	1B
0005432968810	18775	2	2B
0005433724798	18775	3	3B
0005433724799	18775	4	4A
0005433724796	18775	5	5A
0005432968812	18775	6	5B
0005433724797	18775	7	6A
0005433724801	18775	8	6B
0005433724786	21615	1	1A
0005433724760	21615	2	4B
0005432968839	21615	3	5A
0005432968841	21615	4	6A
0005432968840	21615	5	5B
0005433724759	21615	6	6B
0005434138119	7305	1	1A
0005434138080	7305	2	1C
0005434138099	7305	3	1D
0005434138114	7305	4	1F
0005434138116	7305	5	2A
0005434138076	7305	6	2C
0005434138097	7305	7	2F
0005434138060	7305	8	3A
0005434138041	7305	9	3C
0005434138124	7305	10	3D
0005434087509	7305	11	3F
0005434138072	7305	12	4A
0005434138055	7305	13	4C
0005434138112	7305	14	4D
0005434138091	7305	15	4E
0005434138047	7305	16	4F
0005434138063	7305	17	5A
0005434138095	7305	18	5C
0005434138086	7305	19	5D
0005434138079	7305	20	5E
0005434138043	7305	21	5F
0005434138074	7305	22	6A
0005434138061	7305	23	6C
0005434138120	7305	24	6E
0005434138092	7305	25	6D
0005434138122	7305	26	6F
0005434138110	7305	27	7A
0005434138123	7305	28	7C
0005434138090	7305	29	7D
0005434138071	7305	30	7E
0005434138102	7305	31	7F
0005434138104	7305	32	8A
0005434138064	7305	33	8C
0005434138044	7305	34	8D
0005434138108	7305	35	8E
0005434138088	7305	36	8F
0005434138107	7305	37	9A
0005434138048	7305	38	9C
0005434138067	7305	39	9D
0005434138096	7305	40	9E
0005434138051	7305	41	9F
0005434138037	7305	42	10A
0005434138084	7305	43	10C
0005434138065	7305	44	10D
0005434138035	7305	45	10E
0005434138115	7305	46	10F
0005434138103	7305	47	11A
0005434138040	7305	48	11C
0005434138100	7305	49	11D
0005434087507	7305	50	11E
0005434138081	7305	51	11F
0005434138056	7305	52	12A
0005434138062	7305	53	12C
0005434138105	7305	54	12D
0005434138075	7305	55	12E
0005434138053	7305	56	12F
0005434138045	7305	57	13A
0005434138058	7305	58	13D
0005434087510	7305	59	13E
0005434138070	7305	60	13F
0005434138054	7305	61	14A
0005434138049	7305	62	14C
0005434138082	7305	63	14D
0005434138073	7305	64	14E
0005434138039	7305	65	14F
0005434138094	7305	66	15A
0005434138111	7305	67	15C
0005434138036	7305	68	15D
0005434087508	7305	69	15E
0005434138085	7305	70	15F
0005434138118	7305	71	16A
0005434138077	7305	72	16C
0005434138089	7305	73	16D
0005434138078	7305	74	16E
0005434138057	7305	75	16F
0005434138068	7305	76	17A
0005434138113	7305	77	17C
0005434138093	7305	78	17D
0005434138042	7305	79	17E
0005434138038	7305	80	17F
0005434138052	7305	81	18A
0005434138098	7305	82	18C
0005434138083	7305	83	18D
0005434138066	7305	84	18E
0005434138101	7305	85	18F
0005434138046	7305	86	19A
0005434138059	7305	87	19C
0005434138117	7305	88	19D
0005434138106	7305	89	19E
0005434138069	7305	90	19F
0005434138050	7305	91	20A
0005434087506	7305	92	20C
0005434138109	7305	93	20D
0005434138087	7305	94	20E
0005434138121	7305	95	20F
0005434137553	28550	1	1A
0005434137526	28550	2	1C
0005434137398	28550	3	1D
0005434087481	28550	4	1F
0005434136970	28550	5	2A
0005434137520	28550	6	2C
0005434137738	28550	7	2D
0005434137403	28550	8	2F
0005434137182	28550	9	3A
0005434137239	28550	10	3C
0005434137536	28550	11	3D
0005434137539	28550	12	3F
0005434137256	28550	13	4A
0005434137528	28550	14	4C
0005434137589	28550	15	4D
0005434137117	28550	16	4E
0005434137529	28550	17	4F
0005434137512	28550	18	5A
0005434137596	28550	19	5C
0005434136777	28550	20	5D
0005434137354	28550	21	5E
0005434137491	28550	22	5F
0005434137439	28550	23	6A
0005434137144	28550	24	6C
0005434137346	28550	25	6D
0005434137579	28550	26	6E
0005434137222	28550	27	6F
0005434137350	28550	28	7A
0005434137177	28550	29	7D
0005434137737	28550	30	7E
0005434137537	28550	31	7F
0005434136840	28550	32	8A
0005434137227	28550	33	8C
0005434137492	28550	34	8D
0005434137408	28550	35	8E
0005434137591	28550	36	8F
0005434137033	28550	37	9A
0005434137240	28550	38	9C
0005434137472	28550	39	9D
0005434137330	28550	40	9E
0005434137422	28550	41	9F
0005434137490	28550	42	10A
0005434137181	28550	43	10C
0005434137238	28550	44	10D
0005434087467	28550	45	10E
0005434137279	28550	46	10F
0005434137473	28550	47	11C
0005434137225	28550	48	11D
0005434137230	28550	49	11E
0005434137231	28550	50	11F
0005434087469	28550	51	12A
0005434137185	28550	52	12C
0005434136942	28550	53	12D
0005434137347	28550	54	12E
0005434137437	28550	55	12F
0005434137195	28550	56	13A
0005434137597	28550	57	13C
0005434137198	28550	58	13E
0005434137392	28550	59	13F
0005434137155	28550	60	14A
0005434137059	28550	61	14C
0005434137005	28550	62	14E
0005434137673	28550	63	14F
0005434137287	28550	64	15A
0005434137554	28550	65	15C
0005434137471	28550	66	15D
0005434137525	28550	67	15E
0005434136873	28550	68	15F
0005434137152	28550	69	16E
0005434137438	28550	70	16F
0005434137057	28550	71	17A
0005434137353	28550	72	17C
0005434137178	28550	73	17D
0005434137391	28550	74	17F
0005434137197	28550	75	18A
0005434137255	28550	76	18C
0005434137196	28550	77	18D
0005434137233	28550	78	18E
0005434137426	28550	79	18F
0005434137407	28550	80	19A
0005434137349	28550	81	19C
0005434137118	28550	82	19D
0005434137351	28550	83	19E
0005434137466	28550	84	19F
0005434137402	28550	85	20A
0005434137226	28550	86	20C
0005434136969	28550	87	20D
0005434137151	28550	88	20E
0005434087468	28550	89	20F
0005435808230	1941	1	1D
0005435808229	1941	2	2D
0005435808222	1941	3	3A
0005433407509	1941	4	3C
0005435808224	1941	5	3D
0005433407516	1941	6	4D
0005435808225	1941	7	5B
0005433407513	1941	8	6B
0005435808226	1941	9	6C
0005435808227	1941	10	7B
0005435808221	1941	11	18B
0005434610225	1941	12	20A
0005434610226	1941	13	20C
0005435808228	1941	14	20D
0005434610224	1941	15	21A
0005433407510	1941	16	21C
0005435808223	1941	17	22A
0005434610227	1941	18	22B
0005433407512	1941	19	22C
0005434610195	23115	1	2A
0005434610174	23115	2	3A
0005434610173	23115	3	7B
0005434610175	23115	4	22C
0005434503855	16692	1	1B
0005434503687	16692	2	1C
0005434503655	16692	3	1D
0005434503675	16692	4	2A
0005434503685	16692	5	2B
0005434503709	16692	6	2C
0005434503824	16692	7	2D
0005434503594	16692	8	3A
0005434503657	16692	9	3B
0005434503800	16692	10	3C
0005434503809	16692	11	3D
0005434503763	16692	12	4A
0005434503859	16692	13	4C
0005434503595	16692	14	4D
0005434503708	16692	15	5A
0005434503792	16692	16	5C
0005434503844	16692	17	5D
0005434503693	16692	18	6A
0005434503704	16692	19	6B
0005434503810	16692	20	6C
0005434503872	16692	21	6D
0005434503730	16692	22	7B
0005434503928	16692	23	7D
0005434503605	16692	24	18A
0005434503845	16692	25	18B
0005434503656	16692	26	18C
0005434503789	16692	27	18D
0005434503889	16692	28	19A
0005434503699	16692	29	19C
0005434503703	16692	30	19D
0005434503801	16692	31	20A
0005434503748	16692	32	20B
0005434503823	16692	33	20C
0005434503694	16692	34	20D
0005434503682	16692	35	21A
0005434503920	16692	36	21C
0005434503606	16692	37	21D
0005434503858	16692	38	22A
0005434503731	16692	39	22B
0005434503686	16692	40	22C
0005434503956	16692	41	23A
0005434503803	16692	42	23B
0005434504075	22892	1	1A
0005434504086	22892	2	1B
0005434504076	22892	3	1C
0005434504067	22892	4	1D
0005434504103	22892	5	2A
0005434504087	22892	6	2B
0005434504083	22892	7	2C
0005434504102	22892	8	3A
0005434504090	22892	9	3D
0005434504066	22892	10	4A
0005434504092	22892	11	4B
0005434504093	22892	12	4C
0005434504101	22892	13	4D
0005434504073	22892	14	5A
0005434504095	22892	15	5D
0005434504069	22892	16	6A
0005434504097	22892	17	6B
0005434504078	22892	18	6C
0005434504070	22892	19	6D
0005434504064	22892	20	7A
0005434504100	22892	21	7C
0005434504065	22892	22	7D
0005434504079	22892	23	18A
0005434504063	22892	24	18B
0005434504089	22892	25	18C
0005434504081	22892	26	18D
0005434504098	22892	27	19A
0005434504082	22892	28	19C
0005434504077	22892	29	19D
0005434504088	22892	30	20A
0005434504068	22892	31	20B
0005434504099	22892	32	20C
0005434504085	22892	33	20D
0005434504096	22892	34	21B
0005434504091	22892	35	21C
0005434504084	22892	36	21D
0005434504080	22892	37	22A
0005434504062	22892	38	22B
0005434504074	22892	39	22C
0005434504094	22892	40	22D
0005434504072	22892	41	23A
0005434504071	22892	42	23B
0005435078325	2208	1	1A
0005435078318	2208	2	2B
0005435078333	2208	3	3A
0005433266630	2208	4	3C
0005435078321	2208	5	4A
0005435078330	2208	6	4B
0005433266634	2208	7	5A
0005435078323	2208	8	5C
0005433266663	2208	9	5D
0005435078320	2208	10	6A
0005435078327	2208	11	6B
0005435078329	2208	12	6C
0005433266637	2208	13	6D
0005433266635	2208	14	7A
0005435078331	2208	15	18B
0005435078324	2208	16	18D
0005435078326	2208	17	19B
0005433266664	2208	18	20C
0005435078319	2208	19	20D
0005433266636	2208	20	22A
0005435078328	2208	21	22B
0005435078322	2208	22	22C
0005433266617	2208	23	22D
0005435078332	2208	24	23A
0005433266633	2208	25	23B
0005433266709	24376	1	1B
0005433266716	24376	2	1C
0005435078254	24376	3	2A
0005435078200	24376	4	2B
0005435078162	24376	5	2C
0005433266715	24376	6	3A
0005433266711	24376	7	3B
0005435078209	24376	8	3C
0005433266714	24376	9	3D
0005435078231	24376	10	4A
0005435078268	24376	11	4C
0005435078255	24376	12	4D
0005435078193	24376	13	5C
0005435078218	24376	14	5B
0005435078164	24376	15	6A
0005435078198	24376	16	6B
0005435078269	24376	17	6C
0005433266717	24376	18	6D
0005433266713	24376	19	7A
0005435078167	24376	20	7C
0005435078143	24376	21	7D
0005435078166	24376	22	18A
0005435078204	24376	23	18B
0005435078125	24376	24	18C
0005435078256	24376	25	18D
0005433266719	24376	26	19C
0005435078208	24376	27	20A
0005433266718	24376	28	20B
0005433266712	24376	29	20C
0005435078184	24376	30	20D
0005435078206	24376	31	21A
0005435078213	24376	32	21C
0005433266710	24376	33	22A
0005435078172	24376	34	22B
0005435078230	24376	35	22C
0005435078165	24376	36	22D
0005435078163	24376	37	23A
0005435078194	24376	38	23B
0005434988735	6664	1	2A
0005434988725	6664	2	2C
0005434988727	6664	3	3C
0005434988732	6664	4	3D
0005434988724	6664	5	4B
0005435803261	6664	6	4C
0005434988729	6664	7	5A
0005435803260	6664	8	5D
0005434988722	6664	9	6A
0005434988726	6664	10	7B
0005434988739	6664	11	7C
0005434988738	6664	12	7D
0005434988728	6664	13	18C
0005434988723	6664	14	19C
0005434988734	6664	15	19D
0005435464494	6664	16	20A
0005434988730	6664	17	20D
0005434988737	6664	18	21A
0005434988733	6664	19	21B
0005434988736	6664	20	22A
0005434988731	6664	21	22D
0005434988606	23604	1	1B
0005435803245	23604	2	2A
0005435803243	23604	3	2B
0005435803244	23604	4	2D
0005435803232	23604	5	3B
0005434988652	23604	6	4A
0005434988638	23604	7	4B
0005434988611	23604	8	4D
0005434988609	23604	9	6A
0005435464505	23604	10	6C
0005434988614	23604	11	18A
0005434988595	23604	12	19B
0005434988651	23604	13	19D
0005434988610	23604	14	20B
0005435464504	23604	15	21D
0005434988605	23604	16	23A
0005434988612	23604	17	23B
0005432383136	30482	1	1A
0005432383129	30482	2	1D
0005433449950	30482	3	2C
0005433449960	30482	4	2D
0005433449961	30482	5	2F
0005432383143	30482	6	3A
0005432383158	30482	7	4C
0005432383165	30482	8	4D
0005432383160	30482	9	4F
0005432383151	30482	10	5A
0005433449941	30482	11	5C
0005432383137	30482	12	5D
0005433449955	30482	13	5E
0005433454874	30482	14	6A
0005433449953	30482	15	6E
0005433449958	30482	16	6F
0005432383135	30482	17	7A
0005433449944	30482	18	7C
0005432383149	30482	19	7E
0005432383155	30482	20	7F
0005432383138	30482	21	8A
0005433449945	30482	22	8C
0005432383159	30482	23	8F
0005432383157	30482	24	9C
0005432383164	30482	25	9E
0005433454875	30482	26	9F
0005433454873	30482	27	10A
0005432383130	30482	28	10C
0005432383131	30482	29	10D
0005432383154	30482	30	10E
0005433449947	30482	31	10F
0005433449952	30482	32	11A
0005433449949	30482	33	11C
0005432383134	30482	34	11D
0005433453761	30482	35	11E
0005432383141	30482	36	11F
0005433453762	30482	37	12A
0005432383139	30482	38	12C
0005433449959	30482	39	12D
0005432383144	30482	40	12F
0005433449946	30482	41	13A
0005433449951	30482	42	13D
0005432383145	30482	43	13E
0005432383142	30482	44	14E
0005432383161	30482	45	14F
0005432383152	30482	46	15A
0005432383156	30482	47	15C
0005432383162	30482	48	15D
0005433449943	30482	49	15E
0005432383150	30482	50	16D
0005433449954	30482	51	16E
0005433449948	30482	52	16F
0005432383146	30482	53	17A
0005433449956	30482	54	17C
0005432383163	30482	55	17D
0005433453763	30482	56	18D
0005432383147	30482	57	18E
0005432383132	30482	58	18F
0005433449942	30482	59	19A
0005433449957	30482	60	19F
0005432383133	30482	61	20A
0005432383166	30482	62	20C
0005432383140	30482	63	20D
0005432383148	30482	64	20E
0005432383153	30482	65	20F
0005433449751	31291	1	1D
0005433449687	31291	2	1F
0005433449705	31291	3	2A
0005432382689	31291	4	2C
0005432382750	31291	5	2D
0005433449830	31291	6	3A
0005433453736	31291	7	3D
0005432382684	31291	8	3F
0005433449742	31291	9	4A
0005433451590	31291	10	4D
0005432382722	31291	11	4E
0005432382683	31291	12	5A
0005433449775	31291	13	5C
0005433449799	31291	14	5E
0005432382676	31291	15	5F
0005432382751	31291	16	6A
0005433449767	31291	17	6C
0005433449651	31291	18	6D
0005433449802	31291	19	6E
0005433449688	31291	20	6F
0005433449726	31291	21	7D
0005433451605	31291	22	7F
0005433449849	31291	23	8C
0005432382672	31291	24	8D
0005432382721	31291	25	8F
0005433449750	31291	26	9C
0005432382616	31291	27	9E
0005432382587	31291	28	10D
0005432382749	31291	29	10E
0005433449752	31291	30	10F
0005432382742	31291	31	11F
0005432382576	31291	32	12A
0005432382606	31291	33	12C
0005433449793	31291	34	12D
0005433449784	31291	35	12E
0005432382671	31291	36	12F
0005433449701	31291	37	13C
0005432382526	31291	38	13D
0005432382588	31291	39	14C
0005433449711	31291	40	15A
0005432382682	31291	41	15D
0005432382615	31291	42	15E
0005433451601	31291	43	15F
0005432382652	31291	44	16A
0005433449704	31291	45	16C
0005433449749	31291	46	16D
0005433449710	31291	47	16E
0005432382748	31291	48	17A
0005433449848	31291	49	17C
0005433449650	31291	50	17D
0005432382621	31291	51	17F
0005432382649	31291	52	18A
0005432382577	31291	53	18D
0005432382589	31291	54	18E
0005433449783	31291	55	18F
0005433449806	31291	56	19A
0005433449712	31291	57	19C
0005432382688	31291	58	19D
0005433449709	31291	59	19F
0005432382677	31291	60	20C
0005432382687	31291	61	20E
0005432382611	31291	62	20F
0005435548426	20810	1	1B
0005435548443	20810	2	1C
0005435548447	20810	3	1D
0005435548446	20810	4	2A
0005433788205	20810	5	2B
0005433788201	20810	6	2D
0005433788194	20810	7	3A
0005435548419	20810	8	3B
0005433788190	20810	9	3C
0005433788197	20810	10	3D
0005435548432	20810	11	4B
0005433788196	20810	12	4C
0005435548441	20810	13	4D
0005435548442	20810	14	5A
0005435548445	20810	15	5B
0005435548425	20810	16	5C
0005435548424	20810	17	6B
0005433788204	20810	18	6D
0005435548420	20810	19	7B
0005433788193	20810	20	7C
0005433788200	20810	21	18A
0005435548430	20810	22	18B
0005435548418	20810	23	18C
0005433788191	20810	24	19A
0005433788192	20810	25	19B
0005435548438	20810	26	19C
0005433788202	20810	27	19D
0005435548417	20810	28	20A
0005433788198	20810	29	20B
0005433788203	20810	30	20C
0005435548421	20810	31	21A
0005435548431	20810	32	21C
0005435548437	20810	33	22A
0005433788199	20810	34	22B
0005435548429	20810	35	22D
0005435548439	20810	36	23A
0005433788195	20810	37	23B
0005433788168	26474	1	1C
0005435548485	26474	2	2A
0005435548492	26474	3	2B
0005433788174	26474	4	2C
0005435548490	26474	5	2D
0005435548488	26474	6	3A
0005435548489	26474	7	3B
0005435548484	26474	8	3D
0005433788172	26474	9	4A
0005433788149	26474	10	4D
0005433788151	26474	11	5A
0005433788140	26474	12	5B
0005433788160	26474	13	5C
0005433788167	26474	14	6B
0005433788157	26474	15	7A
0005433788175	26474	16	18C
0005435548486	26474	17	18D
0005435548493	26474	18	19A
0005435548487	26474	19	19B
0005433788177	26474	20	19C
0005433788152	26474	21	19D
0005433788150	26474	22	20A
0005435548491	26474	23	20D
0005433788165	26474	24	21A
0005433788159	26474	25	21C
0005433788153	26474	26	21D
0005435548495	26474	27	22A
0005435548494	26474	28	23B
0005433131657	10781	1	1B
0005435299743	10781	2	1C
0005433131654	10781	3	2A
0005433131652	10781	4	2C
0005433131683	10781	5	2D
0005435304136	10781	6	3C
0005433126794	10781	7	4A
0005435299730	10781	8	4C
0005435304104	10781	9	6A
0005435304135	10781	10	6B
0005433131667	10781	11	18D
0005433131681	10781	12	19B
0005433131682	10781	13	19C
0005435299720	10781	14	20A
0005435299750	10781	15	20B
0005435299716	10781	16	20D
0005435299717	10781	17	21A
0005433131651	10781	18	23A
0005433126846	29690	1	1B
0005433129277	29690	2	1C
0005435299777	29690	3	1D
0005433126843	29690	4	2A
0005433129274	29690	5	3A
0005433126842	29690	6	3B
0005435302199	29690	7	3C
0005435302196	29690	8	3D
0005435299774	29690	9	4A
0005435302195	29690	10	5C
0005435302200	29690	11	6C
0005433126847	29690	12	6D
0005433129275	29690	13	18A
0005435302197	29690	14	19B
0005435302201	29690	15	19D
0005435299776	29690	16	20B
0005435299775	29690	17	20C
0005433129273	29690	18	20D
0005433126844	29690	19	21B
0005435302198	29690	20	22A
0005433129276	29690	21	22B
0005433126845	29690	22	23A
0005433109932	2429	1	1A
0005434287269	2429	2	1B
0005433109924	2429	3	1D
0005434287270	2429	4	2B
0005433109925	2429	5	2C
0005433109914	2429	6	2D
0005434287268	2429	7	3A
0005434287276	2429	8	3B
0005434287277	2429	9	3D
0005433109982	2429	10	4A
0005433109935	2429	11	4B
0005434287258	2429	12	4C
0005433109948	2429	13	4D
0005433109943	2429	14	5A
0005433109942	2429	15	5B
0005432264474	2429	16	5C
0005434287272	2429	17	5D
0005433109979	2429	18	6A
0005434287273	2429	19	6B
0005433109983	2429	20	6C
0005434287264	2429	21	6D
0005433109955	2429	22	7A
0005434287275	2429	23	7B
0005433109966	2429	24	7C
0005434287257	2429	25	7D
0005433109950	2429	26	18A
0005433109909	2429	27	18B
0005433109939	2429	28	18C
0005434287261	2429	29	18D
0005434287266	2429	30	19A
0005434287267	2429	31	19B
0005434287260	2429	32	19C
0005434287256	2429	33	19D
0005434287274	2429	34	20A
0005432264473	2429	35	20C
0005433109947	2429	36	20B
0005433109915	2429	37	20D
0005434287259	2429	38	21A
0005434287271	2429	39	21B
0005434287265	2429	40	21C
0005433109949	2429	41	21D
0005433109954	2429	42	22A
0005432264472	2429	43	22B
0005433109940	2429	44	22C
0005434287262	2429	45	22D
0005434287278	2429	46	23A
0005434287263	2429	47	23B
0005434287093	26872	1	1A
0005434287063	26872	2	2A
0005434287123	26872	3	2B
0005434287022	26872	4	2C
0005433110036	26872	5	2D
0005434287077	26872	6	3A
0005434287165	26872	7	3C
0005434287128	26872	8	3D
0005434287099	26872	9	4B
0005434287101	26872	10	4D
0005433110047	26872	11	5B
0005433110042	26872	12	5C
0005433110038	26872	13	6A
0005434287118	26872	14	6B
0005434287000	26872	15	6D
0005433110037	26872	16	7A
0005434287071	26872	17	7B
0005434287076	26872	18	7C
0005434287028	26872	19	7D
0005433110044	26872	20	18B
0005433110039	26872	21	18C
0005434287085	26872	22	19A
0005434286999	26872	23	19B
0005433110043	26872	24	19D
0005433110040	26872	25	20D
0005434287106	26872	26	21A
0005434287150	26872	27	21B
0005433110035	26872	28	21C
0005434287047	26872	29	21D
0005433110045	26872	30	22A
0005434287129	26872	31	22B
0005433110046	26872	32	22C
0005434287117	26872	33	22D
0005433110041	26872	34	23B
0005435856200	25454	1	1A
0005435856201	25454	2	1D
0005435856203	25454	3	3B
0005435856199	25454	4	3C
0005435856198	25454	5	6A
0005435856202	25454	6	18A
0005434269075	25454	7	7D
0005434269074	25454	8	20D
0005434269076	25454	9	21A
0005435856160	26637	1	1C
0005435856132	26637	2	2B
0005435856156	26637	3	2C
0005435856135	26637	4	4A
0005435856164	26637	5	4D
0005435856163	26637	6	7B
0005435856165	26637	7	7D
0005435854047	26637	8	18A
0005435856168	26637	9	19D
0005435856157	26637	10	21A
0005435856155	26637	11	21C
0005435856149	26637	12	23B
0005434520258	6105	1	1A
0005434520251	6105	2	1B
0005434520255	6105	3	1D
0005434520248	6105	4	2A
0005434520249	6105	5	2B
0005434520256	6105	6	2C
0005434520252	6105	7	2D
0005434520257	6105	8	3A
0005434520247	6105	9	3B
0005435314795	6105	10	3C
0005434520269	6105	11	3D
0005435314797	6105	12	4B
0005435314796	6105	13	4D
0005434520245	6105	14	5B
0005434520268	6105	15	5C
0005434520250	6105	16	5D
0005435314790	6105	17	6A
0005434520263	6105	18	6B
0005435314793	6105	19	6C
0005434520246	6105	20	6D
0005434520262	6105	21	7A
0005435314778	6105	22	7D
0005434520254	6105	23	18B
0005435314799	6105	24	18D
0005434520264	6105	25	19A
0005434520266	6105	26	19B
0005434520259	6105	27	19C
0005434520265	6105	28	20A
0005434520261	6105	29	20C
0005435314798	6105	30	20D
0005435314791	6105	31	21A
0005434520260	6105	32	21B
0005435314771	6105	33	22A
0005435314794	6105	34	22C
0005434520267	6105	35	22D
0005434520253	6105	36	23A
0005433650603	7156	1	1A
0005435263523	7156	2	1C
0005435263512	7156	3	1D
0005435263552	7156	4	1F
0005435263535	7156	5	2A
0005433650624	7156	6	2C
0005433650595	7156	7	2D
0005433650592	7156	8	2F
0005433650628	7156	9	3A
0005435263543	7156	10	3C
0005433650584	7156	11	3D
0005435263561	7156	12	3F
0005433650629	7156	13	4A
0005435263494	7156	14	4C
0005435263560	7156	15	4D
0005433650611	7156	16	4E
0005433650637	7156	17	4F
0005433650600	7156	18	5A
0005435263521	7156	19	5C
0005433650635	7156	20	5D
0005433650593	7156	21	5E
0005433650618	7156	22	5F
0005433650587	7156	23	6A
0005433650636	7156	24	6C
0005433650631	7156	25	6D
0005435263532	7156	26	6E
0005435263555	7156	27	6F
0005433650589	7156	28	7A
0005433650634	7156	29	7C
0005433650621	7156	30	7D
0005433650633	7156	31	7E
0005435263506	7156	32	7F
0005435263556	7156	33	8A
0005435263519	7156	34	8C
0005433650602	7156	35	8D
0005433650616	7156	36	8E
0005435263509	7156	37	8F
0005433650594	7156	38	9A
0005433650604	7156	39	9C
0005433650630	7156	40	9D
0005433650577	7156	41	9E
0005433650578	7156	42	10A
0005433650627	7156	43	10C
0005433650613	7156	44	10D
0005435263559	7156	45	10E
0005435263524	7156	46	10F
0005433650625	7156	47	11A
0005433650609	7156	48	11C
0005433650612	7156	49	11D
0005435263493	7156	50	11E
0005433650614	7156	51	11F
0005433650606	7156	52	12A
0005433650598	7156	53	12C
0005435263510	7156	54	12D
0005435263508	7156	55	12E
0005433650576	7156	56	12F
0005433650581	7156	57	13A
0005433650590	7156	58	13C
0005435263544	7156	59	13D
0005435263518	7156	60	13E
0005433650619	7156	61	13F
0005433650626	7156	62	14A
0005435263533	7156	63	14C
0005435263557	7156	64	14D
0005435263520	7156	65	14E
0005433650638	7156	66	14F
0005433650596	7156	67	15A
0005433650585	7156	68	15C
0005433650615	7156	69	15D
0005433650620	7156	70	15E
0005433650608	7156	71	16A
0005435263526	7156	72	16C
0005435263515	7156	73	16D
0005433650591	7156	74	16E
0005435263498	7156	75	16F
0005435263537	7156	76	17A
0005433650601	7156	77	17C
0005433650582	7156	78	17D
0005433650610	7156	79	17E
0005433650607	7156	80	17F
0005433650597	7156	81	18A
0005433650617	7156	82	18C
0005433650580	7156	83	18D
0005433650599	7156	84	18E
0005435263505	7156	85	18F
0005433650623	7156	86	19A
0005433650583	7156	87	19C
0005435263525	7156	88	19D
0005433650622	7156	89	19E
0005433650588	7156	90	19F
0005433650586	7156	91	20A
0005433650605	7156	92	20C
0005435263522	7156	93	20D
0005433650632	7156	94	20E
0005433650579	7156	95	20F
0005433650468	27624	1	1A
0005435263616	27624	2	1C
0005435263607	27624	3	1D
0005433650489	27624	4	1F
0005433650502	27624	5	2A
0005435263606	27624	6	2C
0005435263615	27624	7	2D
0005433650409	27624	8	2F
0005433650507	27624	9	3C
0005433650433	27624	10	3D
0005433650456	27624	11	3F
0005433650444	27624	12	4C
0005433650443	27624	13	4D
0005433650508	27624	14	4F
0005433650462	27624	15	5E
0005433650469	27624	16	5F
0005435263604	27624	17	6A
0005433650455	27624	18	6C
0005433650524	27624	19	6D
0005435263614	27624	20	6E
0005433650503	27624	21	6F
0005433650500	27624	22	7A
0005433650461	27624	23	7C
0005433650511	27624	24	7D
0005435263611	27624	25	7E
0005433650465	27624	26	7F
0005435263601	27624	27	8A
0005433650499	27624	28	8D
0005433650519	27624	29	8F
0005435263613	27624	30	8E
0005433650522	27624	31	9A
0005433650467	27624	32	9C
0005433650506	27624	33	9D
0005433650515	27624	34	9E
0005435263599	27624	35	9F
0005433650450	27624	36	10A
0005435263605	27624	37	10C
0005433650483	27624	38	10E
0005433650406	27624	39	10F
0005433650466	27624	40	11A
0005433650520	27624	41	11C
0005433650442	27624	42	11D
0005433650422	27624	43	11E
0005433650513	27624	44	11F
0005433650478	27624	45	12A
0005433650416	27624	46	12D
0005435263608	27624	47	12E
0005433650415	27624	48	12F
0005435263597	27624	49	13C
0005433650501	27624	50	13D
0005433650430	27624	51	13E
0005435263610	27624	52	13F
0005435263603	27624	53	14C
0005433650521	27624	54	14E
0005433650453	27624	55	15C
0005433650428	27624	56	15E
0005435263602	27624	57	15F
0005433650485	27624	58	16A
0005433650446	27624	59	16D
0005435263612	27624	60	16E
0005435263598	27624	61	17D
0005433650493	27624	62	17E
0005433650509	27624	63	18C
0005433650435	27624	64	18D
0005433650441	27624	65	18E
0005433650464	27624	66	19A
0005433650514	27624	67	18F
0005435263596	27624	68	19E
0005435263609	27624	69	19F
0005433650490	27624	70	20A
0005435263600	27624	71	20C
0005433650445	27624	72	20E
0005433868408	4792	1	1A
0005433868410	4792	2	1B
0005433868389	4792	3	1C
0005433868415	4792	4	1D
0005435860437	4792	5	2A
0005433868425	4792	6	2B
0005433868399	4792	7	2C
0005433868390	4792	8	3A
0005433868392	4792	9	3B
0005433868388	4792	10	3C
0005433868397	4792	11	3D
0005433868406	4792	12	4A
0005433868422	4792	13	4B
0005433868401	4792	14	4C
0005433868427	4792	15	5A
0005433868407	4792	16	4D
0005433868391	4792	17	5B
0005435860445	4792	18	5C
0005435860436	4792	19	5D
0005433868402	4792	20	6A
0005433868396	4792	21	6B
0005433868430	4792	22	6C
0005433868417	4792	23	6D
0005433868412	4792	24	7A
0005433868420	4792	25	7B
0005433868428	4792	26	7C
0005433868411	4792	27	7D
0005433868413	4792	28	18A
0005435860439	4792	29	18B
0005433868404	4792	30	18C
0005433868405	4792	31	18D
0005433868426	4792	32	19A
0005433868398	4792	33	19B
0005433868409	4792	34	19C
0005435860434	4792	35	19D
0005433868414	4792	36	20A
0005433868424	4792	37	20B
0005435860435	4792	38	20C
0005433868423	4792	39	20D
0005433868403	4792	40	21A
0005433868429	4792	41	21B
0005433868419	4792	42	21C
0005433868416	4792	43	21D
0005433868395	4792	44	22A
0005433868421	4792	45	22B
0005433868393	4792	46	22C
0005433868400	4792	47	22D
0005433868394	4792	48	23A
0005433868418	4792	49	23B
0005433868058	32570	1	1B
0005433868083	32570	2	1C
0005433868050	32570	3	1D
0005433867827	32570	4	2A
0005433867968	32570	5	2B
0005433868051	32570	6	2C
0005433868015	32570	7	2D
0005433867952	32570	8	3A
0005433867985	32570	9	3B
0005433867973	32570	10	3C
0005433868052	32570	11	3D
0005435860490	32570	12	4A
0005433867890	32570	13	4C
0005433868017	32570	14	5A
0005433868084	32570	15	5B
0005435860486	32570	16	5C
0005433867955	32570	17	5D
0005435860493	32570	18	6A
0005433868016	32570	19	6B
0005435860492	32570	20	6C
0005433868158	32570	21	6D
0005435860488	32570	22	7C
0005433868023	32570	23	18B
0005433868063	32570	24	18C
0005433867996	32570	25	18D
0005435860491	32570	26	19B
0005433867883	32570	27	19D
0005433868064	32570	28	20A
0005435860487	32570	29	20B
0005433868125	32570	30	20C
0005433868057	32570	31	20D
0005435860489	32570	32	21B
0005433868013	32570	33	21C
0005433868046	32570	34	21D
0005433868055	32570	35	22B
0005433868157	32570	36	22C
0005433868159	32570	37	22D
0005433867984	32570	38	23A
0005433868049	32570	39	23B
0005435911330	3427	1	1A
0005434663397	3427	2	1B
0005435911366	3427	3	1C
0005434663388	3427	4	1D
0005435911378	3427	5	2C
0005434461645	3427	6	2D
0005434663401	3427	7	3C
0005434663389	3427	8	4A
0005434663394	3427	9	4B
0005434460504	3427	10	5A
0005434663392	3427	11	5B
0005435911367	3427	12	6B
0005435911380	3427	13	6D
0005434663396	3427	14	7B
0005434663398	3427	15	7D
0005434663393	3427	16	19A
0005434663390	3427	17	20A
0005435911389	3427	18	20D
0005434663391	3427	19	21A
0005435911379	3427	20	21C
0005434663395	3427	21	21D
0005434663400	3427	22	22A
0005434663399	3427	23	23A
0005435911329	3427	24	23B
0005434663273	12444	1	1A
0005434663243	12444	2	1C
0005434663312	12444	3	1D
0005434663215	12444	4	3A
0005434663235	12444	5	3B
0005434663274	12444	6	3C
0005434663275	12444	7	4A
0005435911443	12444	8	6C
0005434663324	12444	9	6D
0005435911444	12444	10	7A
0005435911442	12444	11	7B
0005434663251	12444	12	7C
0005435911441	12444	13	18A
0005435911447	12444	14	18B
0005434663315	12444	15	18D
0005434663325	12444	16	19A
0005434663332	12444	17	19B
0005434663313	12444	18	20A
0005435911440	12444	19	20B
0005435911446	12444	20	20C
0005434663316	12444	21	21A
0005434663331	12444	22	21B
0005435911445	12444	23	21C
0005434663244	12444	24	21D
0005434663260	12444	25	22D
0005434663326	12444	26	22C
0005434663237	12444	27	23B
0005435860487	14509	1	1B
0005433868046	14509	2	1C
0005433867968	14509	3	1D
0005435860489	14509	4	2B
0005433868084	14509	5	2D
0005433868023	14509	6	3A
0005433867973	14509	7	3B
0005433868051	14509	8	3C
0005433868052	14509	9	3D
0005433867985	14509	10	4A
0005433867996	14509	11	4C
0005433868058	14509	12	4D
0005433867952	14509	13	5B
0005433868057	14509	14	5C
0005433868159	14509	15	6A
0005433868063	14509	16	6B
0005433868158	14509	17	6C
0005433867955	14509	18	6D
0005433868015	14509	19	7A
0005433868049	14509	20	7B
0005433868055	14509	21	7C
0005433868017	14509	22	7D
0005435860486	14509	23	18B
0005433867883	14509	24	18C
0005433868083	14509	25	18D
0005433868125	14509	26	19A
0005435860492	14509	27	19B
0005433868064	14509	28	19C
0005433868157	14509	29	19D
0005435860488	14509	30	20A
0005433868050	14509	31	20B
0005433868013	14509	32	20C
0005433867984	14509	33	20D
0005433868016	14509	34	21B
0005435860493	14509	35	22A
0005435860491	14509	36	22B
0005433867890	14509	37	22C
0005433867827	14509	38	22D
0005435860490	14509	39	23A
0005433868360	32690	1	1A
0005433868346	32690	2	1B
0005435860447	32690	3	1C
0005433868380	32690	4	1D
0005433868384	32690	5	2A
0005433868359	32690	6	2B
0005433868377	32690	7	2C
0005433868364	32690	8	2D
0005433868351	32690	9	3B
0005433868367	32690	10	3C
0005433868373	32690	11	3D
0005435860449	32690	12	4A
0005433868375	32690	13	4B
0005433868378	32690	14	4C
0005433868349	32690	15	4D
0005433868387	32690	16	5A
0005433868385	32690	17	5C
0005433868361	32690	18	5D
0005433868371	32690	19	6B
0005433868363	32690	20	6C
0005433868350	32690	21	6D
0005433868374	32690	22	7A
0005433868381	32690	23	7B
0005433868365	32690	24	7C
0005433868358	32690	25	18A
0005433868372	32690	26	18B
0005433868369	32690	27	18C
0005433868352	32690	28	18D
0005433868347	32690	29	19A
0005433868382	32690	30	19C
0005433868354	32690	31	19D
0005433868366	32690	32	20A
0005433868357	32690	33	20B
0005433868370	32690	34	20C
0005433868376	32690	35	20D
0005433868355	32690	36	21A
0005433868383	32690	37	21B
0005433868368	32690	38	21C
0005433868362	32690	39	21D
0005433868353	32690	40	22A
0005435860448	32690	41	22B
0005433868348	32690	42	22C
0005433868379	32690	43	22D
0005433868386	32690	44	23A
0005433868356	32690	45	23B
0005432799133	12139	1	1A
0005432799210	12139	2	1C
0005432799178	12139	3	2B
0005432799170	12139	4	3A
0005432799244	12139	5	3B
0005432799207	12139	6	3D
0005432799158	12139	7	4B
0005432799259	12139	8	4C
0005432799109	12139	9	5A
0005432799209	12139	10	5B
0005432799084	12139	11	5D
0005432799185	12139	12	6B
0005432799321	12139	13	6D
0005432799161	12139	14	7A
0005432799087	12139	15	18A
0005432799320	12139	16	18C
0005432799157	12139	17	19A
0005432799156	12139	18	19D
0005432799298	12139	19	20A
0005432799217	12139	20	21A
0005432799045	12139	21	22A
0005432799208	12139	22	22B
0005432799159	12139	23	22C
0005432799393	14819	1	1A
0005432799406	14819	2	1B
0005432799391	14819	3	1C
0005432799390	14819	4	1D
0005432799408	14819	5	2C
0005432799389	14819	6	2B
0005432799394	14819	7	3A
0005432799415	14819	8	3C
0005432799399	14819	9	4B
0005432799403	14819	10	4D
0005432799407	14819	11	6A
0005432799398	14819	12	6C
0005432799392	14819	13	6D
0005432799410	14819	14	7A
0005432799412	14819	15	7B
0005432799387	14819	16	7C
0005432799395	14819	17	7D
0005432799397	14819	18	18A
0005432799388	14819	19	18B
0005432799402	14819	20	18C
0005432799404	14819	21	18D
0005432799401	14819	22	19A
0005432799400	14819	23	19C
0005432799411	14819	24	20A
0005432799414	14819	25	20B
0005432799413	14819	26	21B
0005432799409	14819	27	21C
0005432799396	14819	28	22A
0005432799405	14819	29	22C
0005434407720	7077	1	1A
0005435310931	7077	2	1C
0005434299548	7077	3	1F
0005432108246	7077	4	1D
0005434299533	7077	5	2A
0005434407678	7077	6	2D
0005434407692	7077	7	2C
0005434299543	7077	8	3A
0005435310891	7077	9	2F
0005432108247	7077	10	3D
0005434299541	7077	11	3F
0005434407697	7077	12	4A
0005434407681	7077	13	4D
0005434299532	7077	14	4C
0005434407724	7077	15	4E
0005434407675	7077	16	4F
0005434407698	7077	17	5C
0005434407711	7077	18	5B
0005434299531	7077	19	5D
0005434407709	7077	20	5E
0005434407686	7077	21	5F
0005435310870	7077	22	6B
0005435310871	7077	23	6A
0005434299545	7077	24	6C
0005434299547	7077	25	6D
0005434299544	7077	26	6F
0005434407701	7077	27	6E
0005434407679	7077	28	7B
0005435293126	7077	29	7A
0005432108248	7077	30	7C
0005434407703	7077	31	7D
0005435310938	7077	32	7F
0005434407707	7077	33	7E
0005432153934	7077	34	8A
0005434407722	7077	35	8C
0005435293127	7077	36	8B
0005434299549	7077	37	8E
0005434299550	7077	38	8D
0005434407693	7077	39	8F
0005434407730	7077	40	9A
0005434407713	7077	41	9B
0005432153928	7077	42	9D
0005434407699	7077	43	9C
0005434407714	7077	44	9F
0005432153929	7077	45	9E
0005434299530	7077	46	10B
0005434299527	7077	47	10D
0005434407721	7077	48	10C
0005434299539	7077	49	10E
0005435310917	7077	50	11A
0005432153933	7077	51	11B
0005434407682	7077	52	11D
0005432153930	7077	53	11C
0005434407733	7077	54	11E
0005434299534	7077	55	12A
0005434407735	7077	56	11F
0005434299528	7077	57	12B
0005434407677	7077	58	12C
0005434407688	7077	59	12E
0005434299537	7077	60	12D
0005434299529	7077	61	12F
0005435310937	7077	62	13B
0005434407694	7077	63	13A
0005434407695	7077	64	13C
0005435293117	7077	65	13E
0005434407718	7077	66	14A
0005434407734	7077	67	14B
0005434407727	7077	68	14C
0005434407689	7077	69	14E
0005434407732	7077	70	14D
0005435293118	7077	71	15A
0005434299546	7077	72	14F
0005434299538	7077	73	15B
0005435293176	7077	74	15C
0005434407676	7077	75	15D
0005435310892	7077	76	15E
0005434407710	7077	77	15F
0005434407715	7077	78	16B
0005434407725	7077	79	16A
0005434407690	7077	80	16E
0005434407731	7077	81	17A
0005435293141	7077	82	16F
0005434407673	7077	83	17B
0005434299542	7077	84	17C
0005434299540	7077	85	17D
0005434407702	7077	86	18A
0005434299536	7077	87	17F
0005434407726	7077	88	18B
0005434407687	7077	89	18C
0005434407672	7077	90	18E
0005434407674	7077	91	18D
0005435310887	7077	92	18F
0005432153931	7077	93	19A
0005434407696	7077	94	19B
0005434407723	7077	95	19D
0005435293144	7077	96	19C
0005435310919	7077	97	19F
0005435293140	7077	98	19E
0005434407712	7077	99	20A
0005434407680	7077	100	20D
0005434407708	7077	101	20E
0005434407719	7077	102	20F
0005434407729	7077	103	21A
0005434407706	7077	104	21B
0005434407684	7077	105	21D
0005432153932	7077	106	21F
0005434407717	7077	107	21E
0005434407691	7077	108	22B
0005434299535	7077	109	22D
0005434407683	7077	110	22F
0005434407700	7077	111	22E
0005434407728	7077	112	23A
0005435293154	7077	113	23B
0005434407685	7077	114	23C
0005434407705	7077	115	23E
0005434407716	7077	116	23D
0005434407704	7077	117	23F
0005435293239	26920	1	1A
0005434407243	26920	2	1C
0005435311049	26920	3	1D
0005434407248	26920	4	1F
0005435311041	26920	5	2A
0005434299391	26920	6	2C
0005434407240	26920	7	2F
0005434299330	26920	8	3A
0005434407114	26920	9	3C
0005435311046	26920	10	3F
0005434407376	26920	11	4A
0005434299274	26920	12	4C
0005434407086	26920	13	4B
0005434299327	26920	14	4D
0005434407173	26920	15	4E
0005434299358	26920	16	4F
0005434406958	26920	17	5B
0005435293235	26920	18	5A
0005435311040	26920	19	5C
0005434299446	26920	20	5D
0005434299234	26920	21	5E
0005434406918	26920	22	6A
0005432058373	26920	23	5F
0005435293237	26920	24	6C
0005435311039	26920	25	6B
0005435311042	26920	26	6D
0005432058374	26920	27	6F
0005435311038	26920	28	6E
0005434407036	26920	29	7A
0005434406962	26920	30	7B
0005434407151	26920	31	7C
0005434299414	26920	32	7E
0005434299453	26920	33	7F
0005434406919	26920	34	8A
0005434407174	26920	35	8C
0005435311044	26920	36	8E
0005434407216	26920	37	8D
0005434407249	26920	38	8F
0005434407337	26920	39	9A
0005434407136	26920	40	9B
0005434407152	26920	41	9D
0005434407099	26920	42	9C
0005435293244	26920	43	9F
0005434406908	26920	44	9E
0005435293241	26920	45	10B
0005434299415	26920	46	10D
0005434407225	26920	47	10C
0005434406933	26920	48	11A
0005434406998	26920	49	10E
0005434407026	26920	50	11B
0005434407122	26920	51	11C
0005434406991	26920	52	11E
0005435293246	26920	53	11D
0005434299439	26920	54	11F
0005434407344	26920	55	12B
0005434406961	26920	56	12A
0005434406795	26920	57	12C
0005434407081	26920	58	12D
0005435293236	26920	59	12E
0005434407126	26920	60	12F
0005434299357	26920	61	13A
0005434299317	26920	62	13B
0005434407223	26920	63	13C
0005434407029	26920	64	13E
0005434406796	26920	65	13D
0005435293242	26920	66	13F
0005434407154	26920	67	14B
0005434299392	26920	68	14C
0005434299360	26920	69	14D
0005435311048	26920	70	14E
0005434299377	26920	71	14F
0005434299332	26920	72	15B
0005434406952	26920	73	15A
0005434407007	26920	74	15C
0005434299238	26920	75	15D
0005434406951	26920	76	15E
0005435311050	26920	77	16A
0005434299346	26920	78	15F
0005435293238	26920	79	16B
0005434407097	26920	80	16C
0005434299445	26920	81	16E
0005434407226	26920	82	16D
0005435311047	26920	83	16F
0005434299347	26920	84	17A
0005434407063	26920	85	17B
0005434299421	26920	86	17C
0005434406969	26920	87	17D
0005434407037	26920	88	17E
0005434299275	26920	89	18A
0005434407055	26920	90	17F
0005435311043	26920	91	18B
0005434407113	26920	92	18D
0005435311045	26920	93	18C
0005435311051	26920	94	18E
0005434407224	26920	95	18F
0005434407150	26920	96	19A
0005434407153	26920	97	19C
0005434299237	26920	98	19B
0005435293240	26920	99	19D
0005434406960	26920	100	19E
0005434299454	26920	101	19F
0005434407054	26920	102	20A
0005434407115	26920	103	20C
0005434407089	26920	104	20B
0005434406999	26920	105	20D
0005434407011	26920	106	20E
0005434407135	26920	107	20F
0005435311037	26920	108	21B
0005434407242	26920	109	21A
0005435311036	26920	110	21D
0005434406827	26920	111	21C
0005432058372	26920	112	21F
0005434407090	26920	113	21E
0005434299345	26920	114	22C
0005434407100	26920	115	22B
0005434407296	26920	116	22D
0005432058375	26920	117	22F
0005434299310	26920	118	22E
0005434407000	26920	119	23A
0005434407247	26920	120	23B
0005434299311	26920	121	23C
0005434299359	26920	122	23E
0005435293243	26920	123	23D
0005435293245	26920	124	23F
0005432604302	6442	1	1A
0005432604329	6442	2	1B
0005432604312	6442	3	1C
0005432604292	6442	4	1D
0005432604301	6442	5	2A
0005432604297	6442	6	2B
0005432604320	6442	7	2C
0005432604294	6442	8	2D
0005432604315	6442	9	3A
0005432604309	6442	10	3B
0005432604317	6442	11	3D
0005432604322	6442	12	4A
0005432604304	6442	13	4B
0005432604328	6442	14	4C
0005432604325	6442	15	4D
0005432604330	6442	16	5A
0005432604319	6442	17	5B
0005435218105	6442	18	5C
0005434512114	6442	19	5D
0005432604316	6442	20	6A
0005432604299	6442	21	6B
0005432604306	6442	22	6C
0005432604308	6442	23	6D
0005432604296	6442	24	7A
0005432604314	6442	25	7B
0005432604326	6442	26	7C
0005432604310	6442	27	7D
0005432604307	6442	28	18A
0005435218106	6442	29	18B
0005432604324	6442	30	18C
0005432604291	6442	31	18D
0005432604321	6442	32	19A
0005432604331	6442	33	19B
0005432604303	6442	34	19C
0005432604311	6442	35	19D
0005432604318	6442	36	20A
0005432604295	6442	37	20B
0005434512112	6442	38	20C
0005432604313	6442	39	21A
0005432604298	6442	40	21B
0005432604323	6442	41	21C
0005432604293	6442	42	22B
0005432604327	6442	43	22C
0005432604300	6442	44	22D
0005434512113	6442	45	23A
0005432604305	6442	46	23B
0005432603873	21365	1	1A
0005432604069	21365	2	1B
0005432603851	21365	3	1C
0005432603922	21365	4	1D
0005432603883	21365	5	2A
0005432603874	21365	6	2B
0005432603899	21365	7	2C
0005432603882	21365	8	3A
0005432603850	21365	9	3B
0005432603970	21365	10	3C
0005432604119	21365	11	3D
0005432603900	21365	12	4A
0005432603799	21365	13	4B
0005432603872	21365	14	4C
0005432603862	21365	15	4D
0005432603972	21365	16	5A
0005432604120	21365	17	5B
0005432603952	21365	18	5C
0005432603978	21365	19	5D
0005432603814	21365	20	6A
0005432603982	21365	21	6B
0005432603942	21365	22	6C
0005432603933	21365	23	6D
0005432603979	21365	24	7A
0005432603870	21365	25	7B
0005432603943	21365	26	7C
0005432603826	21365	27	7D
0005432604090	21365	28	18A
0005432603931	21365	29	18B
0005432603941	21365	30	18C
0005432603965	21365	31	18D
0005432603961	21365	32	19A
0005432603953	21365	33	19B
0005432603819	21365	34	19C
0005432603921	21365	35	19D
0005432604091	21365	36	20A
0005432603802	21365	37	20B
0005432603963	21365	38	20C
0005432603813	21365	39	20D
0005434512036	21365	40	21B
0005432603932	21365	41	21C
0005432603948	21365	42	21D
0005432603861	21365	43	22A
0005432603852	21365	44	22B
0005432604038	21365	45	22C
0005432603871	21365	46	22D
0005432603944	21365	47	23A
0005432603964	21365	48	23B
0005433251439	14990	1	1C
0005434906706	14990	2	1D
0005434906782	14990	3	1F
0005434906785	14990	4	2A
0005434906696	14990	5	2C
0005434906479	14990	6	2D
0005434906613	14990	7	3A
0005433251456	14990	8	3C
0005434906709	14990	9	3F
0005434906705	14990	10	4A
0005434906738	14990	11	4C
0005434906730	14990	12	4D
0005433251443	14990	13	4F
0005433251444	14990	14	4E
0005434906775	14990	15	5A
0005433251433	14990	16	5C
0005434906653	14990	17	5D
0005434906663	14990	18	5E
0005433251440	14990	19	5F
0005433251464	14990	20	6A
0005434906749	14990	21	6C
0005433251452	14990	22	6D
0005434906378	14990	23	6E
0005434906771	14990	24	6F
0005434906777	14990	25	7A
0005433251454	14990	26	7C
0005434906586	14990	27	7D
0005434906544	14990	28	7F
0005434906736	14990	29	7E
0005433251450	14990	30	8A
0005434906698	14990	31	8C
0005434906542	14990	32	8D
0005434906767	14990	33	8E
0005434906776	14990	34	8F
0005434906674	14990	35	9A
0005433251455	14990	36	9C
0005433251460	14990	37	9D
0005434906707	14990	38	9E
0005434906541	14990	39	9F
0005433251458	14990	40	10A
0005434906748	14990	41	10C
0005434906597	14990	42	10D
0005434906478	14990	43	10F
0005433251453	14990	44	11A
0005434906673	14990	45	11C
0005433251459	14990	46	11D
0005434906583	14990	47	11E
0005434906798	14990	48	11F
0005434906741	14990	49	12A
0005433251446	14990	50	12C
0005434906508	14990	51	12D
0005433251434	14990	52	12E
0005434906766	14990	53	13A
0005433251441	14990	54	13C
0005433251461	14990	55	13D
0005434906599	14990	56	13E
0005434906530	14990	57	13F
0005433251457	14990	58	14A
0005433251451	14990	59	14C
0005433251445	14990	60	14D
0005434906577	14990	61	14E
0005434906654	14990	62	14F
0005433251435	14990	63	15C
0005433251462	14990	64	15D
0005434906773	14990	65	15E
0005434906740	14990	66	15F
0005433251448	14990	67	16A
0005433251438	14990	68	16C
0005433251442	14990	69	16D
0005434906708	14990	70	16F
0005434906754	14990	71	17A
0005433251449	14990	72	17D
0005434906535	14990	73	17F
0005434906675	14990	74	18A
0005434906576	14990	75	18C
0005434906598	14990	76	18D
0005433251436	14990	77	18E
0005433251437	14990	78	18F
0005434906573	14990	79	19A
0005433251463	14990	80	19C
0005434906792	14990	81	19D
0005434906768	14990	82	19E
0005434906739	14990	83	19F
0005434906624	14990	84	20A
0005434906470	14990	85	20C
0005433251447	14990	86	20D
0005434906582	14990	87	20E
0005434906732	14990	88	20F
0005434907183	25852	1	1A
0005434907171	25852	2	1C
0005433251119	25852	3	1D
0005434907177	25852	4	1F
0005433251136	25852	5	2A
0005434907211	25852	6	2C
0005433251188	25852	7	2D
0005434907175	25852	8	2F
0005433251159	25852	9	3A
0005433251231	25852	10	3C
0005433251110	25852	11	3D
0005434907187	25852	12	3F
0005434907181	25852	13	4A
0005434907170	25852	14	4C
0005434907168	25852	15	4D
0005433251084	25852	16	4E
0005434907179	25852	17	5A
0005434907195	25852	18	5D
0005433251223	25852	19	5E
0005434907207	25852	20	5F
0005434907178	25852	21	6C
0005434907201	25852	22	6A
0005433251022	25852	23	6D
0005434907174	25852	24	6E
0005433251194	25852	25	6F
0005433251122	25852	26	7A
0005434907193	25852	27	7C
0005434907198	25852	28	7D
0005434907190	25852	29	7E
0005434907167	25852	30	7F
0005434907197	25852	31	8A
0005434907208	25852	32	8C
0005434907180	25852	33	8D
0005434907188	25852	34	8E
0005434907196	25852	35	8F
0005433251291	25852	36	9A
0005434907206	25852	37	9C
0005434907212	25852	38	9D
0005434907189	25852	39	9E
0005433251242	25852	40	10A
0005433251111	25852	41	10C
0005434907163	25852	42	10D
0005434907186	25852	43	10E
0005434907194	25852	44	10F
0005434907204	25852	45	11A
0005434907166	25852	46	11C
0005434907164	25852	47	11D
0005433251166	25852	48	11E
0005434907210	25852	49	11F
0005433250980	25852	50	12D
0005434907199	25852	51	12E
0005433251261	25852	52	12F
0005434907182	25852	53	13C
0005434907185	25852	54	13D
0005434907192	25852	55	13E
0005433251224	25852	56	13F
0005434907162	25852	57	14A
0005434907165	25852	58	14C
0005434907200	25852	59	14D
0005434907203	25852	60	14E
0005434907169	25852	61	15A
0005434907202	25852	62	15C
0005433251135	25852	63	15D
0005434907161	25852	64	15E
0005434907191	25852	65	15F
0005434907213	25852	66	16C
0005433250981	25852	67	16D
0005433251167	25852	68	16E
0005433251257	25852	69	17A
0005434907176	25852	70	17D
0005434907173	25852	71	17E
0005433251262	25852	72	17F
0005433251212	25852	73	18A
0005433251232	25852	74	18C
0005433251118	25852	75	18D
0005434907205	25852	76	19A
0005434907172	25852	77	19C
0005433251187	25852	78	19D
0005433251271	25852	79	19E
0005434907209	25852	80	19F
0005433251200	25852	81	20A
0005434907184	25852	82	20C
0005433251139	25852	83	20E
0005433251189	25852	84	20F
0005433810505	14174	1	1A
0005433008583	14174	2	1C
0005433810499	14174	3	1D
0005433008581	14174	4	2A
0005433008589	14174	5	2C
0005433008592	14174	6	2F
0005433008595	14174	7	2D
0005433008608	14174	8	3C
0005433008600	14174	9	3D
0005433810502	14174	10	4A
0005433008579	14174	11	4C
0005433008584	14174	12	4D
0005433810500	14174	13	4E
0005433008610	14174	14	5D
0005433008593	14174	15	6C
0005433008590	14174	16	6E
0005433008582	14174	17	6F
0005433008599	14174	18	7A
0005433008603	14174	19	7C
0005433008575	14174	20	7E
0005433008568	14174	21	7F
0005433008571	14174	22	8A
0005433008570	14174	23	9D
0005433008564	14174	24	9E
0005433810504	14174	25	10A
0005433810501	14174	26	10D
0005433008588	14174	27	10E
0005433008577	14174	28	10F
0005433008594	14174	29	11C
0005433008605	14174	30	11D
0005433008573	14174	31	11F
0005433008574	14174	32	12C
0005433008602	14174	33	13C
0005433008597	14174	34	13D
0005433008604	14174	35	13F
0005433008606	14174	36	14A
0005433008585	14174	37	14E
0005433008607	14174	38	15C
0005433008567	14174	39	15F
0005433008586	14174	40	16D
0005433008609	14174	41	16E
0005433008578	14174	42	16F
0005433008591	14174	43	17A
0005433008565	14174	44	17C
0005433008569	14174	45	17D
0005433008598	14174	46	17E
0005433008587	14174	47	17F
0005433008572	14174	48	18A
0005433008580	14174	49	18E
0005433008601	14174	50	18F
0005433810496	14174	51	19E
0005433008596	14174	52	19F
0005433008566	14174	53	20C
0005433008576	14174	54	20D
0005433008110	22826	1	1C
0005433008258	22826	2	2C
0005433008209	22826	3	3F
0005433007961	22826	4	4D
0005433008182	22826	5	4F
0005433008170	22826	6	5A
0005433008168	22826	7	5D
0005433008235	22826	8	5F
0005433008185	22826	9	6C
0005433810535	22826	10	6D
0005433008126	22826	11	7A
0005433008108	22826	12	7D
0005433008125	22826	13	7E
0005433008025	22826	14	8A
0005433810536	22826	15	9D
0005433008061	22826	16	10D
0005433008128	22826	17	10F
0005433008274	22826	18	12A
0005433008359	22826	19	12F
0005433007962	22826	20	14D
0005433810537	22826	21	15A
0005433008230	22826	22	15C
0005433008226	22826	23	15D
0005433008227	22826	24	15F
0005433008169	22826	25	17D
0005433008259	22826	26	18C
0005433008225	22826	27	18D
0005433008240	22826	28	19A
0005433008039	22826	29	19C
0005433008229	22826	30	19E
0005433008060	22826	31	20A
0005433008228	22826	32	20E
0005435718837	27116	1	1D
0005435718863	27116	2	1F
0005435718878	27116	3	2F
0005435718843	27116	4	3D
0005435718836	27116	5	3F
0005435718828	27116	6	4C
0005435718874	27116	7	4D
0005435718853	27116	8	4E
0005435718871	27116	9	5A
0005435718881	27116	10	5E
0005435718847	27116	11	5F
0005435718858	27116	12	6F
0005435718848	27116	13	7A
0005435718829	27116	14	7C
0005435718856	27116	15	8D
0005435718882	27116	16	8F
0005435718861	27116	17	9C
0005435718867	27116	18	9D
0005435718831	27116	19	10C
0005435718873	27116	20	10E
0005435718877	27116	21	11A
0005435718839	27116	22	11C
0005435718875	27116	23	11D
0005435718849	27116	24	11F
0005435718835	27116	25	12E
0005435718841	27116	26	12F
0005435718862	27116	27	13C
0005435718830	27116	28	13E
0005435718834	27116	29	13F
0005435718852	27116	30	14E
0005435718870	27116	31	15D
0005435718846	27116	32	15E
0005435718865	27116	33	16D
0005435718872	27116	34	16E
0005435718827	27116	35	17C
0005435718868	27116	36	17D
0005435718857	27116	37	18A
0005435718840	27116	38	18D
0005435718880	27116	39	19D
0005435718883	27116	40	20A
0005435718854	27116	41	20D
0005435718869	27116	42	20E
0005435718855	27116	43	20F
0005434925450	14957	1	1F
0005434925414	14957	2	2F
0005434925376	14957	3	3F
0005434925399	14957	4	4A
0005434925302	14957	5	4F
0005434925331	14957	6	5A
0005434925321	14957	7	7A
0005434925442	14957	8	8F
0005434925395	14957	9	9C
0005434925330	14957	10	9D
0005434925363	14957	11	9E
0005434925290	14957	12	10C
0005434925364	14957	13	10D
0005434925484	14957	14	10E
0005434925295	14957	15	11A
0005434925303	14957	16	11D
0005434925434	14957	17	11F
0005434925396	14957	18	12A
0005434925343	14957	19	12C
0005434925404	14957	20	14C
0005434925460	14957	21	14E
0005434925375	14957	22	15D
0005434925351	14957	23	15E
0005434925392	14957	24	17D
0005434925468	14957	25	17E
0005434925398	14957	26	18E
0005434925774	20547	1	2D
0005434925766	20547	2	3C
0005434925775	20547	3	3D
0005434925773	20547	4	4A
0005434925753	20547	5	4E
0005434925752	20547	6	5C
0005434925758	20547	7	5E
0005434925767	20547	8	5F
0005434925768	20547	9	6E
0005434925759	20547	10	7F
0005434925756	20547	11	8E
0005434925769	20547	12	8F
0005434925770	20547	13	9C
0005434925765	20547	14	9D
0005434925751	20547	15	10E
0005434925763	20547	16	10F
0005434925760	20547	17	11F
0005434925757	20547	18	12F
0005434925771	20547	19	14C
0005434925764	20547	20	14F
0005434925762	20547	21	16E
0005434925761	20547	22	17A
0005434925754	20547	23	17C
0005434925750	20547	24	17E
0005434925755	20547	25	18F
0005434925772	20547	26	20C
0005435487812	15832	1	1B
0005435487811	15832	2	1C
0005435999051	15832	3	1D
0005435487824	15832	4	2A
0005435999069	15832	5	2B
0005435487809	15832	6	2C
0005435487825	15832	7	3B
0005435487815	15832	8	3C
0005435999017	15832	9	4A
0005435487817	15832	10	4B
0005435487821	15832	11	4C
0005435487827	15832	12	4D
0005435487814	15832	13	5A
0005435487822	15832	14	5B
0005435487818	15832	15	5C
0005435487813	15832	16	6A
0005435487823	15832	17	6B
0005435487828	15832	18	6C
0005435999015	15832	19	7B
0005435999117	15832	20	7D
0005435487808	15832	21	18A
0005435487819	15832	22	19A
0005435999078	15832	23	19B
0005435999104	15832	24	19C
0005435487816	15832	25	19D
0005435487826	15832	26	20A
0005435999016	15832	27	20D
0005435999057	15832	28	21A
0005435487810	15832	29	21D
0005435487820	15832	30	22A
0005435999044	15832	31	22B
0005435999087	15832	32	22C
0005435999010	15832	33	22D
0005435487829	15832	34	23A
0005435999045	15832	35	23B
0005435487699	19683	1	1A
0005435487588	19683	2	1C
0005435487636	19683	3	1D
0005435999222	19683	4	2A
0005435999230	19683	5	2B
0005435999232	19683	6	2D
0005435487609	19683	7	3B
0005435487622	19683	8	3C
0005435487714	19683	9	3D
0005435487642	19683	10	4A
0005435487643	19683	11	4B
0005435999231	19683	12	4D
0005435487621	19683	13	5A
0005435999226	19683	14	5B
0005435487503	19683	15	5D
0005435999234	19683	16	5C
0005435999223	19683	17	6A
0005435487649	19683	18	6B
0005435487504	19683	19	6C
0005435487559	19683	20	7A
0005435487533	19683	21	7B
0005435999233	19683	22	7C
0005435487523	19683	23	7D
0005435487700	19683	24	18A
0005435487529	19683	25	18B
0005435999229	19683	26	18C
0005435999228	19683	27	18D
0005435999225	19683	28	19A
0005435999221	19683	29	19B
0005435999219	19683	30	19C
0005435999227	19683	31	20A
0005435487482	19683	32	20B
0005435999220	19683	33	20C
0005435487671	19683	34	21A
0005435999224	19683	35	21B
0005435999235	19683	36	21D
0005435487610	19683	37	22A
0005435487534	19683	38	22C
0005435999218	19683	39	22D
0005435487510	19683	40	23B
0005435472647	6013	1	1A
0005435472613	6013	2	1D
0005435839446	6013	3	2A
0005435472646	6013	4	1F
0005435839419	6013	5	3C
0005435839421	6013	6	3D
0005435839426	6013	7	3F
0005435839434	6013	8	4D
0005435472685	6013	9	4C
0005435839430	6013	10	4F
0005435839427	6013	11	5C
0005435839422	6013	12	5F
0005435839442	6013	13	6B
0005435839431	6013	14	6C
0005435839432	6013	15	6F
0005432142249	6013	16	7D
0005435472599	6013	17	7F
0005435839441	6013	18	7E
0005432659705	6013	19	8B
0005435472689	6013	20	8C
0005432659706	6013	21	9A
0005435472631	6013	22	10A
0005435839436	6013	23	10C
0005435839445	6013	24	10D
0005435839424	6013	25	10F
0005432142248	6013	26	11B
0005432658590	6013	27	11D
0005435839443	6013	28	11E
0005435472709	6013	29	12A
0005432660817	6013	30	12E
0005435839433	6013	31	13E
0005435839423	6013	32	14B
0005432142250	6013	33	14C
0005435839437	6013	34	14E
0005435839440	6013	35	15E
0005435472655	6013	36	15D
0005435839420	6013	37	15F
0005435472665	6013	38	16B
0005435839435	6013	39	16F
0005435839428	6013	40	17C
0005435839418	6013	41	17A
0005435839429	6013	42	17D
0005432537030	6013	43	17F
0005435839439	6013	44	18B
0005435839425	6013	45	19E
0005435839438	6013	46	19D
0005432658591	6013	47	21C
0005432660818	6013	48	21E
0005435839444	6013	49	21F
0005435472786	18071	1	1C
0005435839070	18071	2	1A
0005435472784	18071	3	1D
0005435839269	18071	4	2C
0005435472793	18071	5	3A
0005435472783	18071	6	2F
0005435839223	18071	7	3D
0005435839208	18071	8	3F
0005435839160	18071	9	5F
0005432667430	18071	10	6B
0005435472795	18071	11	6D
0005435472790	18071	12	7A
0005435839119	18071	13	7C
0005435839195	18071	14	7D
0005435839117	18071	15	8C
0005435472782	18071	16	8A
0005435472785	18071	17	8D
0005435472789	18071	18	9A
0005432667431	18071	19	10C
0005435839118	18071	20	11C
0005432537058	18071	21	12A
0005432537057	18071	22	12D
0005435839281	18071	23	12C
0005435839280	18071	24	12B
0005435839222	18071	25	12F
0005435839132	18071	26	13C
0005432660794	18071	27	13B
0005435472792	18071	28	14C
0005435839155	18071	29	14B
0005435839335	18071	30	14F
0005435839236	18071	31	15D
0005435839126	18071	32	16A
0005435472794	18071	33	16B
0005435839221	18071	34	16D
0005435839194	18071	35	17A
0005435472797	18071	36	16F
0005435839192	18071	37	17D
0005435839131	18071	38	17F
0005435839199	18071	39	18A
0005435472787	18071	40	18E
0005435839220	18071	41	18F
0005435839191	18071	42	19C
0005435839171	18071	43	19A
0005435472791	18071	44	19D
0005435839165	18071	45	20A
0005435839154	18071	46	20C
0005435472788	18071	47	21A
0005435472796	18071	48	21E
0005435839193	18071	49	21D
0005433462712	19912	1	1A
0005433460403	19912	2	2C
0005433460406	19912	3	3H
0005433462717	19912	4	5A
0005433462713	19912	5	5B
0005433462711	19912	6	5C
0005433460407	19912	7	5H
0005433460404	19912	8	9B
0005433460405	19912	9	14A
0005433462723	19912	10	16F
0005433460400	19912	11	17G
0005433460408	19912	12	18D
0005433460398	19912	13	20B
0005433462710	19912	14	20E
0005433462718	19912	15	20G
0005433460409	19912	16	21B
0005433462720	19912	17	22B
0005433460399	19912	18	22D
0005433462715	19912	19	22G
0005433462709	19912	20	22H
0005433460402	19912	21	23H
0005433462724	19912	22	27A
0005433462714	19912	23	27E
0005433462721	19912	24	28A
0005433460401	19912	25	28G
0005433460410	19912	26	33E
0005433462716	19912	27	35G
0005433460412	19912	28	36G
0005433462719	19912	29	38D
0005433284985	23042	1	1A
0005433285094	23042	2	1C
0005433285087	23042	3	1D
0005433284951	23042	4	3A
0005433285037	23042	5	5E
0005435103921	23042	6	6A
0005435103916	23042	7	6C
0005435103917	23042	8	9B
0005435103913	23042	9	10B
0005435103915	23042	10	11E
0005433285186	23042	11	12A
0005435103912	23042	12	12C
0005433284999	23042	13	12D
0005433285095	23042	14	13A
0005433285072	23042	15	13D
0005435103919	23042	16	13E
0005435103911	23042	17	13F
0005435103910	23042	18	14B
0005433284981	23042	19	14E
0005433285071	23042	20	16B
0005433284936	23042	21	16E
0005435103909	23042	22	17C
0005433285024	23042	23	17E
0005433285043	23042	24	17D
0005435103914	23042	25	18A
0005433284919	23042	26	18C
0005433285012	23042	27	18E
0005433284969	23042	28	20A
0005433285056	23042	29	20D
0005435103920	23042	30	22A
0005433285031	23042	31	21F
0005435103918	23042	32	23F
0005435103828	32092	1	1A
0005435103836	32092	2	2C
0005433285276	32092	3	2F
0005433285278	32092	4	4A
0005433285264	32092	5	4E
0005435103830	32092	6	5A
0005433285294	32092	7	5D
0005435103832	32092	8	6B
0005435103831	32092	9	6C
0005435103829	32092	10	6E
0005433285277	32092	11	7A
0005433285290	32092	12	7B
0005433285286	32092	13	7D
0005433285282	32092	14	7F
0005433285293	32092	15	8B
0005433285268	32092	16	9C
0005433285266	32092	17	10B
0005433285279	32092	18	11C
0005435103837	32092	19	11D
0005433285280	32092	20	11F
0005433285281	32092	21	13A
0005433285270	32092	22	13D
0005435103847	32092	23	13C
0005435103823	32092	24	13F
0005433285292	32092	25	14B
0005433285267	32092	26	15A
0005433285291	32092	27	15C
0005435103840	32092	28	15F
0005433285285	32092	29	16D
0005433285272	32092	30	16E
0005433285273	32092	31	18A
0005435103846	32092	32	18C
0005435103838	32092	33	18F
0005435103848	32092	34	18E
0005433285275	32092	35	19A
0005433285288	32092	36	19C
0005433285274	32092	37	19F
0005435103849	32092	38	19E
0005433285289	32092	39	20B
0005433285287	32092	40	20C
0005433285269	32092	41	21A
0005433285283	32092	42	21B
0005433285284	32092	43	21E
0005433285265	32092	44	22E
0005433285271	32092	45	23E
0005432892751	19950	1	1A
0005432802434	19950	2	1C
0005432802444	19950	3	2C
0005433111501	19950	4	3A
0005432802464	19950	5	4C
0005432802457	19950	6	5A
0005432892752	19950	7	5F
0005433112370	19950	8	5D
0005433112365	19950	9	7C
0005433111496	19950	10	8A
0005433111490	19950	11	7F
0005433111498	19950	12	8B
0005432802456	19950	13	8D
0005433111495	19950	14	9A
0005433111497	19950	15	9C
0005432892758	19950	16	9F
0005433111494	19950	17	10B
0005432892744	19950	18	10D
0005433112366	19950	19	10F
0005432802458	19950	20	10E
0005432892754	19950	21	12B
0005432892746	19950	22	12E
0005432802460	19950	23	14A
0005432892757	19950	24	14B
0005432892750	19950	25	14D
0005433112367	19950	26	14F
0005432892749	19950	27	15A
0005432892755	19950	28	15F
0005433112363	19950	29	15D
0005432892748	19950	30	16B
0005433111500	19950	31	16D
0005433111493	19950	32	16F
0005432802461	19950	33	17A
0005433112364	19950	34	17D
0005433111489	19950	35	17C
0005432892747	19950	36	17F
0005432892756	19950	37	17E
0005432802449	19950	38	18C
0005432802463	19950	39	18B
0005433112368	19950	40	18E
0005433112369	19950	41	18F
0005434302853	19950	42	19A
0005433112362	19950	43	19F
0005432802448	19950	44	19E
0005432802462	19950	45	20A
0005433111499	19950	46	20C
0005432892745	19950	47	21B
0005433111502	19950	48	21A
0005433111492	19950	49	21C
0005432892753	19950	50	21D
0005433111491	19950	51	21F
0005434067179	30596	1	1C
0005432526822	30596	2	1A
0005434066620	30596	3	1H
0005432526791	30596	4	1G
0005432535776	30596	5	1D
0005432526362	30596	6	1K
0005432527173	30596	7	2D
0005432526963	30596	8	2H
0005435213575	30596	9	3A
0005432526758	30596	10	2K
0005432527055	30596	11	3D
0005432527036	30596	12	3H
0005435213552	30596	13	3G
0005434066831	30596	14	4C
0005434066927	30596	15	4A
0005432535777	30596	16	4G
0005435213542	30596	17	4D
0005432527001	30596	18	4K
0005434067075	30596	19	4H
0005432526962	30596	20	5A
0005432527107	30596	21	5H
0005432526361	30596	22	5G
0005435213566	30596	23	5D
0005435213573	30596	24	5K
0005435213518	30596	25	11D
0005432526640	30596	26	11C
0005435630968	30596	27	11F
0005435213533	30596	28	11H
0005432211502	30596	29	11G
0005432526821	30596	30	12C
0005432526609	30596	31	12A
0005435213545	30596	32	11K
0005432527236	30596	33	12E
0005435213531	30596	34	12D
0005432526948	30596	35	12G
0005432527072	30596	36	12K
0005432527198	30596	37	12H
0005432527179	30596	38	13D
0005435213555	30596	39	13C
0005432527019	30596	40	13F
0005434066931	30596	41	13E
0005432211501	30596	42	13G
0005434066883	30596	43	14A
0005432526920	30596	44	14D
0005432527362	30596	45	14C
0005434066830	30596	46	14F
0005432527038	30596	47	14E
0005435213520	30596	48	14K
0005434066665	30596	49	14G
0005432526336	30596	50	15A
0005435213558	30596	51	15E
0005432527465	30596	52	15H
0005432526643	30596	53	15F
0005434066702	30596	54	15K
0005432535784	30596	55	16D
0005432526728	30596	56	16C
0005434066707	30596	57	16A
0005432527002	30596	58	16F
0005434067131	30596	59	16E
0005432428906	30596	60	16K
0005435213530	30596	61	16H
0005435213510	30596	62	16G
0005432535779	30596	63	17C
0005434066937	30596	64	17A
0005432159855	30596	65	17D
0005432526745	30596	66	17K
0005435213535	30596	67	17H
0005435213526	30596	68	18C
0005432527096	30596	69	18B
0005435213528	30596	70	18A
0005435213522	30596	71	18E
0005432527337	30596	72	18D
0005432526889	30596	73	18G
0005435213570	30596	74	18F
0005434066977	30596	75	18J
0005434067005	30596	76	18H
0005435213550	30596	77	19B
0005434066890	30596	78	19A
0005432526509	30596	79	19D
0005435213540	30596	80	19C
0005432526729	30596	81	19F
0005432527174	30596	82	19E
0005434067132	30596	83	19J
0005432526360	30596	84	19H
0005435213549	30596	85	19G
0005434067159	30596	86	19K
0005435725600	30596	87	20C
0005432526965	30596	88	20B
0005432526347	30596	89	20A
0005432526690	30596	90	20E
0005432526818	30596	91	20D
0005434066913	30596	92	20H
0005434067036	30596	93	21A
0005432526586	30596	94	21C
0005432527020	30596	95	21B
0005435213511	30596	96	21F
0005432526641	30596	97	21E
0005432526981	30596	98	21H
0005434067006	30596	99	21G
0005432527157	30596	100	21K
0005434066907	30596	101	22B
0005432526514	30596	102	22E
0005432526719	30596	103	22D
0005432526672	30596	104	22J
0005432527246	30596	105	23B
0005432533263	30596	106	23A
0005432526906	30596	107	23D
0005435213512	30596	108	23C
0005435213532	30596	109	23F
0005434066946	30596	110	23E
0005432527037	30596	111	23H
0005432526718	30596	112	23G
0005434066697	30596	113	23K
0005435213571	30596	114	23J
0005435213560	30596	115	24F
0005432527558	30596	116	24E
0005435213561	30596	117	25A
0005434066691	30596	118	25D
0005432526615	30596	119	25C
0005432526443	30596	120	25B
0005433656670	30596	121	25F
0005432527307	30596	122	25H
0005433656672	30596	123	25K
0005434067002	30596	124	26C
0005432527220	30596	125	26B
0005432527361	30596	126	26D
0005435213557	30596	127	26G
0005432526703	30596	128	26F
0005435213554	30596	129	26K
0005435213508	30596	130	26J
0005432527209	30596	131	27A
0005434066799	30596	132	27D
0005432526885	30596	133	27C
0005432527154	30596	134	27E
0005432527367	30596	135	27H
0005432526449	30596	136	27G
0005435725602	30596	137	27K
0005434066708	30596	138	27J
0005434067070	30596	139	28B
0005432527041	30596	140	28A
0005435213524	30596	141	28E
0005432527108	30596	142	28D
0005434066785	30596	143	28C
0005435213563	30596	144	28G
0005435213534	30596	145	28F
0005432526743	30596	146	28J
0005432526867	30596	147	28H
0005432526927	30596	148	29A
0005432428905	30596	149	28K
0005432526691	30596	150	29C
0005432527312	30596	151	29B
0005432526614	30596	152	29E
0005435213569	30596	153	29J
0005432527000	30596	154	29G
0005432211497	30596	155	29K
0005434066701	30596	156	30B
0005432159856	30596	157	30A
0005432428896	30596	158	30E
0005435213519	30596	159	30D
0005435213559	30596	160	30C
0005432526613	30596	161	30G
0005432527029	30596	162	30F
0005434066985	30596	163	30J
0005432527056	30596	164	30H
0005432527119	30596	165	31A
0005434066955	30596	166	30K
0005432533258	30596	167	31D
0005432527030	30596	168	31C
0005432527103	30596	169	31F
0005434066832	30596	170	31E
0005432526802	30596	171	31J
0005432526612	30596	172	31H
0005434066925	30596	173	31G
0005432211503	30596	174	31K
0005434066947	30596	175	32C
0005432526879	30596	176	32A
0005432526513	30596	177	32E
0005432526611	30596	178	32D
0005432527158	30596	179	32G
0005432526692	30596	180	32F
0005432527083	30596	181	32K
0005432527045	30596	182	32J
0005435213541	30596	183	32H
0005435213539	30596	184	33B
0005435213553	30596	185	33A
0005432526773	30596	186	33D
0005432159857	30596	187	33C
0005432527137	30596	188	33G
0005435213546	30596	189	33F
0005435213521	30596	190	33E
0005432526510	30596	191	33K
0005435213543	30596	192	33J
0005434066912	30596	193	34B
0005432211496	30596	194	34D
0005435213536	30596	195	34F
0005435213547	30596	196	34K
0005434067064	30596	197	35B
0005435213538	30596	198	35D
0005434066926	30596	199	35C
0005432526523	30596	200	35F
0005432527123	30596	201	35E
0005435213556	30596	202	36A
0005432526710	30596	203	36C
0005432526578	30596	204	36B
0005432527023	30596	205	36F
0005432526676	30596	206	36D
0005434066951	30596	207	36H
0005432527003	30596	208	36G
0005435213517	30596	209	36K
0005432526759	30596	210	36J
0005432526733	30596	211	37B
0005435213515	30596	212	37A
0005432159858	30596	213	37E
0005435725599	30596	214	37D
0005432526771	30596	215	37F
0005432535791	30596	216	37H
0005434067011	30596	217	37G
0005432211500	30596	218	38A
0005432527466	30596	219	37K
0005432527031	30596	220	38C
0005432527241	30596	221	38K
0005432527356	30596	222	38J
0005432527136	30596	223	38H
0005432527239	30596	224	39B
0005434066786	30596	225	39D
0005434067163	30596	226	39F
0005434066699	30596	227	39E
0005435213523	30596	228	39H
0005433656671	30596	229	39G
0005432527092	30596	230	39K
0005432526966	30596	231	39J
0005434066664	30596	232	40C
0005432526642	30596	233	40B
0005434066800	30596	234	40A
0005435213568	30596	235	40E
0005432527166	30596	236	40D
0005432526800	30596	237	40G
0005434066932	30596	238	40K
0005432526511	30596	239	40J
0005432526830	30596	240	40H
0005432526772	30596	241	41B
0005434066717	30596	242	41C
0005432526616	30596	243	41E
0005435213525	30596	244	41H
0005435213544	30596	245	42C
0005432526964	30596	246	42B
0005435213565	30596	247	42E
0005432526115	30596	248	42D
0005432527132	30596	249	42H
0005435213529	30596	250	42G
0005432526742	30596	251	42F
0005432526732	30596	252	42J
0005434067230	30596	253	43B
0005435213562	30596	254	43A
0005432526921	30596	255	43D
0005432428897	30596	256	43F
0005434066819	30596	257	43E
0005432526770	30596	258	43H
0005432526938	30596	259	43G
0005434066898	30596	260	44A
0005432526907	30596	261	43J
0005432211499	30596	262	44C
0005434066888	30596	263	44B
0005434066906	30596	264	44E
0005432526644	30596	265	44D
0005434066692	30596	266	44F
0005432527109	30596	267	44H
0005432527070	30596	268	45B
0005435213516	30596	269	44K
0005432526712	30596	270	45D
0005432526500	30596	271	45C
0005435213574	30596	272	45F
0005432527308	30596	273	45E
0005432526922	30596	274	45H
0005435725601	30596	275	45G
0005432526727	30596	276	46A
0005435213551	30596	277	45K
0005434067071	30596	278	45J
0005434066690	30596	279	46B
0005432527042	30596	280	46E
0005434066698	30596	281	46D
0005432526744	30596	282	46C
0005432428904	30596	283	46G
0005432159859	30596	284	46F
0005434066965	30596	285	46J
0005435213509	30596	286	47C
0005432526504	30596	287	47A
0005432527106	30596	288	46K
0005435213527	30596	289	47E
0005435213567	30596	290	47G
0005432527199	30596	291	47F
0005432526882	30596	292	47K
0005434066882	30596	293	47H
0005435213548	30596	294	48D
0005432211498	30596	295	48C
0005435213564	30596	296	48A
0005434066784	30596	297	48F
0005432526314	30596	298	48E
0005434066950	30596	299	48G
0005434066889	30596	300	49A
0005432526638	30596	301	48K
0005435213513	30596	302	49E
0005432527364	30596	303	49C
0005435213572	30596	304	49F
0005434066716	30596	305	49K
0005435213514	30596	306	49H
0005435213537	30596	307	50C
0005432527467	30596	308	50A
0005434066619	30596	309	50E
0005432526886	30596	310	50D
0005432526450	30596	311	50G
0005434067063	30596	312	50F
0005432526819	30596	313	50K
0005432527165	30596	314	50H
0005432526505	30596	315	51F
0005432527018	30596	316	51E
0005435213507	30596	317	51D
0005433367885	24856	1	1A
0005435652415	24856	2	1D
0005435652488	24856	3	1F
0005435652474	24856	4	2A
0005433367904	24856	5	2C
0005433367879	24856	6	2D
0005435652631	24856	7	3A
0005435652628	24856	8	3C
0005435652337	24856	9	3D
0005435652626	24856	10	3F
0005435652657	24856	11	4E
0005433367883	24856	12	5A
0005435652601	24856	13	5C
0005433367878	24856	14	5D
0005435652615	24856	15	5E
0005433367907	24856	16	5F
0005433367908	24856	17	6A
0005433367871	24856	18	6C
0005435652637	24856	19	6D
0005433367893	24856	20	6E
0005435652574	24856	21	6F
0005433367876	24856	22	7A
0005435652565	24856	23	7C
0005435652697	24856	24	7D
0005433367875	24856	25	7E
0005435652611	24856	26	7F
0005435652724	24856	27	8A
0005435652553	24856	28	8C
0005435652636	24856	29	8D
0005435652506	24856	30	8E
0005435652558	24856	31	8F
0005433367905	24856	32	9A
0005435652635	24856	33	9C
0005433367881	24856	34	9D
0005433367889	24856	35	9E
0005433367892	24856	36	9F
0005435652550	24856	37	10A
0005433367901	24856	38	10C
0005435652567	24856	39	10D
0005435652632	24856	40	10E
0005433367873	24856	41	10F
0005435652475	24856	42	11A
0005433367890	24856	43	11C
0005433367886	24856	44	11D
0005433367900	24856	45	11E
0005433367887	24856	46	12A
0005435652580	24856	47	12C
0005435652507	24856	48	12D
0005433367884	24856	49	12E
0005433367903	24856	50	12F
0005433367894	24856	51	13A
0005433367906	24856	52	13C
0005435652513	24856	53	13D
0005435652564	24856	54	13E
0005433367880	24856	55	13F
0005435652599	24856	56	14A
0005435652602	24856	57	14C
0005435652588	24856	58	14D
0005435652616	24856	59	14E
0005435652570	24856	60	14F
0005433367877	24856	61	15A
0005435652600	24856	62	15C
0005433367895	24856	63	15D
0005433367896	24856	64	15E
0005435652425	24856	65	15F
0005433367899	24856	66	16A
0005435652619	24856	67	16C
0005435652495	24856	68	16D
0005433367888	24856	69	16E
0005433367897	24856	70	16F
0005433367874	24856	71	17A
0005433367902	24856	72	17C
0005435652723	24856	73	17D
0005435652613	24856	74	17F
0005433367891	24856	75	18C
0005435652670	24856	76	18D
0005435652718	24856	77	18E
0005433367882	24856	78	18F
0005435652540	24856	79	19A
0005433367898	24856	80	19C
0005435652545	24856	81	19D
0005435652416	24856	82	19E
0005433367872	24856	83	20A
0005435652612	24856	84	20C
0005435652579	24856	85	20D
0005435652514	24856	86	20E
0005435652578	24856	87	20F
0005435949781	6603	1	1C
0005435949779	6603	2	1D
0005435949772	6603	3	2C
0005435949776	6603	4	3D
0005435949780	6603	5	4A
0005435949774	6603	6	4C
0005435949775	6603	7	5D
0005435949778	6603	8	6A
0005435949782	6603	9	6C
0005435949773	6603	10	21B
0005435949777	6603	11	22D
0005434979777	2037	1	1A
0005434979798	2037	2	1B
0005434979776	2037	3	1C
0005434979775	2037	4	1D
0005434979778	2037	5	2A
0005434979794	2037	6	2B
0005434979789	2037	7	2C
0005434979799	2037	8	2D
0005434979783	2037	9	3A
0005434979803	2037	10	4A
0005434979801	2037	11	4C
0005434979804	2037	12	5A
0005434979805	2037	13	5B
0005434979786	2037	14	5D
0005434979785	2037	15	5C
0005434979781	2037	16	6B
0005434979792	2037	17	6C
0005434979782	2037	18	7A
0005434979796	2037	19	7B
0005434979795	2037	20	7D
0005434979784	2037	21	18B
0005434979780	2037	22	18C
0005434979791	2037	23	18D
0005434979802	2037	24	19C
0005435801695	2037	25	19D
0005434979800	2037	26	20A
0005434979797	2037	27	20B
0005435801697	2037	28	20C
0005434979793	2037	29	21A
0005434979788	2037	30	21B
0005435801696	2037	31	22A
0005434979779	2037	32	22B
0005434979790	2037	33	22C
0005434979787	2037	34	23A
0005434979504	23556	1	1B
0005434979462	23556	2	1D
0005434979395	23556	3	2A
0005434979383	23556	4	2C
0005434979422	23556	5	2D
0005434979388	23556	6	3A
0005434979471	23556	7	3B
0005435801679	23556	8	3C
0005434979403	23556	9	3D
0005434979291	23556	10	4A
0005434979506	23556	11	4B
0005434979547	23556	12	4C
0005434979505	23556	13	4D
0005435801668	23556	14	5B
0005434979431	23556	15	5C
0005435801678	23556	16	5D
0005434979560	23556	17	6A
0005434979423	23556	18	6B
0005434979576	23556	19	6C
0005434979464	23556	20	7D
0005434979511	23556	21	18B
0005434979561	23556	22	18C
0005434979575	23556	23	18D
0005434979384	23556	24	19A
0005434979512	23556	25	19D
0005434979521	23556	26	20A
0005434979470	23556	27	20B
0005434979441	23556	28	20C
0005434979502	23556	29	21B
0005434979463	23556	30	21C
0005434979440	23556	31	21D
0005434979574	23556	32	22A
0005434979553	23556	33	22C
0005434979389	23556	34	23B
0005434952531	2618	1	3A
0005434952532	2618	2	5A
0005434952530	2618	3	6A
0005434952529	2618	4	6B
0005433256412	2616	1	2B
0005433256413	2616	2	5A
0005433256405	2616	3	6B
0005434952507	28200	1	1B
0005434952499	28200	2	2B
0005434952515	28200	3	3A
0005433256422	28200	4	3B
0005434952486	28200	5	4A
0005434952484	28200	6	5A
0005433256421	28200	7	5B
0005434952485	28200	8	6A
0005434952506	28200	9	6B
0005433112374	19764	1	2A
0005433111507	19764	2	3A
0005433111506	19764	3	5A
0005433112373	19764	4	4B
0005434137572	11949	1	1A
0005434137213	11949	2	1D
0005434137298	11949	3	1F
0005434137380	11949	4	2A
0005434137784	11949	5	2C
0005434137367	11949	6	2D
0005434137184	11949	7	2F
0005434137594	11949	8	3A
0005434137852	11949	9	3C
0005434137558	11949	10	3D
0005434137531	11949	11	3F
0005434137571	11949	12	4A
0005434137450	11949	13	4C
0005434137432	11949	14	4D
0005434137544	11949	15	4E
0005434137595	11949	16	4F
0005434137397	11949	17	5C
0005434137561	11949	18	5D
0005434137396	11949	19	5E
0005434137670	11949	20	5F
0005434137431	11949	21	6A
0005434137603	11949	22	6C
0005434137853	11949	23	6D
0005434137532	11949	24	6E
0005434137605	11949	25	6F
0005434137657	11949	26	7C
0005434137428	11949	27	7E
0005434137235	11949	28	7F
0005434137421	11949	29	8A
0005434137613	11949	30	8C
0005434137494	11949	31	8D
0005434136872	11949	32	8E
0005434137656	11949	33	8F
0005434137534	11949	34	9A
0005434137214	11949	35	9D
0005434137698	11949	36	10A
0005434137493	11949	37	10D
0005434137112	11949	38	10E
0005434136890	11949	39	10F
0005434137156	11949	40	11A
0005434137569	11949	41	11C
0005434137474	11949	42	11D
0005434137302	11949	43	11E
0005434136973	11949	44	11F
0005434137411	11949	45	12A
0005434137655	11949	46	12C
0005434137420	11949	47	12D
0005434137357	11949	48	12E
0005434137451	11949	49	12F
0005434137441	11949	50	13A
0005434137741	11949	51	13D
0005434137212	11949	52	13E
0005434137234	11949	53	13F
0005434137271	11949	54	14C
0005434137430	11949	55	14D
0005434137344	11949	56	14E
0005434137123	11949	57	14F
0005434137135	11949	58	15C
0005434137299	11949	59	15D
0005434137854	11949	60	15E
0005434137427	11949	61	15F
0005434137134	11949	62	16A
0005434136950	11949	63	16C
0005434137361	11949	64	16E
0005434137476	11949	65	16F
0005434137188	11949	66	17A
0005434137303	11949	67	17C
0005434136778	11949	68	17D
0005434137489	11949	69	17E
0005434137309	11949	70	17F
0005434137791	11949	71	18A
0005434137514	11949	72	18C
0005434137311	11949	73	18D
0005434137237	11949	74	18E
0005434137440	11949	75	19A
0005434137272	11949	76	19C
0005434137860	11949	77	19E
0005434137757	11949	78	19F
0005434137533	11949	79	20A
0005434137648	11949	80	20D
0005434137389	11949	81	20E
0005434138082	28745	1	1C
0005434138095	28745	2	1D
0005434138069	28745	3	1F
0005434138066	28745	4	2A
0005434138048	28745	5	2C
0005434138068	28745	6	2F
0005434138038	28745	7	3A
0005434138035	28745	8	3C
0005434138055	28745	9	3D
0005434138075	28745	10	3F
0005434138061	28745	11	4A
0005434138073	28745	12	4C
0005434138108	28745	13	4D
0005434138083	28745	14	4E
0005434138078	28745	15	4F
0005434138116	28745	16	5A
0005434138103	28745	17	5C
0005434138042	28745	18	5D
0005434138063	28745	19	5E
0005434138123	28745	20	5F
0005434138079	28745	21	6A
0005434138089	28745	22	6C
0005434138098	28745	23	6D
0005434138087	28745	24	6E
0005434138112	28745	25	7A
0005434138097	28745	26	7D
0005434138037	28745	27	7E
0005434138102	28745	28	7F
0005434138056	28745	29	8A
0005434138065	28745	30	8C
0005434138054	28745	31	8D
0005434138120	28745	32	8E
0005434138081	28745	33	8F
0005434138072	28745	34	9A
0005434138057	28745	35	9C
0005434138118	28745	36	9D
0005434138100	28745	37	9E
0005434138058	28745	38	9F
0005434138044	28745	39	10A
0005434138105	28745	40	10C
0005434138046	28745	41	10D
0005434138051	28745	42	10E
0005434138088	28745	43	10F
0005434138076	28745	44	11A
0005434138045	28745	45	11C
0005434138119	28745	46	11D
0005434138050	28745	47	11E
0005434138094	28745	48	11F
0005434138064	28745	49	12A
0005434138115	28745	50	12D
0005434138047	28745	51	12E
0005434138059	28745	52	13A
0005434138106	28745	53	13C
0005434138062	28745	54	13E
0005434138099	28745	55	13F
0005434138124	28745	56	14A
0005434138049	28745	57	14C
0005434138122	28745	58	14D
0005434138071	28745	59	14E
0005434138113	28745	60	14F
0005434138091	28745	61	15A
0005434138093	28745	62	15C
0005434138067	28745	63	15D
0005434138080	28745	64	15E
0005434138086	28745	65	15F
0005434138104	28745	66	16A
0005434138121	28745	67	16C
0005434138074	28745	68	16D
0005434138101	28745	69	16E
0005434138117	28745	70	16F
0005434138111	28745	71	17A
0005434138107	28745	72	17C
0005434138060	28745	73	17D
0005434138052	28745	74	17E
0005434138040	28745	75	17F
0005434138114	28745	76	18A
0005434138036	28745	77	18C
0005434138077	28745	78	18D
0005434138070	28745	79	18E
0005434138084	28745	80	18F
0005434138090	28745	81	19A
0005434138039	28745	82	19C
0005434138092	28745	83	19D
0005434138053	28745	84	19E
0005434138043	28745	85	19F
0005434138110	28745	86	20A
0005434138109	28745	87	20C
0005434138085	28745	88	20D
0005434138096	28745	89	20E
0005434138041	28745	90	20F
0005433538870	6798	1	2A
0005435259723	6798	2	4A
0005433538869	6798	3	4B
0005435259732	6798	4	4C
0005433538871	6798	5	4D
0005435259722	6798	6	6C
0005433534498	6798	7	7A
0005433538872	6798	8	7C
0005433538874	6798	9	18C
0005433534497	6798	10	18D
0005433538868	6798	11	19A
0005433538866	6798	12	20C
0005433538867	6798	13	21A
0005433538873	6798	14	21B
0005433534499	6798	15	22D
0005435259758	25043	1	2C
0005435259757	25043	2	3A
0005433534475	25043	3	4B
0005433534484	25043	4	4C
0005433538774	25043	5	5A
0005435259755	25043	6	5B
0005433538805	25043	7	5C
0005433538798	25043	8	18B
0005433534474	25043	9	19C
0005433534476	25043	10	21A
0005435259756	25043	11	22C
0005433511954	809	1	1A
0005432922473	809	2	2C
0005433511953	809	3	2D
0005433511951	809	4	3B
0005432922499	809	5	3C
0005432922503	809	6	4A
0005433511949	809	7	4B
0005432922498	809	8	4C
0005433511952	809	9	5C
0005432922500	809	10	19B
0005432922511	809	11	19C
0005433511955	809	12	21B
0005433511948	809	13	21C
0005433511950	809	14	22A
0005433511947	809	15	22B
0005432922512	809	16	22C
0005433511900	16125	1	1A
0005432922525	16125	2	2C
0005432922526	16125	3	4C
0005433511850	16125	4	4D
0005433511849	16125	5	5C
0005432922524	16125	6	19C
0005433511874	16125	7	21D
0005433511902	16125	8	22B
0005433511901	16125	9	23B
0005435916151	3696	1	1A
0005435697356	3696	2	1B
0005435697345	3696	3	1C
0005434950529	3696	4	1D
0005435697343	3696	5	2A
0005435697332	3696	6	2B
0005435697355	3696	7	2C
0005435697359	3696	8	2D
0005435697338	3696	9	3A
0005435697331	3696	10	3B
0005435697353	3696	11	3D
0005435697344	3696	12	4A
0005435697354	3696	13	4B
0005434950530	3696	14	4D
0005435697340	3696	15	5A
0005435697334	3696	16	5B
0005435697350	3696	17	5C
0005435697357	3696	18	5D
0005435697339	3696	19	6A
0005435916149	3696	20	6B
0005435697342	3696	21	6C
0005435697352	3696	22	7A
0005435697337	3696	23	7B
0005435697351	3696	24	7D
0005435916150	3696	25	18B
0005435697349	3696	26	18C
0005434950528	3696	27	19B
0005435697346	3696	28	19C
0005435697336	3696	29	20A
0005435697333	3696	30	20B
0005435935018	3696	31	21A
0005435697348	3696	32	21B
0005434950531	3696	33	21C
0005435697335	3696	34	22A
0005435697341	3696	35	22D
0005435697347	3696	36	23A
0005435697358	3696	37	23B
0005435697049	16308	1	1A
0005434950487	16308	2	1C
0005435935042	16308	3	1D
0005435697095	16308	4	2A
0005435697100	16308	5	2B
0005435696951	16308	6	2C
0005435697088	16308	7	2D
0005435697009	16308	8	3A
0005435697048	16308	9	3B
0005435697090	16308	10	3D
0005435697126	16308	11	4A
0005435697045	16308	12	4B
0005435697082	16308	13	4C
0005435935044	16308	14	4D
0005435697010	16308	15	5A
0005435697094	16308	16	5B
0005435697046	16308	17	5C
0005435697073	16308	18	5D
0005435935043	16308	19	6C
0005435697043	16308	20	6D
0005435696973	16308	21	7A
0005435697040	16308	22	7B
0005435697081	16308	23	7C
0005435697063	16308	24	7D
0005435916167	16308	25	18B
0005435916168	16308	26	18A
0005435697101	16308	27	18C
0005435696983	16308	28	18D
0005434950485	16308	29	19A
0005435697184	16308	30	19B
0005435916169	16308	31	20A
0005435697064	16308	32	20B
0005434950484	16308	33	20C
0005435697125	16308	34	20D
0005435697005	16308	35	21A
0005434950489	16308	36	21B
0005435697183	16308	37	21C
0005435697139	16308	38	21D
0005435696950	16308	39	22A
0005435697042	16308	40	22B
0005435697044	16308	41	22C
0005435697011	16308	42	22D
0005435697138	16308	43	23A
0005435697047	16308	44	23B
0005434606828	3990	1	1B
0005432607568	3990	2	1C
0005435842321	3990	3	1D
0005434606830	3990	4	2B
0005432609731	3990	5	2C
0005432607566	3990	6	3C
0005433519458	3990	7	3D
0005435904889	3990	8	4C
0005434604897	3990	9	4D
0005432609732	3990	10	5C
0005434604898	3990	11	5D
0005435842320	3990	12	6B
0005434606829	3990	13	7C
0005435904894	3990	14	7D
0005433519462	3990	15	19A
0005433519457	3990	16	19B
0005435842322	3990	17	19C
0005433519456	3990	18	20A
0005432609733	3990	19	20B
0005434604899	3990	20	20C
0005432607567	3990	21	20D
0005433519459	3990	22	21A
0005435853591	3990	23	21B
0005433519461	3990	24	21D
0005432609730	3990	25	22B
0005433519460	3990	26	22D
0005434606779	22077	1	1C
0005433519432	22077	2	2D
0005434606788	22077	3	3C
0005434606799	22077	4	4D
0005434606793	22077	5	5C
0005434606798	22077	6	5D
0005433519418	22077	7	6A
0005434606784	22077	8	6B
0005433519421	22077	9	7A
0005433519420	22077	10	7D
0005434606785	22077	11	18A
0005434606790	22077	12	18D
0005435853612	22077	13	19B
0005435853613	22077	14	19D
0005434606781	22077	15	20D
0005433519417	22077	16	21B
0005434606780	22077	17	21D
0005433519414	22077	18	23B
0005435628726	735	1	1B
0005433348934	735	2	2B
0005433348954	735	3	3A
0005435628725	735	4	4A
0005433348944	735	5	4B
0005435628724	735	6	5B
0005433348909	735	7	6A
0005435628700	15894	1	1A
0005433348989	15894	2	1B
0005435628708	15894	3	2A
0005433348990	15894	4	2B
0005433348992	15894	5	3B
0005435628695	15894	6	4B
0005433348991	15894	7	5A
0005433348993	15894	8	6A
0005433158108	17233	1	1A
0005434445244	17233	2	1B
0005433158107	17233	3	3A
0005433159289	17233	4	2B
0005434446518	17233	5	4A
0005434445245	17233	6	4B
0005433159296	17233	7	5A
0005434445246	17233	8	5B
0005433159297	17233	9	6B
0005433159316	17614	1	2B
0005433159315	17614	2	3B
0005433159314	17614	3	6A
0005435383101	7891	1	1B
0005435132885	7891	2	1D
0005435132878	7891	3	2C
0005435383105	7891	4	2D
0005435132884	7891	5	3A
0005435132888	7891	6	4A
0005435383108	7891	7	4C
0005435383100	7891	8	5A
0005435132883	7891	9	5D
0005435383090	7891	10	6A
0005435383122	7891	11	6D
0005435132882	7891	12	7A
0005435383123	7891	13	18B
0005435383089	7891	14	18C
0005435383119	7891	15	18D
0005435132881	7891	16	19D
0005435383109	7891	17	20A
0005435383117	7891	18	20B
0005435132887	7891	19	21A
0005435132886	7891	20	21C
0005435132879	7891	21	22C
0005435132880	7891	22	22D
0005435383151	33117	1	1A
0005435383152	33117	2	1D
0005435383148	33117	3	2C
0005435132781	33117	4	2D
0005435383153	33117	5	3B
0005435132813	33117	6	3C
0005435132812	33117	7	3D
0005435132760	33117	8	4B
0005435132782	33117	9	5C
0005435132784	33117	10	5D
0005435132783	33117	11	6C
0005435132814	33117	12	7B
0005435383150	33117	13	7D
0005435383149	33117	14	18B
0005435132788	33117	15	20C
0005435132815	33117	16	22C
0005435160304	7519	1	1B
0005435160299	7519	2	1C
0005435160305	7519	3	1D
0005435390178	7519	4	2A
0005435160306	7519	5	4A
0005435160302	7519	6	5A
0005435390172	7519	7	5D
0005435160300	7519	8	6A
0005435390182	7519	9	7D
0005435160308	7519	10	18A
0005435390179	7519	11	19B
0005435390155	7519	12	19D
0005435160301	7519	13	20C
0005435390175	7519	14	22C
0005435160303	7519	15	22D
0005435160307	7519	16	23B
0005435160183	29561	1	1B
0005435390238	29561	2	3A
0005435160163	29561	3	3B
0005435390243	29561	4	3C
0005435160218	29561	5	5D
0005435160164	29561	6	7A
0005435160205	29561	7	7C
0005435160203	29561	8	7D
0005435160233	29561	9	18A
0005435160228	29561	10	18B
0005435390239	29561	11	18C
0005435160184	29561	12	19A
0005435390244	29561	13	19B
0005435390240	29561	14	19C
0005435390241	29561	15	19D
0005435390242	29561	16	20C
0005435160187	29561	17	23A
0005435160202	29561	18	23B
0005432394075	18483	1	1A
0005435178992	18483	2	1B
0005432394055	18483	3	2A
0005435178496	18483	4	2B
0005432398170	18483	5	3A
0005432398169	18483	6	3B
0005432394057	18483	7	4A
0005432394056	18483	8	5A
0005432394058	18483	9	4B
0005435178495	18483	10	5B
0005435178497	18483	11	6A
0005432394076	18483	12	6B
0005432400121	27160	1	1A
0005432398193	27160	2	1B
0005432400119	27160	3	2A
0005432398192	27160	4	2B
0005432400120	27160	5	3A
0005435178480	27160	6	3B
0005435178490	27160	7	4A
0005432400118	27160	8	4B
0005432398194	27160	9	5A
0005432398195	27160	10	5B
0005435179388	27160	11	6B
0005434191266	9795	1	2A
0005434191259	9795	2	3A
0005432663037	21843	1	1C
0005432664131	21843	2	1F
0005432661915	21843	3	1D
0005432664128	21843	4	3D
0005432664138	21843	5	3F
0005432663033	21843	6	5C
0005432664130	21843	7	5F
0005432663032	21843	8	6B
0005432661922	21843	9	6C
0005432661917	21843	10	6E
0005432661921	21843	11	7A
0005432661926	21843	12	7B
0005432661920	21843	13	7D
0005432664133	21843	14	8B
0005432664129	21843	15	8D
0005432663030	21843	16	9A
0005432664136	21843	17	9B
0005432663034	21843	18	9E
0005432661918	21843	19	10A
0005432664135	21843	20	11D
0005432663038	21843	21	11C
0005432664139	21843	22	11E
0005432661913	21843	23	12C
0005432663040	21843	24	12E
0005432663039	21843	25	12D
0005432663035	21843	26	13A
0005432661927	21843	27	13F
0005432661919	21843	28	14C
0005432664141	21843	29	15C
0005432664134	21843	30	16A
0005432663029	21843	31	16E
0005432663028	21843	32	17A
0005432663031	21843	33	17F
0005432661924	21843	34	17E
0005432664140	21843	35	18A
0005432663027	21843	36	18D
0005432663036	21843	37	19B
0005432661914	21843	38	19E
0005432661923	21843	39	19D
0005432664137	21843	40	19F
0005432664132	21843	41	20A
0005432664142	21843	42	20D
0005432661925	21843	43	20F
0005432661916	21843	44	21E
0005434504161	6552	1	1C
0005434504176	6552	2	2D
0005434504177	6552	3	2F
0005434504175	6552	4	3A
0005434504164	6552	5	3C
0005434504170	6552	6	3F
0005435103938	6552	7	4C
0005434504166	6552	8	4E
0005434504154	6552	9	4F
0005434504157	6552	10	5A
0005434504169	6552	11	5C
0005435103941	6552	12	5D
0005434504146	6552	13	5F
0005434504181	6552	14	6A
0005434504155	6552	15	6C
0005434504160	6552	16	6F
0005434504149	6552	17	7A
0005434504178	6552	18	7D
0005434504159	6552	19	7F
0005435103935	6552	20	8A
0005434504148	6552	21	8E
0005434504150	6552	22	10D
0005434504184	6552	23	11C
0005434504183	6552	24	11F
0005434504158	6552	25	12A
0005434504156	6552	26	12C
0005434504172	6552	27	12E
0005434504147	6552	28	13A
0005434504179	6552	29	13E
0005434504171	6552	30	14C
0005434504182	6552	31	14D
0005435103937	6552	32	14E
0005434504174	6552	33	15A
0005434504144	6552	34	15C
0005434504180	6552	35	16A
0005435103936	6552	36	16D
0005435103933	6552	37	16E
0005434504163	6552	38	16F
0005435103940	6552	39	17A
0005435103934	6552	40	17C
0005434504145	6552	41	17E
0005435103939	6552	42	17F
0005434504162	6552	43	18A
0005434504153	6552	44	18C
0005434504167	6552	45	18D
0005434504173	6552	46	18F
0005434504168	6552	47	19A
0005434504165	6552	48	19C
0005434504152	6552	49	20C
0005434504151	6552	50	20F
0005434503694	22673	1	1A
0005435103838	22673	2	1C
0005434503655	22673	3	2A
0005434503687	22673	4	3C
0005434503859	22673	5	3D
0005434503693	22673	6	3F
0005434503748	22673	7	4A
0005434503855	22673	8	4C
0005434503731	22673	9	4D
0005435103846	22673	10	4E
0005434503699	22673	11	4F
0005434503810	22673	12	5A
0005434503763	22673	13	5C
0005435103849	22673	14	5D
0005435103847	22673	15	5E
0005435103830	22673	16	6C
0005434503656	22673	17	6E
0005434503803	22673	18	6F
0005434503956	22673	19	7D
0005435103832	22673	20	8D
0005435103828	22673	21	9E
0005434503789	22673	22	9F
0005434503889	22673	23	10C
0005434503824	22673	24	10D
0005434503800	22673	25	10E
0005434503686	22673	26	11A
0005434503594	22673	27	11C
0005435103837	22673	28	11D
0005434503823	22673	29	11F
0005434503920	22673	30	12A
0005434503730	22673	31	12E
0005434503703	22673	32	13A
0005435103848	22673	33	13D
0005435103829	22673	34	13E
0005434503685	22673	35	14A
0005434503675	22673	36	14C
0005434503657	22673	37	14D
0005434503845	22673	38	14E
0005435103840	22673	39	15A
0005434503709	22673	40	15C
0005434503595	22673	41	15D
0005434503858	22673	42	15F
0005435103836	22673	43	16A
0005434503872	22673	44	17C
0005434503928	22673	45	17D
0005434503792	22673	46	17E
0005434503844	22673	47	18A
0005434503682	22673	48	18D
0005434503801	22673	49	18E
0005434503708	22673	50	18F
0005435103831	22673	51	19C
0005434503605	22673	52	19E
0005434503809	22673	53	19F
0005434503704	22673	54	20D
0005434503606	22673	55	20E
0005435103823	22673	56	20F
0005435653053	1689	1	1A
0005435653052	1689	2	1D
0005435653089	1689	3	1F
0005435653060	1689	4	2A
0005435653068	1689	5	2C
0005435653050	1689	6	2D
0005435653088	1689	7	2F
0005433367582	1689	8	3A
0005433367778	1689	9	3C
0005435653042	1689	10	3D
0005433367631	1689	11	3F
0005435653082	1689	12	4A
0005435653046	1689	13	4C
0005433367567	1689	14	4D
0005435653071	1689	15	4E
0005435653067	1689	16	4F
0005435653085	1689	17	5A
0005433367422	1689	18	5C
0005435653062	1689	19	5D
0005435653066	1689	20	5E
0005433367581	1689	21	5F
0005433367447	1689	22	6A
0005433367566	1689	23	6C
0005435653072	1689	24	6D
0005433367569	1689	25	6E
0005435653077	1689	26	6F
0005433367469	1689	27	7A
0005435653054	1689	28	7D
0005435653047	1689	29	7C
0005435653075	1689	30	7E
0005433367829	1689	31	7F
0005433367580	1689	32	8A
0005435653083	1689	33	8C
0005433367737	1689	34	8D
0005433367583	1689	35	8E
0005435653069	1689	36	8F
0005435653063	1689	37	9A
0005435653059	1689	38	9C
0005435653093	1689	39	9D
0005435653079	1689	40	9E
0005435653092	1689	41	10A
0005435653086	1689	42	10D
0005435653045	1689	43	10E
0005435653056	1689	44	10F
0005433367630	1689	45	11A
0005435653070	1689	46	11C
0005435653080	1689	47	11D
0005435653044	1689	48	11E
0005433367577	1689	49	11F
0005433367517	1689	50	12A
0005435653091	1689	51	12D
0005433367777	1689	52	12E
0005435653087	1689	53	12F
0005435653084	1689	54	13A
0005435653061	1689	55	13C
0005435653090	1689	56	13D
0005435653057	1689	57	13E
0005433367578	1689	58	13F
0005435653041	1689	59	14A
0005435653064	1689	60	14C
0005435653058	1689	61	14D
0005435653065	1689	62	14E
0005433367632	1689	63	15A
0005435653049	1689	64	15C
0005433367629	1689	65	15D
0005435653081	1689	66	15E
0005435653078	1689	67	15F
0005433367564	1689	68	16C
0005435653076	1689	69	16D
0005435653073	1689	70	16F
0005433367399	1689	71	17A
0005433367526	1689	72	17C
0005435653055	1689	73	17D
0005433367828	1689	74	17E
0005433367625	1689	75	17F
0005433367638	1689	76	18A
0005433367513	1689	77	18C
0005433367622	1689	78	18E
0005433367477	1689	79	18F
0005433367514	1689	80	19A
0005435653051	1689	81	19D
0005433367736	1689	82	19E
0005433367626	1689	83	19F
0005435653074	1689	84	20C
0005435653043	1689	85	20D
0005435653048	1689	86	20F
0005435652619	21697	1	1A
0005433367907	21697	2	1C
0005433367896	21697	3	1D
0005435652415	21697	4	1F
0005433367876	21697	5	2A
0005435652628	21697	6	2C
0005435652545	21697	7	2D
0005435652588	21697	8	2F
0005433367883	21697	9	3A
0005433367890	21697	10	3D
0005435652474	21697	11	3F
0005435652578	21697	12	4A
0005435652670	21697	13	4C
0005433367886	21697	14	4D
0005433367889	21697	15	4E
0005433367897	21697	16	4F
0005435652579	21697	17	5A
0005435652540	21697	18	5C
0005433367901	21697	19	5D
0005433367908	21697	20	5F
0005435652632	21697	21	6A
0005435652567	21697	22	6C
0005435652550	21697	23	6D
0005433367906	21697	24	6E
0005435652631	21697	25	6F
0005435652600	21697	26	7A
0005435652553	21697	27	7C
0005435652612	21697	28	7D
0005435652599	21697	29	7E
0005433367884	21697	30	7F
0005435652495	21697	31	8A
0005435652657	21697	32	8D
0005433367880	21697	33	8E
0005435652416	21697	34	8F
0005433367895	21697	35	9A
0005433367882	21697	36	9C
0005435652564	21697	37	9D
0005435652602	21697	38	10A
0005435652601	21697	39	10C
0005435652723	21697	40	10D
0005435652574	21697	41	10E
0005435652616	21697	42	10F
0005433367905	21697	43	11A
0005435652724	21697	44	11C
0005433367902	21697	45	11D
0005433367874	21697	46	11E
0005433367893	21697	47	11F
0005433367871	21697	48	12A
0005433367894	21697	49	12C
0005435652488	21697	50	12D
0005435652514	21697	51	12E
0005435652613	21697	52	12F
0005435652507	21697	53	13A
0005433367903	21697	54	13D
0005433367879	21697	55	13E
0005435652635	21697	56	13F
0005435652558	21697	57	14A
0005435652506	21697	58	14C
0005435652570	21697	59	14E
0005433367891	21697	60	14D
0005433367881	21697	61	14F
0005435652513	21697	62	15A
0005435652615	21697	63	15D
0005435652565	21697	64	15E
0005433367898	21697	65	15F
0005435652636	21697	66	16A
0005433367885	21697	67	16C
0005433367872	21697	68	16D
0005433367899	21697	69	16F
0005435652611	21697	70	17A
0005433367873	21697	71	17C
0005433367887	21697	72	17D
0005433367892	21697	73	17E
0005433367900	21697	74	17F
0005435652697	21697	75	18A
0005433367904	21697	76	18C
0005435652718	21697	77	18E
0005435652580	21697	78	18F
0005435652637	21697	79	19A
0005435652626	21697	80	19C
0005433367877	21697	81	19D
0005435652475	21697	82	19E
0005435652425	21697	83	19F
0005433367875	21697	84	20A
0005433367888	21697	85	20D
0005435652337	21697	86	20E
0005433367878	21697	87	20F
0005435627118	12230	1	1A
0005433985934	4186	1	1C
0005433985950	4186	2	1D
0005435788772	4186	3	1F
0005433985935	4186	4	2A
0005433985965	4186	5	2C
0005433985966	4186	6	2D
0005433985928	4186	7	2F
0005433985981	4186	8	3A
0005433985954	4186	9	3D
0005433985963	4186	10	3F
0005433985958	4186	11	4C
0005433985944	4186	12	4D
0005433985983	4186	13	5A
0005433985979	4186	14	5C
0005433985974	4186	15	5F
0005433985970	4186	16	6C
0005433985957	4186	17	6D
0005433985977	4186	18	6E
0005433985971	4186	19	7D
0005433985969	4186	20	7E
0005433985951	4186	21	8A
0005433985960	4186	22	8E
0005433985939	4186	23	9C
0005433985964	4186	24	9E
0005433985961	4186	25	10D
0005433985942	4186	26	10F
0005433985949	4186	27	11A
0005433985933	4186	28	11C
0005433985931	4186	29	11D
0005433985943	4186	30	11F
0005433985945	4186	31	12A
0005433985952	4186	32	12D
0005433985938	4186	33	12F
0005433985948	4186	34	13C
0005433985972	4186	35	13E
0005433985967	4186	36	13F
0005433985937	4186	37	14A
0005433985941	4186	38	14D
0005433985976	4186	39	14E
0005433985968	4186	40	15A
0005433985982	4186	41	15C
0005433985936	4186	42	15F
0005433985932	4186	43	16A
0005433985955	4186	44	16C
0005433985930	4186	45	16D
0005433985956	4186	46	16F
0005435788771	4186	47	17A
0005433985947	4186	48	17C
0005433985940	4186	49	17E
0005433985978	4186	50	17F
0005433985927	4186	51	18C
0005435788770	4186	52	18D
0005433985980	4186	53	18F
0005433985973	4186	54	19C
0005433985953	4186	55	19E
0005433985975	4186	56	19F
0005433985959	4186	57	20A
0005433985929	4186	58	20D
0005433985962	4186	59	20E
0005433985946	4186	60	20F
0005433985353	25661	1	1A
0005433985469	25661	2	1D
0005433985390	25661	3	2A
0005433985447	25661	4	3D
0005433985478	25661	5	3F
0005433985371	25661	6	4D
0005433985386	25661	7	4E
0005433985448	25661	8	5C
0005433985356	25661	9	5E
0005433985385	25661	10	6A
0005433985489	25661	11	6E
0005433985327	25661	12	7A
0005435788755	25661	13	7C
0005433985310	25661	14	7D
0005435788754	25661	15	7F
0005433985388	25661	16	8A
0005433985391	25661	17	8D
0005433985486	25661	18	8E
0005433985485	25661	19	9E
0005433985429	25661	20	9F
0005433985328	25661	21	10A
0005433985498	25661	22	10C
0005433985444	25661	23	10E
0005433985425	25661	24	11C
0005433985427	25661	25	11D
0005433985192	25661	26	12D
0005433985362	25661	27	12E
0005433985484	25661	28	13F
0005433985457	25661	29	14A
0005433985387	25661	30	14C
0005433985487	25661	31	14E
0005433985488	25661	32	15A
0005433985416	25661	33	15F
0005435788749	25661	34	17D
0005433985468	25661	35	17F
0005433985384	25661	36	18E
0005433985428	25661	37	18F
0005433985456	25661	38	19F
0005433985193	25661	39	19E
0005433985455	25661	40	20A
0005433985357	25661	41	20D
0005434190383	9032	1	1A
0005434516075	9032	2	1C
0005434516079	9032	3	1D
0005434190377	9032	4	4A
0005434516074	9032	5	4B
0005434190381	9032	6	4D
0005434516080	9032	7	6A
0005434516077	9032	8	6B
0005434516078	9032	9	7B
0005434190378	9032	10	19A
0005434190379	9032	11	19B
0005434516076	9032	12	19D
0005434190382	9032	13	20C
0005434190385	9032	14	21A
0005434190395	9032	15	22B
0005434190384	9032	16	22C
0005432663024	17861	1	1A
0005432655404	17861	2	2A
0005432660797	17861	3	2C
0005432869530	17861	4	2F
0005432655388	17861	5	3A
0005432655411	17861	6	3C
0005432666376	17861	7	3D
0005432665259	17861	8	3F
0005432661899	17861	9	4A
0005432660803	17861	10	4D
0005432660800	17861	11	5C
0005432665258	17861	12	5D
0005432655403	17861	13	5E
0005432655426	17861	14	5F
0005432655409	17861	15	6A
0005432664117	17861	16	6C
0005432869526	17861	17	6D
0005432655402	17861	18	6F
0005432659700	17861	19	7A
0005432661898	17861	20	7C
0005432657416	17861	21	7E
0005432655399	17861	22	7F
0005432657423	17861	23	8C
0005432660801	17861	24	8D
0005432660799	17861	25	8E
0005432663017	17861	26	8F
0005432661901	17861	27	9A
0005432663022	17861	28	9F
0005432663021	17861	29	10C
0005432655428	17861	30	10E
0005432869528	17861	31	10F
0005432655408	17861	32	11A
0005432667439	17861	33	11D
0005432869529	17861	34	11F
0005434151707	17861	35	12A
0005432661908	17861	36	12E
0005432869532	17861	37	12F
0005432667434	17861	38	13A
0005432655398	17861	39	13C
0005432658563	17861	40	13D
0005432657415	17861	41	13E
0005432663020	17861	42	14A
0005432869531	17861	43	14F
0005432655484	17861	44	16E
0005432655427	17861	45	16F
0005432655464	17861	46	17A
0005432655407	17861	47	17E
0005432667443	17861	48	18C
0005432655458	17861	49	18D
0005432655443	17861	50	19A
0005432657425	17861	51	19D
0005432665266	17861	52	20C
0005432665265	17861	53	20D
0005432869527	17861	54	20E
0005432657424	17861	55	20F
0005432869451	26305	1	1A
0005432869450	26305	2	1D
0005432665272	26305	3	1F
0005432667451	26305	4	2C
0005432655517	26305	5	3F
0005432666386	26305	6	4A
0005432655512	26305	7	4C
0005432660815	26305	8	4D
0005432655515	26305	9	5A
0005432655518	26305	10	5E
0005432660816	26305	11	5F
0005432658588	26305	12	6D
0005432655516	26305	13	7D
0005432655511	26305	14	7F
0005434151681	26305	15	8A
0005432655509	26305	16	8E
0005432655520	26305	17	9A
0005432659703	26305	18	10A
0005432659704	26305	19	10C
0005434151682	26305	20	10E
0005432655514	26305	21	11D
0005432658589	26305	22	12F
0005434151677	26305	23	13A
0005432666385	26305	24	13C
0005434151676	26305	25	13D
0005432655519	26305	26	15D
0005432666387	26305	27	16A
0005432657446	26305	28	17D
0005432869449	26305	29	17F
0005432655513	26305	30	18C
0005434151680	26305	31	18D
0005432657445	26305	32	19F
0005432655510	26305	33	20A
0005432869418	26305	34	20D
0005432667452	26305	35	20E
0005432328690	3111	1	1A
0005432328715	3111	2	1D
0005433438878	3111	3	1F
0005432328695	3111	4	2A
0005432328729	3111	5	2C
0005432328722	3111	6	2D
0005432328723	3111	7	3A
0005432328692	3111	8	3C
0005432328694	3111	9	3D
0005432328732	3111	10	3F
0005432328734	3111	11	4C
0005432328711	3111	12	4D
0005432328724	3111	13	4F
0005432328698	3111	14	5C
0005432328720	3111	15	5D
0005432328721	3111	16	5E
0005432328719	3111	17	5F
0005433438879	3111	18	6A
0005432328697	3111	19	6D
0005432328716	3111	20	6F
0005432328725	3111	21	7A
0005432328704	3111	22	7D
0005432328706	3111	23	8C
0005432328717	3111	24	8D
0005432905072	3111	25	8E
0005432905071	3111	26	8F
0005432905081	3111	27	9A
0005432328696	3111	28	9C
0005432328689	3111	29	9D
0005432328714	3111	30	9E
0005432287189	3111	31	9F
0005432287191	3111	32	10A
0005432287190	3111	33	10D
0005432328699	3111	34	10E
0005432287192	3111	35	10F
0005433438882	3111	36	11A
0005432328700	3111	37	11D
0005432328693	3111	38	11F
0005433438881	3111	39	12A
0005432328708	3111	40	12C
0005432328701	3111	41	13A
0005432328712	3111	42	13F
0005432328731	3111	43	14D
0005432328703	3111	44	15A
0005432328727	3111	45	15F
0005433438880	3111	46	16A
0005432328710	3111	47	16C
0005432328736	3111	48	16D
0005432328733	3111	49	16E
0005432328707	3111	50	16F
0005432328709	3111	51	17A
0005432328735	3111	52	17D
0005432328726	3111	53	18A
0005432287188	3111	54	18D
0005432328691	3111	55	19C
0005432328730	3111	56	19D
0005432328702	3111	57	19E
0005432328728	3111	58	19F
0005432328705	3111	59	20A
0005433438883	3111	60	20C
0005432328713	3111	61	20D
0005432328718	3111	62	20F
0005432328002	31109	1	1A
0005432328313	31109	2	1C
0005432905127	31109	3	1F
0005432328289	31109	4	2A
0005432328409	31109	5	2C
0005432328260	31109	6	2D
0005432328136	31109	7	2F
0005432328259	31109	8	3A
0005433438824	31109	9	3C
0005432328267	31109	10	3F
0005432327997	31109	11	4A
0005432328369	31109	12	4E
0005432328406	31109	13	5A
0005432328003	31109	14	5C
0005433438826	31109	15	6A
0005432054303	31109	16	6C
0005432327944	31109	17	6E
0005433438830	31109	18	6F
0005432328252	31109	19	7A
0005432328206	31109	20	7C
0005432328137	31109	21	7E
0005432328339	31109	22	7F
0005432328263	31109	23	8D
0005432328135	31109	24	8E
0005432328284	31109	25	8F
0005432328268	31109	26	9C
0005432328222	31109	27	9D
0005432328242	31109	28	9E
0005432328283	31109	29	9F
0005433438823	31109	30	10A
0005432054305	31109	31	10D
0005432054304	31109	32	10E
0005432328376	31109	33	11D
0005432328174	31109	34	11E
0005432328241	31109	35	11F
0005432328340	31109	36	12A
0005432328266	31109	37	12D
0005432905129	31109	38	12E
0005433438825	31109	39	13A
0005432328253	31109	40	13C
0005432328410	31109	41	13D
0005432328440	31109	42	13E
0005432328175	31109	43	13F
0005432905128	31109	44	14D
0005432328336	31109	45	14F
0005432328418	31109	46	15A
0005432328234	31109	47	15F
0005432328221	31109	48	16A
0005432328402	31109	49	16C
0005432905125	31109	50	16D
0005432905126	31109	51	16E
0005432328219	31109	52	17E
0005432328436	31109	53	17F
0005432328317	31109	54	18A
0005433438817	31109	55	18C
0005432328333	31109	56	18D
0005432328117	31109	57	18E
0005432328419	31109	58	19C
0005432328385	31109	59	19D
0005432328235	31109	60	19E
0005432328321	31109	61	20A
0005432328500	31109	62	20D
0005432328162	31109	63	20E
0005432146199	6194	1	1A
0005435999256	6194	2	1C
0005435487702	6194	3	2C
0005434309738	6194	4	2F
0005435487617	6194	5	3D
0005435487486	6194	6	3F
0005435999259	6194	7	4A
0005435999258	6194	8	4C
0005435999250	6194	9	4E
0005435999260	6194	10	5E
0005434309743	6194	11	6C
0005435487485	6194	12	6E
0005435296977	6194	13	6F
0005435487599	6194	14	7B
0005435297001	6194	15	8C
0005435487592	6194	16	8E
0005434309746	6194	17	10B
0005435487685	6194	18	10C
0005435999264	6194	19	11B
0005434309744	6194	20	11D
0005434309747	6194	21	11F
0005434309740	6194	22	12D
0005435999252	6194	23	12E
0005435999249	6194	24	13A
0005435999265	6194	25	13B
0005435487569	6194	26	13E
0005435297006	6194	27	14B
0005435999255	6194	28	14C
0005435487644	6194	29	14D
0005434309749	6194	30	14E
0005435999253	6194	31	15A
0005435999261	6194	32	15B
0005435487591	6194	33	15E
0005434309750	6194	34	16A
0005435487521	6194	35	16E
0005435999263	6194	36	16F
0005435487645	6194	37	17B
0005434309742	6194	38	17C
0005435999254	6194	39	17E
0005435487484	6194	40	17F
0005434309741	6194	41	18A
0005432146200	6194	42	18D
0005435487618	6194	43	18E
0005435487751	6194	44	19A
0005435297012	6194	45	19B
0005434309745	6194	46	20C
0005435487707	6194	47	20B
0005434309748	6194	48	20D
0005435487686	6194	49	20F
0005435487616	6194	50	21A
0005434309751	6194	51	21C
0005435999257	6194	52	22A
0005435487589	6194	53	22C
0005435999251	6194	54	22B
0005435999262	6194	55	22D
0005434309739	6194	56	22F
0005435296978	6194	57	23D
0005435487633	6194	58	23E
0005435487828	19543	1	1F
0005435487824	19543	2	1D
0005434309669	19543	3	2C
0005434309626	19543	4	3A
0005435999017	19543	5	4A
0005435297058	19543	6	4B
0005435487816	19543	7	4D
0005435487811	19543	8	4E
0005435487822	19543	9	5F
0005435487813	19543	10	6A
0005435999078	19543	11	6D
0005434309625	19543	12	6E
0005434309665	19543	13	6F
0005435999087	19543	14	7C
0005434309666	19543	15	8A
0005435999051	19543	16	8E
0005435487817	19543	17	9A
0005435999104	19543	18	9E
0005435999117	19543	19	10B
0005435487826	19543	20	10E
0005434309569	19543	21	10D
0005434309589	19543	22	11E
0005435487808	19543	23	12B
0005435487818	19543	24	12D
0005435297059	19543	25	13A
0005434309638	19543	26	13C
0005435487820	19543	27	13D
0005434309667	19543	28	13E
0005435487809	19543	29	14B
0005435487823	19543	30	14C
0005435999069	19543	31	14E
0005434309603	19543	32	14F
0005435999044	19543	33	15B
0005435487810	19543	34	15A
0005435999057	19543	35	15C
0005435487814	19543	36	15F
0005435297057	19543	37	16C
0005435487821	19543	38	16F
0005434309637	19543	39	17B
0005435999016	19543	40	17F
0005435487827	19543	41	17E
0005434309643	19543	42	18A
0005435487815	19543	43	18D
0005435487829	19543	44	19B
0005434309668	19543	45	19F
0005435487819	19543	46	20C
0005435487812	19543	47	20D
0005435297061	19543	48	20F
0005435999010	19543	49	21A
0005435487825	19543	50	21B
0005435999015	19543	51	22C
0005435999045	19543	52	22D
0005435297063	19543	53	22E
0005435297060	19543	54	23A
0005435297062	19543	55	23D
0005433186077	1550	1	1A
0005435517919	1550	2	1C
0005435502326	1550	3	1D
0005435502309	1550	4	1F
0005434565920	1550	5	2A
0005435502314	1550	6	2C
0005434565917	1550	7	2D
0005434565914	1550	8	2F
0005435502327	1550	9	3A
0005435508374	1550	10	3C
0005435502320	1550	11	3D
0005435508369	1550	12	4A
0005435517924	1550	13	4C
0005435502312	1550	14	4D
0005433186058	1550	15	4E
0005434565911	1550	16	4F
0005433186049	1550	17	5A
0005435517927	1550	18	5D
0005435517922	1550	19	5E
0005435502322	1550	20	5F
0005435502324	1550	21	6C
0005435517920	1550	22	6D
0005433186078	1550	23	6E
0005435508371	1550	24	6F
0005433186064	1550	25	7A
0005435508377	1550	26	7C
0005434565915	1550	27	7D
0005435502328	1550	28	7E
0005435508368	1550	29	7F
0005433186006	1550	30	8C
0005435517918	1550	31	8D
0005435502321	1550	32	9A
0005435508370	1550	33	9D
0005435508378	1550	34	9F
0005435502316	1550	35	10A
0005435508367	1550	36	10C
0005433186050	1550	37	10F
0005433186074	1550	38	11A
0005433186051	1550	39	11C
0005435502318	1550	40	11D
0005434565922	1550	41	11F
0005435502325	1550	42	12C
0005435517926	1550	43	12D
0005435502310	1550	44	12E
0005435502315	1550	45	12F
0005435508376	1550	46	13A
0005433186044	1550	47	13E
0005434565924	1550	48	13F
0005435502313	1550	49	14A
0005435508375	1550	50	14C
0005435502330	1550	51	14D
0005435517923	1550	52	14E
0005433186007	1550	53	14F
0005435502329	1550	54	15A
0005435508372	1550	55	15C
0005433186066	1550	56	15D
0005435502323	1550	57	15E
0005432291930	1550	58	15F
0005435502319	1550	59	16A
0005433186063	1550	60	16D
0005435508373	1550	61	16E
0005433186057	1550	62	16F
0005434565923	1550	63	17D
0005433186072	1550	64	17E
0005435502317	1550	65	17F
0005434565918	1550	66	18A
0005434565921	1550	67	18D
0005434565919	1550	68	19A
0005434565916	1550	69	19C
0005435502311	1550	70	19E
0005434565913	1550	71	19F
0005434565912	1550	72	20A
0005435502308	1550	73	20C
0005435517921	1550	74	20D
0005432291931	1550	75	20E
0005435517925	1550	76	20F
0005435529083	20872	1	1C
0005435529057	20872	2	1D
0005434565790	20872	3	1F
0005435529062	20872	4	2A
0005435529085	20872	5	2C
0005433186121	20872	6	2D
0005435529086	20872	7	2F
0005435502171	20872	8	3A
0005434565764	20872	9	3C
0005434565814	20872	10	3F
0005435502046	20872	11	4C
0005435529019	20872	12	4E
0005435529023	20872	13	5A
0005435502114	20872	14	5C
0005435502149	20872	15	5D
0005435545640	20872	16	5E
0005435529038	20872	17	5F
0005434565852	20872	18	6C
0005435528985	20872	19	6F
0005435545662	20872	20	7C
0005435528983	20872	21	8A
0005435528984	20872	22	8D
0005435502169	20872	23	8E
0005435502080	20872	24	8F
0005435529113	20872	25	9A
0005435545643	20872	26	9C
0005435545669	20872	27	9D
0005434565772	20872	28	10A
0005433186118	20872	29	10D
0005435545651	20872	30	10E
0005434565853	20872	31	10F
0005435502105	20872	32	11A
0005433186124	20872	33	11C
0005434565776	20872	34	11D
0005433186117	20872	35	11E
0005435529040	20872	36	11F
0005435529112	20872	37	12A
0005435545661	20872	38	12C
0005435502161	20872	39	12D
0005435502094	20872	40	12F
0005435502070	20872	41	13C
0005433186122	20872	42	13D
0005433186123	20872	43	13E
0005435529084	20872	44	13F
0005435545615	20872	45	14A
0005435502081	20872	46	14C
0005435502033	20872	47	15A
0005435502071	20872	48	15C
0005435529028	20872	49	15D
0005435545614	20872	50	15E
0005435502170	20872	51	16A
0005435502167	20872	52	16C
0005435529000	20872	53	16D
0005435528947	20872	54	17A
0005434565878	20872	55	17C
0005435529065	20872	56	17D
0005435502131	20872	57	17F
0005435529041	20872	58	18C
0005435529001	20872	59	18D
0005435529064	20872	60	18E
0005435529022	20872	61	18F
0005433186119	20872	62	19D
0005435545660	20872	63	19E
0005435528986	20872	64	19F
0005433186120	20872	65	20C
0005435502130	20872	66	20D
0005435502072	20872	67	20E
0005435153745	3882	1	1A
0005435153746	3882	2	1C
0005435153743	3882	3	2B
0005435153744	3882	4	4D
0005435153742	3882	5	5B
0005435931581	3882	6	7A
0005435931559	3882	7	18B
0005435153747	3882	8	19C
0005435153740	3882	9	20C
0005435931582	3882	10	20D
0005435153741	3882	11	21B
0005435931578	3882	12	22A
0005435931580	3882	13	22B
0005435931568	3882	14	22C
0005435931565	3882	15	23A
0005435153673	21865	1	1B
0005435153690	21865	2	2A
0005435153689	21865	3	2D
0005435153670	21865	4	3A
0005435153691	21865	5	3B
0005435153693	21865	6	7A
0005435931603	21865	7	7B
0005435153692	21865	8	7D
0005435931602	21865	9	18C
0005435931601	21865	10	19A
0005435153688	21865	11	19B
0005435153672	21865	12	22C
0005435931600	21865	13	23A
0005435225514	7223	1	1B
0005432628850	7223	2	1D
0005432628853	7223	3	2A
0005432628845	7223	4	2B
0005432628851	7223	5	3B
0005435225510	7223	6	3D
0005432628852	7223	7	4A
0005432628857	7223	8	4B
0005432628854	7223	9	5A
0005432628856	7223	10	5D
0005435225499	7223	11	6A
0005435225509	7223	12	6B
0005432628846	7223	13	18B
0005432628849	7223	14	19B
0005432628847	7223	15	19C
0005432628855	7223	16	19D
0005432628844	7223	17	20B
0005432628848	7223	18	20C
0005435225498	7223	19	21C
0005435225507	7223	20	22A
0005435225508	7223	21	22D
0005435225505	7223	22	23B
0005432628711	28103	1	1A
0005432628729	28103	2	1B
0005432628661	28103	3	1C
0005432628734	28103	4	1D
0005435225589	28103	5	3C
0005432628761	28103	6	3D
0005432628752	28103	7	4A
0005435225585	28103	8	4C
0005435225586	28103	9	5A
0005432628720	28103	10	5C
0005435225590	28103	11	6A
0005432628763	28103	12	6C
0005432628704	28103	13	7A
0005432628790	28103	14	7C
0005432628728	28103	15	18A
0005432628753	28103	16	18D
0005432628716	28103	17	19B
0005435225583	28103	18	19C
0005435225582	28103	19	20B
0005432628782	28103	20	20C
0005432628705	28103	21	21A
0005435225584	28103	22	21C
0005432628735	28103	23	21D
0005432628755	28103	24	22A
0005435225587	28103	25	22C
0005435225588	28103	26	22D
0005432628783	28103	27	23B
0005435960049	8763	1	3D
0005435960051	8763	2	6C
0005434267906	8763	3	7A
0005434267915	8763	4	7B
0005434267907	8763	5	7C
0005435960050	8763	6	18C
0005434267895	8763	7	19D
0005435960052	8763	8	21B
0005434267916	8763	9	21C
0005434267917	8763	10	23B
0005434267952	15224	1	3A
0005434267949	15224	2	5A
0005434267950	15224	3	6C
0005435960008	15224	4	18D
0005435960004	15224	5	19B
0005434267951	15224	6	19D
0005432693044	1168	1	1D
0005432675133	1168	2	2F
0005432693034	1168	3	2D
0005432693039	1168	4	3F
0005432693038	1168	5	4C
0005432693058	1168	6	5A
0005432693056	1168	7	5C
0005432693032	1168	8	5D
0005432675135	1168	9	6A
0005432693061	1168	10	6C
0005432677568	1168	11	6E
0005432693059	1168	12	7C
0005432693035	1168	13	7B
0005432693049	1168	14	7F
0005432873252	1168	15	8C
0005432873253	1168	16	8B
0005432675136	1168	17	8A
0005432675134	1168	18	8D
0005432693041	1168	19	8F
0005432675132	1168	20	8E
0005432873235	1168	21	9A
0005432677570	1168	22	9C
0005432873221	1168	23	10B
0005432873205	1168	24	10A
0005432693053	1168	25	10E
0005432693042	1168	26	11D
0005432675140	1168	27	11F
0005432693033	1168	28	12E
0005432677571	1168	29	12D
0005432873251	1168	30	13B
0005432693046	1168	31	13E
0005432675138	1168	32	13D
0005432873234	1168	33	14A
0005432675130	1168	34	14B
0005432693048	1168	35	14E
0005432675141	1168	36	15B
0005432693054	1168	37	15C
0005432693040	1168	38	15F
0005432693052	1168	39	15E
0005432693037	1168	40	16A
0005432693060	1168	41	16C
0005432693043	1168	42	16D
0005432677569	1168	43	16F
0005432675142	1168	44	17B
0005432675129	1168	45	17A
0005432693045	1168	46	17D
0005432693055	1168	47	18B
0005432693063	1168	48	18A
0005432675137	1168	49	18D
0005432675131	1168	50	18F
0005432693051	1168	51	19B
0005432873220	1168	52	19D
0005432693050	1168	53	19C
0005432693036	1168	54	20D
0005432675139	1168	55	20C
0005432675127	1168	56	20F
0005432693062	1168	57	21A
0005432693047	1168	58	21C
0005432693057	1168	59	21D
0005432675128	1168	60	21F
0005432692742	17497	1	1A
0005432692920	17497	2	1F
0005432692780	17497	3	1C
0005432692811	17497	4	2A
0005432692669	17497	5	2F
0005432692872	17497	6	3D
0005432692905	17497	7	3C
0005432692807	17497	8	4A
0005432677525	17497	9	3F
0005432692858	17497	10	4C
0005432692875	17497	11	5A
0005432692834	17497	12	4F
0005432677552	17497	13	6C
0005432873291	17497	14	6F
0005432692717	17497	15	7C
0005432675005	17497	16	7B
0005432675041	17497	17	7E
0005432674981	17497	18	8B
0005432873296	17497	19	8E
0005432692656	17497	20	9F
0005432692763	17497	21	9D
0005432674984	17497	22	10E
0005432692824	17497	23	11B
0005432674985	17497	24	11D
0005432674986	17497	25	11C
0005432692749	17497	26	11E
0005432692642	17497	27	12A
0005432873292	17497	28	12C
0005432674980	17497	29	12F
0005432692795	17497	30	13C
0005432674999	17497	31	13B
0005432675033	17497	32	13F
0005432677524	17497	33	14D
0005432677553	17497	34	14E
0005432692748	17497	35	15C
0005432692702	17497	36	15E
0005432692876	17497	37	15F
0005432692692	17497	38	16B
0005432675030	17497	39	16D
0005432692815	17497	40	16E
0005432692816	17497	41	17D
0005432873293	17497	42	18D
0005432675040	17497	43	18C
0005432674997	17497	44	18B
0005432675042	17497	45	19A
0005432692833	17497	46	18F
0005432873295	17497	47	19F
0005432674996	17497	48	20B
0005432692691	17497	49	20E
0005432692835	17497	50	20F
0005432873294	17497	51	21E
0005434435184	1154	1	2B
0005433156687	1154	2	3C
0005434435186	1154	3	4A
0005434435177	1154	4	5C
0005434435179	1154	5	5D
0005434435188	1154	6	6A
0005434435183	1154	7	7B
0005434435178	1154	8	7C
0005434435181	1154	9	7D
0005433156686	1154	10	18A
0005434435192	1154	11	18B
0005434435189	1154	12	19B
0005434435182	1154	13	19C
0005434435190	1154	14	19D
0005434435191	1154	15	21A
0005434435180	1154	16	21B
0005433156664	1154	17	21C
0005434435187	1154	18	22A
0005434435185	1154	19	22B
0005434435068	17303	1	1A
0005433156748	17303	2	1B
0005434435090	17303	3	1C
0005433156750	17303	4	1D
0005434435025	17303	5	3A
0005433156755	17303	6	3C
0005433156753	17303	7	4A
0005434435063	17303	8	4D
0005434435093	17303	9	5B
0005434435094	17303	10	6A
0005433156751	17303	11	6C
0005433156754	17303	12	7C
0005434434988	17303	13	18B
0005434435034	17303	14	18D
0005434435071	17303	15	19C
0005433156749	17303	16	19D
0005433156752	17303	17	20A
0005434435046	17303	18	21C
0005434435092	17303	19	22A
0005434434996	17303	20	22B
0005434435100	17303	21	22D
0005435928095	4096	1	1D
0005435086837	4096	2	2B
0005435086835	4096	3	3A
0005435928096	4096	4	4D
0005435086832	4096	5	5C
0005435928090	4096	6	18C
0005435086836	4096	7	19B
0005435086838	4096	8	20A
0005435086834	4096	9	20D
0005435086833	4096	10	21B
0005435928097	4096	11	21C
0005435086839	4096	12	22D
0005435086766	24418	1	1B
0005435928141	24418	2	1C
0005435086790	24418	3	2C
0005435928144	24418	4	3B
0005435086791	24418	5	3C
0005435086749	24418	6	3D
0005435928143	24418	7	4A
0005435928142	24418	8	5D
0005435086767	24418	9	6A
0005435928145	24418	10	22A
0005435928146	24418	11	22D
0005435098535	11072	1	2B
0005435098536	11072	2	2H
0005435551518	11072	3	4F
0005435098527	11072	4	9H
0005435551528	11072	5	11B
0005435551501	11072	6	11G
0005435098530	11072	7	12D
0005435551535	11072	8	13A
0005435098531	11072	9	13H
0005435551524	11072	10	15D
0005435551536	11072	11	15H
0005435551532	11072	12	16D
0005435098537	11072	13	18E
0005435098529	11072	14	20H
0005435551523	11072	15	21F
0005435551517	11072	16	22B
0005435098534	11072	17	22H
0005435551533	11072	18	25E
0005435098533	11072	19	30B
0005435098532	11072	20	34A
0005435551500	11072	21	34G
0005435551531	11072	22	35A
0005435551521	11072	23	35D
0005435551534	11072	24	37B
0005435551506	11072	25	37H
0005435551525	11072	26	39D
0005435551581	17013	1	5F
0005435098557	17013	2	9H
0005435551586	17013	3	11D
0005435098556	17013	4	12E
0005435551597	17013	5	13D
0005435551579	17013	6	15D
0005435551588	17013	7	16G
0005435098555	17013	8	18A
0005435098559	17013	9	18F
0005435551591	17013	10	18E
0005435551585	17013	11	18G
0005435551589	17013	12	20H
0005435551594	17013	13	24E
0005435098558	17013	14	25E
0005435551582	17013	15	27A
0005435551583	17013	16	29B
0005435551596	17013	17	31D
0005435551595	17013	18	32A
0005435098552	17013	19	32B
0005435551593	17013	20	34B
0005435098553	17013	21	34H
0005435551584	17013	22	35B
0005435098554	17013	23	36B
0005435098560	17013	24	37F
0005435551592	17013	25	38A
0005435551580	17013	26	38D
0005435551587	17013	27	38G
0005435551590	17013	28	39D
0005434963996	18243	1	2A
0005433261563	18243	2	2B
0005433261562	18243	3	2F
0005434963994	18243	4	3A
0005434964049	18243	5	3F
0005434964045	18243	6	3C
0005433261556	18243	7	3H
0005434964001	18243	8	4B
0005434964012	18243	9	4A
0005434963958	18243	10	5H
0005433261559	18243	11	11D
0005434964031	18243	12	12A
0005434964075	18243	13	12D
0005434964068	18243	14	12H
0005434964092	18243	15	13B
0005434963979	18243	16	13F
0005434964040	18243	17	13H
0005433261574	18243	18	15E
0005433261561	18243	19	15D
0005434964056	18243	20	15G
0005433261575	18243	21	16E
0005433261564	18243	22	16H
0005434964070	18243	23	17A
0005433261555	18243	24	17F
0005434963940	18243	25	18A
0005434964104	18243	26	18F
0005433261573	18243	27	18E
0005434963939	18243	28	18G
0005433261571	18243	29	19E
0005434964018	18243	30	20A
0005434964017	18243	31	20G
0005434964065	18243	32	21B
0005434964026	18243	33	21E
0005434964037	18243	34	21F
0005434964066	18243	35	21G
0005433261569	18243	36	22A
0005434964069	18243	37	22H
0005433261567	18243	38	23F
0005433261570	18243	39	23E
0005434964014	18243	40	23G
0005434964041	18243	41	24E
0005434964036	18243	42	24H
0005434964108	18243	43	25D
0005434964121	18243	44	25E
0005433261566	18243	45	25F
0005433261557	18243	46	27D
0005434964107	18243	47	27E
0005434964099	18243	48	28A
0005434964084	18243	49	28E
0005434964038	18243	50	28D
0005434964046	18243	51	29A
0005434964033	18243	52	29F
0005434964043	18243	53	29E
0005434964044	18243	54	29G
0005434963980	18243	55	30H
0005434964027	18243	56	31E
0005433261560	18243	57	32B
0005434964091	18243	58	33F
0005434964032	18243	59	34E
0005433261565	18243	60	34H
0005434963995	18243	61	35D
0005433261558	18243	62	35E
0005434964052	18243	63	35G
0005433261572	18243	64	36B
0005434964112	18243	65	36G
0005434964013	18243	66	37A
0005433261568	18243	67	37B
0005434964015	18243	68	37G
0005434963997	18243	69	38D
0005434964106	18243	70	38B
0005434625964	4819	1	1F
0005434625961	4819	2	2D
0005435907471	4819	3	4D
0005433194842	4819	4	4E
0005435907447	4819	5	7D
0005434625959	4819	6	8A
0005434625966	4819	7	9A
0005433194841	4819	8	9C
0005435907474	4819	9	9D
0005434625963	4819	10	13D
0005434625960	4819	11	13F
0005435907462	4819	12	14C
0005435907446	4819	13	16C
0005434625967	4819	14	16E
0005435907477	4819	15	17F
0005433194832	4819	16	18C
0005434625958	4819	17	19E
0005434625962	4819	18	20A
0005434625965	4819	19	20C
0005434625948	32886	1	3A
0005435907507	32886	2	4E
0005434625866	32886	3	5F
0005433194859	32886	4	8D
0005434625884	32886	5	8F
0005433194858	32886	6	9A
0005434625880	32886	7	9D
0005434625892	32886	8	9F
0005435907511	32886	9	10A
0005434625914	32886	10	11C
0005434625947	32886	11	12E
0005434625867	32886	12	12F
0005433194860	32886	13	13D
0005435907510	32886	14	14A
0005435907506	32886	15	14E
0005434625903	32886	16	15D
0005434625925	32886	17	16C
0005434625913	32886	18	16E
0005435907508	32886	19	18A
0005434625902	32886	20	19A
0005434625929	32886	21	19C
0005435907509	32886	22	19E
0005434625881	32886	23	20C
0005435785138	13769	1	1A
0005435784995	13769	2	1B
0005435785015	13769	3	1C
0005435785153	13769	4	1D
0005435784989	13769	5	2A
0005435785078	13769	6	2B
0005435785048	13769	7	2C
0005435784838	13769	8	2D
0005435785058	13769	9	3A
0005435785096	13769	10	3B
0005435787331	13769	11	3C
0005435784919	13769	12	3D
0005435785039	13769	13	4A
0005435785131	13769	14	4B
0005432195694	13769	15	4C
0005435787332	13769	16	4D
0005435785041	13769	17	5C
0005435787330	13769	18	5D
0005435785023	13769	19	6A
0005435785143	13769	20	6B
0005435784920	13769	21	6C
0005435787333	13769	22	6D
0005435785137	13769	23	7B
0005432195692	13769	24	7C
0005435937389	13769	25	18A
0005435784859	13769	26	18B
0005435785086	13769	27	18C
0005435785095	13769	28	18D
0005435785013	13769	29	19A
0005435784990	13769	30	19B
0005435785144	13769	31	19C
0005432195695	13769	32	20A
0005435784961	13769	33	20B
0005435785040	13769	34	20D
0005435785042	13769	35	20C
0005435785132	13769	36	21A
0005432195693	13769	37	21B
0005435784878	13769	38	21C
0005435784879	13769	39	21D
0005435784996	13769	40	22B
0005435784931	13769	41	22C
0005435785022	13769	42	22D
0005435784791	13769	43	23B
0005435785310	27452	1	1A
0005435785321	27452	2	1B
0005435785316	27452	3	1C
0005435785325	27452	4	1D
0005435785302	27452	5	2A
0005432190625	27452	6	2B
0005435785330	27452	7	2C
0005435937321	27452	8	2D
0005435785328	27452	9	3A
0005435787353	27452	10	3B
0005435785303	27452	11	3C
0005435787350	27452	12	3D
0005435785318	27452	13	4A
0005435785317	27452	14	4B
0005435785327	27452	15	4C
0005432190626	27452	16	4D
0005435785311	27452	17	5A
0005435785294	27452	18	5B
0005435785309	27452	19	5C
0005435785319	27452	20	5D
0005435785314	27452	21	6A
0005435785300	27452	22	6B
0005435785305	27452	23	6C
0005435785299	27452	24	6D
0005435785306	27452	25	7A
0005435785312	27452	26	7B
0005435785320	27452	27	7D
0005435785308	27452	28	18A
0005435785301	27452	29	18B
0005435785326	27452	30	18C
0005435785298	27452	31	18D
0005435937320	27452	32	19A
0005435937327	27452	33	19B
0005435785307	27452	34	19C
0005432190624	27452	35	19D
0005435785304	27452	36	20A
0005435785313	27452	37	20B
0005435785295	27452	38	20C
0005435785329	27452	39	20D
0005432190627	27452	40	21A
0005435785322	27452	41	21C
0005435787351	27452	42	21D
0005435785315	27452	43	22A
0005435785296	27452	44	22B
0005435785323	27452	45	22C
0005435785297	27452	46	22D
0005435787352	27452	47	23A
0005435785324	27452	48	23B
0005434407295	20273	1	1A
0005434407273	20273	2	1D
0005435311063	20273	3	1F
0005435311076	20273	4	2A
0005432058385	20273	5	2C
0005434407228	20273	6	2D
0005434407313	20273	7	2F
0005434407050	20273	8	3C
0005434406899	20273	9	3D
0005434407232	20273	10	3F
0005434407116	20273	11	4A
0005434407227	20273	12	4C
0005434407266	20273	13	4E
0005435311075	20273	14	5A
0005434407016	20273	15	5C
0005434406874	20273	16	5D
0005434407176	20273	17	5E
0005434407255	20273	18	5F
0005434407069	20273	19	6C
0005434407041	20273	20	6D
0005434407235	20273	21	6F
0005435311072	20273	22	7A
0005435311073	20273	23	7C
0005434407314	20273	24	7D
0005434407322	20273	25	7E
0005434407268	20273	26	7F
0005434407371	20273	27	8C
0005434407267	20273	28	8D
0005434406915	20273	29	8E
0005434407413	20273	30	8F
0005434407291	20273	31	9C
0005435311074	20273	32	9E
0005434407245	20273	33	9F
0005434406968	20273	34	10A
0005432058383	20273	35	10C
0005434407073	20273	36	10D
0005434407566	20273	37	10E
0005434407196	20273	38	11A
0005435311064	20273	39	11C
0005435311067	20273	40	11D
0005435311071	20273	41	11F
0005432058384	20273	42	12A
0005434407328	20273	43	12C
0005434407015	20273	44	12D
0005434407294	20273	45	12E
0005434407234	20273	46	12F
0005435311070	20273	47	13C
0005434407020	20273	48	13D
0005432058382	20273	49	13E
0005435311065	20273	50	13F
0005434407340	20273	51	14A
0005434407321	20273	52	14C
0005434407379	20273	53	14D
0005432058381	20273	54	14E
0005434407292	20273	55	14F
0005434407147	20273	56	15A
0005435311077	20273	57	15C
0005434407068	20273	58	15D
0005434407353	20273	59	15E
0005434407178	20273	60	15F
0005434406914	20273	61	16A
0005434407070	20273	62	16C
0005434407208	20273	63	16D
0005434407085	20273	64	16E
0005434407378	20273	65	17A
0005434406906	20273	66	17D
0005434407072	20273	67	17E
0005434407192	20273	68	17F
0005435311068	20273	69	18A
0005434407130	20273	70	18C
0005434407131	20273	71	18D
0005435311069	20273	72	18E
0005434407236	20273	73	18F
0005434407311	20273	74	19D
0005434407203	20273	75	19E
0005434406907	20273	76	19F
0005434407418	20273	77	20A
0005434407256	20273	78	20C
0005434407187	20273	79	20D
0005435311066	20273	80	20E
0005434407213	20273	81	20F
0005435310941	27000	1	1A
0005434407759	27000	2	1C
0005434407789	27000	3	1D
0005434407768	27000	4	1F
0005434407782	27000	5	2A
0005434407786	27000	6	2C
0005434407749	27000	7	3A
0005434407766	27000	8	3D
0005434407793	27000	9	3F
0005435310950	27000	10	4A
0005432153935	27000	11	4D
0005435310946	27000	12	4E
0005434407787	27000	13	4F
0005434407779	27000	14	5A
0005434407742	27000	15	5C
0005434407763	27000	16	5D
0005435310932	27000	17	5E
0005434407774	27000	18	5F
0005434407790	27000	19	6A
0005434407741	27000	20	6C
0005434407740	27000	21	6D
0005435310957	27000	22	6E
0005432153942	27000	23	6F
0005434407777	27000	24	7A
0005434407757	27000	25	7C
0005434407755	27000	26	7D
0005434407792	27000	27	7E
0005434407746	27000	28	7F
0005434407748	27000	29	8A
0005434407769	27000	30	8C
0005434407788	27000	31	8D
0005432153937	27000	32	8E
0005434407736	27000	33	9A
0005434407760	27000	34	9C
0005434407773	27000	35	9F
0005435310947	27000	36	10A
0005434407758	27000	37	10C
0005434407796	27000	38	10D
0005434407771	27000	39	10F
0005434407762	27000	40	11A
0005434407781	27000	41	11C
0005432153941	27000	42	11D
0005432153939	27000	43	11E
0005434407738	27000	44	12A
0005434407747	27000	45	12C
0005434407791	27000	46	12D
0005434407780	27000	47	12E
0005434407764	27000	48	12F
0005434407783	27000	49	13A
0005434407775	27000	50	13C
0005434407770	27000	51	13D
0005434407784	27000	52	13E
0005432153940	27000	53	13F
0005434407752	27000	54	14A
0005435310934	27000	55	14C
0005432153936	27000	56	14D
0005434407744	27000	57	14E
0005434407743	27000	58	14F
0005434407765	27000	59	15A
0005434407756	27000	60	15C
0005434407776	27000	61	15D
0005435310905	27000	62	15E
0005434407785	27000	63	16A
0005434407795	27000	64	16C
0005434407753	27000	65	16D
0005434407750	27000	66	16E
0005434407778	27000	67	16F
0005434407767	27000	68	17A
0005435310933	27000	69	17C
0005434407799	27000	70	17E
0005434407794	27000	71	18A
0005434407751	27000	72	18C
0005432153938	27000	73	18D
0005434407739	27000	74	18F
0005434407754	27000	75	19A
0005435310922	27000	76	19C
0005435310936	27000	77	19E
0005434407798	27000	78	19F
0005434407745	27000	79	20A
0005434407797	27000	80	20C
0005434407737	27000	81	20D
0005434407772	27000	82	20E
0005434407761	27000	83	20F
0005434311219	5705	1	1A
0005433123800	5705	2	2C
0005434319402	5705	3	2D
0005433123710	5705	4	2F
0005433123771	5705	5	3A
0005434319403	5705	6	3D
0005433123699	5705	7	4D
0005433123757	5705	8	6C
0005434319394	5705	9	6D
0005433123747	5705	10	6F
0005433123783	5705	11	7F
0005434311220	5705	12	8C
0005433123765	5705	13	8D
0005433123718	5705	14	9D
0005433123749	5705	15	10C
0005434319397	5705	16	10E
0005433123741	5705	17	11E
0005434319399	5705	18	12A
0005433123775	5705	19	12E
0005432109703	5705	20	12F
0005433123703	5705	21	13A
0005434311218	5705	22	13C
0005433123796	5705	23	13D
0005434319400	5705	24	13E
0005433123723	5705	25	13F
0005433123704	5705	26	14D
0005433123758	5705	27	15D
0005434319401	5705	28	16E
0005434319395	5705	29	17A
0005433123784	5705	30	17C
0005433123748	5705	31	18C
0005433123734	5705	32	18D
0005433123793	5705	33	18F
0005432109702	5705	34	19A
0005433123715	5705	35	19C
0005432109704	5705	36	20C
0005434319396	5705	37	20D
0005434319404	5705	38	20E
0005434319398	5705	39	20F
0005434319274	15661	1	1D
0005433123938	15661	2	1F
0005433123939	15661	3	2A
0005433123949	15661	4	2C
0005434319273	15661	5	2D
0005433123936	15661	6	3C
0005433123953	15661	7	4C
0005433123950	15661	8	4D
0005433123935	15661	9	4E
0005434312299	15661	10	5D
0005433123933	15661	11	5F
0005434319252	15661	12	6C
0005433123932	15661	13	7A
0005433123951	15661	14	7C
0005433123934	15661	15	8A
0005433123946	15661	16	9C
0005433123937	15661	17	10C
0005434319242	15661	18	10F
0005433123952	15661	19	11D
0005434319246	15661	20	12A
0005433123941	15661	21	12C
0005433123947	15661	22	12D
0005434319245	15661	23	12F
0005433123948	15661	24	16C
0005433123942	15661	25	16D
0005434319209	15661	26	16F
0005433123945	15661	27	17D
0005433123931	15661	28	17F
0005433123944	15661	29	18A
0005433123943	15661	30	18E
0005434319283	15661	31	19E
0005433123940	15661	32	20D
0005435220304	24989	1	1A
0005435217680	24989	2	3B
0005435217688	24989	3	4A
0005435217686	24989	4	4C
0005435217681	24989	5	5A
0005435217692	24989	6	5D
0005435217691	24989	7	18A
0005435217694	24989	8	20A
0005435220292	24989	9	20C
0005435217687	24989	10	21A
0005435217679	24989	11	22B
0005435217693	24989	12	23A
0005434484348	8987	1	1D
0005434484351	8987	2	3D
0005434484346	8987	3	5B
0005434189122	8987	4	6C
0005434189130	8987	5	7B
0005434189143	8987	6	18B
0005434189129	8987	7	19B
0005434484349	8987	8	19C
0005434484347	8987	9	20D
0005434484350	8987	10	22C
0005434484273	16634	1	2A
0005434189179	16634	2	2D
0005434484281	16634	3	3B
0005434484286	16634	4	3D
0005434484307	16634	5	4A
0005434484267	16634	6	4B
0005434189178	16634	7	6A
0005434484287	16634	8	7B
0005434484280	16634	9	7C
0005434484272	16634	10	18C
0005434189180	16634	11	20A
0005434189181	16634	12	20D
0005434484297	16634	13	21A
0005433123952	7631	1	1C
0005433123940	7631	2	2A
0005433722150	7631	3	2D
0005433123936	7631	4	3D
0005433123944	7631	5	4A
0005433123953	7631	6	4C
0005433123937	7631	7	4E
0005433722123	7631	8	6F
0005433123943	7631	9	7A
0005433123939	7631	10	7D
0005433123935	7631	11	7F
0005433123931	7631	12	8C
0005433722149	7631	13	8D
0005433123933	7631	14	9C
0005433123949	7631	15	9D
0005433123932	7631	16	9F
0005433123941	7631	17	10E
0005433722153	7631	18	11A
0005433123948	7631	19	13D
0005433123946	7631	20	13F
0005433722137	7631	21	14A
0005433123947	7631	22	15C
0005433123938	7631	23	15F
0005433123934	7631	24	16A
0005433722152	7631	25	17E
0005433123945	7631	26	17F
0005433722136	7631	27	18E
0005433123942	7631	28	20C
0005433123950	7631	29	20E
0005433123951	7631	30	20F
0005433449974	7632	1	1A
0005433449966	7632	2	1C
0005433449983	7632	3	1D
0005432693066	7632	4	1F
0005432693064	7632	5	2C
0005432720898	7632	6	2D
0005432693067	7632	7	2F
0005432720921	7632	8	3A
0005432693093	7632	9	3C
0005432720918	7632	10	3D
0005432720916	7632	11	3F
0005432693068	7632	12	4A
0005432720912	7632	13	4D
0005433449970	7632	14	4E
0005432720895	7632	15	4F
0005432720914	7632	16	5A
0005432720901	7632	17	5C
0005432693076	7632	18	5D
0005433449980	7632	19	5E
0005432720906	7632	20	5F
0005432693071	7632	21	6A
0005432693082	7632	22	6C
0005432720897	7632	23	6E
0005432720899	7632	24	6F
0005432693088	7632	25	7A
0005432693069	7632	26	7C
0005432693084	7632	27	7D
0005433449972	7632	28	7E
0005432720903	7632	29	7F
0005432720908	7632	30	8A
0005432693083	7632	31	8C
0005432720915	7632	32	8D
0005432071573	7632	33	8F
0005433449968	7632	34	9A
0005433449984	7632	35	9C
0005432720920	7632	36	9D
0005433449969	7632	37	9E
0005432720904	7632	38	9F
0005432693078	7632	39	10A
0005433449979	7632	40	10C
0005433449981	7632	41	10D
0005432693080	7632	42	10E
0005432693095	7632	43	10F
0005432693065	7632	44	11A
0005432720900	7632	45	11C
0005432720905	7632	46	11D
0005432720913	7632	47	11E
0005432720919	7632	48	11F
0005432720910	7632	49	12A
0005432720902	7632	50	12C
0005432693087	7632	51	12D
0005432720907	7632	52	13A
0005432720909	7632	53	13C
0005432693094	7632	54	13D
0005432693072	7632	55	13E
0005432071572	7632	56	13F
0005433449976	7632	57	14C
0005433449977	7632	58	14E
0005433449982	7632	59	14D
0005432693086	7632	60	14F
0005432720911	7632	61	15A
0005433449971	7632	62	15C
0005432693077	7632	63	15D
0005432693075	7632	64	15E
0005432693081	7632	65	15F
0005432071574	7632	66	16C
0005433449962	7632	67	16D
0005432720917	7632	68	16E
0005433449965	7632	69	16F
0005432693089	7632	70	17D
0005433449973	7632	71	17E
0005432720896	7632	72	17F
0005432693091	7632	73	18A
0005433449975	7632	74	18C
0005433449964	7632	75	18D
0005433449967	7632	76	18E
0005432693079	7632	77	18F
0005432693074	7632	78	19A
0005432693092	7632	79	19C
0005432693085	7632	80	19D
0005433449978	7632	81	19E
0005433449963	7632	82	19F
0005432693090	7632	83	20D
0005432693073	7632	84	20E
0005432693070	7632	85	20F
0005432692669	30308	1	1C
0005432692656	30308	2	1D
0005433449695	30308	3	1F
0005433449718	30308	4	2D
0005433449720	30308	5	3A
0005433449761	30308	6	3D
0005432692692	30308	7	4A
0005432692876	30308	8	4D
0005433449778	30308	9	5C
0005432692875	30308	10	5E
0005432692717	30308	11	5F
0005433449771	30308	12	6A
0005432692920	30308	13	6C
0005432692795	30308	14	6D
0005433449818	30308	15	7D
0005432692780	30308	16	7E
0005433449858	30308	17	8C
0005432692763	30308	18	8D
0005432692833	30308	19	9E
0005433449815	30308	20	10A
0005433449846	30308	21	10C
0005433449808	30308	22	10F
0005432692811	30308	23	11A
0005433449869	30308	24	11C
0005432692905	30308	25	11D
0005433449813	30308	26	12C
0005432692835	30308	27	12D
0005432692858	30308	28	12F
0005432692816	30308	29	13C
0005432692872	30308	30	13E
0005432692815	30308	31	14A
0005433449807	30308	32	14F
0005432692642	30308	33	15A
0005432692742	30308	34	15C
0005433449776	30308	35	15D
0005432692807	30308	36	15F
0005432692748	30308	37	16A
0005432692834	30308	38	16D
0005432692702	30308	39	17A
0005433449740	30308	40	17D
0005432692824	30308	41	17E
0005433449814	30308	42	18A
0005433449719	30308	43	18C
0005433449779	30308	44	18F
0005433449817	30308	45	19A
0005433449886	30308	46	20C
0005432692691	30308	47	20D
0005432692749	30308	48	20F
0005433123710	30307	1	1A
0005433123784	30307	2	1F
0005433123734	30307	3	2C
0005433123748	30307	4	2D
0005432720548	30307	5	2F
0005433123703	30307	6	3C
0005432720627	30307	7	3F
0005432720805	30307	8	4A
0005433123747	30307	9	4C
0005432720731	30307	10	4F
0005432720653	30307	11	5A
0005433722227	30307	12	6A
0005433123704	30307	13	6C
0005433123775	30307	14	6F
0005432720584	30307	15	7C
0005432720583	30307	16	7D
0005432720581	30307	17	7E
0005433123796	30307	18	8A
0005433123718	30307	19	8D
0005433123723	30307	20	8E
0005432720580	30307	21	9A
0005432720602	30307	22	9C
0005433123741	30307	23	9E
0005433123757	30307	24	10A
0005432720651	30307	25	10D
0005433722226	30307	26	11A
0005433123749	30307	27	12C
0005432720783	30307	28	12D
0005433123715	30307	29	12E
0005433123800	30307	30	12F
0005433123699	30307	31	13F
0005433123771	30307	32	14A
0005432720730	30307	33	15A
0005432720626	30307	34	15C
0005432720628	30307	35	15D
0005433722225	30307	36	15E
0005433722229	30307	37	16A
0005433123765	30307	38	16F
0005433722228	30307	39	17A
0005432720776	30307	40	17E
0005432720678	30307	41	17F
0005433123758	30307	42	18A
0005432720681	30307	43	18C
0005433123793	30307	44	18E
0005432720794	30307	45	19F
0005432720797	30307	46	20E
0005432720796	30307	47	20D
0005433123783	30307	48	20F
0005432271005	1375	1	1C
0005433192978	1375	2	1D
0005433525035	1375	3	1F
0005432927946	1375	4	2A
0005433525036	1375	5	2C
0005433192919	1375	6	2D
0005432968825	1375	7	2F
0005434586610	1375	8	3A
0005433724811	1375	9	3C
0005433724809	1375	10	3D
0005434586616	1375	11	4A
0005434586607	1375	12	4C
0005433192970	1375	13	4D
0005434586629	1375	14	4E
0005434586612	1375	15	4F
0005434586613	1375	16	5D
0005433525041	1375	17	5E
0005434586624	1375	18	5F
0005433724806	1375	19	6D
0005434586623	1375	20	6E
0005434586608	1375	21	7A
0005433192956	1375	22	7C
0005432271003	1375	23	7D
0005433192927	1375	24	7E
0005434513579	1375	25	7F
0005432927934	1375	26	8A
0005434586611	1375	27	8C
0005433192966	1375	28	8D
0005432927940	1375	29	8F
0005432927927	1375	30	9A
0005433192917	1375	31	9C
0005434586619	1375	32	9E
0005433525040	1375	33	9D
0005433525045	1375	34	9F
0005434513581	1375	35	10C
0005433525039	1375	36	10D
0005434586626	1375	37	10E
0005433525044	1375	38	11A
0005434586618	1375	39	11D
0005432927949	1375	40	11F
0005433724810	1375	41	12A
0005432927928	1375	42	12C
0005434586620	1375	43	12E
0005434514968	1375	44	12F
0005433724807	1375	45	13A
0005434586628	1375	46	13C
0005434586621	1375	47	13D
0005434586625	1375	48	13E
0005434586606	1375	49	14C
0005434586617	1375	50	14D
0005433192999	1375	51	14F
0005432927933	1375	52	15C
0005433724808	1375	53	15D
0005434586627	1375	54	15E
0005434586614	1375	55	16A
0005432927947	1375	56	16C
0005433192918	1375	57	16D
0005433525037	1375	58	16E
0005432927948	1375	59	16F
0005433192957	1375	60	17A
0005434586609	1375	61	17C
0005434586622	1375	62	17E
0005433525043	1375	63	18A
0005432271004	1375	64	18C
0005434586605	1375	65	18D
0005433525038	1375	66	18E
0005434586615	1375	67	18F
0005433525042	1375	68	19D
0005432927903	1375	69	19E
0005434513580	1375	70	20E
0005434586435	18543	1	1A
0005433524950	18543	2	1C
0005434586281	18543	3	1D
0005434514947	18543	4	1F
0005434586430	18543	5	2A
0005433193045	18543	6	2C
0005433193052	18543	7	2D
0005432927978	18543	8	2F
0005433193053	18543	9	3A
0005434586396	18543	10	3D
0005432927980	18543	11	3F
0005434586463	18543	12	4A
0005434586407	18543	13	4C
0005434586376	18543	14	4E
0005433524900	18543	15	5A
0005434586450	18543	16	5D
0005433193042	18543	17	5E
0005434586446	18543	18	5F
0005434586390	18543	19	6C
0005434586493	18543	20	6D
0005434586383	18543	21	6E
0005434586440	18543	22	6F
0005433193054	18543	23	7C
0005433193056	18543	24	8A
0005434586503	18543	25	8C
0005433524927	18543	26	8D
0005433724760	18543	27	8E
0005434586415	18543	28	8F
0005433524970	18543	29	9C
0005433193048	18543	30	9E
0005432927979	18543	31	10A
0005432968840	18543	32	10E
0005433524957	18543	33	10F
0005434586401	18543	34	11A
0005433193051	18543	35	11C
0005434586403	18543	36	11D
0005433193049	18543	37	11E
0005433193055	18543	38	12A
0005433524928	18543	39	13A
0005434586402	18543	40	13C
0005433524944	18543	41	13D
0005434586280	18543	42	14A
0005432927977	18543	43	14D
0005433524980	18543	44	14E
0005434586495	18543	45	15E
0005434514936	18543	46	15F
0005432968839	18543	47	16A
0005434586335	18543	48	16D
0005433724759	18543	49	16C
0005434586434	18543	50	16E
0005433193046	18543	51	16F
0005433524912	18543	52	17A
0005433724786	18543	53	17C
0005433193050	18543	54	17E
0005433524955	18543	55	17F
0005433193047	18543	56	18C
0005433524951	18543	57	18D
0005433193044	18543	58	18E
0005432927982	18543	59	18F
0005433193043	18543	60	19A
0005432927981	18543	61	19C
0005434586504	18543	62	19D
0005434586494	18543	63	20C
0005434586445	18543	64	20D
0005432968841	18543	65	20E
0005434142609	11437	1	1A
0005434344186	11437	2	1B
0005434344177	11437	3	1C
0005434344188	11437	4	1D
0005435302150	11437	5	2B
0005434344205	11437	6	2C
0005435302142	11437	7	2D
0005434344191	11437	8	3A
0005434344181	11437	9	3B
0005434344199	11437	10	3C
0005434344187	11437	11	3D
0005434344195	11437	12	4A
0005434344198	11437	13	4B
0005434344192	11437	14	4C
0005434344189	11437	15	4D
0005435302151	11437	16	5A
0005434344178	11437	17	5B
0005434344204	11437	18	5C
0005435302145	11437	19	6A
0005434344210	11437	20	6B
0005434344182	11437	21	6C
0005434344180	11437	22	6D
0005434344190	11437	23	7A
0005434344201	11437	24	7B
0005434344194	11437	25	7C
0005434344203	11437	26	7D
0005434142610	11437	27	18A
0005434344197	11437	28	18B
0005434142612	11437	29	18C
0005434344206	11437	30	18D
0005434344179	11437	31	19A
0005435302154	11437	32	19B
0005434344196	11437	33	19C
0005434142611	11437	34	19D
0005434344209	11437	35	20A
0005434344184	11437	36	20B
0005434344202	11437	37	20C
0005434344185	11437	38	20D
0005434344175	11437	39	21A
0005434344200	11437	40	21B
0005434344176	11437	41	21C
0005434344174	11437	42	21D
0005435302143	11437	43	22A
0005435302153	11437	44	22B
0005434344183	11437	45	22C
0005434344193	11437	46	22D
0005434344208	11437	47	23A
0005434344207	11437	48	23B
0005434343986	29797	1	1A
0005434343742	29797	2	1B
0005434343915	29797	3	1C
0005434343730	29797	4	1D
0005434343933	29797	5	2A
0005434344041	29797	6	2B
0005434142582	29797	7	2C
0005435304158	29797	8	3A
0005435304163	29797	9	3B
0005434343914	29797	10	3C
0005434343851	29797	11	3D
0005434343784	29797	12	4A
0005434343820	29797	13	4B
0005434343985	29797	14	4C
0005434142579	29797	15	4D
0005434344005	29797	16	5A
0005435304159	29797	17	5B
0005434343843	29797	18	5C
0005434344023	29797	19	5D
0005434343717	29797	20	6A
0005434343819	29797	21	6B
0005434343767	29797	22	6D
0005434343865	29797	23	7A
0005434343916	29797	24	7B
0005434344004	29797	25	7C
0005434343979	29797	26	7D
0005435304162	29797	27	18A
0005434343970	29797	28	18B
0005434343912	29797	29	18C
0005434343844	29797	30	18D
0005434343975	29797	31	19A
0005434343776	29797	32	19B
0005434343824	29797	33	19C
0005435304161	29797	34	19D
0005434343801	29797	35	20A
0005434343799	29797	36	20B
0005434343966	29797	37	20C
0005434343766	29797	38	20D
0005434343882	29797	39	21A
0005434142571	29797	40	21B
0005434142556	29797	41	21C
0005434343913	29797	42	21D
0005434343881	29797	43	22A
0005435304160	29797	44	22B
0005434343987	29797	45	22C
0005434343852	29797	46	22D
0005434343782	29797	47	23A
0005434343785	29797	48	23B
0005433415478	1277	1	2A
0005435824629	1277	2	2F
0005433415513	1277	3	3C
0005433415566	1277	4	3F
0005435824643	1277	5	4C
0005433415578	1277	6	4F
0005435824627	1277	7	5F
0005435824623	1277	8	6B
0005435824635	1277	9	6F
0005435824637	1277	10	7C
0005433415524	1277	11	7D
0005435824642	1277	12	8A
0005435824631	1277	13	8B
0005435824645	1277	14	8D
0005435824630	1277	15	9C
0005435824636	1277	16	9F
0005432284558	1277	17	10B
0005435824621	1277	18	11B
0005433415490	1277	19	11E
0005435824626	1277	20	12A
0005435824640	1277	21	12D
0005435824639	1277	22	12C
0005432284559	1277	23	13B
0005433415514	1277	24	13E
0005435824634	1277	25	13D
0005435824625	1277	26	14B
0005435824628	1277	27	15D
0005435824632	1277	28	15C
0005435824622	1277	29	18C
0005435824620	1277	30	18B
0005435824633	1277	31	19A
0005435824638	1277	32	19E
0005435824641	1277	33	19D
0005432284557	1277	34	19F
0005433415565	1277	35	20B
0005435824644	1277	36	20E
0005433415504	1277	37	21D
0005435824624	1277	38	21E
0005433415533	1277	39	21F
0005433415663	18026	1	1C
0005433415672	18026	2	1F
0005435824401	18026	3	1D
0005435824449	18026	4	3A
0005433415667	18026	5	2F
0005435824383	18026	6	3D
0005435824427	18026	7	4C
0005433415665	18026	8	5A
0005433415664	18026	9	5F
0005433415658	18026	10	5D
0005435824413	18026	11	7A
0005435824406	18026	12	7C
0005435824480	18026	13	7F
0005435824446	18026	14	8B
0005435824389	18026	15	8E
0005435824388	18026	16	9A
0005435824481	18026	17	9D
0005435824444	18026	18	9E
0005435824234	18026	19	11A
0005433415656	18026	20	12A
0005435824479	18026	21	12F
0005435824304	18026	22	12E
0005433415660	18026	23	13A
0005433415657	18026	24	13E
0005433415659	18026	25	13F
0005433415669	18026	26	14D
0005435824441	18026	27	14C
0005435824387	18026	28	14E
0005435824445	18026	29	16A
0005435824495	18026	30	15F
0005435824442	18026	31	16B
0005435824305	18026	32	16E
0005433415661	18026	33	17C
0005433415668	18026	34	18B
0005435824400	18026	35	19E
0005433415666	18026	36	19C
0005435824494	18026	37	20A
0005433415662	18026	38	20E
0005435824440	18026	39	21A
0005433415671	18026	40	20F
0005433415670	18026	41	21C
0005435824439	18026	42	21F
0005434462767	17531	1	1A
0005434462771	17531	2	1C
0005434462772	17531	3	4A
0005434462762	17531	4	4C
0005434460472	17531	5	5A
0005434460485	17531	6	5B
0005434460470	17531	7	6D
0005434462775	17531	8	7B
0005434460486	17531	9	7C
0005434462766	17531	10	7D
0005434460469	17531	11	18D
0005434462769	17531	12	20A
0005434462763	17531	13	22A
0005434460477	17531	14	22B
0005434462770	17531	15	23A
0005432783815	5624	1	1A
0005432783786	5624	2	1C
0005432783797	5624	3	1D
0005432143989	5624	4	1F
0005432143987	5624	5	2A
0005435242545	5624	6	2C
0005432783802	5624	7	2D
0005432783817	5624	8	2F
0005432783800	5624	9	3A
0005432783778	5624	10	3C
0005435242666	5624	11	3D
0005435242559	5624	12	3F
0005435242594	5624	13	4A
0005435242633	5624	14	4C
0005432783804	5624	15	4D
0005435242505	5624	16	4E
0005432783822	5624	17	4F
0005432783805	5624	18	5A
0005435242626	5624	19	5C
0005432783820	5624	20	5E
0005432783812	5624	21	5F
0005432783818	5624	22	6A
0005435242620	5624	23	6C
0005432783823	5624	24	6D
0005432783791	5624	25	6E
0005435242599	5624	26	6F
0005432783807	5624	27	7A
0005435242649	5624	28	7C
0005435242653	5624	29	7D
0005435242623	5624	30	7E
0005432783813	5624	31	7F
0005432783806	5624	32	8A
0005435242580	5624	33	8C
0005432783787	5624	34	8D
0005432783829	5624	35	8E
0005432783782	5624	36	8F
0005435242595	5624	37	9A
0005435242534	5624	38	9C
0005435242679	5624	39	9D
0005432783783	5624	40	9E
0005435242698	5624	41	9F
0005435242598	5624	42	10A
0005432783814	5624	43	10C
0005435242697	5624	44	10D
0005432783793	5624	45	10E
0005435242573	5624	46	10F
0005432783808	5624	47	11A
0005435242727	5624	48	11C
0005435242508	5624	49	11D
0005432783828	5624	50	11E
0005435242600	5624	51	11F
0005435242672	5624	52	12A
0005435242628	5624	53	12C
0005432783798	5624	54	12D
0005432783789	5624	55	12E
0005435242509	5624	56	12F
0005435242577	5624	57	13A
0005435242654	5624	58	13C
0005435242634	5624	59	13D
0005435242648	5624	60	13E
0005432783796	5624	61	14A
0005432783819	5624	62	14D
0005432783790	5624	63	14E
0005432783780	5624	64	14F
0005435242581	5624	65	15A
0005432783810	5624	66	15C
0005432783821	5624	67	15D
0005432783824	5624	68	15E
0005432783776	5624	69	15F
0005432783825	5624	70	16A
0005432143986	5624	71	16C
0005435242533	5624	72	16D
0005432143988	5624	73	16E
0005432783781	5624	74	16F
0005432783801	5624	75	17A
0005432783779	5624	76	17C
0005432783799	5624	77	17D
0005432783795	5624	78	17E
0005432783803	5624	79	17F
0005432783794	5624	80	18A
0005432783788	5624	81	18C
0005435242546	5624	82	18D
0005435242606	5624	83	18E
0005435242591	5624	84	18F
0005432783826	5624	85	19A
0005432783792	5624	86	19C
0005435242678	5624	87	19D
0005432783785	5624	88	19E
0005432783777	5624	89	19F
0005432783784	5624	90	20A
0005432783809	5624	91	20C
0005432783827	5624	92	20D
0005432783816	5624	93	20E
0005432783811	5624	94	20F
0005432783288	15365	1	1D
0005432783166	15365	2	1F
0005432783175	15365	3	2A
0005432783400	15365	4	2C
0005435242836	15365	5	2D
0005432783469	15365	6	3A
0005432783168	15365	7	3C
0005432783426	15365	8	4C
0005435242850	15365	9	4D
0005432783506	15365	10	4E
0005435476753	15365	11	4F
0005435242838	15365	12	5A
0005435242833	15365	13	5C
0005432783202	15365	14	5D
0005432783424	15365	15	5E
0005432783225	15365	16	5F
0005435242841	15365	17	6A
0005432783213	15365	18	6D
0005432783299	15365	19	6E
0005435476750	15365	20	6F
0005435242840	15365	21	7A
0005435242849	15365	22	7C
0005435242851	15365	23	7D
0005435242839	15365	24	7E
0005432782989	15365	25	7F
0005432783313	15365	26	8A
0005435242831	15365	27	8C
0005432783479	15365	28	8D
0005435242848	15365	29	8F
0005435242826	15365	30	9A
0005432783298	15365	31	9C
0005435242845	15365	32	9D
0005435476751	15365	33	9E
0005432783176	15365	34	9F
0005432783427	15365	35	10A
0005432783345	15365	36	10D
0005435242842	15365	37	10F
0005435242827	15365	38	11A
0005432783441	15365	39	11D
0005435242837	15365	40	11E
0005435242835	15365	41	11F
0005435242829	15365	42	12A
0005435242843	15365	43	12C
0005435242844	15365	44	12D
0005432783167	15365	45	12E
0005432783566	15365	46	12F
0005432783060	15365	47	13E
0005432783384	15365	48	13F
0005435242846	15365	49	14A
0005432783254	15365	50	14D
0005435242832	15365	51	14E
0005435476752	15365	52	15A
0005432783499	15365	53	15C
0005432783470	15365	54	15D
0005435242830	15365	55	15E
0005432783456	15365	56	15F
0005432783440	15365	57	16A
0005432783567	15365	58	16C
0005435476749	15365	59	16D
0005432783500	15365	60	16E
0005435242828	15365	61	16F
0005432783565	15365	62	17A
0005432783326	15365	63	17C
0005435242834	15365	64	17D
0005432783017	15365	65	17E
0005432783423	15365	66	17F
0005432783156	15365	67	18D
0005432783344	15365	68	18C
0005432783348	15365	69	18E
0005432783385	15365	70	18F
0005435242847	15365	71	19C
0005432783173	15365	72	19D
0005432783212	15365	73	19F
0005435242825	15365	74	20A
0005432783386	15365	75	20F
0005432848313	4386	1	1B
0005434463930	4386	2	1C
0005435850864	4386	3	1D
0005435850861	4386	4	2A
0005435850848	4386	5	2C
0005432848321	4386	6	3B
0005432848312	4386	7	3C
0005435850847	4386	8	3D
0005432848308	4386	9	4B
0005432848317	4386	10	4C
0005432848310	4386	11	4D
0005432848319	4386	12	5A
0005435850855	4386	13	5B
0005432848311	4386	14	5C
0005435850850	4386	15	5D
0005434462791	4386	16	6A
0005432848314	4386	17	6B
0005435850890	4386	18	6C
0005432848309	4386	19	6D
0005435850842	4386	20	7A
0005432848320	4386	21	7B
0005435850846	4386	22	7C
0005435850856	4386	23	18A
0005432848318	4386	24	18C
0005434462790	4386	25	19D
0005435850845	4386	26	20C
0005432848316	4386	27	21A
0005435850851	4386	28	21B
0005434463929	4386	29	21C
0005432848315	4386	30	22B
0005434462792	4386	31	22C
0005435850910	28839	1	1B
0005434463905	28839	2	2A
0005434461629	28839	3	2D
0005434461625	28839	4	3B
0005432848129	28839	5	3C
0005434463902	28839	6	3D
0005435850917	28839	7	4A
0005434461626	28839	8	4B
0005434461630	28839	9	4D
0005432848235	28839	10	5A
0005432848234	28839	11	5B
0005435850915	28839	12	5C
0005435850912	28839	13	5D
0005432848183	28839	14	6B
0005435850907	28839	15	6D
0005432848162	28839	16	7B
0005435850913	28839	17	7D
0005432848163	28839	18	18A
0005432848176	28839	19	18B
0005432848193	28839	20	18C
0005434461627	28839	21	18D
0005435850909	28839	22	19B
0005435850916	28839	23	20D
0005432848168	28839	24	21B
0005434463901	28839	25	21D
0005435850911	28839	26	22A
0005432848192	28839	27	22B
0005435850914	28839	28	22C
0005435850908	28839	29	23B
0005433496982	6291	1	1A
0005433496981	6291	2	1C
0005434925806	6291	3	1D
0005433496964	6291	4	1F
0005434925809	6291	5	2A
0005434443706	6291	6	2C
0005434443718	6291	7	2D
0005434925829	6291	8	2F
0005434443717	6291	9	3A
0005434925822	6291	10	3C
0005434925813	6291	11	3D
0005434443714	6291	12	3F
0005433496966	6291	13	4A
0005434925816	6291	14	4C
0005433496971	6291	15	4D
0005434925821	6291	16	4E
0005433496974	6291	17	5A
0005433496973	6291	18	5C
0005434443707	6291	19	5D
0005434925831	6291	20	5E
0005433496984	6291	21	5F
0005433496979	6291	22	6A
0005434925808	6291	23	6C
0005434925810	6291	24	6D
0005433496980	6291	25	6E
0005433496965	6291	26	6F
0005434925826	6291	27	7C
0005434925820	6291	28	7D
0005433496993	6291	29	7E
0005434443708	6291	30	7F
0005434925802	6291	31	8A
0005434443705	6291	32	8C
0005434925823	6291	33	8D
0005434443712	6291	34	8F
0005433496967	6291	35	9A
0005433496992	6291	36	9C
0005433496968	6291	37	9D
0005433496991	6291	38	9E
0005433496977	6291	39	9F
0005433496985	6291	40	10C
0005433496969	6291	41	10D
0005434925830	6291	42	10E
0005433496988	6291	43	10F
0005434443720	6291	44	11A
0005434925817	6291	45	11C
0005434925828	6291	46	11D
0005434925801	6291	47	11E
0005434443711	6291	48	11F
0005432075230	6291	49	12A
0005432075229	6291	50	12C
0005434925814	6291	51	12D
0005434443716	6291	52	12F
0005433496970	6291	53	13A
0005434925819	6291	54	13C
0005434925827	6291	55	13D
0005433496989	6291	56	13E
0005434443713	6291	57	13F
0005433496990	6291	58	14A
0005433496972	6291	59	14C
0005434443715	6291	60	14D
0005433496962	6291	61	14E
0005434443719	6291	62	14F
0005434925804	6291	63	15C
0005432075232	6291	64	15D
0005434925815	6291	65	15E
0005433496976	6291	66	16A
0005433496975	6291	67	16C
0005434925818	6291	68	16D
0005434925811	6291	69	16E
0005434925800	6291	70	17A
0005433496983	6291	71	17C
0005433496987	6291	72	17D
0005434925805	6291	73	17F
0005434443710	6291	74	18A
0005434925812	6291	75	18D
0005433496963	6291	76	18E
0005434925824	6291	77	18F
0005433496986	6291	78	19A
0005434443709	6291	79	19C
0005434925807	6291	80	19D
0005433496978	6291	81	19E
0005434925803	6291	82	19F
0005434925825	6291	83	20A
0005432075231	6291	84	20C
0005434925495	20316	1	1A
0005433496789	20316	2	1D
0005434925440	20316	3	1F
0005434925498	20316	4	2A
0005434925554	20316	5	2C
0005433496678	20316	6	2D
0005433496850	20316	7	2F
0005434443565	20316	8	3C
0005434443525	20316	9	3A
0005434925314	20316	10	3D
0005433496798	20316	11	3F
0005434925542	20316	12	4C
0005433496794	20316	13	4D
0005434925497	20316	14	4E
0005433496774	20316	15	4F
0005434443543	20316	16	5A
0005434925488	20316	17	5C
0005434925437	20316	18	5D
0005434925556	20316	19	5E
0005433496727	20316	20	5F
0005434925454	20316	21	6A
0005433496806	20316	22	6C
0005434443566	20316	23	6D
0005434443545	20316	24	6E
0005434443546	20316	25	7A
0005433496755	20316	26	7D
0005434925486	20316	27	7F
0005434925543	20316	28	8A
0005434925432	20316	29	8C
0005434925438	20316	30	8D
0005434443623	20316	31	8F
0005434925516	20316	32	9A
0005434925525	20316	33	9C
0005434443547	20316	34	9D
0005433496679	20316	35	9F
0005433496660	20316	36	10A
0005433496803	20316	37	10C
0005434443558	20316	38	10D
0005433496761	20316	39	10F
0005433496744	20316	40	11A
0005433496848	20316	41	11C
0005434925555	20316	42	11D
0005433496760	20316	43	11E
0005434925514	20316	44	11F
0005434925327	20316	45	12A
0005434925517	20316	46	12C
0005434925407	20316	47	12E
0005434925560	20316	48	12F
0005433496799	20316	49	13A
0005434925405	20316	50	13C
0005433496762	20316	51	13D
0005433496712	20316	52	13E
0005433496743	20316	53	13F
0005434925557	20316	54	14A
0005433496669	20316	55	14C
0005434925374	20316	56	14E
0005433496763	20316	57	15A
0005434925406	20316	58	15C
0005434925494	20316	59	15D
0005434925328	20316	60	15F
0005434925410	20316	61	16A
0005434443582	20316	62	16C
0005434925536	20316	63	16E
0005433496646	20316	64	16F
0005434443585	20316	65	17A
0005434925513	20316	66	17C
0005433496804	20316	67	17D
0005434925487	20316	68	17E
0005434443539	20316	69	17F
0005434925515	20316	70	18A
0005434925548	20316	71	18C
0005433496768	20316	72	18E
0005434925559	20316	73	18F
0005434925564	20316	74	19A
0005434925558	20316	75	19D
0005434925537	20316	76	19F
0005434925520	20316	77	20D
0005433496742	20316	78	20E
0005434925527	20316	79	20F
0005432783330	12213	1	1A
0005435242879	12213	2	1C
0005432783464	12213	3	1D
0005432783327	12213	4	1F
0005432783255	12213	5	2D
0005432783277	12213	6	2F
0005432783438	12213	7	3A
0005432783228	12213	8	3C
0005432782934	12213	9	3F
0005432783130	12213	10	4A
0005435242862	12213	11	4E
0005432783329	12213	12	4F
0005435242871	12213	13	5C
0005432783468	12213	14	5D
0005432783640	12213	15	5E
0005432783222	12213	16	5F
0005432783311	12213	17	6A
0005435242873	12213	18	6C
0005435242863	12213	19	6D
0005432783315	12213	20	6F
0005435242875	12213	21	7C
0005435242878	12213	22	7F
0005432783224	12213	23	8C
0005432783244	12213	24	8D
0005435242854	12213	25	8F
0005435242858	12213	26	9A
0005432783351	12213	27	9C
0005432783459	12213	28	9D
0005435242864	12213	29	9E
0005435242872	12213	30	9F
0005435242867	12213	31	10A
0005435242856	12213	32	10C
0005432783555	12213	33	10D
0005435242868	12213	34	10E
0005435242877	12213	35	10F
0005432783290	12213	36	11A
0005432783339	12213	37	11C
0005432783221	12213	38	11D
0005432783474	12213	39	11E
0005435242855	12213	40	12D
0005432783285	12213	41	12E
0005432783338	12213	42	12F
0005432783226	12213	43	13C
0005432783331	12213	44	13E
0005435242860	12213	45	13F
0005435242866	12213	46	14A
0005432783284	12213	47	14C
0005432783347	12213	48	14D
0005432783190	12213	49	14E
0005435242869	12213	50	15C
0005432783312	12213	51	15D
0005432783289	12213	52	15E
0005435242857	12213	53	16A
0005435242874	12213	54	16C
0005432783276	12213	55	16D
0005435242853	12213	56	16E
0005432783592	12213	57	16F
0005432783473	12213	58	17A
0005432783507	12213	59	17C
0005435242865	12213	60	17E
0005432783223	12213	61	17F
0005432783073	12213	62	18A
0005432783207	12213	63	18C
0005435242861	12213	64	18D
0005432783439	12213	65	18E
0005435242870	12213	66	18F
0005435242876	12213	67	19A
0005432783352	12213	68	19D
0005435242852	12213	69	19E
0005432783328	12213	70	19F
0005432783463	12213	71	20C
0005432783420	12213	72	20D
0005435242859	12213	73	20E
0005432783575	12213	74	20F
0005435242682	15423	1	1D
0005432783765	15423	2	2A
0005432783763	15423	3	2C
0005432783757	15423	4	2D
0005435242659	15423	5	3A
0005432783754	15423	6	3C
0005435242592	15423	7	3D
0005435242629	15423	8	3F
0005432783728	15423	9	4C
0005432783733	15423	10	4E
0005432783766	15423	11	5A
0005435242660	15423	12	5C
0005435242621	15423	13	5F
0005432783748	15423	14	6A
0005432783739	15423	15	6C
0005432783744	15423	16	6D
0005435242497	15423	17	6E
0005435242749	15423	18	6F
0005435242683	15423	19	7A
0005435242662	15423	20	7C
0005432783745	15423	21	7D
0005432783724	15423	22	7E
0005432783770	15423	23	7F
0005435242589	15423	24	8A
0005432783769	15423	25	8D
0005435242627	15423	26	8E
0005435242597	15423	27	8F
0005432783723	15423	28	9A
0005432783751	15423	29	9C
0005432783727	15423	30	9D
0005435242669	15423	31	9E
0005432783738	15423	32	9F
0005432783755	15423	33	10A
0005432783732	15423	34	10D
0005435242674	15423	35	10E
0005432783726	15423	36	10F
0005432783775	15423	37	11A
0005432783735	15423	38	11C
0005432783772	15423	39	11D
0005435242585	15423	40	11E
0005432783761	15423	41	11F
0005432783750	15423	42	12A
0005432783749	15423	43	12D
0005432783747	15423	44	12E
0005432783740	15423	45	12F
0005432783720	15423	46	13A
0005432783773	15423	47	13C
0005432783752	15423	48	13D
0005432783774	15423	49	13E
0005432783722	15423	50	13F
0005432783771	15423	51	14A
0005435242488	15423	52	14C
0005432783729	15423	53	14E
0005432783730	15423	54	14F
0005435242622	15423	55	15A
0005432783756	15423	56	15C
0005432783741	15423	57	15D
0005432783762	15423	58	15E
0005432783764	15423	59	15F
0005432783721	15423	60	16A
0005435242536	15423	61	16C
0005435242558	15423	62	16D
0005435242748	15423	63	16E
0005432783742	15423	64	16F
0005432783737	15423	65	17A
0005435242719	15423	66	17C
0005432783758	15423	67	17D
0005435242614	15423	68	17E
0005432783767	15423	69	17F
0005432783734	15423	70	18C
0005432783760	15423	71	18D
0005435242593	15423	72	18E
0005432783746	15423	73	18F
0005435242615	15423	74	19A
0005432783725	15423	75	19C
0005432783731	15423	76	19D
0005432783743	15423	77	19E
0005435242586	15423	78	19F
0005432783759	15423	79	20C
0005432783768	15423	80	20D
0005432783736	15423	81	20E
0005432783753	15423	82	20F
0005434877544	10116	1	1C
0005434876966	10116	2	1A
0005434877515	10116	3	1D
0005434877276	10116	4	2C
0005434877477	10116	5	2A
0005434877847	10116	6	2D
0005434877613	10116	7	3A
0005434877395	10116	8	2F
0005434877284	10116	9	3D
0005434877777	10116	10	4A
0005434877366	10116	11	3F
0005434910113	10116	12	4C
0005434877447	10116	13	4F
0005434877294	10116	14	4D
0005434876930	10116	15	5C
0005434877769	10116	16	5A
0005434877623	10116	17	5F
0005434877435	10116	18	5D
0005434877878	10116	19	6A
0005434877969	10116	20	6D
0005434877768	10116	21	6C
0005434877492	10116	22	6B
0005434877076	10116	23	6F
0005434877349	10116	24	6E
0005434877342	10116	25	7A
0005434877277	10116	26	7C
0005434877483	10116	27	7B
0005434877362	10116	28	7E
0005434877653	10116	29	7D
0005434877548	10116	30	8A
0005434877151	10116	31	8C
0005434877482	10116	32	8B
0005434877238	10116	33	8D
0005434877475	10116	34	8F
0005434877365	10116	35	9B
0005434877322	10116	36	9A
0005435913933	10116	37	9C
0005434910112	10116	38	9F
0005434877497	10116	39	9E
0005434877401	10116	40	9D
0005434877765	10116	41	10A
0005435913934	10116	42	10C
0005434877400	10116	43	10B
0005434877383	10116	44	10E
0005434877600	10116	45	10F
0005434758875	10116	46	11B
0005434877368	10116	47	11D
0005434877248	10116	48	11C
0005434877397	10116	49	11F
0005434877275	10116	50	11E
0005434877478	10116	51	12B
0005434910111	10116	52	12A
0005434877396	10116	53	12C
0005434876965	10116	54	12E
0005434877776	10116	55	12D
0005434877097	10116	56	13A
0005434877237	10116	57	12F
0005434877746	10116	58	13C
0005434877283	10116	59	13B
0005434877434	10116	60	13E
0005434877534	10116	61	13D
0005434877361	10116	62	13F
0005434877495	10116	63	14B
0005434877343	10116	64	14A
0005434877112	10116	65	14E
0005434876931	10116	66	14D
0005434877244	10116	67	14C
0005434877596	10116	68	14F
0005434877446	10116	69	15A
0005434877183	10116	70	15D
0005434877712	10116	71	15C
0005434877527	10116	72	15E
0005434877332	10116	73	16A
0005434877169	10116	74	15F
0005434877436	10116	75	16C
0005434877535	10116	76	16B
0005434877609	10116	77	16E
0005434877551	10116	78	16D
0005434877316	10116	79	17A
0005434877576	10116	80	16F
0005434877239	10116	81	17B
0005434877599	10116	82	17D
0005434877367	10116	83	17C
0005434877598	10116	84	17F
0005434877474	10116	85	17E
0005435913935	10116	86	18A
0005434877308	10116	87	18C
0005434877493	10116	88	18B
0005434877583	10116	89	18E
0005435913936	10116	90	19A
0005434877607	10116	91	18F
0005434877150	10116	92	19C
0005434877265	10116	93	19B
0005434877595	10116	94	19D
0005434877498	10116	95	20A
0005434877182	10116	96	19F
0005434877561	10116	97	19E
0005434877597	10116	98	20D
0005434877608	10116	99	20C
0005434877496	10116	100	20F
0005434877149	10116	101	20E
0005434877315	10116	102	21A
0005434877075	10116	103	21D
0005434877610	10116	104	21C
0005434877462	10116	105	21B
0005434877546	10116	106	21E
0005434758876	10116	107	21F
0005434910092	14617	1	1C
0005434878250	14617	2	1A
0005434878276	14617	3	1F
0005434878291	14617	4	1D
0005434878236	14617	5	2A
0005434878238	14617	6	2D
0005434878255	14617	7	2C
0005434878267	14617	8	3A
0005434878232	14617	9	2F
0005434878286	14617	10	3D
0005434878260	14617	11	3C
0005434878265	14617	12	4A
0005434878204	14617	13	3F
0005435913874	14617	14	4C
0005434878287	14617	15	4F
0005434878210	14617	16	5C
0005434878259	14617	17	5A
0005434878203	14617	18	5F
0005434878269	14617	19	5D
0005434878283	14617	20	6A
0005434758894	14617	21	6C
0005434878292	14617	22	6B
0005434878233	14617	23	6F
0005434878279	14617	24	6E
0005434878256	14617	25	6D
0005434878222	14617	26	7A
0005434910089	14617	27	7C
0005434878235	14617	28	7B
0005434878224	14617	29	7E
0005434878290	14617	30	7D
0005434878249	14617	31	8A
0005434878229	14617	32	7F
0005434878225	14617	33	8B
0005434878202	14617	34	8D
0005434878243	14617	35	8C
0005434878275	14617	36	8F
0005434878241	14617	37	8E
0005434878261	14617	38	9B
0005434758893	14617	39	9A
0005435913895	14617	40	9C
0005434878220	14617	41	9E
0005434878228	14617	42	10A
0005434878213	14617	43	9F
0005434878237	14617	44	10C
0005434878218	14617	45	10B
0005434878270	14617	46	10E
0005434878252	14617	47	10D
0005434878263	14617	48	10F
0005434878223	14617	49	11B
0005434878262	14617	50	11D
0005434878281	14617	51	11C
0005434878266	14617	52	11F
0005434878280	14617	53	11E
0005434878246	14617	54	12B
0005434878289	14617	55	12A
0005434878258	14617	56	12C
0005434878227	14617	57	12F
0005434878268	14617	58	12E
0005434878282	14617	59	13A
0005434878212	14617	60	13C
0005434878221	14617	61	13B
0005434878205	14617	62	13E
0005434878217	14617	63	13D
0005434878209	14617	64	14A
0005434878214	14617	65	14D
0005434878208	14617	66	14C
0005434878242	14617	67	14E
0005434878240	14617	68	15B
0005434878294	14617	69	15A
0005434878206	14617	70	15D
0005434878234	14617	71	15C
0005434878215	14617	72	15E
0005434878284	14617	73	16A
0005434878297	14617	74	15F
0005434878288	14617	75	16C
0005434878257	14617	76	16B
0005434878293	14617	77	16E
0005434878219	14617	78	16D
0005434878231	14617	79	16F
0005434878251	14617	80	17B
0005434878254	14617	81	17A
0005434878245	14617	82	17D
0005434878226	14617	83	17C
0005434878239	14617	84	18B
0005434878285	14617	85	18A
0005434878264	14617	86	17F
0005434878247	14617	87	18C
0005434878211	14617	88	18E
0005434878244	14617	89	18D
0005434910093	14617	90	18F
0005434878273	14617	91	19C
0005434878277	14617	92	19B
0005434878216	14617	93	19A
0005434910094	14617	94	19D
0005434878298	14617	95	19F
0005434910091	14617	96	19E
0005434878295	14617	97	20C
0005434878296	14617	98	20B
0005434878207	14617	99	20A
0005434878253	14617	100	20D
0005434878278	14617	101	20F
0005434878230	14617	102	20E
0005434878248	14617	103	21A
0005434878274	14617	104	21C
0005434878272	14617	105	21B
0005434758892	14617	106	21D
0005434878271	14617	107	21F
0005434251865	9214	1	1A
0005435660137	9214	2	1D
0005434251882	9214	3	2A
0005434251883	9214	4	2B
0005435660133	9214	5	2C
0005434251858	9214	6	2D
0005435660135	9214	7	3B
0005435660136	9214	8	3C
0005435660134	9214	9	3D
0005435660144	9214	10	4A
0005435660142	9214	11	5A
0005435660139	9214	12	5B
0005435660140	9214	13	5C
0005434251866	9214	14	6A
0005434251907	9214	15	7B
0005434251896	9214	16	7C
0005434251873	9214	17	18A
0005435660143	9214	18	19A
0005434251897	9214	19	19B
0005435660138	9214	20	20A
0005434251875	9214	21	20D
0005434251874	9214	22	21C
0005435660141	9214	23	22A
0005434251908	9214	24	22C
0005435660034	24628	1	1A
0005435659992	24628	2	2D
0005435660053	24628	3	3C
0005435660052	24628	4	4B
0005434251967	24628	5	4C
0005434251961	24628	6	5C
0005435660054	24628	7	5D
0005434251969	24628	8	6B
0005435660036	24628	9	6C
0005435660048	24628	10	7A
0005434251964	24628	11	7B
0005435660016	24628	12	7C
0005434251963	24628	13	19B
0005434251962	24628	14	19C
0005434251966	24628	15	19D
0005435660061	24628	16	21A
0005434251965	24628	17	21B
0005434251968	24628	18	22A
0005435660035	24628	19	22B
0005435660055	24628	20	22C
0005433680586	2815	1	1A
0005433680554	2815	2	1F
0005432222780	2815	3	1D
0005433680541	2815	4	2A
0005433680548	2815	5	2D
0005432222779	2815	6	2F
0005432966726	2815	7	3A
0005432966644	2815	8	3C
0005432966736	2815	9	3D
0005433684420	2815	10	3F
0005433680551	2815	11	4A
0005433680565	2815	12	4C
0005433680542	2815	13	4D
0005433680571	2815	14	4E
0005433680546	2815	15	4F
0005432966682	2815	16	5A
0005433680573	2815	17	5F
0005432966592	2815	18	6A
0005433680575	2815	19	6D
0005433680544	2815	20	6E
0005432966681	2815	21	6F
0005433680585	2815	22	7A
0005433680553	2815	23	7D
0005432966676	2815	24	7F
0005432966710	2815	25	8C
0005433680549	2815	26	8E
0005432966593	2815	27	8F
0005432966734	2815	28	9A
0005433680577	2815	29	9C
0005433680563	2815	30	9D
0005433680581	2815	31	9E
0005433680557	2815	32	9F
0005433680574	2815	33	10A
0005433680587	2815	34	10C
0005433680558	2815	35	10D
0005433680572	2815	36	10E
0005433680569	2815	37	10F
0005432966789	2815	38	11A
0005432222785	2815	39	11C
0005433680556	2815	40	11D
0005433680550	2815	41	11E
0005432222783	2815	42	11F
0005433680555	2815	43	12A
0005432966770	2815	44	12C
0005433680583	2815	45	12D
0005432966680	2815	46	12E
0005432222782	2815	47	12F
0005432222784	2815	48	13A
0005433680547	2815	49	13C
0005433680540	2815	50	13D
0005433680564	2815	51	13E
0005433680566	2815	52	13F
0005432966735	2815	53	14C
0005433680588	2815	54	14D
0005432222781	2815	55	14E
0005432966594	2815	56	14F
0005432966788	2815	57	15A
0005433680562	2815	58	15C
0005433680576	2815	59	15D
0005433680570	2815	60	15E
0005433680560	2815	61	15F
0005433680582	2815	62	16A
0005433680580	2815	63	16D
0005433680568	2815	64	16F
0005433680579	2815	65	17A
0005432966769	2815	66	17C
0005433680567	2815	67	17D
0005433680559	2815	68	17E
0005433680552	2815	69	17F
0005432966731	2815	70	18A
0005432966758	2815	71	18C
0005433680561	2815	72	18D
0005433680545	2815	73	18E
0005432966656	2815	74	18F
0005433680578	2815	75	19A
0005432966671	2815	76	19C
0005433684419	2815	77	19D
0005433680543	2815	78	19E
0005433680584	2815	79	19F
0005432966643	2815	80	20C
0005432966787	2815	81	20E
0005433680250	29163	1	1A
0005433680018	29163	2	1C
0005433680007	29163	3	1F
0005432966923	29163	4	2A
0005433680258	29163	5	2C
0005433690907	29163	6	2D
0005432966929	29163	7	2F
0005433684409	29163	8	3A
0005433680104	29163	9	3C
0005433680270	29163	10	3D
0005433680227	29163	11	3F
0005433680017	29163	12	4A
0005432966947	29163	13	4C
0005432966938	29163	14	4D
0005432966948	29163	15	4E
0005433680389	29163	16	4F
0005432966935	29163	17	5A
0005432966939	29163	18	5C
0005432966940	29163	19	5E
0005432966925	29163	20	5F
0005432966924	29163	21	6A
0005433680213	29163	22	6C
0005433680105	29163	23	6D
0005433690904	29163	24	6E
0005432966928	29163	25	6F
0005433680006	29163	26	7A
0005433680204	29163	27	7C
0005433680332	29163	28	7D
0005432966946	29163	29	7E
0005432966941	29163	30	7F
0005432966931	29163	31	8C
0005433680008	29163	32	8D
0005433679973	29163	33	8E
0005433680200	29163	34	8F
0005433690915	29163	35	9A
0005433684408	29163	36	9C
0005432966943	29163	37	9D
0005433680282	29163	38	9E
0005432966930	29163	39	9F
0005433684414	29163	40	10A
0005433680159	29163	41	10C
0005433680102	29163	42	10D
0005432966926	29163	43	10E
0005432966927	29163	44	11C
0005433680182	29163	45	11D
0005433680177	29163	46	11F
0005432966933	29163	47	12A
0005433680212	29163	48	12C
0005432966934	29163	49	12D
0005433679950	29163	50	12E
0005432005212	29163	51	12F
0005433690916	29163	52	13A
0005433680281	29163	53	13C
0005432005214	29163	54	13D
0005433680014	29163	55	13E
0005433680171	29163	56	13F
0005432966932	29163	57	14A
0005433680247	29163	58	14C
0005432966937	29163	59	14D
0005433680341	29163	60	14E
0005432966945	29163	61	15A
0005433680222	29163	62	15C
0005433679859	29163	63	15D
0005433690900	29163	64	15E
0005433680023	29163	65	15F
0005433680093	29163	66	16A
0005433680259	29163	67	16C
0005433680266	29163	68	16D
0005432005213	29163	69	16F
0005432966936	29163	70	17A
0005432966944	29163	71	17C
0005433680248	29163	72	17D
0005433680265	29163	73	17E
0005433680310	29163	74	17F
0005432966942	29163	75	18A
0005433680013	29163	76	18C
0005433680024	29163	77	18D
0005433680158	29163	78	18E
0005433680214	29163	79	18F
0005433680114	29163	80	19C
0005433680377	29163	81	19D
0005433680205	29163	82	19E
0005433680249	29163	83	19F
0005433680337	29163	84	20C
0005433679991	29163	85	20D
0005433690914	29163	86	20E
0005433680251	29163	87	20F
0005433633773	9306	1	1A
0005433614592	9306	2	1C
0005433614642	9306	3	2A
0005433614637	9306	4	2C
0005433633776	9306	5	2D
0005433633778	9306	6	3A
0005433614598	9306	7	2F
0005433614630	9306	8	3C
0005433614597	9306	9	4A
0005432756845	9306	10	3F
0005433614627	9306	11	4C
0005433614617	9306	12	4D
0005433614612	9306	13	5A
0005433614651	9306	14	4F
0005433633787	9306	15	5C
0005433577810	9306	16	5D
0005433633784	9306	17	6A
0005434163541	9306	18	5F
0005434163542	9306	19	6F
0005433577811	9306	20	6D
0005432755074	9306	21	7A
0005433614639	9306	22	7F
0005433614610	9306	23	8A
0005433633781	9306	24	8B
0005434269086	9306	25	8D
0005433633792	9306	26	8C
0005433577799	9306	27	9A
0005433577798	9306	28	9B
0005433614604	9306	29	9C
0005433614652	9306	30	9E
0005432755075	9306	31	9D
0005433633797	9306	32	10A
0005433614589	9306	33	9F
0005433614649	9306	34	10D
0005433614636	9306	35	10C
0005433633777	9306	36	10E
0005433633789	9306	37	11A
0005433614622	9306	38	11C
0005432145110	9306	39	11B
0005433633793	9306	40	11E
0005433614593	9306	41	11D
0005433577805	9306	42	11F
0005433614628	9306	43	12A
0005433614648	9306	44	12B
0005433614644	9306	45	12C
0005433614646	9306	46	12E
0005433633796	9306	47	12D
0005433633780	9306	48	12F
0005433614650	9306	49	13C
0005433577800	9306	50	13B
0005433633786	9306	51	13D
0005433614613	9306	52	14A
0005433577806	9306	53	13F
0005433614618	9306	54	14B
0005432756848	9306	55	14D
0005433614643	9306	56	14C
0005433633791	9306	57	14F
0005433614602	9306	58	15B
0005433614654	9306	59	15A
0005433614614	9306	60	15C
0005433633802	9306	61	15D
0005433633785	9306	62	15F
0005433614599	9306	63	15E
0005433614585	9306	64	16A
0005434272181	9306	65	16B
0005433633774	9306	66	16C
0005433614609	9306	67	16E
0005433614638	9306	68	17A
0005433633788	9306	69	16F
0005433614631	9306	70	17C
0005433614658	9306	71	17F
0005434269090	9306	72	17E
0005433633771	9306	73	18C
0005433614584	9306	74	18B
0005433633794	9306	75	18D
0005433614647	9306	76	18E
0005433577802	9306	77	19B
0005433577801	9306	78	19D
0005433633779	9306	79	19C
0005433633783	9306	80	19E
0005433577803	9306	81	20B
0005433614623	9306	82	20A
0005433614624	9306	83	20F
0005433614606	9306	84	20E
0005432756846	9306	85	21A
0005433614603	9306	86	21D
0005433577809	9306	87	21E
0005433633798	9306	88	21F
0005433614634	9306	89	22B
0005434152779	9306	90	22A
0005433633801	9306	91	22C
0005433614587	9306	92	22E
0005433614596	9306	93	22D
0005433633775	9306	94	22F
0005433633795	9306	95	23A
0005433614616	9306	96	23B
0005433614588	9306	97	23D
0005433614641	9306	98	23C
0005433614615	9306	99	24A
0005433614656	9306	100	24B
0005433633806	9306	101	24C
0005433614591	9306	102	24E
0005433614586	9306	103	24D
0005433614611	9306	104	24F
0005433614626	9306	105	25B
0005433614655	9306	106	25A
0005433614635	9306	107	25D
0005433614607	9306	108	25C
0005433633803	9306	109	25E
0005433614640	9306	110	26A
0005433614608	9306	111	25F
0005433614600	9306	112	26B
0005433614605	9306	113	26C
0005433614621	9306	114	26E
0005434163537	9306	115	26D
0005433614594	9306	116	26F
0005433614595	9306	117	27A
0005433614632	9306	118	27C
0005433633772	9306	119	27D
0005433633790	9306	120	27F
0005433614633	9306	121	27E
0005433577807	9306	122	28A
0005433614645	9306	123	28B
0005433614653	9306	124	28D
0005432755073	9306	125	28C
0005433633805	9306	126	28E
0005433633800	9306	127	29A
0005433577808	9306	128	28F
0005433633782	9306	129	29B
0005433614590	9306	130	29C
0005433614601	9306	131	29D
0005433633799	9306	132	30A
0005433614620	9306	133	29F
0005434163543	9306	134	30B
0005433614619	9306	135	30C
0005433614629	9306	136	30E
0005432756847	9306	137	30F
0005433614657	9306	138	31A
0005434269091	9306	139	31B
0005433614625	9306	140	31E
0005433577804	9306	141	31D
0005433633804	9306	142	31C
0005433613865	25256	1	1A
0005433577706	25256	2	1D
0005433613985	25256	3	1C
0005433633375	25256	4	2A
0005433613629	25256	5	1F
0005433633407	25256	6	2D
0005433614358	25256	7	2C
0005433633362	25256	8	3A
0005433614176	25256	9	2F
0005433613851	25256	10	3D
0005432755028	25256	11	3C
0005433613906	25256	12	3F
0005433614000	25256	13	4A
0005433614112	25256	14	4C
0005434152781	25256	15	4D
0005433613836	25256	16	5A
0005432751485	25256	17	4F
0005433614066	25256	18	5D
0005433613986	25256	19	5C
0005433613931	25256	20	5F
0005433633478	25256	21	6A
0005433577679	25256	22	6C
0005433633492	25256	23	6F
0005433577731	25256	24	6D
0005432755033	25256	25	7A
0005433633534	25256	26	7D
0005433613893	25256	27	7C
0005433614263	25256	28	7F
0005433614162	25256	29	8A
0005433614113	25256	30	8C
0005433614071	25256	31	8B
0005433613892	25256	32	8E
0005433613932	25256	33	8D
0005432751508	25256	34	8F
0005433614400	25256	35	9B
0005433614223	25256	36	9A
0005433613618	25256	37	9C
0005433633675	25256	38	9E
0005432751487	25256	39	9D
0005432751495	25256	40	10A
0005433577618	25256	41	9F
0005433633442	25256	42	10B
0005433614349	25256	43	10C
0005433633430	25256	44	10E
0005433633502	25256	45	10D
0005432751502	25256	46	10F
0005433633501	25256	47	11B
0005433613849	25256	48	11C
0005433613540	25256	49	11D
0005433633500	25256	50	11F
0005433577730	25256	51	11E
0005433614087	25256	52	12A
0005432755035	25256	53	12C
0005433614007	25256	54	12B
0005433613957	25256	55	12E
0005433613861	25256	56	12D
0005433613757	25256	57	12F
0005433613967	25256	58	13A
0005433614053	25256	59	13C
0005433613539	25256	60	13B
0005433633441	25256	61	13D
0005433613883	25256	62	13F
0005433633677	25256	63	13E
0005432751494	25256	64	14A
0005433613884	25256	65	14B
0005433613687	25256	66	14C
0005433613688	25256	67	14E
0005432755026	25256	68	14D
0005432755038	25256	69	14F
0005433633394	25256	70	15B
0005433633431	25256	71	15E
0005433613894	25256	72	15D
0005432751486	25256	73	15C
0005433633490	25256	74	16A
0005433577705	25256	75	15F
0005433633406	25256	76	16C
0005433633505	25256	77	16B
0005433614031	25256	78	16E
0005433614045	25256	79	17A
0005433613966	25256	80	16F
0005433577671	25256	81	17C
0005432751483	25256	82	17B
0005433633580	25256	83	17D
0005433613630	25256	84	17E
0005433633521	25256	85	18A
0005433613778	25256	86	17F
0005433577707	25256	87	18B
0005432751492	25256	88	18C
0005433613999	25256	89	18E
0005433633647	25256	90	18D
0005433613689	25256	91	18F
0005433614174	25256	92	19C
0005433614029	25256	93	19D
0005433614170	25256	94	19E
0005433614102	25256	95	20B
0005433633516	25256	96	20A
0005433614052	25256	97	20C
0005433614001	25256	98	20E
0005433577678	25256	99	20D
0005433614091	25256	100	20F
0005433613924	25256	101	21A
0005433614107	25256	102	21C
0005432751507	25256	103	21B
0005432755027	25256	104	21F
0005433613933	25256	105	21E
0005433633470	25256	106	21D
0005433614350	25256	107	22B
0005433633475	25256	108	22C
0005433614099	25256	109	22D
0005433633646	25256	110	22F
0005433614059	25256	111	22E
0005433613988	25256	112	23B
0005433613791	25256	113	23C
0005433633545	25256	114	23E
0005433633533	25256	115	24A
0005433613864	25256	116	23F
0005433614211	25256	117	24B
0005433613777	25256	118	24D
0005433614139	25256	119	24F
0005433633439	25256	120	24E
0005433613862	25256	121	25A
0005433613970	25256	122	25C
0005433613968	25256	123	25B
0005432755047	25256	124	25D
0005433614108	25256	125	25E
0005433614210	25256	126	26A
0005432755032	25256	127	25F
0005433633586	25256	128	26B
0005432751484	25256	129	26C
0005432755036	25256	130	26E
0005433614175	25256	131	26D
0005433633494	25256	132	26F
0005433613792	25256	133	27A
0005433613799	25256	134	27C
0005433614109	25256	135	27B
0005433614070	25256	136	27D
0005432755034	25256	137	27F
0005433633361	25256	138	27E
0005432751481	25256	139	28A
0005433614023	25256	140	28B
0005432751478	25256	141	28C
0005433614177	25256	142	28D
0005433613971	25256	143	28F
0005433633676	25256	144	29A
0005433614067	25256	145	29B
0005433633504	25256	146	29D
0005433633520	25256	147	29C
0005433613979	25256	148	29F
0005432755031	25256	149	29E
0005433577708	25256	150	30B
0005433614030	25256	151	30C
0005433613732	25256	152	30E
0005433633517	25256	153	30D
0005433613965	25256	154	30F
0005433614138	25256	155	31B
0005433633639	25256	156	31A
0005433613699	25256	157	31C
0005433633440	25256	158	31D
0005433633556	25256	159	31E
0005433613860	25256	160	31F
0005432571280	4227	1	2H
0005435986762	4227	2	3B
0005435947142	4227	3	9G
0005435986768	4227	4	11E
0005435854051	4227	5	11D
0005435986761	4227	6	12D
0005435856176	4227	7	12H
0005435986763	4227	8	13D
0005435947106	4227	9	16F
0005435947095	4227	10	16E
0005435947170	4227	11	16H
0005435947113	4227	12	18F
0005435986759	4227	13	19D
0005435986766	4227	14	22B
0005432571269	4227	15	23B
0005435856169	4227	16	23E
0005435986760	4227	17	25D
0005434271292	4227	18	27D
0005435947075	4227	19	29D
0005432184951	4227	20	30A
0005435986765	4227	21	30H
0005434271289	4227	22	31E
0005432184950	4227	23	31G
0005435787329	4227	24	33E
0005435986767	4227	25	34F
0005435947112	4227	26	35E
0005435986770	4227	27	36E
0005432184949	4227	28	36D
0005435947143	4227	29	37E
0005435986769	4227	30	37F
0005435986764	4227	31	37H
0005435947184	4227	32	38B
0005435947257	26591	1	3A
0005435856204	26591	2	3B
0005435947258	26591	3	13A
0005435947256	26591	4	14A
0005435986680	26591	5	18F
0005432571325	26591	6	19G
0005435856206	26591	7	20E
0005435947262	26591	8	20F
0005435787355	26591	9	21D
0005435947254	26591	10	21G
0005435986712	26591	11	22B
0005435947251	26591	12	22A
0005435947260	26591	13	22F
0005435947252	26591	14	23A
0005432571326	26591	15	22H
0005435856205	26591	16	23B
0005435986684	26591	17	24H
0005435947264	26591	18	27B
0005435947263	26591	19	29G
0005435856207	26591	20	31E
0005435947261	26591	21	31H
0005435947255	26591	22	32G
0005435947259	26591	23	33B
0005435787356	26591	24	34H
0005435947253	26591	25	35B
0005435986683	26591	26	35D
0005435986705	26591	27	35F
0005433569118	332	1	1C
0005433569115	332	2	1A
0005433129243	332	3	1D
0005433569110	332	4	2A
0005433134089	332	5	1F
0005433074433	332	6	2C
0005432948089	332	7	3C
0005433074559	332	8	3F
0005433569072	332	9	3D
0005432238940	332	10	4A
0005432948083	332	11	4C
0005433569100	332	12	5A
0005432238936	332	13	5D
0005432948104	332	14	5C
0005433569061	332	15	5F
0005433569095	332	16	6C
0005433569060	332	17	6A
0005432948088	332	18	6F
0005433074466	332	19	6D
0005432948095	332	20	7C
0005433569070	332	21	7D
0005433074508	332	22	8A
0005432238934	332	23	8C
0005432948188	332	24	8E
0005433569062	332	25	8D
0005433074395	332	26	8F
0005433569108	332	27	9B
0005433569089	332	28	9A
0005433074479	332	29	9C
0005433569083	332	30	9D
0005433569116	332	31	9F
0005433074582	332	32	9E
0005432948010	332	33	10A
0005433569074	332	34	10C
0005433569087	332	35	10E
0005432238935	332	36	10D
0005433569084	332	37	10F
0005433569101	332	38	11A
0005433074365	332	39	11C
0005433569059	332	40	11B
0005432948069	332	41	11D
0005433569050	332	42	11F
0005432948068	332	43	12A
0005432948103	332	44	12C
0005433569120	332	45	12B
0005433569063	332	46	12E
0005433074343	332	47	12D
0005433074429	332	48	12F
0005433569107	332	49	13A
0005433129231	332	50	13B
0005433074342	332	51	13C
0005433569052	332	52	13F
0005433569049	332	53	13E
0005433569077	332	54	14A
0005433569111	332	55	14B
0005433569068	332	56	14D
0005433074568	332	57	14C
0005433129224	332	58	14E
0005433569075	332	59	14F
0005433569114	332	60	15B
0005433074432	332	61	15A
0005433569109	332	62	15C
0005433074581	332	63	15D
0005433569096	332	64	15E
0005433569051	332	65	16A
0005433569117	332	66	15F
0005432947892	332	67	16B
0005433074326	332	68	16D
0005433074245	332	69	16C
0005433129225	332	70	16E
0005432948094	332	71	16F
0005433074494	332	72	17C
0005433569112	332	73	17B
0005432948045	332	74	17D
0005432948127	332	75	17F
0005433569085	332	76	17E
0005433569121	332	77	18A
0005433569066	332	78	18B
0005433074467	332	79	18D
0005433129230	332	80	18C
0005433074431	332	81	18E
0005433569103	332	82	18F
0005433074394	332	83	19C
0005433074244	332	84	19D
0005433569056	332	85	19E
0005433074355	332	86	20B
0005433569076	332	87	20A
0005433074340	332	88	20C
0005433569123	332	89	20E
0005433569058	332	90	20D
0005432948007	332	91	20F
0005432948186	332	92	21A
0005433569105	332	93	21C
0005433074327	332	94	21B
0005433569088	332	95	21D
0005433569054	332	96	21E
0005433569067	332	97	21F
0005432238939	332	98	22B
0005433569081	332	99	22D
0005433569102	332	100	22C
0005433074525	332	101	22E
0005432948096	332	102	22F
0005433569055	332	103	23A
0005433569094	332	104	23C
0005432238937	332	105	23D
0005433569078	332	106	23E
0005433129238	332	107	24A
0005433569073	332	108	23F
0005433569092	332	109	24B
0005433134098	332	110	24D
0005433569065	332	111	24C
0005433569080	332	112	24E
0005433074562	332	113	25B
0005433569057	332	114	25A
0005433569122	332	115	25D
0005432948164	332	116	25C
0005433569069	332	117	25F
0005433074430	332	118	25E
0005433074575	332	119	26A
0005433569093	332	120	26B
0005432948052	332	121	26D
0005433569086	332	122	26C
0005433569106	332	123	26E
0005433569071	332	124	26F
0005433074412	332	125	27A
0005432238938	332	126	27C
0005433569064	332	127	27B
0005433569082	332	128	27E
0005433129246	332	129	28A
0005433129247	332	130	27F
0005433569053	332	131	28C
0005432948028	332	132	28B
0005433569104	332	133	28D
0005433569119	332	134	28E
0005433569099	332	135	28F
0005433074435	332	136	29B
0005433134090	332	137	29A
0005432948272	332	138	29C
0005432948128	332	139	29D
0005433074243	332	140	29F
0005433569113	332	141	29E
0005433569097	332	142	30A
0005432948027	332	143	30C
0005432948046	332	144	30B
0005433074434	332	145	30E
0005433569091	332	146	30D
0005433074509	332	147	30F
0005433569079	332	148	31A
0005433074471	332	149	31B
0005433129248	332	150	31E
0005433569098	332	151	31D
0005433129223	332	152	31C
0005433569090	332	153	31F
0005432948432	11612	1	1A
0005433568645	11612	2	1C
0005433568431	11612	3	1F
0005432948443	11612	4	2D
0005433568273	11612	5	2C
0005433568271	11612	6	2F
0005432948460	11612	7	3A
0005433074699	11612	8	3F
0005433568376	11612	9	3D
0005432948453	11612	10	4D
0005433568435	11612	11	4C
0005433074701	11612	12	4A
0005433131709	11612	13	4F
0005432948439	11612	14	5A
0005433568513	11612	15	5C
0005433568445	11612	16	5D
0005433074715	11612	17	6D
0005432948435	11612	18	6C
0005433074711	11612	19	7A
0005433074714	11612	20	6F
0005433568436	11612	21	7C
0005432192320	11612	22	7D
0005433568474	11612	23	8A
0005433074706	11612	24	8D
0005433568229	11612	25	8C
0005433074716	11612	26	8E
0005432948466	11612	27	8F
0005432948434	11612	28	9A
0005432948456	11612	29	9C
0005433074720	11612	30	9B
0005433568701	11612	31	9D
0005433568485	11612	32	9E
0005433074694	11612	33	9F
0005432948458	11612	34	10B
0005432948462	11612	35	10E
0005432948457	11612	36	10F
0005432948454	11612	37	11A
0005433568682	11612	38	11C
0005433568434	11612	39	11D
0005433568544	11612	40	11F
0005432948446	11612	41	11E
0005433568570	11612	42	12C
0005433074719	11612	43	12B
0005433568393	11612	44	12A
0005432948438	11612	45	12D
0005433074707	11612	46	12F
0005433074705	11612	47	12E
0005433568504	11612	48	13A
0005433568501	11612	49	13C
0005432948450	11612	50	13B
0005433074712	11612	51	13E
0005432948467	11612	52	13F
0005433568344	11612	53	14A
0005433568484	11612	54	14E
0005433074703	11612	55	14D
0005433074709	11612	56	14F
0005433568194	11612	57	15A
0005433074696	11612	58	15C
0005433074710	11612	59	15D
0005433568534	11612	60	15E
0005433568542	11612	61	16A
0005433568569	11612	62	15F
0005432948449	11612	63	16D
0005432948464	11612	64	16C
0005433131710	11612	65	16E
0005433074692	11612	66	17B
0005433568444	11612	67	17C
0005433074704	11612	68	17D
0005433568455	11612	69	17F
0005433134136	11612	70	17E
0005433134139	11612	71	18A
0005433568343	11612	72	18C
0005433074708	11612	73	18B
0005433134138	11612	74	18D
0005433568437	11612	75	18E
0005432948441	11612	76	18F
0005432948452	11612	77	19C
0005433074702	11612	78	19D
0005432948436	11612	79	20A
0005433568517	11612	80	19E
0005433074697	11612	81	20B
0005433568457	11612	82	20C
0005433074700	11612	83	20E
0005433568512	11612	84	20D
0005433568323	11612	85	21A
0005433131707	11612	86	20F
0005433131706	11612	87	21C
0005433074717	11612	88	21B
0005433134137	11612	89	21D
0005432948437	11612	90	21E
0005433568375	11612	91	21F
0005433568413	11612	92	22B
0005433568416	11612	93	22A
0005432948465	11612	94	22C
0005433568496	11612	95	22E
0005433568497	11612	96	22D
0005433568469	11612	97	22F
0005433568468	11612	98	23C
0005432948445	11612	99	23B
0005432948433	11612	100	23D
0005432948470	11612	101	23F
0005433568319	11612	102	23E
0005432948459	11612	103	24A
0005433568592	11612	104	24B
0005433568265	11612	105	24C
0005432192319	11612	106	24E
0005432948461	11612	107	24D
0005432948440	11612	108	24F
0005433131708	11612	109	25A
0005433074695	11612	110	25C
0005432192321	11612	111	25D
0005432948448	11612	112	25F
0005433568543	11612	113	25E
0005432948463	11612	114	26A
0005432948451	11612	115	26B
0005432948471	11612	116	26C
0005433568610	11612	117	26E
0005433568379	11612	118	26D
0005433568417	11612	119	26F
0005432948444	11612	120	27A
0005433074718	11612	121	27C
0005433568433	11612	122	27B
0005432948442	11612	123	27D
0005432948468	11612	124	27E
0005433568456	11612	125	28A
0005433568470	11612	126	27F
0005433568679	11612	127	28B
0005432948447	11612	128	28C
0005433568232	11612	129	28E
0005433568290	11612	130	28D
0005433568591	11612	131	28F
0005433568362	11612	132	29B
0005432948469	11612	133	29D
0005432948455	11612	134	29C
0005433568272	11612	135	29F
0005433568397	11612	136	29E
0005433568599	11612	137	30A
0005433074713	11612	138	30B
0005433568463	11612	139	30C
0005433568716	11612	140	30E
0005433568424	11612	141	30D
0005433074698	11612	142	30F
0005433568385	11612	143	31C
0005433568462	11612	144	31B
0005433568509	11612	145	31F
0005433074693	11612	146	31E
0005434732948	9964	1	1A
0005433817471	9964	2	1B
0005434732966	9964	3	2B
0005434732949	9964	4	3A
0005434732934	9964	5	4B
0005433817472	9964	6	5A
0005433817470	9964	7	5B
0005434732952	9964	8	6A
0005433817462	13970	1	1B
0005434732981	13970	2	2A
0005434732982	13970	3	3B
0005434732980	13970	4	6B
0005433754238	2319	1	1A
0005432984742	2319	2	1C
0005432984732	2319	3	1B
0005435982292	2319	4	1F
0005435982336	2319	5	1G
0005432226057	2319	6	1H
0005432984734	2319	7	2C
0005432869477	2319	8	2B
0005435982341	2319	9	2F
0005432869479	2319	10	2G
0005433754219	2319	11	3A
0005435982296	2319	12	2H
0005432300267	2319	13	3B
0005432984826	2319	14	3C
0005433754231	2319	15	3H
0005432869478	2319	16	3G
0005432984790	2319	17	3F
0005433764680	2319	18	4C
0005435982320	2319	19	4B
0005433434455	2319	20	4H
0005433434436	2319	21	4G
0005435982332	2319	22	4F
0005432655538	2319	23	5A
0005432984817	2319	24	5B
0005433754256	2319	25	5F
0005433754251	2319	26	5C
0005432984686	2319	27	5G
0005433754225	2319	28	9A
0005432984650	2319	29	5H
0005432300268	2319	30	9B
0005435982335	2319	31	9G
0005433754241	2319	32	11B
0005433434505	2319	33	11E
0005433754200	2319	34	11D
0005433754239	2319	35	11G
0005433754229	2319	36	11F
0005435982310	2319	37	11H
0005433754201	2319	38	12B
0005433754240	2319	39	12A
0005433754224	2319	40	12D
0005432984791	2319	41	12G
0005433754222	2319	42	13A
0005433754207	2319	43	13D
0005432300265	2319	44	13B
0005432984865	2319	45	13E
0005432655543	2319	46	13G
0005432984751	2319	47	13F
0005432984812	2319	48	13H
0005432984675	2319	49	14B
0005432984891	2319	50	14A
0005433434579	2319	51	14E
0005435982306	2319	52	14D
0005433754253	2319	53	14G
0005433754249	2319	54	14H
0005433754223	2319	55	15B
0005433766639	2319	56	15E
0005435982327	2319	57	15D
0005433754246	2319	58	15G
0005435982338	2319	59	16A
0005433754228	2319	60	15H
0005432984635	2319	61	16B
0005435982334	2319	62	16E
0005433754204	2319	63	16G
0005435982340	2319	64	16F
0005435982316	2319	65	16H
0005433754211	2319	66	17A
0005435982321	2319	67	17D
0005435982302	2319	68	17B
0005432869473	2319	69	17F
0005435982326	2319	70	17G
0005433434539	2319	71	18A
0005435982297	2319	72	17H
0005432984833	2319	73	18B
0005432984827	2319	74	18F
0005433754218	2319	75	18E
0005435982317	2319	76	18G
0005433754250	2319	77	19A
0005432984673	2319	78	19B
0005432984733	2319	79	19E
0005432300263	2319	80	19D
0005433434511	2319	81	19G
0005433754254	2319	82	20A
0005433434504	2319	83	19H
0005432226060	2319	84	20B
0005435982303	2319	85	20E
0005432655534	2319	86	20D
0005432655537	2319	87	20F
0005433754214	2319	88	20G
0005433434326	2319	89	21A
0005435982315	2319	90	21D
0005432984932	2319	91	21B
0005432869474	2319	92	21E
0005432984752	2319	93	21G
0005432655542	2319	94	21F
0005433434404	2319	95	22B
0005435982328	2319	96	22A
0005433754236	2319	97	22D
0005432655544	2319	98	22E
0005433434325	2319	99	22G
0005432300266	2319	100	22F
0005435982322	2319	101	22H
0005435982301	2319	102	23B
0005433754245	2319	103	23A
0005433754226	2319	104	23D
0005433754232	2319	105	23F
0005433434383	2319	106	23E
0005435982314	2319	107	23H
0005433754209	2319	108	23G
0005435982333	2319	109	24A
0005433434429	2319	110	24B
0005432869471	2319	111	24D
0005432226059	2319	112	24F
0005433434538	2319	113	24G
0005432984687	2319	114	25D
0005435982298	2319	115	24H
0005432300264	2319	116	25E
0005433754202	2319	117	27A
0005435982308	2319	118	25F
0005432655545	2319	119	27B
0005433754242	2319	120	27D
0005433434441	2319	121	27F
0005435982319	2319	122	27H
0005433434411	2319	123	27G
0005435982294	2319	124	28A
0005433754248	2319	125	28B
0005432655541	2319	126	28E
0005435982305	2319	127	28D
0005435982313	2319	128	28F
0005435982312	2319	129	28H
0005433754235	2319	130	29A
0005432984940	2319	131	29B
0005433754230	2319	132	29E
0005433766640	2319	133	29D
0005435982339	2319	134	29F
0005433754212	2319	135	29H
0005433754205	2319	136	29G
0005433754221	2319	137	30A
0005435982295	2319	138	30B
0005432869472	2319	139	30E
0005435982330	2319	140	30G
0005433434428	2319	141	30F
0005433754215	2319	142	31A
0005432984828	2319	143	30H
0005432655535	2319	144	31B
0005433754243	2319	145	31E
0005435982323	2319	146	31D
0005433434410	2319	147	31F
0005433754257	2319	148	31G
0005435982342	2319	149	32A
0005433754237	2319	150	31H
0005433754252	2319	151	32B
0005435982293	2319	152	32E
0005435982324	2319	153	32D
0005435982307	2319	154	32F
0005433754208	2319	155	32H
0005433754247	2319	156	32G
0005433754233	2319	157	33A
0005433766641	2319	158	33B
0005435982300	2319	159	33E
0005433754220	2319	160	33G
0005432226058	2319	161	33H
0005435982331	2319	162	34A
0005432984864	2319	163	34D
0005433434465	2319	164	34F
0005432869480	2319	165	34G
0005432984811	2319	166	35A
0005433754244	2319	167	34H
0005433434481	2319	168	35B
0005433434382	2319	169	35E
0005433754255	2319	170	35D
0005433754227	2319	171	35G
0005433754206	2319	172	36A
0005435982309	2319	173	35H
0005432655540	2319	174	36B
0005433434360	2319	175	36D
0005433754210	2319	176	36F
0005433434551	2319	177	36G
0005433754216	2319	178	37A
0005435982329	2319	179	36H
0005432984832	2319	180	37B
0005435982304	2319	181	37E
0005432655536	2319	182	37D
0005433754203	2319	183	37G
0005435982311	2319	184	37F
0005435982337	2319	185	38A
0005435982299	2319	186	38D
0005432655539	2319	187	38B
0005435982325	2319	188	38E
0005432984831	2319	189	38G
0005435982318	2319	190	38F
0005433754234	2319	191	38H
0005433754217	2319	192	39E
0005433766638	2319	193	39D
0005433754213	2319	194	39F
0005433753517	26209	1	1A
0005435981860	26209	2	1C
0005432655371	26209	3	1B
0005435981884	26209	4	1F
0005432655469	26209	5	1G
0005433434671	26209	6	1H
0005432655393	26209	7	2B
0005435981845	26209	8	2A
0005433753741	26209	9	2F
0005433434669	26209	10	2C
0005432985090	26209	11	2G
0005433434697	26209	12	3C
0005432985069	26209	13	3B
0005433434676	26209	14	3H
0005435981885	26209	15	3G
0005433434686	26209	16	4A
0005432869521	26209	17	4B
0005435981750	26209	18	4F
0005435981867	26209	19	4C
0005432985077	26209	20	4H
0005435981749	26209	21	5B
0005433753842	26209	22	5A
0005432049464	26209	23	5C
0005435981882	26209	24	5F
0005433753545	26209	25	5H
0005433434682	26209	26	9B
0005432985083	26209	27	9A
0005432655390	26209	28	9G
0005434731171	26209	29	11A
0005433753764	26209	30	9H
0005433434672	26209	31	11B
0005432655452	26209	32	11D
0005433753657	26209	33	11F
0005433434683	26209	34	11E
0005432655419	26209	35	11H
0005433753825	26209	36	11G
0005433434685	26209	37	12A
0005432985068	26209	38	12D
0005433753822	26209	39	12B
0005432985073	26209	40	12E
0005432985091	26209	41	12F
0005434731170	26209	42	12G
0005432655470	26209	43	13A
0005432985088	26209	44	13D
0005433753852	26209	45	13B
0005435981866	26209	46	13E
0005432869523	26209	47	13G
0005432655361	26209	48	13F
0005433753846	26209	49	14A
0005433753707	26209	50	13H
0005433753675	26209	51	14D
0005433753774	26209	52	14B
0005432985082	26209	53	14F
0005433753894	26209	54	14E
0005433753668	26209	55	14G
0005435981969	26209	56	15A
0005433753809	26209	57	15E
0005433753572	26209	58	15D
0005432655394	26209	59	16A
0005433753839	26209	60	15H
0005432985089	26209	61	16D
0005435981676	26209	62	16B
0005432985093	26209	63	16E
0005433434688	26209	64	16G
0005433753920	26209	65	16F
0005435981910	26209	66	16H
0005433753796	26209	67	17A
0005433434679	26209	68	17D
0005433753738	26209	69	17F
0005433434696	26209	70	17E
0005432051129	26209	71	17H
0005432985078	26209	72	17G
0005433434677	26209	73	18B
0005433754001	26209	74	18A
0005432985074	26209	75	18E
0005435981970	26209	76	18D
0005432985071	26209	77	18G
0005432869522	26209	78	18F
0005433753837	26209	79	19A
0005435981905	26209	80	19B
0005433434673	26209	81	19D
0005433753570	26209	82	19F
0005433753618	26209	83	19E
0005433764661	26209	84	20A
0005432049465	26209	85	19H
0005435981917	26209	86	20D
0005432051128	26209	87	20E
0005433753565	26209	88	20G
0005433753679	26209	89	20F
0005435981899	26209	90	21A
0005435981615	26209	91	20H
0005433434684	26209	92	21B
0005433434670	26209	93	21E
0005432985081	26209	94	21G
0005435982037	26209	95	21F
0005432655360	26209	96	21H
0005435982002	26209	97	22A
0005433753735	26209	98	22D
0005432655418	26209	99	22B
0005433753737	26209	100	22F
0005435981713	26209	101	22E
0005433753656	26209	102	22G
0005433434680	26209	103	23B
0005432985070	26209	104	23A
0005433434674	26209	105	23D
0005433753876	26209	106	23F
0005435981918	26209	107	23E
0005433753885	26209	108	23G
0005432869524	26209	109	23H
0005435981953	26209	110	24B
0005433753629	26209	111	24A
0005432985085	26209	112	24D
0005433753674	26209	113	24F
0005432869525	26209	114	24G
0005432985084	26209	115	25D
0005432655432	26209	116	24H
0005433753740	26209	117	25F
0005435981861	26209	118	25E
0005433753867	26209	119	27A
0005433753975	26209	120	27B
0005432655430	26209	121	27E
0005433434695	26209	122	27D
0005432985075	26209	123	27F
0005435981881	26209	124	27G
0005433434678	26209	125	28D
0005432869520	26209	126	28B
0005432049463	26209	127	28E
0005435981906	26209	128	28F
0005433434690	26209	129	28H
0005433434689	26209	130	28G
0005433753877	26209	131	29D
0005432985086	26209	132	29B
0005433753725	26209	133	29E
0005432655417	26209	134	29F
0005435981924	26209	135	29G
0005433766612	26209	136	30B
0005435981979	26209	137	30A
0005433434691	26209	138	30E
0005435981809	26209	139	30D
0005432051127	26209	140	30F
0005432985072	26209	141	30G
0005433753678	26209	142	31A
0005433753638	26209	143	30H
0005435981616	26209	144	31B
0005433753630	26209	145	31E
0005433753663	26209	146	31D
0005432985067	26209	147	31F
0005432655362	26209	148	31G
0005432985094	26209	149	32A
0005434731172	26209	150	32B
0005435981894	26209	151	32E
0005435981904	26209	152	32F
0005432985079	26209	153	32G
0005432985087	26209	154	33B
0005433434675	26209	155	33A
0005433753560	26209	156	32H
0005432655431	26209	157	33D
0005433434693	26209	158	33H
0005435981850	26209	159	33G
0005433434692	26209	160	34B
0005434731173	26209	161	34A
0005433434694	26209	162	34D
0005433764660	26209	163	34E
0005432985096	26209	164	34G
0005433753827	26209	165	34F
0005433753742	26209	166	34H
0005435981949	26209	167	35B
0005433753710	26209	168	35A
0005433753739	26209	169	35E
0005435981925	26209	170	35F
0005435981849	26209	171	35G
0005433753658	26209	172	36A
0005432655370	26209	173	35H
0005433434681	26209	174	36D
0005435981903	26209	175	36F
0005432985080	26209	176	36E
0005435981954	26209	177	36H
0005435981973	26209	178	37D
0005432985066	26209	179	37B
0005435981859	26209	180	37E
0005433753856	26209	181	37F
0005434731169	26209	182	37H
0005432655406	26209	183	37G
0005432049462	26209	184	38A
0005435981810	26209	185	38B
0005432869519	26209	186	38E
0005432655405	26209	187	38D
0005432985095	26209	188	38G
0005435981900	26209	189	38F
0005433434687	26209	190	38H
0005432985092	26209	191	39F
0005432985076	26209	192	39E
0005434374652	1525	1	1C
0005433151167	1525	2	1D
0005434374658	1525	3	1F
0005434374669	1525	4	2C
0005434374664	1525	5	2D
0005434374646	1525	6	2F
0005432267893	1525	7	3C
0005433460437	1525	8	3A
0005434374654	1525	9	3D
0005434374657	1525	10	5A
0005434374651	1525	11	4F
0005434374661	1525	12	5B
0005433151230	1525	13	5D
0005434374662	1525	14	5E
0005434374648	1525	15	6A
0005432267899	1525	16	6B
0005434374638	1525	17	6F
0005433151202	1525	18	6E
0005432267895	1525	19	7A
0005434374667	1525	20	7C
0005433461589	1525	21	7E
0005434029627	1525	22	7D
0005432267898	1525	23	8C
0005434374653	1525	24	8E
0005433150912	1525	25	8F
0005434374647	1525	26	9B
0005433931436	1525	27	9D
0005432267897	1525	28	9C
0005434029639	1525	29	9F
0005434374655	1525	30	10C
0005433151228	1525	31	10B
0005433151133	1525	32	10D
0005434374665	1525	33	11A
0005434029640	1525	34	11D
0005434374663	1525	35	11E
0005433151045	1525	36	11F
0005434374649	1525	37	12B
0005433461588	1525	38	12C
0005434374670	1525	39	12E
0005434374645	1525	40	12F
0005432267900	1525	41	13B
0005433764655	1525	42	13A
0005433460436	1525	43	13C
0005434374671	1525	44	13D
0005433151039	1525	45	13E
0005434374675	1525	46	13F
0005434374642	1525	47	14C
0005434374666	1525	48	14B
0005433151229	1525	49	14E
0005434374660	1525	50	15A
0005433151234	1525	51	14F
0005433151168	1525	52	15D
0005433151182	1525	53	15E
0005434376224	1525	54	16B
0005434374644	1525	55	16C
0005434374637	1525	56	16E
0005432267894	1525	57	16D
0005433461590	1525	58	16F
0005434374676	1525	59	17A
0005434029638	1525	60	17D
0005434374634	1525	61	17C
0005433151185	1525	62	17E
0005434374656	1525	63	17F
0005433151143	1525	64	18A
0005433151123	1525	65	18B
0005434374641	1525	66	18C
0005434374650	1525	67	18F
0005434374640	1525	68	19D
0005434374659	1525	69	19C
0005433151134	1525	70	19F
0005433151124	1525	71	20A
0005434374674	1525	72	20C
0005433460435	1525	73	20B
0005434374639	1525	74	20D
0005434374672	1525	75	20E
0005434374636	1525	76	20F
0005432267896	1525	77	21E
0005434374673	1525	78	22A
0005433151100	1525	79	22C
0005434376223	1525	80	22F
0005433151233	1525	81	22E
0005434374635	1525	82	23A
0005434374668	1525	83	23C
0005434374643	1525	84	23F
0005434373970	20140	1	1C
0005433151423	20140	2	1A
0005434374199	20140	3	1F
0005434374432	20140	4	1D
0005433931465	20140	5	2A
0005432056300	20140	6	2D
0005434374431	20140	7	2C
0005434374302	20140	8	2F
0005434374414	20140	9	4A
0005433151415	20140	10	3F
0005433151412	20140	11	3D
0005434374422	20140	12	4B
0005434374403	20140	13	4D
0005433151409	20140	14	4C
0005434374267	20140	15	4E
0005434374200	20140	16	4F
0005433151397	20140	17	5B
0005434374210	20140	18	5D
0005433931467	20140	19	5F
0005433151399	20140	20	5E
0005433151408	20140	21	6A
0005434374201	20140	22	6B
0005434374434	20140	23	6C
0005434374336	20140	24	6D
0005434029657	20140	25	6E
0005433151406	20140	26	7A
0005434374270	20140	27	7B
0005434374202	20140	28	7C
0005433151413	20140	29	7D
0005434374142	20140	30	7E
0005433151419	20140	31	8B
0005434374237	20140	32	8E
0005433151418	20140	33	8D
0005434374433	20140	34	8F
0005434029658	20140	35	9A
0005434374173	20140	36	9C
0005434374399	20140	37	9B
0005434374301	20140	38	9E
0005433151402	20140	39	9F
0005433764680	20140	40	10B
0005433151410	20140	41	10C
0005434374335	20140	42	11A
0005433151421	20140	43	11C
0005434374221	20140	44	11B
0005434374209	20140	45	11E
0005434374110	20140	46	11D
0005433151391	20140	47	11F
0005433151416	20140	48	12A
0005433151401	20140	49	12B
0005434374185	20140	50	12C
0005434374220	20140	51	12D
0005434374421	20140	52	12F
0005433151417	20140	53	13B
0005434374385	20140	54	13C
0005432056297	20140	55	13E
0005433151407	20140	56	14B
0005434374288	20140	57	14D
0005433931464	20140	58	14C
0005434374179	20140	59	14E
0005432056298	20140	60	15A
0005432056299	20140	61	14F
0005434374271	20140	62	15C
0005433931466	20140	63	15B
0005434374143	20140	64	15F
0005434374266	20140	65	16B
0005433151393	20140	66	16A
0005433151424	20140	67	16C
0005434374257	20140	68	16D
0005434374430	20140	69	16E
0005433151392	20140	70	17B
0005433151405	20140	71	17E
0005434374435	20140	72	17D
0005433151394	20140	73	17F
0005434374389	20140	74	18A
0005434374368	20140	75	18B
0005434374243	20140	76	18D
0005434374141	20140	77	18E
0005434374236	20140	78	18F
0005434374390	20140	79	19A
0005433151425	20140	80	19C
0005434374337	20140	81	19B
0005434374122	20140	82	19E
0005434374436	20140	83	19F
0005433151396	20140	84	20A
0005433151400	20140	85	20C
0005433151398	20140	86	20E
0005433151404	20140	87	20F
0005434374273	20140	88	21B
0005434374213	20140	89	21D
0005433151395	20140	90	21C
0005434374123	20140	91	21E
0005433151403	20140	92	22B
0005433151420	20140	93	22D
0005434374269	20140	94	22E
0005433151414	20140	95	23A
0005434374140	20140	96	22F
0005434374268	20140	97	23B
0005433151411	20140	98	23D
0005433151422	20140	99	23F
0005432424462	516	1	2A
0005432282868	516	2	2C
0005432424425	516	3	3A
0005432424443	516	4	3F
0005432424448	516	5	5F
0005432424442	516	6	6F
0005432424445	516	7	7F
0005432424430	516	8	8A
0005432424457	516	9	8D
0005432424451	516	10	9A
0005432424436	516	11	10C
0005432424431	516	12	10E
0005432282865	516	13	11C
0005432424422	516	14	11E
0005432424452	516	15	12D
0005432424435	516	16	12E
0005432424459	516	17	13B
0005432424438	516	18	13D
0005432424453	516	19	13E
0005432424424	516	20	14C
0005432424440	516	21	15A
0005432424429	516	22	16C
0005432282866	516	23	16D
0005432424460	516	24	17C
0005432424456	516	25	18C
0005432282861	516	26	18B
0005432424428	516	27	20D
0005432424434	516	28	21A
0005432424454	516	29	21E
0005432424427	516	30	22E
0005432424455	516	31	22D
0005432282864	516	32	23B
0005432424433	516	33	23A
0005432424423	516	34	23F
0005432424446	516	35	24B
0005432282867	516	36	24A
0005432424450	516	37	24E
0005432424444	516	38	24D
0005432424426	516	39	25B
0005432282862	516	40	25F
0005432424439	516	41	26E
0005432424432	516	42	27A
0005432424437	516	43	28A
0005432424447	516	44	27F
0005432282863	516	45	28B
0005432424441	516	46	28E
0005432424458	516	47	29F
0005432424461	516	48	31D
0005432424449	516	49	31F
0005432302329	12870	1	1A
0005432302331	12870	2	2F
0005432302332	12870	3	20E
0005432302330	12870	4	26D
0005432424019	12826	1	2C
0005432423957	12826	2	4F
0005432424040	12826	3	6A
0005432424031	12826	4	6C
0005432423968	12826	5	6D
0005432423983	12826	6	7A
0005432424055	12826	7	7D
0005432423982	12826	8	9C
0005432424046	12826	9	9B
0005432423901	12826	10	9D
0005432423909	12826	11	9F
0005432424030	12826	12	10C
0005432424013	12826	13	10E
0005432423963	12826	14	11C
0005432423977	12826	15	11F
0005432424053	12826	16	12A
0005432423962	12826	17	12D
0005432423994	12826	18	12E
0005432424005	12826	19	13B
0005432423896	12826	20	13E
0005432423903	12826	21	14E
0005432423981	12826	22	15C
0005432424011	12826	23	15D
0005432424039	12826	24	16D
0005432423900	12826	25	18A
0005432423964	12826	26	19B
0005432423902	12826	27	19E
0005432424026	12826	28	20A
0005432424025	12826	29	20C
0005432423958	12826	30	20F
0005432423955	12826	31	21A
0005432424054	12826	32	21B
0005432424008	12826	33	22E
0005432424006	12826	34	23C
0005432423938	12826	35	24B
0005432423978	12826	36	25A
0005432423943	12826	37	28D
0005432424047	12826	38	28E
0005432424022	12826	39	31A
0005434735616	434	1	1A
0005432235635	434	2	1G
0005433057504	434	3	2A
0005432045612	434	4	2C
0005433057599	434	5	2G
0005434023734	434	6	3A
0005434023700	434	7	2H
0005433057489	434	8	3B
0005433057610	434	9	3G
0005434023722	434	10	4A
0005434023703	434	11	3H
0005433057667	434	12	4F
0005434023749	434	13	4C
0005434029656	434	14	4G
0005433057637	434	15	4H
0005434023729	434	16	5B
0005433057602	434	17	5A
0005433057636	434	18	5C
0005434023724	434	19	5G
0005434023738	434	20	5H
0005434023714	434	21	9B
0005433057631	434	22	9A
0005434023696	434	23	9G
0005434032020	434	24	11A
0005433684400	434	25	11D
0005433057611	434	26	11F
0005434023725	434	27	11E
0005434023748	434	28	11H
0005433929573	434	29	11G
0005434023704	434	30	12E
0005434023715	434	31	12D
0005434023728	434	32	12G
0005434029655	434	33	12F
0005434735615	434	34	12H
0005433684406	434	35	13D
0005434023732	434	36	13B
0005434023710	434	37	13F
0005434023687	434	38	13E
0005434023680	434	39	13H
0005434023716	434	40	14E
0005434023723	434	41	14D
0005433057531	434	42	14F
0005434023708	434	43	14G
0005434023731	434	44	15A
0005433057573	434	45	14H
0005434023739	434	46	15E
0005434023688	434	47	15D
0005434023695	434	48	15F
0005434023721	434	49	16B
0005433057596	434	50	15H
0005433057436	434	51	16D
0005433057739	434	52	16E
0005434023737	434	53	17A
0005434023744	434	54	17B
0005433057503	434	55	17D
0005433057561	434	56	17E
0005433057674	434	57	18A
0005434023681	434	58	18D
0005434023730	434	59	18E
0005434735630	434	60	18F
0005433057612	434	61	18H
0005433057587	434	62	19B
0005434023705	434	63	19G
0005434023701	434	64	20A
0005433057511	434	65	20D
0005432235640	434	66	20B
0005434735621	434	67	20F
0005434023718	434	68	20H
0005434023747	434	69	21E
0005434023746	434	70	21D
0005433057372	434	71	21G
0005434023713	434	72	21F
0005434029654	434	73	21H
0005434023691	434	74	22B
0005434023743	434	75	22E
0005434023720	434	76	22H
0005434023707	434	77	23A
0005433057500	434	78	23F
0005434023726	434	79	23E
0005434023717	434	80	23G
0005433057530	434	81	24E
0005434023742	434	82	24G
0005434735617	434	83	25E
0005434023682	434	84	25D
0005433057537	434	85	25F
0005433057393	434	86	27B
0005433057485	434	87	27E
0005434023711	434	88	27G
0005434023689	434	89	28D
0005434023684	434	90	28B
0005434032019	434	91	28E
0005433057650	434	92	28F
0005434023690	434	93	28H
0005434023740	434	94	29A
0005434023697	434	95	29B
0005433684403	434	96	29E
0005434023706	434	97	29F
0005433057486	434	98	29H
0005432045611	434	99	30A
0005434023683	434	100	30G
0005433057638	434	101	31A
0005432235636	434	102	31B
0005434023719	434	103	31D
0005433057373	434	104	31G
0005433057524	434	105	31H
0005434023686	434	106	32B
0005433929574	434	107	32E
0005434735641	434	108	32D
0005433057509	434	109	32F
0005433057507	434	110	33A
0005432235641	434	111	32H
0005433057675	434	112	33D
0005433057603	434	113	33E
0005434023709	434	114	33H
0005434023727	434	115	34A
0005434023699	434	116	34D
0005433057598	434	117	34F
0005432235638	434	118	34G
0005434032021	434	119	34H
0005433929588	434	120	35A
0005434023698	434	121	35D
0005434023685	434	122	35E
0005434032022	434	123	35H
0005434023693	434	124	35G
0005433057562	434	125	35F
0005434023692	434	126	36D
0005434023745	434	127	36F
0005432235642	434	128	36E
0005434023712	434	129	36H
0005434023736	434	130	36G
0005434023735	434	131	37B
0005432235639	434	132	37F
0005434023694	434	133	37H
0005434023702	434	134	38D
0005434023741	434	135	38E
0005434735622	434	136	38H
0005432235637	434	137	38G
0005434023733	434	138	39F
0005434023139	12652	1	1A
0005433057875	12652	2	1C
0005433929614	12652	3	1H
0005434023046	12652	4	2A
0005432156364	12652	5	2F
0005434023037	12652	6	3F
0005434023256	12652	7	3G
0005433057907	12652	8	3H
0005433057906	12652	9	4B
0005434031982	12652	10	4F
0005433929612	12652	11	4G
0005433057893	12652	12	5B
0005434023111	12652	13	5C
0005434022930	12652	14	5G
0005434023155	12652	15	9A
0005433057897	12652	16	9H
0005433057888	12652	17	9G
0005434023022	12652	18	11D
0005432157492	12652	19	11H
0005434023066	12652	20	12A
0005434031983	12652	21	12B
0005434022898	12652	22	12E
0005433057891	12652	23	12H
0005434023251	12652	24	12G
0005433057881	12652	25	13A
0005434022980	12652	26	13D
0005434022954	12652	27	13B
0005434029640	12652	28	13F
0005434735689	12652	29	14A
0005433057884	12652	30	14E
0005434023156	12652	31	14F
0005434029638	12652	32	14H
0005434023307	12652	33	14G
0005434022831	12652	34	15E
0005434023178	12652	35	15D
0005433057885	12652	36	15F
0005434029639	12652	37	15H
0005434023031	12652	38	16D
0005434023053	12652	39	16E
0005433057901	12652	40	16F
0005433057896	12652	41	16H
0005433057899	12652	42	17A
0005434023313	12652	43	17D
0005432156366	12652	44	17E
0005433057870	12652	45	17G
0005432156365	12652	46	17F
0005434023266	12652	47	18A
0005433929615	12652	48	17H
0005433057903	12652	49	18E
0005434023169	12652	50	18D
0005433057877	12652	51	18F
0005433057900	12652	52	18G
0005434376223	12652	53	19A
0005433057886	12652	54	19B
0005434023225	12652	55	19D
0005433057902	12652	56	19E
0005434023143	12652	57	19H
0005433057898	12652	58	19G
0005434023394	12652	59	20B
0005434023057	12652	60	20E
0005434028275	12652	61	20F
0005434735688	12652	62	21A
0005433057879	12652	63	21E
0005433057874	12652	64	21D
0005434022955	12652	65	21G
0005434735691	12652	66	22A
0005433057905	12652	67	22B
0005432157491	12652	68	22E
0005433057873	12652	69	22G
0005433057876	12652	70	23A
0005434022932	12652	71	23B
0005433057887	12652	72	23G
0005434022999	12652	73	24B
0005434023095	12652	74	24A
0005434022978	12652	75	24F
0005434023190	12652	76	25E
0005434023065	12652	77	27B
0005434023297	12652	78	27D
0005433057869	12652	79	27F
0005433057882	12652	80	28A
0005433057878	12652	81	28B
0005434023395	12652	82	28E
0005433057883	12652	83	28H
0005434023149	12652	84	28G
0005433057889	12652	85	29D
0005433929611	12652	86	29B
0005434022988	12652	87	30A
0005433057872	12652	88	29G
0005434023191	12652	89	30B
0005434023308	12652	90	30E
0005434023052	12652	91	30D
0005434023103	12652	92	30G
0005434022917	12652	93	30F
0005434023047	12652	94	31D
0005433057895	12652	95	31F
0005433057894	12652	96	31H
0005434023153	12652	97	32D
0005433057871	12652	98	32B
0005434023054	12652	99	32F
0005434023447	12652	100	32H
0005434735690	12652	101	33B
0005434023213	12652	102	33E
0005434022928	12652	103	34A
0005434023296	12652	104	34D
0005434029627	12652	105	34E
0005433057880	12652	106	35A
0005434735692	12652	107	34G
0005434022850	12652	108	35B
0005433057892	12652	109	36A
0005433684421	12652	110	36D
0005434023113	12652	111	36F
0005432156367	12652	112	37B
0005434376224	12652	113	37A
0005433057890	12652	114	37E
0005434022931	12652	115	37D
0005434023067	12652	116	37G
0005433057904	12652	117	38A
0005434023257	12652	118	37H
0005434023192	12652	119	38B
0005434023304	12652	120	38F
0005433929613	12652	121	38E
0005434031981	12652	122	38H
0005434028261	12652	123	39D
0005433057868	12652	124	39E
0005433529270	13811	1	1C
0005433527263	13811	2	1A
0005433529276	13811	3	3F
0005433527262	13811	4	5A
0005433529268	13811	5	5F
0005433527257	13811	6	5D
0005433529271	13811	7	7B
0005433529265	13811	8	7E
0005433529275	13811	9	9F
0005433529267	13811	10	11E
0005433527264	13811	11	12E
0005433527256	13811	12	13A
0005433529272	13811	13	12F
0005433529266	13811	14	13E
0005433527255	13811	15	13F
0005433527254	13811	16	15A
0005433527259	13811	17	15D
0005433527258	13811	18	16E
0005433527261	13811	19	17C
0005433527260	13811	20	18D
0005433529274	13811	21	19B
0005433529273	13811	22	19D
0005433529269	13811	23	20D
0005433533288	32440	1	2D
0005433533289	32440	2	3A
0005433529236	32440	3	3D
0005433529229	32440	4	6C
0005433533263	32440	5	7B
0005433533267	32440	6	7D
0005433533271	32440	7	9A
0005433533269	32440	8	10E
0005433529239	32440	9	11D
0005433533281	32440	10	12A
0005433533256	32440	11	12E
0005433533264	32440	12	13C
0005433529228	32440	13	14E
0005433533282	32440	14	15A
0005433529223	32440	15	16D
0005433533268	32440	16	17A
0005433533266	32440	17	16E
0005433533255	32440	18	17D
0005433529231	32440	19	17C
0005433529240	32440	20	18D
0005433529235	32440	21	21A
0005433529241	32440	22	21C
0005433529224	32440	23	21D
0005433923319	2126	1	1C
0005432231565	2126	2	1G
0005433923309	2126	3	2A
0005433923278	2126	4	1H
0005433923283	2126	5	2B
0005433923258	2126	6	2C
0005433035628	2126	7	2G
0005433923352	2126	8	3A
0005433923287	2126	9	2H
0005433035856	2126	10	3C
0005433035875	2126	11	3H
0005433923321	2126	12	3G
0005433923333	2126	13	4B
0005433923337	2126	14	4C
0005433035754	2126	15	4G
0005433923296	2126	16	5A
0005433923267	2126	17	4H
0005433035908	2126	18	5B
0005433923268	2126	19	5C
0005432231569	2126	20	5G
0005432044525	2126	21	5F
0005433923346	2126	22	5H
0005433923331	2126	23	9A
0005433923347	2126	24	9G
0005433931466	2126	25	11A
0005433923284	2126	26	11B
0005433035535	2126	27	11E
0005433923274	2126	28	11F
0005433923262	2126	29	11H
0005433923313	2126	30	11G
0005433923270	2126	31	12A
0005433923290	2126	32	12B
0005433923314	2126	33	12E
0005433929613	2126	34	12G
0005433035853	2126	35	13B
0005433923272	2126	36	13A
0005433923257	2126	37	13D
0005432231570	2126	38	14E
0005433923298	2126	39	14D
0005433923323	2126	40	15A
0005433923311	2126	41	14H
0005432231562	2126	42	15B
0005432044523	2126	43	15E
0005433923327	2126	44	15G
0005433923299	2126	45	15F
0005433923324	2126	46	15H
0005433923326	2126	47	16A
0005433923293	2126	48	16D
0005433929614	2126	49	16B
0005433923307	2126	50	16E
0005433035534	2126	51	16F
0005433923328	2126	52	16H
0005433035854	2126	53	17D
0005433923348	2126	54	17B
0005433923300	2126	55	17F
0005433035965	2126	56	17G
0005433035835	2126	57	18A
0005433923338	2126	58	17H
0005433923302	2126	59	18B
0005433923280	2126	60	18E
0005433923285	2126	61	18F
0005433923292	2126	62	18G
0005432749753	2126	63	19B
0005433923259	2126	64	19D
0005433923261	2126	65	19F
0005433931464	2126	66	19E
0005432231563	2126	67	19G
0005433035889	2126	68	20B
0005433035834	2126	69	20E
0005433923297	2126	70	20D
0005433923349	2126	71	20F
0005433923318	2126	72	20G
0005432231567	2126	73	21A
0005433923277	2126	74	20H
0005433923305	2126	75	21D
0005433923303	2126	76	21B
0005433923276	2126	77	21F
0005433923334	2126	78	22A
0005432231568	2126	79	21H
0005432231566	2126	80	22B
0005433923315	2126	81	22D
0005433035888	2126	82	22F
0005433035686	2126	83	22E
0005433923316	2126	84	22G
0005433923320	2126	85	23A
0005433035881	2126	86	23B
0005433035874	2126	87	23F
0005433923291	2126	88	23E
0005433923312	2126	89	23G
0005433923329	2126	90	23H
0005433923344	2126	91	24A
0005433923330	2126	92	24F
0005433923306	2126	93	24G
0005433923281	2126	94	25D
0005433923263	2126	95	24H
0005433923275	2126	96	25E
0005433923286	2126	97	27A
0005433923336	2126	98	25F
0005433035837	2126	99	27B
0005433875377	2126	100	27F
0005432231564	2126	101	27E
0005433923260	2126	102	27H
0005433923308	2126	103	27G
0005433035809	2126	104	28A
0005434028275	2126	105	28B
0005433923269	2126	106	28E
0005433929611	2126	107	28F
0005433923317	2126	108	28G
0005433923304	2126	109	29A
0005432044524	2126	110	28H
0005433923301	2126	111	29B
0005433035753	2126	112	29E
0005433923279	2126	113	29G
0005433035755	2126	114	29H
0005432749767	2126	115	30B
0005433035663	2126	116	30A
0005433923282	2126	117	30E
0005433923271	2126	118	30G
0005433923264	2126	119	30F
0005433035627	2126	120	31A
0005433923343	2126	121	30H
0005433035993	2126	122	31B
0005433923289	2126	123	31F
0005433035873	2126	124	31E
0005433923345	2126	125	31H
0005433923273	2126	126	32A
0005433929612	2126	127	32B
0005433035855	2126	128	32D
0005433923341	2126	129	32F
0005433923325	2126	130	32E
0005433923294	2126	131	32H
0005433931465	2126	132	32G
0005433923295	2126	133	33A
0005434028261	2126	134	33B
0005433035716	2126	135	33G
0005433923310	2126	136	33E
0005433923265	2126	137	33H
0005433035680	2126	138	34B
0005433923322	2126	139	34A
0005433931467	2126	140	34D
0005433035717	2126	141	34G
0005433923332	2126	142	34F
0005433923340	2126	143	35A
0005433035887	2126	144	34H
0005432231561	2126	145	35D
0005433035757	2126	146	35E
0005432231560	2126	147	35G
0005433035782	2126	148	35H
0005433035972	2126	149	36B
0005433923351	2126	150	36E
0005433923335	2126	151	36D
0005433035903	2126	152	36F
0005433923288	2126	153	36G
0005433923353	2126	154	37B
0005433923339	2126	155	37A
0005433035691	2126	156	37E
0005433923266	2126	157	37F
0005433923342	2126	158	37H
0005433035838	2126	159	37G
0005433923256	2126	160	38A
0005433035603	2126	161	38E
0005433035980	2126	162	38D
0005433036044	2126	163	38F
0005433929615	2126	164	38H
0005433923350	2126	165	39F
0005433922459	24093	1	1A
0005433036284	24093	2	1H
0005432749784	24093	3	1G
0005433036314	24093	4	2A
0005433922349	24093	5	2B
0005433036318	24093	6	2C
0005433922495	24093	7	2G
0005433922620	24093	8	3A
0005433036324	24093	9	3F
0005433922492	24093	10	3C
0005433036325	24093	11	3H
0005432749785	24093	12	3G
0005433922612	24093	13	4B
0005432206196	24093	14	4A
0005433922187	24093	15	4F
0005433036285	24093	16	4H
0005433922301	24093	17	5B
0005433922867	24093	18	5F
0005433929590	24093	19	5C
0005433036288	24093	20	5G
0005433922455	24093	21	9A
0005433922789	24093	22	5H
0005433922434	24093	23	9B
0005432207663	24093	24	9G
0005432206198	24093	25	11A
0005433036319	24093	26	11F
0005433922618	24093	27	11E
0005433036327	24093	28	12A
0005433922432	24093	29	11H
0005433922243	24093	30	12B
0005433922085	24093	31	12E
0005433036306	24093	32	12H
0005433036323	24093	33	12G
0005433922166	24093	34	13D
0005434028297	24093	35	13E
0005433036293	24093	36	13F
0005432206194	24093	37	13H
0005433922500	24093	38	13G
0005433922982	24093	39	14D
0005433922598	24093	40	14B
0005433922195	24093	41	14G
0005433922795	24093	42	14F
0005433922491	24093	43	14H
0005433929575	24093	44	15D
0005433036310	24093	45	15G
0005433036298	24093	46	16A
0005433921940	24093	47	16D
0005433922733	24093	48	16B
0005434028295	24093	49	16E
0005433036302	24093	50	16G
0005433922447	24093	51	16F
0005433922433	24093	52	16H
0005433922446	24093	53	17B
0005433036305	24093	54	17G
0005433036280	24093	55	17F
0005433922414	24093	56	18A
0005433922405	24093	57	17H
0005433036307	24093	58	18B
0005433036296	24093	59	18D
0005433922603	24093	60	18E
0005433931452	24093	61	18G
0005433922898	24093	62	18F
0005433922431	24093	63	18H
0005433931433	24093	64	19B
0005433922547	24093	65	19E
0005433036276	24093	66	19G
0005433036282	24093	67	19F
0005433922617	24093	68	20A
0005433929568	24093	69	19H
0005433036312	24093	70	20D
0005433922123	24093	71	20B
0005433922242	24093	72	20G
0005433922659	24093	73	20F
0005433929576	24093	74	20E
0005433036299	24093	75	21B
0005433922284	24093	76	21E
0005433922981	24093	77	21G
0005433922279	24093	78	21F
0005434028296	24093	79	22D
0005433929577	24093	80	22B
0005433036295	24093	81	22G
0005433036297	24093	82	22H
0005433036289	24093	83	23B
0005433036304	24093	84	23D
0005433036311	24093	85	23F
0005433036278	24093	86	23G
0005433036321	24093	87	24A
0005433922194	24093	88	23H
0005432206197	24093	89	24B
0005433036287	24093	90	24E
0005433036290	24093	91	24F
0005433923058	24093	92	25D
0005433922658	24093	93	24H
0005433922343	24093	94	25E
0005433922747	24093	95	27A
0005433922712	24093	96	27D
0005433036286	24093	97	27F
0005433036315	24093	98	28A
0005433922502	24093	99	27H
0005433922436	24093	100	28D
0005433922623	24093	101	28B
0005433036309	24093	102	28E
0005433922616	24093	103	28H
0005433036301	24093	104	29A
0005433922656	24093	105	29B
0005433922319	24093	106	29E
0005433036320	24093	107	29G
0005433036281	24093	108	29F
0005433922746	24093	109	30A
0005433036316	24093	110	30D
0005433922619	24093	111	30F
0005433036303	24093	112	30G
0005433922375	24093	113	30H
0005433931451	24093	114	31B
0005432207662	24093	115	31A
0005432749786	24093	116	31E
0005433922788	24093	117	31D
0005433036313	24093	118	31F
0005433922292	24093	119	32A
0005433922124	24093	120	31H
0005433036328	24093	121	32D
0005433922832	24093	122	32B
0005433922418	24093	123	32E
0005433922348	24093	124	32H
0005433036294	24093	125	32G
0005433036317	24093	126	33A
0005432206193	24093	127	33B
0005433922507	24093	128	33E
0005433036274	24093	129	33D
0005433922572	24093	130	33G
0005433922622	24093	131	33H
0005433922408	24093	132	34A
0005432206195	24093	133	34D
0005433923059	24093	134	34E
0005433036283	24093	135	34F
0005433922454	24093	136	34H
0005433036322	24093	137	35D
0005433036275	24093	138	35F
0005433922086	24093	139	35G
0005433922606	24093	140	36A
0005433922287	24093	141	36B
0005433036291	24093	142	36D
0005433036326	24093	143	36E
0005433921913	24093	144	36G
0005433922573	24093	145	36H
0005433922637	24093	146	37B
0005433922724	24093	147	37D
0005433036308	24093	148	37F
0005433036277	24093	149	37E
0005433036300	24093	150	38B
0005433036292	24093	151	37H
0005433922651	24093	152	38D
0005433922490	24093	153	38E
0005433036279	24093	154	38F
0005433922288	24093	155	38G
0005433922511	24093	156	39F
0005432207661	24093	157	39E
0005433131674	250	1	1D
0005435142579	250	2	1C
0005434725489	250	3	1A
0005433233283	250	4	1G
0005434031962	250	5	2A
0005435142578	250	6	1K
0005434725527	250	7	2D
0005434725418	250	8	2C
0005434735684	250	9	2H
0005433289802	250	10	3A
0005434725462	250	11	2K
0005434551255	250	12	3G
0005434725491	250	13	3D
0005433233856	250	14	3C
0005433233803	250	15	3K
0005435142571	250	16	3H
0005434302459	250	17	4C
0005434725485	250	18	4A
0005433233450	250	19	4G
0005434725524	250	20	4D
0005434551222	250	21	4K
0005434725514	250	22	4H
0005434302458	250	23	5C
0005433180871	250	24	5A
0005434725496	250	25	5G
0005434725484	250	26	11A
0005434725530	250	27	5K
0005434725478	250	28	11D
0005434725517	250	29	11C
0005434551266	250	30	11F
0005433180842	250	31	11E
0005434551257	250	32	11H
0005433233471	250	33	11G
0005434725532	250	34	12C
0005434735685	250	35	12A
0005433126782	250	36	11K
0005433126818	250	37	12E
0005433180795	250	38	12D
0005434551221	250	39	12G
0005434551218	250	40	12F
0005433233711	250	41	12K
0005433180863	250	42	13C
0005433111472	250	43	13A
0005433180812	250	44	13F
0005433233808	250	45	13E
0005433233900	250	46	13D
0005434725449	250	47	13H
0005434725494	250	48	13G
0005433233641	250	49	14A
0005434725463	250	50	13K
0005433233787	250	51	14D
0005434551226	250	52	14C
0005434725512	250	53	14G
0005433233902	250	54	14F
0005435142582	250	55	14E
0005434725455	250	56	14H
0005434725479	250	57	15D
0005434725497	250	58	15C
0005434725529	250	59	15A
0005435142574	250	60	15E
0005433131662	250	61	15H
0005434725522	250	62	15G
0005433113519	250	63	15F
0005434031976	250	64	16D
0005433131673	250	65	16C
0005434725457	250	66	16A
0005432277815	250	67	16F
0005434551214	250	68	16E
0005434551237	250	69	16H
0005433180931	250	70	16G
0005434302460	250	71	17C
0005433289790	250	72	17A
0005433233837	250	73	16K
0005434725515	250	74	17E
0005434725516	250	75	17D
0005434725474	250	76	17H
0005434725451	250	77	17G
0005434725487	250	78	17F
0005434725465	250	79	18A
0005434725505	250	80	17K
0005434725424	250	81	18B
0005433289752	250	82	18E
0005434725521	250	83	18D
0005434725538	250	84	18G
0005433233329	250	85	18F
0005434725493	250	86	18J
0005434551251	250	87	18H
0005434725448	250	88	19B
0005433180854	250	89	19A
0005433233760	250	90	18K
0005433180815	250	91	19D
0005434551254	250	92	19F
0005434725468	250	93	19E
0005434725536	250	94	19G
0005434551259	250	95	20A
0005433131672	250	96	19K
0005433233282	250	97	19J
0005433233601	250	98	20C
0005434735683	250	99	20E
0005434735686	250	100	20D
0005432277811	250	101	20G
0005433126796	250	102	20F
0005434551267	250	103	20J
0005434725434	250	104	20H
0005434725452	250	105	21B
0005434725429	250	106	21A
0005434551239	250	107	20K
0005432277808	250	108	21D
0005433233844	250	109	21C
0005433180808	250	110	21F
0005434551260	250	111	21E
0005434725419	250	112	21J
0005433233452	250	113	21G
0005433233771	250	114	22A
0005434551265	250	115	21K
0005434731168	250	116	22B
0005434725483	250	117	22E
0005433233592	250	118	22H
0005434551245	250	119	22G
0005433180797	250	120	22F
0005434551212	250	121	22K
0005433233845	250	122	22J
0005432277809	250	123	23B
0005434725428	250	124	23A
0005434725445	250	125	23D
0005433233903	250	126	23C
0005434551235	250	127	23G
0005435142577	250	128	23F
0005433233717	250	129	23E
0005434725461	250	130	23J
0005434725500	250	131	23H
0005433126798	250	132	24D
0005432277810	250	133	23K
0005434725486	250	134	24F
0005433233836	250	135	24E
0005433126797	250	136	25B
0005433180757	250	137	25A
0005433180875	250	138	24G
0005434031973	250	139	25D
0005434725441	250	140	25C
0005433233562	250	141	25F
0005434725426	250	142	25H
0005433181017	250	143	25G
0005433180756	250	144	25K
0005434725533	250	145	25J
0005433131669	250	146	26B
0005435142576	250	147	26A
0005435142572	250	148	26D
0005433233895	250	149	26C
0005434551232	250	150	26H
0005433289803	250	151	26G
0005434725476	250	152	26F
0005434725470	250	153	26J
0005434725537	250	154	27B
0005433131676	250	155	27A
0005433131666	250	156	26K
0005434725433	250	157	27D
0005432277807	250	158	27C
0005434725458	250	159	27H
0005435142573	250	160	27G
0005434551252	250	161	27K
0005433131660	250	162	28C
0005433233772	250	163	28B
0005434725460	250	164	28A
0005434725435	250	165	28E
0005434725431	250	166	28D
0005433233652	250	167	28G
0005433126795	250	168	28F
0005434551250	250	169	28J
0005433131661	250	170	28H
0005433180877	250	171	29A
0005433126819	250	172	28K
0005433113522	250	173	29D
0005433233881	250	174	29C
0005433180865	250	175	29B
0005433233577	250	176	29F
0005433233761	250	177	29E
0005433180796	250	178	29H
0005434725507	250	179	29G
0005433233561	250	180	30A
0005433233882	250	181	29J
0005432277803	250	182	30C
0005434551230	250	183	30B
0005433233690	250	184	30E
0005433233706	250	185	30D
0005434551219	250	186	30G
0005432277812	250	187	30F
0005432277804	250	188	30J
0005434551225	250	189	31B
0005433233901	250	190	31A
0005434551213	250	191	30K
0005433233599	250	192	31D
0005434725472	250	193	31C
0005434725501	250	194	31F
0005433233696	250	195	31E
0005434551247	250	196	31J
0005434725440	250	197	31H
0005434725528	250	198	31G
0005434725437	250	199	32A
0005434725447	250	200	31K
0005434725423	250	201	32C
0005434725509	250	202	32B
0005433233870	250	203	32E
0005434725443	250	204	32D
0005433180981	250	205	32H
0005433234039	250	206	32G
0005432277806	250	207	32F
0005434725488	250	208	32J
0005434551223	250	209	33B
0005433233488	250	210	33A
0005434725518	250	211	32K
0005433126784	250	212	33C
0005434031986	250	213	33G
0005434731166	250	214	33F
0005434725420	250	215	33E
0005434725432	250	216	33D
0005434551234	250	217	33H
0005434725475	250	218	34A
0005434725498	250	219	33K
0005434551258	250	220	33J
0005434725439	250	221	34E
0005433131675	250	222	34D
0005434725525	250	223	34G
0005433233545	250	224	34F
0005434551220	250	225	34K
0005433233726	250	226	34J
0005433233548	250	227	34H
0005434725467	250	228	35B
0005434551224	250	229	35A
0005434551231	250	230	35D
0005433233673	250	231	35C
0005433180846	250	232	35G
0005433180809	250	233	35F
0005434725503	250	234	35E
0005433180864	250	235	35J
0005434725539	250	236	35H
0005433233550	250	237	36A
0005433233634	250	238	35K
0005433233449	250	239	36B
0005434725473	250	240	36E
0005433233667	250	241	36D
0005434551215	250	242	36G
0005434725471	250	243	36F
0005434551263	250	244	36K
0005434725510	250	245	36J
0005434551262	250	246	37B
0005434725508	250	247	37A
0005433180932	250	248	37D
0005434551238	250	249	37C
0005433233858	250	250	37F
0005432277805	250	251	37E
0005434551217	250	252	37J
0005433233600	250	253	37H
0005432277814	250	254	37K
0005435142584	250	255	38C
0005434725531	250	256	38B
0005433233591	250	257	38K
0005434725442	250	258	38J
0005434725480	250	259	38H
0005434551243	250	260	39B
0005433233472	250	261	39A
0005433233782	250	262	39C
0005434725466	250	263	39F
0005433233892	250	264	39E
0005433233393	250	265	39D
0005433233251	250	266	39J
0005434725506	250	267	39H
0005434551236	250	268	39G
0005434725519	250	269	39K
0005434725540	250	270	40B
0005434551253	250	271	40E
0005435142583	250	272	40D
0005433113520	250	273	40H
0005434725425	250	274	40G
0005433233664	250	275	40F
0005433126804	250	276	40J
0005433289789	250	277	41B
0005433233695	250	278	41A
0005434725482	250	279	40K
0005433233746	250	280	41C
0005433180862	250	281	41G
0005433233725	250	282	41F
0005434551240	250	283	41E
0005434551227	250	284	41J
0005435142581	250	285	41H
0005433233757	250	286	42A
0005434725436	250	287	41K
0005433180874	250	288	42C
0005433126799	250	289	42B
0005434725430	250	290	42E
0005433233804	250	291	42D
0005434725499	250	292	42G
0005435142580	250	293	42J
0005432277816	250	294	42H
0005434031963	250	295	43B
0005433131668	250	296	43A
0005433233637	250	297	42K
0005434735687	250	298	43D
0005434551249	250	299	43C
0005434725481	250	300	43F
0005434725513	250	301	43G
0005433289773	250	302	43K
0005433131671	250	303	43J
0005432277813	250	304	44C
0005434031977	250	305	44B
0005433233666	250	306	44E
0005434725446	250	307	44D
0005434725450	250	308	44G
0005434725511	250	309	44F
0005434725459	250	310	44K
0005434725469	250	311	44J
0005434725438	250	312	44H
0005434551246	250	313	45B
0005433233720	250	314	45A
0005435142575	250	315	45D
0005434725495	250	316	45C
0005434725422	250	317	45F
0005434725504	250	318	45E
0005433233671	250	319	45H
0005434725427	250	320	45K
0005434551216	250	321	45J
0005434725454	250	322	46C
0005433126783	250	323	46B
0005434725492	250	324	46A
0005434031959	250	325	46E
0005434551248	250	326	46H
0005434551244	250	327	46G
0005434551233	250	328	47C
0005434725535	250	329	47A
0005433233685	250	330	46K
0005433233871	250	331	47E
0005433233549	250	332	47D
0005434551229	250	333	47G
0005434302461	250	334	47F
0005434551228	250	335	47K
0005434731167	250	336	47H
0005434725444	250	337	48C
0005434551261	250	338	48A
0005433233503	250	339	48F
0005434551264	250	340	48E
0005434725421	250	341	48H
0005433233807	250	342	49A
0005434551256	250	343	48K
0005434725417	250	344	49D
0005434725534	250	345	49C
0005434725520	250	346	49G
0005434725453	250	347	49F
0005434031970	250	348	49E
0005433233328	250	349	49H
0005434031972	250	350	50C
0005433113521	250	351	50A
0005434725526	250	352	49K
0005434725456	250	353	50E
0005433233616	250	354	50D
0005434725490	250	355	50F
0005434725464	250	356	50K
0005434551241	250	357	50H
0005434725477	250	358	51F
0005434725502	250	359	51E
0005434725523	250	360	51D
0005434551242	250	361	51G
0005434724547	9838	1	1A
0005433234183	9838	2	1C
0005433234219	9838	3	1G
0005433234227	9838	4	1D
0005434550736	9838	5	2A
0005433289845	9838	6	1K
0005433234184	9838	7	1H
0005433181094	9838	8	2D
0005434724834	9838	9	2C
0005434550735	9838	10	2H
0005433234190	9838	11	3D
0005434724414	9838	12	3C
0005434724594	9838	13	3H
0005433181096	9838	14	4C
0005434724060	9838	15	4A
0005434724341	9838	16	4G
0005434550811	9838	17	4D
0005434550640	9838	18	5A
0005433234200	9838	19	4K
0005432199248	9838	20	4H
0005432199252	9838	21	5D
0005433234186	9838	22	5C
0005433234187	9838	23	5H
0005434724442	9838	24	5G
0005434724711	9838	25	11A
0005432199250	9838	26	11D
0005432199246	9838	27	11C
0005434032027	9838	28	11F
0005433181108	9838	29	11E
0005434550617	9838	30	11K
0005432199245	9838	31	11H
0005434550810	9838	32	12A
0005433234181	9838	33	12E
0005434302426	9838	34	12D
0005434723931	9838	35	12G
0005434550709	9838	36	12F
0005434550592	9838	37	12K
0005434550733	9838	38	13A
0005433181109	9838	39	13G
0005434724221	9838	40	13E
0005433234210	9838	41	14A
0005434724655	9838	42	14E
0005434724567	9838	43	14C
0005434724011	9838	44	14G
0005433129274	9838	45	14F
0005433766638	9838	46	14K
0005434550542	9838	47	14H
0005435142449	9838	48	15C
0005434032023	9838	49	15A
0005433766641	9838	50	15E
0005433234179	9838	51	15D
0005433129273	9838	52	15H
0005433289844	9838	53	15G
0005434550615	9838	54	15F
0005433234218	9838	55	16A
0005433234220	9838	56	15K
0005434724266	9838	57	16D
0005434550875	9838	58	16C
0005434724620	9838	59	16F
0005434724403	9838	60	16G
0005434550616	9838	61	17C
0005434550509	9838	62	17A
0005433181098	9838	63	16K
0005434550558	9838	64	17D
0005433234221	9838	65	17G
0005434723993	9838	66	17F
0005433234199	9838	67	17K
0005433181092	9838	68	18C
0005434724689	9838	69	18B
0005434550689	9838	70	18A
0005433234232	9838	71	18E
0005434724680	9838	72	18D
0005433181112	9838	73	18G
0005433113536	9838	74	18F
0005434724334	9838	75	18J
0005433234176	9838	76	19A
0005432199249	9838	77	18K
0005434550760	9838	78	19D
0005434724150	9838	79	19C
0005434550690	9838	80	19B
0005433234188	9838	81	19F
0005433234211	9838	82	19E
0005434724736	9838	83	19J
0005434724759	9838	84	19H
0005434724386	9838	85	19G
0005434724078	9838	86	19K
0005434724546	9838	87	20B
0005434724530	9838	88	20D
0005434723875	9838	89	20G
0005434032026	9838	90	20F
0005434724687	9838	91	20K
0005434724545	9838	92	20J
0005434724316	9838	93	21B
0005434724441	9838	94	21A
0005434724400	9838	95	21D
0005433234207	9838	96	21F
0005433181100	9838	97	21E
0005433129276	9838	98	21H
0005434724315	9838	99	21G
0005434724401	9838	100	22A
0005434724519	9838	101	21J
0005433234225	9838	102	22B
0005434550655	9838	103	22F
0005435142368	9838	104	22E
0005433181106	9838	105	22D
0005434550874	9838	106	22H
0005434723642	9838	107	22G
0005433234202	9838	108	22J
0005434550757	9838	109	23B
0005434724859	9838	110	23A
0005433234231	9838	111	22K
0005433234209	9838	112	23D
0005434724971	9838	113	23F
0005434724532	9838	114	23E
0005434724313	9838	115	23J
0005434550718	9838	116	23H
0005433234192	9838	117	24D
0005434550559	9838	118	23K
0005434735653	9838	119	24F
0005434724290	9838	120	24E
0005434724357	9838	121	25B
0005434724216	9838	122	25A
0005433181090	9838	123	24G
0005434724353	9838	124	25D
0005434302395	9838	125	25C
0005433234234	9838	126	25F
0005434723958	9838	127	25H
0005433289848	9838	128	25G
0005434302413	9838	129	25K
0005434550785	9838	130	26A
0005434724333	9838	131	26E
0005434032025	9838	132	26D
0005434550580	9838	133	26G
0005433126846	9838	134	26F
0005433181110	9838	135	26J
0005434724217	9838	136	26H
0005434725037	9838	137	27A
0005434550708	9838	138	27C
0005434550680	9838	139	27B
0005434550693	9838	140	27E
0005434550859	9838	141	27D
0005434723825	9838	142	27H
0005434302414	9838	143	27G
0005434724746	9838	144	27K
0005433234205	9838	145	27J
0005433181105	9838	146	28C
0005434550781	9838	147	28B
0005434550862	9838	148	28D
0005433234229	9838	149	28G
0005434724327	9838	150	28J
0005432199247	9838	151	28H
0005434550786	9838	152	29B
0005435142492	9838	153	29A
0005434724638	9838	154	28K
0005434550688	9838	155	29D
0005434550931	9838	156	29F
0005434302420	9838	157	29H
0005434724571	9838	158	29G
0005434550806	9838	159	30A
0005434724830	9838	160	29K
0005433289847	9838	161	30C
0005434724752	9838	162	30B
0005434724585	9838	163	30E
0005433234195	9838	164	30J
0005433181093	9838	165	30H
0005433234217	9838	166	31A
0005434724468	9838	167	30K
0005435142399	9838	168	31D
0005433181087	9838	169	31C
0005434550819	9838	170	31F
0005434550808	9838	171	31E
0005434724558	9838	172	31J
0005435142450	9838	173	31H
0005434550562	9838	174	31K
0005434724512	9838	175	32C
0005433129275	9838	176	32B
0005434032024	9838	177	32A
0005433289849	9838	178	32E
0005434302412	9838	179	32F
0005434724603	9838	180	32K
0005434724580	9838	181	32H
0005434724688	9838	182	33A
0005433234208	9838	183	33C
0005434724520	9838	184	33G
0005434724760	9838	185	33E
0005434724605	9838	186	33H
0005434723977	9838	187	33K
0005434550812	9838	188	34C
0005434724538	9838	189	34B
0005433234235	9838	190	34A
0005434550784	9838	191	34D
0005434724931	9838	192	34H
0005434723835	9838	193	34G
0005433181111	9838	194	34F
0005434724782	9838	195	35A
0005434725076	9838	196	35D
0005434550853	9838	197	35C
0005434550854	9838	198	35B
0005433234214	9838	199	35F
0005434724415	9838	200	35E
0005434724741	9838	201	35H
0005434724262	9838	202	35G
0005435142400	9838	203	36A
0005434550804	9838	204	35K
0005433234226	9838	205	35J
0005434724090	9838	206	36B
0005433181102	9838	207	36E
0005434550950	9838	208	36D
0005433234216	9838	209	36H
0005433181107	9838	210	36G
0005433181101	9838	211	36F
0005433234206	9838	212	36K
0005433234213	9838	213	37B
0005433234197	9838	214	37A
0005434724665	9838	215	37F
0005434724366	9838	216	37J
0005433113535	9838	217	37H
0005434550710	9838	218	37G
0005433181103	9838	219	38A
0005433234182	9838	220	37K
0005433181099	9838	221	38C
0005434724392	9838	222	38B
0005433234223	9838	223	38H
0005434724903	9838	224	39A
0005434550527	9838	225	38K
0005434724123	9838	226	39D
0005434302404	9838	227	39C
0005434724621	9838	228	39B
0005434735644	9838	229	39F
0005434724709	9838	230	39E
0005434724954	9838	231	39J
0005434550547	9838	232	39H
0005434724761	9838	233	39G
0005434724443	9838	234	39K
0005434723626	9838	235	40C
0005434724237	9838	236	40B
0005433234237	9838	237	40A
0005433234178	9838	238	40E
0005434724548	9838	239	40D
0005433126844	9838	240	40G
0005434724697	9838	241	40F
0005433234198	9838	242	40K
0005433234230	9838	243	40J
0005434550519	9838	244	40H
0005433234228	9838	245	41A
0005434724413	9838	246	41D
0005434724579	9838	247	41C
0005433181088	9838	248	41B
0005434724234	9838	249	41E
0005433234212	9838	250	41G
0005433181104	9838	251	41K
0005434724256	9838	252	41J
0005434302415	9838	253	42C
0005434550579	9838	254	42B
0005433126843	9838	255	42E
0005434724387	9838	256	42D
0005434724476	9838	257	42F
0005433234180	9838	258	42K
0005434550561	9838	259	42J
0005434723830	9838	260	42H
0005434724826	9838	261	43A
0005434724953	9838	262	43D
0005433234203	9838	263	43C
0005434550404	9838	264	43F
0005435142431	9838	265	43E
0005434302409	9838	266	43J
0005434724426	9838	267	43K
0005433129277	9838	268	44C
0005434724563	9838	269	44B
0005433234204	9838	270	44A
0005434724487	9838	271	44D
0005433766639	9838	272	44F
0005434724233	9838	273	44J
0005433234238	9838	274	45A
0005434724753	9838	275	44K
0005432199251	9838	276	45D
0005433234191	9838	277	45B
0005434724533	9838	278	45E
0005433126845	9838	279	45H
0005433234233	9838	280	45K
0005433181095	9838	281	45J
0005434724222	9838	282	46C
0005434724482	9838	283	46B
0005433234239	9838	284	46E
0005434724738	9838	285	46D
0005433181097	9838	286	46G
0005433126842	9838	287	46F
0005434724564	9838	288	46J
0005433234224	9838	289	46H
0005434723874	9838	290	46K
0005433234222	9838	291	47E
0005433234185	9838	292	47D
0005434724714	9838	293	47F
0005434724423	9838	294	47K
0005433234196	9838	295	47H
0005434724311	9838	296	48C
0005433234194	9838	297	48A
0005433766640	9838	298	48F
0005434724690	9838	299	48H
0005433234189	9838	300	48G
0005434550419	9838	301	49A
0005434550861	9838	302	48K
0005435142367	9838	303	49D
0005433126847	9838	304	49C
0005433234236	9838	305	49G
0005433181089	9838	306	49F
0005433234215	9838	307	49K
0005433181091	9838	308	50C
0005434550930	9838	309	50A
0005434724061	9838	310	50E
0005434302425	9838	311	50D
0005434724737	9838	312	50G
0005434724393	9838	313	50F
0005433234177	9838	314	50K
0005433234201	9838	315	50H
0005434724592	9838	316	51F
0005433234193	9838	317	51E
0005433289846	9838	318	51G
0005434067562	7741	1	1A
0005434067600	7741	2	1G
0005432527932	7741	3	1D
0005435212752	7741	4	1K
0005434067595	7741	5	1H
0005435212862	7741	6	2C
0005434067551	7741	7	2A
0005432527985	7741	8	2G
0005432527924	7741	9	2K
0005435213064	7741	10	3D
0005432528035	7741	11	3C
0005432527970	7741	12	3H
0005432528015	7741	13	3G
0005434067556	7741	14	4A
0005432537057	7741	15	4G
0005435213056	7741	16	4D
0005432527969	7741	17	4K
0005435212838	7741	18	4H
0005432528041	7741	19	5A
0005435213275	7741	20	5H
0005432528027	7741	21	5G
0005434067548	7741	22	5D
0005435630944	7741	23	5K
0005433656633	7741	24	11C
0005432527998	7741	25	11G
0005432535834	7741	26	11F
0005432528024	7741	27	11E
0005434067588	7741	28	12C
0005432527937	7741	29	12A
0005432527921	7741	30	12E
0005434067560	7741	31	12G
0005435212888	7741	32	12K
0005434067547	7741	33	12H
0005432528033	7741	34	13D
0005432527973	7741	35	13C
0005435212761	7741	36	13F
0005432069657	7741	37	13E
0005435213123	7741	38	13H
0005434067555	7741	39	13G
0005432527971	7741	40	14A
0005432527967	7741	41	13K
0005434067589	7741	42	14E
0005434067568	7741	43	14C
0005432528000	7741	44	14G
0005432527991	7741	45	14F
0005435212966	7741	46	14H
0005432527997	7741	47	15C
0005432527942	7741	48	14K
0005435212726	7741	49	15E
0005432527920	7741	50	15G
0005432528047	7741	51	15F
0005434067545	7741	52	16A
0005435630938	7741	53	15K
0005432527919	7741	54	15H
0005435213124	7741	55	16D
0005434067564	7741	56	16C
0005432527933	7741	57	16F
0005435213013	7741	58	16E
0005432527977	7741	59	16H
0005434067578	7741	60	16G
0005432069660	7741	61	17C
0005432528030	7741	62	17A
0005434067532	7741	63	17E
0005432150193	7741	64	17D
0005434067530	7741	65	17G
0005432527988	7741	66	17F
0005432069656	7741	67	17H
0005432528008	7741	68	18C
0005432069650	7741	69	18B
0005435212846	7741	70	18E
0005432528038	7741	71	18D
0005435212979	7741	72	18G
0005434067540	7741	73	18J
0005434067590	7741	74	18H
0005432527929	7741	75	19B
0005432528028	7741	76	19A
0005432528001	7741	77	18K
0005432528026	7741	78	19D
0005434067581	7741	79	19F
0005432150192	7741	80	19E
0005432528007	7741	81	19H
0005432528010	7741	82	19G
0005432528014	7741	83	19K
0005432528025	7741	84	19J
0005432537058	7741	85	20A
0005434067552	7741	86	20D
0005435725551	7741	87	20H
0005432069653	7741	88	20G
0005435212801	7741	89	20F
0005434067573	7741	90	20J
0005435213010	7741	91	21B
0005432150191	7741	92	21A
0005434067591	7741	93	21D
0005432527941	7741	94	21C
0005434067570	7741	95	21F
0005435212889	7741	96	21E
0005435213235	7741	97	21J
0005435630918	7741	98	21H
0005432527956	7741	99	21G
0005434067583	7741	100	22A
0005435212463	7741	101	22D
0005435212610	7741	102	22C
0005434067587	7741	103	22B
0005432527966	7741	104	22E
0005435212971	7741	105	22G
0005432527968	7741	106	22F
0005433656638	7741	107	22K
0005432527976	7741	108	22H
0005432527952	7741	109	23E
0005435213089	7741	110	23D
0005434067602	7741	111	23F
0005432528044	7741	112	23J
0005432069651	7741	113	23G
0005434067561	7741	114	23K
0005432527992	7741	115	24E
0005432528018	7741	116	24G
0005432527982	7741	117	25D
0005432150199	7741	118	25F
0005434067579	7741	119	25K
0005435212935	7741	120	25J
0005432527949	7741	121	26C
0005435725535	7741	122	26B
0005432527964	7741	123	26A
0005434067572	7741	124	26E
0005434067538	7741	125	26D
0005432527948	7741	126	26G
0005434067565	7741	127	26F
0005432528045	7741	128	26J
0005435212822	7741	129	26H
0005435212762	7741	130	27A
0005432528037	7741	131	26K
0005435212839	7741	132	27C
0005435212751	7741	133	27F
0005432069648	7741	134	27E
0005432527954	7741	135	27H
0005432527944	7741	136	27G
0005434067542	7741	137	27K
0005432527995	7741	138	27J
0005432069652	7741	139	28C
0005434067596	7741	140	28B
0005432528036	7741	141	28A
0005432428927	7741	142	28E
0005432527928	7741	143	28D
0005435725560	7741	144	28G
0005432428928	7741	145	28F
0005432069658	7741	146	28J
0005432527986	7741	147	28H
0005434067531	7741	148	29A
0005434067571	7741	149	28K
0005435213050	7741	150	29D
0005432069659	7741	151	29C
0005435212895	7741	152	29B
0005432150198	7741	153	29F
0005432533291	7741	154	29E
0005432535835	7741	155	29J
0005432527981	7741	156	29G
0005432527983	7741	157	30A
0005432527963	7741	158	30C
0005432527938	7741	159	30B
0005435212901	7741	160	30E
0005432528034	7741	161	30D
0005434067569	7741	162	30G
0005435212969	7741	163	30F
0005432528017	7741	164	30J
0005432527958	7741	165	30H
0005435212944	7741	166	31B
0005432527960	7741	167	31A
0005435212976	7741	168	30K
0005435213011	7741	169	31D
0005432528016	7741	170	31C
0005435212967	7741	171	31F
0005434067586	7741	172	31E
0005432527914	7741	173	31H
0005434067594	7741	174	31G
0005432533292	7741	175	31K
0005432069649	7741	176	31J
0005435212866	7741	177	32C
0005432150197	7741	178	32B
0005434067575	7741	179	32A
0005432528012	7741	180	32D
0005434067580	7741	181	32G
0005434067597	7741	182	32J
0005435212877	7741	183	32H
0005432527936	7741	184	33B
0005435725536	7741	185	33A
0005435212946	7741	186	33F
0005432527962	7741	187	33J
0005435212834	7741	188	33H
0005432150195	7741	189	33G
0005432527965	7741	190	33K
0005432528022	7741	191	34B
0005432069655	7741	192	34A
0005432528043	7741	193	34E
0005432527915	7741	194	34D
0005435213060	7741	195	34C
0005432535831	7741	196	34G
0005432527990	7741	197	34F
0005435212462	7741	198	34K
0005434067585	7741	199	34J
0005434067582	7741	200	34H
0005434067544	7741	201	35A
0005432527974	7741	202	35E
0005432527945	7741	203	35D
0005432150196	7741	204	35C
0005435725543	7741	205	35F
0005432528040	7741	206	35J
0005434067536	7741	207	35H
0005434067566	7741	208	35G
0005434067557	7741	209	36A
0005435213103	7741	210	35K
0005432527987	7741	211	36C
0005432528039	7741	212	36B
0005434067577	7741	213	36F
0005434067601	7741	214	36E
0005432527972	7741	215	36D
0005432527918	7741	216	36H
0005432527975	7741	217	37C
0005432528031	7741	218	37B
0005432527931	7741	219	37E
0005432527999	7741	220	37D
0005435212970	7741	221	37G
0005432150194	7741	222	37F
0005432527946	7741	223	37J
0005432528029	7741	224	37H
0005434067554	7741	225	38A
0005432527955	7741	226	37K
0005432527961	7741	227	38C
0005432528013	7741	228	38K
0005432527935	7741	229	38J
0005432527943	7741	230	38H
0005432535832	7741	231	39B
0005434067559	7741	232	39A
0005432527923	7741	233	39F
0005432527953	7741	234	39E
0005435213059	7741	235	39H
0005432527994	7741	236	39G
0005434067529	7741	237	40A
0005432527940	7741	238	39K
0005432527939	7741	239	39J
0005432527980	7741	240	40C
0005435212784	7741	241	40B
0005433656620	7741	242	40D
0005434067592	7741	243	40H
0005434067546	7741	244	40G
0005432528006	7741	245	40F
0005432528020	7741	246	40K
0005432069654	7741	247	40J
0005432527950	7741	248	41A
0005434067533	7741	249	41D
0005435212934	7741	250	41C
0005435725544	7741	251	41B
0005432069662	7741	252	41F
0005432528002	7741	253	41E
0005432527927	7741	254	41H
0005435212887	7741	255	42A
0005432527926	7741	256	41K
0005434067550	7741	257	42B
0005432527993	7741	258	42F
0005432527957	7741	259	42E
0005432527979	7741	260	42D
0005434067593	7741	261	42G
0005434067537	7741	262	42K
0005434067541	7741	263	42H
0005435212685	7741	264	43A
0005432527925	7741	265	43D
0005432527916	7741	266	43B
0005434067539	7741	267	43F
0005434067567	7741	268	43E
0005432528021	7741	269	43H
0005435212894	7741	270	43K
0005432528005	7741	271	43J
0005432528004	7741	272	44B
0005432528009	7741	273	44A
0005434067598	7741	274	44E
0005432527996	7741	275	44C
0005432527930	7741	276	44G
0005432528046	7741	277	44K
0005435630917	7741	278	44H
0005432527989	7741	279	45D
0005435212988	7741	280	45C
0005434067584	7741	281	45B
0005435213012	7741	282	45F
0005434067558	7741	283	45E
0005435212649	7741	284	45H
0005432069661	7741	285	45G
0005435213002	7741	286	45K
0005435212771	7741	287	45J
0005434067599	7741	288	46C
0005432528032	7741	289	46B
0005432528003	7741	290	46D
0005435212800	7741	291	46G
0005434067574	7741	292	46F
0005432527978	7741	293	46J
0005432527934	7741	294	47C
0005435212863	7741	295	47A
0005433656642	7741	296	46K
0005434067549	7741	297	47D
0005435725552	7741	298	47G
0005432428929	7741	299	47F
0005432528042	7741	300	47E
0005432527951	7741	301	47K
0005435212991	7741	302	47H
0005434067535	7741	303	48C
0005432527917	7741	304	48F
0005432528023	7741	305	48E
0005432528019	7741	306	48D
0005435212900	7741	307	48H
0005434067534	7741	308	48K
0005435212699	7741	309	49D
0005432527984	7741	310	49C
0005434067553	7741	311	49G
0005432527922	7741	312	49F
0005435212648	7741	313	49E
0005435212945	7741	314	49K
0005432535833	7741	315	50A
0005432527947	7741	316	50E
0005432527959	7741	317	50D
0005434067543	7741	318	50G
0005432528011	7741	319	50K
0005434067576	7741	320	50H
0005435213181	7741	321	51F
0005434067563	7741	322	51E
0005435424350	5308	1	1C
0005435613686	5308	2	1A
0005434573355	5308	3	1G
0005435424197	5308	4	2A
0005434344241	5308	5	1K
0005435613678	5308	6	1H
0005435613600	5308	7	2D
0005434244803	5308	8	2H
0005435380261	5308	9	3A
0005432133208	5308	10	2K
0005435424178	5308	11	3D
0005435424005	5308	12	3C
0005435424555	5308	13	3G
0005434244659	5308	14	4C
0005432133217	5308	15	4A
0005435613605	5308	16	3K
0005435613596	5308	17	4H
0005432363388	5308	18	4G
0005435613703	5308	19	4D
0005435613695	5308	20	5C
0005435424588	5308	21	5A
0005435613634	5308	22	5H
0005434344229	5308	23	5D
0005435613643	5308	24	11A
0005435613654	5308	25	5K
0005435424329	5308	26	11D
0005435613608	5308	27	11C
0005432133205	5308	28	11F
0005435613647	5308	29	11E
0005435319513	5308	30	11G
0005435613653	5308	31	12A
0005435424239	5308	32	12E
0005435613656	5308	33	12H
0005434573357	5308	34	12G
0005435613619	5308	35	13A
0005435613624	5308	36	12K
0005432047548	5308	37	13D
0005435424156	5308	38	13C
0005435097207	5308	39	13F
0005435424288	5308	40	13K
0005435097199	5308	41	13H
0005435380252	5308	42	13G
0005435613589	5308	43	14A
0005432133211	5308	44	14E
0005435424413	5308	45	14D
0005435319519	5308	46	14F
0005435613603	5308	47	14H
0005432047549	5308	48	14G
0005435424311	5308	49	15D
0005435424405	5308	50	15C
0005435613598	5308	51	15E
0005435613591	5308	52	15G
0005432133210	5308	53	15F
0005435613636	5308	54	16A
0005435613629	5308	55	15K
0005434244839	5308	56	16D
0005435423942	5308	57	16C
0005435613684	5308	58	16F
0005434344248	5308	59	16E
0005435424225	5308	60	16H
0005435097205	5308	61	16G
0005435555368	5308	62	17C
0005435613689	5308	63	17A
0005434573350	5308	64	17H
0005435380238	5308	65	17G
0005434244732	5308	66	17F
0005435424457	5308	67	17K
0005434244669	5308	68	18C
0005435617170	5308	69	18B
0005434573352	5308	70	18A
0005435424280	5308	71	18E
0005435613706	5308	72	18D
0005435613668	5308	73	18H
0005435424108	5308	74	18G
0005435613622	5308	75	18F
0005435613607	5308	76	18K
0005435613592	5308	77	18J
0005435613687	5308	78	19A
0005435613594	5308	79	19D
0005434573358	5308	80	19C
0005435380262	5308	81	19B
0005435613692	5308	82	19F
0005435613665	5308	83	19E
0005435424538	5308	84	19J
0005435613588	5308	85	19H
0005435617169	5308	86	19G
0005435380250	5308	87	20A
0005435613696	5308	88	19K
0005435613613	5308	89	20C
0005434344219	5308	90	20B
0005435613639	5308	91	20D
0005435613697	5308	92	20G
0005433719091	5308	93	20K
0005435613669	5308	94	20H
0005434656539	5308	95	21A
0005434344239	5308	96	21D
0005434573347	5308	97	21C
0005434573360	5308	98	21G
0005434344222	5308	99	21F
0005435613610	5308	100	21J
0005434573351	5308	101	22C
0005435613638	5308	102	22B
0005435613620	5308	103	22F
0005435613628	5308	104	22E
0005435613642	5308	105	22D
0005434344217	5308	106	22G
0005435424244	5308	107	22J
0005435424389	5308	108	22H
0005434344246	5308	109	23A
0005435613664	5308	110	23E
0005434344226	5308	111	23D
0005434344242	5308	112	23G
0005434244766	5308	113	23F
0005435613590	5308	114	23H
0005434573359	5308	115	24D
0005435424165	5308	116	24F
0005435613612	5308	117	24E
0005432133207	5308	118	25A
0005434573356	5308	119	24G
0005435613626	5308	120	25B
0005435424063	5308	121	25F
0005435424379	5308	122	25E
0005434344221	5308	123	25J
0005435613693	5308	124	25H
0005435555369	5308	125	25G
0005435424323	5308	126	25K
0005435097203	5308	127	26C
0005435319526	5308	128	26B
0005434244657	5308	129	26A
0005435424287	5308	130	26E
0005432133218	5308	131	26D
0005435424364	5308	132	26G
0005435613606	5308	133	26F
0005434244799	5308	134	26H
0005432047551	5308	135	27B
0005435424177	5308	136	27A
0005435613640	5308	137	27C
0005435490229	5308	138	27F
0005435613602	5308	139	27E
0005435302174	5308	140	27D
0005432133215	5308	141	27H
0005435613641	5308	142	27G
0005435613609	5308	143	27K
0005435613651	5308	144	27J
0005435613631	5308	145	28C
0005435424406	5308	146	28B
0005435613690	5308	147	28A
0005432363387	5308	148	28E
0005435613655	5308	149	28F
0005435613618	5308	150	28J
0005435613688	5308	151	28H
0005435613623	5308	152	29A
0005435613698	5308	153	28K
0005435613616	5308	154	29B
0005435424359	5308	155	29F
0005435613615	5308	156	29E
0005435424164	5308	157	29J
0005435613621	5308	158	29H
0005435302138	5308	159	29G
0005434344227	5308	160	30B
0005435424073	5308	161	30D
0005435613635	5308	162	30G
0005435613682	5308	163	30F
0005435424358	5308	164	30E
0005435613658	5308	165	30J
0005434344233	5308	166	30H
0005435424186	5308	167	31A
0005435613691	5308	168	30K
0005432133216	5308	169	31C
0005434344247	5308	170	31E
0005435613585	5308	171	31H
0005434573349	5308	172	31K
0005435613681	5308	173	31J
0005435424356	5308	174	32C
0005435424513	5308	175	32B
0005435424337	5308	176	32A
0005434244765	5308	177	32G
0005434344220	5308	178	32F
0005434344230	5308	179	32J
0005435424154	5308	180	32H
0005435097201	5308	181	33A
0005435613662	5308	182	32K
0005435613646	5308	183	33D
0005434344224	5308	184	33C
0005434344231	5308	185	33B
0005435424306	5308	186	33F
0005432133204	5308	187	33J
0005434344244	5308	188	33H
0005435613627	5308	189	33G
0005435613685	5308	190	34A
0005434344245	5308	191	33K
0005435097200	5308	192	34E
0005435613663	5308	193	34D
0005432840991	5308	194	34G
0005434344237	5308	195	34F
0005435424537	5308	196	34J
0005435613673	5308	197	34H
0005435424240	5308	198	35A
0005435613694	5308	199	35B
0005434344214	5308	200	35F
0005435613648	5308	201	35E
0005435613630	5308	202	35H
0005435424357	5308	203	36A
0005435424515	5308	204	35K
0005435613660	5308	205	36D
0005434573354	5308	206	36C
0005434656538	5308	207	36B
0005434244800	5308	208	36E
0005435424062	5308	209	36G
0005435380253	5308	210	36K
0005435613657	5308	211	36H
0005435613702	5308	212	37A
0005434344240	5308	213	37E
0005435613674	5308	214	37D
0005435424219	5308	215	37C
0005435613675	5308	216	37F
0005434344236	5308	217	37H
0005435424220	5308	218	37G
0005434573353	5308	219	37K
0005435424344	5308	220	37J
0005432047550	5308	221	38C
0005435424136	5308	222	38B
0005435613676	5308	223	38A
0005434344232	5308	224	38J
0005435613595	5308	225	38H
0005435613680	5308	226	39B
0005435302176	5308	227	39A
0005435613599	5308	228	38K
0005435424493	5308	229	39C
0005432840996	5308	230	39F
0005434344212	5308	231	39E
0005435424187	5308	232	39D
0005434344235	5308	233	39H
0005435613666	5308	234	39G
0005435424270	5308	235	39K
0005435613672	5308	236	39J
0005435424116	5308	237	40C
0005432133206	5308	238	40E
0005435613645	5308	239	40D
0005435424298	5308	240	40H
0005435424448	5308	241	40G
0005432363379	5308	242	40K
0005435490227	5308	243	40J
0005435424291	5308	244	41B
0005435613601	5308	245	41A
0005434344215	5308	246	41D
0005435613659	5308	247	41F
0005435304997	5308	248	41E
0005435424310	5308	249	41J
0005432133212	5308	250	41H
0005435613699	5308	251	41G
0005433719107	5308	252	42C
0005435097202	5308	253	42B
0005435613683	5308	254	42E
0005435613611	5308	255	42D
0005435097204	5308	256	42F
0005434244733	5308	257	43B
0005435490228	5308	258	43A
0005435613593	5308	259	43D
0005434244769	5308	260	43C
0005434573348	5308	261	43F
0005435613652	5308	262	43E
0005435424414	5308	263	43J
0005435613705	5308	264	43H
0005434244884	5308	265	43G
0005435424527	5308	266	44A
0005435613604	5308	267	43K
0005435613597	5308	268	44B
0005434244652	5308	269	44C
0005435613701	5308	270	44G
0005435613633	5308	271	44F
0005435613632	5308	272	44K
0005435424117	5308	273	44J
0005435613587	5308	274	45B
0005432133209	5308	275	45D
0005435097206	5308	276	45C
0005434344225	5308	277	45F
0005435380269	5308	278	45E
0005434244658	5308	279	45H
0005435424284	5308	280	45G
0005435424107	5308	281	45K
0005435424118	5308	282	45J
0005435613667	5308	283	46C
0005434344213	5308	284	46B
0005432133214	5308	285	46A
0005435613625	5308	286	46E
0005432363386	5308	287	46D
0005434344223	5308	288	46G
0005434244755	5308	289	46F
0005435613614	5308	290	46J
0005435302146	5308	291	46H
0005435424140	5308	292	47A
0005435424221	5308	293	46K
0005434344234	5308	294	47E
0005435613679	5308	295	47D
0005435613670	5308	296	47C
0005435424514	5308	297	47G
0005435613617	5308	298	47F
0005435613637	5308	299	48C
0005435613644	5308	300	48A
0005435613677	5308	301	48F
0005434344216	5308	302	48D
0005434244678	5308	303	48H
0005434344211	5308	304	48G
0005435424338	5308	305	49A
0005435302175	5308	306	48K
0005432133213	5308	307	49D
0005435613704	5308	308	49C
0005434344218	5308	309	49G
0005435613586	5308	310	49F
0005435613661	5308	311	49E
0005435613649	5308	312	49K
0005435613671	5308	313	49H
0005435424033	5308	314	50A
0005433719090	5308	315	50E
0005435424326	5308	316	50D
0005435613650	5308	317	50H
0005435424155	5308	318	50G
0005435613700	5308	319	50F
0005434344228	5308	320	50K
0005434344243	5308	321	51F
0005434344238	5308	322	51E
0005435612258	10874	1	1C
0005435555351	10874	2	1G
0005434343847	10874	3	1D
0005435490197	10874	4	2D
0005434343907	10874	5	2C
0005435612284	10874	6	2A
0005434573248	10874	7	2H
0005435612759	10874	8	3A
0005435424820	10874	9	2K
0005434343790	10874	10	3D
0005435612427	10874	11	3C
0005434244987	10874	12	3K
0005435612475	10874	13	3H
0005435612773	10874	14	4C
0005435490198	10874	15	4G
0005435424841	10874	16	4D
0005434343854	10874	17	4K
0005435424783	10874	18	4H
0005433719140	10874	19	5C
0005432841013	10874	20	5H
0005435424845	10874	21	5G
0005434343900	10874	22	5D
0005435319569	10874	23	11D
0005435612613	10874	24	11C
0005435424778	10874	25	11F
0005435612473	10874	26	11E
0005434573215	10874	27	11H
0005435612742	10874	28	12A
0005434244979	10874	29	12E
0005435424784	10874	30	12D
0005435424808	10874	31	12H
0005434244981	10874	32	12G
0005435490185	10874	33	12F
0005435424816	10874	34	13D
0005435612526	10874	35	13C
0005434343762	10874	36	13A
0005433719142	10874	37	13E
0005432165041	10874	38	13H
0005435424831	10874	39	13G
0005435491428	10874	40	14C
0005434343903	10874	41	14A
0005435612481	10874	42	13K
0005435424818	10874	43	14E
0005434343732	10874	44	14D
0005434244988	10874	45	14F
0005435612540	10874	46	14K
0005434244983	10874	47	14G
0005435424828	10874	48	15C
0005435097074	10874	49	15E
0005435612276	10874	50	15F
0005435612556	10874	51	16A
0005435319570	10874	52	15H
0005435612659	10874	53	16D
0005435305015	10874	54	16C
0005434344009	10874	55	16G
0005435424806	10874	56	16F
0005435424836	10874	57	16E
0005434244973	10874	58	16H
0005432165035	10874	59	17E
0005434343779	10874	60	17D
0005434244975	10874	61	17F
0005434343763	10874	62	17H
0005435612658	10874	63	18C
0005432166900	10874	64	18B
0005432166901	10874	65	18A
0005435611911	10874	66	18E
0005434343805	10874	67	18G
0005434343908	10874	68	18F
0005434573187	10874	69	18K
0005435612152	10874	70	18J
0005435612006	10874	71	18H
0005435612645	10874	72	19A
0005435424787	10874	73	19D
0005435304156	10874	74	19C
0005434244989	10874	75	19F
0005434656556	10874	76	19E
0005434573258	10874	77	19H
0005435612007	10874	78	19G
0005435424810	10874	79	19K
0005435319571	10874	80	20C
0005435424812	10874	81	20B
0005435612486	10874	82	20A
0005435424825	10874	83	20E
0005435612259	10874	84	20D
0005435612607	10874	85	20G
0005435612771	10874	86	20F
0005434244966	10874	87	20K
0005435424793	10874	88	20H
0005435424795	10874	89	21B
0005435424804	10874	90	21A
0005435424789	10874	91	21D
0005435612677	10874	92	21C
0005434244976	10874	93	21G
0005434656555	10874	94	21F
0005434244971	10874	95	21E
0005435612425	10874	96	21J
0005435097073	10874	97	21H
0005435424786	10874	98	22A
0005435612787	10874	99	21K
0005432165036	10874	100	22C
0005435097094	10874	101	22B
0005435612426	10874	102	22F
0005435612123	10874	103	22E
0005435424829	10874	104	22D
0005435612710	10874	105	22G
0005435380293	10874	106	22K
0005435612744	10874	107	22J
0005435612735	10874	108	22H
0005434343899	10874	109	23C
0005434244969	10874	110	23B
0005432363414	10874	111	23A
0005435424838	10874	112	23F
0005435612676	10874	113	23J
0005435304157	10874	114	23H
0005435424799	10874	115	23K
0005435424782	10874	116	24E
0005432165039	10874	117	24D
0005434573253	10874	118	25B
0005435424802	10874	119	25A
0005435424780	10874	120	25C
0005434244972	10874	121	25F
0005435612609	10874	122	25K
0005435612541	10874	123	25J
0005435612570	10874	124	26E
0005435424805	10874	125	26D
0005435424835	10874	126	26C
0005435612555	10874	127	26G
0005434573213	10874	128	26K
0005434244994	10874	129	27A
0005435097113	10874	130	27B
0005435424811	10874	131	27F
0005435424832	10874	132	27E
0005435424803	10874	133	27H
0005435612754	10874	134	27G
0005434573214	10874	135	28A
0005432363416	10874	136	27K
0005434656557	10874	137	28B
0005435612661	10874	138	28E
0005435612723	10874	139	28C
0005434343853	10874	140	28G
0005435490191	10874	141	28F
0005435424821	10874	142	28J
0005434343924	10874	143	28H
0005434343764	10874	144	29B
0005435424788	10874	145	29A
0005435424781	10874	146	28K
0005434343827	10874	147	29D
0005435424794	10874	148	29C
0005435612268	10874	149	29F
0005435424790	10874	150	29J
0005434244986	10874	151	30B
0005435612803	10874	152	30A
0005434244985	10874	153	30D
0005435612508	10874	154	30C
0005435424814	10874	155	30E
0005435612750	10874	156	30J
0005435097107	10874	157	31B
0005434343823	10874	158	31A
0005432165034	10874	159	30K
0005435097096	10874	160	31D
0005434343806	10874	161	31C
0005435424827	10874	162	31E
0005434244980	10874	163	31H
0005435612612	10874	164	31G
0005435319572	10874	165	31K
0005435424824	10874	166	31J
0005435424785	10874	167	32C
0005432165040	10874	168	32B
0005434244984	10874	169	32A
0005435612779	10874	170	32E
0005435424800	10874	171	32D
0005432363417	10874	172	32G
0005435424801	10874	173	32F
0005435424798	10874	174	32J
0005435612757	10874	175	33B
0005434343880	10874	176	33A
0005435424819	10874	177	32K
0005434244974	10874	178	33D
0005434343938	10874	179	33C
0005434343950	10874	180	33F
0005435612324	10874	181	33E
0005435305013	10874	182	33J
0005435612542	10874	183	33H
0005434573254	10874	184	33G
0005435424813	10874	185	33K
0005435612005	10874	186	34B
0005435380288	10874	187	34A
0005432166902	10874	188	34E
0005435612706	10874	189	34D
0005435424834	10874	190	34H
0005435424837	10874	191	34G
0005434343879	10874	192	34F
0005435612151	10874	193	34J
0005434244968	10874	194	35B
0005435424796	10874	195	35A
0005432841012	10874	196	35E
0005435424842	10874	197	35D
0005434343826	10874	198	35C
0005435612636	10874	199	35G
0005435424776	10874	200	35F
0005435612656	10874	201	35J
0005435319574	10874	202	35H
0005435424779	10874	203	36A
0005434343841	10874	204	35K
0005435380292	10874	205	36B
0005434573134	10874	206	36E
0005435380290	10874	207	36D
0005435555352	10874	208	36H
0005434343833	10874	209	36G
0005435612709	10874	210	36F
0005435097093	10874	211	36K
0005435319575	10874	212	36J
0005435612729	10874	213	37B
0005435424791	10874	214	37C
0005435612571	10874	215	37G
0005434244982	10874	216	37F
0005435612504	10874	217	37E
0005435612663	10874	218	37J
0005435612799	10874	219	37H
0005435612122	10874	220	38A
0005435612796	10874	221	37K
0005435380291	10874	222	38C
0005435612372	10874	223	38B
0005433719141	10874	224	38J
0005435612548	10874	225	38H
0005435424843	10874	226	39B
0005434343834	10874	227	39A
0005432165037	10874	228	38K
0005435612374	10874	229	39D
0005434343832	10874	230	39C
0005435424809	10874	231	39F
0005435612573	10874	232	39H
0005435612717	10874	233	40A
0005434244967	10874	234	39K
0005435612323	10874	235	39J
0005435612718	10874	236	40C
0005435555353	10874	237	40E
0005435612446	10874	238	40D
0005434343828	10874	239	40H
0005435612537	10874	240	40F
0005435612660	10874	241	40K
0005432166903	10874	242	40J
0005435612574	10874	243	41B
0005434343774	10874	244	41A
0005435612520	10874	245	41D
0005435612348	10874	246	41C
0005435380289	10874	247	41E
0005435612737	10874	248	41G
0005435424792	10874	249	42A
0005434244991	10874	250	41K
0005434244990	10874	251	41J
0005435612736	10874	252	42C
0005435424777	10874	253	42E
0005435424830	10874	254	42D
0005435097115	10874	255	42G
0005435612342	10874	256	42F
0005435491410	10874	257	42K
0005435612363	10874	258	42H
0005435424844	10874	259	43B
0005435424826	10874	260	43A
0005435424797	10874	261	43C
0005434343901	10874	262	43E
0005435612780	10874	263	43H
0005435612662	10874	264	43G
0005435612764	10874	265	43K
0005435319573	10874	266	43J
0005435305014	10874	267	44C
0005435424823	10874	268	44B
0005435319568	10874	269	44E
0005435612380	10874	270	44D
0005434343777	10874	271	44G
0005435612788	10874	272	44F
0005435612774	10874	273	44J
0005434244993	10874	274	44H
0005435097105	10874	275	45B
0005435424822	10874	276	45A
0005434573140	10874	277	44K
0005434573266	10874	278	45C
0005435612547	10874	279	45F
0005434244965	10874	280	45E
0005435612447	10874	281	45J
0005435424839	10874	282	45H
0005434244977	10874	283	45G
0005435424807	10874	284	45K
0005435612758	10874	285	46B
0005434244992	10874	286	46A
0005435097114	10874	287	46E
0005435612741	10874	288	46D
0005435612539	10874	289	46C
0005434343940	10874	290	46G
0005435612783	10874	291	46F
0005435612519	10874	292	46J
0005435612610	10874	293	47A
0005435097106	10874	294	47D
0005435612167	10874	295	47C
0005435612698	10874	296	47G
0005435612269	10874	297	47F
0005435424815	10874	298	48A
0005435612743	10874	299	47K
0005432165038	10874	300	47H
0005434244978	10874	301	48C
0005435612772	10874	302	48F
0005435612474	10874	303	48E
0005434343946	10874	304	48H
0005435097112	10874	305	48K
0005435424833	10874	306	49D
0005434343804	10874	307	49C
0005435305012	10874	308	49F
0005434244970	10874	309	49K
0005435612685	10874	310	49H
0005435612697	10874	311	50C
0005435424817	10874	312	50A
0005435612277	10874	313	50E
0005435612538	10874	314	50D
0005432363415	10874	315	50G
0005435097092	10874	316	51D
0005435424840	10874	317	50K
0005435304155	10874	318	50H
0005435319576	10874	319	51G
0005433633831	3325	1	1A
0005432459507	3325	2	1C
0005433633815	3325	3	2A
0005433507185	3325	4	1F
0005433507183	3325	5	2C
0005433805377	3325	6	2D
0005433633820	3325	7	3A
0005432459557	3325	8	2F
0005432459385	3325	9	3C
0005432459390	3325	10	3D
0005432459439	3325	11	4A
0005432459421	3325	12	4C
0005432181708	3325	13	4F
0005433805362	3325	14	4D
0005433805385	3325	15	5A
0005433805397	3325	16	5D
0005433805364	3325	17	6A
0005433633826	3325	18	6C
0005433805357	3325	19	6F
0005433805360	3325	20	6D
0005432181725	3325	21	7A
0005433805381	3325	22	7C
0005433633833	3325	23	7D
0005433507186	3325	24	8A
0005433633827	3325	25	7F
0005433805369	3325	26	8B
0005433633816	3325	27	8C
0005432459365	3325	28	8E
0005432459366	3325	29	8D
0005432181728	3325	30	8F
0005433633832	3325	31	9B
0005432459487	3325	32	9A
0005432459584	3325	33	9C
0005432459445	3325	34	9D
0005433507177	3325	35	9F
0005432181710	3325	36	9E
0005432181723	3325	37	10A
0005433633807	3325	38	10C
0005433805378	3325	39	10B
0005432459257	3325	40	10E
0005432459375	3325	41	10D
0005432459355	3325	42	10F
0005433633823	3325	43	11B
0005432459258	3325	44	11A
0005433507178	3325	45	11C
0005433805383	3325	46	11D
0005433633812	3325	47	11F
0005433805363	3325	48	11E
0005432459427	3325	49	12A
0005432181727	3325	50	12C
0005433805387	3325	51	12B
0005433805389	3325	52	12E
0005432459583	3325	53	12D
0005432459560	3325	54	12F
0005432181711	3325	55	13B
0005433805398	3325	56	13A
0005433507189	3325	57	13C
0005433633824	3325	58	13F
0005432181715	3325	59	13E
0005432459446	3325	60	14C
0005432181724	3325	61	14B
0005432181718	3325	62	14A
0005432459585	3325	63	14D
0005432181716	3325	64	14F
0005433633808	3325	65	15A
0005432459311	3325	66	15C
0005433805361	3325	67	15B
0005433805366	3325	68	15E
0005432459397	3325	69	15F
0005432181722	3325	70	16A
0005432459087	3325	71	16C
0005432459310	3325	72	16B
0005433805368	3325	73	16E
0005433805391	3325	74	16D
0005433633838	3325	75	16F
0005433805359	3325	76	17A
0005433633836	3325	77	17C
0005432459388	3325	78	17B
0005433633821	3325	79	17D
0005432181717	3325	80	17F
0005433507180	3325	81	17E
0005432181719	3325	82	18A
0005432181713	3325	83	18B
0005433633818	3325	84	18D
0005433805394	3325	85	18C
0005433805367	3325	86	18E
0005432459532	3325	87	18F
0005432181706	3325	88	19C
0005433805380	3325	89	19B
0005433805384	3325	90	19D
0005433507187	3325	91	19E
0005432181707	3325	92	20B
0005433633828	3325	93	20A
0005433507181	3325	94	20C
0005432459238	3325	95	20E
0005432181720	3325	96	20D
0005432181721	3325	97	20F
0005433805388	3325	98	21A
0005432459444	3325	99	21B
0005433805358	3325	100	21D
0005433633835	3325	101	21C
0005433633817	3325	102	21E
0005433633839	3325	103	21F
0005433805370	3325	104	22B
0005433633834	3325	105	22A
0005433633811	3325	106	22D
0005432181709	3325	107	22E
0005432459559	3325	108	22F
0005433507190	3325	109	23A
0005432459488	3325	110	23C
0005432459389	3325	111	23B
0005433633830	3325	112	23D
0005432459386	3325	113	23E
0005432181726	3325	114	23F
0005433805371	3325	115	24B
0005433633825	3325	116	24A
0005433805392	3325	117	24C
0005432459426	3325	118	24E
0005433805373	3325	119	24F
0005432181729	3325	120	25A
0005432459134	3325	121	25C
0005433805393	3325	122	25B
0005432459489	3325	123	25E
0005432459561	3325	124	25D
0005433633809	3325	125	25F
0005433633819	3325	126	26A
0005433805396	3325	127	26B
0005433633810	3325	128	26C
0005433633829	3325	129	26E
0005432459354	3325	130	26D
0005433805390	3325	131	26F
0005433805375	3325	132	27B
0005433507188	3325	133	27A
0005432459305	3325	134	27C
0005433507179	3325	135	27D
0005433507184	3325	136	28A
0005433805399	3325	137	27F
0005433805382	3325	138	28B
0005433633813	3325	139	28C
0005433805365	3325	140	28E
0005432459312	3325	141	28D
0005433805386	3325	142	28F
0005433507182	3325	143	29B
0005433633822	3325	144	29A
0005432459384	3325	145	29C
0005432459357	3325	146	29D
0005433805372	3325	147	29F
0005432181712	3325	148	29E
0005433633814	3325	149	30A
0005433805379	3325	150	30B
0005432459268	3325	151	30D
0005433805374	3325	152	30C
0005433633840	3325	153	30E
0005432459453	3325	154	30F
0005433805376	3325	155	31B
0005433805395	3325	156	31A
0005433633837	3325	157	31D
0005432459356	3325	158	31F
0005432181714	3325	159	31E
0005435884896	3324	1	1A
0005435884729	3324	2	1C
0005435884865	3324	3	3F
0005435884837	3324	4	4F
0005435884525	3324	5	6A
0005435884796	3324	6	7C
0005435884935	3324	7	7D
0005435884844	3324	8	7F
0005435884946	3324	9	8C
0005435884883	3324	10	9D
0005435884762	3324	11	10B
0005435884761	3324	12	11B
0005435885030	3324	13	11A
0005435884866	3324	14	11D
0005435884794	3324	15	12C
0005435884793	3324	16	12E
0005435885018	3324	17	13C
0005435884949	3324	18	13D
0005435884730	3324	19	13E
0005435884850	3324	20	14B
0005435884608	3324	21	15B
0005435884845	3324	22	15A
0005435884985	3324	23	16F
0005435884947	3324	24	17C
0005435885007	3324	25	18B
0005435884779	3324	26	18D
0005435885037	3324	27	18C
0005435884969	3324	28	19E
0005435884753	3324	29	20B
0005435884846	3324	30	20D
0005435884864	3324	31	20F
0005435884840	3324	32	21A
0005435884987	3324	33	21D
0005435884683	3324	34	22A
0005435884868	3324	35	23A
0005435884945	3324	36	24A
0005435884986	3324	37	24F
0005435884661	3324	38	26A
0005435884830	3324	39	26E
0005435885019	3324	40	27D
0005435884760	3324	41	27E
0005435884801	3324	42	28B
0005435884876	3324	43	30B
0005435884609	3324	44	30F
0005435884839	3324	45	31C
0005435884599	3324	46	31E
0005435885263	8236	1	1A
0005432459890	8236	2	1C
0005434312321	8236	3	1D
0005433507053	8236	4	2A
0005435885262	8236	5	1F
0005432459871	8236	6	2C
0005433506940	8236	7	2F
0005432459915	8236	8	2D
0005432459906	8236	9	3F
0005432459898	8236	10	3D
0005432459865	8236	11	4A
0005432042719	8236	12	4C
0005432042722	8236	13	4F
0005435885243	8236	14	4D
0005435885244	8236	15	5A
0005433507026	8236	16	5D
0005432459886	8236	17	5C
0005433507003	8236	18	5F
0005432459888	8236	19	6A
0005433507054	8236	20	6C
0005432459866	8236	21	6D
0005435885252	8236	22	7A
0005432042716	8236	23	7C
0005432459887	8236	24	7F
0005433507072	8236	25	8A
0005435885266	8236	26	8B
0005432459909	8236	27	8D
0005432459901	8236	28	8E
0005432459881	8236	29	9A
0005433507071	8236	30	8F
0005432459895	8236	31	9B
0005433507042	8236	32	9C
0005435885267	8236	33	9D
0005435885270	8236	34	10A
0005432459874	8236	35	10D
0005432459878	8236	36	10C
0005432459883	8236	37	10E
0005432042715	8236	38	11A
0005433507004	8236	39	10F
0005432042720	8236	40	11D
0005432459893	8236	41	11E
0005432459896	8236	42	12A
0005432042710	8236	43	12B
0005435885259	8236	44	12D
0005435885269	8236	45	12E
0005435885275	8236	46	13A
0005432459880	8236	47	13B
0005432042714	8236	48	13D
0005435885242	8236	49	14A
0005434326270	8236	50	14B
0005433506948	8236	51	14C
0005432042721	8236	52	14E
0005435885248	8236	53	14D
0005432459885	8236	54	14F
0005435885274	8236	55	15B
0005432459894	8236	56	15D
0005435885276	8236	57	15F
0005435885246	8236	58	15E
0005432042717	8236	59	16B
0005435885272	8236	60	16D
0005432459897	8236	61	16C
0005433507025	8236	62	16E
0005435885253	8236	63	16F
0005432459869	8236	64	17C
0005432459867	8236	65	17B
0005435885256	8236	66	17D
0005434312320	8236	67	18A
0005432459916	8236	68	18C
0005433507040	8236	69	18B
0005435885249	8236	70	19B
0005432459913	8236	71	18F
0005432459908	8236	72	18E
0005435885261	8236	73	19D
0005432459891	8236	74	19C
0005432459873	8236	75	19E
0005432459882	8236	76	20B
0005435885265	8236	77	20A
0005433506946	8236	78	20C
0005432459917	8236	79	20D
0005433507015	8236	80	20F
0005432459876	8236	81	20E
0005433507002	8236	82	21A
0005432459899	8236	83	21B
0005432459902	8236	84	21C
0005435885257	8236	85	21E
0005432042713	8236	86	22B
0005432459910	8236	87	22A
0005435885250	8236	88	22E
0005432042712	8236	89	22D
0005432459892	8236	90	22F
0005432459864	8236	91	23B
0005432459907	8236	92	23A
0005435885277	8236	93	23D
0005435885245	8236	94	23C
0005434326271	8236	95	23F
0005432459879	8236	96	24B
0005432459900	8236	97	24C
0005432042718	8236	98	25B
0005435885255	8236	99	25A
0005433507058	8236	100	25D
0005435885251	8236	101	25E
0005433507016	8236	102	26A
0005432459872	8236	103	26C
0005432459884	8236	104	26E
0005432459868	8236	105	26D
0005432459875	8236	106	26F
0005435885264	8236	107	27A
0005432459889	8236	108	27C
0005435885273	8236	109	27D
0005435885254	8236	110	27F
0005435885271	8236	111	27E
0005433506968	8236	112	28D
0005435885260	8236	113	28C
0005433506941	8236	114	28E
0005433506945	8236	115	29A
0005432459903	8236	116	28F
0005432459877	8236	117	29C
0005432459904	8236	118	29B
0005432042711	8236	119	29E
0005432459914	8236	120	29D
0005432459905	8236	121	29F
0005432042723	8236	122	30A
0005433506978	8236	123	30B
0005435885247	8236	124	30D
0005432459870	8236	125	30C
0005432459912	8236	126	30F
0005432459911	8236	127	31B
0005432042709	8236	128	31A
0005435885268	8236	129	31C
0005435885258	8236	130	31D
0005433507041	8236	131	31E
0005433804914	8235	1	1A
0005433804975	8235	2	2C
0005433805123	8235	3	2F
0005433633494	8235	4	4A
0005433633556	8235	5	4C
0005433633676	8235	6	5C
0005433633394	8235	7	5F
0005433633520	8235	8	5D
0005433805000	8235	9	6C
0005433633490	8235	10	6D
0005433805215	8235	11	7D
0005433804996	8235	12	8A
0005433633492	8235	13	8F
0005433805042	8235	14	9D
0005433633502	8235	15	10A
0005433804931	8235	16	10D
0005433633516	8235	17	11C
0005433633647	8235	18	11B
0005433633475	8235	19	11F
0005433805214	8235	20	12A
0005433804910	8235	21	12B
0005433805138	8235	22	12D
0005433633517	8235	23	12F
0005433633439	8235	24	13C
0005433805014	8235	25	13B
0005433804943	8235	26	13D
0005433633361	8235	27	13E
0005433804852	8235	28	13F
0005433805120	8235	29	14B
0005433804797	8235	30	14D
0005434271294	8235	31	14F
0005433633504	8235	32	15B
0005433633441	8235	33	15A
0005433804928	8235	34	15E
0005433633375	8235	35	16A
0005433804866	8235	36	15F
0005434143716	8235	37	16C
0005433805152	8235	38	17B
0005433633639	8235	39	17A
0005433804909	8235	40	17C
0005433633431	8235	41	18A
0005433633440	8235	42	18E
0005433805043	8235	43	19B
0005433633675	8235	44	18F
0005433804867	8235	45	19D
0005433633545	8235	46	19C
0005433633362	8235	47	20A
0005433633521	8235	48	20C
0005433805044	8235	49	20F
0005433805145	8235	50	20E
0005434271293	8235	51	21F
0005433805147	8235	52	22B
0005433633580	8235	53	22D
0005433633407	8235	54	22C
0005433633442	8235	55	22F
0005433805146	8235	56	23C
0005433804974	8235	57	23E
0005433633470	8235	58	23F
0005433805030	8235	59	24B
0005433805006	8235	60	24A
0005433804962	8235	61	24D
0005433633500	8235	62	24F
0005433633646	8235	63	25E
0005433805031	8235	64	26B
0005433633478	8235	65	26C
0005433633505	8235	66	26E
0005434143715	8235	67	27A
0005433804963	8235	68	27B
0005433804992	8235	69	28A
0005433633430	8235	70	28B
0005433633406	8235	71	28F
0005433633533	8235	72	29A
0005433633501	8235	73	29E
0005433633677	8235	74	30B
0005433633586	8235	75	30C
0005433633534	8235	76	31B
0005433805063	8235	77	31C
0005434183557	8234	1	25A
0005432727939	4611	1	1C
0005432383194	4611	2	1D
0005432383167	4611	3	1F
0005433454876	4611	4	2A
0005433722228	4611	5	2C
0005432383173	4611	6	2F
0005432383189	4611	7	3A
0005432383188	4611	8	3D
0005432383193	4611	9	3F
0005432383186	4611	10	4A
0005432727933	4611	11	4C
0005432727944	4611	12	5A
0005432383190	4611	13	5D
0005432727942	4611	14	5E
0005432383199	4611	15	5F
0005432383170	4611	16	6A
0005432383198	4611	17	6C
0005432383175	4611	18	6D
0005432727941	4611	19	7E
0005432727937	4611	20	8A
0005433722226	4611	21	8C
0005432727936	4611	22	8E
0005432383171	4611	23	9C
0005432383179	4611	24	10C
0005432383192	4611	25	10E
0005432383197	4611	26	11C
0005432727935	4611	27	11E
0005433722229	4611	28	11F
0005433722227	4611	29	12D
0005432383191	4611	30	12E
0005432383177	4611	31	13A
0005432727934	4611	32	13C
0005432383176	4611	33	13F
0005432383182	4611	34	14E
0005432383172	4611	35	14F
0005432727940	4611	36	15D
0005433722225	4611	37	15E
0005432383196	4611	38	15F
0005432383168	4611	39	16D
0005432383200	4611	40	16E
0005432383178	4611	41	16F
0005432727945	4611	42	17A
0005432727938	4611	43	17C
0005432383174	4611	44	17E
0005432383169	4611	45	17F
0005432383187	4611	46	18D
0005432383195	4611	47	18F
0005432383180	4611	48	19A
0005432727943	4611	49	19E
0005432383181	4611	50	19F
0005432383185	4611	51	20C
0005432383184	4611	52	20D
0005432383201	4611	53	20E
0005432383183	4611	54	20F
0005432382677	30207	1	1A
0005432382676	30207	2	1C
0005432727819	30207	3	1D
0005433194842	30207	4	1F
0005432382749	30207	5	2A
0005432727825	30207	6	2C
0005432727906	30207	7	3A
0005432382606	30207	8	3C
0005432382649	30207	9	3F
0005432382682	30207	10	4A
0005432727838	30207	11	4C
0005432382742	30207	12	4E
0005432382671	30207	13	4F
0005432382616	30207	14	5C
0005432382577	30207	15	5D
0005432727857	30207	16	5E
0005432727885	30207	17	6C
0005433722128	30207	18	6D
0005432382576	30207	19	6F
0005432382652	30207	20	7C
0005432382750	30207	21	7D
0005432382588	30207	22	9C
0005432382589	30207	23	10D
0005432382621	30207	24	10F
0005432727829	30207	25	11D
0005432382683	30207	26	11F
0005432382748	30207	27	12A
0005432727818	30207	28	12C
0005432727828	30207	29	12D
0005433722121	30207	30	12F
0005432382721	30207	31	13E
0005433451605	30207	32	13F
0005432727860	30207	33	14C
0005433194841	30207	34	14F
0005432382722	30207	35	15A
0005433194832	30207	36	15C
0005433451601	30207	37	15D
0005432727830	30207	38	15E
0005432382688	30207	39	16A
0005432382689	30207	40	16D
0005433453736	30207	41	16E
0005432382587	30207	42	17A
0005432727859	30207	43	17C
0005432382684	30207	44	17F
0005432382526	30207	45	18A
0005432382615	30207	46	18C
0005433722131	30207	47	18D
0005432382672	30207	48	18E
0005432727767	30207	49	18F
0005432382687	30207	50	19A
0005432382611	30207	51	20C
0005433451590	30207	52	20D
0005432727824	30207	53	20E
0005432382751	30207	54	20F
0005435541015	1767	1	1D
0005435529263	1767	2	1F
0005435541003	1767	3	2C
0005435529274	1767	4	2D
0005433516884	1767	5	2F
0005435529261	1767	6	3C
0005435529268	1767	7	3D
0005435529266	1767	8	4A
0005435541000	1767	9	4D
0005435541017	1767	10	4E
0005435541020	1767	11	5E
0005433516891	1767	12	6C
0005433516890	1767	13	6D
0005435529258	1767	14	6F
0005432294488	1767	15	7C
0005435529256	1767	16	7D
0005433516886	1767	17	7F
0005435529272	1767	18	8A
0005435529273	1767	19	8C
0005435541002	1767	20	8F
0005435541012	1767	21	9A
0005435541004	1767	22	9C
0005435541014	1767	23	9D
0005433516885	1767	24	9E
0005435541009	1767	25	9F
0005432925001	1767	26	10A
0005433516888	1767	27	10C
0005435541008	1767	28	10F
0005435541018	1767	29	11A
0005435529265	1767	30	11C
0005433516889	1767	31	11E
0005435529269	1767	32	12A
0005432925007	1767	33	12D
0005435541016	1767	34	13C
0005435529264	1767	35	13D
0005435541006	1767	36	13F
0005435529267	1767	37	14A
0005435529271	1767	38	14E
0005433516892	1767	39	14F
0005435541011	1767	40	15A
0005435529257	1767	41	15C
0005435541019	1767	42	15D
0005435541007	1767	43	15F
0005435541010	1767	44	16A
0005435529276	1767	45	16E
0005435529270	1767	46	16F
0005435540999	1767	47	17C
0005435529275	1767	48	17D
0005435541013	1767	49	17E
0005435541022	1767	50	17F
0005435529259	1767	51	18A
0005435529260	1767	52	18D
0005435541021	1767	53	18E
0005432294487	1767	54	18F
0005433516887	1767	55	19D
0005435541001	1767	56	20A
0005435529262	1767	57	20D
0005435541005	1767	58	20F
0005435517602	22022	1	1A
0005435517734	22022	2	1C
0005432925039	22022	3	2C
0005435517673	22022	4	2D
0005435517669	22022	5	2F
0005433516821	22022	6	3D
0005433516836	22022	7	4D
0005435517723	22022	8	5D
0005435540731	22022	9	5F
0005435540820	22022	10	6C
0005432925035	22022	11	6E
0005435517736	22022	12	7C
0005435540783	22022	13	8D
0005435517718	22022	14	8E
0005433516823	22022	15	8F
0005432925038	22022	16	9E
0005435517674	22022	17	10C
0005433516787	22022	18	10E
0005435540851	22022	19	11C
0005435540730	22022	20	12C
0005435517672	22022	21	12D
0005432925036	22022	22	12F
0005435517726	22022	23	13C
0005435540817	22022	24	13F
0005435540793	22022	25	14C
0005435517789	22022	26	14D
0005433516819	22022	27	14E
0005432925037	22022	28	15C
0005435540763	22022	29	15D
0005433516756	22022	30	16A
0005435540751	22022	31	16F
0005435517603	22022	32	17A
0005435540804	22022	33	17D
0005435517727	22022	34	18A
0005433516804	22022	35	18C
0005435517728	22022	36	18E
0005435540819	22022	37	18F
0005435540794	22022	38	19A
0005433516820	22022	39	19D
0005435540784	22022	40	19E
0005435517722	22022	41	20C
0005433516822	22022	42	20D
0005435540805	22022	43	20F
0005432839048	7402	1	1A
0005435491425	7402	2	1C
0005435491418	7402	3	1D
0005432839051	7402	4	1F
0005432839042	7402	5	2A
0005434458809	7402	6	2C
0005435252564	7402	7	2D
0005435252574	7402	8	2F
0005432839052	7402	9	3A
0005432839027	7402	10	3C
0005432839046	7402	11	3D
0005432839029	7402	12	3F
0005432839032	7402	13	4A
0005435252518	7402	14	4C
0005434458803	7402	15	4D
0005434458799	7402	16	4E
0005432839022	7402	17	4F
0005434458814	7402	18	5A
0005434664939	7402	19	5C
0005432839031	7402	20	5E
0005432839043	7402	21	5F
0005435491417	7402	22	6A
0005432839041	7402	23	6C
0005435252637	7402	24	6D
0005435252550	7402	25	6E
0005434458796	7402	26	6F
0005434458801	7402	27	7A
0005432841011	7402	28	7D
0005432839047	7402	29	7C
0005434458807	7402	30	7E
0005434458800	7402	31	7F
0005435252600	7402	32	8A
0005432839030	7402	33	8D
0005432073391	7402	34	8E
0005434458816	7402	35	8F
0005432839038	7402	36	9A
0005432839037	7402	37	9C
0005432823448	7402	38	9D
0005434458815	7402	39	9E
0005432073389	7402	40	9F
0005435252493	7402	41	10A
0005434458804	7402	42	10C
0005434458813	7402	43	10D
0005434458795	7402	44	10E
0005434458812	7402	45	10F
0005435252559	7402	46	11A
0005434458797	7402	47	11C
0005435491424	7402	48	11D
0005432839033	7402	49	11E
0005434664940	7402	50	11F
0005435252561	7402	51	12A
0005435491423	7402	52	12C
0005432839025	7402	53	12D
0005435491409	7402	54	12E
0005434458806	7402	55	12F
0005434458810	7402	56	13A
0005435252638	7402	57	13D
0005432839050	7402	58	13E
0005435252557	7402	59	13F
0005432073392	7402	60	14A
0005434458802	7402	61	14C
0005434458798	7402	62	14D
0005432839045	7402	63	14E
0005435252527	7402	64	14F
0005432839044	7402	65	15A
0005435252528	7402	66	15C
0005432839039	7402	67	15D
0005435252541	7402	68	15E
0005434458811	7402	69	16A
0005435252558	7402	70	16C
0005435252543	7402	71	16D
0005435252542	7402	72	16E
0005435252477	7402	73	16F
0005432839024	7402	74	17A
0005432073390	7402	75	17C
0005435252520	7402	76	17D
0005435252519	7402	77	17E
0005432839028	7402	78	17F
0005432839036	7402	79	18A
0005435252562	7402	80	18D
0005435252616	7402	81	18E
0005435252551	7402	82	18F
0005432839040	7402	83	19A
0005432839023	7402	84	19C
0005432839035	7402	85	19D
0005432823449	7402	86	19E
0005434458808	7402	87	20A
0005432839049	7402	88	20C
0005434458805	7402	89	20D
0005432839026	7402	90	20E
0005432839034	7402	91	20F
0005435252712	28943	1	1A
0005432838847	28943	2	1C
0005432838759	28943	3	2A
0005434458647	28943	4	2C
0005434458618	28943	5	2F
0005432838762	28943	6	3A
0005435491441	28943	7	3D
0005434664962	28943	8	3F
0005432838726	28943	9	4A
0005432838752	28943	10	4C
0005432838693	28943	11	4D
0005435252699	28943	12	4E
0005432823432	28943	13	4F
0005432838681	28943	14	5A
0005435491440	28943	15	5C
0005435252703	28943	16	5D
0005432838846	28943	17	5E
0005434458675	28943	18	5F
0005434458616	28943	19	6A
0005435252706	28943	20	6C
0005432838840	28943	21	6D
0005432838744	28943	22	6F
0005435252711	28943	23	7A
0005434458587	28943	24	7C
0005432001024	28943	25	7E
0005432838753	28943	26	7F
0005432838725	28943	27	8A
0005434458617	28943	28	8C
0005432838702	28943	29	8E
0005432001023	28943	30	8F
0005434458674	28943	31	9A
0005434458673	28943	32	9C
0005432823431	28943	33	9E
0005432838745	28943	34	10C
0005432838701	28943	35	10D
0005432838743	28943	36	10E
0005432838760	28943	37	11A
0005435252710	28943	38	11E
0005434458588	28943	39	12A
0005432838690	28943	40	12E
0005434458676	28943	41	12F
0005435252696	28943	42	13A
0005434458656	28943	43	13C
0005435252709	28943	44	13D
0005432840999	28943	45	13F
0005434458665	28943	46	14A
0005434458695	28943	47	14C
0005432840993	28943	48	14E
0005432838887	28943	49	14F
0005435252698	28943	50	15C
0005434664961	28943	51	15E
0005432838820	28943	52	15F
0005434458663	28943	53	16A
0005432838682	28943	54	16C
0005435491442	28943	55	16E
0005435252707	28943	56	17A
0005432838665	28943	57	17C
0005435252705	28943	58	17D
0005432840994	28943	59	17F
0005432838828	28943	60	17E
0005432838730	28943	61	18C
0005432001022	28943	62	18E
0005432838859	28943	63	18F
0005435252708	28943	64	19A
0005435252702	28943	65	19C
0005434664960	28943	66	19D
0005435252713	28943	67	19E
0005435252704	28943	68	19F
0005435252701	28943	69	20A
0005434458634	28943	70	20C
0005435252697	28943	71	20D
0005435252700	28943	72	20E
0005434458664	28943	73	20F
0005434275972	8811	1	1D
0005434276001	8811	2	2F
0005434276002	8811	3	3D
0005434275971	8811	4	4C
0005434276000	8811	5	6C
0005435990625	8811	6	6E
0005435990627	8811	7	7B
0005435990623	8811	8	7F
0005435990621	8811	9	8A
0005434275979	8811	10	9C
0005434275997	8811	11	10A
0005435990622	8811	12	10C
0005435990624	8811	13	12B
0005435990626	8811	14	15F
0005435990628	8811	15	16B
0005434275996	8811	16	19E
0005435990620	8811	17	21F
0005434276026	15764	1	2C
0005435990582	15764	2	2F
0005434276025	15764	3	3F
0005435990555	15764	4	3D
0005435990556	15764	5	4F
0005435990564	15764	6	5D
0005435990574	15764	7	7E
0005435990566	15764	8	11B
0005435990563	15764	9	13F
0005434276027	15764	10	16A
0005435990581	15764	11	16B
0005434276028	15764	12	17A
0005434276029	15764	13	19B
0005435990549	15764	14	20F
0005435990573	15764	15	21E
0005433476880	20633	1	2B
0005432427142	20633	2	3C
0005433476871	20633	3	3D
0005433476879	20633	4	5C
0005433476868	20633	5	6A
0005432427141	20633	6	6B
0005433476878	20633	7	7B
0005432427140	20633	8	20B
0005432427143	20633	9	22A
0005433476869	20633	10	22D
0005432360344	6390	1	1A
0005432062228	6390	2	1C
0005435176930	6390	3	1D
0005434149650	6390	4	2A
0005432360347	6390	5	1F
0005435176909	6390	6	2C
0005432336034	6390	7	2D
0005432360362	6390	8	3A
0005435176874	6390	9	2F
0005432360360	6390	10	3D
0005435490198	6390	11	3C
0005435723023	6390	12	3F
0005432363414	6390	13	4C
0005435176937	6390	14	4B
0005432360382	6390	15	4D
0005435723024	6390	16	4E
0005432360345	6390	17	4F
0005435176872	6390	18	5B
0005432360356	6390	19	5A
0005432360352	6390	20	5D
0005435176917	6390	21	5C
0005434149590	6390	22	5E
0005434149593	6390	23	5F
0005434149594	6390	24	6B
0005432062229	6390	25	6A
0005432360376	6390	26	6D
0005432360350	6390	27	6E
0005432336040	6390	28	7A
0005432360374	6390	29	7B
0005432360372	6390	30	7E
0005435176802	6390	31	7D
0005432360349	6390	32	7F
0005432360383	6390	33	8A
0005432336038	6390	34	8B
0005434149626	6390	35	8C
0005435176913	6390	36	8D
0005432336037	6390	37	8F
0005432360358	6390	38	8E
0005435176854	6390	39	9A
0005432360343	6390	40	9B
0005432360351	6390	41	9D
0005432360359	6390	42	9C
0005434149651	6390	43	9E
0005435176924	6390	44	9F
0005432360370	6390	45	10B
0005432336039	6390	46	10C
0005432062231	6390	47	10D
0005432360365	6390	48	11A
0005435490197	6390	49	10E
0005432360384	6390	50	11C
0005432360380	6390	51	11B
0005432336036	6390	52	11E
0005435176858	6390	53	11F
0005435176923	6390	54	12A
0005434149589	6390	55	12C
0005432360348	6390	56	12B
0005435176857	6390	57	12E
0005432360390	6390	58	12F
0005432336031	6390	59	13A
0005434149624	6390	60	13C
0005432360367	6390	61	13B
0005432336032	6390	62	13E
0005432360368	6390	63	13D
0005435723030	6390	64	14A
0005432062230	6390	65	14B
0005435176892	6390	66	14C
0005432336035	6390	67	14D
0005432360389	6390	68	14E
0005432360361	6390	69	15A
0005435176859	6390	70	15B
0005432363417	6390	71	15C
0005435176875	6390	72	15E
0005432360379	6390	73	15D
0005432360375	6390	74	16A
0005435176934	6390	75	15F
0005432360364	6390	76	16B
0005435176785	6390	77	16D
0005432363416	6390	78	16E
0005432360354	6390	79	16F
0005432360355	6390	80	17B
0005432062232	6390	81	17A
0005435176873	6390	82	17C
0005432360387	6390	83	17E
0005435176832	6390	84	17F
0005434149617	6390	85	18B
0005432360386	6390	86	18C
0005432360353	6390	87	18D
0005432062227	6390	88	18F
0005435490191	6390	89	18E
0005432363415	6390	90	19A
0005432360366	6390	91	19B
0005432360385	6390	92	19D
0005432360346	6390	93	19C
0005432360363	6390	94	19F
0005432360369	6390	95	20A
0005432360357	6390	96	20B
0005432360371	6390	97	20D
0005434149623	6390	98	20C
0005432360381	6390	99	20E
0005435176957	6390	100	20F
0005435176772	6390	101	21B
0005435723032	6390	102	21C
0005432360377	6390	103	21D
0005432360373	6390	104	21E
0005432360388	6390	105	22A
0005435176786	6390	106	21F
0005432360391	6390	107	22C
0005432336033	6390	108	22B
0005432336030	6390	109	22D
0005432336029	6390	110	22F
0005432360378	6390	111	22E
0005435490185	6390	112	23B
0005435176908	6390	113	23A
0005434149677	6390	114	23C
0005435176803	6390	115	23E
0005435176958	6390	116	23F
0005432359897	21012	1	1A
0005435177070	21012	2	1C
0005432359934	21012	3	1D
0005432363395	21012	4	1F
0005432335910	21012	5	2A
0005435177087	21012	6	2F
0005432359830	21012	7	3C
0005434149733	21012	8	3A
0005435177078	21012	9	4A
0005432335892	21012	10	3D
0005435177071	21012	11	4D
0005434149725	21012	12	4C
0005434149734	21012	13	4E
0005432359889	21012	14	4F
0005432359991	21012	15	5B
0005432359779	21012	16	5A
0005432335926	21012	17	5C
0005432359963	21012	18	5D
0005435490231	21012	19	5E
0005432052747	21012	20	6A
0005435490230	21012	21	6C
0005435177068	21012	22	6D
0005432359974	21012	23	6E
0005435177069	21012	24	6F
0005432363373	21012	25	7A
0005434149732	21012	26	7C
0005432335936	21012	27	7D
0005432359998	21012	28	7E
0005434149728	21012	29	8A
0005432359816	21012	30	7F
0005435177086	21012	31	8B
0005432359932	21012	32	8C
0005435177072	21012	33	8E
0005432359946	21012	34	8D
0005432359931	21012	35	8F
0005432360091	21012	36	9A
0005434149736	21012	37	9B
0005432052748	21012	38	9D
0005432360152	21012	39	9C
0005432052745	21012	40	9E
0005435177067	21012	41	9F
0005432359955	21012	42	10B
0005432363400	21012	43	10C
0005432359944	21012	44	10E
0005435177083	21012	45	10D
0005435723046	21012	46	11A
0005435177075	21012	47	11B
0005432360092	21012	48	11C
0005432359762	21012	49	11E
0005432359842	21012	50	11D
0005432359960	21012	51	11F
0005434149731	21012	52	12A
0005432359792	21012	53	12C
0005435723045	21012	54	12B
0005432359945	21012	55	12D
0005432359938	21012	56	12E
0005435177065	21012	57	12F
0005432052746	21012	58	13B
0005432363390	21012	59	13A
0005435177073	21012	60	13C
0005432360001	21012	61	13E
0005435177080	21012	62	13D
0005432335935	21012	63	14A
0005432359894	21012	64	13F
0005432359914	21012	65	14C
0005432335899	21012	66	14D
0005435177074	21012	67	14E
0005432335898	21012	68	15A
0005432335964	21012	69	14F
0005435490232	21012	70	15B
0005435177089	21012	71	15C
0005432359843	21012	72	15E
0005435177081	21012	73	16A
0005432359999	21012	74	16C
0005432359791	21012	75	16D
0005432360027	21012	76	16F
0005432359939	21012	77	16E
0005435177091	21012	78	17B
0005432335943	21012	79	17A
0005434149735	21012	80	17C
0005434149726	21012	81	17D
0005432335978	21012	82	17F
0005434149729	21012	83	17E
0005435723047	21012	84	18A
0005432360020	21012	85	18C
0005432359990	21012	86	18D
0005435177079	21012	87	18F
0005435177082	21012	88	18E
0005432359778	21012	89	19A
0005435177090	21012	90	19B
0005432359684	21012	91	19D
0005435177076	21012	92	19C
0005435177066	21012	93	19E
0005435177084	21012	94	19F
0005435177077	21012	95	20A
0005432359876	21012	96	20C
0005432360039	21012	97	20B
0005432359927	21012	98	20D
0005432359975	21012	99	20E
0005435177088	21012	100	21A
0005432335937	21012	101	21C
0005434149727	21012	102	21B
0005435177085	21012	103	21D
0005434149730	21012	104	21F
0005432360019	21012	105	22B
0005432359947	21012	106	22C
0005435490233	21012	107	22D
0005432359828	21012	108	22E
0005432359888	21012	109	22F
0005432359926	21012	110	23A
0005432335911	21012	111	23C
0005432359890	21012	112	23D
0005432359956	21012	113	23E
0005432335944	21012	114	23F
0005434448279	17701	1	1C
0005434458597	17701	2	1D
0005434186199	17701	3	2C
0005434458624	17701	4	2D
0005434186198	17701	5	3C
0005434461632	17701	6	3D
0005434461633	17701	7	4B
0005434458626	17701	8	4D
0005434186200	17701	9	5A
0005434458608	17701	10	5C
0005434448268	17701	11	5D
0005434458638	17701	12	6A
0005434458627	17701	13	6B
0005434458641	17701	14	6C
0005434458640	17701	15	18A
0005434463913	17701	16	18C
0005434461624	17701	17	18D
0005434458670	17701	18	19A
0005434458654	17701	19	19B
0005434458694	17701	20	19C
0005434458655	17701	21	19D
0005434458749	17701	22	20C
0005434463903	17701	23	20D
0005434458609	17701	24	21A
0005434448284	17701	25	21C
0005434458598	17701	26	21D
0005434461611	17701	27	22A
0005434458568	17701	28	22B
0005434463911	17701	29	22C
0005434463912	17701	30	23B
0005434186171	29131	1	1B
0005434458809	29131	2	1C
0005434448313	29131	3	2B
0005434462789	29131	4	2D
0005434463928	29131	5	3A
0005434186170	29131	6	3B
0005434462788	29131	7	3C
0005434448312	29131	8	3D
0005434458804	29131	9	4A
0005434458813	29131	10	4B
0005434463926	29131	11	4C
0005434458803	29131	12	4D
0005434458796	29131	13	5A
0005434448310	29131	14	5B
0005434458810	29131	15	5C
0005434462787	29131	16	5D
0005434458795	29131	17	6B
0005434448311	29131	18	6C
0005434458797	29131	19	6D
0005434458811	29131	20	7A
0005434458806	29131	21	7B
0005434186174	29131	22	7C
0005434458800	29131	23	18A
0005434458805	29131	24	18B
0005434458799	29131	25	18C
0005434458807	29131	26	19A
0005434458801	29131	27	19B
0005434458814	29131	28	19D
0005434458815	29131	29	20A
0005434463927	29131	30	20B
0005434458802	29131	31	20C
0005434186173	29131	32	20D
0005434458798	29131	33	21B
0005434458812	29131	34	21D
0005434458808	29131	35	22A
0005434458816	29131	36	23A
0005432604323	21410	1	1A
0005432604294	21410	2	1C
0005432604310	21410	3	1D
0005432604325	21410	4	2B
0005432604306	21410	5	2C
0005432604330	21410	6	2D
0005432604313	21410	7	3A
0005432604303	21410	8	3C
0005432604311	21410	9	3D
0005432604324	21410	10	4A
0005432604304	21410	11	4B
0005432604301	21410	12	4C
0005432604300	21410	13	4D
0005432604295	21410	14	5B
0005432604321	21410	15	5C
0005432604297	21410	16	5D
0005432604292	21410	17	6A
0005432604316	21410	18	6B
0005432604293	21410	19	6C
0005432604319	21410	20	6D
0005435218105	21410	21	7A
0005432604315	21410	22	7B
0005432604326	21410	23	7C
0005432604322	21410	24	7D
0005432604291	21410	25	18A
0005432604308	21410	26	18B
0005432604309	21410	27	18C
0005432604298	21410	28	18D
0005432604317	21410	29	19B
0005432604314	21410	30	19C
0005432604302	21410	31	19D
0005432604299	21410	32	20A
0005432604327	21410	33	20B
0005432604296	21410	34	20C
0005432604331	21410	35	20D
0005432604312	21410	36	21A
0005432604307	21410	37	21B
0005435218106	21410	38	21D
0005432604320	21410	39	22A
0005432604329	21410	40	22B
0005432604318	21410	41	22C
0005432604328	21410	42	22D
0005432604305	21410	43	23B
0005432604081	31666	1	1A
0005432604036	31666	2	1B
0005432603998	31666	3	1C
0005432603884	31666	4	2A
0005432603828	31666	5	2B
0005432604110	31666	6	2C
0005432603893	31666	7	2D
0005432603909	31666	8	3A
0005432604078	31666	9	3B
0005432604070	31666	10	3C
0005432603896	31666	11	3D
0005432603894	31666	12	4A
0005432603969	31666	13	4C
0005432603927	31666	14	4D
0005432603908	31666	15	5A
0005432604001	31666	16	5B
0005432604006	31666	17	5C
0005432603962	31666	18	5D
0005432603937	31666	19	6B
0005432603995	31666	20	6C
0005432603827	31666	21	6D
0005432603919	31666	22	7A
0005432604068	31666	23	7B
0005432604007	31666	24	7C
0005432603848	31666	25	7D
0005432604008	31666	26	18D
0005432603800	31666	27	19A
0005432603918	31666	28	19B
0005432604072	31666	29	19C
0005432603678	31666	30	19D
0005432604002	31666	31	20A
0005432603792	31666	32	20C
0005432603749	31666	33	20D
0005432603934	31666	34	21A
0005432603947	31666	35	21B
0005432604053	31666	36	21C
0005432604044	31666	37	21D
0005432603956	31666	38	22A
0005432603847	31666	39	22B
0005432603920	31666	40	22D
0005432604080	31666	41	23A
0005432604073	31666	42	23B
0005433293190	12296	1	2C
0005433293188	12296	2	2D
0005433293207	12296	3	3A
0005433293183	12296	4	3D
0005433293189	12296	5	3C
0005433293192	12296	6	4A
0005433293164	12296	7	5B
0005433293202	12296	8	18D
0005433293180	12296	9	19A
0005433293156	12296	10	20A
0005433293191	12296	11	22A
0005433293184	12296	12	22C
0005434606792	18898	1	5B
0005434606826	22367	1	1A
0005434606823	22367	2	1B
0005434606827	22367	3	2A
0005434606824	22367	4	2B
0005434604892	22367	5	3A
0005434604893	22367	6	4A
0005434604896	22367	7	3B
0005434606825	22367	8	4B
0005434604895	22367	9	5A
0005434604894	22367	10	6B
0005432747547	405	1	1C
0005432747571	405	2	1D
0005432747556	405	3	2A
0005432753297	405	4	2C
0005432890837	405	5	2D
0005432890864	405	6	2F
0005432747537	405	7	3A
0005432890823	405	8	3C
0005432890790	405	9	3D
0005432890793	405	10	3F
0005433293197	405	11	4A
0005432747560	405	12	4C
0005432747566	405	13	4D
0005432747562	405	14	4E
0005433293178	405	15	4F
0005432753300	405	16	5A
0005432747569	405	17	5C
0005433293170	405	18	5D
0005432747563	405	19	5E
0005432747544	405	20	5F
0005432747565	405	21	6A
0005432751524	405	22	6C
0005432747543	405	23	6D
0005432220002	405	24	6E
0005432220001	405	25	6F
0005433875369	405	26	7A
0005432890836	405	27	7C
0005432890794	405	28	7D
0005432747541	405	29	7E
0005432220003	405	30	8A
0005433293179	405	31	8C
0005432747540	405	32	8D
0005432747554	405	33	8F
0005433293172	405	34	8E
0005432747548	405	35	9A
0005432749782	405	36	9C
0005432747568	405	37	9D
0005432890838	405	38	9E
0005432747536	405	39	9F
0005432747557	405	40	10C
0005432890769	405	41	10D
0005432890944	405	42	10E
0005432747539	405	43	10F
0005432890789	405	44	11A
0005432747559	405	45	11C
0005432890822	405	46	11D
0005432747573	405	47	11F
0005432753299	405	48	11E
0005432747564	405	49	12A
0005432890839	405	50	12D
0005432747538	405	51	12E
0005435154597	405	52	12F
0005432747552	405	53	13A
0005432747570	405	54	13C
0005432753298	405	55	13F
0005432747545	405	56	14A
0005432747551	405	57	14C
0005432890867	405	58	14D
0005432220000	405	59	14E
0005433293218	405	60	14F
0005432890865	405	61	15A
0005433875368	405	62	15D
0005432747561	405	63	15E
0005432747555	405	64	15F
0005432747535	405	65	16A
0005432747549	405	66	16C
0005432890863	405	67	16D
0005432890866	405	68	16F
0005433293217	405	69	17A
0005432890795	405	70	17C
0005432747558	405	71	17D
0005432751523	405	72	17E
0005433293213	405	73	17F
0005432890945	405	74	18A
0005432747553	405	75	18C
0005432747546	405	76	18D
0005433293171	405	77	18E
0005432747542	405	78	18F
0005435154596	405	79	19A
0005432747567	405	80	19D
0005433293196	405	81	20A
0005433293186	405	82	20C
0005432747572	405	83	20D
0005432749783	405	84	20E
0005432747550	405	85	20F
0005432891030	12034	1	1C
0005432747323	12034	2	1F
0005432753268	12034	3	2A
0005433293247	12034	4	2C
0005432891021	12034	5	2D
0005432747200	12034	6	3A
0005432891022	12034	7	3C
0005432747352	12034	8	3D
0005432756819	12034	9	3F
0005432891012	12034	10	4A
0005432891010	12034	11	4C
0005432747159	12034	12	4D
0005435154588	12034	13	4F
0005433293244	12034	14	5A
0005433293242	12034	15	5C
0005432747209	12034	16	5D
0005432747158	12034	17	5E
0005432747422	12034	18	5F
0005432891026	12034	19	6A
0005432891024	12034	20	6C
0005432756818	12034	21	6D
0005435154589	12034	22	6E
0005432756811	12034	23	6F
0005432747454	12034	24	7A
0005432747297	12034	25	7C
0005432747322	12034	26	7D
0005432891029	12034	27	7E
0005432747199	12034	28	7F
0005432747128	12034	29	8A
0005432891016	12034	30	8C
0005432753267	12034	31	8D
0005432891023	12034	32	8F
0005432747444	12034	33	9A
0005435154582	12034	34	9C
0005432753266	12034	35	9D
0005433293246	12034	36	9F
0005433875379	12034	37	10A
0005432891011	12034	38	10C
0005432891013	12034	39	10D
0005432891019	12034	40	10F
0005432756814	12034	41	11A
0005435154581	12034	42	11C
0005433293250	12034	43	11D
0005432747164	12034	44	11E
0005432747241	12034	45	11F
0005432891017	12034	46	12A
0005432747342	12034	47	12C
0005433293248	12034	48	12D
0005432891027	12034	49	12E
0005435154586	12034	50	12F
0005432747445	12034	51	13A
0005432747239	12034	52	13C
0005432891015	12034	53	13D
0005432891018	12034	54	13E
0005432891025	12034	55	13F
0005432214803	12034	56	14A
0005432747256	12034	57	14C
0005432747135	12034	58	14D
0005435154585	12034	59	14E
0005432747296	12034	60	14F
0005435154587	12034	61	15A
0005432747181	12034	62	15C
0005432891014	12034	63	15D
0005432747255	12034	64	15E
0005433293243	12034	65	15F
0005432747281	12034	66	16A
0005432747248	12034	67	16C
0005435154584	12034	68	16D
0005432891020	12034	69	16E
0005433293249	12034	70	17D
0005435154583	12034	71	17E
0005433293251	12034	72	17F
0005432756812	12034	73	18A
0005432891028	12034	74	18C
0005435154580	12034	75	18D
0005433875378	12034	76	18E
0005435154590	12034	77	18F
0005432747127	12034	78	19A
0005432747392	12034	79	19C
0005433293241	12034	80	19D
0005433293245	12034	81	19E
0005432747282	12034	82	19F
0005432753270	12034	83	20A
0005432747247	12034	84	20C
0005432753277	12034	85	20D
0005432753264	12034	86	20E
0005432747079	12034	87	20F
0005433531287	18949	1	1B
0005432927944	18949	2	2C
0005433533303	18949	3	2D
0005433525025	18949	4	3A
0005433531290	18949	5	4B
0005433525026	18949	6	4D
0005433525032	18949	7	5B
0005432927945	18949	8	5D
0005433531289	18949	9	6A
0005433525029	18949	10	6C
0005432927929	18949	11	18B
0005433525028	18949	12	18C
0005433531288	18949	13	18D
0005433525034	18949	14	19B
0005432927930	18949	15	19C
0005433525031	18949	16	20A
0005433533304	18949	17	21A
0005433525030	18949	18	21B
0005433525027	18949	19	21C
0005433525024	18949	20	21D
0005433525033	18949	21	22A
0005433533305	18949	22	22C
0005433533306	18949	23	22D
0005433524920	32467	1	1B
0005432927984	32467	2	1C
0005432927988	32467	3	1D
0005433524939	32467	4	2B
0005433524919	32467	5	2C
0005433527227	32467	6	3B
0005433527232	32467	7	3D
0005433524936	32467	8	4A
0005433527228	32467	9	4B
0005433524947	32467	10	5B
0005433524930	32467	11	5C
0005433527231	32467	12	5D
0005432927985	32467	13	6A
0005433524976	32467	14	6B
0005432927987	32467	15	6C
0005433524954	32467	16	7B
0005433531279	32467	17	19A
0005433524931	32467	18	19B
0005433527206	32467	19	19C
0005432927983	32467	20	19D
0005432927986	32467	21	20B
0005433524940	32467	22	20D
0005433524985	32467	23	21A
0005433527233	32467	24	22A
0005433527205	32467	25	23B
0005432121328	5268	1	1D
0005434823605	5268	2	1C
0005434823530	5268	3	1A
0005435372616	5268	4	1G
0005435372636	5268	5	1H
0005434823596	5268	6	2D
0005434823544	5268	7	2C
0005435372635	5268	8	2A
0005434823523	5268	9	2H
0005434823623	5268	10	2G
0005434558272	5268	11	3A
0005432396242	5268	12	2K
0005434823554	5268	13	3G
0005434823597	5268	14	3D
0005434823594	5268	15	3C
0005435372682	5268	16	4C
0005434823521	5268	17	4A
0005435372652	5268	18	4G
0005435372959	5268	19	4D
0005435735105	5268	20	5A
0005434823536	5268	21	4K
0005434823569	5268	22	5H
0005435386517	5268	23	5G
0005434823646	5268	24	5D
0005434823542	5268	25	11A
0005435372658	5268	26	5K
0005434664959	5268	27	11D
0005434823581	5268	28	11C
0005435735106	5268	29	11F
0005432121333	5268	30	11K
0005434823572	5268	31	11H
0005435299742	5268	32	11G
0005434823616	5268	33	12A
0005434558279	5268	34	12E
0005434823634	5268	35	12D
0005434558275	5268	36	12G
0005435372678	5268	37	12K
0005434823524	5268	38	13D
0005434831146	5268	39	13A
0005434823528	5268	40	13E
0005435386533	5268	41	13H
0005435372486	5268	42	13G
0005434831150	5268	43	14A
0005435372707	5268	44	13K
0005434558271	5268	45	14D
0005434823540	5268	46	14C
0005434823580	5268	47	14G
0005434823621	5268	48	14F
0005432121331	5268	49	14E
0005435372708	5268	50	14K
0005434823631	5268	51	14H
0005435372408	5268	52	15A
0005435372706	5268	53	15E
0005435372954	5268	54	15D
0005434558280	5268	55	15F
0005432121334	5268	56	15H
0005434823615	5268	57	16A
0005434823552	5268	58	16F
0005435372679	5268	59	16E
0005434823527	5268	60	16H
0005434823617	5268	61	16G
0005435735085	5268	62	16K
0005435372495	5268	63	17E
0005434823598	5268	64	17D
0005435150022	5268	65	17C
0005435372641	5268	66	17G
0005435372402	5268	67	17F
0005434823547	5268	68	17K
0005434823604	5268	69	18B
0005434823532	5268	70	18D
0005434823591	5268	71	18G
0005434823585	5268	72	18F
0005434823574	5268	73	18H
0005434823556	5268	74	19A
0005435661912	5268	75	18K
0005434823575	5268	76	19D
0005432121341	5268	77	19C
0005434823576	5268	78	19B
0005435372681	5268	79	19H
0005435372946	5268	80	20A
0005435372716	5268	81	19K
0005435299719	5268	82	19J
0005435150028	5268	83	20C
0005435150025	5268	84	20E
0005434823564	5268	85	20G
0005434831145	5268	86	20F
0005434823601	5268	87	20K
0005434823582	5268	88	20J
0005434558278	5268	89	21B
0005432396243	5268	90	21D
0005434664957	5268	91	21F
0005434823628	5268	92	21E
0005432394106	5268	93	21J
0005432121329	5268	94	21G
0005434823567	5268	95	21K
0005434823630	5268	96	22B
0005434664958	5268	97	22E
0005434823640	5268	98	22D
0005434823609	5268	99	22G
0005435150029	5268	100	22H
0005434558276	5268	101	23B
0005434823636	5268	102	23A
0005435372811	5268	103	23E
0005435179690	5268	104	23F
0005432394102	5268	105	23K
0005435661905	5268	106	24F
0005434823537	5268	107	24E
0005435372657	5268	108	25B
0005435372846	5268	109	25A
0005435386542	5268	110	24G
0005435150036	5268	111	25D
0005434823562	5268	112	25E
0005434823543	5268	113	25H
0005435386525	5268	114	25G
0005435372403	5268	115	25K
0005435372564	5268	116	25J
0005434823625	5268	117	26C
0005435304137	5268	118	26B
0005434823608	5268	119	26E
0005434823553	5268	120	26D
0005435372824	5268	121	26G
0005434823622	5268	122	26F
0005434823612	5268	123	26J
0005435372596	5268	124	26H
0005432394103	5268	125	26K
0005434823561	5268	126	27D
0005432394104	5268	127	27C
0005434823526	5268	128	27B
0005434823578	5268	129	27H
0005434823635	5268	130	27G
0005432121335	5268	131	27K
0005435661910	5268	132	28C
0005435372680	5268	133	28B
0005434823558	5268	134	28A
0005434823538	5268	135	28E
0005434823570	5268	136	28D
0005434823560	5268	137	28F
0005434823535	5268	138	28J
0005434831147	5268	139	28H
0005434823533	5268	140	29B
0005434823620	5268	141	29A
0005435372787	5268	142	28K
0005432121332	5268	143	29D
0005434823555	5268	144	29C
0005435150024	5268	145	29E
0005434823619	5268	146	29H
0005435372801	5268	147	29G
0005435299740	5268	148	29K
0005434823603	5268	149	30B
0005434558268	5268	150	30A
0005435372826	5268	151	30E
0005435372651	5268	152	30D
0005434823638	5268	153	30G
0005434823548	5268	154	30K
0005435372848	5268	155	30J
0005435372847	5268	156	30H
0005435299725	5268	157	31A
0005434823559	5268	158	31D
0005434823626	5268	159	31H
0005434823593	5268	160	31G
0005434823549	5268	161	32B
0005434823607	5268	162	32C
0005434823557	5268	163	32G
0005434823529	5268	164	32F
0005434823600	5268	165	32J
0005435372684	5268	166	33B
0005434823587	5268	167	33A
0005434828694	5268	168	33C
0005434823534	5268	169	33F
0005435661911	5268	170	33H
0005435372638	5268	171	33G
0005435299718	5268	172	34A
0005434558277	5268	173	33K
0005434823595	5268	174	33J
0005434823577	5268	175	34B
0005434823610	5268	176	34D
0005435372765	5268	177	34F
0005434823629	5268	178	34K
0005434823645	5268	179	34J
0005434823647	5268	180	35A
0005435372951	5268	181	35D
0005434823644	5268	182	35F
0005435386516	5268	183	35J
0005434823637	5268	184	35G
0005435735084	5268	185	35K
0005435372750	5268	186	36B
0005435372531	5268	187	36D
0005435150023	5268	188	36H
0005434823539	5268	189	36F
0005435386530	5268	190	36J
0005434823632	5268	191	37A
0005434823589	5268	192	37C
0005432121337	5268	193	37E
0005434823613	5268	194	37J
0005435372392	5268	195	37H
0005434823571	5268	196	37G
0005434828695	5268	197	38A
0005434823565	5268	198	37K
0005434823599	5268	199	38C
0005434823592	5268	200	38B
0005434823590	5268	201	38J
0005434823602	5268	202	39B
0005432394105	5268	203	39A
0005432121330	5268	204	39D
0005435372557	5268	205	39C
0005434823627	5268	206	39F
0005435372734	5268	207	39E
0005434823563	5268	208	40A
0005435386527	5268	209	39K
0005435150027	5268	210	40C
0005435372528	5268	211	40B
0005435372494	5268	212	40F
0005435386528	5268	213	40E
0005434823546	5268	214	40D
0005435735096	5268	215	40G
0005434831148	5268	216	40J
0005432121340	5268	217	41B
0005435150032	5268	218	41A
0005435386545	5268	219	40K
0005435386485	5268	220	41D
0005434823643	5268	221	41C
0005435735088	5268	222	41G
0005434823541	5268	223	41F
0005434558270	5268	224	41J
0005435150034	5268	225	41H
0005434823550	5268	226	41K
0005434823642	5268	227	42C
0005435299741	5268	228	42B
0005432121327	5268	229	42D
0005435372762	5268	230	42F
0005434823545	5268	231	42J
0005435372786	5268	232	43A
0005435372184	5268	233	42K
0005434823624	5268	234	43F
0005434831144	5268	235	43E
0005434823551	5268	236	43D
0005434823522	5268	237	43G
0005434823584	5268	238	43J
0005435372523	5268	239	44B
0005434558273	5268	240	44E
0005432121338	5268	241	44D
0005434823611	5268	242	44C
0005435372785	5268	243	44F
0005435372583	5268	244	44K
0005435372336	5268	245	44H
0005432121339	5268	246	45B
0005434823639	5268	247	45A
0005435372825	5268	248	45D
0005434558274	5268	249	45C
0005432396244	5268	250	45F
0005435304133	5268	251	45E
0005435150030	5268	252	45G
0005435372749	5268	253	45K
0005435304138	5268	254	46B
0005434558269	5268	255	46A
0005434823606	5268	256	46E
0005434823583	5268	257	46K
0005434823531	5268	258	46J
0005435150033	5268	259	46H
0005434823633	5268	260	47A
0005434823579	5268	261	47E
0005434823568	5268	262	47D
0005435372183	5268	263	47G
0005434823520	5268	264	47K
0005435372393	5268	265	47H
0005435735089	5268	266	48D
0005435372667	5268	267	48C
0005434823525	5268	268	48A
0005435150031	5268	269	48F
0005435150026	5268	270	48E
0005432121336	5268	271	48H
0005435372885	5268	272	49A
0005435372945	5268	273	49D
0005434823614	5268	274	49G
0005435372690	5268	275	49F
0005435372696	5268	276	49H
0005435372955	5268	277	50C
0005434823566	5268	278	50A
0005434831149	5268	279	50E
0005434823618	5268	280	50D
0005434823588	5268	281	50H
0005434823586	5268	282	50G
0005435150035	5268	283	51D
0005435372637	5268	284	50K
0005434823641	5268	285	51F
0005434823573	5268	286	51G
0005435373252	9927	1	1D
0005434822840	9927	2	1C
0005435373257	9927	3	1A
0005434822924	9927	4	1G
0005432203062	9927	5	1K
0005434822340	9927	6	2D
0005435299774	9927	7	2C
0005434822832	9927	8	2A
0005434822410	9927	9	2H
0005434822798	9927	10	2G
0005435179394	9927	11	3C
0005434822619	9927	12	3K
0005434822557	9927	13	3H
0005434558181	9927	14	3G
0005434831123	9927	15	4C
0005435373245	9927	16	4A
0005434822603	9927	17	4G
0005434822261	9927	18	4D
0005435149899	9927	19	4H
0005435373231	9927	20	5D
0005435302196	9927	21	11A
0005434822380	9927	22	5K
0005435373229	9927	23	11D
0005435373237	9927	24	11C
0005434822653	9927	25	11F
0005434821882	9927	26	11E
0005434828669	9927	27	11H
0005434558168	9927	28	12A
0005434822431	9927	29	11K
0005434822627	9927	30	12F
0005434558193	9927	31	12G
0005435299775	9927	32	13A
0005435149891	9927	33	12K
0005434822607	9927	34	13D
0005435373288	9927	35	13F
0005434822723	9927	36	13E
0005434822815	9927	37	13H
0005435373255	9927	38	13G
0005434822359	9927	39	14C
0005435149922	9927	40	13K
0005435373282	9927	41	14F
0005434831102	9927	42	14E
0005435373263	9927	43	15C
0005435373253	9927	44	15D
0005434822075	9927	45	15G
0005434558188	9927	46	15F
0005434822432	9927	47	16A
0005434558190	9927	48	16E
0005434822524	9927	49	16K
0005435373247	9927	50	16H
0005434822556	9927	51	16G
0005435373250	9927	52	17C
0005434822664	9927	53	17A
0005435373260	9927	54	17E
0005435373292	9927	55	17D
0005434822833	9927	56	17F
0005434822933	9927	57	18A
0005434822310	9927	58	17K
0005432396207	9927	59	17H
0005435373291	9927	60	18B
0005435373293	9927	61	18D
0005434822583	9927	62	18C
0005434822816	9927	63	18F
0005435373243	9927	64	18J
0005434558169	9927	65	18H
0005434822665	9927	66	19B
0005434822148	9927	67	19D
0005435149798	9927	68	19C
0005434822269	9927	69	19F
0005434822252	9927	70	19E
0005432203065	9927	71	19H
0005434822369	9927	72	19G
0005434823058	9927	73	19K
0005434822677	9927	74	19J
0005434822338	9927	75	20B
0005435735139	9927	76	20E
0005434822626	9927	77	20D
0005434822671	9927	78	20G
0005434822368	9927	79	20F
0005435179393	9927	80	20J
0005434822341	9927	81	21B
0005434822065	9927	82	21A
0005434822422	9927	83	20K
0005434558194	9927	84	21C
0005434822727	9927	85	21F
0005434822043	9927	86	21J
0005434822382	9927	87	21H
0005435373274	9927	88	21G
0005432396222	9927	89	22A
0005435373277	9927	90	21K
0005434822348	9927	91	22C
0005434822625	9927	92	22B
0005432400103	9927	93	22H
0005434822452	9927	94	22G
0005434822817	9927	95	22F
0005434822116	9927	96	22K
0005434831121	9927	97	23B
0005435373259	9927	98	23A
0005435661931	9927	99	23D
0005434822161	9927	100	23C
0005435373266	9927	101	23F
0005435149904	9927	102	23E
0005435373261	9927	103	23J
0005434822887	9927	104	23H
0005434822512	9927	105	24D
0005434821963	9927	106	23K
0005434558189	9927	107	24E
0005432823450	9927	108	25B
0005435373246	9927	109	25A
0005434822189	9927	110	24G
0005434822608	9927	111	25D
0005434828664	9927	112	25C
0005435373267	9927	113	25F
0005435373228	9927	114	25H
0005435373280	9927	115	25G
0005435149843	9927	116	25K
0005435149905	9927	117	25J
0005435373281	9927	118	26B
0005435373268	9927	119	26A
0005435302197	9927	120	26G
0005434822722	9927	121	26K
0005434822578	9927	122	26J
0005435373278	9927	123	26H
0005435149917	9927	124	27A
0005435373272	9927	125	27D
0005434822575	9927	126	27C
0005434822726	9927	127	27F
0005434822262	9927	128	27G
0005435302199	9927	129	27K
0005435373265	9927	130	27J
0005435735140	9927	131	28C
0005435299777	9927	132	28E
0005434822624	9927	133	28G
0005435149857	9927	134	28F
0005435373240	9927	135	28H
0005435373264	9927	136	29A
0005434822162	9927	137	28K
0005434831094	9927	138	29C
0005434822416	9927	139	29D
0005434822420	9927	140	29J
0005435373248	9927	141	29G
0005434822912	9927	142	29K
0005435149895	9927	143	30E
0005434821934	9927	144	30D
0005434822395	9927	145	30J
0005435373230	9927	146	31A
0005435179693	9927	147	30K
0005434822773	9927	148	31E
0005434822423	9927	149	31D
0005432203061	9927	150	31H
0005435149907	9927	151	31J
0005435373262	9927	152	32E
0005435373276	9927	153	32D
0005435302195	9927	154	32C
0005432203060	9927	155	32G
0005435149908	9927	156	32F
0005435373289	9927	157	32J
0005434822208	9927	158	33A
0005434822339	9927	159	33F
0005434822210	9927	160	33E
0005434821893	9927	161	33J
0005434822654	9927	162	33H
0005434822142	9927	163	33G
0005434828663	9927	164	34A
0005435373234	9927	165	34B
0005434822799	9927	166	34G
0005434822384	9927	167	34K
0005435373236	9927	168	34H
0005435149856	9927	169	35A
0005434822548	9927	170	35B
0005434822394	9927	171	35F
0005434558195	9927	172	35E
0005435373275	9927	173	35H
0005432203067	9927	174	35G
0005434558204	9927	175	36A
0005434822997	9927	176	35K
0005432396210	9927	177	35J
0005435373251	9927	178	36B
0005435373258	9927	179	36E
0005435373271	9927	180	36K
0005435179694	9927	181	36J
0005435302198	9927	182	37D
0005434822298	9927	183	37C
0005434822381	9927	184	37J
0005435373242	9927	185	37H
0005435149799	9927	186	37K
0005435373249	9927	187	38B
0005434822455	9927	188	39B
0005434828678	9927	189	39A
0005435149898	9927	190	39H
0005434822251	9927	191	39K
0005434822632	9927	192	40C
0005434558180	9927	193	40B
0005435373283	9927	194	40F
0005435179695	9927	195	40E
0005434822492	9927	196	40D
0005434821969	9927	197	40G
0005435302200	9927	198	40H
0005435299776	9927	199	41B
0005434822642	9927	200	41A
0005435373238	9927	201	41D
0005434828682	9927	202	41F
0005434822513	9927	203	41E
0005435373269	9927	204	41H
0005435373235	9927	205	41G
0005434831122	9927	206	42A
0005432823451	9927	207	41K
0005435373285	9927	208	41J
0005434822819	9927	209	42C
0005434822444	9927	210	42D
0005435373233	9927	211	42G
0005435373284	9927	212	42K
0005435373239	9927	213	42J
0005435373273	9927	214	42H
0005434822762	9927	215	43D
0005434822820	9927	216	43C
0005434822150	9927	217	43F
0005434822618	9927	218	43E
0005435373287	9927	219	43J
0005434822456	9927	220	44C
0005434558196	9927	221	44B
0005434822858	9927	222	44A
0005434822118	9927	223	44G
0005434821844	9927	224	44K
0005435735137	9927	225	44J
0005435373270	9927	226	44H
0005434822383	9927	227	45B
0005435373279	9927	228	45D
0005432203064	9927	229	45C
0005434822409	9927	230	45G
0005434822060	9927	231	45F
0005434822894	9927	232	45E
0005432823452	9927	233	45H
0005435373244	9927	234	46C
0005434821968	9927	235	46A
0005434822518	9927	236	46E
0005435373254	9927	237	46F
0005435373290	9927	238	46K
0005435735138	9927	239	46J
0005434822834	9927	240	46H
0005434822818	9927	241	47E
0005432203066	9927	242	47D
0005434822611	9927	243	47C
0005434822605	9927	244	47H
0005434822746	9927	245	47G
0005434823143	9927	246	47F
0005434831115	9927	247	47K
0005435373256	9927	248	48D
0005434822631	9927	249	48C
0005435149903	9927	250	48F
0005434822630	9927	251	48E
0005432400101	9927	252	48G
0005435149923	9927	253	49C
0005435373232	9927	254	49A
0005434828677	9927	255	48K
0005434822893	9927	256	49D
0005434822579	9927	257	49G
0005434822260	9927	258	49K
0005434822453	9927	259	49H
0005435373286	9927	260	50C
0005432400102	9927	261	50A
0005434822859	9927	262	50D
0005434822454	9927	263	50H
0005435661932	9927	264	50G
0005434558192	9927	265	50F
0005435302201	9927	266	51F
0005432203063	9927	267	51D
0005435373241	9927	268	51G
0005435790306	7021	1	2B
0005435790305	7021	2	4A
0005435082785	7021	3	5C
0005435082787	7021	4	6A
0005435790307	7021	5	20A
0005435082786	7021	6	20B
0005435082784	7021	7	21A
0005435082718	25985	1	1D
0005435082687	25985	2	3D
0005435082712	25985	3	4C
0005435082713	25985	4	18A
0005435790291	25985	5	18B
0005435082711	25985	6	20B
0005435082772	25985	7	20D
0005435790290	25985	8	21D
0005435790289	25985	9	22B
0005434756417	9550	1	1A
0005434756426	9550	2	1C
0005434756435	9550	3	1D
0005434756438	9550	4	1F
0005434756442	9550	5	2A
0005434213911	9550	6	2C
0005434756425	9550	7	2D
0005434214259	9550	8	3A
0005434214133	9550	9	3C
0005434756408	9550	10	3D
0005434756429	9550	11	4D
0005434756412	9550	12	4E
0005434756415	9550	13	5C
0005434756434	9550	14	5D
0005434213980	9550	15	5E
0005434214110	9550	16	5F
0005434756416	9550	17	6A
0005434756445	9550	18	6C
0005434756439	9550	19	6D
0005434214275	9550	20	6E
0005434756430	9550	21	6F
0005434214051	9550	22	7A
0005434756436	9550	23	7C
0005434756423	9550	24	7D
0005434756410	9550	25	7E
0005434214173	9550	26	7F
0005434213938	9550	27	8A
0005434756419	9550	28	8C
0005434214229	9550	29	8D
0005434756413	9550	30	8E
0005434756432	9550	31	8F
0005434214078	9550	32	9A
0005434214162	9550	33	9C
0005434213960	9550	34	9D
0005434756437	9550	35	9E
0005434214178	9550	36	9F
0005434214060	9550	37	10A
0005434213946	9550	38	10C
0005434756427	9550	39	10E
0005434214131	9550	40	10F
0005434756440	9550	41	11C
0005434214073	9550	42	11D
0005434756424	9550	43	11E
0005434756422	9550	44	12A
0005434756421	9550	45	12C
0005434214050	9550	46	12D
0005434214156	9550	47	12E
0005434214158	9550	48	12F
0005434214092	9550	49	13A
0005434213947	9550	50	13C
0005434214161	9550	51	13D
0005434213835	9550	52	13E
0005434213897	9550	53	13F
0005434214062	9550	54	14A
0005434214287	9550	55	14C
0005434214172	9550	56	14D
0005434213876	9550	57	14E
0005434214038	9550	58	15A
0005434756418	9550	59	15C
0005434213850	9550	60	15D
0005434214039	9550	61	15F
0005434756414	9550	62	16A
0005434214002	9550	63	16C
0005434214139	9550	64	16D
0005434756433	9550	65	16E
0005434756441	9550	66	16F
0005434214083	9550	67	17A
0005434213849	9550	68	17C
0005434756443	9550	69	17D
0005434214202	9550	70	17E
0005434214093	9550	71	17F
0005434214132	9550	72	18A
0005434756428	9550	73	18C
0005434756431	9550	74	18D
0005434214157	9550	75	18E
0005434214226	9550	76	18F
0005434214203	9550	77	19A
0005434214264	9550	78	19C
0005434214052	9550	79	19D
0005434756444	9550	80	19E
0005434756409	9550	81	20A
0005434214011	9550	82	20C
0005434756420	9550	83	20D
0005434214001	9550	84	20E
0005434756411	9550	85	20F
0005434214495	28598	1	1A
0005434214503	28598	2	1C
0005434214506	28598	3	1D
0005434214484	28598	4	1F
0005434214476	28598	5	2A
0005434214467	28598	6	2C
0005434755895	28598	7	2D
0005434755888	28598	8	2F
0005434756008	28598	9	3A
0005434755933	28598	10	3C
0005434214497	28598	11	3D
0005434214486	28598	12	3F
0005434755971	28598	13	4A
0005434214504	28598	14	4D
0005434756013	28598	15	4E
0005434214500	28598	16	4F
0005434755834	28598	17	5A
0005434756031	28598	18	5C
0005434214461	28598	19	5D
0005434755833	28598	20	5E
0005434755969	28598	21	5F
0005434756032	28598	22	6A
0005434214482	28598	23	6C
0005434755894	28598	24	6D
0005434755836	28598	25	6E
0005434214507	28598	26	6F
0005434214501	28598	27	7A
0005434756060	28598	28	7C
0005434214494	28598	29	7D
0005434755970	28598	30	7E
0005434214485	28598	31	7F
0005434756072	28598	32	8A
0005434214463	28598	33	8C
0005434214491	28598	34	8D
0005434756000	28598	35	8E
0005434755882	28598	36	8F
0005434214505	28598	37	9A
0005434756040	28598	38	9C
0005434214465	28598	39	9D
0005434755814	28598	40	9E
0005434755972	28598	41	9F
0005434755781	28598	42	10A
0005434214475	28598	43	10C
0005434214481	28598	44	10D
0005434214474	28598	45	10E
0005434214480	28598	46	10F
0005434214477	28598	47	11A
0005434755992	28598	48	11C
0005434214479	28598	49	11D
0005434756061	28598	50	11E
0005434755923	28598	51	11F
0005434214470	28598	52	12A
0005434755983	28598	53	12C
0005434756075	28598	54	12D
0005434214488	28598	55	12E
0005434756076	28598	56	12F
0005434214499	28598	57	13A
0005434755900	28598	58	13C
0005434214469	28598	59	13D
0005434214466	28598	60	13E
0005434214498	28598	61	13F
0005434755979	28598	62	14A
0005434756065	28598	63	14C
0005434214468	28598	64	14D
0005434755896	28598	65	14E
0005434214464	28598	66	14F
0005434214492	28598	67	15A
0005434756059	28598	68	15C
0005434214478	28598	69	15E
0005434755932	28598	70	15F
0005434214460	28598	71	16C
0005434214462	28598	72	16D
0005434214473	28598	73	16E
0005434214483	28598	74	17A
0005434214471	28598	75	16F
0005434755893	28598	76	17C
0005434755924	28598	77	17E
0005434214490	28598	78	17F
0005434214496	28598	79	18A
0005434214502	28598	80	18C
0005434755934	28598	81	18D
0005434756064	28598	82	18E
0005434214487	28598	83	18F
0005434755813	28598	84	19C
0005434755786	28598	85	19D
0005434214489	28598	86	19E
0005434214493	28598	87	19F
0005434755889	28598	88	20A
0005434755978	28598	89	20D
0005434214472	28598	90	20E
0005434214459	28598	91	20F
0005435100123	10858	1	4D
0005434760176	10858	2	5C
0005435100121	10858	3	7A
0005435100125	10858	4	7D
0005435100122	10858	5	21A
0005435100124	10858	6	21B
0005435100105	31799	1	2A
0005435100103	31799	2	4D
0005434760199	31799	3	6D
0005435100104	31799	4	7C
0005435100099	31799	5	7D
0005434760198	31799	6	18C
0005434760197	31799	7	20A
0005433202241	1959	1	1B
0005433202231	1959	2	1C
0005434639319	1959	3	1D
0005434639316	1959	4	2A
0005434639330	1959	5	2B
0005434639320	1959	6	2C
0005434639314	1959	7	2D
0005434639312	1959	8	3A
0005433202282	1959	9	3B
0005433202230	1959	10	3C
0005434639332	1959	11	3D
0005433202232	1959	12	4A
0005434639329	1959	13	4B
0005434639311	1959	14	4C
0005434639315	1959	15	5A
0005434639318	1959	16	5B
0005434639337	1959	17	5C
0005435948328	1959	18	6A
0005434639313	1959	19	6B
0005434639325	1959	20	6C
0005434639336	1959	21	6D
0005433202228	1959	22	7B
0005432290634	1959	23	7A
0005433202185	1959	24	7D
0005434639326	1959	25	18A
0005433202184	1959	26	18B
0005434639310	1959	27	18C
0005434639331	1959	28	18D
0005434639321	1959	29	19A
0005434639317	1959	30	19B
0005434639334	1959	31	19C
0005435948327	1959	32	19D
0005434639324	1959	33	20A
0005434639322	1959	34	20C
0005434639323	1959	35	20D
0005434639335	1959	36	21A
0005432290633	1959	37	21B
0005434639328	1959	38	21D
0005434639327	1959	39	22A
0005434639333	1959	40	22C
0005434639338	1959	41	22D
0005433202198	1959	42	23B
0005434638999	23263	1	1A
0005434639043	23263	2	1B
0005433202352	23263	3	1C
0005434638890	23263	4	1D
0005434639151	23263	5	2A
0005434639133	23263	6	2B
0005434639150	23263	7	2C
0005434639041	23263	8	2D
0005434639006	23263	9	3A
0005434639085	23263	10	3B
0005434638973	23263	11	3C
0005434638955	23263	12	4A
0005434639050	23263	13	4B
0005434638974	23263	14	4D
0005434639002	23263	15	5A
0005433202353	23263	16	5B
0005434639161	23263	17	5D
0005435948311	23263	18	6B
0005434638972	23263	19	6C
0005433202343	23263	20	6D
0005434639160	23263	21	7A
0005433202357	23263	22	7B
0005434639048	23263	23	7C
0005434639042	23263	24	18A
0005434638941	23263	25	18B
0005433202355	23263	26	18C
0005434638906	23263	27	18D
0005433202349	23263	28	19A
0005434639182	23263	29	19B
0005434638994	23263	30	19C
0005433202345	23263	31	20C
0005433202354	23263	32	20D
0005433202344	23263	33	21B
0005433202347	23263	34	21C
0005433202350	23263	35	21D
0005433202346	23263	36	22A
0005433202348	23263	37	22B
0005433202356	23263	38	22C
0005434639009	23263	39	22D
0005433202351	23263	40	23B
0005433531294	6083	1	1A
0005433533309	6083	2	2A
0005434600798	6083	3	2D
0005433531291	6083	4	2F
0005434600796	6083	5	3A
0005434600800	6083	6	3C
0005434600808	6083	7	3D
0005435326586	6083	8	3F
0005433533307	6083	9	4A
0005434600805	6083	10	4C
0005434600818	6083	11	5A
0005433531292	6083	12	5D
0005434600807	6083	13	5E
0005434600814	6083	14	5F
0005435326588	6083	15	6C
0005434600811	6083	16	6F
0005434600815	6083	17	7E
0005435326593	6083	18	8A
0005434600797	6083	19	8C
0005435326611	6083	20	8D
0005434600801	6083	21	9D
0005434600813	6083	22	9F
0005434600819	6083	23	10C
0005434600820	6083	24	10F
0005435326626	6083	25	11F
0005434600799	6083	26	12C
0005434600822	6083	27	12F
0005435326592	6083	28	13E
0005434600816	6083	29	13F
0005434600803	6083	30	14A
0005434600804	6083	31	14C
0005434600817	6083	32	14E
0005435326587	6083	33	15A
0005434600821	6083	34	15D
0005434600812	6083	35	16A
0005435326610	6083	36	16F
0005432111278	6083	37	17C
0005434600810	6083	38	17D
0005432111279	6083	39	17E
0005435326625	6083	40	18E
0005434600806	6083	41	19A
0005434600809	6083	42	19D
0005433533308	6083	43	20A
0005434600802	6083	44	20C
0005433531293	6083	45	20E
0005435326743	18582	1	1F
0005434600654	18582	2	3A
0005434600369	18582	3	3C
0005435326740	18582	4	3F
0005434600368	18582	5	4E
0005434600469	18582	6	4F
0005434600676	18582	7	5C
0005434600331	18582	8	5D
0005435326746	18582	9	5E
0005435326750	18582	10	5F
0005434600598	18582	11	6A
0005434600540	18582	12	6F
0005433527215	18582	13	7C
0005434600594	18582	14	8C
0005435326748	18582	15	8D
0005434600649	18582	16	8E
0005434600589	18582	17	9D
0005434600669	18582	18	9E
0005434600597	18582	19	9F
0005434600593	18582	20	10A
0005435326738	18582	21	10C
0005435326745	18582	22	10F
0005435326749	18582	23	11A
0005435326741	18582	24	11C
0005435326742	18582	25	12A
0005435326739	18582	26	12D
0005434600700	18582	27	12F
0005434600639	18582	28	13C
0005435326744	18582	29	13E
0005434600468	18582	30	13F
0005433527234	18582	31	14E
0005434600644	18582	32	14F
0005433531257	18582	33	15A
0005434600677	18582	34	15C
0005434600600	18582	35	15E
0005434600570	18582	36	15F
0005434600599	18582	37	16C
0005434600590	18582	38	16D
0005434600648	18582	39	17E
0005434600699	18582	40	18D
0005434600569	18582	41	18F
0005435326747	18582	42	19A
0005434600515	18582	43	19F
0005434600592	18582	44	20A
0005433531266	18582	45	20D
0005435326751	18582	46	20E
0005434600585	18582	47	20F
0005434551184	10593	1	1A
0005433180817	10593	2	1C
0005434551203	10593	3	1D
0005434551162	10593	4	1F
0005434558267	10593	5	2A
0005434551177	10593	6	2C
0005434551190	10593	7	2D
0005434551168	10593	8	2F
0005434558259	10593	9	3A
0005434551185	10593	10	3C
0005433180820	10593	11	3D
0005433180818	10593	12	3F
0005434558261	10593	13	4A
0005434551206	10593	14	4C
0005434551183	10593	15	4D
0005434551173	10593	16	4E
0005434551174	10593	17	4F
0005434551193	10593	18	5A
0005434551178	10593	19	5C
0005434551176	10593	20	5D
0005434551166	10593	21	5E
0005433180911	10593	22	5F
0005434551186	10593	23	6A
0005434551167	10593	24	6C
0005434551194	10593	25	6D
0005434551157	10593	26	6E
0005433180835	10593	27	6F
0005434551197	10593	28	7A
0005434551202	10593	29	7C
0005434551182	10593	30	7D
0005434558263	10593	31	7E
0005434551181	10593	32	7F
0005433180834	10593	33	8A
0005433180784	10593	34	8E
0005434551175	10593	35	8D
0005434551161	10593	36	8F
0005433180883	10593	37	9A
0005434551192	10593	38	9C
0005434551169	10593	39	9E
0005433180912	10593	40	9D
0005433180836	10593	41	9F
0005434551172	10593	42	10A
0005434551171	10593	43	10C
0005434551189	10593	44	10D
0005434551209	10593	45	10E
0005433180804	10593	46	10F
0005433180886	10593	47	11A
0005434558265	10593	48	11D
0005433180837	10593	49	11C
0005434551188	10593	50	11E
0005434551210	10593	51	11F
0005434551179	10593	52	12A
0005434551199	10593	53	12C
0005434551198	10593	54	12D
0005434551211	10593	55	12E
0005434554064	10593	56	13A
0005434558264	10593	57	13C
0005433180893	10593	58	13D
0005434551207	10593	59	13E
0005434551170	10593	60	13F
0005434551159	10593	61	14A
0005433180819	10593	62	14C
0005433180788	10593	63	14D
0005433180773	10593	64	14E
0005434551164	10593	65	14F
0005434551208	10593	66	15C
0005434558258	10593	67	15A
0005433180841	10593	68	15D
0005433180894	10593	69	15E
0005434554065	10593	70	15F
0005434551200	10593	71	16A
0005434551205	10593	72	16C
0005434558262	10593	73	16D
0005434551158	10593	74	16F
0005434558260	10593	75	17C
0005434551204	10593	76	17D
0005434551163	10593	77	17E
0005433180840	10593	78	17F
0005433180829	10593	79	18A
0005434551180	10593	80	18C
0005434551201	10593	81	18D
0005434554063	10593	82	18E
0005434551156	10593	83	18F
0005434551187	10593	84	19A
0005434551196	10593	85	19C
0005434551165	10593	86	19D
0005434551191	10593	87	19F
0005434558266	10593	88	20A
0005434551160	10593	89	20C
0005434551195	10593	90	20D
0005433180799	10593	91	20E
0005433181087	27724	1	1A
0005433181106	27724	2	3A
0005433181105	27724	3	3F
0005433181111	27724	4	4A
0005433181094	27724	5	4C
0005433181103	27724	6	6A
0005433181096	27724	7	6F
0005433181088	27724	8	7D
0005433181098	27724	9	8A
0005433181100	27724	10	8E
0005433181099	27724	11	8F
0005433181097	27724	12	9A
0005433181090	27724	13	9E
0005433181101	27724	14	10F
0005433181095	27724	15	11D
0005433181093	27724	16	12C
0005433181108	27724	17	12D
0005433181107	27724	18	13D
0005433181089	27724	19	14E
0005433181091	27724	20	15C
0005433181112	27724	21	15F
0005433181110	27724	22	16C
0005433181104	27724	23	16E
0005433181092	27724	24	18C
0005433181102	27724	25	19F
0005433181109	27724	26	20F
0005434558210	27725	1	1F
0005434550906	27725	2	2A
0005434550818	27725	3	2C
0005434558201	27725	4	2F
0005434554048	27725	5	3A
0005434550816	27725	6	3C
0005434550841	27725	7	3F
0005434550707	27725	8	4C
0005434554051	27725	9	4D
0005434558208	27725	10	4E
0005434550620	27725	11	4F
0005434550768	27725	12	5A
0005434550903	27725	13	5E
0005434550517	27725	14	5F
0005434550885	27725	15	6C
0005434550817	27725	16	6F
0005434550826	27725	17	7A
0005434550872	27725	18	7C
0005434550747	27725	19	7E
0005434550845	27725	20	7F
0005434550987	27725	21	8A
0005434550767	27725	22	8C
0005434550554	27725	23	9A
0005434550836	27725	24	9C
0005434550837	27725	25	9E
0005434550627	27725	26	9F
0005434550632	27725	27	10A
0005434550824	27725	28	10C
0005434550685	27725	29	10D
0005434554052	27725	30	10E
0005434550699	27725	31	10F
0005434550746	27725	32	11A
0005434550858	27725	33	11D
0005434550643	27725	34	11C
0005434550844	27725	35	11F
0005434550700	27725	36	12A
0005434550907	27725	37	12E
0005434550884	27725	38	12F
0005434550518	27725	39	13C
0005434550631	27725	40	13E
0005434550763	27725	41	14A
0005434550846	27725	42	14C
0005434550703	27725	43	14D
0005434550697	27725	44	14E
0005434550486	27725	45	14F
0005434550976	27725	46	15C
0005434550639	27725	47	15E
0005434550840	27725	48	15F
0005434550782	27725	49	16A
0005434558207	27725	50	16D
0005434550857	27725	51	16E
0005434550485	27725	52	16F
0005434550933	27725	53	17A
0005434550723	27725	54	17C
0005434558209	27725	55	17E
0005434550805	27725	56	17F
0005434550860	27725	57	18A
0005434550619	27725	58	18D
0005434554053	27725	59	18E
0005434550661	27725	60	18F
0005434550776	27725	61	19A
0005434550530	27725	62	19E
0005434550531	27725	63	20A
0005434550825	27725	64	20C
0005434554054	27725	65	20E
0005434558202	27725	66	20F
0005433459218	6130	1	2B
0005433459219	6130	2	5A
0005433459221	6130	3	5B
0005433459220	6130	4	6A
0005433459186	19314	1	2A
0005435254473	19314	2	3A
0005433459191	19314	3	3B
0005435254475	19314	4	4B
0005435254474	19314	5	4A
0005433459185	19314	6	5A
0005433459198	19314	7	5B
0005433459159	19314	8	6B
0005433459190	19314	9	6A
0005435437823	6712	1	1A
0005435682150	6712	2	1C
0005435437811	6712	3	1D
0005435682136	6712	4	1F
0005435437765	6712	5	2A
0005435682114	6712	6	2C
0005432136170	6712	7	2F
0005435682144	6712	8	3A
0005435682125	6712	9	3C
0005435682111	6712	10	3D
0005435682115	6712	11	3F
0005435682131	6712	12	4A
0005435682141	6712	13	4C
0005435437791	6712	14	4D
0005435682149	6712	15	4E
0005435630963	6712	16	4F
0005435437842	6712	17	5A
0005435682122	6712	18	5C
0005435437747	6712	19	5D
0005435217699	6712	20	5E
0005435437868	6712	21	5F
0005435682152	6712	22	6A
0005435682128	6712	23	6C
0005435437654	6712	24	6D
0005432136168	6712	25	6E
0005435682139	6712	26	6F
0005435661927	6712	27	7A
0005435682138	6712	28	7C
0005435682142	6712	29	7D
0005435682113	6712	30	7E
0005435682151	6712	31	8A
0005435661930	6712	32	8C
0005435682148	6712	33	8D
0005435682135	6712	34	8E
0005432136167	6712	35	8F
0005435630964	6712	36	9A
0005435682132	6712	37	9C
0005435682109	6712	38	9D
0005432136169	6712	39	9E
0005435682129	6712	40	9F
0005435682130	6712	41	10A
0005435437771	6712	42	10C
0005435437836	6712	43	10D
0005432136171	6712	44	10E
0005434828671	6712	45	10F
0005435682154	6712	46	11C
0005435217696	6712	47	11D
0005435682120	6712	48	11E
0005434828672	6712	49	11F
0005435682117	6712	50	12A
0005435437756	6712	51	12C
0005435437837	6712	52	12D
0005435682127	6712	53	12E
0005435437754	6712	54	12F
0005435437667	6712	55	13A
0005435682121	6712	56	13C
0005435682145	6712	57	13D
0005435682110	6712	58	13E
0005435682119	6712	59	13F
0005435630965	6712	60	14A
0005435630966	6712	61	14C
0005435682112	6712	62	14D
0005435437822	6712	63	14E
0005434828661	6712	64	14F
0005434828675	6712	65	15A
0005435682140	6712	66	15C
0005435682116	6712	67	15D
0005435217698	6712	68	15E
0005434828673	6712	69	15F
0005435437820	6712	70	16A
0005435437764	6712	71	16C
0005435682143	6712	72	16D
0005435437690	6712	73	16E
0005435437755	6712	74	16F
0005435682134	6712	75	17A
0005435682118	6712	76	17C
0005435682126	6712	77	17D
0005435682124	6712	78	17E
0005434828674	6712	79	17F
0005435682147	6712	80	18A
0005435630967	6712	81	18C
0005435682123	6712	82	18D
0005435682137	6712	83	18E
0005435682153	6712	84	18F
0005435437753	6712	85	19A
0005435682133	6712	86	19C
0005435217697	6712	87	19D
0005435437819	6712	88	19E
0005435661929	6712	89	19F
0005435661928	6712	90	20A
0005435437867	6712	91	20D
0005435220300	6712	92	20E
0005435682146	6712	93	20F
0005435681802	24600	1	1A
0005435437946	24600	2	1C
0005435681795	24600	3	1D
0005435681553	24600	4	1F
0005435681761	24600	5	2A
0005435681759	24600	6	2C
0005435220316	24600	7	2D
0005435630917	24600	8	2F
0005435219197	24600	9	3C
0005435437943	24600	10	3D
0005435661902	24600	11	3F
0005435681670	24600	12	4A
0005435681640	24600	13	4D
0005435437954	24600	14	4E
0005435437948	24600	15	4F
0005435437957	24600	16	5A
0005435681779	24600	17	5C
0005435437956	24600	18	5D
0005435681799	24600	19	5E
0005435661908	24600	20	5F
0005435220317	24600	21	6A
0005435681760	24600	22	6C
0005435630918	24600	23	6D
0005435630938	24600	24	6E
0005435437947	24600	25	6F
0005435437939	24600	26	7A
0005435681902	24600	27	7C
0005435661909	24600	28	7D
0005434828699	24600	29	7F
0005432305747	24600	30	8A
0005432305748	24600	31	8C
0005435681840	24600	32	8D
0005435219198	24600	33	8E
0005435681809	24600	34	8F
0005432533291	24600	35	9A
0005435681977	24600	36	9C
0005435219200	24600	37	9D
0005435437945	24600	38	9E
0005435437953	24600	39	10A
0005434828696	24600	40	10C
0005435681621	24600	41	10D
0005434828698	24600	42	10E
0005435681841	24600	43	10F
0005435681671	24600	44	11A
0005435437952	24600	45	11C
0005435219199	24600	46	11D
0005432305749	24600	47	11E
0005435437960	24600	48	11F
0005435681639	24600	49	12A
0005435681708	24600	50	12C
0005435681848	24600	51	12D
0005435661901	24600	52	12E
0005434828697	24600	53	12F
0005435681886	24600	54	13A
0005435437944	24600	55	13C
0005435681833	24600	56	13D
0005435437942	24600	57	13E
0005435681849	24600	58	13F
0005435681685	24600	59	14A
0005435681817	24600	60	14C
0005435681647	24600	61	14D
0005435220319	24600	62	14E
0005435681672	24600	63	14F
0005435681688	24600	64	15A
0005435437938	24600	65	15C
0005435437940	24600	66	15D
0005435437955	24600	67	15E
0005435681768	24600	68	15F
0005435681803	24600	69	16C
0005435437950	24600	70	16D
0005435437958	24600	71	16E
0005435630944	24600	72	16F
0005435220318	24600	73	17A
0005435681715	24600	74	17C
0005435681784	24600	75	17D
0005432533292	24600	76	17F
0005435437941	24600	77	18A
0005435681751	24600	78	18C
0005435681752	24600	79	18D
0005435681631	24600	80	18E
0005435681622	24600	81	18F
0005435437949	24600	82	19A
0005435437951	24600	83	19C
0005435681778	24600	84	19E
0005435661900	24600	85	20A
0005435681932	24600	86	20C
0005435437959	24600	87	20D
0005435681916	24600	88	20E
0005435681794	24600	89	20F
0005435126346	11553	1	1D
0005435126325	11553	2	1F
0005435126332	11553	3	2A
0005435126337	11553	4	2C
0005435126326	11553	5	2D
0005435126341	11553	6	3A
0005435126331	11553	7	3C
0005435126349	11553	8	3D
0005435126354	11553	9	3F
0005435126329	11553	10	4A
0005435126347	11553	11	4E
0005435126348	11553	12	4F
0005435126314	11553	13	5A
0005435126315	11553	14	5D
0005435558059	11553	15	5C
0005435126321	11553	16	5F
0005435126338	11553	17	6A
0005435126324	11553	18	6E
0005435126352	11553	19	7D
0005435126345	11553	20	8A
0005435126334	11553	21	8D
0005435105978	11553	22	8E
0005435126350	11553	23	8F
0005435126351	11553	24	9D
0005435558062	11553	25	9E
0005435126344	11553	26	10A
0005435126320	11553	27	10C
0005435558065	11553	28	10E
0005435126327	11553	29	11C
0005435558066	11553	30	11D
0005435126336	11553	31	11E
0005435105980	11553	32	12D
0005435126318	11553	33	12E
0005435558061	11553	34	13A
0005435558069	11553	35	13E
0005435126342	11553	36	14E
0005435126333	11553	37	15D
0005435126343	11553	38	15E
0005435126316	11553	39	15F
0005435126353	11553	40	16D
0005435126330	11553	41	16E
0005435126322	11553	42	16F
0005435126339	11553	43	17C
0005435105979	11553	44	17E
0005435126317	11553	45	18D
0005435126323	11553	46	18E
0005435126328	11553	47	18F
0005435126340	11553	48	19C
0005435126335	11553	49	19F
0005435126319	11553	50	20D
0005435125948	31883	1	1A
0005435098540	31883	2	1F
0005435126009	31883	3	2A
0005435558088	31883	4	2C
0005435558086	31883	5	2D
0005435126059	31883	6	4A
0005435126078	31883	7	5C
0005435125933	31883	8	5D
0005435125987	31883	9	5E
0005435125892	31883	10	6A
0005435126064	31883	11	6C
0005435125949	31883	12	6E
0005435125954	31883	13	7A
0005435126000	31883	14	7C
0005435126069	31883	15	7D
0005435125924	31883	16	7E
0005435126071	31883	17	8A
0005435105947	31883	18	8C
0005435126228	31883	19	8D
0005435126020	31883	20	9C
0005435125877	31883	21	9E
0005435126008	31883	22	9F
0005435558085	31883	23	10C
0005435125965	31883	24	10D
0005435126048	31883	25	10F
0005435125953	31883	26	11A
0005435126049	31883	27	11C
0005435126115	31883	28	11D
0005435126198	31883	29	11F
0005435558087	31883	30	12A
0005435125982	31883	31	12C
0005435105945	31883	32	12F
0005435126015	31883	33	12E
0005435125923	31883	34	13A
0005435125835	31883	35	13D
0005435125952	31883	36	13E
0005435125988	31883	37	14A
0005435126149	31883	38	14D
0005435126099	31883	39	14F
0005435126050	31883	40	15A
0005435126199	31883	41	15D
0005435126090	31883	42	15F
0005435125916	31883	43	16A
0005435125893	31883	44	16C
0005435126089	31883	45	16D
0005435105946	31883	46	17D
0005435125981	31883	47	17E
0005435125966	31883	48	18D
0005435126145	31883	49	20D
0005435125719	31883	50	20E
0005435126142	31883	51	20F
0005433398050	13526	1	1A
0005433398074	13526	2	1C
0005433398025	13526	3	1F
0005433398055	13526	4	2A
0005433398066	13526	5	2C
0005433398046	13526	6	2F
0005433398038	13526	7	3D
0005433398037	13526	8	3F
0005435732288	13526	9	4A
0005433398040	13526	10	4C
0005433398042	13526	11	4D
0005433398039	13526	12	5A
0005433398035	13526	13	5C
0005433398067	13526	14	5D
0005433398024	13526	15	5E
0005433398062	13526	16	6A
0005433398069	13526	17	6D
0005433398033	13526	18	6E
0005433398043	13526	19	6F
0005433398065	13526	20	7A
0005433398034	13526	21	7C
0005433398056	13526	22	7D
0005435732235	13526	23	8A
0005433398032	13526	24	8C
0005433398058	13526	25	8D
0005433398026	13526	26	8F
0005433398053	13526	27	9A
0005433398052	13526	28	9D
0005433398060	13526	29	9F
0005433398064	13526	30	10A
0005433398071	13526	31	10D
0005433398044	13526	32	10E
0005433398049	13526	33	11C
0005433398027	13526	34	11E
0005433398045	13526	35	12D
0005435732217	13526	36	12E
0005433398059	13526	37	13A
0005433398041	13526	38	13D
0005433398030	13526	39	13E
0005435732174	13526	40	13F
0005435732287	13526	41	14A
0005435732203	13526	42	14D
0005435732219	13526	43	14F
0005433398061	13526	44	16A
0005433398051	13526	45	16C
0005433398054	13526	46	16F
0005433398036	13526	47	17A
0005435732173	13526	48	17C
0005433398028	13526	49	17D
0005433398068	13526	50	17E
0005433398029	13526	51	17F
0005433398057	13526	52	18A
0005433398047	13526	53	18C
0005433398048	13526	54	18E
0005433398073	13526	55	18F
0005433398072	13526	56	19C
0005435732202	13526	57	19E
0005433398031	13526	58	19F
0005435732180	13526	59	20A
0005433398063	13526	60	20D
0005433398070	13526	61	20E
0005433397632	19371	1	1C
0005433397495	19371	2	1F
0005433397609	19371	3	2A
0005433397720	19371	4	2C
0005435732324	19371	5	2D
0005433397621	19371	6	2F
0005433397596	19371	7	3A
0005433397777	19371	8	3C
0005433397655	19371	9	3D
0005433397418	19371	10	4C
0005433397500	19371	11	4D
0005435732322	19371	12	4E
0005433397823	19371	13	4F
0005433397580	19371	14	5A
0005433397788	19371	15	5E
0005435732317	19371	16	5F
0005435732325	19371	17	6A
0005432297276	19371	18	6C
0005433397794	19371	19	6E
0005433397776	19371	20	7A
0005433397730	19371	21	7D
0005433397605	19371	22	8A
0005435732320	19371	23	8E
0005433397600	19371	24	8F
0005433397714	19371	25	9D
0005433397668	19371	26	9E
0005435732323	19371	27	9F
0005433397447	19371	28	10A
0005433397594	19371	29	10C
0005432297277	19371	30	10E
0005433397695	19371	31	11A
0005433397667	19371	32	11C
0005435732326	19371	33	11D
0005433397745	19371	34	12A
0005433397622	19371	35	12C
0005433397746	19371	36	12E
0005433397733	19371	37	12F
0005433397818	19371	38	13A
0005433397540	19371	39	13D
0005433397775	19371	40	13E
0005433397628	19371	41	13F
0005433397642	19371	42	14A
0005433397612	19371	43	14C
0005433397577	19371	44	14D
0005433397643	19371	45	14F
0005435732321	19371	46	15A
0005433397633	19371	47	15D
0005433397512	19371	48	15E
0005433397826	19371	49	16C
0005433397734	19371	50	16E
0005433397527	19371	51	16F
0005433397729	19371	52	17A
0005433397333	19371	53	17C
0005433397481	19371	54	17D
0005433397822	19371	55	17E
0005433397719	19371	56	17F
0005433397639	19371	57	18A
0005435732319	19371	58	18C
0005433397744	19371	59	18D
0005435732318	19371	60	18E
0005433397528	19371	61	18F
0005433397539	19371	62	19A
0005433397663	19371	63	19C
0005433397709	19371	64	19E
0005433397417	19371	65	19F
0005433397532	19371	66	20E
0005433397669	19371	67	20F
0005435068457	13172	1	1A
0005435068664	13172	2	1F
0005435068368	13172	3	2C
0005435068579	13172	4	3A
0005435068458	13172	5	3C
0005435068178	13172	6	3D
0005435068631	13172	7	4C
0005435068593	13172	8	4E
0005435068632	13172	9	5D
0005435068591	13172	10	5E
0005435068618	13172	11	6E
0005435068693	13172	12	6F
0005435068617	13172	13	7C
0005435068645	13172	14	7D
0005435068589	13172	15	7E
0005435068700	13172	16	8A
0005435068578	13172	17	8D
0005435068777	13172	18	8E
0005435068602	13172	19	9D
0005435068657	13172	20	9E
0005435068569	13172	21	9F
0005435068580	13172	22	11C
0005435068583	13172	23	11D
0005435068809	13172	24	11E
0005435068557	13172	25	11F
0005435068547	13172	26	12A
0005435068644	13172	27	12C
0005435068413	13172	28	12D
0005435068699	13172	29	12F
0005435068603	13172	30	13C
0005435068588	13172	31	13E
0005435068491	13172	32	14D
0005435068434	13172	33	14E
0005435068774	13172	34	14F
0005435068666	13172	35	16A
0005435068788	13172	36	16F
0005435068834	13172	37	17A
0005435068556	13172	38	18A
0005435068415	13172	39	19A
0005435068568	13172	40	19F
0005435068414	13172	41	20A
0005435068673	13172	42	20E
0005435068685	13172	43	20F
0005435925162	15467	1	1A
0005435069024	15467	2	1C
0005435069030	15467	3	1D
0005435069033	15467	4	2A
0005435925173	15467	5	2C
0005435069051	15467	6	3A
0005435925118	15467	7	3C
0005435925172	15467	8	3D
0005435069049	15467	9	3F
0005435069045	15467	10	4E
0005435925159	15467	11	4F
0005435069007	15467	12	5A
0005435069036	15467	13	5C
0005435069017	15467	14	5F
0005435069019	15467	15	6C
0005435069016	15467	16	6D
0005435069057	15467	17	6F
0005435925154	15467	18	7A
0005435069031	15467	19	7C
0005435925096	15467	20	7D
0005435069009	15467	21	7E
0005435069011	15467	22	8A
0005435069044	15467	23	8C
0005435069027	15467	24	8D
0005435925130	15467	25	8E
0005435069050	15467	26	8F
0005435069041	15467	27	9A
0005435925161	15467	28	9C
0005435069055	15467	29	9E
0005435069046	15467	30	9F
0005435925099	15467	31	10D
0005435069048	15467	32	10E
0005435069021	15467	33	10F
0005435069038	15467	34	11A
0005435925149	15467	35	11C
0005435069010	15467	36	11F
0005435069043	15467	37	12C
0005435069028	15467	38	12D
0005435069025	15467	39	12E
0005435069034	15467	40	13D
0005435069042	15467	41	13E
0005435925163	15467	42	13F
0005435069037	15467	43	14A
0005435069008	15467	44	14C
0005435925170	15467	45	14D
0005435925178	15467	46	14E
0005435069047	15467	47	14F
0005435069032	15467	48	15C
0005435069052	15467	49	15D
0005435069026	15467	50	15E
0005435069054	15467	51	16A
0005435069022	15467	52	16C
0005435069012	15467	53	16D
0005435069018	15467	54	16E
0005435069015	15467	55	16F
0005435925155	15467	56	17C
0005435069014	15467	57	17D
0005435069053	15467	58	18A
0005435069013	15467	59	18D
0005435069039	15467	60	18F
0005435069040	15467	61	19A
0005435069056	15467	62	19C
0005435069020	15467	63	19D
0005435069035	15467	64	19E
0005435069029	15467	65	20A
0005435069058	15467	66	20C
0005435069023	15467	67	20D
0005435925156	15467	68	20E
0005435808226	23182	1	1A
0005435808224	23182	2	1D
0005435808221	23182	3	2A
0005435808219	23182	4	2C
0005435808213	23182	5	2D
0005435808215	23182	6	3A
0005433407517	23182	7	3B
0005433407516	23182	8	3C
0005435808222	23182	9	3D
0005435808217	23182	10	4A
0005435808209	23182	11	4B
0005433407513	23182	12	4C
0005433407500	23182	13	5A
0005435808218	23182	14	5B
0005435808229	23182	15	5C
0005435808216	23182	16	5D
0005435808228	23182	17	6A
0005435808227	23182	18	6C
0005433407512	23182	19	7A
0005435808212	23182	20	7B
0005433407492	23182	21	7C
0005433407509	23182	22	7D
0005433407510	23182	23	18B
0005435808220	23182	24	18C
0005433407493	23182	25	19D
0005435808225	23182	26	20B
0005435808211	23182	27	20D
0005435808210	23182	28	21B
0005433407499	23182	29	21C
0005433407498	23182	30	22A
0005435808223	23182	31	22B
0005435808214	23182	32	22D
0005435808230	23182	33	23A
0005434214512	10681	1	1A
0005434214519	10681	2	1C
0005434756094	10681	3	1D
0005434755982	10681	4	2A
0005434214534	10681	5	2C
0005434214552	10681	6	2D
0005434755897	10681	7	2F
0005434214550	10681	8	3A
0005434755945	10681	9	3C
0005434214514	10681	10	3D
0005434756052	10681	11	3F
0005434214520	10681	12	4C
0005434214535	10681	13	4D
0005434756092	10681	14	4E
0005434214510	10681	15	4F
0005434214532	10681	16	5A
0005434756016	10681	17	5C
0005434214523	10681	18	5D
0005434214542	10681	19	5E
0005434756091	10681	20	5F
0005434756093	10681	21	6A
0005434214531	10681	22	6C
0005434756048	10681	23	6D
0005434214511	10681	24	6E
0005434214546	10681	25	6F
0005434756051	10681	26	7C
0005434214537	10681	27	7D
0005434756127	10681	28	7E
0005434214533	10681	29	8A
0005434214554	10681	30	8C
0005434214545	10681	31	8D
0005434756023	10681	32	8E
0005434214555	10681	33	8F
0005434214528	10681	34	9A
0005434755974	10681	35	9C
0005434756098	10681	36	9D
0005434214525	10681	37	9E
0005434214538	10681	38	9F
0005434214540	10681	39	10A
0005434756119	10681	40	10C
0005434214524	10681	41	10D
0005434214515	10681	42	10E
0005434756130	10681	43	11A
0005434214522	10681	44	11D
0005434756086	10681	45	11E
0005434755898	10681	46	11F
0005434755948	10681	47	12A
0005434755883	10681	48	12C
0005434214530	10681	49	12D
0005434756078	10681	50	12E
0005434755947	10681	51	12F
0005434755962	10681	52	13A
0005434756186	10681	53	13C
0005434756079	10681	54	13D
0005434214509	10681	55	13E
0005434214551	10681	56	13F
0005434214548	10681	57	14A
0005434214518	10681	58	14C
0005434214541	10681	59	14D
0005434756070	10681	60	14E
0005434214539	10681	61	14F
0005434756104	10681	62	15C
0005434756077	10681	63	15A
0005434214526	10681	64	15D
0005434214516	10681	65	15E
0005434756172	10681	66	15F
0005434214517	10681	67	16A
0005434214513	10681	68	16C
0005434756027	10681	69	16D
0005434755946	10681	70	16E
0005434214556	10681	71	16F
0005434214536	10681	72	17A
0005434756066	10681	73	17C
0005434214521	10681	74	17D
0005434755858	10681	75	17E
0005434756058	10681	76	17F
0005434756117	10681	77	18A
0005434755961	10681	78	18C
0005434755964	10681	79	18D
0005434214527	10681	80	18E
0005434214529	10681	81	18F
0005434756001	10681	82	19A
0005434214547	10681	83	19C
0005434214508	10681	84	19D
0005434756017	10681	85	19E
0005434214553	10681	86	19F
0005434214549	10681	87	20A
0005434214544	10681	88	20C
0005434756074	10681	89	20D
0005434756073	10681	90	20E
0005434214543	10681	91	20F
0005434756367	28688	1	1A
0005434214053	28688	2	1C
0005434756404	28688	3	1D
0005434213857	28688	4	1F
0005434213851	28688	5	2A
0005434756400	28688	6	2C
0005434756402	28688	7	2D
0005434756373	28688	8	2F
0005434756364	28688	9	3A
0005434756368	28688	10	3C
0005434213991	28688	11	3D
0005434756392	28688	12	3F
0005434756405	28688	13	4C
0005434756380	28688	14	4D
0005434213967	28688	15	4E
0005434214095	28688	16	4F
0005434214253	28688	17	5A
0005434756372	28688	18	5C
0005434213886	28688	19	5D
0005434214137	28688	20	5E
0005434756383	28688	21	5F
0005434756381	28688	22	6A
0005434214098	28688	23	6D
0005434756362	28688	24	6C
0005434214261	28688	25	6E
0005434756393	28688	26	6F
0005434214091	28688	27	7A
0005434213873	28688	28	7C
0005434756403	28688	29	7E
0005434214252	28688	30	7F
0005434756387	28688	31	8C
0005434756371	28688	32	8A
0005434213892	28688	33	8D
0005434756365	28688	34	8E
0005434213930	28688	35	8F
0005434756382	28688	36	9A
0005434756397	28688	37	9C
0005434214209	28688	38	9D
0005434214049	28688	39	9E
0005434756389	28688	40	9F
0005434756407	28688	41	10A
0005434756374	28688	42	10C
0005434756379	28688	43	10D
0005434214207	28688	44	10E
0005434756395	28688	45	10F
0005434756388	28688	46	11A
0005434756398	28688	47	11D
0005434213920	28688	48	11E
0005434214028	28688	49	11F
0005434214210	28688	50	12C
0005434756377	28688	51	12D
0005434756396	28688	52	12E
0005434756369	28688	53	12F
0005434213973	28688	54	13A
0005434213901	28688	55	13C
0005434213890	28688	56	13D
0005434214149	28688	57	13E
0005434756390	28688	58	13F
0005434756401	28688	59	14A
0005434756366	28688	60	14C
0005434214146	28688	61	14D
0005434756386	28688	62	14F
0005434214070	28688	63	15A
0005434213900	28688	64	15C
0005434756399	28688	65	15D
0005434756376	28688	66	15E
0005434214144	28688	67	15F
0005434214090	28688	68	16A
0005434213882	28688	69	16D
0005434213906	28688	70	16E
0005434756375	28688	71	16F
0005434214145	28688	72	17A
0005434213983	28688	73	17C
0005434756378	28688	74	17D
0005434756391	28688	75	17E
0005434756406	28688	76	17F
0005434214005	28688	77	18A
0005434756394	28688	78	18C
0005434214208	28688	79	18D
0005434213881	28688	80	18E
0005434214094	28688	81	18F
0005434756370	28688	82	19A
0005434213891	28688	83	19C
0005434214260	28688	84	19D
0005434756363	28688	85	19E
0005434756385	28688	86	20A
0005434214100	28688	87	20C
0005434756384	28688	88	20D
0005434213990	28688	89	20E
0005434214148	28688	90	20F
0005434229174	5461	1	1A
0005435007026	5461	2	1C
0005435039787	5461	3	1D
0005435039796	5461	4	2A
0005435039764	5461	5	1F
0005434229237	5461	6	2C
0005435039738	5461	7	2D
0005435039794	5461	8	3A
0005432125449	5461	9	2F
0005435039761	5461	10	3D
0005434229131	5461	11	3C
0005434229153	5461	12	4A
0005434229072	5461	13	3F
0005435039751	5461	14	4B
0005434229073	5461	15	4D
0005435039798	5461	16	4C
0005435039748	5461	17	4E
0005434229190	5461	18	4F
0005435039741	5461	19	5A
0005435007033	5461	20	5C
0005435039766	5461	21	5B
0005435039774	5461	22	5D
0005435039779	5461	23	5E
0005435007042	5461	24	6A
0005435007038	5461	25	5F
0005435039772	5461	26	6B
0005435007040	5461	27	6C
0005434229145	5461	28	6D
0005432125453	5461	29	6E
0005434229040	5461	30	7A
0005435039784	5461	31	6F
0005435007021	5461	32	7B
0005435039785	5461	33	7C
0005434229179	5461	34	7E
0005434229221	5461	35	7D
0005435039791	5461	36	7F
0005435007039	5461	37	8A
0005435007035	5461	38	8B
0005435007023	5461	39	8C
0005434229196	5461	40	8E
0005435007041	5461	41	8D
0005434229169	5461	42	9B
0005435039753	5461	43	9A
0005435007031	5461	44	8F
0005434229197	5461	45	9D
0005435039746	5461	46	9C
0005435007029	5461	47	9E
0005434229192	5461	48	9F
0005434229220	5461	49	10B
0005435039758	5461	50	10D
0005434229238	5461	51	10C
0005435039745	5461	52	10E
0005435039750	5461	53	11A
0005435039793	5461	54	11B
0005434229276	5461	55	11C
0005435039777	5461	56	11E
0005435039795	5461	57	11D
0005435039743	5461	58	11F
0005435039776	5461	59	12A
0005434229140	5461	60	12C
0005435039783	5461	61	12B
0005435007025	5461	62	12D
0005434229184	5461	63	12E
0005435039773	5461	64	12F
0005435039755	5461	65	13B
0005432125454	5461	66	13A
0005435039788	5461	67	13C
0005435039786	5461	68	13D
0005434229139	5461	69	13E
0005435007030	5461	70	13F
0005435007034	5461	71	14A
0005435039744	5461	72	14B
0005432125452	5461	73	14D
0005434229180	5461	74	14C
0005435039767	5461	75	14E
0005435007022	5461	76	14F
0005432125450	5461	77	15A
0005435039737	5461	78	15C
0005435039740	5461	79	15D
0005435039769	5461	80	16A
0005435039799	5461	81	15F
0005435039747	5461	82	16B
0005435039770	5461	83	16C
0005432125448	5461	84	16D
0005435039771	5461	85	17A
0005435007027	5461	86	16F
0005435039757	5461	87	17B
0005432125451	5461	88	17C
0005434229039	5461	89	17D
0005434229185	5461	90	17E
0005435039760	5461	91	18A
0005434229107	5461	92	17F
0005435007028	5461	93	18B
0005435039792	5461	94	18C
0005435039780	5461	95	18D
0005435039762	5461	96	18F
0005435039754	5461	97	18E
0005435039797	5461	98	19A
0005435039736	5461	99	19B
0005435039775	5461	100	19D
0005435039790	5461	101	19C
0005434229229	5461	102	19E
0005434229240	5461	103	19F
0005435039756	5461	104	20A
0005435039749	5461	105	20B
0005434229122	5461	106	20D
0005435039742	5461	107	20C
0005435039789	5461	108	20E
0005435039782	5461	109	21A
0005435007032	5461	110	20F
0005435039768	5461	111	21C
0005435039765	5461	112	21B
0005435007024	5461	113	21D
0005434229205	5461	114	21E
0005434229146	5461	115	22A
0005435007037	5461	116	21F
0005434229106	5461	117	22B
0005435039759	5461	118	22C
0005435039763	5461	119	22D
0005435007043	5461	120	22E
0005435039752	5461	121	22F
0005435039781	5461	122	23B
0005435007036	5461	123	23A
0005435039778	5461	124	23C
0005434229239	5461	125	23E
0005434229277	5461	126	23D
0005435039739	5461	127	23F
0005435038961	12958	1	1C
0005435039305	12958	2	1F
0005435039326	12958	3	1D
0005435039235	12958	4	2A
0005435039112	12958	5	2C
0005435039073	12958	6	2D
0005434229362	12958	7	2F
0005435006807	12958	8	3A
0005435038947	12958	9	3D
0005434229375	12958	10	3C
0005435006883	12958	11	3F
0005435039152	12958	12	4A
0005435042834	12958	13	4C
0005432304397	12958	14	4B
0005435039303	12958	15	4D
0005435039100	12958	16	4E
0005435039306	12958	17	4F
0005435039241	12958	18	5B
0005435039133	12958	19	5A
0005435039572	12958	20	5C
0005435038979	12958	21	5D
0005434229367	12958	22	5E
0005435038996	12958	23	5F
0005435039178	12958	24	6B
0005435039070	12958	25	6A
0005435006824	12958	26	6C
0005435039130	12958	27	6D
0005435039236	12958	28	6F
0005435039218	12958	29	6E
0005435039075	12958	30	7A
0005434229361	12958	31	7B
0005435006802	12958	32	7C
0005435039284	12958	33	7D
0005435006787	12958	34	7E
0005434229381	12958	35	8A
0005435006803	12958	36	7F
0005435038952	12958	37	8B
0005432304396	12958	38	8D
0005435039051	12958	39	8C
0005435006792	12958	40	8E
0005435039009	12958	41	9A
0005435039067	12958	42	8F
0005435039238	12958	43	9B
0005435039229	12958	44	9D
0005434229377	12958	45	9C
0005435006813	12958	46	9E
0005435006834	12958	47	9F
0005434229360	12958	48	10B
0005435039190	12958	49	10C
0005435039074	12958	50	10D
0005435006769	12958	51	11A
0005435039222	12958	52	10E
0005435039099	12958	53	11B
0005435039281	12958	54	11D
0005434229378	12958	55	11C
0005435006743	12958	56	11E
0005435039132	12958	57	11F
0005435039121	12958	58	12B
0005435006835	12958	59	12A
0005435039154	12958	60	12C
0005434229371	12958	61	12E
0005435039343	12958	62	12D
0005435038925	12958	63	12F
0005435039253	12958	64	13A
0005435039202	12958	65	13C
0005435039223	12958	66	13B
0005435042841	12958	67	13D
0005435006814	12958	68	13E
0005432304398	12958	69	13F
0005435039052	12958	70	14A
0005435039131	12958	71	14B
0005434229370	12958	72	14D
0005434229363	12958	73	14C
0005435039111	12958	74	14F
0005435039043	12958	75	14E
0005435038992	12958	76	15B
0005435039188	12958	77	15A
0005434229366	12958	78	15C
0005435039298	12958	79	15D
0005435039314	12958	80	15F
0005435006788	12958	81	15E
0005435039245	12958	82	16A
0005435039158	12958	83	16B
0005435039327	12958	84	16C
0005434229379	12958	85	16E
0005435039277	12958	86	16D
0005435042840	12958	87	17A
0005435006789	12958	88	16F
0005435039008	12958	89	17B
0005435039336	12958	90	17C
0005435006806	12958	91	17E
0005434229359	12958	92	17D
0005435039385	12958	93	17F
0005435039013	12958	94	18A
0005432304399	12958	95	18B
0005434229365	12958	96	18D
0005435038953	12958	97	18E
0005435039058	12958	98	18F
0005435039012	12958	99	19A
0005435038830	12958	100	19C
0005435006825	12958	101	19B
0005435039119	12958	102	19D
0005435006930	12958	103	19E
0005434229372	12958	104	19F
0005435038749	12958	105	20A
0005434229374	12958	106	20B
0005434229382	12958	107	20D
0005435039285	12958	108	20C
0005435039299	12958	109	20E
0005435039244	12958	110	20F
0005435039011	12958	111	21B
0005435039018	12958	112	21A
0005435038964	12958	113	21C
0005434229376	12958	114	21D
0005434229380	12958	115	21F
0005435039156	12958	116	21E
0005435039157	12958	117	22B
0005435039276	12958	118	22A
0005434229369	12958	119	22C
0005435039296	12958	120	22D
0005435043276	12958	121	22E
0005434229373	12958	122	23A
0005435039083	12958	123	22F
0005435039101	12958	124	23B
0005434229364	12958	125	23C
0005434229368	12958	126	23D
0005435006744	12958	127	23F
0005434426575	14882	1	1D
0005434426573	14882	2	1F
0005434411772	14882	3	2C
0005435902528	14882	4	2F
0005435902545	14882	5	3A
0005435902547	14882	6	3C
0005435902573	14882	7	3D
0005435902405	14882	8	3F
0005435902553	14882	9	4A
0005435554146	14882	10	4C
0005435902536	14882	11	4F
0005434426568	14882	12	5C
0005434426585	14882	13	5D
0005434426578	14882	14	5E
0005435902522	14882	15	5F
0005435902476	14882	16	6A
0005434426587	14882	17	6C
0005432188603	14882	18	6E
0005434426580	14882	19	6D
0005435902500	14882	20	6F
0005435554139	14882	21	7A
0005435902459	14882	22	7D
0005435902475	14882	23	7E
0005435554133	14882	24	7F
0005435902585	14882	25	8D
0005435902477	14882	26	8E
0005434426593	14882	27	8F
0005435902574	14882	28	9A
0005434426579	14882	29	9C
0005432188604	14882	30	9D
0005434426581	14882	31	9F
0005435902457	14882	32	10A
0005434426591	14882	33	10D
0005435902544	14882	34	10E
0005435902548	14882	35	10F
0005434426588	14882	36	11A
0005434426569	14882	37	11D
0005435902462	14882	38	11E
0005434426567	14882	39	11F
0005434426590	14882	40	12C
0005434426570	14882	41	12D
0005434426577	14882	42	12E
0005435902404	14882	43	12F
0005435902508	14882	44	13A
0005434426596	14882	45	13C
0005435902541	14882	46	13D
0005435902572	14882	47	14A
0005434426597	14882	48	14D
0005435902586	14882	49	15A
0005434426586	14882	50	15C
0005435902552	14882	51	15D
0005434426592	14882	52	15E
0005434426589	14882	53	16C
0005434426595	14882	54	16D
0005435902550	14882	55	16E
0005435902493	14882	56	17A
0005435554134	14882	57	17C
0005434426594	14882	58	17D
0005434411773	14882	59	17E
0005434426571	14882	60	17F
0005435902519	14882	61	18A
0005434411775	14882	62	18C
0005434426583	14882	63	18D
0005434426572	14882	64	18E
0005434411774	14882	65	18F
0005434426576	14882	66	19A
0005434426582	14882	67	19C
0005434426574	14882	68	19E
0005435902458	14882	69	19F
0005432188605	14882	70	20C
0005434426584	14882	71	20E
0005434426329	20219	1	1C
0005435554190	20219	2	2A
0005434426333	20219	3	2C
0005435902701	20219	4	2D
0005435902700	20219	5	2F
0005435902709	20219	6	3A
0005434426272	20219	7	3D
0005434426322	20219	8	3F
0005435902696	20219	9	4A
0005434426267	20219	10	4C
0005435902705	20219	11	4F
0005434426265	20219	12	5A
0005434426278	20219	13	5D
0005434426269	20219	14	5E
0005435554191	20219	15	5F
0005435902694	20219	16	6E
0005434411748	20219	17	6F
0005434426470	20219	18	7C
0005434426469	20219	19	7D
0005434426399	20219	20	7E
0005434426377	20219	21	7F
0005434426359	20219	22	8C
0005434426400	20219	23	8D
0005435902706	20219	24	8F
0005434426339	20219	25	9D
0005435902707	20219	26	9E
0005434426286	20219	27	9F
0005434426352	20219	28	10A
0005434426467	20219	29	10D
0005434426358	20219	30	10F
0005434426351	20219	31	11C
0005435902702	20219	32	11E
0005435902711	20219	33	12A
0005434426403	20219	34	12D
0005435902698	20219	35	12E
0005434426315	20219	36	12F
0005435902699	20219	37	13C
0005435554188	20219	38	13E
0005432059505	20219	39	13F
0005434426273	20219	40	14A
0005435554189	20219	41	14C
0005435902697	20219	42	14D
0005435902703	20219	43	15A
0005435902708	20219	44	15C
0005434426350	20219	45	16D
0005434426268	20219	46	16E
0005432059504	20219	47	16F
0005435902704	20219	48	17A
0005434426362	20219	49	17E
0005435902710	20219	50	17F
0005435902695	20219	51	18C
0005434411744	20219	52	18F
0005434411764	20219	53	19C
0005434426382	20219	54	19D
0005434426361	20219	55	19F
0005434426279	20219	56	20A
0005434426384	20219	57	20C
0005434523768	30894	1	1A
0005434523770	30894	2	6A
0005432462483	30894	3	6B
0005432462498	30894	4	6D
0005432462484	30894	5	7F
0005432462482	30894	6	9E
0005432462496	30894	7	9D
0005434523773	30894	8	11C
0005434559095	30894	9	12A
0005432462497	30894	10	12D
0005434523775	30894	11	13B
0005434523767	30894	12	13F
0005434523772	30894	13	14C
0005432462488	30894	14	14E
0005432462480	30894	15	15A
0005434559094	30894	16	16C
0005434559092	30894	17	17C
0005432462492	30894	18	18A
0005434523774	30894	19	18D
0005434559093	30894	20	18F
0005432462499	30894	21	19C
0005432462485	30894	22	21E
0005434523769	30894	23	22A
0005432462493	30894	24	21F
0005432462486	30894	25	23D
0005434523771	30894	26	23E
0005433434439	26511	1	1A
0005435982283	26511	2	1C
0005433434442	26511	3	1D
0005433434297	26511	4	1F
0005435982250	26511	5	2A
0005435982259	26511	6	2C
0005435982264	26511	7	2D
0005433434413	26511	8	2F
0005435982278	26511	9	3A
0005433434375	26511	10	3C
0005435982269	26511	11	3D
0005433434549	26511	12	4A
0005433434350	26511	13	4C
0005435982275	26511	14	4D
0005435982241	26511	15	4E
0005433434420	26511	16	4F
0005433434550	26511	17	5A
0005435982261	26511	18	5C
0005435982281	26511	19	5F
0005435982270	26511	20	6A
0005435982254	26511	21	6C
0005435982255	26511	22	6D
0005433434296	26511	23	6E
0005435982265	26511	24	6F
0005433434380	26511	25	7A
0005433434425	26511	26	7C
0005435982285	26511	27	7D
0005435982248	26511	28	7E
0005435982276	26511	29	7F
0005435982277	26511	30	8A
0005433434367	26511	31	8C
0005435982284	26511	32	8D
0005435982243	26511	33	8E
0005435982247	26511	34	8F
0005435982286	26511	35	9A
0005435982267	26511	36	9C
0005433434426	26511	37	9D
0005435982279	26511	38	9E
0005432300261	26511	39	9F
0005433434491	26511	40	10A
0005433434357	26511	41	10C
0005435982262	26511	42	10D
0005433434440	26511	43	10E
0005433434432	26511	44	10F
0005435982290	26511	45	11A
0005432300258	26511	46	11C
0005433434419	26511	47	11D
0005434270188	26511	48	11E
0005433434366	26511	49	11F
0005432300260	26511	50	12A
0005433434557	26511	51	12C
0005432300257	26511	52	12D
0005435982280	26511	53	12F
0005435982273	26511	54	13A
0005432300259	26511	55	13C
0005435982289	26511	56	13D
0005433434356	26511	57	13E
0005435982257	26511	58	13F
0005433434363	26511	59	14A
0005433434412	26511	60	14C
0005435982260	26511	61	14D
0005433434381	26511	62	14E
0005435982263	26511	63	15A
0005435982256	26511	64	15C
0005435982272	26511	65	15D
0005432300255	26511	66	15E
0005435982268	26511	67	15F
0005432300262	26511	68	16A
0005435982246	26511	69	16C
0005435982245	26511	70	16D
0005434270187	26511	71	16E
0005435982252	26511	72	16F
0005435982266	26511	73	17C
0005435982282	26511	74	17D
0005435982249	26511	75	17E
0005433434556	26511	76	17F
0005435982258	26511	77	18A
0005435982274	26511	78	18C
0005435982291	26511	79	18D
0005432300256	26511	80	18E
0005435982253	26511	81	18F
0005435982271	26511	82	19A
0005433434452	26511	83	19C
0005435982244	26511	84	19D
0005435982251	26511	85	19E
0005435982287	26511	86	19F
0005435982288	26511	87	20A
0005433434427	26511	88	20C
0005435982242	26511	89	20D
0005433434490	26511	90	20F
0005435981867	26689	1	1A
0005433434676	26689	2	1C
0005435981953	26689	3	1D
0005433434694	26689	4	2A
0005433434669	26689	5	2C
0005435981810	26689	6	2D
0005433434671	26689	7	3A
0005435981969	26689	8	3C
0005434271312	26689	9	3D
0005435981676	26689	10	3F
0005432051128	26689	11	4A
0005433434684	26689	12	4C
0005433434692	26689	13	4D
0005435981924	26689	14	4E
0005433434690	26689	15	4F
0005433434678	26689	16	5A
0005435981903	26689	17	5D
0005433434674	26689	18	5E
0005435981615	26689	19	5F
0005433434683	26689	20	6A
0005433434686	26689	21	6C
0005435981894	26689	22	6D
0005435981979	26689	23	6E
0005435981925	26689	24	7A
0005435981973	26689	25	6F
0005434271311	26689	26	7C
0005435981899	26689	27	7D
0005433434685	26689	28	7F
0005433434691	26689	29	8A
0005435981917	26689	30	8C
0005435981860	26689	31	8D
0005433434695	26689	32	8E
0005434270207	26689	33	8F
0005435981905	26689	34	9A
0005433434682	26689	35	9C
0005435982002	26689	36	9D
0005435981970	26689	37	9E
0005432051129	26689	38	9F
0005434269102	26689	39	10A
0005433434696	26689	40	10D
0005433434677	26689	41	10E
0005435981749	26689	42	10F
0005433434672	26689	43	11A
0005434270206	26689	44	11C
0005435981866	26689	45	11D
0005434269104	26689	46	11E
0005433434680	26689	47	11F
0005433434689	26689	48	12A
0005435981849	26689	49	12D
0005433434670	26689	50	12E
0005433434693	26689	51	12F
0005432051127	26689	52	13A
0005435981918	26689	53	13C
0005433434688	26689	54	13D
0005433434673	26689	55	13E
0005435981882	26689	56	13F
0005433434679	26689	57	14C
0005433434687	26689	58	14D
0005435981713	26689	59	14F
0005435981845	26689	60	15C
0005435981900	26689	61	15E
0005435981850	26689	62	15F
0005433434681	26689	63	16F
0005435981859	26689	64	17A
0005435981884	26689	65	17C
0005433434675	26689	66	17D
0005435981750	26689	67	17E
0005434269103	26689	68	17F
0005435981881	26689	69	18A
0005435981906	26689	70	18C
0005435982037	26689	71	18E
0005435981861	26689	72	18F
0005435981809	26689	73	19D
0005435981904	26689	74	19E
0005435981616	26689	75	19F
0005435981954	26689	76	20A
0005435981910	26689	77	20C
0005435981949	26689	78	20D
0005433434697	26689	79	20E
0005435981885	26689	80	20F
0005432584041	3162	1	1A
0005432858009	3162	2	1B
0005432584037	3162	3	1D
0005432584044	3162	4	2A
0005432584025	3162	5	2B
0005432584039	3162	6	2C
0005432857976	3162	7	2D
0005432857972	3162	8	3A
0005432584023	3162	9	3C
0005432584040	3162	10	3D
0005432584032	3162	11	4A
0005432584024	3162	12	4D
0005432584036	3162	13	5A
0005432857975	3162	14	5B
0005432857926	3162	15	5D
0005432584028	3162	16	6A
0005432584035	3162	17	6B
0005432857916	3162	18	6C
0005432857959	3162	19	6D
0005432584027	3162	20	7A
0005432857919	3162	21	7B
0005432584022	3162	22	18B
0005432216272	3162	23	18D
0005432584030	3162	24	19B
0005432584045	3162	25	19C
0005432216271	3162	26	19D
0005432584031	3162	27	20A
0005432584042	3162	28	20C
0005432584043	3162	29	21A
0005432216273	3162	30	21B
0005432584026	3162	31	21C
0005432584029	3162	32	22A
0005432584034	3162	33	22C
0005432584021	3162	34	22D
0005432584033	3162	35	23A
0005432584038	3162	36	23B
0005432583898	31488	1	1A
0005432583890	31488	2	1B
0005432583820	31488	3	1C
0005432858064	31488	4	1D
0005432583687	31488	5	2A
0005432858071	31488	6	2C
0005432583885	31488	7	3B
0005432858068	31488	8	3C
0005432583753	31488	9	3D
0005432858067	31488	10	4B
0005432858066	31488	11	4C
0005432583907	31488	12	4D
0005432583748	31488	13	5A
0005432858065	31488	14	5B
0005432583847	31488	15	5C
0005432583870	31488	16	5D
0005432583886	31488	17	6B
0005432583902	31488	18	6C
0005432583843	31488	19	6D
0005432858062	31488	20	7A
0005432583859	31488	21	7B
0005432858070	31488	22	7C
0005432583848	31488	23	18A
0005432583749	31488	24	18B
0005432583862	31488	25	18C
0005432583865	31488	26	18D
0005432583831	31488	27	19A
0005432583845	31488	28	19B
0005432583844	31488	29	19C
0005432583832	31488	30	19D
0005432583821	31488	31	20A
0005432583752	31488	32	20B
0005432583851	31488	33	20C
0005432583686	31488	34	20D
0005432583889	31488	35	21A
0005432583710	31488	36	21B
0005432583830	31488	37	21C
0005432858063	31488	38	21D
0005432858072	31488	39	22A
0005432583846	31488	40	22B
0005432583861	31488	41	22C
0005432858061	31488	42	23A
0005432858069	31488	43	23B
0005434943350	879	1	1B
0005434943355	879	2	2A
0005434943353	879	3	2C
0005433255072	879	4	3D
0005433255095	879	5	5B
0005434943351	879	6	5C
0005434943348	879	7	7B
0005434943349	879	8	7C
0005433255094	879	9	18A
0005434943352	879	10	18B
0005433255096	879	11	19A
0005433255079	879	12	19B
0005434943347	879	13	19C
0005433255093	879	14	20D
0005434943346	879	15	22A
0005434943354	879	16	23A
0005433255118	16238	1	1A
0005434943288	16238	2	1D
0005434943251	16238	3	2A
0005434943261	16238	4	2B
0005433255116	16238	5	2C
0005434943282	16238	6	2D
0005434943281	16238	7	3A
0005434943244	16238	8	4B
0005433255117	16238	9	4C
0005434943243	16238	10	7B
0005433255119	16238	11	18B
0005434943272	16238	12	19D
0005434943268	16238	13	21A
0005434943245	16238	14	21C
0005433255121	16238	15	22A
0005433255120	16238	16	22C
0005435858548	27620	1	1A
0005435858558	27620	2	1D
0005433654690	27620	3	1C
0005435858557	27620	4	2A
0005433654671	27620	5	2D
0005433654672	27620	6	3D
0005433654668	27620	7	4D
0005433654734	27620	8	4C
0005433654687	27620	9	5A
0005433654707	27620	10	6B
0005433654655	27620	11	6A
0005433654717	27620	12	6C
0005433654735	27620	13	7B
0005435858556	27620	14	6F
0005433654718	27620	15	7E
0005435858560	27620	16	7F
0005435858550	27620	17	8B
0005433654732	27620	18	8A
0005433654681	27620	19	8C
0005433654689	27620	20	8F
0005433654684	27620	21	10A
0005433654656	27620	22	9F
0005435858547	27620	23	10C
0005433654698	27620	24	11C
0005433654691	27620	25	11A
0005435858546	27620	26	11F
0005433654694	27620	27	11E
0005435858552	27620	28	12B
0005433654708	27620	29	12C
0005433654701	27620	30	12E
0005433654692	27620	31	13C
0005433654667	27620	32	13B
0005433654688	27620	33	13E
0005433654686	27620	34	14A
0005433654702	27620	35	14B
0005433654706	27620	36	14D
0005435858553	27620	37	14F
0005435858562	27620	38	15C
0005435858555	27620	39	15E
0005433654719	27620	40	15D
0005433654733	27620	41	16A
0005435858551	27620	42	16D
0005433654709	27620	43	16F
0005433654697	27620	44	18B
0005433654657	27620	45	18A
0005435858561	27620	46	18F
0005435858554	27620	47	19A
0005435858545	27620	48	19E
0005433654693	27620	49	20B
0005435858559	27620	50	20A
0005435858549	27620	51	21D
0005433811617	14422	1	4B
0005435653029	21738	1	1A
0005433367402	21738	2	1C
0005433367545	21738	3	1D
0005435652993	21738	4	1F
0005435653018	21738	5	2A
0005433367508	21738	6	2C
0005435653010	21738	7	2D
0005433367489	21738	8	2F
0005435653012	21738	9	3A
0005433367639	21738	10	3C
0005433367455	21738	11	3D
0005435653019	21738	12	4A
0005433367596	21738	13	4C
0005435653003	21738	14	4D
0005435653021	21738	15	4E
0005435653002	21738	16	4F
0005435653031	21738	17	5A
0005435653035	21738	18	5C
0005435653013	21738	19	5D
0005435653015	21738	20	5E
0005435653032	21738	21	5F
0005433367491	21738	22	6A
0005435653011	21738	23	6C
0005433367494	21738	24	6D
0005435653023	21738	25	6E
0005433367533	21738	26	6F
0005433367662	21738	27	7A
0005435653017	21738	28	7C
0005433367481	21738	29	7D
0005433367395	21738	30	7E
0005435653016	21738	31	7F
0005435653008	21738	32	8A
0005435653026	21738	33	8C
0005433367522	21738	34	8D
0005435652994	21738	35	8E
0005433367548	21738	36	8F
0005435653000	21738	37	9A
0005433367562	21738	38	9C
0005433367363	21738	39	9E
0005435652992	21738	40	9F
0005433367597	21738	41	10A
0005435653007	21738	42	10C
0005433367509	21738	43	10D
0005435653039	21738	44	10E
0005433367480	21738	45	10F
0005433367459	21738	46	11A
0005435653005	21738	47	11C
0005435652999	21738	48	11D
0005435653022	21738	49	11E
0005435653027	21738	50	11F
0005435653030	21738	51	12C
0005433367492	21738	52	12D
0005433367364	21738	53	12E
0005435653038	21738	54	12F
0005435653037	21738	55	13A
0005433367412	21738	56	13D
0005433367663	21738	57	13E
0005433367520	21738	58	13F
0005435653009	21738	59	14A
0005435653014	21738	60	14C
0005433367542	21738	61	14D
0005433367427	21738	62	14E
0005433367493	21738	63	14F
0005435653034	21738	64	15A
0005433367521	21738	65	15D
0005435653036	21738	66	15E
0005433367561	21738	67	15F
0005435653028	21738	68	16A
0005435653004	21738	69	16C
0005433367573	21738	70	16E
0005435652995	21738	71	16F
0005433367544	21738	72	17A
0005433367458	21738	73	17C
0005433367546	21738	74	17F
0005433367598	21738	75	18A
0005435652996	21738	76	18C
0005435653001	21738	77	18D
0005435652997	21738	78	18E
0005433367547	21738	79	18F
0005435653040	21738	80	19A
0005435653006	21738	81	19C
0005435653020	21738	82	19D
0005435653033	21738	83	19E
0005433367532	21738	84	19F
0005433367490	21738	85	20A
0005435652998	21738	86	20C
0005435653024	21738	87	20D
0005433367386	21738	88	20E
0005435653025	21738	89	20F
0005433784924	9354	1	1A
0005433805372	9354	2	1F
0005433784939	9354	3	1C
0005433763207	9354	4	2A
0005433805365	9354	5	2B
0005433784929	9354	6	2F
0005433784949	9354	7	2G
0005432667454	9354	8	2H
0005433784934	9354	9	3B
0005433763211	9354	10	3F
0005433805394	9354	11	3H
0005433805393	9354	12	4C
0005432657449	9354	13	4G
0005433805369	9354	14	4F
0005433784954	9354	15	4H
0005433784926	9354	16	5B
0005433805371	9354	17	5A
0005434170982	9354	18	5G
0005433784932	9354	19	5F
0005433805370	9354	20	5H
0005432666390	9354	21	9H
0005433805382	9354	22	11D
0005433805375	9354	23	11B
0005433763212	9354	24	11E
0005432666389	9354	25	11F
0005433805389	9354	26	11H
0005432665274	9354	27	12A
0005432657448	9354	28	12D
0005433784957	9354	29	12F
0005432666388	9354	30	12H
0005433763206	9354	31	13F
0005433763199	9354	32	13E
0005433763203	9354	33	13G
0005433784948	9354	34	13H
0005434170948	9354	35	14B
0005433784950	9354	36	14D
0005433805361	9354	37	14E
0005433805398	9354	38	14H
0005434170899	9354	39	14G
0005433805384	9354	40	15D
0005433805388	9354	41	15G
0005433784942	9354	42	15F
0005433784927	9354	43	16D
0005433805359	9354	44	16B
0005433784951	9354	45	16G
0005433784940	9354	46	17A
0005433805376	9354	47	17B
0005434170964	9354	48	17F
0005433805378	9354	49	18A
0005433805379	9354	50	17G
0005433805386	9354	51	18B
0005434170917	9354	52	18E
0005433805357	9354	53	18G
0005433805387	9354	54	19B
0005434170960	9354	55	19A
0005433784958	9354	56	19D
0005433805374	9354	57	19G
0005433805358	9354	58	19F
0005433784928	9354	59	19H
0005433784931	9354	60	20A
0005433763205	9354	61	20D
0005433805364	9354	62	20B
0005433805360	9354	63	20F
0005433805380	9354	64	21A
0005433805392	9354	65	20H
0005433805399	9354	66	21D
0005433763200	9354	67	21G
0005433784936	9354	68	22D
0005433805366	9354	69	23A
0005433805395	9354	70	22G
0005434170981	9354	71	23B
0005433763201	9354	72	23D
0005433784933	9354	73	24E
0005433784937	9354	74	25D
0005433805391	9354	75	24H
0005433784945	9354	76	25F
0005434170965	9354	77	27A
0005433784953	9354	78	27D
0005433805383	9354	79	27G
0005434170966	9354	80	27F
0005433805397	9354	81	27E
0005432665273	9354	82	27H
0005433784930	9354	83	28A
0005433784947	9354	84	28B
0005433805368	9354	85	28E
0005433805367	9354	86	29D
0005433784925	9354	87	29H
0005433805381	9354	88	30G
0005433805390	9354	89	30H
0005433784944	9354	90	31B
0005433784935	9354	91	31F
0005433763208	9354	92	31E
0005433763204	9354	93	31H
0005433805363	9354	94	32D
0005433763202	9354	95	32B
0005433784952	9354	96	32F
0005432665275	9354	97	33A
0005434270189	9354	98	33B
0005433805362	9354	99	33F
0005432667455	9354	100	34D
0005433763209	9354	101	34G
0005433784946	9354	102	34H
0005433805396	9354	103	35B
0005433805373	9354	104	35A
0005433784955	9354	105	35D
0005432667453	9354	106	35E
0005433784938	9354	107	35G
0005434170961	9354	108	35F
0005433763210	9354	109	37A
0005433784943	9354	110	37D
0005432657447	9354	111	37F
0005433784959	9354	112	37G
0005433805377	9354	113	38A
0005433805385	9354	114	38B
0005434170857	9354	115	38G
0005433784956	9354	116	39D
0005433784941	9354	117	39E
0005434171061	26246	1	1A
0005433784716	26246	2	1C
0005432666370	26246	3	1G
0005433784752	26246	4	2A
0005433763091	26246	5	2B
0005433805014	26246	6	2C
0005433784711	26246	7	2G
0005432663013	26246	8	2F
0005434151704	26246	9	3B
0005434271310	26246	10	3C
0005434171058	26246	11	3G
0005433805123	26246	12	4A
0005433784674	26246	13	3H
0005433784457	26246	14	4B
0005433784544	26246	15	5A
0005433763090	26246	16	5B
0005434171048	26246	17	5C
0005433763083	26246	18	9A
0005434270204	26246	19	9G
0005433805000	26246	20	11A
0005433804962	26246	21	11D
0005433784714	26246	22	12A
0005433763121	26246	23	11H
0005434171051	26246	24	12D
0005434171059	26246	25	12H
0005433784726	26246	26	13F
0005434171047	26246	27	13H
0005434171052	26246	28	13G
0005433805215	26246	29	14B
0005434269101	26246	30	14F
0005433805063	26246	31	14E
0005434151705	26246	32	15A
0005433784575	26246	33	15B
0005433805006	26246	34	15F
0005434171053	26246	35	15G
0005433784604	26246	36	16D
0005433804974	26246	37	16B
0005433805031	26246	38	16G
0005434151702	26246	39	17A
0005433804928	26246	40	17F
0005433804866	26246	41	17H
0005433784545	26246	42	18B
0005433805030	26246	43	18A
0005433804852	26246	44	18G
0005433805147	26246	45	19A
0005433804996	26246	46	19D
0005434171062	26246	47	19F
0005433784547	26246	48	19H
0005433784546	26246	49	19G
0005433784492	26246	50	20A
0005434171046	26246	51	20E
0005433804909	26246	52	20G
0005434171056	26246	53	20H
0005433784578	26246	54	21E
0005433805043	26246	55	21F
0005433784647	26246	56	22A
0005433784598	26246	57	22D
0005433805044	26246	58	22F
0005434171049	26246	59	22H
0005433784574	26246	60	23B
0005433804914	26246	61	23E
0005433784681	26246	62	23D
0005434171057	26246	63	24A
0005433784541	26246	64	23H
0005433763111	26246	65	24D
0005432666371	26246	66	24E
0005433805214	26246	67	24G
0005433784648	26246	68	25D
0005435269748	26246	69	27B
0005433804867	26246	70	27E
0005433805120	26246	71	27D
0005433784515	26246	72	27H
0005434151703	26246	73	27G
0005433784617	26246	74	28D
0005434171060	26246	75	28F
0005433784683	26246	76	28H
0005433763014	26246	77	28G
0005433805152	26246	78	29D
0005433784727	26246	79	29F
0005434271309	26246	80	29H
0005433784632	26246	81	30A
0005433784715	26246	82	30D
0005434269100	26246	83	30G
0005433804943	26246	84	30F
0005433805042	26246	85	31A
0005434171054	26246	86	30H
0005433763100	26246	87	31D
0005433784663	26246	88	31F
0005433804910	26246	89	31E
0005433805145	26246	90	31G
0005433784618	26246	91	31H
0005433763113	26246	92	32B
0005433805138	26246	93	32E
0005433784701	26246	94	32G
0005433804931	26246	95	33B
0005432663014	26246	96	33F
0005433784684	26246	97	33H
0005434270205	26246	98	33G
0005433784633	26246	99	34B
0005433784625	26246	100	34G
0005433784476	26246	101	35A
0005433763082	26246	102	35F
0005433784673	26246	103	35E
0005433805146	26246	104	36A
0005433804975	26246	105	36D
0005433784537	26246	106	36F
0005433804963	26246	107	37B
0005433804992	26246	108	37D
0005433784710	26246	109	37F
0005433804797	26246	110	37H
0005433784475	26246	111	38E
0005434171055	26246	112	38F
0005433784694	26246	113	38G
0005434171050	26246	114	39D
0005434151706	26246	115	39E
0005435135670	4890	1	1A
0005435929619	4890	2	2A
0005435135667	4890	3	4B
0005435135668	4890	4	5B
0005435135671	4890	5	7B
0005435135672	4890	6	18A
0005435135669	4890	7	20A
0005435929621	4890	8	23A
0005435929644	33026	1	1A
0005435135626	33026	2	5C
0005435135621	33026	3	6D
0005435135628	33026	4	7A
0005435929642	33026	5	7B
0005435135629	33026	6	7C
0005435929643	33026	7	18C
0005435135620	33026	8	21C
0005434983287	9457	1	1B
0005434217952	9457	2	1C
0005434217935	9457	3	3A
0005434217928	9457	4	3D
0005434983284	9457	5	6C
0005434217922	9457	6	18A
0005434217926	9457	7	18C
0005434983288	9457	8	18D
0005434217921	9457	9	19B
0005434217912	9457	10	19D
0005434983286	9457	11	21B
0005434217934	9457	12	22A
0005434217929	9457	13	22D
0005434983285	9457	14	23B
0005434217968	27344	1	2A
0005434983238	27344	2	2B
0005434983251	27344	3	2C
0005434983232	27344	4	3A
0005434217969	27344	5	4C
0005434983252	27344	6	18A
0005434983231	27344	7	18B
0005434983235	27344	8	18C
0005434983255	27344	9	19A
0005434217971	27344	10	20A
0005434217967	27344	11	20B
0005434983236	27344	12	20C
0005434217966	27344	13	22A
0005434217970	27344	14	22B
0005433985387	24237	1	1F
0005433985384	24237	2	1H
0005433960333	24237	3	1G
0005433960094	24237	4	2A
0005433960317	24237	5	2C
0005433960189	24237	6	2F
0005433960350	24237	7	2G
0005433960257	24237	8	3A
0005433960270	24237	9	3B
0005433960339	24237	10	3F
0005433960325	24237	11	3G
0005433985484	24237	12	3H
0005433960156	24237	13	4G
0005433960377	24237	14	4H
0005433960253	24237	15	5B
0005433960190	24237	16	5A
0005433960291	24237	17	5F
0005433985416	24237	18	5H
0005433960368	24237	19	9G
0005433985498	24237	20	11A
0005433960251	24237	21	11B
0005433960078	24237	22	11E
0005433960110	24237	23	11F
0005433985357	24237	24	11G
0005433960229	24237	25	13B
0005433960004	24237	26	13G
0005433960296	24237	27	13F
0005433960103	24237	28	14A
0005433985425	24237	29	13H
0005433960268	24237	30	14B
0005433985457	24237	31	14E
0005433960369	24237	32	14H
0005433985327	24237	33	15B
0005433985362	24237	34	15D
0005433960328	24237	35	15H
0005433960182	24237	36	16B
0005433985356	24237	37	16A
0005433985427	24237	38	16F
0005433960109	24237	39	16G
0005433960300	24237	40	16H
0005433985193	24237	41	17A
0005433960329	24237	42	17E
0005433985328	24237	43	17G
0005433985391	24237	44	17H
0005433959996	24237	45	18B
0005433985478	24237	46	18D
0005433960276	24237	47	18F
0005433960374	24237	48	18E
0005433985429	24237	49	18G
0005433985448	24237	50	19A
0005433985390	24237	51	19B
0005433960197	24237	52	19D
0005433960336	24237	53	19E
0005433985488	24237	54	20A
0005433985371	24237	55	19H
0005433960293	24237	56	20F
0005433960254	24237	57	20H
0005433960125	24237	58	20G
0005433985310	24237	59	21B
0005433960376	24237	60	21E
0005433985468	24237	61	21F
0005433960171	24237	62	21G
0005433960378	24237	63	22A
0005433960287	24237	64	22D
0005433960318	24237	65	22F
0005433960288	24237	66	23A
0005433960342	24237	67	22H
0005433985447	24237	68	23B
0005433960148	24237	69	23F
0005433960370	24237	70	23G
0005433960228	24237	71	24A
0005433960299	24237	72	23H
0005433960373	24237	73	24B
0005433960225	24237	74	25E
0005433960252	24237	75	27E
0005433960269	24237	76	27D
0005433960349	24237	77	27F
0005433960039	24237	78	28D
0005433960292	24237	79	28B
0005433960040	24237	80	28F
0005433985388	24237	81	28G
0005433985455	24237	82	29G
0005433985487	24237	83	30E
0005433985489	24237	84	30G
0005433985485	24237	85	31B
0005433960271	24237	86	31E
0005433960157	24237	87	31D
0005433960155	24237	88	32A
0005433960309	24237	89	32F
0005433985385	24237	90	32E
0005433960314	24237	91	32H
0005433985428	24237	92	33B
0005433985486	24237	93	33D
0005433960315	24237	94	33H
0005433985386	24237	95	34G
0005433960353	24237	96	35A
0005433960308	24237	97	35D
0005433960319	24237	98	35B
0005433960367	24237	99	36B
0005433985456	24237	100	36E
0005433985192	24237	101	36H
0005433960079	24237	102	37E
0005433960283	24237	103	37F
0005433959975	24237	104	38B
0005433985469	24237	105	38E
0005433985353	24237	106	38G
0005433960357	24237	107	38F
0005433985444	24237	108	39D
0005433959915	24237	109	39E
0005433960803	25964	1	1G
0005433960800	25964	2	1H
0005433960798	25964	3	2C
0005433985880	25964	4	2B
0005433985913	25964	5	2H
0005433985882	25964	6	3C
0005433985917	25964	7	3G
0005433960810	25964	8	4A
0005433985898	25964	9	4F
0005433985903	25964	10	4H
0005433985896	25964	11	5A
0005433960801	25964	12	5F
0005433985878	25964	13	5G
0005433985888	25964	14	5H
0005433960806	25964	15	9B
0005433985925	25964	16	9A
0005433960828	25964	17	9H
0005433985884	25964	18	11D
0005433985918	25964	19	11H
0005433985906	25964	20	12B
0005433985921	25964	21	12E
0005433960802	25964	22	12D
0005433960825	25964	23	12H
0005433960822	25964	24	13A
0005433985893	25964	25	13F
0005433960844	25964	26	14A
0005433960799	25964	27	13H
0005433985916	25964	28	14B
0005433985895	25964	29	14H
0005433960836	25964	30	15A
0005433985890	25964	31	15B
0005433960832	25964	32	15E
0005433960807	25964	33	15G
0005433985914	25964	34	15H
0005433960794	25964	35	16A
0005433960846	25964	36	16B
0005433985923	25964	37	16E
0005433960805	25964	38	16D
0005433960797	25964	39	16G
0005433960847	25964	40	17B
0005433985924	25964	41	17F
0005433960833	25964	42	17H
0005433960795	25964	43	17G
0005433960813	25964	44	18B
0005433985883	25964	45	18G
0005433960819	25964	46	18H
0005433985908	25964	47	19D
0005433985905	25964	48	19B
0005433960829	25964	49	19E
0005433960793	25964	50	19G
0005433985891	25964	51	20E
0005433960796	25964	52	20D
0005433985910	25964	53	20G
0005433960845	25964	54	21A
0005433985899	25964	55	22B
0005433960817	25964	56	22A
0005433985879	25964	57	22D
0005433985901	25964	58	22E
0005433960823	25964	59	22G
0005433985920	25964	60	22F
0005433960840	25964	61	22H
0005433960843	25964	62	23B
0005433960821	25964	63	23A
0005433960834	25964	64	23D
0005433985915	25964	65	23F
0005433960831	25964	66	23G
0005433985900	25964	67	24B
0005433960824	25964	68	24A
0005433960837	25964	69	24H
0005433985912	25964	70	24G
0005433985892	25964	71	25F
0005433960848	25964	72	27E
0005433985889	25964	73	28A
0005433985885	25964	74	28B
0005433960827	25964	75	28F
0005433960815	25964	76	28G
0005433960849	25964	77	29A
0005433985897	25964	78	30G
0005433960812	25964	79	31B
0005433960808	25964	80	32B
0005433960841	25964	81	32E
0005433960816	25964	82	32D
0005433985909	25964	83	32G
0005433985926	25964	84	32F
0005433960826	25964	85	32H
0005433960842	25964	86	33B
0005433985902	25964	87	33E
0005433960835	25964	88	33G
0005433960830	25964	89	33F
0005433985887	25964	90	34F
0005433985907	25964	91	34H
0005433960809	25964	92	35A
0005433960804	25964	93	35F
0005433960818	25964	94	35E
0005433985904	25964	95	36B
0005433960820	25964	96	36A
0005433985881	25964	97	36D
0005433985919	25964	98	36F
0005433985886	25964	99	36G
0005433985911	25964	100	37E
0005433985894	25964	101	37G
0005433960850	25964	102	37F
0005433960814	25964	103	38A
0005433960839	25964	104	38B
0005433960811	25964	105	38G
0005433985922	25964	106	38F
0005433960838	25964	107	38H
0005434480327	945	1	1A
0005434480316	945	2	1B
0005434480326	945	3	1C
0005433165824	945	4	1D
0005434480338	945	5	2A
0005432269495	945	6	2B
0005434480321	945	7	2C
0005434480330	945	8	2D
0005434480339	945	9	3A
0005434480319	945	10	3B
0005433165828	945	11	3C
0005433165856	945	12	3D
0005433165855	945	13	4A
0005434480328	945	14	4C
0005434480334	945	15	5B
0005434480337	945	16	5C
0005434480320	945	17	5D
0005434480323	945	18	6A
0005434480333	945	19	6B
0005434480336	945	20	6C
0005432269497	945	21	6D
0005433165816	945	22	7A
0005432269498	945	23	7B
0005433165843	945	24	7C
0005434480332	945	25	7D
0005434480329	945	26	18A
0005434480325	945	27	18B
0005433165777	945	28	18C
0005433165852	945	29	18D
0005434480318	945	30	19A
0005434480331	945	31	19B
0005434480322	945	32	19C
0005433165796	945	33	20A
0005433165818	945	34	20B
0005434480335	945	35	20C
0005433165819	945	36	20D
0005434480317	945	37	21A
0005434480340	945	38	21B
0005432269496	945	39	21C
0005433165827	945	40	22A
0005434480324	945	41	22B
0005433165797	945	42	22C
0005433165820	945	43	22D
0005433165817	945	44	23A
0005433165842	945	45	23B
0005434480159	16563	1	1A
0005433165900	16563	2	1B
0005434480131	16563	3	1C
0005433165906	16563	4	1D
0005434480194	16563	5	2B
0005433165896	16563	6	2D
0005434480282	16563	7	3A
0005434480054	16563	8	3B
0005434480283	16563	9	3D
0005433165904	16563	10	4A
0005434480132	16563	11	4B
0005434480116	16563	12	4C
0005434480099	16563	13	5A
0005434480111	16563	14	5B
0005433165897	16563	15	5C
0005434480155	16563	16	5D
0005433165899	16563	17	6A
0005434480060	16563	18	6B
0005434480158	16563	19	6C
0005434480081	16563	20	7C
0005434480061	16563	21	7B
0005434480038	16563	22	7D
0005434480115	16563	23	18A
0005433165903	16563	24	18B
0005434480079	16563	25	18C
0005433165907	16563	26	18D
0005434480129	16563	27	19A
0005434480130	16563	28	19B
0005434480205	16563	29	19C
0005434480217	16563	30	19D
0005434480098	16563	31	20A
0005433165902	16563	32	20B
0005434480200	16563	33	20C
0005434480080	16563	34	21A
0005434480204	16563	35	21C
0005434480218	16563	36	21D
0005433165901	16563	37	22A
0005434480114	16563	38	22B
0005434480203	16563	39	22C
0005433165905	16563	40	22D
0005433165908	16563	41	23A
0005433165898	16563	42	23B
0005435150018	10316	1	1A
0005435142566	10316	2	1C
0005435150019	10316	3	1B
0005435150021	10316	4	1D
0005435142558	10316	5	2A
0005435142569	10316	6	2C
0005435386490	10316	7	3B
0005435150020	10316	8	3D
0005435150015	10316	9	4A
0005435386529	10316	10	4C
0005435142560	10316	11	5A
0005435386523	10316	12	5B
0005435142562	10316	13	5C
0005435142570	10316	14	5D
0005435386524	10316	15	6B
0005435386498	10316	16	7A
0005435150010	10316	17	7B
0005435150012	10316	18	7C
0005435150017	10316	19	7D
0005435150009	10316	20	18B
0005435386504	10316	21	18D
0005435142557	10316	22	19A
0005435142568	10316	23	19C
0005435142561	10316	24	19D
0005435150013	10316	25	20A
0005435150008	10316	26	20C
0005435150016	10316	27	20D
0005435142564	10316	28	21C
0005435142567	10316	29	21D
0005435142563	10316	30	22A
0005435150011	10316	31	22B
0005435386491	10316	32	22C
0005435142559	10316	33	22D
0005435150014	10316	34	23A
0005435142565	10316	35	23B
0005435149895	21914	1	1A
0005435142500	21914	2	1B
0005435142459	21914	3	1C
0005435142490	21914	4	1D
0005435149857	21914	5	2A
0005435142411	21914	6	2B
0005435142475	21914	7	2C
0005435142410	21914	8	2D
0005433289852	21914	9	3A
0005435142496	21914	10	3B
0005435142435	21914	11	3C
0005435142452	21914	12	3D
0005435149904	21914	13	4A
0005435142453	21914	14	4B
0005435142447	21914	15	4C
0005435142442	21914	16	4D
0005435149899	21914	17	5A
0005435142409	21914	18	5B
0005435142415	21914	19	5C
0005435149799	21914	20	5D
0005435142444	21914	21	6A
0005435142474	21914	22	6B
0005435149923	21914	23	6C
0005435149905	21914	24	6D
0005433289858	21914	25	7A
0005435149922	21914	26	7B
0005433289851	21914	27	7C
0005435142489	21914	28	7D
0005435142477	21914	29	18A
0005435142491	21914	30	18B
0005435149908	21914	31	18C
0005433289855	21914	32	18D
0005435142457	21914	33	19A
0005435149907	21914	34	19B
0005435149917	21914	35	19C
0005433289853	21914	36	19D
0005435149891	21914	37	20A
0005435142476	21914	38	20B
0005435142441	21914	39	20C
0005433289857	21914	40	20D
0005435142458	21914	41	21A
0005433289854	21914	42	21B
0005435149843	21914	43	21C
0005435149898	21914	44	21D
0005435149903	21914	45	22A
0005435142414	21914	46	22B
0005435149856	21914	47	22C
0005435149798	21914	48	22D
0005433289856	21914	49	23A
0005433289850	21914	50	23B
0005435529046	11180	1	1A
0005434573337	11180	2	1C
0005435319494	11180	3	1D
0005435545663	11180	4	1F
0005435529144	11180	5	2A
0005435545664	11180	6	2C
0005435529092	11180	7	2D
0005435545689	11180	8	3A
0005435529104	11180	9	3C
0005435502231	11180	10	3D
0005435502163	11180	11	3F
0005435502115	11180	12	4C
0005435529131	11180	13	4D
0005435529034	11180	14	4E
0005435529042	11180	15	4F
0005434573335	11180	16	5A
0005435319503	11180	17	5C
0005435529052	11180	18	5D
0005435502162	11180	19	5E
0005435502205	11180	20	5F
0005434573339	11180	21	6C
0005434573340	11180	22	6D
0005435529100	11180	23	6E
0005435529009	11180	24	6F
0005435529047	11180	25	7C
0005435502069	11180	26	7D
0005435529060	11180	27	7E
0005435319496	11180	28	7F
0005435545687	11180	29	8C
0005434573345	11180	30	8D
0005434573344	11180	31	8E
0005434573336	11180	32	8F
0005434573342	11180	33	9A
0005435545653	11180	34	9C
0005435529132	11180	35	9D
0005435545688	11180	36	9E
0005435545665	11180	37	10A
0005435319485	11180	38	10C
0005435502232	11180	39	10D
0005435502092	11180	40	10E
0005435319514	11180	41	10F
0005434573341	11180	42	11C
0005434573346	11180	43	11D
0005435502112	11180	44	12A
0005435529031	11180	45	12C
0005435502144	11180	46	12F
0005435545645	11180	47	13A
0005435529103	11180	48	13C
0005435502190	11180	49	13D
0005435529071	11180	50	13E
0005435545654	11180	51	14A
0005435502124	11180	52	14C
0005435545686	11180	53	14D
0005435529070	11180	54	14E
0005434573333	11180	55	14F
0005435529029	11180	56	15A
0005434573332	11180	57	15D
0005435502106	11180	58	15E
0005434573343	11180	59	15F
0005435545666	11180	60	16A
0005435502113	11180	61	16C
0005435545670	11180	62	16F
0005435529105	11180	63	17A
0005435319486	11180	64	17C
0005435545690	11180	65	17D
0005434573338	11180	66	17E
0005435528970	11180	67	17F
0005435502068	11180	68	18A
0005435529135	11180	69	18D
0005434573334	11180	70	18E
0005435502134	11180	71	19A
0005435545652	11180	72	19C
0005435319489	11180	73	19D
0005435529035	11180	74	19E
0005435319495	11180	75	20A
0005435529036	11180	76	19F
0005435529055	11180	77	20C
0005435502148	11180	78	20E
0005435502191	11180	79	20F
0005435517897	20941	1	1A
0005435508364	20941	2	1C
0005435319585	20941	3	1D
0005434573267	20941	4	1F
0005435502304	20941	5	2A
0005435319583	20941	6	2C
0005435508356	20941	7	2D
0005434573221	20941	8	3A
0005435517906	20941	9	3C
0005435517902	20941	10	3D
0005435319584	20941	11	3F
0005435319578	20941	12	4A
0005435319580	20941	13	4D
0005435502298	20941	14	4E
0005435502301	20941	15	4F
0005435502307	20941	16	5A
0005435517913	20941	17	5C
0005435502288	20941	18	5D
0005435508358	20941	19	5E
0005435502302	20941	20	5F
0005434573194	20941	21	6C
0005435502293	20941	22	6D
0005435502286	20941	23	6E
0005435517909	20941	24	6F
0005435517911	20941	25	7C
0005435508365	20941	26	7D
0005435517901	20941	27	7E
0005435508360	20941	28	7F
0005435319579	20941	29	8A
0005435508354	20941	30	8D
0005434573232	20941	31	8E
0005435502290	20941	32	8F
0005435508362	20941	33	9A
0005434573219	20941	34	9C
0005435319581	20941	35	9D
0005435508355	20941	36	9E
0005434573237	20941	37	10A
0005434573238	20941	38	10D
0005435502303	20941	39	10E
0005435502296	20941	40	10F
0005435508353	20941	41	11A
0005435517898	20941	42	11C
0005435517912	20941	43	11D
0005435502299	20941	44	11E
0005432291928	20941	45	12A
0005435502300	20941	46	11F
0005435508363	20941	47	12C
0005435502306	20941	48	12D
0005435502297	20941	49	12F
0005435517905	20941	50	13A
0005435502289	20941	51	13D
0005435517908	20941	52	13E
0005435502305	20941	53	14A
0005435508361	20941	54	14C
0005434573203	20941	55	14D
0005435517917	20941	56	14E
0005435517904	20941	57	14F
0005434573269	20941	58	15A
0005435517896	20941	59	15C
0005434573112	20941	60	15E
0005432291929	20941	61	15F
0005435517899	20941	62	16A
0005435508352	20941	63	16C
0005435319577	20941	64	16D
0005435502287	20941	65	16E
0005435508366	20941	66	16F
0005435508357	20941	67	17C
0005435502291	20941	68	17D
0005435517910	20941	69	17E
0005434573196	20941	70	17F
0005435517914	20941	71	18A
0005435517903	20941	72	18C
0005435517900	20941	73	18D
0005434573218	20941	74	18E
0005434573195	20941	75	19A
0005435502295	20941	76	19C
0005435502292	20941	77	19D
0005435517916	20941	78	19E
0005435319582	20941	79	19F
0005435517907	20941	80	20A
0005434573239	20941	81	20C
0005435517915	20941	82	20D
0005435502294	20941	83	20E
0005435508359	20941	84	20F
0005433927421	24309	1	1C
0005433927413	24309	2	2A
0005433683337	24309	3	4A
0005433927415	24309	4	4D
0005433927411	24309	5	5B
0005433683333	24309	6	5C
0005433927414	24309	7	5D
0005433683334	24309	8	6A
0005433927418	24309	9	6B
0005433927419	24309	10	6D
0005433683338	24309	11	7B
0005433927401	24309	12	7C
0005433927409	24309	13	18A
0005433683339	24309	14	18B
0005433683336	24309	15	18C
0005433683340	24309	16	18D
0005433683335	24309	17	19D
0005433927408	24309	18	20B
0005433683332	24309	19	21A
0005433927412	24309	20	23B
0005433927441	29275	1	1B
0005433927439	29275	2	2A
0005433683307	29275	3	3A
0005433927437	29275	4	3C
0005433927442	29275	5	4A
0005433683304	29275	6	5A
0005433927435	29275	7	5B
0005433927443	29275	8	6A
0005433683331	29275	9	7A
0005433683303	29275	10	18C
0005433683301	29275	11	19A
0005433927438	29275	12	19D
0005433927436	29275	13	20A
0005433683313	29275	14	20B
0005433683319	29275	15	21C
0005433683330	29275	16	22A
0005433927440	29275	17	22B
0005432692717	3036	1	1A
0005432692876	3036	2	1F
0005432692795	3036	3	2C
0005432692748	3036	4	2F
0005432692905	3036	5	4F
0005432692642	3036	6	6E
0005432692749	3036	7	8E
0005432692824	3036	8	9C
0005432692656	3036	9	9E
0005432692780	3036	10	9F
0005432692872	3036	11	10E
0005432692669	3036	12	10F
0005432692691	3036	13	11E
0005432692815	3036	14	12C
0005432692875	3036	15	13A
0005432692742	3036	16	14F
0005432692811	3036	17	15C
0005432692833	3036	18	16C
0005432692702	3036	19	17A
0005432692807	3036	20	17C
0005432692692	3036	21	17D
0005432692835	3036	22	17E
0005432692858	3036	23	17F
0005432692816	3036	24	18A
0005432692763	3036	25	18F
0005432692834	3036	26	19A
0005432692920	3036	27	19F
0005432217776	3037	1	1A
0005432706763	3037	2	1C
0005433123793	3037	3	1D
0005432706756	3037	4	1F
0005433123699	3037	5	2C
0005432706775	3037	6	2D
0005433123723	3037	7	2F
0005432880695	3037	8	3F
0005433123771	3037	9	4A
0005432706768	3037	10	4C
0005432706755	3037	11	4D
0005432706766	3037	12	4E
0005432880671	3037	13	5A
0005433123758	3037	14	5C
0005433123718	3037	15	5E
0005432706764	3037	16	5F
0005432706753	3037	17	6C
0005432706776	3037	18	6E
0005432880736	3037	19	6F
0005432880658	3037	20	7A
0005433123784	3037	21	7D
0005432880635	3037	22	7F
0005432706767	3037	23	8A
0005433123748	3037	24	8C
0005433123783	3037	25	8F
0005432706759	3037	26	9A
0005432706754	3037	27	9C
0005433123703	3037	28	9E
0005432706758	3037	29	9F
0005432880688	3037	30	10C
0005432880657	3037	31	10D
0005432706762	3037	32	10E
0005433123800	3037	33	11A
0005432706771	3037	34	11D
0005432880737	3037	35	11E
0005433123715	3037	36	11F
0005432706770	3037	37	12A
0005432706778	3037	38	12C
0005433123765	3037	39	12D
0005433123741	3037	40	13D
0005432706761	3037	41	13E
0005432706760	3037	42	13F
0005433123704	3037	43	14C
0005432706777	3037	44	14D
0005432706765	3037	45	14E
0005432706757	3037	46	15A
0005432706769	3037	47	15C
0005432706773	3037	48	15F
0005433194850	3037	49	16A
0005433123710	3037	50	16C
0005433123749	3037	51	16D
0005433123734	3037	52	16E
0005432880633	3037	53	17D
0005432880690	3037	54	17E
0005433194848	3037	55	17F
0005433194831	3037	56	18A
0005432217775	3037	57	18C
0005432880659	3037	58	18D
0005433123757	3037	59	18E
0005432880645	3037	60	18F
0005432880719	3037	61	19C
0005433123775	3037	62	19D
0005433123747	3037	63	19E
0005433123796	3037	64	19F
0005432880698	3037	65	20C
0005432706772	3037	66	20D
0005433194849	3037	67	20E
0005432706774	3037	68	20F
0005432880819	29968	1	1A
0005432706601	29968	2	1C
0005432693080	29968	3	1D
0005433123914	29968	4	1F
0005432706522	29968	5	2A
0005432880818	29968	6	2C
0005432693069	29968	7	2D
0005433123926	29968	8	2F
0005432693074	29968	9	3A
0005432693081	29968	10	3C
0005432706684	29968	11	3D
0005432693091	29968	12	3F
0005432706579	29968	13	4A
0005433123923	29968	14	4C
0005432693095	29968	15	4D
0005432693094	29968	16	4E
0005432706463	29968	17	4F
0005433123911	29968	18	5A
0005432706505	29968	19	5C
0005432693071	29968	20	5D
0005432706572	29968	21	5E
0005433123912	29968	22	5F
0005432693065	29968	23	6A
0005432693085	29968	24	6C
0005432693077	29968	25	6D
0005432693072	29968	26	6F
0005432693078	29968	27	6E
0005433123922	29968	28	7A
0005432706526	29968	29	7C
0005432693066	29968	30	7D
0005433123917	29968	31	7E
0005432706552	29968	32	7F
0005432693084	29968	33	8A
0005432693083	29968	34	8C
0005432880806	29968	35	8D
0005432706569	29968	36	8E
0005432693073	29968	37	8F
0005432693092	29968	38	9A
0005432693086	29968	39	9C
0005433123915	29968	40	9D
0005433123918	29968	41	9E
0005432706627	29968	42	9F
0005432706611	29968	43	10A
0005432706525	29968	44	10C
0005432693067	29968	45	10D
0005433123929	29968	46	10E
0005433123921	29968	47	10F
0005432693075	29968	48	11A
0005432706573	29968	49	11C
0005432880813	29968	50	11D
0005432706688	29968	51	11E
0005432880808	29968	52	11F
0005432880817	29968	53	12A
0005433123924	29968	54	12C
0005432880811	29968	55	12D
0005432693064	29968	56	12E
0005432880810	29968	57	12F
0005432706628	29968	58	13A
0005432693079	29968	59	13C
0005432880820	29968	60	13D
0005432693088	29968	61	13E
0005432706553	29968	62	13F
0005432693076	29968	63	14A
0005432706595	29968	64	14C
0005433123925	29968	65	14D
0005433123930	29968	66	14E
0005432706612	29968	67	14F
0005433123919	29968	68	15A
0005432693068	29968	69	15C
0005432706520	29968	70	15D
0005432706604	29968	71	15E
0005432693093	29968	72	15F
0005432706464	29968	73	16A
0005432706547	29968	74	16C
0005432706549	29968	75	16D
0005432693089	29968	76	16E
0005432880816	29968	77	16F
0005432706571	29968	78	17A
0005433123920	29968	79	17C
0005432706600	29968	80	17D
0005432706564	29968	81	17E
0005432880814	29968	82	17F
0005432880809	29968	83	18A
0005432693087	29968	84	18C
0005432693090	29968	85	18D
0005432880815	29968	86	18E
0005433123916	29968	87	18F
0005432706629	29968	88	19A
0005433123928	29968	89	19C
0005433123927	29968	90	19D
0005432880807	29968	91	19E
0005432693070	29968	92	19F
0005432880812	29968	93	20A
0005432706602	29968	94	20C
0005433123913	29968	95	20D
0005432706565	29968	96	20E
0005432693082	29968	97	20F
0005434979751	23660	1	1A
0005434979773	23660	2	1B
0005434988727	23660	3	1C
0005434988730	23660	4	1D
0005434979766	23660	5	2A
0005434979771	23660	6	2B
0005434988729	23660	7	2C
0005434988728	23660	8	2D
0005434979755	23660	9	3A
0005434979750	23660	10	3B
0005434979744	23660	11	3C
0005434988739	23660	12	3D
0005434979762	23660	13	4A
0005434988724	23660	14	4B
0005434979765	23660	15	4D
0005434988725	23660	16	5A
0005434988737	23660	17	5B
0005434988733	23660	18	5C
0005434979764	23660	19	5D
0005434988723	23660	20	6A
0005434979746	23660	21	6B
0005434988735	23660	22	6C
0005434979768	23660	23	6D
0005434979748	23660	24	7A
0005434979753	23660	25	7B
0005434979756	23660	26	7C
0005434979760	23660	27	7D
0005434979763	23660	28	18A
0005434979759	23660	29	18B
0005434988722	23660	30	18C
0005434979745	23660	31	18D
0005434979761	23660	32	19A
0005434988738	23660	33	19C
0005434988731	23660	34	19B
0005434988736	23660	35	19D
0005434979749	23660	36	20A
0005434979747	23660	37	20B
0005434988734	23660	38	20C
0005434988732	23660	39	20D
0005434979772	23660	40	21A
0005434979769	23660	41	21B
0005434979767	23660	42	21C
0005434979757	23660	43	21D
0005434979754	23660	44	22A
0005434979752	23660	45	22B
0005434979770	23660	46	22C
0005434979774	23660	47	22D
0005434979758	23660	48	23A
0005434988726	23660	49	23B
0005434979459	27569	1	1A
0005434979499	27569	2	1B
0005434979489	27569	3	1D
0005434979544	27569	4	2A
0005434979635	27569	5	2B
0005434979508	27569	6	2C
0005434979428	27569	7	2D
0005434979439	27569	8	3A
0005434979478	27569	9	3B
0005434979596	27569	10	3C
0005434979455	27569	11	3D
0005434979450	27569	12	4A
0005434979494	27569	13	4B
0005434979527	27569	14	4C
0005434979448	27569	15	4D
0005434979530	27569	16	5A
0005434979565	27569	17	5B
0005434979419	27569	18	5C
0005434979481	27569	19	5D
0005434988617	27569	20	6A
0005434988618	27569	21	6B
0005434988615	27569	22	6C
0005434979493	27569	23	6D
0005434979490	27569	24	7A
0005434979528	27569	25	7B
0005434979420	27569	26	7C
0005434979522	27569	27	7D
0005434979443	27569	28	18A
0005434979452	27569	29	18B
0005434979514	27569	30	18C
0005434979523	27569	31	18D
0005434979634	27569	32	19A
0005434979496	27569	33	19B
0005434979526	27569	34	19C
0005434979466	27569	35	20A
0005434979456	27569	36	20B
0005434979451	27569	37	20C
0005434979454	27569	38	20D
0005434979543	27569	39	21A
0005434988616	27569	40	21B
0005434979480	27569	41	21D
0005434979488	27569	42	22A
0005434979449	27569	43	22B
0005434979479	27569	44	22C
0005434979531	27569	45	22D
0005434979427	27569	46	23A
0005434979495	27569	47	23B
0005434302872	10268	1	2D
0005433111480	10268	2	3C
0005434302457	10268	3	3D
0005433111475	10268	4	4B
0005433113510	10268	5	5B
0005434302454	10268	6	6D
0005434302871	10268	7	7A
0005434302455	10268	8	18C
0005433111479	10268	9	18D
0005434302870	10268	10	20B
0005434302869	10268	11	20C
0005433111474	10268	12	21A
0005434302453	10268	13	21D
0005434302456	10268	14	22D
0005433113535	19586	1	3D
0005433113536	19586	2	4B
0005434302420	19586	3	5C
0005434302425	19586	4	7C
0005434302395	19586	5	7D
0005434302409	19586	6	19C
0005434302415	19586	7	20B
0005434302413	19586	8	21A
0005434302414	19586	9	22A
0005434302412	19586	10	22D
0005434302404	19586	11	23A
0005434302426	19586	12	23B
0005435069064	3531	1	1A
0005435925128	3531	2	1C
0005435925185	3531	3	1D
0005435069103	3531	4	1F
0005435925160	3531	5	2A
0005435069088	3531	6	2D
0005435925132	3531	7	2F
0005435925138	3531	8	3C
0005435069087	3531	9	3D
0005435069060	3531	10	3F
0005435069108	3531	11	4A
0005435925137	3531	12	4C
0005435925135	3531	13	4D
0005435718942	3531	14	4E
0005435069074	3531	15	4F
0005435925190	3531	16	5A
0005435069061	3531	17	5C
0005435925187	3531	18	5D
0005435069093	3531	19	5F
0005435069109	3531	20	6A
0005435069083	3531	21	6D
0005435925171	3531	22	6E
0005435925167	3531	23	6F
0005435718943	3531	24	7A
0005435069096	3531	25	7C
0005435069076	3531	26	7D
0005435069092	3531	27	7E
0005435069084	3531	28	7F
0005435069079	3531	29	8D
0005435925191	3531	30	8E
0005435069080	3531	31	8F
0005435718945	3531	32	9A
0005435069098	3531	33	9C
0005435718941	3531	34	9D
0005435069063	3531	35	9E
0005435069068	3531	36	9F
0005435925168	3531	37	10A
0005435069072	3531	38	10C
0005435069071	3531	39	10D
0005435069073	3531	40	10F
0005435069110	3531	41	11A
0005435069085	3531	42	11C
0005435069101	3531	43	11D
0005435069095	3531	44	11E
0005435069075	3531	45	12A
0005435069091	3531	46	12C
0005435069105	3531	47	12D
0005435069097	3531	48	12E
0005435069104	3531	49	12F
0005435718944	3531	50	13C
0005435069086	3531	51	13E
0005435069090	3531	52	13F
0005435925184	3531	53	14A
0005435069077	3531	54	14C
0005435718946	3531	55	14E
0005435069111	3531	56	14F
0005435925131	3531	57	15D
0005435069070	3531	58	15F
0005435925186	3531	59	16C
0005435925133	3531	60	16D
0005435069062	3531	61	16E
0005435718939	3531	62	16F
0005435069089	3531	63	17A
0005435069066	3531	64	17C
0005435069065	3531	65	17D
0005435069081	3531	66	17E
0005435069082	3531	67	17F
0005435069100	3531	68	18A
0005435069078	3531	69	18C
0005435069094	3531	70	18E
0005435069059	3531	71	19A
0005435069067	3531	72	19C
0005435069099	3531	73	19D
0005435069107	3531	74	20A
0005435069069	3531	75	20C
0005435718940	3531	76	20D
0005435069102	3531	77	20E
0005435069106	3531	78	20F
0005435718835	15332	1	1A
0005435068834	15332	2	1C
0005435718873	15332	3	1D
0005435068593	15332	4	1F
0005435718848	15332	5	2A
0005435068777	15332	6	2D
0005435718847	15332	7	2F
0005435718883	15332	8	3A
0005435718867	15332	9	3C
0005435718841	15332	10	3D
0005435718878	15332	11	3F
0005435718853	15332	12	4A
0005435068632	15332	13	4C
0005435718870	15332	14	4D
0005435718834	15332	15	5A
0005435068809	15332	16	5C
0005435068368	15332	17	5D
0005435718852	15332	18	5E
0005435068664	15332	19	5F
0005435718830	15332	20	6A
0005435068699	15332	21	6C
0005435718837	15332	22	6D
0005435068617	15332	23	6E
0005435068644	15332	24	6F
0005435068666	15332	25	7A
0005435068589	15332	26	7C
0005435718869	15332	27	7E
0005435068645	15332	28	7F
0005435068788	15332	29	8A
0005435718863	15332	30	8C
0005435068557	15332	31	8D
0005435068685	15332	32	8E
0005435718858	15332	33	8F
0005435718862	15332	34	9A
0005435068458	15332	35	9C
0005435718839	15332	36	9E
0005435718882	15332	37	10A
0005435068569	15332	38	10C
0005435718855	15332	39	10D
0005435068774	15332	40	10E
0005435068673	15332	41	10F
0005435068603	15332	42	11A
0005435068547	15332	43	11C
0005435718868	15332	44	11D
0005435068700	15332	45	11F
0005435068591	15332	46	12A
0005435718861	15332	47	12C
0005435068178	15332	48	12D
0005435068415	15332	49	12E
0005435718854	15332	50	12F
0005435068578	15332	51	13A
0005435068434	15332	52	13C
0005435068579	15332	53	13D
0005435718840	15332	54	13E
0005435068583	15332	55	13F
0005435718836	15332	56	14A
0005435068414	15332	57	14C
0005435718827	15332	58	14D
0005435068602	15332	59	14E
0005435718874	15332	60	14F
0005435718828	15332	61	15A
0005435718877	15332	62	15C
0005435718880	15332	63	15D
0005435718856	15332	64	15E
0005435068568	15332	65	15F
0005435718871	15332	66	16A
0005435718843	15332	67	16D
0005435068413	15332	68	16E
0005435068618	15332	69	17A
0005435718831	15332	70	17C
0005435068491	15332	71	17D
0005435068657	15332	72	17E
0005435068556	15332	73	17F
0005435718881	15332	74	18C
0005435068580	15332	75	18D
0005435718849	15332	76	18E
0005435718865	15332	77	18F
0005435068631	15332	78	19A
0005435068588	15332	79	19C
0005435718872	15332	80	19D
0005435068457	15332	81	19E
0005435718875	15332	82	19F
0005435718857	15332	83	20A
0005435718829	15332	84	20C
0005435068693	15332	85	20E
0005435718846	15332	86	20F
0005432660817	18191	1	2A
0005432660818	18191	2	3B
0005432658590	18191	3	4A
0005432659706	18191	4	5B
0005432658591	18191	5	6A
0005432659705	18191	6	6B
0005432667429	26350	1	1A
0005432660798	26350	2	3A
0005432664113	26350	3	4A
0005432664127	26350	4	6A
0005432901465	193	1	1C
0005432391965	193	2	2A
0005432391956	193	3	2C
0005432919663	193	4	2F
0005433101484	193	5	2D
0005432919662	193	6	4A
0005433101662	193	7	4C
0005432677552	193	8	4F
0005432157491	193	9	5A
0005433101599	193	10	5C
0005433101633	193	11	6D
0005432919728	193	12	6C
0005433101600	193	13	6F
0005433101595	193	14	7C
0005433101553	193	15	7F
0005432919707	193	16	8A
0005433101479	193	17	8B
0005432391972	193	18	8C
0005433101571	193	19	8E
0005433101524	193	20	8D
0005433101685	193	21	8F
0005433101665	193	22	9A
0005433101695	193	23	9C
0005433101707	193	24	9B
0005432391980	193	25	10A
0005432677524	193	26	10C
0005433101663	193	27	10D
0005432901504	193	28	11A
0005432919717	193	29	11D
0005432919722	193	30	11C
0005433101687	193	31	11F
0005433101699	193	32	12A
0005433101717	193	33	12B
0005432391967	193	34	12C
0005433101617	193	35	12D
0005433101721	193	36	12F
0005432919723	193	37	13B
0005433101554	193	38	13C
0005432901469	193	39	13D
0005432919733	193	40	14A
0005433101727	193	41	14B
0005432919686	193	42	14D
0005432157492	193	43	14E
0005433101594	193	44	15A
0005432919692	193	45	15C
0005433101648	193	46	15B
0005433101528	193	47	15F
0005433101465	193	48	16C
0005432919797	193	49	16D
0005432919694	193	50	16E
0005433101698	193	51	17A
0005433101570	193	52	17B
0005433101734	193	53	18C
0005432919798	193	54	18D
0005433101654	193	55	18E
0005432391959	193	56	18F
0005432919664	193	57	19C
0005432919684	193	58	19B
0005432391983	193	59	19D
0005433101569	193	60	19E
0005432901470	193	61	20C
0005432919658	193	62	20B
0005433101641	193	63	20F
0005432901426	193	64	21A
0005433101728	193	65	21B
0005433101518	193	66	21D
0005433101517	193	67	21F
0005433101647	193	68	21E
0005432919769	193	69	22A
0005432919778	193	70	22D
0005433101519	193	71	22F
0005432677553	193	72	23A
0005433101673	193	73	23B
0005432919777	193	74	23E
0005433101716	193	75	24B
0005432901466	193	76	24C
0005432391960	193	77	24D
0005433101664	193	78	24F
0005433101622	193	79	25A
0005433101605	193	80	25C
0005433101715	193	81	25D
0005432919600	193	82	25E
0005433101628	193	83	26B
0005432901460	193	84	26C
0005432901444	193	85	26F
0005432391982	193	86	27A
0005432677525	193	87	27C
0005433101629	193	88	27D
0005432901454	193	89	27E
0005433101732	193	90	28A
0005433101625	193	91	28D
0005433101590	193	92	28C
0005432901474	193	93	28F
0005433101606	193	94	29B
0005433101703	193	95	29A
0005432391966	193	96	29E
0005433101733	193	97	30B
0005433101706	193	98	30E
0005433101616	193	99	30D
0005432391981	193	100	30F
0005433101602	193	101	31B
0005433101655	193	102	31A
0005433101696	193	103	31C
0005432261888	194	1	1F
0005432261882	194	2	1D
0005433690898	194	3	2A
0005432261901	194	4	2C
0005432817471	194	5	2D
0005432261916	194	6	2F
0005432817474	194	7	3D
0005432261883	194	8	3F
0005432261919	194	9	4C
0005434153534	194	10	4D
0005432817464	194	11	5A
0005432261894	194	12	5C
0005432261909	194	13	5F
0005432261886	194	14	6A
0005432817469	194	15	6F
0005432288984	194	16	7C
0005432817483	194	17	7F
0005432261889	194	18	8A
0005432753259	194	19	8B
0005432261923	194	20	8C
0005432261914	194	21	8D
0005432817460	194	22	8F
0005432817480	194	23	9C
0005432817481	194	24	9D
0005432261920	194	25	9F
0005432261913	194	26	10A
0005432261896	194	27	11A
0005432261898	194	28	10F
0005432817462	194	29	11B
0005432288986	194	30	11C
0005432817466	194	31	11D
0005432753260	194	32	11F
0005432261921	194	33	12A
0005433690897	194	34	12B
0005432261891	194	35	12F
0005432817457	194	36	13A
0005432817473	194	37	13C
0005433687677	194	38	13F
0005432261926	194	39	14A
0005432817477	194	40	14B
0005432261899	194	41	14D
0005432817478	194	42	14C
0005432261893	194	43	14F
0005432817458	194	44	15D
0005432261928	194	45	15E
0005432261902	194	46	16A
0005432817455	194	47	15F
0005432261907	194	48	16B
0005432288985	194	49	16C
0005432261905	194	50	16D
0005432817461	194	51	16F
0005433687675	194	52	17C
0005432817468	194	53	17D
0005432261929	194	54	17F
0005434153533	194	55	17E
0005432817467	194	56	18A
0005432817482	194	57	18B
0005432817479	194	58	18D
0005432817476	194	59	19C
0005432261900	194	60	19D
0005432207659	194	61	20A
0005432207660	194	62	21A
0005432756808	194	63	21E
0005432261918	194	64	21D
0005432817463	194	65	22A
0005432261887	194	66	22B
0005434153532	194	67	22F
0005432261910	194	68	23A
0005432261915	194	69	23B
0005432817456	194	70	23D
0005432261903	194	71	23F
0005432261895	194	72	24A
0005432817465	194	73	24B
0005432261906	194	74	24D
0005432261911	194	75	24F
0005432261890	194	76	25B
0005432261912	194	77	25D
0005434153531	194	78	26A
0005432817459	194	79	26B
0005432817454	194	80	26C
0005432288987	194	81	26E
0005433687676	194	82	27A
0005432817472	194	83	27C
0005432261922	194	84	27E
0005432261904	194	85	28A
0005432261925	194	86	29B
0005432261884	194	87	30A
0005432261924	194	88	30C
0005432756801	194	89	30B
0005432261897	194	90	30E
0005432817470	194	91	30D
0005432261892	194	92	30F
0005432261927	194	93	31A
0005432261917	194	94	31C
0005432817475	194	95	31B
0005432261908	194	96	31D
0005432261885	194	97	31F
0005433102149	7985	1	1A
0005432020245	7985	2	1C
0005432919850	7985	3	1D
0005432919863	7985	4	2D
0005432919854	7985	5	2C
0005432753301	7985	6	3C
0005433102164	7985	7	4A
0005432020260	7985	8	4C
0005433102170	7985	9	4D
0005432751530	7985	10	4F
0005432919861	7985	11	5C
0005433102168	7985	12	5A
0005432020259	7985	13	6A
0005433102154	7985	14	5F
0005433102138	7985	15	6D
0005433102163	7985	16	7A
0005433102144	7985	17	7D
0005432751528	7985	18	7C
0005432677575	7985	19	7F
0005433102152	7985	20	8A
0005433102133	7985	21	8C
0005433102151	7985	22	8B
0005432677574	7985	23	8D
0005433102165	7985	24	8F
0005433102162	7985	25	9B
0005432751525	7985	26	9A
0005432020257	7985	27	9C
0005433102135	7985	28	9D
0005432044523	7985	29	9F
0005433102143	7985	30	10A
0005433102145	7985	31	10D
0005432020255	7985	32	10F
0005432751526	7985	33	11B
0005432919852	7985	34	11D
0005433102160	7985	35	11E
0005432020256	7985	36	12A
0005432753302	7985	37	11F
0005433102126	7985	38	12B
0005432919858	7985	39	12C
0005432020252	7985	40	12E
0005433102130	7985	41	12F
0005432020268	7985	42	13A
0005433102156	7985	43	13C
0005432020254	7985	44	13B
0005433102158	7985	45	13D
0005433102153	7985	46	14A
0005432020265	7985	47	14C
0005433102150	7985	48	14E
0005432020249	7985	49	14F
0005433102142	7985	50	15C
0005433102167	7985	51	15B
0005433102147	7985	52	15D
0005432919859	7985	53	16B
0005432020258	7985	54	16A
0005433102127	7985	55	15F
0005432919862	7985	56	16D
0005432020250	7985	57	16C
0005432020262	7985	58	16E
0005432677573	7985	59	16F
0005432020266	7985	60	17B
0005432020247	7985	61	17A
0005433102136	7985	62	17C
0005433102166	7985	63	17D
0005432392000	7985	64	17E
0005432020269	7985	65	18A
0005433102141	7985	66	17F
0005433102125	7985	67	18B
0005432751529	7985	68	18E
0005432919848	7985	69	18D
0005432919855	7985	70	18F
0005432020261	7985	71	19D
0005432677572	7985	72	19C
0005432919847	7985	73	19E
0005432919851	7985	74	20B
0005433102171	7985	75	20C
0005433102134	7985	76	20D
0005432020270	7985	77	20F
0005432020246	7985	78	20E
0005433102132	7985	79	21B
0005432391998	7985	80	21A
0005433102161	7985	81	21C
0005432020253	7985	82	21E
0005432919846	7985	83	22B
0005432020264	7985	84	22C
0005432020271	7985	85	22F
0005433102169	7985	86	23A
0005432751527	7985	87	23C
0005432919849	7985	88	23B
0005432919860	7985	89	23E
0005433102148	7985	90	24A
0005433102131	7985	91	24C
0005433102157	7985	92	24E
0005433102128	7985	93	24F
0005433102155	7985	94	25B
0005432020248	7985	95	25A
0005433102146	7985	96	25D
0005432919864	7985	97	25F
0005433102139	7985	98	25E
0005432045613	7985	99	26C
0005432919853	7985	100	26E
0005432391999	7985	101	26F
0005432044525	7985	102	27C
0005432020267	7985	103	27B
0005432044524	7985	104	27D
0005432919856	7985	105	27E
0005432919865	7985	106	27F
0005432919857	7985	107	28D
0005433102159	7985	108	28C
0005433102140	7985	109	28E
0005433102129	7985	110	29C
0005433102137	7985	111	29D
0005432919866	7985	112	29E
0005432677576	7985	113	29F
0005432020251	7985	114	30F
0005432045614	7985	115	31A
0005432020272	7985	116	31C
0005432020263	7985	117	31B
0005432919867	7985	118	31E
0005432919845	7985	119	31F
0005432901601	7984	1	3D
0005432002077	7984	2	4C
0005432817099	7984	3	5A
0005432901603	7984	4	4F
0005432002075	7984	5	5F
0005432817160	7984	6	5D
0005432817159	7984	7	6C
0005432817298	7984	8	6F
0005432901614	7984	9	8A
0005432901599	7984	10	7F
0005432817233	7984	11	8C
0005432901600	7984	12	9C
0005432817053	7984	13	11C
0005432817232	7984	14	11B
0005432817054	7984	15	12F
0005432901605	7984	16	13C
0005432817348	7984	17	15C
0005432817158	7984	18	16A
0005432901607	7984	19	16B
0005432901604	7984	20	16D
0005432901615	7984	21	17A
0005432817179	7984	22	17D
0005432817255	7984	23	17F
0005432817095	7984	24	19C
0005432817262	7984	25	19E
0005432817166	7984	26	21A
0005432817098	7984	27	21C
0005432901616	7984	28	22C
0005432817346	7984	29	22D
0005432901613	7984	30	22F
0005432901606	7984	31	23A
0005432817216	7984	32	23C
0005432002078	7984	33	24A
0005432901611	7984	34	24E
0005432002076	7984	35	25C
0005432901602	7984	36	26A
0005432817272	7984	37	26B
0005432817271	7984	38	26F
0005432901609	7984	39	27C
0005432901610	7984	40	27F
0005432817347	7984	41	27E
0005432817259	7984	42	29C
0005432817326	7984	43	29E
0005432901612	7984	44	30D
0005432817199	7984	45	30C
0005432901608	7984	46	30F
0005432817249	7984	47	31A
0005432817094	7984	48	31E
0005434175711	9690	1	2B
0005433870731	9690	2	5A
0005434175754	32338	1	1A
0005434175751	32338	2	1B
0005434175752	32338	3	2A
0005434175753	32338	4	2B
0005433870716	32338	5	3A
0005434175750	32338	6	3B
0005433870713	32338	7	4B
0005432799449	3466	1	1C
0005434878283	3466	2	1A
0005434878223	3466	3	1H
0005434878231	3466	4	1K
0005434878297	3466	5	2D
0005434426626	3466	6	2C
0005434878294	3466	7	2H
0005432799450	3466	8	3A
0005435126366	3466	9	2K
0005434426607	3466	10	3H
0005434878220	3466	11	3G
0005435126386	3466	12	4A
0005435914684	3466	13	4G
0005435626168	3466	14	4D
0005434878211	3466	15	4K
0005434878252	3466	16	4H
0005434878226	3466	17	5D
0005435902583	3466	18	5C
0005435126367	3466	19	5H
0005434878255	3466	20	11D
0005434878203	3466	21	11C
0005435626169	3466	22	11E
0005434878272	3466	23	11K
0005434878228	3466	24	11G
0005435126368	3466	25	12C
0005435126375	3466	26	12A
0005435902604	3466	27	12F
0005434878206	3466	28	12E
0005432188606	3466	29	12D
0005434878298	3466	30	12G
0005435126381	3466	31	12K
0005434878285	3466	32	12H
0005435126388	3466	33	13D
0005432188607	3466	34	13E
0005435126369	3466	35	13H
0005434878258	3466	36	13G
0005435913874	3466	37	14C
0005432799448	3466	38	14A
0005434878276	3466	39	13K
0005434426624	3466	40	14F
0005434878214	3466	41	14H
0005432799461	3466	42	14G
0005434938138	3466	43	15C
0005432611711	3466	44	15A
0005434426610	3466	45	15E
0005434426612	3466	46	15D
0005434878274	3466	47	15H
0005434938137	3466	48	15G
0005432613860	3466	49	16A
0005434878224	3466	50	15K
0005434938149	3466	51	16C
0005435126361	3466	52	16E
0005434426601	3466	53	16G
0005434426611	3466	54	17C
0005432799469	3466	55	16K
0005432799464	3466	56	17E
0005434878291	3466	57	17G
0005434878262	3466	58	18A
0005434878293	3466	59	17K
0005432799470	3466	60	18D
0005434878281	3466	61	18G
0005434878235	3466	62	18F
0005434426622	3466	63	18J
0005432188610	3466	64	19A
0005432613863	3466	65	18K
0005434878271	3466	66	19C
0005434938147	3466	67	19J
0005434878267	3466	68	19H
0005432799453	3466	69	19G
0005434878217	3466	70	19K
0005434878249	3466	71	20C
0005434426609	3466	72	20B
0005432799458	3466	73	20A
0005434878240	3466	74	20E
0005434878286	3466	75	20D
0005432799468	3466	76	20F
0005432613861	3466	77	20J
0005434878209	3466	78	20H
0005434878246	3466	79	21B
0005434426620	3466	80	21A
0005434938139	3466	81	21D
0005432611712	3466	82	21F
0005435914693	3466	83	21E
0005432799463	3466	84	21J
0005432799462	3466	85	21K
0005435126394	3466	86	22C
0005434878222	3466	87	22E
0005434938151	3466	88	22D
0005434426602	3466	89	22H
0005434878292	3466	90	22F
0005434426604	3466	91	23B
0005432799444	3466	92	23D
0005434878233	3466	93	23C
0005434878218	3466	94	23J
0005434878244	3466	95	24D
0005434426600	3466	96	23K
0005432188608	3466	97	24F
0005434878273	3466	98	24E
0005434426614	3466	99	25A
0005435841089	3466	100	25C
0005434938152	3466	101	25F
0005435914688	3466	102	26A
0005434878213	3466	103	25J
0005432799447	3466	104	26D
0005434878237	3466	105	26C
0005434878239	3466	106	26G
0005434878288	3466	107	26J
0005435126377	3466	108	26H
0005435126387	3466	109	27B
0005434878207	3466	110	27A
0005432183467	3466	111	27C
0005434938150	3466	112	27F
0005434878261	3466	113	27H
0005432613864	3466	114	27G
0005435902589	3466	115	28A
0005434938140	3466	116	27J
0005434426621	3466	117	28E
0005434878202	3466	118	28C
0005434878212	3466	119	28G
0005435914685	3466	120	29B
0005435126373	3466	121	29D
0005434878227	3466	122	29C
0005435902537	3466	123	29E
0005435126374	3466	124	29J
0005432799466	3466	125	29H
0005434878280	3466	126	29G
0005435126385	3466	127	29K
0005435126391	3466	128	30C
0005434938133	3466	129	30E
0005435126380	3466	130	30F
0005435126378	3466	131	30J
0005435902609	3466	132	30H
0005434878245	3466	133	31B
0005434878221	3466	134	31A
0005432799459	3466	135	30K
0005435126389	3466	136	31F
0005434878277	3466	137	31E
0005434426619	3466	138	31H
0005434878219	3466	139	31K
0005435626171	3466	140	32C
0005435126390	3466	141	32B
0005435902603	3466	142	32E
0005434878269	3466	143	32D
0005434878241	3466	144	32F
0005434426617	3466	145	32J
0005434878242	3466	146	32H
0005435126362	3466	147	33C
0005435913895	3466	148	33B
0005435902473	3466	149	33F
0005434426605	3466	150	33J
0005435914686	3466	151	33H
0005432188609	3466	152	33G
0005434426608	3466	153	33K
0005435914689	3466	154	34B
0005434878257	3466	155	34A
0005435626172	3466	156	34E
0005434878204	3466	157	34D
0005434426618	3466	158	34H
0005434878208	3466	159	34G
0005435126371	3466	160	34F
0005434878268	3466	161	35B
0005434878263	3466	162	35A
0005434878236	3466	163	34K
0005434426613	3466	164	35D
0005434426615	3466	165	35G
0005434878284	3466	166	35F
0005434426599	3466	167	35J
0005432799446	3466	168	36A
0005434878259	3466	169	35K
0005435914690	3466	170	36D
0005435126356	3466	171	36B
0005434878225	3466	172	36E
0005435902579	3466	173	36H
0005432799456	3466	174	36G
0005434878229	3466	175	36F
0005434878278	3466	176	36K
0005435626173	3466	177	36J
0005434878279	3466	178	37B
0005432799460	3466	179	37A
0005434878210	3466	180	37D
0005435126370	3466	181	37J
0005435126395	3466	182	37H
0005435626167	3466	183	38A
0005435626165	3466	184	38B
0005435126355	3466	185	38J
0005434426606	3466	186	38H
0005434878282	3466	187	39B
0005432799451	3466	188	39A
0005432799452	3466	189	39F
0005432799472	3466	190	40A
0005434938135	3466	191	40C
0005434878243	3466	192	40B
0005435126379	3466	193	40E
0005432799455	3466	194	40G
0005434878270	3466	195	40F
0005434878254	3466	196	40K
0005434878232	3466	197	40J
0005435626166	3466	198	40H
0005435126365	3466	199	41B
0005434878265	3466	200	41A
0005434426598	3466	201	41D
0005435126376	3466	202	41G
0005434878266	3466	203	41F
0005434938145	3466	204	41E
0005435626170	3466	205	41J
0005434878251	3466	206	41H
0005434938134	3466	207	42C
0005435126363	3466	208	42B
0005434878289	3466	209	42D
0005434938144	3466	210	42F
0005435902614	3466	211	42J
0005434878216	3466	212	43A
0005435902529	3466	213	42K
0005434878205	3466	214	43D
0005435126393	3466	215	43C
0005435126357	3466	216	43F
0005434878275	3466	217	43E
0005434938141	3466	218	43H
0005434426623	3466	219	43G
0005435126359	3466	220	43J
0005432611710	3466	221	44B
0005434426616	3466	222	44A
0005434938148	3466	223	44E
0005434878248	3466	224	44G
0005432799454	3466	225	44F
0005434878238	3466	226	44J
0005434878253	3466	227	45A
0005434938146	3466	228	45D
0005435902610	3466	229	45C
0005435126364	3466	230	45F
0005434878215	3466	231	45E
0005435126384	3466	232	45G
0005432799445	3466	233	45K
0005432799465	3466	234	46B
0005434878250	3466	235	46A
0005435126372	3466	236	46H
0005435126382	3466	237	46F
0005434878230	3466	238	46J
0005434426625	3466	239	47G
0005434878234	3466	240	47F
0005434938142	3466	241	47H
0005432613862	3466	242	48C
0005434878247	3466	243	48A
0005434878290	3466	244	48F
0005435126358	3466	245	48H
0005434878256	3466	246	48G
0005432799467	3466	247	49A
0005434938136	3466	248	48K
0005435126392	3466	249	49D
0005434426603	3466	250	49C
0005434878264	3466	251	49F
0005435841091	3466	252	49K
0005435126383	3466	253	50C
0005435126360	3466	254	50A
0005434878260	3466	255	50D
0005432799457	3466	256	50H
0005434878287	3466	257	50F
0005434938143	3466	258	50K
0005434878295	3466	259	51E
0005432799471	3466	260	51D
0005434878296	3466	261	51G
0005434426362	14570	1	1C
0005435126103	14570	2	1A
0005434877097	14570	3	1D
0005434426351	14570	4	2A
0005435625971	14570	5	1K
0005434876966	14570	6	2C
0005434877237	14570	7	2H
0005432607542	14570	8	2G
0005432799291	14570	9	2D
0005432799169	14570	10	3A
0005435126134	14570	11	3G
0005435126022	14570	12	3C
0005434877342	14570	13	3H
0005435125870	14570	14	4C
0005434937923	14570	15	4A
0005435625994	14570	16	4G
0005432799319	14570	17	4D
0005434877599	14570	18	4K
0005435625951	14570	19	5D
0005435902703	14570	20	5C
0005434426265	14570	21	5A
0005434937973	14570	22	5H
0005435126038	14570	23	5K
0005434877150	14570	24	11D
0005435902710	14570	25	11G
0005434877239	14570	26	11F
0005435126031	14570	27	11E
0005434877383	14570	28	11K
0005435625995	14570	29	11H
0005434426272	14570	30	12C
0005435902698	14570	31	12E
0005434877609	14570	32	12G
0005434877496	14570	33	12F
0005435125917	14570	34	12K
0005434877847	14570	35	12H
0005434877600	14570	36	13D
0005435126123	14570	37	13C
0005435913935	14570	38	13F
0005434877495	14570	39	13E
0005434426339	14570	40	13G
0005434426269	14570	41	14A
0005432799104	14570	42	13K
0005434426382	14570	43	14D
0005435625979	14570	44	14C
0005434938006	14570	45	14G
0005435841821	14570	46	14E
0005435125747	14570	47	14K
0005434877434	14570	48	15C
0005432799236	14570	49	15A
0005434877365	14570	50	15E
0005434877477	14570	51	15D
0005435126017	14570	52	16A
0005434426470	14570	53	16D
0005435126044	14570	54	16F
0005434877475	14570	55	16G
0005434877076	14570	56	17C
0005435913934	14570	57	17A
0005434877462	14570	58	17E
0005435126051	14570	59	17H
0005432607519	14570	60	17G
0005434877478	14570	61	17F
0005434877308	14570	62	18A
0005434877583	14570	63	17K
0005434877597	14570	64	18B
0005435125803	14570	65	18E
0005434426359	14570	66	18D
0005434877435	14570	67	18C
0005434877151	14570	68	18G
0005435902705	14570	69	18F
0005434877075	14570	70	18J
0005435125980	14570	71	19A
0005435902709	14570	72	19D
0005434877244	14570	73	19B
0005435625958	14570	74	19F
0005435125932	14570	75	19E
0005434877613	14570	76	19H
0005434877447	14570	77	19G
0005434877294	14570	78	19K
0005432799232	14570	79	20C
0005434937984	14570	80	20B
0005434426268	14570	81	20D
0005434877482	14570	82	20H
0005435126016	14570	83	20G
0005435125802	14570	84	20F
0005434877283	14570	85	20J
0005434938041	14570	86	20K
0005435125928	14570	87	21D
0005435902702	14570	88	21C
0005432799231	14570	89	21E
0005434877349	14570	90	22A
0005434877367	14570	91	21K
0005434426350	14570	92	22C
0005434877534	14570	93	22B
0005434877492	14570	94	22E
0005435626003	14570	95	22D
0005435125985	14570	96	22F
0005434877515	14570	97	22K
0005432611656	14570	98	22J
0005435626019	14570	99	23B
0005434937937	14570	100	23A
0005434877548	14570	101	23D
0005432799180	14570	102	23J
0005434877768	14570	103	23H
0005435126156	14570	104	23G
0005434938051	14570	105	24D
0005435625976	14570	106	23K
0005432611682	14570	107	25B
0005435126111	14570	108	25D
0005434877527	14570	109	25E
0005434937938	14570	110	25G
0005434877623	14570	111	26A
0005432607541	14570	112	25K
0005435126043	14570	113	25J
0005434877969	14570	114	26E
0005434877149	14570	115	26D
0005432607512	14570	116	26J
0005434938005	14570	117	26H
0005434877397	14570	118	27B
0005435902708	14570	119	27A
0005434877878	14570	120	27D
0005435902694	14570	121	27C
0005432799056	14570	122	27F
0005432799130	14570	123	27E
0005434426333	14570	124	27G
0005434937924	14570	125	27K
0005434877277	14570	126	27J
0005434877343	14570	127	28B
0005435625973	14570	128	28A
0005434877598	14570	129	28E
0005434426279	14570	130	28D
0005435626015	14570	131	29B
0005432799263	14570	132	28K
0005434937983	14570	133	29D
0005435125943	14570	134	29C
0005434877276	14570	135	29G
0005432611695	14570	136	29F
0005435626006	14570	137	29E
0005434426384	14570	138	29H
0005432607531	14570	139	30A
0005432059505	14570	140	29K
0005435902707	14570	141	29J
0005434877544	14570	142	30C
0005434877498	14570	143	30D
0005434877610	14570	144	30G
0005432799201	14570	145	30K
0005434877400	14570	146	30H
0005432799221	14570	147	31B
0005435902711	14570	148	31A
0005434877322	14570	149	31D
0005432799137	14570	150	31C
0005435125821	14570	151	31F
0005432799342	14570	152	31E
0005434937918	14570	153	31K
0005435626002	14570	154	32B
0005432799213	14570	155	32A
0005435125749	14570	156	32D
0005434877183	14570	157	32K
0005434426278	14570	158	32J
0005434877493	14570	159	32H
0005432799179	14570	160	33B
0005434877112	14570	161	33A
0005435126120	14570	162	33D
0005434426399	14570	163	33C
0005434877275	14570	164	33F
0005434937974	14570	165	33E
0005432607530	14570	166	33H
0005435902695	14570	167	33G
0005434937982	14570	168	34A
0005434426273	14570	169	33K
0005435125994	14570	170	33J
0005435125963	14570	171	34E
0005434877361	14570	172	34D
0005434877535	14570	173	34H
0005435126081	14570	174	34G
0005434877546	14570	175	34F
0005435625972	14570	176	35B
0005434426377	14570	177	35A
0005435913936	14570	178	35C
0005434877653	14570	179	35F
0005434938087	14570	180	35G
0005432799105	14570	181	35K
0005432799219	14570	182	35J
0005434877777	14570	183	36C
0005432799343	14570	184	36B
0005435125907	14570	185	36D
0005434877395	14570	186	36H
0005432799200	14570	187	36F
0005434877551	14570	188	36K
0005435126080	14570	189	37A
0005434877316	14570	190	37D
0005435126032	14570	191	37F
0005435902704	14570	192	37J
0005434426361	14570	193	37H
0005432799318	14570	194	37K
0005434426469	14570	195	38B
0005435902697	14570	196	38H
0005434877776	14570	197	39B
0005435913933	14570	198	39A
0005434426400	14570	199	39C
0005434876930	14570	200	39F
0005434938000	14570	201	39J
0005432799168	14570	202	39H
0005434877608	14570	203	39G
0005434877769	14570	204	40A
0005435625999	14570	205	39K
0005435626005	14570	206	40C
0005435902699	14570	207	40E
0005435902696	14570	208	40D
0005434426358	14570	209	40G
0005432799199	14570	210	40J
0005435125986	14570	211	40H
0005434938042	14570	212	40K
0005434877497	14570	213	41D
0005434877596	14570	214	41C
0005434426352	14570	215	41B
0005435125748	14570	216	41G
0005434938040	14570	217	41F
0005434877366	14570	218	41E
0005434877396	14570	219	41J
0005434877265	14570	220	42A
0005432059504	14570	221	42C
0005434877169	14570	222	42E
0005435125850	14570	223	42D
0005434426322	14570	224	42G
0005434426467	14570	225	42F
0005435126092	14570	226	42K
0005432799222	14570	227	43A
0005435625975	14570	228	43D
0005435625996	14570	229	43C
0005435625974	14570	230	43F
0005434937999	14570	231	43E
0005435126045	14570	232	43H
0005434877436	14570	233	43K
0005434938037	14570	234	43J
0005434877368	14570	235	44B
0005434877315	14570	236	44A
0005435625926	14570	237	44E
0005435125849	14570	238	44D
0005432799250	14570	239	44F
0005434877765	14570	240	45A
0005435125899	14570	241	44K
0005434877712	14570	242	45D
0005435126052	14570	243	45B
0005435902706	14570	244	45F
0005434877595	14570	245	45E
0005435902701	14570	246	45J
0005432799235	14570	247	45G
0005434877607	14570	248	45K
0005434876931	14570	249	46C
0005432611663	14570	250	46B
0005434426329	14570	251	46A
0005432799290	14570	252	46E
0005434876965	14570	253	46G
0005435125860	14570	254	46F
0005434877248	14570	255	46J
0005435126091	14570	256	46H
0005434877561	14570	257	47D
0005434937985	14570	258	47C
0005434877238	14570	259	47G
0005434426315	14570	260	47F
0005435125950	14570	261	47K
0005434877401	14570	262	47H
0005434426267	14570	263	48D
0005434877284	14570	264	48C
0005435625997	14570	265	48A
0005434426403	14570	266	48E
0005434426286	14570	267	48H
0005435125967	14570	268	48G
0005434877446	14570	269	48F
0005432611689	14570	270	49C
0005435626007	14570	271	49A
0005432799317	14570	272	49D
0005435126124	14570	273	49G
0005435125931	14570	274	49F
0005434877483	14570	275	49E
0005434877474	14570	276	49H
0005435902700	14570	277	50A
0005434877362	14570	278	50E
0005434938043	14570	279	50D
0005435625998	14570	280	50H
0005434938090	14570	281	50G
0005434877576	14570	282	51D
0005434877182	14570	283	50K
0005434877746	14570	284	51F
0005434877332	14570	285	51G
0005435889845	3622	1	2A
0005434325648	3622	2	3C
0005434325650	3622	3	3D
0005434312319	3622	4	4A
0005434325653	3622	5	4B
0005434325651	3622	6	4C
0005434325655	3622	7	5C
0005435889825	3622	8	5D
0005434325645	3622	9	6B
0005434325646	3622	10	6C
0005434312318	3622	11	6D
0005434325647	3622	12	7B
0005434325654	3622	13	19C
0005434325644	3622	14	19D
0005434325649	3622	15	20A
0005434325652	3622	16	22A
0005434325619	15615	1	2A
0005435889893	15615	2	2B
0005434325531	15615	3	3B
0005435889897	15615	4	3C
0005434325554	15615	5	4A
0005434325568	15615	6	4D
0005435889899	15615	7	5D
0005435889898	15615	8	6A
0005434325596	15615	9	6B
0005434325541	15615	10	6D
0005434325542	15615	11	7B
0005434325581	15615	12	7C
0005435889896	15615	13	7D
0005435889895	15615	14	18A
0005434325555	15615	15	18C
0005435889894	15615	16	18D
0005434325548	15615	17	21B
0005435957708	668	1	2D
0005435957697	668	2	3A
0005433420323	668	3	3B
0005433420293	668	4	3C
0005433420334	668	5	3D
0005435957706	668	6	4A
0005435957709	668	7	4B
0005433420315	668	8	4C
0005433420324	668	9	5B
0005435957703	668	10	6B
0005433420316	668	11	6C
0005435957698	668	12	6D
0005433420328	668	13	7C
0005433420310	668	14	7D
0005433420303	668	15	18A
0005435957701	668	16	18C
0005435957705	668	17	19A
0005433420279	668	18	19B
0005435957707	668	19	20A
0005435957699	668	20	20B
0005435957700	668	21	21B
0005435957702	668	22	21C
0005435957704	668	23	22B
0005435957591	15211	1	1A
0005435957589	15211	2	1C
0005433420406	15211	3	2A
0005433420399	15211	4	2B
0005433420398	15211	5	2D
0005435957590	15211	6	3C
0005433420401	15211	7	3D
0005435957592	15211	8	4D
0005433420403	15211	9	5C
0005435957630	15211	10	5B
0005433420404	15211	11	5D
0005435957631	15211	12	6D
0005433420402	15211	13	7C
0005433420400	15211	14	7D
0005435957611	15211	15	18A
0005435957580	15211	16	18B
0005433420405	15211	17	18C
0005435957537	15211	18	20D
0005435957588	15211	19	21B
0005435957567	15211	20	21D
0005435957574	15211	21	22A
0005435957581	15211	22	22D
0005435216585	31785	1	1D
0005435217711	31785	2	3C
0005435218115	31785	3	4A
0005435218113	31785	4	4D
0005435216591	31785	5	5A
0005435217715	31785	6	5C
0005435217712	31785	7	6A
0005435216586	31785	8	6B
0005435217713	31785	9	6C
0005435216589	31785	10	7A
0005435216587	31785	11	18A
0005435216590	31785	12	18C
0005435217710	31785	13	19A
0005435218114	31785	14	21B
0005435217709	31785	15	21D
0005435216588	31785	16	22B
0005435217714	31785	17	22D
0005434995301	6698	1	3D
0005434995303	6698	2	3F
0005434995306	6698	3	8B
0005434995307	6698	4	9D
0005434995298	6698	5	11C
0005434995299	6698	6	13D
0005434995309	6698	7	13F
0005434995302	6698	8	14C
0005434995300	6698	9	16E
0005434995297	6698	10	19F
0005434995304	6698	11	20C
0005434995308	6698	12	22B
0005434995305	6698	13	22C
0005434247128	8869	1	4A
0005434247129	8869	2	4B
0005434247124	8869	3	5B
0005434247125	8869	4	6B
0005435629393	16064	1	1A
0005434247149	16064	2	1B
0005434247150	16064	3	2A
0005434247147	16064	4	3B
0005434247148	16064	5	6A
0005434247146	16064	6	6B
0005434467760	4012	1	5D
0005434467764	4012	2	6C
0005434467761	4012	3	7C
0005434467763	4012	4	18D
0005434467758	4012	5	19D
0005434467759	4012	6	20B
0005434467762	4012	7	21A
0005434467732	23214	1	2A
0005434467743	23214	2	2B
0005434467734	23214	3	6B
0005434467739	23214	4	7B
0005434467741	23214	5	18B
0005434467746	23214	6	20C
0005434467737	23214	7	21A
0005434467735	23214	8	21C
0005434467738	23214	9	21D
0005434096740	20171	1	1A
0005434096738	20171	2	2A
0005434096736	20171	3	3A
0005434096744	20171	4	3B
0005434096737	20171	5	3D
0005434096739	20171	6	4C
0005434096743	20171	7	18A
0005434096742	20171	8	21B
0005434096741	20171	9	21C
0005435229400	6832	1	1C
0005432645993	6832	2	1D
0005435229346	6832	3	2A
0005432645966	6832	4	2C
0005432645986	6832	5	2D
0005435229353	6832	6	2F
0005435229383	6832	7	3A
0005435229354	6832	8	3D
0005432645980	6832	9	3F
0005435229375	6832	10	4A
0005432645983	6832	11	4C
0005432645984	6832	12	4D
0005432645992	6832	13	4F
0005432645976	6832	14	5A
0005435229382	6832	15	5D
0005432645977	6832	16	5E
0005435229399	6832	17	5F
0005432645982	6832	18	6E
0005432645990	6832	19	6F
0005435229341	6832	20	7D
0005432645987	6832	21	7F
0005435229370	6832	22	8A
0005432645967	6832	23	8C
0005432645979	6832	24	8F
0005432645960	6832	25	9A
0005435229364	6832	26	9C
0005432645974	6832	27	9E
0005432645998	6832	28	9F
0005432645962	6832	29	10A
0005432645988	6832	30	10C
0005432645994	6832	31	10D
0005435229355	6832	32	10E
0005432645970	6832	33	10F
0005432645969	6832	34	11A
0005432645961	6832	35	11C
0005435229330	6832	36	11D
0005432645978	6832	37	12A
0005432645985	6832	38	12C
0005432645981	6832	39	12D
0005432645995	6832	40	12E
0005432645971	6832	41	12F
0005432645991	6832	42	13A
0005432645997	6832	43	13C
0005432645989	6832	44	13D
0005432645996	6832	45	13E
0005435229349	6832	46	14C
0005435229348	6832	47	14D
0005435229339	6832	48	14E
0005435229344	6832	49	15A
0005432645965	6832	50	15C
0005435229331	6832	51	15D
0005432645972	6832	52	16C
0005432645963	6832	53	16D
0005432645968	6832	54	16E
0005435229360	6832	55	16F
0005435229361	6832	56	17A
0005432645959	6832	57	18A
0005435229342	6832	58	18C
0005435229332	6832	59	18D
0005435229343	6832	60	18F
0005435229381	6832	61	19C
0005435229352	6832	62	19E
0005432645964	6832	63	19F
0005432645975	6832	64	20A
0005435229345	6832	65	20C
0005432645973	6832	66	20F
0005435229420	25103	1	1C
0005432645903	25103	2	1D
0005432645849	25103	3	2A
0005432645897	25103	4	2C
0005432645839	25103	5	2D
0005432645869	25103	6	2F
0005435229424	25103	7	3A
0005435229427	25103	8	3D
0005435229417	25103	9	3F
0005432645772	25103	10	4A
0005432645881	25103	11	4C
0005432645817	25103	12	4D
0005432645902	25103	13	4F
0005432645855	25103	14	5A
0005432645864	25103	15	5C
0005432645815	25103	16	5D
0005432645863	25103	17	5E
0005435229410	25103	18	5F
0005432645852	25103	19	6A
0005435229414	25103	20	6E
0005435229409	25103	21	6F
0005432645853	25103	22	7A
0005432645865	25103	23	7C
0005435229431	25103	24	7D
0005435229430	25103	25	7E
0005435229432	25103	26	8A
0005432645845	25103	27	8C
0005432645797	25103	28	8D
0005432645901	25103	29	8E
0005432645899	25103	30	8F
0005432645813	25103	31	9A
0005432645850	25103	32	9C
0005432645814	25103	33	9D
0005432645830	25103	34	9E
0005435229412	25103	35	9F
0005432645821	25103	36	10A
0005432645825	25103	37	10D
0005432645874	25103	38	10E
0005432645831	25103	39	10F
0005435229423	25103	40	11A
0005432645819	25103	41	11C
0005432645888	25103	42	11D
0005432645857	25103	43	11E
0005435229418	25103	44	12A
0005432645848	25103	45	12C
0005435229413	25103	46	12D
0005432645867	25103	47	12E
0005432645816	25103	48	13A
0005435229425	25103	49	13C
0005435229422	25103	50	13D
0005435229415	25103	51	13E
0005435229416	25103	52	13F
0005435229419	25103	53	14A
0005432645822	25103	54	14E
0005432645847	25103	55	14F
0005432645868	25103	56	15C
0005435229421	25103	57	15D
0005432645832	25103	58	15E
0005432645887	25103	59	15F
0005432645783	25103	60	16A
0005435229426	25103	61	16C
0005432645827	25103	62	16E
0005435229411	25103	63	16F
0005432645877	25103	64	17A
0005432645773	25103	65	17C
0005432645843	25103	66	17D
0005432645866	25103	67	17E
0005432645894	25103	68	17F
0005435229407	25103	69	18A
0005435229434	25103	70	18C
0005435229429	25103	71	18E
0005432645844	25103	72	19A
0005432645861	25103	73	19C
0005432645856	25103	74	19D
0005432645876	25103	75	19E
0005435229408	25103	76	19F
0005435229433	25103	77	20A
0005432645898	25103	78	20C
0005432645820	25103	79	20D
0005432645818	25103	80	20E
0005435229428	25103	81	20F
0005435797471	2852	1	1A
0005435797481	2852	2	2F
0005435797472	2852	3	3F
0005433404683	2852	4	4C
0005435797477	2852	5	5D
0005435797480	2852	6	7C
0005435797474	2852	7	9A
0005435797475	2852	8	9E
0005433404743	2852	9	10A
0005433404770	2852	10	11F
0005435797473	2852	11	12A
0005435797469	2852	12	12C
0005435797479	2852	13	13A
0005433404755	2852	14	13C
0005433404742	2852	15	13D
0005435797478	2852	16	14E
0005435797470	2852	17	15F
0005435797468	2852	18	16F
0005433404740	2852	19	18C
0005433404724	2852	20	18F
0005435797476	2852	21	19C
0005433404682	2852	22	20C
0005435797380	29294	1	1D
0005435797356	29294	2	2A
0005435797375	29294	3	2D
0005433404812	29294	4	4A
0005435797396	29294	5	4E
0005433404806	29294	6	4F
0005435797355	29294	7	6C
0005433404808	29294	8	7D
0005435797382	29294	9	8A
0005433404813	29294	10	10C
0005435797376	29294	11	10F
0005435797357	29294	12	11A
0005435797381	29294	13	11C
0005435797458	29294	14	12A
0005433404810	29294	15	12D
0005433404807	29294	16	13E
0005435797282	29294	17	14A
0005433404811	29294	18	14D
0005435797283	29294	19	15C
0005435797342	29294	20	16D
0005435797394	29294	21	18C
0005435797395	29294	22	18F
0005435797347	29294	23	19A
0005433404809	29294	24	20E
0005435376323	5851	1	5A
0005435376324	5851	2	6B
0005434948026	5827	1	3A
0005434948024	5827	2	2B
0005434948025	5827	3	3B
0005434948022	5827	4	4A
0005434948023	5827	5	5A
0005434948021	5827	6	4B
0005434948019	5827	7	6A
0005434948020	5827	8	6B
0005435376354	16359	1	1A
0005435376352	16359	2	1B
0005435376349	16359	3	2A
0005434947923	16359	4	2B
0005435376351	16359	5	3A
0005435376350	16359	6	3B
0005434947998	16359	7	4A
0005435376353	16359	8	4B
0005435376348	16359	9	5A
0005434947960	16359	10	6B
0005433960909	6880	1	1C
0005433960887	6880	2	1F
0005433960882	6880	3	2C
0005433960912	6880	4	2D
0005433960886	6880	5	3C
0005433960878	6880	6	3D
0005433960868	6880	7	4A
0005433960892	6880	8	4D
0005433960906	6880	9	4E
0005433960874	6880	10	4F
0005433960852	6880	11	5C
0005433960884	6880	12	5D
0005433960894	6880	13	5F
0005433960867	6880	14	6D
0005433960876	6880	15	7C
0005433960859	6880	16	7D
0005433960903	6880	17	7E
0005433960861	6880	18	7F
0005433960871	6880	19	8A
0005433960865	6880	20	8C
0005433960864	6880	21	8D
0005433960870	6880	22	9A
0005433960907	6880	23	9D
0005433960904	6880	24	9F
0005433960888	6880	25	10A
0005433960851	6880	26	10C
0005433960898	6880	27	10E
0005433960900	6880	28	10F
0005433960875	6880	29	11A
0005433960885	6880	30	11C
0005433960899	6880	31	11D
0005433960858	6880	32	11E
0005433960856	6880	33	12C
0005433960857	6880	34	12E
0005433960866	6880	35	12F
0005433960897	6880	36	13E
0005433960889	6880	37	13F
0005433960893	6880	38	14A
0005433960877	6880	39	14C
0005433960869	6880	40	14E
0005433960896	6880	41	15C
0005433960862	6880	42	15D
0005433960872	6880	43	15E
0005433960901	6880	44	15F
0005433960883	6880	45	16A
0005433960902	6880	46	16C
0005433960890	6880	47	16D
0005433960910	6880	48	16E
0005433960863	6880	49	17A
0005433960891	6880	50	17C
0005433960880	6880	51	17D
0005433960854	6880	52	17E
0005433960879	6880	53	17F
0005433960881	6880	54	18A
0005433960905	6880	55	18C
0005433960911	6880	56	18F
0005433960860	6880	57	19A
0005433960895	6880	58	19D
0005433960855	6880	59	20A
0005433960908	6880	60	20C
0005433960853	6880	61	20E
0005433960873	6880	62	20F
0005433960092	25765	1	1A
0005433960160	25765	2	1C
0005433960019	25765	3	2A
0005433960214	25765	4	2D
0005433960186	25765	5	2F
0005433960046	25765	6	3D
0005433960320	25765	7	4A
0005433960301	25765	8	4C
0005433960188	25765	9	4D
0005433960159	25765	10	4E
0005433960138	25765	11	4F
0005433960335	25765	12	5C
0005433960261	25765	13	5D
0005433960166	25765	14	5E
0005433960045	25765	15	5F
0005433960146	25765	16	6A
0005433960263	25765	17	6D
0005433960149	25765	18	6E
0005433960241	25765	19	6F
0005433960306	25765	20	7A
0005433960255	25765	21	7C
0005433960307	25765	22	7F
0005433960167	25765	23	8A
0005433960129	25765	24	8C
0005433960130	25765	25	8D
0005433960215	25765	26	8E
0005433960316	25765	27	8F
0005433960230	25765	28	9A
0005433960305	25765	29	10A
0005433960170	25765	30	10D
0005433960084	25765	31	10F
0005433960280	25765	32	11A
0005433960250	25765	33	11C
0005433960058	25765	34	11D
0005433960265	25765	35	11F
0005433960284	25765	36	12A
0005433959909	25765	37	12D
0005433960298	25765	38	12E
0005433960277	25765	39	13C
0005433960285	25765	40	13D
0005433960187	25765	41	13E
0005433960093	25765	42	14A
0005433960147	25765	43	14C
0005433960256	25765	44	14D
0005433960262	25765	45	14E
0005433960249	25765	46	14F
0005433960334	25765	47	15A
0005433960142	25765	48	15C
0005433960247	25765	49	15E
0005433959908	25765	50	15F
0005433960264	25765	51	16D
0005433960232	25765	52	16F
0005433960143	25765	53	17A
0005433960297	25765	54	17C
0005433960275	25765	55	17D
0005433960321	25765	56	17E
0005433960244	25765	57	17F
0005433960272	25765	58	18C
0005433960231	25765	59	18D
0005433960248	25765	60	18F
0005433960245	25765	61	18E
0005433960158	25765	62	19A
0005433960302	25765	63	19C
0005433960290	25765	64	19E
0005433960020	25765	65	20A
0005433960216	25765	66	20D
0005433960242	25765	67	20E
0005433959999	25765	68	20F
0005435082711	24507	1	1A
0005435082712	24507	2	2A
0005435082687	24507	3	3A
0005435082713	24507	4	4A
0005435082772	24507	5	6A
0005435082718	24507	6	6B
0005435082779	26107	1	1A
0005435082781	26107	2	1B
0005435082782	26107	3	2B
0005435082780	26107	4	3B
0005435082783	26107	5	4B
0005435082778	26107	6	5B
0005434244967	5195	1	4A
0005435286570	5195	2	4C
0005434244982	5195	3	4D
0005434244969	5195	4	6C
0005434244968	5195	5	6F
0005434244977	5195	6	8C
0005435286586	5195	7	8F
0005434244984	5195	8	9C
0005434244970	5195	9	9E
0005434244980	5195	10	10C
0005433534476	5195	11	10F
0005434244978	5195	12	11D
0005434244979	5195	13	12A
0005433534475	5195	14	13A
0005434244983	5195	15	12E
0005433534474	5195	16	13D
0005434244991	5195	17	13F
0005432166900	5195	18	14C
0005434244990	5195	19	14E
0005432166901	5195	20	15D
0005434244989	5195	21	15E
0005433534484	5195	22	16A
0005434244992	5195	23	17C
0005434244994	5195	24	17F
0005435286574	5195	25	18B
0005435286568	5195	26	18E
0005434244986	5195	27	18D
0005435286577	5195	28	19C
0005434244993	5195	29	19D
0005434244988	5195	30	20A
0005434244971	5195	31	21D
0005432166903	5195	32	22B
0005434244976	5195	33	22C
0005434244981	5195	34	23C
0005434244966	5195	35	23E
0005434244987	5195	36	24A
0005434244965	5195	37	27E
0005434244974	5195	38	27F
0005432166902	5195	39	28A
0005434244973	5195	40	29A
0005434244972	5195	41	29E
0005435286581	5195	42	30D
0005434244985	5195	43	30C
0005434244975	5195	44	31E
0005433614690	5170	1	1A
0005432105557	5170	2	1C
0005433614679	5170	3	1D
0005432105560	5170	4	2A
0005432666389	5170	5	1F
0005433614660	5170	6	2C
0005433614661	5170	7	2F
0005432105570	5170	8	2D
0005433614689	5170	9	3A
0005433614688	5170	10	3C
0005432105568	5170	11	3F
0005433614706	5170	12	3D
0005433614717	5170	13	4A
0005433614697	5170	14	4C
0005432105559	5170	15	4F
0005432105577	5170	16	4D
0005433614728	5170	17	5A
0005433614696	5170	18	5D
0005433614671	5170	19	5C
0005433614682	5170	20	6A
0005433784943	5170	21	5F
0005432105549	5170	22	6D
0005432105580	5170	23	6C
0005433784937	5170	24	6F
0005432105558	5170	25	7A
0005433614674	5170	26	7D
0005433784954	5170	27	7C
0005432105578	5170	28	7F
0005432105585	5170	29	8A
0005432667454	5170	30	8B
0005433614729	5170	31	8D
0005433614694	5170	32	8C
0005432105569	5170	33	8E
0005433614704	5170	34	8F
0005432105551	5170	35	9B
0005432105581	5170	36	9A
0005432105572	5170	37	9C
0005433784958	5170	38	9D
0005433614662	5170	39	9F
0005432105545	5170	40	9E
0005433614719	5170	41	10A
0005433614727	5170	42	10C
0005433614672	5170	43	10B
0005433784935	5170	44	10D
0005432105582	5170	45	10E
0005433614677	5170	46	10F
0005433784953	5170	47	11B
0005432105576	5170	48	11A
0005433614664	5170	49	11C
0005432665275	5170	50	11E
0005433614681	5170	51	11D
0005433614675	5170	52	12A
0005433614707	5170	53	11F
0005432145111	5170	54	12C
0005433614692	5170	55	12B
0005433614702	5170	56	12E
0005432105583	5170	57	12D
0005433784930	5170	58	12F
0005433614709	5170	59	13A
0005432105547	5170	60	13C
0005432105561	5170	61	13B
0005433614683	5170	62	13E
0005432667455	5170	63	13D
0005432105563	5170	64	14A
0005433614687	5170	65	13F
0005433614703	5170	66	14B
0005432105565	5170	67	14C
0005433784933	5170	68	14E
0005432105562	5170	69	14D
0005433784944	5170	70	15A
0005432105574	5170	71	14F
0005432105571	5170	72	15B
0005433614668	5170	73	15C
0005433784924	5170	74	15E
0005433614676	5170	75	15D
0005432145112	5170	76	15F
0005433614686	5170	77	16A
0005432105584	5170	78	16B
0005432105552	5170	79	16D
0005432105590	5170	80	16C
0005432105553	5170	81	16E
0005433614730	5170	82	16F
0005433614680	5170	83	17B
0005433784936	5170	84	17A
0005432667453	5170	85	17C
0005432105566	5170	86	17D
0005433784949	5170	87	17E
0005433614699	5170	88	18A
0005433614700	5170	89	17F
0005433784942	5170	90	18C
0005433614669	5170	91	18B
0005433614663	5170	92	18D
0005433784928	5170	93	18E
0005432105546	5170	94	19B
0005433614659	5170	95	18F
0005432105567	5170	96	19C
0005433614693	5170	97	19D
0005433784938	5170	98	20A
0005433614722	5170	99	19E
0005433614715	5170	100	20B
0005433614708	5170	101	20C
0005432666390	5170	102	20D
0005433614710	5170	103	20F
0005433784945	5170	104	20E
0005433784951	5170	105	21B
0005433614665	5170	106	21A
0005433614698	5170	107	21D
0005433614732	5170	108	21C
0005433784932	5170	109	21F
0005433614684	5170	110	21E
0005433614701	5170	111	22B
0005432145113	5170	112	22A
0005433784925	5170	113	22C
0005433614723	5170	114	22E
0005433614721	5170	115	22D
0005433784926	5170	116	22F
0005433614720	5170	117	23A
0005433614718	5170	118	23C
0005433784948	5170	119	23B
0005433614726	5170	120	23D
0005433614733	5170	121	23E
0005432665274	5170	122	24A
0005433784959	5170	123	23F
0005433614711	5170	124	24B
0005432105579	5170	125	24D
0005433614673	5170	126	24C
0005433614725	5170	127	24F
0005432105575	5170	128	24E
0005433784927	5170	129	25A
0005432105556	5170	130	25B
0005433614685	5170	131	25E
0005433784940	5170	132	25D
0005433784934	5170	133	25C
0005433614691	5170	134	26A
0005433784931	5170	135	25F
0005433784950	5170	136	26B
0005433614705	5170	137	26D
0005433784955	5170	138	26C
0005432666388	5170	139	26E
0005433614666	5170	140	26F
0005432105589	5170	141	27A
0005433614731	5170	142	27B
0005432105591	5170	143	27D
0005433784946	5170	144	27C
0005432105586	5170	145	27F
0005432105548	5170	146	27E
0005433784939	5170	147	28B
0005432105550	5170	148	28A
0005433784941	5170	149	28D
0005433784947	5170	150	28C
0005432105588	5170	151	28E
0005433784952	5170	152	29A
0005433614714	5170	153	28F
0005433784929	5170	154	29C
0005433614678	5170	155	29B
0005433614695	5170	156	29E
0005433614713	5170	157	29D
0005433784957	5170	158	30A
0005432105573	5170	159	29F
0005433614670	5170	160	30C
0005433614724	5170	161	30B
0005432105587	5170	162	30D
0005432105555	5170	163	30E
0005432105564	5170	164	30F
0005433784956	5170	165	31B
0005432665273	5170	166	31A
0005433614712	5170	167	31C
0005433614667	5170	168	31D
0005432105554	5170	169	31F
0005433614716	5170	170	31E
0005434265133	5145	1	1A
0005434229370	5145	2	1D
0005434149726	5145	3	2A
0005432335935	5145	4	2F
0005434229375	5145	5	2D
0005432335943	5145	6	3A
0005434265136	5145	7	3D
0005434229374	5145	8	4A
0005434229365	5145	9	3F
0005434229369	5145	10	4D
0005433685503	5145	11	4C
0005435006834	5145	12	4F
0005434229360	5145	13	5C
0005435006792	5145	14	5D
0005434265137	5145	15	6A
0005435006930	5145	16	5F
0005434265125	5145	17	6C
0005434229359	5145	18	6F
0005434149732	5145	19	7A
0005434265147	5145	20	7F
0005434149735	5145	21	7D
0005433815321	5145	22	8A
0005432335898	5145	23	8B
0005434265135	5145	24	8D
0005434173518	5145	25	9A
0005434149730	5145	26	9B
0005435006789	5145	27	9C
0005432335911	5145	28	9D
0005435006788	5145	29	9F
0005434265144	5145	30	10A
0005433815323	5145	31	10B
0005434229368	5145	32	10E
0005434149734	5145	33	10D
0005434265145	5145	34	11A
0005434265138	5145	35	11C
0005435006883	5145	36	11B
0005433815353	5145	37	11D
0005432335899	5145	38	11E
0005435006825	5145	39	12B
0005434229376	5145	40	12E
0005432335937	5145	41	13B
0005434173520	5145	42	13D
0005434173519	5145	43	13E
0005434229367	5145	44	14A
0005434149733	5145	45	14D
0005434149731	5145	46	14C
0005435006802	5145	47	14E
0005434265150	5145	48	14F
0005434229363	5145	49	15A
0005434229362	5145	50	15C
0005434265134	5145	51	15D
0005434265131	5145	52	15E
0005434265127	5145	53	16A
0005433815349	5145	54	15F
0005434229364	5145	55	16B
0005434265128	5145	56	16C
0005434149736	5145	57	16D
0005434229378	5145	58	17A
0005433815331	5145	59	16F
0005433815350	5145	60	17C
0005434229379	5145	61	17D
0005432335964	5145	62	17F
0005434149728	5145	63	17E
0005432335910	5145	64	18A
0005433815320	5145	65	18C
0005434265130	5145	66	18B
0005434265146	5145	67	19C
0005434149725	5145	68	20A
0005434229372	5145	69	19E
0005432335926	5145	70	20B
0005433815332	5145	71	20C
0005433815322	5145	72	20D
0005435006744	5145	73	20F
0005434265139	5145	74	21B
0005434265129	5145	75	21D
0005432335936	5145	76	21E
0005434229381	5145	77	22A
0005435006824	5145	78	22C
0005433815337	5145	79	22E
0005434229366	5145	80	23A
0005435006807	5145	81	23C
0005435006743	5145	82	23B
0005434265148	5145	83	23D
0005433815355	5145	84	23E
0005434173521	5145	85	24A
0005434265149	5145	86	24B
0005435006803	5145	87	24C
0005434229373	5145	88	24F
0005435006835	5145	89	25A
0005434312299	5145	90	25B
0005433685504	5145	91	25C
0005434265141	5145	92	26A
0005433815352	5145	93	25F
0005435006769	5145	94	26B
0005434229382	5145	95	26D
0005432335944	5145	96	26C
0005434229380	5145	97	26E
0005435006806	5145	98	26F
0005433815344	5145	99	27C
0005434265126	5145	100	27E
0005434265142	5145	101	28A
0005435006813	5145	102	27F
0005435006787	5145	103	28D
0005433815330	5145	104	28C
0005432335978	5145	105	29A
0005434265143	5145	106	28F
0005434149729	5145	107	29B
0005434229377	5145	108	29C
0005434149727	5145	109	29D
0005434229361	5145	110	29F
0005434265140	5145	111	30E
0005433815310	5145	112	31A
0005434265132	5145	113	31D
0005432335892	5145	114	31C
0005435006814	5145	115	31E
0005434229371	5145	116	31F
0005434244637	8460	1	1A
0005433784598	8460	2	1C
0005433784674	8460	3	1D
0005434244703	8460	4	1F
0005434244743	8460	5	2D
0005434244727	8460	6	3A
0005433784492	8460	7	3C
0005433784545	8460	8	3F
0005434244796	8460	9	3D
0005434244767	8460	10	4A
0005434244684	8460	11	6A
0005433784475	8460	12	6D
0005434244797	8460	13	6F
0005433784537	8460	14	7C
0005434244744	8460	15	7D
0005434244694	8460	16	8B
0005432666370	8460	17	8C
0005434244636	8460	18	9A
0005434244747	8460	19	9D
0005434244708	8460	20	9E
0005433784701	8460	21	10A
0005434244790	8460	22	10C
0005434244778	8460	23	11F
0005434244737	8460	24	11E
0005432666371	8460	25	12B
0005434244770	8460	26	12D
0005434244860	8460	27	12C
0005434244713	8460	28	12E
0005434244683	8460	29	13A
0005433784683	8460	30	12F
0005434244795	8460	31	13E
0005434244695	8460	32	14B
0005434244647	8460	33	14C
0005433784617	8460	34	14D
0005434244768	8460	35	14F
0005432663013	8460	36	15D
0005434244777	8460	37	15E
0005434244798	8460	38	16A
0005434244706	8460	39	16D
0005433784711	8460	40	17A
0005433784476	8460	41	17D
0005433784681	8460	42	17E
0005433784673	8460	43	17F
0005433784547	8460	44	18C
0005434244725	8460	45	18D
0005433784578	8460	46	20C
0005433784694	8460	47	20E
0005433784541	8460	48	21E
0005433784714	8460	49	21F
0005433784710	8460	50	22B
0005433784715	8460	51	22A
0005433784648	8460	52	22E
0005433784544	8460	53	23C
0005433784752	8460	54	23E
0005433784726	8460	55	24A
0005434244696	8460	56	23F
0005433784716	8460	57	24B
0005433784546	8460	58	24D
0005434244707	8460	59	25D
0005433784618	8460	60	26A
0005434244749	8460	61	26C
0005434244726	8460	62	26D
0005433784625	8460	63	27A
0005433784633	8460	64	27B
0005434244816	8460	65	28A
0005433784663	8460	66	28D
0005433784515	8460	67	28C
0005435269748	8460	68	28E
0005433784457	8460	69	29A
0005434244763	8460	70	28F
0005433784727	8460	71	29B
0005433784647	8460	72	29D
0005433784604	8460	73	29F
0005433784575	8460	74	29E
0005433784574	8460	75	30E
0005432663014	8460	76	31C
0005433784632	8460	77	31D
0005433784684	8460	78	31F
0005433614066	8461	1	1A
0005433613629	8461	2	1F
0005433613892	8461	3	2A
0005433613778	8461	4	2C
0005433613966	8461	5	3A
0005433613957	8461	6	3C
0005433614102	8461	7	3F
0005433613689	8461	8	3D
0005433614099	8461	9	4D
0005433613687	8461	10	4C
0005433613979	8461	11	5D
0005433613906	8461	12	6D
0005433613971	8461	13	6C
0005433613883	8461	14	7A
0005433613792	8461	15	7C
0005433613999	8461	16	7D
0005433613777	8461	17	8A
0005433614138	8461	18	7F
0005433614223	8461	19	8D
0005433613860	8461	20	8C
0005433613924	8461	21	8E
0005433614007	8461	22	9C
0005433614175	8461	23	9D
0005433613699	8461	24	9E
0005433613791	8461	25	11D
0005433614113	8461	26	12C
0005433613861	8461	27	12D
0005433614087	8461	28	12F
0005433613540	8461	29	14B
0005433614210	8461	30	14D
0005433614400	8461	31	14E
0005433614349	8461	32	15C
0005433613894	8461	33	15B
0005433613970	8461	34	15D
0005433614170	8461	35	16A
0005433614091	8461	36	15F
0005433614052	8461	37	16C
0005433614045	8461	38	16E
0005433614263	8461	39	16D
0005433614070	8461	40	16F
0005433614211	8461	41	17B
0005433613688	8461	42	17A
0005433614053	8461	43	17D
0005433614109	8461	44	17E
0005433614071	8461	45	17F
0005433613968	8461	46	18C
0005433613732	8461	47	18B
0005433613967	8461	48	18E
0005433613884	8461	49	19B
0005433613986	8461	50	20B
0005433614031	8461	51	20A
0005433613932	8461	52	20D
0005433614001	8461	53	20F
0005433613849	8461	54	21E
0005433613933	8461	55	22A
0005433613757	8461	56	21F
0005433613630	8461	57	22E
0005433614177	8461	58	22F
0005433614067	8461	59	23C
0005433613931	8461	60	23B
0005433614030	8461	61	23D
0005433614029	8461	62	24B
0005433614162	8461	63	24A
0005433613851	8461	64	24E
0005433614350	8461	65	25A
0005433614000	8461	66	25D
0005433614176	8461	67	26A
0005433613539	8461	68	26B
0005433613799	8461	69	26C
0005433613985	8461	70	27A
0005433614059	8461	71	27B
0005433613618	8461	72	27F
0005433614112	8461	73	27E
0005433613965	8461	74	28C
0005433614139	8461	75	28D
0005433614174	8461	76	28F
0005433613864	8461	77	28E
0005433613865	8461	78	29A
0005433614023	8461	79	29C
0005433613836	8461	80	29D
0005433613893	8461	81	30C
0005433614108	8461	82	30B
0005433613988	8461	83	30F
0005433614107	8461	84	31A
0005433613862	8461	85	31C
0005433614358	8461	86	31D
0005432336030	8462	1	1A
0005434229179	8462	2	1C
0005435007038	8462	3	1F
0005432336034	8462	4	1D
0005434264842	8462	5	2A
0005434229240	8462	6	2C
0005434229106	8462	7	3A
0005434229220	8462	8	2F
0005434229237	8462	9	3C
0005433534499	8462	10	3F
0005434229184	8462	11	3D
0005434311218	8462	12	4A
0005434149617	8462	13	4C
0005434229277	8462	14	4F
0005435007030	8462	15	4D
0005433690928	8462	16	5A
0005432047549	8462	17	5D
0005432336036	8462	18	5C
0005434149623	8462	19	6A
0005434229107	8462	20	5F
0005432034952	8462	21	6D
0005432034954	8462	22	6C
0005435007042	8462	23	7A
0005434229276	8462	24	6F
0005432034962	8462	25	7C
0005432034934	8462	26	7F
0005432336029	8462	27	8A
0005434264903	8462	28	8C
0005434229122	8462	29	8B
0005432047548	8462	30	8E
0005434229169	8462	31	8F
0005435007035	8462	32	9A
0005434264891	8462	33	9C
0005434229073	8462	34	9B
0005434229229	8462	35	9D
0005434149651	8462	36	9E
0005434264949	8462	37	10A
0005435007022	8462	38	9F
0005434264923	8462	39	10C
0005433688810	8462	40	10B
0005434264974	8462	41	10E
0005434311219	8462	42	10D
0005434264859	8462	43	11B
0005432034937	8462	44	11A
0005432047550	8462	45	11C
0005432034960	8462	46	11D
0005432336037	8462	47	11F
0005433815388	8462	48	11E
0005434265024	8462	49	12A
0005434149677	8462	50	12B
0005432336031	8462	51	12D
0005435007041	8462	52	12C
0005434264811	8462	53	12E
0005435007033	8462	54	12F
0005433815386	8462	55	13B
0005435007034	8462	56	13A
0005434229205	8462	57	13C
0005432034950	8462	58	13D
0005434264892	8462	59	13F
0005433534497	8462	60	13E
0005434229174	8462	61	14A
0005434229140	8462	62	14B
0005432034939	8462	63	14E
0005435007039	8462	64	14D
0005434173490	8462	65	14F
0005434149650	8462	66	15B
0005432034959	8462	67	15A
0005432034942	8462	68	15C
0005432034948	8462	69	15E
0005432034944	8462	70	15D
0005433815387	8462	71	15F
0005432047551	8462	72	16A
0005433815385	8462	73	16B
0005435007028	8462	74	16C
0005432336039	8462	75	16F
0005434229039	8462	76	16E
0005432034949	8462	77	17A
0005433689911	8462	78	17C
0005434229197	8462	79	17D
0005434149589	8462	80	17F
0005432336035	8462	81	17E
0005434149624	8462	82	18A
0005434264890	8462	83	18C
0005434173478	8462	84	18B
0005435007024	8462	85	18E
0005434264870	8462	86	18D
0005434264860	8462	87	19C
0005434229238	8462	88	19B
0005434265036	8462	89	19D
0005434149594	8462	90	19E
0005434264969	8462	91	20B
0005432034957	8462	92	20A
0005435007029	8462	93	20C
0005432034955	8462	94	20E
0005434229239	8462	95	20F
0005434229145	8462	96	21A
0005435007040	8462	97	21C
0005434149593	8462	98	21B
0005432034936	8462	99	21D
0005435007043	8462	100	21E
0005432034943	8462	101	22A
0005434229072	8462	102	21F
0005434264841	8462	103	22B
0005434229221	8462	104	22C
0005435007036	8462	105	22E
0005434264888	8462	106	22D
0005434264978	8462	107	23A
0005432336032	8462	108	23C
0005434264924	8462	109	23B
0005435007031	8462	110	23D
0005433690927	8462	111	23E
0005432034941	8462	112	24A
0005434229190	8462	113	23F
0005432034958	8462	114	24B
0005434264925	8462	115	24C
0005433815384	8462	116	24D
0005435007025	8462	117	24F
0005434229139	8462	118	24E
0005434264900	8462	119	25B
0005432034946	8462	120	25A
0005434149626	8462	121	25D
0005432034951	8462	122	25C
0005435007032	8462	123	25E
0005434265014	8462	124	26A
0005434229146	8462	125	25F
0005432034940	8462	126	26B
0005434264817	8462	127	26C
0005434265005	8462	128	26E
0005434229185	8462	129	26D
0005435007023	8462	130	26F
0005432336040	8462	131	27C
0005434311220	8462	132	27B
0005434149590	8462	133	27D
0005432034947	8462	134	27F
0005434264812	8462	135	27E
0005432336033	8462	136	28A
0005433534498	8462	137	28B
0005432336038	8462	138	28C
0005434229040	8462	139	28E
0005435007027	8462	140	28D
0005435007037	8462	141	28F
0005434173491	8462	142	29A
0005435007021	8462	143	29C
0005434229180	8462	144	29B
0005432034953	8462	145	29F
0005434264960	8462	146	29E
0005432034938	8462	147	30A
0005434264843	8462	148	30C
0005432034945	8462	149	30B
0005434173483	8462	150	30D
0005434229153	8462	151	30E
0005432034956	8462	152	30F
0005432034961	8462	153	31A
0005434229192	8462	154	31B
0005434229196	8462	155	31D
0005434229131	8462	156	31C
0005435007026	8462	157	31F
0005432034935	8462	158	31E
0005433202371	12618	1	1A
0005434639220	12618	2	1D
0005434639060	12618	3	2A
0005434639023	12618	4	2B
0005434639024	12618	5	2C
0005433202365	12618	6	2D
0005434639088	12618	7	3B
0005433202368	12618	8	3C
0005433202362	12618	9	3D
0005434639155	12618	10	4A
0005433202366	12618	11	4B
0005433202360	12618	12	4C
0005434639117	12618	13	4D
0005434639062	12618	14	5B
0005433202367	12618	15	5C
0005434639186	12618	16	5D
0005433202363	12618	17	6A
0005434639175	12618	18	6B
0005433202358	12618	19	6C
0005434639061	12618	20	6D
0005434639004	12618	21	7A
0005433202373	12618	22	7B
0005434639174	12618	23	7D
0005433202369	12618	24	18A
0005434639154	12618	25	18B
0005434639084	12618	26	18C
0005434639077	12618	27	18D
0005434639187	12618	28	19B
0005433202370	12618	29	19D
0005434639165	12618	30	20A
0005433202359	12618	31	20C
0005433202372	12618	32	20B
0005434638971	12618	33	20D
0005434639185	12618	34	21A
0005434639116	12618	35	21C
0005433202361	12618	36	21B
0005433202364	12618	37	21D
0005434639037	12618	38	22A
0005434639078	12618	39	22B
0005434639028	12618	40	22C
0005434639104	12618	41	22D
0005433202180	23400	1	1A
0005433202179	23400	2	1B
0005433202143	23400	3	1C
0005432290632	23400	4	1D
0005434639297	23400	5	2A
0005433202158	23400	6	2B
0005434639307	23400	7	2C
0005434639290	23400	8	2D
0005433202246	23400	9	3A
0005433202234	23400	10	3B
0005434639294	23400	11	3C
0005434639303	23400	12	3D
0005433202250	23400	13	4A
0005434639296	23400	14	4B
0005434639308	23400	15	4C
0005434639291	23400	16	4D
0005434639299	23400	17	5A
0005433202222	23400	18	5B
0005434639309	23400	19	5C
0005434639301	23400	20	5D
0005433202247	23400	21	6A
0005433202242	23400	22	6B
0005433202249	23400	23	6C
0005434639300	23400	24	6D
0005432290631	23400	25	7A
0005434639306	23400	26	7C
0005433202112	23400	27	7B
0005433202275	23400	28	7D
0005432290629	23400	29	18A
0005432290630	23400	30	18B
0005433202224	23400	31	18C
0005434639295	23400	32	19A
0005433202244	23400	33	18D
0005433202252	23400	34	19B
0005433202251	23400	35	19C
0005433202297	23400	36	19D
0005434639289	23400	37	20A
0005433202200	23400	38	20B
0005434639298	23400	39	20C
0005434639304	23400	40	20D
0005433202235	23400	41	21A
0005433202296	23400	42	21C
0005433202199	23400	43	21B
0005433202243	23400	44	21D
0005433202233	23400	45	22A
0005434639302	23400	46	22B
0005434639305	23400	47	22C
0005434639292	23400	48	22D
0005434639293	23400	49	23A
0005434639288	23400	50	23B
0005432328263	21074	1	1A
0005432328369	21074	2	1C
0005432328317	21074	3	1D
0005432328137	21074	4	1F
0005432328313	21074	5	2A
0005432382744	21074	6	2C
0005432382968	21074	7	2D
0005432328259	21074	8	2F
0005432328003	21074	9	3A
0005432328117	21074	10	3C
0005432382828	21074	11	3D
0005432382804	21074	12	3F
0005432328283	21074	13	4A
0005432382882	21074	14	4C
0005432382816	21074	15	4D
0005432382829	21074	16	4E
0005432382771	21074	17	4F
0005432382958	21074	18	5A
0005432328440	21074	19	5C
0005432382824	21074	20	5D
0005432382845	21074	21	5E
0005432382883	21074	22	5F
0005432054303	21074	23	6A
0005432382814	21074	24	6C
0005432328268	21074	25	6D
0005432382791	21074	26	6E
0005432328175	21074	27	6F
0005432328500	21074	28	7A
0005432328221	21074	29	7C
0005432328002	21074	30	7D
0005432328419	21074	31	7E
0005432328402	21074	32	7F
0005432382773	21074	33	8A
0005432382762	21074	34	8C
0005432328339	21074	35	8D
0005432382820	21074	36	8E
0005432327944	21074	37	8F
0005432328135	21074	38	9A
0005432328267	21074	39	9C
0005432382915	21074	40	9D
0005432328376	21074	41	9E
0005432328252	21074	42	10A
0005432382699	21074	43	10C
0005432328174	21074	44	10E
0005432382817	21074	45	10D
0005432382763	21074	46	10F
0005432382772	21074	47	11A
0005432328234	21074	48	11C
0005432328284	21074	49	11D
0005432328241	21074	50	11E
0005432382743	21074	51	11F
0005432382761	21074	52	12A
0005432382769	21074	53	12C
0005432328162	21074	54	12D
0005432382620	21074	55	12E
0005432382832	21074	56	12F
0005432328253	21074	57	13A
0005432382967	21074	58	13C
0005432382983	21074	59	13E
0005432382770	21074	60	13F
0005432328336	21074	61	14A
0005432328242	21074	62	14C
0005432328289	21074	63	14E
0005432382813	21074	64	14F
0005432328340	21074	65	15A
0005432328385	21074	66	15C
0005432382669	21074	67	15D
0005432328409	21074	68	15E
0005432328235	21074	69	15F
0005432054304	21074	70	16A
0005432328410	21074	71	16C
0005432328333	21074	72	16D
0005432382768	21074	73	16E
0005432328436	21074	74	16F
0005432328206	21074	75	17A
0005432328222	21074	76	17C
0005432327997	21074	77	17D
0005432382956	21074	78	17E
0005432328136	21074	79	17F
0005432328260	21074	80	18A
0005432328406	21074	81	18C
0005432382745	21074	82	18D
0005432382884	21074	83	18E
0005432382634	21074	84	18F
0005432382957	21074	85	19A
0005432328266	21074	86	19C
0005432328321	21074	87	19D
0005432382825	21074	88	19E
0005432382846	21074	89	19F
0005432382914	21074	90	20A
0005432328418	21074	91	20C
0005432328219	21074	92	20D
0005432382830	21074	93	20E
0005432054305	21074	94	20F
0005432328645	31249	1	1A
0005432383153	31249	2	1C
0005432328688	31249	3	1D
0005432328679	31249	4	1F
0005432328654	31249	5	2A
0005432328678	31249	6	2C
0005432383146	31249	7	2D
0005432328682	31249	8	2F
0005432383155	31249	9	3A
0005432383131	31249	10	3C
0005432328672	31249	11	3D
0005432328677	31249	12	4A
0005432328656	31249	13	4C
0005432383159	31249	14	4D
0005432383149	31249	15	4E
0005432383148	31249	16	4F
0005432383134	31249	17	5A
0005432328667	31249	18	5D
0005432383160	31249	19	5C
0005432328662	31249	20	5F
0005432328643	31249	21	6A
0005432383133	31249	22	6C
0005432328648	31249	23	6D
0005432383143	31249	24	6E
0005432383141	31249	25	6F
0005432328653	31249	26	7A
0005432328646	31249	27	7C
0005432328659	31249	28	7D
0005432328668	31249	29	7E
0005432383150	31249	30	7F
0005432328647	31249	31	8A
0005432328650	31249	32	8C
0005432383154	31249	33	8D
0005432328657	31249	34	8E
0005432383166	31249	35	8F
0005432383162	31249	36	9A
0005432383129	31249	37	9C
0005432383138	31249	38	9D
0005432328660	31249	39	9E
0005432328649	31249	40	9F
0005432287185	31249	41	10A
0005432328655	31249	42	10C
0005432328665	31249	43	10D
0005432287186	31249	44	10E
0005432383130	31249	45	10F
0005432328673	31249	46	11A
0005432328669	31249	47	11C
0005432383144	31249	48	11D
0005432328642	31249	49	11E
0005432383158	31249	50	12A
0005432383164	31249	51	12C
0005432383140	31249	52	12D
0005432328676	31249	53	12E
0005432287184	31249	54	13A
0005432328652	31249	55	13C
0005432328675	31249	56	13D
0005432383161	31249	57	13E
0005432287187	31249	58	14A
0005432383152	31249	59	14C
0005432328663	31249	60	14E
0005432328651	31249	61	14F
0005432383157	31249	62	15A
0005432383156	31249	63	15C
0005432383147	31249	64	15D
0005432328681	31249	65	15E
0005432383163	31249	66	15F
0005432328684	31249	67	16A
0005432328686	31249	68	16C
0005432328687	31249	69	16D
0005432383151	31249	70	16E
0005432328644	31249	71	16F
0005432328661	31249	72	17C
0005432328666	31249	73	17D
0005432328685	31249	74	17E
0005432328658	31249	75	17F
0005432383132	31249	76	18A
0005432383137	31249	77	18C
0005432328670	31249	78	18D
0005432328680	31249	79	18E
0005432328683	31249	80	18F
0005432383142	31249	81	19A
0005432383135	31249	82	19C
0005432383139	31249	83	19D
0005432383165	31249	84	19E
0005432328671	31249	85	19F
0005432383145	31249	86	20A
0005432328674	31249	87	20D
0005432383136	31249	88	20F
0005432328664	31249	89	20E
0005432424417	13280	1	1A
0005432424387	13280	2	1C
0005432424402	13280	3	1D
0005432424401	13280	4	2C
0005432424415	13280	5	2D
0005432424378	13280	6	3C
0005432424406	13280	7	3D
0005432424393	13280	8	4C
0005432424390	13280	9	4E
0005432424399	13280	10	5A
0005432424395	13280	11	5C
0005432424384	13280	12	5E
0005432424414	13280	13	5F
0005432424377	13280	14	6A
0005432424382	13280	15	6C
0005432424420	13280	16	6D
0005432424391	13280	17	7A
0005432424413	13280	18	7C
0005432424394	13280	19	7E
0005432424409	13280	20	7F
0005432424397	13280	21	8A
0005432424421	13280	22	8D
0005432424398	13280	23	8E
0005432424403	13280	24	8F
0005432424416	13280	25	10A
0005432424400	13280	26	10D
0005432424411	13280	27	11A
0005432424389	13280	28	11F
0005432424392	13280	29	12D
0005432424412	13280	30	13A
0005432424419	13280	31	13D
0005432424418	13280	32	14C
0005432424396	13280	33	14E
0005432424386	13280	34	15A
0005432424407	13280	35	15C
0005432424381	13280	36	15D
0005432424408	13280	37	15E
0005432424410	13280	38	17C
0005432424404	13280	39	17F
0005432424383	13280	40	18A
0005432424385	13280	41	18D
0005432424388	13280	42	18E
0005432424405	13280	43	18F
0005432424376	13280	44	19C
0005432424380	13280	45	19E
0005432424379	13280	46	19F
0005432423943	30723	1	1A
0005432423938	30723	2	1F
0005432423964	30723	3	2C
0005432423962	30723	4	3A
0005432424025	30723	5	4C
0005432424054	30723	6	4F
0005432424040	30723	7	5F
0005432423968	30723	8	6C
0005432424005	30723	9	6E
0005432423901	30723	10	7C
0005432424011	30723	11	7E
0005432423977	30723	12	8C
0005432423981	30723	13	8D
0005432424039	30723	14	9A
0005432423958	30723	15	9D
0005432423909	30723	16	9E
0005432423900	30723	17	10A
0005432424006	30723	18	10E
0005432423902	30723	19	10F
0005432423994	30723	20	11C
0005432424022	30723	21	11F
0005432424026	30723	22	12D
0005432423978	30723	23	12F
0005432423957	30723	24	13D
0005432424031	30723	25	14C
0005432424047	30723	26	15A
0005432423983	30723	27	16A
0005432424008	30723	28	16D
0005432424046	30723	29	16E
0005432423963	30723	30	17D
0005432423955	30723	31	17E
0005432424055	30723	32	17F
0005432424013	30723	33	18C
0005432424053	30723	34	18D
0005432423903	30723	35	18E
0005432423982	30723	36	19C
0005432424030	30723	37	19E
0005432423896	30723	38	20A
0005432424019	30723	39	20D
0005432901471	9605	1	1A
0005434448316	9605	2	1C
0005432901535	9605	3	1D
0005432817456	9605	4	2A
0005432822205	9605	5	2C
0005432901536	9605	6	2D
0005432901456	9605	7	2F
0005432901398	9605	8	3C
0005432901537	9605	9	3F
0005432817457	9605	10	4A
0005432822199	9605	11	4C
0005434157436	9605	12	4D
0005434157405	9605	13	4E
0005432817454	9605	14	4F
0005434448315	9605	15	5A
0005432901397	9605	16	5C
0005434157425	9605	17	5D
0005432817472	9605	18	5E
0005432901457	9605	19	5F
0005432817480	9605	20	6C
0005434157427	9605	21	6A
0005432817462	9605	22	6D
0005432901530	9605	23	6E
0005434157426	9605	24	6F
0005432822200	9605	25	7A
0005432817467	9605	26	7F
0005432817481	9605	27	8A
0005432901441	9605	28	8D
0005432817459	9605	29	8E
0005432817460	9605	30	8F
0005434157400	9605	31	9A
0005432817473	9605	32	9C
0005432901433	9605	33	9D
0005432901531	9605	34	9E
0005432817475	9605	35	9F
0005432817464	9605	36	10A
0005434157410	9605	37	10C
0005432901440	9605	38	10E
0005434448314	9605	39	10F
0005434157370	9605	40	11A
0005432901420	9605	41	11C
0005432901473	9605	42	11D
0005432901393	9605	43	11E
0005432901472	9605	44	11F
0005432817476	9605	45	12A
0005432288984	9605	46	12D
0005432822201	9605	47	12E
0005432817468	9605	48	12F
0005432817469	9605	49	13A
0005432901492	9605	50	13C
0005432901434	9605	51	13D
0005432288987	9605	52	13E
0005432817474	9605	53	13F
0005434157413	9605	54	14A
0005434157424	9605	55	14C
0005432288985	9605	56	14D
0005434157411	9605	57	14E
0005432817463	9605	58	14F
0005432817470	9605	59	15A
0005434157443	9605	60	15C
0005432817465	9605	61	15D
0005434157404	9605	62	15E
0005432817478	9605	63	16A
0005432288986	9605	64	16C
0005432822202	9605	65	16D
0005432817466	9605	66	16E
0005434157369	9605	67	16F
0005432817461	9605	68	17A
0005432817455	9605	69	17C
0005432817483	9605	70	17E
0005432817471	9605	71	18C
0005432822206	9605	72	18D
0005432901409	9605	73	18F
0005432817477	9605	74	19C
0005432822203	9605	75	20A
0005432817458	9605	76	20C
0005432822204	9605	77	20D
0005432817479	9605	78	20E
0005432817482	9605	79	20F
0005432901615	29005	1	1C
0005432817259	29005	2	2C
0005432817272	29005	3	2F
0005434157482	29005	4	3A
0005432901613	29005	5	3C
0005432901608	29005	6	4A
0005432901602	29005	7	4C
0005432817233	29005	8	4D
0005434157477	29005	9	4E
0005432901612	29005	10	5A
0005432817166	29005	11	5C
0005432817262	29005	12	5D
0005432817179	29005	13	5E
0005432901611	29005	14	6A
0005434157479	29005	15	6D
0005432817216	29005	16	6F
0005434448270	29005	17	7A
0005432817326	29005	18	7C
0005432901601	29005	19	7E
0005432817158	29005	20	7F
0005432901606	29005	21	8A
0005432901616	29005	22	8C
0005432901614	29005	23	8D
0005432817053	29005	24	9A
0005432822141	29005	25	9D
0005432817249	29005	26	9E
0005432817095	29005	27	9F
0005434186196	29005	28	10A
0005432817255	29005	29	10C
0005432817298	29005	30	10E
0005434157483	29005	31	10F
0005432901605	29005	32	11A
0005432822131	29005	33	11D
0005432002076	29005	34	11E
0005432817094	29005	35	12A
0005432822150	29005	36	12D
0005432002077	29005	37	13A
0005434186197	29005	38	13C
0005432817054	29005	39	13D
0005432901610	29005	40	13E
0005432817348	29005	41	14A
0005432817271	29005	42	14E
0005434157476	29005	43	14F
0005432901604	29005	44	15A
0005432901609	29005	45	15C
0005432817347	29005	46	15E
0005432817099	29005	47	16C
0005432817159	29005	48	16F
0005434157475	29005	49	17A
0005434157480	29005	50	17C
0005432901603	29005	51	17D
0005434448277	29005	52	17E
0005432901599	29005	53	17F
0005434157478	29005	54	18E
0005432817160	29005	55	18F
0005432002075	29005	56	19A
0005432817346	29005	57	19C
0005432002078	29005	58	19D
0005432901600	29005	59	19E
0005432901607	29005	60	19F
0005434157481	29005	61	20A
0005432817232	29005	62	20C
0005432817199	29005	63	20D
0005432817098	29005	64	20E
0005435841089	15063	1	1B
0005432613862	15063	2	2A
0005435841091	15063	3	2B
0005432611711	15063	4	3A
0005432613860	15063	5	4A
0005432611710	15063	6	3B
0005432611712	15063	7	4B
0005432613863	15063	8	5A
0005432613861	15063	9	5B
0005432613864	15063	10	6B
0005432611689	31605	1	1A
0005432607519	31605	2	1B
0005432611695	31605	3	2A
0005432607542	31605	4	2B
0005432611663	31605	5	3A
0005432607541	31605	6	3B
0005432607512	31605	7	4A
0005432607531	31605	8	4B
0005432611656	31605	9	5A
0005432607530	31605	10	5B
0005432611682	31605	11	6A
0005435841821	31605	12	6B
0005433569039	11848	1	1C
0005432947975	11848	2	1A
0005433569036	11848	3	1D
0005432948195	11848	4	2C
0005432948112	11848	5	2A
0005432947976	11848	6	1F
0005432947834	11848	7	2F
0005432948114	11848	8	2D
0005432948074	11848	9	3A
0005432947909	11848	10	3C
0005432948184	11848	11	4A
0005432947835	11848	12	3F
0005432948002	11848	13	4F
0005433569003	11848	14	4D
0005433569048	11848	15	5C
0005432948185	11848	16	5A
0005432947841	11848	17	5F
0005433569007	11848	18	5D
0005432948037	11848	19	6D
0005432947836	11848	20	6C
0005433569035	11848	21	6F
0005432948036	11848	22	7A
0005433569011	11848	23	7C
0005432948038	11848	24	7E
0005432948041	11848	25	7D
0005433569020	11848	26	8A
0005433569018	11848	27	8C
0005432948138	11848	28	8B
0005432948075	11848	29	8E
0005433569047	11848	30	8D
0005433569019	11848	31	9A
0005433569006	11848	32	9D
0005433569008	11848	33	9C
0005433569013	11848	34	9B
0005433569025	11848	35	9F
0005432948077	11848	36	10A
0005433569044	11848	37	10E
0005433569042	11848	38	10D
0005433569009	11848	39	11A
0005433568997	11848	40	10F
0005433569029	11848	41	11B
0005433568998	11848	42	11D
0005432948134	11848	43	11C
0005432947993	11848	44	11F
0005433569001	11848	45	11E
0005432948048	11848	46	12B
0005432948051	11848	47	12A
0005433569023	11848	48	12D
0005433569034	11848	49	12C
0005433569014	11848	50	12E
0005432947912	11848	51	13A
0005433569022	11848	52	13C
0005432948113	11848	53	13B
0005433568994	11848	54	13E
0005433569024	11848	55	13D
0005432948047	11848	56	14A
0005432948058	11848	57	13F
0005433569021	11848	58	14B
0005432947873	11848	59	14D
0005432948097	11848	60	14C
0005433569041	11848	61	14F
0005433569038	11848	62	14E
0005432948101	11848	63	15B
0005432948139	11848	64	15C
0005433569037	11848	65	15E
0005432947874	11848	66	15D
0005433569010	11848	67	16A
0005432948078	11848	68	15F
0005433569015	11848	69	16C
0005433569016	11848	70	16B
0005433569012	11848	71	16E
0005432948141	11848	72	16D
0005432947992	11848	73	17A
0005433568996	11848	74	16F
0005433569017	11848	75	17B
0005433569000	11848	76	17D
0005432947994	11848	77	17C
0005433569027	11848	78	17F
0005432947946	11848	79	18B
0005433569033	11848	80	18A
0005433568995	11848	81	18C
0005433569026	11848	82	18E
0005433569005	11848	83	18D
0005433568999	11848	84	19A
0005432948034	11848	85	18F
0005433569004	11848	86	19C
0005433569030	11848	87	19B
0005433569045	11848	88	19D
0005433569046	11848	89	20A
0005432948063	11848	90	19F
0005433569002	11848	91	19E
0005433569031	11848	92	20B
0005433569040	11848	93	20D
0005432948198	11848	94	20F
0005433569028	11848	95	20E
0005432948140	11848	96	21D
0005433569043	11848	97	21C
0005433569032	11848	98	21B
0005432948135	11848	99	21E
0005433568557	25318	1	1C
0005433568382	25318	2	1A
0005433568254	25318	3	1F
0005433568363	25318	4	1D
0005432948507	25318	5	2C
0005433568502	25318	6	2A
0005433568545	25318	7	2D
0005432948490	25318	8	3A
0005433568190	25318	9	2F
0005432948480	25318	10	3D
0005433568453	25318	11	3C
0005432948477	25318	12	4A
0005432948472	25318	13	3F
0005432948478	25318	14	4C
0005433568322	25318	15	4F
0005433568219	25318	16	5D
0005432948505	25318	17	5C
0005433568258	25318	18	5A
0005433568617	25318	19	5F
0005433568519	25318	20	6B
0005433568465	25318	21	6A
0005432948508	25318	22	6D
0005432948473	25318	23	6C
0005432948511	25318	24	6E
0005433568670	25318	25	7A
0005433568498	25318	26	6F
0005432948488	25318	27	7C
0005433568242	25318	28	7B
0005433568503	25318	29	7D
0005433568539	25318	30	8A
0005433568493	25318	31	7F
0005433568536	25318	32	7E
0005433568227	25318	33	8B
0005433568559	25318	34	8D
0005432948510	25318	35	8F
0005433568531	25318	36	8E
0005433568558	25318	37	9B
0005432948503	25318	38	9A
0005432948494	25318	39	9C
0005433568490	25318	40	9F
0005432948502	25318	41	9E
0005432948481	25318	42	9D
0005433568087	25318	43	10A
0005432948475	25318	44	10C
0005433568438	25318	45	10D
0005433568383	25318	46	11A
0005433568268	25318	47	11D
0005433568302	25318	48	11C
0005432948495	25318	49	11F
0005433568530	25318	50	11E
0005433568518	25318	51	12B
0005432948487	25318	52	12A
0005432948501	25318	53	12D
0005432948497	25318	54	12C
0005432948491	25318	55	13A
0005433568467	25318	56	12F
0005432948498	25318	57	13C
0005432948499	25318	58	13B
0005432948512	25318	59	13E
0005432948476	25318	60	13F
0005433568537	25318	61	14B
0005432948500	25318	62	14A
0005432948492	25318	63	14C
0005433568488	25318	64	14F
0005433568532	25318	65	14E
0005432948493	25318	66	15B
0005433568466	25318	67	15A
0005433568325	25318	68	15C
0005433568604	25318	69	15D
0005433568257	25318	70	16A
0005432948486	25318	71	15F
0005432948474	25318	72	16C
0005432948482	25318	73	16D
0005432948504	25318	74	16F
0005433568603	25318	75	16E
0005433568495	25318	76	17B
0005433568432	25318	77	17A
0005432948509	25318	78	17D
0005433568550	25318	79	17C
0005432948484	25318	80	17F
0005433568425	25318	81	17E
0005433568492	25318	82	18A
0005433568451	25318	83	18C
0005433568494	25318	84	18E
0005432948485	25318	85	18D
0005432948479	25318	86	19A
0005432948506	25318	87	18F
0005432948513	25318	88	19C
0005433568191	25318	89	19B
0005433568151	25318	90	19E
0005433568414	25318	91	19D
0005433568546	25318	92	19F
0005433568346	25318	93	20B
0005433568228	25318	94	20A
0005433568415	25318	95	20C
0005433568347	25318	96	20F
0005432948483	25318	97	20E
0005432948496	25318	98	21B
0005433568452	25318	99	21A
0005432948489	25318	100	21C
0005433568666	25318	101	21E
0005433568520	25318	102	21D
0005433568454	25318	103	21F
0005433808372	30833	1	2C
0005433808367	30833	2	3A
0005433808374	30833	3	3C
0005433808366	30833	4	4F
0005433808364	30833	5	5D
0005432430808	30833	6	5C
0005433812898	30833	7	5A
0005432430830	30833	8	7C
0005432430820	30833	9	7E
0005432430819	30833	10	8A
0005434026672	30833	11	8D
0005433812897	30833	12	10A
0005433808376	30833	13	10E
0005434026682	30833	14	10D
0005433808370	30833	15	11B
0005433812893	30833	16	12B
0005432430809	30833	17	12C
0005434026681	30833	18	13A
0005433812892	30833	19	12F
0005432430833	30833	20	14A
0005433808375	30833	21	13E
0005433808371	30833	22	14F
0005434026673	30833	23	15B
0005432430821	30833	24	15C
0005433812895	30833	25	15F
0005433808365	30833	26	16E
0005433812894	30833	27	17D
0005433812896	30833	28	17E
0005433808369	30833	29	18B
0005433808373	30833	30	18A
0005433808368	30833	31	18D
0005434026684	30833	32	18C
0005433808377	30833	33	19C
0005433808378	30833	34	19B
0005432430826	30833	35	20D
0005435340168	5411	1	1A
0005435340097	5411	2	2A
0005434654696	5411	3	2D
0005435340186	5411	4	2F
0005434654683	5411	5	3A
0005434654670	5411	6	3F
0005435555352	5411	7	5A
0005434654680	5411	8	5C
0005434656556	5411	9	5D
0005434654695	5411	10	5E
0005434654682	5411	11	5F
0005434654677	5411	12	6A
0005435340115	5411	13	6C
0005434654681	5411	14	7A
0005434654684	5411	15	7C
0005434654676	5411	16	7D
0005434654689	5411	17	8C
0005434654673	5411	18	8D
0005434654694	5411	19	8E
0005435340160	5411	20	8F
0005434654679	5411	21	9A
0005434654671	5411	22	9F
0005434654686	5411	23	10C
0005432114205	5411	24	10E
0005435555353	5411	25	11A
0005432114203	5411	26	11C
0005435340116	5411	27	11E
0005434654697	5411	28	11F
0005435340213	5411	29	12F
0005434654687	5411	30	13E
0005435340078	5411	31	13F
0005435340092	5411	32	14A
0005435340117	5411	33	14C
0005434654688	5411	34	15A
0005434654672	5411	35	15E
0005434654690	5411	36	15F
0005434654674	5411	37	16A
0005432114204	5411	38	16C
0005432114201	5411	39	16D
0005434656557	5411	40	16F
0005432114202	5411	41	17D
0005434654685	5411	42	17E
0005434654693	5411	43	18C
0005434654678	5411	44	18D
0005434656555	5411	45	18E
0005435340046	5411	46	18F
0005434654691	5411	47	19A
0005434654668	5411	48	19D
0005434654669	5411	49	19E
0005435340098	5411	50	19F
0005435555351	5411	51	20A
0005434654675	5411	52	20C
0005434654692	5411	53	20F
0005435340266	12529	1	1C
0005434654347	12529	2	1D
0005434654489	12529	3	2F
0005434654517	12529	4	3F
0005434654531	12529	5	4A
0005434654464	12529	6	4C
0005434654523	12529	7	4E
0005434656544	12529	8	5A
0005435340260	12529	9	5C
0005434654396	12529	10	5D
0005434654283	12529	11	5F
0005434654343	12529	12	6A
0005435340258	12529	13	6C
0005435340262	12529	14	6E
0005434656533	12529	15	6F
0005435340269	12529	16	8A
0005434654407	12529	17	8F
0005434654271	12529	18	9A
0005434656532	12529	19	10E
0005434654409	12529	20	10F
0005435340265	12529	21	11C
0005434654462	12529	22	11E
0005434654461	12529	23	11F
0005435555370	12529	24	12D
0005434654313	12529	25	13C
0005434654359	12529	26	13D
0005434654422	12529	27	14A
0005434654342	12529	28	14E
0005434654465	12529	29	14F
0005435340261	12529	30	15D
0005435340257	12529	31	15E
0005435340267	12529	32	15F
0005435340254	12529	33	16A
0005434654477	12529	34	16C
0005434654382	12529	35	16E
0005435340263	12529	36	16F
0005435340259	12529	37	17A
0005435340268	12529	38	17D
0005434654255	12529	39	17E
0005434654484	12529	40	17F
0005435555371	12529	41	18A
0005434654468	12529	42	18C
0005434654431	12529	43	18E
0005435340264	12529	44	19A
0005434654483	12529	45	19C
0005434654478	12529	46	19E
0005435340255	12529	47	20A
0005434654270	12529	48	20C
0005434654377	12529	49	20D
0005435340256	12529	50	20F
0005433715950	7439	1	1C
0005433715943	7439	2	1D
0005433715944	7439	3	2A
0005433715968	7439	4	1F
0005433719137	7439	5	2D
0005433715948	7439	6	2F
0005433715947	7439	7	3A
0005435266099	7439	8	3D
0005435266104	7439	9	3F
0005433690926	7439	10	4B
0005433715977	7439	11	4C
0005433715954	7439	12	4E
0005433719139	7439	13	4F
0005433722218	7439	14	5A
0005432078106	7439	15	5C
0005433715957	7439	16	5B
0005433715975	7439	17	5D
0005433715942	7439	18	5E
0005433715949	7439	19	6A
0005433719136	7439	20	6B
0005433715965	7439	21	6C
0005433722217	7439	22	6D
0005433715972	7439	23	6E
0005433715958	7439	24	6F
0005435266101	7439	25	7B
0005433715941	7439	26	7A
0005435266090	7439	27	7C
0005433722219	7439	28	7E
0005433715974	7439	29	8A
0005433715945	7439	30	8D
0005433715952	7439	31	8F
0005433722220	7439	32	9B
0005433715971	7439	33	9C
0005433715955	7439	34	9D
0005433715986	7439	35	9E
0005433715985	7439	36	10E
0005433715982	7439	37	11A
0005433715939	7439	38	11B
0005432428894	7439	39	11D
0005433689909	7439	40	11C
0005433715979	7439	41	11E
0005433715961	7439	42	12A
0005433715969	7439	43	12C
0005433715936	7439	44	12E
0005433715981	7439	45	12D
0005435266092	7439	46	13A
0005432428903	7439	47	13B
0005433715962	7439	48	13D
0005433715976	7439	49	13F
0005432078107	7439	50	13E
0005433719138	7439	51	14A
0005433715940	7439	52	14D
0005432078109	7439	53	14C
0005435266100	7439	54	15C
0005433715967	7439	55	15B
0005435266095	7439	56	15D
0005433715978	7439	57	16B
0005433715980	7439	58	16D
0005433715984	7439	59	16E
0005432078108	7439	60	17A
0005433656668	7439	61	16F
0005433690925	7439	62	17B
0005435266103	7439	63	17E
0005433715946	7439	64	17F
0005433656669	7439	65	18B
0005433715951	7439	66	18A
0005433715938	7439	67	18D
0005433689908	7439	68	18C
0005433715983	7439	69	19A
0005433689910	7439	70	18F
0005433722224	7439	71	19E
0005433715964	7439	72	19D
0005433715937	7439	73	20C
0005433656667	7439	74	20E
0005433715973	7439	75	20D
0005433715956	7439	76	20F
0005433715960	7439	77	21B
0005433715959	7439	78	21A
0005433722222	7439	79	21D
0005433722223	7439	80	21E
0005433715963	7439	81	22A
0005433688809	7439	82	21F
0005435266091	7439	83	22C
0005433715953	7439	84	22E
0005433688808	7439	85	22D
0005433715966	7439	86	23B
0005433715970	7439	87	23D
0005433722221	7439	88	23E
0005433722136	29220	1	1C
0005433715588	29220	2	1D
0005433715566	29220	3	2A
0005433715477	29220	4	1F
0005433685504	29220	5	3A
0005432428929	29220	6	2F
0005433715590	29220	7	3D
0005433715326	29220	8	3C
0005433715698	29220	9	4A
0005433715365	29220	10	4C
0005433715452	29220	11	4B
0005433715556	29220	12	4D
0005433715493	29220	13	5A
0005433722153	29220	14	5D
0005433656620	29220	15	5C
0005433715485	29220	16	6A
0005433715453	29220	17	6E
0005433715518	29220	18	7A
0005433715398	29220	19	6F
0005433715600	29220	20	7B
0005432006762	29220	21	7C
0005433715550	29220	22	7D
0005433715551	29220	23	8B
0005433715603	29220	24	8C
0005433715524	29220	25	8E
0005433715624	29220	26	8D
0005433715657	29220	27	8F
0005433656638	29220	28	9C
0005433715534	29220	29	9B
0005433715564	29220	30	9E
0005433715592	29220	31	9F
0005433715517	29220	32	10B
0005433715567	29220	33	10D
0005435266147	29220	34	10E
0005433722149	29220	35	11B
0005433715598	29220	36	11D
0005433715220	29220	37	11F
0005432006760	29220	38	12B
0005433715674	29220	39	12A
0005433715601	29220	40	12C
0005433715593	29220	41	12D
0005432006763	29220	42	12F
0005433715677	29220	43	13C
0005433715529	29220	44	13B
0005433715427	29220	45	13F
0005433715656	29220	46	14B
0005433715479	29220	47	14D
0005433715604	29220	48	14E
0005433715425	29220	49	15B
0005433722150	29220	50	15D
0005433719124	29220	51	15F
0005433715305	29220	52	15E
0005432428928	29220	53	16A
0005433715661	29220	54	16D
0005433715771	29220	55	16E
0005433722137	29220	56	17D
0005433715304	29220	57	17C
0005435266148	29220	58	17E
0005432428927	29220	59	18B
0005433715446	29220	60	18C
0005433685503	29220	61	18D
0005433715393	29220	62	19B
0005433715678	29220	63	19C
0005433715699	29220	64	19F
0005433715392	29220	65	20A
0005433715486	29220	66	20B
0005433715655	29220	67	20D
0005432006761	29220	68	20E
0005433715478	29220	69	20F
0005433715559	29220	70	21B
0005433656642	29220	71	21A
0005433715632	29220	72	21C
0005433715589	29220	73	21D
0005433722152	29220	74	21E
0005433722123	29220	75	22A
0005433715704	29220	76	22D
0005433715539	29220	77	22E
0005432006759	29220	78	23B
0005433715602	29220	79	23A
0005433715535	29220	80	23C
0005433719115	29220	81	23D
0005433715428	29220	82	23F
0005433656633	29220	83	23E
0005434095273	8692	1	1F
0005434184647	8692	2	2D
0005434184648	8692	3	3A
0005434095280	8692	4	4E
0005434182109	8692	5	4F
0005434095279	8692	6	5C
0005434095270	8692	7	5D
0005434095268	8692	8	6D
0005434182083	8692	9	7C
0005434182046	8692	10	7F
0005434182047	8692	11	8E
0005434095275	8692	12	9E
0005434182140	8692	13	10F
0005434182062	8692	14	11D
0005434095274	8692	15	12D
0005434095276	8692	16	12F
0005434095269	8692	17	14A
0005434182064	8692	18	14C
0005434095272	8692	19	14E
0005434182086	8692	20	14F
0005434182063	8692	21	15A
0005434095267	8692	22	15C
0005434182082	8692	23	15F
0005434095278	8692	24	16E
0005434182117	8692	25	17C
0005434182041	8692	26	17E
0005434095277	8692	27	18D
0005434095266	8692	28	18F
0005434182110	8692	29	19A
0005434095271	8692	30	20A
0005434184662	11623	1	1A
0005434095157	11623	2	2A
0005434095181	11623	3	3A
0005434182184	11623	4	3F
0005434095183	11623	5	4A
0005434182182	11623	6	4D
0005434182186	11623	7	4E
0005434095137	11623	8	5A
0005434095133	11623	9	5C
0005434095166	11623	10	6A
0005434095138	11623	11	6D
0005434182187	11623	12	6F
0005434182188	11623	13	7A
0005434182179	11623	14	8A
0005434143715	11623	15	8C
0005434182185	11623	16	8F
0005434095119	11623	17	9D
0005434095165	11623	18	11A
0005434095117	11623	19	11D
0005434326085	11623	20	11F
0005434182178	11623	21	13C
0005434183577	11623	22	14A
0005434095109	11623	23	14C
0005434182181	11623	24	14E
0005434095118	11623	25	15D
0005434143716	11623	26	15E
0005434095121	11623	27	15F
0005434182183	11623	28	17C
0005434095142	11623	29	17F
0005434095143	11623	30	19D
0005434182180	11623	31	19E
0005434183578	11623	32	19F
0005434095169	11623	33	20A
0005434182177	11623	34	20C
0005434095141	11623	35	20D
0005434184663	11623	36	20F
0005435732323	1418	1	1A
0005433397333	1418	2	1C
0005433456969	1418	3	1D
0005433397777	1418	4	2A
0005435732326	1418	5	2C
0005433397596	1418	6	3A
0005433397609	1418	7	3C
0005433397612	1418	8	3D
0005433397730	1418	9	3F
0005433397532	1418	10	4C
0005433397621	1418	11	4D
0005433397714	1418	12	4E
0005433397655	1418	13	4F
0005433397622	1418	14	5A
0005433397639	1418	15	5C
0005433397667	1418	16	5E
0005433397418	1418	17	5D
0005432906513	1418	18	6A
0005432297277	1418	19	6D
0005435732325	1418	20	6E
0005433397417	1418	21	6F
0005433397605	1418	22	7C
0005433397709	1418	23	7D
0005433397577	1418	24	8A
0005435732317	1418	25	8D
0005433397633	1418	26	8E
0005433397746	1418	27	9A
0005433397720	1418	28	9C
0005433397733	1418	29	9D
0005433397663	1418	30	9E
0005433397719	1418	31	10A
0005433397628	1418	32	10C
0005433397481	1418	33	10D
0005433456970	1418	34	10E
0005435732322	1418	35	11A
0005433397668	1418	36	11C
0005435732321	1418	37	11D
0005435732324	1418	38	11E
0005433397695	1418	39	11F
0005433397527	1418	40	12A
0005433397776	1418	41	12C
0005433397632	1418	42	12D
0005433397744	1418	43	12E
0005433397495	1418	44	12F
0005433397642	1418	45	13C
0005433397512	1418	46	13D
0005433397745	1418	47	13F
0005433397528	1418	48	14A
0005433397669	1418	49	14C
0005433397729	1418	50	14D
0005432906514	1418	51	14E
0005432906519	1418	52	15A
0005433397775	1418	53	15C
0005433397500	1418	54	15D
0005433397734	1418	55	15E
0005433397539	1418	56	15F
0005433397794	1418	57	16D
0005435732320	1418	58	16E
0005433397826	1418	59	16F
0005433397447	1418	60	17A
0005433397580	1418	61	17F
0005433397600	1418	62	18A
0005435732318	1418	63	18D
0005433397818	1418	64	18E
0005433397823	1418	65	18F
0005433397540	1418	66	19A
0005435732319	1418	67	19D
0005432297276	1418	68	19E
0005433397643	1418	69	19F
0005432906515	1418	70	20A
0005433397822	1418	71	20C
0005433397594	1418	72	20E
0005433397788	1418	73	20F
0005433398058	19235	1	1C
0005432906536	19235	2	2A
0005433398039	19235	3	2D
0005435732174	19235	4	3A
0005433398024	19235	5	3C
0005433398069	19235	6	3D
0005435732203	19235	7	3F
0005433398070	19235	8	4A
0005433398028	19235	9	4C
0005433398042	19235	10	4D
0005433398036	19235	11	4E
0005433398041	19235	12	4F
0005435732219	19235	13	5C
0005433456924	19235	14	5D
0005433398063	19235	15	5E
0005433398052	19235	16	6A
0005433398073	19235	17	6D
0005433456927	19235	18	6E
0005435732217	19235	19	6F
0005433398072	19235	20	7A
0005435732235	19235	21	7D
0005433398045	19235	22	7E
0005433398068	19235	23	7F
0005433456956	19235	24	8A
0005435732202	19235	25	8C
0005433398067	19235	26	8D
0005433398026	19235	27	8E
0005433398032	19235	28	9C
0005433456926	19235	29	9E
0005433398040	19235	30	10A
0005433398034	19235	31	10C
0005435732287	19235	32	10D
0005433456925	19235	33	10F
0005433398043	19235	34	11C
0005433398074	19235	35	11D
0005433398059	19235	36	11E
0005433398061	19235	37	11F
0005433398064	19235	38	12C
0005433398066	19235	39	12D
0005433398062	19235	40	12E
0005433398038	19235	41	12F
0005433398060	19235	42	13A
0005433398057	19235	43	13C
0005435732288	19235	44	13D
0005433398048	19235	45	13E
0005433456938	19235	46	13F
0005433398030	19235	47	14A
0005432906534	19235	48	14D
0005433398051	19235	49	14E
0005433398037	19235	50	15A
0005433398071	19235	51	15C
0005433398049	19235	52	15D
0005433398035	19235	53	15E
0005433398031	19235	54	15F
0005433398046	19235	55	16A
0005433398050	19235	56	16C
0005433398025	19235	57	16E
0005433398055	19235	58	16F
0005435732180	19235	59	17C
0005432906535	19235	60	17E
0005433398033	19235	61	17F
0005435732173	19235	62	18A
0005433398065	19235	63	18C
0005433398047	19235	64	18F
0005433398029	19235	65	19A
0005433398053	19235	66	19D
0005433398044	19235	67	19E
0005433398054	19235	68	20A
0005433398027	19235	69	20D
0005433398056	19235	70	20E
0005434443543	17351	1	1C
0005434443566	17351	2	1D
0005434443558	17351	3	4A
0005434443539	17351	4	5A
0005434443545	17351	5	6C
0005434443623	17351	6	6D
0005434443565	17351	7	7B
0005434443525	17351	8	18A
0005434443546	17351	9	19B
0005434443582	17351	10	21B
0005434443585	17351	11	22B
0005434443547	17351	12	22C
0005434443690	20555	1	1B
0005434443697	20555	2	1C
0005434443692	20555	3	2A
0005434443693	20555	4	2D
0005434443701	20555	5	3A
0005434443699	20555	6	4B
0005434443689	20555	7	4C
0005434443702	20555	8	5B
0005434443700	20555	9	5C
0005434443696	20555	10	6D
0005434443688	20555	11	18A
0005434443695	20555	12	19B
0005434443704	20555	13	20C
0005434443703	20555	14	20D
0005434443694	20555	15	21A
0005434443691	20555	16	22C
0005434443698	20555	17	23A
0005434954607	7266	1	1A
0005435377553	7266	2	3B
0005434954609	7266	3	4B
0005434954608	7266	4	5A
0005434954606	7266	5	5B
0005434954581	28312	1	1A
0005434954574	28312	2	1B
0005435377580	28312	3	4A
0005435377579	28312	4	4B
0005434954575	28312	5	5B
0005434351687	4509	1	22C
0005435893610	4509	2	1A
0005434351689	4509	3	1C
0005434351698	4509	4	1D
0005434351686	4509	5	2A
0005434183562	4509	6	2B
0005435893587	4509	7	3A
0005434351694	4509	8	3B
0005434351692	4509	9	3C
0005434351691	4509	10	3D
0005434326271	4509	11	4A
0005434351693	4509	12	4B
0005435893576	4509	13	4C
0005434351688	4509	14	5C
0005435893578	4509	15	6B
0005434351699	4509	16	7A
0005435893575	4509	17	7B
0005434183561	4509	18	7D
0005434351697	4509	19	19D
0005434351690	4509	20	20A
0005434326270	4509	21	20D
0005434351695	4509	22	21A
0005434351696	4509	23	22A
0005435893581	4509	24	22B
0005435893627	29675	1	6A
0005434351558	29675	2	1D
0005435893633	29675	3	19A
0005434351579	29675	4	19B
0005434351557	29675	5	2B
0005434351582	29675	6	1B
0005434351580	29675	7	5A
0005435893632	29675	8	4C
0005435893628	29675	9	19C
0005435893629	29675	10	20D
0005435893631	29675	11	21A
0005434351574	29675	12	4D
0005435893630	29675	13	4B
0005434351611	29675	14	21B
0005434351610	29675	15	21D
0005435893634	29675	16	22B
0005435893635	29675	17	22C
0005434351575	29675	18	22D
0005434351620	29675	19	2A
0005434351640	29675	20	18C
0005434351619	29675	21	7A
0005434351559	29675	22	7B
0005433341911	1072	1	5G
0005433341779	1072	2	9B
0005433341481	1072	3	11D
0005435545738	1072	4	11B
0005433462746	1072	5	11G
0005433341617	1072	6	12A
0005433342372	1072	7	12D
0005433158112	1072	8	12B
0005433269675	1072	9	12G
0005433342493	1072	10	12F
0005435545737	1072	11	12H
0005433342219	1072	12	13A
0005433341622	1072	13	13D
0005433341933	1072	14	13E
0005433342204	1072	15	14B
0005434445248	1072	16	14E
0005433462745	1072	17	14G
0005433342326	1072	18	14F
0005433342475	1072	19	15A
0005433341916	1072	20	14H
0005433341882	1072	21	15B
0005433342118	1072	22	15D
0005433341868	1072	23	15H
0005433341932	1072	24	15G
0005433342105	1072	25	16D
0005433341930	1072	26	16B
0005433341923	1072	27	16F
0005433341999	1072	28	16E
0005433342238	1072	29	16G
0005433341894	1072	30	16H
0005433158113	1072	31	17B
0005433463899	1072	32	17A
0005433342298	1072	33	17D
0005433342265	1072	34	17G
0005433342142	1072	35	17F
0005433342405	1072	36	17H
0005433462747	1072	37	18D
0005433341978	1072	38	18E
0005433342192	1072	39	18G
0005433342327	1072	40	18F
0005433342374	1072	41	19B
0005435545736	1072	42	19E
0005433342297	1072	43	19F
0005433342274	1072	44	19G
0005435092070	1072	45	20A
0005433341931	1072	46	20B
0005433463901	1072	47	20D
0005433158114	1072	48	20F
0005433342526	1072	49	20H
0005433342718	1072	50	20G
0005433342209	1072	51	21A
0005433341980	1072	52	21D
0005433342016	1072	53	21F
0005433342364	1072	54	21H
0005433342273	1072	55	22B
0005433341979	1072	56	22A
0005433342218	1072	57	22D
0005433342000	1072	58	22F
0005433342440	1072	59	22E
0005432293207	1072	60	22G
0005433341913	1072	61	23D
0005433341614	1072	62	23F
0005433341621	1072	63	23E
0005432293208	1072	64	23G
0005433342106	1072	65	24D
0005433342240	1072	66	24H
0005433341952	1072	67	25D
0005433342197	1072	68	25F
0005433342369	1072	69	25E
0005433342459	1072	70	27E
0005433342375	1072	71	27D
0005432293209	1072	72	27G
0005433159290	1072	73	28A
0005433342514	1072	74	27H
0005435092076	1072	75	28D
0005433342210	1072	76	28F
0005433342124	1072	77	28H
0005433342196	1072	78	28G
0005433158118	1072	79	29A
0005433341809	1072	80	29D
0005433342155	1072	81	29B
0005434446519	1072	82	29F
0005433341799	1072	83	29E
0005433341902	1072	84	30B
0005433342373	1072	85	30A
0005433341973	1072	86	30D
0005433342077	1072	87	30F
0005433342296	1072	88	30E
0005433341944	1072	89	30G
0005433342527	1072	90	30H
0005433341940	1072	91	31D
0005433342237	1072	92	31G
0005435545740	1072	93	32B
0005433342229	1072	94	32D
0005433341613	1072	95	32F
0005433342378	1072	96	33D
0005433342370	1072	97	33E
0005433341883	1072	98	33H
0005433342260	1072	99	34A
0005433342239	1072	100	34D
0005433342534	1072	101	34E
0005433341912	1072	102	35A
0005433342563	1072	103	34H
0005435092073	1072	104	35B
0005433341881	1072	105	35E
0005433342232	1072	106	35F
0005435092072	1072	107	35H
0005433159281	1072	108	36B
0005433342412	1072	109	36E
0005433341914	1072	110	36D
0005433342213	1072	111	36F
0005433342432	1072	112	36G
0005433342181	1072	113	37A
0005433342515	1072	114	36H
0005433462748	1072	115	37B
0005433342023	1072	116	37D
0005435092075	1072	117	37F
0005433342330	1072	118	37G
0005433342109	1072	119	37H
0005433342413	1072	120	38B
0005433342058	1072	121	38F
0005433342165	1072	122	38E
0005433341480	1072	123	38D
0005433342088	1072	124	38H
0005433341616	1072	125	39D
0005435092068	1072	126	39F
0005433463900	1072	127	35G
0005435092069	1072	128	1A
0005435092071	1072	129	1C
0005433341922	1072	130	1B
0005434445247	1072	131	1F
0005433159298	1072	132	1H
0005433342174	1072	133	2B
0005433342230	1072	134	2F
0005433342180	1072	135	2C
0005433342381	1072	136	2H
0005433342361	1072	137	3B
0005433342083	1072	138	3F
0005435545739	1072	139	3C
0005433342228	1072	140	4A
0005433342022	1072	141	3H
0005435092074	1072	142	4B
0005433341798	1072	143	4C
0005433342270	1072	144	4G
0005433342107	1072	145	4F
0005433158115	1072	146	5B
0005435092067	1072	147	5C
0005433342393	1072	148	5H
0005433460410	17030	1	36D
0005433343051	17030	2	1A
0005433460412	17030	3	1B
0005433343039	17030	4	1F
0005435508260	17030	5	1H
0005433343043	17030	6	1G
0005433269717	17030	7	2A
0005433269716	17030	8	2B
0005433269718	17030	9	2F
0005433343036	17030	10	2C
0005433343108	17030	11	2H
0005433460402	17030	12	3B
0005433343089	17030	13	3A
0005433343012	17030	14	3G
0005433343046	17030	15	3H
0005433462721	17030	16	4B
0005433343070	17030	17	4A
0005433343102	17030	18	4C
0005433343097	17030	19	4G
0005433343045	17030	20	4H
0005433343058	17030	21	5B
0005433343110	17030	22	5C
0005433343087	17030	23	5G
0005433343093	17030	24	5F
0005433462719	17030	25	9A
0005433343038	17030	26	9B
0005433343059	17030	27	11B
0005433460401	17030	28	11E
0005435508243	17030	29	11D
0005433343024	17030	30	11F
0005433343088	17030	31	11G
0005433343094	17030	32	11H
0005433462724	17030	33	12D
0005433460405	17030	34	12B
0005433343064	17030	35	12E
0005433462712	17030	36	12G
0005433343104	17030	37	12F
0005433343062	17030	38	12H
0005433343071	17030	39	13B
0005433343081	17030	40	13A
0005433343105	17030	41	13D
0005433343034	17030	42	13F
0005433343107	17030	43	13E
0005433343011	17030	44	13H
0005433462718	17030	45	13G
0005433343048	17030	46	14B
0005433343052	17030	47	14F
0005434445222	17030	48	14E
0005433462711	17030	49	14G
0005433343073	17030	50	15D
0005433343080	17030	51	15A
0005433343021	17030	52	15G
0005433159310	17030	53	16A
0005433343026	17030	54	15H
0005433343054	17030	55	16D
0005433343015	17030	56	16E
0005433343076	17030	57	16G
0005433343103	17030	58	16F
0005435508272	17030	59	16H
0005433343023	17030	60	17D
0005433343099	17030	61	17E
0005433460403	17030	62	17G
0005435508239	17030	63	17F
0005434445221	17030	64	17H
0005433343083	17030	65	18B
0005433343044	17030	66	18A
0005433343017	17030	67	18F
0005433343009	17030	68	18G
0005433343010	17030	69	19A
0005433343033	17030	70	18H
0005433159313	17030	71	19B
0005433343042	17030	72	19D
0005433343098	17030	73	19F
0005433462709	17030	74	19G
0005433343068	17030	75	20A
0005433462717	17030	76	19H
0005433343013	17030	77	20B
0005433343079	17030	78	20E
0005433343077	17030	79	20G
0005433269719	17030	80	21A
0005433343074	17030	81	20H
0005433343084	17030	82	21D
0005433460404	17030	83	21B
0005433462720	17030	84	21E
0005433462710	17030	85	21F
0005433460408	17030	86	22A
0005433343090	17030	87	21G
0005433343078	17030	88	22D
0005433343047	17030	89	22E
0005433343049	17030	90	22F
0005433269715	17030	91	23A
0005433343069	17030	92	23E
0005433460407	17030	93	23G
0005435508257	17030	94	23H
0005433462713	17030	95	24B
0005433462714	17030	96	24A
0005433343075	17030	97	24E
0005433460409	17030	98	24G
0005433343109	17030	99	25D
0005433343096	17030	100	25E
0005433343031	17030	101	25F
0005435091962	17030	102	27B
0005435508236	17030	103	27D
0005433343014	17030	104	27F
0005435091996	17030	105	27H
0005433343027	17030	106	27G
0005435091964	17030	107	28A
0005433343022	17030	108	28E
0005433343032	17030	109	28F
0005433462723	17030	110	28G
0005433343067	17030	111	28H
0005435091977	17030	112	29B
0005433343101	17030	113	29E
0005433343020	17030	114	29G
0005435508258	17030	115	29F
0005433343060	17030	116	29H
0005433343025	17030	117	30B
0005435091989	17030	118	30D
0005433343041	17030	119	30F
0005433460400	17030	120	30H
0005433343063	17030	121	31B
0005434445219	17030	122	31A
0005433343072	17030	123	31D
0005434445220	17030	124	31F
0005433343057	17030	125	31G
0005435508271	17030	126	32A
0005433343100	17030	127	31H
0005433460399	17030	128	32D
0005433343028	17030	129	32B
0005433343082	17030	130	32F
0005433343106	17030	131	32H
0005433343016	17030	132	32G
0005433343061	17030	133	33A
0005433343029	17030	134	33D
0005433343037	17030	135	33E
0005433343050	17030	136	33F
0005433343086	17030	137	33H
0005433343085	17030	138	34A
0005433343053	17030	139	34D
0005433343095	17030	140	34B
0005433460406	17030	141	34E
0005433343092	17030	142	34G
0005433343035	17030	143	34H
0005433159312	17030	144	35D
0005435091963	17030	145	35B
0005433343066	17030	146	35G
0005435508242	17030	147	36B
0005433343091	17030	148	36E
0005435508228	17030	149	36F
0005433462716	17030	150	36H
0005433159311	17030	151	36G
0005433460398	17030	152	37A
0005433343056	17030	153	37D
0005433343065	17030	154	37E
0005433343055	17030	155	37F
0005433462715	17030	156	38A
0005433343019	17030	157	37H
0005435508261	17030	158	38B
0005433343030	17030	159	38E
0005435508227	17030	160	38F
0005433343040	17030	161	39E
0005433343018	17030	162	39F
0005432389971	18259	1	1C
0005432391982	18259	2	1F
0005432390015	18259	3	2C
0005432389968	18259	4	2A
0005432389972	18259	5	2D
0005432851922	18259	6	2F
0005432391972	18259	7	3D
0005432390021	18259	8	3C
0005432390033	18259	9	3F
0005432389976	18259	10	5C
0005432391967	18259	11	5F
0005432389978	18259	12	5D
0005432390056	18259	13	6B
0005432851923	18259	14	6A
0005432390053	18259	15	6D
0005432390055	18259	16	6E
0005432851925	18259	17	7A
0005432851909	18259	18	7B
0005432851907	18259	19	7D
0005432851920	18259	20	8A
0005432390054	18259	21	8B
0005432391956	18259	22	8F
0005432851918	18259	23	8E
0005432851908	18259	24	9A
0005432851924	18259	25	9D
0005432390019	18259	26	9E
0005432390013	18259	27	10C
0005432390016	18259	28	10D
0005432851915	18259	29	11C
0005432390037	18259	30	11B
0005432390032	18259	31	11F
0005432390035	18259	32	12A
0005432390043	18259	33	12C
0005432390031	18259	34	12B
0005432390088	18259	35	13A
0005432851912	18259	36	13C
0005432389977	18259	37	13B
0005432391980	18259	38	14B
0005432390038	18259	39	14D
0005432391981	18259	40	14C
0005432390041	18259	41	14F
0005432390040	18259	42	15B
0005432851921	18259	43	15A
0005432851914	18259	44	15D
0005432389937	18259	45	15C
0005432851916	18259	46	15E
0005432389975	18259	47	15F
0005432851913	18259	48	16C
0005432389973	18259	49	16E
0005432390020	18259	50	16D
0005432391983	18259	51	17A
0005432851919	18259	52	16F
0005432390005	18259	53	17B
0005432390017	18259	54	17F
0005432851917	18259	55	18A
0005432390030	18259	56	18C
0005432391960	18259	57	18D
0005432391959	18259	58	18F
0005432851911	18259	59	19A
0005432389991	18259	60	19D
0005432391966	18259	61	20B
0005432390012	18259	62	20D
0005432851910	18259	63	20C
0005432390027	18259	64	20F
0005432391965	18259	65	20E
0005432390042	18259	66	21A
0005432390074	18259	67	21E
0005432390036	18259	68	21D
0005432390014	18259	69	21F
0005434066955	12824	1	1A
0005434066708	12824	2	1D
0005434066819	12824	3	1C
0005432433677	12824	4	2A
0005434081733	12824	5	2C
0005432159856	12824	6	2D
0005434067179	12824	7	3C
0005434066698	12824	8	3A
0005432161152	12824	9	3F
0005434066889	12824	10	3D
0005434066927	12824	11	4B
0005434066664	12824	12	4A
0005432433680	12824	13	4C
0005433989729	12824	14	4D
0005434081694	12824	15	4E
0005434066784	12824	16	5A
0005434066931	12824	17	4F
0005433812899	12824	18	5B
0005434067011	12824	19	5D
0005434066831	12824	20	6A
0005432433678	12824	21	6C
0005434066620	12824	22	6B
0005434081707	12824	23	6D
0005434066707	12824	24	6E
0005434067075	12824	25	7A
0005434066619	12824	26	6F
0005433989720	12824	27	7B
0005434066702	12824	28	7D
0005432159859	12824	29	8A
0005434081636	12824	30	7F
0005434026677	12824	31	8B
0005433812900	12824	32	8C
0005434081638	12824	33	8D
0005434081719	12824	34	8F
0005434081603	12824	35	9A
0005434066716	12824	36	9B
0005434066882	12824	37	9D
0005434066947	12824	38	9C
0005434066906	12824	39	9F
0005434081678	12824	40	10B
0005434067006	12824	41	10D
0005434066799	12824	42	10C
0005434081654	12824	43	11C
0005434081573	12824	44	11B
0005434081679	12824	45	11D
0005434067131	12824	46	11F
0005434081656	12824	47	12A
0005434067132	12824	48	12C
0005434066785	12824	49	12B
0005434081626	12824	50	12E
0005434066691	12824	51	12D
0005434066932	12824	52	12F
0005434067163	12824	53	13A
0005434081723	12824	54	13B
0005432159858	12824	55	13E
0005434066950	12824	56	13F
0005434066832	12824	57	14B
0005434066925	12824	58	14A
0005434066965	12824	59	14C
0005434066883	12824	60	14D
0005434066985	12824	61	15A
0005434067230	12824	62	14F
0005434067002	12824	63	15B
0005432159857	12824	64	15C
0005434081653	12824	65	15F
0005434066907	12824	66	15E
0005434026686	12824	67	16A
0005434066951	12824	68	16B
0005434067036	12824	69	16C
0005434066692	12824	70	16D
0005434081722	12824	71	17B
0005434066697	12824	72	17C
0005434066977	12824	73	17D
0005434066665	12824	74	17F
0005434066946	12824	75	17E
0005432433679	12824	76	18A
0005434067070	12824	77	18C
0005434026685	12824	78	18B
0005432161151	12824	79	18D
0005434081744	12824	80	18F
0005434081697	12824	81	18E
0005434026678	12824	82	19A
0005434067005	12824	83	19B
0005434081695	12824	84	19D
0005434066830	12824	85	19C
0005434066786	12824	86	19E
0005434066690	12824	87	20A
0005434081604	12824	88	20E
0005434067063	12824	89	20D
0005434081664	12824	90	20F
0005432159855	12824	91	21B
0005434066913	12824	92	21A
0005434081680	12824	93	21C
0005434066888	12824	94	21D
0005434067064	12824	95	21E
0005434067071	12824	96	21F
0005434066717	12824	97	22B
0005434066699	12824	98	22A
0005434066800	12824	99	22C
0005434081602	12824	100	22D
0005434066701	12824	101	22E
0005434066937	12824	102	23A
0005434067159	12824	103	22F
0005434066926	12824	104	23B
0005434066890	12824	105	23C
0005434066898	12824	106	23D
0005434066912	12824	107	23F
0005433989728	12824	108	23E
0005434081869	30653	1	1C
0005434067481	30653	2	1A
0005434067464	30653	3	1D
0005432433621	30653	4	1F
0005434081885	30653	5	2C
0005434081861	30653	6	2A
0005434081868	30653	7	2D
0005434081881	30653	8	2F
0005434067471	30653	9	3A
0005434067461	30653	10	3D
0005434081890	30653	11	3C
0005434067477	30653	12	3F
0005433989765	30653	13	4A
0005434067519	30653	14	4B
0005434081879	30653	15	4D
0005434067509	30653	16	4C
0005434067473	30653	17	4E
0005434067485	30653	18	4F
0005434067513	30653	19	5A
0005434067493	30653	20	5C
0005434067457	30653	21	5B
0005434067503	30653	22	5D
0005434081888	30653	23	5E
0005434067504	30653	24	6A
0005432150189	30653	25	5F
0005432150188	30653	26	6C
0005434081866	30653	27	6B
0005434067523	30653	28	6D
0005432433645	30653	29	6E
0005434067521	30653	30	7A
0005434067460	30653	31	6F
0005433989768	30653	32	7B
0005434067506	30653	33	7C
0005434081887	30653	34	7E
0005434067499	30653	35	7D
0005434067465	30653	36	8A
0005434067496	30653	37	7F
0005434081871	30653	38	8C
0005434067514	30653	39	8B
0005434081877	30653	40	8D
0005434081860	30653	41	8F
0005434067466	30653	42	8E
0005434081872	30653	43	9A
0005434067511	30653	44	9B
0005434067518	30653	45	9C
0005434081862	30653	46	9F
0005434067505	30653	47	9E
0005434067517	30653	48	10B
0005434081878	30653	49	10D
0005434067488	30653	50	10C
0005434067468	30653	51	10E
0005434081874	30653	52	11A
0005434067494	30653	53	11B
0005434067515	30653	54	11D
0005434067492	30653	55	11C
0005434067484	30653	56	11E
0005434067472	30653	57	11F
0005432433642	30653	58	12A
0005434081875	30653	59	12B
0005434081882	30653	60	12D
0005434067475	30653	61	12C
0005434067482	30653	62	12E
0005434067478	30653	63	12F
0005434067520	30653	64	13B
0005432150187	30653	65	13A
0005434081883	30653	66	13C
0005434067502	30653	67	13D
0005432186865	30653	68	14A
0005434067490	30653	69	13F
0005434067470	30653	70	14B
0005434067483	30653	71	14D
0005434081884	30653	72	14C
0005434067497	30653	73	14E
0005434067524	30653	74	14F
0005434081864	30653	75	15A
0005434081863	30653	76	15C
0005432150186	30653	77	15B
0005434067525	30653	78	15D
0005433989766	30653	79	15F
0005434067491	30653	80	15E
0005434067459	30653	81	16A
0005434081867	30653	82	16B
0005434067463	30653	83	16C
0005434081891	30653	84	16D
0005434067486	30653	85	16F
0005434067528	30653	86	16E
0005434067476	30653	87	17A
0005434081886	30653	88	17B
0005434067507	30653	89	17C
0005434081873	30653	90	17D
0005434081880	30653	91	17E
0005432150185	30653	92	18A
0005434081870	30653	93	17F
0005434067479	30653	94	18B
0005434067480	30653	95	18D
0005432150190	30653	96	18C
0005434067501	30653	97	18F
0005433989767	30653	98	18E
0005434067474	30653	99	19A
0005434067467	30653	100	19C
0005434067458	30653	101	19B
0005434067495	30653	102	19D
0005434081876	30653	103	19F
0005434067508	30653	104	19E
0005434067469	30653	105	20B
0005434081865	30653	106	20A
0005434067527	30653	107	20D
0005432433622	30653	108	20C
0005434067489	30653	109	20E
0005434067510	30653	110	20F
0005432433633	30653	111	21A
0005434067512	30653	112	21C
0005434067516	30653	113	21B
0005434067522	30653	114	21D
0005432433639	30653	115	21E
0005432150184	30653	116	22A
0005432186866	30653	117	21F
0005434067500	30653	118	22B
0005434081859	30653	119	22C
0005434067462	30653	120	22E
0005434067498	30653	121	22D
0005433989764	30653	122	23B
0005432150183	30653	123	23A
0005434067526	30653	124	23C
0005434081889	30653	125	23D
0005432186864	30653	126	23E
0005434067487	30653	127	23F
0005433686633	9036	1	1D
0005433685523	9036	2	2D
0005433687704	9036	3	3A
0005433685521	9036	4	3B
0005433685522	9036	5	3C
0005433686631	9036	6	3D
0005433685527	9036	7	4A
0005433687711	9036	8	4C
0005433686635	9036	9	5C
0005433686637	9036	10	5D
0005433686632	9036	11	6A
0005433687705	9036	12	6C
0005433687706	9036	13	7A
0005433685525	9036	14	7C
0005433685526	9036	15	7D
0005433685524	9036	16	18B
0005433686638	9036	17	18C
0005433686636	9036	18	18D
0005433686640	9036	19	20B
0005433687709	9036	20	20C
0005433687710	9036	21	21C
0005433687712	9036	22	22A
0005433686639	9036	23	21D
0005433685528	9036	24	22B
0005433687708	9036	25	22C
0005433687707	9036	26	23A
0005433686634	9036	27	23B
0005434264902	5504	1	1A
0005434264922	5504	2	1B
0005435766243	5504	3	1F
0005435766236	5504	4	1C
0005435766197	5504	5	1G
0005435766238	5504	6	1H
0005435766217	5504	7	2B
0005435766190	5504	8	2G
0005435766218	5504	9	3A
0005435720822	5504	10	3C
0005435720823	5504	11	3B
0005434264955	5504	12	3F
0005435766215	5504	13	3G
0005434264882	5504	14	4A
0005435462101	5504	15	3H
0005435462138	5504	16	4B
0005432140446	5504	17	4C
0005435766216	5504	18	4G
0005435766245	5504	19	5B
0005435766212	5504	20	5A
0005435766239	5504	21	5C
0005434264852	5504	22	5G
0005435766194	5504	23	9B
0005435766241	5504	24	9G
0005435462215	5504	25	9H
0005435722055	5504	26	11D
0005435766211	5504	27	11B
0005435766227	5504	28	11A
0005434264836	5504	29	11H
0005435766225	5504	30	12B
0005434265007	5504	31	12A
0005434264831	5504	32	12D
0005435462144	5504	33	12G
0005435766201	5504	34	12F
0005435462099	5504	35	12H
0005435766192	5504	36	13B
0005434264851	5504	37	13A
0005435766249	5504	38	13D
0005435766208	5504	39	13E
0005435461971	5504	40	13G
0005435766205	5504	41	14A
0005435766220	5504	42	13H
0005435462068	5504	43	14B
0005435766223	5504	44	14D
0005433527266	5504	45	15A
0005435462065	5504	46	14H
0005432140447	5504	47	15D
0005435766219	5504	48	15B
0005435766207	5504	49	15E
0005435766251	5504	50	15F
0005435462176	5504	51	15G
0005435766234	5504	52	16A
0005434264853	5504	53	15H
0005434264866	5504	54	16D
0005435462147	5504	55	16B
0005435462044	5504	56	16E
0005434264905	5504	57	16F
0005435735136	5504	58	16G
0005435725597	5504	59	17A
0005435766206	5504	60	17D
0005435462006	5504	61	17B
0005435725593	5504	62	17E
0005435461970	5504	63	17G
0005435766240	5504	64	17F
0005435766248	5504	65	17H
0005432535785	5504	66	18D
0005435735134	5504	67	18F
0005435766226	5504	68	18G
0005435766221	5504	69	19A
0005435462216	5504	70	18H
0005435766210	5504	71	19D
0005433527268	5504	72	19F
0005432140443	5504	73	19H
0005435462064	5504	74	20B
0005435462170	5504	75	20A
0005435462179	5504	76	20D
0005434264825	5504	77	20F
0005434264755	5504	78	20H
0005435462097	5504	79	20G
0005435461921	5504	80	21B
0005435766189	5504	81	21E
0005435462137	5504	82	21F
0005434264906	5504	83	21G
0005435766214	5504	84	22A
0005435462223	5504	85	22D
0005435462111	5504	86	22F
0005435462039	5504	87	22H
0005435725596	5504	88	23B
0005435766252	5504	89	23D
0005435766233	5504	90	23E
0005434831092	5504	91	23G
0005435766222	5504	92	23F
0005435725594	5504	93	24A
0005435462102	5504	94	24B
0005435461920	5504	95	24E
0005432140445	5504	96	24D
0005435722054	5504	97	24F
0005434264786	5504	98	24G
0005435766228	5504	99	25F
0005433529278	5504	100	25E
0005434264931	5504	101	25D
0005435720824	5504	102	27B
0005433527265	5504	103	27A
0005432535789	5504	104	27F
0005435766242	5504	105	27E
0005435461922	5504	106	27G
0005435766237	5504	107	28B
0005435766209	5504	108	28E
0005434831111	5504	109	28F
0005433527267	5504	110	28G
0005434265008	5504	111	29A
0005435766250	5504	112	28H
0005432140448	5504	113	29E
0005435766231	5504	114	29D
0005434264930	5504	115	29F
0005434264934	5504	116	29H
0005434264901	5504	117	30B
0005435766200	5504	118	30A
0005434264921	5504	119	30E
0005435766246	5504	120	30F
0005435462036	5504	121	30G
0005435462067	5504	122	31B
0005432140449	5504	123	31D
0005434264917	5504	124	31E
0005433529279	5504	125	31H
0005435766224	5504	126	31G
0005435766196	5504	127	32A
0005433529277	5504	128	32D
0005435462066	5504	129	32B
0005434264881	5504	130	32F
0005435725595	5504	131	32G
0005435462000	5504	132	33A
0005435462096	5504	133	32H
0005435766230	5504	134	33D
0005435462123	5504	135	33B
0005435766232	5504	136	33F
0005435766191	5504	137	33G
0005432535771	5504	138	34B
0005435766198	5504	139	34A
0005432535770	5504	140	34E
0005435766195	5504	141	34F
0005435766203	5504	142	34H
0005435766244	5504	143	35A
0005435766202	5504	144	35D
0005435462171	5504	145	35F
0005435462103	5504	146	36A
0005435766213	5504	147	35H
0005435735135	5504	148	36B
0005435462173	5504	149	36D
0005432140444	5504	150	36F
0005435766229	5504	151	36H
0005435723043	5504	152	36G
0005435766193	5504	153	37A
0005434264904	5504	154	37B
0005435766199	5504	155	37E
0005435725598	5504	156	37F
0005435462242	5504	157	37H
0005435766204	5504	158	38B
0005435462060	5504	159	38F
0005435766247	5504	160	38E
0005435766235	5504	161	38D
0005435723044	5504	162	38H
0005435462038	5504	163	39E
0005432140450	5504	164	39D
0005435462241	5504	165	39F
0005434265144	13483	1	1A
0005435462442	13483	2	1C
0005434265149	13483	3	1B
0005435765647	13483	4	1F
0005432535831	13483	5	1H
0005435765732	13483	6	1G
0005435765533	13483	7	2C
0005435765803	13483	8	2B
0005434265137	13483	9	2F
0005432535835	13483	10	2G
0005435765416	13483	11	3A
0005435765417	13483	12	3B
0005435765795	13483	13	3C
0005435725560	13483	14	3H
0005435462436	13483	15	3G
0005434265147	13483	16	4A
0005435735081	13483	17	4B
0005435462432	13483	18	4C
0005435765356	13483	19	4G
0005435765790	13483	20	4F
0005435462451	13483	21	5A
0005434831152	13483	22	5C
0005435765735	13483	23	5G
0005435462446	13483	24	9A
0005435765789	13483	25	5H
0005435462419	13483	26	9B
0005434265129	13483	27	9G
0005435462437	13483	28	9H
0005434265135	13483	29	11B
0005435765862	13483	30	11F
0005435462413	13483	31	11E
0005435462431	13483	32	11G
0005435765384	13483	33	12B
0005435720120	13483	34	12A
0005435765598	13483	35	12D
0005435765385	13483	36	12E
0005435462415	13483	37	12G
0005434265126	13483	38	12F
0005434265127	13483	39	12H
0005435765734	13483	40	13B
0005435765256	13483	41	13A
0005435722038	13483	42	13D
0005435725552	13483	43	13E
0005435765718	13483	44	13G
0005435765543	13483	45	13F
0005435462430	13483	46	13H
0005435765719	13483	47	14B
0005435765692	13483	48	14A
0005435462421	13483	49	14D
0005435723032	13483	50	14F
0005435462414	13483	51	14E
0005435462448	13483	52	14G
0005434831151	13483	53	15B
0005434265128	13483	54	15A
0005435765866	13483	55	15E
0005435765860	13483	56	15D
0005435765452	13483	57	15F
0005435765624	13483	58	16D
0005435765451	13483	59	16B
0005432194510	13483	60	16F
0005435765531	13483	61	17A
0005435765456	13483	62	17E
0005435765493	13483	63	17G
0005434265132	13483	64	17F
0005435735094	13483	65	17H
0005435765654	13483	66	18B
0005434831153	13483	67	18A
0005435765592	13483	68	18D
0005434265143	13483	69	18E
0005435765623	13483	70	18G
0005435462450	13483	71	19A
0005435765690	13483	72	19B
0005435765693	13483	73	19E
0005432194508	13483	74	19D
0005434265141	13483	75	19F
0005435462441	13483	76	19H
0005435725551	13483	77	19G
0005435765804	13483	78	20A
0005432194512	13483	79	20B
0005432535834	13483	80	20E
0005435765691	13483	81	20F
0005434265140	13483	82	20G
0005435462439	13483	83	21B
0005434265138	13483	84	21A
0005435735095	13483	85	20H
0005435462444	13483	86	21G
0005435462425	13483	87	21F
0005435765594	13483	88	21H
0005435765648	13483	89	22A
0005435765517	13483	90	22D
0005435462445	13483	91	22B
0005435462420	13483	92	22E
0005435462423	13483	93	22G
0005435765355	13483	94	22H
0005435765588	13483	95	23B
0005434265146	13483	96	23A
0005435765674	13483	97	23E
0005435765655	13483	98	23D
0005432535833	13483	99	23F
0005435765530	13483	100	23G
0005435765455	13483	101	24A
0005435462440	13483	102	23H
0005435765593	13483	103	24B
0005435765793	13483	104	24D
0005435765763	13483	105	24F
0005435725536	13483	106	24E
0005435765646	13483	107	24G
0005435765688	13483	108	24H
0005435765787	13483	109	25E
0005435765698	13483	110	27B
0005435765689	13483	111	27E
0005435462447	13483	112	27D
0005435462434	13483	113	27F
0005434265145	13483	114	27G
0005435462449	13483	115	28A
0005435723024	13483	116	27H
0005434265125	13483	117	28B
0005435765677	13483	118	28E
0005435723023	13483	119	28D
0005435462428	13483	120	28G
0005435765864	13483	121	29B
0005435462417	13483	122	29A
0005435462429	13483	123	28H
0005435725535	13483	124	29D
0005434265134	13483	125	29E
0005435765679	13483	126	29F
0005432194509	13483	127	29H
0005434265133	13483	128	29G
0005434265130	13483	129	30B
0005435765529	13483	130	30D
0005435765475	13483	131	30E
0005435765658	13483	132	30G
0005432194511	13483	133	30H
0005434265148	13483	134	31B
0005434265136	13483	135	31D
0005434265139	13483	136	31F
0005435765476	13483	137	31G
0005435765631	13483	138	32A
0005435765255	13483	139	31H
0005435765494	13483	140	32B
0005435723030	13483	141	32E
0005435462433	13483	142	32G
0005435725543	13483	143	32F
0005435765257	13483	144	33B
0005435765630	13483	145	33E
0005435735083	13483	146	33G
0005435735107	13483	147	33F
0005434265142	13483	148	33H
0005435765695	13483	149	34A
0005435462438	13483	150	34F
0005435765675	13483	151	34E
0005435462424	13483	152	35A
0005435765905	13483	153	34H
0005434265131	13483	154	35B
0005435765836	13483	155	35D
0005435765642	13483	156	35E
0005435765919	13483	157	35G
0005435725544	13483	158	35F
0005432535832	13483	159	36A
0005435765738	13483	160	35H
0005435462443	13483	161	36B
0005435765766	13483	162	36E
0005435765882	13483	163	36D
0005435765740	13483	164	36H
0005434265150	13483	165	37A
0005435462435	13483	166	37B
0005435765534	13483	167	37F
0005435765408	13483	168	37G
0005435462418	13483	169	38B
0005434831154	13483	170	38A
0005435462426	13483	171	37H
0005435462427	13483	172	38D
0005435462422	13483	173	38E
0005435765587	13483	174	38F
0005435462416	13483	175	38H
0005435765867	13483	176	39F
0005434602878	18661	1	1B
0005434602877	18661	2	4B
0005434514967	18660	1	1A
0005434604869	18660	2	2B
0005434513577	18660	3	3A
0005434514965	18660	4	3B
0005434513576	18660	5	4A
0005434514966	18660	6	4B
0005434604870	18660	7	5A
0005435904704	18660	8	5B
0005434513578	18660	9	6B
0005434514944	19151	1	1A
0005434602895	19151	2	1B
0005434602898	19151	3	3A
0005434602899	19151	4	4A
0005434602897	19151	5	4B
0005434514951	19151	6	5B
0005434602896	19151	7	6A
0005434602894	19151	8	6B
0005433284975	1833	1	5F
0005433285032	1833	2	1C
0005433810547	1833	3	1D
0005433285120	1833	4	1F
0005433008320	1833	5	2A
0005433008325	1833	6	2C
0005432295880	1833	7	2F
0005433285064	1833	8	3A
0005433008152	1833	9	3C
0005433008174	1833	10	3F
0005433285084	1833	11	4A
0005433008205	1833	12	4C
0005433008206	1833	13	4D
0005433008241	1833	14	4E
0005433285099	1833	15	4F
0005433285121	1833	16	5A
0005433008188	1833	17	5C
0005433008192	1833	18	5D
0005433810546	1833	19	5E
0005432295879	1833	20	6A
0005433008076	1833	21	6C
0005433285039	1833	22	6D
0005433008106	1833	23	6E
0005432295878	1833	24	6F
0005433008276	1833	25	7A
0005433008048	1833	26	7C
0005433008337	1833	27	7D
0005433008171	1833	28	7E
0005433285007	1833	29	7F
0005433008264	1833	30	8A
0005433285046	1833	31	8C
0005433008118	1833	32	8D
0005433008204	1833	33	8E
0005433008319	1833	34	9A
0005433008068	1833	35	9D
0005433008376	1833	36	9F
0005433008133	1833	37	10A
0005433008266	1833	38	10D
0005433285047	1833	39	11A
0005433008463	1833	40	11C
0005433284953	1833	41	11D
0005433008200	1833	42	11E
0005433008193	1833	43	11F
0005433008099	1833	44	12A
0005433008239	1833	45	12D
0005433008422	1833	46	12E
0005433285101	1833	47	12F
0005433285065	1833	48	13A
0005433008317	1833	49	13C
0005433008334	1833	50	13D
0005433008207	1833	51	13E
0005433008143	1833	52	13F
0005433008347	1833	53	14A
0005433008156	1833	54	14C
0005433008131	1833	55	14D
0005433285041	1833	56	14E
0005433008147	1833	57	14F
0005433285010	1833	58	15A
0005433008187	1833	59	15C
0005433008338	1833	60	15D
0005433285008	1833	61	15E
0005433008423	1833	62	15F
0005433008265	1833	63	16A
0005433285045	1833	64	16C
0005433285040	1833	65	16D
0005433008372	1833	66	16F
0005433285100	1833	67	17A
0005433285063	1833	68	17C
0005433008375	1833	69	17D
0005433008383	1833	70	17F
0005433008069	1833	71	18A
0005433008119	1833	72	18C
0005433008153	1833	73	18D
0005433008218	1833	74	18E
0005433008282	1833	75	18F
0005433008132	1833	76	19A
0005433810549	1833	77	19C
0005433008079	1833	78	19D
0005433285076	1833	79	19F
0005433810548	1833	80	20A
0005433008144	1833	81	20C
0005433008346	1833	82	20D
0005433285033	1833	83	20E
0005433285289	22542	1	1A
0005433285288	22542	2	1C
0005433285270	22542	3	1D
0005433285286	22542	4	1F
0005433008609	22542	5	2A
0005433285279	22542	6	2D
0005433008596	22542	7	2F
0005433008584	22542	8	3A
0005433008593	22542	9	3C
0005433008600	22542	10	3D
0005433285287	22542	11	3F
0005433008605	22542	12	4A
0005433008587	22542	13	4C
0005433008564	22542	14	4D
0005433008592	22542	15	4E
0005433008573	22542	16	4F
0005433008583	22542	17	5A
0005433008568	22542	18	5C
0005433008588	22542	19	5D
0005433285282	22542	20	5F
0005433008585	22542	21	6C
0005433810496	22542	22	6D
0005433285276	22542	23	6E
0005433008577	22542	24	6F
0005433008589	22542	25	7A
0005433008580	22542	26	7C
0005433285275	22542	27	7D
0005433008582	22542	28	7E
0005433810500	22542	29	7F
0005433285274	22542	30	8C
0005433008597	22542	31	8A
0005433008602	22542	32	8E
0005433008603	22542	33	8F
0005433008606	22542	34	9A
0005433008572	22542	35	9C
0005433285268	22542	36	9D
0005433008565	22542	37	9E
0005433285294	22542	38	9F
0005433285271	22542	39	10A
0005433285284	22542	40	10C
0005433008581	22542	41	10E
0005433008567	22542	42	10F
0005433008598	22542	43	11A
0005433285278	22542	44	11C
0005433008575	22542	45	11D
0005433008604	22542	46	11E
0005433008608	22542	47	11F
0005433810499	22542	48	12A
0005433285272	22542	49	12C
0005433810502	22542	50	12D
0005433008571	22542	51	12F
0005433810501	22542	52	13A
0005433008569	22542	53	13D
0005433008594	22542	54	13E
0005433285290	22542	55	13F
0005433285291	22542	56	14A
0005433810504	22542	57	14C
0005433285264	22542	58	14D
0005433008579	22542	59	14E
0005433285269	22542	60	14F
0005433008595	22542	61	15C
0005433008601	22542	62	15D
0005433285266	22542	63	15E
0005433008574	22542	64	15F
0005433008576	22542	65	16A
0005433008591	22542	66	16D
0005433285267	22542	67	16E
0005433285292	22542	68	16F
0005433285273	22542	69	17A
0005433285283	22542	70	17C
0005433285293	22542	71	17D
0005433008586	22542	72	17F
0005433008599	22542	73	18A
0005433008570	22542	74	18C
0005433008610	22542	75	18D
0005433008566	22542	76	18E
0005433008607	22542	77	18F
0005433810505	22542	78	19A
0005433285285	22542	79	19D
0005433285265	22542	80	19E
0005433008578	22542	81	19F
0005433008590	22542	82	20C
0005433285281	22542	83	20D
0005433285277	22542	84	20E
0005433285280	22542	85	20F
0005432756840	25330	1	1A
0005432756843	25330	2	1C
0005432755070	25330	3	2A
0005432755066	25330	4	3D
0005434153522	25330	5	3F
0005434153520	25330	6	4D
0005434153516	25330	7	5A
0005432755067	25330	8	5F
0005432755071	25330	9	6C
0005434152757	25330	10	6D
0005434153521	25330	11	7C
0005432756835	25330	12	7D
0005432756842	25330	13	8A
0005434152763	25330	14	8C
0005432755069	25330	15	9A
0005434152760	25330	16	9C
0005432755065	25330	17	9E
0005434152756	25330	18	10A
0005434153523	25330	19	10D
0005434152762	25330	20	12C
0005434152761	25330	21	12D
0005434153518	25330	22	13A
0005434153519	25330	23	13C
0005434152769	25330	24	13D
0005432755064	25330	25	13E
0005432756839	25330	26	14D
0005432756844	25330	27	14E
0005434152767	25330	28	14F
0005432756836	25330	29	15D
0005434152768	25330	30	15E
0005432756841	25330	31	15F
0005432756837	25330	32	16A
0005434152764	25330	33	16F
0005434152770	25330	34	17C
0005434152766	25330	35	17D
0005432756838	25330	36	18D
0005432755072	25330	37	20D
0005432755068	25330	38	20F
0005433846731	5563	1	1C
0005435282208	5563	2	1A
0005433846719	5563	3	1F
0005435282315	5563	4	1D
0005433846708	5563	5	2A
0005434173481	5563	6	2D
0005433846710	5563	7	2C
0005433846696	5563	8	3A
0005435282314	5563	9	2F
0005433846687	5563	10	3D
0005435282252	5563	11	3C
0005433846735	5563	12	4A
0005433846734	5563	13	3F
0005435282296	5563	14	4C
0005435282225	5563	15	4F
0005433846686	5563	16	5A
0005435282239	5563	17	5F
0005433846720	5563	18	5D
0005433815383	5563	19	6B
0005433846692	5563	20	6A
0005435282300	5563	21	6D
0005433846736	5563	22	6F
0005433815380	5563	23	6E
0005432081507	5563	24	7A
0005433846699	5563	25	7C
0005433846693	5563	26	7B
0005433846717	5563	27	7E
0005435282259	5563	28	7D
0005433846730	5563	29	8A
0005433846728	5563	30	7F
0005434173467	5563	31	8B
0005433846723	5563	32	8D
0005433846714	5563	33	8E
0005433846733	5563	34	9B
0005433846694	5563	35	9A
0005435282306	5563	36	9C
0005435282299	5563	37	9E
0005432081508	5563	38	9D
0005433846725	5563	39	10A
0005433846697	5563	40	9F
0005433846709	5563	41	10C
0005432081511	5563	42	10B
0005433846722	5563	43	10E
0005435282260	5563	44	10D
0005432081509	5563	45	10F
0005433815382	5563	46	11B
0005433815381	5563	47	11A
0005433846738	5563	48	11E
0005433846680	5563	49	11D
0005433846726	5563	50	11C
0005433846716	5563	51	11F
0005433846702	5563	52	12B
0005434173484	5563	53	12A
0005435282253	5563	54	12D
0005435282343	5563	55	12C
0005435282213	5563	56	12E
0005435282329	5563	57	13A
0005433846685	5563	58	12F
0005433846703	5563	59	13B
0005435282278	5563	60	13E
0005435282283	5563	61	13D
0005433846695	5563	62	14A
0005432081510	5563	63	13F
0005434173482	5563	64	14B
0005435282226	5563	65	14E
0005433846737	5563	66	14D
0005435282240	5563	67	14C
0005433846705	5563	68	14F
0005432081513	5563	69	15A
0005435282282	5563	70	15C
0005433846711	5563	71	15D
0005433846681	5563	72	16A
0005433846690	5563	73	15F
0005433846691	5563	74	16C
0005433846706	5563	75	16B
0005433846682	5563	76	16E
0005435282305	5563	77	16D
0005433846698	5563	78	17A
0005433846729	5563	79	16F
0005432081512	5563	80	17B
0005435282341	5563	81	17D
0005433846701	5563	82	17C
0005433846688	5563	83	17F
0005433846732	5563	84	17E
0005433846707	5563	85	18B
0005435282317	5563	86	18A
0005433846704	5563	87	18C
0005433846713	5563	88	18E
0005435282268	5563	89	18D
0005435282211	5563	90	19A
0005435282301	5563	91	18F
0005435282251	5563	92	19C
0005433846715	5563	93	19B
0005433846689	5563	94	19E
0005435282304	5563	95	19D
0005435282326	5563	96	19F
0005433846700	5563	97	20B
0005435282254	5563	98	20A
0005433846712	5563	99	20D
0005433846718	5563	100	20F
0005433846724	5563	101	20E
0005433846721	5563	102	21A
0005433846683	5563	103	21C
0005432081506	5563	104	21B
0005433846727	5563	105	21F
0005435282344	5563	106	21E
0005433846684	5563	107	21D
0005433815352	13883	1	1C
0005433846097	13883	2	1A
0005433815331	13883	3	1D
0005433846026	13883	4	2C
0005433846474	13883	5	2A
0005433846180	13883	6	2D
0005432003702	13883	7	2F
0005433846162	13883	8	3D
0005433815344	13883	9	3C
0005433846096	13883	10	4A
0005435282501	13883	11	3F
0005433846368	13883	12	4C
0005433846215	13883	13	5A
0005433846067	13883	14	4F
0005433846245	13883	15	4D
0005433846114	13883	16	5C
0005433846170	13883	17	5D
0005433845966	13883	18	6A
0005435282513	13883	19	6D
0005433846409	13883	20	6C
0005433846267	13883	21	6F
0005435282509	13883	22	7A
0005433815322	13883	23	7C
0005433815332	13883	24	7B
0005435282511	13883	25	7D
0005435282503	13883	26	8A
0005433845688	13883	27	7F
0005433815321	13883	28	7E
0005433815323	13883	29	8D
0005435282506	13883	30	8C
0005433846438	13883	31	8F
0005433846240	13883	32	8E
0005433846049	13883	33	9D
0005433846115	13883	34	9C
0005432003700	13883	35	9B
0005433815349	13883	36	9E
0005433846270	13883	37	9F
0005433846316	13883	38	10C
0005433846166	13883	39	10B
0005433846305	13883	40	10D
0005433846042	13883	41	11A
0005433846315	13883	42	10F
0005433815353	13883	43	11B
0005433846278	13883	44	11D
0005433846058	13883	45	11C
0005435282512	13883	46	11F
0005433846313	13883	47	11E
0005433846246	13883	48	12B
0005435282504	13883	49	12A
0005433846304	13883	50	12C
0005433845956	13883	51	12E
0005433846105	13883	52	13A
0005433846004	13883	53	13C
0005433815320	13883	54	13B
0005433846430	13883	55	13E
0005433846314	13883	56	13D
0005433846155	13883	57	13F
0005433846231	13883	58	14B
0005432003701	13883	59	14D
0005433846209	13883	60	14C
0005434173521	13883	61	15A
0005433846279	13883	62	14E
0005433815350	13883	63	15B
0005435282515	13883	64	15C
0005433846299	13883	65	15E
0005433846331	13883	66	15D
0005433846165	13883	67	16A
0005434173520	13883	68	15F
0005433846059	13883	69	16C
0005435282508	13883	70	16B
0005432003699	13883	71	16E
0005433846107	13883	72	16D
0005433815337	13883	73	16F
0005433846005	13883	74	17B
0005435282514	13883	75	17D
0005433815355	13883	76	17C
0005433815330	13883	77	17F
0005435282510	13883	78	17E
0005433846216	13883	79	18A
0005433815310	13883	80	18C
0005433846191	13883	81	18B
0005433846219	13883	82	18E
0005433846113	13883	83	18D
0005433846210	13883	84	19A
0005434173519	13883	85	18F
0005434173518	13883	86	19C
0005433846041	13883	87	19B
0005433845689	13883	88	19D
0005433846300	13883	89	19F
0005433846292	13883	90	19E
0005433846192	13883	91	20B
0005433846156	13883	92	20A
0005435282500	13883	93	20D
0005433846225	13883	94	20C
0005433846367	13883	95	20E
0005435282505	13883	96	21B
0005433846354	13883	97	20F
0005433846218	13883	98	21C
0005435282502	13883	99	21E
0005433846048	13883	100	21D
0005435282507	13883	101	21F
0005435332295	7836	1	1A
0005434620587	7836	2	1B
0005435332206	7836	3	1C
0005435332240	7836	4	1D
0005434620593	7836	5	2A
0005434620600	7836	6	2B
0005432112515	7836	7	2D
0005434620584	7836	8	3A
0005435332252	7836	9	3B
0005435332241	7836	10	3C
0005434620597	7836	11	3D
0005432112517	7836	12	4A
0005434620596	7836	13	4B
0005435332207	7836	14	4C
0005435332245	7836	15	4D
0005435332230	7836	16	5A
0005435332257	7836	17	5C
0005435332234	7836	18	6A
0005435332258	7836	19	6C
0005434620580	7836	20	6D
0005434620581	7836	21	7A
0005432112514	7836	22	7B
0005434620590	7836	23	7D
0005434620601	7836	24	18A
0005434620583	7836	25	18B
0005435332253	7836	26	18C
0005435332284	7836	27	18D
0005434620585	7836	28	19A
0005434620595	7836	29	19B
0005434620591	7836	30	19C
0005434620589	7836	31	20A
0005434620588	7836	32	19D
0005434620599	7836	33	20B
0005435332277	7836	34	20C
0005434620594	7836	35	20D
0005434620592	7836	36	21A
0005435332278	7836	37	21B
0005434620586	7836	38	21C
0005434620598	7836	39	21D
0005435332235	7836	40	22B
0005435332254	7836	41	22C
0005435332276	7836	42	22D
0005432112516	7836	43	23A
0005434620582	7836	44	23B
0005435332332	32952	1	1A
0005434620395	32952	2	1B
0005435332338	32952	3	1C
0005435332334	32952	4	2A
0005434620396	32952	5	2B
0005434620388	32952	6	2C
0005435332337	32952	7	3A
0005435332333	32952	8	3B
0005434620435	32952	9	3C
0005434620495	32952	10	3D
0005434620415	32952	11	4A
0005435332331	32952	12	4B
0005434620436	32952	13	4C
0005434620381	32952	14	4D
0005434620389	32952	15	5A
0005434620373	32952	16	6B
0005434620324	32952	17	6D
0005435332330	32952	18	7A
0005434620407	32952	19	7B
0005435332329	32952	20	18A
0005434620322	32952	21	18C
0005434620325	32952	22	19B
0005434620323	32952	23	19C
0005435332335	32952	24	19D
0005435332328	32952	25	20A
0005434620426	32952	26	20B
0005434620289	32952	27	20C
0005434620460	32952	28	20D
0005435332336	32952	29	21D
0005434620357	32952	30	22D
0005434620471	32952	31	23A
0005434620433	32952	32	23B
0005435787354	4308	1	1A
0005434994023	4308	2	1F
0005435937343	4308	3	2C
0005435785334	4308	4	2D
0005434994025	4308	5	2F
0005435785357	4308	6	3A
0005435937366	4308	7	3D
0005435785332	4308	8	4A
0005435785337	4308	9	4D
0005435785359	4308	10	4E
0005435918619	4308	11	4F
0005435785341	4308	12	5D
0005435785333	4308	13	5E
0005435785364	4308	14	5F
0005435785338	4308	15	6C
0005435937330	4308	16	6D
0005435785340	4308	17	6E
0005434994020	4308	18	7A
0005434994024	4308	19	7C
0005435937342	4308	20	7D
0005435785352	4308	21	7E
0005435785355	4308	22	7F
0005432190630	4308	23	8C
0005435785350	4308	24	8F
0005435785349	4308	25	9C
0005432190628	4308	26	9D
0005435785343	4308	27	9E
0005435785356	4308	28	10C
0005435785360	4308	29	10E
0005435785351	4308	30	10F
0005434994018	4308	31	11A
0005434994019	4308	32	11D
0005435937331	4308	33	11E
0005435785354	4308	34	12A
0005435785362	4308	35	12D
0005435785363	4308	36	12E
0005435918602	4308	37	12F
0005435918601	4308	38	13A
0005435785344	4308	39	13F
0005435785339	4308	40	14A
0005435785347	4308	41	14C
0005435785361	4308	42	14D
0005435785346	4308	43	14F
0005435785345	4308	44	15A
0005435785358	4308	45	15E
0005434994016	4308	46	15F
0005435785331	4308	47	16A
0005434994021	4308	48	16C
0005435785348	4308	49	16D
0005435785335	4308	50	17E
0005432190629	4308	51	17F
0005435785353	4308	52	18A
0005435918617	4308	53	18C
0005434994017	4308	54	18D
0005434994015	4308	55	18E
0005435785336	4308	56	18F
0005435785342	4308	57	19C
0005435937365	4308	58	19E
0005434994022	4308	59	20F
0005435785115	27299	1	1C
0005435937384	27299	2	1D
0005435785002	27299	3	1F
0005434993926	27299	4	2D
0005435784975	27299	5	3C
0005435918656	27299	6	3F
0005434993899	27299	7	4A
0005435784963	27299	8	4C
0005434993946	27299	9	4D
0005434993919	27299	10	4F
0005435784764	27299	11	5A
0005435784867	27299	12	5D
0005434993958	27299	13	6A
0005434993911	27299	14	6D
0005434993900	27299	15	6E
0005435784922	27299	16	6F
0005435785011	27299	17	7A
0005435784977	27299	18	7C
0005435937385	27299	19	7D
0005435784801	27299	20	7E
0005435785065	27299	21	8A
0005435784985	27299	22	8C
0005435785021	27299	23	8E
0005434993929	27299	24	8F
0005435785020	27299	25	9A
0005434993924	27299	26	10E
0005435784976	27299	27	10F
0005435784827	27299	28	11A
0005435785082	27299	29	11C
0005435784864	27299	30	11D
0005435784939	27299	31	11E
0005435784843	27299	32	11F
0005435784882	27299	33	12A
0005435785081	27299	34	12D
0005435937386	27299	35	12F
0005435784958	27299	36	13A
0005435785077	27299	37	13E
0005435785016	27299	38	13F
0005435784998	27299	39	14A
0005435937383	27299	40	14C
0005435937387	27299	41	14E
0005435937388	27299	42	14F
0005435784839	27299	43	15A
0005435785033	27299	44	15D
0005435918652	27299	45	15F
0005435784866	27299	46	16A
0005434993910	27299	47	16D
0005435918654	27299	48	17A
0005434993928	27299	49	17D
0005435784942	27299	50	17F
0005435784974	27299	51	18E
0005435784959	27299	52	19C
0005435784978	27299	53	19E
0005435918655	27299	54	19F
0005435785019	27299	55	20A
0005435787329	27299	56	20D
0005435918653	27299	57	20E
0005435784865	27299	58	20F
0005432146196	19870	1	2A
0005432146197	19870	2	3B
0005432146198	19870	3	7A
0005432459816	4729	1	1A
0005432567600	4729	2	1C
0005432567611	4729	3	1F
0005432567594	4729	4	1H
0005432170382	4729	5	1G
0005432459838	4729	6	2F
0005434081908	4729	7	2C
0005434081907	4729	8	2H
0005432567609	4729	9	2G
0005432567627	4729	10	3B
0005432567635	4729	11	3F
0005432567639	4729	12	3G
0005432567633	4729	13	4A
0005434081898	4729	14	4B
0005432567626	4729	15	4C
0005432567643	4729	16	4H
0005432567593	4729	17	4G
0005432567601	4729	18	5A
0005434081895	4729	19	5B
0005432459848	4729	20	5G
0005432567649	4729	21	5F
0005432567597	4729	22	5H
0005433452738	4729	23	9B
0005433451620	4729	24	9G
0005432459826	4729	25	9H
0005432459836	4729	26	11B
0005432567641	4729	27	11F
0005432567642	4729	28	11H
0005432459852	4729	29	12B
0005432170388	4729	30	12E
0005432567590	4729	31	12D
0005432459843	4729	32	12G
0005432459845	4729	33	12H
0005432567648	4729	34	13B
0005432567608	4729	35	13A
0005432459817	4729	36	13D
0005434081910	4729	37	13F
0005432459824	4729	38	13E
0005432571324	4729	39	13H
0005432186869	4729	40	13G
0005432567634	4729	41	14B
0005433726103	4729	42	14D
0005432459858	4729	43	14F
0005432567645	4729	44	14H
0005434081904	4729	45	14G
0005432571321	4729	46	15D
0005434081913	4729	47	15B
0005434081902	4729	48	15E
0005432459847	4729	49	15F
0005434081916	4729	50	15H
0005432459829	4729	51	15G
0005432459837	4729	52	16D
0005432459823	4729	53	16B
0005432567646	4729	54	16G
0005432567618	4729	55	16F
0005432170386	4729	56	17D
0005434081903	4729	57	17B
0005432571323	4729	58	17E
0005432459849	4729	59	17F
0005432459830	4729	60	18B
0005432459820	4729	61	18A
0005432567636	4729	62	18D
0005432170383	4729	63	18F
0005432567630	4729	64	18G
0005432459862	4729	65	19A
0005432567620	4729	66	18H
0005434081901	4729	67	19B
0005432567598	4729	68	19E
0005432186868	4729	69	19F
0005432567603	4729	70	19G
0005432459840	4729	71	19H
0005432459853	4729	72	20B
0005432567631	4729	73	20E
0005432459857	4729	74	20D
0005433726104	4729	75	20F
0005432459844	4729	76	20H
0005432459813	4729	77	20G
0005432459822	4729	78	21A
0005432567638	4729	79	21E
0005433451619	4729	80	21G
0005432459819	4729	81	21F
0005432567602	4729	82	21H
0005432567637	4729	83	22A
0005432459851	4729	84	22D
0005432567612	4729	85	22E
0005432459835	4729	86	22G
0005432567595	4729	87	22F
0005434081912	4729	88	23A
0005432567604	4729	89	22H
0005432567615	4729	90	23B
0005432459834	4729	91	23F
0005434081905	4729	92	23E
0005432459821	4729	93	23G
0005432459827	4729	94	24A
0005432567606	4729	95	23H
0005432459814	4729	96	24B
0005433451618	4729	97	24D
0005434081896	4729	98	24G
0005432567591	4729	99	25D
0005432567640	4729	100	27A
0005434081917	4729	101	25F
0005432459855	4729	102	27E
0005434081894	4729	103	27H
0005432571320	4729	104	28B
0005432567614	4729	105	28E
0005434081900	4729	106	28D
0005432459828	4729	107	28G
0005432567610	4729	108	28H
0005432567619	4729	109	29B
0005432459846	4729	110	29F
0005434081899	4729	111	29G
0005432571322	4729	112	30B
0005432567647	4729	113	30A
0005432459842	4729	114	30F
0005432567623	4729	115	30E
0005432567629	4729	116	30G
0005432459850	4729	117	31A
0005432567622	4729	118	30H
0005432567632	4729	119	31B
0005432170387	4729	120	31D
0005432459854	4729	121	31H
0005432459856	4729	122	31G
0005432459818	4729	123	32B
0005432567628	4729	124	32D
0005432567605	4729	125	32F
0005432459861	4729	126	32H
0005432186870	4729	127	32G
0005432170385	4729	128	33A
0005432459859	4729	129	33D
0005432567616	4729	130	33B
0005434081892	4729	131	33E
0005432567599	4729	132	33G
0005432567607	4729	133	33F
0005432170384	4729	134	33H
0005432567625	4729	135	34A
0005434081909	4729	136	34D
0005434081915	4729	137	34B
0005432567592	4729	138	34E
0005434081914	4729	139	34G
0005432459833	4729	140	34F
0005432567650	4729	141	34H
0005432567596	4729	142	35B
0005433452739	4729	143	35D
0005432567613	4729	144	35E
0005432186867	4729	145	35G
0005434081897	4729	146	36A
0005434081906	4729	147	35H
0005432459832	4729	148	36B
0005432459860	4729	149	36E
0005434081911	4729	150	37A
0005432567644	4729	151	37E
0005434081893	4729	152	37F
0005432459825	4729	153	37H
0005432459831	4729	154	37G
0005432567624	4729	155	38A
0005432459863	4729	156	38B
0005432459841	4729	157	38E
0005432567621	4729	158	39D
0005432459815	4729	159	38H
0005432567617	4729	160	39E
0005432459839	4729	161	39F
0005434081697	30527	1	1A
0005432567502	30527	2	1F
0005432567148	30527	3	1G
0005432459339	30527	4	2A
0005432567054	30527	5	2B
0005432567129	30527	6	2C
0005432459409	30527	7	2G
0005434081744	30527	8	3A
0005432459393	30527	9	3C
0005432567213	30527	10	3B
0005432567242	30527	11	3F
0005434081678	30527	12	3G
0005432567379	30527	13	4A
0005434081723	30527	14	4G
0005432567031	30527	15	5A
0005432566985	30527	16	4H
0005432567469	30527	17	5B
0005433454856	30527	18	5G
0005432567109	30527	19	9B
0005432567036	30527	20	9G
0005434081604	30527	21	11A
0005434081680	30527	22	9H
0005432459328	30527	23	11B
0005432567244	30527	24	11E
0005433454852	30527	25	11D
0005432459383	30527	26	11G
0005432459602	30527	27	12A
0005432459232	30527	28	12D
0005432567328	30527	29	12E
0005432567017	30527	30	12G
0005432566929	30527	31	12F
0005434081695	30527	32	12H
0005434081679	30527	33	13A
0005432567226	30527	34	13D
0005432459542	30527	35	13B
0005432213605	30527	36	13F
0005432459240	30527	37	13G
0005434081719	30527	38	13H
0005432459730	30527	39	14B
0005433454857	30527	40	14F
0005434081653	30527	41	14E
0005432459414	30527	42	14G
0005432567163	30527	43	15D
0005432567162	30527	44	15B
0005432566930	30527	45	15E
0005432567304	30527	46	15G
0005434081664	30527	47	16A
0005432459447	30527	48	15H
0005432459422	30527	49	16D
0005432567130	30527	50	16B
0005432459580	30527	51	16E
0005432567102	30527	52	16F
0005434081638	30527	53	16H
0005434081602	30527	54	16G
0005432459512	30527	55	17B
0005432459501	30527	56	17E
0005432567074	30527	57	17D
0005433454853	30527	58	17G
0005432459417	30527	59	18A
0005432571295	30527	60	17H
0005432567503	30527	61	18D
0005432567202	30527	62	18G
0005432567218	30527	63	18F
0005432459499	30527	64	19B
0005434081707	30527	65	19A
0005432459296	30527	66	19D
0005432567101	30527	67	19E
0005432567089	30527	68	19H
0005434081722	30527	69	20A
0005432567225	30527	70	20F
0005432459256	30527	71	20H
0005432566876	30527	72	21A
0005432567224	30527	73	21F
0005432459295	30527	74	21H
0005432459410	30527	75	22D
0005432567177	30527	76	22B
0005432459448	30527	77	22E
0005432567071	30527	78	22F
0005432459418	30527	79	22H
0005432459604	30527	80	23B
0005434081656	30527	81	23D
0005432213604	30527	82	23E
0005432567082	30527	83	23H
0005432567254	30527	84	23G
0005432459324	30527	85	24A
0005432459423	30527	86	24B
0005434081573	30527	87	24E
0005432567173	30527	88	24D
0005432567064	30527	89	24F
0005432567286	30527	90	24H
0005432567222	30527	91	24G
0005432567266	30527	92	25D
0005432459394	30527	93	25E
0005434081654	30527	94	27A
0005432567094	30527	95	27D
0005432566880	30527	96	27F
0005432459403	30527	97	27H
0005432213606	30527	98	27G
0005432459415	30527	99	28A
0005432571302	30527	100	28D
0005432567043	30527	101	28B
0005432459412	30527	102	28G
0005432459123	30527	103	28F
0005432567305	30527	104	29A
0005432459603	30527	105	29B
0005432459520	30527	106	29F
0005432459477	30527	107	29E
0005432459440	30527	108	29D
0005432161151	30527	109	29G
0005432567331	30527	110	29H
0005432567358	30527	111	30A
0005434081636	30527	112	30D
0005432567052	30527	113	30B
0005432459460	30527	114	30F
0005432459416	30527	115	30E
0005432567295	30527	116	31A
0005432459451	30527	117	30H
0005434081694	30527	118	31B
0005432459519	30527	119	31F
0005434081626	30527	120	31E
0005432567180	30527	121	31H
0005432213607	30527	122	31G
0005432567223	30527	123	32B
0005434081733	30527	124	32A
0005432567243	30527	125	32D
0005432567175	30527	126	32G
0005432459317	30527	127	33A
0005432566984	30527	128	33E
0005432567208	30527	129	33D
0005432459282	30527	130	34B
0005432459476	30527	131	34F
0005432459513	30527	132	35B
0005432571277	30527	133	35D
0005434081603	30527	134	35H
0005432459332	30527	135	36A
0005432459481	30527	136	36D
0005432459400	30527	137	36H
0005432567018	30527	138	36G
0005432459419	30527	139	37D
0005432161152	30527	140	37B
0005432459424	30527	141	37E
0005433452723	30527	142	37H
0005432567010	30527	143	37G
0005432459360	30527	144	38B
0005432567051	30527	145	38E
0005432459500	30527	146	38D
0005432459361	30527	147	38F
0005432459239	30527	148	38H
0005432459371	30527	149	38G
0005432459452	30527	150	39E
0005435720824	13673	1	2A
0005435720822	13673	2	3A
0005435722054	13673	3	4A
0005435720823	13673	4	5B
0005435722055	13673	5	6B
0005435722036	21133	1	2A
0005435722037	21133	2	2B
0005435722031	21133	3	6A
0005435722022	21133	4	5B
0005432295880	22757	1	1D
0005432295879	22757	2	2C
0005432295878	22757	3	22C
0005433343161	11090	1	1A
0005433343136	11090	2	1C
0005433343135	11090	3	1F
0005433343124	11090	4	1D
0005433343154	11090	5	2C
0005433343190	11090	6	2A
0005433343149	11090	7	3A
0005433343168	11090	8	2F
0005433343210	11090	9	3D
0005433343196	11090	10	3C
0005435380258	11090	11	3F
0005433343198	11090	12	4A
0005433343117	11090	13	4C
0005433343194	11090	14	4B
0005435097196	11090	15	4D
0005433343146	11090	16	4E
0005433343209	11090	17	4F
0005435097191	11090	18	5A
0005433343212	11090	19	5B
0005433343143	11090	20	5D
0005433343120	11090	21	5C
0005433343116	11090	22	5E
0005433343195	11090	23	6A
0005435508246	11090	24	5F
0005433343140	11090	25	6B
0005435508202	11090	26	6D
0005433343158	11090	27	6E
0005433343181	11090	28	7A
0005433343205	11090	29	6F
0005433343211	11090	30	7B
0005435508283	11090	31	7C
0005435508277	11090	32	7E
0005433343167	11090	33	7D
0005433343166	11090	34	7F
0005433343157	11090	35	8B
0005433343151	11090	36	8A
0005433343141	11090	37	8C
0005433343155	11090	38	8E
0005433343207	11090	39	8D
0005433343191	11090	40	9A
0005433343175	11090	41	8F
0005433343165	11090	42	9B
0005433343150	11090	43	9C
0005433343111	11090	44	9E
0005435508250	11090	45	9D
0005433343139	11090	46	9F
0005433343144	11090	47	10C
0005433343183	11090	48	10D
0005433343160	11090	49	11A
0005433343153	11090	50	10E
0005433343132	11090	51	11B
0005435097193	11090	52	11C
0005433343189	11090	53	11E
0005433343174	11090	54	11D
0005435097198	11090	55	11F
0005433343176	11090	56	12A
0005433343137	11090	57	12C
0005433343177	11090	58	12B
0005435508262	11090	59	12E
0005433343112	11090	60	12D
0005433343208	11090	61	12F
0005435097194	11090	62	13B
0005433343133	11090	63	13A
0005433343185	11090	64	13C
0005433343199	11090	65	13E
0005433343171	11090	66	13D
0005435508247	11090	67	13F
0005433343113	11090	68	14B
0005433343130	11090	69	14A
0005433343115	11090	70	14D
0005433343127	11090	71	14C
0005435097190	11090	72	14E
0005435097195	11090	73	15A
0005435380259	11090	74	14F
0005433343126	11090	75	15B
0005433343152	11090	76	15C
0005433343192	11090	77	15D
0005433343148	11090	78	15E
0005433343164	11090	79	16A
0005433343123	11090	80	15F
0005433343134	11090	81	16B
0005433343145	11090	82	16C
0005435380257	11090	83	16E
0005435097197	11090	84	16F
0005433343128	11090	85	17A
0005433343184	11090	86	17B
0005433343180	11090	87	17C
0005433343179	11090	88	17E
0005435508201	11090	89	17D
0005433343118	11090	90	17F
0005433343182	11090	91	18A
0005433343159	11090	92	18B
0005433343119	11090	93	18D
0005433343204	11090	94	18C
0005433343202	11090	95	18E
0005433343188	11090	96	18F
0005433343197	11090	97	19A
0005433343142	11090	98	19C
0005433343200	11090	99	19B
0005433343172	11090	100	19E
0005433343169	11090	101	19D
0005435508266	11090	102	19F
0005433343187	11090	103	20A
0005433343201	11090	104	20B
0005433343138	11090	105	20C
0005433343170	11090	106	20E
0005433343162	11090	107	20D
0005433343114	11090	108	20F
0005433343121	11090	109	21A
0005433343193	11090	110	21C
0005433343122	11090	111	21B
0005433343186	11090	112	21D
0005433343178	11090	113	21F
0005435508279	11090	114	21E
0005433343206	11090	115	22B
0005435097192	11090	116	22A
0005433343131	11090	117	22C
0005433343156	11090	118	22E
0005435380230	11090	119	22D
0005433343173	11090	120	22F
0005433343129	11090	121	23B
0005433343147	11090	122	23A
0005435508276	11090	123	23C
0005433343163	11090	124	23E
0005433343125	11090	125	23D
0005433343203	11090	126	23F
0005435545736	17110	1	22B
0005433342023	17110	2	1A
0005433341912	17110	3	1C
0005433342274	17110	4	1D
0005433342270	17110	5	2A
0005435545738	17110	6	1F
0005433341881	17110	7	2D
0005433342210	17110	8	2C
0005433342373	17110	9	3A
0005433342297	17110	10	2F
0005435097134	17110	11	3C
0005433342196	17110	12	3D
0005433342109	17110	13	3F
0005433342118	17110	14	4A
0005435097098	17110	15	4C
0005435545739	17110	16	4B
0005433341923	17110	17	4D
0005433341613	17110	18	4E
0005433342165	17110	19	4F
0005433342327	17110	20	5A
0005433342514	17110	21	5C
0005433342265	17110	22	5B
0005433341916	17110	23	5D
0005433342381	17110	24	5F
0005433342493	17110	25	5E
0005433341617	17110	26	6A
0005435380298	17110	27	6B
0005433342527	17110	28	6C
0005433341913	17110	29	6D
0005433341799	17110	30	6E
0005433341944	17110	31	6F
0005433342378	17110	32	7B
0005433341911	17110	33	7A
0005433342413	17110	34	7C
0005433342105	17110	35	7D
0005433342330	17110	36	7F
0005433341980	17110	37	7E
0005433342440	17110	38	8B
0005433342058	17110	39	8A
0005433342106	17110	40	8C
0005433341882	17110	41	8E
0005433341614	17110	42	8D
0005433341902	17110	43	9A
0005433342237	17110	44	8F
0005433342155	17110	45	9B
0005433342192	17110	46	9C
0005433342364	17110	47	9E
0005433341978	17110	48	9D
0005433341931	17110	49	9F
0005435097090	17110	50	10B
0005433341883	17110	51	10D
0005433342412	17110	52	10C
0005433342372	17110	53	11A
0005435380294	17110	54	10E
0005433342218	17110	55	11B
0005435380296	17110	56	11D
0005433341940	17110	57	11C
0005433342016	17110	58	11E
0005433341914	17110	59	11F
0005435380295	17110	60	12A
0005433342213	17110	61	12C
0005433342077	17110	62	12B
0005433342022	17110	63	12D
0005433342239	17110	64	12E
0005433342526	17110	65	12F
0005433342296	17110	66	13A
0005433341894	17110	67	13B
0005433342369	17110	68	13D
0005433342229	17110	69	13C
0005433342238	17110	70	13E
0005435545737	17110	71	14A
0005433342718	17110	72	13F
0005433342374	17110	73	14B
0005433342273	17110	74	14D
0005433342088	17110	75	14C
0005433342083	17110	76	14E
0005433342475	17110	77	14F
0005433342240	17110	78	15B
0005433341979	17110	79	15A
0005433342000	17110	80	15C
0005433342232	17110	81	15D
0005433342375	17110	82	15F
0005435097120	17110	83	15E
0005433342405	17110	84	16B
0005433341933	17110	85	16A
0005433342180	17110	86	16C
0005433342534	17110	87	16E
0005433342209	17110	88	16D
0005433342204	17110	89	16F
0005432293208	17110	90	17A
0005433341999	17110	91	17B
0005433341922	17110	92	17C
0005433341481	17110	93	17E
0005433341952	17110	94	17D
0005435097121	17110	95	17F
0005433341973	17110	96	18A
0005433342515	17110	97	18B
0005433342107	17110	98	18C
0005433342361	17110	99	18E
0005435545740	17110	100	18D
0005432293207	17110	101	18F
0005433342393	17110	102	19A
0005435380297	17110	103	19B
0005433342142	17110	104	19C
0005433341930	17110	105	19E
0005433342181	17110	106	19D
0005433341622	17110	107	19F
0005433342197	17110	108	20A
0005432293209	17110	109	20C
0005433341932	17110	110	20B
0005433341621	17110	111	20E
0005433342326	17110	112	20D
0005433341480	17110	113	20F
0005433341809	17110	114	21B
0005433341779	17110	115	21A
0005433342432	17110	116	21C
0005433342174	17110	117	21D
0005433341868	17110	118	21F
0005433342298	17110	119	21E
0005433341798	17110	120	22A
0005433342219	17110	121	22C
0005433342230	17110	122	22D
0005433342459	17110	123	22E
0005433342260	17110	124	23A
0005435097122	17110	125	22F
0005433341616	17110	126	23B
0005433342228	17110	127	23D
0005433342563	17110	128	23C
0005433342124	17110	129	23F
0005433342370	17110	130	23E
0005432919593	9075	1	1D
0005432919724	9075	2	2C
0005432919690	9075	3	2F
0005434158956	9075	4	3A
0005432919727	9075	5	3D
0005432919673	9075	6	4A
0005432919645	9075	7	4D
0005433507190	9075	8	5D
0005433507186	9075	9	6A
0005433507178	9075	10	6D
0005433507179	9075	11	6F
0005433481169	9075	12	7C
0005432919726	9075	13	7D
0005432919708	9075	14	8E
0005433507188	9075	15	8F
0005433507182	9075	16	9E
0005434158954	9075	17	9F
0005433507177	9075	18	10A
0005433507180	9075	19	10D
0005433481166	9075	20	10F
0005432919700	9075	21	11A
0005432919691	9075	22	11D
0005432919592	9075	23	11E
0005433481165	9075	24	12D
0005432919671	9075	25	12E
0005433481167	9075	26	13A
0005432919665	9075	27	13C
0005433507185	9075	28	13D
0005432919699	9075	29	14A
0005434158955	9075	30	14D
0005433481164	9075	31	14F
0005433507183	9075	32	15C
0005432919674	9075	33	15E
0005432919633	9075	34	15F
0005433507181	9075	35	16D
0005433507184	9075	36	16F
0005433507187	9075	37	17C
0005432919697	9075	38	17D
0005432919666	9075	39	17F
0005434158960	9075	40	18D
0005433481170	9075	41	18F
0005432919659	9075	42	19A
0005432919608	9075	43	19C
0005433507189	9075	44	20A
0005433481168	9075	45	20D
0005432919609	9075	46	20F
0005433507007	20468	1	1C
0005433507056	20468	2	1D
0005432919868	20468	3	2C
0005432919882	20468	4	3C
0005433507038	20468	5	3D
0005432919887	20468	6	3F
0005433507055	20468	7	4C
0005433481097	20468	8	4D
0005432919875	20468	9	4E
0005433507006	20468	10	5C
0005433481124	20468	11	5D
0005433506919	20468	12	5F
0005432919884	20468	13	6A
0005433506992	20468	14	6C
0005433481107	20468	15	6F
0005432919869	20468	16	7A
0005433507009	20468	17	7C
0005432919883	20468	18	7D
0005433506917	20468	19	7F
0005433481112	20468	20	8E
0005432919872	20468	21	8F
0005432919879	20468	22	9C
0005432919876	20468	23	9F
0005433481133	20468	24	10D
0005433481085	20468	25	10E
0005433481091	20468	26	10F
0005433507039	20468	27	11A
0005433507005	20468	28	11D
0005432919878	20468	29	11F
0005432919871	20468	30	12C
0005433481101	20468	31	12D
0005432919880	20468	32	12E
0005433481115	20468	33	12F
0005432919886	20468	34	13A
0005432919873	20468	35	13C
0005433481086	20468	36	13F
0005433481078	20468	37	14E
0005432919877	20468	38	14F
0005432919881	20468	39	15C
0005433507029	20468	40	15D
0005433506918	20468	41	15E
0005432919874	20468	42	16A
0005432919870	20468	43	16C
0005433481119	20468	44	16D
0005433481099	20468	45	16E
0005433481111	20468	46	17D
0005433507008	20468	47	17E
0005432919885	20468	48	17F
0005433481100	20468	49	18C
0005433507018	20468	50	18D
0005433507028	20468	51	18E
0005433481093	20468	52	19F
0005433481087	20468	53	20C
0005433507017	20468	54	20F
0005432396241	10202	1	1A
0005432396238	10202	2	1B
0005435178984	10202	3	3A
0005432394099	10202	4	3B
0005432396240	10202	5	4A
0005432396237	10202	6	4B
0005432394100	10202	7	5B
0005432394101	10202	8	5A
0005432396239	10202	9	6A
0005435178983	10202	10	6B
0005432396210	18277	1	1A
0005435179693	18277	2	1B
0005432400101	18277	3	2A
0005435179394	18277	4	2B
0005435179695	18277	5	3A
0005432396207	18277	6	3B
0005435179393	18277	7	4A
0005432400102	18277	8	4B
0005435179694	18277	9	5B
0005432400103	18277	10	6A
0005432396222	18277	11	6B
0005435126081	10995	1	1A
0005435125747	10995	2	1C
0005435625958	10995	3	1D
0005434411780	10995	4	1F
0005435625971	10995	5	2A
0005435125980	10995	6	2D
0005435125749	10995	7	2F
0005435125928	10995	8	3A
0005435126045	10995	9	3C
0005435125994	10995	10	3F
0005435126044	10995	11	4A
0005435125899	10995	12	4C
0005435126092	10995	13	4D
0005435625951	10995	14	4F
0005435625997	10995	15	5A
0005435126156	10995	16	5C
0005435125860	10995	17	5D
0005435625976	10995	18	5E
0005435126080	10995	19	5F
0005435625974	10995	20	6C
0005435126022	10995	21	6D
0005435125803	10995	22	6E
0005435625994	10995	23	6F
0005435125748	10995	24	7A
0005434411776	10995	25	7C
0005435126032	10995	26	7D
0005435625926	10995	27	7F
0005435126017	10995	28	8A
0005435125849	10995	29	8C
0005435125821	10995	30	8D
0005435125931	10995	31	8E
0005435125932	10995	32	8F
0005435126043	10995	33	9A
0005435126091	10995	34	9C
0005435126103	10995	35	9D
0005435625972	10995	36	9E
0005435126134	10995	37	10A
0005435626015	10995	38	10D
0005434411778	10995	39	10E
0005435626007	10995	40	10F
0005435626002	10995	41	11C
0005435625995	10995	42	11D
0005435556669	10995	43	11E
0005435125985	10995	44	12A
0005435625973	10995	45	12C
0005435125917	10995	46	12D
0005435126031	10995	47	12E
0005435125907	10995	48	13C
0005435126120	10995	49	13D
0005435126038	10995	50	13E
0005435625999	10995	51	13F
0005435625975	10995	52	14C
0005435125943	10995	53	14D
0005434411777	10995	54	14F
0005435125850	10995	55	15A
0005435556670	10995	56	15C
0005435625998	10995	57	15D
0005435626019	10995	58	15F
0005434928300	10995	59	16A
0005435125986	10995	60	16C
0005435625996	10995	61	16E
0005435125870	10995	62	17A
0005435126124	10995	63	17C
0005435125802	10995	64	17D
0005434411779	10995	65	17E
0005435625979	10995	66	17F
0005435626005	10995	67	18A
0005435626006	10995	68	18D
0005435126052	10995	69	18E
0005435125950	10995	70	18F
0005435126123	10995	71	19A
0005435125967	10995	72	19C
0005435126111	10995	73	19E
0005435126016	10995	74	19F
0005435125963	10995	75	20A
0005435626003	10995	76	20C
0005435126051	10995	77	20E
0005434928265	14680	1	1A
0005434928277	14680	2	2A
0005435626168	14680	3	2C
0005434411731	14680	4	2D
0005435626170	14680	5	2F
0005435626172	14680	6	3A
0005435126359	14680	7	3C
0005434411740	14680	8	3D
0005435554186	14680	9	3F
0005435554182	14680	10	4A
0005435126371	14680	11	4C
0005435126388	14680	12	4D
0005435126394	14680	13	4F
0005435556692	14680	14	5A
0005435126382	14680	15	5C
0005435126356	14680	16	5D
0005435126387	14680	17	5E
0005435556691	14680	18	5F
0005435554183	14680	19	6C
0005435126375	14680	20	6D
0005435126379	14680	21	6E
0005435126389	14680	22	6F
0005435126391	14680	23	7C
0005435126390	14680	24	7D
0005435626166	14680	25	7E
0005435126358	14680	26	7F
0005435126363	14680	27	8A
0005435126364	14680	28	8D
0005435126385	14680	29	8E
0005435126384	14680	30	8F
0005435126362	14680	31	9A
0005434411734	14680	32	9C
0005435126365	14680	33	9D
0005435626169	14680	34	9E
0005434411743	14680	35	9F
0005435554185	14680	36	10A
0005435126366	14680	37	10C
0005435126395	14680	38	10D
0005435626171	14680	39	10E
0005434411746	14680	40	11A
0005435554184	14680	41	11C
0005435126376	14680	42	11D
0005435554187	14680	43	11E
0005435126392	14680	44	11F
0005435126380	14680	45	13D
0005435126367	14680	46	13E
0005435126383	14680	47	14A
0005435126393	14680	48	14D
0005435126373	14680	49	15A
0005435126372	14680	50	15C
0005435126369	14680	51	15D
0005434928286	14680	52	15E
0005435126361	14680	53	15F
0005435126370	14680	54	16E
0005435626167	14680	55	16F
0005434928287	14680	56	17A
0005435126355	14680	57	17C
0005435126368	14680	58	17E
0005434411739	14680	59	17F
0005435126374	14680	60	18C
0005435126378	14680	61	18D
0005435126377	14680	62	18E
0005434928283	14680	63	19A
0005435626173	14680	64	19C
0005435126386	14680	65	19D
0005435626165	14680	66	19E
0005435126357	14680	67	19F
0005435126360	14680	68	20C
0005435126381	14680	69	20F
0005435443225	7095	1	1A
0005435715475	7095	2	1C
0005435715461	7095	3	2A
0005435715470	7095	4	3A
0005435443224	7095	5	3C
0005435715476	7095	6	4A
0005435443228	7095	7	4C
0005435715462	7095	8	5D
0005435715458	7095	9	5E
0005435443222	7095	10	6E
0005435443205	7095	11	7A
0005435715465	7095	12	7C
0005435715474	7095	13	7E
0005435219178	7095	14	7F
0005435443229	7095	15	8A
0005435715473	7095	16	8F
0005432400122	7095	17	9A
0005435178485	7095	18	9D
0005435216556	7095	19	9F
0005432398198	7095	20	10A
0005432400123	7095	21	10D
0005435178482	7095	22	11E
0005435219182	7095	23	11F
0005435715463	7095	24	12A
0005432398197	7095	25	12C
0005435216557	7095	26	12D
0005435443226	7095	27	12F
0005435443230	7095	28	13E
0005435715459	7095	29	14C
0005435216575	7095	30	14D
0005435715472	7095	31	14F
0005435178472	7095	32	15C
0005435715466	7095	33	15D
0005432400124	7095	34	15E
0005435219175	7095	35	15F
0005435715464	7095	36	16C
0005432398196	7095	37	17C
0005435715467	7095	38	17D
0005435443206	7095	39	17E
0005435715471	7095	40	17F
0005435219183	7095	41	18A
0005435715469	7095	42	18C
0005432398199	7095	43	19D
0005435715460	7095	44	19E
0005435221047	7095	45	19F
0005432400125	7095	46	20C
0005435715468	7095	47	20F
0005435443311	27090	1	1C
0005435443317	27090	2	2A
0005435715335	27090	3	2C
0005432394068	27090	4	2F
0005435715322	27090	5	3C
0005435715311	27090	6	3D
0005435443310	27090	7	4A
0005432394053	27090	8	4D
0005435443309	27090	9	4F
0005435715346	27090	10	5C
0005435443313	27090	11	5E
0005432398161	27090	12	5F
0005435715312	27090	13	6D
0005435715337	27090	14	6E
0005432398171	27090	15	6F
0005435715336	27090	16	7C
0005435178494	27090	17	7D
0005435443308	27090	18	8C
0005432398162	27090	19	8D
0005435715348	27090	20	9A
0005435715360	27090	21	9D
0005435443312	27090	22	10C
0005435715309	27090	23	10D
0005435715181	27090	24	10F
0005432398168	27090	25	11D
0005435715182	27090	26	11E
0005432398172	27090	27	12C
0005435715237	27090	28	12D
0005432398155	27090	29	13A
0005435715388	27090	30	13D
0005435715299	27090	31	13E
0005432398157	27090	32	13F
0005435715316	27090	33	14A
0005435715387	27090	34	14C
0005435443314	27090	35	15D
0005435715238	27090	36	15F
0005435443316	27090	37	16E
0005435443315	27090	38	17A
0005435715310	27090	39	17C
0005432398160	27090	40	17D
0005435715305	27090	41	17E
0005435715405	27090	42	19D
0005432398156	27090	43	19E
0005435443318	27090	44	20A
0005434084929	2740	1	1B
0005434084928	2740	2	2B
0005434084930	2740	3	4A
0005434084932	2740	4	4B
0005433060389	2740	5	5B
0005434084931	2740	6	6A
0005434084895	28474	1	1A
0005434084894	28474	2	1B
0005434084892	28474	3	2A
0005434084893	28474	4	2B
0005433060413	28474	5	3A
0005434084885	28474	6	4A
0005434084886	28474	7	5A
0005434084900	28474	8	5B
0005433060412	28474	9	6A
0005434084896	28474	10	6B
0005432632708	25201	1	1A
0005432632719	25201	2	1B
0005432632722	25201	3	1C
0005432632723	25201	4	2A
0005432632713	25201	5	2B
0005435844263	25201	6	2C
0005432632707	25201	7	2D
0005432632725	25201	8	3B
0005435844273	25201	9	4A
0005432632727	25201	10	4B
0005435844279	25201	11	4C
0005432632715	25201	12	4D
0005432632720	25201	13	5A
0005435844269	25201	14	5B
0005435844270	25201	15	5C
0005432632711	25201	16	5D
0005432632721	25201	17	6A
0005435844264	25201	18	6C
0005435844267	25201	19	6D
0005432632728	25201	20	7A
0005432632724	25201	21	7B
0005435844262	25201	22	7C
0005432632718	25201	23	7D
0005435844268	25201	24	18A
0005435844266	25201	25	18B
0005432632712	25201	26	18C
0005432632714	25201	27	18D
0005432632710	25201	28	19A
0005432632706	25201	29	19C
0005435844280	25201	30	19D
0005435844265	25201	31	20A
0005432632717	25201	32	20C
0005432632709	25201	33	21A
0005432632726	25201	34	21B
0005432632732	25201	35	21C
0005432632730	25201	36	21D
0005435844282	25201	37	22B
0005432632731	25201	38	22C
0005432632716	25201	39	22D
0005432632729	25201	40	23A
0005435844272	25201	41	23B
0005435844316	28174	1	1A
0005432632649	28174	2	1B
0005432632620	28174	3	1C
0005435844326	28174	4	1D
0005435844318	28174	5	2A
0005432632680	28174	6	2B
0005432632634	28174	7	2C
0005432632648	28174	8	2D
0005432632670	28174	9	3A
0005432632651	28174	10	3B
0005435844314	28174	11	3C
0005435844320	28174	12	3D
0005432632681	28174	13	4A
0005435844322	28174	14	4B
0005432632674	28174	15	4C
0005432632662	28174	16	4D
0005432632641	28174	17	5A
0005435844321	28174	18	5B
0005432632655	28174	19	5C
0005432632663	28174	20	5D
0005432632652	28174	21	6A
0005435844324	28174	22	6B
0005432632669	28174	23	6C
0005432632631	28174	24	6D
0005432632673	28174	25	7A
0005432632682	28174	26	7B
0005432632624	28174	27	7C
0005432632650	28174	28	7D
0005432632633	28174	29	18A
0005432632647	28174	30	18B
0005432632698	28174	31	18D
0005432632635	28174	32	19A
0005432632665	28174	33	19B
0005432632659	28174	34	19C
0005435844315	28174	35	19D
0005432632658	28174	36	20A
0005435844325	28174	37	20B
0005432632656	28174	38	20C
0005432632666	28174	39	20D
0005435844323	28174	40	21A
0005435844317	28174	41	21B
0005432632644	28174	42	21C
0005432632695	28174	43	21D
0005432632683	28174	44	22A
0005432632676	28174	45	22B
0005432632696	28174	46	22C
0005432632668	28174	47	22D
0005435844319	28174	48	23A
0005435844313	28174	49	23B
0005435517743	11370	1	1D
0005435517805	11370	2	3C
0005435517744	11370	3	4D
0005435517795	11370	4	4F
0005435517811	11370	5	5C
0005435540854	11370	6	5F
0005435517720	11370	7	6A
0005435517755	11370	8	6E
0005435540866	11370	9	6F
0005435540811	11370	10	7C
0005435517738	11370	11	7D
0005435517796	11370	12	8F
0005435517719	11370	13	9C
0005435540800	11370	14	9D
0005435540801	11370	15	9E
0005435540813	11370	16	10A
0005435517761	11370	17	10D
0005435517751	11370	18	11A
0005435540812	11370	19	11C
0005435517650	11370	20	11E
0005435517769	11370	21	12C
0005435517798	11370	22	12D
0005435517708	11370	23	12E
0005435517756	11370	24	12F
0005435517745	11370	25	13E
0005435540836	11370	26	15C
0005435517772	11370	27	15D
0005435517793	11370	28	16C
0005435540798	11370	29	16E
0005435517768	11370	30	17C
0005435517750	11370	31	18A
0005435540864	11370	32	18C
0005435517794	11370	33	18E
0005435540863	11370	34	19C
0005435517762	11370	35	19D
0005435517797	11370	36	19E
0005435540880	11370	37	19F
0005435517834	11370	38	20A
0005435540868	11370	39	20C
0005435517742	11370	40	20D
0005435517651	11370	41	20E
0005435540799	11370	42	20F
0005435540984	22237	1	1A
0005432294485	22237	2	3A
0005435540995	22237	3	3F
0005435529250	22237	4	4C
0005435529247	22237	5	4D
0005435529240	22237	6	4E
0005432294486	22237	7	4F
0005432294484	22237	8	5A
0005435529248	22237	9	5C
0005435529239	22237	10	6A
0005435540997	22237	11	6D
0005435540986	22237	12	6E
0005435540989	22237	13	6F
0005435540994	22237	14	7C
0005435529236	22237	15	7D
0005435540993	22237	16	8C
0005435540992	22237	17	8D
0005435540990	22237	18	8F
0005435540987	22237	19	9D
0005435529235	22237	20	10A
0005435529234	22237	21	10E
0005435529243	22237	22	11A
0005435529244	22237	23	11C
0005435540978	22237	24	11E
0005435529237	22237	25	12A
0005435529253	22237	26	12D
0005435529242	22237	27	12F
0005435540985	22237	28	13C
0005435529251	22237	29	13F
0005435540996	22237	30	14E
0005435529246	22237	31	15A
0005435529241	22237	32	15C
0005435529255	22237	33	16A
0005435529238	22237	34	16C
0005435540982	22237	35	17D
0005435529249	22237	36	17E
0005435540981	22237	37	17F
0005435540980	22237	38	18D
0005435529254	22237	39	18F
0005435540983	22237	40	19A
0005435540998	22237	41	19C
0005435529252	22237	42	19D
0005435529245	22237	43	19F
0005435540991	22237	44	20D
0005435540979	22237	45	20E
0005435540988	22237	46	20F
0005434907287	2291	1	1A
0005434907306	2291	2	1C
0005434907313	2291	3	1F
0005434907263	2291	4	2A
0005434907289	2291	5	2C
0005434907308	2291	6	2D
0005434907292	2291	7	2F
0005433251241	2291	8	3A
0005433251125	2291	9	3C
0005434907283	2291	10	3D
0005434907285	2291	11	3F
0005433251221	2291	12	4A
0005433251185	2291	13	4C
0005434907264	2291	14	4D
0005434907277	2291	15	4E
0005434907266	2291	16	4F
0005434907309	2291	17	5A
0005434907265	2291	18	5C
0005433251268	2291	19	5D
0005433251426	2291	20	5E
0005433251184	2291	21	6A
0005434907296	2291	22	6C
0005433251326	2291	23	6D
0005433251275	2291	24	6E
0005433251186	2291	25	6F
0005434907301	2291	26	7A
0005433251230	2291	27	7C
0005434907291	2291	28	7D
0005433251239	2291	29	7E
0005434907274	2291	30	7F
0005434907312	2291	31	8A
0005433251305	2291	32	8C
0005434907267	2291	33	8D
0005434907315	2291	34	8E
0005434907300	2291	35	8F
0005434907288	2291	36	9A
0005434907304	2291	37	9C
0005433251138	2291	38	9D
0005433251229	2291	39	9E
0005433251243	2291	40	9F
0005433251216	2291	41	10A
0005433251171	2291	42	10C
0005433251280	2291	43	10D
0005433400950	2291	44	10F
0005434907279	2291	45	11A
0005434907305	2291	46	11C
0005434907280	2291	47	11D
0005434907303	2291	48	11E
0005433251277	2291	49	12A
0005434907286	2291	50	12C
0005434907294	2291	51	12D
0005433251217	2291	52	12E
0005433251276	2291	53	12F
0005434907273	2291	54	13A
0005434907284	2291	55	13C
0005434907268	2291	56	13D
0005434907298	2291	57	13E
0005434907275	2291	58	13F
0005433251126	2291	59	14A
0005434907310	2291	60	14C
0005434907307	2291	61	14D
0005434907299	2291	62	14E
0005433251278	2291	63	14F
0005434907297	2291	64	15A
0005434907311	2291	65	15D
0005434907278	2291	66	15E
0005434907295	2291	67	15F
0005433251285	2291	68	16A
0005433251286	2291	69	16C
0005434907282	2291	70	16D
0005434907269	2291	71	16E
0005434907281	2291	72	16F
0005434907290	2291	73	17A
0005434907270	2291	74	17C
0005433251141	2291	75	17D
0005434907272	2291	76	17E
0005433251249	2291	77	17F
0005433251283	2291	78	18A
0005433251328	2291	79	18C
0005433251279	2291	80	18D
0005433251304	2291	81	18E
0005434907276	2291	82	18F
0005433251124	2291	83	19A
0005434907314	2291	84	19C
0005434907302	2291	85	19D
0005433251329	2291	86	19E
0005433251240	2291	87	19F
0005433251170	2291	88	20A
0005433251220	2291	89	20D
0005434907271	2291	90	20E
0005434907293	2291	91	20F
0005434906772	25597	1	1A
0005434906844	25597	2	1D
0005433251478	25597	3	1F
0005434906455	25597	4	2A
0005433251474	25597	5	2D
0005433251477	25597	6	2F
0005433251475	25597	7	3A
0005434906795	25597	8	3C
0005434906788	25597	9	3D
0005434906757	25597	10	3F
0005433251467	25597	11	4A
0005433251490	25597	12	4C
0005434906692	25597	13	4D
0005434906734	25597	14	4E
0005434906717	25597	15	4F
0005434906644	25597	16	5A
0005433251489	25597	17	5C
0005434906647	25597	18	5D
0005434906699	25597	19	5E
0005434906643	25597	20	5F
0005434906893	25597	21	6A
0005433251465	25597	22	6C
0005434906752	25597	23	6D
0005434906721	25597	24	6E
0005433251480	25597	25	6F
0005434906831	25597	26	7A
0005434906881	25597	27	7C
0005434906825	25597	28	7D
0005433251485	25597	29	7F
0005434906733	25597	30	7E
0005433251468	25597	31	8A
0005433251466	25597	32	8C
0005433400983	25597	33	8D
0005433251476	25597	34	8E
0005434906880	25597	35	8F
0005434906835	25597	36	9A
0005434906700	25597	37	9C
0005433400982	25597	38	9D
0005434906621	25597	39	9F
0005433251484	25597	40	9E
0005434906876	25597	41	10A
0005434906829	25597	42	10C
0005433251470	25597	43	10D
0005434906820	25597	44	10E
0005433251471	25597	45	10F
0005433251494	25597	46	11A
0005433251488	25597	47	11C
0005434906852	25597	48	11D
0005434906605	25597	49	11E
0005434906646	25597	50	11F
0005433251479	25597	51	12A
0005433251482	25597	52	12C
0005434906843	25597	53	12D
0005434906718	25597	54	12E
0005434906836	25597	55	12F
0005434906889	25597	56	13A
0005433251495	25597	57	13C
0005434906691	25597	58	13D
0005434906645	25597	59	13E
0005433251483	25597	60	13F
0005433251486	25597	61	14A
0005434906839	25597	62	14D
0005434906827	25597	63	14F
0005434906892	25597	64	14E
0005433251472	25597	65	15A
0005433400984	25597	66	15C
0005434906789	25597	67	15D
0005434906853	25597	68	15F
0005434906539	25597	69	16A
0005434906701	25597	70	16C
0005433251492	25597	71	16D
0005434906742	25597	72	16E
0005434906834	25597	73	17A
0005433251487	25597	74	17C
0005434906898	25597	75	17D
0005433251481	25597	76	17E
0005434906731	25597	77	17F
0005434906725	25597	78	18A
0005433251473	25597	79	18C
0005434906790	25597	80	18E
0005434906830	25597	81	18F
0005433251491	25597	82	19A
0005434906716	25597	83	19C
0005433251469	25597	84	19D
0005434906607	25597	85	19E
0005434906828	25597	86	20A
0005434906543	25597	87	20C
0005434906821	25597	88	20E
0005433251493	25597	89	20D
0005434906814	25597	90	20F
0005432621045	2497	1	1A
0005432862251	2497	2	1D
0005432621042	2497	3	2A
0005432621032	2497	4	2B
0005432621041	2497	5	2D
0005432621038	2497	6	3A
0005432621033	2497	7	3C
0005432621034	2497	8	4C
0005432862200	2497	9	5A
0005432862217	2497	10	5C
0005432621044	2497	11	6B
0005432862239	2497	12	7A
0005432862249	2497	13	7B
0005432862216	2497	14	7D
0005432621043	2497	15	18A
0005432621036	2497	16	18C
0005432621040	2497	17	18D
0005432862252	2497	18	19C
0005432621035	2497	19	19D
0005432621037	2497	20	21A
0005432862243	2497	21	21D
0005432621039	2497	22	22B
0005432862218	2497	23	22C
0005432862248	2497	24	23A
0005432862244	2497	25	23B
0005432862301	28054	1	1B
0005432620920	28054	2	1D
0005432620951	28054	3	2B
0005432620973	28054	4	3C
0005432620902	28054	5	3D
0005432862303	28054	6	4A
0005432620941	28054	7	4B
0005432620991	28054	8	4C
0005432620939	28054	9	4D
0005432862299	28054	10	5A
0005432620940	28054	11	5B
0005432620944	28054	12	5C
0005432620901	28054	13	7A
0005432862305	28054	14	7D
0005432862302	28054	15	18B
0005432620912	28054	16	18C
0005432620978	28054	17	19A
0005432620872	28054	18	19C
0005432862300	28054	19	19D
0005432620875	28054	20	20C
0005432620960	28054	21	20D
0005432862304	28054	22	21A
0005432620938	28054	23	21B
0005432862298	28054	24	22C
0005434097467	11775	1	1B
0005434097476	13063	1	4A
0005433452738	31071	1	1A
0005433451619	31071	2	1B
0005433452739	31071	3	3A
0005433451620	31071	4	5B
0005433451618	31071	5	5A
0005433454856	31376	1	1A
0005433452723	31376	2	1B
0005433454853	31376	3	4B
0005433454857	31376	4	5A
0005433454852	31376	5	6A
0005433129238	12013	1	1A
0005433134089	12013	2	1B
0005433129225	12013	3	2A
0005433129231	12013	4	2C
0005434184654	12013	5	2D
0005433129246	12013	6	3B
0005433134098	12013	7	3D
0005433134090	12013	8	4A
0005434142578	12013	9	5B
0005433129224	12013	10	5D
0005433129243	12013	11	6A
0005434184655	12013	12	6B
0005433129223	12013	13	7A
0005433129230	12013	14	7D
0005433129248	12013	15	18C
0005434142577	12013	16	18D
0005433129247	12013	17	22D
0005433131707	29822	1	1A
0005433131708	29822	2	1C
0005434183580	29822	3	1D
0005433131710	29822	4	2A
0005433131706	29822	5	2B
0005434142607	29822	6	3C
0005434184666	29822	7	3D
0005434142605	29822	8	4C
0005433134138	29822	9	5A
0005433134139	29822	10	5D
0005433134136	29822	11	19B
0005434142608	29822	12	19C
0005433134137	29822	13	19D
0005434184664	29822	14	20A
0005433131709	29822	15	20B
0005434142606	29822	16	21D
0005434183579	29822	17	22B
0005434184665	29822	18	23B
0005435935023	16503	1	1A
0005435697321	16503	2	1C
0005435697307	16503	3	2A
0005435935032	16503	4	2B
0005435697308	16503	5	2C
0005435697316	16503	6	2D
0005435697306	16503	7	3A
0005435697312	16503	8	3B
0005435935019	16503	9	3D
0005435697324	16503	10	4A
0005435697319	16503	11	4B
0005435697328	16503	12	4C
0005435697314	16503	13	4D
0005435935024	16503	14	5B
0005435697311	16503	15	5C
0005435697310	16503	16	5D
0005435697326	16503	17	6A
0005435697317	16503	18	6B
0005435697305	16503	19	6C
0005435697322	16503	20	6D
0005435697329	16503	21	7A
0005435697323	16503	22	7D
0005435697327	16503	23	18B
0005435697313	16503	24	18D
0005435697304	16503	25	19A
0005435697303	16503	26	19C
0005435935031	16503	27	20A
0005435697309	16503	28	20B
0005435697320	16503	29	20D
0005435697318	16503	30	21D
0005435697325	16503	31	22A
0005435697330	16503	32	22B
0005435697315	16503	33	22C
0005435935022	16503	34	23A
0005435697189	24730	1	1A
0005435697114	24730	2	1C
0005435697062	24730	3	2C
0005435697041	24730	4	2D
0005435697029	24730	5	3A
0005435697085	24730	6	3D
0005435697097	24730	7	4A
0005435697096	24730	8	4B
0005435935047	24730	9	4C
0005435697084	24730	10	4D
0005435697030	24730	11	5B
0005435697115	24730	12	6B
0005435696976	24730	13	7A
0005435697142	24730	14	18D
0005435697000	24730	15	19A
0005435935045	24730	16	19C
0005435697187	24730	17	19D
0005435935046	24730	18	20A
0005435697036	24730	19	20B
0005435697186	24730	20	20D
0005435697120	24730	21	21C
0005435697173	24730	22	22B
0005435696918	24730	23	22C
0005435697077	24730	24	23B
0005432968823	18789	1	1A
0005433724802	18789	2	1B
0005433724803	18789	3	2A
0005433724804	18789	4	3B
0005433724805	18789	5	4A
0005432968824	18789	6	4B
0005432968827	18789	7	6B
0005433724750	21649	1	1A
0005433724764	21649	2	2A
0005433724768	21649	3	1B
0005433724749	21649	4	2B
0005433724770	21649	5	3A
0005433724763	21649	6	3B
0005433724769	21649	7	4A
0005432968842	21649	8	4B
0005433724771	21649	9	5A
0005432968843	21649	10	5B
0005433724765	21649	11	6A
0005433724773	21649	12	6B
0005434138203	7312	1	1A
0005434138195	7312	2	1D
0005434138192	7312	3	1F
0005434138177	7312	4	2A
0005434138147	7312	5	2C
0005434138127	7312	6	2D
0005434138196	7312	7	2F
0005434138172	7312	8	3A
0005434138137	7312	9	3C
0005434138201	7312	10	3D
0005434138198	7312	11	3F
0005434138151	7312	12	4A
0005434138131	7312	13	4C
0005434138191	7312	14	4D
0005434138169	7312	15	4E
0005434138173	7312	16	4F
0005434138205	7312	17	5A
0005434138170	7312	18	5C
0005434138208	7312	19	5D
0005434138155	7312	20	5E
0005434138181	7312	21	5F
0005434138185	7312	22	6A
0005434138164	7312	23	6C
0005434138140	7312	24	6D
0005434138126	7312	25	6E
0005434138125	7312	26	6F
0005434138143	7312	27	7A
0005434138194	7312	28	7C
0005434138190	7312	29	7D
0005434087515	7312	30	7E
0005434138149	7312	31	7F
0005434138136	7312	32	8A
0005434138183	7312	33	8C
0005434138141	7312	34	8D
0005434138154	7312	35	8E
0005434138204	7312	36	8F
0005434138156	7312	37	9A
0005434138211	7312	38	9C
0005434138160	7312	39	9D
0005434087516	7312	40	9E
0005434138182	7312	41	9F
0005434138165	7312	42	10A
0005434138157	7312	43	10C
0005434087512	7312	44	10D
0005434138212	7312	45	10E
0005434138158	7312	46	10F
0005434138167	7312	47	11A
0005434087511	7312	48	11C
0005434138209	7312	49	11D
0005434138186	7312	50	11E
0005434138132	7312	51	11F
0005434138213	7312	52	12A
0005434138145	7312	53	12C
0005434138153	7312	54	12D
0005434138189	7312	55	12E
0005434138129	7312	56	12F
0005434138148	7312	57	13A
0005434087514	7312	58	13C
0005434138150	7312	59	13D
0005434138142	7312	60	13E
0005434138162	7312	61	13F
0005434138197	7312	62	14A
0005434138163	7312	63	14C
0005434138179	7312	64	14D
0005434138193	7312	65	14E
0005434138207	7312	66	14F
0005434138176	7312	67	15A
0005434138161	7312	68	15C
0005434138133	7312	69	15D
0005434138139	7312	70	15E
0005434138166	7312	71	15F
0005434138214	7312	72	16A
0005434138168	7312	73	16C
0005434138152	7312	74	16D
0005434138184	7312	75	16E
0005434087513	7312	76	16F
0005434138175	7312	77	17A
0005434138130	7312	78	17C
0005434138144	7312	79	17D
0005434138200	7312	80	17E
0005434138138	7312	81	17F
0005434138180	7312	82	18A
0005434138206	7312	83	18C
0005434138134	7312	84	18D
0005434138171	7312	85	18E
0005434138146	7312	86	18F
0005434138128	7312	87	19A
0005434138174	7312	88	19C
0005434138187	7312	89	19D
0005434138188	7312	90	19E
0005434138210	7312	91	19F
0005434138199	7312	92	20A
0005434138135	7312	93	20C
0005434138202	7312	94	20D
0005434138159	7312	95	20E
0005434138178	7312	96	20F
0005434087486	28545	1	1A
0005434137107	28545	2	1D
0005434137339	28545	3	1F
0005434137340	28545	4	2C
0005434137448	28545	5	2D
0005434137458	28545	6	2F
0005434137018	28545	7	3A
0005434137455	28545	8	3C
0005434137104	28545	9	3D
0005434137434	28545	10	3F
0005434137169	28545	11	4A
0005434137324	28545	12	4C
0005434137334	28545	13	4D
0005434137032	28545	14	4E
0005434137384	28545	15	4F
0005434137323	28545	16	5A
0005434137215	28545	17	5C
0005434137284	28545	18	5D
0005434137016	28545	19	5E
0005434137381	28545	20	5F
0005434137263	28545	21	6A
0005434137416	28545	22	6C
0005434137551	28545	23	6D
0005434137341	28545	24	6E
0005434137110	28545	25	6F
0005434137462	28545	26	7A
0005434137312	28545	27	7C
0005434137103	28545	28	7D
0005434137289	28545	29	7E
0005434137484	28545	30	7F
0005434137435	28545	31	8A
0005434087472	28545	32	8C
0005434137011	28545	33	8D
0005434137502	28545	34	8E
0005434136875	28545	35	8F
0005434137457	28545	36	9C
0005434137282	28545	37	9D
0005434137267	28545	38	9E
0005434137109	28545	39	9F
0005434137352	28545	40	10A
0005434137327	28545	41	10C
0005434137386	28545	42	10D
0005434137290	28545	43	10E
0005434137124	28545	44	10F
0005434087490	28545	45	11A
0005434137488	28545	46	11C
0005434137219	28545	47	11D
0005434136876	28545	48	11F
0005434087477	28545	49	12A
0005434137261	28545	50	12C
0005434137013	28545	51	12D
0005434137424	28545	52	12E
0005434137301	28545	53	12F
0005434137154	28545	54	13A
0005434137093	28545	55	13C
0005434137246	28545	56	13D
0005434137216	28545	57	13E
0005434137464	28545	58	13F
0005434137283	28545	59	14A
0005434137247	28545	60	14C
0005434137259	28545	61	14D
0005434137465	28545	62	14E
0005434137281	28545	63	14F
0005434087485	28545	64	15A
0005434137168	28545	65	15C
0005434137010	28545	66	15D
0005434137557	28545	67	15E
0005434087484	28545	68	15F
0005434137268	28545	69	16A
0005434137463	28545	70	16C
0005434137436	28545	71	16D
0005434087478	28545	72	16E
0005434137326	28545	73	16F
0005434137335	28545	74	17A
0005434137269	28545	75	17D
0005434137460	28545	76	17E
0005434137461	28545	77	18A
0005434137433	28545	78	18C
0005434137459	28545	79	18D
0005434137385	28545	80	18F
0005434137206	28545	81	19A
0005434137487	28545	82	19C
0005434137479	28545	83	19D
0005434137456	28545	84	19F
0005434137425	28545	85	20A
0005434137538	28545	86	20C
0005434137552	28545	87	20D
0005434137167	28545	88	20E
0005434137501	28545	89	20F
0005433407534	1940	1	1B
0005433407504	1940	2	2C
0005434610229	1940	3	3D
0005435808234	1940	4	4B
0005435808231	1940	5	5B
0005435808237	1940	6	6A
0005435808232	1940	7	6B
0005435808236	1940	8	6D
0005433407503	1940	9	7C
0005433407533	1940	10	7D
0005435808240	1940	11	18A
0005434610228	1940	12	18C
0005435808239	1940	13	19C
0005435808233	1940	14	20C
0005435808235	1940	15	21A
0005434610230	1940	16	22B
0005435808238	1940	17	23B
0005433407558	23074	1	1A
0005433407556	23074	2	1B
0005435808096	23074	3	1C
0005435808094	23074	4	1D
0005435808093	23074	5	2C
0005433407561	23074	6	3A
0005433407562	23074	7	3B
0005435808148	23074	8	3D
0005435808146	23074	9	4A
0005433407564	23074	10	4B
0005435808145	23074	11	4C
0005434610194	23074	12	4D
0005433407555	23074	13	5C
0005433407559	23074	14	5D
0005435808163	23074	15	6A
0005435808091	23074	16	6C
0005435808076	23074	17	7B
0005435808120	23074	18	7C
0005435808147	23074	19	18A
0005433407560	23074	20	18B
0005433407557	23074	21	18C
0005435808104	23074	22	19B
0005435808121	23074	23	19C
0005435808082	23074	24	19D
0005435808083	23074	25	20B
0005435808084	23074	26	21A
0005433407563	23074	27	21C
0005435808092	23074	28	21D
0005435808077	23074	29	22B
0005435808116	23074	30	22C
0005435808127	23074	31	23A
0005434503660	16710	1	1A
0005434503629	16710	2	1B
0005434503719	16710	3	1C
0005434503791	16710	4	1D
0005434503840	16710	5	2A
0005434503649	16710	6	2B
0005434503868	16710	7	2C
0005434503826	16710	8	2D
0005434503774	16710	9	3A
0005434503873	16710	10	3B
0005434503696	16710	11	3C
0005434503839	16710	12	3D
0005434503689	16710	13	4A
0005434503753	16710	14	4B
0005434503746	16710	15	4C
0005434503815	16710	16	4D
0005434503772	16710	17	5A
0005434503836	16710	18	5B
0005434503864	16710	19	5C
0005434503751	16710	20	5D
0005434503729	16710	21	6A
0005434503690	16710	22	6B
0005434503638	16710	23	6C
0005434503727	16710	24	6D
0005434503639	16710	25	7A
0005434503752	16710	26	7B
0005434503724	16710	27	7C
0005434503691	16710	28	7D
0005434503760	16710	29	18A
0005434503666	16710	30	18B
0005434503627	16710	31	18D
0005434503650	16710	32	18C
0005434503776	16710	33	19A
0005434503869	16710	34	19B
0005434503725	16710	35	19C
0005434503758	16710	36	19D
0005434503816	16710	37	20A
0005434503806	16710	38	20B
0005434503713	16710	39	20C
0005434503790	16710	40	20D
0005434503747	16710	41	21A
0005434503663	16710	42	21B
0005434503818	16710	43	21C
0005434503817	16710	44	21D
0005434503628	16710	45	22A
0005434503807	16710	46	22B
0005434503808	16710	47	22C
0005434503728	16710	48	22D
0005434503750	16710	49	23A
0005434503749	16710	50	23B
0005434504120	22889	1	1A
0005434504118	22889	2	1B
0005434504108	22889	3	1C
0005434504122	22889	4	1D
0005434504114	22889	5	2A
0005434504127	22889	6	2B
0005434504119	22889	7	2C
0005434504143	22889	8	2D
0005434504117	22889	9	3A
0005434504133	22889	10	3B
0005434504112	22889	11	3C
0005434504107	22889	12	3D
0005434504139	22889	13	4B
0005434504131	22889	14	4D
0005434504138	22889	15	4C
0005434504140	22889	16	5A
0005434504109	22889	17	5B
0005434504137	22889	18	5C
0005434504123	22889	19	5D
0005434504116	22889	20	6A
0005434504130	22889	21	6B
0005434504132	22889	22	6D
0005434504106	22889	23	7B
0005434504124	22889	24	7D
0005434504136	22889	25	18A
0005434504142	22889	26	18B
0005434504105	22889	27	18D
0005434504134	22889	28	19A
0005434504128	22889	29	19B
0005434504104	22889	30	19C
0005434504113	22889	31	20A
0005434504111	22889	32	20C
0005434504126	22889	33	20D
0005434504135	22889	34	21A
0005434504141	22889	35	21B
0005434504121	22889	36	21C
0005434504115	22889	37	22A
0005434504110	22889	38	22B
0005434504125	22889	39	22D
0005434504129	22889	40	23B
0005435078342	2205	1	1A
0005433266624	2205	2	1B
0005435078341	2205	3	1D
0005435078335	2205	4	2B
0005435078337	2205	5	2D
0005435078347	2205	6	3B
0005435078344	2205	7	4C
0005435078336	2205	8	4D
0005435078340	2205	9	5A
0005433266648	2205	10	5B
0005435078334	2205	11	5C
0005435078339	2205	12	6C
0005435078345	2205	13	7A
0005435078338	2205	14	7D
0005433266647	2205	15	18B
0005435078349	2205	16	19A
0005433266649	2205	17	19B
0005433266658	2205	18	20A
0005433266640	2205	19	20B
0005435078343	2205	20	20C
0005435078348	2205	21	21C
0005435078346	2205	22	21D
0005433266646	2205	23	22D
0005435078207	24325	1	1B
0005435078188	24325	2	1C
0005435078245	24325	3	1D
0005433266725	24325	4	2A
0005435078135	24325	5	2B
0005435078186	24325	6	2C
0005435078229	24325	7	3A
0005435078217	24325	8	3C
0005435078266	24325	9	4A
0005433266720	24325	10	4C
0005433266728	24325	11	4D
0005433266726	24325	12	5A
0005435078199	24325	13	5B
0005435078160	24325	14	5D
0005435078185	24325	15	6B
0005435078267	24325	16	6C
0005435078227	24325	17	6D
0005435078180	24325	18	7A
0005433266721	24325	19	7B
0005435078187	24325	20	7D
0005433266727	24325	21	18B
0005435078182	24325	22	19A
0005435078183	24325	23	19B
0005435078228	24325	24	19C
0005435078136	24325	25	19D
0005435078181	24325	26	20B
0005433266723	24325	27	20D
0005435078161	24325	28	21A
0005435078205	24325	29	22A
0005433266724	24325	30	22B
0005433266722	24325	31	22C
0005434988744	6631	1	1A
0005435464497	6631	2	1D
0005435803266	6631	3	2A
0005434988749	6631	4	2C
0005434988747	6631	5	2D
0005435803263	6631	6	3D
0005435803264	6631	7	4A
0005434988746	6631	8	4C
0005434988741	6631	9	5D
0005435803262	6631	10	6B
0005434988751	6631	11	7A
0005434988743	6631	12	7B
0005434988745	6631	13	7D
0005435803265	6631	14	18C
0005434988742	6631	15	18D
0005434988748	6631	16	20B
0005434988750	6631	17	20D
0005434988740	6631	18	21C
0005435464496	6631	19	21D
0005435464508	23603	1	1A
0005434988632	23603	2	1D
0005434988631	23603	3	2A
0005434988607	23603	4	2B
0005434988629	23603	5	3A
0005434988603	23603	6	4A
0005434988596	23603	7	4B
0005435464506	23603	8	5D
0005435464507	23603	9	6D
0005434988630	23603	10	7D
0005434988608	23603	11	18A
0005434988589	23603	12	18C
0005434988588	23603	13	22A
0005434988604	23603	14	22C
0005433449969	30502	1	1A
0005432383168	30502	2	1D
0005432383197	30502	3	1F
0005432383175	30502	4	2A
0005432383178	30502	5	2C
0005433449973	30502	6	2D
0005432383177	30502	7	2F
0005432383199	30502	8	3A
0005432383200	30502	9	4D
0005432383189	30502	10	4E
0005432383198	30502	11	4F
0005433449968	30502	12	5A
0005432383191	30502	13	5C
0005432383194	30502	14	5D
0005433449982	30502	15	5F
0005432383196	30502	16	6C
0005432383183	30502	17	6E
0005433449983	30502	18	6F
0005432383190	30502	19	7A
0005432383195	30502	20	7C
0005433449965	30502	21	7F
0005432383187	30502	22	8D
0005433449978	30502	23	8E
0005432383174	30502	24	8F
0005433449971	30502	25	9C
0005432383181	30502	26	9D
0005433449980	30502	27	9F
0005432383188	30502	28	10E
0005433449970	30502	29	10F
0005432383169	30502	30	11A
0005432383176	30502	31	11D
0005433449977	30502	32	12A
0005433449984	30502	33	12C
0005432383167	30502	34	12D
0005433449981	30502	35	12E
0005433449966	30502	36	13A
0005432383193	30502	37	13E
0005432383173	30502	38	13F
0005432383171	30502	39	14A
0005433449976	30502	40	14C
0005433449963	30502	41	14D
0005432383180	30502	42	14E
0005433449975	30502	43	15C
0005433449964	30502	44	15E
0005433449974	30502	45	15F
0005433454876	30502	46	16A
0005432383184	30502	47	17A
0005433449962	30502	48	17D
0005432383179	30502	49	17E
0005432383172	30502	50	17F
0005432383185	30502	51	18C
0005433449979	30502	52	18E
0005432383192	30502	53	19A
0005432383186	30502	54	19C
0005432383182	30502	55	19E
0005433449967	30502	56	19F
0005432383170	30502	57	20C
0005432383201	30502	58	20E
0005433449972	30502	59	20F
0005432382710	31328	1	1A
0005432382767	31328	2	1C
0005432382646	31328	3	1D
0005432382798	31328	4	1F
0005433449808	31328	5	2A
0005432382785	31328	6	2D
0005432382877	31328	7	2F
0005433449779	31328	8	3A
0005433449858	31328	9	3C
0005433451612	31328	10	3D
0005432382812	31328	11	4A
0005432382695	31328	12	4C
0005432382757	31328	13	4D
0005433449815	31328	14	5C
0005432382799	31328	15	5D
0005433449740	31328	16	5E
0005432382719	31328	17	5F
0005432382734	31328	18	6A
0005432382786	31328	19	6C
0005433449807	31328	20	6D
0005432382731	31328	21	6F
0005432382837	31328	22	7A
0005432382647	31328	23	7D
0005433449846	31328	24	7E
0005433449818	31328	25	7F
0005433449720	31328	26	8A
0005433449776	31328	27	8C
0005432382709	31328	28	8D
0005432382665	31328	29	8E
0005432382818	31328	30	8F
0005432382815	31328	31	9C
0005432382811	31328	32	9D
0005432382865	31328	33	9E
0005432382857	31328	34	9F
0005432382584	31328	35	10D
0005432382910	31328	36	10C
0005433449813	31328	37	10F
0005432382740	31328	38	11A
0005432382878	31328	39	11D
0005432382783	31328	40	11E
0005433449869	31328	41	12A
0005433449695	31328	42	12C
0005432382906	31328	43	12E
0005432382718	31328	44	13C
0005433449814	31328	45	13D
0005432382792	31328	46	14A
0005433451611	31328	47	14C
0005433449886	31328	48	14D
0005433449719	31328	49	14E
0005432382741	31328	50	14F
0005432382782	31328	51	15C
0005432382794	31328	52	15D
0005432382880	31328	53	16A
0005432382666	31328	54	16C
0005433451598	31328	55	16D
0005433449817	31328	56	16E
0005432382696	31328	57	17A
0005433449778	31328	58	17C
0005432382875	31328	59	17F
0005432382713	31328	60	18A
0005432382874	31328	61	18C
0005432382876	31328	62	18D
0005432382739	31328	63	19A
0005433449718	31328	64	19C
0005432382702	31328	65	19D
0005432382735	31328	66	20A
0005432382793	31328	67	20C
0005433449771	31328	68	20D
0005433449761	31328	69	20E
0005432382694	31328	70	20F
0005433131679	10788	1	1A
0005435299738	10788	2	1C
0005435299736	10788	3	1D
0005435304111	10788	4	2D
0005435304128	10788	5	3A
0005433126788	10788	6	3C
0005433131678	10788	7	3D
0005435299723	10788	8	4B
0005433126773	10788	9	4D
0005433126793	10788	10	5C
0005433126772	10788	11	6B
0005435304123	10788	12	6C
0005433131645	10788	13	6D
0005435299726	10788	14	7C
0005433126789	10788	15	7D
0005433126792	10788	16	18A
0005435299724	10788	17	18B
0005435304103	10788	18	19B
0005435304132	10788	19	20A
0005433126790	10788	20	20D
0005435304122	10788	21	21A
0005435304129	10788	22	22C
0005435304119	10788	23	23B
0005433129281	29747	1	2B
0005435299781	29747	2	4B
0005435302204	29747	3	4C
0005433126850	29747	4	5B
0005435299779	29747	5	6B
0005433126849	29747	6	18C
0005433129280	29747	7	18D
0005433129279	29747	8	19A
0005433126851	29747	9	19B
0005435299782	29747	10	19C
0005435302203	29747	11	21A
0005435299778	29747	12	21C
0005435299780	29747	13	21D
0005433129278	29747	14	22B
0005433126848	29747	15	22C
0005435302202	29747	16	23A
0005434287285	2399	1	1A
0005434287282	2399	2	1B
0005434287281	2399	3	1C
0005434287280	2399	4	1D
0005434287283	2399	5	2A
0005433109956	2399	6	2B
0005433109993	2399	7	2C
0005434287289	2399	8	2D
0005433109946	2399	9	3A
0005432264476	2399	10	3B
0005433109957	2399	11	3C
0005434287290	2399	12	4A
0005434287294	2399	13	4B
0005434287296	2399	14	4C
0005434287297	2399	15	4D
0005433109980	2399	16	5B
0005434287292	2399	17	5C
0005433109981	2399	18	5D
0005434287299	2399	19	6B
0005434287288	2399	20	6A
0005433109969	2399	21	6D
0005433109971	2399	22	6C
0005434287284	2399	23	7A
0005434287302	2399	24	7C
0005433109945	2399	25	7D
0005434287279	2399	26	18A
0005433110001	2399	27	18B
0005434287291	2399	28	18C
0005433109919	2399	29	18D
0005433109923	2399	30	19A
0005434287287	2399	31	19B
0005434287298	2399	32	19C
0005433109970	2399	33	19D
0005434287286	2399	34	20A
0005434287293	2399	35	20B
0005434287295	2399	36	20D
0005432264475	2399	37	21D
0005433109899	2399	38	22A
0005434287301	2399	39	22C
0005433110000	2399	40	23A
0005434287300	2399	41	23B
0005434287072	26850	1	1A
0005433110059	26850	2	1C
0005434287130	26850	3	2A
0005433110049	26850	4	2B
0005434287197	26850	5	2C
0005433110052	26850	6	3A
0005433110058	26850	7	3B
0005433110053	26850	8	4A
0005434287013	26850	9	4C
0005434287196	26850	10	4D
0005433110050	26850	11	5B
0005434287055	26850	12	5C
0005434287124	26850	13	5D
0005434287153	26850	14	6A
0005434287092	26850	15	6B
0005434287066	26850	16	6D
0005434287090	26850	17	7A
0005433110051	26850	18	7C
0005433110048	26850	19	7D
0005434287103	26850	20	18B
0005433110055	26850	21	18D
0005433110054	26850	22	19B
0005434287073	26850	23	19C
0005434287113	26850	24	19D
0005434287184	26850	25	20A
0005434287074	26850	26	20B
0005433110060	26850	27	20D
0005434287114	26850	28	21A
0005434287091	26850	29	21C
0005434287075	26850	30	21D
0005433110057	26850	31	22A
0005434287125	26850	32	22C
0005433110056	26850	33	23A
0005434287067	26850	34	23B
0005434269071	25489	1	1B
0005435856205	25489	2	3A
0005435856206	25489	3	4C
0005434272176	25489	4	5A
0005434269081	25489	5	5B
0005435856204	25489	6	6B
0005435856207	25489	7	7D
0005434269082	25489	8	18A
0005434269080	25489	9	18B
0005434269077	25489	10	21C
0005434272177	25489	11	23B
0005434272192	26647	1	4A
0005434273075	26647	2	5D
0005434273076	26647	3	21A
0005434273077	26647	4	21C
0005433868460	4795	1	1A
0005433868446	4795	2	1B
0005433868467	4795	3	1C
0005433868438	4795	4	2A
0005433868449	4795	5	2B
0005433868471	4795	6	2C
0005433868436	4795	7	2D
0005433868463	4795	8	3B
0005433868432	4795	9	3C
0005433868440	4795	10	3D
0005435860450	4795	11	4A
0005433868452	4795	12	4B
0005433868447	4795	13	4C
0005433868457	4795	14	5B
0005433868458	4795	15	5C
0005433868439	4795	16	5D
0005435860451	4795	17	6A
0005433868464	4795	18	6B
0005433868469	4795	19	6C
0005433868433	4795	20	6D
0005433868462	4795	21	7B
0005433868468	4795	22	7A
0005433868450	4795	23	7C
0005433868431	4795	24	7D
0005433868448	4795	25	18A
0005433868451	4795	26	18B
0005433868456	4795	27	18C
0005433868444	4795	28	18D
0005433868445	4795	29	19A
0005435860452	4795	30	19B
0005433868454	4795	31	19C
0005435860446	4795	32	19D
0005433868453	4795	33	20A
0005433868441	4795	34	20B
0005433868435	4795	35	20C
0005433868434	4795	36	20D
0005433868442	4795	37	21A
0005433868437	4795	38	21B
0005433868455	4795	39	21C
0005433868466	4795	40	21D
0005433868443	4795	41	22A
0005433868470	4795	42	22B
0005433868461	4795	43	22C
0005433868472	4795	44	22D
0005433868459	4795	45	23A
0005433868465	4795	46	23B
0005433868187	32618	1	1A
0005433868078	32618	2	1B
0005433868168	32618	3	1C
0005433868002	32618	4	1D
0005433868119	32618	5	2A
0005433868167	32618	6	2B
0005433868053	32618	7	2C
0005433868207	32618	8	2D
0005433868026	32618	9	3A
0005433868082	32618	10	3B
0005433868003	32618	11	3C
0005433867916	32618	12	3D
0005433868035	32618	13	4A
0005433867917	32618	14	4B
0005433868000	32618	15	4C
0005433868177	32618	16	4D
0005433868113	32618	17	5A
0005433868011	32618	18	5B
0005433868209	32618	19	5C
0005433868041	32618	20	5D
0005433868097	32618	21	6A
0005433868020	32618	22	6B
0005433868176	32618	23	6D
0005433867935	32618	24	7A
0005433868005	32618	25	7B
0005433867874	32618	26	7C
0005433868036	32618	27	7D
0005433868208	32618	28	18A
0005433868001	32618	29	18B
0005433867901	32618	30	18C
0005433868042	32618	31	18D
0005433868250	32618	32	19B
0005433868096	32618	33	19C
0005433868198	32618	34	19D
0005433868118	32618	35	20A
0005433868178	32618	36	20B
0005433868021	32618	37	20C
0005433867897	32618	38	20D
0005433868249	32618	39	21A
0005433867896	32618	40	21B
0005433868045	32618	41	21D
0005433867971	32618	42	22A
0005433868039	32618	43	22B
0005433867960	32618	44	22C
0005433868141	32618	45	22D
0005433868172	32618	46	23A
0005433868114	32618	47	23B
0005434663403	3418	1	1C
0005435911370	3418	2	1D
0005434663412	3418	3	2B
0005435911400	3418	4	2C
0005434663410	3418	5	2D
0005434663409	3418	6	3B
0005434663413	3418	7	4A
0005434663408	3418	8	4C
0005434663405	3418	9	4D
0005435911393	3418	10	5B
0005434663415	3418	11	5C
0005434663414	3418	12	6A
0005434460505	3418	13	6C
0005435911395	3418	14	7A
0005435911409	3418	15	7C
0005434460507	3418	16	18B
0005434663406	3418	17	18D
0005434663407	3418	18	19B
0005435911408	3418	19	19C
0005434663402	3418	20	19D
0005434460506	3418	21	20C
0005434663416	3418	22	20D
0005434461646	3418	23	21A
0005434663411	3418	24	21B
0005434461647	3418	25	21C
0005435911392	3418	26	22C
0005434663404	3418	27	23B
0005434663211	12481	1	1D
0005435911451	12481	2	2A
0005434663337	12481	3	2C
0005435911454	12481	4	3D
0005434663329	12481	5	4A
0005434663310	12481	6	4C
0005434663342	12481	7	5A
0005435911448	12481	8	5C
0005435911455	12481	9	6B
0005434663294	12481	10	6D
0005434663303	12481	11	7A
0005435911453	12481	12	7B
0005434663307	12481	13	18B
0005435911450	12481	14	18C
0005434663311	12481	15	20A
0005434663330	12481	16	20B
0005434663284	12481	17	20D
0005434663308	12481	18	21B
0005434663238	12481	19	21D
0005434663253	12481	20	22B
0005435911452	12481	21	22D
0005435911449	12481	22	23B
0005433868176	14518	1	1A
0005433868035	14518	2	1B
0005433868036	14518	3	1D
0005433867897	14518	4	1C
0005433868045	14518	5	2A
0005433868020	14518	6	2B
0005433868249	14518	7	2C
0005433867896	14518	8	2D
0005433868001	14518	9	3B
0005433868000	14518	10	3C
0005433868207	14518	11	3D
0005433868250	14518	12	4A
0005433868118	14518	13	4B
0005433868011	14518	14	4C
0005433868003	14518	15	4D
0005433867960	14518	16	5A
0005433868167	14518	17	5B
0005433868208	14518	18	5C
0005433868113	14518	19	5D
0005433867971	14518	20	6A
0005433868114	14518	21	6B
0005433868178	14518	22	6C
0005433867874	14518	23	7B
0005433868078	14518	24	7A
0005433868005	14518	25	7C
0005433868026	14518	26	7D
0005433868172	14518	27	18A
0005433867917	14518	28	18B
0005433868042	14518	29	18C
0005433868096	14518	30	18D
0005433868177	14518	31	19A
0005433868141	14518	32	19B
0005433868039	14518	33	19C
0005433868041	14518	34	19D
0005433868002	14518	35	20A
0005433867901	14518	36	20B
0005433868053	14518	37	20C
0005433868119	14518	38	20D
0005433868097	14518	39	21A
0005433867916	14518	40	21B
0005433868209	14518	41	21C
0005433868021	14518	42	21D
0005433868168	14518	43	22A
0005433867935	14518	44	22B
0005433868198	14518	45	22C
0005433868082	14518	46	22D
0005433868187	14518	47	23A
0005433868419	32669	1	1A
0005433868393	32669	2	1B
0005433868406	32669	3	1C
0005433868402	32669	4	1D
0005433868424	32669	5	2A
0005433868427	32669	6	2B
0005433868409	32669	7	2C
0005433868397	32669	8	2D
0005433868422	32669	9	3A
0005433868416	32669	10	3B
0005435860434	32669	11	3C
0005433868400	32669	12	3D
0005433868391	32669	13	4A
0005433868407	32669	14	4B
0005435860436	32669	15	4C
0005433868411	32669	16	4D
0005433868414	32669	17	5A
0005433868396	32669	18	5B
0005433868410	32669	19	5C
0005433868430	32669	20	5D
0005435860437	32669	21	6A
0005433868388	32669	22	6B
0005435860435	32669	23	6C
0005433868390	32669	24	6D
0005433868423	32669	25	7A
0005433868426	32669	26	7B
0005435860445	32669	27	7C
0005433868405	32669	28	18A
0005433868398	32669	29	18B
0005433868399	32669	30	18C
0005433868403	32669	31	18D
0005433868415	32669	32	19A
0005433868425	32669	33	19B
0005433868392	32669	34	19C
0005433868394	32669	35	19D
0005433868417	32669	36	20A
0005433868408	32669	37	20B
0005433868428	32669	38	20C
0005433868418	32669	39	20D
0005433868413	32669	40	21A
0005433868401	32669	41	21B
0005433868404	32669	42	21C
0005433868421	32669	43	21D
0005433868395	32669	44	22A
0005435860439	32669	45	22B
0005433868412	32669	46	22C
0005433868429	32669	47	22D
0005433868389	32669	48	23A
0005433868420	32669	49	23B
0005432799236	12106	1	1A
0005432799104	12106	2	1C
0005432799219	12106	3	1D
0005432799201	12106	4	2A
0005432799343	12106	5	2C
0005432799199	12106	6	2D
0005432799180	12106	7	3B
0005432799291	12106	8	3C
0005432799231	12106	9	3D
0005432799290	12106	10	4A
0005432799318	12106	11	5C
0005432799169	12106	12	5D
0005432799222	12106	13	6A
0005432799179	12106	14	6D
0005432799319	12106	15	7A
0005432799342	12106	16	7B
0005432799130	12106	17	18A
0005432799200	12106	18	18B
0005432799250	12106	19	18C
0005432799235	12106	20	19C
0005432799317	12106	21	19D
0005432799263	12106	22	20A
0005432799168	12106	23	20B
0005432799137	12106	24	20C
0005432799105	12106	25	20D
0005432799232	12106	26	21B
0005432799056	12106	27	21C
0005432799221	12106	28	22A
0005432799213	12106	29	23A
0005432799435	14809	1	1A
0005432799428	14809	2	1B
0005432799424	14809	3	1D
0005432799432	14809	4	2A
0005432799443	14809	5	2C
0005432799419	14809	6	2D
0005432799418	14809	7	3A
0005432799433	14809	8	3B
0005432799440	14809	9	3D
0005432799439	14809	10	4A
0005432799437	14809	11	5C
0005432799423	14809	12	5D
0005432799438	14809	13	6A
0005432799420	14809	14	6B
0005432799441	14809	15	6D
0005432799442	14809	16	7A
0005432799429	14809	17	7B
0005432799434	14809	18	7D
0005432799436	14809	19	18A
0005432799426	14809	20	18C
0005432799417	14809	21	18D
0005432799421	14809	22	19B
0005432799430	14809	23	20A
0005432799422	14809	24	20B
0005432799427	14809	25	20D
0005432799425	14809	26	22C
0005432799416	14809	27	22D
0005432799431	14809	28	23B
0005435293170	7059	1	1A
0005435293106	7059	2	1C
0005435310947	7059	3	1D
0005434407771	7059	4	2A
0005434299565	7059	5	1F
0005434407791	7059	6	2D
0005434407740	7059	7	2C
0005434407796	7059	8	2F
0005434407747	7059	9	3C
0005435293180	7059	10	3A
0005435310941	7059	11	3D
0005435293111	7059	12	3F
0005434407792	7059	13	4A
0005434407744	7059	14	4C
0005434407758	7059	15	4B
0005434407760	7059	16	4D
0005434299561	7059	17	4E
0005435310932	7059	18	4F
0005434407788	7059	19	5A
0005434407762	7059	20	5C
0005434407739	7059	21	5B
0005434407768	7059	22	5D
0005435293143	7059	23	5E
0005434407764	7059	24	5F
0005434407793	7059	25	6B
0005435310905	7059	26	6A
0005434407765	7059	27	6C
0005434299574	7059	28	6D
0005434407776	7059	29	6E
0005434299554	7059	30	7A
0005434407767	7059	31	6F
0005434407769	7059	32	7B
0005434407755	7059	33	7C
0005434407766	7059	34	7E
0005434407772	7059	35	7D
0005434407774	7059	36	7F
0005434299562	7059	37	8A
0005435310946	7059	38	8B
0005434407798	7059	39	8C
0005434407743	7059	40	8E
0005435310922	7059	41	8D
0005432153941	7059	42	8F
0005434407787	7059	43	9A
0005432108251	7059	44	9B
0005435293155	7059	45	9C
0005435310957	7059	46	9E
0005435293142	7059	47	9D
0005435293125	7059	48	9F
0005435310950	7059	49	10B
0005435293146	7059	50	10D
0005434299556	7059	51	10C
0005434407746	7059	52	11A
0005434407775	7059	53	10E
0005434299552	7059	54	11C
0005434407759	7059	55	11B
0005434407778	7059	56	11E
0005434299572	7059	57	11D
0005434407737	7059	58	11F
0005434407763	7059	59	12A
0005432153936	7059	60	12C
0005434407789	7059	61	12B
0005434407742	7059	62	12E
0005434299557	7059	63	12D
0005434407784	7059	64	12F
0005434299573	7059	65	13B
0005434407748	7059	66	13A
0005434407741	7059	67	13C
0005434407773	7059	68	13D
0005434299571	7059	69	13E
0005434299551	7059	70	13F
0005434299567	7059	71	14A
0005434407754	7059	72	14C
0005432108250	7059	73	14B
0005435293145	7059	74	14D
0005434407797	7059	75	14E
0005434407783	7059	76	15A
0005434407799	7059	77	15C
0005434407738	7059	78	15B
0005434407795	7059	79	15F
0005434299555	7059	80	15E
0005434407786	7059	81	16A
0005432153939	7059	82	16D
0005432153942	7059	83	16C
0005434407736	7059	84	16E
0005434407753	7059	85	16F
0005434407777	7059	86	17A
0005435310934	7059	87	17B
0005434299566	7059	88	17C
0005434407770	7059	89	17D
0005434407745	7059	90	17F
0005434299568	7059	91	17E
0005434299553	7059	92	18A
0005434407751	7059	93	18B
0005432153940	7059	94	18C
0005435293163	7059	95	18E
0005432153938	7059	96	18D
0005435293107	7059	97	18F
0005434407779	7059	98	19A
0005434407781	7059	99	19B
0005434407761	7059	100	19C
0005434407757	7059	101	19E
0005434299569	7059	102	19D
0005434407750	7059	103	19F
0005434407756	7059	104	20A
0005434299560	7059	105	20C
0005434299570	7059	106	20B
0005434407782	7059	107	20D
0005434299559	7059	108	20E
0005435293181	7059	109	20F
0005434407780	7059	110	21D
0005434299563	7059	111	21C
0005434299564	7059	112	21E
0005434299558	7059	113	22A
0005435310936	7059	114	22C
0005432108249	7059	115	22B
0005434407790	7059	116	22D
0005434407752	7059	117	22E
0005435310933	7059	118	22F
0005432153935	7059	119	23B
0005434407785	7059	120	23A
0005432153937	7059	121	23E
0005434407794	7059	122	23D
0005434407749	7059	123	23F
0005434407262	26883	1	1D
0005434407423	26883	2	1C
0005434407184	26883	3	2A
0005434407277	26883	4	1F
0005434299393	26883	5	2C
0005434407079	26883	6	3A
0005434407080	26883	7	3C
0005434407261	26883	8	3F
0005434407061	26883	9	4A
0005434299381	26883	10	4B
0005434407287	26883	11	4C
0005434407132	26883	12	4E
0005434407341	26883	13	4F
0005432058376	26883	14	5B
0005434407275	26883	15	5A
0005435293249	26883	16	5C
0005435293250	26883	17	5E
0005434407062	26883	18	6B
0005435311054	26883	19	6D
0005432058380	26883	20	6E
0005434407137	26883	21	6F
0005435293258	26883	22	7B
0005435311060	26883	23	7A
0005434407400	26883	24	7E
0005435311056	26883	25	7D
0005434299495	26883	26	8A
0005434407461	26883	27	7F
0005434407276	26883	28	8B
0005434406850	26883	29	8D
0005434407244	26883	30	8F
0005434299409	26883	31	8E
0005435293254	26883	32	9C
0005435311057	26883	33	9B
0005434407346	26883	34	9E
0005434299431	26883	35	9D
0005435293257	26883	36	9F
0005435293252	26883	37	10B
0005435311052	26883	38	10D
0005434299369	26883	39	10C
0005434299370	26883	40	10E
0005434407108	26883	41	11A
0005434406975	26883	42	11B
0005434406973	26883	43	11C
0005434407156	26883	44	11E
0005434299416	26883	45	12A
0005434407342	26883	46	11F
0005434299382	26883	47	12B
0005432058377	26883	48	12C
0005434299364	26883	49	12D
0005434299307	26883	50	12E
0005434407045	26883	51	12F
0005434299501	26883	52	13B
0005434299423	26883	53	13A
0005434299493	26883	54	13D
0005434407059	26883	55	13E
0005434407348	26883	56	13F
0005435311059	26883	57	14A
0005434407074	26883	58	14C
0005434299267	26883	59	14D
0005434407155	26883	60	14F
0005435293256	26883	61	14E
0005434299380	26883	62	15A
0005434407183	26883	63	15B
0005434299353	26883	64	15E
0005434299287	26883	65	15D
0005435293255	26883	66	15F
0005434407460	26883	67	16A
0005434407053	26883	68	16C
0005434407281	26883	69	17A
0005434299390	26883	70	17B
0005434407422	26883	71	17D
0005435293253	26883	72	17E
0005435293251	26883	73	18A
0005434407260	26883	74	18B
0005434299308	26883	75	18D
0005434299496	26883	76	18C
0005435311055	26883	77	18E
0005435293259	26883	78	18F
0005435293248	26883	79	19A
0005434299286	26883	80	19C
0005434407025	26883	81	19B
0005435293247	26883	82	19D
0005434407347	26883	83	19F
0005434407046	26883	84	19E
0005434407049	26883	85	20A
0005434407401	26883	86	20C
0005434407278	26883	87	20B
0005434407182	26883	88	20E
0005434299502	26883	89	20F
0005434406963	26883	90	21A
0005434407172	26883	91	21C
0005434299371	26883	92	21D
0005434407098	26883	93	21E
0005435311058	26883	94	22A
0005432058378	26883	95	21F
0005434407095	26883	96	22B
0005435311061	26883	97	22C
0005435311062	26883	98	22D
0005434407039	26883	99	22F
0005434299408	26883	100	22E
0005434299322	26883	101	23B
0005434407288	26883	102	23A
0005434407006	26883	103	23C
0005432058379	26883	104	23E
0005434407298	26883	105	23D
0005435311053	26883	106	23F
0005432604337	6460	1	1A
0005432604371	6460	2	1B
0005432604368	6460	3	1C
0005432604343	6460	4	1D
0005434512120	6460	5	2A
0005432604338	6460	6	2B
0005434512121	6460	7	2C
0005434512115	6460	8	2D
0005432604370	6460	9	3C
0005432604347	6460	10	3D
0005432604334	6460	11	4A
0005434512118	6460	12	4B
0005432604365	6460	13	4C
0005432604358	6460	14	4D
0005432604332	6460	15	5A
0005432604359	6460	16	5B
0005432604346	6460	17	5C
0005434512116	6460	18	5D
0005432604353	6460	19	6A
0005432604350	6460	20	6B
0005432604348	6460	21	6C
0005434512117	6460	22	6D
0005432604363	6460	23	7A
0005432604362	6460	24	7B
0005432604341	6460	25	7C
0005432604335	6460	26	7D
0005432604367	6460	27	18A
0005432604356	6460	28	18B
0005432604366	6460	29	18C
0005434512119	6460	30	18D
0005432604354	6460	31	19A
0005432604339	6460	32	19B
0005432604345	6460	33	19C
0005432604349	6460	34	20A
0005432604361	6460	35	20B
0005432604336	6460	36	20C
0005432604352	6460	37	20D
0005432604360	6460	38	21A
0005432604340	6460	39	21B
0005432604357	6460	40	21C
0005432604333	6460	41	21D
0005432604351	6460	42	22A
0005432604364	6460	43	22B
0005432604369	6460	44	22C
0005432604355	6460	45	22D
0005432604344	6460	46	23A
0005432604342	6460	47	23B
0005434512073	21345	1	1A
0005432603828	21345	2	1B
0005432604072	21345	3	1C
0005432603792	21345	4	1D
0005432603827	21345	5	2A
0005432603908	21345	6	2B
0005432604007	21345	7	2C
0005432603937	21345	8	2D
0005432604036	21345	9	3A
0005432603909	21345	10	3B
0005432603998	21345	11	3C
0005432604053	21345	12	4A
0005434512061	21345	13	4B
0005432603894	21345	14	4C
0005432603918	21345	15	4D
0005432603962	21345	16	5A
0005432604070	21345	17	5B
0005432603934	21345	18	5C
0005432603969	21345	19	5D
0005432604073	21345	20	6A
0005432603848	21345	21	6B
0005432603749	21345	22	6C
0005432604044	21345	23	6D
0005432603884	21345	24	7A
0005432603893	21345	25	7B
0005432604078	21345	26	7C
0005432603800	21345	27	7D
0005432603956	21345	28	18A
0005434512079	21345	29	18B
0005432604110	21345	30	18C
0005432604068	21345	31	18D
0005432604001	21345	32	19A
0005434512080	21345	33	19B
0005434512078	21345	34	19C
0005432603678	21345	35	19D
0005432604081	21345	36	20A
0005432603896	21345	37	20B
0005432603847	21345	38	20C
0005432604008	21345	39	21A
0005432604006	21345	40	21B
0005432603995	21345	41	21C
0005432603927	21345	42	21D
0005432604080	21345	43	22B
0005432603947	21345	44	22A
0005432603920	21345	45	22C
0005434512060	21345	46	22D
0005432603919	21345	47	23A
0005432604002	21345	48	23B
0005434906820	15019	1	20A
0005434906892	15019	2	1C
0005433251467	15019	3	1D
0005434906843	15019	4	1F
0005433251473	15019	5	2A
0005433251478	15019	6	2C
0005434906898	15019	7	2D
0005434906647	15019	8	2F
0005434906831	15019	9	3C
0005433251495	15019	10	3D
0005434906789	15019	11	3F
0005434906725	15019	12	4C
0005434906646	15019	13	4D
0005433251477	15019	14	4E
0005434906643	15019	15	4F
0005433251474	15019	16	5A
0005434906731	15019	17	5C
0005434906701	15019	18	5D
0005433251482	15019	19	5E
0005433251481	15019	20	5F
0005434906607	15019	21	6A
0005434906828	15019	22	6C
0005434906543	15019	23	6D
0005434906825	15019	24	6E
0005433251470	15019	25	6F
0005434906835	15019	26	7A
0005434906621	15019	27	7D
0005434906881	15019	28	7E
0005434906757	15019	29	7F
0005433251475	15019	30	8A
0005433251488	15019	31	8C
0005434906889	15019	32	8D
0005433251491	15019	33	8E
0005434906718	15019	34	9A
0005433251493	15019	35	9C
0005433251489	15019	36	9D
0005434906880	15019	37	9F
0005434906692	15019	38	10A
0005434906876	15019	39	10C
0005434906795	15019	40	10D
0005433251480	15019	41	10F
0005433251494	15019	42	11A
0005434906821	15019	43	11C
0005434906827	15019	44	11D
0005434906814	15019	45	11E
0005434906539	15019	46	11F
0005434906844	15019	47	12A
0005434906700	15019	48	12C
0005434906716	15019	49	12D
0005434906829	15019	50	12E
0005434906455	15019	51	12F
0005434906752	15019	52	13C
0005434906721	15019	53	13D
0005433251490	15019	54	13F
0005433251484	15019	55	14A
0005434906605	15019	56	14C
0005434906644	15019	57	14D
0005434906830	15019	58	14E
0005433251466	15019	59	14F
0005434906836	15019	60	15A
0005433251471	15019	61	15C
0005434906733	15019	62	15D
0005434906839	15019	63	15E
0005434906834	15019	64	15F
0005433251483	15019	65	16A
0005434906788	15019	66	16C
0005434906790	15019	67	16D
0005434906699	15019	68	16E
0005434906645	15019	69	16F
0005433251492	15019	70	17A
0005434906853	15019	71	17C
0005433251465	15019	72	17D
0005434906772	15019	73	17E
0005433251469	15019	74	17F
0005434906734	15019	75	18A
0005433251476	15019	76	18D
0005433251487	15019	77	18E
0005434906691	15019	78	18F
0005433251468	15019	79	19A
0005434906742	15019	80	19C
0005434906893	15019	81	19D
0005434906852	15019	82	19E
0005433251485	15019	83	19F
0005433251486	15019	84	20C
0005433251472	15019	85	20D
0005433251479	15019	86	20E
0005434906717	15019	87	20F
0005433251193	25864	1	1A
0005434907216	25864	2	1C
0005433251227	25864	3	1D
0005434907261	25864	4	1F
0005434907219	25864	5	2A
0005434907257	25864	6	2C
0005433251145	25864	7	2D
0005434907249	25864	8	3A
0005434907244	25864	9	3D
0005433251091	25864	10	4C
0005433251172	25864	11	4D
0005434907246	25864	12	4E
0005433251179	25864	13	4F
0005433251210	25864	14	5A
0005433251264	25864	15	5C
0005434907228	25864	16	5D
0005434907245	25864	17	5E
0005434907252	25864	18	5F
0005434907243	25864	19	6A
0005434907236	25864	20	6C
0005434907240	25864	21	6E
0005434907242	25864	22	6F
0005434907214	25864	23	7A
0005433251307	25864	24	7C
0005434907217	25864	25	7D
0005433251246	25864	26	7F
0005433251281	25864	27	8A
0005433251322	25864	28	8C
0005434907237	25864	29	8E
0005433251218	25864	30	8F
0005434907241	25864	31	9A
0005434907223	25864	32	9D
0005434907224	25864	33	9E
0005433251144	25864	34	9F
0005434907251	25864	35	10A
0005434907250	25864	36	10C
0005434907225	25864	37	10D
0005434907234	25864	38	10E
0005434907247	25864	39	10F
0005433251293	25864	40	11A
0005434907253	25864	41	11C
0005434907227	25864	42	11D
0005434907256	25864	43	11E
0005433251161	25864	44	11F
0005434907258	25864	45	12A
0005433251358	25864	46	12C
0005434907230	25864	47	12D
0005434907260	25864	48	12E
0005434907255	25864	49	12F
0005434907248	25864	50	13A
0005434907220	25864	51	13C
0005433251226	25864	52	13D
0005434907233	25864	53	13F
0005434907259	25864	54	14A
0005434907215	25864	55	14C
0005433251192	25864	56	14D
0005434907226	25864	57	14F
0005434907235	25864	58	15A
0005433251233	25864	59	15C
0005434907218	25864	60	15E
0005433251306	25864	61	15F
0005433251323	25864	62	16A
0005434907254	25864	63	16C
0005434907262	25864	64	16D
0005433251219	25864	65	16E
0005433251359	25864	66	16F
0005434907221	25864	67	17A
0005433251209	25864	68	17C
0005433251150	25864	69	17D
0005433251211	25864	70	17E
0005433251191	25864	71	17F
0005433251234	25864	72	18A
0005434907231	25864	73	18C
0005434907238	25864	74	18D
0005434907232	25864	75	18E
0005433251292	25864	76	18F
0005433251228	25864	77	19A
0005433251120	25864	78	19C
0005433251225	25864	79	19D
0005434907222	25864	80	19E
0005433251140	25864	81	19F
0005434907239	25864	82	20A
0005433251357	25864	83	20C
0005433251245	25864	84	20D
0005433251190	25864	85	20E
0005434907229	25864	86	20F
0005432609720	22480	1	1C
0005432607553	22480	2	1D
0005432607555	22480	3	2C
0005432607563	22480	4	2D
0005432607556	22480	5	3B
0005432607564	22480	6	3D
0005432607562	22480	7	4A
0005432607565	22480	8	4B
0005432609721	22480	9	4D
0005432609728	22480	10	6C
0005432609722	22480	11	6D
0005432609725	22480	12	7A
0005432607554	22480	13	7C
0005432607557	22480	14	18B
0005432609719	22480	15	18C
0005432609724	22480	16	18D
0005432607559	22480	17	19A
0005432609727	22480	18	19C
0005435841464	22480	19	19D
0005432609729	22480	20	20A
0005435842317	22480	21	20B
0005432609718	22480	22	20C
0005432607561	22480	23	20D
0005432607560	22480	24	21A
0005432609723	22480	25	21C
0005432609717	22480	26	21D
0005435841470	22480	27	22A
0005432609726	22480	28	22D
0005432607558	22480	29	23A
0005435841461	22480	30	23B
0005435841095	31721	1	1A
0005435841473	31721	2	1B
0005432609695	31721	3	1C
0005432613830	31721	4	2A
0005435841472	31721	5	2B
0005435841094	31721	6	2D
0005432609673	31721	7	3A
0005435841475	31721	8	3B
0005435841098	31721	9	3C
0005432609691	31721	10	3D
0005435841097	31721	11	4A
0005435841471	31721	12	4B
0005432609696	31721	13	4C
0005435841474	31721	14	4D
0005432613800	31721	15	5A
0005432609690	31721	16	5B
0005435841096	31721	17	5C
0005432609687	31721	18	6A
0005432609672	31721	19	6C
0005432613829	31721	20	6D
0005432609688	31721	21	7A
0005435841476	31721	22	7C
0005432613807	31721	23	7D
0005432609698	31721	24	18D
0005432609684	31721	25	19A
0005432613823	31721	26	19D
0005432609697	31721	27	20A
0005432613808	31721	28	22B
0005432609689	31721	29	22C
0005432609693	31721	30	22D
0005432609685	31721	31	23B
0005433008653	14153	1	2C
0005433008621	14153	2	3C
0005433008632	14153	3	3D
0005433008626	14153	4	3F
0005433008656	14153	5	4A
0005433008627	14153	6	4C
0005433008636	14153	7	4F
0005433008615	14153	8	5A
0005433008625	14153	9	5C
0005433008624	14153	10	5E
0005433008618	14153	11	5F
0005433008633	14153	12	6C
0005433008616	14153	13	6F
0005433008643	14153	14	7A
0005433008630	14153	15	7C
0005433008645	14153	16	7E
0005433810494	14153	17	8D
0005433008654	14153	18	8E
0005433008635	14153	19	8F
0005433008623	14153	20	9C
0005433008640	14153	21	9E
0005433008628	14153	22	9F
0005433810507	14153	23	10A
0005433008622	14153	24	10E
0005433008649	14153	25	11C
0005433008619	14153	26	11D
0005433008644	14153	27	11E
0005433008620	14153	28	12C
0005433008614	14153	29	12E
0005433008638	14153	30	12F
0005433008655	14153	31	13C
0005433008637	14153	32	13D
0005433008642	14153	33	13F
0005433008612	14153	34	14C
0005433008650	14153	35	14E
0005433008639	14153	36	15A
0005433008634	14153	37	15E
0005433008652	14153	38	16A
0005433008646	14153	39	16C
0005433008647	14153	40	17C
0005433008613	14153	41	17D
0005433008629	14153	42	17E
0005433008648	14153	43	18E
0005433008641	14153	44	18F
0005433008611	14153	45	19A
0005433008631	14153	46	19D
0005433008617	14153	47	19F
0005433008651	14153	48	20A
0005433810538	22852	1	1C
0005433007921	22852	2	1F
0005433008046	22852	3	2A
0005433008157	22852	4	2C
0005433008201	22852	5	2D
0005433008164	22852	6	3A
0005433810545	22852	7	3C
0005433008278	22852	8	3D
0005433008231	22852	9	4A
0005433008300	22852	10	4C
0005433008175	22852	11	4F
0005433008031	22852	12	5C
0005433008202	22852	13	5E
0005433008047	22852	14	6C
0005433810540	22852	15	6F
0005433008198	22852	16	7C
0005433008402	22852	17	7D
0005433810543	22852	18	7F
0005433008280	22852	19	8A
0005433008181	22852	20	8E
0005433008364	22852	21	9C
0005433008163	22852	22	9E
0005433008272	22852	23	9F
0005433008199	22852	24	10A
0005433008399	22852	25	10C
0005433810542	22852	26	10D
0005433810544	22852	27	10F
0005433008273	22852	28	11A
0005433008356	22852	29	11D
0005433810539	22852	30	11E
0005433008243	22852	31	12C
0005433008030	22852	32	12D
0005433008404	22852	33	12F
0005433008343	22852	34	13C
0005433008277	22852	35	13E
0005433008260	22852	36	13F
0005433008018	22852	37	14C
0005433008365	22852	38	14D
0005433810541	22852	39	14E
0005433008033	22852	40	15E
0005433008122	22852	41	16C
0005433008041	22852	42	16D
0005433008154	22852	43	16F
0005433008279	22852	44	17C
0005433008357	22852	45	17D
0005433008223	22852	46	18E
0005433008172	22852	47	19A
0005433008344	22852	48	19D
0005433008019	22852	49	19E
0005433007920	22852	50	19F
0005433008403	22852	51	20C
0005433008032	22852	52	20E
0005433008354	22852	53	20F
0005434925513	14938	1	1A
0005434925548	14938	2	1F
0005434925537	14938	3	2F
0005434925555	14938	4	3A
0005434925437	14938	5	3C
0005434925438	14938	6	3F
0005434925440	14938	7	4F
0005434925327	14938	8	5D
0005434925559	14938	9	5E
0005434925536	14938	10	5F
0005434925407	14938	11	6D
0005434925487	14938	12	7F
0005434925560	14938	13	8D
0005434925554	14938	14	8F
0005434925564	14938	15	9C
0005434925527	14938	16	9D
0005434925542	14938	17	10C
0005434925410	14938	18	10E
0005434925515	14938	19	10F
0005434925495	14938	20	11A
0005434925486	14938	21	11C
0005434925405	14938	22	11D
0005434925514	14938	23	11E
0005434925494	14938	24	11F
0005434925328	14938	25	12E
0005434925516	14938	26	13F
0005434925556	14938	27	14A
0005434925374	14938	28	14C
0005434925498	14938	29	14F
0005434925454	14938	30	15A
0005434925558	14938	31	15D
0005434925543	14938	32	16A
0005434925314	14938	33	17D
0005434925520	14938	34	17F
0005434925488	14938	35	18A
0005434925517	14938	36	19A
0005434925406	14938	37	19C
0005434925432	14938	38	19E
0005434925497	14938	39	20C
0005434925525	14938	40	20E
0005434925557	14938	41	20F
0005434925791	20524	1	1D
0005434925788	20524	2	2D
0005434925778	20524	3	4C
0005434925790	20524	4	5A
0005434925786	20524	5	6E
0005434925787	20524	6	7A
0005434925779	20524	7	8D
0005434925776	20524	8	8E
0005434925796	20524	9	9D
0005434925797	20524	10	9E
0005434925777	20524	11	10F
0005434925793	20524	12	11D
0005434925789	20524	13	12C
0005434925780	20524	14	12D
0005434925794	20524	15	12E
0005434925799	20524	16	13A
0005434925782	20524	17	13E
0005434925785	20524	18	14E
0005434925795	20524	19	15D
0005434925798	20524	20	16F
0005434925792	20524	21	18A
0005434925781	20524	22	18E
0005434925783	20524	23	18F
0005434925784	20524	24	19A
0005435999074	15836	1	1C
0005435999113	15836	2	1D
0005435999081	15836	3	2A
0005435487848	15836	4	2C
0005435487835	15836	5	3A
0005435999086	15836	6	3B
0005435487838	15836	7	3C
0005435487842	15836	8	3D
0005435999103	15836	9	4A
0005435487840	15836	10	4B
0005435487844	15836	11	4D
0005435999079	15836	12	5A
0005435487845	15836	13	5B
0005435487839	15836	14	6A
0005435999128	15836	15	6B
0005435487846	15836	16	6C
0005435487851	15836	17	6D
0005435487833	15836	18	7A
0005435487850	15836	19	7C
0005435999102	15836	20	18A
0005435487830	15836	21	18B
0005435487841	15836	22	18D
0005435487837	15836	23	19A
0005435999073	15836	24	19C
0005435999110	15836	25	20A
0005435999082	15836	26	20B
0005435999075	15836	27	20D
0005435487836	15836	28	21A
0005435487832	15836	29	21C
0005435487849	15836	30	21D
0005435487847	15836	31	22A
0005435487834	15836	32	22B
0005435487831	15836	33	22C
0005435487843	15836	34	22D
0005435999124	15836	35	23A
0005435999118	15836	36	23B
0005435999246	19695	1	1A
0005435487582	19695	2	1B
0005435999237	19695	3	1C
0005435487587	19695	4	1D
0005435999238	19695	5	2A
0005435487581	19695	6	2B
0005435487605	19695	7	3A
0005435487625	19695	8	3B
0005435487556	19695	9	3C
0005435999244	19695	10	3D
0005435999248	19695	11	4A
0005435487586	19695	12	4B
0005435487612	19695	13	4C
0005435487624	19695	14	5A
0005435487505	19695	15	5B
0005435487554	19695	16	5C
0005435487590	19695	17	5D
0005435487631	19695	18	6A
0005435487647	19695	19	6B
0005435487579	19695	20	6C
0005435999247	19695	21	6D
0005435999236	19695	22	7B
0005435999241	19695	23	7D
0005435999242	19695	24	18A
0005435999243	19695	25	18B
0005435487650	19695	26	18D
0005435487658	19695	27	19B
0005435999239	19695	28	19C
0005435487604	19695	29	19D
0005435487626	19695	30	20A
0005435487555	19695	31	20B
0005435487683	19695	32	20C
0005435487632	19695	33	20D
0005435999245	19695	34	21A
0005435487600	19695	35	21B
0005435487552	19695	36	21C
0005435487580	19695	37	21D
0005435487656	19695	38	22A
0005435487611	19695	39	22C
0005435487657	19695	40	22D
0005435999240	19695	41	23A
0005435487639	19695	42	23B
0005435839475	6028	1	1C
0005432659708	6028	2	1A
0005435472624	6028	3	1D
0005435839459	6028	4	2A
0005432660820	6028	5	2D
0005435839448	6028	6	2F
0005432537042	6028	7	4A
0005435839468	6028	8	3F
0005435472737	6028	9	4C
0005435839470	6028	10	5A
0005435472738	6028	11	6B
0005435839456	6028	12	6C
0005435472625	6028	13	6E
0005435472645	6028	14	6F
0005435472722	6028	15	7C
0005432658592	6028	16	7D
0005432142253	6028	17	8A
0005435839454	6028	18	8F
0005435839469	6028	19	9B
0005435839447	6028	20	9A
0005432537043	6028	21	9C
0005432142251	6028	22	9E
0005435472661	6028	23	9F
0005435839474	6028	24	10D
0005435839457	6028	25	10E
0005435472677	6028	26	11A
0005435472626	6028	27	11C
0005435839472	6028	28	11F
0005435839460	6028	29	11E
0005435472730	6028	30	12B
0005435839452	6028	31	13B
0005432142254	6028	32	13C
0005432658594	6028	33	13E
0005435839453	6028	34	14A
0005435839466	6028	35	13F
0005432142252	6028	36	14C
0005435472657	6028	37	14E
0005432660819	6028	38	15C
0005435472731	6028	39	15F
0005435839467	6028	40	16A
0005432659707	6028	41	16C
0005435472721	6028	42	16E
0005435839471	6028	43	16D
0005435839464	6028	44	16F
0005435472638	6028	45	17B
0005432658593	6028	46	17A
0005435472678	6028	47	17F
0005432142255	6028	48	18A
0005435839461	6028	49	18C
0005435839449	6028	50	18E
0005435472664	6028	51	19A
0005435839451	6028	52	18F
0005435839465	6028	53	20A
0005435472637	6028	54	20B
0005435839462	6028	55	20D
0005435839463	6028	56	20E
0005435839473	6028	57	21B
0005435839458	6028	58	21A
0005435839455	6028	59	21D
0005435839450	6028	60	21F
0005435839202	18035	1	1C
0005435839077	18035	2	1A
0005435839139	18035	3	2A
0005435472799	18035	4	2D
0005435839153	18035	5	3C
0005435839173	18035	6	3A
0005435472807	18035	7	2F
0005435472803	18035	8	3D
0005435839056	18035	9	4A
0005435472810	18035	10	5A
0005435839256	18035	11	5F
0005435839055	18035	12	6B
0005435839174	18035	13	6A
0005435472808	18035	14	6D
0005435839268	18035	15	6F
0005435839203	18035	16	7C
0005435839227	18035	17	8A
0005435839226	18035	18	8B
0005435839215	18035	19	9B
0005435839211	18035	20	9C
0005432660795	18035	21	9F
0005435839141	18035	22	10B
0005435472811	18035	23	10F
0005435839152	18035	24	12A
0005435472813	18035	25	12C
0005435839177	18035	26	12D
0005432537060	18035	27	13E
0005435839140	18035	28	13D
0005432667433	18035	29	14E
0005435839291	18035	30	14F
0005432537059	18035	31	15B
0005435472814	18035	32	15A
0005435839238	18035	33	15E
0005432667432	18035	34	15F
0005435839237	18035	35	16C
0005435472806	18035	36	16B
0005435472812	18035	37	16E
0005435472804	18035	38	16D
0005435839136	18035	39	17B
0005435472802	18035	40	17F
0005435472798	18035	41	18B
0005435839176	18035	42	18D
0005435839135	18035	43	19A
0005435472800	18035	44	18F
0005435472801	18035	45	19E
0005435839241	18035	46	19D
0005435472809	18035	47	20A
0005435839290	18035	48	20C
0005435839334	18035	49	20E
0005435839201	18035	50	21B
0005435472805	18035	51	21A
0005433284975	23006	1	1D
0005433285101	23006	2	4E
0005433285064	23006	3	5B
0005433285100	23006	4	6D
0005435103930	23006	5	7A
0005433285045	23006	6	7C
0005433285063	23006	7	7E
0005435103923	23006	8	8A
0005433285120	23006	9	7F
0005435103927	23006	10	8E
0005433285008	23006	11	8F
0005435103926	23006	12	9A
0005433285039	23006	13	10C
0005433285084	23006	14	11A
0005433285007	23006	15	10E
0005433285010	23006	16	11C
0005433285041	23006	17	11B
0005433285121	23006	18	11F
0005433285033	23006	19	12F
0005433285032	23006	20	13A
0005433284953	23006	21	15B
0005433285099	23006	22	15E
0005433285047	23006	23	17E
0005433285046	23006	24	18E
0005435103922	23006	25	19B
0005433285076	23006	26	19C
0005435103928	23006	27	19D
0005435103931	23006	28	19F
0005435103924	23006	29	20A
0005433285065	23006	30	20F
0005435103929	23006	31	21B
0005435103925	23006	32	23B
0005435103932	23006	33	23E
0005433285040	23006	34	23D
0005433285314	32076	1	1D
0005433285316	32076	2	2A
0005435103852	32076	3	2D
0005433285311	32076	4	4F
0005433285323	32076	5	5B
0005433285324	32076	6	5D
0005433285299	32076	7	6D
0005433285295	32076	8	7A
0005433285305	32076	9	8D
0005433285317	32076	10	9C
0005433285319	32076	11	9E
0005433285296	32076	12	10D
0005433285322	32076	13	10C
0005435103833	32076	14	11A
0005435103853	32076	15	10E
0005435103826	32076	16	12A
0005433285318	32076	17	12C
0005433285309	32076	18	12F
0005433285315	32076	19	14C
0005435103841	32076	20	14E
0005433285313	32076	21	15E
0005433285312	32076	22	16D
0005433285307	32076	23	16F
0005433285304	32076	24	18A
0005433285298	32076	25	18C
0005433285297	32076	26	18D
0005433285310	32076	27	19A
0005433285302	32076	28	19C
0005433285320	32076	29	19D
0005433285321	32076	30	20B
0005435103827	32076	31	20A
0005433285303	32076	32	20C
0005433285300	32076	33	20D
0005433285326	32076	34	21C
0005433285306	32076	35	21F
0005433285301	32076	36	22D
0005433285308	32076	37	23B
0005435103844	32076	38	23A
0005433285325	32076	39	23D
0005433475663	23870	1	1A
0005433475660	23870	2	1D
0005433475647	23870	3	2D
0005433475665	23870	4	3A
0005433475673	23870	5	4A
0005433475669	23870	6	5A
0005435852576	23870	7	5D
0005435852575	23870	8	5C
0005433475664	23870	9	6B
0005433475682	23870	10	7C
0005435852577	23870	11	18C
0005433475648	23870	12	19A
0005435852574	23870	13	21A
0005435852578	23870	14	22A
0005433475649	23870	15	22C
0005435213609	30582	1	1D
0005435725606	30582	2	1C
0005435213628	30582	3	1A
0005432527068	30582	4	1G
0005432526866	30582	5	1K
0005432535814	30582	6	1H
0005435213619	30582	7	2D
0005432526865	30582	8	2C
0005432526807	30582	9	2A
0005432526489	30582	10	2H
0005435213608	30582	11	2G
0005434066868	30582	12	2K
0005432535794	30582	13	3D
0005432211511	30582	14	3C
0005432526767	30582	15	4C
0005432526914	30582	16	3K
0005432527039	30582	17	4H
0005432527321	30582	18	4G
0005434066713	30582	19	4D
0005435213627	30582	20	4K
0005432527193	30582	21	5C
0005435213607	30582	22	5A
0005435213606	30582	23	5G
0005435213622	30582	24	11A
0005434066792	30582	25	5K
0005432526898	30582	26	5H
0005435213626	30582	27	11D
0005432428908	30582	28	11C
0005432526318	30582	29	11F
0005435213600	30582	30	11E
0005435213601	30582	31	11H
0005432526579	30582	32	11G
0005432526496	30582	33	12C
0005432527138	30582	34	12A
0005432527114	30582	35	12E
0005432526576	30582	36	12G
0005434066679	30582	37	12F
0005434066967	30582	38	13A
0005435630970	30582	39	12K
0005435213576	30582	40	12H
0005432527067	30582	41	13D
0005435213640	30582	42	13C
0005432526926	30582	43	13F
0005434066739	30582	44	13E
0005432527264	30582	45	13H
0005434067020	30582	46	13G
0005432527667	30582	47	14A
0005435213605	30582	48	13K
0005432526158	30582	49	14D
0005432527017	30582	50	14C
0005432527213	30582	51	14G
0005432527016	30582	52	14F
0005435213625	30582	53	14E
0005434066815	30582	54	14K
0005432526543	30582	55	14H
0005432526177	30582	56	15C
0005432526674	30582	57	15A
0005432527181	30582	58	15F
0005432526924	30582	59	15E
0005435213621	30582	60	15D
0005432526653	30582	61	15H
0005432526768	30582	62	15G
0005432527325	30582	63	16A
0005432527058	30582	64	15K
0005434066956	30582	65	16C
0005434066816	30582	66	16F
0005434067197	30582	67	16E
0005432527668	30582	68	16D
0005432526512	30582	69	16H
0005432527222	30582	70	16G
0005434066903	30582	71	16K
0005434066920	30582	72	17E
0005435213644	30582	73	17D
0005432527116	30582	74	17H
0005434067026	30582	75	17G
0005434066964	30582	76	18B
0005432527316	30582	77	18A
0005432526587	30582	78	18D
0005432527212	30582	79	18C
0005432526716	30582	80	18G
0005435213598	30582	81	18F
0005434067196	30582	82	18J
0005432211505	30582	83	18H
0005434066867	30582	84	18K
0005434066827	30582	85	19D
0005432527343	30582	86	19C
0005432526570	30582	87	19B
0005435213614	30582	88	19G
0005432526724	30582	89	19F
0005434067022	30582	90	19H
0005432526832	30582	91	19K
0005432527283	30582	92	19J
0005435213617	30582	93	20B
0005433656673	30582	94	20A
0005435213604	30582	95	20E
0005432526812	30582	96	20D
0005434067018	30582	97	20C
0005434067248	30582	98	20F
0005432527105	30582	99	20K
0005434067027	30582	100	20J
0005432527233	30582	101	20H
0005434066963	30582	102	21B
0005434066793	30582	103	21A
0005435213641	30582	104	21D
0005432526996	30582	105	21C
0005432527603	30582	106	21F
0005434066734	30582	107	21E
0005434066936	30582	108	21J
0005435213587	30582	109	21H
0005432527214	30582	110	21G
0005432526978	30582	111	21K
0005434067076	30582	112	22D
0005435213596	30582	113	22C
0005432211512	30582	114	22B
0005434066844	30582	115	22E
0005435213629	30582	116	22H
0005432526857	30582	117	22G
0005434066996	30582	118	22F
0005432527279	30582	119	22K
0005432527146	30582	120	22J
0005434067113	30582	121	23B
0005434066870	30582	122	23A
0005434066715	30582	123	23D
0005434066957	30582	124	23C
0005432211509	30582	125	23G
0005432527101	30582	126	23E
0005432526559	30582	127	23H
0005433656676	30582	128	24D
0005434067204	30582	129	23K
0005435213634	30582	130	23J
0005432527069	30582	131	24F
0005432526880	30582	132	24E
0005435213645	30582	133	25B
0005432527260	30582	134	25A
0005434066826	30582	135	24G
0005435213631	30582	136	25F
0005432527477	30582	137	25E
0005435213630	30582	138	25D
0005434066980	30582	139	25H
0005432526897	30582	140	25G
0005435725607	30582	141	26A
0005432527319	30582	142	26C
0005435630971	30582	143	26E
0005434067004	30582	144	26D
0005432535808	30582	145	26J
0005435213636	30582	146	27A
0005432527273	30582	147	26K
0005435213602	30582	148	27D
0005432533271	30582	149	27C
0005432526900	30582	150	27B
0005435213613	30582	151	27E
0005432526904	30582	152	27J
0005432526859	30582	153	27G
0005432533278	30582	154	27K
0005432527634	30582	155	28C
0005434066812	30582	156	28B
0005434067069	30582	157	28D
0005434067021	30582	158	28G
0005432527221	30582	159	28F
0005434066773	30582	160	28K
0005432527032	30582	161	28J
0005435213615	30582	162	28H
0005434067360	30582	163	29B
0005434066879	30582	164	29A
0005435213638	30582	165	29C
0005432526601	30582	166	29F
0005434066881	30582	167	29E
0005435213594	30582	168	29D
0005434066777	30582	169	29J
0005435213637	30582	170	29H
0005435213612	30582	171	29G
0005435213586	30582	172	30A
0005432527223	30582	173	29K
0005432211508	30582	174	30C
0005432527320	30582	175	30B
0005432526856	30582	176	30E
0005432527232	30582	177	30D
0005432159861	30582	178	30G
0005432527359	30582	179	30K
0005432526377	30582	180	30J
0005432537040	30582	181	30H
0005434067090	30582	182	31A
0005434067189	30582	183	31D
0005434067114	30582	184	31B
0005432527125	30582	185	31E
0005434066820	30582	186	31H
0005432526580	30582	187	31G
0005435213599	30582	188	32A
0005432527162	30582	189	31J
0005432159863	30582	190	32B
0005432526178	30582	191	32E
0005432526980	30582	192	32D
0005432527021	30582	193	32G
0005432533277	30582	194	32F
0005432527284	30582	195	32K
0005432428907	30582	196	32J
0005435213611	30582	197	32H
0005432526560	30582	198	33B
0005434066998	30582	199	33A
0005435725603	30582	200	33D
0005432533270	30582	201	33C
0005435213595	30582	202	33E
0005434066790	30582	203	33H
0005435213583	30582	204	33G
0005435213643	30582	205	34A
0005434066741	30582	206	33K
0005432159862	30582	207	34C
0005435213633	30582	208	34B
0005432526673	30582	209	34E
0005435213610	30582	210	34G
0005435213632	30582	211	34F
0005434066997	30582	212	34K
0005432526664	30582	213	34H
0005434066789	30582	214	35B
0005432526836	30582	215	35A
0005432526813	30582	216	35C
0005432526388	30582	217	35F
0005434066828	30582	218	35E
0005435213580	30582	219	35G
0005432526481	30582	220	36A
0005432211504	30582	221	35K
0005434066988	30582	222	35J
0005432526507	30582	223	36D
0005432527147	30582	224	36C
0005432537041	30582	225	36B
0005434067013	30582	226	36E
0005434066899	30582	227	36H
0005432526561	30582	228	36F
0005432527057	30582	229	36K
0005434066972	30582	230	36J
0005432526991	30582	231	37B
0005432527100	30582	232	37A
0005435213635	30582	233	37D
0005432527177	30582	234	37C
0005434066886	30582	235	37F
0005435630969	30582	236	37E
0005434066908	30582	237	37J
0005435213591	30582	238	37H
0005435213581	30582	239	38A
0005435213589	30582	240	37K
0005434067043	30582	241	38C
0005434066782	30582	242	38B
0005432527358	30582	243	38J
0005434066969	30582	244	38H
0005434066689	30582	245	39D
0005432526665	30582	246	39C
0005432527011	30582	247	39F
0005432526808	30582	248	39E
0005432159860	30582	249	39H
0005432527085	30582	250	39G
0005432527315	30582	251	39K
0005435213585	30582	252	39J
0005432526172	30582	253	40C
0005432526987	30582	254	40B
0005435213642	30582	255	40A
0005432533279	30582	256	40E
0005432527318	30582	257	40D
0005432533267	30582	258	40G
0005432526925	30582	259	40F
0005435213582	30582	260	40K
0005432526979	30582	261	40J
0005432526387	30582	262	40H
0005435725605	30582	263	41A
0005434067017	30582	264	41D
0005435213624	30582	265	41C
0005434067030	30582	266	41B
0005432527145	30582	267	41F
0005434066813	30582	268	41H
0005432526858	30582	269	41G
0005432211510	30582	270	42A
0005432526913	30582	271	41K
0005432527336	30582	272	42C
0005432527141	30582	273	42B
0005434066843	30582	274	42F
0005435213579	30582	275	42D
0005434066742	30582	276	42G
0005432526811	30582	277	42J
0005435213590	30582	278	42H
0005433656674	30582	279	43B
0005432527285	30582	280	43A
0005432527360	30582	281	42K
0005432527226	30582	282	43D
0005434066714	30582	283	43C
0005435213592	30582	284	43F
0005434066880	30582	285	43E
0005435213603	30582	286	43H
0005434066749	30582	287	43G
0005432527424	30582	288	43K
0005432211507	30582	289	43J
0005435213618	30582	290	44C
0005434066791	30582	291	44B
0005435213597	30582	292	44E
0005435725608	30582	293	44D
0005432526967	30582	294	44G
0005435213593	30582	295	44K
0005433656675	30582	296	44J
0005432526490	30582	297	44H
0005435213577	30582	298	45B
0005432527342	30582	299	45A
0005432535807	30582	300	45D
0005432526542	30582	301	45C
0005434066891	30582	302	45E
0005432527164	30582	303	45H
0005435213578	30582	304	45G
0005432211506	30582	305	46A
0005435213616	30582	306	45K
0005434066783	30582	307	45J
0005434066772	30582	308	46C
0005435213588	30582	309	46B
0005432527148	30582	310	46E
0005435213623	30582	311	46D
0005432527168	30582	312	46G
0005434066902	30582	313	46F
0005432535790	30582	314	46H
0005434066781	30582	315	47C
0005432526912	30582	316	47A
0005432526753	30582	317	46K
0005434067249	30582	318	47D
0005434067047	30582	319	47F
0005435213584	30582	320	47K
0005434067067	30582	321	47H
0005432526901	30582	322	48D
0005432526881	30582	323	48C
0005432527115	30582	324	48E
0005435725604	30582	325	48H
0005434067250	30582	326	48G
0005432533269	30582	327	49C
0005432527084	30582	328	49A
0005435213620	30582	329	48K
0005432526766	30582	330	49D
0005432527341	30582	331	49G
0005432533268	30582	332	49E
0005432537045	30582	333	49K
0005434066968	30582	334	49H
0005434067212	30582	335	50C
0005434066973	30582	336	50A
0005434067237	30582	337	50E
0005432527471	30582	338	50G
0005435213639	30582	339	50F
0005434066778	30582	340	50H
0005432526754	30582	341	51F
0005432527263	30582	342	51D
0005434067012	30582	343	51G
0005435652647	24828	1	1A
0005435652811	24828	2	1C
0005435652648	24828	3	1D
0005433367927	24828	4	1F
0005433367934	24828	5	2A
0005433367913	24828	6	2D
0005435652659	24828	7	2F
0005435652380	24828	8	3A
0005435652712	24828	9	3C
0005433367928	24828	10	3D
0005433367916	24828	11	3F
0005435652573	24828	12	4A
0005435652525	24828	13	4C
0005433367923	24828	14	4D
0005433367929	24828	15	4F
0005435652812	24828	16	5C
0005435652815	24828	17	5D
0005433367944	24828	18	5E
0005435652633	24828	19	5F
0005433367909	24828	20	6A
0005433367920	24828	21	6C
0005435652577	24828	22	6D
0005435652566	24828	23	6E
0005433367910	24828	24	6F
0005433367947	24828	25	7C
0005433367925	24828	26	7D
0005435652754	24828	27	7F
0005435652744	24828	28	8C
0005435652381	24828	29	8D
0005435652622	24828	30	8F
0005435652734	24828	31	8E
0005433367914	24828	32	9A
0005433367926	24828	33	9D
0005433367917	24828	34	9E
0005433367938	24828	35	9F
0005433367931	24828	36	10A
0005433367940	24828	37	10C
0005435652705	24828	38	10D
0005433367921	24828	39	10E
0005433367912	24828	40	10F
0005435652831	24828	41	11A
0005433367945	24828	42	11C
0005433367932	24828	43	11D
0005433367937	24828	44	11F
0005435652652	24828	45	12A
0005433367919	24828	46	12C
0005433367943	24828	47	12D
0005435652581	24828	48	12E
0005435652614	24828	49	12F
0005435652818	24828	50	13C
0005435652704	24828	51	13D
0005433367942	24828	52	13E
0005433367933	24828	53	13F
0005435652841	24828	54	14A
0005433367915	24828	55	14C
0005433367918	24828	56	14D
0005435652610	24828	57	14F
0005435652832	24828	58	15A
0005435652702	24828	59	15C
0005435652721	24828	60	15D
0005433367939	24828	61	15E
0005435652654	24828	62	15F
0005435652830	24828	63	16A
0005435652678	24828	64	16C
0005435652755	24828	65	16D
0005433367911	24828	66	16E
0005435652847	24828	67	16F
0005435652842	24828	68	17A
0005433367936	24828	69	17C
0005433367935	24828	70	17E
0005433367941	24828	71	17F
0005435652524	24828	72	18A
0005433367924	24828	73	18C
0005433367922	24828	74	18D
0005435652774	24828	75	18E
0005435652813	24828	76	18F
0005435652634	24828	77	19A
0005433367930	24828	78	19C
0005433367946	24828	79	19D
0005435652538	24828	80	19E
0005435652848	24828	81	19F
0005435652817	24828	82	20A
0005435652526	24828	83	20F
0005435949758	23322	1	1C
0005435949763	23322	2	4B
0005435949754	23322	3	6D
0005435949762	23322	4	18B
0005435949747	23322	5	19A
0005435949746	23322	6	20B
0005435949764	23322	7	20D
0005435949744	23322	8	21C
0005435949750	23322	9	21D
0005435949757	23322	10	22C
0005435949743	23322	11	22D
0005434979820	2023	1	1B
0005434979807	2023	2	1D
0005434979808	2023	3	2A
0005434979821	2023	4	2B
0005434979811	2023	5	2C
0005434979814	2023	6	2D
0005434979835	2023	7	3A
0005434979813	2023	8	3B
0005434979825	2023	9	3C
0005434979831	2023	10	4A
0005434979822	2023	11	4B
0005434979819	2023	12	4C
0005434979832	2023	13	5B
0005434979836	2023	14	5D
0005434979834	2023	15	6A
0005434979827	2023	16	6B
0005434979815	2023	17	7A
0005434979826	2023	18	7C
0005434979833	2023	19	7D
0005434979830	2023	20	18A
0005434979816	2023	21	18B
0005434979828	2023	22	18C
0005435801700	2023	23	18D
0005434979829	2023	24	19B
0005434979806	2023	25	19C
0005435801698	2023	26	19D
0005434979812	2023	27	20C
0005434979810	2023	28	20D
0005434979823	2023	29	21B
0005434979809	2023	30	21C
0005434979824	2023	31	21D
0005434979817	2023	32	22B
0005434979818	2023	33	22C
0005435801699	2023	34	23B
0005434979478	23581	1	1B
0005434979531	23581	2	1C
0005434979428	23581	3	1D
0005434979635	23581	4	2A
0005434979454	23581	5	2B
0005434979508	23581	6	2C
0005434979523	23581	7	2D
0005434979419	23581	8	3A
0005434979527	23581	9	3B
0005434979495	23581	10	3C
0005434979439	23581	11	3D
0005435801674	23581	12	4A
0005434979530	23581	13	4B
0005434979449	23581	14	4D
0005434979443	23581	15	5A
0005434979459	23581	16	5B
0005434979427	23581	17	5C
0005434979544	23581	18	5D
0005434979494	23581	19	6A
0005434979479	23581	20	6B
0005434979634	23581	21	6C
0005434979596	23581	22	6D
0005434979489	23581	23	7A
0005434979514	23581	24	7B
0005434979481	23581	25	7C
0005434979565	23581	26	7D
0005434979488	23581	27	18A
0005434979543	23581	28	18B
0005434979456	23581	29	18C
0005434979493	23581	30	18D
0005434979526	23581	31	19A
0005434979448	23581	32	19B
0005434979420	23581	33	19C
0005434979480	23581	34	19D
0005434979451	23581	35	20A
0005434979452	23581	36	20B
0005434979522	23581	37	20C
0005434979490	23581	38	20D
0005435801670	23581	39	21A
0005435801675	23581	40	21B
0005435801669	23581	41	21C
0005434979528	23581	42	21D
0005434979496	23581	43	22A
0005434979450	23581	44	22B
0005434979499	23581	45	22C
0005434979466	23581	46	23A
0005434979455	23581	47	23B
0005434952536	2661	1	3A
0005434952533	2661	2	2B
0005434952535	2661	3	3B
0005434952534	2661	4	6A
0005433256401	2670	1	4B
0005433256423	28216	1	2B
0005434952497	28216	2	3B
0005434952502	28216	3	4B
0005433256424	28216	4	5B
0005434952498	28216	5	6A
0005434952509	28216	6	6B
0005433112375	19754	1	1B
0005433111508	19754	2	2A
0005433111509	19754	3	3A
0005433112376	19754	4	4A
0005433112378	19754	5	6A
0005433112377	19754	6	6B
0005434137452	11934	1	1A
0005434137636	11934	2	2A
0005434137635	11934	3	2C
0005434137506	11934	4	2D
0005434137388	11934	5	2F
0005434137467	11934	6	3A
0005434137394	11934	7	3C
0005434137581	11934	8	3D
0005434137522	11934	9	3F
0005434137548	11934	10	4A
0005434137406	11934	11	4D
0005434137508	11934	12	4E
0005434137317	11934	13	4F
0005434137699	11934	14	5A
0005434137639	11934	15	5E
0005434137535	11934	16	5F
0005434137297	11934	17	6A
0005434137481	11934	18	6C
0005434137296	11934	19	6D
0005434137387	11934	20	6E
0005434137562	11934	21	6F
0005434137566	11934	22	7C
0005434137186	11934	23	7D
0005434137395	11934	24	7E
0005434137042	11934	25	8A
0005434137505	11934	26	8C
0005434137482	11934	27	8D
0005434137641	11934	28	8E
0005434137565	11934	29	8F
0005434137119	11934	30	9A
0005434137345	11934	31	9C
0005434137399	11934	32	9D
0005434137650	11934	33	9E
0005434137477	11934	34	9F
0005434137120	11934	35	10A
0005434137315	11934	36	10C
0005434137314	11934	37	10D
0005434137030	11934	38	10E
0005434137665	11934	39	10F
0005434137378	11934	40	11A
0005434137447	11934	41	11C
0005434137651	11934	42	11D
0005434137687	11934	43	11E
0005434137483	11934	44	11F
0005434137288	11934	45	12A
0005434137468	11934	46	12C
0005434137041	11934	47	12D
0005434137108	11934	48	12F
0005434137179	11934	49	13A
0005434137393	11934	50	13C
0005434137374	11934	51	13D
0005434137664	11934	52	13E
0005434137546	11934	53	13F
0005434137517	11934	54	14A
0005434137043	11934	55	14C
0005434137516	11934	56	14D
0005434137342	11934	57	14E
0005434137210	11934	58	14F
0005434137209	11934	59	15A
0005434137547	11934	60	15C
0005434137343	11934	61	15E
0005434137453	11934	62	15F
0005434137478	11934	63	16A
0005434137521	11934	64	16C
0005434137640	11934	65	16D
0005434137693	11934	66	16E
0005434137316	11934	67	16F
0005434137727	11934	68	17A
0005434137375	11934	69	17C
0005434137519	11934	70	17D
0005434137638	11934	71	17E
0005434137379	11934	72	17F
0005434137348	11934	73	18E
0005434137470	11934	74	18F
0005434137507	11934	75	19A
0005434137199	11934	76	19C
0005434137694	11934	77	19D
0005434137602	11934	78	19E
0005434137333	11934	79	19F
0005434137686	11934	80	20A
0005434137580	11934	81	20C
0005434137652	11934	82	20D
0005434137513	11934	83	20F
0005434138190	28753	1	1A
0005434138153	28753	2	1D
0005434138211	28753	3	1F
0005434138139	28753	4	2C
0005434138127	28753	5	2D
0005434138202	28753	6	2F
0005434138146	28753	7	3A
0005434138163	28753	8	3C
0005434138191	28753	9	3D
0005434138194	28753	10	3F
0005434138143	28753	11	4A
0005434138152	28753	12	4C
0005434138181	28753	13	4D
0005434138198	28753	14	4E
0005434138166	28753	15	4F
0005434138188	28753	16	5A
0005434138149	28753	17	5C
0005434138203	28753	18	5D
0005434138167	28753	19	5E
0005434138172	28753	20	6A
0005434138159	28753	21	6C
0005434138160	28753	22	6D
0005434138137	28753	23	6E
0005434138212	28753	24	6F
0005434138196	28753	25	7A
0005434138140	28753	26	7C
0005434138206	28753	27	7D
0005434138214	28753	28	7E
0005434138170	28753	29	7F
0005434138133	28753	30	8A
0005434138156	28753	31	8E
0005434138204	28753	32	8F
0005434138177	28753	33	9A
0005434138210	28753	34	9C
0005434138145	28753	35	9D
0005434138208	28753	36	9E
0005434138201	28753	37	9F
0005434138189	28753	38	10A
0005434138126	28753	39	10C
0005434138164	28753	40	10D
0005434138155	28753	41	10E
0005434138141	28753	42	10F
0005434138179	28753	43	11A
0005434138182	28753	44	11C
0005434138173	28753	45	11D
0005434138213	28753	46	11E
0005434138169	28753	47	11F
0005434138135	28753	48	12A
0005434138150	28753	49	12C
0005434138165	28753	50	12D
0005434138175	28753	51	12E
0005434138197	28753	52	12F
0005434138131	28753	53	13A
0005434138144	28753	54	13C
0005434138138	28753	55	13D
0005434138195	28753	56	13E
0005434138142	28753	57	13F
0005434138154	28753	58	14C
0005434138161	28753	59	14D
0005434138209	28753	60	14E
0005434138171	28753	61	14F
0005434138134	28753	62	15A
0005434138205	28753	63	15C
0005434138186	28753	64	15D
0005434138157	28753	65	15E
0005434138151	28753	66	15F
0005434138129	28753	67	16A
0005434138125	28753	68	16C
0005434138176	28753	69	16D
0005434138183	28753	70	16E
0005434138174	28753	71	16F
0005434138200	28753	72	17A
0005434138185	28753	73	17C
0005434138148	28753	74	17D
0005434138193	28753	75	17E
0005434138162	28753	76	17F
0005434138132	28753	77	18A
0005434138207	28753	78	18D
0005434138199	28753	79	18E
0005434138130	28753	80	18F
0005434138178	28753	81	19A
0005434138158	28753	82	19C
0005434138147	28753	83	19D
0005434138187	28753	84	19E
0005434138168	28753	85	19F
0005434138192	28753	86	20A
0005434138128	28753	87	20C
0005434138136	28753	88	20D
0005434138180	28753	89	20E
0005434138184	28753	90	20F
0005435312786	6589	1	1A
0005434466467	6589	2	1D
0005434466468	6589	3	2A
0005434466464	6589	4	2D
0005435312774	6589	5	5A
0005434466465	6589	6	5D
0005434466462	6589	7	18D
0005434466466	6589	8	19D
0005435312787	6589	9	20B
0005434466460	6589	10	21A
0005434466459	6589	11	21B
0005434466461	6589	12	21C
0005434466463	6589	13	21D
0005434466458	6589	14	22B
0005434513573	19087	1	1C
0005434513556	19087	2	2B
0005434190402	19087	3	2C
0005434516057	19087	4	2D
0005434516051	19087	5	3C
0005434190400	19087	6	4A
0005434190406	19087	7	4B
0005434513554	19087	8	4C
0005434513557	19087	9	4D
0005434190401	19087	10	5A
0005434516059	19087	11	5B
0005434190407	19087	12	5C
0005434516058	19087	13	5D
0005434190403	19087	14	6A
0005434513552	19087	15	6C
0005434513553	19087	16	7A
0005434513547	19087	17	7B
0005434516064	19087	18	7D
0005434190408	19087	19	18B
0005434516052	19087	20	18D
0005434516055	19087	21	19D
0005434513558	19087	22	20A
0005434516060	19087	23	20B
0005434190404	19087	24	20C
0005434513551	19087	25	20D
0005434513555	19087	26	21A
0005434516062	19087	27	22C
0005434516056	19087	28	23A
0005434190405	19087	29	23B
0005433538877	6795	1	2C
0005433534500	6795	2	2D
0005433538875	6795	3	3B
0005435259740	6795	4	3C
0005433538881	6795	5	4C
0005435259726	6795	6	6A
0005435259727	6795	7	6D
0005433534501	6795	8	7C
0005433538880	6795	9	7D
0005435259712	6795	10	18D
0005433538879	6795	11	19B
0005433538876	6795	12	19D
0005435259710	6795	13	20B
0005433538883	6795	14	20C
0005433538882	6795	15	22B
0005435259733	6795	16	22D
0005433538878	6795	17	23A
0005435259711	6795	18	23B
0005435259761	25022	1	2A
0005433538825	25022	2	2D
0005435259760	25022	3	5A
0005435259763	25022	4	5D
0005433538803	25022	5	6B
0005433538802	25022	6	7B
0005435259762	25022	7	7C
0005433538759	25022	8	7D
0005433538788	25022	9	18A
0005433538824	25022	10	18D
0005433538843	25022	11	19B
0005433538812	25022	12	19C
0005433538809	25022	13	21C
0005433538808	25022	14	21D
0005435259759	25022	15	22D
0005433538811	25022	16	23B
0005433511964	801	1	3B
0005433511959	801	2	4B
0005433511960	801	3	4C
0005432922496	801	4	5B
0005433511963	801	5	7A
0005433511957	801	6	7D
0005433511966	801	7	19D
0005432922483	801	8	20A
0005433511962	801	9	20B
0005433511961	801	10	20C
0005433511956	801	11	20D
0005433511958	801	12	21D
0005433511965	801	13	23A
0005432922527	16179	1	3B
0005432922530	16179	2	4D
0005433511898	16179	3	5B
0005432922529	16179	4	7D
0005432922532	16179	5	18A
0005432922528	16179	6	20B
0005433511917	16179	7	21B
0005432922531	16179	8	21C
0005435697369	3697	1	1A
0005435697383	3697	2	1B
0005435697362	3697	3	1C
0005435697384	3697	4	1D
0005434950536	3697	5	2A
0005435697374	3697	6	2B
0005435916139	3697	7	2C
0005435697363	3697	8	2D
0005434950534	3697	9	3A
0005435697389	3697	10	3B
0005435697380	3697	11	3D
0005435916142	3697	12	4A
0005434950535	3697	13	4B
0005435697365	3697	14	4C
0005435697370	3697	15	4D
0005435916147	3697	16	5A
0005435697379	3697	17	5B
0005435916158	3697	18	5C
0005435697386	3697	19	6A
0005435697364	3697	20	6B
0005434950533	3697	21	6C
0005435697377	3697	22	6D
0005435916145	3697	23	7A
0005435697366	3697	24	7B
0005435916140	3697	25	7C
0005435697381	3697	26	7D
0005435697378	3697	27	18A
0005435697373	3697	28	18B
0005435697368	3697	29	18D
0005434950532	3697	30	19A
0005435916130	3697	31	19B
0005435697387	3697	32	19C
0005435697360	3697	33	20A
0005435916144	3697	34	20B
0005435697372	3697	35	20C
0005435697361	3697	36	21A
0005435916159	3697	37	21B
0005435697367	3697	38	21C
0005435697388	3697	39	21D
0005435697382	3697	40	22A
0005435697376	3697	41	22B
0005435697371	3697	42	22C
0005435697375	3697	43	22D
0005435697385	3697	44	23A
0005435916148	3697	45	23B
0005435697077	16271	1	1D
0005434950494	16271	2	2A
0005435935046	16271	3	2B
0005434950510	16271	4	3A
0005435697120	16271	5	3B
0005435935047	16271	6	3C
0005435697173	16271	7	3D
0005435697036	16271	8	4A
0005434950501	16271	9	4B
0005435697097	16271	10	4C
0005434950492	16271	11	4D
0005435697114	16271	12	5A
0005435697041	16271	13	5B
0005435696976	16271	14	5C
0005435697096	16271	15	6A
0005435697115	16271	16	6B
0005434950511	16271	17	6C
0005435697084	16271	18	7A
0005434950491	16271	19	7B
0005435916172	16271	20	7C
0005435697187	16271	21	7D
0005434950482	16271	22	18A
0005435697085	16271	23	18B
0005435697030	16271	24	18C
0005434950483	16271	25	18D
0005435697142	16271	26	19A
0005435935045	16271	27	19B
0005435697029	16271	28	20C
0005434950481	16271	29	20D
0005435916171	16271	30	21A
0005435696918	16271	31	21B
0005435697186	16271	32	21C
0005435697062	16271	33	22A
0005435697189	16271	34	22B
0005434950493	16271	35	22C
0005435697000	16271	36	22D
0005435916170	16271	37	23A
0005435904892	3972	1	1B
0005432607572	3972	2	1C
0005434606833	3972	3	2A
0005434604900	3972	4	2D
0005434606831	3972	5	3A
0005434604901	3972	6	3C
0005433519464	3972	7	3D
0005435904891	3972	8	4B
0005434604902	3972	9	4C
0005435853600	3972	10	4D
0005432607571	3972	11	6C
0005432609734	3972	12	6D
0005435853605	3972	13	7B
0005435841466	3972	14	7D
0005432609735	3972	15	18A
0005433519463	3972	16	18B
0005435853601	3972	17	18C
0005434604903	3972	18	18D
0005432609738	3972	19	20A
0005434606832	3972	20	21B
0005432609737	3972	21	21D
0005432607569	3972	22	22B
0005432607570	3972	23	22C
0005435853606	3972	24	22D
0005432609736	3972	25	23B
0005435841094	22078	1	1C
0005434606792	22078	2	2A
0005433519416	22078	3	1D
0005433519415	22078	4	2B
0005432609688	22078	5	2D
0005432609687	22078	6	3A
0005432609697	22078	7	3B
0005433519413	22078	8	3C
0005435841096	22078	9	3D
0005432609698	22078	10	4A
0005432613823	22078	11	4B
0005432609693	22078	12	4C
0005432609691	22078	13	4D
0005432609684	22078	14	5B
0005435841476	22078	15	5C
0005432613829	22078	16	5D
0005435841473	22078	17	6A
0005432609689	22078	18	6B
0005432613807	22078	19	6D
0005435841097	22078	20	7B
0005433519423	22078	21	7C
0005435841472	22078	22	7D
0005432609673	22078	23	19A
0005432609672	22078	24	19B
0005435841474	22078	25	19C
0005435841475	22078	26	19D
0005432613808	22078	27	20A
0005435841098	22078	28	20B
0005432609696	22078	29	20C
0005432613800	22078	30	21A
0005435841471	22078	31	21B
0005433519412	22078	32	21D
0005435841095	22078	33	22A
0005432613830	22078	34	22B
0005432609695	22078	35	22C
0005432609685	22078	36	22D
0005432609690	22078	37	23B
0005433348961	768	1	1A
0005435628727	768	2	2B
0005433348960	768	3	3A
0005433348932	768	4	4A
0005433348928	768	5	4B
0005433348933	768	6	5A
0005433348994	15985	1	2A
0005435628701	15985	2	2B
0005435628703	15985	3	3A
0005433348995	15985	4	3B
0005433348998	15985	5	4A
0005435628698	15985	6	4B
0005433348997	15985	7	5A
0005435628702	15985	8	5B
0005433348999	15985	9	6A
0005433348996	15985	10	6B
0005433158118	17255	1	1A
0005433158113	17255	2	1B
0005433159298	17255	3	2A
0005434446519	17255	4	2B
0005433158114	17255	5	3A
0005433158112	17255	6	4A
0005434445247	17255	7	5A
0005433159290	17255	8	4B
0005434445248	17255	9	5B
0005433158115	17255	10	6A
0005433159281	17255	11	6B
0005434445230	17668	1	1A
0005434445236	17668	2	1B
0005434445239	17668	3	4B
0005434445238	17668	4	6A
0005434445224	17668	5	6B
0005435132895	7881	1	1A
0005435132894	7881	2	2B
0005435132890	7881	3	2C
0005435383102	7881	4	3C
0005435132889	7881	5	4D
0005435132896	7881	6	5D
0005435132892	7881	7	7B
0005435383121	7881	8	18A
0005435132891	7881	9	18D
0005435132899	7881	10	20B
0005435132897	7881	11	21A
0005435132893	7881	12	21D
0005435132898	7881	13	23A
0005435383114	7881	14	23B
0005435383155	33108	1	1C
0005435132800	33108	2	2C
0005435132805	33108	3	3A
0005435383158	33108	4	3C
0005435132809	33108	5	4C
0005435383156	33108	6	6D
0005435132855	33108	7	22C
0005435383157	33108	8	22D
0005435383154	33108	9	23B
0005435811084	4409	1	1F
0005435811076	4409	2	2F
0005435811072	4409	3	3A
0005435811070	4409	4	4D
0005435811069	4409	5	6B
0005435811079	4409	6	7A
0005435938863	4409	7	8D
0005435811082	4409	8	9B
0005435811071	4409	9	9A
0005435811077	4409	10	10C
0005435938860	4409	11	10F
0005435938864	4409	12	11A
0005435811074	4409	13	11F
0005435938873	4409	14	12B
0005435811083	4409	15	15B
0005435811075	4409	16	15A
0005435938855	4409	17	17A
0005435811078	4409	18	17C
0005435811073	4409	19	17E
0005435811080	4409	20	21B
0005435811081	4409	21	21E
0005435811025	29439	1	1C
0005435938887	29439	2	1A
0005435811031	29439	3	1D
0005435811043	29439	4	2A
0005435938886	29439	5	2C
0005435811001	29439	6	3D
0005435811013	29439	7	6D
0005435811048	29439	8	6C
0005435811014	29439	9	6E
0005435811034	29439	10	8A
0005435811029	29439	11	8E
0005435811012	29439	12	9F
0005435811026	29439	13	10B
0005435811028	29439	14	11D
0005435938889	29439	15	12D
0005435811024	29439	16	12C
0005435811027	29439	17	13A
0005435811033	29439	18	14A
0005435811023	29439	19	14D
0005435811011	29439	20	15A
0005435938891	29439	21	15E
0005435811022	29439	22	17D
0005435938890	29439	23	18F
0005435938885	29439	24	19D
0005435938888	29439	25	20E
0005435160320	7526	1	1A
0005435390177	7526	2	1C
0005435390176	7526	3	2B
0005435390195	7526	4	3A
0005435160309	7526	5	3B
0005435160312	7526	6	4A
0005435160316	7526	7	4B
0005435390184	7526	8	5B
0005435390209	7526	9	5D
0005435390204	7526	10	7B
0005435390210	7526	11	7C
0005435160319	7526	12	18D
0005435160318	7526	13	19B
0005435160313	7526	14	20A
0005435160314	7526	15	20B
0005435160315	7526	16	20C
0005435160310	7526	17	20D
0005435390194	7526	18	21A
0005435390189	7526	19	21B
0005435160317	7526	20	21C
0005435160311	7526	21	21D
0005435160222	29585	1	1B
0005435160245	29585	2	1D
0005435160257	29585	3	2C
0005435160261	29585	4	3B
0005435390251	29585	5	3C
0005435160229	29585	6	3D
0005435390248	29585	7	4A
0005435160259	29585	8	5B
0005435160199	29585	9	5C
0005435160198	29585	10	5D
0005435390247	29585	11	6B
0005435390246	29585	12	6D
0005435390249	29585	13	7B
0005435160200	29585	14	7D
0005435160201	29585	15	18A
0005435390245	29585	16	18D
0005435160221	29585	17	19A
0005435160197	29585	18	19D
0005435160244	29585	19	20B
0005435160258	29585	20	21C
0005435390250	29585	21	23B
0005435178995	18476	1	1A
0005432398181	18476	2	2A
0005432394080	18476	3	2B
0005435178993	18476	4	3B
0005432398164	18476	5	4A
0005432394082	18476	6	4B
0005432394081	18476	7	5A
0005435178498	18476	8	6A
0005435178994	18476	9	6B
0005432400124	27158	1	1A
0005435178485	27158	2	1B
0005432398198	27158	3	2A
0005432398199	27158	4	2B
0005432400122	27158	5	3A
0005432400125	27158	6	3B
0005432398197	27158	7	4A
0005435178472	27158	8	4B
0005432400123	27158	9	5B
0005432398196	27158	10	6A
0005435178482	27158	11	6B
0005432639139	2256	1	1A
0005432639152	2256	2	1C
0005432639150	2256	3	1D
0005432639148	2256	4	1F
0005432865945	2256	5	3A
0005432639134	2256	6	3C
0005432865958	2256	7	4C
0005432865963	2256	8	4E
0005432865961	2256	9	6D
0005432639155	2256	10	6F
0005432639137	2256	11	7C
0005432865976	2256	12	7E
0005432639154	2256	13	7F
0005432865977	2256	14	8C
0005432639151	2256	15	8F
0005432639136	2256	16	9E
0005432639142	2256	17	10E
0005432865948	2256	18	12D
0005432639135	2256	19	13C
0005432639156	2256	20	14A
0005432865957	2256	21	14E
0005432639153	2256	22	15A
0005432639149	2256	23	15C
0005432865975	2256	24	15D
0005432639141	2256	25	15E
0005432639132	2256	26	15F
0005432639140	2256	27	16D
0005432865959	2256	28	16E
0005432639147	2256	29	17C
0005432639138	2256	30	17E
0005432639143	2256	31	17F
0005432639146	2256	32	18A
0005432639145	2256	33	18C
0005432639133	2256	34	19C
0005432639144	2256	35	19E
0005432865946	2256	36	20E
0005434191262	9706	1	4A
0005434191267	9706	2	6B
0005434504208	6548	1	1C
0005435103942	6548	2	2A
0005435103943	6548	3	2C
0005434504217	6548	4	3A
0005435103944	6548	5	3F
0005434504191	6548	6	4A
0005434504188	6548	7	4C
0005434504189	6548	8	4E
0005434504186	6548	9	5A
0005434504195	6548	10	5C
0005434504202	6548	11	5D
0005435103948	6548	12	5F
0005434504194	6548	13	6A
0005434504199	6548	14	6D
0005434504212	6548	15	6F
0005434504213	6548	16	8C
0005434504203	6548	17	8D
0005434504200	6548	18	9C
0005434504222	6548	19	9E
0005435103947	6548	20	10A
0005434504225	6548	21	10E
0005434504190	6548	22	11A
0005434504196	6548	23	11E
0005434504210	6548	24	12A
0005435103945	6548	25	12F
0005434504219	6548	26	13C
0005434504207	6548	27	13D
0005434504197	6548	28	13E
0005434504187	6548	29	14C
0005434504193	6548	30	14D
0005434504198	6548	31	14E
0005434504211	6548	32	15A
0005435103946	6548	33	15D
0005434504205	6548	34	15E
0005434504204	6548	35	15F
0005434504220	6548	36	16A
0005434504216	6548	37	16E
0005434504185	6548	38	17A
0005434504218	6548	39	17C
0005434504223	6548	40	17E
0005434504214	6548	41	17F
0005434504192	6548	42	18D
0005434504215	6548	43	18F
0005434504201	6548	44	19C
0005434504224	6548	45	19E
0005434504221	6548	46	19F
0005435103949	6548	47	20C
0005434504209	6548	48	20D
0005434504206	6548	49	20E
0005434503776	22648	1	1A
0005434503628	22648	2	1D
0005435103844	22648	3	2C
0005434503836	22648	4	2D
0005434503725	22648	5	2F
0005434503807	22648	6	3A
0005434503727	22648	7	3C
0005435103853	22648	8	3D
0005434503691	22648	9	4A
0005434503817	22648	10	4C
0005435103841	22648	11	4D
0005434503815	22648	12	4F
0005434503772	22648	13	5A
0005434503752	22648	14	5E
0005434503873	22648	15	5F
0005434503749	22648	16	6A
0005434503750	22648	17	6C
0005434503806	22648	18	6D
0005434503753	22648	19	6E
0005434503818	22648	20	7A
0005434503790	22648	21	7C
0005434503839	22648	22	7D
0005435103827	22648	23	7E
0005434503751	22648	24	7F
0005434503666	22648	25	8F
0005434503639	22648	26	9D
0005434503869	22648	27	9F
0005434503791	22648	28	10C
0005434503660	22648	29	10E
0005434503649	22648	30	10F
0005434503724	22648	31	12C
0005434503747	22648	32	12D
0005434503663	22648	33	12E
0005434503826	22648	34	12F
0005434503808	22648	35	13A
0005434503758	22648	36	13D
0005434503627	22648	37	14A
0005434503689	22648	38	14D
0005434503728	22648	39	15A
0005434503774	22648	40	15C
0005434503650	22648	41	15F
0005434503629	22648	42	16C
0005435103833	22648	43	16E
0005434503713	22648	44	16F
0005434503864	22648	45	17A
0005435103852	22648	46	17C
0005434503816	22648	47	17D
0005434503746	22648	48	17E
0005434503638	22648	49	18C
0005434503760	22648	50	18D
0005434503840	22648	51	19A
0005434503690	22648	52	19C
0005435103826	22648	53	19D
0005434503696	22648	54	19F
0005434503719	22648	55	20A
0005434503729	22648	56	20D
0005434503868	22648	57	20F
0005435653129	1653	1	1C
0005435653104	1653	2	1D
0005435653121	1653	3	2A
0005435653103	1653	4	2C
0005433367633	1653	5	2D
0005433367553	1653	6	3A
0005435653097	1653	7	3C
0005433367699	1653	8	3D
0005433367610	1653	9	3F
0005433367624	1653	10	4A
0005433367715	1653	11	4C
0005435653102	1653	12	4D
0005433367648	1653	13	4E
0005435653095	1653	14	4F
0005435653101	1653	15	5A
0005435653119	1653	16	5C
0005435653133	1653	17	5D
0005435653131	1653	18	5E
0005433367440	1653	19	5F
0005433367647	1653	20	6A
0005435653098	1653	21	6D
0005433367644	1653	22	6E
0005433367589	1653	23	7A
0005435653136	1653	24	7C
0005435653105	1653	25	7D
0005435653117	1653	26	7E
0005433367609	1653	27	7F
0005433367623	1653	28	8D
0005435653120	1653	29	8E
0005435653138	1653	30	8F
0005433367568	1653	31	9A
0005433367614	1653	32	9D
0005433367671	1653	33	9E
0005433367439	1653	34	9F
0005433367587	1653	35	10A
0005435653107	1653	36	10C
0005435653134	1653	37	10D
0005433367716	1653	38	10E
0005435653130	1653	39	10F
0005435653100	1653	40	11A
0005433367697	1653	41	11C
0005435653108	1653	42	11D
0005433367780	1653	43	11E
0005435653127	1653	44	11F
0005435653099	1653	45	12A
0005435653122	1653	46	12C
0005435653096	1653	47	12D
0005433367585	1653	48	12E
0005433367433	1653	49	13A
0005435653115	1653	50	13D
0005435653106	1653	51	13E
0005435653125	1653	52	13F
0005433367438	1653	53	14A
0005435653112	1653	54	14C
0005433367674	1653	55	14D
0005433367431	1653	56	14E
0005435653110	1653	57	14F
0005435653109	1653	58	15A
0005435653124	1653	59	15C
0005433367612	1653	60	15D
0005435653113	1653	61	15E
0005433367473	1653	62	15F
0005435653123	1653	63	16A
0005433367608	1653	64	16C
0005433367588	1653	65	16D
0005433367552	1653	66	16E
0005435653128	1653	67	17A
0005433367576	1653	68	17D
0005433367781	1653	69	17F
0005435653094	1653	70	18A
0005433367556	1653	71	18C
0005435653135	1653	72	18D
0005435653126	1653	73	19A
0005435653132	1653	74	19C
0005433367615	1653	75	19D
0005433367474	1653	76	19E
0005435653137	1653	77	19F
0005435653118	1653	78	20A
0005433367432	1653	79	20C
0005435653111	1653	80	20D
0005435653116	1653	81	20E
0005435653114	1653	82	20F
0005433367911	21684	1	1A
0005433367930	21684	2	1C
0005433367944	21684	3	1D
0005435652704	21684	4	2A
0005433367933	21684	5	2D
0005435652610	21684	6	2F
0005435652526	21684	7	3A
0005433367925	21684	8	3D
0005433367914	21684	9	3F
0005433367917	21684	10	4A
0005435652577	21684	11	4D
0005433367941	21684	12	4E
0005435652755	21684	13	4F
0005435652633	21684	14	5C
0005435652712	21684	15	5D
0005433367923	21684	16	5E
0005435652817	21684	17	5F
0005433367927	21684	18	6A
0005433367924	21684	19	6C
0005435652832	21684	20	6D
0005433367932	21684	21	6E
0005435652831	21684	22	6F
0005433367935	21684	23	7A
0005435652812	21684	24	7C
0005433367939	21684	25	7D
0005433367909	21684	26	7F
0005435652754	21684	27	8A
0005435652654	21684	28	8C
0005435652847	21684	29	8D
0005435652678	21684	30	8E
0005433367940	21684	31	8F
0005435652525	21684	32	9A
0005433367947	21684	33	9C
0005435652622	21684	34	9D
0005435652652	21684	35	9E
0005435652573	21684	36	10A
0005433367912	21684	37	10D
0005433367926	21684	38	10E
0005433367920	21684	39	10F
0005433367913	21684	40	11A
0005433367942	21684	41	11D
0005435652524	21684	42	11E
0005435652647	21684	43	11F
0005433367946	21684	44	12C
0005433367931	21684	45	12D
0005435652380	21684	46	12E
0005435652538	21684	47	12F
0005435652581	21684	48	13A
0005433367945	21684	49	13C
0005433367936	21684	50	13D
0005433367919	21684	51	13E
0005435652813	21684	52	13F
0005433367915	21684	53	14C
0005435652848	21684	54	14A
0005435652648	21684	55	14D
0005433367943	21684	56	14E
0005435652811	21684	57	14F
0005435652830	21684	58	15A
0005435652744	21684	59	15C
0005435652659	21684	60	15D
0005435652815	21684	61	15F
0005435652818	21684	62	16A
0005433367929	21684	63	16C
0005435652702	21684	64	16D
0005433367928	21684	65	16E
0005433367918	21684	66	16F
0005435652705	21684	67	17A
0005433367910	21684	68	17C
0005435652774	21684	69	17D
0005433367921	21684	70	17E
0005435652381	21684	71	17F
0005435652566	21684	72	18A
0005433367916	21684	73	18C
0005433367937	21684	74	18D
0005435652721	21684	75	18F
0005435652842	21684	76	19A
0005433367934	21684	77	19C
0005435652841	21684	78	19D
0005435652614	21684	79	19E
0005435652734	21684	80	20A
0005433367938	21684	81	20C
0005435652634	21684	82	20D
0005433367922	21684	83	20E
0005434466413	23230	1	1A
0005434466441	23230	2	1D
0005435312811	23230	3	2C
0005434466405	23230	4	3A
0005434466423	23230	5	4B
0005434466406	23230	6	4C
0005434466417	23230	7	4D
0005435312810	23230	8	5A
0005435312809	23230	9	5B
0005434466425	23230	10	6A
0005434466436	23230	11	7D
0005434466418	23230	12	18A
0005434466412	23230	13	19A
0005434466438	23230	14	19D
0005434466442	23230	15	20A
0005435312808	23230	16	21B
0005434466422	23230	17	22A
0005435312807	23230	18	22B
0005434466411	23230	19	22C
0005434466424	23230	20	23A
0005433985987	4149	1	1C
0005433986023	4149	2	1D
0005433985988	4149	3	1F
0005433985992	4149	4	3C
0005433986010	4149	5	3F
0005433986021	4149	6	4D
0005433986018	4149	7	5E
0005433986004	4149	8	6C
0005433986006	4149	9	6F
0005433986016	4149	10	7A
0005433986013	4149	11	7D
0005433985996	4149	12	7F
0005433986008	4149	13	8E
0005433986019	4149	14	8F
0005433985991	4149	15	9C
0005435788774	4149	16	9E
0005433986025	4149	17	9F
0005433985993	4149	18	10D
0005433985998	4149	19	10E
0005433986017	4149	20	10F
0005433986007	4149	21	11C
0005433986001	4149	22	11E
0005435788773	4149	23	11F
0005433986022	4149	24	12A
0005433986009	4149	25	12C
0005433985999	4149	26	12E
0005433985984	4149	27	12F
0005433986003	4149	28	13E
0005433986000	4149	29	15A
0005433986024	4149	30	15D
0005433986012	4149	31	15E
0005433985997	4149	32	16D
0005433986015	4149	33	16E
0005433985995	4149	34	16F
0005433986014	4149	35	17A
0005433985990	4149	36	17C
0005433986026	4149	37	18A
0005433985985	4149	38	18C
0005433986020	4149	39	18D
0005433985986	4149	40	18E
0005433986002	4149	41	18F
0005433986005	4149	42	19A
0005433985989	4149	43	19F
0005433985994	4149	44	20C
0005433986011	4149	45	20F
0005433985567	25668	1	1A
0005433985382	25668	2	2C
0005433985612	25668	3	2D
0005433985676	25668	4	3C
0005433985226	25668	5	3F
0005433985227	25668	6	4C
0005433985295	25668	7	4D
0005433985591	25668	8	5D
0005435788743	25668	9	5F
0005433985522	25668	10	6C
0005433985355	25668	11	6D
0005433985662	25668	12	7C
0005433985715	25668	13	8C
0005433985611	25668	14	8D
0005433985717	25668	15	8F
0005433985664	25668	16	9A
0005433985778	25668	17	9D
0005433985777	25668	18	9E
0005433985663	25668	19	9F
0005433985419	25668	20	10A
0005435788762	25668	21	10D
0005433985543	25668	22	10E
0005433985598	25668	23	10F
0005433985618	25668	24	11C
0005433985610	25668	25	12A
0005433985228	25668	26	12C
0005435788761	25668	27	12D
0005433985613	25668	28	13D
0005433985660	25668	29	13E
0005433985479	25668	30	14E
0005433985536	25668	31	15D
0005433985381	25668	32	15E
0005433985671	25668	33	16A
0005433985418	25668	34	16C
0005433985509	25668	35	16E
0005433985621	25668	36	17C
0005433985466	25668	37	17D
0005433985609	25668	38	17F
0005435788753	25668	39	18C
0005433985659	25668	40	18D
0005433985566	25668	41	19A
0005433985718	25668	42	19D
0005433985472	25668	43	20A
0005433985467	25668	44	20C
0005433985532	25668	45	20D
0005433985615	25668	46	20E
0005433985770	25668	47	20F
0005433461550	19920	1	1B
0005433461557	19920	2	2B
0005433463874	19920	3	3A
0005433463869	19920	4	3C
0005433461560	19920	5	4C
0005433461553	19920	6	9G
0005433461556	19920	7	12A
0005433463877	19920	8	12D
0005433463866	19920	9	12E
0005433461580	19920	10	13E
0005433461554	19920	11	15A
0005433463865	19920	12	17F
0005433461559	19920	13	18G
0005433463875	19920	14	21A
0005433461561	19920	15	21H
0005433461552	19920	16	22D
0005433463870	19920	17	23E
0005433463868	19920	18	28E
0005433463873	19920	19	28F
0005433463864	19920	20	33A
0005433461562	19920	21	33D
0005433461551	19920	22	33E
0005433461558	19920	23	34F
0005433463878	19920	24	35D
0005433463871	19920	25	37E
0005433463876	19920	26	37D
0005435720818	21275	1	5C
0005435720819	21275	2	18D
0005435719557	21275	3	20A
0005435719556	21275	4	20B
0005434509151	1631	1	1A
0005433168337	1631	2	1B
0005434509157	1631	3	1C
0005434509156	1631	4	1D
0005433168334	1631	5	2A
0005434509147	1631	6	2B
0005434509152	1631	7	2D
0005434509139	1631	8	3A
0005434509150	1631	9	3B
0005434509140	1631	10	3C
0005434509154	1631	11	3D
0005434509161	1631	12	4C
0005434509149	1631	13	4D
0005433168325	1631	14	5C
0005434509144	1631	15	5D
0005434509143	1631	16	6A
0005434509141	1631	17	6B
0005434509158	1631	18	7B
0005433168327	1631	19	7C
0005434509155	1631	20	18B
0005434509146	1631	21	18C
0005433168348	1631	22	18D
0005434509160	1631	23	19A
0005433168314	1631	24	19C
0005434509159	1631	25	20B
0005434509142	1631	26	20C
0005433168341	1631	27	20D
0005433168326	1631	28	21A
0005434509162	1631	29	21C
0005434509153	1631	30	21D
0005433168336	1631	31	22A
0005434509148	1631	32	22B
0005433168329	1631	33	22C
0005433168335	1631	34	22D
0005433168338	1631	35	23A
0005434509145	1631	36	23B
0005432655415	17853	1	1A
0005434151709	17853	2	2D
0005432664123	17853	3	2F
0005432658576	17853	4	3A
0005432661903	17853	5	3D
0005432655454	17853	6	4C
0005432869538	17853	7	4D
0005432664115	17853	8	4E
0005432655401	17853	9	4F
0005432667435	17853	10	5A
0005432660793	17853	11	5C
0005432659691	17853	12	5E
0005432667442	17853	13	5F
0005432659690	17853	14	6A
0005432869535	17853	15	6D
0005432659689	17853	16	6F
0005434151708	17853	17	7A
0005432659685	17853	18	7C
0005432661902	17853	19	7E
0005432657436	17853	20	8D
0005432658581	17853	21	8E
0005432655459	17853	22	9C
0005432666375	17853	23	9E
0005432869537	17853	24	10D
0005432663023	17853	25	10E
0005434151710	17853	26	10F
0005432658560	17853	27	11A
0005432655456	17853	28	11C
0005432664126	17853	29	11F
0005432869534	17853	30	12A
0005432655400	17853	31	12D
0005432657437	17853	32	13D
0005432869540	17853	33	13E
0005432655444	17853	34	14A
0005432869533	17853	35	14C
0005432661905	17853	36	14F
0005432657433	17853	37	15A
0005432664121	17853	38	15D
0005432658577	17853	39	15E
0005432869536	17853	40	15F
0005432667436	17853	41	16C
0005432869539	17853	42	16E
0005432666373	17853	43	17C
0005432657434	17853	44	17F
0005432655416	17853	45	18C
0005432661910	17853	46	18E
0005432665260	17853	47	19D
0005432664124	17853	48	19E
0005432658580	17853	49	19F
0005432665267	17853	50	20A
0005432664116	17853	51	20C
0005432661906	17853	52	20E
0005432663036	26300	1	1A
0005432661913	26300	2	1C
0005432655532	26300	3	1F
0005432869443	26300	4	1D
0005432663035	26300	5	2A
0005432661915	26300	6	2C
0005432666390	26300	7	2D
0005432663040	26300	8	3A
0005432663033	26300	9	3C
0005432869442	26300	10	3D
0005432663027	26300	11	3F
0005432661925	26300	12	4A
0005432659706	26300	13	4C
0005432661917	26300	14	4D
0005432664136	26300	15	4F
0005432665273	26300	16	5A
0005432657447	26300	17	5C
0005432667454	26300	18	5D
0005432655531	26300	19	5E
0005432658591	26300	20	5F
0005432664137	26300	21	6A
0005432664138	26300	22	6C
0005432658590	26300	23	6E
0005432664135	26300	24	6F
0005432661920	26300	25	7C
0005432665275	26300	26	7D
0005432664141	26300	27	7E
0005432663029	26300	28	8A
0005432663030	26300	29	8D
0005432655521	26300	30	8E
0005432664133	26300	31	8F
0005432664130	26300	32	9A
0005432664134	26300	33	9C
0005432655522	26300	34	9D
0005432655529	26300	35	9E
0005432655530	26300	36	9F
0005432661916	26300	37	10A
0005432666389	26300	38	10E
0005432869439	26300	39	10F
0005432655528	26300	40	11C
0005432667453	26300	41	11E
0005432655527	26300	42	11F
0005432655524	26300	43	12A
0005432664132	26300	44	12C
0005432657448	26300	45	12D
0005432659705	26300	46	12E
0005432869468	26300	47	12F
0005432664128	26300	48	13A
0005432661926	26300	49	13C
0005432661914	26300	50	13D
0005432869446	26300	51	13F
0005432869458	26300	52	14A
0005432655533	26300	53	14C
0005432666388	26300	54	14D
0005432661924	26300	55	14E
0005432661923	26300	56	14F
0005432660818	26300	57	15A
0005432663032	26300	58	15C
0005432661922	26300	59	15D
0005432663031	26300	60	15E
0005432664140	26300	61	15F
0005432663038	26300	62	16A
0005432660817	26300	63	16C
0005432661919	26300	64	16D
0005432663034	26300	65	16E
0005432869438	26300	66	16F
0005432661918	26300	67	17A
0005432667455	26300	68	17C
0005432664131	26300	69	17D
0005432657449	26300	70	17E
0005432869457	26300	71	17F
0005432665274	26300	72	18A
0005432664139	26300	73	18C
0005432869440	26300	74	18D
0005432661927	26300	75	18F
0005432655526	26300	76	19A
0005432663039	26300	77	19C
0005432663037	26300	78	19D
0005432664129	26300	79	19E
0005432655525	26300	80	19F
0005432663028	26300	81	20A
0005432655523	26300	82	20C
0005432661921	26300	83	20D
0005432664142	26300	84	20E
0005432639073	25058	1	1A
0005432639034	25058	2	1C
0005432638937	25058	3	1F
0005432866020	25058	4	2A
0005432639022	25058	5	2C
0005432639050	25058	6	2F
0005432639040	25058	7	3C
0005432866012	25058	8	3D
0005432639038	25058	9	4C
0005432639004	25058	10	4D
0005432866027	25058	11	4E
0005432639027	25058	12	4F
0005432639012	25058	13	5A
0005432638988	25058	14	5C
0005432866010	25058	15	5D
0005432639049	25058	16	6D
0005432638994	25058	17	6E
0005432638965	25058	18	7A
0005432639037	25058	19	7D
0005432639052	25058	20	7F
0005432639023	25058	21	8A
0005432639051	25058	22	8D
0005432866029	25058	23	8E
0005432866014	25058	24	8F
0005432638995	25058	25	9A
0005432639091	25058	26	9D
0005432866028	25058	27	9E
0005432639013	25058	28	10C
0005432639014	25058	29	10D
0005432866025	25058	30	10F
0005432866009	25058	31	11A
0005432639024	25058	32	11C
0005432866015	25058	33	11D
0005432639084	25058	34	12E
0005432639030	25058	35	12F
0005432639011	25058	36	13A
0005432639036	25058	37	13C
0005432866021	25058	38	13E
0005432639090	25058	39	14A
0005432638993	25058	40	14C
0005432639028	25058	41	14D
0005432866017	25058	42	14E
0005432866018	25058	43	15A
0005432639074	25058	44	15D
0005432639009	25058	45	15E
0005432638964	25058	46	15F
0005432866026	25058	47	16A
0005432866019	25058	48	16D
0005432866016	25058	49	16E
0005432639003	25058	50	16F
0005432639041	25058	51	17A
0005432639039	25058	52	17D
0005432866023	25058	53	17E
0005432866022	25058	54	18A
0005432639061	25058	55	18C
0005432866013	25058	56	18D
0005432639044	25058	57	18E
0005432638989	25058	58	19D
0005432638991	25058	59	19F
0005432866024	25058	60	20E
0005432866011	25058	61	20F
0005433438888	3124	1	1D
0005432287193	3124	2	1F
0005432328767	3124	3	2A
0005432328749	3124	4	2C
0005433438891	3124	5	2D
0005432328773	3124	6	2F
0005433438892	3124	7	3A
0005432328750	3124	8	3C
0005432328766	3124	9	3D
0005432328768	3124	10	3F
0005432328764	3124	11	4A
0005432328746	3124	12	4C
0005432328772	3124	13	4D
0005432905076	3124	14	4E
0005432328777	3124	15	5C
0005432328774	3124	16	5D
0005433438885	3124	17	5F
0005432328780	3124	18	6C
0005432328741	3124	19	6D
0005432328755	3124	20	6E
0005432328775	3124	21	7A
0005432328751	3124	22	7C
0005432905104	3124	23	7D
0005433438886	3124	24	7E
0005433438884	3124	25	8A
0005432287194	3124	26	8C
0005432328761	3124	27	8E
0005432328770	3124	28	8F
0005432905063	3124	29	9C
0005432328752	3124	30	9D
0005432328781	3124	31	9F
0005432328753	3124	32	10A
0005432328758	3124	33	10C
0005432328779	3124	34	10D
0005432328757	3124	35	10E
0005433438889	3124	36	11A
0005432905075	3124	37	11D
0005433438887	3124	38	11F
0005432328762	3124	39	11E
0005432328744	3124	40	12A
0005432328754	3124	41	12C
0005432905106	3124	42	12D
0005432328776	3124	43	13A
0005432287195	3124	44	13D
0005432328745	3124	45	13E
0005432328769	3124	46	13F
0005432328771	3124	47	14A
0005432905105	3124	48	14C
0005433438890	3124	49	14D
0005432328760	3124	50	14E
0005432328742	3124	51	14F
0005432328740	3124	52	15A
0005432905086	3124	53	15C
0005432328756	3124	54	15D
0005432328778	3124	55	15E
0005432328738	3124	56	15F
0005432328765	3124	57	16D
0005432287197	3124	58	16E
0005432287196	3124	59	16F
0005432328737	3124	60	17A
0005432328739	3124	61	17C
0005432328783	3124	62	17F
0005432328759	3124	63	18D
0005432328748	3124	64	18E
0005432328782	3124	65	18F
0005432328747	3124	66	19D
0005432287198	3124	67	19C
0005432328763	3124	68	20E
0005432328743	3124	69	20F
0005432328393	31152	1	1D
0005433438840	31152	2	1F
0005432328399	31152	3	2A
0005432328325	31152	4	2C
0005432328273	31152	5	2D
0005432328088	31152	6	2F
0005432905132	31152	7	3A
0005433438811	31152	8	3C
0005432328355	31152	9	3D
0005432328276	31152	10	4A
0005432054308	31152	11	4D
0005432328287	31152	12	4E
0005432328405	31152	13	5A
0005432328354	31152	14	5E
0005432328390	31152	15	5F
0005432328184	31152	16	6C
0005433438847	31152	17	6D
0005432328185	31152	18	7C
0005432328230	31152	19	7E
0005433438832	31152	20	8C
0005432328231	31152	21	8F
0005432328346	31152	22	9A
0005432328251	31152	23	9E
0005432328265	31152	24	9F
0005432054306	31152	25	10A
0005432054307	31152	26	10C
0005432328425	31152	27	10D
0005432328426	31152	28	10E
0005432328256	31152	29	11C
0005432328486	31152	30	11F
0005432905131	31152	31	12D
0005432328090	31152	32	12E
0005432328307	31152	33	12F
0005432328532	31152	34	13C
0005432328483	31152	35	13E
0005432905133	31152	36	14A
0005433438862	31152	37	14C
0005432905130	31152	38	16A
0005432328190	31152	39	16C
0005432328365	31152	40	16D
0005432328487	31152	41	16F
0005432328412	31152	42	17C
0005432328161	31152	43	17D
0005432328217	31152	44	17F
0005432328324	31152	45	18C
0005432328462	31152	46	18D
0005432905134	31152	47	19A
0005432328546	31152	48	19D
0005433438846	31152	49	19F
0005432328392	31152	50	20A
0005432328338	31152	51	20C
0005432328364	31152	52	20E
0005432328089	31152	53	20F
0005434309765	6190	1	1F
0005435296999	6190	2	2C
0005434309759	6190	3	2D
0005435999268	6190	4	3A
0005435487709	6190	5	3C
0005435999278	6190	6	4E
0005434309763	6190	7	4F
0005435487628	6190	8	5B
0005434309760	6190	9	5C
0005434309752	6190	10	5D
0005435297046	6190	11	5E
0005435999266	6190	12	6A
0005435487684	6190	13	6F
0005435999274	6190	14	7B
0005435487602	6190	15	7C
0005435487629	6190	16	7E
0005435999269	6190	17	8A
0005435999273	6190	18	8B
0005435487641	6190	19	8E
0005435999276	6190	20	9A
0005435487667	6190	21	9E
0005434309754	6190	22	10C
0005435999277	6190	23	11B
0005435487601	6190	24	11F
0005435296998	6190	25	12F
0005435487627	6190	26	13C
0005435487677	6190	27	13B
0005434309764	6190	28	13D
0005435487691	6190	29	14A
0005435487708	6190	30	14B
0005434309761	6190	31	14D
0005435999270	6190	32	15B
0005435487651	6190	33	15D
0005435999271	6190	34	16C
0005434309755	6190	35	16E
0005435296946	6190	36	17B
0005434309753	6190	37	17D
0005435296994	6190	38	17F
0005435487603	6190	39	18A
0005434309758	6190	40	18C
0005432146201	6190	41	18D
0005435999272	6190	42	18F
0005434309762	6190	43	19C
0005432146202	6190	44	19D
0005434309756	6190	45	19F
0005435487663	6190	46	21B
0005435487561	6190	47	21C
0005435999275	6190	48	21D
0005435999279	6190	49	23A
0005434309757	6190	50	23C
0005435999267	6190	51	23D
0005435297067	19530	1	1C
0005435487837	19530	2	2A
0005435297070	19530	3	2F
0005435487844	19530	4	3D
0005435487839	19530	5	4A
0005435487833	19530	6	4C
0005435999074	19530	7	4D
0005435999110	19530	8	4F
0005434309628	19530	9	5B
0005435999079	19530	10	5A
0005435487832	19530	11	5D
0005435999073	19530	12	5E
0005435487834	19530	13	6A
0005435487830	19530	14	6D
0005435487841	19530	15	7C
0005435487843	19530	16	7E
0005435297066	19530	17	8A
0005435297065	19530	18	7F
0005435297064	19530	19	8D
0005435999124	19530	20	8F
0005435297068	19530	21	9D
0005435999082	19530	22	9E
0005434309632	19530	23	10B
0005434309555	19530	24	11B
0005435487838	19530	25	11C
0005435487831	19530	26	11E
0005434309601	19530	27	11D
0005434309623	19530	28	12A
0005435487846	19530	29	12B
0005435487847	19530	30	13B
0005434309606	19530	31	13F
0005435487836	19530	32	14B
0005434309609	19530	33	14C
0005435487851	19530	34	14D
0005435999086	19530	35	14E
0005435487835	19530	36	15A
0005434309605	19530	37	14F
0005435999081	19530	38	15D
0005434309554	19530	39	16C
0005435487845	19530	40	16B
0005434309722	19530	41	16D
0005435487842	19530	42	17B
0005435297071	19530	43	17E
0005435999128	19530	44	18C
0005434309608	19530	45	18E
0005434309604	19530	46	19A
0005435999103	19530	47	19B
0005435487848	19530	48	19C
0005435487840	19530	49	19E
0005435999113	19530	50	20C
0005435999102	19530	51	20B
0005435487849	19530	52	20E
0005434309633	19530	53	22A
0005434309627	19530	54	22C
0005435999118	19530	55	22F
0005434309660	19530	56	23B
0005435487850	19530	57	23C
0005435999075	19530	58	23E
0005435297069	19530	59	23F
0005434446496	17556	1	1C
0005433158132	17556	2	5C
0005434446499	17556	3	5D
0005434446502	17556	4	6B
0005433158134	17556	5	18A
0005433158135	17556	6	19A
0005433158133	17556	7	20B
0005433158131	17556	8	20C
0005434446497	17556	9	21D
0005434446500	17556	10	22C
0005433186055	1572	1	1A
0005435517936	1572	2	1C
0005435508382	1572	3	1D
0005435508385	1572	4	1F
0005435517937	1572	5	2D
0005435517929	1572	6	2F
0005432291934	1572	7	3C
0005435508387	1572	8	3F
0005434565932	1572	9	4A
0005435508383	1572	10	4C
0005435508384	1572	11	4D
0005434565935	1572	12	4F
0005435502331	1572	13	5C
0005435502339	1572	14	5E
0005435502346	1572	15	5F
0005435517943	1572	16	6A
0005435502336	1572	17	6C
0005435502340	1572	18	6D
0005435517942	1572	19	6E
0005435502343	1572	20	6F
0005432291932	1572	21	7A
0005435502333	1572	22	7C
0005435502347	1572	23	7D
0005435502332	1572	24	7E
0005435502344	1572	25	7F
0005435502350	1572	26	8A
0005434565928	1572	27	8C
0005435502345	1572	28	8D
0005435517928	1572	29	8E
0005433186025	1572	30	8F
0005435508391	1572	31	9A
0005432291933	1572	32	9C
0005435517940	1572	33	9D
0005433186026	1572	34	9E
0005433186062	1572	35	10A
0005434565936	1572	36	10C
0005435517931	1572	37	10D
0005434565930	1572	38	10F
0005434565938	1572	39	11C
0005435508389	1572	40	11D
0005435502351	1572	41	11F
0005435502337	1572	42	12C
0005435517934	1572	43	12E
0005435517938	1572	44	13A
0005434565925	1572	45	13C
0005435508390	1572	46	13D
0005435517935	1572	47	13E
0005433186065	1572	48	13F
0005435502335	1572	49	14A
0005435508380	1572	50	14C
0005435508386	1572	51	14D
0005433186040	1572	52	14E
0005435502334	1572	53	14F
0005435502341	1572	54	15A
0005435517932	1572	55	15C
0005433186039	1572	56	15D
0005435517933	1572	57	15E
0005435517939	1572	58	15F
0005434565937	1572	59	16A
0005434565927	1572	60	16C
0005435502338	1572	61	16F
0005434565926	1572	62	17A
0005433186079	1572	63	17C
0005434565933	1572	64	17E
0005434565934	1572	65	18A
0005433186061	1572	66	18C
0005435517930	1572	67	18D
0005435517945	1572	68	18E
0005435508379	1572	69	18F
0005435502342	1572	70	19A
0005435502349	1572	71	19C
0005435508381	1572	72	19D
0005435517944	1572	73	19E
0005435502348	1572	74	19F
0005435517941	1572	75	20A
0005434565929	1572	76	20C
0005434565931	1572	77	20D
0005433186048	1572	78	20E
0005435508388	1572	79	20F
0005435545688	20874	1	1A
0005435529131	20874	2	1C
0005435502232	20874	3	1D
0005435529009	20874	4	1F
0005435502092	20874	5	2A
0005434565862	20874	6	2D
0005435529070	20874	7	2F
0005435545689	20874	8	3A
0005434565899	20874	9	3D
0005435529092	20874	10	3F
0005433186125	20874	11	4A
0005435545690	20874	12	4D
0005435545666	20874	13	4F
0005435529100	20874	14	5A
0005435545670	20874	15	5C
0005435502163	20874	16	5D
0005435529103	20874	17	5E
0005435529042	20874	18	5F
0005435502162	20874	19	6C
0005435528970	20874	20	6D
0005434565849	20874	21	6E
0005434565798	20874	22	6F
0005435502231	20874	23	7D
0005434565861	20874	24	7E
0005435502124	20874	25	7F
0005435529029	20874	26	8A
0005433186132	20874	27	8C
0005434565789	20874	28	8D
0005435502144	20874	29	8E
0005433186131	20874	30	8F
0005435502068	20874	31	9C
0005435545686	20874	32	9D
0005433186126	20874	33	9E
0005433186130	20874	34	9F
0005435502205	20874	35	10A
0005435529132	20874	36	10C
0005435529135	20874	37	10D
0005434565827	20874	38	10E
0005434565802	20874	39	10F
0005435545654	20874	40	11A
0005435545653	20874	41	11C
0005435545687	20874	42	11D
0005433186128	20874	43	11E
0005434565803	20874	44	11F
0005435529036	20874	45	12A
0005435529105	20874	46	12D
0005435545645	20874	47	12F
0005435502191	20874	48	13A
0005435529144	20874	49	13D
0005435529104	20874	50	13E
0005435529035	20874	51	14D
0005434565788	20874	52	14E
0005435529060	20874	53	14F
0005433186127	20874	54	15A
0005435502148	20874	55	15E
0005433186129	20874	56	15F
0005435529052	20874	57	16C
0005435545665	20874	58	16D
0005435502115	20874	59	16E
0005435502112	20874	60	16F
0005435502069	20874	61	17A
0005435502106	20874	62	17C
0005435545663	20874	63	17D
0005435545664	20874	64	17E
0005435545652	20874	65	17F
0005435502190	20874	66	18A
0005435529031	20874	67	18C
0005435529034	20874	68	18D
0005434565825	20874	69	19A
0005433186134	20874	70	19C
0005435529055	20874	71	19D
0005435502134	20874	72	19E
0005435502113	20874	73	19F
0005435529046	20874	74	20A
0005435529047	20874	75	20C
0005435529071	20874	76	20D
0005433186133	20874	77	20E
0005435153752	3906	1	1D
0005435153748	3906	2	2A
0005435153751	3906	3	4D
0005435153750	3906	4	5B
0005435931567	3906	5	6A
0005435153749	3906	6	6C
0005435931579	3906	7	21B
0005435153753	3906	8	21C
0005435931566	3906	9	21D
0005435153721	21866	1	1A
0005435153706	21866	2	3A
0005435153695	21866	3	3B
0005435153694	21866	4	3C
0005435153722	21866	5	3D
0005435153710	21866	6	4D
0005435931607	21866	7	5A
0005435153704	21866	8	5B
0005435153703	21866	9	5D
0005435153711	21866	10	6B
0005435931605	21866	11	7A
0005435153696	21866	12	18B
0005435153719	21866	13	18C
0005435931604	21866	14	19A
0005435153720	21866	15	20B
0005435153705	21866	16	20C
0005435153702	21866	17	21C
0005435931606	21866	18	23A
0005435225555	7215	1	1A
0005432628858	7215	2	2C
0005432628862	7215	3	3A
0005432628870	7215	4	5D
0005432628866	7215	5	6B
0005432628863	7215	6	6C
0005435225530	7215	7	7C
0005435225531	7215	8	7D
0005432628869	7215	9	18D
0005432628867	7215	10	19C
0005432628871	7215	11	19D
0005432628861	7215	12	20A
0005432628865	7215	13	20B
0005432628864	7215	14	21A
0005432628859	7215	15	21B
0005432628860	7215	16	21D
0005432628872	7215	17	22B
0005432628868	7215	18	22D
0005432628778	28133	1	1C
0005435225595	28133	2	1D
0005432628709	28133	3	2A
0005432628809	28133	4	2B
0005435225592	28133	5	2D
0005432628751	28133	6	3D
0005435225597	28133	7	4C
0005435225594	28133	8	5D
0005432628710	28133	9	6C
0005432628760	28133	10	18B
0005432628762	28133	11	19B
0005432628696	28133	12	19C
0005432628737	28133	13	19D
0005435225591	28133	14	20B
0005432628808	28133	15	20D
0005432628684	28133	16	21A
0005432628759	28133	17	21B
0005432628683	28133	18	21C
0005435225596	28133	19	21D
0005432628774	28133	20	22B
0005435225598	28133	21	22C
0005435225593	28133	22	22D
0005432628724	28133	23	23A
0005434267896	8749	1	1D
0005435960053	8749	2	2C
0005434267898	8749	3	4C
0005435960054	8749	4	4D
0005435960055	8749	5	7A
0005434267897	8749	6	18C
0005434267922	8749	7	19B
0005435960057	8749	8	19C
0005434267908	8749	9	19D
0005435960056	8749	10	20B
0005434267923	8749	11	22C
0005434267918	8749	12	22D
0005434267955	15256	1	5A
0005434267956	15256	2	7B
0005434267953	15256	3	21A
0005434267954	15256	4	21C
0005432873244	1203	1	1A
0005432677574	1203	2	1F
0005432693065	1203	3	1D
0005432675148	1203	4	2A
0005432693070	1203	5	2C
0005432873243	1203	6	3A
0005432675143	1203	7	4A
0005432693082	1203	8	5C
0005432693079	1203	9	5A
0005432693088	1203	10	6E
0005432693067	1203	11	6D
0005432693086	1203	12	7A
0005432873256	1203	13	7B
0005432693083	1203	14	7D
0005432693074	1203	15	7F
0005432693076	1203	16	8C
0005432677573	1203	17	8A
0005432693078	1203	18	8F
0005432675155	1203	19	9A
0005432873254	1203	20	9D
0005432675146	1203	21	9E
0005432675149	1203	22	10A
0005432693093	1203	23	10C
0005432675151	1203	24	10F
0005432693080	1203	25	11C
0005432693091	1203	26	11F
0005432675147	1203	27	11E
0005432677575	1203	28	12C
0005432693072	1203	29	13A
0005432675157	1203	30	13C
0005432693075	1203	31	13F
0005432675156	1203	32	14C
0005432693068	1203	33	14D
0005432693073	1203	34	14F
0005432675145	1203	35	15B
0005432693090	1203	36	15C
0005432693066	1203	37	15E
0005432675150	1203	38	16A
0005432693071	1203	39	16B
0005432675144	1203	40	16E
0005432677576	1203	41	16D
0005432873236	1203	42	17B
0005432693081	1203	43	17D
0005432873257	1203	44	17E
0005432675152	1203	45	18D
0005432693089	1203	46	18C
0005432693092	1203	47	18E
0005432693087	1203	48	18F
0005432693085	1203	49	19C
0005432693064	1203	50	19B
0005432677572	1203	51	19D
0005432693084	1203	52	20A
0005432693094	1203	53	19F
0005432675154	1203	54	19E
0005432693077	1203	55	20F
0005432693095	1203	56	21A
0005432693069	1203	57	21E
0005432675153	1203	58	21F
0005432675028	17477	1	1A
0005432677531	17477	2	2A
0005432873303	17477	3	2F
0005432674987	17477	4	2D
0005432675011	17477	5	2C
0005432675047	17477	6	3A
0005432692723	17477	7	3C
0005432692796	17477	8	4A
0005432675092	17477	9	3F
0005432677548	17477	10	4C
0005432674970	17477	11	4F
0005432674948	17477	12	5C
0005432873302	17477	13	6A
0005432675006	17477	14	6B
0005432692813	17477	15	6D
0005432675053	17477	16	7A
0005432692916	17477	17	7F
0005432675085	17477	18	8A
0005432674957	17477	19	8E
0005432692732	17477	20	8C
0005432675054	17477	21	9B
0005432692913	17477	22	9A
0005432675026	17477	23	9C
0005432873298	17477	24	9F
0005432675086	17477	25	10E
0005432675010	17477	26	10D
0005432675034	17477	27	10F
0005432674983	17477	28	11C
0005432692693	17477	29	11D
0005432692945	17477	30	11F
0005432692857	17477	31	12A
0005432873301	17477	32	12D
0005432675027	17477	33	12E
0005432675048	17477	34	13C
0005432692873	17477	35	13D
0005432675049	17477	36	13F
0005432692747	17477	37	14B
0005432692917	17477	38	14F
0005432692921	17477	39	15C
0005432692722	17477	40	16A
0005432675073	17477	41	15F
0005432675024	17477	42	16C
0005432692733	17477	43	16B
0005432873300	17477	44	16E
0005432677532	17477	45	17A
0005432674956	17477	46	16F
0005432674961	17477	47	17B
0005432675015	17477	48	17D
0005432692823	17477	49	17C
0005432692746	17477	50	17F
0005432674992	17477	51	17E
0005432873299	17477	52	18B
0005432692996	17477	53	18C
0005432674960	17477	54	18E
0005432675007	17477	55	18D
0005432692779	17477	56	19A
0005432692933	17477	57	19C
0005432692885	17477	58	19D
0005432873297	17477	59	20B
0005432692944	17477	60	20A
0005432677554	17477	61	20D
0005432692721	17477	62	21A
0005432675025	17477	63	21C
0005432692814	17477	64	21F
0005433156714	1116	1	1A
0005433156695	1116	2	2B
0005434435197	1116	3	2D
0005434435199	1116	4	3A
0005434435202	1116	5	3B
0005434435194	1116	6	3C
0005434435193	1116	7	4B
0005433156694	1116	8	4D
0005434435195	1116	9	5B
0005434435207	1116	10	5D
0005434435205	1116	11	6A
0005434435200	1116	12	6B
0005434435208	1116	13	6D
0005434435203	1116	14	7A
0005434435206	1116	15	7D
0005434435196	1116	16	18B
0005434435198	1116	17	19C
0005434435204	1116	18	20B
0005434435201	1116	19	21A
0005433156710	1116	20	22B
0005433156685	1116	21	23B
0005433156756	17289	1	1A
0005434435148	17289	2	1C
0005434435107	17289	3	2D
0005434435108	17289	4	3B
0005433156757	17289	5	3C
0005434435106	17289	6	4A
0005433156763	17289	7	4D
0005434435123	17289	8	5A
0005433156760	17289	9	5B
0005433156764	17289	10	6B
0005434435083	17289	11	6C
0005433156761	17289	12	7B
0005434435129	17289	13	7C
0005434435067	17289	14	18A
0005434435047	17289	15	18B
0005434435065	17289	16	18D
0005434435048	17289	17	19B
0005433156759	17289	18	19C
0005434435082	17289	19	19D
0005433156762	17289	20	20C
0005434435135	17289	21	20D
0005433156765	17289	22	21C
0005434435091	17289	23	21D
0005434435122	17289	24	22A
0005433156758	17289	25	23A
0005434435075	17289	26	23B
0005435086840	4065	1	1D
0005435928125	4065	2	2D
0005435928107	4065	3	4B
0005435928113	4065	4	4D
0005435086843	4065	5	5C
0005435086842	4065	6	6B
0005435086841	4065	7	6C
0005435086844	4065	8	18C
0005435086847	4065	9	20D
0005435086846	4065	10	21B
0005435086845	4065	11	22C
0005435086785	24415	1	2C
0005435086789	24415	2	2D
0005435086786	24415	3	3A
0005435928149	24415	4	5B
0005435928147	24415	5	5D
0005435928150	24415	6	6C
0005435086776	24415	7	6D
0005435928148	24415	8	7B
0005435086788	24415	9	18D
0005435086799	24415	10	19B
0005435928151	24415	11	21C
0005435086777	24415	12	21D
0005435086800	24415	13	22D
0005435086783	24415	14	23B
0005435706382	2453	1	1A
0005435706389	2453	2	1C
0005433373443	2453	3	1D
0005435706387	2453	4	1F
0005435706401	2453	5	2C
0005433373455	2453	6	2F
0005435706392	2453	7	3F
0005433373493	2453	8	4A
0005435706381	2453	9	4F
0005435706403	2453	10	5A
0005433373457	2453	11	5E
0005433373439	2453	12	6A
0005435706395	2453	13	6D
0005435706407	2453	14	7A
0005433373452	2453	15	7F
0005435706413	2453	16	8C
0005435706411	2453	17	8D
0005433373471	2453	18	8E
0005435706393	2453	19	9A
0005435706404	2453	20	9C
0005433373447	2453	21	9E
0005433373451	2453	22	9F
0005433373473	2453	23	10A
0005435706386	2453	24	10D
0005435706383	2453	25	11C
0005435706396	2453	26	11F
0005433373481	2453	27	12E
0005435706414	2453	28	12F
0005435706388	2453	29	13C
0005435706394	2453	30	13E
0005433373482	2453	31	13F
0005435706397	2453	32	14A
0005435706391	2453	33	14C
0005435706408	2453	34	14D
0005435706385	2453	35	14E
0005435706398	2453	36	14F
0005435706399	2453	37	15F
0005435706400	2453	38	16A
0005433373441	2453	39	16C
0005435706412	2453	40	16D
0005435706402	2453	41	16F
0005435706409	2453	42	17C
0005433373491	2453	43	17F
0005435706410	2453	44	18A
0005433373492	2453	45	18D
0005435706405	2453	46	18F
0005435706384	2453	47	19D
0005433373465	2453	48	19E
0005433373485	2453	49	19F
0005435706390	2453	50	20C
0005435706406	2453	51	20D
0005433373483	2453	52	20E
0005433373536	27024	1	1A
0005435706182	27024	2	1D
0005433373546	27024	3	3F
0005435706200	27024	4	4C
0005435706276	27024	5	4D
0005433373535	27024	6	4E
0005435706241	27024	7	4F
0005435706221	27024	8	5E
0005435706231	27024	9	6A
0005435706282	27024	10	6C
0005435706260	27024	11	6D
0005435706209	27024	12	6E
0005435706233	27024	13	6F
0005435706275	27024	14	7A
0005433373543	27024	15	7C
0005435706186	27024	16	8D
0005433373541	27024	17	8E
0005433373539	27024	18	8F
0005433373540	27024	19	9C
0005433373534	27024	20	9D
0005435706229	27024	21	10C
0005435706324	27024	22	10D
0005433373532	27024	23	10E
0005433373550	27024	24	10F
0005433373547	27024	25	11A
0005435706251	27024	26	11E
0005435706237	27024	27	12A
0005433373545	27024	28	12C
0005435706211	27024	29	12D
0005433373548	27024	30	13A
0005435706280	27024	31	13C
0005435706219	27024	32	13D
0005433373549	27024	33	13F
0005433373542	27024	34	14A
0005435706281	27024	35	14D
0005435706234	27024	36	15C
0005435706244	27024	37	15E
0005435706259	27024	38	15F
0005435706300	27024	39	16C
0005435706301	27024	40	16D
0005435706263	27024	41	16E
0005435706245	27024	42	16F
0005433373538	27024	43	17A
0005435706208	27024	44	17C
0005433373533	27024	45	17D
0005435706271	27024	46	17E
0005435706181	27024	47	18A
0005435706258	27024	48	18C
0005435706257	27024	49	18D
0005433373544	27024	50	18E
0005435706232	27024	51	19A
0005435706216	27024	52	19C
0005435706246	27024	53	19D
0005435706220	27024	54	19F
0005433373537	27024	55	20D
0005435706230	27024	56	20E
0005434964222	1310	1	2A
0005434964232	1310	2	2B
0005434964263	1310	3	2C
0005434964218	1310	4	3A
0005433261446	1310	5	2H
0005434964251	1310	6	3C
0005434964225	1310	7	3F
0005434964257	1310	8	4A
0005434964260	1310	9	4H
0005433261470	1310	10	9B
0005434964214	1310	11	9A
0005434964245	1310	12	9H
0005434964241	1310	13	11E
0005434964247	1310	14	11F
0005434964244	1310	15	12D
0005434964212	1310	16	12B
0005434964248	1310	17	13A
0005433261466	1310	18	13D
0005433261434	1310	19	14A
0005434964258	1310	20	14G
0005432279274	1310	21	15D
0005434964239	1310	22	15F
0005432279272	1310	23	15G
0005432279271	1310	24	16A
0005434964233	1310	25	16E
0005433261474	1310	26	16G
0005433261463	1310	27	16F
0005434964265	1310	28	17B
0005434964240	1310	29	17D
0005433261494	1310	30	17F
0005434964252	1310	31	17E
0005434964209	1310	32	17H
0005433261485	1310	33	18G
0005433261439	1310	34	19D
0005434964261	1310	35	19F
0005434964229	1310	36	20A
0005434964211	1310	37	20G
0005434964215	1310	38	21A
0005434964253	1310	39	21D
0005434964228	1310	40	21G
0005434964255	1310	41	22D
0005434964220	1310	42	22E
0005433261432	1310	43	22G
0005433261471	1310	44	22F
0005434964259	1310	45	23F
0005434964235	1310	46	24A
0005434964216	1310	47	23H
0005434964254	1310	48	24B
0005433261483	1310	49	24D
0005433261498	1310	50	24F
0005433261492	1310	51	24H
0005434964256	1310	52	25E
0005434964236	1310	53	25D
0005434964243	1310	54	27H
0005433261493	1310	55	28A
0005434964210	1310	56	28E
0005434964250	1310	57	28H
0005434964219	1310	58	28G
0005434964246	1310	59	29B
0005434964242	1310	60	29D
0005434964237	1310	61	29F
0005434964226	1310	62	30A
0005434964223	1310	63	30D
0005434964208	1310	64	30E
0005433261473	1310	65	31E
0005433261430	1310	66	31D
0005433261462	1310	67	31F
0005433261410	1310	68	31G
0005432279273	1310	69	32A
0005434964227	1310	70	31H
0005434964238	1310	71	32B
0005434964234	1310	72	32D
0005434964224	1310	73	32F
0005433261472	1310	74	32G
0005433261440	1310	75	33A
0005433261458	1310	76	33E
0005434964249	1310	77	33H
0005433261484	1310	78	34A
0005434964264	1310	79	34E
0005433261488	1310	80	34G
0005434964217	1310	81	35D
0005434964231	1310	82	35G
0005434964213	1310	83	35H
0005432279275	1310	84	36H
0005432279270	1310	85	37A
0005432279269	1310	86	37F
0005434964230	1310	87	37E
0005433261514	1310	88	37H
0005434964262	1310	89	38H
0005433261481	1310	90	38G
0005433261433	1310	91	39D
0005434964221	1310	92	39F
0005435907489	4815	1	3C
0005434625970	4815	2	4E
0005433194849	4815	3	6A
0005434625968	4815	4	7C
0005434625973	4815	5	8A
0005433194831	4815	6	9C
0005434625976	4815	7	10A
0005433194850	4815	8	12C
0005435907488	4815	9	12E
0005434625972	4815	10	15A
0005435907475	4815	11	15D
0005435907470	4815	12	16E
0005434625974	4815	13	17A
0005434625969	4815	14	17C
0005434625975	4815	15	18A
0005435907490	4815	16	18E
0005435907453	4815	17	19A
0005433194848	4815	18	19C
0005435907476	4815	19	19F
0005434625971	4815	20	20D
0005435907516	32931	1	4A
0005434625917	32931	2	6F
0005434625899	32931	3	7C
0005435907515	32931	4	9A
0005434625905	32931	5	9D
0005434625944	32931	6	11A
0005434625926	32931	7	13A
0005435907513	32931	8	15A
0005435907512	32931	9	15E
0005434625916	32931	10	16E
0005434625927	32931	11	17D
0005435907514	32931	12	17E
0005435785049	13804	1	1A
0005435785129	13804	2	1B
0005435785092	13804	3	1C
0005435787328	13804	4	2A
0005435785171	13804	5	1D
0005435784951	13804	6	2B
0005435785127	13804	7	2C
0005435785057	13804	8	3A
0005435785050	13804	9	3C
0005435785135	13804	10	4A
0005435785172	13804	11	4B
0005435785034	13804	12	4C
0005435785112	13804	13	4D
0005435785128	13804	14	5A
0005435785091	13804	15	5B
0005432195696	13804	16	5D
0005435785101	13804	17	6A
0005435785055	13804	18	6B
0005435785035	13804	19	6C
0005435785047	13804	20	6D
0005435785056	13804	21	7A
0005435784943	13804	22	7B
0005435784970	13804	23	7C
0005435785089	13804	24	7D
0005435784944	13804	25	18A
0005435784952	13804	26	18B
0005435785114	13804	27	18D
0005435785170	13804	28	19A
0005435784984	13804	29	19B
0005435785062	13804	30	19C
0005435785169	13804	31	19D
0005435785052	13804	32	20A
0005435784997	13804	33	20B
0005435785051	13804	34	20D
0005435785046	13804	35	21B
0005435937390	13804	36	21C
0005435787346	13804	37	22A
0005435784945	13804	38	22B
0005435784986	13804	39	22D
0005435785173	13804	40	23A
0005435785045	13804	41	23B
0005435785343	27431	1	1A
0005435937343	27431	2	1B
0005435785336	27431	3	1C
0005435785360	27431	4	2A
0005435785351	27431	5	2B
0005435937331	27431	6	2C
0005435937365	27431	7	2D
0005435937330	27431	8	3A
0005435937366	27431	9	3B
0005432190630	27431	10	3C
0005435785341	27431	11	4A
0005435785340	27431	12	4B
0005435785357	27431	13	4C
0005435785355	27431	14	4D
0005432190628	27431	15	5A
0005435785337	27431	16	5B
0005435785333	27431	17	5C
0005435785342	27431	18	5D
0005435785350	27431	19	6A
0005435785363	27431	20	6B
0005435785359	27431	21	6D
0005435785356	27431	22	6C
0005435785344	27431	23	7A
0005435785349	27431	24	7C
0005435785352	27431	25	7D
0005435787354	27431	26	18A
0005435785347	27431	27	18B
0005435785335	27431	28	18C
0005435785346	27431	29	18D
0005435785353	27431	30	19A
0005435785334	27431	31	19B
0005435785345	27431	32	19D
0005435785362	27431	33	20A
0005435785332	27431	34	20B
0005432190629	27431	35	20C
0005435937342	27431	36	20D
0005435785338	27431	37	21A
0005435785361	27431	38	21C
0005435785331	27431	39	21D
0005435785348	27431	40	22A
0005435785354	27431	41	22B
0005435785339	27431	42	22C
0005435785364	27431	43	22D
0005435785358	27431	44	23B
0005434407254	20255	1	1A
0005434407209	20255	2	1C
0005434407258	20255	3	1D
0005434407214	20255	4	1F
0005434407206	20255	5	2A
0005434407034	20255	6	2C
0005434407129	20255	7	2D
0005434407643	20255	8	2F
0005434406922	20255	9	3A
0005435311081	20255	10	3C
0005434407331	20255	11	3D
0005435311080	20255	12	4A
0005434407289	20255	13	4C
0005434407330	20255	14	4E
0005435311079	20255	15	4F
0005434407035	20255	16	5A
0005434407530	20255	17	5C
0005434407310	20255	18	5E
0005434407140	20255	19	6A
0005435311085	20255	20	6C
0005435311087	20255	21	6D
0005435311084	20255	22	6E
0005434407218	20255	23	6F
0005434407641	20255	24	7C
0005434407032	20255	25	7E
0005434407139	20255	26	7F
0005434407215	20255	27	8A
0005434407286	20255	28	8C
0005434407354	20255	29	8E
0005434407374	20255	30	8F
0005434407009	20255	31	9C
0005434407164	20255	32	9E
0005434407436	20255	33	9F
0005434407219	20255	34	10A
0005434407375	20255	35	10D
0005434407104	20255	36	10E
0005434407297	20255	37	10F
0005434407120	20255	38	11A
0005434407333	20255	39	11C
0005434407359	20255	40	11D
0005434407031	20255	41	11E
0005434407092	20255	42	11F
0005434407084	20255	43	12C
0005434407083	20255	44	12D
0005432058388	20255	45	12E
0005434407088	20255	46	13A
0005434407309	20255	47	13C
0005434407082	20255	48	13D
0005434407307	20255	49	13E
0005434407158	20255	50	13F
0005434407308	20255	51	14A
0005434407091	20255	52	14C
0005435311086	20255	53	14D
0005434406921	20255	54	14E
0005434407470	20255	55	14F
0005434407316	20255	56	15A
0005434407332	20255	57	15C
0005434407010	20255	58	15D
0005434407123	20255	59	15E
0005434407119	20255	60	15F
0005435311078	20255	61	16A
0005434407163	20255	62	16D
0005435311083	20255	63	16F
0005434407257	20255	64	17A
0005434407420	20255	65	17C
0005434407528	20255	66	17D
0005434407030	20255	67	17E
0005434407642	20255	68	17F
0005435311082	20255	69	18A
0005434407290	20255	70	18C
0005432058387	20255	71	18E
0005434407157	20255	72	19A
0005434407529	20255	73	19D
0005434407220	20255	74	19C
0005434407197	20255	75	19E
0005432058386	20255	76	19F
0005434407395	20255	77	20C
0005434407496	20255	78	20D
0005434407483	20255	79	20E
0005434407380	20255	80	20F
0005434407803	26980	1	1A
0005435310912	26980	2	1C
0005434407853	26980	3	1D
0005434407839	26980	4	1F
0005434407855	26980	5	2A
0005434407851	26980	6	2C
0005434407852	26980	7	2D
0005434407835	26980	8	2F
0005434407802	26980	9	3A
0005434407861	26980	10	3C
0005434407826	26980	11	3D
0005434407800	26980	12	3F
0005435310954	26980	13	4A
0005432153948	26980	14	4C
0005434407836	26980	15	4D
0005432153944	26980	16	4E
0005435310953	26980	17	4F
0005434407828	26980	18	5A
0005434407844	26980	19	5C
0005434407833	26980	20	5D
0005434407864	26980	21	5F
0005434407804	26980	22	6A
0005435310955	26980	23	6C
0005434407820	26980	24	6D
0005434407829	26980	25	6E
0005434407825	26980	26	6F
0005434407813	26980	27	7A
0005435310971	26980	28	7C
0005434407801	26980	29	7D
0005434407863	26980	30	7E
0005434407857	26980	31	7F
0005434407858	26980	32	8A
0005434407854	26980	33	8C
0005432153946	26980	34	8D
0005434407816	26980	35	8F
0005434407821	26980	36	9A
0005432153945	26980	37	9C
0005435310913	26980	38	9D
0005434407838	26980	39	9E
0005434407845	26980	40	9F
0005434407806	26980	41	10A
0005434407865	26980	42	10C
0005434407846	26980	43	10E
0005434407823	26980	44	10F
0005434407807	26980	45	11A
0005434407810	26980	46	11C
0005434407832	26980	47	11D
0005434407862	26980	48	11E
0005435310948	26980	49	11F
0005434407840	26980	50	12A
0005435310962	26980	51	12C
0005435310911	26980	52	12E
0005434407830	26980	53	12F
0005435310942	26980	54	13A
0005434407815	26980	55	13D
0005434407837	26980	56	13E
0005434407818	26980	57	13F
0005434407822	26980	58	14A
0005434407827	26980	59	14C
0005434407812	26980	60	14D
0005434407834	26980	61	14F
0005435310961	26980	62	15A
0005434407824	26980	63	15C
0005434407805	26980	64	15D
0005434407850	26980	65	15F
0005434407817	26980	66	16D
0005432153947	26980	67	16E
0005434407809	26980	68	16F
0005434407849	26980	69	17A
0005434407819	26980	70	17C
0005434407841	26980	71	17D
0005434407808	26980	72	17E
0005434407831	26980	73	17F
0005435310943	26980	74	18A
0005434407814	26980	75	18C
0005434407847	26980	76	18D
0005434407848	26980	77	18E
0005434407811	26980	78	18F
0005434407842	26980	79	19A
0005434407856	26980	80	19C
0005434407843	26980	81	19D
0005432153943	26980	82	19E
0005435310952	26980	83	19F
0005434407859	26980	84	20A
0005435310924	26980	85	20D
0005434407860	26980	86	20F
0005432109705	5708	1	1A
0005434319406	5708	2	1C
0005433123821	5708	3	1F
0005433123735	5708	4	2D
0005433123728	5708	5	3D
0005433123818	5708	6	3F
0005432109706	5708	7	4A
0005434319411	5708	8	4C
0005433123769	5708	9	4D
0005433123755	5708	10	5D
0005433123764	5708	11	6A
0005433123754	5708	12	7A
0005433123820	5708	13	7C
0005434319409	5708	14	8E
0005433123744	5708	15	9A
0005434311222	5708	16	9D
0005433123729	5708	17	9E
0005434319408	5708	18	9F
0005433123819	5708	19	10D
0005433123686	5708	20	10F
0005433123766	5708	21	11C
0005433123772	5708	22	13E
0005434319405	5708	23	13F
0005433123794	5708	24	14A
0005433123701	5708	25	14C
0005433123736	5708	26	14E
0005433123779	5708	27	14F
0005433123770	5708	28	15A
0005434311221	5708	29	15D
0005433123743	5708	30	16C
0005433123809	5708	31	16E
0005433123713	5708	32	16F
0005433123831	5708	33	17A
0005433123705	5708	34	17C
0005434319407	5708	35	17D
0005433123768	5708	36	17F
0005434319413	5708	37	18A
0005434319412	5708	38	19A
0005432109707	5708	39	19C
0005433123763	5708	40	19D
0005434319410	5708	41	19F
0005434319258	15666	1	1A
0005433123969	15666	2	1C
0005434319285	15666	3	1D
0005434319287	15666	4	1F
0005433123962	15666	5	2C
0005434319297	15666	6	2D
0005433123968	15666	7	2F
0005433123967	15666	8	3F
0005434319266	15666	9	4E
0005434319255	15666	10	5A
0005434319247	15666	11	5C
0005433123961	15666	12	5D
0005434319263	15666	13	5E
0005433123973	15666	14	6E
0005433123954	15666	15	8C
0005433123964	15666	16	8D
0005434319284	15666	17	8E
0005434319265	15666	18	8F
0005434319193	15666	19	9C
0005434319261	15666	20	9D
0005433123960	15666	21	10C
0005434312297	15666	22	10D
0005433123963	15666	23	10F
0005433123966	15666	24	11E
0005433123965	15666	25	11F
0005434319341	15666	26	12D
0005433123955	15666	27	12F
0005434319259	15666	28	13C
0005434319309	15666	29	13F
0005433123959	15666	30	14C
0005434319327	15666	31	14E
0005434319286	15666	32	15C
0005434319298	15666	33	16C
0005434319268	15666	34	16D
0005434319281	15666	35	16E
0005433123971	15666	36	17D
0005434319267	15666	37	18C
0005433123957	15666	38	18D
0005433123970	15666	39	18E
0005433123972	15666	40	19E
0005433123956	15666	41	20A
0005434319260	15666	42	20C
0005434319264	15666	43	20D
0005433123958	15666	44	20F
0005435220322	31753	1	1C
0005435219204	31753	2	1D
0005435220323	31753	3	3B
0005435219202	31753	4	18D
0005435220321	31753	5	19D
0005435220320	31753	6	21A
0005435219201	31753	7	21B
0005435219203	31753	8	22D
0005434189139	8983	1	3C
0005434484356	8983	2	3D
0005434484358	8983	3	4C
0005434189137	8983	4	6B
0005434484354	8983	5	7A
0005434484357	8983	6	18B
0005434484352	8983	7	18D
0005434484355	8983	8	19C
0005434189140	8983	9	20B
0005434189153	8983	10	20C
0005434189138	8983	11	21C
0005434189131	8983	12	21D
0005434484353	8983	13	22C
0005434189187	16612	1	2D
0005434484302	16612	2	4B
0005434484303	16612	3	5D
0005434484291	16612	4	6D
0005434484290	16612	5	7C
0005434189184	16612	6	7D
0005434484296	16612	7	19A
0005434189182	16612	8	19D
0005434189185	16612	9	21A
0005434189186	16612	10	22C
0005434189183	16612	11	22D
0005433123968	7709	1	1A
0005433123971	7709	2	1D
0005433123954	7709	3	2C
0005433123957	7709	4	3C
0005433123955	7709	5	3F
0005433722151	7709	6	4A
0005433123963	7709	7	4F
0005433123964	7709	8	5C
0005433722166	7709	9	6E
0005433123973	7709	10	7A
0005433123967	7709	11	8E
0005433722116	7709	12	9D
0005433123965	7709	13	11C
0005433722155	7709	14	11E
0005433123969	7709	15	12F
0005433123970	7709	16	13C
0005433722147	7709	17	13D
0005433722148	7709	18	13F
0005433123960	7709	19	14A
0005433123958	7709	20	14C
0005433123972	7709	21	14D
0005433722162	7709	22	14F
0005433123966	7709	23	15D
0005433123956	7709	24	16A
0005433123962	7709	25	16F
0005433722161	7709	26	17A
0005433123959	7709	27	17C
0005433722160	7709	28	17F
0005433722154	7709	29	18D
0005433123961	7709	30	20A
0005432693097	7710	1	1A
0005433449995	7710	2	1C
0005433450003	7710	3	1F
0005432693114	7710	4	2A
0005433449993	7710	5	2C
0005432720928	7710	6	2D
0005432693123	7710	7	2F
0005432720940	7710	8	3A
0005432720922	7710	9	3F
0005433449994	7710	10	4C
0005432720945	7710	11	4D
0005432720943	7710	12	4F
0005432693122	7710	13	5A
0005433449997	7710	14	5D
0005432720936	7710	15	5E
0005432693120	7710	16	5F
0005432693106	7710	17	6A
0005432693112	7710	18	6C
0005432693103	7710	19	6D
0005433450002	7710	20	6E
0005432693121	7710	21	6F
0005433450001	7710	22	7A
0005432693105	7710	23	7C
0005432720939	7710	24	7E
0005432693110	7710	25	7F
0005432720946	7710	26	8A
0005432693119	7710	27	8C
0005432720949	7710	28	8D
0005433449990	7710	29	8F
0005433449987	7710	30	9A
0005432693115	7710	31	9C
0005433449992	7710	32	9D
0005432693111	7710	33	9E
0005432720944	7710	34	9F
0005432720933	7710	35	10A
0005433450004	7710	36	10C
0005432720934	7710	37	10D
0005433449996	7710	38	10E
0005432693113	7710	39	10F
0005432720923	7710	40	11C
0005432071575	7710	41	11D
0005433450006	7710	42	11E
0005432693098	7710	43	11F
0005432693107	7710	44	12A
0005433449999	7710	45	12C
0005432693109	7710	46	12D
0005433450005	7710	47	12E
0005432720926	7710	48	12F
0005432720941	7710	49	13C
0005433449989	7710	50	13D
0005432693096	7710	51	13E
0005432693117	7710	52	13F
0005432720948	7710	53	14A
0005432720947	7710	54	14C
0005432693124	7710	55	14D
0005433449998	7710	56	14F
0005432693102	7710	57	15A
0005432693118	7710	58	15C
0005433450000	7710	59	15D
0005432720938	7710	60	15E
0005432720929	7710	61	16A
0005432720930	7710	62	15F
0005433449988	7710	63	16C
0005432720924	7710	64	16D
0005432720925	7710	65	16E
0005432693101	7710	66	16F
0005432693125	7710	67	17A
0005433450007	7710	68	17C
0005432720937	7710	69	17D
0005432693126	7710	70	17E
0005433449985	7710	71	17F
0005432693099	7710	72	18A
0005432071577	7710	73	18C
0005433449991	7710	74	18D
0005432720931	7710	75	18E
0005432693116	7710	76	18F
0005432693100	7710	77	19A
0005432071576	7710	78	19C
0005432720935	7710	79	19D
0005432693108	7710	80	19F
0005432693104	7710	81	20A
0005432720932	7710	82	20C
0005432720942	7710	83	20D
0005433449986	7710	84	20E
0005432720927	7710	85	20F
0005433449917	30296	1	1A
0005433449643	30296	2	1C
0005432692721	30296	3	1D
0005433449786	30296	4	2C
0005433449801	30296	5	2D
0005433449739	30296	6	2F
0005433449821	30296	7	3C
0005432692779	30296	8	3D
0005433449782	30296	9	3F
0005433449833	30296	10	4C
0005432692823	30296	11	4D
0005432692996	30296	12	4E
0005433449829	30296	13	4F
0005432692746	30296	14	5A
0005433449857	30296	15	5C
0005432692814	30296	16	6A
0005432692921	30296	17	6D
0005432692733	30296	18	6F
0005433449932	30296	19	7D
0005432692944	30296	20	7E
0005433449890	30296	21	7F
0005433449897	30296	22	8A
0005433449790	30296	23	8D
0005433449822	30296	24	8E
0005432692933	30296	25	8F
0005433449861	30296	26	9A
0005433449760	30296	27	9C
0005432692722	30296	28	9D
0005432692913	30296	29	9E
0005432692693	30296	30	9F
0005433449812	30296	31	10C
0005432692732	30296	32	10D
0005433449868	30296	33	11C
0005432692917	30296	34	11D
0005432692723	30296	35	11F
0005433449785	30296	36	12D
0005433449773	30296	37	12F
0005432692813	30296	38	13C
0005433449789	30296	39	13D
0005433449828	30296	40	13E
0005433449856	30296	41	14A
0005433449843	30296	42	14C
0005433449834	30296	43	14E
0005433449772	30296	44	15A
0005432692885	30296	45	15C
0005432692796	30296	46	16A
0005433449759	30296	47	16D
0005433449781	30296	48	16E
0005432692747	30296	49	16F
0005433449791	30296	50	17A
0005432692916	30296	51	17D
0005432692945	30296	52	17F
0005433449757	30296	53	17E
0005432692873	30296	54	18D
0005433449884	30296	55	18E
0005432692857	30296	56	18F
0005433449839	30296	57	19A
0005433449774	30296	58	19C
0005433449741	30296	59	19D
0005433449916	30296	60	20A
0005433449792	30296	61	20E
0005433123831	30295	1	1A
0005432720793	30295	2	1D
0005433123755	30295	3	2A
0005433123794	30295	4	2C
0005432720751	30295	5	2D
0005433123820	30295	6	2F
0005432720664	30295	7	3F
0005433123779	30295	8	4A
0005432720654	30295	9	4C
0005432720700	30295	10	4D
0005433123821	30295	11	4E
0005432720695	30295	12	4F
0005432720694	30295	13	5C
0005433123728	30295	14	5D
0005432720779	30295	15	5E
0005433123818	30295	16	5F
0005433123743	30295	17	6C
0005432720734	30295	18	6E
0005433123766	30295	19	6F
0005432720806	30295	20	7A
0005432720722	30295	21	7C
0005432720677	30295	22	7F
0005432720721	30295	23	8A
0005433123729	30295	24	8F
0005433123772	30295	25	9A
0005432720784	30295	26	9D
0005433123705	30295	27	9E
0005433123769	30295	28	10C
0005433123770	30295	29	10D
0005433123736	30295	30	10E
0005433722231	30295	31	11C
0005432720726	30295	32	11E
0005433123809	30295	33	12D
0005432720795	30295	34	13A
0005432720725	30295	35	13D
0005432720748	30295	36	13E
0005433123686	30295	37	14C
0005432720701	30295	38	14F
0005432720709	30295	39	15A
0005433123819	30295	40	15D
0005432720780	30295	41	15E
0005433123701	30295	42	15F
0005432720781	30295	43	16E
0005432720729	30295	44	16F
0005432720789	30295	45	17A
0005433722230	30295	46	17C
0005432720661	30295	47	17D
0005433123768	30295	48	17E
0005433123754	30295	49	18C
0005433123764	30295	50	18E
0005433123735	30295	51	19A
0005432720702	30295	52	19D
0005433123713	30295	53	19E
0005433123763	30295	54	20A
0005433123744	30295	55	20E
0005433525048	1407	1	1A
0005433192894	1407	2	1C
0005434586641	1407	3	1D
0005433192990	1407	4	1F
0005434586634	1407	5	2A
0005434586650	1407	6	2D
0005434586648	1407	7	2F
0005434586630	1407	8	3A
0005433525053	1407	9	3D
0005433192945	1407	10	3F
0005433525049	1407	11	4A
0005432968826	1407	12	4C
0005433192964	1407	13	4D
0005434586646	1407	14	4E
0005434513583	1407	15	4F
0005432927981	1407	16	5C
0005433724814	1407	17	5D
0005433525050	1407	18	5E
0005434586633	1407	19	6A
0005433192937	1407	20	6C
0005432968817	1407	21	6D
0005433192932	1407	22	6E
0005434514969	1407	23	6F
0005432927925	1407	24	7A
0005433192893	1407	25	7C
0005432968830	1407	26	7D
0005433525051	1407	27	7F
0005433192969	1407	28	8C
0005434586638	1407	29	8D
0005434586640	1407	30	9A
0005433525046	1407	31	9C
0005433192963	1407	32	9D
0005434586656	1407	33	9F
0005434586644	1407	34	10D
0005434586637	1407	35	10E
0005434514970	1407	36	11D
0005433525057	1407	37	11E
0005434586632	1407	38	12A
0005432968807	1407	39	12C
0005434586651	1407	40	12D
0005433525054	1407	41	12E
0005433724813	1407	42	13A
0005433192946	1407	43	13C
0005434586654	1407	44	13E
0005433525055	1407	45	13F
0005433724812	1407	46	14A
0005434586635	1407	47	14C
0005434586639	1407	48	14D
0005433192958	1407	49	15A
0005433525056	1407	50	15D
0005432968831	1407	51	15E
0005433525052	1407	52	15F
0005434586649	1407	53	16A
0005434586652	1407	54	16C
0005434586647	1407	55	16D
0005433192943	1407	56	16E
0005433192864	1407	57	16F
0005434514971	1407	58	17A
0005434586631	1407	59	17C
0005432968818	1407	60	17D
0005432271008	1407	61	17E
0005434513582	1407	62	17F
0005434586642	1407	63	18A
0005432927936	1407	64	18C
0005433193011	1407	65	18E
0005434586655	1407	66	18F
0005434586636	1407	67	19A
0005432968816	1407	68	19C
0005434586645	1407	69	19D
0005432271006	1407	70	19E
0005432271007	1407	71	19F
0005434586653	1407	72	20A
0005433525047	1407	73	20C
0005434586643	1407	74	20D
0005432271009	1407	75	20F
0005434586350	18506	1	1A
0005434586508	18506	2	1C
0005433193062	18506	3	1D
0005433724750	18506	4	2A
0005434586329	18506	5	2C
0005433724771	18506	6	2D
0005434586375	18506	7	2F
0005434586443	18506	8	3A
0005434586431	18506	9	3C
0005434586425	18506	10	3D
0005434586372	18506	11	4A
0005433524919	18506	12	4C
0005434586362	18506	13	4D
0005434586485	18506	14	4E
0005434586391	18506	15	4F
0005434586518	18506	16	5C
0005433193058	18506	17	5D
0005433524936	18506	18	5F
0005433724764	18506	19	6A
0005433724773	18506	20	6D
0005433724768	18506	21	6E
0005434586454	18506	22	7A
0005434586317	18506	23	7C
0005434514951	18506	24	7D
0005434586423	18506	25	7E
0005432927987	18506	26	7F
0005434586334	18506	27	8C
0005433524939	18506	28	8E
0005433524954	18506	29	8F
0005433193064	18506	30	9A
0005432968842	18506	31	9C
0005433524920	18506	32	9D
0005433524931	18506	33	9E
0005434586462	18506	34	10A
0005433193059	18506	35	10D
0005432968843	18506	36	10E
0005432927988	18506	37	10F
0005433524930	18506	38	11A
0005433193063	18506	39	11C
0005432927986	18506	40	11D
0005433724770	18506	41	11E
0005433193066	18506	42	12A
0005434586377	18506	43	12C
0005433193068	18506	44	12D
0005434586515	18506	45	12F
0005434586509	18506	46	12E
0005434586476	18506	47	13A
0005432927983	18506	48	13C
0005433524985	18506	49	13D
0005433724765	18506	50	13E
0005434586363	18506	51	13F
0005434586428	18506	52	14D
0005433193060	18506	53	14E
0005434586424	18506	54	15A
0005433524947	18506	55	15D
0005432927984	18506	56	15F
0005434586453	18506	57	16C
0005433193065	18506	58	16E
0005433724749	18506	59	16F
0005434586432	18506	60	17A
0005433524976	18506	61	17C
0005433193061	18506	62	17E
0005433193067	18506	63	17F
0005433524940	18506	64	18A
0005433724769	18506	65	18D
0005433193057	18506	66	18C
0005432927985	18506	67	18E
0005433724763	18506	68	18F
0005434586475	18506	69	19C
0005434586361	18506	70	19D
0005434586316	18506	71	19E
0005434586517	18506	72	19F
0005434586427	18506	73	20C
0005434514944	18506	74	20D
0005435304997	11427	1	1A
0005434344213	11427	2	1B
0005434344231	11427	3	1C
0005434344217	11427	4	1D
0005434344220	11427	5	2A
0005434344234	11427	6	2B
0005434344225	11427	7	2C
0005434142616	11427	8	2D
0005434344224	11427	9	3A
0005435302175	11427	10	3B
0005434344241	11427	11	3C
0005434142615	11427	12	3D
0005434344219	11427	13	4A
0005434344221	11427	14	4B
0005434344218	11427	15	4C
0005434142613	11427	16	4D
0005435302146	11427	17	5A
0005434344230	11427	18	5B
0005435302174	11427	19	5C
0005434344233	11427	20	5D
0005434344226	11427	21	6A
0005434142614	11427	22	6B
0005434344214	11427	23	6C
0005434344237	11427	24	6D
0005434344242	11427	25	7A
0005434344232	11427	26	7B
0005434344215	11427	27	7C
0005434344246	11427	28	7D
0005434344235	11427	29	18B
0005434344227	11427	30	18C
0005434142617	11427	31	18D
0005434344247	11427	32	19A
0005434344239	11427	33	19B
0005434344240	11427	34	19C
0005434344223	11427	35	19D
0005434344229	11427	36	20A
0005434344211	11427	37	20B
0005434344245	11427	38	20C
0005434344222	11427	39	20D
0005434344236	11427	40	21A
0005434344228	11427	41	21B
0005434344244	11427	42	21C
0005434344216	11427	43	21D
0005434344248	11427	44	22A
0005434344238	11427	45	22B
0005434344243	11427	46	22C
0005434344212	11427	47	22D
0005435302176	11427	48	23A
0005435302138	11427	49	23B
0005434343856	29768	1	1A
0005434343850	29768	2	1B
0005434344021	29768	3	1C
0005434343890	29768	4	1D
0005434343959	29768	5	2A
0005434344002	29768	6	2B
0005434344045	29768	7	2C
0005434344078	29768	8	2D
0005435304166	29768	9	3A
0005434343780	29768	10	3B
0005434343945	29768	11	3C
0005434343886	29768	12	3D
0005434343996	29768	13	4B
0005434344077	29768	14	4A
0005434343956	29768	15	4C
0005434343737	29768	16	4D
0005434344050	29768	17	5A
0005434343700	29768	18	5B
0005434343898	29768	19	5C
0005434142578	29768	20	5D
0005434343941	29768	21	6A
0005434343891	29768	22	6B
0005434343884	29768	23	6C
0005434344061	29768	24	6D
0005434343991	29768	25	7A
0005434343911	29768	26	7B
0005434343707	29768	27	7C
0005434343885	29768	28	7D
0005434343949	29768	29	18A
0005434344003	29768	30	18B
0005435304167	29768	31	18D
0005434343905	29768	32	18C
0005434344097	29768	33	19A
0005435304165	29768	34	19B
0005434344127	29768	35	19C
0005434343876	29768	36	19D
0005434343825	29768	37	20A
0005434343830	29768	38	20B
0005434343829	29768	39	20C
0005434142577	29768	40	20D
0005434343960	29768	41	21A
0005434344049	29768	42	21B
0005435304164	29768	43	21C
0005434344031	29768	44	21D
0005434343993	29768	45	22A
0005434343955	29768	46	22B
0005434343958	29768	47	22C
0005434343925	29768	48	22D
0005434343992	29768	49	23A
0005434343942	29768	50	23B
0005435824668	1260	1	2C
0005435824651	1260	2	1F
0005435824666	1260	3	3D
0005435824664	1260	4	4D
0005433415552	1260	5	4A
0005433415601	1260	6	4F
0005435824660	1260	7	5C
0005433415494	1260	8	6A
0005433415564	1260	9	6B
0005435824658	1260	10	6E
0005433415569	1260	11	6F
0005435824672	1260	12	7C
0005433415492	1260	13	7B
0005435824650	1260	14	7E
0005432284561	1260	15	7F
0005435824652	1260	16	8B
0005433415637	1260	17	8E
0005435824659	1260	18	8D
0005435824646	1260	19	9A
0005435824662	1260	20	9D
0005433415594	1260	21	9C
0005435824648	1260	22	10D
0005435824669	1260	23	11C
0005432284562	1260	24	11E
0005433415557	1260	25	12B
0005435824656	1260	26	13B
0005433415556	1260	27	13D
0005432284563	1260	28	14A
0005435824649	1260	29	14B
0005435824670	1260	30	14D
0005432284560	1260	31	14F
0005435824663	1260	32	14E
0005433415584	1260	33	15B
0005435824654	1260	34	15A
0005433415604	1260	35	15F
0005435824665	1260	36	15E
0005435824655	1260	37	16F
0005433415515	1260	38	17B
0005433415585	1260	39	17A
0005433415630	1260	40	17E
0005435824667	1260	41	18C
0005433415493	1260	42	19A
0005435824661	1260	43	18F
0005435824647	1260	44	19E
0005435824653	1260	45	20F
0005433415586	1260	46	21D
0005435824671	1260	47	21E
0005435824657	1260	48	21F
0005435824438	18024	1	1D
0005433415685	18024	2	2D
0005435824296	18024	3	2C
0005433415677	18024	4	3A
0005433415679	18024	5	3D
0005435824429	18024	6	3C
0005433415673	18024	7	4D
0005433415675	18024	8	4C
0005435824385	18024	9	5C
0005435824317	18024	10	5F
0005433415674	18024	11	6B
0005435824452	18024	12	6A
0005435824330	18024	13	6E
0005435824432	18024	14	7A
0005435824333	18024	15	6F
0005435824347	18024	16	7C
0005435824275	18024	17	7E
0005435824318	18024	18	8A
0005435824509	18024	19	8B
0005435824437	18024	20	8D
0005433415678	18024	21	8E
0005435824414	18024	22	9C
0005435824434	18024	23	9D
0005435824433	18024	24	10A
0005435824476	18024	25	9F
0005435824430	18024	26	10C
0005435824421	18024	27	10B
0005435824423	18024	28	10D
0005435824428	18024	29	10F
0005433415681	18024	30	12D
0005435824472	18024	31	13B
0005435824334	18024	32	13A
0005435824526	18024	33	12F
0005435824409	18024	34	13D
0005435824331	18024	35	13F
0005433415676	18024	36	14B
0005435824492	18024	37	14D
0005435824377	18024	38	15C
0005433415682	18024	39	15F
0005435824493	18024	40	16A
0005433415684	18024	41	16C
0005435824332	18024	42	16B
0005435824329	18024	43	16D
0005433415683	18024	44	17A
0005435824403	18024	45	18C
0005433415680	18024	46	18B
0005433415687	18024	47	18F
0005435824379	18024	48	19D
0005435824415	18024	49	19C
0005435824352	18024	50	19E
0005435824295	18024	51	20B
0005433415686	18024	52	20C
0005435824378	18024	53	20F
0005435824286	18024	54	21E
0005432143990	5648	1	1A
0005432143992	5648	2	1C
0005435242641	5648	3	1D
0005432783843	5648	4	1F
0005435476687	5648	5	2A
0005432783841	5648	6	2C
0005432783883	5648	7	2D
0005435242575	5648	8	2F
0005435242616	5648	9	3A
0005435242529	5648	10	3C
0005432783858	5648	11	3F
0005432783833	5648	12	4A
0005432783834	5648	13	4C
0005432783847	5648	14	4D
0005432783877	5648	15	4E
0005435242584	5648	16	4F
0005432783837	5648	17	5C
0005432783840	5648	18	5D
0005435242617	5648	19	5E
0005432783845	5648	20	5F
0005432783879	5648	21	6A
0005432783880	5648	22	6C
0005432783848	5648	23	6D
0005432783866	5648	24	6E
0005432783873	5648	25	6F
0005432783835	5648	26	7A
0005432783878	5648	27	7C
0005432783831	5648	28	7D
0005432783861	5648	29	7E
0005432783859	5648	30	7F
0005432783836	5648	31	8A
0005435476707	5648	32	8C
0005432783838	5648	33	8D
0005435476714	5648	34	8E
0005432783875	5648	35	8F
0005432783846	5648	36	9A
0005432783857	5648	37	9C
0005432783872	5648	38	9D
0005435242576	5648	39	9E
0005432783839	5648	40	9F
0005435476701	5648	41	10A
0005435242655	5648	42	10C
0005432783853	5648	43	10D
0005435476715	5648	44	10E
0005432783862	5648	45	10F
0005432783868	5648	46	11A
0005432783842	5648	47	11C
0005435476692	5648	48	11D
0005435242596	5648	49	11E
0005432783849	5648	50	12A
0005435242646	5648	51	12C
0005432783882	5648	52	12D
0005432783832	5648	53	12E
0005432783869	5648	54	12F
0005432783864	5648	55	13A
0005432783850	5648	56	13C
0005435242647	5648	57	13D
0005435242550	5648	58	13E
0005435242661	5648	59	13F
0005432783863	5648	60	14A
0005432783844	5648	61	14C
0005432783884	5648	62	14D
0005435242644	5648	63	14E
0005435242603	5648	64	14F
0005432783870	5648	65	15C
0005432783871	5648	66	15A
0005435476716	5648	67	15D
0005435242517	5648	68	15E
0005435476691	5648	69	15F
0005432783867	5648	70	16A
0005435242706	5648	71	16C
0005432783874	5648	72	16D
0005432783854	5648	73	16E
0005435242624	5648	74	16F
0005435476698	5648	75	17A
0005435242619	5648	76	17C
0005432783856	5648	77	17D
0005435242643	5648	78	17E
0005432783851	5648	79	17F
0005432783860	5648	80	18A
0005432783852	5648	81	18C
0005432143991	5648	82	18D
0005432783830	5648	83	18E
0005435476682	5648	84	18F
0005432783881	5648	85	19A
0005435242677	5648	86	19C
0005435242645	5648	87	19D
0005435242638	5648	88	19E
0005432783855	5648	89	19F
0005432783865	5648	90	20A
0005435242544	5648	91	20C
0005435242618	5648	92	20D
0005432783876	5648	93	20E
0005435242557	5648	94	20F
0005435476758	15344	1	1A
0005432783330	15344	2	1C
0005435242857	15344	3	1D
0005435476754	15344	4	1F
0005435242861	15344	5	2C
0005432783226	15344	6	2D
0005432783351	15344	7	2F
0005435476759	15344	8	3A
0005435242865	15344	9	3C
0005432783073	15344	10	3D
0005432783277	15344	11	3F
0005435476760	15344	12	4A
0005432783190	15344	13	4C
0005432783473	15344	14	4D
0005435242866	15344	15	4E
0005435242864	15344	16	4F
0005435476756	15344	17	5A
0005432783555	15344	18	5C
0005432783339	15344	19	5D
0005435242859	15344	20	5E
0005432783352	15344	21	5F
0005432783255	15344	22	6A
0005432783289	15344	23	6C
0005435242856	15344	24	6D
0005432783207	15344	25	6E
0005435242871	15344	26	7A
0005435476761	15344	27	7C
0005432782934	15344	28	7D
0005435242863	15344	29	7E
0005435242878	15344	30	7F
0005435476762	15344	31	8A
0005432783315	15344	32	8C
0005432783464	15344	33	8D
0005435242877	15344	34	8E
0005435476757	15344	35	8F
0005435242853	15344	36	9A
0005432783312	15344	37	9C
0005435242868	15344	38	9E
0005432783575	15344	39	10A
0005435242876	15344	40	10C
0005435242869	15344	41	10D
0005432783276	15344	42	10E
0005432783468	15344	43	10F
0005435242874	15344	44	11D
0005435476755	15344	45	11E
0005435242879	15344	46	11F
0005432783420	15344	47	12A
0005435242873	15344	48	12C
0005432783327	15344	49	12E
0005432783640	15344	50	12F
0005432783329	15344	51	13A
0005432783463	15344	52	13C
0005432783438	15344	53	13D
0005432783311	15344	54	13E
0005432783592	15344	55	13F
0005432783222	15344	56	14A
0005435242872	15344	57	14D
0005435242854	15344	58	14F
0005432783221	15344	59	15A
0005435242870	15344	60	15D
0005432783439	15344	61	15E
0005432783328	15344	62	15F
0005432783507	15344	63	16A
0005432783459	15344	64	16C
0005432783223	15344	65	16D
0005432783130	15344	66	16E
0005435242862	15344	67	16F
0005432783228	15344	68	17A
0005432783474	15344	69	17C
0005432783244	15344	70	17D
0005432783338	15344	71	18A
0005435242855	15344	72	18C
0005435242852	15344	73	18D
0005435242860	15344	74	18E
0005435242875	15344	75	18F
0005435242858	15344	76	19A
0005435242867	15344	77	19C
0005432783224	15344	78	19D
0005432783347	15344	79	19E
0005432783285	15344	80	19F
0005432783290	15344	81	20A
0005432783331	15344	82	20C
0005432783284	15344	83	20D
0005432848322	4354	1	1D
0005432848335	4354	2	2A
0005432848325	4354	3	2D
0005432848324	4354	4	3C
0005435850838	4354	5	3D
0005435850866	4354	6	4A
0005434463931	4354	7	4B
0005432848332	4354	8	4C
0005435850880	4354	9	5A
0005432848336	4354	10	5B
0005432848330	4354	11	5C
0005435850835	4354	12	5D
0005432848326	4354	13	6A
0005432848323	4354	14	6D
0005432848328	4354	15	7A
0005432848327	4354	16	7B
0005434463932	4354	17	7D
0005432848333	4354	18	18C
0005435850832	4354	19	18D
0005435850867	4354	20	19A
0005435850905	4354	21	19B
0005435850879	4354	22	19C
0005435850834	4354	23	20A
0005432848334	4354	24	20B
0005432848331	4354	25	20C
0005434463933	4354	26	21C
0005434462793	4354	27	22C
0005435850878	4354	28	22D
0005432848329	4354	29	23A
0005435850920	28857	1	1B
0005432848228	28857	2	1C
0005434461633	28857	3	1D
0005435850923	28857	4	2A
0005432848211	28857	5	2B
0005434463913	28857	6	2D
0005434461624	28857	7	3B
0005432848216	28857	8	3C
0005432848160	28857	9	3D
0005435850921	28857	10	4A
0005432848256	28857	11	4B
0005435850925	28857	12	4C
0005432848203	28857	13	4D
0005435850924	28857	14	5C
0005432848222	28857	15	5D
0005432848215	28857	16	6D
0005435850919	28857	17	7C
0005432848199	28857	18	7D
0005435850918	28857	19	18D
0005432848227	28857	20	19C
0005434463903	28857	21	19D
0005434461632	28857	22	20A
0005432848202	28857	23	20B
0005434463912	28857	24	20C
0005432848139	28857	25	20D
0005435850922	28857	26	21B
0005432848230	28857	27	21C
0005432848221	28857	28	21D
0005432848167	28857	29	22A
0005432848212	28857	30	22C
0005432848137	28857	31	22D
0005434461611	28857	32	23A
0005434463911	28857	33	23B
0005433496995	6343	1	7D
0005433497002	6343	2	1A
0005434925832	6343	3	1D
0005432075233	6343	4	1F
0005434443735	6343	5	2A
0005433497009	6343	6	2C
0005433497000	6343	7	2D
0005433497013	6343	8	2F
0005434925849	6343	9	3A
0005434443722	6343	10	3D
0005434443733	6343	11	3F
0005433496996	6343	12	4A
0005433497020	6343	13	4C
0005434925837	6343	14	4D
0005432075236	6343	15	4E
0005434443730	6343	16	4F
0005434443729	6343	17	5A
0005434443728	6343	18	5C
0005434443736	6343	19	5F
0005434925843	6343	20	6A
0005433497010	6343	21	6D
0005433496994	6343	22	6E
0005433497022	6343	23	6F
0005434925841	6343	24	7A
0005433497025	6343	25	7C
0005434925848	6343	26	8A
0005434925846	6343	27	8D
0005434925838	6343	28	8F
0005433497023	6343	29	9A
0005434925851	6343	30	9C
0005434925855	6343	31	9D
0005433496999	6343	32	9E
0005433497012	6343	33	9F
0005433497003	6343	34	10C
0005434925834	6343	35	10E
0005434925844	6343	36	10D
0005433497001	6343	37	10F
0005434443737	6343	38	11A
0005434925833	6343	39	11C
0005434925850	6343	40	11D
0005434925839	6343	41	11F
0005433496997	6343	42	12A
0005433497015	6343	43	12C
0005434443731	6343	44	12D
0005433497014	6343	45	12E
0005434925856	6343	46	12F
0005432075234	6343	47	13A
0005434925852	6343	48	13D
0005434925842	6343	49	13F
0005432075235	6343	50	14A
0005433497005	6343	51	14C
0005434443724	6343	52	14E
0005433497011	6343	53	15A
0005434443721	6343	54	15C
0005433497007	6343	55	15D
0005434925836	6343	56	15E
0005434925854	6343	57	15F
0005433497006	6343	58	16A
0005434443723	6343	59	16D
0005433497024	6343	60	16E
0005434443727	6343	61	16F
0005433496998	6343	62	17A
0005433497017	6343	63	17C
0005434443726	6343	64	17D
0005433497018	6343	65	17E
0005434925840	6343	66	17F
0005433497019	6343	67	18A
0005434443725	6343	68	18C
0005433497004	6343	69	18E
0005433497016	6343	70	18F
0005434925835	6343	71	19A
0005434443732	6343	72	19D
0005433497008	6343	73	19E
0005434925847	6343	74	19F
0005434925845	6343	75	20A
0005433497021	6343	76	20C
0005434443734	6343	77	20E
0005434925853	6343	78	20F
0005434925662	20416	1	1A
0005434925635	20416	2	1C
0005433496515	20416	3	1D
0005433496693	20416	4	1F
0005433496740	20416	5	2A
0005434925577	20416	6	2C
0005434925745	20416	7	2D
0005434443615	20416	8	2F
0005433496814	20416	9	3D
0005434443516	20416	10	3F
0005434925417	20416	11	4C
0005434925401	20416	12	4D
0005434925553	20416	13	4E
0005434925524	20416	14	5E
0005434925636	20416	15	5F
0005433496516	20416	16	6A
0005434925510	20416	17	6C
0005433496923	20416	18	6D
0005433496694	20416	19	6E
0005434443590	20416	20	6F
0005434925469	20416	21	7C
0005434925692	20416	22	7D
0005434443515	20416	23	7F
0005433496696	20416	24	8A
0005434925420	20416	25	8C
0005434925492	20416	26	8D
0005433496615	20416	27	8E
0005433496695	20416	28	8F
0005434443498	20416	29	9D
0005433496862	20416	30	9E
0005433496616	20416	31	9F
0005433496614	20416	32	10A
0005434925649	20416	33	10E
0005434925419	20416	34	10F
0005434925512	20416	35	11A
0005433496863	20416	36	11C
0005434443614	20416	37	11D
0005433496860	20416	38	11E
0005433496692	20416	39	12A
0005433496702	20416	40	12D
0005433496772	20416	41	12F
0005433496665	20416	42	13A
0005434925648	20416	43	13C
0005434925464	20416	44	13D
0005434925422	20416	45	13E
0005433496861	20416	46	13F
0005433496809	20416	47	14A
0005434925502	20416	48	14C
0005434925674	20416	49	14D
0005433496815	20416	50	14E
0005433496650	20416	51	15A
0005433496617	20416	52	15C
0005433496773	20416	53	15D
0005434443571	20416	54	15E
0005433496717	20416	55	15F
0005433496924	20416	56	16A
0005433496698	20416	57	16D
0005433496858	20416	58	16E
0005434925663	20416	59	16F
0005434925481	20416	60	17D
0005434925673	20416	61	17E
0005433496683	20416	62	17F
0005434925400	20416	63	18A
0005434443639	20416	64	18C
0005433496672	20416	65	18D
0005434443570	20416	66	18E
0005434925573	20416	67	18F
0005433496708	20416	68	19A
0005434925463	20416	69	19C
0005434925661	20416	70	19D
0005434925572	20416	71	19E
0005434443579	20416	72	19F
0005433496843	20416	73	20A
0005434925441	20416	74	20C
0005433496684	20416	75	20E
0005434925456	20416	76	20F
0005432783460	12165	1	1A
0005432783397	12165	2	1C
0005432783536	12165	3	1D
0005435242882	12165	4	1F
0005435242902	12165	5	2A
0005432783361	12165	6	2C
0005432783062	12165	7	2D
0005432783376	12165	8	2F
0005432783428	12165	9	3A
0005435242894	12165	10	3C
0005432783271	12165	11	3D
0005432783461	12165	12	3F
0005432783227	12165	13	4A
0005432783401	12165	14	4C
0005432783635	12165	15	4D
0005432783362	12165	16	5A
0005432783574	12165	17	5C
0005432783646	12165	18	5D
0005435242899	12165	19	5E
0005432783407	12165	20	5F
0005432783059	12165	21	6C
0005432783374	12165	22	6D
0005432783142	12165	23	6E
0005435242881	12165	24	6F
0005432783537	12165	25	7A
0005432783373	12165	26	7C
0005432783232	12165	27	7D
0005435242887	12165	28	7E
0005435242884	12165	29	7F
0005432783126	12165	30	8A
0005432783314	12165	31	8C
0005435242880	12165	32	8D
0005432783472	12165	33	8E
0005432783356	12165	34	8F
0005432783296	12165	35	9A
0005432783584	12165	36	9C
0005432783550	12165	37	9D
0005432783410	12165	38	9E
0005432783415	12165	39	10A
0005432783411	12165	40	10C
0005432783136	12165	41	11A
0005435242892	12165	42	11C
0005435242905	12165	43	11E
0005432783182	12165	44	11F
0005432783231	12165	45	12A
0005432783442	12165	46	12C
0005435242898	12165	47	12D
0005432783141	12165	48	12E
0005432783214	12165	49	12F
0005432783063	12165	50	13A
0005432783534	12165	51	13C
0005435242895	12165	52	13D
0005432783137	12165	53	13E
0005432783485	12165	54	13F
0005435242889	12165	55	14A
0005432783535	12165	56	14C
0005435242897	12165	57	14D
0005435242904	12165	58	14E
0005432783370	12165	59	14F
0005435242886	12165	60	15A
0005435242890	12165	61	15C
0005435242900	12165	62	15D
0005435242896	12165	63	15E
0005432783630	12165	64	15F
0005432783306	12165	65	16A
0005432783545	12165	66	16C
0005435242883	12165	67	16E
0005432783269	12165	68	16F
0005432783467	12165	69	17A
0005432783391	12165	70	17D
0005435242906	12165	71	17E
0005432783486	12165	72	17F
0005432783629	12165	73	18A
0005432783217	12165	74	18C
0005435242903	12165	75	18D
0005435242885	12165	76	18E
0005432783365	12165	77	18F
0005432783135	12165	78	19A
0005432783498	12165	79	19C
0005432783471	12165	80	19D
0005435242907	12165	81	19E
0005435242891	12165	82	19F
0005432783392	12165	83	20C
0005432783573	12165	84	20A
0005435242901	12165	85	20D
0005435242893	12165	86	20E
0005435242888	12165	87	20F
0005432783823	15424	1	1A
0005435242545	15424	2	1C
0005432783818	15424	3	1D
0005432783793	15424	4	1F
0005432783781	15424	5	2A
0005435242606	15424	6	2C
0005435242679	15424	7	2D
0005435242678	15424	8	2F
0005435242628	15424	9	3A
0005432783813	15424	10	3C
0005435242577	15424	11	3D
0005435242623	15424	12	3F
0005432783785	15424	13	4A
0005432783792	15424	14	4C
0005435242666	15424	15	4D
0005435242533	15424	16	4E
0005435242559	15424	17	4F
0005432783802	15424	18	5A
0005432783784	15424	19	5C
0005435242698	15424	20	5D
0005432783816	15424	21	5E
0005432783797	15424	22	5F
0005435242634	15424	23	6A
0005432783786	15424	24	6C
0005435242546	15424	25	6D
0005432783817	15424	26	6E
0005432783829	15424	27	6F
0005432783800	15424	28	7A
0005435242633	15424	29	7C
0005432783811	15424	30	7E
0005435242727	15424	31	7F
0005432783819	15424	32	8A
0005432783827	15424	33	8C
0005432783782	15424	34	8E
0005432783776	15424	35	8F
0005432783806	15424	36	9A
0005432783828	15424	37	9C
0005435242620	15424	38	9D
0005432783789	15424	39	9E
0005435242649	15424	40	9F
0005435242600	15424	41	10A
0005432783812	15424	42	10C
0005435242573	15424	43	10D
0005435242581	15424	44	10E
0005432783808	15424	45	10F
0005432783824	15424	46	11A
0005432783794	15424	47	11D
0005432783826	15424	48	11E
0005435242591	15424	49	11F
0005432783783	15424	50	12A
0005432783801	15424	51	12C
0005432783780	15424	52	12D
0005432783791	15424	53	13A
0005435242595	15424	54	13C
0005435242594	15424	55	13D
0005432783798	15424	56	13F
0005432783820	15424	57	14A
0005432783777	15424	58	14C
0005432783807	15424	59	14D
0005432783787	15424	60	14E
0005435242599	15424	61	14F
0005432783815	15424	62	15A
0005432783825	15424	63	15C
0005432783799	15424	64	15D
0005435242505	15424	65	15E
0005432783803	15424	66	15F
0005435242653	15424	67	16A
0005432783805	15424	68	16C
0005432783821	15424	69	16D
0005432783814	15424	70	16E
0005432783810	15424	71	16F
0005432783788	15424	72	17A
0005432783779	15424	73	17C
0005435242626	15424	74	17E
0005432783822	15424	75	17F
0005435242508	15424	76	18A
0005432783804	15424	77	18C
0005435242672	15424	78	18D
0005432783795	15424	79	18E
0005435242648	15424	80	18F
0005432783790	15424	81	19A
0005435242509	15424	82	19C
0005432783809	15424	83	19D
0005435242598	15424	84	19E
0005435242534	15424	85	19F
0005435242654	15424	86	20A
0005432783778	15424	87	20C
0005435242697	15424	88	20D
0005432783796	15424	89	20E
0005435242580	15424	90	20F
0005434877636	10064	1	1C
0005434877691	10064	2	1A
0005434877480	10064	3	1F
0005434877586	10064	4	2A
0005434877337	10064	5	2D
0005434877560	10064	6	3A
0005434877318	10064	7	2F
0005434877344	10064	8	3D
0005434877476	10064	9	3C
0005434877718	10064	10	4A
0005434877357	10064	11	3F
0005434877471	10064	12	4D
0005434877531	10064	13	4C
0005434877144	10064	14	4F
0005434877470	10064	15	5C
0005434877682	10064	16	5A
0005434877231	10064	17	5D
0005434877204	10064	18	6A
0005434877656	10064	19	6C
0005434877257	10064	20	6B
0005434877764	10064	21	6E
0005434877706	10064	22	6D
0005434877402	10064	23	7A
0005435913938	10064	24	6F
0005434877423	10064	25	7C
0005434877555	10064	26	7B
0005434877692	10064	27	7E
0005434877689	10064	28	7D
0005434877529	10064	29	7F
0005434877250	10064	30	8C
0005434877258	10064	31	8B
0005434877485	10064	32	8F
0005434877369	10064	33	9B
0005434877547	10064	34	9A
0005434877565	10064	35	9E
0005434877643	10064	36	10A
0005434877345	10064	37	9F
0005434877336	10064	38	10C
0005434877410	10064	39	10B
0005434877141	10064	40	10E
0005434758874	10064	41	10D
0005434877487	10064	42	10F
0005434877585	10064	43	11B
0005434877370	10064	44	11A
0005434877364	10064	45	11D
0005434758862	10064	46	11F
0005435913939	10064	47	11E
0005434877319	10064	48	12A
0005434877317	10064	49	12D
0005434877532	10064	50	12C
0005434877827	10064	51	12B
0005434758863	10064	52	12F
0005435913937	10064	53	12E
0005434877637	10064	54	13A
0005434877569	10064	55	13B
0005434877251	10064	56	14A
0005434877726	10064	57	13F
0005434877592	10064	58	14C
0005434877205	10064	59	14B
0005434910114	10064	60	14D
0005434877069	10064	61	14F
0005434877633	10064	62	15B
0005434877422	10064	63	15E
0005434758880	10064	64	15D
0005434877690	10064	65	15F
0005434758872	10064	66	16C
0005434876852	10064	67	16B
0005434876851	10064	68	16E
0005434877102	10064	69	16F
0005434877722	10064	70	17B
0005434878090	10064	71	17A
0005434877489	10064	72	17D
0005434877503	10064	73	17C
0005434877433	10064	74	17E
0005434877681	10064	75	17F
0005434877507	10064	76	18C
0005434877203	10064	77	18E
0005434877240	10064	78	18D
0005434877466	10064	79	19A
0005434877528	10064	80	19C
0005434877407	10064	81	19B
0005434877448	10064	82	20A
0005434877358	10064	83	19F
0005434877514	10064	84	19E
0005434877568	10064	85	20B
0005434877241	10064	86	20C
0005434878057	10064	87	20F
0005434877441	10064	88	20E
0005434877173	10064	89	20D
0005434877259	10064	90	21A
0005434877685	10064	91	21C
0005434877727	10064	92	21B
0005434877199	10064	93	21E
0005434877481	10064	94	21D
0005434758877	10064	95	21F
0005434878322	14607	1	1A
0005434878363	14607	2	1F
0005434878341	14607	3	1D
0005434878354	14607	4	1C
0005435913881	14607	5	2A
0005434878304	14607	6	2D
0005434878327	14607	7	2C
0005434758898	14607	8	3A
0005434878382	14607	9	2F
0005434878302	14607	10	3D
0005434878359	14607	11	3C
0005434878321	14607	12	4A
0005434878352	14607	13	4F
0005434878378	14607	14	4D
0005434878318	14607	15	5C
0005434878373	14607	16	5A
0005434878335	14607	17	5F
0005434878301	14607	18	6B
0005434878329	14607	19	6A
0005434878344	14607	20	6C
0005434878336	14607	21	6F
0005434878343	14607	22	6E
0005434878368	14607	23	6D
0005434878366	14607	24	7A
0005434878361	14607	25	7C
0005434878351	14607	26	7B
0005434878383	14607	27	7D
0005434878334	14607	28	8A
0005434878331	14607	29	7F
0005434878338	14607	30	7E
0005434878367	14607	31	8B
0005434878333	14607	32	8D
0005434878349	14607	33	8F
0005435913886	14607	34	8E
0005434878308	14607	35	9B
0005434878314	14607	36	9A
0005434878305	14607	37	9D
0005434878388	14607	38	9C
0005434878369	14607	39	10C
0005434878387	14607	40	10B
0005434910088	14607	41	10E
0005435913888	14607	42	10D
0005434878386	14607	43	11A
0005434878375	14607	44	10F
0005434878362	14607	45	11D
0005434878347	14607	46	11C
0005434878340	14607	47	11F
0005434878325	14607	48	11E
0005434878330	14607	49	12B
0005435913880	14607	50	12A
0005434878360	14607	51	12C
0005434878374	14607	52	12E
0005434878311	14607	53	12D
0005435913872	14607	54	13A
0005434878310	14607	55	12F
0005434878339	14607	56	13C
0005434878320	14607	57	13B
0005434878376	14607	58	13D
0005434878319	14607	59	14B
0005434878299	14607	60	14A
0005434878300	14607	61	14D
0005434878345	14607	62	14C
0005434878379	14607	63	14F
0005434878309	14607	64	14E
0005434878356	14607	65	15B
0005434878328	14607	66	15C
0005434878372	14607	67	15F
0005434758896	14607	68	15E
0005435913887	14607	69	15D
0005434878337	14607	70	16A
0005434758895	14607	71	16C
0005434878365	14607	72	16B
0005434878384	14607	73	16E
0005434878346	14607	74	16D
0005434878317	14607	75	17A
0005434878312	14607	76	16F
0005434878385	14607	77	17B
0005434878353	14607	78	17D
0005434878313	14607	79	17C
0005434878355	14607	80	17F
0005434878357	14607	81	17E
0005434878315	14607	82	18A
0005434878324	14607	83	18D
0005434878380	14607	84	18C
0005434878371	14607	85	18B
0005434878326	14607	86	18E
0005434878307	14607	87	19C
0005434878381	14607	88	19B
0005434878316	14607	89	19E
0005434878377	14607	90	19D
0005434878342	14607	91	19F
0005434878332	14607	92	20C
0005434878323	14607	93	20B
0005434878364	14607	94	20A
0005434878303	14607	95	20D
0005434878306	14607	96	21B
0005434878389	14607	97	21A
0005434878358	14607	98	20F
0005434878350	14607	99	21C
0005434878370	14607	100	21E
0005434878348	14607	101	21D
0005434758897	14607	102	21F
0005434251930	9230	1	1C
0005435660145	9230	2	1D
0005434251931	9230	3	4C
0005434251894	9230	4	4D
0005435660150	9230	5	5C
0005435660147	9230	6	6B
0005435660151	9230	7	6C
0005434251895	9230	8	7A
0005434251892	9230	9	7C
0005434251887	9230	10	7D
0005435660149	9230	11	18B
0005435660146	9230	12	18D
0005435660152	9230	13	19B
0005434251867	9230	14	19D
0005435660154	9230	15	21A
0005435660148	9230	16	21B
0005434251904	9230	17	22A
0005435660155	9230	18	22C
0005434251868	9230	19	22D
0005435660153	9230	20	23A
0005435659998	24639	1	1B
0005435660081	24639	2	1D
0005434251970	24639	3	2A
0005435660082	24639	4	2B
0005435660074	24639	5	2D
0005434251972	24639	6	3A
0005435660038	24639	7	3B
0005435660018	24639	8	3C
0005434251979	24639	9	4A
0005434251973	24639	10	4B
0005435660075	24639	11	5B
0005435660087	24639	12	5C
0005434251977	24639	13	6B
0005435659997	24639	14	6C
0005435660079	24639	15	7B
0005435660017	24639	16	7C
0005434251971	24639	17	7D
0005435660040	24639	18	18B
0005435660060	24639	19	19B
0005435660080	24639	20	19C
0005435660072	24639	21	20B
0005434251974	24639	22	20A
0005435660073	24639	23	21D
0005434251978	24639	24	22A
0005435660071	24639	25	22B
0005434251976	24639	26	22D
0005435660039	24639	27	23B
0005434251975	24639	28	23A
0005433680599	2816	1	1A
0005433680594	2816	2	1C
0005433680610	2816	3	1F
0005432222789	2816	4	2A
0005432966756	2816	5	2C
0005433680628	2816	6	2D
0005433680607	2816	7	2F
0005433680624	2816	8	3A
0005433680620	2816	9	3C
0005433680618	2816	10	3D
0005432966689	2816	11	3F
0005432222787	2816	12	4A
0005433680611	2816	13	4C
0005433680612	2816	14	4D
0005433680633	2816	15	4F
0005433680621	2816	16	5A
0005433680602	2816	17	5C
0005433680631	2816	18	5D
0005433680609	2816	19	5E
0005433680622	2816	20	6C
0005433680632	2816	21	6D
0005432966717	2816	22	6E
0005432966722	2816	23	7A
0005433680608	2816	24	7C
0005432966804	2816	25	7E
0005433680604	2816	26	7F
0005432966754	2816	27	8C
0005433680596	2816	28	8D
0005433680605	2816	29	8E
0005433680626	2816	30	9A
0005433680606	2816	31	9C
0005433680591	2816	32	9E
0005432966757	2816	33	9F
0005432222788	2816	34	10A
0005432966779	2816	35	10C
0005433680619	2816	36	10D
0005432966690	2816	37	10E
0005433680595	2816	38	10F
0005432222786	2816	39	11A
0005433680593	2816	40	11C
0005433680635	2816	41	11D
0005432966800	2816	42	12A
0005433680627	2816	43	12C
0005432966714	2816	44	12D
0005432966688	2816	45	12E
0005433680597	2816	46	12F
0005432966713	2816	47	13A
0005433680625	2816	48	13C
0005433680636	2816	49	13D
0005433680592	2816	50	13E
0005433680598	2816	51	14A
0005432966733	2816	52	14C
0005432966738	2816	53	14D
0005433680630	2816	54	14E
0005433680603	2816	55	14F
0005432966715	2816	56	15A
0005433680617	2816	57	15C
0005432966799	2816	58	15D
0005433680589	2816	59	15E
0005433680616	2816	60	15F
0005433680613	2816	61	16D
0005432966615	2816	62	16F
0005432966827	2816	63	17A
0005432966739	2816	64	17C
0005433680590	2816	65	17D
0005433680615	2816	66	17E
0005433680623	2816	67	18A
0005432966718	2816	68	18C
0005432966755	2816	69	18D
0005433680614	2816	70	18F
0005433684421	2816	71	19A
0005433680629	2816	72	19C
0005432966743	2816	73	19D
0005433680601	2816	74	20A
0005433680600	2816	75	20C
0005433680634	2816	76	20D
0005432966616	2816	77	20E
0005432966780	2816	78	20F
0005433680390	29162	1	1A
0005433680263	29162	2	1C
0005432966958	29162	3	1D
0005433680373	29162	4	1F
0005432966957	29162	5	2D
0005432966959	29162	6	2F
0005433680267	29162	7	3C
0005433680189	29162	8	3D
0005433680385	29162	9	3F
0005433680487	29162	10	4A
0005433680374	29162	11	4C
0005433680376	29162	12	4D
0005433680216	29162	13	4E
0005433680206	29162	14	4F
0005433680325	29162	15	5C
0005432966954	29162	16	5D
0005433680048	29162	17	5E
0005432966974	29162	18	5F
0005432966966	29162	19	6A
0005433679939	29162	20	6D
0005433680296	29162	21	6E
0005432966973	29162	22	6F
0005432966952	29162	23	7A
0005432966970	29162	24	7D
0005433680326	29162	25	7E
0005432966965	29162	26	7F
0005432966960	29162	27	8A
0005432005217	29162	28	8C
0005433687679	29162	29	8D
0005433680140	29162	30	8E
0005433684402	29162	31	8F
0005432005215	29162	32	9A
0005433680338	29162	33	9C
0005433680340	29162	34	9D
0005432966967	29162	35	9F
0005432966953	29162	36	10A
0005432966968	29162	37	10C
0005433680188	29162	38	10D
0005433680141	29162	39	10E
0005432966963	29162	40	10F
0005433684401	29162	41	11A
0005432005216	29162	42	11D
0005433684399	29162	43	12C
0005433680264	29162	44	12D
0005433687678	29162	45	12E
0005433680065	29162	46	12F
0005433684396	29162	47	13A
0005432966961	29162	48	13C
0005433680339	29162	49	13D
0005432966950	29162	50	13E
0005432966949	29162	51	13F
0005433679986	29162	52	14A
0005433680209	29162	53	14C
0005432966972	29162	54	14D
0005433680183	29162	55	14F
0005433680300	29162	56	15A
0005433680173	29162	57	15C
0005433680244	29162	58	15D
0005433680406	29162	59	15F
0005433680257	29162	60	16A
0005433680230	29162	61	16C
0005433679769	29162	62	16D
0005432966975	29162	63	16E
0005432966956	29162	64	16F
0005432966951	29162	65	17A
0005433680176	29162	66	17C
0005433680269	29162	67	17D
0005433680215	29162	68	17F
0005433680154	29162	69	18A
0005433680386	29162	70	18C
0005433684395	29162	71	18D
0005432966971	29162	72	18E
0005432966964	29162	73	18F
0005433680155	29162	74	19A
0005433680469	29162	75	19D
0005432966969	29162	76	19F
0005433680375	29162	77	20A
0005433680103	29162	78	20D
0005432966955	29162	79	20E
0005432966962	29162	80	20F
0005433614696	9303	1	1A
0005433577814	9303	2	1C
0005433577820	9303	3	1D
0005434163560	9303	4	2A
0005433633833	9303	5	2C
0005433614670	9303	6	2F
0005433633834	9303	7	3C
0005433614682	9303	8	3F
0005433633818	9303	9	3D
0005433614690	9303	10	4A
0005433614721	9303	11	4C
0005433633832	9303	12	4F
0005433614720	9303	13	4D
0005433633817	9303	14	5A
0005434152776	9303	15	5D
0005433633820	9303	16	5C
0005434152778	9303	17	5F
0005433577816	9303	18	6A
0005433614729	9303	19	6C
0005433614725	9303	20	6F
0005433633830	9303	21	6D
0005433614715	9303	22	7A
0005433614674	9303	23	7D
0005433614701	9303	24	7C
0005433614700	9303	25	7F
0005433614667	9303	26	8A
0005433614663	9303	27	8B
0005433614714	9303	28	8C
0005433614726	9303	29	8E
0005434163584	9303	30	8D
0005432755077	9303	31	9A
0005433614723	9303	32	8F
0005433614680	9303	33	9C
0005433614666	9303	34	9B
0005434163564	9303	35	9D
0005432756849	9303	36	9F
0005433633839	9303	37	9E
0005433614716	9303	38	10A
0005433614677	9303	39	10B
0005433614698	9303	40	10D
0005433633827	9303	41	10E
0005434272173	9303	42	11B
0005433633840	9303	43	11A
0005433614727	9303	44	11C
0005433614718	9303	45	11E
0005433614685	9303	46	11D
0005432145111	9303	47	11F
0005434269085	9303	48	12A
0005432145112	9303	49	12D
0005433614684	9303	50	12C
0005433614733	9303	51	12E
0005432756850	9303	52	12F
0005433577824	9303	53	13C
0005433614661	9303	54	13B
0005433614703	9303	55	13D
0005433614712	9303	56	13F
0005433633835	9303	57	13E
0005434163585	9303	58	14A
0005433633812	9303	59	14D
0005432755079	9303	60	14C
0005433614681	9303	61	14E
0005433633838	9303	62	15A
0005433614708	9303	63	14F
0005434163576	9303	64	15C
0005433614731	9303	65	15B
0005433577815	9303	66	15E
0005434163534	9303	67	15D
0005433633829	9303	68	15F
0005433614717	9303	69	16A
0005433614697	9303	70	16C
0005433614711	9303	71	16B
0005433614660	9303	72	16D
0005433633836	9303	73	16F
0005433577818	9303	74	17B
0005433614694	9303	75	17A
0005433614722	9303	76	17C
0005433614699	9303	77	17D
0005433614705	9303	78	18A
0005433614659	9303	79	17F
0005433614692	9303	80	18B
0005432145113	9303	81	18C
0005433614665	9303	82	18D
0005433633825	9303	83	18F
0005433614719	9303	84	18E
0005433614704	9303	85	19B
0005432756851	9303	86	19D
0005433614693	9303	87	19C
0005433614671	9303	88	20A
0005433614669	9303	89	20C
0005434163536	9303	90	20B
0005433614707	9303	91	20F
0005433614676	9303	92	20E
0005433577822	9303	93	21A
0005433614702	9303	94	21C
0005433577821	9303	95	21B
0005433633814	9303	96	21D
0005433614689	9303	97	21F
0005433614732	9303	98	21E
0005433633816	9303	99	22A
0005433633828	9303	100	22B
0005433614675	9303	101	22C
0005433614709	9303	102	22E
0005433633823	9303	103	22D
0005433633809	9303	104	22F
0005434163583	9303	105	23A
0005433614730	9303	106	23D
0005434152774	9303	107	23C
0005433633821	9303	108	23F
0005433614683	9303	109	23E
0005433577812	9303	110	24B
0005433633837	9303	111	24A
0005432755076	9303	112	24D
0005433633826	9303	113	24C
0005433577813	9303	114	24F
0005434163573	9303	115	25A
0005433614686	9303	116	25C
0005433614679	9303	117	25B
0005433633815	9303	118	25E
0005433614688	9303	119	25F
0005433614662	9303	120	26B
0005433614713	9303	121	26A
0005433633810	9303	122	26C
0005433614724	9303	123	26E
0005433633824	9303	124	26D
0005433614695	9303	125	26F
0005433614706	9303	126	27A
0005433633807	9303	127	27E
0005433614673	9303	128	27D
0005433633831	9303	129	28A
0005434152777	9303	130	27F
0005434163582	9303	131	28C
0005433614691	9303	132	28B
0005433614678	9303	133	28E
0005433577819	9303	134	28F
0005433633811	9303	135	29A
0005433633808	9303	136	29B
0005433614672	9303	137	29D
0005433614710	9303	138	29C
0005433633813	9303	139	29E
0005433633822	9303	140	30B
0005433633819	9303	141	30A
0005433614664	9303	142	30C
0005433614687	9303	143	30E
0005434163563	9303	144	30D
0005433614668	9303	145	31A
0005432756852	9303	146	31C
0005433577817	9303	147	31B
0005432755078	9303	148	31D
0005433577823	9303	149	31F
0005433614728	9303	150	31E
0005433614002	25208	1	1A
0005433633513	25208	2	1D
0005434163621	25208	3	2A
0005433633663	25208	4	2C
0005433633462	25208	5	2F
0005433577649	25208	6	2D
0005433614006	25208	7	3A
0005433613941	25208	8	3D
0005433577754	25208	9	3C
0005433633541	25208	10	3F
0005433633423	25208	11	4A
0005433613765	25208	12	4C
0005433633526	25208	13	4F
0005433613896	25208	14	4D
0005433577710	25208	15	5A
0005433633624	25208	16	5C
0005434163619	25208	17	6A
0005433614233	25208	18	6C
0005433613871	25208	19	6F
0005433577741	25208	20	6D
0005433633537	25208	21	7C
0005433613994	25208	22	7F
0005433613942	25208	23	8A
0005433633631	25208	24	8B
0005433614094	25208	25	8E
0005433577742	25208	26	9A
0005433633466	25208	27	8F
0005433577755	25208	28	9B
0005433614125	25208	29	9C
0005433613564	25208	30	9E
0005434163625	25208	31	10A
0005433633463	25208	32	10B
0005433613698	25208	33	10F
0005433614499	25208	34	11B
0005433633477	25208	35	11D
0005434163620	25208	36	11C
0005433633432	25208	37	11F
0005433613804	25208	38	11E
0005433577687	25208	39	12A
0005433577716	25208	40	12B
0005433633530	25208	41	12D
0005433614046	25208	42	12C
0005433633525	25208	43	12E
0005434163618	25208	44	13C
0005433613565	25208	45	13E
0005433577694	25208	46	13D
0005433613815	25208	47	14A
0005433614022	25208	48	14B
0005435854057	25208	49	14D
0005433633485	25208	50	15B
0005433614187	25208	51	15C
0005433633401	25208	52	15E
0005433614279	25208	53	15D
0005434273075	25208	54	15F
0005433613563	25208	55	16A
0005433577696	25208	56	16D
0005433614416	25208	57	16C
0005433633449	25208	58	16E
0005433614086	25208	59	16F
0005433633654	25208	60	17A
0005434272192	25208	61	17C
0005435854059	25208	62	17B
0005433614159	25208	63	17D
0005433614093	25208	64	17F
0005434163617	25208	65	17E
0005433633389	25208	66	18A
0005433633656	25208	67	18C
0005433614234	25208	68	18E
0005433633465	25208	69	18F
0005433613964	25208	70	19D
0005433614064	25208	71	19E
0005433613991	25208	72	20B
0005433614127	25208	73	20A
0005433577648	25208	74	20C
0005434273077	25208	75	20E
0005433633467	25208	76	20D
0005433613990	25208	77	21B
0005433613961	25208	78	21D
0005433614181	25208	79	21C
0005433633531	25208	80	21E
0005433614208	25208	81	22B
0005433614038	25208	82	22A
0005433633698	25208	83	22D
0005433614182	25208	84	22C
0005433577652	25208	85	22F
0005434163622	25208	86	23A
0005434273076	25208	87	23C
0005433633650	25208	88	23D
0005434163623	25208	89	23E
0005433577643	25208	90	24A
0005433614130	25208	91	24B
0005433614260	25208	92	24D
0005435854060	25208	93	24E
0005434163624	25208	94	24F
0005433614316	25208	95	25A
0005433614085	25208	96	25B
0005433577713	25208	97	25E
0005433633484	25208	98	25D
0005433614298	25208	99	26A
0005433614297	25208	100	26B
0005433633514	25208	101	26E
0005433614188	25208	102	26D
0005433614076	25208	103	26F
0005433633486	25208	104	27A
0005433613848	25208	105	27C
0005433633655	25208	106	27B
0005433633388	25208	107	27F
0005433614084	25208	108	28C
0005433613895	25208	109	28F
0005433613832	25208	110	29C
0005433613972	25208	111	29B
0005433613921	25208	112	29D
0005435854058	25208	113	30A
0005433577644	25208	114	30B
0005434163616	25208	115	30D
0005433614347	25208	116	30C
0005433614228	25208	117	30E
0005433614116	25208	118	30F
0005433614207	25208	119	31A
0005433613996	25208	120	31C
0005433633649	25208	121	31B
0005433613816	25208	122	31E
0005433613814	25208	123	31D
0005433577695	25208	124	31F
0005435986771	4252	1	1G
0005435986778	4252	2	2C
0005435856166	4252	3	2H
0005434271293	4252	4	3C
0005435947087	4252	5	4A
0005432184954	4252	6	4F
0005435947102	4252	7	9H
0005435986776	4252	8	12A
0005432184952	4252	9	12H
0005435947136	4252	10	13E
0005435787332	4252	11	14D
0005435787333	4252	12	15G
0005435947188	4252	13	15H
0005435986775	4252	14	17D
0005435947121	4252	15	17E
0005435947086	4252	16	18A
0005435986777	4252	17	18E
0005435986780	4252	18	18H
0005435856151	4252	19	19A
0005435947151	4252	20	19F
0005435947211	4252	21	20F
0005435947137	4252	22	21B
0005435947144	4252	23	21H
0005435947210	4252	24	21G
0005435787330	4252	25	22E
0005432571295	4252	26	22H
0005434271294	4252	27	23B
0005435947175	4252	28	25D
0005435947105	4252	29	27B
0005435947145	4252	30	27A
0005435947158	4252	31	27G
0005435947122	4252	32	28B
0005435787331	4252	33	28G
0005435986779	4252	34	29E
0005432571302	4252	35	31F
0005435947118	4252	36	32B
0005435947103	4252	37	33A
0005432184955	4252	38	33B
0005435986774	4252	39	33H
0005435986773	4252	40	34G
0005432571277	4252	41	35A
0005435986772	4252	42	36D
0005435947159	4252	43	37H
0005435947114	4252	44	38A
0005432184953	4252	45	39F
0005435787358	26572	1	1A
0005435856211	26572	2	1C
0005435947270	26572	3	11B
0005435947269	26572	4	11H
0005435856208	26572	5	16A
0005435856209	26572	6	16G
0005435947266	26572	7	16H
0005435947273	26572	8	17E
0005435947274	26572	9	18A
0005435947277	26572	10	18H
0005432571328	26572	11	19B
0005432571330	26572	12	19E
0005435787359	26572	13	21D
0005435856212	26572	14	21E
0005435986696	26572	15	23B
0005435856210	26572	16	23E
0005435986702	26572	17	24F
0005432571327	26572	18	24H
0005435947272	26572	19	27B
0005435947276	26572	20	27F
0005435787357	26572	21	27H
0005435947265	26572	22	30E
0005435947267	26572	23	30G
0005435947268	26572	24	31B
0005435947275	26572	25	31F
0005435947271	26572	26	31E
0005435947279	26572	27	33F
0005435947278	26572	28	33G
0005432571329	26572	29	39D
0005432948231	335	1	1C
0005432948255	335	2	1D
0005433569150	335	3	2A
0005432948133	335	4	1F
0005433134092	335	5	2C
0005432948183	335	6	2F
0005433569147	335	7	2D
0005432948085	335	8	3A
0005432238943	335	9	3D
0005433074413	335	10	3C
0005432948106	335	11	3F
0005433569165	335	12	4A
0005433074539	335	13	4C
0005433569169	335	14	4D
0005433569168	335	15	5A
0005432948122	335	16	4F
0005433074537	335	17	5C
0005433569174	335	18	5F
0005433569152	335	19	5D
0005433569160	335	20	6A
0005433074624	335	21	6D
0005432948107	335	22	6F
0005433569149	335	23	7A
0005432238941	335	24	7D
0005432948050	335	25	8A
0005433134093	335	26	8B
0005432948146	335	27	8C
0005432948019	335	28	8E
0005433569171	335	29	9A
0005433569131	335	30	8F
0005432948172	335	31	9B
0005433569138	335	32	9D
0005433569178	335	33	9E
0005433074538	335	34	10A
0005432948289	335	35	10C
0005433569167	335	36	10B
0005432947961	335	37	10E
0005433129245	335	38	10D
0005433569156	335	39	10F
0005432948040	335	40	11C
0005432948232	335	41	11B
0005433074406	335	42	11F
0005432948111	335	43	11E
0005433569154	335	44	12A
0005433569177	335	45	12C
0005433569163	335	46	12B
0005433074528	335	47	12D
0005432947989	335	48	12E
0005433569166	335	49	12F
0005432948042	335	50	13A
0005433074623	335	51	13C
0005433074540	335	52	13B
0005433569126	335	53	13E
0005433074505	335	54	13F
0005433569151	335	55	14B
0005433569133	335	56	14A
0005432238944	335	57	14D
0005433074547	335	58	14F
0005433074530	335	59	14E
0005432947827	335	60	15B
0005433569170	335	61	15A
0005433569158	335	62	15C
0005433569135	335	63	15D
0005433074460	335	64	15F
0005433569129	335	65	15E
0005433569125	335	66	16A
0005432947974	335	67	16B
0005433074487	335	68	16E
0005433569139	335	69	16F
0005433569130	335	70	17B
0005433569176	335	71	17A
0005433569181	335	72	17C
0005433074545	335	73	17E
0005432238942	335	74	17D
0005433569137	335	75	18A
0005433569136	335	76	17F
0005433569128	335	77	18B
0005432948225	335	78	18C
0005432948280	335	79	18D
0005433074524	335	80	18F
0005432948248	335	81	19D
0005432948171	335	82	20A
0005432948216	335	83	19E
0005432238945	335	84	20B
0005432948262	335	85	20D
0005432947938	335	86	20F
0005433569140	335	87	21A
0005433074531	335	88	21C
0005433074514	335	89	21B
0005432948281	335	90	21D
0005433569161	335	91	21F
0005433569175	335	92	21E
0005433569162	335	93	22B
0005433074523	335	94	22A
0005432948194	335	95	22C
0005433134094	335	96	22E
0005433569148	335	97	22D
0005433569144	335	98	23A
0005432948250	335	99	23C
0005432948081	335	100	23B
0005432948217	335	101	23D
0005432948110	335	102	23F
0005433074527	335	103	24B
0005433074407	335	104	24A
0005433569132	335	105	24E
0005432948043	335	106	24D
0005433074409	335	107	24F
0005432948145	335	108	25A
0005433074599	335	109	25C
0005433569159	335	110	25B
0005433134108	335	111	25F
0005433569155	335	112	25E
0005433569172	335	113	26A
0005433129244	335	114	26B
0005432948073	335	115	26C
0005433569143	335	116	26D
0005433569157	335	117	26F
0005432948121	335	118	27A
0005432947973	335	119	27C
0005432948254	335	120	27B
0005433569146	335	121	27E
0005433074553	335	122	27D
0005432948177	335	123	28B
0005433569142	335	124	28A
0005433074548	335	125	28E
0005432948105	335	126	28D
0005433074526	335	127	28F
0005433569179	335	128	29C
0005433569127	335	129	29B
0005433569153	335	130	29D
0005433569124	335	131	29F
0005433569173	335	132	30B
0005432947960	335	133	30A
0005433569164	335	134	30D
0005433569145	335	135	30C
0005433569141	335	136	30E
0005433569180	335	137	30F
0005433074513	335	138	31B
0005432948181	335	139	31A
0005432947972	335	140	31C
0005432948182	335	141	31E
0005432948292	335	142	31D
0005433569134	335	143	31F
0005433568228	11563	1	1C
0005433568492	11563	2	1A
0005432192324	11563	3	2A
0005433568537	11563	4	1F
0005433074742	11563	5	2C
0005433074728	11563	6	2F
0005433074749	11563	7	3C
0005433074729	11563	8	3F
0005432948495	11563	9	3D
0005433134143	11563	10	4C
0005433074731	11563	11	4A
0005433074743	11563	12	4F
0005432948491	11563	13	4D
0005433134140	11563	14	5A
0005433568322	11563	15	5C
0005432948494	11563	16	5F
0005433074723	11563	17	5D
0005433568493	11563	18	6A
0005433568302	11563	19	6C
0005432948489	11563	20	6F
0005432948483	11563	21	6D
0005433568502	11563	22	7A
0005433568466	11563	23	7C
0005433568414	11563	24	7F
0005433568465	11563	25	7D
0005433568425	11563	26	8A
0005433074736	11563	27	8C
0005432948481	11563	28	8B
0005432948509	11563	29	8E
0005433131712	11563	30	9C
0005433134141	11563	31	9B
0005432948504	11563	32	9D
0005433074751	11563	33	10A
0005433131713	11563	34	9F
0005433074732	11563	35	10C
0005433568191	11563	36	10B
0005433568546	11563	37	10D
0005432948485	11563	38	10F
0005432948480	11563	39	10E
0005433074737	11563	40	11B
0005433568151	11563	41	11A
0005433568488	11563	42	11C
0005433074724	11563	43	11D
0005432948478	11563	44	11E
0005433568558	11563	45	12A
0005432948513	11563	46	11F
0005433568467	11563	47	12C
0005433074727	11563	48	12B
0005432948476	11563	49	12E
0005432948511	11563	50	12D
0005433134144	11563	51	12F
0005433568268	11563	52	13B
0005433074748	11563	53	13C
0005432948503	11563	54	13D
0005432948488	11563	55	13F
0005432948484	11563	56	13E
0005432948499	11563	57	14A
0005433568531	11563	58	14B
0005433568451	11563	59	14D
0005432948497	11563	60	14C
0005433568254	11563	61	14E
0005433568503	11563	62	14F
0005433568363	11563	63	15B
0005433568520	11563	64	15A
0005432948479	11563	65	15C
0005433568438	11563	66	15D
0005433131714	11563	67	15E
0005432948472	11563	68	16C
0005433074730	11563	69	16E
0005433568519	11563	70	16D
0005432948474	11563	71	17C
0005434087918	11563	72	17E
0005433074733	11563	73	17D
0005433074734	11563	74	17F
0005433929858	11563	75	18A
0005433568603	11563	76	18B
0005433074739	11563	77	18D
0005433074722	11563	78	18C
0005433074738	11563	79	18F
0005433074726	11563	80	19B
0005433568382	11563	81	19C
0005433568494	11563	82	20A
0005433074740	11563	83	19E
0005433568532	11563	84	20C
0005433568604	11563	85	20E
0005432948477	11563	86	20D
0005432948507	11563	87	20F
0005433568258	11563	88	21A
0005433074746	11563	89	21B
0005433568190	11563	90	21C
0005433134142	11563	91	21E
0005433568518	11563	92	22A
0005433568530	11563	93	21F
0005433568432	11563	94	22B
0005433074725	11563	95	22C
0005433074744	11563	96	22E
0005433568346	11563	97	22D
0005432948512	11563	98	23A
0005433568550	11563	99	23B
0005432948498	11563	100	23D
0005433568325	11563	101	23C
0005433568545	11563	102	23E
0005433074750	11563	103	24A
0005432948496	11563	104	23F
0005432948501	11563	105	24B
0005433074741	11563	106	24C
0005432948490	11563	107	24D
0005433568498	11563	108	24F
0005432192322	11563	109	24E
0005433568452	11563	110	25B
0005433568347	11563	111	25A
0005432948493	11563	112	25C
0005432948505	11563	113	25D
0005432948502	11563	114	25E
0005433568453	11563	115	26A
0005433074735	11563	116	26B
0005432948508	11563	117	26D
0005433568383	11563	118	26C
0005433568415	11563	119	26E
0005433568257	11563	120	27C
0005432948475	11563	121	27B
0005432948487	11563	122	27D
0005433568559	11563	123	27F
0005433568617	11563	124	27E
0005433568490	11563	125	28A
0005433568454	11563	126	28B
0005432948506	11563	127	28D
0005433568495	11563	128	28C
0005433568666	11563	129	28E
0005432948473	11563	130	28F
0005432948486	11563	131	29A
0005433568087	11563	132	29B
0005433568536	11563	133	29D
0005432948482	11563	134	29C
0005432192323	11563	135	29F
0005432948492	11563	136	29E
0005433568557	11563	137	30A
0005432948500	11563	138	30B
0005433131711	11563	139	30C
0005433568539	11563	140	30E
0005433074745	11563	141	30D
0005433568219	11563	142	30F
0005432948510	11563	143	31B
0005433074747	11563	144	31A
0005433074721	11563	145	31E
0005433568242	11563	146	31D
0005433568670	11563	147	31C
0005433568227	11563	148	31F
0005433817473	10056	1	1A
0005434732955	10056	2	1B
0005434732957	10056	3	2B
0005434732958	10056	4	3B
0005433817475	10056	5	4B
0005433817474	10056	6	5B
0005433817476	10056	7	6A
0005433817477	10056	8	6B
0005433817442	13924	1	1A
0005433817421	13924	2	1B
0005433817453	13924	3	2A
0005433817452	13924	4	2B
0005433817419	13924	5	3A
0005434732984	13924	6	3B
0005434732983	13924	7	4A
0005434732985	13924	8	4B
0005433817420	13924	9	5A
0005433817440	13924	10	5B
0005433817454	13924	11	6A
0005435982350	2332	1	1A
0005435982359	2332	2	1B
0005432984854	2332	3	1F
0005435982346	2332	4	1C
0005433434422	2332	5	1G
0005432984953	2332	6	2A
0005433754282	2332	7	1H
0005432655553	2332	8	2C
0005433766643	2332	9	2B
0005432984753	2332	10	2F
0005432300269	2332	11	2G
0005435982385	2332	12	3A
0005433764682	2332	13	2H
0005433754296	2332	14	3B
0005432226064	2332	15	3F
0005433754281	2332	16	3C
0005435982364	2332	17	3G
0005435982391	2332	18	4A
0005435982368	2332	19	3H
0005435982352	2332	20	4B
0005433434346	2332	21	4F
0005432984830	2332	22	4C
0005432984870	2332	23	4G
0005433754305	2332	24	5A
0005435982379	2332	25	4H
0005433754280	2332	26	5B
0005433754291	2332	27	5F
0005432984796	2332	28	5C
0005432984710	2332	29	5H
0005433754309	2332	30	9B
0005433434486	2332	31	9A
0005435982369	2332	32	9G
0005435982343	2332	33	11A
0005433754289	2332	34	9H
0005432984859	2332	35	11B
0005433434423	2332	36	11E
0005435982367	2332	37	11D
0005432655547	2332	38	11F
0005432655557	2332	39	11G
0005432300272	2332	40	12A
0005433434603	2332	41	12D
0005432984906	2332	42	12B
0005433754279	2332	43	12E
0005432984893	2332	44	12G
0005432984754	2332	45	12F
0005433434478	2332	46	12H
0005433754262	2332	47	13A
0005435982381	2332	48	13D
0005432226063	2332	49	13B
0005435982351	2332	50	13E
0005433754292	2332	51	13G
0005435982374	2332	52	13F
0005435982366	2332	53	14A
0005433766646	2332	54	13H
0005435982386	2332	55	14E
0005433764681	2332	56	14D
0005432984978	2332	57	14B
0005432226066	2332	58	14F
0005433754311	2332	59	14H
0005435982378	2332	60	14G
0005435982361	2332	61	15A
0005434731132	2332	62	15B
0005432984915	2332	63	15E
0005432984775	2332	64	15D
0005433754269	2332	65	15F
0005432984784	2332	66	15H
0005433434532	2332	67	15G
0005435982354	2332	68	16A
0005433754276	2332	69	16E
0005432984807	2332	70	16D
0005435982387	2332	71	16G
0005433754273	2332	72	16F
0005432984834	2332	73	16H
0005435982358	2332	74	17B
0005435982373	2332	75	17A
0005435982365	2332	76	17D
0005435982353	2332	77	17E
0005432984902	2332	78	17G
0005433754288	2332	79	17F
0005433434531	2332	80	17H
0005435982370	2332	81	18B
0005433754283	2332	82	18D
0005435982384	2332	83	18F
0005432655552	2332	84	18E
0005433754275	2332	85	18G
0005433766644	2332	86	18H
0005435982360	2332	87	19B
0005432984905	2332	88	19A
0005432655548	2332	89	19E
0005433754312	2332	90	19F
0005433434467	2332	91	19G
0005435982382	2332	92	20A
0005435982349	2332	93	19H
0005435982345	2332	94	20D
0005432226062	2332	95	20B
0005433754272	2332	96	20G
0005433434547	2332	97	20F
0005433754287	2332	98	20E
0005433434421	2332	99	20H
0005433766645	2332	100	21A
0005435982375	2332	101	21D
0005433754268	2332	102	21B
0005435982371	2332	103	21E
0005432984851	2332	104	21F
0005433434468	2332	105	21H
0005433754314	2332	106	21G
0005433754271	2332	107	22B
0005433434463	2332	108	22D
0005432984885	2332	109	22E
0005433434602	2332	110	22G
0005433434464	2332	111	23A
0005435982372	2332	112	22H
0005433754264	2332	113	23D
0005432984901	2332	114	23B
0005435982392	2332	115	23F
0005433434466	2332	116	23E
0005433754303	2332	117	23G
0005435982377	2332	118	24A
0005433754266	2332	119	23H
0005433434500	2332	120	24B
0005432300271	2332	121	24D
0005433754306	2332	122	24E
0005433754260	2332	123	24H
0005432869464	2332	124	24G
0005432869476	2332	125	24F
0005433754277	2332	126	25D
0005432984844	2332	127	25F
0005433434528	2332	128	25E
0005435982347	2332	129	27A
0005433754284	2332	130	27B
0005432984907	2332	131	27E
0005433434501	2332	132	27D
0005433434443	2332	133	27F
0005433754267	2332	134	27H
0005433754259	2332	135	27G
0005433434447	2332	136	28A
0005432655555	2332	137	28B
0005432655546	2332	138	28E
0005432984950	2332	139	28D
0005435982383	2332	140	28F
0005433754307	2332	141	28H
0005433434477	2332	142	28G
0005432984980	2332	143	29A
0005435982356	2332	144	29D
0005435982389	2332	145	29B
0005433754299	2332	146	29E
0005432984920	2332	147	29G
0005432869467	2332	148	29F
0005433754270	2332	149	30A
0005432300270	2332	150	29H
0005432984861	2332	151	30D
0005433434558	2332	152	30B
0005433754298	2332	153	30F
0005432984951	2332	154	30E
0005433754300	2332	155	30G
0005435982363	2332	156	30H
0005432869466	2332	157	31B
0005433434487	2332	158	31A
0005432655549	2332	159	31E
0005432869453	2332	160	31D
0005432226061	2332	161	31F
0005435982380	2332	162	31G
0005432984872	2332	163	31H
0005432984774	2332	164	32B
0005435982376	2332	165	32A
0005433754290	2332	166	32D
0005433754261	2332	167	32F
0005432984886	2332	168	32G
0005432984914	2332	169	33A
0005433754310	2332	170	32H
0005432984952	2332	171	33B
0005433754263	2332	172	33E
0005432984979	2332	173	33D
0005433754286	2332	174	33F
0005432655550	2332	175	33H
0005433754278	2332	176	33G
0005432984884	2332	177	34D
0005433754297	2332	178	34B
0005433434552	2332	179	34F
0005435982355	2332	180	34E
0005435982357	2332	181	34G
0005432655554	2332	182	34H
0005433434485	2332	183	35A
0005433754302	2332	184	35D
0005433754301	2332	185	35E
0005432984852	2332	186	35G
0005435982348	2332	187	35F
0005433754285	2332	188	36A
0005432984855	2332	189	35H
0005433754294	2332	190	36B
0005433754308	2332	191	36D
0005433754304	2332	192	36F
0005432869465	2332	193	36E
0005433754295	2332	194	36G
0005432984887	2332	195	37A
0005433754293	2332	196	36H
0005432984892	2332	197	37B
0005433434540	2332	198	37E
0005433754313	2332	199	37D
0005435982388	2332	200	37F
0005433754258	2332	201	38A
0005435982362	2332	202	37H
0005432655551	2332	203	38D
0005435982344	2332	204	38B
0005433766642	2332	205	38E
0005432226065	2332	206	38G
0005435982390	2332	207	38F
0005433754274	2332	208	38H
0005433754265	2332	209	39E
0005432655556	2332	210	39D
0005433434512	2332	211	39F
0005432051132	26162	1	1A
0005433753695	26162	2	1C
0005435981855	26162	3	1B
0005433753697	26162	4	1F
0005433753715	26162	5	1H
0005435981806	26162	6	2A
0005432655458	26162	7	2B
0005432985123	26162	8	2F
0005433434722	26162	9	2C
0005433753830	26162	10	2G
0005435981834	26162	11	3A
0005433753696	26162	12	3C
0005435981762	26162	13	3B
0005433753800	26162	14	3F
0005435981995	26162	15	3H
0005432655398	26162	16	3G
0005435981853	26162	17	4A
0005432655388	26162	18	4B
0005435981763	26162	19	4F
0005435981846	26162	20	4C
0005433753775	26162	21	4G
0005432985118	26162	22	4H
0005433434705	26162	23	5B
0005432985128	26162	24	5A
0005435981807	26162	25	5C
0005432049469	26162	26	5G
0005433753768	26162	27	5F
0005435981873	26162	28	9A
0005433753874	26162	29	5H
0005433434703	26162	30	9B
0005432985106	26162	31	9G
0005432985116	26162	32	9H
0005433434720	26162	33	11B
0005435982008	26162	34	11E
0005433753593	26162	35	11D
0005435982015	26162	36	11F
0005433434709	26162	37	11G
0005433434699	26162	38	12B
0005432985111	26162	39	12A
0005433764668	26162	40	11H
0005433753797	26162	41	12E
0005432051131	26162	42	12D
0005434731177	26162	43	12F
0005432655404	26162	44	12H
0005432985114	26162	45	12G
0005432655399	26162	46	13A
0005433434708	26162	47	13B
0005435981920	26162	48	13E
0005433434712	26162	49	13G
0005435981645	26162	50	13F
0005435982005	26162	51	13H
0005435982014	26162	52	14B
0005435981655	26162	53	14A
0005435981933	26162	54	14E
0005433753683	26162	55	14D
0005432985108	26162	56	14F
0005433754018	26162	57	14G
0005435981800	26162	58	15A
0005432985125	26162	59	14H
0005432985120	26162	60	15B
0005433434725	26162	61	15E
0005433753769	26162	62	15D
0005432985104	26162	63	15F
0005433753820	26162	64	15H
0005432985129	26162	65	15G
0005433753600	26162	66	16A
0005433753801	26162	67	16D
0005432985117	26162	68	16B
0005435981960	26162	69	16E
0005432869529	26162	70	16G
0005435981932	26162	71	16F
0005433753745	26162	72	16H
0005433753779	26162	73	17B
0005433753706	26162	74	17A
0005433434718	26162	75	17D
0005432869528	26162	76	17E
0005432985131	26162	77	17G
0005432985115	26162	78	17H
0005433753712	26162	79	18B
0005435981854	26162	80	18A
0005432985097	26162	81	18D
0005433753704	26162	82	18F
0005432655409	26162	83	18E
0005433753791	26162	84	18G
0005433434723	26162	85	19A
0005433753777	26162	86	18H
0005435981952	26162	87	19B
0005432869532	26162	88	19D
0005433753892	26162	89	19F
0005435982000	26162	90	19E
0005434731174	26162	91	19G
0005433753900	26162	92	20A
0005432049468	26162	93	19H
0005433766594	26162	94	20B
0005435981895	26162	95	20E
0005433434721	26162	96	20D
0005432655402	26162	97	20F
0005433753724	26162	98	20H
0005435981908	26162	99	20G
0005432655464	26162	100	21A
0005435981999	26162	101	21D
0005435981934	26162	102	21B
0005435982028	26162	103	21E
0005432985119	26162	104	21F
0005435981921	26162	105	21H
0005432985124	26162	106	21G
0005432985100	26162	107	22A
0005433434713	26162	108	22D
0005432049470	26162	109	22B
0005435981815	26162	110	22F
0005432985105	26162	111	22E
0005433753819	26162	112	22G
0005433753579	26162	113	22H
0005435981922	26162	114	23A
0005433434707	26162	115	23E
0005433753831	26162	116	23D
0005432869531	26162	117	23B
0005433434698	26162	118	23F
0005432051130	26162	119	23G
0005433434724	26162	120	23H
0005432655443	26162	121	24B
0005435981759	26162	122	24A
0005432985101	26162	123	24D
0005432985103	26162	124	24F
0005433753778	26162	125	24H
0005435981998	26162	126	24G
0005433434726	26162	127	25E
0005432985110	26162	128	25D
0005432049467	26162	129	27A
0005433753875	26162	130	25F
0005435981738	26162	131	27D
0005435981739	26162	132	27B
0005433754019	26162	133	27E
0005435981936	26162	134	27F
0005433434710	26162	135	27H
0005435982009	26162	136	27G
0005435981961	26162	137	28A
0005435981808	26162	138	28B
0005433753956	26162	139	28D
0005432985130	26162	140	28F
0005433434714	26162	141	28E
0005435981835	26162	142	28H
0005435981838	26162	143	28G
0005433753776	26162	144	29A
0005433753849	26162	145	29B
0005435981956	26162	146	29E
0005433434711	26162	147	29D
0005432655403	26162	148	29F
0005433434702	26162	149	29H
0005432869527	26162	150	29G
0005433753813	26162	151	30A
0005433434700	26162	152	30D
0005435982006	26162	153	30B
0005433764667	26162	154	30F
0005432655411	26162	155	30E
0005432049466	26162	156	30G
0005433753857	26162	157	30H
0005433753785	26162	158	31B
0005433434716	26162	159	31A
0005432985126	26162	160	31E
0005433753585	26162	161	31D
0005432985098	26162	162	31F
0005432985113	26162	163	31H
0005432655407	26162	164	31G
0005432985109	26162	165	32A
0005432869530	26162	166	32B
0005435981984	26162	167	32E
0005435982004	26162	168	32D
0005433434715	26162	169	32G
0005435981955	26162	170	32F
0005433434719	26162	171	32H
0005432985102	26162	172	33A
0005432655427	26162	173	33B
0005433766600	26162	174	33E
0005435981856	26162	175	33D
0005435981758	26162	176	33G
0005433753705	26162	177	33F
0005435981930	26162	178	33H
0005433753703	26162	179	34B
0005433766610	26162	180	34A
0005435982019	26162	181	34D
0005434731175	26162	182	34F
0005432985122	26162	183	34E
0005433753684	26162	184	34H
0005432985112	26162	185	35B
0005433753850	26162	186	35A
0005432985121	26162	187	35E
0005435981646	26162	188	35D
0005433753594	26162	189	35F
0005433753726	26162	190	35G
0005432655484	26162	191	36A
0005433434717	26162	192	35H
0005434731176	26162	193	36B
0005435981965	26162	194	36D
0005433434704	26162	195	36F
0005432985099	26162	196	36E
0005433754013	26162	197	36G
0005433753584	26162	198	37D
0005432869526	26162	199	37B
0005433753821	26162	200	37E
0005432655428	26162	201	37F
0005435982016	26162	202	37H
0005432655408	26162	203	37G
0005433434706	26162	204	38B
0005432985127	26162	205	38A
0005433434701	26162	206	38E
0005432655426	26162	207	38D
0005433753792	26162	208	38F
0005432985107	26162	209	38H
0005435981931	26162	210	38G
0005435981878	26162	211	39D
0005434731178	26162	212	39F
0005433754012	26162	213	39E
0005433151203	1490	1	1A
0005434374706	1490	2	1C
0005433151283	1490	3	2A
0005432267903	1490	4	2C
0005433151219	1490	5	2F
0005433151147	1490	6	3A
0005432267902	1490	7	4B
0005433461592	1490	8	4D
0005433151300	1490	9	4F
0005433151189	1490	10	4E
0005434374678	1490	11	5B
0005433151299	1490	12	5A
0005433151204	1490	13	5C
0005433151058	1490	14	5D
0005434374702	1490	15	5E
0005433151187	1490	16	6A
0005434374708	1490	17	5F
0005433151137	1490	18	6B
0005432267901	1490	19	6C
0005433931433	1490	20	6D
0005434029637	1490	21	6E
0005434374692	1490	22	7C
0005433151144	1490	23	7F
0005432267904	1490	24	7E
0005433151247	1490	25	8C
0005433151240	1490	26	8B
0005434374681	1490	27	8A
0005433151132	1490	28	8E
0005434374686	1490	29	8D
0005433151285	1490	30	9A
0005433151127	1490	31	9B
0005434374699	1490	32	9C
0005433151220	1490	33	9E
0005433151080	1490	34	10C
0005433150997	1490	35	10E
0005434374700	1490	36	10D
0005433151251	1490	37	11A
0005433151126	1490	38	11C
0005433151278	1490	39	11E
0005433151206	1490	40	11D
0005434029633	1490	41	12B
0005434374689	1490	42	12D
0005433764661	1490	43	12E
0005434374690	1490	44	13C
0005434374693	1490	45	13B
0005434374694	1490	46	13E
0005434374698	1490	47	14A
0005433151179	1490	48	14B
0005433764660	1490	49	14D
0005434374691	1490	50	15A
0005434374684	1490	51	15C
0005434374682	1490	52	15D
0005434374696	1490	53	15E
0005434374709	1490	54	16A
0005433151178	1490	55	16B
0005433151065	1490	56	16E
0005434029630	1490	57	16D
0005433460438	1490	58	16F
0005434374697	1490	59	17B
0005433151314	1490	60	17D
0005434374703	1490	61	17C
0005432267906	1490	62	17E
0005432267905	1490	63	17F
0005434374683	1490	64	18A
0005434029634	1490	65	18B
0005434374701	1490	66	18E
0005434374705	1490	67	19A
0005434374704	1490	68	19D
0005433151073	1490	69	19C
0005434374707	1490	70	19E
0005433151298	1490	71	19F
0005434374679	1490	72	20A
0005434374677	1490	73	20C
0005433151079	1490	74	20E
0005433931452	1490	75	20F
0005433151059	1490	76	21A
0005434374688	1490	77	21C
0005433931451	1490	78	21B
0005433151284	1490	79	21E
0005433151188	1490	80	21F
0005433151379	1490	81	22B
0005434374695	1490	82	22A
0005433460439	1490	83	22C
0005433151236	1490	84	22D
0005433151169	1490	85	22E
0005434374680	1490	86	23A
0005433461591	1490	87	22F
0005434374687	1490	88	23B
0005433151066	1490	89	23C
0005433150989	1490	90	23D
0005434374685	1490	91	23F
0005433151426	20132	1	1A
0005434374327	20132	2	1D
0005433931470	20132	3	1F
0005434374410	20132	4	2C
0005434374253	20132	5	2A
0005434374178	20132	6	2D
0005434374294	20132	7	3C
0005434374326	20132	8	3A
0005434374260	20132	9	3F
0005434374159	20132	10	4A
0005434374242	20132	11	4B
0005434374396	20132	12	4D
0005433151444	20132	13	4E
0005434374177	20132	14	5A
0005433151428	20132	15	5B
0005434029659	20132	16	5C
0005433151452	20132	17	5E
0005434374186	20132	18	5F
0005434374394	20132	19	6B
0005434374447	20132	20	6C
0005433151435	20132	21	6D
0005433151432	20132	22	6E
0005433151438	20132	23	6F
0005433151431	20132	24	7B
0005433151440	20132	25	7D
0005434029660	20132	26	7E
0005434374388	20132	27	8A
0005434374102	20132	28	7F
0005434374417	20132	29	8D
0005434374328	20132	30	8C
0005434374231	20132	31	8E
0005434374309	20132	32	9A
0005433151439	20132	33	9C
0005432056304	20132	34	9B
0005433151446	20132	35	9E
0005434374427	20132	36	9D
0005433151447	20132	37	9F
0005434374449	20132	38	10E
0005434374383	20132	39	10D
0005432056301	20132	40	11A
0005434374101	20132	41	11B
0005433151441	20132	42	11D
0005434374211	20132	43	11F
0005433151453	20132	44	11E
0005433151459	20132	45	12A
0005433151443	20132	46	12B
0005434374222	20132	47	12D
0005434374320	20132	48	12E
0005434373904	20132	49	13A
0005434374448	20132	50	13C
0005433151437	20132	51	13B
0005433151429	20132	52	13E
0005434374415	20132	53	13D
0005433151454	20132	54	14A
0005434374455	20132	55	14B
0005434374319	20132	56	14C
0005434374395	20132	57	14F
0005433151449	20132	58	15D
0005433764681	20132	59	15F
0005433151458	20132	60	15E
0005433151433	20132	61	16B
0005434374454	20132	62	16A
0005434374289	20132	63	16C
0005433151451	20132	64	16E
0005432056302	20132	65	16F
0005434374409	20132	66	17A
0005433764682	20132	67	17B
0005433931469	20132	68	17D
0005433151434	20132	69	17E
0005434374183	20132	70	18A
0005433151457	20132	71	18B
0005434374293	20132	72	18C
0005434374265	20132	73	18D
0005434374184	20132	74	19A
0005434374158	20132	75	18F
0005434374235	20132	76	19B
0005434374254	20132	77	19D
0005434373903	20132	78	19C
0005434374312	20132	79	19F
0005434374310	20132	80	19E
0005434374230	20132	81	20A
0005432056303	20132	82	20B
0005433151436	20132	83	20D
0005433151460	20132	84	20C
0005433151455	20132	85	20E
0005434374295	20132	86	21A
0005434374276	20132	87	21C
0005434374437	20132	88	21B
0005434374043	20132	89	21D
0005433151448	20132	90	21F
0005433931471	20132	91	21E
0005433151430	20132	92	22B
0005433151456	20132	93	22A
0005434374350	20132	94	22C
0005434374277	20132	95	22D
0005433151427	20132	96	22F
0005433931468	20132	97	22E
0005433151445	20132	98	23A
0005433151450	20132	99	23B
0005434374308	20132	100	23C
0005434374286	20132	101	23E
0005433151442	20132	102	23D
0005434374279	20132	103	23F
0005432424484	507	1	1A
0005432424498	507	2	1D
0005432424475	507	3	2D
0005432424489	507	4	2C
0005432424471	507	5	4A
0005432282876	507	6	3F
0005432424509	507	7	4C
0005432282871	507	8	4D
0005432282873	507	9	5F
0005432424487	507	10	8B
0005432424496	507	11	8D
0005432424514	507	12	9A
0005432424469	507	13	9F
0005432424505	507	14	10B
0005432424481	507	15	10E
0005432424502	507	16	11B
0005432282875	507	17	12A
0005432282869	507	18	12B
0005432282874	507	19	12F
0005432424488	507	20	13B
0005432424516	507	21	13A
0005432424519	507	22	13C
0005432424463	507	23	13D
0005432424511	507	24	13F
0005432424499	507	25	14B
0005432424491	507	26	14C
0005432424518	507	27	14E
0005432424483	507	28	15A
0005432424497	507	29	15C
0005432424480	507	30	15E
0005432424472	507	31	16B
0005432424479	507	32	17B
0005432424466	507	33	17C
0005432424513	507	34	17E
0005432424515	507	35	18E
0005432424512	507	36	19B
0005432424506	507	37	19D
0005432424500	507	38	20B
0005432424470	507	39	20A
0005432424492	507	40	21E
0005432424474	507	41	22B
0005432424464	507	42	22C
0005432424473	507	43	22D
0005432424467	507	44	23A
0005432424476	507	45	23C
0005432424465	507	46	23F
0005432424468	507	47	23E
0005432424494	507	48	24A
0005432424504	507	49	24D
0005432424495	507	50	24F
0005432424503	507	51	25D
0005432424493	507	52	25E
0005432424490	507	53	26A
0005432424510	507	54	27A
0005432424485	507	55	27C
0005432424508	507	56	27D
0005432282872	507	57	27E
0005432424477	507	58	28A
0005432424517	507	59	27F
0005432282870	507	60	28B
0005432424478	507	61	29D
0005432424486	507	62	29F
0005432424482	507	63	30E
0005432424507	507	64	31B
0005432424501	507	65	31F
0005432302334	12897	1	4C
0005434446500	12897	2	6C
0005433158131	12897	3	11B
0005434446499	12897	4	12D
0005433158132	12897	5	14B
0005433158134	12897	6	14C
0005433158133	12897	7	16C
0005432302333	12897	8	16E
0005434446502	12897	9	18A
0005432302336	12897	10	23D
0005434446497	12897	11	24A
0005432302335	12897	12	24B
0005434446496	12897	13	25C
0005433158135	12897	14	31F
0005432424048	12896	1	1A
0005432423975	12896	2	1F
0005432424021	12896	3	3A
0005432423932	12896	4	3D
0005432423920	12896	5	4C
0005432423846	12896	6	5A
0005432423933	12896	7	6C
0005432423874	12896	8	6F
0005432424090	12896	9	7C
0005432423919	12896	10	7F
0005432424093	12896	11	8A
0005432424096	12896	12	8D
0005432424049	12896	13	9B
0005432424050	12896	14	9D
0005432424091	12896	15	9F
0005432423979	12896	16	9E
0005432424038	12896	17	10E
0005432423873	12896	18	10D
0005432423974	12896	19	12B
0005432423866	12896	20	13A
0005432423985	12896	21	14B
0005432424089	12896	22	15C
0005432423991	12896	23	16C
0005432423986	12896	24	18A
0005432424027	12896	25	18D
0005432424058	12896	26	19D
0005432424066	12896	27	19C
0005432424004	12896	28	20B
0005432423939	12896	29	20F
0005432423960	12896	30	21E
0005432423855	12896	31	22C
0005432423996	12896	32	22E
0005432423942	12896	33	23E
0005432423992	12896	34	24A
0005432424059	12896	35	24B
0005432424060	12896	36	24E
0005432424028	12896	37	25E
0005432423865	12896	38	25F
0005432424057	12896	39	26B
0005432424092	12896	40	27A
0005432423934	12896	41	29A
0005432424056	12896	42	29C
0005432424000	12896	43	29D
0005432424012	12896	44	30A
0005432423995	12896	45	30D
0005432423993	12896	46	30F
0005434023750	482	1	1A
0005433057490	482	2	1B
0005433057554	482	3	1F
0005433057727	482	4	2A
0005432235643	482	5	1H
0005434023802	482	6	2B
0005434023795	482	7	2F
0005434023757	482	8	2C
0005432045613	482	9	2H
0005432235651	482	10	3C
0005433057619	482	11	3B
0005432235648	482	12	3F
0005434023810	482	13	3G
0005433057685	482	14	4A
0005433057728	482	15	3H
0005434028295	482	16	4B
0005434735644	482	17	4C
0005434023766	482	18	4G
0005434735653	482	19	5A
0005433057470	482	20	4H
0005434032025	482	21	5B
0005433929575	482	22	5F
0005434023772	482	23	5G
0005434023765	482	24	5H
0005433057673	482	25	9B
0005433057747	482	26	9H
0005432235650	482	27	11D
0005434023784	482	28	11B
0005433057733	482	29	11H
0005434023774	482	30	12D
0005434023761	482	31	12B
0005434028296	482	32	12G
0005433057734	482	33	12F
0005433929568	482	34	13A
0005433057748	482	35	13B
0005433057544	482	36	13F
0005434029657	482	37	13G
0005434032026	482	38	13H
0005434032023	482	39	14A
0005434023786	482	40	14B
0005433057597	482	41	14F
0005434032027	482	42	14E
0005434023793	482	43	14G
0005433057731	482	44	15A
0005432235645	482	45	15G
0005434023754	482	46	15H
0005434023753	482	47	16D
0005434023801	482	48	16B
0005434023790	482	49	16E
0005434023807	482	50	16G
0005433057774	482	51	16F
0005434023809	482	52	16H
0005433057526	482	53	17B
0005434023763	482	54	17A
0005433684414	482	55	17D
0005433057687	482	56	17E
0005433057735	482	57	17G
0005433057812	482	58	17F
0005434023806	482	59	18E
0005434023775	482	60	18F
0005434023798	482	61	18H
0005432235647	482	62	19B
0005434023791	482	63	19E
0005432235649	482	64	19H
0005432045614	482	65	19G
0005434023788	482	66	20E
0005434023759	482	67	20F
0005434023813	482	68	21A
0005434023792	482	69	21D
0005434023794	482	70	21B
0005434023777	482	71	21E
0005434023803	482	72	21G
0005434023800	482	73	21F
0005434023778	482	74	21H
0005434023768	482	75	22A
0005434023767	482	76	22D
0005434032024	482	77	22F
0005434023797	482	78	22H
0005434023816	482	79	23B
0005433057757	482	80	23D
0005434023783	482	81	24A
0005433057613	482	82	23H
0005432235644	482	83	24D
0005434023758	482	84	24G
0005434023799	482	85	24H
0005434023776	482	86	25E
0005433057491	482	87	25D
0005433684408	482	88	25F
0005434023764	482	89	27B
0005434023804	482	90	27D
0005433057492	482	91	27F
0005434023760	482	92	27E
0005434023782	482	93	27G
0005434023762	482	94	28D
0005434023814	482	95	28B
0005434023812	482	96	28F
0005433929576	482	97	28H
0005434023796	482	98	29A
0005434023779	482	99	29B
0005434023780	482	100	29E
0005434029658	482	101	29G
0005433057718	482	102	29H
0005433057697	482	103	30E
0005434023808	482	104	30G
0005434023787	482	105	31H
0005433057527	482	106	31G
0005433057759	482	107	32A
0005433057743	482	108	32B
0005433929577	482	109	32E
0005433057659	482	110	32D
0005434023781	482	111	32H
0005434023785	482	112	32G
0005434023773	482	113	33A
0005433929590	482	114	33B
0005434028297	482	115	33E
0005433057553	482	116	33D
0005434023771	482	117	33F
0005433684409	482	118	34B
0005434023817	482	119	34E
0005434023815	482	120	34H
0005434023752	482	121	35F
0005434023789	482	122	35E
0005434023805	482	123	36B
0005434023811	482	124	36E
0005434023751	482	125	37E
0005434023770	482	126	37G
0005433057686	482	127	37H
0005432235646	482	128	38A
0005434023755	482	129	38B
0005433057620	482	130	38G
0005434023769	482	131	38H
0005433057744	482	132	39F
0005434023756	482	133	39E
0005434023084	12646	1	1B
0005434023142	12646	2	1F
0005433057928	12646	3	2F
0005434023415	12646	4	2C
0005434735693	12646	5	2G
0005433057931	12646	6	2H
0005434023331	12646	7	3A
0005433057936	12646	8	3F
0005434023228	12646	9	4A
0005433057916	12646	10	4B
0005434022872	12646	11	4H
0005434023068	12646	12	5B
0005434023234	12646	13	5C
0005434023250	12646	14	5G
0005432156371	12646	15	5F
0005433057938	12646	16	9A
0005434023167	12646	17	5H
0005434023392	12646	18	9B
0005434023431	12646	19	9H
0005434031994	12646	20	9G
0005434023302	12646	21	11B
0005433057940	12646	22	12A
0005434735695	12646	23	12E
0005434023261	12646	24	12F
0005434023430	12646	25	13A
0005434735698	12646	26	13D
0005434023076	12646	27	13B
0005433057927	12646	28	14E
0005432157493	12646	29	14D
0005433057923	12646	30	15A
0005434023294	12646	31	15B
0005433057929	12646	32	15D
0005434023500	12646	33	15F
0005434028294	12646	34	15H
0005434023141	12646	35	15G
0005433057939	12646	36	16A
0005434028271	12646	37	16G
0005434023407	12646	38	16F
0005434023175	12646	39	16H
0005433057922	12646	40	17A
0005434031966	12646	41	17D
0005434735694	12646	42	17B
0005434023380	12646	43	17E
0005433057941	12646	44	17G
0005434029633	12646	45	17F
0005433057914	12646	46	17H
0005434023101	12646	47	18B
0005434023405	12646	48	18D
0005434031990	12646	49	18E
0005434023367	12646	50	19A
0005434023301	12646	51	19D
0005434023421	12646	52	19G
0005434022997	12646	53	19F
0005434023210	12646	54	19E
0005434022914	12646	55	20A
0005433684423	12646	56	20E
0005433057935	12646	57	20D
0005434023449	12646	58	20G
0005434029634	12646	59	21G
0005434023151	12646	60	21F
0005434023249	12646	61	21H
0005434028287	12646	62	22B
0005434023209	12646	63	22D
0005434023090	12646	64	22F
0005433929618	12646	65	22E
0005433057913	12646	66	22G
0005433057920	12646	67	23B
0005434023204	12646	68	23D
0005433057947	12646	69	23F
0005434023177	12646	70	23E
0005434023183	12646	71	23G
0005433929619	12646	72	23H
0005433057921	12646	73	24A
0005433057911	12646	74	24D
0005433057933	12646	75	24F
0005434023188	12646	76	24H
0005434735697	12646	77	25D
0005434023365	12646	78	27B
0005434022982	12646	79	27E
0005433057946	12646	80	27F
0005433684422	12646	81	27H
0005432156372	12646	82	27G
0005433057925	12646	83	28A
0005433057926	12646	84	28F
0005433057943	12646	85	29A
0005434022871	12646	86	29D
0005434023176	12646	87	29B
0005433057924	12646	88	29E
0005434023420	12646	89	29H
0005433057917	12646	90	29G
0005433057945	12646	91	30A
0005433057915	12646	92	30D
0005434023434	12646	93	30B
0005432156369	12646	94	30F
0005434023091	12646	95	31A
0005434023138	12646	96	30H
0005433057918	12646	97	31B
0005433929616	12646	98	31H
0005434023433	12646	99	31G
0005434023295	12646	100	32B
0005433057908	12646	101	32D
0005432157494	12646	102	33D
0005434023406	12646	103	33B
0005434023015	12646	104	33E
0005433057930	12646	105	33F
0005433929617	12646	106	34A
0005434023085	12646	107	34D
0005433057948	12646	108	34E
0005432156370	12646	109	34G
0005434023224	12646	110	34F
0005433057944	12646	111	35A
0005434023189	12646	112	34H
0005433057912	12646	113	35B
0005434023322	12646	114	35D
0005434023366	12646	115	35E
0005434029630	12646	116	35G
0005433057937	12646	117	35F
0005434031965	12646	118	36A
0005433057934	12646	119	36B
0005434023137	12646	120	36D
0005434023248	12646	121	36F
0005434023475	12646	122	36E
0005434029637	12646	123	36H
0005434023079	12646	124	36G
0005434031968	12646	125	37A
0005433057932	12646	126	37E
0005433057909	12646	127	37G
0005434023184	12646	128	38B
0005433057942	12646	129	38A
0005434735696	12646	130	37H
0005432156368	12646	131	38E
0005433057910	12646	132	38G
0005433057919	12646	133	39E
0005433035728	2127	1	1B
0005433036040	2127	2	1A
0005433923384	2127	3	1F
0005433923376	2127	4	1H
0005433923387	2127	5	1G
0005433923363	2127	6	2A
0005432044527	2127	7	2C
0005433923409	2127	8	2B
0005433036143	2127	9	2F
0005433923447	2127	10	2G
0005433923451	2127	11	3A
0005432044526	2127	12	2H
0005433923444	2127	13	3C
0005433035893	2127	14	3B
0005433923393	2127	15	3F
0005433923400	2127	16	3G
0005433035759	2127	17	4A
0005432044528	2127	18	4B
0005433923415	2127	19	4C
0005434028294	2127	20	4F
0005433923425	2127	21	4H
0005433035891	2127	22	5B
0005433923431	2127	23	5F
0005433923390	2127	24	5C
0005433923378	2127	25	5H
0005433923394	2127	26	9B
0005433923427	2127	27	9A
0005433035725	2127	28	9G
0005433923366	2127	29	11A
0005433035775	2127	30	9H
0005433035900	2127	31	11B
0005433035923	2127	32	11F
0005434028287	2127	33	11E
0005433923359	2127	34	11H
0005433923368	2127	35	11G
0005433923412	2127	36	12A
0005433923414	2127	37	12B
0005433931468	2127	38	12G
0005433035974	2127	39	12F
0005432231578	2127	40	13B
0005433923383	2127	41	13A
0005433036139	2127	42	13D
0005433035727	2127	43	13E
0005433875379	2127	44	13F
0005433923450	2127	45	13H
0005433923403	2127	46	13G
0005432231580	2127	47	14B
0005433923373	2127	48	14A
0005433923434	2127	49	14D
0005433035920	2127	50	14F
0005433035905	2127	51	14G
0005433035844	2127	52	15B
0005433036140	2127	53	15G
0005433923372	2127	54	15E
0005433923437	2127	55	15H
0005433035864	2127	56	16A
0005433923417	2127	57	16D
0005433923426	2127	58	16B
0005433036162	2127	59	16E
0005433035738	2127	60	16F
0005433923420	2127	61	16G
0005433923446	2127	62	17A
0005433035957	2127	63	17D
0005433929619	2127	64	17F
0005433923416	2127	65	17E
0005433923392	2127	66	17G
0005432231576	2127	67	17H
0005433923397	2127	68	18A
0005432231572	2127	69	18D
0005433923370	2127	70	18B
0005433923399	2127	71	18F
0005433923432	2127	72	18E
0005433923429	2127	73	18G
0005433923423	2127	74	19A
0005433923389	2127	75	18H
0005433923380	2127	76	19D
0005433923440	2127	77	19B
0005433923424	2127	78	19E
0005433036088	2127	79	20A
0005433923364	2127	80	19H
0005433923356	2127	81	20B
0005433923357	2127	82	20E
0005433923362	2127	83	20D
0005433035930	2127	84	20F
0005433923360	2127	85	20H
0005433035883	2127	86	20G
0005433923441	2127	87	21B
0005433036142	2127	88	21G
0005433929618	2127	89	21F
0005433923421	2127	90	21H
0005433036163	2127	91	22A
0005433035774	2127	92	22D
0005433923402	2127	93	22F
0005433036141	2127	94	22E
0005432231573	2127	95	22G
0005433923369	2127	96	22H
0005433035882	2127	97	23B
0005433035892	2127	98	23D
0005433035954	2127	99	23F
0005433923354	2127	100	23E
0005433035922	2127	101	23G
0005433035962	2127	102	23H
0005433923418	2127	103	24B
0005433035971	2127	104	24A
0005433036039	2127	105	24E
0005433035969	2127	106	24D
0005433923439	2127	107	24F
0005433923411	2127	108	24H
0005433036002	2127	109	24G
0005433923367	2127	110	25D
0005433923443	2127	111	25F
0005433923396	2127	112	25E
0005433035973	2127	113	27A
0005433035952	2127	114	27B
0005433923391	2127	115	27E
0005433923375	2127	116	27D
0005433931471	2127	117	27F
0005433923398	2127	118	27G
0005432231577	2127	119	28A
0005433923436	2127	120	27H
0005432231579	2127	121	28D
0005433035929	2127	122	28B
0005433923386	2127	123	28E
0005433035894	2127	124	28G
0005433036144	2127	125	28F
0005433923407	2127	126	28H
0005433035928	2127	127	29B
0005433923382	2127	128	29A
0005433923401	2127	129	29E
0005433923419	2127	130	29D
0005433923374	2127	131	29G
0005433923381	2127	132	30B
0005433035921	2127	133	30A
0005433035939	2127	134	30F
0005433923449	2127	135	30E
0005433923404	2127	136	30G
0005433035924	2127	137	31A
0005433923448	2127	138	30H
0005433923385	2127	139	31B
0005432231581	2127	140	31E
0005433035951	2127	141	31G
0005433923408	2127	142	31F
0005433923433	2127	143	32A
0005433923365	2127	144	32D
0005433931469	2127	145	32B
0005432231571	2127	146	32E
0005433923388	2127	147	32F
0005433923358	2127	148	32G
0005433036037	2127	149	33A
0005432231574	2127	150	32H
0005433036008	2127	151	33E
0005433035797	2127	152	33D
0005433036021	2127	153	33G
0005433036007	2127	154	33F
0005433929617	2127	155	33H
0005433923422	2127	156	34B
0005433875378	2127	157	34E
0005433923379	2127	158	34G
0005433923406	2127	159	34H
0005433923445	2127	160	35B
0005433036087	2127	161	35A
0005433035991	2127	162	35D
0005433036006	2127	163	35G
0005433923410	2127	164	35F
0005433923395	2127	165	35H
0005433923442	2127	166	36B
0005433923355	2127	167	36A
0005433923430	2127	168	36E
0005433035953	2127	169	36D
0005433036089	2127	170	36F
0005434028271	2127	171	36G
0005433923428	2127	172	37A
0005433035770	2127	173	36H
0005433923377	2127	174	37D
0005433036137	2127	175	37B
0005433923405	2127	176	37F
0005433035608	2127	177	37G
0005433923371	2127	178	38B
0005433035904	2127	179	38A
0005433036138	2127	180	37H
0005433923438	2127	181	38D
0005433931470	2127	182	38E
0005433923361	2127	183	38F
0005433923413	2127	184	38H
0005432231575	2127	185	38G
0005433923435	2127	186	39E
0005433929616	2127	187	39D
0005433035958	2127	188	39F
0005433036335	24130	1	1A
0005433922314	24130	2	1B
0005433922530	24130	3	1F
0005433922853	24130	4	1C
0005433036344	24130	5	1H
0005433922323	24130	6	1G
0005433931430	24130	7	2A
0005433922310	24130	8	2C
0005433036380	24130	9	2B
0005432206199	24130	10	2F
0005433036329	24130	11	2H
0005433922553	24130	12	2G
0005433922929	24130	13	3B
0005432206204	24130	14	3A
0005433922536	24130	15	3F
0005433922760	24130	16	3C
0005433036370	24130	17	3H
0005432749788	24130	18	3G
0005433922866	24130	19	4A
0005433922928	24130	20	4B
0005433922554	24130	21	4G
0005433922438	24130	22	4F
0005433922609	24130	23	4H
0005433922918	24130	24	5B
0005433036334	24130	25	5F
0005433036364	24130	26	9A
0005433036374	24130	27	5H
0005433036333	24130	28	9B
0005433922552	24130	29	9H
0005433036347	24130	30	9G
0005433922681	24130	31	11B
0005433922924	24130	32	11A
0005433922985	24130	33	11E
0005433036353	24130	34	11F
0005433922749	24130	35	11H
0005432206201	24130	36	11G
0005433036367	24130	37	12A
0005433922835	24130	38	12B
0005433922555	24130	39	12E
0005433036343	24130	40	12D
0005433922671	24130	41	12H
0005433922763	24130	42	12G
0005433922816	24130	43	13B
0005433922608	24130	44	13A
0005433922742	24130	45	13D
0005433922678	24130	46	13F
0005433922316	24130	47	13E
0005433922736	24130	48	13H
0005433036363	24130	49	14B
0005433922592	24130	50	14F
0005433922551	24130	51	14E
0005433922743	24130	52	14G
0005433036368	24130	53	15B
0005433036378	24130	54	15E
0005433036375	24130	55	15D
0005433922655	24130	56	15F
0005433922864	24130	57	15G
0005433922919	24130	58	16A
0005433036371	24130	59	15H
0005433922476	24130	60	16D
0005433036376	24130	61	16B
0005433922311	24130	62	16E
0005433922251	24130	63	16G
0005433922240	24130	64	16F
0005433036342	24130	65	16H
0005432206203	24130	66	17B
0005433922786	24130	67	17A
0005433929581	24130	68	17D
0005433922996	24130	69	17E
0005432206202	24130	70	17F
0005433036351	24130	71	18A
0005433036340	24130	72	17H
0005433036359	24130	73	18D
0005432749787	24130	74	18B
0005433036338	24130	75	18E
0005433922805	24130	76	18G
0005433922761	24130	77	18H
0005433036357	24130	78	19B
0005433922664	24130	79	19E
0005433036356	24130	80	19D
0005433922101	24130	81	19F
0005433036354	24130	82	19H
0005433036332	24130	83	20A
0005433922317	24130	84	20E
0005433036365	24130	85	20F
0005433923035	24130	86	20H
0005433922679	24130	87	20G
0005433922836	24130	88	21E
0005433036339	24130	89	21G
0005433922755	24130	90	21F
0005433922670	24130	91	21H
0005433922797	24130	92	22A
0005433922633	24130	93	22D
0005433922388	24130	94	22E
0005432207664	24130	95	22H
0005433036366	24130	96	22G
0005433923039	24130	97	23B
0005433922737	24130	98	23A
0005433036330	24130	99	23E
0005433929607	24130	100	23D
0005433036381	24130	101	23F
0005433922676	24130	102	23G
0005433929606	24130	103	23H
0005433036345	24130	104	24E
0005433929587	24130	105	24D
0005433929585	24130	106	24F
0005433922815	24130	107	24G
0005433036350	24130	108	25D
0005433036362	24130	109	25E
0005433929586	24130	110	27A
0005433931435	24130	111	25F
0005433922595	24130	112	27B
0005433036331	24130	113	27E
0005433922865	24130	114	27D
0005433036341	24130	115	27F
0005433036358	24130	116	27G
0005433923036	24130	117	28A
0005433931439	24130	118	27H
0005433922464	24130	119	28B
0005433922313	24130	120	28E
0005434028298	24130	121	28D
0005433922100	24130	122	28F
0005433036373	24130	123	29A
0005433036352	24130	124	28H
0005433922668	24130	125	29E
0005433922395	24130	126	29G
0005433922762	24130	127	29F
0005433922807	24130	128	29H
0005433036346	24130	129	30B
0005433036337	24130	130	30A
0005433922653	24130	131	30D
0005433922796	24130	132	30F
0005433922635	24130	133	30G
0005434028301	24130	134	31A
0005432206200	24130	135	30H
0005433922748	24130	136	31B
0005433036355	24130	137	31D
0005433922794	24130	138	31F
0005433036377	24130	139	32A
0005433922312	24130	140	31H
0005433922654	24130	141	32B
0005433922750	24130	142	32E
0005433922862	24130	143	32D
0005433922463	24130	144	32G
0005433922667	24130	145	32H
0005433922756	24130	146	33A
0005434028300	24130	147	33B
0005434028299	24130	148	33D
0005433922785	24130	149	33G
0005433922634	24130	150	33F
0005433036379	24130	151	34D
0005432207665	24130	152	34F
0005433036348	24130	153	34E
0005433929570	24130	154	34G
0005433931434	24130	155	34H
0005433922584	24130	156	35D
0005433036336	24130	157	35F
0005433922710	24130	158	35E
0005433036361	24130	159	35G
0005433922688	24130	160	36A
0005433922709	24130	161	35H
0005433922585	24130	162	36B
0005433922806	24130	163	36F
0005433922769	24130	164	36E
0005433036372	24130	165	36G
0005433922590	24130	166	36H
0005433922241	24130	167	37B
0005433922387	24130	168	37A
0005433036369	24130	169	37D
0005433922768	24130	170	37H
0005433036360	24130	171	37G
0005433922793	24130	172	38B
0005433922575	24130	173	38A
0005433922980	24130	174	38D
0005433922687	24130	175	38E
0005433922591	24130	176	38G
0005433922439	24130	177	38F
0005433922379	24130	178	38H
0005433922726	24130	179	39D
0005433922727	24130	180	39F
0005433036349	24130	181	39E
0005433180919	275	1	1C
0005434725658	275	2	1A
0005433233812	275	3	1G
0005433233707	275	4	1D
0005433126807	275	5	1K
0005434725554	275	6	2D
0005434725541	275	7	2C
0005433233820	275	8	2A
0005433180776	275	9	2H
0005434551321	275	10	2G
0005434551290	275	11	3A
0005433233825	275	12	2K
0005434725619	275	13	3G
0005434725559	275	14	3D
0005434725574	275	15	3C
0005433180926	275	16	3H
0005434725553	275	17	4C
0005434735689	275	18	4A
0005433289770	275	19	4G
0005434551306	275	20	4D
0005432277818	275	21	4K
0005433113523	275	22	5D
0005434725549	275	23	5C
0005433234022	275	24	5A
0005434725657	275	25	5G
0005433113514	275	26	11A
0005434725583	275	27	5K
0005434725639	275	28	11D
0005433180879	275	29	11C
0005435142590	275	30	11F
0005434725602	275	31	11E
0005434551310	275	32	11K
0005434731172	275	33	11H
0005434551322	275	34	11G
0005434551285	275	35	12C
0005433233849	275	36	12A
0005435142595	275	37	12F
0005434725542	275	38	12E
0005433180903	275	39	12K
0005434725547	275	40	12H
0005434551278	275	41	13D
0005433233899	275	42	13C
0005434725661	275	43	13A
0005432277820	275	44	13F
0005434302465	275	45	13E
0005433233893	275	46	13H
0005433233959	275	47	13G
0005433233648	275	48	14D
0005433233708	275	49	14C
0005434725644	275	50	14G
0005434551298	275	51	14F
0005434725576	275	52	14E
0005433289791	275	53	14K
0005434551274	275	54	14H
0005434725563	275	55	15A
0005433233937	275	56	15E
0005434725616	275	57	15D
0005434725605	275	58	15F
0005434725647	275	59	15K
0005433233850	275	60	16D
0005432277825	275	61	16C
0005434725603	275	62	16F
0005433233791	275	63	16E
0005434725590	275	64	16H
0005434551293	275	65	16G
0005433233676	275	66	17A
0005434725650	275	67	16K
0005434725585	275	68	17E
0005433180957	275	69	17D
0005434725663	275	70	17H
0005434551283	275	71	17F
0005433233701	275	72	17K
0005434725653	275	73	18C
0005434551303	275	74	18B
0005434551291	275	75	18A
0005433233699	275	76	18E
0005433180909	275	77	18G
0005432277821	275	78	18F
0005435142589	275	79	18K
0005433233703	275	80	18J
0005433180942	275	81	18H
0005433233378	275	82	19B
0005432277817	275	83	19A
0005433233377	275	84	19D
0005433289798	275	85	19C
0005433113515	275	86	19F
0005434725645	275	87	19E
0005434725594	275	88	19H
0005434725591	275	89	20A
0005433233698	275	90	19K
0005433233524	275	91	20C
0005434725625	275	92	20E
0005434725624	275	93	20G
0005434725557	275	94	20F
0005435142585	275	95	20H
0005435142593	275	96	21A
0005434551320	275	97	21D
0005434551319	275	98	21C
0005434551315	275	99	21F
0005434725600	275	100	21E
0005434725556	275	101	21H
0005434725604	275	102	21G
0005433233938	275	103	21J
0005433766612	275	104	22C
0005434725551	275	105	22B
0005433233490	275	106	22F
0005434725656	275	107	22E
0005434551307	275	108	22D
0005434725648	275	109	22K
0005433233743	275	110	23B
0005434725569	275	111	23A
0005434725633	275	112	23D
0005434302463	275	113	23C
0005433233485	275	114	23F
0005433113516	275	115	23H
0005434731173	275	116	23G
0005433289769	275	117	24D
0005433111493	275	118	23K
0005434725620	275	119	24G
0005434725601	275	120	24F
0005434551268	275	121	24E
0005434725643	275	122	25B
0005434725582	275	123	25A
0005434725621	275	124	25C
0005433233694	275	125	25E
0005433233662	275	126	25H
0005433289792	275	127	25G
0005434725567	275	128	25J
0005434725622	275	129	26C
0005434551317	275	130	26B
0005434725610	275	131	26A
0005433233738	275	132	26D
0005434551276	275	133	26H
0005434725548	275	134	26F
0005434551292	275	135	26J
0005432277829	275	136	27B
0005433233847	275	137	27A
0005434725614	275	138	26K
0005434725655	275	139	27D
0005433233797	275	140	27C
0005434302462	275	141	27F
0005434725588	275	142	27E
0005433233775	275	143	27H
0005434725558	275	144	27G
0005434551281	275	145	27K
0005434551284	275	146	28B
0005433180987	275	147	28A
0005434551279	275	148	28E
0005433234144	275	149	28D
0005432277822	275	150	28C
0005434725568	275	151	28G
0005433289801	275	152	28F
0005433233957	275	153	28K
0005433233796	275	154	28J
0005434551305	275	155	28H
0005434725649	275	156	29B
0005433233204	275	157	29A
0005435142587	275	158	29D
0005433113513	275	159	29C
0005434725546	275	160	29F
0005433233826	275	161	29E
0005434725577	275	162	29H
0005434725592	275	163	29G
0005434725662	275	164	29J
0005434725641	275	165	30B
0005434031983	275	166	30A
0005432277826	275	167	30E
0005434725637	275	168	30D
0005434725664	275	169	30C
0005434725565	275	170	30G
0005434551277	275	171	30J
0005434725595	275	172	30H
0005434551300	275	173	31B
0005434551275	275	174	31A
0005434725640	275	175	30K
0005433234038	275	176	31D
0005434725584	275	177	31C
0005434735691	275	178	31F
0005433180866	275	179	31E
0005433233636	275	180	31H
0005434725564	275	181	31K
0005434725646	275	182	31J
0005434725545	275	183	32C
0005434725634	275	184	32B
0005434551273	275	185	32A
0005433234037	275	186	32E
0005434731169	275	187	32D
0005434725632	275	188	32H
0005434551304	275	189	32G
0005432277827	275	190	32F
0005434551314	275	191	33B
0005434725575	275	192	33A
0005434725571	275	193	32K
0005432277823	275	194	33D
0005433180887	275	195	33C
0005435142591	275	196	33F
0005434725597	275	197	33J
0005434725660	275	198	33H
0005434551288	275	199	33G
0005434551316	275	200	34A
0005434725608	275	201	33K
0005434725544	275	202	34B
0005434731170	275	203	34E
0005433180980	275	204	34D
0005434725615	275	205	34G
0005434551286	275	206	34F
0005434551312	275	207	34K
0005433233539	275	208	34J
0005434725543	275	209	35B
0005434551289	275	210	35A
0005433111494	275	211	35D
0005435142598	275	212	35C
0005435142592	275	213	35F
0005434725578	275	214	35E
0005434551280	275	215	35H
0005434725613	275	216	35G
0005434551297	275	217	36A
0005433233936	275	218	35K
0005434725651	275	219	35J
0005435142596	275	220	36C
0005434725606	275	221	36E
0005434725555	275	222	36H
0005433180802	275	223	36G
0005434725586	275	224	36F
0005434725607	275	225	36K
0005433233737	275	226	36J
0005434725570	275	227	37B
0005433180904	275	228	37A
0005434731171	275	229	37D
0005433131665	275	230	37F
0005434551271	275	231	37E
0005433180956	275	232	37H
0005433233744	275	233	38A
0005434551282	275	234	37K
0005434735690	275	235	37J
0005433180944	275	236	38B
0005434725579	275	237	38J
0005434725617	275	238	39B
0005434551318	275	239	38K
0005433111495	275	240	39C
0005434725580	275	241	39F
0005434725572	275	242	39E
0005433233540	275	243	39H
0005433233939	275	244	39G
0005434725612	275	245	39K
0005434725552	275	246	39J
0005434725561	275	247	40C
0005433233663	275	248	40B
0005434725598	275	249	40E
0005435142597	275	250	40D
0005433233758	275	251	40H
0005434551294	275	252	40J
0005434725654	275	253	41B
0005433131664	275	254	41F
0005433180744	275	255	41E
0005433233675	275	256	41H
0005433233649	275	257	41G
0005434735692	275	258	41K
0005433233790	275	259	42C
0005433126813	275	260	42B
0005432277824	275	261	42E
0005434725623	275	262	42D
0005434725599	275	263	42G
0005434725609	275	264	42K
0005434725611	275	265	42J
0005435142586	275	266	43B
0005433233426	275	267	43D
0005434725630	275	268	43C
0005434551296	275	269	43F
0005434302464	275	270	43H
0005434725560	275	271	43G
0005433233700	275	272	44A
0005434551269	275	273	43K
0005433233819	275	274	44C
0005434725629	275	275	44B
0005433180947	275	276	44E
0005434551311	275	277	44D
0005434031981	275	278	44G
0005434725638	275	279	44F
0005434551299	275	280	44K
0005434551323	275	281	44H
0005434551309	275	282	45B
0005434725652	275	283	45A
0005434725589	275	284	45C
0005433180888	275	285	45F
0005433233523	275	286	45E
0005434725631	275	287	45D
0005433233489	275	288	45H
0005433126808	275	289	45G
0005434725635	275	290	46A
0005434725618	275	291	45K
0005434031982	275	292	45J
0005433111492	275	293	46B
0005432277819	275	294	46D
0005433180745	275	295	46C
0005433180902	275	296	46G
0005434551295	275	297	46J
0005434725642	275	298	46H
0005434735688	275	299	47C
0005433233429	275	300	47A
0005433233958	275	301	46K
0005434725581	275	302	47E
0005434725566	275	303	47D
0005434551287	275	304	47G
0005435142588	275	305	47F
0005434551308	275	306	47K
0005434725628	275	307	48C
0005433180961	275	308	48A
0005434725626	275	309	48F
0005434551270	275	310	48D
0005434725550	275	311	48H
0005433233693	275	312	48G
0005434725627	275	313	49A
0005434725659	275	314	48K
0005433233846	275	315	49E
0005434551313	275	316	49D
0005434725562	275	317	49C
0005432277828	275	318	49F
0005434551272	275	319	49K
0005434725587	275	320	49H
0005435142594	275	321	50C
0005434551301	275	322	50A
0005434551302	275	323	50E
0005434302466	275	324	50D
0005434725573	275	325	50G
0005434725636	275	326	50F
0005434725596	275	327	50H
0005434725593	275	328	51F
0005433180848	275	329	51G
0005434724452	9853	1	1C
0005434724014	9853	2	1A
0005434550619	9853	3	1D
0005434550632	9853	4	1K
0005434724783	9853	5	1H
0005434550846	9853	6	2C
0005435142410	9853	7	2A
0005434724617	9853	8	2H
0005434724628	9853	9	2G
0005435142452	9853	10	2D
0005434550661	9853	11	2K
0005434550782	9853	12	3D
0005434724339	9853	13	3C
0005435142474	9853	14	3K
0005435142409	9853	15	3H
0005433289857	9853	16	4A
0005433181130	9853	17	4D
0005434723985	9853	18	4K
0005434724728	9853	19	4H
0005434724506	9853	20	5C
0005433181132	9853	21	5H
0005434724466	9853	22	5G
0005434724505	9853	23	5D
0005434550767	9853	24	11A
0005434550485	9853	25	5K
0005432199258	9853	26	11D
0005433234251	9853	27	11C
0005434725292	9853	28	11F
0005434550707	9853	29	11K
0005433234301	9853	30	11H
0005433234293	9853	31	12C
0005434723986	9853	32	12A
0005434302406	9853	33	12E
0005434550620	9853	34	12G
0005433234276	9853	35	12F
0005433181127	9853	36	12K
0005435142489	9853	37	12H
0005433234290	9853	38	13D
0005434550840	9853	39	13A
0005433181138	9853	40	13F
0005433766645	9853	41	13E
0005434550746	9853	42	13K
0005433234303	9853	43	13G
0005434724639	9853	44	14D
0005433234255	9853	45	14G
0005433234272	9853	46	14F
0005434724644	9853	47	14E
0005434550518	9853	48	14K
0005433234296	9853	49	14H
0005433234273	9853	50	15C
0005433234268	9853	51	15F
0005433289855	9853	52	15H
0005434724926	9853	53	16A
0005434724300	9853	54	15K
0005434724474	9853	55	16D
0005433181131	9853	56	16C
0005433234287	9853	57	16F
0005433234295	9853	58	16E
0005434724614	9853	59	16H
0005434724329	9853	60	16G
0005435142500	9853	61	17C
0005433234289	9853	62	17A
0005434550703	9853	63	16K
0005433234288	9853	64	17E
0005434724428	9853	65	17D
0005434550933	9853	66	17G
0005433181122	9853	67	17F
0005433234244	9853	68	17K
0005434724747	9853	69	17H
0005434725018	9853	70	18C
0005434550858	9853	71	18A
0005434724606	9853	72	18E
0005433234298	9853	73	18D
0005433766642	9853	74	18G
0005434550826	9853	75	18F
0005434724180	9853	76	18H
0005434550836	9853	77	19B
0005435142411	9853	78	19A
0005433289852	9853	79	19D
0005433181123	9853	80	19C
0005434724088	9853	81	19F
0005434550844	9853	82	19E
0005433234300	9853	83	19G
0005435142444	9853	84	20A
0005434724888	9853	85	19K
0005434724786	9853	86	20C
0005433181115	9853	87	20B
0005433234302	9853	88	20E
0005433113537	9853	89	20D
0005434724846	9853	90	20H
0005433766644	9853	91	20G
0005433289853	9853	92	20F
0005434724636	9853	93	20K
0005433234252	9853	94	21B
0005434302411	9853	95	21A
0005433234270	9853	96	21D
0005433234260	9853	97	21C
0005434724501	9853	98	21G
0005434724692	9853	99	21F
0005433234284	9853	100	21J
0005433234281	9853	101	21K
0005433234243	9853	102	22B
0005434724475	9853	103	22E
0005433181118	9853	104	22G
0005435142459	9853	105	22F
0005433234292	9853	106	22J
0005434724535	9853	107	23B
0005434724473	9853	108	23A
0005434724527	9853	109	23E
0005433234258	9853	110	23D
0005434724845	9853	111	23C
0005434724338	9853	112	23G
0005433234297	9853	113	23F
0005433234245	9853	114	23J
0005433181129	9853	115	23H
0005433234278	9853	116	24D
0005434550747	9853	117	24F
0005434724493	9853	118	25A
0005434724465	9853	119	24G
0005435142458	9853	120	25C
0005434550976	9853	121	25E
0005433234294	9853	122	25D
0005434724596	9853	123	25H
0005434724425	9853	124	25G
0005434724743	9853	125	25K
0005434735645	9853	126	25J
0005433289856	9853	127	26C
0005434724248	9853	128	26B
0005433234279	9853	129	26A
0005434550818	9853	130	26E
0005434735619	9853	131	26D
0005434724796	9853	132	26H
0005433234240	9853	133	26G
0005434725019	9853	134	26F
0005434550817	9853	135	26J
0005434550763	9853	136	26K
0005433234275	9853	137	27C
0005433181125	9853	138	27B
0005432199253	9853	139	27F
0005433289854	9853	140	27E
0005433234242	9853	141	27H
0005434724764	9853	142	27G
0005433181119	9853	143	28A
0005433129281	9853	144	27K
0005434550531	9853	145	27J
0005433234263	9853	146	28B
0005434724755	9853	147	28E
0005433234266	9853	148	28C
0005434550627	9853	149	28G
0005434550837	9853	150	28F
0005434550906	9853	151	28H
0005433181113	9853	152	29B
0005434724716	9853	153	29D
0005434724656	9853	154	29C
0005434550841	9853	155	29F
0005434724388	9853	156	29E
0005434302405	9853	157	29J
0005435142496	9853	158	29G
0005433126849	9853	159	29K
0005433126850	9853	160	30C
0005434550872	9853	161	30B
0005433181126	9853	162	30A
0005434724317	9853	163	30E
0005433234256	9853	164	30D
0005434032028	9853	165	30G
0005433234254	9853	166	30J
0005434032029	9853	167	31A
0005433181133	9853	168	30K
0005434724249	9853	169	31D
0005434724477	9853	170	31C
0005433234250	9853	171	31G
0005434724502	9853	172	31F
0005434550554	9853	173	31E
0005433234283	9853	174	31H
0005434724453	9853	175	32A
0005434724553	9853	176	31K
0005434724590	9853	177	31J
0005434550699	9853	178	32C
0005434724164	9853	179	32B
0005433234246	9853	180	32E
0005434550643	9853	181	32D
0005434724774	9853	182	32G
0005434724768	9853	183	32F
0005434724013	9853	184	32J
0005433234248	9853	185	32H
0005434724542	9853	186	33A
0005434724419	9853	187	32K
0005433234257	9853	188	33D
0005434724797	9853	189	33C
0005435142447	9853	190	33E
0005434735639	9853	191	33J
0005434724757	9853	192	33H
0005433234274	9853	193	33G
0005432199254	9853	194	34A
0005434724595	9853	195	33K
0005433234262	9853	196	34B
0005434550824	9853	197	34E
0005434735618	9853	198	34C
0005434724693	9853	199	34G
0005433126851	9853	200	34F
0005435142435	9853	201	34J
0005433181121	9853	202	34H
0005434724584	9853	203	35B
0005434550697	9853	204	35A
0005434724522	9853	205	34K
0005434550903	9853	206	35D
0005433766646	9853	207	35C
0005434724748	9853	208	35G
0005434032031	9853	209	35F
0005434550631	9853	210	35E
0005434724434	9853	211	35H
0005434724769	9853	212	35J
0005434724433	9853	213	36D
0005434735640	9853	214	36C
0005433126848	9853	215	36B
0005433181116	9853	216	36A
0005433234259	9853	217	36F
0005434724727	9853	218	36E
0005433234277	9853	219	36H
0005434723961	9853	220	36G
0005433234267	9853	221	36K
0005433234291	9853	222	36J
0005435142414	9853	223	37B
0005434724511	9853	224	37A
0005434550860	9853	225	37D
0005434550907	9853	226	37C
0005434550639	9853	227	37G
0005435142477	9853	228	37F
0005434724744	9853	229	37J
0005434724781	9853	230	37H
0005433289851	9853	231	37K
0005432199257	9853	232	38H
0005435142441	9853	233	38C
0005434724785	9853	234	38B
0005434550486	9853	235	38K
0005434724429	9853	236	38J
0005434735646	9853	237	39A
0005434550530	9853	238	39C
0005432199256	9853	239	39B
0005433181128	9853	240	39F
0005434724758	9853	241	39E
0005433234271	9853	242	39J
0005434724424	9853	243	39H
0005434550825	9853	244	40A
0005434724668	9853	245	39K
0005435142442	9853	246	40C
0005433234253	9853	247	40E
0005434724116	9853	248	40D
0005434724645	9853	249	40G
0005434724295	9853	250	40F
0005433129280	9853	251	40J
0005434550517	9853	252	40H
0005434724865	9853	253	41B
0005434724604	9853	254	40K
0005434724821	9853	255	41D
0005433234247	9853	256	41F
0005433289858	9853	257	41E
0005435142415	9853	258	41H
0005434724554	9853	259	41K
0005433113538	9853	260	41J
0005434724822	9853	261	42C
0005434725161	9853	262	42B
0005434550884	9853	263	42E
0005434725025	9853	264	42D
0005433181120	9853	265	42H
0005432199255	9853	266	42G
0005435142491	9853	267	43A
0005435142476	9853	268	42K
0005433129279	9853	269	43D
0005433129278	9853	270	43F
0005434724835	9853	271	43E
0005433234286	9853	272	43J
0005433181114	9853	273	43H
0005433181117	9853	274	43G
0005435142490	9853	275	44A
0005433234282	9853	276	43K
0005434724343	9853	277	44C
0005434724726	9853	278	44B
0005433234269	9853	279	44E
0005434550857	9853	280	44D
0005434724022	9853	281	44G
0005433234241	9853	282	44K
0005433181124	9853	283	44J
0005434724947	9853	284	45B
0005433181134	9853	285	45C
0005434302432	9853	286	45E
0005434724492	9853	287	45D
0005434724407	9853	288	45H
0005434724271	9853	289	45G
0005434550885	9853	290	46A
0005435142457	9853	291	45K
0005434724775	9853	292	45J
0005433234299	9853	293	46B
0005434731132	9853	294	46E
0005434032030	9853	295	46D
0005433289850	9853	296	46H
0005434724878	9853	297	46G
0005433181137	9853	298	46F
0005434725011	9853	299	46J
0005433766643	9853	300	47A
0005434550805	9853	301	47E
0005434724618	9853	302	47D
0005433181136	9853	303	47C
0005434550987	9853	304	47G
0005434724866	9853	305	47F
0005434550723	9853	306	47K
0005434550700	9853	307	47H
0005434724507	9853	308	48C
0005433234265	9853	309	48A
0005433234249	9853	310	48F
0005433234280	9853	311	48E
0005435142475	9853	312	48D
0005434724328	9853	313	48G
0005434550816	9853	314	49A
0005434724528	9853	315	48K
0005434725038	9853	316	49D
0005434550685	9853	317	49C
0005434032032	9853	318	49H
0005433181135	9853	319	49G
0005433234264	9853	320	50D
0005434724707	9853	321	50C
0005433234285	9853	322	50A
0005434550768	9853	323	50G
0005434550776	9853	324	50F
0005434724235	9853	325	50K
0005434550845	9853	326	50H
0005435142453	9853	327	51E
0005433234261	9853	328	51G
0005432528084	7772	1	1D
0005435213207	7772	2	1C
0005432150206	7772	3	1A
0005435212908	7772	4	1H
0005434067619	7772	5	2D
0005432528140	7772	6	2A
0005434067608	7772	7	2H
0005435630946	7772	8	2G
0005435213058	7772	9	3A
0005432528153	7772	10	2K
0005432528175	7772	11	3D
0005432528072	7772	12	3K
0005435212859	7772	13	3H
0005432528136	7772	14	4A
0005435212968	7772	15	4D
0005434067610	7772	16	4C
0005434067635	7772	17	4K
0005434067607	7772	18	4H
0005432528160	7772	19	5D
0005432528139	7772	20	5A
0005432528085	7772	21	5H
0005432528088	7772	22	11A
0005435725548	7772	23	5K
0005432528171	7772	24	11D
0005432528173	7772	25	11C
0005435212985	7772	26	11F
0005434067647	7772	27	11E
0005435213173	7772	28	11H
0005432528138	7772	29	12C
0005434067657	7772	30	12A
0005435630947	7772	31	12E
0005435213121	7772	32	12D
0005435212876	7772	33	12G
0005435213217	7772	34	13A
0005432528081	7772	35	12K
0005432528125	7772	36	12H
0005435213122	7772	37	13D
0005432528162	7772	38	13C
0005432528092	7772	39	13F
0005432069667	7772	40	13E
0005432528181	7772	41	13H
0005435212925	7772	42	13G
0005432528051	7772	43	14C
0005434067627	7772	44	14A
0005432069676	7772	45	14D
0005434067672	7772	46	14E
0005432528070	7772	47	14K
0005432150203	7772	48	14H
0005435212886	7772	49	14G
0005435212875	7772	50	15C
0005435213102	7772	51	15A
0005435213170	7772	52	15F
0005435725550	7772	53	15E
0005434067645	7772	54	15D
0005434067636	7772	55	16A
0005435213188	7772	56	15H
0005432528176	7772	57	16D
0005432528053	7772	58	16F
0005434067646	7772	59	16E
0005432069665	7772	60	16H
0005434067662	7772	61	17C
0005434067628	7772	62	16K
0005435213172	7772	63	17E
0005432528120	7772	64	17D
0005434067625	7772	65	17G
0005434067652	7772	66	17F
0005434067658	7772	67	17K
0005432528109	7772	68	17H
0005434067603	7772	69	18B
0005432528094	7772	70	18A
0005432528112	7772	71	18E
0005432150202	7772	72	18D
0005435212924	7772	73	18C
0005432069663	7772	74	18F
0005432528169	7772	75	18K
0005434067665	7772	76	18J
0005432528074	7772	77	18H
0005434067634	7772	78	19B
0005434067626	7772	79	19A
0005434067643	7772	80	19D
0005432528087	7772	81	19F
0005432537060	7772	82	19E
0005432535840	7772	83	19J
0005434067674	7772	84	19H
0005432528080	7772	85	20A
0005434067606	7772	86	19K
0005435213434	7772	87	20C
0005432528106	7772	88	20B
0005434067667	7772	89	20E
0005435725565	7772	90	20D
0005432069675	7772	91	20G
0005434067638	7772	92	20F
0005432528060	7772	93	20K
0005435213243	7772	94	20J
0005434067675	7772	95	20H
0005434067653	7772	96	21D
0005435212922	7772	97	21C
0005434067629	7772	98	21G
0005432528143	7772	99	21F
0005432528058	7772	100	21H
0005432150201	7772	101	22A
0005432069669	7772	102	21K
0005432528062	7772	103	22C
0005435212858	7772	104	22B
0005435213208	7772	105	22D
0005435212947	7772	106	22G
0005434067654	7772	107	22F
0005435213147	7772	108	22J
0005432528089	7772	109	22H
0005434067666	7772	110	23B
0005434067632	7772	111	23A
0005432528069	7772	112	23D
0005432528129	7772	113	23C
0005435212874	7772	114	23G
0005435213300	7772	115	23F
0005432528182	7772	116	23J
0005432528163	7772	117	24D
0005435212996	7772	118	23K
0005432528048	7772	119	24F
0005432528170	7772	120	25A
0005432428933	7772	121	24G
0005434067651	7772	122	25D
0005432528049	7772	123	25C
0005432528071	7772	124	25B
0005435725556	7772	125	25E
0005432528117	7772	126	25H
0005432528111	7772	127	25G
0005432528078	7772	128	26A
0005434067650	7772	129	25K
0005434067644	7772	130	25J
0005432528097	7772	131	26B
0005432528179	7772	132	26E
0005432069673	7772	133	26D
0005434067663	7772	134	26G
0005432528167	7772	135	26J
0005432528127	7772	136	26H
0005432528133	7772	137	27A
0005434067604	7772	138	26K
0005432528180	7772	139	27D
0005434067623	7772	140	27C
0005435212907	7772	141	27F
0005432528126	7772	142	27E
0005432528137	7772	143	27G
0005432528118	7772	144	27K
0005432537059	7772	145	27J
0005434067649	7772	146	28B
0005432528063	7772	147	28A
0005435212997	7772	148	28E
0005432528114	7772	149	28D
0005432528159	7772	150	28F
0005432528110	7772	151	28J
0005432528107	7772	152	28H
0005434067614	7772	153	29A
0005435213014	7772	154	28K
0005432528157	7772	155	29D
0005432533293	7772	156	29C
0005432528054	7772	157	29F
0005432535838	7772	158	29E
0005435213171	7772	159	29H
0005433656635	7772	160	29G
0005434067637	7772	161	29K
0005432069668	7772	162	30C
0005434067615	7772	163	30B
0005432528141	7772	164	30A
0005432528121	7772	165	30E
0005432069672	7772	166	30G
0005435213133	7772	167	30F
0005434067664	7772	168	30J
0005432150204	7772	169	30H
0005432528142	7772	170	31B
0005432528177	7772	171	31A
0005432069671	7772	172	30K
0005432528055	7772	173	31D
0005432528161	7772	174	31C
0005432428930	7772	175	31F
0005435212923	7772	176	31E
0005432428932	7772	177	31H
0005432069664	7772	178	32A
0005432428934	7772	179	31K
0005432069674	7772	180	31J
0005432528149	7772	181	32C
0005432528050	7772	182	32B
0005434067630	7772	183	32D
0005432528119	7772	184	32G
0005433656636	7772	185	32F
0005432528068	7772	186	32K
0005435212906	7772	187	32J
0005435213015	7772	188	32H
0005432428931	7772	189	33A
0005432528164	7772	190	33D
0005432528151	7772	191	33C
0005432528056	7772	192	33B
0005434067640	7772	193	33G
0005432069670	7772	194	33F
0005432528083	7772	195	33E
0005435213025	7772	196	33H
0005435213215	7772	197	34A
0005432528132	7772	198	33J
0005432528095	7772	199	34C
0005434067668	7772	200	34B
0005435213187	7772	201	34D
0005432150205	7772	202	34F
0005432528128	7772	203	34K
0005432528101	7772	204	35A
0005432528100	7772	205	35D
0005434067656	7772	206	35B
0005435213146	7772	207	35G
0005432528116	7772	208	35F
0005434067624	7772	209	35E
0005432528145	7772	210	36A
0005435212826	7772	211	35K
0005434067605	7772	212	36C
0005432528052	7772	213	36E
0005432528061	7772	214	36H
0005434067621	7772	215	36F
0005432528148	7772	216	36K
0005434067609	7772	217	37A
0005434067639	7772	218	37D
0005434067613	7772	219	37C
0005432533294	7772	220	37F
0005434067648	7772	221	37E
0005432528057	7772	222	37J
0005432528135	7772	223	37H
0005432528099	7772	224	38A
0005434067617	7772	225	37K
0005432528086	7772	226	38C
0005432528174	7772	227	38B
0005432528076	7772	228	38J
0005432528115	7772	229	38H
0005432150200	7772	230	39D
0005432528130	7772	231	39C
0005432528144	7772	232	39B
0005434067631	7772	233	39E
0005435725564	7772	234	39J
0005434067661	7772	235	39H
0005435213057	7772	236	39G
0005435725557	7772	237	39K
0005432528168	7772	238	40C
0005435630945	7772	239	40B
0005432528183	7772	240	40E
0005432528123	7772	241	40D
0005432528091	7772	242	40F
0005435213216	7772	243	40K
0005434067669	7772	244	40J
0005435213033	7772	245	40H
0005432528134	7772	246	41A
0005432528067	7772	247	41D
0005434067611	7772	248	41C
0005432528166	7772	249	41F
0005435212926	7772	250	41H
0005432533296	7772	251	41G
0005435212833	7772	252	42A
0005435212963	7772	253	41K
0005432528102	7772	254	41J
0005434067673	7772	255	42C
0005434067620	7772	256	42B
0005432528178	7772	257	42E
0005435213138	7772	258	42D
0005435213134	7772	259	42H
0005432528103	7772	260	42G
0005432528147	7772	261	42F
0005434067622	7772	262	42K
0005435213240	7772	263	42J
0005434067642	7772	264	43B
0005432069666	7772	265	43A
0005435213049	7772	266	43D
0005432535836	7772	267	43C
0005432528108	7772	268	43F
0005435213085	7772	269	43E
0005432528155	7772	270	43H
0005434067641	7772	271	43G
0005432528146	7772	272	43K
0005435725568	7772	273	43J
0005435213031	7772	274	44C
0005435213032	7772	275	44E
0005432528066	7772	276	44D
0005432535837	7772	277	44H
0005432528124	7772	278	44G
0005432528096	7772	279	44F
0005432528156	7772	280	44K
0005432528172	7772	281	44J
0005432528131	7772	282	45B
0005435212565	7772	283	45A
0005434067633	7772	284	45D
0005432528075	7772	285	45C
0005432528077	7772	286	45F
0005434067612	7772	287	45E
0005435213233	7772	288	45H
0005432528152	7772	289	45G
0005432528113	7772	290	46A
0005432535839	7772	291	45K
0005434067670	7772	292	45J
0005435725527	7772	293	46B
0005432528073	7772	294	46E
0005432528098	7772	295	46C
0005435212853	7772	296	46F
0005434067618	7772	297	46J
0005432528093	7772	298	46H
0005432528090	7772	299	47C
0005434067655	7772	300	47A
0005432528059	7772	301	46K
0005434067616	7772	302	47E
0005432528065	7772	303	47D
0005434067659	7772	304	47H
0005432528104	7772	305	48D
0005432528064	7772	306	48C
0005432528154	7772	307	48E
0005432533295	7772	308	48H
0005432528122	7772	309	48G
0005432528150	7772	310	49A
0005432528105	7772	311	49D
0005432528082	7772	312	49C
0005434067660	7772	313	49E
0005435212829	7772	314	49K
0005435725553	7772	315	49H
0005435212953	7772	316	50A
0005434067671	7772	317	50G
0005432528079	7772	318	50F
0005432528165	7772	319	50H
0005432528158	7772	320	51G
0005435424471	5341	1	1D
0005435424218	5341	2	1A
0005435424299	5341	3	1G
0005435613717	5341	4	1K
0005435613810	5341	5	1H
0005434344267	5341	6	2D
0005435613765	5341	7	2C
0005432840993	5341	8	2A
0005435613771	5341	9	2H
0005435424192	5341	10	2G
0005434244743	5341	11	3A
0005434244713	5341	12	3G
0005434344278	5341	13	3D
0005435424207	5341	14	3H
0005435613788	5341	15	4C
0005435424758	5341	16	3K
0005434244860	5341	17	4D
0005435613743	5341	18	4H
0005435613739	5341	19	5A
0005435613747	5341	20	5G
0005435613797	5341	21	5D
0005435613783	5341	22	5K
0005432133226	5341	23	5H
0005435042840	5341	24	11E
0005435097212	5341	25	11D
0005434573369	5341	26	11C
0005435613781	5341	27	11F
0005435491442	5341	28	11K
0005435613751	5341	29	11G
0005435380260	5341	30	12C
0005435424332	5341	31	12E
0005435613802	5341	32	12D
0005435424163	5341	33	12G
0005434244763	5341	34	12F
0005435613714	5341	35	13A
0005434244795	5341	36	12K
0005434244647	5341	37	12H
0005435613755	5341	38	13D
0005435424430	5341	39	13C
0005432363390	5341	40	13E
0005434344272	5341	41	13H
0005434573372	5341	42	13G
0005435097209	5341	43	14C
0005435613707	5341	44	14A
0005432133227	5341	45	13K
0005435424534	5341	46	14E
0005434244737	5341	47	14D
0005435613817	5341	48	14G
0005435613818	5341	49	14F
0005435424596	5341	50	14K
0005435613778	5341	51	14H
0005435380263	5341	52	15D
0005434344273	5341	53	15F
0005434573371	5341	54	15E
0005435491440	5341	55	15H
0005435613795	5341	56	15G
0005435424167	5341	57	16A
0005435423900	5341	58	15K
0005435613740	5341	59	16D
0005433719115	5341	60	16C
0005434244816	5341	61	16F
0005435319510	5341	62	16E
0005435424106	5341	63	16K
0005432133225	5341	64	16H
0005435424369	5341	65	16G
0005434244694	5341	66	17C
0005434244727	5341	67	17A
0005435613761	5341	68	17E
0005435613726	5341	69	17F
0005434244703	5341	70	17H
0005435613724	5341	71	18B
0005435613728	5341	72	18A
0005434344253	5341	73	18E
0005435424069	5341	74	18D
0005435613722	5341	75	18G
0005434344255	5341	76	18F
0005435491441	5341	77	18K
0005434244790	5341	78	18H
0005435042834	5341	79	19B
0005434344259	5341	80	19A
0005434344279	5341	81	19D
0005434244706	5341	82	19C
0005433719124	5341	83	19F
0005434244683	5341	84	19E
0005435613720	5341	85	19H
0005435613712	5341	86	19G
0005434244707	5341	87	19K
0005435424300	5341	88	20C
0005434244726	5341	89	20B
0005435613770	5341	90	20A
0005435613806	5341	91	20E
0005434344257	5341	92	20D
0005435424309	5341	93	20G
0005434573363	5341	94	20F
0005435613813	5341	95	20J
0005435613760	5341	96	20H
0005435613809	5341	97	21B
0005434573362	5341	98	21A
0005435490233	5341	99	20K
0005435613777	5341	100	21D
0005435424229	5341	101	21C
0005435424375	5341	102	21F
0005435613735	5341	103	21E
0005435424472	5341	104	21H
0005435613816	5341	105	21G
0005432133223	5341	106	22A
0005435424398	5341	107	22D
0005432133220	5341	108	22C
0005435613748	5341	109	22B
0005435613789	5341	110	22F
0005435424042	5341	111	22E
0005435555370	5341	112	22H
0005435097208	5341	113	22J
0005435613805	5341	114	23B
0005432047553	5341	115	23A
0005432840999	5341	116	23D
0005435424273	5341	117	23C
0005435613798	5341	118	23F
0005435613736	5341	119	23E
0005435424105	5341	120	23H
0005435424535	5341	121	23G
0005435613710	5341	122	24D
0005434344266	5341	123	23J
0005434244637	5341	124	24F
0005435424476	5341	125	24E
0005435613744	5341	126	25B
0005434573373	5341	127	25A
0005435613772	5341	128	24G
0005435613746	5341	129	25C
0005435424238	5341	130	25F
0005435613793	5341	131	25E
0005435424386	5341	132	25D
0005435302156	5341	133	25J
0005435424474	5341	134	25G
0005435424342	5341	135	25K
0005435380266	5341	136	26B
0005435424475	5341	137	26A
0005435424227	5341	138	26D
0005432363395	5341	139	26G
0005435613759	5341	140	26F
0005435097210	5341	141	26K
0005435613814	5341	142	26J
0005435613787	5341	143	26H
0005434344284	5341	144	27A
0005435613753	5341	145	27D
0005434344282	5341	146	27C
0005435613776	5341	147	27B
0005435613785	5341	148	27F
0005435613786	5341	149	27E
0005434344286	5341	150	27H
0005434244744	5341	151	27G
0005435613792	5341	152	28A
0005435613769	5341	153	27J
0005435613729	5341	154	28C
0005435302155	5341	155	28E
0005435613749	5341	156	28D
0005434344254	5341	157	28F
0005435613767	5341	158	28K
0005434344250	5341	159	28J
0005435042841	5341	160	28H
0005435613737	5341	161	29B
0005434573364	5341	162	29A
0005435613774	5341	163	29D
0005434656532	5341	164	29C
0005434344274	5341	165	29F
0005435424610	5341	166	29E
0005435319530	5341	167	29H
0005435319552	5341	168	29K
0005435424104	5341	169	29J
0005435613764	5341	170	30C
0005435305002	5341	171	30B
0005435613738	5341	172	30A
0005435613745	5341	173	30E
0005435424346	5341	174	30D
0005435424397	5341	175	30G
0005432047554	5341	176	30F
0005432133222	5341	177	30K
0005435424361	5341	178	30J
0005435613791	5341	179	31D
0005434244636	5341	180	31C
0005435302172	5341	181	31B
0005434344275	5341	182	31F
0005435613754	5341	183	31E
0005435319545	5341	184	31J
0005435424502	5341	185	31H
0005434573370	5341	186	31G
0005432133234	5341	187	32A
0005435613807	5341	188	32C
0005435613757	5341	189	32B
0005435613709	5341	190	32D
0005435613719	5341	191	32G
0005435613819	5341	192	32F
0005435424556	5341	193	32H
0005434573365	5341	194	33A
0005434244696	5341	195	32K
0005432133231	5341	196	33C
0005434344280	5341	197	33B
0005435613808	5341	198	33F
0005435424466	5341	199	33E
0005434244796	5341	200	33H
0005434573368	5341	201	33G
0005434344260	5341	202	34A
0005434344263	5341	203	33K
0005435613758	5341	204	34C
0005432133233	5341	205	34B
0005435424180	5341	206	34E
0005435490230	5341	207	34D
0005435613721	5341	208	34G
0005434344277	5341	209	34F
0005434244778	5341	210	34J
0005434344285	5341	211	34H
0005432133232	5341	212	35B
0005435613815	5341	213	35A
0005434344271	5341	214	34K
0005434244797	5341	215	35D
0005435613773	5341	216	35C
0005432363373	5341	217	35G
0005434244770	5341	218	35E
0005432363400	5341	219	35J
0005435424041	5341	220	35H
0005434244767	5341	221	36A
0005435319508	5341	222	36C
0005435424757	5341	223	36B
0005434344261	5341	224	36E
0005434344249	5341	225	36G
0005432133221	5341	226	36F
0005435613731	5341	227	36K
0005434344262	5341	228	36J
0005435613784	5341	229	37B
0005435613801	5341	230	37D
0005432133229	5341	231	37C
0005434573367	5341	232	37G
0005435613711	5341	233	37F
0005435424419	5341	234	37E
0005434244768	5341	235	37H
0005434244749	5341	236	38A
0005435424341	5341	237	37K
0005435613742	5341	238	37J
0005435613741	5341	239	38C
0005432840994	5341	240	38B
0005435613715	5341	241	38J
0005435613790	5341	242	38H
0005435613796	5341	243	39B
0005434344265	5341	244	39A
0005435490232	5341	245	39D
0005435613794	5341	246	39E
0005435613727	5341	247	39J
0005435424352	5341	248	39H
0005435613718	5341	249	39G
0005435613766	5341	250	40A
0005435613763	5341	251	39K
0005435424217	5341	252	40B
0005435613800	5341	253	40E
0005434344264	5341	254	40D
0005435424531	5341	255	40G
0005435613734	5341	256	40F
0005434573374	5341	257	40K
0005432133228	5341	258	40J
0005435613708	5341	259	40H
0005435613811	5341	260	41B
0005435424345	5341	261	41A
0005434344252	5341	262	41D
0005435424264	5341	263	41C
0005434244747	5341	264	41F
0005432133230	5341	265	41E
0005435319515	5341	266	41J
0005435613716	5341	267	41H
0005435490231	5341	268	41G
0005435424351	5341	269	42A
0005434344256	5341	270	41K
0005435613762	5341	271	42C
0005434344283	5341	272	42B
0005434573366	5341	273	42E
0005435613799	5341	274	42F
0005435613812	5341	275	42J
0005435097213	5341	276	42H
0005434344251	5341	277	43A
0005435319509	5341	278	43D
0005435424340	5341	279	43C
0005435424276	5341	280	43B
0005435423886	5341	281	43F
0005435319531	5341	282	43E
0005435613723	5341	283	43H
0005434344270	5341	284	43G
0005435424336	5341	285	43K
0005435613750	5341	286	43J
0005435380267	5341	287	44B
0005435097211	5341	288	44A
0005435613779	5341	289	44E
0005435424277	5341	290	44D
0005435613713	5341	291	44C
0005435319497	5341	292	44F
0005434244708	5341	293	44K
0005432133224	5341	294	44J
0005434244695	5341	295	44H
0005435613768	5341	296	45A
0005434244777	5341	297	45D
0005434344281	5341	298	45C
0005434244684	5341	299	45B
0005435319551	5341	300	45F
0005432047555	5341	301	45E
0005434656533	5341	302	45H
0005435613725	5341	303	45K
0005435613733	5341	304	45J
0005434344276	5341	305	46B
0005435555371	5341	306	46E
0005435613732	5341	307	46D
0005435424278	5341	308	46H
0005435613780	5341	309	46G
0005432047552	5341	310	46F
0005435424301	5341	311	47C
0005435424245	5341	312	47A
0005434244725	5341	313	47E
0005435613752	5341	314	47D
0005434656544	5341	315	47G
0005435424246	5341	316	47H
0005435613775	5341	317	48C
0005435424202	5341	318	48F
0005435613803	5341	319	48E
0005435380254	5341	320	48D
0005435613782	5341	321	48H
0005435424195	5341	322	48G
0005434344258	5341	323	49A
0005434344268	5341	324	48K
0005435423887	5341	325	49D
0005435613756	5341	326	49G
0005435424516	5341	327	49E
0005434344269	5341	328	49K
0005435424185	5341	329	50C
0005435613804	5341	330	50A
0005434573361	5341	331	50E
0005435424559	5341	332	50D
0005434244798	5341	333	50F
0005435613730	5341	334	51D
0005432133219	5341	335	50K
0005435424372	5341	336	50H
0005435319498	5341	337	51E
0005435305001	5341	338	51G
0005435424881	10903	1	1D
0005435424846	10903	2	1C
0005435612825	10903	3	1A
0005434573195	10903	4	1G
0005435424899	10903	5	1K
0005435424901	10903	6	1H
0005434244999	10903	7	2D
0005434344023	10903	8	2C
0005435424870	10903	9	2A
0005435612936	10903	10	2H
0005435612396	10903	11	2G
0005435097090	10903	12	3A
0005435424894	10903	13	2K
0005435424869	10903	14	3D
0005434344041	10903	15	3C
0005435424849	10903	16	3H
0005434244996	10903	17	3G
0005435424916	10903	18	4A
0005435612563	10903	19	3K
0005434245004	10903	20	4G
0005435612329	10903	21	4C
0005435424878	10903	22	4H
0005434343717	10903	23	5A
0005435380298	10903	24	5H
0005435612769	10903	25	5G
0005435613230	10903	26	11A
0005435613006	10903	27	5K
0005435613070	10903	28	11D
0005435319577	10903	29	11C
0005434244995	10903	30	11G
0005435612881	10903	31	11E
0005435424895	10903	32	11K
0005434245008	10903	33	11H
0005435612982	10903	34	12C
0005434343730	10903	35	12E
0005434245021	10903	36	12D
0005432165049	10903	37	12G
0005435319578	10903	38	12F
0005435424890	10903	39	13A
0005434343987	10903	40	13D
0005435612593	10903	41	13C
0005434245011	10903	42	13E
0005434343914	10903	43	13H
0005435612988	10903	44	13G
0005435424886	10903	45	14A
0005432363419	10903	46	13K
0005435424904	10903	47	14C
0005435424879	10903	48	14F
0005434573218	10903	49	14E
0005435097122	10903	50	14G
0005435613159	10903	51	15A
0005434343865	10903	52	14K
0005432841014	10903	53	15E
0005434245022	10903	54	15D
0005435612786	10903	55	15H
0005434244998	10903	56	15G
0005435490195	10903	57	15F
0005435612433	10903	58	16D
0005435612620	10903	59	16C
0005435612815	10903	60	16G
0005435319583	10903	61	16F
0005434343801	10903	62	16E
0005434573237	10903	63	17C
0005435424893	10903	64	17A
0005434573238	10903	65	17E
0005435613093	10903	66	17D
0005435424889	10903	67	17H
0005434573267	10903	68	17G
0005435612484	10903	69	17F
0005435612740	10903	70	18C
0005435424897	10903	71	18B
0005434245013	10903	72	18A
0005434573203	10903	73	18E
0005435612766	10903	74	18D
0005435612326	10903	75	18G
0005435424900	10903	76	18F
0005432165045	10903	77	18K
0005435613231	10903	78	18J
0005435612580	10903	79	19B
0005435424875	10903	80	19A
0005435424914	10903	81	19C
0005434245025	10903	82	19D
0005435424902	10903	83	19H
0005435380297	10903	84	19G
0005435424908	10903	85	20A
0005434343882	10903	86	19K
0005435612625	10903	87	20C
0005435424853	10903	88	20B
0005435491430	10903	89	20E
0005435612608	10903	90	20G
0005435424909	10903	91	20K
0005434244997	10903	92	21A
0005435612517	10903	93	21D
0005434343913	10903	94	21F
0005435304159	10903	95	21E
0005435613264	10903	96	21H
0005435612885	10903	97	21G
0005432165048	10903	98	22A
0005435612907	10903	99	21K
0005435424915	10903	100	21J
0005435424888	10903	101	22B
0005435612836	10903	102	22E
0005435424905	10903	103	22D
0005435613202	10903	104	22H
0005435612777	10903	105	22G
0005435612902	10903	106	22K
0005434343742	10903	107	22J
0005434343975	10903	108	23B
0005435612639	10903	109	23A
0005435424898	10903	110	23E
0005435612941	10903	111	23G
0005432363422	10903	112	23F
0005434343986	10903	113	23J
0005434343916	10903	114	23H
0005435613122	10903	115	24D
0005435424848	10903	116	23K
0005435304162	10903	117	24G
0005435319579	10903	118	24F
0005435612874	10903	119	24E
0005435319584	10903	120	25B
0005434245012	10903	121	25A
0005435424884	10903	122	25C
0005434343985	10903	123	25F
0005435424857	10903	124	25E
0005435424865	10903	125	25D
0005435613161	10903	126	25H
0005434343819	10903	127	25G
0005435304160	10903	128	26A
0005434343784	10903	129	25K
0005435613256	10903	130	25J
0005435424855	10903	131	26C
0005432165047	10903	132	26B
0005435424885	10903	133	26D
0005435613066	10903	134	26H
0005435304161	10903	135	26G
0005435612898	10903	136	26F
0005435424892	10903	137	26J
0005434343785	10903	138	27B
0005434343970	10903	139	27A
0005435612924	10903	140	27D
0005435612762	10903	141	27E
0005435319585	10903	142	27H
0005434343881	10903	143	27G
0005434245017	10903	144	27F
0005435612785	10903	145	27K
0005435612963	10903	146	27J
0005435612876	10903	147	28C
0005434245005	10903	148	28B
0005434573196	10903	149	28A
0005435424882	10903	150	28E
0005434245010	10903	151	28F
0005435380294	10903	152	28K
0005434344004	10903	153	28J
0005435097098	10903	154	28H
0005435612617	10903	155	29A
0005435612716	10903	156	29D
0005432841015	10903	157	29C
0005435424871	10903	158	29B
0005435612621	10903	159	29F
0005435490202	10903	160	29E
0005435613039	10903	161	29H
0005434573232	10903	162	29G
0005435613013	10903	163	29K
0005435424887	10903	164	29J
0005435424850	10903	165	30C
0005435304158	10903	166	30A
0005434343767	10903	167	30E
0005434343979	10903	168	30F
0005435424883	10903	169	30K
0005434343782	10903	170	30J
0005432165046	10903	171	30H
0005434245009	10903	172	31B
0005435612631	10903	173	31A
0005434245019	10903	174	31D
0005435424862	10903	175	31F
0005435424911	10903	176	31H
0005435612962	10903	177	31K
0005434343844	10903	178	31J
0005435424863	10903	179	32C
0005435424859	10903	180	32B
0005435380295	10903	181	32E
0005435424891	10903	182	32D
0005435319580	10903	183	32G
0005435424903	10903	184	32F
0005434245003	10903	185	32J
0005435380296	10903	186	33B
0005435424910	10903	187	33A
0005435424852	10903	188	32K
0005435424866	10903	189	33D
0005435424847	10903	190	33F
0005434245016	10903	191	33E
0005435612882	10903	192	33H
0005435612707	10903	193	33G
0005435613007	10903	194	34A
0005435613162	10903	195	33K
0005434573219	10903	196	33J
0005435612901	10903	197	34C
0005434245014	10903	198	34E
0005434245002	10903	199	34D
0005435613203	10903	200	34G
0005432841016	10903	201	34F
0005435612768	10903	202	34J
0005435319581	10903	203	35A
0005432166905	10903	204	34K
0005435612784	10903	205	35D
0005434343912	10903	206	35B
0005435424858	10903	207	35F
0005435612642	10903	208	35J
0005435424912	10903	209	35G
0005432363420	10903	210	35K
0005435612842	10903	211	36C
0005434656559	10903	212	36A
0005435612926	10903	213	36E
0005434343824	10903	214	36G
0005435612867	10903	215	36K
0005435612844	10903	216	36J
0005434343766	10903	217	37B
0005434245023	10903	218	37A
0005435097121	10903	219	37D
0005434573239	10903	220	37J
0005435612461	10903	221	37H
0005434573112	10903	222	38A
0005435613078	10903	223	37K
0005435613135	10903	224	38C
0005434573194	10903	225	38B
0005434245024	10903	226	38J
0005435319582	10903	227	38H
0005432165044	10903	228	39A
0005435424854	10903	229	38K
0005435424868	10903	230	39D
0005435424861	10903	231	39C
0005434343852	10903	232	39E
0005434343776	10903	233	39H
0005435613152	10903	234	39G
0005435612320	10903	235	39K
0005434573221	10903	236	39J
0005435612954	10903	237	40C
0005435424867	10903	238	40B
0005435424864	10903	239	40A
0005435424874	10903	240	40E
0005435612850	10903	241	40D
0005432363421	10903	242	40G
0005435612814	10903	243	40F
0005435424851	10903	244	40H
0005435612843	10903	245	41B
0005434245007	10903	246	41A
0005435424880	10903	247	41D
0005434245015	10903	248	41F
0005434245000	10903	249	41E
0005435612682	10903	250	41J
0005435612983	10903	251	41H
0005432166904	10903	252	42A
0005435304163	10903	253	42C
0005435612991	10903	254	42B
0005435424873	10903	255	42D
0005435555350	10903	256	42G
0005435612616	10903	257	42F
0005435612923	10903	258	42H
0005434343851	10903	259	43A
0005435612674	10903	260	42K
0005435612731	10903	261	43C
0005434343799	10903	262	43B
0005435612978	10903	263	43F
0005435611990	10903	264	43E
0005432363418	10903	265	43H
0005435490200	10903	266	43G
0005432165043	10903	267	44A
0005435612755	10903	268	43K
0005435613048	10903	269	43J
0005434343843	10903	270	44B
0005435613164	10903	271	44C
0005435612837	10903	272	44F
0005434245001	10903	273	44J
0005433719143	10903	274	44H
0005433719146	10903	275	45A
0005435612730	10903	276	44K
0005435424856	10903	277	45F
0005435612899	10903	278	45E
0005435612985	10903	279	45H
0005435612767	10903	280	45G
0005434245018	10903	281	46A
0005435424876	10903	282	45K
0005434656558	10903	283	46C
0005434245006	10903	284	46B
0005435424896	10903	285	46D
0005435613114	10903	286	46G
0005433719144	10903	287	46F
0005435611989	10903	288	46J
0005435097134	10903	289	47C
0005435613198	10903	290	47A
0005435612756	10903	291	47D
0005435424872	10903	292	47G
0005435424907	10903	293	47F
0005435555359	10903	294	47E
0005434343915	10903	295	47K
0005435555358	10903	296	47H
0005435612790	10903	297	48D
0005434343820	10903	298	48A
0005435490196	10903	299	48F
0005435424913	10903	300	48E
0005435490199	10903	301	48H
0005435612793	10903	302	48G
0005435424877	10903	303	49E
0005434245020	10903	304	49D
0005432165042	10903	305	49G
0005433719145	10903	306	49F
0005434344005	10903	307	49K
0005435097120	10903	308	49H
0005435424906	10903	309	50C
0005435612681	10903	310	50A
0005435612990	10903	311	50E
0005434343966	10903	312	50G
0005434343933	10903	313	50F
0005435424860	10903	314	51D
0005435612708	10903	315	50K
0005435612875	10903	316	50H
0005434573269	10903	317	51F
0005435612870	10903	318	51G
0005432181730	3319	1	1A
0005432459730	3319	2	1C
0005433507206	3319	3	1D
0005432459448	3319	4	2A
0005433633860	3319	5	1F
0005433633857	3319	6	2D
0005432459410	3319	7	2C
0005433805427	3319	8	2F
0005433633843	3319	9	3A
0005432181746	3319	10	3D
0005432459409	3319	11	3C
0005433805400	3319	12	4A
0005432459296	3319	13	3F
0005432181742	3319	14	4C
0005433805431	3319	15	4D
0005433805425	3319	16	4F
0005433507195	3319	17	5C
0005432459424	3319	18	5A
0005433805415	3319	19	5D
0005433633851	3319	20	5F
0005433507199	3319	21	6C
0005433633875	3319	22	6A
0005433633849	3319	23	6F
0005432459416	3319	24	6D
0005432459452	3319	25	7A
0005432459282	3319	26	7C
0005432181736	3319	27	7F
0005433805417	3319	28	7D
0005433507211	3319	29	8A
0005433633866	3319	30	8C
0005433805424	3319	31	8B
0005433805406	3319	32	8E
0005433805421	3319	33	8D
0005433633863	3319	34	8F
0005432459414	3319	35	9B
0005432459412	3319	36	9A
0005433633872	3319	37	9C
0005433805430	3319	38	9D
0005432181744	3319	39	9F
0005433633855	3319	40	9E
0005432181740	3319	41	10A
0005432181745	3319	42	10C
0005432459603	3319	43	10B
0005433507210	3319	44	10D
0005432459415	3319	45	10E
0005433633856	3319	46	11A
0005433507196	3319	47	10F
0005432459542	3319	48	11B
0005432459400	3319	49	11C
0005432459447	3319	50	11D
0005432459419	3319	51	11E
0005433805407	3319	52	12A
0005433805435	3319	53	11F
0005433507203	3319	54	12C
0005433805420	3319	55	12B
0005432181735	3319	56	12D
0005433633858	3319	57	12E
0005432459422	3319	58	12F
0005433507200	3319	59	13A
0005432459339	3319	60	13C
0005433633845	3319	61	13B
0005432459383	3319	62	13D
0005432181733	3319	63	13F
0005433633853	3319	64	13E
0005433633876	3319	65	14A
0005432459123	3319	66	14B
0005433633848	3319	67	14C
0005433633864	3319	68	14E
0005433805418	3319	69	14D
0005432459512	3319	70	14F
0005433507194	3319	71	15B
0005432459440	3319	72	15A
0005432459423	3319	73	15C
0005433633861	3319	74	15D
0005432459501	3319	75	15F
0005433805410	3319	76	15E
0005432459499	3319	77	16A
0005433507192	3319	78	16B
0005433633852	3319	79	16D
0005433805429	3319	80	16C
0005433633841	3319	81	16E
0005432181739	3319	82	16F
0005433805432	3319	83	17B
0005432459500	3319	84	17A
0005432459295	3319	85	17C
0005433805408	3319	86	17E
0005432181731	3319	87	17D
0005432459393	3319	88	18B
0005432459239	3319	89	18A
0005432459513	3319	90	17F
0005432459451	3319	91	18C
0005433805419	3319	92	18D
0005433507197	3319	93	18E
0005433805422	3319	94	19B
0005433507191	3319	95	18F
0005432459604	3319	96	19C
0005433633870	3319	97	19D
0005433633847	3319	98	19E
0005433633862	3319	99	20B
0005433805412	3319	100	20A
0005433633842	3319	101	20C
0005433507209	3319	102	20E
0005432459256	3319	103	20D
0005433633859	3319	104	20F
0005433805409	3319	105	21A
0005432459520	3319	106	21C
0005432181737	3319	107	21B
0005433507208	3319	108	21D
0005433805411	3319	109	21E
0005432459328	3319	110	22A
0005432459580	3319	111	21F
0005433805423	3319	112	22B
0005432459232	3319	113	22C
0005433805434	3319	114	22E
0005432459418	3319	115	22D
0005433507207	3319	116	22F
0005433805402	3319	117	23B
0005432459360	3319	118	23A
0005433805404	3319	119	23C
0005432181748	3319	120	23D
0005432459371	3319	121	23E
0005432181738	3319	122	24A
0005433805405	3319	123	23F
0005433507202	3319	124	24B
0005432459332	3319	125	24D
0005432459460	3319	126	24C
0005433805414	3319	127	24E
0005433805433	3319	128	24F
0005432459519	3319	129	25B
0005433633844	3319	130	25A
0005433805428	3319	131	25C
0005433805413	3319	132	25D
0005432459602	3319	133	25E
0005433633873	3319	134	26A
0005433805403	3319	135	25F
0005432181732	3319	136	26C
0005433507193	3319	137	26B
0005433633854	3319	138	26D
0005433507205	3319	139	26F
0005433507201	3319	140	26E
0005432181743	3319	141	27B
0005432459324	3319	142	27A
0005432181751	3319	143	27D
0005433507204	3319	144	27C
0005432459481	3319	145	27E
0005433633846	3319	146	28A
0005432459394	3319	147	27F
0005433633869	3319	148	28B
0005432459317	3319	149	28C
0005432459476	3319	150	28E
0005433507198	3319	151	28D
0005432181747	3319	152	28F
0005433805416	3319	153	29B
0005432181749	3319	154	29A
0005433633871	3319	155	29E
0005433805426	3319	156	29D
0005432459477	3319	157	29C
0005433633865	3319	158	29F
0005432459403	3319	159	30A
0005433633867	3319	160	30B
0005432459361	3319	161	30C
0005433633850	3319	162	30E
0005433633868	3319	163	30D
0005433633874	3319	164	30F
0005432181741	3319	165	31A
0005432459417	3319	166	31C
0005432459240	3319	167	31B
0005433805401	3319	168	31E
0005432181734	3319	169	31D
0005432181750	3319	170	31F
0005435885081	3318	1	2F
0005435885047	3318	2	3A
0005435884901	3318	3	4C
0005435885060	3318	4	6C
0005435884989	3318	5	7C
0005435884988	3318	6	8A
0005435884894	3318	7	8C
0005435884705	3318	8	9B
0005435885017	3318	9	12C
0005435884815	3318	10	12E
0005435884873	3318	11	12F
0005435884879	3318	12	14B
0005435884812	3318	13	14C
0005435885076	3318	14	14E
0005435884980	3318	15	14F
0005435884952	3318	16	15B
0005435885003	3318	17	15C
0005435884891	3318	18	16B
0005435885077	3318	19	16C
0005435885046	3318	20	17F
0005435885005	3318	21	18E
0005435885002	3318	22	19C
0005435884916	3318	23	19E
0005435884998	3318	24	20B
0005435884999	3318	25	21A
0005435885004	3318	26	22C
0005435884784	3318	27	23C
0005435884892	3318	28	23D
0005435884878	3318	29	24B
0005435884639	3318	30	24E
0005435884962	3318	31	25B
0005435884976	3318	32	25D
0005435884695	3318	33	25F
0005435885061	3318	34	26B
0005435885133	3318	35	26F
0005435885031	3318	36	27C
0005435884785	3318	37	27D
0005435884816	3318	38	28D
0005435884925	3318	39	28E
0005435884973	3318	40	29B
0005435885075	3318	41	30A
0005435885062	3318	42	30C
0005435884982	3318	43	31B
0005435884640	3318	44	31A
0005435885080	3318	45	31D
0005435884941	3318	46	31F
0005435885303	8203	1	1A
0005433507009	8203	2	1D
0005432459926	8203	3	1C
0005435885311	8203	4	2A
0005433507038	8203	5	1F
0005432459969	8203	6	2D
0005432459970	8203	7	3C
0005432459921	8203	8	3F
0005435885308	8203	9	3D
0005433507018	8203	10	4A
0005435885300	8203	11	4F
0005432459929	8203	12	4D
0005432459964	8203	13	5A
0005432459962	8203	14	5C
0005432042735	8203	15	5F
0005433506919	8203	16	5D
0005435885317	8203	17	6A
0005432459932	8203	18	6C
0005435885290	8203	19	6F
0005432459946	8203	20	6D
0005432459923	8203	21	7F
0005433506918	8203	22	8A
0005435885283	8203	23	8C
0005432459966	8203	24	8F
0005433507006	8203	25	9B
0005435885310	8203	26	9A
0005433507056	8203	27	9C
0005432042732	8203	28	9D
0005432459951	8203	29	9E
0005435885294	8203	30	10A
0005434312323	8203	31	10B
0005432459918	8203	32	10C
0005432459935	8203	33	10E
0005432459937	8203	34	10D
0005432459963	8203	35	10F
0005432459955	8203	36	11A
0005432459942	8203	37	11E
0005433507039	8203	38	11D
0005432042724	8203	39	11F
0005432459956	8203	40	12B
0005432459949	8203	41	12A
0005432042736	8203	42	12D
0005432042737	8203	43	12C
0005432459928	8203	44	12E
0005435885282	8203	45	12F
0005432459920	8203	46	13B
0005435885320	8203	47	13A
0005432042730	8203	48	13C
0005432459925	8203	49	13D
0005432042734	8203	50	13E
0005435885305	8203	51	14A
0005433506992	8203	52	13F
0005435885287	8203	53	14D
0005433507005	8203	54	15A
0005432459953	8203	55	14F
0005433507028	8203	56	15D
0005435885279	8203	57	15F
0005432459941	8203	58	16B
0005435885319	8203	59	16C
0005432042731	8203	60	17A
0005435885306	8203	61	16F
0005433507008	8203	62	17C
0005434312322	8203	63	17B
0005435885288	8203	64	17E
0005435885314	8203	65	17D
0005435885291	8203	66	17F
0005432042729	8203	67	18A
0005432459919	8203	68	18C
0005432459938	8203	69	18B
0005433507017	8203	70	18D
0005435885307	8203	71	18E
0005432459939	8203	72	18F
0005432459950	8203	73	19C
0005432459957	8203	74	19D
0005432459930	8203	75	19E
0005432459961	8203	76	20B
0005435885281	8203	77	20A
0005435885318	8203	78	20C
0005433506917	8203	79	20E
0005432459943	8203	80	20F
0005432459965	8203	81	21B
0005435885286	8203	82	21D
0005435885278	8203	83	21C
0005432459936	8203	84	21E
0005432459959	8203	85	21F
0005432459924	8203	86	22B
0005433507055	8203	87	22C
0005432459945	8203	88	22F
0005435885312	8203	89	22E
0005433507007	8203	90	23A
0005432459931	8203	91	23B
0005435885292	8203	92	23D
0005432042727	8203	93	23E
0005435885313	8203	94	24A
0005435885280	8203	95	23F
0005432459947	8203	96	24B
0005432459940	8203	97	24C
0005432459922	8203	98	24F
0005432459967	8203	99	24E
0005434312324	8203	100	25B
0005432459948	8203	101	25A
0005432459968	8203	102	25C
0005435885296	8203	103	25E
0005435885299	8203	104	25F
0005435885302	8203	105	26B
0005435885309	8203	106	26C
0005435885316	8203	107	26E
0005432459952	8203	108	26D
0005432042733	8203	109	26F
0005432459933	8203	110	27A
0005435885284	8203	111	27E
0005435885315	8203	112	27F
0005435885293	8203	113	28B
0005435885297	8203	114	28C
0005435885304	8203	115	28E
0005435885301	8203	116	28D
0005435885289	8203	117	28F
0005435885298	8203	118	29A
0005432459927	8203	119	29C
0005432459934	8203	120	29B
0005433507029	8203	121	29D
0005432042726	8203	122	29E
0005432459960	8203	123	30A
0005432042738	8203	124	30B
0005435885295	8203	125	30D
0005432459971	8203	126	30E
0005432042725	8203	127	30F
0005432042728	8203	128	31B
0005435885285	8203	129	31A
0005432459944	8203	130	31D
0005432459958	8203	131	31E
0005432459954	8203	132	31F
0005433633654	8305	1	1C
0005434271301	8305	2	1D
0005433633477	8305	3	2F
0005433805080	8305	4	2D
0005433805027	8305	5	3A
0005433805223	8305	6	3F
0005433633467	8305	7	4A
0005433633513	8305	8	4D
0005433633655	8305	9	5A
0005433804953	8305	10	4F
0005433633432	8305	11	5F
0005434143714	8305	12	6C
0005433633541	8305	13	7A
0005433633388	8305	14	7D
0005434143713	8305	15	8A
0005433805108	8305	16	7F
0005433633537	8305	17	8D
0005433633465	8305	18	8E
0005433633530	8305	19	9A
0005433805095	8305	20	10E
0005433633463	8305	21	11A
0005433805231	8305	22	11C
0005433805238	8305	23	11E
0005433633514	8305	24	12D
0005433633698	8305	25	13B
0005433633462	8305	26	13E
0005435854059	8305	27	14A
0005433805156	8305	28	15C
0005433805092	8305	29	15E
0005433633656	8305	30	15D
0005433805260	8305	31	15F
0005435854057	8305	32	16B
0005433805195	8305	33	16C
0005433633423	8305	34	16E
0005433805073	8305	35	16D
0005433805196	8305	36	16F
0005435854058	8305	37	17A
0005433805134	8305	38	17B
0005433805220	8305	39	18A
0005433805107	8305	40	18B
0005433805072	8305	41	18D
0005433633466	8305	42	19C
0005433633486	8305	43	19E
0005434271296	8305	44	20D
0005433805096	8305	45	20F
0005433633631	8305	46	21E
0005433805139	8305	47	22B
0005433633649	8305	48	22A
0005433633624	8305	49	22D
0005433633449	8305	50	23C
0005434271295	8305	51	23D
0005433805232	8305	52	24A
0005433805239	8305	53	24C
0005435854060	8305	54	24E
0005433633401	8305	55	24D
0005433633484	8305	56	24F
0005433805085	8305	57	26A
0005433805121	8305	58	25F
0005433633525	8305	59	26D
0005433633531	8305	60	26F
0005433633526	8305	61	27A
0005433805119	8305	62	27D
0005433633650	8305	63	28A
0005433633663	8305	64	28B
0005433805221	8305	65	28F
0005433804954	8305	66	30A
0005433805093	8305	67	30F
0005433633485	8305	68	31A
0005433805197	8305	69	31C
0005433633389	8305	70	31B
0005433805122	8305	71	31D
0005433805180	8305	72	31F
0005434183569	8237	1	10F
0005434183568	8237	2	17B
0005434183570	8237	3	29F
0005433453764	4525	1	1D
0005432727955	4525	2	2C
0005433722230	4525	3	2D
0005432383229	4525	4	2F
0005433194858	4525	5	3A
0005432383221	4525	6	3C
0005432383234	4525	7	3D
0005433194859	4525	8	4A
0005432383230	4525	9	4D
0005432383203	4525	10	4E
0005432383219	4525	11	4F
0005433194860	4525	12	5A
0005432727953	4525	13	5D
0005432383202	4525	14	5F
0005432383217	4525	15	6A
0005432383216	4525	16	6C
0005432383208	4525	17	6E
0005432383214	4525	18	7C
0005433722231	4525	19	7D
0005432727948	4525	20	7F
0005432383212	4525	21	8A
0005432383226	4525	22	8D
0005432727949	4525	23	8E
0005432383237	4525	24	9A
0005432727957	4525	25	9D
0005432727951	4525	26	9E
0005432383223	4525	27	10A
0005432383213	4525	28	10C
0005432383215	4525	29	11C
0005432383236	4525	30	11D
0005432383231	4525	31	11F
0005432383211	4525	32	12A
0005432383220	4525	33	12E
0005432727947	4525	34	12F
0005432383218	4525	35	13C
0005432383206	4525	36	13D
0005432383205	4525	37	13E
0005432727946	4525	38	14A
0005432727950	4525	39	14C
0005432383210	4525	40	14D
0005433454878	4525	41	14E
0005432383232	4525	42	14F
0005432727952	4525	43	15C
0005432383224	4525	44	16A
0005432727954	4525	45	16C
0005433454877	4525	46	17A
0005432727956	4525	47	17C
0005432383235	4525	48	17D
0005432383209	4525	49	18A
0005432727958	4525	50	18C
0005432383228	4525	51	18D
0005432383225	4525	52	18E
0005432383207	4525	53	19E
0005432383204	4525	54	19F
0005432383233	4525	55	20C
0005432383222	4525	56	20D
0005432383227	4525	57	20E
0005432382767	30186	1	1C
0005432382647	30186	2	1D
0005432382794	30186	3	1F
0005432382718	30186	4	2A
0005432382880	30186	5	2C
0005432382857	30186	6	2D
0005433722136	30186	7	2F
0005432382811	30186	8	3C
0005433194848	30186	9	3D
0005432382584	30186	10	3F
0005432382646	30186	11	4A
0005432382876	30186	12	4C
0005432727764	30186	13	4E
0005432382741	30186	14	4F
0005433194849	30186	15	5A
0005432382910	30186	16	5C
0005432382782	30186	17	5D
0005432382785	30186	18	5E
0005432382792	30186	19	5F
0005432382709	30186	20	6A
0005433722152	30186	21	6C
0005433451612	30186	22	6D
0005432382815	30186	23	6F
0005432382710	30186	24	7A
0005432382878	30186	25	7C
0005432382666	30186	26	7D
0005432382735	30186	27	7F
0005433722153	30186	28	8A
0005432727827	30186	29	8D
0005432382786	30186	30	8E
0005433194831	30186	31	9A
0005432727836	30186	32	9C
0005432727865	30186	33	9E
0005432727864	30186	34	9F
0005432382798	30186	35	10A
0005432727805	30186	36	10C
0005432382793	30186	37	10D
0005433722149	30186	38	10E
0005432382875	30186	39	10F
0005432382757	30186	40	11A
0005433451611	30186	41	11C
0005433722150	30186	42	11D
0005433722123	30186	43	11E
0005432382739	30186	44	11F
0005432382696	30186	45	12A
0005432382812	30186	46	12C
0005432382713	30186	47	12D
0005432382874	30186	48	13A
0005432382906	30186	49	13C
0005432727834	30186	50	13D
0005432727863	30186	51	13E
0005432382731	30186	52	14A
0005432727850	30186	53	14C
0005433722137	30186	54	14D
0005432727854	30186	55	14E
0005432727862	30186	56	15A
0005432382877	30186	57	15C
0005432382740	30186	58	15D
0005432727826	30186	59	15E
0005433194850	30186	60	16A
0005432382719	30186	61	16C
0005432727861	30186	62	16D
0005432382865	30186	63	16F
0005432727798	30186	64	17A
0005432382783	30186	65	17E
0005432382799	30186	66	17F
0005432382665	30186	67	18A
0005432727831	30186	68	18D
0005432727791	30186	69	18E
0005432382818	30186	70	18F
0005432382695	30186	71	19C
0005433451598	30186	72	19D
0005432382734	30186	73	19E
0005432382694	30186	74	19F
0005432382837	30186	75	20A
0005432382702	30186	76	20C
0005432727858	30186	77	20D
0005432727837	30186	78	20F
0005435541037	1768	1	1A
0005435529290	1768	2	1C
0005435541024	1768	3	1D
0005435541032	1768	4	1F
0005435529293	1768	5	2C
0005435541036	1768	6	2D
0005432294489	1768	7	2F
0005433516896	1768	8	3A
0005435529296	1768	9	3F
0005435541038	1768	10	4D
0005433516901	1768	11	4E
0005435541025	1768	12	5C
0005433516897	1768	13	5E
0005433516899	1768	14	5F
0005435541035	1768	15	6A
0005435529299	1768	16	6C
0005435529282	1768	17	6D
0005432294490	1768	18	6E
0005432924993	1768	19	7D
0005435529289	1768	20	7E
0005433516893	1768	21	7F
0005435541029	1768	22	8A
0005435529287	1768	23	8D
0005435529288	1768	24	8F
0005435541027	1768	25	9A
0005435529281	1768	26	9C
0005435529294	1768	27	9E
0005435529283	1768	28	9D
0005435541030	1768	29	9F
0005435541042	1768	30	10A
0005432925002	1768	31	11A
0005435541033	1768	32	11C
0005432294491	1768	33	11D
0005435529286	1768	34	11E
0005435541034	1768	35	12A
0005435529292	1768	36	12C
0005435541041	1768	37	12D
0005435529297	1768	38	12F
0005435541026	1768	39	13C
0005433516898	1768	40	13D
0005435541039	1768	41	13F
0005433516900	1768	42	14A
0005432925003	1768	43	14D
0005433516895	1768	44	15F
0005435529291	1768	45	16A
0005435529279	1768	46	16D
0005435529278	1768	47	16E
0005435541031	1768	48	17A
0005435529298	1768	49	17C
0005435541023	1768	50	17D
0005435529280	1768	51	17F
0005435529285	1768	52	18C
0005432924994	1768	53	18F
0005433516894	1768	54	19A
0005435541028	1768	55	19C
0005435541040	1768	56	19D
0005435529295	1768	57	19E
0005433516902	1768	58	19F
0005435529284	1768	59	20A
0005435529277	1768	60	20D
0005433516839	21979	1	1A
0005435517769	21979	2	1C
0005435517772	21979	3	2A
0005435517793	21979	4	2C
0005435517756	21979	5	2D
0005433516770	21979	6	3A
0005435540864	21979	7	3C
0005435540798	21979	8	4C
0005435517720	21979	9	4D
0005435517834	21979	10	5A
0005435517745	21979	11	5C
0005435517744	21979	12	5D
0005435517762	21979	13	5E
0005433516769	21979	14	5F
0005435540863	21979	15	6C
0005435517795	21979	16	6D
0005435540799	21979	17	6F
0005435540800	21979	18	7F
0005435517743	21979	19	8F
0005435517805	21979	20	9A
0005435517811	21979	21	9C
0005435517708	21979	22	9D
0005435517751	21979	23	9E
0005433516800	21979	24	9F
0005435540854	21979	25	10C
0005435517650	21979	26	10F
0005435517738	21979	27	11C
0005435540813	21979	28	11E
0005432925043	21979	29	12C
0005435517719	21979	30	12D
0005435540812	21979	31	12E
0005432925042	21979	32	12F
0005435517798	21979	33	13A
0005435517750	21979	34	13E
0005435540868	21979	35	13F
0005435540866	21979	36	14A
0005435517794	21979	37	14C
0005432925040	21979	38	14E
0005435540880	21979	39	15A
0005435540811	21979	40	15C
0005435517768	21979	41	15D
0005435540836	21979	42	15F
0005432925041	21979	43	16C
0005435517651	21979	44	16D
0005435517755	21979	45	17A
0005433516834	21979	46	17C
0005433516835	21979	47	17D
0005435540801	21979	48	17E
0005433516801	21979	49	17F
0005435517761	21979	50	18D
0005433516843	21979	51	19A
0005435517742	21979	52	19C
0005433516811	21979	53	19E
0005435517796	21979	54	19F
0005435517797	21979	55	20F
0005432839060	7404	1	1A
0005435252577	7404	2	1C
0005432839057	7404	3	1F
0005434458836	7404	4	2C
0005435252556	7404	5	2D
0005434458824	7404	6	2F
0005432839069	7404	7	3A
0005432839062	7404	8	3C
0005432823450	7404	9	3D
0005434458820	7404	10	3F
0005434458830	7404	11	4A
0005432839066	7404	12	4C
0005432839061	7404	13	4E
0005432839053	7404	14	4D
0005432073393	7404	15	4F
0005435491410	7404	16	5C
0005432839072	7404	17	5D
0005432839056	7404	18	5E
0005435252567	7404	19	6E
0005434458829	7404	20	6F
0005432073395	7404	21	7A
0005435252548	7404	22	7C
0005434458819	7404	23	7D
0005432073394	7404	24	7E
0005434458817	7404	25	7F
0005432839059	7404	26	8A
0005432839081	7404	27	8C
0005432839080	7404	28	8D
0005432839070	7404	29	8E
0005435491428	7404	30	8F
0005434458835	7404	31	9C
0005432839076	7404	32	9A
0005435252568	7404	33	9D
0005432823452	7404	34	9F
0005432839064	7404	35	10A
0005432839074	7404	36	10D
0005434458818	7404	37	10E
0005432839083	7404	38	10F
0005432839058	7404	39	11A
0005435252573	7404	40	11C
0005432841012	7404	41	11D
0005434458833	7404	42	11E
0005432839065	7404	43	11F
0005432839084	7404	44	12A
0005434458832	7404	45	12C
0005435252591	7404	46	12F
0005432839068	7404	47	13C
0005432839078	7404	48	13D
0005432839077	7404	49	13E
0005432839075	7404	50	13F
0005432839071	7404	51	14A
0005435252531	7404	52	14C
0005435252578	7404	53	14E
0005435252598	7404	54	14D
0005434458834	7404	55	15A
0005432839082	7404	56	15D
0005432839055	7404	57	15E
0005432839054	7404	58	15F
0005434458825	7404	59	16C
0005435252576	7404	60	16D
0005434458823	7404	61	16E
0005434458837	7404	62	17A
0005434458821	7404	63	17C
0005434458828	7404	64	17D
0005435252569	7404	65	17E
0005435252532	7404	66	17F
0005432839073	7404	67	18A
0005434458822	7404	68	18D
0005432823451	7404	69	18E
0005435252566	7404	70	18F
0005432841013	7404	71	19A
0005432839063	7404	72	19C
0005434458827	7404	73	19D
0005434458826	7404	74	19E
0005434458831	7404	75	19F
0005435252655	7404	76	20A
0005432839067	7404	77	20C
0005432839079	7404	78	20E
0005435252579	7404	79	20F
0005432001025	28934	1	1A
0005434458641	28934	2	1C
0005434458608	28934	3	1D
0005432838863	28934	4	1F
0005434458654	28934	5	2A
0005432838960	28934	6	2C
0005435252723	28934	7	2D
0005434458640	28934	8	2F
0005435252730	28934	9	3A
0005435252715	28934	10	3D
0005434458597	28934	11	3F
0005432838799	28934	12	4D
0005432838818	28934	13	4F
0005435252731	28934	14	5A
0005432838904	28934	15	5C
0005435252724	28934	16	5D
0005435252714	28934	17	5E
0005434458626	28934	18	6A
0005432838864	28934	19	6C
0005432841002	28934	20	6D
0005432838815	28934	21	6E
0005432838959	28934	22	6F
0005434664963	28934	23	7C
0005432838865	28934	24	7D
0005434664964	28934	25	7E
0005435491443	28934	26	8A
0005435252721	28934	27	8C
0005432838819	28934	28	8E
0005432838808	28934	29	9A
0005434458568	28934	30	9C
0005432838789	28934	31	9D
0005434458638	28934	32	9E
0005435252716	28934	33	9F
0005435252728	28934	34	10A
0005435252727	28934	35	10C
0005435252722	28934	36	10D
0005435252726	28934	37	10E
0005435252717	28934	38	11E
0005432838861	28934	39	11F
0005432838685	28934	40	12A
0005434458624	28934	41	12C
0005432838903	28934	42	12D
0005432838817	28934	43	12E
0005434458609	28934	44	12F
0005432838848	28934	45	13A
0005432838813	28934	46	13C
0005435252732	28934	47	13F
0005435252718	28934	48	14A
0005432838774	28934	49	14C
0005434458749	28934	50	14E
0005432838891	28934	51	14F
0005432838793	28934	52	15A
0005435252733	28934	53	15D
0005432838649	28934	54	16C
0005435491444	28934	55	16D
0005432838715	28934	56	16E
0005435252729	28934	57	16F
0005432838823	28934	58	17A
0005435252719	28934	59	17D
0005432838849	28934	60	17F
0005434458627	28934	61	18A
0005432838810	28934	62	18D
0005434458655	28934	63	18E
0005434458598	28934	64	18F
0005432838853	28934	65	19A
0005432838806	28934	66	19C
0005434458670	28934	67	19D
0005432838816	28934	68	19E
0005432838790	28934	69	19F
0005434458694	28934	70	20A
0005435252720	28934	71	20C
0005432838809	28934	72	20D
0005432838890	28934	73	20E
0005435252725	28934	74	20F
0005434275985	8820	1	7D
0005435990630	8820	2	8A
0005435990631	8820	3	9B
0005434275986	8820	4	11D
0005434275987	8820	5	11C
0005434275980	8820	6	13C
0005435990632	8820	7	13F
0005434275962	8820	8	14B
0005434275983	8820	9	14E
0005435990629	8820	10	15D
0005435990633	8820	11	16C
0005435990634	8820	12	20D
0005434276006	8820	13	21B
0005434276036	15768	1	3A
0005434276031	15768	2	10D
0005435990569	15768	3	10F
0005435990567	15768	4	11C
0005434276032	15768	5	12C
0005435990604	15768	6	13A
0005434276030	15768	7	15F
0005434276033	15768	8	17A
0005434276035	15768	9	18E
0005434276034	15768	10	20A
0005432427129	30854	1	1A
0005432427124	30854	2	2B
0005433476894	30854	3	2C
0005432427121	30854	4	2D
0005432427119	30854	5	4C
0005432427128	30854	6	4D
0005432427127	30854	7	5C
0005433476891	30854	8	7B
0005432427122	30854	9	18B
0005433476893	30854	10	19B
0005432427123	30854	11	21C
0005433476895	30854	12	22A
0005432427115	30854	13	23A
0005433476892	30854	14	23B
0005433468280	23837	1	1C
0005432909287	23837	2	2A
0005432909292	23837	3	2C
0005432909291	23837	4	2D
0005432909288	23837	5	3B
0005433468278	23837	6	3C
0005433468215	23837	7	4A
0005432909283	23837	8	4B
0005432909293	23837	9	5C
0005433468268	23837	10	5D
0005433468279	23837	11	6A
0005433468223	23837	12	6B
0005433468293	23837	13	18C
0005432909284	23837	14	18D
0005432909286	23837	15	19A
0005433468237	23837	16	19C
0005432909289	23837	17	19D
0005432909290	23837	18	20C
0005433468241	23837	19	21A
0005433468214	23837	20	21B
0005433468286	23837	21	22A
0005432909285	23837	22	22B
0005433468290	23837	23	22C
0005432909294	23837	24	23A
0005432360418	6360	1	1A
0005434149634	6360	2	1C
0005432336046	6360	3	1D
0005432360397	6360	4	2A
0005432360417	6360	5	1F
0005435176998	6360	6	2C
0005432360395	6360	7	2D
0005432360436	6360	8	2F
0005435176773	6360	9	3C
0005435176914	6360	10	3A
0005432336050	6360	11	3F
0005432360434	6360	12	3D
0005435176950	6360	13	4A
0005435490200	6360	14	4C
0005435176869	6360	15	4B
0005432360411	6360	16	4D
0005435176936	6360	17	4E
0005434149655	6360	18	4F
0005435176915	6360	19	5A
0005432360410	6360	20	5C
0005432062237	6360	21	5B
0005435176870	6360	22	5E
0005435177057	6360	23	6B
0005432360423	6360	24	6A
0005432360420	6360	25	6D
0005432363419	6360	26	6C
0005432360406	6360	27	6E
0005435176973	6360	28	7A
0005432360435	6360	29	6F
0005432336049	6360	30	7B
0005435176774	6360	31	7D
0005432360408	6360	32	7C
0005432360402	6360	33	7E
0005432062236	6360	34	8A
0005435176820	6360	35	7F
0005432360409	6360	36	8B
0005432360419	6360	37	8D
0005432336052	6360	38	8F
0005432360432	6360	39	9A
0005435176966	6360	40	9C
0005435176878	6360	41	9B
0005432336045	6360	42	9D
0005435176825	6360	43	10B
0005435176880	6360	44	10C
0005432360398	6360	45	10D
0005435177000	6360	46	11A
0005432360422	6360	47	10E
0005435176940	6360	48	11B
0005432360437	6360	49	11D
0005435176881	6360	50	11C
0005432360394	6360	51	11E
0005435176953	6360	52	11F
0005435176991	6360	53	12A
0005432360427	6360	54	12B
0005435490199	6360	55	12D
0005432360392	6360	56	12C
0005435176916	6360	57	12E
0005435176845	6360	58	13A
0005435490196	6360	59	12F
0005435176830	6360	60	13C
0005432360413	6360	61	13B
0005432360428	6360	62	13D
0005435176904	6360	63	13E
0005432360416	6360	64	13F
0005432360433	6360	65	14A
0005434149637	6360	66	14C
0005432360440	6360	67	14B
0005432336044	6360	68	14D
0005432336048	6360	69	14E
0005435176877	6360	70	15B
0005434149667	6360	71	15A
0005435176817	6360	72	15C
0005432360426	6360	73	15E
0005435176879	6360	74	16A
0005435176903	6360	75	16B
0005432360430	6360	76	16C
0005435176974	6360	77	16E
0005432062233	6360	78	16D
0005432360399	6360	79	17A
0005435490202	6360	80	16F
0005434149616	6360	81	17B
0005435176999	6360	82	17C
0005432360396	6360	83	17E
0005434149654	6360	84	17D
0005435176900	6360	85	18A
0005432360403	6360	86	17F
0005432360415	6360	87	18B
0005435176899	6360	88	18D
0005432360439	6360	89	18C
0005434149636	6360	90	18E
0005432336043	6360	91	18F
0005432360431	6360	92	19A
0005432336042	6360	93	19C
0005432360400	6360	94	19B
0005435176882	6360	95	19E
0005432360412	6360	96	19D
0005432360421	6360	97	19F
0005432062235	6360	98	20A
0005435176965	6360	99	20B
0005432360401	6360	100	20D
0005432062234	6360	101	20C
0005432360425	6360	102	20E
0005432360424	6360	103	20F
0005432336041	6360	104	21A
0005432336051	6360	105	21C
0005432363418	6360	106	21D
0005434149628	6360	107	21F
0005435490195	6360	108	21E
0005432360407	6360	109	22A
0005432363422	6360	110	22B
0005432360429	6360	111	22C
0005432363420	6360	112	22D
0005432360405	6360	113	22E
0005432336047	6360	114	23A
0005432360404	6360	115	22F
0005432363421	6360	116	23B
0005432360393	6360	117	23D
0005432360438	6360	118	23C
0005432360414	6360	119	23F
0005434149666	6360	120	23E
0005432359885	21019	1	1A
0005432360050	21019	2	1D
0005435490234	21019	3	2A
0005432359984	21019	4	2D
0005432360011	21019	5	2C
0005434149743	21019	6	2F
0005432360078	21019	7	3A
0005435177112	21019	8	3D
0005435177115	21019	9	4A
0005434149742	21019	10	3F
0005432360049	21019	11	4B
0005432360084	21019	12	4C
0005432360086	21019	13	4F
0005435490235	21019	14	5B
0005435177113	21019	15	5A
0005435490236	21019	16	5C
0005432359873	21019	17	5D
0005432359962	21019	18	5F
0005435177103	21019	19	5E
0005432360044	21019	20	6A
0005432360113	21019	21	6C
0005432360051	21019	22	6D
0005435177104	21019	23	6E
0005432360038	21019	24	6F
0005432335983	21019	25	7B
0005432359865	21019	26	7A
0005432359839	21019	27	7C
0005432359864	21019	28	7E
0005432360059	21019	29	7F
0005432335859	21019	30	8C
0005432359954	21019	31	8D
0005434149738	21019	32	8E
0005435177111	21019	33	8F
0005435177097	21019	34	9C
0005435177105	21019	35	9B
0005434149748	21019	36	9E
0005432360043	21019	37	9D
0005432335920	21019	38	9F
0005434149737	21019	39	10C
0005435177119	21019	40	10E
0005432359754	21019	41	10D
0005432360145	21019	42	11C
0005432360008	21019	43	11D
0005435723048	21019	44	11F
0005432359949	21019	45	11E
0005435177107	21019	46	12B
0005435177118	21019	47	12D
0005432335963	21019	48	12E
0005432335858	21019	49	12F
0005434149746	21019	50	13A
0005434149740	21019	51	13B
0005432335982	21019	52	13D
0005435177114	21019	53	13F
0005432359924	21019	54	14A
0005434149745	21019	55	14C
0005432359983	21019	56	14B
0005432359918	21019	57	14D
0005432359969	21019	58	14E
0005434149747	21019	59	14F
0005432360041	21019	60	15B
0005432359968	21019	61	15C
0005432360007	21019	62	15D
0005435177092	21019	63	15E
0005434149744	21019	64	16A
0005435177106	21019	65	15F
0005432359907	21019	66	16C
0005435177098	21019	67	16E
0005432335980	21019	68	16D
0005435177094	21019	69	17C
0005435177093	21019	70	17E
0005432360056	21019	71	18A
0005432360055	21019	72	17F
0005435177099	21019	73	18B
0005435177110	21019	74	18D
0005432335925	21019	75	18C
0005435177102	21019	76	18F
0005432360014	21019	77	18E
0005435177117	21019	78	19A
0005432360042	21019	79	19C
0005435723049	21019	80	19B
0005432359755	21019	81	19E
0005432335962	21019	82	19D
0005435177101	21019	83	19F
0005432360101	21019	84	20A
0005432335954	21019	85	20C
0005432360112	21019	86	20E
0005432052750	21019	87	20F
0005435177108	21019	88	21B
0005434149739	21019	89	21A
0005435177095	21019	90	21E
0005432335981	21019	91	21F
0005432052749	21019	92	22B
0005432360114	21019	93	22A
0005432360012	21019	94	22C
0005432359979	21019	95	22D
0005435177096	21019	96	22E
0005435177100	21019	97	23A
0005435177109	21019	98	23B
0005434149741	21019	99	23C
0005435177116	21019	100	23F
0005432360088	21019	101	23E
0005434463907	17717	1	1A
0005434458711	17717	2	1B
0005434186203	17717	3	1C
0005434463922	17717	4	1D
0005434458669	17717	5	2A
0005434448290	17717	6	2B
0005434458677	17717	7	2D
0005434458710	17717	8	3C
0005434458499	17717	9	3D
0005434458628	17717	10	4A
0005434448278	17717	11	5D
0005434461621	17717	12	6A
0005434458667	17717	13	6B
0005434186201	17717	14	6D
0005434458586	17717	15	7A
0005434458680	17717	16	7D
0005434458709	17717	17	18A
0005434458699	17717	18	18B
0005434458700	17717	19	19A
0005434458727	17717	20	19B
0005434458636	17717	21	19C
0005434458688	17717	22	19D
0005434458689	17717	23	20A
0005434458631	17717	24	20C
0005434458611	17717	25	20D
0005434186202	17717	26	21A
0005434463923	17717	27	21C
0005434458583	17717	28	22C
0005434458678	17717	29	22D
0005434458619	17717	30	23A
0005434458827	29122	1	1A
0005434462790	29122	2	2B
0005434458822	29122	3	2C
0005434448315	29122	4	3B
0005434448316	29122	5	3C
0005434458828	29122	6	3D
0005434458824	29122	7	4A
0005434458818	29122	8	4D
0005434458823	29122	9	5A
0005434458819	29122	10	5B
0005434458835	29122	11	5D
0005434448314	29122	12	6B
0005434458833	29122	13	6D
0005434458817	29122	14	7A
0005434458836	29122	15	7B
0005434462792	29122	16	7C
0005434463929	29122	17	18B
0005434458829	29122	18	19B
0005434458832	29122	19	19D
0005434463930	29122	20	20A
0005434458834	29122	21	20C
0005434458831	29122	22	20D
0005434458825	29122	23	21A
0005434458830	29122	24	21B
0005434458821	29122	25	21D
0005434458837	29122	26	22B
0005434458826	29122	27	22C
0005434458820	29122	28	22D
0005434462791	29122	29	23A
0005432665242	21837	1	2D
0005432665241	21837	2	5C
0005432658567	21837	3	9A
0005432665249	21837	4	10A
0005432665240	21837	5	10B
0005432665243	21837	6	11C
0005432658566	21837	7	11B
0005432665237	21837	8	11F
0005432658556	21837	9	13A
0005432658565	21837	10	13D
0005432665239	21837	11	15C
0005432665250	21837	12	16A
0005432665238	21837	13	16B
0005432658555	21837	14	17F
0005432665244	21837	15	18F
0005432658561	21837	16	19B
0005432665245	21837	17	21D
0005432604341	21433	1	1A
0005432604348	21433	2	1B
0005432604364	21433	3	2A
0005432604345	21433	4	2C
0005432604336	21433	5	2D
0005432604339	21433	6	3A
0005432604363	21433	7	3B
0005432604342	21433	8	3C
0005432604369	21433	9	3D
0005432604359	21433	10	4A
0005432604340	21433	11	4B
0005432604356	21433	12	4C
0005432604360	21433	13	4D
0005432604366	21433	14	5C
0005432604333	21433	15	5B
0005432604346	21433	16	5D
0005432604338	21433	17	6A
0005432604332	21433	18	6B
0005432604358	21433	19	6C
0005432604352	21433	20	7A
0005432604353	21433	21	7B
0005432604357	21433	22	7C
0005432604335	21433	23	7D
0005432604371	21433	24	18A
0005432604362	21433	25	18B
0005432604354	21433	26	18C
0005432604361	21433	27	18D
0005432604344	21433	28	19A
0005432604368	21433	29	19B
0005432604367	21433	30	20A
0005432604347	21433	31	20B
0005432604337	21433	32	20C
0005432604351	21433	33	20D
0005432604349	21433	34	21A
0005432604355	21433	35	21B
0005432604343	21433	36	22B
0005432604370	21433	37	22C
0005432604365	21433	38	22D
0005432604334	21433	39	23A
0005432604350	21433	40	23B
0005432604046	31705	1	1A
0005432603854	31705	2	1C
0005432603997	31705	3	1D
0005432603958	31705	4	2A
0005432603988	31705	5	2B
0005435221515	31705	6	2C
0005432603853	31705	7	2D
0005432604058	31705	8	3B
0005432604048	31705	9	3C
0005435221514	31705	10	3D
0005432604243	31705	11	4A
0005432604045	31705	12	4B
0005432604242	31705	13	4C
0005435221053	31705	14	4D
0005435221052	31705	15	5A
0005432604084	31705	16	5B
0005432603996	31705	17	5D
0005432603954	31705	18	6A
0005432603856	31705	19	6B
0005432604086	31705	20	6C
0005432603938	31705	21	6D
0005432603975	31705	22	7A
0005432604087	31705	23	7C
0005432603957	31705	24	7D
0005432604034	31705	25	18B
0005432604083	31705	26	18C
0005432603980	31705	27	18D
0005432603885	31705	28	19A
0005432604037	31705	29	19B
0005432603986	31705	30	19C
0005432604035	31705	31	20A
0005432603855	31705	32	20B
0005432603981	31705	33	21A
0005432603992	31705	34	21B
0005432603994	31705	35	21C
0005432604024	31705	36	22A
0005432603977	31705	37	22B
0005432603976	31705	38	23A
0005432604076	31705	39	22D
0005432603993	31705	40	23B
0005433293254	29614	1	1C
0005433293260	29614	2	1D
0005433293263	29614	3	2B
0005433293258	29614	4	2C
0005433293253	29614	5	2D
0005433293259	29614	6	3A
0005433293252	29614	7	5B
0005433293256	29614	8	6A
0005433293257	29614	9	6B
0005433293261	29614	10	7B
0005433293264	29614	11	19D
0005433293255	29614	12	22A
0005433293262	29614	13	22B
0005433473270	6674	1	1A
0005435257195	6674	2	1B
0005433473264	6674	3	1C
0005435257192	6674	4	2A
0005435257175	6674	5	2B
0005433473271	6674	6	3A
0005433473261	6674	7	3B
0005433473272	6674	8	4B
0005433473265	6674	9	4D
0005433473262	6674	10	5A
0005433473274	6674	11	5C
0005433473278	6674	12	5D
0005433473268	6674	13	6A
0005435257183	6674	14	6C
0005435257170	6674	15	7A
0005435257218	6674	16	7B
0005433473275	6674	17	7D
0005435257208	6674	18	18B
0005435257169	6674	19	18C
0005435257217	6674	20	18D
0005433473269	6674	21	19A
0005433473279	6674	22	19B
0005435257196	6674	23	19C
0005433473267	6674	24	19D
0005433473276	6674	25	20B
0005433473263	6674	26	20C
0005435257182	6674	27	21A
0005433473273	6674	28	22A
0005433473266	6674	29	22B
0005433473277	6674	30	22C
0005435257191	6674	31	23A
0005435257190	6674	32	23B
0005435257239	23893	1	1B
0005435257241	23893	2	1C
0005433473156	23893	3	1D
0005435257238	23893	4	2A
0005433473124	23893	5	2C
0005433473150	23893	6	2D
0005433473123	23893	7	3A
0005433473162	23893	8	4A
0005433473193	23893	9	4C
0005433473220	23893	10	5A
0005433473148	23893	11	5B
0005433473171	23893	12	5D
0005435257245	23893	13	6A
0005433473166	23893	14	6B
0005433473172	23893	15	6C
0005433473177	23893	16	6D
0005435257237	23893	17	7A
0005433473207	23893	18	18A
0005433473153	23893	19	18C
0005433473178	23893	20	18D
0005435257243	23893	21	19A
0005433473167	23893	22	19C
0005435257240	23893	23	20A
0005433473212	23893	24	20B
0005433473202	23893	25	20C
0005435257242	23893	26	21B
0005433473155	23893	27	21C
0005433473182	23893	28	21D
0005435257244	23893	29	22A
0005435257236	23893	30	23A
0005433473200	23893	31	23B
0005435904895	18936	1	2A
0005434606794	18936	2	3B
0005434606829	22341	1	1A
0005435904889	22341	2	2A
0005434604897	22341	3	3B
0005434604899	22341	4	4A
0005434604898	22341	5	4B
0005434606830	22341	6	5A
0005435904894	22341	7	6A
0005434606828	22341	8	6B
0005435904379	3838	1	1D
0005435904385	3838	2	2B
0005435904387	3838	3	2C
0005434522448	3838	4	3B
0005434522450	3838	5	4B
0005434522446	3838	6	5C
0005435904378	3838	7	5D
0005434602900	3838	8	6C
0005434522447	3838	9	7B
0005434522444	3838	10	18A
0005434522445	3838	11	18D
0005434522449	3838	12	19D
0005434602901	3838	13	20B
0005435904395	3838	14	20C
0005435904380	3838	15	21A
0005434602904	3838	16	21B
0005435904386	3838	17	21D
0005434602902	3838	18	22B
0005434602903	3838	19	22C
0005435904396	3838	20	22D
0005434604870	19064	1	1A
0005434602877	19064	2	2C
0005435904706	19064	3	3A
0005435904407	19064	4	3B
0005434522409	19064	5	3C
0005434522416	19064	6	3D
0005434602878	19064	7	5B
0005434522418	19064	8	5C
0005434604873	19064	9	5D
0005434522423	19064	10	6A
0005434604874	19064	11	6B
0005435904705	19064	12	7B
0005435904410	19064	13	7C
0005435904412	19064	14	7D
0005435904704	19064	15	18A
0005434522415	19064	16	18B
0005435904409	19064	17	18D
0005435904411	19064	18	19C
0005434522417	19064	19	19D
0005434604869	19064	20	20A
0005434604872	19064	21	20C
0005435904408	19064	22	22A
0005434522427	19064	23	22D
0005434604864	19064	24	23A
0005433293169	403	1	1A
0005432753302	403	2	1C
0005432890896	403	3	1D
0005432751528	403	4	1F
0005433293168	403	5	2C
0005432747580	403	6	2D
0005432751525	403	7	2F
0005435154598	403	8	3A
0005432747593	403	9	3C
0005433293187	403	10	3D
0005432220005	403	11	3F
0005432747592	403	12	4C
0005432747588	403	13	4D
0005432220008	403	14	4E
0005432747577	403	15	4F
0005432747603	403	16	5A
0005432890811	403	17	5C
0005432747594	403	18	5E
0005432747599	403	19	5F
0005432747605	403	20	6A
0005432220006	403	21	6C
0005432747581	403	22	6D
0005432749784	403	23	6E
0005432890737	403	24	7A
0005432747575	403	25	7C
0005432890840	403	26	7D
0005432747589	403	27	7E
0005433293198	403	28	7F
0005432890812	403	29	8A
0005432747585	403	30	8C
0005432890902	403	31	8D
0005432747582	403	32	8E
0005432747609	403	33	8F
0005432747595	403	34	9A
0005432751527	403	35	9D
0005432890841	403	36	9E
0005432747611	403	37	9F
0005432890746	403	38	10A
0005432890912	403	39	10C
0005433293185	403	40	10D
0005433293201	403	41	10E
0005432890791	403	42	10F
0005432751526	403	43	11A
0005432747579	403	44	11C
0005432747597	403	45	11D
0005432747601	403	46	11E
0005432890857	403	47	11F
0005432890895	403	48	12A
0005432747607	403	49	12C
0005432747586	403	50	12D
0005432747583	403	51	12E
0005433293210	403	52	12F
0005432749786	403	53	13A
0005432747587	403	54	13D
0005432747608	403	55	13E
0005432747574	403	56	13F
0005432753301	403	57	14A
0005432890856	403	58	14C
0005432747598	403	59	14D
0005432747591	403	60	14E
0005432220009	403	61	14F
0005432747604	403	62	15C
0005432220007	403	63	15D
0005432890711	403	64	15E
0005432747590	403	65	16A
0005432220004	403	66	16C
0005432890901	403	67	16D
0005432890874	403	68	16E
0005432751530	403	69	16F
0005432751529	403	70	17C
0005432747606	403	71	17D
0005432890833	403	72	17E
0005432890873	403	73	17F
0005432749785	403	74	18A
0005432747576	403	75	18D
0005432747578	403	76	18E
0005432747584	403	77	18F
0005432747613	403	78	19A
0005433293182	403	79	19C
0005432747600	403	80	19D
0005432747596	403	81	19E
0005432747612	403	82	19F
0005432747610	403	83	20A
0005432747602	403	84	20D
0005433293181	403	85	20F
0005432747272	12066	1	1A
0005432749768	12066	2	1C
0005432747265	12066	3	1D
0005432747475	12066	4	1F
0005432891031	12066	5	2A
0005432891035	12066	6	2D
0005432891048	12066	7	2F
0005432753273	12066	8	3C
0005432753274	12066	9	3F
0005432214804	12066	10	4C
0005432747109	12066	11	4D
0005432891037	12066	12	4E
0005434153535	12066	13	5A
0005432747366	12066	14	5C
0005432747327	12066	15	5E
0005432747321	12066	16	5F
0005432747289	12066	17	6A
0005432753280	12066	18	6D
0005432747356	12066	19	6E
0005432756820	12066	20	6F
0005432747309	12066	21	7A
0005432891039	12066	22	7C
0005432891033	12066	23	7D
0005432747245	12066	24	7E
0005432747409	12066	25	7F
0005432747332	12066	26	8C
0005432747429	12066	27	8D
0005432747344	12066	28	8E
0005432749769	12066	29	9A
0005432747206	12066	30	9C
0005432747357	12066	31	9D
0005432747383	12066	32	9E
0005432891047	12066	33	9F
0005432747124	12066	34	10C
0005432891045	12066	35	10E
0005432747142	12066	36	10F
0005432891032	12066	37	11A
0005432747333	12066	38	11C
0005432214805	12066	39	11D
0005432891043	12066	40	11F
0005432747474	12066	41	12A
0005432747328	12066	42	12D
0005432747252	12066	43	12C
0005432747190	12066	44	12E
0005432891046	12066	45	12F
0005432214806	12066	46	13A
0005432891040	12066	47	13C
0005432891036	12066	48	13D
0005432891038	12066	49	13F
0005432747249	12066	50	14C
0005432753283	12066	51	14D
0005432891041	12066	52	14E
0005432747290	12066	53	14F
0005432747264	12066	54	15C
0005432747204	12066	55	15E
0005433875382	12066	56	15F
0005432747271	12066	57	16A
0005434153537	12066	58	16C
0005432747408	12066	59	16E
0005432891042	12066	60	16F
0005433875380	12066	61	17A
0005432753281	12066	62	17C
0005432747205	12066	63	17D
0005434153536	12066	64	17E
0005432747329	12066	65	17F
0005432747275	12066	66	18C
0005432747244	12066	67	18D
0005432747395	12066	68	18E
0005432753282	12066	69	19A
0005432891044	12066	70	19D
0005432891034	12066	71	19E
0005432891049	12066	72	19F
0005434153538	12066	73	20C
0005432747228	12066	74	20A
0005433875381	12066	75	20D
0005432747242	12066	76	20E
0005432747343	12066	77	20F
0005433533307	18964	1	1A
0005433525043	18964	2	2B
0005432927927	18964	3	2C
0005433525036	18964	4	3B
0005432927903	18964	5	3C
0005432927928	18964	6	4A
0005433533309	18964	7	4D
0005433525041	18964	8	5B
0005433525039	18964	9	5C
0005433525038	18964	10	6A
0005433525040	18964	11	6D
0005433525035	18964	12	7B
0005433525042	18964	13	7D
0005432927946	18964	14	18C
0005432927949	18964	15	18D
0005432927933	18964	16	19A
0005433531293	18964	17	19B
0005433533308	18964	18	19C
0005433525044	18964	19	19D
0005433531291	18964	20	20A
0005433531292	18964	21	20B
0005433531294	18964	22	20C
0005432927948	18964	23	21A
0005433525045	18964	24	21C
0005432927934	18964	25	21D
0005433525037	18964	26	22B
0005432927940	18964	27	22C
0005432927947	18964	28	22D
0005433531256	32482	1	1A
0005433527224	32482	2	1B
0005433527216	32482	3	1C
0005432927993	32482	4	1D
0005433531274	32482	5	2A
0005433531270	32482	6	2D
0005433524952	32482	7	3A
0005433531255	32482	8	3C
0005433531254	32482	9	4D
0005433527222	32482	10	5A
0005433524953	32482	11	5B
0005433524965	32482	12	5C
0005433531253	32482	13	5D
0005433531263	32482	14	6B
0005433527223	32482	15	6D
0005432927989	32482	16	7A
0005432927991	32482	17	7B
0005433531264	32482	18	7C
0005433524892	32482	19	18A
0005432927992	32482	20	18C
0005433524922	32482	21	19A
0005433524966	32482	22	19B
0005432927990	32482	23	19C
0005433524893	32482	24	19D
0005433531252	32482	25	20A
0005433531269	32482	26	20D
0005433524921	32482	27	21A
0005432927994	32482	28	21B
0005433524946	32482	29	21D
0005433527225	32482	30	22A
0005433524943	32482	31	22B
0005433524967	32482	32	22C
0005434558287	5279	1	1D
0005435372578	5279	2	1C
0005434823741	5279	3	1G
0005434823686	5279	4	1K
0005435304143	5279	5	2C
0005432121343	5279	6	2A
0005434823723	5279	7	2D
0005434823725	5279	8	3A
0005435372630	5279	9	2K
0005432823431	5279	10	2H
0005435150050	5279	11	3D
0005434823777	5279	12	3C
0005434823738	5279	13	3H
0005434823658	5279	14	4A
0005435299722	5279	15	4D
0005435304117	5279	16	4K
0005434823772	5279	17	4H
0005435150049	5279	18	5C
0005434823715	5279	19	5A
0005435178986	5279	20	5G
0005435372628	5279	21	5D
0005434823660	5279	22	11A
0005434823735	5279	23	5K
0005434823655	5279	24	5H
0005435150039	5279	25	11D
0005434823697	5279	26	11C
0005434823763	5279	27	11G
0005435150048	5279	28	11F
0005435304144	5279	29	11E
0005435372467	5279	30	11K
0005432394107	5279	31	11H
0005434823657	5279	32	12C
0005434823673	5279	33	12A
0005434823737	5279	34	12E
0005435372754	5279	35	12H
0005435372788	5279	36	12G
0005432396248	5279	37	12F
0005434823734	5279	38	12K
0005434823753	5279	39	13D
0005434823720	5279	40	13C
0005435372903	5279	41	13A
0005434823666	5279	42	13F
0005435372793	5279	43	13E
0005435372739	5279	44	13H
0005434558288	5279	45	13G
0005434823674	5279	46	14G
0005435372875	5279	47	14F
0005434823762	5279	48	14E
0005435372818	5279	49	14K
0005434823766	5279	50	14H
0005434823765	5279	51	15C
0005435372720	5279	52	15A
0005434823743	5279	53	15E
0005435735081	5279	54	15F
0005435372782	5279	55	16A
0005434823752	5279	56	15K
0005434823648	5279	57	16C
0005435372661	5279	58	16F
0005435372991	5279	59	16E
0005434823669	5279	60	16K
0005432121348	5279	61	16G
0005434823729	5279	62	17C
0005435372814	5279	63	17A
0005434823745	5279	64	17E
0005434828696	5279	65	17F
0005434823705	5279	66	17H
0005434823689	5279	67	18C
0005434558286	5279	68	18A
0005434823700	5279	69	18E
0005434823677	5279	70	18D
0005435661909	5279	71	18G
0005434823717	5279	72	18K
0005435372645	5279	73	18J
0005432121349	5279	74	18H
0005435372660	5279	75	19A
0005435661908	5279	76	19C
0005435735095	5279	77	19B
0005434828699	5279	78	19F
0005435372687	5279	79	19J
0005435372666	5279	80	19K
0005434823742	5279	81	20C
0005435372746	5279	82	20D
0005434558283	5279	83	20G
0005434823653	5279	84	20F
0005434823679	5279	85	20K
0005434823733	5279	86	20J
0005434823652	5279	87	21B
0005434823740	5279	88	21G
0005434823672	5279	89	21F
0005434823756	5279	90	21E
0005435386526	5279	91	21J
0005434823654	5279	92	21H
0005434823659	5279	93	22A
0005435386512	5279	94	21K
0005434558281	5279	95	22C
0005434823761	5279	96	22F
0005434823744	5279	97	22E
0005432121342	5279	98	22D
0005435372794	5279	99	22H
0005434823706	5279	100	22G
0005435373077	5279	101	22K
0005434664960	5279	102	22J
0005434823719	5279	103	23D
0005434823730	5279	104	23G
0005434823728	5279	105	23F
0005434823678	5279	106	23E
0005435372701	5279	107	23H
0005434823684	5279	108	24D
0005434823693	5279	109	24F
0005435150044	5279	110	24E
0005435372585	5279	111	25A
0005434823675	5279	112	24G
0005434823748	5279	113	25D
0005434823739	5279	114	25C
0005434823665	5279	115	25F
0005434823776	5279	116	25E
0005435372595	5279	117	25G
0005432121344	5279	118	25K
0005432823432	5279	119	26B
0005434823703	5279	120	26A
0005434823664	5279	121	26F
0005435372748	5279	122	26D
0005435372586	5279	123	26K
0005434823736	5279	124	26J
0005434823759	5279	125	27A
0005432121352	5279	126	27C
0005432121354	5279	127	27F
0005434823692	5279	128	27E
0005435373032	5279	129	27J
0005435304118	5279	130	28C
0005435372617	5279	131	28B
0005435150047	5279	132	28A
0005432396247	5279	133	28D
0005434823754	5279	134	28G
0005434823764	5279	135	28F
0005435150051	5279	136	28E
0005435372813	5279	137	28K
0005434823713	5279	138	28J
0005435372947	5279	139	29B
0005434823746	5279	140	29A
0005434823681	5279	141	29D
0005432121351	5279	142	29F
0005435373016	5279	143	29E
0005432396245	5279	144	29J
0005434823755	5279	145	29G
0005434823721	5279	146	29K
0005434823731	5279	147	30C
0005435372743	5279	148	30B
0005435150038	5279	149	30A
0005434823667	5279	150	30D
0005432121350	5279	151	30G
0005434823757	5279	152	30F
0005435372659	5279	153	30J
0005435372622	5279	154	30H
0005434823687	5279	155	31A
0005435372646	5279	156	30K
0005435150042	5279	157	31C
0005434831153	5279	158	31B
0005432121346	5279	159	31F
0005434823670	5279	160	31E
0005432394109	5279	161	31G
0005435386500	5279	162	31J
0005434823702	5279	163	32C
0005434823724	5279	164	32B
0005435735083	5279	165	32D
0005434823699	5279	166	32J
0005434823722	5279	167	32H
0005434823709	5279	168	33B
0005434823751	5279	169	33A
0005435372721	5279	170	33D
0005435372711	5279	171	33F
0005434823773	5279	172	33E
0005434823769	5279	173	33J
0005434831152	5279	174	33H
0005435150046	5279	175	33G
0005434823691	5279	176	33K
0005435372912	5279	177	34C
0005434823726	5279	178	34B
0005435735107	5279	179	34F
0005434831154	5279	180	34K
0005434823656	5279	181	34J
0005435372606	5279	182	35B
0005432396246	5279	183	35A
0005434823774	5279	184	35C
0005435304131	5279	185	35F
0005434823750	5279	186	35E
0005435372623	5279	187	35H
0005434823668	5279	188	35G
0005434823758	5279	189	36A
0005434828697	5279	190	35K
0005434823690	5279	191	36B
0005434823698	5279	192	36F
0005435372817	5279	193	36D
0005435386501	5279	194	36G
0005434823760	5279	195	36K
0005435372753	5279	196	36J
0005432121345	5279	197	36H
0005435372742	5279	198	37A
0005435150040	5279	199	37E
0005434823749	5279	200	37D
0005435372710	5279	201	37C
0005434823649	5279	202	37J
0005434823727	5279	203	37H
0005434823768	5279	204	37G
0005435372718	5279	205	38A
0005435372850	5279	206	37K
0005434823695	5279	207	38K
0005434823650	5279	208	38H
0005434823775	5279	209	39B
0005435372747	5279	210	39D
0005434823694	5279	211	39E
0005434823680	5279	212	39K
0005434823662	5279	213	40B
0005434823771	5279	214	40H
0005432121353	5279	215	40F
0005435373076	5279	216	40J
0005435372860	5279	217	41B
0005434823714	5279	218	41D
0005435372990	5279	219	41F
0005434823685	5279	220	41G
0005434664962	5279	221	42C
0005434823676	5279	222	42B
0005434823716	5279	223	42D
0005435372890	5279	224	42G
0005434558285	5279	225	42F
0005435372844	5279	226	42K
0005435372466	5279	227	42J
0005434828698	5279	228	43A
0005434831151	5279	229	43D
0005435372994	5279	230	43C
0005435150043	5279	231	43E
0005434823696	5279	232	43G
0005435372525	5279	233	43K
0005434558284	5279	234	44A
0005435661901	5279	235	44E
0005435304120	5279	236	44D
0005434823663	5279	237	44H
0005434823688	5279	238	44F
0005435372769	5279	239	44J
0005435372571	5279	240	45B
0005435386511	5279	241	45A
0005435372572	5279	242	45C
0005434823732	5279	243	45F
0005435372632	5279	244	45D
0005435150045	5279	245	45J
0005434558282	5279	246	45H
0005435150041	5279	247	45G
0005435304127	5279	248	46A
0005435372800	5279	249	45K
0005434823701	5279	250	46C
0005435372631	5279	251	46E
0005435661902	5279	252	46G
0005434823682	5279	253	46H
0005434664961	5279	254	47E
0005434823671	5279	255	47D
0005435735094	5279	256	47G
0005434823661	5279	257	47F
0005434823711	5279	258	47H
0005434823683	5279	259	48E
0005432121347	5279	260	48H
0005434823767	5279	261	48G
0005434823747	5279	262	49C
0005435372752	5279	263	49A
0005435372719	5279	264	48K
0005434823704	5279	265	49D
0005434823718	5279	266	49G
0005434823708	5279	267	49K
0005435150037	5279	268	49H
0005434823707	5279	269	50C
0005435372662	5279	270	50A
0005435304121	5279	271	50E
0005432121355	5279	272	50D
0005434823770	5279	273	50G
0005432394108	5279	274	50F
0005435661900	5279	275	51D
0005435373015	5279	276	50K
0005434823651	5279	277	50H
0005434823712	5279	278	51F
0005434823710	5279	279	51E
0005434822367	9922	1	1C
0005435373331	9922	2	1A
0005435373351	9922	3	1H
0005434822379	9922	4	1G
0005434822644	9922	5	1D
0005432396204	9922	6	2A
0005434822886	9922	7	2H
0005434822375	9922	8	3A
0005434822713	9922	9	3K
0005434822254	9922	10	3H
0005435373322	9922	11	4H
0005435386572	9922	12	5D
0005434822814	9922	13	5A
0005435373342	9922	14	5H
0005432396206	9922	15	5G
0005435149878	9922	16	5K
0005434822613	9922	17	11E
0005434821905	9922	18	11D
0005435373336	9922	19	11G
0005434822889	9922	20	11F
0005434822686	9922	21	11H
0005432203071	9922	22	12D
0005434822612	9922	23	12F
0005435373296	9922	24	12K
0005432400082	9922	25	12H
0005434823007	9922	26	13F
0005434822828	9922	27	13H
0005435299782	9922	28	13G
0005434828668	9922	29	14A
0005434822468	9922	30	13K
0005434822882	9922	31	14E
0005434822590	9922	32	14D
0005435373303	9922	33	14C
0005434822655	9922	34	14K
0005434822515	9922	35	15E
0005435373312	9922	36	15D
0005434822404	9922	37	15G
0005435735143	9922	38	16A
0005435373335	9922	39	15K
0005434822090	9922	40	16C
0005435373302	9922	41	16E
0005435386575	9922	42	16K
0005434822778	9922	43	17C
0005435661933	9922	44	17A
0005435386573	9922	45	17E
0005435373300	9922	46	17G
0005435373337	9922	47	17F
0005434822768	9922	48	17K
0005434558210	9922	49	17H
0005432203073	9922	50	18E
0005432396213	9922	51	18C
0005435373338	9922	52	18J
0005435299778	9922	53	19A
0005434822542	9922	54	18K
0005435373324	9922	55	19F
0005435373327	9922	56	19G
0005434822182	9922	57	19K
0005435373326	9922	58	20C
0005434822332	9922	59	20B
0005434822183	9922	60	20E
0005432203069	9922	61	20D
0005435373295	9922	62	20H
0005434822695	9922	63	20G
0005434822826	9922	64	20F
0005434822089	9922	65	20K
0005434822378	9922	66	21B
0005434822373	9922	67	21D
0005435373323	9922	68	21E
0005434823102	9922	69	22A
0005435373305	9922	70	21K
0005434822640	9922	71	22C
0005434558207	9922	72	22B
0005435373318	9922	73	22F
0005435373341	9922	74	22E
0005435373345	9922	75	22G
0005432396209	9922	76	23B
0005434822617	9922	77	23A
0005435373317	9922	78	22K
0005434822712	9922	79	23G
0005434822574	9922	80	23F
0005434822436	9922	81	23J
0005435373354	9922	82	23H
0005435373316	9922	83	24D
0005434822595	9922	84	25A
0005435661935	9922	85	24G
0005434822437	9922	86	25F
0005434822692	9922	87	25E
0005434822760	9922	88	25H
0005435302203	9922	89	25K
0005434822827	9922	90	26C
0005435373344	9922	91	26A
0005434823083	9922	92	26D
0005434822255	9922	93	26G
0005435373339	9922	94	26F
0005435373350	9922	95	26K
0005435373348	9922	96	26H
0005435373321	9922	97	27C
0005434831103	9922	98	27F
0005435373297	9922	99	27D
0005435386578	9922	100	27G
0005432203072	9922	101	27K
0005434823008	9922	102	27J
0005434823130	9922	103	28E
0005435373357	9922	104	28D
0005434822200	9922	105	28G
0005435373359	9922	106	28F
0005435373325	9922	107	28K
0005434822139	9922	108	28H
0005434822133	9922	109	29D
0005435373360	9922	110	29B
0005434831091	9922	111	29F
0005434822883	9922	112	29E
0005435386576	9922	113	29H
0005434822759	9922	114	29K
0005434558208	9922	115	30C
0005435386574	9922	116	30E
0005434822580	9922	117	30F
0005435373355	9922	118	30K
0005434822857	9922	119	30J
0005435735142	9922	120	30H
0005432396214	9922	121	31D
0005434558201	9922	122	31C
0005432823453	9922	123	31B
0005435299780	9922	124	31J
0005435373347	9922	125	31G
0005435661934	9922	126	32A
0005435373340	9922	127	31K
0005434822856	9922	128	32C
0005434822935	9922	129	32B
0005434821906	9922	130	32E
0005434822267	9922	131	32G
0005434822201	9922	132	32F
0005435302204	9922	133	32J
0005434822602	9922	134	32H
0005434823108	9922	135	33D
0005434822253	9922	136	33C
0005435373309	9922	137	33H
0005432396205	9922	138	34E
0005434822689	9922	139	34F
0005435149945	9922	140	34J
0005432396208	9922	141	34H
0005435373320	9922	142	35A
0005435299781	9922	143	35D
0005434822725	9922	144	35B
0005435373334	9922	145	35F
0005434823006	9922	146	35J
0005435299779	9922	147	36F
0005434822673	9922	148	36D
0005435373314	9922	149	36H
0005434558202	9922	150	36K
0005435373352	9922	151	36J
0005432400084	9922	152	37A
0005434822716	9922	153	37D
0005432400083	9922	154	37F
0005435373294	9922	155	37H
0005434822769	9922	156	37G
0005434822658	9922	157	38A
0005434823082	9922	158	37K
0005435373319	9922	159	38C
0005432823454	9922	160	38B
0005434822670	9922	161	38J
0005434822531	9922	162	38H
0005434822598	9922	163	39B
0005435373298	9922	164	39A
0005435373308	9922	165	38K
0005434822224	9922	166	39D
0005434822986	9922	167	39F
0005435373315	9922	168	39E
0005434822597	9922	169	39J
0005434822288	9922	170	40A
0005434822591	9922	171	39K
0005432203070	9922	172	40B
0005434822370	9922	173	40E
0005434822184	9922	174	40D
0005434822138	9922	175	40G
0005435373332	9922	176	40K
0005435149879	9922	177	40J
0005435735141	9922	178	41B
0005434823129	9922	179	41A
0005434822903	9922	180	41D
0005435373346	9922	181	41G
0005435373311	9922	182	41H
0005434822783	9922	183	42A
0005435373330	9922	184	41K
0005434822721	9922	185	42B
0005434822702	9922	186	42D
0005434822594	9922	187	42F
0005434822198	9922	188	43B
0005434822869	9922	189	43A
0005435373301	9922	190	43C
0005435373333	9922	191	43E
0005434831109	9922	192	43H
0005434822910	9922	193	43G
0005435149944	9922	194	44A
0005434822782	9922	195	43J
0005434822374	9922	196	44E
0005432396219	9922	197	44G
0005434822544	9922	198	44F
0005434823055	9922	199	44K
0005435373343	9922	200	44H
0005435373353	9922	201	45C
0005435373358	9922	202	45E
0005435373310	9922	203	45J
0005434822601	9922	204	45G
0005434822672	9922	205	46A
0005435302202	9922	206	45K
0005435373349	9922	207	46B
0005434822657	9922	208	46D
0005435149934	9922	209	46H
0005434822306	9922	210	46G
0005434822287	9922	211	46F
0005434822302	9922	212	46J
0005435373304	9922	213	47C
0005435373299	9922	214	47A
0005434822197	9922	215	46K
0005434822443	9922	216	47E
0005434822509	9922	217	47D
0005435149915	9922	218	47G
0005434558209	9922	219	47H
0005434822199	9922	220	48A
0005435373307	9922	221	48E
0005434822586	9922	222	48G
0005434822985	9922	223	48F
0005432203068	9922	224	49A
0005435149939	9922	225	48K
0005435373329	9922	226	49D
0005434822703	9922	227	49F
0005435373313	9922	228	49E
0005434822543	9922	229	49K
0005434822256	9922	230	50C
0005434822405	9922	231	50A
0005434822064	9922	232	50F
0005434822836	9922	233	50E
0005434822867	9922	234	50D
0005434822678	9922	235	50H
0005434822685	9922	236	50G
0005435373306	9922	237	50K
0005435386577	9922	238	51F
0005435373356	9922	239	51E
0005435373328	9922	240	51G
0005435082793	6992	1	1C
0005435082792	6992	2	1D
0005435790309	6992	3	2A
0005435082788	6992	4	3C
0005435790308	6992	5	4D
0005435082789	6992	6	6C
0005435790310	6992	7	7A
0005435082791	6992	8	18A
0005435082790	6992	9	18D
0005435082794	6992	10	20D
0005435790298	25974	1	1A
0005435790297	25974	2	2C
0005435082740	25974	3	3B
0005435790295	25974	4	3D
0005435082716	25974	5	4B
0005435082728	25974	6	4C
0005435082717	25974	7	4D
0005435082726	25974	8	6C
0005435082723	25974	9	20B
0005435082724	25974	10	21B
0005435082738	25974	11	22B
0005435082727	25974	12	22D
0005434756455	9565	1	1C
0005434214087	9565	2	1A
0005434756465	9565	3	1D
0005434756449	9565	4	1F
0005434756459	9565	5	2A
0005434214123	9565	6	2C
0005434756450	9565	7	2D
0005434756469	9565	8	2F
0005434214150	9565	9	3A
0005434214117	9565	10	3C
0005434756456	9565	11	3D
0005434756454	9565	12	3F
0005434214281	9565	13	4A
0005434213969	9565	14	4C
0005434214126	9565	15	4D
0005434214099	9565	16	4E
0005434756446	9565	17	4F
0005434214154	9565	18	5A
0005434214013	9565	19	5C
0005434756452	9565	20	5D
0005434213979	9565	21	5E
0005434213961	9565	22	5F
0005434214182	9565	23	6A
0005434214121	9565	24	6E
0005434756458	9565	25	6F
0005434214232	9565	26	7A
0005434214312	9565	27	7C
0005434214118	9565	28	7D
0005434214079	9565	29	7E
0005434214120	9565	30	7F
0005434214309	9565	31	8A
0005434214080	9565	32	8C
0005434756451	9565	33	8D
0005434214223	9565	34	8E
0005434756460	9565	35	8F
0005434213981	9565	36	9A
0005434214167	9565	37	9C
0005434214086	9565	38	9D
0005434214198	9565	39	9F
0005434214197	9565	40	10C
0005434756457	9565	41	10D
0005434214058	9565	42	10E
0005434214193	9565	43	10F
0005434214245	9565	44	11A
0005434214170	9565	45	11C
0005434214195	9565	46	11D
0005434756467	9565	47	11E
0005434756448	9565	48	11F
0005434214220	9565	49	12A
0005434214122	9565	50	12C
0005434214234	9565	51	12E
0005434214247	9565	52	12F
0005434756463	9565	53	13A
0005434214221	9565	54	13C
0005434213933	9565	55	13D
0005434214067	9565	56	13E
0005434756461	9565	57	13F
0005434213962	9565	58	14A
0005434756466	9565	59	14C
0005434214153	9565	60	14D
0005434213959	9565	61	14E
0005434214194	9565	62	14F
0005434214222	9565	63	15A
0005434214250	9565	64	15C
0005434214171	9565	65	15D
0005434214280	9565	66	15E
0005434213847	9565	67	15F
0005434214125	9565	68	16A
0005434214089	9565	69	16C
0005434213958	9565	70	16D
0005434756462	9565	71	16F
0005434214179	9565	72	17A
0005434214233	9565	73	17C
0005434213846	9565	74	17D
0005434214204	9565	75	17E
0005434214064	9565	76	17F
0005434756464	9565	77	18A
0005434213982	9565	78	18C
0005434214231	9565	79	18D
0005434214012	9565	80	18F
0005434214199	9565	81	19A
0005434756447	9565	82	19C
0005434214310	9565	83	19D
0005434214190	9565	84	19E
0005434214063	9565	85	19F
0005434213934	9565	86	20A
0005434214027	9565	87	20C
0005434214200	9565	88	20D
0005434756453	9565	89	20E
0005434756468	9565	90	20F
0005434755858	28642	1	1A
0005434756186	28642	2	1C
0005434755947	28642	3	1D
0005434214527	28642	4	1F
0005434214524	28642	5	2A
0005434756098	28642	6	2C
0005434756066	28642	7	2D
0005434214532	28642	8	2F
0005434214536	28642	9	3A
0005434214552	28642	10	3C
0005434214553	28642	11	3D
0005434755964	28642	12	4A
0005434756127	28642	13	4C
0005434756094	28642	14	4D
0005434214547	28642	15	4E
0005434214528	28642	16	4F
0005434214516	28642	17	5A
0005434756058	28642	18	5C
0005434756093	28642	19	5D
0005434214521	28642	20	5E
0005434214512	28642	21	5F
0005434756023	28642	22	6A
0005434756052	28642	23	6C
0005434214551	28642	24	6D
0005434755974	28642	25	6E
0005434214539	28642	26	6F
0005434214514	28642	27	7A
0005434756016	28642	28	7C
0005434214549	28642	29	7E
0005434756077	28642	30	7F
0005434755945	28642	31	8A
0005434214541	28642	32	8C
0005434755962	28642	33	8D
0005434214534	28642	34	8E
0005434756074	28642	35	8F
0005434214515	28642	36	9A
0005434756078	28642	37	9C
0005434756104	28642	38	9D
0005434756073	28642	39	9F
0005434756117	28642	40	10A
0005434755898	28642	41	10C
0005434214531	28642	42	10E
0005434756086	28642	43	10D
0005434214529	28642	44	10F
0005434214545	28642	45	11A
0005434755946	28642	46	11C
0005434214508	28642	47	11D
0005434755897	28642	48	11E
0005434756172	28642	49	11F
0005434214533	28642	50	12A
0005434214544	28642	51	12C
0005434756079	28642	52	12D
0005434756091	28642	53	12E
0005434755948	28642	54	12F
0005434214555	28642	55	13A
0005434756119	28642	56	13C
0005434214542	28642	57	13E
0005434756130	28642	58	13F
0005434214517	28642	59	14A
0005434214546	28642	60	14C
0005434756070	28642	61	14D
0005434214526	28642	62	14E
0005434756001	28642	63	14F
0005434755982	28642	64	15A
0005434214537	28642	65	15C
0005434214550	28642	66	15E
0005434214518	28642	67	15F
0005434214510	28642	68	16A
0005434214535	28642	69	16C
0005434756027	28642	70	16D
0005434214554	28642	71	16F
0005434214525	28642	72	17A
0005434214519	28642	73	17C
0005434214556	28642	74	17D
0005434214543	28642	75	17E
0005434214509	28642	76	17F
0005434756092	28642	77	18A
0005434214538	28642	78	18C
0005434214513	28642	79	18D
0005434756051	28642	80	18E
0005434755883	28642	81	18F
0005434214540	28642	82	19A
0005434214530	28642	83	19C
0005434755961	28642	84	19D
0005434214520	28642	85	19E
0005434756017	28642	86	19F
0005434214523	28642	87	20A
0005434214522	28642	88	20C
0005434214511	28642	89	20D
0005434214548	28642	90	20E
0005434756048	28642	91	20F
0005435100127	10830	1	1A
0005434760172	10830	2	2A
0005435100126	10830	3	20D
0005435100098	31821	1	4B
0005435100112	31821	2	5B
0005434760200	31821	3	7C
0005434760201	31821	4	7D
0005435100102	31821	5	18C
0005435100113	31821	6	21A
0005435100097	31821	7	21B
0005434639343	1956	1	1A
0005434639361	1956	2	1C
0005432290637	1956	3	1D
0005433202263	1956	4	2A
0005432290635	1956	5	2C
0005433202257	1956	6	2B
0005432290638	1956	7	2D
0005434639344	1956	8	3A
0005434639353	1956	9	3B
0005433202267	1956	10	3C
0005434639348	1956	11	3D
0005434639357	1956	12	4A
0005434639345	1956	13	4B
0005433202226	1956	14	4C
0005433202194	1956	15	4D
0005434639352	1956	16	5A
0005433202197	1956	17	5B
0005434639355	1956	18	5C
0005434639366	1956	19	5D
0005434639360	1956	20	6A
0005433202193	1956	21	6B
0005434639341	1956	22	6C
0005433202201	1956	23	6D
0005433202273	1956	24	7A
0005433202196	1956	25	7B
0005433202280	1956	26	7C
0005434639354	1956	27	7D
0005434639363	1956	28	18A
0005434639342	1956	29	18B
0005434639350	1956	30	18C
0005434639346	1956	31	18D
0005434639362	1956	32	19A
0005434639339	1956	33	19B
0005433202293	1956	34	19C
0005434639351	1956	35	19D
0005434639356	1956	36	20A
0005433202260	1956	37	20B
0005433202216	1956	38	20C
0005434639347	1956	39	20D
0005433202261	1956	40	21A
0005433202192	1956	41	21B
0005434639349	1956	42	21C
0005434639340	1956	43	21D
0005434639358	1956	44	22A
0005433202262	1956	45	22B
0005432290636	1956	46	22C
0005434639365	1956	47	22D
0005434639364	1956	48	23A
0005434639359	1956	49	23B
0005434639028	23277	1	1A
0005434639174	23277	2	1B
0005434639023	23277	3	1C
0005433202362	23277	4	1D
0005433202367	23277	5	2A
0005433202365	23277	6	2B
0005433202359	23277	7	2D
0005433202369	23277	8	3A
0005434639186	23277	9	3B
0005434639175	23277	10	3C
0005433202360	23277	11	4A
0005434639037	23277	12	4B
0005434639187	23277	13	4D
0005434639078	23277	14	5A
0005434639061	23277	15	5B
0005433202366	23277	16	5C
0005433202358	23277	17	5D
0005434639220	23277	18	6A
0005434639077	23277	19	6B
0005433202371	23277	20	6C
0005434639062	23277	21	6D
0005434639165	23277	22	7B
0005434639155	23277	23	7C
0005433202361	23277	24	7D
0005435948313	23277	25	18B
0005434639116	23277	26	18D
0005434639185	23277	27	19A
0005433202372	23277	28	19B
0005434639084	23277	29	19C
0005434639004	23277	30	19D
0005434639117	23277	31	20A
0005434639104	23277	32	20C
0005433202364	23277	33	20D
0005433202373	23277	34	21A
0005433202363	23277	35	21B
0005433202368	23277	36	21C
0005434638971	23277	37	21D
0005434639154	23277	38	22A
0005433202370	23277	39	22B
0005435948312	23277	40	22C
0005434639024	23277	41	22D
0005434639088	23277	42	23A
0005434639060	23277	43	23B
0005434600827	6078	1	1A
0005434600828	6078	2	1D
0005434600839	6078	3	1F
0005434600838	6078	4	2A
0005433533313	6078	5	2C
0005435326617	6078	6	2F
0005435326708	6078	7	3A
0005433531299	6078	8	3C
0005434600840	6078	9	3D
0005434600830	6078	10	4A
0005433531296	6078	11	4C
0005434600831	6078	12	4D
0005434600836	6078	13	4F
0005434600846	6078	14	5E
0005434600849	6078	15	5F
0005434600832	6078	16	6F
0005433533312	6078	17	7C
0005434600850	6078	18	8F
0005434600829	6078	19	9E
0005433531300	6078	20	9F
0005434600843	6078	21	10A
0005435326654	6078	22	11C
0005435326594	6078	23	11E
0005434600848	6078	24	11F
0005434600837	6078	25	13A
0005432111280	6078	26	13C
0005434600833	6078	27	13D
0005434600824	6078	28	13F
0005433531297	6078	29	14A
0005435326619	6078	30	14F
0005432111283	6078	31	15A
0005434600847	6078	32	15C
0005434600842	6078	33	15D
0005435326681	6078	34	15E
0005432111281	6078	35	15F
0005433533310	6078	36	16C
0005434600845	6078	37	16D
0005434600844	6078	38	16E
0005432111282	6078	39	16F
0005434600834	6078	40	17A
0005434600835	6078	41	17C
0005434600823	6078	42	17E
0005433531298	6078	43	18A
0005434600825	6078	44	18C
0005435326648	6078	45	18F
0005435326618	6078	46	19A
0005433533311	6078	47	19C
0005434600826	6078	48	19E
0005434600841	6078	49	19F
0005435326649	6078	50	20A
0005433531295	6078	51	20C
0005434600549	18577	1	2A
0005434600672	18577	2	2C
0005434600514	18577	3	3A
0005434600602	18577	4	3C
0005434600591	18577	5	3F
0005434600637	18577	6	4C
0005433527206	18577	7	4E
0005435326756	18577	8	5A
0005434600635	18577	9	5D
0005435326754	18577	10	5F
0005434600596	18577	11	6A
0005434600679	18577	12	6C
0005434600552	18577	13	6E
0005435326762	18577	14	6F
0005434600525	18577	15	7C
0005435326763	18577	16	7D
0005433527227	18577	17	7F
0005434600633	18577	18	8D
0005434600582	18577	19	8C
0005435326759	18577	20	8E
0005433527233	18577	21	8F
0005434600675	18577	22	9A
0005435326765	18577	23	9E
0005434600583	18577	24	9F
0005434600571	18577	25	10C
0005434600708	18577	26	10D
0005434600624	18577	27	10E
0005433527231	18577	28	10F
0005435326752	18577	29	11A
0005433527232	18577	30	11C
0005435326761	18577	31	11D
0005434600513	18577	32	11F
0005433527228	18577	33	12C
0005434600616	18577	34	12F
0005435326758	18577	35	13E
0005435326755	18577	36	14D
0005434600707	18577	37	14E
0005435326764	18577	38	14F
0005435326753	18577	39	15C
0005434600572	18577	40	15D
0005434600445	18577	41	15F
0005434600485	18577	42	16A
0005434600678	18577	43	17C
0005434600601	18577	44	17D
0005434600628	18577	45	17E
0005434600650	18577	46	18C
0005435326757	18577	47	18D
0005434600466	18577	48	18F
0005434600548	18577	49	19C
0005434600573	18577	50	19E
0005434600636	18577	51	19F
0005435326760	18577	52	20C
0005433527205	18577	53	20D
0005434600574	18577	54	20E
0005433531279	18577	55	20F
0005434551218	10659	1	1A
0005434551250	10659	2	1C
0005434551263	10659	3	1D
0005434551261	10659	4	1F
0005433180871	10659	5	2A
0005434551235	10659	6	2C
0005434551225	10659	7	2D
0005434551245	10659	8	2F
0005434551255	10659	9	3A
0005434551240	10659	10	3C
0005434558278	10659	11	3D
0005433180931	10659	12	3F
0005433180812	10659	13	4A
0005434551259	10659	14	4C
0005434558277	10659	15	4D
0005434558279	10659	16	4E
0005434551220	10659	17	4F
0005434551258	10659	18	5A
0005434558271	10659	19	5C
0005434558268	10659	20	5D
0005434551214	10659	21	5E
0005433180756	10659	22	5F
0005434551266	10659	23	6A
0005434551254	10659	24	6C
0005434558274	10659	25	6D
0005434551265	10659	26	6E
0005434551239	10659	27	6F
0005434551219	10659	28	7A
0005434551227	10659	29	7C
0005434551248	10659	30	7D
0005434558276	10659	31	7E
0005434554066	10659	32	7F
0005433180797	10659	33	8A
0005434551226	10659	34	8C
0005433180808	10659	35	8D
0005433180854	10659	36	8E
0005433180815	10659	37	8F
0005434551256	10659	38	9A
0005434551257	10659	39	9E
0005434551234	10659	40	9D
0005434551215	10659	41	9F
0005433180865	10659	42	10A
0005434558269	10659	43	10C
0005434551252	10659	44	10D
0005433180795	10659	45	10E
0005434551229	10659	46	10F
0005433180863	10659	47	11A
0005434551249	10659	48	11C
0005434551228	10659	49	11E
0005433180874	10659	50	11F
0005433180864	10659	51	12A
0005434551260	10659	52	12C
0005434551223	10659	53	12D
0005433180877	10659	54	12E
0005434551233	10659	55	12F
0005433180981	10659	56	13A
0005434558275	10659	57	13C
0005434551222	10659	58	13D
0005433180796	10659	59	13E
0005434551246	10659	60	13F
0005434551236	10659	61	14A
0005434558272	10659	62	14C
0005434551267	10659	63	14D
0005434551230	10659	64	14E
0005434551241	10659	65	14F
0005434558280	10659	66	15A
0005434551232	10659	67	15D
0005434551244	10659	68	15C
0005434558273	10659	69	15E
0005434551262	10659	70	15F
0005434551253	10659	71	16A
0005434551212	10659	72	16C
0005433180862	10659	73	16D
0005433180809	10659	74	16E
0005433180846	10659	75	16F
0005434558270	10659	76	17A
0005434551221	10659	77	17C
0005434554067	10659	78	17D
0005434551213	10659	79	17E
0005434551251	10659	80	17F
0005433180757	10659	81	18A
0005434551217	10659	82	18C
0005434551247	10659	83	18D
0005434551216	10659	84	18E
0005434551242	10659	85	18F
0005434551264	10659	86	19A
0005433181017	10659	87	19C
0005434551243	10659	88	19D
0005433180932	10659	89	19E
0005434551238	10659	90	19F
0005434551237	10659	91	20A
0005434551224	10659	92	20C
0005433180842	10659	93	20D
0005434551231	10659	94	20E
0005433180875	10659	95	20F
0005433181113	27772	1	2F
0005433181125	27772	2	3D
0005433181132	27772	3	4F
0005433181118	27772	4	5E
0005433181136	27772	5	6A
0005433181120	27772	6	7A
0005433181123	27772	7	7C
0005433181134	27772	8	8F
0005433181119	27772	9	10F
0005433181121	27772	10	11D
0005433181122	27772	11	12A
0005433181116	27772	12	12C
0005433181137	27772	13	12D
0005433181133	27772	14	12F
0005433181135	27772	15	13F
0005433181131	27772	16	14C
0005433181117	27772	17	14E
0005433181129	27772	18	14F
0005433181114	27772	19	15D
0005433181127	27772	20	16C
0005433181128	27772	21	17C
0005433181126	27772	22	17E
0005433181124	27772	23	18A
0005433181130	27772	24	18F
0005433181115	27772	25	20A
0005433181138	27772	26	20D
0005434550904	27773	1	1A
0005434558211	27773	2	1C
0005434550692	27773	3	1D
0005434550566	27773	4	1F
0005434550809	27773	5	2A
0005434550401	27773	6	2F
0005434550893	27773	7	3C
0005434550678	27773	8	3D
0005434550877	27773	9	3F
0005434550586	27773	10	4A
0005434550865	27773	11	4D
0005434550584	27773	12	4F
0005434558213	27773	13	5A
0005434550863	27773	14	5C
0005434550590	27773	15	5E
0005434550828	27773	16	5F
0005434558197	27773	17	6C
0005434558186	27773	18	6D
0005434554050	27773	19	6E
0005434550838	27773	20	6F
0005434558199	27773	21	7C
0005434558217	27773	22	7D
0005434550764	27773	23	8C
0005434550783	27773	24	8D
0005434550778	27773	25	9A
0005434550646	27773	26	9C
0005434550647	27773	27	9D
0005434551023	27773	28	9E
0005434550648	27773	29	9F
0005434550564	27773	30	10A
0005434550664	27773	31	10D
0005434550788	27773	32	10E
0005434550565	27773	33	11C
0005434550823	27773	34	11D
0005434558218	27773	35	11E
0005434558212	27773	36	11F
0005434550691	27773	37	12A
0005434550892	27773	38	12E
0005434550494	27773	39	13A
0005434550724	27773	40	13E
0005434550587	27773	41	14A
0005434550765	27773	42	14C
0005434550698	27773	43	14E
0005434550775	27773	44	15A
0005434550563	27773	45	15F
0005434550979	27773	46	16C
0005434558175	27773	47	16F
0005434558200	27773	48	17A
0005434550866	27773	49	17D
0005434550732	27773	50	18A
0005434550766	27773	51	18D
0005434550787	27773	52	18F
0005434550864	27773	53	19C
0005434558191	27773	54	19D
0005434550744	27773	55	19E
0005434550773	27773	56	20A
0005434558216	27773	57	20C
0005434550774	27773	58	20E
0005434558203	27773	59	20F
0005435254446	6118	1	1A
0005435254454	6118	2	1B
0005435254463	6118	3	2B
0005433459223	6118	4	3A
0005433459222	6118	5	3B
0005433459225	6118	6	4A
0005435254464	6118	7	5A
0005435254445	6118	8	5B
0005433459224	6118	9	6A
0005435254456	6118	10	6B
0005435254478	19323	1	2B
0005433459183	19323	2	3A
0005433459201	19323	3	3B
0005435254477	19323	4	4B
0005433459184	19323	5	4A
0005433459202	19323	6	5B
0005435254476	19323	7	5A
0005435220306	6757	1	1A
0005435682191	6757	2	1C
0005435682156	6757	3	1D
0005432533258	6757	4	1F
0005435682163	6757	5	2A
0005435661931	6757	6	2C
0005435682188	6757	7	2D
0005434828682	6757	8	2F
0005434828677	6757	9	3A
0005435437813	6757	10	3C
0005435437881	6757	11	3D
0005435720132	6757	12	4A
0005435682197	6757	13	4C
0005435682168	6757	14	4D
0005432136175	6757	15	4E
0005435437824	6757	16	4F
0005435682190	6757	17	5A
0005435682173	6757	18	5C
0005435682169	6757	19	5D
0005435437810	6757	20	5E
0005435437782	6757	21	6A
0005435437879	6757	22	6C
0005435682182	6757	23	6D
0005435437733	6757	24	6E
0005435437734	6757	25	6F
0005435682195	6757	26	7A
0005434828678	6757	27	7C
0005432533263	6757	28	7D
0005435630968	6757	29	7E
0005435682171	6757	30	8A
0005435661932	6757	31	8D
0005435682155	6757	32	8E
0005435437809	6757	33	8F
0005435682160	6757	34	9A
0005435437931	6757	35	9C
0005435682170	6757	36	9F
0005435720134	6757	37	10C
0005435682183	6757	38	10E
0005435682162	6757	39	10F
0005435682172	6757	40	11A
0005434828663	6757	41	11C
0005435682192	6757	42	11D
0005434828664	6757	43	11E
0005435682181	6757	44	12A
0005432136172	6757	45	12C
0005435682179	6757	46	12D
0005435682186	6757	47	12E
0005435220301	6757	48	12F
0005435682178	6757	49	13A
0005435682157	6757	50	13C
0005435682167	6757	51	13D
0005435682177	6757	52	13E
0005435682158	6757	53	13F
0005435682161	6757	54	14A
0005435682165	6757	55	14C
0005434828669	6757	56	14D
0005435682194	6757	57	14E
0005435682166	6757	58	14F
0005435682196	6757	59	15A
0005435682189	6757	60	15C
0005435437930	6757	61	15D
0005435221504	6757	62	15E
0005435217695	6757	63	15F
0005435720133	6757	64	16F
0005435682174	6757	65	17C
0005435682185	6757	66	17D
0005435682187	6757	67	17E
0005435682184	6757	68	17F
0005435682193	6757	69	18A
0005435682164	6757	70	18C
0005435437880	6757	71	18E
0005435682176	6757	72	19A
0005435437770	6757	73	19C
0005435220302	6757	74	19D
0005435682175	6757	75	19E
0005435682180	6757	76	19F
0005432136173	6757	77	20A
0005432136174	6757	78	20C
0005435682159	6757	79	20F
0005435437975	24590	1	1A
0005435437969	24590	2	1D
0005432533294	24590	3	1F
0005435681730	24590	4	2C
0005435681919	24590	5	2D
0005435681775	24590	6	3A
0005432305750	24590	7	3C
0005435437982	24590	8	3D
0005435681769	24590	9	3F
0005435681912	24590	10	4C
0005435681956	24590	11	4E
0005435681857	24590	12	4F
0005434828701	24590	13	5A
0005435437981	24590	14	5C
0005435681810	24590	15	5D
0005435681864	24590	16	6C
0005432533296	24590	17	6E
0005435681839	24590	18	6F
0005435437972	24590	19	7A
0005435437967	24590	20	7C
0005435661904	24590	21	7D
0005435630947	24590	22	7E
0005435681875	24590	23	7F
0005435437973	24590	24	8C
0005435437961	24590	25	8D
0005435681777	24590	26	8E
0005435681710	24590	27	8F
0005435681643	24590	28	9A
0005435437979	24590	29	9D
0005435437978	24590	30	9E
0005434828700	24590	31	9F
0005435437977	24590	32	10A
0005435681806	24590	33	10D
0005435437963	24590	34	10E
0005435437971	24590	35	10F
0005435681930	24590	36	11A
0005435681703	24590	37	11C
0005435437974	24590	38	11D
0005435681711	24590	39	11E
0005435437965	24590	40	12A
0005435681774	24590	41	12D
0005435681745	24590	42	12E
0005435681731	24590	43	13A
0005432305751	24590	44	13D
0005435681944	24590	45	13E
0005435681804	24590	46	13F
0005435681762	24590	47	14C
0005435681763	24590	48	14D
0005435681781	24590	49	14E
0005435661903	24590	50	14F
0005435681888	24590	51	15A
0005435437968	24590	52	15C
0005435661897	24590	53	15D
0005435630945	24590	54	15E
0005435437976	24590	55	15F
0005435681712	24590	56	16A
0005435681721	24590	57	16C
0005435437966	24590	58	16D
0005435681811	24590	59	16E
0005435681878	24590	60	17A
0005435681913	24590	61	16F
0005435437980	24590	62	17C
0005435681782	24590	63	17D
0005432533293	24590	64	17E
0005435437970	24590	65	18A
0005435681865	24590	66	18C
0005435681744	24590	67	18E
0005435681732	24590	68	18F
0005432533295	24590	69	19A
0005435681630	24590	70	19C
0005435681668	24590	71	19E
0005435437962	24590	72	19F
0005435630946	24590	73	20C
0005435437964	24590	74	20D
0005435681955	24590	75	20E
0005435681951	24590	76	20F
0005435126376	11544	1	1D
0005435126391	11544	2	1F
0005435126372	11544	3	2A
0005435126355	11544	4	2C
0005435126384	11544	5	2F
0005435098559	11544	6	3A
0005435126373	11544	7	3C
0005435126381	11544	8	3D
0005435126367	11544	9	3F
0005435126379	11544	10	4A
0005435126371	11544	11	4D
0005435126361	11544	12	4E
0005435126365	11544	13	4F
0005435126388	11544	14	5C
0005435126375	11544	15	5E
0005435126364	11544	16	6A
0005435126357	11544	17	6E
0005435126387	11544	18	7D
0005435126370	11544	19	8A
0005435098553	11544	20	9A
0005435126395	11544	21	9D
0005435098555	11544	22	10A
0005435126363	11544	23	10C
0005435126360	11544	24	10E
0005435105982	11544	25	10F
0005435126390	11544	26	11A
0005435126393	11544	27	11C
0005435126359	11544	28	11F
0005435105983	11544	29	12E
0005435126392	11544	30	12F
0005435126356	11544	31	13A
0005435126383	11544	32	13D
0005435126374	11544	33	14A
0005435126368	11544	34	14C
0005435558051	11544	35	14D
0005435098556	11544	36	14E
0005435126380	11544	37	14F
0005435126386	11544	38	15E
0005435098557	11544	39	15F
0005435126385	11544	40	16A
0005435126358	11544	41	16D
0005435126369	11544	42	16E
0005435126378	11544	43	16F
0005435098554	11544	44	17D
0005435126389	11544	45	17E
0005435126362	11544	46	18E
0005435126394	11544	47	18F
0005435098558	11544	48	19A
0005435105981	11544	49	19D
0005435126377	11544	50	19E
0005435126382	11544	51	19F
0005435098552	11544	52	20A
0005435126366	11544	53	20D
0005435098560	11544	54	20F
0005435105953	31859	1	1C
0005435126019	31859	2	1D
0005435126204	31859	3	1F
0005435125852	31859	4	2A
0005435126322	31859	5	2C
0005435126057	31859	6	2D
0005435558089	31859	7	2F
0005435126147	31859	8	3C
0005435125968	31859	9	3D
0005435126182	31859	10	4C
0005435105971	31859	11	5C
0005435125906	31859	12	5E
0005435125997	31859	13	6D
0005435126040	31859	14	6E
0005435105949	31859	15	6F
0005435126137	31859	16	7A
0005435126160	31859	17	7C
0005435126206	31859	18	7F
0005435125979	31859	19	8A
0005435126230	31859	20	8D
0005435126146	31859	21	9D
0005435125919	31859	22	9E
0005435126067	31859	23	9F
0005435126180	31859	24	10D
0005435126148	31859	25	11A
0005435125969	31859	26	11C
0005435125905	31859	27	11E
0005435126205	31859	28	12A
0005435125918	31859	29	12C
0005435126028	31859	30	12D
0005435125999	31859	31	12F
0005435125898	31859	32	13C
0005435125993	31859	33	13D
0005435126138	31859	34	13F
0005435105963	31859	35	14A
0005435126055	31859	36	14C
0005435126253	31859	37	14F
0005435126058	31859	38	15C
0005435558090	31859	39	15D
0005435125851	31859	40	15E
0005435126181	31859	41	15F
0005435126161	31859	42	16A
0005435125974	31859	43	16C
0005435126066	31859	44	16D
0005435126104	31859	45	16E
0005435126159	31859	46	16F
0005435126068	31859	47	17A
0005435126098	31859	48	17C
0005435126229	31859	49	17D
0005435125962	31859	50	17E
0005435126187	31859	51	18A
0005435126173	31859	52	18C
0005435125998	31859	53	18E
0005435125920	31859	54	18F
0005435126207	31859	55	19C
0005435126070	31859	56	19E
0005435105950	31859	57	20A
0005435126105	31859	58	20F
0005433398108	13549	1	1A
0005433398103	13549	2	1C
0005433398121	13549	3	2C
0005433398088	13549	4	2D
0005433398102	13549	5	2F
0005435732259	13549	6	3A
0005433398096	13549	7	3C
0005433398093	13549	8	3F
0005433398109	13549	9	4A
0005433398100	13549	10	4C
0005435732292	13549	11	4D
0005433398112	13549	12	4E
0005433398120	13549	13	4F
0005435732276	13549	14	5A
0005433398079	13549	15	5C
0005433398080	13549	16	5E
0005433398122	13549	17	6C
0005433398113	13549	18	6E
0005433398091	13549	19	6F
0005433398098	13549	20	7A
0005433398107	13549	21	7C
0005433398094	13549	22	7F
0005433398099	13549	23	8A
0005433398095	13549	24	8E
0005435732227	13549	25	8F
0005433398097	13549	26	9A
0005433398085	13549	27	10C
0005433398084	13549	28	10E
0005433398092	13549	29	10F
0005435732281	13549	30	11E
0005433398075	13549	31	11F
0005433398083	13549	32	12A
0005433398087	13549	33	12C
0005435732192	13549	34	12D
0005433398089	13549	35	13A
0005435732226	13549	36	13D
0005433398114	13549	37	13E
0005433398077	13549	38	13F
0005433398117	13549	39	14C
0005433398082	13549	40	14D
0005433398115	13549	41	14E
0005433398106	13549	42	14F
0005433398076	13549	43	15E
0005435732247	13549	44	15F
0005433398123	13549	45	16C
0005433398081	13549	46	16E
0005435732258	13549	47	17C
0005433398116	13549	48	17D
0005433398078	13549	49	17E
0005435732291	13549	50	17F
0005433398105	13549	51	18C
0005433398111	13549	52	18D
0005433398118	13549	53	18F
0005433398086	13549	54	19A
0005433398090	13549	55	19D
0005433398104	13549	56	19E
0005435732193	13549	57	19F
0005433398101	13549	58	20C
0005433398119	13549	59	20D
0005433398110	13549	60	20E
0005435732330	19413	1	1C
0005435732327	19413	2	1D
0005433397837	19413	3	2A
0005433397611	19413	4	2C
0005433397786	19413	5	2D
0005435732344	19413	6	2F
0005435732328	19413	7	3C
0005433397792	19413	8	3D
0005433397521	19413	9	3F
0005433397626	19413	10	4A
0005433397799	19413	11	4D
0005433397684	19413	12	4E
0005433397676	19413	13	5A
0005433397800	19413	14	5C
0005433397696	19413	15	5D
0005433397657	19413	16	6A
0005433397520	19413	17	6C
0005433397535	19413	18	6E
0005433397566	19413	19	7A
0005435732339	19413	20	7C
0005435732331	19413	21	7D
0005435732342	19413	22	7E
0005435732332	19413	23	7F
0005433397644	19413	24	8C
0005433397774	19413	25	8E
0005435732335	19413	26	8F
0005433397645	19413	27	9A
0005435732333	19413	28	9E
0005433397522	19413	29	10A
0005433397625	19413	30	10D
0005433397598	19413	31	10E
0005433397801	19413	32	10F
0005435732337	19413	33	11A
0005433397536	19413	34	11D
0005433397545	19413	35	11E
0005433397791	19413	36	11F
0005433397537	19413	37	12A
0005433397692	19413	38	12C
0005433397817	19413	39	12F
0005433397798	19413	40	13C
0005435732338	19413	41	13E
0005435732345	19413	42	13F
0005435732343	19413	43	14A
0005433397761	19413	44	14C
0005433397702	19413	45	14D
0005435732336	19413	46	14E
0005433397544	19413	47	15C
0005433397977	19413	48	15D
0005432297280	19413	49	15F
0005435732346	19413	50	16A
0005433397608	19413	51	16E
0005433397780	19413	52	17A
0005433397690	19413	53	17D
0005433397381	19413	54	17E
0005432297279	19413	55	17F
0005433397807	19413	56	18A
0005435732341	19413	57	18C
0005433397978	19413	58	18D
0005432297278	19413	59	18F
0005435732329	19413	60	19C
0005433397691	19413	61	19F
0005433397766	19413	62	20A
0005433397567	19413	63	20C
0005433397808	19413	64	20D
0005435732340	19413	65	20E
0005435732334	19413	66	20F
0005435068878	13168	1	1A
0005435925296	13168	2	1D
0005435068517	13168	3	1F
0005435068721	13168	4	2C
0005435068484	13168	5	2D
0005435068694	13168	6	3C
0005435068622	13168	7	3D
0005435068461	13168	8	3F
0005435925300	13168	9	4C
0005435068650	13168	10	4D
0005435068608	13168	11	4E
0005435068485	13168	12	4F
0005435068516	13168	13	5A
0005435068503	13168	14	5C
0005435068706	13168	15	6A
0005435925301	13168	16	6C
0005435068521	13168	17	6E
0005435068424	13168	18	6F
0005435068785	13168	19	7C
0005435068701	13168	20	7D
0005435925302	13168	21	7E
0005435068758	13168	22	8A
0005435068623	13168	23	8D
0005435068513	13168	24	8E
0005435068486	13168	25	8F
0005435068687	13168	26	9A
0005435068669	13168	27	9D
0005435068586	13168	28	10C
0005435068649	13168	29	10D
0005435925303	13168	30	10F
0005435068682	13168	31	11A
0005435068506	13168	32	11C
0005435925299	13168	33	11E
0005435925295	13168	34	12A
0005435068760	13168	35	12C
0005435068398	13168	36	12D
0005435068522	13168	37	12E
0005435068514	13168	38	12F
0005435068686	13168	39	13A
0005435068702	13168	40	13C
0005435068596	13168	41	13D
0005435068515	13168	42	13E
0005435068680	13168	43	13F
0005435925298	13168	44	14A
0005435068672	13168	45	14C
0005435068648	13168	46	14D
0005435068502	13168	47	14E
0005435068696	13168	48	14F
0005435068575	13168	49	15C
0005435068805	13168	50	15D
0005435068399	13168	51	15E
0005435925304	13168	52	15F
0005435068932	13168	53	16A
0005435068722	13168	54	16C
0005435068731	13168	55	16D
0005435068757	13168	56	16E
0005435068695	13168	57	16F
0005435068606	13168	58	17C
0005435068523	13168	59	17D
0005435068749	13168	60	17E
0005435068332	13168	61	17F
0005435068681	13168	62	18A
0005435068665	13168	63	18C
0005435068691	13168	64	18D
0005435925297	13168	65	18E
0005435068653	13168	66	19A
0005435068507	13168	67	19C
0005435068663	13168	68	19D
0005435068512	13168	69	19E
0005435068743	13168	70	19F
0005435068662	13168	71	20C
0005435068806	13168	72	20F
0005435925190	15461	1	1A
0005435069099	15461	2	1D
0005435069089	15461	3	2A
0005435069107	15461	4	2C
0005435069085	15461	5	2D
0005435069104	15461	6	3A
0005435069106	15461	7	3C
0005435069068	15461	8	3D
0005435069076	15461	9	3F
0005435069082	15461	10	4A
0005435925138	15461	11	4C
0005435069110	15461	12	4E
0005435069084	15461	13	5A
0005435925128	15461	14	5E
0005435069075	15461	15	5F
0005435925137	15461	16	6A
0005435069080	15461	17	6C
0005435925191	15461	18	6D
0005435069087	15461	19	7C
0005435069109	15461	20	7E
0005435069090	15461	21	7F
0005435925160	15461	22	8A
0005435925185	15461	23	8C
0005435069092	15461	24	8E
0005435069102	15461	25	8F
0005435069101	15461	26	9A
0005435069062	15461	27	9D
0005435069098	15461	28	9E
0005435925184	15461	29	9F
0005435069067	15461	30	10A
0005435069060	15461	31	10C
0005435069088	15461	32	10D
0005435069105	15461	33	10E
0005435069094	15461	34	10F
0005435069070	15461	35	11A
0005435925171	15461	36	11C
0005435925167	15461	37	12A
0005435069072	15461	38	12C
0005435069079	15461	39	12D
0005435069083	15461	40	12E
0005435069063	15461	41	12F
0005435069074	15461	42	13A
0005435069078	15461	43	13C
0005435069096	15461	44	13D
0005435069065	15461	45	14A
0005435069077	15461	46	14C
0005435069061	15461	47	14D
0005435069073	15461	48	14F
0005435925135	15461	49	15A
0005435925131	15461	50	15C
0005435925133	15461	51	15D
0005435069103	15461	52	15E
0005435069071	15461	53	16A
0005435069066	15461	54	16C
0005435925186	15461	55	16D
0005435925187	15461	56	16F
0005435069069	15461	57	17A
0005435925132	15461	58	17C
0005435069064	15461	59	17D
0005435069086	15461	60	17E
0005435069100	15461	61	18C
0005435069108	15461	62	18F
0005435069097	15461	63	19A
0005435069093	15461	64	19D
0005435069111	15461	65	19E
0005435069081	15461	66	19F
0005435069059	15461	67	20A
0005435069091	15461	68	20C
0005435925168	15461	69	20E
0005435069095	15461	70	20F
0005433407572	29485	1	1A
0005435808117	29485	2	1C
0005435808161	29485	3	1D
0005433407574	29485	4	2A
0005433407571	29485	5	2B
0005435808111	29485	6	2C
0005435808123	29485	7	3A
0005435808118	29485	8	3D
0005433407565	29485	9	4A
0005435808087	29485	10	4D
0005435808131	29485	11	5B
0005435808088	29485	12	5C
0005435808138	29485	13	5D
0005435808169	29485	14	6A
0005433407568	29485	15	6B
0005435808114	29485	16	6C
0005435808122	29485	17	6D
0005433407570	29485	18	7A
0005433407566	29485	19	7C
0005435808097	29485	20	7D
0005433407569	29485	21	18B
0005435808119	29485	22	18C
0005435808102	29485	23	19A
0005433407567	29485	24	19B
0005435808099	29485	25	20A
0005435808137	29485	26	20B
0005435808126	29485	27	20C
0005435808139	29485	28	21B
0005435808100	29485	29	21D
0005435808132	29485	30	22A
0005435808085	29485	31	22B
0005433407573	29485	32	22D
0005435808113	29485	33	23A
0005434756170	10723	1	1A
0005434214588	10723	2	1C
0005434756128	10723	3	1D
0005434214578	10723	4	1F
0005434214596	10723	5	2A
0005434214587	10723	6	2C
0005434755993	10723	7	2D
0005434214597	10723	8	2F
0005434214568	10723	9	3A
0005434214559	10723	10	3C
0005434756054	10723	11	3D
0005434756112	10723	12	3F
0005434756111	10723	13	4A
0005434756057	10723	14	4C
0005434755913	10723	15	4D
0005434214577	10723	16	4E
0005434214589	10723	17	4F
0005434214557	10723	18	5A
0005434756168	10723	19	5C
0005434756109	10723	20	5D
0005434214573	10723	21	5E
0005434214565	10723	22	6A
0005434214558	10723	23	6C
0005434214593	10723	24	6D
0005434214575	10723	25	6E
0005434756158	10723	26	6F
0005434214561	10723	27	7A
0005434214591	10723	28	7C
0005434756025	10723	29	7D
0005434756038	10723	30	7F
0005434756211	10723	31	8A
0005434756103	10723	32	8C
0005434756136	10723	33	8D
0005434756068	10723	34	8E
0005434214570	10723	35	8F
0005434756110	10723	36	9A
0005434756039	10723	37	9C
0005434214574	10723	38	9D
0005434756053	10723	39	9F
0005434214571	10723	40	10A
0005434214567	10723	41	10C
0005434214601	10723	42	10D
0005434756227	10723	43	10E
0005434756106	10723	44	10F
0005434214585	10723	45	11A
0005434756056	10723	46	11C
0005434214572	10723	47	11D
0005434755835	10723	48	11E
0005434214560	10723	49	11F
0005434756129	10723	50	12A
0005434755916	10723	51	12C
0005434756003	10723	52	12D
0005434756010	10723	53	12E
0005434214566	10723	54	12F
0005434214569	10723	55	13A
0005434214583	10723	56	13C
0005434214564	10723	57	13D
0005434214599	10723	58	13F
0005434214576	10723	59	14A
0005434756146	10723	60	14C
0005434756174	10723	61	14D
0005434756087	10723	62	14E
0005434756164	10723	63	14F
0005434214592	10723	64	15A
0005434756097	10723	65	15C
0005434756009	10723	66	15D
0005434214584	10723	67	15E
0005434756163	10723	68	15F
0005434756264	10723	69	16A
0005434214562	10723	70	16C
0005434214579	10723	71	16D
0005434214582	10723	72	16E
0005434756055	10723	73	16F
0005434214594	10723	74	17A
0005434756185	10723	75	17C
0005434756026	10723	76	17D
0005434756159	10723	77	17E
0005434214581	10723	78	17F
0005434756007	10723	79	18A
0005434214598	10723	80	18C
0005434756184	10723	81	18D
0005434756047	10723	82	18E
0005434214595	10723	83	18F
0005434214600	10723	84	19A
0005434214580	10723	85	19D
0005434214586	10723	86	19E
0005434214563	10723	87	20A
0005434756067	10723	88	20C
0005434756024	10723	89	20D
0005434214590	10723	90	20E
0005434756134	10723	91	20F
0005434213876	28658	1	1A
0005434756444	28658	2	1C
0005434214051	28658	3	1D
0005434214001	28658	4	1F
0005434214011	28658	5	2A
0005434756420	28658	6	2C
0005434756409	28658	7	2D
0005434213897	28658	8	2F
0005434214259	28658	9	3A
0005434756434	28658	10	3C
0005434214156	28658	11	3D
0005434213947	28658	12	3F
0005434756422	28658	13	4C
0005434756413	28658	14	4A
0005434756424	28658	15	4F
0005434214202	28658	16	5A
0005434214083	28658	17	5C
0005434756418	28658	18	5D
0005434756438	28658	19	5E
0005434756430	28658	20	5F
0005434214264	28658	21	6A
0005434756429	28658	22	6C
0005434756425	28658	23	6D
0005434214287	28658	24	6E
0005434214173	28658	25	6F
0005434214158	28658	26	7A
0005434214157	28658	27	7C
0005434756427	28658	28	7D
0005434756410	28658	29	7E
0005434214073	28658	30	7F
0005434756431	28658	31	8A
0005434214133	28658	32	8C
0005434756412	28658	33	8D
0005434214050	28658	34	8F
0005434213960	28658	35	9C
0005434213911	28658	36	9D
0005434213980	28658	37	9F
0005434756445	28658	38	10A
0005434214052	28658	39	10C
0005434756419	28658	40	10D
0005434756417	28658	41	10E
0005434756440	28658	42	10F
0005434756432	28658	43	11A
0005434214092	28658	44	11C
0005434214093	28658	45	11D
0005434756408	28658	46	11F
0005434214162	28658	47	12A
0005434214131	28658	48	12C
0005434213835	28658	49	12E
0005434756426	28658	50	12F
0005434214226	28658	51	13A
0005434756433	28658	52	13C
0005434756439	28658	53	13D
0005434756416	28658	54	13E
0005434214178	28658	55	13F
0005434756428	28658	56	14A
0005434756441	28658	57	14C
0005434214062	28658	58	14E
0005434214002	28658	59	14F
0005434214139	28658	60	15A
0005434213850	28658	61	15C
0005434756443	28658	62	15D
0005434756421	28658	63	15E
0005434756414	28658	64	15F
0005434213849	28658	65	16A
0005434214203	28658	66	16C
0005434214161	28658	67	16D
0005434213938	28658	68	16E
0005434214038	28658	69	16F
0005434214132	28658	70	17A
0005434756411	28658	71	17C
0005434214275	28658	72	17D
0005434756415	28658	73	17F
0005434214110	28658	74	18A
0005434756423	28658	75	18C
0005434214060	28658	76	18E
0005434214229	28658	77	18F
0005434214039	28658	78	19A
0005434213946	28658	79	19C
0005434214172	28658	80	19D
0005434756437	28658	81	19E
0005434756435	28658	82	20A
0005434214078	28658	83	20C
0005434756436	28658	84	20D
0005434756442	28658	85	20F
0005435007046	5439	1	1A
0005435039806	5439	2	1C
0005432125455	5439	3	1F
0005435039853	5439	4	1D
0005435039850	5439	5	2C
0005434229228	5439	6	2A
0005435039833	5439	7	2D
0005432125457	5439	8	3A
0005435039801	5439	9	2F
0005435007049	5439	10	3C
0005435039823	5439	11	3D
0005435039828	5439	12	3F
0005434229265	5439	13	4A
0005435039815	5439	14	4B
0005435039865	5439	15	4D
0005435007055	5439	16	4C
0005435039836	5439	17	4E
0005435039855	5439	18	4F
0005435039837	5439	19	5B
0005435039822	5439	20	5A
0005435039861	5439	21	5C
0005435039821	5439	22	5E
0005435039825	5439	23	6A
0005432125460	5439	24	5F
0005435007057	5439	25	6B
0005434229133	5439	26	6D
0005434229164	5439	27	6C
0005434229258	5439	28	6F
0005435007062	5439	29	7A
0005435039829	5439	30	7C
0005435007070	5439	31	7B
0005435039800	5439	32	7D
0005435039844	5439	33	7F
0005435007050	5439	34	7E
0005435039858	5439	35	8B
0005435039824	5439	36	8A
0005434229175	5439	37	8C
0005434229177	5439	38	8D
0005435039842	5439	39	8F
0005435007058	5439	40	8E
0005435039805	5439	41	9A
0005435007053	5439	42	9B
0005435007044	5439	43	9D
0005435039846	5439	44	9C
0005435039820	5439	45	9E
0005435039818	5439	46	9F
0005434229227	5439	47	10B
0005435039814	5439	48	10D
0005435039827	5439	49	10C
0005435039816	5439	50	10E
0005434229154	5439	51	11A
0005435039856	5439	52	11C
0005435039804	5439	53	11D
0005435007052	5439	54	11F
0005432125462	5439	55	11E
0005435007066	5439	56	12A
0005435039808	5439	57	12B
0005435039834	5439	58	12D
0005435039813	5439	59	12C
0005435007060	5439	60	12E
0005435039864	5439	61	12F
0005432125459	5439	62	13A
0005434229124	5439	63	13B
0005434229251	5439	64	13D
0005435007065	5439	65	13C
0005435039826	5439	66	13E
0005435039812	5439	67	13F
0005434229211	5439	68	14A
0005434229168	5439	69	14C
0005435039862	5439	70	14B
0005435039807	5439	71	14D
0005435007069	5439	72	14F
0005435039854	5439	73	14E
0005432125456	5439	74	15B
0005432125461	5439	75	15A
0005435039832	5439	76	15C
0005435039803	5439	77	15D
0005435007054	5439	78	15F
0005435039848	5439	79	15E
0005435007064	5439	80	16A
0005434229214	5439	81	16C
0005435039852	5439	82	16B
0005435039851	5439	83	16D
0005434229246	5439	84	16E
0005435007063	5439	85	17B
0005435007067	5439	86	17A
0005435039838	5439	87	17C
0005435039835	5439	88	17D
0005435039845	5439	89	17F
0005434229126	5439	90	17E
0005435039860	5439	91	18A
0005434229134	5439	92	18B
0005434229163	5439	93	18D
0005435007068	5439	94	18C
0005435039839	5439	95	18F
0005434229158	5439	96	18E
0005435039817	5439	97	19A
0005435007061	5439	98	19B
0005435039809	5439	99	19D
0005435039843	5439	100	19C
0005434229194	5439	101	19F
0005434229244	5439	102	19E
0005435039857	5439	103	20A
0005435039830	5439	104	20C
0005435039802	5439	105	20B
0005435039847	5439	106	20E
0005435007056	5439	107	20D
0005432125458	5439	108	20F
0005434229245	5439	109	21A
0005435007045	5439	110	21B
0005435039840	5439	111	21D
0005435007059	5439	112	21C
0005435039811	5439	113	21E
0005435007048	5439	114	21F
0005434229176	5439	115	22B
0005435039841	5439	116	22A
0005435039866	5439	117	22D
0005435039819	5439	118	22C
0005435039859	5439	119	22F
0005435007051	5439	120	22E
0005435039849	5439	121	23A
0005435039831	5439	122	23B
0005435007047	5439	123	23C
0005434229252	5439	124	23D
0005435039863	5439	125	23F
0005435039810	5439	126	23E
0005435039199	13002	1	1C
0005435006854	13002	2	1A
0005435006837	13002	3	1D
0005435039452	13002	4	2A
0005435006857	13002	5	1F
0005435039200	13002	6	2C
0005435006856	13002	7	2D
0005435039564	13002	8	3A
0005434229388	13002	9	2F
0005434229400	13002	10	3C
0005435039395	13002	11	3D
0005435039183	13002	12	3F
0005435039220	13002	13	4B
0005435039391	13002	14	4A
0005435006795	13002	15	4D
0005435039283	13002	16	4C
0005435006880	13002	17	4E
0005435039259	13002	18	5A
0005432304402	13002	19	4F
0005435039255	13002	20	5C
0005434229387	13002	21	5B
0005435006755	13002	22	5D
0005434229389	13002	23	5E
0005434229383	13002	24	6A
0005435039375	13002	25	5F
0005435006822	13002	26	6B
0005435039421	13002	27	6C
0005435039420	13002	28	6D
0005435039388	13002	29	6F
0005435039249	13002	30	6E
0005435039233	13002	31	7A
0005435006851	13002	32	7C
0005435039307	13002	33	7B
0005435006796	13002	34	7E
0005435039264	13002	35	7D
0005435039232	13002	36	7F
0005435042832	13002	37	8A
0005435006849	13002	38	8B
0005434229401	13002	39	8C
0005434229384	13002	40	8D
0005435039445	13002	41	8E
0005435006775	13002	42	9A
0005435039145	13002	43	9C
0005435039093	13002	44	9B
0005435006850	13002	45	9D
0005435039234	13002	46	9E
0005435039219	13002	47	9F
0005435006826	13002	48	10C
0005435039103	13002	49	10B
0005435039453	13002	50	10E
0005435039426	13002	51	10D
0005434229403	13002	52	11A
0005435039313	13002	53	11B
0005434229397	13002	54	11C
0005435039196	13002	55	11E
0005435006808	13002	56	11D
0005435039176	13002	57	11F
0005435039319	13002	58	12A
0005435039246	13002	59	12B
0005435043279	13002	60	12D
0005435039312	13002	61	12C
0005434229390	13002	62	12E
0005435006836	13002	63	12F
0005435039449	13002	64	13A
0005434229396	13002	65	13B
0005435039092	13002	66	13D
0005435039212	13002	67	13C
0005435038962	13002	68	13E
0005435039461	13002	69	14A
0005435039643	13002	70	13F
0005435039390	13002	71	14C
0005435039320	13002	72	14B
0005434229391	13002	73	14D
0005435039041	13002	74	14E
0005435039397	13002	75	15A
0005435006948	13002	76	14F
0005432304400	13002	77	15B
0005435039394	13002	78	15C
0005435039251	13002	79	15D
0005435039252	13002	80	15F
0005435039322	13002	81	15E
0005435006855	13002	82	16A
0005435039001	13002	83	16C
0005434229392	13002	84	16B
0005435039032	13002	85	16E
0005435039102	13002	86	16D
0005435039460	13002	87	17A
0005435039250	13002	88	16F
0005435043280	13002	89	17B
0005435042831	13002	90	17D
0005435039451	13002	91	17C
0005432304401	13002	92	17E
0005435039321	13002	93	18A
0005435039169	13002	94	17F
0005434229399	13002	95	18B
0005434229393	13002	96	18C
0005435039334	13002	97	18D
0005435039172	13002	98	18F
0005435039310	13002	99	18E
0005434229398	13002	100	19A
0005435039387	13002	101	19C
0005435039195	13002	102	19B
0005435039308	13002	103	19D
0005435006867	13002	104	19E
0005435039205	13002	105	19F
0005435006777	13002	106	20A
0005434229395	13002	107	20C
0005434229394	13002	108	20B
0005435039282	13002	109	20D
0005434229405	13002	110	20E
0005434229402	13002	111	20F
0005435006778	13002	112	21B
0005435039427	13002	113	21A
0005435039448	13002	114	21C
0005434229385	13002	115	21D
0005435039386	13002	116	21E
0005435039309	13002	117	21F
0005435039335	13002	118	22B
0005435006809	13002	119	22A
0005434229404	13002	120	22D
0005434229386	13002	121	22C
0005435006949	13002	122	22E
0005435039091	13002	123	23A
0005435006768	13002	124	22F
0005435039555	13002	125	23B
0005435039351	13002	126	23C
0005435039258	13002	127	23E
0005432304403	13002	128	23D
0005435006767	13002	129	23F
0005434426598	14896	1	1C
0005434426604	14896	2	1D
0005434426610	14896	3	2A
0005434426611	14896	4	2C
0005434426607	14896	5	2D
0005434411777	14896	6	2F
0005432188607	14896	7	3C
0005434426612	14896	8	3D
0005434426613	14896	9	3F
0005434426623	14896	10	4A
0005434426600	14896	11	4C
0005435902603	14896	12	4F
0005434426603	14896	13	5A
0005434411776	14896	14	5D
0005434426625	14896	15	5F
0005435902473	14896	16	6A
0005434426602	14896	17	6F
0005435902583	14896	18	7D
0005435902610	14896	19	8C
0005434426605	14896	20	8D
0005435902609	14896	21	8E
0005434426606	14896	22	9A
0005434426619	14896	23	9C
0005434426599	14896	24	10A
0005434426626	14896	25	10C
0005434426622	14896	26	10D
0005434426618	14896	27	11A
0005435902529	14896	28	11D
0005434426608	14896	29	11F
0005435902589	14896	30	12A
0005432188609	14896	31	12C
0005435902614	14896	32	12D
0005432188608	14896	33	12F
0005434426624	14896	34	13A
0005434411778	14896	35	13D
0005435902604	14896	36	14A
0005434426621	14896	37	14D
0005432188606	14896	38	14F
0005432188610	14896	39	15A
0005434426601	14896	40	15D
0005434426617	14896	41	16C
0005434426620	14896	42	17C
0005434426609	14896	43	17D
0005434426615	14896	44	17E
0005435902579	14896	45	17F
0005435902537	14896	46	18E
0005434411780	14896	47	19E
0005434426614	14896	48	19F
0005434426616	14896	49	20C
0005434411779	14896	50	20F
0005434411738	20230	1	1A
0005435554196	20230	2	1C
0005435554194	20230	3	1D
0005434426243	20230	4	2A
0005434426441	20230	5	2D
0005435902725	20230	6	2F
0005435902722	20230	7	3A
0005434426429	20230	8	3D
0005432059507	20230	9	4D
0005435902720	20230	10	4E
0005434426461	20230	11	5A
0005434426319	20230	12	5C
0005434426465	20230	13	5F
0005434426356	20230	14	6A
0005435902717	20230	15	6C
0005435902716	20230	16	6E
0005435902726	20230	17	7A
0005435902714	20230	18	7C
0005434426442	20230	19	7D
0005434426289	20230	20	7E
0005434426335	20230	21	7F
0005434426443	20230	22	8A
0005435902729	20230	23	8D
0005435902715	20230	24	8E
0005435902727	20230	25	9A
0005434426396	20230	26	9C
0005435902718	20230	27	9D
0005434411732	20230	28	9E
0005434426431	20230	29	9F
0005434411756	20230	30	10A
0005435902712	20230	31	10F
0005434411733	20230	32	11A
0005434426439	20230	33	11C
0005435554197	20230	34	11E
0005434426397	20230	35	11F
0005434426212	20230	36	12A
0005434426503	20230	37	12C
0005435902719	20230	38	12D
0005434426407	20230	39	12E
0005435554195	20230	40	12F
0005434426385	20230	41	13A
0005435554193	20230	42	13C
0005434426501	20230	43	13D
0005434426360	20230	44	13E
0005434426409	20230	45	13F
0005434426413	20230	46	14A
0005434426337	20230	47	14C
0005434426369	20230	48	14D
0005435902713	20230	49	14E
0005435902724	20230	50	14F
0005434426244	20230	51	15A
0005432059506	20230	52	15D
0005434426357	20230	53	15E
0005434426457	20230	54	15F
0005434411726	20230	55	16A
0005434426211	20230	56	16E
0005432059508	20230	57	16F
0005434426446	20230	58	17C
0005434426215	20230	59	17F
0005434426430	20230	60	18C
0005434426447	20230	61	18D
0005435902721	20230	62	18F
0005434426379	20230	63	19A
0005435902728	20230	64	19D
0005435902723	20230	65	19E
0005434411755	20230	66	19F
0005434426336	20230	67	20A
0005434426445	20230	68	20C
0005435554192	20230	69	20D
0005434426242	20230	70	20F
0005432300263	26550	1	1A
0005435982306	26550	2	1D
0005433434382	26550	3	1F
0005435982332	26550	4	2A
0005433434504	26550	5	2C
0005433434505	26550	6	2F
0005434270189	26550	7	3A
0005432300267	26550	8	3C
0005435982304	26550	9	3D
0005435982297	26550	10	3F
0005435982315	26550	11	4A
0005435982313	26550	12	4C
0005435982294	26550	13	4D
0005435982321	26550	14	4E
0005435982324	26550	15	5C
0005435982295	26550	16	5D
0005432300268	26550	17	5E
0005433434383	26550	18	5F
0005433434579	26550	19	6A
0005435982311	26550	20	6C
0005435982309	26550	21	6D
0005435982317	26550	22	6E
0005435982320	26550	23	6F
0005433434360	26550	24	7A
0005433434404	26550	25	7C
0005432300264	26550	26	7D
0005435982300	26550	27	7E
0005435982298	26550	28	7F
0005435982299	26550	29	8C
0005435982312	26550	30	8D
0005435982329	26550	31	8F
0005433434455	26550	32	9A
0005435982302	26550	33	9C
0005435982326	26550	34	9D
0005435982318	26550	35	9E
0005433434411	26550	36	9F
0005433434538	26550	37	10A
0005435982337	26550	38	10D
0005435982296	26550	39	10E
0005433434481	26550	40	10F
0005435982325	26550	41	11A
0005435982314	26550	42	11D
0005435982310	26550	43	11E
0005435982330	26550	44	12C
0005435982340	26550	45	12D
0005435982341	26550	46	12E
0005435982342	26550	47	12F
0005435982323	26550	48	13A
0005435982292	26550	49	13C
0005433434441	26550	50	13D
0005435982333	26550	51	13E
0005435982327	26550	52	14C
0005435982335	26550	53	14D
0005433434429	26550	54	14E
0005433434326	26550	55	14F
0005433434551	26550	56	15A
0005433434539	26550	57	15D
0005435982331	26550	58	15C
0005435982334	26550	59	15E
0005435982339	26550	60	15F
0005435982322	26550	61	16A
0005433434511	26550	62	16C
0005435982301	26550	63	16F
0005435982308	26550	64	17A
0005435982305	26550	65	17D
0005435982338	26550	66	17E
0005433434325	26550	67	17F
0005435982336	26550	68	18A
0005435982307	26550	69	18C
0005435982303	26550	70	18D
0005435982293	26550	71	18E
0005432300266	26550	72	18F
0005435982328	26550	73	19C
0005435982319	26550	74	19E
0005435982316	26550	75	19F
0005432300265	26550	76	20A
0005433434465	26550	77	20C
0005433434410	26550	78	20D
0005433434436	26550	79	20E
0005433434428	26550	80	20F
0005432051130	26688	1	1A
0005435981834	26688	2	1C
0005433434701	26688	3	1D
0005435981808	26688	4	1F
0005434270208	26688	5	2A
0005435981807	26688	6	2C
0005433434715	26688	7	2D
0005433434705	26688	8	2F
0005435981645	26688	9	3A
0005435981955	26688	10	3C
0005432051132	26688	11	3D
0005435981998	26688	12	3F
0005433434722	26688	13	4A
0005435981895	26688	14	4C
0005433434708	26688	15	4D
0005433434710	26688	16	4E
0005435982028	26688	17	4F
0005435981838	26688	18	5A
0005435981806	26688	19	5C
0005435981655	26688	20	5D
0005433434699	26688	21	5E
0005433434719	26688	22	5F
0005434271313	26688	23	6A
0005433434704	26688	24	6C
0005435981932	26688	25	6D
0005434269106	26688	26	6E
0005435981984	26688	27	6F
0005435981908	26688	28	7A
0005435981960	26688	29	7C
0005435981854	26688	30	7D
0005435981853	26688	31	7E
0005435981759	26688	32	7F
0005435981762	26688	33	8A
0005435981922	26688	34	8C
0005433434712	26688	35	8D
0005435981921	26688	36	8E
0005433434717	26688	37	8F
0005435982014	26688	38	9A
0005435982006	26688	39	9C
0005435981815	26688	40	9D
0005435981646	26688	41	9E
0005433434709	26688	42	9F
0005433434714	26688	43	10A
0005433434707	26688	44	10C
0005435981956	26688	45	10D
0005435981931	26688	46	10F
0005435981763	26688	47	11A
0005435981999	26688	48	11C
0005433434725	26688	49	11D
0005434271315	26688	50	11E
0005435981965	26688	51	11F
0005433434726	26688	52	12A
0005432051131	26688	53	12C
0005435982019	26688	54	12D
0005435981855	26688	55	12E
0005435982015	26688	56	12F
0005435982005	26688	57	13A
0005435982000	26688	58	13C
0005434269105	26688	59	13D
0005435981739	26688	60	13E
0005433434716	26688	61	13F
0005434270209	26688	62	14A
0005433434703	26688	63	14C
0005435981846	26688	64	14D
0005435981961	26688	65	14E
0005433434713	26688	66	14F
0005435982016	26688	67	15A
0005435981800	26688	68	15C
0005433434711	26688	69	15D
0005433434723	26688	70	15E
0005435981952	26688	71	15F
0005435982004	26688	72	16A
0005435981995	26688	73	16C
0005433434702	26688	74	16D
0005433434706	26688	75	16F
0005435981738	26688	76	17A
0005435981920	26688	77	17C
0005435981878	26688	78	17D
0005433434724	26688	79	17E
0005435982009	26688	80	17F
0005435981933	26688	81	18A
0005433434718	26688	82	18C
0005435981936	26688	83	18D
0005435982008	26688	84	18E
0005433434700	26688	85	18F
0005435981758	26688	86	19A
0005435981930	26688	87	19C
0005433434698	26688	88	19D
0005433434720	26688	89	19E
0005435981835	26688	90	19F
0005433434721	26688	91	20A
0005435981873	26688	92	20C
0005435981934	26688	93	20D
0005435981856	26688	94	20E
0005434271314	26688	95	20F
0005432857925	3184	1	1A
0005432584050	3184	2	1B
0005432857931	3184	3	1C
0005432857903	3184	4	1D
0005432584067	3184	5	2A
0005432584061	3184	6	2B
0005432584059	3184	7	2C
0005432584071	3184	8	2D
0005432584053	3184	9	3A
0005432584048	3184	10	3B
0005432584055	3184	11	3C
0005432584052	3184	12	3D
0005432584062	3184	13	4A
0005432584066	3184	14	4C
0005432584063	3184	15	4D
0005432584051	3184	16	5A
0005432584064	3184	17	5C
0005432216275	3184	18	5D
0005432584046	3184	19	6A
0005432857994	3184	20	6B
0005432216274	3184	21	6D
0005432857951	3184	22	18A
0005432584056	3184	23	18B
0005432584065	3184	24	18C
0005432857988	3184	25	18D
0005432857993	3184	26	19A
0005432584070	3184	27	19B
0005432584069	3184	28	19C
0005432584068	3184	29	20B
0005432584060	3184	30	20C
0005432584047	3184	31	20D
0005432584058	3184	32	21B
0005432857989	3184	33	21C
0005432857995	3184	34	22B
0005432584054	3184	35	22C
0005432858016	3184	36	22D
0005432584057	3184	37	23A
0005432584049	3184	38	23B
0005432583943	31482	1	1A
0005432858083	31482	2	1B
0005432583810	31482	3	2A
0005432583842	31482	4	2B
0005432583779	31482	5	2C
0005432583855	31482	6	2D
0005432858080	31482	7	3A
0005432583876	31482	8	3B
0005432583799	31482	9	3C
0005432583853	31482	10	3D
0005432583763	31482	11	4A
0005432583798	31482	12	4B
0005432858082	31482	13	4C
0005432858073	31482	14	5A
0005432583926	31482	15	5B
0005432858077	31482	16	5C
0005432583913	31482	17	5D
0005432583828	31482	18	6A
0005432583801	31482	19	6B
0005432583940	31482	20	6C
0005432583769	31482	21	6D
0005432583856	31482	22	7A
0005432583813	31482	23	7B
0005432583928	31482	24	7C
0005432583954	31482	25	7D
0005432583800	31482	26	18A
0005432858076	31482	27	18B
0005432858081	31482	28	18C
0005432858075	31482	29	18D
0005432583915	31482	30	19A
0005432858084	31482	31	19B
0005432583766	31482	32	19C
0005432858074	31482	33	19D
0005432583778	31482	34	20A
0005432858078	31482	35	20C
0005432583939	31482	36	20B
0005432583729	31482	37	21A
0005432583955	31482	38	21B
0005432583927	31482	39	21C
0005432583829	31482	40	21D
0005432583901	31482	41	22A
0005432583866	31482	42	22B
0005432583854	31482	43	22C
0005432583824	31482	44	22D
0005432583893	31482	45	23A
0005432858079	31482	46	23B
0005434943356	885	1	1A
0005433255086	885	2	1B
0005434943364	885	3	4A
0005434943360	885	4	4B
0005433255091	885	5	4C
0005434943358	885	6	5A
0005434943361	885	7	5B
0005433255085	885	8	6A
0005434943359	885	9	19D
0005434943362	885	10	20A
0005434943363	885	11	20C
0005434943357	885	12	22D
0005433255092	885	13	23A
0005433255090	885	14	23B
0005433255122	16209	1	1C
0005434943275	16209	2	1D
0005434943294	16209	3	3A
0005434943289	16209	4	3B
0005434943324	16209	5	3C
0005434943311	16209	6	4D
0005434943296	16209	7	5D
0005434943295	16209	8	7A
0005434943283	16209	9	7D
0005433255125	16209	10	18C
0005434943277	16209	11	20C
0005434943274	16209	12	21A
0005434943278	16209	13	21B
0005433255123	16209	14	22A
0005433255126	16209	15	22D
0005433255124	16209	16	23B
0005433654789	4324	1	1D
0005433654786	4324	2	2D
0005435858501	4324	3	3D
0005433654760	4324	4	4F
0005433654772	4324	5	5C
0005433654774	4324	6	5D
0005435858542	4324	7	6A
0005433654782	4324	8	6E
0005435858500	4324	9	6D
0005433654767	4324	10	7A
0005435858524	4324	11	7B
0005433654766	4324	12	7E
0005433654781	4324	13	7D
0005433654768	4324	14	7F
0005433654770	4324	15	8B
0005435858522	4324	16	9D
0005435858534	4324	17	10C
0005435858517	4324	18	10B
0005433654777	4324	19	11A
0005433654762	4324	20	10F
0005433654761	4324	21	11F
0005433654771	4324	22	12A
0005435858541	4324	23	12D
0005435858523	4324	24	12F
0005433654769	4324	25	13B
0005435858510	4324	26	13E
0005433654779	4324	27	13F
0005433654783	4324	28	14D
0005433654785	4324	29	14C
0005435858507	4324	30	15B
0005433654788	4324	31	15C
0005433654773	4324	32	15D
0005433654775	4324	33	16B
0005433654787	4324	34	16E
0005433654765	4324	35	16D
0005435858486	4324	36	16F
0005433654776	4324	37	17D
0005433654763	4324	38	18A
0005433654780	4324	39	18C
0005433654784	4324	40	18D
0005435858526	4324	41	19A
0005435858521	4324	42	19E
0005433654764	4324	43	19D
0005435858493	4324	44	19F
0005435858503	4324	45	20A
0005435858502	4324	46	20E
0005435858508	4324	47	21A
0005433654778	4324	48	21C
0005433811618	14392	1	1A
0005433811616	14392	2	1B
0005433811620	14392	3	3B
0005433811619	14392	4	5B
0005435653043	21754	1	1A
0005435653051	21754	2	1C
0005435653048	21754	3	1D
0005435653052	21754	4	1F
0005435653060	21754	5	2A
0005433367625	21754	6	2C
0005433367526	21754	7	2D
0005433367626	21754	8	2F
0005435653081	21754	9	3A
0005435653078	21754	10	3C
0005435653070	21754	11	3D
0005435653056	21754	12	4A
0005435653061	21754	13	4C
0005435653063	21754	14	4D
0005435653076	21754	15	4E
0005435653041	21754	16	4F
0005435653044	21754	17	5A
0005435653049	21754	18	5C
0005433367581	21754	19	5D
0005433367630	21754	20	5E
0005433367567	21754	21	5F
0005435653083	21754	22	6A
0005435653055	21754	23	6C
0005435653054	21754	24	6D
0005435653082	21754	25	6F
0005433367629	21754	26	7A
0005433367582	21754	27	7C
0005435653050	21754	28	7D
0005435653086	21754	29	7E
0005435653068	21754	30	7F
0005433367513	21754	31	8A
0005435653046	21754	32	8C
0005435653091	21754	33	8D
0005433367422	21754	34	8E
0005433367622	21754	35	8F
0005435653045	21754	36	9A
0005435653062	21754	37	9D
0005433367517	21754	38	9E
0005435653093	21754	39	9F
0005435653067	21754	40	10A
0005433367737	21754	41	10D
0005435653059	21754	42	10E
0005433367447	21754	43	10F
0005435653071	21754	44	11A
0005435653084	21754	45	11C
0005435653089	21754	46	11D
0005435653064	21754	47	11E
0005433367583	21754	48	11F
0005435653066	21754	49	12A
0005435653087	21754	50	12C
0005435653073	21754	51	12D
0005433367569	21754	52	12E
0005433367577	21754	53	12F
0005435653077	21754	54	13A
0005435653069	21754	55	13C
0005435653047	21754	56	13D
0005433367477	21754	57	13F
0005435653080	21754	58	14A
0005433367828	21754	59	14C
0005433367631	21754	60	14D
0005433367638	21754	61	14E
0005433367778	21754	62	14F
0005435653088	21754	63	15C
0005433367578	21754	64	15E
0005433367829	21754	65	15F
0005435653053	21754	66	16A
0005435653057	21754	67	16C
0005433367566	21754	68	16D
0005435653065	21754	69	16F
0005433367632	21754	70	17A
0005433367580	21754	71	17C
0005433367777	21754	72	17D
0005435653085	21754	73	17E
0005435653058	21754	74	17F
0005433367399	21754	75	18A
0005435653042	21754	76	18C
0005435653074	21754	77	18D
0005435653079	21754	78	18E
0005435653075	21754	79	18F
0005433367564	21754	80	19A
0005435653072	21754	81	19C
0005433367514	21754	82	19D
0005433367469	21754	83	19E
0005433367736	21754	84	19F
0005435653090	21754	85	20A
0005435653092	21754	86	20F
0005433784992	9382	1	1A
0005433805400	9382	2	1C
0005433805409	9382	3	1F
0005433763225	9382	4	1H
0005433805421	9382	5	1G
0005434170967	9382	6	2C
0005433784983	9382	7	3A
0005433784993	9382	8	3C
0005433784985	9382	9	3B
0005433763224	9382	10	3F
0005433805422	9382	11	4A
0005433763218	9382	12	4G
0005433784974	9382	13	5A
0005433784989	9382	14	5B
0005434170971	9382	15	5C
0005433784966	9382	16	5H
0005433805433	9382	17	9B
0005433784975	9382	18	9A
0005433763219	9382	19	9H
0005434273059	9382	20	11B
0005433784976	9382	21	11A
0005433805417	9382	22	11D
0005434151685	9382	23	11E
0005433784965	9382	24	11G
0005433784996	9382	25	12B
0005433805424	9382	26	12F
0005433805429	9382	27	12G
0005432666391	9382	28	13A
0005433784969	9382	29	13D
0005433784997	9382	30	13E
0005433805435	9382	31	13G
0005433784988	9382	32	14A
0005433784972	9382	33	14E
0005433805412	9382	34	14G
0005434270192	9382	35	15A
0005433784984	9382	36	15B
0005433805428	9382	37	15E
0005433805420	9382	38	15G
0005433805427	9382	39	15F
0005433805425	9382	40	16D
0005433805415	9382	41	16E
0005434151694	9382	42	16F
0005433763216	9382	43	16G
0005433805406	9382	44	17B
0005434170986	9382	45	17A
0005433784967	9382	46	17D
0005432657450	9382	47	18A
0005433805411	9382	48	17H
0005433784973	9382	49	18B
0005433784970	9382	50	18H
0005434170946	9382	51	19H
0005433763215	9382	52	19G
0005433784964	9382	53	20A
0005433805414	9382	54	20B
0005433805423	9382	55	20E
0005434170959	9382	56	20H
0005433784968	9382	57	21B
0005432657452	9382	58	21F
0005433805403	9382	59	21E
0005433784998	9382	60	21D
0005433784991	9382	61	21H
0005433805432	9382	62	22A
0005433784987	9382	63	22B
0005432665277	9382	64	22G
0005433805426	9382	65	22F
0005433763220	9382	66	23A
0005433805401	9382	67	23E
0005432657451	9382	68	23F
0005433805431	9382	69	23G
0005433763222	9382	70	24B
0005433784963	9382	71	24H
0005433763223	9382	72	25D
0005434170991	9382	73	27E
0005433805430	9382	74	27H
0005433805402	9382	75	27G
0005433763217	9382	76	28A
0005433784971	9382	77	28F
0005433763213	9382	78	28H
0005434170924	9382	79	28G
0005433805407	9382	80	29D
0005433784990	9382	81	29E
0005432665276	9382	82	29G
0005433805413	9382	83	30D
0005432667456	9382	84	30E
0005433784995	9382	85	30H
0005433805434	9382	86	31D
0005433784982	9382	87	31E
0005434270194	9382	88	31H
0005434170945	9382	89	32A
0005434170992	9382	90	32D
0005433763221	9382	91	32F
0005433784980	9382	92	32G
0005434170952	9382	93	32H
0005433805416	9382	94	33E
0005434273063	9382	95	33D
0005433784962	9382	96	33G
0005434273064	9382	97	33H
0005433784977	9382	98	34D
0005433805418	9382	99	34B
0005433784981	9382	100	34F
0005433784960	9382	101	34E
0005433763226	9382	102	35A
0005433784978	9382	103	35B
0005434170962	9382	104	35E
0005433784979	9382	105	35H
0005433805404	9382	106	36D
0005434170996	9382	107	36F
0005433805405	9382	108	36E
0005434170997	9382	109	37A
0005434170925	9382	110	37B
0005433763214	9382	111	37F
0005433805408	9382	112	37G
0005433784961	9382	113	38A
0005433784986	9382	114	38D
0005433784994	9382	115	38F
0005433805410	9382	116	38E
0005433805419	9382	117	38G
0005434170932	9382	118	39D
0005433784668	26227	1	1B
0005432663022	26227	2	1A
0005433805232	26227	3	1F
0005434171075	26227	4	2A
0005434171070	26227	5	2B
0005432657424	26227	6	2F
0005433784540	26227	7	2C
0005434171074	26227	8	3G
0005433804954	26227	9	4B
0005432657425	26227	10	5A
0005433784670	26227	11	4H
0005433784627	26227	12	5C
0005432659700	26227	13	9B
0005432657423	26227	14	9A
0005433805180	26227	15	9H
0005433784521	26227	16	11B
0005433784522	26227	17	11F
0005434171073	26227	18	12A
0005432663017	26227	19	13B
0005433805238	26227	20	13E
0005433784623	26227	21	14G
0005433805239	26227	22	15D
0005434171068	26227	23	15A
0005432663024	26227	24	15F
0005434271311	26227	25	15G
0005433805108	26227	26	16A
0005433784669	26227	27	16E
0005434171065	26227	28	16G
0005434171071	26227	29	16H
0005433804953	26227	30	17E
0005435269750	26227	31	18A
0005433784763	26227	32	18F
0005434269103	26227	33	18E
0005433805196	26227	34	18H
0005433805121	26227	35	18G
0005434269102	26227	36	19A
0005433805096	26227	37	19B
0005433784597	26227	38	19D
0005432663021	26227	39	19F
0005433805231	26227	40	19H
0005433805195	26227	41	20B
0005434171069	26227	42	20E
0005433805072	26227	43	20G
0005433805085	26227	44	20F
0005433805134	26227	45	20H
0005433784603	26227	46	21D
0005433762992	26227	47	21E
0005433784687	26227	48	22B
0005434271312	26227	49	22G
0005433805073	26227	50	23A
0005432666376	26227	51	22H
0005433805092	26227	52	23B
0005433805223	26227	53	23F
0005432657415	26227	54	24B
0005433763108	26227	55	24D
0005433784810	26227	56	24G
0005434270207	26227	57	25D
0005434171064	26227	58	25E
0005433784596	26227	59	25F
0005433784599	26227	60	27H
0005432663020	26227	61	28D
0005433805080	26227	62	28B
0005433763084	26227	63	28E
0005433805197	26227	64	28G
0005433784612	26227	65	28F
0005433805122	26227	66	28H
0005434171063	26227	67	29A
0005433784586	26227	68	29E
0005433784602	26227	69	29G
0005433805119	26227	70	30A
0005433805221	26227	71	30D
0005434269104	26227	72	30B
0005433805260	26227	73	30G
0005433805107	26227	74	31A
0005433784611	26227	75	30H
0005433763066	26227	76	31D
0005433784585	26227	77	31E
0005433784764	26227	78	31H
0005434171066	26227	79	32A
0005433784709	26227	80	32B
0005432657416	26227	81	32H
0005433784742	26227	82	33B
0005433763105	26227	83	33E
0005433784527	26227	84	33H
0005433763120	26227	85	33G
0005434270206	26227	86	34F
0005435269749	26227	87	34E
0005434171067	26227	88	35A
0005433805095	26227	89	35B
0005433805027	26227	90	35D
0005434151707	26227	91	35E
0005434171072	26227	92	35F
0005433784741	26227	93	36A
0005433805156	26227	94	36E
0005433784610	26227	95	36F
0005433784743	26227	96	36G
0005433805139	26227	97	37A
0005433784523	26227	98	37G
0005433763099	26227	99	38A
0005433762993	26227	100	38D
0005433763077	26227	101	38E
0005433805220	26227	102	39E
0005433805093	26227	103	39F
0005435135674	4893	1	2B
0005435135673	4893	2	5A
0005435135675	4893	3	6C
0005435929634	4893	4	18D
0005435135676	4893	5	20C
0005435135623	33044	1	1C
0005435135663	33044	2	1D
0005435929647	33044	3	2B
0005435135622	33044	4	3C
0005435929648	33044	5	4D
0005435929645	33044	6	18A
0005435135648	33044	7	18C
0005435135664	33044	8	19C
0005435135645	33044	9	20B
0005435135647	33044	10	21A
0005435929646	33044	11	22C
0005434217947	9494	1	2A
0005434983289	9494	2	3C
0005434983293	9494	3	4D
0005434983292	9494	4	6B
0005434983294	9494	5	20B
0005434983291	9494	6	21A
0005434217946	9494	7	21C
0005434983290	9494	8	23A
0005434983264	27354	1	3A
0005434217972	27354	2	5C
0005434217974	27354	3	5D
0005434217973	27354	4	6C
0005434983263	27354	5	21A
0005433960344	24273	1	2C
0005433960422	24273	2	3A
0005433960236	24273	3	3B
0005433960398	24273	4	3H
0005433985522	24273	5	5B
0005433985717	24273	6	5C
0005433960379	24273	7	5F
0005433960144	24273	8	9A
0005433960427	24273	9	9B
0005433985777	24273	10	9G
0005433960382	24273	11	11E
0005433985543	24273	12	11F
0005433960238	24273	13	11G
0005433985615	24273	14	13D
0005433985660	24273	15	14B
0005433985567	24273	16	14D
0005433985466	24273	17	15A
0005433985715	24273	18	15B
0005433985778	24273	19	15E
0005433985659	24273	20	15F
0005433960323	24273	21	16B
0005433960201	24273	22	16E
0005433985612	24273	23	16G
0005433960435	24273	24	16F
0005433960165	24273	25	16H
0005433985226	24273	26	17A
0005433960408	24273	27	17B
0005433960383	24273	28	17E
0005433960428	24273	29	18B
0005433985663	24273	30	18E
0005433960434	24273	31	19B
0005433960406	24273	32	19D
0005433985418	24273	33	19G
0005433985676	24273	34	20A
0005433985536	24273	35	20D
0005433960345	24273	36	21D
0005433985355	24273	37	21F
0005433985609	24273	38	22A
0005433985228	24273	39	22D
0005433960226	24273	40	22F
0005433960355	24273	41	22H
0005433985621	24273	42	23A
0005433985532	24273	43	23D
0005433985610	24273	44	23G
0005433960430	24273	45	24B
0005433960413	24273	46	24D
0005433960324	24273	47	25E
0005433985671	24273	48	27B
0005433960224	24273	49	27G
0005433985295	24273	50	28E
0005433960433	24273	51	28F
0005433960380	24273	52	28H
0005433960258	24273	53	29D
0005433960282	24273	54	29H
0005433960322	24273	55	29G
0005433960431	24273	56	30B
0005433985664	24273	57	30F
0005433960327	24273	58	30G
0005433960348	24273	59	31A
0005433985227	24273	60	30H
0005433985618	24273	61	31B
0005433960363	24273	62	31E
0005433985718	24273	63	32B
0005433960200	24273	64	32G
0005433985598	24273	65	32F
0005433985382	24273	66	33E
0005433960326	24273	67	33F
0005433985467	24273	68	33H
0005433985611	24273	69	34D
0005433985566	24273	70	35A
0005433960145	24273	71	34H
0005433985662	24273	72	35D
0005433960239	24273	73	35E
0005433985419	24273	74	36F
0005433985479	24273	75	36G
0005433985472	24273	76	37D
0005433960195	24273	77	37H
0005433985770	24273	78	38E
0005433985509	24273	79	38F
0005433985613	24273	80	38H
0005433985591	24273	81	39E
0005433985381	24273	82	39D
0005433960860	25918	1	24H
0005433960863	25918	2	1F
0005433985953	25918	3	1C
0005433985935	25918	4	1G
0005433985939	25918	5	1H
0005433985948	25918	6	2F
0005433960903	25918	7	2C
0005433960899	25918	8	2H
0005433960873	25918	9	3B
0005433985973	25918	10	3F
0005433985930	25918	11	4A
0005433985929	25918	12	4C
0005433985977	25918	13	4F
0005433985933	25918	14	5B
0005433985927	25918	15	5A
0005433985964	25918	16	5F
0005433960854	25918	17	5C
0005433985945	25918	18	5G
0005433960908	25918	19	9B
0005433985983	25918	20	11A
0005433985971	25918	21	11B
0005433960867	25918	22	11F
0005433985961	25918	23	11H
0005433985975	25918	24	12E
0005433960891	25918	25	12F
0005433960853	25918	26	12H
0005433985970	25918	27	12G
0005433960910	25918	28	13B
0005433985957	25918	29	13A
0005433985962	25918	30	13D
0005433960870	25918	31	13F
0005433985982	25918	32	13H
0005433985969	25918	33	14F
0005433960901	25918	34	14E
0005433960897	25918	35	14G
0005433960866	25918	36	15E
0005433985928	25918	37	15D
0005433960909	25918	38	15F
0005433960900	25918	39	16B
0005433985947	25918	40	16E
0005433960893	25918	41	16G
0005433960898	25918	42	17B
0005433960869	25918	43	17H
0005433960883	25918	44	18E
0005433960886	25918	45	18B
0005433960877	25918	46	18F
0005433960865	25918	47	18H
0005433960851	25918	48	19A
0005433985944	25918	49	19F
0005433960892	25918	50	19G
0005433960861	25918	51	20A
0005433960906	25918	52	20D
0005433985938	25918	53	20E
0005433985954	25918	54	20G
0005433985940	25918	55	20F
0005433985936	25918	56	21E
0005433985980	25918	57	21H
0005433960857	25918	58	21G
0005433985979	25918	59	22D
0005433985972	25918	60	22E
0005433985960	25918	61	22H
0005433960864	25918	62	23B
0005433960879	25918	63	23A
0005433985941	25918	64	23D
0005433985952	25918	65	23G
0005433960885	25918	66	24D
0005433960855	25918	67	24G
0005433960880	25918	68	25D
0005433960902	25918	69	25E
0005433985934	25918	70	27A
0005433960896	25918	71	27B
0005433960907	25918	72	27E
0005433960905	25918	73	27D
0005433960912	25918	74	28A
0005433960881	25918	75	28B
0005433985942	25918	76	28D
0005433985967	25918	77	28G
0005433960894	25918	78	28H
0005433985950	25918	79	29B
0005433960889	25918	80	29D
0005433960858	25918	81	29H
0005433960888	25918	82	30A
0005433960874	25918	83	30D
0005433985932	25918	84	30G
0005433960890	25918	85	30H
0005433985966	25918	86	31B
0005433960871	25918	87	31A
0005433960904	25918	88	31G
0005433960884	25918	89	32B
0005433960868	25918	90	32E
0005433960859	25918	91	32D
0005433960875	25918	92	32F
0005433985937	25918	93	32H
0005433960852	25918	94	33B
0005433985974	25918	95	33E
0005433960878	25918	96	33G
0005433985978	25918	97	33F
0005433985958	25918	98	33H
0005433960895	25918	99	34A
0005433960911	25918	100	34D
0005433985959	25918	101	34B
0005433960856	25918	102	34F
0005433985976	25918	103	34E
0005433985963	25918	104	35D
0005433985956	25918	105	35B
0005433985981	25918	106	36A
0005433985946	25918	107	35H
0005433960876	25918	108	36B
0005433985949	25918	109	36E
0005433985968	25918	110	36D
0005433960887	25918	111	36F
0005433985943	25918	112	37A
0005433960872	25918	113	36H
0005433985955	25918	114	37B
0005433960882	25918	115	37D
0005433985965	25918	116	37F
0005433960862	25918	117	38A
0005433985951	25918	118	38H
0005433985931	25918	119	39E
0005434480354	917	1	1B
0005433165837	917	2	1D
0005434480359	917	3	2A
0005434480364	917	4	2B
0005434480343	917	5	2C
0005433165780	917	6	2D
0005434480341	917	7	3A
0005433165813	917	8	3B
0005434480349	917	9	3C
0005434480356	917	10	4A
0005434480347	917	11	4B
0005434480362	917	12	4D
0005434480345	917	13	5A
0005433165740	917	14	5B
0005433165854	917	15	5D
0005434480358	917	16	6A
0005434480363	917	17	6B
0005433165851	917	18	6C
0005433165814	917	19	6D
0005434480342	917	20	7A
0005434480361	917	21	7B
0005434480353	917	22	7D
0005434480344	917	23	18A
0005434480365	917	24	18B
0005434480350	917	25	18C
0005432269499	917	26	18D
0005434480352	917	27	19B
0005433165838	917	28	19C
0005433165741	917	29	19D
0005434480357	917	30	20A
0005434480348	917	31	20C
0005434480346	917	32	20D
0005433165729	917	33	21A
0005434480360	917	34	21C
0005433165849	917	35	21D
0005434480355	917	36	22A
0005434480351	917	37	22C
0005433165781	917	38	23A
0005434480366	917	39	23B
0005433165916	16586	1	1A
0005434480220	16586	2	1B
0005433165919	16586	3	1C
0005434480177	16586	4	1D
0005434480162	16586	5	2A
0005433165917	16586	6	3B
0005433165920	16586	7	3C
0005433165913	16586	8	3D
0005433165912	16586	9	4A
0005434480149	16586	10	4C
0005433165921	16586	11	4D
0005433165922	16586	12	5A
0005434480150	16586	13	5B
0005434480156	16586	14	6A
0005433165914	16586	15	6B
0005434480223	16586	16	6C
0005434480086	16586	17	6D
0005433165911	16586	18	7B
0005434480104	16586	19	7C
0005434480224	16586	20	18A
0005433165923	16586	21	18B
0005434480093	16586	22	18C
0005434480088	16586	23	19B
0005433165910	16586	24	20C
0005433165915	16586	25	21A
0005433165918	16586	26	21B
0005433165909	16586	27	21D
0005434480184	16586	28	22A
0005434480102	16586	29	22C
0005434480196	16586	30	22D
0005434480185	16586	31	23A
0005434480157	16586	32	23B
0005433872490	3191	1	2B
0005433872486	3191	2	2C
0005433872485	3191	3	4A
0005433872487	3191	4	19D
0005433872484	3191	5	20A
0005433872488	3191	6	20D
0005433872489	3191	7	23B
0005433872456	32559	1	3D
0005433872475	32559	2	6D
0005433872457	32559	3	18A
0005433872447	32559	4	22D
0005433872476	32559	5	23A
0005435386530	10371	1	1A
0005435386545	10371	2	1B
0005433289802	10371	3	1C
0005435386485	10371	4	1D
0005435142583	10371	5	2A
0005435386516	10371	6	2B
0005435386517	10371	7	2C
0005435142574	10371	8	2D
0005435150026	10371	9	3A
0005435142580	10371	10	3B
0005435150023	10371	11	3C
0005435142572	10371	12	4A
0005435142584	10371	13	4B
0005435386527	10371	14	4C
0005435142582	10371	15	4D
0005435150024	10371	16	5A
0005435386525	10371	17	5B
0005435386533	10371	18	5C
0005435142571	10371	19	5D
0005435150035	10371	20	6A
0005435150033	10371	21	6C
0005435150030	10371	22	6D
0005433289773	10371	23	7A
0005435142573	10371	24	7B
0005435150034	10371	25	7C
0005435150032	10371	26	7D
0005435386528	10371	27	18A
0005433289790	10371	28	18B
0005435142581	10371	29	19A
0005435142577	10371	30	19B
0005435150029	10371	31	19C
0005435150022	10371	32	19D
0005435150028	10371	33	20A
0005435150027	10371	34	20B
0005435150031	10371	35	20C
0005435142579	10371	36	20D
0005435142578	10371	37	21B
0005433289803	10371	38	21C
0005435150036	10371	39	21D
0005435386542	10371	40	22A
0005435142575	10371	41	22B
0005435150025	10371	42	22C
0005433289789	10371	43	22D
0005433289752	10371	44	23A
0005435142576	10371	45	23B
0005435142499	21932	1	1A
0005435142401	21932	2	1B
0005435142462	21932	3	1C
0005435142437	21932	4	2A
0005435149944	21932	5	2B
0005435142467	21932	6	2C
0005435386575	21932	7	2D
0005435142493	21932	8	4A
0005435386573	21932	9	4C
0005435149939	21932	10	5B
0005433289862	21932	11	5C
0005435149878	21932	12	5D
0005433289859	21932	13	6A
0005435386577	21932	14	6B
0005435142460	21932	15	6D
0005435142487	21932	16	7A
0005435142438	21932	17	18A
0005435149934	21932	18	18B
0005435142481	21932	19	19A
0005435386578	21932	20	19C
0005435142461	21932	21	19D
0005435149915	21932	22	20A
0005435386576	21932	23	20C
0005435386574	21932	24	20D
0005435142494	21932	25	21A
0005435149945	21932	26	21C
0005435149879	21932	27	21D
0005435386572	21932	28	22A
0005433289864	21932	29	22B
0005433289861	21932	30	22C
0005433289860	21932	31	22D
0005433289863	21932	32	23B
0005434573350	11210	1	1A
0005435502109	11210	2	1C
0005435529073	11210	3	1D
0005435545656	11210	4	1F
0005435319513	11210	5	2A
0005435502110	11210	6	2C
0005435529153	11210	7	2D
0005435545667	11210	8	2F
0005435529152	11210	9	3C
0005435529099	11210	10	3D
0005434573347	11210	11	3F
0005435528969	11210	12	4C
0005435502164	11210	13	4E
0005434573359	11210	14	5A
0005435529059	11210	15	5C
0005435529054	11210	16	6A
0005434573357	11210	17	6C
0005435529110	11210	18	6E
0005435502135	11210	19	7A
0005435529045	11210	20	7E
0005435529098	11210	21	7F
0005435529111	11210	22	8C
0005434573360	11210	23	8D
0005435319519	11210	24	8E
0005435529121	11210	25	8F
0005435502108	11210	26	9A
0005435502187	11210	27	9D
0005434573358	11210	28	9E
0005434573354	11210	29	9F
0005435529014	11210	30	10C
0005435545671	11210	31	10D
0005434573355	11210	32	10E
0005435529053	11210	33	10F
0005435502173	11210	34	11C
0005435528952	11210	35	11D
0005435545659	11210	36	11F
0005435502136	11210	37	11E
0005435502181	11210	38	12A
0005435529007	11210	39	12C
0005435502122	11210	40	12D
0005434573353	11210	41	12E
0005434573352	11210	42	13A
0005435502160	11210	43	13C
0005435529139	11210	44	13D
0005435529080	11210	45	13F
0005435529058	11210	46	14A
0005435502150	11210	47	14C
0005435529120	11210	48	14D
0005435529051	11210	49	14F
0005435502186	11210	50	15A
0005435528951	11210	51	15C
0005435319526	11210	52	15D
0005435502166	11210	53	15E
0005435545674	11210	54	15F
0005435529075	11210	55	16A
0005435502196	11210	56	16D
0005435545632	11210	57	16E
0005435529048	11210	58	16F
0005435529013	11210	59	17A
0005435502123	11210	60	17C
0005435545644	11210	61	17D
0005435529049	11210	62	17E
0005434573356	11210	63	17F
0005434573349	11210	64	18C
0005434573351	11210	65	18D
0005435502098	11210	66	18E
0005435529050	11210	67	18F
0005435529140	11210	68	19A
0005434573348	11210	69	19C
0005435502234	11210	70	19D
0005435502165	11210	71	19F
0005435502168	11210	72	20A
0005435529006	11210	73	20C
0005435529091	11210	74	20D
0005435502239	11210	75	20E
0005435545631	11210	76	20F
0005434573224	20938	1	1A
0005435508378	20938	2	1C
0005435508374	20938	3	1D
0005435502311	20938	4	2C
0005435517918	20938	5	2D
0005435502328	20938	6	2F
0005435502327	20938	7	3A
0005435517920	20938	8	3C
0005435508373	20938	9	3F
0005435502325	20938	10	4A
0005435502326	20938	11	4D
0005435517925	20938	12	4F
0005434573264	20938	13	5A
0005434573220	20938	14	5C
0005435319594	20938	15	5E
0005435508367	20938	16	5F
0005435508377	20938	17	6A
0005435508371	20938	18	6D
0005435508375	20938	19	6E
0005435508369	20938	20	6F
0005435502316	20938	21	7A
0005435319589	20938	22	7F
0005435502317	20938	23	8A
0005434573312	20938	24	8D
0005435502309	20938	25	8E
0005435508376	20938	26	8F
0005434573297	20938	27	9E
0005435502329	20938	28	10A
0005432291930	20938	29	10C
0005435508372	20938	30	10D
0005435319591	20938	31	10E
0005435319590	20938	32	10F
0005435517922	20938	33	11A
0005435319595	20938	34	11C
0005435319586	20938	35	11D
0005435517923	20938	36	11E
0005435502324	20938	37	12A
0005435502323	20938	38	12C
0005435502330	20938	39	12D
0005435502321	20938	40	12F
0005435502314	20938	41	13A
0005435517924	20938	42	13C
0005435508370	20938	43	13E
0005435517921	20938	44	13F
0005435508368	20938	45	14A
0005435502315	20938	46	14D
0005435502310	20938	47	14E
0005435517927	20938	48	14F
0005434573229	20938	49	15A
0005435517919	20938	50	15D
0005435502308	20938	51	15E
0005435502312	20938	52	16A
0005435319592	20938	53	16C
0005435319593	20938	54	16D
0005434573158	20938	55	16E
0005435502320	20938	56	16F
0005435502319	20938	57	18C
0005432291931	20938	58	18F
0005435502318	20938	59	19A
0005435319587	20938	60	19C
0005435517926	20938	61	19D
0005435502313	20938	62	19E
0005435319588	20938	63	19F
0005435502322	20938	64	20A
0005434573241	20938	65	20C
0005432692733	3011	1	1C
0005432692996	3011	2	1F
0005432692722	3011	3	2A
0005432692723	3011	4	2C
0005432692814	3011	5	2F
0005432692944	3011	6	3C
0005432692747	3011	7	3F
0005432692693	3011	8	4E
0005432692721	3011	9	5A
0005432692873	3011	10	7D
0005432692746	3011	11	8D
0005432692857	3011	12	9A
0005432692916	3011	13	12C
0005432692796	3011	14	13D
0005432692921	3011	15	13E
0005432692933	3011	16	15C
0005432692732	3011	17	15F
0005432692813	3011	18	16D
0005432692945	3011	19	17C
0005432692917	3011	20	17D
0005432692823	3011	21	17E
0005432692913	3011	22	17F
0005432692885	3011	23	18C
0005432692779	3011	24	20A
0005433123820	3010	1	1A
0005432880713	3010	2	1C
0005432880709	3010	3	1D
0005432706787	3010	4	1F
0005432880728	3010	5	2A
0005432706785	3010	6	2C
0005432217779	3010	7	2D
0005433123686	3010	8	3A
0005433123744	3010	9	3F
0005432706803	3010	10	4C
0005433123809	3010	11	4D
0005432217778	3010	12	4E
0005432706804	3010	13	4F
0005433123705	3010	14	5C
0005432706788	3010	15	5D
0005432706786	3010	16	5E
0005432706783	3010	17	6A
0005432880764	3010	18	6C
0005432706797	3010	19	6D
0005432880652	3010	20	6F
0005433123729	3010	21	7A
0005433123701	3010	22	7C
0005432706781	3010	23	7D
0005433123713	3010	24	7E
0005432706798	3010	25	7F
0005432706795	3010	26	8A
0005432706779	3010	27	8C
0005433123736	3010	28	8E
0005432880721	3010	29	8F
0005432880663	3010	30	9C
0005433123779	3010	31	9D
0005433123818	3010	32	9E
0005433123764	3010	33	9F
0005432880729	3010	34	10A
0005433194844	3010	35	10C
0005432880680	3010	36	10D
0005433123763	3010	37	10E
0005433123755	3010	38	10F
0005432706793	3010	39	11D
0005432217777	3010	40	11E
0005433123831	3010	41	11F
0005432880703	3010	42	12A
0005432880697	3010	43	12C
0005432706799	3010	44	12D
0005433123794	3010	45	12F
0005432880734	3010	46	13A
0005432706794	3010	47	13C
0005432880711	3010	48	13F
0005432706789	3010	49	14D
0005432880727	3010	50	14E
0005432706791	3010	51	14F
0005432706792	3010	52	15A
0005433123735	3010	53	15C
0005432706790	3010	54	15E
0005432706796	3010	55	15F
0005432880710	3010	56	16A
0005432706801	3010	57	16C
0005433194838	3010	58	16E
0005433123754	3010	59	16F
0005433123821	3010	60	17A
0005432706802	3010	61	17C
0005432706780	3010	62	17D
0005432880708	3010	63	17F
0005433123766	3010	64	18A
0005432880664	3010	65	18C
0005433123769	3010	66	18D
0005433123819	3010	67	18E
0005432880696	3010	68	18F
0005433123770	3010	69	19A
0005432880678	3010	70	19D
0005433123728	3010	71	19E
0005433123772	3010	72	19F
0005432706784	3010	73	20A
0005432706800	3010	74	20C
0005433123768	3010	75	20D
0005433123743	3010	76	20E
0005432706782	3010	77	20F
0005432693110	29998	1	1A
0005432706616	29998	2	1C
0005432706540	29998	3	1D
0005433123948	29998	4	1F
0005433123942	29998	5	2A
0005433123941	29998	6	2C
0005432706558	29998	7	2D
0005433123933	29998	8	2F
0005433194860	29998	9	3A
0005432706470	29998	10	3C
0005432880826	29998	11	3D
0005433123952	29998	12	3F
0005433123940	29998	13	4A
0005432693118	29998	14	4C
0005432880834	29998	15	4D
0005432880830	29998	16	4E
0005432706433	29998	17	4F
0005432693111	29998	18	5A
0005433123936	29998	19	5C
0005433123953	29998	20	5D
0005432693104	29998	21	5E
0005433123935	29998	22	5F
0005432693100	29998	23	6A
0005432693099	29998	24	6C
0005432706656	29998	25	6D
0005432693126	29998	26	6E
0005432693108	29998	27	6F
0005432706646	29998	28	7A
0005432880828	29998	29	7C
0005432706596	29998	30	7E
0005432693122	29998	31	7D
0005432706622	29998	32	7F
0005432693097	29998	33	8A
0005432706471	29998	34	8C
0005432706532	29998	35	8D
0005432880827	29998	36	8E
0005432693116	29998	37	8F
0005432693119	29998	38	9A
0005432706588	29998	39	9C
0005432693121	29998	40	9D
0005432693103	29998	41	9E
0005432706621	29998	42	9F
0005432706559	29998	43	10A
0005433123945	29998	44	10C
0005432880823	29998	45	10D
0005432693125	29998	46	10E
0005432880821	29998	47	10F
0005433123932	29998	48	11A
0005432693102	29998	49	11C
0005432880824	29998	50	11D
0005432693109	29998	51	11E
0005433123938	29998	52	11F
0005433123937	29998	53	12A
0005432706720	29998	54	12C
0005432706554	29998	55	12D
0005432693115	29998	56	12E
0005433123949	29998	57	12F
0005432693114	29998	58	13A
0005432693120	29998	59	13C
0005432880835	29998	60	13E
0005433123947	29998	61	13D
0005433123939	29998	62	13F
0005432880825	29998	63	14C
0005432693112	29998	64	14D
0005432693098	29998	65	14E
0005432706546	29998	66	14F
0005432706645	29998	67	15A
0005432880831	29998	68	15C
0005432693101	29998	69	15D
0005432693123	29998	70	15E
0005432693117	29998	71	15F
0005432693113	29998	72	16A
0005432880822	29998	73	16C
0005432706581	29998	74	16D
0005433123931	29998	75	16E
0005432880832	29998	76	16F
0005433194859	29998	77	17A
0005433123943	29998	78	17C
0005433194858	29998	79	17D
0005433123944	29998	80	17E
0005433123950	29998	81	17F
0005433123951	29998	82	18A
0005432880833	29998	83	18C
0005432693106	29998	84	18D
0005432706541	29998	85	18E
0005432880829	29998	86	18F
0005433123946	29998	87	19A
0005432706589	29998	88	19C
0005432706574	29998	89	19D
0005432693124	29998	90	19E
0005432706625	29998	91	19F
0005432693105	29998	92	20A
0005432693107	29998	93	20C
0005433123934	29998	94	20D
0005432706550	29998	95	20F
0005432693096	29998	96	20E
0005434979785	23681	1	1A
0005434979791	23681	2	1B
0005434988743	23681	3	1C
0005434979783	23681	4	2A
0005434979792	23681	5	2B
0005434979786	23681	6	2C
0005434979778	23681	7	2D
0005434988741	23681	8	3C
0005434988750	23681	9	3D
0005434979776	23681	10	4A
0005434979782	23681	11	4B
0005434979795	23681	12	4D
0005434979777	23681	13	5A
0005434979803	23681	14	5B
0005434988744	23681	15	5C
0005434979787	23681	16	5D
0005434988745	23681	17	6A
0005434979790	23681	18	6B
0005434979775	23681	19	6C
0005434988746	23681	20	6D
0005434979781	23681	21	7B
0005434979788	23681	22	7C
0005434979793	23681	23	7D
0005434979799	23681	24	18A
0005434979794	23681	25	18B
0005434979800	23681	26	18C
0005434988751	23681	27	18D
0005434988742	23681	28	19A
0005434979779	23681	29	19B
0005434979798	23681	30	19C
0005434979780	23681	31	20A
0005434979789	23681	32	20B
0005434979805	23681	33	20C
0005434979784	23681	34	21A
0005434988747	23681	35	21B
0005434979801	23681	36	21C
0005434979802	23681	37	21D
0005434979797	23681	38	22A
0005434988748	23681	39	22B
0005434979796	23681	40	22C
0005434988740	23681	41	22D
0005434988749	23681	42	23A
0005434979804	23681	43	23B
0005434979582	27555	1	1B
0005434988626	27555	2	1C
0005434979595	27555	3	2D
0005434979612	27555	4	3B
0005434979492	27555	5	3C
0005434979570	27555	6	3D
0005434979515	27555	7	4A
0005434988625	27555	8	4B
0005434979510	27555	9	4D
0005434979555	27555	10	5A
0005434979573	27555	11	5B
0005434979557	27555	12	5C
0005434988645	27555	13	5D
0005434979587	27555	14	6A
0005434988633	27555	15	6B
0005434979501	27555	16	6C
0005434979621	27555	17	6D
0005434979545	27555	18	7A
0005434979608	27555	19	7B
0005434988643	27555	20	7C
0005434979500	27555	21	7D
0005434979586	27555	22	18A
0005434979491	27555	23	18B
0005434979525	27555	24	18C
0005434979376	27555	25	19A
0005434979293	27555	26	19B
0005434988636	27555	27	19D
0005434988644	27555	28	20B
0005434979606	27555	29	20C
0005434988619	27555	30	20D
0005434979516	27555	31	21A
0005434979507	27555	32	21B
0005434979556	27555	33	21C
0005434979620	27555	34	21D
0005434979584	27555	35	22A
0005434979546	27555	36	22B
0005434979583	27555	37	22C
0005434979554	27555	38	22D
0005434979585	27555	39	23B
0005434302460	10266	1	2B
0005433113520	10266	2	3A
0005433113522	10266	3	4C
0005433111472	10266	4	5B
0005434302461	10266	5	5C
0005434302459	10266	6	6B
0005433113519	10266	7	7B
0005434302458	10266	8	7C
0005433113521	10266	9	21C
0005434302432	19644	1	3C
0005434302405	19644	2	4A
0005434302411	19644	3	4C
0005433113538	19644	4	6A
0005434302406	19644	5	18A
0005433113537	19644	6	18B
0005435069145	3545	1	1D
0005435069164	3545	2	1F
0005435069112	3545	3	2A
0005435069148	3545	4	2D
0005435069121	3545	5	2F
0005435925134	3545	6	3A
0005435069122	3545	7	3C
0005435069154	3545	8	3D
0005435069166	3545	9	4C
0005435069135	3545	10	4D
0005435718952	3545	11	4E
0005435925165	3545	12	5A
0005435069158	3545	13	5C
0005435069130	3545	14	5D
0005435925157	3545	15	6A
0005435718947	3545	16	6C
0005435069116	3545	17	6D
0005435069156	3545	18	6E
0005435069134	3545	19	6F
0005435069126	3545	20	7C
0005435925181	3545	21	7D
0005435925176	3545	22	7E
0005435069139	3545	23	7F
0005435069149	3545	24	8A
0005435718953	3545	25	8C
0005435925182	3545	26	8D
0005435069131	3545	27	8E
0005435069162	3545	28	8F
0005435069140	3545	29	9A
0005435069119	3545	30	9C
0005435069160	3545	31	9F
0005435925175	3545	32	10C
0005435069159	3545	33	10E
0005435069133	3545	34	10F
0005435069152	3545	35	11D
0005435718950	3545	36	11C
0005435069125	3545	37	11E
0005435069147	3545	38	12A
0005435069161	3545	39	12C
0005435069113	3545	40	12D
0005435069165	3545	41	12E
0005435069163	3545	42	12F
0005435925183	3545	43	13A
0005435925189	3545	44	13D
0005435069132	3545	45	13F
0005435069129	3545	46	14A
0005435069146	3545	47	14C
0005435069127	3545	48	14D
0005435069124	3545	49	14E
0005435069151	3545	50	14F
0005435069157	3545	51	15D
0005435069128	3545	52	15E
0005435069120	3545	53	15F
0005435925164	3545	54	16A
0005435718949	3545	55	16C
0005435925150	3545	56	16D
0005435069117	3545	57	16F
0005435069142	3545	58	17A
0005435925166	3545	59	17C
0005435069144	3545	60	17D
0005435069118	3545	61	17E
0005435069141	3545	62	17F
0005435718948	3545	63	18A
0005435069143	3545	64	18C
0005435069136	3545	65	18D
0005435069114	3545	66	18E
0005435069138	3545	67	18F
0005435069115	3545	68	19A
0005435069150	3545	69	19E
0005435718951	3545	70	19F
0005435069155	3545	71	20A
0005435069153	3545	72	20C
0005435925177	3545	73	20D
0005435069137	3545	74	20E
0005435069123	3545	75	20F
0005435068706	15323	1	1A
0005435068702	15323	2	1C
0005435068650	15323	3	1F
0005435068806	15323	4	2A
0005435068731	15323	5	2C
0005435939877	15323	6	2D
0005435068522	15323	7	2F
0005435068502	15323	8	3A
0005435925303	15323	9	3C
0005435068517	15323	10	3F
0005435925302	15323	11	4A
0005435068669	15323	12	4C
0005435068622	15323	13	4E
0005435068648	15323	14	5A
0005435068701	15323	15	5C
0005435068760	15323	16	5D
0005435068721	15323	17	5E
0005435068694	15323	18	6A
0005435068681	15323	19	6D
0005435068398	15323	20	6E
0005435068653	15323	21	7A
0005435939878	15323	22	7C
0005435068672	15323	23	7D
0005435068516	15323	24	7E
0005435068722	15323	25	7F
0005435068399	15323	26	8C
0005435925299	15323	27	8D
0005435068514	15323	28	8E
0005435925301	15323	29	8F
0005435068523	15323	30	9C
0005435068695	15323	31	9D
0005435068932	15323	32	9F
0005435068665	15323	33	10A
0005435925295	15323	34	10C
0005435925300	15323	35	10D
0005435068506	15323	36	11A
0005435068332	15323	37	11C
0005435939880	15323	38	11D
0005435068649	15323	39	11E
0005435068606	15323	40	12A
0005435068507	15323	41	12C
0005435068521	15323	42	12D
0005435068687	15323	43	12E
0005435068512	15323	44	12F
0005435068513	15323	45	13C
0005435925297	15323	46	13D
0005435068691	15323	47	13F
0005435068461	15323	48	14A
0005435925296	15323	49	14C
0005435068749	15323	50	14F
0005435068757	15323	51	14E
0005435068686	15323	52	15A
0005435925304	15323	53	15C
0005435068486	15323	54	15F
0005435068515	15323	55	16A
0005435068485	15323	56	16C
0005435068503	15323	57	16E
0005435068696	15323	58	16F
0005435068663	15323	59	17A
0005435939881	15323	60	17C
0005435068596	15323	61	17D
0005435068424	15323	62	17E
0005435068680	15323	63	17F
0005435068758	15323	64	18A
0005435068785	15323	65	18C
0005435068608	15323	66	18D
0005435925298	15323	67	18E
0005435068805	15323	68	18F
0005435068743	15323	69	19A
0005435068662	15323	70	19C
0005435068575	15323	71	19E
0005435068623	15323	72	19F
0005435068484	15323	73	20A
0005435939879	15323	74	20C
0005435068878	15323	75	20D
0005435068586	15323	76	20E
0005435068682	15323	77	20F
0005432660819	18111	1	3A
0005432659708	18111	2	2B
0005432659707	18111	3	3B
0005432658593	18111	4	4A
0005432660820	18111	5	5B
0005432658594	18111	6	6A
0005432658592	18111	7	6B
0005432660797	26425	1	1A
0005432667443	26425	2	1B
0005432667434	26425	3	2B
0005432660799	26425	4	3B
0005432664117	26425	5	4A
0005432667439	26425	6	5A
0005432660803	26425	7	5B
0005432660801	26425	8	6A
0005432660800	26425	9	6B
0005432677531	207	1	1A
0005433101762	207	2	2A
0005432919709	207	3	1F
0005433101512	207	4	3A
0005433101817	207	5	2F
0005433101821	207	6	3D
0005433101759	207	7	4A
0005433101743	207	8	4D
0005433101726	207	9	4F
0005432919702	207	10	6A
0005433101835	207	11	6C
0005432919675	207	12	6F
0005432901489	207	13	7A
0005432919736	207	14	7D
0005433101814	207	15	7F
0005433101720	207	16	8C
0005433101781	207	17	8B
0005432919737	207	18	8D
0005433101772	207	19	8E
0005433101514	207	20	8F
0005433101820	207	21	9A
0005433101702	207	22	9C
0005433101815	207	23	9B
0005432901416	207	24	9F
0005433101626	207	25	10A
0005432901480	207	26	10B
0005433101811	207	27	10C
0005433101725	207	28	10E
0005433101780	207	29	10D
0005433101777	207	30	10F
0005433101776	207	31	11D
0005432901485	207	32	11F
0005433101722	207	33	12A
0005432901423	207	34	12D
0005432901445	207	35	13A
0005433101748	207	36	12F
0005433101704	207	37	13E
0005432677548	207	38	13D
0005433101745	207	39	13F
0005433101464	207	40	14A
0005432901520	207	41	14D
0005432919750	207	42	14C
0005433101578	207	43	14E
0005433101627	207	44	14F
0005432901452	207	45	15B
0005433101792	207	46	15A
0005433101577	207	47	15C
0005433101632	207	48	15D
0005432157493	207	49	16A
0005432157494	207	50	15F
0005433101646	207	51	16C
0005433101827	207	52	16B
0005433101741	207	53	16D
0005432901519	207	54	16E
0005432901453	207	55	17A
0005432901500	207	56	17B
0005433101538	207	57	17E
0005433101828	207	58	17D
0005433101697	207	59	18A
0005432901425	207	60	17F
0005432919751	207	61	18D
0005432901499	207	62	18C
0005433101630	207	63	19D
0005432919780	207	64	19C
0005433101744	207	65	19E
0005432901508	207	66	20A
0005432901415	207	67	20C
0005432901422	207	68	20F
0005433101818	207	69	21A
0005433101841	207	70	21F
0005433101670	207	71	22B
0005433101738	207	72	22D
0005432901429	207	73	23C
0005432677554	207	74	23E
0005432901484	207	75	23F
0005433101513	207	76	24A
0005432919701	207	77	24C
0005432901424	207	78	24F
0005432919677	207	79	25A
0005433101761	207	80	25B
0005433101760	207	81	25D
0005432919676	207	82	25C
0005432901509	207	83	26C
0005433101819	207	84	26B
0005432901551	207	85	26D
0005433101672	207	86	26F
0005432901455	207	87	27A
0005433101773	207	88	27C
0005433101631	207	89	27B
0005433101782	207	90	27D
0005433101747	207	91	28A
0005433101537	207	92	27F
0005433101791	207	93	28C
0005433101746	207	94	28B
0005433101783	207	95	28E
0005433101813	207	96	29A
0005432919734	207	97	29C
0005433101802	207	98	29B
0005433101769	207	99	29D
0005433101701	207	100	29E
0005433101766	207	101	29F
0005432901389	207	102	30B
0005433101724	207	103	30D
0005432919725	207	104	31A
0005433101768	207	105	31B
0005432677532	207	106	31E
0005432261933	208	1	1C
0005432817485	208	2	1A
0005433690904	208	3	2A
0005432817509	208	4	1F
0005432288991	208	5	2D
0005432261975	208	6	2C
0005432261941	208	7	3A
0005432817514	208	8	4A
0005432261974	208	9	3F
0005432207661	208	10	4C
0005432817498	208	11	5A
0005432817511	208	12	4F
0005432756818	208	13	5C
0005432817489	208	14	5D
0005432753266	208	15	6C
0005432261952	208	16	6D
0005432261948	208	17	7A
0005432261949	208	18	7F
0005432261964	208	19	8A
0005432261969	208	20	8C
0005432817493	208	21	8F
0005433690914	208	22	9E
0005432817495	208	23	9F
0005432756819	208	24	10D
0005432817510	208	25	10C
0005432261966	208	26	10E
0005432261951	208	27	10F
0005432817484	208	28	11A
0005432261972	208	29	11C
0005432261970	208	30	11B
0005432261944	208	31	11D
0005432817492	208	32	11F
0005432261950	208	33	11E
0005432753277	208	34	12B
0005432817503	208	35	12E
0005432817501	208	36	12D
0005432817505	208	37	12F
0005432817496	208	38	13C
0005432261954	208	39	13F
0005432817513	208	40	13E
0005432261946	208	41	14A
0005432753264	208	42	14B
0005432261957	208	43	14D
0005432261943	208	44	14C
0005432261961	208	45	14E
0005432261930	208	46	15C
0005432261973	208	47	15D
0005432261955	208	48	15F
0005432261962	208	49	16A
0005432753270	208	50	16C
0005432817497	208	51	16B
0005432261971	208	52	16D
0005432817488	208	53	17A
0005433690907	208	54	17B
0005432261965	208	55	17E
0005432288988	208	56	17F
0005432288990	208	57	18A
0005432261958	208	58	18B
0005432817499	208	59	18D
0005432261937	208	60	18C
0005432756814	208	61	18F
0005432261953	208	62	19C
0005432817487	208	63	19B
0005432817502	208	64	19D
0005432817515	208	65	19E
0005432261967	208	66	20A
0005432261936	208	67	20F
0005432817506	208	68	21A
0005432817507	208	69	21B
0005432817486	208	70	21F
0005432261934	208	71	22A
0005432261959	208	72	22B
0005433690900	208	73	22C
0005432261931	208	74	22E
0005432261956	208	75	22F
0005432817504	208	76	23A
0005432817491	208	77	23B
0005432817500	208	78	24A
0005432207662	208	79	23F
0005432753268	208	80	24E
0005432261940	208	81	25A
0005432817512	208	82	25B
0005432261938	208	83	25F
0005433690915	208	84	26B
0005432261935	208	85	26A
0005432261932	208	86	26D
0005432261968	208	87	26F
0005432753267	208	88	27C
0005432207663	208	89	28A
0005432817494	208	90	27F
0005432288989	208	91	28B
0005432261947	208	92	28C
0005432756812	208	93	28F
0005432817490	208	94	29A
0005432817508	208	95	29C
0005432261960	208	96	30D
0005433690916	208	97	30C
0005432261939	208	98	30E
0005432756811	208	99	30F
0005432261945	208	100	31A
0005432261942	208	101	31C
0005432261963	208	102	31E
0005432919877	8159	1	1C
0005433102216	8159	2	1D
0005432020296	8159	3	2A
0005433102173	8159	4	1F
0005433102239	8159	5	2C
0005432020297	8159	6	2F
0005433102213	8159	7	2D
0005432045615	8159	8	3C
0005432020284	8159	9	3F
0005433102209	8159	10	3D
0005433102235	8159	11	4C
0005432020282	8159	12	4F
0005433102227	8159	13	5D
0005433102188	8159	14	5A
0005433102176	8159	15	6A
0005433102237	8159	16	6C
0005432919874	8159	17	7A
0005432044527	8159	18	6F
0005432020290	8159	19	7C
0005432020285	8159	20	8A
0005433102238	8159	21	7F
0005432919883	8159	22	8F
0005432020286	8159	23	9B
0005433102218	8159	24	9C
0005433102186	8159	25	9E
0005433102199	8159	26	9D
0005433102189	8159	27	10A
0005433102180	8159	28	10C
0005432020273	8159	29	10D
0005432020294	8159	30	10F
0005432919881	8159	31	11A
0005433102195	8159	32	11D
0005432677578	8159	33	12B
0005432919885	8159	34	12E
0005432751531	8159	35	12F
0005433102193	8159	36	13A
0005433102224	8159	37	13C
0005433102229	8159	38	13B
0005432020276	8159	39	13D
0005432677579	8159	40	13F
0005433102222	8159	41	14A
0005432045616	8159	42	14B
0005432677580	8159	43	14C
0005432044528	8159	44	14E
0005433102204	8159	45	14D
0005432919876	8159	46	14F
0005433102232	8159	47	15B
0005432020295	8159	48	15A
0005433102198	8159	49	15C
0005432919873	8159	50	15D
0005433102228	8159	51	15E
0005433102200	8159	52	16A
0005433102225	8159	53	15F
0005433102202	8159	54	16B
0005433102230	8159	55	16C
0005433102231	8159	56	16F
0005433102182	8159	57	16E
0005432677577	8159	58	17A
0005433102226	8159	59	17C
0005433102223	8159	60	17B
0005432919869	8159	61	17E
0005433102217	8159	62	17D
0005433102190	8159	63	17F
0005432919871	8159	64	18A
0005432020274	8159	65	18B
0005433102233	8159	66	18D
0005432753305	8159	67	18C
0005432020283	8159	68	18E
0005432392003	8159	69	18F
0005432020281	8159	70	19B
0005433102212	8159	71	19D
0005432677581	8159	72	19C
0005433102219	8159	73	19E
0005432919870	8159	74	20A
0005433102177	8159	75	20C
0005433102206	8159	76	20E
0005432020299	8159	77	20D
0005432919880	8159	78	20F
0005433102181	8159	79	21A
0005432020298	8159	80	21B
0005433102215	8159	81	21D
0005432919878	8159	82	21E
0005432919884	8159	83	22A
0005433102236	8159	84	21F
0005433102208	8159	85	22C
0005432919868	8159	86	22D
0005433102175	8159	87	22F
0005432392002	8159	88	23A
0005433102210	8159	89	23B
0005433102183	8159	90	23F
0005432020289	8159	91	23E
0005433102205	8159	92	24B
0005432919886	8159	93	24C
0005432020278	8159	94	24D
0005433102194	8159	95	25A
0005432020275	8159	96	24F
0005432020288	8159	97	25C
0005432020291	8159	98	25B
0005432020293	8159	99	25E
0005432020287	8159	100	26A
0005433102220	8159	101	25F
0005432919887	8159	102	26B
0005433102172	8159	103	26C
0005432919879	8159	104	26E
0005432753303	8159	105	26D
0005432753306	8159	106	26F
0005433102197	8159	107	27B
0005432753304	8159	108	27A
0005432020277	8159	109	27C
0005433102178	8159	110	27D
0005432044526	8159	111	27E
0005432919875	8159	112	27F
0005433102192	8159	113	28B
0005433102185	8159	114	28A
0005433102179	8159	115	28C
0005432919872	8159	116	28D
0005433102207	8159	117	28F
0005432020280	8159	118	28E
0005433102214	8159	119	29B
0005433102234	8159	120	29A
0005433102187	8159	121	29C
0005432020292	8159	122	29D
0005432392004	8159	123	29E
0005432020279	8159	124	30A
0005432919882	8159	125	29F
0005432392001	8159	126	30B
0005433102191	8159	127	30C
0005433102174	8159	128	30E
0005433102211	8159	129	30F
0005433102201	8159	130	31A
0005433102184	8159	131	31C
0005433102203	8159	132	31B
0005433102221	8159	133	31E
0005433102196	8159	134	31F
0005434513557	8160	1	1A
0005432817214	8160	2	2A
0005432817230	8160	3	3F
0005432817127	8160	4	5C
0005432817149	8160	5	6A
0005432901632	8160	6	7A
0005432901622	8160	7	7C
0005434513553	8160	8	8A
0005432817251	8160	9	8D
0005434513558	8160	10	9A
0005432817430	8160	11	9E
0005432901634	8160	12	10A
0005432817296	8160	13	10C
0005432901620	8160	14	11E
0005432817231	8160	15	12A
0005432817142	8160	16	11F
0005432817145	8160	17	12E
0005432817291	8160	18	12D
0005432817247	8160	19	13C
0005432817213	8160	20	14A
0005434513555	8160	21	14C
0005432817181	8160	22	14B
0005432901623	8160	23	15C
0005434513551	8160	24	15D
0005432817143	8160	25	15F
0005432817144	8160	26	16B
0005432817290	8160	27	16E
0005432817193	8160	28	17B
0005432901627	8160	29	17A
0005432817125	8160	30	17E
0005432817242	8160	31	19C
0005432901624	8160	32	19B
0005432901628	8160	33	19E
0005434513547	8160	34	20A
0005432817147	8160	35	20D
0005432817195	8160	36	21B
0005432817215	8160	37	21C
0005432817282	8160	38	21D
0005432901617	8160	39	21E
0005434513552	8160	40	21F
0005432817148	8160	41	22D
0005432817196	8160	42	23C
0005432817155	8160	43	23B
0005432901626	8160	44	24C
0005432901619	8160	45	24F
0005432817276	8160	46	26B
0005432817330	8160	47	27E
0005432817157	8160	48	28A
0005432817269	8160	49	28C
0005432901631	8160	50	28B
0005434513556	8160	51	28E
0005432817126	8160	52	28D
0005432817323	8160	53	29A
0005432901621	8160	54	29C
0005432817156	8160	55	29B
0005432901633	8160	56	29D
0005434513554	8160	57	29E
0005432901625	8160	58	30D
0005432817180	8160	59	30C
0005432901629	8160	60	30E
0005432901618	8160	61	31A
0005432901630	8160	62	31B
0005432817324	8160	63	31C
0005434513573	8160	64	31D
0005432817250	8160	65	31E
0005433870733	9691	1	1A
0005434175710	9691	2	1B
0005434175700	9691	3	2B
0005434175718	9691	4	3B
0005434175717	9691	5	4B
0005434175731	9691	6	5B
0005433870732	9691	7	6B
0005434175758	32326	1	2B
0005434175756	32326	2	3A
0005433870720	32326	3	3B
0005434175757	32326	4	5A
0005434175755	32326	5	6B
0005432799481	3479	1	1A
0005434878379	3479	2	1H
0005434878322	3479	3	1G
0005434878315	3479	4	1D
0005435126427	3479	5	2A
0005434878347	3479	6	1K
0005432799501	3479	7	2D
0005434938158	3479	8	2C
0005434426631	3479	9	2H
0005435902489	3479	10	2G
0005434426641	3479	11	3A
0005434878331	3479	12	2K
0005434878357	3479	13	3C
0005434878352	3479	14	3H
0005435126421	3479	15	3G
0005434878336	3479	16	4C
0005434878387	3479	17	3K
0005434878348	3479	18	4H
0005435902517	3479	19	4G
0005434878334	3479	20	4K
0005435626186	3479	21	5C
0005434878313	3479	22	5A
0005434878303	3479	23	5H
0005435902620	3479	24	5G
0005432799500	3479	25	5D
0005435126408	3479	26	11D
0005435126425	3479	27	11G
0005435902562	3479	28	11E
0005435126435	3479	29	11K
0005435626188	3479	30	11H
0005434426649	3479	31	12C
0005434426629	3479	32	12A
0005435902598	3479	33	12G
0005435913880	3479	34	12K
0005434878314	3479	35	12H
0005435626191	3479	36	13D
0005435126405	3479	37	13H
0005434878321	3479	38	14C
0005432613866	3479	39	14A
0005434426639	3479	40	13K
0005435626180	3479	41	14D
0005434878376	3479	42	14G
0005434878361	3479	43	14F
0005434878301	3479	44	14E
0005435902523	3479	45	14H
0005432799484	3479	46	15C
0005434938168	3479	47	15A
0005432183470	3479	48	14K
0005435126397	3479	49	15D
0005432799475	3479	50	15G
0005434878358	3479	51	15F
0005432799476	3479	52	16A
0005435126401	3479	53	15K
0005435126429	3479	54	15H
0005435126403	3479	55	16C
0005434426630	3479	56	16K
0005434426653	3479	57	17G
0005435126434	3479	58	17E
0005435626179	3479	59	17K
0005434938159	3479	60	18B
0005435126411	3479	61	18A
0005434878327	3479	62	18C
0005434938156	3479	63	18K
0005432183469	3479	64	18J
0005434878382	3479	65	18H
0005435626178	3479	66	19A
0005434878312	3479	67	19D
0005434878299	3479	68	19B
0005434938155	3479	69	19H
0005434878378	3479	70	19G
0005435126433	3479	71	19K
0005434878345	3479	72	19J
0005435841814	3479	73	20C
0005432799491	3479	74	20B
0005432799496	3479	75	20E
0005434878326	3479	76	20D
0005435902560	3479	77	20G
0005434426647	3479	78	20F
0005434878349	3479	79	20J
0005432611714	3479	80	20H
0005434426644	3479	81	21B
0005434878324	3479	82	21A
0005435902566	3479	83	20K
0005432799498	3479	84	21D
0005434878388	3479	85	21C
0005435126402	3479	86	21F
0005434878338	3479	87	21E
0005434878363	3479	88	21J
0005432799473	3479	89	21K
0005434878384	3479	90	22C
0005432799497	3479	91	22B
0005434878300	3479	92	22D
0005435902520	3479	93	22H
0005434426645	3479	94	22F
0005434426633	3479	95	22K
0005435902559	3479	96	22J
0005432799478	3479	97	23B
0005435126399	3479	98	23D
0005434938166	3479	99	23C
0005434938157	3479	100	23E
0005435626184	3479	101	23J
0005435902602	3479	102	23H
0005434878307	3479	103	24D
0005432188611	3479	104	24F
0005435902563	3479	105	24E
0005435626176	3479	106	25B
0005435626182	3479	107	25H
0005432799494	3479	108	26C
0005434878366	3479	109	26B
0005434878305	3479	110	26A
0005434938163	3479	111	26D
0005434426640	3479	112	26G
0005434938161	3479	113	26H
0005435902484	3479	114	27A
0005434878320	3479	115	26K
0005434878302	3479	116	27D
0005435126418	3479	117	27C
0005435126430	3479	118	27B
0005434938160	3479	119	27E
0005434878377	3479	120	27H
0005432799483	3479	121	27K
0005434426638	3479	122	27J
0005435126417	3479	123	28C
0005435126416	3479	124	28B
0005434878309	3479	125	28D
0005435913886	3479	126	28F
0005434878381	3479	127	28K
0005435913888	3479	128	28H
0005434938165	3479	129	29B
0005434426636	3479	130	29A
0005435626192	3479	131	29C
0005434878367	3479	132	29G
0005434878389	3479	133	29K
0005435126412	3479	134	29J
0005434878362	3479	135	30B
0005434938171	3479	136	30A
0005434878319	3479	137	30D
0005434878335	3479	138	30G
0005434938169	3479	139	30F
0005434878342	3479	140	31A
0005435126404	3479	141	30K
0005435626177	3479	142	31D
0005435902524	3479	143	31C
0005432188612	3479	144	31B
0005434878340	3479	145	31F
0005434426652	3479	146	31E
0005435902538	3479	147	31J
0005435126409	3479	148	31H
0005434426632	3479	149	31K
0005434878337	3479	150	32C
0005434878355	3479	151	32B
0005434878359	3479	152	32A
0005435126406	3479	153	32E
0005434426650	3479	154	32G
0005434426627	3479	155	32F
0005432799490	3479	156	32K
0005435126415	3479	157	32J
0005432611716	3479	158	33C
0005434878350	3479	159	33F
0005435126420	3479	160	33G
0005435913881	3479	161	33K
0005435626185	3479	162	34B
0005434878310	3479	163	34H
0005435126413	3479	164	34G
0005435902534	3479	165	34F
0005432799479	3479	166	34J
0005434878304	3479	167	35A
0005434878325	3479	168	34K
0005432799493	3479	169	35D
0005432799488	3479	170	35C
0005434938172	3479	171	35B
0005435126436	3479	172	35F
0005434426643	3479	173	35E
0005432799489	3479	174	35J
0005434938164	3479	175	36C
0005432799495	3479	176	36D
0005434878375	3479	177	36H
0005434426628	3479	178	36G
0005434878323	3479	179	36K
0005435913872	3479	180	37C
0005434878341	3479	181	37B
0005434426642	3479	182	37D
0005435626187	3479	183	37F
0005434878380	3479	184	37G
0005435626175	3479	185	37K
0005435126428	3479	186	38H
0005435626190	3479	187	38C
0005432613867	3479	188	38B
0005435626174	3479	189	38A
0005434878385	3479	190	39A
0005432611713	3479	191	39D
0005435126400	3479	192	39B
0005432799477	3479	193	39H
0005434426648	3479	194	40A
0005432799492	3479	195	39K
0005434938154	3479	196	40C
0005434426654	3479	197	40B
0005435126437	3479	198	40E
0005434426651	3479	199	40D
0005432799482	3479	200	40G
0005434878383	3479	201	40K
0005434878356	3479	202	40J
0005434878344	3479	203	40H
0005434878333	3479	204	41B
0005432183468	3479	205	41A
0005434878368	3479	206	41D
0005434878346	3479	207	41C
0005434426635	3479	208	41G
0005434878354	3479	209	41F
0005434878360	3479	210	41E
0005434878308	3479	211	41K
0005435913887	3479	212	42C
0005434878369	3479	213	42E
0005434878306	3479	214	42D
0005434878364	3479	215	42H
0005434878370	3479	216	42G
0005434878328	3479	217	42J
0005432799487	3479	218	43A
0005434878311	3479	219	42K
0005434878329	3479	220	43E
0005434938162	3479	221	43H
0005435902483	3479	222	43G
0005434938173	3479	223	44A
0005434938153	3479	224	43J
0005435626189	3479	225	44B
0005435902533	3479	226	44E
0005434878365	3479	227	44D
0005434426634	3479	228	44C
0005434878318	3479	229	44G
0005435126432	3479	230	44F
0005434878317	3479	231	45D
0005435902587	3479	232	45C
0005435126419	3479	233	45B
0005435126423	3479	234	45F
0005432799485	3479	235	45E
0005435126410	3479	236	45H
0005434878374	3479	237	45G
0005434938167	3479	238	45K
0005434878343	3479	239	45J
0005435126431	3479	240	46C
0005434878332	3479	241	46B
0005434878339	3479	242	46E
0005432799474	3479	243	46D
0005435126424	3479	244	46G
0005435126414	3479	245	46J
0005434878372	3479	246	46H
0005435126422	3479	247	47D
0005434878371	3479	248	47C
0005435126396	3479	249	47G
0005434426646	3479	250	47F
0005434938170	3479	251	47K
0005434426656	3479	252	47H
0005434878351	3479	253	48D
0005434878330	3479	254	48C
0005432799499	3479	255	48E
0005434878353	3479	256	48H
0005432611715	3479	257	48G
0005434878316	3479	258	49A
0005432613865	3479	259	49D
0005432799480	3479	260	49C
0005434426637	3479	261	49G
0005435126398	3479	262	49F
0005435902535	3479	263	49E
0005435126407	3479	264	49K
0005435626181	3479	265	50C
0005434426655	3479	266	50E
0005435626183	3479	267	50H
0005434878373	3479	268	50G
0005432799486	3479	269	50K
0005435902567	3479	270	51F
0005434878386	3479	271	51E
0005435126426	3479	272	51G
0005435626000	14556	1	1C
0005435626024	14556	2	1A
0005435902718	14556	3	1D
0005434877529	14556	4	2D
0005432607524	14556	5	2A
0005435125719	14556	6	2H
0005432799174	14556	7	2G
0005432799413	14556	8	2K
0005432799289	14556	9	3D
0005434877692	14556	10	3H
0005432799270	14556	11	4C
0005434877257	14556	12	4A
0005434937922	14556	13	4H
0005432799284	14556	14	4G
0005434426441	14556	15	4D
0005435626001	14556	16	5D
0005435125966	14556	17	5A
0005435125952	14556	18	5G
0005434877718	14556	19	11A
0005435126064	14556	20	5K
0005435126015	14556	21	11D
0005432799176	14556	22	11C
0005435902719	14556	23	11F
0005435126089	14556	24	12C
0005434877141	14556	25	12E
0005432799241	14556	26	12G
0005435126199	14556	27	13A
0005435126071	14556	28	12H
0005434878090	14556	29	13D
0005434938061	14556	30	13C
0005434426211	14556	31	13F
0005434426385	14556	32	13E
0005435126198	14556	33	13K
0005434877344	14556	34	13G
0005434426439	14556	35	14A
0005434877532	14556	36	14E
0005434877485	14556	37	14D
0005434938007	14556	38	14C
0005434877410	14556	39	14K
0005432611679	14556	40	14H
0005435126145	14556	41	14G
0005435902727	14556	42	15C
0005434877471	14556	43	15A
0005434877489	14556	44	15E
0005434877370	14556	45	15D
0005432799364	14556	46	15H
0005435626022	14556	47	15G
0005435902726	14556	48	15F
0005434877656	14556	49	16D
0005434426379	14556	50	16C
0005434877423	14556	51	16A
0005435126048	14556	52	16E
0005432799285	14556	53	16K
0005435125893	14556	54	16H
0005435126008	14556	55	17A
0005434877144	14556	56	17D
0005435125954	14556	57	17G
0005432799228	14556	58	17K
0005435126009	14556	59	18C
0005434426430	14556	60	18D
0005435126000	14556	61	18G
0005434426397	14556	62	18K
0005434938023	14556	63	18J
0005432607513	14556	64	18H
0005432799276	14556	65	19B
0005434877102	14556	66	19A
0005432611661	14556	67	19D
0005434937930	14556	68	19C
0005434426445	14556	69	19E
0005435125877	14556	70	19J
0005435902725	14556	71	19H
0005435125953	14556	72	19G
0005435902712	14556	73	20A
0005434877637	14556	74	19K
0005435902720	14556	75	20B
0005434877337	14556	76	20E
0005434877487	14556	77	20D
0005435125924	14556	78	20G
0005435902716	14556	79	20F
0005434877240	14556	80	20J
0005434426447	14556	81	20H
0005432799309	14556	82	21B
0005432799307	14556	83	21A
0005435902715	14556	84	20K
0005435126069	14556	85	21D
0005432799184	14556	86	21C
0005434426442	14556	87	21F
0005432799310	14556	88	21J
0005434426461	14556	89	21H
0005434878057	14556	90	22A
0005434877364	14556	91	22C
0005434877433	14556	92	22B
0005435902717	14556	93	22E
0005435913937	14556	94	22D
0005435125981	14556	95	22H
0005435125948	14556	96	22G
0005435125835	14556	97	22K
0005434426243	14556	98	22J
0005435913939	14556	99	23B
0005434877204	14556	100	23D
0005434877481	14556	101	23C
0005434937976	14556	102	23G
0005435626023	14556	103	23F
0005435125916	14556	104	23H
0005434877448	14556	105	24D
0005434938004	14556	106	23K
0005434877681	14556	107	23J
0005435902713	14556	108	24E
0005434877422	14556	109	25D
0005435626010	14556	110	25C
0005434426443	14556	111	25B
0005434877402	14556	112	25E
0005435125949	14556	113	25H
0005432799306	14556	114	25G
0005434877203	14556	115	25K
0005434937977	14556	116	25J
0005434877689	14556	117	26C
0005434877690	14556	118	26B
0005434877726	14556	119	26D
0005434877345	14556	120	26G
0005435126020	14556	121	26F
0005434426503	14556	122	26J
0005434877466	14556	123	26H
0005434877636	14556	124	27B
0005434877507	14556	125	27A
0005432799365	14556	126	26K
0005434938008	14556	127	27D
0005435902724	14556	128	27F
0005434877319	14556	129	27E
0005434426409	14556	130	27J
0005434877706	14556	131	27H
0005434877568	14556	132	27G
0005432607523	14556	133	28A
0005434877336	14556	134	27K
0005434877241	14556	135	28E
0005434877586	14556	136	28C
0005432611680	14556	137	28G
0005435125923	14556	138	28F
0005435626025	14556	139	28J
0005432799186	14556	140	28H
0005434877407	14556	141	29B
0005434426336	14556	142	29A
0005435626030	14556	143	28K
0005434426244	14556	144	29D
0005434426319	14556	145	29C
0005434937979	14556	146	29E
0005432799347	14556	147	29G
0005432799412	14556	148	29K
0005434877317	14556	149	29J
0005434937980	14556	150	30B
0005434877727	14556	151	30D
0005435625980	14556	152	30H
0005434426407	14556	153	30F
0005435126059	14556	154	30J
0005432799294	14556	155	31C
0005434426335	14556	156	31B
0005434938025	14556	157	31G
0005434877480	14556	158	31H
0005435125892	14556	159	32C
0005434937978	14556	160	32E
0005434877173	14556	161	32D
0005435902722	14556	162	32H
0005434877357	14556	163	32G
0005432799275	14556	164	32F
0005432611664	14556	165	32J
0005434877592	14556	166	33A
0005432059506	14556	167	33D
0005434876851	14556	168	33C
0005435125965	14556	169	33F
0005435625989	14556	170	33J
0005434877560	14556	171	33H
0005435902714	14556	172	34C
0005435626020	14556	173	34B
0005432799260	14556	174	34A
0005434876852	14556	175	34E
0005432799268	14556	176	34D
0005434877369	14556	177	34F
0005434877199	14556	178	34J
0005435902728	14556	179	34H
0005435626014	14556	180	35B
0005432607514	14556	181	35A
0005434938050	14556	182	35C
0005435126115	14556	183	35F
0005434877569	14556	184	35H
0005434877691	14556	185	35G
0005434877503	14556	186	36C
0005435125988	14556	187	36D
0005434877722	14556	188	36G
0005434877531	14556	189	36H
0005435125933	14556	190	37B
0005435126050	14556	191	36K
0005434938024	14556	192	37D
0005434877685	14556	193	37C
0005434877231	14556	194	37E
0005434877555	14556	195	37H
0005434877514	14556	196	37G
0005432059508	14556	197	38A
0005434877205	14556	198	37K
0005434426396	14556	199	38C
0005435626018	14556	200	38B
0005432799245	14556	201	38H
0005435625917	14556	202	38K
0005432799366	14556	203	39D
0005434937975	14556	204	39B
0005434877585	14556	205	39F
0005432799281	14556	206	39E
0005434426369	14556	207	39J
0005435902721	14556	208	40B
0005432799374	14556	209	40E
0005434426356	14556	210	40D
0005434426457	14556	211	40H
0005434426429	14556	212	40F
0005435625953	14556	213	40J
0005434877633	14556	214	41B
0005434877565	14556	215	41A
0005434426357	14556	216	41F
0005432799269	14556	217	41G
0005434877069	14556	218	42A
0005435126099	14556	219	41K
0005434426212	14556	220	42B
0005435126149	14556	221	42D
0005435626011	14556	222	42G
0005434877764	14556	223	42F
0005434877251	14556	224	42J
0005435625993	14556	225	43A
0005435626036	14556	226	42K
0005434426446	14556	227	43D
0005432799367	14556	228	43C
0005435126090	14556	229	43B
0005435125987	14556	230	43F
0005434877643	14556	231	43J
0005434426242	14556	232	43H
0005432799198	14556	233	43G
0005435126078	14556	234	44A
0005434877827	14556	235	43K
0005434877258	14556	236	44E
0005434877441	14556	237	44D
0005432799177	14556	238	44C
0005435626016	14556	239	44G
0005432611662	14556	240	44J
0005434426215	14556	241	44H
0005434426413	14556	242	45A
0005432799175	14556	243	44K
0005434877682	14556	244	45D
0005434877476	14556	245	45C
0005434938009	14556	246	45E
0005432799055	14556	247	45H
0005434426465	14556	248	45K
0005434938003	14556	249	45J
0005435126142	14556	250	46B
0005432607532	14556	251	46E
0005434426337	14556	252	46D
0005435625981	14556	253	46C
0005432059507	14556	254	46G
0005434877358	14556	255	46F
0005435913938	14556	256	46K
0005432799242	14556	257	47C
0005432607535	14556	258	47A
0005434877470	14556	259	47D
0005432799134	14556	260	47F
0005435125982	14556	261	47K
0005435902729	14556	262	48F
0005434426431	14556	263	48E
0005434877528	14556	264	48H
0005435126228	14556	265	49A
0005432607550	14556	266	48K
0005432799411	14556	267	49F
0005435126049	14556	268	49E
0005434877318	14556	269	49K
0005435902723	14556	270	49H
0005434426289	14556	271	49G
0005434877250	14556	272	50C
0005435626021	14556	273	50E
0005434426360	14556	274	50G
0005434877547	14556	275	50F
0005434877259	14556	276	50K
0005434426501	14556	277	51F
0005432799246	14556	278	51E
0005434325664	3595	1	2C
0005434325666	3595	2	3C
0005434312320	3595	3	3D
0005435889835	3595	4	4C
0005434325656	3595	5	4D
0005434325662	3595	6	5A
0005435889862	3595	7	5B
0005434325658	3595	8	5C
0005434325665	3595	9	6C
0005435889863	3595	10	18A
0005434312321	3595	11	19A
0005434325661	3595	12	19C
0005434325659	3595	13	20A
0005434325667	3595	14	20C
0005434325660	3595	15	21A
0005434325663	3595	16	21C
0005435889861	3595	17	22B
0005434325657	3595	18	22C
0005435889868	3595	19	23A
0005434325573	15611	1	1B
0005434325578	15611	2	1C
0005434325597	15611	3	2B
0005435889903	15611	4	3C
0005435889902	15611	5	4C
0005435889905	15611	6	4D
0005434325600	15611	7	5C
0005434325611	15611	8	5D
0005434325485	15611	9	6A
0005434325610	15611	10	6B
0005434325538	15611	11	6C
0005435889901	15611	12	6D
0005434325582	15611	13	7B
0005435889900	15611	14	7D
0005434325484	15611	15	19D
0005435889904	15611	16	20A
0005434325545	15611	17	20B
0005434325483	15611	18	22D
0005435957723	640	1	1B
0005433420351	640	2	1C
0005433420341	640	3	1D
0005435957717	640	4	2B
0005433420332	640	5	2C
0005433420314	640	6	3A
0005435957710	640	7	4A
0005435957719	640	8	4B
0005435957720	640	9	5C
0005435957725	640	10	5D
0005433420333	640	11	6B
0005435957713	640	12	6D
0005435957714	640	13	7A
0005435957712	640	14	7B
0005435957724	640	15	19B
0005433420347	640	16	19C
0005435957715	640	17	19D
0005435957721	640	18	20A
0005435957711	640	19	20B
0005435957718	640	20	20C
0005433420352	640	21	20D
0005435957722	640	22	21C
0005433420331	640	23	22A
0005435957716	640	24	23B
0005433420414	15197	1	1A
0005435957573	15197	2	1D
0005435957594	15197	3	2A
0005433420408	15197	4	2B
0005433420407	15197	5	2D
0005435957519	15197	6	3A
0005435957629	15197	7	4B
0005435957572	15197	8	4D
0005433420410	15197	9	5C
0005435957654	15197	10	6A
0005435957625	15197	11	6B
0005435957656	15197	12	6C
0005435957596	15197	13	6D
0005433420413	15197	14	7C
0005435957621	15197	15	7D
0005435957655	15197	16	19C
0005433420411	15197	17	20A
0005433420412	15197	18	21C
0005435957624	15197	19	21B
0005435957595	15197	20	22C
0005433420409	15197	21	23B
0005435221047	27267	1	1B
0005435216568	27267	2	1C
0005435221042	27267	3	1D
0005435219179	27267	4	2A
0005435216562	27267	5	2B
0005435221041	27267	6	2D
0005435216561	27267	7	3B
0005435219183	27267	8	3D
0005435216571	27267	9	4A
0005435219188	27267	10	4B
0005435221044	27267	11	4C
0005435219182	27267	12	5B
0005435216567	27267	13	7D
0005435216575	27267	14	18A
0005435219178	27267	15	18C
0005435216556	27267	16	19A
0005435221043	27267	17	19B
0005435219175	27267	18	20A
0005435219170	27267	19	20B
0005435221048	27267	20	20C
0005435216557	27267	21	20D
0005435219166	27267	22	21A
0005435216574	27267	23	21C
0005435216563	27267	24	21D
0005435221045	27267	25	22C
0005435221049	27267	26	23B
0005434247130	8897	1	1A
0005434247135	8897	2	1B
0005434247117	8897	3	2A
0005435629403	8897	4	3B
0005434247127	8897	5	4A
0005434247131	8897	6	5A
0005434247123	8897	7	5B
0005435629396	16073	1	3A
0005435163237	4426	1	1B
0005435163238	4426	2	2B
0005435163233	4426	3	2C
0005435933436	4426	4	3B
0005435163236	4426	5	3D
0005435933443	4426	6	4B
0005435163234	4426	7	5B
0005435163240	4426	8	6A
0005435163239	4426	9	6C
0005435933425	4426	10	7C
0005435933424	4426	11	18C
0005435163232	4426	12	19A
0005435933433	4426	13	19C
0005435163235	4426	14	19D
0005435933442	4426	15	20B
0005435933430	4426	16	21B
0005435933435	4426	17	22A
0005435933434	4426	18	22B
0005435163231	4426	19	23B
0005433404759	2878	1	1C
0005433404752	2878	2	1F
0005435797493	2878	3	2C
0005433404756	2878	4	2F
0005433404737	2878	5	4F
0005435797491	2878	6	5A
0005433404751	2878	7	5D
0005433404736	2878	8	5F
0005433404750	2878	9	7D
0005435797484	2878	10	8C
0005433404747	2878	11	8D
0005435797486	2878	12	8F
0005435797490	2878	13	9E
0005433404745	2878	14	10E
0005435797494	2878	15	10F
0005435797488	2878	16	11F
0005433404766	2878	17	12A
0005435797496	2878	18	12E
0005435797492	2878	19	13A
0005435797489	2878	20	13C
0005433404746	2878	21	13F
0005433404757	2878	22	14F
0005435797483	2878	23	16A
0005433404749	2878	24	16F
0005433404744	2878	25	17A
0005433404769	2878	26	17C
0005433404748	2878	27	17F
0005435797495	2878	28	18D
0005433404758	2878	29	19A
0005435797485	2878	30	19C
0005435797487	2878	31	19D
0005435797482	2878	32	20E
0005435797399	29317	1	1F
0005435797397	29317	2	2A
0005435797422	29317	3	3A
0005435797439	29317	4	7D
0005435797377	29317	5	7E
0005435797419	29317	6	7F
0005435797398	29317	7	8C
0005435797438	29317	8	8E
0005435797402	29317	9	10A
0005433404816	29317	10	10D
0005435797323	29317	11	10E
0005435797418	29317	12	11E
0005433404817	29317	13	12A
0005433404814	29317	14	13C
0005433404818	29317	15	14A
0005435797328	29317	16	14F
0005433404815	29317	17	15D
0005433404820	29317	18	17E
0005433404819	29317	19	18D
0005435797432	29317	20	18F
0005435797414	29317	21	19F
0005435376340	5819	1	2A
0005435376327	5819	2	3A
0005435376326	5819	3	4B
0005434948030	5752	1	1A
0005434948027	5752	2	1B
0005434948034	5752	3	2B
0005434948033	5752	4	3B
0005434948028	5752	5	4A
0005434948031	5752	6	5A
0005434948029	5752	7	5B
0005434948032	5752	8	6B
0005434947974	16354	1	1A
0005434947933	16354	2	1B
0005434947943	16354	3	2A
0005434947944	16354	4	2B
0005434947985	16354	5	3A
0005434947977	16354	6	3B
0005434947957	16354	7	4A
0005434947975	16354	8	4B
0005434947984	16354	9	5A
0005434947976	16354	10	5B
0005434947972	16354	11	6A
0005434947973	16354	12	6B
0005433960937	6908	1	1C
0005433960932	6908	2	1D
0005433960933	6908	3	1F
0005433960944	6908	4	2C
0005433960924	6908	5	2F
0005433960948	6908	6	3C
0005433960942	6908	7	4A
0005433960916	6908	8	4D
0005433960939	6908	9	4F
0005433960935	6908	10	5A
0005433960929	6908	11	5D
0005433960920	6908	12	5E
0005433960923	6908	13	6A
0005433960917	6908	14	6C
0005433960967	6908	15	7A
0005433960957	6908	16	7C
0005433960936	6908	17	7E
0005433960913	6908	18	7F
0005433960941	6908	19	8A
0005433960925	6908	20	8D
0005433960960	6908	21	8F
0005433960926	6908	22	9A
0005433960927	6908	23	9D
0005433960959	6908	24	9F
0005433960915	6908	25	10A
0005433960958	6908	26	10C
0005433960954	6908	27	10D
0005433960964	6908	28	10E
0005433960921	6908	29	10F
0005433960922	6908	30	11A
0005433960952	6908	31	11C
0005433960972	6908	32	11E
0005433960961	6908	33	11F
0005433960947	6908	34	12C
0005433960962	6908	35	12D
0005433960971	6908	36	13D
0005433960951	6908	37	14A
0005433960950	6908	38	14D
0005433960953	6908	39	14E
0005433960965	6908	40	14F
0005433960934	6908	41	15D
0005433960931	6908	42	15E
0005433960914	6908	43	15F
0005433960969	6908	44	16A
0005433960943	6908	45	16E
0005433960968	6908	46	16F
0005433960966	6908	47	17A
0005433960938	6908	48	17C
0005433960940	6908	49	17D
0005433960970	6908	50	17E
0005433960963	6908	51	18C
0005433960918	6908	52	18D
0005433960956	6908	53	18E
0005433960955	6908	54	19A
0005433960928	6908	55	19D
0005433960945	6908	56	19E
0005433960946	6908	57	19F
0005433960919	6908	58	20C
0005433960973	6908	59	20D
0005433960930	6908	60	20E
0005433960949	6908	61	20F
0005433960328	25798	1	1C
0005433960078	25798	2	1F
0005433960125	25798	3	2A
0005433960293	25798	4	2C
0005433960288	25798	5	2D
0005433960171	25798	6	2F
0005433960368	25798	7	3A
0005433960342	25798	8	3D
0005433960189	25798	9	3F
0005433960103	25798	10	4A
0005433960287	25798	11	4D
0005433960229	25798	12	4F
0005433960148	25798	13	4E
0005433960040	25798	14	5A
0005433960309	25798	15	5C
0005433960228	25798	16	5E
0005433960370	25798	17	6A
0005433960333	25798	18	6C
0005433960197	25798	19	6D
0005433960299	25798	20	6F
0005433960353	25798	21	7C
0005433960349	25798	22	7D
0005433960374	25798	23	7E
0005433959975	25798	24	7F
0005433960157	25798	25	8A
0005433960253	25798	26	8E
0005433960339	25798	27	8F
0005433960094	25798	28	9C
0005433960109	25798	29	9D
0005433959996	25798	30	9E
0005433960377	25798	31	10A
0005433960252	25798	32	10C
0005433960373	25798	33	10D
0005433960318	25798	34	10F
0005433960325	25798	35	11C
0005433960110	25798	36	11D
0005433960314	25798	37	11F
0005433960039	25798	38	12A
0005433960276	25798	39	12C
0005433960270	25798	40	12D
0005433960378	25798	41	12E
0005433960269	25798	42	12F
0005433960315	25798	43	13A
0005433960336	25798	44	13C
0005433960156	25798	45	13E
0005433960271	25798	46	13F
0005433960079	25798	47	14A
0005433960225	25798	48	14C
0005433960182	25798	49	14D
0005433960367	25798	50	15A
0005433960350	25798	51	15C
0005433960369	25798	52	15E
0005433960155	25798	53	16C
0005433960296	25798	54	16D
0005433960257	25798	55	16E
0005433960291	25798	56	17A
0005433960308	25798	57	17C
0005433959915	25798	58	17D
0005433960004	25798	59	17E
0005433960190	25798	60	18A
0005433960319	25798	61	18C
0005433960300	25798	62	18D
0005433960251	25798	63	18F
0005433960357	25798	64	19A
0005433960329	25798	65	19D
0005433960268	25798	66	19E
0005433960283	25798	67	19F
0005433960292	25798	68	20A
0005433960317	25798	69	20C
0005433960376	25798	70	20D
0005433960254	25798	71	20E
0005435082723	24491	1	1B
0005435082727	24491	2	2B
0005435082738	24491	3	3A
0005435082726	24491	4	3B
0005435082728	24491	5	4A
0005435082716	24491	6	4B
0005435082717	24491	7	5A
0005435082740	24491	8	6A
0005435082724	24491	9	6B
0005435082785	26141	1	2B
0005435082784	26141	2	3B
0005435082786	26141	3	5A
0005435082787	26141	4	5B
0005434245011	5209	1	2C
0005434245010	5209	2	3A
0005434245014	5209	3	3D
0005434245021	5209	4	5C
0005434245022	5209	5	6A
0005432166905	5209	6	7D
0005434245001	5209	7	7C
0005434245019	5209	8	8B
0005434245006	5209	9	8E
0005435286592	5209	10	10F
0005434245017	5209	11	11B
0005434244998	5209	12	12D
0005435286579	5209	13	12F
0005435286595	5209	14	13A
0005434245025	5209	15	13C
0005434245023	5209	16	13E
0005434245005	5209	17	13D
0005435286563	5209	18	14A
0005434245003	5209	19	14B
0005435286589	5209	20	14F
0005434245008	5209	21	15A
0005434245002	5209	22	15D
0005435286583	5209	23	15F
0005434245015	5209	24	15E
0005435286582	5209	25	16B
0005434245007	5209	26	17D
0005435286580	5209	27	18E
0005432166904	5209	28	19C
0005434245018	5209	29	19D
0005434245013	5209	30	19E
0005434244999	5209	31	20F
0005434244997	5209	32	24B
0005434245012	5209	33	24A
0005434245000	5209	34	26C
0005434245016	5209	35	27B
0005434245024	5209	36	27D
0005434245004	5209	37	28F
0005434245020	5209	38	29F
0005434244996	5209	39	29E
0005434244995	5209	40	30C
0005434245009	5209	41	31F
0005433784984	5208	1	1C
0005433614807	5208	2	1A
0005433784983	5208	3	1F
0005433614805	5208	4	1D
0005433784998	5208	5	2A
0005433614776	5208	6	2D
0005432105624	5208	7	2C
0005433784973	5208	8	2F
0005433614757	5208	9	3A
0005433784977	5208	10	3C
0005433614774	5208	11	3D
0005432105613	5208	12	4A
0005432667456	5208	13	3F
0005433614785	5208	14	4D
0005432105596	5208	15	4C
0005433614734	5208	16	5A
0005433784969	5208	17	4F
0005433614780	5208	18	5C
0005432105593	5208	19	5D
0005432105592	5208	20	6A
0005433784996	5208	21	5F
0005432105607	5208	22	6C
0005433784981	5208	23	6F
0005432105612	5208	24	6D
0005432105603	5208	25	7A
0005433784966	5208	26	7D
0005432105605	5208	27	7C
0005433614754	5208	28	7F
0005433614806	5208	29	8A
0005433614758	5208	30	8C
0005432105636	5208	31	8B
0005433614782	5208	32	8E
0005432105639	5208	33	8D
0005433614737	5208	34	9A
0005433784961	5208	35	8F
0005432105615	5208	36	9C
0005433614755	5208	37	9B
0005433784974	5208	38	9D
0005433784989	5208	39	9E
0005433614779	5208	40	10A
0005433784995	5208	41	9F
0005432105629	5208	42	10B
0005433784962	5208	43	10D
0005433784976	5208	44	10C
0005433614793	5208	45	10E
0005432105634	5208	46	10F
0005433614744	5208	47	11A
0005432105625	5208	48	11C
0005433614762	5208	49	11B
0005433614796	5208	50	11D
0005433784994	5208	51	11E
0005433784967	5208	52	12A
0005433784972	5208	53	11F
0005433614804	5208	54	12B
0005433614764	5208	55	12C
0005432105628	5208	56	12E
0005432105622	5208	57	12D
0005433614797	5208	58	12F
0005432145115	5208	59	13A
0005433784982	5208	60	13C
0005433784993	5208	61	13B
0005433784985	5208	62	13D
0005433784960	5208	63	13F
0005433614742	5208	64	13E
0005432105611	5208	65	14A
0005433614783	5208	66	14B
0005433614746	5208	67	14C
0005432105623	5208	68	14E
0005433614740	5208	69	14D
0005433784988	5208	70	14F
0005432145114	5208	71	15A
0005432105602	5208	72	15C
0005432665277	5208	73	15B
0005433784978	5208	74	15E
0005433614765	5208	75	15D
0005433614784	5208	76	15F
0005433614743	5208	77	16A
0005433784990	5208	78	16C
0005433614751	5208	79	16B
0005433614786	5208	80	16E
0005432105600	5208	81	16D
0005432105617	5208	82	16F
0005433614803	5208	83	17A
0005432105604	5208	84	17C
0005433614808	5208	85	17B
0005433614771	5208	86	17E
0005433614790	5208	87	17D
0005432105616	5208	88	18A
0005433784965	5208	89	17F
0005433784992	5208	90	18C
0005433614801	5208	91	18B
0005433784968	5208	92	18D
0005433614768	5208	93	18E
0005432105627	5208	94	18F
0005433614747	5208	95	19B
0005432105619	5208	96	19D
0005433614778	5208	97	19C
0005432105599	5208	98	19E
0005433614798	5208	99	20B
0005433784970	5208	100	20A
0005433784997	5208	101	20C
0005433614736	5208	102	20D
0005432105640	5208	103	20F
0005432105638	5208	104	20E
0005433614735	5208	105	21A
0005433614787	5208	106	21B
0005433784979	5208	107	21D
0005432105630	5208	108	21C
0005432105609	5208	109	21F
0005433614760	5208	110	21E
0005433614794	5208	111	22B
0005433784991	5208	112	22A
0005432665276	5208	113	22C
0005433614799	5208	114	22D
0005433614802	5208	115	22F
0005433614789	5208	116	22E
0005433784980	5208	117	23A
0005433614761	5208	118	23C
0005433614772	5208	119	23B
0005433614756	5208	120	23D
0005432105595	5208	121	23E
0005432105635	5208	122	24A
0005433614739	5208	123	23F
0005433614741	5208	124	24B
0005432666391	5208	125	24C
0005433614792	5208	126	24E
0005432105610	5208	127	24D
0005432105620	5208	128	24F
0005433784971	5208	129	25A
0005433614759	5208	130	25B
0005433614800	5208	131	25E
0005433614777	5208	132	25D
0005432105597	5208	133	25C
0005433614773	5208	134	25F
0005433614749	5208	135	26B
0005433614763	5208	136	26A
0005433614795	5208	137	26C
0005432105606	5208	138	26E
0005432105618	5208	139	26D
0005433614767	5208	140	26F
0005432105637	5208	141	27A
0005432105601	5208	142	27C
0005433614766	5208	143	27B
0005433614750	5208	144	27D
0005433614753	5208	145	27F
0005433614738	5208	146	27E
0005432105614	5208	147	28A
0005432105633	5208	148	28B
0005433784964	5208	149	28C
0005433614770	5208	150	28E
0005433784986	5208	151	28D
0005432105608	5208	152	29A
0005433784963	5208	153	29B
0005432105631	5208	154	29C
0005433614752	5208	155	29D
0005433614775	5208	156	29F
0005432105598	5208	157	29E
0005433614745	5208	158	30A
0005432105626	5208	159	30B
0005432105621	5208	160	30C
0005433614769	5208	161	30E
0005433614791	5208	162	30D
0005432105632	5208	163	30F
0005433784975	5208	164	31B
0005433614781	5208	165	31A
0005433614748	5208	166	31C
0005433784987	5208	167	31E
0005432105594	5208	168	31D
0005433614788	5208	169	31F
0005434229402	5203	1	1C
0005434229388	5203	2	1D
0005434265162	5203	3	2A
0005435006867	5203	4	1F
0005434229387	5203	5	2C
0005434149740	5203	6	3A
0005434173523	5203	7	2F
0005434229395	5203	8	3C
0005432335962	5203	9	3D
0005435006775	5203	10	4A
0005435006822	5203	11	3F
0005434229404	5203	12	4C
0005434265158	5203	13	5A
0005435006795	5203	14	4F
0005433685505	5203	15	5C
0005434229384	5203	16	6A
0005434149745	5203	17	6C
0005434229397	5203	18	6D
0005435006880	5203	19	7F
0005434265157	5203	20	8B
0005434229401	5203	21	8E
0005432335954	5203	22	9A
0005433815356	5203	23	9B
0005434265164	5203	24	9D
0005434173524	5203	25	9F
0005434265151	5203	26	9E
0005432335980	5203	27	10B
0005435269674	5203	28	10C
0005434149741	5203	29	10E
0005435006851	5203	30	10D
0005435269675	5203	31	11B
0005434265178	5203	32	11A
0005434229389	5203	33	11C
0005435006837	5203	34	11D
0005435269686	5203	35	11F
0005433688785	5203	36	12A
0005434229405	5203	37	12B
0005434149746	5203	38	12E
0005434149747	5203	39	12F
0005434229391	5203	40	13A
0005435006849	5203	41	13C
0005434149744	5203	42	13D
0005435269691	5203	43	14A
0005434265161	5203	44	13F
0005434265153	5203	45	14C
0005434149742	5203	46	14B
0005434265173	5203	47	14E
0005434229383	5203	48	15B
0005434229398	5203	49	15A
0005432335925	5203	50	15C
0005434265176	5203	51	15E
0005435006808	5203	52	16A
0005433685520	5203	53	16B
0005432335982	5203	54	16C
0005434229403	5203	55	16D
0005434229393	5203	56	16F
0005434229386	5203	57	17B
0005434149738	5203	58	17A
0005434265169	5203	59	17C
0005435269668	5203	60	17E
0005434173522	5203	61	17D
0005435006767	5203	62	18A
0005433815354	5203	63	17F
0005435006836	5203	64	18C
0005435006755	5203	65	18E
0005434265168	5203	66	18D
0005434229385	5203	67	18F
0005432335981	5203	68	19C
0005434265152	5203	69	19B
0005433688797	5203	70	19D
0005434265167	5203	71	19E
0005435006854	5203	72	20B
0005435006796	5203	73	20A
0005434149739	5203	74	20C
0005432335859	5203	75	20E
0005435006856	5203	76	20D
0005432335858	5203	77	21A
0005434265166	5203	78	21C
0005435006949	5203	79	21B
0005434229400	5203	80	21D
0005434149748	5203	81	21F
0005434229392	5203	82	22A
0005434265170	5203	83	22D
0005434229399	5203	84	22C
0005434229396	5203	85	22F
0005434265163	5203	86	23C
0005433685506	5203	87	23B
0005433815338	5203	88	23D
0005435006857	5203	89	24A
0005435269667	5203	90	23F
0005434229390	5203	91	24B
0005432335963	5203	92	24D
0005434265165	5203	93	24E
0005435006850	5203	94	24F
0005434149743	5203	95	25A
0005434173525	5203	96	25B
0005434229394	5203	97	25D
0005435006768	5203	98	26A
0005435006948	5203	99	25F
0005435269679	5203	100	26B
0005434265155	5203	101	26E
0005434265159	5203	102	26D
0005435006778	5203	103	27A
0005435006855	5203	104	27B
0005434312297	5203	105	27D
0005434265160	5203	106	27C
0005434265175	5203	107	27F
0005435006777	5203	108	27E
0005434265177	5203	109	28A
0005433815325	5203	110	28D
0005435269676	5203	111	28C
0005435269685	5203	112	29A
0005434265154	5203	113	28F
0005432335920	5203	114	29B
0005435006826	5203	115	29C
0005434265156	5203	116	29D
0005434265172	5203	117	29E
0005432335983	5203	118	30A
0005433688790	5203	119	29F
0005433815347	5203	120	30C
0005434149737	5203	121	30D
0005435006809	5203	122	31B
0005434265171	5203	123	31E
0005434265174	5203	124	31F
0005433784670	8485	1	3C
0005435269749	8485	2	4A
0005432659700	8485	3	3F
0005433784623	8485	4	5A
0005433784610	8485	5	5D
0005433784585	8485	6	6D
0005434244840	8485	7	6C
0005434244873	8485	8	8A
0005433784810	8485	9	8D
0005433784540	8485	10	8E
0005434244715	8485	11	9A
0005432663022	8485	12	10A
0005433784627	8485	13	10C
0005433784599	8485	14	10D
0005434244728	8485	15	10F
0005434244745	8485	16	11A
0005434244734	8485	17	11C
0005433784521	8485	18	11D
0005433784741	8485	19	12A
0005434244794	8485	20	12D
0005434244802	8485	21	13B
0005434244793	8485	22	14C
0005433784743	8485	23	14D
0005434244874	8485	24	15A
0005433784669	8485	25	15C
0005433784763	8485	26	15F
0005434244926	8485	27	16D
0005434244746	8485	28	16E
0005434244729	8485	29	17D
0005434244910	8485	30	18A
0005433784586	8485	31	18D
0005434244714	8485	32	18C
0005432666376	8485	33	19C
0005433784527	8485	34	19D
0005432663021	8485	35	21E
0005434244843	8485	36	22A
0005434244801	8485	37	22D
0005433784668	8485	38	22C
0005432663020	8485	39	23E
0005433784602	8485	40	23F
0005435269750	8485	41	24B
0005433784709	8485	42	24C
0005434244698	8485	43	24E
0005433784687	8485	44	25D
0005434244846	8485	45	25E
0005433784522	8485	46	26A
0005433784612	8485	47	26B
0005433784764	8485	48	26F
0005432663024	8485	49	27A
0005433784523	8485	50	27E
0005434244841	8485	51	27D
0005433784742	8485	52	28E
0005433784603	8485	53	29A
0005433784611	8485	54	29B
0005432663017	8485	55	29D
0005434244685	8485	56	29E
0005433784597	8485	57	30B
0005433784596	8485	58	30C
0005434244754	8485	59	31A
0005434244825	8485	60	31C
0005434244927	8485	61	31D
0005433613816	8486	1	1A
0005433613996	8486	2	2F
0005433614084	8486	3	3F
0005433614298	8486	4	4A
0005433614279	8486	5	4F
0005433614187	8486	6	5D
0005433614093	8486	7	6F
0005433613765	8486	8	7A
0005433613814	8486	9	8C
0005433613564	8486	10	9B
0005433614085	8486	11	9A
0005433614208	8486	12	9D
0005433614188	8486	13	9C
0005433613990	8486	14	9E
0005433614038	8486	15	10C
0005433613848	8486	16	11A
0005433614260	8486	17	11B
0005433614182	8486	18	11F
0005433613871	8486	19	12C
0005433613815	8486	20	12E
0005433614022	8486	21	12F
0005433613565	8486	22	13A
0005433613563	8486	23	13D
0005433614086	8486	24	14D
0005433614228	8486	25	14C
0005433614416	8486	26	14F
0005433614233	8486	27	15B
0005433613941	8486	28	15D
0005433614181	8486	29	16B
0005433614130	8486	30	17D
0005433614046	8486	31	17E
0005433614297	8486	32	18F
0005433613961	8486	33	19D
0005433614159	8486	34	19E
0005433614127	8486	35	20C
0005433613698	8486	36	20D
0005433614002	8486	37	20F
0005433614076	8486	38	21A
0005433614207	8486	39	21B
0005433613832	8486	40	22A
0005433613921	8486	41	22B
0005433614234	8486	42	23B
0005433614064	8486	43	23D
0005433614499	8486	44	23E
0005433613804	8486	45	24B
0005433613896	8486	46	25C
0005433613942	8486	47	25B
0005433613972	8486	48	26A
0005433613964	8486	49	26E
0005433613991	8486	50	27B
0005433614006	8486	51	27A
0005433614125	8486	52	27C
0005433614094	8486	53	27D
0005433613994	8486	54	28F
0005433614316	8486	55	30B
0005433614116	8486	56	30A
0005433614347	8486	57	31D
0005433613895	8486	58	31F
0005434264947	8487	1	1A
0005433815391	8487	2	1C
0005433815389	8487	3	1F
0005434265065	8487	4	1D
0005434229175	8487	5	2A
0005432047555	8487	6	2C
0005434149616	8487	7	2D
0005432047553	8487	8	3A
0005435007052	8487	9	2F
0005434149637	8487	10	3C
0005433815393	8487	11	3F
0005435007053	8487	12	3D
0005435007066	8487	13	4A
0005434173485	8487	14	4C
0005434229246	8487	15	5A
0005432034967	8487	16	4F
0005434264959	8487	17	5C
0005434229245	8487	18	5F
0005435007057	8487	19	5D
0005432034988	8487	20	6A
0005434229251	8487	21	6C
0005434264945	8487	22	6F
0005433690929	8487	23	6D
0005435286628	8487	24	7A
0005433689913	8487	25	7D
0005434264897	8487	26	7C
0005434264946	8487	27	7F
0005435007068	8487	28	8A
0005434264781	8487	29	8C
0005435007047	8487	30	8B
0005433815394	8487	31	8D
0005434229194	8487	32	9B
0005435286631	8487	33	9A
0005434229177	8487	34	9C
0005434264981	8487	35	9D
0005432034982	8487	36	9E
0005432034971	8487	37	10A
0005432336043	8487	38	9F
0005432034977	8487	39	10B
0005435007046	8487	40	10C
0005434264910	8487	41	10E
0005433689914	8487	42	10D
0005433688812	8487	43	11A
0005435007050	8487	44	10F
0005434229252	8487	45	11B
0005434229133	8487	46	11E
0005435007059	8487	47	11D
0005434229168	8487	48	12A
0005432336045	8487	49	12D
0005434229134	8487	50	12C
0005435286634	8487	51	12E
0005435007048	8487	52	12F
0005435286629	8487	53	13A
0005432034980	8487	54	13C
0005434229154	8487	55	13B
0005433815395	8487	56	13D
0005432034984	8487	57	13F
0005435007069	8487	58	13E
0005434149655	8487	59	14A
0005434264948	8487	60	14B
0005432034979	8487	61	14D
0005435007064	8487	62	14C
0005434229163	8487	63	14E
0005434149654	8487	64	14F
0005434149628	8487	65	15A
0005434265063	8487	66	15C
0005434149666	8487	67	15B
0005433534501	8487	68	15D
0005432047554	8487	69	15F
0005434173476	8487	70	15E
0005432047552	8487	71	16A
0005435286632	8487	72	16B
0005434229124	8487	73	16C
0005432034969	8487	74	16D
0005432034986	8487	75	16F
0005434265064	8487	76	17B
0005432034963	8487	77	17A
0005435007063	8487	78	17C
0005432034974	8487	79	17D
0005433534500	8487	80	17E
0005434229126	8487	81	17F
0005435286633	8487	82	18C
0005435007061	8487	83	18B
0005432336052	8487	84	18D
0005434229176	8487	85	18E
0005434149667	8487	86	18F
0005435007056	8487	87	19C
0005435007054	8487	88	19B
0005434265090	8487	89	20A
0005433815390	8487	90	20B
0005435007049	8487	91	20C
0005435007067	8487	92	20F
0005432336051	8487	93	20E
0005432034987	8487	94	21A
0005434173477	8487	95	21C
0005434149636	8487	96	21B
0005435286630	8487	97	21D
0005432336049	8487	98	21F
0005432336042	8487	99	21E
0005432034989	8487	100	22A
0005432034975	8487	101	22B
0005432336044	8487	102	22D
0005434229227	8487	103	22C
0005435007065	8487	104	22E
0005434264990	8487	105	22F
0005434229158	8487	106	23A
0005432034966	8487	107	23C
0005435007045	8487	108	23B
0005432034978	8487	109	23D
0005433688811	8487	110	23E
0005434229164	8487	111	24B
0005434229214	8487	112	24D
0005434229244	8487	113	24C
0005432034972	8487	114	24F
0005434265011	8487	115	25A
0005434264835	8487	116	25C
0005432336047	8487	117	25B
0005432034973	8487	118	25D
0005435007058	8487	119	25E
0005432034983	8487	120	26A
0005434264864	8487	121	25F
0005432034964	8487	122	26C
0005432336041	8487	123	26D
0005434229258	8487	124	26F
0005435007044	8487	125	27B
0005435007062	8487	126	27D
0005433689912	8487	127	27C
0005434311222	8487	128	27F
0005434264964	8487	129	27E
0005432034976	8487	130	28A
0005434311221	8487	131	28B
0005434264991	8487	132	28C
0005433815392	8487	133	28E
0005434264909	8487	134	28F
0005435007070	8487	135	29A
0005434229228	8487	136	29C
0005432336050	8487	137	29B
0005434229265	8487	138	29D
0005435007060	8487	139	29F
0005433690930	8487	140	29E
0005432034968	8487	141	30B
0005432034965	8487	142	30A
0005432034985	8487	143	30C
0005434229211	8487	144	30E
0005432034970	8487	145	30D
0005432336048	8487	146	30F
0005432034981	8487	147	31B
0005435007051	8487	148	31A
0005434149634	8487	149	31C
0005432336046	8487	150	31D
0005432034990	8487	151	31F
0005435007055	8487	152	31E
0005434639053	12628	1	1A
0005433202380	12628	2	1B
0005434639121	12628	3	1C
0005434639285	12628	4	2A
0005433202374	12628	5	2B
0005434639284	12628	6	2C
0005434639176	12628	7	2D
0005434639147	12628	8	3B
0005434639058	12628	9	3C
0005433202384	12628	10	3D
0005434639197	12628	11	4B
0005433202378	12628	12	4C
0005434638969	12628	13	4D
0005433202377	12628	14	5A
0005434639180	12628	15	5B
0005434639054	12628	16	5C
0005434639179	12628	17	5D
0005434639140	12628	18	6B
0005433202382	12628	19	6C
0005433202386	12628	20	6D
0005433202383	12628	21	7A
0005434639208	12628	22	7B
0005434639212	12628	23	7C
0005433202387	12628	24	7D
0005433202376	12628	25	18A
0005434639124	12628	26	18B
0005434639051	12628	27	18C
0005433202381	12628	28	18D
0005433202379	12628	29	19A
0005434639129	12628	30	19B
0005434639195	12628	31	19D
0005433202388	12628	32	20A
0005434639139	12628	33	20B
0005434639070	12628	34	20C
0005434639093	12628	35	20D
0005434639207	12628	36	21A
0005434639181	12628	37	21B
0005434639142	12628	38	21D
0005433202385	12628	39	22A
0005434639094	12628	40	22B
0005433202375	12628	41	22D
0005434639090	12628	42	23A
0005433202184	23388	1	1A
0005434639316	23388	2	1C
0005434639317	23388	3	1D
0005434639327	23388	4	2C
0005432290634	23388	5	2D
0005433202228	23388	6	3B
0005434639335	23388	7	3C
0005434639329	23388	8	3D
0005434639314	23388	9	4A
0005434639323	23388	10	4B
0005434639318	23388	11	4C
0005434639338	23388	12	4D
0005434639333	23388	13	5A
0005434639336	23388	14	5B
0005434639331	23388	15	6B
0005434639315	23388	16	6C
0005434639330	23388	17	6D
0005433202241	23388	18	7A
0005434639324	23388	19	7B
0005434639337	23388	20	7C
0005434639325	23388	21	7D
0005433202185	23388	22	18A
0005434639310	23388	23	18B
0005434639322	23388	24	18D
0005432290633	23388	25	19A
0005434639312	23388	26	19C
0005434639326	23388	27	19D
0005433202231	23388	28	20A
0005434639320	23388	29	20B
0005434639311	23388	30	20D
0005433202282	23388	31	21A
0005433202198	23388	32	21B
0005434639334	23388	33	21C
0005434639332	23388	34	21D
0005434639321	23388	35	22A
0005433202232	23388	36	22B
0005434639319	23388	37	22C
0005434639313	23388	38	22D
0005433202230	23388	39	23A
0005434639328	23388	40	23B
0005432382725	21079	1	1A
0005432328265	21079	2	1D
0005432328273	21079	3	1F
0005432328392	21079	4	2A
0005432382728	21079	5	2D
0005432328256	21079	6	2F
0005432328276	21079	7	3A
0005432382796	21079	8	3C
0005432328307	21079	9	3D
0005432382843	21079	10	3F
0005432328161	21079	11	4A
0005432382808	21079	12	4C
0005432382842	21079	13	4D
0005432054308	21079	14	4E
0005432328462	21079	15	4F
0005432328425	21079	16	5A
0005432382754	21079	17	5C
0005432382923	21079	18	5D
0005432382849	21079	19	5F
0005432382724	21079	20	6A
0005432382850	21079	21	6C
0005432328532	21079	22	7A
0005432328364	21079	23	6F
0005432328185	21079	24	7C
0005432328231	21079	25	7D
0005432328546	21079	26	7E
0005432382823	21079	27	7F
0005432328365	21079	28	8A
0005432328324	21079	29	8C
0005432382582	21079	30	8E
0005432328390	21079	31	9A
0005432328090	21079	32	9C
0005432328089	21079	33	9D
0005432382822	21079	34	9E
0005432328251	21079	35	10A
0005432382729	21079	36	10C
0005432382941	21079	37	10D
0005432382893	21079	38	10F
0005432382821	21079	39	11A
0005432382924	21079	40	11D
0005432328184	21079	41	11F
0005432328487	21079	42	12A
0005432382807	21079	43	12C
0005432382891	21079	44	12D
0005432382858	21079	45	12E
0005432328217	21079	46	12F
0005432328486	21079	47	13C
0005432328354	21079	48	13D
0005432328399	21079	49	13E
0005432328355	21079	50	13F
0005432328426	21079	51	14A
0005432383011	21079	52	14C
0005432382809	21079	53	14D
0005432382999	21079	54	14E
0005432382854	21079	55	15A
0005432382939	21079	56	15C
0005432328405	21079	57	15D
0005432328412	21079	58	16A
0005432054306	21079	59	16C
0005432382775	21079	60	16D
0005432328325	21079	61	16E
0005432382894	21079	62	17C
0005432328287	21079	63	17D
0005432328483	21079	64	17E
0005432382834	21079	65	17F
0005432382583	21079	66	18A
0005432382966	21079	67	18C
0005432328088	21079	68	18E
0005432328346	21079	69	18F
0005432328230	21079	70	19A
0005432382927	21079	71	19C
0005432328338	21079	72	19D
0005432382864	21079	73	19E
0005432382853	21079	74	19F
0005432328393	21079	75	20A
0005432328190	21079	76	20D
0005432054307	21079	77	20E
0005432382866	21079	78	20F
0005432328711	31262	1	1A
0005432383180	31262	2	1C
0005432383167	31262	3	1D
0005432328700	31262	4	1F
0005432328734	31262	5	2A
0005432383178	31262	6	2C
0005432328718	31262	7	2D
0005432328716	31262	8	2F
0005432328696	31262	9	3A
0005432328689	31262	10	3C
0005432328719	31262	11	4A
0005432328722	31262	12	4C
0005432328691	31262	13	4D
0005432383184	31262	14	4E
0005432328736	31262	15	4F
0005432383171	31262	16	5A
0005432287188	31262	17	5C
0005432383174	31262	18	5D
0005432383176	31262	19	5F
0005432328701	31262	20	6A
0005432383197	31262	21	6C
0005432383175	31262	22	6D
0005432287192	31262	23	6E
0005432328720	31262	24	7A
0005432328723	31262	25	7C
0005432328699	31262	26	7D
0005432383168	31262	27	7E
0005432287189	31262	28	7F
0005432328721	31262	29	8A
0005432383189	31262	30	8C
0005432287191	31262	31	8D
0005432383183	31262	32	8E
0005432328731	31262	33	8F
0005432383177	31262	34	9A
0005432328690	31262	35	9C
0005432328729	31262	36	9D
0005432328733	31262	37	9E
0005432328730	31262	38	9F
0005432383199	31262	39	10A
0005432383192	31262	40	10C
0005432328715	31262	41	10D
0005432328710	31262	42	10E
0005432328727	31262	43	10F
0005432383195	31262	44	11A
0005432383185	31262	45	11C
0005432328702	31262	46	11D
0005432383169	31262	47	11E
0005432383194	31262	48	11F
0005432328728	31262	49	12A
0005432328703	31262	50	12D
0005432328706	31262	51	12C
0005432328697	31262	52	12E
0005432383193	31262	53	12F
0005432328704	31262	54	13A
0005432383198	31262	55	13C
0005432328726	31262	56	13D
0005432328714	31262	57	13E
0005432383196	31262	58	13F
0005432383182	31262	59	14C
0005432328694	31262	60	14E
0005432328708	31262	61	15A
0005432328693	31262	62	15C
0005432383181	31262	63	15D
0005432383200	31262	64	15E
0005432328713	31262	65	15F
0005432328709	31262	66	16A
0005432383170	31262	67	16C
0005432328698	31262	68	16D
0005432383190	31262	69	16E
0005432328735	31262	70	16F
0005432383172	31262	71	17C
0005432287190	31262	72	17A
0005432383173	31262	73	17D
0005432328725	31262	74	17E
0005432328695	31262	75	17F
0005432328732	31262	76	18A
0005432328707	31262	77	18D
0005432383186	31262	78	18E
0005432383201	31262	79	18F
0005432328692	31262	80	19A
0005432328705	31262	81	19C
0005432383187	31262	82	19E
0005432383191	31262	83	19D
0005432328712	31262	84	19F
0005432383179	31262	85	20A
0005432328724	31262	86	20D
0005432383188	31262	87	20E
0005432328717	31262	88	20F
0005433642360	2490	1	1D
0005433642344	2490	2	3C
0005433642341	2490	3	3D
0005433642357	2490	4	4A
0005432953875	2490	5	4C
0005432953873	2490	6	4F
0005433642336	2490	7	5C
0005433642366	2490	8	6A
0005433642340	2490	9	6C
0005432953876	2490	10	6D
0005433642347	2490	11	6E
0005432953837	2490	12	7A
0005432953854	2490	13	7C
0005432953861	2490	14	7E
0005432953833	2490	15	7F
0005433642358	2490	16	8C
0005433642339	2490	17	8D
0005432953871	2490	18	8F
0005432953874	2490	19	9C
0005432953860	2490	20	9D
0005432953883	2490	21	10C
0005433642345	2490	22	10F
0005433642354	2490	23	11A
0005433642343	2490	24	11C
0005433642337	2490	25	11F
0005433642355	2490	26	12C
0005433642351	2490	27	12F
0005433642359	2490	28	13D
0005433642335	2490	29	13E
0005432953872	2490	30	13F
0005433642356	2490	31	14A
0005433642361	2490	32	14C
0005433642365	2490	33	15C
0005433642352	2490	34	15E
0005433642362	2490	35	15F
0005433642353	2490	36	16A
0005432953859	2490	37	16C
0005433642349	2490	38	16D
0005433642350	2490	39	16F
0005433642338	2490	40	17F
0005433642346	2490	41	18C
0005432953870	2490	42	18E
0005433642364	2490	43	18F
0005433642342	2490	44	19E
0005432953858	2490	45	20A
0005433642348	2490	46	20C
0005433642363	2490	47	20E
0005433642245	27583	1	1C
0005433642242	27583	2	2F
0005433642180	27583	3	3C
0005432953936	27583	4	3D
0005433642158	27583	5	3F
0005432953943	27583	6	4A
0005432953950	27583	7	4D
0005433642257	27583	8	4E
0005433642165	27583	9	4F
0005433642241	27583	10	5A
0005433642246	27583	11	5C
0005432953935	27583	12	5D
0005432953944	27583	13	5E
0005432953942	27583	14	6C
0005433642285	27583	15	6D
0005432953938	27583	16	7C
0005432953939	27583	17	7D
0005432953940	27583	18	7F
0005433642223	27583	19	8D
0005433642160	27583	20	8E
0005433642244	27583	21	8F
0005433642248	27583	22	9C
0005433642256	27583	23	10D
0005433642205	27583	24	10E
0005433642250	27583	25	11C
0005433642217	27583	26	13C
0005433642239	27583	27	13A
0005433642243	27583	28	13E
0005432953948	27583	29	14A
0005433642200	27583	30	14D
0005433642240	27583	31	14F
0005433642181	27583	32	15C
0005432953945	27583	33	15E
0005432953947	27583	34	16C
0005433642204	27583	35	16F
0005432953937	27583	36	17A
0005432953941	27583	37	17D
0005433642247	27583	38	18A
0005432953946	27583	39	18D
0005432953949	27583	40	19D
0005433642284	27583	41	20C
0005433642157	27583	42	20D
0005432953934	27583	43	20F
0005432424462	13274	1	1D
0005432424433	13274	2	2A
0005432424449	13274	3	2D
0005432424445	13274	4	3F
0005432424431	13274	5	4A
0005432424425	13274	6	4C
0005432424450	13274	7	4D
0005432424435	13274	8	6A
0005432424452	13274	9	7A
0005432424454	13274	10	7E
0005432424437	13274	11	8A
0005432424457	13274	12	8C
0005432424458	13274	13	9C
0005432424423	13274	14	9D
0005432424456	13274	15	10C
0005432424455	13274	16	10D
0005432424453	13274	17	10F
0005432424439	13274	18	11A
0005432424438	13274	19	11E
0005432424432	13274	20	12D
0005432424428	13274	21	13C
0005432424436	13274	22	14D
0005432424461	13274	23	14F
0005432424448	13274	24	15A
0005432424434	13274	25	15C
0005432424447	13274	26	16A
0005432424446	13274	27	16E
0005432424460	13274	28	16F
0005432424440	13274	29	17A
0005432424429	13274	30	17C
0005432424424	13274	31	17D
0005432424427	13274	32	17E
0005432424444	13274	33	17F
0005432424430	13274	34	18C
0005432424443	13274	35	18D
0005432424422	13274	36	18E
0005432424451	13274	37	18F
0005432424441	13274	38	20A
0005432424442	13274	39	20C
0005432424459	13274	40	20D
0005432424426	13274	41	20E
0005432423933	30792	1	1A
0005432423979	30792	2	1C
0005432424027	30792	3	1F
0005432423934	30792	4	2D
0005432423919	30792	5	2F
0005432424060	30792	6	3F
0005432424048	30792	7	4A
0005432424004	30792	8	4F
0005432424059	30792	9	5A
0005432424038	30792	10	5C
0005432423855	30792	11	6A
0005432424057	30792	12	6C
0005432423991	30792	13	6E
0005432423993	30792	14	7A
0005432424049	30792	15	7C
0005432424090	30792	16	7D
0005432423865	30792	17	7E
0005432423942	30792	18	7F
0005432423992	30792	19	8C
0005432424096	30792	20	8D
0005432423866	30792	21	9C
0005432423920	30792	22	9D
0005432424056	30792	23	9F
0005432423985	30792	24	10F
0005432423975	30792	25	11F
0005432423974	30792	26	12A
0005432424021	30792	27	12C
0005432423960	30792	28	12D
0005432424089	30792	29	13E
0005432423873	30792	30	14A
0005432424091	30792	31	14C
0005432424000	30792	32	14D
0005432423939	30792	33	14E
0005432423986	30792	34	15D
0005432424066	30792	35	16C
0005432423995	30792	36	16D
0005432424058	30792	37	16E
0005432423846	30792	38	16F
0005432424050	30792	39	17A
0005432423874	30792	40	18A
0005432424093	30792	41	19A
0005432424092	30792	42	19D
0005432424028	30792	43	19E
0005432423996	30792	44	20C
0005432424012	30792	45	20D
0005432423932	30792	46	20E
0005434448317	9583	1	1A
0005434157412	9583	2	1D
0005432822207	9583	3	1F
0005432817504	9583	4	2A
0005434157408	9583	5	2C
0005434186179	9583	6	2D
0005434448318	9583	7	2F
0005434157379	9583	8	3A
0005432901466	9583	9	3C
0005432822212	9583	10	3F
0005432817500	9583	11	4A
0005434157415	9583	12	4C
0005432817502	9583	13	4D
0005432901444	9583	14	4E
0005432817495	9583	15	5C
0005432901474	9583	16	5D
0005432901465	9583	17	5E
0005432901460	9583	18	5F
0005432817503	9583	19	6C
0005432822211	9583	20	6D
0005434448320	9583	21	6E
0005434157437	9583	22	6F
0005434186172	9583	23	7A
0005432901469	9583	24	7F
0005432817505	9583	25	8A
0005432817515	9583	26	8D
0005432817499	9583	27	8F
0005432817513	9583	28	9A
0005432817494	9583	29	9C
0005432822210	9583	30	9D
0005432817497	9583	31	9E
0005432817484	9583	32	9F
0005432288991	9583	33	10C
0005432817512	9583	34	10D
0005434157393	9583	35	10E
0005432817509	9583	36	10F
0005432817488	9583	37	11A
0005432817487	9583	38	11C
0005432822209	9583	39	11D
0005432817501	9583	40	11F
0005432817498	9583	41	12A
0005432817508	9583	42	13A
0005432817506	9583	43	13C
0005432817490	9583	44	13D
0005434157429	9583	45	13E
0005432817514	9583	46	13F
0005432901470	9583	47	14A
0005432817493	9583	48	14C
0005432817489	9583	49	14D
0005432817492	9583	50	14E
0005432822214	9583	51	15A
0005432901504	9583	52	15C
0005432822213	9583	53	15D
0005432822208	9583	54	15E
0005432817507	9583	55	15F
0005432817510	9583	56	16A
0005432817491	9583	57	16C
0005432901426	9583	58	16F
0005432817496	9583	59	17A
0005434157394	9583	60	17C
0005432817485	9583	61	17D
0005434157428	9583	62	17E
0005434157472	9583	63	18A
0005432817486	9583	64	18C
0005432288989	9583	65	18E
0005432901454	9583	66	19C
0005432288990	9583	67	19F
0005434448319	9583	68	20A
0005432817511	9583	69	20D
0005434157447	9583	70	20E
0005432288988	9583	71	20F
0005432817126	28966	1	1A
0005432822139	28966	2	1C
0005434157488	28966	3	1D
0005432822152	28966	4	1F
0005434157490	28966	5	2A
0005432817430	28966	6	2C
0005432822149	28966	7	2F
0005432901628	28966	8	3A
0005434448284	28966	9	3C
0005434186200	28966	10	3D
0005432901629	28966	11	3F
0005432817156	28966	12	4A
0005432817149	28966	13	4D
0005434186199	28966	14	4E
0005432817144	28966	15	4F
0005432817142	28966	16	5A
0005432817147	28966	17	5C
0005434448279	28966	18	5D
0005432901630	28966	19	5F
0005432901633	28966	20	6C
0005432901618	28966	21	6D
0005432817291	28966	22	6F
0005432901627	28966	23	7A
0005432817157	28966	24	7C
0005432817276	28966	25	7D
0005432817282	28966	26	7E
0005432817214	28966	27	7F
0005432817290	28966	28	8A
0005432901625	28966	29	8C
0005432817180	28966	30	8D
0005432817247	28966	31	8E
0005432817323	28966	32	8F
0005432817143	28966	33	9C
0005432822145	28966	34	9D
0005432901617	28966	35	9E
0005432817251	28966	36	9F
0005432817196	28966	37	10C
0005432901626	28966	38	10D
0005434157484	28966	39	10E
0005434186198	28966	40	10F
0005434157486	28966	41	11C
0005432822151	28966	42	11D
0005432901620	28966	43	11F
0005432822126	28966	44	11E
0005432822137	28966	45	12A
0005432901632	28966	46	12D
0005432817242	28966	47	12E
0005432817296	28966	48	12F
0005434157487	28966	49	13A
0005432817145	28966	50	13C
0005432817230	28966	51	13D
0005432817250	28966	52	13E
0005432817324	28966	53	13F
0005432901631	28966	54	14A
0005432901622	28966	55	14C
0005432817330	28966	56	14D
0005432817231	28966	57	14F
0005432901624	28966	58	15C
0005432817193	28966	59	15D
0005432817213	28966	60	15E
0005432822144	28966	61	15F
0005432817148	28966	62	16A
0005432822125	28966	63	16C
0005434157485	28966	64	17C
0005432817127	28966	65	17E
0005432901634	28966	66	18A
0005432822172	28966	67	18C
0005432817125	28966	68	18D
0005432901623	28966	69	18E
0005432901621	28966	70	18F
0005432822138	28966	71	19A
0005432817155	28966	72	19C
0005432822124	28966	73	19D
0005434157489	28966	74	19E
0005434448268	28966	75	19F
0005432817195	28966	76	20A
0005432901619	28966	77	20C
0005432817269	28966	78	20D
0005432817215	28966	79	20E
0005432817181	28966	80	20F
0005432611715	15044	1	1A
0005435841814	15044	2	1B
0005432613867	15044	3	2A
0005432611713	15044	4	3A
0005432613866	15044	5	4A
0005432611714	15044	6	5A
0005432611716	15044	7	6A
0005432613865	15044	8	6B
0005432607513	31635	1	1A
0005432607524	31635	2	1B
0005432611664	31635	3	2B
0005432607535	31635	4	2A
0005432607550	31635	5	3B
0005432611679	31635	6	3A
0005432607532	31635	7	4A
0005432611661	31635	8	4B
0005432607514	31635	9	5A
0005432611680	31635	10	5B
0005432607523	31635	11	6A
0005432611662	31635	12	6B
0005433569105	11837	1	1C
0005432948103	11837	2	1A
0005433569096	11837	3	1F
0005433569051	11837	4	2C
0005433569118	11837	5	2A
0005432948186	11837	6	2D
0005432948089	11837	7	3A
0005432948027	11837	8	2F
0005433569087	11837	9	3C
0005433569065	11837	10	4A
0005433569090	11837	11	3F
0005433569120	11837	12	4C
0005432948188	11837	13	4F
0005432948028	11837	14	4D
0005433569059	11837	15	5D
0005433569101	11837	16	5C
0005432948272	11837	17	6B
0005433569121	11837	18	6A
0005433569104	11837	19	6D
0005433569116	11837	20	6C
0005433569061	11837	21	6E
0005433569109	11837	22	7A
0005433569093	11837	23	6F
0005433569081	11837	24	7C
0005433569085	11837	25	7B
0005433569113	11837	26	8A
0005433569064	11837	27	7F
0005432948128	11837	28	7E
0005433569057	11837	29	8C
0005432948069	11837	30	8B
0005432948007	11837	31	8D
0005433569123	11837	32	8F
0005433569074	11837	33	8E
0005433569056	11837	34	9B
0005433569122	11837	35	9A
0005432948096	11837	36	9C
0005433569102	11837	37	9E
0005432948052	11837	38	10A
0005433569084	11837	39	9F
0005433569077	11837	40	10B
0005433569067	11837	41	10E
0005432948094	11837	42	10D
0005433569088	11837	43	10F
0005433569073	11837	44	11C
0005433569115	11837	45	11B
0005433569076	11837	46	11A
0005433569097	11837	47	11D
0005433569066	11837	48	11F
0005433569100	11837	49	11E
0005433569072	11837	50	12B
0005433569055	11837	51	12D
0005433569053	11837	52	12C
0005432948083	11837	53	13A
0005432947892	11837	54	12F
0005433569095	11837	55	13C
0005432948068	11837	56	13E
0005433569106	11837	57	13D
0005433569086	11837	58	14A
0005433569110	11837	59	14B
0005433569079	11837	60	14D
0005433569054	11837	61	14C
0005433569049	11837	62	15B
0005432948127	11837	63	15A
0005433569112	11837	64	15C
0005433569063	11837	65	15D
0005433569107	11837	66	16A
0005433569083	11837	67	15F
0005433569091	11837	68	16C
0005433569108	11837	69	16B
0005433569103	11837	70	16E
0005432948104	11837	71	16D
0005432948010	11837	72	17A
0005432948088	11837	73	16F
0005433569119	11837	74	17D
0005432948164	11837	75	17C
0005433569089	11837	76	17E
0005433569050	11837	77	18A
0005433569070	11837	78	17F
0005433569082	11837	79	18D
0005433569071	11837	80	18C
0005433569094	11837	81	18B
0005433569078	11837	82	18E
0005433569098	11837	83	18F
0005433569099	11837	84	19B
0005433569111	11837	85	19E
0005433569069	11837	86	19D
0005433569075	11837	87	19C
0005433569052	11837	88	19F
0005432948046	11837	89	20C
0005433569117	11837	90	20B
0005433569068	11837	91	20A
0005433569058	11837	92	20D
0005433569092	11837	93	20E
0005433569080	11837	94	21A
0005433569060	11837	95	21C
0005432948045	11837	96	21B
0005433569114	11837	97	21E
0005433569062	11837	98	21D
0005432948095	11837	99	21F
0005433568475	25310	1	1A
0005433568564	25310	2	1D
0005433568528	25310	3	1C
0005432948527	25310	4	2A
0005433568529	25310	5	2C
0005432948530	25310	6	3D
0005433568403	25310	7	3C
0005433568588	25310	8	3F
0005433568522	25310	9	4D
0005433568577	25310	10	4C
0005433568178	25310	11	4F
0005432948533	25310	12	5C
0005432948543	25310	13	5A
0005433568553	25310	14	5F
0005432948519	25310	15	5D
0005432948539	25310	16	6B
0005432948514	25310	17	6A
0005432948524	25310	18	6D
0005432948532	25310	19	6C
0005433568404	25310	20	6F
0005433568642	25310	21	6E
0005432948515	25310	22	7A
0005432948520	25310	23	7C
0005433568192	25310	24	7B
0005432948534	25310	25	7D
0005432948542	25310	26	8A
0005433568380	25310	27	7F
0005433568203	25310	28	8C
0005433568535	25310	29	8B
0005433568394	25310	30	8D
0005433568561	25310	31	8F
0005433568450	25310	32	8E
0005432948549	25310	33	9B
0005433568226	25310	34	9A
0005433568225	25310	35	9C
0005433568606	25310	36	9E
0005433568479	25310	37	10A
0005432948547	25310	38	10C
0005433568406	25310	39	10B
0005432948554	25310	40	10E
0005432948517	25310	41	10F
0005432948529	25310	42	11B
0005433568449	25310	43	11A
0005432948531	25310	44	11D
0005433568548	25310	45	11C
0005432948536	25310	46	11F
0005433568419	25310	47	11E
0005433568442	25310	48	12B
0005433568538	25310	49	12A
0005432948555	25310	50	12D
0005433568586	25310	51	12C
0005433568576	25310	52	12E
0005432948540	25310	53	13A
0005432948541	25310	54	12F
0005433568562	25310	55	13C
0005432948526	25310	56	13B
0005432948545	25310	57	13F
0005432948553	25310	58	14C
0005432948522	25310	59	14B
0005432948516	25310	60	14A
0005433568407	25310	61	14D
0005433568372	25310	62	14F
0005433568423	25310	63	14E
0005433568334	25310	64	15B
0005432948548	25310	65	15A
0005432948544	25310	66	15D
0005433568523	25310	67	15C
0005433568587	25310	68	15F
0005433568552	25310	69	15E
0005433568654	25310	70	16A
0005433568193	25310	71	16C
0005432948521	25310	72	16B
0005433568652	25310	73	16E
0005433568563	25310	74	16F
0005433568381	25310	75	17B
0005432948552	25310	76	17A
0005433568555	25310	77	17D
0005432948518	25310	78	17C
0005433568443	25310	79	17F
0005433568575	25310	80	17E
0005433568373	25310	81	18A
0005433568486	25310	82	18C
0005432948535	25310	83	18B
0005433568549	25310	84	18E
0005432948551	25310	85	18D
0005432948537	25310	86	18F
0005433568489	25310	87	19C
0005433568395	25310	88	19B
0005433568590	25310	89	19A
0005432948550	25310	90	19E
0005432948523	25310	91	19D
0005432948525	25310	92	19F
0005433568396	25310	93	20C
0005433568589	25310	94	20B
0005432948546	25310	95	20A
0005433568400	25310	96	20D
0005433568516	25310	97	21A
0005433568651	25310	98	20F
0005433568487	25310	99	21C
0005433568675	25310	100	21B
0005432948538	25310	101	21F
0005433568585	25310	102	21E
0005432948528	25310	103	21D
0005433808330	14457	1	2A
0005434026702	14457	2	2F
0005432430860	14457	3	2D
0005433808332	14457	4	3C
0005433808344	14457	5	4A
0005433808333	14457	6	3F
0005433812877	14457	7	5A
0005433812875	14457	8	5F
0005432430871	14457	9	6B
0005434026707	14457	10	6D
0005432430862	14457	11	6C
0005432430859	14457	12	6E
0005433808324	14457	13	7B
0005432430866	14457	14	7E
0005433812867	14457	15	8A
0005433812865	14457	16	9C
0005433808321	14457	17	9F
0005432430861	14457	18	10D
0005432430863	14457	19	10F
0005433808347	14457	20	11B
0005434026708	14457	21	11C
0005434026704	14457	22	12A
0005432430868	14457	23	13C
0005433808328	14457	24	13E
0005432430867	14457	25	13D
0005432430857	14457	26	14A
0005433812873	14457	27	13F
0005432430870	14457	28	14D
0005432430865	14457	29	14C
0005434026703	14457	30	14F
0005433812874	14457	31	15B
0005432430858	14457	32	15D
0005432430864	14457	33	16A
0005433808322	14457	34	16B
0005433812864	14457	35	16F
0005433808345	14457	36	17B
0005433812876	14457	37	17D
0005433808325	14457	38	18D
0005434026706	14457	39	18E
0005433808331	14457	40	19D
0005433808346	14457	41	19F
0005433808310	14457	42	19E
0005433808343	14457	43	20C
0005434026705	14457	44	20F
0005433808342	14457	45	20E
0005432430869	14457	46	21A
0005433812872	14457	47	21E
0005434026701	14457	48	21F
0005434654722	5364	1	1A
0005432114207	5364	2	2C
0005432114206	5364	3	2D
0005434654702	5364	4	3F
0005434654727	5364	5	4A
0005435340147	5364	6	4C
0005434654709	5364	7	4E
0005434654700	5364	8	4F
0005435340165	5364	9	5A
0005435340149	5364	10	5C
0005434654705	5364	11	5D
0005434654711	5364	12	5E
0005432114208	5364	13	5F
0005434654706	5364	14	6E
0005434654715	5364	15	7C
0005435555359	5364	16	7D
0005435340141	5364	17	7E
0005434654716	5364	18	7F
0005435340114	5364	19	8C
0005435555350	5364	20	8E
0005435340102	5364	21	8F
0005435340155	5364	22	9C
0005434654701	5364	23	9E
0005434654719	5364	24	9F
0005434654723	5364	25	10C
0005434654718	5364	26	10D
0005434654698	5364	27	10F
0005435340140	5364	28	11A
0005434654713	5364	29	12C
0005435340135	5364	30	12E
0005434654712	5364	31	12F
0005435340120	5364	32	13D
0005434654724	5364	33	13E
0005434654726	5364	34	13F
0005434654714	5364	35	14C
0005435340146	5364	36	14F
0005435340169	5364	37	15A
0005435340157	5364	38	15C
0005434654708	5364	39	15E
0005435340142	5364	40	15F
0005435340144	5364	41	16C
0005434654704	5364	42	16F
0005434654717	5364	43	17A
0005435340156	5364	44	17C
0005434654721	5364	45	17F
0005434656559	5364	46	18A
0005434656558	5364	47	18C
0005435555358	5364	48	18D
0005434654699	5364	49	18E
0005434654720	5364	50	19F
0005434654725	5364	51	20C
0005434654710	5364	52	20D
0005434654707	5364	53	20E
0005434654703	5364	54	20F
0005434654508	12535	1	1F
0005434654524	12535	2	2D
0005434654417	12535	3	3A
0005435340276	12535	4	3C
0005435340281	12535	5	3D
0005435340273	12535	6	4C
0005434654416	12535	7	5C
0005434654509	12535	8	6D
0005435340270	12535	9	6E
0005434654546	12535	10	7A
0005434654486	12535	11	7C
0005434654488	12535	12	7E
0005434654487	12535	13	8E
0005435340271	12535	14	10C
0005434654414	12535	15	11C
0005434654542	12535	16	11D
0005434654479	12535	17	11F
0005434654579	12535	18	12A
0005435340280	12535	19	12E
0005434654543	12535	20	13E
0005434654626	12535	21	14A
0005435340277	12535	22	14C
0005434654376	12535	23	14E
0005434654548	12535	24	14D
0005435340278	12535	25	15D
0005434654480	12535	26	16A
0005435340275	12535	27	16C
0005434654578	12535	28	16E
0005435340285	12535	29	16F
0005435340274	12535	30	17C
0005434654547	12535	31	17F
0005435340284	12535	32	18A
0005435340283	12535	33	18E
0005434654413	12535	34	19A
0005434654636	12535	35	19C
0005435340272	12535	36	19D
0005435555373	12535	37	19E
0005435555372	12535	38	19F
0005434654429	12535	39	20A
0005435340286	12535	40	20D
0005435340282	12535	41	20E
0005435340279	12535	42	20F
0005433716035	7446	1	1A
0005433716030	7446	2	1C
0005433715991	7446	3	1D
0005433716011	7446	4	2A
0005435266115	7446	5	2C
0005433715997	7446	6	2F
0005433715994	7446	7	3C
0005433716019	7446	8	3A
0005433716027	7446	9	3F
0005433715990	7446	10	3D
0005435266109	7446	11	4A
0005433716012	7446	12	4B
0005432428905	7446	13	4E
0005433656671	7446	14	4F
0005433716008	7446	15	5B
0005433716024	7446	16	5C
0005433688810	7446	17	6A
0005433716031	7446	18	5F
0005433716023	7446	19	6D
0005433722227	7446	20	6C
0005433716006	7446	21	6E
0005433716025	7446	22	6F
0005433716018	7446	23	7B
0005432078113	7446	24	7C
0005433716034	7446	25	7D
0005433716020	7446	26	7E
0005433716010	7446	27	7F
0005433716038	7446	28	8D
0005433690927	7446	29	9A
0005433690928	7446	30	9C
0005433716014	7446	31	9D
0005432078110	7446	32	9F
0005435266113	7446	33	10D
0005433689911	7446	34	11A
0005433715998	7446	35	11B
0005432078112	7446	36	11C
0005433719140	7446	37	11D
0005433716000	7446	38	12A
0005433716022	7446	39	11F
0005435266111	7446	40	13A
0005433715993	7446	41	13C
0005432078114	7446	42	13B
0005435266107	7446	43	13E
0005433716001	7446	44	13F
0005435266108	7446	45	14B
0005433716026	7446	46	14A
0005432428906	7446	47	14D
0005433716003	7446	48	14F
0005433716016	7446	49	15A
0005433716032	7446	50	15B
0005433716017	7446	51	15C
0005433716002	7446	52	16B
0005433719141	7446	53	16C
0005433719142	7446	54	16E
0005433716036	7446	55	16D
0005432428896	7446	56	17A
0005435266106	7446	57	17B
0005433715995	7446	58	17C
0005433716033	7446	59	17F
0005433715999	7446	60	18A
0005433656672	7446	61	18E
0005435266114	7446	62	19A
0005433715987	7446	63	19C
0005433722229	7446	64	19D
0005433715996	7446	65	19F
0005433716015	7446	66	19E
0005433716037	7446	67	20A
0005433715988	7446	68	20B
0005433715992	7446	69	20E
0005433722228	7446	70	20D
0005433716007	7446	71	21A
0005433715989	7446	72	20F
0005432078111	7446	73	21B
0005433722226	7446	74	21C
0005433716004	7446	75	21D
0005432428897	7446	76	21F
0005432078115	7446	77	22B
0005433716005	7446	78	22A
0005433716009	7446	79	22C
0005433716021	7446	80	22D
0005433716028	7446	81	22E
0005432428904	7446	82	23A
0005433722225	7446	83	23B
0005433716013	7446	84	23C
0005433656670	7446	85	23E
0005433716029	7446	86	23F
0005433685505	29204	1	1A
0005433719101	29204	2	1C
0005433722151	29204	3	2C
0005433715512	29204	4	2D
0005432428934	29204	5	2F
0005433715561	29204	6	3A
0005433656635	29204	7	3D
0005433722160	29204	8	4A
0005433715688	29204	9	4B
0005433715445	29204	10	4D
0005433715764	29204	11	4E
0005433719121	29204	12	5A
0005433715618	29204	13	4F
0005433688785	29204	14	5B
0005433722166	29204	15	5D
0005433715848	29204	16	5F
0005433715462	29204	17	6A
0005432428930	29204	18	6C
0005433715826	29204	19	6D
0005432428932	29204	20	6E
0005433715574	29204	21	6F
0005433715676	29204	22	7B
0005432428933	29204	23	7D
0005433715871	29204	24	7F
0005433722154	29204	25	7E
0005433685520	29204	26	8A
0005433715687	29204	27	8B
0005433719120	29204	28	8C
0005433656636	29204	29	8D
0005433722147	29204	30	8E
0005433715774	29204	31	9A
0005433715695	29204	32	9B
0005433715456	29204	33	10E
0005433715490	29204	34	10D
0005433715696	29204	35	11B
0005433715628	29204	36	11D
0005433715274	29204	37	11E
0005433715544	29204	38	11F
0005433722148	29204	39	12A
0005433715689	29204	40	12C
0005433715619	29204	41	12B
0005433719100	29204	42	12D
0005433715636	29204	43	12F
0005433715575	29204	44	13B
0005433715594	29204	45	13A
0005433715516	29204	46	13C
0005433688797	29204	47	13D
0005432006764	29204	48	13E
0005433722161	29204	49	13F
0005433722116	29204	50	14A
0005433715667	29204	51	14D
0005433715583	29204	52	14F
0005433715464	29204	53	14E
0005433715641	29204	54	15B
0005433715765	29204	55	15C
0005433715513	29204	56	15D
0005433715685	29204	57	15E
0005433715625	29204	58	16B
0005433715501	29204	59	16C
0005433715552	29204	60	16D
0005433715629	29204	61	16E
0005433688790	29204	62	17A
0005433715531	29204	63	17B
0005433715457	29204	64	17C
0005433715697	29204	65	17F
0005433715612	29204	66	18A
0005433715434	29204	67	18B
0005433715463	29204	68	18C
0005433715606	29204	69	18D
0005433685506	29204	70	19A
0005433719102	29204	71	20A
0005433715642	29204	72	20C
0005433719113	29204	73	20E
0005433715613	29204	74	20D
0005433715461	29204	75	21B
0005433715615	29204	76	21F
0005432428931	29204	77	22D
0005433715752	29204	78	22E
0005433722155	29204	79	23B
0005433715708	29204	80	23C
0005433715849	29204	81	23E
0005433722162	29204	82	23D
0005433715675	29204	83	23F
0005434184646	8669	1	2D
0005434095282	8669	2	3C
0005434182069	8669	3	4E
0005434182107	8669	4	6C
0005434095293	8669	5	7F
0005434095286	8669	6	8C
0005434095288	8669	7	8D
0005434095294	8669	8	8E
0005434095284	8669	9	9D
0005434095283	8669	10	10E
0005434184645	8669	11	10F
0005434095289	8669	12	11C
0005434095287	8669	13	12C
0005434182099	8669	14	12D
0005434095281	8669	15	14C
0005434095285	8669	16	14E
0005434182059	8669	17	15A
0005434095291	8669	18	15C
0005434095290	8669	19	15E
0005434095292	8669	20	16A
0005434182106	8669	21	16D
0005434095295	8669	22	17C
0005434182085	8669	23	18E
0005434182124	8669	24	19F
0005434182058	8669	25	20A
0005434095114	11637	1	2D
0005434095159	11637	2	2F
0005434095168	11637	3	3A
0005434184665	11637	4	3C
0005434182199	11637	5	3F
0005434095164	11637	6	4C
0005434182193	11637	7	5A
0005434182200	11637	8	5E
0005434182194	11637	9	5F
0005434184666	11637	10	6A
0005434182201	11637	11	6D
0005434182196	11637	12	7A
0005434095244	11637	13	7D
0005434095147	11637	14	7F
0005434182189	11637	15	8C
0005434143714	11637	16	8D
0005434095167	11637	17	8F
0005434182197	11637	18	9A
0005434184664	11637	19	9F
0005434095103	11637	20	10A
0005434095184	11637	21	11C
0005434182192	11637	22	11F
0005434095191	11637	23	12C
0005434143713	11637	24	13F
0005434182198	11637	25	14C
0005434182190	11637	26	14F
0005434095107	11637	27	15C
0005434183580	11637	28	16D
0005434095170	11637	29	17D
0005434182191	11637	30	17E
0005434095187	11637	31	18E
0005434095174	11637	32	18F
0005434182195	11637	33	19E
0005434183579	11637	34	20D
0005435732339	1466	1	1A
0005433397780	1466	2	1C
0005433397625	1466	3	1F
0005433397690	1466	4	2D
0005433397522	1466	5	2F
0005435732332	1466	6	3A
0005435732343	1466	7	3C
0005435732344	1466	8	3D
0005433397566	1466	9	4A
0005433397801	1466	10	4C
0005433397544	1466	11	4D
0005433397537	1466	12	4E
0005435732337	1466	13	4F
0005433397774	1466	14	5A
0005433397702	1466	15	5D
0005433397799	1466	16	5E
0005435732342	1466	17	5F
0005435732336	1466	18	6A
0005432297278	1466	19	6C
0005433397761	1466	20	6D
0005435732338	1466	21	6E
0005433397978	1466	22	6F
0005433397766	1466	23	7A
0005433456975	1466	24	7C
0005433397692	1466	25	7D
0005433397608	1466	26	7E
0005433397691	1466	27	7F
0005433397676	1466	28	8A
0005435732330	1466	29	8C
0005433397808	1466	30	8D
0005433397696	1466	31	8E
0005435732327	1466	32	9C
0005433456974	1466	33	9D
0005433397791	1466	34	9E
0005435732331	1466	35	10C
0005433397684	1466	36	10D
0005435732345	1466	37	10E
0005433397657	1466	38	10F
0005435732341	1466	39	11A
0005433456972	1466	40	11C
0005432297279	1466	41	11E
0005435732335	1466	42	11F
0005433397520	1466	43	12A
0005435732333	1466	44	12D
0005433397535	1466	45	12F
0005433397381	1466	46	13A
0005435732329	1466	47	13D
0005433397598	1466	48	13E
0005433397792	1466	49	13F
0005433397626	1466	50	14A
0005433397817	1466	51	14C
0005433397798	1466	52	15A
0005435732334	1466	53	15C
0005432906524	1466	54	15D
0005432906525	1466	55	15E
0005432297280	1466	56	16D
0005433397567	1466	57	16E
0005433397837	1466	58	16F
0005433397645	1466	59	17A
0005433397521	1466	60	17C
0005433456973	1466	61	17D
0005433397545	1466	62	17E
0005435732346	1466	63	18A
0005433397807	1466	64	18E
0005433397786	1466	65	18F
0005433397644	1466	66	19A
0005435732340	1466	67	19C
0005435732328	1466	68	19D
0005433397536	1466	69	19E
0005433397611	1466	70	19F
0005433456971	1466	71	20C
0005433397977	1466	72	20D
0005433397800	1466	73	20F
0005433398083	19279	1	1A
0005433398109	19279	2	1D
0005433398122	19279	3	1F
0005435732227	19279	4	2A
0005433398120	19279	5	2C
0005433398093	19279	6	2D
0005432906537	19279	7	2F
0005433398104	19279	8	3A
0005433398076	19279	9	3C
0005433398110	19279	10	3D
0005435732226	19279	11	3F
0005433398088	19279	12	4D
0005435732247	19279	13	4E
0005433456933	19279	14	4F
0005433456945	19279	15	5A
0005433398080	19279	16	5D
0005432906540	19279	17	5F
0005433398084	19279	18	6A
0005435732281	19279	19	6C
0005433398089	19279	20	6E
0005435732258	19279	21	6F
0005432906539	19279	22	7A
0005433398101	19279	23	7D
0005433398100	19279	24	7E
0005433398090	19279	25	7F
0005432906538	19279	26	8D
0005433398075	19279	27	8E
0005433398094	19279	28	9A
0005433398112	19279	29	9F
0005433398086	19279	30	10A
0005433398117	19279	31	10D
0005433456918	19279	32	10F
0005433398107	19279	33	11A
0005433398113	19279	34	11E
0005433398105	19279	35	11F
0005435732276	19279	36	12C
0005435732292	19279	37	12E
0005433398087	19279	38	12F
0005435732193	19279	39	13C
0005433456939	19279	40	13D
0005433398121	19279	41	13E
0005433398102	19279	42	13F
0005433398108	19279	43	14A
0005433398118	19279	44	14C
0005433398106	19279	45	14D
0005433398091	19279	46	14E
0005433398123	19279	47	14F
0005433398119	19279	48	15C
0005433398098	19279	49	15D
0005435732291	19279	50	15E
0005433398099	19279	51	15F
0005433398115	19279	52	16A
0005433398116	19279	53	16D
0005433398095	19279	54	16E
0005433456941	19279	55	17A
0005433456919	19279	56	17C
0005433398082	19279	57	17D
0005433398081	19279	58	17E
0005433398079	19279	59	18A
0005433398111	19279	60	18C
0005433456936	19279	61	18D
0005435732192	19279	62	18E
0005433398085	19279	63	18F
0005433398097	19279	64	19A
0005433398114	19279	65	19C
0005433398092	19279	66	19D
0005433398077	19279	67	19E
0005435732259	19279	68	19F
0005433398103	19279	69	20C
0005433398096	19279	70	20D
0005433456940	19279	71	20E
0005433398078	19279	72	20F
0005434443570	17350	1	1B
0005434443579	17350	2	3A
0005434443571	17350	3	3B
0005434443614	17350	4	4C
0005434443515	17350	5	5C
0005434443498	17350	6	18B
0005434443516	17350	7	19D
0005434443615	17350	8	21A
0005434443639	17350	9	21D
0005434443590	17350	10	22D
0005434443714	20612	1	1A
0005434443707	20612	2	1B
0005434443715	20612	3	1D
0005434443712	20612	4	3C
0005434443705	20612	5	5A
0005434443713	20612	6	6B
0005434443719	20612	7	6C
0005434443716	20612	8	18B
0005434443709	20612	9	18D
0005434443708	20612	10	19D
0005434443711	20612	11	20A
0005434443720	20612	12	20D
0005434443717	20612	13	21C
0005434443710	20612	14	22C
0005434443706	20612	15	23A
0005434443718	20612	16	23B
0005434954614	7241	1	1A
0005434954610	7241	2	1B
0005434954612	7241	3	3B
0005434954615	7241	4	4A
0005434954611	7241	5	4B
0005434954613	7241	6	6B
0005435377583	28331	1	2A
0005435377581	28331	2	3A
0005435377582	28331	3	4A
0005434954563	28331	4	5B
0005434954562	28331	5	6B
0005434351709	4454	1	1A
0005434351707	4454	2	4A
0005435893584	4454	3	5B
0005435893551	4454	4	5C
0005434351701	4454	5	6C
0005434351705	4454	6	6D
0005435893565	4454	7	7A
0005434351713	4454	8	7C
0005434351711	4454	9	18A
0005434351700	4454	10	18C
0005434351712	4454	11	19A
0005435893552	4454	12	19B
0005434351702	4454	13	19D
0005434351706	4454	14	20A
0005435893553	4454	15	20B
0005434351703	4454	16	20C
0005435893583	4454	17	21A
0005434183557	4454	18	21B
0005434351710	4454	19	21D
0005434351704	4454	20	22B
0005434351708	4454	21	22D
0005434351596	29648	1	1A
0005434351601	29648	2	1B
0005434351556	29648	3	1D
0005434351612	29648	4	2C
0005434351560	29648	5	3D
0005435893639	29648	6	4A
0005434351598	29648	7	4C
0005435893638	29648	8	4D
0005435893636	29648	9	5B
0005434351568	29648	10	5C
0005434351607	29648	11	18A
0005434351585	29648	12	18B
0005434351548	29648	13	20A
0005435893640	29648	14	20C
0005435893637	29648	15	21A
0005434351599	29648	16	21B
0005434351609	29648	17	21D
0005434351597	29648	18	22A
0005434351608	29648	19	22B
0005434351549	29648	20	22C
0005434351602	29648	21	23A
0005433341733	1061	1	1C
0005433342310	1061	2	1B
0005433342258	1061	3	1G
0005433342518	1061	4	2B
0005433342539	1061	5	2G
0005433342095	1061	6	2H
0005433342305	1061	7	3C
0005433342340	1061	8	3B
0005433342473	1061	9	3A
0005433158111	1061	10	3F
0005433342444	1061	11	4A
0005433342306	1061	12	3H
0005433342560	1061	13	4B
0005435545749	1061	14	4C
0005435092086	1061	15	4G
0005433342578	1061	16	5A
0005433342480	1061	17	5B
0005433342161	1061	18	5C
0005433342315	1061	19	5F
0005433342445	1061	20	9B
0005433342156	1061	21	9G
0005435545750	1061	22	11B
0005433269655	1061	23	11F
0005433342446	1061	24	11G
0005433341927	1061	25	12A
0005433342246	1061	26	12E
0005433341906	1061	27	12D
0005433342422	1061	28	12G
0005433159291	1061	29	12F
0005433269671	1061	30	13B
0005435092077	1061	31	13A
0005433462749	1061	32	13D
0005435545747	1061	33	13G
0005435092083	1061	34	13F
0005433341926	1061	35	14B
0005433341947	1061	36	14A
0005433341934	1061	37	14D
0005434446520	1061	38	14E
0005435092081	1061	39	14G
0005433342579	1061	40	15A
0005433269656	1061	41	15D
0005433342433	1061	42	15B
0005433342272	1061	43	15H
0005433342401	1061	44	15G
0005433342171	1061	45	16A
0005433341925	1061	46	16E
0005435545741	1061	47	17B
0005433342126	1061	48	17A
0005433342269	1061	49	17D
0005433342402	1061	50	17E
0005435545742	1061	51	18B
0005433342552	1061	52	18D
0005433341935	1061	53	18F
0005433342282	1061	54	18E
0005433159301	1061	55	18H
0005433342474	1061	56	19A
0005435092078	1061	57	19D
0005435092082	1061	58	19E
0005433342714	1061	59	19G
0005433342003	1061	60	20D
0005433342094	1061	61	20B
0005433342127	1061	62	20F
0005434445250	1061	63	20H
0005433269680	1061	64	20G
0005433342681	1061	65	21A
0005433341908	1061	66	21D
0005435545748	1061	67	21B
0005433342507	1061	68	21F
0005433342285	1061	69	21E
0005433342506	1061	70	21G
0005433342550	1061	71	21H
0005433342792	1061	72	22D
0005433341909	1061	73	22F
0005433342553	1061	74	22G
0005433341820	1061	75	22H
0005433342304	1061	76	23B
0005433342508	1061	77	23F
0005434445251	1061	78	23G
0005433158109	1061	79	24E
0005433342395	1061	80	24F
0005433342241	1061	81	25D
0005433342160	1061	82	25F
0005433342366	1061	83	25E
0005435092080	1061	84	27A
0005435545751	1061	85	27B
0005433342332	1061	86	27E
0005435092079	1061	87	27G
0005433342430	1061	88	28A
0005435545744	1061	89	28E
0005433342116	1061	90	28D
0005433342495	1061	91	28H
0005433342494	1061	92	28G
0005433342423	1061	93	29A
0005433341919	1061	94	29F
0005433463902	1061	95	29E
0005433342830	1061	96	29G
0005435545743	1061	97	29H
0005433342360	1061	98	30B
0005433341939	1061	99	30E
0005433342104	1061	100	31B
0005433342359	1061	101	31A
0005433342038	1061	102	31D
0005433342570	1061	103	31F
0005433342469	1061	104	31G
0005435545746	1061	105	32D
0005433342144	1061	106	32B
0005433342325	1061	107	32F
0005433342713	1061	108	33A
0005433158110	1061	109	33D
0005433158116	1061	110	33B
0005435092084	1061	111	33E
0005433342039	1061	112	33F
0005433341910	1061	113	33G
0005433341819	1061	114	34B
0005433342479	1061	115	34A
0005433341907	1061	116	34G
0005433342379	1061	117	35B
0005433342283	1061	118	35E
0005433342429	1061	119	35D
0005432293211	1061	120	35F
0005433342139	1061	121	35G
0005433342284	1061	122	36A
0005433342591	1061	123	35H
0005433342324	1061	124	36B
0005433342512	1061	125	36E
0005433342047	1061	126	36G
0005433342145	1061	127	37A
0005433342358	1061	128	37E
0005435545745	1061	129	37G
0005432293210	1061	130	37F
0005433463903	1061	131	38B
0005435092085	1061	132	38A
0005433342481	1061	133	37H
0005433269672	1061	134	38E
0005433342286	1061	135	38G
0005433342082	1061	136	38F
0005433342561	1061	137	38H
0005433342331	1061	138	39E
0005434445249	1061	139	39D
0005433343131	17039	1	1A
0005433343146	17039	2	1C
0005433343204	17039	3	1F
0005433343154	17039	4	1H
0005433159315	17039	5	2B
0005435508247	17039	6	2C
0005433343163	17039	7	2G
0005433343197	17039	8	2H
0005433343126	17039	9	3B
0005433343212	17039	10	3G
0005433343201	17039	11	3H
0005433343184	17039	12	4B
0005435091971	17039	13	4A
0005433159316	17039	14	4F
0005433343179	17039	15	4C
0005433343147	17039	16	5A
0005433343161	17039	17	4H
0005433343196	17039	18	5B
0005433343133	17039	19	5C
0005433343186	17039	20	5G
0005433343141	17039	21	5H
0005433343149	17039	22	9B
0005433343194	17039	23	9G
0005433269721	17039	24	11A
0005433343150	17039	25	9H
0005435508262	17039	26	11B
0005433343187	17039	27	11D
0005433269723	17039	28	11H
0005433343188	17039	29	11G
0005433343190	17039	30	12A
0005433343125	17039	31	12E
0005433343112	17039	32	12F
0005435092006	17039	33	13B
0005433343180	17039	34	13A
0005433343198	17039	35	13D
0005433343129	17039	36	14A
0005433343144	17039	37	13H
0005433343130	17039	38	14B
0005433343115	17039	39	14E
0005435508276	17039	40	14F
0005433343193	17039	41	15B
0005433343165	17039	42	15E
0005433343153	17039	43	15D
0005433343160	17039	44	15G
0005433343210	17039	45	15H
0005435508201	17039	46	16D
0005433343138	17039	47	16B
0005433343182	17039	48	16G
0005433343128	17039	49	16H
0005433343207	17039	50	17A
0005435091990	17039	51	17F
0005433343139	17039	52	17E
0005435091988	17039	53	18D
0005433343159	17039	54	18G
0005433343124	17039	55	18F
0005435092000	17039	56	19A
0005433269722	17039	57	18H
0005433343169	17039	58	19D
0005433343199	17039	59	19F
0005433343203	17039	60	19G
0005433343145	17039	61	20A
0005433343127	17039	62	19H
0005433343183	17039	63	20B
0005433343181	17039	64	20E
0005435508283	17039	65	20D
0005433343173	17039	66	20F
0005433343158	17039	67	20H
0005433343185	17039	68	20G
0005433343156	17039	69	21B
0005433343164	17039	70	21F
0005433343206	17039	71	21H
0005435092001	17039	72	22B
0005433343170	17039	73	22A
0005433343192	17039	74	22E
0005433343119	17039	75	22F
0005433343135	17039	76	23A
0005433343189	17039	77	22H
0005433343120	17039	78	23B
0005433343205	17039	79	23E
0005433343122	17039	80	23F
0005433343167	17039	81	23H
0005435092029	17039	82	24B
0005433343209	17039	83	24F
0005433343137	17039	84	24E
0005433269720	17039	85	25D
0005433343172	17039	86	25F
0005433343117	17039	87	25E
0005433343121	17039	88	27A
0005433343166	17039	89	27B
0005433343176	17039	90	27F
0005435508277	17039	91	27E
0005433343111	17039	92	27H
0005433343151	17039	93	28A
0005433343152	17039	94	28D
0005433343178	17039	95	28G
0005435508279	17039	96	29A
0005433269724	17039	97	29E
0005433343143	17039	98	29F
0005433343200	17039	99	30A
0005433343140	17039	100	30D
0005433343191	17039	101	30F
0005435091970	17039	102	31A
0005433343113	17039	103	30H
0005433343136	17039	104	31B
0005433343211	17039	105	31F
0005433343202	17039	106	31G
0005433343208	17039	107	32B
0005433343148	17039	108	32D
0005433343177	17039	109	32H
0005433343134	17039	110	32G
0005433343123	17039	111	33F
0005433343142	17039	112	33G
0005435508202	17039	113	34A
0005435092007	17039	114	34D
0005435508250	17039	115	34B
0005433269725	17039	116	35B
0005433343175	17039	117	35E
0005433343132	17039	118	35D
0005433343168	17039	119	35F
0005435508266	17039	120	35G
0005433343116	17039	121	36D
0005433159314	17039	122	36F
0005433343195	17039	123	36E
0005435508246	17039	124	36G
0005433343171	17039	125	36H
0005433343118	17039	126	37G
0005433343155	17039	127	38A
0005433343162	17039	128	38B
0005433343114	17039	129	38E
0005433343174	17039	130	38D
0005433343157	17039	131	38G
0005435092013	17039	132	38F
0005434067012	12806	1	1A
0005434067020	12806	2	1C
0005432433686	12806	3	1D
0005434066880	12806	4	2A
0005432159861	12806	5	1F
0005434081601	12806	6	2C
0005434066749	12806	7	2D
0005434081669	12806	8	2F
0005434081627	12806	9	3A
0005434066879	12806	10	3D
0005434081666	12806	11	3C
0005434066778	12806	12	3F
0005434066881	12806	13	4B
0005433812901	12806	14	4A
0005433989722	12806	15	4C
0005434066903	12806	16	4D
0005434066741	12806	17	4E
0005434066843	12806	18	5A
0005434066891	12806	19	4F
0005434067250	12806	20	5C
0005434066899	12806	21	5B
0005434067018	12806	22	5D
0005434066957	12806	23	5E
0005434066826	12806	24	5F
0005433989742	12806	25	6A
0005434067360	12806	26	6C
0005434066936	12806	27	6B
0005432159863	12806	28	6D
0005434066812	12806	29	6E
0005434081665	12806	30	7A
0005434067047	12806	31	6F
0005433812902	12806	32	7B
0005434067017	12806	33	7C
0005434066789	12806	34	7E
0005434066714	12806	35	7D
0005434067090	12806	36	8A
0005434081687	12806	37	7F
0005434081667	12806	38	8B
0005434081628	12806	39	8D
0005432433682	12806	40	8C
0005434066815	12806	41	8E
0005434066844	12806	42	9A
0005434067027	12806	43	8F
0005434066792	12806	44	9B
0005434081658	12806	45	9C
0005434066964	12806	46	9E
0005434066902	12806	47	9D
0005432161153	12806	48	9F
0005434067030	12806	49	10B
0005434066772	12806	50	10D
0005434067069	12806	51	10C
0005434067249	12806	52	11A
0005432433683	12806	53	10E
0005434066715	12806	54	11B
0005434066972	12806	55	11D
0005433989743	12806	56	11C
0005434066996	12806	57	11F
0005434066828	12806	58	11E
0005434066973	12806	59	12B
0005434066820	12806	60	12A
0005434066980	12806	61	12D
0005434066870	12806	62	12C
0005434081643	12806	63	12E
0005434081670	12806	64	12F
0005434081688	12806	65	13A
0005433989721	12806	66	13C
0005434067204	12806	67	13B
0005432433685	12806	68	13E
0005434067113	12806	69	13D
0005433812903	12806	70	14A
0005433989741	12806	71	13F
0005432159860	12806	72	14B
0005434067021	12806	73	14C
0005434081623	12806	74	14D
0005434067189	12806	75	14E
0005434066742	12806	76	14F
0005434066968	12806	77	15A
0005434081655	12806	78	15C
0005434067013	12806	79	15B
0005434066689	12806	80	15D
0005434066867	12806	81	15E
0005434067067	12806	82	16A
0005434067212	12806	83	15F
0005434066782	12806	84	16B
0005434067237	12806	85	16C
0005434026683	12806	86	16D
0005434066790	12806	87	16E
0005434081657	12806	88	17A
0005434066777	12806	89	16F
0005434066988	12806	90	17B
0005434066781	12806	91	17C
0005434066967	12806	92	17D
0005434066793	12806	93	17F
0005434066827	12806	94	17E
0005434066679	12806	95	18A
0005434066969	12806	96	18B
0005434067114	12806	97	18C
0005434067022	12806	98	18E
0005434026696	12806	99	18D
0005434067197	12806	100	18F
0005434066773	12806	101	19A
0005434066816	12806	102	19B
0005434066713	12806	103	19C
0005432433687	12806	104	19E
0005434066956	12806	105	19D
0005432161154	12806	106	19F
0005432433684	12806	107	20B
0005434081645	12806	108	20A
0005433989719	12806	109	20C
0005434067004	12806	110	20D
0005434066886	12806	111	20E
0005434066998	12806	112	21A
0005434066813	12806	113	20F
0005432433681	12806	114	21B
0005434067248	12806	115	21D
0005434066783	12806	116	21C
0005434066868	12806	117	21E
0005434066963	12806	118	21F
0005434066734	12806	119	22B
0005434066791	12806	120	22A
0005434066920	12806	121	22C
0005434067026	12806	122	22D
0005434067076	12806	123	22E
0005434067196	12806	124	23A
0005434066908	12806	125	22F
0005432159862	12806	126	23B
0005434067043	12806	127	23D
0005434066739	12806	128	23C
0005434066997	12806	129	23E
0005434081622	12806	130	23F
0005434067596	30638	1	1A
0005434081894	30638	2	1C
0005434067589	30638	3	1D
0005434067594	30638	4	2A
0005434067579	30638	5	2C
0005434081907	30638	6	2D
0005432186868	30638	7	2F
0005432150196	30638	8	3A
0005434081899	30638	9	3D
0005432150195	30638	10	3C
0005434081902	30638	11	3F
0005432150194	30638	12	4A
0005434081913	30638	13	4B
0005434067571	30638	14	4D
0005434067598	30638	15	4C
0005434081898	30638	16	4E
0005432433676	30638	17	4F
0005434067582	30638	18	5B
0005432433658	30638	19	5A
0005434067544	30638	20	5C
0005433989771	30638	21	5D
0005434067569	30638	22	5F
0005434067566	30638	23	5E
0005434067542	30638	24	6A
0005432433644	30638	25	6C
0005434067530	30638	26	6B
0005434081904	30638	27	6D
0005433989772	30638	28	6E
0005434081897	30638	29	6F
0005433989774	30638	30	7B
0005434067595	30638	31	7A
0005434067574	30638	32	7C
0005434081895	30638	33	7E
0005434067565	30638	34	7D
0005434067529	30638	35	8A
0005434067539	30638	36	7F
0005434067593	30638	37	8B
0005434067588	30638	38	8D
0005434081905	30638	39	8C
0005434067548	30638	40	8E
0005432433675	30638	41	8F
0005433989769	30638	42	9A
0005434067578	30638	43	9B
0005433989770	30638	44	9D
0005434067560	30638	45	9C
0005434081911	30638	46	9F
0005434067555	30638	47	9E
0005434081901	30638	48	10B
0005434067568	30638	49	10D
0005434067577	30638	50	10E
0005434067550	30638	51	11A
0005434067534	30638	52	11B
0005434067562	30638	53	11D
0005434067557	30638	54	11C
0005434067597	30638	55	11E
0005434067576	30638	56	11F
0005434081903	30638	57	12A
0005434067540	30638	58	12C
0005434067581	30638	59	12B
0005434067585	30638	60	12D
0005434067573	30638	61	12E
0005432150197	30638	62	12F
0005434067570	30638	63	13A
0005434067549	30638	64	13C
0005434067552	30638	65	13B
0005433989773	30638	66	13D
0005434081915	30638	67	13E
0005434067558	30638	68	13F
0005434067590	30638	69	14B
0005432186867	30638	70	14A
0005434067543	30638	71	14C
0005434067559	30638	72	14D
0005434067561	30638	73	14E
0005434081909	30638	74	14F
0005432150191	30638	75	15B
0005432150192	30638	76	15A
0005434067601	30638	77	15C
0005434081917	30638	78	15D
0005434081892	30638	79	15F
0005434067536	30638	80	15E
0005434067535	30638	81	16A
0005434081896	30638	82	16B
0005434081893	30638	83	16D
0005434067531	30638	84	16C
0005434081900	30638	85	16F
0005434067575	30638	86	16E
0005434081910	30638	87	17A
0005434067602	30638	88	17B
0005434067545	30638	89	17C
0005434067599	30638	90	17D
0005432433668	30638	91	17F
0005434081912	30638	92	17E
0005432150198	30638	93	18B
0005434081916	30638	94	18A
0005434067537	30638	95	18C
0005434067551	30638	96	18D
0005434081908	30638	97	18E
0005434067572	30638	98	19A
0005432150193	30638	99	18F
0005434067591	30638	100	19C
0005434067554	30638	101	19B
0005434067556	30638	102	19E
0005432433632	30638	103	19D
0005432186869	30638	104	19F
0005434067563	30638	105	20A
0005434067600	30638	106	20C
0005434067583	30638	107	20B
0005434067553	30638	108	20D
0005434067584	30638	109	20E
0005432150199	30638	110	20F
0005434067541	30638	111	21A
0005434067564	30638	112	21C
0005434067538	30638	113	21B
0005434067546	30638	114	21D
0005434081914	30638	115	21E
0005434067547	30638	116	22A
0005434067586	30638	117	22B
0005434067592	30638	118	22C
0005434067567	30638	119	22D
0005434067580	30638	120	22F
0005434067587	30638	121	22E
0005434067533	30638	122	23B
0005432186870	30638	123	23C
0005432433667	30638	124	23D
0005434081906	30638	125	23F
0005434067532	30638	126	23E
0005433686605	19361	1	2B
0005433689885	19361	2	4B
0005433686602	19361	3	5D
0005433689886	19361	4	7B
0005433686606	19361	5	18C
0005433689889	19361	6	20A
0005433686604	19361	7	20B
0005433686607	19361	8	20C
0005435766289	5520	1	1A
0005432535791	5520	2	1B
0005435766290	5520	3	1F
0005435725599	5520	4	1C
0005435462335	5520	5	1G
0005434264841	5520	6	2C
0005434831115	5520	7	2F
0005435766303	5520	8	2H
0005435766271	5520	9	3A
0005435766262	5520	10	3C
0005435766287	5520	11	3B
0005432535779	5520	12	3F
0005435725600	5520	13	3G
0005435766294	5520	14	4C
0005432535777	5520	15	4B
0005435461906	5520	16	4A
0005435766295	5520	17	4G
0005434265005	5520	18	5A
0005435766265	5520	19	5F
0005435462071	5520	20	5C
0005435462189	5520	21	5H
0005435766283	5520	22	9B
0005433527270	5520	23	9A
0005434264949	5520	24	9H
0005435766288	5520	25	9G
0005434264903	5520	26	11A
0005435766278	5520	27	11B
0005434264860	5520	28	11E
0005435766259	5520	29	11D
0005434264923	5520	30	11F
0005435766256	5520	31	11G
0005435766280	5520	32	12A
0005435766272	5520	33	11H
0005435766267	5520	34	12D
0005432140451	5520	35	12E
0005435766308	5520	36	12F
0005435462120	5520	37	12H
0005435462078	5520	38	13B
0005434264891	5520	39	13F
0005435462178	5520	40	13E
0005435766273	5520	41	13G
0005432140459	5520	42	14A
0005435462117	5520	43	13H
0005432140453	5520	44	14B
0005435462128	5520	45	14D
0005434264888	5520	46	14G
0005435462157	5520	47	15A
0005434264924	5520	48	14H
0005435766286	5520	49	15E
0005435462143	5520	50	15D
0005434264978	5520	51	15G
0005435462172	5520	52	15F
0005435766255	5520	53	15H
0005434265024	5520	54	16D
0005435766258	5520	55	16B
0005435462121	5520	56	16F
0005434265014	5520	57	16E
0005435766276	5520	58	16H
0005435766292	5520	59	17F
0005435462113	5520	60	17E
0005434264890	5520	61	18B
0005434264969	5520	62	18A
0005435766263	5520	63	18D
0005435766274	5520	64	18E
0005435722057	5520	65	18G
0005435766284	5520	66	18F
0005435735138	5520	67	19A
0005434264859	5520	68	19B
0005432140454	5520	69	19D
0005435766301	5520	70	19F
0005434264812	5520	71	19E
0005435725602	5520	72	19H
0005435462072	5520	73	20A
0005435043276	5520	74	20D
0005435766253	5520	75	20B
0005435462186	5520	76	20E
0005435766268	5520	77	20G
0005435766291	5520	78	20F
0005435766304	5520	79	20H
0005435766277	5520	80	21B
0005435766281	5520	81	21E
0005435766293	5520	82	21D
0005432140455	5520	83	21F
0005435462132	5520	84	21H
0005433527269	5520	85	22A
0005432535776	5520	86	22D
0005435766282	5520	87	23A
0005435766296	5520	88	22H
0005435723046	5520	89	23B
0005435462240	5520	90	23E
0005435766260	5520	91	23D
0005434831102	5520	92	23F
0005435462187	5520	93	23H
0005435462232	5520	94	24D
0005435766305	5520	95	24F
0005435735139	5520	96	24E
0005435462130	5520	97	24G
0005435462244	5520	98	25D
0005432140452	5520	99	25E
0005435462131	5520	100	25F
0005435461905	5520	101	27D
0005432535784	5520	102	27G
0005434264925	5520	103	27F
0005435725601	5520	104	27H
0005435462188	5520	105	28E
0005434831121	5520	106	28D
0005435766302	5520	107	28F
0005433529281	5520	108	28G
0005435462190	5520	109	29A
0005434264870	5520	110	28H
0005435766300	5520	111	29B
0005434264974	5520	112	29D
0005435766257	5520	113	29G
0005435462129	5520	114	29F
0005435462088	5520	115	29H
0005435766270	5520	116	30A
0005435766275	5520	117	30E
0005433527272	5520	118	30F
0005434831094	5520	119	31A
0005435722056	5520	120	31D
0005435766307	5520	121	31F
0005435766297	5520	122	31E
0005435462177	5520	123	31H
0005432140458	5520	124	31G
0005434264817	5520	125	32A
0005435735140	5520	126	32B
0005432140457	5520	127	32E
0005433529283	5520	128	32G
0005435462214	5520	129	33A
0005435462127	5520	130	33D
0005434265036	5520	131	33F
0005435766269	5520	132	33H
0005435766254	5520	133	33G
0005435766279	5520	134	34A
0005435462156	5520	135	34D
0005435766266	5520	136	34B
0005435766299	5520	137	34G
0005434264960	5520	138	34H
0005434831123	5520	139	35B
0005434831122	5520	140	35A
0005433529282	5520	141	35E
0005435462073	5520	142	35F
0005435766298	5520	143	36A
0005434264811	5520	144	35H
0005433529280	5520	145	36B
0005435766309	5520	146	36F
0005435723047	5520	147	36E
0005434264843	5520	148	36G
0005435766285	5520	149	37A
0005435723045	5520	150	36H
0005435735137	5520	151	37B
0005433527271	5520	152	37E
0005435766264	5520	153	37D
0005432140456	5520	154	37F
0005435462112	5520	155	37H
0005435462041	5520	156	38A
0005435766261	5520	157	38F
0005435462124	5520	158	38E
0005434264842	5520	159	38D
0005435766306	5520	160	38H
0005434264892	5520	161	38G
0005435766310	5520	162	39D
0005434264900	5520	163	39F
0005435462456	13458	1	1A
0005433529241	13458	2	1B
0005434265164	13458	3	1F
0005435765621	13458	4	2A
0005434265162	13458	5	1H
0005435462472	13458	6	2B
0005435462490	13458	7	2C
0005435765745	13458	8	2G
0005435765761	13458	9	2F
0005435765924	13458	10	3A
0005434831155	13458	11	2H
0005435462473	13458	12	3B
0005435765683	13458	13	3C
0005435462466	13458	14	3G
0005434831158	13458	15	3H
0005435462484	13458	16	4B
0005435765509	13458	17	4C
0005435765855	13458	18	4G
0005434265177	13458	19	4F
0005435765739	13458	20	4H
0005434265154	13458	21	5F
0005434831156	13458	22	5H
0005434265166	13458	23	9B
0005433533268	13458	24	9A
0005435765786	13458	25	9H
0005435765664	13458	26	9G
0005435765622	13458	27	11A
0005435462480	13458	28	11B
0005435765923	13458	29	11E
0005434265158	13458	30	11D
0005435617171	13458	31	11F
0005435765510	13458	32	11H
0005433533266	13458	33	11G
0005432194516	13458	34	12A
0005435462468	13458	35	12D
0005435765465	13458	36	12E
0005432535839	13458	37	12F
0005434265156	13458	38	12H
0005435765857	13458	39	13B
0005433529228	13458	40	13G
0005433533282	13458	41	13F
0005433533267	13458	42	14A
0005435765920	13458	43	14B
0005435462483	13458	44	14F
0005435765715	13458	45	14E
0005434265165	13458	46	14G
0005435765748	13458	47	14H
0005435462460	13458	48	15D
0005433529235	13458	49	15B
0005432535840	13458	50	15A
0005435765812	13458	51	15E
0005435765495	13458	52	15F
0005433533281	13458	53	15H
0005435765781	13458	54	15G
0005435462452	13458	55	16A
0005435765555	13458	56	16D
0005435725550	13458	57	16F
0005434265152	13458	58	16G
0005434265159	13458	59	16H
0005434265155	13458	60	17B
0005435722031	13458	61	17A
0005434265163	13458	62	17D
0005435765411	13458	63	17E
0005432194514	13458	64	17F
0005433529223	13458	65	17H
0005433533288	13458	66	18B
0005435462479	13458	67	18D
0005433533289	13458	68	18F
0005435722036	13458	69	18E
0005435765873	13458	70	18H
0005435462478	13458	71	18G
0005434265172	13458	72	19A
0005435765556	13458	73	19B
0005435765684	13458	74	19D
0005434265171	13458	75	19F
0005435722022	13458	76	20A
0005434265160	13458	77	20B
0005435765610	13458	78	20E
0005434265173	13458	79	20F
0005433533255	13458	80	20G
0005433529240	13458	81	21A
0005433529236	13458	82	20H
0005435765682	13458	83	21B
0005435765571	13458	84	21E
0005433533269	13458	85	21G
0005435765949	13458	86	21F
0005434265161	13458	87	21H
0005435722037	13458	88	22A
0005435765635	13458	89	22E
0005435765496	13458	90	22G
0005432194517	13458	91	22H
0005435765848	13458	92	23A
0005435462462	13458	93	23E
0005435765852	13458	94	23D
0005435462476	13458	95	23B
0005435765946	13458	96	23F
0005434265169	13458	97	24B
0005435765711	13458	98	24A
0005435462459	13458	99	24D
0005433529224	13458	100	24F
0005432194515	13458	101	24E
0005435765602	13458	102	24G
0005434265151	13458	103	25D
0005434265175	13458	104	24H
0005435725553	13458	105	25E
0005433533264	13458	106	27A
0005435462486	13458	107	25F
0005435765805	13458	108	27D
0005434265157	13458	109	27B
0005435765900	13458	110	27E
0005435725568	13458	111	27F
0005434831157	13458	112	27H
0005435725564	13458	113	27G
0005432535838	13458	114	28B
0005434265176	13458	115	28D
0005433529239	13458	116	28E
0005435462487	13458	117	28H
0005435765634	13458	118	28G
0005435765861	13458	119	29A
0005435765724	13458	120	29D
0005435765749	13458	121	29B
0005433533256	13458	122	29E
0005434831159	13458	123	29G
0005435462481	13458	124	29F
0005435462458	13458	125	30A
0005435462454	13458	126	29H
0005435462477	13458	127	30D
0005435765702	13458	128	30F
0005435765704	13458	129	30E
0005434265178	13458	130	30H
0005435462485	13458	131	31B
0005435765953	13458	132	31D
0005435725565	13458	133	31F
0005435462470	13458	134	31H
0005435462474	13458	135	31G
0005435765703	13458	136	32D
0005433533271	13458	137	32B
0005434265167	13458	138	32F
0005435462489	13458	139	32E
0005435725556	13458	140	32H
0005435462463	13458	141	32G
0005435462488	13458	142	33B
0005432535837	13458	143	33E
0005435765950	13458	144	33G
0005435725557	13458	145	33F
0005435462461	13458	146	33H
0005435462457	13458	147	34D
0005435735103	13458	148	34B
0005435765921	13458	149	34E
0005433529229	13458	150	34G
0005435462464	13458	151	34F
0005433529231	13458	152	35A
0005435617172	13458	153	35B
0005435725548	13458	154	35D
0005435462469	13458	155	35E
0005435765650	13458	156	35G
0005435462471	13458	157	35F
0005435725527	13458	158	36A
0005435462482	13458	159	35H
0005435765636	13458	160	36B
0005435735104	13458	161	36D
0005435765508	13458	162	36F
0005435765440	13458	163	36E
0005434265168	13458	164	36G
0005435765768	13458	165	37A
0005435462465	13458	166	36H
0005434265153	13458	167	37B
0005435462467	13458	168	37E
0005432194513	13458	169	37D
0005434265170	13458	170	37F
0005435765603	13458	171	37H
0005432535836	13458	172	37G
0005435765823	13458	173	38D
0005433533263	13458	174	38E
0005435462453	13458	175	38G
0005435462455	13458	176	38F
0005435765651	13458	177	38H
0005434265174	13458	178	39E
0005435462475	13458	179	39D
0005435765557	13458	180	39F
0005434602879	18651	1	2A
0005434602881	18651	2	2B
0005434602876	18651	3	3B
0005434602880	18651	4	4B
0005434602875	18651	5	5B
0005434602884	18651	6	6A
0005434604864	18652	1	1A
0005434604873	18652	2	1B
0005435904706	18652	3	2A
0005434513581	18652	4	2B
0005434513580	18652	5	3B
0005434513579	18652	6	4A
0005434604874	18652	7	5A
0005434604872	18652	8	5B
0005435904705	18652	9	6A
0005434514968	18652	10	6B
0005432649408	4110	1	1A
0005432632740	4110	2	1D
0005432649412	4110	3	1F
0005435844304	4110	4	2D
0005432649399	4110	5	2F
0005432632752	4110	6	3C
0005432632738	4110	7	4A
0005432632746	4110	8	4C
0005435846214	4110	9	4D
0005432649406	4110	10	4E
0005432649395	4110	11	5C
0005435846226	4110	12	5D
0005432632754	4110	13	5E
0005432649401	4110	14	5F
0005435846217	4110	15	6A
0005435844281	4110	16	6C
0005435844275	4110	17	6D
0005435844283	4110	18	6E
0005432632734	4110	19	6F
0005435846233	4110	20	7A
0005432632737	4110	21	7E
0005432649398	4110	22	7F
0005435844276	4110	23	8A
0005432649397	4110	24	8D
0005435846215	4110	25	8F
0005432632742	4110	26	9C
0005432649402	4110	27	9D
0005432649405	4110	28	9E
0005435846232	4110	29	9F
0005432649407	4110	30	10C
0005432632743	4110	31	10E
0005432632748	4110	32	11C
0005432649410	4110	33	11E
0005432632750	4110	34	11F
0005435844274	4110	35	12A
0005432649413	4110	36	12C
0005432649411	4110	37	12F
0005435846213	4110	38	13A
0005432632736	4110	39	13C
0005432632751	4110	40	13D
0005432649409	4110	41	13E
0005432632741	4110	42	14A
0005432649404	4110	43	14C
0005432649403	4110	44	14E
0005432632744	4110	45	15A
0005432632747	4110	46	15C
0005432632753	4110	47	15D
0005435844278	4110	48	15F
0005435846225	4110	49	16C
0005435844284	4110	50	16E
0005432649400	4110	51	17A
0005432632749	4110	52	17C
0005432632733	4110	53	17E
0005435846209	4110	54	18D
0005435844271	4110	55	18E
0005432632745	4110	56	18F
0005432649396	4110	57	19C
0005432632735	4110	58	19F
0005435846208	4110	59	20A
0005432632739	4110	60	20E
0005435844277	4110	61	20F
0005433008301	1879	1	1A
0005433008111	1879	2	1D
0005433810554	1879	3	1F
0005433008420	1879	4	2A
0005433008471	1879	5	2C
0005433285038	1879	6	2D
0005433285173	1879	7	2F
0005433008197	1879	8	3A
0005433008305	1879	9	3C
0005433008115	1879	10	3D
0005432295882	1879	11	3F
0005433008096	1879	12	4C
0005433008421	1879	13	4E
0005433008419	1879	14	4F
0005433008327	1879	15	5C
0005433285016	1879	16	5D
0005433008362	1879	17	5E
0005433008160	1879	18	5F
0005433810552	1879	19	6A
0005433284971	1879	20	6C
0005433285077	1879	21	6D
0005433008475	1879	22	6E
0005433285057	1879	23	6F
0005433285078	1879	24	7A
0005433810550	1879	25	7C
0005433008470	1879	26	7D
0005433008377	1879	27	7E
0005433285058	1879	28	7F
0005433008408	1879	29	8A
0005433008313	1879	30	8C
0005433008256	1879	31	8F
0005433285018	1879	32	9A
0005433008237	1879	33	9C
0005433008294	1879	34	9D
0005433285000	1879	35	9E
0005433285170	1879	36	9F
0005433285025	1879	37	10A
0005433810551	1879	38	10C
0005433008378	1879	39	10D
0005433008312	1879	40	10E
0005433008215	1879	41	10F
0005433008196	1879	42	11A
0005433008329	1879	43	11C
0005433285096	1879	44	11D
0005433008159	1879	45	11E
0005433008398	1879	46	11F
0005432295881	1879	47	12A
0005433285011	1879	48	12C
0005433285049	1879	49	12D
0005433008418	1879	50	12F
0005433008195	1879	51	13C
0005433008220	1879	52	13D
0005433285172	1879	53	13E
0005433008097	1879	54	13F
0005433285048	1879	55	14A
0005433008416	1879	56	14C
0005433008269	1879	57	14F
0005433008466	1879	58	15A
0005433285129	1879	59	15C
0005433008292	1879	60	15F
0005433285150	1879	61	16A
0005433008098	1879	62	16C
0005433008236	1879	63	16E
0005433008303	1879	64	16F
0005433810553	1879	65	17A
0005433285127	1879	66	17C
0005433008271	1879	67	17D
0005433008330	1879	68	17E
0005433285079	1879	69	17F
0005433008255	1879	70	18A
0005433008293	1879	71	18C
0005433284970	1879	72	18D
0005433284972	1879	73	18E
0005433008275	1879	74	18F
0005433008518	1879	75	19A
0005433008361	1879	76	19D
0005433008304	1879	77	19E
0005433008424	1879	78	19F
0005433008270	1879	79	20A
0005433284993	1879	80	20C
0005433008221	1879	81	20D
0005433285171	1879	82	20E
0005433008158	1879	83	20F
0005433285308	22534	1	1A
0005433008640	22534	2	1C
0005433285303	22534	3	1F
0005433285306	22534	4	2A
0005433285296	22534	5	2C
0005433285295	22534	6	2D
0005433285316	22534	7	2F
0005433008633	22534	8	3A
0005433285307	22534	9	3C
0005433008651	22534	10	3D
0005433008634	22534	11	3F
0005433008643	22534	12	4A
0005433285299	22534	13	4D
0005433285312	22534	14	4E
0005433008619	22534	15	4F
0005433008638	22534	16	5C
0005433008654	22534	17	5D
0005433008637	22534	18	5E
0005433008622	22534	19	5F
0005433810494	22534	20	6A
0005433008629	22534	21	6D
0005433285310	22534	22	6E
0005433285300	22534	23	6F
0005433285324	22534	24	7A
0005433008625	22534	25	7C
0005433008621	22534	26	7D
0005433285301	22534	27	7E
0005433008655	22534	28	8C
0005433008656	22534	29	8D
0005433285298	22534	30	8E
0005433008648	22534	31	9A
0005433008645	22534	32	9D
0005433285302	22534	33	9E
0005433285321	22534	34	9F
0005433008613	22534	35	10A
0005433008623	22534	36	10C
0005433008653	22534	37	10D
0005433008639	22534	38	10E
0005433008628	22534	39	10F
0005433285319	22534	40	11A
0005433008627	22534	41	11D
0005433285305	22534	42	11F
0005433285326	22534	43	12A
0005433008615	22534	44	12C
0005433285314	22534	45	12D
0005433008636	22534	46	12E
0005433008618	22534	47	13A
0005433810507	22534	48	13C
0005433285315	22534	49	13D
0005433008652	22534	50	13E
0005433285309	22534	51	13F
0005433285318	22534	52	14A
0005433008624	22534	53	14C
0005433008631	22534	54	14D
0005433285323	22534	55	14E
0005433008642	22534	56	14F
0005433008611	22534	57	15A
0005433285311	22534	58	15C
0005433285325	22534	59	15D
0005433008635	22534	60	15F
0005433008649	22534	61	16A
0005433008650	22534	62	16C
0005433008647	22534	63	16D
0005433008617	22534	64	16E
0005433008646	22534	65	17A
0005433008620	22534	66	17C
0005433285317	22534	67	17D
0005433008632	22534	68	17E
0005433008630	22534	69	18A
0005433008612	22534	70	18D
0005433285297	22534	71	18E
0005433285322	22534	72	18F
0005433008616	22534	73	19A
0005433285320	22534	74	19C
0005433008626	22534	75	19E
0005433008644	22534	76	19D
0005433008614	22534	77	20C
0005433008641	22534	78	20D
0005433285313	22534	79	20E
0005433285304	22534	80	20F
0005433846768	5558	1	1C
0005433846778	5558	2	1A
0005433846787	5558	3	1F
0005434173483	5558	4	1D
0005433846769	5558	5	2C
0005435282349	5558	6	2A
0005433846762	5558	7	2D
0005433846750	5558	8	2F
0005433846780	5558	9	3D
0005435282476	5558	10	3C
0005433846789	5558	11	4A
0005433846746	5558	12	3F
0005433846794	5558	13	4D
0005433815384	5558	14	4C
0005435282338	5558	15	4F
0005435282295	5558	16	5C
0005433846763	5558	17	5A
0005435282291	5558	18	5F
0005433846770	5558	19	5D
0005432081515	5558	20	6B
0005435282372	5558	21	6A
0005433815385	5558	22	6D
0005435282381	5558	23	6C
0005433846785	5558	24	6E
0005433846744	5558	25	7A
0005433846777	5558	26	6F
0005433846755	5558	27	7C
0005433846767	5558	28	7B
0005433846774	5558	29	7E
0005433846757	5558	30	7D
0005433846781	5558	31	8A
0005435282362	5558	32	7F
0005432081517	5558	33	8D
0005433846740	5558	34	8C
0005433846795	5558	35	8F
0005433846752	5558	36	8E
0005433846742	5558	37	9B
0005432081516	5558	38	9A
0005433846751	5558	39	9C
0005433846793	5558	40	9E
0005435282323	5558	41	9D
0005433846790	5558	42	10A
0005435282322	5558	43	9F
0005433846754	5558	44	10C
0005433846782	5558	45	10B
0005434173478	5558	46	10E
0005433846776	5558	47	10D
0005433846788	5558	48	10F
0005435282361	5558	49	11C
0005433815386	5558	50	11B
0005433846783	5558	51	11A
0005433846772	5558	52	11D
0005433846773	5558	53	11E
0005435282483	5558	54	12B
0005433846775	5558	55	12A
0005433846741	5558	56	12C
0005435282367	5558	57	12E
0005434173491	5558	58	12D
0005435282360	5558	59	13A
0005435282285	5558	60	12F
0005433846791	5558	61	13C
0005433846759	5558	62	13B
0005435282281	5558	63	13E
0005433846771	5558	64	13D
0005433846792	5558	65	13F
0005433846765	5558	66	14C
0005433846761	5558	67	14B
0005435282359	5558	68	14A
0005433846779	5558	69	14D
0005435282294	5558	70	14F
0005435282292	5558	71	15B
0005435282366	5558	72	15D
0005435282280	5558	73	15F
0005432081514	5558	74	16B
0005435282390	5558	75	16A
0005433846797	5558	76	16C
0005433846760	5558	77	16F
0005432081518	5558	78	17B
0005433846748	5558	79	17A
0005435282482	5558	80	17D
0005433846764	5558	81	17C
0005435282477	5558	82	17F
0005434173490	5558	83	17E
0005433846739	5558	84	18B
0005435282277	5558	85	18C
0005433846756	5558	86	18F
0005433846747	5558	87	18E
0005433815387	5558	88	18D
0005433846799	5558	89	19A
0005435282358	5558	90	19E
0005433846743	5558	91	19D
0005433815388	5558	92	19C
0005433846766	5558	93	19F
0005433846784	5558	94	20B
0005433846745	5558	95	20A
0005433846798	5558	96	20C
0005433846749	5558	97	20F
0005433846796	5558	98	20E
0005435282365	5558	99	20D
0005435282475	5558	100	21A
0005433846758	5558	101	21B
0005433846786	5558	102	21E
0005433846753	5558	103	21F
0005433846262	13879	1	1A
0005433846263	13879	2	1F
0005433846348	13879	3	1D
0005433846189	13879	4	2A
0005435282542	13879	5	3A
0005433815325	13879	6	2F
0005433846332	13879	7	3D
0005432003704	13879	8	3C
0005432003705	13879	9	4A
0005435282530	13879	10	3F
0005433846223	13879	11	4C
0005433846534	13879	12	4F
0005433846144	13879	13	4D
0005435282543	13879	14	5C
0005434173523	13879	15	5F
0005433846381	13879	16	5D
0005433846403	13879	17	6B
0005433845916	13879	18	6A
0005435282523	13879	19	6F
0005434173522	13879	20	6D
0005433815338	13879	21	7A
0005433846506	13879	22	7C
0005435282521	13879	23	7B
0005435282525	13879	24	7E
0005433846230	13879	25	7D
0005435282534	13879	26	8A
0005433846351	13879	27	7F
0005432003703	13879	28	8C
0005433846563	13879	29	8B
0005433846349	13879	30	8D
0005433846188	13879	31	8F
0005435282536	13879	32	8E
0005434173525	13879	33	9B
0005433846437	13879	34	9A
0005435282538	13879	35	9C
0005433846184	13879	36	9D
0005433846217	13879	37	10A
0005433846152	13879	38	10C
0005435282531	13879	39	10B
0005433846100	13879	40	10E
0005433846265	13879	41	10D
0005433846185	13879	42	11A
0005435282535	13879	43	10F
0005433846353	13879	44	11B
0005433815347	13879	45	11D
0005435282516	13879	46	11C
0005433846161	13879	47	11F
0005435282533	13879	48	11E
0005435282529	13879	49	12B
0005433815354	13879	50	12D
0005433846298	13879	51	12C
0005434173524	13879	52	12F
0005435282526	13879	53	12E
0005433846371	13879	54	13A
0005433846346	13879	55	13C
0005435282539	13879	56	13B
0005433846318	13879	57	13E
0005433846350	13879	58	13D
0005433846424	13879	59	14A
0005433846257	13879	60	13F
0005433846352	13879	61	14B
0005433846269	13879	62	14D
0005433846382	13879	63	14C
0005433846293	13879	64	14F
0005433846448	13879	65	14E
0005433846309	13879	66	15B
0005433846565	13879	67	15A
0005433846186	13879	68	15D
0005435282522	13879	69	15C
0005433846190	13879	70	15F
0005433846425	13879	71	15E
0005433846213	13879	72	16A
0005435282524	13879	73	16C
0005435282537	13879	74	16B
0005435282518	13879	75	16F
0005435282520	13879	76	17B
0005433846564	13879	77	17A
0005433846582	13879	78	17E
0005433846317	13879	79	17C
0005433846040	13879	80	17F
0005433846308	13879	81	18A
0005435282519	13879	82	18C
0005435282532	13879	83	18E
0005433846435	13879	84	18D
0005433846397	13879	85	19A
0005433846222	13879	86	18F
0005433846329	13879	87	19B
0005433846264	13879	88	19E
0005433846077	13879	89	19D
0005435282517	13879	90	19C
0005435282541	13879	91	19F
0005433846395	13879	92	20C
0005433846396	13879	93	20B
0005435282528	13879	94	20A
0005433846328	13879	95	20D
0005435282540	13879	96	20E
0005433846101	13879	97	21A
0005433846301	13879	98	20F
0005433846505	13879	99	21D
0005435282527	13879	100	21C
0005433815356	13879	101	21E
0005433846386	13879	102	21F
0005434620616	7822	1	1A
0005434620604	7822	2	1C
0005434620602	7822	3	1D
0005432112518	7822	4	2A
0005435332226	7822	5	2C
0005435332268	7822	6	3A
0005432112519	7822	7	3C
0005434620605	7822	8	3D
0005434620620	7822	9	4A
0005434620618	7822	10	4D
0005434620613	7822	11	5A
0005435332259	7822	12	5C
0005434620615	7822	13	6A
0005434620617	7822	14	6B
0005435332275	7822	15	6C
0005434620619	7822	16	7B
0005434620621	7822	17	18B
0005434620608	7822	18	18C
0005434620606	7822	19	18D
0005434620614	7822	20	19A
0005434620603	7822	21	19D
0005434620609	7822	22	20A
0005435332218	7822	23	20D
0005434620607	7822	24	21A
0005435332274	7822	25	21D
0005434620612	7822	26	22A
0005434620610	7822	27	22C
0005434620611	7822	28	22D
0005434620416	32981	1	1C
0005434620444	32981	2	1D
0005435332344	32981	3	2B
0005434620479	32981	4	2C
0005434620440	32981	5	2D
0005434620470	32981	6	3B
0005435332346	32981	7	4A
0005434620445	32981	8	4C
0005434620469	32981	9	5B
0005434620485	32981	10	5D
0005434620458	32981	11	6B
0005435332340	32981	12	6C
0005434620442	32981	13	7A
0005434620402	32981	14	7B
0005435332339	32981	15	7C
0005434620468	32981	16	7D
0005434620472	32981	17	18A
0005435332343	32981	18	18C
0005435332341	32981	19	19A
0005434620430	32981	20	19C
0005434620510	32981	21	19D
0005434620482	32981	22	20B
0005434620441	32981	23	20A
0005434620453	32981	24	20C
0005434620480	32981	25	20D
0005435332342	32981	26	21D
0005435332347	32981	27	22B
0005435332345	32981	28	22C
0005434994030	4294	1	1A
0005434994031	4294	2	1C
0005435785378	4294	3	2A
0005435785373	4294	4	2D
0005434994028	4294	5	2F
0005435785370	4294	6	3A
0005435937329	4294	7	4A
0005435787355	4294	8	4C
0005435785389	4294	9	4D
0005435785367	4294	10	5C
0005435918631	4294	11	5E
0005435787356	4294	12	6A
0005435785365	4294	13	6C
0005434994033	4294	14	6D
0005435918621	4294	15	6E
0005435785377	4294	16	7A
0005435937333	4294	17	7D
0005435785381	4294	18	7F
0005435785395	4294	19	8A
0005435785393	4294	20	8C
0005435918620	4294	21	8D
0005435785379	4294	22	8E
0005432190634	4294	23	8F
0005435785387	4294	24	9A
0005435918630	4294	25	9C
0005435785394	4294	26	9D
0005435785372	4294	27	9E
0005435785383	4294	28	9F
0005435937332	4294	29	10A
0005435785392	4294	30	10D
0005432190633	4294	31	10F
0005435785397	4294	32	11A
0005435785385	4294	33	11C
0005435785369	4294	34	11D
0005435785398	4294	35	11F
0005435785371	4294	36	12A
0005435785390	4294	37	12C
0005435937352	4294	38	12D
0005434994032	4294	39	12F
0005435785399	4294	40	13A
0005435785376	4294	41	13C
0005435785401	4294	42	14A
0005435785400	4294	43	14C
0005435785374	4294	44	14D
0005435785375	4294	45	14E
0005435785382	4294	46	15A
0005434994027	4294	47	15C
0005434994036	4294	48	15D
0005432190631	4294	49	15E
0005434994035	4294	50	15F
0005435785366	4294	51	16C
0005432190632	4294	52	16D
0005435918627	4294	53	16E
0005435785388	4294	54	17A
0005434994026	4294	55	17C
0005434994034	4294	56	17D
0005435785391	4294	57	19A
0005435785380	4294	58	19C
0005435937348	4294	59	19D
0005435937347	4294	60	19E
0005435785384	4294	61	19F
0005434994029	4294	62	20A
0005435785368	4294	63	20C
0005435785396	4294	64	20D
0005435785386	4294	65	20F
0005434993948	27326	1	1A
0005435785058	27326	2	1C
0005435784989	27326	3	1D
0005434993920	27326	4	1F
0005434993967	27326	5	2A
0005435785137	27326	6	3C
0005435785144	27326	7	3D
0005435784919	27326	8	4A
0005435784920	27326	9	4C
0005435784878	27326	10	4F
0005435785153	27326	11	5D
0005435785086	27326	12	5E
0005435785131	27326	13	6D
0005435785048	27326	14	6C
0005435785039	27326	15	6E
0005435785095	27326	16	7C
0005435785015	27326	17	7E
0005435787331	27326	18	7F
0005435785023	27326	19	8A
0005435787332	27326	20	8F
0005435785138	27326	21	9A
0005434993974	27326	22	9D
0005435918661	27326	23	9E
0005432195694	27326	24	9F
0005435784996	27326	25	10A
0005435785041	27326	26	10C
0005435785042	27326	27	10D
0005435784859	27326	28	10F
0005435784961	27326	29	11A
0005435918660	27326	30	11C
0005435918659	27326	31	12C
0005435785132	27326	32	12D
0005435787330	27326	33	12E
0005435785143	27326	34	12F
0005435784931	27326	35	13E
0005434993947	27326	36	13F
0005432195695	27326	37	14A
0005435785078	27326	38	14D
0005432195693	27326	39	14E
0005435918657	27326	40	15A
0005435784995	27326	41	15C
0005435785013	27326	42	15E
0005435785022	27326	43	16A
0005435784838	27326	44	16D
0005435937389	27326	45	16F
0005435784990	27326	46	17A
0005434993966	27326	47	17C
0005435784879	27326	48	17E
0005435787333	27326	49	17F
0005434993957	27326	50	18A
0005435785040	27326	51	18D
0005435785096	27326	52	18E
0005432195692	27326	53	18F
0005435918658	27326	54	19A
0005435784791	27326	55	20D
0005432146200	19850	1	4D
0005432146199	19850	2	7A
0005434081924	4725	1	1A
0005432567690	4725	2	1C
0005432567696	4725	3	1B
0005432567685	4725	4	1F
0005432567691	4725	5	2A
0005432459916	4725	6	1H
0005432567708	4725	7	2C
0005432459867	4725	8	2B
0005432567667	4725	9	2F
0005432567710	4725	10	2G
0005433451621	4725	11	3A
0005432567669	4725	12	3C
0005432459878	4725	13	3G
0005432567659	4725	14	3F
0005432459897	4725	15	4A
0005433726105	4725	16	3H
0005432567701	4725	17	4F
0005432567673	4725	18	4C
0005432459864	4725	19	4G
0005432170389	4725	20	5A
0005432459894	4725	21	4H
0005432567711	4725	22	5B
0005432571326	4725	23	5F
0005432567698	4725	24	5G
0005432459884	4725	25	5H
0005432567657	4725	26	9H
0005432567684	4725	27	11B
0005432567694	4725	28	11A
0005432567695	4725	29	11E
0005432567681	4725	30	11D
0005432459868	4725	31	11F
0005432459888	4725	32	12A
0005432567709	4725	33	11H
0005432459889	4725	34	12B
0005432567665	4725	35	12E
0005434081927	4725	36	12D
0005432567688	4725	37	12G
0005434081925	4725	38	12F
0005432567656	4725	39	12H
0005432567678	4725	40	13A
0005432459902	4725	41	13F
0005432459876	4725	42	14A
0005432567652	4725	43	13H
0005432567670	4725	44	14D
0005432567671	4725	45	14F
0005434081921	4725	46	14E
0005432567692	4725	47	14H
0005434081923	4725	48	14G
0005432567675	4725	49	15E
0005432459911	4725	50	15D
0005432567674	4725	51	15G
0005432459870	4725	52	15F
0005432567699	4725	53	16A
0005432459900	4725	54	15H
0005432459874	4725	55	16B
0005432459906	4725	56	16E
0005432459904	4725	57	16F
0005432459872	4725	58	16H
0005432459908	4725	59	17B
0005432170395	4725	60	17F
0005432567700	4725	61	17G
0005432567680	4725	62	17H
0005432459915	4725	63	18D
0005432186871	4725	64	18F
0005432170390	4725	65	18E
0005432459893	4725	66	18G
0005432459891	4725	67	18H
0005432567689	4725	68	19A
0005432567668	4725	69	19F
0005432459879	4725	70	19E
0005432459892	4725	71	19G
0005432567679	4725	72	20E
0005432170394	4725	73	20G
0005432567651	4725	74	21B
0005434081920	4725	75	20H
0005432459914	4725	76	21D
0005432459912	4725	77	21E
0005432567683	4725	78	21F
0005432459901	4725	79	22B
0005432567682	4725	80	22D
0005432459890	4725	81	22G
0005432567663	4725	82	22F
0005434081926	4725	83	23A
0005432459905	4725	84	22H
0005434081918	4725	85	23D
0005432567661	4725	86	23F
0005434081922	4725	87	23G
0005432571325	4725	88	23H
0005433452742	4725	89	24B
0005432567686	4725	90	24G
0005432459883	4725	91	25D
0005432459903	4725	92	24H
0005432567713	4725	93	25E
0005432567704	4725	94	27A
0005432459896	4725	95	27B
0005432170396	4725	96	27E
0005432170392	4725	97	27H
0005432567705	4725	98	28A
0005432567655	4725	99	28D
0005432459882	4725	100	28G
0005432459917	4725	101	28F
0005432459895	4725	102	28H
0005432170391	4725	103	29A
0005432567658	4725	104	29D
0005432567664	4725	105	29E
0005432459910	4725	106	29G
0005434081919	4725	107	30B
0005433452741	4725	108	30A
0005432459881	4725	109	30D
0005432459899	4725	110	30G
0005432567687	4725	111	30H
0005432459866	4725	112	31B
0005432567712	4725	113	31D
0005432459871	4725	114	31G
0005432459885	4725	115	32B
0005433726106	4725	116	32D
0005432459887	4725	117	32F
0005432186874	4725	118	32G
0005432567693	4725	119	33A
0005432459913	4725	120	32H
0005432567702	4725	121	33D
0005432567654	4725	122	33B
0005432459880	4725	123	33E
0005432567677	4725	124	33G
0005434081928	4725	125	33F
0005432459909	4725	126	33H
0005432459869	4725	127	34A
0005432567672	4725	128	34E
0005432567660	4725	129	34F
0005432459886	4725	130	34H
0005432459873	4725	131	35B
0005432567707	4725	132	35A
0005432567706	4725	133	35E
0005432170393	4725	134	35G
0005432567697	4725	135	36B
0005432459875	4725	136	36D
0005432567676	4725	137	36F
0005432459907	4725	138	36H
0005432186872	4725	139	36G
0005432567703	4725	140	37B
0005432567653	4725	141	37D
0005432186873	4725	142	37H
0005432567666	4725	143	38B
0005432459865	4725	144	38E
0005432459877	4725	145	38G
0005433452740	4725	146	38F
0005432459898	4725	147	39E
0005432567662	4725	148	39D
0005432459334	30572	1	1A
0005432161153	30572	2	1B
0005432459363	30572	3	1F
0005432567416	30572	4	2A
0005432567252	30572	5	2C
0005432567318	30572	6	2H
0005432567317	30572	7	2G
0005434081627	30572	8	3B
0005432567033	30572	9	3C
0005432213609	30572	10	3F
0005432567248	30572	11	3H
0005432459668	30572	12	4B
0005432567171	30572	13	4G
0005432459490	30572	14	4F
0005432567412	30572	15	4H
0005432567433	30572	16	5A
0005432161154	30572	17	5F
0005432459438	30572	18	5G
0005432459669	30572	19	5H
0005433452726	30572	20	9A
0005432567219	30572	21	9G
0005432459402	30572	22	9H
0005432566895	30572	23	11B
0005432567133	30572	24	11D
0005432567445	30572	25	11E
0005432566909	30572	26	11G
0005434081667	30572	27	12E
0005432567196	30572	28	12G
0005432567169	30572	29	12F
0005432567313	30572	30	12H
0005432459437	30572	31	13D
0005434081643	30572	32	13F
0005432567367	30572	33	13E
0005432459504	30572	34	13G
0005432567186	30572	35	14E
0005434081622	30572	36	14G
0005434081669	30572	37	15A
0005432459378	30572	38	15B
0005432459523	30572	39	15E
0005432459545	30572	40	15D
0005432459288	30572	41	15H
0005432459655	30572	42	15G
0005434081601	30572	43	16B
0005432459471	30572	44	16G
0005434081645	30572	45	16H
0005433452727	30572	46	17A
0005432567312	30572	47	17D
0005432459333	30572	48	17B
0005432213610	30572	49	17E
0005434081665	30572	50	18A
0005434081688	30572	51	17H
0005432571284	30572	52	18B
0005432567168	30572	53	18D
0005432567322	30572	54	18E
0005432213608	30572	55	18H
0005432567329	30572	56	19A
0005432459184	30572	57	19E
0005432567355	30572	58	19H
0005432459677	30572	59	20B
0005432567448	30572	60	20E
0005434081670	30572	61	20F
0005432567570	30572	62	20H
0005432567315	30572	63	20G
0005434081655	30572	64	21F
0005432459450	30572	65	21H
0005432571300	30572	66	22D
0005432459578	30572	67	22B
0005432567267	30572	68	22E
0005433452724	30572	69	22G
0005432567209	30572	70	23E
0005432567220	30572	71	23H
0005432459287	30572	72	24B
0005432459579	30572	73	24A
0005432459348	30572	74	24D
0005432567178	30572	75	24F
0005432567386	30572	76	24H
0005432459514	30572	77	24G
0005432459608	30572	78	25D
0005432567166	30572	79	25E
0005432459676	30572	80	27A
0005432459609	30572	81	25F
0005432567381	30572	82	27E
0005432567270	30572	83	27D
0005432567569	30572	84	27F
0005432459515	30572	85	28A
0005432567356	30572	86	28D
0005432567179	30572	87	28B
0005432459428	30572	88	28E
0005432459618	30572	89	28G
0005432459527	30572	90	28H
0005432459654	30572	91	29E
0005434081628	30572	92	29D
0005432459441	30572	93	29F
0005433454854	30572	94	29H
0005432567055	30572	95	30B
0005432567357	30572	96	30E
0005432567284	30572	97	30F
0005432459392	30572	98	30G
0005432459269	30572	99	30H
0005432567041	30572	100	31A
0005432567253	30572	101	31D
0005432567366	30572	102	31G
0005432566949	30572	103	32A
0005432459752	30572	104	31H
0005433452728	30572	105	32B
0005434081687	30572	106	32E
0005434081666	30572	107	32D
0005432567238	30572	108	32F
0005432459449	30572	109	32H
0005432459480	30572	110	33D
0005432571294	30572	111	33B
0005432571296	30572	112	33G
0005432567247	30572	113	34B
0005434081657	30572	114	34D
0005433454855	30572	115	34E
0005432567188	30572	116	35A
0005432459401	30572	117	34H
0005432459391	30572	118	35B
0005432567167	30572	119	35D
0005432459407	30572	120	35F
0005432567050	30572	121	35G
0005432567316	30572	122	35H
0005432459619	30572	123	36B
0005432459571	30572	124	36D
0005434081658	30572	125	37A
0005434081623	30572	126	36H
0005432567413	30572	127	37E
0005432567319	30572	128	37G
0005432459572	30572	129	38A
0005432567330	30572	130	37H
0005432566947	30572	131	38E
0005432567113	30572	132	38F
0005432566896	30572	133	38H
0005432567258	30572	134	39E
0005432566948	30572	135	39D
0005432567246	30572	136	39F
0005435722057	13664	1	2B
0005435722056	13664	2	3B
0005435720127	21128	1	1A
0005435720129	21128	2	3B
0005435722039	21128	3	5B
0005435720124	21128	4	6A
0005432295882	22793	1	2A
0005432295881	22793	2	18C
0005433343305	11127	1	1A
0005435508256	11127	2	1C
0005433343311	11127	3	1F
0005433343274	11127	4	1D
0005435380262	11127	5	2A
0005435508235	11127	6	2D
0005433343275	11127	7	2C
0005435508265	11127	8	3A
0005433343251	11127	9	2F
0005433343225	11127	10	3C
0005433343257	11127	11	3F
0005433343237	11127	12	3D
0005435380269	11127	13	4B
0005433343306	11127	14	4A
0005433343228	11127	15	4C
0005433343235	11127	16	4D
0005433343256	11127	17	4E
0005433343260	11127	18	4F
0005433343218	11127	19	5B
0005433343281	11127	20	5A
0005435380261	11127	21	5C
0005433343278	11127	22	5D
0005433343246	11127	23	5E
0005433343288	11127	24	5F
0005435097203	11127	25	6B
0005433343297	11127	26	6A
0005433343255	11127	27	6C
0005435097205	11127	28	6D
0005433343270	11127	29	6F
0005435097202	11127	30	6E
0005433343262	11127	31	7A
0005433343268	11127	32	7C
0005433343243	11127	33	7B
0005435097201	11127	34	7E
0005435380238	11127	35	7D
0005433343244	11127	36	7F
0005433343214	11127	37	8A
0005435097207	11127	38	8B
0005433343226	11127	39	8C
0005433343310	11127	40	8E
0005435508237	11127	41	8D
0005433343282	11127	42	8F
0005433343247	11127	43	9A
0005433343312	11127	44	9B
0005433343285	11127	45	9D
0005433343263	11127	46	9C
0005433343248	11127	47	9E
0005433343266	11127	48	9F
0005433343279	11127	49	10B
0005435380253	11127	50	10C
0005433343294	11127	51	10D
0005435508225	11127	52	11A
0005433343240	11127	53	10E
0005433343304	11127	54	11B
0005433343264	11127	55	11D
0005435097199	11127	56	11C
0005433343283	11127	57	11F
0005433343291	11127	58	12B
0005433343302	11127	59	12A
0005433343286	11127	60	12C
0005433343271	11127	61	12D
0005433343234	11127	62	12E
0005433343245	11127	63	12F
0005433343284	11127	64	13A
0005433343280	11127	65	13B
0005433343242	11127	66	13D
0005433343287	11127	67	13C
0005433343308	11127	68	13E
0005433343249	11127	69	14A
0005433343307	11127	70	13F
0005433343219	11127	71	14C
0005433343254	11127	72	14B
0005433343232	11127	73	14D
0005433343241	11127	74	14E
0005433343215	11127	75	14F
0005433343230	11127	76	15B
0005433343293	11127	77	15A
0005433343303	11127	78	15C
0005433343261	11127	79	15E
0005433343229	11127	80	15D
0005433343238	11127	81	15F
0005433343290	11127	82	16A
0005433343236	11127	83	16B
0005433343269	11127	84	16C
0005433343300	11127	85	16D
0005435508263	11127	86	16E
0005433343299	11127	87	17A
0005433343223	11127	88	16F
0005433343222	11127	89	17B
0005433343231	11127	90	17C
0005433343295	11127	91	17E
0005433343265	11127	92	17D
0005433343292	11127	93	17F
0005433343313	11127	94	18A
0005433343277	11127	95	18B
0005433343252	11127	96	18C
0005433343273	11127	97	18E
0005433343296	11127	98	18D
0005433343233	11127	99	19B
0005435097206	11127	100	19A
0005433343217	11127	101	19D
0005433343298	11127	102	19C
0005433343239	11127	103	19E
0005433343267	11127	104	19F
0005433343227	11127	105	20A
0005433343216	11127	106	20B
0005433343220	11127	107	20D
0005435508264	11127	108	20C
0005435508238	11127	109	20E
0005433343289	11127	110	20F
0005435508248	11127	111	21B
0005433343258	11127	112	21A
0005433343309	11127	113	21C
0005435097204	11127	114	21D
0005435380252	11127	115	21E
0005433343253	11127	116	22A
0005433343213	11127	117	21F
0005433343259	11127	118	22C
0005433343224	11127	119	22B
0005433343276	11127	120	22D
0005435380250	11127	121	22E
0005433343301	11127	122	23A
0005433343250	11127	123	22F
0005435508249	11127	124	23B
0005435097200	11127	125	23D
0005433343221	11127	126	23C
0005433343272	11127	127	23E
0005435508215	11127	128	23F
0005435545741	17131	1	1A
0005433342366	17131	2	1C
0005433342286	17131	3	1D
0005433341910	17131	4	1F
0005435097118	17131	5	2C
0005433341919	17131	6	2A
0005435545747	17131	7	2D
0005433342550	17131	8	2F
0005435545745	17131	9	3C
0005435545749	17131	10	3A
0005433341927	17131	11	3D
0005435380300	17131	12	3F
0005435380303	17131	13	4B
0005435545743	17131	14	4A
0005435545742	17131	15	4D
0005433341935	17131	16	4C
0005435097088	17131	17	4E
0005435380304	17131	18	5A
0005433342395	17131	19	4F
0005433342446	17131	20	5B
0005433342282	17131	21	5C
0005433342423	17131	22	5D
0005435545744	17131	23	5E
0005433342269	17131	24	6A
0005435380301	17131	25	5F
0005433342160	17131	26	6B
0005433342241	17131	27	6C
0005433342507	17131	28	6D
0005433342038	17131	29	6E
0005433341947	17131	30	7A
0005433342495	17131	31	6F
0005433341926	17131	32	7B
0005433342325	17131	33	7C
0005433342082	17131	34	7D
0005433342494	17131	35	7E
0005433342591	17131	36	8A
0005435097138	17131	37	7F
0005433342512	17131	38	8B
0005433342047	17131	39	8C
0005435380299	17131	40	8E
0005433342479	17131	41	8D
0005435545751	17131	42	9A
0005433342310	17131	43	8F
0005433342430	17131	44	9B
0005435097132	17131	45	9D
0005433342469	17131	46	9C
0005433342560	17131	47	9F
0005433342145	17131	48	9E
0005433342358	17131	49	10B
0005433342792	17131	50	10D
0005433342539	17131	51	10C
0005435097140	17131	52	10E
0005433342444	17131	53	11A
0005432293210	17131	54	11C
0005433342579	17131	55	11B
0005433341909	17131	56	11D
0005435097125	17131	57	11E
0005433342285	17131	58	11F
0005433342681	17131	59	12A
0005433342126	17131	60	12B
0005433342306	17131	61	12C
0005433341820	17131	62	12E
0005433341906	17131	63	12D
0005433341939	17131	64	12F
0005433342340	17131	65	13A
0005433342003	17131	66	13B
0005433341733	17131	67	13C
0005433342359	17131	68	13E
0005433342127	17131	69	13D
0005433342258	17131	70	13F
0005433342246	17131	71	14B
0005433342324	17131	72	14A
0005433342553	17131	73	14C
0005433342713	17131	74	14E
0005433342508	17131	75	14D
0005433341819	17131	76	14F
0005433342139	17131	77	15B
0005433342570	17131	78	15A
0005433342429	17131	79	15C
0005433342161	17131	80	15D
0005435097117	17131	81	15E
0005435380302	17131	82	16A
0005433342039	17131	83	16B
0005433342518	17131	84	16C
0005433342094	17131	85	16E
0005433342830	17131	86	16D
0005433342305	17131	87	16F
0005433342474	17131	88	17A
0005433342116	17131	89	17B
0005433342284	17131	90	17C
0005433342402	17131	91	17D
0005433342422	17131	92	17F
0005433342433	17131	93	17E
0005433342552	17131	94	18A
0005433342332	17131	95	18B
0005433342104	17131	96	18D
0005433341907	17131	97	18C
0005433342304	17131	98	18E
0005433342095	17131	99	18F
0005433342144	17131	100	19B
0005432293211	17131	101	19A
0005435097139	17131	102	19D
0005433342156	17131	103	19C
0005433342561	17131	104	19E
0005433342445	17131	105	20A
0005433342272	17131	106	20C
0005433342506	17131	107	20B
0005433342481	17131	108	20D
0005433342480	17131	109	20E
0005435545750	17131	110	21A
0005433342714	17131	111	20F
0005433341934	17131	112	21B
0005435097126	17131	113	21C
0005433342171	17131	114	21D
0005435545746	17131	115	21F
0005433342360	17131	116	22A
0005433342379	17131	117	22B
0005433342315	17131	118	22C
0005433342331	17131	119	22D
0005433342578	17131	120	22F
0005433342283	17131	121	22E
0005433342473	17131	122	23B
0005433341925	17131	123	23A
0005435097127	17131	124	23C
0005435545748	17131	125	23D
0005433342401	17131	126	23E
0005433341908	17131	127	23F
0005433507210	9070	1	1A
0005433507203	9070	2	1C
0005433507208	9070	3	1F
0005432919600	9070	4	2D
0005433507204	9070	5	2F
0005433481177	9070	6	3D
0005433507200	9070	7	4A
0005432919662	9070	8	5C
0005433481173	9070	9	5D
0005433507211	9070	10	5E
0005433481171	9070	11	5F
0005433507197	9070	12	6A
0005432919722	9070	13	6C
0005433481172	9070	14	6E
0005432919733	9070	15	7A
0005432919777	9070	16	7C
0005432919692	9070	17	7D
0005434158957	9070	18	7E
0005433507202	9070	19	7F
0005433507193	9070	20	8E
0005433507207	9070	21	8F
0005433507196	9070	22	9A
0005432919684	9070	23	9C
0005433507206	9070	24	9D
0005432919778	9070	25	9F
0005432919707	9070	26	10A
0005433481178	9070	27	10F
0005433481175	9070	28	11A
0005433481174	9070	29	11C
0005432919686	9070	30	11E
0005432919664	9070	31	12C
0005434158963	9070	32	12F
0005432919723	9070	33	13A
0005433507191	9070	34	13D
0005433507195	9070	35	13F
0005432919658	9070	36	14C
0005432919694	9070	37	14E
0005432919769	9070	38	15A
0005432919663	9070	39	15D
0005432919717	9070	40	15F
0005433507201	9070	41	16A
0005433507209	9070	42	16C
0005433507198	9070	43	16E
0005433507194	9070	44	17A
0005433507199	9070	45	17C
0005432919728	9070	46	18C
0005433481176	9070	47	18F
0005432919797	9070	48	19A
0005433507205	9070	49	19E
0005433507192	9070	50	20A
0005432919798	9070	51	20C
0005432919907	20474	1	1A
0005433507023	20474	2	1C
0005433507057	20474	3	1F
0005434158976	20474	4	2A
0005433507084	20474	5	2C
0005432919890	20474	6	2F
0005433507031	20474	7	3C
0005433507110	20474	8	3D
0005433507148	20474	9	4C
0005432919898	20474	10	4D
0005432919896	20474	11	4E
0005433481144	20474	12	5C
0005433507062	20474	13	5D
0005432919891	20474	14	5E
0005434158975	20474	15	5F
0005434158977	20474	16	6C
0005432919895	20474	17	7C
0005433507109	20474	18	8C
0005433481123	20474	19	8D
0005433507083	20474	20	8E
0005432919906	20474	21	9C
0005433481108	20474	22	9D
0005433507052	20474	23	9E
0005433507013	20474	24	10A
0005432919908	20474	25	10D
0005433507078	20474	26	10F
0005432919894	20474	27	11A
0005432919904	20474	28	11D
0005432919905	20474	29	11F
0005433481120	20474	30	12C
0005432919903	20474	31	12D
0005433507082	20474	32	13C
0005432919901	20474	33	14A
0005432919888	20474	34	13F
0005433507066	20474	35	14D
0005433507122	20474	36	14E
0005433507077	20474	37	15A
0005433507034	20474	38	15D
0005433507089	20474	39	15E
0005432919897	20474	40	16E
0005432919899	20474	41	16F
0005433507051	20474	42	17D
0005433507111	20474	43	18A
0005433506988	20474	44	18C
0005433507087	20474	45	18D
0005432919893	20474	46	18E
0005432919900	20474	47	18F
0005433507065	20474	48	19C
0005432919902	20474	49	19D
0005432919892	20474	50	19E
0005432919889	20474	51	19F
0005433507030	20474	52	20A
0005433481083	20474	53	20E
0005432394102	10184	1	1A
0005432396242	10184	2	1B
0005432394103	10184	3	2A
0005432394104	10184	4	3A
0005435179690	10184	5	3B
0005432394106	10184	6	4B
0005432394105	10184	7	5B
0005432396243	10184	8	6A
0005432396244	10184	9	6B
0005432396219	18296	1	1A
0005432396204	18296	2	1B
0005432396205	18296	3	2B
0005432396206	18296	4	3A
0005432400084	18296	5	3B
0005432400083	18296	6	4A
0005432396213	18296	7	4B
0005432400082	18296	8	5A
0005432396209	18296	9	5B
0005432396208	18296	10	6A
0005432396214	18296	11	6B
0005435125988	10949	1	1C
0005435626020	10949	2	1D
0005435125981	10949	3	1F
0005435125987	10949	4	2C
0005435126090	10949	5	2D
0005435125924	10949	6	3A
0005435125982	10949	7	3F
0005435126059	10949	8	4A
0005435626025	10949	9	4C
0005435125953	10949	10	4D
0005435626021	10949	11	4E
0005435626022	10949	12	4F
0005435126078	10949	13	5F
0005435126064	10949	14	6A
0005435126071	10949	15	6E
0005435625980	10949	16	6D
0005434928301	10949	17	6F
0005434411781	10949	18	7A
0005434411782	10949	19	7D
0005435625917	10949	20	7F
0005435625989	10949	21	8A
0005435125954	10949	22	8C
0005435126009	10949	23	8D
0005435626011	10949	24	8E
0005435126099	10949	25	8F
0005435126149	10949	26	9A
0005435126000	10949	27	9C
0005435626036	10949	28	9D
0005435125965	10949	29	9E
0005435554164	10949	30	9F
0005435126199	10949	31	10A
0005435126198	10949	32	10C
0005435626023	10949	33	10D
0005435626018	10949	34	10F
0005435125949	10949	35	11A
0005435626001	10949	36	11C
0005435125835	10949	37	11D
0005434928303	10949	38	11F
0005435126228	10949	39	12A
0005434928302	10949	40	12C
0005435126049	10949	41	12E
0005435625953	10949	42	12F
0005435126142	10949	43	13A
0005435626000	10949	44	13C
0005435125923	10949	45	13D
0005435126015	10949	46	13E
0005435126020	10949	47	13F
0005435125966	10949	48	14C
0005435125719	10949	49	14D
0005435556671	10949	50	14E
0005435626024	10949	51	15A
0005435126069	10949	52	15C
0005435125916	10949	53	15D
0005435125952	10949	54	15E
0005435126089	10949	55	15F
0005435126115	10949	56	16A
0005435626014	10949	57	16C
0005435126145	10949	58	16D
0005434411783	10949	59	16E
0005434928304	10949	60	17A
0005435126050	10949	61	17C
0005435626016	10949	62	17F
0005435125948	10949	63	18A
0005435125877	10949	64	18C
0005435625981	10949	65	18E
0005435126048	10949	66	18F
0005435125933	10949	67	19A
0005435626030	10949	68	19C
0005435125893	10949	69	19D
0005435626010	10949	70	19E
0005435625993	10949	71	19F
0005435125892	10949	72	20A
0005434411784	10949	73	20D
0005435554140	10949	74	20E
0005435126008	10949	75	20F
0005434411748	14716	1	1A
0005435126423	14716	2	1C
0005435126410	14716	3	1F
0005435126400	14716	4	2A
0005435126403	14716	5	2C
0005435126431	14716	6	2D
0005435126419	14716	7	2F
0005435126435	14716	8	3A
0005434411744	14716	9	3C
0005435126424	14716	10	3D
0005435126433	14716	11	3F
0005435126402	14716	12	4C
0005435126401	14716	13	4E
0005435626175	14716	14	4F
0005435626181	14716	15	5A
0005435554190	14716	16	5C
0005435626191	14716	17	5E
0005435126404	14716	18	5F
0005435556696	14716	19	6A
0005435126411	14716	20	6D
0005435126426	14716	21	6E
0005435126436	14716	22	6F
0005435554191	14716	23	7A
0005434411764	14716	24	7C
0005435126432	14716	25	7D
0005435626186	14716	26	8A
0005435126417	14716	27	8C
0005435126413	14716	28	8D
0005435126405	14716	29	8E
0005435126408	14716	30	8F
0005435126421	14716	31	9A
0005435126415	14716	32	9C
0005435626184	14716	33	9F
0005435126434	14716	34	10C
0005435626180	14716	35	10D
0005435126407	14716	36	10E
0005435556695	14716	37	11A
0005435626178	14716	38	11D
0005435556693	14716	39	11E
0005435626177	14716	40	11F
0005435126409	14716	41	12C
0005435126420	14716	42	12F
0005435626190	14716	43	13C
0005435126428	14716	44	13D
0005435554188	14716	45	14A
0005435126416	14716	46	14C
0005435626183	14716	47	14E
0005435126418	14716	48	14F
0005435126422	14716	49	15D
0005435626189	14716	50	15E
0005435626187	14716	51	15F
0005435626188	14716	52	16A
0005435626174	14716	53	16C
0005435126406	14716	54	16E
0005435126425	14716	55	16F
0005435556694	14716	56	17A
0005435126412	14716	57	17C
0005435126397	14716	58	17D
0005435626176	14716	59	17F
0005435626192	14716	60	18A
0005435126399	14716	61	18C
0005435126427	14716	62	18D
0005435626185	14716	63	18F
0005435126398	14716	64	19A
0005435126429	14716	65	19C
0005435126396	14716	66	19E
0005435626182	14716	67	19F
0005435126437	14716	68	20A
0005435626179	14716	69	20C
0005435126430	14716	70	20D
0005435126414	14716	71	20E
0005435554189	14716	72	20F
0005434928278	14717	1	7E
0005434928279	14717	2	8C
0005435219188	7113	1	1A
0005432400128	7113	2	1F
0005435715484	7113	3	2A
0005435715489	7113	4	2D
0005432400126	7113	5	2F
0005435178483	7113	6	3D
0005435443259	7113	7	3F
0005435443190	7113	8	4E
0005432398201	7113	9	4D
0005435715491	7113	10	5C
0005435715486	7113	11	6A
0005435221044	7113	12	7A
0005435715493	7113	13	8A
0005432398200	7113	14	9C
0005435216574	7113	15	9D
0005432398203	7113	16	9E
0005435715483	7113	17	11A
0005432400129	7113	18	11C
0005435443268	7113	19	11D
0005432398202	7113	20	11E
0005435715490	7113	21	12A
0005435443282	7113	22	12D
0005435715487	7113	23	13A
0005435715481	7113	24	13E
0005435715479	7113	25	13F
0005435715482	7113	26	14F
0005435443257	7113	27	15C
0005435715480	7113	28	15D
0005435715478	7113	29	15E
0005432400127	7113	30	15F
0005435443189	7113	31	16C
0005435221045	7113	32	16E
0005435443204	7113	33	17C
0005432400130	7113	34	17E
0005435715492	7113	35	18C
0005435715477	7113	36	19C
0005435715488	7113	37	19E
0005435715485	7113	38	20D
0005435178992	27059	1	1C
0005435216587	27059	2	1D
0005432394056	27059	3	2A
0005435217714	27059	4	2C
0005435443327	27059	5	2D
0005435715398	27059	6	3D
0005435715329	27059	7	3F
0005435216590	27059	8	4C
0005435217712	27059	9	4D
0005435715298	27059	10	4E
0005435715343	27059	11	5A
0005435216585	27059	12	5C
0005435443323	27059	13	6E
0005435217709	27059	14	6F
0005435217711	27059	15	7A
0005435715349	27059	16	7D
0005435715363	27059	17	8C
0005432394058	27059	18	8E
0005435715301	27059	19	8F
0005432398170	27059	20	9C
0005435715351	27059	21	9D
0005435178497	27059	22	9F
0005432398169	27059	23	10C
0005435216591	27059	24	10D
0005435443321	27059	25	10E
0005435443325	27059	26	10F
0005435715353	27059	27	11A
0005435218113	27059	28	11C
0005435715278	27059	29	11D
0005435218115	27059	30	12A
0005435715355	27059	31	12C
0005435715345	27059	32	12D
0005435715367	27059	33	12E
0005435715330	27059	34	12F
0005435715344	27059	35	13A
0005435217715	27059	36	13E
0005435216589	27059	37	13F
0005435443326	27059	38	14A
0005432394076	27059	39	14D
0005435216586	27059	40	15A
0005435715300	27059	41	15C
0005435178495	27059	42	15D
0005435216588	27059	43	15E
0005435443320	27059	44	16A
0005435715277	27059	45	16C
0005435443319	27059	46	16D
0005435443324	27059	47	16F
0005435715352	27059	48	17A
0005435217713	27059	49	17D
0005435178496	27059	50	17E
0005435715279	27059	51	17F
0005435443322	27059	52	18C
0005432394055	27059	53	18E
0005432394075	27059	54	18F
0005435715324	27059	55	19A
0005432394057	27059	56	19D
0005435217710	27059	57	19E
0005435715328	27059	58	19F
0005435218114	27059	59	20C
0005435715361	27059	60	20D
0005434084934	2748	1	1A
0005433060390	2748	2	1B
0005433060384	2748	3	2B
0005434084935	2748	4	3A
0005434084936	2748	5	4A
0005434084933	2748	6	6A
0005433060396	2748	7	6B
0005434084887	28487	1	1A
0005434084891	28487	2	2A
0005434084877	28487	3	1B
0005433060415	28487	4	2B
0005434084888	28487	5	3A
0005434084902	28487	6	3B
0005433060416	28487	7	4A
0005434084875	28487	8	4B
0005433060417	28487	9	5A
0005433060414	28487	10	5B
0005434084901	28487	11	6A
0005434084876	28487	12	6B
0005433788216	11167	1	1B
0005433788210	11167	2	2C
0005433788208	11167	3	3B
0005435548427	11167	4	3D
0005433788207	11167	5	4A
0005435548440	11167	6	4C
0005435548452	11167	7	5A
0005435548449	11167	8	5B
0005433788215	11167	9	5C
0005433788213	11167	10	6A
0005435548467	11167	11	6C
0005433788206	11167	12	6D
0005435548453	11167	13	18A
0005435548464	11167	14	18B
0005433788209	11167	15	18C
0005433788211	11167	16	18D
0005435548428	11167	17	19B
0005433788214	11167	18	19D
0005435548454	11167	19	20C
0005435548444	11167	20	21C
0005433788212	11167	21	22A
0005433788218	11167	22	22B
0005433788217	11167	23	22C
0005435548448	11167	24	23A
0005435548460	11167	25	23B
0005433788153	20679	1	1A
0005433788149	20679	2	1B
0005435548490	20679	3	1C
0005433788184	20679	4	1D
0005435548497	20679	5	2A
0005433788159	20679	6	2B
0005435548496	20679	7	2C
0005433788151	20679	8	2D
0005433788175	20679	9	3A
0005435548489	20679	10	3B
0005433788170	20679	11	3C
0005435548487	20679	12	3D
0005435548501	20679	13	4A
0005435548488	20679	14	4C
0005433788173	20679	15	4D
0005433788168	20679	16	5A
0005435548503	20679	17	5B
0005435548500	20679	18	5D
0005433788157	20679	19	6A
0005435548504	20679	20	6B
0005435548499	20679	21	6C
0005435548491	20679	22	6D
0005433788177	20679	23	7B
0005433788150	20679	24	7C
0005433788165	20679	25	7D
0005433788155	20679	26	18B
0005433788156	20679	27	18C
0005435548492	20679	28	18D
0005433788172	20679	29	19B
0005435548486	20679	30	19C
0005433788152	20679	31	19D
0005433788140	20679	32	20A
0005435548484	20679	33	20B
0005435548502	20679	34	20C
0005435548494	20679	35	20D
0005435548485	20679	36	21B
0005435548495	20679	37	21C
0005433788183	20679	38	21D
0005433788174	20679	39	22A
0005435548498	20679	40	22B
0005433788160	20679	41	22C
0005433788167	20679	42	22D
0005435548493	20679	43	23A
0005433788171	20679	44	23B
0005435540713	11376	1	1D
0005435540847	11376	2	1F
0005435540856	11376	3	3A
0005435540782	11376	4	3F
0005435540821	11376	5	4A
0005435517808	11376	6	4C
0005435540828	11376	7	4E
0005435540898	11376	8	5A
0005435517815	11376	9	5F
0005435540916	11376	10	6A
0005435540845	11376	11	6D
0005435517816	11376	12	6F
0005435540758	11376	13	7C
0005435540806	11376	14	7D
0005435540865	11376	15	7E
0005435540843	11376	16	7F
0005435540841	11376	17	8F
0005435540829	11376	18	9F
0005435540869	11376	19	10C
0005435540822	11376	20	10D
0005435517752	11376	21	11D
0005435540810	11376	22	11E
0005435517866	11376	23	12A
0005435517779	11376	24	12D
0005435540712	11376	25	12E
0005435540846	11376	26	12F
0005435517781	11376	27	13C
0005435540937	11376	28	13D
0005435517787	11376	29	13E
0005435517753	11376	30	14C
0005435540844	11376	31	14D
0005435540842	11376	32	15A
0005435517809	11376	33	15D
0005435517806	11376	34	15E
0005435540917	11376	35	15F
0005435517865	11376	36	16A
0005435540932	11376	37	16D
0005435540891	11376	38	16E
0005435517857	11376	39	17E
0005435517775	11376	40	17F
0005435517807	11376	41	18A
0005435540862	11376	42	18D
0005435540814	11376	43	18E
0005435517858	11376	44	19E
0005435540861	11376	45	19F
0005435540816	11376	46	20A
0005435517833	11376	47	20D
0005435540848	11376	48	20F
0005435529275	22265	1	1A
0005435541015	22265	2	1C
0005435541020	22265	3	1D
0005435541014	22265	4	1F
0005435541000	22265	5	2D
0005435541002	22265	6	2F
0005435529265	22265	7	3C
0005435529268	22265	8	3D
0005435529267	22265	9	3F
0005435541009	22265	10	4C
0005435529270	22265	11	4E
0005435529273	22265	12	4F
0005435529259	22265	13	5A
0005435529272	22265	14	6A
0005435529258	22265	15	6D
0005435529257	22265	16	6F
0005435541010	22265	17	7C
0005435541012	22265	18	8A
0005432294487	22265	19	8C
0005435541019	22265	20	8E
0005435541003	22265	21	8F
0005435529269	22265	22	9D
0005432294488	22265	23	9F
0005435529274	22265	24	10E
0005435529266	22265	25	11C
0005435541001	22265	26	12A
0005435529264	22265	27	12D
0005435529271	22265	28	12E
0005435541004	22265	29	13A
0005435541011	22265	30	13E
0005435541022	22265	31	14A
0005435529256	22265	32	14D
0005435541021	22265	33	15A
0005435541013	22265	34	15C
0005435540999	22265	35	16C
0005435541006	22265	36	16E
0005435541008	22265	37	17A
0005435529262	22265	38	17C
0005435529263	22265	39	17D
0005435529261	22265	40	17E
0005435541007	22265	41	18C
0005435529260	22265	42	18D
0005435529276	22265	43	18F
0005435541016	22265	44	19A
0005435541005	22265	45	19C
0005435541018	22265	46	19E
0005435541017	22265	47	20D
0005433400954	2307	1	1A
0005434907364	2307	2	1C
0005434907336	2307	3	1D
0005434907325	2307	4	1F
0005434907327	2307	5	2A
0005433251348	2307	6	2C
0005434907345	2307	7	2D
0005434907337	2307	8	3A
0005434907328	2307	9	3D
0005433251181	2307	10	3F
0005434907365	2307	11	4C
0005434907340	2307	12	4D
0005433251263	2307	13	4E
0005433251236	2307	14	4F
0005434907346	2307	15	5A
0005433251417	2307	16	5C
0005433251202	2307	17	5D
0005434907332	2307	18	5F
0005433251183	2307	19	6A
0005433251331	2307	20	6C
0005434907370	2307	21	6D
0005434907334	2307	22	6E
0005434907318	2307	23	6F
0005434907342	2307	24	7A
0005433251029	2307	25	7C
0005434907366	2307	26	7D
0005434907330	2307	27	7E
0005434907347	2307	28	7F
0005433251237	2307	29	8A
0005433251364	2307	30	8C
0005434907316	2307	31	8D
0005434907344	2307	32	8E
0005433251030	2307	33	8F
0005434907371	2307	34	9A
0005434907326	2307	35	9C
0005434907349	2307	36	9D
0005434907362	2307	37	9E
0005434907320	2307	38	9F
0005434907361	2307	39	10A
0005433251201	2307	40	10C
0005434907359	2307	41	10E
0005434907355	2307	42	10F
0005434907348	2307	43	11A
0005434907339	2307	44	11C
0005434907329	2307	45	11D
0005434907331	2307	46	12A
0005434907360	2307	47	12C
0005433251270	2307	48	12D
0005434907352	2307	49	12E
0005434907338	2307	50	13D
0005433251288	2307	51	13F
0005434907323	2307	52	14A
0005434907368	2307	53	14C
0005434907369	2307	54	14D
0005433251180	2307	55	14E
0005434907333	2307	56	14F
0005433251248	2307	57	15A
0005434907350	2307	58	15C
0005433251251	2307	59	15D
0005434907343	2307	60	15E
0005433251182	2307	61	16A
0005434907358	2307	62	16C
0005433251353	2307	63	16E
0005434907319	2307	64	16F
0005434907317	2307	65	17A
0005434907363	2307	66	17D
0005434907367	2307	67	17E
0005433251252	2307	68	17F
0005434907356	2307	69	18A
0005433251349	2307	70	18C
0005433251269	2307	71	18D
0005434907353	2307	72	18E
0005433251340	2307	73	18F
0005434907354	2307	74	19D
0005434907322	2307	75	19C
0005434907351	2307	76	19E
0005434907341	2307	77	19F
0005434907324	2307	78	20A
0005434907335	2307	79	20D
0005434907321	2307	80	20E
0005434907357	2307	81	20F
0005434906600	25623	1	1A
0005434906670	25623	2	1C
0005434906917	25623	3	1D
0005434906886	25623	4	1F
0005434906791	25623	5	2A
0005434906822	25623	6	2C
0005434906805	25623	7	2D
0005433400986	25623	8	2F
0005434906847	25623	9	3A
0005433251523	25623	10	3C
0005434906697	25623	11	3D
0005433251503	25623	12	3F
0005434906910	25623	13	4A
0005433400987	25623	14	4C
0005433251497	25623	15	4D
0005433251520	25623	16	4E
0005434906796	25623	17	4F
0005433251502	25623	18	5A
0005434906848	25623	19	5C
0005434906840	25623	20	5D
0005434906901	25623	21	5E
0005433251498	25623	22	5F
0005433251519	25623	23	6A
0005433251522	25623	24	6C
0005433251511	25623	25	6D
0005433251504	25623	26	6E
0005433251505	25623	27	6F
0005434906640	25623	28	7A
0005433251500	25623	29	7D
0005433251507	25623	30	7E
0005434906902	25623	31	7F
0005434906955	25623	32	8A
0005433251501	25623	33	8C
0005433251506	25623	34	8D
0005434907042	25623	35	8E
0005434906911	25623	36	8F
0005434906907	25623	37	9A
0005434906808	25623	38	9C
0005434906807	25623	39	9D
0005434906800	25623	40	9F
0005433251499	25623	41	10A
0005433251527	25623	42	10C
0005433251517	25623	43	10D
0005434906591	25623	44	10F
0005433251513	25623	45	11A
0005433251525	25623	46	11C
0005434907030	25623	47	11D
0005433400985	25623	48	11F
0005434906985	25623	49	12A
0005434906939	25623	50	12C
0005433251516	25623	51	12D
0005433251515	25623	52	12E
0005434906687	25623	53	12F
0005434907041	25623	54	13A
0005434906887	25623	55	13C
0005434906837	25623	56	13E
0005433251524	25623	57	13F
0005434906879	25623	58	14A
0005434906970	25623	59	14C
0005434906913	25623	60	14D
0005434906688	25623	61	14E
0005434906824	25623	62	15A
0005434906590	25623	63	15C
0005434906818	25623	64	15D
0005434906922	25623	65	15E
0005434906849	25623	66	15F
0005434906905	25623	67	16A
0005433251510	25623	68	16C
0005433251509	25623	69	16D
0005433251526	25623	70	16E
0005434906906	25623	71	16F
0005433400988	25623	72	17C
0005433251496	25623	73	17D
0005433251518	25623	74	17E
0005434906851	25623	75	17F
0005433251514	25623	76	18A
0005434907148	25623	77	18C
0005434906989	25623	78	18D
0005434906781	25623	79	18E
0005433251508	25623	80	18F
0005434907025	25623	81	19C
0005434906762	25623	82	19D
0005433251512	25623	83	19E
0005434906954	25623	84	19F
0005433251521	25623	85	20A
0005434907031	25623	86	20C
0005434906823	25623	87	20E
0005434906862	25623	88	20F
0005432862228	2508	1	1A
0005432862258	2508	2	2A
0005432862266	2508	3	2B
0005432862247	2508	4	2D
0005432862257	2508	5	3A
0005432621059	2508	6	3B
0005432621055	2508	7	4A
0005432621056	2508	8	4B
0005432621050	2508	9	4C
0005432621054	2508	10	5A
0005432621049	2508	11	5B
0005432621048	2508	12	5D
0005432621058	2508	13	6A
0005432862267	2508	14	6B
0005432621052	2508	15	7B
0005432621053	2508	16	7C
0005432621057	2508	17	19D
0005432621051	2508	18	20A
0005432621046	2508	19	20D
0005432862222	2508	20	21A
0005432862236	2508	21	21D
0005432862265	2508	22	21C
0005432621060	2508	23	22A
0005432621047	2508	24	22B
0005432621061	2508	25	22C
0005432862256	2508	26	23A
0005432862307	28087	1	1A
0005432620958	28087	2	1C
0005432620947	28087	3	1D
0005432620961	28087	4	2A
0005432620895	28087	5	2D
0005432620967	28087	6	3C
0005432620969	28087	7	4C
0005432862311	28087	8	5A
0005432862309	28087	9	5B
0005432620926	28087	10	6A
0005432862312	28087	11	6B
0005432862306	28087	12	7A
0005432862310	28087	13	7D
0005432620968	28087	14	18A
0005432620954	28087	15	18D
0005432620953	28087	16	19A
0005432620946	28087	17	20A
0005432620894	28087	18	20B
0005432862313	28087	19	20D
0005432620948	28087	20	21C
0005432620893	28087	21	21D
0005432620905	28087	22	22A
0005432620907	28087	23	22B
0005432620934	28087	24	22C
0005432620908	28087	25	22D
0005432862308	28087	26	23A
0005432620945	28087	27	23B
0005434097468	11743	1	1A
0005434097459	11743	2	3B
0005434097456	11743	3	4A
0005434097477	13015	1	4A
0005434097478	13015	2	5B
0005433451621	31085	1	1B
0005433452742	31085	2	2A
0005433452741	31085	3	3B
0005433452740	31085	4	4A
0005433454855	31423	1	1A
0005433452724	31423	2	2A
0005433452727	31423	3	4B
0005433452728	31423	4	5B
0005433454854	31423	5	6A
0005433452726	31423	6	6B
0005434142592	11993	1	1A
0005433129244	11993	2	1B
0005433134108	11993	3	2C
0005433134094	11993	4	4B
0005434142597	11993	5	4C
0005433134092	11993	6	6A
0005434142580	11993	7	6C
0005434184647	11993	8	6D
0005434142581	11993	9	19A
0005434184648	11993	10	21C
0005433134093	11993	11	22A
0005433129245	11993	12	22B
0005434142609	29868	1	2B
0005433131712	29868	2	2C
0005434142611	29868	3	3C
0005434183581	29868	4	4A
0005433134144	29868	5	4D
0005433134142	29868	6	7B
0005433134140	29868	7	7D
0005433134143	29868	8	18B
0005434184667	29868	9	18C
0005433131711	29868	10	20A
0005433131714	29868	11	20B
0005433131713	29868	12	20D
0005434142610	29868	13	21A
0005434183582	29868	14	21C
0005434142612	29868	15	21D
0005433134141	29868	16	22A
0005434183583	29868	17	22B
0005435697347	16459	1	1A
0005435697359	16459	2	1B
0005435697351	16459	3	1C
0005435697338	16459	4	1D
0005435697335	16459	5	2C
0005435697341	16459	6	2D
0005435935018	16459	7	3B
0005435697334	16459	8	3C
0005435697353	16459	9	4A
0005435697340	16459	10	4B
0005435697352	16459	11	4C
0005435697331	16459	12	4D
0005435697349	16459	13	5A
0005435697350	16459	14	5C
0005435697354	16459	15	5D
0005435697346	16459	16	6A
0005435697344	16459	17	6B
0005435697342	16459	18	6C
0005435697333	16459	19	6D
0005435697355	16459	20	7A
0005435697343	16459	21	7B
0005435697345	16459	22	18C
0005435697348	16459	23	19A
0005435697356	16459	24	20D
0005435697337	16459	25	21A
0005435697339	16459	26	21B
0005435697336	16459	27	22B
0005435697357	16459	28	22C
0005435697332	16459	29	22D
0005435697358	16459	30	23B
0005435697155	24729	1	1A
0005435696965	24729	2	1B
0005435697092	24729	3	2A
0005435935051	24729	4	2B
0005435697298	24729	5	2C
0005435697136	24729	6	2D
0005435697133	24729	7	3A
0005435697247	24729	8	3B
0005435697167	24729	9	3C
0005435697222	24729	10	3D
0005435697156	24729	11	4A
0005435935048	24729	12	4B
0005435697106	24729	13	4D
0005435697130	24729	14	5A
0005435697179	24729	15	5C
0005435697122	24729	16	5D
0005435697129	24729	17	6A
0005435697171	24729	18	6B
0005435697160	24729	19	6C
0005435697192	24729	20	6D
0005435697157	24729	21	7A
0005435697221	24729	22	7B
0005435697191	24729	23	7C
0005435697161	24729	24	18A
0005435697154	24729	25	18B
0005435697089	24729	26	18C
0005435697206	24729	27	19B
0005435697105	24729	28	19D
0005435697299	24729	29	20A
0005435697207	24729	30	20C
0005435697199	24729	31	20D
0005435935050	24729	32	21B
0005435697135	24729	33	21C
0005435697162	24729	34	21D
0005435697180	24729	35	22A
0005435697087	24729	36	22B
0005435935049	24729	37	23A
0005435697093	24729	38	23B
0005433724809	18784	1	1B
0005433724807	18784	2	2A
0005433724811	18784	3	2B
0005433724808	18784	4	4B
0005432968825	18784	5	5A
0005433724806	18784	6	6A
0005433724810	18784	7	6B
0005433724776	21644	1	1A
0005432968844	21644	2	4A
0005433724775	21644	3	4B
0005433724777	21644	4	5B
0005432968845	21644	5	6B
0005434138252	7327	1	1A
0005434138300	7327	2	1C
0005434138262	7327	3	1D
0005434138216	7327	4	1F
0005434138255	7327	5	2A
0005434138298	7327	6	2C
0005434138266	7327	7	2D
0005434138222	7327	8	2F
0005434138219	7327	9	3A
0005434138263	7327	10	3C
0005434087517	7327	11	3D
0005434138282	7327	12	3F
0005434138221	7327	13	4A
0005434138264	7327	14	4C
0005434138235	7327	15	4D
0005434138230	7327	16	4E
0005434138239	7327	17	4F
0005434138234	7327	18	5A
0005434138232	7327	19	5C
0005434138279	7327	20	5D
0005434138290	7327	21	5E
0005434087518	7327	22	5F
0005434138256	7327	23	6A
0005434138249	7327	24	6C
0005434138254	7327	25	6D
0005434138218	7327	26	6E
0005434138226	7327	27	6F
0005434138250	7327	28	7A
0005434138272	7327	29	7C
0005434138231	7327	30	7D
0005434138286	7327	31	7E
0005434138248	7327	32	7F
0005434138260	7327	33	8A
0005434138271	7327	34	8C
0005434138284	7327	35	8D
0005434138295	7327	36	8E
0005434138288	7327	37	8F
0005434138228	7327	38	9A
0005434138251	7327	39	9C
0005434138236	7327	40	9D
0005434138287	7327	41	9E
0005434138229	7327	42	9F
0005434138297	7327	43	10A
0005434138299	7327	44	10C
0005434138220	7327	45	10D
0005434138296	7327	46	10E
0005434138240	7327	47	10F
0005434138289	7327	48	11C
0005434138267	7327	49	11A
0005434138237	7327	50	11D
0005434138233	7327	51	11E
0005434138246	7327	52	11F
0005434138293	7327	53	12A
0005434138277	7327	54	12C
0005434138247	7327	55	12D
0005434138258	7327	56	12E
0005434138238	7327	57	12F
0005434138281	7327	58	13A
0005434138244	7327	59	13C
0005434138253	7327	60	13D
0005434138278	7327	61	13E
0005434138223	7327	62	13F
0005434138242	7327	63	14A
0005434087519	7327	64	14C
0005434138270	7327	65	14D
0005434138283	7327	66	14E
0005434138224	7327	67	14F
0005434138217	7327	68	15C
0005434138259	7327	69	15D
0005434138280	7327	70	15E
0005434138241	7327	71	15F
0005434138276	7327	72	16A
0005434138243	7327	73	16C
0005434138285	7327	74	16D
0005434087520	7327	75	16E
0005434087521	7327	76	16F
0005434138265	7327	77	17A
0005434138301	7327	78	17C
0005434138225	7327	79	17D
0005434138294	7327	80	17E
0005434138268	7327	81	17F
0005434138291	7327	82	18A
0005434138303	7327	83	18C
0005434138215	7327	84	18D
0005434138227	7327	85	18E
0005434138269	7327	86	18F
0005434138302	7327	87	19A
0005434138261	7327	88	19C
0005434138257	7327	89	19D
0005434138275	7327	90	19E
0005434138304	7327	91	19F
0005434138292	7327	92	20A
0005434138305	7327	93	20C
0005434138245	7327	94	20D
0005434138274	7327	95	20E
0005434138273	7327	96	20F
0005434137411	28540	1	1A
0005434137441	28540	2	1C
0005434137595	28540	3	1D
0005434137670	28540	4	1F
0005434137428	28540	5	2C
0005434137698	28540	6	2D
0005434136778	28540	7	2F
0005434137303	28540	8	3A
0005434137112	28540	9	3C
0005434137299	28540	10	3D
0005434137272	28540	11	3F
0005434137531	28540	12	4A
0005434137396	28540	13	4D
0005434137397	28540	14	4E
0005434137309	28540	15	4F
0005434137571	28540	16	5A
0005434137235	28540	17	5C
0005434137389	28540	18	5D
0005434137514	28540	19	5E
0005434137212	28540	20	5F
0005434137533	28540	21	6A
0005434137594	28540	22	6E
0005434137271	28540	23	6F
0005434137757	28540	24	7C
0005434137234	28540	25	7D
0005434137494	28540	26	7E
0005434137361	28540	27	7F
0005434137213	28540	28	8A
0005434137188	28540	29	8C
0005434137214	28540	30	8D
0005434136950	28540	31	8E
0005434137476	28540	32	8F
0005434137558	28540	33	9A
0005434137367	28540	34	9C
0005434137854	28540	35	9D
0005434136872	28540	36	9E
0005434137853	28540	37	9F
0005434137134	28540	38	10A
0005434137784	28540	39	10C
0005434137135	28540	40	10D
0005434137532	28540	41	11A
0005434137493	28540	42	11C
0005434137544	28540	43	11D
0005434137311	28540	44	11E
0005434137860	28540	45	11F
0005434137572	28540	46	12A
0005434136890	28540	47	12C
0005434087480	28540	48	12E
0005434136973	28540	49	12F
0005434137741	28540	50	13A
0005434137431	28540	51	13C
0005434137451	28540	52	13D
0005434137450	28540	53	13E
0005434137421	28540	54	13F
0005434137569	28540	55	14A
0005434137605	28540	56	14C
0005434137655	28540	57	14E
0005434137344	28540	58	14F
0005434087479	28540	59	15A
0005434137648	28540	60	15C
0005434137791	28540	61	15D
0005434137237	28540	62	16A
0005434137852	28540	63	16C
0005434137656	28540	64	16D
0005434137432	28540	65	16F
0005434137603	28540	66	16E
0005434137298	28540	67	17A
0005434137357	28540	68	17C
0005434137534	28540	69	17D
0005434087500	28540	70	17E
0005434137613	28540	71	17F
0005434137561	28540	72	18A
0005434137430	28540	73	18C
0005434137380	28540	74	18D
0005434137123	28540	75	18F
0005434137440	28540	76	19C
0005434137420	28540	77	19D
0005434137427	28540	78	19E
0005434137184	28540	79	19F
0005434137657	28540	80	20A
0005434137156	28540	81	20C
0005434137474	28540	82	20D
0005434137489	28540	83	20E
0005434137302	28540	84	20F
0005433407526	1949	1	1C
0005434610233	1949	2	2A
0005435808244	1949	3	2C
0005433407527	1949	4	2D
0005434610235	1949	5	3D
0005433407528	1949	6	5B
0005434610232	1949	7	6A
0005435808250	1949	8	6B
0005435808251	1949	9	6D
0005433407501	1949	10	7A
0005435808247	1949	11	7C
0005434610231	1949	12	18A
0005435808248	1949	13	18B
0005435808245	1949	14	18D
0005435808241	1949	15	19C
0005434610234	1949	16	19D
0005435808246	1949	17	20A
0005435808242	1949	18	20B
0005435808243	1949	19	20C
0005433407529	1949	20	20D
0005435808249	1949	21	22B
0005433407507	1949	22	22D
0005433407525	1949	23	23B
0005434610190	23085	1	7A
0005434610210	23085	2	20D
0005434610196	23085	3	21B
0005434503831	16714	1	1A
0005434503832	16714	2	1B
0005434503814	16714	3	1C
0005434503952	16714	4	1D
0005434503863	16714	5	2A
0005434503890	16714	6	2B
0005434503813	16714	7	2C
0005434503954	16714	8	3A
0005434503866	16714	9	2D
0005434503908	16714	10	3C
0005434503887	16714	11	3D
0005434503843	16714	12	4A
0005434503597	16714	13	4B
0005434503802	16714	14	4C
0005434503936	16714	15	4D
0005434503938	16714	16	5A
0005434503950	16714	17	5B
0005434503907	16714	18	5C
0005434503676	16714	19	5D
0005434503953	16714	20	6A
0005434503842	16714	21	6B
0005434503561	16714	22	6C
0005434503739	16714	23	6D
0005434503893	16714	24	7A
0005434503912	16714	25	7C
0005434503865	16714	26	7D
0005434503888	16714	27	18A
0005434503838	16714	28	18B
0005434503939	16714	29	18C
0005434503909	16714	30	18D
0005434503951	16714	31	19A
0005434503830	16714	32	19B
0005434503720	16714	33	19C
0005434503820	16714	34	19D
0005434503848	16714	35	20A
0005434503698	16714	36	20C
0005434503913	16714	37	20D
0005434503849	16714	38	21B
0005434503862	16714	39	21C
0005434503949	16714	40	22A
0005434503740	16714	41	22B
0005434503856	16714	42	22C
0005434503857	16714	43	22D
0005434503891	16714	44	23A
0005434503560	16714	45	23B
0005434504151	22877	1	1A
0005434504167	22877	2	1B
0005434504169	22877	3	1C
0005434504159	22877	4	1D
0005434504170	22877	5	2B
0005434504173	22877	6	2C
0005434504154	22877	7	2D
0005434504182	22877	8	3A
0005434504172	22877	9	3B
0005434504149	22877	10	3C
0005434504155	22877	11	3D
0005434504144	22877	12	4A
0005434504175	22877	13	4B
0005434504164	22877	14	4D
0005434504158	22877	15	5A
0005434504153	22877	16	5C
0005434504174	22877	17	5D
0005434504183	22877	18	6A
0005434504156	22877	19	6C
0005434504166	22877	20	6D
0005434504147	22877	21	7A
0005434504148	22877	22	7B
0005434504180	22877	23	7C
0005434504179	22877	24	7D
0005434504157	22877	25	18B
0005434504171	22877	26	18C
0005434504160	22877	27	18D
0005434504181	22877	28	19A
0005434504168	22877	29	19B
0005434504150	22877	30	19C
0005434504176	22877	31	19D
0005434504184	22877	32	20B
0005434504152	22877	33	20C
0005434504178	22877	34	20D
0005434504161	22877	35	21A
0005434504165	22877	36	21B
0005434504177	22877	37	21D
0005434504146	22877	38	22A
0005434504162	22877	39	22C
0005434504163	22877	40	22D
0005434504145	22877	41	23A
0005433266678	2220	1	1C
0005435078350	2220	2	1D
0005435078361	2220	3	2B
0005435078354	2220	4	2C
0005433266645	2220	5	2D
0005433266696	2220	6	3A
0005435078352	2220	7	3B
0005435078362	2220	8	3C
0005435078351	2220	9	4A
0005435078358	2220	10	4C
0005435078364	2220	11	5A
0005435078356	2220	12	5B
0005435078357	2220	13	5D
0005433266628	2220	14	6D
0005435078365	2220	15	7A
0005433266654	2220	16	7D
0005433266650	2220	17	18B
0005433266629	2220	18	18C
0005435078353	2220	19	19B
0005435078360	2220	20	20A
0005435078363	2220	21	20D
0005433266619	2220	22	21C
0005435078359	2220	23	21D
0005435078355	2220	24	22A
0005433266695	2220	25	22B
0005433266736	24337	1	1A
0005435078221	24337	2	2B
0005433266733	24337	3	2D
0005435078225	24337	4	3A
0005435078224	24337	5	3B
0005433266735	24337	6	3D
0005433266729	24337	7	4A
0005435078215	24337	8	4B
0005433266738	24337	9	4C
0005433266731	24337	10	5A
0005435078214	24337	11	5C
0005433266730	24337	12	6A
0005435078297	24337	13	6C
0005435078247	24337	14	7A
0005435078190	24337	15	7B
0005435078226	24337	16	7C
0005435078192	24337	17	18C
0005435078246	24337	18	19A
0005435078298	24337	19	19B
0005435078222	24337	20	19C
0005433266737	24337	21	19D
0005433266734	24337	22	20B
0005433266732	24337	23	21D
0005435078259	24337	24	22C
0005435078191	24337	25	23A
0005434988760	6619	1	4B
0005434988753	6619	2	4D
0005434988757	6619	3	5A
0005434988754	6619	4	6A
0005435803268	6619	5	7C
0005434988762	6619	6	7D
0005434988758	6619	7	18A
0005434988761	6619	8	18D
0005434988756	6619	9	19C
0005435803267	6619	10	19D
0005434988759	6619	11	20C
0005434988755	6619	12	22C
0005434988752	6619	13	23B
0005434988618	23601	1	1B
0005434988617	23601	2	1C
0005434988615	23601	3	2D
0005435803241	23601	4	4C
0005435803240	23601	5	6D
0005435464509	23601	6	18C
0005435803242	23601	7	18D
0005434988616	23601	8	20D
0005432383225	30494	1	1A
0005433449999	30494	2	1C
0005433449989	30494	3	1D
0005432383232	30494	4	1F
0005432383222	30494	5	2A
0005433453764	30494	6	2C
0005432383215	30494	7	2F
0005432383221	30494	8	3A
0005432383203	30494	9	3C
0005433450001	30494	10	3F
0005432383235	30494	11	4D
0005432383220	30494	12	4E
0005432383207	30494	13	5A
0005433450002	30494	14	5E
0005432383218	30494	15	5F
0005433449985	30494	16	6A
0005433450000	30494	17	6C
0005432383217	30494	18	6E
0005433450006	30494	19	7C
0005433449988	30494	20	7D
0005432383234	30494	21	7E
0005433449986	30494	22	7F
0005433449987	30494	23	8A
0005432383204	30494	24	8E
0005432383223	30494	25	8F
0005433454878	30494	26	9A
0005432383229	30494	27	9C
0005432383208	30494	28	9D
0005432383202	30494	29	9E
0005433449993	30494	30	9F
0005433449991	30494	31	10C
0005433449990	30494	32	10F
0005433450004	30494	33	11A
0005433450005	30494	34	11C
0005432383226	30494	35	11E
0005432383219	30494	36	11F
0005433449992	30494	37	12A
0005432383236	30494	38	12C
0005432383205	30494	39	12D
0005432383216	30494	40	12F
0005433449994	30494	41	13A
0005433454877	30494	42	13F
0005432383237	30494	43	14A
0005432383228	30494	44	14C
0005432383212	30494	45	14D
0005433450007	30494	46	14E
0005432383214	30494	47	15C
0005432383213	30494	48	15E
0005433449995	30494	49	16A
0005433449998	30494	50	16C
0005432383231	30494	51	16F
0005432383227	30494	52	17D
0005433449996	30494	53	18C
0005432383209	30494	54	18D
0005432383211	30494	55	18E
0005433449997	30494	56	18F
0005432383206	30494	57	19C
0005432383233	30494	58	19D
0005433450003	30494	59	19E
0005432383210	30494	60	20A
0005432383230	30494	61	20C
0005432383224	30494	62	20F
0005432382771	31323	1	1C
0005432382768	31323	2	1D
0005433449861	31323	3	1F
0005433449785	31323	4	2A
0005433449916	31323	5	2C
0005432382634	31323	6	2D
0005433449801	31323	7	3C
0005433449843	31323	8	3D
0005432382915	31323	9	3F
0005433449821	31323	10	4D
0005433449834	31323	11	4E
0005433449829	31323	12	4F
0005433449643	31323	13	5A
0005432382772	31323	14	5C
0005432382817	31323	15	5D
0005432382968	31323	16	5E
0005432382791	31323	17	5F
0005433451610	31323	18	6C
0005433449857	31323	19	6D
0005433449773	31323	20	6E
0005432382744	31323	21	6F
0005433449833	31323	22	7A
0005433449884	31323	23	7D
0005432382804	31323	24	8A
0005432382820	31323	25	8C
0005433449781	31323	26	8D
0005433449868	31323	27	8E
0005433449932	31323	28	8F
0005433449789	31323	29	9A
0005432382967	31323	30	9C
0005433451588	31323	31	9E
0005432382620	31323	32	9F
0005433449890	31323	33	10A
0005432382762	31323	34	10C
0005433449760	31323	35	10D
0005432382770	31323	36	10E
0005432382829	31323	37	10F
0005432382957	31323	38	11A
0005432382816	31323	39	11C
0005433449822	31323	40	11D
0005432382824	31323	41	11E
0005433449897	31323	42	11F
0005432382958	31323	43	12A
0005433449739	31323	44	12C
0005433449856	31323	45	12D
0005433449791	31323	46	12E
0005432382813	31323	47	12F
0005433449786	31323	48	13A
0005432382846	31323	49	13C
0005433449812	31323	50	13D
0005433449917	31323	51	13E
0005432382832	31323	52	13F
0005432382745	31323	53	14A
0005433449757	31323	54	14C
0005432382828	31323	55	14D
0005432382882	31323	56	14E
0005432382669	31323	57	14F
0005433449790	31323	58	15A
0005432382825	31323	59	15C
0005433449774	31323	60	15D
0005432382883	31323	61	15E
0005432382983	31323	62	15F
0005433449772	31323	63	16A
0005432382845	31323	64	16C
0005432382914	31323	65	16E
0005432382699	31323	66	16F
0005432382761	31323	67	17A
0005433449792	31323	68	17C
0005432382773	31323	69	17D
0005432382814	31323	70	17F
0005433453754	31323	71	18A
0005433453753	31323	72	18D
0005432382763	31323	73	18F
0005432382956	31323	74	19A
0005432382830	31323	75	19C
0005433449782	31323	76	19D
0005433449759	31323	77	19E
0005433449741	31323	78	19F
0005432382743	31323	79	20A
0005433449839	31323	80	20C
0005432382769	31323	81	20D
0005433449828	31323	82	20E
0005432382884	31323	83	20F
0005433788184	26475	1	1A
0005433788170	26475	2	1B
0005433788173	26475	3	2A
0005435548501	26475	4	2B
0005435548498	26475	5	3A
0005435548503	26475	6	5B
0005435548497	26475	7	6A
0005435548502	26475	8	6B
0005433788155	26475	9	18B
0005435548499	26475	10	19A
0005433788183	26475	11	19B
0005435548496	26475	12	19D
0005433788171	26475	13	20B
0005435548504	26475	14	20C
0005433788156	26475	15	21C
0005435548500	26475	16	22A
0005435299718	10776	1	1A
0005433131660	10776	2	1C
0005433126795	10776	3	1D
0005435304138	10776	4	2A
0005433131668	10776	5	2B
0005433126782	10776	6	3A
0005433131672	10776	7	3C
0005433131661	10776	8	3D
0005433126819	10776	9	4C
0005433131669	10776	10	4D
0005433131676	10776	11	5A
0005433126796	10776	12	6A
0005433131662	10776	13	6B
0005435299719	10776	14	6C
0005433131673	10776	15	6D
0005435304137	10776	16	7A
0005433131671	10776	17	7B
0005433126799	10776	18	7C
0005433131675	10776	19	19A
0005435299741	10776	20	19C
0005433126784	10776	21	19D
0005433126804	10776	22	20B
0005433131666	10776	23	20C
0005435304133	10776	24	20D
0005433126783	10776	25	21A
0005435299740	10776	26	21B
0005435299725	10776	27	21C
0005433126798	10776	28	22A
0005435299742	10776	29	22B
0005433126818	10776	30	22C
0005433131674	10776	31	22D
0005433126797	10776	32	23A
0005433126853	29739	1	1B
0005435299784	29739	2	1C
0005433126855	29739	3	1D
0005435299786	29739	4	2D
0005435299783	29739	5	3D
0005433126852	29739	6	4D
0005435299785	29739	7	5D
0005435302207	29739	8	6D
0005435302206	29739	9	7B
0005435302209	29739	10	7C
0005435302208	29739	11	7D
0005433126854	29739	12	18B
0005433129285	29739	13	18C
0005433129283	29739	14	19D
0005435299787	29739	15	20D
0005435302205	29739	16	21A
0005433129282	29739	17	22A
0005433129286	29739	18	22D
0005433129284	29739	19	23B
0005434287318	2413	1	1A
0005434287321	2413	2	1B
0005434287322	2413	3	1D
0005434287309	2413	4	2A
0005434287307	2413	5	3B
0005433109959	2413	6	3C
0005434287312	2413	7	3D
0005433109994	2413	8	4A
0005433109985	2413	9	4B
0005434287317	2413	10	4C
0005433109974	2413	11	4D
0005434287316	2413	12	5A
0005433109976	2413	13	5B
0005434287310	2413	14	5C
0005433110010	2413	15	5D
0005433109977	2413	16	6A
0005434287315	2413	17	6B
0005434287313	2413	18	6C
0005432264477	2413	19	6D
0005434287304	2413	20	7A
0005433109975	2413	21	7B
0005434287303	2413	22	7C
0005432264478	2413	23	7D
0005434287308	2413	24	18A
0005434287311	2413	25	18B
0005433109968	2413	26	18C
0005434287319	2413	27	18D
0005434287306	2413	28	19C
0005433109991	2413	29	19D
0005434287320	2413	30	20B
0005434287323	2413	31	21A
0005433109992	2413	32	21B
0005434287324	2413	33	22A
0005434287314	2413	34	22C
0005434287305	2413	35	23A
0005434287032	26821	1	1A
0005434287058	26821	2	1B
0005434287160	26821	3	1C
0005433110061	26821	4	1D
0005434287143	26821	5	2A
0005433110063	26821	6	2B
0005434287142	26821	7	2C
0005434287161	26821	8	2D
0005434287094	26821	9	3A
0005434287192	26821	10	3B
0005434287186	26821	11	3C
0005434287151	26821	12	3D
0005434287149	26821	13	4A
0005434287096	26821	14	4B
0005434287157	26821	15	4C
0005433110067	26821	16	4D
0005433110068	26821	17	5A
0005434287023	26821	18	5B
0005434287144	26821	19	5C
0005434287059	26821	20	5D
0005434287057	26821	21	6A
0005434287182	26821	22	6B
0005433110071	26821	23	6C
0005434287224	26821	24	6D
0005434287079	26821	25	7A
0005434287100	26821	26	7B
0005433110064	26821	27	7C
0005434287185	26821	28	7D
0005434287097	26821	29	18A
0005434287046	26821	30	18B
0005434286969	26821	31	18C
0005434287148	26821	32	18D
0005433110066	26821	33	19A
0005433110070	26821	34	19B
0005433110069	26821	35	19C
0005434287181	26821	36	19D
0005433110065	26821	37	20A
0005434287180	26821	38	20C
0005434287156	26821	39	20D
0005434286970	26821	40	21A
0005434287102	26821	41	21C
0005434286968	26821	42	21D
0005434287179	26821	43	22C
0005433110072	26821	44	22D
0005433110062	26821	45	23A
0005434287031	26821	46	23B
0005435856210	25448	1	3B
0005434269090	25448	2	4B
0005434269091	25448	3	5D
0005435856209	25448	4	6D
0005435856212	25448	5	18A
0005434269086	25448	6	18C
0005435856208	25448	7	19C
0005434272181	25448	8	19D
0005435856211	25448	9	21D
0005435856182	26657	1	3B
0005435856161	26657	2	7C
0005435856162	26657	3	19A
0005434273078	26657	4	20C
0005434273079	26657	5	20D
0005434272193	26657	6	21A
0005434272194	26657	7	21D
0005434520183	19075	1	1A
0005434520216	19075	2	1B
0005434520160	19075	3	1C
0005434520155	19075	4	1D
0005434520191	19075	5	2A
0005435314836	19075	6	2B
0005435314837	19075	7	2C
0005434520166	19075	8	2D
0005434520227	19075	9	3A
0005434520209	19075	10	3B
0005434520173	19075	11	3C
0005434520129	19075	12	3D
0005434520204	19075	13	4A
0005434520199	19075	14	4B
0005434520179	19075	15	4C
0005435314832	19075	16	4D
0005434520172	19075	17	5A
0005434520168	19075	18	5B
0005435314840	19075	19	5C
0005434520161	19075	20	5D
0005435314842	19075	21	6A
0005434520241	19075	22	6B
0005434520181	19075	23	6C
0005435314831	19075	24	6D
0005435314829	19075	25	7A
0005434520162	19075	26	7B
0005434520190	19075	27	7C
0005434520192	19075	28	7D
0005434520128	19075	29	18A
0005434520187	19075	30	18B
0005434520182	19075	31	18C
0005435314835	19075	32	18D
0005434520167	19075	33	19A
0005435314834	19075	34	19B
0005435314830	19075	35	19C
0005435314838	19075	36	19D
0005434520240	19075	37	20A
0005434520188	19075	38	20B
0005434520178	19075	39	20C
0005435314843	19075	40	20D
0005434520170	19075	41	21A
0005434520203	19075	42	21B
0005435314841	19075	43	21C
0005434520210	19075	44	21D
0005434520174	19075	45	22A
0005434520169	19075	46	22B
0005434520208	19075	47	22C
0005434520215	19075	48	22D
0005435314833	19075	49	23A
0005435314839	19075	50	23B
0005433874355	7778	1	1B
0005433874357	7778	2	2B
0005433874350	7778	3	3C
0005433874352	7778	4	5A
0005433874346	7778	5	6A
0005433874344	7778	6	6B
0005433874345	7778	7	7A
0005433874358	7778	8	18A
0005433874348	7778	9	18C
0005433874347	7778	10	19B
0005433874353	7778	11	19C
0005433874356	7778	12	21C
0005433874354	7778	13	22B
0005433874351	7778	14	23A
0005433874349	7778	15	23B
0005433874304	32629	1	1D
0005433874308	32629	2	2A
0005433874314	32629	3	2B
0005433874324	32629	4	3C
0005433874331	32629	5	4B
0005433874310	32629	6	5B
0005433874328	32629	7	5C
0005433874323	32629	8	6C
0005433874342	32629	9	7B
0005433874294	32629	10	7D
0005433874320	32629	11	18B
0005433874305	32629	12	18C
0005433874340	32629	13	19C
0005433874312	32629	14	20A
0005433874311	32629	15	20B
0005433874309	32629	16	20C
0005433874332	32629	17	21A
0005433874313	32629	18	21C
0005433874333	32629	19	22A
0005433874329	32629	20	22B
0005433874325	32629	21	22C
0005433874322	32629	22	23A
0005433874334	32629	23	23B
0005435860463	4787	1	1B
0005433868473	4787	2	1D
0005433868507	4787	3	2A
0005433868505	4787	4	2B
0005435860459	4787	5	2C
0005433868476	4787	6	2D
0005435860467	4787	7	3A
0005433868488	4787	8	3B
0005433868491	4787	9	3C
0005433868485	4787	10	3D
0005433868498	4787	11	4C
0005433868484	4787	12	4D
0005433868489	4787	13	5A
0005433868499	4787	14	5B
0005433868506	4787	15	5C
0005433868511	4787	16	5D
0005433868490	4787	17	6A
0005433868503	4787	18	6B
0005433868504	4787	19	6C
0005433868509	4787	20	6D
0005433868479	4787	21	7A
0005433868480	4787	22	7B
0005433868482	4787	23	7C
0005433868502	4787	24	7D
0005433868496	4787	25	18A
0005435860464	4787	26	18B
0005433868492	4787	27	18C
0005433868475	4787	28	18D
0005433868481	4787	29	19A
0005433868486	4787	30	19B
0005433868483	4787	31	19C
0005433868487	4787	32	19D
0005433868477	4787	33	20A
0005433868478	4787	34	20B
0005433868512	4787	35	20C
0005433868510	4787	36	20D
0005433868494	4787	37	21A
0005433868508	4787	38	21B
0005433868474	4787	39	21D
0005433868500	4787	40	22A
0005433868493	4787	41	22B
0005433868495	4787	42	22C
0005435860465	4787	43	22D
0005433868501	4787	44	23A
0005433868497	4787	45	23B
0005433868080	32575	1	1A
0005433868010	32575	2	1B
0005433867914	32575	3	1C
0005433868075	32575	4	1D
0005433868133	32575	5	2A
0005433868044	32575	6	2C
0005433868115	32575	7	2B
0005433868121	32575	8	2D
0005433868043	32575	9	3A
0005433868345	32575	10	3B
0005433868156	32575	11	3C
0005433868009	32575	12	3D
0005433868169	32575	13	4A
0005433868074	32575	14	4B
0005433868073	32575	15	4C
0005433868088	32575	16	4D
0005433868038	32575	17	5A
0005433868048	32575	18	5B
0005433868170	32575	19	5C
0005433868047	32575	20	5D
0005433868202	32575	21	6A
0005433868019	32575	22	6B
0005433868132	32575	23	6C
0005433868129	32575	24	6D
0005433868147	32575	25	7A
0005433868196	32575	26	7B
0005433868090	32575	27	7C
0005433868146	32575	28	7D
0005433867915	32575	29	18A
0005433868292	32575	30	18B
0005433867944	32575	31	18C
0005433868344	32575	32	18D
0005433868008	32575	33	19A
0005433867998	32575	34	19B
0005433868148	32575	35	19C
0005433868248	32575	36	19D
0005433868061	32575	37	20A
0005433867889	32575	38	20B
0005433868089	32575	39	20C
0005433868247	32575	40	20D
0005433868205	32575	41	21A
0005433868070	32575	42	21B
0005433868195	32575	43	21C
0005433868155	32575	44	21D
0005433868245	32575	45	22A
0005433868101	32575	46	22B
0005433868079	32575	47	22C
0005433867943	32575	48	22D
0005433868263	32575	49	23A
0005433868246	32575	50	23B
0005434663418	3449	1	1C
0005434663419	3449	2	1D
0005435911401	3449	3	2A
0005435911382	3449	4	2B
0005434460508	3449	5	3A
0005434663425	3449	6	3B
0005434663427	3449	7	3C
0005434663422	3449	8	4A
0005435911347	3449	9	4C
0005434663429	3449	10	5B
0005435911399	3449	11	5C
0005434461650	3449	12	6C
0005435911377	3449	13	7A
0005434461649	3449	14	7C
0005435911391	3449	15	18A
0005434461648	3449	16	18B
0005434663420	3449	17	19B
0005434663428	3449	18	20B
0005434663424	3449	19	20D
0005434663417	3449	20	21C
0005434663423	3449	21	22A
0005434663421	3449	22	22C
0005434663426	3449	23	23B
0005434663287	12490	1	1A
0005434462772	12490	2	1B
0005434663314	12490	3	1C
0005434460486	12490	4	1D
0005435911463	12490	5	2A
0005434462763	12490	6	2B
0005434460469	12490	7	2C
0005434663301	12490	8	2D
0005434663285	12490	9	3B
0005434462766	12490	10	3D
0005434663318	12490	11	4A
0005434460485	12490	12	4B
0005435911459	12490	13	4D
0005434663291	12490	14	5A
0005434663317	12490	15	5B
0005434663347	12490	16	5C
0005434460470	12490	17	6A
0005435911458	12490	18	6B
0005434663250	12490	19	6D
0005434663356	12490	20	7A
0005434663358	12490	21	7B
0005435911462	12490	22	7C
0005434462775	12490	23	18A
0005435911457	12490	24	18C
0005435911456	12490	25	18D
0005434462767	12490	26	19A
0005434460472	12490	27	19C
0005434462762	12490	28	19D
0005435911460	12490	29	20A
0005434663348	12490	30	20B
0005434462770	12490	31	20C
0005434460477	12490	32	20D
0005434663290	12490	33	21C
0005434663327	12490	34	21D
0005434663286	12490	35	22B
0005435911461	12490	36	22C
0005434462769	12490	37	22D
0005434663328	12490	38	23A
0005434462771	12490	39	23B
0005433868129	14482	1	1A
0005433868101	14482	2	1B
0005433867944	14482	3	1D
0005433868008	14482	4	1C
0005433868147	14482	5	2A
0005433868061	14482	6	2B
0005433868248	14482	7	2C
0005433868155	14482	8	2D
0005433868263	14482	9	3A
0005433868070	14482	10	3B
0005433868075	14482	11	3C
0005433868079	14482	12	3D
0005433868047	14482	13	4A
0005433868245	14482	14	4B
0005433868148	14482	15	4D
0005433867915	14482	16	4C
0005433867889	14482	17	5A
0005433868169	14482	18	5B
0005433868090	14482	19	5C
0005433868146	14482	20	5D
0005433868121	14482	21	6A
0005433868019	14482	22	6B
0005433867998	14482	23	6C
0005433868202	14482	24	6D
0005433868247	14482	25	7A
0005433868088	14482	26	7B
0005433868344	14482	27	7C
0005433868170	14482	28	7D
0005433868048	14482	29	18A
0005433868133	14482	30	18B
0005433868009	14482	31	18C
0005433867914	14482	32	18D
0005433868074	14482	33	19A
0005433868292	14482	34	19B
0005433868196	14482	35	19C
0005433868010	14482	36	19D
0005433868044	14482	37	20A
0005433868043	14482	38	20B
0005433868156	14482	39	20C
0005433868089	14482	40	20D
0005433868345	14482	41	21A
0005433868132	14482	42	21B
0005433868205	14482	43	21C
0005433868073	14482	44	21D
0005433868115	14482	45	22A
0005433868246	14482	46	22B
0005433868195	14482	47	22C
0005433868080	14482	48	22D
0005433867943	14482	49	23A
0005433868038	14482	50	23B
0005433868441	32687	1	1A
0005433868470	32687	2	1C
0005433868458	32687	3	1D
0005433868457	32687	4	2A
0005435860450	32687	5	2B
0005433868452	32687	6	2D
0005433868462	32687	7	3A
0005433868435	32687	8	3B
0005435860452	32687	9	3C
0005433868465	32687	10	3D
0005433868469	32687	11	4A
0005433868471	32687	12	4B
0005433868440	32687	13	4D
0005433868463	32687	14	5A
0005433868433	32687	15	5B
0005433868451	32687	16	5C
0005433868467	32687	17	5D
0005433868437	32687	18	6A
0005433868454	32687	19	6B
0005433868442	32687	20	6C
0005433868461	32687	21	6D
0005433868431	32687	22	7A
0005433868447	32687	23	7B
0005433868456	32687	24	7C
0005433868455	32687	25	7D
0005433868472	32687	26	18A
0005433868432	32687	27	18B
0005433868443	32687	28	18C
0005433868448	32687	29	18D
0005433868438	32687	30	19A
0005433868466	32687	31	19B
0005433868434	32687	32	19C
0005433868460	32687	33	19D
0005433868468	32687	34	20A
0005435860446	32687	35	20B
0005433868464	32687	36	20C
0005433868446	32687	37	20D
0005433868450	32687	38	21A
0005433868453	32687	39	21B
0005433868439	32687	40	21C
0005435860451	32687	41	21D
0005433868436	32687	42	22A
0005433868445	32687	43	22C
0005433868459	32687	44	22D
0005433868444	32687	45	23A
0005433868449	32687	46	23B
0005432799365	12127	1	1B
0005432799281	12127	2	1D
0005432799174	12127	3	2A
0005432799310	12127	4	2B
0005432799176	12127	5	2C
0005432799289	12127	6	2D
0005432799284	12127	7	3B
0005432799285	12127	8	3C
0005432799364	12127	9	3D
0005432799268	12127	10	4B
0005432799177	12127	11	4C
0005432799175	12127	12	4D
0005432799275	12127	13	5A
0005432799055	12127	14	5B
0005432799198	12127	15	5C
0005432799374	12127	16	5D
0005432799270	12127	17	6A
0005432799276	12127	18	6D
0005432799413	12127	19	7B
0005432799309	12127	20	7C
0005432799411	12127	21	7D
0005432799246	12127	22	18A
0005432799347	12127	23	18B
0005432799134	12127	24	18C
0005432799260	12127	25	18D
0005432799241	12127	26	19B
0005432799367	12127	27	19D
0005432799245	12127	28	20A
0005432799186	12127	29	20C
0005432799228	12127	30	20D
0005432799306	12127	31	21A
0005432799366	12127	32	21C
0005432799294	12127	33	21D
0005432799269	12127	34	22A
0005432799242	12127	35	22B
0005432799307	12127	36	22C
0005432799184	12127	37	23A
0005432799412	12127	38	23B
0005432799459	14781	1	1A
0005432799466	14781	2	1C
0005432799445	14781	3	2A
0005432799458	14781	4	2B
0005432799444	14781	5	2D
0005432799449	14781	6	4A
0005432799447	14781	7	4B
0005432799454	14781	8	4C
0005432799470	14781	9	4D
0005432799453	14781	10	5C
0005432799468	14781	11	5D
0005432799446	14781	12	6B
0005432799471	14781	13	6D
0005432799467	14781	14	7A
0005432799464	14781	15	7B
0005432799462	14781	16	7C
0005432799463	14781	17	7D
0005432799469	14781	18	18A
0005432799461	14781	19	18B
0005432799452	14781	20	19A
0005432799460	14781	21	19D
0005432799450	14781	22	20A
0005432799465	14781	23	20D
0005432799455	14781	24	21A
0005432799457	14781	25	21C
0005432799451	14781	26	22B
0005432799448	14781	27	22C
0005432799472	14781	28	23A
0005432799456	14781	29	23B
0005435293171	7049	1	1A
0005435310954	7049	2	1D
0005432153946	7049	3	2A
0005434407833	7049	4	1F
0005435310952	7049	5	2C
0005434407865	7049	6	2D
0005434299578	7049	7	2F
0005434299589	7049	8	3A
0005434407843	7049	9	3D
0005434407830	7049	10	3C
0005434299590	7049	11	3F
0005434407846	7049	12	4A
0005434299584	7049	13	4B
0005434407800	7049	14	4D
0005434299583	7049	15	4C
0005434299596	7049	16	4E
0005432153945	7049	17	4F
0005435310924	7049	18	5B
0005434407853	7049	19	5A
0005434407804	7049	20	5C
0005434407829	7049	21	5D
0005434407808	7049	22	5E
0005434407802	7049	23	6A
0005434407845	7049	24	5F
0005434407801	7049	25	6B
0005434407842	7049	26	6C
0005434299582	7049	27	6D
0005434407803	7049	28	6F
0005434407856	7049	29	6E
0005434407820	7049	30	7A
0005434407852	7049	31	7C
0005434407806	7049	32	7B
0005434407821	7049	33	7D
0005434407805	7049	34	7F
0005435293172	7049	35	7E
0005434407848	7049	36	8A
0005434299577	7049	37	8B
0005434407818	7049	38	8C
0005434407837	7049	39	8E
0005434407859	7049	40	8D
0005435310913	7049	41	9A
0005435310953	7049	42	8F
0005434407835	7049	43	9C
0005434299587	7049	44	9B
0005432153947	7049	45	9D
0005434407828	7049	46	9E
0005434299598	7049	47	10B
0005434407863	7049	48	10C
0005435293131	7049	49	11A
0005435293151	7049	50	11B
0005434407815	7049	51	11D
0005434299594	7049	52	11C
0005434407854	7049	53	11E
0005432108252	7049	54	11F
0005434299576	7049	55	12A
0005434299591	7049	56	12C
0005434407836	7049	57	12B
0005434407838	7049	58	12E
0005434299593	7049	59	12D
0005435310962	7049	60	12F
0005434407819	7049	61	13B
0005434407850	7049	62	13A
0005435310912	7049	63	13D
0005435310943	7049	64	13C
0005432108253	7049	65	13E
0005434407864	7049	66	14A
0005434407858	7049	67	13F
0005434407839	7049	68	14B
0005434407822	7049	69	14D
0005434407824	7049	70	14C
0005435293173	7049	71	14E
0005434407860	7049	72	14F
0005434299595	7049	73	15B
0005434407812	7049	74	15A
0005434407817	7049	75	15E
0005434299597	7049	76	15D
0005435293165	7049	77	15F
0005434407851	7049	78	16A
0005434407847	7049	79	16C
0005435293164	7049	80	16B
0005434407826	7049	81	16E
0005434407861	7049	82	16D
0005435310911	7049	83	16F
0005434299580	7049	84	17A
0005434407844	7049	85	17B
0005434407810	7049	86	17C
0005434407832	7049	87	17D
0005434407855	7049	88	17F
0005432153943	7049	89	17E
0005435293161	7049	90	18B
0005435293153	7049	91	18A
0005434407825	7049	92	18C
0005434407857	7049	93	18E
0005434407862	7049	94	18D
0005434299575	7049	95	18F
0005434299586	7049	96	19A
0005434407827	7049	97	19B
0005435310942	7049	98	19C
0005432153948	7049	99	19D
0005434407809	7049	100	19F
0005435293135	7049	101	19E
0005434407840	7049	102	20A
0005432153944	7049	103	20B
0005434407841	7049	104	20D
0005434407834	7049	105	20C
0005434407831	7049	106	20E
0005434299585	7049	107	21A
0005434299581	7049	108	20F
0005434407814	7049	109	21B
0005435293147	7049	110	21C
0005434407811	7049	111	21D
0005434299579	7049	112	21E
0005435310948	7049	113	21F
0005434299592	7049	114	22B
0005434407813	7049	115	22A
0005434407823	7049	116	22C
0005434407849	7049	117	22E
0005434407807	7049	118	22D
0005434299588	7049	119	22F
0005435310955	7049	120	23A
0005434407816	7049	121	23D
0005435310971	7049	122	23C
0005435293160	7049	123	23E
0005435310961	7049	124	23F
0005435311069	26907	1	1A
0005434407235	26907	2	1C
0005434407267	26907	3	1D
0005435293268	26907	4	1F
0005434407228	26907	5	2C
0005434299373	26907	6	2D
0005435293266	26907	7	3A
0005432058384	26907	8	2F
0005434406915	26907	9	3D
0005434299389	26907	10	3C
0005434407371	26907	11	3F
0005435293262	26907	12	4B
0005434299366	26907	13	4A
0005434299394	26907	14	4C
0005434407041	26907	15	4E
0005434299365	26907	16	4D
0005434407418	26907	17	5A
0005435311067	26907	18	4F
0005434407234	26907	19	5B
0005435311074	26907	20	5D
0005434407268	26907	21	5E
0005434299478	26907	22	5F
0005434407203	26907	23	6B
0005434407227	26907	24	6C
0005435311077	26907	25	6D
0005434407245	26907	26	6E
0005434407050	26907	27	7A
0005434406874	26907	28	6F
0005434299451	26907	29	7B
0005435293272	26907	30	7C
0005435311065	26907	31	7D
0005434299428	26907	32	7F
0005434406899	26907	33	7E
0005434407016	26907	34	8A
0005434407192	26907	35	8B
0005434407353	26907	36	8C
0005434406907	26907	37	8E
0005434407068	26907	38	8D
0005434299334	26907	39	8F
0005434407273	26907	40	9B
0005434407294	26907	41	9A
0005434407378	26907	42	9D
0005434407176	26907	43	9C
0005434299411	26907	44	9E
0005432058382	26907	45	9F
0005434299506	26907	46	10B
0005435293265	26907	47	10D
0005434407130	26907	48	10C
0005435293261	26907	49	11A
0005434407291	26907	50	10E
0005435311070	26907	51	11B
0005432058383	26907	52	11D
0005435311076	26907	53	11C
0005434407232	26907	54	11E
0005434407340	26907	55	11F
0005432058381	26907	56	12A
0005434407314	26907	57	12B
0005434407131	26907	58	12D
0005434299452	26907	59	12C
0005434299361	26907	60	12E
0005434299458	26907	61	12F
0005434299340	26907	62	13B
0005434407196	26907	63	13A
0005434299405	26907	64	13D
0005435293271	26907	65	13C
0005435311066	26907	66	13E
0005435311064	26907	67	13F
0005434407322	26907	68	14B
0005435293260	26907	69	14A
0005434299468	26907	70	14C
0005434299384	26907	71	14D
0005434407566	26907	72	14E
0005434407413	26907	73	14F
0005434299492	26907	74	15B
0005434406906	26907	75	15A
0005435293270	26907	76	15C
0005434299372	26907	77	15D
0005434407321	26907	78	15F
0005435311071	26907	79	15E
0005434407255	26907	80	16B
0005434407328	26907	81	16A
0005434407236	26907	82	16C
0005434407311	26907	83	16D
0005434407313	26907	84	16E
0005432058385	26907	85	17A
0005434299348	26907	86	16F
0005434407073	26907	87	17B
0005434406968	26907	88	17D
0005434407295	26907	89	17F
0005434299429	26907	90	17E
0005434407116	26907	91	18A
0005434407266	26907	92	18B
0005434299399	26907	93	18C
0005435311072	26907	94	18E
0005434407256	26907	95	18D
0005434406914	26907	96	18F
0005434407187	26907	97	19A
0005434299388	26907	98	19B
0005434407208	26907	99	19D
0005434407072	26907	100	19C
0005435293273	26907	101	19E
0005434407178	26907	102	20A
0005434407147	26907	103	20B
0005434299404	26907	104	20D
0005435311073	26907	105	20C
0005434407292	26907	106	20E
0005435311075	26907	107	21A
0005434299444	26907	108	20F
0005435311063	26907	109	21B
0005435311068	26907	110	21C
0005434299387	26907	111	21D
0005434407070	26907	112	21E
0005434299419	26907	113	21F
0005434407015	26907	114	22B
0005434407213	26907	115	22A
0005434299456	26907	116	22C
0005434299333	26907	117	22D
0005434407020	26907	118	22E
0005435293269	26907	119	23A
0005434407085	26907	120	22F
0005434407069	26907	121	23B
0005435293267	26907	122	23C
0005435293263	26907	123	23E
0005435293264	26907	124	23D
0005434407379	26907	125	23F
0005434512125	6472	1	1A
0005432604381	6472	2	1B
0005432604372	6472	3	1D
0005432604378	6472	4	2A
0005434512126	6472	5	2B
0005432604373	6472	6	2C
0005432604394	6472	7	2D
0005432604390	6472	8	3A
0005432604391	6472	9	3C
0005432604388	6472	10	3D
0005432604406	6472	11	4A
0005432604384	6472	12	4B
0005432604398	6472	13	4C
0005432604395	6472	14	4D
0005434512124	6472	15	5A
0005432604376	6472	16	5B
0005434512123	6472	17	5C
0005432604396	6472	18	5D
0005432604387	6472	19	6A
0005432604385	6472	20	6B
0005432604404	6472	21	6C
0005432604377	6472	22	6D
0005432604401	6472	23	7A
0005432604389	6472	24	7B
0005432604403	6472	25	7D
0005432604410	6472	26	18A
0005432604392	6472	27	18B
0005432604393	6472	28	18C
0005432604397	6472	29	18D
0005432604386	6472	30	19A
0005432604399	6472	31	19B
0005432604375	6472	32	19C
0005432604400	6472	33	19D
0005432604411	6472	34	20B
0005432604402	6472	35	20C
0005432604383	6472	36	20D
0005432604382	6472	37	21A
0005432604380	6472	38	21B
0005432604408	6472	39	21C
0005432604374	6472	40	21D
0005432604407	6472	41	22A
0005432604379	6472	42	22C
0005432604409	6472	43	22D
0005432604405	6472	44	23A
0005434512122	6472	45	23B
0005432603853	21341	1	1A
0005432604035	21341	2	1B
0005434512090	21341	3	1C
0005432604045	21341	4	1D
0005434512095	21341	5	2A
0005432604083	21341	6	2B
0005432603958	21341	7	2C
0005432603980	21341	8	2D
0005432603975	21341	9	3A
0005435221514	21341	10	3B
0005432604087	21341	11	4A
0005432603981	21341	12	3D
0005434512094	21341	13	4B
0005434512075	21341	14	4C
0005432603954	21341	15	4D
0005432603938	21341	16	5A
0005432603994	21341	17	5B
0005432603996	21341	18	5C
0005432604242	21341	19	5D
0005432603988	21341	20	6A
0005432604058	21341	21	6B
0005432603855	21341	22	6C
0005434512068	21341	23	6D
0005432603885	21341	24	7A
0005432604243	21341	25	7B
0005432603997	21341	26	7C
0005435221053	21341	27	7D
0005432604037	21341	28	18A
0005432604076	21341	29	18B
0005432603986	21341	30	18C
0005434512076	21341	31	18D
0005432604034	21341	32	19A
0005435221515	21341	33	19B
0005434512067	21341	34	19C
0005432603976	21341	35	19D
0005434512086	21341	36	20A
0005434512077	21341	37	20B
0005435221052	21341	38	20C
0005432603854	21341	39	20D
0005432604046	21341	40	21B
0005432603957	21341	41	21A
0005432603977	21341	42	21C
0005432603992	21341	43	21D
0005432604086	21341	44	22A
0005432604048	21341	45	22C
0005432603993	21341	46	22B
0005432604084	21341	47	22D
0005432604024	21341	48	23A
0005432603856	21341	49	23B
0005434906837	14988	1	1C
0005433251511	14988	2	1D
0005434906590	14988	3	1F
0005434906985	14988	4	2A
0005434906913	14988	5	2D
0005434906800	14988	6	2F
0005433251519	14988	7	3A
0005434906862	14988	8	3F
0005434906954	14988	9	4A
0005434906796	14988	10	4C
0005434906824	14988	11	4D
0005434906848	14988	12	4E
0005434906907	14988	13	4F
0005434906688	14988	14	5A
0005434906791	14988	15	5C
0005434906887	14988	16	5D
0005433251520	14988	17	5E
0005433251525	14988	18	5F
0005434906818	14988	19	6A
0005433251500	14988	20	6C
0005433251504	14988	21	6D
0005434906886	14988	22	6E
0005433251501	14988	23	6F
0005433251526	14988	24	7A
0005434906910	14988	25	7C
0005434906901	14988	26	7D
0005433251506	14988	27	7E
0005433251509	14988	28	7F
0005434907041	14988	29	8C
0005433251496	14988	30	8D
0005433251521	14988	31	8E
0005433251497	14988	32	8F
0005434906762	14988	33	9A
0005434906911	14988	34	9C
0005433251527	14988	35	9E
0005434906906	14988	36	9F
0005433251517	14988	37	10A
0005433251508	14988	38	10C
0005434906781	14988	39	10D
0005434907031	14988	40	10E
0005433251499	14988	41	11A
0005434906697	14988	42	11C
0005434906879	14988	43	11D
0005434906989	14988	44	11E
0005434906847	14988	45	11F
0005433251510	14988	46	12C
0005434906670	14988	47	12D
0005434906849	14988	48	12E
0005434906808	14988	49	12F
0005434907030	14988	50	13A
0005434907025	14988	51	13C
0005433251518	14988	52	13D
0005433251513	14988	53	13E
0005433251524	14988	54	13F
0005434906640	14988	55	14A
0005433251512	14988	56	14C
0005433251505	14988	57	14D
0005434906807	14988	58	14E
0005434906805	14988	59	14F
0005434906600	14988	60	15C
0005434907148	14988	61	15D
0005433251502	14988	62	15E
0005434906955	14988	63	15F
0005433251507	14988	64	16C
0005434906939	14988	65	16D
0005433251503	14988	66	16F
0005433251516	14988	67	17A
0005434906851	14988	68	17C
0005434906902	14988	69	17D
0005434906917	14988	70	17E
0005434906822	14988	71	17F
0005434906687	14988	72	18A
0005433251522	14988	73	18C
0005434906823	14988	74	18D
0005434906905	14988	75	18E
0005434906922	14988	76	18F
0005433251514	14988	77	19A
0005433251498	14988	78	19C
0005434906840	14988	79	19D
0005433251515	14988	80	19E
0005434906970	14988	81	19F
0005433251523	14988	82	20C
0005434906591	14988	83	20D
0005434907042	14988	84	20E
0005434907300	25860	1	1C
0005434907292	25860	2	1A
0005434907280	25860	3	1D
0005434907308	25860	4	1F
0005434907297	25860	5	2A
0005433251268	25860	6	2C
0005434907315	25860	7	2D
0005433251304	25860	8	2F
0005433251243	25860	9	3A
0005434907294	25860	10	3C
0005434907268	25860	11	3D
0005434907305	25860	12	4A
0005434907309	25860	13	4C
0005434907298	25860	14	4D
0005433251241	25860	15	4E
0005434907303	25860	16	4F
0005434907269	25860	17	5A
0005434907293	25860	18	5C
0005433251184	25860	19	5D
0005434907276	25860	20	5E
0005434907307	25860	21	5F
0005434907275	25860	22	6A
0005433251426	25860	23	6C
0005433251277	25860	24	6D
0005434907301	25860	25	6E
0005433251328	25860	26	6F
0005433251138	25860	27	7C
0005433251186	25860	28	7D
0005433251217	25860	29	7E
0005433251326	25860	30	7F
0005434907285	25860	31	8A
0005434907314	25860	32	8D
0005434907282	25860	33	8E
0005433251279	25860	34	8F
0005434907304	25860	35	9A
0005433251216	25860	36	9C
0005433251283	25860	37	9D
0005433251170	25860	38	9E
0005434907287	25860	39	9F
0005434907296	25860	40	10A
0005434907273	25860	41	10C
0005433251185	25860	42	10D
0005434907299	25860	43	10E
0005433251239	25860	44	10F
0005433251126	25860	45	11A
0005434907283	25860	46	11C
0005434907295	25860	47	11D
0005434907289	25860	48	11F
0005433251275	25860	49	12A
0005434907291	25860	50	12C
0005434907302	25860	51	12D
0005433251249	25860	52	12E
0005434907270	25860	53	12F
0005433251280	25860	54	13A
0005433251171	25860	55	13C
0005434907271	25860	56	13D
0005433251285	25860	57	13E
0005433251229	25860	58	13F
0005434907263	25860	59	14A
0005434907288	25860	60	14C
0005434907311	25860	61	14D
0005434907281	25860	62	14E
0005433251276	25860	63	14F
0005434907267	25860	64	15A
0005433251305	25860	65	15C
0005434907274	25860	66	15D
0005434907279	25860	67	15F
0005433251329	25860	68	16A
0005434907278	25860	69	16D
0005434907290	25860	70	16E
0005433251220	25860	71	16F
0005434907306	25860	72	17A
0005434907313	25860	73	17C
0005434907310	25860	74	17D
0005434907266	25860	75	17E
0005434907264	25860	76	17F
0005434907286	25860	77	18A
0005433251124	25860	78	18C
0005434907265	25860	79	18E
0005433251240	25860	80	18F
0005434907277	25860	81	19A
0005433251230	25860	82	19C
0005433251278	25860	83	19D
0005434907284	25860	84	19E
0005433251221	25860	85	19F
0005434907272	25860	86	20A
0005433251125	25860	87	20C
0005433251141	25860	88	20D
0005434907312	25860	89	20E
0005433251286	25860	90	20F
0005433008664	14172	1	1F
0005433008668	14172	2	2C
0005433008685	14172	3	2D
0005433008700	14172	4	3C
0005433008689	14172	5	3F
0005433008678	14172	6	4A
0005433008665	14172	7	4D
0005433008659	14172	8	4F
0005433008697	14172	9	5C
0005433008660	14172	10	5D
0005433008670	14172	11	6A
0005433008696	14172	12	6F
0005433008690	14172	13	7C
0005433008663	14172	14	7D
0005433008672	14172	15	7E
0005433008679	14172	16	8C
0005433008680	14172	17	8D
0005433008692	14172	18	9A
0005433008669	14172	19	9E
0005433008691	14172	20	9F
0005433008658	14172	21	10A
0005433008701	14172	22	10C
0005433008695	14172	23	10D
0005433008683	14172	24	11A
0005433008667	14172	25	11D
0005433008686	14172	26	11F
0005433008682	14172	27	12C
0005433008684	14172	28	12F
0005433008673	14172	29	13C
0005433008693	14172	30	13D
0005433008666	14172	31	13F
0005433008688	14172	32	14A
0005433008702	14172	33	14C
0005433008694	14172	34	14D
0005433008674	14172	35	15E
0005433008676	14172	36	15F
0005433008687	14172	37	16A
0005433008699	14172	38	16C
0005433008662	14172	39	16D
0005433008671	14172	40	17A
0005433008661	14172	41	17F
0005433810506	14172	42	18C
0005433008698	14172	43	18D
0005433008677	14172	44	18F
0005433008681	14172	45	19C
0005433008675	14172	46	20C
0005433008657	14172	47	20E
0005433008334	22870	1	1A
0005433008069	22870	2	1D
0005433810549	22870	3	1F
0005433008132	22870	4	2C
0005433008118	22870	5	2D
0005433008463	22870	6	2F
0005433008320	22870	7	3C
0005433008193	22870	8	3D
0005433008147	22870	9	3F
0005433008076	22870	10	4A
0005433008319	22870	11	4C
0005433008347	22870	12	4D
0005433008206	22870	13	5C
0005433008156	22870	14	5D
0005433008276	22870	15	5E
0005433008317	22870	16	5F
0005433008205	22870	17	6D
0005433008375	22870	18	6E
0005433008241	22870	19	7D
0005433008192	22870	20	7F
0005433008325	22870	21	8A
0005433008282	22870	22	8E
0005433810546	22870	23	9E
0005433008133	22870	24	10A
0005433008422	22870	25	10D
0005433810547	22870	26	10F
0005433008099	22870	27	11F
0005433008346	22870	28	12D
0005433008372	22870	29	12E
0005433008153	22870	30	13C
0005433008383	22870	31	13E
0005433008106	22870	32	14C
0005433008152	22870	33	14D
0005433008264	22870	34	14E
0005433008187	22870	35	14F
0005433008174	22870	36	15A
0005433008200	22870	37	15C
0005433008144	22870	38	15E
0005433008131	22870	39	15F
0005433008423	22870	40	16D
0005433008266	22870	41	16E
0005433008204	22870	42	17A
0005433008338	22870	43	17C
0005433008171	22870	44	17D
0005433008119	22870	45	17F
0005433008079	22870	46	18A
0005433008376	22870	47	18C
0005433008068	22870	48	18D
0005433008218	22870	49	18E
0005433008337	22870	50	18F
0005433008048	22870	51	19D
0005433810548	22870	52	19F
0005433008207	22870	53	20A
0005433008188	22870	54	20C
0005433008143	22870	55	20D
0005433008239	22870	56	20E
0005433008265	22870	57	20F
0005434925492	14948	1	1C
0005434925661	14948	2	1D
0005434925692	14948	3	3D
0005434925420	14948	4	3F
0005434925635	14948	5	4C
0005434925636	14948	6	4D
0005434925663	14948	7	4E
0005434925745	14948	8	5C
0005434925464	14948	9	5E
0005434925649	14948	10	5F
0005434925463	14948	11	6D
0005434925673	14948	12	7D
0005434925577	14948	13	8C
0005434925572	14948	14	8E
0005434925510	14948	15	8F
0005434925524	14948	16	9C
0005434925481	14948	17	11A
0005434925441	14948	18	11E
0005434925674	14948	19	12D
0005434925573	14948	20	12F
0005434925422	14948	21	13C
0005434925553	14948	22	13D
0005434925648	14948	23	14A
0005434925469	14948	24	14D
0005434925512	14948	25	15C
0005434925662	14948	26	15E
0005434925400	14948	27	16D
0005434925456	14948	28	16E
0005434925401	14948	29	17E
0005434925417	14948	30	18C
0005434925419	14948	31	20A
0005434925502	14948	32	20E
0005434925818	20513	1	1A
0005434925831	20513	2	2A
0005434925817	20513	3	4D
0005434925821	20513	4	5C
0005434925819	20513	5	5E
0005434925811	20513	6	6A
0005434925816	20513	7	6D
0005434925813	20513	8	7A
0005434925806	20513	9	7E
0005434925810	20513	10	8D
0005434925814	20513	11	9C
0005434925801	20513	12	9D
0005434925828	20513	13	9F
0005434925822	20513	14	10C
0005434925825	20513	15	10D
0005434925808	20513	16	10F
0005434925830	20513	17	11C
0005434925820	20513	18	12D
0005434925815	20513	19	12E
0005434925826	20513	20	12F
0005434925802	20513	21	13D
0005434925809	20513	22	14A
0005434925803	20513	23	14F
0005434925805	20513	24	15C
0005434925804	20513	25	15F
0005434925812	20513	26	16F
0005434925827	20513	27	17A
0005434925800	20513	28	17C
0005434925824	20513	29	18C
0005434925807	20513	30	18D
0005434925823	20513	31	19C
0005434925829	20513	32	19D
0005435999055	15837	1	1B
0005435487870	15837	2	1C
0005435487853	15837	3	1D
0005435999111	15837	4	2A
0005435999116	15837	5	2B
0005435487857	15837	6	2C
0005435487868	15837	7	2D
0005435999093	15837	8	3A
0005435487858	15837	9	3B
0005435999054	15837	10	3D
0005435487873	15837	11	4A
0005435999092	15837	12	4B
0005435487867	15837	13	4C
0005435487854	15837	14	4D
0005435487863	15837	15	5A
0005435999161	15837	16	5B
0005435487852	15837	17	5C
0005435487872	15837	18	5D
0005435487856	15837	19	6A
0005435999112	15837	20	6B
0005435487866	15837	21	6C
0005435487862	15837	22	6D
0005435487859	15837	23	7A
0005435999089	15837	24	7C
0005435487864	15837	25	7D
0005435487860	15837	26	18A
0005435999095	15837	27	18B
0005435487855	15837	28	18C
0005435999065	15837	29	18D
0005435999106	15837	30	19A
0005435487861	15837	31	19B
0005435487865	15837	32	19D
0005435999164	15837	33	20C
0005435487871	15837	34	21A
0005435487869	15837	35	21B
0005435999107	15837	36	21D
0005435999159	15837	37	22C
0005435999160	15837	38	23A
0005435999120	15837	39	23B
0005435487589	19681	1	1B
0005435999256	19681	2	1C
0005435487751	19681	3	1D
0005435999251	19681	4	2B
0005435487618	19681	5	2C
0005435999250	19681	6	2D
0005435999264	19681	7	3A
0005435999253	19681	8	3B
0005435487633	19681	9	3C
0005435999257	19681	10	3D
0005435487592	19681	11	4A
0005435487486	19681	12	4B
0005435999258	19681	13	4D
0005435999255	19681	14	4C
0005435999261	19681	15	5B
0005435487702	19681	16	5D
0005435999252	19681	17	6B
0005435487599	19681	18	6A
0005435999249	19681	19	6C
0005435487569	19681	20	6D
0005435487685	19681	21	7A
0005435487521	19681	22	7B
0005435487591	19681	23	7C
0005435487686	19681	24	7D
0005435999254	19681	25	18D
0005435487617	19681	26	19B
0005435487484	19681	27	19C
0005435487644	19681	28	20A
0005435487645	19681	29	20C
0005435999262	19681	30	20D
0005435487616	19681	31	21A
0005435487707	19681	32	21D
0005435999265	19681	33	22A
0005435487485	19681	34	22C
0005435999263	19681	35	22D
0005435999260	19681	36	23A
0005435999259	19681	37	23B
0005435839502	6016	1	1D
0005435839492	6016	2	2A
0005432142257	6016	3	2F
0005435839490	6016	4	3F
0005435839503	6016	5	5A
0005435839500	6016	6	5F
0005435839501	6016	7	5D
0005435839478	6016	8	6A
0005435839483	6016	9	6B
0005435839481	6016	10	6E
0005435839496	6016	11	7B
0005435472718	6016	12	7E
0005435472556	6016	13	8C
0005435839493	6016	14	9A
0005435839499	6016	15	9E
0005435839485	6016	16	10B
0005435472707	6016	17	9F
0005435472727	6016	18	10C
0005432659709	6016	19	10E
0005435472674	6016	20	10D
0005435839491	6016	21	10F
0005432658595	6016	22	11C
0005435839487	6016	23	11D
0005435839486	6016	24	11E
0005432660822	6016	25	12D
0005435472705	6016	26	13B
0005435472675	6016	27	13A
0005435472666	6016	28	13D
0005435839497	6016	29	13C
0005435472684	6016	30	13E
0005435839480	6016	31	14A
0005432659710	6016	32	14D
0005435839494	6016	33	14E
0005435472676	6016	34	15B
0005432660821	6016	35	15D
0005435839482	6016	36	15E
0005435472648	6016	37	16A
0005435472704	6016	38	16C
0005435839489	6016	39	16B
0005435472662	6016	40	17D
0005435839495	6016	41	17C
0005435839479	6016	42	17E
0005432142256	6016	43	18B
0005435472728	6016	44	18A
0005435839498	6016	45	18F
0005435839484	6016	46	19C
0005435839476	6016	47	19D
0005435839504	6016	48	20A
0005435839477	6016	49	21A
0005435839488	6016	50	21C
0005435472686	6016	51	21D
0005432537062	18050	1	1F
0005435839200	18050	2	1D
0005435839229	18050	3	2C
0005435472817	18050	4	4D
0005435472827	18050	5	4F
0005435839266	18050	6	5F
0005435839347	18050	7	5D
0005435472825	18050	8	6A
0005435839353	18050	9	6B
0005435617235	18050	10	6E
0005435472823	18050	11	6D
0005432664113	18050	12	7A
0005435839210	18050	13	6F
0005435839239	18050	14	7E
0005435472831	18050	15	7D
0005435839212	18050	16	8C
0005435472821	18050	17	8F
0005435839346	18050	18	8E
0005435472818	18050	19	9A
0005435839206	18050	20	9E
0005435839267	18050	21	10C
0005435839179	18050	22	11E
0005435472820	18050	23	12A
0005435839250	18050	24	12C
0005435839249	18050	25	12F
0005435839178	18050	26	13B
0005435472819	18050	27	14B
0005435839242	18050	28	15A
0005432660798	18050	29	15D
0005435617234	18050	30	16A
0005432537061	18050	31	17A
0005435839228	18050	32	17D
0005435472824	18050	33	17F
0005435839283	18050	34	17E
0005435472822	18050	35	18F
0005435472828	18050	36	19B
0005432667429	18050	37	19F
0005435472826	18050	38	19E
0005435839180	18050	39	20F
0005435472829	18050	40	20E
0005435472830	18050	41	21C
0005432664127	18050	42	21B
0005435472816	18050	43	21D
0005435472815	18050	44	21F
0005433285078	23056	1	1A
0005435103936	23056	2	2C
0005435103940	23056	3	2D
0005433285172	23056	4	2F
0005433284993	23056	5	4B
0005433284971	23056	6	4D
0005435103934	23056	7	5B
0005435103935	23056	8	5C
0005433284972	23056	9	8B
0005433285016	23056	10	9E
0005433285079	23056	11	9F
0005433285049	23056	12	10E
0005433285173	23056	13	11D
0005433285096	23056	14	11C
0005435103938	23056	15	11E
0005433285057	23056	16	11F
0005433285129	23056	17	12A
0005433285127	23056	18	12D
0005433285171	23056	19	12E
0005433284970	23056	20	13C
0005433285018	23056	21	14D
0005433285025	23056	22	15A
0005433285058	23056	23	14F
0005433285077	23056	24	15B
0005435103933	23056	25	17A
0005433285150	23056	26	16F
0005433285000	23056	27	17E
0005433285011	23056	28	17F
0005435103941	23056	29	18E
0005435103939	23056	30	19C
0005433285170	23056	31	19F
0005433285038	23056	32	20C
0005435103937	23056	33	21C
0005433285048	23056	34	23C
0005433285337	32087	1	1C
0005433285342	32087	2	2A
0005433285336	32087	3	2C
0005433285343	32087	4	3F
0005433285333	32087	5	4E
0005433285334	32087	6	5E
0005433285341	32087	7	5F
0005433285332	32087	8	6A
0005433285349	32087	9	6D
0005433285348	32087	10	7B
0005433285355	32087	11	8A
0005433285340	32087	12	8B
0005433285331	32087	13	8D
0005433285353	32087	14	8F
0005433285329	32087	15	9F
0005433285327	32087	16	10D
0005435103839	32087	17	11E
0005433285358	32087	18	11F
0005433285328	32087	19	12B
0005433285346	32087	20	13B
0005433285335	32087	21	14E
0005433285344	32087	22	14F
0005433285345	32087	23	15F
0005433285330	32087	24	17A
0005433285356	32087	25	17C
0005433285347	32087	26	17E
0005433285352	32087	27	18A
0005433285357	32087	28	19C
0005433285350	32087	29	19D
0005433285338	32087	30	19F
0005433285339	32087	31	20C
0005433285354	32087	32	21B
0005433285351	32087	33	23A
0005434067263	30632	1	1C
0005435213675	30632	2	1A
0005434066615	30632	3	1D
0005435213679	30632	4	1K
0005432527397	30632	5	2C
0005432527557	30632	6	2A
0005434067091	30632	7	2H
0005432526875	30632	8	2G
0005432527238	30632	9	2D
0005435213667	30632	10	3A
0005434067089	30632	11	2K
0005435213666	30632	12	3C
0005432527313	30632	13	3H
0005434066817	30632	14	4C
0005434066971	30632	15	4A
0005435213654	30632	16	4G
0005432527447	30632	17	4D
0005434067254	30632	18	4K
0005432526874	30632	19	4H
0005432526992	30632	20	5C
0005432526684	30632	21	5A
0005432527203	30632	22	5H
0005432526928	30632	23	5G
0005434066822	30632	24	5D
0005435213685	30632	25	5K
0005435213688	30632	26	11D
0005432526805	30632	27	11C
0005432527292	30632	28	11G
0005432428919	30632	29	11F
0005432526628	30632	30	11E
0005435213713	30632	31	11H
0005434066934	30632	32	12C
0005435213689	30632	33	12E
0005432526631	30632	34	12D
0005435213674	30632	35	12G
0005432527333	30632	36	13A
0005434067151	30632	37	12H
0005434066994	30632	38	13C
0005434067082	30632	39	13F
0005434067019	30632	40	13E
0005435213659	30632	41	13K
0005435725609	30632	42	13H
0005434067265	30632	43	14C
0005432526792	30632	44	14A
0005435213694	30632	45	14D
0005434066933	30632	46	14G
0005432526844	30632	47	14H
0005435213647	30632	48	15C
0005432527102	30632	49	15A
0005432526461	30632	50	15F
0005432526597	30632	51	15D
0005434067014	30632	52	15G
0005434067041	30632	53	15K
0005432527010	30632	54	16D
0005432526995	30632	55	16C
0005435213649	30632	56	16A
0005432211518	30632	57	16G
0005432527022	30632	58	16E
0005432526872	30632	59	16K
0005435213676	30632	60	17A
0005434067209	30632	61	17D
0005435725613	30632	62	17C
0005433656677	30632	63	17F
0005432526810	30632	64	18A
0005432159867	30632	65	18C
0005432527040	30632	66	18G
0005432527809	30632	67	18F
0005432527159	30632	68	18K
0005432527257	30632	69	18J
0005435213711	30632	70	19B
0005432159864	30632	71	19A
0005432527372	30632	72	19D
0005434067003	30632	73	19F
0005435213652	30632	74	19E
0005432527585	30632	75	19H
0005432535782	30632	76	20A
0005435213696	30632	77	19K
0005432527248	30632	78	19J
0005434066984	30632	79	20B
0005435213684	30632	80	20E
0005432527251	30632	81	20D
0005432527176	30632	82	20C
0005434067040	30632	83	20G
0005432533276	30632	84	20F
0005434066659	30632	85	20J
0005432527371	30632	86	20H
0005434067124	30632	87	21B
0005432527194	30632	88	21A
0005435213663	30632	89	20K
0005434067146	30632	90	21D
0005432211513	30632	91	21C
0005432527048	30632	92	21F
0005434066751	30632	93	21E
0005432527422	30632	94	21J
0005434066974	30632	95	21G
0005435213661	30632	96	22A
0005434067046	30632	97	21K
0005435213650	30632	98	22B
0005432527531	30632	99	22F
0005435213686	30632	100	22E
0005434067065	30632	101	22G
0005434066940	30632	102	22K
0005432159865	30632	103	22J
0005433656679	30632	104	22H
0005432535813	30632	105	23B
0005432535798	30632	106	23A
0005434066750	30632	107	23E
0005432527047	30632	108	23D
0005432527090	30632	109	23C
0005434066614	30632	110	23G
0005435213693	30632	111	23F
0005435213665	30632	112	23K
0005435213708	30632	113	23J
0005435213671	30632	114	24G
0005432527153	30632	115	24F
0005432527416	30632	116	25B
0005432159866	30632	117	25A
0005432527363	30632	118	25C
0005432428921	30632	119	25E
0005435213687	30632	120	25D
0005434067157	30632	121	25H
0005434066885	30632	122	25G
0005434066660	30632	123	25K
0005434067348	30632	124	25J
0005434067170	30632	125	26C
0005432527412	30632	126	26B
0005432527584	30632	127	26E
0005432527636	30632	128	26D
0005435213699	30632	129	26G
0005432526873	30632	130	26F
0005434066693	30632	131	26J
0005435213701	30632	132	26H
0005432526482	30632	133	27B
0005432527448	30632	134	27A
0005434066767	30632	135	26K
0005434067203	30632	136	27C
0005432527327	30632	137	27F
0005435213683	30632	138	27E
0005434067208	30632	139	27D
0005432211520	30632	140	27H
0005432527012	30632	141	27G
0005432526994	30632	142	27K
0005434067253	30632	143	27J
0005435213657	30632	144	28C
0005432527328	30632	145	28B
0005432527334	30632	146	28A
0005434066935	30632	147	28E
0005435213704	30632	148	28G
0005432527439	30632	149	28F
0005435213680	30632	150	28J
0005433656678	30632	151	28H
0005435213673	30632	152	29B
0005432526804	30632	153	28K
0005432526849	30632	154	29D
0005432527502	30632	155	29C
0005432526847	30632	156	29F
0005432527379	30632	157	29E
0005435213677	30632	158	29G
0005435213705	30632	159	29K
0005435213697	30632	160	29J
0005434067100	30632	161	30B
0005435213709	30632	162	30E
0005432527062	30632	163	30D
0005435213655	30632	164	30G
0005432526629	30632	165	30F
0005434067349	30632	166	30K
0005432526639	30632	167	30J
0005434066914	30632	168	30H
0005435213698	30632	169	31A
0005432526946	30632	170	31B
0005432527289	30632	171	31F
0005432526970	30632	172	31H
0005432527169	30632	173	31G
0005434067073	30632	174	31J
0005434066821	30632	175	32A
0005432527472	30632	176	32E
0005432527309	30632	177	32D
0005432526983	30632	178	32F
0005435213662	30632	179	32K
0005435213691	30632	180	32H
0005434067125	30632	181	33B
0005434067162	30632	182	33A
0005432527027	30632	183	33D
0005435213707	30632	184	33C
0005432527365	30632	185	33F
0005432527353	30632	186	33E
0005432527380	30632	187	33H
0005435213678	30632	188	33G
0005434067010	30632	189	33K
0005434067042	30632	190	33J
0005434066896	30632	191	34C
0005434067174	30632	192	34B
0005432527049	30632	193	34A
0005435213651	30632	194	34G
0005434067320	30632	195	34F
0005432526918	30632	196	34K
0005432527089	30632	197	35B
0005432526958	30632	198	35A
0005432526903	30632	199	35D
0005432159868	30632	200	35C
0005432526630	30632	201	35E
0005432527450	30632	202	35H
0005435213664	30632	203	36A
0005434066857	30632	204	35K
0005432527310	30632	205	35J
0005435630972	30632	206	36C
0005434067093	30632	207	36B
0005432527332	30632	208	36F
0005432527210	30632	209	36E
0005435213681	30632	210	36H
0005434066897	30632	211	36G
0005435213690	30632	212	36K
0005434066986	30632	213	36J
0005435213692	30632	214	37B
0005432527745	30632	215	37D
0005432527191	30632	216	37F
0005432527620	30632	217	37E
0005435630973	30632	218	37J
0005432527746	30632	219	37H
0005432527258	30632	220	38A
0005435213703	30632	221	37K
0005435213656	30632	222	38C
0005432428922	30632	223	38B
0005435725612	30632	224	38K
0005435725611	30632	225	38J
0005434066848	30632	226	38H
0005432527381	30632	227	39A
0005432211516	30632	228	39D
0005432527252	30632	229	39C
0005435213714	30632	230	39E
0005435213646	30632	231	39H
0005432526848	30632	232	39G
0005432527536	30632	233	39K
0005432527311	30632	234	40C
0005432526870	30632	235	40B
0005432526598	30632	236	40E
0005432527317	30632	237	40D
0005432526855	30632	238	40H
0005432527433	30632	239	40F
0005432211519	30632	240	40J
0005432526919	30632	241	41B
0005434067081	30632	242	41A
0005432526854	30632	243	40K
0005432527140	30632	244	41D
0005432526947	30632	245	41C
0005434066818	30632	246	41F
0005432527013	30632	247	41G
0005432527451	30632	248	42A
0005432526868	30632	249	41J
0005432527314	30632	250	42C
0005434067235	30632	251	42E
0005432526843	30632	252	42D
0005432211517	30632	253	42G
0005432527075	30632	254	42F
0005435213648	30632	255	42J
0005435213712	30632	256	42H
0005432527250	30632	257	43B
0005435213669	30632	258	43A
0005434067066	30632	259	42K
0005432428910	30632	260	43C
0005434067045	30632	261	43F
0005435213668	30632	262	43E
0005432527088	30632	263	43G
0005432526462	30632	264	43K
0005432527074	30632	265	43J
0005432428918	30632	266	44C
0005432526899	30632	267	44B
0005432527417	30632	268	44A
0005434066941	30632	269	44E
0005432527243	30632	270	44D
0005432526871	30632	271	44H
0005432526869	30632	272	44G
0005432526943	30632	273	44F
0005434067092	30632	274	44J
0005432527377	30632	275	45B
0005432533272	30632	276	45A
0005435213658	30632	277	44K
0005432527569	30632	278	45C
0005435213660	30632	279	45E
0005435213710	30632	280	45D
0005432527028	30632	281	45H
0005432526853	30632	282	45G
0005435213670	30632	283	46A
0005432428917	30632	284	45K
0005432527099	30632	285	45J
0005432211515	30632	286	46C
0005435213695	30632	287	46E
0005435213702	30632	288	46D
0005432537038	30632	289	46G
0005432535781	30632	290	46F
0005434066970	30632	291	47A
0005435213700	30632	292	47E
0005434066878	30632	293	47D
0005432527009	30632	294	47C
0005432526683	30632	295	47G
0005434067180	30632	296	47F
0005432527432	30632	297	47H
0005435725610	30632	298	48D
0005432527338	30632	299	48A
0005432211514	30632	300	48E
0005434066731	30632	301	48H
0005432527548	30632	302	48G
0005435213706	30632	303	48F
0005432527329	30632	304	49A
0005434066811	30632	305	48K
0005434067236	30632	306	49D
0005432527026	30632	307	49C
0005435213653	30632	308	49F
0005434066801	30632	309	49E
0005432526997	30632	310	49K
0005432535783	30632	311	49H
0005435630974	30632	312	50A
0005432527195	30632	313	50F
0005432535795	30632	314	50E
0005435213682	30632	315	50D
0005435213672	30632	316	50G
0005434067264	30632	317	50K
0005432527449	30632	318	50H
0005434067210	30632	319	51E
0005432527403	30632	320	51G
0005435652766	24850	1	1A
0005435652644	24850	2	1C
0005433367958	24850	3	1D
0005435652816	24850	4	1F
0005433367963	24850	5	2C
0005433367948	24850	6	2D
0005435652745	24850	7	3A
0005435652820	24850	8	3C
0005435652777	24850	9	3D
0005435652826	24850	10	3F
0005433367950	24850	11	4A
0005435652596	24850	12	4C
0005433367967	24850	13	4D
0005435652801	24850	14	4E
0005433367964	24850	15	4F
0005433367966	24850	16	5A
0005433367965	24850	17	5C
0005433367957	24850	18	5D
0005433367979	24850	19	5E
0005435652800	24850	20	5F
0005435652706	24850	21	6D
0005433367983	24850	22	6E
0005435652783	24850	23	6F
0005435652571	24850	24	7A
0005435652769	24850	25	7C
0005435652651	24850	26	7D
0005433367971	24850	27	7E
0005433367977	24850	28	7F
0005435652623	24850	29	8A
0005435652776	24850	30	8C
0005433367974	24850	31	8D
0005435652536	24850	32	8E
0005435652746	24850	33	8F
0005433367986	24850	34	9A
0005433367960	24850	35	9C
0005435652770	24850	36	9D
0005435652625	24850	37	9F
0005433367978	24850	38	10A
0005433367949	24850	39	10C
0005435652681	24850	40	10D
0005433367969	24850	41	10E
0005433367972	24850	42	10F
0005433367959	24850	43	11A
0005435652535	24850	44	11C
0005433367951	24850	45	11D
0005435652701	24850	46	11E
0005433367980	24850	47	11F
0005435652686	24850	48	12A
0005433367975	24850	49	12C
0005435652707	24850	50	12D
0005435652677	24850	51	12E
0005433367955	24850	52	12F
0005435652731	24850	53	13A
0005433367962	24850	54	13C
0005435652624	24850	55	13D
0005435652590	24850	56	13F
0005433367953	24850	57	14A
0005435652552	24850	58	14C
0005435652737	24850	59	14D
0005433367968	24850	60	14E
0005435652595	24850	61	14F
0005433367976	24850	62	15A
0005433367973	24850	63	15D
0005433367956	24850	64	15E
0005433367984	24850	65	15F
0005433367982	24850	66	16A
0005433367970	24850	67	16D
0005435652655	24850	68	16F
0005433367985	24850	69	17A
0005433367952	24850	70	17D
0005435652717	24850	71	17F
0005435652561	24850	72	18A
0005435652835	24850	73	18C
0005435652827	24850	74	18D
0005435652819	24850	75	18E
0005435652685	24850	76	18F
0005435652691	24850	77	19A
0005433367961	24850	78	19C
0005433367954	24850	79	19D
0005435652822	24850	80	19E
0005435652738	24850	81	19F
0005435652810	24850	82	20A
0005435652440	24850	83	20C
0005435652621	24850	84	20D
0005435652676	24850	85	20E
0005433367981	24850	86	20F
0005434979837	2040	1	1A
0005434979848	2040	2	1D
0005434979853	2040	3	2A
0005435801701	2040	4	2C
0005434979860	2040	5	2D
0005434979852	2040	6	3B
0005434979859	2040	7	3C
0005434979856	2040	8	4A
0005434979866	2040	9	4B
0005434979857	2040	10	4D
0005434979862	2040	11	5A
0005434979844	2040	12	6A
0005434979865	2040	13	6B
0005434979863	2040	14	6C
0005435801703	2040	15	6D
0005435801702	2040	16	7A
0005434979843	2040	17	7B
0005434979855	2040	18	7C
0005434979864	2040	19	7D
0005434979851	2040	20	18A
0005434979841	2040	21	18B
0005434979845	2040	22	19A
0005434979840	2040	23	18D
0005434979849	2040	24	19C
0005434979838	2040	25	20A
0005434979858	2040	26	20D
0005435801705	2040	27	21A
0005435801704	2040	28	21B
0005434979847	2040	29	21C
0005434979854	2040	30	21D
0005434979850	2040	31	22A
0005434979842	2040	32	22C
0005434979839	2040	33	22D
0005434979861	2040	34	23A
0005434979846	2040	35	23B
0005434979620	23527	1	1A
0005434979582	23527	2	1B
0005434979573	23527	3	1C
0005434979492	23527	4	1D
0005434979595	23527	5	2B
0005434979570	23527	6	2A
0005434979586	23527	7	2D
0005434979587	23527	8	3B
0005435801671	23527	9	4A
0005434979606	23527	10	4B
0005434979525	23527	11	5A
0005434979546	23527	12	5D
0005434979376	23527	13	6A
0005434979557	23527	14	6D
0005434979612	23527	15	7A
0005434979584	23527	16	7D
0005434979515	23527	17	18A
0005434979516	23527	18	18B
0005434979545	23527	19	18D
0005434979500	23527	20	19A
0005434979608	23527	21	19C
0005434979585	23527	22	20A
0005434979583	23527	23	20B
0005434979501	23527	24	20C
0005434979491	23527	25	20D
0005434979621	23527	26	21A
0005434979293	23527	27	21D
0005434979556	23527	28	22A
0005434979507	23527	29	22B
0005434979555	23527	30	22C
0005434979510	23527	31	23A
0005434979554	23527	32	23B
0005434952540	2617	1	1B
0005434952537	2617	2	2A
0005434952539	2617	3	3B
0005434952541	2617	4	6A
0005434952538	2617	5	6B
0005433256425	28213	1	1B
0005434952505	28213	2	2A
0005434952503	28213	3	4A
0005433256426	28213	4	5A
0005434952500	28213	5	5B
0005433256427	28213	6	6B
0005433111510	19752	1	1A
0005433111511	19752	2	1B
0005433112379	19752	3	2B
0005434137504	11959	1	1A
0005434137600	11959	2	1C
0005434137337	11959	3	1D
0005434137623	11959	4	1F
0005434137764	11959	5	2A
0005434137707	11959	6	2C
0005434137543	11959	7	2D
0005434137575	11959	8	2F
0005434137313	11959	9	3A
0005434137668	11959	10	3D
0005434137510	11959	11	3F
0005434137874	11959	12	4A
0005434137515	11959	13	4C
0005434137588	11959	14	4D
0005434137875	11959	15	4E
0005434136882	11959	16	4F
0005434137418	11959	17	5A
0005434137858	11959	18	5C
0005434137419	11959	19	5E
0005434137500	11959	20	5F
0005434137831	11959	21	6A
0005434137412	11959	22	6C
0005434137778	11959	23	6D
0005434137837	11959	24	6E
0005434137026	11959	25	6F
0005434137817	11959	26	7D
0005434137291	11959	27	7E
0005434137739	11959	28	7F
0005434137736	11959	29	8A
0005434137807	11959	30	8C
0005434137570	11959	31	8D
0005434137622	11959	32	8E
0005434137862	11959	33	8F
0005434137610	11959	34	9A
0005434137499	11959	35	9C
0005434137675	11959	36	9D
0005434137734	11959	37	9E
0005434137511	11959	38	9F
0005434137801	11959	39	10A
0005434137183	11959	40	10D
0005434137629	11959	41	10E
0005434137697	11959	42	10F
0005434137360	11959	43	11C
0005434137732	11959	44	11D
0005434137560	11959	45	11E
0005434137809	11959	46	12C
0005434137258	11959	47	12D
0005434137444	11959	48	12E
0005434137503	11959	49	13A
0005434137876	11959	50	13C
0005434137498	11959	51	13E
0005434137863	11959	52	13F
0005434137733	11959	53	14C
0005434137445	11959	54	14E
0005434137469	11959	55	14D
0005434137446	11959	56	14F
0005434137598	11959	57	15A
0005434137599	11959	58	15C
0005434137667	11959	59	15D
0005434137880	11959	60	15E
0005434137823	11959	61	16A
0005434137735	11959	62	16C
0005434137585	11959	63	16D
0005434137559	11959	64	16E
0005434137615	11959	65	16F
0005434137674	11959	66	17A
0005434137808	11959	67	17C
0005434137824	11959	68	17D
0005434137836	11959	69	17E
0005434137601	11959	70	17F
0005434137607	11959	71	18A
0005434137606	11959	72	18C
0005434137586	11959	73	18D
0005434137763	11959	74	18E
0005434137718	11959	75	18F
0005434137609	11959	76	19A
0005434137627	11959	77	19D
0005434137628	11959	78	19E
0005434137338	11959	79	19F
0005434137415	11959	80	20A
0005434137608	11959	81	20C
0005434137262	11959	82	20D
0005434137073	11959	83	20E
0005434137587	11959	84	20F
0005434138301	28710	1	1A
0005434138278	28710	2	1C
0005434138292	28710	3	1D
0005434138235	28710	4	1F
0005434138262	28710	5	2A
0005434138269	28710	6	2D
0005434138270	28710	7	2F
0005434138293	28710	8	3A
0005434138247	28710	9	3C
0005434138289	28710	10	3D
0005434138298	28710	11	3F
0005434138260	28710	12	4A
0005434138219	28710	13	4C
0005434138238	28710	14	4D
0005434138251	28710	15	4E
0005434138229	28710	16	4F
0005434138224	28710	17	5A
0005434138245	28710	18	5C
0005434138252	28710	19	5E
0005434138239	28710	20	5D
0005434138281	28710	21	5F
0005434138261	28710	22	6C
0005434138275	28710	23	6D
0005434138256	28710	24	6E
0005434138273	28710	25	6F
0005434138220	28710	26	7A
0005434138225	28710	27	7C
0005434138258	28710	28	7D
0005434138243	28710	29	7E
0005434138299	28710	30	7F
0005434138255	28710	31	8A
0005434138303	28710	32	8C
0005434138300	28710	33	8E
0005434138296	28710	34	8F
0005434138249	28710	35	9A
0005434138271	28710	36	9C
0005434138287	28710	37	9D
0005434138241	28710	38	9E
0005434138236	28710	39	10A
0005434138226	28710	40	10C
0005434138230	28710	41	10D
0005434138284	28710	42	10E
0005434138279	28710	43	10F
0005434138297	28710	44	11A
0005434138268	28710	45	11C
0005434138295	28710	46	11D
0005434138263	28710	47	11E
0005434138216	28710	48	11F
0005434138265	28710	49	12A
0005434138302	28710	50	12D
0005434138283	28710	51	12E
0005434138266	28710	52	12F
0005434138231	28710	53	13A
0005434138215	28710	54	13C
0005434138228	28710	55	13D
0005434138232	28710	56	13E
0005434138221	28710	57	13F
0005434138294	28710	58	14A
0005434138242	28710	59	14C
0005434138248	28710	60	14D
0005434138253	28710	61	14E
0005434138222	28710	62	14F
0005434138254	28710	63	15A
0005434138290	28710	64	15C
0005434138267	28710	65	15D
0005434138246	28710	66	15E
0005434138259	28710	67	15F
0005434138264	28710	68	16A
0005434138304	28710	69	16C
0005434138272	28710	70	16D
0005434138233	28710	71	16E
0005434138282	28710	72	16F
0005434138285	28710	73	17C
0005434138227	28710	74	17D
0005434138305	28710	75	17E
0005434138240	28710	76	17F
0005434138257	28710	77	18A
0005434138277	28710	78	18C
0005434138234	28710	79	18D
0005434138250	28710	80	18E
0005434138218	28710	81	18F
0005434138217	28710	82	19A
0005434138286	28710	83	19C
0005434138276	28710	84	19D
0005434138288	28710	85	19E
0005434138223	28710	86	19F
0005434138291	28710	87	20A
0005434138237	28710	88	20C
0005434138244	28710	89	20D
0005434138280	28710	90	20E
0005434138274	28710	91	20F
0005433534503	6792	1	2C
0005433538885	6792	2	3A
0005433538891	6792	3	3D
0005433538892	6792	4	5B
0005433538889	6792	5	6D
0005433538890	6792	6	7D
0005433538888	6792	7	18C
0005433538887	6792	8	19B
0005433534502	6792	9	19C
0005433538884	6792	10	20D
0005435259738	6792	11	21C
0005433538886	6792	12	22B
0005433538817	25019	1	2A
0005435259767	25019	2	2D
0005433538792	25019	3	4A
0005435259766	25019	4	4D
0005433538820	25019	5	5C
0005433538816	25019	6	6A
0005435259764	25019	7	7B
0005433538793	25019	8	18B
0005433538822	25019	9	19B
0005433538821	25019	10	20B
0005433538783	25019	11	20D
0005433538777	25019	12	22B
0005435259765	25019	13	23B
0005433511967	811	1	1B
0005433511971	811	2	1D
0005433511970	811	3	2A
0005433511972	811	4	3D
0005432922502	811	5	5C
0005432922495	811	6	7A
0005433511968	811	7	7C
0005432922494	811	8	18A
0005433511969	811	9	20B
0005432922490	811	10	22B
0005433511927	16159	1	1B
0005432922533	16159	2	1D
0005433511887	16159	3	2B
0005433511925	16159	4	3A
0005433511915	16159	5	6D
0005433511924	16159	6	7D
0005433511889	16159	7	18A
0005433511923	16159	8	21B
0005432922535	16159	9	22B
0005432922534	16159	10	23B
0005435852563	4032	1	3A
0005433475713	4032	2	3C
0005433475712	4032	3	3D
0005433475716	4032	4	4B
0005433475707	4032	5	4C
0005435852553	4032	6	4D
0005435852558	4032	7	5A
0005435852557	4032	8	5C
0005433475714	4032	9	6B
0005433475711	4032	10	7A
0005435852556	4032	11	7B
0005435852545	4032	12	7C
0005435852547	4032	13	18B
0005435852548	4032	14	18D
0005433475718	4032	15	19B
0005433475715	4032	16	19D
0005435852549	4032	17	20D
0005433475709	4032	18	21A
0005433475717	4032	19	21C
0005435852555	4032	20	21D
0005433475710	4032	21	23A
0005433475708	4032	22	23B
0005435697412	3688	1	1A
0005435697408	3688	2	1C
0005435697411	3688	3	1D
0005435697391	3688	4	2B
0005435697409	3688	5	2D
0005435697405	3688	6	3A
0005434950537	3688	7	3B
0005435697396	3688	8	3D
0005435697402	3688	9	4A
0005435935027	3688	10	5A
0005435697394	3688	11	5B
0005435697414	3688	12	5C
0005435935036	3688	13	5D
0005434950538	3688	14	6A
0005435697413	3688	15	6B
0005435697399	3688	16	6C
0005435697393	3688	17	6D
0005435697416	3688	18	7A
0005435697401	3688	19	7B
0005435697398	3688	20	7C
0005435697397	3688	21	7D
0005435697407	3688	22	18A
0005435697403	3688	23	18B
0005435697395	3688	24	18D
0005434950539	3688	25	19A
0005435935025	3688	26	19B
0005435697415	3688	27	19C
0005435697406	3688	28	19D
0005435935037	3688	29	20A
0005435916164	3688	30	20B
0005435916165	3688	31	20C
0005435697390	3688	32	20D
0005435697392	3688	33	21A
0005435697410	3688	34	21D
0005435697404	3688	35	22A
0005435935026	3688	36	22B
0005435697400	3688	37	22D
0005434950540	3688	38	23A
0005435697106	16273	1	1A
0005435697129	16273	2	1B
0005435697155	16273	3	1D
0005435697092	16273	4	2A
0005435697180	16273	5	2B
0005435697171	16273	6	2C
0005435916174	16273	7	2D
0005435697089	16273	8	3A
0005435697136	16273	9	3B
0005435697222	16273	10	3C
0005435697192	16273	11	3D
0005435697206	16273	12	4A
0005435697221	16273	13	4B
0005435697162	16273	14	4C
0005435697161	16273	15	4D
0005434950515	16273	16	5A
0005435697105	16273	17	5B
0005435697157	16273	18	5C
0005435697130	16273	19	5D
0005435935049	16273	20	6A
0005435697087	16273	21	6B
0005435697167	16273	22	6C
0005435697135	16273	23	6D
0005435697179	16273	24	7B
0005435916173	16273	25	7C
0005435697207	16273	26	18B
0005435697298	16273	27	19A
0005435697154	16273	28	19B
0005435697191	16273	29	19C
0005434950507	16273	30	19D
0005435697093	16273	31	20A
0005435935050	16273	32	20B
0005435697122	16273	33	20C
0005435697299	16273	34	20D
0005435697160	16273	35	21B
0005435696965	16273	36	21C
0005435697133	16273	37	21D
0005435935051	16273	38	22A
0005435697247	16273	39	22B
0005435697156	16273	40	22D
0005435697199	16273	41	23A
0005435935048	16273	42	23B
0005432609741	3967	1	1A
0005433519469	3967	2	1C
0005433519466	3967	3	1D
0005435853595	3967	4	2A
0005434606835	3967	5	2B
0005433519465	3967	6	2C
0005433519468	3967	7	2D
0005434604908	3967	8	3A
0005432609740	3967	9	4D
0005435841467	3967	10	5B
0005435853603	3967	11	5D
0005434604906	3967	12	5C
0005432609739	3967	13	6B
0005435904893	3967	14	6D
0005435853604	3967	15	7A
0005432607574	3967	16	7C
0005435841469	3967	17	7B
0005434604905	3967	18	18D
0005434604907	3967	19	19A
0005434606836	3967	20	19D
0005433519467	3967	21	20B
0005435841468	3967	22	20D
0005434606834	3967	23	21A
0005432607575	3967	24	21C
0005432607573	3967	25	21D
0005434604904	3967	26	22B
0005432607576	3967	27	22C
0005435853594	3967	28	23A
0005433519400	22051	1	1A
0005435904895	22051	2	4B
0005435853615	22051	3	7D
0005434606794	22051	4	18D
0005435853614	22051	5	19C
0005433519431	22051	6	20C
0005433348946	771	1	1A
0005433348949	771	2	1B
0005433348976	771	3	2A
0005433348943	771	4	2B
0005433348957	771	5	3A
0005433348945	771	6	3B
0005433348948	771	7	5A
0005433348973	771	8	4B
0005433348955	771	9	5B
0005433348956	771	10	6A
0005433348975	771	11	6B
0005433349001	15967	1	1A
0005433349002	15967	2	1B
0005435628705	15967	3	2A
0005433349000	15967	4	3A
0005433349004	15967	5	4B
0005433349003	15967	6	5A
0005435628706	15967	7	5B
0005433349005	15967	8	6A
0005433158110	17236	1	1B
0005434445250	17236	2	2A
0005433159301	17236	3	2B
0005434445249	17236	4	3A
0005433159291	17236	5	4B
0005434445251	17236	6	4A
0005433158116	17236	7	5A
0005433158109	17236	8	5B
0005433158111	17236	9	6A
0005434446520	17236	10	6B
0005433159317	17617	1	1A
0005433159319	17617	2	2B
0005434445225	17617	3	3B
0005433159318	17617	4	5B
0005435383112	7901	1	1C
0005435132908	7901	2	2A
0005435383116	7901	3	4A
0005435132907	7901	4	4D
0005435132902	7901	5	5A
0005435383115	7901	6	5B
0005435132910	7901	7	6B
0005435383113	7901	8	6D
0005435132903	7901	9	7B
0005435132905	7901	10	18C
0005435132900	7901	11	19B
0005435383111	7901	12	19C
0005435132901	7901	13	19D
0005435132909	7901	14	20A
0005435132904	7901	15	20B
0005435132906	7901	16	21C
0005435132798	33072	1	1A
0005435132742	33072	2	1C
0005435383161	33072	3	2D
0005435132818	33072	4	3B
0005435132772	33072	5	3C
0005435132828	33072	6	3D
0005435132799	33072	7	4B
0005435132829	33072	8	5B
0005435132804	33072	9	5C
0005435132830	33072	10	6B
0005435383163	33072	11	7D
0005435132743	33072	12	18B
0005435132839	33072	13	18D
0005435132835	33072	14	19A
0005435132803	33072	15	19B
0005435132819	33072	16	19C
0005435132817	33072	17	20B
0005435383160	33072	18	21A
0005435132771	33072	19	21B
0005435383162	33072	20	22B
0005435383159	33072	21	22C
0005435383164	33072	22	23A
0005435390198	7481	1	1B
0005435160329	7481	2	1D
0005435390186	7481	3	2A
0005435390162	7481	4	4A
0005435160327	7481	5	4C
0005435390163	7481	6	5A
0005435160326	7481	7	5C
0005435160322	7481	8	6A
0005435160324	7481	9	6C
0005435160332	7481	10	6D
0005435160323	7481	11	18C
0005435160330	7481	12	19A
0005435160325	7481	13	20A
0005435160328	7481	14	20C
0005435160331	7481	15	21A
0005435390231	7481	16	21B
0005435160321	7481	17	22B
0005435390156	7481	18	22D
0005435390258	29584	1	1A
0005435390254	29584	2	3A
0005435160243	29584	3	3C
0005435390255	29584	4	4B
0005435160254	29584	5	5B
0005435390257	29584	6	5C
0005435160224	29584	7	18C
0005435160231	29584	8	18D
0005435390253	29584	9	19C
0005435160252	29584	10	19D
0005435390256	29584	11	20B
0005435160226	29584	12	21C
0005435390252	29584	13	22A
0005435160276	29584	14	22D
0005435160253	29584	15	23A
0005432398175	18484	1	1A
0005432394072	18484	2	1B
0005432394091	18484	3	2A
0005435178499	18484	4	3A
0005432394069	18484	5	2B
0005432394066	18484	6	3B
0005432394090	18484	7	4A
0005435178500	18484	8	4B
0005432394070	18484	9	5A
0005432398174	18484	10	5B
0005432398188	18484	11	6A
0005432394071	18484	12	6B
0005432400128	27157	1	1A
0005432400130	27157	2	1B
0005432398202	27157	3	2A
0005432400126	27157	4	2B
0005432400129	27157	5	3B
0005432400127	27157	6	4A
0005432398201	27157	7	4B
0005432398203	27157	8	5B
0005435178483	27157	9	6A
0005432398200	27157	10	6B
0005434191269	9726	1	3A
0005434191272	9726	2	4A
0005434191270	9726	3	6B
0005434504243	6525	1	1D
0005434504255	6525	2	1F
0005434504240	6525	3	2D
0005435103950	6525	4	3A
0005434504259	6525	5	3C
0005435103951	6525	6	4C
0005434504234	6525	7	4D
0005434504237	6525	8	4F
0005434504241	6525	9	5A
0005434504242	6525	10	5C
0005434504235	6525	11	5E
0005434504228	6525	12	5D
0005434504239	6525	13	6C
0005434504232	6525	14	6E
0005434504252	6525	15	7A
0005434504260	6525	16	8D
0005434504246	6525	17	9C
0005434504256	6525	18	9D
0005434504247	6525	19	9F
0005434504257	6525	20	10C
0005434504236	6525	21	11A
0005434504227	6525	22	11C
0005434504249	6525	23	11D
0005434504251	6525	24	11F
0005434504245	6525	25	12A
0005434504244	6525	26	12D
0005434504229	6525	27	12E
0005434504233	6525	28	14A
0005434504238	6525	29	14D
0005435103953	6525	30	14E
0005434504254	6525	31	14F
0005434504258	6525	32	15A
0005434504231	6525	33	16A
0005434504253	6525	34	16C
0005434504230	6525	35	17E
0005434504226	6525	36	17F
0005434504248	6525	37	19A
0005434504250	6525	38	20A
0005435103952	6525	39	20F
0005434503863	22634	1	1C
0005434503813	22634	2	2A
0005434503832	22634	3	2C
0005434503830	22634	4	3A
0005434503888	22634	5	3D
0005434503908	22634	6	3F
0005434503814	22634	7	4A
0005434503843	22634	8	4D
0005434503913	22634	9	4E
0005434503938	22634	10	5F
0005434503953	22634	11	6A
0005434503857	22634	12	6C
0005434503866	22634	13	6E
0005434503890	22634	14	6F
0005434503848	22634	15	7A
0005434503838	22634	16	7C
0005434503952	22634	17	8A
0005434503720	22634	18	8C
0005434503842	22634	19	8D
0005434503950	22634	20	8F
0005434503740	22634	21	9D
0005434503887	22634	22	10C
0005434503954	22634	23	10F
0005434503560	22634	24	11F
0005434503865	22634	25	12C
0005434503939	22634	26	13D
0005434503820	22634	27	13F
0005435103839	22634	28	14C
0005434503893	22634	29	14E
0005434503831	22634	30	15A
0005434503698	22634	31	15C
0005434503849	22634	32	15D
0005434503949	22634	33	15F
0005434503561	22634	34	16C
0005434503597	22634	35	16D
0005434503936	22634	36	16E
0005434503909	22634	37	16F
0005434503891	22634	38	17C
0005434503739	22634	39	17D
0005434503676	22634	40	17F
0005434503951	22634	41	18A
0005434503862	22634	42	18C
0005434503856	22634	43	18E
0005434503912	22634	44	18F
0005434503802	22634	45	19E
0005434503907	22634	46	20D
0005433367645	1676	1	1A
0005435653141	1676	2	1C
0005435653161	1676	3	1D
0005435653144	1676	4	1F
0005433367535	1676	5	2A
0005435653165	1676	6	2C
0005435653183	1676	7	2D
0005435653187	1676	8	3A
0005435653177	1676	9	3C
0005435653140	1676	10	3D
0005435653143	1676	11	3F
0005433367719	1676	12	4C
0005435653179	1676	13	4A
0005433367772	1676	14	4D
0005433367501	1676	15	4F
0005435653168	1676	16	5A
0005435653147	1676	17	5C
0005433367641	1676	18	5D
0005435653185	1676	19	5E
0005435653150	1676	20	5F
0005433367812	1676	21	6A
0005435653172	1676	22	6D
0005433367502	1676	23	6E
0005433367407	1676	24	6F
0005433367667	1676	25	7C
0005435653174	1676	26	7D
0005433367696	1676	27	7E
0005433367529	1676	28	7F
0005435653188	1676	29	8A
0005435653156	1676	30	8C
0005435653154	1676	31	8D
0005435653184	1676	32	8E
0005433367534	1676	33	8F
0005433367619	1676	34	9A
0005435653170	1676	35	9C
0005435653139	1676	36	9D
0005435653182	1676	37	9F
0005435653155	1676	38	10A
0005433367707	1676	39	10C
0005435653191	1676	40	10D
0005435653186	1676	41	10E
0005433367665	1676	42	10F
0005433367680	1676	43	11A
0005435653190	1676	44	11C
0005433367657	1676	45	11D
0005435653158	1676	46	11F
0005435653152	1676	47	12A
0005435653160	1676	48	12C
0005435653149	1676	49	12D
0005435653159	1676	50	12E
0005435653164	1676	51	13A
0005435653167	1676	52	13C
0005435653153	1676	53	13D
0005435653180	1676	54	13E
0005435653181	1676	55	13F
0005433367642	1676	56	14A
0005435653176	1676	57	14C
0005435653169	1676	58	14D
0005435653166	1676	59	14E
0005435653148	1676	60	14F
0005433367666	1676	61	15A
0005435653151	1676	62	15C
0005435653146	1676	63	15D
0005433367689	1676	64	16A
0005435653173	1676	65	16C
0005433367408	1676	66	16D
0005433367771	1676	67	16E
0005433367757	1676	68	16F
0005433367695	1676	69	17A
0005433367681	1676	70	17C
0005433367791	1676	71	17D
0005433367652	1676	72	17E
0005433367811	1676	73	17F
0005435653145	1676	74	18A
0005435653175	1676	75	18C
0005433367586	1676	76	18D
0005435653171	1676	77	18E
0005435653142	1676	78	19A
0005435653163	1676	79	19C
0005433367409	1676	80	19D
0005435653178	1676	81	19E
0005433367613	1676	82	19F
0005435653157	1676	83	20A
0005435653162	1676	84	20C
0005435653189	1676	85	20D
0005433367813	1676	86	20E
0005433367487	1676	87	20F
0005433367954	21698	1	1A
0005435652746	21698	2	1C
0005435652822	21698	3	1D
0005435652561	21698	4	1F
0005435652655	21698	5	2A
0005435652596	21698	6	2C
0005433367983	21698	7	2D
0005435652624	21698	8	2F
0005435652777	21698	9	3A
0005435652686	21698	10	3C
0005433367981	21698	11	3D
0005433367969	21698	12	3F
0005433367964	21698	13	4A
0005433367974	21698	14	4C
0005433367956	21698	15	4E
0005433367985	21698	16	4F
0005435652595	21698	17	5A
0005435652691	21698	18	5E
0005435652820	21698	19	6A
0005433367984	21698	20	5F
0005435652826	21698	21	6C
0005433367950	21698	22	6D
0005433367961	21698	23	6E
0005433367957	21698	24	6F
0005433367952	21698	25	7A
0005435652827	21698	26	7C
0005435652745	21698	27	7D
0005433367966	21698	28	7E
0005435652769	21698	29	7F
0005435652676	21698	30	8A
0005435652685	21698	31	8C
0005435652810	21698	32	8D
0005433367971	21698	33	8E
0005435652738	21698	34	9A
0005435652681	21698	35	9C
0005435652535	21698	36	9D
0005433367986	21698	37	9F
0005435652770	21698	38	10A
0005433367967	21698	39	10D
0005433367972	21698	40	10E
0005433367955	21698	41	10F
0005433367976	21698	42	11A
0005435652776	21698	43	11C
0005435652625	21698	44	11D
0005435652536	21698	45	11E
0005435652717	21698	46	11F
0005433367965	21698	47	12A
0005433367979	21698	48	12C
0005435652706	21698	49	12E
0005433367978	21698	50	12F
0005435652552	21698	51	13A
0005433367982	21698	52	13C
0005433367951	21698	53	13D
0005435652801	21698	54	13E
0005433367958	21698	55	13F
0005433367977	21698	56	14A
0005433367968	21698	57	14C
0005433367973	21698	58	14D
0005433367963	21698	59	14E
0005435652819	21698	60	14F
0005435652783	21698	61	15A
0005435652835	21698	62	15C
0005433367948	21698	63	15E
0005435652440	21698	64	15F
0005433367960	21698	65	16A
0005433367959	21698	66	16D
0005435652800	21698	67	16F
0005433367975	21698	68	16E
0005433367980	21698	69	17A
0005435652707	21698	70	17C
0005433367949	21698	71	17E
0005435652701	21698	72	17F
0005435652651	21698	73	18A
0005435652621	21698	74	18C
0005435652571	21698	75	18D
0005435652644	21698	76	18E
0005435652677	21698	77	18F
0005433367953	21698	78	19C
0005433367962	21698	79	19D
0005435652731	21698	80	19E
0005435652766	21698	81	19F
0005435652623	21698	82	20A
0005435652816	21698	83	20C
0005435652737	21698	84	20D
0005435652590	21698	85	20E
0005433367970	21698	86	20F
0005433986029	4157	1	1C
0005435788776	4157	2	2A
0005433986070	4157	3	2C
0005433986038	4157	4	2D
0005433986057	4157	5	2F
0005433986049	4157	6	3A
0005433986043	4157	7	3C
0005433986075	4157	8	3D
0005433986064	4157	9	3F
0005433986052	4157	10	4D
0005435788777	4157	11	5F
0005435788775	4157	12	6C
0005433986073	4157	13	6D
0005433986039	4157	14	7F
0005433986065	4157	15	8C
0005433986037	4157	16	8D
0005433986060	4157	17	8E
0005433986051	4157	18	9A
0005435788778	4157	19	9C
0005433986074	4157	20	9E
0005433986031	4157	21	9F
0005433986055	4157	22	10A
0005433986032	4157	23	10D
0005433986056	4157	24	11A
0005433986058	4157	25	11D
0005433986072	4157	26	11E
0005433986061	4157	27	11F
0005433986033	4157	28	12A
0005433986048	4157	29	12C
0005433986030	4157	30	12D
0005433986040	4157	31	12E
0005433986050	4157	32	13C
0005433986034	4157	33	13D
0005433986042	4157	34	13E
0005433986046	4157	35	13F
0005433986041	4157	36	14A
0005433986047	4157	37	14D
0005433986066	4157	38	15C
0005433986045	4157	39	15F
0005433986059	4157	40	16C
0005433986053	4157	41	17C
0005433986068	4157	42	17D
0005433986044	4157	43	17E
0005433986062	4157	44	17F
0005433986069	4157	45	18A
0005433986067	4157	46	18C
0005433986027	4157	47	18E
0005433986028	4157	48	19A
0005433986054	4157	49	19C
0005433986036	4157	50	19D
0005433986071	4157	51	19E
0005433986063	4157	52	20A
0005433986035	4157	53	20F
0005433985632	25684	1	1C
0005433985577	25684	2	1D
0005433985605	25684	3	1F
0005433985597	25684	4	3C
0005433985563	25684	5	3F
0005433985582	25684	6	5A
0005433985640	25684	7	5C
0005433985538	25684	8	5D
0005433985276	25684	9	5E
0005433985617	25684	10	6D
0005433985564	25684	11	6F
0005433985506	25684	12	7A
0005433985521	25684	13	7C
0005433985625	25684	14	7F
0005433985496	25684	15	8A
0005433985548	25684	16	8C
0005433985557	25684	17	8F
0005433985565	25684	18	9A
0005433985595	25684	19	9D
0005433985451	25684	20	10A
0005433985643	25684	21	10C
0005433985639	25684	22	10D
0005433985495	25684	23	10E
0005433985520	25684	24	10F
0005433985471	25684	25	11A
0005433985470	25684	26	11C
0005433985581	25684	27	11D
0005433985562	25684	28	11E
0005433985616	25684	29	11F
0005433985573	25684	30	12F
0005433985606	25684	31	13A
0005433985527	25684	32	13C
0005433985277	25684	33	13D
0005433985537	25684	34	13F
0005433985594	25684	35	14C
0005433985494	25684	36	14D
0005433985477	25684	37	14E
0005435788759	25684	38	15C
0005433985571	25684	39	15E
0005433985347	25684	40	15F
0005433985627	25684	41	17C
0005433985570	25684	42	17F
0005433985403	25684	43	18D
0005433985614	25684	44	18E
0005433985558	25684	45	19A
0005433985626	25684	46	19E
0005433985459	25684	47	19F
0005433985452	25684	48	20A
0005435719558	21285	1	4B
0005435720817	21285	2	18D
0005435719564	21285	3	19C
0005435719560	21285	4	20D
0005435719559	21285	5	23A
0005435720133	24747	1	3C
0005435720132	24747	2	19C
0005435720134	24747	3	21D
0005434509077	21335	1	1A
0005434509088	21335	2	1B
0005434509081	21335	3	2A
0005433168380	21335	4	2B
0005434509106	21335	5	3A
0005434509094	21335	6	3B
0005433168372	21335	7	3C
0005434509102	21335	8	4A
0005433168378	21335	9	3D
0005434509116	21335	10	4B
0005433168377	21335	11	5B
0005433168373	21335	12	5D
0005434509104	21335	13	6A
0005434509107	21335	14	6B
0005434509086	21335	15	6C
0005433168382	21335	16	6D
0005434509098	21335	17	7A
0005434509122	21335	18	7C
0005433168383	21335	19	7D
0005433168375	21335	20	18A
0005434509096	21335	21	18D
0005433168374	21335	22	19B
0005434509092	21335	23	20B
0005433168381	21335	24	20C
0005433168379	21335	25	20D
0005434509078	21335	26	21A
0005433168376	21335	27	21B
0005434509103	21335	28	21C
0005434509119	21335	29	21D
0005434509091	21335	30	22A
0005434509082	21335	31	22B
0005434509118	21335	32	22C
0005434509090	21335	33	23A
0005434509101	21335	34	23B
0005432657439	17848	1	1C
0005434151711	17848	2	2A
0005432869545	17848	3	2D
0005432655441	17848	4	3D
0005432869541	17848	5	4E
0005432666362	17848	6	5D
0005432655449	17848	7	5E
0005432663026	17848	8	5F
0005432666361	17848	9	6A
0005432663012	17848	10	7C
0005432869542	17848	11	8C
0005432655439	17848	12	9C
0005432657438	17848	13	10F
0005432661904	17848	14	11A
0005434151713	17848	15	12A
0005432663018	17848	16	12C
0005432657440	17848	17	12F
0005432664120	17848	18	13D
0005432655423	17848	19	13F
0005432655412	17848	20	14A
0005432660805	17848	21	14D
0005432655468	17848	22	14E
0005432655425	17848	23	14F
0005432667441	17848	24	15C
0005432661907	17848	25	15E
0005432663025	17848	26	15F
0005432666372	17848	27	16D
0005432869544	17848	28	17A
0005432657430	17848	29	17D
0005432660804	17848	30	17E
0005432869543	17848	31	17F
0005432655436	17848	32	18D
0005432655424	17848	33	19C
0005432655511	17848	34	19D
0005434151712	17848	35	19E
0005432657431	17848	36	19F
0005432655440	17848	37	20E
0005432869473	26322	1	1D
0005432869480	26322	2	2C
0005432655541	26322	3	3C
0005432869472	26322	4	3D
0005432655543	26322	5	4A
0005432869471	26322	6	4C
0005432655536	26322	7	5A
0005432869479	26322	8	5E
0005432655535	26322	9	6D
0005434151694	26322	10	7A
0005432657450	26322	11	7D
0005432658592	26322	12	7F
0005432655538	26322	13	8A
0005432869477	26322	14	9C
0005432667456	26322	15	9D
0005432665276	26322	16	10D
0005432655534	26322	17	11A
0005432869478	26322	18	11D
0005432655537	26322	19	12A
0005432655539	26322	20	12D
0005432655545	26322	21	13A
0005432665277	26322	22	13C
0005432659707	26322	23	13D
0005432657452	26322	24	13E
0005432657451	26322	25	14F
0005432659708	26322	26	15C
0005432655540	26322	27	15E
0005434151685	26322	28	16D
0005432655542	26322	29	17A
0005432658594	26322	30	17E
0005432658593	26322	31	18A
0005432660819	26322	32	18D
0005432655544	26322	33	18E
0005432869474	26322	34	19D
0005432666391	26322	35	20A
0005432660820	26322	36	20D
0005432328787	3082	1	1A
0005432287199	3082	2	1C
0005432905093	3082	3	1D
0005432328824	3082	4	1F
0005432328829	3082	5	2A
0005432328794	3082	6	2C
0005432328805	3082	7	2D
0005432905094	3082	8	2F
0005433438898	3082	9	3A
0005432328806	3082	10	3C
0005432905078	3082	11	3D
0005432287204	3082	12	3F
0005432328784	3082	13	4D
0005432328793	3082	14	4E
0005432328825	3082	15	4F
0005432328813	3082	16	5C
0005432328819	3082	17	5E
0005432328789	3082	18	6C
0005432328800	3082	19	6D
0005432328792	3082	20	6E
0005432905083	3082	21	7A
0005432328797	3082	22	7C
0005432328799	3082	23	7D
0005432328790	3082	24	7E
0005433438895	3082	25	7F
0005432328804	3082	26	8A
0005432328827	3082	27	8C
0005432328791	3082	28	9C
0005432328807	3082	29	9D
0005432328828	3082	30	9F
0005433438897	3082	31	10C
0005432328818	3082	32	10D
0005432905113	3082	33	10E
0005432328801	3082	34	11C
0005432328815	3082	35	11D
0005432328830	3082	36	11E
0005432328785	3082	37	12C
0005432287201	3082	38	12F
0005433438894	3082	39	13A
0005432328812	3082	40	13C
0005432328798	3082	41	13D
0005432905082	3082	42	13E
0005432328786	3082	43	13F
0005432328816	3082	44	14A
0005432905070	3082	45	14C
0005432328803	3082	46	14D
0005432328817	3082	47	14E
0005432328811	3082	48	14F
0005432328795	3082	49	15A
0005432328796	3082	50	15C
0005432328821	3082	51	15D
0005433438893	3082	52	16C
0005432328802	3082	53	16D
0005432328820	3082	54	16F
0005433438896	3082	55	17C
0005432328814	3082	56	17D
0005432328809	3082	57	17E
0005432328810	3082	58	18A
0005432328808	3082	59	18C
0005432328822	3082	60	18D
0005432328788	3082	61	18E
0005432287202	3082	62	18F
0005432328826	3082	63	19A
0005432905112	3082	64	19C
0005432287203	3082	65	19D
0005432287200	3082	66	19F
0005432328823	3082	67	20A
0005432905077	3082	68	20E
0005432328476	31106	1	1A
0005432328275	31106	2	1C
0005432328335	31106	3	1D
0005432328574	31106	4	1F
0005432054309	31106	5	2C
0005432905138	31106	6	2D
0005432328225	31106	7	2F
0005432328381	31106	8	3A
0005432328375	31106	9	3C
0005432328323	31106	10	3D
0005432328272	31106	11	4A
0005432328264	31106	12	4C
0005432905140	31106	13	4D
0005432328350	31106	14	4E
0005432328429	31106	15	5C
0005432328282	31106	16	5D
0005432328423	31106	17	5E
0005432328297	31106	18	6A
0005432328291	31106	19	6C
0005432905137	31106	20	6E
0005432328351	31106	21	7A
0005432328223	31106	22	7D
0005432328270	31106	23	7F
0005432328659	31106	24	8A
0005432328349	31106	25	8C
0005432905136	31106	26	8D
0005432905142	31106	27	8E
0005432905139	31106	28	9A
0005432328233	31106	29	9D
0005432328379	31106	30	10E
0005432328344	31106	31	10F
0005432328330	31106	32	11A
0005432054313	31106	33	11D
0005432328322	31106	34	11E
0005433438799	31106	35	11F
0005432328352	31106	36	12C
0005432328274	31106	37	12E
0005432328430	31106	38	12F
0005432328224	31106	39	13A
0005432328281	31106	40	13C
0005432054312	31106	41	13D
0005432328360	31106	42	13E
0005432328320	31106	43	14A
0005432328232	31106	44	14C
0005432328236	31106	45	14D
0005432327992	31106	46	14E
0005432328290	31106	47	14F
0005432328445	31106	48	15A
0005432328382	31106	49	15F
0005432905141	31106	50	16D
0005432328332	31106	51	16F
0005432328342	31106	52	17C
0005432328278	31106	53	17D
0005432328279	31106	54	17E
0005432328516	31106	55	17F
0005432328431	31106	56	18C
0005432328345	31106	57	18D
0005432328424	31106	58	18E
0005432328292	31106	59	18F
0005432328319	31106	60	19A
0005432054311	31106	61	19C
0005432328444	31106	62	19D
0005432328356	31106	63	19E
0005432054310	31106	64	19F
0005432905135	31106	65	20A
0005433438808	31106	66	20C
0005432328343	31106	67	20D
0005433438807	31106	68	20E
0005432328660	31106	69	20F
0005435487672	6180	1	1A
0005435487679	6180	2	1D
0005435487572	6180	3	2A
0005434309777	6180	4	2C
0005435999294	6180	5	3C
0005435487688	6180	6	4B
0005435297037	6180	7	4A
0005435487669	6180	8	4D
0005435487715	6180	9	5B
0005435297024	6180	10	5A
0005435487660	6180	11	5C
0005435999287	6180	12	5F
0005435487573	6180	13	6C
0005435999288	6180	14	6B
0005435999291	6180	15	6D
0005434309769	6180	16	6F
0005435487734	6180	17	7B
0005435487694	6180	18	7C
0005435297020	6180	19	7E
0005435297035	6180	20	7F
0005434309770	6180	21	8B
0005435999289	6180	22	8D
0005435999292	6180	23	8C
0005432146204	6180	24	8F
0005435999299	6180	25	9B
0005435487735	6180	26	9C
0005435999296	6180	27	9E
0005435487673	6180	28	10E
0005435999285	6180	29	11A
0005434309768	6180	30	11D
0005434309773	6180	31	11C
0005435487662	6180	32	11E
0005435999295	6180	33	11F
0005435999286	6180	34	12A
0005434309778	6180	35	12B
0005435999282	6180	36	12C
0005434309771	6180	37	12F
0005435487744	6180	38	13C
0005435999298	6180	39	14A
0005435296993	6180	40	13F
0005435999283	6180	41	14C
0005435487652	6180	42	15B
0005435487745	6180	43	15D
0005434309767	6180	44	15E
0005435999280	6180	45	15F
0005434309774	6180	46	16B
0005435487615	6180	47	16E
0005435487716	6180	48	16F
0005435999297	6180	49	17D
0005434309780	6180	50	17E
0005434309766	6180	51	18C
0005435487646	6180	52	18E
0005435487695	6180	53	19A
0005435297019	6180	54	18F
0005434309775	6180	55	19B
0005435999290	6180	56	19D
0005435999284	6180	57	20A
0005432146203	6180	58	20D
0005434309779	6180	59	20E
0005435297026	6180	60	20F
0005435487687	6180	61	21D
0005434309772	6180	62	21E
0005434309776	6180	63	21F
0005435297025	6180	64	22F
0005435999293	6180	65	22E
0005435297009	6180	66	23B
0005435487670	6180	67	23C
0005435999281	6180	68	23F
0005435487862	19576	1	1C
0005435999161	19576	2	1D
0005435487858	19576	3	2A
0005435487867	19576	4	3A
0005435999159	19576	5	4A
0005435487855	19576	6	4C
0005434309654	19576	7	4B
0005434309600	19576	8	4D
0005435487859	19576	9	4F
0005434309615	19576	10	5B
0005434309639	19576	11	5E
0005434309653	19576	12	6A
0005435487857	19576	13	7A
0005434309655	19576	14	7B
0005435487854	19576	15	7D
0005435487865	19576	16	7E
0005435999054	19576	17	8B
0005434309614	19576	18	8C
0005435487856	19576	19	8D
0005435999107	19576	20	8E
0005435487860	19576	21	9A
0005434309652	19576	22	9B
0005434309642	19576	23	9C
0005434309599	19576	24	9E
0005435999065	19576	25	10B
0005434309640	19576	26	10D
0005434309616	19576	27	11A
0005435999089	19576	28	11C
0005435487871	19576	29	11D
0005434309726	19576	30	12B
0005435297077	19576	31	12D
0005435487869	19576	32	12E
0005434309564	19576	33	13A
0005434309617	19576	34	13E
0005435999116	19576	35	14E
0005434309657	19576	36	15A
0005435487872	19576	37	15C
0005435487866	19576	38	15D
0005434309707	19576	39	15E
0005435487861	19576	40	16A
0005435999120	19576	41	16B
0005435487853	19576	42	16D
0005435487863	19576	43	16F
0005434309641	19576	44	16E
0005435999092	19576	45	17A
0005435999093	19576	46	17B
0005434309705	19576	47	17C
0005435297074	19576	48	17D
0005435297075	19576	49	17E
0005434309656	19576	50	18A
0005434309731	19576	51	18C
0005435297076	19576	52	18E
0005434309675	19576	53	18D
0005435999112	19576	54	18F
0005435297073	19576	55	19A
0005435487868	19576	56	19C
0005435487864	19576	57	19B
0005435487870	19576	58	19E
0005435487873	19576	59	19D
0005435999160	19576	60	20B
0005435999055	19576	61	20D
0005434309706	19576	62	20C
0005435999095	19576	63	21A
0005435999106	19576	64	22B
0005435297072	19576	65	22D
0005435487852	19576	66	22F
0005435999164	19576	67	23A
0005435999111	19576	68	23E
0005434309704	19576	69	23D
0005433186088	1546	1	1A
0005435517960	1546	2	1D
0005435517957	1546	3	2A
0005432291936	1546	4	2C
0005435502357	1546	5	2D
0005435517946	1546	6	2F
0005435517948	1546	7	3A
0005435502369	1546	8	3C
0005435502356	1546	9	3D
0005435502359	1546	10	4A
0005435502373	1546	11	4E
0005435517959	1546	12	5A
0005433186035	1546	13	5C
0005433186086	1546	14	5D
0005435508393	1546	15	5F
0005433186054	1546	16	6C
0005435502366	1546	17	6D
0005435502353	1546	18	6E
0005432291935	1546	19	6F
0005434565941	1546	20	7A
0005435508394	1546	21	7C
0005433186041	1546	22	7F
0005435502374	1546	23	8A
0005433186094	1546	24	8C
0005434565944	1546	25	8D
0005435502362	1546	26	8E
0005435517951	1546	27	8F
0005435517955	1546	28	9A
0005435502352	1546	29	9C
0005434565943	1546	30	9D
0005435517949	1546	31	9E
0005434565940	1546	32	9F
0005435502358	1546	33	10A
0005433186093	1546	34	10D
0005435517952	1546	35	10E
0005434565947	1546	36	10F
0005435502367	1546	37	11C
0005434565951	1546	38	11D
0005433186052	1546	39	11E
0005433186071	1546	40	12C
0005433186087	1546	41	12E
0005435502370	1546	42	12F
0005435502355	1546	43	13C
0005435502364	1546	44	13D
0005435502372	1546	45	13E
0005435508392	1546	46	14C
0005434565950	1546	47	14F
0005434565945	1546	48	15A
0005434565949	1546	49	15C
0005434565939	1546	50	15D
0005435517953	1546	51	15E
0005434565948	1546	52	16A
0005433186047	1546	53	16D
0005435502371	1546	54	16F
0005435517956	1546	55	17A
0005435517947	1546	56	17C
0005434565946	1546	57	17D
0005434565952	1546	58	17E
0005433186034	1546	59	17F
0005435502354	1546	60	18A
0005435502365	1546	61	18C
0005433186053	1546	62	18D
0005435502360	1546	63	18F
0005435502361	1546	64	19A
0005435502368	1546	65	19C
0005432291937	1546	66	19D
0005435517950	1546	67	19E
0005434565942	1546	68	20A
0005435517954	1546	69	20C
0005435517958	1546	70	20E
0005435502363	1546	71	20F
0005435529048	20843	1	1A
0005435502187	20843	2	1C
0005435502166	20843	3	1F
0005435529054	20843	4	2A
0005433186138	20843	5	2D
0005435502173	20843	6	2F
0005435529053	20843	7	3A
0005435545632	20843	8	3C
0005433186140	20843	9	3D
0005435502181	20843	10	3F
0005435502123	20843	11	4C
0005435529058	20843	12	4D
0005435545656	20843	13	4E
0005435529006	20843	14	4F
0005435502122	20843	15	5A
0005433186141	20843	16	5C
0005435502108	20843	17	5D
0005435502186	20843	18	5E
0005435529075	20843	19	5F
0005435529049	20843	20	6C
0005435529099	20843	21	6D
0005435545644	20843	22	6E
0005435529152	20843	23	6F
0005435502110	20843	24	7A
0005435529014	20843	25	7D
0005435529121	20843	26	7F
0005435529013	20843	27	8A
0005435529007	20843	28	8C
0005435502196	20843	29	8D
0005435529098	20843	30	8E
0005435502098	20843	31	8F
0005435529091	20843	32	9A
0005433186142	20843	33	9D
0005435529045	20843	34	9E
0005433186137	20843	35	10A
0005435502168	20843	36	10C
0005435529050	20843	37	10D
0005435502165	20843	38	10E
0005433186143	20843	39	11A
0005435545631	20843	40	11E
0005435545667	20843	41	11F
0005434565811	20843	42	12A
0005435529051	20843	43	12C
0005435529153	20843	44	12D
0005435529059	20843	45	12E
0005434565847	20843	46	12F
0005435528969	20843	47	13A
0005434565844	20843	48	13D
0005435502160	20843	49	13F
0005435545674	20843	50	14A
0005435502136	20843	51	14C
0005434565765	20843	52	15A
0005435529139	20843	53	15C
0005435528951	20843	54	15D
0005435529073	20843	55	15E
0005433186135	20843	56	15F
0005435529110	20843	57	16A
0005435545659	20843	58	16C
0005435529080	20843	59	16D
0005435502234	20843	60	16F
0005433186136	20843	61	17A
0005435545671	20843	62	17C
0005435502150	20843	63	17D
0005434565829	20843	64	17E
0005434565797	20843	65	17F
0005434565830	20843	66	18A
0005434565796	20843	67	18D
0005435502239	20843	68	18E
0005435502164	20843	69	18F
0005435502135	20843	70	19C
0005435529120	20843	71	19D
0005434565848	20843	72	19E
0005433186139	20843	73	19F
0005435502109	20843	74	20A
0005435529111	20843	75	20D
0005435528952	20843	76	20E
0005435529140	20843	77	20F
0005435153760	3885	1	1D
0005435153754	3885	2	2C
0005435931596	3885	3	3D
0005435931588	3885	4	4A
0005435153755	3885	5	5C
0005435153756	3885	6	5D
0005435931597	3885	7	7B
0005435153759	3885	8	18D
0005435153757	3885	9	19D
0005435931574	3885	10	20A
0005435153758	3885	11	21C
0005435931610	21867	1	3D
0005435931609	21867	2	4C
0005435153709	21867	3	5B
0005435153682	21867	4	6C
0005435931611	21867	5	18C
0005435931608	21867	6	21D
0005435153718	21867	7	22A
0005432628884	7211	1	1A
0005432628881	7211	2	1C
0005435225545	7211	3	1D
0005432628882	7211	4	2B
0005435225556	7211	5	2D
0005432628877	7211	6	3A
0005432628878	7211	7	3C
0005432628886	7211	8	5A
0005432628885	7211	9	6B
0005435225493	7211	10	6C
0005432628883	7211	11	6D
0005435225518	7211	12	7B
0005432628879	7211	13	7C
0005432628876	7211	14	7D
0005432628874	7211	15	18C
0005435225557	7211	16	18D
0005432628887	7211	17	20A
0005432628880	7211	18	21A
0005435225558	7211	19	21D
0005432628875	7211	20	22A
0005435225547	7211	21	22B
0005432628873	7211	22	22D
0005435225562	7211	23	23A
0005432628787	28104	1	1A
0005432628730	28104	2	1D
0005432628796	28104	3	2B
0005432628766	28104	4	3A
0005432628727	28104	5	2D
0005435225605	28104	6	4C
0005435225606	28104	7	4D
0005435225604	28104	8	5C
0005432628731	28104	9	6A
0005432628788	28104	10	5D
0005435225603	28104	11	6B
0005432628797	28104	12	18A
0005432628813	28104	13	18B
0005435225601	28104	14	19B
0005435225599	28104	15	20B
0005432628773	28104	16	20C
0005432628769	28104	17	20D
0005432628812	28104	18	21A
0005435225602	28104	19	22B
0005432628781	28104	20	23A
0005435225600	28104	21	23B
0005435960059	8733	1	2D
0005434267886	8733	2	6B
0005434267925	8733	3	7D
0005435960060	8733	4	18B
0005434267920	8733	5	20D
0005435960058	8733	6	21A
0005434267921	8733	7	21B
0005435960030	15255	1	1A
0005435960031	15255	2	1C
0005434267957	15255	3	2C
0005434267958	15255	4	4C
0005434267959	15255	5	4D
0005435960012	15255	6	6D
0005435960028	15255	7	7B
0005435960027	15255	8	18A
0005435960029	15255	9	18D
0005435960041	15255	10	20D
0005435960033	15255	11	23B
0005432873262	1174	1	1C
0005432693114	1174	2	1D
0005432677581	1174	3	2C
0005432873277	1174	4	2D
0005432693110	1174	5	2F
0005432693122	1174	6	3D
0005432873245	1174	7	3F
0005432693124	1174	8	5C
0005432675174	1174	9	5D
0005432675163	1174	10	6A
0005432675162	1174	11	6D
0005432693103	1174	12	6C
0005432677580	1174	13	6E
0005432675161	1174	14	7A
0005432693118	1174	15	6F
0005432873231	1174	16	7C
0005432677579	1174	17	7B
0005432693109	1174	18	7F
0005432873278	1174	19	8C
0005432693101	1174	20	8B
0005432693107	1174	21	8F
0005432675169	1174	22	8E
0005432693119	1174	23	9A
0005432675166	1174	24	9C
0005432675172	1174	25	9B
0005432693104	1174	26	10B
0005432873241	1174	27	10A
0005432873246	1174	28	9F
0005432675165	1174	29	10C
0005432693115	1174	30	10F
0005432873261	1174	31	11D
0005432873264	1174	32	11C
0005432693106	1174	33	12B
0005432677577	1174	34	12A
0005432693096	1174	35	12C
0005432675160	1174	36	13B
0005432675170	1174	37	13D
0005432693111	1174	38	14B
0005432693105	1174	39	14C
0005432693120	1174	40	14F
0005432693117	1174	41	15B
0005432675171	1174	42	15A
0005432693098	1174	43	15C
0005432677578	1174	44	15D
0005432693100	1174	45	16A
0005432693113	1174	46	15F
0005432693099	1174	47	16B
0005432693112	1174	48	16D
0005432675173	1174	49	16F
0005432873281	1174	50	17C
0005432693097	1174	51	17B
0005432873263	1174	52	17F
0005432675164	1174	53	17E
0005432693125	1174	54	18B
0005432693123	1174	55	18C
0005432675158	1174	56	18E
0005432693116	1174	57	18D
0005432693126	1174	58	18F
0005432675159	1174	59	19F
0005432693108	1174	60	20A
0005432693121	1174	61	20D
0005432693102	1174	62	20F
0005432675167	1174	63	21C
0005432675168	1174	64	21B
0005432873242	1174	65	21E
0005432675001	17464	1	1A
0005432675044	17464	2	1F
0005432677535	17464	3	1D
0005432692992	17464	4	2A
0005432873306	17464	5	2D
0005432675022	17464	6	3D
0005432692877	17464	7	3C
0005432692761	17464	8	4A
0005432692781	17464	9	4F
0005432675043	17464	10	5C
0005432692994	17464	11	5A
0005432675038	17464	12	5F
0005432692884	17464	13	5D
0005432692791	17464	14	6D
0005432873309	17464	15	6C
0005432692965	17464	16	7B
0005432692982	17464	17	8D
0005432675063	17464	18	8C
0005432692983	17464	19	8F
0005432692799	17464	20	9C
0005432692801	17464	21	9E
0005432675105	17464	22	9D
0005432677547	17464	23	10A
0005432692878	17464	24	9F
0005432692789	17464	25	10D
0005432675037	17464	26	10C
0005432692802	17464	27	10E
0005432873313	17464	28	11A
0005432873310	17464	29	10F
0005432692893	17464	30	11B
0005432692964	17464	31	11C
0005432692923	17464	32	12A
0005432692800	17464	33	12C
0005432677546	17464	34	12F
0005432692762	17464	35	13C
0005432675051	17464	36	13E
0005432675002	17464	37	13D
0005432675023	17464	38	14D
0005432692812	17464	39	15A
0005432675039	17464	40	15C
0005432675016	17464	41	15E
0005432873311	17464	42	16A
0005432692783	17464	43	15F
0005432692888	17464	44	16C
0005432692966	17464	45	16B
0005432692758	17464	46	17C
0005432675056	17464	47	17E
0005432873304	17464	48	18B
0005432692790	17464	49	18A
0005432675062	17464	50	18D
0005432692728	17464	51	19A
0005432873305	17464	52	18F
0005432692993	17464	53	19D
0005432692829	17464	54	19C
0005432677536	17464	55	20B
0005432692889	17464	56	20D
0005432873308	17464	57	20C
0005432873312	17464	58	20F
0005432873307	17464	59	20E
0005432692782	17464	60	21A
0005432692825	17464	61	21E
0005434435221	1113	1	1A
0005434435220	1113	2	1C
0005434435223	1113	3	1D
0005434435216	1113	4	2C
0005434435211	1113	5	2D
0005434435213	1113	6	3A
0005433156701	1113	7	3B
0005433156728	1113	8	3D
0005433156661	1113	9	4C
0005433156693	1113	10	4D
0005433156697	1113	11	5B
0005434435209	1113	12	5D
0005434435210	1113	13	6A
0005433156706	1113	14	6C
0005434435212	1113	15	6D
0005433156660	1113	16	7A
0005433156674	1113	17	7D
0005434435219	1113	18	18D
0005434435224	1113	19	19B
0005433156696	1113	20	19C
0005433156698	1113	21	19D
0005433156673	1113	22	20A
0005434435214	1113	23	20B
0005433156727	1113	24	20C
0005434435222	1113	25	20D
0005434435217	1113	26	22B
0005434435215	1113	27	22D
0005434435218	1113	28	23A
0005434435088	17324	1	1A
0005434435121	17324	2	1C
0005433156772	17324	3	2B
0005434435053	17324	4	2C
0005434435070	17324	5	2D
0005434435057	17324	6	3A
0005434435089	17324	7	4C
0005433156769	17324	8	4D
0005433156771	17324	9	5C
0005433156766	17324	10	6A
0005434435052	17324	11	6C
0005433156767	17324	12	7A
0005434435130	17324	13	7C
0005434435085	17324	14	18C
0005434435086	17324	15	18D
0005434435076	17324	16	20A
0005433156768	17324	17	20D
0005434435111	17324	18	21A
0005433156770	17324	19	21B
0005434434990	17324	20	22C
0005434435051	17324	21	23B
0005435928099	4077	1	1D
0005435086854	4077	2	1C
0005435928129	4077	3	2B
0005435086851	4077	4	3A
0005435928128	4077	5	4B
0005435086852	4077	6	5B
0005435086849	4077	7	5D
0005435086853	4077	8	6B
0005435928098	4077	9	6C
0005435086848	4077	10	7C
0005435928123	4077	11	21A
0005435086850	4077	12	23B
0005435086792	24421	1	1A
0005435086780	24421	2	1D
0005435086808	24421	3	3C
0005435086793	24421	4	4A
0005435086761	24421	5	4D
0005435928154	24421	6	5B
0005435086821	24421	7	18A
0005435086822	24421	8	19C
0005435928152	24421	9	20A
0005435086779	24421	10	20B
0005435928153	24421	11	21A
0005435928155	24421	12	21C
0005435086807	24421	13	21D
0005434625985	4830	1	1D
0005434625979	4830	2	3F
0005434625980	4830	3	6F
0005434625986	4830	4	7A
0005434625977	4830	5	9E
0005435907495	4830	6	10D
0005433194838	4830	7	11A
0005434625984	4830	8	11F
0005435907473	4830	9	13F
0005434625982	4830	10	16C
0005434625978	4830	11	16E
0005434625981	4830	12	17A
0005433194844	4830	13	19D
0005434625983	4830	14	19E
0005435907468	4830	15	20A
0005434625895	32910	1	5F
0005434625906	32910	2	6D
0005434625907	32910	3	11C
0005434625908	32910	4	15F
0005434625872	32910	5	20C
0005434625896	32910	6	20D
0005435785211	13748	1	1A
0005435785031	13748	2	1B
0005435785110	13748	3	1D
0005435784925	13748	4	2A
0005435937391	13748	5	2C
0005435785216	13748	6	3D
0005435785207	13748	7	4A
0005435785098	13748	8	4B
0005435937392	13748	9	4C
0005435784979	13748	10	4D
0005435785202	13748	11	5A
0005435785109	13748	12	5B
0005435785060	13748	13	5D
0005435785102	13748	14	6B
0005435785084	13748	15	6D
0005435785122	13748	16	7A
0005435785105	13748	17	7B
0005435785059	13748	18	7D
0005432195697	13748	19	18A
0005435785113	13748	20	18C
0005435785244	13748	21	19A
0005432195698	13748	22	19B
0005435785121	13748	23	19D
0005435787338	13748	24	20A
0005435785201	13748	25	20B
0005435787340	13748	26	20C
0005435785167	13748	27	20D
0005435785210	13748	28	21A
0005435785188	13748	29	21C
0005435785152	13748	30	22A
0005435787339	13748	31	22C
0005435785151	13748	32	22D
0005435785387	27425	1	1A
0005435785386	27425	2	1B
0005435937352	27425	3	1C
0005435785385	27425	4	1D
0005435785376	27425	5	2A
0005435937347	27425	6	2B
0005435785397	27425	7	2C
0005435937329	27425	8	2D
0005435785389	27425	9	3A
0005432190634	27425	10	3B
0005432190632	27425	11	3C
0005435785379	27425	12	3D
0005435785383	27425	13	4A
0005435785375	27425	14	4B
0005435785392	27425	15	4C
0005435785398	27425	16	4D
0005435785381	27425	17	5A
0005435785399	27425	18	5B
0005435785372	27425	19	5D
0005435785395	27425	20	6A
0005435787356	27425	21	6B
0005435785370	27425	22	6C
0005435785384	27425	23	6D
0005435785373	27425	24	7A
0005435785388	27425	25	7B
0005435937333	27425	26	7C
0005435785371	27425	27	7D
0005435785393	27425	28	18A
0005432190633	27425	29	18B
0005435785394	27425	30	18C
0005435785365	27425	31	18D
0005435785374	27425	32	19A
0005435785400	27425	33	19B
0005435787355	27425	34	19C
0005435785380	27425	35	19D
0005435785378	27425	36	20A
0005435785390	27425	37	20B
0005435785382	27425	38	20C
0005435785367	27425	39	20D
0005435785391	27425	40	21A
0005435785377	27425	41	21B
0005435785401	27425	42	21C
0005435785369	27425	43	21D
0005435785396	27425	44	22A
0005435937332	27425	45	22B
0005435937348	27425	46	22C
0005432190631	27425	47	23A
0005435785368	27425	48	22D
0005435785366	27425	49	23B
0005432058391	20303	1	1C
0005434407383	20303	2	2A
0005435311088	20303	3	1F
0005434407537	20303	4	2C
0005434406700	20303	5	2D
0005434407351	20303	6	2F
0005434407075	20303	7	3A
0005434407595	20303	8	3D
0005434407205	20303	9	3C
0005434407303	20303	10	3F
0005434407237	20303	11	4A
0005434407421	20303	12	4C
0005434407127	20303	13	4D
0005434407477	20303	14	4F
0005434407118	20303	15	5A
0005434407204	20303	16	5C
0005435311089	20303	17	5D
0005434407388	20303	18	5E
0005434407408	20303	19	5F
0005434407454	20303	20	6A
0005434407170	20303	21	6C
0005434407175	20303	22	6D
0005434407538	20303	23	6E
0005434407194	20303	24	6F
0005434407449	20303	25	7A
0005434406920	20303	26	7C
0005434407638	20303	27	7D
0005434407191	20303	28	7F
0005434407304	20303	29	8A
0005434407392	20303	30	8C
0005434407142	20303	31	8D
0005434407562	20303	32	8E
0005435311092	20303	33	8F
0005434407352	20303	34	9A
0005434407195	20303	35	9C
0005434407373	20303	36	9D
0005434407362	20303	37	9E
0005434407550	20303	38	9F
0005434407480	20303	39	10A
0005434407168	20303	40	10C
0005434407527	20303	41	10D
0005434407096	20303	42	10E
0005434407217	20303	43	10F
0005434407479	20303	44	11A
0005434407457	20303	45	11D
0005432058389	20303	46	11E
0005434407552	20303	47	12A
0005434407141	20303	48	12C
0005434407238	20303	49	12D
0005434407211	20303	50	12E
0005434407365	20303	51	12F
0005434407437	20303	52	13A
0005434407138	20303	53	13C
0005434407185	20303	54	13D
0005434407279	20303	55	13E
0005434407389	20303	56	14C
0005434407563	20303	57	14D
0005434407317	20303	58	14E
0005434407509	20303	59	14F
0005434407372	20303	60	15A
0005434407453	20303	61	15C
0005434407169	20303	62	15D
0005435311091	20303	63	15E
0005434407569	20303	64	15F
0005434407553	20303	65	16A
0005434407409	20303	66	16C
0005434407438	20303	67	16D
0005434407190	20303	68	16E
0005432058392	20303	69	16F
0005434407478	20303	70	17A
0005434407489	20303	71	17C
0005434407343	20303	72	17D
0005434407186	20303	73	17E
0005434407171	20303	74	17F
0005434407485	20303	75	18A
0005432058390	20303	76	18C
0005434407508	20303	77	18D
0005435311090	20303	78	18E
0005435311093	20303	79	18F
0005434407312	20303	80	19A
0005434407212	20303	81	19C
0005434407076	20303	82	19D
0005434407370	20303	83	19E
0005434407124	20303	84	19F
0005434407407	20303	85	20A
0005434407293	20303	86	20C
0005434407159	20303	87	20D
0005434407251	20303	88	20E
0005434407558	20303	89	20F
0005434407883	26966	1	1A
0005434407887	26966	2	1C
0005434407911	26966	3	1D
0005432153956	26966	4	1F
0005434407869	26966	5	2A
0005434407873	26966	6	2C
0005434407878	26966	7	2D
0005434407891	26966	8	2F
0005434407907	26966	9	3A
0005435310956	26966	10	3C
0005434407868	26966	11	3D
0005434407919	26966	12	3F
0005434407885	26966	13	4A
0005435310958	26966	14	4C
0005434407882	26966	15	4D
0005434407925	26966	16	4E
0005435310968	26966	17	4F
0005434407928	26966	18	5A
0005434407897	26966	19	5C
0005434407926	26966	20	5E
0005434407871	26966	21	5F
0005432153951	26966	22	6A
0005435310899	26966	23	6C
0005434407904	26966	24	6D
0005434407915	26966	25	6E
0005434407866	26966	26	6F
0005434407899	26966	27	7A
0005434407870	26966	28	7C
0005434407895	26966	29	7D
0005434407918	26966	30	7E
0005434407874	26966	31	7F
0005434407880	26966	32	8A
0005435310959	26966	33	8C
0005434407901	26966	34	8E
0005434407916	26966	35	9A
0005432153954	26966	36	9C
0005435310966	26966	37	9D
0005435310944	26966	38	9E
0005434407929	26966	39	9F
0005434407877	26966	40	10C
0005434407909	26966	41	10D
0005434407920	26966	42	10E
0005434407923	26966	43	10F
0005434407881	26966	44	11A
0005434407894	26966	45	11C
0005434407884	26966	46	11D
0005434407908	26966	47	11E
0005434407924	26966	48	11F
0005434407896	26966	49	12A
0005435310980	26966	50	12C
0005434407917	26966	51	12D
0005432153952	26966	52	12E
0005434407890	26966	53	12F
0005434407921	26966	54	13A
0005434407875	26966	55	13D
0005435310963	26966	56	13E
0005432153955	26966	57	14C
0005434407903	26966	58	14D
0005434407910	26966	59	14E
0005434407879	26966	60	14F
0005435310969	26966	61	15A
0005434407922	26966	62	15D
0005435310935	26966	63	15E
0005432153950	26966	64	15F
0005434407889	26966	65	16A
0005434407927	26966	66	16C
0005434407893	26966	67	16D
0005434407905	26966	68	16E
0005434407876	26966	69	16F
0005434407906	26966	70	17A
0005432153953	26966	71	17D
0005435310970	26966	72	17E
0005434407900	26966	73	17F
0005435310972	26966	74	18A
0005435310973	26966	75	18C
0005434407872	26966	76	18F
0005434407902	26966	77	19A
0005434407898	26966	78	19C
0005434407892	26966	79	19D
0005434407888	26966	80	19E
0005434407914	26966	81	19F
0005434407912	26966	82	20A
0005432153949	26966	83	20C
0005434407886	26966	84	20D
0005434407867	26966	85	20E
0005434407913	26966	86	20F
0005434319415	5710	1	1D
0005433123780	5710	2	3A
0005433123711	5710	3	3F
0005433123823	5710	4	4C
0005434319422	5710	5	4F
0005433123798	5710	6	6C
0005434319414	5710	7	6F
0005433123733	5710	8	7A
0005433123777	5710	9	9A
0005433123813	5710	10	9D
0005434319418	5710	11	10F
0005434311224	5710	12	11A
0005434311225	5710	13	11C
0005432109708	5710	14	11F
0005434319420	5710	15	12A
0005434311223	5710	16	12C
0005434319416	5710	17	12D
0005433123858	5710	18	13E
0005433123712	5710	19	14C
0005433123740	5710	20	14E
0005432109709	5710	21	14F
0005433123797	5710	22	15A
0005433123732	5710	23	15D
0005434319417	5710	24	15F
0005434319421	5710	25	16A
0005433123812	5710	26	16C
0005433123826	5710	27	16E
0005433123717	5710	28	17C
0005434319419	5710	29	18F
0005432109710	5710	30	20C
0005433123778	5710	31	20F
0005434312308	15696	1	1D
0005434319365	15696	2	1F
0005434312315	15696	3	2D
0005434319366	15696	4	2F
0005433123978	15696	5	3A
0005434319330	15696	6	3D
0005434312305	15696	7	3F
0005434319275	15696	8	4F
0005434311203	15696	9	5D
0005433123974	15696	10	6A
0005433123986	15696	11	7C
0005434319364	15696	12	8D
0005433123989	15696	13	9A
0005434319360	15696	14	9C
0005434319315	15696	15	10F
0005433123983	15696	16	11A
0005434319269	15696	17	11C
0005434319316	15696	18	11E
0005434319361	15696	19	11F
0005433123975	15696	20	12C
0005433123977	15696	21	12D
0005433123982	15696	22	12E
0005434319333	15696	23	13A
0005433123987	15696	24	13C
0005433123979	15696	25	13E
0005434319289	15696	26	13F
0005433123981	15696	27	14A
0005434312307	15696	28	15A
0005434312306	15696	29	15E
0005433123984	15696	30	17A
0005433123988	15696	31	17C
0005434319332	15696	32	17E
0005433123985	15696	33	18C
0005434319328	15696	34	18D
0005433123980	15696	35	18E
0005434319331	15696	36	18F
0005434319310	15696	37	19A
0005434319335	15696	38	20C
0005434319334	15696	39	20D
0005433123976	15696	40	20E
0005434484359	8990	1	3D
0005434484364	8990	2	4A
0005434484363	8990	3	4B
0005434484360	8990	4	5A
0005434484365	8990	5	5C
0005434484362	8990	6	6A
0005434189156	8990	7	7B
0005434189127	8990	8	18D
0005434484361	8990	9	22C
0005434189126	8990	10	22D
0005434189189	16632	1	1B
0005434484322	16632	2	2D
0005434189191	16632	3	5D
0005434189190	16632	4	6A
0005434189193	16632	5	18C
0005434189192	16632	6	19D
0005434484327	16632	7	20D
0005434189188	16632	8	22B
0005433123982	7669	1	1D
0005433123985	7669	2	3C
0005433123974	7669	3	3D
0005433123978	7669	4	5C
0005433722167	7669	5	5E
0005433123975	7669	6	7E
0005433123981	7669	7	9A
0005433123977	7669	8	12C
0005433123980	7669	9	12D
0005433123983	7669	10	12E
0005433123979	7669	11	13F
0005433123976	7669	12	14C
0005433722169	7669	13	14E
0005433123986	7669	14	15E
0005433123984	7669	15	17A
0005433123987	7669	16	18D
0005433123989	7669	17	18F
0005433123988	7669	18	20D
0005432693135	7668	1	1C
0005432720962	7668	2	1D
0005433450016	7668	3	1F
0005432720960	7668	4	2A
0005432720971	7668	5	2C
0005432693140	7668	6	2D
0005433450012	7668	7	2F
0005432720974	7668	8	3A
0005432693158	7668	9	3C
0005432693141	7668	10	3D
0005432693139	7668	11	3F
0005433450009	7668	12	4A
0005432720967	7668	13	4D
0005432693151	7668	14	4F
0005432720954	7668	15	5A
0005432720975	7668	16	5D
0005432693145	7668	17	5E
0005433450022	7668	18	5F
0005433450024	7668	19	6A
0005432693156	7668	20	6C
0005432693132	7668	21	6D
0005432693146	7668	22	6E
0005432071580	7668	23	6F
0005432071578	7668	24	7A
0005432720959	7668	25	7C
0005432693131	7668	26	7D
0005432693133	7668	27	7E
0005433450017	7668	28	7F
0005432071581	7668	29	8A
0005432720955	7668	30	8C
0005432693152	7668	31	8D
0005433450011	7668	32	8E
0005433450028	7668	33	8F
0005432720970	7668	34	9A
0005432693157	7668	35	9C
0005432720950	7668	36	9D
0005433450027	7668	37	10A
0005432693134	7668	38	10C
0005432720957	7668	39	10D
0005432693128	7668	40	10E
0005433450014	7668	41	10F
0005432693149	7668	42	11A
0005433450019	7668	43	11C
0005432720977	7668	44	11D
0005432720964	7668	45	11E
0005432720956	7668	46	11F
0005432693136	7668	47	12A
0005432693130	7668	48	12C
0005433450021	7668	49	12D
0005432720961	7668	50	12E
0005432720966	7668	51	12F
0005433450023	7668	52	13A
0005432693154	7668	53	13C
0005432720965	7668	54	13D
0005432693155	7668	55	14A
0005432720951	7668	56	14C
0005433450015	7668	57	14D
0005432693150	7668	58	14F
0005432720958	7668	59	15A
0005432693148	7668	60	15D
0005432693143	7668	61	15E
0005432720952	7668	62	15F
0005433450020	7668	63	16A
0005432720968	7668	64	16C
0005432693144	7668	65	16D
0005432693127	7668	66	16E
0005433450025	7668	67	16F
0005432720976	7668	68	17A
0005432071579	7668	69	17C
0005432720972	7668	70	17D
0005432693142	7668	71	17E
0005432720969	7668	72	17F
0005432693153	7668	73	18D
0005433450010	7668	74	18C
0005432720953	7668	75	18E
0005433450013	7668	76	18F
0005433450018	7668	77	19A
0005433450026	7668	78	19C
0005432720963	7668	79	19D
0005433450008	7668	80	19E
0005432720973	7668	81	19F
0005432693147	7668	82	20A
0005432693138	7668	83	20C
0005432693129	7668	84	20D
0005432693137	7668	85	20F
0005432692802	30290	1	1A
0005433449922	30290	2	1D
0005432692782	30290	3	2A
0005433449835	30290	4	2C
0005432692877	30290	5	2F
0005432692993	30290	6	3C
0005433449763	30290	7	4C
0005433449803	30290	8	5A
0005433449796	30290	9	5C
0005433449826	30290	10	5D
0005432692888	30290	11	5F
0005432692884	30290	12	6A
0005432692994	30290	13	6D
0005433449850	30290	14	6E
0005433449805	30290	15	6F
0005433449836	30290	16	7A
0005433449866	30290	17	7C
0005432692781	30290	18	7E
0005432692799	30290	19	8A
0005432692762	30290	20	8C
0005433449871	30290	21	8D
0005432692964	30290	22	8E
0005432692728	30290	23	8F
0005432692893	30290	24	9A
0005432692829	30290	25	9C
0005432692790	30290	26	9E
0005432692965	30290	27	10A
0005433449882	30290	28	10C
0005432692966	30290	29	10D
0005433449867	30290	30	10E
0005433449838	30290	31	11D
0005433449862	30290	32	11E
0005432692789	30290	33	12F
0005433449887	30290	34	13C
0005432692889	30290	35	13D
0005432692923	30290	36	13F
0005432692791	30290	37	14A
0005433449874	30290	38	14E
0005433449875	30290	39	14F
0005432692825	30290	40	15C
0005433449865	30290	41	15D
0005432692758	30290	42	16A
0005432692800	30290	43	16C
0005432692878	30290	44	16D
0005433449837	30290	45	16E
0005432692992	30290	46	16F
0005433449889	30290	47	17A
0005432692812	30290	48	17C
0005433449825	30290	49	17E
0005432692783	30290	50	18A
0005432692983	30290	51	18C
0005432692761	30290	52	18D
0005433449888	30290	53	18E
0005433449872	30290	54	19A
0005433449831	30290	55	19C
0005432692982	30290	56	19D
0005432692801	30290	57	20A
0005433449883	30290	58	20C
0005433449840	30290	59	20E
0005433449804	30290	60	20F
0005432720787	30289	1	1A
0005432720692	30289	2	1C
0005432720680	30289	3	1D
0005433123733	30289	4	2F
0005432720746	30289	5	3A
0005432720685	30289	6	3C
0005433123712	30289	7	3F
0005433722233	30289	8	4A
0005433123823	30289	9	4C
0005433722236	30289	10	4D
0005432720669	30289	11	4E
0005432720792	30289	12	5A
0005432720706	30289	13	5E
0005432720817	30289	14	6C
0005433123812	30289	15	6D
0005432720670	30289	16	6E
0005433123732	30289	17	7A
0005433123711	30289	18	7C
0005432720786	30289	19	7F
0005433123813	30289	20	8C
0005433123740	30289	21	8D
0005432720762	30289	22	8E
0005432720707	30289	23	8F
0005433123797	30289	24	10C
0005433722234	30289	25	11C
0005432720810	30289	26	11F
0005433722232	30289	27	13E
0005433123777	30289	28	13F
0005432720761	30289	29	14A
0005432720684	30289	30	14D
0005432720791	30289	31	15A
0005432720782	30289	32	15C
0005433123778	30289	33	15D
0005433722235	30289	34	15F
0005433123780	30289	35	16C
0005433123798	30289	36	16E
0005433123858	30289	37	17F
0005432720785	30289	38	18D
0005432720815	30289	39	19E
0005433123717	30289	40	20C
0005433123826	30289	41	20E
0005434586666	1401	1	1A
0005432968822	1401	2	1C
0005434586672	1401	3	2A
0005432927954	1401	4	2C
0005434514974	1401	5	2D
0005433192951	1401	6	2F
0005434586680	1401	7	3A
0005434586661	1401	8	3F
0005434586657	1401	9	4A
0005433192953	1401	10	4C
0005432927937	1401	11	4E
0005434514972	1401	12	5C
0005433192997	1401	13	5D
0005432968828	1401	14	5E
0005434586667	1401	15	5F
0005434513586	1401	16	6A
0005434586681	1401	17	6E
0005433525067	1401	18	7A
0005433724818	1401	19	7C
0005433724815	1401	20	7E
0005434586679	1401	21	7F
0005432271011	1401	22	8A
0005434586658	1401	23	8C
0005434586669	1401	24	8D
0005433192954	1401	25	8E
0005433525064	1401	26	8F
0005434586674	1401	27	9A
0005433192938	1401	28	9C
0005434513585	1401	29	9D
0005433724817	1401	30	9E
0005433724816	1401	31	9F
0005432968821	1401	32	10D
0005432271010	1401	33	10F
0005434586663	1401	34	11A
0005434586671	1401	35	11C
0005434586678	1401	36	11D
0005434513584	1401	37	11F
0005433192939	1401	38	12A
0005434586660	1401	39	12C
0005433525069	1401	40	12D
0005434586670	1401	41	12F
0005433525063	1401	42	13A
0005434586664	1401	43	13C
0005434586662	1401	44	13D
0005434586677	1401	45	13F
0005433192998	1401	46	14A
0005433192952	1401	47	14C
0005432968829	1401	48	14F
0005433193022	1401	49	15A
0005434586673	1401	50	15D
0005434586659	1401	51	15E
0005434586682	1401	52	16A
0005434586675	1401	53	16C
0005434514973	1401	54	16D
0005433525060	1401	55	16E
0005434586665	1401	56	16F
0005433525066	1401	57	17A
0005434586668	1401	58	17C
0005432927952	1401	59	17D
0005432968820	1401	60	17F
0005433525068	1401	61	18A
0005433525059	1401	62	18C
0005433525058	1401	63	18D
0005433525062	1401	64	18E
0005433525061	1401	65	18F
0005433192989	1401	66	19A
0005434586676	1401	67	19C
0005433525065	1401	68	19D
0005433192955	1401	69	20C
0005432927938	1401	70	20D
0005434513587	1401	71	20E
0005432927990	18537	1	1A
0005433193069	18537	2	1D
0005434586468	18537	3	2C
0005432927991	18537	4	3A
0005433193077	18537	5	3C
0005434586418	18537	6	3F
0005433524966	18537	7	4D
0005434586421	18537	8	4E
0005434586439	18537	9	4F
0005434586539	18537	10	5F
0005433724777	18537	11	6A
0005433193078	18537	12	6E
0005434586438	18537	13	7C
0005433524946	18537	14	7D
0005433193076	18537	15	7E
0005433193073	18537	16	7F
0005433193079	18537	17	8A
0005433524952	18537	18	8D
0005433524892	18537	19	8E
0005433193080	18537	20	8F
0005433193070	18537	21	9A
0005434586479	18537	22	9F
0005433193081	18537	23	10C
0005434586406	18537	24	10E
0005433193071	18537	25	10F
0005434586464	18537	26	11A
0005433524943	18537	27	11D
0005433524922	18537	28	12A
0005433724776	18537	29	12C
0005434586470	18537	30	12D
0005434586441	18537	31	12E
0005434586472	18537	32	13A
0005433524967	18537	33	13C
0005434586566	18537	34	13D
0005434586491	18537	35	13E
0005433724775	18537	36	13F
0005434586444	18537	37	14C
0005432927993	18537	38	14D
0005433524893	18537	39	14F
0005434586467	18537	40	15A
0005434586478	18537	41	15C
0005432968845	18537	42	15F
0005432927992	18537	43	16A
0005433524921	18537	44	16C
0005433193072	18537	45	16D
0005432927994	18537	46	16E
0005434586422	18537	47	17A
0005433524965	18537	48	17C
0005432968844	18537	49	17E
0005434586417	18537	50	18C
0005433193075	18537	51	18D
0005434586469	18537	52	18F
0005434586490	18537	53	18E
0005434586473	18537	54	19A
0005432927989	18537	55	19F
0005434586516	18537	56	20C
0005433524953	18537	57	20E
0005433193074	18537	58	20F
0005434344267	11456	1	1A
0005434344265	11456	2	1C
0005434344254	11456	3	1B
0005434344251	11456	4	1D
0005434344270	11456	5	2A
0005434344276	11456	6	2B
0005434344284	11456	7	2C
0005434344257	11456	8	2D
0005434344275	11456	9	3A
0005434344266	11456	10	3B
0005434344268	11456	11	3C
0005434344249	11456	12	4A
0005434344277	11456	13	4B
0005435305001	11456	14	4C
0005434344281	11456	15	4D
0005434344263	11456	16	5A
0005434344271	11456	17	5B
0005434142620	11456	18	5C
0005435305002	11456	19	5D
0005434344285	11456	20	6C
0005434344262	11456	21	6B
0005434142618	11456	22	6D
0005435302156	11456	23	7A
0005435302172	11456	24	7B
0005434344280	11456	25	7C
0005434344250	11456	26	7D
0005434344269	11456	27	18B
0005434142621	11456	28	18C
0005435302155	11456	29	18D
0005434344252	11456	30	19A
0005434344258	11456	31	19B
0005434344260	11456	32	19C
0005434344273	11456	33	19D
0005434344279	11456	34	20A
0005434344259	11456	35	20B
0005434344283	11456	36	20C
0005434344255	11456	37	20D
0005434344282	11456	38	21A
0005434344286	11456	39	21B
0005434142619	11456	40	21C
0005434344261	11456	41	21D
0005434344256	11456	42	22A
0005434344253	11456	43	22B
0005434344274	11456	44	22C
0005434344272	11456	45	22D
0005434344278	11456	46	23A
0005434344264	11456	47	23B
0005435304168	29754	1	1A
0005434343814	29754	2	1B
0005435304169	29754	3	1C
0005435304171	29754	4	1D
0005434343936	29754	5	2B
0005434343792	29754	6	2C
0005434343980	29754	7	2D
0005435304172	29754	8	3B
0005434343791	29754	9	3C
0005434344017	29754	10	3D
0005434343932	29754	11	4A
0005434343861	29754	12	4B
0005435304173	29754	13	4C
0005434343902	29754	14	4D
0005434343937	29754	15	5A
0005434343858	29754	16	5B
0005434142592	29754	17	5C
0005434344022	29754	18	5D
0005434343860	29754	19	6A
0005434344059	29754	20	6B
0005434344006	29754	21	6C
0005434343981	29754	22	7A
0005434142580	29754	23	7B
0005434344018	29754	24	7C
0005434343984	29754	25	7D
0005434343877	29754	26	18A
0005434343775	29754	27	18C
0005434142581	29754	28	19A
0005434343943	29754	29	19B
0005434344048	29754	30	19D
0005434343954	29754	31	19C
0005434343859	29754	32	20A
0005434343978	29754	33	20B
0005434343862	29754	34	20C
0005434344016	29754	35	20D
0005434344125	29754	36	21A
0005434142597	29754	37	21B
0005434343857	29754	38	21C
0005434343815	29754	39	21D
0005434343926	29754	40	22A
0005434343875	29754	41	22B
0005434343944	29754	42	22C
0005434343961	29754	43	22D
0005435304170	29754	44	23A
0005435824677	1259	1	1A
0005435824697	1259	2	2F
0005432284566	1259	3	3A
0005433415570	1259	4	3D
0005433415534	1259	5	5D
0005433415572	1259	6	5C
0005435824673	1259	7	6A
0005435824688	1259	8	6B
0005435824674	1259	9	6F
0005433415539	1259	10	6E
0005433415574	1259	11	7A
0005435824694	1259	12	7E
0005433415577	1259	13	8B
0005435824699	1259	14	8D
0005435824676	1259	15	9A
0005433415576	1259	16	9C
0005435824690	1259	17	10B
0005433415621	1259	18	10C
0005435824696	1259	19	10E
0005435824698	1259	20	11A
0005435824683	1259	21	10F
0005435824692	1259	22	11B
0005433415618	1259	23	11D
0005433415613	1259	24	11E
0005433415535	1259	25	12D
0005433415573	1259	26	12C
0005435824675	1259	27	12E
0005435824691	1259	28	13F
0005435824680	1259	29	14C
0005435824684	1259	30	14A
0005432284565	1259	31	14E
0005433415602	1259	32	14F
0005432284567	1259	33	15D
0005435824681	1259	34	15F
0005435824686	1259	35	15E
0005433415575	1259	36	16B
0005435824693	1259	37	16F
0005435824682	1259	38	17D
0005432284564	1259	39	17C
0005433415599	1259	40	18A
0005435824685	1259	41	18B
0005435824695	1259	42	18E
0005435824689	1259	43	18D
0005435824679	1259	44	19A
0005433415598	1259	45	19B
0005433415620	1259	46	19D
0005435824678	1259	47	20C
0005435824687	1259	48	20F
0005433415600	1259	49	21B
0005433415581	1259	50	21C
0005433415693	18010	1	1A
0005435824469	18010	2	2A
0005435824411	18010	3	3A
0005433415701	18010	4	2F
0005433415698	18010	5	3D
0005435824500	18010	6	3C
0005435824357	18010	7	4F
0005433415692	18010	8	6C
0005435824285	18010	9	6E
0005433415702	18010	10	6D
0005433415700	18010	11	7E
0005435824512	18010	12	7F
0005435824422	18010	13	8F
0005435824346	18010	14	9B
0005433415696	18010	15	9A
0005435824402	18010	16	9C
0005435824467	18010	17	9F
0005435824508	18010	18	10C
0005433415699	18010	19	10B
0005435824419	18010	20	11A
0005435824356	18010	21	11B
0005435824552	18010	22	11D
0005435824405	18010	23	11F
0005435824345	18010	24	11E
0005435824515	18010	25	12A
0005435824431	18010	26	12C
0005435824474	18010	27	12F
0005435824358	18010	28	13B
0005435824335	18010	29	13A
0005435824460	18010	30	13E
0005435824284	18010	31	13D
0005435824516	18010	32	14C
0005433415694	18010	33	15C
0005433415690	18010	34	15E
0005433415691	18010	35	15D
0005435824448	18010	36	16A
0005435824498	18010	37	16C
0005435824507	18010	38	16E
0005435824468	18010	39	17C
0005433415697	18010	40	17E
0005433415689	18010	41	18E
0005435824511	18010	42	19C
0005433415703	18010	43	19B
0005433415695	18010	44	19F
0005433415688	18010	45	20D
0005435824586	18010	46	20E
0005435824359	18010	47	21C
0005435824412	18010	48	21D
0005434460504	12577	1	1A
0005434461643	12577	2	1B
0005434460505	12577	3	1D
0005434460508	12577	4	2C
0005434461648	12577	5	3A
0005434460501	12577	6	3D
0005434461649	12577	7	4B
0005434460506	12577	8	4C
0005434461645	12577	9	6A
0005434460503	12577	10	7B
0005434460500	12577	11	7D
0005434461642	12577	12	18B
0005434461644	12577	13	18D
0005434460507	12577	14	19B
0005434461646	12577	15	21C
0005434461650	12577	16	22C
0005434461647	12577	17	22D
0005434460502	12577	18	23B
0005432783905	5628	1	1A
0005432783896	5628	2	1C
0005432783935	5628	3	1D
0005432783903	5628	4	1F
0005432783937	5628	5	2A
0005432783925	5628	6	2C
0005432783919	5628	7	2D
0005435242690	5628	8	2F
0005432783885	5628	9	3A
0005432783927	5628	10	3C
0005435242588	5628	11	3D
0005435242632	5628	12	3F
0005432783906	5628	13	4A
0005435242572	5628	14	4C
0005432783912	5628	15	4D
0005435242671	5628	16	4E
0005432783922	5628	17	4F
0005432783886	5628	18	5A
0005435242722	5628	19	5C
0005432783939	5628	20	5D
0005435242630	5628	21	5E
0005432783917	5628	22	5F
0005432783936	5628	23	6A
0005432783889	5628	24	6C
0005432783929	5628	25	6D
0005435476695	5628	26	6E
0005435242631	5628	27	6F
0005432783932	5628	28	7A
0005432783908	5628	29	7C
0005432783928	5628	30	7D
0005432783921	5628	31	7E
0005435242663	5628	32	7F
0005432783923	5628	33	8A
0005432783914	5628	34	8C
0005432783895	5628	35	8D
0005435242785	5628	36	8E
0005432783893	5628	37	8F
0005432783926	5628	38	9A
0005435476744	5628	39	9C
0005432783888	5628	40	9D
0005432783892	5628	41	9E
0005432783904	5628	42	9F
0005432783898	5628	43	10A
0005435476730	5628	44	10C
0005435242724	5628	45	10E
0005432783916	5628	46	10F
0005432783902	5628	47	11A
0005432783887	5628	48	11C
0005432783900	5628	49	11D
0005435242670	5628	50	11E
0005432783918	5628	51	11F
0005435242657	5628	52	12A
0005432783897	5628	53	12C
0005432783934	5628	54	12D
0005435476731	5628	55	12E
0005435242673	5628	56	12F
0005435242786	5628	57	13A
0005432783924	5628	58	13C
0005432783901	5628	59	13D
0005432143995	5628	60	13E
0005432783890	5628	61	13F
0005432783915	5628	62	14A
0005432783891	5628	63	14C
0005432783909	5628	64	14D
0005435242694	5628	65	14E
0005432783911	5628	66	14F
0005435242760	5628	67	15C
0005432783933	5628	68	15D
0005432783907	5628	69	15E
0005432143994	5628	70	15F
0005435242571	5628	71	16A
0005435476711	5628	72	16C
0005435476696	5628	73	16D
0005432783920	5628	74	16E
0005435242555	5628	75	16F
0005432783894	5628	76	17A
0005432783930	5628	77	17C
0005435476710	5628	78	17D
0005435476709	5628	79	17E
0005435476713	5628	80	17F
0005432783899	5628	81	18C
0005435242611	5628	82	18E
0005432783931	5628	83	18F
0005432783913	5628	84	19A
0005435242787	5628	85	19C
0005432143993	5628	86	19D
0005435242612	5628	87	19E
0005435242587	5628	88	19F
0005432783910	5628	89	20A
0005435242658	5628	90	20C
0005432783938	5628	91	20D
0005435476705	5628	92	20E
0005432783401	15382	1	1A
0005432783635	15382	2	1C
0005432783214	15382	3	1D
0005435242896	15382	4	1F
0005432783062	15382	5	2C
0005435242891	15382	6	2D
0005432783296	15382	7	2F
0005432783232	15382	8	3A
0005432783136	15382	9	3C
0005432783231	15382	10	3D
0005435242903	15382	11	3F
0005432783646	15382	12	4A
0005435242899	15382	13	4C
0005432783536	15382	14	4D
0005435242890	15382	15	4E
0005432783135	15382	16	4F
0005435242905	15382	17	5A
0005435242892	15382	18	5C
0005432783361	15382	19	5E
0005432783142	15382	20	6A
0005432783374	15382	21	6C
0005432783460	15382	22	6D
0005432783534	15382	23	6E
0005432783486	15382	24	6F
0005435242902	15382	25	7A
0005435242900	15382	26	7C
0005435242886	15382	27	7D
0005435242889	15382	28	7E
0005435242895	15382	29	7F
0005432783485	15382	30	8A
0005432783410	15382	31	8C
0005432783573	15382	32	8D
0005435242898	15382	33	8F
0005432783498	15382	34	8E
0005432783471	15382	35	9A
0005432783373	15382	36	9C
0005432783407	15382	37	9D
0005432783063	15382	38	9E
0005432783397	15382	39	9F
0005432783306	15382	40	10A
0005432783411	15382	41	10C
0005432783574	15382	42	10D
0005435242897	15382	43	10E
0005435476766	15382	44	10F
0005435242881	15382	45	11A
0005435242888	15382	46	11C
0005432783356	15382	47	11D
0005432783629	15382	48	11F
0005435242893	15382	49	12A
0005435242882	15382	50	12C
0005432783365	15382	51	12D
0005432783141	15382	52	12E
0005432783584	15382	53	12F
0005432783545	15382	54	13A
0005432783415	15382	55	13C
0005435476764	15382	56	13D
0005432783126	15382	57	13E
0005435242906	15382	58	13F
0005435476763	15382	59	14A
0005432783550	15382	60	14C
0005432783271	15382	61	14D
0005435242884	15382	62	14E
0005435242901	15382	63	14F
0005432783442	15382	64	15A
0005435242887	15382	65	15C
0005432783362	15382	66	15D
0005432783376	15382	67	15E
0005432783467	15382	68	15F
0005435242883	15382	69	16A
0005432783227	15382	70	16C
0005432783314	15382	71	16D
0005432783269	15382	72	16E
0005435242907	15382	73	17A
0005432783059	15382	74	17C
0005435242885	15382	75	17D
0005432783472	15382	76	17E
0005432783137	15382	77	17F
0005432783461	15382	78	18A
0005435242894	15382	79	18C
0005432783428	15382	80	18D
0005432783391	15382	81	18E
0005435242904	15382	82	18F
0005432783217	15382	83	19A
0005432783535	15382	84	19C
0005432783537	15382	85	19D
0005432783392	15382	86	19E
0005432783182	15382	87	20A
0005435242880	15382	88	19F
0005435476765	15382	89	20C
0005432783370	15382	90	20D
0005432783630	15382	91	20E
0005435476767	15382	92	20F
0005435850883	4357	1	1B
0005435850852	4357	2	1C
0005432848338	4357	3	2A
0005434463934	4357	4	2C
0005435850853	4357	5	3B
0005435850881	4357	6	3A
0005435850882	4357	7	3C
0005432848345	4357	8	3D
0005434462796	4357	9	4A
0005432848344	4357	10	5C
0005432848347	4357	11	5D
0005434463935	4357	12	6A
0005434462794	4357	13	6B
0005432848346	4357	14	6C
0005432848340	4357	15	7C
0005435850854	4357	16	20A
0005432848343	4357	17	20C
0005434462795	4357	18	20D
0005432848348	4357	19	21A
0005432848351	4357	20	21B
0005432848337	4357	21	21C
0005432848342	4357	22	21D
0005432848350	4357	23	22A
0005432848349	4357	24	22B
0005432848339	4357	25	22C
0005432848341	4357	26	23A
0005432848275	28875	1	1A
0005432848254	28875	2	1B
0005432848273	28875	3	1C
0005432848198	28875	4	1D
0005432848231	28875	5	2A
0005432848190	28875	6	2B
0005432848274	28875	7	3B
0005432848243	28875	8	3C
0005432848207	28875	9	3D
0005432848272	28875	10	4A
0005432848196	28875	11	4C
0005434463923	28875	12	4D
0005432848189	28875	13	5A
0005432848267	28875	14	5B
0005434463922	28875	15	5D
0005432848223	28875	16	6A
0005435850927	28875	17	6B
0005432848208	28875	18	6C
0005432848213	28875	19	6D
0005435850934	28875	20	7A
0005435850929	28875	21	7B
0005435850930	28875	22	7C
0005432848187	28875	23	7D
0005435850931	28875	24	18B
0005432848268	28875	25	18D
0005432848181	28875	26	19A
0005432848186	28875	27	19B
0005435850926	28875	28	19C
0005432848242	28875	29	20A
0005432848165	28875	30	20B
0005435850928	28875	31	20D
0005432848244	28875	32	21A
0005435850933	28875	33	21B
0005432848185	28875	34	21C
0005434463907	28875	35	21D
0005432848180	28875	36	22A
0005435850932	28875	37	22B
0005432848197	28875	38	22D
0005434461621	28875	39	23A
0005432848214	28875	40	23B
0005434925871	6310	1	1A
0005434925857	6310	2	1D
0005433497026	6310	3	1F
0005433497047	6310	4	2F
0005434925870	6310	5	3A
0005433497027	6310	6	3C
0005434925863	6310	7	3D
0005434925878	6310	8	3F
0005434443738	6310	9	4A
0005433497043	6310	10	4C
0005433497037	6310	11	4D
0005434443742	6310	12	4E
0005433497056	6310	13	4F
0005434925867	6310	14	5A
0005433497032	6310	15	5C
0005433497028	6310	16	5D
0005434443745	6310	17	5E
0005433497044	6310	18	5F
0005432075238	6310	19	6C
0005433497031	6310	20	6D
0005433497036	6310	21	7A
0005434925876	6310	22	7C
0005433497038	6310	23	7D
0005432075237	6310	24	7E
0005434925869	6310	25	7F
0005433497055	6310	26	8A
0005433497049	6310	27	8D
0005434925875	6310	28	8F
0005433497045	6310	29	9A
0005433497034	6310	30	9C
0005433497039	6310	31	9D
0005434925872	6310	32	9E
0005434925860	6310	33	9F
0005433497054	6310	34	10A
0005434443741	6310	35	10C
0005434925858	6310	36	10F
0005434443751	6310	37	11A
0005434443750	6310	38	11C
0005434925864	6310	39	11D
0005434925862	6310	40	11E
0005434443748	6310	41	11F
0005433497040	6310	42	12A
0005434925879	6310	43	12C
0005434925866	6310	44	12D
0005434443753	6310	45	12E
0005434925882	6310	46	12F
0005434925874	6310	47	13C
0005434443739	6310	48	13D
0005434443747	6310	49	13E
0005434925881	6310	50	13F
0005433497046	6310	51	14A
0005434443746	6310	52	14C
0005434925868	6310	53	14D
0005432075239	6310	54	14F
0005434925861	6310	55	15A
0005433497051	6310	56	15C
0005434443744	6310	57	15D
0005433497030	6310	58	15E
0005434443743	6310	59	15F
0005433497033	6310	60	16A
0005433497053	6310	61	16C
0005434925865	6310	62	16F
0005433497042	6310	63	17A
0005434925873	6310	64	17C
0005433497029	6310	65	17D
0005434925859	6310	66	17E
0005434443740	6310	67	18C
0005434443754	6310	68	18D
0005434925880	6310	69	18E
0005433497052	6310	70	18F
0005433497048	6310	71	19C
0005433497041	6310	72	19D
0005434925877	6310	73	19E
0005434443752	6310	74	19F
0005433497035	6310	75	20A
0005433497057	6310	76	20C
0005433497050	6310	77	20D
0005434443749	6310	78	20F
0005433496887	20405	1	1A
0005434443630	20405	2	1C
0005434925501	20405	3	1F
0005433496888	20405	4	2A
0005433496884	20405	5	2D
0005434443631	20405	6	2F
0005434925367	20405	7	3A
0005433496767	20405	8	3C
0005434925505	20405	9	3D
0005434925585	20405	10	3F
0005434925546	20405	11	4A
0005433496788	20405	12	4D
0005433496664	20405	13	4E
0005434925563	20405	14	4F
0005434925408	20405	15	5A
0005433496828	20405	16	5C
0005433496754	20405	17	5D
0005433496857	20405	18	5E
0005433496829	20405	19	5F
0005434925603	20405	20	6A
0005434925561	20405	21	6D
0005434925521	20405	22	6E
0005433496745	20405	23	6F
0005433496952	20405	24	7A
0005434925645	20405	25	7C
0005434925565	20405	26	7D
0005433496886	20405	27	7F
0005434925509	20405	28	8A
0005434925655	20405	29	8C
0005434925435	20405	30	8D
0005433496885	20405	31	8F
0005433496778	20405	32	9A
0005433496846	20405	33	9C
0005434925409	20405	34	9D
0005434925644	20405	35	9E
0005434925599	20405	36	9F
0005434925583	20405	37	10A
0005433496766	20405	38	10C
0005433496816	20405	39	10D
0005433496635	20405	40	10E
0005434925587	20405	41	10F
0005434443518	20405	42	11C
0005434925571	20405	43	11D
0005434925584	20405	44	11E
0005433496746	20405	45	11F
0005434925592	20405	46	12A
0005434925567	20405	47	12C
0005434925568	20405	48	12D
0005434443629	20405	49	12E
0005434925506	20405	50	12F
0005433496890	20405	51	13A
0005434925606	20405	52	13D
0005434443563	20405	53	13E
0005434925562	20405	54	13F
0005434925582	20405	55	14A
0005433496721	20405	56	14C
0005434925483	20405	57	14D
0005433496922	20405	58	14F
0005434925533	20405	59	15C
0005434925368	20405	60	15D
0005433496653	20405	61	15F
0005433496787	20405	62	16A
0005433496776	20405	63	16D
0005434925598	20405	64	16F
0005433496777	20405	65	17A
0005434925547	20405	66	17C
0005434925641	20405	67	17D
0005434925518	20405	68	17E
0005434925507	20405	69	17F
0005434925500	20405	70	18A
0005434925640	20405	71	18C
0005434443593	20405	72	18D
0005433496805	20405	73	18E
0005434925545	20405	74	18F
0005434925534	20405	75	19A
0005434925586	20405	76	19C
0005434925600	20405	77	19D
0005434925596	20405	78	19F
0005434925566	20405	79	20C
0005434925436	20405	80	20A
0005433496728	20405	81	20D
0005433496652	20405	82	20E
0005434925504	20405	83	20F
0005432783295	12201	1	1C
0005435242921	12201	2	1D
0005432783437	12201	3	1F
0005432783402	12201	4	2A
0005435242909	12201	5	2C
0005432783358	12201	6	2D
0005432783357	12201	7	3A
0005435242914	12201	8	3F
0005435242917	12201	9	4A
0005435242933	12201	10	4C
0005435242915	12201	11	4D
0005432783234	12201	12	4E
0005432783371	12201	13	4F
0005435242910	12201	14	5A
0005435242924	12201	15	5C
0005435242927	12201	16	5D
0005432783705	12201	17	5E
0005435242908	12201	18	5F
0005432783409	12201	19	6A
0005432783408	12201	20	6C
0005432783178	12201	21	6D
0005432783294	12201	22	6F
0005432783704	12201	23	7A
0005435242922	12201	24	7C
0005432783519	12201	25	7D
0005435242934	12201	26	7E
0005432783443	12201	27	7F
0005432783303	12201	28	8A
0005435242912	12201	29	8C
0005432783457	12201	30	8E
0005432783318	12201	31	8F
0005432783529	12201	32	9A
0005435242935	12201	33	9C
0005432783562	12201	34	9D
0005432783455	12201	35	9E
0005432783576	12201	36	9F
0005432783359	12201	37	10A
0005432783155	12201	38	10C
0005435242929	12201	39	10D
0005432783305	12201	40	10F
0005432783465	12201	41	11A
0005432783478	12201	42	11C
0005432783399	12201	43	11D
0005435242925	12201	44	11E
0005435242923	12201	45	11F
0005432783310	12201	46	12A
0005435242916	12201	47	12C
0005432783538	12201	48	12E
0005432783717	12201	49	12F
0005432783018	12201	50	13C
0005435242931	12201	51	13D
0005435242919	12201	52	13E
0005435242926	12201	53	13F
0005432783304	12201	54	14A
0005435242932	12201	55	14C
0005432783364	12201	56	14E
0005435242930	12201	57	14F
0005435242928	12201	58	15C
0005432783511	12201	59	15D
0005435242920	12201	60	15F
0005432783722	12201	61	16D
0005432783403	12201	62	16E
0005432783520	12201	63	16F
0005432783165	12201	64	17C
0005432783431	12201	65	17D
0005432783477	12201	66	17F
0005432783660	12201	67	18A
0005432783476	12201	68	18C
0005432783561	12201	69	18F
0005435242911	12201	70	19A
0005432783417	12201	71	19C
0005432783703	12201	72	19D
0005432783518	12201	73	19E
0005435242918	12201	74	19F
0005432783510	12201	75	20A
0005435242913	12201	76	20C
0005432783335	12201	77	20D
0005432783466	12201	78	20E
0005432783154	12201	79	20F
0005432783883	15426	1	1A
0005432783854	15426	2	1F
0005432783832	15426	3	2A
0005432783830	15426	4	2C
0005435242638	15426	5	2D
0005432783843	15426	6	2F
0005435242641	15426	7	3A
0005432783834	15426	8	3D
0005435242544	15426	9	3F
0005432783865	15426	10	4A
0005432783877	15426	11	4C
0005432783852	15426	12	4D
0005432783851	15426	13	4E
0005435242624	15426	14	5A
0005435242661	15426	15	5C
0005432783859	15426	16	5D
0005432783884	15426	17	5E
0005435242596	15426	18	5F
0005435242618	15426	19	6A
0005432783831	15426	20	6C
0005432783869	15426	21	6D
0005432783842	15426	22	6E
0005432783858	15426	23	6F
0005435242655	15426	24	7A
0005432783856	15426	25	7C
0005432783862	15426	26	7D
0005432783857	15426	27	7E
0005432783868	15426	28	7F
0005435242647	15426	29	8A
0005435242557	15426	30	8C
0005432783871	15426	31	8D
0005432783855	15426	32	8E
0005435242603	15426	33	8F
0005432783844	15426	34	9A
0005432783850	15426	35	9C
0005432783833	15426	36	9D
0005432783876	15426	37	9E
0005435242619	15426	38	9F
0005432783874	15426	39	10A
0005435242550	15426	40	10C
0005435242644	15426	41	10D
0005432783861	15426	42	10E
0005432783845	15426	43	10F
0005435242576	15426	44	11A
0005432783849	15426	45	11C
0005432783838	15426	46	12A
0005435242677	15426	47	12C
0005432783863	15426	48	12D
0005432783867	15426	49	12E
0005435242643	15426	50	12F
0005432783846	15426	51	13A
0005432783837	15426	52	13C
0005435242517	15426	53	13D
0005432783880	15426	54	13E
0005435242616	15426	55	14A
0005435242706	15426	56	14C
0005432783840	15426	57	14E
0005432783872	15426	58	15A
0005432783878	15426	59	15C
0005432783870	15426	60	15D
0005432783860	15426	61	15E
0005432783881	15426	62	16A
0005432783836	15426	63	16C
0005432783839	15426	64	16D
0005435242646	15426	65	16E
0005435242529	15426	66	17C
0005435242584	15426	67	17D
0005432783848	15426	68	17E
0005432783835	15426	69	17F
0005432783853	15426	70	18C
0005432783866	15426	71	18D
0005432783879	15426	72	18E
0005432783882	15426	73	19A
0005432783847	15426	74	19C
0005435242575	15426	75	19D
0005435242645	15426	76	19E
0005435242617	15426	77	19F
0005432783873	15426	78	20A
0005432783841	15426	79	20C
0005432783875	15426	80	20D
0005432783864	15426	81	20E
0005434877876	10077	1	1A
0005434877870	10077	2	1F
0005434877730	10077	3	1D
0005434877792	10077	4	2D
0005434877755	10077	5	2C
0005434877621	10077	6	3A
0005434877461	10077	7	3D
0005434877444	10077	8	3C
0005434877542	10077	9	3F
0005434877729	10077	10	4C
0005434758888	10077	11	4F
0005434877728	10077	12	4D
0005434877663	10077	13	5C
0005434877740	10077	14	5A
0005434877875	10077	15	5F
0005434877425	10077	16	5D
0005434877862	10077	17	6B
0005434877359	10077	18	6A
0005434877563	10077	19	6C
0005434877861	10077	20	6E
0005434877694	10077	21	6D
0005434877775	10077	22	7A
0005434877426	10077	23	6F
0005434877335	10077	24	7C
0005434877620	10077	25	7B
0005434877805	10077	26	7E
0005434877617	10077	27	7D
0005434877385	10077	28	8A
0005434877454	10077	29	7F
0005434877574	10077	30	8C
0005434877714	10077	31	8D
0005434877709	10077	32	8E
0005434877662	10077	33	9A
0005434877628	10077	34	9C
0005434877711	10077	35	9E
0005434877619	10077	36	10A
0005434877269	10077	37	10C
0005434877801	10077	38	10B
0005434910117	10077	39	10E
0005434877101	10077	40	10D
0005434877631	10077	41	11A
0005434877611	10077	42	10F
0005434877572	10077	43	11B
0005434877421	10077	44	11E
0005434877877	10077	45	12B
0005434910118	10077	46	12D
0005434877999	10077	47	12C
0005434877360	10077	48	13B
0005434877666	10077	49	13A
0005434877545	10077	50	12F
0005434877341	10077	51	13C
0005434877449	10077	52	13E
0005434877905	10077	53	13D
0005434877803	10077	54	14A
0005434877502	10077	55	13F
0005434877741	10077	56	14B
0005434877793	10077	57	14D
0005434877645	10077	58	14C
0005434877904	10077	59	14F
0005434877802	10077	60	14E
0005434877693	10077	61	15B
0005434877627	10077	62	15A
0005434877715	10077	63	15C
0005434877587	10077	64	15F
0005434877830	10077	65	15E
0005434877713	10077	66	15D
0005434877625	10077	67	16A
0005434877831	10077	68	16C
0005434877721	10077	69	16B
0005434877622	10077	70	16D
0005434910116	10077	71	16F
0005434877263	10077	72	16E
0005434877573	10077	73	17B
0005434877564	10077	74	17A
0005434877293	10077	75	17D
0005434877774	10077	76	17C
0005434877646	10077	77	17E
0005434877543	10077	78	18B
0005434877505	10077	79	18A
0005434877782	10077	80	17F
0005434877896	10077	81	18C
0005434877268	10077	82	18E
0005434877897	10077	83	18D
0005434877499	10077	84	19A
0005434877584	10077	85	18F
0005434878000	10077	86	19C
0005434877405	10077	87	19D
0005434877575	10077	88	20A
0005434877612	10077	89	19F
0005434877667	10077	90	20B
0005434877556	10077	91	20D
0005434910115	10077	92	20C
0005434877577	10077	93	20F
0005434877820	10077	94	20E
0005434877384	10077	95	21B
0005434877451	10077	96	21A
0005434877800	10077	97	21C
0005434877504	10077	98	21D
0005434877618	10077	99	21F
0005434878448	14632	1	1A
0005434878468	14632	2	1D
0005434878470	14632	3	1C
0005434878432	14632	4	2A
0005434878464	14632	5	1F
0005435913900	14632	6	2D
0005434878420	14632	7	2C
0005434878429	14632	8	3A
0005434878480	14632	9	2F
0005434910095	14632	10	3C
0005434878476	14632	11	4A
0005434878446	14632	12	3F
0005434878408	14632	13	3D
0005434878460	14632	14	4C
0005434878473	14632	15	4F
0005434878438	14632	16	4D
0005434878433	14632	17	5C
0005434878416	14632	18	5A
0005435913899	14632	19	5F
0005434878441	14632	20	5D
0005434878431	14632	21	6B
0005435913885	14632	22	6A
0005434878457	14632	23	6E
0005434878462	14632	24	6D
0005434878458	14632	25	7A
0005435913893	14632	26	6F
0005434878394	14632	27	7C
0005434878454	14632	28	7B
0005434878397	14632	29	7F
0005434878400	14632	30	8B
0005434878472	14632	31	8A
0005434878425	14632	32	8D
0005434878467	14632	33	8C
0005434878418	14632	34	8F
0005434878463	14632	35	8E
0005434878435	14632	36	9A
0005434878443	14632	37	9D
0005434878404	14632	38	9C
0005435913905	14632	39	9E
0005434878415	14632	40	9F
0005434878417	14632	41	10C
0005434878390	14632	42	10B
0005434878427	14632	43	10E
0005434878411	14632	44	10D
0005434878410	14632	45	11A
0005434878414	14632	46	10F
0005434878479	14632	47	11D
0005434878461	14632	48	11C
0005434878424	14632	49	11F
0005435913894	14632	50	11E
0005434878406	14632	51	12B
0005434878481	14632	52	12A
0005434878434	14632	53	12C
0005434878428	14632	54	12F
0005434878449	14632	55	12E
0005434878399	14632	56	12D
0005435913901	14632	57	13A
0005434878482	14632	58	13B
0005434878422	14632	59	13D
0005434878430	14632	60	13F
0005434758899	14632	61	14C
0005434878465	14632	62	14B
0005434878444	14632	63	14A
0005434878436	14632	64	14D
0005434878398	14632	65	14F
0005434878453	14632	66	14E
0005434878395	14632	67	15B
0005434878419	14632	68	15A
0005434878442	14632	69	15C
0005434878393	14632	70	15F
0005434878478	14632	71	15E
0005434878407	14632	72	15D
0005434878423	14632	73	16A
0005434878426	14632	74	16C
0005434878405	14632	75	16B
0005434878447	14632	76	16D
0005434878445	14632	77	16F
0005434878401	14632	78	16E
0005434878474	14632	79	17B
0005435913902	14632	80	17A
0005434878413	14632	81	17D
0005434878440	14632	82	17C
0005434878455	14632	83	17F
0005434878477	14632	84	17E
0005434878403	14632	85	18B
0005434878471	14632	86	18A
0005434878475	14632	87	18C
0005435913908	14632	88	18F
0005434878409	14632	89	18E
0005434878456	14632	90	18D
0005434878439	14632	91	19A
0005434878466	14632	92	19C
0005434878437	14632	93	19B
0005434878402	14632	94	19E
0005434878452	14632	95	19D
0005434878421	14632	96	20B
0005434878396	14632	97	20A
0005434878451	14632	98	20C
0005434878459	14632	99	21B
0005434878469	14632	100	21A
0005434878392	14632	101	20F
0005434878412	14632	102	21C
0005434878450	14632	103	21E
0005434878391	14632	104	21D
0005434910096	14632	105	21F
0005434251899	9266	1	1A
0005435660161	9266	2	1B
0005435660165	9266	3	1D
0005435660163	9266	4	3A
0005434251900	9266	5	3C
0005434251913	9266	6	4B
0005435660166	9266	7	4D
0005435660156	9266	8	5D
0005435660159	9266	9	6C
0005434251918	9266	10	6D
0005435660157	9266	11	7B
0005434251919	9266	12	7D
0005435660167	9266	13	18B
0005435660162	9266	14	19A
0005435660164	9266	15	19C
0005434251893	9266	16	20C
0005434251876	9266	17	21A
0005435660158	9266	18	21B
0005434251959	9266	19	22A
0005435660160	9266	20	22B
0005434251939	9266	21	22D
0005434251917	9266	22	23A
0005434251901	9266	23	23B
0005435660084	24679	1	2A
0005434251986	24679	2	2B
0005434251980	24679	3	3D
0005435660108	24679	4	4A
0005435660083	24679	5	4D
0005434251984	24679	6	6A
0005435660059	24679	7	6B
0005434251985	24679	8	7A
0005434251990	24679	9	18A
0005434251982	24679	10	18C
0005435660094	24679	11	19A
0005434251987	24679	12	19B
0005434251988	24679	13	20D
0005435660086	24679	14	21A
0005434251983	24679	15	21B
0005434251981	24679	16	22B
0005434251989	24679	17	23B
0005433680659	2802	1	1A
0005433680642	2802	2	1C
0005433680647	2802	3	1D
0005433680677	2802	4	2A
0005433680638	2802	5	2C
0005432966822	2802	6	2D
0005433684423	2802	7	2F
0005433680641	2802	8	3A
0005432222791	2802	9	3C
0005433680685	2802	10	3F
0005433680644	2802	11	4C
0005433680660	2802	12	4D
0005433680640	2802	13	4E
0005432222792	2802	14	4F
0005433680670	2802	15	5C
0005433680683	2802	16	5E
0005432966729	2802	17	5F
0005432222790	2802	18	6A
0005433680657	2802	19	6C
0005432966752	2802	20	6D
0005433684422	2802	21	6E
0005433680668	2802	22	6F
0005433680665	2802	23	7A
0005433680681	2802	24	7C
0005433680671	2802	25	7D
0005433680667	2802	26	8A
0005433680674	2802	27	8C
0005433680646	2802	28	8D
0005433680669	2802	29	8F
0005433680661	2802	30	9A
0005433680653	2802	31	9C
0005432966737	2802	32	9D
0005433680664	2802	33	9F
0005433680684	2802	34	10C
0005432966778	2802	35	10E
0005433680655	2802	36	10F
0005432966777	2802	37	11A
0005433680672	2802	38	11C
0005433680645	2802	39	11D
0005433680663	2802	40	11E
0005432966707	2802	41	11F
0005433680676	2802	42	12A
0005433680650	2802	43	12C
0005432966720	2802	44	12E
0005432966771	2802	45	12F
0005433680682	2802	46	13A
0005433680678	2802	47	13C
0005433680643	2802	48	13D
0005432966721	2802	49	13E
0005432966767	2802	50	13F
0005433680651	2802	51	14C
0005432966840	2802	52	14D
0005432222794	2802	53	14E
0005433680648	2802	54	15C
0005432966766	2802	55	15D
0005433680652	2802	56	15E
0005433680658	2802	57	15F
0005432966785	2802	58	16C
0005433680639	2802	59	16D
0005432222793	2802	60	16F
0005433680656	2802	61	17A
0005432222795	2802	62	17C
0005433680637	2802	63	17D
0005432966790	2802	64	17F
0005433680654	2802	65	18A
0005432966839	2802	66	18C
0005433680675	2802	67	18D
0005433680649	2802	68	18E
0005433680680	2802	69	19A
0005433680679	2802	70	19C
0005432966708	2802	71	19D
0005433680673	2802	72	19E
0005433680666	2802	73	20A
0005432966719	2802	74	19F
0005433680662	2802	75	20C
0005432966709	2802	76	20F
0005433680134	29187	1	1A
0005433680360	29187	2	1C
0005433680471	29187	3	1D
0005433680512	29187	4	1F
0005433680228	29187	5	2A
0005432966991	29187	6	2C
0005432966976	29187	7	2D
0005433680085	29187	8	2F
0005433687685	29187	9	3A
0005433680344	29187	10	3C
0005433680299	29187	11	3D
0005433680234	29187	12	3F
0005433680197	29187	13	4A
0005433680115	29187	14	4C
0005433680320	29187	15	4D
0005432966999	29187	16	4E
0005433680236	29187	17	4F
0005433680231	29187	18	5A
0005433680203	29187	19	5C
0005432966983	29187	20	5D
0005432966997	29187	21	5E
0005433684394	29187	22	5F
0005433680116	29187	23	6A
0005432966979	29187	24	6D
0005432966986	29187	25	6E
0005433680380	29187	26	6F
0005433684407	29187	27	7A
0005433684410	29187	28	7C
0005433680473	29187	29	7D
0005433680278	29187	30	7E
0005433680133	29187	31	7F
0005433690909	29187	32	8A
0005433680508	29187	33	8C
0005432966978	29187	34	8E
0005432966993	29187	35	8F
0005433690911	29187	36	9A
0005432966980	29187	37	9C
0005432966989	29187	38	9D
0005432966995	29187	39	9E
0005433680305	29187	40	10A
0005432967000	29187	41	10C
0005433680378	29187	42	10D
0005432005218	29187	43	10E
0005432966988	29187	44	10F
0005433680298	29187	45	11A
0005433680073	29187	46	11C
0005432966998	29187	47	11D
0005433680367	29187	48	11E
0005432966987	29187	49	12A
0005433680433	29187	50	12C
0005433687684	29187	51	12D
0005432005220	29187	52	12E
0005432966992	29187	53	12F
0005433680072	29187	54	13A
0005433680441	29187	55	13C
0005432966984	29187	56	13D
0005432966994	29187	57	13E
0005433680321	29187	58	13F
0005433680432	29187	59	14A
0005433680382	29187	60	14C
0005432966985	29187	61	14D
0005433680285	29187	62	14E
0005433687682	29187	63	15A
0005432966982	29187	64	15C
0005433690910	29187	65	15D
0005433687681	29187	66	15E
0005433680319	29187	67	16A
0005433680233	29187	68	16C
0005433680342	29187	69	16D
0005433680284	29187	70	16E
0005433680301	29187	71	16F
0005432966996	29187	72	17A
0005433684404	29187	73	17D
0005432966990	29187	74	17E
0005433680529	29187	75	17F
0005433680126	29187	76	18A
0005433680329	29187	77	18C
0005433680313	29187	78	18D
0005432967001	29187	79	18F
0005433680343	29187	80	19A
0005433680277	29187	81	19C
0005433680362	29187	82	19D
0005432966981	29187	83	19E
0005432966977	29187	84	19F
0005433680505	29187	85	20A
0005433679985	29187	86	20C
0005432005219	29187	87	20E
0005433680125	29187	88	20D
0005433684405	29187	89	20F
0005433633865	9278	1	1A
0005433633863	9278	2	1C
0005433633866	9278	3	1D
0005433614793	9278	4	1F
0005433614738	9278	5	2C
0005433614777	9278	6	2A
0005433614799	9278	7	2D
0005433614770	9278	8	3A
0005433614766	9278	9	3C
0005433614801	9278	10	3F
0005433614742	9278	11	3D
0005434163505	9278	12	4A
0005433614767	9278	13	4C
0005433614757	9278	14	5A
0005433614753	9278	15	4F
0005433614758	9278	16	5C
0005433614736	9278	17	5F
0005433633845	9278	18	6A
0005433614772	9278	19	6C
0005433633861	9278	20	6F
0005433614751	9278	21	6D
0005433633851	9278	22	7A
0005433614756	9278	23	7D
0005433614759	9278	24	8A
0005432755080	9278	25	7F
0005434163539	9278	26	8B
0005433614762	9278	27	8D
0005433614744	9278	28	8E
0005433577836	9278	29	8F
0005433633846	9278	30	9B
0005433614775	9278	31	9A
0005433577835	9278	32	9C
0005433577827	9278	33	9E
0005433614739	9278	34	9D
0005433633850	9278	35	10A
0005433633868	9278	36	10B
0005433614802	9278	37	10D
0005433633869	9278	38	10C
0005433633871	9278	39	10E
0005433614768	9278	40	10F
0005433614765	9278	41	11A
0005432755081	9278	42	11C
0005433614745	9278	43	11B
0005433614761	9278	44	11D
0005433614806	9278	45	11F
0005433614790	9278	46	11E
0005433614794	9278	47	12B
0005433633842	9278	48	12D
0005432756854	9278	49	12C
0005433614748	9278	50	12F
0005433577831	9278	51	13A
0005434152780	9278	52	13C
0005433633867	9278	53	13B
0005433633870	9278	54	13D
0005433614752	9278	55	13F
0005434269083	9278	56	13E
0005433614805	9278	57	14B
0005433614743	9278	58	14A
0005432756855	9278	59	14D
0005433614747	9278	60	14C
0005433614787	9278	61	14E
0005433633873	9278	62	14F
0005433633854	9278	63	15B
0005433633876	9278	64	15A
0005433614764	9278	65	15C
0005433614780	9278	66	15D
0005433614776	9278	67	15F
0005433614798	9278	68	15E
0005433614735	9278	69	16A
0005434163532	9278	70	16D
0005433614771	9278	71	16C
0005433614800	9278	72	16E
0005433633858	9278	73	16F
0005433633844	9278	74	17B
0005433614760	9278	75	17C
0005433614769	9278	76	17D
0005433614773	9278	77	17F
0005433614734	9278	78	17E
0005433577838	9278	79	18A
0005434269084	9278	80	18C
0005433614763	9278	81	18B
0005433614749	9278	82	18D
0005433614782	9278	83	18E
0005433633862	9278	84	18F
0005433614781	9278	85	19C
0005433614774	9278	86	19D
0005433614783	9278	87	20B
0005433577829	9278	88	20A
0005433614778	9278	89	20C
0005432756853	9278	90	20E
0005433633847	9278	91	20D
0005433577834	9278	92	20F
0005433633859	9278	93	21C
0005433614746	9278	94	21B
0005433614754	9278	95	21D
0005433614795	9278	96	21E
0005433633857	9278	97	21F
0005433633875	9278	98	22B
0005433633852	9278	99	22E
0005433614808	9278	100	22F
0005433633864	9278	101	23C
0005434163518	9278	102	23D
0005433614786	9278	103	23E
0005432755084	9278	104	24A
0005433614797	9278	105	23F
0005433614807	9278	106	24C
0005434163540	9278	107	24D
0005433577825	9278	108	24F
0005433577828	9278	109	25A
0005433614755	9278	110	25C
0005433633848	9278	111	25B
0005432756856	9278	112	25D
0005433577826	9278	113	25E
0005433633841	9278	114	25F
0005433633853	9278	115	26C
0005433614804	9278	116	26B
0005433614803	9278	117	26D
0005433614789	9278	118	26F
0005433614779	9278	119	26E
0005433633874	9278	120	27A
0005433614792	9278	121	27C
0005433633843	9278	122	27B
0005432145114	9278	123	27F
0005433577832	9278	124	27E
0005432145115	9278	125	28A
0005433577830	9278	126	28B
0005432755082	9278	127	28C
0005433614740	9278	128	28E
0005434163504	9278	129	28D
0005433614750	9278	130	28F
0005433614737	9278	131	29A
0005433614784	9278	132	29C
0005433633856	9278	133	29B
0005433614741	9278	134	29D
0005433633855	9278	135	29E
0005433633860	9278	136	30A
0005432755083	9278	137	29F
0005433614791	9278	138	30B
0005433633849	9278	139	30D
0005433614785	9278	140	30C
0005433577837	9278	141	30E
0005433633872	9278	142	30F
0005434163553	9278	143	31A
0005433577833	9278	144	31D
0005433614796	9278	145	31C
0005433614788	9278	146	31F
0005434163636	25259	1	1A
0005433614111	25259	2	1C
0005433614015	25259	3	1D
0005434163627	25259	4	1F
0005433577720	25259	5	2C
0005433614336	25259	6	2A
0005434163634	25259	7	2D
0005433614353	25259	8	2F
0005433614205	25259	9	3C
0005433614118	25259	10	3D
0005433633604	25259	11	4A
0005434163635	25259	12	3F
0005433633488	25259	13	4C
0005434163626	25259	14	4F
0005433614231	25259	15	4D
0005433577703	25259	16	5A
0005433614186	25259	17	5C
0005433614158	25259	18	6A
0005433613771	25259	19	5F
0005433633508	25259	20	6C
0005433633566	25259	21	6F
0005433614277	25259	22	6D
0005433577717	25259	23	7A
0005433633382	25259	24	7D
0005433614169	25259	25	7C
0005433614062	25259	26	7F
0005433614082	25259	27	8A
0005433613857	25259	28	8B
0005433633557	25259	29	8D
0005433633454	25259	30	8C
0005433614081	25259	31	8E
0005433633669	25259	32	8F
0005433614202	25259	33	9A
0005433633563	25259	34	9C
0005433577670	25259	35	9B
0005433614590	25259	36	9D
0005433633489	25259	37	9F
0005433614060	25259	38	10B
0005433614315	25259	39	10D
0005434272194	25259	40	10C
0005433633607	25259	41	10E
0005433633583	25259	42	10F
0005433613956	25259	43	11B
0005433613858	25259	44	11A
0005433613916	25259	45	11C
0005433633495	25259	46	11D
0005433614083	25259	47	11F
0005433633562	25259	48	12A
0005433614136	25259	49	12B
0005433614308	25259	50	12D
0005433614435	25259	51	12F
0005433614167	25259	52	13B
0005433614441	25259	53	13A
0005433614246	25259	54	13C
0005433614090	25259	55	13E
0005433633506	25259	56	13D
0005433614299	25259	57	14A
0005433614278	25259	58	14B
0005433614168	25259	59	14D
0005433633571	25259	60	14C
0005433614055	25259	61	14E
0005433614281	25259	62	15B
0005433614140	25259	63	15A
0005433577719	25259	64	15C
0005433614041	25259	65	15D
0005433633524	25259	66	16A
0005433614314	25259	67	16B
0005434163631	25259	68	16E
0005433577718	25259	69	16F
0005433633564	25259	70	17B
0005433577791	25259	71	17A
0005433577702	25259	72	17C
0005433614096	25259	73	17E
0005433614148	25259	74	17D
0005433614354	25259	75	17F
0005433614178	25259	76	18A
0005433614309	25259	77	18B
0005433614095	25259	78	18C
0005434272193	25259	79	18E
0005433614243	25259	80	18D
0005433614105	25259	81	18F
0005433613943	25259	82	19C
0005433577669	25259	83	19B
0005433577714	25259	84	19E
0005433633625	25259	85	20B
0005433633565	25259	86	20A
0005433614269	25259	87	20C
0005434163637	25259	88	20D
0005433577715	25259	89	20F
0005433633499	25259	90	20E
0005433614104	25259	91	21D
0005433613976	25259	92	21E
0005434163633	25259	93	21F
0005433614337	25259	94	22B
0005434163630	25259	95	22A
0005433614075	25259	96	22D
0005433633438	25259	97	22C
0005434163629	25259	98	22F
0005433614244	25259	99	22E
0005433613907	25259	100	23A
0005433614247	25259	101	23C
0005433614248	25259	102	23B
0005433614080	25259	103	23D
0005433614185	25259	104	23E
0005433633555	25259	105	24B
0005433614442	25259	106	24A
0005433614355	25259	107	24C
0005434273079	25259	108	24E
0005433633453	25259	109	24F
0005433614137	25259	110	25A
0005433613873	25259	111	25B
0005433633630	25259	112	25D
0005433614135	25259	113	25C
0005433614106	25259	114	25F
0005433633429	25259	115	25E
0005434163632	25259	116	26A
0005433613897	25259	117	26B
0005433633487	25259	118	26D
0005433614184	25259	119	26E
0005433614264	25259	120	27A
0005433613959	25259	121	27C
0005433614280	25259	122	27D
0005433633626	25259	123	28A
0005433614406	25259	124	27F
0005433633627	25259	125	28B
0005433614132	25259	126	28D
0005433614065	25259	127	28C
0005433614214	25259	128	28E
0005433633507	25259	129	28F
0005433577684	25259	130	29C
0005433614028	25259	131	29B
0005433633523	25259	132	29D
0005433577704	25259	133	30A
0005433614232	25259	134	29F
0005433614061	25259	135	30B
0005433613863	25259	136	30D
0005433614226	25259	137	30C
0005433577746	25259	138	30E
0005433633648	25259	139	30F
0005434163628	25259	140	31A
0005434273078	25259	141	31C
0005433614312	25259	142	31D
0005434271296	4229	1	1A
0005435856191	4229	2	2F
0005435986781	4229	3	3A
0005434271295	4229	4	3C
0005435856172	4229	5	3H
0005435986783	4229	6	11B
0005435947187	4229	7	12B
0005435947164	4229	8	12E
0005435986793	4229	9	12D
0005435947149	4229	10	13A
0005435986785	4229	11	13D
0005435986792	4229	12	13E
0005435947153	4229	13	13G
0005435947148	4229	14	14G
0005435947166	4229	15	15E
0005432184957	4229	16	15H
0005432571294	4229	17	16A
0005435787346	4229	18	17A
0005435947128	4229	19	17G
0005435856178	4229	20	18B
0005435947130	4229	21	20F
0005435986791	4229	22	20H
0005435986789	4229	23	21G
0005432184956	4229	24	23A
0005435854045	4229	25	23E
0005435854048	4229	26	23G
0005435856171	4229	27	24D
0005435947119	4229	28	27B
0005435856186	4229	29	27G
0005435986782	4229	30	28H
0005432571300	4229	31	28G
0005435856177	4229	32	29D
0005435986784	4229	33	29B
0005435947186	4229	34	29E
0005434271301	4229	35	30F
0005435986787	4229	36	31D
0005435947129	4229	37	31G
0005435986786	4229	38	31H
0005435856179	4229	39	33B
0005435787328	4229	40	33E
0005432571284	4229	41	34A
0005435947185	4229	42	35D
0005435947167	4229	43	35E
0005435986790	4229	44	36E
0005435986788	4229	45	36G
0005435854046	4229	46	37F
0005435947131	4229	47	38A
0005432571296	4229	48	37H
0005435947165	4229	49	38B
0005435856180	4229	50	38G
0005432571332	26610	1	1G
0005435947294	26610	2	2H
0005435947285	26610	3	3G
0005435947289	26610	4	3F
0005435947292	26610	5	3H
0005435947287	26610	6	5G
0005435947286	26610	7	11H
0005435856215	26610	8	13D
0005435986698	26610	9	14E
0005435986688	26610	10	18B
0005435947291	26610	11	18F
0005435947290	26610	12	20H
0005435986689	26610	13	21D
0005432571331	26610	14	22B
0005435856214	26610	15	22H
0005435986704	26610	16	23A
0005435856213	26610	17	24A
0005435947280	26610	18	24E
0005435947282	26610	19	24H
0005435787360	26610	20	27E
0005435947283	26610	21	28A
0005435986706	26610	22	28F
0005435947284	26610	23	30E
0005435986697	26610	24	31F
0005435947288	26610	25	32E
0005435947281	26610	26	35A
0005432571333	26610	27	35H
0005435947293	26610	28	38F
0005433569235	339	1	1C
0005433569229	339	2	1A
0005433569196	339	3	1F
0005432948196	339	4	1D
0005433569221	339	5	2A
0005432948091	339	6	2C
0005433569208	339	7	2D
0005433569237	339	8	3A
0005433569238	339	9	2F
0005433569212	339	10	3C
0005433569189	339	11	3D
0005433569182	339	12	4A
0005433569217	339	13	4D
0005433074408	339	14	4C
0005433569184	339	15	4F
0005432238950	339	16	5A
0005432948149	339	17	5C
0005433569220	339	18	5F
0005432948190	339	19	5D
0005432948049	339	20	6A
0005432948156	339	21	6C
0005433074480	339	22	6F
0005433569226	339	23	7A
0005433074369	339	24	7F
0005433134104	339	25	7D
0005433074573	339	26	8A
0005432948191	339	27	8B
0005433134105	339	28	8D
0005433074515	339	29	8C
0005433569195	339	30	8E
0005432238947	339	31	8F
0005433569185	339	32	9B
0005433074518	339	33	9A
0005433569198	339	34	9C
0005433569199	339	35	9D
0005433569188	339	36	9F
0005433074535	339	37	9E
0005432948261	339	38	10A
0005432948243	339	39	10C
0005433074534	339	40	10B
0005433569241	339	41	10D
0005432238951	339	42	10E
0005433569201	339	43	10F
0005433074366	339	44	11B
0005433134095	339	45	11A
0005433074474	339	46	11C
0005433074472	339	47	11E
0005432948211	339	48	11D
0005433569215	339	49	12A
0005432948222	339	50	11F
0005433134112	339	51	12B
0005432948071	339	52	12E
0005432948158	339	53	12D
0005432948300	339	54	12F
0005433569187	339	55	13B
0005432948270	339	56	13A
0005432948092	339	57	13C
0005432238952	339	58	13D
0005433074543	339	59	13F
0005432948178	339	60	14A
0005433569200	339	61	14C
0005433569211	339	62	14B
0005433569230	339	63	14D
0005433569216	339	64	14E
0005432948159	339	65	15B
0005432948253	339	66	15A
0005433074522	339	67	15C
0005432948318	339	68	15E
0005433569231	339	69	16A
0005432948244	339	70	16C
0005433569219	339	71	16B
0005433569222	339	72	16D
0005433074512	339	73	16E
0005433134109	339	74	17B
0005432948235	339	75	17A
0005433569191	339	76	17C
0005432948129	339	77	17D
0005432948279	339	78	17E
0005433074602	339	79	17F
0005433569209	339	80	18D
0005433569236	339	81	18E
0005433134110	339	82	19D
0005433569190	339	83	19E
0005433569232	339	84	20B
0005433074542	339	85	20A
0005432948080	339	86	20C
0005433074544	339	87	20D
0005433129255	339	88	21A
0005433569205	339	89	20F
0005432948093	339	90	21C
0005433074482	339	91	21B
0005432948238	339	92	21D
0005433074475	339	93	21E
0005433074516	339	94	22B
0005432948076	339	95	22C
0005432948352	339	96	22F
0005433074453	339	97	22E
0005432947936	339	98	23B
0005433569240	339	99	23A
0005433074536	339	100	23C
0005433569183	339	101	23F
0005432238949	339	102	23E
0005433569214	339	103	24B
0005433074517	339	104	24A
0005433569223	339	105	24D
0005433569233	339	106	24C
0005433074465	339	107	24F
0005433569194	339	108	24E
0005433569234	339	109	25A
0005433569193	339	110	25C
0005433569228	339	111	25E
0005433129261	339	112	25D
0005433569218	339	113	26A
0005432948118	339	114	25F
0005432948079	339	115	26B
0005433569207	339	116	26D
0005433569206	339	117	26E
0005433569204	339	118	27B
0005433074411	339	119	27A
0005433134096	339	120	27C
0005433569197	339	121	27D
0005432948230	339	122	27F
0005433074427	339	123	28B
0005432947937	339	124	28D
0005433074541	339	125	28C
0005433569203	339	126	28F
0005433569227	339	127	28E
0005433569210	339	128	29B
0005433569225	339	129	29A
0005433569239	339	130	29D
0005433074510	339	131	29C
0005432948117	339	132	29E
0005432948090	339	133	30A
0005432238946	339	134	29F
0005432238948	339	135	30B
0005433569213	339	136	30D
0005433074401	339	137	30C
0005433569202	339	138	30E
0005433074572	339	139	30F
0005433569186	339	140	31A
0005433074481	339	141	31C
0005433569192	339	142	31D
0005433569224	339	143	31F
0005432948147	339	144	31E
0005433134145	11593	1	1C
0005433568555	11593	2	1A
0005432948515	11593	3	2A
0005433568654	11593	4	1F
0005432948540	11593	5	2C
0005433074756	11593	6	2D
0005433074755	11593	7	3A
0005432948545	11593	8	2F
0005433074765	11593	9	3C
0005433568553	11593	10	4A
0005432948553	11593	11	4D
0005433131715	11593	12	4C
0005432948519	11593	13	4F
0005433074771	11593	14	5A
0005433568590	11593	15	5D
0005433074758	11593	16	5C
0005432948533	11593	17	5F
0005432948555	11593	18	6A
0005433074761	11593	19	6D
0005432948550	11593	20	6C
0005433568489	11593	21	7A
0005433074780	11593	22	6F
0005433074762	11593	23	7D
0005433568577	11593	24	8A
0005433568203	11593	25	7F
0005433134147	11593	26	8B
0005432948547	11593	27	8C
0005433568576	11593	28	9A
0005433568675	11593	29	8F
0005433568586	11593	30	9B
0005433074770	11593	31	9C
0005432948538	11593	32	9D
0005433568552	11593	33	9E
0005433568178	11593	34	10A
0005433131717	11593	35	9F
0005433568381	11593	36	10B
0005433074753	11593	37	10C
0005432948537	11593	38	11A
0005432948516	11593	39	11C
0005433568380	11593	40	11B
0005432948529	11593	41	11E
0005432948536	11593	42	11D
0005433568486	11593	43	11F
0005433134150	11593	44	12A
0005433568442	11593	45	12B
0005432948543	11593	46	12C
0005432948531	11593	47	12E
0005432948548	11593	48	12D
0005433074772	11593	49	13A
0005432948534	11593	50	12F
0005433568589	11593	51	13B
0005432948535	11593	52	13C
0005433131716	11593	53	13D
0005433074777	11593	54	13F
0005432948526	11593	55	13E
0005432948517	11593	56	14A
0005433568396	11593	57	14D
0005432948522	11593	58	14C
0005433568522	11593	59	14E
0005433568564	11593	60	14F
0005433568563	11593	61	15A
0005433568642	11593	62	15C
0005433568528	11593	63	15B
0005433074769	11593	64	15E
0005432192325	11593	65	15F
0005433568606	11593	66	16A
0005433568587	11593	67	16C
0005432948525	11593	68	16B
0005433568549	11593	69	16E
0005433568523	11593	70	16F
0005433568406	11593	71	17B
0005432948539	11593	72	17A
0005433568548	11593	73	17C
0005433568403	11593	74	17E
0005433568407	11593	75	17F
0005433568479	11593	76	18D
0005432192328	11593	77	18C
0005433568475	11593	78	18E
0005433568443	11593	79	19B
0005433568192	11593	80	18F
0005433074776	11593	81	19C
0005432948549	11593	82	19D
0005433568535	11593	83	19E
0005433568225	11593	84	20B
0005433074760	11593	85	20C
0005433074774	11593	86	20E
0005433568585	11593	87	20D
0005433074757	11593	88	21A
0005432948527	11593	89	21C
0005433568395	11593	90	21B
0005432948554	11593	91	21D
0005433568373	11593	92	21E
0005432948521	11593	93	22A
0005433568423	11593	94	21F
0005433568419	11593	95	22B
0005433568372	11593	96	22C
0005433568562	11593	97	22E
0005432948541	11593	98	22D
0005433568487	11593	99	22F
0005433568404	11593	100	23A
0005432192326	11593	101	23C
0005433568588	11593	102	23B
0005432948542	11593	103	23D
0005432948523	11593	104	23E
0005433131718	11593	105	23F
0005433074752	11593	106	24B
0005433568516	11593	107	24A
0005432948528	11593	108	24C
0005433074767	11593	109	24E
0005432948530	11593	110	24D
0005432192327	11593	111	25A
0005433568651	11593	112	25C
0005433074773	11593	113	25B
0005432948551	11593	114	25D
0005432948514	11593	115	25E
0005433568226	11593	116	25F
0005433568652	11593	117	26C
0005432948552	11593	118	26A
0005433568538	11593	119	26D
0005432948518	11593	120	26F
0005433568400	11593	121	26E
0005433568334	11593	122	27A
0005433134149	11593	123	27B
0005433568193	11593	124	27D
0005433568575	11593	125	27F
0005432948544	11593	126	27E
0005433134146	11593	127	28B
0005433074779	11593	128	28C
0005433074781	11593	129	28E
0005433568394	11593	130	28D
0005433568529	11593	131	28F
0005432948524	11593	132	29B
0005433074766	11593	133	29A
0005433074775	11593	134	29D
0005433074768	11593	135	29E
0005433568449	11593	136	30A
0005432948520	11593	137	29F
0005433568561	11593	138	30B
0005433074764	11593	139	30C
0005433134148	11593	140	30E
0005433131719	11593	141	30D
0005433568450	11593	142	30F
0005433074763	11593	143	31B
0005432948546	11593	144	31A
0005432948532	11593	145	31C
0005433074754	11593	146	31E
0005433074759	11593	147	31D
0005433074778	11593	148	31F
0005433817480	10048	1	1A
0005433817479	10048	2	1B
0005433817478	10048	3	4B
0005434732953	10048	4	5B
0005434732974	10048	5	6A
0005434732968	10048	6	6B
0005434732988	13910	1	1A
0005433817436	13910	2	2A
0005433817444	13910	3	1B
0005434732989	13910	4	2B
0005434732987	13910	5	3B
0005433817445	13910	6	4A
0005434732986	13910	7	5A
0005433817449	13910	8	4B
0005433817455	13910	9	5B
0005433817458	13910	10	6A
0005433817437	13910	11	6B
0005432655566	2336	1	1A
0005435982400	2336	2	1C
0005432984842	2336	3	1B
0005435982414	2336	4	1F
0005433754344	2336	5	1G
0005432300276	2336	6	1H
0005433754316	2336	7	2B
0005433754367	2336	8	2F
0005433754365	2336	9	2C
0005432655560	2336	10	2G
0005433754362	2336	11	3A
0005433434622	2336	12	2H
0005435982407	2336	13	3B
0005435982435	2336	14	3F
0005435982412	2336	15	3C
0005432984740	2336	16	3G
0005432226068	2336	17	4A
0005433754323	2336	18	3H
0005432869488	2336	19	4F
0005433754333	2336	20	4C
0005432985053	2336	21	4G
0005435982408	2336	22	4H
0005435982431	2336	23	5B
0005432985054	2336	24	5A
0005435982423	2336	25	5C
0005432869470	2336	26	5G
0005433434462	2336	27	5H
0005433434434	2336	28	9B
0005433754337	2336	29	9A
0005433434536	2336	30	9G
0005435982417	2336	31	11A
0005435982405	2336	32	9H
0005432226067	2336	33	11B
0005433754332	2336	34	11D
0005435982442	2336	35	11F
0005433754329	2336	36	11H
0005432655561	2336	37	11G
0005433754315	2336	38	12A
0005435982418	2336	39	12D
0005433434541	2336	40	12B
0005433754347	2336	41	12G
0005433754324	2336	42	12F
0005433754319	2336	43	12H
0005433434446	2336	44	13B
0005433434395	2336	45	13A
0005433754363	2336	46	13D
0005435982422	2336	47	13E
0005433754366	2336	48	13G
0005433754356	2336	49	13F
0005432984799	2336	50	13H
0005435982401	2336	51	14B
0005435982441	2336	52	14A
0005433754358	2336	53	14D
0005435982429	2336	54	14F
0005432226071	2336	55	14E
0005433754352	2336	56	15B
0005433754341	2336	57	15D
0005432869482	2336	58	15F
0005435982438	2336	59	15E
0005433754351	2336	60	15G
0005435982439	2336	61	16B
0005435982437	2336	62	16A
0005435982395	2336	63	16D
0005435982433	2336	64	16E
0005433434424	2336	65	16F
0005433434459	2336	66	16H
0005433434553	2336	67	16G
0005434731146	2336	68	17B
0005433754343	2336	69	17A
0005433754328	2336	70	17D
0005432984825	2336	71	17F
0005435982427	2336	72	17E
0005433754336	2336	73	18A
0005432984878	2336	74	17H
0005432984960	2336	75	17G
0005432984889	2336	76	18B
0005433754369	2336	77	18D
0005432985010	2336	78	18F
0005432985011	2336	79	18E
0005432300274	2336	80	18G
0005433434513	2336	81	19A
0005432869486	2336	82	18H
0005433754354	2336	83	19D
0005435982434	2336	84	19B
0005433434417	2336	85	19F
0005435982416	2336	86	19E
0005433434677	2336	87	19G
0005433754318	2336	88	19H
0005432655559	2336	89	20D
0005433434461	2336	90	20B
0005433754342	2336	91	20E
0005433434394	2336	92	20G
0005434731139	2336	93	20F
0005433754325	2336	94	20H
0005433434530	2336	95	21B
0005435982426	2336	96	21A
0005435982404	2336	97	21D
0005432984709	2336	98	21E
0005435982415	2336	99	21F
0005432655570	2336	100	21H
0005433764684	2336	101	21G
0005433434519	2336	102	22B
0005432655562	2336	103	22D
0005433754360	2336	104	22F
0005433754317	2336	105	22E
0005435982430	2336	106	23A
0005432655568	2336	107	22H
0005433754321	2336	108	22G
0005433754346	2336	109	23D
0005433754326	2336	110	23F
0005432655565	2336	111	23E
0005432984866	2336	112	23G
0005433754338	2336	113	24A
0005433754331	2336	114	23H
0005432984888	2336	115	24B
0005432300273	2336	116	24D
0005433434445	2336	117	24F
0005433754371	2336	118	24E
0005432869475	2336	119	24G
0005433766647	2336	120	25D
0005433754349	2336	121	24H
0005433434529	2336	122	25E
0005432226070	2336	123	25F
0005435982394	2336	124	27B
0005435982403	2336	125	27A
0005435982411	2336	126	27D
0005432984708	2336	127	27F
0005433754345	2336	128	27E
0005433754350	2336	129	27H
0005432300278	2336	130	27G
0005432300277	2336	131	28A
0005432984945	2336	132	28B
0005432655563	2336	133	28G
0005435982432	2336	134	28F
0005432655564	2336	135	28E
0005432655569	2336	136	28H
0005433434460	2336	137	29B
0005433754335	2336	138	29A
0005433434506	2336	139	29D
0005432984800	2336	140	29E
0005435982410	2336	141	29F
0005433766649	2336	142	29H
0005433754370	2336	143	29G
0005432869484	2336	144	30B
0005433754348	2336	145	30A
0005435982398	2336	146	30D
0005433766648	2336	147	30E
0005433754353	2336	148	30G
0005432984821	2336	149	30H
0005435982421	2336	150	31B
0005432984822	2336	151	31A
0005432226069	2336	152	31E
0005433754330	2336	153	31D
0005432226072	2336	154	31F
0005432984877	2336	155	32A
0005435982393	2336	156	31H
0005435982397	2336	157	32D
0005435982419	2336	158	32G
0005432984795	2336	159	32F
0005432300275	2336	160	32E
0005433764683	2336	161	32H
0005432984835	2336	162	33A
0005435982420	2336	163	33B
0005435982396	2336	164	33E
0005434731131	2336	165	33G
0005433434433	2336	166	34A
0005432984871	2336	167	34D
0005433754340	2336	168	34B
0005435982406	2336	169	34E
0005433754357	2336	170	34G
0005433754339	2336	171	34F
0005433434537	2336	172	34H
0005432984849	2336	173	35B
0005435982425	2336	174	35A
0005433434623	2336	175	35D
0005432984646	2336	176	35F
0005432869493	2336	177	35E
0005432869469	2336	178	35H
0005435982399	2336	179	35G
0005435982440	2336	180	36A
0005435982409	2336	181	36B
0005432655567	2336	182	36E
0005433754359	2336	183	36D
0005433754368	2336	184	36F
0005435982402	2336	185	36H
0005432984848	2336	186	36G
0005435982436	2336	187	37D
0005435982413	2336	188	37B
0005432655558	2336	189	37A
0005432984867	2336	190	37E
0005433754322	2336	191	37G
0005433434444	2336	192	37F
0005433754361	2336	193	37H
0005433754355	2336	194	38A
0005435982424	2336	195	38D
0005433754334	2336	196	38B
0005432869485	2336	197	38E
0005433754320	2336	198	38F
0005433754364	2336	199	38H
0005432226073	2336	200	38G
0005435982428	2336	201	39D
0005433434533	2336	202	39F
0005433754327	2336	203	39E
0005432869540	26208	1	1A
0005433753835	26208	2	1B
0005433434741	26208	3	1F
0005433753758	26208	4	1C
0005435981821	26208	5	1G
0005433753754	26208	6	2A
0005433434736	26208	7	2B
0005433754058	26208	8	2F
0005433434752	26208	9	2C
0005435981941	26208	10	2H
0005432985141	26208	11	2G
0005435981957	26208	12	3A
0005434731179	26208	13	3C
0005433766613	26208	14	3B
0005433753942	26208	15	3F
0005432655400	26208	16	3G
0005433753844	26208	17	3H
0005433753897	26208	18	4B
0005433754034	26208	19	4A
0005432869533	26208	20	4F
0005432985149	26208	21	4C
0005433753836	26208	22	4G
0005433753908	26208	23	5A
0005433753743	26208	24	4H
0005432985153	26208	25	5B
0005433754116	26208	26	5C
0005433753823	26208	27	5F
0005432985150	26208	28	5H
0005432985147	26208	29	5G
0005435981816	26208	30	9B
0005435981773	26208	31	9A
0005433434730	26208	32	9G
0005435981926	26208	33	11A
0005433753829	26208	34	9H
0005435981909	26208	35	11D
0005435981996	26208	36	11B
0005432655444	26208	37	11E
0005434731181	26208	38	11F
0005435981997	26208	39	11G
0005432985133	26208	40	12A
0005433434745	26208	41	12E
0005435981907	26208	42	12D
0005435981948	26208	43	12H
0005435981938	26208	44	12G
0005434731182	26208	45	13B
0005432655459	26208	46	13D
0005433434734	26208	47	13F
0005435981958	26208	48	13E
0005432985139	26208	49	13G
0005433434732	26208	50	14A
0005433753868	26208	51	13H
0005433753744	26208	52	14D
0005435981942	26208	53	14F
0005433754020	26208	54	14E
0005435981943	26208	55	14G
0005435982039	26208	56	15A
0005435981886	26208	57	14H
0005432985137	26208	58	15B
0005432051133	26208	59	15D
0005432985159	26208	60	15F
0005433753932	26208	61	15E
0005433753645	26208	62	15H
0005433753939	26208	63	16A
0005432985151	26208	64	16D
0005432655416	26208	65	16B
0005433753911	26208	66	16E
0005432049473	26208	67	16G
0005433753859	26208	68	16F
0005435981951	26208	69	16H
0005435981912	26208	70	17A
0005435982040	26208	71	17D
0005432985140	26208	72	17B
0005435981993	26208	73	17E
0005433434740	26208	74	17G
0005435982115	26208	75	17F
0005435982029	26208	76	17H
0005433753826	26208	77	18A
0005433753940	26208	78	18D
0005433753901	26208	79	18E
0005435982030	26208	80	18G
0005433434755	26208	81	18F
0005432049472	26208	82	19A
0005433753961	26208	83	18H
0005433753843	26208	84	19B
0005432051135	26208	85	19D
0005435981827	26208	86	19E
0005432985134	26208	87	19H
0005433434742	26208	88	19G
0005433434750	26208	89	20A
0005435982172	26208	90	20B
0005433434754	26208	91	20E
0005435981893	26208	92	20F
0005433434749	26208	93	20G
0005432985163	26208	94	21A
0005432985164	26208	95	20H
0005432985158	26208	96	21D
0005435981888	26208	97	21B
0005432985146	26208	98	21E
0005435982012	26208	99	21G
0005433753845	26208	100	21F
0005433753841	26208	101	22A
0005435981991	26208	102	21H
0005435981947	26208	103	22B
0005433434727	26208	104	22D
0005433434731	26208	105	22F
0005435982010	26208	106	22E
0005433434743	26208	107	22G
0005433753853	26208	108	22H
0005433753637	26208	109	23B
0005433766623	26208	110	23D
0005433753978	26208	111	23E
0005432869534	26208	112	23G
0005433434744	26208	113	23F
0005435981887	26208	114	24A
0005433753861	26208	115	23H
0005432985154	26208	116	24D
0005435981959	26208	117	24B
0005432985135	26208	118	24E
0005433434733	26208	119	24F
0005432049471	26208	120	24H
0005433753673	26208	121	25E
0005433753818	26208	122	25F
0005433753828	26208	123	27D
0005433434737	26208	124	27B
0005432985161	26208	125	27A
0005432985160	26208	126	27E
0005433753858	26208	127	27F
0005432869536	26208	128	27G
0005435981858	26208	129	27H
0005432985144	26208	130	28D
0005433434739	26208	131	28B
0005432985156	26208	132	28G
0005435982114	26208	133	28F
0005433434735	26208	134	29A
0005432655454	26208	135	28H
0005433753904	26208	136	29B
0005432869535	26208	137	29F
0005432051134	26208	138	29D
0005433753924	26208	139	29H
0005433753824	26208	140	29G
0005433753903	26208	141	30B
0005433754032	26208	142	30A
0005435981939	26208	143	30D
0005432869537	26208	144	30F
0005435982078	26208	145	30E
0005433766609	26208	146	30G
0005432051136	26208	147	30H
0005433434729	26208	148	31B
0005435981820	26208	149	31A
0005432655415	26208	150	31D
0005433434753	26208	151	31F
0005432869538	26208	152	31G
0005433753881	26208	153	31H
0005435982011	26208	154	32B
0005432985157	26208	155	32A
0005435981812	26208	156	32E
0005433434738	26208	157	32D
0005432869539	26208	158	32F
0005433434751	26208	159	32H
0005433434747	26208	160	32G
0005432985136	26208	161	33A
0005432985162	26208	162	33D
0005432985143	26208	163	33B
0005433434728	26208	164	33E
0005435981967	26208	165	33F
0005433753943	26208	166	33H
0005433754033	26208	167	34D
0005435981966	26208	168	34G
0005435981983	26208	169	34F
0005433753880	26208	170	34H
0005432985145	26208	171	35A
0005435981968	26208	172	35E
0005432985155	26208	173	35D
0005433753632	26208	174	35B
0005433434746	26208	175	35F
0005433764662	26208	176	35G
0005432655401	26208	177	36A
0005435981837	26208	178	35H
0005433753931	26208	179	36B
0005432655456	26208	180	36E
0005432985138	26208	181	36D
0005435982007	26208	182	36H
0005432985142	26208	183	36G
0005435981976	26208	184	36F
0005433753755	26208	185	37B
0005434731183	26208	186	37E
0005433766611	26208	187	37D
0005433753722	26208	188	37F
0005433764664	26208	189	37H
0005433434748	26208	190	37G
0005435982038	26208	191	38D
0005434731180	26208	192	38B
0005435981819	26208	193	38E
0005435982050	26208	194	38G
0005432985132	26208	195	38F
0005432985152	26208	196	38H
0005432985148	26208	197	39D
0005434374724	1498	1	1C
0005434374737	1498	2	1D
0005433151255	1498	3	2A
0005434374722	1498	4	2C
0005434374732	1498	5	2D
0005434374754	1498	6	2F
0005433151086	1498	7	3A
0005433151107	1498	8	3D
0005433151231	1498	9	3F
0005433931434	1498	10	4B
0005433151227	1498	11	4D
0005434374734	1498	12	5A
0005434374738	1498	13	5D
0005432267910	1498	14	6A
0005433460440	1498	15	6D
0005434374740	1498	16	6C
0005433764667	1498	17	6E
0005434374714	1498	18	6F
0005434374733	1498	19	7B
0005434374748	1498	20	7A
0005434374720	1498	21	7D
0005432267907	1498	22	7F
0005433931435	1498	23	8B
0005433151085	1498	24	8C
0005433461593	1498	25	8F
0005434374751	1498	26	9B
0005434374717	1498	27	9E
0005432267909	1498	28	9F
0005432267911	1498	29	10B
0005434374726	1498	30	10E
0005433151215	1498	31	11A
0005434374739	1498	32	11C
0005434374736	1498	33	11F
0005434374755	1498	34	12A
0005434374728	1498	35	12C
0005433151309	1498	36	12B
0005433151094	1498	37	12D
0005432267913	1498	38	12E
0005434374711	1498	39	13A
0005434374745	1498	40	13C
0005434374725	1498	41	13D
0005433460442	1498	42	13E
0005434374743	1498	43	13F
0005433151256	1498	44	14A
0005434374712	1498	45	14C
0005434374721	1498	46	14B
0005434374730	1498	47	14E
0005434374744	1498	48	14F
0005434374758	1498	49	15B
0005434374735	1498	50	15A
0005433151225	1498	51	15C
0005433151267	1498	52	15F
0005433151253	1498	53	16A
0005434374747	1498	54	16C
0005434374752	1498	55	16E
0005434374741	1498	56	16D
0005433151209	1498	57	17A
0005434374742	1498	58	16F
0005434374710	1498	59	17C
0005433764668	1498	60	17D
0005434374753	1498	61	17F
0005434374731	1498	62	17E
0005434374719	1498	63	18B
0005434374757	1498	64	18A
0005433151208	1498	65	18C
0005434374716	1498	66	18D
0005434029649	1498	67	18F
0005433151254	1498	68	19A
0005434374727	1498	69	19D
0005432267912	1498	70	19C
0005433151166	1498	71	19E
0005433931439	1498	72	20A
0005434374756	1498	73	20B
0005433151293	1498	74	20D
0005434374729	1498	75	20C
0005434374750	1498	76	20E
0005434374713	1498	77	20F
0005434374718	1498	78	21B
0005434374715	1498	79	21A
0005434374749	1498	80	21D
0005433460441	1498	81	21E
0005434374723	1498	82	21F
0005433151266	1498	83	22C
0005433151367	1498	84	22E
0005432267908	1498	85	22D
0005433931430	1498	86	22F
0005433151268	1498	87	23D
0005433151216	1498	88	23C
0005434374746	1498	89	23F
0005434374386	20126	1	1A
0005433151496	20126	2	1C
0005433151477	20126	3	2A
0005433764684	20126	4	1F
0005433151462	20126	5	2D
0005433463875	20126	6	2C
0005433931472	20126	7	3C
0005434374373	20126	8	3D
0005433151475	20126	9	3F
0005434374187	20126	10	4A
0005433151479	20126	11	4C
0005434374155	20126	12	4D
0005433461561	20126	13	4E
0005433931473	20126	14	4F
0005434374342	20126	15	5B
0005434374387	20126	16	5C
0005434374303	20126	17	5D
0005433151463	20126	18	5E
0005432056305	20126	19	5F
0005434374280	20126	20	6B
0005434374278	20126	21	6A
0005434374217	20126	22	6C
0005434374348	20126	23	6D
0005433151476	20126	24	6E
0005434374372	20126	25	7A
0005434374188	20126	26	6F
0005433461551	20126	27	7B
0005433151461	20126	28	7C
0005434374391	20126	29	7D
0005434374343	20126	30	7F
0005434374290	20126	31	8B
0005433461553	20126	32	8A
0005433461556	20126	33	8C
0005433151466	20126	34	8D
0005433461580	20126	35	8E
0005433461550	20126	36	9A
0005433151492	20126	37	9B
0005432056309	20126	38	9C
0005433463870	20126	39	9E
0005433463864	20126	40	9D
0005432056306	20126	41	9F
0005433151490	20126	42	10B
0005433151472	20126	43	10E
0005434374170	20126	44	10D
0005433151468	20126	45	11D
0005434374333	20126	46	11E
0005432056307	20126	47	11F
0005433151470	20126	48	12B
0005434374171	20126	49	12A
0005433463868	20126	50	12C
0005434374311	20126	51	12E
0005433461558	20126	52	12F
0005433151464	20126	53	13A
0005433151493	20126	54	13B
0005433151482	20126	55	13D
0005433151474	20126	56	13E
0005433151480	20126	57	13F
0005433764683	20126	58	14A
0005433151467	20126	59	14C
0005434374380	20126	60	14B
0005433151478	20126	61	14D
0005433463878	20126	62	15A
0005434029661	20126	63	15C
0005434374104	20126	64	15E
0005433461562	20126	65	15D
0005434374097	20126	66	15F
0005433151495	20126	67	16A
0005433151473	20126	68	16C
0005433151487	20126	69	16D
0005433151483	20126	70	16F
0005433461560	20126	71	17B
0005433463877	20126	72	17C
0005433151485	20126	73	17E
0005433151486	20126	74	17D
0005433463876	20126	75	17F
0005433151488	20126	76	18B
0005434374359	20126	77	18C
0005433461557	20126	78	18E
0005433463865	20126	79	18D
0005433151491	20126	80	19B
0005433151494	20126	81	19D
0005433461554	20126	82	19C
0005434029662	20126	83	19E
0005433931474	20126	84	19F
0005433463871	20126	85	20A
0005433151481	20126	86	20B
0005432056308	20126	87	20D
0005433463873	20126	88	20C
0005433151469	20126	89	20E
0005433463874	20126	90	21A
0005434374225	20126	91	21B
0005434374330	20126	92	21C
0005433151484	20126	93	21D
0005433461552	20126	94	21E
0005433151465	20126	95	21F
0005433151489	20126	96	22B
0005434374416	20126	97	22A
0005433151471	20126	98	22C
0005433461559	20126	99	22D
0005434374218	20126	100	22E
0005433463869	20126	101	23A
0005434374358	20126	102	23B
0005434374392	20126	103	23D
0005433463866	20126	104	23F
0005432424545	592	1	2A
0005432424532	592	2	1F
0005432424535	592	3	2C
0005432424544	592	4	3A
0005432424547	592	5	3F
0005432424549	592	6	6D
0005432424554	592	7	7A
0005432282881	592	8	7D
0005432424520	592	9	8B
0005432424553	592	10	9A
0005432424542	592	11	9C
0005432424524	592	12	9F
0005432424555	592	13	10C
0005432424552	592	14	10B
0005432424538	592	15	11C
0005432282882	592	16	12A
0005432424570	592	17	12C
0005432424551	592	18	13F
0005432424530	592	19	14A
0005432424526	592	20	14B
0005432424564	592	21	14C
0005432424533	592	22	14D
0005432424527	592	23	14F
0005432424561	592	24	15A
0005432424540	592	25	15C
0005432424569	592	26	15D
0005432282877	592	27	15F
0005432424568	592	28	15E
0005432424528	592	29	17A
0005432424536	592	30	16F
0005432424548	592	31	17D
0005432424534	592	32	20A
0005432424546	592	33	19E
0005432424565	592	34	20B
0005432424560	592	35	20F
0005432424558	592	36	21C
0005432424521	592	37	21F
0005432424563	592	38	22B
0005432424529	592	39	22A
0005432424537	592	40	23A
0005432424559	592	41	23D
0005432424525	592	42	23F
0005432424531	592	43	23E
0005432282878	592	44	24D
0005432424557	592	45	24F
0005432424522	592	46	25C
0005432424543	592	47	25D
0005432424541	592	48	26A
0005432424556	592	49	26C
0005432424562	592	50	27E
0005432424550	592	51	28C
0005432282879	592	52	29A
0005432282880	592	53	30B
0005432424539	592	54	30A
0005432424523	592	55	30C
0005432424566	592	56	31A
0005432424567	592	57	31E
0005432302337	12854	1	15B
0005432302339	12854	2	17E
0005432302338	12854	3	21F
0005432302340	12854	4	29B
0005432423971	12849	1	1F
0005432424052	12849	2	2A
0005432424146	12849	3	5C
0005432424069	12849	4	6D
0005432424074	12849	5	8C
0005432424073	12849	6	8B
0005432424016	12849	7	8D
0005432424157	12849	8	8E
0005432424061	12849	9	8F
0005432424119	12849	10	10A
0005432424075	12849	11	10B
0005432424120	12849	12	10D
0005432424156	12849	13	11A
0005432424015	12849	14	11E
0005432424122	12849	15	12C
0005432424076	12849	16	13D
0005432423916	12849	17	13F
0005432424133	12849	18	13E
0005432424149	12849	19	14A
0005432424081	12849	20	14D
0005432423917	12849	21	14E
0005432424161	12849	22	15A
0005432424097	12849	23	16E
0005432423918	12849	24	17A
0005432423970	12849	25	18A
0005432423922	12849	26	18B
0005432423972	12849	27	20F
0005432424029	12849	28	21D
0005432424077	12849	29	21E
0005432424068	12849	30	22A
0005432424063	12849	31	22E
0005432424080	12849	32	23A
0005432423959	12849	33	23F
0005432423973	12849	34	24C
0005432424084	12849	35	24E
0005432424072	12849	36	24D
0005432424143	12849	37	26A
0005432424102	12849	38	25F
0005432424018	12849	39	27B
0005432424105	12849	40	27F
0005432424017	12849	41	28B
0005432424051	12849	42	28F
0005432424134	12849	43	30C
0005432424062	12849	44	30B
0005434032030	473	1	1A
0005434735619	473	2	1B
0005434023862	473	3	2B
0005434023884	473	4	2F
0005434023820	473	5	2H
0005434023882	473	6	2G
0005432045616	473	7	3A
0005434028300	473	8	3B
0005433057558	473	9	3C
0005433057608	473	10	3H
0005434032029	473	11	4B
0005434735639	473	12	4A
0005432235657	473	13	4G
0005434023854	473	14	4H
0005433929586	473	15	5B
0005434023872	473	16	5A
0005433057736	473	17	5G
0005433057679	473	18	5H
0005434023840	473	19	9B
0005434023852	473	20	9G
0005433057671	473	21	11A
0005433057691	473	22	11B
0005434023863	473	23	11E
0005433057678	473	24	11D
0005434023883	473	25	11F
0005432235656	473	26	12D
0005434023868	473	27	12E
0005433057600	473	28	12H
0005433057626	473	29	12G
0005433057737	473	30	13B
0005433057700	473	31	13E
0005433057635	473	32	13F
0005433057725	473	33	13H
0005434023843	473	34	13G
0005434023851	473	35	14B
0005434023861	473	36	14E
0005434023850	473	37	14D
0005433057640	473	38	14H
0005434032031	473	39	14G
0005434735646	473	40	14F
0005434023828	473	41	15B
0005434023860	473	42	15A
0005434023887	473	43	15F
0005434023871	473	44	15G
0005433929581	473	45	16A
0005433684401	473	46	15H
0005434023864	473	47	16G
0005433057766	473	48	16H
0005434023866	473	49	17A
0005433057669	473	50	17F
0005434029659	473	51	17G
0005434028301	473	52	18A
0005434023824	473	53	17H
0005433684396	473	54	18F
0005434023819	473	55	18E
0005433057581	473	56	19B
0005433057560	473	57	19D
0005433057684	473	58	19F
0005433057688	473	59	19G
0005434023880	473	60	20A
0005432235653	473	61	20D
0005434023830	473	62	20E
0005434023856	473	63	20G
0005434023842	473	64	20H
0005434023886	473	65	21B
0005434023831	473	66	21A
0005434023881	473	67	21D
0005434023877	473	68	21E
0005433684402	473	69	21G
0005433057694	473	70	21F
0005433057703	473	71	21H
0005434023876	473	72	22B
0005434032028	473	73	22A
0005434029660	473	74	22D
0005433929587	473	75	22E
0005434023869	473	76	22G
0005434023867	473	77	22F
0005433057582	473	78	22H
0005434023885	473	79	23A
0005433929606	473	80	23D
0005434023834	473	81	23B
0005434023821	473	82	23E
0005434023838	473	83	23G
0005433057623	473	84	23F
0005434023849	473	85	24A
0005434023857	473	86	24B
0005434023855	473	87	24E
0005434023853	473	88	24D
0005433057639	473	89	24F
0005434023841	473	90	24G
0005433057767	473	91	25D
0005434023825	473	92	24H
0005433057690	473	93	27A
0005433057779	473	94	25F
0005433929607	473	95	27D
0005433057720	473	96	27F
0005434023878	473	97	27E
0005434028299	473	98	27G
0005433929585	473	99	27H
0005434023865	473	100	28D
0005434023875	473	101	28B
0005433057738	473	102	28E
0005433057764	473	103	28F
0005434023818	473	104	28G
0005434023837	473	105	29D
0005432045615	473	106	29B
0005434023879	473	107	29F
0005434023844	473	108	29H
0005434023848	473	109	30A
0005434023836	473	110	30F
0005433057683	473	111	30G
0005432235654	473	112	31A
0005434023859	473	113	31E
0005432235652	473	114	31D
0005434023833	473	115	31H
0005433057726	473	116	31G
0005433929570	473	117	32G
0005434023823	473	118	32E
0005433057609	473	119	33A
0005434023847	473	120	32H
0005434735640	473	121	33D
0005434023870	473	122	33B
0005434023829	473	123	33E
0005433057689	473	124	33G
0005433057670	473	125	33H
0005433684395	473	126	34A
0005434023874	473	127	34D
0005433057477	473	128	35B
0005434023826	473	129	35D
0005434023839	473	130	35E
0005434032032	473	131	36A
0005434023822	473	132	35H
0005434023873	473	133	36B
0005434023827	473	134	36D
0005433057516	473	135	36E
0005434023832	473	136	36H
0005433057682	473	137	37B
0005433057559	473	138	37E
0005433057476	473	139	37F
0005434028298	473	140	37H
0005434023835	473	141	38A
0005434735645	473	142	38B
0005433684399	473	143	38D
0005432235655	473	144	38H
0005434023845	473	145	38G
0005434023846	473	146	39D
0005434023858	473	147	39F
0005434735618	473	148	39E
0005434735703	12668	1	1A
0005434023096	12668	2	1F
0005433057984	12668	3	1C
0005433057954	12668	4	1G
0005434023207	12668	5	2A
0005434023411	12668	6	1H
0005433057975	12668	7	2B
0005434031960	12668	8	2C
0005432157495	12668	9	2G
0005433057990	12668	10	3A
0005434023074	12668	11	3B
0005434023073	12668	12	3F
0005434023206	12668	13	3G
0005434023274	12668	14	4A
0005434023097	12668	15	3H
0005433057955	12668	16	4B
0005434031988	12668	17	4F
0005433057970	12668	18	4C
0005434031989	12668	19	4G
0005434023358	12668	20	5A
0005434032003	12668	21	4H
0005433057988	12668	22	5B
0005433057974	12668	23	5C
0005434023438	12668	24	5G
0005433057957	12668	25	5F
0005434023128	12668	26	9A
0005434032002	12668	27	5H
0005434031997	12668	28	9B
0005433057971	12668	29	11F
0005433057973	12668	30	11E
0005432156374	12668	31	11G
0005433057981	12668	32	12A
0005434023368	12668	33	11H
0005434023402	12668	34	12E
0005433929623	12668	35	12F
0005433057949	12668	36	12G
0005433057965	12668	37	13A
0005434023602	12668	38	13D
0005434023435	12668	39	13B
0005433057956	12668	40	14A
0005434735701	12668	41	13H
0005433057989	12668	42	14D
0005433057977	12668	43	14B
0005434028280	12668	44	14E
0005434023369	12668	45	14G
0005433057969	12668	46	15A
0005434028281	12668	47	14H
0005434028265	12668	48	15E
0005434023238	12668	49	15G
0005433057951	12668	50	16A
0005434022900	12668	51	16F
0005434032008	12668	52	16G
0005434023327	12668	53	17B
0005434735700	12668	54	17D
0005433057950	12668	55	17E
0005434023450	12668	56	17F
0005434023119	12668	57	17H
0005434023465	12668	58	18E
0005432157496	12668	59	18G
0005434023040	12668	60	18F
0005434023448	12668	61	19A
0005434023060	12668	62	18H
0005434023423	12668	63	19B
0005434023328	12668	64	19D
0005433057961	12668	65	19G
0005434023451	12668	66	19F
0005433057986	12668	67	19H
0005434023436	12668	68	20A
0005434028277	12668	69	20D
0005434032005	12668	70	20F
0005434023265	12668	71	20H
0005433057959	12668	72	21A
0005434023586	12668	73	21E
0005434023205	12668	74	21G
0005434023388	12668	75	22D
0005433057964	12668	76	22B
0005434023166	12668	77	22G
0005434023562	12668	78	23B
0005433057958	12668	79	23A
0005434023035	12668	80	23D
0005433057962	12668	81	23F
0005434032009	12668	82	23E
0005434032006	12668	83	23G
0005433057967	12668	84	23H
0005434023071	12668	85	24E
0005434028264	12668	86	24G
0005434023319	12668	87	24H
0005434031984	12668	88	25D
0005434023039	12668	89	27E
0005434023536	12668	90	27D
0005434023254	12668	91	27F
0005434023437	12668	92	27H
0005433057968	12668	93	27G
0005433057980	12668	94	28D
0005434023150	12668	95	28B
0005434023381	12668	96	28F
0005434023439	12668	97	28H
0005433057987	12668	98	28G
0005434023144	12668	99	29A
0005434023476	12668	100	29E
0005433057979	12668	101	29D
0005433684426	12668	102	29F
0005434029649	12668	103	30A
0005434022989	12668	104	30B
0005434023601	12668	105	30F
0005434735699	12668	106	30H
0005433057972	12668	107	31B
0005433057966	12668	108	31F
0005434023288	12668	109	31E
0005433057952	12668	110	31G
0005433057976	12668	111	32A
0005433929620	12668	112	31H
0005434023038	12668	113	32B
0005434735702	12668	114	32D
0005434031996	12668	115	32F
0005433057978	12668	116	32H
0005433929621	12668	117	33B
0005433057953	12668	118	33G
0005434023118	12668	119	34D
0005432156375	12668	120	34H
0005434023686	12668	121	35B
0005434023320	12668	122	35A
0005432156376	12668	123	35F
0005434023336	12668	124	35E
0005434023173	12668	125	35G
0005434023136	12668	126	35H
0005434023162	12668	127	36E
0005433929622	12668	128	36F
0005434023464	12668	129	36G
0005434023154	12668	130	37A
0005434023253	12668	131	36H
0005434023393	12668	132	37B
0005433057985	12668	133	37E
0005433057982	12668	134	37D
0005433057991	12668	135	37F
0005432156373	12668	136	37H
0005433684425	12668	137	37G
0005434023324	12668	138	38A
0005434023271	12668	139	38D
0005433057983	12668	140	38B
0005434023051	12668	141	38E
0005434023187	12668	142	38F
0005433684424	12668	143	39D
0005434023003	12668	144	38H
0005433057963	12668	145	38G
0005433057960	12668	146	39F
0005433923453	2160	1	1B
0005433923536	2160	2	1F
0005434028264	2160	3	1C
0005433923525	2160	4	2A
0005433923469	2160	5	1H
0005433923452	2160	6	2B
0005433875382	2160	7	2F
0005433923531	2160	8	2G
0005433929622	2160	9	3A
0005433923514	2160	10	3C
0005433923455	2160	11	3B
0005433923461	2160	12	3F
0005433035948	2160	13	3H
0005433035995	2160	14	4A
0005433923521	2160	15	4B
0005433923545	2160	16	4C
0005433036028	2160	17	4G
0005433036015	2160	18	4F
0005433923547	2160	19	5B
0005433923483	2160	20	5A
0005433923480	2160	21	5F
0005433923524	2160	22	5C
0005433923522	2160	23	5G
0005433036018	2160	24	5H
0005433923495	2160	25	9A
0005433923470	2160	26	9B
0005433923489	2160	27	9H
0005433923456	2160	28	11B
0005432231586	2160	29	11E
0005433923530	2160	30	12A
0005432231589	2160	31	12B
0005433035897	2160	32	12D
0005432231587	2160	33	12F
0005433923468	2160	34	12H
0005433923507	2160	35	12G
0005433035932	2160	36	13A
0005433929620	2160	37	13D
0005432044531	2160	38	13E
0005433035849	2160	39	13G
0005434028277	2160	40	13F
0005433035804	2160	41	13H
0005433036077	2160	42	14E
0005433036069	2160	43	14G
0005432231582	2160	44	15A
0005433923546	2160	45	14H
0005433923490	2160	46	15B
0005433923532	2160	47	15F
0005432231584	2160	48	15E
0005433036082	2160	49	15G
0005433923542	2160	50	16B
0005433923510	2160	51	16E
0005433923494	2160	52	16F
0005433923504	2160	53	16H
0005433923502	2160	54	17B
0005433035918	2160	55	17A
0005433923476	2160	56	17E
0005432231588	2160	57	17G
0005432749768	2160	58	17F
0005433923535	2160	59	18A
0005433923485	2160	60	17H
0005433923537	2160	61	18D
0005434028280	2160	62	18G
0005433923491	2160	63	19B
0005433036101	2160	64	19A
0005433875381	2160	65	19E
0005433923519	2160	66	19H
0005433929858	2160	67	19G
0005433923466	2160	68	20A
0005433923527	2160	69	20B
0005433923529	2160	70	20D
0005433923528	2160	71	20F
0005433923500	2160	72	20H
0005433923549	2160	73	20G
0005432231590	2160	74	21A
0005433931474	2160	75	21B
0005433923487	2160	76	21E
0005433923503	2160	77	21G
0005433923523	2160	78	21F
0005433923533	2160	79	21H
0005433035703	2160	80	22B
0005433923458	2160	81	22A
0005433035803	2160	82	22D
0005433923493	2160	83	22E
0005433036108	2160	84	22G
0005433923520	2160	85	22F
0005433923548	2160	86	22H
0005433035885	2160	87	23B
0005433923541	2160	88	23A
0005433923534	2160	89	23D
0005433923508	2160	90	23F
0005434028281	2160	91	23E
0005433035876	2160	92	23G
0005433035745	2160	93	24A
0005433036109	2160	94	23H
0005433923486	2160	95	24B
0005433923467	2160	96	24D
0005433923499	2160	97	24F
0005433923465	2160	98	24E
0005433923478	2160	99	24H
0005434028265	2160	100	24G
0005433035807	2160	101	25E
0005433923473	2160	102	27A
0005433923492	2160	103	27B
0005433035960	2160	104	27E
0005433035990	2160	105	27G
0005432749769	2160	106	28A
0005433923475	2160	107	27H
0005433923477	2160	108	28B
0005433929621	2160	109	28D
0005433923479	2160	110	28F
0005433929623	2160	111	28E
0005433923515	2160	112	28H
0005433923496	2160	113	28G
0005433923472	2160	114	29B
0005432231583	2160	115	29A
0005433923509	2160	116	29D
0005433923511	2160	117	29E
0005433923551	2160	118	29G
0005433923550	2160	119	29F
0005432044529	2160	120	29H
0005433035850	2160	121	30A
0005433923512	2160	122	30D
0005432231585	2160	123	30B
0005433875380	2160	124	30E
0005433035912	2160	125	30G
0005433035886	2160	126	30F
0005433923513	2160	127	30H
0005433035859	2160	128	31B
0005433923484	2160	129	31A
0005433923501	2160	130	31D
0005433035946	2160	131	31F
0005433923459	2160	132	31G
0005433923488	2160	133	32A
0005433923517	2160	134	31H
0005433036060	2160	135	32F
0005433923481	2160	136	32E
0005433923526	2160	137	33A
0005433923497	2160	138	33B
0005433036150	2160	139	33E
0005433923454	2160	140	33D
0005433923482	2160	141	33F
0005433036094	2160	142	33H
0005433923460	2160	143	34A
0005433035961	2160	144	34D
0005433923543	2160	145	34F
0005433036032	2160	146	34E
0005433035926	2160	147	34G
0005433923540	2160	148	35A
0005433931473	2160	149	34H
0005433035911	2160	150	35D
0005433923506	2160	151	35F
0005433923471	2160	152	35E
0005433035917	2160	153	35G
0005432231592	2160	154	35H
0005433923505	2160	155	36B
0005433923544	2160	156	36E
0005432044530	2160	157	36D
0005433923539	2160	158	36G
0005433035860	2160	159	36F
0005433923516	2160	160	37A
0005433923498	2160	161	36H
0005433923463	2160	162	37B
0005433923474	2160	163	37E
0005433035898	2160	164	37D
0005433036076	2160	165	37F
0005433923457	2160	166	37H
0005433036133	2160	167	37G
0005432231591	2160	168	38D
0005433923518	2160	169	38B
0005433923538	2160	170	38E
0005433931472	2160	171	38H
0005433036151	2160	172	39E
0005433923464	2160	173	39D
0005433923462	2160	174	39F
0005433922208	24126	1	1A
0005433922494	24126	2	1C
0005432207668	24126	3	1B
0005433036422	24126	4	1F
0005433036418	24126	5	1H
0005433922510	24126	6	1G
0005433922787	24126	7	2A
0005433036397	24126	8	2C
0005434028305	24126	9	2G
0005433922596	24126	10	2F
0005433922513	24126	11	3A
0005433922419	24126	12	2H
0005433931447	24126	13	3B
0005433922400	24126	14	3C
0005433922703	24126	15	3G
0005433036385	24126	16	3F
0005433922442	24126	17	3H
0005433036425	24126	18	4B
0005433922856	24126	19	4C
0005433922509	24126	20	4H
0005433036420	24126	21	4G
0005433922131	24126	22	4F
0005433875370	24126	23	5B
0005433922471	24126	24	5A
0005432206210	24126	25	5C
0005433036412	24126	26	5F
0005432749790	24126	27	9B
0005433922281	24126	28	11A
0005433922178	24126	29	9H
0005433922926	24126	30	11D
0005433922677	24126	31	11B
0005433036413	24126	32	11E
0005433922589	24126	33	11F
0005434028304	24126	34	11H
0005432206207	24126	35	11G
0005433922838	24126	36	12B
0005433922469	24126	37	12A
0005433922691	24126	38	12E
0005433036384	24126	39	12D
0005433036400	24126	40	12F
0005434028302	24126	41	12G
0005433036386	24126	42	13A
0005433922337	24126	43	13D
0005433922493	24126	44	13E
0005433036435	24126	45	13G
0005433036396	24126	46	13H
0005433922640	24126	47	14A
0005433922186	24126	48	14D
0005433922990	24126	49	14F
0005433922686	24126	50	14E
0005433922825	24126	51	14H
0005433922406	24126	52	14G
0005433929582	24126	53	15A
0005433922683	24126	54	15B
0005433922854	24126	55	15D
0005433036431	24126	56	15H
0005433036401	24126	57	15G
0005433036399	24126	58	16D
0005433922698	24126	59	16B
0005433922921	24126	60	16E
0005433922525	24126	61	16G
0005433922697	24126	62	16F
0005433929583	24126	63	17A
0005433929571	24126	64	17D
0005433922995	24126	65	17E
0005433036388	24126	66	17G
0005433922534	24126	67	17F
0005433036433	24126	68	18B
0005433922521	24126	69	18E
0005433036394	24126	70	18D
0005432749791	24126	71	18G
0005433922920	24126	72	18F
0005432207666	24126	73	18H
0005433036411	24126	74	19A
0005433036410	24126	75	19E
0005433922540	24126	76	19D
0005433922989	24126	77	19F
0005433036434	24126	78	19H
0005433929584	24126	79	20B
0005433922624	24126	80	20A
0005432206206	24126	81	20D
0005433036407	24126	82	20F
0005433036415	24126	83	20H
0005433922774	24126	84	21B
0005433036395	24126	85	21A
0005433036436	24126	86	21H
0005433036398	24126	87	21G
0005433922728	24126	88	22A
0005432206205	24126	89	22B
0005433931446	24126	90	22E
0005433036402	24126	91	22F
0005433922729	24126	92	23B
0005434028303	24126	93	23D
0005432206209	24126	94	23E
0005433036382	24126	95	23G
0005433922674	24126	96	24A
0005433036427	24126	97	23H
0005433036416	24126	98	24B
0005433931445	24126	99	24E
0005433922326	24126	100	24D
0005433929580	24126	101	24F
0005433923128	24126	102	25E
0005433922930	24126	103	25D
0005433922179	24126	104	27A
0005433922564	24126	105	25F
0005433922775	24126	106	27B
0005433922660	24126	107	27E
0005433036387	24126	108	27D
0005433922689	24126	109	27H
0005433036419	24126	110	27G
0005433922754	24126	111	28A
0005433036393	24126	112	28D
0005433923090	24126	113	28B
0005433922325	24126	114	28E
0005433922699	24126	115	28G
0005433922594	24126	116	29B
0005433036409	24126	117	29A
0005433922663	24126	118	28H
0005433036383	24126	119	29E
0005433922485	24126	120	29D
0005433922588	24126	121	29G
0005433922508	24126	122	29F
0005433922719	24126	123	29H
0005433929589	24126	124	30B
0005433036421	24126	125	30D
0005433922597	24126	126	30F
0005433036432	24126	127	30E
0005433036429	24126	128	31A
0005433922855	24126	129	30H
0005433931448	24126	130	31B
0005433922467	24126	131	31E
0005433036403	24126	132	31D
0005432207667	24126	133	31F
0005433931449	24126	134	31G
0005433922685	24126	135	31H
0005433922440	24126	136	32B
0005433036389	24126	137	32E
0005433922449	24126	138	32D
0005433036430	24126	139	32G
0005433923038	24126	140	32H
0005433922563	24126	141	33A
0005433923048	24126	142	33D
0005433929572	24126	143	33B
0005433922954	24126	144	33E
0005433036392	24126	145	33F
0005433922684	24126	146	33H
0005433036423	24126	147	34A
0005433036417	24126	148	34D
0005433922682	24126	149	34E
0005433922535	24126	150	34G
0005433922662	24126	151	34H
0005433036405	24126	152	35A
0005433036426	24126	153	35B
0005433922776	24126	154	35F
0005433922478	24126	155	35E
0005433922831	24126	156	35G
0005433922931	24126	157	36A
0005432206208	24126	158	35H
0005433036390	24126	159	36B
0005433922576	24126	160	36F
0005434028306	24126	161	36E
0005433922821	24126	162	37A
0005433036406	24126	163	36H
0005433875367	24126	164	37D
0005433922526	24126	165	37B
0005432749789	24126	166	37E
0005433036424	24126	167	37F
0005433922514	24126	168	37H
0005433036404	24126	169	38A
0005433922753	24126	170	38D
0005433036408	24126	171	38B
0005433922441	24126	172	38E
0005433923089	24126	173	38G
0005433036414	24126	174	38F
0005433036428	24126	175	38H
0005433036391	24126	176	39D
0005433922675	24126	177	39F
0005433922837	24126	178	39E
0005433233718	286	1	1A
0005434725781	286	2	1G
0005434725682	286	3	1D
0005433234112	286	4	2A
0005434551380	286	5	1K
0005434725778	286	6	1H
0005434551346	286	7	2D
0005434551364	286	8	2C
0005434725721	286	9	2H
0005434725679	286	10	2K
0005434725738	286	11	3G
0005434725736	286	12	3D
0005434725706	286	13	3C
0005434551377	286	14	3H
0005433233739	286	15	4A
0005433233817	286	16	3K
0005433233806	286	17	4G
0005433180970	286	18	4D
0005433180996	286	19	4C
0005434551339	286	20	4K
0005432277840	286	21	4H
0005434725743	286	22	5C
0005433233731	286	23	5A
0005434551329	286	24	5H
0005433289797	286	25	5G
0005433113526	286	26	11A
0005434725712	286	27	11D
0005432277830	286	28	11G
0005434551369	286	29	11F
0005434725763	286	30	11E
0005433233828	286	31	11H
0005434551360	286	32	12C
0005433233933	286	33	12A
0005434725752	286	34	12E
0005433233716	286	35	12D
0005434725681	286	36	12H
0005434725739	286	37	12G
0005432277833	286	38	12F
0005434735694	286	39	13D
0005434551356	286	40	13C
0005434551326	286	41	13A
0005434031965	286	42	13F
0005434725692	286	43	13E
0005434725666	286	44	13G
0005434031966	286	45	14A
0005432277831	286	46	13K
0005434725703	286	47	14E
0005434551357	286	48	14D
0005434725768	286	49	14C
0005434551365	286	50	14G
0005433131677	286	51	14F
0005434551340	286	52	14K
0005433233894	286	53	14H
0005433233805	286	54	15C
0005434725718	286	55	15A
0005433233646	286	56	15E
0005433233732	286	57	15D
0005434725711	286	58	15G
0005434551343	286	59	15F
0005434725729	286	60	15K
0005432277834	286	61	15H
0005432277841	286	62	16D
0005434725774	286	63	16C
0005433233823	286	64	16G
0005433233728	286	65	16F
0005434725766	286	66	16E
0005434551376	286	67	16H
0005433233580	286	68	17A
0005433180891	286	69	16K
0005434725674	286	70	17E
0005434725705	286	71	17D
0005434551349	286	72	17G
0005434551334	286	73	17F
0005434302467	286	74	17H
0005435142605	286	75	18B
0005434551368	286	76	18E
0005433233942	286	77	18D
0005434725764	286	78	18C
0005433233554	286	79	18G
0005434551351	286	80	18F
0005433180927	286	81	18J
0005433180938	286	82	19A
0005434731178	286	83	18K
0005434725741	286	84	19D
0005434551338	286	85	19C
0005434725668	286	86	19B
0005433233733	286	87	19F
0005434725737	286	88	19E
0005434735698	286	89	19H
0005435142608	286	90	19G
0005434725762	286	91	19K
0005434725695	286	92	20C
0005434551337	286	93	20E
0005434725748	286	94	20D
0005433233635	286	95	20G
0005434725680	286	96	20F
0005433233822	286	97	20J
0005433233768	286	98	21B
0005434725758	286	99	21A
0005434551345	286	100	21D
0005434551366	286	101	21C
0005433180972	286	102	21G
0005434725701	286	103	21F
0005433233553	286	104	21E
0005433233668	286	105	21J
0005434551353	286	106	21H
0005434725740	286	107	22A
0005434725696	286	108	21K
0005434551371	286	109	22D
0005433233697	286	110	22C
0005435142610	286	111	22E
0005433233802	286	112	22H
0005434725767	286	113	22G
0005434725731	286	114	22F
0005433233824	286	115	22K
0005434725691	286	116	22J
0005433113518	286	117	23B
0005433233582	286	118	23A
0005434725756	286	119	23D
0005434551358	286	120	23C
0005434725726	286	121	23G
0005433233533	286	122	23E
0005434551332	286	123	23H
0005433289779	286	124	24D
0005433180995	286	125	23K
0005434551354	286	126	23J
0005433233517	286	127	24F
0005434551347	286	128	24E
0005434725734	286	129	25B
0005433233831	286	130	24G
0005434551325	286	131	25D
0005433233745	286	132	25C
0005433233564	286	133	25F
0005433180907	286	134	25E
0005434725776	286	135	25J
0005433233827	286	136	25G
0005434725733	286	137	25K
0005434725742	286	138	26A
0005434725670	286	139	26E
0005434725677	286	140	26H
0005434551359	286	141	26G
0005434725687	286	142	26F
0005434551375	286	143	26J
0005433233563	286	144	27B
0005434725746	286	145	26K
0005433233992	286	146	27D
0005434725707	286	147	27C
0005434735695	286	148	27F
0005434725747	286	149	27E
0005435142601	286	150	27H
0005434725697	286	151	27G
0005433233940	286	152	27K
0005434551344	286	153	27J
0005434302471	286	154	28B
0005434725722	286	155	28A
0005433180971	286	156	28D
0005435142602	286	157	28C
0005434725719	286	158	28G
0005434551330	286	159	28F
0005433766594	286	160	28H
0005433233851	286	161	29A
0005434725749	286	162	28K
0005434725750	286	163	29C
0005434551367	286	164	29G
0005434725665	286	165	29F
0005434551324	286	166	29H
0005434725754	286	167	30A
0005432277837	286	168	29K
0005434551341	286	169	29J
0005434725700	286	170	30B
0005432277832	286	171	30E
0005434725732	286	172	30D
0005434725710	286	173	30H
0005434725789	286	174	30G
0005434302468	286	175	30F
0005433233809	286	176	30K
0005434725769	286	177	30J
0005433233686	286	178	31D
0005433234073	286	179	31C
0005433233766	286	180	31B
0005433233781	286	181	31F
0005434551355	286	182	31E
0005434725685	286	183	31H
0005433233767	286	184	32A
0005435142612	286	185	31K
0005434551372	286	186	31J
0005434725772	286	187	32C
0005433180950	286	188	32B
0005433233964	286	189	32E
0005433233501	286	190	32D
0005435142599	286	191	32G
0005434725716	286	192	32F
0005435142603	286	193	32J
0005434725709	286	194	32H
0005433233821	286	195	33B
0005433233680	286	196	33A
0005433233927	286	197	32K
0005435142604	286	198	33D
0005434725678	286	199	33C
0005433131658	286	200	33F
0005434725760	286	201	33E
0005435142606	286	202	34A
0005434725744	286	203	33K
0005434725735	286	204	33J
0005433180933	286	205	34E
0005432277842	286	206	34D
0005434551336	286	207	34G
0005433180906	286	208	34F
0005433233832	286	209	34J
0005434725717	286	210	34H
0005434725672	286	211	35B
0005433180810	286	212	35A
0005434551363	286	213	34K
0005434735693	286	214	35D
0005434551362	286	215	35C
0005434725690	286	216	35F
0005434725753	286	217	35E
0005434725708	286	218	35J
0005434725755	286	219	36A
0005433180905	286	220	35K
0005432277836	286	221	36B
0005434725683	286	222	36D
0005434551335	286	223	36G
0005433233941	286	224	36F
0005433233896	286	225	36K
0005434725771	286	226	36J
0005434725724	286	227	36H
0005433233884	286	228	37B
0005432277843	286	229	37D
0005434302470	286	230	37C
0005433289811	286	231	37E
0005433233740	286	232	37J
0005435142607	286	233	37H
0005434731176	286	234	37G
0005434551350	286	235	38A
0005434725693	286	236	37K
0005434725786	286	237	38C
0005434551333	286	238	38B
0005433233610	286	239	38J
0005434725723	286	240	38H
0005433233681	286	241	39B
0005433233965	286	242	39A
0005433233474	286	243	38K
0005434725785	286	244	39C
0005433234014	286	245	39F
0005434551378	286	246	39D
0005434551379	286	247	39J
0005434725713	286	248	39H
0005434725684	286	249	39G
0005434031994	286	250	40A
0005434725698	286	251	39K
0005434551374	286	252	40B
0005434302469	286	253	40D
0005434731175	286	254	40H
0005433233852	286	255	40G
0005434725757	286	256	40K
0005433233611	286	257	40J
0005434725725	286	258	41B
0005434725686	286	259	41A
0005432277838	286	260	41D
0005434725751	286	261	41C
0005434725761	286	262	41E
0005434725671	286	263	41J
0005434551327	286	264	41H
0005434725720	286	265	42A
0005434725694	286	266	41K
0005434725704	286	267	42C
0005433180908	286	268	42B
0005434551328	286	269	42E
0005433233502	286	270	42D
0005434725715	286	271	42G
0005433113517	286	272	42F
0005434725702	286	273	42J
0005434725788	286	274	42H
0005434551352	286	275	43A
0005433233715	286	276	42K
0005434725787	286	277	43C
0005434551373	286	278	43B
0005433131659	286	279	43F
0005434725784	286	280	43E
0005434725675	286	281	43H
0005433233829	286	282	43G
0005433233801	286	283	44A
0005434551361	286	284	43K
0005434725745	286	285	44C
0005435142611	286	286	44B
0005433289812	286	287	44E
0005433233669	286	288	44D
0005434725669	286	289	44G
0005434031968	286	290	44F
0005434725773	286	291	44J
0005434731174	286	292	44H
0005434735697	286	293	45B
0005434725673	286	294	45A
0005435142609	286	295	44K
0005434725779	286	296	45D
0005434725775	286	297	45F
0005433233880	286	298	45H
0005434725688	286	299	45G
0005433131680	286	300	45K
0005433233993	286	301	46C
0005433180986	286	302	46B
0005433289813	286	303	46A
0005434725667	286	304	46E
0005434551348	286	305	46D
0005434725759	286	306	46G
0005434725777	286	307	46F
0005434031990	286	308	46K
0005434551331	286	309	46J
0005433180916	286	310	46H
0005434735696	286	311	47C
0005433233534	286	312	47A
0005434725730	286	313	47D
0005433233926	286	314	47G
0005433233581	286	315	47F
0005433766610	286	316	47E
0005435142600	286	317	47K
0005434725728	286	318	47H
0005434731177	286	319	48D
0005434725714	286	320	48C
0005434725699	286	321	48E
0005434551342	286	322	48H
0005434725782	286	323	48F
0005434725780	286	324	49A
0005434725765	286	325	48K
0005433233730	286	326	49D
0005433113525	286	327	49C
0005432277839	286	328	49F
0005433289816	286	329	49K
0005433233752	286	330	49H
0005433180859	286	331	49G
0005434725727	286	332	50C
0005434725770	286	333	50A
0005434725689	286	334	50E
0005433766600	286	335	50D
0005434725783	286	336	50H
0005434725676	286	337	50F
0005433126802	286	338	51D
0005433180878	286	339	50K
0005434551370	286	340	51F
0005432277835	286	341	51G
0005433234346	9877	1	1C
0005433129286	9877	2	1A
0005434724700	9877	3	1G
0005433234322	9877	4	1D
0005434735652	9877	5	1K
0005433234329	9877	6	2D
0005434724819	9877	7	2C
0005434724837	9877	8	2A
0005434550828	9877	9	2H
0005434032035	9877	10	2K
0005434724556	9877	11	3D
0005433126854	9877	12	3K
0005434724820	9877	13	3H
0005434302417	9877	14	3G
0005434302418	9877	15	4C
0005434550823	9877	16	4A
0005434724844	9877	17	4G
0005432199263	9877	18	4D
0005434724456	9877	19	4K
0005433129282	9877	20	4H
0005434724895	9877	21	5C
0005433234313	9877	22	5H
0005434724385	9877	23	5D
0005434724740	9877	24	11A
0005434725263	9877	25	5K
0005434724231	9877	26	11D
0005434550892	9877	27	11C
0005433234342	9877	28	11F
0005434724463	9877	29	12C
0005434302427	9877	30	12A
0005433181155	9877	31	11K
0005434724884	9877	32	12F
0005434724951	9877	33	12E
0005434731146	9877	34	12D
0005434550863	9877	35	12G
0005434550724	9877	36	12K
0005434302419	9877	37	12H
0005433181151	9877	38	13D
0005434724504	9877	39	13C
0005434724525	9877	40	13F
0005434725229	9877	41	13E
0005434724303	9877	42	13H
0005433289860	9877	43	13G
0005433234336	9877	44	14C
0005433234358	9877	45	13K
0005434724157	9877	46	14E
0005434724784	9877	47	14D
0005433234356	9877	48	14G
0005434724891	9877	49	14F
0005434724149	9877	50	14H
0005434724988	9877	51	15C
0005435142494	9877	52	15A
0005434724589	9877	53	15E
0005433234310	9877	54	15D
0005434724670	9877	55	15G
0005434724968	9877	56	16A
0005434550647	9877	57	15K
0005433234365	9877	58	15H
0005434724381	9877	59	16D
0005434724600	9877	60	16C
0005433234319	9877	61	16E
0005433234327	9877	62	16H
0005434550494	9877	63	16G
0005434550664	9877	64	17C
0005433234359	9877	65	17A
0005435142499	9877	66	16K
0005434724848	9877	67	17E
0005434724575	9877	68	17D
0005433234321	9877	69	17H
0005434724732	9877	70	17F
0005433289864	9877	71	17K
0005434724967	9877	72	18B
0005434724840	9877	73	18A
0005434550765	9877	74	18E
0005433234326	9877	75	18G
0005433181142	9877	76	18F
0005434724515	9877	77	18K
0005434032034	9877	78	18J
0005433181143	9877	79	19B
0005433234340	9877	80	19A
0005433234366	9877	81	19D
0005434724358	9877	82	19F
0005434724382	9877	83	19E
0005434550775	9877	84	19J
0005434725007	9877	85	19H
0005433234337	9877	86	19G
0005434725207	9877	87	20A
0005434731131	9877	88	19K
0005434725109	9877	89	20C
0005434725256	9877	90	20B
0005434724733	9877	91	20D
0005432199260	9877	92	20G
0005434725199	9877	93	20F
0005434725155	9877	94	20K
0005434724857	9877	95	20J
0005433234311	9877	96	20H
0005433181149	9877	97	21B
0005433234341	9877	98	21A
0005433181160	9877	99	21D
0005434550864	9877	100	21C
0005434724812	9877	101	21F
0005433234364	9877	102	21E
0005434032037	9877	103	21H
0005433234367	9877	104	21G
0005434724577	9877	105	22A
0005433234357	9877	106	21K
0005433234333	9877	107	21J
0005434724439	9877	108	22C
0005434550648	9877	109	22B
0005434302416	9877	110	22F
0005434724447	9877	111	22E
0005433234320	9877	112	22D
0005433289859	9877	113	22K
0005434724937	9877	114	22J
0005434724136	9877	115	23B
0005434725102	9877	116	23A
0005433126855	9877	117	23D
0005434724440	9877	118	23F
0005434724963	9877	119	23E
0005434724135	9877	120	23J
0005435142461	9877	121	23H
0005434724762	9877	122	23G
0005434724503	9877	123	24D
0005433181154	9877	124	23K
0005434724831	9877	125	24F
0005433234352	9877	126	24E
0005434550732	9877	127	24G
0005433289863	9877	128	25D
0005434724335	9877	129	25B
0005435142460	9877	130	25F
0005434550904	9877	131	25E
0005434550678	9877	132	25H
0005434724739	9877	133	25G
0005434725103	9877	134	26A
0005433234339	9877	135	26C
0005433234343	9877	136	26B
0005434725114	9877	137	26E
0005434550590	9877	138	26D
0005434724539	9877	139	26F
0005434735648	9877	140	26K
0005434724486	9877	141	26H
0005432199265	9877	142	27B
0005433181152	9877	143	27A
0005433129284	9877	144	27D
0005434724455	9877	145	27K
0005434550646	9877	146	28C
0005434724907	9877	147	28E
0005434724882	9877	148	28D
0005434550401	9877	149	28G
0005434550774	9877	150	28F
0005434550692	9877	151	28J
0005433234308	9877	152	28H
0005433181145	9877	153	29B
0005434735651	9877	154	29A
0005434724691	9877	155	28K
0005435142481	9877	156	29D
0005433181158	9877	157	29C
0005434724625	9877	158	29F
0005434724581	9877	159	29H
0005434724698	9877	160	29G
0005434724742	9877	161	30C
0005434725198	9877	162	30B
0005433234361	9877	163	30E
0005433234345	9877	164	30G
0005434550893	9877	165	30K
0005433234323	9877	166	30J
0005433234331	9877	167	30H
0005433234309	9877	168	31D
0005434724649	9877	169	31C
0005434724734	9877	170	31G
0005434724549	9877	171	31F
0005434724751	9877	172	31E
0005434550865	9877	173	31J
0005433234334	9877	174	31H
0005435142467	9877	175	32A
0005434735649	9877	176	31K
0005433234347	9877	177	32C
0005434724574	9877	178	32B
0005434550783	9877	179	32E
0005434724832	9877	180	32K
0005433181161	9877	181	32J
0005434725101	9877	182	32H
0005434724795	9877	183	33B
0005434724582	9877	184	33A
0005433234353	9877	185	33D
0005434550788	9877	186	33C
0005433234318	9877	187	33F
0005435142487	9877	188	33E
0005435142462	9877	189	33G
0005433234363	9877	190	34A
0005433766648	9877	191	33K
0005433181146	9877	192	33J
0005434724526	9877	193	34C
0005434550698	9877	194	34B
0005434724383	9877	195	34E
0005434724881	9877	196	34D
0005434724349	9877	197	34H
0005434550587	9877	198	34F
0005433113539	9877	199	34K
0005434550773	9877	200	35B
0005434724838	9877	201	35A
0005434724986	9877	202	35D
0005434724588	9877	203	35G
0005433129285	9877	204	35F
0005434550866	9877	205	35E
0005434550744	9877	206	35J
0005434735647	9877	207	36A
0005434724643	9877	208	35K
0005434550564	9877	209	36C
0005433234349	9877	210	36B
0005434724513	9877	211	36E
0005435142493	9877	212	36D
0005433234355	9877	213	36G
0005434724660	9877	214	36F
0005434724362	9877	215	36K
0005434724181	9877	216	36J
0005433289862	9877	217	37A
0005434725006	9877	218	37E
0005434550787	9877	219	37D
0005434724869	9877	220	37C
0005433181144	9877	221	37G
0005433181162	9877	222	37F
0005434724555	9877	223	37J
0005434724890	9877	224	38A
0005433181157	9877	225	37K
0005434724158	9877	226	38C
0005433234316	9877	227	38J
0005433234317	9877	228	38H
0005434724847	9877	229	39B
0005434724156	9877	230	39A
0005434724706	9877	231	38K
0005434550979	9877	232	39C
0005434724347	9877	233	39F
0005434724856	9877	234	39E
0005433234315	9877	235	39H
0005433126853	9877	236	40A
0005433181147	9877	237	39K
0005434550809	9877	238	39J
0005433234307	9877	239	40C
0005434550778	9877	240	40E
0005433181159	9877	241	40D
0005434724985	9877	242	40H
0005433234324	9877	243	40F
0005433234354	9877	244	41B
0005432199262	9877	245	41A
0005433234325	9877	246	40K
0005434724874	9877	247	41D
0005433181139	9877	248	41C
0005434724669	9877	249	41F
0005434724987	9877	250	41E
0005434723636	9877	251	41J
0005433234362	9877	252	41H
0005434725152	9877	253	41G
0005433234306	9877	254	41K
0005434724375	9877	255	42C
0005434724340	9877	256	42B
0005434724416	9877	257	42F
0005433234328	9877	258	42E
0005433234305	9877	259	42D
0005433234360	9877	260	42K
0005434724673	9877	261	42J
0005433766647	9877	262	42H
0005432199259	9877	263	43A
0005434551023	9877	264	43D
0005434724672	9877	265	43C
0005433181150	9877	266	43F
0005434724650	9877	267	43E
0005434550565	9877	268	43J
0005433181156	9877	269	43H
0005434550563	9877	270	43G
0005434725134	9877	271	43K
0005432199261	9877	272	44C
0005434725005	9877	273	44B
0005434731139	9877	274	44A
0005433234304	9877	275	44E
0005434724432	9877	276	44G
0005433766649	9877	277	44J
0005434550566	9877	278	45B
0005434724576	9877	279	45A
0005434724310	9877	280	45C
0005434724858	9877	281	45F
0005434724348	9877	282	45E
0005434550838	9877	283	45H
0005434724873	9877	284	45G
0005434550764	9877	285	45K
0005433234330	9877	286	45J
0005433181153	9877	287	46C
0005433234332	9877	288	46B
0005433234314	9877	289	46A
0005434724637	9877	290	46G
0005433234344	9877	291	46J
0005435142401	9877	292	46H
0005434550691	9877	293	47A
0005433234348	9877	294	46K
0005433234351	9877	295	47D
0005433181164	9877	296	47C
0005435142438	9877	297	47F
0005433181140	9877	298	47E
0005433234338	9877	299	48A
0005433234312	9877	300	47K
0005433181163	9877	301	47H
0005435142437	9877	302	48C
0005434032033	9877	303	48F
0005433126852	9877	304	48E
0005433181148	9877	305	48D
0005433113541	9877	306	48H
0005433129283	9877	307	48G
0005434724787	9877	308	49A
0005434724376	9877	309	48K
0005434724514	9877	310	49E
0005434724569	9877	311	49D
0005434735650	9877	312	49C
0005434550584	9877	313	49G
0005434724839	9877	314	49K
0005433234350	9877	315	49H
0005433234335	9877	316	50C
0005433181141	9877	317	50A
0005434724771	9877	318	50E
0005434032036	9877	319	50D
0005433113540	9877	320	50H
0005434724464	9877	321	50G
0005434550586	9877	322	50F
0005432199264	9877	323	50K
0005433289861	9877	324	51F
0005434550877	9877	325	51D
0005434550766	9877	326	51G
0005434067698	7734	1	1A
0005434067695	7734	2	1G
0005432528311	7734	3	1D
0005435213153	7734	4	2A
0005434067741	7734	5	1K
0005435213296	7734	6	2D
0005435213029	7734	7	2C
0005434067684	7734	8	2G
0005432528200	7734	9	3A
0005432150212	7734	10	2K
0005432528213	7734	11	3D
0005435213219	7734	12	3C
0005432528312	7734	13	3K
0005432528222	7734	14	3H
0005432528232	7734	15	4C
0005432528228	7734	16	4H
0005434067720	7734	17	4G
0005434067704	7734	18	4D
0005434067688	7734	19	5A
0005432528204	7734	20	4K
0005432528302	7734	21	5D
0005432528226	7734	22	5G
0005432535845	7734	23	11A
0005434067736	7734	24	5K
0005432528255	7734	25	5H
0005434067687	7734	26	11D
0005432528239	7734	27	11C
0005434067689	7734	28	11F
0005432069681	7734	29	11E
0005432528273	7734	30	11K
0005435630939	7734	31	11H
0005435213295	7734	32	11G
0005432528257	7734	33	12C
0005432533298	7734	34	12A
0005434067714	7734	35	12E
0005435213220	7734	36	12H
0005432528191	7734	37	12G
0005435213083	7734	38	12F
0005432528241	7734	39	12K
0005432528208	7734	40	13A
0005432528252	7734	41	13F
0005435725558	7734	42	13E
0005432528186	7734	43	13H
0005432528282	7734	44	13G
0005432528260	7734	45	14A
0005435213004	7734	46	13K
0005432528291	7734	47	14D
0005432528274	7734	48	14C
0005432528301	7734	49	14G
0005434067707	7734	50	14F
0005432528316	7734	51	14H
0005432528210	7734	52	15C
0005432528187	7734	53	15A
0005432528253	7734	54	15G
0005432069686	7734	55	15F
0005434067705	7734	56	16A
0005435213139	7734	57	15K
0005434067717	7734	58	15H
0005434067693	7734	59	16C
0005432528292	7734	60	16F
0005432528267	7734	61	16E
0005432528185	7734	62	16H
0005432069688	7734	63	16G
0005432069684	7734	64	17A
0005435213163	7734	65	16K
0005434067737	7734	66	17E
0005432528287	7734	67	17C
0005435725578	7734	68	17G
0005432528217	7734	69	17K
0005434067731	7734	70	17H
0005435212951	7734	71	18C
0005435213036	7734	72	18B
0005432528225	7734	73	18A
0005435725521	7734	74	18D
0005432528263	7734	75	18F
0005432528306	7734	76	19B
0005435213008	7734	77	19A
0005432528223	7734	78	18K
0005434067690	7734	79	19C
0005434067711	7734	80	19G
0005435725559	7734	81	19F
0005432528246	7734	82	19E
0005432528294	7734	83	19J
0005432528188	7734	84	20E
0005432535841	7734	85	20D
0005432528212	7734	86	20C
0005432528285	7734	87	20H
0005435212984	7734	88	20G
0005434067724	7734	89	20J
0005432069690	7734	90	21A
0005432528224	7734	91	21D
0005432069689	7734	92	21C
0005434067700	7734	93	21B
0005435213130	7734	94	21F
0005432528270	7734	95	21J
0005432528281	7734	96	21H
0005432528299	7734	97	22A
0005434067699	7734	98	21K
0005435213118	7734	99	22C
0005432528216	7734	100	22B
0005432528314	7734	101	22F
0005435213179	7734	102	22E
0005435630936	7734	103	22D
0005432528288	7734	104	22H
0005432528259	7734	105	22G
0005432428936	7734	106	22K
0005432150213	7734	107	23B
0005434067677	7734	108	23A
0005432535843	7734	109	23D
0005432528256	7734	110	23F
0005432069679	7734	111	23E
0005435212957	7734	112	23H
0005432528215	7734	113	23G
0005434067728	7734	114	24D
0005432528265	7734	115	23K
0005434067738	7734	116	23J
0005435212978	7734	117	24F
0005432528266	7734	118	24E
0005434067706	7734	119	25B
0005432528199	7734	120	25A
0005432069680	7734	121	24G
0005435213084	7734	122	25D
0005434067691	7734	123	25F
0005434067680	7734	124	25E
0005432069677	7734	125	25H
0005434067694	7734	126	25G
0005434067681	7734	127	25K
0005432428937	7734	128	25J
0005435213157	7734	129	26C
0005432528214	7734	130	26B
0005434067709	7734	131	26A
0005432528315	7734	132	26E
0005435213231	7734	133	26D
0005432528245	7734	134	26H
0005432528293	7734	135	26G
0005434067703	7734	136	27C
0005435213051	7734	137	27B
0005432528190	7734	138	27E
0005432528296	7734	139	27D
0005432528235	7734	140	27H
0005432069685	7734	141	27G
0005435212910	7734	142	27K
0005432528184	7734	143	28C
0005434067701	7734	144	28B
0005432528237	7734	145	28A
0005432528194	7734	146	28E
0005432528240	7734	147	28D
0005432528300	7734	148	28G
0005434067744	7734	149	28F
0005433656649	7734	150	28K
0005432528203	7734	151	28H
0005432528233	7734	152	29B
0005434067730	7734	153	29A
0005432150214	7734	154	29D
0005432528193	7734	155	29F
0005434067715	7734	156	29E
0005432528202	7734	157	29H
0005432528234	7734	158	29G
0005432528247	7734	159	29K
0005432528269	7734	160	30C
0005435213052	7734	161	30B
0005432528197	7734	162	30A
0005435212909	7734	163	30E
0005432528238	7734	164	30D
0005432528305	7734	165	30G
0005435213065	7734	166	30F
0005432528230	7734	167	30H
0005432528308	7734	168	31B
0005432069691	7734	169	30K
0005434067685	7734	170	31D
0005432528304	7734	171	31C
0005432428935	7734	172	31F
0005435212728	7734	173	31E
0005432528309	7734	174	31H
0005434067713	7734	175	31G
0005434067727	7734	176	31J
0005432528271	7734	177	32C
0005435630940	7734	178	32B
0005433656637	7734	179	32A
0005435725573	7734	180	32E
0005435213054	7734	181	32D
0005432528242	7734	182	32G
0005434067678	7734	183	32F
0005432528227	7734	184	32H
0005432150207	7734	185	33B
0005432528209	7734	186	33A
0005434067708	7734	187	32K
0005435213081	7734	188	33C
0005432528243	7734	189	33F
0005432528195	7734	190	33G
0005434067721	7734	191	34A
0005435213149	7734	192	33K
0005432528286	7734	193	34B
0005432528192	7734	194	34E
0005434067686	7734	195	34D
0005435213006	7734	196	34C
0005435213365	7734	197	34H
0005432528254	7734	198	34G
0005434067735	7734	199	34K
0005435213274	7734	200	34J
0005432528219	7734	201	35B
0005434067719	7734	202	35A
0005432528201	7734	203	35D
0005434067702	7734	204	35C
0005432528207	7734	205	35F
0005432528289	7734	206	35E
0005432150209	7734	207	35J
0005432528313	7734	208	35H
0005435212960	7734	209	35G
0005432528307	7734	210	36A
0005432528258	7734	211	35K
0005432528249	7734	212	36C
0005434067692	7734	213	36B
0005435213305	7734	214	36E
0005432069678	7734	215	36D
0005435213195	7734	216	36F
0005432528272	7734	217	36H
0005435213071	7734	218	37A
0005435213148	7734	219	37D
0005434067742	7734	220	37F
0005432528196	7734	221	37J
0005432528220	7734	222	37G
0005434067712	7734	223	38A
0005434067726	7734	224	38C
0005434067725	7734	225	38J
0005432535842	7734	226	38H
0005435213230	7734	227	39A
0005434067716	7734	228	38K
0005432528303	7734	229	39C
0005432528211	7734	230	39B
0005432528248	7734	231	39E
0005432528275	7734	232	39J
0005432537062	7734	233	39H
0005434067732	7734	234	39K
0005432150211	7734	235	40B
0005432528231	7734	236	40A
0005434067682	7734	237	40E
0005435213114	7734	238	40D
0005434067739	7734	239	40G
0005434067746	7734	240	40F
0005432069682	7734	241	40K
0005432528277	7734	242	40H
0005435213073	7734	243	41A
0005432528218	7734	244	41D
0005434067745	7734	245	41C
0005435213021	7734	246	41F
0005432535844	7734	247	41E
0005435212430	7734	248	41H
0005434067683	7734	249	41G
0005432150210	7734	250	42A
0005435212962	7734	251	41J
0005432528284	7734	252	42C
0005435213113	7734	253	42B
0005432069683	7734	254	42E
0005433656627	7734	255	42D
0005435212919	7734	256	42G
0005432528189	7734	257	42J
0005435213277	7734	258	43A
0005435213196	7734	259	42K
0005432528298	7734	260	43C
0005434067743	7734	261	43F
0005432528295	7734	262	43E
0005435212912	7734	263	43D
0005435213194	7734	264	43H
0005434067733	7734	265	43G
0005434067723	7734	266	43K
0005435212918	7734	267	43J
0005432528264	7734	268	44A
0005435630935	7734	269	44E
0005432528206	7734	270	44D
0005435213308	7734	271	44C
0005432533297	7734	272	44F
0005434067696	7734	273	44J
0005434067679	7734	274	44H
0005435212793	7734	275	45A
0005434067740	7734	276	44K
0005432528221	7734	277	45C
0005432528297	7734	278	45F
0005432528250	7734	279	45E
0005434067718	7734	280	45J
0005432528261	7734	281	45H
0005435213079	7734	282	45G
0005435213152	7734	283	45K
0005435213205	7734	284	46C
0005432528310	7734	285	46A
0005432528279	7734	286	46E
0005432150208	7734	287	46D
0005435212727	7734	288	46G
0005435212917	7734	289	46F
0005435213135	7734	290	46J
0005435213007	7734	291	47C
0005432528283	7734	292	47E
0005432528251	7734	293	47D
0005435212916	7734	294	47G
0005434067734	7734	295	47F
0005432537061	7734	296	47K
0005434067722	7734	297	47H
0005432069687	7734	298	48D
0005432528244	7734	299	48C
0005432528198	7734	300	48A
0005434067710	7734	301	48F
0005432528280	7734	302	48E
0005435213199	7734	303	48H
0005435213078	7734	304	48G
0005434067697	7734	305	49C
0005432528229	7734	306	49A
0005432528278	7734	307	48K
0005434067676	7734	308	49D
0005432069692	7734	309	49G
0005432528205	7734	310	49F
0005434067729	7734	311	49E
0005435212911	7734	312	49K
0005435212950	7734	313	49H
0005435213210	7734	314	50C
0005432528276	7734	315	50A
0005435213082	7734	316	50E
0005432528236	7734	317	50F
0005435213209	7734	318	51D
0005435213197	7734	319	50K
0005432528262	7734	320	50H
0005435213115	7734	321	51F
0005432528268	7734	322	51E
0005432528290	7734	323	51G
0005434244714	5336	1	1A
0005435613872	5336	2	1D
0005434573375	5336	3	2A
0005435490235	5336	4	1H
0005435491444	5336	5	2C
0005435613849	5336	6	2G
0005434244801	5336	7	2D
0005435613904	5336	8	2K
0005435613903	5336	9	3D
0005435613859	5336	10	3C
0005434573383	5336	11	3H
0005435613880	5336	12	3G
0005435613821	5336	13	4A
0005434344312	5336	14	3K
0005435613936	5336	15	4G
0005435613935	5336	16	4D
0005435613823	5336	17	4K
0005435424434	5336	18	4H
0005435613918	5336	19	5C
0005432133242	5336	20	5A
0005435424171	5336	21	5G
0005435613956	5336	22	5D
0005435613871	5336	23	11A
0005434344289	5336	24	5K
0005435613873	5336	25	5H
0005435613825	5336	26	11D
0005434344318	5336	27	11C
0005434244793	5336	28	11F
0005433719100	5336	29	11E
0005434244846	5336	30	11K
0005435613914	5336	31	11G
0005432133245	5336	32	12C
0005434344308	5336	33	12F
0005434344294	5336	34	12E
0005434344316	5336	35	12D
0005434573380	5336	36	12G
0005435424586	5336	37	13A
0005435097219	5336	38	12K
0005434344313	5336	39	12H
0005435302179	5336	40	13C
0005435319520	5336	41	13F
0005435613870	5336	42	13E
0005435319533	5336	43	13K
0005433719101	5336	44	13H
0005435613931	5336	45	13G
0005435613855	5336	46	14A
0005435424484	5336	47	14E
0005435613867	5336	48	14D
0005435613913	5336	49	14C
0005435613895	5336	50	14F
0005435424453	5336	51	14K
0005435613929	5336	52	14H
0005432133249	5336	53	15C
0005435613898	5336	54	15A
0005434244729	5336	55	15E
0005435613897	5336	56	15H
0005435424265	5336	57	15F
0005435613944	5336	58	16A
0005435613943	5336	59	15K
0005434244794	5336	60	16D
0005435613905	5336	61	16F
0005435613869	5336	62	16E
0005435424304	5336	63	16H
0005432133240	5336	64	16G
0005435613878	5336	65	17C
0005435424374	5336	66	17A
0005435613954	5336	67	16K
0005435613822	5336	68	17E
0005434573376	5336	69	17G
0005433719121	5336	70	17K
0005435613851	5336	71	17H
0005434244927	5336	72	18B
0005435613911	5336	73	18A
0005434344288	5336	74	18E
0005435613894	5336	75	18D
0005435613839	5336	76	18C
0005435613921	5336	77	18G
0005435097215	5336	78	18F
0005435613932	5336	79	18J
0005435424216	5336	80	18H
0005435613860	5336	81	19A
0005435613922	5336	82	18K
0005432047559	5336	83	19D
0005435424380	5336	84	19C
0005435319532	5336	85	19F
0005435319546	5336	86	19E
0005435613901	5336	87	19H
0005435613950	5336	88	19G
0005434344299	5336	89	20A
0005435424255	5336	90	19K
0005435424366	5336	91	19J
0005435613926	5336	92	20B
0005435613836	5336	93	20F
0005435424376	5336	94	20D
0005435613848	5336	95	20C
0005435319534	5336	96	20H
0005435424495	5336	97	20G
0005434573377	5336	98	20J
0005435613874	5336	99	21B
0005435613884	5336	100	21A
0005434344307	5336	101	20K
0005435424210	5336	102	21D
0005432133241	5336	103	21C
0005435319565	5336	104	21F
0005435424571	5336	105	21E
0005435042832	5336	106	21J
0005435319518	5336	107	21H
0005435613948	5336	108	21G
0005435423963	5336	109	22A
0005435613949	5336	110	22C
0005435613902	5336	111	22B
0005434244685	5336	112	22F
0005435555372	5336	113	22D
0005432133237	5336	114	22K
0005434344322	5336	115	22J
0005435613906	5336	116	22H
0005435424347	5336	117	23B
0005435613838	5336	118	23A
0005435613864	5336	119	23D
0005435617171	5336	120	23C
0005434344301	5336	121	23F
0005435613947	5336	122	23J
0005435424616	5336	123	23H
0005435424241	5336	124	23G
0005435613889	5336	125	24D
0005435319564	5336	126	23K
0005435617234	5336	127	24F
0005435613863	5336	128	24E
0005434244745	5336	129	25B
0005434573379	5336	130	25A
0005435613907	5336	131	24G
0005434573381	5336	132	25C
0005435097222	5336	133	25F
0005435319553	5336	134	25E
0005434344302	5336	135	25D
0005435424313	5336	136	25J
0005435613891	5336	137	25H
0005435613952	5336	138	25G
0005434244825	5336	139	25K
0005435613834	5336	140	26B
0005435613862	5336	141	26A
0005435424572	5336	142	26G
0005434573389	5336	143	26F
0005435424353	5336	144	26J
0005435613925	5336	145	27A
0005434344320	5336	146	26K
0005435302126	5336	147	27D
0005435319535	5336	148	27C
0005435424305	5336	149	27B
0005435613883	5336	150	27F
0005435613840	5336	151	27E
0005434344300	5336	152	27J
0005435613868	5336	153	27G
0005435613885	5336	154	27K
0005432133235	5336	155	28A
0005435613866	5336	156	28E
0005434344291	5336	157	28D
0005432841002	5336	158	28G
0005435613881	5336	159	28J
0005435613908	5336	160	28H
0005435097214	5336	161	29B
0005435424256	5336	162	29A
0005435097221	5336	163	28K
0005435613953	5336	164	29C
0005435613915	5336	165	29F
0005435319523	5336	166	29E
0005435424697	5336	167	29H
0005435617235	5336	168	29G
0005432133236	5336	169	30C
0005435613876	5336	170	30B
0005435424526	5336	171	30A
0005432047557	5336	172	30E
0005435097216	5336	173	30D
0005435613850	5336	174	30H
0005435613899	5336	175	30G
0005434244840	5336	176	30F
0005435613888	5336	177	31A
0005435613946	5336	178	30K
0005435613857	5336	179	31D
0005435424308	5336	180	31C
0005435613912	5336	181	31B
0005434344323	5336	182	31F
0005435097218	5336	183	31E
0005435555373	5336	184	31J
0005435424681	5336	185	31H
0005435424378	5336	186	31G
0005434344305	5336	187	32A
0005432133246	5336	188	31K
0005435042831	5336	189	32B
0005435097223	5336	190	32F
0005435613854	5336	191	32J
0005435424500	5336	192	32H
0005434344310	5336	193	33A
0005435319517	5336	194	32K
0005434344324	5336	195	33D
0005435424170	5336	196	33C
0005435613827	5336	197	33B
0005435613829	5336	198	33E
0005435424489	5336	199	33J
0005435613826	5336	200	33H
0005435319502	5336	201	33G
0005435613856	5336	202	33K
0005435424721	5336	203	34B
0005432133247	5336	204	34A
0005434344315	5336	205	34E
0005435613909	5336	206	34D
0005435491443	5336	207	34G
0005435613828	5336	208	34F
0005435613927	5336	209	34K
0005434244926	5336	210	34J
0005435302127	5336	211	34H
0005435097220	5336	212	35D
0005434244746	5336	213	35B
0005435613890	5336	214	35F
0005435490234	5336	215	35E
0005435424373	5336	216	35H
0005435613896	5336	217	35G
0005435613877	5336	218	36A
0005435613853	5336	219	35K
0005434344304	5336	220	35J
0005434244754	5336	221	36C
0005434244910	5336	222	36B
0005434344309	5336	223	36F
0005434344287	5336	224	36D
0005434573378	5336	225	36H
0005435613916	5336	226	36G
0005434573387	5336	227	37B
0005435302157	5336	228	37A
0005432047558	5336	229	36K
0005435613846	5336	230	37D
0005435613945	5336	231	37C
0005435424687	5336	232	37F
0005434344292	5336	233	37H
0005432133238	5336	234	37G
0005435424615	5336	235	38A
0005434244874	5336	236	37K
0005435490236	5336	237	38H
0005434344321	5336	238	38C
0005435613832	5336	239	38B
0005435613892	5336	240	38K
0005434244715	5336	241	38J
0005435613830	5336	242	39A
0005435613951	5336	243	39D
0005435613900	5336	244	39B
0005435424215	5336	245	39G
0005434573385	5336	246	39F
0005434344290	5336	247	39E
0005435613858	5336	248	39K
0005434344311	5336	249	39J
0005434573384	5336	250	40A
0005435613879	5336	251	40E
0005434244728	5336	252	40H
0005435319522	5336	253	40G
0005435613919	5336	254	40K
0005435613824	5336	255	40J
0005433719113	5336	256	41B
0005435613924	5336	257	41D
0005435613893	5336	258	41C
0005435613939	5336	259	41F
0005435097224	5336	260	41E
0005435613930	5336	261	41J
0005435613933	5336	262	41H
0005435424367	5336	263	41G
0005435302169	5336	264	41K
0005435613923	5336	265	42C
0005435319516	5336	266	42B
0005435613835	5336	267	42A
0005435613845	5336	268	42E
0005435424365	5336	269	42D
0005434244873	5336	270	42G
0005435424494	5336	271	42F
0005435613887	5336	272	42K
0005432133239	5336	273	42J
0005434344317	5336	274	42H
0005434244698	5336	275	43D
0005435613942	5336	276	43B
0005435424628	5336	277	43F
0005435424589	5336	278	43E
0005434344295	5336	279	43H
0005434244802	5336	280	43G
0005435424623	5336	281	43K
0005433719120	5336	282	43J
0005432133248	5336	283	44C
0005435613941	5336	284	44B
0005435613920	5336	285	44E
0005435613917	5336	286	44H
0005435613882	5336	287	44G
0005435613837	5336	288	44F
0005435613875	5336	289	44J
0005435613934	5336	290	45A
0005434344306	5336	291	44K
0005435424490	5336	292	45D
0005434573388	5336	293	45C
0005435613886	5336	294	45F
0005435613847	5336	295	45E
0005434344314	5336	296	45G
0005434244841	5336	297	45K
0005434344319	5336	298	46B
0005434344293	5336	299	46A
0005435613833	5336	300	46E
0005435617172	5336	301	46D
0005435319555	5336	302	46C
0005435424461	5336	303	46G
0005434344297	5336	304	46F
0005435319554	5336	305	46K
0005435613852	5336	306	46J
0005434573382	5336	307	46H
0005432133243	5336	308	47C
0005435424368	5336	309	47A
0005434344298	5336	310	47E
0005435613938	5336	311	47D
0005435424172	5336	312	47G
0005435613844	5336	313	47F
0005435424462	5336	314	47K
0005435613940	5336	315	47H
0005435613955	5336	316	48A
0005435613842	5336	317	48F
0005434244734	5336	318	48E
0005435613865	5336	319	48D
0005433719102	5336	320	48H
0005435424488	5336	321	48G
0005435424570	5336	322	49A
0005435613841	5336	323	48K
0005435613861	5336	324	49D
0005435613843	5336	325	49C
0005434344303	5336	326	49G
0005435097217	5336	327	49F
0005432047556	5336	328	49K
0005435613910	5336	329	49H
0005435613937	5336	330	50A
0005434244843	5336	331	50E
0005435613820	5336	332	50D
0005434344296	5336	333	50G
0005435319521	5336	334	50F
0005435613831	5336	335	50K
0005434573386	5336	336	50H
0005435613928	5336	337	51E
0005432133244	5336	338	51D
0005435424242	5336	339	51G
0005434343898	10886	1	1A
0005435612877	10886	2	1G
0005434343945	10886	3	1D
0005435613017	10886	4	1K
0005435424979	10886	5	1H
0005434245032	10886	6	2C
0005435613184	10886	7	2A
0005435424937	10886	8	2H
0005435424960	10886	9	2G
0005435612908	10886	10	2D
0005435612600	10886	11	3C
0005435613319	10886	12	3A
0005435612696	10886	13	2K
0005434343991	10886	14	3D
0005434245053	10886	15	3K
0005435612657	10886	16	3H
0005435424922	10886	17	3G
0005435424943	10886	18	4C
0005435319587	10886	19	4A
0005435424982	10886	20	4G
0005432165054	10886	21	4D
0005435097138	10886	22	4K
0005435612273	10886	23	4H
0005435612820	10886	24	5D
0005434344045	10886	25	5C
0005435613296	10886	26	5A
0005434245031	10886	27	11A
0005434245040	10886	28	5H
0005435424917	10886	29	11C
0005434344050	10886	30	11G
0005435612692	10886	31	12C
0005435613050	10886	32	12A
0005434343780	10886	33	11K
0005435424921	10886	34	12E
0005435612853	10886	35	12H
0005435613141	10886	36	12F
0005435612753	10886	37	12K
0005435380302	10886	38	13D
0005434343942	10886	39	13C
0005435612951	10886	40	13A
0005435424961	10886	41	13E
0005434573229	10886	42	13H
0005432165052	10886	43	13G
0005435424977	10886	44	14A
0005435097117	10886	45	13K
0005433719149	10886	46	14E
0005435424928	10886	47	14D
0005435424981	10886	48	14C
0005435424954	10886	49	14G
0005434245044	10886	50	14K
0005435613338	10886	51	14H
0005435424941	10886	52	15D
0005434343992	10886	53	15A
0005435424959	10886	54	15F
0005434573241	10886	55	16A
0005435613150	10886	56	15K
0005435380299	10886	57	16D
0005434343876	10886	58	16C
0005435042858	10886	59	16E
0005435424942	10886	60	16K
0005435319593	10886	61	16H
0005435424971	10886	62	16G
0005435304167	10886	63	17C
0005434343955	10886	64	17A
0005435424934	10886	65	17E
0005434343911	10886	66	17G
0005435613018	10886	67	17F
0005432165051	10886	68	17K
0005432363424	10886	69	18B
0005434245028	10886	70	18E
0005435612913	10886	71	18D
0005435319588	10886	72	18C
0005435613183	10886	73	18J
0005435612914	10886	74	18H
0005435613276	10886	75	19A
0005435424953	10886	76	18K
0005435612915	10886	77	19C
0005434245033	10886	78	19F
0005434343829	10886	79	19J
0005435424974	10886	80	19G
0005434343941	10886	81	20A
0005435424924	10886	82	19K
0005435490205	10886	83	20C
0005434343890	10886	84	20B
0005435613126	10886	85	20D
0005435612715	10886	86	20G
0005434245043	10886	87	20F
0005435424967	10886	88	21B
0005434343996	10886	89	21A
0005435613295	10886	90	21D
0005434343737	10886	91	21C
0005435613233	10886	92	21F
0005432166910	10886	93	21E
0005435097139	10886	94	21J
0005435424932	10886	95	21H
0005435424976	10886	96	21G
0005435612975	10886	97	22A
0005435424929	10886	98	22C
0005434245026	10886	99	22B
0005435613027	10886	100	22F
0005435424964	10886	101	22E
0005434344003	10886	102	22G
0005434245050	10886	103	22K
0005435612267	10886	104	22J
0005434656560	10886	105	23B
0005435424983	10886	106	23A
0005435613072	10886	107	23E
0005435612545	10886	108	23D
0005434245045	10886	109	23C
0005435319591	10886	110	23F
0005435424939	10886	111	23K
0005435424958	10886	112	23J
0005434245052	10886	113	24E
0005435424980	10886	114	25B
0005435490208	10886	115	25A
0005435613052	10886	116	25D
0005435613001	10886	117	25F
0005434245041	10886	118	25H
0005435319589	10886	119	25G
0005435613320	10886	120	26A
0005435612738	10886	121	25K
0005434344031	10886	122	26C
0005435424944	10886	123	26B
0005435613112	10886	124	26E
0005435424952	10886	125	26G
0005435424933	10886	126	26F
0005435424962	10886	127	26H
0005434343958	10886	128	27A
0005435424923	10886	129	26K
0005435424931	10886	130	27D
0005434343884	10886	131	27C
0005434343993	10886	132	27F
0005435097127	10886	133	27E
0005435424936	10886	134	28A
0005435424925	10886	135	27K
0005434245054	10886	136	28C
0005435613306	10886	137	28B
0005435612928	10886	138	28E
0005432841017	10886	139	28D
0005435612748	10886	140	28J
0005434245027	10886	141	29D
0005435613080	10886	142	29C
0005435612845	10886	143	29B
0005435424919	10886	144	29H
0005434344002	10886	145	29K
0005434343830	10886	146	30B
0005435490221	10886	147	30E
0005432165057	10886	148	30D
0005435304164	10886	149	30G
0005435097088	10886	150	30F
0005435424948	10886	151	30K
0005435424969	10886	152	30J
0005435097132	10886	153	30H
0005435612695	10886	154	31A
0005434344127	10886	155	31D
0005435380304	10886	156	31C
0005434245034	10886	157	31B
0005434245051	10886	158	31F
0005435424945	10886	159	31E
0005434245037	10886	160	31H
0005435424920	10886	161	31K
0005435424973	10886	162	32C
0005434344077	10886	163	32B
0005432166909	10886	164	32E
0005435424940	10886	165	32G
0005432165050	10886	166	32F
0005432165053	10886	167	32K
0005435424950	10886	168	32J
0005434245042	10886	169	32H
0005433719148	10886	170	33B
0005434245048	10886	171	33A
0005435490204	10886	172	33D
0005435319590	10886	173	33C
0005435612683	10886	174	33J
0005435612909	10886	175	33H
0005432166907	10886	176	34A
0005435613095	10886	177	33K
0005435424956	10886	178	34E
0005435380303	10886	179	34G
0005435424918	10886	180	34F
0005435424972	10886	181	34H
0005434344021	10886	182	35A
0005434573312	10886	183	35D
0005434343956	10886	184	35C
0005435613038	10886	185	35E
0005434245036	10886	186	35G
0005434343856	10886	187	36A
0005435424927	10886	188	36C
0005434245049	10886	189	36B
0005432165056	10886	190	36E
0005434245056	10886	191	36D
0005434656561	10886	192	36G
0005435319586	10886	193	36F
0005434343886	10886	194	36H
0005435613258	10886	195	37B
0005435612568	10886	196	37A
0005435380301	10886	197	37C
0005434245046	10886	198	37F
0005432363425	10886	199	37E
0005435613110	10886	200	37H
0005435613224	10886	201	37G
0005435319592	10886	202	37K
0005434245038	10886	203	38C
0005434344049	10886	204	38B
0005435613046	10886	205	38K
0005435613548	10886	206	38J
0005434245030	10886	207	38H
0005435424978	10886	208	39A
0005434245029	10886	209	39D
0005435612872	10886	210	39B
0005432166906	10886	211	39G
0005434343700	10886	212	40A
0005435613142	10886	213	39K
0005435097125	10886	214	39J
0005434343891	10886	215	40B
0005435424947	10886	216	40E
0005435612903	10886	217	40D
0005435613222	10886	218	40G
0005435424966	10886	219	40F
0005434573220	10886	220	40K
0005434573224	10886	221	40J
0005435424949	10886	222	40H
0005435612873	10886	223	41A
0005433719147	10886	224	41D
0005435612974	10886	225	41C
0005434344078	10886	226	41B
0005434343925	10886	227	41G
0005435097126	10886	228	41F
0005435612546	10886	229	41E
0005435613000	10886	230	41J
0005435304166	10886	231	41H
0005432841018	10886	232	41K
0005435097140	10886	233	42C
0005434573264	10886	234	42B
0005434245055	10886	235	42E
0005434343949	10886	236	42D
0005434344061	10886	237	42G
0005435613191	10886	238	42F
0005435424926	10886	239	42K
0005435097118	10886	240	42J
0005435612665	10886	241	42H
0005434343905	10886	242	43B
0005435613339	10886	243	43D
0005435612714	10886	244	43C
0005435424963	10886	245	43E
0005435612818	10886	246	43J
0005434245047	10886	247	43H
0005432363423	10886	248	43G
0005435612993	10886	249	44A
0005435424955	10886	250	43K
0005435319595	10886	251	44C
0005435612996	10886	252	44B
0005435612739	10886	253	44E
0005435612846	10886	254	44D
0005432165055	10886	255	44G
0005435613221	10886	256	44F
0005435424946	10886	257	44K
0005435612943	10886	258	44H
0005434245035	10886	259	45B
0005435613026	10886	260	45A
0005435319594	10886	261	45D
0005435613243	10886	262	45C
0005435424951	10886	263	45F
0005435424984	10886	264	45H
0005435612664	10886	265	45G
0005435613037	10886	266	46A
0005435424968	10886	267	45J
0005434343707	10886	268	46C
0005435613064	10886	269	46B
0005435612749	10886	270	46E
0005434344097	10886	271	46F
0005434343825	10886	272	46H
0005435612851	10886	273	46K
0005434343885	10886	274	47D
0005434343960	10886	275	47C
0005434343959	10886	276	47G
0005435424957	10886	277	47F
0005435612920	10886	278	47K
0005435424938	10886	279	47H
0005435613094	10886	280	48D
0005434245039	10886	281	48C
0005435304165	10886	282	48A
0005435424975	10886	283	48E
0005435612852	10886	284	48H
0005435612292	10886	285	49A
0005434573297	10886	286	49D
0005435424970	10886	287	49C
0005435424930	10886	288	49G
0005435613252	10886	289	49F
0005432166908	10886	290	49E
0005435613307	10886	291	49K
0005435612272	10886	292	49H
0005435424935	10886	293	50C
0005435612415	10886	294	50E
0005435380300	10886	295	50H
0005435613045	10886	296	50G
0005435612693	10886	297	50F
0005434573158	10886	298	51D
0005435424965	10886	299	50K
0005434343850	10886	300	51E
0005433805451	3297	1	1A
0005432459572	3297	2	1D
0005432459480	3297	3	1C
0005432459287	3297	4	2A
0005432181764	3297	5	1F
0005432459348	3297	6	2C
0005432181759	3297	7	2D
0005433805440	3297	8	3A
0005432181767	3297	9	2F
0005433633882	3297	10	3C
0005432459378	3297	11	3F
0005433805459	3297	12	3D
0005432459752	3297	13	4A
0005433633902	3297	14	4C
0005432459655	3297	15	4F
0005433507217	3297	16	4D
0005433507228	3297	17	5A
0005434143726	3297	18	5D
0005432459428	3297	19	5C
0005432181768	3297	20	5F
0005433507213	3297	21	6A
0005433805464	3297	22	6C
0005433633904	3297	23	6F
0005433633884	3297	24	6D
0005432181761	3297	25	7A
0005432181752	3297	26	7C
0005432181765	3297	27	7F
0005432459407	3297	28	7D
0005433805462	3297	29	8A
0005432459449	3297	30	8B
0005432459441	3297	31	8D
0005433507232	3297	32	8C
0005432181757	3297	33	8E
0005433507225	3297	34	8F
0005432459401	3297	35	9A
0005433805441	3297	36	9C
0005433633900	3297	37	9B
0005432459668	3297	38	9D
0005433633908	3297	39	9F
0005432181754	3297	40	9E
0005432459333	3297	41	10A
0005433633893	3297	42	10C
0005433507223	3297	43	10B
0005433633885	3297	44	10D
0005433805436	3297	45	10E
0005433633910	3297	46	10F
0005433633888	3297	47	11B
0005432459578	3297	48	11A
0005432459392	3297	49	11C
0005432181760	3297	50	11D
0005433805463	3297	51	11E
0005433507216	3297	52	12A
0005433805449	3297	53	11F
0005433633878	3297	54	12C
0005433507221	3297	55	12B
0005433633894	3297	56	12D
0005432459579	3297	57	12F
0005433805475	3297	58	12E
0005433805444	3297	59	13A
0005434143727	3297	60	13C
0005433633899	3297	61	13B
0005433805442	3297	62	13D
0005433805476	3297	63	13F
0005433633877	3297	64	13E
0005433805443	3297	65	14A
0005433805469	3297	66	14C
0005433805471	3297	67	14B
0005432459654	3297	68	14E
0005433805473	3297	69	14D
0005433633892	3297	70	15A
0005433633889	3297	71	14F
0005433633890	3297	72	15B
0005433507222	3297	73	15C
0005433805467	3297	74	15D
0005433805438	3297	75	15F
0005433805470	3297	76	15E
0005432459391	3297	77	16A
0005433507230	3297	78	16B
0005432459490	3297	79	16D
0005434143730	3297	80	16C
0005433507227	3297	81	16E
0005432181774	3297	82	17A
0005433507226	3297	83	16F
0005432181772	3297	84	17B
0005433507219	3297	85	17C
0005433507215	3297	86	17E
0005433633906	3297	87	17D
0005433805461	3297	88	17F
0005433507229	3297	89	18A
0005433805474	3297	90	18B
0005433805453	3297	91	18D
0005432459608	3297	92	18C
0005433507212	3297	93	18E
0005432459334	3297	94	18F
0005432181755	3297	95	19C
0005432459527	3297	96	19B
0005433633880	3297	97	19D
0005433805445	3297	98	19E
0005433633903	3297	99	20A
0005432459514	3297	100	20C
0005432459471	3297	101	20B
0005432459504	3297	102	20E
0005432459669	3297	103	20D
0005432181758	3297	104	20F
0005433633905	3297	105	21A
0005433805450	3297	106	21C
0005432459363	3297	107	21B
0005433633886	3297	108	21D
0005432181756	3297	109	21E
0005433805457	3297	110	21F
0005432181762	3297	111	22B
0005432181766	3297	112	22A
0005432181770	3297	113	22C
0005433507233	3297	114	22E
0005433805472	3297	115	22D
0005432459437	3297	116	22F
0005432459184	3297	117	23B
0005433633879	3297	118	23A
0005432181771	3297	119	23D
0005433507214	3297	120	23C
0005433805446	3297	121	23F
0005433633887	3297	122	23E
0005432181769	3297	123	24A
0005433805447	3297	124	24B
0005432459269	3297	125	24D
0005434143725	3297	126	24C
0005433805466	3297	127	24F
0005433805458	3297	128	24E
0005433507231	3297	129	25A
0005433805437	3297	130	25C
0005433633897	3297	131	25B
0005434143729	3297	132	25E
0005432459609	3297	133	25D
0005432181763	3297	134	26A
0005433805456	3297	135	25F
0005432459438	3297	136	26B
0005433633891	3297	137	26C
0005433507218	3297	138	26E
0005432459619	3297	139	26D
0005432459545	3297	140	27A
0005432459618	3297	141	26F
0005433633907	3297	142	27C
0005432459523	3297	143	27B
0005432459677	3297	144	27D
0005433633883	3297	145	27E
0005433507220	3297	146	28A
0005433633896	3297	147	27F
0005433805448	3297	148	28B
0005432459515	3297	149	28D
0005432459288	3297	150	28C
0005433633901	3297	151	28E
0005433805460	3297	152	28F
0005433805455	3297	153	29A
0005433507224	3297	154	29C
0005433805452	3297	155	29B
0005433805454	3297	156	29D
0005432459676	3297	157	29E
0005433633895	3297	158	30A
0005433805465	3297	159	29F
0005433633898	3297	160	30B
0005433805439	3297	161	30C
0005433633909	3297	162	30E
0005433633881	3297	163	30D
0005434143728	3297	164	31A
0005433805468	3297	165	30F
0005432181753	3297	166	31B
0005432459402	3297	167	31C
0005432459571	3297	168	31D
0005432459450	3297	169	31F
0005432181773	3297	170	31E
0005435885090	3296	1	1F
0005435884929	3296	2	1D
0005435884633	3296	3	3A
0005435885082	3296	4	6A
0005435885123	3296	5	5F
0005435884978	3296	6	6D
0005435884981	3296	7	8C
0005435884874	3296	8	8F
0005435884872	3296	9	9E
0005435884805	3296	10	10B
0005435884632	3296	11	10F
0005435885010	3296	12	11A
0005435884742	3296	13	11B
0005435884961	3296	14	13B
0005435884895	3296	15	13D
0005435885054	3296	16	15D
0005435884804	3296	17	17C
0005435885038	3296	18	17E
0005435885083	3296	19	18A
0005435885008	3296	20	18B
0005435884963	3296	21	18D
0005435884983	3296	22	19C
0005435884926	3296	23	20D
0005435885183	3296	24	21A
0005435884871	3296	25	21B
0005435884810	3296	26	21D
0005435885089	3296	27	21E
0005435884966	3296	28	22A
0005435884971	3296	29	23A
0005435885006	3296	30	23B
0005435885009	3296	31	23D
0005435884570	3296	32	23C
0005435884970	3296	33	25C
0005435884917	3296	34	26A
0005435884960	3296	35	26B
0005435884965	3296	36	26D
0005435884852	3296	37	26E
0005435885148	3296	38	28B
0005435885135	3296	39	28E
0005435884792	3296	40	28F
0005435884912	3296	41	29A
0005435885039	3296	42	29B
0005435885147	3296	43	30A
0005435884791	3296	44	30C
0005435884919	3296	45	31E
0005433507078	8173	1	1C
0005432460009	8173	2	1F
0005432042748	8173	3	1D
0005432459999	8173	4	2C
0005433506988	8173	5	2A
0005435885323	8173	6	2D
0005433507023	8173	7	2F
0005433507110	8173	8	3D
0005432459983	8173	9	3C
0005432459981	8173	10	3F
0005432459997	8173	11	4A
0005435885353	8173	12	4C
0005432460000	8173	13	4F
0005432459995	8173	14	4D
0005435885340	8173	15	5C
0005435885341	8173	16	5D
0005433507122	8173	17	5F
0005433507087	8173	18	6C
0005435885349	8173	19	6D
0005435885325	8173	20	7A
0005433507083	8173	21	6F
0005432460006	8173	22	7D
0005435885345	8173	23	7C
0005433507031	8173	24	7F
0005435885363	8173	25	8A
0005432459990	8173	26	8B
0005432460003	8173	27	8D
0005432042741	8173	28	8C
0005432459980	8173	29	8E
0005435885343	8173	30	9A
0005435885368	8173	31	8F
0005432459994	8173	32	9B
0005432459976	8173	33	9C
0005433507051	8173	34	9F
0005432459991	8173	35	9E
0005432460010	8173	36	10A
0005435885356	8173	37	10B
0005435885344	8173	38	10C
0005435885330	8173	39	10E
0005432459986	8173	40	10D
0005435885338	8173	41	10F
0005432459978	8173	42	11B
0005433507082	8173	43	11A
0005435885322	8173	44	11C
0005433507084	8173	45	11E
0005434312326	8173	46	11D
0005433507034	8173	47	11F
0005434312325	8173	48	12A
0005432459973	8173	49	12B
0005435885348	8173	50	12C
0005433507109	8173	51	12E
0005432459996	8173	52	12D
0005435885324	8173	53	12F
0005432460023	8173	54	13B
0005432460011	8173	55	13A
0005432042743	8173	56	13D
0005432460021	8173	57	13E
0005435885351	8173	58	14A
0005432460016	8173	59	13F
0005432459987	8173	60	14C
0005435885346	8173	61	14B
0005433507062	8173	62	14D
0005435885327	8173	63	14E
0005432459988	8173	64	14F
0005432042752	8173	65	15A
0005432460004	8173	66	15C
0005432042751	8173	67	15B
0005435885342	8173	68	15D
0005435885326	8173	69	15E
0005433507052	8173	70	16A
0005432042742	8173	71	15F
0005435885357	8173	72	16B
0005435885366	8173	73	16C
0005433507057	8173	74	16E
0005432459992	8173	75	16D
0005432460015	8173	76	17A
0005435885355	8173	77	17B
0005432460020	8173	78	17E
0005435885337	8173	79	17D
0005433507148	8173	80	18A
0005435885359	8173	81	18B
0005432042739	8173	82	18D
0005435885361	8173	83	18C
0005435885347	8173	84	18E
0005432460012	8173	85	19B
0005432460008	8173	86	18F
0005435885362	8173	87	19C
0005433507066	8173	88	19D
0005432042745	8173	89	20B
0005435885365	8173	90	20C
0005435885328	8173	91	20D
0005432459982	8173	92	20F
0005435885329	8173	93	21B
0005432042749	8173	94	21E
0005435885335	8173	95	21F
0005432460019	8173	96	22B
0005433507111	8173	97	22A
0005435885358	8173	98	22D
0005432459984	8173	99	22E
0005432460024	8173	100	22F
0005435885364	8173	101	23B
0005432042750	8173	102	23A
0005432459998	8173	103	23D
0005435885339	8173	104	23E
0005432042746	8173	105	24A
0005432042747	8173	106	23F
0005435885350	8173	107	24B
0005432460014	8173	108	24C
0005433507013	8173	109	24E
0005432459989	8173	110	24D
0005432460022	8173	111	24F
0005432459993	8173	112	25A
0005433507089	8173	113	25C
0005432459977	8173	114	25E
0005435885334	8173	115	26B
0005435885354	8173	116	26C
0005433507077	8173	117	26E
0005435885367	8173	118	26D
0005435885352	8173	119	26F
0005432460001	8173	120	27A
0005432460002	8173	121	27C
0005435885332	8173	122	27F
0005435885369	8173	123	27E
0005432459979	8173	124	28B
0005432460018	8173	125	28D
0005432460007	8173	126	29A
0005432460013	8173	127	28F
0005432042740	8173	128	29B
0005435885333	8173	129	29C
0005432459972	8173	130	29D
0005433507030	8173	131	29E
0005432459985	8173	132	30A
0005433507065	8173	133	29F
0005432460005	8173	134	30B
0005432459975	8173	135	30C
0005432459974	8173	136	30E
0005435885321	8173	137	31A
0005435885336	8173	138	30F
0005432042744	8173	139	31B
0005432460017	8173	140	31D
0005435885360	8173	141	31F
0005435885331	8173	142	31E
0005434143718	8175	1	1C
0005433805167	8175	2	2F
0005433633626	8175	3	4A
0005433633604	8175	4	3F
0005433633627	8175	5	4C
0005433633429	8175	6	4F
0005433805207	8175	7	5C
0005433805022	8175	8	5D
0005433633488	8175	9	6D
0005433805222	8175	10	7D
0005433805324	8175	11	8A
0005433633524	8175	12	8B
0005433633454	8175	13	8E
0005433633583	8175	14	9A
0005433805141	8175	15	8F
0005433805162	8175	16	9D
0005433633648	8175	17	9F
0005433805173	8175	18	10F
0005433805206	8175	19	11C
0005433633382	8175	20	11E
0005433633489	8175	21	12F
0005433805154	8175	22	13B
0005433633564	8175	23	13E
0005433805089	8175	24	13F
0005433633607	8175	25	14E
0005433805039	8175	26	16B
0005433805061	8175	27	16A
0005433633571	8175	28	16F
0005433633453	8175	29	17B
0005433633566	8175	30	17D
0005433805194	8175	31	17F
0005433633499	8175	32	18A
0005433633625	8175	33	18E
0005433805163	8175	34	19B
0005433805245	8175	35	20A
0005433633438	8175	36	20B
0005434271299	8175	37	21D
0005433633487	8175	38	21C
0005433805244	8175	39	22C
0005433633565	8175	40	22F
0005433805155	8175	41	22E
0005433633495	8175	42	23A
0005433633506	8175	43	23D
0005433805062	8175	44	24C
0005433805164	8175	45	24E
0005433805142	8175	46	24D
0005433633563	8175	47	24F
0005433633507	8175	48	25A
0005433805205	8175	49	25D
0005433805166	8175	50	26B
0005433805023	8175	51	26D
0005433805082	8175	52	26E
0005433633669	8175	53	27A
0005433633630	8175	54	27B
0005433633562	8175	55	27D
0005434271291	8175	56	27F
0005433633557	8175	57	28D
0005433633508	8175	58	29B
0005433805165	8175	59	29C
0005433805157	8175	60	30B
0005433805172	8175	61	30A
0005434271304	8175	62	30C
0005434271300	8175	63	31A
0005433805081	8175	64	30F
0005433805243	8175	65	31B
0005433633523	8175	66	31C
0005433805011	8175	67	31D
0005433633555	8175	68	31F
0005434183565	8180	1	1F
0005434183556	8180	2	24E
0005434183564	8180	3	28D
0005432383242	4596	1	1A
0005432383255	4596	2	1D
0005432383270	4596	3	2A
0005432727961	4596	4	2C
0005432383268	4596	5	2D
0005432383249	4596	6	3D
0005433722235	4596	7	3F
0005432383278	4596	8	4A
0005433722232	4596	9	4C
0005432383238	4596	10	4D
0005432383276	4596	11	5A
0005432727964	4596	12	5D
0005432383240	4596	13	5F
0005432383243	4596	14	6C
0005432727969	4596	15	6D
0005432727968	4596	16	6E
0005432383260	4596	17	6F
0005433722234	4596	18	7A
0005432727967	4596	19	7C
0005432383277	4596	20	8A
0005432383261	4596	21	8C
0005432727965	4596	22	8E
0005432383275	4596	23	8F
0005433722233	4596	24	9A
0005432727970	4596	25	9C
0005432383253	4596	26	9E
0005433453766	4596	27	10A
0005432383239	4596	28	10D
0005432383266	4596	29	10E
0005432383269	4596	30	10F
0005432727960	4596	31	11A
0005432383272	4596	32	11D
0005432383244	4596	33	11F
0005432383267	4596	34	12C
0005432383274	4596	35	12D
0005432383264	4596	36	12E
0005432383247	4596	37	13C
0005433454879	4596	38	13D
0005432383257	4596	39	13E
0005432383265	4596	40	14A
0005432383271	4596	41	14C
0005432383250	4596	42	14D
0005432727963	4596	43	14E
0005432383252	4596	44	15A
0005432383245	4596	45	15D
0005432383262	4596	46	15F
0005432383251	4596	47	16A
0005432383241	4596	48	16D
0005433722236	4596	49	16E
0005432727971	4596	50	16F
0005432727959	4596	51	17A
0005432383259	4596	52	17D
0005432383248	4596	53	18A
0005433453767	4596	54	18C
0005433454880	4596	55	18D
0005432383263	4596	56	18E
0005432727966	4596	57	18F
0005432383254	4596	58	19A
0005432727962	4596	59	19C
0005432383258	4596	60	19E
0005432383246	4596	61	20A
0005433453765	4596	62	20C
0005432383256	4596	63	20E
0005432383273	4596	64	20F
0005432382882	30133	1	1C
0005432382956	30133	2	1A
0005432382957	30133	3	1D
0005432382769	30133	4	1F
0005432382669	30133	5	2A
0005432382762	30133	6	2C
0005433722116	30133	7	2F
0005432382743	30133	8	3A
0005433722148	30133	9	4C
0005432382768	30133	10	4E
0005432382761	30133	11	4F
0005432727804	30133	12	5C
0005432382915	30133	13	5F
0005432382829	30133	14	6A
0005432727823	30133	15	6C
0005432382772	30133	16	6F
0005432382883	30133	17	7A
0005432382770	30133	18	7D
0005432382958	30133	19	7E
0005433722160	30133	20	8A
0005432382983	30133	21	8C
0005432382832	30133	22	8E
0005432382820	30133	23	8F
0005432727843	30133	24	9A
0005432382744	30133	25	9C
0005432382804	30133	26	9E
0005432382699	30133	27	9F
0005433194838	30133	28	10A
0005433722161	30133	29	10E
0005432382620	30133	30	11C
0005432727808	30133	31	11E
0005433722147	30133	32	12A
0005432382813	30133	33	12D
0005433451588	30133	34	12E
0005432382845	30133	35	12F
0005432727876	30133	36	13A
0005432382816	30133	37	13E
0005432382968	30133	38	13F
0005432382830	30133	39	14A
0005433722151	30133	40	14C
0005432382745	30133	41	14D
0005432382814	30133	42	15A
0005432727809	30133	43	15C
0005432382825	30133	44	15D
0005432382773	30133	45	15E
0005432382817	30133	46	15F
0005433722162	30133	47	16A
0005432382824	30133	48	16C
0005432382828	30133	49	16D
0005433453754	30133	50	16E
0005432382884	30133	51	16F
0005432382763	30133	52	17A
0005432727905	30133	53	17C
0005432382846	30133	54	17D
0005432382634	30133	55	17E
0005433453753	30133	56	17F
0005432382771	30133	57	18A
0005432727875	30133	58	18D
0005432382914	30133	59	18E
0005432727833	30133	60	18F
0005432382967	30133	61	19A
0005433451610	30133	62	19C
0005432382791	30133	63	19D
0005433722154	30133	64	19F
0005433722166	30133	65	20A
0005432727892	30133	66	20C
0005433194844	30133	67	20D
0005432727815	30133	68	20E
0005433722155	30133	69	20F
0005432924999	1758	1	1A
0005435529320	1758	2	1D
0005435529311	1758	3	2A
0005435529303	1758	4	2D
0005435529308	1758	5	2F
0005435541060	1758	6	3A
0005435529317	1758	7	3C
0005435529301	1758	8	3F
0005435541065	1758	9	4A
0005435529312	1758	10	4D
0005435541044	1758	11	4F
0005435529321	1758	12	5C
0005435541052	1758	13	5D
0005435541064	1758	14	5E
0005435541061	1758	15	5F
0005435529300	1758	16	6A
0005435529313	1758	17	6D
0005435541055	1758	18	6E
0005435541043	1758	19	6F
0005435529310	1758	20	7A
0005433516911	1758	21	7C
0005435529316	1758	22	8C
0005435541059	1758	23	8D
0005435541048	1758	24	8F
0005433516905	1758	25	9C
0005435529318	1758	26	9F
0005435529304	1758	27	10A
0005432925016	1758	28	10C
0005435529302	1758	29	10D
0005432925004	1758	30	10E
0005435529314	1758	31	11C
0005432925012	1758	32	11D
0005433516907	1758	33	11E
0005433516903	1758	34	11F
0005435541057	1758	35	12A
0005435529306	1758	36	12C
0005435541050	1758	37	12D
0005432294493	1758	38	12E
0005432925008	1758	39	12F
0005432925006	1758	40	13C
0005433516909	1758	41	13D
0005432294492	1758	42	13E
0005435541049	1758	43	13F
0005435529315	1758	44	14A
0005435541047	1758	45	14C
0005435529307	1758	46	14F
0005435541062	1758	47	15F
0005435529309	1758	48	16A
0005435541051	1758	49	16C
0005435541053	1758	50	16D
0005435541046	1758	51	17A
0005435529319	1758	52	17C
0005433516904	1758	53	17E
0005435541063	1758	54	17F
0005433516910	1758	55	18A
0005435529305	1758	56	18C
0005435541058	1758	57	18F
0005433516908	1758	58	19A
0005435541056	1758	59	19C
0005433516906	1758	60	19E
0005435541054	1758	61	20C
0005435541045	1758	62	20E
0005435540713	21978	1	1D
0005435540829	21978	2	1F
0005435540932	21978	3	2A
0005435517808	21978	4	2D
0005435517866	21978	5	3C
0005435540847	21978	6	3D
0005435540856	21978	7	3F
0005435517807	21978	8	4C
0005433516861	21978	9	4D
0005435540844	21978	10	4E
0005435540916	21978	11	5C
0005435517781	21978	12	5D
0005433516779	21978	13	5E
0005435540846	21978	14	5F
0005435540891	21978	15	6C
0005433516860	21978	16	6D
0005432925044	21978	17	6E
0005435540758	21978	18	6F
0005432925048	21978	19	7C
0005435540814	21978	20	7D
0005435540861	21978	21	7F
0005435540821	21978	22	8A
0005435517787	21978	23	8C
0005435540828	21978	24	8D
0005435540816	21978	25	8F
0005435517779	21978	26	9A
0005435540782	21978	27	9C
0005435540937	21978	28	9E
0005435540917	21978	29	10A
0005433516818	21978	30	10C
0005435540848	21978	31	10F
0005435540841	21978	32	11A
0005433516817	21978	33	11F
0005435517809	21978	34	12A
0005435540810	21978	35	12C
0005435517816	21978	36	12D
0005435540862	21978	37	13C
0005435517833	21978	38	13F
0005435517753	21978	39	14C
0005435517775	21978	40	14E
0005435540898	21978	41	14F
0005435517865	21978	42	15A
0005435540843	21978	43	15D
0005435517815	21978	44	15E
0005435540869	21978	45	15F
0005435540806	21978	46	16A
0005435540842	21978	47	16C
0005435540865	21978	48	17A
0005435517752	21978	49	17C
0005435540845	21978	50	17E
0005433516805	21978	51	18A
0005435540712	21978	52	18C
0005432925046	21978	53	18E
0005432925047	21978	54	19A
0005435517806	21978	55	19E
0005435517858	21978	56	19F
0005435540822	21978	57	20D
0005432925045	21978	58	20E
0005435517857	21978	59	20F
0005432839098	7386	1	1A
0005432839085	7386	2	1C
0005432839086	7386	3	1F
0005434458842	7386	4	2A
0005432839107	7386	5	2C
0005432823453	7386	6	2D
0005435252602	7386	7	3C
0005432839100	7386	8	3F
0005432839099	7386	9	4A
0005435252633	7386	10	4C
0005432839095	7386	11	4D
0005432839101	7386	12	4E
0005432823454	7386	13	4F
0005432839089	7386	14	5C
0005432839104	7386	15	5D
0005432839088	7386	16	5F
0005432839115	7386	17	6A
0005432839096	7386	18	6C
0005434458845	7386	19	6D
0005432839113	7386	20	6E
0005434458843	7386	21	6F
0005432839090	7386	22	7A
0005435252603	7386	23	7C
0005432073398	7386	24	7F
0005435252605	7386	25	8A
0005432073399	7386	26	8D
0005434458848	7386	27	8E
0005432839110	7386	28	8F
0005435252619	7386	29	9A
0005432839108	7386	30	9C
0005434458852	7386	31	9D
0005432073396	7386	32	10A
0005435252641	7386	33	10C
0005434458851	7386	34	10D
0005435491430	7386	35	10E
0005432839105	7386	36	10F
0005432839093	7386	37	11A
0005435252604	7386	38	11C
0005434458850	7386	39	11D
0005434458858	7386	40	11E
0005432839087	7386	41	11F
0005434458847	7386	42	12A
0005434458838	7386	43	12C
0005432839106	7386	44	12E
0005432839116	7386	45	12F
0005434458849	7386	46	13C
0005432841016	7386	47	13D
0005432839111	7386	48	14A
0005432839112	7386	49	14C
0005432839097	7386	50	14D
0005432839114	7386	51	14F
0005434458846	7386	52	15A
0005434458855	7386	53	15C
0005434458857	7386	54	15D
0005435252592	7386	55	15E
0005434458840	7386	56	16A
0005434458844	7386	57	16C
0005432839091	7386	58	16F
0005432839103	7386	59	17A
0005432839094	7386	60	17D
0005434458841	7386	61	18A
0005435252640	7386	62	18C
0005434458856	7386	63	18D
0005435252639	7386	64	18E
0005434458839	7386	65	18F
0005432839109	7386	66	19A
0005432841014	7386	67	19C
0005432839102	7386	68	19D
0005434458853	7386	69	19E
0005434458854	7386	70	19F
0005432841015	7386	71	20A
0005432073397	7386	72	20C
0005432839092	7386	73	20D
0005435491447	28900	1	1A
0005434458628	28900	2	1C
0005432839006	28900	3	1D
0005435252749	28900	4	1F
0005432823428	28900	5	2C
0005432838897	28900	6	2D
0005432001029	28900	7	2F
0005435252738	28900	8	3A
0005434458586	28900	9	3C
0005432838924	28900	10	3F
0005432838922	28900	11	4A
0005435252746	28900	12	4C
0005432838714	28900	13	4D
0005435252739	28900	14	4F
0005434458619	28900	15	5C
0005434458700	28900	16	5D
0005435252735	28900	17	5E
0005432838869	28900	18	5F
0005435252734	28900	19	6A
0005432838947	28900	20	6C
0005435252736	28900	21	6D
0005432838948	28900	22	6E
0005432838881	28900	23	6F
0005435252747	28900	24	7C
0005432838883	28900	25	7E
0005432838768	28900	26	8A
0005432838805	28900	27	8C
0005432838870	28900	28	8E
0005432838879	28900	29	8F
0005434458669	28900	30	9A
0005435252748	28900	31	9C
0005434458677	28900	32	9D
0005434458727	28900	33	9E
0005432838892	28900	34	9F
0005432838867	28900	35	10A
0005434458611	28900	36	10C
0005432001026	28900	37	10D
0005432838858	28900	38	10E
0005434458709	28900	39	10F
0005434458680	28900	40	11C
0005432838920	28900	41	11D
0005432838921	28900	42	11E
0005434458667	28900	43	11F
0005432838880	28900	44	12A
0005434458688	28900	45	12C
0005432838791	28900	46	12E
0005434458689	28900	47	12F
0005432838868	28900	48	13D
0005432838893	28900	49	13E
0005434458499	28900	50	13F
0005434458699	28900	51	14A
0005432001028	28900	52	14C
0005434664965	28900	53	14D
0005432838899	28900	54	14E
0005435252743	28900	55	14F
0005434458583	28900	56	15A
0005435252740	28900	57	15C
0005434458711	28900	58	15D
0005435491445	28900	59	15E
0005435252737	28900	60	15F
0005432838746	28900	61	16A
0005434458710	28900	62	16C
0005432838886	28900	63	16E
0005432838857	28900	64	16F
0005432838898	28900	65	17A
0005435252750	28900	66	17C
0005432001027	28900	67	17D
0005435252745	28900	68	17E
0005432838856	28900	69	17F
0005434458636	28900	70	18A
0005432838923	28900	71	18C
0005435252751	28900	72	18D
0005432838953	28900	73	18E
0005432838866	28900	74	18F
0005434458631	28900	75	19A
0005435252741	28900	76	19C
0005435252742	28900	77	19E
0005435491446	28900	78	19F
0005434458678	28900	79	20C
0005432838800	28900	80	20D
0005432838882	28900	81	20E
0005435252744	28900	82	20F
0005435990635	8773	1	6A
0005435990638	8773	2	8D
0005435990641	8773	3	8F
0005435990639	8773	4	10E
0005434275999	8773	5	13A
0005435990636	8773	6	19B
0005435990640	8773	7	19D
0005435990637	8773	8	20E
0005435990578	15725	1	1C
0005434276038	15725	2	3C
0005434276037	15725	3	4C
0005435990605	15725	4	6E
0005434276040	15725	5	9A
0005435990558	15725	6	10D
0005435990572	15725	7	12B
0005435990557	15725	8	12E
0005434276041	15725	9	15B
0005435990568	15725	10	15A
0005434276039	15725	11	16C
0005435990571	15725	12	19A
0005433468358	2089	1	1A
0005432909227	2089	2	1B
0005432909245	2089	3	1D
0005432909233	2089	4	2A
0005432909244	2089	5	2B
0005433468360	2089	6	2D
0005432909254	2089	7	3A
0005433468345	2089	8	3B
0005432909243	2089	9	3C
0005433468355	2089	10	3D
0005432909241	2089	11	4A
0005433468354	2089	12	4B
0005433468341	2089	13	4C
0005432909249	2089	14	5B
0005433468348	2089	15	5C
0005433468340	2089	16	5D
0005432909236	2089	17	6A
0005432909242	2089	18	6B
0005432909240	2089	19	6C
0005433468359	2089	20	7A
0005433468343	2089	21	6D
0005433468344	2089	22	7B
0005433468357	2089	23	7C
0005433468336	2089	24	7D
0005433468352	2089	25	18B
0005433468346	2089	26	18C
0005432909235	2089	27	18D
0005432909237	2089	28	19A
0005432909239	2089	29	19B
0005433468356	2089	30	19C
0005432909234	2089	31	19D
0005432909221	2089	32	20A
0005433468361	2089	33	20B
0005433468342	2089	34	20C
0005433468338	2089	35	20D
0005432909253	2089	36	21B
0005433468337	2089	37	21A
0005433468351	2089	38	21C
0005433468339	2089	39	21D
0005433468349	2089	40	22A
0005433468353	2089	41	22B
0005433468347	2089	42	22C
0005432909231	2089	43	22D
0005432909264	2089	44	23A
0005433468350	2089	45	23B
0005435490208	6388	1	1A
0005435176836	6388	2	1D
0005435176831	6388	3	1F
0005434149687	6388	4	2C
0005432360451	6388	5	3A
0005434149614	6388	6	2F
0005434149670	6388	7	3D
0005432360441	6388	8	3C
0005435723025	6388	9	3F
0005432360475	6388	10	4A
0005435176987	6388	11	4C
0005434149671	6388	12	4B
0005432363425	6388	13	4E
0005432360462	6388	14	4F
0005432360454	6388	15	5A
0005435176918	6388	16	5C
0005432360463	6388	17	5B
0005434149638	6388	18	5D
0005434149587	6388	19	5E
0005432360469	6388	20	6A
0005432360467	6388	21	5F
0005432360446	6388	22	6C
0005432360457	6388	23	6B
0005434149652	6388	24	6E
0005435490204	6388	25	6F
0005432336055	6388	26	7B
0005435490205	6388	27	7A
0005434149605	6388	28	7C
0005432062242	6388	29	7E
0005435723026	6388	30	7D
0005432363423	6388	31	8A
0005435176985	6388	32	8B
0005432336054	6388	33	8C
0005432360474	6388	34	8D
0005435176945	6388	35	8F
0005434149676	6388	36	8E
0005435176926	6388	37	9A
0005432360449	6388	38	9B
0005432360476	6388	39	9D
0005434149606	6388	40	9C
0005435176928	6388	41	9E
0005432360458	6388	42	10B
0005435176946	6388	43	10C
0005432360455	6388	44	10E
0005435176887	6388	45	10D
0005432360444	6388	46	11A
0005432336064	6388	47	11B
0005432360465	6388	48	11D
0005432336061	6388	49	11C
0005434149658	6388	50	11E
0005432360450	6388	51	11F
0005432360452	6388	52	12A
0005432360461	6388	53	12C
0005432062238	6388	54	12B
0005432363424	6388	55	12D
0005432360484	6388	56	12E
0005432360466	6388	57	13A
0005434149639	6388	58	13B
0005432360485	6388	59	13D
0005432360473	6388	60	13C
0005435176919	6388	61	13E
0005432336065	6388	62	14A
0005435176843	6388	63	13F
0005435176997	6388	64	14C
0005432360460	6388	65	14B
0005432360489	6388	66	14D
0005432360445	6388	67	14E
0005434149673	6388	68	15A
0005434149613	6388	69	14F
0005435176962	6388	70	15B
0005432336063	6388	71	15C
0005432360479	6388	72	15D
0005435176895	6388	73	15F
0005432360481	6388	74	15E
0005432360472	6388	75	16A
0005435176984	6388	76	16B
0005432360486	6388	77	16C
0005432360480	6388	78	16D
0005432062239	6388	79	16E
0005432336062	6388	80	16F
0005434149710	6388	81	17B
0005432360453	6388	82	17A
0005434149686	6388	83	17C
0005432360442	6388	84	17E
0005435176948	6388	85	17D
0005434149657	6388	86	17F
0005432360443	6388	87	18A
0005432062240	6388	88	18B
0005432336058	6388	89	18D
0005432360468	6388	90	18C
0005435490221	6388	91	18F
0005435176886	6388	92	18E
0005432360477	6388	93	19A
0005432336056	6388	94	19B
0005435176866	6388	95	19D
0005432360456	6388	96	19C
0005432336057	6388	97	19E
0005434149659	6388	98	19F
0005432360447	6388	99	20A
0005432360478	6388	100	20C
0005435176876	6388	101	20B
0005432360470	6388	102	20E
0005432336053	6388	103	20D
0005435723027	6388	104	20F
0005435176947	6388	105	21A
0005432360487	6388	106	21C
0005432360448	6388	107	21B
0005432360488	6388	108	21D
0005432360464	6388	109	21F
0005432360459	6388	110	21E
0005435176986	6388	111	22B
0005434149653	6388	112	22A
0005434149615	6388	113	22C
0005435176927	6388	114	22D
0005434149701	6388	115	22F
0005432336059	6388	116	22E
0005432336060	6388	117	23B
0005435176949	6388	118	23A
0005432360482	6388	119	23C
0005432062241	6388	120	23E
0005432360483	6388	121	23D
0005432360471	6388	122	23F
0005434149749	20994	1	1A
0005435177140	20994	2	1D
0005432359970	20994	3	2A
0005432360081	20994	4	1F
0005432336002	20994	5	2C
0005435490240	20994	6	2D
0005435723051	20994	7	2F
0005435177133	20994	8	3C
0005435177146	20994	9	3A
0005432360017	20994	10	3D
0005435177130	20994	11	3F
0005432360186	20994	12	4A
0005432359959	20994	13	4B
0005432360188	20994	14	4D
0005435723050	20994	15	4E
0005435177147	20994	16	5A
0005435177125	20994	17	5B
0005435177141	20994	18	5D
0005432360045	20994	19	5C
0005432052752	20994	20	5E
0005435177123	20994	21	6A
0005432360083	20994	22	5F
0005432360182	20994	23	6B
0005434149750	20994	24	6C
0005432360189	20994	25	6D
0005432360126	20994	26	6F
0005432359994	20994	27	6E
0005432359920	20994	28	7B
0005432360062	20994	29	7A
0005432360108	20994	30	7C
0005432359997	20994	31	7E
0005432359982	20994	32	7F
0005435177127	20994	33	8A
0005435177144	20994	34	8B
0005432360228	20994	35	8C
0005434149759	20994	36	8E
0005435177138	20994	37	9A
0005432360187	20994	38	8F
0005432359951	20994	39	9C
0005435177122	20994	40	9B
0005432360180	20994	41	9E
0005432360184	20994	42	9D
0005434149758	20994	43	10B
0005435177139	20994	44	10C
0005435177131	20994	45	10D
0005432360054	20994	46	11A
0005434149755	20994	47	11B
0005434149754	20994	48	11C
0005435177142	20994	49	11E
0005432360227	20994	50	12A
0005435177120	20994	51	12D
0005434149760	20994	52	12C
0005432335955	20994	53	13A
0005434149753	20994	54	13B
0005432360226	20994	55	13D
0005432052753	20994	56	13C
0005432360190	20994	57	13E
0005435177129	20994	58	13F
0005432360015	20994	59	14C
0005435490239	20994	60	14E
0005432363389	20994	61	14F
0005432360181	20994	62	15A
0005435177137	20994	63	15C
0005435177148	20994	64	16C
0005432360082	20994	65	16B
0005435177136	20994	66	16E
0005432360046	20994	67	16F
0005435723052	20994	68	17B
0005432359995	20994	69	17A
0005432359985	20994	70	17D
0005432359948	20994	71	17C
0005432359930	20994	72	17E
0005434149757	20994	73	18C
0005435177145	20994	74	18B
0005435177128	20994	75	18D
0005435177135	20994	76	18F
0005432335990	20994	77	19A
0005435177143	20994	78	19B
0005432335951	20994	79	19D
0005434149751	20994	80	19E
0005432360159	20994	81	20B
0005432359971	20994	82	20E
0005432359953	20994	83	20F
0005432335994	20994	84	21A
0005435490238	20994	85	21D
0005435177121	20994	86	21C
0005432052751	20994	87	21E
0005432360099	20994	88	22A
0005435177132	20994	89	21F
0005434149752	20994	90	22C
0005432360122	20994	91	22E
0005434149756	20994	92	22D
0005435177124	20994	93	23A
0005435490237	20994	94	23B
0005432359952	20994	95	23C
0005432360000	20994	96	23D
0005435177126	20994	97	23F
0005435177134	20994	98	23E
0005434458726	17730	1	1A
0005434448293	17730	2	1C
0005434186206	17730	3	2A
0005434458731	17730	4	2B
0005434458782	17730	5	2D
0005434458719	17730	6	3A
0005434186207	17730	7	3B
0005434458737	17730	8	3C
0005434458666	17730	9	4A
0005434458762	17730	10	3D
0005434458720	17730	11	4B
0005434458725	17730	12	4C
0005434448280	17730	13	4D
0005434458686	17730	14	5A
0005434458761	17730	15	5B
0005434448287	17730	16	5C
0005434448294	17730	17	5D
0005434448306	17730	18	6A
0005434458703	17730	19	6B
0005434461637	17730	20	6C
0005434458645	17730	21	7A
0005434458760	17730	22	7B
0005434186205	17730	23	7C
0005434458732	17730	24	7D
0005434458788	17730	25	18A
0005434458629	17730	26	18B
0005434458713	17730	27	18C
0005434186204	17730	28	19A
0005434461635	17730	29	19C
0005434458630	17730	30	19D
0005434458687	17730	31	20A
0005434458693	17730	32	20B
0005434458712	17730	33	20D
0005434458791	17730	34	21A
0005434461636	17730	35	21B
0005434463924	17730	36	21C
0005434458781	17730	37	21D
0005434458704	17730	38	22C
0005434458646	17730	39	23A
0005434448282	17730	40	23B
0005434458849	29095	1	1C
0005434448320	29095	2	2A
0005434458839	29095	3	2B
0005434448319	29095	4	3C
0005434458845	29095	5	4B
0005434458841	29095	6	5B
0005434458856	29095	7	5C
0005434458854	29095	8	6A
0005434458857	29095	9	6C
0005434458846	29095	10	6B
0005434458858	29095	11	6D
0005434186179	29095	12	7A
0005434458843	29095	13	7B
0005434448318	29095	14	18A
0005434448317	29095	15	18B
0005434458848	29095	16	18D
0005434463931	29095	17	19B
0005434458844	29095	18	19C
0005434458855	29095	19	19D
0005434458838	29095	20	20A
0005434458852	29095	21	20B
0005434458850	29095	22	20C
0005434463933	29095	23	20D
0005434458840	29095	24	21B
0005434458851	29095	25	21C
0005434463932	29095	26	21D
0005434462793	29095	27	22A
0005434458842	29095	28	22B
0005434458847	29095	29	22D
0005434186172	29095	30	23A
0005434458853	29095	31	23B
0005432604394	21447	1	1A
0005432604372	21447	2	1B
0005432604383	21447	3	1C
0005432604387	21447	4	1D
0005432604404	21447	5	2A
0005432604390	21447	6	2B
0005432604388	21447	7	2C
0005432604373	21447	8	3A
0005432604402	21447	9	3B
0005432604399	21447	10	3D
0005432604377	21447	11	4B
0005432604386	21447	12	4D
0005432604389	21447	13	5A
0005432604406	21447	14	5B
0005432604382	21447	15	5D
0005432604401	21447	16	6C
0005432604405	21447	17	7A
0005432604379	21447	18	7C
0005432604403	21447	19	7B
0005432604378	21447	20	7D
0005432604407	21447	21	18A
0005432604410	21447	22	18B
0005432604397	21447	23	18C
0005432604411	21447	24	18D
0005432604395	21447	25	19A
0005432604374	21447	26	19B
0005432604393	21447	27	19C
0005432604398	21447	28	19D
0005432604409	21447	29	20A
0005432604384	21447	30	20B
0005432604400	21447	31	20C
0005432604392	21447	32	20D
0005432604375	21447	33	21A
0005432604396	21447	34	21C
0005432604376	21447	35	21D
0005432604385	21447	36	22A
0005432604391	21447	37	22B
0005432604408	21447	38	22C
0005432604381	21447	39	22D
0005432604380	21447	40	23B
0005432603869	31677	1	1A
0005432603930	31677	2	1B
0005432604168	31677	3	1D
0005435221054	31677	4	2B
0005432604055	31677	5	2A
0005432604154	31677	6	2C
0005432603987	31677	7	2D
0005432604029	31677	8	3A
0005432604167	31677	9	3B
0005432603967	31677	10	3C
0005432604047	31677	11	3D
0005432604031	31677	12	4A
0005432604060	31677	13	4B
0005432604179	31677	14	4D
0005432604030	31677	15	5A
0005432604146	31677	16	5B
0005435221516	31677	17	5D
0005432604059	31677	18	6A
0005432604032	31677	19	6B
0005432604043	31677	20	6C
0005432604054	31677	21	6D
0005435221056	31677	22	7A
0005432603960	31677	23	7B
0005432604074	31677	24	7C
0005432604056	31677	25	7D
0005432603974	31677	26	18A
0005432603955	31677	27	18B
0005432604143	31677	28	18D
0005432603966	31677	29	19A
0005432603905	31677	30	19B
0005432604153	31677	31	19D
0005432604018	31677	32	20B
0005432604042	31677	33	20C
0005432603983	31677	34	21A
0005432604041	31677	35	21B
0005435221055	31677	36	21D
0005432604009	31677	37	22A
0005432603959	31677	38	22B
0005432604226	31677	39	22C
0005432603984	31677	40	22D
0005432604201	31677	41	23A
0005432603973	31677	42	23B
0005434606795	18819	1	1A
0005434606797	18819	2	1B
0005434606796	18819	3	3A
0005435904896	18819	4	4B
0005435904897	18819	5	5A
0005434606809	18819	6	5B
0005434606833	22325	1	1B
0005434606831	22325	2	2A
0005435904892	22325	3	2B
0005434604902	22325	4	3A
0005435904891	22325	5	4A
0005434604900	22325	6	4B
0005434606832	22325	7	5A
0005434604901	22325	8	5B
0005434604903	22325	9	6A
0005432747631	397	1	7A
0005432747622	397	2	1C
0005432890933	397	3	1A
0005432890852	397	4	2A
0005432747627	397	5	2C
0005433293222	397	6	2D
0005432890872	397	7	2F
0005432890937	397	8	3A
0005432753303	397	9	3C
0005432747624	397	10	3F
0005432747650	397	11	4C
0005432890936	397	12	4E
0005432890853	397	13	4F
0005432753305	397	14	5A
0005432747628	397	15	5C
0005432747646	397	16	5D
0005432747649	397	17	6A
0005432747620	397	18	6D
0005432747637	397	19	6E
0005432747626	397	20	6F
0005432747633	397	21	7C
0005432751531	397	22	7D
0005432890909	397	23	7E
0005432747621	397	24	7F
0005432747648	397	25	8A
0005432220010	397	26	8C
0005432220011	397	27	8D
0005432890870	397	28	8E
0005432890883	397	29	9A
0005432747651	397	30	9C
0005432753306	397	31	9D
0005432747639	397	32	9F
0005432749788	397	33	10A
0005432747615	397	34	10C
0005432747636	397	35	10D
0005432747641	397	36	10E
0005432890849	397	37	10F
0005432753304	397	38	11A
0005432890911	397	39	11D
0005432747614	397	40	11C
0005432747629	397	41	11E
0005432747632	397	42	11F
0005432747623	397	43	12A
0005432890829	397	44	12C
0005432747640	397	45	12D
0005433293223	397	46	12E
0005432747642	397	47	13C
0005432747630	397	48	13D
0005432747625	397	49	13E
0005432890862	397	50	13F
0005432747616	397	51	14C
0005432890931	397	52	14D
0005432747619	397	53	14E
0005432747635	397	54	15A
0005432747652	397	55	15D
0005432747644	397	56	15F
0005432747638	397	57	16A
0005432747634	397	58	16C
0005432747618	397	59	16D
0005435627120	397	60	16E
0005435627119	397	61	16F
0005432890971	397	62	17C
0005432747645	397	63	17D
0005433293204	397	64	18A
0005432890851	397	65	18C
0005432747617	397	66	18D
0005433293203	397	67	18F
0005432749787	397	68	19A
0005432220012	397	69	19C
0005432747643	397	70	19D
0005432890934	397	71	19E
0005432890908	397	72	20C
0005432890871	397	73	20D
0005432747647	397	74	20F
0005432753272	12081	1	1A
0005432891063	12081	2	1C
0005432747365	12081	3	1D
0005432747134	12081	4	1F
0005433293260	12081	5	2A
0005433293259	12081	6	2C
0005433293255	12081	7	2D
0005432891052	12081	8	2F
0005432891055	12081	9	3A
0005432747294	12081	10	3C
0005432747387	12081	11	3D
0005432747269	12081	12	3F
0005432891053	12081	13	4A
0005432891061	12081	14	4C
0005432747336	12081	15	4D
0005432749774	12081	16	4E
0005432753269	12081	17	4F
0005433293261	12081	18	5A
0005433293256	12081	19	5C
0005432753296	12081	20	5D
0005433293254	12081	21	5E
0005432214808	12081	22	5F
0005432747211	12081	23	6A
0005432747103	12081	24	6C
0005432747316	12081	25	6D
0005432747355	12081	26	6E
0005433875384	12081	27	6F
0005433293264	12081	28	7A
0005432891059	12081	29	7C
0005432747227	12081	30	7D
0005432753265	12081	31	7E
0005432747102	12081	32	7F
0005432747317	12081	33	8A
0005432891062	12081	34	8C
0005432891060	12081	35	8D
0005432747193	12081	36	8E
0005432891067	12081	37	8F
0005432747304	12081	38	9A
0005432747315	12081	39	9C
0005433293252	12081	40	9D
0005432749772	12081	41	9E
0005432747354	12081	42	9F
0005432747260	12081	43	10A
0005433293263	12081	44	10C
0005433293253	12081	45	10D
0005432891065	12081	46	10E
0005432747222	12081	47	10F
0005432891064	12081	48	11A
0005432747390	12081	49	11C
0005432756829	12081	50	11D
0005432891054	12081	51	11E
0005432747308	12081	52	11F
0005432747413	12081	53	12A
0005432747353	12081	54	12C
0005432747295	12081	55	12D
0005432747448	12081	56	12E
0005432749773	12081	57	12F
0005432891058	12081	58	13A
0005432747147	12081	59	13C
0005433293262	12081	60	13D
0005432747182	12081	61	13E
0005432747303	12081	62	13F
0005432747428	12081	63	14C
0005432747391	12081	64	14D
0005432747318	12081	65	14E
0005432747133	12081	66	14F
0005432747397	12081	67	15A
0005432214809	12081	68	15C
0005432747380	12081	69	15D
0005432747243	12081	70	15E
0005432747402	12081	71	15F
0005432891050	12081	72	16A
0005433293258	12081	73	16C
0005432747259	12081	74	16D
0005432214807	12081	75	16E
0005433875383	12081	76	16F
0005432747258	12081	77	17A
0005432753271	12081	78	17C
0005432747364	12081	79	17D
0005432891066	12081	80	17E
0005432891057	12081	81	17F
0005432891056	12081	82	18A
0005432747384	12081	83	18C
0005432747412	12081	84	18D
0005432891051	12081	85	18E
0005432891068	12081	86	19A
0005432747219	12081	87	19C
0005432747224	12081	88	19D
0005433293257	12081	89	19E
0005432747192	12081	90	19F
0005432747587	12081	91	20A
0005432747340	12081	92	20C
0005432891069	12081	93	20D
0005432747237	12081	94	20E
0005432747411	12081	95	20F
0005433525048	18968	1	1A
0005433525055	18968	2	1B
0005433533313	18968	3	1D
0005433525046	18968	4	2A
0005433531297	18968	5	2C
0005432927925	18968	6	3D
0005433525050	18968	7	4B
0005433525054	18968	8	6A
0005433531298	18968	9	6B
0005433531300	18968	10	6D
0005432927981	18968	11	7A
0005433525057	18968	12	18C
0005433525051	18968	13	18D
0005433531299	18968	14	19B
0005433525047	18968	15	19C
0005432927936	18968	16	20B
0005433533311	18968	17	20D
0005433525052	18968	18	21B
0005433531296	18968	19	21C
0005433525053	18968	20	21D
0005433533310	18968	21	22A
0005433533312	18968	22	22B
0005433531295	18968	23	22C
0005433525049	18968	24	22D
0005433525056	18968	25	23A
0005433524959	32460	1	1B
0005433531259	32460	2	1D
0005432927997	32460	3	2C
0005433531265	32460	4	2D
0005433527214	32460	5	3B
0005433531268	32460	6	3C
0005433524958	32460	7	3D
0005433524964	32460	8	4B
0005433531260	32460	9	4C
0005432927996	32460	10	5D
0005433531272	32460	11	6B
0005433524977	32460	12	6C
0005433531271	32460	13	7A
0005433524960	32460	14	7C
0005433527220	32460	15	7D
0005433531258	32460	16	18B
0005433527226	32460	17	18C
0005433531267	32460	18	18D
0005432927995	32460	19	20A
0005432927998	32460	20	20B
0005433524961	32460	21	20C
0005433524963	32460	22	21A
0005433524962	32460	23	21D
0005433524997	32460	24	22C
0005432927999	32460	25	23A
0005434831158	5293	1	1C
0005435150065	5293	2	1G
0005434558290	5293	3	1D
0005434823801	5293	4	1H
0005434823785	5293	5	2D
0005435372777	5293	6	2C
0005434823898	5293	7	2A
0005435372698	5293	8	2H
0005432121360	5293	9	2G
0005434823814	5293	10	3A
0005435304125	5293	11	2K
0005434823853	5293	12	3D
0005434823908	5293	13	3C
0005434823813	5293	14	3K
0005434823840	5293	15	3H
0005435372863	5293	16	3G
0005434558291	5293	17	4C
0005434828700	5293	18	4G
0005434823802	5293	19	5A
0005435372730	5293	20	4K
0005434823871	5293	21	4H
0005434823822	5293	22	5D
0005434823794	5293	23	5C
0005435372981	5293	24	5H
0005434823779	5293	25	5G
0005432394110	5293	26	11E
0005435372812	5293	27	11D
0005434823903	5293	28	11C
0005434823786	5293	29	11F
0005435386505	5293	30	11H
0005434823869	5293	31	11G
0005435372714	5293	32	12C
0005432121361	5293	33	12A
0005435372649	5293	34	11K
0005435372574	5293	35	12E
0005434823811	5293	36	12D
0005434823854	5293	37	12H
0005435661904	5293	38	12G
0005434823823	5293	39	12F
0005434823838	5293	40	13D
0005435386518	5293	41	13C
0005435373023	5293	42	13E
0005434823873	5293	43	13H
0005435372902	5293	44	13K
0005432396249	5293	45	14C
0005432121370	5293	46	14G
0005434823844	5293	47	14F
0005435372840	5293	48	15C
0005434823864	5293	49	15A
0005434823858	5293	50	15F
0005434823846	5293	51	15E
0005434558298	5293	52	15D
0005435372784	5293	53	15H
0005435372971	5293	54	15K
0005434823805	5293	55	16D
0005434823816	5293	56	16C
0005434823850	5293	57	16A
0005435735103	5293	58	16F
0005435372731	5293	59	16E
0005434823852	5293	60	16K
0005432396253	5293	61	16G
0005434823791	5293	62	17C
0005435372852	5293	63	17E
0005435372970	5293	64	17D
0005435150057	5293	65	17G
0005435372849	5293	66	17F
0005434823819	5293	67	17K
0005434823867	5293	68	17H
0005434823835	5293	69	18C
0005434823798	5293	70	18B
0005434823799	5293	71	18E
0005434823778	5293	72	18D
0005434558295	5293	73	18H
0005434831157	5293	74	19A
0005434823800	5293	75	18K
0005434823796	5293	76	19D
0005434823792	5293	77	19F
0005434558301	5293	78	19E
0005434823882	5293	79	19G
0005435372842	5293	80	19K
0005434823841	5293	81	20B
0005434823899	5293	82	20A
0005434823891	5293	83	20D
0005434823897	5293	84	20H
0005434823807	5293	85	20J
0005434823782	5293	86	21B
0005435372758	5293	87	20K
0005435372868	5293	88	21D
0005435372922	5293	89	21C
0005434823894	5293	90	21F
0005434823880	5293	91	21E
0005432121364	5293	92	21G
0005434823817	5293	93	22A
0005434823856	5293	94	21K
0005432121366	5293	95	22B
0005434823906	5293	96	22F
0005435372914	5293	97	22E
0005434823839	5293	98	22G
0005432121368	5293	99	22J
0005435150052	5293	100	23A
0005435373144	5293	101	23D
0005435150060	5293	102	23C
0005435735104	5293	103	23G
0005435372776	5293	104	23F
0005435150053	5293	105	23E
0005434831155	5293	106	23H
0005434823892	5293	107	24D
0005434823886	5293	108	23K
0005435372725	5293	109	24F
0005434823780	5293	110	25B
0005434823783	5293	111	25A
0005434823793	5293	112	24G
0005434823889	5293	113	25D
0005435372702	5293	114	25C
0005434823818	5293	115	25E
0005434823812	5293	116	25H
0005435372783	5293	117	25G
0005432121365	5293	118	25K
0005435372771	5293	119	25J
0005435299731	5293	120	26C
0005435373038	5293	121	26H
0005434823905	5293	122	26K
0005435661897	5293	123	26J
0005435372751	5293	124	27B
0005434823834	5293	125	27A
0005434823862	5293	126	27C
0005434823887	5293	127	27F
0005434823826	5293	128	27D
0005434823855	5293	129	27H
0005435372781	5293	130	27G
0005432394111	5293	131	28A
0005434823810	5293	132	27J
0005435386543	5293	133	28B
0005435299746	5293	134	28D
0005435372775	5293	135	28C
0005432121359	5293	136	28G
0005434823901	5293	137	28F
0005434823865	5293	138	28K
0005435372980	5293	139	28H
0005434558293	5293	140	29B
0005434823815	5293	141	29A
0005435150055	5293	142	29D
0005435373050	5293	143	29C
0005432121362	5293	144	29E
0005435372862	5293	145	29G
0005432121367	5293	146	30B
0005434823833	5293	147	30A
0005434823821	5293	148	30D
0005432121369	5293	149	30G
0005435150063	5293	150	30J
0005434823820	5293	151	31B
0005434823797	5293	152	30K
0005434823884	5293	153	31D
0005434823828	5293	154	31F
0005435372877	5293	155	31E
0005435372853	5293	156	31H
0005434558302	5293	157	31G
0005434823860	5293	158	31K
0005435178987	5293	159	31J
0005435372841	5293	160	32B
0005435304142	5293	161	32E
0005432394113	5293	162	32D
0005435372653	5293	163	32H
0005434823832	5293	164	32G
0005435372831	5293	165	32F
0005434823877	5293	166	32K
0005434823824	5293	167	32J
0005435372729	5293	168	33B
0005434823845	5293	169	33A
0005435372956	5293	170	33D
0005435299732	5293	171	33F
0005434558296	5293	172	33K
0005432121358	5293	173	33J
0005435372881	5293	174	34C
0005434823795	5293	175	34B
0005434823787	5293	176	34D
0005434823883	5293	177	34G
0005435372982	5293	178	34J
0005435372489	5293	179	35B
0005435299734	5293	180	35D
0005434823888	5293	181	35F
0005434823857	5293	182	35E
0005435372774	5293	183	36A
0005434823809	5293	184	35K
0005434823863	5293	185	35J
0005435372923	5293	186	36C
0005434823836	5293	187	36B
0005434823895	5293	188	36E
0005435372655	5293	189	36D
0005435150054	5293	190	36G
0005435372904	5293	191	36H
0005434823874	5293	192	37B
0005432121363	5293	193	37D
0005435150058	5293	194	37C
0005434823837	5293	195	37H
0005435373055	5293	196	37G
0005435372882	5293	197	38A
0005434823830	5293	198	37J
0005435178985	5293	199	38C
0005434831159	5293	200	38B
0005434823789	5293	201	38J
0005432121357	5293	202	38H
0005435373117	5293	203	39B
0005435372869	5293	204	39A
0005434831156	5293	205	39D
0005434823803	5293	206	39C
0005435372715	5293	207	39F
0005434823848	5293	208	39G
0005434823831	5293	209	40A
0005432394112	5293	210	39K
0005434823790	5293	211	40C
0005434823843	5293	212	40B
0005435372740	5293	213	40E
0005434828701	5293	214	40D
0005434823829	5293	215	40G
0005434558289	5293	216	40F
0005434664964	5293	217	40K
0005434823847	5293	218	40J
0005435373039	5293	219	40H
0005434823859	5293	220	41B
0005434823879	5293	221	41A
0005435372895	5293	222	41C
0005434823808	5293	223	41F
0005432396250	5293	224	41E
0005435299737	5293	225	42B
0005434558297	5293	226	42E
0005435304134	5293	227	42D
0005434823876	5293	228	42G
0005434823804	5293	229	42F
0005435150059	5293	230	42K
0005434558292	5293	231	42J
0005434823878	5293	232	42H
0005435372608	5293	233	43A
0005435372969	5293	234	43C
0005435386532	5293	235	43B
0005435150061	5293	236	43D
0005435150056	5293	237	44C
0005434823827	5293	238	44A
0005435372757	5293	239	44D
0005434823784	5293	240	44F
0005434823788	5293	241	44J
0005435372609	5293	242	45B
0005435150062	5293	243	45A
0005435304126	5293	244	44K
0005435372663	5293	245	45F
0005432121356	5293	246	45D
0005435661903	5293	247	45H
0005432396252	5293	248	45G
0005434823851	5293	249	45K
0005434823893	5293	250	46C
0005435372674	5293	251	46E
0005435304124	5293	252	46D
0005434823890	5293	253	46G
0005434823868	5293	254	46F
0005434823902	5293	255	46K
0005435178988	5293	256	46J
0005432396251	5293	257	47E
0005434558300	5293	258	47D
0005434664963	5293	259	47C
0005434823781	5293	260	47G
0005434823881	5293	261	47F
0005434823900	5293	262	47K
0005435372977	5293	263	48C
0005434823907	5293	264	48F
0005435372547	5293	265	48E
0005434823825	5293	266	48D
0005434823861	5293	267	48H
0005434823872	5293	268	48G
0005434823866	5293	269	49C
0005434823904	5293	270	48K
0005435372976	5293	271	49G
0005434823849	5293	272	49F
0005434823875	5293	273	49K
0005435150064	5293	274	50C
0005434823896	5293	275	50A
0005434823885	5293	276	50E
0005435372673	5293	277	50H
0005435373063	5293	278	50G
0005434823870	5293	279	50F
0005434823842	5293	280	50K
0005434558294	5293	281	51F
0005434823806	5293	282	51E
0005434558299	5293	283	51D
0005434822675	9888	1	1A
0005434822391	9888	2	1G
0005435373397	9888	3	1K
0005434558199	9888	4	2C
0005434821987	9888	5	2A
0005434823111	9888	6	3A
0005435373399	9888	7	2K
0005434822704	9888	8	3D
0005435373392	9888	9	3C
0005434823018	9888	10	3K
0005434822638	9888	11	4C
0005434558203	9888	12	4D
0005432203075	9888	13	5A
0005435661937	9888	14	4K
0005435373424	9888	15	5C
0005434822850	9888	16	5G
0005434822656	9888	17	11A
0005434664948	9888	18	5K
0005434822589	9888	19	11E
0005434822600	9888	20	11D
0005435373377	9888	21	11C
0005434822708	9888	22	11G
0005434822813	9888	23	11F
0005434664933	9888	24	12C
0005435373396	9888	25	12A
0005435373406	9888	26	12E
0005434822411	9888	27	12D
0005435386585	9888	28	12G
0005434822849	9888	29	12F
0005435373382	9888	30	12H
0005435299787	9888	31	13D
0005435373391	9888	32	13A
0005434558218	9888	33	13F
0005435373414	9888	34	13H
0005434822998	9888	35	13G
0005435373401	9888	36	14A
0005435373370	9888	37	13K
0005435373413	9888	38	14D
0005434822538	9888	39	14F
0005434822791	9888	40	14H
0005434822546	9888	41	15A
0005434822480	9888	42	15E
0005435373365	9888	43	15D
0005434558197	9888	44	15G
0005434822996	9888	45	15F
0005435373426	9888	46	15K
0005434823278	9888	47	15H
0005434822020	9888	48	16C
0005435179396	9888	49	16E
0005434823202	9888	50	16H
0005435386583	9888	51	17C
0005435373375	9888	52	17A
0005435302207	9888	53	16K
0005434822888	9888	54	17D
0005434822765	9888	55	17H
0005435302206	9888	56	17G
0005434558186	9888	57	17F
0005435373427	9888	58	18A
0005434664941	9888	59	18B
0005434822616	9888	60	18E
0005435386580	9888	61	18D
0005434822792	9888	62	18C
0005435373412	9888	63	18G
0005434822693	9888	64	18J
0005434822506	9888	65	18H
0005434822733	9888	66	19A
0005434558212	9888	67	19D
0005434822899	9888	68	19C
0005434822755	9888	69	19F
0005434822991	9888	70	19H
0005434822390	9888	71	19G
0005434822623	9888	72	20C
0005434823141	9888	73	20B
0005435302209	9888	74	20A
0005435373386	9888	75	20F
0005435373393	9888	76	20K
0005435373407	9888	77	20H
0005435373387	9888	78	21A
0005435373420	9888	79	21D
0005434822293	9888	80	21C
0005434821587	9888	81	21F
0005434822843	9888	82	21E
0005435149971	9888	83	21H
0005435386586	9888	84	21G
0005434558213	9888	85	22D
0005435373400	9888	86	22C
0005434822764	9888	87	22B
0005435373368	9888	88	22F
0005434822117	9888	89	22E
0005434822244	9888	90	22H
0005434822786	9888	91	22K
0005435149909	9888	92	22J
0005434822862	9888	93	23B
0005434822473	9888	94	23A
0005434823041	9888	95	23D
0005434822797	9888	96	23F
0005434821973	9888	97	23J
0005435373421	9888	98	23G
0005434822822	9888	99	23K
0005434831093	9888	100	24E
0005435302208	9888	101	25B
0005434822502	9888	102	25D
0005434822916	9888	103	25C
0005434822321	9888	104	25F
0005432203078	9888	105	25E
0005434822953	9888	106	25J
0005434823186	9888	107	26A
0005434822848	9888	108	26E
0005432203080	9888	109	26D
0005434822821	9888	110	26J
0005434823234	9888	111	26H
0005434558216	9888	112	27A
0005435373374	9888	113	27D
0005434822545	9888	114	27B
0005435373419	9888	115	27F
0005432396202	9888	116	27E
0005435373389	9888	117	27G
0005435373415	9888	118	28A
0005434823198	9888	119	27K
0005434822498	9888	120	28E
0005435373379	9888	121	28C
0005435373390	9888	122	28G
0005434822307	9888	123	28F
0005434822021	9888	124	28J
0005434822192	9888	125	28H
0005434558175	9888	126	29D
0005435373373	9888	127	29C
0005434823168	9888	128	29B
0005435373417	9888	129	29F
0005434822517	9888	130	29E
0005434558217	9888	131	29G
0005432400108	9888	132	29K
0005434822496	9888	133	30B
0005434664934	9888	134	30A
0005435386581	9888	135	30E
0005435735145	9888	136	30D
0005435373367	9888	137	30G
0005435735146	9888	138	30F
0005434822505	9888	139	30J
0005434822753	9888	140	30H
0005432823455	9888	141	31B
0005435373404	9888	142	31A
0005434823280	9888	143	30K
0005434831097	9888	144	31C
0005435373378	9888	145	31F
0005434822915	9888	146	31E
0005434823255	9888	147	31D
0005432203079	9888	148	31J
0005434822412	9888	149	31H
0005434664947	9888	150	31G
0005435373422	9888	151	32A
0005434664945	9888	152	32E
0005434822554	9888	153	32G
0005435373416	9888	154	32F
0005434821996	9888	155	32K
0005434822584	9888	156	33A
0005434822984	9888	157	33D
0005435373371	9888	158	33E
0005434822873	9888	159	33J
0005434822516	9888	160	34A
0005434822643	9888	161	33K
0005435373361	9888	162	34C
0005434822724	9888	163	34B
0005435299783	9888	164	34D
0005434822403	9888	165	34G
0005435373411	9888	166	34F
0005435373408	9888	167	34H
0005434822864	9888	168	34K
0005434828667	9888	169	35E
0005434823096	9888	170	35C
0005435299786	9888	171	35B
0005435373363	9888	172	35F
0005435149853	9888	173	35H
0005435735144	9888	174	35G
0005434822466	9888	175	35K
0005434822707	9888	176	35J
0005434664946	9888	177	36C
0005434822905	9888	178	36B
0005434822555	9888	179	36F
0005435373395	9888	180	36D
0005432400092	9888	181	36H
0005434558191	9888	182	36K
0005435149906	9888	183	37B
0005434822766	9888	184	37A
0005434822295	9888	185	37F
0005434822191	9888	186	37E
0005434822134	9888	187	37H
0005434822356	9888	188	37K
0005435373380	9888	189	37J
0005434822221	9888	190	38C
0005434823299	9888	191	39B
0005434822914	9888	192	39A
0005435373423	9888	193	38K
0005435373385	9888	194	39D
0005435373372	9888	195	39C
0005434822874	9888	196	39F
0005435373381	9888	197	39H
0005435373398	9888	198	40A
0005434823266	9888	199	39J
0005434823148	9888	200	40E
0005435661936	9888	201	40D
0005434664944	9888	202	40G
0005434821997	9888	203	40J
0005435373362	9888	204	40H
0005435149962	9888	205	41A
0005435386579	9888	206	40K
0005434822700	9888	207	41D
0005434822481	9888	208	41F
0005434822274	9888	209	41E
0005435373383	9888	210	41H
0005435373425	9888	211	41G
0005434822585	9888	212	42A
0005434823229	9888	213	41K
0005435373409	9888	214	41J
0005434823146	9888	215	42C
0005435373410	9888	216	42B
0005434823254	9888	217	42G
0005435179696	9888	218	42H
0005434822756	9888	219	43A
0005434822220	9888	220	43D
0005432396203	9888	221	43C
0005435373366	9888	222	43B
0005434822674	9888	223	43F
0005435299784	9888	224	43E
0005435661938	9888	225	43J
0005435386582	9888	226	43H
0005434822639	9888	227	43G
0005434822472	9888	228	43K
0005434822842	9888	229	44A
0005432203077	9888	230	44E
0005435373369	9888	231	44D
0005434831133	9888	232	44G
0005435373394	9888	233	44J
0005434831114	9888	234	44H
0005434822694	9888	235	45B
0005435179395	9888	236	45C
0005434831116	9888	237	45F
0005434822871	9888	238	45E
0005435299785	9888	239	45D
0005434558200	9888	240	45H
0005432203074	9888	241	45G
0005434822599	9888	242	45K
0005435373364	9888	243	45J
0005432396211	9888	244	46C
0005435373402	9888	245	46B
0005435373376	9888	246	46D
0005434822467	9888	247	46G
0005435373403	9888	248	46F
0005434822128	9888	249	46J
0005434823045	9888	250	46H
0005434822830	9888	251	46K
0005435373418	9888	252	47D
0005434558211	9888	253	47C
0005434822812	9888	254	47G
0005434822877	9888	255	47F
0005432203076	9888	256	47E
0005435149910	9888	257	48A
0005435373405	9888	258	47K
0005432203081	9888	259	47H
0005434822863	9888	260	48C
0005435386584	9888	261	48E
0005434822275	9888	262	48H
0005434822934	9888	263	49A
0005434822489	9888	264	48K
0005434822844	9888	265	49D
0005434823097	9888	266	49C
0005435302205	9888	267	49E
0005434822421	9888	268	49H
0005435373388	9888	269	49G
0005434823171	9888	270	50C
0005434822810	9888	271	50A
0005434822732	9888	272	50F
0005435373384	9888	273	50D
0005435735147	9888	274	50H
0005434822294	9888	275	50G
0005434823235	9888	276	50K
0005434822190	9888	277	51D
0005435082798	7002	1	2D
0005435082801	7002	2	4A
0005435082800	7002	3	5A
0005435790312	7002	4	6A
0005435082802	7002	5	6C
0005435790311	7002	6	7D
0005435790314	7002	7	20A
0005435082795	7002	8	20B
0005435082796	7002	9	20C
0005435082803	7002	10	21A
0005435082799	7002	11	21C
0005435790313	7002	12	21D
0005435082797	7002	13	23B
0005435082744	26018	1	2D
0005435082725	26018	2	3B
0005435790281	26018	3	3C
0005435082729	26018	4	4A
0005435082719	26018	5	4B
0005435082750	26018	6	5A
0005435790287	26018	7	5C
0005435082710	26018	8	6C
0005435082749	26018	9	7C
0005435082733	26018	10	18D
0005435790294	26018	11	19A
0005435790288	26018	12	20A
0005435082748	26018	13	21C
0005435082732	26018	14	21D
0005434214335	9564	1	1A
0005434214358	9564	2	1D
0005434214349	9564	3	1F
0005434214030	9564	4	2C
0005434756499	9564	5	2D
0005434756480	9564	6	3A
0005434756485	9564	7	3D
0005434214072	9564	8	3F
0005434214235	9564	9	4C
0005434214041	9564	10	4D
0005434756498	9564	11	4E
0005434214097	9564	12	5A
0005434756490	9564	13	5C
0005434756492	9564	14	5F
0005434756491	9564	15	6A
0005434756509	9564	16	6E
0005434214130	9564	17	7D
0005434756508	9564	18	7F
0005434756504	9564	19	8A
0005434756489	9564	20	8C
0005434756478	9564	21	8D
0005434756483	9564	22	8E
0005434756507	9564	23	8F
0005434214299	9564	24	9A
0005434214272	9564	25	9C
0005434756484	9564	26	9E
0005434214119	9564	27	9F
0005434756511	9564	28	10A
0005434214068	9564	29	10C
0005434214096	9564	30	10E
0005434214236	9564	31	10F
0005434214192	9564	32	11C
0005434756488	9564	33	11D
0005434756486	9564	34	11E
0005434756474	9564	35	11F
0005434756476	9564	36	12A
0005434756514	9564	37	12D
0005434756500	9564	38	12E
0005434214189	9564	39	12F
0005434756495	9564	40	13C
0005434756512	9564	41	13D
0005434756505	9564	42	13E
0005434214054	9564	43	13F
0005434756506	9564	44	14C
0005434756482	9564	45	14D
0005434214291	9564	46	14E
0005434756470	9564	47	14F
0005434756479	9564	48	15A
0005434756502	9564	49	15C
0005434214069	9564	50	15D
0005434214187	9564	51	15E
0005434756503	9564	52	15F
0005434214271	9564	53	16A
0005434756494	9564	54	16C
0005434756477	9564	55	16D
0005434756472	9564	56	16E
0005434756473	9564	57	16F
0005434214254	9564	58	17A
0005434756513	9564	59	17D
0005434214066	9564	60	17F
0005434756496	9564	61	17E
0005434756497	9564	62	18C
0005434756493	9564	63	18D
0005434756487	9564	64	18E
0005434756481	9564	65	18F
0005434756510	9564	66	19D
0005434214237	9564	67	19F
0005434214188	9564	68	20A
0005434756501	9564	69	20C
0005434756475	9564	70	20D
0005434756471	9564	71	20E
0005434214243	9564	72	20F
0005434214586	28613	1	1A
0005434214599	28613	2	1C
0005434756055	28613	3	1D
0005434756106	28613	4	1F
0005434214560	28613	5	2A
0005434214562	28613	6	2C
0005434756174	28613	7	2D
0005434214566	28613	8	2F
0005434755835	28613	9	3A
0005434214585	28613	10	3D
0005434756025	28613	11	4A
0005434214590	28613	12	4C
0005434214558	28613	13	4D
0005434755993	28613	14	4E
0005434756109	28613	15	4F
0005434756184	28613	16	5A
0005434214576	28613	17	5C
0005434214577	28613	18	5D
0005434756128	28613	19	5E
0005434214572	28613	20	5F
0005434214559	28613	21	6C
0005434214601	28613	22	6D
0005434756111	28613	23	6E
0005434756057	28613	24	6F
0005434756158	28613	25	7A
0005434756110	28613	26	7C
0005434756039	28613	27	7D
0005434756024	28613	28	7E
0005434214582	28613	29	7F
0005434214568	28613	30	8A
0005434756054	28613	31	8C
0005434756136	28613	32	8D
0005434214570	28613	33	8E
0005434756264	28613	34	8F
0005434755916	28613	35	9A
0005434214567	28613	36	9C
0005434756007	28613	37	9D
0005434756053	28613	38	9E
0005434214583	28613	39	10A
0005434756067	28613	40	10C
0005434214561	28613	41	10D
0005434214581	28613	42	10E
0005434214557	28613	43	10F
0005434756129	28613	44	11A
0005434214593	28613	45	11C
0005434214579	28613	46	11D
0005434756164	28613	47	11E
0005434214596	28613	48	11F
0005434756185	28613	49	12A
0005434756068	28613	50	12C
0005434214564	28613	51	12D
0005434756134	28613	52	12E
0005434214588	28613	53	12F
0005434755913	28613	54	13A
0005434756097	28613	55	13C
0005434756038	28613	56	13D
0005434756170	28613	57	13E
0005434214600	28613	58	13F
0005434756103	28613	59	14A
0005434214594	28613	60	14C
0005434214573	28613	61	14E
0005434756026	28613	62	14D
0005434756003	28613	63	14F
0005434756056	28613	64	15A
0005434756146	28613	65	15C
0005434214597	28613	66	15D
0005434214592	28613	67	15E
0005434214591	28613	68	15F
0005434214571	28613	69	16A
0005434214598	28613	70	16C
0005434214580	28613	71	16D
0005434756010	28613	72	16E
0005434214584	28613	73	16F
0005434756211	28613	74	17A
0005434214595	28613	75	17C
0005434214589	28613	76	17D
0005434214565	28613	77	17E
0005434756047	28613	78	18C
0005434756168	28613	79	18A
0005434756087	28613	80	18D
0005434756009	28613	81	18E
0005434756227	28613	82	18F
0005434756163	28613	83	19A
0005434214587	28613	84	19C
0005434214569	28613	85	19E
0005434214574	28613	86	19F
0005434214575	28613	87	20A
0005434756159	28613	88	20C
0005434756112	28613	89	20D
0005434214563	28613	90	20E
0005434214578	28613	91	20F
0005435100130	10822	1	1A
0005435100129	10822	2	4B
0005435100128	10822	3	22B
0005434760203	31837	1	5B
0005435100116	31837	2	19D
0005435100095	31837	3	21D
0005434760202	31837	4	22A
0005434639384	1980	1	1A
0005434639389	1980	2	1B
0005433202259	1980	3	1D
0005434639369	1980	4	2A
0005432290640	1980	5	2B
0005434639386	1980	6	2C
0005434639382	1980	7	2D
0005434639371	1980	8	3A
0005433202325	1980	9	3B
0005434639378	1980	10	3C
0005434639390	1980	11	3D
0005433202324	1980	12	4A
0005434639379	1980	13	4B
0005433202283	1980	14	4C
0005434639380	1980	15	4D
0005434639375	1980	16	5A
0005434639373	1980	17	5B
0005434639367	1980	18	5C
0005433202278	1980	19	5D
0005434639370	1980	20	6B
0005433202229	1980	21	6A
0005432290641	1980	22	6C
0005434639383	1980	23	6D
0005434639388	1980	24	7B
0005434639385	1980	25	7C
0005435948329	1980	26	7D
0005434639392	1980	27	18A
0005433202279	1980	28	18C
0005432290642	1980	29	18D
0005434639387	1980	30	19B
0005434639391	1980	31	19C
0005434639393	1980	32	20A
0005434639377	1980	33	20B
0005434639374	1980	34	20D
0005433202195	1980	35	21A
0005434639381	1980	36	21B
0005434639376	1980	37	22A
0005434639368	1980	38	22B
0005434639372	1980	39	22C
0005432290639	1980	40	23A
0005433202387	23286	1	1A
0005434639051	23286	2	1B
0005434639121	23286	3	1C
0005434639285	23286	4	1D
0005434639195	23286	5	2A
0005433202376	23286	6	2B
0005433202377	23286	7	2C
0005434639212	23286	8	2D
0005434639208	23286	9	3A
0005434639179	23286	10	3B
0005434639139	23286	11	3C
0005433202382	23286	12	3D
0005434639053	23286	13	4A
0005434639070	23286	14	4D
0005434639054	23286	15	5A
0005435948318	23286	16	5B
0005434639093	23286	17	5D
0005434639147	23286	18	6A
0005434639176	23286	19	6B
0005433202383	23286	20	6C
0005433202381	23286	21	6D
0005434639207	23286	22	7A
0005434639180	23286	23	7B
0005434639197	23286	24	7C
0005433202385	23286	25	7D
0005433202386	23286	26	18A
0005434639090	23286	27	18B
0005433202374	23286	28	18C
0005433202378	23286	29	18D
0005434639124	23286	30	19B
0005433202388	23286	31	19C
0005434639094	23286	32	19D
0005434639284	23286	33	20A
0005434639058	23286	34	20B
0005433202379	23286	35	20C
0005434639129	23286	36	20D
0005434638969	23286	37	21A
0005434639181	23286	38	21B
0005433202375	23286	39	21C
0005433202380	23286	40	21D
0005433202384	23286	41	22A
0005434639140	23286	42	22C
0005435948319	23286	43	22D
0005434639142	23286	44	23B
0005435326664	6069	1	1F
0005434600859	6069	2	2C
0005433533314	6069	3	2D
0005434600864	6069	4	3A
0005435326636	6069	5	3D
0005434600862	6069	6	3F
0005433531301	6069	7	4A
0005432111286	6069	8	4C
0005434600856	6069	9	4F
0005434600871	6069	10	5A
0005435326679	6069	11	5C
0005435326604	6069	12	5D
0005433531302	6069	13	5F
0005435326680	6069	14	6A
0005434600861	6069	15	6D
0005434600852	6069	16	6E
0005434600860	6069	17	6F
0005432111285	6069	18	7A
0005435326643	6069	19	7E
0005434600854	6069	20	8C
0005435326655	6069	21	8D
0005435326675	6069	22	8E
0005435326642	6069	23	9C
0005433533315	6069	24	9D
0005434600872	6069	25	9E
0005434600877	6069	26	10A
0005434600851	6069	27	10E
0005434600873	6069	28	10F
0005435326668	6069	29	11A
0005435326667	6069	30	11D
0005432111284	6069	31	12C
0005434600868	6069	32	12E
0005434600855	6069	33	12F
0005434600869	6069	34	13A
0005435326640	6069	35	13D
0005434600858	6069	36	14E
0005434600866	6069	37	14F
0005433533316	6069	38	15A
0005434600870	6069	39	15D
0005434600867	6069	40	15F
0005435326641	6069	41	16A
0005434600853	6069	42	16D
0005434600874	6069	43	16E
0005435326656	6069	44	17A
0005435326658	6069	45	17D
0005433531303	6069	46	17E
0005435326647	6069	47	17F
0005435326637	6069	48	18A
0005434600863	6069	49	18C
0005435326666	6069	50	18D
0005434600865	6069	51	18F
0005434600857	6069	52	19A
0005435326676	6069	53	19C
0005434600876	6069	54	20A
0005433533317	6069	55	20C
0005434600875	6069	56	20F
0005433527225	18573	1	1A
0005434600645	18573	2	1C
0005435326768	18573	3	1D
0005434600652	18573	4	1F
0005434600674	18573	5	2A
0005434600575	18573	6	2C
0005435326770	18573	7	3C
0005434600609	18573	8	3F
0005433531263	18573	9	4C
0005434600610	18573	10	4D
0005433531269	18573	11	4E
0005433531252	18573	12	4F
0005433531270	18573	13	5C
0005434600521	18573	14	5D
0005434600608	18573	15	5F
0005435326775	18573	16	6C
0005434600706	18573	17	6E
0005434600625	18573	18	7E
0005433531274	18573	19	7F
0005434600584	18573	20	8E
0005434600705	18573	21	8F
0005434600605	18573	22	9D
0005434600604	18573	23	9E
0005433531264	18573	24	9F
0005435326772	18573	25	10C
0005433527223	18573	26	10D
0005435326776	18573	27	11A
0005435326766	18573	28	11C
0005434600653	18573	29	11F
0005433531255	18573	30	12A
0005435326771	18573	31	12D
0005434600558	18573	32	12E
0005434600542	18573	33	12F
0005434600564	18573	34	13C
0005435326769	18573	35	13E
0005435326773	18573	36	13F
0005434600716	18573	37	14A
0005435326778	18573	38	14C
0005434600643	18573	39	14E
0005435326780	18573	40	14F
0005434600630	18573	41	15A
0005434600541	18573	42	15D
0005434600606	18573	43	16A
0005435326774	18573	44	16E
0005433531253	18573	45	16F
0005435326777	18573	46	17D
0005433527224	18573	47	17E
0005435326779	18573	48	17F
0005434600512	18573	49	18A
0005434600524	18573	50	18E
0005433527222	18573	51	18F
0005433527216	18573	52	19D
0005433531256	18573	53	19E
0005435326767	18573	54	19F
0005433531254	18573	55	20C
0005434600607	18573	56	20E
0005434551297	10635	1	1A
0005434551288	10635	2	1C
0005434551272	10635	3	1D
0005433180957	10635	4	1F
0005434558284	10635	5	2C
0005434551308	10635	6	2D
0005434551291	10635	7	2F
0005433180926	10635	8	3A
0005434551311	10635	9	3C
0005434551278	10635	10	3D
0005434551280	10635	11	3F
0005434551305	10635	12	4A
0005434551313	10635	13	4C
0005433180879	10635	14	4D
0005434558286	10635	15	4E
0005433180909	10635	16	4F
0005434551294	10635	17	5A
0005434558282	10635	18	5C
0005434551317	10635	19	5D
0005434551269	10635	20	5E
0005434551315	10635	21	5F
0005434558287	10635	22	6A
0005434558283	10635	23	6C
0005434551289	10635	24	6D
0005434551304	10635	25	6E
0005434551279	10635	26	6F
0005433180802	10635	27	7A
0005434551283	10635	28	7C
0005434551282	10635	29	7D
0005433180745	10635	30	7E
0005434551303	10635	31	7F
0005434551292	10635	32	8A
0005434551285	10635	33	8C
0005434551319	10635	34	8E
0005434551306	10635	35	9A
0005434551323	10635	36	9C
0005433180776	10635	37	9E
0005433180744	10635	38	9F
0005434551300	10635	39	10A
0005434551268	10635	40	10C
0005434551277	10635	41	10D
0005434551281	10635	42	10E
0005434551276	10635	43	10F
0005434551321	10635	44	11A
0005433180888	10635	45	11C
0005434554069	10635	46	11D
0005434551314	10635	47	11E
0005433180848	10635	48	11F
0005433180987	10635	49	12A
0005434551275	10635	50	12C
0005433180887	10635	51	12E
0005433180903	10635	52	12D
0005434558281	10635	53	12F
0005434551310	10635	54	13A
0005434551273	10635	55	13C
0005434551307	10635	56	13D
0005434551318	10635	57	13E
0005433180947	10635	58	13F
0005434551274	10635	59	14A
0005434551287	10635	60	14C
0005433180944	10635	61	14D
0005433180980	10635	62	14E
0005434551302	10635	63	14F
0005434551301	10635	64	15A
0005433180866	10635	65	15C
0005434551298	10635	66	15D
0005434551296	10635	67	15E
0005433180919	10635	68	15F
0005434551309	10635	69	16A
0005434551299	10635	70	16C
0005434551320	10635	71	16D
0005434558285	10635	72	16E
0005433180904	10635	73	16F
0005433180961	10635	74	17A
0005434551293	10635	75	17C
0005434551295	10635	76	17E
0005434551270	10635	77	17F
0005434551316	10635	78	18A
0005434551284	10635	79	18C
0005433180956	10635	80	18D
0005434551290	10635	81	18E
0005434554068	10635	82	19A
0005434558288	10635	83	19C
0005433180942	10635	84	19F
0005434551322	10635	85	20A
0005434551286	10635	86	20C
0005434551271	10635	87	20D
0005434551312	10635	88	20E
0005433180902	10635	89	20F
0005433181146	27778	1	1A
0005433181161	27778	2	1C
0005433181140	27778	3	2A
0005433181153	27778	4	2D
0005433181160	27778	5	3C
0005433181158	27778	6	3D
0005433181144	27778	7	4A
0005433181148	27778	8	4D
0005433181154	27778	9	6F
0005433181156	27778	10	7A
0005433181149	27778	11	7C
0005433181143	27778	12	8D
0005433181159	27778	13	8F
0005433181162	27778	14	11D
0005433181147	27778	15	11E
0005433181163	27778	16	11F
0005433181155	27778	17	12D
0005433181152	27778	18	13C
0005433181151	27778	19	13D
0005433181145	27778	20	14E
0005433181164	27778	21	15C
0005433181157	27778	22	16A
0005433181139	27778	23	16C
0005433181141	27778	24	19D
0005433181142	27778	25	19F
0005433181150	27778	26	20E
0005434550871	27777	1	1A
0005434551061	27777	2	1C
0005434550686	27777	3	1D
0005434550830	27777	4	1F
0005434550814	27777	5	2A
0005434550883	27777	6	2C
0005434551004	27777	7	2D
0005434550896	27777	8	2F
0005434550960	27777	9	3A
0005434550792	27777	10	3C
0005434550835	27777	11	3F
0005434551100	27777	12	4A
0005434558222	27777	13	4D
0005434558225	27777	14	4E
0005434551016	27777	15	4F
0005434551081	27777	16	5A
0005434554042	27777	17	5D
0005434551041	27777	18	5F
0005434550793	27777	19	6A
0005434550965	27777	20	6C
0005434551020	27777	21	6F
0005434550644	27777	22	7A
0005434550944	27777	23	7C
0005434550714	27777	24	7D
0005434550634	27777	25	7E
0005434551062	27777	26	8A
0005434558220	27777	27	8D
0005434550807	27777	28	8E
0005434550961	27777	29	8F
0005434550870	27777	30	9A
0005434550891	27777	31	9E
0005434550748	27777	32	10A
0005434550761	27777	33	10C
0005434550687	27777	34	10D
0005434550831	27777	35	10E
0005434550889	27777	36	10F
0005434550997	27777	37	11A
0005434550734	27777	38	11C
0005434550959	27777	39	11D
0005434551118	27777	40	11E
0005434550839	27777	41	11F
0005434558226	27777	42	12A
0005434550876	27777	43	12C
0005434550850	27777	44	12E
0005434550777	27777	45	13D
0005434551082	27777	46	13E
0005434554044	27777	47	14A
0005434550833	27777	48	14C
0005434551015	27777	49	14D
0005434550829	27777	50	14E
0005434550958	27777	51	14F
0005434550743	27777	52	15A
0005434551005	27777	53	15C
0005434550762	27777	54	15D
0005434550898	27777	55	15F
0005434550882	27777	56	16D
0005434550897	27777	57	16F
0005434554049	27777	58	17D
0005434550832	27777	59	17E
0005434550834	27777	60	18D
0005434550947	27777	61	18E
0005434551072	27777	62	18F
0005434550742	27777	63	19A
0005434558219	27777	64	19C
0005434550996	27777	65	19D
0005434550913	27777	66	19F
0005434550749	27777	67	20A
0005434558221	27777	68	20D
0005434554043	27777	69	20E
0005433459228	6117	1	1B
0005435254457	6117	2	2A
0005435254447	6117	3	3A
0005435254453	6117	4	2B
0005433459229	6117	5	4B
0005433459226	6117	6	5A
0005433459227	6117	7	5B
0005435254458	6117	8	6A
0005435254480	19346	1	1A
0005435254482	19346	2	5A
0005435254479	19346	3	4B
0005435254481	19346	4	6A
0005435682199	6764	1	1A
0005435437875	6764	2	1C
0005435682228	6764	3	1D
0005435437843	6764	4	2C
0005435682218	6764	5	2D
0005435682232	6764	6	2F
0005432136178	6764	7	3A
0005435682217	6764	8	3C
0005435682237	6764	9	3D
0005432533278	6764	10	3F
0005435682216	6764	11	4A
0005435437797	6764	12	4C
0005435437736	6764	13	4D
0005435437786	6764	14	4E
0005435437906	6764	15	4F
0005435682205	6764	16	5A
0005432533270	6764	17	5C
0005435437787	6764	18	5D
0005435682229	6764	19	5E
0005435682240	6764	20	5F
0005435221512	6764	21	6A
0005435682233	6764	22	6C
0005435682238	6764	23	6D
0005435682203	6764	24	6E
0005435437856	6764	25	6F
0005435682206	6764	26	7A
0005432533271	6764	27	7C
0005435661935	6764	28	7E
0005432533279	6764	29	8A
0005435682231	6764	30	8C
0005435682201	6764	31	8D
0005435437798	6764	32	8E
0005435682230	6764	33	8F
0005435682227	6764	34	9A
0005435437831	6764	35	9D
0005435437859	6764	36	9E
0005435220297	6764	37	9F
0005435682215	6764	38	10A
0005432533277	6764	39	10C
0005435682204	6764	40	10D
0005435682208	6764	41	10E
0005434828668	6764	42	10F
0005432136179	6764	43	11A
0005435437898	6764	44	11C
0005435682202	6764	45	11D
0005435220298	6764	46	11E
0005435682235	6764	47	11F
0005435682226	6764	48	12A
0005435682198	6764	49	12C
0005435682221	6764	50	12D
0005435682209	6764	51	12F
0005435682200	6764	52	13A
0005435682212	6764	53	13C
0005435437848	6764	54	13D
0005435682239	6764	55	13E
0005435682236	6764	56	13F
0005435682214	6764	57	14A
0005435682211	6764	58	14C
0005432136176	6764	59	14D
0005435630969	6764	60	14E
0005432533268	6764	61	14F
0005435720135	6764	62	15A
0005432533267	6764	63	15C
0005432533269	6764	64	15D
0005435682241	6764	65	15E
0005435682223	6764	66	15F
0005435682220	6764	67	16C
0005435630971	6764	68	16D
0005435682222	6764	69	16E
0005435220299	6764	70	16F
0005435437808	6764	71	17A
0005435437796	6764	72	17C
0005435682213	6764	73	17D
0005435682234	6764	74	17E
0005435630970	6764	75	17F
0005432136177	6764	76	18D
0005435682210	6764	77	18E
0005435661934	6764	78	18F
0005435682207	6764	79	19A
0005435682224	6764	80	19C
0005435661933	6764	81	19D
0005435437849	6764	82	19E
0005435720136	6764	83	19F
0005432136180	6764	84	20A
0005435437869	6764	85	20C
0005435682225	6764	86	20D
0005435682219	6764	87	20F
0005435681818	24594	1	1A
0005432533297	24594	2	1C
0005435681627	24594	3	1D
0005435437985	24594	4	1F
0005435720819	24594	5	2A
0005435437993	24594	6	2F
0005435681936	24594	7	3C
0005435437988	24594	8	3A
0005434828703	24594	9	3D
0005435681815	24594	10	3F
0005435681822	24594	11	4A
0005435681954	24594	12	4C
0005435681980	24594	13	4D
0005435681814	24594	14	4E
0005435437999	24594	15	4F
0005435438000	24594	16	5A
0005435681791	24594	17	5C
0005435681982	24594	18	5D
0005435437994	24594	19	5E
0005435438003	24594	20	5F
0005432305755	24594	21	6A
0005435220322	24594	22	6C
0005435437984	24594	23	6D
0005435720818	24594	24	6F
0005435630940	24594	25	7A
0005434828702	24594	26	7C
0005435681842	24594	27	7D
0005435219201	24594	28	7E
0005432305752	24594	29	7F
0005435630935	24594	30	8A
0005435681813	24594	31	8C
0005435681911	24594	32	8D
0005435437990	24594	33	8E
0005435661906	24594	34	8F
0005435438005	24594	35	9A
0005435437995	24594	36	9C
0005435437997	24594	37	9D
0005435219204	24594	38	9E
0005435719556	24594	39	9F
0005435437991	24594	40	10A
0005435681819	24594	41	10C
0005435681674	24594	42	10D
0005435682118	24594	43	10E
0005435719557	24594	44	10F
0005432533298	24594	45	11A
0005435681785	24594	46	11D
0005435681677	24594	47	11F
0005435681957	24594	48	12A
0005435437989	24594	49	12D
0005435630939	24594	50	12E
0005435437992	24594	51	12F
0005435438004	24594	52	13A
0005434828704	24594	53	13C
0005432305754	24594	54	13F
0005435437998	24594	55	14A
0005435682117	24594	56	14D
0005435681879	24594	57	14E
0005435437996	24594	58	14F
0005435219202	24594	59	15A
0005435681845	24594	60	15C
0005435681970	24594	61	15D
0005435438001	24594	62	15E
0005435681816	24594	63	15F
0005435681958	24594	64	16A
0005435220321	24594	65	16C
0005435681786	24594	66	16D
0005435437983	24594	67	16E
0005435220320	24594	68	17A
0005435437986	24594	69	17D
0005435681796	24594	70	17E
0005435438002	24594	71	17F
0005435220323	24594	72	18A
0005435681836	24594	73	18C
0005435681881	24594	74	18D
0005435681648	24594	75	18E
0005435630936	24594	76	18F
0005435437987	24594	77	19A
0005435219203	24594	78	19D
0005435681843	24594	79	19F
0005435681978	24594	80	20A
0005435681981	24594	81	20C
0005435681812	24594	82	20D
0005432305753	24594	83	20E
0005435681820	24594	84	20F
0005435126432	11534	1	1D
0005435126405	11534	2	1F
0005435126424	11534	3	2A
0005435126415	11534	4	2C
0005435126401	11534	5	2F
0005435126399	11534	6	3A
0005435126430	11534	7	3C
0005435126431	11534	8	4D
0005435126404	11534	9	4F
0005435126406	11534	10	5A
0005435126416	11534	11	5D
0005435126398	11534	12	5F
0005435126421	11534	13	6A
0005435105986	11534	14	6C
0005435126434	11534	15	8A
0005435126403	11534	16	8D
0005435105985	11534	17	8F
0005435126418	11534	18	9D
0005435126422	11534	19	10A
0005435126425	11534	20	10C
0005435126397	11534	21	10D
0005435126402	11534	22	10F
0005435126423	11534	23	11C
0005435126411	11534	24	11E
0005435126435	11534	25	12C
0005435126414	11534	26	12D
0005435105987	11534	27	12E
0005435126400	11534	28	13A
0005435126412	11534	29	13C
0005435126428	11534	30	13D
0005435558056	11534	31	14A
0005435126437	11534	32	14D
0005435126419	11534	33	14E
0005435126426	11534	34	15A
0005435126396	11534	35	15C
0005435126417	11534	36	15D
0005435126413	11534	37	16A
0005435105984	11534	38	17A
0005435126429	11534	39	17C
0005435126433	11534	40	17E
0005435126436	11534	41	18D
0005435126409	11534	42	18E
0005435126410	11534	43	19A
0005435126427	11534	44	19C
0005435126407	11534	45	19D
0005435126408	11534	46	19E
0005435126420	11534	47	20C
0005435126193	31905	1	2C
0005435126102	31905	2	2D
0005435126132	31905	3	2F
0005435126227	31905	4	3C
0005435126216	31905	5	3F
0005435126285	31905	6	4C
0005435126226	31905	7	4F
0005435105970	31905	8	5E
0005435126196	31905	9	6A
0005435558093	31905	10	6D
0005435105969	31905	11	6E
0005435558092	31905	12	7C
0005435126029	31905	13	7E
0005435125983	31905	14	7F
0005435105968	31905	15	8C
0005435126217	31905	16	9C
0005435126082	31905	17	9D
0005435126027	31905	18	10C
0005435558091	31905	19	11A
0005435126197	31905	20	11E
0005435105962	31905	21	12C
0005435105956	31905	22	13D
0005435126225	31905	23	13E
0005435125995	31905	24	14F
0005435105954	31905	25	15A
0005435126272	31905	26	15D
0005435126039	31905	27	16E
0005435125926	31905	28	17D
0005435126118	31905	29	18A
0005435125925	31905	30	18D
0005435126195	31905	31	19A
0005435126178	31905	32	19C
0005435126119	31905	33	19D
0005435126283	31905	34	19E
0005435125984	31905	35	20D
0005435126131	31905	36	20E
0005433398162	13529	1	1C
0005433398148	13529	2	2A
0005433398172	13529	3	2C
0005433398124	13529	4	2D
0005435732198	13529	5	3A
0005433398170	13529	6	3C
0005435732269	13529	7	4C
0005433398144	13529	8	5A
0005433398152	13529	9	5D
0005433398158	13529	10	5F
0005433398165	13529	11	6A
0005433398128	13529	12	6C
0005433398160	13529	13	6D
0005433398156	13529	14	6F
0005433398125	13529	15	7A
0005433398127	13529	16	8A
0005433398147	13529	17	8C
0005433398130	13529	18	8E
0005433398136	13529	19	8F
0005433398166	13529	20	9A
0005433398135	13529	21	9C
0005433398173	13529	22	9D
0005435732268	13529	23	9F
0005433398164	13529	24	10D
0005435732221	13529	25	10E
0005433398163	13529	26	10F
0005433398168	13529	27	11A
0005433398132	13529	28	11C
0005433398138	13529	29	11D
0005435732254	13529	30	11E
0005433398140	13529	31	11F
0005435732246	13529	32	12A
0005433398171	13529	33	12C
0005433398167	13529	34	12E
0005433398141	13529	35	12F
0005433398145	13529	36	13A
0005433398149	13529	37	13D
0005433398142	13529	38	13E
0005433398153	13529	39	13F
0005433398150	13529	40	14A
0005433398133	13529	41	14C
0005435732267	13529	42	14E
0005433398146	13529	43	15A
0005433398169	13529	44	15C
0005433398143	13529	45	15D
0005435732240	13529	46	15E
0005433398154	13529	47	16A
0005433398151	13529	48	16C
0005433398126	13529	49	16D
0005435732234	13529	50	16E
0005433398161	13529	51	16F
0005433398155	13529	52	17A
0005435732189	13529	53	17C
0005435732199	13529	54	17E
0005435732264	13529	55	17F
0005433398134	13529	56	18C
0005433398129	13529	57	18D
0005433398139	13529	58	18E
0005435732253	13529	59	19A
0005433398131	13529	60	19C
0005433398157	13529	61	19E
0005433398159	13529	62	19F
0005433398137	13529	63	20E
0005435732355	19390	1	1A
0005433397682	19390	2	2A
0005435732350	19390	3	2C
0005435732354	19390	4	2F
0005433397724	19390	5	3A
0005433397675	19390	6	3F
0005435732359	19390	7	4D
0005433397674	19390	8	4E
0005433397469	19390	9	4F
0005433397924	19390	10	5A
0005433397708	19390	11	5C
0005433397789	19390	12	5D
0005433397646	19390	13	5E
0005433397753	19390	14	5F
0005435732360	19390	15	6A
0005433397862	19390	16	6C
0005435732357	19390	17	6E
0005433397923	19390	18	7C
0005433397758	19390	19	7D
0005435732351	19390	20	7F
0005433397740	19390	21	8A
0005433397752	19390	22	8C
0005433397790	19390	23	8D
0005432297281	19390	24	8E
0005435732353	19390	25	9C
0005433397697	19390	26	9D
0005433397820	19390	27	9E
0005433397635	19390	28	10A
0005433397671	19390	29	10E
0005433397896	19390	30	10F
0005433397787	19390	31	11A
0005435732356	19390	32	11C
0005435732348	19390	33	11D
0005433397694	19390	34	11E
0005433397411	19390	35	12C
0005433397742	19390	36	12D
0005435732347	19390	37	12E
0005433397672	19390	38	13A
0005433397627	19390	39	13C
0005433397578	19390	40	13D
0005432297283	19390	41	13F
0005433397759	19390	42	14A
0005433397850	19390	43	14F
0005433397685	19390	44	15A
0005433397686	19390	45	15C
0005433397732	19390	46	15D
0005433397693	19390	47	15E
0005433397762	19390	48	15F
0005435732358	19390	49	16A
0005433397760	19390	50	16C
0005433397673	19390	51	16E
0005433397944	19390	52	16F
0005433397763	19390	53	17A
0005433397648	19390	54	17C
0005435732352	19390	55	17E
0005432297282	19390	56	17F
0005433397725	19390	57	18A
0005433397647	19390	58	18D
0005433397634	19390	59	18E
0005435732349	19390	60	18F
0005433397945	19390	61	19A
0005433397389	19390	62	19C
0005433397916	19390	63	19D
0005433397741	19390	64	19F
0005433397743	19390	65	20C
0005433397963	19390	66	20D
0005433397579	19390	67	20E
0005435068803	13174	1	1C
0005435068804	13174	2	1D
0005435925310	13174	3	1F
0005435068704	13174	4	2A
0005435068707	13174	5	3A
0005435068733	13174	6	3D
0005435925320	13174	7	4A
0005435925309	13174	8	4C
0005435925317	13174	9	4D
0005435925311	13174	10	4E
0005435068835	13174	11	5C
0005435068466	13174	12	5D
0005435925323	13174	13	5E
0005435068859	13174	14	5F
0005435068436	13174	15	6D
0005435068736	13174	16	6E
0005435068861	13174	17	6F
0005435068802	13174	18	7A
0005435068624	13174	19	7C
0005435925314	13174	20	7E
0005435068524	13174	21	8A
0005435068567	13174	22	8D
0005435068761	13174	23	8F
0005435068641	13174	24	9A
0005435068734	13174	25	9C
0005435068614	13174	26	9D
0005435068826	13174	27	10A
0005435068789	13174	28	10C
0005435068642	13174	29	10F
0005435068778	13174	30	11E
0005435068540	13174	31	11D
0005435925319	13174	32	11F
0005435068787	13174	33	12A
0005435068626	13174	34	12C
0005435068692	13174	35	12E
0005435925308	13174	36	13C
0005435925313	13174	37	13E
0005435068688	13174	38	14C
0005435925324	13174	39	14F
0005435925321	13174	40	15A
0005435068620	13174	41	15C
0005435925316	13174	42	15D
0005435068539	13174	43	15E
0005435068597	13174	44	16A
0005435068717	13174	45	16C
0005435068784	13174	46	16D
0005435068621	13174	47	16E
0005435068846	13174	48	16F
0005435068643	13174	49	17A
0005435068592	13174	50	17C
0005435925306	13174	51	17F
0005435068619	13174	52	18A
0005435925305	13174	53	18C
0005435925307	13174	54	18D
0005435925312	13174	55	18F
0005435925315	13174	56	19A
0005435925318	13174	57	19C
0005435068737	13174	58	19D
0005435068598	13174	59	19E
0005435068725	13174	60	19F
0005435068799	13174	61	20A
0005435068770	13174	62	20D
0005435925322	13174	63	20E
0005435068712	13174	64	20F
0005435069130	15508	1	1A
0005435069158	15508	2	1C
0005435069134	15508	3	1D
0005435069145	15508	4	2A
0005435069138	15508	5	2C
0005435069125	15508	6	2D
0005435069142	15508	7	2F
0005435069127	15508	8	3D
0005435069120	15508	9	3F
0005435069161	15508	10	4A
0005435069154	15508	11	4C
0005435069112	15508	12	4D
0005435069153	15508	13	4E
0005435069137	15508	14	5C
0005435069140	15508	15	5E
0005435069117	15508	16	6A
0005435069150	15508	17	6C
0005435925150	15508	18	6E
0005435069152	15508	19	6F
0005435069143	15508	20	7A
0005435069147	15508	21	7C
0005435925175	15508	22	7D
0005435069124	15508	23	7E
0005435069122	15508	24	8C
0005435069118	15508	25	9A
0005435069165	15508	26	9D
0005435069162	15508	27	9F
0005435069160	15508	28	10A
0005435069121	15508	29	10D
0005435069115	15508	30	10E
0005435925157	15508	31	10F
0005435925166	15508	32	11A
0005435069148	15508	33	11C
0005435069163	15508	34	11D
0005435069159	15508	35	11E
0005435069141	15508	36	11F
0005435069136	15508	37	12A
0005435069157	15508	38	12C
0005435069114	15508	39	12D
0005435069128	15508	40	12E
0005435925182	15508	41	13A
0005435069123	15508	42	13D
0005435069113	15508	43	13E
0005435069164	15508	44	14A
0005435069166	15508	45	14C
0005435069132	15508	46	14E
0005435925181	15508	47	15A
0005435069116	15508	48	15D
0005435069156	15508	49	15E
0005435069155	15508	50	15F
0005435069149	15508	51	16A
0005435069126	15508	52	16C
0005435069131	15508	53	16E
0005435925164	15508	54	16F
0005435925183	15508	55	17A
0005435069133	15508	56	17C
0005435069129	15508	57	17E
0005435069119	15508	58	18A
0005435925177	15508	59	18C
0005435069139	15508	60	18D
0005435925134	15508	61	18F
0005435925165	15508	62	19A
0005435069146	15508	63	19D
0005435925176	15508	64	19E
0005435069151	15508	65	19F
0005435069144	15508	66	20C
0005435069135	15508	67	20D
0005435925189	15508	68	20F
0005434756230	10711	1	1A
0005434756193	10711	2	1C
0005434756157	10711	3	1D
0005434214649	10711	4	1F
0005434756037	10711	5	2C
0005434214630	10711	6	2D
0005434756238	10711	7	2F
0005434756135	10711	8	3A
0005434756071	10711	9	3C
0005434756033	10711	10	3D
0005434214626	10711	11	3F
0005434214607	10711	12	4A
0005434214648	10711	13	4C
0005434214610	10711	14	4D
0005434214641	10711	15	4E
0005434756044	10711	16	4F
0005434756115	10711	17	5A
0005434214640	10711	18	5C
0005434214606	10711	19	5D
0005434214612	10711	20	5E
0005434214643	10711	21	5F
0005434756197	10711	22	6A
0005434756113	10711	23	6D
0005434214633	10711	24	6E
0005434214608	10711	25	7A
0005434214632	10711	26	7C
0005434756153	10711	27	7D
0005434214639	10711	28	7E
0005434756262	10711	29	7F
0005434214604	10711	30	8A
0005434756041	10711	31	8C
0005434214603	10711	32	8D
0005434214623	10711	33	8F
0005434214613	10711	34	9A
0005434756181	10711	35	9C
0005434214609	10711	36	9D
0005434756178	10711	37	9E
0005434214617	10711	38	9F
0005434756120	10711	39	10A
0005434214636	10711	40	10C
0005434214622	10711	41	10D
0005434756002	10711	42	10E
0005434756133	10711	43	10F
0005434756045	10711	44	11C
0005434755985	10711	45	11D
0005434214629	10711	46	11E
0005434756014	10711	47	11F
0005434214605	10711	48	12A
0005434214627	10711	49	12C
0005434214614	10711	50	12D
0005434214631	10711	51	12E
0005434756229	10711	52	12F
0005434214647	10711	53	13A
0005434214620	10711	54	13C
0005434214616	10711	55	13D
0005434214644	10711	56	13E
0005434214628	10711	57	13F
0005434214621	10711	58	14A
0005434756085	10711	59	14C
0005434756228	10711	60	14D
0005434756122	10711	61	14E
0005434756046	10711	62	15A
0005434214645	10711	63	15C
0005434755908	10711	64	15D
0005434214635	10711	65	15E
0005434756022	10711	66	15F
0005434214615	10711	67	16A
0005434755928	10711	68	16C
0005434214642	10711	69	16D
0005434214638	10711	70	16E
0005434214619	10711	71	16F
0005434755907	10711	72	17C
0005434214611	10711	73	17D
0005434755927	10711	74	17F
0005434756089	10711	75	18A
0005434756011	10711	76	18C
0005434756121	10711	77	18D
0005434756180	10711	78	18E
0005434214646	10711	79	18F
0005434214624	10711	80	19A
0005434756108	10711	81	19C
0005434214637	10711	82	19D
0005434214602	10711	83	19E
0005434756237	10711	84	19F
0005434214634	10711	85	20A
0005434214625	10711	86	20D
0005434214618	10711	87	20E
0005434756105	10711	88	20F
0005434756467	28704	1	1A
0005434214204	28704	2	1C
0005434756464	28704	3	1D
0005434214179	28704	4	1F
0005434214063	28704	5	2A
0005434214118	28704	6	2C
0005434756453	28704	7	2D
0005434213982	28704	8	2F
0005434214067	28704	9	3A
0005434214170	28704	10	3C
0005434214167	28704	11	3D
0005434756452	28704	12	3F
0005434214222	28704	13	4A
0005434214012	28704	14	4C
0005434214122	28704	15	4D
0005434756462	28704	16	4E
0005434214231	28704	17	4F
0005434214193	28704	18	5A
0005434214200	28704	19	5C
0005434756468	28704	20	5D
0005434214221	28704	21	5E
0005434214099	28704	22	5F
0005434214150	28704	23	6A
0005434213979	28704	24	6D
0005434214232	28704	25	6C
0005434214310	28704	26	6E
0005434214220	28704	27	6F
0005434756469	28704	28	7C
0005434214013	28704	29	7D
0005434756450	28704	30	7E
0005434756446	28704	31	7F
0005434756465	28704	32	8A
0005434214154	28704	33	8C
0005434213933	28704	34	8D
0005434214223	28704	35	8E
0005434214126	28704	36	9A
0005434214309	28704	37	9C
0005434756449	28704	38	9D
0005434213981	28704	39	9E
0005434214121	28704	40	10A
0005434756451	28704	41	10C
0005434214089	28704	42	10E
0005434756454	28704	43	10F
0005434214171	28704	44	11A
0005434214198	28704	45	11C
0005434213847	28704	46	11D
0005434214064	28704	47	11E
0005434213961	28704	48	11F
0005434213962	28704	49	12A
0005434214194	28704	50	12C
0005434756455	28704	51	12D
0005434214312	28704	52	12E
0005434756447	28704	53	12F
0005434214280	28704	54	13A
0005434756448	28704	55	13C
0005434756458	28704	56	13E
0005434214250	28704	57	13F
0005434756460	28704	58	14A
0005434214080	28704	59	14C
0005434214195	28704	60	14D
0005434214190	28704	61	14E
0005434213934	28704	62	14F
0005434756457	28704	63	15A
0005434214153	28704	64	15C
0005434213959	28704	65	15D
0005434756461	28704	66	15E
0005434214079	28704	67	15F
0005434214234	28704	68	16A
0005434214058	28704	69	16C
0005434214125	28704	70	16D
0005434756463	28704	71	16E
0005434214281	28704	72	16F
0005434756459	28704	73	17A
0005434214247	28704	74	17C
0005434214199	28704	75	17D
0005434756466	28704	76	17F
0005434213846	28704	77	18A
0005434214182	28704	78	18D
0005434213958	28704	79	18E
0005434214233	28704	80	18F
0005434214123	28704	81	19A
0005434214245	28704	82	19C
0005434214087	28704	83	19D
0005434756456	28704	84	19E
0005434213969	28704	85	19F
0005434214197	28704	86	20A
0005434214120	28704	87	20C
0005434214027	28704	88	20D
0005434214117	28704	89	20E
0005434214086	28704	90	20F
0005435039888	5426	1	1C
0005434229225	5426	2	1D
0005432125469	5426	3	2A
0005434229226	5426	4	1F
0005435039905	5426	5	2C
0005435039920	5426	6	2F
0005435039921	5426	7	3C
0005435039912	5426	8	3D
0005434229193	5426	9	3F
0005434229178	5426	10	4B
0005435039925	5426	11	4A
0005435039928	5426	12	4C
0005434229167	5426	13	4E
0005435039910	5426	14	4F
0005435039874	5426	15	5A
0005434229283	5426	16	5D
0005435007080	5426	17	5E
0005435039891	5426	18	6A
0005435039869	5426	19	5F
0005435039878	5426	20	6C
0005435039904	5426	21	6D
0005434229104	5426	22	6F
0005435007072	5426	23	6E
0005435039930	5426	24	7B
0005435039911	5426	25	7A
0005435039868	5426	26	7C
0005435039887	5426	27	7D
0005435039875	5426	28	7F
0005435039923	5426	29	7E
0005434229210	5426	30	8A
0005435039879	5426	31	8B
0005435039884	5426	32	8C
0005435039908	5426	33	8E
0005435039917	5426	34	8D
0005435007084	5426	35	8F
0005434229282	5426	36	9A
0005435007074	5426	37	9B
0005435039899	5426	38	9E
0005435007081	5426	39	9D
0005435039906	5426	40	10B
0005434229247	5426	41	10D
0005435039914	5426	42	10C
0005435039919	5426	43	10E
0005434229213	5426	44	11A
0005435039892	5426	45	11B
0005434229128	5426	46	11D
0005435039896	5426	47	11C
0005434229219	5426	48	11F
0005435039903	5426	49	11E
0005435039881	5426	50	12A
0005435007077	5426	51	12C
0005435039929	5426	52	12E
0005435039918	5426	53	12F
0005432125467	5426	54	13B
0005435039876	5426	55	13A
0005434229144	5426	56	13C
0005434229188	5426	57	13E
0005435039867	5426	58	13F
0005435039926	5426	59	14A
0005435039907	5426	60	14C
0005435039927	5426	61	14B
0005434229262	5426	62	14D
0005435039871	5426	63	14E
0005435039901	5426	64	15B
0005435039900	5426	65	15A
0005435042858	5426	66	15C
0005435039872	5426	67	15D
0005435007071	5426	68	15F
0005434229263	5426	69	15E
0005435007073	5426	70	16A
0005435039880	5426	71	16B
0005435039877	5426	72	16D
0005435039886	5426	73	16C
0005435039883	5426	74	16E
0005435039924	5426	75	17A
0005435039890	5426	76	16F
0005432125464	5426	77	17C
0005435039889	5426	78	17E
0005435039898	5426	79	17D
0005432125466	5426	80	17F
0005432125465	5426	81	18A
0005435039922	5426	82	18B
0005435039873	5426	83	18C
0005434229268	5426	84	18E
0005435007083	5426	85	18D
0005434229129	5426	86	18F
0005435007076	5426	87	19A
0005435039916	5426	88	19B
0005435039913	5426	89	19D
0005435039894	5426	90	19C
0005435007082	5426	91	19F
0005435039893	5426	92	20A
0005435039882	5426	93	20B
0005432125468	5426	94	20C
0005434229311	5426	95	20E
0005434229212	5426	96	20D
0005435039902	5426	97	20F
0005435039870	5426	98	21C
0005435039931	5426	99	21B
0005434229187	5426	100	21D
0005435039885	5426	101	21E
0005434229166	5426	102	21F
0005435039915	5426	103	22B
0005434229292	5426	104	22A
0005434229222	5426	105	22C
0005432125463	5426	106	22D
0005435039909	5426	107	22F
0005435039897	5426	108	22E
0005435007075	5426	109	23A
0005435007078	5426	110	23B
0005434229209	5426	111	23D
0005435007079	5426	112	23F
0005435039895	5426	113	23E
0005435039201	12955	1	1A
0005435039166	12955	2	1C
0005435039275	12955	3	1D
0005434229413	12955	4	1F
0005435039207	12955	5	2C
0005435006862	12955	6	2A
0005434229424	12955	7	2D
0005434229414	12955	8	2F
0005435039295	12955	9	3C
0005434229425	12955	10	4B
0005435039197	12955	11	4A
0005434229411	12955	12	4D
0005435039463	12955	13	4C
0005435039214	12955	14	4F
0005435039269	12955	15	5B
0005435039208	12955	16	5A
0005435039341	12955	17	5C
0005435039198	12955	18	5D
0005434229417	12955	19	5E
0005435039301	12955	20	6A
0005435006913	12955	21	5F
0005435039636	12955	22	6B
0005435039288	12955	23	6C
0005435039065	12955	24	6D
0005434229423	12955	25	6E
0005435039068	12955	26	7A
0005435039593	12955	27	6F
0005435039185	12955	28	7B
0005435006827	12955	29	7C
0005434229427	12955	30	7D
0005435006885	12955	31	7F
0005435042845	12955	32	7E
0005435039330	12955	33	8A
0005435006921	12955	34	8C
0005435006868	12955	35	8B
0005435006843	12955	36	8E
0005435039571	12955	37	8D
0005434229416	12955	38	8F
0005435006896	12955	39	9B
0005435006828	12955	40	9C
0005435039483	12955	41	9E
0005435039396	12955	42	9D
0005435039581	12955	43	9F
0005434229419	12955	44	10B
0005435006897	12955	45	10D
0005435039402	12955	46	10C
0005435006864	12955	47	11A
0005435039457	12955	48	10E
0005435039345	12955	49	11C
0005435039228	12955	50	11E
0005435006842	12955	51	11F
0005435039458	12955	52	12A
0005434229422	12955	53	12B
0005435006912	12955	54	12D
0005434229428	12955	55	12C
0005432304407	12955	56	12E
0005435039594	12955	57	13A
0005435006863	12955	58	12F
0005435006922	12955	59	13C
0005435039470	12955	60	13B
0005435039344	12955	61	13D
0005432304404	12955	62	13E
0005435043278	12955	63	13F
0005434229421	12955	64	14B
0005434229407	12955	65	14A
0005432304405	12955	66	14C
0005435006829	12955	67	14D
0005435039184	12955	68	14E
0005434229406	12955	69	14F
0005434229420	12955	70	15B
0005435039211	12955	71	15A
0005434229409	12955	72	15C
0005435006831	12955	73	15E
0005435042839	12955	74	16B
0005435039366	12955	75	16A
0005435006887	12955	76	16C
0005434229410	12955	77	16E
0005435043281	12955	78	16D
0005435039379	12955	79	16F
0005435039192	12955	80	17B
0005435039094	12955	81	17F
0005435039582	12955	82	17E
0005435039256	12955	83	18A
0005435039287	12955	84	18C
0005435039429	12955	85	18B
0005435006890	12955	86	18E
0005435039331	12955	87	18D
0005432304406	12955	88	18F
0005434229426	12955	89	19A
0005435039368	12955	90	19B
0005435039503	12955	91	19C
0005434229429	12955	92	19F
0005434229418	12955	93	20A
0005435006886	12955	94	20B
0005435039257	12955	95	20C
0005435039347	12955	96	20D
0005434229415	12955	97	21A
0005435039304	12955	98	20F
0005435039367	12955	99	21C
0005434229412	12955	100	21B
0005434229408	12955	101	21E
0005435039588	12955	102	22A
0005435039095	12955	103	21F
0005435039354	12955	104	22B
0005435039380	12955	105	22C
0005435039346	12955	106	22D
0005435039381	12955	107	22F
0005435006830	12955	108	22E
0005435039382	12955	109	23B
0005435039405	12955	110	23A
0005435039324	12955	111	23D
0005435039369	12955	112	23C
0005435039436	12955	113	23E
0005435039527	12955	114	23F
0005434426632	14850	1	1D
0005434411782	14850	2	1F
0005435902489	14850	3	2A
0005435902598	14850	4	2C
0005434426652	14850	5	2D
0005434426642	14850	6	2F
0005434426630	14850	7	3D
0005434426649	14850	8	3F
0005435902566	14850	9	4A
0005435902587	14850	10	4C
0005435902562	14850	11	4F
0005435902620	14850	12	5C
0005434426654	14850	13	5F
0005434426638	14850	14	6A
0005432188611	14850	15	6C
0005434426640	14850	16	6D
0005434426633	14850	17	6F
0005435902567	14850	18	7A
0005435902538	14850	19	7C
0005434426646	14850	20	7E
0005435902560	14850	21	8C
0005435902559	14850	22	8D
0005434426635	14850	23	8F
0005434426639	14850	24	9A
0005434426636	14850	25	9C
0005435902602	14850	26	9D
0005434426641	14850	27	9F
0005435554164	14850	28	10A
0005434426648	14850	29	10D
0005434426644	14850	30	10E
0005434426655	14850	31	10F
0005435902524	14850	32	11A
0005434426643	14850	33	11C
0005434426653	14850	34	11F
0005434411784	14850	35	12A
0005435902534	14850	36	12F
0005434426631	14850	37	13D
0005434426650	14850	38	13E
0005434426637	14850	39	13F
0005434411781	14850	40	14D
0005434426628	14850	41	14E
0005434426651	14850	42	14F
0005435902563	14850	43	15A
0005435902484	14850	44	15C
0005432188612	14850	45	15D
0005434426656	14850	46	15E
0005434426647	14850	47	16A
0005434426629	14850	48	16D
0005435902533	14850	49	16E
0005435554140	14850	50	17A
0005435902535	14850	51	17C
0005434426634	14850	52	17D
0005435902523	14850	53	17E
0005435902517	14850	54	18A
0005434411783	14850	55	18C
0005435902483	14850	56	18E
0005434426645	14850	57	19A
0005435902520	14850	58	19D
0005434426627	14850	59	20E
0005434411749	20193	1	1A
0005434426193	20193	2	2C
0005434411750	20193	3	2D
0005434426513	20193	4	2F
0005435902736	20193	5	3D
0005435902730	20193	6	4F
0005434426440	20193	7	5A
0005435902744	20193	8	6A
0005434426349	20193	9	6D
0005435902742	20193	10	6E
0005435554199	20193	11	6F
0005435902732	20193	12	7D
0005434426305	20193	13	7E
0005435902747	20193	14	8A
0005435902731	20193	15	8C
0005435902745	20193	16	8D
0005434426348	20193	17	8E
0005434426343	20193	18	9C
0005434426458	20193	19	9E
0005434426306	20193	20	9F
0005435554200	20193	21	10A
0005434426426	20193	22	10D
0005434426464	20193	23	11A
0005434426483	20193	24	11C
0005435902740	20193	25	11F
0005435554198	20193	26	12C
0005435902739	20193	27	12D
0005435902746	20193	28	12E
0005434426463	20193	29	12F
0005434426421	20193	30	13A
0005434426424	20193	31	13C
0005434426484	20193	32	13D
0005434426514	20193	33	13F
0005434426422	20193	34	14C
0005434426478	20193	35	14D
0005434426449	20193	36	14E
0005434426390	20193	37	15D
0005434411754	20193	38	16A
0005434426511	20193	39	16D
0005435902735	20193	40	16E
0005435902738	20193	41	17A
0005435902737	20193	42	17C
0005435902743	20193	43	17D
0005435902741	20193	44	17F
0005435554201	20193	45	18A
0005434426363	20193	46	18E
0005434426450	20193	47	19C
0005434426391	20193	48	19D
0005435902733	20193	49	19E
0005435902734	20193	50	20C
0005434426296	20193	51	20F
0005435982361	26508	1	1C
0005435982369	26508	2	1D
0005433434346	26508	3	1F
0005435982363	26508	4	2A
0005435982365	26508	5	2C
0005435982368	26508	6	2D
0005433434603	26508	7	2F
0005433434528	26508	8	3A
0005435982383	26508	9	3C
0005433434477	26508	10	3D
0005435982351	26508	11	3F
0005435982357	26508	12	4A
0005435982387	26508	13	4C
0005433434478	26508	14	4E
0005433434547	26508	15	4F
0005435982346	26508	16	5A
0005435982364	26508	17	5C
0005433434467	26508	18	5D
0005435982362	26508	19	5E
0005433434466	26508	20	5F
0005435982388	26508	21	6A
0005432300272	26508	22	6C
0005433434531	26508	23	6D
0005433434501	26508	24	7A
0005435982350	26508	25	7C
0005433434468	26508	26	7D
0005433434443	26508	27	7E
0005435982382	26508	28	7F
0005435982378	26508	29	8A
0005435982348	26508	30	8C
0005434270194	26508	31	8D
0005432300271	26508	32	8E
0005435982377	26508	33	8F
0005433434486	26508	34	9A
0005433434558	26508	35	9C
0005433434487	26508	36	9D
0005435982373	26508	37	9F
0005435982375	26508	38	10A
0005434273063	26508	39	10C
0005435982381	26508	40	10D
0005435982360	26508	41	10E
0005435982371	26508	42	10F
0005435982370	26508	43	11A
0005433434532	26508	44	11C
0005434270192	26508	45	11D
0005435982347	26508	46	11F
0005435982389	26508	47	12A
0005433434552	26508	48	12C
0005435982379	26508	49	12D
0005434273059	26508	50	12E
0005435982376	26508	51	12F
0005435982354	26508	52	13A
0005433434540	26508	53	13C
0005435982349	26508	54	13D
0005433434464	26508	55	13E
0005433434500	26508	56	13F
0005435982380	26508	57	14A
0005435982344	26508	58	14C
0005435982359	26508	59	14D
0005434273064	26508	60	14F
0005433434602	26508	61	15A
0005435982374	26508	62	15C
0005432300270	26508	63	15D
0005433434463	26508	64	15E
0005435982355	26508	65	15F
0005435982384	26508	66	16A
0005435982353	26508	67	16C
0005435982386	26508	68	16D
0005435982385	26508	69	17A
0005433434447	26508	70	17D
0005435982372	26508	71	17E
0005435982366	26508	72	17F
0005435982392	26508	73	18A
0005432300269	26508	74	18C
0005435982391	26508	75	18D
0005433434422	26508	76	18E
0005435982358	26508	77	18F
0005433434485	26508	78	19A
0005433434421	26508	79	19C
0005433434423	26508	80	19D
0005435982356	26508	81	19E
0005435982352	26508	82	19F
0005435982390	26508	83	20A
0005435982367	26508	84	20C
0005435982345	26508	85	20D
0005433434512	26508	86	20E
0005435982343	26508	87	20F
0005435981983	26679	1	1A
0005433434755	26679	2	1C
0005435981912	26679	3	1D
0005433434732	26679	4	1F
0005433434736	26679	5	2A
0005435981827	26679	6	2C
0005433434731	26679	7	2D
0005435981996	26679	8	2F
0005435981976	26679	9	3A
0005435981926	26679	10	3C
0005435981837	26679	11	3D
0005435981858	26679	12	3F
0005435982050	26679	13	4A
0005433434741	26679	14	4C
0005433434746	26679	15	4D
0005435981966	26679	16	4E
0005435982039	26679	17	4F
0005435981959	26679	18	5A
0005433434749	26679	19	5C
0005435982115	26679	20	5D
0005432051133	26679	21	5E
0005435981967	26679	22	5F
0005435981948	26679	23	6A
0005434269108	26679	24	6C
0005435981820	26679	25	6D
0005435981943	26679	26	6E
0005433434743	26679	27	6F
0005435981888	26679	28	7A
0005433434730	26679	29	7E
0005434269107	26679	30	7F
0005435981812	26679	31	8A
0005435981941	26679	32	8C
0005435982114	26679	33	8D
0005433434728	26679	34	8E
0005435981821	26679	35	8F
0005435981997	26679	36	9A
0005435981993	26679	37	9C
0005435981942	26679	38	9D
0005433434751	26679	39	9E
0005435981907	26679	40	10A
0005435982030	26679	41	10C
0005435982038	26679	42	10D
0005435981951	26679	43	10E
0005432051134	26679	44	10F
0005433434745	26679	45	11A
0005435981909	26679	46	11C
0005433434747	26679	47	11D
0005435981939	26679	48	11E
0005435981947	26679	49	11F
0005434271316	26679	50	12A
0005433434752	26679	51	12C
0005433434750	26679	52	12D
0005435982029	26679	53	12E
0005433434733	26679	54	12F
0005435982012	26679	55	13A
0005433434727	26679	56	13C
0005433434748	26679	57	13D
0005434271317	26679	58	13E
0005435981958	26679	59	13F
0005433434740	26679	60	14A
0005435981938	26679	61	14C
0005434270211	26679	62	14E
0005433434738	26679	63	14F
0005435982078	26679	64	15C
0005435981773	26679	65	15D
0005433434729	26679	66	15E
0005433434744	26679	67	15F
0005433434739	26679	68	16A
0005435981991	26679	69	16C
0005435982007	26679	70	16D
0005433434753	26679	71	16E
0005435981816	26679	72	17A
0005433434742	26679	73	17C
0005435982172	26679	74	17E
0005435981893	26679	75	17F
0005432051136	26679	76	18A
0005435981968	26679	77	18C
0005435981819	26679	78	18D
0005435982010	26679	79	18E
0005433434735	26679	80	18F
0005432051135	26679	81	19A
0005435981957	26679	82	19C
0005433434737	26679	83	19D
0005433434734	26679	84	19E
0005435982011	26679	85	19F
0005435981886	26679	86	20A
0005434270210	26679	87	20C
0005435981887	26679	88	20D
0005435982040	26679	89	20E
0005433434754	26679	90	20F
0005432584088	3131	1	1A
0005432584084	3131	2	1B
0005432584076	3131	3	1C
0005432584074	3131	4	1D
0005432584082	3131	5	2A
0005432857997	3131	6	2B
0005432216278	3131	7	2C
0005432857936	3131	8	2D
0005432584075	3131	9	3A
0005432858042	3131	10	3B
0005432584091	3131	11	3D
0005432584097	3131	12	3C
0005432216277	3131	13	4A
0005432584086	3131	14	4B
0005432584077	3131	15	4C
0005432858003	3131	16	4D
0005432857978	3131	17	5A
0005432584096	3131	18	5B
0005432584080	3131	19	5C
0005432584085	3131	20	5D
0005432584083	3131	21	6A
0005432857966	3131	22	6C
0005432857944	3131	23	6B
0005432584078	3131	24	6D
0005432584087	3131	25	7A
0005432857992	3131	26	7B
0005432584094	3131	27	7D
0005432584090	3131	28	18A
0005432584072	3131	29	18B
0005432584089	3131	30	18C
0005432584079	3131	31	18D
0005432857977	3131	32	19B
0005432584073	3131	33	19D
0005432858043	3131	34	20A
0005432857917	3131	35	20B
0005432216276	3131	36	20C
0005432584095	3131	37	20D
0005432584092	3131	38	21A
0005432857996	3131	39	21B
0005432584093	3131	40	21C
0005432857984	3131	41	22A
0005432216279	3131	42	22B
0005432584081	3131	43	22C
0005432857943	3131	44	23A
0005432857985	3131	45	23B
0005432583883	31524	1	1A
0005432858090	31524	2	1B
0005432583905	31524	3	1C
0005432583900	31524	4	2A
0005432858086	31524	5	2B
0005432583966	31524	6	2C
0005432583802	31524	7	3B
0005432583911	31524	8	3A
0005432858088	31524	9	3C
0005432583912	31524	10	3D
0005432858089	31524	11	4B
0005432858096	31524	12	4C
0005432583932	31524	13	4D
0005432858093	31524	14	5A
0005432583924	31524	15	5D
0005432858087	31524	16	6A
0005432858085	31524	17	6D
0005432858091	31524	18	7A
0005432583904	31524	19	7B
0005432583922	31524	20	18A
0005432858097	31524	21	18B
0005432583803	31524	22	19A
0005432583910	31524	23	19B
0005432583965	31524	24	19C
0005432583964	31524	25	19D
0005432583925	31524	26	20A
0005432583908	31524	27	20B
0005432858092	31524	28	20D
0005432583930	31524	29	21A
0005432858095	31524	30	22A
0005432858094	31524	31	23A
0005432583923	31524	32	23B
0005434943369	875	1	1B
0005434943373	875	2	3C
0005433255077	875	3	3D
0005434943366	875	4	4A
0005433255109	875	5	5A
0005434943367	875	6	7D
0005433255087	875	7	19A
0005434943370	875	8	19B
0005434943371	875	9	20A
0005434943372	875	10	20B
0005433255100	875	11	20D
0005434943365	875	12	21A
0005433255108	875	13	22B
0005434943368	875	14	22C
0005433255129	16202	1	1B
0005434943279	16202	2	1C
0005433255131	16202	3	2C
0005434943310	16202	4	3A
0005434943304	16202	5	3D
0005433255128	16202	6	4B
0005434943299	16202	7	4D
0005434943335	16202	8	5A
0005434943298	16202	9	6A
0005433255127	16202	10	7A
0005433255130	16202	11	7C
0005434943271	16202	12	18A
0005434943309	16202	13	19C
0005434943276	16202	14	20A
0005434943303	16202	15	20B
0005433255132	16202	16	20C
0005434943342	16202	17	20D
0005434943336	16202	18	23B
0005433811622	14370	1	2A
0005433811623	14370	2	2B
0005433811621	14370	3	6B
0005435653137	21747	1	1A
0005435653132	21747	2	1C
0005433367556	21747	3	1D
0005435653120	21747	4	1F
0005435653129	21747	5	2A
0005433367440	21747	6	2C
0005435653112	21747	7	2D
0005433367648	21747	8	3A
0005433367609	21747	9	3C
0005435653134	21747	10	3D
0005433367615	21747	11	3F
0005435653127	21747	12	4A
0005435653105	21747	13	4C
0005435653117	21747	14	4D
0005435653121	21747	15	4E
0005433367553	21747	16	4F
0005435653124	21747	17	5A
0005433367588	21747	18	5C
0005433367699	21747	19	5D
0005435653133	21747	20	5E
0005433367623	21747	21	5F
0005433367585	21747	22	6A
0005433367474	21747	23	6C
0005435653135	21747	24	6D
0005435653118	21747	25	6E
0005435653099	21747	26	6F
0005433367431	21747	27	7C
0005435653095	21747	28	7E
0005433367568	21747	29	7F
0005435653123	21747	30	8A
0005435653107	21747	31	8D
0005433367576	21747	32	8E
0005433367612	21747	33	8F
0005435653108	21747	34	9A
0005435653128	21747	35	9C
0005435653131	21747	36	9D
0005435653119	21747	37	9E
0005433367780	21747	38	9F
0005433367614	21747	39	10A
0005433367473	21747	40	10D
0005435653098	21747	41	10C
0005433367610	21747	42	11A
0005435653122	21747	43	11C
0005435653138	21747	44	11E
0005433367438	21747	45	11F
0005433367608	21747	46	12A
0005433367633	21747	47	12C
0005435653110	21747	48	12D
0005435653104	21747	49	12E
0005435653111	21747	50	12F
0005435653094	21747	51	13A
0005433367552	21747	52	13D
0005433367716	21747	53	13E
0005435653115	21747	54	13F
0005433367781	21747	55	14C
0005433367624	21747	56	14D
0005435653109	21747	57	14E
0005433367589	21747	58	15A
0005435653097	21747	59	15C
0005435653114	21747	60	15D
0005435653101	21747	61	15E
0005435653125	21747	62	15F
0005433367644	21747	63	16A
0005435653126	21747	64	16D
0005433367432	21747	65	16F
0005435653100	21747	66	17A
0005433367433	21747	67	17C
0005433367647	21747	68	17D
0005433367587	21747	69	17E
0005433367715	21747	70	17F
0005435653116	21747	71	18A
0005433367439	21747	72	18D
0005435653103	21747	73	18E
0005433367674	21747	74	18F
0005435653096	21747	75	19A
0005435653106	21747	76	19C
0005433367697	21747	77	19D
0005433367671	21747	78	19E
0005435653136	21747	79	19F
0005435653102	21747	80	20A
0005435653130	21747	81	20C
0005435653113	21747	82	20E
0005433785001	9360	1	1B
0005433805440	9360	2	1H
0005433785012	9360	3	2F
0005433805451	9360	4	3B
0005433805468	9360	5	3F
0005433805444	9360	6	3C
0005432665279	9360	7	3H
0005433805442	9360	8	3G
0005432657456	9360	9	4A
0005433805459	9360	10	4F
0005433785035	9360	11	4C
0005433805461	9360	12	4G
0005433763234	9360	13	5A
0005433785010	9360	14	5B
0005433785037	9360	15	5C
0005433785000	9360	16	5F
0005433785016	9360	17	5H
0005433785011	9360	18	9A
0005432666393	9360	19	9H
0005433805465	9360	20	9G
0005433805472	9360	21	11D
0005433785022	9360	22	11B
0005433805471	9360	23	11A
0005433785019	9360	24	11G
0005434170988	9360	25	12A
0005434170994	9360	26	12D
0005433805448	9360	27	12H
0005433805469	9360	28	13B
0005433763241	9360	29	13A
0005433785014	9360	30	13D
0005433763239	9360	31	13F
0005434170973	9360	32	14A
0005433805445	9360	33	14E
0005433785018	9360	34	14D
0005435269691	9360	35	15A
0005434171033	9360	36	14H
0005433805454	9360	37	15B
0005433785020	9360	38	15E
0005433805466	9360	39	15H
0005433785017	9360	40	15G
0005435269679	9360	41	16D
0005433763230	9360	42	16G
0005434170923	9360	43	17B
0005433785033	9360	44	17D
0005435269668	9360	45	17F
0005432665278	9360	46	17G
0005433805436	9360	47	17H
0005433763231	9360	48	18E
0005433784999	9360	49	18D
0005433805441	9360	50	18F
0005433785006	9360	51	18G
0005433805458	9360	52	19E
0005433763232	9360	53	19F
0005433785030	9360	54	19G
0005435269675	9360	55	20A
0005434170975	9360	56	19H
0005433805450	9360	57	20B
0005433805475	9360	58	20E
0005435269686	9360	59	20D
0005433805467	9360	60	21B
0005434170993	9360	61	21D
0005433805449	9360	62	21E
0005433805438	9360	63	21F
0005433785007	9360	64	21G
0005433805456	9360	65	22B
0005434170974	9360	66	23A
0005433763236	9360	67	23D
0005433785036	9360	68	23F
0005433763238	9360	69	23G
0005433805476	9360	70	23H
0005433805446	9360	71	24E
0005432657455	9360	72	24F
0005433805470	9360	73	24G
0005433805460	9360	74	25D
0005433785032	9360	75	24H
0005433785029	9360	76	25E
0005433785003	9360	77	27A
0005434171032	9360	78	25F
0005433785021	9360	79	27D
0005433805439	9360	80	27E
0005433805473	9360	81	27F
0005433763228	9360	82	27G
0005432666392	9360	83	28A
0005434171011	9360	84	28E
0005434170957	9360	85	28F
0005433763227	9360	86	28G
0005432667458	9360	87	29B
0005433763229	9360	88	29A
0005433805443	9360	89	28H
0005433805457	9360	90	29G
0005433785009	9360	91	29F
0005433763237	9360	92	29H
0005433785025	9360	93	30B
0005435269676	9360	94	30F
0005433785034	9360	95	30E
0005433763233	9360	96	30G
0005434170968	9360	97	31A
0005434170970	9360	98	31D
0005433805453	9360	99	31F
0005433785024	9360	100	31E
0005433805455	9360	101	32A
0005433805462	9360	102	31H
0005433785002	9360	103	32B
0005435269667	9360	104	32E
0005434170969	9360	105	33A
0005432667457	9360	106	32H
0005433785023	9360	107	33B
0005433785031	9360	108	33E
0005434170958	9360	109	33H
0005432657454	9360	110	34B
0005433785013	9360	111	34A
0005434170987	9360	112	34F
0005435269674	9360	113	34E
0005433805464	9360	114	34G
0005433785004	9360	115	34H
0005433785005	9360	116	35B
0005433785008	9360	117	35A
0005433785028	9360	118	35D
0005434270202	9360	119	35G
0005433805437	9360	120	35F
0005433805447	9360	121	36D
0005433763242	9360	122	36G
0005433785027	9360	123	37B
0005433785026	9360	124	37E
0005433785015	9360	125	37F
0005433763235	9360	126	37G
0005434270201	9360	127	38A
0005432657453	9360	128	38G
0005435269685	9360	129	38F
0005433805474	9360	130	38H
0005433805452	9360	131	39D
0005433805463	9360	132	39F
0005433763240	9360	133	39E
0005433784557	26270	1	1A
0005433784755	26270	2	1C
0005433805023	26270	3	1F
0005435269755	26270	4	1H
0005433784555	26270	5	2A
0005433805089	26270	6	2C
0005433784751	26270	7	2G
0005433784913	26270	8	3B
0005433805039	26270	9	3H
0005434171082	26270	10	4B
0005433805167	26270	11	4F
0005433805154	26270	12	4G
0005432663023	26270	13	4H
0005433805062	26270	14	5B
0005433763147	26270	15	5A
0005435269751	26270	16	5F
0005432666373	26270	17	5G
0005433784791	26270	18	5H
0005434271315	26270	19	9B
0005433805222	26270	20	9A
0005434151709	26270	21	11A
0005433763081	26270	22	9H
0005433805142	26270	23	11B
0005434269106	26270	24	11D
0005433784534	26270	25	11H
0005433784628	26270	26	11G
0005433763158	26270	27	12B
0005433784779	26270	28	12F
0005434171084	26270	29	12E
0005433784634	26270	30	13A
0005433805163	26270	31	13D
0005434171081	26270	32	13F
0005434171086	26270	33	13G
0005434269105	26270	34	14A
0005433805207	26270	35	13H
0005432659691	26270	36	14B
0005433805206	26270	37	14F
0005434171085	26270	38	14H
0005433805245	26270	39	15F
0005433784649	26270	40	15H
0005433784552	26270	41	16D
0005433784652	26270	42	16G
0005433805082	26270	43	16H
0005433784756	26270	44	17A
0005432659690	26270	45	17E
0005433784771	26270	46	17H
0005434171079	26270	47	18A
0005432666375	26270	48	18D
0005434151710	26270	49	18G
0005433784641	26270	50	18F
0005433784802	26270	51	18H
0005433784512	26270	52	19A
0005433805244	26270	53	19F
0005433805061	26270	54	20A
0005432659685	26270	55	20D
0005434171087	26270	56	20F
0005433805165	26270	57	20H
0005433784749	26270	58	21A
0005432657437	26270	59	21B
0005433784698	26270	60	21E
0005433784650	26270	61	22D
0005433784748	26270	62	22F
0005433784646	26270	63	22G
0005433763141	26270	64	22H
0005433805157	26270	65	23B
0005435269756	26270	66	23F
0005434270208	26270	67	24B
0005433805155	26270	68	24A
0005435269758	26270	69	25D
0005432659689	26270	70	24H
0005433805141	26270	71	25E
0005433784760	26270	72	25F
0005434171078	26270	73	27D
0005434171076	26270	74	27F
0005433763112	26270	75	27E
0005433784705	26270	76	27G
0005433784809	26270	77	28A
0005433805081	26270	78	28D
0005433784754	26270	79	28E
0005433763146	26270	80	28G
0005434171088	26270	81	29D
0005433784640	26270	82	29E
0005433784651	26270	83	29G
0005433763114	26270	84	29F
0005435269757	26270	85	30B
0005433805162	26270	86	30G
0005434171089	26270	87	30H
0005434171077	26270	88	31D
0005433805173	26270	89	31F
0005433784826	26270	90	31G
0005433805194	26270	91	31H
0005433805011	26270	92	32D
0005433805164	26270	93	32B
0005433805243	26270	94	32F
0005435269752	26270	95	32E
0005434271313	26270	96	32G
0005433805324	26270	97	32H
0005433784558	26270	98	33E
0005434270209	26270	99	33D
0005435269753	26270	100	33F
0005434171080	26270	101	33H
0005433784801	26270	102	34A
0005434271314	26270	103	34B
0005433784704	26270	104	34F
0005434171083	26270	105	34E
0005435269754	26270	106	34G
0005433784753	26270	107	34H
0005433784513	26270	108	35B
0005432657436	26270	109	35E
0005433784660	26270	110	36A
0005432657434	26270	111	36D
0005433805022	26270	112	36F
0005433784682	26270	113	36H
0005433784535	26270	114	36G
0005433784914	26270	115	37F
0005432657433	26270	116	37H
0005433763076	26270	117	37G
0005434151708	26270	118	38E
0005433805205	26270	119	38F
0005433805172	26270	120	38H
0005433805166	26270	121	39E
0005435929625	4879	1	5A
0005435135677	4879	2	5B
0005435135678	4879	3	5D
0005435135679	4879	4	7C
0005435135681	4879	5	19C
0005435135680	4879	6	20A
0005435929624	4879	7	22D
0005435135661	33039	1	2B
0005435135641	33039	2	3B
0005435929649	33039	3	6D
0005435135635	33039	4	18A
0005435135655	33039	5	20C
0005435135646	33039	6	22B
0005435135644	33039	7	22D
0005434217931	9504	1	1B
0005434983297	9504	2	6A
0005434217930	9504	3	6C
0005434983298	9504	4	6D
0005434217942	9504	5	7C
0005434983295	9504	6	18A
0005434983299	9504	7	18D
0005434983296	9504	8	20D
0005434217941	9504	9	22B
0005434983249	27347	1	1B
0005434217977	27347	2	4D
0005434983250	27347	3	7C
0005434983248	27347	4	7D
0005434983258	27347	5	18C
0005434217975	27347	6	20A
0005434217976	27347	7	20D
0005434983257	27347	8	23A
0005433960259	24235	1	1H
0005433960365	24235	2	2C
0005433985597	24235	3	2G
0005433985573	24235	4	3F
0005433985277	24235	5	4C
0005433960163	24235	6	4F
0005433960460	24235	7	5A
0005433960371	24235	8	4H
0005433960437	24235	9	5B
0005433960210	24235	10	5H
0005433985577	24235	11	9B
0005433985643	24235	12	9A
0005433960152	24235	13	11F
0005433985451	24235	14	11E
0005433960260	24235	15	12D
0005433985581	24235	16	12F
0005433985548	24235	17	12H
0005433960511	24235	18	12G
0005433985496	24235	19	13D
0005433960104	24235	20	13B
0005433960425	24235	21	13G
0005433985582	24235	22	13H
0005433960219	24235	23	14B
0005433960294	24235	24	14D
0005433960360	24235	25	14G
0005433960440	24235	26	15B
0005433960455	24235	27	15E
0005433985571	24235	28	15F
0005433960387	24235	29	15H
0005433985570	24235	30	16A
0005433960451	24235	31	16D
0005433985459	24235	32	16E
0005433960462	24235	33	17A
0005433985640	24235	34	17D
0005433985614	24235	35	17F
0005433960150	24235	36	18A
0005433960312	24235	37	17H
0005433985563	24235	38	18E
0005433960220	24235	39	18G
0005433959987	24235	40	19E
0005433985632	24235	41	19D
0005433960208	24235	42	19F
0005433985506	24235	43	19H
0005433960458	24235	44	20A
0005433985564	24235	45	20D
0005433960438	24235	46	20G
0005433985495	24235	47	20F
0005433960356	24235	48	21A
0005433960454	24235	49	20H
0005433960295	24235	50	21B
0005433960209	24235	51	21D
0005433960510	24235	52	21F
0005433960185	24235	53	21H
0005433960436	24235	54	21G
0005433985594	24235	55	23A
0005433985403	24235	56	23F
0005433985605	24235	57	23H
0005433985494	24235	58	24A
0005433960523	24235	59	27B
0005433960466	24235	60	27D
0005433985471	24235	61	27G
0005433960459	24235	62	28A
0005433960405	24235	63	28D
0005433960457	24235	64	28H
0005433960313	24235	65	29A
0005433985558	24235	66	29H
0005433985606	24235	67	30D
0005433985565	24235	68	30B
0005433985470	24235	69	30H
0005433985616	24235	70	30F
0005433985617	24235	71	31A
0005433985527	24235	72	31B
0005433985520	24235	73	31E
0005433960483	24235	74	31G
0005433960310	24235	75	32E
0005433985452	24235	76	32F
0005433960286	24235	77	32G
0005433985538	24235	78	33D
0005433959986	24235	79	33H
0005433985521	24235	80	34A
0005433985639	24235	81	34D
0005433960522	24235	82	34B
0005433985562	24235	83	34F
0005433960456	24235	84	34E
0005433960151	24235	85	34G
0005433985627	24235	86	35E
0005433960361	24235	87	35F
0005433985347	24235	88	36A
0005433985595	24235	89	35H
0005433960372	24235	90	37A
0005433985626	24235	91	37B
0005433985625	24235	92	37E
0005433985557	24235	93	37D
0005433960362	24235	94	37F
0005433985537	24235	95	37G
0005433960381	24235	96	38D
0005433985276	24235	97	38E
0005433960311	24235	98	38F
0005433985477	24235	99	38H
0005433985999	25931	1	1C
0005433960930	25931	2	1F
0005433986003	25931	3	1G
0005433960971	25931	4	2F
0005433985991	25931	5	4F
0005433960934	25931	6	4C
0005433960953	25931	7	5A
0005433960937	25931	8	4H
0005433960970	25931	9	5F
0005433986001	25931	10	5C
0005433960923	25931	11	5B
0005433960952	25931	12	5H
0005433985988	25931	13	9G
0005433986023	25931	14	11B
0005433960958	25931	15	11E
0005433960944	25931	16	11D
0005433985996	25931	17	11H
0005433986011	25931	18	12A
0005433985995	25931	19	12D
0005433960957	25931	20	12B
0005433986010	25931	21	12E
0005433986021	25931	22	12G
0005433960942	25931	23	13A
0005433960954	25931	24	14E
0005433960939	25931	25	14G
0005433960961	25931	26	14F
0005433985989	25931	27	15A
0005433960920	25931	28	15E
0005433960965	25931	29	15G
0005433960948	25931	30	15H
0005433985992	25931	31	16B
0005433960964	25931	32	16E
0005433985990	25931	33	16F
0005433985984	25931	34	17D
0005433960960	25931	35	17F
0005433960922	25931	36	17H
0005433960943	25931	37	18B
0005433986014	25931	38	18A
0005433960921	25931	39	18D
0005433986018	25931	40	18E
0005433986005	25931	41	18G
0005433960925	25931	42	18H
0005433985985	25931	43	19B
0005433960929	25931	44	19E
0005433986017	25931	45	19F
0005433960914	25931	46	20F
0005433960947	25931	47	20E
0005433985986	25931	48	20G
0005433986008	25931	49	21B
0005433960933	25931	50	21E
0005433960973	25931	51	21G
0005433960924	25931	52	21F
0005433986019	25931	53	22D
0005433960917	25931	54	22F
0005433986020	25931	55	22G
0005433986012	25931	56	22H
0005433985987	25931	57	23D
0005433960915	25931	58	23F
0005433986022	25931	59	23E
0005433960941	25931	60	23H
0005433985997	25931	61	24A
0005433985993	25931	62	24E
0005433960962	25931	63	24F
0005433960949	25931	64	24H
0005433960919	25931	65	25E
0005433960938	25931	66	25F
0005433960932	25931	67	27D
0005433960913	25931	68	27E
0005433960935	25931	69	27H
0005433960967	25931	70	28A
0005433960945	25931	71	28G
0005433960963	25931	72	29E
0005433960936	25931	73	29H
0005433986009	25931	74	29G
0005433986025	25931	75	30B
0005433960951	25931	76	30E
0005433986024	25931	77	30F
0005433960972	25931	78	30H
0005433960946	25931	79	31A
0005433960916	25931	80	31D
0005433960926	25931	81	32F
0005433960927	25931	82	32G
0005433960969	25931	83	33A
0005433986015	25931	84	33B
0005433986016	25931	85	33H
0005433985998	25931	86	34G
0005433986026	25931	87	34H
0005433960966	25931	88	35D
0005433960928	25931	89	35F
0005433986004	25931	90	35E
0005433986000	25931	91	35G
0005433960955	25931	92	35H
0005433960918	25931	93	36B
0005433986002	25931	94	36H
0005433960931	25931	95	36G
0005433985994	25931	96	37D
0005433986006	25931	97	37B
0005433960968	25931	98	37H
0005433960950	25931	99	37G
0005433960940	25931	100	38D
0005433986007	25931	101	38E
0005433986013	25931	102	38F
0005433960956	25931	103	38H
0005433960959	25931	104	39F
0005434480392	919	1	1A
0005434480369	919	2	1B
0005433165798	919	3	1C
0005434480378	919	4	2A
0005434480368	919	5	2B
0005434480374	919	6	2D
0005433165874	919	7	3B
0005434480388	919	8	3C
0005432269500	919	9	3D
0005434480389	919	10	4A
0005433165831	919	11	4B
0005434480372	919	12	4C
0005434480385	919	13	5A
0005434480367	919	14	5D
0005432269501	919	15	6A
0005434480381	919	16	6C
0005434480384	919	17	6D
0005434480387	919	18	7B
0005434480376	919	19	7C
0005433165830	919	20	7D
0005433165800	919	21	18A
0005434480379	919	22	18B
0005434480373	919	23	18C
0005434480370	919	24	18D
0005433165875	919	25	19B
0005434480386	919	26	19D
0005434480380	919	27	20A
0005434480391	919	28	20B
0005434480377	919	29	20C
0005434480382	919	30	21C
0005434480383	919	31	21B
0005433165812	919	32	21D
0005434480390	919	33	22A
0005434480375	919	34	22B
0005434480371	919	35	22D
0005433165829	919	36	23A
0005433165859	919	37	23B
0005434480083	16598	1	1D
0005434480101	16598	2	2A
0005434480231	16598	3	2B
0005434480146	16598	4	2C
0005433165935	16598	5	3A
0005434480255	16598	6	3C
0005434480302	16598	7	3D
0005434480198	16598	8	4C
0005433165930	16598	9	4D
0005434480100	16598	10	5A
0005433165924	16598	11	5C
0005434480176	16598	12	5D
0005433165931	16598	13	6A
0005434480109	16598	14	6B
0005434480186	16598	15	6C
0005434480134	16598	16	6D
0005434480256	16598	17	7A
0005434480193	16598	18	18A
0005433165926	16598	19	18B
0005433165925	16598	20	18D
0005433165928	16598	21	19C
0005434480261	16598	22	19D
0005434480180	16598	23	20A
0005433165932	16598	24	20B
0005434480110	16598	25	20C
0005433165934	16598	26	20D
0005433165927	16598	27	21A
0005434480133	16598	28	21B
0005434480082	16598	29	21C
0005434480095	16598	30	22A
0005433165929	16598	31	22B
0005434480189	16598	32	22C
0005433165933	16598	33	22D
0005434480230	16598	34	23A
0005434480175	16598	35	23B
0005435150041	10321	1	1B
0005435150040	10321	2	1C
0005435150051	10321	3	1D
0005435142590	10321	4	2A
0005435150044	10321	5	2B
0005433289769	10321	6	2C
0005435150039	10321	7	2D
0005435142595	10321	8	3A
0005435386501	10321	9	3B
0005435386511	10321	10	3C
0005435150042	10321	11	3D
0005435150043	10321	12	4A
0005435142586	10321	13	4C
0005435142593	10321	14	4D
0005435142598	10321	15	5B
0005435150048	10321	16	6A
0005435150047	10321	17	6B
0005433289792	10321	18	6D
0005435142594	10321	19	7A
0005435150049	10321	20	7B
0005435150050	10321	21	7C
0005435142597	10321	22	18A
0005435150037	10321	23	18B
0005435142589	10321	24	18C
0005433289770	10321	25	18D
0005435142588	10321	26	19A
0005435150046	10321	27	19C
0005435150038	10321	28	20A
0005435386526	10321	29	20B
0005435142592	10321	30	20C
0005435142591	10321	31	20D
0005433289791	10321	32	21A
0005435142585	10321	33	21B
0005435386512	10321	34	21C
0005435150045	10321	35	21D
0005433289801	10321	36	22A
0005435142587	10321	37	22B
0005435386500	10321	38	22C
0005433289798	10321	39	23A
0005435142596	10321	40	23B
0005433289871	21942	1	1A
0005435386579	21942	2	1B
0005435142421	21942	3	1C
0005435149910	21942	4	1D
0005435142417	21942	5	2A
0005435386582	21942	6	2C
0005435386580	21942	7	2D
0005435149971	21942	8	3A
0005435149853	21942	9	3C
0005435142465	21942	10	4A
0005435386584	21942	11	4B
0005435142448	21942	12	4C
0005433289867	21942	13	5A
0005435142529	21942	14	5B
0005433289866	21942	15	5C
0005435149962	21942	16	5D
0005435142464	21942	17	6A
0005433289872	21942	18	6B
0005435386581	21942	19	6C
0005435142478	21942	20	6D
0005435142468	21942	21	7A
0005435386586	21942	22	7B
0005433289868	21942	23	7C
0005435142463	21942	24	7D
0005435142440	21942	25	18A
0005435149906	21942	26	18B
0005435142439	21942	27	19A
0005433289870	21942	28	19D
0005433289865	21942	29	20A
0005435142422	21942	30	20B
0005435149909	21942	31	20D
0005435142528	21942	32	21A
0005435142495	21942	33	21B
0005435386585	21942	34	21D
0005433289869	21942	35	22B
0005435142511	21942	36	22D
0005435142512	21942	37	23A
0005435386583	21942	38	23B
0005435502066	11215	1	1A
0005435319508	11215	2	1C
0005434573368	11215	3	1D
0005434573367	11215	4	2A
0005435529126	11215	5	2D
0005435529143	11215	6	2F
0005435529180	11215	7	3A
0005434573373	11215	8	3D
0005435319510	11215	9	3F
0005435319498	11215	10	4A
0005435545707	11215	11	4C
0005434573370	11215	12	4E
0005435545710	11215	13	5D
0005435319551	11215	14	5E
0005435529130	11215	15	5F
0005435319509	11215	16	6A
0005434573374	11215	17	6C
0005435319530	11215	18	6F
0005435529081	11215	19	7C
0005435319531	11215	20	7D
0005435528980	11215	21	7E
0005435529066	11215	22	8A
0005435319552	11215	23	8C
0005435529072	11215	24	8D
0005435502214	11215	25	8E
0005435529107	11215	26	8F
0005435319545	11215	27	9A
0005435319497	11215	28	9C
0005435529129	11215	29	10E
0005435545712	11215	30	10F
0005435502088	11215	31	11A
0005434573361	11215	32	11C
0005435545678	11215	33	11D
0005434573362	11215	34	11E
0005435545655	11215	35	12A
0005435529179	11215	36	12D
0005434573372	11215	37	13A
0005435502159	11215	38	13C
0005435545715	11215	39	13D
0005435529210	11215	40	13F
0005435502158	11215	41	14A
0005435545672	11215	42	14D
0005434573363	11215	43	14E
0005435502195	11215	44	14F
0005435529067	11215	45	15A
0005435529037	11215	46	15C
0005435502154	11215	47	15D
0005435502172	11215	48	15E
0005435528942	11215	49	15F
0005435319515	11215	50	16A
0005435529125	11215	51	16C
0005435545679	11215	52	16D
0005435502202	11215	53	16E
0005435529108	11215	54	16F
0005434573365	11215	55	17A
0005434573364	11215	56	17C
0005435529118	11215	57	17D
0005435529106	11215	58	17F
0005435502194	11215	59	18A
0005435502083	11215	60	18C
0005434573366	11215	61	18D
0005434573369	11215	62	19A
0005435529109	11215	63	19D
0005435545716	11215	64	19E
0005435545680	11215	65	19F
0005435545650	11215	66	20A
0005434573371	11215	67	20C
0005435502224	11215	68	20F
0005435502345	20947	1	1A
0005435319600	20947	2	1C
0005435508390	20947	3	1D
0005435517939	20947	4	1F
0005435319604	20947	5	2A
0005434573261	20947	6	2C
0005435517928	20947	7	2D
0005435502347	20947	8	2F
0005435517945	20947	9	3A
0005435517938	20947	10	3C
0005435517934	20947	11	3D
0005435502350	20947	12	3F
0005435319598	20947	13	4C
0005435508379	20947	14	4F
0005435502344	20947	15	5A
0005435502349	20947	16	5C
0005435502337	20947	17	5E
0005435517941	20947	18	5F
0005435508385	20947	19	6A
0005434573288	20947	20	6C
0005435508382	20947	21	6D
0005435502331	20947	22	6E
0005434573302	20947	23	6F
0005435508383	20947	24	7C
0005435517935	20947	25	7A
0005435502341	20947	26	7F
0005435517932	20947	27	8A
0005435502332	20947	28	8D
0005435517931	20947	29	9A
0005432291932	20947	30	9C
0005435517943	20947	31	9E
0005435502340	20947	32	10A
0005435502335	20947	33	10D
0005435508381	20947	34	10E
0005435508387	20947	35	11A
0005435517936	20947	36	11D
0005435502343	20947	37	11E
0005435502334	20947	38	11F
0005435319599	20947	39	12A
0005435502336	20947	40	12C
0005434573303	20947	41	12D
0005434573226	20947	42	12E
0005435319597	20947	43	12F
0005434573251	20947	44	13C
0005435508380	20947	45	13D
0005435508391	20947	46	13E
0005432291933	20947	47	13F
0005435502339	20947	48	14D
0005432291934	20947	49	14F
0005435319601	20947	50	15A
0005435517944	20947	51	15D
0005435502338	20947	52	15E
0005435508389	20947	53	15F
0005435319603	20947	54	16C
0005435517940	20947	55	16D
0005435502342	20947	56	16E
0005435508386	20947	57	16F
0005435517942	20947	58	17C
0005435517930	20947	59	17D
0005435517937	20947	60	17E
0005435502346	20947	61	18A
0005435517929	20947	62	18C
0005435508388	20947	63	18E
0005435508384	20947	64	18F
0005435502348	20947	65	19A
0005435502333	20947	66	19E
0005435502351	20947	67	20A
0005435319602	20947	68	20D
0005435517933	20947	69	20E
0005435319596	20947	70	20F
0005432692888	3053	1	2A
0005432692983	3053	2	2D
0005432692801	3053	3	4D
0005432692783	3053	4	4E
0005432692802	3053	5	5D
0005432692877	3053	6	6E
0005432692799	3053	7	7A
0005432692789	3053	8	7E
0005432692964	3053	9	8A
0005432692992	3053	10	8C
0005432692993	3053	11	8D
0005432692825	3053	12	9C
0005432692812	3053	13	9E
0005432692761	3053	14	10C
0005432692829	3053	15	11A
0005432692878	3053	16	12C
0005432692791	3053	17	12D
0005432692982	3053	18	14D
0005432692966	3053	19	15A
0005432692758	3053	20	15C
0005432692781	3053	21	15D
0005432692994	3053	22	16A
0005432692762	3053	23	16C
0005432692965	3053	24	17C
0005432692884	3053	25	17D
0005432692889	3053	26	18A
0005432692782	3053	27	19A
0005432692893	3053	28	19E
0005432692728	3053	29	19F
0005432692923	3053	30	20A
0005432692790	3053	31	20D
0005432692800	3053	32	20F
0005432706822	3052	1	1F
0005433123858	3052	2	2A
0005432706809	3052	3	2C
0005432706806	3052	4	2F
0005432706826	3052	5	3C
0005432706818	3052	6	3D
0005433123778	3052	7	3F
0005432706823	3052	8	4A
0005432706828	3052	9	4E
0005433123777	3052	10	4F
0005432706805	3052	11	5A
0005432880732	3052	12	5C
0005433123780	3052	13	5D
0005432880687	3052	14	6A
0005432880714	3052	15	6E
0005433123732	3052	16	7E
0005432706821	3052	17	7F
0005432706808	3052	18	8A
0005432217780	3052	19	8C
0005433123812	3052	20	9C
0005432706816	3052	21	9D
0005432706811	3052	22	9F
0005433123798	3052	23	10A
0005432880769	3052	24	10C
0005433123823	3052	25	10D
0005432880715	3052	26	10E
0005432217781	3052	27	10F
0005433194846	3052	28	11F
0005432706827	3052	29	12A
0005433123813	3052	30	12C
0005432880693	3052	31	12E
0005432880712	3052	32	12F
0005432706825	3052	33	13A
0005433123712	3052	34	13C
0005432880742	3052	35	13D
0005432706820	3052	36	13E
0005432706817	3052	37	13F
0005432880679	3052	38	14A
0005432880717	3052	39	14C
0005432706810	3052	40	14D
0005432880718	3052	41	14E
0005432217782	3052	42	14F
0005432706814	3052	43	15C
0005433123797	3052	44	15D
0005432706819	3052	45	15E
0005432880733	3052	46	15F
0005433123826	3052	47	16A
0005432706813	3052	48	16C
0005433123733	3052	49	16D
0005433123717	3052	50	17A
0005432706812	3052	51	17C
0005432706829	3052	52	17E
0005433123711	3052	53	17F
0005432880686	3052	54	18D
0005432706815	3052	55	18E
0005433194833	3052	56	19D
0005432706830	3052	57	19E
0005433123740	3052	58	19F
0005432880770	3052	59	20C
0005432706807	3052	60	20E
0005432706824	3052	61	20F
0005432706606	29999	1	1A
0005432880840	29999	2	1C
0005432880841	29999	3	1D
0005432693149	29999	4	1F
0005432706665	29999	5	2A
0005432693139	29999	6	2C
0005433123965	29999	7	2D
0005432693146	29999	8	2F
0005432693127	29999	9	3A
0005433123962	29999	10	3C
0005432693134	29999	11	3D
0005432706568	29999	12	3F
0005432693150	29999	13	4A
0005432693154	29999	14	4C
0005432693144	29999	15	4D
0005432706608	29999	16	4E
0005432693147	29999	17	4F
0005432880851	29999	18	5A
0005432706634	29999	19	5C
0005433123955	29999	20	5D
0005433123964	29999	21	5E
0005432706677	29999	22	5F
0005433123957	29999	23	6A
0005432706607	29999	24	6C
0005432880844	29999	25	6D
0005432706667	29999	26	6E
0005433123971	29999	27	6F
0005432693143	29999	28	7A
0005432706556	29999	29	7C
0005433123958	29999	30	7D
0005432706678	29999	31	7E
0005432706599	29999	32	7F
0005433123968	29999	33	8A
0005432693153	29999	34	8C
0005432706681	29999	35	8D
0005432880846	29999	36	8E
0005432706635	29999	37	8F
0005433123961	29999	38	9A
0005432880839	29999	39	9C
0005432693152	29999	40	9D
0005432880847	29999	41	9E
0005432693155	29999	42	9F
0005432880838	29999	43	10A
0005432706682	29999	44	10C
0005432706652	29999	45	10D
0005432706662	29999	46	10E
0005432693131	29999	47	10F
0005432706630	29999	48	11A
0005432693137	29999	49	11C
0005432693142	29999	50	11D
0005432880848	29999	51	11E
0005433123960	29999	52	11F
0005432880849	29999	53	12A
0005432880843	29999	54	12C
0005432693138	29999	55	12D
0005432693129	29999	56	12E
0005432693157	29999	57	12F
0005432706609	29999	58	13A
0005432693145	29999	59	13C
0005432706655	29999	60	13D
0005432880842	29999	61	13E
0005432706631	29999	62	13F
0005433123963	29999	63	14A
0005433123959	29999	64	14C
0005432706605	29999	65	14D
0005432693156	29999	66	14E
0005432706654	29999	67	14F
0005432706663	29999	68	15A
0005432706651	29999	69	15C
0005433123972	29999	70	15D
0005432706548	29999	71	15E
0005433123969	29999	72	15F
0005432693148	29999	73	16A
0005432693135	29999	74	16C
0005432706640	29999	75	16D
0005432880837	29999	76	16E
0005432693136	29999	77	16F
0005433123966	29999	78	17A
0005433123967	29999	79	17C
0005433123954	29999	80	17D
0005432693130	29999	81	17E
0005432693132	29999	82	17F
0005433123970	29999	83	18A
0005433123973	29999	84	18C
0005432693133	29999	85	18D
0005432693151	29999	86	18E
0005432693141	29999	87	18F
0005432880845	29999	88	19A
0005432693128	29999	89	19C
0005432693158	29999	90	19D
0005432706666	29999	91	19E
0005432706653	29999	92	19F
0005432706610	29999	93	20A
0005433123956	29999	94	20C
0005432880850	29999	95	20D
0005432693140	29999	96	20E
0005432880836	29999	97	20F
0005434979835	23666	1	1A
0005434979833	23666	2	1B
0005434979818	23666	3	1D
0005434979819	23666	4	2A
0005434988754	23666	5	2B
0005434988762	23666	6	2C
0005434979831	23666	7	2D
0005434979810	23666	8	3A
0005434979820	23666	9	3D
0005434988753	23666	10	4B
0005434979816	23666	11	4C
0005434979832	23666	12	4D
0005434988761	23666	13	5A
0005434979827	23666	14	5B
0005434988752	23666	15	5C
0005434988755	23666	16	5D
0005434988757	23666	17	6A
0005434979836	23666	18	6C
0005434979822	23666	19	6D
0005434979829	23666	20	7A
0005434979812	23666	21	7B
0005434979834	23666	22	7C
0005434979826	23666	23	18A
0005434988756	23666	24	18B
0005434979809	23666	25	18C
0005434988760	23666	26	18D
0005434979821	23666	27	19B
0005434979815	23666	28	19C
0005434979814	23666	29	19D
0005434979808	23666	30	20A
0005434979817	23666	31	20B
0005434979806	23666	32	20C
0005434979807	23666	33	20D
0005434979823	23666	34	21A
0005434979828	23666	35	21B
0005434988759	23666	36	21C
0005434979825	23666	37	21D
0005434979813	23666	38	22A
0005434979811	23666	39	22B
0005434979824	23666	40	22C
0005434988758	23666	41	22D
0005434979830	23666	42	23B
0005434979656	27571	1	1A
0005434988656	27571	2	1D
0005434979517	27571	3	2A
0005434979630	27571	4	2D
0005434988623	27571	5	3A
0005434988655	27571	6	3B
0005434979629	27571	7	3D
0005434979644	27571	8	4A
0005434988624	27571	9	4D
0005434979469	27571	10	5A
0005434988642	27571	11	5B
0005434988622	27571	12	5C
0005434979472	27571	13	6A
0005434988665	27571	14	6B
0005434979645	27571	15	6C
0005434979564	27571	16	7B
0005434979468	27571	17	7C
0005434979631	27571	18	7D
0005434979609	27571	19	18A
0005434979643	27571	20	18C
0005434979447	27571	21	18D
0005434988654	27571	22	19B
0005434988620	27571	23	20B
0005434979588	27571	24	20C
0005434988677	27571	25	21B
0005434979519	27571	26	21C
0005434979524	27571	27	21D
0005434988634	27571	28	22A
0005434979569	27571	29	22B
0005434988621	27571	30	22C
0005434979520	27571	31	22D
0005434979473	27571	32	23B
0005433111495	10299	1	2A
0005433113515	10299	2	2D
0005433113516	10299	3	3B
0005434302462	10299	4	4A
0005433111492	10299	5	4D
0005434302466	10299	6	5C
0005434302463	10299	7	6D
0005434302465	10299	8	7B
0005433111494	10299	9	18B
0005433111493	10299	10	19A
0005433113513	10299	11	19D
0005433113523	10299	12	20B
0005433113514	10299	13	20D
0005434302464	10299	14	22A
0005434302416	19637	1	6B
0005434302419	19637	2	19B
0005433113539	19637	3	19D
0005433113540	19637	4	20B
0005434302427	19637	5	20D
0005433113541	19637	6	21A
0005434302417	19637	7	21B
0005434302418	19637	8	21D
0005435069171	3532	1	1C
0005435925213	3532	2	1D
0005435069168	3532	3	1F
0005435069209	3532	4	2A
0005435069172	3532	5	2C
0005435925197	3532	6	2D
0005435069206	3532	7	2F
0005435069197	3532	8	3A
0005435069187	3532	9	3C
0005435069170	3532	10	3D
0005435069167	3532	11	3F
0005435718954	3532	12	4C
0005435925188	3532	13	4D
0005435925108	3532	14	4E
0005435069199	3532	15	4F
0005435925201	3532	16	5A
0005435069180	3532	17	5D
0005435069207	3532	18	5F
0005435069193	3532	19	6C
0005435069216	3532	20	6D
0005435939868	3532	21	6E
0005435925174	3532	22	6F
0005435069181	3532	23	7C
0005435925206	3532	24	7D
0005435069214	3532	25	7E
0005435718958	3532	26	7F
0005435069169	3532	27	8A
0005435069179	3532	28	8C
0005435069192	3532	29	8D
0005435718960	3532	30	8E
0005435069194	3532	31	9C
0005435069198	3532	32	9D
0005435069189	3532	33	9F
0005435069185	3532	34	10A
0005435069200	3532	35	10C
0005435718956	3532	36	10D
0005435069211	3532	37	10E
0005435069182	3532	38	10F
0005435925204	3532	39	11A
0005435069212	3532	40	11C
0005435718957	3532	41	11D
0005435925158	3532	42	11E
0005435069184	3532	43	11F
0005435069210	3532	44	12A
0005435069175	3532	45	12C
0005435925216	3532	46	12D
0005435069215	3532	47	12E
0005435069196	3532	48	12F
0005435069213	3532	49	13A
0005435925198	3532	50	13C
0005435718959	3532	51	13D
0005435069176	3532	52	13E
0005435069208	3532	53	13F
0005435925218	3532	54	14A
0005435069217	3532	55	14C
0005435069205	3532	56	14D
0005435925211	3532	57	14F
0005435069188	3532	58	15A
0005435069203	3532	59	15F
0005435718961	3532	60	16C
0005435069174	3532	61	16D
0005435925151	3532	62	16F
0005435925215	3532	63	17A
0005435069186	3532	64	17C
0005435950296	3532	65	17D
0005435069190	3532	66	17F
0005435069183	3532	67	18A
0005435069202	3532	68	18C
0005435069173	3532	69	18D
0005435069178	3532	70	18E
0005435718955	3532	71	19A
0005435069191	3532	72	19C
0005435069177	3532	73	19E
0005435069195	3532	74	20C
0005435069201	3532	75	20D
0005435069204	3532	76	20E
0005435925202	3532	77	20F
0005435068626	15328	1	1C
0005435068802	15328	2	1F
0005435068787	15328	3	2A
0005435068692	15328	4	2C
0005435925315	15328	5	3A
0005435925305	15328	6	3C
0005435925313	15328	7	3D
0005435925314	15328	8	3F
0005435068436	15328	9	4A
0005435925312	15328	10	4C
0005435068688	15328	11	4D
0005435068770	15328	12	4E
0005435068624	15328	13	5C
0005435925321	15328	14	5D
0005435068598	15328	15	5E
0005435068597	15328	16	5F
0005435068707	15328	17	6A
0005435068826	15328	18	6D
0005435068619	15328	19	6E
0005435925308	15328	20	6F
0005435068712	15328	21	7C
0005435068861	15328	22	7E
0005435925307	15328	23	8C
0005435925320	15328	24	8E
0005435068846	15328	25	8F
0005435068789	15328	26	9A
0005435925318	15328	27	9C
0005435068734	15328	28	9D
0005435068804	15328	29	9E
0005435068643	15328	30	10A
0005435925309	15328	31	10C
0005435068466	15328	32	10D
0005435925306	15328	33	10F
0005435068717	15328	34	11A
0005435068803	15328	35	11F
0005435068784	15328	36	12A
0005435068725	15328	37	12C
0005435925322	15328	38	12D
0005435925324	15328	39	12E
0005435068778	15328	40	12F
0005435925317	15328	41	13A
0005435925319	15328	42	13D
0005435068835	15328	43	13E
0005435068620	15328	44	13F
0005435925311	15328	45	14C
0005435068540	15328	46	14D
0005435925310	15328	47	14E
0005435068524	15328	48	14F
0005435068641	15328	49	15C
0005435068642	15328	50	15D
0005435068799	15328	51	15E
0005435939882	15328	52	15F
0005435068733	15328	53	16C
0005435068859	15328	54	16E
0005435925316	15328	55	16F
0005435925323	15328	56	17D
0005435068539	15328	57	17F
0005435068761	15328	58	18A
0005435068567	15328	59	18D
0005435068614	15328	60	18F
0005435068621	15328	61	19C
0005435068704	15328	62	19D
0005435068592	15328	63	19F
0005435068736	15328	64	20C
0005435068737	15328	65	20F
0005432660822	18159	1	2A
0005432659709	18159	2	2B
0005432659710	18159	3	5A
0005432658595	18159	4	6A
0005432660821	18159	5	6B
0005432667435	26434	1	1A
0005432660793	26434	2	1B
0005432664116	26434	3	2A
0005432664126	26434	4	2B
0005432664123	26434	5	3B
0005432667436	26434	6	4B
0005432667442	26434	7	5B
0005432664115	26434	8	5A
0005432664121	26434	9	6A
0005432664124	26434	10	6B
0005432901529	223	1	1D
0005432919661	223	2	2A
0005432919657	223	3	1F
0005433101674	223	4	2D
0005433101859	223	5	2F
0005433101837	223	6	3C
0005433101752	223	7	3F
0005433101809	223	8	3D
0005433101810	223	9	4A
0005433101778	223	10	4D
0005432901525	223	11	4C
0005433101803	223	12	5A
0005432919696	223	13	4F
0005432919721	223	14	5D
0005432901524	223	15	5C
0005433101735	223	16	5F
0005432677547	223	17	7A
0005433101680	223	18	7D
0005432919641	223	19	8A
0005432901498	223	20	8C
0005433101714	223	21	8B
0005433101700	223	22	8D
0005433101857	223	23	8E
0005432901506	223	24	9D
0005433101607	223	25	9C
0005432919695	223	26	9E
0005433101830	223	27	10A
0005432901488	223	28	10B
0005432677536	223	29	11A
0005433101753	223	30	11C
0005432919764	223	31	11D
0005432919779	223	32	11E
0005433101658	223	33	11F
0005433101853	223	34	12D
0005433101498	223	35	12C
0005432919672	223	36	12F
0005433101635	223	37	13D
0005432157495	223	38	13E
0005433101651	223	39	14A
0005432919720	223	40	14B
0005432901526	223	41	14D
0005433101844	223	42	14C
0005433101834	223	43	15A
0005432901505	223	44	15D
0005433101593	223	45	16B
0005433101755	223	46	16D
0005432919731	223	47	16C
0005433101661	223	48	16F
0005432919826	223	49	16E
0005433101675	223	50	17B
0005433101659	223	51	17C
0005433101856	223	52	17D
0005433101754	223	53	17E
0005433101862	223	54	18A
0005432901533	223	55	17F
0005433101774	223	56	18B
0005432901532	223	57	18E
0005432901528	223	58	19D
0005432901584	223	59	20C
0005432901502	223	60	20E
0005432919814	223	61	21A
0005433101845	223	62	21C
0005432677535	223	63	21E
0005433101614	223	64	22B
0005432919815	223	65	22C
0005433101676	223	66	23B
0005433101831	223	67	23A
0005433101795	223	68	23C
0005433101775	223	69	23D
0005432901487	223	70	23E
0005433101812	223	71	24C
0005432919739	223	72	24F
0005433101758	223	73	25B
0005433101805	223	74	25C
0005433101804	223	75	25D
0005432157496	223	76	25F
0005433101679	223	77	25E
0005432901486	223	78	26A
0005432919656	223	79	26D
0005433101833	223	80	26C
0005432919594	223	81	26E
0005433101843	223	82	27B
0005432919687	223	83	27C
0005433101742	223	84	27D
0005432919827	223	85	28A
0005433101826	223	86	28D
0005432919642	223	87	28E
0005433101660	223	88	29B
0005433101723	223	89	29A
0005433101823	223	90	29C
0005433101497	223	91	29E
0005432677546	223	92	29D
0005433101824	223	93	29F
0005433101705	223	94	30B
0005432919756	223	95	30E
0005432919732	223	96	30F
0005433101836	223	97	31C
0005433101645	223	98	31D
0005432901477	223	99	31F
0005433101825	223	100	31E
0005432817543	224	1	1C
0005432817544	224	2	1A
0005432262010	224	3	2A
0005432756820	224	4	1F
0005432262018	224	5	2C
0005432817519	224	6	3C
0005432753283	224	7	3D
0005432817534	224	8	4A
0005432817539	224	9	4C
0005432261993	224	10	4D
0005432262017	224	11	5A
0005432817523	224	12	5C
0005432817531	224	13	5D
0005432262016	224	14	6A
0005432261997	224	15	6C
0005432262019	224	16	7A
0005432817521	224	17	7C
0005432262006	224	18	7F
0005432262015	224	19	8A
0005432261996	224	20	8B
0005432753280	224	21	8D
0005432261999	224	22	8E
0005432262011	224	23	8F
0005432261982	224	24	9C
0005432817542	224	25	9E
0005433687679	224	26	10A
0005432817532	224	27	10C
0005432261988	224	28	10B
0005432262009	224	29	10E
0005432261976	224	30	11B
0005432261985	224	31	11A
0005432262005	224	32	11D
0005434153536	224	33	12A
0005432817540	224	34	11F
0005432817528	224	35	12B
0005432262000	224	36	12F
0005432262012	224	37	13B
0005432262022	224	38	13D
0005432817529	224	39	13F
0005432262001	224	40	14A
0005432288992	224	41	14C
0005432817526	224	42	14F
0005432817530	224	43	15C
0005432261991	224	44	15B
0005432262004	224	45	16A
0005432817525	224	46	16B
0005434153538	224	47	16D
0005432261989	224	48	16C
0005432261994	224	49	16F
0005432261995	224	50	16E
0005432817517	224	51	17C
0005432817545	224	52	17E
0005432262002	224	53	18A
0005432262003	224	54	18D
0005432817516	224	55	19B
0005432207665	224	56	19D
0005432817535	224	57	19E
0005432753274	224	58	20A
0005432817518	224	59	20D
0005432262023	224	60	20F
0005432288993	224	61	21B
0005432817538	224	62	21A
0005432261984	224	63	21D
0005432261979	224	64	21E
0005432261990	224	65	22C
0005432262020	224	66	22F
0005432262013	224	67	23C
0005432753273	224	68	23F
0005433687678	224	69	23E
0005432261977	224	70	24A
0005432261983	224	71	24B
0005432261987	224	72	24E
0005432817541	224	73	25B
0005432261978	224	74	25E
0005432261980	224	75	25D
0005432261981	224	76	25F
0005434153537	224	77	26C
0005432262008	224	78	26B
0005432817537	224	79	26E
0005432261998	224	80	26F
0005432817527	224	81	27B
0005432262007	224	82	27C
0005432207664	224	83	28A
0005432261986	224	84	28B
0005432753281	224	85	28D
0005432817524	224	86	28E
0005432262014	224	87	28F
0005434153535	224	88	29C
0005432261992	224	89	29B
0005432753282	224	90	30A
0005432817520	224	91	30F
0005432817536	224	92	31A
0005432817522	224	93	31B
0005432262021	224	94	31D
0005432817533	224	95	31F
0005432045618	8006	1	1A
0005433102268	8006	2	1F
0005432919889	8006	3	2C
0005432751532	8006	4	2F
0005432919904	8006	5	2D
0005432919890	8006	6	3D
0005432020306	8006	7	3C
0005433102256	8006	8	3A
0005433102246	8006	9	4A
0005432919891	8006	10	3F
0005432919902	8006	11	4F
0005433102292	8006	12	4D
0005432044529	8006	13	5F
0005433102273	8006	14	6C
0005432020324	8006	15	6F
0005432919896	8006	16	6D
0005432020302	8006	17	7A
0005433102283	8006	18	7C
0005433102240	8006	19	7D
0005432020312	8006	20	8A
0005432020318	8006	21	8C
0005433102276	8006	22	8B
0005432020304	8006	23	8E
0005433102263	8006	24	8D
0005433102291	8006	25	9B
0005432392005	8006	26	9A
0005433102288	8006	27	9C
0005433102278	8006	28	9E
0005433102241	8006	29	9D
0005433102287	8006	30	10B
0005432919895	8006	31	10E
0005432919897	8006	32	10F
0005433102269	8006	33	11A
0005432020305	8006	34	11C
0005432751535	8006	35	11B
0005432020308	8006	36	11D
0005432020328	8006	37	11F
0005433102251	8006	38	12A
0005432045617	8006	39	12B
0005432919905	8006	40	12C
0005432020303	8006	41	12E
0005433102286	8006	42	13C
0005432020307	8006	43	13F
0005433102259	8006	44	14A
0005433102279	8006	45	15A
0005432044530	8006	46	14F
0005432020316	8006	47	15C
0005433102281	8006	48	15B
0005432020325	8006	49	15F
0005432919898	8006	50	15E
0005433102280	8006	51	16A
0005433102267	8006	52	16B
0005432020323	8006	53	16E
0005432919888	8006	54	17B
0005432392006	8006	55	17A
0005432751533	8006	56	17C
0005432020317	8006	57	17D
0005432753309	8006	58	17F
0005432020319	8006	59	17E
0005432020327	8006	60	18A
0005432919907	8006	61	18B
0005432020301	8006	62	18D
0005433102284	8006	63	18C
0005432751536	8006	64	18E
0005432751534	8006	65	18F
0005432020309	8006	66	19B
0005432919908	8006	67	19C
0005432020315	8006	68	20D
0005433102274	8006	69	20C
0005433102289	8006	70	20F
0005433102254	8006	71	21B
0005433102270	8006	72	21A
0005432919901	8006	73	21C
0005433102272	8006	74	21D
0005433102285	8006	75	21F
0005432020322	8006	76	21E
0005432020321	8006	77	22B
0005432020311	8006	78	22A
0005433102282	8006	79	22C
0005432677582	8006	80	22E
0005432677583	8006	81	22D
0005432919894	8006	82	22F
0005432020320	8006	83	23B
0005433102271	8006	84	23A
0005433102266	8006	85	23C
0005433102257	8006	86	23D
0005433102243	8006	87	23F
0005432919899	8006	88	23E
0005433102244	8006	89	24A
0005433102277	8006	90	24D
0005432919892	8006	91	25B
0005433102260	8006	92	25D
0005433102242	8006	93	25C
0005432020314	8006	94	25E
0005433102245	8006	95	26A
0005432919906	8006	96	25F
0005433102264	8006	97	26D
0005432753307	8006	98	26C
0005433102261	8006	99	26F
0005432677584	8006	100	26E
0005432020313	8006	101	27A
0005432020300	8006	102	27C
0005432919903	8006	103	27B
0005432919900	8006	104	27D
0005433102250	8006	105	27E
0005433102262	8006	106	28A
0005432753308	8006	107	27F
0005433102290	8006	108	28B
0005432753310	8006	109	28D
0005433102265	8006	110	28C
0005433102248	8006	111	28F
0005432044531	8006	112	29B
0005433102255	8006	113	29E
0005433102247	8006	114	30A
0005433102249	8006	115	29F
0005432020310	8006	116	30D
0005433102258	8006	117	30C
0005433102275	8006	118	30F
0005433102253	8006	119	31B
0005433102252	8006	120	31A
0005432020326	8006	121	31D
0005432919893	8006	122	31C
0005432901652	8007	1	1D
0005432817301	8007	2	4D
0005432901651	8007	3	5A
0005432901650	8007	4	5D
0005432901640	8007	5	5C
0005432901648	8007	6	6C
0005432817211	8007	7	7C
0005432901643	8007	8	8B
0005432901636	8007	9	8D
0005432002079	8007	10	8E
0005432817275	8007	11	9E
0005432817401	8007	12	10B
0005432817320	8007	13	11A
0005432817225	8007	14	11F
0005432901635	8007	15	11E
0005432817171	8007	16	13F
0005432002081	8007	17	15A
0005432817253	8007	18	15B
0005432817359	8007	19	15E
0005432817353	8007	20	16A
0005432817210	8007	21	16C
0005432901639	8007	22	16B
0005432817286	8007	23	16D
0005432817185	8007	24	16E
0005432901645	8007	25	17B
0005432817170	8007	26	17D
0005432901649	8007	27	19B
0005432901647	8007	28	20B
0005432817418	8007	29	21A
0005432901642	8007	30	21B
0005432817267	8007	31	21D
0005432901641	8007	32	21F
0005432901637	8007	33	22E
0005432817268	8007	34	25A
0005432817289	8007	35	26D
0005432817285	8007	36	27A
0005432817311	8007	37	27C
0005432817310	8007	38	27B
0005432817419	8007	39	28A
0005432901638	8007	40	28B
0005432002080	8007	41	28C
0005432901644	8007	42	28D
0005432901646	8007	43	31E
0005434175720	9678	1	1A
0005434175740	9678	2	1B
0005434175738	9678	3	2A
0005433870734	9678	4	2B
0005434175737	9678	5	3A
0005434175739	9678	6	3B
0005433870735	9678	7	4A
0005434175741	9678	8	4B
0005434175719	9678	9	5A
0005433870736	9678	10	5B
0005433870737	9678	11	6B
0005434175761	32347	1	1A
0005434175760	32347	2	1B
0005434175759	32347	3	3A
0005434175762	32347	4	3B
0005433870721	32347	5	4B
0005433870722	32347	6	6A
0005435902616	3476	1	1D
0005432799514	3476	2	1A
0005434938176	3476	3	1K
0005434878411	3476	4	1H
0005434878458	3476	5	2D
0005432613870	3476	6	2C
0005435913899	3476	7	2A
0005434878438	3476	8	2H
0005432799517	3476	9	2G
0005435126450	3476	10	3A
0005435126454	3476	11	2K
0005434426657	3476	12	3G
0005435126441	3476	13	3D
0005434878392	3476	14	3C
0005435841087	3476	15	3H
0005434938188	3476	16	4C
0005434426686	3476	17	4A
0005435626200	3476	18	3K
0005434878482	3476	19	4D
0005435841088	3476	20	4K
0005434426681	3476	21	4H
0005434878440	3476	22	5C
0005435126459	3476	23	5A
0005434878425	3476	24	5H
0005434878480	3476	25	5G
0005434878445	3476	26	5D
0005434938191	3476	27	11A
0005435126444	3476	28	5K
0005434938179	3476	29	11D
0005434426673	3476	30	11C
0005434878435	3476	31	11H
0005434426658	3476	32	11G
0005435626206	3476	33	11K
0005435902594	3476	34	12F
0005435626209	3476	35	12G
0005435902605	3476	36	13A
0005435126455	3476	37	12H
0005434878475	3476	38	13D
0005434938184	3476	39	13C
0005435626205	3476	40	13F
0005434878391	3476	41	13E
0005434878472	3476	42	13H
0005434878448	3476	43	14C
0005432799506	3476	44	14A
0005434878471	3476	45	14D
0005434878427	3476	46	14G
0005434878457	3476	47	14F
0005435913894	3476	48	14E
0005435126448	3476	49	14K
0005435913893	3476	50	14H
0005435126471	3476	51	15D
0005435126457	3476	52	15H
0005432799509	3476	53	15G
0005434878397	3476	54	15F
0005434426662	3476	55	15K
0005435126447	3476	56	16D
0005432799504	3476	57	16A
0005434938174	3476	58	16G
0005434426661	3476	59	16F
0005432799511	3476	60	16E
0005434426670	3476	61	16H
0005434878451	3476	62	17C
0005434938183	3476	63	17A
0005435126463	3476	64	17G
0005434878433	3476	65	18E
0005434878401	3476	66	18D
0005432799527	3476	67	18C
0005435913905	3476	68	18G
0005434938189	3476	69	18F
0005434878428	3476	70	18J
0005435126475	3476	71	18H
0005435913901	3476	72	19A
0005435626210	3476	73	18K
0005434426660	3476	74	19C
0005435626195	3476	75	19B
0005434426679	3476	76	19F
0005435126438	3476	77	19E
0005434878439	3476	78	19H
0005434878429	3476	79	19G
0005435626194	3476	80	19J
0005435902565	3476	81	20C
0005432799512	3476	82	20B
0005435902640	3476	83	20H
0005434938192	3476	84	20G
0005434878424	3476	85	20F
0005435126468	3476	86	20K
0005434878444	3476	87	20J
0005434878464	3476	88	21A
0005434878443	3476	89	21D
0005435902606	3476	90	21F
0005432799526	3476	91	21E
0005435626214	3476	92	21J
0005435902595	3476	93	22C
0005434878450	3476	94	22D
0005435626202	3476	95	22H
0005434938186	3476	96	22G
0005435126472	3476	97	22F
0005435626197	3476	98	22J
0005432799510	3476	99	23B
0005434878413	3476	100	23A
0005434426659	3476	101	23C
0005434878442	3476	102	23G
0005434878396	3476	103	23E
0005435626196	3476	104	23J
0005434426677	3476	105	23H
0005435626204	3476	106	24D
0005432188613	3476	107	23K
0005434878398	3476	108	24F
0005432799529	3476	109	24E
0005435902654	3476	110	25D
0005432799524	3476	111	25B
0005432611720	3476	112	25E
0005434878390	3476	113	25H
0005435126445	3476	114	25K
0005434426667	3476	115	25J
0005432183471	3476	116	26C
0005434878410	3476	117	26B
0005435126456	3476	118	26A
0005435126460	3476	119	26E
0005434878415	3476	120	26H
0005434878406	3476	121	26G
0005432611718	3476	122	27B
0005432799523	3476	123	26K
0005435126464	3476	124	27C
0005434938175	3476	125	27E
0005435626208	3476	126	27H
0005434878468	3476	127	27G
0005435902639	3476	128	28A
0005434938177	3476	129	27K
0005435626215	3476	130	28C
0005434878449	3476	131	28E
0005434878437	3476	132	28D
0005434878402	3476	133	28G
0005434878479	3476	134	28F
0005435913902	3476	135	28H
0005432799513	3476	136	29B
0005435126453	3476	137	28K
0005435902608	3476	138	29C
0005435902581	3476	139	29F
0005434878419	3476	140	29D
0005435126462	3476	141	29H
0005435913885	3476	142	29K
0005435126458	3476	143	29J
0005434878460	3476	144	30C
0005434878394	3476	145	30A
0005435902580	3476	146	30E
0005432613869	3476	147	30D
0005435902530	3476	148	30G
0005434878441	3476	149	30F
0005434878423	3476	150	30J
0005434878436	3476	151	31B
0005435126474	3476	152	30K
0005434878463	3476	153	31D
0005434878465	3476	154	31C
0005434878416	3476	155	31E
0005435126467	3476	156	31H
0005434426664	3476	157	31G
0005434878470	3476	158	31K
0005435626213	3476	159	32C
0005434938181	3476	160	32B
0005432799519	3476	161	32G
0005432188615	3476	162	32F
0005435626216	3476	163	32K
0005435126473	3476	164	32J
0005435902551	3476	165	32H
0005432799518	3476	166	33B
0005432799507	3476	167	33A
0005434878456	3476	168	33D
0005434878474	3476	169	33E
0005434878469	3476	170	33H
0005435126466	3476	171	33G
0005434426665	3476	172	33K
0005435626212	3476	173	34C
0005435126477	3476	174	34B
0005435902601	3476	175	34E
0005432188614	3476	176	34D
0005435902501	3476	177	34F
0005434426668	3476	178	35D
0005434878393	3476	179	35C
0005435126449	3476	180	35F
0005434878477	3476	181	35E
0005435126440	3476	182	35J
0005435626199	3476	183	35H
0005434878452	3476	184	35G
0005434426675	3476	185	35K
0005434878422	3476	186	36B
0005432799528	3476	187	36E
0005432799530	3476	188	36D
0005435626217	3476	189	36G
0005434878454	3476	190	36K
0005432799516	3476	191	36J
0005432799515	3476	192	37B
0005432799520	3476	193	37D
0005435126465	3476	194	37C
0005435626198	3476	195	37F
0005434426683	3476	196	37E
0005435902612	3476	197	37H
0005432799505	3476	198	38A
0005434878407	3476	199	37K
0005434426684	3476	200	37J
0005434938190	3476	201	38B
0005434426676	3476	202	38J
0005435902611	3476	203	39B
0005434426671	3476	204	38K
0005434878414	3476	205	39D
0005434878453	3476	206	39C
0005435126479	3476	207	39G
0005434878399	3476	208	39F
0005435913908	3476	209	39H
0005434878408	3476	210	39K
0005434878409	3476	211	39J
0005434878412	3476	212	40C
0005434938182	3476	213	40B
0005434878447	3476	214	40E
0005432613871	3476	215	40D
0005434878473	3476	216	40K
0005435841815	3476	217	40J
0005434878432	3476	218	40H
0005434878478	3476	219	41B
0005434878395	3476	220	41D
0005434938185	3476	221	41C
0005432183472	3476	222	41G
0005435126480	3476	223	41F
0005435626211	3476	224	41J
0005435902615	3476	225	42A
0005434878455	3476	226	41K
0005434878476	3476	227	42C
0005434878462	3476	228	42B
0005432611717	3476	229	42F
0005434878431	3476	230	42E
0005434426678	3476	231	42D
0005435126442	3476	232	42G
0005434878430	3476	233	42K
0005435126446	3476	234	42H
0005435126439	3476	235	43D
0005434878466	3476	236	43C
0005434878420	3476	237	43B
0005432799502	3476	238	43H
0005434426680	3476	239	43G
0005435626207	3476	240	43K
0005434426682	3476	241	43J
0005432799521	3476	242	44C
0005434878421	3476	243	44B
0005434878405	3476	244	44E
0005434878467	3476	245	44D
0005435126478	3476	246	44F
0005434426685	3476	247	44K
0005434426663	3476	248	44H
0005432799503	3476	249	45A
0005435626193	3476	250	45C
0005434878400	3476	251	45B
0005434878403	3476	252	45F
0005435126476	3476	253	45E
0005435126469	3476	254	45J
0005432799508	3476	255	45G
0005432613868	3476	256	45K
0005434878459	3476	257	46C
0005434878481	3476	258	46B
0005434878461	3476	259	46A
0005434938178	3476	260	46E
0005434938180	3476	261	46F
0005435841816	3476	262	46J
0005434938187	3476	263	46H
0005432799525	3476	264	47A
0005435126443	3476	265	47D
0005434878404	3476	266	47C
0005434878418	3476	267	47F
0005435126451	3476	268	47K
0005435126470	3476	269	47H
0005434426672	3476	270	48C
0005434878417	3476	271	48A
0005435902582	3476	272	48F
0005432799522	3476	273	48E
0005435126461	3476	274	48H
0005434426674	3476	275	49A
0005434878434	3476	276	48K
0005432611719	3476	277	49F
0005435626201	3476	278	49K
0005434878426	3476	279	49H
0005435126452	3476	280	50C
0005435913900	3476	281	50E
0005435902521	3476	282	50D
0005434426669	3476	283	50F
0005435626203	3476	284	50K
0005434426666	3476	285	51E
0005434878446	3476	286	51G
0005434877263	14583	1	1C
0005434426349	14583	2	1K
0005435126137	14583	3	1H
0005434938015	14583	4	2C
0005434877542	14583	5	2A
0005435126206	14583	6	2H
0005434938012	14583	7	2G
0005435126019	14583	8	2D
0005434877755	14583	9	3A
0005434877645	14583	10	2K
0005434938016	14583	11	3G
0005435126105	14583	12	3D
0005432611672	14583	13	3K
0005432799262	14583	14	4C
0005434877612	14583	15	4K
0005435125905	14583	16	4H
0005434877545	14583	17	5H
0005434877587	14583	18	5G
0005435126205	14583	19	11A
0005434938013	14583	20	5K
0005434877870	14583	21	11D
0005435126229	14583	22	11C
0005435902734	14583	23	11G
0005432799173	14583	24	11F
0005435126173	14583	25	11E
0005432799316	14583	26	11H
0005434426458	14583	27	12C
0005435914697	14583	28	12E
0005432799325	14583	29	12D
0005434877877	14583	30	12K
0005435902744	14583	31	12H
0005434426424	14583	32	13A
0005434877709	14583	33	13F
0005435902743	14583	34	13E
0005435126207	14583	35	13H
0005434426511	14583	36	13G
0005432799324	14583	37	14C
0005434877905	14583	38	14A
0005432799264	14583	39	13K
0005434877662	14583	40	14E
0005434426343	14583	41	14K
0005435126040	14583	42	14H
0005434426514	14583	43	14G
0005432799172	14583	44	15C
0005435125918	14583	45	15D
0005435126067	14583	46	15H
0005434877384	14583	47	15F
0005434877728	14583	48	15K
0005434877584	14583	49	16D
0005434877502	14583	50	16C
0005434426305	14583	51	16F
0005434877711	14583	52	16E
0005434877575	14583	53	16H
0005434938060	14583	54	16G
0005435125997	14583	55	16K
0005435126055	14583	56	17D
0005434426478	14583	57	17G
0005434938068	14583	58	17K
0005434877454	14583	59	17H
0005434877802	14583	60	18A
0005435125979	14583	61	18D
0005434426390	14583	62	18G
0005434877646	14583	63	18F
0005435126230	14583	64	18E
0005435914696	14583	65	18K
0005434426450	14583	66	18J
0005434937965	14583	67	19A
0005434877667	14583	68	19C
0005434877504	14583	69	19J
0005432799265	14583	70	19G
0005435125962	14583	71	20A
0005435626040	14583	72	19K
0005435125993	14583	73	20B
0005434877729	14583	74	20D
0005434426440	14583	75	20G
0005435125968	14583	76	20J
0005432799271	14583	77	20H
0005432799348	14583	78	21B
0005435902735	14583	79	21D
0005434877800	14583	80	21G
0005434877715	14583	81	21F
0005435902745	14583	82	21E
0005434877574	14583	83	21J
0005432799189	14583	84	21K
0005432799248	14583	85	22C
0005435126182	14583	86	22E
0005434877618	14583	87	22G
0005432799254	14583	88	22F
0005435126181	14583	89	22K
0005434877694	14583	90	22J
0005434426421	14583	91	22H
0005435841822	14583	92	23B
0005435126204	14583	93	23E
0005434877461	14583	94	23D
0005434877564	14583	95	23C
0005434877573	14583	96	23F
0005435126058	14583	97	23J
0005435125851	14583	98	23H
0005434877897	14583	99	24D
0005435626026	14583	100	24G
0005435902739	14583	101	24F
0005434938067	14583	102	24E
0005435914699	14583	103	25A
0005434877730	14583	104	25D
0005434877359	14583	105	25H
0005435126160	14583	106	25G
0005434426464	14583	107	25J
0005432799292	14583	108	26C
0005435902730	14583	109	26A
0005435626041	14583	110	26D
0005434877999	14583	111	26G
0005432607539	14583	112	26F
0005432611684	14583	113	26J
0005432799277	14583	114	26H
0005434877444	14583	115	26K
0005432799297	14583	116	27D
0005435902731	14583	117	27F
0005434877563	14583	118	27E
0005434938032	14583	119	27H
0005434426484	14583	120	27G
0005434877385	14583	121	28A
0005435902741	14583	122	28D
0005434877268	14583	123	28C
0005435126161	14583	124	28G
0005434877451	14583	125	28F
0005432799326	14583	126	28J
0005435902733	14583	127	28H
0005435125999	14583	128	29A
0005434877792	14583	129	28K
0005434426449	14583	130	29D
0005435902742	14583	131	29C
0005434877713	14583	132	29E
0005435125898	14583	133	29H
0005434877335	14583	134	29G
0005434877805	14583	135	30A
0005434877622	14583	136	29J
0005434877741	14583	137	30E
0005434877499	14583	138	30C
0005434877617	14583	139	30G
0005432799337	14583	140	30J
0005434877611	14583	141	31A
0005435126147	14583	142	30K
0005434877628	14583	143	31D
0005432799405	14583	144	31E
0005432799278	14583	145	31H
0005434937949	14583	146	31K
0005434426391	14583	147	31J
0005432799336	14583	148	32A
0005434937964	14583	149	32E
0005434426296	14583	150	32G
0005432799155	14583	151	32H
0005434938059	14583	152	33B
0005434877820	14583	153	33A
0005435126057	14583	154	33C
0005434877425	14583	155	33E
0005434877782	14583	156	33J
0005434877341	14583	157	33G
0005434877663	14583	158	34A
0005435841825	14583	159	33K
0005434877775	14583	160	34C
0005432799253	14583	161	34G
0005434877426	14583	162	34F
0005432799293	14583	163	34J
0005434877620	14583	164	34H
0005434877904	14583	165	35B
0005434938038	14583	166	35A
0005434877572	14583	167	35D
0005434877896	14583	168	35F
0005435126159	14583	169	35E
0005434426306	14583	170	35J
0005434426363	14583	171	35G
0005432799404	14583	172	36D
0005434938089	14583	173	36C
0005435125969	14583	174	36B
0005435902738	14583	175	36E
0005434426513	14583	176	36H
0005432799163	14583	177	36K
0005434426422	14583	178	36J
0005434938014	14583	179	37C
0005434877666	14583	180	37A
0005435626004	14583	181	37D
0005434877505	14583	182	37F
0005434426463	14583	183	37E
0005435125974	14583	184	37J
0005435841824	14583	185	37H
0005434877101	14583	186	37G
0005435126070	14583	187	37K
0005435126148	14583	188	38C
0005432799131	14583	189	38A
0005434426193	14583	190	38J
0005434877556	14583	191	39A
0005435625954	14583	192	39C
0005434877740	14583	193	39B
0005432611678	14583	194	39F
0005434877360	14583	195	39E
0005434426348	14583	196	39D
0005434877831	14583	197	39J
0005435126138	14583	198	39H
0005434878000	14583	199	39G
0005434938039	14583	200	40B
0005435125919	14583	201	40D
0005434877861	14583	202	40H
0005435126098	14583	203	40G
0005432799328	14583	204	40F
0005432799225	14583	205	41B
0005435125906	14583	206	41A
0005434877830	14583	207	41E
0005435914698	14583	208	41H
0005435126322	14583	209	41K
0005432799238	14583	210	42C
0005434877801	14583	211	42B
0005434877803	14583	212	42E
0005434877449	14583	213	42D
0005434426426	14583	214	42K
0005434877862	14583	215	42J
0005435125852	14583	216	43B
0005435126253	14583	217	43A
0005434877721	14583	218	43C
0005434877269	14583	219	43J
0005435902737	14583	220	43H
0005434877875	14583	221	43G
0005434877714	14583	222	44E
0005435902747	14583	223	44C
0005434877421	14583	224	44F
0005434877876	14583	225	44J
0005434877693	14583	226	44H
0005432611677	14583	227	45D
0005432799132	14583	228	45C
0005435126066	14583	229	45B
0005434877631	14583	230	45F
0005434877621	14583	231	45E
0005432611686	14583	232	45G
0005434877625	14583	233	46A
0005432799272	14583	234	45K
0005435125998	14583	235	45J
0005435841823	14583	236	46B
0005435902746	14583	237	46E
0005434877405	14583	238	46D
0005434877619	14583	239	46F
0005435126068	14583	240	46K
0005434877543	14583	241	46J
0005435626042	14583	242	47D
0005434877577	14583	243	47C
0005434877293	14583	244	47G
0005435126180	14583	245	47F
0005435914695	14583	246	47E
0005432799296	14583	247	47K
0005435126028	14583	248	47H
0005435126187	14583	249	48F
0005435126104	14583	250	48E
0005434877793	14583	251	49A
0005432611676	14583	252	49E
0005432611687	14583	253	49D
0005435125920	14583	254	49G
0005435626039	14583	255	49F
0005434426483	14583	256	49H
0005432799138	14583	257	50C
0005435902740	14583	258	50D
0005435902736	14583	259	50F
0005435902732	14583	260	50H
0005435126146	14583	261	51F
0005434877627	14583	262	51E
0005434877774	14583	263	51G
0005434325673	3592	1	1B
0005434325669	3592	2	1D
0005434325679	3592	3	2A
0005434325668	3592	4	2C
0005435889880	3592	5	2D
0005434325677	3592	6	3B
0005434312322	3592	7	3C
0005434325678	3592	8	3D
0005435889839	3592	9	4B
0005435889886	3592	10	4C
0005435889879	3592	11	4D
0005435889840	3592	12	5B
0005434325674	3592	13	5C
0005435889876	3592	14	6A
0005434312324	3592	15	6B
0005434312323	3592	16	6D
0005434325670	3592	17	7D
0005435889877	3592	18	18A
0005435889844	3592	19	18C
0005434325671	3592	20	19D
0005435889855	3592	21	20A
0005434325672	3592	22	20D
0005434325676	3592	23	21C
0005435889854	3592	24	22A
0005434325675	3592	25	22C
0005434325588	15608	1	1A
0005434325574	15608	2	1B
0005435889906	15608	3	2B
0005434325532	15608	4	2C
0005434325576	15608	5	2D
0005434325575	15608	6	3A
0005434325580	15608	7	3C
0005435889907	15608	8	4A
0005434325557	15608	9	5A
0005434325552	15608	10	5B
0005435889909	15608	11	6A
0005434325563	15608	12	7C
0005434325584	15608	13	18A
0005434325643	15608	14	18C
0005434325618	15608	15	18D
0005435889908	15608	16	19A
0005435889910	15608	17	19D
0005434325556	15608	18	21A
0005434325583	15608	19	21B
0005435889912	15608	20	22A
0005434325617	15608	21	22C
0005435889911	15608	22	22D
0005435957727	661	1	1A
0005433420311	661	2	1B
0005433420337	661	3	1D
0005433420330	661	4	2A
0005433420312	661	5	2C
0005435957728	661	6	3A
0005433420318	661	7	3C
0005435957734	661	8	3D
0005435957733	661	9	5D
0005435957735	661	10	6A
0005433420343	661	11	6C
0005435957737	661	12	7B
0005433420321	661	13	18B
0005435957732	661	14	18D
0005433420319	661	15	19C
0005435957736	661	16	19D
0005435957729	661	17	20B
0005435957730	661	18	20C
0005435957726	661	19	20D
0005435957739	661	20	21A
0005435957738	661	21	21D
0005433420329	661	22	22A
0005435957731	661	23	23A
0005433420423	15183	1	1A
0005433420419	15183	2	4B
0005435957612	15183	3	4C
0005435957563	15183	4	5A
0005433420415	15183	5	5C
0005435957608	15183	6	6A
0005435957660	15183	7	19A
0005435957609	15183	8	19D
0005433420417	15183	9	20B
0005433420416	15183	10	20C
0005433420422	15183	11	21B
0005433420420	15183	12	22A
0005435957610	15183	13	22C
0005433420421	15183	14	22D
0005433420418	15183	15	23B
0005434247138	8919	1	2B
0005435629405	8919	2	4B
0005434247137	8919	3	5B
0005435629404	8919	4	6A
0005434247152	16079	1	2B
0005435629400	16079	2	2A
0005435629398	16079	3	3A
0005434247151	16079	4	4A
0005435629401	16079	5	4B
0005434247153	16079	6	5A
0005434247154	16079	7	6B
0005435163188	29510	1	1A
0005435933459	29510	2	1B
0005435163187	29510	3	1C
0005435933455	29510	4	1D
0005435163166	29510	5	2C
0005435163147	29510	6	5D
0005435933457	29510	7	6D
0005435933458	29510	8	7A
0005435933463	29510	9	18A
0005435163203	29510	10	18C
0005435933456	29510	11	18D
0005435163204	29510	12	19A
0005435933461	29510	13	20B
0005435163183	29510	14	20C
0005435933454	29510	15	21A
0005435933462	29510	16	21C
0005435163202	29510	17	21D
0005435163185	29510	18	22B
0005435163178	29510	19	22D
0005435933460	29510	20	23A
0005435797502	2829	1	1C
0005433404768	2829	2	5E
0005435797506	2829	3	6C
0005435797507	2829	4	6D
0005435797497	2829	5	6E
0005435797504	2829	6	6F
0005435797499	2829	7	7C
0005435797500	2829	8	7E
0005433404783	2829	9	8D
0005435797505	2829	10	9A
0005435797503	2829	11	9C
0005433404785	2829	12	10F
0005435797510	2829	13	14A
0005433404738	2829	14	14F
0005435797501	2829	15	16F
0005435797511	2829	16	18F
0005435797509	2829	17	19C
0005433404782	2829	18	19E
0005435797498	2829	19	20D
0005435797508	2829	20	20E
0005435797446	29343	1	1C
0005433404822	29343	2	1F
0005435797425	29343	3	3D
0005435797340	29343	4	5C
0005433404829	29343	5	5E
0005435797386	29343	6	6A
0005433404828	29343	7	10C
0005435797362	29343	8	10D
0005435797385	29343	9	10E
0005433404825	29343	10	12E
0005435797452	29343	11	14D
0005433404826	29343	12	14F
0005433404823	29343	13	15C
0005435797437	29343	14	17A
0005435797420	29343	15	17C
0005433404821	29343	16	17F
0005433404824	29343	17	18F
0005433404827	29343	18	20C
0005435797353	29343	19	20F
0005435376336	5802	1	4A
0005434948042	5808	1	1A
0005434948041	5808	2	2A
0005434948038	5808	3	3A
0005434948040	5808	4	2B
0005434948035	5808	5	3B
0005434948036	5808	6	4A
0005434948039	5808	7	5A
0005434948037	5808	8	6B
0005434947982	16352	1	1A
0005434947983	16352	2	1B
0005434947956	16352	3	2A
0005435376357	16352	4	3A
0005434948011	16352	5	2B
0005435376355	16352	6	3B
0005434948000	16352	7	4A
0005434947955	16352	8	4B
0005435376356	16352	9	5A
0005435376358	16352	10	5B
0005434947981	16352	11	6A
0005434947980	16352	12	6B
0005433961025	6923	1	1A
0005433961001	6923	2	1C
0005433961015	6923	3	1D
0005433961014	6923	4	2F
0005433960975	6923	5	3A
0005433960997	6923	6	3C
0005433961016	6923	7	3D
0005433961022	6923	8	4A
0005433961004	6923	9	4C
0005433961000	6923	10	4E
0005433961019	6923	11	4F
0005433960979	6923	12	5C
0005433961021	6923	13	5D
0005433961033	6923	14	5E
0005433960999	6923	15	6A
0005433961009	6923	16	6D
0005433960987	6923	17	6E
0005433960991	6923	18	6F
0005433961023	6923	19	7A
0005433960996	6923	20	7E
0005433960981	6923	21	8A
0005433960992	6923	22	8D
0005433960989	6923	23	8F
0005433961020	6923	24	9C
0005433961005	6923	25	9D
0005433960988	6923	26	9E
0005433961024	6923	27	10A
0005433961003	6923	28	10D
0005433961030	6923	29	10E
0005433960982	6923	30	10F
0005433960980	6923	31	11E
0005433961010	6923	32	11F
0005433961018	6923	33	12C
0005433960985	6923	34	12D
0005433961012	6923	35	12E
0005433961028	6923	36	12F
0005433961006	6923	37	13A
0005433961027	6923	38	13D
0005433960990	6923	39	13E
0005433960984	6923	40	13F
0005433961002	6923	41	14C
0005433960978	6923	42	14E
0005433960977	6923	43	15C
0005433961032	6923	44	15E
0005433960976	6923	45	15F
0005433961017	6923	46	16A
0005433961007	6923	47	16C
0005433960986	6923	48	16D
0005433961008	6923	49	16E
0005433960974	6923	50	16F
0005433961026	6923	51	17A
0005433960993	6923	52	17C
0005433960994	6923	53	17E
0005433961011	6923	54	17F
0005433960983	6923	55	19D
0005433961031	6923	56	19E
0005433960995	6923	57	19F
0005433960998	6923	58	20C
0005433961013	6923	59	20E
0005433961029	6923	60	20F
0005433960427	25814	1	1D
0005433960435	25814	2	2C
0005433960422	25814	3	2F
0005433960236	25814	4	3A
0005433960433	25814	5	4E
0005433960363	25814	6	4F
0005433960398	25814	7	5C
0005433960226	25814	8	5D
0005433960408	25814	9	5F
0005433960355	25814	10	6A
0005433960434	25814	11	6E
0005433960195	25814	12	7C
0005433960323	25814	13	7D
0005433960144	25814	14	7E
0005433960344	25814	15	8A
0005433960165	25814	16	8C
0005433960282	25814	17	8D
0005433960379	25814	18	8F
0005433960431	25814	19	9A
0005433960324	25814	20	9D
0005433960224	25814	21	9F
0005433960345	25814	22	10D
0005433960239	25814	23	10E
0005433960406	25814	24	11F
0005433960382	25814	25	12E
0005433960430	25814	26	13A
0005433960238	25814	27	13C
0005433960201	25814	28	14A
0005433960258	25814	29	15F
0005433960326	25814	30	16C
0005433960380	25814	31	17E
0005433960327	25814	32	17F
0005433960322	25814	33	18C
0005433960413	25814	34	18E
0005433960348	25814	35	18F
0005433960383	25814	36	19A
0005433960428	25814	37	20C
0005433960145	25814	38	20D
0005433960200	25814	39	20E
0005435082725	24478	1	1A
0005435082749	24478	2	1B
0005435082733	24478	3	2A
0005435082710	24478	4	2B
0005435082719	24478	5	3B
0005435082732	24478	6	3A
0005435082750	24478	7	4A
0005435082729	24478	8	4B
0005435082748	24478	9	5B
0005435082744	24478	10	6B
0005435082788	26096	1	1A
0005435082793	26096	2	2B
0005435082791	26096	3	3A
0005435082789	26096	4	3B
0005435082794	26096	5	4B
0005435082792	26096	6	5B
0005435082790	26096	7	6B
0005434245032	5120	1	2A
0005434245041	5120	2	3A
0005434245056	5120	3	3F
0005434245033	5120	4	4D
0005434245029	5120	5	4C
0005434245039	5120	6	5A
0005434245043	5120	7	7C
0005435286575	5120	8	7F
0005435286576	5120	9	8B
0005434245040	5120	10	8C
0005434245052	5120	11	8F
0005434245027	5120	12	10F
0005434245046	5120	13	11B
0005434245053	5120	14	12D
0005432166906	5120	15	12C
0005434245049	5120	16	13C
0005434245036	5120	17	13E
0005435286598	5120	18	14C
0005434245042	5120	19	14F
0005435286591	5120	20	15D
0005435286596	5120	21	16F
0005435286573	5120	22	18A
0005434245047	5120	23	19D
0005434245044	5120	24	20F
0005434245035	5120	25	22B
0005432166909	5120	26	22F
0005435286600	5120	27	23B
0005434245030	5120	28	23A
0005432166907	5120	29	23C
0005435286590	5120	30	24B
0005434245048	5120	31	24D
0005434245028	5120	32	24F
0005434245051	5120	33	25C
0005435286599	5120	34	25B
0005434245055	5120	35	25E
0005434245050	5120	36	27B
0005434245031	5120	37	27C
0005434245034	5120	38	29B
0005434245026	5120	39	29A
0005434245045	5120	40	29E
0005434245037	5120	41	29F
0005432166910	5120	42	30B
0005434245038	5120	43	31A
0005434245054	5120	44	31C
0005432166908	5120	45	31F
0005433614828	5119	1	1A
0005433614857	5119	2	1C
0005433614867	5119	3	1D
0005433614840	5119	4	2A
0005433614834	5119	5	1F
0005433614843	5119	6	2C
0005432105655	5119	7	2F
0005433614816	5119	8	2D
0005432105651	5119	9	3D
0005433614853	5119	10	3C
0005433614869	5119	11	3A
0005433785017	5119	12	3F
0005433785037	5119	13	4A
0005433614841	5119	14	4C
0005433614881	5119	15	4F
0005433614838	5119	16	4D
0005432105689	5119	17	5A
0005433785016	5119	18	5C
0005432105654	5119	19	5D
0005433614846	5119	20	6A
0005433614818	5119	21	5F
0005433614859	5119	22	6C
0005432666393	5119	23	6F
0005433614882	5119	24	6D
0005433614874	5119	25	7A
0005433614875	5119	26	7C
0005433614814	5119	27	7F
0005433614824	5119	28	7D
0005433785015	5119	29	8A
0005433785036	5119	30	8C
0005433614836	5119	31	8B
0005433614832	5119	32	8D
0005433614813	5119	33	8E
0005433785010	5119	34	8F
0005432105669	5119	35	9B
0005433614862	5119	36	9A
0005433614847	5119	37	9C
0005433785007	5119	38	9D
0005433614872	5119	39	9F
0005432105685	5119	40	9E
0005432666392	5119	41	10A
0005432105649	5119	42	10B
0005433614833	5119	43	10D
0005433614848	5119	44	10C
0005432105675	5119	45	10E
0005432105688	5119	46	11A
0005432105656	5119	47	10F
0005433614879	5119	48	11C
0005432105679	5119	49	11B
0005433614839	5119	50	11D
0005433614878	5119	51	11E
0005433614863	5119	52	12A
0005432105662	5119	53	11F
0005433785002	5119	54	12C
0005432145117	5119	55	12B
0005433785008	5119	56	12D
0005433614819	5119	57	12F
0005433614810	5119	58	12E
0005433785027	5119	59	13B
0005433785011	5119	60	13A
0005432105645	5119	61	13C
0005432105659	5119	62	13E
0005433614815	5119	63	13D
0005433614864	5119	64	13F
0005433785025	5119	65	14A
0005433614809	5119	66	14B
0005432105643	5119	67	14D
0005432105646	5119	68	14C
0005432105650	5119	69	14E
0005433614868	5119	70	15A
0005432105681	5119	71	14F
0005433614826	5119	72	15B
0005433614851	5119	73	15C
0005433785014	5119	74	15E
0005432105642	5119	75	15D
0005433614877	5119	76	15F
0005432105660	5119	77	16A
0005433785020	5119	78	16C
0005433614811	5119	79	16B
0005432105687	5119	80	16D
0005432145116	5119	81	16E
0005433784999	5119	82	16F
0005433614854	5119	83	17B
0005433614856	5119	84	17A
0005432105668	5119	85	17C
0005433614876	5119	86	17E
0005432105666	5119	87	17D
0005433614871	5119	88	18A
0005432105671	5119	89	17F
0005433614831	5119	90	18B
0005433785000	5119	91	18C
0005433785026	5119	92	18E
0005432105684	5119	93	18D
0005433614845	5119	94	18F
0005433614870	5119	95	19C
0005432105644	5119	96	19B
0005433614842	5119	97	19D
0005433785021	5119	98	20A
0005433614823	5119	99	19E
0005432665278	5119	100	20B
0005432105641	5119	101	20C
0005432105667	5119	102	20D
0005433614812	5119	103	20F
0005432105670	5119	104	20E
0005433785012	5119	105	21A
0005432105674	5119	106	21B
0005433614835	5119	107	21D
0005432667458	5119	108	21C
0005433785018	5119	109	21F
0005432105673	5119	110	21E
0005433614837	5119	111	22B
0005433614880	5119	112	22A
0005432105672	5119	113	22C
0005432105648	5119	114	22D
0005432105683	5119	115	22F
0005433785032	5119	116	22E
0005433614830	5119	117	23B
0005433785004	5119	118	23A
0005433614849	5119	119	23D
0005432105653	5119	120	23C
0005432665279	5119	121	23E
0005433785006	5119	122	24A
0005433614827	5119	123	23F
0005432105661	5119	124	24B
0005432105665	5119	125	24D
0005433614820	5119	126	24C
0005433785022	5119	127	25A
0005433785009	5119	128	24F
0005433614855	5119	129	24E
0005433614866	5119	130	25C
0005433785003	5119	131	25B
0005433614817	5119	132	25E
0005433785013	5119	133	25D
0005433785024	5119	134	25F
0005432105686	5119	135	26A
0005433785028	5119	136	26B
0005433785034	5119	137	26D
0005433785030	5119	138	26C
0005432105652	5119	139	26E
0005433785023	5119	140	26F
0005432105664	5119	141	27B
0005432105658	5119	142	27A
0005433785001	5119	143	27C
0005433614829	5119	144	27D
0005433614844	5119	145	27E
0005433785005	5119	146	28A
0005433614861	5119	147	27F
0005433614865	5119	148	28C
0005432105657	5119	149	28B
0005433614873	5119	150	28D
0005433785031	5119	151	28E
0005432105663	5119	152	29A
0005432105647	5119	153	28F
0005433785029	5119	154	29B
0005432105677	5119	155	29C
0005433785035	5119	156	29E
0005433614860	5119	157	29D
0005432667457	5119	158	30A
0005432105678	5119	159	29F
0005432105682	5119	160	30C
0005433614825	5119	161	30B
0005433614821	5119	162	30E
0005433614850	5119	163	30D
0005433614858	5119	164	30F
0005433614822	5119	165	31A
0005433785033	5119	166	31C
0005433614852	5119	167	31B
0005433785019	5119	168	31D
0005432105676	5119	169	31F
0005432105680	5119	170	31E
0005434265179	5117	1	1D
0005433688795	5117	2	2A
0005434173527	5117	3	2C
0005434265200	5117	4	3A
0005435006922	5117	5	2F
0005434265194	5117	6	3F
0005434312307	5117	7	3D
0005435006896	5117	8	4A
0005434149751	5117	9	4C
0005434173526	5117	10	4F
0005434229419	5117	11	5A
0005434229413	5117	12	5F
0005433815366	5117	13	6A
0005434173529	5117	14	6C
0005435269689	5117	15	7A
0005434229414	5117	16	7C
0005432336002	5117	17	7F
0005435006831	5117	18	8A
0005435269688	5117	19	8C
0005434312305	5117	20	8E
0005434265184	5117	21	9A
0005434229407	5117	22	8F
0005434265198	5117	23	9B
0005434229427	5117	24	9D
0005434149750	5117	25	9F
0005435269694	5117	26	9E
0005434229415	5117	27	10A
0005434265185	5117	28	10C
0005433688796	5117	29	10E
0005435269703	5117	30	10D
0005435006897	5117	31	10F
0005434265201	5117	32	11A
0005434229423	5117	33	11C
0005435006912	5117	34	11D
0005435269687	5117	35	12C
0005433815351	5117	36	12D
0005435269690	5117	37	12F
0005434149760	5117	38	13B
0005434265188	5117	39	13C
0005433688787	5117	40	13D
0005435006921	5117	41	13E
0005433688791	5117	42	14A
0005435269684	5117	43	13F
0005434265195	5117	44	14B
0005434229409	5117	45	14D
0005432335994	5117	46	14E
0005434312315	5117	47	14F
0005433815340	5117	48	15A
0005434229408	5117	49	15C
0005434265203	5117	50	15D
0005435006890	5117	51	15F
0005434265191	5117	52	15E
0005434229428	5117	53	16B
0005435006862	5117	54	16D
0005434149759	5117	55	16C
0005435006863	5117	56	16E
0005433815341	5117	57	16F
0005434229417	5117	58	17B
0005435006913	5117	59	17D
0005435006886	5117	60	17E
0005434229416	5117	61	18A
0005434229420	5117	62	18C
0005432335951	5117	63	18B
0005435006830	5117	64	18D
0005435006828	5117	65	19C
0005434149754	5117	66	19E
0005432335990	5117	67	20A
0005435006887	5117	68	20C
0005434229406	5117	69	20B
0005434265197	5117	70	20E
0005434265199	5117	71	21A
0005434229422	5117	72	21E
0005435269698	5117	73	21F
0005434149749	5117	74	22A
0005434229429	5117	75	22C
0005434229426	5117	76	22D
0005435006829	5117	77	23B
0005434149753	5117	78	23C
0005434311203	5117	79	23D
0005434265186	5117	80	23F
0005434265202	5117	81	24A
0005434229424	5117	82	24B
0005434229421	5117	83	24C
0005434265192	5117	84	24E
0005435006843	5117	85	24D
0005434149755	5117	86	25A
0005435006864	5117	87	25C
0005434229418	5117	88	25B
0005434265182	5117	89	26A
0005434149752	5117	90	25F
0005435006868	5117	91	26B
0005434265193	5117	92	26C
0005434312308	5117	93	26E
0005435269678	5117	94	26D
0005434265183	5117	95	26F
0005434229410	5117	96	27A
0005434265189	5117	97	27C
0005434265181	5117	98	27D
0005434173528	5117	99	27F
0005435006885	5117	100	28B
0005434265196	5117	101	28C
0005432335955	5117	102	28E
0005435006827	5117	103	28F
0005434265190	5117	104	29A
0005434229412	5117	105	29C
0005434229425	5117	106	29B
0005434149757	5117	107	30A
0005434229411	5117	108	29F
0005435006842	5117	109	30B
0005434149756	5117	110	30E
0005433815362	5117	111	30D
0005434312306	5117	112	30F
0005433815363	5117	113	31C
0005434265187	5117	114	31B
0005434265180	5117	115	31D
0005434173530	5117	116	31E
0005434149758	5117	117	31F
0005433784779	8495	1	1C
0005433784534	8495	2	1A
0005435269754	8495	3	1D
0005434244775	8495	4	2C
0005433784756	8495	5	3A
0005435269757	8495	6	3C
0005432659685	8495	7	3D
0005433784698	8495	8	4A
0005433784650	8495	9	3F
0005434244717	8495	10	5F
0005433784651	8495	11	6F
0005433784755	8495	12	8E
0005433784535	8495	13	8F
0005435269756	8495	14	9A
0005433784914	8495	15	9B
0005433784513	8495	16	9D
0005434244817	8495	17	9F
0005434244741	8495	18	10A
0005433784809	8495	19	10B
0005434244892	8495	20	10C
0005432663023	8495	21	10E
0005435269752	8495	22	10F
0005433784754	8495	23	11F
0005435269753	8495	24	11E
0005434244883	8495	25	12B
0005433784826	8495	26	12F
0005434244833	8495	27	13B
0005434244776	8495	28	13D
0005433784557	8495	29	13E
0005432666373	8495	30	14A
0005433784751	8495	31	14D
0005433784913	8495	32	14C
0005433784753	8495	33	15A
0005433784749	8495	34	15B
0005433784512	8495	35	15F
0005432659689	8495	36	16C
0005433784760	8495	37	16D
0005434244900	8495	38	16F
0005433784555	8495	39	17C
0005434244750	8495	40	17D
0005433784649	8495	41	17E
0005434244821	8495	42	18A
0005434244870	8495	43	17F
0005433784791	8495	44	18D
0005434244901	8495	45	18E
0005434244718	8495	46	18F
0005433784802	8495	47	19E
0005433784646	8495	48	20B
0005432659690	8495	49	20E
0005435269751	8495	50	21D
0005433784771	8495	51	22E
0005433784558	8495	52	22D
0005434244891	8495	53	23A
0005433784748	8495	54	23C
0005432659691	8495	55	23D
0005434244784	8495	56	23E
0005433784641	8495	57	24A
0005434244882	8495	58	24B
0005433784801	8495	59	24D
0005434244779	8495	60	25C
0005435269758	8495	61	25B
0005433784628	8495	62	25F
0005434244834	8495	63	26A
0005434244783	8495	64	26D
0005433784634	8495	65	26C
0005433784652	8495	66	26F
0005433784660	8495	67	27A
0005433784552	8495	68	27C
0005432666375	8495	69	27E
0005434244830	8495	70	28A
0005434244742	8495	71	28E
0005434244854	8495	72	29A
0005434244822	8495	73	29B
0005433784704	8495	74	30A
0005433784682	8495	75	30C
0005434244753	8495	76	30E
0005433784705	8495	77	30F
0005435269755	8495	78	31C
0005434244785	8495	79	31D
0005433784640	8495	80	31F
0005433614226	8496	1	2A
0005433614243	8496	2	2C
0005433614354	8496	3	3D
0005433614132	8496	4	4D
0005433614355	8496	5	4C
0005433614308	8496	6	4F
0005433614135	8496	7	5F
0005433614277	8496	8	5D
0005433614269	8496	9	6A
0005433614169	8496	10	6F
0005433614060	8496	11	6D
0005433614231	8496	12	7D
0005433613956	8496	13	8A
0005433614136	8496	14	8D
0005433613916	8496	15	9B
0005433614202	8496	16	9D
0005433614441	8496	17	9F
0005433613863	8496	18	9E
0005433614081	8496	19	10D
0005433614281	8496	20	10E
0005433613897	8496	21	11A
0005433614167	8496	22	10F
0005433614185	8496	23	11B
0005433614082	8496	24	11C
0005433614406	8496	25	11E
0005433614137	8496	26	11D
0005433614080	8496	27	12A
0005433614148	8496	28	12B
0005433614435	8496	29	12C
0005433614247	8496	30	12D
0005433614248	8496	31	12F
0005433613858	8496	32	12E
0005433614178	8496	33	13F
0005433614244	8496	34	13E
0005433613873	8496	35	14A
0005433614336	8496	36	14E
0005433614075	8496	37	15B
0005433614205	8496	38	15D
0005433614158	8496	39	15F
0005433614140	8496	40	15E
0005433613976	8496	41	16B
0005433614118	8496	42	16D
0005433614111	8496	43	16E
0005433613907	8496	44	18A
0005433614061	8496	45	18E
0005433614028	8496	46	20B
0005433614590	8496	47	20C
0005433614186	8496	48	20D
0005433614299	8496	49	20F
0005433614353	8496	50	21C
0005433614312	8496	51	21E
0005433614214	8496	52	22A
0005433614062	8496	53	22D
0005433613771	8496	54	22E
0005433614015	8496	55	22F
0005433614106	8496	56	23B
0005433614280	8496	57	23A
0005433613943	8496	58	23D
0005433614246	8496	59	23C
0005433614055	8496	60	23F
0005433614083	8496	61	24A
0005433614442	8496	62	24D
0005433614315	8496	63	24F
0005433614232	8496	64	25C
0005433614065	8496	65	25D
0005433614041	8496	66	26E
0005433614314	8496	67	26D
0005433614104	8496	68	28A
0005433613959	8496	69	27F
0005433613857	8496	70	28E
0005433614095	8496	71	29A
0005433614337	8496	72	28F
0005433614184	8496	73	29C
0005433614096	8496	74	29E
0005433614309	8496	75	29F
0005433614090	8496	76	30B
0005433614264	8496	77	30A
0005433614105	8496	78	30C
0005433614278	8496	79	31C
0005433614168	8496	80	31E
0005435007082	8497	1	1A
0005433534503	8497	2	1F
0005434264961	8497	3	1D
0005434149606	8497	4	2A
0005434264929	8497	5	2D
0005434265086	8497	6	2C
0005435007076	8497	7	2F
0005434264954	8497	8	3C
0005434264962	8497	9	3A
0005434264895	8497	10	3F
0005434229212	8497	11	3D
0005432034999	8497	12	4A
0005432336055	8497	13	4D
0005434229209	8497	14	4C
0005434229283	8497	15	4F
0005434149710	8497	16	5A
0005432336063	8497	17	5C
0005434264937	8497	18	5F
0005434229262	8497	19	5D
0005434229263	8497	20	6A
0005432035010	8497	21	6D
0005432034994	8497	22	6F
0005432035008	8497	23	7C
0005435007077	8497	24	7F
0005432035017	8497	25	7D
0005434229129	8497	26	8A
0005433815399	8497	27	8C
0005435007078	8497	28	8B
0005434229104	8497	29	8E
0005432035006	8497	30	8D
0005432034995	8497	31	8F
0005432047559	8497	32	9C
0005434149638	8497	33	9B
0005434149614	8497	34	9D
0005432336061	8497	35	9E
0005434229188	8497	36	10A
0005433534502	8497	37	9F
0005435007080	8497	38	10B
0005434229213	8497	39	10D
0005434265017	8497	40	10C
0005434149652	8497	41	10E
0005434264927	8497	42	10F
0005434264953	8497	43	11B
0005435007071	8497	44	11A
0005432336056	8497	45	11C
0005432336059	8497	46	11D
0005434229144	8497	47	12A
0005434229187	8497	48	12C
0005434149687	8497	49	12B
0005434229193	8497	50	12E
0005434264938	8497	51	12D
0005434149613	8497	52	12F
0005433689915	8497	53	13B
0005432035012	8497	54	13D
0005434264894	8497	55	13E
0005432035015	8497	56	14A
0005434311224	8497	57	14B
0005434149639	8497	58	14D
0005432035014	8497	59	14C
0005432336060	8497	60	14E
0005432035002	8497	61	14F
0005434149659	8497	62	15B
0005432047557	8497	63	15A
0005432035001	8497	64	15C
0005432047556	8497	65	15D
0005432336058	8497	66	15E
0005435007073	8497	67	16A
0005435007081	8497	68	15F
0005433815396	8497	69	16B
0005434229178	8497	70	16D
0005433690931	8497	71	16C
0005434265002	8497	72	16E
0005432336065	8497	73	16F
0005432034991	8497	74	17B
0005433688814	8497	75	17A
0005435007072	8497	76	17C
0005434229222	8497	77	17E
0005432336053	8497	78	17D
0005434264876	8497	79	18A
0005433815398	8497	80	17F
0005434149587	8497	81	18B
0005434229311	8497	82	18D
0005434173492	8497	83	18C
0005434264911	8497	84	18F
0005435007074	8497	85	19C
0005434265004	8497	86	19B
0005435007084	8497	87	19D
0005433689916	8497	88	20A
0005434229128	8497	89	19E
0005434264984	8497	90	20B
0005435007083	8497	91	20C
0005434229226	8497	92	20D
0005432034993	8497	93	20F
0005432047558	8497	94	20E
0005434229282	8497	95	21B
0005434149676	8497	96	21C
0005434229292	8497	97	21D
0005434149701	8497	98	21E
0005432035013	8497	99	22B
0005434229219	8497	100	22A
0005435007075	8497	101	22E
0005434149615	8497	102	22D
0005432034992	8497	103	22F
0005434264896	8497	104	23A
0005434229167	8497	105	23C
0005434265003	8497	106	23B
0005434229247	8497	107	23D
0005432336057	8497	108	23E
0005432034997	8497	109	24A
0005432035018	8497	110	23F
0005434173475	8497	111	24B
0005434149605	8497	112	24C
0005434149653	8497	113	24E
0005434264965	8497	114	24D
0005434149670	8497	115	24F
0005434264936	8497	116	25A
0005434265001	8497	117	25B
0005432035007	8497	118	25D
0005434265000	8497	119	25E
0005433815397	8497	120	25F
0005432035009	8497	121	26B
0005434173495	8497	122	26C
0005434149658	8497	123	26E
0005434311225	8497	124	26D
0005432336062	8497	125	26F
0005432035004	8497	126	27A
0005434265040	8497	127	27C
0005435007079	8497	128	27B
0005432336064	8497	129	27D
0005432336054	8497	130	27F
0005434229166	8497	131	27E
0005434149686	8497	132	28A
0005434264935	8497	133	28B
0005432034998	8497	134	28C
0005432035016	8497	135	28E
0005434149671	8497	136	28D
0005434229268	8497	137	28F
0005432035005	8497	138	29A
0005434311223	8497	139	29C
0005432035011	8497	140	29B
0005434264933	8497	141	29D
0005433688813	8497	142	29F
0005434264963	8497	143	29E
0005434265039	8497	144	30A
0005432035003	8497	145	30B
0005432034996	8497	146	30D
0005434229210	8497	147	30C
0005434149673	8497	148	30E
0005434264928	8497	149	30F
0005432035000	8497	150	31B
0005434149657	8497	151	31C
0005434264985	8497	152	31D
0005434229225	8497	153	31E
0005434639110	12614	1	1A
0005434639136	12614	2	1B
0005434639244	12614	3	1C
0005434639125	12614	4	1D
0005434639138	12614	5	2A
0005434639081	12614	6	2B
0005433202398	12614	7	2C
0005434639144	12614	8	2D
0005434639243	12614	9	3A
0005433202396	12614	10	3B
0005433202392	12614	11	3C
0005433202390	12614	12	3D
0005434639127	12614	13	4A
0005434639018	12614	14	4B
0005434639068	12614	15	4C
0005434639137	12614	16	4D
0005434639178	12614	17	5A
0005434639103	12614	18	5B
0005434639239	12614	19	5C
0005434639172	12614	20	5D
0005433202401	12614	21	6A
0005433202389	12614	22	6B
0005433202395	12614	23	6C
0005434639203	12614	24	6D
0005434639201	12614	25	7A
0005434639173	12614	26	7B
0005433202393	12614	27	7C
0005434639202	12614	28	7D
0005434639200	12614	29	18A
0005434639071	12614	30	18B
0005434639111	12614	31	18C
0005434639199	12614	32	18D
0005433202397	12614	33	19A
0005434639143	12614	34	19B
0005433202394	12614	35	19C
0005433202399	12614	36	19D
0005434639198	12614	37	20A
0005434639069	12614	38	20B
0005433202400	12614	39	20C
0005434639240	12614	40	20D
0005433202391	12614	41	21A
0005434639102	12614	42	21B
0005434639162	12614	43	21C
0005433202402	12614	44	22A
0005434639083	12614	45	22B
0005434639092	12614	46	22C
0005434639177	12614	47	22D
0005434639128	12614	48	23A
0005434639145	12614	49	23B
0005433202193	23377	1	1A
0005434639365	23377	2	1B
0005434639348	23377	3	1C
0005433202201	23377	4	1D
0005434639359	23377	5	2A
0005433202267	23377	6	2B
0005434639345	23377	7	2C
0005434639364	23377	8	2D
0005434639355	23377	9	3A
0005433202226	23377	10	3B
0005434639350	23377	11	3C
0005433202263	23377	12	3D
0005432290635	23377	13	4A
0005433202194	23377	14	4B
0005434639366	23377	15	4C
0005434639341	23377	16	4D
0005434639358	23377	17	5A
0005434639353	23377	18	5B
0005434639346	23377	19	5C
0005433202216	23377	20	5D
0005434639361	23377	21	6A
0005433202273	23377	22	6B
0005434639354	23377	23	6C
0005434639357	23377	24	6D
0005434639339	23377	25	7A
0005433202261	23377	26	7C
0005433202260	23377	27	7D
0005432290638	23377	28	18A
0005434639363	23377	29	18B
0005434639352	23377	30	18C
0005433202197	23377	31	18D
0005432290636	23377	32	19A
0005434639340	23377	33	19B
0005433202293	23377	34	19C
0005434639349	23377	35	19D
0005434639342	23377	36	20A
0005433202196	23377	37	20B
0005434639356	23377	38	20C
0005434639344	23377	39	20D
0005434639360	23377	40	21A
0005434639362	23377	41	21B
0005433202280	23377	42	21C
0005433202257	23377	43	21D
0005433202262	23377	44	22A
0005433202192	23377	45	22B
0005434639347	23377	46	22C
0005432290637	23377	47	22D
0005434639351	23377	48	23A
0005434639343	23377	49	23B
0005432328236	21083	1	1A
0005432382860	21083	2	1C
0005432328320	21083	3	1D
0005432382805	21083	4	1F
0005432328223	21083	5	2A
0005432382795	21083	6	2C
0005432328278	21083	7	2D
0005432328330	21083	8	2F
0005432382648	21083	9	3A
0005432328379	21083	10	3C
0005432328574	21083	11	3D
0005432328445	21083	12	3F
0005432328332	21083	13	4A
0005432383107	21083	14	4C
0005432328659	21083	15	4D
0005432383087	21083	16	4E
0005432328350	21083	17	4F
0005432328232	21083	18	5A
0005432382879	21083	19	5D
0005432382847	21083	20	5E
0005432054309	21083	21	5F
0005432382833	21083	22	6A
0005432382961	21083	23	6C
0005432328375	21083	24	6D
0005432328516	21083	25	6E
0005432328352	21083	26	6F
0005432328351	21083	27	7A
0005432328233	21083	28	7C
0005432382747	21083	29	7D
0005432328660	21083	30	7E
0005432382806	21083	31	7F
0005432328360	21083	32	8A
0005432328476	21083	33	8C
0005432328335	21083	34	8E
0005432328275	21083	35	8F
0005432327992	21083	36	9A
0005432328430	21083	37	9C
0005432328342	21083	38	9D
0005432328344	21083	39	9E
0005432328444	21083	40	9F
0005432054311	21083	41	10A
0005432328279	21083	42	10C
0005432382863	21083	43	10D
0005432328356	21083	44	10E
0005432328349	21083	45	10F
0005432328292	21083	46	11A
0005432382943	21083	47	11C
0005432382730	21083	48	11D
0005432382756	21083	49	11F
0005432382959	21083	50	12A
0005432328424	21083	51	12C
0005432382831	21083	52	12D
0005432328282	21083	53	12E
0005432054312	21083	54	12F
0005432328225	21083	55	13A
0005432382912	21083	56	13C
0005432328431	21083	57	13D
0005432328322	21083	58	13F
0005432328274	21083	59	14A
0005432382788	21083	60	14C
0005432383026	21083	61	14D
0005432328429	21083	62	14E
0005432382790	21083	63	14F
0005432328224	21083	64	15A
0005432382789	21083	65	15C
0005432328272	21083	66	15D
0005432328382	21083	67	15E
0005432328343	21083	68	15F
0005432383079	21083	69	16A
0005432382938	21083	70	16C
0005432328297	21083	71	16D
0005432382969	21083	72	16E
0005432328345	21083	73	16F
0005432382920	21083	74	17A
0005432383027	21083	75	17C
0005432382888	21083	76	17D
0005432328290	21083	77	17F
0005432328270	21083	78	18A
0005432328281	21083	79	18C
0005432328319	21083	80	18D
0005432054313	21083	81	18E
0005432382940	21083	82	18F
0005432328381	21083	83	19A
0005432382930	21083	84	19C
0005432328264	21083	85	19D
0005432328323	21083	86	19E
0005432054310	21083	87	19F
0005432328291	21083	88	20C
0005432382890	21083	89	20D
0005432328423	21083	90	20E
0005432382913	21083	91	20F
0005432328782	31245	1	1A
0005432328766	31245	2	1C
0005432328769	31245	3	1D
0005432328763	31245	4	1F
0005432328737	31245	5	2A
0005432328772	31245	6	2C
0005432383205	31245	7	2D
0005432383207	31245	8	2F
0005432383202	31245	9	3A
0005432328753	31245	10	3C
0005432328750	31245	11	3D
0005432328778	31245	12	3F
0005432328740	31245	13	4A
0005432328771	31245	14	4C
0005432287197	31245	15	4D
0005432328749	31245	16	4F
0005432328773	31245	17	5A
0005432328757	31245	18	5D
0005432287193	31245	19	5E
0005432328781	31245	20	5F
0005432328762	31245	21	6A
0005432287195	31245	22	6C
0005432328777	31245	23	6D
0005432383223	31245	24	6E
0005432383231	31245	25	6F
0005432383217	31245	26	7C
0005432328752	31245	27	7D
0005432328758	31245	28	7E
0005432383218	31245	29	7F
0005432328754	31245	30	8A
0005432287198	31245	31	8C
0005432383214	31245	32	8D
0005432328780	31245	33	8F
0005432383237	31245	34	9A
0005432383213	31245	35	9C
0005432328738	31245	36	9D
0005432328783	31245	37	9E
0005432287196	31245	38	9F
0005432383229	31245	39	10A
0005432328761	31245	40	10C
0005432328765	31245	41	10D
0005432383227	31245	42	10E
0005432383212	31245	43	10F
0005432383234	31245	44	11A
0005432383222	31245	45	11C
0005432328745	31245	46	11D
0005432383204	31245	47	11E
0005432328742	31245	48	11F
0005432328741	31245	49	12A
0005432383220	31245	50	12C
0005432383232	31245	51	12D
0005432383203	31245	52	12E
0005432328776	31245	53	12F
0005432383208	31245	54	13A
0005432383235	31245	55	13C
0005432383219	31245	56	13D
0005432383210	31245	57	13E
0005432328764	31245	58	13F
0005432328767	31245	59	14A
0005432328759	31245	60	14C
0005432328760	31245	61	14D
0005432328743	31245	62	14E
0005432328768	31245	63	14F
0005432328775	31245	64	15A
0005432383215	31245	65	15C
0005432328755	31245	66	15D
0005432287194	31245	67	15E
0005432383226	31245	68	15F
0005432328739	31245	69	16A
0005432383216	31245	70	16C
0005432383206	31245	71	16D
0005432383209	31245	72	16E
0005432328779	31245	73	16F
0005432328748	31245	74	17A
0005432328746	31245	75	17C
0005432328756	31245	76	17E
0005432383224	31245	77	17F
0005432383211	31245	78	18A
0005432328770	31245	79	18C
0005432383233	31245	80	18D
0005432328747	31245	81	18E
0005432328744	31245	82	19A
0005432383236	31245	83	19C
0005432383221	31245	84	19D
0005432383225	31245	85	19E
0005432328774	31245	86	19F
0005432383230	31245	87	20A
0005432383228	31245	88	20F
0005432328751	31245	89	20E
0005432424492	13259	1	1A
0005432424483	13259	2	1C
0005432424481	13259	3	1F
0005432424495	13259	4	2A
0005432424506	13259	5	2C
0005432424477	13259	6	2D
0005432424465	13259	7	3F
0005432424485	13259	8	4A
0005432424463	13259	9	4C
0005432424501	13259	10	4E
0005432424470	13259	11	4F
0005432424511	13259	12	5C
0005432424475	13259	13	5D
0005432424486	13259	14	5E
0005432424488	13259	15	6C
0005432424490	13259	16	6E
0005432424498	13259	17	7A
0005432424507	13259	18	7C
0005432424487	13259	19	7F
0005432424519	13259	20	9A
0005432424466	13259	21	9D
0005432424464	13259	22	9F
0005432424517	13259	23	10D
0005432424503	13259	24	10E
0005432424508	13259	25	10F
0005432424496	13259	26	11A
0005432424474	13259	27	11D
0005432424515	13259	28	11E
0005432424504	13259	29	11F
0005432424510	13259	30	12C
0005432424480	13259	31	12D
0005432424505	13259	32	13A
0005432424500	13259	33	13C
0005432424479	13259	34	13D
0005432424489	13259	35	13F
0005432424493	13259	36	14A
0005432424482	13259	37	14C
0005432424516	13259	38	14E
0005432424502	13259	39	14F
0005432424476	13259	40	15A
0005432424478	13259	41	15D
0005432424514	13259	42	15E
0005432424473	13259	43	15F
0005432424494	13259	44	16A
0005432424512	13259	45	16F
0005432424471	13259	46	17D
0005432424499	13259	47	17F
0005432424491	13259	48	18A
0005432424467	13259	49	18C
0005432424513	13259	50	18D
0005432424518	13259	51	18E
0005432424509	13259	52	19A
0005432424497	13259	53	19D
0005432424468	13259	54	19F
0005432424469	13259	55	20D
0005432424472	13259	56	20E
0005432424484	13259	57	20F
0005432424061	30730	1	1A
0005432424017	30730	2	1F
0005432424062	30730	3	2C
0005432424063	30730	4	2F
0005432424097	30730	5	3C
0005432424018	30730	6	4A
0005432424052	30730	7	4C
0005432424029	30730	8	4F
0005432423917	30730	9	5A
0005432424122	30730	10	5D
0005432424075	30730	11	5E
0005432424146	30730	12	5F
0005432423970	30730	13	6A
0005432424084	30730	14	6D
0005432423922	30730	15	7A
0005432424157	30730	16	7C
0005432424080	30730	17	7E
0005432424069	30730	18	8C
0005432424073	30730	19	8D
0005432424102	30730	20	8F
0005432424120	30730	21	9F
0005432424156	30730	22	10A
0005432424077	30730	23	10D
0005432424016	30730	24	10F
0005432424133	30730	25	12D
0005432423916	30730	26	12E
0005432424161	30730	27	12F
0005432424074	30730	28	13E
0005432424149	30730	29	14C
0005432423972	30730	30	14E
0005432424051	30730	31	14F
0005432423971	30730	32	15E
0005432424068	30730	33	16A
0005432423973	30730	34	16C
0005432424072	30730	35	16E
0005432424143	30730	36	16F
0005432424134	30730	37	17D
0005432424105	30730	38	17E
0005432423918	30730	39	18C
0005432423959	30730	40	18F
0005432424119	30730	41	19A
0005432424081	30730	42	19F
0005432424076	30730	43	20A
0005432424015	30730	44	20D
0005432817524	9603	1	1A
0005432817540	9603	2	1C
0005432817521	9603	3	1D
0005434157458	9603	4	1F
0005432817534	9603	5	2A
0005432901424	9603	6	2D
0005432817518	9603	7	2F
0005432901389	9603	8	3C
0005432822220	9603	9	3D
0005432901489	9603	10	3F
0005432901423	9603	11	4A
0005434186164	9603	12	4C
0005432817531	9603	13	5A
0005432901455	9603	14	5C
0005434157459	9603	15	5D
0005432901416	9603	16	5E
0005432901551	9603	17	5F
0005432817541	9603	18	6C
0005432817544	9603	19	6D
0005432288993	9603	20	6E
0005432901422	9603	21	7A
0005432817535	9603	22	7D
0005432901509	9603	23	7E
0005432901508	9603	24	7F
0005432822221	9603	25	8A
0005432901500	9603	26	8C
0005432901429	9603	27	8D
0005432817536	9603	28	8F
0005432817522	9603	29	9A
0005434448321	9603	30	9C
0005432817526	9603	31	9E
0005434186163	9603	32	9F
0005432901485	9603	33	10C
0005432817545	9603	34	10A
0005434448323	9603	35	10E
0005432817533	9603	36	11C
0005432822215	9603	37	11D
0005432817538	9603	38	11E
0005432817519	9603	39	11F
0005434448324	9603	40	12A
0005432817517	9603	41	12C
0005432901453	9603	42	12D
0005432817527	9603	43	12E
0005432901484	9603	44	12F
0005434448322	9603	45	13A
0005432901452	9603	46	13D
0005432817539	9603	47	13E
0005434186182	9603	48	13F
0005432822217	9603	49	14A
0005432817525	9603	50	14C
0005432822219	9603	51	14E
0005432817537	9603	52	14F
0005434448325	9603	53	15A
0005432901520	9603	54	15C
0005432817542	9603	55	15D
0005432901480	9603	56	15E
0005432817530	9603	57	16C
0005432817543	9603	58	16D
0005432817529	9603	59	16F
0005432817516	9603	60	17A
0005432817528	9603	61	17C
0005432901519	9603	62	17D
0005432817532	9603	63	17E
0005432901425	9603	64	17F
0005434157460	9603	65	18A
0005434186178	9603	66	18C
0005432822218	9603	67	18D
0005432901499	9603	68	18E
0005434186175	9603	69	19A
0005432288992	9603	70	19C
0005432817520	9603	71	19D
0005432901415	9603	72	19E
0005432817523	9603	73	20A
0005432822216	9603	74	20C
0005432822222	9603	75	20D
0005432901445	9603	76	20F
0005432901650	29012	1	1F
0005434157492	29012	2	2A
0005432817185	29012	3	2C
0005432817253	29012	4	2F
0005432817359	29012	5	3A
0005432822165	29012	6	3C
0005434448278	29012	7	3D
0005432901647	29012	8	3F
0005432002081	29012	9	4C
0005432817401	29012	10	4F
0005432817286	29012	11	5C
0005432901636	29012	12	5D
0005432817418	29012	13	5E
0005434157498	29012	14	5F
0005432901645	29012	15	6D
0005432817268	29012	16	6E
0005432817275	29012	17	7A
0005432817170	29012	18	7F
0005434157496	29012	19	8A
0005432822093	29012	20	8C
0005434186203	29012	21	8D
0005432822164	29012	22	8E
0005432822158	29012	23	8F
0005432901638	29012	24	9A
0005432817419	29012	25	10A
0005432817301	29012	26	10C
0005432901648	29012	27	10D
0005434157495	29012	28	10E
0005432822155	29012	29	10F
0005434157494	29012	30	11A
0005432901646	29012	31	11C
0005432901639	29012	32	11D
0005434186201	29012	33	11E
0005434157491	29012	34	11F
0005434157497	29012	35	12A
0005432822157	29012	36	12C
0005432817211	29012	37	12D
0005432901652	29012	38	12E
0005432817171	29012	39	12F
0005432002079	29012	40	13C
0005432901644	29012	41	13A
0005432901642	29012	42	14A
0005432901637	29012	43	14D
0005434186202	29012	44	14E
0005432002080	29012	45	14F
0005434448290	29012	46	15A
0005432817289	29012	47	15D
0005432901641	29012	48	15F
0005432901651	29012	49	16C
0005432901640	29012	50	16D
0005432817210	29012	51	16E
0005432822094	29012	52	16F
0005432817311	29012	53	17E
0005432901643	29012	54	17F
0005432817320	29012	55	18A
0005432817225	29012	56	18C
0005432822156	29012	57	18E
0005432817285	29012	58	19A
0005432817267	29012	59	19C
0005432901649	29012	60	19D
0005432822143	29012	61	19E
0005434157493	29012	62	19F
0005432817310	29012	63	20D
0005432817353	29012	64	20E
0005432901635	29012	65	20F
0005432611719	15082	1	1A
0005435841087	15082	2	1B
0005432613869	15082	3	2B
0005435841816	15082	4	2A
0005432611717	15082	5	3A
0005432613871	15082	6	3B
0005432611718	15082	7	4A
0005432611720	15082	8	4B
0005435841088	15082	9	5A
0005435841815	15082	10	5B
0005432613870	15082	11	6A
0005432613868	15082	12	6B
0005435841823	31602	1	1A
0005432611684	31602	2	1B
0005435841825	31602	3	2A
0005432611686	31602	4	2B
0005432611677	31602	5	3A
0005432607539	31602	6	3B
0005432611672	31602	7	4A
0005432611676	31602	8	4B
0005435841822	31602	9	5A
0005432611678	31602	10	5B
0005435841824	31602	11	6A
0005432611687	31602	12	6B
0005433569129	11871	1	1C
0005433569181	11871	2	1A
0005432948177	11871	3	1F
0005432948281	11871	4	1D
0005433569169	11871	5	2C
0005432948043	11871	6	2A
0005433569146	11871	7	3A
0005432948073	11871	8	3C
0005433569147	11871	9	4A
0005432948182	11871	10	3D
0005432947960	11871	11	4C
0005433569134	11871	12	4F
0005432948289	11871	13	4D
0005433569159	11871	14	5C
0005433569167	11871	15	5A
0005433569132	11871	16	5F
0005433569149	11871	17	5D
0005433569128	11871	18	6A
0005432948122	11871	19	6D
0005433569125	11871	20	6C
0005432948111	11871	21	6B
0005432948194	11871	22	6F
0005432947974	11871	23	6E
0005432948262	11871	24	7A
0005432948183	11871	25	7C
0005433569138	11871	26	7B
0005433569148	11871	27	7E
0005432948121	11871	28	7D
0005433569137	11871	29	8A
0005432948107	11871	30	7F
0005433569133	11871	31	8B
0005433569158	11871	32	8D
0005433569150	11871	33	8F
0005432948217	11871	34	8E
0005433569127	11871	35	9A
0005432948171	11871	36	9D
0005433569164	11871	37	9B
0005433569139	11871	38	9E
0005432948280	11871	39	10B
0005433569165	11871	40	10A
0005432948019	11871	41	9F
0005433569140	11871	42	10C
0005432948085	11871	43	10E
0005433569162	11871	44	10D
0005433569141	11871	45	11A
0005432948081	11871	46	10F
0005433569136	11871	47	11C
0005432948110	11871	48	11B
0005432947938	11871	49	11F
0005432948105	11871	50	11E
0005432948248	11871	51	12B
0005433569161	11871	52	12A
0005433569153	11871	53	12C
0005433569170	11871	54	12F
0005433569152	11871	55	12E
0005433569163	11871	56	12D
0005433569143	11871	57	13B
0005432947961	11871	58	13A
0005433569178	11871	59	13C
0005433569145	11871	60	13E
0005432948146	11871	61	13D
0005433569166	11871	62	13F
0005433569126	11871	63	14B
0005433569168	11871	64	14D
0005432948232	11871	65	14C
0005433569175	11871	66	14F
0005433569154	11871	67	14E
0005433569173	11871	68	15B
0005432948216	11871	69	15C
0005432948254	11871	70	15F
0005432948231	11871	71	15E
0005432948225	11871	72	15D
0005433569176	11871	73	16A
0005433569144	11871	74	16B
0005432947827	11871	75	16E
0005433569151	11871	76	16D
0005433569142	11871	77	16F
0005433569131	11871	78	17B
0005433569124	11871	79	17A
0005432948181	11871	80	17D
0005432948172	11871	81	17C
0005432948255	11871	82	17F
0005433569135	11871	83	17E
0005432948050	11871	84	18B
0005432948106	11871	85	18A
0005433569130	11871	86	18D
0005433569172	11871	87	18C
0005433569174	11871	88	18E
0005433569180	11871	89	19A
0005432947973	11871	90	18F
0005432947989	11871	91	19C
0005433569177	11871	92	19B
0005432948292	11871	93	19D
0005432948145	11871	94	20A
0005432948040	11871	95	19F
0005432948250	11871	96	19E
0005432948133	11871	97	20B
0005432947972	11871	98	20C
0005433569156	11871	99	20F
0005433569171	11871	100	20E
0005433569155	11871	101	21B
0005433569179	11871	102	21A
0005433569157	11871	103	21C
0005432948042	11871	104	21D
0005433569160	11871	105	21F
0005433568598	25273	1	1C
0005432948556	25273	2	1A
0005433568623	25273	3	1F
0005433568439	25273	4	1D
0005433568579	25273	5	2A
0005433568740	25273	6	2F
0005432948578	25273	7	2D
0005432948586	25273	8	2C
0005433568663	25273	9	3A
0005433568712	25273	10	3D
0005433568754	25273	11	4A
0005433568785	25273	12	4C
0005432948579	25273	13	4F
0005433568671	25273	14	4D
0005432948563	25273	15	5A
0005433568354	25273	16	5F
0005433568755	25273	17	5D
0005432948575	25273	18	6A
0005432948564	25273	19	6C
0005433568681	25273	20	6B
0005433568601	25273	21	6E
0005432948597	25273	22	7A
0005432948587	25273	23	6F
0005432948566	25273	24	7C
0005433568615	25273	25	7B
0005432948567	25273	26	7E
0005433568723	25273	27	7D
0005433568324	25273	28	7F
0005432948561	25273	29	8C
0005432948576	25273	30	8B
0005433568441	25273	31	8A
0005433568507	25273	32	8D
0005433568508	25273	33	8F
0005433568729	25273	34	8E
0005433568756	25273	35	9B
0005433568527	25273	36	9A
0005433568757	25273	37	9C
0005433568602	25273	38	9E
0005432948588	25273	39	10A
0005433568715	25273	40	9F
0005433568573	25273	41	10C
0005432948568	25273	42	10B
0005432948560	25273	43	10D
0005433568594	25273	44	11A
0005432948558	25273	45	10F
0005432948559	25273	46	10E
0005433568524	25273	47	11C
0005432948581	25273	48	11B
0005433568609	25273	49	11D
0005432948562	25273	50	11F
0005433568368	25273	51	11E
0005433568525	25273	52	12B
0005432948571	25273	53	12A
0005433568554	25273	54	12D
0005433568440	25273	55	12C
0005432948582	25273	56	12E
0005432948594	25273	57	13B
0005432948596	25273	58	13A
0005433568786	25273	59	12F
0005433568597	25273	60	13D
0005433568422	25273	61	13C
0005433568773	25273	62	13E
0005433568593	25273	63	13F
0005433568643	25273	64	14C
0005433568686	25273	65	14A
0005433568472	25273	66	14D
0005432948593	25273	67	14F
0005432948595	25273	68	14E
0005433568713	25273	69	15A
0005432948589	25273	70	15C
0005432948580	25273	71	15F
0005433568526	25273	72	15E
0005433568690	25273	73	16A
0005433568560	25273	74	16B
0005433568248	25273	75	16E
0005432948569	25273	76	16C
0005433568595	25273	77	17A
0005432948585	25273	78	16F
0005432948573	25273	79	17B
0005433568662	25273	80	17D
0005433568571	25273	81	17C
0005433568572	25273	82	17E
0005432948590	25273	83	18A
0005432948557	25273	84	18C
0005433568321	25273	85	18B
0005433568614	25273	86	18E
0005432948591	25273	87	18D
0005433568359	25273	88	19A
0005433568637	25273	89	18F
0005432948584	25273	90	19C
0005432948565	25273	91	19B
0005433568471	25273	92	19D
0005432948592	25273	93	19F
0005432948570	25273	94	20B
0005433568477	25273	95	20D
0005433568724	25273	96	20C
0005432948577	25273	97	20E
0005433568580	25273	98	21B
0005433568672	25273	99	21A
0005432948583	25273	100	20F
0005432948574	25273	101	21C
0005432948572	25273	102	21E
0005433568695	25273	103	21D
0005435340108	5420	1	1C
0005435340150	5420	2	1F
0005434654757	5420	3	2A
0005434654751	5420	4	2C
0005432114209	5420	5	3C
0005435340179	5420	6	3F
0005435340177	5420	7	4A
0005435340137	5420	8	4C
0005434654729	5420	9	4E
0005434656561	5420	10	5C
0005435340099	5420	11	5D
0005434654749	5420	12	5E
0005435340127	5420	13	5F
0005435340090	5420	14	6A
0005434654750	5420	15	6D
0005434654740	5420	16	6C
0005434654736	5420	17	6F
0005432114210	5420	18	7A
0005434654735	5420	19	7C
0005435340124	5420	20	7F
0005435340159	5420	21	8A
0005434654745	5420	22	8E
0005434654730	5420	23	8F
0005434654752	5420	24	9C
0005434654753	5420	25	9D
0005435340145	5420	26	9E
0005434654755	5420	27	10A
0005434654732	5420	28	10D
0005435340178	5420	29	10E
0005435340151	5420	30	10F
0005434654744	5420	31	11C
0005435340107	5420	32	11D
0005434654756	5420	33	12C
0005434654747	5420	34	12E
0005435340125	5420	35	13A
0005434654742	5420	36	13C
0005434654741	5420	37	13F
0005434654733	5420	38	14A
0005435340185	5420	39	14D
0005434654746	5420	40	14E
0005435340192	5420	41	14F
0005434654754	5420	42	15A
0005434654734	5420	43	15D
0005434654737	5420	44	15F
0005434654738	5420	45	16D
0005434656560	5420	46	17E
0005434654739	5420	47	17F
0005434654748	5420	48	18C
0005434654728	5420	49	18D
0005435340091	5420	50	19C
0005435340118	5420	51	20A
0005432114211	5420	52	20C
0005434654731	5420	53	20D
0005434654743	5420	54	20E
0005434654583	12519	1	1A
0005435340299	12519	2	1C
0005434654482	12519	3	1D
0005434654365	12519	4	2C
0005434654577	12519	5	3C
0005434654442	12519	6	3F
0005434654568	12519	7	4A
0005434654474	12519	8	4C
0005434654530	12519	9	5A
0005434654449	12519	10	5D
0005434654567	12519	11	5E
0005435340289	12519	12	6A
0005434654445	12519	13	6F
0005434654398	12519	14	7A
0005434654448	12519	15	7D
0005434654569	12519	16	7E
0005434654475	12519	17	7F
0005435340287	12519	18	8A
0005435340292	12519	19	9A
0005434654545	12519	20	10A
0005434654404	12519	21	10F
0005435340296	12519	22	11A
0005435340293	12519	23	11D
0005435340290	12519	24	11E
0005434654440	12519	25	12C
0005434656545	12519	26	12F
0005434654646	12519	27	13A
0005434654476	12519	28	13C
0005434654512	12519	29	13E
0005434654549	12519	30	14C
0005435340297	12519	31	14D
0005435555375	12519	32	15A
0005434654397	12519	33	15C
0005434654443	12519	34	15E
0005435555376	12519	35	15F
0005434654573	12519	36	16C
0005434654544	12519	37	16D
0005435340288	12519	38	17C
0005434654469	12519	39	17D
0005434654584	12519	40	17E
0005435340294	12519	41	18A
0005435340298	12519	42	18C
0005434656543	12519	43	18E
0005434654645	12519	44	18F
0005435340291	12519	45	19A
0005435340295	12519	46	19C
0005434656542	12519	47	19D
0005434656540	12519	48	19E
0005434654428	12519	49	19F
0005434654447	12519	50	20A
0005434654444	12519	51	20C
0005435555374	12519	52	20E
0005433716085	7418	1	2A
0005433716083	7418	2	1F
0005433656676	7418	3	2D
0005433716042	7418	4	2C
0005433716084	7418	5	2F
0005432078121	7418	6	3C
0005433716050	7418	7	3D
0005433716075	7418	8	3F
0005433716070	7418	9	4A
0005433716081	7418	10	4C
0005433716074	7418	11	4E
0005433716079	7418	12	5A
0005433716054	7418	13	4F
0005432078117	7418	14	5C
0005433689912	7418	15	5D
0005433719143	7418	16	5E
0005433716044	7418	17	6A
0005433716051	7418	18	5F
0005433716046	7418	19	6B
0005433716039	7418	20	6C
0005433716063	7418	21	6E
0005432428908	7418	22	7B
0005433716052	7418	23	7D
0005433716041	7418	24	7F
0005432078120	7418	25	8B
0005433716047	7418	26	8C
0005432428907	7418	27	8E
0005433716088	7418	28	9A
0005433716040	7418	29	9C
0005433716069	7418	30	9B
0005433716065	7418	31	9D
0005433716073	7418	32	10D
0005432078122	7418	33	11C
0005433719144	7418	34	11E
0005433716060	7418	35	11F
0005433716059	7418	36	12A
0005433716055	7418	37	13A
0005433716071	7418	38	13C
0005433716087	7418	39	13D
0005433716045	7418	40	13E
0005433656674	7418	41	14A
0005433656673	7418	42	14C
0005435266105	7418	43	14E
0005433656675	7418	44	14F
0005433716066	7418	45	15B
0005433716058	7418	46	15E
0005433716082	7418	47	16A
0005433688812	7418	48	16B
0005433716057	7418	49	16E
0005433716049	7418	50	16D
0005433716061	7418	51	16F
0005433719145	7418	52	17C
0005433716068	7418	53	17D
0005433689913	7418	54	17F
0005433716064	7418	55	17E
0005433690930	7418	56	18A
0005433716048	7418	57	18D
0005433716067	7418	58	18E
0005433722230	7418	59	19A
0005432078116	7418	60	19C
0005432078118	7418	61	19E
0005433716077	7418	62	19D
0005432078119	7418	63	20A
0005433719146	7418	64	19F
0005433690929	7418	65	20B
0005435266116	7418	66	20C
0005433689914	7418	67	20D
0005433716072	7418	68	21B
0005433716078	7418	69	21C
0005433716053	7418	70	21D
0005433716086	7418	71	22A
0005433716080	7418	72	21F
0005433716076	7418	73	22B
0005433722231	7418	74	22E
0005433716056	7418	75	22F
0005433716043	7418	76	23C
0005433688811	7418	77	23F
0005433716062	7418	78	23E
0005433715573	29222	1	1A
0005433715833	29222	2	1C
0005433719114	29222	3	1F
0005433719123	29222	4	2D
0005433715746	29222	5	3F
0005433715595	29222	6	4A
0005433688795	29222	7	4D
0005433715587	29222	8	5A
0005433715731	29222	9	4F
0005433715503	29222	10	5D
0005433715626	29222	11	6B
0005433715553	29222	12	6A
0005433715690	29222	13	6D
0005433715511	29222	14	6F
0005432006767	29222	15	7A
0005433715557	29222	16	7C
0005433722169	29222	17	7B
0005433715417	29222	18	7D
0005433715805	29222	19	7F
0005433715722	29222	20	7E
0005433656637	29222	21	8B
0005433715571	29222	22	8C
0005433715404	29222	23	8E
0005433715684	29222	24	9A
0005433715651	29222	25	9B
0005435266149	29222	26	9C
0005433715570	29222	27	9D
0005433715832	29222	28	10C
0005433722167	29222	29	11A
0005433715795	29222	30	11D
0005433715668	29222	31	12A
0005433656649	29222	32	12C
0005433715614	29222	33	12D
0005433715510	29222	34	12F
0005433715627	29222	35	13A
0005433715714	29222	36	13E
0005435266150	29222	37	14A
0005433715547	29222	38	14D
0005433715796	29222	39	14C
0005432006766	29222	40	14F
0005433715578	29222	41	15B
0005433715572	29222	42	15C
0005435266152	29222	43	15D
0005432006768	29222	44	16C
0005435266153	29222	45	16E
0005435266151	29222	46	16D
0005433715724	29222	47	16F
0005433719112	29222	48	17A
0005433715806	29222	49	17C
0005433715470	29222	50	17F
0005433688787	29222	51	18C
0005432006765	29222	52	19A
0005433715548	29222	53	18F
0005433715723	29222	54	19B
0005433715435	29222	55	19C
0005433715733	29222	56	19F
0005432428936	29222	57	20A
0005433688796	29222	58	20C
0005433715658	29222	59	20E
0005433715732	29222	60	21A
0005432428937	29222	61	21D
0005433715577	29222	62	21C
0005433715763	29222	63	21E
0005433719111	29222	64	22B
0005433715739	29222	65	22A
0005433715691	29222	66	22C
0005433688791	29222	67	22F
0005433715878	29222	68	23A
0005433656627	29222	69	23B
0005432428935	29222	70	23E
0005433715416	29222	71	23F
0005434095305	8698	1	2C
0005434143730	8698	2	2D
0005434143727	8698	3	3C
0005434095307	8698	4	3F
0005434182113	8698	5	3D
0005434182077	8698	6	5A
0005434182049	8698	7	6E
0005434181998	8698	8	6F
0005434095309	8698	9	7E
0005434095296	8698	10	8E
0005434182048	8698	11	9C
0005434182061	8698	12	9E
0005434095297	8698	13	9F
0005434095298	8698	14	10C
0005434182143	8698	15	10D
0005434095300	8698	16	10F
0005434095299	8698	17	11A
0005434095302	8698	18	11D
0005434095306	8698	19	12C
0005434095301	8698	20	12D
0005434095308	8698	21	12F
0005434181997	8698	22	13A
0005434143728	8698	23	13D
0005434143725	8698	24	14A
0005434182169	8698	25	14D
0005434182078	8698	26	15D
0005434182093	8698	27	15E
0005434182168	8698	28	16A
0005434182114	8698	29	16D
0005434095310	8698	30	18C
0005434095304	8698	31	18D
0005434095303	8698	32	18F
0005434143729	8698	33	19A
0005434143726	8698	34	19C
0005434182137	8698	35	19D
0005434182092	8698	36	19E
0005434182094	8698	37	20F
0005434095182	11677	1	1A
0005434184667	11677	2	2A
0005434095152	11677	3	2D
0005434095199	11677	4	3F
0005434182209	11677	5	4C
0005434095204	11677	6	4D
0005434183582	11677	7	4E
0005434095176	11677	8	5A
0005434182206	11677	9	5C
0005434095203	11677	10	5E
0005434182207	11677	11	6A
0005434095149	11677	12	6C
0005434182205	11677	13	8A
0005434095194	11677	14	8D
0005434095192	11677	15	8F
0005434182203	11677	16	9A
0005434182202	11677	17	9C
0005434095175	11677	18	9E
0005434095249	11677	19	9F
0005434183581	11677	20	11E
0005434182208	11677	21	12A
0005434095202	11677	22	13D
0005434182204	11677	23	14F
0005434182212	11677	24	15A
0005434182211	11677	25	15C
0005434182214	11677	26	15F
0005434095193	11677	27	16F
0005434183583	11677	28	17C
0005434143718	11677	29	17F
0005434182213	11677	30	18A
0005434182210	11677	31	18C
0005434095162	11677	32	18D
0005434095201	11677	33	18E
0005434095214	11677	34	18F
0005434182215	11677	35	19D
0005433397682	1440	1	1A
0005435732347	1440	2	1C
0005433397924	1440	3	2A
0005433397762	1440	4	2C
0005433397760	1440	5	2D
0005433397741	1440	6	2F
0005433397646	1440	7	3A
0005433397672	1440	8	3C
0005435732351	1440	9	3D
0005433397635	1440	10	3F
0005433397627	1440	11	4C
0005432297282	1440	12	5A
0005433456976	1440	13	5C
0005433397787	1440	14	5D
0005433397579	1440	15	5F
0005433397923	1440	16	6A
0005433397944	1440	17	6C
0005435732352	1440	18	6D
0005433397763	1440	19	6E
0005433397732	1440	20	6F
0005433397758	1440	21	7C
0005435732353	1440	22	7F
0005435732355	1440	23	8A
0005433397647	1440	24	8D
0005433397725	1440	25	8F
0005433397411	1440	26	9A
0005433397469	1440	27	9C
0005435732360	1440	28	9D
0005433397724	1440	29	9E
0005433397697	1440	30	9F
0005433397742	1440	31	10A
0005433397862	1440	32	10C
0005435732359	1440	33	10D
0005433397634	1440	34	10E
0005433397752	1440	35	10F
0005435732356	1440	36	11A
0005433397963	1440	37	11D
0005435732358	1440	38	11E
0005433397850	1440	39	11F
0005433397759	1440	40	12A
0005432906530	1440	41	12D
0005433397674	1440	42	12E
0005432297281	1440	43	12F
0005433397789	1440	44	13A
0005433397740	1440	45	13C
0005433397671	1440	46	13D
0005433456978	1440	47	14A
0005435732349	1440	48	14C
0005433397694	1440	49	14D
0005433397578	1440	50	14F
0005433397673	1440	51	15C
0005433397790	1440	52	15D
0005433397945	1440	53	15E
0005433397896	1440	54	15F
0005433397685	1440	55	16C
0005433397686	1440	56	16D
0005435732348	1440	57	16E
0005435732357	1440	58	16F
0005433397820	1440	59	17A
0005433397916	1440	60	17C
0005433397753	1440	61	17E
0005433397389	1440	62	18A
0005432297283	1440	63	18D
0005435732354	1440	64	18E
0005435732350	1440	65	19C
0005433397708	1440	66	19E
0005433456977	1440	67	20A
0005433397743	1440	68	20C
0005433397648	1440	69	20D
0005433397675	1440	70	20E
0005433397693	1440	71	20F
0005435732253	19236	1	1C
0005435732240	19236	2	1D
0005433398153	19236	3	1F
0005433398132	19236	4	2A
0005435732199	19236	5	2C
0005433398160	19236	6	2D
0005435732246	19236	7	3A
0005433398140	19236	8	4C
0005433398133	19236	9	4D
0005433456942	19236	10	4E
0005433398144	19236	11	4F
0005433398156	19236	12	5C
0005433398148	19236	13	5D
0005435732198	19236	14	5E
0005433398164	19236	15	5F
0005433398126	19236	16	6A
0005433398146	19236	17	6C
0005435732269	19236	18	6D
0005435732268	19236	19	6E
0005433398147	19236	20	6F
0005433398170	19236	21	7C
0005433398171	19236	22	7E
0005433398136	19236	23	7F
0005433398167	19236	24	8A
0005433398149	19236	25	8C
0005433398173	19236	26	8D
0005433398139	19236	27	8E
0005433398137	19236	28	8F
0005433398141	19236	29	9A
0005433456943	19236	30	9C
0005433398172	19236	31	9D
0005433398162	19236	32	9E
0005433398127	19236	33	9F
0005433398165	19236	34	10C
0005433398138	19236	35	10D
0005435732234	19236	36	10E
0005433398152	19236	37	11C
0005435732254	19236	38	11F
0005433398142	19236	39	12D
0005433398163	19236	40	13A
0005435732264	19236	41	13D
0005433398159	19236	42	13F
0005433398166	19236	43	14A
0005435732221	19236	44	14D
0005433398131	19236	45	14E
0005433398125	19236	46	14F
0005433398129	19236	47	15A
0005433398154	19236	48	15C
0005433398130	19236	49	15E
0005432906541	19236	50	16A
0005433398155	19236	51	16C
0005433398134	19236	52	16E
0005433398161	19236	53	17C
0005433398124	19236	54	17F
0005433398169	19236	55	18C
0005435732189	19236	56	18D
0005435732267	19236	57	18E
0005433398158	19236	58	18F
0005433398150	19236	59	19A
0005433398143	19236	60	19C
0005433398145	19236	61	19D
0005433398128	19236	62	19E
0005433398151	19236	63	19F
0005433398135	19236	64	20A
0005433398157	19236	65	20D
0005433398168	19236	66	20E
0005433456934	19236	67	20F
0005434443593	17369	1	2A
0005434443629	17369	2	2C
0005434443518	17369	3	6C
0005434443630	17369	4	7D
0005434443631	17369	5	18D
0005434443563	17369	6	19B
0005434443726	20581	1	1D
0005434443721	20581	2	2A
0005434443735	20581	3	2D
0005434443722	20581	4	3A
0005434443734	20581	5	3B
0005434443724	20581	6	3C
0005434443729	20581	7	4A
0005434443736	20581	8	4C
0005434443732	20581	9	4D
0005434443725	20581	10	6A
0005434443733	20581	11	18B
0005434443727	20581	12	19C
0005434443730	20581	13	20A
0005434443728	20581	14	20B
0005434443731	20581	15	20D
0005434443723	20581	16	22A
0005434443737	20581	17	23B
0005434954617	7255	1	3B
0005434954616	7255	2	4A
0005434954585	28355	1	1A
0005434954582	28355	2	2A
0005434954577	28355	3	2B
0005435377585	28355	4	3A
0005434954584	28355	5	3B
0005435377586	28355	6	4B
0005434954588	28355	7	5B
0005434954583	28355	8	6A
0005435377584	28355	9	6B
0005435893593	4458	1	1B
0005434183570	4458	2	1C
0005435893596	4458	3	2A
0005435893590	4458	4	2B
0005434351715	4458	5	3A
0005434351724	4458	6	3B
0005435893605	4458	7	3D
0005434351721	4458	8	3C
0005435893600	4458	9	4A
0005434351716	4458	10	4D
0005435893574	4458	11	5A
0005434351714	4458	12	5D
0005434183569	4458	13	6A
0005434351717	4458	14	6B
0005434351720	4458	15	7A
0005435893604	4458	16	7B
0005435893599	4458	17	7C
0005434351725	4458	18	18A
0005434183568	4458	19	18B
0005435893595	4458	20	18C
0005435893594	4458	21	18D
0005434351723	4458	22	19C
0005435893589	4458	23	19D
0005435893573	4458	24	20A
0005434351722	4458	25	20B
0005435893601	4458	26	20C
0005435893561	4458	27	21C
0005434351719	4458	28	22A
0005435893586	4458	29	22C
0005434351718	4458	30	23A
0005434351592	29674	1	1A
0005435893644	29674	2	1B
0005434351589	29674	3	1D
0005434351652	29674	4	2A
0005434351554	29674	5	2B
0005434351667	29674	6	2C
0005435893643	29674	7	3C
0005434351649	29674	8	4D
0005434351614	29674	9	5A
0005434351666	29674	10	5B
0005434351605	29674	11	5C
0005434351613	29674	12	5D
0005434351591	29674	13	6A
0005434351594	29674	14	6D
0005434351644	29674	15	7A
0005435893642	29674	16	7D
0005434351643	29674	17	18A
0005435893647	29674	18	18B
0005434351621	29674	19	19A
0005435893648	29674	20	19B
0005435893641	29674	21	20A
0005434351645	29674	22	20B
0005435893645	29674	23	20D
0005434351593	29674	24	21C
0005434351555	29674	25	21D
0005434351648	29674	26	22A
0005435893646	29674	27	22B
0005435545760	1049	1	1A
0005435092093	1049	2	1B
0005433342120	1049	3	2B
0005433342014	1049	4	2F
0005433342448	1049	5	2C
0005433342288	1049	6	2G
0005433342477	1049	7	2H
0005433342380	1049	8	3B
0005433269674	1049	9	3F
0005433269685	1049	10	3C
0005433342121	1049	11	4A
0005433342580	1049	12	4F
0005433342211	1049	13	4G
0005433342510	1049	14	5A
0005433342190	1049	15	5F
0005433342167	1049	16	5C
0005435545765	1049	17	9G
0005434446523	1049	18	11D
0005433342303	1049	19	11E
0005435545752	1049	20	11H
0005433342660	1049	21	11G
0005433342451	1049	22	12E
0005435092090	1049	23	12D
0005433342198	1049	24	12F
0005434446524	1049	25	12H
0005433463905	1049	26	12G
0005435545758	1049	27	13B
0005434445252	1049	28	13A
0005433342466	1049	29	13F
0005433342362	1049	30	13E
0005433342794	1049	31	14A
0005433462750	1049	32	14D
0005433342625	1049	33	14E
0005433342287	1049	34	15E
0005433342403	1049	35	15F
0005432293214	1049	36	15G
0005435545759	1049	37	16B
0005433342037	1049	38	16G
0005433463904	1049	39	16F
0005433342013	1049	40	16H
0005433342212	1049	41	17B
0005435092087	1049	42	17D
0005435092089	1049	43	17E
0005435092094	1049	44	17G
0005433342491	1049	45	17F
0005435092096	1049	46	17H
0005433342447	1049	47	18B
0005433342125	1049	48	18A
0005433342111	1049	49	18E
0005435545766	1049	50	18D
0005433342558	1049	51	18F
0005435545762	1049	52	18G
0005433269684	1049	53	19A
0005433342615	1049	54	18H
0005435545756	1049	55	19D
0005433342183	1049	56	19F
0005433341870	1049	57	19E
0005433269673	1049	58	19G
0005433342312	1049	59	20D
0005433342482	1049	60	20E
0005433342420	1049	61	20G
0005433342419	1049	62	20F
0005433342484	1049	63	20H
0005432293213	1049	64	21A
0005433342712	1049	65	21F
0005433342659	1049	66	22A
0005433342421	1049	67	21G
0005433342581	1049	68	22B
0005433342562	1049	69	22E
0005432293212	1049	70	22H
0005433342122	1049	71	23B
0005433341898	1049	72	23A
0005433342231	1049	73	23D
0005435545757	1049	74	23F
0005433342043	1049	75	23G
0005435092097	1049	76	24A
0005433342476	1049	77	24F
0005433342382	1049	78	24E
0005433269659	1049	79	24G
0005433269658	1049	80	24H
0005433342302	1049	81	25F
0005433342669	1049	82	27B
0005433462751	1049	83	27D
0005433342596	1049	84	27H
0005433342617	1049	85	28B
0005433342511	1049	86	28E
0005435545754	1049	87	28D
0005433342490	1049	88	28G
0005435545761	1049	89	29A
0005435092095	1049	90	28H
0005433342191	1049	91	29B
0005435545755	1049	92	29E
0005435545753	1049	93	29F
0005433342410	1049	94	30B
0005433342354	1049	95	30D
0005433342636	1049	96	31D
0005433342694	1049	97	31E
0005433342483	1049	98	31G
0005435545767	1049	99	32A
0005434446521	1049	100	31H
0005434446522	1049	101	32B
0005433342626	1049	102	32D
0005433342262	1049	103	32F
0005433342346	1049	104	32G
0005433342290	1049	105	33A
0005433342671	1049	106	33B
0005433342616	1049	107	33E
0005433269660	1049	108	33G
0005433342977	1049	109	33H
0005433342627	1049	110	34A
0005433342478	1049	111	34G
0005433342347	1049	112	34F
0005433342108	1049	113	35B
0005433342392	1049	114	35A
0005435545763	1049	115	35F
0005433342342	1049	116	35E
0005434445253	1049	117	35G
0005433342519	1049	118	36B
0005435092092	1049	119	36E
0005433342363	1049	120	36F
0005433342582	1049	121	36H
0005433342059	1049	122	36G
0005433158122	1049	123	37A
0005435092091	1049	124	37D
0005433342701	1049	125	37B
0005435545764	1049	126	37F
0005433342635	1049	127	37H
0005433342157	1049	128	38D
0005433342264	1049	129	38B
0005435092088	1049	130	38E
0005433342263	1049	131	38F
0005433342450	1049	132	38H
0005433341970	1049	133	39E
0005433343269	17043	1	1C
0005433343214	17043	2	1B
0005435508237	17043	3	1H
0005433343232	17043	4	1G
0005433343220	17043	5	2B
0005435092037	17043	6	2C
0005434445238	17043	7	2G
0005433343282	17043	8	3A
0005433343268	17043	9	3F
0005433343262	17043	10	3G
0005433343251	17043	11	3H
0005435091994	17043	12	4H
0005433343218	17043	13	5B
0005433343276	17043	14	5F
0005435508248	17043	15	5H
0005433343313	17043	16	9B
0005433343259	17043	17	9A
0005434445230	17043	18	9H
0005433343246	17043	19	11B
0005433343271	17043	20	11E
0005434445236	17043	21	11F
0005433343303	17043	22	11H
0005433343305	17043	23	11G
0005433343219	17043	24	12A
0005433343229	17043	25	12B
0005433343222	17043	26	12E
0005433343223	17043	27	12D
0005435091993	17043	28	12F
0005433343257	17043	29	13B
0005433343308	17043	30	13A
0005433343277	17043	31	13G
0005435508225	17043	32	13F
0005433343258	17043	33	13H
0005433343309	17043	34	14E
0005433343296	17043	35	14D
0005435091995	17043	36	14B
0005433343290	17043	37	14G
0005435508235	17043	38	15B
0005433343272	17043	39	15A
0005433343261	17043	40	15D
0005433269730	17043	41	15F
0005433343288	17043	42	16B
0005433343253	17043	43	16A
0005433343217	17043	44	16E
0005433343247	17043	45	16H
0005433343215	17043	46	17A
0005433343226	17043	47	17D
0005433343238	17043	48	17F
0005433343292	17043	49	17E
0005433343307	17043	50	17G
0005433343213	17043	51	17H
0005433343234	17043	52	18B
0005433343241	17043	53	18E
0005433343227	17043	54	18G
0005433343302	17043	55	19A
0005433343285	17043	56	20A
0005433343295	17043	57	19H
0005433343287	17043	58	20F
0005433269729	17043	59	21D
0005433343301	17043	60	21E
0005433343243	17043	61	21G
0005435508215	17043	62	21H
0005433343225	17043	63	22B
0005434445239	17043	64	22E
0005433343245	17043	65	22H
0005433343280	17043	66	23B
0005433343286	17043	67	23E
0005433343275	17043	68	24D
0005433343311	17043	69	24B
0005433343255	17043	70	24F
0005433343270	17043	71	24H
0005433343300	17043	72	24G
0005433343306	17043	73	25D
0005433343265	17043	74	25F
0005433343216	17043	75	25E
0005433343312	17043	76	27A
0005433343289	17043	77	27B
0005433343230	17043	78	27E
0005433343273	17043	79	27F
0005433343252	17043	80	27H
0005433343293	17043	81	28A
0005433343228	17043	82	28D
0005435508264	17043	83	28G
0005435508249	17043	84	28F
0005433343299	17043	85	29A
0005433343266	17043	86	29F
0005433343281	17043	87	29H
0005433343233	17043	88	30D
0005433343250	17043	89	30F
0005433343304	17043	90	30E
0005433343298	17043	91	30H
0005433343264	17043	92	31B
0005433343236	17043	93	31A
0005433343235	17043	94	31E
0005433269728	17043	95	31D
0005433343237	17043	96	32A
0005433269726	17043	97	32B
0005435091976	17043	98	32E
0005433343291	17043	99	32D
0005433343283	17043	100	32H
0005433343240	17043	101	33A
0005433343248	17043	102	33F
0005435508263	17043	103	33H
0005435508238	17043	104	33G
0005433343249	17043	105	34B
0005433343239	17043	106	34E
0005433343260	17043	107	34F
0005433343256	17043	108	35A
0005434445224	17043	109	34G
0005433343297	17043	110	35B
0005433343242	17043	111	35D
0005433343310	17043	112	35E
0005435508265	17043	113	35H
0005433343274	17043	114	35G
0005433343278	17043	115	36B
0005433269727	17043	116	36A
0005435092036	17043	117	36E
0005433343267	17043	118	36D
0005433343263	17043	119	36G
0005435508256	17043	120	37A
0005433343224	17043	121	37D
0005433343231	17043	122	37F
0005433343254	17043	123	38B
0005433343221	17043	124	38A
0005433343244	17043	125	38D
0005433343294	17043	126	38E
0005433343279	17043	127	38F
0005433343284	17043	128	38G
0005434067146	12810	1	1A
0005434067065	12810	2	1C
0005434066984	12810	3	1F
0005434066897	12810	4	1D
0005434081677	12810	5	2C
0005434081727	12810	6	2A
0005432159867	12810	7	2D
0005434066801	12810	8	3A
0005434067151	12810	9	2F
0005432433691	12810	10	3D
0005434081714	12810	11	3C
0005434067253	12810	12	3F
0005434067045	12810	13	4B
0005434067157	12810	14	4A
0005432159864	12810	15	4C
0005434081784	12810	16	4D
0005434081797	12810	17	4E
0005434066974	12810	18	5A
0005433989726	12810	19	4F
0005432433688	12810	20	5C
0005434066614	12810	21	5B
0005433989737	12810	22	5D
0005434066750	12810	23	5E
0005434081710	12810	24	5F
0005433989751	12810	25	6A
0005434067014	12810	26	6C
0005432433690	12810	27	6B
0005432159868	12810	28	6D
0005434067046	12810	29	6E
0005434067124	12810	30	7A
0005434081783	12810	31	6F
0005434081702	12810	32	7C
0005434081729	12810	33	7D
0005434067264	12810	34	7E
0005434067348	12810	35	8A
0005434066821	12810	36	7F
0005432161157	12810	37	8B
0005434067092	12810	38	8C
0005434067091	12810	39	8D
0005434067042	12810	40	8F
0005433812905	12810	41	8E
0005434066615	12810	42	9A
0005434066822	12810	43	9B
0005434067349	12810	44	9C
0005434066885	12810	45	9E
0005434067125	12810	46	9D
0005434067263	12810	47	9F
0005434081735	12810	48	10B
0005434066935	12810	49	10D
0005434081607	12810	50	10C
0005434081605	12810	51	10E
0005434066693	12810	52	11C
0005434081742	12810	53	11B
0005434067041	12810	54	11D
0005434066896	12810	55	11E
0005434066933	12810	56	11F
0005434067003	12810	57	12A
0005434067180	12810	58	12C
0005434067019	12810	59	12B
0005434081788	12810	60	12D
0005434066994	12810	61	12F
0005433989723	12810	62	13A
0005434067174	12810	63	13B
0005434081690	12810	64	13C
0005434067254	12810	65	13F
0005434066986	12810	66	13E
0005434067162	12810	67	13D
0005434066731	12810	68	14B
0005434066817	12810	69	14A
0005434067040	12810	70	14C
0005432159865	12810	71	14D
0005434081748	12810	72	14E
0005433989763	12810	73	15A
0005434066914	12810	74	14F
0005434066934	12810	75	15B
0005434081692	12810	76	15C
0005434066659	12810	77	15D
0005434067170	12810	78	15E
0005434081726	12810	79	16A
0005434066941	12810	80	15F
0005434067073	12810	81	16D
0005434081637	12810	82	16C
0005434066751	12810	83	16F
0005434067089	12810	84	16E
0005433989727	12810	85	17A
0005432159866	12810	86	17B
0005434067209	12810	87	17D
0005432161156	12810	88	17C
0005434081717	12810	89	17E
0005434066878	12810	90	18A
0005434066818	12810	91	17F
0005434066660	12810	92	18B
0005434067066	12810	93	18D
0005434081693	12810	94	18C
0005434081711	12810	95	18E
0005434066940	12810	96	18F
0005434067203	12810	97	19C
0005434081789	12810	98	19B
0005434066857	12810	99	19D
0005434081676	12810	100	19F
0005434067265	12810	101	19E
0005434067208	12810	102	20A
0005434067081	12810	103	20C
0005434066767	12810	104	20B
0005434066971	12810	105	20D
0005434066848	12810	106	20E
0005434067093	12810	107	21A
0005434081730	12810	108	20F
0005433812904	12810	109	21B
0005434067210	12810	110	21C
0005434081606	12810	111	21D
0005432433689	12810	112	21E
0005434066811	12810	113	22A
0005432433692	12810	114	21F
0005432161155	12810	115	22C
0005434081778	12810	116	22B
0005434067236	12810	117	22D
0005434067082	12810	118	22E
0005434067235	12810	119	23A
0005434067320	12810	120	22F
0005434081715	12810	121	23B
0005434067100	12810	122	23D
0005434067010	12810	123	23C
0005434081790	12810	124	23E
0005434066970	12810	125	23F
0005433989777	30660	1	1A
0005434067632	30660	2	1C
0005432433664	30660	3	1D
0005434067620	30660	4	2A
0005433812876	30660	5	1F
0005434067666	30660	6	2C
0005434067617	30660	7	2F
0005434067621	30660	8	3C
0005434067622	30660	9	3A
0005434067673	30660	10	3F
0005434081920	30660	11	3D
0005434067605	30660	12	4B
0005432150200	30660	13	4A
0005434081925	30660	14	4C
0005434067624	30660	15	4D
0005434067656	30660	16	4E
0005433812873	30660	17	5A
0005434067657	30660	18	4F
0005434067667	30660	19	5B
0005433812877	30660	20	5C
0005432150205	30660	21	5D
0005434067651	30660	22	5E
0005434081921	30660	23	5F
0005434067604	30660	24	6B
0005434067642	30660	25	6A
0005434067650	30660	26	6C
0005434067653	30660	27	6D
0005433812875	30660	28	6E
0005434067627	30660	29	6F
0005434081927	30660	30	7A
0005434067668	30660	31	7C
0005434067649	30660	32	7D
0005434067630	30660	33	7F
0005434026702	30660	34	7E
0005434067654	30660	35	8A
0005434067635	30660	36	8B
0005433812864	30660	37	8D
0005434067619	30660	38	8C
0005432433665	30660	39	8E
0005434067672	30660	40	9B
0005434067612	30660	41	9A
0005434067603	30660	42	8F
0005434067663	30660	43	9D
0005433989776	30660	44	9C
0005434067628	30660	45	9F
0005434067658	30660	46	9E
0005434067655	30660	47	10B
0005434067664	30660	48	10C
0005434067660	30660	49	10E
0005434067618	30660	50	11A
0005432150203	30660	51	11B
0005434067611	30660	52	11C
0005432150204	30660	53	11E
0005434026701	30660	54	11D
0005434026705	30660	55	11F
0005434067616	30660	56	12C
0005434067639	30660	57	12B
0005434081926	30660	58	12D
0005433812872	30660	59	12E
0005434067675	30660	60	12F
0005433989775	30660	61	13A
0005434067615	30660	62	13B
0005434067636	30660	63	13D
0005434067671	30660	64	13C
0005434067659	30660	65	13E
0005434067623	30660	66	13F
0005434067652	30660	67	14A
0005434067631	30660	68	14C
0005432150206	30660	69	14B
0005432150201	30660	70	14D
0005432433629	30660	71	14E
0005432186873	30660	72	15B
0005434067670	30660	73	15A
0005434026708	30660	74	15C
0005434067643	30660	75	15D
0005434067641	30660	76	15E
0005434067614	30660	77	15F
0005434067638	30660	78	16B
0005434067609	30660	79	16C
0005434067607	30660	80	16D
0005434067644	30660	81	16F
0005433812865	30660	82	16E
0005434067625	30660	83	17A
0005434081922	30660	84	17B
0005432186871	30660	85	17C
0005434026704	30660	86	17E
0005434067634	30660	87	17D
0005434067669	30660	88	17F
0005433812867	30660	89	18A
0005434067646	30660	90	18B
0005434067608	30660	91	18D
0005434067606	30660	92	18C
0005432186874	30660	93	18F
0005434081928	30660	94	18E
0005434026707	30660	95	19A
0005434067665	30660	96	19B
0005432150202	30660	97	19D
0005434067640	30660	98	19C
0005434026706	30660	99	19E
0005434081919	30660	100	19F
0005433812874	30660	101	20A
0005432186872	30660	102	20B
0005432433635	30660	103	20D
0005432433649	30660	104	21A
0005434081923	30660	105	20F
0005434067661	30660	106	21C
0005434067633	30660	107	21B
0005434026703	30660	108	21D
0005434067662	30660	109	21F
0005434067645	30660	110	22B
0005434067610	30660	111	22A
0005432433636	30660	112	22C
0005434067674	30660	113	22E
0005434067613	30660	114	22D
0005434067629	30660	115	22F
0005434067626	30660	116	23B
0005434081924	30660	117	23A
0005434081918	30660	118	23C
0005434067647	30660	119	23D
0005434067648	30660	120	23F
0005434067637	30660	121	23E
0005435766347	5546	1	1B
0005435735141	5546	2	1F
0005435462152	5546	3	1G
0005435725605	5546	4	2B
0005435461993	5546	5	2F
0005434264910	5546	6	2C
0005435461995	5546	7	2G
0005435766354	5546	8	3A
0005435766315	5546	9	2H
0005435462148	5546	10	3C
0005435766329	5546	11	3B
0005434265064	5546	12	3G
0005435462202	5546	13	3F
0005435462054	5546	14	4A
0005435462125	5546	15	3H
0005435766355	5546	16	4B
0005434264897	5546	17	4C
0005435766333	5546	18	4G
0005435462151	5546	19	5A
0005435462262	5546	20	4H
0005435766346	5546	21	5C
0005434265090	5546	22	5G
0005435462225	5546	23	5F
0005435462040	5546	24	5H
0005435723048	5546	25	9B
0005433529286	5546	26	11A
0005435766343	5546	27	9H
0005433527273	5546	28	11B
0005435725608	5546	29	11E
0005435735142	5546	30	11D
0005435462327	5546	31	11G
0005433527274	5546	32	11F
0005434831091	5546	33	11H
0005435766319	5546	34	12A
0005435462266	5546	35	12D
0005435462250	5546	36	12B
0005435462027	5546	37	12F
0005435766317	5546	38	12G
0005435766357	5546	39	13A
0005433529289	5546	40	13D
0005433529285	5546	41	13B
0005435462326	5546	42	13E
0005435462281	5546	43	13H
0005435725603	5546	44	13G
0005435462166	5546	45	14B
0005435766332	5546	46	14A
0005434265011	5546	47	14F
0005435462252	5546	48	14G
0005435722060	5546	49	14H
0005435462218	5546	50	15D
0005434264909	5546	51	15B
0005432535794	5546	52	15G
0005435462306	5546	53	15E
0005432140465	5546	54	15H
0005432140462	5546	55	16B
0005434264947	5546	56	16A
0005435766322	5546	57	16D
0005434264864	5546	58	16E
0005435462251	5546	59	16G
0005435462160	5546	60	16H
0005434265063	5546	61	17A
0005434264945	5546	62	17E
0005432140460	5546	63	17G
0005435462169	5546	64	17F
0005435462140	5546	65	17H
0005435766340	5546	66	18B
0005435766311	5546	67	18F
0005435462195	5546	68	18E
0005435766336	5546	69	18G
0005435462168	5546	70	19B
0005435461997	5546	71	19A
0005435766352	5546	72	19D
0005435735143	5546	73	19G
0005435462150	5546	74	19H
0005435462024	5546	75	20B
0005433529288	5546	76	20E
0005432140466	5546	77	20D
0005435766324	5546	78	20G
0005435462149	5546	79	20H
0005434831103	5546	80	21A
0005433527275	5546	81	21D
0005432535807	5546	82	21E
0005435766345	5546	83	21G
0005432535808	5546	84	22A
0005435462199	5546	85	22D
0005435725604	5546	86	22B
0005435766348	5546	87	22E
0005435766327	5546	88	22G
0005435766351	5546	89	22H
0005435766338	5546	90	23A
0005435766356	5546	91	23D
0005435766325	5546	92	23F
0005435462203	5546	93	23G
0005435766321	5546	94	23H
0005435766318	5546	95	24B
0005435462219	5546	96	24A
0005433529287	5546	97	24E
0005434264959	5546	98	24F
0005435462161	5546	99	24G
0005432140464	5546	100	25D
0005435766331	5546	101	25F
0005435766328	5546	102	25E
0005435462200	5546	103	27A
0005434264991	5546	104	27B
0005435461934	5546	105	27E
0005435461996	5546	106	27D
0005435043280	5546	107	27F
0005435725606	5546	108	27H
0005432535814	5546	109	27G
0005435462182	5546	110	28A
0005435462224	5546	111	28B
0005435766330	5546	112	28D
0005435462264	5546	113	28F
0005432140463	5546	114	28H
0005435725607	5546	115	28G
0005434265065	5546	116	29A
0005435766358	5546	117	29B
0005432140461	5546	118	29E
0005435766334	5546	119	29D
0005435766312	5546	120	29G
0005435462269	5546	121	29F
0005435766349	5546	122	29H
0005435766323	5546	123	30A
0005435462028	5546	124	30E
0005432535790	5546	125	30D
0005435043279	5546	126	30G
0005435462204	5546	127	31A
0005435766337	5546	128	30H
0005435722058	5546	129	31B
0005435462291	5546	130	31E
0005435462180	5546	131	31D
0005435766342	5546	132	31F
0005435766316	5546	133	32A
0005435766320	5546	134	31H
0005435766359	5546	135	32D
0005435462272	5546	136	32B
0005435722059	5546	137	32G
0005435766353	5546	138	33A
0005435766339	5546	139	33B
0005435462126	5546	140	33E
0005435766344	5546	141	34A
0005435462261	5546	142	34D
0005433527276	5546	143	34B
0005434264964	5546	144	34E
0005435722061	5546	145	35A
0005435462206	5546	146	34H
0005434264781	5546	147	35B
0005435766350	5546	148	35E
0005435462098	5546	149	35D
0005435723049	5546	150	35G
0005434831109	5546	151	36A
0005434264948	5546	152	35H
0005434264981	5546	153	36B
0005435462181	5546	154	36E
0005434264990	5546	155	36D
0005435462332	5546	156	36F
0005435462282	5546	157	36G
0005435766341	5546	158	37A
0005435461994	5546	159	37B
0005435766335	5546	160	37D
0005433529284	5546	161	37E
0005435766314	5546	162	37H
0005435766326	5546	163	37G
0005434264946	5546	164	38A
0005435462290	5546	165	38E
0005434264835	5546	166	38H
0005435766313	5546	167	39D
0005435462217	5546	168	39F
0005435462513	13500	1	1A
0005435462508	13500	2	1B
0005435735090	13500	3	1H
0005435765827	13500	4	1G
0005435765960	13500	5	2A
0005435765767	13500	6	2C
0005435722039	13500	7	2B
0005435765737	13500	8	2G
0005435765856	13500	9	2H
0005435765809	13500	10	3B
0005432535842	13500	11	3A
0005434265182	13500	12	3F
0005434265200	13500	13	3C
0005435720124	13500	14	3G
0005434265194	13500	15	4A
0005434265193	13500	16	3H
0005432194518	13500	17	4B
0005435766105	13500	18	4G
0005432535843	13500	19	4F
0005435462512	13500	20	4H
0005435765845	13500	21	5B
0005435765780	13500	22	5A
0005435725559	13500	23	5C
0005435765676	13500	24	5G
0005435765506	13500	25	5F
0005435765972	13500	26	5H
0005435765694	13500	27	9G
0005434831160	13500	28	9H
0005435765756	13500	29	11B
0005435765637	13500	30	11E
0005435765792	13500	31	11D
0005435765727	13500	32	11F
0005435765965	13500	33	11H
0005435765844	13500	34	11G
0005435766011	13500	35	12A
0005435765507	13500	36	12B
0005435765903	13500	37	12E
0005434265202	13500	38	12G
0005435765797	13500	39	12F
0005435462526	13500	40	12H
0005434265198	13500	41	13B
0005435720129	13500	42	13A
0005435723027	13500	43	13D
0005435765958	13500	44	13G
0005435462523	13500	45	13F
0005432535845	13500	46	13H
0005435765872	13500	47	14B
0005434265192	13500	48	14E
0005435462499	13500	49	14D
0005435765926	13500	50	14G
0005434265179	13500	51	14H
0005435462503	13500	52	15B
0005435462494	13500	53	15E
0005435766106	13500	54	15D
0005435462495	13500	55	15G
0005435723026	13500	56	15F
0005435462517	13500	57	15H
0005435725578	13500	58	16B
0005435766099	13500	59	16A
0005434265180	13500	60	16D
0005434265184	13500	61	16E
0005435765966	13500	62	16G
0005432194520	13500	63	16F
0005435765914	13500	64	16H
0005435766160	13500	65	17A
0005435765414	13500	66	17D
0005435462520	13500	67	17E
0005435765863	13500	68	17G
0005434265190	13500	69	17F
0005435766128	13500	70	18A
0005435462500	13500	71	18B
0005434265195	13500	72	18F
0005435462507	13500	73	18E
0005435462511	13500	74	18G
0005435766002	13500	75	19A
0005435462510	13500	76	18H
0005434265196	13500	77	19D
0005434265181	13500	78	19G
0005435765876	13500	79	20A
0005435462505	13500	80	20D
0005432535841	13500	81	20B
0005435765859	13500	82	20E
0005435725521	13500	83	21D
0005435765700	13500	84	21B
0005435735093	13500	85	21E
0005435766129	13500	86	21F
0005435462498	13500	87	22A
0005435766159	13500	88	21H
0005434265183	13500	89	21G
0005435766024	13500	90	22B
0005435766009	13500	91	22D
0005435462491	13500	92	22F
0005435765988	13500	93	23A
0005435765785	13500	94	22H
0005432194519	13500	95	23B
0005435765798	13500	96	23E
0005435720127	13500	97	23D
0005435462502	13500	98	23F
0005435766049	13500	99	23H
0005435765673	13500	100	24B
0005435765667	13500	101	24A
0005435765699	13500	102	24E
0005435725573	13500	103	24D
0005435462522	13500	104	24F
0005432535844	13500	105	24H
0005434831161	13500	106	24G
0005435766130	13500	107	25E
0005435765829	13500	108	27A
0005435766004	13500	109	27B
0005435462527	13500	110	27E
0005434265187	13500	111	27D
0005435462528	13500	112	27F
0005435765779	13500	113	27H
0005435765723	13500	114	27G
0005435765837	13500	115	28A
0005435462515	13500	116	28D
0005435765415	13500	117	28B
0005435765649	13500	118	28F
0005435765799	13500	119	28G
0005435735086	13500	120	29B
0005435462509	13500	121	29A
0005435766003	13500	122	29D
0005435462521	13500	123	29F
0005435735097	13500	124	29H
0005435765816	13500	125	30A
0005435462525	13500	126	30E
0005435462516	13500	127	30D
0005435765902	13500	128	30F
0005435765489	13500	129	30H
0005434265191	13500	130	31B
0005435462524	13500	131	31A
0005435462501	13500	132	31E
0005434831162	13500	133	31F
0005435735098	13500	134	31G
0005434265188	13500	135	31H
0005435735099	13500	136	32B
0005434265189	13500	137	32F
0005435723025	13500	138	32G
0005435765838	13500	139	33A
0005434265199	13500	140	32H
0005435765777	13500	141	33D
0005435462497	13500	142	33B
0005435765839	13500	143	33F
0005435766025	13500	144	33H
0005435765746	13500	145	33G
0005435462506	13500	146	34D
0005435765817	13500	147	34B
0005435765490	13500	148	34E
0005435765755	13500	149	34G
0005435765877	13500	150	34F
0005434265186	13500	151	34H
0005435766162	13500	152	35B
0005435462492	13500	153	35A
0005434265201	13500	154	35D
0005435765922	13500	155	35F
0005435462504	13500	156	35G
0005435766161	13500	157	35H
0005435765751	13500	158	36A
0005435462518	13500	159	36G
0005435725558	13500	160	37A
0005434265185	13500	161	37B
0005435766010	13500	162	37E
0005435462496	13500	163	37D
0005435462519	13500	164	37G
0005434265197	13500	165	37F
0005435765828	13500	166	37H
0005435766046	13500	167	38A
0005435462514	13500	168	38D
0005435765665	13500	169	38B
0005435765678	13500	170	38E
0005435765909	13500	171	38G
0005435765961	13500	172	38F
0005435765904	13500	173	38H
0005435462493	13500	174	39E
0005435765551	13500	175	39D
0005434265203	13500	176	39F
0005434513582	18747	1	1A
0005434604862	18747	2	1B
0005434604861	18747	3	2A
0005434514970	18747	4	2B
0005434513583	18747	5	3B
0005434604871	18747	6	4B
0005435904707	18747	7	5A
0005434514971	18747	8	6A
0005434514969	18747	9	6B
0005434602904	19177	1	1A
0005434514941	19177	2	1B
0005434514963	19177	3	2A
0005434602903	19177	4	3A
0005434602902	19177	5	2B
0005434514957	19177	6	3B
0005434602901	19177	7	4A
0005434514940	19177	8	4B
0005434514964	19177	9	5A
0005434514946	19177	10	6A
0005434602900	19177	11	6B
0005435844326	25102	1	1A
0005435846259	25102	2	1D
0005432632680	25102	3	1F
0005435844313	25102	4	2A
0005432649351	25102	5	2D
0005432632682	25102	6	2F
0005432649372	25102	7	3A
0005432632641	25102	8	3D
0005432632652	25102	9	3F
0005435844322	25102	10	4A
0005432632624	25102	11	4D
0005432632666	25102	12	4F
0005435844315	25102	13	4E
0005432649356	25102	14	5A
0005432649359	25102	15	5C
0005435846254	25102	16	5D
0005435846255	25102	17	5F
0005435844324	25102	18	6A
0005432649394	25102	19	6C
0005432632683	25102	20	6D
0005435844314	25102	21	7A
0005432632681	25102	22	7C
0005432649373	25102	23	7D
0005435844319	25102	24	7E
0005435846253	25102	25	7F
0005432649355	25102	26	8A
0005432649342	25102	27	8C
0005432632674	25102	28	8F
0005435844317	25102	29	8E
0005432632698	25102	30	9A
0005432632650	25102	31	9C
0005432632656	25102	32	9D
0005432632696	25102	33	10A
0005432632631	25102	34	10C
0005435846258	25102	35	10D
0005432632649	25102	36	10E
0005432649371	25102	37	10F
0005432632669	25102	38	11C
0005432632648	25102	39	11D
0005432632659	25102	40	11E
0005435844320	25102	41	11F
0005432632668	25102	42	12A
0005435844323	25102	43	12C
0005432632663	25102	44	12D
0005435844318	25102	45	12F
0005432649348	25102	46	13A
0005432649350	25102	47	13D
0005432649368	25102	48	13F
0005432632662	25102	49	14D
0005435846251	25102	50	14E
0005432632665	25102	51	14F
0005435846257	25102	52	15C
0005432632655	25102	53	15D
0005432632634	25102	54	15F
0005432632673	25102	55	16A
0005432632695	25102	56	16C
0005435846261	25102	57	16D
0005435846252	25102	58	16E
0005435844325	25102	59	16F
0005435844316	25102	60	17A
0005432632644	25102	61	17C
0005432649358	25102	62	17D
0005432632670	25102	63	17E
0005432649357	25102	64	18C
0005432632620	25102	65	18D
0005432649393	25102	66	18E
0005435844321	25102	67	18F
0005432632647	25102	68	19A
0005432632633	25102	69	19C
0005432632651	25102	70	19E
0005435846260	25102	71	19F
0005435846256	25102	72	20A
0005432632635	25102	73	20C
0005432632658	25102	74	20D
0005432649347	25102	75	20E
0005432632676	25102	76	20F
0005432295886	1845	1	1C
0005433008306	1845	2	1D
0005433285192	1845	3	1F
0005433008321	1845	4	2A
0005433285133	1845	5	2C
0005433008238	1845	6	2D
0005433810560	1845	7	2F
0005433008155	1845	8	3A
0005433810557	1845	9	3C
0005433008176	1845	10	3F
0005433285023	1845	11	4A
0005433008532	1845	12	4C
0005432295883	1845	13	4D
0005433285019	1845	14	4E
0005433810565	1845	15	5A
0005433008297	1845	16	5D
0005433285203	1845	17	5E
0005433008112	1845	18	5F
0005433008479	1845	19	6A
0005433008381	1845	20	6C
0005433285067	1845	21	6D
0005433810562	1845	22	6E
0005433008380	1845	23	6F
0005433008336	1845	24	7A
0005433285231	1845	25	7C
0005433285145	1845	26	7D
0005433008245	1845	27	7E
0005433008291	1845	28	7F
0005433008299	1845	29	8A
0005433285083	1845	30	8C
0005433284997	1845	31	8D
0005433285122	1845	32	8E
0005433008335	1845	33	8F
0005433285092	1845	34	9A
0005433285132	1845	35	9C
0005433285131	1845	36	9D
0005433285241	1845	37	9F
0005433008246	1845	38	10A
0005433008247	1845	39	10D
0005433285093	1845	40	10E
0005433285216	1845	41	10F
0005433008382	1845	42	11A
0005433008284	1845	43	11C
0005433008373	1845	44	11D
0005433810556	1845	45	11E
0005433008353	1845	46	11F
0005433810558	1845	47	12A
0005433008311	1845	48	12C
0005433008296	1845	49	12D
0005433285068	1845	50	12E
0005433810561	1845	51	12F
0005433284980	1845	52	13A
0005433285070	1845	53	13C
0005433285225	1845	54	13D
0005432295885	1845	55	13E
0005433008374	1845	56	13F
0005433008360	1845	57	14A
0005433285147	1845	58	14C
0005433285085	1845	59	14D
0005433285226	1845	60	14F
0005433008295	1845	61	15A
0005433285156	1845	62	15C
0005433008290	1845	63	15D
0005433285082	1845	64	15E
0005433810563	1845	65	15F
0005433008526	1845	66	16A
0005433285106	1845	67	16D
0005433285230	1845	68	17A
0005433285297	1845	69	17C
0005433008405	1845	70	17D
0005433285020	1845	71	17F
0005433008288	1845	72	18C
0005433008315	1845	73	18D
0005433284998	1845	74	18E
0005433008283	1845	75	18F
0005433810555	1845	76	19A
0005433810564	1845	77	19C
0005433008298	1845	78	19D
0005432295884	1845	79	19E
0005433008289	1845	80	19F
0005433285202	1845	81	20A
0005433810559	1845	82	20C
0005433008461	1845	83	20E
0005433008310	1845	84	20F
0005433285358	22530	1	1A
0005433008695	22530	2	1D
0005433008677	22530	3	1F
0005433285353	22530	4	2A
0005433008687	22530	5	2C
0005433008662	22530	6	2D
0005433285349	22530	7	2F
0005433285346	22530	8	3C
0005433008669	22530	9	3D
0005433285333	22530	10	3F
0005433008673	22530	11	4A
0005433008665	22530	12	4C
0005433008688	22530	13	4F
0005433008667	22530	14	5A
0005433008702	22530	15	5E
0005433008698	22530	16	5F
0005433008663	22530	17	6A
0005433008689	22530	18	6C
0005433008686	22530	19	6D
0005433008701	22530	20	6E
0005433285328	22530	21	6F
0005433810506	22530	22	7A
0005433285356	22530	23	7C
0005433008657	22530	24	7D
0005433008699	22530	25	7E
0005433285331	22530	26	7F
0005433285341	22530	27	8A
0005433008664	22530	28	8C
0005433285354	22530	29	8D
0005433285350	22530	30	8E
0005433285336	22530	31	8F
0005433285357	22530	32	9A
0005433008675	22530	33	9C
0005433008678	22530	34	9D
0005433008690	22530	35	9E
0005433008672	22530	36	10A
0005433285343	22530	37	10C
0005433008685	22530	38	10D
0005433285334	22530	39	11C
0005433008658	22530	40	11D
0005433008697	22530	41	11E
0005433285332	22530	42	11F
0005433008666	22530	43	12A
0005433008684	22530	44	12C
0005433285337	22530	45	12D
0005433285340	22530	46	12E
0005433008680	22530	47	12F
0005433008661	22530	48	13C
0005433285355	22530	49	13D
0005433285330	22530	50	13E
0005433008671	22530	51	14A
0005433008668	22530	52	14C
0005433285327	22530	53	14D
0005433285347	22530	54	14E
0005433008693	22530	55	14F
0005433008659	22530	56	15A
0005433008692	22530	57	15C
0005433285329	22530	58	15E
0005433285348	22530	59	15F
0005433008694	22530	60	16A
0005433008682	22530	61	16C
0005433008670	22530	62	16D
0005433008681	22530	63	16F
0005433285342	22530	64	17A
0005433008696	22530	65	17C
0005433285344	22530	66	17E
0005433285338	22530	67	17F
0005433008674	22530	68	18A
0005433008683	22530	69	18C
0005433008691	22530	70	18D
0005433285335	22530	71	18E
0005433285352	22530	72	18F
0005433285345	22530	73	19A
0005433008676	22530	74	19C
0005433285339	22530	75	19D
0005433285351	22530	76	19E
0005433008679	22530	77	19F
0005433008700	22530	78	20A
0005433008660	22530	79	20D
0005435282248	5593	1	1A
0005434173477	5593	2	1C
0005435282414	5593	3	2C
0005433846847	5593	4	2A
0005433846828	5593	5	1F
0005435282425	5593	6	2F
0005432081524	5593	7	2D
0005433815393	5593	8	3A
0005432081526	5593	9	3D
0005435282298	5593	10	3C
0005433846834	5593	11	4A
0005433846820	5593	12	3F
0005433815394	5593	13	4C
0005433846846	5593	14	4F
0005433846849	5593	15	4D
0005433846813	5593	16	5F
0005433846821	5593	17	5D
0005432081522	5593	18	6A
0005433846848	5593	19	6D
0005433846826	5593	20	6C
0005433846857	5593	21	6B
0005433846841	5593	22	6E
0005435282257	5593	23	7A
0005433846837	5593	24	6F
0005433846803	5593	25	7C
0005433846801	5593	26	7B
0005433846835	5593	27	7E
0005433846827	5593	28	7D
0005433846855	5593	29	7F
0005433846830	5593	30	8B
0005435282430	5593	31	8A
0005433846858	5593	32	8D
0005435282284	5593	33	8C
0005434173485	5593	34	8F
0005433815395	5593	35	8E
0005432081523	5593	36	9B
0005435282242	5593	37	9A
0005433846817	5593	38	9D
0005433846851	5593	39	9C
0005435282392	5593	40	9F
0005433846810	5593	41	9E
0005433846829	5593	42	10A
0005435282312	5593	43	10C
0005435282308	5593	44	10B
0005435282313	5593	45	10E
0005433846804	5593	46	10D
0005435282357	5593	47	11A
0005433846811	5593	48	10F
0005433846853	5593	49	11C
0005435282427	5593	50	11D
0005433846807	5593	51	11F
0005433815390	5593	52	11E
0005435282348	5593	53	12B
0005433846815	5593	54	12C
0005432081519	5593	55	12E
0005433846838	5593	56	12D
0005433846845	5593	57	13B
0005434173476	5593	58	13A
0005433815389	5593	59	12F
0005433846854	5593	60	13C
0005435282424	5593	61	13E
0005433846816	5593	62	13D
0005433846814	5593	63	13F
0005433846832	5593	64	14C
0005432081521	5593	65	14B
0005433846852	5593	66	14D
0005433846800	5593	67	14E
0005433846805	5593	68	15B
0005433846806	5593	69	15A
0005433846825	5593	70	15D
0005433846822	5593	71	15C
0005435282328	5593	72	15E
0005433846831	5593	73	16A
0005433846819	5593	74	15F
0005432081520	5593	75	16C
0005433846836	5593	76	16B
0005435282391	5593	77	16E
0005433846823	5593	78	16D
0005433846842	5593	79	17A
0005433846812	5593	80	16F
0005435282307	5593	81	17B
0005433846839	5593	82	17D
0005435282228	5593	83	17F
0005435282351	5593	84	17E
0005435282255	5593	85	18A
0005435282327	5593	86	18B
0005433846824	5593	87	18E
0005433846802	5593	88	18D
0005433846833	5593	89	18F
0005433846818	5593	90	19C
0005433815392	5593	91	19B
0005435282256	5593	92	19D
0005433846843	5593	93	19E
0005433815391	5593	94	20B
0005432081525	5593	95	20A
0005433846808	5593	96	20D
0005435282413	5593	97	20C
0005435282426	5593	98	20F
0005433846850	5593	99	20E
0005435282258	5593	100	21B
0005433846844	5593	101	21A
0005433846809	5593	102	21C
0005433846856	5593	103	21E
0005433846840	5593	104	21D
0005433846358	13862	1	1C
0005433846171	13862	2	1A
0005435282553	13862	3	1D
0005433846373	13862	4	2C
0005435282562	13862	5	2A
0005433846282	13862	6	1F
0005433846286	13862	7	2D
0005433846398	13862	8	3A
0005433846605	13862	9	2F
0005433846160	13862	10	3D
0005433815363	13862	11	3C
0005433815351	13862	12	4A
0005435282552	13862	13	3F
0005433846339	13862	14	4D
0005433846535	13862	15	4C
0005433846280	13862	16	5A
0005433846520	13862	17	4F
0005433846175	13862	18	5C
0005433846284	13862	19	5F
0005432003708	13862	20	5D
0005435282560	13862	21	6A
0005433846338	13862	22	6C
0005433846591	13862	23	6B
0005433846253	13862	24	6E
0005433846281	13862	25	7A
0005433846427	13862	26	6F
0005433846547	13862	27	7C
0005433846383	13862	28	7B
0005433846321	13862	29	7E
0005435282547	13862	30	7D
0005435282563	13862	31	8A
0005433846384	13862	32	7F
0005435282558	13862	33	8B
0005435282557	13862	34	8D
0005433846327	13862	35	8F
0005433846378	13862	36	8E
0005432003706	13862	37	9A
0005433815340	13862	38	9D
0005434173529	13862	39	9C
0005433846070	13862	40	9B
0005433846456	13862	41	9E
0005433846399	13862	42	10A
0005433846294	13862	43	9F
0005433846390	13862	44	10C
0005435282556	13862	45	10B
0005433846275	13862	46	10E
0005433846546	13862	47	10D
0005433846266	13862	48	10F
0005432003707	13862	49	11B
0005433815341	13862	50	11D
0005433846389	13862	51	11C
0005435282550	13862	52	11F
0005434173526	13862	53	12B
0005435282545	13862	54	12A
0005433846274	13862	55	12D
0005433846453	13862	56	12C
0005433846519	13862	57	12E
0005433846224	13862	58	13A
0005433845970	13862	59	12F
0005433815362	13862	60	13D
0005433846174	13862	61	14A
0005433846478	13862	62	13F
0005433815366	13862	63	13E
0005433846479	13862	64	14B
0005433846249	13862	65	14E
0005434173530	13862	66	14D
0005434173528	13862	67	15B
0005435282549	13862	68	15A
0005433846330	13862	69	15C
0005433846276	13862	70	15E
0005435282548	13862	71	15D
0005433846416	13862	72	16A
0005435282561	13862	73	15F
0005433846169	13862	74	16C
0005434173527	13862	75	16B
0005433846379	13862	76	16D
0005435282544	13862	77	16F
0005433846454	13862	78	17B
0005435282559	13862	79	17D
0005433846636	13862	80	17C
0005433846388	13862	81	17F
0005433846289	13862	82	17E
0005433846254	13862	83	18A
0005433846366	13862	84	18B
0005433846374	13862	85	18E
0005433846455	13862	86	18D
0005433846434	13862	87	19A
0005433846248	13862	88	18F
0005433846221	13862	89	19C
0005435282546	13862	90	19B
0005433846252	13862	91	19E
0005435282554	13862	92	19D
0005433846211	13862	93	19F
0005433846355	13862	94	20C
0005433846212	13862	95	20B
0005433846548	13862	96	20A
0005433846283	13862	97	20D
0005433846426	13862	98	20E
0005433846291	13862	99	21B
0005433846259	13862	100	21A
0005435282555	13862	101	21D
0005433846290	13862	102	21E
0005435282551	13862	103	21F
0005434620638	7813	1	1B
0005434620623	7813	2	1D
0005435332267	7813	3	1C
0005434620627	7813	4	2A
0005435332239	7813	5	2C
0005434620628	7813	6	2D
0005432112520	7813	7	3A
0005435332319	7813	8	3B
0005434620637	7813	9	3D
0005434620641	7813	10	4A
0005435332266	7813	11	4D
0005435332304	7813	12	5C
0005434620634	7813	13	5D
0005434620635	7813	14	6A
0005434620626	7813	15	6C
0005434620630	7813	16	7A
0005435332262	7813	17	7B
0005435332247	7813	18	7C
0005435332303	7813	19	18A
0005434620640	7813	20	18C
0005435332263	7813	21	18D
0005435332246	7813	22	19A
0005434620631	7813	23	19B
0005434620639	7813	24	19C
0005434620632	7813	25	20C
0005435332318	7813	26	20D
0005434620642	7813	27	21A
0005434620636	7813	28	21C
0005434620624	7813	29	21D
0005434620629	7813	30	22A
0005434620625	7813	31	22B
0005434620622	7813	32	22C
0005434620633	7813	33	22D
0005435332238	7813	34	23A
0005434620499	32960	1	1D
0005435332352	32960	2	2A
0005435332355	32960	3	2D
0005434620446	32960	4	3A
0005434620431	32960	5	3D
0005435332353	32960	6	4A
0005435332354	32960	7	4B
0005434620509	32960	8	4C
0005435332358	32960	9	5A
0005435332350	32960	10	5B
0005434620423	32960	11	5C
0005434620422	32960	12	6B
0005434620476	32960	13	6D
0005434620459	32960	14	7C
0005434620428	32960	15	18A
0005434620390	32960	16	18B
0005434620437	32960	17	18C
0005435332349	32960	18	18D
0005434620432	32960	19	19A
0005434620439	32960	20	19B
0005435332351	32960	21	19C
0005434620516	32960	22	20B
0005435332348	32960	23	20C
0005434620447	32960	24	21A
0005435332356	32960	25	22A
0005435332357	32960	26	22C
0005434620473	32960	27	23A
0005434994038	4268	1	1A
0005435785425	4268	2	1C
0005432190636	4268	3	1D
0005434994043	4268	4	2D
0005435785435	4268	5	2F
0005435785410	4268	6	3A
0005435937341	4268	7	3D
0005435785429	4268	8	4A
0005435785423	4268	9	4C
0005432190638	4268	10	4E
0005435785415	4268	11	5E
0005435785418	4268	12	6A
0005435785403	4268	13	6C
0005435785414	4268	14	6D
0005432190637	4268	15	6E
0005435785428	4268	16	6F
0005435918623	4268	17	7A
0005435785406	4268	18	7C
0005435785424	4268	19	7D
0005435937336	4268	20	7E
0005435785431	4268	21	8A
0005435937335	4268	22	8E
0005435918636	4268	23	9A
0005435785430	4268	24	9C
0005432190635	4268	25	9D
0005435785432	4268	26	9E
0005435785421	4268	27	10C
0005434994042	4268	28	10D
0005435937334	4268	29	11C
0005435785407	4268	30	11D
0005435785417	4268	31	11F
0005435785416	4268	32	12A
0005435785409	4268	33	12C
0005435785402	4268	34	12E
0005434994044	4268	35	12F
0005434994037	4268	36	13C
0005434994039	4268	37	13D
0005435937339	4268	38	13E
0005435785420	4268	39	13F
0005435785427	4268	40	14A
0005435937340	4268	41	14E
0005435785405	4268	42	14F
0005435785411	4268	43	15A
0005435785412	4268	44	15E
0005435785408	4268	45	15F
0005434994041	4268	46	16A
0005435785426	4268	47	16C
0005435937338	4268	48	16D
0005435918633	4268	49	16F
0005435785422	4268	50	17D
0005435785413	4268	51	17E
0005435785434	4268	52	18A
0005434994040	4268	53	18D
0005435787357	4268	54	18E
0005435785419	4268	55	18F
0005435918637	4268	56	19A
0005435785433	4268	57	19C
0005435787359	4268	58	19E
0005435787358	4268	59	19F
0005435918611	4268	60	20A
0005435785436	4268	61	20C
0005435785404	4268	62	20F
0005435785051	27295	1	1C
0005435784970	27295	2	1D
0005435785050	27295	3	1F
0005435787328	27295	4	2A
0005435785056	27295	5	2C
0005435787346	27295	6	2D
0005435784986	27295	7	3A
0005435784952	27295	8	3C
0005435918667	27295	9	3F
0005434993937	27295	10	4D
0005434993938	27295	11	5D
0005435785171	27295	12	5F
0005435784997	27295	13	6C
0005435785052	27295	14	6F
0005435784944	27295	15	7A
0005435785101	27295	16	7C
0005435785129	27295	17	7E
0005435785172	27295	18	8A
0005435785114	27295	19	8C
0005434993935	27295	20	9C
0005435785127	27295	21	9D
0005434993927	27295	22	9E
0005434993956	27295	23	9F
0005435785092	27295	24	10A
0005435784943	27295	25	10F
0005435785049	27295	26	11D
0005435785135	27295	27	11E
0005434993955	27295	28	11F
0005435918662	27295	29	12C
0005435785046	27295	30	12D
0005435785047	27295	31	13C
0005435785112	27295	32	13D
0005435785089	27295	33	13F
0005435785170	27295	34	14A
0005432195696	27295	35	14E
0005435784984	27295	36	15C
0005435918666	27295	37	15D
0005435785057	27295	38	16A
0005435785062	27295	39	16C
0005434993939	27295	40	16D
0005435784945	27295	41	16E
0005435937390	27295	42	16F
0005435785169	27295	43	17C
0005434993923	27295	44	17D
0005435785035	27295	45	17F
0005435784951	27295	46	18A
0005435918665	27295	47	18D
0005435785128	27295	48	18F
0005435918664	27295	49	19A
0005435785055	27295	50	19C
0005435918663	27295	51	19D
0005435785045	27295	52	19E
0005435785034	27295	53	19F
0005434993921	27295	54	20C
0005435785091	27295	55	20E
0005435785173	27295	56	20F
0005432146202	19848	1	3D
0005432146201	19848	2	23A
0005432170397	4706	1	1B
0005432459958	4706	2	1A
0005433726108	4706	3	1C
0005432186880	4706	4	1F
0005432186875	4706	5	2A
0005434081938	4706	6	2B
0005432459936	4706	7	2C
0005434081948	4706	8	2G
0005433726110	4706	9	3A
0005432459941	4706	10	3B
0005432571329	4706	11	3F
0005432571327	4706	12	3G
0005434081933	4706	13	4B
0005432186878	4706	14	4F
0005432170398	4706	15	4C
0005432459948	4706	16	4G
0005432567719	4706	17	5A
0005434081930	4706	18	4H
0005432571328	4706	19	5B
0005432459943	4706	20	5F
0005434081944	4706	21	5G
0005432170403	4706	22	9A
0005432459956	4706	23	5H
0005432567756	4706	24	9B
0005432459934	4706	25	9H
0005432567737	4706	26	9G
0005432567772	4706	27	11A
0005434081940	4706	28	11B
0005432567739	4706	29	11E
0005432567742	4706	30	11D
0005432567769	4706	31	11F
0005432459955	4706	32	11G
0005432567718	4706	33	12A
0005434081934	4706	34	11H
0005432459945	4706	35	12D
0005432459949	4706	36	12B
0005432567746	4706	37	12E
0005432567732	4706	38	12G
0005432567734	4706	39	12H
0005432567754	4706	40	13A
0005432567726	4706	41	13D
0005432459938	4706	42	14A
0005432567728	4706	43	14B
0005432567749	4706	44	14D
0005434081937	4706	45	14F
0005432459962	4706	46	14E
0005432567757	4706	47	14H
0005432567745	4706	48	14G
0005432567714	4706	49	15D
0005433726109	4706	50	15B
0005432459932	4706	51	15A
0005432459924	4706	52	15F
0005432567720	4706	53	15E
0005432567760	4706	54	15G
0005433452743	4706	55	16B
0005432567753	4706	56	15H
0005432567730	4706	57	16D
0005432459953	4706	58	16E
0005432459929	4706	59	16F
0005432567771	4706	60	16H
0005432459933	4706	61	16G
0005432567733	4706	62	17A
0005432567765	4706	63	17D
0005432459942	4706	64	17F
0005432567740	4706	65	17G
0005432459966	4706	66	18A
0005432459970	4706	67	18D
0005432567741	4706	68	18F
0005432567764	4706	69	18E
0005432170401	4706	70	18G
0005432567715	4706	71	18H
0005432459965	4706	72	19B
0005432567761	4706	73	19A
0005432567736	4706	74	19D
0005432567723	4706	75	19F
0005432459947	4706	76	19E
0005432567747	4706	77	19G
0005432567766	4706	78	20A
0005432567727	4706	79	20B
0005432567763	4706	80	20E
0005434081943	4706	81	20D
0005432186879	4706	82	20G
0005432186876	4706	83	20H
0005434081935	4706	84	21F
0005432459954	4706	85	21E
0005432459940	4706	86	21H
0005432567716	4706	87	21G
0005432459921	4706	88	22B
0005432459951	4706	89	22D
0005432567748	4706	90	22E
0005432459967	4706	91	22G
0005432459928	4706	92	22H
0005432459946	4706	93	23B
0005434081942	4706	94	23D
0005432459925	4706	95	23F
0005434081931	4706	96	23E
0005432459944	4706	97	23H
0005432567755	4706	98	24A
0005432459918	4706	99	24E
0005432567752	4706	100	24F
0005432459957	4706	101	24H
0005432459963	4706	102	25D
0005432459969	4706	103	25F
0005432567767	4706	104	25E
0005432170402	4706	105	27A
0005432567724	4706	106	27B
0005432459952	4706	107	27D
0005434081952	4706	108	27F
0005432459927	4706	109	27E
0005432459919	4706	110	27G
0005432567738	4706	111	28B
0005432459926	4706	112	28D
0005432170399	4706	113	28H
0005432567725	4706	114	28G
0005432567759	4706	115	29A
0005432567758	4706	116	29B
0005433451622	4706	117	29E
0005432459960	4706	118	29D
0005432567729	4706	119	29F
0005432459922	4706	120	29H
0005432170400	4706	121	30A
0005434081929	4706	122	30B
0005432459959	4706	123	30F
0005432567744	4706	124	30E
0005432459939	4706	125	30G
0005432459968	4706	126	31A
0005433452744	4706	127	30H
0005432459920	4706	128	31F
0005433451623	4706	129	31E
0005432567775	4706	130	31G
0005432567735	4706	131	32A
0005432567721	4706	132	31H
0005432459923	4706	133	32B
0005434081947	4706	134	32E
0005434081949	4706	135	32F
0005432459935	4706	136	32H
0005432459937	4706	137	33B
0005432571330	4706	138	33E
0005434081939	4706	139	33D
0005432567768	4706	140	33F
0005432567762	4706	141	33H
0005432567774	4706	142	34B
0005432459961	4706	143	34A
0005434081945	4706	144	34D
0005432567743	4706	145	34E
0005432567773	4706	146	34F
0005432567717	4706	147	35B
0005432459950	4706	148	35A
0005434081951	4706	149	35F
0005434081936	4706	150	35E
0005432567770	4706	151	35H
0005432459971	4706	152	36B
0005432567731	4706	153	36A
0005434081953	4706	154	36D
0005432186877	4706	155	36F
0005432459964	4706	156	36E
0005432567751	4706	157	36G
0005434081941	4706	158	37A
0005432567750	4706	159	37B
0005432567776	4706	160	37D
0005432459930	4706	161	37G
0005434081932	4706	162	37F
0005432459931	4706	163	37E
0005433726107	4706	164	37H
0005434081950	4706	165	38A
0005434081946	4706	166	38H
0005432567722	4706	167	39F
0005432459540	30516	1	1A
0005432567399	30516	2	1C
0005434081797	30516	3	1B
0005432459508	30516	4	1F
0005434081692	30516	5	1H
0005432459582	30516	6	1G
0005432459554	30516	7	2F
0005432567376	30516	8	2G
0005432459800	30516	9	3A
0005432567341	30516	10	2H
0005432459757	30516	11	3C
0005432567195	30516	12	3B
0005432567439	30516	13	3F
0005432459646	30516	14	3G
0005434081690	30516	15	4A
0005432567279	30516	16	3H
0005433452717	30516	17	4B
0005434081727	30516	18	4G
0005434081710	30516	19	4F
0005432459662	30516	20	4H
0005432567182	30516	21	5B
0005432567475	30516	22	5A
0005432567251	30516	23	5F
0005432459692	30516	24	5H
0005432567296	30516	25	5G
0005432567361	30516	26	9A
0005432567062	30516	27	9H
0005433452718	30516	28	9G
0005432459475	30516	29	11D
0005432567068	30516	30	11B
0005432459406	30516	31	11A
0005432161156	30516	32	11F
0005433452722	30516	33	11H
0005432567292	30516	34	11G
0005432213614	30516	35	12A
0005433454865	30516	36	12D
0005434081789	30516	37	12B
0005432459632	30516	38	12E
0005432567515	30516	39	12F
0005432567135	30516	40	12H
0005432567380	30516	41	12G
0005432567181	30516	42	13B
0005434081717	30516	43	13A
0005432567451	30516	44	13D
0005432459479	30516	45	13E
0005432567520	30516	46	13H
0005432459521	30516	47	14B
0005432567408	30516	48	14A
0005432459631	30516	49	14D
0005434081606	30516	50	14E
0005432567127	30516	51	14G
0005432459463	30516	52	14H
0005432567455	30516	53	15A
0005432459664	30516	54	15E
0005432567200	30516	55	15F
0005432459659	30516	56	15H
0005434081729	30516	57	16A
0005432567398	30516	58	16D
0005432567274	30516	59	16E
0005432459345	30516	60	16G
0005432567065	30516	61	16F
0005432567227	30516	62	16H
0005432567365	30516	63	17A
0005432567278	30516	64	17D
0005432459429	30516	65	17B
0005432459563	30516	66	17F
0005432459627	30516	67	17E
0005432459599	30516	68	18A
0005432459630	30516	69	17H
0005432567456	30516	70	18B
0005434081788	30516	71	18D
0005432567375	30516	72	18F
0005432459530	30516	73	18E
0005432161155	30516	74	18G
0005432459801	30516	75	19A
0005432567136	30516	76	18H
0005432567521	30516	77	19B
0005432567063	30516	78	19E
0005432459464	30516	79	19D
0005432459539	30516	80	19F
0005432567291	30516	81	20A
0005432567294	30516	82	20B
0005432459562	30516	83	20E
0005432459581	30516	84	20D
0005432213613	30516	85	20F
0005434081711	30516	86	20H
0005434081693	30516	87	20G
0005432459370	30516	88	21A
0005432567550	30516	89	21B
0005432567090	30516	90	21E
0005432567400	30516	91	21D
0005432567290	30516	92	21H
0005432459663	30516	93	22D
0005432459558	30516	94	22F
0005433454861	30516	95	22G
0005432459522	30516	96	23A
0005432567360	30516	97	22H
0005432567450	30516	98	23B
0005434081784	30516	99	23E
0005432459177	30516	100	23D
0005434081607	30516	101	23F
0005432567480	30516	102	23G
0005432567114	30516	103	24A
0005432459468	30516	104	23H
0005432459565	30516	105	24B
0005434081714	30516	106	24E
0005434081730	30516	107	24F
0005432571303	30516	108	24G
0005432567066	30516	109	24H
0005432459509	30516	110	25F
0005432567211	30516	111	25E
0005432459529	30516	112	27B
0005432567280	30516	113	27E
0005432567340	30516	114	27D
0005432567551	30516	115	27F
0005432459600	30516	116	28A
0005434081637	30516	117	27H
0005432567582	30516	118	28B
0005432459753	30516	119	28E
0005432567383	30516	120	28D
0005432567146	30516	121	28F
0005432161157	30516	122	28G
0005432459511	30516	123	29B
0005432459536	30516	124	29F
0005432459593	30516	125	29E
0005432567210	30516	126	29G
0005434081702	30516	127	29H
0005432459474	30516	128	30A
0005434081726	30516	129	30D
0005432571304	30516	130	30B
0005432567559	30516	131	30G
0005432459505	30516	132	30H
0005432459595	30516	133	31A
0005433454866	30516	134	31F
0005432459510	30516	135	31E
0005432567191	30516	136	31G
0005434081676	30516	137	32A
0005434081677	30516	138	31H
0005434081778	30516	139	32B
0005433454862	30516	140	32E
0005432567112	30516	141	32D
0005432459535	30516	142	32F
0005432567221	30516	143	32G
0005432567199	30516	144	32H
0005432459526	30516	145	33B
0005432567287	30516	146	33E
0005434081735	30516	147	33D
0005432567212	30516	148	33G
0005432567415	30516	149	33F
0005432567192	30516	150	33H
0005434081790	30516	151	34D
0005432567288	30516	152	34B
0005433454860	30516	153	34E
0005432567377	30516	154	34G
0005434081605	30516	155	34F
0005432459693	30516	156	34H
0005432567183	30516	157	35B
0005432459695	30516	158	35A
0005432213612	30516	159	35D
0005434081783	30516	160	35F
0005432567067	30516	161	35E
0005432459694	30516	162	36A
0005434081748	30516	163	35H
0005432459601	30516	164	36B
0005432567442	30516	165	36D
0005432567275	30516	166	36H
0005432213611	30516	167	36G
0005432567522	30516	168	37A
0005432459564	30516	169	37E
0005432567440	30516	170	37D
0005432459502	30516	171	37F
0005432459197	30516	172	37H
0005432567508	30516	173	38F
0005432459724	30516	174	38E
0005434081715	30516	175	38D
0005432459336	30516	176	38G
0005432567108	30516	177	38H
0005434081742	30516	178	39D
0005432567205	30516	179	39E
0005435722058	13590	1	2A
0005435722061	13590	2	5A
0005435722060	13590	3	5B
0005435722059	13590	4	6B
0005435720128	21173	1	1B
0005435722043	21173	2	2A
0005432295885	22764	1	2B
0005432295886	22764	2	2C
0005432295883	22764	3	21C
0005432295884	22764	4	23B
0005435097211	11074	1	1C
0005433343398	11074	2	1A
0005433343373	11074	3	1F
0005435380263	11074	4	2C
0005433343409	11074	5	2A
0005433343344	11074	6	2D
0005433343328	11074	7	3A
0005433343376	11074	8	2F
0005435508231	11074	9	3C
0005433343366	11074	10	3D
0005433343325	11074	11	3F
0005433343351	11074	12	4A
0005435508226	11074	13	4B
0005433343385	11074	14	4D
0005433343326	11074	15	4C
0005433343381	11074	16	4E
0005435508245	11074	17	5A
0005433343355	11074	18	5C
0005433343377	11074	19	5B
0005433343404	11074	20	5D
0005433343321	11074	21	5E
0005433343342	11074	22	6A
0005433343413	11074	23	6C
0005435380260	11074	24	6B
0005433343395	11074	25	6D
0005433343374	11074	26	6F
0005433343335	11074	27	6E
0005433343369	11074	28	7A
0005433343320	11074	29	7B
0005433343363	11074	30	7C
0005433343388	11074	31	7D
0005433343358	11074	32	7E
0005433343356	11074	33	8A
0005433343330	11074	34	7F
0005433343329	11074	35	8B
0005433343407	11074	36	8C
0005433343384	11074	37	8E
0005433343396	11074	38	8D
0005435508267	11074	39	9A
0005433343352	11074	40	8F
0005433343337	11074	41	9B
0005433343347	11074	42	9C
0005433343323	11074	43	9D
0005433343317	11074	44	9E
0005433343391	11074	45	10B
0005433343410	11074	46	9F
0005433343380	11074	47	10C
0005433343375	11074	48	10E
0005433343353	11074	49	10D
0005433343345	11074	50	11A
0005433343399	11074	51	11B
0005435508233	11074	52	11D
0005433343318	11074	53	11C
0005435380267	11074	54	11E
0005433343367	11074	55	11F
0005435097212	11074	56	12B
0005433343370	11074	57	12A
0005433343362	11074	58	12C
0005433343378	11074	59	12E
0005433343400	11074	60	12D
0005433343333	11074	61	12F
0005433343364	11074	62	13A
0005433343338	11074	63	13B
0005435508251	11074	64	13E
0005433343402	11074	65	13D
0005433343357	11074	66	13F
0005435508232	11074	67	14A
0005433343343	11074	68	14B
0005433343394	11074	69	14D
0005433343393	11074	70	14C
0005433343327	11074	71	14E
0005433343365	11074	72	15A
0005433343411	11074	73	14F
0005433343406	11074	74	15B
0005433343397	11074	75	15C
0005433343316	11074	76	15D
0005433343386	11074	77	15F
0005433343334	11074	78	15E
0005433343360	11074	79	16A
0005433343319	11074	80	16B
0005433343324	11074	81	16C
0005433343315	11074	82	16D
0005433343331	11074	83	16E
0005433343361	11074	84	17A
0005435508244	11074	85	16F
0005433343371	11074	86	17B
0005433343405	11074	87	17C
0005433343390	11074	88	17D
0005433343336	11074	89	18A
0005435097209	11074	90	17F
0005433343383	11074	91	18B
0005435097210	11074	92	18D
0005433343403	11074	93	18C
0005433343341	11074	94	18E
0005435097208	11074	95	18F
0005433343348	11074	96	19A
0005433343379	11074	97	19B
0005433343314	11074	98	19C
0005433343339	11074	99	19F
0005433343412	11074	100	19E
0005433343382	11074	101	20A
0005435380266	11074	102	20D
0005433343401	11074	103	20C
0005433343346	11074	104	20E
0005433343392	11074	105	20F
0005433343408	11074	106	21A
0005433343368	11074	107	21C
0005433343387	11074	108	21B
0005435097213	11074	109	21D
0005433343389	11074	110	21E
0005435508275	11074	111	22A
0005433343359	11074	112	21F
0005433343372	11074	113	22B
0005435380254	11074	114	22C
0005433343340	11074	115	22E
0005433343349	11074	116	22F
0005433343322	11074	117	23B
0005433343332	11074	118	23D
0005433343354	11074	119	23F
0005433343350	11074	120	23E
0005433342183	17095	1	1C
0005432293214	17095	2	1F
0005435545753	17095	3	1D
0005433342122	17095	4	2A
0005433342303	17095	5	2D
0005433342347	17095	6	2C
0005433342490	17095	7	2F
0005433342447	17095	8	3C
0005435545766	17095	9	3A
0005435097163	17095	10	3D
0005435545752	17095	11	3F
0005433342346	17095	12	4A
0005435545765	17095	13	4B
0005433342635	17095	14	4D
0005432293212	17095	15	4C
0005433342580	17095	16	4E
0005435545759	17095	17	4F
0005433342694	17095	18	5B
0005435097176	17095	19	5A
0005433342288	17095	20	5C
0005433342191	17095	21	5D
0005433342263	17095	22	5F
0005433342466	17095	23	6B
0005435097177	17095	24	6A
0005433342059	17095	25	6C
0005433342562	17095	26	6E
0005433342362	17095	27	6F
0005433342671	17095	28	7B
0005433342231	17095	29	7A
0005435545764	17095	30	7C
0005433342264	17095	31	7E
0005433342626	17095	32	7D
0005435380308	17095	33	8A
0005433342450	17095	34	7F
0005433342392	17095	35	8B
0005433342125	17095	36	8C
0005433342380	17095	37	8D
0005435380307	17095	38	8E
0005433342477	17095	39	9A
0005433342108	17095	40	8F
0005435545767	17095	41	9B
0005433342419	17095	42	9C
0005433342262	17095	43	9E
0005433342478	17095	44	9D
0005433342701	17095	45	9F
0005435545762	17095	46	10D
0005433342354	17095	47	10C
0005433342625	17095	48	11A
0005433342302	17095	49	10E
0005435097100	17095	50	11C
0005433342212	17095	51	11B
0005433342794	17095	52	11E
0005435545757	17095	53	11D
0005435545755	17095	54	11F
0005435097145	17095	55	12A
0005435545758	17095	56	12B
0005433341898	17095	57	12C
0005435097137	17095	58	12E
0005433342211	17095	59	12D
0005433342198	17095	60	12F
0005433342483	17095	61	13A
0005433342484	17095	62	13C
0005435380310	17095	63	13B
0005433342596	17095	64	13D
0005435545754	17095	65	13E
0005435097099	17095	66	14A
0005433342581	17095	67	13F
0005433342636	17095	68	14C
0005433342312	17095	69	14B
0005433342491	17095	70	14D
0005433342558	17095	71	14E
0005435097162	17095	72	14F
0005433342659	17095	73	15B
0005433342013	17095	74	15A
0005433342157	17095	75	15C
0005433342476	17095	76	15D
0005435380305	17095	77	15F
0005433341870	17095	78	15E
0005433342382	17095	79	16B
0005433342977	17095	80	16A
0005433342712	17095	81	16C
0005433342420	17095	82	16D
0005433342421	17095	83	16F
0005433342287	17095	84	16E
0005433342582	17095	85	17A
0005433342451	17095	86	17B
0005433342669	17095	87	17D
0005433342043	17095	88	17C
0005433342482	17095	89	17E
0005435097188	17095	90	18A
0005435380306	17095	91	17F
0005433342617	17095	92	18D
0005433342627	17095	93	18C
0005435380309	17095	94	18E
0005433342403	17095	95	18F
0005433342014	17095	96	19B
0005435097144	17095	97	19A
0005435097131	17095	98	19D
0005433342167	17095	99	19C
0005433342290	17095	100	19E
0005433342037	17095	101	19F
0005433342410	17095	102	20A
0005432293213	17095	103	20C
0005433342342	17095	104	20B
0005433341970	17095	105	20D
0005433342120	17095	106	20E
0005433342616	17095	107	21B
0005433342519	17095	108	21C
0005433342121	17095	109	21D
0005435545761	17095	110	21E
0005433342111	17095	111	21F
0005433342363	17095	112	22A
0005433342190	17095	113	22C
0005433342448	17095	114	22B
0005433342660	17095	115	22D
0005435545763	17095	116	22F
0005435545756	17095	117	22E
0005433342615	17095	118	23A
0005433342510	17095	119	23B
0005435097130	17095	120	23C
0005435545760	17095	121	23D
0005433342511	17095	122	23F
0005432919751	9062	1	1C
0005434158965	9062	2	1F
0005433507225	9062	3	2A
0005432919750	9062	4	2C
0005434158962	9062	5	2D
0005433507217	9062	6	3D
0005432919676	9062	7	4A
0005432919701	9062	8	5D
0005433507232	9062	9	6D
0005434158961	9062	10	6E
0005433507221	9062	11	6F
0005432919736	9062	12	7C
0005432919709	9062	13	7E
0005432919675	9062	14	8C
0005433507233	9062	15	8E
0005433507215	9062	16	9C
0005432919702	9062	17	9E
0005434158952	9062	18	10D
0005433481181	9062	19	10E
0005433507228	9062	20	11A
0005433481185	9062	21	11C
0005433507224	9062	22	11E
0005433481184	9062	23	11F
0005433507231	9062	24	12A
0005433481182	9062	25	12C
0005433507214	9062	26	12D
0005433507222	9062	27	12E
0005433507218	9062	28	12F
0005432919725	9062	29	13A
0005433481183	9062	30	13E
0005433507212	9062	31	14E
0005433507220	9062	32	15E
0005433507213	9062	33	15F
0005434158964	9062	34	16C
0005433507219	9062	35	16E
0005433481180	9062	36	17A
0005433481179	9062	37	17C
0005433507229	9062	38	17E
0005433507216	9062	39	17F
0005432919734	9062	40	18C
0005433507223	9062	41	18D
0005433507227	9062	42	18E
0005432919737	9062	43	19C
0005433507230	9062	44	19D
0005432919780	9062	45	19E
0005432919677	9062	46	20A
0005433507226	9062	47	20C
0005433507060	20477	1	1C
0005434158980	20477	2	1D
0005432919917	20477	3	1F
0005432919915	20477	4	2A
0005433507156	20477	5	2C
0005434158981	20477	6	2F
0005433507049	20477	7	3A
0005432919912	20477	8	4A
0005432919914	20477	9	4C
0005433507048	20477	10	4D
0005432919930	20477	11	4F
0005434158982	20477	12	5E
0005433506965	20477	13	5F
0005433507024	20477	14	6C
0005433507098	20477	15	6E
0005433507105	20477	16	7A
0005433507010	20477	17	7D
0005432919925	20477	18	8D
0005432919924	20477	19	8F
0005433507144	20477	20	9C
0005433507047	20477	21	9D
0005433507107	20477	22	9E
0005433507059	20477	23	10C
0005433507061	20477	24	11C
0005433507073	20477	25	11D
0005432919909	20477	26	11E
0005433507143	20477	27	11F
0005432919927	20477	28	12A
0005434158978	20477	29	12C
0005433507091	20477	30	12D
0005433507032	20477	31	13E
0005432919916	20477	32	14A
0005432919928	20477	33	14D
0005433507090	20477	34	14E
0005432919913	20477	35	14F
0005432919921	20477	36	15A
0005432919919	20477	37	15C
0005433481117	20477	38	15D
0005432919920	20477	39	16A
0005432919922	20477	40	16C
0005434158979	20477	41	16F
0005433507046	20477	42	17D
0005433507075	20477	43	17E
0005433507104	20477	44	17F
0005432919926	20477	45	18A
0005432919929	20477	46	18C
0005432919910	20477	47	18D
0005432919918	20477	48	19A
0005433507076	20477	49	19C
0005433481116	20477	50	19D
0005434158983	20477	51	19F
0005432919923	20477	52	20C
0005432919911	20477	53	20D
0005433507033	20477	54	20E
0005432394107	10154	1	1A
0005432394109	10154	2	1B
0005435178986	10154	3	2A
0005432396245	10154	4	2B
0005432396248	10154	5	3A
0005432396247	10154	6	4B
0005432394108	10154	7	5A
0005432396246	10154	8	5B
0005432396211	18310	1	1A
0005435179696	18310	2	2A
0005432396203	18310	3	2B
0005432400108	18310	4	3A
0005432396202	18310	5	3B
0005435179395	18310	6	4A
0005435179396	18310	7	5A
0005432400092	18310	8	6A
0005435125918	10957	1	1A
0005435556677	10957	2	1C
0005435126161	10957	3	1D
0005435126230	10957	4	1F
0005435125920	10957	5	2A
0005435126057	10957	6	2C
0005435554136	10957	7	2D
0005434411785	10957	8	2F
0005435126148	10957	9	3A
0005435556655	10957	10	3C
0005435125993	10957	11	3F
0005435126019	10957	12	4A
0005435626040	10957	13	4C
0005435126137	10957	14	4D
0005435126322	10957	15	4E
0005435126068	10957	16	4F
0005434411787	10957	17	5A
0005435126229	10957	18	5C
0005434411789	10957	19	5D
0005435626042	10957	20	5E
0005435554137	10957	21	5F
0005435125905	10957	22	6C
0005435126138	10957	23	6E
0005435554175	10957	24	6F
0005435625954	10957	25	7A
0005435126146	10957	26	7C
0005435126147	10957	27	7D
0005434928306	10957	28	7E
0005435126070	10957	29	7F
0005435126160	10957	30	8A
0005435125851	10957	31	8C
0005435125906	10957	32	8D
0005435126204	10957	33	8E
0005435556678	10957	34	8F
0005435626039	10957	35	9A
0005435125974	10957	36	9C
0005435126105	10957	37	9D
0005435125898	10957	38	9E
0005435125969	10957	39	9F
0005435556679	10957	40	10A
0005435125852	10957	41	10C
0005435554158	10957	42	10D
0005435626004	10957	43	10F
0005435126205	10957	44	11C
0005435126058	10957	45	11D
0005435126055	10957	46	11E
0005434928305	10957	47	11F
0005435126040	10957	48	12A
0005435126182	10957	49	12C
0005435554145	10957	50	12D
0005435126159	10957	51	12E
0005435125968	10957	52	12F
0005435554148	10957	53	13A
0005435554147	10957	54	13C
0005435125999	10957	55	13D
0005435556673	10957	56	13E
0005435125919	10957	57	13F
0005435126206	10957	58	14C
0005435126066	10957	59	14D
0005434411786	10957	60	14E
0005435556676	10957	61	14F
0005435556656	10957	62	15A
0005435125998	10957	63	15D
0005435125979	10957	64	15E
0005435125962	10957	65	15F
0005435126067	10957	66	16A
0005435126187	10957	67	16E
0005435126181	10957	68	16F
0005435554176	10957	69	17D
0005435556657	10957	70	17F
0005435126098	10957	71	18A
0005435126180	10957	72	18D
0005435126173	10957	73	18F
0005435626041	10957	74	19A
0005435126104	10957	75	19C
0005434411788	10957	76	19D
0005435556654	10957	77	19E
0005435126253	10957	78	19F
0005435556675	10957	79	20A
0005435126207	10957	80	20C
0005435125997	10957	81	20D
0005435126028	10957	82	20E
0005435626026	10957	83	20F
0005435126460	14740	1	1A
0005435126463	14740	2	1C
0005435126468	14740	3	1D
0005435126474	14740	4	1F
0005435126448	14740	5	2A
0005435626207	14740	6	2D
0005435626209	14740	7	2F
0005435126466	14740	8	3C
0005435126455	14740	9	3D
0005435126446	14740	10	3F
0005435626205	14740	11	4A
0005434411756	14740	12	4C
0005435626195	14740	13	4D
0005435554193	14740	14	5A
0005435626193	14740	15	5D
0005435554194	14740	16	5E
0005435554192	14740	17	5F
0005435126472	14740	18	6A
0005435126450	14740	19	6C
0005435126478	14740	20	6D
0005435126476	14740	21	6E
0005435626206	14740	22	6F
0005435126442	14740	23	7A
0005435626215	14740	24	7C
0005435126452	14740	25	7E
0005435126445	14740	26	7F
0005435626211	14740	27	8A
0005435626216	14740	28	8C
0005435626201	14740	29	8E
0005435554196	14740	30	8F
0005434411732	14740	31	9C
0005435554195	14740	32	9A
0005435126473	14740	33	9D
0005435126456	14740	34	9E
0005435126454	14740	35	9F
0005435126480	14740	36	10A
0005435554197	14740	37	10C
0005435126469	14740	38	10D
0005435626197	14740	39	10E
0005435126475	14740	40	10F
0005435126479	14740	41	11A
0005434928284	14740	42	11D
0005435126470	14740	43	11E
0005435626199	14740	44	11F
0005435126447	14740	45	12A
0005434411755	14740	46	12C
0005435626204	14740	47	12D
0005435626212	14740	48	12E
0005435126477	14740	49	12F
0005435126444	14740	50	13A
0005435626198	14740	51	13C
0005435626213	14740	52	13D
0005435126440	14740	53	13E
0005435126457	14740	54	13F
0005435126464	14740	55	14A
0005434411738	14740	56	14C
0005435626203	14740	57	14D
0005435126459	14740	58	14E
0005435626196	14740	59	14F
0005435126462	14740	60	15A
0005435626208	14740	61	15C
0005434411733	14740	62	15D
0005435626194	14740	63	15E
0005435126451	14740	64	16A
0005435626217	14740	65	16C
0005435626202	14740	66	16D
0005435556698	14740	67	16E
0005434928282	14740	68	16F
0005435126453	14740	69	17A
0005435126443	14740	70	17C
0005435126467	14740	71	17D
0005435126461	14740	72	17E
0005435126439	14740	73	18C
0005434411726	14740	74	18D
0005435126449	14740	75	18E
0005435126471	14740	76	18F
0005435626214	14740	77	19C
0005435126441	14740	78	19D
0005435556697	14740	79	19E
0005435126458	14740	80	19F
0005435626210	14740	81	20C
0005435126465	14740	82	20D
0005435626200	14740	83	20E
0005435126438	14740	84	20F
0005432398204	7111	1	1C
0005435443263	7111	2	1D
0005432398205	7111	3	1F
0005435715510	7111	4	3D
0005432400134	7111	5	4C
0005435179390	7111	6	4D
0005435178486	7111	7	4E
0005435715497	7111	8	4F
0005432400133	7111	9	5A
0005435216569	7111	10	5D
0005435715500	7111	11	6A
0005435715498	7111	12	6C
0005435443244	7111	13	6D
0005432400131	7111	14	6E
0005435443240	7111	15	7A
0005435178484	7111	16	7C
0005435715494	7111	17	7D
0005435715504	7111	18	7E
0005435715507	7111	19	8A
0005435715506	7111	20	8E
0005435443251	7111	21	9C
0005435443245	7111	22	9D
0005435443278	7111	23	9F
0005435219189	7111	24	10A
0005435443264	7111	25	10C
0005435443267	7111	26	10E
0005435443250	7111	27	11D
0005435715502	7111	28	11E
0005435715505	7111	29	11F
0005435443239	7111	30	12F
0005435443277	7111	31	13C
0005432400132	7111	32	13E
0005435715508	7111	33	14A
0005435178489	7111	34	14D
0005435443243	7111	35	15D
0005435715503	7111	36	15F
0005435443246	7111	37	16C
0005435715509	7111	38	16D
0005435219190	7111	39	17C
0005435715495	7111	40	17D
0005435219176	7111	41	17E
0005435715499	7111	42	17F
0005435219191	7111	43	18C
0005435219177	7111	44	19A
0005435715496	7111	45	19C
0005435443241	7111	46	19E
0005435715501	7111	47	19F
0005435715394	27048	1	1A
0005435715342	27048	2	2C
0005435715385	27048	3	3A
0005435715270	27048	4	5C
0005435715407	27048	5	6A
0005435715339	27048	6	6D
0005435715271	27048	7	6E
0005435715364	27048	8	7A
0005435443336	27048	9	7D
0005435715303	27048	10	7E
0005435178995	27048	11	8A
0005435715384	27048	12	8F
0005432398181	27048	13	9C
0005435178993	27048	14	9F
0005435715418	27048	15	10A
0005435178498	27048	16	10F
0005435443330	27048	17	11D
0005435443332	27048	18	12F
0005432394081	27048	19	13E
0005435443331	27048	20	15C
0005435443334	27048	21	15D
0005435715302	27048	22	15F
0005435443329	27048	23	16A
0005435715464	27048	24	16E
0005432398164	27048	25	16F
0005435715313	27048	26	17A
0005435715465	27048	27	17D
0005435178994	27048	28	17E
0005435443328	27048	29	17F
0005435715338	27048	30	18D
0005435443333	27048	31	18E
0005432394080	27048	32	18F
0005432394082	27048	33	19C
0005435443335	27048	34	19E
0005433060394	2751	1	1A
0005433060401	2751	2	2A
0005434084937	2751	3	1B
0005434084942	2751	4	2B
0005434084941	2751	5	3A
0005433060400	2751	6	4A
0005433060383	2751	7	4B
0005433060388	2751	8	5A
0005434084938	2751	9	5B
0005434084940	2751	10	6A
0005434084939	2751	11	6B
0005434084899	28496	1	1A
0005433060419	28496	2	3A
0005434084898	28496	3	3B
0005433060418	28496	4	6B
0005435517777	11378	1	1F
0005435540830	11378	2	2D
0005435540781	11378	3	5D
0005435517803	11378	4	5E
0005435517848	11378	5	7A
0005435540888	11378	6	7D
0005435540930	11378	7	8A
0005435540889	11378	8	8C
0005435540824	11378	9	8F
0005435540837	11378	10	10A
0005435517824	11378	11	11C
0005435517823	11378	12	11D
0005435540949	11378	13	11F
0005435540823	11378	14	14A
0005435540890	11378	15	14E
0005435517776	11378	16	15D
0005435540825	11378	17	15E
0005435540939	11378	18	19D
0005435540969	11378	19	19E
0005435540780	11378	20	20A
0005435540826	11378	21	20D
0005435517847	11378	22	20F
0005435541035	22232	1	1C
0005435529289	22232	2	2A
0005435529295	22232	3	2C
0005435529299	22232	4	2F
0005435541033	22232	5	3F
0005435541031	22232	6	4A
0005432294490	22232	7	4C
0005435529280	22232	8	4E
0005435529278	22232	9	4F
0005435529288	22232	10	5C
0005435529282	22232	11	5D
0005435529294	22232	12	6D
0005435541042	22232	13	6E
0005435529285	22232	14	7E
0005435541034	22232	15	7F
0005435529281	22232	16	8C
0005435541036	22232	17	8E
0005435541041	22232	18	9A
0005432294489	22232	19	9E
0005435529283	22232	20	10A
0005435541039	22232	21	10E
0005435529297	22232	22	10F
0005435541027	22232	23	11A
0005435541026	22232	24	11D
0005435529296	22232	25	11E
0005435541025	22232	26	12A
0005435541040	22232	27	12F
0005435541023	22232	28	13A
0005435541030	22232	29	13C
0005435541038	22232	30	13D
0005435529291	22232	31	13F
0005435541037	22232	32	14A
0005435529298	22232	33	14C
0005435541024	22232	34	15C
0005435541029	22232	35	15D
0005435541028	22232	36	15F
0005435529286	22232	37	16A
0005435529279	22232	38	16C
0005435529290	22232	39	17C
0005432294491	22232	40	17D
0005435541032	22232	41	17E
0005435529292	22232	42	18D
0005435529287	22232	43	19C
0005435529277	22232	44	19D
0005435529293	22232	45	20A
0005435529284	22232	46	20E
0005434907408	2272	1	1A
0005434907419	2272	2	1C
0005434907388	2272	3	1D
0005433251296	2272	4	1F
0005433251508	2272	5	2A
0005434907426	2272	6	2C
0005434907385	2272	7	2D
0005433400966	2272	8	2F
0005434907427	2272	9	3C
0005434907411	2272	10	3A
0005433251265	2272	11	3D
0005434907412	2272	12	3F
0005434907374	2272	13	4A
0005434907379	2272	14	4C
0005434907416	2272	15	4D
0005434907386	2272	16	4E
0005434907431	2272	17	4F
0005434907397	2272	18	5A
0005433400972	2272	19	5C
0005434907380	2272	20	5D
0005433400970	2272	21	5E
0005433400971	2272	22	5F
0005434907421	2272	23	6A
0005434907401	2272	24	6C
0005434907423	2272	25	6D
0005434907406	2272	26	6E
0005434907420	2272	27	6F
0005434907400	2272	28	7A
0005433400965	2272	29	7C
0005434907392	2272	30	7D
0005433251334	2272	31	7E
0005434907396	2272	32	7F
0005434907403	2272	33	8A
0005434907424	2272	34	8D
0005434907387	2272	35	8E
0005434907404	2272	36	8F
0005433251253	2272	37	9A
0005434907415	2272	38	9D
0005434907384	2272	39	9E
0005434907407	2272	40	9F
0005433251361	2272	41	10A
0005434907390	2272	42	10C
0005433251213	2272	43	10D
0005434907372	2272	44	10E
0005434907413	2272	45	10F
0005434907375	2272	46	11A
0005434907376	2272	47	11C
0005433251335	2272	48	11D
0005434907429	2272	49	11E
0005434907402	2272	50	11F
0005434907435	2272	51	12C
0005434907389	2272	52	12D
0005434907394	2272	53	12E
0005433251378	2272	54	12F
0005434907373	2272	55	13A
0005433251289	2272	56	13C
0005434907405	2272	57	13D
0005434907377	2272	58	13E
0005434907382	2272	59	13F
0005434907391	2272	60	14A
0005433251214	2272	61	14C
0005434907381	2272	62	14D
0005434907433	2272	63	14E
0005434907383	2272	64	15A
0005434907409	2272	65	15C
0005434907378	2272	66	15D
0005433251266	2272	67	15E
0005434907417	2272	68	15F
0005433251376	2272	69	16A
0005434907395	2272	70	16C
0005434907418	2272	71	16D
0005434907399	2272	72	16E
0005433251267	2272	73	16F
0005434907398	2272	74	17A
0005433251337	2272	75	17C
0005434907430	2272	76	17D
0005434907422	2272	77	17E
0005433251297	2272	78	17F
0005434907425	2272	79	18C
0005434907432	2272	80	18D
0005434907393	2272	81	18E
0005434907414	2272	82	19A
0005433400964	2272	83	19C
0005434907410	2272	84	19D
0005433251365	2272	85	19F
0005433251411	2272	86	20A
0005434907428	2272	87	20C
0005433251244	2272	88	20D
0005433251360	2272	89	20E
0005434907434	2272	90	20F
0005433251544	25588	1	1A
0005433251538	25588	2	1D
0005433251542	25588	3	1F
0005434906870	25588	4	2A
0005434906965	25588	5	2C
0005434906764	25588	6	2F
0005434907008	25588	7	3A
0005433251554	25588	8	3C
0005434906838	25588	9	3D
0005434906890	25588	10	3F
0005434906743	25588	11	4A
0005434906636	25588	12	4C
0005433251537	25588	13	4D
0005434906869	25588	14	4E
0005433251555	25588	15	4F
0005434906832	25588	16	5A
0005434906930	25588	17	5C
0005434906774	25588	18	5D
0005433251551	25588	19	5E
0005433251558	25588	20	5F
0005434906931	25588	21	6A
0005433251528	25588	22	6C
0005433251556	25588	23	6D
0005433251559	25588	24	6E
0005433251532	25588	25	6F
0005433251540	25588	26	7A
0005434906928	25588	27	7C
0005433251536	25588	28	7D
0005434907007	25588	29	7E
0005434907047	25588	30	7F
0005434906914	25588	31	8A
0005434906858	25588	32	8C
0005434906988	25588	33	8D
0005434906744	25588	34	8E
0005433251552	25588	35	8F
0005434906927	25588	36	9A
0005433251534	25588	37	9C
0005433251541	25588	38	9D
0005434906811	25588	39	9E
0005434906553	25588	40	9F
0005434906855	25588	41	10A
0005434906944	25588	42	10D
0005434906763	25588	43	10C
0005434906919	25588	44	10E
0005433400990	25588	45	10F
0005434906868	25588	46	11A
0005433251553	25588	47	11D
0005434906925	25588	48	11E
0005434906769	25588	49	11F
0005433251550	25588	50	12A
0005434906864	25588	51	12C
0005433251530	25588	52	12D
0005434906916	25588	53	12E
0005433251546	25588	54	12F
0005434906947	25588	55	13A
0005434906770	25588	56	13C
0005434906753	25588	57	13D
0005433251533	25588	58	13E
0005433251529	25588	59	13F
0005433251547	25588	60	14A
0005434906856	25588	61	14C
0005433251549	25588	62	14D
0005434906918	25588	63	14E
0005433251548	25588	64	14F
0005434906971	25588	65	15A
0005434906921	25588	66	15D
0005434906865	25588	67	15E
0005434906946	25588	68	15F
0005434906896	25588	69	16A
0005434906635	25588	70	16C
0005434907013	25588	71	16D
0005434906760	25588	72	16F
0005433400989	25588	73	17A
0005433251535	25588	74	17D
0005434906957	25588	75	17C
0005433251539	25588	76	17E
0005434906857	25588	77	18A
0005434906812	25588	78	18C
0005434906895	25588	79	18D
0005433251545	25588	80	18E
0005434906860	25588	81	19A
0005434906964	25588	82	19C
0005433251531	25588	83	19D
0005434907014	25588	84	19E
0005434906915	25588	85	19F
0005434906555	25588	86	20A
0005434906804	25588	87	20C
0005434906894	25588	88	20D
0005433251543	25588	89	20E
0005433251557	25588	90	20F
0005432621063	2496	1	1C
0005432862278	2496	2	1D
0005432862301	2496	3	2A
0005432862271	2496	4	2C
0005432862302	2496	5	5A
0005432621068	2496	6	5C
0005432621064	2496	7	5D
0005432621067	2496	8	6C
0005432621070	2496	9	6D
0005432862279	2496	10	7A
0005432621066	2496	11	7B
0005432862275	2496	12	7C
0005432621074	2496	13	18A
0005432862270	2496	14	18C
0005432621071	2496	15	19A
0005432621065	2496	16	19C
0005432621069	2496	17	20A
0005432621073	2496	18	20B
0005432862261	2496	19	20D
0005432862253	2496	20	21C
0005432621062	2496	21	21D
0005432621072	2496	22	22B
0005432862260	2496	23	22D
0005432862316	28048	1	1A
0005432862323	28048	2	1B
0005432620932	28048	3	1D
0005432862320	28048	4	2A
0005432620879	28048	5	2B
0005432862315	28048	6	2C
0005432620930	28048	7	2D
0005432620870	28048	8	3C
0005432862314	28048	9	3D
0005432862321	28048	10	4A
0005432862322	28048	11	4C
0005432620929	28048	12	5C
0005432620963	28048	13	6C
0005432620914	28048	14	7B
0005432620987	28048	15	7D
0005432620983	28048	16	18A
0005432620937	28048	17	19A
0005432620971	28048	18	19B
0005432620931	28048	19	19C
0005432620903	28048	20	19D
0005432862317	28048	21	21B
0005432620933	28048	22	21C
0005432862318	28048	23	21D
0005432620899	28048	24	22B
0005432862319	28048	25	22D
0005434097466	11721	1	2A
0005434097481	13046	1	1A
0005434097480	13046	2	1B
0005434097479	13046	3	3A
0005433452744	31097	1	1A
0005433451623	31097	2	3B
0005433452743	31097	3	4A
0005433451622	31097	4	5A
0005433452722	31343	1	1A
0005433454866	31343	2	1B
0005433454860	31343	3	2A
0005433452718	31343	4	3A
0005433454861	31343	5	4A
0005433452717	31343	6	5B
0005433454862	31343	7	6A
0005433454865	31343	8	6B
0005434142586	12003	1	1A
0005434142583	12003	2	1B
0005434142584	12003	3	1D
0005433134096	12003	4	2A
0005434184645	12003	5	2D
0005433134095	12003	6	4C
0005433134112	12003	7	4D
0005433134109	12003	8	6A
0005433134110	12003	9	7D
0005434142587	12003	10	18A
0005433129261	12003	11	18D
0005434142585	12003	12	19A
0005433129255	12003	13	19B
0005433134104	12003	14	21C
0005434184646	12003	15	23A
0005433134105	12003	16	23B
0005434183584	29832	1	1C
0005433131715	29832	2	1D
0005434142616	29832	3	2B
0005434184669	29832	4	3A
0005433134149	29832	5	3B
0005434142614	29832	6	3D
0005433131717	29832	7	4D
0005434142615	29832	8	5D
0005434142613	29832	9	6B
0005434142617	29832	10	6D
0005433131719	29832	11	7B
0005433134147	29832	12	7C
0005434184670	29832	13	7D
0005433134145	29832	14	18C
0005434184668	29832	15	19A
0005433134146	29832	16	20B
0005433134148	29832	17	20C
0005433134150	29832	18	20D
0005433131718	29832	19	22A
0005434183585	29832	20	22B
0005433131716	29832	21	22D
0005435697378	16447	1	1A
0005435697364	16447	2	1C
0005435697368	16447	3	2C
0005435697365	16447	4	3A
0005435697382	16447	5	3B
0005435697380	16447	6	3D
0005435697374	16447	7	4C
0005435697384	16447	8	5A
0005435697362	16447	9	5B
0005435697373	16447	10	5D
0005435697377	16447	11	6A
0005435697379	16447	12	6B
0005435697361	16447	13	6D
0005435697383	16447	14	7A
0005435697375	16447	15	7B
0005435697386	16447	16	7D
0005435697367	16447	17	18A
0005435697372	16447	18	18B
0005435697370	16447	19	18C
0005435697369	16447	20	19B
0005435697363	16447	21	19C
0005435697387	16447	22	19D
0005435697381	16447	23	20B
0005435697366	16447	24	20D
0005435697376	16447	25	21A
0005435697389	16447	26	21B
0005435697360	16447	27	21C
0005435697385	16447	28	22C
0005435697371	16447	29	22D
0005435697388	16447	30	23A
0005435935056	24704	1	1A
0005435697149	24704	2	1B
0005435697107	24704	3	1C
0005435697141	24704	4	1D
0005435697275	24704	5	2B
0005435935055	24704	6	2C
0005435935053	24704	7	2D
0005435697224	24704	8	3A
0005435697166	24704	9	3D
0005435697301	24704	10	4A
0005435697131	24704	11	4B
0005435697124	24704	12	4C
0005435697214	24704	13	4D
0005435697134	24704	14	5B
0005435697223	24704	15	5C
0005435697302	24704	16	5D
0005435697165	24704	17	6A
0005435697267	24704	18	7A
0005435697132	24704	19	7B
0005435935052	24704	20	7C
0005435697268	24704	21	18A
0005435697140	24704	22	19A
0005435697204	24704	23	19B
0005435697286	24704	24	19C
0005435935057	24704	25	20A
0005435697074	24704	26	20B
0005435697168	24704	27	20C
0005435935054	24704	28	21A
0005435697104	24704	29	21B
0005435697108	24704	30	21C
0005435697239	24704	31	21D
0005435697123	24704	32	22A
0005435697285	24704	33	22C
0005435697205	24704	34	23B
0005432968817	18814	1	2A
0005432968826	18814	2	1B
0005432968807	18814	3	2B
0005432968816	18814	4	3A
0005432968818	18814	5	3B
0005432968831	18814	6	4A
0005433724814	18814	7	5A
0005432968830	18814	8	4B
0005433724813	18814	9	5B
0005433724812	18814	10	6A
0005432968846	21626	1	1B
0005433724793	21626	2	2A
0005432968847	21626	3	3A
0005433724792	21626	4	4A
0005433724772	21626	5	4B
0005433724778	21626	6	5B
0005434138356	7292	1	1A
0005434138329	7292	2	1C
0005434138359	7292	3	1D
0005434138307	7292	4	1F
0005434138323	7292	5	2C
0005434138331	7292	6	2D
0005434138308	7292	7	2F
0005434138341	7292	8	3A
0005434138313	7292	9	3C
0005434138347	7292	10	3D
0005434138387	7292	11	3F
0005434138380	7292	12	4A
0005434138355	7292	13	4C
0005434087522	7292	14	4D
0005434138357	7292	15	4E
0005434138336	7292	16	4F
0005434138363	7292	17	5A
0005434138351	7292	18	5C
0005434138337	7292	19	5D
0005434138352	7292	20	5F
0005434138346	7292	21	6A
0005434138325	7292	22	6C
0005434138339	7292	23	6D
0005434138362	7292	24	6E
0005434138353	7292	25	6F
0005434138324	7292	26	7A
0005434138376	7292	27	7C
0005434138310	7292	28	7E
0005434138338	7292	29	7F
0005434138361	7292	30	8C
0005434138335	7292	31	8D
0005434138368	7292	32	8E
0005434138350	7292	33	8F
0005434087525	7292	34	9A
0005434138322	7292	35	9D
0005434138340	7292	36	9F
0005434138383	7292	37	10A
0005434138315	7292	38	10C
0005434138369	7292	39	10E
0005434138318	7292	40	10F
0005434138348	7292	41	11A
0005434138372	7292	42	11C
0005434138328	7292	43	11D
0005434138333	7292	44	11E
0005434138334	7292	45	11F
0005434138382	7292	46	12A
0005434138349	7292	47	12C
0005434138330	7292	48	12D
0005434138386	7292	49	12E
0005434138343	7292	50	12F
0005434138375	7292	51	13A
0005434138377	7292	52	13C
0005434138311	7292	53	13D
0005434138388	7292	54	13E
0005434138320	7292	55	13F
0005434138309	7292	56	14A
0005434138374	7292	57	14C
0005434138314	7292	58	14D
0005434138306	7292	59	14E
0005434138384	7292	60	14F
0005434138379	7292	61	15A
0005434138344	7292	62	15C
0005434138312	7292	63	15D
0005434138371	7292	64	15E
0005434138319	7292	65	16A
0005434138385	7292	66	16C
0005434138378	7292	67	16D
0005434138326	7292	68	16E
0005434138366	7292	69	16F
0005434138373	7292	70	17A
0005434138367	7292	71	17C
0005434138317	7292	72	17F
0005434138342	7292	73	18A
0005434138354	7292	74	18C
0005434138332	7292	75	18D
0005434138370	7292	76	18E
0005434087523	7292	77	18F
0005434138360	7292	78	19A
0005434138316	7292	79	19C
0005434138365	7292	80	19D
0005434138345	7292	81	19E
0005434138327	7292	82	19F
0005434138381	7292	83	20A
0005434087524	7292	84	20C
0005434138364	7292	85	20D
0005434138321	7292	86	20E
0005434138358	7292	87	20F
0005434137546	28535	1	1C
0005434137288	28535	2	1D
0005434137297	28535	3	1F
0005434137687	28535	4	2A
0005434137517	28535	5	2C
0005434137468	28535	6	2D
0005434137179	28535	7	2F
0005434137639	28535	8	3C
0005434137348	28535	9	3D
0005434137030	28535	10	3F
0005434137482	28535	11	4A
0005434137199	28535	12	4E
0005434137395	28535	13	4F
0005434137477	28535	14	5A
0005434137333	28535	15	5C
0005434137693	28535	16	5E
0005434137406	28535	17	5F
0005434137602	28535	18	6A
0005434137209	28535	19	6C
0005434137699	28535	20	6D
0005434137043	28535	21	6E
0005434137120	28535	22	6F
0005434137379	28535	23	7A
0005434137566	28535	24	7C
0005434137467	28535	25	7D
0005434137119	28535	26	7E
0005434137519	28535	27	7F
0005434137296	28535	28	8A
0005434137513	28535	29	8C
0005434137453	28535	30	8D
0005434137399	28535	31	8E
0005434137478	28535	32	8F
0005434137651	28535	33	9A
0005434137522	28535	34	9C
0005434137317	28535	35	9D
0005434137387	28535	36	9E
0005434137374	28535	37	9F
0005434137316	28535	38	10A
0005434137650	28535	39	10C
0005434137345	28535	40	10D
0005434137652	28535	41	10E
0005434137516	28535	42	10F
0005434137547	28535	43	11C
0005434137686	28535	44	11D
0005434137393	28535	45	11E
0005434137665	28535	46	11F
0005434137565	28535	47	12A
0005434137638	28535	48	12C
0005434137505	28535	49	12D
0005434137042	28535	50	12E
0005434137636	28535	51	12F
0005434137470	28535	52	13A
0005434137521	28535	53	13C
0005434137506	28535	54	13D
0005434137108	28535	55	13E
0005434137694	28535	56	13F
0005434137210	28535	57	14A
0005434137447	28535	58	14D
0005434137186	28535	59	14E
0005434137375	28535	60	14F
0005434087483	28535	61	15A
0005434137483	28535	62	15C
0005434137041	28535	63	15E
0005434137378	28535	64	15F
0005434137508	28535	65	16C
0005434137548	28535	66	16D
0005434137315	28535	67	16E
0005434137664	28535	68	16F
0005434137581	28535	69	17A
0005434137641	28535	70	17C
0005434137580	28535	71	17D
0005434137314	28535	72	17E
0005434137452	28535	73	17F
0005434087489	28535	74	18A
0005434137342	28535	75	18D
0005434137562	28535	76	19A
0005434137394	28535	77	19C
0005434137640	28535	78	19D
0005434137388	28535	79	19E
0005434137535	28535	80	19F
0005434137727	28535	81	20A
0005434137343	28535	82	20C
0005434137481	28535	83	20D
0005434137635	28535	84	20E
0005434137507	28535	85	20F
0005435808253	1925	1	1A
0005433407497	1925	2	2C
0005435808261	1925	3	2D
0005435808262	1925	4	4B
0005434610236	1925	5	5A
0005435808258	1925	6	5D
0005435808255	1925	7	6A
0005435808260	1925	8	7C
0005435808252	1925	9	7D
0005433407520	1925	10	18A
0005435808256	1925	11	18B
0005434610237	1925	12	18D
0005433407519	1925	13	19A
0005433407521	1925	14	19D
0005433407524	1925	15	20D
0005435808254	1925	16	21A
0005435808257	1925	17	21B
0005434610238	1925	18	22B
0005435808259	1925	19	22D
0005435808097	23107	1	1A
0005435808137	23107	2	1B
0005433407566	23107	3	1C
0005434610205	23107	4	2A
0005435808114	23107	5	2B
0005435808123	23107	6	2D
0005435808102	23107	7	3A
0005435808139	23107	8	3B
0005434610217	23107	9	3D
0005433407572	23107	10	4A
0005434610204	23107	11	4B
0005435808085	23107	12	4D
0005434610192	23107	13	5A
0005435808138	23107	14	5B
0005435808100	23107	15	5D
0005435808169	23107	16	6A
0005434610203	23107	17	6B
0005435808131	23107	18	6D
0005433407574	23107	19	7B
0005435808161	23107	20	7C
0005435808118	23107	21	7D
0005433407569	23107	22	18A
0005433407568	23107	23	18C
0005435808113	23107	24	18D
0005435808087	23107	25	19A
0005433407567	23107	26	19B
0005433407565	23107	27	19C
0005435808111	23107	28	20A
0005435808099	23107	29	20C
0005435808126	23107	30	20D
0005435808117	23107	31	21A
0005433407570	23107	32	21B
0005435808119	23107	33	21C
0005435808088	23107	34	22A
0005435808122	23107	35	22B
0005433407573	23107	36	22C
0005433407571	23107	37	22D
0005434610199	23107	38	23A
0005435808132	23107	39	23B
0005434503835	16722	1	1B
0005434503834	16722	2	1C
0005434503883	16722	3	1D
0005434504049	16722	4	2A
0005434504020	16722	5	2B
0005434503892	16722	6	3A
0005434503678	16722	7	3C
0005434503700	16722	8	4A
0005434503921	16722	9	4C
0005434503941	16722	10	4D
0005434503851	16722	11	5A
0005434503804	16722	12	5B
0005434503769	16722	13	5C
0005434503898	16722	14	5D
0005434504011	16722	15	6A
0005434503635	16722	16	6B
0005434503878	16722	17	6C
0005434503922	16722	18	6D
0005434504012	16722	19	7A
0005434503781	16722	20	7B
0005434503942	16722	21	7C
0005434503770	16722	22	7D
0005434503647	16722	23	18A
0005434503971	16722	24	18C
0005434503886	16722	25	18D
0005434504013	16722	26	19B
0005434503805	16722	27	19C
0005434503646	16722	28	19D
0005434503877	16722	29	20B
0005434503981	16722	30	20C
0005434504006	16722	31	21A
0005434503880	16722	32	21B
0005434504021	16722	33	21C
0005434503963	16722	34	21D
0005434503782	16722	35	22A
0005434503771	16722	36	22B
0005434504051	16722	37	22C
0005434503980	16722	38	22D
0005434503634	16722	39	23A
0005434504211	22931	1	1A
0005434504210	22931	2	1B
0005434504195	22931	3	1C
0005434504202	22931	4	1D
0005434504203	22931	5	2A
0005434504217	22931	6	2B
0005434504188	22931	7	2C
0005434504215	22931	8	2D
0005434504207	22931	9	3B
0005434504220	22931	10	3C
0005434504193	22931	11	4A
0005434504189	22931	12	4B
0005434504214	22931	13	4C
0005434504194	22931	14	5B
0005434504185	22931	15	5C
0005434504201	22931	16	5D
0005434504219	22931	17	6A
0005434504191	22931	18	6B
0005434504199	22931	19	7A
0005434504209	22931	20	6D
0005434504187	22931	21	7B
0005434504223	22931	22	7C
0005434504218	22931	23	7D
0005434504198	22931	24	18A
0005434504190	22931	25	18B
0005434504216	22931	26	18C
0005434504200	22931	27	19A
0005434504222	22931	28	19C
0005434504213	22931	29	19D
0005434504225	22931	30	20A
0005434504224	22931	31	20B
0005434504212	22931	32	20D
0005434504205	22931	33	20C
0005434504192	22931	34	21A
0005434504204	22931	35	21B
0005434504221	22931	36	21C
0005434504186	22931	37	21D
0005434504196	22931	38	22A
0005434504206	22931	39	22B
0005434504197	22931	40	23A
0005434504208	22931	41	23B
0005435078375	2200	1	1B
0005435078368	2200	2	1C
0005435078374	2200	3	2B
0005435078376	2200	4	3A
0005435078378	2200	5	3C
0005433266659	2200	6	3D
0005433266655	2200	7	4B
0005435078371	2200	8	4D
0005435078366	2200	9	5B
0005433266643	2200	10	5C
0005435078370	2200	11	5D
0005433266708	2200	12	6A
0005435078369	2200	13	6C
0005435078367	2200	14	7A
0005435078372	2200	15	18A
0005435078381	2200	16	18B
0005435078373	2200	17	19B
0005433266667	2200	18	19D
0005435078380	2200	19	20A
0005433266669	2200	20	20B
0005435078377	2200	21	20C
0005433266681	2200	22	20D
0005433266706	2200	23	21A
0005433266594	2200	24	21D
0005433266683	2200	25	22A
0005433266687	2200	26	22B
0005433266668	2200	27	22C
0005435078379	2200	28	22D
0005433266644	2200	29	23B
0005433266744	24357	1	1A
0005435078216	24357	2	1C
0005435078242	24357	3	2C
0005435078258	24357	4	3A
0005433266739	24357	5	3B
0005435078275	24357	6	4A
0005433266740	24357	7	5A
0005435078278	24357	8	5D
0005433266743	24357	9	6A
0005435078276	24357	10	6C
0005435078306	24357	11	6D
0005435078257	24357	12	7A
0005435078236	24357	13	7B
0005433266745	24357	14	19A
0005435078277	24357	15	19C
0005433266746	24357	16	19D
0005435078202	24357	17	20C
0005435078235	24357	18	20D
0005435078292	24357	19	21B
0005435078319	24357	20	21C
0005435078201	24357	21	22A
0005433266741	24357	22	22D
0005433266742	24357	23	23A
0005434988772	6633	1	1B
0005435464492	6633	2	1D
0005434988770	6633	3	2A
0005435464495	6633	4	2D
0005435803269	6633	5	5B
0005434988774	6633	6	5D
0005434988771	6633	7	6B
0005434988767	6633	8	6C
0005434988766	6633	9	6D
0005434988765	6633	10	7A
0005434988769	6633	11	19A
0005434988776	6633	12	19B
0005434988773	6633	13	19C
0005434988775	6633	14	19D
0005434988768	6633	15	20A
0005434988764	6633	16	21A
0005434988763	6633	17	21C
0005434988633	23623	1	2A
0005434988626	23623	2	3D
0005434988645	23623	3	4D
0005435464510	23623	4	5A
0005435803248	23623	5	6B
0005434988644	23623	6	7C
0005435464512	23623	7	18C
0005434988636	23623	8	20A
0005434988625	23623	9	21A
0005434988619	23623	10	21D
0005435464511	23623	11	22C
0005434988643	23623	12	22D
0005435803237	23623	13	23B
0005433450012	30484	1	1C
0005433450008	30484	2	1D
0005432383270	30484	3	1F
0005433450011	30484	4	2A
0005432383250	30484	5	2D
0005432383240	30484	6	2F
0005432383263	30484	7	3A
0005432383251	30484	8	3C
0005432383256	30484	9	3F
0005433450013	30484	10	4A
0005432383254	30484	11	4C
0005432383272	30484	12	4D
0005432383267	30484	13	4F
0005432383278	30484	14	5A
0005433450027	30484	15	5F
0005433450015	30484	16	6A
0005432383275	30484	17	6C
0005432383253	30484	18	6D
0005433450023	30484	19	6F
0005433450026	30484	20	7C
0005432383258	30484	21	7D
0005433450022	30484	22	7E
0005432383249	30484	23	7F
0005433450018	30484	24	8A
0005432383246	30484	25	8C
0005432383262	30484	26	8E
0005432383245	30484	27	8F
0005432383257	30484	28	9A
0005432383269	30484	29	9C
0005433454880	30484	30	9E
0005432383273	30484	31	9F
0005432383271	30484	32	10C
0005432383261	30484	33	10D
0005432383274	30484	34	10E
0005432383247	30484	35	11A
0005432383242	30484	36	11C
0005433450016	30484	37	11D
0005432383241	30484	38	11F
0005432383244	30484	39	12C
0005433450014	30484	40	12E
0005432383265	30484	41	13C
0005433453766	30484	42	13D
0005432383255	30484	43	13F
0005432383243	30484	44	14A
0005432383276	30484	45	14D
0005433450021	30484	46	14E
0005433450010	30484	47	14F
0005433450025	30484	48	15A
0005432383260	30484	49	15E
0005433450020	30484	50	15F
0005432383259	30484	51	16C
0005433453767	30484	52	16D
0005432383268	30484	53	16E
0005432383266	30484	54	17C
0005432383252	30484	55	17D
0005433450028	30484	56	17E
0005432383264	30484	57	17F
0005432383238	30484	58	18A
0005432383277	30484	59	18C
0005433454879	30484	60	18D
0005433453765	30484	61	18F
0005432383248	30484	62	19C
0005432383239	30484	63	19D
0005433450017	30484	64	19E
0005433450009	30484	65	20A
0005433450024	30484	66	20C
0005433450019	30484	67	20F
0005432382729	31310	1	1C
0005432382725	31310	2	1F
0005432382923	31310	3	2A
0005433449831	31310	4	2C
0005433451603	31310	5	2D
0005432382924	31310	6	3A
0005433449862	31310	7	3C
0005432382999	31310	8	3D
0005433449796	31310	9	4A
0005432382808	31310	10	4C
0005433449866	31310	11	4D
0005433453749	31310	12	4F
0005432382796	31310	13	5C
0005432382893	31310	14	5D
0005433449763	31310	15	5E
0005433449840	31310	16	5F
0005432382822	31310	17	6A
0005432382941	31310	18	6C
0005433449889	31310	19	6D
0005433451606	31310	20	6E
0005432382891	31310	21	6F
0005433449804	31310	22	7A
0005432382939	31310	23	7C
0005432382858	31310	24	7D
0005432382850	31310	25	8A
0005433449838	31310	26	8E
0005433449871	31310	27	8F
0005432382821	31310	28	9A
0005433449888	31310	29	9C
0005433451602	31310	30	9D
0005432382853	31310	31	9F
0005433449826	31310	32	10A
0005433453752	31310	33	10E
0005433449875	31310	34	10F
0005433449825	31310	35	11C
0005432382834	31310	36	11D
0005433453747	31310	37	11E
0005433451607	31310	38	12A
0005432382927	31310	39	12D
0005432382775	31310	40	12E
0005433449850	31310	41	12F
0005433453748	31310	42	13A
0005433449872	31310	43	13C
0005432383011	31310	44	13D
0005432382894	31310	45	13E
0005432382864	31310	46	14A
0005432382583	31310	47	14C
0005432382724	31310	48	14D
0005432382728	31310	49	14E
0005433449865	31310	50	14F
0005433449883	31310	51	15A
0005432382809	31310	52	15D
0005433449874	31310	53	15F
0005433449922	31310	54	16A
0005432382849	31310	55	16C
0005433453751	31310	56	16D
0005432382854	31310	57	17A
0005432382754	31310	58	17C
0005433449837	31310	59	17D
0005433449805	31310	60	17E
0005432382866	31310	61	17F
0005433449887	31310	62	18A
0005433449803	31310	63	18D
0005432382582	31310	64	18E
0005433449882	31310	65	18F
0005432382823	31310	66	19A
0005433449836	31310	67	19C
0005432382843	31310	68	19E
0005432382842	31310	69	19F
0005433449867	31310	70	20C
0005432382966	31310	71	20D
0005433449835	31310	72	20E
0005432382807	31310	73	20F
0005435304127	10785	1	1B
0005433126807	10785	2	1D
0005435299722	10785	3	3D
0005435304121	10785	4	4A
0005433131664	10785	5	6A
0005435304118	10785	6	6C
0005435304143	10785	7	7B
0005435304117	10785	8	7D
0005435304120	10785	9	20A
0005435304144	10785	10	20C
0005435304131	10785	11	21B
0005433126813	10785	12	22A
0005433126808	10785	13	22B
0005433131665	10785	14	23B
0005433126857	29708	1	2C
0005435299789	29708	2	3C
0005435299792	29708	3	4A
0005435302210	29708	4	4C
0005435302211	29708	5	5D
0005433129291	29708	6	6D
0005433129288	29708	7	7C
0005433129289	29708	8	7D
0005433129287	29708	9	18B
0005435302213	29708	10	18C
0005433129290	29708	11	18D
0005435299791	29708	12	19B
0005435302215	29708	13	19C
0005433126856	29708	14	20A
0005433126859	29708	15	20B
0005433126858	29708	16	20C
0005435299790	29708	17	21A
0005433126860	29708	18	21C
0005435302214	29708	19	21D
0005435299788	29708	20	22C
0005435302212	29708	21	23B
0005432264480	2432	1	1A
0005434287343	2432	2	1C
0005434287334	2432	3	2A
0005434287337	2432	4	2B
0005434287332	2432	5	3B
0005432264479	2432	6	3C
0005434287331	2432	7	3D
0005434287327	2432	8	4A
0005434287328	2432	9	4B
0005434287338	2432	10	4C
0005434287333	2432	11	4D
0005434287342	2432	12	5A
0005433109960	2432	13	5B
0005434287325	2432	14	5C
0005433110012	2432	15	5D
0005433109937	2432	16	6A
0005434287326	2432	17	6B
0005433110035	2432	18	6C
0005434287346	2432	19	7A
0005433109938	2432	20	7B
0005433109972	2432	21	7D
0005434287341	2432	22	18A
0005432264481	2432	23	18B
0005434287329	2432	24	18C
0005434287330	2432	25	19A
0005433110023	2432	26	19B
0005434287344	2432	27	19C
0005433109936	2432	28	19D
0005434287340	2432	29	20A
0005433109995	2432	30	20B
0005433109944	2432	31	20D
0005434287335	2432	32	21C
0005433110036	2432	33	21D
0005434287345	2432	34	22A
0005434287339	2432	35	22B
0005433109961	2432	36	22C
0005433109978	2432	37	22D
0005434287336	2432	38	23A
0005433110073	26845	1	1B
0005433110084	26845	2	1C
0005434287048	26845	3	1D
0005434287132	26845	4	2A
0005433110085	26845	5	2D
0005434287134	26845	6	3A
0005434287135	26845	7	3B
0005434287062	26845	8	3C
0005433110078	26845	9	4A
0005434287131	26845	10	3D
0005434287098	26845	11	4C
0005434287163	26845	12	4D
0005434287159	26845	13	5A
0005434287158	26845	14	5B
0005434287111	26845	15	5C
0005434287166	26845	16	5D
0005434287065	26845	17	6A
0005434287121	26845	18	6B
0005433110077	26845	19	6C
0005433110081	26845	20	6D
0005434287198	26845	21	7A
0005433110082	26845	22	7B
0005434287122	26845	23	7D
0005434287078	26845	24	18B
0005433110076	26845	25	18C
0005434287164	26845	26	18D
0005433110075	26845	27	19A
0005434287080	26845	28	19B
0005434287081	26845	29	20B
0005433110080	26845	30	20D
0005434287116	26845	31	21A
0005433110079	26845	32	21C
0005434287082	26845	33	22A
0005434287133	26845	34	22C
0005433110083	26845	35	22D
0005433110074	26845	36	23A
0005434269085	25498	1	4B
0005435856213	25498	2	5D
0005435856215	25498	3	18D
0005434272173	25498	4	21A
0005435856214	25498	5	23B
0005435854051	26663	1	1A
0005435856176	26663	2	1B
0005434272196	26663	3	3B
0005435856169	26663	4	4A
0005434272195	26663	5	5A
0005434272197	26663	6	6C
0005434273080	26663	7	21C
0005433650656	7154	1	1A
0005433650688	7154	2	1C
0005433650686	7154	3	1D
0005433650646	7154	4	1F
0005433650679	7154	5	2A
0005433650687	7154	6	2C
0005433650641	7154	7	2D
0005433650651	7154	8	2F
0005433650666	7154	9	3A
0005433650689	7154	10	3C
0005435263562	7154	11	4A
0005435263550	7154	12	4C
0005433650672	7154	13	4D
0005433650652	7154	14	4E
0005433650650	7154	15	5C
0005433650659	7154	16	5D
0005435263576	7154	17	5F
0005433650671	7154	18	6A
0005435263592	7154	19	6C
0005433650669	7154	20	6D
0005433650678	7154	21	6E
0005433650674	7154	22	7A
0005433650647	7154	23	7C
0005435263568	7154	24	7D
0005433650676	7154	25	7E
0005433650682	7154	26	8C
0005435263541	7154	27	8E
0005433650664	7154	28	8F
0005433650685	7154	29	9A
0005435263536	7154	30	9C
0005433650643	7154	31	9D
0005433650668	7154	32	9E
0005433650663	7154	33	9F
0005435263540	7154	34	10A
0005435263563	7154	35	10D
0005433650673	7154	36	10C
0005433650667	7154	37	10E
0005435263574	7154	38	10F
0005435263547	7154	39	11A
0005433650684	7154	40	11C
0005433650675	7154	41	11D
0005435263566	7154	42	12A
0005433650662	7154	43	12C
0005433650660	7154	44	12D
0005433650644	7154	45	12F
0005435263549	7154	46	13A
0005433650653	7154	47	13C
0005435263545	7154	48	13E
0005433650657	7154	49	13D
0005435263591	7154	50	14A
0005433650661	7154	51	14C
0005433650645	7154	52	14E
0005433650677	7154	53	15A
0005433650683	7154	54	15C
0005433650649	7154	55	15D
0005435263548	7154	56	15E
0005433650680	7154	57	16A
0005435263546	7154	58	16C
0005435263539	7154	59	16D
0005433650654	7154	60	16E
0005435263587	7154	61	16F
0005433650658	7154	62	17A
0005435263575	7154	63	17C
0005435263558	7154	64	17E
0005433650639	7154	65	17F
0005433650655	7154	66	18A
0005435263585	7154	67	18D
0005433650648	7154	68	18F
0005435263586	7154	69	19A
0005433650642	7154	70	19C
0005433650670	7154	71	19D
0005433650681	7154	72	19E
0005433650640	7154	73	20A
0005435263542	7154	74	20C
0005433650665	7154	75	20D
0005435263551	7154	76	20F
0005433868530	4768	1	1B
0005435860461	4768	2	1C
0005433868529	4768	3	1D
0005433868527	4768	4	2A
0005433868518	4768	5	2B
0005433868513	4768	6	2C
0005433868522	4768	7	3A
0005433868545	4768	8	3B
0005433868535	4768	9	3C
0005433868514	4768	10	3D
0005433868539	4768	11	4A
0005433868533	4768	12	4B
0005433868534	4768	13	4C
0005433868550	4768	14	4D
0005433868537	4768	15	5A
0005433868526	4768	16	5B
0005433868517	4768	17	5D
0005433868515	4768	18	6A
0005433868540	4768	19	6B
0005433868549	4768	20	6D
0005433868542	4768	21	7A
0005433868528	4768	22	7C
0005433868536	4768	23	7D
0005433868524	4768	24	18A
0005433868516	4768	25	18B
0005435860460	4768	26	18C
0005433868523	4768	27	18D
0005433868544	4768	28	19A
0005433868520	4768	29	19B
0005433868546	4768	30	19C
0005433868547	4768	31	19D
0005433868538	4768	32	20A
0005433868543	4768	33	20B
0005433868525	4768	34	20C
0005433868548	4768	35	20D
0005433868551	4768	36	21A
0005433868541	4768	37	21B
0005433868521	4768	38	21C
0005433868532	4768	39	21D
0005433868519	4768	40	22B
0005435860453	4768	41	22C
0005433868531	4768	42	22D
0005435860454	4768	43	23B
0005433868230	32600	1	1A
0005433868018	32600	2	1C
0005433868134	32600	3	1D
0005433868014	32600	4	2A
0005433868271	32600	5	2B
0005433868006	32600	6	2C
0005433868110	32600	7	2D
0005433867995	32600	8	3A
0005433868149	32600	9	3B
0005433868130	32600	10	3C
0005433868143	32600	11	3D
0005433868062	32600	12	4A
0005433868229	32600	13	4B
0005433867990	32600	14	4C
0005433868142	32600	15	4D
0005433868154	32600	16	5A
0005435860495	32600	17	5B
0005433868135	32600	18	5C
0005433868111	32600	19	5D
0005433868054	32600	20	6A
0005433868109	32600	21	6B
0005433868333	32600	22	6C
0005433868334	32600	23	6D
0005433868087	32600	24	7A
0005435860499	32600	25	7B
0005433868296	32600	26	7C
0005433868040	32600	27	7D
0005433867857	32600	28	18A
0005433868225	32600	29	18B
0005433868031	32600	30	18C
0005433868165	32600	31	18D
0005433868210	32600	32	19A
0005433868032	32600	33	19B
0005435860494	32600	34	19C
0005433867945	32600	35	19D
0005433868272	32600	36	20A
0005435860496	32600	37	20B
0005433868066	32600	38	20C
0005433868252	32600	39	20D
0005433868160	32600	40	21A
0005433868108	32600	41	21B
0005435860497	32600	42	21C
0005433868112	32600	43	21D
0005433868194	32600	44	22A
0005435860498	32600	45	22B
0005433868027	32600	46	22C
0005433868192	32600	47	22D
0005433868226	32600	48	23A
0005433868116	32600	49	23B
0005434663439	3434	1	1B
0005434663443	3434	2	1D
0005434461651	3434	3	2A
0005434663442	3434	4	3B
0005434663431	3434	5	3C
0005435911444	3434	6	4A
0005434663438	3434	7	4B
0005434460509	3434	8	4C
0005435911406	3434	9	5B
0005434663435	3434	10	5C
0005435911432	3434	11	5D
0005434663437	3434	12	6A
0005434663440	3434	13	6B
0005435911404	3434	14	6C
0005435911398	3434	15	7A
0005435911410	3434	16	7C
0005435911411	3434	17	7D
0005434663436	3434	18	18A
0005434663430	3434	19	18C
0005434663433	3434	20	18D
0005435911416	3434	21	19A
0005435911405	3434	22	19C
0005435911418	3434	23	19D
0005435911390	3434	24	20A
0005434461652	3434	25	20C
0005434663441	3434	26	21A
0005434460510	3434	27	21B
0005434663434	3434	28	22A
0005435911443	3434	29	21D
0005435911381	3434	30	22B
0005435911417	3434	31	22C
0005435911387	3434	32	23A
0005434663432	3434	33	23B
0005434663334	12496	1	1C
0005434663320	12496	2	2C
0005435911466	12496	3	3B
0005435911465	12496	4	4C
0005435911472	12496	5	6C
0005435911467	12496	6	7D
0005434663319	12496	7	18A
0005435911470	12496	8	19A
0005435911468	12496	9	19B
0005434663302	12496	10	20A
0005435911464	12496	11	20B
0005435911471	12496	12	21C
0005434663335	12496	13	21D
0005435911469	12496	14	22B
0005434663359	12496	15	22D
0005433868230	14524	1	1A
0005433867857	14524	2	1B
0005433868252	14524	3	1C
0005435860495	14524	4	1D
0005433868229	14524	5	2A
0005433868066	14524	6	2B
0005433868333	14524	7	2C
0005435860497	14524	8	2D
0005433867995	14524	9	3A
0005433868210	14524	10	3C
0005433868062	14524	11	3D
0005433868116	14524	12	4A
0005433868087	14524	13	4B
0005433868194	14524	14	4C
0005433868027	14524	15	4D
0005433868014	14524	16	5A
0005433868134	14524	17	5B
0005435860496	14524	18	5C
0005433868226	14524	19	5D
0005433867990	14524	20	6A
0005433868142	14524	21	6B
0005433868018	14524	22	6C
0005435860498	14524	23	6D
0005433868112	14524	24	7A
0005433868271	14524	25	7B
0005433868040	14524	26	7C
0005433868054	14524	27	7D
0005433867945	14524	28	18A
0005433868143	14524	29	18B
0005433868108	14524	30	18C
0005433868111	14524	31	18D
0005433868149	14524	32	19A
0005435860499	14524	33	19B
0005435860494	14524	34	19C
0005433868165	14524	35	19D
0005433868225	14524	36	20A
0005433868032	14524	37	20B
0005433868109	14524	38	20C
0005433868160	14524	39	20D
0005433868130	14524	40	21A
0005433868296	14524	41	21B
0005433868272	14524	42	21C
0005433868154	14524	43	21D
0005433868006	14524	44	22A
0005433868192	14524	45	22B
0005433868031	14524	46	22C
0005433868135	14524	47	22D
0005433868110	14524	48	23A
0005433868334	14524	49	23B
0005433868508	32702	1	1A
0005433868502	32702	2	1B
0005433868484	32702	3	1C
0005433868491	32702	4	1D
0005433868489	32702	5	2A
0005433868501	32702	6	2B
0005433868497	32702	7	2C
0005433868499	32702	8	2D
0005435860464	32702	9	3A
0005433868482	32702	10	3B
0005433868486	32702	11	3C
0005433868475	32702	12	3D
0005435860459	32702	13	4A
0005433868500	32702	14	4B
0005433868473	32702	15	4D
0005433868504	32702	16	5A
0005433868507	32702	17	5B
0005433868478	32702	18	5C
0005433868485	32702	19	6A
0005433868479	32702	20	6C
0005433868483	32702	21	6D
0005435860465	32702	22	7A
0005433868509	32702	23	7B
0005433868490	32702	24	7C
0005433868511	32702	25	7D
0005435860467	32702	26	18A
0005433868512	32702	27	18B
0005433868510	32702	28	18C
0005433868503	32702	29	18D
0005433868477	32702	30	19B
0005433868494	32702	31	19A
0005433868476	32702	32	19C
0005433868492	32702	33	19D
0005433868474	32702	34	20A
0005433868505	32702	35	20B
0005433868481	32702	36	20C
0005435860463	32702	37	20D
0005433868495	32702	38	21B
0005433868487	32702	39	21C
0005433868498	32702	40	21D
0005433868506	32702	41	22B
0005433868496	32702	42	22C
0005433868488	32702	43	22D
0005433868493	32702	44	23A
0005433868480	32702	45	23B
0005432799262	12119	1	1A
0005432799326	12119	2	1C
0005432799325	12119	3	1D
0005432799138	12119	4	2B
0005432799404	12119	5	2D
0005432799324	12119	6	3A
0005432799296	12119	7	3C
0005432799297	12119	8	3D
0005432799278	12119	9	4A
0005432799189	12119	10	4D
0005432799253	12119	11	5A
0005432799348	12119	12	5C
0005432799336	12119	13	6A
0005432799163	12119	14	6B
0005432799172	12119	15	6C
0005432799328	12119	16	6D
0005432799292	12119	17	7A
0005432799131	12119	18	7C
0005432799272	12119	19	7D
0005432799293	12119	20	18B
0005432799265	12119	21	19A
0005432799277	12119	22	19B
0005432799405	12119	23	19D
0005432799337	12119	24	20A
0005432799264	12119	25	20B
0005432799155	12119	26	20C
0005432799316	12119	27	21B
0005432799271	12119	28	21C
0005432799173	12119	29	21D
0005432799254	12119	30	22B
0005432799132	12119	31	22C
0005432799225	12119	32	22D
0005432799238	12119	33	23A
0005432799248	12119	34	23B
0005432799481	14811	1	1A
0005432799487	14811	2	1B
0005432799498	14811	3	1D
0005432799501	14811	4	2A
0005432799486	14811	5	2C
0005432799478	14811	6	2D
0005432799494	14811	7	3B
0005432799489	14811	8	4A
0005432799497	14811	9	4B
0005432799473	14811	10	4C
0005432799499	14811	11	4D
0005432799491	14811	12	5C
0005432799490	14811	13	5D
0005432799482	14811	14	6A
0005432799477	14811	15	6D
0005432799483	14811	16	7A
0005432799475	14811	17	7C
0005432799496	14811	18	18B
0005432799476	14811	19	18D
0005432799484	14811	20	19B
0005432799488	14811	21	19D
0005432799492	14811	22	20D
0005432799493	14811	23	21A
0005432799500	14811	24	21D
0005432799495	14811	25	22A
0005432799480	14811	26	22B
0005432799485	14811	27	22C
0005432799479	14811	28	22D
0005432799474	14811	29	23B
0005434407920	7035	1	1A
0005434407900	7035	2	1C
0005434299602	7035	3	1F
0005435310972	7035	4	1D
0005434407889	7035	5	2A
0005435310973	7035	6	2C
0005435293182	7035	7	2D
0005434407887	7035	8	3A
0005435310968	7035	9	2F
0005434407923	7035	10	3D
0005434407882	7035	11	3C
0005435293183	7035	12	3F
0005434299618	7035	13	4A
0005432153956	7035	14	4B
0005434407902	7035	15	4C
0005434407904	7035	16	4F
0005435310956	7035	17	5A
0005434407919	7035	18	5C
0005435310944	7035	19	5B
0005434407911	7035	20	5D
0005434299605	7035	21	5E
0005434299606	7035	22	5F
0005435293184	7035	23	6B
0005434407876	7035	24	6C
0005434407927	7035	25	6D
0005432153953	7035	26	6E
0005434299621	7035	27	6F
0005434407922	7035	28	7B
0005435310969	7035	29	7A
0005435310963	7035	30	7D
0005434407885	7035	31	7E
0005434299610	7035	32	8A
0005435293175	7035	33	7F
0005435293179	7035	34	8B
0005434299614	7035	35	8D
0005434299615	7035	36	8C
0005435310970	7035	37	8E
0005432108255	7035	38	9A
0005434299600	7035	39	8F
0005432153952	7035	40	9C
0005434407897	7035	41	9B
0005434407866	7035	42	9E
0005434407873	7035	43	9D
0005435293174	7035	44	9F
0005434407881	7035	45	10B
0005434299619	7035	46	10D
0005435310980	7035	47	10C
0005434407867	7035	48	10E
0005434407891	7035	49	11A
0005434407907	7035	50	11B
0005434407888	7035	51	11D
0005434407868	7035	52	11C
0005435293169	7035	53	11E
0005434407926	7035	54	11F
0005434407895	7035	55	12A
0005434407929	7035	56	12C
0005434299607	7035	57	12B
0005434407893	7035	58	12D
0005432108256	7035	59	12E
0005434299599	7035	60	13A
0005434407890	7035	61	12F
0005432153954	7035	62	13B
0005434407898	7035	63	13C
0005435310899	7035	64	13D
0005434407918	7035	65	13E
0005434407925	7035	66	13F
0005434407896	7035	67	14A
0005434407871	7035	68	14B
0005435293148	7035	69	14D
0005434407894	7035	70	14C
0005434407879	7035	71	14E
0005434407870	7035	72	14F
0005434407903	7035	73	15B
0005434407909	7035	74	15A
0005434407910	7035	75	15C
0005432108254	7035	76	15D
0005434299620	7035	77	15F
0005434299611	7035	78	15E
0005435293168	7035	79	16A
0005434299617	7035	80	16C
0005434407916	7035	81	16B
0005434407913	7035	82	16E
0005435293191	7035	83	16D
0005434407912	7035	84	16F
0005434407883	7035	85	17A
0005434407899	7035	86	17C
0005434407928	7035	87	17E
0005435293149	7035	88	17D
0005434407884	7035	89	17F
0005432153949	7035	90	18A
0005434299601	7035	91	18B
0005432153955	7035	92	18C
0005434407877	7035	93	18D
0005434407875	7035	94	18F
0005434299613	7035	95	18E
0005434407917	7035	96	19A
0005434407905	7035	97	19B
0005434407869	7035	98	19D
0005434407924	7035	99	19C
0005435310958	7035	100	19E
0005434407874	7035	101	19F
0005434407880	7035	102	20A
0005434299603	7035	103	20B
0005435310959	7035	104	20C
0005434299608	7035	105	20E
0005432153951	7035	106	20F
0005432153950	7035	107	21B
0005435310935	7035	108	21D
0005434407886	7035	109	21C
0005434299604	7035	110	21F
0005434407878	7035	111	21E
0005434299616	7035	112	22A
0005435310966	7035	113	22B
0005434407914	7035	114	22D
0005434407901	7035	115	22C
0005434407915	7035	116	22E
0005434407908	7035	117	22F
0005434407892	7035	118	23B
0005434299609	7035	119	23A
0005434407872	7035	120	23C
0005434407906	7035	121	23D
0005434407921	7035	122	23E
0005434299612	7035	123	23F
0005434299448	26906	1	1A
0005435293283	26906	2	1C
0005432058387	26906	3	1D
0005434407084	26906	4	1F
0005434407529	26906	5	2C
0005435293282	26906	6	2D
0005434299410	26906	7	2F
0005435311084	26906	8	3C
0005435293284	26906	9	3A
0005434407030	26906	10	3D
0005434407380	26906	11	3F
0005435311085	26906	12	4B
0005435293277	26906	13	4A
0005434299457	26906	14	4D
0005434407082	26906	15	4C
0005434299449	26906	16	4E
0005434407214	26906	17	5A
0005435293274	26906	18	4F
0005434299418	26906	19	5B
0005434406922	26906	20	5C
0005434407331	26906	21	5D
0005434407528	26906	22	5F
0005434407642	26906	23	5E
0005434407354	26906	24	6A
0005434299402	26906	25	6C
0005434407496	26906	26	6F
0005434407220	26906	27	6E
0005435293280	26906	28	7B
0005434407091	26906	29	7A
0005434407157	26906	30	7C
0005434299435	26906	31	7E
0005434299523	26906	32	7D
0005434407420	26906	33	7F
0005434299417	26906	34	8A
0005435293276	26906	35	8D
0005434407310	26906	36	8C
0005434407129	26906	37	8E
0005434407034	26906	38	8F
0005434407032	26906	39	9A
0005434299395	26906	40	9B
0005434407470	26906	41	9D
0005434407035	26906	42	9C
0005435311083	26906	43	9E
0005435293279	26906	44	9F
0005434299386	26906	45	10B
0005434407104	26906	46	10C
0005435311078	26906	47	10E
0005435311081	26906	48	11A
0005434299385	26906	49	11B
0005434299447	26906	50	11D
0005435293285	26906	51	11C
0005434299430	26906	52	11E
0005434407258	26906	53	11F
0005434407083	26906	54	12A
0005434407483	26906	55	12B
0005434407092	26906	56	12D
0005434407163	26906	57	12C
0005434407010	26906	58	13A
0005434407330	26906	59	12F
0005434299482	26906	60	13C
0005434407308	26906	61	13B
0005434407139	26906	62	13D
0005434407158	26906	63	13E
0005434407254	26906	64	14A
0005434407289	26906	65	13F
0005435293275	26906	66	14C
0005434407197	26906	67	14D
0005434407218	26906	68	14E
0005434407286	26906	69	14F
0005435311082	26906	70	15A
0005432058386	26906	71	15C
0005434407088	26906	72	15D
0005434407641	26906	73	15F
0005434407215	26906	74	16A
0005434407316	26906	75	16C
0005434299483	26906	76	16E
0005434299422	26906	77	17A
0005434299440	26906	78	16F
0005434299466	26906	79	17B
0005434407119	26906	80	17C
0005434407209	26906	81	17D
0005434407219	26906	82	17E
0005434407297	26906	83	18A
0005432058388	26906	84	17F
0005434407530	26906	85	18B
0005434299500	26906	86	18C
0005434407309	26906	87	18E
0005434299450	26906	88	18D
0005434299420	26906	89	18F
0005435311080	26906	90	19A
0005434407643	26906	91	19C
0005434407332	26906	92	19B
0005434407123	26906	93	19D
0005434407140	26906	94	19E
0005435293278	26906	95	20B
0005435293281	26906	96	20A
0005434407395	26906	97	20C
0005435311087	26906	98	20D
0005435311079	26906	99	20E
0005434407374	26906	100	20F
0005434407375	26906	101	21B
0005434407031	26906	102	21A
0005434299441	26906	103	21C
0005434407206	26906	104	21D
0005434407359	26906	105	21F
0005434407436	26906	106	21E
0005434407307	26906	107	22B
0005434406921	26906	108	22C
0005434407120	26906	109	22D
0005435311086	26906	110	22E
0005434407257	26906	111	23A
0005434299463	26906	112	23B
0005434407009	26906	113	23C
0005434407333	26906	114	23E
0005434407290	26906	115	23D
0005434407164	26906	116	23F
0005432604425	6484	1	1A
0005432604416	6484	2	1B
0005432604435	6484	3	1C
0005432604437	6484	4	1D
0005432604450	6484	5	2A
0005432604417	6484	6	2C
0005432604452	6484	7	2D
0005432604428	6484	8	3A
0005432604429	6484	9	3B
0005432604418	6484	10	3C
0005432604446	6484	11	3D
0005432604449	6484	12	4A
0005432604451	6484	13	4C
0005432604413	6484	14	4D
0005432604422	6484	15	5B
0005432604444	6484	16	5A
0005432604445	6484	17	5C
0005432604439	6484	18	5D
0005432604414	6484	19	6B
0005432604440	6484	20	6C
0005432604448	6484	21	6D
0005432604427	6484	22	7A
0005432604412	6484	23	7C
0005432604441	6484	24	7D
0005432604438	6484	25	18B
0005432604420	6484	26	18C
0005435218108	6484	27	18D
0005432604415	6484	28	19A
0005432604419	6484	29	19B
0005432604426	6484	30	19C
0005432604436	6484	31	19D
0005432604421	6484	32	20A
0005432604442	6484	33	20B
0005432604432	6484	34	20C
0005432604423	6484	35	20D
0005432604424	6484	36	21A
0005432604430	6484	37	21B
0005435218109	6484	38	21C
0005432604431	6484	39	21D
0005432604434	6484	40	22A
0005432604443	6484	41	22B
0005432604433	6484	42	22C
0005432604447	6484	43	23A
0005432604029	21357	1	1A
0005432604074	21357	2	1B
0005432603960	21357	3	1C
0005432604146	21357	4	1D
0005432604055	21357	5	2A
0005432603955	21357	6	2B
0005432604032	21357	7	2C
0005432603974	21357	8	2D
0005432603973	21357	9	3A
0005432604041	21357	10	3B
0005432604143	21357	11	3C
0005432604056	21357	12	3D
0005432603959	21357	13	4A
0005432604042	21357	14	4B
0005432604179	21357	15	4C
0005432603984	21357	16	4D
0005434512084	21357	17	5A
0005432604047	21357	18	5B
0005435221516	21357	19	5C
0005435221054	21357	20	5D
0005434512110	21357	21	6A
0005432603966	21357	22	6B
0005435221056	21357	23	6C
0005432604018	21357	24	6D
0005432603905	21357	25	7A
0005432603930	21357	26	7B
0005432604060	21357	27	7C
0005432604043	21357	28	7D
0005434512072	21357	29	18A
0005434512100	21357	30	18B
0005432603987	21357	31	18C
0005434512111	21357	32	18D
0005435221055	21357	33	19A
0005432604059	21357	34	19B
0005434512106	21357	35	19C
0005432604054	21357	36	19D
0005432604201	21357	37	20A
0005434512089	21357	38	20B
0005432604031	21357	39	20C
0005432604226	21357	40	20D
0005432603983	21357	41	21A
0005432603967	21357	42	21B
0005432604153	21357	43	21C
0005432604030	21357	44	21D
0005432604168	21357	45	22A
0005434512082	21357	46	22C
0005432603869	21357	47	22B
0005432604154	21357	48	22D
0005432604167	21357	49	23A
0005432604009	21357	50	23B
0005433251528	15008	1	1A
0005434906864	15008	2	1D
0005433251553	15008	3	1F
0005434906927	15008	4	2A
0005434906804	15008	5	2C
0005434906914	15008	6	2D
0005433251548	15008	7	3A
0005434906858	15008	8	2F
0005434906957	15008	9	3C
0005433251540	15008	10	3D
0005433251552	15008	11	3F
0005433251551	15008	12	4A
0005433251558	15008	13	4C
0005433251557	15008	14	4D
0005433251538	15008	15	4E
0005434906965	15008	16	4F
0005433251546	15008	17	5A
0005434906869	15008	18	5C
0005433251534	15008	19	5D
0005433251545	15008	20	5E
0005434906895	15008	21	5F
0005433251542	15008	22	6C
0005434906832	15008	23	6A
0005433251554	15008	24	6D
0005434906918	15008	25	6E
0005434906928	15008	26	6F
0005434906744	15008	27	7A
0005433251539	15008	28	7C
0005434906635	15008	29	7D
0005433251556	15008	30	7F
0005434906894	15008	31	8A
0005434906896	15008	32	8C
0005433251530	15008	33	8D
0005434906812	15008	34	8E
0005433251544	15008	35	8F
0005434906944	15008	36	9A
0005434906964	15008	37	9C
0005434906553	15008	38	9D
0005433251547	15008	39	9E
0005434906811	15008	40	9F
0005433251535	15008	41	10A
0005434906916	15008	42	10C
0005434906760	15008	43	10E
0005434906856	15008	44	10F
0005434906868	15008	45	11A
0005433251536	15008	46	11C
0005434907014	15008	47	11D
0005433251549	15008	48	11E
0005434906770	15008	49	11F
0005434906838	15008	50	12A
0005434906925	15008	51	12C
0005433251541	15008	52	12D
0005434906855	15008	53	12E
0005434906857	15008	54	12F
0005434906921	15008	55	13A
0005433251537	15008	56	13C
0005434907008	15008	57	13D
0005434906860	15008	58	13F
0005433251531	15008	59	14A
0005433251532	15008	60	14D
0005434906971	15008	61	14E
0005434906890	15008	62	14F
0005434907013	15008	63	15C
0005434906743	15008	64	15D
0005434906764	15008	65	15F
0005433251555	15008	66	16A
0005434906774	15008	67	16C
0005434906555	15008	68	16D
0005434906988	15008	69	16E
0005434907007	15008	70	16F
0005434906763	15008	71	17A
0005433251533	15008	72	17C
0005433251543	15008	73	17D
0005434906919	15008	74	17E
0005434906931	15008	75	17F
0005433251550	15008	76	18C
0005434907047	15008	77	18A
0005434906753	15008	78	18E
0005434906930	15008	79	18F
0005433251559	15008	80	19A
0005434906769	15008	81	19D
0005434906946	15008	82	19E
0005434906870	15008	83	19F
0005434906915	15008	84	20A
0005434906865	15008	85	20C
0005434906636	15008	86	20D
0005433251529	15008	87	20E
0005434906947	15008	88	20F
0005434907350	25868	1	1A
0005433251252	25868	2	1D
0005434907319	25868	3	1F
0005434907327	25868	4	2A
0005433251030	25868	5	2C
0005433251417	25868	6	2D
0005434907366	25868	7	2F
0005434907318	25868	8	3A
0005434907317	25868	9	3C
0005433251269	25868	10	4A
0005433251182	25868	11	4C
0005433251348	25868	12	4D
0005434907329	25868	13	4E
0005434907347	25868	14	4F
0005434907326	25868	15	5A
0005434907368	25868	16	5C
0005434907334	25868	17	5D
0005434907365	25868	18	5E
0005434907345	25868	19	5F
0005434907337	25868	20	6A
0005434907363	25868	21	6C
0005434907369	25868	22	6E
0005434907371	25868	23	6F
0005434907328	25868	24	7A
0005433251270	25868	25	7C
0005433251181	25868	26	7D
0005434907359	25868	27	7E
0005434907343	25868	28	7F
0005434907360	25868	29	8A
0005434907332	25868	30	8C
0005434907316	25868	31	8F
0005433251263	25868	32	9A
0005433251029	25868	33	9C
0005434907321	25868	34	9D
0005434907338	25868	35	9E
0005434907355	25868	36	9F
0005434907370	25868	37	10A
0005434907341	25868	38	10C
0005433251364	25868	39	10E
0005433251288	25868	40	11A
0005433251331	25868	41	11C
0005433251251	25868	42	11D
0005434907336	25868	43	11E
0005434907353	25868	44	12A
0005434907342	25868	45	12C
0005434907339	25868	46	12D
0005434907351	25868	47	12E
0005434907331	25868	48	12F
0005434907325	25868	49	13A
0005434907356	25868	50	13C
0005434907322	25868	51	13D
0005434907344	25868	52	13E
0005434907323	25868	53	13F
0005434907367	25868	54	14A
0005433251248	25868	55	14C
0005434907324	25868	56	14D
0005434907320	25868	57	14E
0005434907354	25868	58	15A
0005433251349	25868	59	15D
0005433251202	25868	60	15E
0005433251237	25868	61	15F
0005434907330	25868	62	16A
0005434907348	25868	63	16C
0005433251201	25868	64	16D
0005434907364	25868	65	16F
0005433251340	25868	66	17A
0005434907358	25868	67	17C
0005433251353	25868	68	17D
0005434907346	25868	69	17E
0005433251183	25868	70	18C
0005434907333	25868	71	18E
0005434907352	25868	72	19A
0005434907335	25868	73	19C
0005434907340	25868	74	19D
0005434907349	25868	75	19E
0005434907357	25868	76	19F
0005434907362	25868	77	20A
0005433251180	25868	78	20C
0005434907361	25868	79	20D
0005433251236	25868	80	20F
0005433810509	14159	1	1A
0005433008725	14159	2	2A
0005433008724	14159	3	2D
0005433008732	14159	4	2F
0005433008744	14159	5	3D
0005433008727	14159	6	4A
0005433008723	14159	7	4C
0005433008710	14159	8	4E
0005433008726	14159	9	5A
0005433008712	14159	10	5C
0005433008722	14159	11	5D
0005433810497	14159	12	5E
0005433008718	14159	13	5F
0005433008730	14159	14	6D
0005433008711	14159	15	6F
0005433008746	14159	16	7A
0005433008745	14159	17	7C
0005433008705	14159	18	7D
0005433008737	14159	19	7E
0005433008704	14159	20	8D
0005433008738	14159	21	8F
0005433008728	14159	22	9A
0005433008743	14159	23	9C
0005433008720	14159	24	9F
0005433008706	14159	25	10A
0005433008719	14159	26	10F
0005433008749	14159	27	11A
0005433008721	14159	28	11C
0005433810511	14159	29	11D
0005433008733	14159	30	11E
0005433008742	14159	31	11F
0005433008717	14159	32	12A
0005433008748	14159	33	12C
0005433008747	14159	34	12D
0005433008715	14159	35	12E
0005433008741	14159	36	13A
0005433810508	14159	37	13D
0005433008735	14159	38	13E
0005433008734	14159	39	13F
0005433810498	14159	40	14C
0005433008703	14159	41	14D
0005433008731	14159	42	14E
0005433008740	14159	43	15C
0005433008709	14159	44	15F
0005433008729	14159	45	16A
0005433008708	14159	46	16F
0005433008736	14159	47	17D
0005433810510	14159	48	18C
0005433008714	14159	49	18D
0005433008716	14159	50	19D
0005433008713	14159	51	20A
0005433008739	14159	52	20D
0005433008707	14159	53	20E
0005433008416	22825	1	1A
0005433008292	22825	2	1C
0005433008236	22825	3	1D
0005433008301	22825	4	1F
0005433810551	22825	5	2A
0005433008377	22825	6	2C
0005433008470	22825	7	2F
0005433008304	22825	8	3A
0005433008237	22825	9	3C
0005433008312	22825	10	4A
0005433008475	22825	11	4E
0005433008270	22825	12	5A
0005433008378	22825	13	5D
0005433008269	22825	14	5F
0005433008303	22825	15	6A
0005433008330	22825	16	6C
0005433008313	22825	17	6D
0005433810554	22825	18	6E
0005433008159	22825	19	6F
0005433008160	22825	20	7A
0005433008418	22825	21	7C
0005433008305	22825	22	7D
0005433008424	22825	23	7E
0005433008421	22825	24	7F
0005433810550	22825	25	8A
0005433008098	22825	26	8C
0005433008294	22825	27	8F
0005433008420	22825	28	9C
0005433008096	22825	29	9D
0005433008518	22825	30	9F
0005433008215	22825	31	10A
0005433008275	22825	32	10C
0005433008398	22825	33	10E
0005433008466	22825	34	11C
0005433008327	22825	35	11F
0005433008158	22825	36	12E
0005433008115	22825	37	13A
0005433008197	22825	38	13C
0005433008362	22825	39	13D
0005433008293	22825	40	13F
0005433008329	22825	41	14A
0005433008471	22825	42	14D
0005433008408	22825	43	14F
0005433008195	22825	44	15F
0005433008220	22825	45	16C
0005433810553	22825	46	17A
0005433810552	22825	47	17C
0005433008255	22825	48	17E
0005433008221	22825	49	17F
0005433008256	22825	50	18A
0005433008419	22825	51	18D
0005433008111	22825	52	19A
0005433008097	22825	53	19C
0005433008271	22825	54	19E
0005433008196	22825	55	19F
0005433008361	22825	56	20E
0005434925545	14908	1	1A
0005434925606	14908	2	1D
0005434925506	14908	3	1F
0005434925505	14908	4	2C
0005434925509	14908	5	2F
0005434925571	14908	6	3D
0005434925507	14908	7	4C
0005434925436	14908	8	4D
0005434925521	14908	9	5D
0005434925586	14908	10	5F
0005434925640	14908	11	6D
0005434925504	14908	12	6E
0005434925533	14908	13	6F
0005434925600	14908	14	7D
0005434925641	14908	15	7E
0005434925592	14908	16	7F
0005434925598	14908	17	8D
0005434925409	14908	18	8E
0005434925596	14908	19	9E
0005434925547	14908	20	9F
0005434925435	14908	21	10D
0005434925563	14908	22	10E
0005434925582	14908	23	11A
0005434925655	14908	24	11C
0005434925483	14908	25	11F
0005434925587	14908	26	12A
0005434925583	14908	27	12C
0005434925501	14908	28	13A
0005434925408	14908	29	13C
0005434925368	14908	30	13F
0005434925645	14908	31	14C
0005434925500	14908	32	14D
0005434925367	14908	33	15A
0005434925567	14908	34	14F
0005434925644	14908	35	15D
0005434925599	14908	36	15E
0005434925561	14908	37	16C
0005434925562	14908	38	16E
0005434925565	14908	39	17A
0005434925534	14908	40	17C
0005434925568	14908	41	17F
0005434925585	14908	42	18C
0005434925566	14908	43	18D
0005434925584	14908	44	18F
0005434925546	14908	45	19C
0005434925603	14908	46	20A
0005434925518	14908	47	20F
0005434925843	20512	1	1C
0005434925849	20512	2	1D
0005434925835	20512	3	2C
0005434925848	20512	4	3D
0005434925856	20512	5	3F
0005434925840	20512	6	4D
0005434925836	20512	7	4E
0005434925847	20512	8	5A
0005434925852	20512	9	5E
0005434925855	20512	10	6C
0005434925842	20512	11	7A
0005434925844	20512	12	7D
0005434925834	20512	13	8C
0005434925837	20512	14	8F
0005434925854	20512	15	9E
0005434925846	20512	16	10C
0005434925832	20512	17	10E
0005434925841	20512	18	13D
0005434925850	20512	19	13E
0005434925845	20512	20	14F
0005434925838	20512	21	15D
0005434925833	20512	22	16C
0005434925851	20512	23	17C
0005434925853	20512	24	19D
0005434925839	20512	25	20E
0005435999122	15840	1	1A
0005435487897	15840	2	1B
0005435487898	15840	3	1C
0005435487875	15840	4	1D
0005435487893	15840	5	2A
0005435487878	15840	6	2B
0005435999096	15840	7	2C
0005435999126	15840	8	2D
0005435487885	15840	9	3A
0005435999094	15840	10	3C
0005435999141	15840	11	4A
0005435487874	15840	12	3D
0005435487896	15840	13	4B
0005435487883	15840	14	4C
0005435999080	15840	15	4D
0005435487887	15840	16	5A
0005435999097	15840	17	5B
0005435487879	15840	18	5C
0005435999133	15840	19	5D
0005435999165	15840	20	6A
0005435999038	15840	21	6B
0005435999090	15840	22	6C
0005435999157	15840	23	6D
0005435487891	15840	24	7A
0005435487892	15840	25	7B
0005435999121	15840	26	7C
0005435487890	15840	27	7D
0005435487895	15840	28	18B
0005435999134	15840	29	18C
0005435999091	15840	30	18D
0005435487880	15840	31	19A
0005435999163	15840	32	19B
0005435487884	15840	33	19C
0005435487894	15840	34	19D
0005435999151	15840	35	20A
0005435999123	15840	36	20B
0005435999150	15840	37	20D
0005435487877	15840	38	21A
0005435487882	15840	39	21B
0005435487876	15840	40	21C
0005435487886	15840	41	21D
0005435487881	15840	42	22A
0005435999037	15840	43	22B
0005435999162	15840	44	22C
0005435487888	15840	45	22D
0005435487889	15840	46	23A
0005435999039	15840	47	23B
0005435999276	19698	1	1B
0005435999269	19698	2	1C
0005435487709	19698	3	2C
0005435487651	19698	4	2D
0005435999271	19698	5	3A
0005435487561	19698	6	3C
0005435487629	19698	7	3D
0005435487601	19698	8	4A
0005435487603	19698	9	4D
0005435999273	19698	10	6A
0005435487641	19698	11	6B
0005435999268	19698	12	6C
0005435487677	19698	13	7A
0005435999279	19698	14	7B
0005435487667	19698	15	7D
0005435487628	19698	16	18A
0005435999270	19698	17	18B
0005435487684	19698	18	19B
0005435999267	19698	19	19D
0005435487691	19698	20	20A
0005435487602	19698	21	20B
0005435487627	19698	22	20C
0005435999278	19698	23	20D
0005435999274	19698	24	21A
0005435999266	19698	25	21B
0005435999277	19698	26	21C
0005435999272	19698	27	21D
0005435487708	19698	28	22B
0005435487663	19698	29	22D
0005435999275	19698	30	23A
0005435472618	5991	1	1C
0005435839517	5991	2	1F
0005435839506	5991	3	1D
0005435839531	5991	4	2F
0005435839511	5991	5	2D
0005432659714	5991	6	2C
0005432658597	5991	7	3C
0005435472695	5991	8	3F
0005435472703	5991	9	4D
0005432660823	5991	10	4F
0005435839533	5991	11	5C
0005435472717	5991	12	6B
0005432142261	5991	13	6A
0005435839529	5991	14	6D
0005432537040	5991	15	6C
0005435839518	5991	16	6F
0005435839522	5991	17	7C
0005435839528	5991	18	7E
0005435839513	5991	19	7D
0005435839521	5991	20	8C
0005435839516	5991	21	8B
0005435472636	5991	22	8A
0005432658596	5991	23	8D
0005432142259	5991	24	8E
0005435472719	5991	25	9A
0005435472669	5991	26	9C
0005435839519	5991	27	9D
0005435839515	5991	28	10A
0005432658598	5991	29	10B
0005435472746	5991	30	11A
0005435839523	5991	31	11D
0005435839526	5991	32	11F
0005435472740	5991	33	11E
0005435839509	5991	34	12B
0005435839507	5991	35	12A
0005435839505	5991	36	12D
0005435839527	5991	37	12C
0005435839525	5991	38	13A
0005432142258	5991	39	13C
0005435472769	5991	40	13B
0005432537041	5991	41	14A
0005432659711	5991	42	13F
0005435472687	5991	43	14B
0005435839510	5991	44	14C
0005435472688	5991	45	15C
0005435472660	5991	46	15E
0005435839514	5991	47	16A
0005435839530	5991	48	15F
0005432659712	5991	49	16C
0005435472747	5991	50	16E
0005435839524	5991	51	17E
0005435839532	5991	52	18C
0005435839508	5991	53	18B
0005432659713	5991	54	18D
0005435472702	5991	55	19C
0005435472739	5991	56	19D
0005435472670	5991	57	19E
0005435472720	5991	58	20C
0005435472696	5991	59	20B
0005432660824	5991	60	20D
0005432537045	5991	61	20F
0005435839520	5991	62	21A
0005435472768	5991	63	21D
0005432142260	5991	64	21C
0005435839512	5991	65	21F
0005435472842	18054	1	1A
0005435839287	18054	2	1F
0005435839306	18054	3	2D
0005432660801	18054	4	4A
0005435839356	18054	5	3F
0005435839309	18054	6	4C
0005432660803	18054	7	5F
0005435839328	18054	8	5D
0005435472832	18054	9	6A
0005435839233	18054	10	6D
0005435839295	18054	11	6B
0005432537064	18054	12	6E
0005435472834	18054	13	7E
0005435839415	18054	14	8B
0005435839245	18054	15	8E
0005435472843	18054	16	9B
0005435472844	18054	17	9D
0005435839189	18054	18	9C
0005432667434	18054	19	9F
0005435839323	18054	20	10B
0005435839277	18054	21	10D
0005435472836	18054	22	11A
0005435472833	18054	23	10F
0005432660799	18054	24	10E
0005432664117	18054	25	11B
0005435839246	18054	26	11D
0005435839322	18054	27	12B
0005432660800	18054	28	12E
0005435472846	18054	29	12D
0005435839244	18054	30	13C
0005435472837	18054	31	13E
0005435839276	18054	32	13D
0005435472840	18054	33	14B
0005432667443	18054	34	14A
0005435839294	18054	35	14F
0005435472841	18054	36	15E
0005432537063	18054	37	15D
0005435472847	18054	38	16A
0005435839286	18054	39	15F
0005435472839	18054	40	16C
0005432660797	18054	41	16D
0005435839302	18054	42	17A
0005435472848	18054	43	17B
0005435472845	18054	44	17D
0005435472838	18054	45	17C
0005435839243	18054	46	18B
0005435839305	18054	47	18E
0005435839234	18054	48	18D
0005435839355	18054	49	19B
0005435839331	18054	50	19E
0005435839252	18054	51	20C
0005435839340	18054	52	20F
0005435839329	18054	53	20E
0005435839114	18054	54	21A
0005435472835	18054	55	21C
0005432667439	18054	56	21E
0005435839327	18054	57	21F
0005433285131	23000	1	1C
0005433285067	23000	2	2C
0005433285023	23000	3	4A
0005433285203	23000	4	4D
0005435103943	23000	5	4E
0005433285085	23000	6	5D
0005435103949	23000	7	7E
0005433285156	23000	8	8E
0005433285147	23000	9	9B
0005433285241	23000	10	9D
0005433285225	23000	11	9E
0005433285093	23000	12	10B
0005433284998	23000	13	10D
0005433285070	23000	14	11C
0005435103948	23000	15	11E
0005433285132	23000	16	11F
0005435103946	23000	17	12D
0005435103944	23000	18	12E
0005433285068	23000	19	13A
0005433285297	23000	20	13B
0005433285145	23000	21	14A
0005433285216	23000	22	14C
0005433285020	23000	23	14E
0005433284980	23000	24	15A
0005433285226	23000	25	15B
0005433284997	23000	26	15D
0005433285231	23000	27	15F
0005433285019	23000	28	16D
0005433285082	23000	29	16F
0005435103942	23000	30	17F
0005433285092	23000	31	17E
0005433285202	23000	32	18A
0005433285106	23000	33	18B
0005433285230	23000	34	18E
0005435103945	23000	35	19C
0005433285192	23000	36	20E
0005433285122	23000	37	21A
0005433285133	23000	38	21D
0005435103947	23000	39	21F
0005433285083	23000	40	21E
0005433285387	32081	1	1A
0005433285391	32081	2	2A
0005433285379	32081	3	3C
0005433285371	32081	4	4C
0005433285386	32081	5	4F
0005433285383	32081	6	5F
0005433285381	32081	7	6E
0005433285372	32081	8	7A
0005433285389	32081	9	7B
0005433285382	32081	10	7F
0005433285363	32081	11	9A
0005433285362	32081	12	9C
0005433285368	32081	13	9E
0005433285370	32081	14	9D
0005433285359	32081	15	10C
0005433285377	32081	16	11B
0005433285365	32081	17	11F
0005433285375	32081	18	12A
0005433285366	32081	19	12E
0005433285380	32081	20	13C
0005433285373	32081	21	15A
0005433285378	32081	22	15F
0005433285376	32081	23	15E
0005433285374	32081	24	16D
0005433285384	32081	25	16E
0005435103842	32081	26	17C
0005433285360	32081	27	18B
0005433285390	32081	28	19A
0005433285361	32081	29	20A
0005433285369	32081	30	21D
0005435103843	32081	31	22C
0005433285364	32081	32	22B
0005433285367	32081	33	22D
0005433285385	32081	34	22F
0005433285388	32081	35	23C
0005433475681	23878	1	1D
0005433475683	23878	2	2B
0005433475675	23878	3	2D
0005433475667	23878	4	4B
0005435852581	23878	5	4D
0005435852579	23878	6	5B
0005433475653	23878	7	5C
0005433475668	23878	8	6C
0005433475657	23878	9	6D
0005433475671	23878	10	18A
0005435852580	23878	11	18B
0005433475684	23878	12	18D
0005433475652	23878	13	19A
0005433475693	23878	14	19C
0005433475674	23878	15	20A
0005433475658	23878	16	20B
0005435852582	23878	17	20D
0005433475670	23878	18	21B
0005435852583	23878	19	22B
0005432527461	30590	1	1C
0005435213735	30590	2	1A
0005434067368	30590	3	1G
0005432527112	30590	4	1D
0005435213785	30590	5	2C
0005432526940	30590	6	2G
0005432527418	30590	7	3A
0005434067028	30590	8	2K
0005432527660	30590	9	2H
0005435213780	30590	10	3G
0005432526806	30590	11	4A
0005434067443	30590	12	3K
0005434067166	30590	13	4G
0005435213773	30590	14	4C
0005435213746	30590	15	4K
0005435213784	30590	16	4H
0005432527375	30590	17	5C
0005435213747	30590	18	5A
0005432527134	30590	19	5G
0005432527770	30590	20	5D
0005434067338	30590	21	11A
0005434067016	30590	22	5H
0005435213743	30590	23	11D
0005434067140	30590	24	11C
0005435725615	30590	25	11G
0005435213738	30590	26	11F
0005435213775	30590	27	11E
0005434067231	30590	28	12A
0005432428901	30590	29	11K
0005432526764	30590	30	12G
0005434067150	30590	31	12F
0005435213741	30590	32	12K
0005432526650	30590	33	13A
0005434067185	30590	34	13F
0005434067128	30590	35	13H
0005432527481	30590	36	13G
0005432527499	30590	37	14A
0005435213744	30590	38	14D
0005432527706	30590	39	14C
0005434067375	30590	40	14F
0005435283409	30590	41	14E
0005435630976	30590	42	14G
0005432527046	30590	43	15C
0005435213769	30590	44	15A
0005435213740	30590	45	14K
0005434067206	30590	46	15F
0005435213762	30590	47	15E
0005432527515	30590	48	15D
0005435213751	30590	49	15G
0005435213760	30590	50	15K
0005435213779	30590	51	15H
0005434066976	30590	52	16C
0005434067337	30590	53	16A
0005432527127	30590	54	16F
0005432527750	30590	55	16E
0005432526990	30590	56	16K
0005435213782	30590	57	16H
0005432527543	30590	58	16G
0005432526989	30590	59	17E
0005434067165	30590	60	17D
0005434067194	30590	61	17C
0005434067413	30590	62	17G
0005432527445	30590	63	17F
0005434066958	30590	64	17K
0005435213763	30590	65	18B
0005435725618	30590	66	18A
0005435630977	30590	67	18D
0005435213755	30590	68	18C
0005434067098	30590	69	18J
0005432526776	30590	70	18H
0005432527440	30590	71	19C
0005432527509	30590	72	19B
0005435213752	30590	73	19G
0005434067369	30590	74	19F
0005432527508	30590	75	19E
0005432428891	30590	76	19D
0005432159873	30590	77	20A
0005434067049	30590	78	19K
0005432526961	30590	79	19J
0005435213748	30590	80	20C
0005435725616	30590	81	20B
0005434067029	30590	82	20E
0005432527061	30590	83	20D
0005432527767	30590	84	20H
0005435213754	30590	85	20G
0005432526713	30590	86	20F
0005432211524	30590	87	20J
0005434067137	30590	88	21A
0005432535810	30590	89	21D
0005432526651	30590	90	21C
0005434067057	30590	91	21B
0005432527490	30590	92	21F
0005432527383	30590	93	21E
0005435213734	30590	94	21J
0005435213723	30590	95	21H
0005432527444	30590	96	21G
0005432527290	30590	97	22A
0005435213758	30590	98	21K
0005435213745	30590	99	22D
0005435213750	30590	100	22C
0005434067135	30590	101	22B
0005435213728	30590	102	22E
0005435213730	30590	103	22H
0005434067164	30590	104	22G
0005433656681	30590	105	22F
0005432527130	30590	106	22J
0005434067152	30590	107	23B
0005435725617	30590	108	23A
0005435213720	30590	109	23D
0005432527185	30590	110	23C
0005432159870	30590	111	23F
0005434067138	30590	112	23H
0005434067153	30590	113	23K
0005435213765	30590	114	23J
0005434067258	30590	115	24F
0005432527493	30590	116	24E
0005435213753	30590	117	25D
0005432526725	30590	118	25B
0005432526801	30590	119	25F
0005432526888	30590	120	25G
0005432527768	30590	121	25K
0005435213721	30590	122	26B
0005432527769	30590	123	26A
0005434067139	30590	124	26D
0005434067119	30590	125	26C
0005435213719	30590	126	26G
0005435213725	30590	127	26F
0005432211521	30590	128	26K
0005435213783	30590	129	26J
0005432527441	30590	130	26H
0005434066915	30590	131	27A
0005434067077	30590	132	27D
0005434067294	30590	133	27B
0005432526741	30590	134	27F
0005432527126	30590	135	27E
0005435213736	30590	136	27H
0005433656682	30590	137	27G
0005432526659	30590	138	28A
0005435213729	30590	139	27K
0005432537039	30590	140	27J
0005435213727	30590	141	28E
0005435213768	30590	142	28D
0005432527708	30590	143	28G
0005434067154	30590	144	28F
0005434067129	30590	145	28H
0005434067099	30590	146	29B
0005432527278	30590	147	29A
0005432526915	30590	148	29D
0005434066869	30590	149	29C
0005432527286	30590	150	29F
0005432527435	30590	151	29E
0005432527113	30590	152	29H
0005435213766	30590	153	29G
0005435283410	30590	154	29K
0005434067120	30590	155	30A
0005432527529	30590	156	30E
0005432527133	30590	157	30D
0005435630978	30590	158	30C
0005434067367	30590	159	30J
0005432526775	30590	160	30H
0005434066696	30590	161	31A
0005432527305	30590	162	31D
0005434067118	30590	163	31C
0005432527491	30590	164	31B
0005432527087	30590	165	31F
0005432526887	30590	166	31E
0005432159871	30590	167	31J
0005432527577	30590	168	31H
0005432526602	30590	169	31G
0005432527060	30590	170	32A
0005434067142	30590	171	31K
0005435213781	30590	172	32E
0005432527766	30590	173	32D
0005435213726	30590	174	33B
0005432535804	30590	175	33A
0005432527421	30590	176	33C
0005435213757	30590	177	33G
0005432526988	30590	178	33K
0005432526917	30590	179	34C
0005432527155	30590	180	34B
0005432527156	30590	181	34D
0005432526652	30590	182	34F
0005432211526	30590	183	34K
0005432527211	30590	184	34J
0005434066983	30590	185	35A
0005435213756	30590	186	35D
0005435213716	30590	187	35C
0005432527707	30590	188	35G
0005432428914	30590	189	35H
0005434067078	30590	190	35K
0005432527200	30590	191	35J
0005432211522	30590	192	36C
0005432527551	30590	193	36B
0005432527645	30590	194	36A
0005435213715	30590	195	36F
0005432527291	30590	196	36E
0005432526985	30590	197	36K
0005432527170	30590	198	36J
0005434066945	30590	199	37A
0005435213742	30590	200	37D
0005434066960	30590	201	37F
0005432527086	30590	202	37H
0005434067136	30590	203	37G
0005432526760	30590	204	38A
0005435213778	30590	205	37J
0005434066864	30590	206	38C
0005434067059	30590	207	38B
0005435213764	30590	208	38J
0005432527590	30590	209	38H
0005432527129	30590	210	39B
0005435213737	30590	211	39D
0005432527059	30590	212	39C
0005432211523	30590	213	39G
0005432527217	30590	214	40A
0005434067377	30590	215	39K
0005434067376	30590	216	39J
0005433656683	30590	217	40C
0005432527171	30590	218	40B
0005435213774	30590	219	40E
0005432526916	30590	220	40D
0005435213733	30590	221	40H
0005435213771	30590	222	40F
0005432527357	30590	223	40K
0005435213772	30590	224	40J
0005435725614	30590	225	41B
0005432527482	30590	226	41D
0005432527492	30590	227	41F
0005432527542	30590	228	41J
0005435213767	30590	229	41H
0005432527501	30590	230	41G
0005432428900	30590	231	42A
0005434067295	30590	232	41K
0005435213777	30590	233	42C
0005435213724	30590	234	42E
0005434067147	30590	235	42D
0005432526984	30590	236	42G
0005434067048	30590	237	43A
0005435213722	30590	238	42K
0005432527376	30590	239	43D
0005434067427	30590	240	43C
0005435213732	30590	241	43B
0005432211525	30590	242	43F
0005435213731	30590	243	43G
0005435213739	30590	244	43J
0005432527374	30590	245	44B
0005432526982	30590	246	44E
0005432527151	30590	247	44D
0005435213776	30590	248	44G
0005432527139	30590	249	44F
0005432159872	30590	250	44K
0005434067095	30590	251	44J
0005432527302	30590	252	44H
0005434067058	30590	253	45B
0005432527910	30590	254	45A
0005432526796	30590	255	45D
0005434066862	30590	256	45C
0005432527161	30590	257	45H
0005435213718	30590	258	45G
0005434067105	30590	259	45K
0005435213759	30590	260	45J
0005435213770	30590	261	46C
0005432527402	30590	262	46B
0005432527500	30590	263	46A
0005433656680	30590	264	46G
0005432527576	30590	265	46F
0005432527183	30590	266	47E
0005435630975	30590	267	47C
0005435213761	30590	268	47F
0005435213749	30590	269	47K
0005432527152	30590	270	47H
0005432535803	30590	271	48C
0005432535811	30590	272	48A
0005434067290	30590	273	48E
0005432527306	30590	274	48D
0005432527552	30590	275	48H
0005432527128	30590	276	48G
0005435213717	30590	277	48F
0005432159869	30590	278	48K
0005434067141	30590	279	49E
0005432527434	30590	280	49D
0005432428890	30590	281	49C
0005434066865	30590	282	49G
0005434067056	30590	283	49K
0005432527117	30590	284	50A
0005432527565	30590	285	50E
0005432428902	30590	286	50D
0005432527135	30590	287	50G
0005432527184	30590	288	50K
0005434067053	30590	289	51E
0005432527201	30590	290	51D
0005433368025	24873	1	1A
0005435652713	24873	2	1C
0005433368009	24873	3	1D
0005433367990	24873	4	1F
0005433368020	24873	5	2A
0005435652791	24873	6	2C
0005435652682	24873	7	2D
0005435652667	24873	8	2F
0005435652543	24873	9	3A
0005433368015	24873	10	3C
0005435652759	24873	11	3D
0005435652741	24873	12	3F
0005435652710	24873	13	4A
0005435652544	24873	14	4C
0005433367999	24873	15	4D
0005433368017	24873	16	4E
0005433368023	24873	17	5A
0005433368018	24873	18	5C
0005435652672	24873	19	5D
0005433368005	24873	20	5E
0005435652698	24873	21	5F
0005433368022	24873	22	6A
0005435652674	24873	23	6C
0005435652725	24873	24	6D
0005433367993	24873	25	6E
0005435652758	24873	26	6F
0005433368007	24873	27	7A
0005435652669	24873	28	7C
0005433368003	24873	29	7F
0005433368014	24873	30	8A
0005435652772	24873	31	8C
0005435652695	24873	32	8D
0005435652699	24873	33	8F
0005435652687	24873	34	9A
0005433367988	24873	35	9C
0005433368019	24873	36	9D
0005435652521	24873	37	9E
0005433368002	24873	38	9F
0005433367994	24873	39	10A
0005433367987	24873	40	10C
0005435652666	24873	41	10E
0005433368010	24873	42	10F
0005433367996	24873	43	11A
0005435652760	24873	44	11C
0005435652643	24873	45	11D
0005433367997	24873	46	11E
0005433367989	24873	47	11F
0005435652557	24873	48	12A
0005435652733	24873	49	12C
0005435652720	24873	50	12D
0005435652719	24873	51	12E
0005435652768	24873	52	12F
0005433368001	24873	53	13A
0005433368016	24873	54	13C
0005433367991	24873	55	13D
0005435652781	24873	56	13E
0005433368006	24873	57	13F
0005435652715	24873	58	14A
0005435652556	24873	59	14C
0005435652675	24873	60	14D
0005433368000	24873	61	14E
0005433368011	24873	62	14F
0005435652586	24873	63	15D
0005433367992	24873	64	15C
0005433368021	24873	65	15E
0005433367998	24873	66	15F
0005435652673	24873	67	16A
0005435652692	24873	68	16C
0005433368012	24873	69	16D
0005435652780	24873	70	16E
0005435652559	24873	71	16F
0005435652792	24873	72	17A
0005435652740	24873	73	17C
0005433367995	24873	74	17D
0005435652668	24873	75	17E
0005435652491	24873	76	17F
0005433368004	24873	77	18A
0005435652585	24873	78	18C
0005433368024	24873	79	18D
0005435652694	24873	80	18E
0005435652714	24873	81	18F
0005435652520	24873	82	19A
0005433368008	24873	83	19C
0005435652789	24873	84	19E
0005435652756	24873	85	19F
0005433368013	24873	86	20A
0005435652726	24873	87	20C
0005435652519	24873	88	20D
0005435652771	24873	89	20E
0005435652751	24873	90	20F
0005435949789	6601	1	6B
0005435949787	6601	2	6D
0005435949788	6601	3	7A
0005435949786	6601	4	7B
0005435949784	6601	5	18C
0005435949783	6601	6	20B
0005435949785	6601	7	21A
0005435949790	6601	8	21C
0005435949791	6601	9	23B
0005434979881	2052	1	1A
0005434979876	2052	2	1B
0005434979891	2052	3	1C
0005434979879	2052	4	2A
0005434979890	2052	5	2C
0005434979867	2052	6	2D
0005435801706	2052	7	3A
0005434979877	2052	8	4A
0005434979886	2052	9	4B
0005434979868	2052	10	4C
0005434979880	2052	11	4D
0005434979892	2052	12	5A
0005434979883	2052	13	5B
0005434979888	2052	14	5C
0005434979871	2052	15	5D
0005434979875	2052	16	6A
0005434979889	2052	17	6C
0005434979887	2052	18	6D
0005434979884	2052	19	7A
0005434979869	2052	20	7B
0005434979894	2052	21	7D
0005434979885	2052	22	18A
0005434979878	2052	23	18D
0005434979882	2052	24	19A
0005434979897	2052	25	19C
0005434979872	2052	26	20A
0005434979895	2052	27	20C
0005434979870	2052	28	21A
0005434979896	2052	29	21B
0005434979873	2052	30	22B
0005434979893	2052	31	22C
0005434979874	2052	32	23A
0005434979643	23540	1	1A
0005434979447	23540	2	1B
0005434979588	23540	3	2A
0005434979473	23540	4	2C
0005434979644	23540	5	2D
0005434979630	23540	6	3A
0005434979645	23540	7	4A
0005434979631	23540	8	4B
0005434979609	23540	9	4C
0005434979520	23540	10	6A
0005435801665	23540	11	6C
0005434979629	23540	12	7C
0005434979569	23540	13	18A
0005434979469	23540	14	18B
0005434979519	23540	15	19A
0005434979472	23540	16	19D
0005435801676	23540	17	20A
0005434979656	23540	18	20B
0005434979517	23540	19	21C
0005434979524	23540	20	21D
0005435801677	23540	21	22A
0005435801666	23540	22	22C
0005434979468	23540	23	22D
0005434979564	23540	24	23B
0005434952542	2637	1	1A
0005434952545	2637	2	2A
0005434952544	2637	3	6A
0005434952543	2637	4	5B
0005433256403	2636	1	2A
0005433256417	2636	2	2B
0005433256414	2636	3	3A
0005433256404	2636	4	3B
0005434952519	28262	1	1A
0005434952504	28262	2	1B
0005433256428	28262	3	3A
0005434952518	28262	4	3B
0005433256429	28262	5	4A
0005434952516	28262	6	4B
0005434952510	28262	7	5A
0005434952517	28262	8	5B
0005434952511	28262	9	6A
0005433111513	19746	1	2A
0005433112380	19746	2	1B
0005433111512	19746	3	2B
0005433111514	19746	4	3A
0005433112381	19746	5	5B
0005434137658	11953	1	1A
0005434137889	11953	2	1C
0005434137555	11953	3	1D
0005434137563	11953	4	1F
0005434137633	11953	5	2A
0005434137745	11953	6	2C
0005434137692	11953	7	2F
0005434137243	11953	8	3A
0005434137660	11953	9	3C
0005434137245	11953	10	3D
0005434137870	11953	11	3F
0005434137659	11953	12	4C
0005434137423	11953	13	4E
0005434137681	11953	14	4F
0005434137785	11953	15	5A
0005434137761	11953	16	5C
0005434137859	11953	17	5D
0005434137449	11953	18	5E
0005434137850	11953	19	5F
0005434137691	11953	20	6A
0005434137377	11953	21	6C
0005434137857	11953	22	6D
0005434137800	11953	23	6E
0005434137754	11953	24	6F
0005434137695	11953	25	7C
0005434137792	11953	26	7D
0005434137611	11953	27	7F
0005434137573	11953	28	8A
0005434137568	11953	29	8C
0005434137637	11953	30	8D
0005434137703	11953	31	8F
0005434137495	11953	32	9C
0005434137518	11953	33	9D
0005434137442	11953	34	9F
0005434137744	11953	35	10A
0005434137592	11953	36	10C
0005434137672	11953	37	10E
0005434137725	11953	38	10F
0005434137582	11953	39	11A
0005434137696	11953	40	11C
0005434137802	11953	41	11D
0005434137847	11953	42	11E
0005434137634	11953	43	12A
0005434137523	11953	44	12C
0005434137840	11953	45	12E
0005434137690	11953	46	12F
0005434137567	11953	47	13A
0005434137849	11953	48	13C
0005434137540	11953	49	13D
0005434137878	11953	50	13E
0005434137845	11953	51	13F
0005434137583	11953	52	14A
0005434137654	11953	53	14C
0005434137755	11953	54	14D
0005434137799	11953	55	14F
0005434137376	11953	56	15A
0005434137752	11953	57	15C
0005434137614	11953	58	15D
0005434137336	11953	59	15F
0005434137677	11953	60	16A
0005434137865	11953	61	16C
0005434137564	11953	62	16D
0005434137556	11953	63	16E
0005434137359	11953	64	16F
0005434137671	11953	65	17A
0005434137839	11953	66	17D
0005434137524	11953	67	17E
0005434137788	11953	68	17F
0005434137676	11953	69	18A
0005434137584	11953	70	18C
0005434137244	11953	71	18D
0005434137818	11953	72	18F
0005434137743	11953	73	19A
0005434137773	11953	74	19C
0005434137762	11953	75	19D
0005434137786	11953	76	19E
0005434137789	11953	77	19F
0005434137879	11953	78	20A
0005434137794	11953	79	20C
0005434137429	11953	80	20F
0005434137653	11953	81	20E
0005434138317	28749	1	1A
0005434138335	28749	2	1C
0005434138331	28749	3	1D
0005434138316	28749	4	1F
0005434138342	28749	5	2D
0005434138310	28749	6	2F
0005434138385	28749	7	3A
0005434138364	28749	8	3D
0005434138348	28749	9	3F
0005434138324	28749	10	4A
0005434138323	28749	11	4C
0005434138360	28749	12	4D
0005434138362	28749	13	4F
0005434138358	28749	14	4E
0005434138308	28749	15	5A
0005434138374	28749	16	5C
0005434138349	28749	17	5D
0005434138370	28749	18	5E
0005434138347	28749	19	5F
0005434138376	28749	20	6A
0005434138382	28749	21	6C
0005434138307	28749	22	6D
0005434138311	28749	23	6F
0005434138363	28749	24	7A
0005434138344	28749	25	7D
0005434138340	28749	26	7E
0005434138352	28749	27	7F
0005434138369	28749	28	8A
0005434138361	28749	29	8D
0005434138336	28749	30	8E
0005434138318	28749	31	9A
0005434138368	28749	32	9C
0005434138388	28749	33	9D
0005434138321	28749	34	9E
0005434138351	28749	35	9F
0005434138353	28749	36	10A
0005434138313	28749	37	10C
0005434138350	28749	38	10D
0005434138330	28749	39	10E
0005434138306	28749	40	10F
0005434138372	28749	41	11A
0005434138384	28749	42	11D
0005434138315	28749	43	11E
0005434138387	28749	44	11F
0005434138378	28749	45	12A
0005434138355	28749	46	12C
0005434138309	28749	47	12D
0005434138332	28749	48	12E
0005434138379	28749	49	12F
0005434138326	28749	50	13A
0005434138345	28749	51	13C
0005434138373	28749	52	13D
0005434138375	28749	53	13E
0005434138359	28749	54	13F
0005434138371	28749	55	14A
0005434138312	28749	56	14C
0005434138366	28749	57	14D
0005434138320	28749	58	14E
0005434138341	28749	59	14F
0005434138319	28749	60	15A
0005434138322	28749	61	15C
0005434138329	28749	62	15D
0005434138367	28749	63	15E
0005434138327	28749	64	15F
0005434138377	28749	65	16A
0005434138381	28749	66	16C
0005434138334	28749	67	16D
0005434138314	28749	68	16E
0005434138338	28749	69	16F
0005434138354	28749	70	17A
0005434138339	28749	71	17D
0005434138328	28749	72	17E
0005434138386	28749	73	18A
0005434138337	28749	74	18C
0005434138346	28749	75	18E
0005434138333	28749	76	18F
0005434138380	28749	77	19A
0005434138343	28749	78	19C
0005434138357	28749	79	19D
0005434138325	28749	80	19F
0005434138356	28749	81	20A
0005434138383	28749	82	20C
0005434138365	28749	83	20D
0005435312779	6579	1	1B
0005435312788	6579	2	2A
0005434466470	6579	3	2D
0005434466469	6579	4	3A
0005434466476	6579	5	3B
0005434466471	6579	6	3C
0005434466474	6579	7	3D
0005435312791	6579	8	4C
0005435312790	6579	9	5A
0005435312806	6579	10	5C
0005434466472	6579	11	5D
0005434466475	6579	12	6D
0005435312778	6579	13	18B
0005434466473	6579	14	20C
0005434466477	6579	15	21A
0005435312805	6579	16	22B
0005435312789	6579	17	23A
0005433538895	6780	1	1B
0005433538898	6780	2	1C
0005433538894	6780	3	1D
0005433538893	6780	4	5A
0005433538900	6780	5	5B
0005435259731	6780	6	5D
0005435259718	6780	7	6C
0005433538899	6780	8	6D
0005433534504	6780	9	7A
0005435259721	6780	10	7B
0005435259728	6780	11	18A
0005435259747	6780	12	19B
0005435259719	6780	13	20D
0005433538897	6780	14	21B
0005435259750	6780	15	22C
0005433534505	6780	16	23A
0005433538896	6780	17	23B
0005433538790	25020	1	2A
0005433538789	25020	2	2B
0005433538814	25020	3	4D
0005435259771	25020	4	6B
0005435259768	25020	5	6D
0005433534493	25020	6	7A
0005435259770	25020	7	7D
0005433534494	25020	8	18A
0005433538791	25020	9	18B
0005433538801	25020	10	18D
0005435259772	25020	11	19B
0005435259769	25020	12	21C
0005433538815	25020	13	22C
0005433534481	25020	14	23A
0005433511975	830	1	1D
0005433511973	830	2	2B
0005433511983	830	3	3D
0005432922506	830	4	4C
0005433511982	830	5	7D
0005433511974	830	6	18B
0005433511976	830	7	18D
0005433511977	830	8	19B
0005433511979	830	9	19D
0005432922497	830	10	20A
0005433511980	830	11	20B
0005433511981	830	12	21B
0005433511978	830	13	22D
0005433511894	16173	1	1A
0005433511912	16173	2	1D
0005433511919	16173	3	2C
0005432922536	16173	4	3B
0005432922538	16173	5	4D
0005433511910	16173	6	5A
0005433511909	16173	7	5C
0005433511916	16173	8	6B
0005432922537	16173	9	7A
0005433511921	16173	10	18B
0005433511892	16173	11	19A
0005433511918	16173	12	19B
0005432922539	16173	13	21D
0005433511893	16173	14	22A
0005433511890	16173	15	22C
0005433511908	16173	16	23A
0005433511913	16173	17	23B
0005435935020	3651	1	1A
0005434950542	3651	2	1B
0005435697426	3651	3	1C
0005435697420	3651	4	2A
0005435697438	3651	5	2C
0005435697422	3651	6	3A
0005435697440	3651	7	3B
0005435697437	3651	8	3C
0005435697424	3651	9	3D
0005435697417	3651	10	4A
0005435697436	3651	11	4B
0005435916163	3651	12	4C
0005435697434	3651	13	5A
0005435697443	3651	14	4D
0005435697432	3651	15	5B
0005435916156	3651	16	5C
0005435697421	3651	17	5D
0005435935029	3651	18	6A
0005434950544	3651	19	6B
0005434950546	3651	20	6C
0005435697430	3651	21	6D
0005435697429	3651	22	7A
0005435697441	3651	23	7C
0005435697442	3651	24	7D
0005435697418	3651	25	18A
0005435697433	3651	26	18C
0005434950541	3651	27	18D
0005435916161	3651	28	19B
0005435697427	3651	29	19C
0005435697423	3651	30	19D
0005435697431	3651	31	20A
0005435697419	3651	32	20B
0005434950543	3651	33	20C
0005435697428	3651	34	21A
0005435697435	3651	35	21C
0005435935028	3651	36	21B
0005435697445	3651	37	21D
0005435697425	3651	38	22A
0005434950545	3651	39	22C
0005435697444	3651	40	22B
0005435697439	3651	41	23A
0005435916162	3651	42	23B
0005435697149	16274	1	1A
0005435916177	16274	2	1B
0005435697165	16274	3	1C
0005435697168	16274	4	2A
0005435697286	16274	5	2B
0005434950498	16274	6	2C
0005435697124	16274	7	2D
0005435697301	16274	8	3A
0005435697267	16274	9	3B
0005435697214	16274	10	3C
0005435697224	16274	11	4A
0005435697131	16274	12	4D
0005435697107	16274	13	5A
0005435697285	16274	14	5B
0005435697205	16274	15	5C
0005435935055	16274	16	5D
0005435697104	16274	17	6A
0005435697134	16274	18	6C
0005434950499	16274	19	6D
0005435697123	16274	20	7B
0005435935056	16274	21	7C
0005435697132	16274	22	18A
0005435697141	16274	23	18B
0005435916175	16274	24	18C
0005435697204	16274	25	19A
0005435697166	16274	26	19C
0005435697140	16274	27	19D
0005435935054	16274	28	20A
0005435697074	16274	29	20B
0005435935057	16274	30	20C
0005435697108	16274	31	20D
0005435697275	16274	32	21A
0005435697302	16274	33	21B
0005435697223	16274	34	21C
0005435935053	16274	35	21D
0005435697268	16274	36	22A
0005435697239	16274	37	22C
0005435916176	16274	38	22D
0005435935052	16274	39	23B
0005433519473	3937	1	1C
0005432609746	3937	2	1D
0005432609744	3937	3	3B
0005434606838	3937	4	3C
0005433519475	3937	5	4D
0005432607581	3937	6	4C
0005433519474	3937	7	5B
0005435841471	3937	8	5C
0005432607579	3937	9	5D
0005433519470	3937	10	6A
0005432607580	3937	11	6B
0005432609743	3937	12	6C
0005432607578	3937	13	7A
0005434606837	3937	14	18D
0005432609742	3937	15	19B
0005432609745	3937	16	19D
0005433519471	3937	17	20B
0005433519472	3937	18	20D
0005435841475	3937	19	21A
0005432607582	3937	20	21B
0005435841465	3937	21	22A
0005435842323	3937	22	22D
0005432607577	3937	23	23B
0005434606797	22087	1	1B
0005434606809	22087	2	2B
0005433519428	22087	3	3D
0005435904897	22087	4	4D
0005435853616	22087	5	6C
0005433519429	22087	6	7D
0005435853619	22087	7	18B
0005433519427	22087	8	19A
0005435853618	22087	9	20D
0005434606796	22087	10	21C
0005435904896	22087	11	22A
0005434606795	22087	12	22B
0005435853617	22087	13	23A
0005433348950	793	1	1A
0005435628731	793	2	1B
0005435628730	793	3	2A
0005435628735	793	4	2B
0005433348958	793	5	3A
0005435628729	793	6	4A
0005435628733	793	7	4B
0005435628734	793	8	5B
0005435628728	793	9	6A
0005435628732	793	10	6B
0005435628715	15946	1	2A
0005433349008	15946	2	2B
0005435628717	15946	3	3A
0005435628693	15946	4	4A
0005433349011	15946	5	3B
0005433349007	15946	6	4B
0005433349010	15946	7	5A
0005435628692	15946	8	5B
0005433349006	15946	9	6A
0005433349009	15946	10	6B
0005434446523	17220	1	1A
0005434445253	17220	2	2A
0005434446521	17220	3	3A
0005434446522	17220	4	3B
0005433158122	17220	5	4B
0005434445252	17220	6	4A
0005434446524	17220	7	6B
0005434445226	17573	1	1B
0005434445227	17573	2	2A
0005434445233	17573	3	2B
0005433159320	17573	4	4B
0005434445234	17573	5	4A
0005434445235	17573	6	5A
0005434445237	17573	7	6A
0005433159321	17573	8	6B
0005435132917	7861	1	3B
0005435132921	7861	2	4A
0005435132911	7861	3	4C
0005435132915	7861	4	6B
0005435132919	7861	5	6D
0005435132920	7861	6	7A
0005435132912	7861	7	7D
0005435383118	7861	8	18D
0005435132916	7861	9	19C
0005435383132	7861	10	20D
0005435132914	7861	11	22A
0005435132918	7861	12	22D
0005435132913	7861	13	23A
0005435132856	33067	1	2C
0005435383166	33067	2	3D
0005435383169	33067	3	6B
0005435383165	33067	4	6C
0005435132833	33067	5	6D
0005435383167	33067	6	7C
0005435132832	33067	7	20D
0005435132816	33067	8	21C
0005435132871	33067	9	21D
0005435132857	33067	10	22A
0005435383168	33067	11	22C
0005435132864	33067	12	22D
0005435811088	4402	1	3D
0005435811090	4402	2	4A
0005435811095	4402	3	7A
0005435811086	4402	4	7F
0005435811089	4402	5	9C
0005435811087	4402	6	12B
0005435811085	4402	7	12F
0005435938877	4402	8	13B
0005435811094	4402	9	17D
0005435811091	4402	10	17E
0005435811092	4402	11	18B
0005435938878	4402	12	20D
0005435811093	4402	13	20F
0005435938895	29452	1	1A
0005435938893	29452	2	4A
0005435938896	29452	3	6F
0005435811038	29452	4	10A
0005435938894	29452	5	11B
0005435938892	29452	6	15D
0005435160337	7488	1	1A
0005435390201	7488	2	1C
0005435160340	7488	3	1D
0005435160341	7488	4	2C
0005435160334	7488	5	2D
0005435160339	7488	6	3C
0005435160338	7488	7	3D
0005435390191	7488	8	4A
0005435390192	7488	9	4D
0005435160342	7488	10	5C
0005435390207	7488	11	7C
0005435390234	7488	12	7D
0005435390215	7488	13	18D
0005435160333	7488	14	19B
0005435390187	7488	15	19D
0005435160343	7488	16	20B
0005435160335	7488	17	20D
0005435160336	7488	18	21D
0005435390188	7488	19	22C
0005435390202	7488	20	22D
0005435160268	29551	1	1A
0005435160251	29551	2	2A
0005435160212	29551	3	2B
0005435160289	29551	4	2C
0005435390264	29551	5	2D
0005435160213	29551	6	3C
0005435160214	29551	7	4B
0005435390265	29551	8	5B
0005435160250	29551	9	5C
0005435390262	29551	10	5D
0005435160240	29551	11	6B
0005435160284	29551	12	7C
0005435160278	29551	13	7D
0005435160235	29551	14	18B
0005435390259	29551	15	18C
0005435390261	29551	16	19A
0005435160237	29551	17	19B
0005435160267	29551	18	20A
0005435160236	29551	19	20B
0005435160285	29551	20	20C
0005435390260	29551	21	21D
0005435160223	29551	22	22A
0005435390263	29551	23	22B
0005432398176	18474	1	1A
0005435178996	18474	2	1B
0005432398165	18474	3	2A
0005432394067	18474	4	2B
0005432398163	18474	5	3A
0005432398177	18474	6	3B
0005432398178	18474	7	4A
0005435178501	18474	8	4B
0005435178997	18474	9	5A
0005432398173	18474	10	6A
0005432398189	18474	11	6B
0005435178486	27155	1	1A
0005432400132	27155	2	2A
0005435178489	27155	3	2B
0005435179390	27155	4	3A
0005432398204	27155	5	3B
0005432400131	27155	6	4A
0005432400134	27155	7	5A
0005432400133	27155	8	5B
0005435178484	27155	9	6A
0005432398205	27155	10	6B
0005432865971	2249	1	1D
0005432639166	2249	2	2A
0005432639165	2249	3	2C
0005432639176	2249	4	3F
0005432865967	2249	5	4C
0005432639175	2249	6	4E
0005432865962	2249	7	5A
0005432639158	2249	8	7A
0005432639179	2249	9	7D
0005432639164	2249	10	8A
0005432639173	2249	11	8D
0005432865970	2249	12	8E
0005432639180	2249	13	9A
0005432639163	2249	14	9C
0005432639178	2249	15	9E
0005432639170	2249	16	9F
0005432639171	2249	17	10A
0005432639162	2249	18	10C
0005432865936	2249	19	10D
0005432639168	2249	20	10E
0005432639160	2249	21	10F
0005432639174	2249	22	11C
0005432639182	2249	23	11A
0005432865953	2249	24	12A
0005432639161	2249	25	12D
0005432639177	2249	26	12E
0005432639172	2249	27	12F
0005432865954	2249	28	13C
0005432865993	2249	29	14D
0005432865968	2249	30	14F
0005432639169	2249	31	16C
0005432639159	2249	32	16D
0005432639167	2249	33	17C
0005432866006	2249	34	18F
0005432639157	2249	35	19D
0005432865952	2249	36	20A
0005432639181	2249	37	20E
0005433811639	24298	1	5B
0005433811640	24298	2	5D
0005433811642	24298	3	5F
0005433811638	24298	4	6C
0005433811634	24298	5	6F
0005433811641	24298	6	11A
0005433811636	24298	7	11C
0005433811644	24298	8	12E
0005433811643	24298	9	19B
0005433811637	24298	10	19D
0005433811633	24298	11	21A
0005433811635	24298	12	22A
0005434191282	32793	1	1A
0005434191279	32793	2	1B
0005434191280	32793	3	2A
0005434191281	32793	4	2B
0005434191278	32793	5	3A
0005434191277	32793	6	4A
0005434191283	32793	7	4B
0005434191284	32793	8	5A
0005434191274	32793	9	5B
0005434191276	32793	10	6A
0005434191275	32793	11	6B
0005432658560	26491	1	1A
0005432661908	26491	2	2A
0005432661906	26491	3	1F
0005432658563	26491	4	3A
0005432658568	26491	5	4A
0005432661901	26491	6	4D
0005432665251	26491	7	5F
0005432661907	26491	8	5D
0005432658580	26491	9	6B
0005432658571	26491	10	6A
0005432661912	26491	11	6D
0005432661905	26491	12	7B
0005432665253	26491	13	7A
0005432661904	26491	14	7F
0005432658558	26491	15	8B
0005432658581	26491	16	8E
0005432658570	26491	17	8C
0005432665260	26491	18	9B
0005432661903	26491	19	9F
0005432658559	26491	20	9D
0005432661899	26491	21	10F
0005432661898	26491	22	11B
0005432658569	26491	23	11C
0005432665259	26491	24	11F
0005432665256	26491	25	12C
0005432658575	26491	26	12D
0005432665254	26491	27	12F
0005432665266	26491	28	13C
0005432658574	26491	29	13E
0005432658562	26491	30	13D
0005432665257	26491	31	14D
0005432661910	26491	32	14F
0005432658577	26491	33	14E
0005432665258	26491	34	16A
0005432665248	26491	35	15F
0005432658564	26491	36	17B
0005432658573	26491	37	17D
0005432665252	26491	38	17E
0005432658576	26491	39	18C
0005432658557	26491	40	19A
0005432661902	26491	41	19C
0005432665255	26491	42	19E
0005432665265	26491	43	19D
0005432665267	26491	44	20A
0005432665246	26491	45	20F
0005432661909	26491	46	21C
0005432665247	26491	47	21B
0005435103957	6539	1	1F
0005434504285	6539	2	2A
0005435103961	6539	3	2C
0005434504288	6539	4	2D
0005434504289	6539	5	2F
0005434504265	6539	6	3A
0005435103956	6539	7	3D
0005434504282	6539	8	3F
0005434504286	6539	9	4A
0005434504262	6539	10	4D
0005434504270	6539	11	4E
0005434504261	6539	12	6A
0005435103955	6539	13	6D
0005434504300	6539	14	7D
0005434504264	6539	15	7E
0005434504281	6539	16	8A
0005434504277	6539	17	8C
0005434504298	6539	18	8E
0005435103958	6539	19	9C
0005434504267	6539	20	9F
0005434504295	6539	21	10A
0005434504296	6539	22	10D
0005434504263	6539	23	10E
0005434504294	6539	24	12D
0005434504284	6539	25	12F
0005434504292	6539	26	13A
0005435103954	6539	27	13C
0005434504274	6539	28	13D
0005434504272	6539	29	13F
0005435103960	6539	30	14A
0005434504269	6539	31	14E
0005434504299	6539	32	14F
0005434504268	6539	33	15D
0005434504280	6539	34	15F
0005435103959	6539	35	16D
0005434504293	6539	36	16E
0005434504290	6539	37	16F
0005434504283	6539	38	17A
0005434504279	6539	39	17C
0005434504291	6539	40	17D
0005434504276	6539	41	17E
0005434504273	6539	42	17F
0005434504297	6539	43	18C
0005434504287	6539	44	18E
0005434504266	6539	45	18F
0005434504275	6539	46	19C
0005434504278	6539	47	20C
0005434504271	6539	48	20D
0005434503782	22665	1	1A
0005434504020	22665	2	1D
0005434503771	22665	3	2A
0005434503834	22665	4	2D
0005434503878	22665	5	2F
0005434503804	22665	6	3A
0005435103843	22665	7	3F
0005434503646	22665	8	4F
0005434503700	22665	9	5A
0005434503883	22665	10	7D
0005434503880	22665	11	7E
0005434503805	22665	12	8C
0005434503770	22665	13	8D
0005434503942	22665	14	8F
0005434503980	22665	15	9D
0005434503634	22665	16	9F
0005434504021	22665	17	10C
0005434504013	22665	18	10E
0005434504011	22665	19	10F
0005434503971	22665	20	11C
0005434503886	22665	21	11D
0005434503877	22665	22	11E
0005434504006	22665	23	12A
0005434503922	22665	24	12C
0005434503647	22665	25	13C
0005434504012	22665	26	13E
0005434503851	22665	27	13F
0005435103842	22665	28	14C
0005434503898	22665	29	14E
0005434503981	22665	30	15C
0005434504049	22665	31	15F
0005434503921	22665	32	16E
0005434503769	22665	33	17A
0005434503835	22665	34	17C
0005434504051	22665	35	17E
0005434503892	22665	36	18F
0005434503781	22665	37	19C
0005434503941	22665	38	19E
0005434503635	22665	39	20D
0005434503963	22665	40	20E
0005434503678	22665	41	20F
0005433367709	1640	1	1A
0005435653218	1640	2	1C
0005435653214	1640	3	1D
0005435653234	1640	4	1F
0005433367761	1640	5	2C
0005435653192	1640	6	2F
0005435653226	1640	7	3A
0005433367677	1640	8	3D
0005435653202	1640	9	3F
0005435653205	1640	10	4A
0005435653221	1640	11	4C
0005433367661	1640	12	4D
0005433367600	1640	13	4E
0005435653220	1640	14	4F
0005435653196	1640	15	5A
0005435653224	1640	16	5C
0005435653195	1640	17	5D
0005433367805	1640	18	5E
0005435653233	1640	19	5F
0005435653200	1640	20	6A
0005435653227	1640	21	6C
0005433367676	1640	22	6D
0005435653236	1640	23	6E
0005435653229	1640	24	6F
0005433367701	1640	25	7A
0005433367555	1640	26	7C
0005435653232	1640	27	7D
0005435653208	1640	28	7E
0005435653215	1640	29	8A
0005433367528	1640	30	8C
0005435653213	1640	31	8D
0005433367713	1640	32	8E
0005433367675	1640	33	8F
0005435653235	1640	34	9C
0005435653230	1640	35	9D
0005435653198	1640	36	9E
0005433367747	1640	37	9F
0005433367467	1640	38	10A
0005435653206	1640	39	10C
0005435653219	1640	40	10D
0005433367728	1640	41	10E
0005433367678	1640	42	11A
0005433367554	1640	43	11C
0005435653193	1640	44	11E
0005433367660	1640	45	12A
0005433367686	1640	46	12D
0005435653194	1640	47	12F
0005433367601	1640	48	13A
0005435653222	1640	49	13C
0005435653231	1640	50	13D
0005435653197	1640	51	13E
0005433367746	1640	52	13F
0005435653212	1640	53	14A
0005433367730	1640	54	14C
0005433367634	1640	55	14D
0005435653210	1640	56	14F
0005435653211	1640	57	15C
0005435653204	1640	58	15E
0005433367599	1640	59	16A
0005435653225	1640	60	16C
0005433367646	1640	61	16D
0005435653203	1640	62	16E
0005433367779	1640	63	16F
0005435653216	1640	64	17C
0005435653223	1640	65	17D
0005433367804	1640	66	17E
0005435653201	1640	67	18A
0005435653207	1640	68	18C
0005435653228	1640	69	18D
0005433367702	1640	70	18E
0005433367651	1640	71	18F
0005435653199	1640	72	19A
0005435653217	1640	73	19D
0005433367870	1640	74	19F
0005435653209	1640	75	20A
0005433367658	1640	76	20C
0005433367650	1640	77	20D
0005433367635	1640	78	20E
0005435652726	21703	1	1A
0005435652557	21703	2	1C
0005435652520	21703	3	1D
0005433368003	21703	4	1F
0005433367999	21703	5	2A
0005433367998	21703	6	2C
0005435652719	21703	7	2D
0005435652759	21703	8	2F
0005435652720	21703	9	3A
0005435652695	21703	10	3C
0005435652674	21703	11	3D
0005433368002	21703	12	3F
0005433368011	21703	13	4A
0005433368021	21703	14	4C
0005435652699	21703	15	4D
0005435652698	21703	16	4E
0005433368020	21703	17	4F
0005435652519	21703	18	5C
0005435652758	21703	19	5D
0005435652781	21703	20	5E
0005435652756	21703	21	5F
0005433368014	21703	22	6A
0005433368000	21703	23	6C
0005433368001	21703	24	6D
0005435652687	21703	25	6E
0005433367987	21703	26	6F
0005433367994	21703	27	7A
0005435652672	21703	28	7C
0005435652585	21703	29	7D
0005433368022	21703	30	7E
0005433367989	21703	31	7F
0005435652713	21703	32	8A
0005435652694	21703	33	8C
0005433368007	21703	34	8D
0005433367992	21703	35	8E
0005433367991	21703	36	8F
0005433368006	21703	37	9A
0005433368023	21703	38	9C
0005433368018	21703	39	9D
0005435652772	21703	40	9E
0005433368009	21703	41	9F
0005435652780	21703	42	10A
0005433368025	21703	43	10C
0005435652666	21703	44	10D
0005435652559	21703	45	10E
0005433367993	21703	46	10F
0005435652586	21703	47	11A
0005435652692	21703	48	11C
0005435652543	21703	49	11D
0005435652751	21703	50	11E
0005435652768	21703	51	11F
0005435652733	21703	52	12A
0005433368015	21703	53	12C
0005435652741	21703	54	12E
0005433368013	21703	55	12F
0005435652544	21703	56	13A
0005433368008	21703	57	13C
0005435652668	21703	58	13D
0005435652789	21703	59	13F
0005433368019	21703	60	14A
0005433367996	21703	61	14C
0005435652491	21703	62	14D
0005433368017	21703	63	14E
0005435652669	21703	64	14F
0005435652673	21703	65	15A
0005435652771	21703	66	15C
0005433367988	21703	67	15D
0005435652521	21703	68	15E
0005435652792	21703	69	16A
0005435652682	21703	70	16C
0005433367990	21703	71	16F
0005433368004	21703	72	17A
0005435652643	21703	73	17C
0005435652725	21703	74	17E
0005433368024	21703	75	17F
0005433367997	21703	76	18A
0005433367995	21703	77	18C
0005435652667	21703	78	18D
0005435652760	21703	79	18E
0005435652791	21703	80	18F
0005435652740	21703	81	19A
0005435652714	21703	82	19C
0005435652715	21703	83	19D
0005433368005	21703	84	19E
0005433368010	21703	85	19F
0005433368012	21703	86	20A
0005435652710	21703	87	20C
0005433368016	21703	88	20D
0005435652675	21703	89	20E
0005435652556	21703	90	20F
0005435627119	12270	1	4A
0005435627120	12270	2	4B
0005435627114	23816	1	1A
0005435627115	23816	2	4B
0005435312815	23241	1	1B
0005434466449	23241	2	3A
0005434466448	23241	3	3D
0005435312814	23241	4	4C
0005434466420	23241	5	5C
0005435312812	23241	6	6C
0005435312813	23241	7	7A
0005434466430	23241	8	7D
0005435312816	23241	9	18D
0005434466435	23241	10	22A
0005434466453	23241	11	22B
0005434466428	23241	12	23A
0005433986121	4173	1	1C
0005433986118	4173	2	1D
0005433986129	4173	3	1F
0005433986111	4173	4	3A
0005433986093	4173	5	3C
0005433986083	4173	6	3D
0005433986122	4173	7	4A
0005433986112	4173	8	4C
0005433986108	4173	9	4D
0005433986105	4173	10	4E
0005433986092	4173	11	5A
0005433986077	4173	12	5D
0005433986079	4173	13	5F
0005433986116	4173	14	6A
0005433986107	4173	15	6C
0005433986089	4173	16	6D
0005433986097	4173	17	6E
0005433986085	4173	18	6F
0005433986124	4173	19	7E
0005433986088	4173	20	8C
0005433986087	4173	21	8D
0005433986123	4173	22	8F
0005433986084	4173	23	9C
0005435788779	4173	24	9D
0005433986099	4173	25	9F
0005433986100	4173	26	10C
0005433986091	4173	27	10D
0005435788780	4173	28	10F
0005433986098	4173	29	11A
0005433986126	4173	30	11C
0005433986125	4173	31	11E
0005433986095	4173	32	11F
0005433986109	4173	33	12A
0005433986110	4173	34	12C
0005433986080	4173	35	12D
0005433986076	4173	36	13D
0005433986104	4173	37	13E
0005433986078	4173	38	14C
0005433986090	4173	39	14D
0005433986115	4173	40	14F
0005433986114	4173	41	15C
0005433986086	4173	42	15D
0005433986094	4173	43	15F
0005433986096	4173	44	16C
0005433986106	4173	45	16D
0005433986120	4173	46	17C
0005433986117	4173	47	17F
0005433986081	4173	48	18C
0005433986102	4173	49	18D
0005433986128	4173	50	18E
0005433986101	4173	51	19C
0005433986082	4173	52	19D
0005433986127	4173	53	19E
0005433986113	4173	54	20D
0005433986119	4173	55	20E
0005433986103	4173	56	20F
0005433985725	25691	1	1C
0005433985674	25691	2	1F
0005433985555	25691	3	2A
0005433985750	25691	4	2F
0005433985502	25691	5	3A
0005433985704	25691	6	3C
0005433985768	25691	7	3F
0005433985593	25691	8	4C
0005433985757	25691	9	4D
0005433985742	25691	10	4E
0005433985556	25691	11	4F
0005433985670	25691	12	5A
0005433985601	25691	13	5C
0005433985518	25691	14	7C
0005433985512	25691	15	7F
0005433985769	25691	16	8A
0005433985501	25691	17	8C
0005433985575	25691	18	9A
0005433985602	25691	19	9C
0005433985519	25691	20	9D
0005433985675	25691	21	9E
0005433985815	25691	22	9F
0005433985530	25691	23	11C
0005433985578	25691	24	11E
0005433985734	25691	25	11F
0005433985513	25691	26	12A
0005433985503	25691	27	12D
0005433985834	25691	28	13C
0005433985319	25691	29	13D
0005433985653	25691	30	13F
0005435788758	25691	31	14F
0005433985738	25691	32	15A
0005433985682	25691	33	15F
0005433985703	25691	34	16E
0005433985661	25691	35	17A
0005433985683	25691	36	17D
0005433985603	25691	37	18D
0005433985604	25691	38	18E
0005433985669	25691	39	19A
0005433985821	25691	40	19C
0005433985596	25691	41	19D
0005433985681	25691	42	19E
0005433985579	25691	43	20A
0005433985724	25691	44	20C
0005433985574	25691	45	20D
0005435720814	21251	1	2A
0005435719562	21251	2	6A
0005435719561	21251	3	18D
0005435720813	21251	4	22A
0005435720136	24769	1	1B
0005435720135	24769	2	2C
0005433168351	1617	1	1C
0005433168340	1617	2	2A
0005434509176	1617	3	2B
0005434509168	1617	4	2C
0005434509164	1617	5	2D
0005434509174	1617	6	3B
0005433168352	1617	7	4A
0005433168371	1617	8	4B
0005434509173	1617	9	4C
0005434509178	1617	10	5B
0005434509171	1617	11	5C
0005434509165	1617	12	5D
0005434509167	1617	13	6A
0005434509169	1617	14	7B
0005434509175	1617	15	18A
0005434509180	1617	16	18C
0005433168353	1617	17	19D
0005434509170	1617	18	20B
0005434509166	1617	19	21D
0005434509172	1617	20	22A
0005434509179	1617	21	22B
0005434509163	1617	22	22C
0005434509177	1617	23	23A
0005434190391	9017	1	1A
0005434516087	9017	2	1D
0005434516083	9017	3	3D
0005434516084	9017	4	4B
0005434190387	9017	5	5A
0005434516081	9017	6	5B
0005434516086	9017	7	18C
0005434190388	9017	8	18D
0005434190386	9017	9	19A
0005434516082	9017	10	19B
0005434190399	9017	11	20A
0005434190393	9017	12	21B
0005434516085	9017	13	21C
0005434190394	9017	14	21D
0005434190392	9017	15	22B
0005434190390	9017	16	23A
0005432869550	17840	1	1A
0005432869546	17840	2	1C
0005432665262	17840	3	1D
0005432666382	17840	4	3A
0005432660796	17840	5	3F
0005432667438	17840	6	4A
0005432667437	17840	7	4C
0005432660807	17840	8	6C
0005432655421	17840	9	6F
0005432664118	17840	10	7D
0005432655387	17840	11	7F
0005432655445	17840	12	8A
0005432666369	17840	13	8C
0005432657444	17840	14	8D
0005432655453	17840	15	8F
0005434151715	17840	16	9C
0005432664128	17840	17	9D
0005434151714	17840	18	10A
0005434151716	17840	19	10D
0005432869548	17840	20	11A
0005432655479	17840	21	11C
0005432665261	17840	22	12E
0005432869549	17840	23	13A
0005432664119	17840	24	13E
0005432657443	17840	25	14E
0005432869551	17840	26	15D
0005432869547	17840	27	15F
0005432666367	17840	28	16E
0005432655480	17840	29	17E
0005432657429	17840	30	17F
0005432666368	17840	31	19D
0005432663015	17840	32	19E
0005432658578	17840	33	20C
0005432869552	17840	34	20E
0005432667447	17840	35	20F
0005432665278	26324	1	1C
0005432655552	26324	2	1D
0005432655556	26324	3	2D
0005432655547	26324	4	4D
0005432667458	26324	5	4E
0005432655553	26324	6	4F
0005432666393	26324	7	5C
0005432657455	26324	8	5E
0005432869464	26324	9	5F
0005432658595	26324	10	6C
0005432666392	26324	11	7A
0005432869453	26324	12	7F
0005432660821	26324	13	8D
0005432659709	26324	14	8F
0005432869465	26324	15	10A
0005432655548	26324	16	10E
0005432869476	26324	17	11A
0005432655550	26324	18	11D
0005432869467	26324	19	13A
0005432667457	26324	20	13D
0005432657456	26324	21	13F
0005432655549	26324	22	14A
0005432660822	26324	23	14D
0005432655555	26324	24	14F
0005432659710	26324	25	16E
0005432657453	26324	26	16F
0005432657454	26324	27	17A
0005432655557	26324	28	17C
0005432665279	26324	29	18A
0005432655551	26324	30	19C
0005432655546	26324	31	19E
0005432655554	26324	32	19F
0005432869466	26324	33	20C
0005432866036	25070	1	1A
0005432639032	25070	2	1C
0005432639025	25070	3	1D
0005432866034	25070	4	1F
0005432639057	25070	5	2C
0005432866041	25070	6	2F
0005432639126	25070	7	3A
0005432639070	25070	8	3D
0005432639019	25070	9	4A
0005432639026	25070	10	4C
0005432639055	25070	11	5D
0005432639035	25070	12	5E
0005432866030	25070	13	5F
0005432639069	25070	14	6C
0005432866037	25070	15	6D
0005432866039	25070	16	7C
0005432639088	25070	17	8C
0005432639018	25070	18	8F
0005432866035	25070	19	9A
0005432866040	25070	20	9C
0005432639015	25070	21	9D
0005432866033	25070	22	9E
0005432866038	25070	23	10C
0005432639006	25070	24	10D
0005432639005	25070	25	10E
0005432866032	25070	26	11C
0005432639067	25070	27	11E
0005432639066	25070	28	11F
0005432639031	25070	29	12C
0005432639068	25070	30	12E
0005432639017	25070	31	13C
0005432639127	25070	32	13D
0005432866042	25070	33	13F
0005432639007	25070	34	14A
0005432866043	25070	35	15C
0005432639065	25070	36	15E
0005432639056	25070	37	16D
0005432866031	25070	38	16E
0005432639086	25070	39	17A
0005432639064	25070	40	17E
0005432639016	25070	41	18E
0005432639087	25070	42	19D
0005432639048	25070	43	19E
0005433438902	3090	1	1A
0005432328845	3090	2	1C
0005432905111	3090	3	1D
0005432905079	3090	4	1F
0005432328838	3090	5	2C
0005432905080	3090	6	2D
0005433438899	3090	7	3C
0005432328850	3090	8	3D
0005432328846	3090	9	3F
0005432328844	3090	10	4A
0005432328840	3090	11	4D
0005433438900	3090	12	4E
0005432287209	3090	13	4F
0005432328851	3090	14	5A
0005432328837	3090	15	5E
0005432328875	3090	16	6A
0005432328862	3090	17	6C
0005432328870	3090	18	6D
0005432328842	3090	19	6E
0005432905115	3090	20	7A
0005432328858	3090	21	7E
0005432328831	3090	22	7F
0005432328852	3090	23	8A
0005432287208	3090	24	8C
0005432287207	3090	25	8E
0005432328853	3090	26	8F
0005432328864	3090	27	9A
0005432328873	3090	28	9C
0005432287206	3090	29	9F
0005432328867	3090	30	10C
0005432328860	3090	31	10E
0005432328854	3090	32	10F
0005432905101	3090	33	11A
0005432328835	3090	34	11C
0005432328869	3090	35	11E
0005432905110	3090	36	11F
0005432905102	3090	37	12C
0005432328833	3090	38	12D
0005432287205	3090	39	12E
0005432328876	3090	40	13A
0005432905103	3090	41	13C
0005432328871	3090	42	13E
0005432328839	3090	43	14C
0005432328836	3090	44	14E
0005432328866	3090	45	14F
0005432328865	3090	46	15A
0005432328855	3090	47	15C
0005432328848	3090	48	15D
0005432848837	3090	49	15E
0005432328834	3090	50	15F
0005432905117	3090	51	16A
0005432328857	3090	52	16C
0005433438901	3090	53	16D
0005432328841	3090	54	17A
0005432328849	3090	55	17C
0005432328843	3090	56	17D
0005432328856	3090	57	17E
0005432328832	3090	58	17F
0005432328859	3090	59	18C
0005432328868	3090	60	18D
0005432328872	3090	61	18E
0005432328874	3090	62	18F
0005432328861	3090	63	19E
0005432328863	3090	64	20C
0005432328847	3090	65	20E
0005433438819	31111	1	1A
0005432848840	31111	2	1C
0005432328370	31111	3	1D
0005432328386	31111	4	1F
0005432848839	31111	5	3A
0005432328509	31111	6	3C
0005432328447	31111	7	3D
0005432328328	31111	8	3F
0005432328432	31111	9	4D
0005432848838	31111	10	4E
0005432328465	31111	11	4F
0005432328593	31111	12	5A
0005432328314	31111	13	5D
0005432328564	31111	14	5E
0005432328493	31111	15	5F
0005432328480	31111	16	6C
0005432328380	31111	17	7E
0005432328387	31111	18	7F
0005433438820	31111	19	8C
0005432328463	31111	20	8D
0005432328472	31111	21	8E
0005432328442	31111	22	8F
0005432328389	31111	23	9A
0005432328528	31111	24	9C
0005432328280	31111	25	10A
0005432054314	31111	26	10E
0005432328457	31111	27	12C
0005432905145	31111	28	12D
0005432328635	31111	29	12E
0005432328570	31111	30	13C
0005432328478	31111	31	13D
0005432328443	31111	32	13E
0005432328503	31111	33	13F
0005432328277	31111	34	14A
0005432905143	31111	35	14C
0005432328473	31111	36	14D
0005432328167	31111	37	14E
0005432905144	31111	38	14F
0005432328065	31111	39	15C
0005432328441	31111	40	15E
0005433438864	31111	41	15F
0005433438834	31111	42	16A
0005432328064	31111	43	16C
0005432328504	31111	44	16E
0005432328228	31111	45	16D
0005432328562	31111	46	17A
0005432328240	31111	47	17F
0005433438858	31111	48	18C
0005432328481	31111	49	18D
0005432328634	31111	50	18E
0005433438845	31111	51	18F
0005433438833	31111	52	19A
0005432328477	31111	53	19C
0005432328550	31111	54	19D
0005432328417	31111	55	19E
0005432328388	31111	56	19F
0005432328448	31111	57	20C
0005433438821	31111	58	20D
0005432328359	31111	59	20E
0005435296992	6174	1	1A
0005435999322	6174	2	1D
0005435999300	6174	3	3C
0005435999302	6174	4	3A
0005435487655	6174	5	3F
0005434309793	6174	6	3D
0005435999320	6174	7	4C
0005435487733	6174	8	4D
0005435487738	6174	9	5B
0005435487675	6174	10	5E
0005435297021	6174	11	6A
0005435999304	6174	12	5F
0005434309790	6174	13	6C
0005435487693	6174	14	6B
0005435487757	6174	15	6E
0005435999316	6174	16	7A
0005434309787	6174	17	7C
0005434309791	6174	18	7D
0005435297008	6174	19	7F
0005435999318	6174	20	8B
0005435999313	6174	21	8A
0005434309792	6174	22	8D
0005435487659	6174	23	9A
0005435297033	6174	24	9C
0005435487674	6174	25	10C
0005435487640	6174	26	10E
0005434309785	6174	27	11B
0005434309781	6174	28	11D
0005435296997	6174	29	12A
0005435487761	6174	30	12C
0005435297022	6174	31	12D
0005434309784	6174	32	12E
0005435487703	6174	33	13A
0005435487717	6174	34	13B
0005435999305	6174	35	13C
0005435487732	6174	36	14B
0005435999317	6174	37	14D
0005435999315	6174	38	15A
0005434309783	6174	39	15B
0005435297032	6174	40	15D
0005435999303	6174	41	15F
0005435487648	6174	42	15E
0005435999314	6174	43	16A
0005435487666	6174	44	16D
0005435999319	6174	45	16B
0005435487740	6174	46	16F
0005434309788	6174	47	16E
0005432146206	6174	48	17A
0005435297007	6174	49	17B
0005435999301	6174	50	17D
0005435487758	6174	51	17E
0005435999321	6174	52	18B
0005435487762	6174	53	18C
0005435999308	6174	54	18E
0005434309782	6174	55	18D
0005435487635	6174	56	19A
0005435487739	6174	57	19D
0005435487697	6174	58	19F
0005435297017	6174	59	20C
0005435999310	6174	60	20E
0005435487720	6174	61	21A
0005435487698	6174	62	21C
0005435999309	6174	63	21D
0005435297034	6174	64	21E
0005435487704	6174	65	21F
0005435999307	6174	66	22C
0005434309789	6174	67	22E
0005435999312	6174	68	22F
0005432146205	6174	69	23A
0005435999306	6174	70	23C
0005434309786	6174	71	23D
0005435999311	6174	72	23E
0005435297081	19533	1	1F
0005435487878	19533	2	2A
0005435999151	19533	3	2F
0005435487898	19533	4	2D
0005435487876	19533	5	3C
0005435999096	19533	6	3D
0005435487880	19533	7	4A
0005435999141	19533	8	4C
0005435297083	19533	9	4D
0005435999122	19533	10	4E
0005434309703	19533	11	4F
0005435297079	19533	12	5D
0005435999080	19533	13	5F
0005435999097	19533	14	6A
0005435487897	19533	15	6D
0005434309644	19533	16	6E
0005434309650	19533	17	7C
0005435487886	19533	18	7F
0005434309694	19533	19	7E
0005434309649	19533	20	8B
0005435999121	19533	21	8C
0005435999165	19533	22	9A
0005435999038	19533	23	9C
0005435487882	19533	24	9E
0005435999150	19533	25	10B
0005435487884	19533	26	10D
0005435487881	19533	27	11A
0005434309701	19533	28	10E
0005435487877	19533	29	11B
0005435297082	19533	30	11E
0005435297080	19533	31	12A
0005435999133	19533	32	12C
0005435999094	19533	33	12B
0005435999091	19533	34	12E
0005435999162	19533	35	12F
0005435487879	19533	36	13D
0005435487874	19533	37	13E
0005435297084	19533	38	14B
0005434309648	19533	39	14C
0005435999126	19533	40	14E
0005435487887	19533	41	15A
0005435487888	19533	42	14F
0005435487896	19533	43	15B
0005435999157	19533	44	16B
0005435999163	19533	45	17A
0005435487893	19533	46	17B
0005435487875	19533	47	17D
0005435487895	19533	48	17F
0005434309683	19533	49	18F
0005435487885	19533	50	19E
0005435999134	19533	51	19F
0005435487890	19533	52	20B
0005435999037	19533	53	20C
0005434309684	19533	54	20E
0005435999039	19533	55	20F
0005435487883	19533	56	21D
0005434309695	19533	57	21E
0005435999123	19533	58	22B
0005435487894	19533	59	22A
0005435297078	19533	60	22D
0005435999090	19533	61	22F
0005435487891	19533	62	22E
0005435487889	19533	63	23C
0005435487892	19533	64	23E
0005434565966	1594	1	1D
0005435517964	1594	2	2A
0005435517965	1594	3	2C
0005435517976	1594	4	3C
0005435502389	1594	5	3D
0005435502396	1594	6	4A
0005435517967	1594	7	4C
0005434565965	1594	8	4F
0005435502382	1594	9	5A
0005435502378	1594	10	5C
0005432291939	1594	11	5E
0005435502393	1594	12	6A
0005435502390	1594	13	6D
0005434565964	1594	14	6C
0005434565957	1594	15	6E
0005435502383	1594	16	6F
0005435502377	1594	17	7C
0005435517970	1594	18	7D
0005435502376	1594	19	7E
0005435508398	1594	20	8A
0005435517975	1594	21	8D
0005435502380	1594	22	8C
0005433186085	1594	23	8F
0005433186084	1594	24	9A
0005433186059	1594	25	9C
0005435517961	1594	26	9D
0005435502386	1594	27	9E
0005435502387	1594	28	10A
0005434565963	1594	29	10D
0005435502394	1594	30	10E
0005435502388	1594	31	11A
0005435502392	1594	32	11D
0005434565961	1594	33	11E
0005435517972	1594	34	11F
0005435508395	1594	35	12A
0005435517962	1594	36	12C
0005433186067	1594	37	12D
0005435502375	1594	38	12E
0005432291938	1594	39	12F
0005435502391	1594	40	13A
0005433186056	1594	41	13C
0005435502384	1594	42	13D
0005435508396	1594	43	13E
0005434565959	1594	44	13F
0005434565954	1594	45	14A
0005435517973	1594	46	14C
0005435508399	1594	47	14D
0005434565967	1594	48	15A
0005434565962	1594	49	15D
0005433186081	1594	50	16A
0005432291940	1594	51	16C
0005435517971	1594	52	16E
0005434565960	1594	53	16F
0005435517966	1594	54	17A
0005434565956	1594	55	17C
0005435502385	1594	56	17D
0005435517963	1594	57	17E
0005435502381	1594	58	17F
0005435502395	1594	59	18A
0005435517974	1594	60	18E
0005434565958	1594	61	19A
0005435502379	1594	62	19D
0005434565953	1594	63	19E
0005435517969	1594	64	19F
0005435517968	1594	65	20A
0005435508397	1594	66	20D
0005434565955	1594	67	20F
0005434565810	20883	1	1A
0005434565840	20883	2	1C
0005434565795	20883	3	2A
0005435545715	20883	4	2C
0005434565841	20883	5	2F
0005434565826	20883	6	3A
0005434565812	20883	7	3C
0005435502066	20883	8	3D
0005435529179	20883	9	3F
0005434565813	20883	10	4A
0005435545672	20883	11	4F
0005433186147	20883	12	5A
0005435545678	20883	13	5D
0005435529107	20883	14	5E
0005435545716	20883	15	6C
0005433186151	20883	16	6D
0005435529109	20883	17	6E
0005435529072	20883	18	6F
0005435529081	20883	19	7A
0005435502202	20883	20	7C
0005435502214	20883	21	7D
0005435502159	20883	22	7E
0005435529108	20883	23	7F
0005435529126	20883	24	8A
0005435502194	20883	25	8C
0005435545655	20883	26	8D
0005435545712	20883	27	8E
0005435529067	20883	28	8F
0005435529180	20883	29	9A
0005435528980	20883	30	9C
0005435529106	20883	31	9D
0005435545707	20883	32	9E
0005435545710	20883	33	9F
0005434565805	20883	34	10A
0005435502083	20883	35	11A
0005435545679	20883	36	11D
0005433186149	20883	37	11E
0005434565806	20883	38	11F
0005435529143	20883	39	12A
0005433186144	20883	40	12D
0005434565842	20883	41	12E
0005434565859	20883	42	12F
0005435502195	20883	43	13A
0005435528942	20883	44	13C
0005435529129	20883	45	13D
0005435502158	20883	46	13E
0005433186146	20883	47	13F
0005434565804	20883	48	14A
0005434565858	20883	49	14C
0005433186145	20883	50	14D
0005434565801	20883	51	15A
0005435502172	20883	52	15F
0005435529210	20883	53	16A
0005434565835	20883	54	16C
0005435545680	20883	55	16E
0005434565793	20883	56	16F
0005435529130	20883	57	17C
0005435502088	20883	58	17E
0005435529118	20883	59	17F
0005435545650	20883	60	18A
0005434565882	20883	61	18C
0005434565794	20883	62	18D
0005434565846	20883	63	18E
0005435529037	20883	64	19A
0005435529125	20883	65	19C
0005433186150	20883	66	19E
0005435529066	20883	67	19F
0005435502224	20883	68	20C
0005435502154	20883	69	20D
0005433186148	20883	70	20E
0005435153766	3900	1	1A
0005435153764	3900	2	3D
0005435931573	3900	3	4C
0005435153762	3900	4	5C
0005435931583	3900	5	7C
0005435153765	3900	6	19A
0005435153763	3900	7	21B
0005435153761	3900	8	23B
0005435153700	21868	1	3C
0005435153724	21868	2	5B
0005435931612	21868	3	6A
0005435153681	21868	4	6D
0005435153723	21868	5	20A
0005435931613	21868	6	20B
0005435153699	21868	7	22A
0005435931615	21868	8	22B
0005435153716	21868	9	22D
0005435931614	21868	10	23A
0005432628903	7206	1	2A
0005432628893	7206	2	2B
0005435225546	7206	3	2D
0005432628899	7206	4	3A
0005435225483	7206	5	3C
0005432628895	7206	6	4A
0005432628901	7206	7	4D
0005432628897	7206	8	5A
0005432628894	7206	9	5B
0005435225492	7206	10	6A
0005432628890	7206	11	6B
0005435225538	7206	12	6D
0005432628891	7206	13	7A
0005432628898	7206	14	7D
0005435225574	7206	15	18C
0005432628888	7206	16	18D
0005432628896	7206	17	20A
0005432628889	7206	18	20B
0005435225535	7206	19	20C
0005435225517	7206	20	20D
0005432628902	7206	21	21A
0005432628892	7206	22	21B
0005432628900	7206	23	21C
0005435225536	7206	24	22B
0005435225537	7206	25	23A
0005435225516	7206	26	23B
0005432628719	28121	1	1A
0005435225607	28121	2	1B
0005432628765	28121	3	1D
0005435225611	28121	4	2B
0005432628837	28121	5	2D
0005432628740	28121	6	3A
0005432628856	28121	7	3B
0005432628770	28121	8	3C
0005432628794	28121	9	3D
0005432628764	28121	10	4B
0005432628691	28121	11	4C
0005435225615	28121	12	4D
0005432628845	28121	13	5A
0005435225614	28121	14	5B
0005432628795	28121	15	5C
0005435225613	28121	16	6D
0005432628839	28121	17	19B
0005435225609	28121	18	19C
0005432628754	28121	19	19D
0005432628807	28121	20	20A
0005432628840	28121	21	20B
0005435225610	28121	22	21A
0005435225612	28121	23	21C
0005432628741	28121	24	21D
0005435225608	28121	25	22B
0005432628756	28121	26	22C
0005432628742	28121	27	23A
0005434267929	8720	1	1B
0005434267930	8720	2	1D
0005434267928	8720	3	3C
0005435960062	8720	4	4B
0005434267931	8720	5	5A
0005435960063	8720	6	6B
0005434267936	8720	7	19D
0005434267940	8720	8	20C
0005435960061	8720	9	20D
0005434267937	8720	10	21B
0005435960064	8720	11	23B
0005435960047	15233	1	2A
0005434267960	15233	2	2C
0005435960009	15233	3	5A
0005434267962	15233	4	19D
0005434267961	15233	5	21A
0005434267963	15233	6	23A
0005432693147	1184	1	1C
0005432693137	1184	2	2A
0005432693142	1184	3	3A
0005432693156	1184	4	3D
0005432873259	1184	5	4D
0005432693140	1184	6	4F
0005432675179	1184	7	5C
0005432693153	1184	8	5A
0005432675180	1184	9	5F
0005432693145	1184	10	5D
0005432675178	1184	11	6E
0005432693148	1184	12	6D
0005432693144	1184	13	7A
0005432693152	1184	14	6F
0005432693138	1184	15	7C
0005432693135	1184	16	7D
0005432693158	1184	17	8E
0005432693157	1184	18	8D
0005432675176	1184	19	8F
0005432873237	1184	20	9D
0005432693129	1184	21	9F
0005432675183	1184	22	10C
0005432693154	1184	23	10E
0005432675188	1184	24	10D
0005432693128	1184	25	11A
0005432693132	1184	26	10F
0005432693143	1184	27	11B
0005432693150	1184	28	11D
0005432873265	1184	29	11C
0005432675175	1184	30	12B
0005432677584	1184	31	12A
0005432675181	1184	32	12D
0005432693149	1184	33	13C
0005432693131	1184	34	13B
0005432693130	1184	35	13E
0005432675184	1184	36	13D
0005432693146	1184	37	13F
0005432675182	1184	38	14D
0005432873266	1184	39	15B
0005432675187	1184	40	15C
0005432693133	1184	41	16A
0005432675177	1184	42	16B
0005432677582	1184	43	17D
0005432693141	1184	44	18B
0005432693136	1184	45	18D
0005432675185	1184	46	18F
0005432873238	1184	47	19D
0005432693127	1184	48	19F
0005432693139	1184	49	20C
0005432693151	1184	50	20B
0005432677583	1184	51	20A
0005432675186	1184	52	20D
0005432693155	1184	53	21B
0005432693134	1184	54	21A
0005432873258	1184	55	21E
0005432873318	17491	1	1C
0005432692963	17491	2	1A
0005432675050	17491	3	1F
0005432692951	17491	4	1D
0005432693015	17491	5	2D
0005432692976	17491	6	2C
0005432692855	17491	7	2F
0005432873314	17491	8	3D
0005432692956	17491	9	3C
0005432692901	17491	10	4F
0005432692989	17491	11	4D
0005432692837	17491	12	5D
0005432675066	17491	13	5A
0005432674995	17491	14	6B
0005432675018	17491	15	6A
0005432692849	17491	16	6D
0005432692850	17491	17	6E
0005432692886	17491	18	7C
0005432675019	17491	19	8A
0005432692968	17491	20	8C
0005432692851	17491	21	8B
0005432675065	17491	22	8D
0005432692988	17491	23	8F
0005432692818	17491	24	8E
0005432675078	17491	25	9A
0005432692932	17491	26	9F
0005432692922	17491	27	9E
0005432692943	17491	28	10B
0005432692887	17491	29	10C
0005432693013	17491	30	10D
0005432692961	17491	31	10F
0005432675020	17491	32	11B
0005432692844	17491	33	11D
0005432674979	17491	34	11F
0005432674978	17491	35	11E
0005432873316	17491	36	12B
0005432692962	17491	37	12A
0005432677539	17491	38	12C
0005432692806	17491	39	12F
0005432692845	17491	40	12E
0005432692967	17491	41	13A
0005432692838	17491	42	13C
0005432674977	17491	43	13B
0005432675036	17491	44	14B
0005432692942	17491	45	14D
0005432675072	17491	46	14C
0005432692843	17491	47	14F
0005432675094	17491	48	14E
0005432692958	17491	49	15B
0005432674976	17491	50	15E
0005432675095	17491	51	15D
0005432692874	17491	52	16A
0005432675017	17491	53	16E
0005432675077	17491	54	17A
0005432693014	17491	55	16F
0005432692856	17491	56	17D
0005432873317	17491	57	17E
0005432692899	17491	58	18E
0005432692805	17491	59	19A
0005432692950	17491	60	18F
0005432692959	17491	61	19C
0005432675096	17491	62	19F
0005432873315	17491	63	20B
0005432692902	17491	64	20A
0005432692957	17491	65	20C
0005432675035	17491	66	20E
0005432692819	17491	67	21E
0005434435225	1118	1	1B
0005433156764	1118	2	1C
0005434435231	1118	3	2B
0005434435235	1118	4	3A
0005434435237	1118	5	3B
0005433156731	1118	6	3C
0005434435233	1118	7	4C
0005433156732	1118	8	5C
0005434435229	1118	9	5D
0005434435239	1118	10	6B
0005434435236	1118	11	6D
0005433156713	1118	12	7B
0005434435234	1118	13	7C
0005433156745	1118	14	7D
0005434435232	1118	15	18B
0005434435226	1118	16	18C
0005434435228	1118	17	19B
0005434435238	1118	18	20B
0005434435230	1118	19	20D
0005433156691	1118	20	22B
0005433156765	1118	21	23A
0005434435227	1118	22	23B
0005433156777	17293	1	1A
0005433156773	17293	2	1B
0005433156778	17293	3	1D
0005433156782	17293	4	2A
0005434435112	17293	5	2B
0005434435077	17293	6	2C
0005433156774	17293	7	3B
0005433156779	17293	8	3C
0005434435117	17293	9	4C
0005434435038	17293	10	5A
0005433156780	17293	11	6A
0005433156781	17293	12	7A
0005434435101	17293	13	7D
0005433156775	17293	14	18A
0005434435096	17293	15	19A
0005434435116	17293	16	19C
0005434435099	17293	17	20C
0005434434971	17293	18	20D
0005434435095	17293	19	21A
0005433156776	17293	20	22B
0005435928120	4058	1	1B
0005435086858	4058	2	1C
0005435086861	4058	3	2C
0005435086857	4058	4	4A
0005435928117	4058	5	4B
0005435086859	4058	6	5B
0005435086860	4058	7	5C
0005435086856	4058	8	6D
0005435928124	4058	9	7A
0005435928122	4058	10	18B
0005435928139	4058	11	19C
0005435086855	4058	12	20C
0005435928118	4058	13	21A
0005435928121	4058	14	21C
0005435928106	4058	15	21D
0005435928105	4058	16	22B
0005435086862	4058	17	23B
0005435928157	24395	1	1A
0005435086763	24395	2	1B
0005435928160	24395	3	1D
0005435086774	24395	4	2B
0005435086806	24395	5	3C
0005435928158	24395	6	4A
0005435086802	24395	7	4C
0005435086762	24395	8	4D
0005435086803	24395	9	5A
0005435086813	24395	10	5D
0005435928159	24395	11	6D
0005435086778	24395	12	18A
0005435086814	24395	13	18C
0005435928156	24395	14	20C
0005435086805	24395	15	22B
0005435551520	11069	1	3H
0005435551529	11069	2	4A
0005435551555	11069	3	9G
0005435551539	11069	4	12A
0005435551572	11069	5	13H
0005435098540	11069	6	15B
0005435551574	11069	7	16B
0005435551514	11069	8	16A
0005435551499	11069	9	17F
0005435551537	11069	10	18A
0005435551556	11069	11	18E
0005435551498	11069	12	19D
0005435551569	11069	13	21F
0005435551549	11069	14	22H
0005435551573	11069	15	24H
0005435551554	11069	16	29A
0005435551519	11069	17	30B
0005435551570	11069	18	31E
0005435551548	11069	19	32B
0005435551541	11069	20	33D
0005435551575	11069	21	33H
0005435551571	11069	22	37B
0005435551540	11069	23	37E
0005435706417	2446	1	1A
0005435706432	2446	2	1C
0005433373499	2446	3	1D
0005435706427	2446	4	2D
0005435706437	2446	5	2F
0005435706429	2446	6	3F
0005435706421	2446	7	4A
0005433373444	2446	8	4E
0005435706415	2446	9	5A
0005435706438	2446	10	5C
0005435706423	2446	11	5F
0005435706419	2446	12	6C
0005435706436	2446	13	6E
0005435706428	2446	14	7A
0005435706442	2446	15	7E
0005435706447	2446	16	7F
0005433373498	2446	17	8A
0005435706441	2446	18	8C
0005433373474	2446	19	8E
0005435706443	2446	20	9E
0005435706418	2446	21	10A
0005435706439	2446	22	10C
0005435706416	2446	23	10D
0005435706444	2446	24	10E
0005435706425	2446	25	11A
0005433373462	2446	26	11C
0005433373456	2446	27	12C
0005435706445	2446	28	12E
0005433373497	2446	29	13A
0005435706435	2446	30	13C
0005435706422	2446	31	13D
0005433373472	2446	32	13F
0005435706420	2446	33	14A
0005435706426	2446	34	14C
0005435706448	2446	35	14D
0005433373495	2446	36	14E
0005435706424	2446	37	15E
0005435706446	2446	38	16A
0005433373478	2446	39	16D
0005435706434	2446	40	16F
0005433373486	2446	41	17C
0005435706430	2446	42	18C
0005435706433	2446	43	18F
0005435706431	2446	44	19A
0005435706440	2446	45	19D
0005433373479	2446	46	20C
0005435706296	27027	1	1A
0005435706305	27027	2	1C
0005433373558	27027	3	2C
0005435706264	27027	4	2F
0005433373561	27027	5	3A
0005433373564	27027	6	3F
0005435706228	27027	7	4A
0005433373563	27027	8	4C
0005435706253	27027	9	4D
0005433373556	27027	10	4E
0005433373555	27027	11	5A
0005435706321	27027	12	5C
0005435706217	27027	13	5D
0005435706267	27027	14	5F
0005435706363	27027	15	6E
0005435706287	27027	16	6F
0005435706298	27027	17	7A
0005435706266	27027	18	7C
0005433373569	27027	19	7D
0005435706248	27027	20	7F
0005435706303	27027	21	8A
0005435706325	27027	22	8C
0005435706273	27027	23	8E
0005435706187	27027	24	8F
0005433373567	27027	25	9A
0005433373551	27027	26	9E
0005435706326	27027	27	9F
0005435706254	27027	28	10A
0005435706295	27027	29	10D
0005435706274	27027	30	10F
0005433373560	27027	31	11A
0005435706320	27027	32	11C
0005433373566	27027	33	11F
0005433373552	27027	34	12E
0005433373562	27027	35	12F
0005435706240	27027	36	13E
0005435706284	27027	37	13F
0005435706261	27027	38	14A
0005435706265	27027	39	14D
0005433373559	27027	40	14F
0005433373553	27027	41	15A
0005435706312	27027	42	15C
0005435706299	27027	43	15D
0005433373571	27027	44	15E
0005435706286	27027	45	16A
0005435706294	27027	46	16C
0005435706288	27027	47	16F
0005435706252	27027	48	17A
0005435706293	27027	49	17C
0005433373554	27027	50	17D
0005435706289	27027	51	17E
0005435706304	27027	52	17F
0005435706242	27027	53	18A
0005433373557	27027	54	18D
0005435706218	27027	55	18E
0005435706243	27027	56	18F
0005435706272	27027	57	19E
0005433373568	27027	58	20A
0005433373570	27027	59	20E
0005433373565	27027	60	20F
0005434964269	1326	1	1B
0005434964297	1326	2	1H
0005434964295	1326	3	2H
0005434964298	1326	4	2G
0005434964293	1326	5	3B
0005434964288	1326	6	4B
0005433261437	1326	7	4C
0005434964294	1326	8	4H
0005432279279	1326	9	5B
0005434964278	1326	10	5G
0005434964267	1326	11	9B
0005434964273	1326	12	11A
0005433261465	1326	13	11E
0005434964285	1326	14	11D
0005434964286	1326	15	11F
0005433261501	1326	16	12A
0005433261506	1326	17	12B
0005434964270	1326	18	12E
0005433261489	1326	19	12H
0005434964303	1326	20	13A
0005434964266	1326	21	13D
0005434964283	1326	22	15D
0005434964300	1326	23	16B
0005433261490	1326	24	16E
0005434964282	1326	25	16F
0005434964291	1326	26	16H
0005434964279	1326	27	17A
0005433261530	1326	28	17D
0005432279277	1326	29	17G
0005434964277	1326	30	20H
0005433261505	1326	31	21H
0005434964272	1326	32	22A
0005434964274	1326	33	22E
0005433261527	1326	34	23G
0005434964275	1326	35	24A
0005432279278	1326	36	24B
0005434964302	1326	37	24F
0005434964292	1326	38	25D
0005433261502	1326	39	24H
0005433261500	1326	40	25E
0005434964281	1326	41	27A
0005434964271	1326	42	27F
0005433261503	1326	43	29A
0005433261491	1326	44	29E
0005433261499	1326	45	30E
0005434964268	1326	46	30G
0005434964304	1326	47	30F
0005432279276	1326	48	30H
0005433261486	1326	49	31A
0005434964296	1326	50	31D
0005434964287	1326	51	33A
0005433261528	1326	52	33B
0005434964290	1326	53	33H
0005433261529	1326	54	34A
0005434964276	1326	55	34G
0005433261515	1326	56	35A
0005434964301	1326	57	35H
0005433261533	1326	58	36G
0005434964280	1326	59	36H
0005434964284	1326	60	37H
0005434964299	1326	61	38H
0005434964289	1326	62	39E
0005434964127	18234	1	1H
0005433261585	18234	2	2A
0005434964113	18234	3	2F
0005433261589	18234	4	3B
0005433261601	18234	5	3C
0005433261602	18234	6	3G
0005433261598	18234	7	3F
0005433261577	18234	8	3H
0005433261592	18234	9	4G
0005434964088	18234	10	4F
0005434964119	18234	11	5C
0005433261606	18234	12	5H
0005433261588	18234	13	11B
0005433261596	18234	14	11D
0005434964114	18234	15	11H
0005434964118	18234	16	11G
0005434964176	18234	17	12D
0005433261578	18234	18	12E
0005434964136	18234	19	12F
0005433261576	18234	20	13A
0005434964138	18234	21	13E
0005434964115	18234	22	13H
0005434964047	18234	23	14E
0005433261603	18234	24	14D
0005433261582	18234	25	15D
0005433261593	18234	26	15G
0005434964087	18234	27	15F
0005434964050	18234	28	16E
0005433261586	18234	29	16D
0005434964135	18234	30	17A
0005434964122	18234	31	17B
0005434964116	18234	32	17E
0005434964058	18234	33	18E
0005433261580	18234	34	18D
0005434964102	18234	35	18G
0005433261594	18234	36	19B
0005433261599	18234	37	19H
0005434964085	18234	38	20A
0005433261584	18234	39	20D
0005434964089	18234	40	20E
0005434964003	18234	41	20G
0005433261597	18234	42	20F
0005434964101	18234	43	21B
0005433261605	18234	44	22B
0005433261607	18234	45	22E
0005434964142	18234	46	22F
0005434964128	18234	47	23B
0005433261579	18234	48	23F
0005434964060	18234	49	23E
0005434964062	18234	50	23G
0005433261587	18234	51	23H
0005434964083	18234	52	24G
0005434964182	18234	53	25F
0005434964183	18234	54	27B
0005434964078	18234	55	27G
0005434964086	18234	56	28A
0005434964158	18234	57	27H
0005434964090	18234	58	28B
0005434964067	18234	59	28D
0005434964080	18234	60	29A
0005433261595	18234	61	30A
0005434964120	18234	62	30G
0005434964082	18234	63	30H
0005434964160	18234	64	31E
0005433261590	18234	65	32A
0005433261583	18234	66	32E
0005434964063	18234	67	32F
0005434964139	18234	68	32H
0005433261581	18234	69	33E
0005434964095	18234	70	33D
0005434964111	18234	71	33F
0005434964051	18234	72	34A
0005434964094	18234	73	34G
0005433261604	18234	74	35A
0005434964181	18234	75	35B
0005434964105	18234	76	35D
0005434964137	18234	77	35H
0005434964141	18234	78	36D
0005434964180	18234	79	36F
0005434964074	18234	80	37B
0005434964117	18234	81	37F
0005434964140	18234	82	37G
0005434964103	18234	83	38A
0005433261591	18234	84	38D
0005434964073	18234	85	38B
0005433261600	18234	86	38E
0005434964096	18234	87	39E
0005435907466	4841	1	3F
0005434625996	4841	2	4D
0005434625989	4841	3	4F
0005434625987	4841	4	5E
0005434625990	4841	5	6A
0005434625993	4841	6	7A
0005434625991	4841	7	8A
0005433194833	4841	8	8C
0005434625995	4841	9	9A
0005434625992	4841	10	9E
0005435907467	4841	11	9F
0005435907479	4841	12	10C
0005433194846	4841	13	11C
0005434625994	4841	14	11F
0005435907478	4841	15	13A
0005435907493	4841	16	17D
0005434625988	4841	17	19C
0005435907498	4841	18	19E
0005434625890	32900	1	3A
0005435907521	32900	2	7C
0005435907520	32900	3	8A
0005434625957	32900	4	8E
0005435907518	32900	5	9A
0005434625900	32900	6	10C
0005434625889	32900	7	10F
0005435907519	32900	8	11E
0005434625935	32900	9	14C
0005435907517	32900	10	14F
0005434625928	32900	11	16C
0005434625934	32900	12	16D
0005434625904	32900	13	17A
0005434625901	32900	14	19C
0005434625887	32900	15	19F
0005435785277	13797	1	1A
0005435785247	13797	2	1B
0005435785090	13797	3	1C
0005435784982	13797	4	1D
0005435785176	13797	5	2B
0005435785194	13797	6	2C
0005435937399	13797	7	2D
0005435785038	13797	8	3A
0005435937396	13797	9	3B
0005435937393	13797	10	3C
0005435785099	13797	11	3D
0005435785074	13797	12	4A
0005435785246	13797	13	4B
0005435937398	13797	14	4C
0005435785136	13797	15	4D
0005435785067	13797	16	5A
0005435785014	13797	17	5B
0005435785106	13797	18	5C
0005435785230	13797	19	5D
0005435785026	13797	20	6B
0005435785248	13797	21	6C
0005435785071	13797	22	6D
0005435785075	13797	23	7A
0005435785126	13797	24	7B
0005435784993	13797	25	7C
0005435785063	13797	26	7D
0005435785100	13797	27	18A
0005435785162	13797	28	18B
0005435785003	13797	29	18C
0005435785145	13797	30	19A
0005435785054	13797	31	19B
0005435785133	13797	32	19C
0005435785123	13797	33	19D
0005432195700	13797	34	20A
0005435785001	13797	35	20B
0005435785053	13797	36	20C
0005435785111	13797	37	20D
0005435785245	13797	38	21A
0005435937395	13797	39	21B
0005435785064	13797	40	21C
0005435785107	13797	41	21D
0005435937397	13797	42	22A
0005435785108	13797	43	22B
0005432195699	13797	44	22C
0005435937394	13797	45	22D
0005435787335	13797	46	23A
0005435785146	13797	47	23B
0005435785427	27427	1	1A
0005435785412	27427	2	1B
0005435787358	27427	3	1C
0005435785406	27427	4	1D
0005435785410	27427	5	2A
0005435785403	27427	6	2B
0005435785429	27427	7	2C
0005435785432	27427	8	2D
0005435785426	27427	9	3A
0005435785422	27427	10	3B
0005435785436	27427	11	3C
0005435785416	27427	12	3D
0005435785431	27427	13	4A
0005435785418	27427	14	4C
0005435787359	27427	15	4D
0005432190635	27427	16	5A
0005435785413	27427	17	5B
0005435785434	27427	18	5C
0005435785405	27427	19	5D
0005435937335	27427	20	6A
0005435785428	27427	21	6B
0005435785404	27427	22	6C
0005435785414	27427	23	6D
0005435787357	27427	24	7A
0005435785419	27427	25	7B
0005435785425	27427	26	7C
0005435937338	27427	27	7D
0005435785435	27427	28	18A
0005435785421	27427	29	18B
0005432190637	27427	30	18C
0005435937340	27427	31	18D
0005435937334	27427	32	19A
0005435785417	27427	33	19B
0005435785411	27427	34	19C
0005435785408	27427	35	19D
0005435785423	27427	36	20A
0005435937339	27427	37	20B
0005435937336	27427	38	20C
0005435785415	27427	39	20D
0005435785420	27427	40	21A
0005435785424	27427	41	21B
0005435785430	27427	42	21C
0005435937341	27427	43	21D
0005435785407	27427	44	22A
0005432190636	27427	45	22B
0005435785433	27427	46	22C
0005435785402	27427	47	22D
0005435785409	27427	48	23A
0005432190638	27427	49	23B
0005432058397	20253	1	1A
0005434407428	20253	2	1C
0005434407320	20253	3	1D
0005434407440	20253	4	1F
0005434407210	20253	5	2A
0005434407451	20253	6	2C
0005434407253	20253	7	2D
0005434407500	20253	8	2F
0005434407207	20253	9	3A
0005435311098	20253	10	3C
0005434407230	20253	11	3D
0005434407541	20253	12	3F
0005434407589	20253	13	4A
0005434407385	20253	14	4C
0005434407499	20253	15	4D
0005435311095	20253	16	4E
0005434407394	20253	17	4F
0005434407515	20253	18	5A
0005434407510	20253	19	5C
0005434407463	20253	20	5E
0005434407396	20253	21	5F
0005434407363	20253	22	6A
0005434407404	20253	23	6C
0005434407121	20253	24	6D
0005435311100	20253	25	6E
0005434407640	20253	26	6F
0005434407542	20253	27	7A
0005434407623	20253	28	7C
0005434407624	20253	29	7D
0005434407694	20253	30	7E
0005434407299	20253	31	7F
0005434407610	20253	32	8A
0005434407411	20253	33	8C
0005434407571	20253	34	8E
0005434407517	20253	35	8F
0005434407622	20253	36	9C
0005432058395	20253	37	9D
0005434407476	20253	38	9E
0005434407444	20253	39	9F
0005434407672	20253	40	10A
0005434407384	20253	41	10C
0005434407611	20253	42	10D
0005434407274	20253	43	10E
0005434407586	20253	44	10F
0005434407458	20253	45	11A
0005434407448	20253	46	11D
0005434407301	20253	47	11E
0005434407633	20253	48	11F
0005434407302	20253	49	12C
0005434407648	20253	50	12D
0005435311101	20253	51	12E
0005435311099	20253	52	12F
0005434407441	20253	53	13C
0005435311103	20253	54	13D
0005434407649	20253	55	13E
0005434407632	20253	56	13F
0005434407439	20253	57	14A
0005435311097	20253	58	14C
0005432058393	20253	59	14D
0005434407252	20253	60	14E
0005434407272	20253	61	14F
0005434407300	20253	62	15A
0005434407450	20253	63	15C
0005434407673	20253	64	15D
0005434407397	20253	65	15E
0005434407410	20253	66	15F
0005432058394	20253	67	16C
0005434407334	20253	68	16D
0005434407683	20253	69	16E
0005435311104	20253	70	16F
0005434407459	20253	71	17A
0005434407471	20253	72	17C
0005434407427	20253	73	17D
0005434407487	20253	74	17E
0005435311102	20253	75	17F
0005434407467	20253	76	18A
0005434407433	20253	77	18C
0005432058396	20253	78	18D
0005434407390	20253	79	18E
0005434407052	20253	80	18F
0005434407663	20253	81	19A
0005434407516	20253	82	19C
0005434407412	20253	83	19D
0005435311096	20253	84	19E
0005434407233	20253	85	19F
0005435311094	20253	86	20A
0005434407315	20253	87	20C
0005434407377	20253	88	20D
0005434407319	20253	89	20E
0005434407231	20253	90	20F
0005434407964	26992	1	1C
0005434407966	26992	2	1D
0005434407962	26992	3	1F
0005434407955	26992	4	2A
0005434407946	26992	5	2C
0005432153962	26992	6	2D
0005435310927	26992	7	2F
0005432153959	26992	8	3A
0005434407959	26992	9	3C
0005434407961	26992	10	3D
0005434407982	26992	11	3F
0005434407989	26992	12	4A
0005432153958	26992	13	4C
0005434407992	26992	14	4D
0005434407978	26992	15	4E
0005434407931	26992	16	4F
0005434407984	26992	17	5C
0005435310928	26992	18	5E
0005434407986	26992	19	5D
0005434407970	26992	20	5F
0005434407968	26992	21	6A
0005434407939	26992	22	6C
0005434407967	26992	23	6D
0005434407941	26992	24	6E
0005435310949	26992	25	6F
0005434407958	26992	26	7A
0005435310992	26992	27	7C
0005432153957	26992	28	7E
0005434407981	26992	29	7D
0005434407977	26992	30	7F
0005435310976	26992	31	8A
0005434407972	26992	32	8D
0005434407940	26992	33	8E
0005432153960	26992	34	8F
0005434407969	26992	35	9A
0005434407954	26992	36	9C
0005434407935	26992	37	9D
0005435311003	26992	38	9E
0005434407987	26992	39	9F
0005434407932	26992	40	10A
0005434407991	26992	41	10C
0005434407974	26992	42	10D
0005434407933	26992	43	10F
0005435310982	26992	44	11A
0005434407983	26992	45	11C
0005435310987	26992	46	11D
0005434407993	26992	47	11E
0005435310977	26992	48	11F
0005434407973	26992	49	12A
0005434407971	26992	50	12C
0005435310940	26992	51	12F
0005434407980	26992	52	13A
0005434407949	26992	53	13C
0005434407953	26992	54	13D
0005435310945	26992	55	13E
0005434407944	26992	56	13F
0005434407938	26992	57	14A
0005434407963	26992	58	14C
0005434407942	26992	59	14D
0005434407948	26992	60	14E
0005435310993	26992	61	14F
0005434407979	26992	62	15A
0005434407947	26992	63	15C
0005434407976	26992	64	15D
0005434407990	26992	65	15E
0005434407957	26992	66	15F
0005435310926	26992	67	16A
0005434407960	26992	68	16C
0005435310939	26992	69	16D
0005434407951	26992	70	16F
0005432153963	26992	71	17A
0005434407975	26992	72	17C
0005435310951	26992	73	17D
0005434407988	26992	74	17E
0005434407965	26992	75	18A
0005434407985	26992	76	18C
0005434407937	26992	77	18D
0005434407943	26992	78	18E
0005435310967	26992	79	18F
0005432153961	26992	80	19A
0005434407956	26992	81	19C
0005434407952	26992	82	19D
0005435310983	26992	83	19E
0005434407945	26992	84	19F
0005434407950	26992	85	20A
0005434407934	26992	86	20C
0005435310986	26992	87	20D
0005434407930	26992	88	20E
0005434407936	26992	89	20F
0005434319439	5712	1	1C
0005434319424	5712	2	1D
0005434319426	5712	3	1F
0005434319429	5712	4	2A
0005433123830	5712	5	2D
0005434311228	5712	6	2F
0005434319436	5712	7	4E
0005434311227	5712	8	5A
0005433123788	5712	9	6A
0005432109712	5712	10	6C
0005434319438	5712	11	6D
0005433123806	5712	12	7A
0005433123799	5712	13	7C
0005434319444	5712	14	7F
0005434319428	5712	15	8D
0005434319431	5712	16	8E
0005433123829	5712	17	8F
0005433123746	5712	18	9E
0005432109711	5712	19	9F
0005433123840	5712	20	10D
0005434319427	5712	21	10F
0005434319433	5712	22	11A
0005433123811	5712	23	11C
0005434319435	5712	24	11D
0005434319445	5712	25	11E
0005433123814	5712	26	12A
0005434319423	5712	27	12C
0005433123815	5712	28	13D
0005433123795	5712	29	13E
0005433123745	5712	30	14A
0005434319443	5712	31	14F
0005432109715	5712	32	15A
0005432109713	5712	33	15C
0005434319441	5712	34	15D
0005434319430	5712	35	15F
0005434319432	5712	36	16D
0005434319437	5712	37	16E
0005434319425	5712	38	17C
0005433123804	5712	39	17D
0005434311226	5712	40	18A
0005433123787	5712	41	18D
0005432109714	5712	42	18F
0005434319440	5712	43	19A
0005434319434	5712	44	19F
0005434319442	5712	45	20A
0005433123737	5712	46	20F
0005433124006	15660	1	1F
0005433124008	15660	2	2F
0005433124012	15660	3	3C
0005434319279	15660	4	3D
0005433124009	15660	5	3F
0005433123997	15660	6	4A
0005434319254	15660	7	4D
0005433124011	15660	8	5A
0005433123995	15660	9	5D
0005433124002	15660	10	5E
0005433123994	15660	11	6D
0005434319262	15660	12	6E
0005433124003	15660	13	7C
0005434311207	15660	14	8E
0005434311206	15660	15	9A
0005434319249	15660	16	9C
0005433124013	15660	17	9D
0005434319282	15660	18	9F
0005433124010	15660	19	10C
0005434319250	15660	20	10D
0005434319288	15660	21	10F
0005434312303	15660	22	11A
0005434319280	15660	23	11C
0005433123999	15660	24	11D
0005433123992	15660	25	12C
0005434319278	15660	26	13D
0005433123996	15660	27	13F
0005434312304	15660	28	14A
0005434319277	15660	29	14C
0005433124000	15660	30	14F
0005433123991	15660	31	15A
0005433123990	15660	32	16A
0005433123998	15660	33	16E
0005433124007	15660	34	17D
0005433124004	15660	35	18A
0005433123993	15660	36	18E
0005433124001	15660	37	19A
0005433124005	15660	38	20E
0005434311208	15660	39	20F
0005435217696	24982	1	1C
0005435220301	24982	2	2A
0005435220299	24982	3	4A
0005435217699	24982	4	5A
0005435221512	24982	5	5C
0005435221504	24982	6	5D
0005435217698	24982	7	7C
0005435217695	24982	8	18D
0005435220306	24982	9	19A
0005435220300	24982	10	19B
0005435220298	24982	11	19C
0005435217697	24982	12	20B
0005435220297	24982	13	20D
0005435220302	24982	14	23A
0005434189147	8973	1	1A
0005434189132	8973	2	1D
0005434484366	8973	3	2B
0005434189123	8973	4	2C
0005434189134	8973	5	3D
0005434484370	8973	6	5B
0005434189125	8973	7	5C
0005434189133	8973	8	6B
0005434484368	8973	9	6D
0005434189124	8973	10	7A
0005434484372	8973	11	7C
0005434484371	8973	12	18D
0005434189157	8973	13	19C
0005434189158	8973	14	21A
0005434484367	8973	15	21B
0005434189128	8973	16	21C
0005434484369	8973	17	22A
0005434189155	8973	18	22B
0005434189154	8973	19	22D
0005434189148	8973	20	23B
0005434484300	16633	1	2A
0005434189197	16633	2	2D
0005434189199	16633	3	3C
0005434484314	16633	4	3D
0005434484312	16633	5	4C
0005434189198	16633	6	7A
0005434189194	16633	7	19B
0005434189196	16633	8	21B
0005434484323	16633	9	22A
0005434484301	16633	10	22B
0005434189195	16633	11	22C
0005433123998	7608	1	1D
0005433124012	7608	2	2D
0005433123996	7608	3	3D
0005433123992	7608	4	4D
0005433123997	7608	5	4E
0005433123993	7608	6	5C
0005433722174	7608	7	5E
0005433124009	7608	8	6C
0005433722183	7608	9	6E
0005433124001	7608	10	7C
0005433124005	7608	11	7F
0005433124000	7608	12	8A
0005433722191	7608	13	8D
0005433123994	7608	14	9A
0005433722178	7608	15	9D
0005433124007	7608	16	9E
0005433722159	7608	17	10A
0005433123995	7608	18	10F
0005433124003	7608	19	11A
0005433722196	7608	20	11F
0005433722181	7608	21	12F
0005433722173	7608	22	13C
0005433123990	7608	23	13F
0005433124010	7608	24	14A
0005433124004	7608	25	14C
0005433123999	7608	26	14D
0005433722158	7608	27	14F
0005433722157	7608	28	15C
0005433124002	7608	29	15E
0005433722164	7608	30	16A
0005433722156	7608	31	16D
0005433722165	7608	32	17A
0005433722179	7608	33	17D
0005433722175	7608	34	18A
0005433124011	7608	35	18C
0005433123991	7608	36	18F
0005433722176	7608	37	19A
0005433124006	7608	38	19C
0005433722180	7608	39	20A
0005433124008	7608	40	20D
0005433124013	7608	41	20E
0005432720980	7607	1	1C
0005433450032	7607	2	1D
0005432720994	7607	3	1F
0005433450030	7607	4	2A
0005432693161	7607	5	2C
0005433450037	7607	6	2D
0005432720991	7607	7	2F
0005432693181	7607	8	3A
0005432693178	7607	9	3C
0005433450029	7607	10	3D
0005432693187	7607	11	3F
0005432720995	7607	12	4A
0005432720978	7607	13	4D
0005432693185	7607	14	4E
0005432721001	7607	15	4F
0005432693163	7607	16	5D
0005432693183	7607	17	5E
0005432720981	7607	18	5F
0005433450041	7607	19	6A
0005432720993	7607	20	6F
0005432693172	7607	21	7A
0005432693177	7607	22	7C
0005432720996	7607	23	7D
0005432693186	7607	24	7E
0005432693167	7607	25	7F
0005432693166	7607	26	8C
0005432721002	7607	27	8D
0005432693175	7607	28	8E
0005432720985	7607	29	8F
0005433450031	7607	30	9A
0005432721003	7607	31	9D
0005432693168	7607	32	9F
0005432693179	7607	33	9E
0005432693189	7607	34	10A
0005432693170	7607	35	10C
0005432693162	7607	36	10E
0005432693174	7607	37	10F
0005433450050	7607	38	11A
0005432071584	7607	39	11C
0005432721000	7607	40	11D
0005432693184	7607	41	11E
0005432720983	7607	42	11F
0005432693188	7607	43	12A
0005432720997	7607	44	12C
0005432720979	7607	45	12D
0005433450045	7607	46	12E
0005433450035	7607	47	12F
0005433450047	7607	48	13A
0005432720988	7607	49	13C
0005432693169	7607	50	13D
0005433450049	7607	51	13E
0005432720990	7607	52	13F
0005433450036	7607	53	14A
0005433450039	7607	54	14C
0005432720987	7607	55	14D
0005433450038	7607	56	14E
0005433450033	7607	57	14F
0005432071583	7607	58	15A
0005432693164	7607	59	15C
0005432693165	7607	60	15D
0005432693180	7607	61	15E
0005432720986	7607	62	15F
0005433450046	7607	63	16A
0005433450048	7607	64	16C
0005433450040	7607	65	16D
0005433450043	7607	66	16F
0005432693171	7607	67	17A
0005432721005	7607	68	17C
0005432693159	7607	69	17D
0005432693160	7607	70	17E
0005432693173	7607	71	17F
0005432693176	7607	72	18A
0005432720982	7607	73	18C
0005432720998	7607	74	18D
0005433450044	7607	75	18E
0005432720984	7607	76	18F
0005433450034	7607	77	19A
0005432720999	7607	78	19C
0005432693182	7607	79	19D
0005433450042	7607	80	19E
0005432071582	7607	81	19F
0005432720989	7607	82	20A
0005433450051	7607	83	20C
0005432721004	7607	84	20D
0005432720992	7607	85	20E
0005432692886	30281	1	1A
0005432692843	30281	2	1D
0005432693013	30281	3	2C
0005432692951	30281	4	2F
0005433449722	30281	5	3A
0005432692845	30281	6	3C
0005432692958	30281	7	3D
0005433449915	30281	8	4A
0005432692956	30281	9	4C
0005432692849	30281	10	4D
0005433449717	30281	11	4F
0005433449841	30281	12	5A
0005433449958	30281	13	5D
0005433449842	30281	14	5F
0005432692957	30281	15	6A
0005432692932	30281	16	6F
0005433449832	30281	17	7A
0005432692942	30281	18	7C
0005432692805	30281	19	7D
0005432692961	30281	20	7E
0005432692902	30281	21	7F
0005432693014	30281	22	8A
0005432692899	30281	23	8D
0005433449937	30281	24	8E
0005432692901	30281	25	8F
0005433449810	30281	26	9C
0005432692838	30281	27	9D
0005432692818	30281	28	9E
0005432692943	30281	29	10C
0005433449901	30281	30	10D
0005432692962	30281	31	10E
0005432692959	30281	32	11C
0005432692874	30281	33	11D
0005432692851	30281	34	11F
0005432692850	30281	35	12C
0005433449855	30281	36	12E
0005432692988	30281	37	12F
0005432692856	30281	38	13D
0005432692887	30281	39	13F
0005433449936	30281	40	14A
0005432692844	30281	41	14D
0005433449765	30281	42	14F
0005432692950	30281	43	15D
0005432692989	30281	44	15E
0005432692963	30281	45	15F
0005432692837	30281	46	16A
0005432693015	30281	47	16C
0005432692806	30281	48	16F
0005432692922	30281	49	17C
0005432692967	30281	50	17D
0005433449723	30281	51	17E
0005433449766	30281	52	18A
0005432692976	30281	53	18D
0005432692819	30281	54	18E
0005432692968	30281	55	18F
0005433449780	30281	56	19A
0005433449902	30281	57	19E
0005433449725	30281	58	19F
0005432692855	30281	59	20D
0005432720723	30280	1	1C
0005432720777	30280	2	2A
0005433123795	30280	3	2C
0005433123799	30280	4	2D
0005433722237	30280	5	3C
0005432720883	30280	6	3D
0005433722245	30280	7	3F
0005432720764	30280	8	4E
0005432720753	30280	9	4F
0005432720752	30280	10	5A
0005432720837	30280	11	5C
0005433123788	30280	12	5D
0005433722242	30280	13	5E
0005432720882	30280	14	6A
0005433123811	30280	15	6C
0005432720749	30280	16	6D
0005433722239	30280	17	6E
0005433722240	30280	18	7A
0005433123746	30280	19	7D
0005432720755	30280	20	7E
0005432720667	30280	21	8A
0005433722238	30280	22	9A
0005432720885	30280	23	9D
0005433722241	30280	24	10A
0005432720881	30280	25	10D
0005432720671	30280	26	11D
0005433123830	30280	27	11E
0005432720802	30280	28	12C
0005433123815	30280	29	12E
0005432720801	30280	30	13C
0005433722244	30280	31	13D
0005433123804	30280	32	13E
0005433123787	30280	33	13F
0005433123737	30280	34	14D
0005433123829	30280	35	14F
0005432720735	30280	36	15C
0005433123814	30280	37	15E
0005432720803	30280	38	15F
0005432720770	30280	39	16A
0005433123745	30280	40	16D
0005432720739	30280	41	16E
0005432720836	30280	42	16F
0005432720765	30280	43	17C
0005432720766	30280	44	18E
0005433123806	30280	45	18F
0005432720884	30280	46	19C
0005432720811	30280	47	19D
0005433123840	30280	48	19F
0005432720763	30280	49	20C
0005433722243	30280	50	20D
0005432720778	30280	51	20E
0005432720769	30280	52	20F
0005434586684	1394	1	1A
0005432927957	1394	2	1C
0005433525071	1394	3	1D
0005433193017	1394	4	2C
0005433192982	1394	5	2D
0005433192960	1394	6	2F
0005434586705	1394	7	3A
0005434586687	1394	8	3D
0005433193016	1394	9	3F
0005434513589	1394	10	4A
0005432927955	1394	11	4C
0005434586691	1394	12	4E
0005433192987	1394	13	4F
0005434586703	1394	14	5A
0005433724820	1394	15	5C
0005433525076	1394	16	5D
0005434586700	1394	17	6C
0005434586706	1394	18	6D
0005433192981	1394	19	6E
0005433192971	1394	20	6F
0005434586701	1394	21	7A
0005434586696	1394	22	7C
0005434513590	1394	23	7E
0005432271012	1394	24	7F
0005433525073	1394	25	8C
0005432271014	1394	26	8D
0005433525074	1394	27	8E
0005433525079	1394	28	9C
0005434586690	1394	29	9D
0005433192984	1394	30	9E
0005434586693	1394	31	10C
0005434513591	1394	32	10D
0005434586695	1394	33	10F
0005434586688	1394	34	11A
0005434586692	1394	35	11F
0005433525078	1394	36	12A
0005432927956	1394	37	12C
0005434586685	1394	38	12D
0005433192959	1394	39	12F
0005434586689	1394	40	13A
0005432271013	1394	41	13C
0005433192972	1394	42	13F
0005434586683	1394	43	14A
0005434586686	1394	44	14C
0005434586702	1394	45	14D
0005434586699	1394	46	14E
0005434514975	1394	47	14F
0005434514977	1394	48	16A
0005433724819	1394	49	16C
0005433525077	1394	50	16D
0005434586697	1394	51	16E
0005432927926	1394	52	17A
0005434586704	1394	53	17C
0005433724821	1394	54	17D
0005434513588	1394	55	17E
0005433525075	1394	56	18A
0005432927939	1394	57	18C
0005434586707	1394	58	18D
0005434586708	1394	59	19A
0005434586698	1394	60	19C
0005434586694	1394	61	19D
0005433525072	1394	62	20A
0005433525070	1394	63	20D
0005434514976	1394	64	20F
0005432927996	18523	1	1A
0005434586525	18523	2	1C
0005434586562	18523	3	1D
0005434586531	18523	4	1F
0005434514946	18523	5	2A
0005433193083	18523	6	2D
0005433193084	18523	7	2F
0005433724792	18523	8	3C
0005433193095	18523	9	3D
0005433724778	18523	10	3F
0005433524977	18523	11	4C
0005434586482	18523	12	4E
0005434586387	18523	13	4F
0005434586537	18523	14	5A
0005434586437	18523	15	5C
0005432968847	18523	16	5D
0005432927997	18523	17	5F
0005433524964	18523	18	6A
0005434586448	18523	19	6D
0005434586524	18523	20	6E
0005434586547	18523	21	6F
0005434586542	18523	22	7A
0005433193092	18523	23	7C
0005433524997	18523	24	8A
0005433193093	18523	25	8C
0005433193088	18523	26	8D
0005434586373	18523	27	8E
0005433524958	18523	28	8F
0005434586480	18523	29	9A
0005433193090	18523	30	9C
0005434514957	18523	31	9E
0005434586412	18523	32	9F
0005434514963	18523	33	10C
0005434586413	18523	34	10D
0005434586507	18523	35	10F
0005434514964	18523	36	11A
0005433524961	18523	37	11F
0005432927995	18523	38	12C
0005434586451	18523	39	12D
0005432927998	18523	40	12E
0005434586506	18523	41	12F
0005434514941	18523	42	13C
0005433524962	18523	43	13D
0005434586374	18523	44	13E
0005433724772	18523	45	13F
0005434586460	18523	46	14C
0005434586505	18523	47	14D
0005433193086	18523	48	14E
0005434586541	18523	49	14F
0005433193094	18523	50	15A
0005433524960	18523	51	15C
0005434514940	18523	52	15D
0005432968846	18523	53	15E
0005434586414	18523	54	15F
0005433193085	18523	55	16A
0005433193082	18523	56	16C
0005434586466	18523	57	17C
0005432927999	18523	58	17E
0005433193091	18523	59	18A
0005433724793	18523	60	18C
0005434586449	18523	61	19A
0005433524959	18523	62	19D
0005433524963	18523	63	19F
0005434586386	18523	64	20A
0005433193089	18523	65	20C
0005433193087	18523	66	20D
0005434586500	18523	67	20E
0005435302179	11465	1	1A
0005434344308	11465	2	1B
0005435302157	11465	3	1D
0005434344302	11465	4	2A
0005434344296	11465	5	2B
0005434344321	11465	6	2D
0005434344309	11465	7	3A
0005434344304	11465	8	3B
0005434344287	11465	9	3C
0005434344297	11465	10	4A
0005434344295	11465	11	3D
0005434344324	11465	12	4B
0005434344319	11465	13	4C
0005434344314	11465	14	4D
0005434344315	11465	15	5A
0005435302126	11465	16	5B
0005434344318	11465	17	5C
0005434344317	11465	18	5D
0005434344313	11465	19	6A
0005434344311	11465	20	6B
0005434344300	11465	21	6C
0005434344306	11465	22	6D
0005434344305	11465	23	7A
0005434344322	11465	24	7B
0005434344293	11465	25	7C
0005434142624	11465	26	7D
0005434344307	11465	27	18A
0005434344301	11465	28	18B
0005434344289	11465	29	18C
0005434142622	11465	30	18D
0005434344290	11465	31	19B
0005434344288	11465	32	19C
0005434344323	11465	33	19D
0005434344294	11465	34	20A
0005434142625	11465	35	20B
0005434344291	11465	36	20C
0005435302127	11465	37	20D
0005434344292	11465	38	21A
0005434344299	11465	39	21B
0005434344320	11465	40	21C
0005434142623	11465	41	21D
0005434344298	11465	42	22A
0005434344303	11465	43	22B
0005434344310	11465	44	22C
0005434344316	11465	45	22D
0005434344312	11465	46	23A
0005435302169	11465	47	23B
0005434343962	29779	1	1A
0005434343930	29779	2	1B
0005434343931	29779	3	1C
0005434344037	29779	4	1D
0005435304175	29779	5	2A
0005434343968	29779	6	2B
0005434142585	29779	7	2C
0005434344025	29779	8	2D
0005434344133	29779	9	3A
0005435304176	29779	10	3B
0005434343855	29779	11	3C
0005434343897	29779	12	3D
0005434344010	29779	13	4A
0005434142584	29779	14	4B
0005434142583	29779	15	4C
0005434343939	29779	16	4D
0005435304178	29779	17	5A
0005434344136	29779	18	5B
0005434344098	29779	19	5C
0005434343947	29779	20	5D
0005434344080	29779	21	6A
0005434142586	29779	22	6C
0005434343948	29779	23	6D
0005434343967	29779	24	7A
0005434344174	29779	25	7B
0005434344067	29779	26	7C
0005434343927	29779	27	7D
0005435305016	29779	28	18A
0005434343976	29779	29	18B
0005435305017	29779	30	18C
0005434344081	29779	31	18D
0005434343883	29779	32	19A
0005434142587	29779	33	19B
0005434343929	29779	34	19C
0005434344011	29779	35	19D
0005435305018	29779	36	20A
0005434344094	29779	37	20B
0005434344110	29779	38	20C
0005435304177	29779	39	20D
0005434344042	29779	40	21A
0005434344101	29779	41	21B
0005435304174	29779	42	21C
0005434343896	29779	43	21D
0005434343953	29779	44	22A
0005434344100	29779	45	22B
0005434344013	29779	46	22C
0005434343957	29779	47	22D
0005434343963	29779	48	23A
0005434343878	29779	49	23B
0005433415653	1250	1	1A
0005435824722	1250	2	2A
0005433415663	1250	3	2D
0005433415525	1250	4	3D
0005435824717	1250	5	3F
0005432284569	1250	6	4D
0005435824727	1250	7	4F
0005435824707	1250	8	6D
0005435824703	1250	9	7B
0005435824726	1250	10	7E
0005435824705	1250	11	7F
0005433415664	1250	12	8E
0005435824724	1250	13	9C
0005435824723	1250	14	10A
0005433415563	1250	15	10D
0005433415603	1250	16	11A
0005435824701	1250	17	11F
0005435824720	1250	18	12D
0005435824725	1250	19	12C
0005435824704	1250	20	12B
0005435824714	1250	21	12E
0005433415579	1250	22	13B
0005435824710	1250	23	13E
0005433415580	1250	24	14A
0005435824712	1250	25	14B
0005435824700	1250	26	14D
0005435824709	1250	27	15A
0005435824708	1250	28	15C
0005432284568	1250	29	16B
0005435824719	1250	30	16E
0005435824711	1250	31	16D
0005435824718	1250	32	16F
0005435824721	1250	33	17C
0005435824716	1250	34	18D
0005433415595	1250	35	18C
0005435824715	1250	36	19C
0005435824702	1250	37	20D
0005435824713	1250	38	20E
0005435824706	1250	39	21F
0005435824521	17976	1	1D
0005435824459	17976	2	2C
0005433415706	17976	3	2D
0005433415713	17976	4	3C
0005435824364	17976	5	4C
0005435824524	17976	6	5F
0005433415717	17976	7	6B
0005435824453	17976	8	6A
0005435824602	17976	9	6C
0005435824559	17976	10	6E
0005435824417	17976	11	7A
0005435824365	17976	12	6F
0005435824455	17976	13	7C
0005433415704	17976	14	7B
0005435824426	17976	15	7F
0005435824504	17976	16	8B
0005433415711	17976	17	8E
0005433415719	17976	18	8C
0005433415718	17976	19	9A
0005435824503	17976	20	9D
0005433415708	17976	21	9F
0005435824363	17976	22	10F
0005435824482	17976	23	11D
0005433415715	17976	24	11F
0005433415714	17976	25	11E
0005435824418	17976	26	12C
0005435824525	17976	27	13C
0005435824485	17976	28	14D
0005435824454	17976	29	14E
0005435824366	17976	30	15B
0005435824458	17976	31	15D
0005433415709	17976	32	15C
0005433415712	17976	33	15E
0005435824475	17976	34	16D
0005435824408	17976	35	17A
0005435824514	17976	36	17D
0005433415707	17976	37	17C
0005433415705	17976	38	18F
0005435824505	17976	39	20E
0005435824367	17976	40	21B
0005433415716	17976	41	21D
0005433415710	17976	42	21C
0005435824499	17976	43	21E
0005434462778	17520	1	1D
0005434460493	17520	2	2D
0005434460484	17520	3	3A
0005434462761	17520	4	3B
0005434462781	17520	5	4B
0005434462782	17520	6	4C
0005434460479	17520	7	6C
0005434460494	17520	8	6D
0005434462776	17520	9	7C
0005434460487	17520	10	7D
0005434462777	17520	11	18A
0005434460497	17520	12	18C
0005434462779	17520	13	20C
0005434462768	17520	14	21A
0005434462774	17520	15	21C
0005432783947	5619	1	1A
0005432783977	5619	2	1C
0005435242613	5619	3	1D
0005435242680	5619	4	1F
0005435476704	5619	5	2A
0005432783981	5619	6	2C
0005435242686	5619	7	2D
0005432783987	5619	8	2F
0005432783975	5619	9	3A
0005432783982	5619	10	3C
0005435242812	5619	11	3D
0005435242711	5619	12	3F
0005432783969	5619	13	4A
0005432783959	5619	14	4C
0005432783942	5619	15	4D
0005435242709	5619	16	4E
0005435242676	5619	17	4F
0005435242762	5619	18	5A
0005435242761	5619	19	5C
0005432783962	5619	20	5D
0005432783985	5619	21	5E
0005432783954	5619	22	5F
0005435242728	5619	23	6A
0005435242771	5619	24	6C
0005432783960	5619	25	6D
0005432783945	5619	26	6E
0005435242770	5619	27	6F
0005432783971	5619	28	7A
0005432143999	5619	29	7C
0005435242715	5619	30	7D
0005435242768	5619	31	7E
0005432783992	5619	32	7F
0005435242769	5619	33	8A
0005432783980	5619	34	8C
0005435242578	5619	35	8D
0005432783965	5619	36	8E
0005435242635	5619	37	8F
0005432783968	5619	38	9A
0005432783949	5619	39	9C
0005432783970	5619	40	9D
0005435242675	5619	41	9E
0005432783963	5619	42	9F
0005432783989	5619	43	10A
0005435242651	5619	44	10C
0005435242688	5619	45	10D
0005432783961	5619	46	10E
0005432783994	5619	47	10F
0005432783993	5619	48	11A
0005432783976	5619	49	11C
0005432783995	5619	50	11E
0005432783986	5619	51	11F
0005432783988	5619	52	12A
0005435476693	5619	53	12C
0005432783990	5619	54	12D
0005432783958	5619	55	12E
0005432783991	5619	56	12F
0005435242733	5619	57	13A
0005432783979	5619	58	13C
0005432783984	5619	59	13D
0005432783953	5619	60	13E
0005432783967	5619	61	13F
0005432783952	5619	62	14A
0005435242732	5619	63	14C
0005432783972	5619	64	14D
0005435476694	5619	65	14E
0005435242708	5619	66	14F
0005432783946	5619	67	15A
0005432783983	5619	68	15C
0005432783955	5619	69	15D
0005435242723	5619	70	15E
0005435242535	5619	71	15F
0005432783944	5619	72	16A
0005432144001	5619	73	16C
0005435242664	5619	74	16D
0005432783950	5619	75	16E
0005432783964	5619	76	16F
0005432143998	5619	77	17A
0005435476712	5619	78	17C
0005432143997	5619	79	17D
0005432783951	5619	80	17E
0005432143996	5619	81	17F
0005432783957	5619	82	18A
0005432783940	5619	83	18C
0005435242687	5619	84	18D
0005432783941	5619	85	18E
0005432783978	5619	86	18F
0005432783943	5619	87	19A
0005432783956	5619	88	19C
0005432783974	5619	89	19D
0005435242650	5619	90	19E
0005432783948	5619	91	19F
0005432783966	5619	92	20A
0005432144000	5619	93	20C
0005435242689	5619	94	20D
0005432783973	5619	95	20E
0005435242665	5619	96	20F
0005435242932	15388	1	1A
0005432783431	15388	2	1C
0005432783310	15388	3	1D
0005432783518	15388	4	1F
0005432783443	15388	5	2A
0005435242918	15388	6	2C
0005435242912	15388	7	2D
0005432783476	15388	8	2F
0005435242924	15388	9	3A
0005435242922	15388	10	3C
0005432783403	15388	11	3D
0005432783437	15388	12	3F
0005432783154	15388	13	4A
0005435242920	15388	14	4C
0005432783165	15388	15	4D
0005432783457	15388	16	4E
0005432783703	15388	17	4F
0005435242930	15388	18	5C
0005432783529	15388	19	5D
0005432783520	15388	20	5E
0005435242927	15388	21	5F
0005432783705	15388	22	6A
0005432783408	15388	23	6C
0005435242935	15388	24	6D
0005432783409	15388	25	6E
0005432783318	15388	26	6F
0005432783234	15388	27	7D
0005432783305	15388	28	7E
0005435242928	15388	29	8A
0005432783357	15388	30	8C
0005435242919	15388	31	8D
0005435242913	15388	32	8E
0005432783455	15388	33	8F
0005435242921	15388	34	9A
0005435242931	15388	35	9C
0005435476768	15388	36	9D
0005432783538	15388	37	9E
0005432783465	15388	38	9F
0005432783510	15388	39	10A
0005435242926	15388	40	10C
0005432783576	15388	41	10D
0005432783722	15388	42	10E
0005432783335	15388	43	10F
0005432783399	15388	44	11A
0005432783477	15388	45	11C
0005432783155	15388	46	11D
0005435242923	15388	47	11E
0005432783417	15388	48	11F
0005432783359	15388	49	12A
0005432783295	15388	50	12C
0005435242929	15388	51	12D
0005435476771	15388	52	12E
0005432783358	15388	53	12F
0005435476773	15388	54	13A
0005435242934	15388	55	13C
0005432783178	15388	56	13D
0005435476776	15388	57	13E
0005432783402	15388	58	13F
0005435476775	15388	59	14C
0005432783562	15388	60	14D
0005435242933	15388	61	14E
0005432783660	15388	62	15A
0005435476777	15388	63	15C
0005432783561	15388	64	15D
0005435242925	15388	65	15E
0005435476778	15388	66	15F
0005432783371	15388	67	16A
0005435242909	15388	68	16D
0005435242908	15388	69	16E
0005432783364	15388	70	16F
0005435242914	15388	71	17A
0005432783704	15388	72	17C
0005435476772	15388	73	17D
0005432783717	15388	74	17E
0005432783303	15388	75	17F
0005435242917	15388	76	18A
0005432783466	15388	77	18C
0005432783304	15388	78	18D
0005435242915	15388	79	18E
0005432783478	15388	80	18F
0005432783511	15388	81	19A
0005432783294	15388	82	19C
0005435476769	15388	83	19D
0005435242911	15388	84	19E
0005435242910	15388	85	19F
0005432783018	15388	86	20A
0005435242916	15388	87	20C
0005435476774	15388	88	20D
0005435476770	15388	89	20E
0005432783519	15388	90	20F
0005435850865	4335	1	1A
0005435850868	4335	2	1C
0005432848358	4335	3	2A
0005432848353	4335	4	2B
0005432848357	4335	5	2D
0005432848360	4335	6	3B
0005432848363	4335	7	3C
0005434463936	4335	8	3D
0005434462797	4335	9	4A
0005435850909	4335	10	4D
0005435850857	4335	11	5C
0005435850903	4335	12	5D
0005432848365	4335	13	6B
0005432848356	4335	14	6C
0005432848355	4335	15	6D
0005432848361	4335	16	7C
0005432848359	4335	17	18A
0005432848354	4335	18	18B
0005432848364	4335	19	18C
0005435850902	4335	20	19B
0005435850860	4335	21	20A
0005435850875	4335	22	20B
0005435850873	4335	23	20D
0005435850901	4335	24	21B
0005432848366	4335	25	22C
0005432848352	4335	26	23A
0005432848362	4335	27	23B
0005435850942	28847	1	2A
0005435850943	28847	2	2D
0005432848266	28847	3	3D
0005434461636	28847	4	4A
0005435850940	28847	5	4B
0005435850938	28847	6	4C
0005432848251	28847	7	4D
0005435850936	28847	8	5A
0005435850945	28847	9	5B
0005435850941	28847	10	5C
0005434461637	28847	11	6A
0005432848304	28847	12	6B
0005432848238	28847	13	6D
0005435850944	28847	14	7A
0005432848220	28847	15	7B
0005435850939	28847	16	7C
0005432848255	28847	17	18C
0005434463924	28847	18	19D
0005434461635	28847	19	20A
0005432848219	28847	20	20D
0005432848265	28847	21	21B
0005432848206	28847	22	21C
0005435850935	28847	23	22A
0005432848245	28847	24	22D
0005435850937	28847	25	23A
0005432848246	28847	26	23B
0005434925911	6321	1	1A
0005433497074	6321	2	1C
0005434925922	6321	3	1D
0005434925902	6321	4	1F
0005434443768	6321	5	2C
0005434443765	6321	6	2D
0005434925900	6321	7	2F
0005434925917	6321	8	3A
0005434443756	6321	9	3C
0005434925894	6321	10	3D
0005433497076	6321	11	3F
0005433497059	6321	12	4A
0005433497079	6321	13	4C
0005433497072	6321	14	4D
0005432075240	6321	15	4E
0005433497087	6321	16	4F
0005433497062	6321	17	5A
0005433497061	6321	18	5C
0005434925907	6321	19	5D
0005434925903	6321	20	5F
0005434443761	6321	21	6A
0005434443764	6321	22	6C
0005434925887	6321	23	6D
0005432075242	6321	24	6E
0005434925889	6321	25	6F
0005434443758	6321	26	7A
0005433497088	6321	27	7C
0005434925910	6321	28	7D
0005434925893	6321	29	7E
0005434925883	6321	30	7F
0005434925895	6321	31	8A
0005433497082	6321	32	8C
0005434443760	6321	33	8D
0005434443757	6321	34	8E
0005434925886	6321	35	9A
0005433497064	6321	36	9C
0005433497080	6321	37	9D
0005434925914	6321	38	9E
0005433497078	6321	39	9F
0005434443763	6321	40	10A
0005433497071	6321	41	10C
0005434925918	6321	42	10D
0005434925899	6321	43	10E
0005434925898	6321	44	10F
0005434925884	6321	45	11A
0005433497085	6321	46	11C
0005434925896	6321	47	11D
0005434925919	6321	48	11E
0005434925920	6321	49	11F
0005434443766	6321	50	12A
0005433497077	6321	51	12C
0005433497067	6321	52	12D
0005434925916	6321	53	12E
0005433497066	6321	54	12F
0005433497060	6321	55	13A
0005434443770	6321	56	13C
0005434925890	6321	57	13D
0005434925888	6321	58	13E
0005434443762	6321	59	14A
0005434443755	6321	60	14C
0005434925906	6321	61	14D
0005433497069	6321	62	14E
0005433497070	6321	63	14F
0005434925901	6321	64	15A
0005433497073	6321	65	15D
0005434925912	6321	66	15E
0005433497084	6321	67	15F
0005433497086	6321	68	16A
0005434925892	6321	69	16C
0005434443767	6321	70	16D
0005433497063	6321	71	16E
0005434925908	6321	72	16F
0005434925905	6321	73	17A
0005433497089	6321	74	17C
0005433497083	6321	75	17D
0005433497065	6321	76	17E
0005434925904	6321	77	17F
0005434925891	6321	78	18A
0005434443769	6321	79	18D
0005433497075	6321	80	18E
0005434925897	6321	81	18F
0005433497081	6321	82	19A
0005434925921	6321	83	19C
0005434925913	6321	84	19D
0005434925885	6321	85	19E
0005434925915	6321	86	19F
0005434925909	6321	87	20A
0005432075241	6321	88	20C
0005433497058	6321	89	20D
0005434443759	6321	90	20E
0005433497068	6321	91	20F
0005434925570	20387	1	1A
0005434443655	20387	2	1D
0005434443626	20387	3	1F
0005434443624	20387	4	2A
0005434443636	20387	5	2C
0005434443635	20387	6	2D
0005433496837	20387	7	2F
0005434443491	20387	8	3A
0005433496966	20387	9	3C
0005434925569	20387	10	3D
0005433496881	20387	11	4A
0005434443576	20387	12	4D
0005433496808	20387	13	4E
0005434443625	20387	14	5A
0005434925539	20387	15	5C
0005434925576	20387	16	5D
0005433496786	20387	17	5F
0005434443595	20387	18	6A
0005434443627	20387	19	6C
0005434443553	20387	20	6D
0005434443589	20387	21	6F
0005434443674	20387	22	7A
0005434443637	20387	23	7C
0005434925621	20387	24	7D
0005434443550	20387	25	7E
0005433496889	20387	26	7F
0005434443575	20387	27	8D
0005434925531	20387	28	8E
0005434925618	20387	29	8F
0005434925538	20387	30	9A
0005434443594	20387	31	9C
0005434925575	20387	32	9D
0005434925611	20387	33	9E
0005433496834	20387	34	10A
0005434925620	20387	35	10C
0005434925430	20387	36	10D
0005434925597	20387	37	10E
0005433496937	20387	38	10F
0005434443573	20387	39	11A
0005433496796	20387	40	11C
0005433496831	20387	41	11D
0005434925578	20387	42	11E
0005434443588	20387	43	11F
0005434925574	20387	44	12A
0005433496801	20387	45	12C
0005434443599	20387	46	12D
0005433496838	20387	47	12E
0005434925622	20387	48	12F
0005434443628	20387	49	13A
0005433496770	20387	50	13C
0005433496781	20387	51	13E
0005433496690	20387	52	13F
0005434443549	20387	53	14A
0005433496830	20387	54	14C
0005433496878	20387	55	14D
0005433496764	20387	56	14F
0005433496936	20387	57	15A
0005433496938	20387	58	15C
0005433496769	20387	59	15E
0005434443598	20387	60	15F
0005433496807	20387	61	16C
0005433496802	20387	62	16D
0005434925530	20387	63	17A
0005433496765	20387	64	17C
0005433496800	20387	65	17D
0005434925619	20387	66	17E
0005434443548	20387	67	18A
0005434925397	20387	68	18D
0005434443572	20387	69	18E
0005433496771	20387	70	18F
0005433496785	20387	71	19A
0005434443591	20387	72	19C
0005434925532	20387	73	19D
0005434443586	20387	74	19E
0005433496871	20387	75	19F
0005434925523	20387	76	20A
0005433496833	20387	77	20C
0005433496782	20387	78	20D
0005433496880	20387	79	20E
0005433496793	20387	80	20F
0005432783591	12157	1	1A
0005435242953	12157	2	1C
0005432783681	12157	3	1D
0005432783317	12157	4	1F
0005435242945	12157	5	2C
0005432783390	12157	6	2D
0005432783621	12157	7	3A
0005432783546	12157	8	3C
0005432783642	12157	9	3F
0005435242962	12157	10	4A
0005432783824	12157	11	4C
0005435242958	12157	12	4D
0005432783586	12157	13	4E
0005432783632	12157	14	4F
0005432783515	12157	15	5A
0005432783336	12157	16	5C
0005432783643	12157	17	5D
0005432783585	12157	18	5F
0005435242947	12157	19	6A
0005432783669	12157	20	6C
0005432783690	12157	21	6D
0005432783524	12157	22	6E
0005432783481	12157	23	6F
0005432783484	12157	24	7A
0005432783770	12157	25	7C
0005432783495	12157	26	7D
0005432783349	12157	27	7E
0005435242954	12157	28	7F
0005432783641	12157	29	8A
0005435242939	12157	30	8C
0005432783412	12157	31	8D
0005432783526	12157	32	8E
0005435242951	12157	33	8F
0005432783398	12157	34	9A
0005432783580	12157	35	9C
0005432783198	12157	36	9D
0005435242937	12157	37	9E
0005435242942	12157	38	9F
0005435242938	12157	39	10A
0005435242936	12157	40	10C
0005432783332	12157	41	10D
0005432783568	12157	42	10E
0005435242944	12157	43	10F
0005435242959	12157	44	11A
0005432783609	12157	45	11C
0005432783494	12157	46	11D
0005435242960	12157	47	11E
0005432783360	12157	48	11F
0005435242955	12157	49	12A
0005432783493	12157	50	12C
0005432783547	12157	51	12D
0005432783633	12157	52	12E
0005435242941	12157	53	12F
0005435242961	12157	54	13A
0005435242956	12157	55	13C
0005435242957	12157	56	13D
0005432783449	12157	57	13E
0005432783528	12157	58	13F
0005432783571	12157	59	14A
0005432783636	12157	60	14C
0005435242952	12157	61	14D
0005432783482	12157	62	14E
0005432783682	12157	63	14F
0005432783579	12157	64	15A
0005435242940	12157	65	15D
0005432783489	12157	66	15F
0005432783637	12157	67	16A
0005432783581	12157	68	16C
0005435242946	12157	69	16E
0005432783448	12157	70	16F
0005432783572	12157	71	17A
0005435242950	12157	72	17D
0005432783590	12157	73	17E
0005432783655	12157	74	17F
0005432783543	12157	75	18A
0005435242948	12157	76	18C
0005435242949	12157	77	18D
0005432783492	12157	78	18E
0005432783413	12157	79	18F
0005432783582	12157	80	19A
0005432783393	12157	81	19C
0005432783527	12157	82	19D
0005432783388	12157	83	19E
0005432783525	12157	84	19F
0005432783389	12157	85	20C
0005435242943	12157	86	20D
0005432783491	12157	87	20E
0005432783480	12157	88	20F
0005435242571	15427	1	1A
0005432783903	15427	2	1D
0005432783935	15427	3	1F
0005435242631	15427	4	2A
0005435242787	15427	5	2C
0005435242572	15427	6	2D
0005432783912	15427	7	2F
0005435242658	15427	8	3C
0005432783913	15427	9	3F
0005435242690	15427	10	4A
0005432783932	15427	11	4C
0005432783910	15427	12	4D
0005432783921	15427	13	4E
0005432783895	15427	14	5A
0005432783938	15427	15	4F
0005432783914	15427	16	5C
0005435242694	15427	17	5E
0005432783925	15427	18	5F
0005435242630	15427	19	6A
0005432783902	15427	20	6C
0005432783893	15427	21	6D
0005432783905	15427	22	6E
0005432783888	15427	23	7A
0005432783936	15427	24	7C
0005432783917	15427	25	7D
0005432783906	15427	26	7E
0005432783911	15427	27	7F
0005432783920	15427	28	8D
0005432783897	15427	29	8F
0005432783898	15427	30	9A
0005432783919	15427	31	9C
0005432783901	15427	32	9D
0005435242587	15427	33	9E
0005435242760	15427	34	9F
0005432783930	15427	35	10A
0005435242786	15427	36	10C
0005435242588	15427	37	10D
0005435242657	15427	38	10F
0005435242722	15427	39	11A
0005432783904	15427	40	11C
0005432783909	15427	41	11D
0005435242555	15427	42	11E
0005432783928	15427	43	11F
0005432783899	15427	44	12A
0005432783927	15427	45	12C
0005432783934	15427	46	12D
0005432783892	15427	47	12F
0005432783926	15427	48	13A
0005432783889	15427	49	13D
0005432783900	15427	50	13E
0005432783885	15427	51	13F
0005432783908	15427	52	14A
0005432783929	15427	53	14C
0005432783924	15427	54	14D
0005432783896	15427	55	14E
0005432783886	15427	56	14F
0005432783916	15427	57	15A
0005432783918	15427	58	15C
0005432783931	15427	59	15D
0005435242673	15427	60	15F
0005432783937	15427	61	16A
0005435242671	15427	62	16D
0005435242785	15427	63	16F
0005435242670	15427	64	17C
0005435242632	15427	65	17F
0005432783922	15427	66	18A
0005432783890	15427	67	18C
0005435242612	15427	68	18D
0005435242663	15427	69	18E
0005432783923	15427	70	18F
0005435242611	15427	71	19A
0005432783907	15427	72	19C
0005432783887	15427	73	19D
0005435242724	15427	74	19E
0005432783933	15427	75	19F
0005432783915	15427	76	20A
0005432783894	15427	77	20C
0005432783939	15427	78	20D
0005432783891	15427	79	20E
0005434877589	10075	1	1C
0005434878041	10075	2	1A
0005434877252	10075	3	1F
0005434878004	10075	4	1D
0005434910120	10075	5	2C
0005434877744	10075	6	2A
0005434877312	10075	7	2D
0005434877824	10075	8	3A
0005434878172	10075	9	2F
0005434877921	10075	10	3D
0005434877679	10075	11	3C
0005434877804	10075	12	4A
0005434877289	10075	13	3F
0005434877680	10075	14	4D
0005434877559	10075	15	4C
0005434877816	10075	16	4F
0005434877863	10075	17	5C
0005434878194	10075	18	5A
0005434877756	10075	19	5F
0005434877892	10075	20	5D
0005434878005	10075	21	6B
0005434877843	10075	22	6A
0005434910119	10075	23	6D
0005434877988	10075	24	6C
0005434877857	10075	25	6F
0005434877526	10075	26	6E
0005434877605	10075	27	7B
0005434877152	10075	28	7A
0005434877742	10075	29	7C
0005434877856	10075	30	7E
0005434877249	10075	31	7D
0005434877789	10075	32	8A
0005434877153	10075	33	7F
0005434877790	10075	34	8B
0005434877796	10075	35	8D
0005434877253	10075	36	8C
0005434877567	10075	37	8F
0005434877737	10075	38	8E
0005434877541	10075	39	9B
0005434878051	10075	40	9A
0005434878068	10075	41	9D
0005434877773	10075	42	9C
0005434877748	10075	43	9E
0005434877974	10075	44	10A
0005434877465	10075	45	9F
0005434877864	10075	46	10C
0005434877783	10075	47	10B
0005434877371	10075	48	10E
0005434877557	10075	49	10D
0005434877525	10075	50	10F
0005434877989	10075	51	11B
0005434877678	10075	52	11A
0005434877735	10075	53	11D
0005434877650	10075	54	11C
0005434877648	10075	55	11F
0005434877604	10075	56	11E
0005434877749	10075	57	12A
0005434877758	10075	58	12D
0005434878205	10075	59	12C
0005434877372	10075	60	12B
0005434877886	10075	61	12E
0005434877659	10075	62	13A
0005434877844	10075	63	12F
0005434877757	10075	64	13C
0005434877759	10075	65	13B
0005434877936	10075	66	13E
0005434877858	10075	67	13D
0005434877660	10075	68	14A
0005434877725	10075	69	13F
0005434877450	10075	70	14B
0005434877893	10075	71	14D
0005434877937	10075	72	14C
0005434877845	10075	73	14F
0005434877392	10075	74	14E
0005434878178	10075	75	15B
0005434877228	10075	76	15A
0005434878033	10075	77	15D
0005434877624	10075	78	15C
0005434877860	10075	79	15E
0005434877649	10075	80	16A
0005434877658	10075	81	15F
0005434878021	10075	82	16C
0005434877781	10075	83	16B
0005434877350	10075	84	16E
0005434877990	10075	85	16D
0005434877464	10075	86	17A
0005434877651	10075	87	16F
0005434877647	10075	88	17C
0005434877723	10075	89	17B
0005434877634	10075	90	17D
0005434877865	10075	91	17E
0005434877670	10075	92	18B
0005434877453	10075	93	18A
0005434877717	10075	94	17F
0005434877736	10075	95	18C
0005434877797	10075	96	18E
0005434877922	10075	97	18D
0005434877760	10075	98	18F
0005434877794	10075	99	19C
0005434877540	10075	100	19B
0005434877772	10075	101	19A
0005434877409	10075	102	19D
0005434878107	10075	103	19F
0005434877641	10075	104	19E
0005434878022	10075	105	20C
0005434877452	10075	106	20B
0005434877975	10075	107	20A
0005434877581	10075	108	20D
0005434877642	10075	109	20E
0005434877791	10075	110	21B
0005434877823	10075	111	21A
0005434877810	10075	112	20F
0005434758878	10075	113	21C
0005434877486	10075	114	21E
0005434877558	10075	115	21D
0005434877743	10075	116	21F
0005434910101	14613	1	1C
0005434878572	14613	2	1A
0005434878532	14613	3	1D
0005434878553	14613	4	2C
0005434878503	14613	5	2A
0005434878570	14613	6	1F
0005434878501	14613	7	3C
0005434878564	14613	8	3A
0005435913891	14613	9	2F
0005434878573	14613	10	3D
0005434878504	14613	11	4A
0005434878523	14613	12	3F
0005435913892	14613	13	4D
0005434878488	14613	14	4C
0005434878567	14613	15	4F
0005435913911	14613	16	5D
0005434878529	14613	17	5C
0005434878568	14613	18	5F
0005434878537	14613	19	6B
0005434878530	14613	20	6A
0005434878549	14613	21	6C
0005434878527	14613	22	6F
0005434878494	14613	23	6E
0005434878559	14613	24	6D
0005434878563	14613	25	7A
0005434878506	14613	26	7C
0005434878498	14613	27	7B
0005434910099	14613	28	7D
0005434878542	14613	29	7F
0005435913868	14613	30	7E
0005434878533	14613	31	8B
0005435913910	14613	32	8A
0005434878484	14613	33	8D
0005434878560	14613	34	8F
0005434878576	14613	35	8E
0005434878552	14613	36	9A
0005434878489	14613	37	9D
0005435913898	14613	38	9C
0005434878487	14613	39	9B
0005434878546	14613	40	9E
0005434878524	14613	41	10A
0005434878565	14613	42	9F
0005434878521	14613	43	10B
0005434878547	14613	44	10E
0005434878495	14613	45	10D
0005434878557	14613	46	10F
0005434878536	14613	47	11B
0005434878562	14613	48	11A
0005434878548	14613	49	11D
0005435913897	14613	50	11C
0005434878550	14613	51	11F
0005434878538	14613	52	11E
0005434878499	14613	53	12A
0005434878574	14613	54	12B
0005434878502	14613	55	12E
0005434878522	14613	56	12D
0005434878493	14613	57	13B
0005434878561	14613	58	13A
0005434878485	14613	59	13C
0005434878520	14613	60	13E
0005434878541	14613	61	13D
0005434878569	14613	62	13F
0005434878492	14613	63	14B
0005434878544	14613	64	14A
0005434878551	14613	65	14C
0005434878571	14613	66	14F
0005434878526	14613	67	14E
0005434878545	14613	68	15B
0005434878514	14613	69	15A
0005434878555	14613	70	15D
0005434878566	14613	71	15C
0005434878496	14613	72	15F
0005434878510	14613	73	15E
0005434878577	14613	74	16A
0005434878483	14613	75	16C
0005434878508	14613	76	16B
0005434878554	14613	77	16E
0005434878535	14613	78	16D
0005434878519	14613	79	17A
0005434878516	14613	80	16F
0005434878486	14613	81	17B
0005434758900	14613	82	17D
0005434878525	14613	83	17C
0005434878505	14613	84	17F
0005434878578	14613	85	17E
0005434878507	14613	86	18A
0005434878517	14613	87	18D
0005434878543	14613	88	18C
0005434878556	14613	89	18B
0005434878511	14613	90	18E
0005435913906	14613	91	19A
0005434758901	14613	92	18F
0005434878490	14613	93	19B
0005434878515	14613	94	19D
0005434878518	14613	95	19C
0005434878500	14613	96	19F
0005434878558	14613	97	19E
0005434878512	14613	98	20B
0005434878528	14613	99	20A
0005434878531	14613	100	20D
0005434878509	14613	101	20C
0005434878513	14613	102	20F
0005434878539	14613	103	20E
0005434878491	14613	104	21A
0005434878497	14613	105	21C
0005434878540	14613	106	21B
0005434878575	14613	107	21E
0005434910100	14613	108	21D
0005434878534	14613	109	21F
0005435660176	9227	1	1C
0005435660174	9227	2	2C
0005435660169	9227	3	2D
0005434251951	9227	4	3D
0005435660170	9227	5	4A
0005435660173	9227	6	4D
0005435660175	9227	7	5B
0005434251885	9227	8	6B
0005434251922	9227	9	6D
0005434251949	9227	10	7A
0005434251912	9227	11	7B
0005434251929	9227	12	7C
0005435660172	9227	13	18A
0005434251869	9227	14	18D
0005435660177	9227	15	19B
0005434251950	9227	16	19C
0005435660178	9227	17	19D
0005434251884	9227	18	20C
0005435660168	9227	19	20D
0005434251921	9227	20	21A
0005435660171	9227	21	22C
0005434251898	9227	22	22D
0005435660031	24680	1	1A
0005434251996	24680	2	1B
0005434251994	24680	3	1C
0005435660090	24680	4	1D
0005435660030	24680	5	2C
0005434251997	24680	6	3A
0005435660057	24680	7	3D
0005435660056	24680	8	4A
0005435660058	24680	9	5D
0005435660029	24680	10	6A
0005435660092	24680	11	7A
0005434251998	24680	12	7C
0005434251995	24680	13	18A
0005435660089	24680	14	18C
0005435660088	24680	15	19B
0005435660091	24680	16	20B
0005434251992	24680	17	20C
0005434251993	24680	18	21C
0005434251999	24680	19	21D
0005434251991	24680	20	22B
0005434252000	24680	21	23A
0005433684426	2786	1	1A
0005432966776	2786	2	1C
0005432966728	2786	3	1D
0005432966841	2786	4	2A
0005433680688	2786	5	2F
0005433680725	2786	6	3A
0005433680695	2786	7	3C
0005433680717	2786	8	3D
0005433680690	2786	9	4A
0005432966848	2786	10	4C
0005433684425	2786	11	4D
0005433680723	2786	12	4E
0005433680691	2786	13	4F
0005433680720	2786	14	5A
0005433680733	2786	15	5D
0005432966808	2786	16	5E
0005433680718	2786	17	5F
0005432966842	2786	18	6A
0005433680701	2786	19	6C
0005432222800	2786	20	6D
0005433684424	2786	21	6E
0005433680694	2786	22	6F
0005433680714	2786	23	7A
0005432966871	2786	24	7C
0005433680692	2786	25	7D
0005433680705	2786	26	7E
0005433680724	2786	27	7F
0005433680687	2786	28	8C
0005433680719	2786	29	8D
0005433680707	2786	30	8E
0005433680689	2786	31	8F
0005433680709	2786	32	9A
0005433680728	2786	33	9C
0005432966786	2786	34	9D
0005433680712	2786	35	9E
0005433680716	2786	36	9F
0005433680700	2786	37	10C
0005433680708	2786	38	10D
0005432222799	2786	39	10E
0005433680731	2786	40	11A
0005433680686	2786	41	11C
0005432966865	2786	42	11D
0005433680703	2786	43	11E
0005433680727	2786	44	11F
0005433680706	2786	45	12A
0005432966815	2786	46	12D
0005432966727	2786	47	12E
0005433680713	2786	48	13C
0005432966798	2786	49	13D
0005432222797	2786	50	13E
0005432966765	2786	51	14A
0005433680715	2786	52	14C
0005433680699	2786	53	14D
0005433680722	2786	54	14E
0005432966793	2786	55	14F
0005433680704	2786	56	15C
0005433680730	2786	57	15D
0005432966864	2786	58	15E
0005432966650	2786	59	15F
0005433680696	2786	60	16A
0005432966730	2786	61	16C
0005433680702	2786	62	16D
0005433680698	2786	63	16E
0005433680732	2786	64	16F
0005432966816	2786	65	17A
0005433680729	2786	66	17C
0005433680693	2786	67	17F
0005432966830	2786	68	17E
0005433680711	2786	69	18C
0005432222798	2786	70	18D
0005433680710	2786	71	18E
0005432222796	2786	72	18F
0005432966866	2786	73	19A
0005433680726	2786	74	19C
0005433680734	2786	75	19F
0005432966843	2786	76	20A
0005433680697	2786	77	20C
0005432966742	2786	78	20D
0005433680721	2786	79	20E
0005432967011	29195	1	1A
0005433680185	29195	2	1C
0005432967003	29195	3	1D
0005433687694	29195	4	1F
0005433680294	29195	5	2A
0005433680186	29195	6	2C
0005433680470	29195	7	2D
0005433680392	29195	8	2F
0005433690920	29195	9	3A
0005433680408	29195	10	3C
0005432967010	29195	11	3D
0005433680187	29195	12	4A
0005432967014	29195	13	4C
0005433680351	29195	14	4E
0005433680225	29195	15	4F
0005433680409	29195	16	5A
0005433680238	29195	17	5C
0005433684411	29195	18	5D
0005433680352	29195	19	5E
0005433680391	29195	20	5F
0005433680237	29195	21	6A
0005432967015	29195	22	6C
0005433684412	29195	23	6D
0005433680355	29195	24	6E
0005433680476	29195	25	7A
0005432967026	29195	26	7C
0005433690913	29195	27	7D
0005433680317	29195	28	7E
0005432967006	29195	29	7F
0005433680371	29195	30	8A
0005432967016	29195	31	8C
0005432967013	29195	32	8D
0005432967020	29195	33	8E
0005433687695	29195	34	8F
0005433680295	29195	35	9C
0005432967022	29195	36	9D
0005432967019	29195	37	9E
0005432967025	29195	38	9F
0005432005222	29195	39	10A
0005432967002	29195	40	10C
0005432967004	29195	41	10D
0005433684413	29195	42	10F
0005433680304	29195	43	11C
0005432005221	29195	44	11E
0005433680356	29195	45	11F
0005433680309	29195	46	12A
0005433680466	29195	47	12C
0005433680357	29195	48	12D
0005433680423	29195	49	12E
0005433680517	29195	50	12F
0005433680440	29195	51	13A
0005433680052	29195	52	13C
0005432967007	29195	53	13D
0005433680559	29195	54	13E
0005433680419	29195	55	13F
0005432967027	29195	56	14A
0005433680308	29195	57	14C
0005433680456	29195	58	14E
0005433680379	29195	59	14F
0005433680354	29195	60	15A
0005433680422	29195	61	15C
0005433690919	29195	62	15D
0005432967017	29195	63	15E
0005432005223	29195	64	15F
0005433680372	29195	65	16A
0005432967023	29195	66	16C
0005433680358	29195	67	16D
0005433690921	29195	68	16E
0005432967024	29195	69	16F
0005433680289	29195	70	17A
0005433680293	29195	71	17C
0005433687696	29195	72	17D
0005433690912	29195	73	17E
0005433680229	29195	74	18A
0005432967008	29195	75	18D
0005433680533	29195	76	18E
0005433680405	29195	77	18F
0005433680457	29195	78	19A
0005433680420	29195	79	19C
0005432967018	29195	80	19D
0005432967005	29195	81	19E
0005432967009	29195	82	19F
0005433680520	29195	83	20A
0005433680368	29195	84	20C
0005432967021	29195	85	20D
0005432967012	29195	86	20F
0005433633885	9289	1	1A
0005433614839	9289	2	1C
0005433577853	9289	3	1F
0005433633882	9289	4	1D
0005432756859	9289	5	2C
0005433614831	9289	6	2F
0005433614868	9289	7	2D
0005434163549	9289	8	3C
0005433614816	9289	9	3A
0005433614857	9289	10	3D
0005433614840	9289	11	4A
0005434163581	9289	12	3F
0005433614850	9289	13	4C
0005433577851	9289	14	4F
0005433614863	9289	15	4D
0005434269089	9289	16	5C
0005433633907	9289	17	5D
0005433614872	9289	18	6A
0005433614837	9289	19	5F
0005433614833	9289	20	6C
0005433614826	9289	21	6F
0005433633888	9289	22	6D
0005433577839	9289	23	7C
0005433614875	9289	24	7F
0005433614844	9289	25	7D
0005433614846	9289	26	8A
0005432755085	9289	27	8B
0005433614876	9289	28	8D
0005432145117	9289	29	8C
0005433614843	9289	30	8E
0005433577848	9289	31	8F
0005434272178	9289	32	9B
0005433633909	9289	33	9A
0005433614879	9289	34	9C
0005433614815	9289	35	9E
0005433614822	9289	36	9D
0005433633881	9289	37	9F
0005434272182	9289	38	10A
0005433614881	9289	39	10B
0005433614864	9289	40	10C
0005433633891	9289	41	10E
0005433614855	9289	42	10D
0005434163594	9289	43	10F
0005433614835	9289	44	11A
0005433614834	9289	45	11C
0005433577852	9289	46	11B
0005433614842	9289	47	11D
0005433614832	9289	48	11F
0005433577844	9289	49	12A
0005433633898	9289	50	12C
0005433577842	9289	51	12B
0005433614874	9289	52	12D
0005433614836	9289	53	12F
0005432145116	9289	54	13B
0005432755086	9289	55	13A
0005433614825	9289	56	13C
0005433614871	9289	57	13E
0005433614830	9289	58	14A
0005433614819	9289	59	13F
0005433633880	9289	60	14B
0005433633908	9289	61	14C
0005433614817	9289	62	15A
0005433614823	9289	63	14F
0005434163547	9289	64	14E
0005433614877	9289	65	15B
0005433614860	9289	66	15C
0005433614838	9289	67	15E
0005434269093	9289	68	15D
0005434163552	9289	69	16A
0005433633879	9289	70	16B
0005433614847	9289	71	16D
0005433614859	9289	72	16E
0005433633892	9289	73	16F
0005433633897	9289	74	17B
0005433614821	9289	75	17A
0005433614867	9289	76	17C
0005433633894	9289	77	17D
0005433614812	9289	78	17F
0005433633901	9289	79	18A
0005433614810	9289	80	18B
0005433633887	9289	81	18D
0005433577840	9289	82	18C
0005433614854	9289	83	18E
0005433577843	9289	84	19B
0005433633890	9289	85	19D
0005433614829	9289	86	19C
0005433633877	9289	87	19E
0005433633893	9289	88	20B
0005433614820	9289	89	20A
0005433614814	9289	90	20C
0005433614866	9289	91	20F
0005433614841	9289	92	20E
0005434272179	9289	93	21A
0005434163548	9289	94	21B
0005433614856	9289	95	21D
0005433614809	9289	96	21F
0005433633896	9289	97	21E
0005433633900	9289	98	22A
0005433633902	9289	99	22B
0005433614862	9289	100	22C
0005432756857	9289	101	22D
0005433577841	9289	102	22F
0005433614824	9289	103	22E
0005433633910	9289	104	23A
0005433614878	9289	105	23B
0005433633905	9289	106	23D
0005433614861	9289	107	23E
0005433633899	9289	108	23F
0005432756858	9289	109	24B
0005433614827	9289	110	24A
0005433633903	9289	111	24D
0005433614813	9289	112	24F
0005433633889	9289	113	24E
0005433614811	9289	114	25A
0005433577849	9289	115	25C
0005433633883	9289	116	25D
0005433577850	9289	117	25E
0005433614828	9289	118	26A
0005434153529	9289	119	25F
0005433614869	9289	120	26B
0005434163550	9289	121	26C
0005433577847	9289	122	26E
0005434153525	9289	123	26D
0005433614851	9289	124	26F
0005433614882	9289	125	27B
0005433614873	9289	126	27A
0005433614865	9289	127	27C
0005434163588	9289	128	27E
0005432756860	9289	129	28A
0005433577846	9289	130	27F
0005433614848	9289	131	28D
0005433633886	9289	132	28C
0005433614845	9289	133	28E
0005433614853	9289	134	28F
0005433577845	9289	135	29A
0005433614858	9289	136	29C
0005433633884	9289	137	29B
0005433614880	9289	138	29E
0005434163589	9289	139	29F
0005433614849	9289	140	30A
0005433614870	9289	141	30C
0005433614852	9289	142	30E
0005433614818	9289	143	31B
0005433633895	9289	144	31A
0005433633878	9289	145	31C
0005433633904	9289	146	31D
0005434272180	9289	147	31F
0005433633906	9289	148	31E
0005433577722	25246	1	1A
0005433613843	25246	2	1C
0005433613982	25246	3	1D
0005433614189	25246	4	2A
0005433614163	25246	5	1F
0005433577783	25246	6	2C
0005433614283	25246	7	2D
0005433614320	25246	8	2F
0005433614193	25246	9	3C
0005433614322	25246	10	3A
0005433633641	25246	11	3F
0005434272197	25246	12	3D
0005433614239	25246	13	4A
0005433614218	25246	14	4C
0005433577769	25246	15	4D
0005434163640	25246	16	4F
0005433633735	25246	17	5C
0005433577712	25246	18	5A
0005433614196	25246	19	6A
0005433633599	25246	20	6D
0005433614204	25246	21	6F
0005433614092	25246	22	7A
0005433614227	25246	23	7C
0005433614171	25246	24	7D
0005433614051	25246	25	7F
0005433614254	25246	26	8C
0005433577711	25246	27	8B
0005433633726	25246	28	8E
0005433614219	25246	29	8F
0005433614395	25246	30	9B
0005433614511	25246	31	9A
0005433614282	25246	32	9C
0005433577622	25246	33	10A
0005433577639	25246	34	9F
0005433614417	25246	35	10B
0005433614194	25246	36	10C
0005433614050	25246	37	10D
0005433614089	25246	38	10F
0005433577770	25246	39	10E
0005433613949	25246	40	11B
0005433633456	25246	41	11A
0005433633610	25246	42	11C
0005433614155	25246	43	11D
0005433614284	25246	44	11E
0005433614418	25246	45	12A
0005433614195	25246	46	11F
0005433633595	25246	47	12B
0005433633578	25246	48	12D
0005433633425	25246	49	12F
0005433633424	25246	50	13A
0005433614266	25246	51	13B
0005433614546	25246	52	13D
0005433614040	25246	53	13C
0005433614149	25246	54	13F
0005433577638	25246	55	13E
0005433633558	25246	56	14A
0005434163638	25246	57	14C
0005434272196	25246	58	14B
0005433614470	25246	59	14E
0005433614088	25246	60	14D
0005433633623	25246	61	14F
0005433633600	25246	62	15B
0005433614439	25246	63	15A
0005433633540	25246	64	15E
0005433633497	25246	65	15D
0005434163643	25246	66	15F
0005433613983	25246	67	16A
0005433614522	25246	68	16B
0005433614531	25246	69	16C
0005433614147	25246	70	16E
0005433614662	25246	71	16D
0005433633589	25246	72	16F
0005433633836	25246	73	17B
0005433633704	25246	74	17A
0005433633559	25246	75	17C
0005433614074	25246	76	17D
0005433614359	25246	77	17E
0005433633496	25246	78	18A
0005433577782	25246	79	17F
0005433614520	25246	80	18D
0005434163645	25246	81	18C
0005433614103	25246	82	19B
0005433614249	25246	83	18F
0005433633590	25246	84	19D
0005433614039	25246	85	19C
0005433633418	25246	86	19E
0005433633740	25246	87	20A
0005433613948	25246	88	20C
0005433614276	25246	89	20E
0005433633609	25246	90	20F
0005433614265	25246	91	21A
0005434163646	25246	92	21D
0005433577721	25246	93	21C
0005433633736	25246	94	21E
0005433614049	25246	95	21F
0005433614341	25246	96	22B
0005433613992	25246	97	22C
0005433614121	25246	98	22D
0005433577689	25246	99	22F
0005433614245	25246	100	22E
0005433614240	25246	101	23A
0005433633621	25246	102	23C
0005434273080	25246	103	23B
0005434163644	25246	104	23D
0005433614407	25246	105	24A
0005434163639	25246	106	23F
0005433633457	25246	107	24B
0005433614310	25246	108	24D
0005433633567	25246	109	24C
0005433614268	25246	110	24E
0005434163642	25246	111	24F
0005433613923	25246	112	25B
0005433633548	25246	113	25A
0005433614119	25246	114	25C
0005433614321	25246	115	25D
0005433633579	25246	116	25E
0005433614235	25246	117	25F
0005433614215	25246	118	26A
0005433613775	25246	119	26C
0005433613993	25246	120	26D
0005433633493	25246	121	27A
0005433614340	25246	122	27B
0005433614302	25246	123	27D
0005434163641	25246	124	27F
0005433633527	25246	125	28A
0005433614122	25246	126	28B
0005433614530	25246	127	28D
0005433613750	25246	128	28C
0005433577747	25246	129	28E
0005433633560	25246	130	29A
0005433614209	25246	131	29C
0005433614150	25246	132	29B
0005433633538	25246	133	29D
0005433614469	25246	134	29F
0005434272195	25246	135	29E
0005434163647	25246	136	30A
0005433614200	25246	137	30B
0005433614521	25246	138	30C
0005433633664	25246	139	30D
0005433614120	25246	140	30F
0005433614008	25246	141	31A
0005433577757	25246	142	31C
0005433633601	25246	143	31B
0005433614165	25246	144	31E
0005433614222	25246	145	31F
0005432571303	4236	1	1F
0005435947200	4236	2	1G
0005435947140	4236	3	2C
0005435947138	4236	4	4A
0005435947216	4236	5	4B
0005435947157	4236	6	4H
0005432184959	4236	7	5C
0005435856158	4236	8	9B
0005435947134	4236	9	9G
0005432184958	4236	10	11E
0005434271291	4236	11	12E
0005435947133	4236	12	12H
0005435947173	4236	13	13A
0005434271299	4236	14	13D
0005435947196	4236	15	13G
0005435854052	4236	16	16B
0005435856173	4236	17	16F
0005435787339	4236	18	17B
0005435947177	4236	19	18A
0005435787340	4236	20	18E
0005435854053	4236	21	18G
0005435947178	4236	22	19H
0005435947076	4236	23	22E
0005432571304	4236	24	22G
0005435947197	4236	25	22F
0005435787338	4236	26	24A
0005435947174	4236	27	25D
0005435854050	4236	28	27B
0005435947161	4236	29	28E
0005435947201	4236	30	29B
0005435947139	4236	31	29G
0005434271300	4236	32	31D
0005435947192	4236	33	32B
0005435947150	4236	34	33G
0005434271304	4236	35	34A
0005435947124	4236	36	34D
0005432184960	4236	37	35E
0005435854049	4236	38	36A
0005435947193	4236	39	36F
0005435854054	4236	40	36G
0005435947304	26582	1	1H
0005435856216	26582	2	2C
0005435947296	26582	3	2B
0005435986709	26582	4	3A
0005435947303	26582	5	3H
0005435986714	26582	6	5A
0005435986715	26582	7	9H
0005435947295	26582	8	11A
0005435947299	26582	9	12D
0005432571335	26582	10	13G
0005435947301	26582	11	14D
0005435787363	26582	12	16D
0005435947305	26582	13	18B
0005435947306	26582	14	18E
0005435947298	26582	15	18H
0005435856219	26582	16	20A
0005435947297	26582	17	20B
0005435787361	26582	18	20E
0005432571336	26582	19	21E
0005435947308	26582	20	23B
0005435986713	26582	21	23A
0005435856218	26582	22	24F
0005435787362	26582	23	24H
0005435787364	26582	24	27G
0005435947300	26582	25	27H
0005435986742	26582	26	28D
0005435986722	26582	27	29D
0005435986729	26582	28	30B
0005435986707	26582	29	33F
0005435947302	26582	30	34A
0005435856217	26582	31	34E
0005435986700	26582	32	35A
0005435986701	26582	33	35G
0005432571337	26582	34	37A
0005435986708	26582	35	37F
0005435947307	26582	36	37H
0005432571334	26582	37	39E
0005433569254	342	1	1A
0005432948115	342	2	1C
0005433569295	342	3	1D
0005433569274	342	4	2A
0005433569270	342	5	2D
0005433569273	342	6	3A
0005433569296	342	7	2F
0005432948180	342	8	3C
0005433569286	342	9	3F
0005433569267	342	10	4A
0005433569260	342	11	4C
0005433074593	342	12	4F
0005433569294	342	13	4D
0005432948179	342	14	5C
0005433569276	342	15	5F
0005432948142	342	16	5D
0005433569242	342	17	6A
0005432238956	342	18	6D
0005433569259	342	19	6C
0005433569249	342	20	6F
0005433074589	342	21	7A
0005433569279	342	22	7C
0005433569266	342	23	7F
0005433074566	342	24	7D
0005432948132	342	25	8A
0005433569299	342	26	8B
0005432238955	342	27	8D
0005432948210	342	28	8C
0005433569278	342	29	8E
0005433074501	342	30	8F
0005432948126	342	31	9B
0005432948381	342	32	9A
0005433074503	342	33	9D
0005433569252	342	34	9F
0005433569244	342	35	9E
0005433569246	342	36	10A
0005433074565	342	37	10B
0005433074685	342	38	10D
0005432238958	342	39	10C
0005433074579	342	40	10E
0005433569262	342	41	10F
0005433569275	342	42	11B
0005433569264	342	43	11C
0005433569263	342	44	11D
0005432238954	342	45	11F
0005433134121	342	46	12A
0005432948206	342	47	12B
0005432948153	342	48	12D
0005432948309	342	49	12C
0005433074404	342	50	12E
0005433074550	342	51	12F
0005433569250	342	52	13C
0005432238957	342	53	13B
0005433134123	342	54	13D
0005433569283	342	55	13F
0005433569285	342	56	13E
0005433074594	342	57	14A
0005432948160	342	58	14B
0005432948175	342	59	14D
0005433569271	342	60	14C
0005432948143	342	61	14E
0005433074462	342	62	14F
0005432948187	342	63	15B
0005433074650	342	64	15C
0005433569292	342	65	15D
0005433569268	342	66	15E
0005433074463	342	67	16A
0005433569289	342	68	16B
0005433074595	342	69	16D
0005433074455	342	70	16C
0005433569256	342	71	16E
0005432948161	342	72	16F
0005433074558	342	73	17A
0005433569287	342	74	17C
0005433569243	342	75	17B
0005432948053	342	76	17D
0005432948136	342	77	17F
0005433074502	342	78	17E
0005433569245	342	79	18A
0005432948162	342	80	18B
0005432948364	342	81	18C
0005432948223	342	82	18D
0005433074596	342	83	19B
0005432948313	342	84	20B
0005433569293	342	85	20A
0005433569265	342	86	20C
0005433074557	342	87	20E
0005432948329	342	88	20D
0005433074546	342	89	20F
0005432948176	342	90	21B
0005433569269	342	91	21D
0005432948203	342	92	21C
0005433569255	342	93	21E
0005433074438	342	94	22A
0005433569282	342	95	21F
0005432947996	342	96	22B
0005433074519	342	97	22D
0005432948057	342	98	22F
0005433134099	342	99	22E
0005432948247	342	100	23A
0005432948246	342	101	23C
0005432238953	342	102	23D
0005432948365	342	103	23E
0005433569253	342	104	24A
0005433569298	342	105	23F
0005432948192	342	106	24D
0005432948137	342	107	24E
0005433569284	342	108	24F
0005432948224	342	109	25A
0005432948218	342	110	25C
0005433569288	342	111	25B
0005432948098	342	112	25D
0005433569272	342	113	25F
0005433074461	342	114	26A
0005433569261	342	115	26C
0005433129240	342	116	26D
0005432948116	342	117	26F
0005433569251	342	118	26E
0005433569291	342	119	27A
0005433129254	342	120	27C
0005433074684	342	121	27B
0005432948148	342	122	27E
0005432948308	342	123	27D
0005433569280	342	124	28A
0005432948163	342	125	27F
0005433569258	342	126	28B
0005432948207	342	127	28C
0005433569297	342	128	28E
0005433569277	342	129	28D
0005432948296	342	130	29A
0005432948298	342	131	28F
0005433129239	342	132	29C
0005433569290	342	133	29B
0005433569257	342	134	29D
0005433074590	342	135	29F
0005432948242	342	136	30C
0005432948152	342	137	30B
0005433074586	342	138	30A
0005432948202	342	139	30D
0005432948256	342	140	30F
0005432948193	342	141	30E
0005433569248	342	142	31B
0005433074580	342	143	31A
0005433569281	342	144	31E
0005432948297	342	145	31D
0005433569247	342	146	31F
0005433568572	11618	1	1A
0005433568359	11618	2	1C
0005432948584	11618	3	1D
0005433568643	11618	4	2A
0005433568525	11618	5	1F
0005433568441	11618	6	2C
0005433568672	11618	7	2D
0005433568729	11618	8	3A
0005432948567	11618	9	2F
0005433568422	11618	10	3C
0005432948589	11618	11	3F
0005433568554	11618	12	4A
0005433568368	11618	13	4C
0005433568713	11618	14	4D
0005432948562	11618	15	5A
0005433568248	11618	16	4F
0005432948588	11618	17	5C
0005433568712	11618	18	5F
0005432948581	11618	19	5D
0005432948586	11618	20	6A
0005433568321	11618	21	6F
0005433074806	11618	22	7A
0005432948597	11618	23	8A
0005433134152	11618	24	7F
0005432192330	11618	25	8B
0005432948574	11618	26	8D
0005433568508	11618	27	8E
0005433568579	11618	28	8F
0005432948582	11618	29	9B
0005433568663	11618	30	9A
0005433074787	11618	31	9D
0005433568593	11618	32	9F
0005432948577	11618	33	9E
0005432948561	11618	34	10A
0005432948596	11618	35	10C
0005433074793	11618	36	10B
0005433568439	11618	37	10E
0005432948572	11618	38	10F
0005432948570	11618	39	11A
0005433568560	11618	40	11C
0005433568526	11618	41	11B
0005433074786	11618	42	11D
0005432948587	11618	43	11E
0005433568580	11618	44	12B
0005433074797	11618	45	12D
0005432948590	11618	46	12C
0005433568723	11618	47	12E
0005433074783	11618	48	12F
0005433568614	11618	49	13A
0005433568690	11618	50	13B
0005433568615	11618	51	13E
0005433074788	11618	52	13D
0005433568571	11618	53	13C
0005433568471	11618	54	13F
0005433568354	11618	55	14A
0005433568602	11618	56	14C
0005433568598	11618	57	14B
0005432948563	11618	58	14D
0005432948578	11618	59	14F
0005433074791	11618	60	15B
0005433074798	11618	61	15A
0005433568756	11618	62	15C
0005432948560	11618	63	15D
0005433074792	11618	64	15F
0005432948557	11618	65	15E
0005433074796	11618	66	16A
0005433568594	11618	67	16C
0005433131724	11618	68	16B
0005433568755	11618	69	17B
0005432948583	11618	70	17A
0005433568695	11618	71	17C
0005432948558	11618	72	18A
0005433074804	11618	73	18B
0005433568740	11618	74	18D
0005432948594	11618	75	18E
0005432948568	11618	76	18F
0005432192329	11618	77	19C
0005432948580	11618	78	19B
0005433134151	11618	79	20A
0005433568595	11618	80	19E
0005433568681	11618	81	20C
0005433568507	11618	82	20B
0005433568573	11618	83	20D
0005433134153	11618	84	20F
0005433568440	11618	85	20E
0005432948556	11618	86	21C
0005432948559	11618	87	21B
0005432948575	11618	88	21D
0005433074785	11618	89	21E
0005433568686	11618	90	21F
0005433568773	11618	91	22B
0005433074805	11618	92	22A
0005432948566	11618	93	22C
0005433074795	11618	94	22E
0005433568609	11618	95	22D
0005433568757	11618	96	22F
0005433074807	11618	97	23A
0005433131723	11618	98	23D
0005433568524	11618	99	23E
0005433074782	11618	100	23F
0005433074789	11618	101	24C
0005433568715	11618	102	24E
0005433568637	11618	103	24D
0005433074808	11618	104	24F
0005433568662	11618	105	25A
0005433074794	11618	106	25B
0005432948592	11618	107	25C
0005432948579	11618	108	25F
0005433568477	11618	109	25E
0005433568785	11618	110	26A
0005433568601	11618	111	26C
0005432948565	11618	112	26E
0005432948595	11618	113	26D
0005433074784	11618	114	26F
0005432948569	11618	115	27A
0005432948564	11618	116	27C
0005433568786	11618	117	27B
0005433568597	11618	118	27D
0005432948585	11618	119	27F
0005433568623	11618	120	27E
0005433131720	11618	121	28A
0005433074799	11618	122	28C
0005433568472	11618	123	28E
0005433568754	11618	124	28D
0005433568671	11618	125	28F
0005432948576	11618	126	29A
0005433568527	11618	127	29C
0005432948571	11618	128	29D
0005433074803	11618	129	29E
0005433074801	11618	130	29F
0005432948573	11618	131	30B
0005433131722	11618	132	30A
0005433131721	11618	133	30C
0005433568324	11618	134	30E
0005433074802	11618	135	31A
0005433568724	11618	136	30F
0005432948593	11618	137	31C
0005433074800	11618	138	31B
0005433074790	11618	139	31D
0005433134154	11618	140	31F
0005432948591	11618	141	31E
0005433817482	9969	1	1A
0005433817483	9969	2	1B
0005433817481	9969	3	2A
0005434732961	9969	4	2B
0005434732971	9969	5	3B
0005434732962	9969	6	4A
0005434732963	9969	7	4B
0005433817484	9969	8	5B
0005433817441	13958	1	1A
0005433817443	13958	2	2B
0005434732990	13958	3	3B
0005434732992	13958	4	4B
0005434732993	13958	5	5B
0005434732991	13958	6	6B
0005432984916	2354	1	1A
0005433754382	2354	2	1B
0005435982449	2354	3	1F
0005432984958	2354	4	1C
0005435982443	2354	5	1H
0005432984987	2354	6	1G
0005433754424	2354	7	2A
0005432984970	2354	8	2B
0005432984785	2354	9	2F
0005432655571	2354	10	2C
0005433754427	2354	11	2G
0005435982445	2354	12	3A
0005432984956	2354	13	2H
0005433434454	2354	14	3B
0005435982482	2354	15	3C
0005433434545	2354	16	3G
0005433754428	2354	17	3F
0005433434610	2354	18	3H
0005435982469	2354	19	4C
0005432984890	2354	20	4B
0005432869497	2354	21	4A
0005433434586	2354	22	4F
0005433434508	2354	23	4G
0005435982462	2354	24	4H
0005432869500	2354	25	5B
0005435982470	2354	26	5A
0005432984999	2354	27	5F
0005433764685	2354	28	5C
0005433434546	2354	29	5G
0005433754410	2354	30	9A
0005433434502	2354	31	5H
0005433754383	2354	32	9B
0005435982447	2354	33	9H
0005433434414	2354	34	9G
0005433434430	2354	35	11A
0005435982455	2354	36	11B
0005432984883	2354	37	11E
0005434731142	2354	38	11D
0005432985058	2354	39	11G
0005435982446	2354	40	11F
0005432984927	2354	41	12B
0005433754392	2354	42	12A
0005432300281	2354	43	12D
0005432984771	2354	44	12E
0005433434521	2354	45	12F
0005432655578	2354	46	12H
0005432984881	2354	47	12G
0005435982467	2354	48	13B
0005435982452	2354	49	13A
0005432869496	2354	50	13D
0005433754426	2354	51	13E
0005433754380	2354	52	13G
0005433754396	2354	53	13F
0005432869495	2354	54	13H
0005435982457	2354	55	14A
0005433754385	2354	56	14D
0005433434583	2354	57	14B
0005433434493	2354	58	14F
0005433754422	2354	59	14E
0005432984882	2354	60	14G
0005435982461	2354	61	15A
0005432226074	2354	62	14H
0005435982484	2354	63	15D
0005432655575	2354	64	15B
0005432655577	2354	65	15G
0005432985046	2354	66	15F
0005432300283	2354	67	15E
0005433754414	2354	68	15H
0005433754413	2354	69	16A
0005433754374	2354	70	16D
0005432985057	2354	71	16B
0005433754409	2354	72	16E
0005433754398	2354	73	16G
0005432984843	2354	74	16F
0005432655581	2354	75	16H
0005434731136	2354	76	17A
0005433754407	2354	77	17D
0005433754404	2354	78	17B
0005433754389	2354	79	17E
0005435982473	2354	80	17G
0005432869492	2354	81	17F
0005433754378	2354	82	17H
0005433754401	2354	83	18B
0005432984853	2354	84	18A
0005432984969	2354	85	18D
0005432300282	2354	86	18E
0005435982453	2354	87	18G
0005433434571	2354	88	18F
0005433754391	2354	89	18H
0005433754402	2354	90	19B
0005435982450	2354	91	19A
0005433754399	2354	92	19D
0005435982475	2354	93	19F
0005432984776	2354	94	19E
0005433754423	2354	95	19G
0005432984946	2354	96	20A
0005433764686	2354	97	19H
0005435982451	2354	98	20D
0005433434507	2354	99	20B
0005433766652	2354	100	20E
0005433434535	2354	101	20F
0005433754394	2354	102	20G
0005433434494	2354	103	21B
0005435982444	2354	104	21A
0005433434544	2354	105	20H
0005433764687	2354	106	21E
0005433754388	2354	107	21D
0005435982474	2354	108	21G
0005432300284	2354	109	21F
0005433434453	2354	110	21H
0005434731135	2354	111	22A
0005433434431	2354	112	22D
0005433434639	2354	113	22B
0005435982479	2354	114	22E
0005435982458	2354	115	22G
0005432655574	2354	116	22F
0005435982480	2354	117	22H
0005433754415	2354	118	23B
0005434731141	2354	119	23A
0005432984858	2354	120	23D
0005432869499	2354	121	23E
0005432984770	2354	122	23G
0005433754379	2354	123	23F
0005433434517	2354	124	24A
0005432226075	2354	125	23H
0005433434534	2354	126	24B
0005433754406	2354	127	24D
0005432984986	2354	128	24F
0005432655582	2354	129	24E
0005433754417	2354	130	24G
0005432869456	2354	131	25D
0005432226079	2354	132	24H
0005432984874	2354	133	25F
0005432226076	2354	134	25E
0005433766650	2354	135	27A
0005435982477	2354	136	27B
0005432984841	2354	137	27D
0005432300279	2354	138	27F
0005435982472	2354	139	27E
0005432655580	2354	140	27H
0005432226078	2354	141	27G
0005433754408	2354	142	28A
0005433754384	2354	143	28B
0005433754381	2354	144	28E
0005435982465	2354	145	28D
0005432869483	2354	146	28F
0005435982463	2354	147	28H
0005432226077	2354	148	28G
0005433754419	2354	149	29A
0005432655572	2354	150	29B
0005433754420	2354	151	29E
0005433754387	2354	152	29D
0005433754425	2354	153	29G
0005433434448	2354	154	29F
0005433754386	2354	155	29H
0005433434503	2354	156	30B
0005432984788	2354	157	30A
0005435982464	2354	158	30E
0005433754395	2354	159	30D
0005433434569	2354	160	30G
0005435982459	2354	161	30F
0005432655579	2354	162	31A
0005432984769	2354	163	30H
0005435982471	2354	164	31B
0005432985020	2354	165	31D
0005433434516	2354	166	31E
0005435982468	2354	167	31H
0005432984936	2354	168	31G
0005433754375	2354	169	32A
0005432655576	2354	170	32B
0005433754429	2354	171	32E
0005432300280	2354	172	32F
0005434731147	2354	173	32H
0005433754373	2354	174	32G
0005433754416	2354	175	33A
0005433754372	2354	176	33D
0005433754397	2354	177	33B
0005433754377	2354	178	33E
0005433754405	2354	179	33G
0005433754418	2354	180	34B
0005435982466	2354	181	34A
0005433434570	2354	182	33H
0005432984943	2354	183	34D
0005432984918	2354	184	34F
0005432984829	2354	185	34E
0005433754393	2354	186	34G
0005433434611	2354	187	34H
0005432985045	2354	188	35B
0005432984926	2354	189	35A
0005435982481	2354	190	35D
0005432984840	2354	191	35E
0005433434609	2354	192	35G
0005435982454	2354	193	35F
0005433766653	2354	194	35H
0005433754390	2354	195	36B
0005432984925	2354	196	36A
0005435982448	2354	197	36E
0005435982456	2354	198	36D
0005433754411	2354	199	36F
0005433766651	2354	200	36H
0005433434631	2354	201	36G
0005433754403	2354	202	37A
0005433754376	2354	203	37D
0005432984944	2354	204	37B
0005433754400	2354	205	37E
0005433754412	2354	206	37F
0005432984873	2354	207	37G
0005432984839	2354	208	38A
0005433434522	2354	209	37H
0005435982483	2354	210	38D
0005434731130	2354	211	38B
0005432655573	2354	212	38E
0005435982478	2354	213	38G
0005433754421	2354	214	38F
0005435982460	2354	215	38H
0005435982476	2354	216	39E
0005432984900	2354	217	39D
0005432984957	2354	218	39F
0005433753782	26157	1	1A
0005435982043	26157	2	1B
0005433754129	26157	3	1F
0005433753691	26157	4	1C
0005435981843	26157	5	1H
0005433754017	26157	6	1G
0005433753860	26157	7	2B
0005432985189	26157	8	2F
0005433434765	26157	9	2C
0005433753914	26157	10	2H
0005432985170	26157	11	3A
0005433754108	26157	12	3C
0005433754094	26157	13	3B
0005433753986	26157	14	3F
0005433753833	26157	15	3G
0005435982154	26157	16	3H
0005433766608	26157	17	4C
0005432655436	26157	18	4B
0005433753915	26157	19	4A
0005432869543	26157	20	4F
0005435982080	26157	21	4G
0005435982152	26157	22	5A
0005433753872	26157	23	4H
0005432985183	26157	24	5B
0005433434767	26157	25	5C
0005433434777	26157	26	5G
0005435981937	26157	27	5F
0005433434757	26157	28	9A
0005433754010	26157	29	5H
0005432985193	26157	30	9G
0005432985180	26157	31	9B
0005432985186	26157	32	9H
0005433753751	26157	33	11D
0005433754064	26157	34	11B
0005432985177	26157	35	11A
0005435982066	26157	36	11E
0005432985182	26157	37	11G
0005433753667	26157	38	11F
0005432985179	26157	39	12B
0005433753992	26157	40	12A
0005433753524	26157	41	11H
0005435981890	26157	42	12E
0005432985178	26157	43	12D
0005432655440	26157	44	12G
0005433753840	26157	45	12H
0005433754027	26157	46	13B
0005432985167	26157	47	13A
0005432051139	26157	48	13D
0005433434769	26157	49	13F
0005433753647	26157	50	13E
0005433434781	26157	51	13G
0005433434756	26157	52	14A
0005432985175	26157	53	13H
0005433753812	26157	54	14B
0005434731185	26157	55	14D
0005435982081	26157	56	14F
0005434731186	26157	57	14E
0005433434772	26157	58	14G
0005435982102	26157	59	15A
0005435982077	26157	60	14H
0005433754015	26157	61	15B
0005433753888	26157	62	15E
0005432655441	26157	63	15D
0005432985188	26157	64	15F
0005432985185	26157	65	15G
0005432985194	26157	66	16A
0005433434758	26157	67	15H
0005433753950	26157	68	16D
0005432985171	26157	69	16B
0005433753906	26157	70	16E
0005435982036	26157	71	16H
0005433766626	26157	72	16G
0005432655424	26157	73	17D
0005433753954	26157	74	17B
0005435982020	26157	75	17E
0005432985195	26157	76	17G
0005433753692	26157	77	17F
0005435982074	26157	78	17H
0005432051137	26157	79	18B
0005432985181	26157	80	18A
0005433753870	26157	81	18E
0005432655423	26157	82	18D
0005433754043	26157	83	18G
0005432655425	26157	84	18F
0005433753578	26157	85	18H
0005433753926	26157	86	19B
0005433753752	26157	87	19E
0005433753878	26157	88	19D
0005433753873	26157	89	19F
0005435982105	26157	90	19G
0005433753686	26157	91	20A
0005433434762	26157	92	20B
0005433754014	26157	93	20D
0005435982044	26157	94	20G
0005432869545	26157	95	20F
0005433753685	26157	96	20E
0005433766627	26157	97	21A
0005432869544	26157	98	20H
0005435982054	26157	99	21B
0005433753802	26157	100	21E
0005435981842	26157	101	21D
0005433434763	26157	102	21F
0005433434778	26157	103	21H
0005433434782	26157	104	22B
0005433434764	26157	105	22E
0005432869541	26157	106	22G
0005435981927	26157	107	22F
0005435982051	26157	108	22H
0005432655412	26157	109	23B
0005433754095	26157	110	23A
0005432985191	26157	111	23D
0005432985184	26157	112	23F
0005435981963	26157	113	24A
0005432985172	26157	114	23H
0005433753882	26157	115	24B
0005433434779	26157	116	24E
0005435981901	26157	117	24D
0005433753896	26157	118	24F
0005433434780	26157	119	24G
0005433753799	26157	120	24H
0005435981844	26157	121	25E
0005433753883	26157	122	25D
0005433434783	26157	123	25F
0005435981990	26157	124	27B
0005433753869	26157	125	27A
0005433434768	26157	126	27E
0005433753895	26157	127	27D
0005435982117	26157	128	27F
0005433434770	26157	129	27G
0005432655449	26157	130	28A
0005433434766	26157	131	27H
0005435982164	26157	132	28D
0005433753969	26157	133	28B
0005433753811	26157	134	28E
0005433753781	26157	135	28G
0005433766607	26157	136	28F
0005433754068	26157	137	29A
0005433753681	26157	138	28H
0005432985197	26157	139	29D
0005432049474	26157	140	29B
0005435982104	26157	141	29E
0005432985173	26157	142	29G
0005432985187	26157	143	29F
0005433434771	26157	144	29H
0005432985176	26157	145	30B
0005433753955	26157	146	30A
0005432985169	26157	147	30D
0005435982041	26157	148	30F
0005432985196	26157	149	30E
0005435982067	26157	150	30G
0005432655439	26157	151	31A
0005433753957	26157	152	30H
0005433434761	26157	153	31B
0005433753648	26157	154	31D
0005435982179	26157	155	31F
0005435982064	26157	156	31E
0005435982103	26157	157	31G
0005435982042	26157	158	31H
0005435981928	26157	159	32B
0005433753871	26157	160	32A
0005433434759	26157	161	32E
0005432985192	26157	162	32D
0005433766622	26157	163	32F
0005435982086	26157	164	32G
0005435982035	26157	165	33A
0005433434775	26157	166	32H
0005432655511	26157	167	33D
0005433754121	26157	168	33B
0005433434773	26157	169	33E
0005435982027	26157	170	33F
0005435981848	26157	171	33H
0005432985190	26157	172	33G
0005433753838	26157	173	34A
0005433764657	26157	174	34D
0005435981929	26157	175	34B
0005432655468	26157	176	34E
0005432049475	26157	177	34G
0005432985166	26157	178	34F
0005433753913	26157	179	35A
0005433754093	26157	180	34H
0005432985168	26157	181	35B
0005433753968	26157	182	35D
0005433754081	26157	183	35F
0005433434760	26157	184	35E
0005434731184	26157	185	35G
0005432985174	26157	186	35H
0005433753834	26157	187	36B
0005435981889	26157	188	36D
0005433753995	26157	189	36F
0005433753998	26157	190	36E
0005433753646	26157	191	36G
0005433754069	26157	192	37A
0005435981891	26157	193	36H
0005433766621	26157	194	37B
0005435981892	26157	195	37E
0005435982001	26157	196	37D
0005433434774	26157	197	37G
0005433766606	26157	198	37F
0005432051138	26157	199	38A
0005432049476	26157	200	37H
0005432985165	26157	201	38D
0005433753916	26157	202	38B
0005433753912	26157	203	38E
0005432869542	26157	204	38G
0005433764656	26157	205	38F
0005433434776	26157	206	38H
0005435981962	26157	207	39E
0005435981940	26157	208	39D
0005433151175	1514	1	1A
0005434374803	1514	2	2C
0005433151259	1514	3	2D
0005434374810	1514	4	2F
0005433151304	1514	5	3C
0005434374799	1514	6	3D
0005433764664	1514	7	3F
0005432267918	1514	8	4B
0005434374787	1514	9	4A
0005433151186	1514	10	4D
0005433460444	1514	11	4E
0005434374773	1514	12	5A
0005434374802	1514	13	5B
0005434374804	1514	14	5C
0005434374805	1514	15	5D
0005434374796	1514	16	5E
0005434374767	1514	17	5F
0005433931447	1514	18	6A
0005434374774	1514	19	6C
0005434374809	1514	20	6B
0005433151302	1514	21	6D
0005434374770	1514	22	6F
0005434374776	1514	23	7B
0005434374772	1514	24	7A
0005434374760	1514	25	7D
0005433151347	1514	26	7C
0005433151270	1514	27	7E
0005433461595	1514	28	8A
0005434374782	1514	29	8D
0005433151213	1514	30	8C
0005433151249	1514	31	8E
0005433151339	1514	32	8F
0005434374800	1514	33	9A
0005433151076	1514	34	9B
0005434374771	1514	35	9C
0005433151235	1514	36	9E
0005433151308	1514	37	9D
0005434374759	1514	38	9F
0005434374761	1514	39	10C
0005434374775	1514	40	10B
0005434374806	1514	41	10D
0005433151180	1514	42	10E
0005433151239	1514	43	11A
0005434374764	1514	44	11C
0005433151323	1514	45	11B
0005434374794	1514	46	11E
0005434374783	1514	47	11D
0005433151340	1514	48	11F
0005433151333	1514	49	12A
0005433764662	1514	50	12B
0005433151075	1514	51	12D
0005433151260	1514	52	12E
0005434374762	1514	53	12F
0005433151040	1514	54	13A
0005434374789	1514	55	13B
0005433931446	1514	56	13C
0005434374792	1514	57	13E
0005434374793	1514	58	14A
0005434374808	1514	59	14D
0005433151250	1514	60	14E
0005434374811	1514	61	15B
0005433151271	1514	62	15A
0005433151218	1514	63	15C
0005433461594	1514	64	15E
0005433151257	1514	65	15D
0005433151334	1514	66	15F
0005434374786	1514	67	16A
0005433151217	1514	68	16C
0005433151150	1514	69	16B
0005433151184	1514	70	16D
0005432267915	1514	71	16F
0005433151307	1514	72	16E
0005432267914	1514	73	17A
0005434374781	1514	74	17B
0005434374795	1514	75	17D
0005433151273	1514	76	17C
0005433931449	1514	77	17E
0005434374788	1514	78	18A
0005433151272	1514	79	18B
0005434374777	1514	80	18C
0005434374778	1514	81	18D
0005434374807	1514	82	19A
0005434374791	1514	83	18F
0005433461596	1514	84	19C
0005433151303	1514	85	19E
0005434374784	1514	86	19F
0005434374780	1514	87	20C
0005432267916	1514	88	20B
0005434374765	1514	89	20D
0005433151183	1514	90	20E
0005433460443	1514	91	20F
0005432267919	1514	92	21A
0005434374769	1514	93	21C
0005432267917	1514	94	21B
0005434374779	1514	95	21D
0005433151348	1514	96	21E
0005434374801	1514	97	21F
0005433931448	1514	98	22B
0005434374763	1514	99	22A
0005434374797	1514	100	22E
0005434374798	1514	101	22F
0005434374785	1514	102	23B
0005434374766	1514	103	23A
0005433931445	1514	104	23C
0005434374790	1514	105	23D
0005434374768	1514	106	23E
0005434374377	20101	1	1A
0005434374332	20101	2	1C
0005433151526	20101	3	1F
0005433151508	20101	4	2C
0005434374365	20101	5	2A
0005434374353	20101	6	2D
0005434029664	20101	7	2F
0005434374364	20101	8	3D
0005434374459	20101	9	3C
0005434374452	20101	10	3F
0005433151503	20101	11	4A
0005434374487	20101	12	4B
0005434374548	20101	13	4D
0005434374426	20101	14	4F
0005433764687	20101	15	5A
0005434374379	20101	16	5B
0005434374382	20101	17	5D
0005433151523	20101	18	5C
0005433151531	20101	19	5E
0005434374469	20101	20	6A
0005433151504	20101	21	6C
0005434374486	20101	22	6B
0005434029663	20101	23	6D
0005433151522	20101	24	6E
0005434374300	20101	25	7A
0005433151506	20101	26	7D
0005434374412	20101	27	7C
0005433151507	20101	28	7B
0005434374507	20101	29	7E
0005434374194	20101	30	7F
0005433151500	20101	31	8B
0005434374658	20101	32	8A
0005434374299	20101	33	8C
0005433151512	20101	34	8E
0005434374384	20101	35	9D
0005434374376	20101	36	10B
0005433151519	20101	37	10D
0005433151505	20101	38	10C
0005434029665	20101	39	10E
0005434374495	20101	40	11B
0005434374292	20101	41	11D
0005434374252	20101	42	11E
0005433151510	20101	43	12A
0005434374524	20101	44	12C
0005434374577	20101	45	12B
0005434374381	20101	46	12D
0005433764685	20101	47	12E
0005433151514	20101	48	12F
0005434374468	20101	49	13A
0005433151517	20101	50	13B
0005433151525	20101	51	13D
0005434374673	20101	52	13E
0005433151527	20101	53	13F
0005434374117	20101	54	14A
0005433151524	20101	55	14C
0005433151520	20101	56	14B
0005434029666	20101	57	14E
0005433151518	20101	58	14F
0005433151498	20101	59	15B
0005433151521	20101	60	15D
0005434374506	20101	61	15E
0005433151515	20101	62	16A
0005434374484	20101	63	15F
0005433764686	20101	64	16B
0005434374488	20101	65	16C
0005434374458	20101	66	16E
0005433151499	20101	67	16D
0005434374525	20101	68	16F
0005433151497	20101	69	17A
0005433151511	20101	70	17C
0005434374508	20101	71	17D
0005434374467	20101	72	17E
0005434374367	20101	73	18A
0005433151509	20101	74	17F
0005432056312	20101	75	18B
0005434374528	20101	76	18C
0005433151513	20101	77	18F
0005432056310	20101	78	19C
0005434374451	20101	79	19B
0005434374503	20101	80	19D
0005434374453	20101	81	19F
0005434374529	20101	82	19E
0005433151516	20101	83	20A
0005433151502	20101	84	20C
0005433151530	20101	85	20D
0005432056311	20101	86	20E
0005434374509	20101	87	20F
0005434374192	20101	88	21A
0005434374539	20101	89	21D
0005434374672	20101	90	21E
0005434374413	20101	91	21F
0005434374195	20101	92	22B
0005433151501	20101	93	22A
0005433151528	20101	94	22C
0005434374378	20101	95	22D
0005434374324	20101	96	22E
0005433151529	20101	97	23A
0005434374494	20101	98	23C
0005434374318	20101	99	23E
0005434374538	20101	100	23D
0005432424606	567	1	1C
0005432424600	567	2	1D
0005432424604	567	3	2C
0005432424595	567	4	3D
0005432424571	567	5	3F
0005432424581	567	6	5A
0005432282889	567	7	5C
0005432424603	567	8	6D
0005432424605	567	9	7C
0005432424596	567	10	9B
0005432424584	567	11	9D
0005432424587	567	12	10C
0005432424574	567	13	10B
0005432424588	567	14	10E
0005432424592	567	15	11D
0005432282886	567	16	11C
0005432424577	567	17	13A
0005432282885	567	18	12F
0005432424598	567	19	13E
0005432424589	567	20	13F
0005432424576	567	21	14A
0005432282891	567	22	15D
0005432424572	567	23	15E
0005432424607	567	24	16A
0005432424583	567	25	17D
0005432424593	567	26	17F
0005432282884	567	27	18E
0005432424608	567	28	20A
0005432424590	567	29	20C
0005432282887	567	30	21A
0005432424579	567	31	21C
0005432282888	567	32	21B
0005432424573	567	33	21D
0005432424597	567	34	22A
0005432424578	567	35	21F
0005432282883	567	36	23A
0005432424591	567	37	24C
0005432424602	567	38	25C
0005432424582	567	39	26B
0005432424575	567	40	26D
0005432424594	567	41	27A
0005432424599	567	42	27B
0005432424585	567	43	27C
0005432424580	567	44	28D
0005432282890	567	45	29D
0005432424609	567	46	29E
0005432424601	567	47	30D
0005432424586	567	48	31C
0005432302344	12884	1	2C
0005432302341	12884	2	6D
0005432302342	12884	3	16E
0005432302343	12884	4	28C
0005432424169	12932	1	1A
0005432424138	12932	2	2C
0005432424159	12932	3	3D
0005432424095	12932	4	5A
0005432424033	12932	5	5C
0005432424139	12932	6	6A
0005432424123	12932	7	5F
0005432424020	12932	8	6F
0005432424034	12932	9	8D
0005432424116	12932	10	8C
0005432424043	12932	11	9D
0005432424121	12932	12	11C
0005432424041	12932	13	11B
0005432424067	12932	14	11E
0005432423988	12932	15	12F
0005432424113	12932	16	14A
0005432424035	12932	17	14E
0005432424065	12932	18	15B
0005432424103	12932	19	15A
0005432424111	12932	20	15E
0005432424129	12932	21	16B
0005432424078	12932	22	15F
0005432423956	12932	23	16C
0005432424160	12932	24	16F
0005432424110	12932	25	17D
0005432423989	12932	26	18B
0005432424109	12932	27	19B
0005432424036	12932	28	19E
0005432423937	12932	29	21C
0005432424112	12932	30	23F
0005432424037	12932	31	24C
0005432424107	12932	32	24F
0005432423961	12932	33	24E
0005432424158	12932	34	25A
0005432424115	12932	35	25D
0005432424044	12932	36	25C
0005432424042	12932	37	25F
0005432424104	12932	38	26D
0005432424032	12932	39	27A
0005432424094	12932	40	28A
0005432424135	12932	41	28E
0005432423967	12932	42	29A
0005432424079	12932	43	30D
0005432424108	12932	44	30E
0005432424152	12932	45	30F
0005432235663	462	1	1A
0005433057556	462	2	1B
0005434023957	462	3	1F
0005434029662	462	4	1H
0005433684394	462	5	2A
0005434023940	462	6	2C
0005433057513	462	7	2G
0005434023905	462	8	3B
0005434028304	462	9	3F
0005434023921	462	10	3G
0005433057760	462	11	3H
0005434023914	462	12	4B
0005434735649	462	13	4A
0005434023889	462	14	4F
0005433057665	462	15	4C
0005434023904	462	16	4G
0005434023890	462	17	4H
0005434023932	462	18	5B
0005434023915	462	19	5A
0005434032035	462	20	5G
0005433057666	462	21	5F
0005433057649	462	22	5H
0005434023936	462	23	9B
0005434023941	462	24	9A
0005434023918	462	25	9G
0005434023952	462	26	11A
0005434735650	462	27	9H
0005433057643	462	28	11B
0005432235662	462	29	11E
0005434023928	462	30	11G
0005434028306	462	31	11F
0005434023951	462	32	12A
0005434023955	462	33	12D
0005433057617	462	34	12B
0005434023934	462	35	12E
0005433057645	462	36	12G
0005434023933	462	37	13A
0005434023924	462	38	13B
0005434023956	462	39	13F
0005433929572	462	40	13H
0005433929571	462	41	14B
0005434023896	462	42	14A
0005432045618	462	43	14D
0005434023946	462	44	14F
0005433057618	462	45	14E
0005433057772	462	46	15A
0005434023895	462	47	14H
0005433057714	462	48	15B
0005434023945	462	49	15E
0005433057677	462	50	15D
0005434023950	462	51	15F
0005434032037	462	52	15H
0005433057616	462	53	16B
0005433057770	462	54	16F
0005434029661	462	55	16E
0005434028305	462	56	16G
0005433057709	462	57	17B
0005433057924	462	58	17F
0005434735647	462	59	17H
0005433057657	462	60	18A
0005434023888	462	61	18D
0005434023931	462	62	18B
0005432235658	462	63	18F
0005434023930	462	64	18G
0005434032034	462	65	19A
0005434023913	462	66	19B
0005433057646	462	67	19F
0005434023909	462	68	19E
0005434023953	462	69	19H
0005434023894	462	70	19G
0005434023944	462	71	20A
0005433057658	462	72	20E
0005434023920	462	73	20D
0005432235665	462	74	20G
0005434735651	462	75	21E
0005434023899	462	76	21G
0005434023942	462	77	21F
0005433929582	462	78	22A
0005434023938	462	79	22D
0005434028302	462	80	22F
0005434023900	462	81	22E
0005432235664	462	82	22G
0005433057642	462	83	23B
0005433057625	462	84	23A
0005433684405	462	85	23F
0005433057768	462	86	23E
0005434023892	462	87	23H
0005434023947	462	88	23G
0005434023917	462	89	24A
0005434023926	462	90	24B
0005434023912	462	91	24F
0005433684410	462	92	24G
0005434735652	462	93	25D
0005433057769	462	94	24H
0005433929584	462	95	25F
0005433684407	462	96	27A
0005433057708	462	97	27B
0005434023903	462	98	27D
0005434023939	462	99	27H
0005434023908	462	100	27G
0005434023923	462	101	28A
0005434023937	462	102	28D
0005433057716	462	103	28B
0005434023922	462	104	28F
0005433929580	462	105	28E
0005433057681	462	106	29B
0005433057536	462	107	29E
0005433057732	462	108	29D
0005432235660	462	109	29H
0005434023925	462	110	29G
0005433929589	462	111	30A
0005434023898	462	112	30B
0005433057773	462	113	30F
0005433057680	462	114	30G
0005434023906	462	115	31A
0005434023948	462	116	31D
0005434023901	462	117	31E
0005434023929	462	118	32B
0005434023893	462	119	32E
0005433929583	462	120	32D
0005434023949	462	121	32H
0005433057771	462	122	33A
0005433057641	462	123	33B
0005434032036	462	124	33E
0005434023935	462	125	33D
0005434023897	462	126	33F
0005434023927	462	127	33H
0005434023902	462	128	33G
0005434023954	462	129	34A
0005432235659	462	130	34B
0005432235661	462	131	34F
0005433684404	462	132	34G
0005434023907	462	133	34H
0005434028303	462	134	35A
0005433057590	462	135	35D
0005433057753	462	136	35E
0005433057535	462	137	35G
0005434023916	462	138	36B
0005434023891	462	139	36D
0005433057923	462	140	36F
0005433057717	462	141	36H
0005432045617	462	142	37B
0005434032033	462	143	37H
0005434023943	462	144	38B
0005433057715	462	145	38D
0005434023919	462	146	38E
0005434023910	462	147	38H
0005434023911	462	148	38G
0005434735648	462	149	39D
0005433057555	462	150	39E
0005432156381	12643	1	1B
0005434023375	12643	2	1C
0005434023273	12643	3	2A
0005433057995	12643	4	1H
0005434023340	12643	5	2F
0005433058029	12643	6	2C
0005434023521	12643	7	2H
0005433929625	12643	8	3B
0005434031999	12643	9	3C
0005434023083	12643	10	3H
0005434023001	12643	11	4B
0005434023126	12643	12	4A
0005434023214	12643	13	4C
0005434023174	12643	14	4F
0005434023276	12643	15	5A
0005434023310	12643	16	4H
0005433058016	12643	17	5F
0005433058008	12643	18	5C
0005434023242	12643	19	5G
0005433058027	12643	20	9A
0005432156379	12643	21	11A
0005433058005	12643	22	9H
0005434023231	12643	23	11B
0005433058018	12643	24	11D
0005434023417	12643	25	11F
0005434023355	12643	26	11E
0005434023181	12643	27	12D
0005434023160	12643	28	12G
0005433058017	12643	29	12F
0005433058024	12643	30	12H
0005433058007	12643	31	13A
0005434023222	12643	32	13D
0005434023161	12643	33	13B
0005434023525	12643	34	13E
0005434032004	12643	35	13G
0005432157499	12643	36	13F
0005434023230	12643	37	13H
0005434031987	12643	38	14A
0005433057998	12643	39	14E
0005434023309	12643	40	14D
0005432157498	12643	41	14F
0005433058025	12643	42	14G
0005434023520	12643	43	14H
0005433058028	12643	44	15B
0005433057997	12643	45	15E
0005434023243	12643	46	15D
0005433057994	12643	47	15F
0005434023330	12643	48	16A
0005434032001	12643	49	16D
0005434023605	12643	50	16B
0005434023519	12643	51	16H
0005434022870	12643	52	16G
0005433058009	12643	53	17A
0005432156377	12643	54	17D
0005434023262	12643	55	17B
0005434023171	12643	56	17E
0005434023059	12643	57	17G
0005434023258	12643	58	17F
0005433058019	12643	59	18A
0005433929624	12643	60	18B
0005433058006	12643	61	18D
0005434023268	12643	62	18E
0005433057996	12643	63	18G
0005434023152	12643	64	18F
0005434023334	12643	65	19B
0005434023441	12643	66	19G
0005432156380	12643	67	19F
0005434023339	12643	68	20A
0005434023709	12643	69	19H
0005434023280	12643	70	20B
0005434023215	12643	71	20E
0005434023281	12643	72	20G
0005433058000	12643	73	21A
0005434023082	12643	74	21D
0005433058010	12643	75	21B
0005433058012	12643	76	21F
0005433058011	12643	77	21E
0005434023376	12643	78	21G
0005434023428	12643	79	22B
0005434023418	12643	80	22A
0005433058004	12643	81	22E
0005433057992	12643	82	22G
0005434023263	12643	83	22F
0005434735705	12643	84	23A
0005434023408	12643	85	22H
0005433058030	12643	86	23B
0005434023272	12643	87	23F
0005434023351	12643	88	23G
0005433058001	12643	89	24A
0005434022882	12643	90	24B
0005434023329	12643	91	24D
0005434023614	12643	92	24F
0005434023356	12643	93	24G
0005432156378	12643	94	25D
0005434023457	12643	95	24H
0005434023201	12643	96	25E
0005434023058	12643	97	27A
0005434023127	12643	98	27D
0005434023172	12643	99	27F
0005434031995	12643	100	27G
0005434023629	12643	101	28A
0005434735704	12643	102	28F
0005434023269	12643	103	28E
0005434023458	12643	104	28H
0005434023275	12643	105	28G
0005433929626	12643	106	29D
0005434023168	12643	107	29F
0005432157497	12643	108	30A
0005434022921	12643	109	29H
0005434023102	12643	110	29G
0005434023613	12643	111	30B
0005433058003	12643	112	30D
0005434023382	12643	113	30F
0005434023471	12643	114	30G
0005434023383	12643	115	31A
0005433058021	12643	116	30H
0005434032000	12643	117	31E
0005434023216	12643	118	31D
0005434023220	12643	119	31F
0005433684427	12643	120	32A
0005433057993	12643	121	32D
0005434023186	12643	122	32F
0005433058014	12643	123	32G
0005434023221	12643	124	33A
0005434023460	12643	125	33E
0005434023537	12643	126	33D
0005433057999	12643	127	33G
0005433058026	12643	128	34A
0005433929628	12643	129	34B
0005434023708	12643	130	34G
0005434023579	12643	131	34F
0005433929627	12643	132	34H
0005434023335	12643	133	35B
0005434735707	12643	134	35E
0005434023203	12643	135	35H
0005433058023	12643	136	36D
0005434023510	12643	137	36F
0005434735708	12643	138	36E
0005433058020	12643	139	37A
0005433058002	12643	140	36H
0005434023159	12643	141	37E
0005434023202	12643	142	37F
0005433058022	12643	143	38A
0005434023571	12643	144	37H
0005432156382	12643	145	38B
0005433684428	12643	146	38E
0005434023459	12643	147	38D
0005434735706	12643	148	38G
0005434023170	12643	149	38F
0005433058013	12643	150	39F
0005433058015	12643	151	39E
0005433035925	2134	1	1A
0005433923564	2134	2	1B
0005433923633	2134	3	1F
0005433923600	2134	4	1C
0005433036017	2134	5	2A
0005433923627	2134	6	1H
0005433036065	2134	7	2C
0005433929628	2134	8	2F
0005433923567	2134	9	2G
0005433923570	2134	10	3A
0005433036170	2134	11	2H
0005432231593	2134	12	3B
0005433923641	2134	13	3F
0005432044533	2134	14	3C
0005433923645	2134	15	3G
0005433036212	2134	16	4A
0005433923614	2134	17	3H
0005433035987	2134	18	4B
0005433923611	2134	19	4C
0005433923605	2134	20	4G
0005433923609	2134	21	4F
0005433923554	2134	22	4H
0005433923620	2134	23	5B
0005432231594	2134	24	5A
0005433929625	2134	25	5C
0005432749772	2134	26	5G
0005433923562	2134	27	5F
0005433036165	2134	28	9A
0005433923593	2134	29	5H
0005433036042	2134	30	9B
0005433036000	2134	31	9G
0005433035736	2134	32	11A
0005433036083	2134	33	11B
0005433923592	2134	34	11D
0005433923625	2134	35	11F
0005433923581	2134	36	11E
0005433923585	2134	37	11G
0005433923553	2134	38	12A
0005433036126	2134	39	11H
0005433923563	2134	40	12D
0005433923624	2134	41	12B
0005433923571	2134	42	12E
0005433923603	2134	43	12H
0005433036146	2134	44	13B
0005433923634	2134	45	13D
0005433923643	2134	46	13F
0005432231600	2134	47	13E
0005433035907	2134	48	13G
0005433036185	2134	49	13H
0005433923587	2134	50	14B
0005433923552	2134	51	14A
0005433035919	2134	52	14F
0005433923565	2134	53	14E
0005433923615	2134	54	14G
0005433923607	2134	55	15A
0005433929624	2134	56	14H
0005433923599	2134	57	15D
0005433875383	2134	58	15B
0005433923639	2134	59	15E
0005433923584	2134	60	15F
0005433036025	2134	61	15H
0005432749773	2134	62	16A
0005433923583	2134	63	16E
0005433036043	2134	64	16F
0005433035940	2134	65	16H
0005433923555	2134	66	17B
0005433923589	2134	67	17E
0005433036097	2134	68	17D
0005433923560	2134	69	17G
0005433035735	2134	70	18A
0005433036055	2134	71	17H
0005433036075	2134	72	18D
0005433035915	2134	73	18B
0005433036041	2134	74	18E
0005433923596	2134	75	18H
0005433036147	2134	76	18G
0005433036001	2134	77	18F
0005433036186	2134	78	19B
0005433929627	2134	79	19D
0005433875384	2134	80	19F
0005433036080	2134	81	19H
0005433035916	2134	82	19G
0005433036058	2134	83	20A
0005433923638	2134	84	20B
0005433035950	2134	85	20E
0005433923626	2134	86	20D
0005433923647	2134	87	20G
0005433923606	2134	88	20F
0005432231597	2134	89	20H
0005433036099	2134	90	21A
0005433923619	2134	91	21D
0005433923617	2134	92	21B
0005433923602	2134	93	21E
0005433036191	2134	94	21G
0005432231596	2134	95	21F
0005433923646	2134	96	21H
0005433035949	2134	97	22B
0005433035828	2134	98	22A
0005433923630	2134	99	22D
0005433923595	2134	100	22E
0005433923608	2134	101	22F
0005433923561	2134	102	22H
0005433035994	2134	103	22G
0005433036067	2134	104	23B
0005433923572	2134	105	23A
0005433923631	2134	106	23D
0005433923637	2134	107	23F
0005433923622	2134	108	23E
0005433923597	2134	109	23G
0005433923648	2134	110	23H
0005433036096	2134	111	24B
0005432231602	2134	112	24A
0005433923616	2134	113	24D
0005432231598	2134	114	24F
0005433923578	2134	115	24E
0005433035861	2134	116	24G
0005433036046	2134	117	25D
0005433923640	2134	118	24H
0005433923635	2134	119	25F
0005433035999	2134	120	25E
0005433035784	2134	121	27B
0005433923594	2134	122	27E
0005433035793	2134	123	27F
0005432231601	2134	124	27G
0005433923612	2134	125	28A
0005433035947	2134	126	27H
0005433923586	2134	127	28B
0005433923604	2134	128	28D
0005433923610	2134	129	28F
0005433036164	2134	130	28H
0005433036098	2134	131	28G
0005433035821	2134	132	29B
0005433035989	2134	133	29A
0005433036072	2134	134	29D
0005433923574	2134	135	29E
0005433923576	2134	136	29G
0005433923629	2134	137	29F
0005433036026	2134	138	29H
0005433035858	2134	139	30A
0005433036152	2134	140	30D
0005433036057	2134	141	30F
0005432749774	2134	142	30E
0005433923621	2134	143	31A
0005433923598	2134	144	30H
0005433923575	2134	145	31B
0005433923613	2134	146	31D
0005432044532	2134	147	31F
0005433923636	2134	148	31E
0005433923618	2134	149	31G
0005433923644	2134	150	32A
0005433036269	2134	151	31H
0005433036030	2134	152	32B
0005433036045	2134	153	32E
0005433035931	2134	154	32D
0005433035945	2134	155	32F
0005433923557	2134	156	32G
0005433036031	2134	157	33A
0005433923556	2134	158	32H
0005433923580	2134	159	33B
0005433923601	2134	160	33E
0005433923569	2134	161	33D
0005433035982	2134	162	33G
0005433036196	2134	163	33F
0005433923590	2134	164	33H
0005433923566	2134	165	34A
0005433923559	2134	166	34D
0005433923582	2134	167	34B
0005433036071	2134	168	34F
0005433036074	2134	169	34E
0005433036084	2134	170	34H
0005433035988	2134	171	35E
0005432231599	2134	172	35D
0005433923568	2134	173	35F
0005433035941	2134	174	35G
0005433035906	2134	175	36A
0005433036027	2134	176	35H
0005433036038	2134	177	36B
0005433036102	2134	178	36D
0005433923577	2134	179	36F
0005433923642	2134	180	36E
0005433035959	2134	181	36G
0005433923623	2134	182	37A
0005432044534	2134	183	36H
0005433036125	2134	184	37B
0005433923573	2134	185	37E
0005433036010	2134	186	37F
0005433929626	2134	187	37H
0005433035944	2134	188	37G
0005433923591	2134	189	38A
0005433923588	2134	190	38D
0005433923558	2134	191	38B
0005433923632	2134	192	38E
0005433035901	2134	193	38F
0005433036171	2134	194	38G
0005433923579	2134	195	39E
0005432231595	2134	196	39D
0005433923628	2134	197	39F
0005433922809	24119	1	1A
0005433923022	24119	2	1C
0005433922498	24119	3	1B
0005433922784	24119	4	1F
0005433922905	24119	5	1H
0005433923088	24119	6	2A
0005433036453	24119	7	2B
0005433923098	24119	8	2F
0005433923111	24119	9	2C
0005433922812	24119	10	2G
0005434028308	24119	11	2H
0005433923002	24119	12	3B
0005433922630	24119	13	3A
0005432206211	24119	14	3C
0005433922420	24119	15	3G
0005433922777	24119	16	3F
0005433922803	24119	17	3H
0005433036458	24119	18	4B
0005433922428	24119	19	4A
0005433931440	24119	20	4F
0005433036440	24119	21	4C
0005433923123	24119	22	4G
0005433922404	24119	23	5A
0005433929591	24119	24	4H
0005433036473	24119	25	5B
0005433922830	24119	26	5G
0005433922429	24119	27	5F
0005433036483	24119	28	9A
0005433923110	24119	29	5H
0005433922102	24119	30	9B
0005433923085	24119	31	9G
0005433922907	24119	32	11A
0005433922771	24119	33	11B
0005433922790	24119	34	11E
0005433922472	24119	35	11D
0005433922539	24119	36	11F
0005433036454	24119	37	11G
0005433922860	24119	38	11H
0005433923082	24119	39	12B
0005433923132	24119	40	12E
0005433922952	24119	41	12D
0005433036459	24119	42	12F
0005433036460	24119	43	12G
0005433922772	24119	44	13A
0005433922722	24119	45	13D
0005433922549	24119	46	13E
0005433922933	24119	47	13G
0005433036456	24119	48	14B
0005433922632	24119	49	14A
0005432206215	24119	50	14D
0005433036462	24119	51	14E
0005433036438	24119	52	14G
0005433036485	24119	53	14F
0005433922872	24119	54	15A
0005433923142	24119	55	14H
0005433922537	24119	56	15D
0005433923083	24119	57	15B
0005433036461	24119	58	15E
0005433036446	24119	59	15F
0005433922940	24119	60	15G
0005434028307	24119	61	15H
0005433923079	24119	62	16B
0005433923086	24119	63	16F
0005433875359	24119	64	16E
0005432749792	24119	65	16G
0005433922570	24119	66	16H
0005433922706	24119	67	17B
0005433036478	24119	68	17A
0005433922903	24119	69	17E
0005433036475	24119	70	17G
0005433036455	24119	71	17F
0005433036448	24119	72	18A
0005433036450	24119	73	18B
0005433922811	24119	74	18D
0005433922643	24119	75	18F
0005433931426	24119	76	18E
0005433923031	24119	77	18G
0005433922886	24119	78	19A
0005433036449	24119	79	19B
0005432206212	24119	80	19E
0005433922890	24119	81	20A
0005433923049	24119	82	19H
0005432206214	24119	83	20B
0005433036439	24119	84	20E
0005433036467	24119	85	20D
0005433922800	24119	86	20G
0005433922953	24119	87	20F
0005433922505	24119	88	20H
0005432206217	24119	89	21A
0005433922717	24119	90	21D
0005433923124	24119	91	21B
0005433036481	24119	92	21E
0005433922504	24119	93	21G
0005433922883	24119	94	21F
0005433923045	24119	95	21H
0005433036464	24119	96	22B
0005433923130	24119	97	22A
0005433036488	24119	98	22D
0005433923109	24119	99	22F
0005433036442	24119	100	22E
0005433931442	24119	101	22G
0005433922949	24119	102	22H
0005433922955	24119	103	23B
0005433922810	24119	104	23F
0005433923084	24119	105	23E
0005433922571	24119	106	23G
0005433923129	24119	107	24A
0005433922744	24119	108	23H
0005433931441	24119	109	24B
0005433922497	24119	110	24D
0005433036468	24119	111	24F
0005433922701	24119	112	24E
0005433036443	24119	113	24G
0005433922473	24119	114	25D
0005433922935	24119	115	24H
0005432207669	24119	116	25F
0005433036490	24119	117	25E
0005433922550	24119	118	27B
0005433036437	24119	119	27A
0005433036470	24119	120	27E
0005433923254	24119	121	27D
0005433922822	24119	122	27F
0005433923050	24119	123	27H
0005433922783	24119	124	27G
0005433922700	24119	125	28D
0005433036441	24119	126	28B
0005433922631	24119	127	28E
0005433036444	24119	128	28G
0005433036489	24119	129	28F
0005433036480	24119	130	28H
0005433923015	24119	131	29B
0005433922904	24119	132	29A
0005433922948	24119	133	29D
0005433922501	24119	134	29F
0005433922702	24119	135	29H
0005432207670	24119	136	29G
0005433923001	24119	137	30A
0005433922908	24119	138	30D
0005432206216	24119	139	30G
0005433922745	24119	140	31A
0005433922735	24119	141	31B
0005433922861	24119	142	31D
0005433922773	24119	143	31F
0005433922221	24119	144	31E
0005433036452	24119	145	31G
0005433922382	24119	146	31H
0005433875365	24119	147	32B
0005433922770	24119	148	32D
0005433036487	24119	149	32F
0005433036447	24119	150	33A
0005433922557	24119	151	32H
0005433036479	24119	152	33D
0005433036477	24119	153	33B
0005433036472	24119	154	33E
0005433036474	24119	155	33G
0005433923108	24119	156	33F
0005433922841	24119	157	33H
0005433922939	24119	158	34A
0005433036465	24119	159	34B
0005433036463	24119	160	34E
0005433036482	24119	161	34G
0005433036451	24119	162	34F
0005432206213	24119	163	35A
0005433922713	24119	164	35D
0005433922690	24119	165	35B
0005433922220	24119	166	35E
0005433922228	24119	167	35G
0005433923141	24119	168	36A
0005433923105	24119	169	35H
0005433036471	24119	170	36D
0005433931456	24119	171	36F
0005433922840	24119	172	36E
0005433036484	24119	173	36G
0005433036466	24119	174	37A
0005433036476	24119	175	36H
0005433036457	24119	176	37D
0005433922950	24119	177	37F
0005433036445	24119	178	37H
0005433036486	24119	179	37G
0005433922741	24119	180	38E
0005433922947	24119	181	38G
0005433036469	24119	182	38F
0005433922734	24119	183	38H
0005433922657	24119	184	39E
0005433923044	24119	185	39D
0005433923131	24119	186	39F
0005434725864	268	1	1C
0005434551437	268	2	1A
0005433180861	268	3	1G
0005434725867	268	4	1D
0005434725903	268	5	2D
0005433289780	268	6	2C
0005434551395	268	7	2A
0005433234070	268	8	2H
0005434551397	268	9	2G
0005434551388	268	10	3A
0005434725801	268	11	3D
0005433233862	268	12	3C
0005433180989	268	13	3H
0005434725807	268	14	3G
0005433131663	268	15	4C
0005434731180	268	16	3K
0005433180869	268	17	4G
0005434551432	268	18	4K
0005433234079	268	19	5D
0005434725885	268	20	5C
0005434551429	268	21	5A
0005434551404	268	22	5H
0005434551417	268	23	5G
0005434725875	268	24	11A
0005433233670	268	25	5K
0005433233910	268	26	11D
0005434551396	268	27	11C
0005433233627	268	28	11E
0005434031996	268	29	11K
0005434551424	268	30	11H
0005432277858	268	31	11G
0005434725810	268	32	12C
0005434725884	268	33	12A
0005432277856	268	34	12E
0005434551384	268	35	12G
0005433233843	268	36	12F
0005434725878	268	37	12K
0005434725846	268	38	12H
0005433233748	268	39	13A
0005433234101	268	40	13F
0005433289783	268	41	13E
0005434725809	268	42	13D
0005433180860	268	43	13K
0005434725865	268	44	13H
0005433126805	268	45	13G
0005434551420	268	46	14A
0005434725902	268	47	14D
0005434725835	268	48	14C
0005434551409	268	49	14G
0005434725832	268	50	14F
0005434725887	268	51	14E
0005434725819	268	52	14K
0005434725901	268	53	14H
0005434725860	268	54	15C
0005434725790	268	55	15A
0005435142624	268	56	15F
0005434551405	268	57	15E
0005434725828	268	58	15D
0005433234010	268	59	15G
0005433233883	268	60	16A
0005433289785	268	61	15K
0005435142620	268	62	15H
0005433233702	268	63	16D
0005432277851	268	64	16C
0005433233795	268	65	16F
0005435142613	268	66	16E
0005434725817	268	67	16G
0005434725826	268	68	17C
0005434725868	268	69	17A
0005434725816	268	70	16K
0005434725871	268	71	17E
0005434725794	268	72	17D
0005433289772	268	73	17G
0005434725888	268	74	18A
0005433289827	268	75	17K
0005433180943	268	76	17H
0005433180922	268	77	18B
0005434725847	268	78	18E
0005434551386	268	79	18D
0005434551390	268	80	18C
0005434725861	268	81	18G
0005435142615	268	82	18F
0005434725831	268	83	18H
0005433180969	268	84	19B
0005433289782	268	85	19A
0005434551428	268	86	18K
0005434725874	268	87	19D
0005434725800	268	88	19C
0005434725825	268	89	19F
0005434725872	268	90	19E
0005434725879	268	91	19J
0005433289819	268	92	19H
0005434725834	268	93	19G
0005433233747	268	94	20A
0005433234155	268	95	19K
0005434725811	268	96	20C
0005434725894	268	97	20B
0005433180915	268	98	20E
0005434725889	268	99	20D
0005434725812	268	100	20G
0005434725797	268	101	20K
0005434735699	268	102	20J
0005434032009	268	103	20H
0005433234011	268	104	21A
0005433233763	268	105	21E
0005434551416	268	106	21D
0005434725853	268	107	21C
0005433234042	268	108	21G
0005433289809	268	109	21F
0005434551392	268	110	21J
0005433234003	268	111	21H
0005434725827	268	112	22A
0005433233623	268	113	21K
0005434551391	268	114	22C
0005433233628	268	115	22B
0005433233640	268	116	22G
0005432277854	268	117	22F
0005434551406	268	118	22J
0005433180901	268	119	22H
0005434725873	268	120	23B
0005434725821	268	121	23A
0005432277844	268	122	22K
0005433766613	268	123	23D
0005434725900	268	124	23F
0005434725852	268	125	23J
0005434725869	268	126	23H
0005433233950	268	127	23G
0005435142616	268	128	24D
0005434725870	268	129	24F
0005434302473	268	130	24E
0005434731183	268	131	25B
0005434725822	268	132	25A
0005434725854	268	133	24G
0005433233916	268	134	25C
0005434302474	268	135	25F
0005433233947	268	136	25E
0005434031989	268	137	25D
0005434551412	268	138	25H
0005433233934	268	139	25G
0005434725808	268	140	26A
0005433233762	268	141	25K
0005434551389	268	142	25J
0005433126830	268	143	26B
0005434725842	268	144	26E
0005434031960	268	145	26D
0005434032008	268	146	26C
0005434551414	268	147	26G
0005433233915	268	148	26F
0005433180954	268	149	26K
0005434725851	268	150	26J
0005434725862	268	151	26H
0005432277850	268	152	27A
0005433180923	268	153	27D
0005434725806	268	154	27C
0005434551419	268	155	27B
0005433233924	268	156	27F
0005433180962	268	157	27H
0005434551408	268	158	27G
0005433289771	268	159	28A
0005434725795	268	160	27K
0005434032006	268	161	28C
0005434725898	268	162	28B
0005433126822	268	163	28E
0005434731182	268	164	28D
0005434551435	268	165	28G
0005434725829	268	166	28F
0005434725841	268	167	28J
0005434725866	268	168	29B
0005434551434	268	169	29A
0005433233981	268	170	28K
0005434551433	268	171	29D
0005434725799	268	172	29C
0005433766611	268	173	29E
0005434551381	268	174	29H
0005433180832	268	175	29G
0005433233879	268	176	29K
0005434551385	268	177	29J
0005433234040	268	178	30C
0005432277846	268	179	30B
0005433180900	268	180	30A
0005434725845	268	181	30E
0005433234004	268	182	30D
0005434725882	268	183	30G
0005434725909	268	184	30F
0005434551399	268	185	30J
0005433233794	268	186	30H
0005434551425	268	187	31B
0005434735700	268	188	30K
0005434032003	268	189	31D
0005433289781	268	190	31C
0005434725815	268	191	31F
0005435142617	268	192	31E
0005435142625	268	193	31H
0005433180910	268	194	31G
0005433233683	268	195	31K
0005433233606	268	196	31J
0005434725910	268	197	32C
0005434032002	268	198	32B
0005434725803	268	199	32A
0005434551413	268	200	32E
0005433180968	268	201	32D
0005433233943	268	202	32G
0005434551418	268	203	32H
0005434725908	268	204	33B
0005434725833	268	205	32K
0005434031997	268	206	33D
0005434725804	268	207	33C
0005434551422	268	208	33F
0005433180963	268	209	33E
0005434725899	268	210	33H
0005435142618	268	211	33G
0005434725890	268	212	34A
0005434725850	268	213	33K
0005434725796	268	214	33J
0005433234102	268	215	34C
0005433233546	268	216	34B
0005434551393	268	217	34E
0005434725857	268	218	34D
0005434725863	268	219	34G
0005434725849	268	220	34F
0005434725824	268	221	34J
0005434725883	268	222	34H
0005433233774	268	223	34K
0005432277845	268	224	35D
0005433180985	268	225	35C
0005433289810	268	226	35B
0005433233944	268	227	35E
0005434725844	268	228	35H
0005434725839	268	229	35G
0005433233998	268	230	35K
0005433766609	268	231	35J
0005434551427	268	232	36D
0005434731179	268	233	36C
0005434725858	268	234	36B
0005434551394	268	235	36E
0005434735702	268	236	36H
0005434725912	268	237	36F
0005433180870	268	238	36K
0005433233951	268	239	36J
0005434725877	268	240	37B
0005434725840	268	241	37A
0005434725813	268	242	37D
0005434725792	268	243	37G
0005433131697	268	244	37E
0005434032005	268	245	37H
0005434031984	268	246	38A
0005433233798	268	247	37K
0005434735703	268	248	37J
0005434725793	268	249	38C
0005434551411	268	250	38B
0005434725818	268	251	38J
0005434725791	268	252	38H
0005433233990	268	253	39B
0005434725895	268	254	39A
0005433233982	268	255	38K
0005434725855	268	256	39D
0005433126810	268	257	39C
0005434031988	268	258	39G
0005433233724	268	259	39F
0005434731181	268	260	39E
0005434725891	268	261	39H
0005433233830	268	262	39K
0005433233759	268	263	39J
0005434725798	268	264	40C
0005433234154	268	265	40B
0005433233914	268	266	40F
0005433180953	268	267	40D
0005434725904	268	268	40G
0005433181044	268	269	40K
0005435142623	268	270	40J
0005434725856	268	271	40H
0005433233877	268	272	41A
0005433233925	268	273	41D
0005435142614	268	274	41C
0005432277848	268	275	41B
0005434551398	268	276	41F
0005434551387	268	277	41E
0005434725880	268	278	41J
0005433233833	268	279	41H
0005434735701	268	280	41G
0005434551431	268	281	42A
0005434725881	268	282	41K
0005433233624	268	283	42C
0005433180952	268	284	42B
0005434725876	268	285	42E
0005434725859	268	286	42D
0005434551400	268	287	42G
0005432277849	268	288	42F
0005434725893	268	289	42J
0005434725892	268	290	43B
0005433233935	268	291	43A
0005434725911	268	292	42K
0005434551426	268	293	43D
0005434725848	268	294	43C
0005434725823	268	295	43F
0005434725905	268	296	43E
0005433233853	268	297	43H
0005433289784	268	298	43G
0005435142621	268	299	44A
0005434551403	268	300	43K
0005433181045	268	301	43J
0005433126803	268	302	44C
0005433126806	268	303	44B
0005432277852	268	304	44E
0005433233684	268	305	44D
0005434725814	268	306	44G
0005434725897	268	307	44F
0005433233863	268	308	44K
0005433126809	268	309	44J
0005434725802	268	310	44H
0005432277847	268	311	45B
0005434551430	268	312	45A
0005433234002	268	313	45C
0005434551410	268	314	45F
0005434725805	268	315	45H
0005434551407	268	316	45G
0005433233876	268	317	45J
0005434725896	268	318	46C
0005434551382	268	319	46A
0005433233948	268	320	46E
0005433766623	268	321	46D
0005434725907	268	322	46G
0005434725836	268	323	46F
0005434551402	268	324	46J
0005433126811	268	325	46H
0005434725830	268	326	47A
0005434725906	268	327	46K
0005433234041	268	328	47E
0005432277855	268	329	47D
0005433233960	268	330	47C
0005434551415	268	331	47G
0005434551383	268	332	47H
0005435142622	268	333	48D
0005432277853	268	334	48C
0005433233872	268	335	48A
0005434551421	268	336	48H
0005434725886	268	337	48G
0005434725820	268	338	48F
0005434725838	268	339	48K
0005433113524	268	340	49E
0005433180936	268	341	49D
0005433180937	268	342	49C
0005433180988	268	343	49G
0005434725843	268	344	49F
0005435142619	268	345	49K
0005434302472	268	346	50A
0005433233633	268	347	50E
0005434551401	268	348	50D
0005433233729	268	349	50G
0005433180941	268	350	50F
0005433233800	268	351	51D
0005432277857	268	352	50K
0005434551436	268	353	50H
0005434725837	268	354	51F
0005434551423	268	355	51E
0005433234377	9847	1	1C
0005433181172	9847	2	1H
0005434550947	9847	3	1G
0005433181176	9847	4	1D
0005433129288	9847	5	2A
0005434032041	9847	6	1K
0005434725226	9847	7	2C
0005433234379	9847	8	2H
0005433234403	9847	9	2D
0005434725151	9847	10	3C
0005433129287	9847	11	2K
0005434550833	9847	12	3D
0005433126857	9847	13	3K
0005434724559	9847	14	3H
0005433234370	9847	15	3G
0005434724922	9847	16	4C
0005434551020	9847	17	4A
0005434724591	9847	18	4D
0005433234420	9847	19	4K
0005434724562	9847	20	4H
0005434724624	9847	21	5D
0005434725094	9847	22	5C
0005432199267	9847	23	5A
0005434550898	9847	24	11A
0005433181166	9847	25	5K
0005434724722	9847	26	11E
0005434724801	9847	27	11C
0005434550814	9847	28	11G
0005434550876	9847	29	11F
0005433181171	9847	30	11H
0005435142468	9847	31	12C
0005433181178	9847	32	12A
0005434724776	9847	33	11K
0005434724809	9847	34	12E
0005434724389	9847	35	12D
0005434550870	9847	36	12F
0005434551062	9847	37	13A
0005434725104	9847	38	12K
0005434550829	9847	39	12H
0005434724684	9847	40	13C
0005434550793	9847	41	13E
0005434724807	9847	42	13H
0005434725039	9847	43	13G
0005433181184	9847	44	14C
0005433234380	9847	45	14A
0005434550997	9847	46	14D
0005433181183	9847	47	14G
0005434724682	9847	48	14F
0005434725078	9847	49	14E
0005435142465	9847	50	14K
0005433181167	9847	51	14H
0005434550944	9847	52	15C
0005433234400	9847	53	15E
0005432199268	9847	54	15D
0005434724996	9847	55	15H
0005434550996	9847	56	15G
0005433234373	9847	57	15F
0005434551041	9847	58	16A
0005433289870	9847	59	15K
0005434724323	9847	60	16D
0005434724663	9847	61	16C
0005433234418	9847	62	16E
0005434724587	9847	63	16K
0005434725093	9847	64	16H
0005433766650	9847	65	16G
0005434724989	9847	66	17A
0005433129290	9847	67	17E
0005434724908	9847	68	17D
0005434724288	9847	69	17C
0005434725002	9847	70	17G
0005432199270	9847	71	18A
0005433234430	9847	72	17K
0005433289869	9847	73	17H
0005434725408	9847	74	18C
0005434735628	9847	75	18B
0005434032038	9847	76	18E
0005434551082	9847	77	18H
0005433181180	9847	78	18F
0005434550714	9847	79	18J
0005432199272	9847	80	19B
0005433766653	9847	81	18K
0005434735660	9847	82	19D
0005434550807	9847	83	19C
0005433126859	9847	84	19F
0005434724472	9847	85	19E
0005435142528	9847	86	19H
0005434724459	9847	87	19G
0005433766652	9847	88	19K
0005433234428	9847	89	20B
0005434724802	9847	90	20E
0005434724893	9847	91	20D
0005433234404	9847	92	20G
0005433234423	9847	93	20F
0005434724806	9847	94	20K
0005434302434	9847	95	20J
0005434725071	9847	96	20H
0005433181189	9847	97	21A
0005435142421	9847	98	21D
0005433234396	9847	99	21C
0005434724713	9847	100	21G
0005434724799	9847	101	21F
0005434724681	9847	102	21E
0005434551072	9847	103	21H
0005433234397	9847	104	22A
0005433181187	9847	105	21K
0005433234408	9847	106	22C
0005433181170	9847	107	22B
0005435142512	9847	108	22F
0005433234371	9847	109	22E
0005434551061	9847	110	22D
0005434724915	9847	111	22G
0005433181175	9847	112	22K
0005433234414	9847	113	22J
0005434724479	9847	114	22H
0005433181185	9847	115	23B
0005433234402	9847	116	23A
0005434302421	9847	117	23D
0005434731142	9847	118	23C
0005433126856	9847	119	23G
0005433181177	9847	120	23E
0005433181168	9847	121	23J
0005434551081	9847	122	23H
0005434724653	9847	123	24D
0005434724710	9847	124	23K
0005434725407	9847	125	25B
0005434724678	9847	126	25A
0005434550777	9847	127	24G
0005434724412	9847	128	25C
0005434725040	9847	129	25E
0005433234374	9847	130	25H
0005435142529	9847	131	25G
0005435142511	9847	132	26A
0005434731147	9847	133	25K
0005434724695	9847	134	25J
0005433234372	9847	135	26C
0005434724615	9847	136	26B
0005432199269	9847	137	26D
0005434550748	9847	138	26G
0005433234427	9847	139	26F
0005434724995	9847	140	26J
0005434724541	9847	141	26H
0005433289872	9847	142	27A
0005434724815	9847	143	27D
0005433234406	9847	144	27C
0005434302422	9847	145	27F
0005434724872	9847	146	27E
0005434724497	9847	147	27H
0005434550634	9847	148	27G
0005434725001	9847	149	27K
0005434550850	9847	150	28E
0005433113543	9847	151	28D
0005434735642	9847	152	28C
0005434724664	9847	153	28G
0005434550762	9847	154	28F
0005432199266	9847	155	28K
0005434724363	9847	156	28J
0005434724686	9847	157	28H
0005435142478	9847	158	29B
0005433234387	9847	159	29A
0005434724543	9847	160	29D
0005434724877	9847	161	29C
0005434724824	9847	162	29F
0005434551016	9847	163	29E
0005433181179	9847	164	29H
0005435142464	9847	165	29G
0005434550961	9847	166	29K
0005434550830	9847	167	29J
0005434724652	9847	168	30B
0005434724685	9847	169	30E
0005434724745	9847	170	30D
0005434724610	9847	171	30C
0005434550686	9847	172	30F
0005433126860	9847	173	30J
0005432199271	9847	174	30H
0005434550896	9847	175	31B
0005434550644	9847	176	31A
0005433234416	9847	177	30K
0005433234385	9847	178	31C
0005434724798	9847	179	31E
0005433234412	9847	180	31D
0005434724679	9847	181	31H
0005434724906	9847	182	32A
0005434551015	9847	183	31K
0005433181188	9847	184	32C
0005434550883	9847	185	32E
0005433234399	9847	186	32D
0005434550749	9847	187	32G
0005434724629	9847	188	32F
0005434550832	9847	189	32K
0005434550871	9847	190	32J
0005434550834	9847	191	32H
0005434724818	9847	192	33A
0005434724097	9847	193	33D
0005434725075	9847	194	33C
0005433234425	9847	195	33F
0005434731136	9847	196	33E
0005433289871	9847	197	33J
0005434724810	9847	198	33H
0005434550839	9847	199	33G
0005434724992	9847	200	34A
0005434550792	9847	201	33K
0005435142463	9847	202	34E
0005434550913	9847	203	34D
0005434724816	9847	204	34C
0005434724201	9847	205	34F
0005433234395	9847	206	34K
0005433234422	9847	207	34J
0005434550687	9847	208	34H
0005434724712	9847	209	35A
0005434724540	9847	210	35D
0005434735643	9847	211	35C
0005434725137	9847	212	35F
0005433234383	9847	213	35E
0005433181174	9847	214	35H
0005433181182	9847	215	35G
0005434550889	9847	216	36A
0005434550960	9847	217	35K
0005433181190	9847	218	36B
0005434724905	9847	219	36F
0005433234409	9847	220	36E
0005433234426	9847	221	36D
0005434302433	9847	222	36H
0005433289867	9847	223	36G
0005433234419	9847	224	36K
0005434724289	9847	225	37B
0005434731130	9847	226	37E
0005434724364	9847	227	37C
0005435142448	9847	228	37G
0005434724462	9847	229	37F
0005433234411	9847	230	37J
0005434724940	9847	231	37H
0005433181173	9847	232	38A
0005434724825	9847	233	37K
0005434550761	9847	234	38C
0005434724627	9847	235	38B
0005433234401	9847	236	38H
0005433234398	9847	237	39A
0005434724725	9847	238	39D
0005434724790	9847	239	39C
0005433234386	9847	240	39B
0005434724552	9847	241	39F
0005434724803	9847	242	39E
0005433129291	9847	243	39H
0005433234376	9847	244	39G
0005433129289	9847	245	39J
0005433234410	9847	246	40C
0005434302423	9847	247	40B
0005433234431	9847	248	40D
0005434724864	9847	249	40H
0005433289868	9847	250	40G
0005435142440	9847	251	40F
0005434302424	9847	252	40J
0005434735671	9847	253	41B
0005434724365	9847	254	41A
0005434724694	9847	255	41D
0005433234369	9847	256	41F
0005434551004	9847	257	41E
0005433113542	9847	258	41H
0005434724791	9847	259	41G
0005433234393	9847	260	42A
0005433234424	9847	261	41K
0005434550831	9847	262	42B
0005433234390	9847	263	42E
0005433234394	9847	264	42D
0005434550959	9847	265	42G
0005434731141	9847	266	42J
0005434551118	9847	267	42H
0005434724909	9847	268	43A
0005433234392	9847	269	42K
0005435142422	9847	270	43D
0005434551005	9847	271	43C
0005435142439	9847	272	43B
0005433181186	9847	273	43F
0005434032040	9847	274	43E
0005434724914	9847	275	43H
0005434724283	9847	276	43G
0005434724800	9847	277	43K
0005433234388	9847	278	43J
0005433234375	9847	279	44C
0005434724980	9847	280	44B
0005434550965	9847	281	44A
0005433234381	9847	282	44D
0005433234417	9847	283	44H
0005434550891	9847	284	44G
0005434735627	9847	285	44F
0005434724448	9847	286	44J
0005434724458	9847	287	45B
0005435142495	9847	288	45A
0005434724792	9847	289	44K
0005434725130	9847	290	45D
0005433234413	9847	291	45C
0005434724654	9847	292	45G
0005434550882	9847	293	45F
0005433234407	9847	294	45E
0005434724117	9847	295	45J
0005434724367	9847	296	45H
0005434550743	9847	297	45K
0005433234405	9847	298	46B
0005434724808	9847	299	46A
0005434550958	9847	300	46E
0005434550897	9847	301	46D
0005434550742	9847	302	46C
0005433289865	9847	303	46G
0005433234391	9847	304	46F
0005434724619	9847	305	46K
0005435142417	9847	306	46J
0005433234429	9847	307	47C
0005434724521	9847	308	47D
0005433234382	9847	309	47G
0005433181165	9847	310	47F
0005433234432	9847	311	47E
0005433289866	9847	312	47K
0005434724544	9847	313	48C
0005433234378	9847	314	48A
0005433234389	9847	315	48E
0005434724312	9847	316	48D
0005434724489	9847	317	48H
0005434724991	9847	318	48G
0005433181181	9847	319	49A
0005434550734	9847	320	48K
0005434731135	9847	321	49D
0005433234384	9847	322	49F
0005433234415	9847	323	49E
0005434724193	9847	324	49K
0005434724833	9847	325	49H
0005433126858	9847	326	49G
0005434032039	9847	327	50C
0005434724616	9847	328	50A
0005434551100	9847	329	50E
0005434724438	9847	330	50G
0005433234368	9847	331	50F
0005433234421	9847	332	50K
0005433181169	9847	333	50H
0005433766651	9847	334	51F
0005434724498	9847	335	51E
0005434550835	9847	336	51G
0005432528436	7755	1	1C
0005432528356	7755	2	1A
0005435213016	7755	3	1D
0005432528347	7755	4	2A
0005435213175	7755	5	1H
0005432528369	7755	6	2C
0005435213344	7755	7	2H
0005432150221	7755	8	2G
0005432528427	7755	9	2D
0005435213041	7755	10	3A
0005432528392	7755	11	2K
0005432535847	7755	12	3G
0005435213119	7755	13	3D
0005435213343	7755	14	3C
0005435213176	7755	15	3H
0005432528405	7755	16	4A
0005432069701	7755	17	3K
0005435212883	7755	18	4D
0005435213226	7755	19	4C
0005435213186	7755	20	4K
0005435213321	7755	21	4H
0005433656644	7755	22	5C
0005434067808	7755	23	5A
0005434067773	7755	24	5H
0005432069700	7755	25	5G
0005432528416	7755	26	11C
0005432528353	7755	27	11A
0005434067768	7755	28	5K
0005435213442	7755	29	11D
0005432528344	7755	30	11F
0005435212958	7755	31	11E
0005435213317	7755	32	11K
0005432528384	7755	33	11H
0005432528424	7755	34	11G
0005432528380	7755	35	12C
0005434067781	7755	36	12E
0005435212882	7755	37	12D
0005434067789	7755	38	12G
0005432528438	7755	39	12F
0005434067777	7755	40	12K
0005432150219	7755	41	12H
0005435212816	7755	42	13D
0005435213048	7755	43	13A
0005432528415	7755	44	13F
0005432528430	7755	45	13H
0005432528421	7755	46	13G
0005432528374	7755	47	14A
0005435213168	7755	48	13K
0005432528337	7755	49	14F
0005432528375	7755	50	14K
0005435213120	7755	51	14G
0005432528389	7755	52	15C
0005432528376	7755	53	15A
0005435213451	7755	54	15E
0005432528368	7755	55	15D
0005432528318	7755	56	15H
0005434067759	7755	57	15F
0005432528410	7755	58	16A
0005435213053	7755	59	15K
0005434067818	7755	60	16D
0005432528413	7755	61	16C
0005434067762	7755	62	16F
0005434067785	7755	63	16H
0005435630949	7755	64	16G
0005433656655	7755	65	17C
0005435213289	7755	66	17A
0005435213619	7755	67	17E
0005432069705	7755	68	17D
0005434067751	7755	69	17H
0005435213425	7755	70	17F
0005432533302	7755	71	17K
0005434067794	7755	72	18C
0005434067797	7755	73	18B
0005434067806	7755	74	18A
0005432528445	7755	75	18E
0005432528386	7755	76	18D
0005432528329	7755	77	18G
0005432528418	7755	78	18F
0005435213255	7755	79	18J
0005434067776	7755	80	18H
0005432528391	7755	81	19B
0005432528340	7755	82	19A
0005435213389	7755	83	18K
0005432069698	7755	84	19D
0005435213086	7755	85	19C
0005432528338	7755	86	19F
0005434067790	7755	87	19E
0005432150220	7755	88	19H
0005435213161	7755	89	19G
0005435213174	7755	90	19K
0005432528360	7755	91	19J
0005432528326	7755	92	20B
0005432528357	7755	93	20A
0005434067807	7755	94	20E
0005434067780	7755	95	20D
0005432528426	7755	96	20G
0005432528320	7755	97	20F
0005432150218	7755	98	20J
0005432428938	7755	99	20H
0005434067763	7755	100	21A
0005432528435	7755	101	21D
0005432528400	7755	102	21C
0005434067787	7755	103	21B
0005432528428	7755	104	21F
0005432528366	7755	105	21J
0005432528439	7755	106	21G
0005432069697	7755	107	22A
0005434067756	7755	108	21K
0005435213003	7755	109	22C
0005435213096	7755	110	22E
0005434067747	7755	111	22D
0005432528359	7755	112	22H
0005435630950	7755	113	22G
0005434067767	7755	114	22F
0005432528404	7755	115	22K
0005432528327	7755	116	22J
0005432535850	7755	117	23A
0005432528403	7755	118	23E
0005432528423	7755	119	23D
0005432528419	7755	120	23C
0005435213261	7755	121	23F
0005432528446	7755	122	23J
0005434067771	7755	123	23H
0005432528345	7755	124	24D
0005432528373	7755	125	23K
0005435213474	7755	126	24G
0005434067774	7755	127	24E
0005434067770	7755	128	25A
0005432528407	7755	129	25C
0005435213262	7755	130	25B
0005434067749	7755	131	25D
0005432069702	7755	132	25G
0005435213042	7755	133	25J
0005432528444	7755	134	26C
0005434067779	7755	135	26B
0005434067783	7755	136	26A
0005433656643	7755	137	26D
0005435213284	7755	138	26F
0005432528440	7755	139	26J
0005435213131	7755	140	27A
0005435212817	7755	141	27D
0005434067801	7755	142	27C
0005435212975	7755	143	27B
0005435213331	7755	144	27F
0005434067800	7755	145	27E
0005432528385	7755	146	27H
0005435212835	7755	147	27G
0005434067786	7755	148	27K
0005435213249	7755	149	27J
0005432537064	7755	150	28C
0005435213080	7755	151	28B
0005432528346	7755	152	28E
0005434067752	7755	153	28D
0005435213095	7755	154	28H
0005432535846	7755	155	28G
0005432528378	7755	156	28F
0005432528370	7755	157	28J
0005432528339	7755	158	29B
0005432528417	7755	159	29A
0005435213072	7755	160	28K
0005432528328	7755	161	29D
0005435213040	7755	162	29C
0005435213045	7755	163	29F
0005432528442	7755	164	29E
0005432069699	7755	165	29H
0005435213323	7755	166	29G
0005432428939	7755	167	29J
0005432528351	7755	168	30B
0005432528324	7755	169	30A
0005434067764	7755	170	30D
0005434067795	7755	171	30G
0005432528433	7755	172	30F
0005434067758	7755	173	30J
0005432528437	7755	174	31A
0005432528367	7755	175	30K
0005434067766	7755	176	31D
0005432528406	7755	177	31C
0005432533301	7755	178	31B
0005432528393	7755	179	31F
0005432528450	7755	180	31H
0005432528330	7755	181	31G
0005432528422	7755	182	31K
0005434067812	7755	183	32C
0005432528399	7755	184	32B
0005434067750	7755	185	32A
0005432528402	7755	186	32E
0005434067769	7755	187	32D
0005434067803	7755	188	32G
0005432528354	7755	189	32K
0005432528319	7755	190	32J
0005432528434	7755	191	32H
0005432069706	7755	192	33A
0005432150222	7755	193	33C
0005434067804	7755	194	33G
0005432528395	7755	195	33E
0005435213291	7755	196	33H
0005435213143	7755	197	34A
0005434067799	7755	198	33K
0005435212986	7755	199	33J
0005432528394	7755	200	34C
0005432528323	7755	201	34B
0005432528336	7755	202	34E
0005435213309	7755	203	34D
0005432069696	7755	204	34H
0005432528363	7755	205	34G
0005434067809	7755	206	34F
0005435213290	7755	207	34J
0005432528317	7755	208	35B
0005432528325	7755	209	35A
0005432528335	7755	210	35D
0005432528350	7755	211	35C
0005435213017	7755	212	35G
0005432528432	7755	213	35E
0005435725594	7755	214	35J
0005434067811	7755	215	35H
0005432528447	7755	216	36A
0005432528349	7755	217	36C
0005432528425	7755	218	36E
0005432528333	7755	219	36D
0005432535848	7755	220	36G
0005434067810	7755	221	36F
0005432069703	7755	222	36J
0005432533299	7755	223	37B
0005432528334	7755	224	37A
0005435213337	7755	225	36K
0005432528361	7755	226	37D
0005432533300	7755	227	37C
0005434067805	7755	228	37F
0005435213105	7755	229	37E
0005434067813	7755	230	37G
0005435212954	7755	231	38A
0005434067761	7755	232	38C
0005435213185	7755	233	38B
0005432528321	7755	234	38J
0005435213223	7755	235	39A
0005432528431	7755	236	38K
0005434067796	7755	237	39D
0005432069694	7755	238	39C
0005434067772	7755	239	39F
0005432528358	7755	240	39H
0005434067775	7755	241	39K
0005434067753	7755	242	39J
0005435213203	7755	243	40C
0005432069695	7755	244	40B
0005432528332	7755	245	40A
0005432528388	7755	246	40E
0005432528414	7755	247	40D
0005432528390	7755	248	40G
0005432528365	7755	249	40F
0005435213022	7755	250	40K
0005432428941	7755	251	40J
0005432528381	7755	252	41A
0005432528429	7755	253	41C
0005432528342	7755	254	41B
0005435213164	7755	255	41F
0005435212987	7755	256	41E
0005435213221	7755	257	41J
0005433656654	7755	258	41H
0005435213310	7755	259	41G
0005434067816	7755	260	42A
0005435213165	7755	261	42C
0005432528449	7755	262	42B
0005432528412	7755	263	42E
0005432528396	7755	264	42D
0005434067760	7755	265	42F
0005432535849	7755	266	42K
0005432528371	7755	267	42J
0005432528401	7755	268	42H
0005435212959	7755	269	43A
0005435213162	7755	270	43C
0005432528420	7755	271	43F
0005434067793	7755	272	43E
0005434067778	7755	273	43D
0005432528362	7755	274	43H
0005432528364	7755	275	43G
0005435213283	7755	276	43J
0005434067815	7755	277	44C
0005432528343	7755	278	44A
0005434067755	7755	279	44E
0005432528331	7755	280	44D
0005434067784	7755	281	44G
0005435213087	7755	282	44F
0005432528348	7755	283	44H
0005435213239	7755	284	45B
0005432069704	7755	285	45A
0005434067814	7755	286	44K
0005432528377	7755	287	45D
0005435212931	7755	288	45C
0005432528443	7755	289	45F
0005435212803	7755	290	45E
0005435213484	7755	291	45H
0005432528379	7755	292	45G
0005434067782	7755	293	45K
0005434067819	7755	294	46C
0005434067765	7755	295	46B
0005435213070	7755	296	46A
0005435213250	7755	297	46E
0005434067757	7755	298	46D
0005434067788	7755	299	46G
0005434067754	7755	300	46F
0005434067798	7755	301	46J
0005432528352	7755	302	46H
0005432528372	7755	303	47C
0005432150216	7755	304	47A
0005432528382	7755	305	46K
0005432528411	7755	306	47E
0005432528398	7755	307	47G
0005434067802	7755	308	47F
0005435213213	7755	309	47K
0005432528448	7755	310	47H
0005434067817	7755	311	48C
0005435213088	7755	312	48A
0005435213094	7755	313	48E
0005432528383	7755	314	48D
0005435213330	7755	315	48H
0005432528387	7755	316	48G
0005432537063	7755	317	49A
0005432428940	7755	318	48K
0005434067748	7755	319	49E
0005432528322	7755	320	49D
0005434067792	7755	321	49C
0005432528341	7755	322	49G
0005432150215	7755	323	49F
0005432528409	7755	324	49K
0005435213214	7755	325	49H
0005435213034	7755	326	50C
0005432528441	7755	327	50A
0005432069693	7755	328	50E
0005432528397	7755	329	50D
0005434067791	7755	330	50H
0005432528355	7755	331	50F
0005432150217	7755	332	51D
0005435213224	7755	333	51E
0005432528408	7755	334	51G
0005435614004	5328	1	1C
0005435613963	5328	2	1D
0005432133263	5328	3	1K
0005435614060	5328	4	1H
0005435302160	5328	5	2C
0005435490237	5328	6	2A
0005435613957	5328	7	2H
0005434244834	5328	8	3A
0005435614073	5328	9	2K
0005434244882	5328	10	3D
0005435424339	5328	11	3C
0005435614009	5328	12	3K
0005435319537	5328	13	3H
0005435614036	5328	14	3G
0005434573396	5328	15	4C
0005434244718	5328	16	4A
0005435613984	5328	17	4G
0005435097234	5328	18	4D
0005435614011	5328	19	5A
0005435613959	5328	20	4K
0005434344355	5328	21	4H
0005435097225	5328	22	5D
0005435319500	5328	23	5C
0005434573402	5328	24	5H
0005434244821	5328	25	5G
0005435614050	5328	26	11A
0005435614034	5328	27	5K
0005435305005	5328	28	11D
0005435613994	5328	29	11C
0005435613995	5328	30	11E
0005435424286	5328	31	11H
0005435424290	5328	32	11G
0005434244717	5328	33	12C
0005434344359	5328	34	11K
0005435614012	5328	35	12F
0005435319548	5328	36	12E
0005432133251	5328	37	12D
0005435613960	5328	38	13A
0005434344345	5328	39	12K
0005434244750	5328	40	12H
0005435614031	5328	41	13D
0005435424224	5328	42	13C
0005435424644	5328	43	13F
0005435424267	5328	44	13E
0005434344349	5328	45	13H
0005435424467	5328	46	13G
0005435424554	5328	47	14A
0005435614041	5328	48	13K
0005435614003	5328	49	14D
0005434573399	5328	50	14F
0005434344353	5328	51	14E
0005434344337	5328	52	14K
0005434344346	5328	53	14H
0005435097229	5328	54	14G
0005434344335	5328	55	15F
0005435424292	5328	56	15E
0005433719112	5328	57	15D
0005435305004	5328	58	16A
0005435490240	5328	59	15K
0005435613986	5328	60	15H
0005434656543	5328	61	16D
0005433719111	5328	62	16C
0005434573397	5328	63	16F
0005432133256	5328	64	16E
0005435614039	5328	65	16K
0005432133258	5328	66	16H
0005435380277	5328	67	16G
0005435424560	5328	68	17C
0005434244833	5328	69	17A
0005435614027	5328	70	17D
0005435319480	5328	71	17G
0005432363389	5328	72	17E
0005435614071	5328	73	18A
0005435614048	5328	74	17K
0005435424528	5328	75	17H
0005435613980	5328	76	18C
0005434573398	5328	77	18B
0005435424663	5328	78	18G
0005435424658	5328	79	18F
0005434344343	5328	80	18K
0005435614028	5328	81	18J
0005432133265	5328	82	18H
0005435424312	5328	83	19A
0005434244901	5328	84	19D
0005435424439	5328	85	19C
0005435614064	5328	86	19B
0005432133262	5328	87	19G
0005434244753	5328	88	19F
0005435424030	5328	89	19E
0005435614014	5328	90	19H
0005434344357	5328	91	20A
0005435424643	5328	92	19K
0005434244779	5328	93	19J
0005434244741	5328	94	20B
0005435614000	5328	95	20E
0005435613998	5328	96	20D
0005435424813	5328	97	20C
0005434344329	5328	98	20H
0005435614058	5328	99	20G
0005435613988	5328	100	20F
0005435613958	5328	101	20J
0005435614059	5328	102	21B
0005435614023	5328	103	21A
0005434244870	5328	104	21D
0005434344347	5328	105	21F
0005432133260	5328	106	21E
0005435491445	5328	107	21J
0005432133252	5328	108	21H
0005435424629	5328	109	21G
0005435042845	5328	110	22A
0005435614019	5328	111	22C
0005432133250	5328	112	22B
0005434344326	5328	113	22E
0005435614074	5328	114	22D
0005435424409	5328	115	22G
0005435613987	5328	116	22F
0005435424387	5328	117	22K
0005435613977	5328	118	22J
0005435424420	5328	119	23B
0005432133264	5328	120	23A
0005435614062	5328	121	23D
0005434573395	5328	122	23C
0005435614068	5328	123	23F
0005435042839	5328	124	23E
0005435614030	5328	125	23J
0005434344334	5328	126	23H
0005434656542	5328	127	23G
0005435614066	5328	128	24D
0005435424307	5328	129	23K
0005435424327	5328	130	24F
0005435613969	5328	131	24E
0005434344342	5328	132	25B
0005435614067	5328	133	24G
0005435424459	5328	134	25C
0005435614054	5328	135	25F
0005435614063	5328	136	25E
0005434344339	5328	137	25J
0005435424498	5328	138	25G
0005435613968	5328	139	26A
0005435424549	5328	140	25K
0005434244783	5328	141	26C
0005435614013	5328	142	26B
0005434244892	5328	143	26E
0005435555374	5328	144	26G
0005435424268	5328	145	26F
0005435097227	5328	146	26J
0005435614016	5328	147	26H
0005435614053	5328	148	27A
0005434344325	5328	149	26K
0005432133254	5328	150	27D
0005435614037	5328	151	27C
0005435614055	5328	152	27B
0005433719114	5328	153	27E
0005435613985	5328	154	27H
0005435614024	5328	155	27G
0005435613990	5328	156	28A
0005435613972	5328	157	27K
0005435614010	5328	158	27J
0005435614046	5328	159	28B
0005435097226	5328	160	28E
0005432133255	5328	161	28D
0005435614015	5328	162	28C
0005435614021	5328	163	28G
0005434573403	5328	164	28F
0005435614032	5328	165	28J
0005435613967	5328	166	28K
0005435424553	5328	167	29C
0005435424422	5328	168	29B
0005435613993	5328	169	29G
0005435613964	5328	170	29F
0005435424432	5328	171	29E
0005435614026	5328	172	30A
0005435613976	5328	173	29K
0005434344352	5328	174	29J
0005434344341	5328	175	30C
0005434244784	5328	176	30B
0005435424320	5328	177	30E
0005434573392	5328	178	30D
0005435424321	5328	179	30G
0005435319525	5328	180	30F
0005434244854	5328	181	30K
0005435614038	5328	182	30J
0005435555375	5328	183	30H
0005434244900	5328	184	31A
0005434244785	5328	185	31D
0005435614001	5328	186	31C
0005435613982	5328	187	31B
0005434344361	5328	188	31F
0005435613989	5328	189	31E
0005435614018	5328	190	31G
0005434344344	5328	191	32A
0005435319547	5328	192	31J
0005435380279	5328	193	32C
0005435491447	5328	194	32E
0005435424547	5328	195	32D
0005432133259	5328	196	32G
0005435613979	5328	197	32F
0005435614057	5328	198	32K
0005432133257	5328	199	32J
0005434244883	5328	200	32H
0005435613974	5328	201	33A
0005435614005	5328	202	33D
0005435424243	5328	203	33C
0005434573390	5328	204	33B
0005435424499	5328	205	33F
0005435614065	5328	206	33E
0005435614051	5328	207	33J
0005434573400	5328	208	33H
0005434573393	5328	209	33G
0005435424686	5328	210	33K
0005435424820	5328	211	34B
0005434573394	5328	212	34A
0005434344360	5328	213	34D
0005435613997	5328	214	34G
0005435614025	5328	215	34J
0005435424701	5328	216	34H
0005435424388	5328	217	35B
0005435424349	5328	218	35A
0005435319528	5328	219	35D
0005435614006	5328	220	35C
0005435613991	5328	221	35F
0005435613973	5328	222	35E
0005435424473	5328	223	35H
0005435424685	5328	224	35G
0005435319543	5328	225	36A
0005435319507	5328	226	35K
0005434244830	5328	227	36C
0005435424603	5328	228	36B
0005435614070	5328	229	36D
0005434344351	5328	230	36H
0005435424517	5328	231	36G
0005434344328	5328	232	36F
0005435302159	5328	233	36J
0005434344333	5328	234	37B
0005434344330	5328	235	36K
0005435424617	5328	236	37D
0005435614040	5328	237	37C
0005434344338	5328	238	37F
0005434344332	5328	239	37E
0005435424581	5328	240	37J
0005434344358	5328	241	37H
0005435424548	5328	242	37G
0005435097235	5328	243	38A
0005434344348	5328	244	38B
0005435614029	5328	245	38H
0005435424031	5328	246	39A
0005435424662	5328	247	38K
0005435613975	5328	248	39D
0005435380278	5328	249	39C
0005435097230	5328	250	39F
0005435613965	5328	251	39E
0005435424595	5328	252	39H
0005435424470	5328	253	39G
0005432133261	5328	254	40A
0005435613981	5328	255	39K
0005434244775	5328	256	40C
0005435614052	5328	257	40B
0005435319499	5328	258	40E
0005435097228	5328	259	40D
0005435424656	5328	260	40G
0005435424742	5328	261	40F
0005435614061	5328	262	40K
0005434244817	5328	263	40J
0005435097231	5328	264	41B
0005435613971	5328	265	41A
0005435097233	5328	266	41F
0005434344356	5328	267	41E
0005435614044	5328	268	41H
0005435424262	5328	269	42A
0005435613978	5328	270	41K
0005435613999	5328	271	41J
0005435424503	5328	272	42C
0005435555376	5328	273	42B
0005434656540	5328	274	42D
0005435424460	5328	275	42H
0005435424657	5328	276	42G
0005435614047	5328	277	42F
0005435424469	5328	278	42J
0005432047562	5328	279	43A
0005435097232	5328	280	43D
0005435319479	5328	281	43C
0005435305006	5328	282	43B
0005434573391	5328	283	43G
0005435424437	5328	284	43F
0005435613962	5328	285	43E
0005435614056	5328	286	43H
0005435424348	5328	287	44A
0005435614007	5328	288	43K
0005435424266	5328	289	43J
0005435614043	5328	290	44B
0005435490238	5328	291	44E
0005435380270	5328	292	44D
0005434344340	5328	293	44C
0005435613983	5328	294	44G
0005435424289	5328	295	44F
0005432133253	5328	296	44K
0005435614008	5328	297	44J
0005435424421	5328	298	45B
0005432047561	5328	299	45A
0005434244891	5328	300	45D
0005434244742	5328	301	45C
0005435614033	5328	302	45E
0005435613961	5328	303	45G
0005435614022	5328	304	45K
0005435614035	5328	305	45J
0005432047563	5328	306	46A
0005435614072	5328	307	46E
0005435380280	5328	308	46D
0005435424412	5328	309	46G
0005435613966	5328	310	46F
0005432047560	5328	311	46J
0005435614069	5328	312	46H
0005434573401	5328	313	47C
0005435424558	5328	314	47A
0005434344331	5328	315	46K
0005435614017	5328	316	47E
0005435491446	5328	317	47D
0005434344327	5328	318	47G
0005435614002	5328	319	47F
0005433719123	5328	320	47K
0005435424411	5328	321	47H
0005435614042	5328	322	48C
0005435424557	5328	323	48A
0005435614020	5328	324	48F
0005435319536	5328	325	48E
0005435424519	5328	326	48D
0005435490239	5328	327	48H
0005435614075	5328	328	48G
0005435614049	5328	329	49A
0005435613992	5328	330	48K
0005434244822	5328	331	49D
0005434656545	5328	332	49C
0005434344354	5328	333	49G
0005435305003	5328	334	49F
0005434344350	5328	335	49K
0005435613996	5328	336	49H
0005435424410	5328	337	50C
0005434344336	5328	338	50A
0005435424438	5328	339	50F
0005435614045	5328	340	50E
0005435424468	5328	341	50D
0005434244776	5328	342	50H
0005435424624	5328	343	50K
0005435613970	5328	344	51D
0005435097144	10906	1	1C
0005435425029	10906	2	1A
0005434573226	10906	3	1G
0005435612942	10906	4	1D
0005435319597	10906	5	2A
0005435613452	10906	6	1K
0005435612802	10906	7	1H
0005435612817	10906	8	2D
0005434343877	10906	9	2C
0005435425050	10906	10	2H
0005435612734	10906	11	2G
0005435612760	10906	12	3D
0005435425020	10906	13	3C
0005435612577	10906	14	3K
0005434245072	10906	15	3H
0005432841020	10906	16	4C
0005435612895	10906	17	4A
0005435612726	10906	18	4G
0005434245062	10906	19	4D
0005435613225	10906	20	4K
0005435380305	10906	21	5D
0005435425015	10906	22	5C
0005435097100	10906	23	5G
0005435613105	10906	24	5K
0005435613247	10906	25	5H
0005435425009	10906	26	11D
0005435425055	10906	27	11C
0005435425036	10906	28	11F
0005435613057	10906	29	11E
0005435613194	10906	30	11K
0005435319604	10906	31	11H
0005434245060	10906	32	12C
0005434245081	10906	33	12A
0005435613356	10906	34	12E
0005435612848	10906	35	12H
0005435613480	10906	36	12F
0005434573302	10906	37	13D
0005435613272	10906	38	13C
0005435613056	10906	39	13F
0005435613372	10906	40	13E
0005435613563	10906	41	13H
0005435490193	10906	42	13G
0005434343944	10906	43	13K
0005435612576	10906	44	14D
0005435425043	10906	45	14C
0005434245074	10906	46	14F
0005435613099	10906	47	14E
0005435424994	10906	48	14H
0005435612938	10906	49	15C
0005435490194	10906	50	15D
0005434573288	10906	51	15H
0005435613071	10906	52	15G
0005435304168	10906	53	15K
0005435612640	10906	54	16D
0005435319599	10906	55	16C
0005435613107	10906	56	16A
0005434245066	10906	57	16F
0005434344022	10906	58	16E
0005434343860	10906	59	16K
0005435613129	10906	60	16H
0005434245070	10906	61	16G
0005434245079	10906	62	17C
0005435425045	10906	63	17H
0005435613204	10906	64	17F
0005432363427	10906	65	17E
0005435612816	10906	66	17K
0005435319600	10906	67	18C
0005435613172	10906	68	18B
0005435425012	10906	69	18A
0005435613364	10906	70	18E
0005435612800	10906	71	18D
0005434245061	10906	72	18G
0005435613171	10906	73	18F
0005434245075	10906	74	18K
0005435425038	10906	75	18J
0005435097131	10906	76	18H
0005435425008	10906	77	19B
0005435425004	10906	78	19A
0005435097099	10906	79	19D
0005435612761	10906	80	19F
0005435613100	10906	81	19H
0005435425005	10906	82	19G
0005435613487	10906	83	20A
0005435613181	10906	84	20C
0005435425040	10906	85	20F
0005435424987	10906	86	20E
0005435097130	10906	87	20D
0005435319598	10906	88	20G
0005434245084	10906	89	20H
0005435612833	10906	90	21A
0005434343875	10906	91	20K
0005432165061	10906	92	21D
0005435613368	10906	93	21C
0005435613377	10906	94	21G
0005435612894	10906	95	21F
0005435613012	10906	96	21E
0005435613123	10906	97	22A
0005435425030	10906	98	21K
0005434245083	10906	99	21J
0005435612912	10906	100	22C
0005435424997	10906	101	22B
0005435613025	10906	102	22E
0005435612880	10906	103	22D
0005435424986	10906	104	22H
0005434656562	10906	105	22G
0005435612829	10906	106	22K
0005434343814	10906	107	22J
0005435424992	10906	108	23A
0005435613479	10906	109	23C
0005434343978	10906	110	23F
0005435612595	10906	111	23J
0005435425044	10906	112	23H
0005434245068	10906	113	24D
0005434573261	10906	114	23K
0005432165060	10906	115	24F
0005434245067	10906	116	25B
0005435612904	10906	117	25A
0005435613030	10906	118	24G
0005435612083	10906	119	25C
0005434245073	10906	120	25F
0005434343861	10906	121	25E
0005435304171	10906	122	25D
0005435613033	10906	123	25H
0005435612862	10906	124	25G
0005435424999	10906	125	25K
0005432165064	10906	126	25J
0005434245058	10906	127	26C
0005435424985	10906	128	26B
0005434344016	10906	129	26A
0005435425022	10906	130	26E
0005435612897	10906	131	26D
0005435097162	10906	132	26G
0005434343775	10906	133	26J
0005435319601	10906	134	26H
0005435424988	10906	135	27A
0005435425052	10906	136	27D
0005432166912	10906	137	27C
0005434343815	10906	138	27F
0005434573303	10906	139	27J
0005434245078	10906	140	27H
0005435613232	10906	141	28A
0005435612801	10906	142	27K
0005434343862	10906	143	28C
0005435613002	10906	144	28B
0005435425024	10906	145	28E
0005434343936	10906	146	28D
0005432165063	10906	147	28G
0005432166911	10906	148	28F
0005435319602	10906	149	28K
0005435425053	10906	150	28J
0005435613209	10906	151	28H
0005435304169	10906	152	29D
0005435612184	10906	153	29C
0005435613215	10906	154	29B
0005435425010	10906	155	29F
0005434344006	10906	156	29E
0005435612949	10906	157	29H
0005434245063	10906	158	29G
0005435097145	10906	159	29K
0005434343859	10906	160	29J
0005434344125	10906	161	30C
0005435424996	10906	162	30B
0005435097163	10906	163	30A
0005435613217	10906	164	30E
0005433719150	10906	165	30D
0005435613210	10906	166	30G
0005432165062	10906	167	30J
0005435097177	10906	168	30H
0005435425018	10906	169	31B
0005435612506	10906	170	31A
0005435380310	10906	171	30K
0005434245064	10906	172	31D
0005435612937	10906	173	31C
0005434343932	10906	174	31F
0005435425026	10906	175	31E
0005435613016	10906	176	31H
0005435612864	10906	177	31G
0005434343943	10906	178	32A
0005435613035	10906	179	31K
0005432165059	10906	180	32C
0005434245077	10906	181	32B
0005434343857	10906	182	32E
0005435425031	10906	183	32D
0005435380308	10906	184	32H
0005435424991	10906	185	32F
0005435612807	10906	186	32J
0005434343791	10906	187	33B
0005434343980	10906	188	33A
0005435425032	10906	189	32K
0005435425013	10906	190	33D
0005435612596	10906	191	33F
0005435319596	10906	192	33E
0005435613154	10906	193	33G
0005435613423	10906	194	34A
0005434343926	10906	195	33K
0005435612879	10906	196	34C
0005435612810	10906	197	34B
0005434344048	10906	198	34E
0005435491432	10906	199	34G
0005435612896	10906	200	34F
0005435612887	10906	201	34J
0005435613743	10906	202	34H
0005434573251	10906	203	35B
0005434343984	10906	204	34K
0005434245080	10906	205	35D
0005435304173	10906	206	35C
0005435613109	10906	207	35F
0005434343981	10906	208	35H
0005435613267	10906	209	36A
0005435304172	10906	210	35K
0005435613371	10906	211	35J
0005435612905	10906	212	36C
0005435425037	10906	213	36B
0005435613041	10906	214	36E
0005435425035	10906	215	36D
0005435424993	10906	216	36G
0005433719152	10906	217	36F
0005434343858	10906	218	36K
0005435612809	10906	219	36J
0005435613246	10906	220	36H
0005435613098	10906	221	37B
0005435425016	10906	222	37A
0005435613216	10906	223	37D
0005435424995	10906	224	37C
0005434245076	10906	225	37G
0005435042859	10906	226	37F
0005435613083	10906	227	37E
0005434656563	10906	228	37J
0005435304170	10906	229	38A
0005435490186	10906	230	37K
0005434344059	10906	231	38C
0005434343902	10906	232	38B
0005435425047	10906	233	38J
0005435613207	10906	234	38H
0005435425006	10906	235	39A
0005434344018	10906	236	38K
0005435097176	10906	237	39D
0005435612840	10906	238	39C
0005434343937	10906	239	39F
0005435613273	10906	240	39E
0005435612828	10906	241	39H
0005435425014	10906	242	39K
0005435319603	10906	243	39J
0005435425011	10906	244	40C
0005435490187	10906	245	40B
0005435425001	10906	246	40E
0005435380306	10906	247	40D
0005435380309	10906	248	40G
0005435613088	10906	249	40F
0005435612997	10906	250	40K
0005435425017	10906	251	40J
0005435613260	10906	252	40H
0005435613082	10906	253	41B
0005435425023	10906	254	41A
0005435612888	10906	255	41E
0005435425003	10906	256	41J
0005435612827	10906	257	41H
0005435425028	10906	258	41G
0005435613472	10906	259	42A
0005435097188	10906	260	41K
0005435613081	10906	261	42C
0005434245069	10906	262	42B
0005435612998	10906	263	42E
0005435612641	10906	264	42D
0005432841019	10906	265	42G
0005435613034	10906	266	42F
0005435425027	10906	267	42K
0005434245082	10906	268	42H
0005435425019	10906	269	43B
0005435613042	10906	270	43D
0005435613116	10906	271	43C
0005435424990	10906	272	43F
0005434245085	10906	273	43E
0005435425048	10906	274	43G
0005435613022	10906	275	44A
0005435490207	10906	276	43K
0005435425042	10906	277	43J
0005435425025	10906	278	44E
0005435425046	10906	279	44D
0005435613086	10906	280	44F
0005435425051	10906	281	44K
0005435425000	10906	282	44J
0005435612878	10906	283	44H
0005435612856	10906	284	45B
0005435425002	10906	285	45A
0005435425049	10906	286	45D
0005435613208	10906	287	45C
0005435612863	10906	288	45F
0005435424998	10906	289	45E
0005435612214	10906	290	45H
0005435612847	10906	291	45K
0005435042860	10906	292	46B
0005434343961	10906	293	46A
0005435097137	10906	294	46E
0005435425007	10906	295	46D
0005434343792	10906	296	46C
0005432363426	10906	297	46G
0005435380307	10906	298	46F
0005435613424	10906	299	46J
0005435425034	10906	300	46H
0005435612468	10906	301	47C
0005435490206	10906	302	47A
0005435613032	10906	303	47D
0005435613564	10906	304	47G
0005434343954	10906	305	47F
0005435613024	10906	306	47E
0005433719153	10906	307	47K
0005433719151	10906	308	47H
0005435613031	10906	309	48D
0005435613163	10906	310	48C
0005435424989	10906	311	48A
0005435490211	10906	312	48F
0005435612966	10906	313	48E
0005435613113	10906	314	48H
0005434245059	10906	315	48G
0005435425033	10906	316	49A
0005434245071	10906	317	48K
0005435612967	10906	318	49D
0005435613361	10906	319	49F
0005435425039	10906	320	49E
0005435425041	10906	321	49K
0005434245057	10906	322	50C
0005434245065	10906	323	50D
0005435425054	10906	324	50G
0005434344017	10906	325	50F
0005435425021	10906	326	51D
0005435613180	10906	327	50K
0005432165058	10906	328	51F
0005435613367	10906	329	51E
0005435613127	10906	330	51G
0005432459600	3293	1	1A
0005433633922	3293	2	1C
0005432181788	3293	3	1D
0005433507239	3293	4	1F
0005432181777	3293	5	2D
0005433805485	3293	6	2F
0005433633942	3293	7	3A
0005433805479	3293	8	3C
0005433507245	3293	9	4A
0005433633928	3293	10	3F
0005432459530	3293	11	4C
0005432459508	3293	12	4D
0005433805501	3293	13	5A
0005432459406	3293	14	4F
0005432459510	3293	15	5D
0005432181780	3293	16	5C
0005433805488	3293	17	5F
0005433805486	3293	18	6C
0005433633938	3293	19	6A
0005432459595	3293	20	6D
0005433633911	3293	21	7A
0005432459540	3293	22	6F
0005433633927	3293	23	7D
0005432181778	3293	24	7C
0005433633920	3293	25	8A
0005433507237	3293	26	7F
0005432459646	3293	27	8C
0005432459564	3293	28	8B
0005433633917	3293	29	8E
0005433633929	3293	30	9A
0005433805481	3293	31	8F
0005433633936	3293	32	9B
0005433507242	3293	33	9C
0005432459659	3293	34	9D
0005433507244	3293	35	9F
0005433507240	3293	36	9E
0005433507241	3293	37	10A
0005432459565	3293	38	10B
0005432459632	3293	39	10D
0005432459539	3293	40	10C
0005432459468	3293	41	10E
0005433805497	3293	42	10F
0005432459370	3293	43	11A
0005433633931	3293	44	11B
0005433805491	3293	45	11D
0005432181794	3293	46	11C
0005432459599	3293	47	11E
0005432181795	3293	48	12A
0005432181783	3293	49	11F
0005432459529	3293	50	12B
0005432459479	3293	51	12D
0005432459526	3293	52	12C
0005432181785	3293	53	12E
0005433507247	3293	54	12F
0005433507238	3293	55	13B
0005433633919	3293	56	13A
0005432459627	3293	57	13C
0005433633925	3293	58	13D
0005433805484	3293	59	13E
0005432181789	3293	60	14A
0005433507236	3293	61	13F
0005432181781	3293	62	14B
0005433507243	3293	63	14D
0005433805477	3293	64	14C
0005432459601	3293	65	14E
0005433805487	3293	66	14F
0005433805483	3293	67	15A
0005432459511	3293	68	15C
0005432459724	3293	69	15B
0005432459475	3293	70	15D
0005432459581	3293	71	15E
0005433805505	3293	72	16A
0005433805503	3293	73	15F
0005432459753	3293	74	16B
0005432181793	3293	75	16D
0005432181776	3293	76	16C
0005432459562	3293	77	16F
0005432181796	3293	78	16E
0005433805494	3293	79	17A
0005432181784	3293	80	17C
0005432459801	3293	81	17B
0005432459630	3293	82	17D
0005433805492	3293	83	17F
0005432459558	3293	84	17E
0005433633935	3293	85	18A
0005433633926	3293	86	18C
0005432181779	3293	87	18B
0005432459505	3293	88	18E
0005432459664	3293	89	18D
0005433507235	3293	90	18F
0005432459692	3293	91	19C
0005433633932	3293	92	19D
0005433805482	3293	93	20A
0005433633937	3293	94	19E
0005433805478	3293	95	20B
0005432459463	3293	96	20C
0005433633913	3293	97	20E
0005433805499	3293	98	20D
0005433805489	3293	99	20F
0005432459536	3293	100	21A
0005433633915	3293	101	21C
0005433633940	3293	102	21B
0005433633914	3293	103	21D
0005432459800	3293	104	21F
0005432459582	3293	105	21E
0005433633923	3293	106	22A
0005432181792	3293	107	22B
0005433633918	3293	108	22C
0005432181782	3293	109	22D
0005433633941	3293	110	22F
0005433633945	3293	111	22E
0005433633939	3293	112	23A
0005432181787	3293	113	23B
0005433633916	3293	114	23D
0005433507234	3293	115	23C
0005433805490	3293	116	23F
0005433805502	3293	117	23E
0005433805480	3293	118	24A
0005433633943	3293	119	24C
0005432459474	3293	120	24B
0005433633933	3293	121	24D
0005432459554	3293	122	24E
0005432459464	3293	123	24F
0005432459563	3293	124	25C
0005432181791	3293	125	25B
0005432459663	3293	126	25D
0005433507249	3293	127	25F
0005432459662	3293	128	25E
0005433633924	3293	129	26A
0005432459522	3293	130	26B
0005433805504	3293	131	26D
0005432459345	3293	132	26C
0005433633912	3293	133	26E
0005433805498	3293	134	26F
0005433805495	3293	135	27A
0005432181797	3293	136	27C
0005432459695	3293	137	27B
0005433805500	3293	138	27E
0005432459757	3293	139	27D
0005432459693	3293	140	28A
0005432459429	3293	141	27F
0005432459694	3293	142	28B
0005432181786	3293	143	28D
0005433633934	3293	144	28C
0005432459336	3293	145	28E
0005432459177	3293	146	28F
0005432459502	3293	147	29A
0005432459509	3293	148	29C
0005433805496	3293	149	29B
0005432459593	3293	150	29D
0005432181775	3293	151	29E
0005432181798	3293	152	29F
0005432459535	3293	153	30B
0005432181790	3293	154	30A
0005433805493	3293	155	30C
0005432459521	3293	156	30E
0005433507250	3293	157	30D
0005433507248	3293	158	30F
0005433633921	3293	159	31A
0005433633930	3293	160	31C
0005433633944	3293	161	31B
0005432459197	3293	162	31D
0005432459631	3293	163	31F
0005433507246	3293	164	31E
0005435885228	3292	1	1F
0005435885024	3292	2	2C
0005435885078	3292	3	3C
0005435884944	3292	4	4A
0005435884996	3292	5	4D
0005435885070	3292	6	4C
0005435885086	3292	7	5A
0005435885212	3292	8	5C
0005435885196	3292	9	6C
0005435884995	3292	10	6F
0005435885028	3292	11	7C
0005435885073	3292	12	8B
0005435885029	3292	13	8D
0005435884867	3292	14	9B
0005435884957	3292	15	9C
0005435885020	3292	16	11C
0005435885027	3292	17	11D
0005435884991	3292	18	12D
0005435884993	3292	19	12C
0005435885032	3292	20	14B
0005435884994	3292	21	15E
0005435885168	3292	22	15D
0005435884997	3292	23	16B
0005435884902	3292	24	16C
0005435885072	3292	25	16E
0005435884913	3292	26	16D
0005435884984	3292	27	17A
0005435885042	3292	28	17D
0005435885053	3292	29	18A
0005435885059	3292	30	19B
0005435885129	3292	31	19E
0005435884967	3292	32	20B
0005435885069	3292	33	21C
0005435885079	3292	34	22B
0005435885041	3292	35	22D
0005435885111	3292	36	25B
0005435885014	3292	37	25A
0005435884992	3292	38	25C
0005435885023	3292	39	26A
0005435885191	3292	40	26B
0005435885192	3292	41	26E
0005435884841	3292	42	27B
0005435885229	3292	43	27F
0005435884956	3292	44	29B
0005435885169	3292	45	29C
0005435884911	3292	46	30F
0005435884959	3292	47	31E
0005435885386	8326	1	1A
0005435885377	8326	2	1D
0005435885382	8326	3	1C
0005432460055	8326	4	1F
0005432460061	8326	5	2A
0005432460034	8326	6	2D
0005435885388	8326	7	3A
0005435885405	8326	8	2F
0005432460031	8326	9	3C
0005435885381	8326	10	3D
0005435885397	8326	11	3F
0005432460042	8326	12	4C
0005435885416	8326	13	4D
0005432460032	8326	14	5A
0005432042764	8326	15	4F
0005435885383	8326	16	5C
0005432460073	8326	17	5D
0005435885403	8326	18	6A
0005432460054	8326	19	5F
0005432460048	8326	20	6D
0005432460059	8326	21	7A
0005435885410	8326	22	7C
0005435885394	8326	23	7D
0005435885380	8326	24	8A
0005435885412	8326	25	7F
0005432460069	8326	26	8B
0005435885373	8326	27	8D
0005435885395	8326	28	8E
0005433507010	8326	29	9A
0005432460035	8326	30	8F
0005435885370	8326	31	9B
0005432460049	8326	32	9C
0005432460044	8326	33	9D
0005433507090	8326	34	9F
0005432042755	8326	35	9E
0005432460052	8326	36	10A
0005435885402	8326	37	10B
0005432460071	8326	38	10D
0005435885390	8326	39	10C
0005432042759	8326	40	10E
0005432460051	8326	41	10F
0005435885413	8326	42	11A
0005435885374	8326	43	11C
0005432042766	8326	44	11D
0005433507032	8326	45	11F
0005433507156	8326	46	11E
0005433507144	8326	47	12B
0005433507105	8326	48	12D
0005433507024	8326	49	12C
0005435885396	8326	50	12E
0005432460058	8326	51	12F
0005432042758	8326	52	13B
0005432460066	8326	53	13A
0005432460072	8326	54	13C
0005432042763	8326	55	13D
0005432460060	8326	56	13E
0005435885418	8326	57	14A
0005435885415	8326	58	13F
0005432460057	8326	59	14C
0005433507048	8326	60	14B
0005435885409	8326	61	14E
0005433507073	8326	62	15A
0005435885389	8326	63	14F
0005432460050	8326	64	15B
0005432042757	8326	65	15D
0005435885375	8326	66	15F
0005432042760	8326	67	15E
0005432042756	8326	68	16A
0005433507091	8326	69	16B
0005432460033	8326	70	16C
0005432460046	8326	71	16E
0005432460026	8326	72	17A
0005432460039	8326	73	16F
0005432460053	8326	74	17C
0005432460038	8326	75	17E
0005433507104	8326	76	18A
0005432460029	8326	77	17F
0005435885393	8326	78	18B
0005432460076	8326	79	18C
0005432042762	8326	80	18E
0005432460077	8326	81	18D
0005432460074	8326	82	19B
0005435885400	8326	83	18F
0005432460040	8326	84	19C
0005432460043	8326	85	20B
0005432042761	8326	86	20A
0005432460067	8326	87	20C
0005435885387	8326	88	20D
0005435885378	8326	89	20F
0005433507046	8326	90	21A
0005432460047	8326	91	21B
0005432042753	8326	92	21D
0005432460064	8326	93	21C
0005435885414	8326	94	21E
0005435885408	8326	95	21F
0005433507049	8326	96	22B
0005435885417	8326	97	22A
0005432460028	8326	98	22C
0005435885407	8326	99	22E
0005433506965	8326	100	22F
0005433507060	8326	101	23A
0005434312327	8326	102	23B
0005435885392	8326	103	23D
0005432460062	8326	104	23E
0005435885376	8326	105	24A
0005432460036	8326	106	23F
0005435885404	8326	107	24B
0005433507075	8326	108	24D
0005433507061	8326	109	24C
0005433507107	8326	110	24F
0005432460056	8326	111	24E
0005432460030	8326	112	25A
0005435885398	8326	113	25C
0005432460063	8326	114	25B
0005432460041	8326	115	25E
0005432460027	8326	116	25F
0005435885411	8326	117	26A
0005435885419	8326	118	26B
0005432460037	8326	119	26C
0005435885384	8326	120	26E
0005432460075	8326	121	26D
0005433507033	8326	122	26F
0005432460045	8326	123	27C
0005432460065	8326	124	27B
0005435885420	8326	125	27D
0005433507059	8326	126	27E
0005432460070	8326	127	28A
0005433507143	8326	128	27F
0005432460068	8326	129	28B
0005435885379	8326	130	28D
0005435885371	8326	131	28C
0005435885372	8326	132	28F
0005435885391	8326	133	29B
0005433507076	8326	134	29A
0005435885399	8326	135	29C
0005432042765	8326	136	29D
0005435885385	8326	137	29E
0005432042754	8326	138	30A
0005433507047	8326	139	30B
0005435885401	8326	140	30D
0005435885406	8326	141	30C
0005433507098	8326	142	31B
0005432460025	8326	143	31D
0005433805170	8328	1	1D
0005433633538	8328	2	2A
0005433805233	8328	3	1F
0005433805115	8328	4	2C
0005433805051	8328	5	3C
0005433805208	8328	6	3F
0005433633527	8328	7	3D
0005434143720	8328	8	4A
0005433805019	8328	9	4C
0005433805126	8328	10	4F
0005433633601	8328	11	5D
0005433633621	8328	12	5F
0005433633595	8328	13	6C
0005433805084	8328	14	6D
0005433633836	8328	15	6F
0005433805321	8328	16	7C
0005433633579	8328	17	8A
0005433805254	8328	18	8E
0005433805200	8328	19	8D
0005433633704	8328	20	8F
0005433633664	8328	21	9B
0005433633559	8328	22	9A
0005433805136	8328	23	9E
0005433805103	8328	24	10A
0005433805171	8328	25	10C
0005434143707	8328	26	10D
0005433633609	8328	27	10E
0005433633540	8328	28	11A
0005433633496	8328	29	11D
0005433633497	8328	30	12A
0005433633548	8328	31	12C
0005433805179	8328	32	12D
0005433805320	8328	33	13C
0005433633735	8328	34	13D
0005433633457	8328	35	14A
0005433633623	8328	36	14C
0005433633567	8328	37	14B
0005433633726	8328	38	14E
0005433805143	8328	39	14D
0005433633590	8328	40	14F
0005433805199	8328	41	15E
0005433633740	8328	42	16F
0005433633610	8328	43	17A
0005433805113	8328	44	17C
0005433805018	8328	45	17B
0005433805127	8328	46	18D
0005433633424	8328	47	18E
0005433805050	8328	48	20A
0005433805101	8328	49	20B
0005433805102	8328	50	20C
0005433633599	8328	51	20D
0005433805319	8328	52	20F
0005433805083	8328	53	20E
0005433633600	8328	54	21C
0005433805094	8328	55	21E
0005433805255	8328	56	21F
0005434143723	8328	57	22B
0005433805190	8328	58	22A
0005433633589	8328	59	22C
0005433633736	8328	60	22D
0005433805218	8328	61	22F
0005433633560	8328	62	22E
0005433805228	8328	63	23A
0005433633641	8328	64	23C
0005433805198	8328	65	24B
0005433633578	8328	66	24D
0005433805266	8328	67	25F
0005433805265	8328	68	26C
0005433805213	8328	69	26E
0005433805189	8328	70	26F
0005433805129	8328	71	27B
0005433633425	8328	72	27A
0005433805227	8328	73	27F
0005433805112	8328	74	28A
0005434143719	8328	75	28C
0005433633493	8328	76	28D
0005433633558	8328	77	29A
0005433805175	8328	78	28F
0005433633456	8328	79	29C
0005434143706	8328	80	29D
0005433805128	8328	81	29F
0005434271308	8328	82	30A
0005433805079	8328	83	30B
0005433805100	8328	84	30D
0005433805144	8328	85	30E
0005433633418	8328	86	31A
0005433805219	8328	87	31B
0005434271298	8328	88	31F
0005434183578	8330	1	4C
0005434183572	8330	2	26D
0005432383290	4654	1	1A
0005432383302	4654	2	1C
0005432727979	4654	3	1D
0005432383315	4654	4	1F
0005432383295	4654	5	2A
0005432383287	4654	6	2C
0005432383316	4654	7	2D
0005433722237	4654	8	2F
0005432383296	4654	9	3C
0005432383314	4654	10	3D
0005432383293	4654	11	4A
0005432383299	4654	12	4C
0005432383301	4654	13	4D
0005432383311	4654	14	4E
0005432727973	4654	15	4F
0005432383291	4654	16	5C
0005433722244	4654	17	5F
0005433722238	4654	18	6C
0005432383310	4654	19	6E
0005432383283	4654	20	6F
0005432727980	4654	21	7D
0005432727972	4654	22	7E
0005432383309	4654	23	8C
0005432727975	4654	24	8D
0005432383306	4654	25	8E
0005432383285	4654	26	9A
0005432727982	4654	27	9C
0005432727983	4654	28	9D
0005433454881	4654	29	9F
0005432383288	4654	30	10A
0005432383281	4654	31	11C
0005432727978	4654	32	11D
0005432383298	4654	33	11E
0005432383282	4654	34	11F
0005432727974	4654	35	12C
0005432727984	4654	36	12D
0005432727977	4654	37	12F
0005432727976	4654	38	13C
0005432383308	4654	39	13D
0005432383284	4654	40	13F
0005433454882	4654	41	14A
0005432383280	4654	42	14C
0005432383300	4654	43	14F
0005433722245	4654	44	15A
0005433722243	4654	45	15C
0005432383292	4654	46	15D
0005432383307	4654	47	15F
0005432383312	4654	48	16C
0005432383297	4654	49	16D
0005432383289	4654	50	16E
0005432383294	4654	51	17A
0005432727981	4654	52	17C
0005433722241	4654	53	17D
0005433722240	4654	54	18C
0005433722239	4654	55	18D
0005432383305	4654	56	18E
0005432383313	4654	57	18F
0005432383303	4654	58	19A
0005432383304	4654	59	19C
0005432383286	4654	60	19D
0005433453768	4654	61	20A
0005432383279	4654	62	20C
0005433722242	4654	63	20D
0005432727847	30238	1	1A
0005433451606	30238	2	1D
0005432382821	30238	3	1F
0005432382724	30238	4	2A
0005432382853	30238	5	3A
0005433194846	30238	6	3D
0005432382834	30238	7	4A
0005432382924	30238	8	4C
0005432727849	30238	9	4D
0005432382893	30238	10	4F
0005432382923	30238	11	5C
0005433451607	30238	12	5F
0005432382850	30238	13	6A
0005433453749	30238	14	6C
0005433453747	30238	15	6E
0005432382891	30238	16	7C
0005432727807	30238	17	7D
0005432382807	30238	18	7E
0005432727846	30238	19	7F
0005432382725	30238	20	8A
0005433451602	30238	21	8D
0005432382941	30238	22	8E
0005432382843	30238	23	8F
0005432382822	30238	24	9A
0005432382842	30238	25	9D
0005433453751	30238	26	9E
0005432727926	30238	27	9F
0005432727840	30238	28	10C
0005432382999	30238	29	10D
0005432727925	30238	30	10E
0005433722169	30238	31	11A
0005432727910	30238	32	11C
0005432382927	30238	33	12E
0005433194833	30238	34	12F
0005432382582	30238	35	13A
0005432382728	30238	36	13C
0005433453748	30238	37	13F
0005432382866	30238	38	14C
0005432383011	30238	39	14D
0005432382775	30238	40	14F
0005432382583	30238	41	15C
0005432382854	30238	42	15D
0005432727839	30238	43	15E
0005432727848	30238	44	16A
0005432382823	30238	45	16C
0005432382864	30238	46	16D
0005432382966	30238	47	16E
0005432382939	30238	48	17A
0005433451603	30238	49	17D
0005432382729	30238	50	17E
0005432382894	30238	51	17F
0005432382809	30238	52	18A
0005432727855	30238	53	18C
0005432382796	30238	54	18F
0005432382858	30238	55	19A
0005433453752	30238	56	19F
0005432382849	30238	57	20A
0005432382754	30238	58	20D
0005433722167	30238	59	20E
0005432382808	30238	60	20F
0005435529329	1754	1	1A
0005435541072	1754	2	1C
0005435541081	1754	3	1F
0005435529341	1754	4	2A
0005433516912	1754	5	2D
0005435541075	1754	6	2F
0005432924978	1754	7	3A
0005435529326	1754	8	3C
0005435541080	1754	9	3F
0005435529339	1754	10	4A
0005435541068	1754	11	4C
0005433516919	1754	12	4E
0005435541069	1754	13	4F
0005435529335	1754	14	5A
0005432294494	1754	15	5C
0005435529340	1754	16	5D
0005435529334	1754	17	5E
0005435541088	1754	18	6C
0005433516917	1754	19	7A
0005435541079	1754	20	7E
0005433516915	1754	21	7F
0005432294495	1754	22	8A
0005435529332	1754	23	8C
0005435541082	1754	24	9A
0005433516921	1754	25	9C
0005435541078	1754	26	9D
0005432925020	1754	27	9F
0005432294496	1754	28	10A
0005435541085	1754	29	10D
0005435529336	1754	30	10E
0005435541086	1754	31	10F
0005433516920	1754	32	11A
0005435541083	1754	33	11C
0005432294497	1754	34	11D
0005435529327	1754	35	11F
0005435541084	1754	36	12C
0005435541074	1754	37	12E
0005433516918	1754	38	14A
0005435541076	1754	39	14C
0005435529323	1754	40	14E
0005433516916	1754	41	14F
0005435541067	1754	42	15C
0005435529325	1754	43	15D
0005435529322	1754	44	15E
0005435529338	1754	45	16A
0005435541087	1754	46	16C
0005435529324	1754	47	16D
0005435529331	1754	48	16F
0005435529342	1754	49	17A
0005435529337	1754	50	17C
0005432925000	1754	51	17D
0005435541066	1754	52	17E
0005435529330	1754	53	17F
0005435529328	1754	54	18C
0005433516914	1754	55	18E
0005435541071	1754	56	18F
0005435529343	1754	57	19C
0005435541073	1754	58	19E
0005435541077	1754	59	19F
0005433516913	1754	60	20A
0005435541070	1754	61	20D
0005435529333	1754	62	20E
0005433516831	22006	1	1C
0005435540825	22006	2	1D
0005435540949	22006	3	2A
0005433516846	22006	4	2D
0005435540939	22006	5	4D
0005435540824	22006	6	5D
0005435540969	22006	7	6C
0005433516854	22006	8	6F
0005435517803	22006	9	7C
0005435517823	22006	10	7E
0005435540889	22006	11	8C
0005433516859	22006	12	8D
0005435540930	22006	13	8E
0005435540823	22006	14	9A
0005432925050	22006	15	9C
0005433516844	22006	16	9F
0005435540830	22006	17	10E
0005432925053	22006	18	11A
0005432925049	22006	19	11D
0005435517776	22006	20	11F
0005435540780	22006	21	12A
0005435540826	22006	22	12C
0005435517848	22006	23	12D
0005435540837	22006	24	13F
0005435540888	22006	25	14D
0005433516829	22006	26	14F
0005435517777	22006	27	15E
0005435540890	22006	28	15F
0005432925052	22006	29	16C
0005435517847	22006	30	16F
0005433516837	22006	31	17C
0005433516845	22006	32	17D
0005433516853	22006	33	17E
0005433516828	22006	34	17F
0005435540781	22006	35	18C
0005433516830	22006	36	18D
0005433516847	22006	37	18F
0005435517824	22006	38	19D
0005433516838	22006	39	20A
0005432925051	22006	40	20C
0005434664941	7396	1	1A
0005434664948	7396	2	1C
0005434458875	7396	3	1D
0005434458871	7396	4	1F
0005432839142	7396	5	2A
0005432823455	7396	6	2C
0005432839126	7396	7	2D
0005434458868	7396	8	2F
0005432839134	7396	9	3A
0005432839128	7396	10	3C
0005434458867	7396	11	3D
0005432839129	7396	12	3F
0005435252650	7396	13	4A
0005432839141	7396	14	4C
0005432839146	7396	15	4D
0005432839140	7396	16	4F
0005432839117	7396	17	5A
0005435252570	7396	18	5C
0005435252652	7396	19	5D
0005434458862	7396	20	5E
0005432839119	7396	21	5F
0005434458865	7396	22	6A
0005432839131	7396	23	6C
0005434458872	7396	24	6D
0005432839137	7396	25	6E
0005432073400	7396	26	7A
0005432839123	7396	27	7C
0005432839124	7396	28	7D
0005432839130	7396	29	7E
0005434664944	7396	30	7F
0005432839120	7396	31	8A
0005435252606	7396	32	8C
0005432839145	7396	33	8D
0005435252620	7396	34	8E
0005434458876	7396	35	8F
0005434458860	7396	36	9A
0005434458864	7396	37	9C
0005434458880	7396	38	9D
0005432839127	7396	39	9E
0005432839133	7396	40	9F
0005432839147	7396	41	10A
0005435252622	7396	42	10D
0005434458861	7396	43	10C
0005432839144	7396	44	10E
0005435252516	7396	45	10F
0005432839136	7396	46	11A
0005435252507	7396	47	11C
0005435252625	7396	48	11E
0005434458869	7396	49	11F
0005435252651	7396	50	12A
0005432839121	7396	51	12D
0005434458873	7396	52	12E
0005434458870	7396	53	12F
0005432839148	7396	54	13A
0005434664945	7396	55	13C
0005432839118	7396	56	13D
0005432073401	7396	57	13E
0005432839138	7396	58	13F
0005432839149	7396	59	14C
0005435252627	7396	60	14A
0005432839122	7396	61	14E
0005435252659	7396	62	14F
0005434458866	7396	63	15A
0005432839135	7396	64	15C
0005432841018	7396	65	15D
0005432839132	7396	66	15E
0005434664933	7396	67	15F
0005434458859	7396	68	16A
0005434458878	7396	69	16C
0005435252668	7396	70	16D
0005434664946	7396	71	16E
0005434458879	7396	72	16F
0005434458863	7396	73	17A
0005435252508	7396	74	17C
0005432839143	7396	75	17D
0005435252612	7396	76	17E
0005435252632	7396	77	18A
0005434458881	7396	78	18C
0005432841017	7396	79	18D
0005432073402	7396	80	18E
0005434664947	7396	81	18F
0005435252590	7396	82	19A
0005434458877	7396	83	19C
0005435252595	7396	84	19D
0005434664934	7396	85	20A
0005432839139	7396	86	19F
0005432839125	7396	87	20C
0005434458874	7396	88	20D
0005435252667	7396	89	20E
0005435252544	7396	90	20F
0005435252753	28933	1	1A
0005432840995	28933	2	1C
0005432838988	28933	3	1D
0005434458630	28933	4	1F
0005432838937	28933	5	2A
0005432838934	28933	6	2C
0005434664966	28933	7	2D
0005432838932	28933	8	2F
0005432823436	28933	9	3A
0005432838873	28933	10	3C
0005434458645	28933	11	3D
0005434664968	28933	12	3F
0005434458760	28933	13	4A
0005434664967	28933	14	4C
0005435252761	28933	15	4D
0005432838909	28933	16	4E
0005432838936	28933	17	4F
0005435252757	28933	18	5A
0005434458791	28933	19	5C
0005432838908	28933	20	5D
0005432839022	28933	21	5E
0005434458726	28933	22	5F
0005434664969	28933	23	6A
0005432838979	28933	24	6C
0005432823435	28933	25	6D
0005432838843	28933	26	6E
0005432838821	28933	27	6F
0005432838989	28933	28	7A
0005432841001	28933	29	7C
0005434458693	28933	30	7D
0005432838935	28933	31	7E
0005432838973	28933	32	7F
0005432838875	28933	33	8A
0005434458703	28933	34	8C
0005432838983	28933	35	8D
0005434458737	28933	36	8E
0005432838876	28933	37	8F
0005432838913	28933	38	9A
0005432001030	28933	39	9C
0005432838877	28933	40	9D
0005434458629	28933	41	9E
0005434458732	28933	42	9F
0005434458719	28933	43	10A
0005434458762	28933	44	10C
0005434458782	28933	45	10D
0005432838895	28933	46	10E
0005435252756	28933	47	10F
0005434458731	28933	48	11A
0005434458713	28933	49	11C
0005434458646	28933	50	11D
0005434458725	28933	51	11E
0005432838912	28933	52	11F
0005432838878	28933	53	12A
0005434458720	28933	54	12C
0005432838894	28933	55	12D
0005432838826	28933	56	12E
0005432838842	28933	57	12F
0005434664970	28933	58	13A
0005434458704	28933	59	13C
0005432838822	28933	60	13D
0005434458781	28933	61	13E
0005432838804	28933	62	13F
0005435252762	28933	63	14A
0005432838902	28933	64	14C
0005432838978	28933	65	14D
0005435252765	28933	66	14E
0005432838827	28933	67	14F
0005432838914	28933	68	15A
0005434458788	28933	69	15C
0005432838787	28933	70	15D
0005435252764	28933	71	15E
0005434458712	28933	72	15F
0005435252754	28933	73	16A
0005432838933	28933	74	16C
0005435252752	28933	75	16D
0005434458687	28933	76	16E
0005432838949	28933	77	16F
0005432838794	28933	78	17A
0005432838874	28933	79	17C
0005434458761	28933	80	17D
0005434458666	28933	81	17E
0005432838900	28933	82	17F
0005432838915	28933	83	18A
0005432838838	28933	84	18C
0005432838970	28933	85	18D
0005432838741	28933	86	18E
0005435252759	28933	87	18F
0005434458686	28933	88	19A
0005435252758	28933	89	19C
0005435252763	28933	90	19D
0005435252760	28933	91	19E
0005432838871	28933	92	19F
0005432838872	28933	93	20A
0005435252755	28933	94	20C
0005432841000	28933	95	20D
0005432838980	28933	96	20E
0005432841016	28933	97	20F
0005434276007	8814	1	2D
0005435990647	8814	2	3C
0005434275993	8814	3	8B
0005435990645	8814	4	8D
0005434276009	8814	5	12B
0005435990646	8814	6	14B
0005434276008	8814	7	15B
0005434276010	8814	8	16B
0005435990648	8814	9	16D
0005435990644	8814	10	17F
0005435990642	8814	11	19F
0005435990649	8814	12	20F
0005435990643	8814	13	20E
0005434276045	15728	1	1F
0005434276043	15728	2	2F
0005434276048	15728	3	6F
0005435990594	15728	4	7B
0005434276044	15728	5	7F
0005434276046	15728	6	10B
0005435990596	15728	7	12A
0005435990598	15728	8	14E
0005435990595	15728	9	15B
0005434276047	15728	10	17F
0005435990608	15728	11	17E
0005434276042	15728	12	20A
0005432427145	20629	1	2B
0005432427144	20629	2	2D
0005433476876	20629	3	4B
0005432427149	20629	4	6B
0005433476882	20629	5	7A
0005433476877	20629	6	7D
0005432427148	20629	7	19A
0005432427146	20629	8	19B
0005433476881	20629	9	20B
0005432427150	20629	10	20D
0005433476883	20629	11	21D
0005432427147	20629	12	22A
0005432427125	30848	1	2C
0005433476897	30848	2	3C
0005432427135	30848	3	5A
0005432427134	30848	4	6B
0005432427126	30848	5	6C
0005433476898	30848	6	7A
0005432427131	30848	7	19A
0005432427117	30848	8	19B
0005433476900	30848	9	19C
0005433476896	30848	10	21A
0005432427130	30848	11	21B
0005433476899	30848	12	21D
0005433468277	23853	1	1A
0005433468260	23853	2	1D
0005432909298	23853	3	2A
0005433468265	23853	4	2B
0005432909303	23853	5	2C
0005433468270	23853	6	2D
0005433468284	23853	7	3B
0005433468276	23853	8	3C
0005432909295	23853	9	4A
0005433468256	23853	10	4B
0005433468288	23853	11	4C
0005433468258	23853	12	4D
0005432909297	23853	13	5C
0005433468273	23853	14	5D
0005432909300	23853	15	6C
0005433468263	23853	16	7A
0005433468257	23853	17	18A
0005433468309	23853	18	18C
0005433468295	23853	19	18D
0005433468269	23853	20	19A
0005432909304	23853	21	19C
0005432909296	23853	22	20A
0005432909302	23853	23	20D
0005433468262	23853	24	21A
0005433468294	23853	25	21B
0005433468250	23853	26	21C
0005433468238	23853	27	22A
0005433468264	23853	28	22C
0005432909299	23853	29	22D
0005432909301	23853	30	23B
0005432360498	6383	1	1C
0005432336075	6383	2	1D
0005432360501	6383	3	1F
0005435490194	6383	4	2C
0005432062246	6383	5	2A
0005432360518	6383	6	2D
0005432360503	6383	7	3A
0005432360514	6383	8	2F
0005432360509	6383	9	3C
0005435176931	6383	10	3F
0005434149669	6383	11	4B
0005435177033	6383	12	4D
0005435490207	6383	13	4C
0005432360533	6383	14	4E
0005435176864	6383	15	5A
0005432360515	6383	16	5C
0005435490187	6383	17	5D
0005432360539	6383	18	5E
0005432360490	6383	19	5F
0005432360536	6383	20	6C
0005432360492	6383	21	6D
0005432360506	6383	22	6F
0005434149683	6383	23	6E
0005435177007	6383	24	7C
0005432363426	6383	25	7B
0005432062247	6383	26	7E
0005432360512	6383	27	7D
0005435176956	6383	28	7F
0005435176971	6383	29	8A
0005434149719	6383	30	8B
0005432360494	6383	31	8C
0005432360500	6383	32	8E
0005432360522	6383	33	8D
0005432360491	6383	34	8F
0005432360513	6383	35	9A
0005432360534	6383	36	9B
0005434149611	6383	37	9D
0005434149682	6383	38	9C
0005432360496	6383	39	9F
0005435176955	6383	40	10B
0005432360528	6383	41	10C
0005435176912	6383	42	11B
0005432360524	6383	43	11D
0005435176980	6383	44	11C
0005432360508	6383	45	11E
0005434149711	6383	46	12A
0005432360521	6383	47	12C
0005432336066	6383	48	12B
0005432363427	6383	49	12D
0005432360505	6383	50	13A
0005432336067	6383	51	13C
0005435176894	6383	52	13B
0005435176867	6383	53	13E
0005435176844	6383	54	14A
0005435176981	6383	55	14B
0005432360520	6383	56	14D
0005432336069	6383	57	14C
0005432360497	6383	58	14E
0005435177016	6383	59	14F
0005432360502	6383	60	15A
0005432360499	6383	61	15C
0005432360507	6383	62	15B
0005435490206	6383	63	15E
0005435490211	6383	64	15D
0005432336071	6383	65	16A
0005435177027	6383	66	15F
0005432360510	6383	67	16B
0005435490193	6383	68	16C
0005432336073	6383	69	16D
0005435176848	6383	70	16F
0005432336077	6383	71	16E
0005435176868	6383	72	17A
0005435177028	6383	73	17B
0005435176849	6383	74	17C
0005432360527	6383	75	17D
0005434149712	6383	76	18A
0005432336076	6383	77	17F
0005432062243	6383	78	18B
0005432360516	6383	79	18D
0005432360517	6383	80	18C
0005434149696	6383	81	18E
0005432360530	6383	82	18F
0005432360526	6383	83	19A
0005432336070	6383	84	19B
0005432360538	6383	85	19C
0005432360504	6383	86	19D
0005435176863	6383	87	19F
0005432360532	6383	88	20A
0005432360537	6383	89	20C
0005432360535	6383	90	20B
0005435177080	6383	91	20D
0005432336074	6383	92	20E
0005432360531	6383	93	21A
0005432360511	6383	94	20F
0005432062244	6383	95	21B
0005434149668	6383	96	21D
0005432360519	6383	97	21C
0005432336068	6383	98	21F
0005432360529	6383	99	22A
0005432062245	6383	100	22C
0005435490186	6383	101	22B
0005435177008	6383	102	22D
0005432360495	6383	103	22F
0005432336072	6383	104	22E
0005432360523	6383	105	23A
0005434149640	6383	106	23C
0005432360493	6383	107	23D
0005432360525	6383	108	23F
0005435177174	21016	1	1A
0005435177154	21016	2	1D
0005432360048	21016	3	1C
0005432359957	21016	4	2A
0005434149768	21016	5	1F
0005432360076	21016	6	2D
0005435177175	21016	7	2F
0005435177165	21016	8	3A
0005435177152	21016	9	3C
0005435177171	21016	10	3F
0005432360333	21016	11	4A
0005435177159	21016	12	4B
0005432360058	21016	13	4C
0005435177158	21016	14	4E
0005432360090	21016	15	4D
0005432363391	21016	16	5A
0005432360151	21016	17	5C
0005432360124	21016	18	5B
0005435490244	21016	19	5D
0005432335985	21016	20	5E
0005432360123	21016	21	6A
0005432336015	21016	22	5F
0005435490242	21016	23	6B
0005432335961	21016	24	6D
0005432363392	21016	25	6C
0005432360104	21016	26	6E
0005435177169	21016	27	6F
0005434149771	21016	28	7A
0005432360150	21016	29	7C
0005434149762	21016	30	7B
0005432360341	21016	31	7F
0005432360024	21016	32	7E
0005435177153	21016	33	8A
0005432360077	21016	34	8B
0005432360107	21016	35	8C
0005435177163	21016	36	8F
0005432363393	21016	37	8E
0005432360130	21016	38	9B
0005432360143	21016	39	9D
0005435177161	21016	40	9C
0005434149765	21016	41	9E
0005432360262	21016	42	9F
0005432360136	21016	43	10C
0005432359919	21016	44	10E
0005432363394	21016	45	10D
0005432360138	21016	46	11A
0005435177172	21016	47	11B
0005432335953	21016	48	11D
0005434149763	21016	49	11C
0005432052757	21016	50	11E
0005432360270	21016	51	11F
0005432360095	21016	52	12A
0005432359898	21016	53	12C
0005432360106	21016	54	12B
0005434149772	21016	55	12E
0005432052755	21016	56	12F
0005432360246	21016	57	13A
0005432359908	21016	58	13C
0005432359910	21016	59	13B
0005435177166	21016	60	13D
0005432335949	21016	61	13E
0005435177173	21016	62	13F
0005435177155	21016	63	14A
0005432363396	21016	64	14C
0005435177151	21016	65	14D
0005434149769	21016	66	14F
0005432360098	21016	67	14E
0005432360132	21016	68	15A
0005432335959	21016	69	15B
0005434149773	21016	70	15C
0005434149770	21016	71	15D
0005432360109	21016	72	15F
0005432363397	21016	73	15E
0005432363405	21016	74	16B
0005434149766	21016	75	16A
0005432360284	21016	76	16C
0005432360097	21016	77	16D
0005432360096	21016	78	16E
0005435177157	21016	79	17A
0005432360010	21016	80	16F
0005435177156	21016	81	17B
0005435723053	21016	82	17C
0005435177160	21016	83	17E
0005432360137	21016	84	17D
0005432360133	21016	85	18A
0005435177150	21016	86	17F
0005432335952	21016	87	18B
0005432335958	21016	88	18D
0005432335927	21016	89	18C
0005432052754	21016	90	18E
0005432360031	21016	91	19A
0005434149767	21016	92	18F
0005432360013	21016	93	19C
0005432359906	21016	94	19B
0005432360149	21016	95	19D
0005435177149	21016	96	19E
0005432359909	21016	97	19F
0005432360129	21016	98	20A
0005432363402	21016	99	20C
0005434149761	21016	100	20B
0005432360342	21016	101	20E
0005435490241	21016	102	20D
0005432360263	21016	103	20F
0005432360089	21016	104	21A
0005435490243	21016	105	21B
0005435177168	21016	106	21D
0005432359996	21016	107	21E
0005434149764	21016	108	22A
0005435490245	21016	109	21F
0005432052756	21016	110	22B
0005432335948	21016	111	22D
0005435177167	21016	112	22C
0005432360271	21016	113	22F
0005432360141	21016	114	22E
0005435177162	21016	115	23B
0005432335928	21016	116	23A
0005432359811	21016	117	23C
0005435177176	21016	118	23E
0005435177170	21016	119	23D
0005435177164	21016	120	23F
0005434458745	17713	1	1A
0005434186208	17713	2	1B
0005434458705	17713	3	1C
0005434448300	17713	4	2A
0005434458633	17713	5	2B
0005434458702	17713	6	2D
0005434458662	17713	7	3A
0005434186209	17713	8	3D
0005434448295	17713	9	4B
0005434461631	17713	10	4D
0005434186210	17713	11	5B
0005434461628	17713	12	5C
0005434458672	17713	13	6A
0005434448305	17713	14	6D
0005434448309	17713	15	7D
0005434458706	17713	16	18C
0005434458769	17713	17	19A
0005434458771	17713	18	19C
0005434458802	17713	19	20C
0005434458698	17713	20	20D
0005434458701	17713	21	21C
0005434458671	17713	22	21D
0005434458661	17713	23	22A
0005434458632	17713	24	22B
0005434458758	17713	25	22C
0005434448304	17713	26	22D
0005434458744	17713	27	23A
0005434458863	29098	1	1A
0005434462794	29098	2	1B
0005434458869	29098	3	1D
0005434458868	29098	4	2A
0005434458878	29098	5	2B
0005434448324	29098	6	2C
0005434462796	29098	7	2D
0005434463935	29098	8	3A
0005434458875	29098	9	3B
0005434458874	29098	10	3C
0005434458867	29098	11	3D
0005434458865	29098	12	4A
0005434458862	29098	13	4B
0005434458879	29098	14	4D
0005434458861	29098	15	5A
0005434186178	29098	16	5B
0005434458873	29098	17	5C
0005434186163	29098	18	6D
0005434186175	29098	19	7B
0005434458876	29098	20	7C
0005434458864	29098	21	7D
0005434186182	29098	22	18A
0005434458866	29098	23	18D
0005434458859	29098	24	19A
0005434186164	29098	25	19C
0005434448322	29098	26	19D
0005434448325	29098	27	20A
0005434448323	29098	28	20B
0005434458860	29098	29	20C
0005434458877	29098	30	20D
0005434463934	29098	31	21B
0005434458872	29098	32	21C
0005434458871	29098	33	21D
0005434462795	29098	34	22A
0005434458880	29098	35	22B
0005434458881	29098	36	22C
0005434448321	29098	37	22D
0005434458870	29098	38	23B
0005432664155	6494	1	1C
0005432663054	6494	2	2A
0005432664153	6494	3	2F
0005432664144	6494	4	2C
0005432663052	6494	5	3A
0005432664149	6494	6	4A
0005432663046	6494	7	4F
0005432661940	6494	8	5D
0005432661934	6494	9	6B
0005432661938	6494	10	6C
0005432663048	6494	11	6E
0005432664154	6494	12	6D
0005432661936	6494	13	7C
0005432663042	6494	14	7B
0005432661931	6494	15	7D
0005432661939	6494	16	8B
0005432663041	6494	17	8D
0005432663045	6494	18	9A
0005432661941	6494	19	9C
0005432663044	6494	20	9E
0005432663047	6494	21	10A
0005432663051	6494	22	9F
0005432663049	6494	23	10C
0005432664145	6494	24	10B
0005432664152	6494	25	11D
0005432663050	6494	26	12C
0005432664157	6494	27	13C
0005432664151	6494	28	13F
0005432663053	6494	29	14D
0005432661932	6494	30	14F
0005432661942	6494	31	15C
0005432661943	6494	32	15B
0005432661930	6494	33	15E
0005432664147	6494	34	16A
0005432664148	6494	35	15F
0005432661928	6494	36	17B
0005432661935	6494	37	17F
0005432661929	6494	38	18A
0005432664150	6494	39	18B
0005432664143	6494	40	19A
0005432664146	6494	41	19B
0005432664156	6494	42	19D
0005432663055	6494	43	19F
0005432663043	6494	44	20A
0005432661937	6494	45	20F
0005432661933	6494	46	21E
0005432604445	21426	1	1A
0005432604440	21426	2	1C
0005432604433	21426	3	1D
0005432604412	21426	4	2A
0005432604439	21426	5	2B
0005432604451	21426	6	2C
0005432604413	21426	7	2D
0005432604422	21426	8	3B
0005432604437	21426	9	3C
0005432604438	21426	10	3D
0005432604432	21426	11	4A
0005432604444	21426	12	4C
0005432604429	21426	13	4D
0005432604436	21426	14	5A
0005432604449	21426	15	5B
0005432604442	21426	16	5C
0005432604424	21426	17	5D
0005432604430	21426	18	6A
0005432604423	21426	19	6B
0005432604441	21426	20	6C
0005432604443	21426	21	7A
0005432604448	21426	22	7B
0005432604420	21426	23	7C
0005435218108	21426	24	7D
0005432604414	21426	25	18A
0005432604452	21426	26	18B
0005432604447	21426	27	18C
0005432604431	21426	28	18D
0005432604426	21426	29	19A
0005432604415	21426	30	19B
0005432604419	21426	31	19D
0005432604450	21426	32	20B
0005432604417	21426	33	20C
0005432604428	21426	34	20D
0005432604446	21426	35	21A
0005432604425	21426	36	21C
0005432604435	21426	37	21D
0005432604418	21426	38	22A
0005432604421	21426	39	22B
0005432604416	21426	40	22C
0005432604427	21426	41	23A
0005435218109	21426	42	22D
0005432604434	21426	43	23B
0005432604147	31669	1	1A
0005432604121	31669	2	1B
0005435221518	31669	3	2B
0005432604117	31669	4	2A
0005432604207	31669	5	2D
0005432604208	31669	6	3C
0005432604209	31669	7	3D
0005432604004	31669	8	4A
0005432604139	31669	9	4B
0005432604156	31669	10	4D
0005432604193	31669	11	5B
0005432604107	31669	12	5D
0005432604017	31669	13	6A
0005435221057	31669	14	6B
0005432603849	31669	15	7A
0005432604140	31669	16	7B
0005432604132	31669	17	7C
0005432604102	31669	18	7D
0005432604137	31669	19	18A
0005432604109	31669	20	18C
0005432604092	31669	21	18D
0005432604122	31669	22	19B
0005432604138	31669	23	19C
0005432604025	31669	24	19D
0005432604108	31669	25	20D
0005432604144	31669	26	21A
0005432604155	31669	27	21B
0005432604280	31669	28	21C
0005432604085	31669	29	21D
0005435221517	31669	30	22A
0005432604011	31669	31	22B
0005432604016	31669	32	22C
0005432604093	31669	33	23A
0005433293171	12312	1	1A
0005433293178	12312	2	1B
0005433293179	12312	3	1C
0005433293168	12312	4	2C
0005433293170	12312	5	2D
0005433293172	12312	6	3D
0005433293217	12312	7	4A
0005433293218	12312	8	4B
0005433293210	12312	9	4D
0005435154597	12312	10	5C
0005433293222	12312	11	6B
0005433293201	12312	12	6D
0005433293181	12312	13	7C
0005433293198	12312	14	7D
0005435154598	12312	15	18A
0005433293187	12312	16	18B
0005433293182	12312	17	18C
0005433293223	12312	18	19C
0005433293169	12312	19	19D
0005433293203	12312	20	20A
0005433293197	12312	21	20C
0005435154596	12312	22	21A
0005433293204	12312	23	21C
0005433293213	12312	24	21D
0005433293185	12312	25	22B
0005433293196	12312	26	22D
0005433293186	12312	27	23B
0005433473209	23889	1	1A
0005435257250	23889	2	1B
0005433473210	23889	3	1C
0005433473181	23889	4	2A
0005435257247	23889	5	2C
0005435257255	23889	6	2D
0005433473211	23889	7	3B
0005435257249	23889	8	3C
0005433473190	23889	9	3D
0005435257254	23889	10	4D
0005433473147	23889	11	5A
0005433473199	23889	12	5B
0005433473201	23889	13	5C
0005433473192	23889	14	5D
0005435257257	23889	15	6A
0005433473230	23889	16	6B
0005433473180	23889	17	6C
0005433473205	23889	18	6D
0005433473191	23889	19	7A
0005435257251	23889	20	7B
0005435257246	23889	21	7C
0005433473179	23889	22	18A
0005433473229	23889	23	18D
0005435257253	23889	24	19C
0005433473241	23889	25	19D
0005433473146	23889	26	21A
0005433473225	23889	27	22A
0005435257252	23889	28	22C
0005435257256	23889	29	22D
0005435257248	23889	30	23B
0005434606801	18923	1	2B
0005434603020	18923	2	3B
0005434606806	18923	3	4B
0005434606800	18923	4	5B
0005434606802	18923	5	6A
0005434606836	22303	1	1A
0005434604907	22303	2	2A
0005434604908	22303	3	2B
0005434604905	22303	4	3B
0005434606835	22303	5	4A
0005434604906	22303	6	4B
0005435904893	22303	7	5B
0005434604904	22303	8	5A
0005434606834	22303	9	6A
0005434602908	3859	1	1B
0005434522457	3859	2	2B
0005434602909	3859	3	3A
0005434522455	3859	4	3D
0005434522451	3859	5	5B
0005434602910	3859	6	5D
0005434522452	3859	7	6D
0005434602905	3859	8	7C
0005434602907	3859	9	19C
0005434602906	3859	10	20A
0005434522454	3859	11	20D
0005435904392	3859	12	21A
0005435904384	3859	13	21B
0005434522459	3859	14	22A
0005434522456	3859	15	22B
0005434522458	3859	16	22D
0005434522453	3859	17	23A
0005434604866	19048	1	1A
0005434522425	19048	2	1C
0005434604852	19048	3	2A
0005434522420	19048	4	2C
0005435904417	19048	5	2D
0005434602880	19048	6	3A
0005434604862	19048	7	3C
0005435904416	19048	8	3D
0005435904413	19048	9	4A
0005434522426	19048	10	4C
0005434522422	19048	11	5A
0005434602875	19048	12	5B
0005434602884	19048	13	5C
0005434522448	19048	14	5D
0005435904415	19048	15	6B
0005434522441	19048	16	6C
0005434522406	19048	17	7B
0005435904414	19048	18	18A
0005434602876	19048	19	18B
0005434604851	19048	20	18C
0005434522447	19048	21	18D
0005434522430	19048	22	19B
0005434604865	19048	23	19D
0005434604871	19048	24	20B
0005434604867	19048	25	21B
0005434522419	19048	26	21C
0005434604861	19048	27	21D
0005435904707	19048	28	22A
0005434522440	19048	29	22C
0005434522421	19048	30	22D
0005434602879	19048	31	23A
0005434602881	19048	32	23B
0005432747680	396	1	1A
0005432747667	396	2	1C
0005432747656	396	3	1D
0005432747668	396	4	1F
0005432751535	396	5	2A
0005432890877	396	6	2C
0005432890921	396	7	2D
0005432890922	396	8	2F
0005432747666	396	9	3A
0005432890869	396	10	3C
0005432751532	396	11	3D
0005432747655	396	12	3F
0005432890929	396	13	4A
0005432747675	396	14	4C
0005432747669	396	15	4D
0005432220019	396	16	4E
0005432890887	396	17	4F
0005432890932	396	18	5A
0005433293221	396	19	5C
0005432890892	396	20	5D
0005432220017	396	21	5E
0005432747657	396	22	5F
0005432890713	396	23	6A
0005432890882	396	24	6C
0005432747663	396	25	6D
0005432747693	396	26	6E
0005432749789	396	27	6F
0005432220018	396	28	7A
0005433875367	396	29	7C
0005433293208	396	30	7D
0005432753310	396	31	7E
0005432890910	396	32	7F
0005433293206	396	33	8A
0005432749790	396	34	8C
0005432747673	396	35	8D
0005432890888	396	36	8E
0005432890898	396	37	8F
0005432747687	396	38	9A
0005432749791	396	39	9C
0005432751533	396	40	9D
0005432890930	396	41	9E
0005432890894	396	42	9F
0005432890926	396	43	10A
0005432747684	396	44	10C
0005432747662	396	45	10D
0005432747688	396	46	10E
0005432747671	396	47	10F
0005432747679	396	48	11A
0005433875370	396	49	11C
0005433293227	396	50	11D
0005432751534	396	51	11E
0005432890960	396	52	11F
0005432890886	396	53	12A
0005433293199	396	54	12C
0005432747654	396	55	12D
0005432220015	396	56	12E
0005432747659	396	57	12F
0005432890885	396	58	13A
0005432747665	396	59	13C
0005432747674	396	60	13D
0005432753307	396	61	13E
0005432220016	396	62	13F
0005432753308	396	63	14A
0005432747664	396	64	14C
0005432890966	396	65	14D
0005432747678	396	66	14E
0005432751536	396	67	14F
0005432890884	396	68	15A
0005432890965	396	69	15C
0005432890868	396	70	15D
0005432747670	396	71	15E
0005433293220	396	72	15F
0005432747676	396	73	16A
0005432747685	396	74	16C
0005432747672	396	75	16D
0005432747653	396	76	16E
0005432890920	396	77	16F
0005432747681	396	78	17A
0005433293226	396	79	17C
0005432747677	396	80	17D
0005432747691	396	81	17E
0005432747682	396	82	17F
0005432747661	396	83	18A
0005432747686	396	84	18C
0005432747683	396	85	18D
0005432747690	396	86	18E
0005432753309	396	87	18F
0005433293195	396	88	19A
0005432220013	396	89	19C
0005432890967	396	90	19D
0005432220014	396	91	19E
0005432747658	396	92	19F
0005432890928	396	93	20A
0005432747660	396	94	20C
0005433293194	396	95	20D
0005432747692	396	96	20E
0005432747689	396	97	20F
0005432747349	12093	1	1C
0005432753288	12093	2	1F
0005432747515	12093	3	2C
0005432747305	12093	4	2D
0005432747300	12093	5	2F
0005432747418	12093	6	3C
0005432756815	12093	7	3D
0005432747419	12093	8	3F
0005432747301	12093	9	4A
0005432747132	12093	10	4C
0005432891089	12093	11	4D
0005432747369	12093	12	4E
0005432747550	12093	13	4F
0005432891071	12093	14	5A
0005432747306	12093	15	5C
0005432747517	12093	16	5D
0005432747404	12093	17	5E
0005432747371	12093	18	5F
0005432747386	12093	19	6A
0005433875386	12093	20	6C
0005432747417	12093	21	6D
0005432891084	12093	22	6E
0005432747131	12093	23	6F
0005432747398	12093	24	7A
0005432891078	12093	25	7C
0005432747551	12093	26	7D
0005432747310	12093	27	7E
0005432891087	12093	28	7F
0005432891081	12093	29	8A
0005432747447	12093	30	8C
0005432891085	12093	31	8D
0005432747405	12093	32	8E
0005432747533	12093	33	8F
0005432214810	12093	34	9A
0005432747372	12093	35	9D
0005433875385	12093	36	9E
0005432891088	12093	37	9F
0005432214811	12093	38	10A
0005432747231	12093	39	10D
0005432747399	12093	40	10E
0005432891072	12093	41	10F
0005435627115	12093	42	11A
0005432747233	12093	43	11C
0005432891076	12093	44	11D
0005432747416	12093	45	11E
0005432747518	12093	46	11F
0005432747307	12093	47	12A
0005432747470	12093	48	12C
0005432747338	12093	49	12D
0005432747337	12093	50	12E
0005432747532	12093	51	12F
0005432214812	12093	52	13C
0005432753276	12093	53	13D
0005432891077	12093	54	13E
0005432891075	12093	55	13F
0005432756826	12093	56	14A
0005432891082	12093	57	14C
0005432891079	12093	58	14D
0005432747367	12093	59	14E
0005432747351	12093	60	14F
0005432747462	12093	61	15A
0005435627114	12093	62	15C
0005432891070	12093	63	15D
0005432747373	12093	64	15F
0005432747420	12093	65	16A
0005432749770	12093	66	16C
0005432747433	12093	67	16E
0005432891083	12093	68	16F
0005432747393	12093	69	17A
0005432747446	12093	70	17C
0005432753275	12093	71	17D
0005432747319	12093	72	17E
0005432747350	12093	73	17F
0005432891080	12093	74	18C
0005432891086	12093	75	18D
0005432891074	12093	76	18E
0005432753295	12093	77	18F
0005432747270	12093	78	19A
0005432753285	12093	79	19C
0005432747536	12093	80	19D
0005432747370	12093	81	19E
0005432753284	12093	82	19F
0005432891073	12093	83	20A
0005432747403	12093	84	20D
0005432747514	12093	85	20E
0005432747320	12093	86	20F
0005432927954	18959	1	2A
0005433525060	18959	2	3B
0005433525063	18959	3	3C
0005433525067	18959	4	4A
0005433525062	18959	5	4D
0005433533315	18959	6	5A
0005433525065	18959	7	5B
0005433531301	18959	8	5C
0005432927938	18959	9	6A
0005433531302	18959	10	6B
0005433533316	18959	11	6D
0005433525066	18959	12	7A
0005433525061	18959	13	7B
0005433525059	18959	14	7C
0005432927952	18959	15	7D
0005433533314	18959	16	18A
0005433525064	18959	17	19A
0005433525069	18959	18	19C
0005433531303	18959	19	20A
0005432927937	18959	20	21A
0005433533317	18959	21	21C
0005433525068	18959	22	22D
0005433525058	18959	23	23B
0005433524984	32489	1	1A
0005433524969	32489	2	1B
0005433524989	32489	3	1C
0005432928003	32489	4	2A
0005433531280	32489	5	3B
0005433524981	32489	6	3C
0005433524971	32489	7	4A
0005433524998	32489	8	4C
0005432928000	32489	9	5B
0005433524982	32489	10	6A
0005432928005	32489	11	6C
0005433524983	32489	12	7A
0005433524990	32489	13	7B
0005432928002	32489	14	7C
0005433531277	32489	15	7D
0005433525031	32489	16	18B
0005433525016	32489	17	19B
0005433525032	32489	18	20B
0005432928001	32489	19	20C
0005433531285	32489	20	21C
0005433531275	32489	21	21D
0005433531284	32489	22	22A
0005432928006	32489	23	22B
0005433531276	32489	24	22D
0005432928004	32489	25	23A
0005435373007	5244	1	1C
0005434824017	5244	2	1A
0005432121378	5244	3	1H
0005435373049	5244	4	1G
0005435372962	5244	5	1K
0005435372761	5244	6	2C
0005435150078	5244	7	3C
0005435372919	5244	8	3A
0005435372732	5244	9	2K
0005435372898	5244	10	3D
0005434828704	5244	11	3K
0005434824029	5244	12	3H
0005434824015	5244	13	4C
0005434823941	5244	14	4A
0005432121374	5244	15	4G
0005434823939	5244	16	4K
0005435150075	5244	17	4H
0005434824013	5244	18	5C
0005434824027	5244	19	5A
0005434824003	5244	20	5H
0005435372861	5244	21	5G
0005435372804	5244	22	5K
0005435150070	5244	23	11E
0005435299747	5244	24	11C
0005432394114	5244	25	11G
0005434823959	5244	26	11K
0005432396254	5244	27	11H
0005434824035	5244	28	12C
0005434824023	5244	29	12A
0005435373014	5244	30	12E
0005434823936	5244	31	12D
0005434823938	5244	32	12H
0005434558303	5244	33	12G
0005435735098	5244	34	12K
0005434823970	5244	35	13C
0005434824007	5244	36	13F
0005435372791	5244	37	13E
0005434823994	5244	38	13H
0005435372948	5244	39	13G
0005432394119	5244	40	14C
0005435372889	5244	41	14A
0005435372668	5244	42	13K
0005435372803	5244	43	14E
0005434558308	5244	44	14G
0005435373018	5244	45	14F
0005434823918	5244	46	14K
0005434823947	5244	47	15A
0005434823933	5244	48	15F
0005435372864	5244	49	15E
0005435150068	5244	50	15H
0005435150072	5244	51	15G
0005434823931	5244	52	16A
0005434823973	5244	53	15K
0005434823985	5244	54	16C
0005434558307	5244	55	16F
0005434823986	5244	56	16E
0005434824001	5244	57	16H
0005434823952	5244	58	17C
0005434823969	5244	59	16K
0005435372986	5244	60	17E
0005432121376	5244	61	17G
0005435373002	5244	62	17F
0005435372704	5244	63	17K
0005435372694	5244	64	18C
0005435372552	5244	65	18A
0005434823968	5244	66	18E
0005434824022	5244	67	18D
0005434823966	5244	68	18G
0005435735097	5244	69	18F
0005435150067	5244	70	18J
0005434823995	5244	71	18H
0005435372756	5244	72	19A
0005434823987	5244	73	18K
0005434823993	5244	74	19D
0005434823911	5244	75	19C
0005434823932	5244	76	19F
0005434823965	5244	77	19E
0005434823958	5244	78	19H
0005435372859	5244	79	20A
0005432121381	5244	80	20C
0005432121377	5244	81	20B
0005435373153	5244	82	20E
0005434824012	5244	83	20D
0005434823996	5244	84	20H
0005435150079	5244	85	20G
0005434823999	5244	86	20F
0005435150066	5244	87	20J
0005435386541	5244	88	21B
0005434823955	5244	89	21C
0005434824009	5244	90	21G
0005435150071	5244	91	21F
0005432394120	5244	92	21E
0005434824008	5244	93	21J
0005434823992	5244	94	21H
0005435373164	5244	95	22C
0005434823915	5244	96	22E
0005434823982	5244	97	22H
0005434823945	5244	98	22G
0005435150077	5244	99	22F
0005435150069	5244	100	22K
0005434831162	5244	101	22J
0005435372767	5244	102	23B
0005434823990	5244	103	23A
0005434824026	5244	104	23C
0005435372855	5244	105	23H
0005435150074	5244	106	24D
0005435150076	5244	107	23J
0005432121372	5244	108	24E
0005434824021	5244	109	25A
0005435299762	5244	110	24G
0005432121375	5244	111	25D
0005434823917	5244	112	25C
0005434823909	5244	113	25F
0005434664965	5244	114	25E
0005434824010	5244	115	25K
0005435373084	5244	116	26C
0005434823991	5244	117	26E
0005435299749	5244	118	26D
0005435299748	5244	119	26G
0005435372566	5244	120	26H
0005432121379	5244	121	27B
0005434558305	5244	122	26K
0005434823967	5244	123	27C
0005435150080	5244	124	27F
0005434823997	5244	125	27D
0005435372820	5244	126	27K
0005434823949	5244	127	27J
0005434823957	5244	128	28B
0005434823922	5244	129	28A
0005434831161	5244	130	28E
0005434823943	5244	131	28C
0005435373103	5244	132	28H
0005434823924	5244	133	28G
0005434823927	5244	134	28F
0005435372705	5244	135	28K
0005434823921	5244	136	28J
0005434823998	5244	137	29A
0005434823913	5244	138	29D
0005434823971	5244	139	29B
0005434823937	5244	140	29F
0005434823942	5244	141	29E
0005434823948	5244	142	29J
0005434828702	5244	143	29H
0005435735090	5244	144	29K
0005434823981	5244	145	30B
0005434823910	5244	146	30A
0005434823980	5244	147	30E
0005434824005	5244	148	30C
0005432394117	5244	149	30G
0005432121385	5244	150	30J
0005434824014	5244	151	30H
0005432823428	5244	152	31B
0005434823977	5244	153	31D
0005434823984	5244	154	31C
0005435372760	5244	155	31F
0005435372964	5244	156	31E
0005435372965	5244	157	31H
0005434824032	5244	158	31G
0005435372741	5244	159	32A
0005435373121	5244	160	32B
0005435372854	5244	161	32E
0005435372918	5244	162	32D
0005434823920	5244	163	32C
0005435372915	5244	164	32H
0005434824025	5244	165	32G
0005434824020	5244	166	33D
0005434824002	5244	167	33F
0005434824030	5244	168	33E
0005434828703	5244	169	33H
0005434823950	5244	170	33G
0005434823935	5244	171	33K
0005434824024	5244	172	33J
0005435372993	5244	173	34B
0005434824006	5244	174	34A
0005435373017	5244	175	34E
0005432121382	5244	176	34D
0005435150073	5244	177	34C
0005432394115	5244	178	34G
0005435372773	5244	179	34F
0005435386520	5244	180	34K
0005432121371	5244	181	35A
0005435735093	5244	182	35D
0005435372827	5244	183	35F
0005434824031	5244	184	35J
0005435661906	5244	185	35K
0005435299739	5244	186	36B
0005434823914	5244	187	36A
0005435373165	5244	188	36E
0005435386544	5244	189	36D
0005434823979	5244	190	36F
0005435372790	5244	191	36K
0005434823925	5244	192	36J
0005434823930	5244	193	37B
0005434824019	5244	194	37A
0005432394116	5244	195	37E
0005435386531	5244	196	37F
0005435372899	5244	197	37J
0005434823962	5244	198	38A
0005434558304	5244	199	38H
0005435373043	5244	200	38J
0005435150081	5244	201	39A
0005434823974	5244	202	39C
0005435299721	5244	203	39G
0005435372768	5244	204	39F
0005435735099	5244	205	39E
0005434823946	5244	206	39J
0005434823964	5244	207	39H
0005434823923	5244	208	39K
0005434824018	5244	209	40A
0005432121380	5244	210	40F
0005435372989	5244	211	40D
0005434824016	5244	212	40H
0005435386521	5244	213	40G
0005435372565	5244	214	41B
0005434823988	5244	215	41A
0005435372695	5244	216	40K
0005434824037	5244	217	41D
0005434824034	5244	218	41E
0005434823975	5244	219	41H
0005435372727	5244	220	42A
0005434823961	5244	221	41K
0005435386506	5244	222	42B
0005435735086	5244	223	42H
0005435386519	5244	224	42F
0005434824028	5244	225	42J
0005434824000	5244	226	42K
0005434823976	5244	227	43C
0005434823972	5244	228	43F
0005435372795	5244	229	43G
0005434824004	5244	230	43K
0005434558306	5244	231	43J
0005432121383	5244	232	44A
0005432396255	5244	233	44E
0005435372703	5244	234	44H
0005434823978	5244	235	45A
0005435372796	5244	236	44K
0005435372835	5244	237	45D
0005434824033	5244	238	45C
0005435372865	5244	239	45F
0005435373116	5244	240	45E
0005432121384	5244	241	45H
0005434824036	5244	242	45G
0005434823929	5244	243	46C
0005435372939	5244	244	46B
0005434824011	5244	245	46E
0005434823916	5244	246	46D
0005432396256	5244	247	46G
0005435372642	5244	248	46F
0005435372654	5244	249	46J
0005434823989	5244	250	46H
0005434823940	5244	251	47C
0005434823944	5244	252	47A
0005434823928	5244	253	46K
0005435372553	5244	254	47E
0005434823934	5244	255	47D
0005435372985	5244	256	47F
0005435372866	5244	257	47H
0005434823951	5244	258	48C
0005435386507	5244	259	48E
0005434831160	5244	260	48D
0005434823963	5244	261	48H
0005435372957	5244	262	48F
0005435373083	5244	263	49C
0005434823954	5244	264	49A
0005434823956	5244	265	49E
0005432394118	5244	266	49G
0005434823953	5244	267	49K
0005435372728	5244	268	49H
0005434823926	5244	269	50C
0005434823960	5244	270	50A
0005435372897	5244	271	50F
0005434823983	5244	272	50D
0005432396257	5244	273	50G
0005432121373	5244	274	50K
0005434823919	5244	275	50H
0005434823912	5244	276	51E
0005435373477	9890	1	1D
0005435373452	9890	2	1A
0005434823482	9890	3	1H
0005434822451	9890	4	1G
0005434822879	9890	5	1K
0005434822897	9890	6	2A
0005432396223	9890	7	2H
0005434558225	9890	8	2D
0005434823009	9890	9	3D
0005435373480	9890	10	3C
0005435302212	9890	11	3H
0005434823078	9890	12	4C
0005435150001	9890	13	4A
0005434823244	9890	14	4G
0005435373473	9890	15	4D
0005435373483	9890	16	4H
0005432203088	9890	17	5C
0005434822962	9890	18	5A
0005432400086	9890	19	5H
0005435149953	9890	20	11A
0005434823405	9890	21	11D
0005435373442	9890	22	11C
0005435373487	9890	23	11G
0005434822311	9890	24	11F
0005434823139	9890	25	11E
0005432823456	9890	26	11K
0005434831119	9890	27	11H
0005434823079	9890	28	12A
0005434823120	9890	29	12D
0005434822918	9890	30	12G
0005434823253	9890	31	12F
0005432396232	9890	32	12K
0005434822787	9890	33	12H
0005435373432	9890	34	13D
0005434822659	9890	35	14A
0005434822922	9890	36	14C
0005435373458	9890	37	14G
0005435386589	9890	38	14K
0005434822983	9890	39	14H
0005432400115	9890	40	15C
0005434823136	9890	41	15A
0005434823064	9890	42	15E
0005435373440	9890	43	15H
0005435386587	9890	44	15K
0005435299791	9890	45	16D
0005435373431	9890	46	16A
0005435299789	9890	47	16G
0005435150000	9890	48	16E
0005435373461	9890	49	16K
0005435373491	9890	50	17A
0005434822335	9890	51	17E
0005435373436	9890	52	17D
0005434822419	9890	53	17G
0005434828681	9890	54	17F
0005434664951	9890	55	18C
0005434823190	9890	56	18B
0005432203087	9890	57	18E
0005434822739	9890	58	18F
0005435373446	9890	59	18J
0005434823630	9890	60	18H
0005432400096	9890	61	19A
0005434822414	9890	62	19B
0005434823221	9890	63	19F
0005432203084	9890	64	19G
0005434558220	9890	65	20A
0005434823144	9890	66	19K
0005435373468	9890	67	20B
0005434823187	9890	68	20G
0005434664938	9890	69	20K
0005434823032	9890	70	20J
0005432203085	9890	71	20H
0005434823236	9890	72	21B
0005434822789	9890	73	21A
0005434823062	9890	74	21C
0005434823145	9890	75	21G
0005435302214	9890	76	21F
0005434831118	9890	77	22A
0005435149912	9890	78	21K
0005434822688	9890	79	21J
0005434823110	9890	80	22C
0005435373478	9890	81	22B
0005434822881	9890	82	22E
0005435373430	9890	83	22D
0005434823065	9890	84	22G
0005434822651	9890	85	22F
0005435373481	9890	86	22J
0005435149954	9890	87	22H
0005434822801	9890	88	23B
0005434822433	9890	89	23A
0005434823348	9890	90	23D
0005435373463	9890	91	23C
0005435386593	9890	92	23F
0005434822336	9890	93	23E
0005434822534	9890	94	23K
0005434831120	9890	95	23J
0005435373474	9890	96	24F
0005434823029	9890	97	25A
0005434822652	9890	98	25D
0005435373482	9890	99	25C
0005434822163	9890	100	25F
0005434822730	9890	101	25E
0005434831086	9890	102	25G
0005432396215	9890	103	25K
0005434822720	9890	104	26C
0005435299792	9890	105	26F
0005434823358	9890	106	26H
0005435373447	9890	107	27A
0005434822661	9890	108	26K
0005435149913	9890	109	27B
0005434823107	9890	110	27E
0005434822974	9890	111	27J
0005434823629	9890	112	27H
0005434822993	9890	113	27G
0005435373464	9890	114	27K
0005435386591	9890	115	28C
0005434822788	9890	116	28E
0005434822875	9890	117	28D
0005434822500	9890	118	28H
0005435373443	9890	119	28F
0005435373445	9890	120	28J
0005435373455	9890	121	29B
0005434823135	9890	122	29C
0005434822418	9890	123	29F
0005435373465	9890	124	29J
0005435373476	9890	125	29H
0005434822917	9890	126	29G
0005435373484	9890	127	30A
0005435735150	9890	128	29K
0005434558219	9890	129	30B
0005434822719	9890	130	30C
0005435373439	9890	131	30H
0005434822802	9890	132	31A
0005434823275	9890	133	30K
0005434823220	9890	134	31D
0005435373441	9890	135	31C
0005434822533	9890	136	31E
0005434831126	9890	137	31G
0005435661940	9890	138	31K
0005432203083	9890	139	31J
0005432203082	9890	140	32C
0005435373449	9890	141	32B
0005435149942	9890	142	32A
0005434823157	9890	143	32D
0005434822796	9890	144	32G
0005434823347	9890	145	32F
0005434823243	9890	146	33A
0005435373490	9890	147	32K
0005435735149	9890	148	33C
0005434823158	9890	149	33B
0005434822417	9890	150	33F
0005434823237	9890	151	33E
0005435661939	9890	152	33H
0005435373444	9890	153	33G
0005434822975	9890	154	34C
0005435373485	9890	155	34A
0005435302215	9890	156	34E
0005435373459	9890	157	34D
0005434822831	9890	158	34G
0005435373428	9890	159	34H
0005434664937	9890	160	35B
0005435373470	9890	161	35A
0005434822855	9890	162	35C
0005434823004	9890	163	35G
0005434822784	9890	164	35F
0005434823091	9890	165	35E
0005434822549	9890	166	35J
0005434822771	9890	167	35K
0005435373467	9890	168	36C
0005434823245	9890	169	36D
0005435735151	9890	170	36H
0005435386590	9890	171	36F
0005432203086	9890	172	36K
0005435373454	9890	173	37A
0005434828680	9890	174	37D
0005434822415	9890	175	37C
0005435373434	9890	176	37E
0005434823021	9890	177	38A
0005434822851	9890	178	37J
0005434558222	9890	179	38C
0005435373475	9890	180	38J
0005434822236	9890	181	38K
0005435149926	9890	182	39D
0005434823020	9890	183	39C
0005435373450	9890	184	39B
0005435661941	9890	185	39F
0005435373438	9890	186	39E
0005434823003	9890	187	39H
0005435373469	9890	188	40A
0005435373433	9890	189	39J
0005434831087	9890	190	40B
0005434823068	9890	191	40E
0005434822978	9890	192	40D
0005434822738	9890	193	40H
0005435373456	9890	194	40G
0005435299790	9890	195	40F
0005434831117	9890	196	40K
0005435386592	9890	197	41C
0005435373466	9890	198	41G
0005434823442	9890	199	41F
0005434823106	9890	200	41E
0005435373460	9890	201	41J
0005434823109	9890	202	42A
0005434823019	9890	203	41K
0005432400104	9890	204	42C
0005434823261	9890	205	42B
0005435302211	9890	206	42D
0005434831112	9890	207	42H
0005435373488	9890	208	42G
0005435373435	9890	209	42F
0005435386588	9890	210	42J
0005434822961	9890	211	43A
0005434823574	9890	212	43C
0005435373492	9890	213	43F
0005434822994	9890	214	43E
0005435373448	9890	215	43H
0005435386594	9890	216	43G
0005434822794	9890	217	44C
0005434823184	9890	218	44D
0005435373489	9890	219	44K
0005435373457	9890	220	44J
0005435373462	9890	221	44H
0005434822963	9890	222	45A
0005435735148	9890	223	45D
0005435373493	9890	224	45C
0005435373479	9890	225	45B
0005435373486	9890	226	45G
0005434828679	9890	227	45F
0005432823457	9890	228	45E
0005434822895	9890	229	45H
0005434822880	9890	230	45J
0005434823406	9890	231	46C
0005434822633	9890	232	46B
0005435149951	9890	233	46A
0005435373494	9890	234	46E
0005434822532	9890	235	46D
0005435373451	9890	236	46G
0005434822956	9890	237	46F
0005434558221	9890	238	47A
0005435373437	9890	239	47F
0005434822829	9890	240	47E
0005435149928	9890	241	47K
0005435299788	9890	242	47H
0005434822800	9890	243	48A
0005435373429	9890	244	48F
0005434823063	9890	245	48E
0005432396196	9890	246	48D
0005434822977	9890	247	48H
0005434823080	9890	248	48G
0005435373453	9890	249	49A
0005434822392	9890	250	49E
0005435302210	9890	251	49D
0005435302213	9890	252	49F
0005434822976	9890	253	49K
0005434822920	9890	254	49H
0005435373471	9890	255	50A
0005434822744	9890	256	50F
0005434822660	9890	257	50E
0005434823092	9890	258	50D
0005434823081	9890	259	50G
0005434558226	9890	260	51D
0005435735152	9890	261	50K
0005435373472	9890	262	50H
0005434823010	9890	263	51F
0005434822728	9890	264	51E
0005434822457	9890	265	51G
0005435082810	6997	1	1D
0005435790316	6997	2	3A
0005435082804	6997	3	4A
0005435082811	6997	4	6A
0005435082809	6997	5	18A
0005435082808	6997	6	18D
0005435082806	6997	7	19B
0005435790315	6997	8	20A
0005435082812	6997	9	20D
0005435082805	6997	10	21A
0005435790317	6997	11	22B
0005435082807	6997	12	22C
0005435082758	26002	1	1B
0005435790308	26002	2	2A
0005435790293	26002	3	3B
0005435082730	26002	4	3C
0005435082734	26002	5	3D
0005435082731	26002	6	4B
0005435790299	26002	7	5B
0005435790300	26002	8	5D
0005435790309	26002	9	6C
0005435790310	26002	10	18B
0005435082735	26002	11	19A
0005435790292	26002	12	19C
0005435082756	26002	13	21B
0005435790296	26002	14	21D
0005435082757	26002	15	22C
0005434214183	9558	1	1A
0005434756564	9558	2	1C
0005434214201	9558	3	1D
0005434756541	9558	4	1F
0005434214165	9558	5	2A
0005434214174	9558	6	2C
0005434756563	9558	7	2D
0005434756516	9558	8	2F
0005434756535	9558	9	3A
0005434756537	9558	10	3F
0005434214360	9558	11	4A
0005434214140	9558	12	4C
0005434756547	9558	13	4D
0005434756540	9558	14	4F
0005434756549	9558	15	5A
0005434756527	9558	16	5C
0005434756554	9558	17	5D
0005434756558	9558	18	5E
0005434756560	9558	19	5F
0005434756524	9558	20	6A
0005434756526	9558	21	6C
0005434214176	9558	22	6D
0005434756528	9558	23	6E
0005434756538	9558	24	6F
0005434756559	9558	25	7A
0005434214128	9558	26	7C
0005434756566	9558	27	7D
0005434214255	9558	28	7E
0005434214249	9558	29	8A
0005434214111	9558	30	8C
0005434756517	9558	31	8D
0005434756550	9558	32	8E
0005434756525	9558	33	9A
0005434756557	9558	34	9C
0005434214325	9558	35	9D
0005434214300	9558	36	9E
0005434756565	9558	37	9F
0005434214217	9558	38	10A
0005434756539	9558	39	10C
0005434214330	9558	40	10D
0005434214216	9558	41	10E
0005434756546	9558	42	10F
0005434756545	9558	43	11A
0005434214212	9558	44	11C
0005434756522	9558	45	11D
0005434756515	9558	46	11F
0005434214127	9558	47	12A
0005434214143	9558	48	12D
0005434756543	9558	49	12E
0005434756523	9558	50	12F
0005434214230	9558	51	13A
0005434756552	9558	52	13C
0005434756531	9558	53	13D
0005434214285	9558	54	13E
0005434214061	9558	55	13F
0005434756556	9558	56	14A
0005434756561	9558	57	14C
0005434214164	9558	58	14E
0005434756520	9558	59	14F
0005434756532	9558	60	15A
0005434756533	9558	61	15C
0005434756562	9558	62	15D
0005434214286	9558	63	15E
0005434214177	9558	64	15F
0005434756555	9558	65	16A
0005434214129	9558	66	16C
0005434214278	9558	67	16D
0005434756544	9558	68	16E
0005434756536	9558	69	16F
0005434214246	9558	70	17C
0005434756542	9558	71	17D
0005434756521	9558	72	17E
0005434756553	9558	73	17F
0005434756551	9558	74	18C
0005434214141	9558	75	18D
0005434214112	9558	76	18F
0005434214107	9558	77	19A
0005434756548	9558	78	19C
0005434756534	9558	79	19D
0005434214329	9558	80	19E
0005434214211	9558	81	19F
0005434756530	9558	82	20A
0005434756518	9558	83	20C
0005434756519	9558	84	20D
0005434214138	9558	85	20E
0005434756529	9558	86	20F
0005434214622	28636	1	1A
0005434756041	28636	2	1C
0005434755985	28636	3	1D
0005434214647	28636	4	1F
0005434214617	28636	5	2A
0005434214625	28636	6	2C
0005434214634	28636	7	2D
0005434756237	28636	8	2F
0005434756120	28636	9	3A
0005434214607	28636	10	3C
0005434756121	28636	11	3D
0005434214623	28636	12	4A
0005434214615	28636	13	4C
0005434214636	28636	14	4D
0005434214609	28636	15	4E
0005434755927	28636	16	4F
0005434756197	28636	17	5A
0005434214618	28636	18	5C
0005434756044	28636	19	5E
0005434214630	28636	20	5F
0005434214614	28636	21	6A
0005434214606	28636	22	6C
0005434756046	28636	23	6D
0005434756153	28636	24	6E
0005434756193	28636	25	6F
0005434756115	28636	26	7A
0005434756033	28636	27	7C
0005434756157	28636	28	7D
0005434756229	28636	29	7E
0005434756045	28636	30	7F
0005434214632	28636	31	8C
0005434214610	28636	32	8D
0005434756133	28636	33	8E
0005434214643	28636	34	8F
0005434214646	28636	35	9A
0005434756135	28636	36	9C
0005434214626	28636	37	9D
0005434756122	28636	38	9E
0005434214608	28636	39	9F
0005434214613	28636	40	10A
0005434214602	28636	41	10C
0005434756230	28636	42	10E
0005434756262	28636	43	11A
0005434214640	28636	44	11C
0005434756002	28636	45	11D
0005434755908	28636	46	11E
0005434214633	28636	47	11F
0005434214635	28636	48	12A
0005434214631	28636	49	12D
0005434756105	28636	50	12E
0005434756238	28636	51	12F
0005434214649	28636	52	13A
0005434756014	28636	53	13C
0005434214604	28636	54	13D
0005434214648	28636	55	13E
0005434214638	28636	56	13F
0005434214627	28636	57	14A
0005434756178	28636	58	14C
0005434755928	28636	59	14D
0005434756089	28636	60	14E
0005434756022	28636	61	14F
0005434756108	28636	62	15A
0005434756071	28636	63	15C
0005434214624	28636	64	15D
0005434214621	28636	65	15E
0005434756011	28636	66	16A
0005434214642	28636	67	16C
0005434214620	28636	68	16D
0005434214611	28636	69	16E
0005434756037	28636	70	16F
0005434214637	28636	71	17A
0005434214619	28636	72	17C
0005434214616	28636	73	17D
0005434214644	28636	74	17E
0005434756228	28636	75	17F
0005434214629	28636	76	18A
0005434214605	28636	77	18C
0005434756113	28636	78	18D
0005434214639	28636	79	18E
0005434214628	28636	80	18F
0005434214603	28636	81	19A
0005434756180	28636	82	19C
0005434214612	28636	83	19D
0005434755907	28636	84	19E
0005434214645	28636	85	19F
0005434756181	28636	86	20A
0005434756085	28636	87	20C
0005434214641	28636	88	20E
0005434760184	10857	1	2D
0005435100133	10857	2	5C
0005434760173	10857	3	18B
0005435100132	10857	4	20D
0005435100131	10857	5	22A
0005435100107	31814	1	4C
0005434760205	31814	2	4D
0005435100106	31814	3	7B
0005435100111	31814	4	19B
0005435100108	31814	5	19C
0005434760204	31814	6	22C
0005435100109	31814	7	23B
0005434639399	1991	1	1A
0005434639417	1991	2	1B
0005434639408	1991	3	1C
0005434639398	1991	4	1D
0005434639397	1991	5	2A
0005433202302	1991	6	2B
0005434639419	1991	7	2C
0005434639400	1991	8	2D
0005434639415	1991	9	3A
0005434639403	1991	10	3B
0005433202210	1991	11	3C
0005434639405	1991	12	3D
0005434639409	1991	13	4A
0005433202223	1991	14	4C
0005434639421	1991	15	4D
0005434639411	1991	16	5A
0005434639402	1991	17	5B
0005433202248	1991	18	5C
0005433202281	1991	19	5D
0005434639401	1991	20	6A
0005433202276	1991	21	6C
0005434639394	1991	22	6D
0005434639418	1991	23	7B
0005433202277	1991	24	7D
0005432290644	1991	25	18A
0005433202225	1991	26	18B
0005433202285	1991	27	18C
0005434639416	1991	28	18D
0005434639406	1991	29	19A
0005434639410	1991	30	19B
0005434639404	1991	31	19C
0005433202290	1991	32	19D
0005433202245	1991	33	20A
0005433202299	1991	34	20C
0005434639407	1991	35	20D
0005434639395	1991	36	21C
0005434639412	1991	37	21D
0005434639396	1991	38	22A
0005434639414	1991	39	22B
0005434639413	1991	40	22C
0005432290643	1991	41	23A
0005434639420	1991	42	23B
0005433202396	23294	1	1A
0005434639177	23294	2	1B
0005434639018	23294	3	1C
0005433202391	23294	4	1D
0005434639240	23294	5	2A
0005434639125	23294	6	2B
0005433202400	23294	7	2C
0005434639143	23294	8	2D
0005434639138	23294	9	3A
0005433202389	23294	10	3B
0005434639198	23294	11	3C
0005434639244	23294	12	4A
0005433202398	23294	13	3D
0005433202395	23294	14	4B
0005434639069	23294	15	4C
0005433202401	23294	16	4D
0005434639092	23294	17	5A
0005434639203	23294	18	5B
0005434639178	23294	19	5C
0005434639137	23294	20	5D
0005434639239	23294	21	6A
0005434639127	23294	22	6B
0005434639200	23294	23	6C
0005434639111	23294	24	6D
0005434639243	23294	25	7A
0005434639199	23294	26	7B
0005434639136	23294	27	7C
0005434639103	23294	28	7D
0005434639145	23294	29	18A
0005434639202	23294	30	18C
0005434639081	23294	31	18B
0005434639128	23294	32	18D
0005433202397	23294	33	19A
0005434639071	23294	34	19B
0005433202402	23294	35	19C
0005434639172	23294	36	20A
0005434639201	23294	37	20B
0005433202394	23294	38	20C
0005434639162	23294	39	20D
0005434639083	23294	40	21A
0005434639144	23294	41	21B
0005433202399	23294	42	21C
0005434639173	23294	43	21D
0005433202392	23294	44	22A
0005433202390	23294	45	22B
0005434639068	23294	46	22C
0005434639110	23294	47	22D
0005433202393	23294	48	23A
0005434639102	23294	49	23B
0005435326630	6077	1	1C
0005435326682	6077	2	1D
0005434600879	6077	3	1F
0005434600897	6077	4	2A
0005433533318	6077	5	2C
0005435326621	6077	6	2F
0005434600881	6077	7	3A
0005434600899	6077	8	3F
0005433531305	6077	9	4C
0005434600878	6077	10	4D
0005432111288	6077	11	4E
0005433533319	6077	12	5A
0005432111287	6077	13	5D
0005434600885	6077	14	5E
0005434600905	6077	15	6A
0005434600896	6077	16	6D
0005434600880	6077	17	6E
0005434600895	6077	18	6F
0005435326738	6077	19	7A
0005434600900	6077	20	7F
0005434600904	6077	21	8E
0005435326631	6077	22	9C
0005435326665	6077	23	9E
0005434600882	6077	24	9F
0005434600890	6077	25	10A
0005433533322	6077	26	10E
0005434600902	6077	27	10F
0005435326633	6077	28	11A
0005434600892	6077	29	11C
0005434600893	6077	30	11E
0005434600888	6077	31	12A
0005434600886	6077	32	12E
0005435326697	6077	33	13A
0005434600894	6077	34	13C
0005435326632	6077	35	13E
0005434600884	6077	36	14E
0005433531306	6077	37	14F
0005434600903	6077	38	15A
0005435326696	6077	39	15C
0005434600891	6077	40	16A
0005433533320	6077	41	16D
0005434600883	6077	42	16F
0005435326620	6077	43	17A
0005434600898	6077	44	17C
0005433533321	6077	45	17D
0005433531304	6077	46	18C
0005434600889	6077	47	18D
0005434600901	6077	48	18E
0005435326663	6077	49	19A
0005435326660	6077	50	19D
0005434600887	6077	51	20C
0005434600906	6077	52	20D
0005433527220	18570	1	1D
0005434600547	18570	2	1F
0005434600611	18570	3	3A
0005434600586	18570	4	3C
0005435326794	18570	5	3D
0005433531272	18570	6	3F
0005434600664	18570	7	5C
0005434600731	18570	8	5D
0005434600551	18570	9	6C
0005435326781	18570	10	6E
0005434600744	18570	11	6F
0005434600702	18570	12	7A
0005435326792	18570	13	7C
0005433531260	18570	14	7D
0005435326784	18570	15	10A
0005433527226	18570	16	10C
0005434600701	18570	17	11C
0005433531259	18570	18	12A
0005435326790	18570	19	12D
0005435326793	18570	20	12E
0005435326783	18570	21	13C
0005435326782	18570	22	13E
0005433531267	18570	23	13F
0005433527214	18570	24	14D
0005433531268	18570	25	14E
0005434600546	18570	26	14F
0005434600722	18570	27	15A
0005435326791	18570	28	15C
0005434600603	18570	29	15D
0005435326787	18570	30	15E
0005435326789	18570	31	16A
0005435326788	18570	32	16C
0005435326785	18570	33	16E
0005433531265	18570	34	17C
0005433531258	18570	35	17D
0005433531271	18570	36	17F
0005434600641	18570	37	18A
0005435326786	18570	38	18C
0005434600688	18570	39	18F
0005434600656	18570	40	19D
0005434600755	18570	41	19E
0005434558291	10567	1	1A
0005434558296	10567	2	1D
0005434551350	10567	3	1F
0005434551378	10567	4	2A
0005434558302	10567	5	2C
0005434551371	10567	6	2D
0005434551346	10567	7	2F
0005434551355	10567	8	3A
0005434554070	10567	9	3C
0005434551344	10567	10	3D
0005434551334	10567	11	3F
0005434551337	10567	12	4A
0005434551343	10567	13	4C
0005434551333	10567	14	4D
0005434558290	10567	15	4E
0005434551358	10567	16	4F
0005433180970	10567	17	5A
0005433180971	10567	18	5C
0005434551361	10567	19	5D
0005434554072	10567	20	5E
0005434551359	10567	21	5F
0005433180810	10567	22	6A
0005434551362	10567	23	6C
0005434558299	10567	24	6D
0005434551380	10567	25	6E
0005434551349	10567	26	7C
0005434551368	10567	27	7D
0005433180878	10567	28	7E
0005434551369	10567	29	7F
0005433180995	10567	30	8A
0005434558294	10567	31	8C
0005434551331	10567	32	8D
0005433180938	10567	33	8E
0005433180972	10567	34	8F
0005434558300	10567	35	9A
0005434551329	10567	36	9C
0005434551341	10567	37	9D
0005434558297	10567	38	9E
0005434551342	10567	39	9F
0005434551326	10567	40	10A
0005434551376	10567	41	10C
0005433180859	10567	42	10D
0005434551347	10567	43	10E
0005434558301	10567	44	10F
0005433180927	10567	45	11C
0005434551365	10567	46	11A
0005434554071	10567	47	11D
0005434551330	10567	48	11E
0005434551327	10567	49	11F
0005433180907	10567	50	12A
0005434551375	10567	51	12C
0005434551336	10567	52	12D
0005434551332	10567	53	12E
0005434551354	10567	54	12F
0005434558298	10567	55	13A
0005434551366	10567	56	13C
0005433180996	10567	57	13D
0005434551353	10567	58	13E
0005434558295	10567	59	13F
0005434551363	10567	60	14A
0005434551335	10567	61	14C
0005434551345	10567	62	14D
0005434554073	10567	63	14E
0005434551352	10567	64	14F
0005433180986	10567	65	15A
0005434558293	10567	66	15C
0005434551364	10567	67	15D
0005433180891	10567	68	15E
0005433180950	10567	69	15F
0005434551367	10567	70	16A
0005434551374	10567	71	16C
0005434558289	10567	72	16D
0005433180916	10567	73	16E
0005434551339	10567	74	16F
0005434551340	10567	75	17A
0005434551324	10567	76	17C
0005433180906	10567	77	17D
0005434551338	10567	78	17E
0005433180905	10567	79	17F
0005434551379	10567	80	18A
0005434551351	10567	81	18C
0005433180908	10567	82	18D
0005434551357	10567	83	18E
0005434551325	10567	84	18F
0005434551328	10567	85	19A
0005434558292	10567	86	19C
0005434551370	10567	87	19D
0005434551348	10567	88	19E
0005434551377	10567	89	19F
0005434551360	10567	90	20A
0005434551372	10567	91	20C
0005434551356	10567	92	20D
0005434551373	10567	93	20E
0005433180933	10567	94	20F
0005433181173	27723	1	1F
0005433181185	27723	2	2A
0005433181179	27723	3	2C
0005433181167	27723	4	3F
0005433181183	27723	5	4F
0005433181186	27723	6	5D
0005433181188	27723	7	6D
0005433181175	27723	8	6E
0005433181166	27723	9	6F
0005433181187	27723	10	8E
0005433181189	27723	11	9C
0005433181172	27723	12	9F
0005433181178	27723	13	10C
0005433181171	27723	14	10E
0005433181170	27723	15	14A
0005433181168	27723	16	14C
0005433181165	27723	17	14F
0005433181182	27723	18	15C
0005433181184	27723	19	15D
0005433181177	27723	20	15F
0005433181181	27723	21	16D
0005433181176	27723	22	16E
0005433181174	27723	23	16F
0005433181169	27723	24	17E
0005433181190	27723	25	19A
0005433181180	27723	26	19D
0005434558223	27722	1	1A
0005434551013	27722	2	1D
0005434551201	27722	3	1F
0005434550629	27722	4	2C
0005434550975	27722	5	2D
0005434551050	27722	6	2F
0005434550908	27722	7	3A
0005434550989	27722	8	3C
0005434550995	27722	9	3D
0005434550843	27722	10	3F
0005434550954	27722	11	4C
0005434550924	27722	12	4D
0005434550658	27722	13	4F
0005434550849	27722	14	5C
0005434550712	27722	15	5D
0005434550909	27722	16	5F
0005434550842	27722	17	6A
0005434550630	27722	18	6C
0005434551086	27722	19	6E
0005434551108	27722	20	6F
0005434550985	27722	21	7A
0005434550772	27722	22	7C
0005434550910	27722	23	7E
0005434550934	27722	24	7F
0005434550914	27722	25	8C
0005434551025	27722	26	8E
0005434551032	27722	27	8F
0005434551109	27722	28	9A
0005434550929	27722	29	9C
0005434550848	27722	30	9D
0005434550986	27722	31	9E
0005434550990	27722	32	9F
0005434550713	27722	33	10D
0005434550888	27722	34	10C
0005434551092	27722	35	10E
0005434550972	27722	36	10F
0005434550977	27722	37	11A
0005434558224	27722	38	11D
0005434558205	27722	39	11E
0005434551122	27722	40	11F
0005434550978	27722	41	12A
0005434551091	27722	42	12C
0005434558198	27722	43	12D
0005434558214	27722	44	12E
0005434551114	27722	45	13C
0005434550922	27722	46	13D
0005434550880	27722	47	13E
0005434550974	27722	48	13F
0005434550955	27722	49	14A
0005434554060	27722	50	14C
0005434551085	27722	51	14E
0005434550923	27722	52	14F
0005434551034	27722	53	15C
0005434551033	27722	54	15D
0005434550962	27722	55	15E
0005434550921	27722	56	15F
0005434550813	27722	57	16C
0005434550984	27722	58	16D
0005434550928	27722	59	16F
0005434550560	27722	60	17D
0005434558215	27722	61	17E
0005434551012	27722	62	17F
0005434551115	27722	63	18A
0005434551019	27722	64	18C
0005434551123	27722	65	18D
0005434550991	27722	66	18F
0005434550939	27722	67	19C
0005434550920	27722	68	19D
0005434550992	27722	69	19E
0005434554059	27722	70	19F
0005434551052	27722	71	20A
0005434551093	27722	72	20C
0005434550971	27722	73	20D
0005434550618	27722	74	20E
0005433459233	6172	1	1B
0005435254455	6172	2	2A
0005435254452	6172	3	2B
0005435254451	6172	4	3B
0005433459232	6172	5	4A
0005433459230	6172	6	4B
0005435254470	6172	7	5A
0005433459231	6172	8	6A
0005435254469	6172	9	6B
0005435254483	19302	1	5A
0005433459200	19302	2	5B
0005432533276	6751	1	1A
0005435682244	6751	2	1C
0005432136185	6751	3	1D
0005435437761	6751	4	1F
0005432136183	6751	5	2A
0005435221509	6751	6	2C
0005435682276	6751	7	2D
0005435437818	6751	8	2F
0005435682251	6751	9	3A
0005435682257	6751	10	3C
0005435682281	6751	11	3D
0005435682264	6751	12	3F
0005435437802	6751	13	4A
0005432136184	6751	14	4C
0005435221507	6751	15	4D
0005435682262	6751	16	4E
0005435682267	6751	17	4F
0005435437829	6751	18	5A
0005435220318	6751	19	5C
0005435437825	6751	20	5D
0005435682250	6751	21	5E
0005435682269	6751	22	5F
0005435437855	6751	23	6A
0005432136182	6751	24	6C
0005432136186	6751	25	6D
0005435437817	6751	26	6E
0005435682258	6751	27	6F
0005435437838	6751	28	7A
0005435221508	6751	29	7C
0005435682247	6751	30	7D
0005435437826	6751	31	7E
0005435437845	6751	32	7F
0005435682259	6751	33	8A
0005432533272	6751	34	8C
0005435682275	6751	35	8D
0005432136181	6751	36	8E
0005435220296	6751	37	8F
0005434828667	6751	38	9A
0005435437807	6751	39	9C
0005435682243	6751	40	9D
0005435682266	6751	41	9E
0005435682285	6751	42	9F
0005435682253	6751	43	10A
0005435682280	6751	44	10C
0005435437937	6751	45	10D
0005435220303	6751	46	10E
0005435437748	6751	47	10F
0005435437905	6751	48	11A
0005435437839	6751	49	11C
0005435682245	6751	50	11D
0005435682274	6751	51	11E
0005435682252	6751	52	11F
0005435682279	6751	53	12A
0005435682282	6751	54	12C
0005435682249	6751	55	12D
0005435682272	6751	56	12E
0005435661937	6751	57	12F
0005435630973	6751	58	13A
0005435437870	6751	59	13C
0005435682270	6751	60	13D
0005435437758	6751	61	13E
0005435661938	6751	62	13F
0005435682246	6751	63	14A
0005435630972	6751	64	14C
0005435682263	6751	65	14D
0005435682242	6751	66	14E
0005435437801	6751	67	14F
0005435437828	6751	68	15C
0005435217705	6751	69	15D
0005435661936	6751	70	15E
0005435630974	6751	71	15F
0005435437862	6751	72	16A
0005435682268	6751	73	16C
0005435437883	6751	74	16D
0005435682254	6751	75	16E
0005435682278	6751	76	16F
0005435682248	6751	77	17A
0005435682255	6751	78	17C
0005435682283	6751	79	17D
0005435437803	6751	80	17E
0005435682284	6751	81	17F
0005435437834	6751	82	18A
0005435682277	6751	83	18C
0005435437882	6751	84	18D
0005435437757	6751	85	18E
0005435437860	6751	86	18F
0005435437878	6751	87	19A
0005435437844	6751	88	19C
0005435682261	6751	89	19D
0005435682271	6751	90	19E
0005435437854	6751	91	19F
0005435682265	6751	92	20A
0005435682256	6751	93	20C
0005435682273	6751	94	20D
0005435437827	6751	95	20E
0005435682260	6751	96	20F
0005435681724	24565	1	1A
0005435681837	24565	2	1C
0005435720817	24565	3	1D
0005435681619	24565	4	1F
0005435438018	24565	5	2C
0005435719558	24565	6	2D
0005435681772	24565	7	2F
0005435681941	24565	8	3A
0005435681800	24565	9	3C
0005435681972	24565	10	3D
0005435438027	24565	11	3F
0005435681993	24565	12	4A
0005435438028	24565	13	4C
0005435719559	24565	14	4D
0005435681771	24565	15	4E
0005435681866	24565	16	5A
0005435681928	24565	17	5C
0005435682027	24565	18	5D
0005435681920	24565	19	5E
0005435438015	24565	20	5F
0005435681965	24565	21	6A
0005435681885	24565	22	6C
0005435681825	24565	23	6D
0005435438019	24565	24	6E
0005435681805	24565	25	7A
0005435438012	24565	26	7C
0005434828707	24565	27	7D
0005432533302	24565	28	7E
0005435438021	24565	29	7F
0005435438020	24565	30	8A
0005435438016	24565	31	8C
0005435438008	24565	32	8D
0005435682099	24565	33	8E
0005435719560	24565	34	9A
0005435681725	24565	35	9C
0005435681873	24565	36	9D
0005435438009	24565	37	9E
0005435661907	24565	38	9F
0005435681926	24565	39	10A
0005435681831	24565	40	10C
0005435681770	24565	41	10D
0005435681733	24565	42	10E
0005435438011	24565	43	10F
0005435438025	24565	44	11A
0005435681620	24565	45	11C
0005435438006	24565	46	11D
0005435682008	24565	47	11E
0005432305756	24565	48	11F
0005435630949	24565	49	12C
0005435630950	24565	50	12D
0005435681973	24565	51	12E
0005435682115	24565	52	12F
0005432533299	24565	53	13A
0005435681838	24565	54	13D
0005434828706	24565	55	13E
0005435438017	24565	56	13F
0005435681900	24565	57	14C
0005435681832	24565	58	14D
0005435681999	24565	59	14E
0005435681750	24565	60	15C
0005435719564	24565	61	15D
0005432533301	24565	62	15E
0005435438007	24565	63	15F
0005435438022	24565	64	16A
0005435438026	24565	65	16C
0005435438013	24565	66	16D
0005435438024	24565	67	16E
0005435681801	24565	68	16F
0005435681737	24565	69	17A
0005435438023	24565	70	17D
0005435661917	24565	71	17E
0005435681736	24565	72	17F
0005435438010	24565	73	18A
0005435661921	24565	74	18C
0005434828705	24565	75	18D
0005435682055	24565	76	18E
0005435438014	24565	77	19C
0005435681962	24565	78	19D
0005435681910	24565	79	19E
0005435681925	24565	80	19F
0005432533300	24565	81	20A
0005435681929	24565	82	20F
0005435126474	11503	1	1A
0005435126464	11503	2	1C
0005435126479	11503	3	1F
0005435126449	11503	4	4C
0005435126452	11503	5	4D
0005435126438	11503	6	5D
0005435126459	11503	7	6E
0005435126463	11503	8	6F
0005435105988	11503	9	7C
0005435126458	11503	10	7D
0005435126439	11503	11	7F
0005435126442	11503	12	8A
0005435126471	11503	13	8E
0005435126440	11503	14	9A
0005435126456	11503	15	9C
0005435105990	11503	16	9E
0005435126465	11503	17	9F
0005435558077	11503	18	10A
0005435126468	11503	19	10D
0005435558076	11503	20	11A
0005435126472	11503	21	11C
0005435126477	11503	22	11D
0005435126457	11503	23	11E
0005435126443	11503	24	12F
0005435105989	11503	25	13A
0005435126445	11503	26	13D
0005435558071	11503	27	13E
0005435126447	11503	28	13F
0005435126460	11503	29	14A
0005435126441	11503	30	14F
0005435126478	11503	31	15A
0005435126453	11503	32	15C
0005435126461	11503	33	15D
0005435126466	11503	34	15E
0005435126450	11503	35	16A
0005435126448	11503	36	16C
0005435126467	11503	37	16D
0005435126475	11503	38	16E
0005435126446	11503	39	17A
0005435126454	11503	40	17D
0005435126451	11503	41	18A
0005435126469	11503	42	18D
0005435126480	11503	43	18E
0005435126476	11503	44	18F
0005435126470	11503	45	19C
0005435126455	11503	46	19D
0005435126444	11503	47	19E
0005435126473	11503	48	20A
0005435126462	11503	49	20C
0005435126117	31876	1	3F
0005435126221	31876	2	4C
0005435126238	31876	3	4D
0005435126143	31876	4	4F
0005435126025	31876	5	5D
0005435098541	31876	6	5F
0005435126200	31876	7	6A
0005435126011	31876	8	6C
0005435558096	31876	9	6D
0005435126155	31876	10	6E
0005435126141	31876	11	7D
0005435126094	31876	12	7E
0005435126144	31876	13	7F
0005435126046	31876	14	8C
0005435126108	31876	15	8D
0005435126056	31876	16	8E
0005435125940	31876	17	9A
0005435126114	31876	18	9C
0005435126084	31876	19	9D
0005435126106	31876	20	9E
0005435126095	31876	21	9F
0005435125956	31876	22	10A
0005435125955	31876	23	10D
0005435125971	31876	24	11C
0005435105952	31876	25	11D
0005435126133	31876	26	11E
0005435126291	31876	27	12A
0005435126047	31876	28	12E
0005435558094	31876	29	13C
0005435126201	31876	30	13D
0005435126088	31876	31	14A
0005435126136	31876	32	14C
0005435126026	31876	33	15A
0005435126220	31876	34	15C
0005435126062	31876	35	16A
0005435126010	31876	36	16E
0005435126154	31876	37	16F
0005435098556	31876	38	17C
0005435558095	31876	39	17E
0005435126209	31876	40	18A
0005435126063	31876	41	18C
0005435126113	31876	42	18D
0005435126252	31876	43	18E
0005435126264	31876	44	18F
0005435126135	31876	45	19C
0005435126140	31876	46	19D
0005435126126	31876	47	19E
0005435105951	31876	48	19F
0005435105955	31876	49	20C
0005435126107	31876	50	20D
0005435126093	31876	51	20F
0005433398183	13532	1	1C
0005433398194	13532	2	1D
0005433398186	13532	3	1F
0005433398199	13532	4	2C
0005433398221	13532	5	2D
0005433398197	13532	6	2F
0005433398216	13532	7	3C
0005435732275	13532	8	3D
0005433398212	13532	9	3F
0005433398184	13532	10	4A
0005433398191	13532	11	4C
0005433398202	13532	12	4D
0005435732218	13532	13	4E
0005433398180	13532	14	5A
0005433398219	13532	15	5E
0005433398205	13532	16	6A
0005433398190	13532	17	6C
0005435732289	13532	18	6D
0005433398209	13532	19	6F
0005433398178	13532	20	7A
0005433398195	13532	21	7C
0005433398215	13532	22	7D
0005433398198	13532	23	8C
0005433398210	13532	24	8D
0005433398179	13532	25	8E
0005433398200	13532	26	8F
0005435732261	13532	27	9D
0005435732233	13532	28	9E
0005433398206	13532	29	9F
0005433398188	13532	30	10C
0005435732274	13532	31	10E
0005433398223	13532	32	10F
0005433398211	13532	33	11C
0005433398201	13532	34	11D
0005433398187	13532	35	11F
0005433398217	13532	36	12C
0005433398218	13532	37	12D
0005435732249	13532	38	12F
0005433398220	13532	39	13E
0005433398182	13532	40	13F
0005435732252	13532	41	14C
0005433398177	13532	42	14D
0005433398181	13532	43	14E
0005433398204	13532	44	14F
0005433398207	13532	45	15C
0005433398222	13532	46	15F
0005433398193	13532	47	16A
0005433398174	13532	48	16C
0005433398203	13532	49	16E
0005435732280	13532	50	17A
0005433398196	13532	51	17D
0005433398208	13532	52	17F
0005433398175	13532	53	18C
0005433398213	13532	54	18D
0005433398192	13532	55	18E
0005435732262	13532	56	18F
0005433398189	13532	57	19C
0005433398176	13532	58	19D
0005433398214	13532	59	19E
0005433398185	13532	60	20E
0005433397870	19369	1	1D
0005433397768	19369	2	1F
0005433397706	19369	3	2A
0005433398027	19369	4	3C
0005432297287	19369	5	3F
0005433397529	19369	6	4A
0005433397705	19369	7	4C
0005435732364	19369	8	5C
0005435732361	19369	9	5D
0005433397704	19369	10	5E
0005433397903	19369	11	6C
0005433397868	19369	12	6D
0005433397716	19369	13	6E
0005433397772	19369	14	7A
0005433397681	19369	15	7D
0005433397765	19369	16	7E
0005432297284	19369	17	7F
0005432297286	19369	18	8A
0005433397849	19369	19	8C
0005433397586	19369	20	8D
0005433397883	19369	21	8E
0005433397754	19369	22	9A
0005433397869	19369	23	9C
0005433397699	19369	24	9D
0005433397610	19369	25	9E
0005433397547	19369	26	10A
0005433397773	19369	27	10C
0005433397727	19369	28	10E
0005435732365	19369	29	10F
0005433397845	19369	30	11C
0005433397650	19369	31	11D
0005433397804	19369	32	11E
0005432297288	19369	33	11F
0005433397638	19369	34	12A
0005433397879	19369	35	12C
0005433397653	19369	36	12E
0005433397840	19369	37	12F
0005433397967	19369	38	13A
0005435732363	19369	39	13C
0005435732362	19369	40	13F
0005433397993	19369	41	14A
0005433397731	19369	42	14C
0005433397767	19369	43	14D
0005433397683	19369	44	14E
0005433397757	19369	45	14F
0005433397715	19369	46	15C
0005433397764	19369	47	15F
0005433397651	19369	48	16E
0005432297285	19369	49	16F
0005433397707	19369	50	17A
0005433397877	19369	51	17D
0005433397918	19369	52	17E
0005433397771	19369	53	17F
0005433397906	19369	54	18C
0005433397701	19369	55	18D
0005433397654	19369	56	18E
0005433397703	19369	57	19A
0005433397848	19369	58	19C
0005433397656	19369	59	19D
0005433397920	19369	60	19E
0005433397937	19369	61	20A
0005433397756	19369	62	19F
0005433397700	19369	63	20C
0005433397728	19369	64	20E
0005435068698	13181	1	1A
0005435068729	13181	2	1D
0005435068750	13181	3	2A
0005435069034	13181	4	2C
0005435068724	13181	5	2D
0005435068780	13181	6	3A
0005435068927	13181	7	3D
0005435925329	13181	8	3F
0005435068735	13181	9	4C
0005435068613	13181	10	4D
0005435068728	13181	11	4F
0005435068836	13181	12	5C
0005435925336	13181	13	5D
0005435068587	13181	14	5F
0005435925328	13181	15	6A
0005435068612	13181	16	6D
0005435925335	13181	17	7A
0005435925340	13181	18	7D
0005435068751	13181	19	7E
0005435068465	13181	20	7F
0005435068782	13181	21	8A
0005435068769	13181	22	8D
0005435925326	13181	23	8E
0005435068697	13181	24	9A
0005435068553	13181	25	9C
0005435068483	13181	26	9D
0005435068676	13181	27	9E
0005435068727	13181	28	11A
0005435068916	13181	29	11C
0005435068781	13181	30	11D
0005435068738	13181	31	12C
0005435925338	13181	32	12D
0005435925331	13181	33	12E
0005435925334	13181	34	12F
0005435068670	13181	35	13A
0005435068671	13181	36	13C
0005435925332	13181	37	13E
0005435068595	13181	38	14A
0005435068753	13181	39	14C
0005435068342	13181	40	14D
0005435068943	13181	41	14E
0005435068723	13181	42	15D
0005435925337	13181	43	15E
0005435068823	13181	44	16A
0005435068923	13181	45	16C
0005435925325	13181	46	16E
0005435925333	13181	47	16F
0005435068779	13181	48	17D
0005435925330	13181	49	17F
0005435068607	13181	50	18C
0005435068594	13181	51	18D
0005435068843	13181	52	18E
0005435068533	13181	53	19C
0005435925339	13181	54	19D
0005435068730	13181	55	19E
0005435925327	13181	56	19F
0005435068768	13181	57	20A
0005435068532	13181	58	20C
0005435068924	13181	59	20F
0005435925204	15503	1	1C
0005435069208	15503	2	1F
0005435069168	15503	3	2A
0005435925201	15503	4	2C
0005435925197	15503	5	2F
0005435069186	15503	6	3A
0005435069201	15503	7	3F
0005435069193	15503	8	4A
0005435069174	15503	9	4C
0005435069172	15503	10	4D
0005435069216	15503	11	4E
0005435069199	15503	12	4F
0005435925206	15503	13	5A
0005435069184	15503	14	5C
0005435069207	15503	15	5D
0005435069204	15503	16	6A
0005435069205	15503	17	6D
0005435925213	15503	18	6E
0005435069178	15503	19	6F
0005435925218	15503	20	7E
0005435069189	15503	21	7F
0005435069215	15503	22	8A
0005435069197	15503	23	8C
0005435069202	15503	24	8F
0005435069190	15503	25	9A
0005435925108	15503	26	9C
0005435925198	15503	27	9D
0005435069210	15503	28	9E
0005435069198	15503	29	9F
0005435069167	15503	30	10D
0005435069192	15503	31	10E
0005435069176	15503	32	11D
0005435069181	15503	33	12A
0005435925216	15503	34	12C
0005435069194	15503	35	12D
0005435069188	15503	36	13A
0005435925211	15503	37	13C
0005435069206	15503	38	13D
0005435069177	15503	39	13E
0005435925151	15503	40	13F
0005435069212	15503	41	14A
0005435069170	15503	42	14D
0005435069169	15503	43	14F
0005435925202	15503	44	15A
0005435069196	15503	45	15C
0005435069214	15503	46	15D
0005435069179	15503	47	15E
0005435069200	15503	48	15F
0005435925215	15503	49	16A
0005435069180	15503	50	16C
0005435925188	15503	51	16E
0005435069211	15503	52	17C
0005435069203	15503	53	17E
0005435069213	15503	54	17F
0005435069187	15503	55	18A
0005435069195	15503	56	18D
0005435069183	15503	57	18E
0005435069182	15503	58	18F
0005435069175	15503	59	19A
0005435069185	15503	60	19C
0005435925174	15503	61	19D
0005435069217	15503	62	19E
0005435069171	15503	63	19F
0005435069191	15503	64	20C
0005435069173	15503	65	20D
0005435069209	15503	66	20E
0005435925158	15503	67	20F
0005435808259	23186	1	1A
0005435808250	23186	2	1B
0005435808262	23186	3	1C
0005435808243	23186	4	1D
0005433407526	23186	5	2A
0005433407503	23186	6	2B
0005435808233	23186	7	2C
0005435808253	23186	8	2D
0005433407525	23186	9	3A
0005435808247	23186	10	3B
0005435808256	23186	11	3C
0005435808258	23186	12	3D
0005435808244	23186	13	4A
0005435808260	23186	14	4B
0005435808242	23186	15	4D
0005433407520	23186	16	5A
0005433407529	23186	17	5B
0005433407497	23186	18	5C
0005435808251	23186	19	5D
0005435808239	23186	20	6A
0005435808231	23186	21	6B
0005433407534	23186	22	6C
0005435808232	23186	23	6D
0005433407533	23186	24	7A
0005435808246	23186	25	7B
0005435808240	23186	26	7C
0005433407507	23186	27	7D
0005433407504	23186	28	18B
0005435808237	23186	29	18C
0005435808249	23186	30	18D
0005433407501	23186	31	19A
0005435808235	23186	32	19B
0005435808238	23186	33	19C
0005433407527	23186	34	19D
0005435808248	23186	35	20A
0005433407524	23186	36	20B
0005435808255	23186	37	20C
0005435808261	23186	38	20D
0005435808257	23186	39	21A
0005435808252	23186	40	21B
0005433407519	23186	41	21C
0005435808245	23186	42	21D
0005435808234	23186	43	22A
0005435808254	23186	44	22B
0005435808241	23186	45	22C
0005433407521	23186	46	22D
0005435808236	23186	47	23A
0005433407528	23186	48	23B
0005434214658	10683	1	1A
0005434214693	10683	2	1C
0005434755966	10683	3	1D
0005434756102	10683	4	1F
0005434756150	10683	5	2A
0005434756179	10683	6	2C
0005434755975	10683	7	2D
0005434756124	10683	8	2F
0005434756243	10683	9	3A
0005434214666	10683	10	3C
0005434756200	10683	11	3F
0005434756148	10683	12	4A
0005434756095	10683	13	4D
0005434756126	10683	14	5A
0005434756173	10683	15	5C
0005434214681	10683	16	5E
0005434214677	10683	17	5F
0005434756138	10683	18	6A
0005434214678	10683	19	6C
0005434214676	10683	20	6D
0005434214651	10683	21	6E
0005434214690	10683	22	6F
0005434756162	10683	23	7A
0005434214695	10683	24	7C
0005434214680	10683	25	7D
0005434756171	10683	26	7E
0005434756239	10683	27	7F
0005434756268	10683	28	8A
0005434756182	10683	29	8C
0005434756029	10683	30	8D
0005434756101	10683	31	8E
0005434756177	10683	32	8F
0005434214669	10683	33	9A
0005434214689	10683	34	9C
0005434756096	10683	35	9E
0005434214687	10683	36	9F
0005434214661	10683	37	10A
0005434214679	10683	38	10C
0005434756042	10683	39	10D
0005434214686	10683	40	10E
0005434214653	10683	41	10F
0005434214667	10683	42	11A
0005434214655	10683	43	11C
0005434756269	10683	44	11D
0005434214656	10683	45	11E
0005434214683	10683	46	11F
0005434756183	10683	47	12A
0005434214665	10683	48	12C
0005434214696	10683	49	12D
0005434214674	10683	50	12E
0005434756294	10683	51	12F
0005434214685	10683	52	13A
0005434214657	10683	53	13C
0005434756149	10683	54	13D
0005434214691	10683	55	13F
0005434214650	10683	56	13E
0005434756099	10683	57	14A
0005434756373	10683	58	14C
0005434756118	10683	59	14D
0005434214664	10683	60	14E
0005434756114	10683	61	14F
0005434214662	10683	62	15C
0005434214692	10683	63	15D
0005434214673	10683	64	15E
0005434756191	10683	65	15F
0005434214675	10683	66	16A
0005434214671	10683	67	16C
0005434214670	10683	68	16D
0005434214694	10683	69	16E
0005434756125	10683	70	16F
0005434756161	10683	71	17A
0005434214688	10683	72	17C
0005434214663	10683	73	17D
0005434756116	10683	74	17F
0005434214672	10683	75	18A
0005434756107	10683	76	18D
0005434214654	10683	77	18E
0005434756267	10683	78	18F
0005434756244	10683	79	19A
0005434756043	10683	80	19C
0005434214668	10683	81	19D
0005434756210	10683	82	19E
0005434214659	10683	83	19F
0005434756190	10683	84	20A
0005434214684	10683	85	20C
0005434214652	10683	86	20D
0005434214682	10683	87	20E
0005434214660	10683	88	20F
0005434756502	28674	1	1A
0005434756478	28674	2	1C
0005434214291	28674	3	1D
0005434756498	28674	4	1F
0005434756497	28674	5	2C
0005434214097	28674	6	2D
0005434756495	28674	7	2F
0005434214335	28674	8	3A
0005434756504	28674	9	3D
0005434756496	28674	10	4A
0005434756475	28674	11	4D
0005434756489	28674	12	4E
0005434756503	28674	13	4F
0005434214237	28674	14	5A
0005434756487	28674	15	5D
0005434214066	28674	16	5F
0005434756490	28674	17	6C
0005434214041	28674	18	6D
0005434756476	28674	19	6E
0005434214271	28674	20	6F
0005434214189	28674	21	7A
0005434756509	28674	22	7C
0005434756472	28674	23	7D
0005434214030	28674	24	7E
0005434214130	28674	25	8D
0005434214254	28674	26	8E
0005434756484	28674	27	9C
0005434756507	28674	28	9D
0005434214119	28674	29	9E
0005434214236	28674	30	9F
0005434756508	28674	31	10A
0005434756488	28674	32	10C
0005434756506	28674	33	10E
0005434756492	28674	34	11A
0005434756470	28674	35	11C
0005434214188	28674	36	11E
0005434214272	28674	37	11F
0005434214349	28674	38	12D
0005434756483	28674	39	12E
0005434756477	28674	40	12F
0005434756491	28674	41	13A
0005434756501	28674	42	13C
0005434756500	28674	43	13E
0005434214069	28674	44	14A
0005434214187	28674	45	14E
0005434756499	28674	46	14F
0005434756482	28674	47	15A
0005434756471	28674	48	15D
0005434756511	28674	49	15E
0005434214068	28674	50	15F
0005434756480	28674	51	16A
0005434214072	28674	52	16C
0005434756510	28674	53	16D
0005434214235	28674	54	16E
0005434756473	28674	55	16F
0005434214299	28674	56	17C
0005434756479	28674	57	17D
0005434756512	28674	58	17E
0005434214054	28674	59	17F
0005434214096	28674	60	18A
0005434756474	28674	61	18C
0005434756481	28674	62	18D
0005434214192	28674	63	18E
0005434214358	28674	64	18F
0005434756494	28674	65	19A
0005434756485	28674	66	19C
0005434756505	28674	67	19E
0005434214243	28674	68	19F
0005434756486	28674	69	20C
0005434756513	28674	70	20D
0005434756493	28674	71	20E
0005434756514	28674	72	20F
0005435039971	5430	1	1A
0005435039969	5430	2	1D
0005435042859	5430	3	1C
0005432125475	5430	4	2A
0005435039952	5430	5	1F
0005435042860	5430	6	2C
0005435039975	5430	7	2F
0005432125472	5430	8	3A
0005435007099	5430	9	3D
0005435039978	5430	10	3C
0005434229248	5430	11	3F
0005435007091	5430	12	4A
0005435007104	5430	13	4B
0005435039991	5430	14	4D
0005435007103	5430	15	4C
0005435007102	5430	16	4E
0005435039974	5430	17	4F
0005435007095	5430	18	5A
0005435039938	5430	19	5B
0005435039943	5430	20	5D
0005435039955	5430	21	5C
0005435039964	5430	22	5E
0005435039985	5430	23	6A
0005435039948	5430	24	5F
0005435039945	5430	25	6C
0005435039942	5430	26	6D
0005435039973	5430	27	6E
0005434229296	5430	28	6F
0005435039993	5430	29	7A
0005435039939	5430	30	7C
0005434229218	5430	31	7B
0005435039970	5430	32	7D
0005435007092	5430	33	7E
0005435007089	5430	34	8A
0005435007106	5430	35	7F
0005434229183	5430	36	8C
0005434229231	5430	37	8D
0005435039949	5430	38	8F
0005435007086	5430	39	8E
0005435039994	5430	40	9A
0005435039986	5430	41	9C
0005435039960	5430	42	9B
0005432125471	5430	43	9D
0005435007105	5430	44	9F
0005435007098	5430	45	10C
0005435039963	5430	46	10B
0005434229171	5430	47	10D
0005435039941	5430	48	11A
0005434229234	5430	49	11C
0005435039996	5430	50	11B
0005435007087	5430	51	11E
0005435039968	5430	52	11D
0005434229182	5430	53	11F
0005435039966	5430	54	12A
0005435039961	5430	55	12B
0005435007096	5430	56	12D
0005435039987	5430	57	12C
0005432125473	5430	58	13A
0005434229330	5430	59	12F
0005435039965	5430	60	13B
0005435039932	5430	61	13D
0005435039988	5430	62	13C
0005435039992	5430	63	13E
0005434229232	5430	64	14A
0005435039944	5430	65	13F
0005435039983	5430	66	14B
0005435039940	5430	67	14C
0005435039957	5430	68	14D
0005435007094	5430	69	14E
0005435039976	5430	70	14F
0005435039982	5430	71	15A
0005435007108	5430	72	15C
0005435039953	5430	73	15B
0005435007101	5430	74	15E
0005435039962	5430	75	15D
0005435007100	5430	76	16A
0005435039954	5430	77	15F
0005434229285	5430	78	16B
0005435039947	5430	79	16D
0005432125476	5430	80	16F
0005434229200	5430	81	16E
0005435007085	5430	82	17A
0005435039934	5430	83	17B
0005434229243	5430	84	17C
0005434229302	5430	85	17E
0005435039956	5430	86	17D
0005435039981	5430	87	18A
0005435039989	5430	88	17F
0005435007109	5430	89	18B
0005434229135	5430	90	18D
0005435039979	5430	91	18C
0005435039984	5430	92	18F
0005434229261	5430	93	18E
0005432125470	5430	94	19B
0005435039936	5430	95	19C
0005435039972	5430	96	19E
0005435039958	5430	97	19F
0005435007090	5430	98	20A
0005435039967	5430	99	20B
0005435039935	5430	100	20D
0005435007107	5430	101	20C
0005435039950	5430	102	20F
0005435007093	5430	103	21A
0005435039990	5430	104	21C
0005435039959	5430	105	21B
0005435039977	5430	106	21D
0005435007097	5430	107	21E
0005432125474	5430	108	22A
0005435039946	5430	109	21F
0005434229199	5430	110	22C
0005434229142	5430	111	22E
0005435039980	5430	112	22D
0005435039937	5430	113	22F
0005434229233	5430	114	23A
0005434229236	5430	115	23B
0005435007088	5430	116	23C
0005435039995	5430	117	23D
0005435039933	5430	118	23F
0005435039951	5430	119	23E
0005434229431	12953	1	1A
0005435039613	12953	2	1C
0005435039181	12953	3	1F
0005435039129	12953	4	1D
0005435006935	12953	5	2C
0005435039574	12953	6	2A
0005435039536	12953	7	2D
0005432304410	12953	8	2F
0005435039439	12953	9	3A
0005435043277	12953	10	3D
0005435039606	12953	11	3C
0005435039551	12953	12	3F
0005435039127	12953	13	4A
0005435006845	12953	14	4B
0005434229436	12953	15	4D
0005435039407	12953	16	4C
0005432304409	12953	17	4E
0005432304408	12953	18	5A
0005435039584	12953	19	4F
0005435039189	12953	20	5C
0005434229440	12953	21	5B
0005435039501	12953	22	5D
0005435039621	12953	23	5E
0005435039473	12953	24	5F
0005435039494	12953	25	6B
0005435039409	12953	26	6A
0005435006821	12953	27	6C
0005434229449	12953	28	6D
0005435039559	12953	29	6E
0005435006893	12953	30	6F
0005435006906	12953	31	7B
0005435039469	12953	32	7A
0005435006875	12953	33	7C
0005435039438	12953	34	7D
0005434229450	12953	35	7E
0005435039128	12953	36	8A
0005435006774	12953	37	7F
0005435039273	12953	38	8B
0005435039464	12953	39	8C
0005435039704	12953	40	8E
0005435039374	12953	41	8D
0005435039425	12953	42	8F
0005435039404	12953	43	9A
0005435006859	12953	44	9B
0005435039648	12953	45	9D
0005435039333	12953	46	9C
0005435039560	12953	47	9E
0005434229445	12953	48	9F
0005435377904	12953	49	10C
0005435039150	12953	50	10B
0005435039413	12953	51	10E
0005435039142	12953	52	10D
0005434229434	12953	53	11A
0005435039141	12953	54	11B
0005434229443	12953	55	11C
0005434229447	12953	56	11E
0005435039575	12953	57	11D
0005435042843	12953	58	11F
0005435042844	12953	59	12A
0005435006951	12953	60	12B
0005435039513	12953	61	12D
0005435039539	12953	62	12C
0005435039447	12953	63	12E
0005434229435	12953	64	12F
0005435039153	12953	65	13A
0005435039530	12953	66	13B
0005434229437	12953	67	13D
0005435039224	12953	68	13E
0005435006858	12953	69	14A
0005434229441	12953	70	13F
0005434229433	12953	71	14C
0005435007018	12953	72	14D
0005435006955	12953	73	14F
0005435039537	12953	74	14E
0005435039332	12953	75	15A
0005435039280	12953	76	15B
0005435039424	12953	77	15C
0005435039552	12953	78	15D
0005435039482	12953	79	15F
0005435039292	12953	80	15E
0005434229432	12953	81	16B
0005435039437	12953	82	16A
0005435006894	12953	83	16C
0005435039204	12953	84	16E
0005435042838	12953	85	16D
0005435039403	12953	86	16F
0005435006844	12953	87	17B
0005435039507	12953	88	17A
0005435039225	12953	89	17D
0005435039576	12953	90	17C
0005435039694	12953	91	17E
0005435006963	12953	92	18A
0005435039239	12953	93	17F
0005435006916	12953	94	18C
0005434229430	12953	95	18B
0005434229448	12953	96	18D
0005435039472	12953	97	18F
0005435039272	12953	98	18E
0005434229446	12953	99	19A
0005435039240	12953	100	19B
0005432304411	12953	101	19C
0005435039535	12953	102	19E
0005435039423	12953	103	19D
0005435039406	12953	104	19F
0005435006907	12953	105	20B
0005434229442	12953	106	20A
0005435039349	12953	107	20D
0005435039399	12953	108	20C
0005434229438	12953	109	20E
0005434229444	12953	110	20F
0005435006860	12953	111	21B
0005435039514	12953	112	21A
0005435039622	12953	113	21C
0005435006950	12953	114	21D
0005435006861	12953	115	21F
0005435039542	12953	116	21E
0005435039096	12953	117	22A
0005435039408	12953	118	22C
0005434229439	12953	119	22D
0005435039520	12953	120	22F
0005435039529	12953	121	22E
0005435039620	12953	122	23A
0005435039430	12953	123	23B
0005435039703	12953	124	23C
0005435039446	12953	125	23E
0005435039583	12953	126	23F
0005434426668	14847	1	1C
0005435902580	14847	2	1D
0005435554136	14847	3	2A
0005434426681	14847	4	2F
0005435902654	14847	5	3A
0005435554145	14847	6	3D
0005434426660	14847	7	3F
0005435902521	14847	8	4A
0005434426672	14847	9	4C
0005434426666	14847	10	4D
0005434411789	14847	11	4E
0005435902606	14847	12	5C
0005435902611	14847	13	5D
0005435902615	14847	14	5E
0005434411787	14847	15	6A
0005434426678	14847	16	6E
0005435902640	14847	17	6D
0005435554137	14847	18	7A
0005435902565	14847	19	7C
0005434426673	14847	20	7D
0005434426662	14847	21	7E
0005434426684	14847	22	7F
0005435554176	14847	23	8A
0005435902639	14847	24	8C
0005434426676	14847	25	8D
0005432188614	14847	26	9C
0005434426680	14847	27	9E
0005434426679	14847	28	10A
0005435902595	14847	29	10C
0005435902608	14847	30	10D
0005434426682	14847	31	10E
0005434426667	14847	32	10F
0005435902601	14847	33	11A
0005434426664	14847	34	11C
0005435902612	14847	35	11D
0005435902605	14847	36	11F
0005434426657	14847	37	12C
0005435902501	14847	38	12E
0005434426661	14847	39	12F
0005434426658	14847	40	13C
0005435554148	14847	41	13E
0005435554147	14847	42	14A
0005435902616	14847	43	14C
0005434426677	14847	44	14F
0005435902594	14847	45	15A
0005432188615	14847	46	15D
0005434426670	14847	47	15E
0005434411788	14847	48	15F
0005432188613	14847	49	16A
0005434426685	14847	50	16D
0005434426674	14847	51	16F
0005434426659	14847	52	17A
0005434426669	14847	53	17C
0005435902530	14847	54	17D
0005435554175	14847	55	17E
0005435554158	14847	56	17F
0005435902581	14847	57	18C
0005434426675	14847	58	18D
0005434426671	14847	59	18E
0005434426686	14847	60	18F
0005435902582	14847	61	19A
0005434426665	14847	62	19C
0005434411785	14847	63	19D
0005434411786	14847	64	19E
0005435902551	14847	65	20A
0005434426663	14847	66	20C
0005434426683	14847	67	20E
0005435902760	20191	1	1A
0005435902754	20191	2	1D
0005434426505	20191	3	1F
0005435902749	20191	4	2A
0005434426494	20191	5	3A
0005434426508	20191	6	3C
0005432059510	20191	7	3D
0005434426504	20191	8	4A
0005434426432	20191	9	4D
0005434426502	20191	10	4F
0005435902759	20191	11	5D
0005434426603	20191	12	5E
0005435554204	20191	13	6A
0005435902756	20191	14	6D
0005434426546	20191	15	6F
0005434426433	20191	16	7A
0005434426493	20191	17	7C
0005435902763	20191	18	8A
0005435902765	20191	19	8D
0005434411757	20191	20	8E
0005435902761	20191	21	8F
0005435902750	20191	22	9A
0005435554205	20191	23	9D
0005434426455	20191	24	10C
0005434426398	20191	25	10D
0005435554206	20191	26	10E
0005435902753	20191	27	10F
0005435902758	20191	28	11E
0005435902748	20191	29	11F
0005434426474	20191	30	12C
0005434426554	20191	31	12D
0005435902752	20191	32	12F
0005434426392	20191	33	13A
0005432059509	20191	34	13C
0005435902764	20191	35	13E
0005434411762	20191	36	13F
0005434426591	20191	37	14C
0005435902755	20191	38	14D
0005432059511	20191	39	14F
0005434426370	20191	40	15A
0005434426371	20191	41	15D
0005435902751	20191	42	16A
0005434426475	20191	43	16F
0005434426575	20191	44	17A
0005434411763	20191	45	17C
0005435902757	20191	46	17E
0005434426448	20191	47	17F
0005435902766	20191	48	18A
0005434426328	20191	49	18D
0005435554202	20191	50	18E
0005434426576	20191	51	18F
0005435902762	20191	52	19C
0005434426372	20191	53	19D
0005434426459	20191	54	19E
0005434411770	20191	55	19F
0005434426456	20191	56	20C
0005435554203	20191	57	20E
0005434411769	20191	58	20F
0005434523756	28015	1	4F
0005434559082	28015	2	5A
0005434523754	28015	3	5B
0005434559083	28015	4	6B
0005432462514	28015	5	6C
0005432462519	28015	6	6F
0005434523759	28015	7	7E
0005434523755	28015	8	9A
0005434523748	28015	9	9C
0005432462523	28015	10	10C
0005434523747	28015	11	11A
0005432462515	28015	12	11C
0005432462520	28015	13	11E
0005432462517	28015	14	12D
0005434559085	28015	15	12E
0005434523757	28015	16	14A
0005432462521	28015	17	14C
0005434523758	28015	18	14E
0005434559087	28015	19	14F
0005432462518	28015	20	15A
0005432462522	28015	21	15D
0005434559084	28015	22	17B
0005434523753	28015	23	17E
0005432462516	28015	24	18B
0005434559086	28015	25	20B
0005434523750	28015	26	23F
0005432462490	30895	1	2C
0005434523777	30895	2	8E
0005434523780	30895	3	10D
0005432462489	30895	4	10E
0005434523778	30895	5	12B
0005432462487	30895	6	14D
0005434523779	30895	7	16E
0005432462495	30895	8	17B
0005432462505	30895	9	17C
0005434523781	30895	10	18E
0005434523782	30895	11	19C
0005434523776	30895	12	19B
0005432462494	30895	13	22F
0005432462506	30895	14	23E
0005433726103	30866	1	2C
0005433726098	30866	2	3C
0005433726101	30866	3	8A
0005433726100	30866	4	8F
0005433726109	30866	5	9D
0005433726097	30866	6	9F
0005433726106	30866	7	12E
0005433726102	30866	8	12F
0005433726104	30866	9	13D
0005433726093	30866	10	13E
0005433726096	30866	11	14B
0005433726108	30866	12	15E
0005433726094	30866	13	16B
0005433726107	30866	14	16C
0005433726110	30866	15	16E
0005433726105	30866	16	17D
0005433726095	30866	17	19B
0005433726099	30866	18	19E
0005435982426	26535	1	1A
0005435982424	26535	2	1C
0005432300274	26535	3	1D
0005433434513	26535	4	1F
0005432300276	26535	5	2A
0005435982397	26535	6	2C
0005435982400	26535	7	2D
0005435982434	26535	8	2F
0005433434445	26535	9	3A
0005432300273	26535	10	3C
0005435982432	26535	11	3F
0005435982394	26535	12	4A
0005435982416	26535	13	4C
0005433434677	26535	14	4D
0005435982409	26535	15	4E
0005433434530	26535	16	4F
0005435982442	26535	17	5A
0005435982441	26535	18	5C
0005435982411	26535	19	5D
0005433434461	26535	20	5E
0005433434536	26535	21	5F
0005433434417	26535	22	6A
0005435982414	26535	23	6C
0005433434533	26535	24	6D
0005435982419	26535	25	6E
0005435982410	26535	26	7A
0005435982418	26535	27	7C
0005433434541	26535	28	7D
0005435982435	26535	29	7F
0005433434434	26535	30	8A
0005435982422	26535	31	8C
0005433434444	26535	32	8D
0005435982412	26535	33	8F
0005435982420	26535	34	9A
0005435982407	26535	35	9C
0005435982440	26535	36	9D
0005435982431	26535	37	9E
0005433434460	26535	38	9F
0005435982413	26535	39	10A
0005433434446	26535	40	10C
0005435982421	26535	41	10D
0005433434623	26535	42	10F
0005433434506	26535	43	11A
0005435982405	26535	44	11C
0005435982439	26535	45	11D
0005435982406	26535	46	12A
0005433434537	26535	47	12C
0005433434459	26535	48	12D
0005435982438	26535	49	12E
0005435982428	26535	50	12F
0005433434395	26535	51	13A
0005435982393	26535	52	13C
0005435982436	26535	53	13D
0005433434553	26535	54	13E
0005435982427	26535	55	13F
0005434270202	26535	56	14A
0005435982425	26535	57	14C
0005432300277	26535	58	14E
0005435982398	26535	59	14F
0005432300275	26535	60	15A
0005435982399	26535	61	15C
0005433434462	26535	62	15D
0005435982437	26535	63	15E
0005433434622	26535	64	15F
0005434270201	26535	65	16A
0005435982403	26535	66	16C
0005435982402	26535	67	16D
0005433434424	26535	68	16E
0005435982433	26535	69	16F
0005435982401	26535	70	17A
0005433434394	26535	71	17C
0005432300278	26535	72	17D
0005435982417	26535	73	17F
0005435982395	26535	74	18C
0005433434529	26535	75	18E
0005435982396	26535	76	19A
0005435982408	26535	77	19C
0005435982404	26535	78	19D
0005433434519	26535	79	19E
0005435982429	26535	80	19F
0005435982415	26535	81	20A
0005435982430	26535	82	20D
0005433434433	26535	83	20C
0005435982423	26535	84	20E
0005433434776	26721	1	1A
0005435981962	26721	2	1D
0005433434771	26721	3	1F
0005434271318	26721	4	2A
0005433434757	26721	5	2C
0005433434780	26721	6	2D
0005435982152	26721	7	3A
0005435982001	26721	8	3C
0005435982086	26721	9	3D
0005433434781	26721	10	3F
0005435981940	26721	11	4A
0005433434770	26721	12	4C
0005435982020	26721	13	4D
0005434269110	26721	14	4E
0005435981843	26721	15	4F
0005433434782	26721	16	5A
0005432051137	26721	17	5C
0005435981848	26721	18	5D
0005433434775	26721	19	5F
0005435982117	26721	20	6A
0005435982104	26721	21	6C
0005433434758	26721	22	6E
0005435981842	26721	23	6F
0005435982036	26721	24	7A
0005435982042	26721	25	7C
0005433434777	26721	26	7D
0005434270214	26721	27	7F
0005435982035	26721	28	8A
0005435981929	26721	29	8C
0005433434773	26721	30	8D
0005435981927	26721	31	8E
0005433434772	26721	32	8F
0005435981990	26721	33	9C
0005435981889	26721	34	9D
0005435981844	26721	35	9E
0005435981891	26721	36	10C
0005433434783	26721	37	10D
0005435982044	26721	38	10E
0005435982103	26721	39	10F
0005434269109	26721	40	11A
0005433434756	26721	41	11C
0005435982064	26721	42	11D
0005435982154	26721	43	11E
0005433434762	26721	44	11F
0005434271319	26721	45	12A
0005435982043	26721	46	12C
0005433434764	26721	47	12D
0005435982067	26721	48	12E
0005435981928	26721	49	12F
0005433434778	26721	50	13C
0005433434760	26721	51	13D
0005433434766	26721	52	13E
0005435981892	26721	53	13F
0005435982077	26721	54	14A
0005435981937	26721	55	14C
0005435981890	26721	56	14D
0005435982164	26721	57	14E
0005433434768	26721	58	15A
0005434270212	26721	59	15C
0005434270213	26721	60	15D
0005433434763	26721	61	15E
0005433434767	26721	62	15F
0005435982080	26721	63	16A
0005433434761	26721	64	16E
0005435981901	26721	65	16F
0005435982179	26721	66	17A
0005435982081	26721	67	17C
0005435982041	26721	68	17D
0005435982027	26721	69	17E
0005435981963	26721	70	17F
0005435982051	26721	71	18C
0005433434765	26721	72	18D
0005433434779	26721	73	18E
0005435982102	26721	74	18F
0005435982066	26721	75	19A
0005433434759	26721	76	19C
0005435982074	26721	77	19D
0005432051139	26721	78	19E
0005435982105	26721	79	20A
0005433434769	26721	80	20C
0005432051138	26721	81	20D
0005433434774	26721	82	20E
0005435982054	26721	83	20F
0005433689897	29260	1	1A
0005433686622	29260	2	1B
0005433686627	29260	3	1D
0005433686613	29260	4	2C
0005433686610	29260	5	3A
0005433689894	29260	6	3C
0005433686617	29260	7	3D
0005433686618	29260	8	4A
0005433689891	29260	9	4B
0005433689893	29260	10	4D
0005433689904	29260	11	5A
0005433689905	29260	12	5C
0005433686615	29260	13	6A
0005433689896	29260	14	6B
0005433689890	29260	15	18A
0005433686621	29260	16	18C
0005433689900	29260	17	18D
0005433686603	29260	18	20C
0005433689903	29260	19	21A
0005433686616	29260	20	21C
0005433689902	29260	21	21D
0005433686611	29260	22	22B
0005433686612	29260	23	22C
0005433689895	29260	24	23A
0005433689892	29260	25	23B
0005432584112	3187	1	1A
0005432584123	3187	2	1C
0005432584109	3187	3	2A
0005432584122	3187	4	2B
0005432584106	3187	5	3C
0005432584117	3187	6	3D
0005432858022	3187	7	4B
0005432584111	3187	8	4C
0005432857990	3187	9	4D
0005432216280	3187	10	5A
0005432584114	3187	11	5B
0005432584105	3187	12	5D
0005432216281	3187	13	6A
0005432584098	3187	14	6B
0005432857979	3187	15	6C
0005432584108	3187	16	6D
0005432858021	3187	17	7A
0005432584102	3187	18	7B
0005432584113	3187	19	7C
0005432858059	3187	20	18A
0005432584100	3187	21	18B
0005432858013	3187	22	18D
0005432584107	3187	23	19A
0005432584115	3187	24	19B
0005432584099	3187	25	19C
0005432584116	3187	26	19D
0005432858023	3187	27	20B
0005432584120	3187	28	20C
0005432584110	3187	29	20D
0005432584121	3187	30	21A
0005432584103	3187	31	21C
0005432857980	3187	32	21D
0005432858008	3187	33	22A
0005432584118	3187	34	22B
0005432584104	3187	35	22D
0005432584101	3187	36	23A
0005432584119	3187	37	23B
0005432583909	31507	1	1A
0005432583880	31507	2	1B
0005432583906	31507	3	1C
0005432858105	31507	4	2A
0005432583841	31507	5	2B
0005432858098	31507	6	2D
0005432583895	31507	7	3A
0005432583918	31507	8	3C
0005432583852	31507	9	4A
0005432858108	31507	10	4C
0005432583879	31507	11	4D
0005432858101	31507	12	5A
0005432583931	31507	13	5B
0005432583914	31507	14	5D
0005432583754	31507	15	6A
0005432583840	31507	16	6C
0005432583882	31507	17	7A
0005432858104	31507	18	7B
0005432858107	31507	19	7D
0005432858102	31507	20	18A
0005432858099	31507	21	18C
0005432583968	31507	22	19B
0005432583953	31507	23	19D
0005432583877	31507	24	20A
0005432583956	31507	25	20B
0005432583957	31507	26	20C
0005432583894	31507	27	20D
0005432583919	31507	28	21A
0005432583896	31507	29	21B
0005432583990	31507	30	21C
0005432858106	31507	31	21D
0005432858100	31507	32	22B
0005432583967	31507	33	22A
0005432858109	31507	34	22D
0005432858103	31507	35	23B
0005434943378	866	1	2A
0005434943383	866	2	3D
0005433255102	866	3	4B
0005434943381	866	4	6D
0005434943376	866	5	7B
0005434943377	866	6	18A
0005433255101	866	7	19B
0005434943382	866	8	19D
0005434943375	866	9	20B
0005434943380	866	10	21A
0005434943374	866	11	22C
0005434943379	866	12	23B
0005433255135	16213	1	1D
0005433255136	16213	2	3C
0005434943319	16213	3	5A
0005434943317	16213	4	6D
0005434943293	16213	5	7D
0005434943264	16213	6	18A
0005433255134	16213	7	20A
0005433255133	16213	8	20B
0005434943318	16213	9	21C
0005433255137	16213	10	23B
0005435858563	27619	1	1A
0005433654727	27619	2	2A
0005435858570	27619	3	1F
0005435858577	27619	4	2D
0005433654699	27619	5	3A
0005433654730	27619	6	2F
0005435858576	27619	7	5C
0005435858573	27619	8	7C
0005433654721	27619	9	7D
0005433654747	27619	10	7F
0005433654723	27619	11	8C
0005435858567	27619	12	8E
0005435858575	27619	13	10C
0005433654720	27619	14	10F
0005435858569	27619	15	11C
0005435858568	27619	16	11F
0005435858578	27619	17	13B
0005433654728	27619	18	13D
0005433654710	27619	19	14A
0005435858574	27619	20	13F
0005433654725	27619	21	15D
0005433654700	27619	22	15C
0005435858571	27619	23	16B
0005433654722	27619	24	16A
0005433654703	27619	25	15F
0005435858572	27619	26	16D
0005433654685	27619	27	17A
0005433654744	27619	28	17C
0005433654731	27619	29	17F
0005433654704	27619	30	17E
0005433654746	27619	31	18A
0005435858566	27619	32	18D
0005433654748	27619	33	19A
0005435858564	27619	34	19E
0005433654724	27619	35	20B
0005433654729	27619	36	20D
0005433654726	27619	37	20F
0005435858565	27619	38	21A
0005433654705	27619	39	21E
0005433811630	14345	1	5B
0005435653147	21740	1	1A
0005433367812	21740	2	1C
0005435653177	21740	3	1D
0005435653174	21740	4	2A
0005433367645	21740	5	2C
0005435653186	21740	6	2D
0005433367667	21740	7	2F
0005435653190	21740	8	3A
0005433367680	21740	9	3C
0005435653159	21740	10	3D
0005435653157	21740	11	3F
0005435653154	21740	12	4A
0005435653144	21740	13	4C
0005433367772	21740	14	4D
0005435653179	21740	15	4E
0005433367487	21740	16	4F
0005433367502	21740	17	5A
0005433367619	21740	18	5C
0005435653187	21740	19	5D
0005435653166	21740	20	5F
0005435653178	21740	21	6A
0005433367681	21740	22	6C
0005435653181	21740	23	6F
0005433367642	21740	24	7A
0005435653152	21740	25	7C
0005433367657	21740	26	7D
0005435653158	21740	27	7F
0005433367407	21740	28	8A
0005433367652	21740	29	8C
0005435653151	21740	30	8D
0005435653148	21740	31	8E
0005433367719	21740	32	9A
0005433367811	21740	33	9C
0005433367707	21740	34	9D
0005435653167	21740	35	9E
0005435653155	21740	36	9F
0005433367757	21740	37	10A
0005435653176	21740	38	10D
0005435653165	21740	39	10C
0005435653171	21740	40	10E
0005433367529	21740	41	10F
0005433367695	21740	42	11A
0005433367771	21740	43	11E
0005435653163	21740	44	11F
0005433367586	21740	45	12A
0005435653173	21740	46	12D
0005435653153	21740	47	12C
0005435653170	21740	48	12E
0005435653142	21740	49	13A
0005433367641	21740	50	13C
0005433367501	21740	51	13D
0005435653182	21740	52	13E
0005435653168	21740	53	13F
0005435653185	21740	54	14A
0005435653162	21740	55	14C
0005435653164	21740	56	14D
0005435653189	21740	57	14E
0005435653172	21740	58	14F
0005433367813	21740	59	15A
0005433367535	21740	60	15C
0005435653188	21740	61	15D
0005433367696	21740	62	15E
0005435653161	21740	63	15F
0005435653139	21740	64	16A
0005433367408	21740	65	16C
0005435653149	21740	66	16D
0005435653150	21740	67	16E
0005435653169	21740	68	16F
0005435653191	21740	69	17A
0005435653146	21740	70	17C
0005433367666	21740	71	17D
0005435653160	21740	72	17E
0005433367791	21740	73	17F
0005433367689	21740	74	18A
0005435653143	21740	75	18C
0005435653140	21740	76	18D
0005435653180	21740	77	18F
0005435653183	21740	78	19A
0005435653156	21740	79	19C
0005435653145	21740	80	19D
0005433367534	21740	81	19E
0005433367665	21740	82	19F
0005435653175	21740	83	20A
0005433367613	21740	84	20C
0005435653141	21740	85	20D
0005433367409	21740	86	20E
0005435653184	21740	87	20F
0005433785066	9377	1	1A
0005433805493	9377	2	1F
0005434170999	9377	3	1G
0005432666395	9377	4	1H
0005433785056	9377	5	2C
0005433785059	9377	6	2F
0005432667459	9377	7	3B
0005434273067	9377	8	3C
0005433785068	9377	9	3G
0005433763243	9377	10	4A
0005433785061	9377	11	5B
0005433785044	9377	12	5C
0005433805498	9377	13	5G
0005434171036	9377	14	5H
0005434170951	9377	15	11A
0005432665280	9377	16	11D
0005432657457	9377	17	11F
0005433805502	9377	18	12D
0005435269678	9377	19	12F
0005433805477	9377	20	12G
0005433785054	9377	21	13A
0005433785053	9377	22	13F
0005433785060	9377	23	13H
0005433785070	9377	24	14A
0005433785075	9377	25	14E
0005434171005	9377	26	14D
0005435269688	9377	27	14F
0005433763250	9377	28	14H
0005433763253	9377	29	14G
0005434270191	9377	30	15B
0005434170972	9377	31	15A
0005434270200	9377	32	15D
0005433785043	9377	33	15F
0005432665281	9377	34	15E
0005433785055	9377	35	16B
0005433763256	9377	36	16E
0005434270193	9377	37	16G
0005433805497	9377	38	16H
0005433805489	9377	39	17A
0005433785042	9377	40	17B
0005433805491	9377	41	17E
0005433763246	9377	42	17H
0005433785048	9377	43	18B
0005433763252	9377	44	18D
0005433805503	9377	45	18E
0005434171037	9377	46	18F
0005433785040	9377	47	19A
0005433763255	9377	48	18H
0005433805481	9377	49	19D
0005433785071	9377	50	19F
0005433785051	9377	51	19E
0005433785063	9377	52	19G
0005432657458	9377	53	20A
0005435269703	9377	54	20D
0005432657459	9377	55	20B
0005433805496	9377	56	20F
0005434170998	9377	57	20H
0005434170955	9377	58	21D
0005433805486	9377	59	21B
0005433805499	9377	60	21E
0005433805479	9377	61	21F
0005433785041	9377	62	21H
0005434273068	9377	63	22B
0005434151679	9377	64	22D
0005434151693	9377	65	22G
0005433805488	9377	66	22H
0005435269684	9377	67	23B
0005432667461	9377	68	23E
0005434171000	9377	69	23G
0005433763245	9377	70	24B
0005433785067	9377	71	24F
0005433805480	9377	72	24G
0005435269687	9377	73	25F
0005433785046	9377	74	27E
0005433785069	9377	75	27D
0005435269698	9377	76	27F
0005434171013	9377	77	27G
0005433805504	9377	78	28A
0005433785047	9377	79	27H
0005433763254	9377	80	28F
0005433763247	9377	81	29A
0005433805487	9377	82	28H
0005433805494	9377	83	29E
0005433785073	9377	84	29D
0005433785072	9377	85	29H
0005433805492	9377	86	30D
0005435269694	9377	87	30E
0005433805495	9377	88	30G
0005433763251	9377	89	30F
0005433785058	9377	90	31A
0005432666394	9377	91	30H
0005433763244	9377	92	31B
0005433785062	9377	93	31D
0005434171002	9377	94	31F
0005433805501	9377	95	31E
0005432667460	9377	96	31H
0005433763248	9377	97	31G
0005433785050	9377	98	32A
0005433763249	9377	99	32E
0005433805490	9377	100	32G
0005433805478	9377	101	33A
0005433785065	9377	102	32H
0005433785049	9377	103	33B
0005433805484	9377	104	34F
0005433785074	9377	105	34G
0005434170950	9377	106	34H
0005433805483	9377	107	35A
0005433785064	9377	108	35H
0005433785039	9377	109	36B
0005433805485	9377	110	36A
0005433785045	9377	111	36E
0005435269690	9377	112	36D
0005435269689	9377	113	37B
0005433805482	9377	114	37E
0005433785038	9377	115	37D
0005433785057	9377	116	37F
0005434171038	9377	117	37G
0005433805505	9377	118	38A
0005434170956	9377	119	38D
0005433805500	9377	120	38B
0005433785052	9377	121	38H
0005434170963	9377	122	39F
0005434270210	26243	1	1A
0005433805019	26243	2	1B
0005433784915	26243	3	1G
0005433805255	26243	4	2A
0005433784719	26243	5	1H
0005433805094	26243	6	2B
0005433763151	26243	7	2C
0005434171102	26243	8	2F
0005433763154	26243	9	3A
0005434171103	26243	10	3F
0005435269761	26243	11	3C
0005433784616	26243	12	4A
0005433784619	26243	13	3H
0005433784615	26243	14	4B
0005433784644	26243	15	4G
0005433805144	26243	16	4F
0005433784624	26243	17	4H
0005433784614	26243	18	5B
0005434171101	26243	19	5A
0005434269108	26243	20	5F
0005433763107	26243	21	9A
0005433763127	26243	22	5H
0005433805218	26243	23	5G
0005433763093	26243	24	9B
0005433805233	26243	25	9H
0005433763103	26243	26	9G
0005433805200	26243	27	11A
0005433763160	26243	28	11B
0005435269766	26243	29	11G
0005433763123	26243	30	11H
0005433805113	26243	31	12D
0005434171100	26243	32	12G
0005433784708	26243	33	13A
0005432657431	26243	34	13D
0005433784794	26243	35	13B
0005433784820	26243	36	13F
0005433805228	26243	37	13E
0005433805143	26243	38	13G
0005433763106	26243	39	13H
0005433805051	26243	40	14B
0005434151712	26243	41	14A
0005433805083	26243	42	14D
0005433805198	26243	43	14F
0005432666372	26243	44	14G
0005434171092	26243	45	15E
0005435269765	26243	46	15D
0005433784885	26243	47	15F
0005433805179	26243	48	15G
0005433805319	26243	49	15H
0005433763156	26243	50	16D
0005432663026	26243	51	16B
0005435269762	26243	52	16E
0005434151711	26243	53	16F
0005433784822	26243	54	17A
0005433784777	26243	55	17D
0005433784713	26243	56	17E
0005433805199	26243	57	17F
0005435269763	26243	58	17H
0005433805219	26243	59	18D
0005434171093	26243	60	18G
0005433805100	26243	61	18F
0005434171091	26243	62	19A
0005433784738	26243	63	19B
0005434171095	26243	64	19F
0005433784792	26243	65	19G
0005433805190	26243	66	19H
0005433784818	26243	67	20D
0005433784645	26243	68	20F
0005433784737	26243	69	20E
0005434171097	26243	70	20H
0005433784703	26243	71	21A
0005432657438	26243	72	21E
0005432663012	26243	73	21H
0005434271316	26243	74	21G
0005433763122	26243	75	22A
0005433784790	26243	76	22D
0005433784750	26243	77	22B
0005432657430	26243	78	22E
0005433805103	26243	79	22F
0005433805079	26243	80	23A
0005433784745	26243	81	23D
0005433784757	26243	82	23F
0005434171099	26243	83	23E
0005433784819	26243	84	23G
0005433784718	26243	85	24A
0005433784788	26243	86	23H
0005433805018	26243	87	24E
0005433805189	26243	88	24F
0005433805128	26243	89	25E
0005433805050	26243	90	25D
0005433763142	26243	91	25F
0005433784766	26243	92	27D
0005433763094	26243	93	27F
0005433805101	26243	94	28A
0005433805127	26243	95	27H
0005435269760	26243	96	28B
0005435269759	26243	97	28E
0005434171096	26243	98	28D
0005433805213	26243	99	28F
0005433805171	26243	100	28H
0005433805115	26243	101	29B
0005432663025	26243	102	29A
0005432666362	26243	103	29D
0005433805266	26243	104	29E
0005433763104	26243	105	30A
0005433805175	26243	106	29H
0005433805208	26243	107	30B
0005433763115	26243	108	30F
0005435269764	26243	109	30E
0005434271317	26243	110	31A
0005433805129	26243	111	30H
0005433784765	26243	112	31D
0005434171094	26243	113	31H
0005432663018	26243	114	31G
0005433805136	26243	115	32A
0005433805254	26243	116	32B
0005433784666	26243	117	32D
0005433784884	26243	118	32F
0005432666361	26243	119	33B
0005433763050	26243	120	33A
0005434270211	26243	121	33E
0005434171090	26243	122	34A
0005433805102	26243	123	34E
0005434151713	26243	124	34G
0005433784793	26243	125	34F
0005433784789	26243	126	34H
0005433805265	26243	127	35B
0005433805170	26243	128	35G
0005433784817	26243	129	36B
0005433805320	26243	130	36A
0005433784665	26243	131	36D
0005433805126	26243	132	36G
0005433805112	26243	133	37A
0005433805227	26243	134	36H
0005433805084	26243	135	37E
0005433805321	26243	136	37D
0005434171104	26243	137	37H
0005432657439	26243	138	37G
0005432657440	26243	139	38B
0005434269107	26243	140	38E
0005434171098	26243	141	38G
0005433763051	26243	142	38H
0005435135684	4889	1	1C
0005435135682	4889	2	2A
0005435135687	4889	3	4D
0005435135686	4889	4	6D
0005435929620	4889	5	7D
0005435135685	4889	6	21D
0005435135683	4889	7	23B
0005435135642	33030	1	1B
0005435135633	33030	2	1D
0005435135637	33030	3	2B
0005435135660	33030	4	3A
0005435135638	33030	5	3D
0005435929651	33030	6	5B
0005435135659	33030	7	19B
0005435135636	33030	8	19C
0005435135643	33030	9	21B
0005435929652	33030	10	22A
0005435929650	33030	11	22D
0005435135639	33030	12	23A
0005434983304	9486	1	3A
0005434217940	9486	2	3D
0005434983302	9486	3	4A
0005434983300	9486	4	20B
0005434983301	9486	5	21A
0005434217943	9486	6	21B
0005434983303	9486	7	21C
0005434217944	9486	8	22A
0005434983266	27389	1	1A
0005434983267	27389	2	1D
0005434217981	27389	3	2A
0005434217978	27389	4	3A
0005434217980	27389	5	3B
0005434983278	27389	6	3D
0005434217982	27389	7	4B
0005434983268	27389	8	4C
0005434217979	27389	9	18C
0005434983272	27389	10	20A
0005434983262	27389	11	21A
0005434983271	27389	12	22A
0005434983269	27389	13	22C
0005433960432	24268	1	1A
0005433985513	24268	2	1B
0005433960506	24268	3	1F
0005433960521	24268	4	2B
0005433985575	24268	5	2H
0005433960424	24268	6	3B
0005433960528	24268	7	3F
0005433960341	24268	8	3H
0005433985661	24268	9	4G
0005433960520	24268	10	4H
0005433985821	24268	11	5B
0005433960563	24268	12	5F
0005433960441	24268	13	9A
0005433960429	24268	14	5H
0005433985769	24268	15	9B
0005433960416	24268	16	11E
0005433960480	24268	17	12F
0005433985674	24268	18	12H
0005433985670	24268	19	13B
0005433960550	24268	20	13A
0005433960423	24268	21	13E
0005433985603	24268	22	14B
0005433985682	24268	23	14D
0005433985530	24268	24	14H
0005433985503	24268	25	15E
0005433960246	24268	26	15G
0005433960439	24268	27	16A
0005433960417	24268	28	16E
0005433960548	24268	29	16G
0005433960421	24268	30	16F
0005433985675	24268	31	17A
0005433985578	24268	32	17D
0005433985556	24268	33	17F
0005433960426	24268	34	18A
0005433960217	24268	35	18F
0005433960512	24268	36	18E
0005433985596	24268	37	19B
0005433960549	24268	38	19E
0005433960273	24268	39	19G
0005433960278	24268	40	20A
0005433960574	24268	41	20G
0005433985519	24268	42	21D
0005433985512	24268	43	21B
0005433960351	24268	44	21E
0005433960397	24268	45	21G
0005433960450	24268	46	21F
0005433960352	24268	47	22B
0005433960069	24268	48	22A
0005433960517	24268	49	22H
0005433985555	24268	50	23D
0005433985501	24268	51	23F
0005433985601	24268	52	23E
0005433960407	24268	53	24G
0005433960303	24268	54	25D
0005433960279	24268	55	25E
0005433960518	24268	56	27D
0005433985502	24268	57	28A
0005433960481	24268	58	28E
0005433985704	24268	59	28G
0005433960551	24268	60	28H
0005433985681	24268	61	29A
0005433985815	24268	62	29D
0005433985724	24268	63	29H
0005433985683	24268	64	29G
0005433985602	24268	65	30D
0005433960513	24268	66	30F
0005433960400	24268	67	30E
0005433985653	24268	68	30H
0005433960391	24268	69	31B
0005433985725	24268	70	31F
0005433960527	24268	71	31G
0005433960111	24268	72	32A
0005433960364	24268	73	32B
0005433985703	24268	74	33A
0005433985574	24268	75	32H
0005433985742	24268	76	33D
0005433985750	24268	77	33G
0005433985669	24268	78	34B
0005433960274	24268	79	34A
0005433985319	24268	80	34D
0005433985768	24268	81	34E
0005433960442	24268	82	34F
0005433985734	24268	83	35B
0005433985579	24268	84	35F
0005433985518	24268	85	35G
0005433985738	24268	86	36A
0005433985593	24268	87	36F
0005433960475	24268	88	36E
0005433985834	24268	89	37A
0005433960402	24268	90	36H
0005433960552	24268	91	37B
0005433960505	24268	92	37D
0005433960399	24268	93	38E
0005433985757	24268	94	38F
0005433985604	24268	95	38G
0005433960366	24268	96	39D
0005433960340	24268	97	39F
0005433986031	25908	1	1A
0005433986060	25908	2	1G
0005433986030	25908	3	1F
0005433986066	25908	4	2F
0005433961008	25908	5	2C
0005433961016	25908	6	2H
0005433961029	25908	7	2G
0005433960991	25908	8	3C
0005433961000	25908	9	4B
0005433986064	25908	10	4A
0005433986036	25908	11	5A
0005433960990	25908	12	5F
0005433986040	25908	13	9G
0005433986044	25908	14	11A
0005433986071	25908	15	9H
0005433961032	25908	16	11B
0005433986061	25908	17	11F
0005433986043	25908	18	11H
0005433961002	25908	19	12D
0005433961011	25908	20	12G
0005433960994	25908	21	12H
0005433986035	25908	22	13A
0005433986051	25908	23	13D
0005433961010	25908	24	13B
0005433961003	25908	25	13E
0005433960992	25908	26	13G
0005433960998	25908	27	14H
0005433986041	25908	28	15D
0005433986047	25908	29	15H
0005433986042	25908	30	15G
0005433961021	25908	31	16E
0005433986055	25908	32	16H
0005433960997	25908	33	17B
0005433986027	25908	34	17E
0005433986046	25908	35	17F
0005433960981	25908	36	18A
0005433960988	25908	37	17H
0005433961024	25908	38	18B
0005433961001	25908	39	18F
0005433986039	25908	40	19E
0005433986029	25908	41	19G
0005433961006	25908	42	20A
0005433960976	25908	43	19H
0005433960974	25908	44	20B
0005433961022	25908	45	21A
0005433961023	25908	46	21D
0005433961004	25908	47	21E
0005433960978	25908	48	21G
0005433986062	25908	49	22B
0005433961030	25908	50	22F
0005433961018	25908	51	22G
0005433986065	25908	52	23A
0005433986034	25908	53	23B
0005433961028	25908	54	23D
0005433960996	25908	55	23F
0005433960985	25908	56	23G
0005433986037	25908	57	24A
0005433986057	25908	58	23H
0005433961009	25908	59	24B
0005433961015	25908	60	24E
0005433961013	25908	61	25D
0005433986049	25908	62	24H
0005433986068	25908	63	25F
0005433960995	25908	64	27A
0005433961031	25908	65	27F
0005433960999	25908	66	27H
0005433960993	25908	67	28B
0005433960980	25908	68	28E
0005433961005	25908	69	28F
0005433960979	25908	70	28H
0005433986058	25908	71	29B
0005433961014	25908	72	29A
0005433986063	25908	73	29E
0005433961017	25908	74	29D
0005433986073	25908	75	29G
0005433961007	25908	76	29F
0005433960989	25908	77	30B
0005433961033	25908	78	31D
0005433986052	25908	79	31G
0005433960984	25908	80	32B
0005433986050	25908	81	32D
0005433986028	25908	82	32F
0005433961026	25908	83	33A
0005433960977	25908	84	32H
0005433986054	25908	85	33B
0005433986075	25908	86	33E
0005433986072	25908	87	33D
0005433960987	25908	88	33F
0005433986033	25908	89	33H
0005433986045	25908	90	34B
0005433961019	25908	91	34D
0005433986069	25908	92	34E
0005433961027	25908	93	34F
0005433960982	25908	94	34H
0005433961020	25908	95	35A
0005433986067	25908	96	35D
0005433986048	25908	97	35F
0005433986053	25908	98	35E
0005433986070	25908	99	36A
0005433960975	25908	100	36B
0005433961025	25908	101	36D
0005433986074	25908	102	36H
0005433986032	25908	103	37A
0005433961012	25908	104	37B
0005433986059	25908	105	37E
0005433960983	25908	106	37F
0005433960986	25908	107	37G
0005433986038	25908	108	38H
0005433986056	25908	109	39F
0005434480406	920	1	1A
0005434480395	920	2	1B
0005434480408	920	3	1C
0005434480404	920	4	2A
0005434480400	920	5	2B
0005434480412	920	6	3A
0005434480413	920	7	3B
0005433165862	920	8	4A
0005434480394	920	9	4B
0005432269502	920	10	4C
0005434480402	920	11	5A
0005433165882	920	12	5B
0005434480415	920	13	5C
0005434480398	920	14	5D
0005434480397	920	15	6A
0005433165823	920	16	6C
0005434480418	920	17	6D
0005434480399	920	18	7A
0005434480407	920	19	7B
0005434480414	920	20	7C
0005434480405	920	21	18A
0005434480396	920	22	18C
0005434480416	920	23	18D
0005433165861	920	24	19A
0005434480410	920	25	19B
0005433165887	920	26	19C
0005433165883	920	27	19D
0005434480401	920	28	20A
0005434480411	920	29	20B
0005433165886	920	30	20C
0005432269503	920	31	20D
0005432269504	920	32	21A
0005434480417	920	33	21B
0005434480409	920	34	21C
0005433165822	920	35	21D
0005434480393	920	36	22A
0005432269505	920	37	22D
0005434480403	920	38	23B
0005434480226	16606	1	1A
0005434480246	16606	2	1B
0005434480245	16606	3	1C
0005433165945	16606	4	1D
0005434480276	16606	5	2B
0005433165947	16606	6	2D
0005434480117	16606	7	3A
0005434480178	16606	8	3B
0005434480252	16606	9	3C
0005433165940	16606	10	3D
0005434480107	16606	11	4A
0005434480182	16606	12	4B
0005434480201	16606	13	4C
0005434480288	16606	14	5A
0005434480202	16606	15	5B
0005434480285	16606	16	5C
0005433165937	16606	17	5D
0005433165942	16606	18	6B
0005434480197	16606	19	6C
0005433165944	16606	20	6D
0005434480163	16606	21	7A
0005434479983	16606	22	7B
0005433165941	16606	23	18A
0005434480164	16606	24	18C
0005433165943	16606	25	18D
0005433165949	16606	26	19A
0005434480242	16606	27	19B
0005434480122	16606	28	19C
0005434480181	16606	29	20A
0005434480251	16606	30	20B
0005434480199	16606	31	20C
0005434480143	16606	32	20D
0005433165948	16606	33	21B
0005434480121	16606	34	21C
0005433165938	16606	35	21D
0005433165946	16606	36	22A
0005434480144	16606	37	22B
0005433165939	16606	38	22C
0005433165936	16606	39	22D
0005434480243	16606	40	23A
0005435150063	10375	1	1A
0005435142599	10375	2	1C
0005435150059	10375	3	2A
0005435142606	10375	4	2B
0005433289811	10375	5	2C
0005435142608	10375	6	2D
0005435150064	10375	7	3A
0005435150058	10375	8	3B
0005435386518	10375	9	3C
0005435142611	10375	10	4A
0005435150062	10375	11	4B
0005435142607	10375	12	4C
0005435150056	10375	13	5A
0005435150053	10375	14	5B
0005435142602	10375	15	5C
0005435386505	10375	16	5D
0005435150065	10375	17	6C
0005435386543	10375	18	6D
0005435142600	10375	19	7A
0005435150060	10375	20	7B
0005435142603	10375	21	7C
0005435142605	10375	22	7D
0005433289813	10375	23	18A
0005435150055	10375	24	18B
0005433289797	10375	25	18C
0005435150061	10375	26	19A
0005435150054	10375	27	19C
0005435150052	10375	28	19B
0005435142610	10375	29	19D
0005435142612	10375	30	20C
0005435150057	10375	31	20D
0005433289779	10375	32	21B
0005433289816	10375	33	21C
0005435142601	10375	34	21D
0005435142604	10375	35	22A
0005435142609	10375	36	22B
0005435386532	10375	37	22C
0005433289812	10375	38	23A
0005435386591	21941	1	1A
0005435149953	21941	2	1C
0005435142484	21941	3	1D
0005433289880	21941	4	2A
0005433289878	21941	5	2B
0005435142521	21941	6	2C
0005435386592	21941	7	2D
0005435142408	21941	8	3A
0005435142570	21941	9	3B
0005435142520	21941	10	3C
0005435150001	21941	11	3D
0005435142522	21941	12	4B
0005433289875	21941	13	4C
0005435142498	21941	14	4D
0005435149912	21941	15	5A
0005433289876	21941	16	5B
0005435149954	21941	17	6A
0005435149928	21941	18	6B
0005435149926	21941	19	6C
0005435386590	21941	20	6D
0005435386588	21941	21	7A
0005433289877	21941	22	7B
0005435149942	21941	23	7C
0005433289874	21941	24	18A
0005435142472	21941	25	7D
0005433289879	21941	26	18B
0005435386594	21941	27	18C
0005435142485	21941	28	19A
0005435149951	21941	29	19C
0005435149913	21941	30	19B
0005435142428	21941	31	20A
0005435142482	21941	32	20B
0005435142483	21941	33	20C
0005435142486	21941	34	20D
0005435386587	21941	35	21A
0005435142519	21941	36	21B
0005435386589	21941	37	21C
0005433289873	21941	38	21D
0005435142473	21941	39	22A
0005435386593	21941	40	22B
0005435150000	21941	41	22D
0005435142569	21941	42	23B
0005435319518	11188	1	1A
0005434573386	11188	2	1C
0005435529199	11188	3	1D
0005435502233	11188	4	1F
0005435502118	11188	5	2A
0005435502180	11188	6	2C
0005435319554	11188	7	2D
0005435502193	11188	8	2F
0005435502132	11188	9	3A
0005435502240	11188	10	3C
0005435502179	11188	11	3D
0005435529181	11188	12	4A
0005435502107	11188	13	4C
0005435502299	11188	14	4D
0005435502300	11188	15	4E
0005435502241	11188	16	4F
0005435529095	11188	17	5A
0005435502192	11188	18	5C
0005434573387	11188	19	5D
0005434573376	11188	20	5E
0005435319522	11188	21	5F
0005435319555	11188	22	6A
0005434573385	11188	23	6C
0005435545657	11188	24	6D
0005434573375	11188	25	6E
0005435529087	11188	26	6F
0005435502206	11188	27	7A
0005434573382	11188	28	7C
0005435502225	11188	29	7D
0005435529198	11188	30	7E
0005435529096	11188	31	7F
0005435502215	11188	32	8A
0005435502176	11188	33	8C
0005435529039	11188	34	8D
0005435319521	11188	35	8E
0005435545684	11188	36	8F
0005435502242	11188	37	9A
0005435502272	11188	38	9C
0005435545673	11188	39	9D
0005435319520	11188	40	9E
0005435502175	11188	41	9F
0005434573380	11188	42	10A
0005435319502	11188	43	10C
0005435502209	11188	44	10D
0005435502260	11188	45	10E
0005435529141	11188	46	10F
0005435502146	11188	47	11A
0005434573383	11188	48	11C
0005435319517	11188	49	11D
0005435529239	11188	50	11F
0005435529200	11188	51	12A
0005435545683	11188	52	12C
0005434573389	11188	53	12D
0005435319534	11188	54	12E
0005435502203	11188	55	13A
0005435502254	11188	56	12F
0005434573377	11188	57	13C
0005435319564	11188	58	13D
0005435319546	11188	59	13E
0005434573381	11188	60	13F
0005435319535	11188	61	14A
0005435502204	11188	62	14C
0005435502157	11188	63	14D
0005435502119	11188	64	14E
0005435502189	11188	65	14F
0005435319523	11188	66	15A
0005435502220	11188	67	15C
0005435502271	11188	68	15D
0005435529201	11188	69	15E
0005435502183	11188	70	15F
0005435529061	11188	71	16A
0005434573379	11188	72	16C
0005435529142	11188	73	16E
0005435502182	11188	74	16F
0005435319516	11188	75	17A
0005435502207	11188	76	17C
0005435529122	11188	77	17E
0005435319532	11188	78	18A
0005435545692	11188	79	17F
0005435319553	11188	80	18C
0005435502277	11188	81	18D
0005434573378	11188	82	18F
0005435502145	11188	83	19A
0005435319533	11188	84	19C
0005435529128	11188	85	19E
0005435319565	11188	86	19F
0005435502188	11188	87	20A
0005435545668	11188	88	20C
0005434573388	11188	89	20D
0005434573384	11188	90	20E
0005435502216	11188	91	20F
0005435508392	20924	1	1A
0005434573272	20924	2	1C
0005435517953	20924	3	1D
0005435517955	20924	4	1F
0005435502373	20924	5	2A
0005434573200	20924	6	2C
0005435319609	20924	7	2D
0005435502354	20924	8	3C
0005435319605	20924	9	3D
0005435517956	20924	10	3F
0005435502364	20924	11	4A
0005435319606	20924	12	4F
0005435502370	20924	13	5A
0005435517958	20924	14	5C
0005435517948	20924	15	5E
0005435502358	20924	16	5F
0005435502372	20924	17	6C
0005435319611	20924	18	6D
0005435517947	20924	19	6E
0005434573247	20924	20	7A
0005435502368	20924	21	7D
0005435319610	20924	22	8A
0005435502361	20924	23	8C
0005435517950	20924	24	8F
0005435502365	20924	25	9A
0005435502355	20924	26	9C
0005435508393	20924	27	10C
0005435502353	20924	28	10D
0005432291937	20924	29	10E
0005435502369	20924	30	10F
0005435517954	20924	31	11A
0005434573250	20924	32	11C
0005434573225	20924	33	11D
0005435502360	20924	34	11E
0005435517951	20924	35	11F
0005435502363	20924	36	12C
0005435319613	20924	37	12D
0005435502357	20924	38	12E
0005435502352	20924	39	12F
0005435517946	20924	40	13A
0005435502362	20924	41	13C
0005435319607	20924	42	13E
0005434573263	20924	43	13F
0005434573204	20924	44	14A
0005435517957	20924	45	14C
0005432291935	20924	46	15A
0005435517960	20924	47	15C
0005435508394	20924	48	15E
0005434573222	20924	49	16A
0005435502359	20924	50	16C
0005435319612	20924	51	16F
0005435502371	20924	52	17A
0005435502374	20924	53	17C
0005435517952	20924	54	17F
0005434573199	20924	55	18A
0005432291936	20924	56	18C
0005435502356	20924	57	18E
0005434573246	20924	58	19A
0005435517949	20924	59	19D
0005435517959	20924	60	19E
0005435502367	20924	61	19F
0005435319608	20924	62	20C
0005435502366	20924	63	20D
0005435319614	20924	64	20F
0005432692963	2976	1	1A
0005432692976	2976	2	1F
0005432692922	2976	3	2A
0005432693015	2976	4	2F
0005432692989	2976	5	3C
0005432692849	2976	6	3D
0005432692951	2976	7	3F
0005432692850	2976	8	5A
0005432692967	2976	9	5C
0005432692887	2976	10	5E
0005432692942	2976	11	5F
0005432692837	2976	12	6A
0005432692805	2976	13	6C
0005432692819	2976	14	6D
0005432692856	2976	15	7E
0005432692843	2976	16	7F
0005432692886	2976	17	8C
0005432692874	2976	18	8D
0005432692855	2976	19	8E
0005432692851	2976	20	8F
0005432692806	2976	21	9A
0005432692959	2976	22	9C
0005432692943	2976	23	11A
0005432692899	2976	24	11C
0005432692961	2976	25	11D
0005432692962	2976	26	12E
0005432692932	2976	27	13C
0005432692958	2976	28	13D
0005432692818	2976	29	14A
0005432692988	2976	30	14C
0005432692902	2976	31	15A
0005432692901	2976	32	16C
0005432692844	2976	33	17A
0005432692838	2976	34	17C
0005432693014	2976	35	17D
0005432692950	2976	36	17F
0005432692845	2976	37	18E
0005432692957	2976	38	19D
0005432693013	2976	39	19F
0005432692956	2976	40	20E
0005432692968	2976	41	20F
0005432706853	2977	1	1D
0005432880730	2977	2	1F
0005433123795	2977	3	2A
0005433123840	2977	4	2D
0005433194840	2977	5	3A
0005432217783	2977	6	3C
0005432880691	2977	7	3F
0005433123788	2977	8	4A
0005432706847	2977	9	4C
0005432706833	2977	10	4F
0005432706856	2977	11	5A
0005433123815	2977	12	5E
0005433123737	2977	13	5F
0005433123799	2977	14	6A
0005433194837	2977	15	6D
0005432706842	2977	16	6E
0005432880757	2977	17	6F
0005433194839	2977	18	7A
0005433123746	2977	19	7E
0005432880741	2977	20	7F
0005432706851	2977	21	8C
0005432706854	2977	22	8E
0005432706843	2977	23	9A
0005432706835	2977	24	9C
0005432880758	2977	25	9D
0005432880765	2977	26	9E
0005433123829	2977	27	9F
0005433123745	2977	28	10A
0005433123804	2977	29	10C
0005432880731	2977	30	10E
0005432706841	2977	31	11A
0005432706857	2977	32	11D
0005432706850	2977	33	11E
0005433123830	2977	34	11F
0005432880694	2977	35	12A
0005432706837	2977	36	12D
0005432706844	2977	37	13A
0005432706858	2977	38	13E
0005432880745	2977	39	13F
0005432880692	2977	40	14A
0005433123811	2977	41	14D
0005432706849	2977	42	14F
0005433123806	2977	43	15C
0005432217785	2977	44	15D
0005432880720	2977	45	15E
0005432706836	2977	46	15F
0005432706834	2977	47	16A
0005432706846	2977	48	16E
0005432217784	2977	49	17A
0005432880689	2977	50	17C
0005433123787	2977	51	17D
0005432706832	2977	52	17E
0005432706839	2977	53	17F
0005432706838	2977	54	18C
0005432706848	2977	55	18F
0005432706855	2977	56	19A
0005432880744	2977	57	19D
0005432706852	2977	58	19E
0005432706845	2977	59	19F
0005433123814	2977	60	20A
0005432706840	2977	61	20E
0005432706831	2977	62	20F
0005433123985	29990	1	1A
0005432880853	29990	2	1C
0005432706580	29990	3	1D
0005433123980	29990	4	1F
0005432706638	29990	5	2A
0005432706696	29990	6	2C
0005432693167	29990	7	2D
0005432880858	29990	8	2F
0005432693181	29990	9	3A
0005433123988	29990	10	3C
0005432706636	29990	11	3D
0005433123974	29990	12	3F
0005432706650	29990	13	4A
0005432693185	29990	14	4C
0005432880859	29990	15	4D
0005432693188	29990	16	4E
0005433123984	29990	17	4F
0005433123981	29990	18	5A
0005432706719	29990	19	5C
0005432706583	29990	20	5D
0005433123979	29990	21	5E
0005433123982	29990	22	5F
0005432706752	29990	23	6C
0005432706592	29990	24	6D
0005432880860	29990	25	6E
0005432693179	29990	26	6F
0005432706613	29990	27	7A
0005432706721	29990	28	7C
0005433123978	29990	29	7D
0005432693183	29990	30	7E
0005432706692	29990	31	7F
0005432706759	29990	32	8A
0005432693162	29990	33	8C
0005433123986	29990	34	8D
0005432880857	29990	35	8E
0005432706718	29990	36	8F
0005432693187	29990	37	9A
0005432706712	29990	38	9C
0005432693178	29990	39	9D
0005432693170	29990	40	9E
0005433123975	29990	41	9F
0005432880856	29990	42	10A
0005432880852	29990	43	10C
0005432693182	29990	44	10D
0005432880855	29990	45	10E
0005432706695	29990	46	10F
0005432693176	29990	47	11A
0005432706637	29990	48	11C
0005432706582	29990	49	11D
0005433123983	29990	50	11E
0005432693159	29990	51	11F
0005432693160	29990	52	12A
0005432693174	29990	53	12C
0005432693172	29990	54	12D
0005432693161	29990	55	12E
0005432706693	29990	56	12F
0005432706671	29990	57	13A
0005432706670	29990	58	13C
0005432706672	29990	59	13D
0005432706591	29990	60	13E
0005432706716	29990	61	13F
0005432693164	29990	62	14A
0005432706469	29990	63	14C
0005432693166	29990	64	14D
0005432706615	29990	65	14E
0005432706456	29990	66	14F
0005432693169	29990	67	15A
0005432880861	29990	68	15C
0005432706617	29990	69	15D
0005432880864	29990	70	15E
0005432693189	29990	71	15F
0005432693175	29990	72	16A
0005432693168	29990	73	16C
0005432880863	29990	74	16D
0005432693163	29990	75	16E
0005432880866	29990	76	16F
0005432706639	29990	77	17A
0005433123977	29990	78	17C
0005432693171	29990	79	17D
0005432693180	29990	80	17E
0005432693173	29990	81	17F
0005433123989	29990	82	18A
0005432880862	29990	83	18C
0005432693177	29990	84	18D
0005433123976	29990	85	18E
0005432706576	29990	86	18F
0005432693186	29990	87	19A
0005432706715	29990	88	19C
0005432880865	29990	89	19D
0005432693165	29990	90	19E
0005432706711	29990	91	19F
0005432706614	29990	92	20A
0005432693184	29990	93	20C
0005433123987	29990	94	20D
0005432706457	29990	95	20E
0005432880854	29990	96	20F
0005434988773	23663	1	1A
0005434979851	23663	2	1B
0005434979848	23663	3	1C
0005434979866	23663	4	1D
0005434979837	23663	5	2A
0005434979843	23663	6	2B
0005434988775	23663	7	2C
0005434988764	23663	8	2D
0005434979861	23663	9	3A
0005434979860	23663	10	3B
0005434979840	23663	11	3C
0005434979863	23663	12	3D
0005434979852	23663	13	4B
0005434988766	23663	14	4D
0005434979846	23663	15	5A
0005434979856	23663	16	5B
0005434988771	23663	17	5D
0005434979839	23663	18	6A
0005434979854	23663	19	6B
0005434979850	23663	20	6C
0005434979864	23663	21	6D
0005434979845	23663	22	7A
0005434979855	23663	23	7B
0005434988770	23663	24	7C
0005434979844	23663	25	7D
0005434988765	23663	26	18A
0005434979853	23663	27	18B
0005434979858	23663	28	18C
0005434988767	23663	29	18D
0005434979841	23663	30	19A
0005434988776	23663	31	19B
0005434988768	23663	32	19C
0005434988774	23663	33	19D
0005434979862	23663	34	20A
0005434988763	23663	35	20C
0005434979859	23663	36	20D
0005434979847	23663	37	21A
0005434979857	23663	38	21C
0005434979865	23663	39	21D
0005434988772	23663	40	22A
0005434979842	23663	41	22C
0005434988769	23663	42	22D
0005434979849	23663	43	23A
0005434979838	23663	44	23B
0005434979532	27528	1	1C
0005434979550	27528	2	1D
0005434979548	27528	3	2A
0005434988659	27528	4	2C
0005434988641	27528	5	2B
0005434979549	27528	6	2D
0005434979536	27528	7	3A
0005434988650	27528	8	3B
0005434979551	27528	9	3C
0005434988666	27528	10	3D
0005434979607	27528	11	4A
0005434979616	27528	12	4B
0005434979602	27528	13	4C
0005434979653	27528	14	5A
0005434979597	27528	15	5B
0005434979771	27528	16	5C
0005434979541	27528	17	5D
0005434979566	27528	18	6B
0005434979534	27528	19	6C
0005434988660	27528	20	6D
0005434979509	27528	21	7A
0005434979537	27528	22	7B
0005434979497	27528	23	7C
0005434979664	27528	24	7D
0005434979577	27528	25	18A
0005434988661	27528	26	18B
0005434979763	27528	27	18C
0005434988664	27528	28	19A
0005434979538	27528	29	19B
0005434979552	27528	30	19C
0005434979503	27528	31	19D
0005434979542	27528	32	20B
0005434979568	27528	33	20C
0005434979762	27528	34	20D
0005434979533	27528	35	21A
0005434979539	27528	36	21B
0005434979603	27528	37	21C
0005434979540	27528	38	21D
0005434979615	27528	39	22A
0005434979518	27528	40	22B
0005434979684	27528	41	22C
0005434979654	27528	42	22D
0005434988646	27528	43	23A
0005434979513	27528	44	23B
0005433113517	10278	1	3A
0005433113525	10278	2	4B
0005434302468	10278	3	5B
0005434302467	10278	4	5C
0005434302471	10278	5	5D
0005434302469	10278	6	18A
0005433113526	10278	7	19B
0005434302470	10278	8	19D
0005433113518	10278	9	20B
0005434302422	19643	1	2A
0005434302424	19643	2	3B
0005434302434	19643	3	4C
0005433113543	19643	4	5A
0005434302433	19643	5	6A
0005433113542	19643	6	6D
0005434302423	19643	7	18A
0005434302421	19643	8	20D
0005435069221	3563	1	1D
0005435069257	3563	2	1F
0005435069247	3563	3	2A
0005435925260	3563	4	2C
0005435069230	3563	5	2D
0005435069250	3563	6	2F
0005435069238	3563	7	3A
0005435069235	3563	8	3C
0005435069254	3563	9	4A
0005435069259	3563	10	4C
0005435069220	3563	11	4D
0005435069260	3563	12	4E
0005435925225	3563	13	5A
0005435069266	3563	14	5C
0005435718967	3563	15	5D
0005435069244	3563	16	5E
0005435069255	3563	17	5F
0005435939867	3563	18	6A
0005435718968	3563	19	6C
0005435069236	3563	20	6D
0005435069227	3563	21	6E
0005435069267	3563	22	7A
0005435939866	3563	23	7C
0005435069239	3563	24	7D
0005435069252	3563	25	7E
0005435069229	3563	26	7F
0005435069222	3563	27	8A
0005435925220	3563	28	8D
0005435069226	3563	29	8F
0005435069231	3563	30	8E
0005435069248	3563	31	9A
0005435069240	3563	32	9D
0005435069269	3563	33	9E
0005435069258	3563	34	9F
0005435069265	3563	35	10C
0005435718964	3563	36	10D
0005435069249	3563	37	11A
0005435718966	3563	38	11C
0005435069218	3563	39	11D
0005435718970	3563	40	11E
0005435069261	3563	41	12A
0005435925253	3563	42	12C
0005435069246	3563	43	12D
0005435069242	3563	44	12E
0005435069237	3563	45	12F
0005435925105	3563	46	13A
0005435925237	3563	47	13C
0005435718965	3563	48	13D
0005435925241	3563	49	13E
0005435069224	3563	50	13F
0005435069232	3563	51	14C
0005435718963	3563	52	14E
0005435718969	3563	53	15A
0005435069270	3563	54	15C
0005435925238	3563	55	15D
0005435069241	3563	56	15E
0005435925219	3563	57	15F
0005435939873	3563	58	16A
0005435069268	3563	59	16C
0005435069256	3563	60	16D
0005435069262	3563	61	16E
0005435718962	3563	62	16F
0005435069243	3563	63	17A
0005435925214	3563	64	17C
0005435069233	3563	65	17D
0005435069223	3563	66	17E
0005435069263	3563	67	17F
0005435925180	3563	68	18A
0005435069234	3563	69	18C
0005435069253	3563	70	18E
0005435069225	3563	71	19A
0005435069271	3563	72	19C
0005435925240	3563	73	19D
0005435069264	3563	74	19E
0005435925203	3563	75	19F
0005435069245	3563	76	20A
0005435069251	3563	77	20C
0005435069228	3563	78	20E
0005435069219	3563	79	20F
0005435925326	15307	1	1A
0005435068671	15307	2	1F
0005435925325	15307	3	2A
0005435068750	15307	4	3A
0005435068613	15307	5	3C
0005435068670	15307	6	3D
0005435069034	15307	7	4A
0005435939885	15307	8	4C
0005435068768	15307	9	4F
0005435068533	15307	10	5C
0005435939884	15307	11	5D
0005435925337	15307	12	5E
0005435068943	15307	13	5F
0005435068738	15307	14	6A
0005435939883	15307	15	6D
0005435068724	15307	16	6E
0005435925340	15307	17	7A
0005435068782	15307	18	7C
0005435068532	15307	19	7E
0005435068843	15307	20	7F
0005435068924	15307	21	8C
0005435068676	15307	22	8D
0005435068836	15307	23	9C
0005435068780	15307	24	10A
0005435068553	15307	25	10C
0005435068342	15307	26	10D
0005435068781	15307	27	10E
0005435068698	15307	28	10F
0005435068727	15307	29	11C
0005435925327	15307	30	11E
0005435925339	15307	31	12A
0005435068753	15307	32	12C
0005435068587	15307	33	12D
0005435068697	15307	34	12E
0005435068927	15307	35	12F
0005435925334	15307	36	13A
0005435068483	15307	37	13E
0005435925338	15307	38	13D
0005435068751	15307	39	14A
0005435068769	15307	40	14C
0005435068612	15307	41	14D
0005435068729	15307	42	14F
0005435068723	15307	43	15A
0005435068823	15307	44	15C
0005435925329	15307	45	15D
0005435068916	15307	46	15E
0005435068735	15307	47	15F
0005435925333	15307	48	16A
0005435925328	15307	49	16C
0005435068594	15307	50	17A
0005435068465	15307	51	17C
0005435925335	15307	52	17D
0005435068730	15307	53	17F
0005435068607	15307	54	18A
0005435068923	15307	55	18C
0005435925331	15307	56	19C
0005435068779	15307	57	19D
0005435068728	15307	58	19E
0005435925330	15307	59	20A
0005435925332	15307	60	20C
0005435068595	15307	61	20D
0005435925336	15307	62	20E
0005432659712	18197	1	1A
0005432658597	18197	2	1B
0005432658598	18197	3	2B
0005432658596	18197	4	2A
0005432659714	18197	5	3A
0005432659711	18197	6	3B
0005432659713	18197	7	4B
0005432660824	18197	8	5A
0005432660823	18197	9	6A
0005432667441	26360	1	4B
0005432664120	26360	2	5A
0005432660804	26360	3	5B
0005432660805	26360	4	6A
0005433101885	2	1	1F
0005433101832	2	2	1D
0005433101689	2	3	2C
0005433101879	2	4	3D
0005433101883	2	5	4D
0005433101867	2	6	4C
0005432157499	2	7	4A
0005433101934	2	8	5C
0005433101684	2	9	5D
0005433101784	2	10	6A
0005433101736	2	11	6D
0005433101892	2	12	6F
0005432901540	2	13	7C
0005432919745	2	14	7F
0005433101770	2	15	8B
0005432919786	2	16	8D
0005432919789	2	17	8C
0005432901523	2	18	8F
0005432901442	2	19	9B
0005432901443	2	20	9C
0005433101886	2	21	9F
0005432901510	2	22	10A
0005433101839	2	23	10B
0005433101919	2	24	10C
0005432901482	2	25	10E
0005433101688	2	26	11B
0005432901522	2	27	11C
0005433101877	2	28	11D
0005432901543	2	29	11F
0005433101865	2	30	12A
0005433101739	2	31	12C
0005433101918	2	32	12D
0005433101893	2	33	12E
0005433101794	2	34	12F
0005433101852	2	35	13A
0005432901608	2	36	13E
0005433101903	2	37	13D
0005432901538	2	38	13F
0005432901512	2	39	15C
0005432919744	2	40	15D
0005433101911	2	41	15E
0005432919743	2	42	16A
0005432919738	2	43	16B
0005433101866	2	44	16D
0005432919741	2	45	17A
0005432919787	2	46	16F
0005433101829	2	47	17D
0005433101838	2	48	18A
0005432919774	2	49	17F
0005432901539	2	50	18B
0005433101719	2	51	18F
0005433101710	2	52	19C
0005432919765	2	53	19D
0005432919771	2	54	19E
0005432919714	2	55	20B
0005432901497	2	56	20A
0005433101887	2	57	21A
0005433101798	2	58	21C
0005432919821	2	59	21B
0005433101796	2	60	21D
0005432919794	2	61	22A
0005433101708	2	62	22C
0005432919688	2	63	22F
0005432919742	2	64	23A
0005432901483	2	65	23F
0005433101874	2	66	23E
0005432919740	2	67	24B
0005432677539	2	68	24A
0005432901496	2	69	24E
0005432919812	2	70	24D
0005433101895	2	71	25A
0005433101709	2	72	24F
0005432919730	2	73	25B
0005432157498	2	74	25C
0005433101938	2	75	25D
0005432901511	2	76	26B
0005433101801	2	77	26C
0005433101763	2	78	26D
0005433101840	2	79	27A
0005433101935	2	80	27B
0005432919729	2	81	27D
0005432901609	2	82	27F
0005432919820	2	83	27E
0005433101718	2	84	28A
0005433101875	2	85	28C
0005432157497	2	86	28B
0005432919767	2	87	28D
0005433101822	2	88	28E
0005433101855	2	89	28F
0005433101850	2	90	29A
0005432919716	2	91	29C
0005433101884	2	92	29E
0005433101797	2	93	29F
0005432901567	2	94	30C
0005432901568	2	95	30E
0005432919775	2	96	30D
0005433101881	2	97	30F
0005433101740	2	98	31A
0005433101864	2	99	31C
0005432919819	2	100	31B
0005432919715	2	101	31F
0005432817568	3	1	1D
0005432207667	3	2	1C
0005432817559	3	3	2C
0005432817560	3	4	2F
0005432817573	3	5	3A
0005432753271	3	6	3D
0005433687684	3	7	4A
0005432817558	3	8	4C
0005432817547	3	9	4D
0005432817564	3	10	5A
0005432753272	3	11	4F
0005432262047	3	12	5D
0005432817561	3	13	5F
0005433687681	3	14	7A
0005432262061	3	15	7C
0005432262057	3	16	8C
0005432262027	3	17	8E
0005432817563	3	18	8D
0005432262031	3	19	8F
0005432262042	3	20	9A
0005432262054	3	21	9B
0005432817570	3	22	9E
0005432262046	3	23	9D
0005432288995	3	24	10A
0005432817549	3	25	9F
0005432817566	3	26	10C
0005432753265	3	27	10B
0005432262059	3	28	10E
0005432262035	3	29	10F
0005432262064	3	30	11E
0005432262048	3	31	12C
0005432262025	3	32	12B
0005432262034	3	33	12D
0005432262051	3	34	12F
0005432262068	3	35	13B
0005432262063	3	36	13C
0005432288994	3	37	13D
0005432262045	3	38	14A
0005433687685	3	39	15C
0005432262053	3	40	15F
0005432262032	3	41	16A
0005432262026	3	42	16D
0005432262036	3	43	16F
0005432262069	3	44	17B
0005432262039	3	45	17C
0005432262024	3	46	17D
0005432753269	3	47	18A
0005433690911	3	48	18C
0005432817567	3	49	18E
0005432817572	3	50	18D
0005432262044	3	51	18F
0005432817565	3	52	19C
0005432817574	3	53	20A
0005432262058	3	54	19E
0005432817562	3	55	20B
0005432753296	3	56	20D
0005432817575	3	57	21B
0005432817546	3	58	21C
0005432262033	3	59	21E
0005432262050	3	60	22B
0005432262049	3	61	22A
0005432817556	3	62	23B
0005432262029	3	63	23A
0005433690909	3	64	23D
0005432817555	3	65	23C
0005432262041	3	66	24D
0005432262055	3	67	24C
0005432817557	3	68	24E
0005432262066	3	69	24F
0005432262043	3	70	25B
0005432262067	3	71	25A
0005432262040	3	72	25E
0005432262056	3	73	25D
0005432262060	3	74	25F
0005432262038	3	75	26B
0005433687682	3	76	26C
0005432262070	3	77	26E
0005432756829	3	78	26F
0005432817553	3	79	27C
0005432262065	3	80	27D
0005432262062	3	81	27F
0005432262052	3	82	27E
0005432817552	3	83	28A
0005432207666	3	84	28C
0005432207668	3	85	29A
0005432288997	3	86	29C
0005432817551	3	87	29B
0005432817554	3	88	29E
0005432817569	3	89	30A
0005432262037	3	90	30C
0005432262030	3	91	30D
0005432817548	3	92	30F
0005432817550	3	93	30E
0005432262028	3	94	31B
0005432288996	3	95	31A
0005433690910	3	96	31D
0005432817571	3	97	31E
0005432020342	8097	1	1A
0005433102309	8097	2	1C
0005433102338	8097	3	1D
0005433102339	8097	4	2C
0005432919910	8097	5	2D
0005433102333	8097	6	3A
0005432919930	8097	7	3D
0005432392007	8097	8	3C
0005432020337	8097	9	4A
0005432919911	8097	10	3F
0005432045619	8097	11	4F
0005433102299	8097	12	4D
0005432751538	8097	13	5D
0005433102317	8097	14	6C
0005432045620	8097	15	6F
0005433102304	8097	16	7C
0005433102296	8097	17	8A
0005433102328	8097	18	7F
0005433102320	8097	19	8B
0005432020348	8097	20	8E
0005433102312	8097	21	9A
0005432392009	8097	22	10A
0005433102307	8097	23	10B
0005432919918	8097	24	10C
0005432919915	8097	25	10E
0005433102335	8097	26	10F
0005433102295	8097	27	11A
0005432919921	8097	28	11C
0005432020336	8097	29	11B
0005432020339	8097	30	11D
0005432919919	8097	31	11F
0005432677585	8097	32	11E
0005432020331	8097	33	12A
0005433102336	8097	34	12B
0005432919917	8097	35	12E
0005432919922	8097	36	12D
0005433102306	8097	37	12F
0005432753312	8097	38	13C
0005432020349	8097	39	13B
0005433102313	8097	40	13D
0005433102301	8097	41	13E
0005432020351	8097	42	14A
0005432020334	8097	43	14B
0005433102298	8097	44	14E
0005432919916	8097	45	14D
0005432020329	8097	46	15C
0005433102331	8097	47	15B
0005433102294	8097	48	15D
0005433102319	8097	49	15F
0005432044534	8097	50	16A
0005432677586	8097	51	16B
0005432020341	8097	52	16D
0005432020330	8097	53	16E
0005433102318	8097	54	16F
0005433102322	8097	55	17B
0005433102332	8097	56	17A
0005433102314	8097	57	17D
0005432044532	8097	58	17E
0005432020354	8097	59	18A
0005432919909	8097	60	18B
0005433102311	8097	61	18C
0005432020347	8097	62	18E
0005432919920	8097	63	18F
0005433102316	8097	64	19C
0005433102310	8097	65	19B
0005433102303	8097	66	19D
0005433102325	8097	67	19E
0005433102330	8097	68	20D
0005432677588	8097	69	20C
0005432020353	8097	70	20B
0005432020345	8097	71	21C
0005432919913	8097	72	21E
0005432020352	8097	73	21D
0005432753313	8097	74	22A
0005433102308	8097	75	22B
0005433102321	8097	76	22C
0005432392008	8097	77	22D
0005432020332	8097	78	22E
0005433102300	8097	79	23C
0005432919926	8097	80	23F
0005433102327	8097	81	23E
0005432919912	8097	82	24B
0005432677587	8097	83	24A
0005433102329	8097	84	24C
0005432919928	8097	85	24D
0005432919927	8097	86	24F
0005433102315	8097	87	24E
0005433102324	8097	88	25A
0005432753311	8097	89	25C
0005432919923	8097	90	25B
0005432020350	8097	91	25D
0005433102337	8097	92	25E
0005433102305	8097	93	26A
0005432020335	8097	94	26B
0005432020333	8097	95	26D
0005432020344	8097	96	26C
0005432020343	8097	97	26E
0005433102293	8097	98	27B
0005433102323	8097	99	27C
0005432020338	8097	100	27D
0005432751537	8097	101	27F
0005432020346	8097	102	27E
0005432753314	8097	103	28D
0005432919914	8097	104	28C
0005432919925	8097	105	28E
0005432919929	8097	106	28F
0005433102326	8097	107	29A
0005432044533	8097	108	29D
0005433102297	8097	109	29E
0005433102334	8097	110	30B
0005432919924	8097	111	30C
0005433102302	8097	112	30D
0005432020340	8097	113	31F
0005432901665	8098	1	1C
0005432817169	8098	2	2A
0005432817297	8098	3	2F
0005432817362	8098	4	2D
0005432901653	8098	5	3A
0005432901656	8098	6	3C
0005432817177	8098	7	6C
0005432002082	8098	8	7A
0005432901666	8098	9	7C
0005432901660	8098	10	8E
0005432817332	8098	11	9A
0005432817206	8098	12	9D
0005432817312	8098	13	10F
0005432817410	8098	14	11A
0005432002084	8098	15	11D
0005432817341	8098	16	12C
0005432901663	8098	17	13E
0005432901670	8098	18	14E
0005432817314	8098	19	15C
0005432817236	8098	20	15E
0005432817383	8098	21	17E
0005432817411	8098	22	18B
0005432817182	8098	23	20B
0005432901669	8098	24	20A
0005432901668	8098	25	20D
0005432817280	8098	26	21E
0005432817260	8098	27	22B
0005432901654	8098	28	22A
0005432901658	8098	29	22C
0005432817294	8098	30	23D
0005432817315	8098	31	23F
0005432901661	8098	32	24B
0005432817361	8098	33	25C
0005432901664	8098	34	26A
0005432901667	8098	35	26D
0005432901662	8098	36	26E
0005432817333	8098	37	27D
0005432817363	8098	38	28E
0005432817208	8098	39	29B
0005432901657	8098	40	29A
0005432817381	8098	41	29C
0005432817209	8098	42	29D
0005432901659	8098	43	29F
0005432817281	8098	44	31A
0005432901655	8098	45	30F
0005432002083	8098	46	31B
0005432817128	8098	47	31C
0005432817183	8098	48	31D
0005433870738	9655	1	1A
0005434175723	9655	2	1B
0005434175721	9655	3	2A
0005434175730	9655	4	5A
0005434175722	9655	5	6B
0005434175765	32322	1	1A
0005433870723	32322	2	3B
0005434175767	32322	3	4A
0005434175763	32322	4	4B
0005434175764	32322	5	5B
0005434175766	32322	6	6B
0005435126484	3486	1	1C
0005434938197	3486	2	1H
0005432799533	3486	3	1G
0005435126508	3486	4	1D
0005434878506	3486	5	2D
0005435126504	3486	6	2A
0005432799537	3486	7	2G
0005434426705	3486	8	3A
0005434878494	3486	9	2K
0005434878528	3486	10	2H
0005435913906	3486	11	3D
0005434878567	3486	12	3C
0005434426700	3486	13	4C
0005435902633	3486	14	4A
0005434878522	3486	15	3K
0005434878500	3486	16	4G
0005432188619	3486	17	4D
0005432799541	3486	18	4K
0005434878503	3486	19	4H
0005432799558	3486	20	5D
0005432188616	3486	21	5C
0005435626236	3486	22	5G
0005435126485	3486	23	11A
0005434878566	3486	24	11C
0005432799561	3486	25	11F
0005434938212	3486	26	11E
0005435126512	3486	27	11H
0005434878505	3486	28	12C
0005434426691	3486	29	12A
0005432611723	3486	30	11K
0005434878492	3486	31	12D
0005434426715	3486	32	12F
0005434878555	3486	33	13A
0005435902622	3486	34	12K
0005434878534	3486	35	12H
0005434426703	3486	36	13C
0005435126514	3486	37	13F
0005435902584	3486	38	13E
0005435902695	3486	39	13H
0005434878576	3486	40	14C
0005434878569	3486	41	14K
0005434426716	3486	42	14G
0005435626222	3486	43	15C
0005434426718	3486	44	15A
0005435902655	3486	45	15H
0005435902642	3486	46	15G
0005432613876	3486	47	15F
0005435126497	3486	48	16A
0005432188617	3486	49	15K
0005435626229	3486	50	16D
0005434878525	3486	51	16F
0005434878559	3486	52	16E
0005434938204	3486	53	16K
0005434426711	3486	54	16G
0005434878573	3486	55	17C
0005435126490	3486	56	17A
0005435126487	3486	57	17E
0005434878489	3486	58	17D
0005435902638	3486	59	17G
0005432183474	3486	60	17F
0005434878493	3486	61	17H
0005435902649	3486	62	18C
0005434878547	3486	63	18E
0005434878524	3486	64	18G
0005434878510	3486	65	18K
0005434878570	3486	66	18H
0005435902641	3486	67	19A
0005435126488	3486	68	19C
0005434426717	3486	69	19B
0005434878513	3486	70	19F
0005434938193	3486	71	19E
0005432799556	3486	72	19H
0005432799553	3486	73	19K
0005434878539	3486	74	20A
0005434878545	3486	75	20E
0005434878520	3486	76	20D
0005435902648	3486	77	20H
0005432799542	3486	78	20G
0005435902597	3486	79	20F
0005434426687	3486	80	20J
0005434878495	3486	81	21B
0005434426697	3486	82	21A
0005434878523	3486	83	21D
0005435913910	3486	84	21C
0005435126496	3486	85	21E
0005434878565	3486	86	21J
0005434878504	3486	87	21H
0005435626225	3486	88	21G
0005435126502	3486	89	22A
0005434878553	3486	90	21K
0005435841817	3486	91	22D
0005432799531	3486	92	22B
0005435902596	3486	93	22E
0005435126519	3486	94	22F
0005432799549	3486	95	22K
0005434426689	3486	96	22J
0005435626231	3486	97	23A
0005435913891	3486	98	23D
0005435902677	3486	99	23C
0005434938199	3486	100	23G
0005434878488	3486	101	23F
0005435626233	3486	102	23J
0005435126492	3486	103	23H
0005435126511	3486	104	24D
0005434938194	3486	105	23K
0005435626221	3486	106	24G
0005432799540	3486	107	24F
0005435626226	3486	108	25F
0005435126500	3486	109	25E
0005434426704	3486	110	25H
0005434878563	3486	111	26A
0005434938207	3486	112	26C
0005434938198	3486	113	26B
0005434426713	3486	114	26D
0005435626224	3486	115	26F
0005434878550	3486	116	26K
0005435126499	3486	117	26J
0005432799557	3486	118	27A
0005434426708	3486	119	27D
0005434938203	3486	120	27C
0005434878541	3486	121	27F
0005435126495	3486	122	27E
0005434878511	3486	123	27H
0005435126507	3486	124	27G
0005432183473	3486	125	28A
0005434878483	3486	126	27K
0005434938202	3486	127	27J
0005435126513	3486	128	28C
0005434426706	3486	129	28B
0005435126482	3486	130	28D
0005434878512	3486	131	28G
0005434878486	3486	132	28F
0005432611725	3486	133	28K
0005434878554	3486	134	29A
0005435626219	3486	135	29D
0005435913868	3486	136	29C
0005434878558	3486	137	29B
0005435126517	3486	138	29F
0005434878562	3486	139	29E
0005434878527	3486	140	29J
0005434938195	3486	141	29K
0005435913898	3486	142	30B
0005434426696	3486	143	30C
0005434878502	3486	144	30G
0005434878501	3486	145	30J
0005435902632	3486	146	30H
0005434878551	3486	147	31B
0005434938201	3486	148	31A
0005435126503	3486	149	30K
0005435126481	3486	150	31D
0005434878484	3486	151	31C
0005432799538	3486	152	31H
0005434426710	3486	153	31G
0005435126483	3486	154	32C
0005434878519	3486	155	32B
0005434878490	3486	156	32A
0005434938200	3486	157	32E
0005435126520	3486	158	32D
0005432613873	3486	159	32G
0005435126491	3486	160	32K
0005435902651	3486	161	32H
0005434938196	3486	162	33B
0005435626227	3486	163	33D
0005432188618	3486	164	33G
0005435626218	3486	165	33E
0005432799545	3486	166	33H
0005434878540	3486	167	33K
0005434878529	3486	168	34C
0005434878499	3486	169	34E
0005432611722	3486	170	34G
0005434426690	3486	171	34F
0005435126489	3486	172	34K
0005434938211	3486	173	34J
0005435913892	3486	174	34H
0005434426688	3486	175	35A
0005434878556	3486	176	35D
0005435902634	3486	177	35C
0005435126505	3486	178	35G
0005434878498	3486	179	35F
0005434878544	3486	180	35E
0005434878530	3486	181	36A
0005434878491	3486	182	35K
0005432799559	3486	183	35J
0005435126510	3486	184	36C
0005432613874	3486	185	36B
0005434878564	3486	186	36E
0005435626235	3486	187	36H
0005434426709	3486	188	36G
0005435126509	3486	189	36K
0005435126515	3486	190	36J
0005435626239	3486	191	37B
0005435626228	3486	192	37A
0005435126516	3486	193	37E
0005434878535	3486	194	37D
0005434878507	3486	195	37C
0005432799536	3486	196	37F
0005434878578	3486	197	37J
0005434878518	3486	198	37H
0005435626220	3486	199	37K
0005432799554	3486	200	38C
0005434878514	3486	201	38B
0005434878508	3486	202	38K
0005432799560	3486	203	38J
0005434938206	3486	204	38H
0005434878533	3486	205	39B
0005434878496	3486	206	39C
0005435126493	3486	207	39F
0005435902629	3486	208	39E
0005435902600	3486	209	39H
0005434878561	3486	210	39G
0005435626232	3486	211	40A
0005432799544	3486	212	39J
0005434878517	3486	213	40C
0005434426707	3486	214	40G
0005434878560	3486	215	40F
0005434938205	3486	216	40J
0005434878516	3486	217	40H
0005434878577	3486	218	41B
0005435902531	3486	219	41A
0005432799548	3486	220	40K
0005435902623	3486	221	41C
0005434878571	3486	222	41F
0005435626238	3486	223	41E
0005435626237	3486	224	41H
0005432611724	3486	225	42A
0005432799539	3486	226	42C
0005435126498	3486	227	42B
0005434938210	3486	228	42E
0005432799532	3486	229	42D
0005435626234	3486	230	42H
0005434878485	3486	231	42G
0005432799555	3486	232	42F
0005434878537	3486	233	43B
0005435126518	3486	234	43D
0005434878497	3486	235	43E
0005434938209	3486	236	43H
0005435902656	3486	237	43G
0005435902540	3486	238	44A
0005434878538	3486	239	43K
0005434878572	3486	240	44B
0005434878542	3486	241	44D
0005435902532	3486	242	44C
0005435626230	3486	243	44K
0005434426699	3486	244	45C
0005434426702	3486	245	45B
0005435626223	3486	246	45F
0005434426695	3486	247	45E
0005434878575	3486	248	45D
0005434426694	3486	249	45H
0005432799551	3486	250	45G
0005432799550	3486	251	46C
0005435126506	3486	252	46B
0005434426714	3486	253	46A
0005434426693	3486	254	46E
0005432799543	3486	255	46D
0005434878536	3486	256	46G
0005432613875	3486	257	46K
0005432799546	3486	258	46J
0005434938208	3486	259	46H
0005434878531	3486	260	47C
0005434426712	3486	261	47A
0005435126494	3486	262	47E
0005434426701	3486	263	47D
0005435126501	3486	264	47F
0005434878509	3486	265	47K
0005432799552	3486	266	47H
0005434878546	3486	267	48A
0005434878515	3486	268	48E
0005434878574	3486	269	48D
0005434878557	3486	270	48H
0005432613872	3486	271	48G
0005432188620	3486	272	49A
0005432799535	3486	273	48K
0005434878548	3486	274	49D
0005434878549	3486	275	49C
0005432611721	3486	276	49F
0005435913897	3486	277	49K
0005434426698	3486	278	49H
0005435126486	3486	279	49G
0005434878552	3486	280	50C
0005434878487	3486	281	50A
0005434878521	3486	282	50E
0005434878526	3486	283	50D
0005434878543	3486	284	50H
0005434878568	3486	285	50G
0005434878532	3486	286	50F
0005432799547	3486	287	51F
0005432799534	3486	288	51E
0005435913911	3486	289	51D
0005434426692	3486	290	51G
0005434877796	14550	1	1C
0005435626090	14550	2	1A
0005434877743	14550	3	1G
0005435126217	14550	4	1D
0005432799303	14550	5	1K
0005434877773	14550	6	1H
0005432607527	14550	7	2D
0005434426371	14550	8	2H
0005434877759	14550	9	2K
0005432607563	14550	10	3G
0005432799288	14550	11	3C
0005435126132	14550	12	4C
0005434426474	14550	13	4A
0005434878005	14550	14	3K
0005435126285	14550	15	4D
0005434877649	14550	16	4K
0005434877742	14550	17	4H
0005434877790	14550	18	5C
0005434877810	14550	19	5G
0005434877804	14550	20	11A
0005434877758	14550	21	5K
0005434877725	14550	22	11D
0005435902749	14550	23	11G
0005434877864	14550	24	11F
0005435902751	14550	25	12C
0005434878051	14550	26	12A
0005435126118	14550	27	12D
0005434877289	14550	28	12H
0005435842328	14550	29	12F
0005434426591	14550	30	13A
0005434426502	14550	31	13C
0005432799229	14550	32	13E
0005435626088	14550	33	13H
0005434938046	14550	34	13G
0005435626087	14550	35	14A
0005432799301	14550	36	13K
0005434426505	14550	37	14D
0005435126195	14550	38	14G
0005434877660	14550	39	14F
0005432799376	14550	40	14E
0005435626035	14550	41	14K
0005432799414	14550	42	14H
0005432607525	14550	43	15A
0005434877679	14550	44	15G
0005434877860	14550	45	16A
0005434938109	14550	46	15K
0005435902748	14550	47	15H
0005432799287	14550	48	16D
0005434877557	14550	49	16C
0005435126196	14550	50	16F
0005435626037	14550	51	16E
0005434877605	14550	52	16K
0005435902761	14550	53	16H
0005435902765	14550	54	17C
0005432611694	14550	55	17A
0005432799216	14550	56	17D
0005434877989	14550	57	17G
0005434877772	14550	58	17K
0005434877680	14550	59	17H
0005435626062	14550	60	18B
0005434877452	14550	61	18A
0005435126225	14550	62	18H
0005434426603	14550	63	18F
0005435626063	14550	64	18J
0005435626013	14550	65	19B
0005434938111	14550	66	18K
0005435126227	14550	67	19E
0005435626044	14550	68	19H
0005434877372	14550	69	19G
0005435126197	14550	70	19K
0005435842330	14550	71	20C
0005432799357	14550	72	20B
0005434877990	14550	73	20G
0005434426372	14550	74	21A
0005434877648	14550	75	21G
0005434426508	14550	76	21F
0005432799247	14550	77	21E
0005435126131	14550	78	22A
0005435126102	14550	79	22C
0005434426433	14550	80	22B
0005434877858	14550	81	22H
0005435626038	14550	82	22G
0005432611681	14550	83	22K
0005434877486	14550	84	22J
0005434877865	14550	85	23A
0005434877936	14550	86	23C
0005434877558	14550	87	23G
0005434938021	14550	88	23F
0005435902753	14550	89	23H
0005434877465	14550	90	24D
0005434877892	14550	91	23K
0005434938052	14550	92	24F
0005434426576	14550	93	24E
0005434878194	14550	94	25A
0005435626065	14550	95	24G
0005434877409	14550	96	25D
0005434877789	14550	97	25C
0005434938077	14550	98	25B
0005434878004	14550	99	25F
0005434877797	14550	100	25E
0005435125983	14550	101	26A
0005435126029	14550	102	25K
0005435902763	14550	103	26C
0005434877253	14550	104	26D
0005434426398	14550	105	26G
0005434877453	14550	106	26F
0005434877581	14550	107	26J
0005434426448	14550	108	26H
0005435902764	14550	109	27B
0005435126216	14550	110	27A
0005432799299	14550	111	26K
0005435902762	14550	112	27C
0005435126082	14550	113	27F
0005432799355	14550	114	27E
0005434877975	14550	115	27D
0005434938064	14550	116	27H
0005434426493	14550	117	28C
0005432799273	14550	118	28B
0005435842329	14550	119	28D
0005434426455	14550	120	28F
0005434938047	14550	121	28J
0005435626057	14550	122	28H
0005435902752	14550	123	29B
0005434426456	14550	124	28K
0005434877735	14550	125	29F
0005434938020	14550	126	29G
0005434426546	14550	127	30A
0005432799392	14550	128	29J
0005434877823	14550	129	30C
0005434878205	14550	130	30B
0005434877857	14550	131	30D
0005432799304	14550	132	30F
0005434426554	14550	133	30K
0005435125995	14550	134	31C
0005434877988	14550	135	31F
0005434877464	14550	136	31G
0005434877589	14550	137	31J
0005435125984	14550	138	32C
0005434426432	14550	139	32A
0005434877781	14550	140	32E
0005434877312	14550	141	32D
0005434426370	14550	142	32H
0005434426575	14550	143	32G
0005434877816	14550	144	32F
0005434877541	14550	145	32K
0005432799356	14550	146	32J
0005434877371	14550	147	33A
0005432607551	14550	148	33D
0005435902757	14550	149	33C
0005434877659	14550	150	33B
0005434877650	14550	151	33G
0005435126039	14550	152	33F
0005434877794	14550	153	33E
0005434877723	14550	154	33K
0005434938084	14550	155	34B
0005435902758	14550	156	34A
0005434877748	14550	157	34E
0005432607526	14550	158	34C
0005434877921	14550	159	34F
0005434877791	14550	160	34K
0005435125926	14550	161	34J
0005434878107	14550	162	34H
0005434878178	14550	163	35A
0005432059510	14550	164	35F
0005435625985	14550	165	35H
0005434877647	14550	166	35G
0005434426475	14550	167	36A
0005435126119	14550	168	36B
0005434938070	14550	169	36E
0005432799171	14550	170	36D
0005434877392	14550	171	36G
0005434938074	14550	172	36F
0005434877634	14550	173	36K
0005435126027	14550	174	36J
0005434877153	14550	175	37C
0005434877757	14550	176	37A
0005434938045	14550	177	37D
0005435902754	14550	178	37E
0005434877844	14550	179	37J
0005434938063	14550	180	38A
0005434878041	14550	181	37K
0005434878068	14550	182	38C
0005432607552	14550	183	38J
0005434426328	14550	184	39D
0005434877152	14550	185	39F
0005435902759	14550	186	39H
0005434877736	14550	187	40A
0005435625960	14550	188	39J
0005435125925	14550	189	40C
0005435626017	14550	190	40F
0005434877824	14550	191	40E
0005434877651	14550	192	40D
0005434877252	14550	193	40H
0005435902760	14550	194	40G
0005435626043	14550	195	40K
0005434426494	14550	196	40J
0005434938078	14550	197	41D
0005434877856	14550	198	41C
0005434938069	14550	199	41G
0005434877937	14550	200	41F
0005435626008	14550	201	41H
0005435626032	14550	202	42C
0005434937944	14550	203	42B
0005434877843	14550	204	42A
0005434938058	14550	205	42E
0005435902766	14550	206	42G
0005434877604	14550	207	42H
0005434877749	14550	208	43A
0005434877886	14550	209	43B
0005435626012	14550	210	43F
0005434877658	14550	211	43D
0005435902756	14550	212	43H
0005434878021	14550	213	43G
0005434877642	14550	214	43K
0005435126193	14550	215	43J
0005434877737	14550	216	44B
0005432059511	14550	217	44A
0005434877249	14550	218	44E
0005435126226	14550	219	44D
0005435126283	14550	220	44G
0005434877783	14550	221	44K
0005434877922	14550	222	44J
0005432799205	14550	223	44H
0005434877540	14550	224	45B
0005435902750	14550	225	45A
0005434877756	14550	226	45D
0005432607556	14550	227	45C
0005434426392	14550	228	45E
0005435126272	14550	229	45H
0005434938057	14550	230	45G
0005434877670	14550	231	45K
0005434937988	14550	232	45J
0005434877863	14550	233	46C
0005434938019	14550	234	46B
0005434426459	14550	235	46A
0005434938100	14550	236	46D
0005434877760	14550	237	46H
0005432059509	14550	238	47C
0005434937989	14550	239	47A
0005434877559	14550	240	47E
0005434878022	14550	241	47D
0005435126178	14550	242	47G
0005434877624	14550	243	47F
0005434877717	14550	244	47H
0005432799391	14550	245	48D
0005434877744	14550	246	48C
0005434877450	14550	247	48A
0005435626061	14550	248	48F
0005434877845	14550	249	48H
0005434877525	14550	250	49A
0005434878033	14550	251	49E
0005434877678	14550	252	49K
0005435626009	14550	253	49G
0005434877974	14550	254	50D
0005434877228	14550	255	50C
0005434877350	14550	256	50A
0005432799300	14550	257	50F
0005434877526	14550	258	50E
0005434877567	14550	259	50G
0005434877641	14550	260	50K
0005434878172	14550	261	50H
0005434877893	14550	262	51F
0005435902755	14550	263	51E
0005434426504	14550	264	51G
0005434312326	3597	1	2A
0005435889867	3597	2	2B
0005434325682	3597	3	3B
0005434325685	3597	4	3D
0005435889866	3597	5	4D
0005434325689	3597	6	5A
0005434325687	3597	7	5C
0005434325690	3597	8	6B
0005435889869	3597	9	6C
0005434325683	3597	10	7C
0005434325688	3597	11	18D
0005434325680	3597	12	19B
0005435889856	3597	13	19C
0005435889871	3597	14	19D
0005434325681	3597	15	20C
0005435889872	3597	16	20D
0005434325684	3597	17	21B
0005435889865	3597	18	22A
0005434312325	3597	19	22D
0005434325686	3597	20	23B
0005434325561	15603	1	1C
0005435889917	15603	2	1D
0005435889913	15603	3	2B
0005435889918	15603	4	2C
0005434325594	15603	5	2D
0005434325605	15603	6	3C
0005434325644	15603	7	3D
0005434325645	15603	8	5A
0005435889914	15603	9	5C
0005434325655	15603	10	5D
0005435889916	15603	11	7D
0005434325604	15603	12	18A
0005434325579	15603	13	18C
0005434325646	15603	14	18D
0005434325550	15603	15	19A
0005434325613	15603	16	20A
0005434325593	15603	17	21D
0005435889915	15603	18	23B
0005433420336	647	1	1A
0005433420380	647	2	2A
0005435957745	647	3	3A
0005435957744	647	4	3B
0005433420356	647	5	3C
0005435957755	647	6	3D
0005435957752	647	7	4A
0005435957750	647	8	5A
0005435957742	647	9	5B
0005435957756	647	10	7B
0005435957754	647	11	7C
0005435957740	647	12	18A
0005435957749	647	13	18C
0005435957748	647	14	18D
0005435957751	647	15	19A
0005435957747	647	16	19B
0005435957743	647	17	19C
0005435957746	647	18	19D
0005433420322	647	19	20A
0005433420381	647	20	20B
0005433420335	647	21	20D
0005435957741	647	22	21C
0005435957753	647	23	23A
0005433420340	647	24	23B
0005433420428	15206	1	1B
0005435957639	15206	2	2B
0005435957616	15206	3	3B
0005433420425	15206	4	3D
0005435957681	15206	5	4C
0005433420429	15206	6	4D
0005435957579	15206	7	5D
0005435957562	15206	8	6B
0005433420432	15206	9	6C
0005435957637	15206	10	7D
0005433420424	15206	11	18A
0005433420427	15206	12	18C
0005435957586	15206	13	20A
0005435957585	15206	14	21A
0005433420430	15206	15	21C
0005435957638	15206	16	22B
0005433420431	15206	17	22C
0005433420426	15206	18	22D
0005435957568	15206	19	23A
0005435957615	15206	20	23B
0005435629406	8947	1	1B
0005434247139	8947	2	2A
0005435629408	8947	3	2B
0005434247126	8947	4	4A
0005435629407	8947	5	5A
0005434247156	16088	1	4B
0005434247155	16088	2	6A
0005434096725	11825	1	4D
0005434096732	11825	2	5A
0005434096721	11825	3	5B
0005434096722	11825	4	7A
0005434096723	11825	5	18D
0005434096727	11825	6	19C
0005434096726	11825	7	19D
0005434096748	20167	1	1C
0005434096746	20167	2	2C
0005434096745	20167	3	4A
0005434096749	20167	4	18A
0005434096747	20167	5	21C
0005432645947	25113	1	1A
0005432645883	25113	2	1D
0005432645837	25113	3	2A
0005435229449	25113	4	2C
0005432645935	25113	5	3C
0005432645834	25113	6	3F
0005432645895	25113	7	4C
0005432645890	25113	8	4D
0005435229444	25113	9	4E
0005432645851	25113	10	5C
0005432645833	25113	11	5D
0005432645904	25113	12	5E
0005432645900	25113	13	6C
0005435229435	25113	14	6D
0005432645953	25113	15	6E
0005432645880	25113	16	6F
0005432645862	25113	17	7A
0005432645921	25113	18	7C
0005435229441	25113	19	7E
0005432645836	25113	20	8A
0005432645909	25113	21	8C
0005432645910	25113	22	8D
0005432645879	25113	23	8E
0005432645882	25113	24	9C
0005432645933	25113	25	9D
0005432645835	25113	26	9E
0005432645932	25113	27	10A
0005432645884	25113	28	10C
0005435229437	25113	29	10D
0005435229442	25113	30	10E
0005432645958	25113	31	10F
0005432645871	25113	32	11E
0005432645870	25113	33	12A
0005435229454	25113	34	12C
0005432645875	25113	35	12D
0005435229438	25113	36	12E
0005435229436	25113	37	13D
0005435229451	25113	38	13E
0005435229447	25113	39	13F
0005432645915	25113	40	14A
0005435229448	25113	41	14C
0005435229453	25113	42	14D
0005432645896	25113	43	14E
0005432645885	25113	44	14F
0005432645878	25113	45	15D
0005435229456	25113	46	15F
0005435229455	25113	47	16A
0005435229443	25113	48	16C
0005435229440	25113	49	16D
0005432645824	25113	50	16E
0005432645943	25113	51	16F
0005432645931	25113	52	17D
0005435229439	25113	53	18C
0005435229452	25113	54	18D
0005435229445	25113	55	18E
0005435229450	25113	56	18F
0005432645872	25113	57	19C
0005435229446	25113	58	19F
0005432645905	25113	59	20A
0005432645823	25113	60	20E
0005432645826	25113	61	20F
0005435797518	2881	1	1C
0005435797516	2881	2	4A
0005435797512	2881	3	5C
0005435797513	2881	4	5F
0005435797523	2881	5	6C
0005435797520	2881	6	7C
0005435797519	2881	7	8D
0005435797522	2881	8	9E
0005433404784	2881	9	10A
0005435797525	2881	10	11C
0005435797515	2881	11	11E
0005435797514	2881	12	15E
0005435797521	2881	13	16A
0005433404804	2881	14	16C
0005435797524	2881	15	16E
0005433404803	2881	16	17A
0005433404739	2881	17	19A
0005435797517	2881	18	19F
0005435797368	29306	1	1D
0005435797363	29306	2	2F
0005435797474	29306	3	4F
0005435797429	29306	4	5C
0005435797434	29306	5	5F
0005435797393	29306	6	6C
0005433404834	29306	7	6F
0005433404833	29306	8	7C
0005435797407	29306	9	9A
0005435797408	29306	10	10C
0005435797392	29306	11	10D
0005433404836	29306	12	10F
0005435797383	29306	13	12A
0005435797417	29306	14	15C
0005433404837	29306	15	15F
0005433404830	29306	16	16A
0005433404831	29306	17	16C
0005435797404	29306	18	16F
0005433404835	29306	19	17E
0005435797435	29306	20	18A
0005435797433	29306	21	19C
0005435797367	29306	22	19E
0005433404832	29306	23	20A
0005435376343	5756	1	1A
0005435376354	5756	2	2A
0005435376342	5756	3	3B
0005435376345	5756	4	4B
0005435376344	5756	5	5B
0005435376353	5756	6	5A
0005435376341	5756	7	6B
0005434948044	5794	1	3A
0005434948043	5794	2	4B
0005434948045	5794	3	5B
0005434947978	16346	1	1A
0005434948003	16346	2	1B
0005434947988	16346	3	2A
0005434947979	16346	4	3A
0005434947970	16346	5	2B
0005434947966	16346	6	4A
0005434947989	16346	7	4B
0005434947961	16346	8	5A
0005434947954	16346	9	6A
0005434948012	16346	10	5B
0005434947965	16346	11	6B
0005433961086	6955	1	1A
0005433961055	6955	2	1C
0005433961084	6955	3	1F
0005433961079	6955	4	2A
0005433961067	6955	5	2C
0005433961044	6955	6	2D
0005433961099	6955	7	2F
0005433961054	6955	8	3A
0005433961057	6955	9	3C
0005433961088	6955	10	4A
0005433961068	6955	11	4C
0005433961058	6955	12	4D
0005433961075	6955	13	4E
0005433961108	6955	14	4F
0005433961102	6955	15	5A
0005433961083	6955	16	5C
0005433961073	6955	17	5E
0005433961071	6955	18	6A
0005433961077	6955	19	6C
0005433961094	6955	20	6F
0005433961070	6955	21	7A
0005433961097	6955	22	7C
0005433961106	6955	23	7D
0005433961103	6955	24	7E
0005433961063	6955	25	7F
0005433961076	6955	26	8A
0005433961038	6955	27	8C
0005433961095	6955	28	8D
0005433961062	6955	29	8E
0005433961053	6955	30	9A
0005433961082	6955	31	9D
0005433961089	6955	32	9E
0005433961050	6955	33	9F
0005433961069	6955	34	10A
0005433961074	6955	35	10C
0005433961101	6955	36	10F
0005433961093	6955	37	11A
0005433961087	6955	38	11D
0005433961056	6955	39	11E
0005433961047	6955	40	11F
0005433961048	6955	41	12A
0005433961052	6955	42	12C
0005433961080	6955	43	12D
0005433961066	6955	44	12E
0005433961035	6955	45	13A
0005433961034	6955	46	13D
0005433961098	6955	47	13E
0005433961049	6955	48	13F
0005433961046	6955	49	14A
0005433961064	6955	50	14D
0005433961045	6955	51	14E
0005433961107	6955	52	15A
0005433961091	6955	53	15C
0005433961065	6955	54	15D
0005433961105	6955	55	15E
0005433961040	6955	56	15F
0005433961041	6955	57	16A
0005433961051	6955	58	16D
0005433961039	6955	59	16E
0005433961043	6955	60	16F
0005433961061	6955	61	17A
0005433961085	6955	62	17C
0005433961090	6955	63	17D
0005433961072	6955	64	17E
0005433961037	6955	65	17F
0005433961059	6955	66	18A
0005433961104	6955	67	18C
0005433961081	6955	68	18D
0005433961100	6955	69	18E
0005433961060	6955	70	18F
0005433961092	6955	71	19A
0005433961096	6955	72	19C
0005433961042	6955	73	19F
0005433961078	6955	74	20A
0005433961036	6955	75	20E
0005433961109	6955	76	20F
0005433960220	25728	1	1C
0005433960522	25728	2	1F
0005433960295	25728	3	2C
0005433960361	25728	4	3C
0005433960286	25728	5	4C
0005433960462	25728	6	4E
0005433959987	25728	7	4F
0005433960219	25728	8	5C
0005433960104	25728	9	5F
0005433960310	25728	10	6A
0005433960459	25728	11	6D
0005433960356	25728	12	7A
0005433960456	25728	13	7C
0005433960210	25728	14	7D
0005433960460	25728	15	7F
0005433960151	25728	16	8A
0005433960436	25728	17	8C
0005433960466	25728	18	8D
0005433960163	25728	19	9A
0005433960208	25728	20	9D
0005433960362	25728	21	9E
0005433959986	25728	22	9F
0005433960311	25728	23	10A
0005433960425	25728	24	10C
0005433960360	25728	25	10D
0005433960372	25728	26	11C
0005433960294	25728	27	12A
0005433960185	25728	28	12C
0005433960440	25728	29	12E
0005433960457	25728	30	12F
0005433960511	25728	31	13A
0005433960313	25728	32	13E
0005433960260	25728	33	14A
0005433960312	25728	34	14C
0005433960387	25728	35	14D
0005433960437	25728	36	14F
0005433960371	25728	37	15A
0005433960259	25728	38	15C
0005433960405	25728	39	15E
0005433960438	25728	40	16C
0005433960381	25728	41	16D
0005433960483	25728	42	16F
0005433960458	25728	43	17C
0005433960454	25728	44	17F
0005433960451	25728	45	18D
0005433960455	25728	46	18F
0005433960523	25728	47	19A
0005433960209	25728	48	19C
0005433960152	25728	49	19D
0005433960510	25728	50	19E
0005433960150	25728	51	20D
0005433960365	25728	52	20F
0005435082757	24448	1	1A
0005435082730	24448	2	2A
0005435082735	24448	3	2B
0005435082758	24448	4	3A
0005435082756	24448	5	4A
0005435082734	24448	6	5A
0005435082731	24448	7	6A
0005435082802	26051	1	1A
0005435082797	26051	2	2A
0005435082803	26051	3	2B
0005435082796	26051	4	3A
0005435082795	26051	5	3B
0005435082801	26051	6	4B
0005435082798	26051	7	5B
0005435082800	26051	8	6A
0005435082799	26051	9	6B
0005434245076	5049	1	1C
0005434245073	5049	2	1F
0005434245061	5049	3	2C
0005435286585	5049	4	2F
0005434245069	5049	5	4D
0005435286593	5049	6	5A
0005434245060	5049	7	6D
0005434245057	5049	8	8B
0005434245065	5049	9	9A
0005434245063	5049	10	9E
0005434245068	5049	11	10C
0005434245072	5049	12	11C
0005433534494	5049	13	11D
0005434245070	5049	14	13D
0005434245074	5049	15	14A
0005434245062	5049	16	14C
0005434245084	5049	17	14D
0005434245059	5049	18	14F
0005435286594	5049	19	15A
0005434245067	5049	20	15E
0005434245085	5049	21	18A
0005434245079	5049	22	19C
0005435286604	5049	23	20B
0005432166911	5049	24	20D
0005433534493	5049	25	20C
0005434245082	5049	26	20F
0005434245071	5049	27	22D
0005434245077	5049	28	24A
0005434245083	5049	29	24B
0005434245066	5049	30	24E
0005433534481	5049	31	25F
0005432166912	5049	32	26B
0005434245081	5049	33	26E
0005434245064	5049	34	27C
0005434245075	5049	35	28C
0005434245078	5049	36	30E
0005434245058	5049	37	31D
0005434245080	5049	38	31F
0005433614917	5048	1	1A
0005433614900	5048	2	1D
0005433785055	5048	3	1C
0005432105732	5048	4	2A
0005432105701	5048	5	1F
0005433614892	5048	6	2C
0005433614887	5048	7	2F
0005432105709	5048	8	2D
0005433614926	5048	9	3A
0005432105690	5048	10	3C
0005432105695	5048	11	3F
0005433614949	5048	12	3D
0005433785051	5048	13	4A
0005433785068	5048	14	4D
0005433614948	5048	15	4C
0005433614934	5048	16	4F
0005433614933	5048	17	5A
0005433614952	5048	18	5C
0005432105693	5048	19	5D
0005432105716	5048	20	6A
0005432105723	5048	21	5F
0005433614956	5048	22	6D
0005432105691	5048	23	6C
0005432667459	5048	24	6F
0005433785070	5048	25	7A
0005433785040	5048	26	7D
0005432105707	5048	27	7C
0005433614908	5048	28	7F
0005433785072	5048	29	8A
0005433614905	5048	30	8C
0005433614937	5048	31	8B
0005432105720	5048	32	8E
0005433614890	5048	33	8D
0005433614935	5048	34	9A
0005432105726	5048	35	8F
0005433614902	5048	36	9C
0005433785047	5048	37	9B
0005433785039	5048	38	9E
0005433785065	5048	39	9D
0005433614888	5048	40	9F
0005433785056	5048	41	10A
0005433614938	5048	42	10C
0005433614955	5048	43	10B
0005433785057	5048	44	10D
0005433785058	5048	45	10E
0005432105708	5048	46	10F
0005433614944	5048	47	11B
0005433785042	5048	48	11A
0005433614911	5048	49	11C
0005433785044	5048	50	11D
0005433614906	5048	51	11F
0005433614945	5048	52	11E
0005433785059	5048	53	12A
0005433614931	5048	54	12B
0005433785069	5048	55	12D
0005432105727	5048	56	12C
0005433785066	5048	57	12E
0005433614920	5048	58	12F
0005433614939	5048	59	13A
0005432105731	5048	60	13C
0005433785061	5048	61	13B
0005433614943	5048	62	13D
0005433614912	5048	63	13E
0005433614910	5048	64	14A
0005433614924	5048	65	13F
0005433614932	5048	66	14C
0005432105722	5048	67	14B
0005433614889	5048	68	14E
0005432105699	5048	69	14D
0005432105728	5048	70	15A
0005432105697	5048	71	14F
0005433614895	5048	72	15C
0005433785041	5048	73	15B
0005433785048	5048	74	15E
0005432105736	5048	75	15D
0005433785075	5048	76	16A
0005433614915	5048	77	15F
0005432665280	5048	78	16C
0005433785054	5048	79	16B
0005433614947	5048	80	16E
0005433785064	5048	81	16D
0005432666394	5048	82	16F
0005433614914	5048	83	17B
0005433614883	5048	84	17A
0005432105735	5048	85	17C
0005432105729	5048	86	17E
0005433614898	5048	87	17D
0005433614950	5048	88	17F
0005433614921	5048	89	18A
0005432105730	5048	90	18B
0005433614946	5048	91	18C
0005433614899	5048	92	18E
0005432105719	5048	93	18D
0005432667460	5048	94	18F
0005432105712	5048	95	19C
0005433614916	5048	96	19B
0005432105717	5048	97	19D
0005433614929	5048	98	20A
0005432105733	5048	99	19E
0005433614904	5048	100	20B
0005433614886	5048	101	20C
0005433614941	5048	102	20D
0005433614907	5048	103	20F
0005432105694	5048	104	20E
0005433785045	5048	105	21A
0005432105711	5048	106	21B
0005433785038	5048	107	21D
0005433614925	5048	108	21C
0005432105721	5048	109	21E
0005432666395	5048	110	22A
0005432105724	5048	111	21F
0005432105734	5048	112	22B
0005432105704	5048	113	22C
0005433614928	5048	114	22E
0005433785073	5048	115	22D
0005433785049	5048	116	22F
0005432105710	5048	117	23A
0005433614957	5048	118	23C
0005433614919	5048	119	23B
0005433614954	5048	120	23D
0005432105692	5048	121	23E
0005433785053	5048	122	24A
0005433614918	5048	123	23F
0005433614894	5048	124	24B
0005433785043	5048	125	24C
0005432105725	5048	126	24E
0005432665281	5048	127	24D
0005433614951	5048	128	24F
0005433785050	5048	129	25A
0005432105713	5048	130	25C
0005432105705	5048	131	25B
0005433614953	5048	132	25D
0005433614927	5048	133	25F
0005432105718	5048	134	25E
0005433785071	5048	135	26A
0005433614901	5048	136	26B
0005433614909	5048	137	26C
0005432667461	5048	138	26D
0005433785060	5048	139	27A
0005433785062	5048	140	26F
0005432105706	5048	141	26E
0005433614913	5048	142	27C
0005433614897	5048	143	27B
0005433614930	5048	144	27E
0005433614891	5048	145	27D
0005433614896	5048	146	27F
0005433614903	5048	147	28A
0005433614922	5048	148	28B
0005432105698	5048	149	28D
0005433785067	5048	150	28C
0005432105738	5048	151	28E
0005433614884	5048	152	28F
0005433614923	5048	153	29B
0005433614942	5048	154	29A
0005433614936	5048	155	29C
0005432105702	5048	156	29D
0005432105714	5048	157	29E
0005433785046	5048	158	30A
0005433614940	5048	159	29F
0005432105715	5048	160	30B
0005432105700	5048	161	30D
0005433785074	5048	162	30C
0005432105703	5048	163	30E
0005432105696	5048	164	30F
0005433785063	5048	165	31A
0005433785052	5048	166	31C
0005432105737	5048	167	31B
0005433614893	5048	168	31D
0005433614885	5048	169	31E
0005432145118	5048	170	31F
0005434149761	5046	1	1C
0005435269721	5046	2	1D
0005434229447	5046	3	2A
0005434312304	5046	4	2C
0005434173531	5046	5	2D
0005434229430	5046	6	3A
0005434265214	5046	7	3C
0005434265215	5046	8	3D
0005435269716	5046	9	4A
0005434265225	5046	10	3F
0005434265210	5046	11	4C
0005434265227	5046	12	4F
0005433815348	5046	13	4D
0005434149765	5046	14	5A
0005434229434	5046	15	5F
0005432335949	5046	16	6D
0005435006894	5046	17	6F
0005434149766	5046	18	7F
0005434229449	5046	19	7D
0005435269732	5046	20	8A
0005435269705	5046	21	8B
0005434265213	5046	22	8D
0005434229443	5046	23	8C
0005433685501	5046	24	8E
0005432336015	5046	25	9A
0005434229442	5046	26	9D
0005435269744	5046	27	9F
0005434265207	5046	28	10B
0005434265219	5046	29	10D
0005435269702	5046	30	10C
0005432335952	5046	31	10E
0005435006893	5046	32	10F
0005434265228	5046	33	11B
0005435006858	5046	34	11A
0005435269677	5046	35	11C
0005434265208	5046	36	11D
0005434265218	5046	37	11E
0005435006821	5046	38	12A
0005434229445	5046	39	12B
0005434173532	5046	40	12C
0005434229432	5046	41	12E
0005435269696	5046	42	12D
0005434311206	5046	43	12F
0005435269720	5046	44	13A
0005435269697	5046	45	13C
0005434149773	5046	46	13B
0005434265209	5046	47	13D
0005432335953	5046	48	13F
0005434265222	5046	49	14A
0005434265212	5046	50	14D
0005435269715	5046	51	14C
0005434229439	5046	52	14F
0005434265216	5046	53	15B
0005434265226	5046	54	15A
0005435006906	5046	55	15C
0005432335927	5046	56	15D
0005435006774	5046	57	15F
0005434229435	5046	58	15E
0005434149764	5046	59	16A
0005433815375	5046	60	16C
0005434265206	5046	61	16B
0005435269704	5046	62	16D
0005432335985	5046	63	17B
0005435269714	5046	64	17A
0005434149762	5046	65	17C
0005433815360	5046	66	17D
0005434229431	5046	67	17E
0005434149763	5046	68	18A
0005435006950	5046	69	18B
0005434229444	5046	70	18D
0005435269741	5046	71	18C
0005434229450	5046	72	18E
0005434229440	5046	73	18F
0005434265229	5046	74	19D
0005434229448	5046	75	19E
0005434265223	5046	76	20B
0005435269745	5046	77	20A
0005434229433	5046	78	20C
0005434229438	5046	79	20D
0005432335958	5046	80	20F
0005433815343	5046	81	21A
0005435006859	5046	82	21C
0005434149767	5046	83	21B
0005435006861	5046	84	21D
0005434265224	5046	85	21E
0005435006951	5046	86	22B
0005435269726	5046	87	22A
0005435006935	5046	88	22D
0005435269717	5046	89	22C
0005435269682	5046	90	23A
0005435006955	5046	91	23C
0005433815359	5046	92	23E
0005435006845	5046	93	23F
0005433685502	5046	94	24B
0005435269727	5046	95	24A
0005434173533	5046	96	24C
0005435269680	5046	97	24F
0005432335959	5046	98	24E
0005435006844	5046	99	25A
0005434229441	5046	100	25B
0005432335928	5046	101	25D
0005435006907	5046	102	25E
0005434312303	5046	103	26C
0005434311207	5046	104	26B
0005434311208	5046	105	26D
0005435007018	5046	106	26F
0005434265211	5046	107	26E
0005434229436	5046	108	27A
0005435269731	5046	109	27C
0005434149768	5046	110	27B
0005434149771	5046	111	27D
0005435269742	5046	112	27E
0005435006916	5046	113	28D
0005434149769	5046	114	28C
0005434265204	5046	115	28E
0005434229437	5046	116	28F
0005433815342	5046	117	29B
0005434265205	5046	118	29A
0005434149772	5046	119	29C
0005435006963	5046	120	29F
0005434265221	5046	121	29E
0005434149770	5046	122	30B
0005434265217	5046	123	30D
0005432335961	5046	124	30C
0005435006860	5046	125	30F
0005435269683	5046	126	31B
0005434265220	5046	127	31A
0005435006875	5046	128	31C
0005435269681	5046	129	31D
0005432335948	5046	130	31E
0005434229446	5046	131	31F
0005433784713	8520	1	1A
0005434244808	8520	2	2C
0005434244844	8520	3	3D
0005433784614	8520	4	4A
0005434244702	8520	5	4C
0005433784766	8520	6	4D
0005433784624	8520	7	5A
0005432663026	8520	8	5C
0005434244995	8520	9	6A
0005434244792	8520	10	7A
0005434244762	8520	11	6F
0005434244758	8520	12	8A
0005434244922	8520	13	7F
0005435269764	8520	14	8C
0005433784820	8520	15	8B
0005433784822	8520	16	8F
0005433784884	8520	17	9C
0005434244939	8520	18	9B
0005433784738	8520	19	9E
0005433784619	8520	20	10A
0005432663025	8520	21	10B
0005433784645	8520	22	10D
0005434244751	8520	23	11A
0005434244903	8520	24	10F
0005434244851	8520	25	11B
0005433784790	8520	26	11D
0005434244904	8520	27	12A
0005434244815	8520	28	11F
0005434244814	8520	29	12B
0005434244867	8520	30	13A
0005434244872	8520	31	13C
0005435269759	8520	32	13D
0005434244791	8520	33	13F
0005433784792	8520	34	14B
0005434244805	8520	35	14E
0005433784750	8520	36	14D
0005433784819	8520	37	15B
0005434244906	8520	38	15A
0005434244757	8520	39	15C
0005434244804	8520	40	15F
0005434244871	8520	41	16B
0005434244876	8520	42	16D
0005434244905	8520	43	16C
0005433784777	8520	44	16E
0005434244968	8520	45	17A
0005433784915	8520	46	17D
0005434244897	8520	47	17E
0005433784793	8520	48	18A
0005433784665	8520	49	18D
0005433784616	8520	50	18C
0005435269761	8520	51	18E
0005434244902	8520	52	18F
0005435269760	8520	53	19C
0005432663018	8520	54	19B
0005435269762	8520	55	20A
0005435269763	8520	56	20B
0005433784644	8520	57	20F
0005434244638	8520	58	21B
0005433784737	8520	59	21E
0005433784885	8520	60	21F
0005435269766	8520	61	22B
0005434244701	8520	62	22C
0005433784757	8520	63	22D
0005435269765	8520	64	23B
0005432666362	8520	65	23D
0005433784817	8520	66	23F
0005433784719	8520	67	24B
0005433784708	8520	68	24C
0005433784788	8520	69	24F
0005434244810	8520	70	24E
0005433784789	8520	71	25B
0005433784765	8520	72	25C
0005434244845	8520	73	26E
0005432663012	8520	74	27A
0005434244809	8520	75	27C
0005434244969	8520	76	27B
0005433784745	8520	77	27E
0005434244819	8520	78	27F
0005432666361	8520	79	28C
0005432666372	8520	80	28F
0005433784818	8520	81	29A
0005434244938	8520	82	30A
0005433784718	8520	83	29F
0005434244820	8520	84	30C
0005434244866	8520	85	30E
0005433784794	8520	86	30D
0005433784615	8520	87	31B
0005434244966	8520	88	31A
0005433784703	8520	89	31C
0005434244896	8520	90	31E
0005433784666	8520	91	31F
0005433614194	8521	1	1C
0005433614283	8521	2	2C
0005433614218	8521	3	3A
0005433614050	8521	4	3C
0005433614320	8521	5	3D
0005433614470	8521	6	3F
0005433614200	8521	7	4C
0005433614511	8521	8	4F
0005433614122	8521	9	5A
0005433613949	8521	10	5F
0005433613993	8521	11	6D
0005433613775	8521	12	6C
0005433614222	8521	13	7C
0005433614040	8521	14	7F
0005433614235	8521	15	7D
0005433614149	8521	16	8E
0005433614239	8521	17	8D
0005433614439	8521	18	8F
0005433614322	8521	19	9A
0005433614008	8521	20	9C
0005433614088	8521	21	9F
0005433614196	8521	22	9E
0005433614321	8521	23	10D
0005433614120	8521	24	10C
0005433614195	8521	25	11E
0005433614039	8521	26	11D
0005433614150	8521	27	11F
0005433614240	8521	28	12C
0005433614215	8521	29	12B
0005433614341	8521	30	13B
0005433614165	8521	31	13D
0005433614074	8521	32	14B
0005433614265	8521	33	14D
0005433614302	8521	34	14F
0005433614051	8521	35	15C
0005433614284	8521	36	15B
0005433614119	8521	37	15D
0005433614310	8521	38	16A
0005433614521	8521	39	17E
0005433613983	8521	40	17D
0005433614189	8521	41	17F
0005433614219	8521	42	18D
0005433614417	8521	43	18E
0005433613843	8521	44	19B
0005433614469	8521	45	20F
0005433614282	8521	46	20E
0005433614531	8521	47	21B
0005433614268	8521	48	21A
0005433613948	8521	49	21F
0005433614171	8521	50	22B
0005433614227	8521	51	22C
0005433614155	8521	52	22D
0005433614407	8521	53	23A
0005433613750	8521	54	23C
0005433614276	8521	55	23B
0005433614340	8521	56	23E
0005433614089	8521	57	24B
0005433613982	8521	58	24D
0005433614049	8521	59	25D
0005433613992	8521	60	25E
0005433614546	8521	61	25F
0005433614530	8521	62	26B
0005433614092	8521	63	26D
0005433614147	8521	64	27A
0005433614662	8521	65	26F
0005433614359	8521	66	27B
0005433614103	8521	67	27C
0005433614245	8521	68	27D
0005433614395	8521	69	27F
0005433614254	8521	70	28E
0005433614209	8521	71	29C
0005433614193	8521	72	29B
0005433613923	8521	73	29D
0005433614249	8521	74	30B
0005433614418	8521	75	30C
0005433614163	8521	76	30E
0005433614204	8521	77	30D
0005433614520	8521	78	30F
0005433614266	8521	79	31C
0005433614121	8521	80	31D
0005433614522	8521	81	31E
0005433689918	8522	1	1A
0005434229200	8522	2	1C
0005435286645	8522	3	1D
0005435286643	8522	4	1F
0005435007094	8522	5	2D
0005432035034	8522	6	2C
0005434229285	8522	7	3A
0005435007090	8522	8	2F
0005435286646	8522	9	3D
0005433690932	8522	10	3C
0005432035037	8522	11	3F
0005434229171	8522	12	4A
0005435286649	8522	13	4C
0005435007104	8522	14	4D
0005434229231	8522	15	5A
0005434264982	8522	16	5C
0005434229330	8522	17	5F
0005432336075	8522	18	6C
0005434229199	8522	19	6A
0005433688816	8522	20	6F
0005432035041	8522	21	6D
0005434265056	8522	22	7A
0005434229236	8522	23	7D
0005434229243	8522	24	7C
0005435286641	8522	25	8A
0005432035046	8522	26	8B
0005432035045	8522	27	8D
0005434229183	8522	28	8C
0005434149696	8522	29	8E
0005432035033	8522	30	8F
0005434311227	8522	31	9B
0005434311226	8522	32	9A
0005435007092	8522	33	9C
0005433815401	8522	34	9D
0005434229302	8522	35	9F
0005432035029	8522	36	9E
0005434149611	8522	37	10A
0005432336070	8522	38	10B
0005434311228	8522	39	10D
0005432035030	8522	40	10C
0005435007088	8522	41	10E
0005434264980	8522	42	10F
0005432035019	8522	43	11A
0005432336076	8522	44	11C
0005435007107	8522	45	11B
0005435007093	8522	46	11D
0005432035043	8522	47	11F
0005435007103	8522	48	11E
0005434229261	8522	49	12B
0005435007109	8522	50	12D
0005435007097	8522	51	12C
0005435286642	8522	52	12E
0005434229142	8522	53	13B
0005432336073	8522	54	13A
0005434229233	8522	55	13C
0005435286636	8522	56	13D
0005433815403	8522	57	13F
0005433534505	8522	58	13E
0005434173506	8522	59	14A
0005432035039	8522	60	14B
0005435286651	8522	61	14D
0005432035032	8522	62	14C
0005435007106	8522	63	14E
0005435286648	8522	64	15A
0005432047563	8522	65	14F
0005435007101	8522	66	15C
0005435007099	8522	67	15B
0005432035035	8522	68	15D
0005435007098	8522	69	15E
0005434149682	8522	70	16A
0005434264995	8522	71	15F
0005434264958	8522	72	16C
0005434265022	8522	73	16B
0005434264943	8522	74	16D
0005432035024	8522	75	16E
0005434173525	8522	76	16F
0005434265049	8522	77	17B
0005433689917	8522	78	17A
0005434265082	8522	79	17E
0005434229248	8522	80	17D
0005435007095	8522	81	18A
0005432035028	8522	82	17F
0005432336068	8522	83	18B
0005435286644	8522	84	18D
0005432035031	8522	85	18C
0005434265081	8522	86	18E
0005435286650	8522	87	18F
0005434229232	8522	88	19B
0005434264956	8522	89	19D
0005434265048	8522	90	19E
0005433534504	8522	91	20A
0005432035022	8522	92	20C
0005435007108	8522	93	20B
0005434229182	8522	94	20D
0005434264884	8522	95	20F
0005435286637	8522	96	20E
0005434264919	8522	97	21B
0005432336066	8522	98	21A
0005435286635	8522	99	21D
0005434149668	8522	100	21C
0005434264944	8522	101	21F
0005434265057	8522	102	21E
0005435007086	8522	103	22A
0005434265013	8522	104	22B
0005433688815	8522	105	22C
0005435007089	8522	106	22E
0005432336074	8522	107	22F
0005432035027	8522	108	23B
0005434149669	8522	109	23A
0005434149719	8522	110	23D
0005434264983	8522	111	23C
0005433815402	8522	112	24A
0005432035021	8522	113	24B
0005435286647	8522	114	24C
0005432336072	8522	115	24E
0005434229218	8522	116	24D
0005434149683	8522	117	24F
0005435286638	8522	118	25A
0005434149711	8522	119	25C
0005432336071	8522	120	25B
0005434229135	8522	121	25E
0005433815400	8522	122	25D
0005434264971	8522	123	26A
0005434149640	8522	124	25F
0005435286639	8522	125	26B
0005432035040	8522	126	26D
0005432035023	8522	127	26C
0005434173489	8522	128	27A
0005432035044	8522	129	26F
0005432047562	8522	130	26E
0005435007091	8522	131	27B
0005435007085	8522	132	27C
0005434229296	8522	133	27D
0005434264994	8522	134	27E
0005432035025	8522	135	28A
0005434173507	8522	136	27F
0005432336069	8522	137	28B
0005434264957	8522	138	28D
0005435007102	8522	139	28C
0005432035036	8522	140	28E
0005432047561	8522	141	28F
0005434264918	8522	142	29B
0005432336077	8522	143	29A
0005435007105	8522	144	29C
0005432047560	8522	145	29D
0005435286640	8522	146	29F
0005434229234	8522	147	29E
0005432336067	8522	148	30A
0005435007100	8522	149	30C
0005432035026	8522	150	30D
0005432035042	8522	151	30E
0005434264979	8522	152	30F
0005435007087	8522	153	31B
0005435007096	8522	154	31A
0005432035020	8522	155	31C
0005432035038	8522	156	31E
0005434265050	8522	157	31D
0005434149712	8522	158	31F
0005433202417	12639	1	1A
0005434639224	12639	2	1C
0005433202410	12639	3	1D
0005434639148	12639	4	2A
0005434639190	12639	5	2C
0005434639221	12639	6	2D
0005433202409	12639	7	3A
0005434639188	12639	8	3B
0005434639267	12639	9	3C
0005434639196	12639	10	3D
0005433202415	12639	11	4A
0005434639234	12639	12	4C
0005433202416	12639	13	4D
0005433202413	12639	14	5A
0005434639225	12639	15	5B
0005433202407	12639	16	5C
0005434639213	12639	17	5D
0005433202405	12639	18	6A
0005434639222	12639	19	6B
0005434639228	12639	20	6C
0005434639191	12639	21	6D
0005433202403	12639	22	7A
0005434639204	12639	23	7B
0005433202414	12639	24	7C
0005434639279	12639	25	7D
0005433202408	12639	26	18A
0005434639017	12639	27	18B
0005434639189	12639	28	18C
0005434639223	12639	29	18D
0005433202411	12639	30	19A
0005434639205	12639	31	19B
0005433202404	12639	32	19D
0005434639227	12639	33	20D
0005433202412	12639	34	21A
0005434639082	12639	35	21B
0005433202418	12639	36	21D
0005434639146	12639	37	22A
0005434639226	12639	38	22B
0005434639098	12639	39	22C
0005433202406	12639	40	22D
0005434639149	12639	41	23A
0005434639235	12639	42	23B
0005434639374	23372	1	1C
0005434639385	23372	2	1D
0005433202279	23372	3	2A
0005434639383	23372	4	2C
0005434639381	23372	5	3A
0005434639378	23372	6	3D
0005433202195	23372	7	4A
0005432290640	23372	8	4B
0005434639377	23372	9	4C
0005434639392	23372	10	4D
0005434639386	23372	11	5A
0005434639384	23372	12	5B
0005434639389	23372	13	5C
0005434639371	23372	14	5D
0005432290642	23372	15	6A
0005433202259	23372	16	6B
0005434639379	23372	17	6C
0005434639380	23372	18	6D
0005434639390	23372	19	7A
0005434639387	23372	20	7B
0005434639369	23372	21	7C
0005432290641	23372	22	7D
0005434639375	23372	23	18A
0005433202324	23372	24	18B
0005433202325	23372	25	18D
0005433202229	23372	26	19A
0005434639373	23372	27	19B
0005433202283	23372	28	19C
0005434639368	23372	29	20A
0005434639388	23372	30	20B
0005434639382	23372	31	20D
0005434639367	23372	32	21B
0005433202278	23372	33	21C
0005434639393	23372	34	21D
0005434639372	23372	35	22A
0005434639376	23372	36	22C
0005434639370	23372	37	22D
0005434639391	23372	38	23A
0005432290639	23372	39	23B
0005432848840	21091	1	1A
0005432328564	21091	2	1C
0005432328064	21091	3	1D
0005432848838	21091	4	1F
0005432328504	21091	5	2A
0005432328473	21091	6	2C
0005432382777	21091	7	2D
0005432328328	21091	8	2F
0005432328509	21091	9	3A
0005432328463	21091	10	3C
0005432328493	21091	11	3D
0005432383075	21091	12	3F
0005432383088	21091	13	4A
0005432328448	21091	14	4C
0005432328443	21091	15	4D
0005432382989	21091	16	4E
0005432382978	21091	17	4F
0005432382948	21091	18	5A
0005432382733	21091	19	5C
0005432382902	21091	20	5D
0005432382909	21091	21	5E
0005432328387	21091	22	5F
0005432382901	21091	23	6A
0005432382844	21091	24	6C
0005432382945	21091	25	6D
0005432328167	21091	26	6E
0005432328481	21091	27	6F
0005432328277	21091	28	7A
0005432328442	21091	29	7C
0005432382755	21091	30	7D
0005432328457	21091	31	7E
0005432328472	21091	32	7F
0005432382949	21091	33	8A
0005432382908	21091	34	8C
0005432328465	21091	35	8E
0005432328228	21091	36	8F
0005432328380	21091	37	9A
0005432382946	21091	38	9C
0005432328417	21091	39	9E
0005432382835	21091	40	9F
0005432328432	21091	41	10A
0005432328634	21091	42	10D
0005432328562	21091	43	10E
0005432328389	21091	44	10F
0005432382925	21091	45	11A
0005432054314	21091	46	11C
0005432382900	21091	47	11D
0005432328314	21091	48	11E
0005432328503	21091	49	11F
0005432382903	21091	50	12A
0005432328478	21091	51	12C
0005432382873	21091	52	12D
0005432382736	21091	53	12E
0005432328570	21091	54	12F
0005432328480	21091	55	13A
0005432383002	21091	56	13C
0005432328635	21091	57	13D
0005432383122	21091	58	13E
0005432328359	21091	59	13F
0005432328441	21091	60	14A
0005432383074	21091	61	14C
0005432328477	21091	62	14D
0005432328550	21091	63	14E
0005432382977	21091	64	14F
0005432328528	21091	65	15A
0005432382953	21091	66	15C
0005432382780	21091	67	15D
0005432328240	21091	68	15E
0005432382881	21091	69	15F
0005432382926	21091	70	16A
0005432328447	21091	71	16C
0005432382921	21091	72	16D
0005432383001	21091	73	16E
0005432382859	21091	74	16F
0005432382779	21091	75	17A
0005432328593	21091	76	17C
0005432328388	21091	77	17D
0005432382787	21091	78	17E
0005432328386	21091	79	17F
0005432382954	21091	80	18A
0005432382922	21091	81	18C
0005432383168	21091	82	18D
0005432382778	21091	83	18E
0005432328065	21091	84	18F
0005432382947	21091	85	19A
0005432848839	21091	86	19C
0005432382759	21091	87	19D
0005432382781	21091	88	19E
0005432328280	21091	89	19F
0005432383124	21091	90	20A
0005432328370	21091	91	20C
0005432382827	21091	92	20D
0005432383123	21091	93	20E
0005432382855	21091	94	20F
0005432383240	31258	1	1C
0005432328815	31258	2	1D
0005432383275	31258	3	1F
0005432383243	31258	4	2A
0005432328795	31258	5	2C
0005432328800	31258	6	2D
0005432383273	31258	7	2F
0005432328792	31258	8	3A
0005432328806	31258	9	3C
0005432383272	31258	10	3D
0005432383242	31258	11	3F
0005432328810	31258	12	4A
0005432383274	31258	13	4C
0005432383257	31258	14	4D
0005432383258	31258	15	4E
0005432287203	31258	16	4F
0005432328798	31258	17	5A
0005432328824	31258	18	5D
0005432328787	31258	19	5E
0005432383277	31258	20	5F
0005432287200	31258	21	6A
0005432328785	31258	22	6C
0005432383265	31258	23	6E
0005432328801	31258	24	6F
0005432383264	31258	25	7A
0005432328827	31258	26	7C
0005432383271	31258	27	7D
0005432328819	31258	28	7E
0005432328812	31258	29	7F
0005432328823	31258	30	8A
0005432328818	31258	31	8C
0005432383276	31258	32	8D
0005432328784	31258	33	8E
0005432383267	31258	34	8F
0005432383262	31258	35	9A
0005432328794	31258	36	9C
0005432383244	31258	37	9D
0005432328817	31258	38	9E
0005432328797	31258	39	9F
0005432287202	31258	40	10A
0005432383268	31258	41	10C
0005432328820	31258	42	10D
0005432328813	31258	43	10E
0005432328803	31258	44	10F
0005432328796	31258	45	11A
0005432287201	31258	46	11C
0005432328825	31258	47	11D
0005432328793	31258	48	11E
0005432328789	31258	49	11F
0005432328799	31258	50	12A
0005432383239	31258	51	12C
0005432328791	31258	52	12D
0005432383248	31258	53	12E
0005432287199	31258	54	12F
0005432383241	31258	55	13A
0005432328811	31258	56	13C
0005432383260	31258	57	13D
0005432328816	31258	58	13E
0005432383245	31258	59	13F
0005432328804	31258	60	14A
0005432383278	31258	61	14C
0005432328830	31258	62	14D
0005432383255	31258	63	14E
0005432328786	31258	64	14F
0005432383270	31258	65	15A
0005432287204	31258	66	15C
0005432383247	31258	67	15D
0005432383253	31258	68	15E
0005432328822	31258	69	15F
0005432328790	31258	70	16A
0005432383256	31258	71	16C
0005432328828	31258	72	16D
0005432383238	31258	73	16E
0005432383269	31258	74	16F
0005432328808	31258	75	17A
0005432383252	31258	76	17C
0005432383261	31258	77	17D
0005432328805	31258	78	17E
0005432328802	31258	79	17F
0005432328829	31258	80	18A
0005432383254	31258	81	18C
0005432383251	31258	82	18D
0005432383263	31258	83	18E
0005432383250	31258	84	18F
0005432383249	31258	85	19A
0005432383266	31258	86	19C
0005432328821	31258	87	19D
0005432328807	31258	88	19E
0005432328809	31258	89	19F
0005432328826	31258	90	20A
0005432383246	31258	91	20C
0005432383259	31258	92	20D
0005432328788	31258	93	20E
0005432328814	31258	94	20F
0005432953967	27587	1	1F
0005432953953	27587	2	3A
0005433642222	27587	3	3C
0005433642251	27587	4	3D
0005432953961	27587	5	4D
0005432953954	27587	6	4F
0005432953951	27587	7	5D
0005433642252	27587	8	6A
0005432953960	27587	9	6D
0005432953955	27587	10	6E
0005433642253	27587	11	7A
0005432953957	27587	12	7C
0005433642211	27587	13	7E
0005433642230	27587	14	8E
0005432953966	27587	15	9E
0005433642212	27587	16	10A
0005432953959	27587	17	11A
0005433642279	27587	18	11D
0005433642187	27587	19	12C
0005433642166	27587	20	12E
0005432953965	27587	21	12F
0005433642264	27587	22	13A
0005433642213	27587	23	13F
0005432953963	27587	24	14F
0005432953962	27587	25	15C
0005433642302	27587	26	15D
0005432953958	27587	27	16C
0005432953968	27587	28	16D
0005433642209	27587	29	16F
0005433642332	27587	30	17A
0005432953964	27587	31	17C
0005433642236	27587	32	17D
0005433642229	27587	33	18C
0005432953952	27587	34	18D
0005433642233	27587	35	19C
0005433642291	27587	36	19F
0005432953956	27587	37	19E
0005432424546	13335	1	1A
0005432424566	13335	2	1F
0005432424534	13335	3	2A
0005432424558	13335	4	2C
0005432424562	13335	5	2D
0005432424555	13335	6	2F
0005432424554	13335	7	3C
0005432424560	13335	8	3F
0005432424551	13335	9	4A
0005432424520	13335	10	4E
0005432424523	13335	11	4F
0005432424531	13335	12	5A
0005432424568	13335	13	5C
0005432424565	13335	14	5D
0005432424556	13335	15	5E
0005432424542	13335	16	6A
0005432424549	13335	17	6C
0005432424557	13335	18	6D
0005432424527	13335	19	6E
0005432424553	13335	20	7C
0005432424547	13335	21	7D
0005432424529	13335	22	7E
0005432424541	13335	23	8C
0005432424522	13335	24	8D
0005432424559	13335	25	8F
0005432424561	13335	26	9A
0005432424524	13335	27	9D
0005432424538	13335	28	9E
0005432424532	13335	29	10E
0005432424545	13335	30	10F
0005432424544	13335	31	11C
0005432424526	13335	32	11E
0005432424548	13335	33	13C
0005432424539	13335	34	13F
0005432424533	13335	35	14A
0005432424569	13335	36	14F
0005432424530	13335	37	15C
0005432424570	13335	38	15F
0005432424521	13335	39	16A
0005432424543	13335	40	16D
0005432424537	13335	41	16E
0005432424567	13335	42	17A
0005432424528	13335	43	17C
0005432424563	13335	44	17E
0005432424525	13335	45	18C
0005432424536	13335	46	18D
0005432424552	13335	47	18E
0005432424540	13335	48	19C
0005432424535	13335	49	19D
0005432424550	13335	50	19E
0005432424564	13335	51	20E
0005432424094	30709	1	1C
0005432424129	30709	2	2A
0005432424095	30709	3	2D
0005432424078	30709	4	3A
0005432423956	30709	5	3C
0005432424160	30709	6	3D
0005432424169	30709	7	3F
0005432424113	30709	8	4A
0005432424115	30709	9	4C
0005432424020	30709	10	4D
0005432424138	30709	11	5A
0005432423967	30709	12	5D
0005432424135	30709	13	5E
0005432424139	30709	14	6A
0005432424079	30709	15	6E
0005432424035	30709	16	7A
0005432424041	30709	17	8A
0005432424111	30709	18	8D
0005432424109	30709	19	8E
0005432424033	30709	20	9A
0005432424159	30709	21	9E
0005432424107	30709	22	10A
0005432424032	30709	23	10C
0005432424037	30709	24	10D
0005432423961	30709	25	10E
0005432424121	30709	26	10F
0005432424042	30709	27	11A
0005432424110	30709	28	12D
0005432424034	30709	29	12F
0005432424104	30709	30	13C
0005432424043	30709	31	13D
0005432424065	30709	32	13E
0005432424044	30709	33	14C
0005432424152	30709	34	14E
0005432424158	30709	35	16A
0005432424123	30709	36	16F
0005432424116	30709	37	17E
0005432424036	30709	38	18D
0005432423937	30709	39	18F
0005432424103	30709	40	19A
0005432423988	30709	41	19C
0005432424108	30709	42	19E
0005432424067	30709	43	19F
0005432424112	30709	44	20D
0005432423989	30709	45	20F
0005432822229	9591	1	1A
0005432817569	9591	2	1C
0005434157471	9591	3	1F
0005432817571	9591	4	2A
0005432817568	9591	5	2C
0005432901486	9591	6	2D
0005432817557	9591	7	2F
0005432901487	9591	8	3A
0005432288994	9591	9	3D
0005434157470	9591	10	4C
0005432901505	9591	11	4E
0005432817550	9591	12	4F
0005434186169	9591	13	5A
0005432901528	9591	14	5C
0005432817549	9591	15	5D
0005432901498	9591	16	5E
0005434448326	9591	17	5F
0005432901502	9591	18	6A
0005432901506	9591	19	6C
0005434157452	9591	20	6D
0005434157457	9591	21	6E
0005432817563	9591	22	6F
0005432822223	9591	23	7A
0005432817564	9591	24	7D
0005432817551	9591	25	7E
0005432288997	9591	26	8C
0005432901584	9591	27	8D
0005432817559	9591	28	8F
0005432817558	9591	29	9A
0005432817573	9591	30	9C
0005432817554	9591	31	9E
0005434157435	9591	32	9F
0005432822224	9591	33	10A
0005432817565	9591	34	10C
0005434157448	9591	35	10D
0005432817572	9591	36	10E
0005432822230	9591	37	10F
0005432901526	9591	38	11C
0005432288995	9591	39	11D
0005432817561	9591	40	11E
0005432822225	9591	41	11F
0005432817555	9591	42	12A
0005432817548	9591	43	12D
0005432901488	9591	44	12C
0005432822228	9591	45	12E
0005434157431	9591	46	12F
0005432822226	9591	47	13A
0005432817552	9591	48	13C
0005434157453	9591	49	13D
0005434157444	9591	50	13E
0005432817566	9591	51	13F
0005432817570	9591	52	14C
0005432901525	9591	53	14A
0005432817575	9591	54	14D
0005434157407	9591	55	14E
0005434157434	9591	56	14F
0005432817553	9591	57	15C
0005432817556	9591	58	15D
0005432817546	9591	59	15E
0005434448328	9591	60	15F
0005432901532	9591	61	16C
0005432817560	9591	62	16D
0005434448327	9591	63	16E
0005432817547	9591	64	16F
0005432901524	9591	65	17A
0005434157456	9591	66	17D
0005432901529	9591	67	17E
0005432817562	9591	68	18C
0005432822227	9591	69	18F
0005432901477	9591	70	19C
0005432817574	9591	71	19D
0005432288996	9591	72	19F
0005432901533	9591	73	20C
0005432817567	9591	74	20D
0005432822170	28975	1	1A
0005434157503	28975	2	1D
0005432901662	28975	3	1F
0005432822163	28975	4	2D
0005432817297	28975	5	3A
0005432817383	28975	6	3C
0005432817333	28975	7	3D
0005432817332	28975	8	4A
0005432901658	28975	9	4C
0005432901670	28975	10	4E
0005432817381	28975	11	5A
0005434157500	28975	12	5C
0005432822153	28975	13	5D
0005432817341	28975	14	5E
0005432901665	28975	15	6A
0005432002084	28975	16	6C
0005432822132	28975	17	6D
0005434448280	28975	18	6E
0005432817169	28975	19	6F
0005432901668	28975	20	7A
0005432817410	28975	21	7C
0005432901656	28975	22	7D
0005434448287	28975	23	7F
0005434186205	28975	24	8A
0005432817183	28975	25	8C
0005434157499	28975	26	8E
0005432817280	28975	27	9A
0005432817208	28975	28	9C
0005432901669	28975	29	9E
0005432901666	28975	30	9F
0005432817411	28975	31	10C
0005434448293	28975	32	10D
0005432817281	28975	33	10E
0005432817236	28975	34	10F
0005432817260	28975	35	11C
0005432817361	28975	36	11D
0005432822183	28975	37	11E
0005434186206	28975	38	11F
0005432901655	28975	39	12C
0005432901660	28975	40	12E
0005432901664	28975	41	12F
0005432817312	28975	42	13A
0005432822154	28975	43	13C
0005432901657	28975	44	13E
0005432817363	28975	45	13D
0005432817177	28975	46	13F
0005432002083	28975	47	14A
0005432817315	28975	48	14C
0005432901667	28975	49	14D
0005432822162	28975	50	14E
0005432002082	28975	51	15A
0005434448282	28975	52	15C
0005434157501	28975	53	15D
0005432817182	28975	54	15E
0005432822166	28975	55	15F
0005432901663	28975	56	16A
0005432817206	28975	57	16C
0005434157505	28975	58	16D
0005434157502	28975	59	16E
0005434448294	28975	60	16F
0005434186207	28975	61	17C
0005434157504	28975	62	17D
0005432901661	28975	63	17E
0005432822133	28975	64	17F
0005432817294	28975	65	18A
0005432817128	28975	66	18C
0005432817314	28975	67	18D
0005432822134	28975	68	18E
0005432901653	28975	69	18F
0005432817362	28975	70	19A
0005432901659	28975	71	19C
0005434448306	28975	72	19D
0005434186204	28975	73	20C
0005432817209	28975	74	20D
0005434157506	28975	75	20E
0005432901654	28975	76	20F
0005432611723	15060	1	1A
0005435841817	15060	2	1B
0005432611725	15060	3	2A
0005432611724	15060	4	2B
0005432613872	15060	5	3A
0005432613876	15060	6	4A
0005432613873	15060	7	4B
0005432613874	15060	8	5A
0005432611722	15060	9	5B
0005432613875	15060	10	6A
0005432611721	15060	11	6B
0005432607525	31545	1	1A
0005432607563	31545	2	1B
0005432607552	31545	3	2A
0005432611681	31545	4	2B
0005432607527	31545	5	3A
0005435842328	31545	6	3B
0005432607526	31545	7	4A
0005432607556	31545	8	4B
0005432607551	31545	9	5A
0005435842330	31545	10	5B
0005435842329	31545	11	6A
0005432611694	31545	12	6B
0005433569186	11882	1	1C
0005432948235	11882	2	1A
0005433569217	11882	3	1F
0005432948243	11882	4	1D
0005433569231	11882	5	2A
0005433569221	11882	6	2F
0005433569199	11882	7	2D
0005432948238	11882	8	2C
0005433569235	11882	9	3A
0005433569227	11882	10	3D
0005433569238	11882	11	3F
0005432948093	11882	12	4C
0005432948071	11882	13	4A
0005433569224	11882	14	4F
0005432948244	11882	15	4D
0005433569226	11882	16	5A
0005433569229	11882	17	5D
0005432948261	11882	18	6B
0005433569189	11882	19	6A
0005433569202	11882	20	5F
0005432948190	11882	21	6D
0005432948118	11882	22	6C
0005433569214	11882	23	6F
0005432947936	11882	24	7B
0005432948076	11882	25	7E
0005433569191	11882	26	7D
0005433569196	11882	27	7F
0005432948129	11882	28	8C
0005433569222	11882	29	8B
0005433569187	11882	30	8A
0005432948091	11882	31	8D
0005432948149	11882	32	8F
0005432948279	11882	33	9D
0005432948211	11882	34	9C
0005433569182	11882	35	9B
0005433569225	11882	36	10A
0005433569188	11882	37	9F
0005432948318	11882	38	10C
0005433569216	11882	39	10B
0005433569207	11882	40	10D
0005433569215	11882	41	10F
0005433569195	11882	42	10E
0005433569183	11882	43	11B
0005433569237	11882	44	11C
0005433569192	11882	45	11E
0005433569208	11882	46	12B
0005432948092	11882	47	12A
0005432948253	11882	48	11F
0005433569205	11882	49	12C
0005433569197	11882	50	12F
0005433569201	11882	51	12E
0005432947937	11882	52	13C
0005433569232	11882	53	13B
0005433569241	11882	54	13E
0005433569233	11882	55	13D
0005432948196	11882	56	14A
0005432948117	11882	57	13F
0005433569228	11882	58	14B
0005433569240	11882	59	14D
0005432948159	11882	60	14C
0005433569198	11882	61	14F
0005433569194	11882	62	14E
0005433569218	11882	63	15B
0005433569200	11882	64	15A
0005433569203	11882	65	15C
0005433569212	11882	66	15E
0005433569204	11882	67	15D
0005433569206	11882	68	16A
0005432948352	11882	69	16C
0005432948090	11882	70	16B
0005433569209	11882	71	16D
0005432948230	11882	72	17A
0005432948147	11882	73	16F
0005433569219	11882	74	17B
0005433569230	11882	75	17D
0005433569223	11882	76	17C
0005433569190	11882	77	17F
0005432948300	11882	78	17E
0005432948222	11882	79	18A
0005432948079	11882	80	18D
0005432948191	11882	81	18C
0005433569220	11882	82	18E
0005432948270	11882	83	19A
0005433569185	11882	84	19B
0005433569211	11882	85	19D
0005432948158	11882	86	19F
0005432948156	11882	87	19E
0005433569210	11882	88	20B
0005433569236	11882	89	20A
0005433569239	11882	90	20D
0005432948049	11882	91	20F
0005433569184	11882	92	20E
0005433569213	11882	93	21B
0005432948080	11882	94	21A
0005433569234	11882	95	21F
0005432948178	11882	96	21E
0005433569193	11882	97	21D
0005433568650	25286	1	1C
0005432948637	25286	2	1F
0005433568547	25286	3	1D
0005433568781	25286	4	2A
0005432948635	25286	5	2D
0005433568687	25286	6	2C
0005432948630	25286	7	3A
0005433568676	25286	8	3D
0005433568667	25286	9	3C
0005432948618	25286	10	4A
0005433568624	25286	11	3F
0005432948620	25286	12	4D
0005433568769	25286	13	4C
0005433568691	25286	14	5A
0005433568600	25286	15	4F
0005433568784	25286	16	5D
0005432948604	25286	17	5C
0005432948614	25286	18	5F
0005433568727	25286	19	6B
0005433568619	25286	20	6A
0005433568506	25286	21	6C
0005433568664	25286	22	6E
0005432948613	25286	23	6D
0005433568749	25286	24	7A
0005433568574	25286	25	6F
0005432948629	25286	26	7C
0005433568567	25286	27	7E
0005433568699	25286	28	7D
0005432948627	25286	29	8A
0005433568725	25286	30	7F
0005433568541	25286	31	8B
0005432948633	25286	32	8D
0005432948599	25286	33	8C
0005432948622	25286	34	8F
0005432948628	25286	35	8E
0005432948612	25286	36	9B
0005432948616	25286	37	9A
0005432948626	25286	38	9D
0005433568566	25286	39	9C
0005433568635	25286	40	9E
0005433568620	25286	41	10A
0005432948608	25286	42	9F
0005433568657	25286	43	10C
0005432948624	25286	44	10B
0005433568737	25286	45	10E
0005433568780	25286	46	10D
0005432948603	25286	47	10F
0005433568583	25286	48	11C
0005432948617	25286	49	11B
0005432948600	25286	50	11A
0005433568505	25286	51	11D
0005432948602	25286	52	11F
0005432948606	25286	53	11E
0005433568707	25286	54	12B
0005433568733	25286	55	12A
0005433568758	25286	56	12C
0005433568633	25286	57	12E
0005433568736	25286	58	12D
0005432948625	25286	59	13A
0005433568611	25286	60	13C
0005433568734	25286	61	13B
0005433568730	25286	62	13E
0005432948623	25286	63	13D
0005432948636	25286	64	14A
0005433568685	25286	65	13F
0005433568648	25286	66	14C
0005433568721	25286	67	14B
0005433568621	25286	68	14D
0005433568618	25286	69	14F
0005432948609	25286	70	14E
0005433568392	25286	71	15B
0005433568568	25286	72	15A
0005432948601	25286	73	15C
0005433568540	25286	74	15E
0005433568473	25286	75	15D
0005433568759	25286	76	16A
0005433568581	25286	77	16C
0005432948631	25286	78	16D
0005433568726	25286	79	16F
0005433568634	25286	80	16E
0005432948638	25286	81	17B
0005433568746	25286	82	17A
0005432948621	25286	83	17D
0005433568705	25286	84	17E
0005433568703	25286	85	18A
0005433568460	25286	86	17F
0005433568647	25286	87	18C
0005433568805	25286	88	18B
0005432948639	25286	89	18E
0005433568481	25286	90	18D
0005433568731	25286	91	19A
0005432948632	25286	92	18F
0005432948619	25286	93	19C
0005433568565	25286	94	19B
0005432948634	25286	95	19D
0005433568706	25286	96	20A
0005433568649	25286	97	19F
0005433568428	25286	98	19E
0005433568718	25286	99	20C
0005432948607	25286	100	20B
0005433568482	25286	101	20D
0005432948605	25286	102	20E
0005432948610	25286	103	21B
0005432948611	25286	104	21A
0005432948598	25286	105	20F
0005433568632	25286	106	21C
0005433568735	25286	107	21E
0005432948615	25286	108	21D
0005433568766	25286	109	21F
0005434654777	5380	1	1C
0005434654765	5380	2	1D
0005434654786	5380	3	2A
0005435340191	5380	4	3C
0005434654758	5380	5	3D
0005434654784	5380	6	4F
0005434654783	5380	7	5A
0005434654773	5380	8	5D
0005434654787	5380	9	5E
0005434654774	5380	10	5F
0005434656563	5380	11	6A
0005434654782	5380	12	6D
0005435340101	5380	13	6E
0005434654775	5380	14	6F
0005434654776	5380	15	7A
0005434654771	5380	16	7C
0005435340197	5380	17	7D
0005434654772	5380	18	7F
0005434654766	5380	19	8F
0005432114214	5380	20	9C
0005435340082	5380	21	9A
0005434654760	5380	22	9E
0005435340190	5380	23	9F
0005435340172	5380	24	10A
0005434654780	5380	25	10F
0005434654759	5380	26	11F
0005434654763	5380	27	12C
0005435340193	5380	28	12D
0005432114213	5380	29	13A
0005434654767	5380	30	13E
0005434654769	5380	31	14A
0005435340130	5380	32	14F
0005434654761	5380	33	15A
0005434654778	5380	34	16A
0005435340093	5380	35	16C
0005434654770	5380	36	16E
0005434654768	5380	37	16F
0005434654785	5380	38	17A
0005435340187	5380	39	17D
0005434654762	5380	40	17E
0005435340121	5380	41	18A
0005435340122	5380	42	18C
0005435340212	5380	43	18E
0005434654779	5380	44	19C
0005434654781	5380	45	19D
0005435340129	5380	46	19E
0005434654764	5380	47	19F
0005434656562	5380	48	20A
0005432114212	5380	49	20F
0005435340315	12522	1	1D
0005434654612	12522	2	1F
0005434654576	12522	3	2A
0005434654555	12522	4	2C
0005434654613	12522	5	2D
0005434654501	12522	6	2F
0005434654529	12522	7	3C
0005434654346	12522	8	3D
0005434654582	12522	9	3F
0005435340307	12522	10	4A
0005435555377	12522	11	4C
0005435340311	12522	12	4D
0005434654472	12522	13	4E
0005435340313	12522	14	4F
0005434654495	12522	15	5A
0005434654436	12522	16	5C
0005434654526	12522	17	5E
0005434654496	12522	18	6C
0005434654587	12522	19	6E
0005434654459	12522	20	7D
0005435340305	12522	21	7F
0005434654525	12522	22	8E
0005435340302	12522	23	9D
0005434654522	12522	24	10C
0005434654490	12522	25	10D
0005434654541	12522	26	10F
0005434654551	12522	27	11C
0005434654537	12522	28	11D
0005434654430	12522	29	11E
0005435340306	12522	30	12A
0005435340300	12522	31	12E
0005435340314	12522	32	12F
0005434654528	12522	33	13A
0005434654562	12522	34	13C
0005434654538	12522	35	13D
0005434654460	12522	36	13E
0005434654500	12522	37	13F
0005434654552	12522	38	14A
0005435555378	12522	39	14E
0005434654340	12522	40	14F
0005435340309	12522	41	15A
0005434654438	12522	42	15C
0005434654506	12522	43	15E
0005434654400	12522	44	15F
0005434654329	12522	45	16C
0005434654498	12522	46	16F
0005434654345	12522	47	17A
0005435340303	12522	48	17C
0005434654458	12522	49	17D
0005434654473	12522	50	17F
0005435340308	12522	51	17E
0005434654497	12522	52	18A
0005435340301	12522	53	19A
0005435340312	12522	54	19C
0005434654507	12522	55	19D
0005435340310	12522	56	19E
0005434654471	12522	57	20A
0005435340304	12522	58	20C
0005434654439	12522	59	20E
0005434654499	12522	60	20F
0005433716095	7423	1	1A
0005433716101	7423	2	1C
0005432428919	7423	3	1D
0005433716116	7423	4	1F
0005433716123	7423	5	2F
0005433722232	7423	6	3A
0005433716122	7423	7	3C
0005435266117	7423	8	3F
0005432078123	7423	9	4D
0005433722235	7423	10	4C
0005433716138	7423	11	4E
0005433716126	7423	12	5A
0005433716103	7423	13	5C
0005433688813	7423	14	5E
0005432078127	7423	15	5F
0005433719149	7423	16	6C
0005433716141	7423	17	6B
0005433688814	7423	18	6D
0005433716121	7423	19	6F
0005433689916	7423	20	6E
0005433716104	7423	21	7D
0005433716100	7423	22	7E
0005433716125	7423	23	8A
0005433716099	7423	24	8C
0005433716117	7423	25	8D
0005433716136	7423	26	8F
0005433716110	7423	27	8E
0005432078126	7423	28	9A
0005433690931	7423	29	9C
0005433716115	7423	30	9B
0005433716102	7423	31	9D
0005433716120	7423	32	9E
0005433716106	7423	33	10B
0005433656677	7423	34	10E
0005433716127	7423	35	10D
0005433689915	7423	36	11A
0005433716132	7423	37	11F
0005433716133	7423	38	12D
0005432428910	7423	39	12E
0005433716131	7423	40	13A
0005433722234	7423	41	13C
0005433716091	7423	42	13E
0005433716093	7423	43	13F
0005433716090	7423	44	14B
0005433716130	7423	45	14A
0005433716109	7423	46	14C
0005433716140	7423	47	14D
0005433656679	7423	48	15A
0005432078124	7423	49	14F
0005433716092	7423	50	15C
0005433716118	7423	51	15D
0005433722233	7423	52	15F
0005433656678	7423	53	16A
0005433716105	7423	54	16B
0005433716111	7423	55	16D
0005433716135	7423	56	16F
0005433722236	7423	57	16E
0005433716129	7423	58	17B
0005433716113	7423	59	17D
0005432428917	7423	60	18A
0005433716094	7423	61	18B
0005433716128	7423	62	18D
0005433716114	7423	63	19C
0005433716098	7423	64	19B
0005433716107	7423	65	19D
0005433716097	7423	66	20B
0005433716096	7423	67	20D
0005432078125	7423	68	20C
0005433716124	7423	69	20F
0005433719147	7423	70	21B
0005432428921	7423	71	21D
0005433719148	7423	72	22B
0005433716112	7423	73	22A
0005432428918	7423	74	22C
0005433716108	7423	75	22F
0005433716089	7423	76	23A
0005433716134	7423	77	23C
0005433716119	7423	78	23B
0005432428922	7423	79	23D
0005433716137	7423	80	23F
0005433716139	7423	81	23E
0005433722196	29234	1	1A
0005433715644	29234	2	1C
0005433715635	29234	3	1D
0005435266157	29234	4	1F
0005433715734	29234	5	2A
0005435266156	29234	6	2F
0005433719105	29234	7	3D
0005433715599	29234	8	3C
0005433685501	29234	9	3F
0005433656643	29234	10	4A
0005433715776	29234	11	4C
0005433715713	29234	12	4E
0005433722191	29234	13	4F
0005433715439	29234	14	5A
0005433722173	29234	15	5D
0005432428941	29234	16	5E
0005433715414	29234	17	5F
0005433715526	29234	18	6A
0005433715580	29234	19	6C
0005433715911	29234	20	6D
0005433715768	29234	21	6E
0005433715811	29234	22	7A
0005433719098	29234	23	6F
0005433715743	29234	24	7B
0005433715744	29234	25	7D
0005433715631	29234	26	7F
0005433722174	29234	27	8B
0005433715492	29234	28	8D
0005433715784	29234	29	9A
0005435266155	29234	30	9E
0005433715584	29234	31	9F
0005433715605	29234	32	10B
0005435266154	29234	33	10C
0005433722178	29234	34	10E
0005433722183	29234	35	11A
0005433715581	29234	36	11C
0005433722156	29234	37	11E
0005433715770	29234	38	11D
0005433715912	29234	39	12A
0005433715530	29234	40	12B
0005433715777	29234	41	12C
0005433715630	29234	42	12E
0005433715525	29234	43	13C
0005433715738	29234	44	13D
0005433722176	29234	45	13E
0005433715607	29234	46	13F
0005433722179	29234	47	14A
0005433685502	29234	48	14B
0005433715715	29234	49	14D
0005433715555	29234	50	14C
0005433715670	29234	51	14E
0005433715711	29234	52	14F
0005433715735	29234	53	15B
0005433715591	29234	54	15A
0005433715527	29234	55	15C
0005433722180	29234	56	15D
0005433715633	29234	57	15E
0005433719134	29234	58	16A
0005433715608	29234	59	16C
0005433656655	29234	60	16B
0005433715643	29234	61	16D
0005433719126	29234	62	16F
0005433715778	29234	63	16E
0005433715726	29234	64	17A
0005433715737	29234	65	17B
0005433715788	29234	66	17C
0005433715910	29234	67	17F
0005433656644	29234	68	17E
0005433715812	29234	69	18A
0005433722159	29234	70	18B
0005433719125	29234	71	18F
0005433715652	29234	72	19A
0005433656654	29234	73	19B
0005433715789	29234	74	19C
0005432006770	29234	75	19D
0005435266158	29234	76	19F
0005433722175	29234	77	19E
0005433715654	29234	78	20B
0005433715742	29234	79	20A
0005433715415	29234	80	20C
0005433722158	29234	81	20D
0005432428939	29234	82	20E
0005433722157	29234	83	21A
0005432428938	29234	84	20F
0005433715783	29234	85	21B
0005433715646	29234	86	21C
0005433715741	29234	87	22A
0005433715669	29234	88	21F
0005432006769	29234	89	22C
0005433715634	29234	90	22D
0005433722165	29234	91	22E
0005433715645	29234	92	22F
0005433715637	29234	93	23B
0005433722164	29234	94	23C
0005432428940	29234	95	23E
0005433722181	29234	96	23D
0005433715769	29234	97	23F
0005434182171	8700	1	1A
0005434095314	8700	2	1C
0005434095313	8700	3	1D
0005434182165	8700	4	2D
0005434182158	8700	5	3C
0005434095319	8700	6	4A
0005434182123	8700	7	4E
0005434095324	8700	8	4F
0005434095322	8700	9	5E
0005434182112	8700	10	6A
0005434095315	8700	11	6C
0005434182144	8700	12	6F
0005434182089	8700	13	9F
0005434095311	8700	14	10C
0005434184656	8700	15	12A
0005434182157	8700	16	13A
0005434182138	8700	17	13C
0005434182111	8700	18	13D
0005434095317	8700	19	14F
0005434182167	8700	20	15C
0005434182135	8700	21	15D
0005434095323	8700	22	16A
0005434095312	8700	23	16D
0005434095316	8700	24	17A
0005434095321	8700	25	17C
0005434182161	8700	26	17E
0005434095320	8700	27	17F
0005434095318	8700	28	19A
0005434182155	8700	29	19F
0005434184653	8700	30	20C
0005434182220	11667	1	1F
0005434182218	11667	2	2A
0005434182227	11667	3	2C
0005434182228	11667	4	2D
0005434095198	11667	5	4A
0005434182217	11667	6	4D
0005434184669	11667	7	4E
0005434095173	11667	8	4F
0005434095188	11667	9	6A
0005434182223	11667	10	6D
0005434182221	11667	11	7A
0005434182226	11667	12	7F
0005434182216	11667	13	8A
0005434143723	11667	14	9A
0005434183585	11667	15	9C
0005434182224	11667	16	9D
0005434143720	11667	17	10C
0005434143707	11667	18	11D
0005434095263	11667	19	12C
0005434184670	11667	20	12D
0005434183584	11667	21	13C
0005434182225	11667	22	13E
0005434095206	11667	23	15D
0005434095189	11667	24	16D
0005434095172	11667	25	16E
0005434143706	11667	26	17A
0005434182222	11667	27	17D
0005434143719	11667	28	18A
0005434184668	11667	29	19D
0005434095205	11667	30	19F
0005434182219	11667	31	20F
0005433456980	1416	1	1A
0005433398027	1416	2	1C
0005433397870	1416	3	1D
0005433397764	1416	4	1F
0005433397651	1416	5	2A
0005433397840	1416	6	2F
0005433397845	1416	7	3A
0005435732364	1416	8	3C
0005433397869	1416	9	3D
0005433456983	1416	10	3F
0005433397529	1416	11	4A
0005433397650	1416	12	4C
0005433397848	1416	13	4D
0005433397653	1416	14	4E
0005433397703	1416	15	4F
0005433397967	1416	16	5A
0005433397906	1416	17	5C
0005432297284	1416	18	5D
0005433397547	1416	19	5E
0005433397683	1416	20	5F
0005433397883	1416	21	6A
0005433397715	1416	22	6C
0005435732365	1416	23	6D
0005433397700	1416	24	6F
0005433397937	1416	25	7A
0005433397879	1416	26	7C
0005433397765	1416	27	7D
0005433397699	1416	28	7E
0005435732363	1416	29	8A
0005432297285	1416	30	7F
0005433397656	1416	31	8D
0005433397638	1416	32	8F
0005433397727	1416	33	9A
0005433456981	1416	34	9C
0005433397586	1416	35	9D
0005433397681	1416	36	9F
0005433397918	1416	37	10A
0005433397706	1416	38	10C
0005433397767	1416	39	10E
0005433397773	1416	40	10F
0005433397701	1416	41	11D
0005433397771	1416	42	12A
0005433397768	1416	43	12C
0005432297286	1416	44	12F
0005433397756	1416	45	13A
0005435732362	1416	46	13C
0005433397868	1416	47	13D
0005432297287	1416	48	13E
0005433397707	1416	49	13F
0005433397993	1416	50	14A
0005432297288	1416	51	14D
0005433456979	1416	52	14E
0005433397757	1416	53	14F
0005433397654	1416	54	15A
0005433397704	1416	55	15C
0005433397610	1416	56	15E
0005433397754	1416	57	16A
0005433397920	1416	58	16C
0005433397903	1416	59	16D
0005433397804	1416	60	16E
0005433397849	1416	61	17C
0005433397877	1416	62	17E
0005433397772	1416	63	17F
0005433397716	1416	64	18A
0005433397705	1416	65	18E
0005433397728	1416	66	18F
0005433456982	1416	67	19D
0005432906516	1416	68	20A
0005433397731	1416	69	20C
0005435732361	1416	70	20F
0005433398181	19227	1	1A
0005435732280	19227	2	1C
0005433398193	19227	3	1D
0005433398208	19227	4	2A
0005433398195	19227	5	2D
0005435732218	19227	6	3C
0005433398197	19227	7	3D
0005433398175	19227	8	4A
0005433398190	19227	9	4C
0005433398180	19227	10	4D
0005433456957	19227	11	5A
0005433398178	19227	12	5C
0005433398214	19227	13	5E
0005435732289	19227	14	6A
0005433398207	19227	15	6C
0005433456950	19227	16	6D
0005433398176	19227	17	6E
0005433398213	19227	18	6F
0005433398215	19227	19	7A
0005435732275	19227	20	7C
0005433398183	19227	21	7D
0005433398223	19227	22	7F
0005433398199	19227	23	8A
0005433398189	19227	24	8C
0005433398219	19227	25	8D
0005433456951	19227	26	8F
0005435732274	19227	27	9D
0005433398179	19227	28	9E
0005433398210	19227	29	10D
0005433398206	19227	30	11C
0005433398202	19227	31	11D
0005433398216	19227	32	11F
0005433398182	19227	33	12A
0005435732261	19227	34	12D
0005433398218	19227	35	12E
0005433398185	19227	36	12F
0005433398196	19227	37	13A
0005433398201	19227	38	13C
0005433398221	19227	39	13D
0005433398177	19227	40	13E
0005435732249	19227	41	13F
0005433398204	19227	42	14A
0005435732252	19227	43	14C
0005433398188	19227	44	14E
0005433398200	19227	45	14F
0005433398212	19227	46	15A
0005432906542	19227	47	15C
0005432906543	19227	48	15D
0005433398187	19227	49	15E
0005433398222	19227	50	15F
0005433398192	19227	51	16D
0005433398220	19227	52	16F
0005433456953	19227	53	17C
0005435732233	19227	54	17D
0005433398198	19227	55	17E
0005433398186	19227	56	18C
0005433398205	19227	57	18D
0005433398209	19227	58	18E
0005433398211	19227	59	18F
0005433398217	19227	60	19A
0005433398174	19227	61	19C
0005433398194	19227	62	19E
0005433398191	19227	63	19F
0005433398203	19227	64	20C
0005435732262	19227	65	20D
0005433398184	19227	66	20E
0005433456949	19227	67	20F
0005434443553	17342	1	1B
0005434443628	17342	2	1C
0005434443635	17342	3	1D
0005434443549	17342	4	2C
0005434443491	17342	5	2B
0005434443591	17342	6	2D
0005434443674	17342	7	3A
0005434443572	17342	8	3B
0005434443595	17342	9	3C
0005434443627	17342	10	4B
0005434443588	17342	11	4C
0005434443624	17342	12	7C
0005434443575	17342	13	7B
0005434443586	17342	14	18A
0005434443637	17342	15	18C
0005434443576	17342	16	19A
0005434443598	17342	17	19B
0005434443573	17342	18	19C
0005434443550	17342	19	19D
0005434443594	17342	20	20C
0005434443636	17342	21	20D
0005434443599	17342	22	21B
0005434443548	17342	23	21C
0005434443589	17342	24	22A
0005434443626	17342	25	22B
0005434443625	17342	26	23A
0005434443655	17342	27	23B
0005434443750	20601	1	1B
0005434443744	20601	2	1D
0005434443745	20601	3	3D
0005434443742	20601	4	4A
0005434443738	20601	5	6A
0005434443749	20601	6	6C
0005434443740	20601	7	18A
0005434443753	20601	8	18C
0005434443746	20601	9	18D
0005434443741	20601	10	19D
0005434443748	20601	11	20A
0005434443747	20601	12	20B
0005434443751	20601	13	21A
0005434443743	20601	14	21B
0005434443752	20601	15	21D
0005434443739	20601	16	22D
0005434443754	20601	17	23B
0005435377574	7287	1	1A
0005435377572	7287	2	1B
0005435377570	7287	3	2A
0005435377575	7287	4	2B
0005434954618	7287	5	3A
0005435377567	7287	6	4A
0005434954620	7287	7	4B
0005434954619	7287	8	5A
0005434954621	7287	9	5B
0005435377566	7287	10	6A
0005435377571	7287	11	6B
0005434954589	28335	1	1B
0005434954576	28335	2	3B
0005434954603	28335	3	3A
0005434954602	28335	4	6A
0005435377587	28335	5	6B
0005435893615	4469	1	1A
0005435893567	4469	2	1B
0005434351732	4469	3	1D
0005434351735	4469	4	2B
0005434183564	4469	5	2C
0005434351726	4469	6	2D
0005435893588	4469	7	3A
0005435893628	4469	8	3C
0005434183565	4469	9	3D
0005434351737	4469	10	4A
0005434351736	4469	11	4C
0005434183556	4469	12	5A
0005435893577	4469	13	6A
0005434351728	4469	14	6B
0005435893566	4469	15	6D
0005434351733	4469	16	7A
0005434351738	4469	17	7B
0005434351729	4469	18	18D
0005434351739	4469	19	19A
0005434351731	4469	20	19B
0005435893597	4469	21	20A
0005434351734	4469	22	20B
0005434351730	4469	23	20C
0005434351727	4469	24	21A
0005435893619	4469	25	21B
0005435893598	4469	26	22D
0005435893568	4469	27	23B
0005435893650	29654	1	1A
0005434351553	29654	2	1B
0005435893649	29654	3	1C
0005435893652	29654	4	1D
0005434351653	29654	5	2C
0005435893651	29654	6	2D
0005434351616	29654	7	3A
0005434351590	29654	8	3D
0005434351633	29654	9	4C
0005434351650	29654	10	4D
0005434351639	29654	11	5B
0005434351634	29654	12	7A
0005435893654	29654	13	7B
0005434351632	29654	14	18C
0005434351615	29654	15	18D
0005434351583	29654	16	19B
0005434351651	29654	17	19D
0005434351584	29654	18	20D
0005434351637	29654	19	21A
0005434351595	29654	20	21C
0005435893655	29654	21	22A
0005434351638	29654	22	22C
0005434351581	29654	23	22D
0005435893653	29654	24	23B
0005435092100	1079	1	1C
0005433342543	1079	2	1B
0005433342521	1079	3	1F
0005433269686	1079	4	1H
0005435092099	1079	5	1G
0005433342426	1079	6	2A
0005433342031	1079	7	2C
0005433159307	1079	8	2B
0005433342664	1079	9	2F
0005433342464	1079	10	2H
0005433342320	1079	11	2G
0005433159293	1079	12	3C
0005433342523	1079	13	3F
0005435092103	1079	14	4A
0005433342765	1079	15	3H
0005433342535	1079	16	4C
0005433343002	1079	17	5F
0005433342753	1079	18	5H
0005433342929	1079	19	9G
0005433342348	1079	20	11A
0005433342425	1079	21	9H
0005434445255	1079	22	11B
0005433342542	1079	23	11E
0005433342690	1079	24	11D
0005433342643	1079	25	11H
0005433269677	1079	26	12A
0005433342500	1079	27	12D
0005433342735	1079	28	12B
0005433342899	1079	29	12F
0005433342261	1079	30	12H
0005433342460	1079	31	13D
0005433342143	1079	32	13G
0005433342631	1079	33	13F
0005433463906	1079	34	13H
0005433342391	1079	35	14B
0005433342509	1079	36	14D
0005433342316	1079	37	14H
0005433342278	1079	38	14G
0005433342299	1079	39	15A
0005433342759	1079	40	15B
0005433342226	1079	41	15F
0005433342622	1079	42	15E
0005435092102	1079	43	15H
0005433342621	1079	44	16A
0005433269676	1079	45	16B
0005433342691	1079	46	16F
0005433342336	1079	47	16H
0005433342654	1079	48	16G
0005433343003	1079	49	17D
0005433342456	1079	50	17E
0005433159294	1079	51	17G
0005433342308	1079	52	17F
0005433159304	1079	53	17H
0005433342030	1079	54	18A
0005433342828	1079	55	18D
0005435092101	1079	56	18F
0005433342928	1079	57	18E
0005433462753	1079	58	18G
0005433342630	1079	59	18H
0005434445254	1079	60	19B
0005432293215	1079	61	19D
0005433342520	1079	62	20A
0005433342695	1079	63	20B
0005433342472	1079	64	20E
0005435092105	1079	65	20G
0005433462752	1079	66	21A
0005433342576	1079	67	21B
0005433342776	1079	68	21E
0005433342790	1079	69	21F
0005433342663	1079	70	21H
0005433342216	1079	71	22B
0005433342071	1079	72	22F
0005433342291	1079	73	22G
0005433463907	1079	74	22H
0005433342564	1079	75	23B
0005433342390	1079	76	23D
0005433342737	1079	77	23E
0005433342319	1079	78	23G
0005433342845	1079	79	23F
0005433343070	1079	80	24A
0005433342736	1079	81	24D
0005433342277	1079	82	24H
0005433341864	1079	83	24G
0005433342349	1079	84	25D
0005433158117	1079	85	25E
0005433342301	1079	86	27A
0005433342594	1079	87	27B
0005433342335	1079	88	27E
0005433343024	1079	89	27D
0005433342187	1079	90	27F
0005433342424	1079	91	28A
0005433342827	1079	92	28B
0005433342785	1079	93	28E
0005433342557	1079	94	28D
0005433342593	1079	95	28F
0005433269689	1079	96	28H
0005433342752	1079	97	28G
0005433342497	1079	98	29D
0005433342775	1079	99	29G
0005433343023	1079	100	29F
0005433342341	1079	101	30A
0005435092098	1079	102	30D
0005433342541	1079	103	30F
0005433342644	1079	104	30E
0005433342859	1079	105	30G
0005433342321	1079	106	31A
0005433342538	1079	107	30H
0005435092104	1079	108	31B
0005433342667	1079	109	31D
0005433342418	1079	110	31F
0005433159295	1079	111	31E
0005433342376	1079	112	32A
0005433342333	1079	113	32B
0005433342758	1079	114	32E
0005433342544	1079	115	32D
0005433342276	1079	116	32F
0005433342496	1079	117	32H
0005433342300	1079	118	32G
0005433342857	1079	119	33D
0005433342653	1079	120	33E
0005435092107	1079	121	33H
0005433342215	1079	122	34A
0005433342242	1079	123	34B
0005433342243	1079	124	34E
0005433342317	1079	125	34F
0005433342461	1079	126	34H
0005435092106	1079	127	35B
0005433158127	1079	128	35D
0005433342259	1079	129	35F
0005433342637	1079	130	35E
0005433342867	1079	131	36A
0005433342679	1079	132	35H
0005433269697	1079	133	36B
0005433342318	1079	134	36E
0005432293216	1079	135	36D
0005433342455	1079	136	36G
0005433341985	1079	137	36H
0005433158126	1079	138	37D
0005433342822	1079	139	37E
0005433342356	1079	140	37G
0005433342323	1079	141	38A
0005433269657	1079	142	37H
0005433342702	1079	143	38D
0005433269691	1079	144	38B
0005433342858	1079	145	38F
0005433269690	1079	146	38H
0005433342504	1079	147	38G
0005433342355	1079	148	39D
0005433343370	17066	1	1B
0005433343332	17066	2	1G
0005433343363	17066	3	2A
0005433343378	17066	4	2B
0005433269735	17066	5	2C
0005433343376	17066	6	2H
0005433343386	17066	7	2G
0005433343408	17066	8	3C
0005434445225	17066	9	4C
0005433343335	17066	10	4A
0005435508233	17066	11	4F
0005433343405	17066	12	4G
0005435092002	17066	13	5A
0005433343346	17066	14	4H
0005433343412	17066	15	5C
0005433343410	17066	16	5H
0005435092035	17066	17	5G
0005433343391	17066	18	9B
0005433343397	17066	19	9H
0005433343377	17066	20	9G
0005435092032	17066	21	11A
0005433343358	17066	22	11D
0005433343407	17066	23	11F
0005433343368	17066	24	11G
0005433269733	17066	25	11H
0005433343380	17066	26	12F
0005435508244	17066	27	12H
0005435092023	17066	28	12G
0005433343382	17066	29	13B
0005435508267	17066	30	13A
0005433343342	17066	31	13H
0005433343339	17066	32	14E
0005433343333	17066	33	15A
0005433343379	17066	34	15D
0005435091973	17066	35	15E
0005433343330	17066	36	15G
0005433343359	17066	37	15H
0005435508232	17066	38	16B
0005433343328	17066	39	16E
0005433343352	17066	40	16H
0005433343383	17066	41	16G
0005433343349	17066	42	17B
0005433343372	17066	43	17D
0005433343318	17066	44	17F
0005433343360	17066	45	17E
0005433343392	17066	46	17H
0005433343327	17066	47	18A
0005433343396	17066	48	18D
0005433343404	17066	49	18F
0005433343319	17066	50	19E
0005433343357	17066	51	19D
0005433343341	17066	52	20A
0005433343375	17066	53	20B
0005433343401	17066	54	20E
0005435508275	17066	55	20D
0005433343337	17066	56	20G
0005433343351	17066	57	20H
0005433343326	17066	58	21A
0005433343371	17066	59	21B
0005433343324	17066	60	21H
0005433343409	17066	61	21G
0005433343398	17066	62	22B
0005433343331	17066	63	22A
0005433343325	17066	64	22F
0005433343338	17066	65	22E
0005433343347	17066	66	22G
0005435092021	17066	67	23B
0005433343320	17066	68	23D
0005433343329	17066	69	23E
0005433343413	17066	70	24A
0005433343345	17066	71	24D
0005433159318	17066	72	24B
0005433343336	17066	73	24F
0005433343393	17066	74	24G
0005433343365	17066	75	25D
0005433343399	17066	76	24H
0005433343389	17066	77	25F
0005433343384	17066	78	25E
0005433343340	17066	79	27B
0005433343321	17066	80	27A
0005433343387	17066	81	27F
0005433343388	17066	82	28A
0005433159319	17066	83	28B
0005433343394	17066	84	28F
0005435508231	17066	85	28G
0005435508245	17066	86	29A
0005433343364	17066	87	29E
0005433343348	17066	88	29F
0005435091972	17066	89	29H
0005433269732	17066	90	29G
0005435508251	17066	91	30B
0005433343322	17066	92	30A
0005433343400	17066	93	30D
0005435092022	17066	94	30E
0005433343374	17066	95	30G
0005433269731	17066	96	30H
0005433343367	17066	97	31B
0005433343385	17066	98	31F
0005433343406	17066	99	31H
0005433343403	17066	100	32A
0005433343402	17066	101	32B
0005433343369	17066	102	32E
0005433343343	17066	103	32D
0005435091992	17066	104	32H
0005433343344	17066	105	32G
0005433159317	17066	106	33A
0005433269734	17066	107	33E
0005435508226	17066	108	33F
0005433343334	17066	109	33H
0005433343395	17066	110	34A
0005435092031	17066	111	34D
0005433343355	17066	112	34B
0005435091981	17066	113	34F
0005433343366	17066	114	34E
0005433343317	17066	115	34G
0005433343411	17066	116	34H
0005433343356	17066	117	35B
0005433343361	17066	118	35A
0005433343390	17066	119	35H
0005433343362	17066	120	36A
0005433343354	17066	121	36E
0005433343373	17066	122	36F
0005433269736	17066	123	36G
0005433343350	17066	124	36H
0005433343314	17066	125	37B
0005433343323	17066	126	37D
0005433343315	17066	127	37F
0005433343316	17066	128	38A
0005433343353	17066	129	38E
0005433343381	17066	130	38D
0005432390160	1342	1	1F
0005432851856	1342	2	1D
0005432851822	1342	3	2A
0005432392004	1342	4	2D
0005432851889	1342	5	2F
0005432390164	1342	6	3C
0005432390166	1342	7	4A
0005432390156	1342	8	3D
0005432390138	1342	9	4C
0005432391999	1342	10	4F
0005432390181	1342	11	4D
0005432390159	1342	12	5C
0005432390143	1342	13	5A
0005432851868	1342	14	5D
0005432390148	1342	15	6A
0005432391996	1342	16	5F
0005432390155	1342	17	6E
0005432392001	1342	18	7A
0005432851871	1342	19	6F
0005432390136	1342	20	7C
0005432851876	1342	21	7E
0005432851869	1342	22	7D
0005432390177	1342	23	8C
0005432851865	1342	24	8B
0005432390171	1342	25	8D
0005432390145	1342	26	8E
0005432851888	1342	27	9A
0005432851845	1342	28	9C
0005432390154	1342	29	10A
0005432390147	1342	30	9F
0005432390161	1342	31	10C
0005432390163	1342	32	10B
0005432851870	1342	33	11A
0005432851867	1342	34	10F
0005432390174	1342	35	10E
0005432851881	1342	36	11B
0005432392003	1342	37	11D
0005432851878	1342	38	11C
0005432851847	1342	39	11F
0005432851880	1342	40	12B
0005432390175	1342	41	12D
0005432390142	1342	42	12C
0005432390157	1342	43	12F
0005432390172	1342	44	12E
0005432390153	1342	45	13A
0005432851866	1342	46	13C
0005432851861	1342	47	13B
0005432851864	1342	48	13E
0005432390150	1342	49	13D
0005432390173	1342	50	13F
0005432390179	1342	51	14B
0005432390169	1342	52	14A
0005432390140	1342	53	14D
0005432391997	1342	54	14C
0005432390167	1342	55	14F
0005432851877	1342	56	14E
0005432390162	1342	57	15B
0005432851844	1342	58	15A
0005432390170	1342	59	15D
0005432851842	1342	60	15C
0005432390149	1342	61	15E
0005432390180	1342	62	16B
0005432391998	1342	63	15F
0005432390165	1342	64	16E
0005432851843	1342	65	16D
0005432851862	1342	66	16C
0005432851879	1342	67	17A
0005432390158	1342	68	17B
0005432390137	1342	69	17D
0005432392005	1342	70	17C
0005432851882	1342	71	17F
0005432390135	1342	72	17E
0005432390168	1342	73	18A
0005432390178	1342	74	18D
0005432851848	1342	75	18C
0005432851898	1342	76	18E
0005432390151	1342	77	19A
0005432392000	1342	78	18F
0005432390141	1342	79	19B
0005432390152	1342	80	19D
0005432392006	1342	81	19C
0005432851846	1342	82	19E
0005432390144	1342	83	20B
0005432390176	1342	84	20A
0005432390139	1342	85	20D
0005432392002	1342	86	20C
0005432390146	1342	87	20F
0005432390182	1342	88	20E
0005432851863	1342	89	21A
0005432851891	1342	90	21C
0005432391995	1342	91	21B
0005432851858	1342	92	21E
0005432433697	12770	1	1C
0005434067165	12770	2	1F
0005434067337	12770	3	1D
0005434067294	12770	4	2A
0005434081740	12770	5	2F
0005434067077	12770	6	2D
0005433989736	12770	7	3A
0005434067016	12770	8	3D
0005434067095	12770	9	4B
0005433812907	12770	10	4C
0005434081756	12770	11	4D
0005434067028	12770	12	4E
0005434067375	12770	13	4F
0005434067048	12770	14	5A
0005434067231	12770	15	5C
0005434066862	12770	16	5B
0005434067128	12770	17	5F
0005435283410	12770	18	6B
0005434067056	12770	19	6C
0005434081737	12770	20	6D
0005434067099	12770	21	6F
0005434067413	12770	22	7B
0005432161158	12770	23	7A
0005434067029	12770	24	7D
0005434067119	12770	25	7C
0005434067058	12770	26	7F
0005434067141	12770	27	7E
0005434067290	12770	28	8A
0005434081881	12770	29	8C
0005434067164	12770	30	8D
0005433812908	12770	31	8F
0005434066983	12770	32	8E
0005434081767	12770	33	9A
0005435283409	12770	34	9B
0005434067150	12770	35	9D
0005434081844	12770	36	9F
0005432159871	12770	37	9E
0005434067185	12770	38	10B
0005434067137	12770	39	10D
0005434067139	12770	40	10C
0005434067049	12770	41	11A
0005432159869	12770	42	10E
0005434066696	12770	43	11B
0005434081749	12770	44	11D
0005432433694	12770	45	11C
0005433989733	12770	46	11F
0005432159872	12770	47	11E
0005434066865	12770	48	12A
0005434067377	12770	49	12C
0005434081682	12770	50	12B
0005434067338	12770	51	12E
0005434066915	12770	52	12F
0005434066960	12770	53	13E
0005434066976	12770	54	13D
0005432161159	12770	55	13F
0005434067258	12770	56	14B
0005434067120	12770	57	14A
0005434067118	12770	58	14C
0005433989734	12770	59	14F
0005434066869	12770	60	15A
0005434067147	12770	61	15C
0005434067078	12770	62	15B
0005434067053	12770	63	15D
0005434067206	12770	64	15E
0005434067138	12770	65	15F
0005434081758	12770	66	16A
0005434067142	12770	67	16C
0005434067152	12770	68	16E
0005434081716	12770	69	16D
0005434067129	12770	70	17A
0005434067427	12770	71	16F
0005434067376	12770	72	17D
0005434081681	12770	73	17C
0005434067057	12770	74	17E
0005434067059	12770	75	18A
0005433989745	12770	76	18B
0005434067098	12770	77	18C
0005434067367	12770	78	18E
0005434067135	12770	79	18D
0005433812909	12770	80	19A
0005434067443	12770	81	18F
0005434067295	12770	82	19C
0005434081706	12770	83	19B
0005433812906	12770	84	19E
0005432159873	12770	85	19D
0005432433696	12770	86	19F
0005432433695	12770	87	20A
0005434067368	12770	88	20B
0005434081736	12770	89	20C
0005434067140	12770	90	20D
0005433989724	12770	91	20F
0005434067154	12770	92	21A
0005434067369	12770	93	21C
0005434067105	12770	94	21B
0005434067194	12770	95	21E
0005432159870	12770	96	22A
0005434067166	12770	97	22B
0005434067153	12770	98	22C
0005434066945	12770	99	22D
0005434081686	12770	100	22E
0005434067136	12770	101	22F
0005432433693	12770	102	23B
0005434081739	12770	103	23C
0005434066864	12770	104	23E
0005434081738	12770	105	23D
0005434066958	12770	106	23F
0005434067707	30688	1	1A
0005432150209	30688	2	1C
0005434081948	30688	3	1F
0005434067697	30688	4	1D
0005432433628	30688	5	2C
0005434067715	30688	6	2A
0005434067691	30688	7	2D
0005434081933	30688	8	2F
0005434067720	30688	9	3A
0005434067734	30688	10	3D
0005434081944	30688	11	3C
0005434067683	30688	12	3F
0005434081940	30688	13	4A
0005434081943	30688	14	4B
0005434067679	30688	15	4D
0005434067745	30688	16	4C
0005432186875	30688	17	4E
0005434067685	30688	18	4F
0005434067676	30688	19	5B
0005434067686	30688	20	5A
0005434081931	30688	21	5C
0005434067716	30688	22	5D
0005434067712	30688	23	5E
0005434067729	30688	24	6A
0005434081929	30688	25	5F
0005434067731	30688	26	6B
0005434067741	30688	27	6C
0005432433669	30688	28	6D
0005433989782	30688	29	6F
0005434081949	30688	30	6E
0005432433653	30688	31	7A
0005434067709	30688	32	7C
0005434067719	30688	33	7B
0005434067677	30688	34	7D
0005433989779	30688	35	7F
0005434067699	30688	36	7E
0005432150213	30688	37	8A
0005434067714	30688	38	8B
0005434067718	30688	39	8C
0005432150208	30688	40	8E
0005434067695	30688	41	8D
0005434067694	30688	42	9A
0005434067736	30688	43	8F
0005434067711	30688	44	9D
0005434067698	30688	45	9C
0005432186877	30688	46	9F
0005434081937	30688	47	9E
0005434067682	30688	48	10B
0005434081932	30688	49	10D
0005434067692	30688	50	10C
0005434067706	30688	51	10E
0005434067721	30688	52	11A
0005433989778	30688	53	11B
0005434067733	30688	54	11C
0005434067737	30688	55	11E
0005432150212	30688	56	11D
0005434067688	30688	57	11F
0005432433648	30688	58	12A
0005434067702	30688	59	12C
0005434067680	30688	60	12B
0005434067746	30688	61	12E
0005434067678	30688	62	12D
0005434067704	30688	63	12F
0005434067700	30688	64	13A
0005434067681	30688	65	13C
0005434067723	30688	66	13B
0005434081946	30688	67	13D
0005432186878	30688	68	13F
0005434067725	30688	69	14B
0005434081942	30688	70	14A
0005434081945	30688	71	14C
0005434067717	30688	72	14D
0005434067687	30688	73	14E
0005432186880	30688	74	14F
0005434081952	30688	75	15B
0005434081953	30688	76	15A
0005432150207	30688	77	15C
0005434067732	30688	78	15D
0005434067728	30688	79	15E
0005434067738	30688	80	15F
0005432433650	30688	81	16B
0005434081934	30688	82	16A
0005434067739	30688	83	16C
0005434081938	30688	84	16E
0005434067690	30688	85	16D
0005434067713	30688	86	16F
0005434067684	30688	87	17A
0005434067708	30688	88	17B
0005434081930	30688	89	17D
0005434067722	30688	90	17F
0005434081947	30688	91	17E
0005432150214	30688	92	18A
0005434067730	30688	93	18B
0005434067701	30688	94	18C
0005432150211	30688	95	18E
0005434081939	30688	96	18D
0005434067703	30688	97	18F
0005433989780	30688	98	19A
0005434081950	30688	99	19B
0005434067724	30688	100	19D
0005434067689	30688	101	19C
0005434067735	30688	102	19E
0005434081951	30688	103	19F
0005432433652	30688	104	20B
0005433989781	30688	105	20A
0005432150210	30688	106	20C
0005432433651	30688	107	20D
0005434081941	30688	108	20E
0005434067693	30688	109	20F
0005434067743	30688	110	21C
0005432186879	30688	111	21B
0005434067740	30688	112	21D
0005434067742	30688	113	21E
0005432433660	30688	114	21F
0005434067705	30688	115	22C
0005434081935	30688	116	22B
0005434067744	30688	117	22D
0005434081936	30688	118	22E
0005434067710	30688	119	23A
0005432433661	30688	120	22F
0005432433657	30688	121	23B
0005434067696	30688	122	23C
0005434067727	30688	123	23D
0005432186876	30688	124	23F
0005434067726	30688	125	23E
0005433685532	9034	1	1B
0005433685534	9034	2	2A
0005433687713	9034	3	2C
0005433687716	9034	4	4A
0005433685533	9034	5	5A
0005433687715	9034	6	5B
0005433687714	9034	7	5D
0005433687717	9034	8	6C
0005433686644	9034	9	6D
0005433685529	9034	10	7B
0005433686646	9034	11	18A
0005433685535	9034	12	19C
0005433685530	9034	13	20B
0005433686641	9034	14	20C
0005433686642	9034	15	20D
0005433685531	9034	16	21C
0005433686643	9034	17	22C
0005433687718	9034	18	23A
0005433686645	9034	19	23B
0005435766360	5521	1	1A
0005434831133	5521	2	1B
0005435725612	5521	3	1F
0005435766392	5521	4	1C
0005434264927	5521	5	1G
0005434265000	5521	6	2A
0005435462321	5521	7	1H
0005435462236	5521	8	2C
0005435462331	5521	9	2B
0005434264965	5521	10	2F
0005435723052	5521	11	2G
0005435462333	5521	12	3A
0005435462104	5521	13	2H
0005435766408	5521	14	3C
0005435462271	5521	15	3B
0005435735146	5521	16	3F
0005435766374	5521	17	3G
0005435766410	5521	18	4A
0005435766416	5521	19	3H
0005435462392	5521	20	4B
0005435766417	5521	21	4F
0005435766365	5521	22	4G
0005435462351	5521	23	4H
0005434264938	5521	24	5B
0005435766397	5521	25	5C
0005434265001	5521	26	9A
0005435462106	5521	27	9B
0005435766399	5521	28	9G
0005434831114	5521	29	9H
0005435766398	5521	30	11B
0005434831093	5521	31	11E
0005433529291	5521	32	11F
0005435462184	5521	33	11H
0005435766420	5521	34	11G
0005432140470	5521	35	12A
0005435462159	5521	36	12D
0005435462115	5521	37	12B
0005435462133	5521	38	12E
0005435723051	5521	39	12F
0005434265086	5521	40	12G
0005434264937	5521	41	13A
0005435766418	5521	42	13D
0005435766388	5521	43	13E
0005432140468	5521	44	13G
0005434264962	5521	45	13F
0005433527281	5521	46	13H
0005434264895	5521	47	14B
0005434264896	5521	48	14A
0005433529290	5521	49	14E
0005435462398	5521	50	14D
0005435766404	5521	51	14F
0005433527280	5521	52	14G
0005432140473	5521	53	15A
0005434264933	5521	54	15E
0005435766413	5521	55	15F
0005435462145	5521	56	15H
0005435462285	5521	57	15G
0005435735145	5521	58	16B
0005435462146	5521	59	16A
0005434264961	5521	60	16E
0005435766426	5521	61	16D
0005435766396	5521	62	16G
0005434265003	5521	63	16F
0005435720825	5521	64	17B
0005435766395	5521	65	17A
0005434264963	5521	66	17D
0005433527279	5521	67	17E
0005435766364	5521	68	17G
0005435766379	5521	69	17F
0005432535798	5521	70	18A
0005435766382	5521	71	17H
0005435766384	5521	72	18B
0005434264953	5521	73	18D
0005432535781	5521	74	18E
0005435766376	5521	75	18G
0005435766366	5521	76	19A
0005434264928	5521	77	18H
0005435766375	5521	78	19F
0005435462276	5521	79	19G
0005434264894	5521	80	20A
0005435766386	5521	81	19H
0005435462397	5521	82	20B
0005435766385	5521	83	20E
0005435462056	5521	84	20D
0005435766394	5521	85	20F
0005435043281	5521	86	20H
0005435723050	5521	87	20G
0005435766393	5521	88	21A
0005435766373	5521	89	21B
0005434265040	5521	90	21E
0005435766424	5521	91	21F
0005434264936	5521	92	22A
0005435766419	5521	93	21H
0005435462352	5521	94	21G
0005434265039	5521	95	22D
0005435766412	5521	96	22G
0005434831097	5521	97	23B
0005435766378	5521	98	23D
0005435462270	5521	99	23F
0005435766405	5521	100	23E
0005432140471	5521	101	23G
0005434264985	5521	102	23H
0005435766387	5521	103	24B
0005435725610	5521	104	24D
0005435462322	5521	105	24F
0005432535782	5521	106	24G
0005433527277	5521	107	25D
0005435766401	5521	108	24H
0005435766403	5521	109	25F
0005435766422	5521	110	25E
0005435462308	5521	111	27A
0005435462141	5521	112	27E
0005433527278	5521	113	27D
0005435735147	5521	114	27F
0005435766377	5521	115	27G
0005434265004	5521	116	28A
0005435462304	5521	117	28B
0005434264984	5521	118	28D
0005435766381	5521	119	28G
0005435766423	5521	120	28E
0005435766402	5521	121	28H
0005435462309	5521	122	29A
0005432140467	5521	123	29D
0005435766383	5521	124	29B
0005435462158	5521	125	29E
0005434831116	5521	126	29G
0005435766406	5521	127	29F
0005435722062	5521	128	30A
0005435462391	5521	129	30D
0005435766400	5521	130	30B
0005435462142	5521	131	30F
0005435462330	5521	132	30E
0005432140474	5521	133	30G
0005435766368	5521	134	31B
0005435766414	5521	135	31E
0005435766369	5521	136	31F
0005434264876	5521	137	31G
0005435462305	5521	138	32A
0005435766409	5521	139	31H
0005434264935	5521	140	32D
0005435462105	5521	141	32B
0005435766361	5521	142	32F
0005434264929	5521	143	32E
0005434264954	5521	144	33F
0005434265002	5521	145	33H
0005435766407	5521	146	34B
0005435766415	5521	147	34A
0005432140472	5521	148	34D
0005432535813	5521	149	34F
0005435766362	5521	150	34E
0005432535795	5521	151	34G
0005435462399	5521	152	35A
0005432140475	5521	153	34H
0005435462310	5521	154	35B
0005435766371	5521	155	35E
0005435725613	5521	156	35D
0005435766389	5521	157	35G
0005435766391	5521	158	36A
0005434265017	5521	159	35H
0005435766411	5521	160	36B
0005435462134	5521	161	36E
0005435462247	5521	162	36F
0005432535783	5521	163	36H
0005435043278	5521	164	36G
0005432140469	5521	165	37D
0005435725609	5521	166	37B
0005434264911	5521	167	37E
0005435766367	5521	168	37F
0005435462114	5521	169	37G
0005435725611	5521	170	38B
0005435766390	5521	171	38F
0005435766380	5521	172	38E
0005435766370	5521	173	38D
0005435735144	5521	174	38H
0005435766372	5521	175	38G
0005435766421	5521	176	39E
0005435766363	5521	177	39D
0005435766425	5521	178	39F
0005434265210	13448	1	1C
0005435765888	13448	2	1G
0005435765957	13448	3	1H
0005435462561	13448	4	2F
0005435765605	13448	5	2G
0005432194524	13448	6	3A
0005434265217	13448	7	2H
0005435765976	13448	8	3B
0005435462532	13448	9	3F
0005435462557	13448	10	4B
0005432535846	13448	11	4A
0005435765807	13448	12	4C
0005434265222	13448	13	4H
0005435765906	13448	14	5B
0005434265226	13448	15	5C
0005435462529	13448	16	5G
0005432535848	13448	17	5F
0005435735114	13448	18	9H
0005435765818	13448	19	9G
0005435462540	13448	20	11D
0005434265214	13448	21	11E
0005434265208	13448	22	11H
0005432194522	13448	23	11G
0005434265221	13448	24	12A
0005435462545	13448	25	12E
0005435765847	13448	26	12F
0005435765758	13448	27	12H
0005435765788	13448	28	12G
0005435462555	13448	29	13A
0005435765820	13448	30	13D
0005435462556	13448	31	13G
0005435765879	13448	32	14A
0005435765939	13448	33	14F
0005435765808	13448	34	14H
0005434265218	13448	35	15A
0005435735100	13448	36	15D
0005434265220	13448	37	15B
0005434831167	13448	38	15E
0005435765420	13448	39	15G
0005434265212	13448	40	15H
0005435765771	13448	41	16A
0005435462553	13448	42	16D
0005435735125	13448	43	16B
0005435462536	13448	44	16E
0005435735116	13448	45	16H
0005435462530	13448	46	17D
0005435765886	13448	47	17F
0005435462549	13448	48	17E
0005435765772	13448	49	17H
0005435462560	13448	50	18B
0005435462558	13448	51	18D
0005435462541	13448	52	18F
0005435765913	13448	53	18E
0005435765800	13448	54	18H
0005432535849	13448	55	18G
0005435765419	13448	56	19B
0005435765730	13448	57	19A
0005435735120	13448	58	19E
0005435462550	13448	59	19F
0005435765908	13448	60	19G
0005435462537	13448	61	20A
0005435765709	13448	62	19H
0005435765705	13448	63	20E
0005434831163	13448	64	21B
0005435462533	13448	65	21E
0005435462546	13448	66	21G
0005432535850	13448	67	21F
0005435462565	13448	68	21H
0005435725594	13448	69	22B
0005435765609	13448	70	22A
0005434265227	13448	71	22D
0005434265215	13448	72	22G
0005435765769	13448	73	22F
0005432194521	13448	74	22H
0005435765765	13448	75	23B
0005435765941	13448	76	23E
0005435462568	13448	77	23D
0005435765878	13448	78	23F
0005435462554	13448	79	23G
0005435765701	13448	80	24D
0005434265213	13448	81	24F
0005435765927	13448	82	24E
0005435765831	13448	83	24H
0005435735115	13448	84	25D
0005434265219	13448	85	27A
0005432535847	13448	86	27B
0005435765912	13448	87	27F
0005434831166	13448	88	27G
0005435462567	13448	89	28A
0005435462539	13448	90	28B
0005434831165	13448	91	28E
0005434265229	13448	92	28D
0005435765935	13448	93	28F
0005435765757	13448	94	28H
0005435765938	13448	95	28G
0005435462535	13448	96	29A
0005434265225	13448	97	29D
0005434265228	13448	98	29B
0005435720128	13448	99	29E
0005435462542	13448	100	29H
0005435462544	13448	101	29G
0005435462538	13448	102	30B
0005435765762	13448	103	30G
0005435462563	13448	104	30F
0005432194523	13448	105	30H
0005434265205	13448	106	31B
0005435765794	13448	107	31A
0005435765911	13448	108	31E
0005435765880	13448	109	31D
0005435765970	13448	110	31F
0005435765846	13448	111	31H
0005435765764	13448	112	31G
0005434265216	13448	113	32A
0005435722043	13448	114	32B
0005435765934	13448	115	32E
0005434265224	13448	116	32D
0005435462552	13448	117	32H
0005435462562	13448	118	33A
0005435765662	13448	119	33B
0005435462551	13448	120	33F
0005435462534	13448	121	33H
0005435765686	13448	122	33G
0005435462547	13448	123	34B
0005435462566	13448	124	34A
0005435765843	13448	125	34E
0005435462543	13448	126	34G
0005435765928	13448	127	34F
0005435765632	13448	128	35F
0005435462531	13448	129	35G
0005434265211	13448	130	35H
0005434265206	13448	131	36A
0005435765806	13448	132	36E
0005435765819	13448	133	36D
0005434831164	13448	134	36F
0005435765833	13448	135	36H
0005434265204	13448	136	37B
0005435765747	13448	137	37E
0005435462564	13448	138	37F
0005434265223	13448	139	37G
0005435462548	13448	140	38A
0005434265207	13448	141	37H
0005435765776	13448	142	38B
0005434265209	13448	143	38E
0005435735092	13448	144	38H
0005435765552	13448	145	39E
0005435462559	13448	146	39F
0005434602886	18682	1	3B
0005434513586	18684	1	1A
0005434604851	18684	2	1B
0005434604865	18684	3	2A
0005434604852	18684	4	2B
0005434513587	18684	5	3A
0005434604866	18684	6	3B
0005434513584	18684	7	4A
0005434514974	18684	8	4B
0005434604867	18684	9	5A
0005434513585	18684	10	5B
0005434514972	18684	11	6A
0005434514973	18684	12	6B
0005434514945	19192	1	5A
0005434514949	19192	2	6A
0005432649424	4119	1	1F
0005432649419	4119	2	2F
0005432649421	4119	3	3D
0005432649422	4119	4	3F
0005435844306	4119	5	4A
0005432632767	4119	6	5A
0005432632755	4119	7	5C
0005432649415	4119	8	5E
0005432649423	4119	9	6F
0005435846223	4119	10	7C
0005435846224	4119	11	7D
0005435844295	4119	12	7E
0005432632766	4119	13	8C
0005432649425	4119	14	8D
0005435844297	4119	15	8E
0005432649426	4119	16	9D
0005432632764	4119	17	11A
0005432632758	4119	18	11E
0005435844296	4119	19	11F
0005432632760	4119	20	12A
0005432649417	4119	21	12C
0005432649418	4119	22	13C
0005432649420	4119	23	14A
0005432632763	4119	24	14C
0005432632765	4119	25	14E
0005435846203	4119	26	15D
0005432632756	4119	27	16D
0005435844299	4119	28	16F
0005432649414	4119	29	17C
0005435846220	4119	30	17E
0005432632761	4119	31	18A
0005435844298	4119	32	18F
0005432632762	4119	33	19A
0005435844291	4119	34	19C
0005432632757	4119	35	20A
0005432649416	4119	36	20D
0005432632759	4119	37	20E
0005433284990	1857	1	1A
0005433285167	1857	2	1C
0005433810566	1857	3	1D
0005433285119	1857	4	1F
0005432295887	1857	5	2A
0005433008309	1857	6	2C
0005433284989	1857	7	2D
0005433285191	1857	8	3A
0005433008460	1857	9	3C
0005433285026	1857	10	3D
0005433008506	1857	11	3F
0005433008287	1857	12	4A
0005433285103	1857	13	4C
0005433284965	1857	14	4D
0005433285155	1857	15	4E
0005433008178	1857	16	4F
0005433008355	1857	17	5A
0005433285028	1857	18	5C
0005433285200	1857	19	5D
0005433008308	1857	20	5E
0005433008512	1857	21	5F
0005433285185	1857	22	6A
0005433285081	1857	23	6C
0005433285055	1857	24	6D
0005433285053	1857	25	6E
0005433008505	1857	26	6F
0005433008464	1857	27	7A
0005433285054	1857	28	7C
0005433008490	1857	29	7E
0005433008194	1857	30	7F
0005433008435	1857	31	8A
0005433285105	1857	32	8C
0005433008457	1857	33	8D
0005433008440	1857	34	8E
0005433008491	1857	35	8F
0005433285190	1857	36	9A
0005433008314	1857	37	9C
0005433285089	1857	38	9D
0005433008370	1857	39	9E
0005433008507	1857	40	9F
0005433008513	1857	41	10A
0005433008438	1857	42	10C
0005433008216	1857	43	10D
0005433008286	1857	44	10E
0005433285182	1857	45	10F
0005433008494	1857	46	11C
0005433008148	1857	47	11D
0005433008333	1857	48	11E
0005433008302	1857	49	11F
0005433008437	1857	50	12A
0005433285134	1857	51	12D
0005433008371	1857	52	12E
0005433008341	1857	53	12F
0005432295888	1857	54	13A
0005433285097	1857	55	13C
0005433008429	1857	56	13D
0005433285052	1857	57	13E
0005433285239	1857	58	13F
0005433008439	1857	59	14A
0005433008500	1857	60	14C
0005433008367	1857	61	14D
0005433008263	1857	62	14E
0005433285198	1857	63	14F
0005433008366	1857	64	15A
0005433008504	1857	65	15C
0005433008324	1857	66	15D
0005433285128	1857	67	15F
0005433008257	1857	68	16A
0005433008436	1857	69	16D
0005433285066	1857	70	17A
0005433008469	1857	71	17C
0005433285183	1857	72	17D
0005433008480	1857	73	17E
0005433285184	1857	74	17F
0005433008503	1857	75	18A
0005433008492	1857	76	18C
0005433285237	1857	77	18D
0005433285181	1857	78	18E
0005433008519	1857	79	18F
0005433285135	1857	80	19A
0005433008340	1857	81	19C
0005433285042	1857	82	19D
0005433285088	1857	83	19E
0005433285104	1857	84	19F
0005433285168	1857	85	20A
0005433285136	1857	86	20D
0005433008342	1857	87	20E
0005433008149	1857	88	20F
0005433285359	22520	1	1A
0005433008727	22520	2	1C
0005433008708	22520	3	1D
0005433008747	22520	4	1F
0005433285370	22520	5	2C
0005433285377	22520	6	2D
0005433008734	22520	7	2F
0005433008737	22520	8	3A
0005433008718	22520	9	3C
0005433008719	22520	10	3D
0005433008723	22520	11	3F
0005433285363	22520	12	4C
0005433008726	22520	13	4D
0005433285391	22520	14	4F
0005433008746	22520	15	5A
0005433008722	22520	16	5C
0005433285390	22520	17	5D
0005433008739	22520	18	5E
0005433008721	22520	19	5F
0005433008728	22520	20	6A
0005433008715	22520	21	6C
0005433008712	22520	22	6D
0005433285367	22520	23	6E
0005433810511	22520	24	6F
0005433285378	22520	25	7A
0005433285384	22520	26	7C
0005433285366	22520	27	7D
0005433810497	22520	28	7E
0005433008706	22520	29	7F
0005433285382	22520	30	8A
0005433285371	22520	31	8C
0005433008703	22520	32	8E
0005433810510	22520	33	8F
0005433008738	22520	34	9F
0005433810509	22520	35	10A
0005433008749	22520	36	10C
0005433008743	22520	37	10D
0005433008731	22520	38	10F
0005433008729	22520	39	11A
0005433285362	22520	40	11C
0005433285385	22520	41	11D
0005433008720	22520	42	11E
0005433285389	22520	43	11F
0005433285379	22520	44	12A
0005433008745	22520	45	12C
0005433285361	22520	46	12D
0005433008707	22520	47	12E
0005433008713	22520	48	12F
0005433008741	22520	49	13A
0005433285373	22520	50	13C
0005433285376	22520	51	13D
0005433810498	22520	52	13E
0005433285374	22520	53	13F
0005433285387	22520	54	14A
0005433285364	22520	55	14C
0005433285388	22520	56	14D
0005433008732	22520	57	14E
0005433810508	22520	58	14F
0005433285375	22520	59	15C
0005433285365	22520	60	15D
0005433008744	22520	61	15E
0005433008704	22520	62	15F
0005433008736	22520	63	16A
0005433008724	22520	64	16C
0005433285369	22520	65	16D
0005433008735	22520	66	16E
0005433008733	22520	67	16F
0005433008742	22520	68	17A
0005433285386	22520	69	17C
0005433008705	22520	70	17D
0005433285360	22520	71	17E
0005433285372	22520	72	17F
0005433285380	22520	73	18A
0005433008709	22520	74	18C
0005433008717	22520	75	18D
0005433008716	22520	76	18E
0005433008740	22520	77	18F
0005433008710	22520	78	19A
0005433285368	22520	79	19C
0005433008711	22520	80	19D
0005433008730	22520	81	19E
0005433285383	22520	82	19F
0005433285381	22520	83	20C
0005433008725	22520	84	20D
0005433008748	22520	85	20E
0005433008714	22520	86	20F
0005432751489	12282	1	1F
0005432755042	12282	2	2A
0005432755058	12282	3	3F
0005434152783	12282	4	4A
0005432751490	12282	5	4F
0005434152791	12282	6	5A
0005434152790	12282	7	5C
0005432755057	12282	8	5D
0005434152782	12282	9	5F
0005434152792	12282	10	6E
0005432751488	12282	11	7E
0005432751497	12282	12	8C
0005432755046	12282	13	9E
0005432751501	12282	14	10C
0005432755041	12282	15	11A
0005432751500	12282	16	11F
0005432755037	12282	17	12A
0005434152789	12282	18	12C
0005432751499	12282	19	13C
0005432751515	12282	20	13F
0005432755039	12282	21	14A
0005434152787	12282	22	14C
0005434152784	12282	23	14D
0005432755040	12282	24	14E
0005432755063	12282	25	15A
0005434152788	12282	26	16C
0005432755048	12282	27	16E
0005432751491	12282	28	17A
0005432751496	12282	29	17E
0005434152786	12282	30	18E
0005432755062	12282	31	19D
0005432755029	12282	32	20C
0005432755045	12282	33	20D
0005434152785	12282	34	20E
0005432081530	5565	1	1C
0005433846900	5565	2	1A
0005435282418	5565	3	1F
0005433846883	5565	4	1D
0005433846863	5565	5	2C
0005433815399	5565	6	2A
0005433846903	5565	7	2D
0005433846875	5565	8	3A
0005433846865	5565	9	2F
0005433846884	5565	10	3D
0005433846891	5565	11	3C
0005433846889	5565	12	4A
0005433846879	5565	13	3F
0005433846861	5565	14	4D
0005433846893	5565	15	4C
0005435282379	5565	16	4F
0005433846899	5565	17	5C
0005433815396	5565	18	5A
0005432081531	5565	19	5F
0005433846908	5565	20	5D
0005434173492	5565	21	6A
0005435282380	5565	22	6D
0005433846892	5565	23	6E
0005433846915	5565	24	7A
0005433846905	5565	25	6F
0005435282287	5565	26	7C
0005433846902	5565	27	7B
0005434173495	5565	28	7E
0005435282316	5565	29	7D
0005435282311	5565	30	7F
0005432081527	5565	31	8B
0005433846867	5565	32	8A
0005433846868	5565	33	8D
0005433846906	5565	34	8C
0005434173475	5565	35	8E
0005435282336	5565	36	9B
0005433846909	5565	37	9A
0005433846877	5565	38	9F
0005435282419	5565	39	9E
0005435282331	5565	40	9D
0005435282429	5565	41	10A
0005433846869	5565	42	10C
0005433846872	5565	43	10B
0005433846895	5565	44	10D
0005433846870	5565	45	10F
0005435282321	5565	46	11C
0005433846876	5565	47	11B
0005433846910	5565	48	11A
0005433846913	5565	49	11F
0005435282332	5565	50	11E
0005432081528	5565	51	12B
0005435282474	5565	52	12A
0005433846860	5565	53	12D
0005433846901	5565	54	12E
0005435282433	5565	55	13A
0005433846885	5565	56	12F
0005435282417	5565	57	13C
0005433846864	5565	58	13B
0005435282261	5565	59	13E
0005433846890	5565	60	13D
0005433846866	5565	61	14A
0005433846911	5565	62	13F
0005433846912	5565	63	14B
0005433846888	5565	64	14E
0005433846904	5565	65	14D
0005435282337	5565	66	15A
0005433846887	5565	67	15D
0005435282339	5565	68	15C
0005435282382	5565	69	15B
0005435282389	5565	70	16A
0005433846878	5565	71	16B
0005433846917	5565	72	16E
0005433846916	5565	73	16D
0005433815398	5565	74	16C
0005432081529	5565	75	17A
0005433846882	5565	76	16F
0005433846874	5565	77	17D
0005433846897	5565	78	17C
0005435282428	5565	79	17F
0005433815397	5565	80	17E
0005433846886	5565	81	18A
0005433846907	5565	82	18C
0005435282325	5565	83	18B
0005435282445	5565	84	18E
0005433846898	5565	85	18D
0005433846873	5565	86	19A
0005433846896	5565	87	18F
0005433846859	5565	88	19B
0005433846894	5565	89	19E
0005433846880	5565	90	19C
0005435282324	5565	91	19F
0005435282345	5565	92	20B
0005433846862	5565	93	20D
0005435282368	5565	94	20C
0005435282446	5565	95	20F
0005435282342	5565	96	20E
0005433846914	5565	97	21A
0005435282330	5565	98	21C
0005435282335	5565	99	21B
0005433846881	5565	100	21F
0005433846871	5565	101	21E
0005435282353	5565	102	21D
0005433846334	13835	1	1A
0005433846232	13835	2	1F
0005435282584	13835	3	1D
0005433846336	13835	4	2A
0005433846326	13835	5	2F
0005433846428	13835	6	2C
0005433846420	13835	7	3A
0005433846510	13835	8	3D
0005435282590	13835	9	3C
0005433846447	13835	10	4D
0005433846451	13835	11	4C
0005435282577	13835	12	4F
0005435282568	13835	13	5D
0005433846749	13835	14	5C
0005433815343	13835	15	5A
0005433846136	13835	16	5F
0005433846205	13835	17	6A
0005435282576	13835	18	6C
0005432003710	13835	19	6B
0005435282569	13835	20	6F
0005433846432	13835	21	6E
0005434173531	13835	22	7A
0005435282564	13835	23	7B
0005433815359	13835	24	8B
0005435282572	13835	25	8D
0005433846365	13835	26	8F
0005433846233	13835	27	8E
0005435282586	13835	28	9C
0005433846446	13835	29	10B
0005433846616	13835	30	10A
0005433846613	13835	31	9F
0005435282589	13835	32	10C
0005433846277	13835	33	11A
0005433846364	13835	34	10F
0005435282578	13835	35	10E
0005433846357	13835	36	11D
0005433815375	13835	37	11C
0005435282591	13835	38	11F
0005435282574	13835	39	11E
0005435282570	13835	40	12B
0005433846356	13835	41	12A
0005433846483	13835	42	12C
0005435282567	13835	43	12E
0005435282575	13835	44	13A
0005435282571	13835	45	12F
0005433846614	13835	46	13E
0005435282583	13835	47	13D
0005435282582	13835	48	14B
0005435282565	13835	49	14E
0005433846297	13835	50	14D
0005433846481	13835	51	14C
0005433846380	13835	52	14F
0005435282587	13835	53	15B
0005433846076	13835	54	15A
0005433815360	13835	55	15C
0005433846721	13835	56	15E
0005432003709	13835	57	16A
0005435282580	13835	58	16C
0005433815342	13835	59	16B
0005433846075	13835	60	16F
0005433846657	13835	61	16E
0005435282573	13835	62	17D
0005433846507	13835	63	17C
0005433846204	13835	64	17E
0005434173532	13835	65	18A
0005435282579	13835	66	18C
0005432003711	13835	67	18E
0005435282566	13835	68	19A
0005435282588	13835	69	19C
0005435282585	13835	70	19B
0005433846612	13835	71	19D
0005433815348	13835	72	19E
0005433846529	13835	73	20B
0005433846385	13835	74	20D
0005435282581	13835	75	20C
0005433846418	13835	76	20F
0005434173533	13835	77	21B
0005433846433	13835	78	21F
0005433846333	13835	79	21E
0005435332338	7802	1	1A
0005435332327	7802	2	1B
0005434620646	7802	3	1C
0005434620644	7802	4	1D
0005434620656	7802	5	2A
0005432112523	7802	6	2D
0005432112521	7802	7	3C
0005434620662	7802	8	4A
0005434620650	7802	9	4B
0005434620660	7802	10	4D
0005434620652	7802	11	5A
0005434620658	7802	12	5B
0005435332326	7802	13	5C
0005432112522	7802	14	6A
0005434620643	7802	15	6B
0005432112524	7802	16	6C
0005435332337	7802	17	6D
0005435332264	7802	18	7B
0005434620654	7802	19	7C
0005434620653	7802	20	18A
0005434620659	7802	21	18B
0005434620649	7802	22	18C
0005435332265	7802	23	19A
0005434620663	7802	24	19C
0005434620651	7802	25	20A
0005434620657	7802	26	20C
0005434620661	7802	27	20D
0005435332255	7802	28	21A
0005434620655	7802	29	21C
0005434620648	7802	30	22C
0005434620647	7802	31	22D
0005434620645	7802	32	23B
0005434620419	32969	1	1A
0005435332366	32969	2	1B
0005435332359	32969	3	1C
0005434620505	32969	4	1D
0005435332365	32969	5	2B
0005435332364	32969	6	2C
0005435332363	32969	7	2D
0005435332369	32969	8	3A
0005434620506	32969	9	3B
0005435332362	32969	10	3C
0005434620452	32969	11	3D
0005434620487	32969	12	4D
0005434620392	32969	13	5C
0005434620455	32969	14	5D
0005434620454	32969	15	6A
0005434620391	32969	16	6B
0005434620339	32969	17	6C
0005434620463	32969	18	7A
0005434620491	32969	19	7B
0005434620490	32969	20	7D
0005434620504	32969	21	18C
0005434620512	32969	22	18D
0005435332361	32969	23	19A
0005434620427	32969	24	19B
0005435332367	32969	25	19C
0005434620340	32969	26	20C
0005435332368	32969	27	20D
0005434620466	32969	28	21A
0005435332360	32969	29	21C
0005434620562	32969	30	22A
0005434620557	32969	31	22C
0005434620449	32969	32	22D
0005434620338	32969	33	23A
0005434620420	32969	34	23B
0005435785441	4276	1	1A
0005435918646	4276	2	1F
0005434994050	4276	3	2C
0005435785438	4276	4	2D
0005434994051	4276	5	3A
0005435785453	4276	6	3C
0005435937351	4276	7	3F
0005435785439	4276	8	4A
0005435785449	4276	9	4C
0005435785437	4276	10	4D
0005435785440	4276	11	4E
0005435785452	4276	12	5A
0005435785468	4276	13	5C
0005435785442	4276	14	5F
0005435785454	4276	15	6C
0005435785444	4276	16	6D
0005435785461	4276	17	6E
0005432190641	4276	18	6F
0005434994049	4276	19	7E
0005435785459	4276	20	7F
0005434994054	4276	21	8A
0005435785456	4276	22	8D
0005435785445	4276	23	8F
0005435785466	4276	24	9C
0005435785463	4276	25	9D
0005435937359	4276	26	9E
0005435918634	4276	27	9F
0005435785448	4276	28	10A
0005435937362	4276	29	10C
0005434994052	4276	30	10E
0005435785469	4276	31	10F
0005435785460	4276	32	11A
0005435785465	4276	33	11C
0005434994053	4276	34	11D
0005435918632	4276	35	11E
0005435785443	4276	36	12A
0005435918624	4276	37	12C
0005435785467	4276	38	12D
0005435785446	4276	39	12E
0005435785451	4276	40	12F
0005435787360	4276	41	13A
0005434994048	4276	42	13C
0005435785455	4276	43	13D
0005435785462	4276	44	14A
0005435937357	4276	45	14F
0005435785470	4276	46	15F
0005434994045	4276	47	16C
0005435785447	4276	48	16D
0005435918629	4276	49	16F
0005434994056	4276	50	17D
0005435937353	4276	51	17E
0005434994047	4276	52	18A
0005434994046	4276	53	18C
0005435785450	4276	54	18E
0005434994055	4276	55	19A
0005432190639	4276	56	19C
0005435785458	4276	57	19D
0005432190640	4276	58	19F
0005435937346	4276	59	20A
0005435785464	4276	60	20C
0005435937363	4276	61	20E
0005435785457	4276	62	20F
0005434993973	27313	1	1A
0005435784979	27313	2	1C
0005435937391	27313	3	2A
0005435785059	27313	4	2D
0005435785113	27313	5	2C
0005435785216	27313	6	3A
0005435785060	27313	7	3F
0005435785121	27313	8	5A
0005434993951	27313	9	5D
0005435785105	27313	10	5F
0005435785109	27313	11	6A
0005435918669	27313	12	6E
0005435918670	27313	13	7D
0005435785102	27313	14	7E
0005435785202	27313	15	8D
0005435787340	27313	16	8E
0005432195697	27313	17	10A
0005435785211	27313	18	10E
0005435785098	27313	19	11A
0005435785122	27313	20	11C
0005435785244	27313	21	11E
0005435785188	27313	22	11F
0005435918668	27313	23	12A
0005435785167	27313	24	12F
0005435785201	27313	25	13D
0005435787338	27313	26	13F
0005435785110	27313	27	14C
0005435787339	27313	28	14F
0005435918671	27313	29	15C
0005435785207	27313	30	15D
0005435937392	27313	31	16A
0005435785152	27313	32	16C
0005435785210	27313	33	16D
0005435785151	27313	34	17A
0005435785031	27313	35	17E
0005434993950	27313	36	17F
0005432195698	27313	37	18A
0005435784925	27313	38	19D
0005434993941	27313	39	19E
0005435785084	27313	40	19F
0005432146204	19869	1	7A
0005432146203	19869	2	19D
0005432460013	4713	1	1A
0005432460004	4713	2	1C
0005432460001	4713	3	1B
0005433726111	4713	4	1F
0005432567812	4713	5	1G
0005432170405	4713	6	2A
0005434081964	4713	7	1H
0005434081969	4713	8	2B
0005432567807	4713	9	2F
0005432460014	4713	10	2C
0005432460008	4713	11	2G
0005432567802	4713	12	3A
0005432567817	4713	13	2H
0005432567830	4713	14	3F
0005434081974	4713	15	3H
0005432567811	4713	16	4F
0005432460010	4713	17	4C
0005432567777	4713	18	4G
0005434081975	4713	19	4H
0005432567828	4713	20	5A
0005432567798	4713	21	5C
0005432460017	4713	22	5G
0005432460002	4713	23	9B
0005432567804	4713	24	9A
0005432459994	4713	25	9G
0005432567813	4713	26	11A
0005433452745	4713	27	11B
0005432567819	4713	28	11G
0005432459988	4713	29	11F
0005432459986	4713	30	11E
0005435840358	4713	31	11H
0005432567801	4713	32	12A
0005434081982	4713	33	12B
0005432459975	4713	34	12D
0005432567816	4713	35	12G
0005432567793	4713	36	12F
0005434081959	4713	37	13A
0005432567795	4713	38	13D
0005432571331	4713	39	13B
0005432567800	4713	40	13G
0005432567810	4713	41	13F
0005432459977	4713	42	13H
0005432459991	4713	43	14B
0005432567829	4713	44	14D
0005432567835	4713	45	14F
0005432460022	4713	46	14E
0005432567789	4713	47	15A
0005432567827	4713	48	15B
0005432460021	4713	49	15E
0005433451624	4713	50	15F
0005434081961	4713	51	15G
0005434081983	4713	52	16A
0005432567796	4713	53	16D
0005432459996	4713	54	16B
0005434081980	4713	55	16E
0005434081960	4713	56	16F
0005432170406	4713	57	16H
0005432459987	4713	58	16G
0005434081977	4713	59	17D
0005433451625	4713	60	17B
0005432567825	4713	61	17G
0005434081979	4713	62	18A
0005432460016	4713	63	17H
0005432571332	4713	64	18E
0005432460012	4713	65	18D
0005432567790	4713	66	18B
0005434081958	4713	67	18G
0005434081955	4713	68	18H
0005432567786	4713	69	19B
0005432567832	4713	70	19A
0005432459981	4713	71	19D
0005432459984	4713	72	19F
0005432459997	4713	73	19E
0005432567824	4713	74	19H
0005432460003	4713	75	20A
0005432567799	4713	76	20E
0005432459998	4713	77	20D
0005432567797	4713	78	20F
0005434081967	4713	79	20G
0005432567837	4713	80	21B
0005432460019	4713	81	21E
0005432567808	4713	82	21G
0005432567809	4713	83	22D
0005432459973	4713	84	22E
0005432567814	4713	85	22G
0005432571333	4713	86	22H
0005432567784	4713	87	23B
0005432567803	4713	88	23A
0005434081962	4713	89	23D
0005432567779	4713	90	23E
0005434081968	4713	91	23G
0005432459995	4713	92	23F
0005432460020	4713	93	24A
0005432459993	4713	94	23H
0005432567782	4713	95	24B
0005432459985	4713	96	24F
0005432567833	4713	97	25F
0005434081976	4713	98	25E
0005432567818	4713	99	27B
0005432186881	4713	100	27A
0005432567806	4713	101	27E
0005432567838	4713	102	27D
0005434081970	4713	103	27G
0005432460009	4713	104	27F
0005432459976	4713	105	28A
0005434081973	4713	106	28B
0005432567820	4713	107	28F
0005432567791	4713	108	28E
0005432460023	4713	109	28H
0005432567821	4713	110	28G
0005432170407	4713	111	29A
0005433452746	4713	112	29D
0005432567823	4713	113	29B
0005432567785	4713	114	29E
0005432460015	4713	115	29F
0005432460011	4713	116	29H
0005432567836	4713	117	30A
0005432567805	4713	118	30D
0005432459999	4713	119	30B
0005434081966	4713	120	30E
0005432459978	4713	121	30H
0005432459983	4713	122	31B
0005432459992	4713	123	31A
0005434559098	4713	124	31E
0005432459972	4713	125	31D
0005432567781	4713	126	31F
0005432459989	4713	127	31G
0005434081972	4713	128	32B
0005434081978	4713	129	32A
0005434559096	4713	130	32E
0005432170404	4713	131	32D
0005434081971	4713	132	32G
0005432567778	4713	133	32F
0005432459974	4713	134	32H
0005432459980	4713	135	33B
0005432460005	4713	136	33E
0005434081956	4713	137	33D
0005432459990	4713	138	33F
0005432567783	4713	139	34A
0005432460006	4713	140	34D
0005432460018	4713	141	34B
0005434081957	4713	142	34F
0005432567822	4713	143	34G
0005434081965	4713	144	34H
0005432567826	4713	145	35B
0005432567787	4713	146	35A
0005432170409	4713	147	35E
0005432460024	4713	148	35H
0005432170408	4713	149	36B
0005432567794	4713	150	36A
0005432567834	4713	151	36E
0005432567792	4713	152	36D
0005434081981	4713	153	36F
0005434081954	4713	154	36G
0005432459982	4713	155	36H
0005434081963	4713	156	37D
0005434559099	4713	157	37H
0005434559097	4713	158	38A
0005432459979	4713	159	38B
0005434081984	4713	160	38E
0005432460007	4713	161	38D
0005432460000	4713	162	38G
0005432567831	4713	163	38F
0005432567815	4713	164	38H
0005432567788	4713	165	39F
0005432567780	4713	166	39E
0005432567314	30547	1	1A
0005434081844	30547	2	1B
0005434081767	30547	3	1F
0005434081739	30547	4	1G
0005432459642	30547	5	2A
0005434081881	30547	6	2F
0005432459550	30547	7	2C
0005432567476	30547	8	2H
0005434081738	30547	9	3C
0005432567128	30547	10	3B
0005432567273	30547	11	3A
0005432567264	30547	12	3F
0005432459784	30547	13	3G
0005432459683	30547	14	4A
0005432459658	30547	15	3H
0005432567289	30547	16	4C
0005432567548	30547	17	4B
0005432567156	30547	18	4F
0005432567185	30547	19	4G
0005432567525	30547	20	5B
0005432567359	30547	21	5F
0005434081736	30547	22	5C
0005432567625	30547	23	5H
0005432567334	30547	24	9B
0005432567307	30547	25	9G
0005432459552	30547	26	9H
0005432459636	30547	27	11D
0005432567385	30547	28	11F
0005432567368	30547	29	11E
0005432459494	30547	30	11H
0005432567332	30547	31	11G
0005432567428	30547	32	12A
0005432567370	30547	33	12E
0005432567285	30547	34	12D
0005432459624	30547	35	12G
0005432567310	30547	36	12F
0005434559083	30547	37	12H
0005432459821	30547	38	13A
0005432567409	30547	39	13D
0005432459633	30547	40	13B
0005434081686	30547	41	13E
0005432567449	30547	42	13G
0005432459635	30547	43	13F
0005432459783	30547	44	14B
0005432567435	30547	45	14E
0005432459525	30547	46	15A
0005434081681	30547	47	14H
0005432459671	30547	48	15B
0005432567201	30547	49	15E
0005432459528	30547	50	15D
0005432567265	30547	51	15F
0005432567352	30547	52	15G
0005432459592	30547	53	16A
0005432567091	30547	54	16E
0005434081756	30547	55	16D
0005433454863	30547	56	16F
0005432459666	30547	57	16H
0005432459712	30547	58	17A
0005432567441	30547	59	17D
0005432567447	30547	60	17G
0005432459466	30547	61	17F
0005432213617	30547	62	18A
0005432567234	30547	63	18G
0005432571306	30547	64	19D
0005434081682	30547	65	19A
0005432567568	30547	66	19E
0005432567263	30547	67	19F
0005432567446	30547	68	19H
0005432571292	30547	69	20D
0005432459670	30547	70	20B
0005432567410	30547	71	20E
0005432161158	30547	72	20H
0005434081737	30547	73	21B
0005432567371	30547	74	21A
0005432459551	30547	75	21D
0005432213616	30547	76	21E
0005432567519	30547	77	21G
0005432567072	30547	78	21F
0005434559086	30547	79	22A
0005432567351	30547	80	21H
0005432459665	30547	81	22B
0005434559082	30547	82	22F
0005432213615	30547	83	22E
0005432571307	30547	84	22G
0005432459413	30547	85	22H
0005432459387	30547	86	23B
0005432567422	30547	87	23A
0005432571298	30547	88	23E
0005432567203	30547	89	23D
0005432567549	30547	90	23G
0005432459399	30547	91	24A
0005432459605	30547	92	24B
0005432459607	30547	93	24D
0005432567039	30547	94	24F
0005432459398	30547	95	24G
0005432567262	30547	96	25D
0005432459478	30547	97	24H
0005432459518	30547	98	27A
0005432567189	30547	99	25F
0005432567615	30547	100	27E
0005432459455	30547	101	27F
0005432567407	30547	102	27H
0005432567427	30547	103	27G
0005432567350	30547	104	28D
0005434081749	30547	105	28B
0005432459657	30547	106	28G
0005432567299	30547	107	28F
0005432459644	30547	108	29A
0005432567382	30547	109	29D
0005432459667	30547	110	29F
0005432567231	30547	111	29E
0005432459761	30547	112	30A
0005432459517	30547	113	30D
0005432567233	30547	114	30B
0005432459574	30547	115	30G
0005432459590	30547	116	31A
0005432567261	30547	117	30H
0005432567184	30547	118	31E
0005432567419	30547	119	31D
0005432459531	30547	120	31F
0005432567542	30547	121	31G
0005432567389	30547	122	31H
0005432567204	30547	123	32B
0005432567362	30547	124	32E
0005432161159	30547	125	32D
0005434559085	30547	126	32F
0005432459713	30547	127	32H
0005432459711	30547	128	33A
0005432567369	30547	129	33B
0005434081716	30547	130	33D
0005432459524	30547	131	33F
0005432459573	30547	132	33H
0005432567250	30547	133	34A
0005432459589	30547	134	34B
0005434081740	30547	135	34G
0005432571301	30547	136	34F
0005432459606	30547	137	34H
0005432459495	30547	138	35B
0005432567155	30547	139	35A
0005432571293	30547	140	35E
0005432567363	30547	141	35D
0005432459634	30547	142	35G
0005434559084	30547	143	35F
0005432459553	30547	144	36A
0005432459454	30547	145	35H
0005432459691	30547	146	36B
0005433454859	30547	147	36E
0005432459591	30547	148	36F
0005432213618	30547	149	36G
0005432567423	30547	150	37A
0005432459778	30547	151	37B
0005432459710	30547	152	37E
0005432567616	30547	153	37D
0005432567545	30547	154	37F
0005434081758	30547	155	38A
0005434559087	30547	156	37H
0005432459498	30547	157	38B
0005432459364	30547	158	38E
0005432567170	30547	159	38D
0005432459486	30547	160	38G
0005434081706	30547	161	38F
0005432459643	30547	162	39E
0005435720825	13669	1	2A
0005435722062	13669	2	4A
0005435722026	21230	1	1A
0005435722044	21230	2	1B
0005435722045	21230	3	3A
0005435722034	21230	4	5A
0005435722035	21230	5	6A
0005432295887	22788	1	2A
0005432295888	22788	2	4A
0005433343471	11093	1	1A
0005433343465	11093	2	1C
0005433343459	11093	3	1F
0005433343440	11093	4	1D
0005435097224	11093	5	2A
0005433343431	11093	6	2C
0005433343491	11093	7	2D
0005433343443	11093	8	2F
0005433343494	11093	9	3C
0005433343444	11093	10	3A
0005435508295	11093	11	3F
0005433343425	11093	12	3D
0005433343501	11093	13	4A
0005433343470	11093	14	4C
0005433343473	11093	15	4B
0005435508341	11093	16	4D
0005433343507	11093	17	4E
0005435508294	11093	18	4F
0005433343458	11093	19	5A
0005433343502	11093	20	5B
0005433343428	11093	21	5D
0005435508259	11093	22	5C
0005435508321	11093	23	5F
0005433343418	11093	24	5E
0005433343426	11093	25	6A
0005433343434	11093	26	6B
0005433343490	11093	27	6D
0005433343497	11093	28	6C
0005433343495	11093	29	6F
0005433343474	11093	30	6E
0005433343441	11093	31	7B
0005433343449	11093	32	7A
0005433343505	11093	33	7C
0005433343478	11093	34	7E
0005433343463	11093	35	7D
0005433343506	11093	36	7F
0005433343487	11093	37	8A
0005433343475	11093	38	8C
0005433343485	11093	39	8B
0005433343486	11093	40	8D
0005433343415	11093	41	8F
0005435508322	11093	42	8E
0005433343460	11093	43	9A
0005433343435	11093	44	9B
0005433343429	11093	45	9C
0005433343437	11093	46	9D
0005433343513	11093	47	9F
0005433343416	11093	48	9E
0005433343508	11093	49	10B
0005433343504	11093	50	10D
0005435097217	11093	51	10C
0005435508278	11093	52	11A
0005433343445	11093	53	10E
0005433343436	11093	54	11B
0005433343466	11093	55	11D
0005433343420	11093	56	11C
0005435508289	11093	57	11F
0005435097218	11093	58	11E
0005433343422	11093	59	12B
0005435097214	11093	60	12A
0005435508320	11093	61	12C
0005433343493	11093	62	12E
0005433343467	11093	63	12D
0005433343509	11093	64	13A
0005433343419	11093	65	12F
0005433343510	11093	66	13B
0005435097215	11093	67	13D
0005433343456	11093	68	13C
0005433343489	11093	69	13E
0005433343499	11093	70	13F
0005433343514	11093	71	14B
0005433343488	11093	72	14A
0005435508281	11093	73	14C
0005433343455	11093	74	14D
0005433343461	11093	75	14F
0005433343450	11093	76	14E
0005433343479	11093	77	15A
0005435508308	11093	78	15B
0005433343432	11093	79	15C
0005433343421	11093	80	15D
0005433343424	11093	81	15F
0005433343481	11093	82	16B
0005433343451	11093	83	16A
0005435097221	11093	84	16D
0005433343472	11093	85	16C
0005433343492	11093	86	16E
0005433343468	11093	87	16F
0005433343477	11093	88	17B
0005435508336	11093	89	17A
0005433343439	11093	90	17C
0005433343503	11093	91	17D
0005433343414	11093	92	17E
0005433343438	11093	93	18A
0005435097219	11093	94	17F
0005435097220	11093	95	18B
0005433343454	11093	96	18D
0005433343433	11093	97	18C
0005433343483	11093	98	18E
0005433343469	11093	99	18F
0005433343448	11093	100	19A
0005435508362	11093	101	19C
0005433343427	11093	102	19B
0005433343453	11093	103	19E
0005435508319	11093	104	19F
0005433343464	11093	105	20A
0005433343430	11093	106	20C
0005433343452	11093	107	20B
0005433343500	11093	108	20D
0005433343482	11093	109	20E
0005433343480	11093	110	21A
0005433343423	11093	111	20F
0005433343496	11093	112	21C
0005433343498	11093	113	21B
0005435097216	11093	114	21D
0005433343484	11093	115	21F
0005435508282	11093	116	21E
0005435508307	11093	117	22A
0005433343447	11093	118	22C
0005435097223	11093	119	22B
0005433343442	11093	120	22D
0005433343446	11093	121	22F
0005433343462	11093	122	22E
0005433343511	11093	123	23B
0005435097222	11093	124	23A
0005433343512	11093	125	23C
0005433343476	11093	126	23E
0005433343417	11093	127	23D
0005433343457	11093	128	23F
0005433342663	17115	1	1A
0005433342822	17115	2	1C
0005432293215	17115	3	1F
0005433342929	17115	4	1D
0005433342630	17115	5	2A
0005433342644	17115	6	2D
0005433342278	17115	7	2C
0005433342593	17115	8	2F
0005433342867	17115	9	3A
0005433342261	17115	10	3D
0005433341864	17115	11	3C
0005433342523	17115	12	3F
0005433342557	17115	13	4A
0005433342564	17115	14	4B
0005433343002	17115	15	4D
0005435097151	17115	16	4C
0005433342538	17115	17	4E
0005433342736	17115	18	4F
0005433342496	17115	19	5B
0005433342621	17115	20	5A
0005433342277	17115	21	5C
0005433342653	17115	22	5D
0005433342425	17115	23	5E
0005433342426	17115	24	5F
0005435097149	17115	25	6B
0005433342301	17115	26	6A
0005433342424	17115	27	6C
0005433342631	17115	28	6D
0005433342320	17115	29	6E
0005433342543	17115	30	7A
0005433342859	17115	31	6F
0005432293216	17115	32	7D
0005433342521	17115	33	7C
0005433342071	17115	34	7B
0005433342504	17115	35	7E
0005433342622	17115	36	8A
0005433342664	17115	37	7F
0005433342790	17115	38	8C
0005433342348	17115	39	8B
0005433341985	17115	40	8E
0005435097128	17115	41	8D
0005433342318	17115	42	8F
0005433342535	17115	43	9A
0005433342691	17115	44	9B
0005433342376	17115	45	9C
0005433342509	17115	46	9D
0005435097143	17115	47	9F
0005433342259	17115	48	9E
0005433342695	17115	49	10C
0005433343023	17115	50	10B
0005433342690	17115	51	10D
0005433342341	17115	52	11A
0005433343070	17115	53	10E
0005435097116	17115	54	11C
0005433342594	17115	55	11B
0005433342637	17115	56	11D
0005435097142	17115	57	11F
0005433343003	17115	58	11E
0005433342143	17115	59	12A
0005433342775	17115	60	12C
0005433342858	17115	61	12B
0005433342520	17115	62	12E
0005433342702	17115	63	12D
0005433342464	17115	64	13A
0005433342356	17115	65	12F
0005433342308	17115	66	13C
0005433342500	17115	67	13B
0005433342765	17115	68	13D
0005433342735	17115	69	13E
0005433342391	17115	70	14A
0005433342679	17115	71	13F
0005433342243	17115	72	14B
0005433342349	17115	73	14D
0005433342355	17115	74	14C
0005433342472	17115	75	14E
0005433342336	17115	76	15A
0005435097165	17115	77	14F
0005433342455	17115	78	15B
0005433342418	17115	79	15E
0005433342461	17115	80	15D
0005433342576	17115	81	15C
0005433342300	17115	82	15F
0005433342187	17115	83	16A
0005433343024	17115	84	16B
0005433342390	17115	85	16C
0005433342316	17115	86	16D
0005433342226	17115	87	16F
0005433342828	17115	88	16E
0005433342319	17115	89	17A
0005433342785	17115	90	17B
0005433342291	17115	91	17D
0005433342759	17115	92	17C
0005433342758	17115	93	17E
0005433342335	17115	94	18A
0005435097119	17115	95	17F
0005433342667	17115	96	18B
0005435097164	17115	97	18C
0005433342299	17115	98	18E
0005433342544	17115	99	18D
0005435097135	17115	100	18F
0005433342216	17115	101	19A
0005433342857	17115	102	19C
0005433342928	17115	103	19B
0005433342323	17115	104	19E
0005433342541	17115	105	19D
0005433342030	17115	106	19F
0005433342215	17115	107	20A
0005435097150	17115	108	20C
0005433342737	17115	109	20B
0005433342654	17115	110	20D
0005435097141	17115	111	20E
0005433342031	17115	112	21A
0005433342643	17115	113	20F
0005435097129	17115	114	21B
0005433342899	17115	115	21C
0005433342456	17115	116	21D
0005433342333	17115	117	21E
0005433342242	17115	118	22A
0005433342497	17115	119	21F
0005433342276	17115	120	22B
0005433342542	17115	121	22C
0005433342752	17115	122	22D
0005433342776	17115	123	22F
0005433342321	17115	124	22E
0005433342317	17115	125	23A
0005433342460	17115	126	23B
0005433342753	17115	127	23C
0005435097136	17115	128	23D
0005433342827	17115	129	23F
0005433342845	17115	130	23E
0005433507242	9089	1	1A
0005432919779	9089	2	1C
0005434158959	9089	3	1D
0005432919732	9089	4	2A
0005432919756	9089	5	2C
0005433481191	9089	6	2D
0005433507249	9089	7	2F
0005433507239	9089	8	3A
0005433481187	9089	9	3C
0005433507246	9089	10	3D
0005433507237	9089	11	4A
0005432919687	9089	12	4D
0005433507238	9089	13	4E
0005433481192	9089	14	5C
0005432919721	9089	15	5F
0005433507236	9089	16	6E
0005432919815	9089	17	7C
0005432919720	9089	18	7E
0005433507245	9089	19	8D
0005432919661	9089	20	9A
0005433481188	9089	21	9C
0005433481186	9089	22	9D
0005433481189	9089	23	9E
0005432919641	9089	24	9F
0005432919642	9089	25	10C
0005432919814	9089	26	11A
0005432919594	9089	27	11C
0005433507244	9089	28	11E
0005433507240	9089	29	12A
0005432919826	9089	30	12D
0005433481190	9089	31	12F
0005432919731	9089	32	13A
0005432919696	9089	33	13C
0005433507234	9089	34	13E
0005432919827	9089	35	13F
0005433507247	9089	36	14A
0005433507241	9089	37	14E
0005433481193	9089	38	15D
0005432919739	9089	39	15F
0005433507248	9089	40	16C
0005432919656	9089	41	17A
0005432919657	9089	42	17D
0005433507235	9089	43	17E
0005433507243	9089	44	18C
0005433507250	9089	45	18D
0005432919764	9089	46	18F
0005432919672	9089	47	19C
0005432919695	9089	48	20F
0005433507123	20481	1	1D
0005433507011	20481	2	1F
0005433481128	20481	3	2C
0005432919945	20481	4	2F
0005433507067	20481	5	3C
0005432919940	20481	6	3D
0005433507063	20481	7	4D
0005432919942	20481	8	5A
0005433507079	20481	9	5E
0005433507134	20481	10	6A
0005432919935	20481	11	6D
0005432919931	20481	12	7D
0005432919932	20481	13	8C
0005432919944	20481	14	9C
0005432919949	20481	15	9D
0005433507085	20481	16	9F
0005432919934	20481	17	10A
0005432919933	20481	18	10D
0005433481131	20481	19	11A
0005433507118	20481	20	11D
0005432919947	20481	21	11F
0005433507125	20481	22	12A
0005432919938	20481	23	12E
0005432919941	20481	24	12F
0005433481152	20481	25	13A
0005433481129	20481	26	13C
0005432919948	20481	27	13E
0005432919950	20481	28	14C
0005433507086	20481	29	14E
0005433481130	20481	30	14F
0005433507108	20481	31	15A
0005433507124	20481	32	15C
0005433507157	20481	33	15D
0005433507012	20481	34	15E
0005433507097	20481	35	17A
0005433507180	20481	36	17F
0005433507113	20481	37	18A
0005433507080	20481	38	18C
0005432919943	20481	39	18D
0005433507167	20481	40	18F
0005433507096	20481	41	19D
0005432919939	20481	42	19F
0005433507127	20481	43	20A
0005432919936	20481	44	20C
0005432919946	20481	45	20D
0005432919951	20481	46	20E
0005432919937	20481	47	20F
0005432396252	10135	1	1A
0005432394113	10135	2	2A
0005432394112	10135	3	1B
0005432396251	10135	4	2B
0005432396250	10135	5	3A
0005432396249	10135	6	3B
0005435178985	10135	7	4A
0005432394110	10135	8	4B
0005432396253	10135	9	5A
0005432394111	10135	10	5B
0005435178988	10135	11	6A
0005435178987	10135	12	6B
0005432396215	18331	1	1A
0005432400115	18331	2	3A
0005432396196	18331	3	3B
0005432400086	18331	4	4A
0005432396223	18331	5	4B
0005432396232	18331	6	5B
0005432400096	18331	7	6A
0005432400104	18331	8	6B
0005435554160	10971	1	1C
0005435625985	10971	2	1D
0005435626035	10971	3	2A
0005435126027	10971	4	2C
0005435626063	10971	5	2F
0005435554144	10971	6	3D
0005435626043	10971	7	4C
0005435626012	10971	8	4E
0005435126039	10971	9	5A
0005434928308	10971	10	5D
0005434411790	10971	11	5F
0005435126227	10971	12	6A
0005435626009	10971	13	6C
0005435626008	10971	14	6D
0005435626057	10971	15	6E
0005435626017	10971	16	6F
0005435126285	10971	17	7A
0005434411793	10971	18	7C
0005435626044	10971	19	7D
0005435126225	10971	20	7E
0005435126029	10971	21	7F
0005435126178	10971	22	8C
0005435126193	10971	23	8E
0005435125995	10971	24	8F
0005435626090	10971	25	9A
0005434411791	10971	26	9C
0005435126217	10971	27	9D
0005435126119	10971	28	9F
0005435626032	10971	29	10E
0005435626065	10971	30	10F
0005435126272	10971	31	11C
0005435626038	10971	32	12D
0005435126216	10971	33	12E
0005435126197	10971	34	13A
0005435126226	10971	35	13C
0005435125926	10971	36	13D
0005435626087	10971	37	13E
0005435625960	10971	38	13F
0005435126082	10971	39	14A
0005435556672	10971	40	14C
0005435125983	10971	41	14D
0005434928307	10971	42	14E
0005435626061	10971	43	15A
0005435126196	10971	44	15D
0005435554153	10971	45	15E
0005435556674	10971	46	15F
0005435126283	10971	47	16C
0005435126131	10971	48	16E
0005435626013	10971	49	16F
0005435126195	10971	50	17A
0005435125925	10971	51	17C
0005434411792	10971	52	17D
0005434928309	10971	53	17E
0005435126118	10971	54	17F
0005435626088	10971	55	18A
0005435126102	10971	56	18C
0005435626037	10971	57	19C
0005435626062	10971	58	19D
0005435126132	10971	59	20A
0005435554156	10971	60	20C
0005435125984	10971	61	20E
0005435626228	14774	1	1A
0005435626223	14774	2	1C
0005435626221	14774	3	1F
0005435126495	14774	4	2A
0005435626233	14774	5	2C
0005435126504	14774	6	3F
0005435626225	14774	7	4D
0005435126508	14774	8	4E
0005435126516	14774	9	4F
0005435126514	14774	10	5A
0005435126511	14774	11	5D
0005435126506	14774	12	5E
0005435556700	14774	13	5F
0005435126502	14774	14	6A
0005435126512	14774	15	6C
0005435626219	14774	16	6D
0005435126484	14774	17	6E
0005435126510	14774	18	6F
0005435126481	14774	19	7A
0005435126482	14774	20	7C
0005435626226	14774	21	7D
0005435126505	14774	22	7E
0005435126507	14774	23	7F
0005435556699	14774	24	8C
0005434411754	14774	25	8D
0005435126496	14774	26	8E
0005435126520	14774	27	9A
0005435126499	14774	28	9C
0005435626236	14774	29	9D
0005435626237	14774	30	9F
0005435626218	14774	31	10C
0005435126487	14774	32	10E
0005435626222	14774	33	10F
0005435626227	14774	34	11A
0005435554199	14774	35	11C
0005435126517	14774	36	11D
0005435554198	14774	37	11F
0005435126518	14774	38	12A
0005435126498	14774	39	12D
0005435126509	14774	40	12E
0005435126513	14774	41	12F
0005435126519	14774	42	13A
0005435626230	14774	43	13E
0005435556701	14774	44	14A
0005435126492	14774	45	14C
0005435554200	14774	46	14D
0005435126497	14774	47	14F
0005434928289	14774	48	14E
0005435126491	14774	49	15A
0005434411749	14774	50	15C
0005435126490	14774	51	15E
0005435126485	14774	52	15F
0005435626229	14774	53	16A
0005435626235	14774	54	16C
0005435626220	14774	55	16D
0005435626231	14774	56	16E
0005435126500	14774	57	16F
0005435126488	14774	58	17A
0005435126494	14774	59	17C
0005435626224	14774	60	17D
0005434411750	14774	61	17F
0005435126489	14774	62	18A
0005435626238	14774	63	18C
0005435626232	14774	64	18D
0005435626234	14774	65	18F
0005435126483	14774	66	19A
0005435126503	14774	67	19C
0005435126486	14774	68	19D
0005435126501	14774	69	19E
0005435126515	14774	70	20A
0005435626239	14774	71	20C
0005435126493	14774	72	20E
0005435554201	14774	73	20F
0005435443238	7145	1	1D
0005435221046	7145	2	2D
0005435443266	7145	3	2F
0005435715525	7145	4	4C
0005435715522	7145	5	4D
0005435715520	7145	6	4E
0005435715516	7145	7	4F
0005435715517	7145	8	5C
0005435443289	7145	9	5E
0005435715512	7145	10	6A
0005435443288	7145	11	6D
0005435715518	7145	12	7D
0005435715524	7145	13	7F
0005435443273	7145	14	8A
0005435219185	7145	15	9A
0005432400136	7145	16	9D
0005432398207	7145	17	10E
0005432398210	7145	18	11C
0005435715515	7145	19	11E
0005435443286	7145	20	12D
0005435715513	7145	21	12E
0005435443260	7145	22	13A
0005435715523	7145	23	13E
0005435443237	7145	24	13F
0005435715511	7145	25	14A
0005435178481	7145	26	14C
0005432400139	7145	27	14E
0005435715519	7145	28	14F
0005435219184	7145	29	15A
0005435443274	7145	30	15C
0005435443265	7145	31	15E
0005435443252	7145	32	15F
0005435715527	7145	33	16A
0005432398206	7145	34	16C
0005435715521	7145	35	16E
0005432400137	7145	36	16F
0005432398208	7145	37	17E
0005435443254	7145	38	17F
0005435715528	7145	39	18A
0005435715526	7145	40	18E
0005432398209	7145	41	19A
0005432400135	7145	42	19C
0005435219186	7145	43	19E
0005435715514	7145	44	20E
0005432400138	7145	45	20F
0005435715350	27046	1	1A
0005435715416	27046	2	1F
0005435715414	27046	3	2C
0005432394072	27046	4	3D
0005432394071	27046	5	3F
0005432398188	27046	6	4A
0005435715287	27046	7	4C
0005435443342	27046	8	4D
0005435443346	27046	9	4E
0005435715288	27046	10	4F
0005435715381	27046	11	5A
0005435715371	27046	12	5C
0005435443341	27046	13	5D
0005435443345	27046	14	5E
0005435715434	27046	15	5F
0005435715341	27046	16	6A
0005435443339	27046	17	6C
0005432398175	27046	18	6F
0005435443338	27046	19	7C
0005435715433	27046	20	8D
0005435715365	27046	21	8E
0005432394091	27046	22	9A
0005435715357	27046	23	9F
0005435715366	27046	24	10E
0005432394090	27046	25	11A
0005435443347	27046	26	11E
0005435715382	27046	27	12D
0005435443340	27046	28	13A
0005432398174	27046	29	13C
0005432394066	27046	30	13F
0005435715417	27046	31	14D
0005435178500	27046	32	14E
0005432394069	27046	33	15A
0005435443348	27046	34	16C
0005435443343	27046	35	17A
0005435178499	27046	36	17F
0005432394070	27046	37	18C
0005435443344	27046	38	18D
0005435715415	27046	39	18E
0005435715286	27046	40	19D
0005435715380	27046	41	19E
0005435715340	27046	42	20A
0005435443337	27046	43	20D
0005434084944	2738	1	1B
0005434084946	2738	2	2A
0005434084943	2738	3	2B
0005434084947	2738	4	4A
0005434084945	2738	5	5A
0005433060399	2738	6	6B
0005433060422	28491	1	1A
0005434084912	28491	2	1B
0005434084911	28491	3	2A
0005434084913	28491	4	2B
0005434084906	28491	5	3A
0005434084904	28491	6	3B
0005434084903	28491	7	4A
0005433060420	28491	8	4B
0005434084907	28491	9	5A
0005434084910	28491	10	5B
0005433060421	28491	11	6A
0005434084914	28491	12	6B
0005432632749	25196	1	1A
0005432632741	25196	2	1D
0005435844304	25196	3	2C
0005432632751	25196	4	3A
0005435844283	25196	5	3B
0005432632733	25196	6	3D
0005432632737	25196	7	4C
0005432632752	25196	8	5A
0005432632744	25196	9	5B
0005435844277	25196	10	5D
0005435844278	25196	11	6A
0005435844274	25196	12	6C
0005435844276	25196	13	6B
0005435844284	25196	14	7A
0005432632743	25196	15	7B
0005432632739	25196	16	7D
0005432632750	25196	17	18A
0005432632754	25196	18	18B
0005432632734	25196	19	18C
0005432632747	25196	20	19A
0005435844271	25196	21	19C
0005435844281	25196	22	19D
0005432632742	25196	23	20A
0005432632746	25196	24	20B
0005432632738	25196	25	20C
0005432632736	25196	26	21C
0005432632753	25196	27	21D
0005435844275	25196	28	22A
0005432632740	25196	29	22B
0005432632748	25196	30	22D
0005432632745	25196	31	23A
0005432632735	25196	32	23B
0005435844332	28163	1	1C
0005435844327	28163	2	1D
0005432632694	28163	3	2B
0005432632661	28163	4	3A
0005435844330	28163	5	4B
0005435844336	28163	6	4C
0005432632671	28163	7	5D
0005432632675	28163	8	6A
0005432632699	28163	9	7A
0005432632660	28163	10	7B
0005432632643	28163	11	7C
0005435844337	28163	12	18C
0005435844335	28163	13	19C
0005435844333	28163	14	19D
0005435844334	28163	15	20D
0005432632672	28163	16	21A
0005432632667	28163	17	21C
0005435844331	28163	18	21D
0005432632731	28163	19	22B
0005435844329	28163	20	22D
0005435844328	28163	21	23B
0005435540920	11384	1	1A
0005435517867	11384	2	1C
0005435540892	11384	3	1D
0005435540993	11384	4	1F
0005435517725	11384	5	2A
0005435540922	11384	6	2C
0005435540992	11384	7	3A
0005435540904	11384	8	3C
0005435540879	11384	9	4A
0005435540909	11384	10	4C
0005435540910	11384	11	4E
0005435517812	11384	12	4F
0005435540790	11384	13	5C
0005435540852	11384	14	5D
0005435517882	11384	15	5E
0005435540875	11384	16	5F
0005435540933	11384	17	6E
0005435517766	11384	18	7A
0005435540894	11384	19	7D
0005435517771	11384	20	8A
0005435517856	11384	21	8C
0005435517820	11384	22	8E
0005435517838	11384	23	9E
0005435540991	11384	24	9F
0005435540901	11384	25	10A
0005435540905	11384	26	10D
0005435517804	11384	27	10E
0005435517827	11384	28	10F
0005435540870	11384	29	11A
0005435540948	11384	30	11C
0005435517819	11384	31	11F
0005435517821	11384	32	12A
0005435540903	11384	33	12D
0005435517814	11384	34	13A
0005435540908	11384	35	13C
0005435540972	11384	36	13D
0005435517852	11384	37	13E
0005435517778	11384	38	13F
0005435540802	11384	39	14A
0005435540935	11384	40	14D
0005435540853	11384	41	14E
0005435540955	11384	42	15A
0005435540902	11384	43	15C
0005435540945	11384	44	15D
0005435540886	11384	45	15E
0005435517774	11384	46	15F
0005435540952	11384	47	16C
0005435540791	11384	48	17D
0005435540893	11384	49	17E
0005435517813	11384	50	17F
0005435540803	11384	51	18A
0005435540840	11384	52	18C
0005435540923	11384	53	18D
0005435517770	11384	54	18E
0005435540885	11384	55	18F
0005435517767	11384	56	19C
0005435540921	11384	57	19D
0005435540900	11384	58	19E
0005435517748	11384	59	19F
0005435540874	11384	60	20A
0005435540928	11384	61	20C
0005435517773	11384	62	20D
0005435529314	22262	1	1A
0005435529315	22262	2	1C
0005435541061	22262	3	1D
0005435541054	22262	4	1F
0005435529307	22262	5	2A
0005435529317	22262	6	2D
0005435541059	22262	7	2F
0005435541050	22262	8	3D
0005435529306	22262	9	4D
0005435529320	22262	10	5D
0005435529310	22262	11	5E
0005435529303	22262	12	5F
0005435541051	22262	13	6A
0005435541064	22262	14	7A
0005435541047	22262	15	7D
0005435529312	22262	16	8C
0005435529302	22262	17	8F
0005435529313	22262	18	9A
0005435529321	22262	19	9C
0005435541060	22262	20	9D
0005435541063	22262	21	9E
0005435541062	22262	22	10A
0005435541046	22262	23	10C
0005432294493	22262	24	10D
0005435541049	22262	25	11C
0005435541056	22262	26	11D
0005432294492	22262	27	11F
0005435529309	22262	28	12D
0005435541053	22262	29	12E
0005435541055	22262	30	12F
0005435529301	22262	31	13D
0005435529311	22262	32	13E
0005435541058	22262	33	14A
0005435541052	22262	34	15E
0005435529304	22262	35	16A
0005435541065	22262	36	16C
0005435541043	22262	37	16D
0005435541057	22262	38	16E
0005435529300	22262	39	17A
0005435541048	22262	40	17D
0005435529305	22262	41	17E
0005435529308	22262	42	17F
0005435529319	22262	43	18A
0005435541044	22262	44	19A
0005435541045	22262	45	19D
0005435529316	22262	46	20A
0005435529318	22262	47	20D
0005433251317	2259	1	1A
0005433251372	2259	2	1C
0005434907481	2259	3	1D
0005434907448	2259	4	1F
0005433251205	2259	5	2C
0005433251284	2259	6	2D
0005434907474	2259	7	2F
0005434907458	2259	8	3A
0005434907455	2259	9	3C
0005434907473	2259	10	3F
0005434907468	2259	11	4A
0005434907485	2259	12	4C
0005434907449	2259	13	4D
0005433251298	2259	14	4E
0005434907477	2259	15	4F
0005433251300	2259	16	5A
0005433251423	2259	17	5C
0005434907466	2259	18	5D
0005434907465	2259	19	5E
0005434907445	2259	20	5F
0005433251369	2259	21	6A
0005434907437	2259	22	6C
0005434907470	2259	23	6D
0005434907439	2259	24	6E
0005434907469	2259	25	7A
0005433251362	2259	26	7C
0005433251373	2259	27	7D
0005433251342	2259	28	7E
0005433251309	2259	29	7F
0005434907453	2259	30	8A
0005433251308	2259	31	8C
0005434907484	2259	32	8D
0005433251368	2259	33	8E
0005433251375	2259	34	9A
0005434907443	2259	35	9C
0005434907479	2259	36	9D
0005433251363	2259	37	9E
0005433251370	2259	38	9F
0005433251295	2259	39	10A
0005434907451	2259	40	10C
0005434907452	2259	41	10D
0005434907476	2259	42	10E
0005433251287	2259	43	10F
0005433251354	2259	44	11C
0005433251394	2259	45	11D
0005434907446	2259	46	11E
0005434907459	2259	47	11F
0005434907467	2259	48	12A
0005433251290	2259	49	12C
0005434907480	2259	50	12D
0005434907447	2259	51	12E
0005433251350	2259	52	12F
0005434907457	2259	53	13A
0005434907471	2259	54	13C
0005434907472	2259	55	13D
0005434907475	2259	56	13E
0005433251393	2259	57	13F
0005433251206	2259	58	14A
0005434907460	2259	59	14C
0005434907454	2259	60	14D
0005433251374	2259	61	14E
0005434907462	2259	62	14F
0005434907444	2259	63	15C
0005433251384	2259	64	15D
0005433251274	2259	65	15E
0005433251318	2259	66	15F
0005434907464	2259	67	16A
0005433251440	2259	68	16C
0005434907436	2259	69	16E
0005433251333	2259	70	16F
0005434907450	2259	71	17A
0005434907442	2259	72	17C
0005434907483	2259	73	17D
0005434907461	2259	74	17E
0005433251301	2259	75	17F
0005434907456	2259	76	18C
0005433251385	2259	77	18D
0005434907478	2259	78	18E
0005434907463	2259	79	18F
0005434907441	2259	80	19A
0005433251294	2259	81	19D
0005434907482	2259	82	19F
0005433400976	2259	83	20A
0005434907438	2259	84	20C
0005434907440	2259	85	20D
0005433251302	2259	86	20E
0005433251422	2259	87	20F
0005434907094	25632	1	1A
0005433251580	25632	2	1D
0005433251574	25632	3	2A
0005434906633	25632	4	2C
0005434906935	25632	5	2D
0005433251562	25632	6	2F
0005434906996	25632	7	3A
0005434907080	25632	8	3C
0005433251563	25632	9	3D
0005434906803	25632	10	3F
0005433251583	25632	11	4A
0005434907009	25632	12	4D
0005433251573	25632	13	4E
0005433251561	25632	14	5A
0005433251570	25632	15	5C
0005434907095	25632	16	5D
0005433251590	25632	17	5E
0005434906632	25632	18	5F
0005434906815	25632	19	6C
0005433251572	25632	20	6D
0005433251567	25632	21	6E
0005434906993	25632	22	6F
0005434907117	25632	23	7C
0005434906759	25632	24	7D
0005433400992	25632	25	7E
0005434906817	25632	26	7F
0005434906863	25632	27	8A
0005434906891	25632	28	8C
0005433251566	25632	29	8D
0005434907018	25632	30	8E
0005434907049	25632	31	8F
0005434907006	25632	32	9C
0005434906873	25632	33	9E
0005434906938	25632	34	9F
0005434906976	25632	35	10A
0005433251576	25632	36	10D
0005433251568	25632	37	10E
0005433400993	25632	38	10F
0005434907129	25632	39	11A
0005434906845	25632	40	11C
0005434906846	25632	41	11D
0005433251586	25632	42	11E
0005433251588	25632	43	11F
0005434907118	25632	44	12A
0005434906997	25632	45	12C
0005433251584	25632	46	12D
0005433251564	25632	47	12E
0005433251582	25632	48	12F
0005433400991	25632	49	13A
0005433251587	25632	50	13D
0005434906859	25632	51	13E
0005433251565	25632	52	13F
0005434907089	25632	53	14A
0005434907090	25632	54	14C
0005433251578	25632	55	14D
0005433251581	25632	56	14E
0005434906934	25632	57	14F
0005433251571	25632	58	15A
0005434906933	25632	59	15C
0005433251589	25632	60	15D
0005434906940	25632	61	15E
0005433251585	25632	62	15F
0005434906882	25632	63	16A
0005434906602	25632	64	16C
0005434906972	25632	65	16D
0005433251579	25632	66	16E
0005434906802	25632	67	16F
0005434907071	25632	68	17A
0005433251569	25632	69	17C
0005433251560	25632	70	17D
0005434906942	25632	71	17F
0005434906872	25632	72	18A
0005433251577	25632	73	18C
0005434907001	25632	74	18D
0005434906689	25632	75	18E
0005434907076	25632	76	19A
0005434906758	25632	77	19C
0005434906816	25632	78	19D
0005434906973	25632	79	20A
0005434907119	25632	80	20C
0005434907088	25632	81	20D
0005434907116	25632	82	20E
0005433251575	25632	83	20F
0005432621077	2553	1	1A
0005432621084	2553	2	2B
0005432621080	2553	3	2D
0005432621086	2553	4	3A
0005432621076	2553	5	3B
0005432621085	2553	6	3C
0005432621090	2553	7	4B
0005432862232	2553	8	4C
0005432621075	2553	9	4D
0005432621087	2553	10	5A
0005432621078	2553	11	5D
0005432621082	2553	12	6A
0005432621083	2553	13	6C
0005432621089	2553	14	7C
0005432621088	2553	15	19A
0005432862289	2553	16	20B
0005432862297	2553	17	20C
0005432621081	2553	18	21D
0005432621079	2553	19	23B
0005432620936	28076	1	1A
0005432620909	28076	2	2C
0005432620959	28076	3	2D
0005432620904	28076	4	3A
0005432621004	28076	5	3C
0005432620911	28076	6	3D
0005432620988	28076	7	4A
0005432862327	28076	8	4D
0005432862326	28076	9	5B
0005432862324	28076	10	5D
0005432620935	28076	11	6B
0005432620923	28076	12	7B
0005432621013	28076	13	7D
0005432620910	28076	14	18C
0005432620984	28076	15	18D
0005432862328	28076	16	19A
0005432862329	28076	17	19D
0005432620924	28076	18	20B
0005432862325	28076	19	21B
0005432620985	28076	20	21C
0005432620986	28076	21	21D
0005432621003	28076	22	23A
0005434191281	28027	1	2A
0005434191282	28027	2	6A
0005434191277	28027	3	6E
0005434191279	28027	4	6F
0005434191274	28027	5	7F
0005434191278	28027	6	12D
0005434191280	28027	7	12E
0005434191275	28027	8	13D
0005434191276	28027	9	14F
0005434191283	28027	10	15E
0005434191284	28027	11	17A
0005433452745	31080	1	1A
0005433451625	31080	2	3A
0005433451624	31080	3	4A
0005433452746	31080	4	6B
0005433454859	31424	1	2A
0005433454863	31424	2	6A
0005434142590	12017	1	1D
0005433134099	12017	2	2B
0005433134121	12017	3	3C
0005433129239	12017	4	4D
0005433129240	12017	5	6D
0005434142591	12017	6	18C
0005433134123	12017	7	19D
0005433129254	12017	8	21A
0005434142589	12017	9	21B
0005434184672	29812	1	1A
0005433134153	29812	2	1C
0005433134154	29812	3	1D
0005433131723	29812	4	2B
0005434183586	29812	5	4C
0005434184671	29812	6	6A
0005433131721	29812	7	7D
0005433131722	29812	8	18A
0005434142620	29812	9	18B
0005434142619	29812	10	19C
0005433131724	29812	11	20C
0005434142621	29812	12	21B
0005433131720	29812	13	21D
0005433134151	29812	14	22B
0005434142618	29812	15	23A
0005433134152	29812	16	23B
0005435697408	16470	1	1A
0005435697393	16470	2	1B
0005435935026	16470	3	1C
0005435697414	16470	4	2A
0005435935036	16470	5	2B
0005435935025	16470	6	2D
0005435697391	16470	7	3B
0005435697392	16470	8	3C
0005435697413	16470	9	3D
0005435697411	16470	10	4B
0005435697397	16470	11	4C
0005435935037	16470	12	4D
0005435697403	16470	13	5B
0005435697409	16470	14	5C
0005435697400	16470	15	5D
0005435697395	16470	16	6B
0005435697398	16470	17	6C
0005435697405	16470	18	6D
0005435697410	16470	19	7B
0005435697412	16470	20	7C
0005435935027	16470	21	7D
0005435697396	16470	22	18A
0005435697404	16470	23	18B
0005435697390	16470	24	19A
0005435697406	16470	25	19B
0005435697394	16470	26	19C
0005435697415	16470	27	20D
0005435697399	16470	28	21B
0005435697402	16470	29	21D
0005435697401	16470	30	22A
0005435697416	16470	31	22B
0005435697407	16470	32	23A
0005435697308	24722	1	1A
0005435697170	24722	2	1B
0005435697148	24722	3	1C
0005435935058	24722	4	1D
0005435697169	24722	5	2B
0005435697164	24722	6	2C
0005435697144	24722	7	2D
0005435697080	24722	8	3A
0005435697243	24722	9	3B
0005435697242	24722	10	3C
0005435697113	24722	11	3D
0005435697172	24722	12	4C
0005435697227	24722	13	4D
0005435697117	24722	14	5A
0005435697218	24722	15	5B
0005435697079	24722	16	5D
0005435697159	24722	17	6C
0005435697102	24722	18	7B
0005435697260	24722	19	7D
0005435697251	24722	20	18C
0005435697261	24722	21	19A
0005435697147	24722	22	19B
0005435697078	24722	23	19C
0005435697052	24722	24	19D
0005435697317	24722	25	20A
0005435697238	24722	26	20C
0005435697127	24722	27	21A
0005435697153	24722	28	21B
0005435697278	24722	29	21C
0005435697244	24722	30	21D
0005435697197	24722	31	22A
0005435697277	24722	32	22C
0005435697146	24722	33	22D
0005435697053	24722	34	23A
0005435697228	24722	35	23B
0005432968820	18796	1	1A
0005432968821	18796	2	1B
0005433724816	18796	3	2A
0005432968828	18796	4	2B
0005432968822	18796	5	3A
0005433724818	18796	6	3B
0005433724815	18796	7	4A
0005432968829	18796	8	6A
0005433724817	18796	9	6B
0005433724791	21595	1	1A
0005432968848	21595	2	2A
0005433724780	21595	3	2B
0005432968849	21595	4	3A
0005433724779	21595	5	3B
0005432968850	21595	6	5A
0005433724795	21595	7	6A
0005434138441	7310	1	1A
0005434138464	7310	2	1D
0005434138409	7310	3	1F
0005434138459	7310	4	2A
0005434138421	7310	5	2C
0005434138433	7310	6	2D
0005434138408	7310	7	2F
0005434138446	7310	8	3D
0005434138447	7310	9	3F
0005434138460	7310	10	4A
0005434138431	7310	11	4C
0005434138392	7310	12	4D
0005434138395	7310	13	4E
0005434138457	7310	14	4F
0005434138456	7310	15	5A
0005434138389	7310	16	5C
0005434138448	7310	17	5D
0005434087529	7310	18	5E
0005434138404	7310	19	5F
0005434138399	7310	20	6A
0005434138422	7310	21	6C
0005434138415	7310	22	6D
0005434138450	7310	23	6E
0005434138410	7310	24	6F
0005434138440	7310	25	7A
0005434138414	7310	26	7C
0005434138396	7310	27	7D
0005434138452	7310	28	7E
0005434138424	7310	29	7F
0005434138438	7310	30	8A
0005434138420	7310	31	8C
0005434138429	7310	32	8D
0005434138468	7310	33	8E
0005434138442	7310	34	8F
0005434138403	7310	35	9A
0005434138469	7310	36	9C
0005434138439	7310	37	9D
0005434138465	7310	38	9E
0005434138461	7310	39	9F
0005434138444	7310	40	10A
0005434138397	7310	41	10C
0005434138445	7310	42	10D
0005434138467	7310	43	10E
0005434138417	7310	44	10F
0005434087527	7310	45	11A
0005434138455	7310	46	11C
0005434138412	7310	47	11D
0005434138454	7310	48	11E
0005434138458	7310	49	12A
0005434138462	7310	50	12D
0005434138423	7310	51	12E
0005434138411	7310	52	12F
0005434138436	7310	53	13A
0005434087526	7310	54	13C
0005434138453	7310	55	13E
0005434138437	7310	56	13F
0005434138402	7310	57	14A
0005434138418	7310	58	14C
0005434138390	7310	59	14E
0005434138426	7310	60	14F
0005434138432	7310	61	15A
0005434138419	7310	62	15C
0005434138393	7310	63	15D
0005434087528	7310	64	15E
0005434138466	7310	65	15F
0005434138406	7310	66	16D
0005434138391	7310	67	16E
0005434138405	7310	68	16F
0005434138430	7310	69	17A
0005434138449	7310	70	17C
0005434138443	7310	71	17D
0005434138451	7310	72	17E
0005434138435	7310	73	17F
0005434138434	7310	74	18A
0005434138398	7310	75	18C
0005434138427	7310	76	18D
0005434138400	7310	77	18E
0005434087530	7310	78	18F
0005434138463	7310	79	19C
0005434138394	7310	80	19D
0005434138428	7310	81	19E
0005434138401	7310	82	19F
0005434138425	7310	83	20A
0005434138413	7310	84	20C
0005434138416	7310	85	20D
0005434138407	7310	86	20F
0005434137817	28530	1	1A
0005434137498	28530	2	1C
0005434137570	28530	3	1D
0005434137360	28530	4	1F
0005434137559	28530	5	2A
0005434137415	28530	6	2C
0005434137801	28530	7	2D
0005434137675	28530	8	2F
0005434137606	28530	9	3A
0005434137446	28530	10	3C
0005434137778	28530	11	3F
0005434137697	28530	12	4A
0005434137764	28530	13	4D
0005434087487	28530	14	4E
0005434137607	28530	15	4F
0005434137073	28530	16	5A
0005434137608	28530	17	5C
0005434137600	28530	18	5D
0005434137586	28530	19	5E
0005434137444	28530	20	5F
0005434087501	28530	21	6A
0005434137503	28530	22	6C
0005434137262	28530	23	6D
0005434137610	28530	24	6E
0005434137763	28530	25	6F
0005434137823	28530	26	7A
0005434137837	28530	27	7C
0005434137809	28530	28	7D
0005434137736	28530	29	7E
0005434137733	28530	30	7F
0005434137674	28530	31	8C
0005434137337	28530	32	8D
0005434137510	28530	33	8E
0005434137412	28530	34	8F
0005434137291	28530	35	9A
0005434137615	28530	36	9C
0005434137543	28530	37	9E
0005434137504	28530	38	9F
0005434137874	28530	39	10A
0005434137338	28530	40	10C
0005434137824	28530	41	10D
0005434137418	28530	42	10E
0005434137499	28530	43	10F
0005434137629	28530	44	11A
0005434137511	28530	45	11C
0005434137598	28530	46	11D
0005434137880	28530	47	11E
0005434137585	28530	48	11F
0005434137875	28530	49	12A
0005434137560	28530	50	12C
0005434137862	28530	51	12E
0005434087488	28530	52	12F
0005434137419	28530	53	13A
0005434137707	28530	54	13C
0005434137739	28530	55	13D
0005434137627	28530	56	13E
0005434137876	28530	57	13F
0005434137026	28530	58	14A
0005434137500	28530	59	14C
0005434087497	28530	60	14E
0005434137667	28530	61	14F
0005434137588	28530	62	15A
0005434087482	28530	63	15C
0005434137735	28530	64	15D
0005434137599	28530	65	15E
0005434137732	28530	66	15F
0005434137718	28530	67	16A
0005434137575	28530	68	16C
0005434087474	28530	69	16D
0005434137807	28530	70	16E
0005434137258	28530	71	16F
0005434136882	28530	72	17A
0005434087473	28530	73	17C
0005434137734	28530	74	17D
0005434137445	28530	75	17E
0005434137587	28530	76	17F
0005434137623	28530	77	18A
0005434137628	28530	78	18C
0005434137831	28530	79	18D
0005434137858	28530	80	18E
0005434137515	28530	81	18F
0005434137863	28530	82	19A
0005434137836	28530	83	19C
0005434137808	28530	84	19D
0005434137313	28530	85	19E
0005434137469	28530	86	19F
0005434137622	28530	87	20A
0005434137609	28530	88	20C
0005434137668	28530	89	20D
0005434137183	28530	90	20E
0005434137601	28530	91	20F
0005433407547	1922	1	1C
0005435808268	1922	2	1D
0005433407515	1922	3	2A
0005434610240	1922	4	3C
0005435808272	1922	5	3D
0005433407548	1922	6	4D
0005435808266	1922	7	5D
0005435808271	1922	8	6A
0005435808263	1922	9	7A
0005433407514	1922	10	7B
0005435808273	1922	11	18B
0005435808270	1922	12	19B
0005433407522	1922	13	19D
0005433407511	1922	14	20C
0005434610241	1922	15	20D
0005433407549	1922	16	21A
0005434610239	1922	17	21B
0005435808265	1922	18	21D
0005433407523	1922	19	22A
0005435808267	1922	20	22B
0005433407550	1922	21	22C
0005435808264	1922	22	22D
0005435808269	1922	23	23A
0005434610206	23070	1	1B
0005434610207	23070	2	21A
0005434503955	16683	1	1A
0005434503940	16683	2	1B
0005434503917	16683	3	1C
0005434504009	16683	4	1D
0005434504062	16683	5	2A
0005434503927	16683	6	2B
0005434503706	16683	7	2C
0005434503969	16683	8	2D
0005434503668	16683	9	3A
0005434503904	16683	10	3B
0005434503970	16683	11	3C
0005434503926	16683	12	3D
0005434503998	16683	13	4A
0005434503881	16683	14	4B
0005434503788	16683	15	4C
0005434503874	16683	16	4D
0005434503875	16683	17	5A
0005434503777	16683	18	5B
0005434503906	16683	19	5C
0005434503786	16683	20	5D
0005434503918	16683	21	6A
0005434503828	16683	22	6B
0005434503964	16683	23	6C
0005434503787	16683	24	6D
0005434503734	16683	25	7B
0005434504018	16683	26	7A
0005434503852	16683	27	7D
0005434503934	16683	28	18A
0005434503793	16683	29	18B
0005434503937	16683	30	18C
0005434503761	16683	31	18D
0005434503965	16683	32	19A
0005434503829	16683	33	19B
0005434504007	16683	34	19C
0005434503916	16683	35	19D
0005434503931	16683	36	20A
0005434503957	16683	37	20B
0005434504054	16683	38	20C
0005434503723	16683	39	20D
0005434503905	16683	40	21A
0005434503742	16683	41	21B
0005434503903	16683	42	21C
0005434503958	16683	43	21D
0005434503935	16683	44	22B
0005434503735	16683	45	22C
0005434503743	16683	46	23A
0005434504010	16683	47	23B
0005434504240	22916	1	1A
0005434504254	22916	2	1B
0005434504228	22916	3	1C
0005434504243	22916	4	2B
0005434504226	22916	5	2C
0005434504246	22916	6	2D
0005434504232	22916	7	3A
0005434504258	22916	8	3B
0005434504247	22916	9	3C
0005434504237	22916	10	3D
0005434504256	22916	11	4A
0005434504231	22916	12	4D
0005434504238	22916	13	5A
0005434504248	22916	14	5B
0005434504242	22916	15	5D
0005434504236	22916	16	6B
0005434504255	22916	17	6C
0005434504249	22916	18	7A
0005434504239	22916	19	7B
0005434504251	22916	20	7D
0005434504227	22916	21	18A
0005434504260	22916	22	18B
0005434504235	22916	23	18C
0005434504230	22916	24	18D
0005434504241	22916	25	19B
0005434504234	22916	26	19C
0005434504229	22916	27	19D
0005434504253	22916	28	20A
0005434504233	22916	29	20B
0005434504244	22916	30	20C
0005434504250	22916	31	20D
0005434504252	22916	32	21A
0005434504257	22916	33	21B
0005434504259	22916	34	22D
0005434504245	22916	35	23A
0005435078395	2181	1	1A
0005435078391	2181	2	1B
0005433266662	2181	3	1C
0005435078390	2181	4	3B
0005435078394	2181	5	4A
0005435078397	2181	6	4C
0005435078385	2181	7	4D
0005433266689	2181	8	5B
0005435078398	2181	9	5C
0005435078392	2181	10	5D
0005435078396	2181	11	6A
0005435078389	2181	12	6D
0005433266688	2181	13	7C
0005435078382	2181	14	7D
0005433266682	2181	15	18B
0005435078384	2181	16	18D
0005435078393	2181	17	19A
0005433266673	2181	18	19B
0005435078386	2181	19	19C
0005433266671	2181	20	19D
0005433266679	2181	21	20A
0005435078387	2181	22	20C
0005433266670	2181	23	20D
0005435078388	2181	24	21D
0005433266672	2181	25	22A
0005435078383	2181	26	22B
0005433266680	2181	27	22C
0005433266755	24367	1	1A
0005435078287	24367	2	1D
0005433266748	24367	3	2B
0005433266752	24367	4	3A
0005433266754	24367	5	4A
0005433266747	24367	6	4C
0005435078307	24367	7	4D
0005433266750	24367	8	5B
0005435078322	24367	9	5D
0005433266756	24367	10	6A
0005433266751	24367	11	6B
0005435078195	24367	12	6C
0005435078244	24367	13	7B
0005435078243	24367	14	7C
0005435078270	24367	15	18B
0005435078223	24367	16	18D
0005435078271	24367	17	19B
0005435078302	24367	18	19C
0005433266753	24367	19	20A
0005435078310	24367	20	20B
0005435078296	24367	21	20D
0005435078238	24367	22	21A
0005435078303	24367	23	21C
0005435078323	24367	24	22B
0005435078308	24367	25	22D
0005433266749	24367	26	23A
0005434988780	6648	1	1C
0005434988781	6648	2	2C
0005435803271	6648	3	4C
0005435803272	6648	4	7C
0005435464493	6648	5	18A
0005434988782	6648	6	19B
0005434988779	6648	7	20C
0005434988778	6648	8	21A
0005434988777	6648	9	21B
0005435803270	6648	10	21D
0005435803273	6648	11	22B
0005434988783	6648	12	22C
0005434988624	23626	1	1B
0005435464515	23626	2	1D
0005434988634	23626	3	2C
0005435803236	23626	4	3D
0005435803258	23626	5	4A
0005434988654	23626	6	4B
0005434988656	23626	7	4C
0005435803246	23626	8	4D
0005434988620	23626	9	5B
0005434988665	23626	10	5D
0005435803247	23626	11	6C
0005435464514	23626	12	7B
0005434988623	23626	13	7D
0005435803259	23626	14	18C
0005434988677	23626	15	18D
0005435464513	23626	16	20A
0005434988621	23626	17	21B
0005434988642	23626	18	21C
0005434988622	23626	19	21D
0005434988655	23626	20	23B
0005433450051	30485	1	1A
0005432383311	30485	2	1C
0005433450043	30485	3	1D
0005432383281	30485	4	2D
0005432383282	30485	5	3A
0005432383283	30485	6	3C
0005432383286	30485	7	3D
0005432383310	30485	8	3F
0005433450045	30485	9	4A
0005433450029	30485	10	4C
0005433450035	30485	11	4D
0005432383289	30485	12	4E
0005433450034	30485	13	5C
0005432383305	30485	14	5E
0005432383314	30485	15	6A
0005432383296	30485	16	6D
0005432383294	30485	17	6E
0005432383290	30485	18	6F
0005433450032	30485	19	7A
0005432383297	30485	20	7C
0005433450037	30485	21	7D
0005432383292	30485	22	7E
0005432383279	30485	23	8A
0005433450033	30485	24	8C
0005432383284	30485	25	8F
0005432383302	30485	26	9A
0005432383301	30485	27	9C
0005433450046	30485	28	9D
0005433450038	30485	29	9E
0005433450030	30485	30	9F
0005433450039	30485	31	10C
0005433450031	30485	32	10D
0005433450044	30485	33	11A
0005432383295	30485	34	11C
0005433450036	30485	35	11D
0005432383303	30485	36	11E
0005432383299	30485	37	11F
0005432383316	30485	38	12F
0005433454882	30485	39	13A
0005433450042	30485	40	13C
0005432383315	30485	41	13D
0005432383307	30485	42	14A
0005432383288	30485	43	14C
0005432383309	30485	44	14D
0005433450049	30485	45	14E
0005432383280	30485	46	15A
0005432383308	30485	47	15D
0005432383287	30485	48	15E
0005432383306	30485	49	15F
0005432383300	30485	50	16C
0005432383285	30485	51	16D
0005433450040	30485	52	16E
0005432383293	30485	53	17C
0005432383291	30485	54	17D
0005433454881	30485	55	17E
0005432383304	30485	56	18D
0005432383298	30485	57	19A
0005433453768	30485	58	19D
0005433450047	30485	59	19E
0005433450050	30485	60	19F
0005433450041	30485	61	20C
0005432383312	30485	62	20D
0005433450048	30485	63	20E
0005432383313	30485	64	20F
0005433449855	31319	1	1A
0005433449902	31319	2	1C
0005432383079	31319	3	1D
0005432382940	31319	4	2A
0005432383107	31319	5	2F
0005433451616	31319	6	3C
0005433449958	31319	7	3D
0005432382890	31319	8	3F
0005433449780	31319	9	4A
0005432382863	31319	10	4C
0005432382913	31319	11	4D
0005432382879	31319	12	4E
0005433449915	31319	13	4F
0005432382756	31319	14	5A
0005432382789	31319	15	5C
0005432382730	31319	16	5F
0005432382961	31319	17	6E
0005433449725	31319	18	7C
0005432382747	31319	19	7E
0005433449841	31319	20	8E
0005432382795	31319	21	8F
0005432382805	31319	22	9C
0005433449810	31319	23	9D
0005432382920	31319	24	9F
0005433449832	31319	25	10A
0005433449723	31319	26	10C
0005432382943	31319	27	10D
0005432382959	31319	28	11D
0005433449766	31319	29	11E
0005433449717	31319	30	12A
0005432382888	31319	31	12C
0005432382969	31319	32	12D
0005432382648	31319	33	12F
0005433451604	31319	34	13D
0005433449936	31319	35	13E
0005433449842	31319	36	13F
0005432382860	31319	37	14A
0005433449722	31319	38	14C
0005432383027	31319	39	14D
0005432382912	31319	40	14E
0005432382938	31319	41	15A
0005432382806	31319	42	14F
0005432382833	31319	43	15D
0005432383087	31319	44	15F
0005432382788	31319	45	16C
0005432382790	31319	46	17A
0005432382930	31319	47	17C
0005432382831	31319	48	17F
0005432382847	31319	49	18C
0005432383026	31319	50	19C
0005433449937	31319	51	19D
0005433449901	31319	52	19F
0005433449765	31319	53	20A
0005433788169	26483	1	1D
0005435548507	26483	2	2C
0005433788163	26483	3	2D
0005433788179	26483	4	3A
0005433788161	26483	5	3C
0005433788176	26483	6	4C
0005435548513	26483	7	4D
0005435548509	26483	8	5B
0005433788162	26483	9	5D
0005435548506	26483	10	6C
0005435548511	26483	11	7A
0005435548512	26483	12	7B
0005433788180	26483	13	18A
0005433788178	26483	14	18C
0005433788189	26483	15	19D
0005435548505	26483	16	20B
0005433788164	26483	17	21A
0005435548508	26483	18	22A
0005435548510	26483	19	23B
0005435299734	10752	1	1A
0005433131677	10752	2	1C
0005435299732	10752	3	1D
0005435299731	10752	4	2A
0005435299746	10752	5	2C
0005433131658	10752	6	3B
0005433131659	10752	7	3D
0005435299737	10752	8	4B
0005435304134	10752	9	4D
0005433131680	10752	10	5A
0005435304142	10752	11	7B
0005435304124	10752	12	7D
0005433126802	10752	13	19D
0005435304126	10752	14	20A
0005435304125	10752	15	22C
0005433126862	29696	1	1A
0005433129292	29696	2	1B
0005435299796	29696	3	1C
0005433129296	29696	4	2B
0005433126861	29696	5	2C
0005435302216	29696	6	3C
0005435299798	29696	7	4A
0005435299793	29696	8	4C
0005433129295	29696	9	4D
0005435302219	29696	10	5A
0005435299797	29696	11	5C
0005433126863	29696	12	18A
0005433126865	29696	13	18B
0005435299795	29696	14	19C
0005433129294	29696	15	19D
0005435299794	29696	16	20A
0005435302217	29696	17	20B
0005435302218	29696	18	20D
0005433129293	29696	19	21A
0005433126864	29696	20	21C
0005434287350	2395	1	1A
0005433109987	2395	2	1B
0005433109989	2395	3	1C
0005433109988	2395	4	2A
0005434287361	2395	5	2C
0005433110031	2395	6	3A
0005434287366	2395	7	3B
0005434287362	2395	8	3C
0005434287351	2395	9	3D
0005434287353	2395	10	4A
0005434287360	2395	11	4B
0005434287359	2395	12	4C
0005434287370	2395	13	4D
0005433109986	2395	14	5A
0005434287358	2395	15	5B
0005434287354	2395	16	5C
0005433110034	2395	17	6B
0005433110009	2395	18	6C
0005432264482	2395	19	7A
0005434287356	2395	20	7B
0005433109997	2395	21	18A
0005434287357	2395	22	18B
0005434287365	2395	23	18C
0005434287364	2395	24	19A
0005434287368	2395	25	19B
0005434287369	2395	26	19D
0005434287352	2395	27	20A
0005432264483	2395	28	20B
0005434287347	2395	29	20C
0005433109984	2395	30	20D
0005434287367	2395	31	21A
0005433110032	2395	32	21B
0005434287348	2395	33	21C
0005433109996	2395	34	22A
0005434287349	2395	35	22C
0005434287355	2395	36	22D
0005433110033	2395	37	23A
0005434287363	2395	38	23B
0005433110094	26840	1	1A
0005433110092	26840	2	1B
0005434287267	26840	3	1D
0005434287154	26840	4	2A
0005434287168	26840	5	2B
0005433110091	26840	6	2C
0005433110090	26840	7	2D
0005433110087	26840	8	3A
0005433110093	26840	9	4A
0005434287170	26840	10	4C
0005433110096	26840	11	4D
0005433110095	26840	12	5A
0005434287217	26840	13	5B
0005434287167	26840	14	5D
0005434287183	26840	15	6A
0005434287174	26840	16	6B
0005434287216	26840	17	6D
0005434287147	26840	18	7A
0005433110086	26840	19	7D
0005434287087	26840	20	18C
0005433110089	26840	21	18D
0005434287246	26840	22	19A
0005434287206	26840	23	19B
0005434287086	26840	24	19C
0005434287175	26840	25	20A
0005434287171	26840	26	20B
0005434287210	26840	27	20C
0005433110088	26840	28	21D
0005434287155	26840	29	23A
0005435856219	25486	1	2A
0005435856217	25486	2	2C
0005435856218	25486	3	3B
0005434269083	25486	4	3C
0005434269084	25486	5	6B
0005435856216	25486	6	20D
0005435856166	26676	1	4B
0005435856151	26676	2	7A
0005434520283	6104	1	1A
0005434520289	6104	2	1B
0005434520273	6104	3	1C
0005434520295	6104	4	1D
0005435314808	6104	5	2A
0005434520278	6104	6	2B
0005434520302	6104	7	2C
0005434520300	6104	8	2D
0005434520298	6104	9	3A
0005434520292	6104	10	3B
0005435314803	6104	11	3C
0005435314806	6104	12	3D
0005434520279	6104	13	4A
0005435314813	6104	14	4B
0005434520288	6104	15	4C
0005435314807	6104	16	5A
0005435314804	6104	17	5B
0005435314816	6104	18	5C
0005434520303	6104	19	5D
0005434520290	6104	20	6A
0005434520285	6104	21	6B
0005434520281	6104	22	6C
0005434520277	6104	23	6D
0005434520284	6104	24	7A
0005434520275	6104	25	7B
0005435314801	6104	26	7C
0005435314777	6104	27	7D
0005434520293	6104	28	18A
0005435314800	6104	29	18B
0005434520297	6104	30	18C
0005434520301	6104	31	18D
0005434520276	6104	32	19A
0005434520291	6104	33	19B
0005434520282	6104	34	19C
0005434520296	6104	35	19D
0005434520299	6104	36	20A
0005435314809	6104	37	20B
0005435314792	6104	38	20C
0005434520286	6104	39	20D
0005434520272	6104	40	21A
0005434520271	6104	41	21B
0005434520294	6104	42	21C
0005435314789	6104	43	21D
0005434520274	6104	44	22A
0005435314788	6104	45	22C
0005434520270	6104	46	22D
0005434520287	6104	47	23A
0005434520280	6104	48	23B
0005433650556	27633	1	1A
0005433650510	27633	2	1C
0005433650538	27633	3	1D
0005435263632	27633	4	1F
0005433650476	27633	5	2A
0005433650529	27633	6	2C
0005433650494	27633	7	2D
0005435263638	27633	8	2F
0005433650542	27633	9	3A
0005433650545	27633	10	3C
0005435263618	27633	11	3D
0005435263639	27633	12	3F
0005433650526	27633	13	4A
0005435263637	27633	14	4C
0005435263626	27633	15	4D
0005433650569	27633	16	4E
0005433650492	27633	17	4F
0005433650479	27633	18	5A
0005435263648	27633	19	5C
0005433650426	27633	20	5D
0005433650550	27633	21	5E
0005435263650	27633	22	5F
0005433650537	27633	23	6A
0005433650543	27633	24	6C
0005433650505	27633	25	6D
0005433650512	27633	26	6E
0005433650432	27633	27	6F
0005433650470	27633	28	7A
0005433650623	27633	29	7C
0005433650573	27633	30	7D
0005435263623	27633	31	7E
0005433650563	27633	32	7F
0005433650541	27633	33	8A
0005435263635	27633	34	8C
0005433650436	27633	35	8D
0005433650535	27633	36	8E
0005433650463	27633	37	8F
0005435263644	27633	38	9A
0005435263625	27633	39	9C
0005433650546	27633	40	9D
0005433650516	27633	41	9E
0005433650539	27633	42	9F
0005433650566	27633	43	10A
0005435263630	27633	44	10C
0005433650451	27633	45	10D
0005433650517	27633	46	10E
0005433650482	27633	47	10F
0005433650491	27633	48	11A
0005435263634	27633	49	11C
0005435263641	27633	50	11D
0005433650475	27633	51	11E
0005433650471	27633	52	11F
0005435263631	27633	53	12A
0005435263636	27633	54	12C
0005433650481	27633	55	12D
0005433650394	27633	56	12E
0005435263624	27633	57	12F
0005435263621	27633	58	13A
0005433650548	27633	59	13C
0005433650498	27633	60	13D
0005433650496	27633	61	13E
0005433650574	27633	62	13F
0005435263619	27633	63	14A
0005433650567	27633	64	14C
0005433650431	27633	65	14D
0005435263651	27633	66	14E
0005433650495	27633	67	14F
0005433650497	27633	68	15A
0005435263620	27633	69	15C
0005433650575	27633	70	15D
0005433650484	27633	71	15E
0005433650437	27633	72	15F
0005435263647	27633	73	16A
0005435263646	27633	74	16C
0005433650572	27633	75	16D
0005433650540	27633	76	16E
0005435263629	27633	77	16F
0005435263617	27633	78	17A
0005433650544	27633	79	17C
0005435263642	27633	80	17D
0005433650434	27633	81	17E
0005435263622	27633	82	17F
0005433650530	27633	83	18A
0005433650472	27633	84	18C
0005433650427	27633	85	18D
0005435263649	27633	86	18E
0005435263640	27633	87	18F
0005435263633	27633	88	19A
0005433650488	27633	89	19C
0005433650518	27633	90	19D
0005433650527	27633	91	19E
0005433650549	27633	92	19F
0005435263628	27633	93	20A
0005433650525	27633	94	20C
0005435263627	27633	95	20D
0005435263643	27633	96	20E
0005435263645	27633	97	20F
0005433868571	4800	1	1A
0005433868569	4800	2	1B
0005433868591	4800	3	1C
0005433868592	4800	4	1D
0005433868564	4800	5	2A
0005433868575	4800	6	2B
0005433868585	4800	7	2C
0005433868567	4800	8	2D
0005433868578	4800	9	3A
0005433868568	4800	10	3B
0005433868584	4800	11	3C
0005433868582	4800	12	3D
0005433868560	4800	13	4A
0005433868561	4800	14	4B
0005433868559	4800	15	4C
0005433868554	4800	16	4D
0005433868555	4800	17	5B
0005433868589	4800	18	5C
0005435860466	4800	19	5D
0005435860457	4800	20	6A
0005433868580	4800	21	6B
0005433868586	4800	22	6C
0005433868566	4800	23	6D
0005433868573	4800	24	7A
0005433868581	4800	25	7B
0005435860458	4800	26	7C
0005433868562	4800	27	18A
0005433868590	4800	28	18B
0005433868583	4800	29	18D
0005433868556	4800	30	19A
0005433868572	4800	31	19B
0005435860456	4800	32	19C
0005433868587	4800	33	19D
0005433868557	4800	34	20A
0005433868552	4800	35	20B
0005433868565	4800	36	20C
0005433868570	4800	37	20D
0005433868553	4800	38	21A
0005433868577	4800	39	21B
0005433868574	4800	40	21C
0005433868558	4800	41	22A
0005433868579	4800	42	22B
0005433868593	4800	43	22C
0005433868588	4800	44	22D
0005433868576	4800	45	23A
0005433868563	4800	46	23B
0005433868444	32576	1	1B
0005433868215	32576	2	1C
0005433868257	32576	3	1D
0005433868007	32576	4	2A
0005433868076	32576	5	2B
0005433868069	32576	6	2C
0005433868206	32576	7	2D
0005433868077	32576	8	3A
0005433868282	32576	9	3B
0005433868102	32576	10	3C
0005433868106	32576	11	4B
0005435860501	32576	12	4C
0005433868166	32576	13	4D
0005433868445	32576	14	5B
0005433868085	32576	15	5D
0005433868067	32576	16	6A
0005433868287	32576	17	6B
0005433868285	32576	18	6C
0005433868298	32576	19	6D
0005433868197	32576	20	7A
0005433868300	32576	21	7C
0005433868117	32576	22	7D
0005433868283	32576	23	18A
0005433868286	32576	24	18B
0005433868072	32576	25	18C
0005433868319	32576	26	18D
0005433868071	32576	27	19A
0005433868259	32576	28	19B
0005433868068	32576	29	19C
0005435860500	32576	30	19D
0005433868171	32576	31	20A
0005433868028	32576	32	20C
0005433868299	32576	33	20D
0005433868151	32576	34	21A
0005433868284	32576	35	21B
0005433868107	32576	36	21C
0005433868243	32576	37	21D
0005433868103	32576	38	22A
0005433868204	32576	39	22B
0005433868105	32576	40	22C
0005433867994	32576	41	22D
0005433867970	32576	42	23A
0005433868258	32576	43	23B
0005434663457	3460	1	1A
0005434663451	3460	2	1B
0005434663450	3460	3	1C
0005434663444	3460	4	2A
0005434663453	3460	5	2D
0005435911419	3460	6	3A
0005434663446	3460	7	3B
0005434663445	3460	8	3C
0005434460513	3460	9	4A
0005434663456	3460	10	4C
0005435911371	3460	11	5A
0005435911435	3460	12	5B
0005435911397	3460	13	6B
0005434663448	3460	14	7A
0005434663447	3460	15	7B
0005434663455	3460	16	18B
0005434461653	3460	17	18A
0005435911428	3460	18	19A
0005434460511	3460	19	19D
0005434461654	3460	20	20A
0005434663452	3460	21	20D
0005434460512	3460	22	21B
0005435911434	3460	23	21D
0005434663454	3460	24	22A
0005434663449	3460	25	22B
0005435911388	3460	26	22D
0005435911429	3460	27	23A
0005434663458	3460	28	23B
0005434663267	12480	1	1A
0005434663341	12480	2	1C
0005434663304	12480	3	3D
0005434663339	12480	4	4D
0005434663338	12480	5	5A
0005435911477	12480	6	5B
0005434663340	12480	7	6C
0005434663357	12480	8	7A
0005434663306	12480	9	7B
0005435911475	12480	10	7D
0005435911476	12480	11	19B
0005434663309	12480	12	20B
0005435911474	12480	13	20C
0005434663305	12480	14	20D
0005435911473	12480	15	21C
0005434663345	12480	16	21D
0005434663333	12480	17	22A
0005434663266	12480	18	22B
0005435911478	12480	19	22D
0005433867994	14481	1	1B
0005433868085	14481	2	1C
0005433868151	14481	3	1D
0005433868215	14481	4	2C
0005433868445	14481	5	2B
0005433868071	14481	6	2D
0005433868257	14481	7	3B
0005433868072	14481	8	3C
0005433868285	14481	9	3D
0005433868444	14481	10	4A
0005433868107	14481	11	4B
0005433868076	14481	12	4D
0005433868286	14481	13	5A
0005433868243	14481	14	5B
0005433868068	14481	15	5D
0005433868106	14481	16	5C
0005433868067	14481	17	6A
0005433868077	14481	18	6B
0005435860500	14481	19	6C
0005435860501	14481	20	6D
0005433868103	14481	21	7A
0005433868319	14481	22	7B
0005433868171	14481	23	7C
0005433868197	14481	24	7D
0005433868028	14481	25	18A
0005433868206	14481	26	18B
0005433868287	14481	27	18C
0005433868102	14481	28	18D
0005433868007	14481	29	19C
0005433868204	14481	30	19D
0005433868283	14481	31	20A
0005433868117	14481	32	20B
0005433868258	14481	33	20C
0005433868105	14481	34	20D
0005433868259	14481	35	21A
0005433868069	14481	36	21B
0005433868282	14481	37	21D
0005433868284	14481	38	22A
0005433867970	14481	39	22B
0005433868299	14481	40	22C
0005433868298	14481	41	22D
0005433868300	14481	42	23A
0005433868166	14481	43	23B
0005433868535	32670	1	1A
0005433868539	32670	2	1B
0005433868548	32670	3	1C
0005433868517	32670	4	1D
0005435860454	32670	5	2A
0005433868529	32670	6	2B
0005433868532	32670	7	2C
0005435860461	32670	8	3A
0005433868541	32670	9	2D
0005433868524	32670	10	3B
0005433868514	32670	11	3C
0005433868516	32670	12	4A
0005433868526	32670	13	4C
0005433868538	32670	14	4D
0005435860453	32670	15	5B
0005433868531	32670	16	5C
0005433868537	32670	17	5D
0005433868534	32670	18	6A
0005433868550	32670	19	6B
0005433868536	32670	20	6C
0005433868515	32670	21	7A
0005433868513	32670	22	6D
0005433868551	32670	23	7B
0005433868549	32670	24	7D
0005433868519	32670	25	18A
0005433868543	32670	26	18B
0005433868540	32670	27	18D
0005433868544	32670	28	18C
0005433868542	32670	29	19A
0005433868522	32670	30	19B
0005433868547	32670	31	19C
0005433868533	32670	32	20A
0005433868545	32670	33	20B
0005433868523	32670	34	20D
0005433868528	32670	35	21A
0005433868527	32670	36	21B
0005433868525	32670	37	21D
0005433868520	32670	38	22A
0005433868518	32670	39	22B
0005433868530	32670	40	22C
0005433868546	32670	41	22D
0005435860460	32670	42	23A
0005433868521	32670	43	23B
0005432799287	12114	1	1B
0005432799229	12114	2	1C
0005432799288	12114	3	2C
0005432799205	12114	4	3A
0005432799301	12114	5	3B
0005432799392	12114	6	3D
0005432799247	12114	7	4B
0005432799216	12114	8	5A
0005432799357	12114	9	5C
0005432799356	12114	10	6A
0005432799273	12114	11	6D
0005432799303	12114	12	7A
0005432799414	12114	13	18C
0005432799171	12114	14	20B
0005432799304	12114	15	21A
0005432799355	12114	16	21B
0005432799300	12114	17	21D
0005432799391	12114	18	22A
0005432799299	12114	19	22D
0005432799376	12114	20	23A
0005432799505	14833	1	1A
0005432799521	14833	2	1B
0005432799506	14833	3	1D
0005432799504	14833	4	2A
0005432799524	14833	5	2B
0005432799509	14833	6	2C
0005432799519	14833	7	2D
0005432799520	14833	8	3B
0005432799528	14833	9	3D
0005432799516	14833	10	4B
0005432799510	14833	11	4C
0005432799522	14833	12	4D
0005432799530	14833	13	6C
0005432799526	14833	14	6D
0005432799527	14833	15	7A
0005432799529	14833	16	7D
0005432799507	14833	17	18C
0005432799517	14833	18	18D
0005432799513	14833	19	19A
0005432799523	14833	20	19B
0005432799525	14833	21	19D
0005432799502	14833	22	20A
0005432799515	14833	23	20B
0005432799512	14833	24	20C
0005432799514	14833	25	20D
0005432799511	14833	26	21C
0005432799503	14833	27	21B
0005432799508	14833	28	22C
0005432799518	14833	29	23B
0005434299637	7071	1	1A
0005434299627	7071	2	1D
0005434407966	7071	3	1C
0005434407987	7071	4	2A
0005434299632	7071	5	1F
0005434407967	7071	6	2C
0005434407955	7071	7	2D
0005432153960	7071	8	2F
0005435293203	7071	9	3A
0005434407950	7071	10	3C
0005435310983	7071	11	3F
0005434407941	7071	12	4A
0005432108259	7071	13	4B
0005434407957	7071	14	4D
0005435293186	7071	15	4C
0005434407949	7071	16	4E
0005434407964	7071	17	4F
0005434407961	7071	18	5B
0005435310945	7071	19	5A
0005434299645	7071	20	5C
0005434299629	7071	21	5D
0005434407984	7071	22	5E
0005435310993	7071	23	5F
0005435310949	7071	24	6A
0005434407980	7071	25	6C
0005434407986	7071	26	6D
0005435310939	7071	27	6E
0005434407975	7071	28	7A
0005434299634	7071	29	6F
0005434299643	7071	30	7B
0005435310940	7071	31	7C
0005434299639	7071	32	7D
0005434407960	7071	33	7E
0005435293177	7071	34	7F
0005434407958	7071	35	8B
0005434407992	7071	36	8C
0005434299626	7071	37	8D
0005434299640	7071	38	8F
0005434407962	7071	39	8E
0005435293193	7071	40	9A
0005434299624	7071	41	9C
0005434407985	7071	42	9B
0005434407946	7071	43	9D
0005434299641	7071	44	9F
0005434407937	7071	45	9E
0005434407954	7071	46	10B
0005434299628	7071	47	10C
0005434299638	7071	48	10E
0005434407933	7071	49	11A
0005434407940	7071	50	11B
0005434407965	7071	51	11C
0005434299636	7071	52	11E
0005435310987	7071	53	11D
0005434407979	7071	54	11F
0005434407939	7071	55	12A
0005434407930	7071	56	12C
0005434407952	7071	57	12B
0005434407945	7071	58	12D
0005434299622	7071	59	12E
0005434407974	7071	60	12F
0005434407990	7071	61	13B
0005434407983	7071	62	13A
0005434407973	7071	63	13C
0005435310926	7071	64	13D
0005432108258	7071	65	13E
0005434407971	7071	66	13F
0005435310927	7071	67	14B
0005434299630	7071	68	14A
0005434407936	7071	69	14D
0005434407959	7071	70	14C
0005435310977	7071	71	14E
0005435310982	7071	72	15A
0005434299623	7071	73	14F
0005432153958	7071	74	15C
0005434407988	7071	75	15B
0005434407977	7071	76	15D
0005434299635	7071	77	15E
0005434407951	7071	78	16A
0005434407981	7071	79	15F
0005435293192	7071	80	16B
0005435311003	7071	81	16C
0005434407968	7071	82	16D
0005432153957	7071	83	16F
0005435310928	7071	84	16E
0005434407953	7071	85	17A
0005435310986	7071	86	17B
0005432108257	7071	87	17C
0005434299642	7071	88	17D
0005434407935	7071	89	17F
0005434299625	7071	90	17E
0005434407934	7071	91	18A
0005434407963	7071	92	18B
0005434407989	7071	93	18C
0005435293150	7071	94	18D
0005434407944	7071	95	18F
0005434299644	7071	96	18E
0005432153959	7071	97	19B
0005435310992	7071	98	19C
0005432153961	7071	99	19D
0005432153962	7071	100	19F
0005434407969	7071	101	19E
0005434407970	7071	102	20B
0005434407947	7071	103	20A
0005434407931	7071	104	20C
0005434407972	7071	105	20E
0005434407991	7071	106	20F
0005434407938	7071	107	21A
0005434407942	7071	108	21B
0005434299631	7071	109	21D
0005434299633	7071	110	21C
0005435310951	7071	111	21E
0005434407982	7071	112	21F
0005434407978	7071	113	22B
0005435310976	7071	114	22A
0005434407956	7071	115	22C
0005435293187	7071	116	22E
0005434407932	7071	117	22D
0005434407948	7071	118	23A
0005434407993	7071	119	22F
0005435293190	7071	120	23B
0005434407976	7071	121	23C
0005432153963	7071	122	23D
0005434407943	7071	123	23F
0005435310967	7071	124	23E
0005435311088	26922	1	1A
0005435293292	26922	2	1D
0005434407190	26922	3	1C
0005434299512	26922	4	1F
0005434407389	26922	5	2A
0005435293295	26922	6	2D
0005435293297	26922	7	3C
0005434407175	26922	8	3A
0005434407373	26922	9	3F
0005434407312	26922	10	3D
0005434407552	26922	11	4A
0005434407304	26922	12	4C
0005434299477	26922	13	4B
0005434407408	26922	14	4D
0005434299442	26922	15	4E
0005434407457	26922	16	4F
0005434407075	26922	17	5B
0005434407527	26922	18	5A
0005434407508	26922	19	5C
0005434299437	26922	20	5D
0005434407169	26922	21	5E
0005434407237	26922	22	5F
0005434407076	26922	23	6B
0005434407251	26922	24	6C
0005434299565	26922	25	6D
0005434407303	26922	26	6F
0005434299344	26922	27	6E
0005434407407	26922	28	7A
0005434407191	26922	29	7B
0005434299406	26922	30	7C
0005434407454	26922	31	7E
0005434407421	26922	32	7D
0005435311093	26922	33	8A
0005434407217	26922	34	8B
0005434407205	26922	35	8C
0005434407478	26922	36	8D
0005434407558	26922	37	8F
0005434407168	26922	38	8E
0005432058390	26922	39	9A
0005434407595	26922	40	9B
0005434406700	26922	41	9D
0005434407141	26922	42	9C
0005434407211	26922	43	9E
0005434407392	26922	44	9F
0005434407195	26922	45	10B
0005434299426	26922	46	10C
0005434407362	26922	47	10E
0005434407485	26922	48	11A
0005435311090	26922	49	11C
0005434299534	26922	50	11E
0005434407550	26922	51	11D
0005434407096	26922	52	11F
0005434407238	26922	53	12B
0005434407479	26922	54	12A
0005434407170	26922	55	12C
0005434407383	26922	56	12D
0005435293296	26922	57	12E
0005435293286	26922	58	13A
0005432058389	26922	59	12F
0005434299354	26922	60	13B
0005435311091	26922	61	13D
0005434407343	26922	62	13C
0005434407537	26922	63	13E
0005434407351	26922	64	13F
0005434407365	26922	65	14B
0005434407477	26922	66	14A
0005435293290	26922	67	14D
0005434407489	26922	68	14C
0005434299427	26922	69	14F
0005435311089	26922	70	14E
0005434407438	26922	71	15B
0005432058391	26922	72	15A
0005434299436	26922	73	15C
0005434407437	26922	74	15E
0005434407186	26922	75	15D
0005434407569	26922	76	16A
0005434407118	26922	77	15F
0005434407142	26922	78	16C
0005434407124	26922	79	16B
0005434407204	26922	80	16D
0005434407352	26922	81	16E
0005434407171	26922	82	17A
0005434407212	26922	83	16F
0005434407553	26922	84	17B
0005434407638	26922	85	17C
0005434407159	26922	86	17E
0005434299524	26922	87	17D
0005434407293	26922	88	17F
0005434407563	26922	89	18A
0005435311092	26922	90	18B
0005434407279	26922	91	18C
0005434406920	26922	92	18D
0005435293288	26922	93	18F
0005434407372	26922	94	18E
0005434407538	26922	95	19A
0005435293293	26922	96	19B
0005434407317	26922	97	19C
0005434299497	26922	98	19D
0005434407409	26922	99	19F
0005434407453	26922	100	19E
0005435293287	26922	101	20B
0005432058392	26922	102	20A
0005434299513	26922	103	20C
0005434299566	26922	104	20E
0005434407562	26922	105	20D
0005434407185	26922	106	20F
0005434299537	26922	107	21A
0005434299190	26922	108	21C
0005435293294	26922	109	21B
0005434407194	26922	110	21D
0005434299554	26922	111	21E
0005435293289	26922	112	21F
0005434407388	26922	113	22B
0005434407509	26922	114	22A
0005434299424	26922	115	22D
0005434299191	26922	116	22C
0005434407138	26922	117	22F
0005434407127	26922	118	22E
0005434407449	26922	119	23B
0005434407480	26922	120	23A
0005434407370	26922	121	23C
0005434299443	26922	122	23D
0005435293291	26922	123	23F
0005434299476	26922	124	23E
0005432604479	6445	1	1A
0005432604453	6445	2	1D
0005432604467	6445	3	2A
0005432604478	6445	4	2B
0005432604470	6445	5	2C
0005432604492	6445	6	2D
0005432604477	6445	7	3A
0005432604464	6445	8	3B
0005432604459	6445	9	3C
0005432604458	6445	10	4A
0005432604480	6445	11	4B
0005434512128	6445	12	4C
0005432604493	6445	13	4D
0005432604473	6445	14	5A
0005432604475	6445	15	5B
0005432604457	6445	16	5D
0005432604491	6445	17	6A
0005432604481	6445	18	6C
0005432604483	6445	19	6D
0005432604490	6445	20	7A
0005432604460	6445	21	7B
0005432604463	6445	22	7C
0005432604489	6445	23	18A
0005432604468	6445	24	18B
0005432604484	6445	25	18C
0005432604476	6445	26	18D
0005432604486	6445	27	19A
0005432604461	6445	28	19B
0005432604465	6445	29	19C
0005432604471	6445	30	19D
0005432604454	6445	31	20A
0005432604472	6445	32	20B
0005432604487	6445	33	20C
0005432604469	6445	34	20D
0005432604456	6445	35	21A
0005432604466	6445	36	21B
0005432604488	6445	37	21D
0005432604462	6445	38	22A
0005432604455	6445	39	22B
0005432604474	6445	40	22C
0005432604482	6445	41	22D
0005434512127	6445	42	23A
0005432604485	6445	43	23B
0005432604138	21369	1	1A
0005432604137	21369	2	1B
0005435221517	21369	3	1C
0005432604122	21369	4	1D
0005434512091	21369	5	2C
0005434512087	21369	6	2D
0005432604004	21369	7	3B
0005432604121	21369	8	3D
0005434512088	21369	9	4A
0005432604108	21369	10	4C
0005432604140	21369	11	5A
0005432604209	21369	12	5C
0005432604139	21369	13	5D
0005432604016	21369	14	6C
0005432604208	21369	15	6D
0005432604092	21369	16	7A
0005432604155	21369	17	7B
0005432604093	21369	18	7C
0005432604109	21369	19	7D
0005432604102	21369	20	18B
0005432604017	21369	21	18C
0005432604193	21369	22	18D
0005432603849	21369	23	19A
0005432604025	21369	24	19B
0005432604147	21369	25	19C
0005435221057	21369	26	19D
0005432604280	21369	27	20B
0005432604144	21369	28	20D
0005432604011	21369	29	21B
0005432604132	21369	30	21C
0005432604156	21369	31	21D
0005432604117	21369	32	22A
0005432604107	21369	33	22B
0005432604207	21369	34	22C
0005435221518	21369	35	22D
0005432604085	21369	36	23A
0005434906940	14970	1	1A
0005433251575	14970	2	1C
0005433251568	14970	3	1D
0005434907095	14970	4	1F
0005433251574	14970	5	2A
0005434906802	14970	6	2C
0005434907080	14970	7	2F
0005434906633	14970	8	3A
0005434906815	14970	9	3C
0005433251570	14970	10	3D
0005434906935	14970	11	3F
0005433251584	14970	12	4A
0005433251579	14970	13	4C
0005434907090	14970	14	4D
0005433251577	14970	15	4E
0005433251586	14970	16	4F
0005434906972	14970	17	5A
0005433251587	14970	18	5C
0005433251565	14970	19	5E
0005434907018	14970	20	5F
0005434907129	14970	21	6A
0005434906933	14970	22	6D
0005434906863	14970	23	6E
0005434907071	14970	24	7A
0005433251578	14970	25	7C
0005433251562	14970	26	7D
0005434907006	14970	27	7E
0005434906996	14970	28	7F
0005434907118	14970	29	8A
0005434906872	14970	30	8D
0005433251583	14970	31	8E
0005434907094	14970	32	8F
0005434906934	14970	33	9A
0005434906882	14970	34	9C
0005434906689	14970	35	9D
0005434906873	14970	36	9E
0005433251564	14970	37	9F
0005434906846	14970	38	10A
0005434906817	14970	39	10C
0005434906993	14970	40	10E
0005433251581	14970	41	10F
0005433251580	14970	42	11A
0005434907009	14970	43	11C
0005434906632	14970	44	11D
0005434906942	14970	45	11E
0005434907076	14970	46	11F
0005433251571	14970	47	12A
0005433251567	14970	48	12C
0005433251561	14970	49	12E
0005434906759	14970	50	13C
0005434906973	14970	51	13E
0005433251589	14970	52	13F
0005434906758	14970	53	14A
0005434907089	14970	54	14C
0005433251572	14970	55	14D
0005434906891	14970	56	14E
0005434906602	14970	57	15A
0005434907116	14970	58	15D
0005434906803	14970	59	15E
0005433251563	14970	60	15F
0005433251590	14970	61	16A
0005434906845	14970	62	16C
0005434906997	14970	63	16D
0005434907049	14970	64	16F
0005433251588	14970	65	17A
0005433251585	14970	66	17D
0005434906938	14970	67	17F
0005434906859	14970	68	18A
0005434907088	14970	69	18C
0005434906816	14970	70	18D
0005433251569	14970	71	18E
0005434907119	14970	72	19A
0005434907117	14970	73	19C
0005433251560	14970	74	19D
0005433251576	14970	75	19E
0005434906976	14970	76	19F
0005433251573	14970	77	20A
0005434907001	14970	78	20C
0005433251582	14970	79	20E
0005433251566	14970	80	20F
0005433251335	25830	1	1A
0005434907434	25830	2	1C
0005434907384	25830	3	1D
0005434907380	25830	4	1F
0005434907377	25830	5	2A
0005433251360	25830	6	2C
0005434907391	25830	7	2D
0005434907419	25830	8	2F
0005434907408	25830	9	3A
0005434907405	25830	10	3C
0005434907404	25830	11	3D
0005434907386	25830	12	3F
0005433251411	25830	13	4A
0005434907392	25830	14	4C
0005434907372	25830	15	4D
0005434907424	25830	16	4E
0005434907414	25830	17	4F
0005434907412	25830	18	5A
0005434907396	25830	19	5C
0005434907394	25830	20	5D
0005434907417	25830	21	5E
0005434907395	25830	22	6A
0005434907420	25830	23	6C
0005434907429	25830	24	6D
0005434907422	25830	25	6E
0005434907393	25830	26	6F
0005434907426	25830	27	7C
0005434907411	25830	28	7D
0005433251214	25830	29	7E
0005434907390	25830	30	7F
0005434907397	25830	31	8C
0005433251365	25830	32	8D
0005433251334	25830	33	8E
0005433251253	25830	34	8F
0005433251213	25830	35	9A
0005433251361	25830	36	9C
0005434907433	25830	37	9D
0005434907401	25830	38	9F
0005434907388	25830	39	10A
0005434907423	25830	40	10C
0005434907398	25830	41	10D
0005434907432	25830	42	10E
0005434907430	25830	43	10F
0005434907387	25830	44	11A
0005434907378	25830	45	11C
0005434907382	25830	46	12A
0005434907418	25830	47	12C
0005434907381	25830	48	12D
0005434907379	25830	49	12E
0005433251266	25830	50	12F
0005433251289	25830	51	13A
0005434907374	25830	52	13C
0005434907400	25830	53	13D
0005434907425	25830	54	13E
0005434907373	25830	55	14A
0005434907406	25830	56	14C
0005434907399	25830	57	14D
0005433251378	25830	58	14E
0005434907403	25830	59	14F
0005433251265	25830	60	15A
0005433251297	25830	61	15C
0005434907407	25830	62	15D
0005433251376	25830	63	15E
0005433251267	25830	64	15F
0005434907421	25830	65	16C
0005433251296	25830	66	16D
0005434907376	25830	67	16E
0005434907410	25830	68	16F
0005434907375	25830	69	17A
0005434907409	25830	70	17C
0005434907435	25830	71	17E
0005434907431	25830	72	18A
0005434907416	25830	73	18C
0005434907389	25830	74	18D
0005434907385	25830	75	18F
0005434907413	25830	76	19C
0005434907383	25830	77	19D
0005434907415	25830	78	19E
0005434907428	25830	79	19F
0005434907427	25830	80	20A
0005433251508	25830	81	20C
0005434907402	25830	82	20D
0005433251337	25830	83	20E
0005433251244	25830	84	20F
0005433008774	14155	1	1A
0005433008793	14155	2	2A
0005433008777	14155	3	2D
0005433008783	14155	4	2F
0005433008794	14155	5	3A
0005433008779	14155	6	3D
0005433008778	14155	7	3F
0005433008764	14155	8	4A
0005433008770	14155	9	4C
0005433008752	14155	10	4E
0005433008755	14155	11	5E
0005433008765	14155	12	5F
0005433008776	14155	13	6A
0005433008753	14155	14	6C
0005433008782	14155	15	6E
0005433008772	14155	16	7A
0005433008751	14155	17	7D
0005433008767	14155	18	8A
0005433008754	14155	19	8D
0005433008787	14155	20	8E
0005433008760	14155	21	9A
0005433008761	14155	22	9D
0005433008762	14155	23	9F
0005433008785	14155	24	10A
0005433008780	14155	25	10D
0005433008784	14155	26	10E
0005433008757	14155	27	10F
0005433008773	14155	28	11C
0005433008789	14155	29	12C
0005433008775	14155	30	12D
0005433008768	14155	31	13A
0005433008791	14155	32	13D
0005433008792	14155	33	13F
0005433008796	14155	34	14C
0005433008795	14155	35	14D
0005433008750	14155	36	16A
0005433008763	14155	37	16C
0005433008790	14155	38	16D
0005433008756	14155	39	17A
0005433008786	14155	40	17D
0005433008771	14155	41	17E
0005433008781	14155	42	17F
0005433008769	14155	43	19C
0005433008758	14155	44	19F
0005433008766	14155	45	20D
0005433008759	14155	46	20E
0005433008788	14155	47	20F
0005433008461	22848	1	1C
0005433008283	22848	2	1D
0005433008284	22848	3	1F
0005433008306	22848	4	3D
0005433008382	22848	5	3F
0005433008311	22848	6	4A
0005433008299	22848	7	4E
0005433008296	22848	8	5A
0005433810562	22848	9	5C
0005433810556	22848	10	6D
0005433008321	22848	11	6E
0005433810565	22848	12	7A
0005433008526	22848	13	7E
0005433008374	22848	14	7F
0005433008405	22848	15	8D
0005433008380	22848	16	8E
0005433008360	22848	17	9C
0005433008290	22848	18	9D
0005433008238	22848	19	10A
0005433008310	22848	20	10C
0005433810564	22848	21	10D
0005433008336	22848	22	10E
0005433810559	22848	23	10F
0005433008295	22848	24	11D
0005433810561	22848	25	11E
0005433810563	22848	26	11F
0005433008315	22848	27	12D
0005433008245	22848	28	12E
0005433008112	22848	29	12F
0005433008291	22848	30	13A
0005433008247	22848	31	13D
0005433008246	22848	32	13E
0005433008479	22848	33	14A
0005433008373	22848	34	14C
0005433008176	22848	35	14E
0005433008381	22848	36	14F
0005433810557	22848	37	15A
0005433810558	22848	38	15C
0005433008532	22848	39	15E
0005433008298	22848	40	17D
0005433810555	22848	41	17F
0005433008288	22848	42	18A
0005433008297	22848	43	18F
0005433810560	22848	44	19A
0005433008155	22848	45	19D
0005433008289	22848	46	20C
0005433008353	22848	47	20E
0005433008335	22848	48	20F
0005434925532	14917	1	2F
0005434925618	14917	2	3A
0005434925621	14917	3	3C
0005434925530	14917	4	3D
0005434925574	14917	5	4F
0005434925430	14917	6	5C
0005434925611	14917	7	7D
0005434925538	14917	8	7F
0005434925578	14917	9	9A
0005434925570	14917	10	10D
0005434925569	14917	11	10E
0005434925597	14917	12	11F
0005434925620	14917	13	12E
0005434925397	14917	14	13F
0005434925575	14917	15	14C
0005434925619	14917	16	14D
0005434925531	14917	17	14F
0005434925539	14917	18	16E
0005434925576	14917	19	18C
0005434925622	14917	20	20A
0005434925523	14917	21	20D
0005434925873	20545	1	1A
0005434925876	20545	2	2C
0005434925875	20545	3	3D
0005434925867	20545	4	6D
0005434925861	20545	5	6E
0005434925863	20545	6	7A
0005434925869	20545	7	7F
0005434925859	20545	8	8E
0005434925879	20545	9	9E
0005434925860	20545	10	9F
0005434925874	20545	11	10D
0005434925881	20545	12	12A
0005434925865	20545	13	12D
0005434925877	20545	14	13C
0005434925868	20545	15	13E
0005434925864	20545	16	14E
0005434925866	20545	17	15A
0005434925870	20545	18	15C
0005434925857	20545	19	15F
0005434925880	20545	20	16D
0005434925872	20545	21	17D
0005434925882	20545	22	18D
0005434925871	20545	23	18E
0005434925878	20545	24	18F
0005434925862	20545	25	19D
0005434925858	20545	26	20D
0005435487914	15841	1	1A
0005435999166	15841	2	1B
0005435487899	15841	3	1C
0005435999138	15841	4	1D
0005435487900	15841	5	2A
0005435999180	15841	6	2B
0005435487916	15841	7	2C
0005435487904	15841	8	2D
0005435999105	15841	9	3A
0005435999181	15841	10	3B
0005435487908	15841	11	3C
0005435999101	15841	12	3D
0005435999136	15841	13	4A
0005435487909	15841	14	4B
0005435999143	15841	15	4C
0005435487905	15841	16	4D
0005435999108	15841	17	5A
0005435487903	15841	18	5B
0005435487915	15841	19	5C
0005435999158	15841	20	6B
0005435999109	15841	21	6C
0005435999139	15841	22	6D
0005435999168	15841	23	7A
0005435487913	15841	24	7D
0005435999153	15841	25	18A
0005435999152	15841	26	18D
0005435487917	15841	27	19A
0005435999119	15841	28	19B
0005435487910	15841	29	19C
0005435487902	15841	30	19D
0005435998987	15841	31	20A
0005435999135	15841	32	20B
0005435487911	15841	33	20C
0005435999125	15841	34	21A
0005435487918	15841	35	21B
0005435487907	15841	36	21C
0005435999169	15841	37	21D
0005435487906	15841	38	22A
0005435999167	15841	39	22C
0005435487901	15841	40	22D
0005435487912	15841	41	23A
0005435999137	15841	42	23B
0005435999298	19723	1	1A
0005435487669	19723	2	1B
0005435487695	19723	3	1C
0005435487745	19723	4	1D
0005435999290	19723	5	2A
0005435487672	19723	6	2C
0005435487660	19723	7	2D
0005435999297	19723	8	3A
0005435487573	19723	9	3B
0005435999280	19723	10	3C
0005435487735	19723	11	4A
0005435487716	19723	12	4B
0005435487652	19723	13	4D
0005435487744	19723	14	5B
0005435999291	19723	15	5C
0005435999283	19723	16	5D
0005435999296	19723	17	6A
0005435487572	19723	18	6B
0005435999284	19723	19	6D
0005435487715	19723	20	7B
0005435487688	19723	21	7C
0005435487734	19723	22	7D
0005435999292	19723	23	18A
0005435999285	19723	24	18B
0005435487670	19723	25	18C
0005435487679	19723	26	18D
0005435487615	19723	27	19A
0005435999281	19723	28	19B
0005435487662	19723	29	19C
0005435999299	19723	30	19D
0005435487673	19723	31	20B
0005435999286	19723	32	20D
0005435999282	19723	33	21A
0005435999288	19723	34	21B
0005435487646	19723	35	21C
0005435487694	19723	36	21D
0005435999293	19723	37	22A
0005435999287	19723	38	22B
0005435999289	19723	39	22C
0005435487687	19723	40	22D
0005435999294	19723	41	23A
0005435999295	19723	42	23B
0005435472754	5996	1	1A
0005432142262	5996	2	1F
0005432660826	5996	3	2D
0005435472683	5996	4	2C
0005435839545	5996	5	3C
0005435839540	5996	6	4D
0005435839561	5996	7	5A
0005435839534	5996	8	6B
0005435472743	5996	9	6D
0005435839555	5996	10	7A
0005435472682	5996	11	6F
0005435839560	5996	12	7C
0005435839542	5996	13	7D
0005435472605	5996	14	8A
0005435472671	5996	15	8D
0005435472715	5996	16	8C
0005435472732	5996	17	8F
0005435839558	5996	18	9D
0005435839539	5996	19	9E
0005435472734	5996	20	10A
0005435839549	5996	21	10C
0005435472712	5996	22	10B
0005435472780	5996	23	10D
0005435839535	5996	24	11A
0005435839537	5996	25	11B
0005435839546	5996	26	11D
0005435472744	5996	27	11C
0005432142263	5996	28	11E
0005432659715	5996	29	12B
0005435839550	5996	30	12A
0005435839548	5996	31	12D
0005432537038	5996	32	12E
0005435472767	5996	33	13A
0005435472779	5996	34	13C
0005435472692	5996	35	13B
0005435472753	5996	36	13E
0005435472726	5996	37	14A
0005435472772	5996	38	14C
0005432660825	5996	39	14D
0005435472672	5996	40	14F
0005435839541	5996	41	14E
0005432658599	5996	42	15C
0005435472668	5996	43	15F
0005435472733	5996	44	15D
0005435839559	5996	45	16A
0005435472667	5996	46	16B
0005435839544	5996	47	16E
0005435472752	5996	48	16D
0005435839536	5996	49	17A
0005435839557	5996	50	17D
0005435472771	5996	51	17C
0005435839551	5996	52	18B
0005435839554	5996	53	18C
0005435839556	5996	54	19A
0005435839553	5996	55	19C
0005435472729	5996	56	19D
0005435839543	5996	57	19F
0005435472749	5996	58	20A
0005435839547	5996	59	20D
0005435839552	5996	60	20E
0005435472606	5996	61	21C
0005435472766	5996	62	21D
0005435839538	5996	63	21F
0005435839296	18092	1	1D
0005435839320	18092	2	2F
0005435839332	18092	3	2D
0005432667436	18092	4	2C
0005432664116	18092	5	3A
0005435472855	18092	6	3D
0005435839310	18092	7	3F
0005432667442	18092	8	4F
0005435839253	18092	9	5C
0005435472860	18092	10	5A
0005435839254	18092	11	6A
0005435839308	18092	12	6D
0005435472857	18092	13	7A
0005435472850	18092	14	7B
0005435472863	18092	15	8C
0005432664115	18092	16	8F
0005435839298	18092	17	8E
0005435472856	18092	18	9A
0005435839273	18092	19	9E
0005435839425	18092	20	9D
0005435472849	18092	21	10A
0005435472861	18092	22	10D
0005435839248	18092	23	11A
0005435839219	18092	24	10F
0005435472864	18092	25	11D
0005435472854	18092	26	11C
0005435839319	18092	27	11F
0005432660793	18092	28	12B
0005435839424	18092	29	12A
0005435839307	18092	30	12C
0005435839354	18092	31	13A
0005432537066	18092	32	13C
0005432664124	18092	33	13D
0005432664121	18092	34	13E
0005435839398	18092	35	14C
0005435839397	18092	36	15B
0005435472852	18092	37	15D
0005435472851	18092	38	15C
0005435472853	18092	39	16A
0005435472866	18092	40	15F
0005435472858	18092	41	17A
0005435472862	18092	42	16E
0005432667435	18092	43	17B
0005435839218	18092	44	18A
0005432537067	18092	45	18C
0005435839297	18092	46	18D
0005435839321	18092	47	18F
0005432537065	18092	48	19C
0005432664126	18092	49	19E
0005432664123	18092	50	19F
0005435472865	18092	51	20B
0005435839396	18092	52	20C
0005435839423	18092	53	20F
0005435472859	18092	54	20E
0005435839251	18092	55	21C
0005435839403	18092	56	21E
0005435839436	18092	57	21D
0005433285105	23025	1	1C
0005433285181	23025	2	1F
0005433285185	23025	3	3C
0005433285088	23025	4	3F
0005433285042	23025	5	3D
0005433285239	23025	6	4A
0005435103953	23025	7	4D
0005433285237	23025	8	4C
0005433285198	23025	9	4E
0005433285119	23025	10	5B
0005433284965	23025	11	5E
0005433285182	23025	12	6A
0005433285055	23025	13	6B
0005433285097	23025	14	7E
0005433285190	23025	15	8B
0005433285103	23025	16	8C
0005433285135	23025	17	9B
0005433285081	23025	18	10C
0005433285167	23025	19	11A
0005433285053	23025	20	12A
0005433285136	23025	21	12D
0005435103952	23025	22	13A
0005433285200	23025	23	13B
0005433285089	23025	24	13D
0005433285168	23025	25	14D
0005433285028	23025	26	14E
0005433285183	23025	27	15C
0005433285191	23025	28	15F
0005433285104	23025	29	16C
0005433285134	23025	30	17A
0005433284990	23025	31	17C
0005433285128	23025	32	17D
0005433285052	23025	33	19C
0005435103950	23025	34	19B
0005433285026	23025	35	20A
0005433285066	23025	36	20C
0005435103951	23025	37	20B
0005433284989	23025	38	22B
0005433285155	23025	39	23A
0005433285054	23025	40	23D
0005433285184	23025	41	23E
0005435103877	32095	1	1A
0005435103851	32095	2	1D
0005433285404	32095	3	2A
0005435103856	32095	4	2C
0005433285416	32095	5	2D
0005433285393	32095	6	3C
0005435103866	32095	7	3D
0005433285408	32095	8	4B
0005435103834	32095	9	4F
0005433285417	32095	10	5D
0005433285423	32095	11	7A
0005433285414	32095	12	7B
0005433285396	32095	13	9A
0005433285395	32095	14	9E
0005433285412	32095	15	9F
0005435103864	32095	16	10E
0005433285415	32095	17	11A
0005433285402	32095	18	11D
0005433285392	32095	19	12C
0005433285420	32095	20	12B
0005433285406	32095	21	13A
0005433285403	32095	22	12F
0005435103870	32095	23	13B
0005435103845	32095	24	14A
0005433285411	32095	25	13F
0005435103876	32095	26	14C
0005433285398	32095	27	14D
0005435103871	32095	28	14E
0005435103865	32095	29	16B
0005433285405	32095	30	16C
0005433285410	32095	31	16E
0005433285407	32095	32	17D
0005433285401	32095	33	17F
0005433285421	32095	34	18A
0005433285397	32095	35	18E
0005433285422	32095	36	19B
0005433285419	32095	37	20B
0005435103872	32095	38	20E
0005433285400	32095	39	21B
0005433285394	32095	40	21C
0005433285409	32095	41	22B
0005433285399	32095	42	22D
0005435103873	32095	43	22F
0005433285413	32095	44	22E
0005433285418	32095	45	23C
0005435103850	32095	46	23E
0005435213840	30615	1	1C
0005434067476	30615	2	1A
0005434066909	30615	3	1H
0005432527583	30615	4	1G
0005432535799	30615	5	1D
0005432527345	30615	6	1K
0005435725619	30615	7	2D
0005432537057	30615	8	2H
0005435213794	30615	9	2K
0005435213791	30615	10	3D
0005435213786	30615	11	3C
0005435213828	30615	12	3H
0005432527052	30615	13	3G
0005432527637	30615	14	4C
0005434067035	30615	15	4G
0005434067287	30615	16	4D
0005432527142	30615	17	5D
0005434067156	30615	18	5A
0005432527324	30615	19	5H
0005432527144	30615	20	5G
0005432527625	30615	21	11A
0005435213816	30615	22	11F
0005432527497	30615	23	11E
0005434067419	30615	24	11K
0005434067107	30615	25	11H
0005432527788	30615	26	12D
0005435213817	30615	27	12G
0005434067158	30615	28	12F
0005435213839	30615	29	13A
0005432527478	30615	30	12K
0005432527568	30615	31	13D
0005432526944	30615	32	13C
0005435630980	30615	33	13F
0005432527396	30615	34	13E
0005435213819	30615	35	13H
0005434067394	30615	36	13G
0005432527373	30615	37	14A
0005432428911	30615	38	13K
0005432527297	30615	39	14E
0005434067310	30615	40	14D
0005432527611	30615	41	14F
0005434067032	30615	42	14K
0005434067112	30615	43	14H
0005432211527	30615	44	14G
0005432527296	30615	45	15C
0005432527261	30615	46	15E
0005434067308	30615	47	15D
0005434066978	30615	48	15H
0005435213834	30615	49	15G
0005432527495	30615	50	15F
0005435213853	30615	51	16A
0005434067068	30615	52	15K
0005432533274	30615	53	16C
0005435725621	30615	54	16G
0005435213802	30615	55	16F
0005435213837	30615	56	16E
0005432537053	30615	57	16K
0005434067256	30615	58	16H
0005432527635	30615	59	17C
0005434067025	30615	60	17E
0005434067109	30615	61	17D
0005435213813	30615	62	17H
0005434066979	30615	63	18A
0005432527601	30615	64	18E
0005435213812	30615	65	18D
0005434067108	30615	66	18J
0005432526474	30615	67	19A
0005432526999	30615	68	19D
0005434066770	30615	69	19C
0005434066911	30615	70	19F
0005432526814	30615	71	19H
0005435213809	30615	72	19G
0005432527732	30615	73	19K
0005435213833	30615	74	19J
0005434067306	30615	75	20B
0005435213827	30615	76	20A
0005432527281	30615	77	20D
0005432527591	30615	78	20F
0005432535800	30615	79	20K
0005432527807	30615	80	20H
0005434067218	30615	81	21B
0005432526765	30615	82	21A
0005435213849	30615	83	21E
0005435213804	30615	84	21D
0005435213820	30615	85	21F
0005434067207	30615	86	21J
0005433656686	30615	87	21H
0005435213848	30615	88	22A
0005432526945	30615	89	21K
0005432159874	30615	90	22C
0005432527304	30615	91	22F
0005434066901	30615	92	22D
0005432527612	30615	93	22H
0005432527496	30615	94	22G
0005435213823	30615	95	22K
0005432527784	30615	96	22J
0005435725623	30615	97	23B
0005434066989	30615	98	23A
0005433656685	30615	99	23D
0005435213797	30615	100	23F
0005434067033	30615	101	23H
0005435213803	30615	102	23K
0005435725622	30615	103	24G
0005432428912	30615	104	24E
0005435213815	30615	105	25B
0005432527998	30615	106	25A
0005432527693	30615	107	25D
0005432211528	30615	108	25F
0005432211533	30615	109	25E
0005434067148	30615	110	25H
0005434067393	30615	111	25G
0005435213798	30615	112	26B
0005435213808	30615	113	26A
0005435213835	30615	114	26D
0005435213830	30615	115	26G
0005434067298	30615	116	26F
0005432527506	30615	117	26J
0005435213818	30615	118	27C
0005432211529	30615	119	27F
0005435213790	30615	120	27D
0005434067307	30615	121	27G
0005432159876	30615	122	27K
0005432527121	30615	123	27J
0005435213852	30615	124	28C
0005434067346	30615	125	28B
0005432527323	30615	126	28E
0005432526884	30615	127	28G
0005432527393	30615	128	28J
0005434067198	30615	129	28H
0005432527366	30615	130	29A
0005432526841	30615	131	29D
0005434066929	30615	132	29F
0005432159875	30615	133	29E
0005432527656	30615	134	29H
0005432527237	30615	135	30A
0005432535815	30615	136	29K
0005434067455	30615	137	29J
0005434067494	30615	138	30C
0005432527567	30615	139	30B
0005435213807	30615	140	30E
0005432527498	30615	141	30G
0005432526783	30615	142	30F
0005432528013	30615	143	30H
0005434067356	30615	144	31A
0005435213838	30615	145	31D
0005435213842	30615	146	31E
0005435213851	30615	147	31G
0005434067186	30615	148	32A
0005435213821	30615	149	31J
0005432527430	30615	150	32C
0005432527414	30615	151	32D
0005435213832	30615	152	32F
0005432527322	30615	153	32K
0005432527715	30615	154	32H
0005435213800	30615	155	33A
0005432527438	30615	156	33D
0005432533288	30615	157	33C
0005435213843	30615	158	33F
0005432533287	30615	159	33H
0005434067241	30615	160	33K
0005435213825	30615	161	34B
0005434067193	30615	162	34E
0005435213846	30615	163	34C
0005432527727	30615	164	34K
0005432211531	30615	165	34H
0005435213850	30615	166	35B
0005432535801	30615	167	35A
0005432527249	30615	168	35C
0005435213805	30615	169	35F
0005432527834	30615	170	35E
0005432527160	30615	171	35J
0005432527626	30615	172	35H
0005434066991	30615	173	35G
0005432526910	30615	174	36A
0005432527749	30615	175	35K
0005434067495	30615	176	36E
0005434067200	30615	177	36F
0005432527190	30615	178	36J
0005435213826	30615	179	36H
0005434067299	30615	180	37B
0005432526781	30615	181	37A
0005432527204	30615	182	36K
0005432527697	30615	183	37C
0005432526622	30615	184	37F
0005434067044	30615	185	37E
0005434067074	30615	186	37H
0005435213788	30615	187	37G
0005433656684	30615	188	38A
0005435213796	30615	189	37K
0005435213836	30615	190	38C
0005432527613	30615	191	38J
0005434067024	30615	192	39A
0005432526908	30615	193	38K
0005432159878	30615	194	39C
0005435213792	30615	195	39B
0005434067404	30615	196	39E
0005432211534	30615	197	39H
0005432527799	30615	198	39G
0005432527282	30615	199	40A
0005432527120	30615	200	39K
0005432526998	30615	201	40B
0005434067199	30615	202	40E
0005434067103	30615	203	40D
0005435213810	30615	204	40H
0005435213811	30615	205	40G
0005434066981	30615	206	40F
0005432211532	30615	207	40K
0005435213829	30615	208	40J
0005432535832	30615	209	41B
0005432527655	30615	210	41A
0005432535827	30615	211	41D
0005434067403	30615	212	41C
0005435213814	30615	213	41G
0005434067239	30615	214	41J
0005432526780	30615	215	41H
0005432527175	30615	216	41K
0005434067009	30615	217	42C
0005432211530	30615	218	42B
0005434067161	30615	219	42E
0005432527180	30615	220	42D
0005434067347	30615	221	42G
0005432526476	30615	222	42F
0005435725620	30615	223	42J
0005434067223	30615	224	42H
0005435213787	30615	225	43C
0005435213822	30615	226	43B
0005432527582	30615	227	43F
0005435213845	30615	228	43E
0005434067201	30615	229	43H
0005434067023	30615	230	43K
0005435213801	30615	231	43J
0005434067370	30615	232	44B
0005434067121	30615	233	44A
0005432527024	30615	234	44E
0005435630981	30615	235	44D
0005432527902	30615	236	44C
0005432159877	30615	237	44F
0005432527722	30615	238	45B
0005432527346	30615	239	45A
0005434067083	30615	240	44K
0005434066990	30615	241	45C
0005435213789	30615	242	45F
0005434067130	30615	243	45E
0005434066910	30615	244	45H
0005434067436	30615	245	46A
0005435213824	30615	246	45J
0005434067470	30615	247	46C
0005432526909	30615	248	46D
0005435213793	30615	249	46G
0005435213847	30615	250	46J
0005434067202	30615	251	46H
0005435213795	30615	252	46K
0005434067102	30615	253	47D
0005434067034	30615	254	47G
0005432527602	30615	255	47F
0005432527205	30615	256	47E
0005434067133	30615	257	47K
0005434067469	30615	258	47H
0005432526784	30615	259	48A
0005432527335	30615	260	48E
0005432527460	30615	261	48D
0005435213806	30615	262	48H
0005434067087	30615	263	48G
0005432527579	30615	264	49A
0005434067088	30615	265	49E
0005435213841	30615	266	49C
0005434067288	30615	267	49F
0005435213831	30615	268	49K
0005432527578	30615	269	50C
0005432527933	30615	270	50A
0005432527208	30615	271	50E
0005435213844	30615	272	50G
0005432535816	30615	273	50F
0005435213799	30615	274	50K
0005435630979	30615	275	50H
0005434067160	30615	276	51E
0005435725624	30615	277	51D
0005432526842	30615	278	51G
0005433368042	24839	1	1A
0005435652683	24839	2	1C
0005433368058	24839	3	1D
0005435652747	24839	4	1F
0005433368062	24839	5	2A
0005435652844	24839	6	2D
0005435652735	24839	7	3A
0005433368061	24839	8	3F
0005435652690	24839	9	4A
0005433368039	24839	10	4C
0005433368056	24839	11	4D
0005435652828	24839	12	4E
0005435652804	24839	13	4F
0005433368043	24839	14	5C
0005435652805	24839	15	5E
0005435652665	24839	16	5D
0005435652748	24839	17	5F
0005433368046	24839	18	6A
0005433368033	24839	19	6C
0005435652853	24839	20	6D
0005433368048	24839	21	6F
0005433368047	24839	22	7A
0005435652846	24839	23	7C
0005433368052	24839	24	7D
0005433368041	24839	25	7E
0005435652650	24839	26	7F
0005435652696	24839	27	8A
0005435652852	24839	28	8C
0005435652764	24839	29	8D
0005433368054	24839	30	8E
0005433368040	24839	31	8F
0005435652688	24839	32	9A
0005433368027	24839	33	9C
0005435652845	24839	34	9D
0005435652762	24839	35	9E
0005435652839	24839	36	10A
0005435652854	24839	37	10C
0005433368049	24839	38	10D
0005435652700	24839	39	10F
0005435652689	24839	40	11A
0005433368035	24839	41	11C
0005435652761	24839	42	11D
0005435652736	24839	43	11E
0005433368038	24839	44	11F
0005433368034	24839	45	12A
0005435652786	24839	46	12D
0005433368059	24839	47	12E
0005435652732	24839	48	12F
0005435652825	24839	49	13A
0005435652803	24839	50	13C
0005433368030	24839	51	13D
0005433368055	24839	52	13E
0005435652843	24839	53	13F
0005435652466	24839	54	14A
0005433368053	24839	55	14C
0005433368029	24839	56	14D
0005433368032	24839	57	14E
0005435652653	24839	58	14F
0005433368031	24839	59	15A
0005433368044	24839	60	15C
0005433368036	24839	61	15D
0005433368050	24839	62	15E
0005433368060	24839	63	15F
0005435652824	24839	64	16A
0005435652778	24839	65	16D
0005435652829	24839	66	16E
0005435652773	24839	67	16F
0005435652779	24839	68	17A
0005433368045	24839	69	17C
0005433368028	24839	70	17E
0005435652862	24839	71	17F
0005435652649	24839	72	18A
0005433368057	24839	73	18C
0005435652664	24839	74	18D
0005435652749	24839	75	18E
0005435652872	24839	76	18F
0005435652763	24839	77	19A
0005435652684	24839	78	19D
0005433368026	24839	79	19E
0005435652840	24839	80	19F
0005433368037	24839	81	20A
0005435652802	24839	82	20C
0005435652836	24839	83	20D
0005435652806	24839	84	20E
0005433368051	24839	85	20F
0005435949771	23308	1	1A
0005435949759	23308	2	1B
0005435949765	23308	3	3B
0005435949760	23308	4	18B
0005435949770	23308	5	18D
0005435949761	23308	6	18C
0005435949769	23308	7	19C
0005435949756	23308	8	19D
0005435949753	23308	9	20A
0005435949782	23308	10	20C
0005435949752	23308	11	22B
0005435949755	23308	12	23B
0005435801709	2054	1	1B
0005434979914	2054	2	1C
0005434979910	2054	3	1D
0005434979905	2054	4	2A
0005434979928	2054	5	2B
0005434979917	2054	6	2C
0005434979920	2054	7	2D
0005434979926	2054	8	3A
0005434979921	2054	9	3B
0005434979924	2054	10	4A
0005434979911	2054	11	4C
0005434979909	2054	12	4D
0005434979912	2054	13	5B
0005434979918	2054	14	5C
0005435801707	2054	15	6A
0005434979907	2054	16	6B
0005434979915	2054	17	6D
0005434979900	2054	18	7A
0005434979913	2054	19	7C
0005434979927	2054	20	7D
0005434979916	2054	21	18A
0005434979904	2054	22	18C
0005434979901	2054	23	18D
0005434979899	2054	24	19B
0005434979903	2054	25	19C
0005434979902	2054	26	20A
0005434979919	2054	27	20B
0005434979898	2054	28	20C
0005434979908	2054	29	20D
0005434979922	2054	30	21A
0005435801708	2054	31	21B
0005434979906	2054	32	21C
0005434979925	2054	33	22C
0005434979923	2054	34	23B
0005434979654	23536	1	1A
0005434979534	23536	2	1C
0005434979541	23536	3	1D
0005434979597	23536	4	2B
0005434979537	23536	5	2A
0005434979552	23536	6	2D
0005434979763	23536	7	3A
0005435801699	23536	8	3B
0005434979568	23536	9	3C
0005434979539	23536	10	3D
0005434979762	23536	11	4A
0005434979540	23536	12	4C
0005435801698	23536	13	4D
0005434979607	23536	14	5B
0005434979615	23536	15	5D
0005434979533	23536	16	6B
0005434979664	23536	17	6D
0005434979566	23536	18	7A
0005434979616	23536	19	7B
0005434979542	23536	20	7C
0005434979548	23536	21	7D
0005434979532	23536	22	18A
0005434979551	23536	23	18B
0005434979577	23536	24	18C
0005435801683	23536	25	18D
0005434979549	23536	26	19A
0005434979603	23536	27	19C
0005434979653	23536	28	19D
0005434979550	23536	29	20A
0005434979518	23536	30	20B
0005434979602	23536	31	20C
0005434979536	23536	32	20D
0005435801687	23536	33	21A
0005434979497	23536	34	21B
0005434979538	23536	35	21C
0005434979684	23536	36	21D
0005434979513	23536	37	22B
0005435801684	23536	38	22C
0005434979503	23536	39	22D
0005434979509	23536	40	23A
0005434979771	23536	41	23B
0005434952546	2598	1	1B
0005434952547	2598	2	6B
0005433256430	28253	1	3B
0005433256431	28253	2	4A
0005434952514	28253	3	6A
0005433111516	19744	1	5B
0005433111515	19744	2	6B
0005434137576	11948	1	1A
0005434137787	11948	2	1D
0005434137358	11948	3	1F
0005434137410	11948	4	2A
0005434137894	11948	5	2C
0005434137723	11948	6	2D
0005434137830	11948	7	2F
0005434137777	11948	8	3A
0005434137996	11948	9	3C
0005434137678	11948	10	3D
0005434137577	11948	11	3F
0005434137649	11948	12	4A
0005434137578	11948	13	4C
0005434137753	11948	14	4D
0005434137829	11948	15	4E
0005434137661	11948	16	5C
0005434137893	11948	17	5D
0005434137646	11948	18	5E
0005434137766	11948	19	5F
0005434137877	11948	20	6A
0005434137620	11948	21	6C
0005434137760	11948	22	6D
0005434137724	11948	23	6E
0005434137721	11948	24	6F
0005434137952	11948	25	7A
0005434137885	11948	26	7C
0005434137751	11948	27	7D
0005434138001	11948	28	7E
0005434137621	11948	29	7F
0005434137856	11948	30	8A
0005434137485	11948	31	8C
0005434137798	11948	32	8D
0005434137549	11948	33	8E
0005434137475	11948	34	8F
0005434137944	11948	35	9A
0005434137486	11948	36	9C
0005434137618	11948	37	9D
0005434137669	11948	38	9F
0005434137409	11948	39	10A
0005434137625	11948	40	10C
0005434137542	11948	41	10D
0005434137995	11948	42	10E
0005434137932	11948	43	10F
0005434137941	11948	44	11A
0005434137496	11948	45	11C
0005434137632	11948	46	11D
0005434137720	11948	47	11E
0005434137617	11948	48	11F
0005434137726	11948	49	12A
0005434137776	11948	50	12C
0005434137322	11948	51	12D
0005434137305	11948	52	12E
0005434137722	11948	53	12F
0005434137767	11948	54	13A
0005434137886	11948	55	13C
0005434137974	11948	56	13D
0005434137931	11948	57	13E
0005434137871	11948	58	13F
0005434138015	11948	59	14A
0005434137626	11948	60	14C
0005434137975	11948	61	14D
0005434137647	11948	62	14E
0005434137719	11948	63	14F
0005434137612	11948	64	15A
0005434137740	11948	65	15C
0005434137497	11948	66	15D
0005434137550	11948	67	15E
0005434137306	11948	68	15F
0005434137969	11948	69	16A
0005434137768	11948	70	16C
0005434138020	11948	71	16D
0005434137545	11948	72	16E
0005434137541	11948	73	16F
0005434137759	11948	74	17A
0005434138014	11948	75	17C
0005434138068	11948	76	17D
0005434137662	11948	77	17E
0005434137981	11948	78	17F
0005434137961	11948	79	18A
0005434137624	11948	80	18D
0005434137663	11948	81	18E
0005434137631	11948	82	18F
0005434137713	11948	83	19A
0005434137619	11948	84	19C
0005434137929	11948	85	19D
0005434137866	11948	86	19E
0005434137321	11948	87	19F
0005434137630	11948	88	20A
0005434137616	11948	89	20C
0005434137769	11948	90	20D
0005434137307	11948	91	20E
0005434137848	11948	92	20F
0005434138464	28715	1	1A
0005434138451	28715	2	1C
0005434138418	28715	3	1D
0005434138447	28715	4	1F
0005434138427	28715	5	2A
0005434138435	28715	6	2C
0005434138396	28715	7	2D
0005434138403	28715	8	2F
0005434138414	28715	9	3A
0005434138459	28715	10	3C
0005434138462	28715	11	3D
0005434138389	28715	12	3F
0005434138394	28715	13	4C
0005434138405	28715	14	4D
0005434138438	28715	15	4E
0005434138416	28715	16	4F
0005434138450	28715	17	5A
0005434138423	28715	18	5D
0005434138407	28715	19	5E
0005434138390	28715	20	5F
0005434138402	28715	21	6A
0005434138452	28715	22	6C
0005434138463	28715	23	6E
0005434138432	28715	24	6F
0005434138466	28715	25	7A
0005434138404	28715	26	7C
0005434138443	28715	27	7D
0005434138453	28715	28	7E
0005434138440	28715	29	7F
0005434138454	28715	30	8A
0005434138412	28715	31	8C
0005434138400	28715	32	8D
0005434138391	28715	33	8E
0005434138397	28715	34	8F
0005434138417	28715	35	9A
0005434138421	28715	36	9C
0005434138446	28715	37	9D
0005434138456	28715	38	9E
0005434138467	28715	39	9F
0005434138426	28715	40	10A
0005434138409	28715	41	10C
0005434138428	28715	42	10D
0005434138393	28715	43	10E
0005434138431	28715	44	11A
0005434138420	28715	45	11C
0005434138430	28715	46	11D
0005434138392	28715	47	11E
0005434138419	28715	48	11F
0005434138436	28715	49	12A
0005434138468	28715	50	12C
0005434138449	28715	51	12D
0005434138413	28715	52	12E
0005434138434	28715	53	12F
0005434138399	28715	54	13A
0005434138444	28715	55	13C
0005434138398	28715	56	13D
0005434138415	28715	57	13E
0005434138455	28715	58	14A
0005434138424	28715	59	14C
0005434138460	28715	60	14E
0005434138442	28715	61	15A
0005434138411	28715	62	15D
0005434138410	28715	63	15F
0005434138425	28715	64	16A
0005434138469	28715	65	16C
0005434138465	28715	66	16E
0005434138408	28715	67	17A
0005434138458	28715	68	17C
0005434138429	28715	69	17D
0005434138445	28715	70	17F
0005434138439	28715	71	18A
0005434138422	28715	72	18D
0005434138406	28715	73	18E
0005434138437	28715	74	19A
0005434138433	28715	75	19C
0005434138461	28715	76	19D
0005434138457	28715	77	19E
0005434138395	28715	78	20C
0005434138401	28715	79	20D
0005434138441	28715	80	20E
0005434138448	28715	81	20F
0005434516070	19094	1	1D
0005434513559	19094	2	2A
0005434513575	19094	3	2B
0005434516061	19094	4	3A
0005434516063	19094	5	3C
0005434190412	19094	6	4A
0005434516068	19094	7	4C
0005434190413	19094	8	5C
0005434516069	19094	9	5D
0005434516067	19094	10	6A
0005434190414	19094	11	7C
0005434516066	19094	12	18B
0005434516071	19094	13	18C
0005434516065	19094	14	19B
0005434513565	19094	15	19C
0005434513566	19094	16	20A
0005434190410	19094	17	20B
0005434513560	19094	18	21A
0005434190409	19094	19	21C
0005434190411	19094	20	22A
0005433538901	6813	1	1B
0005433534506	6813	2	1C
0005433538906	6813	3	1D
0005433538902	6813	4	2B
0005433538908	6813	5	2D
0005433538903	6813	6	3A
0005433534507	6813	7	5C
0005433538907	6813	8	7A
0005435259734	6813	9	7C
0005433538905	6813	10	19A
0005435259741	6813	11	20D
0005433538904	6813	12	21B
0005433538909	6813	13	23B
0005433538827	25039	1	1A
0005435259775	25039	2	1D
0005433538862	25039	3	2A
0005433538841	25039	4	2B
0005433538773	25039	5	2D
0005435259773	25039	6	3B
0005433538830	25039	7	3C
0005433538858	25039	8	3D
0005435259774	25039	9	4D
0005433538856	25039	10	4C
0005433538832	25039	11	5D
0005433538831	25039	12	6A
0005433538861	25039	13	6C
0005433538837	25039	14	18A
0005433538829	25039	15	18B
0005433538828	25039	16	19C
0005433538833	25039	17	20A
0005433538855	25039	18	20B
0005433538813	25039	19	20C
0005433538799	25039	20	21A
0005435259776	25039	21	21D
0005433534483	25039	22	22B
0005433534482	25039	23	22C
0005433538772	25039	24	22D
0005433538826	25039	25	23A
0005433538800	25039	26	23B
0005433511985	795	1	2C
0005432922504	795	2	2D
0005433511986	795	3	6B
0005433511990	795	4	6D
0005433511989	795	5	7B
0005432922505	795	6	18B
0005433511984	795	7	19D
0005433511988	795	8	22C
0005432922513	795	9	22D
0005433511987	795	10	23B
0005433511905	16139	1	1D
0005432922542	16139	2	2C
0005433511895	16139	3	2D
0005433511926	16139	4	3C
0005433511896	16139	5	3D
0005433511911	16139	6	5A
0005433511948	16139	7	7B
0005433511945	16139	8	7D
0005432922540	16139	9	18B
0005433511942	16139	10	18D
0005433511947	16139	11	19B
0005432922543	16139	12	20D
0005433511943	16139	13	21B
0005433511904	16139	14	21D
0005432922541	16139	15	23B
0005433475722	4045	1	2A
0005435852567	4045	2	3A
0005433475726	4045	3	4C
0005435852572	4045	4	4D
0005433475724	4045	5	5B
0005435852565	4045	6	5C
0005433475723	4045	7	6A
0005433475725	4045	8	6B
0005435852559	4045	9	6C
0005433475720	4045	10	6D
0005435852560	4045	11	7B
0005433475719	4045	12	7C
0005435852573	4045	13	7D
0005433475721	4045	14	19B
0005435852570	4045	15	19C
0005435852562	4045	16	20A
0005435852569	4045	17	20B
0005435852561	4045	18	22D
0005433475727	4045	19	23B
0005435697457	3662	1	1B
0005435697465	3662	2	2A
0005435697464	3662	3	2B
0005435697446	3662	4	2C
0005435935048	3662	5	2D
0005434950547	3662	6	3A
0005435697448	3662	7	3B
0005434950548	3662	8	3C
0005435697452	3662	9	4B
0005435697455	3662	10	4D
0005435697450	3662	11	5A
0005435697466	3662	12	5B
0005435697447	3662	13	5C
0005435697449	3662	14	6B
0005435697470	3662	15	6C
0005435697467	3662	16	6D
0005434950549	3662	17	7A
0005435697473	3662	18	7B
0005435697453	3662	19	7D
0005435697454	3662	20	18C
0005435697451	3662	21	18D
0005435697461	3662	22	19A
0005435697460	3662	23	19B
0005435916157	3662	24	19C
0005435935035	3662	25	19D
0005435697458	3662	26	20A
0005435697471	3662	27	20B
0005435697463	3662	28	20C
0005435697462	3662	29	20D
0005435697456	3662	30	21A
0005434950550	3662	31	21B
0005435697459	3662	32	22A
0005435697469	3662	33	22B
0005435697472	3662	34	22C
0005435916155	3662	35	22D
0005435697468	3662	36	23A
0005435697079	16300	1	1B
0005435697102	16300	2	1A
0005434950512	16300	3	1C
0005435697052	16300	4	1D
0005434950528	16300	5	2A
0005435697169	16300	6	2B
0005435697172	16300	7	2D
0005434950509	16300	8	3A
0005435916179	16300	9	3C
0005435697243	16300	10	3D
0005435697147	16300	11	4A
0005435697053	16300	12	4B
0005435697144	16300	13	4C
0005435697080	16300	14	4D
0005434950513	16300	15	5A
0005435697170	16300	16	5B
0005435697148	16300	17	5C
0005435697117	16300	18	5D
0005434950517	16300	19	6A
0005435697242	16300	20	6B
0005435697238	16300	21	6C
0005435697251	16300	22	6D
0005435697277	16300	23	7A
0005434950524	16300	24	7B
0005435697078	16300	25	7C
0005435697127	16300	26	7D
0005434950516	16300	27	18A
0005435697317	16300	28	18B
0005435916178	16300	29	18C
0005435697228	16300	30	18D
0005435697260	16300	31	19A
0005435697164	16300	32	19B
0005435697244	16300	33	19C
0005435697227	16300	34	19D
0005435697159	16300	35	20A
0005435697153	16300	36	20B
0005435916180	16300	37	20C
0005435697146	16300	38	20D
0005435935058	16300	39	21A
0005435697308	16300	40	21B
0005435697113	16300	41	21C
0005434950529	16300	42	21D
0005435697218	16300	43	22B
0005435697278	16300	44	22C
0005435697197	16300	45	23A
0005435697261	16300	46	23B
0005434606841	3965	1	1A
0005433519476	3965	2	1B
0005432609751	3965	3	1C
0005432609747	3965	4	2B
0005433519479	3965	5	2D
0005434604912	3965	6	3A
0005433519480	3965	7	3B
0005435853609	3965	8	4A
0005434604914	3965	9	4C
0005434606842	3965	10	5A
0005433519478	3965	11	5C
0005432607585	3965	12	5D
0005434604910	3965	13	6A
0005435853610	3965	14	7A
0005432609749	3965	15	7B
0005432609748	3965	16	7C
0005434604909	3965	17	7D
0005435853611	3965	18	18A
0005434606843	3965	19	18C
0005432607584	3965	20	20B
0005432609750	3965	21	20D
0005435853599	3965	22	21A
0005434606844	3965	23	21B
0005434604911	3965	24	21D
0005434606839	3965	25	22A
0005434604913	3965	26	22C
0005433519477	3965	27	22D
0005434606840	3965	28	23A
0005432607583	3965	29	23B
0005433519435	22060	1	1B
0005435853620	22060	2	3D
0005434606802	22060	3	7A
0005433519439	22060	4	7B
0005434606806	22060	5	7C
0005434606800	22060	6	20C
0005433519436	22060	7	20D
0005434606801	22060	8	22C
0005434603020	22060	9	22D
0005433348991	726	1	1A
0005433348981	726	2	1B
0005433348992	726	3	2A
0005433348969	726	4	2B
0005433348967	726	5	3B
0005433348974	726	6	4A
0005433348952	726	7	4B
0005433348980	726	8	5A
0005433348968	726	9	5B
0005435628736	726	10	6B
0005433349016	15921	1	1A
0005433349015	15921	2	2B
0005433349012	15921	3	3A
0005433349013	15921	4	4A
0005435628707	15921	5	4B
0005433349014	15921	6	5B
0005435628716	15921	7	6A
0005433159307	17202	1	1A
0005433158127	17202	2	1B
0005434445254	17202	3	2B
0005433159294	17202	4	3A
0005433159304	17202	5	3B
0005433159295	17202	6	4A
0005434445255	17202	7	4B
0005433158117	17202	8	5A
0005433158126	17202	9	6A
0005433159293	17202	10	6B
0005433159322	17567	1	3A
0005433159323	17567	2	5B
0005435132926	7913	1	1B
0005435132927	7913	2	2A
0005435132922	7913	3	4B
0005435132929	7913	4	4D
0005435383129	7913	5	5B
0005435132928	7913	6	6A
0005435132923	7913	7	7A
0005435132930	7913	8	7D
0005435132925	7913	9	19B
0005435132931	7913	10	20B
0005435132924	7913	11	21A
0005435383140	7913	12	22B
0005435383134	7913	13	23A
0005435383133	7913	14	23B
0005435132837	33078	1	1A
0005435383173	33078	2	1B
0005435383171	33078	3	1C
0005435383175	33078	4	2B
0005435132825	33078	5	2C
0005435132794	33078	6	3A
0005435383170	33078	7	5C
0005435132836	33078	8	7A
0005435383174	33078	9	7D
0005435132850	33078	10	18D
0005435132865	33078	11	19A
0005435132851	33078	12	21B
0005435132866	33078	13	22A
0005435383172	33078	14	22D
0005435160346	7509	1	1B
0005435390200	7509	2	2A
0005435390180	7509	3	2B
0005435390193	7509	4	3C
0005435390214	7509	5	4D
0005435390222	7509	6	5C
0005435160347	7509	7	6D
0005435160345	7509	8	7C
0005435160348	7509	9	18A
0005435160352	7509	10	18C
0005435160354	7509	11	19C
0005435160353	7509	12	20A
0005435160351	7509	13	20C
0005435160349	7509	14	20D
0005435390181	7509	15	21B
0005435160350	7509	16	21D
0005435160344	7509	17	22B
0005435390221	7509	18	23B
0005435390270	29562	1	1A
0005435160255	29562	2	1B
0005435160282	29562	3	1D
0005435390273	29562	4	2A
0005435160279	29562	5	2C
0005435160272	29562	6	3D
0005435390269	29562	7	4A
0005435390272	29562	8	5A
0005435160247	29562	9	6A
0005435160248	29562	10	6C
0005435160249	29562	11	6D
0005435390267	29562	12	7C
0005435160217	29562	13	18A
0005435160232	29562	14	18B
0005435160219	29562	15	18C
0005435390274	29562	16	18D
0005435160281	29562	17	19B
0005435390271	29562	18	19D
0005435390268	29562	19	20C
0005435160227	29562	20	22A
0005435390266	29562	21	22C
0005435160271	29562	22	22D
0005435160280	29562	23	23A
0005432394086	18425	1	1A
0005432394074	18425	2	1B
0005432394087	18425	3	2A
0005432398183	18425	4	2B
0005432394073	18425	5	3B
0005432398179	18425	6	3A
0005432394084	18425	7	4A
0005432394094	18425	8	4B
0005432394095	18425	9	5B
0005432394085	18425	10	5A
0005432398182	18425	11	6A
0005432394096	18425	12	6B
0005435178481	27154	1	1A
0005432398208	27154	2	2A
0005432398210	27154	3	2B
0005432400136	27154	4	3A
0005432400139	27154	5	3B
0005432400137	27154	6	4A
0005432398207	27154	7	4B
0005432398209	27154	8	5A
0005432400138	27154	9	5B
0005432398206	27154	10	6A
0005432400135	27154	11	6B
0005434504334	6535	1	1C
0005434504325	6535	2	1D
0005435103963	6535	3	2D
0005434504306	6535	4	3C
0005434504340	6535	5	3D
0005434504316	6535	6	3F
0005434504321	6535	7	4C
0005434504333	6535	8	5F
0005434504311	6535	9	6F
0005434504318	6535	10	7C
0005435103962	6535	11	8C
0005434504302	6535	12	8F
0005434504315	6535	13	9A
0005434504341	6535	14	9E
0005434504336	6535	15	10C
0005434504314	6535	16	10E
0005434504323	6535	17	11A
0005434504339	6535	18	11D
0005434504322	6535	19	12A
0005434504307	6535	20	12C
0005434504313	6535	21	12D
0005434504320	6535	22	12E
0005434504308	6535	23	12F
0005434504330	6535	24	13A
0005434504329	6535	25	13C
0005434504331	6535	26	13E
0005434504304	6535	27	13F
0005434504310	6535	28	14C
0005435103966	6535	29	14D
0005434504335	6535	30	14E
0005434504326	6535	31	15A
0005434504324	6535	32	15C
0005435103964	6535	33	16A
0005434504301	6535	34	16D
0005434504328	6535	35	16E
0005434504309	6535	36	17C
0005434504327	6535	37	17D
0005434504319	6535	38	17F
0005434504338	6535	39	18E
0005435103967	6535	40	19C
0005434504317	6535	41	19D
0005434504332	6535	42	19E
0005434504303	6535	43	19F
0005434504337	6535	44	20A
0005435103965	6535	45	20D
0005434504312	6535	46	20E
0005434504305	6535	47	20F
0005435103877	22637	1	1A
0005434504018	22637	2	1F
0005435103845	22637	3	2A
0005434503875	22637	4	2D
0005434503969	22637	5	2F
0005434503735	22637	6	3A
0005434504010	22637	7	3C
0005434503903	22637	8	3D
0005434503937	22637	9	4C
0005434503918	22637	10	5C
0005435103864	22637	11	5E
0005435103871	22637	12	5F
0005435103865	22637	13	6C
0005434503935	22637	14	6D
0005434503787	22637	15	6F
0005434503828	22637	16	7A
0005434503998	22637	17	7C
0005435103870	22637	18	7D
0005434503829	22637	19	7E
0005434503668	22637	20	7F
0005434503957	22637	21	8A
0005434504007	22637	22	8D
0005435103866	22637	23	8E
0005435103856	22637	24	9C
0005434503874	22637	25	9F
0005434503706	22637	26	10C
0005434503970	22637	27	10D
0005435103873	22637	28	10E
0005434503905	22637	29	11A
0005434503964	22637	30	11C
0005435103872	22637	31	11D
0005435103834	22637	32	11E
0005434503761	22637	33	12A
0005434504009	22637	34	12C
0005434503916	22637	35	12D
0005434503926	22637	36	12F
0005434503955	22637	37	13D
0005434503723	22637	38	13E
0005434503917	22637	39	14C
0005435103876	22637	40	14E
0005434503881	22637	41	15C
0005435103850	22637	42	15D
0005434503788	22637	43	15E
0005434504054	22637	44	16A
0005434503927	22637	45	16D
0005434503904	22637	46	16E
0005434504062	22637	47	16F
0005434503958	22637	48	17C
0005435103851	22637	49	17D
0005434503931	22637	50	18A
0005434503793	22637	51	18C
0005434503734	22637	52	18D
0005434503940	22637	53	18F
0005434503786	22637	54	19A
0005434503934	22637	55	19C
0005434503852	22637	56	19D
0005434503906	22637	57	19F
0005434503777	22637	58	20C
0005434503743	22637	59	20D
0005434503742	22637	60	20E
0005434503965	22637	61	20F
0005433367753	1697	1	1A
0005435653237	1697	2	1C
0005433367659	1697	3	1D
0005435653261	1697	4	2A
0005433367692	1697	5	2C
0005433367776	1697	6	3A
0005435653240	1697	7	3C
0005433367505	1697	8	3F
0005433367604	1697	9	4C
0005433367818	1697	10	4D
0005433367673	1697	11	4E
0005433367718	1697	12	4F
0005435653252	1697	13	5C
0005433367734	1697	14	5D
0005433367770	1697	15	5E
0005433367856	1697	16	5F
0005435653245	1697	17	6A
0005433367769	1697	18	6D
0005435653256	1697	19	6F
0005433367766	1697	20	7A
0005433367855	1697	21	7C
0005435653259	1697	22	7D
0005433367817	1697	23	7E
0005435653253	1697	24	7F
0005435653242	1697	25	8A
0005433367672	1697	26	8C
0005433367724	1697	27	8D
0005435653249	1697	28	8E
0005435653247	1697	29	8F
0005435653248	1697	30	9C
0005433367748	1697	31	9D
0005435653243	1697	32	9F
0005433367679	1697	33	10C
0005433367750	1697	34	10D
0005435653250	1697	35	10E
0005433367712	1697	36	10F
0005435653254	1697	37	11C
0005433367749	1697	38	11D
0005433367694	1697	39	11E
0005433367775	1697	40	11F
0005435653260	1697	41	12C
0005433367732	1697	42	12D
0005433367808	1697	43	12E
0005433367807	1697	44	12F
0005433367790	1697	45	13A
0005435653255	1697	46	13C
0005435653241	1697	47	13D
0005435653239	1697	48	13E
0005433367683	1697	49	13F
0005433367703	1697	50	14A
0005435653238	1697	51	14C
0005435653258	1697	52	14F
0005433367758	1697	53	14E
0005433367574	1697	54	15A
0005433367789	1697	55	15D
0005433367729	1697	56	15E
0005433367693	1697	57	16A
0005433367711	1697	58	16C
0005433367798	1697	59	16D
0005433367717	1697	60	16E
0005433367627	1697	61	16F
0005433367733	1697	62	17C
0005433367751	1697	63	17F
0005433367731	1697	64	18A
0005433367853	1697	65	18D
0005433367852	1697	66	18F
0005433367691	1697	67	19A
0005433367682	1697	68	19C
0005435653246	1697	69	19D
0005433367765	1697	70	19E
0005433367605	1697	71	19F
0005435653244	1697	72	20A
0005433367506	1697	73	20C
0005435653257	1697	74	20D
0005435653251	1697	75	20E
0005433367656	1697	76	20F
0005435652665	21717	1	1A
0005435652839	21717	2	1C
0005435652749	21717	3	1D
0005435652763	21717	4	1F
0005435652779	21717	5	2A
0005433368035	21717	6	2C
0005435652764	21717	7	2D
0005435652664	21717	8	2F
0005435652840	21717	9	3A
0005435652852	21717	10	3C
0005433368037	21717	11	3D
0005435652688	21717	12	3F
0005433368049	21717	13	4A
0005433368062	21717	14	4D
0005433368059	21717	15	4E
0005433368054	21717	16	4F
0005433368043	21717	17	5A
0005435652825	21717	18	5C
0005433368042	21717	19	5D
0005435652650	21717	20	5E
0005433368050	21717	21	5F
0005433368032	21717	22	6A
0005435652732	21717	23	6C
0005435652836	21717	24	6D
0005435652735	21717	25	6E
0005435652843	21717	26	6F
0005433368046	21717	27	7A
0005433368029	21717	28	7D
0005433368061	21717	29	7E
0005435652802	21717	30	7F
0005433368030	21717	31	8A
0005433368036	21717	32	8C
0005435652844	21717	33	9A
0005433368056	21717	34	9C
0005433368047	21717	35	9D
0005435652778	21717	36	9F
0005435652829	21717	37	10A
0005433368028	21717	38	10C
0005433368034	21717	39	10D
0005435652853	21717	40	10E
0005435652862	21717	41	10F
0005435652806	21717	42	11A
0005435652824	21717	43	11C
0005435652854	21717	44	11D
0005435652700	21717	45	11E
0005435652466	21717	46	11F
0005435652683	21717	47	12C
0005433368031	21717	48	12D
0005433368052	21717	49	12E
0005435652761	21717	50	12F
0005435652762	21717	51	13A
0005435652653	21717	52	13C
0005435652845	21717	53	13D
0005433368053	21717	54	13E
0005433368033	21717	55	13F
0005433368055	21717	56	14A
0005435652828	21717	57	14C
0005433368051	21717	58	14D
0005433368048	21717	59	14E
0005433368041	21717	60	14F
0005433368040	21717	61	15A
0005433368027	21717	62	15C
0005435652747	21717	63	15D
0005435652805	21717	64	15E
0005433368039	21717	65	15F
0005435652684	21717	66	16A
0005433368057	21717	67	16C
0005433368060	21717	68	16D
0005433368038	21717	69	16F
0005435652748	21717	70	17C
0005433368026	21717	71	17D
0005435652689	21717	72	17F
0005433368058	21717	73	18A
0005435652690	21717	74	18C
0005435652872	21717	75	18D
0005435652846	21717	76	18F
0005435652786	21717	77	19A
0005433368044	21717	78	19C
0005433368045	21717	79	19D
0005435652649	21717	80	19E
0005435652803	21717	81	19F
0005435652696	21717	82	20A
0005435652804	21717	83	20C
0005435652736	21717	84	20D
0005435652773	21717	85	20F
0005435627117	23771	1	1B
0005435627116	23771	2	2B
0005433986173	4146	1	1A
0005433986162	4146	2	1C
0005433986172	4146	3	2A
0005433986143	4146	4	2F
0005433986166	4146	5	3D
0005433986148	4146	6	4A
0005433986146	4146	7	4C
0005433986160	4146	8	4D
0005433986156	4146	9	4F
0005433986149	4146	10	6A
0005433986134	4146	11	6C
0005433986168	4146	12	6D
0005433986158	4146	13	6E
0005433986155	4146	14	7D
0005433986153	4146	15	8A
0005433986141	4146	16	8D
0005433986165	4146	17	8E
0005433986131	4146	18	8F
0005433986150	4146	19	10D
0005433986164	4146	20	10F
0005433986138	4146	21	11A
0005433986139	4146	22	11D
0005433986144	4146	23	12A
0005433986161	4146	24	12C
0005433986159	4146	25	13C
0005433986145	4146	26	13D
0005433986175	4146	27	13F
0005433986132	4146	28	14A
0005433986135	4146	29	14C
0005433986133	4146	30	14D
0005433986170	4146	31	15C
0005433986167	4146	32	15F
0005435788781	4146	33	16A
0005433986152	4146	34	16D
0005433986142	4146	35	16E
0005433986130	4146	36	17A
0005433986154	4146	37	17C
0005433986163	4146	38	17D
0005433986151	4146	39	17E
0005433986174	4146	40	17F
0005433986171	4146	41	19A
0005433986137	4146	42	19C
0005433986169	4146	43	19F
0005433986157	4146	44	20A
0005433986147	4146	45	20C
0005433986140	4146	46	20D
0005435788782	4146	47	20E
0005433986136	4146	48	20F
0005433985549	25649	1	1F
0005433985711	25649	2	2A
0005433985619	25649	3	2C
0005433985727	25649	4	2D
0005433985789	25649	5	3A
0005433985642	25649	6	3D
0005433985644	25649	7	3F
0005433985584	25649	8	4E
0005433985630	25649	9	4F
0005433985721	25649	10	5A
0005433985710	25649	11	5C
0005433985647	25649	12	5D
0005433985657	25649	13	5E
0005433985636	25649	14	5F
0005433985790	25649	15	6E
0005433985645	25649	16	6F
0005433985665	25649	17	7A
0005433985786	25649	18	7D
0005433985801	25649	19	7E
0005433985751	25649	20	8C
0005433985656	25649	21	8E
0005433985658	25649	22	9C
0005433985699	25649	23	9E
0005433985787	25649	24	10D
0005433985705	25649	25	10E
0005433985666	25649	26	10F
0005433985720	25649	27	11C
0005433985649	25649	28	11E
0005433985698	25649	29	12A
0005433985620	25649	30	13A
0005433985580	25649	31	13C
0005433985697	25649	32	13E
0005433985812	25649	33	13F
0005433985740	25649	34	14D
0005433985631	25649	35	14F
0005433985550	25649	36	15D
0005433985690	25649	37	16A
0005433985771	25649	38	16C
0005433985650	25649	39	16F
0005433985623	25649	40	17F
0005433985746	25649	41	18A
0005435788768	25649	42	18D
0005433985728	25649	43	19C
0005433985646	25649	44	19E
0005433985726	25649	45	20A
0005433985741	25649	46	20D
0005433985551	25649	47	20E
0005433461585	20247	1	1H
0005433460436	20247	2	2H
0005433461591	20247	3	3G
0005433461590	20247	4	4G
0005433460438	20247	5	9A
0005433461596	20247	6	9H
0005433460440	20247	7	11D
0005433460443	20247	8	16D
0005433460442	20247	9	16F
0005433461581	20247	10	17B
0005433460430	20247	11	19E
0005433460429	20247	12	20F
0005433461589	20247	13	21H
0005433460441	20247	14	22B
0005433460431	20247	15	22A
0005433460434	20247	16	22H
0005433461593	20247	17	23A
0005433461584	20247	18	23H
0005433461583	20247	19	24D
0005433461594	20247	20	24E
0005433460432	20247	21	24F
0005433460435	20247	22	28D
0005433460433	20247	23	28G
0005433461595	20247	24	29D
0005433461582	20247	25	30A
0005433461586	20247	26	30B
0005433460437	20247	27	31A
0005433460439	20247	28	35A
0005433461592	20247	29	35D
0005433460444	20247	30	37D
0005433461588	20247	31	37A
0005433461587	20247	32	37G
0005435719568	21234	1	5D
0005435719567	21234	2	22B
0005433168384	21333	1	2B
0005434509135	21333	2	2C
0005434509097	21333	3	4D
0005433168390	21333	4	5A
0005434509110	21333	5	5D
0005433168387	21333	6	6D
0005434509109	21333	7	7A
0005434509093	21333	8	7B
0005433168388	21333	9	7D
0005433168385	21333	10	18A
0005433168389	21333	11	19B
0005433168392	21333	12	19C
0005433168391	21333	13	20A
0005434509087	21333	14	21D
0005433168386	21333	15	22C
0005432659693	17834	1	1A
0005432661900	17834	2	1D
0005432657441	17834	3	2A
0005432665263	17834	4	2D
0005432657442	17834	5	3C
0005432666387	17834	6	4D
0005432666379	17834	7	4F
0005432661911	17834	8	5A
0005434151718	17834	9	5D
0005432869554	17834	10	5E
0005432655463	17834	11	6A
0005432655438	17834	12	6C
0005432655478	17834	13	6E
0005432667448	17834	14	6F
0005432665264	17834	15	7A
0005434151717	17834	16	7C
0005432869559	17834	17	7D
0005432667446	17834	18	7E
0005432667445	17834	19	7F
0005432655437	17834	20	8D
0005432666366	17834	21	8C
0005432659698	17834	22	8E
0005432869555	17834	23	8F
0005432666378	17834	24	9E
0005432655476	17834	25	10A
0005432655457	17834	26	10D
0005432664125	17834	27	10E
0005432666377	17834	28	10F
0005432869557	17834	29	11A
0005432869558	17834	30	11C
0005432657428	17834	31	11D
0005432655477	17834	32	11F
0005432657426	17834	33	12A
0005432667449	17834	34	13A
0005432659697	17834	35	13E
0005432655442	17834	36	13F
0005432659692	17834	37	14F
0005432660806	17834	38	15A
0005432655506	17834	39	15F
0005432655496	17834	40	16C
0005432660802	17834	41	16D
0005432655489	17834	42	16E
0005432655450	17834	43	16F
0005434151720	17834	44	17A
0005432659694	17834	45	17D
0005432869556	17834	46	17F
0005432655460	17834	47	18A
0005432655475	17834	48	18F
0005432658572	17834	49	19D
0005432655422	17834	50	19E
0005432667440	17834	51	19F
0005432657427	17834	52	20C
0005432869553	17834	53	20E
0005434151719	17834	54	20F
0005432869488	26284	1	1A
0005432658598	26284	2	1C
0005432667460	26284	3	1F
0005432655564	26284	4	2A
0005432869485	26284	5	3C
0005432667459	26284	6	3D
0005432655559	26284	7	4D
0005432659713	26284	8	4E
0005432655562	26284	9	5A
0005432655565	26284	10	5C
0005432869482	26284	11	5F
0005432655561	26284	12	6D
0005432666395	26284	13	6F
0005432655568	26284	14	7A
0005432869493	26284	15	7C
0005432659711	26284	16	8F
0005432659714	26284	17	9F
0005432666394	26284	18	10A
0005432660824	26284	19	10D
0005432657458	26284	20	10E
0005432658597	26284	21	11A
0005432667461	26284	22	11D
0005432655569	26284	23	11E
0005432869484	26284	24	12A
0005432657459	26284	25	12C
0005432869486	26284	26	12D
0005432660823	26284	27	12E
0005432655567	26284	28	13A
0005432659712	26284	29	13D
0005432869469	26284	30	13F
0005432665281	26284	31	14C
0005432665280	26284	32	14E
0005432655566	26284	33	15C
0005434151693	26284	34	16A
0005432655570	26284	35	16C
0005434151679	26284	36	16D
0005432655560	26284	37	16F
0005432657457	26284	38	18C
0005432869470	26284	39	18D
0005432869475	26284	40	18F
0005432658596	26284	41	19E
0005432655563	26284	42	19F
0005432655558	26284	43	20C
0005432328902	3119	1	1A
0005432905097	3119	2	1C
0005432328886	3119	3	1D
0005432328898	3119	4	1F
0005432328893	3119	5	2A
0005432328897	3119	6	2C
0005432328916	3119	7	2F
0005433438911	3119	8	3A
0005432328892	3119	9	3D
0005432328922	3119	10	4C
0005432905098	3119	11	4D
0005432328877	3119	12	4E
0005432287213	3119	13	4F
0005432328907	3119	14	5A
0005433438908	3119	15	5C
0005433438905	3119	16	5D
0005432328891	3119	17	5E
0005433438906	3119	18	5F
0005432328882	3119	19	6A
0005432328889	3119	20	6C
0005432328923	3119	21	6E
0005432287212	3119	22	7C
0005432905129	3119	23	7D
0005432328900	3119	24	7F
0005433438903	3119	25	8A
0005432328925	3119	26	9A
0005432287211	3119	27	9D
0005432905128	3119	28	9E
0005432328905	3119	29	10A
0005433438904	3119	30	10D
0005432328906	3119	31	10E
0005432328919	3119	32	11C
0005432328920	3119	33	11D
0005432328880	3119	34	11E
0005432328924	3119	35	11F
0005432328909	3119	36	12D
0005432328917	3119	37	12C
0005432328914	3119	38	12E
0005432328883	3119	39	12F
0005432328921	3119	40	13C
0005432905084	3119	41	13A
0005432328884	3119	42	13D
0005432328881	3119	43	13F
0005432328918	3119	44	14C
0005432328887	3119	45	14D
0005432328904	3119	46	14E
0005432328915	3119	47	14F
0005432328896	3119	48	15A
0005432328901	3119	49	15C
0005432328903	3119	50	15E
0005433438907	3119	51	16C
0005432328910	3119	52	16E
0005432328913	3119	53	16D
0005432328911	3119	54	16F
0005432328890	3119	55	17A
0005432287210	3119	56	17F
0005432328912	3119	57	18C
0005432328895	3119	58	18D
0005432905085	3119	59	18E
0005432328879	3119	60	19A
0005433438912	3119	61	19C
0005432328885	3119	62	19D
0005432328878	3119	63	19E
0005432328888	3119	64	19F
0005432328908	3119	65	20A
0005433438909	3119	66	20C
0005432328894	3119	67	20D
0005432328899	3119	68	20E
0005433438910	3119	69	20F
0005432328427	31137	1	1C
0005432328498	31137	2	1F
0005432905148	31137	3	1D
0005432328372	31137	4	2A
0005432328454	31137	5	2D
0005432328420	31137	6	2F
0005432328255	31137	7	3A
0005433438805	31137	8	3D
0005432328373	31137	9	4A
0005433438828	31137	10	4C
0005432328416	31137	11	4D
0005432328422	31137	12	4E
0005432328400	31137	13	4F
0005432328474	31137	14	5C
0005432328648	31137	15	5D
0005432328401	31137	16	5E
0005432328647	31137	17	5F
0005432328318	31137	18	6A
0005432328575	31137	19	6C
0005432054316	31137	20	6D
0005432328300	31137	21	6E
0005432328649	31137	22	7A
0005432328361	31137	23	7C
0005432328499	31137	24	7E
0005432905150	31137	25	7F
0005432328582	31137	26	8C
0005432328341	31137	27	8D
0005432905149	31137	28	8F
0005432328398	31137	29	9C
0005432905151	31137	30	9E
0005432328296	31137	31	10D
0005432328469	31137	32	10E
0005432328395	31137	33	10F
0005433438827	31137	34	11A
0005432328428	31137	35	11D
0005432328538	31137	36	11F
0005432054315	31137	37	12A
0005432328502	31137	38	12E
0005432328583	31137	39	12F
0005432054317	31137	40	13C
0005433438829	31137	41	13D
0005432328301	31137	42	13F
0005432328519	31137	43	14A
0005432328507	31137	44	14F
0005432328563	31137	45	15A
0005432328415	31137	46	15C
0005433438836	31137	47	15D
0005432328421	31137	48	15E
0005432328407	31137	49	16A
0005432328620	31137	50	16C
0005432328496	31137	51	16E
0005432328348	31137	52	16F
0005432328347	31137	53	17A
0005432328378	31137	54	17C
0005432328531	31137	55	17E
0005432328466	31137	56	17F
0005432328495	31137	57	18C
0005432328408	31137	58	18D
0005432328459	31137	59	18F
0005432328302	31137	60	19A
0005432328394	31137	61	19D
0005432905147	31137	62	19E
0005432328397	31137	63	19F
0005433438837	31137	64	20C
0005432905146	31137	65	20D
0005432328257	31137	66	20F
0005435487730	6185	1	1C
0005435999324	6185	2	2C
0005435999331	6185	3	2D
0005435487737	6185	4	2F
0005435487723	6185	5	4C
0005434309803	6185	6	4E
0005432146207	6185	7	5A
0005434309797	6185	8	4F
0005434309807	6185	9	5D
0005435297018	6185	10	6A
0005435487724	6185	11	6B
0005435487771	6185	12	7C
0005435487712	6185	13	8C
0005435487793	6185	14	8E
0005434309796	6185	15	8D
0005435999330	6185	16	8F
0005432146208	6185	17	9B
0005435487653	6185	18	9C
0005435297031	6185	19	9F
0005434309799	6185	20	9E
0005434309802	6185	21	11D
0005435999329	6185	22	11F
0005434309794	6185	23	12D
0005434309795	6185	24	12F
0005435999332	6185	25	13B
0005435999326	6185	26	13C
0005435487736	6185	27	13E
0005435487654	6185	28	14A
0005435487630	6185	29	14F
0005435487721	6185	30	15B
0005435487692	6185	31	15C
0005435999327	6185	32	15F
0005435999323	6185	33	16B
0005434309800	6185	34	16F
0005434309798	6185	35	16E
0005434309804	6185	36	17A
0005435999325	6185	37	18A
0005435487593	6185	38	18B
0005435999333	6185	39	18C
0005434309805	6185	40	18D
0005435487722	6185	41	19A
0005434309806	6185	42	19C
0005435487594	6185	43	19B
0005435999328	6185	44	20A
0005434309801	6185	45	20B
0005435487805	6185	46	21C
0005435487719	6185	47	21F
0005435487729	6185	48	22B
0005435487792	6185	49	22C
0005435487829	6185	50	23D
0005435999334	6185	51	23F
0005435999105	19541	1	1C
0005435487911	19541	2	1F
0005435487909	19541	3	2D
0005435999181	19541	4	3C
0005435487913	19541	5	3D
0005434309646	19541	6	3F
0005435487914	19541	7	4C
0005435487917	19541	8	4B
0005435999119	19541	9	4E
0005435999152	19541	10	4D
0005435487900	19541	11	5C
0005435487901	19541	12	6A
0005435297091	19541	13	6C
0005435999158	19541	14	6D
0005435999138	19541	15	6E
0005435487899	19541	16	7A
0005435297090	19541	17	8A
0005434309728	19541	18	8C
0005435487908	19541	19	8E
0005435487902	19541	20	9E
0005435487915	19541	21	9D
0005435999169	19541	22	9F
0005435999137	19541	23	10D
0005435999125	19541	24	10E
0005434309645	19541	25	11D
0005434309662	19541	26	11C
0005435297086	19541	27	12A
0005435999166	19541	28	12D
0005435999180	19541	29	12E
0005435487904	19541	30	13A
0005435999168	19541	31	13B
0005435297088	19541	32	13D
0005434309691	19541	33	13E
0005434309661	19541	34	13F
0005435297085	19541	35	14A
0005435487906	19541	36	14C
0005434309708	19541	37	14B
0005434309659	19541	38	14D
0005435999139	19541	39	15D
0005435487910	19541	40	16A
0005435487916	19541	41	16E
0005435487905	19541	42	17D
0005435999108	19541	43	17E
0005435297089	19541	44	18C
0005434309619	19541	45	18D
0005435999153	19541	46	19A
0005435487912	19541	47	19D
0005434309702	19541	48	19C
0005435999143	19541	49	20C
0005435297087	19541	50	20E
0005435487907	19541	51	21A
0005434309685	19541	52	21C
0005435998987	19541	53	21D
0005435999109	19541	54	22B
0005435999136	19541	55	22A
0005435487903	19541	56	22C
0005435487918	19541	57	22F
0005435999135	19541	58	23B
0005435999101	19541	59	23C
0005434309647	19541	60	23E
0005435999167	19541	61	23F
0005434446513	17545	1	1A
0005433158140	17545	2	1C
0005433158137	17545	3	2B
0005434446498	17545	4	2C
0005433158138	17545	5	2D
0005433158139	17545	6	3D
0005434446504	17545	7	4D
0005434446505	17545	8	5D
0005434446506	17545	9	6D
0005433158136	17545	10	7D
0005433158141	17545	11	18B
0005434446503	17545	12	18D
0005434446512	17545	13	20C
0005434446511	17545	14	22D
0005435508403	1557	1	9C
0005435517984	1557	2	1A
0005435517992	1557	3	1C
0005434565971	1557	4	1F
0005435502407	1557	5	2A
0005434565975	1557	6	2C
0005435502397	1557	7	2D
0005435502419	1557	8	3C
0005434565974	1557	9	3D
0005435517995	1557	10	3F
0005435517991	1557	11	4A
0005435502404	1557	12	4C
0005433186096	1557	13	4D
0005435517986	1557	14	4E
0005435502416	1557	15	4F
0005432291941	1557	16	5A
0005434565976	1557	17	5C
0005435517994	1557	18	5D
0005434565970	1557	19	5E
0005435502406	1557	20	5F
0005435517990	1557	21	6A
0005434565968	1557	22	6D
0005433186095	1557	23	6E
0005435508401	1557	24	6F
0005435517993	1557	25	7A
0005435502413	1557	26	7C
0005435502414	1557	27	7D
0005435517987	1557	28	7E
0005433186109	1557	29	7F
0005434565973	1557	30	8C
0005435517982	1557	31	8D
0005435502410	1557	32	8E
0005435517985	1557	33	8F
0005433186101	1557	34	9A
0005435502408	1557	35	9F
0005435502405	1557	36	10A
0005435502401	1557	37	10E
0005435502415	1557	38	10F
0005435502399	1557	39	11A
0005435502403	1557	40	11C
0005435517988	1557	41	11D
0005435502418	1557	42	11E
0005433186080	1557	43	11F
0005433186076	1557	44	12C
0005435517980	1557	45	12F
0005435517979	1557	46	13A
0005435517989	1557	47	13C
0005435517978	1557	48	13D
0005435502411	1557	49	14A
0005433186108	1557	50	14D
0005433186075	1557	51	14F
0005435508405	1557	52	15A
0005434565969	1557	53	15C
0005434565972	1557	54	15E
0005435508400	1557	55	16A
0005435502409	1557	56	16C
0005435508404	1557	57	16D
0005435517996	1557	58	16E
0005435502417	1557	59	16F
0005434565978	1557	60	17A
0005435508402	1557	61	17E
0005434565977	1557	62	17F
0005435502398	1557	63	18D
0005435502400	1557	64	18E
0005435502412	1557	65	19A
0005435502402	1557	66	19D
0005433186110	1557	67	19E
0005435517983	1557	68	19F
0005434565979	1557	69	20A
0005435517981	1557	70	20C
0005435517977	1557	71	20E
0005435502277	20895	1	1A
0005433186159	20895	2	1C
0005435502182	20895	3	1F
0005434565836	20895	4	2A
0005435502260	20895	5	2C
0005435502188	20895	6	2D
0005435502241	20895	7	2F
0005434565807	20895	8	3A
0005435545683	20895	9	3C
0005435502254	20895	10	3D
0005435529181	20895	11	3F
0005434565808	20895	12	4A
0005435502271	20895	13	4D
0005433186155	20895	14	4E
0005434565874	20895	15	4F
0005435529128	20895	16	5A
0005435502225	20895	17	5C
0005435502242	20895	18	5D
0005435502119	20895	19	5E
0005435529061	20895	20	5F
0005435502118	20895	21	6A
0005435502180	20895	22	6D
0005433186153	20895	23	6E
0005434565845	20895	24	6F
0005435502215	20895	25	7A
0005435502204	20895	26	7D
0005435502175	20895	27	7E
0005434565875	20895	28	7F
0005435502107	20895	29	8C
0005434565869	20895	30	8D
0005435502193	20895	31	8E
0005435529142	20895	32	8F
0005433186156	20895	33	9A
0005435502300	20895	34	9C
0005435502176	20895	35	9D
0005435529087	20895	36	9E
0005434565809	20895	37	9F
0005435529199	20895	38	10A
0005433186152	20895	39	10C
0005435545668	20895	40	10D
0005435502203	20895	41	10E
0005435502179	20895	42	10F
0005435502209	20895	43	11C
0005435502146	20895	44	11D
0005433186154	20895	45	11E
0005435502206	20895	46	11F
0005435502216	20895	47	12A
0005435529201	20895	48	12C
0005434565838	20895	49	12D
0005435502240	20895	50	12E
0005434565863	20895	51	12F
0005434565873	20895	52	13A
0005434565837	20895	53	13D
0005435545657	20895	54	13E
0005435502207	20895	55	13F
0005435502299	20895	56	14A
0005435529141	20895	57	14C
0005434565870	20895	58	14D
0005435545692	20895	59	14E
0005434565889	20895	60	14F
0005435502145	20895	61	15C
0005435529095	20895	62	15D
0005435529122	20895	63	15E
0005435502183	20895	64	15F
0005433186157	20895	65	16A
0005434565828	20895	66	16F
0005435545673	20895	67	17A
0005435502189	20895	68	17C
0005435502192	20895	69	17D
0005435502272	20895	70	17E
0005435529096	20895	71	17F
0005435529039	20895	72	18A
0005435529198	20895	73	18D
0005435502132	20895	74	18E
0005435502157	20895	75	19A
0005435502233	20895	76	19C
0005435502220	20895	77	19E
0005433186160	20895	78	19F
0005435529200	20895	79	20A
0005435545684	20895	80	20C
0005433186158	20895	81	20D
0005435529239	20895	82	20F
0005435153767	3915	1	1A
0005435153772	3915	2	1C
0005435931586	3915	3	3D
0005435153769	3915	4	4A
0005435931589	3915	5	6B
0005435153768	3915	6	6C
0005435153773	3915	7	6D
0005435931590	3915	8	7B
0005435931587	3915	9	22C
0005435153771	3915	10	22D
0005435153770	3915	11	23B
0005435153708	21869	1	2C
0005435931619	21869	2	5C
0005435153707	21869	3	5D
0005435931618	21869	4	6C
0005435931617	21869	5	19D
0005435931616	21869	6	20A
0005435153727	21869	7	20D
0005435153715	21869	8	22D
0005432628915	7204	1	1A
0005435225569	7204	2	1B
0005435225529	7204	3	1C
0005435225539	7204	4	1D
0005435225570	7204	5	2B
0005432628904	7204	6	2C
0005432628910	7204	7	2D
0005432628907	7204	8	3A
0005435225559	7204	9	3B
0005435225543	7204	10	3D
0005432628906	7204	11	4A
0005432628909	7204	12	5A
0005435225541	7204	13	5B
0005432628911	7204	14	5C
0005432628913	7204	15	6A
0005432628914	7204	16	6C
0005435225549	7204	17	6D
0005432628916	7204	18	7A
0005435225540	7204	19	7D
0005432628908	7204	20	18A
0005432628918	7204	21	18B
0005432628917	7204	22	18C
0005432628905	7204	23	18D
0005435225521	7204	24	22A
0005435225548	7204	25	22B
0005435225563	7204	26	22D
0005432628912	7204	27	23A
0005435225542	7204	28	23B
0005432628818	28149	1	1D
0005432628792	28149	2	2B
0005432628750	28149	3	2A
0005432628829	28149	4	2D
0005435225619	28149	5	3A
0005435225621	28149	6	3B
0005432628779	28149	7	4A
0005432628681	28149	8	4B
0005432628785	28149	9	4C
0005432628780	28149	10	5A
0005435225616	28149	11	5B
0005435225620	28149	12	5D
0005435225618	28149	13	6A
0005432628758	28149	14	6B
0005432628810	28149	15	6D
0005432628817	28149	16	7A
0005432628786	28149	17	7B
0005432628733	28149	18	18A
0005432628791	28149	19	18B
0005432628828	28149	20	18C
0005435225623	28149	21	19B
0005432628757	28149	22	19C
0005435225622	28149	23	19D
0005435225617	28149	24	20B
0005432628793	28149	25	21A
0005432628800	28149	26	21D
0005432628732	28149	27	22A
0005432628798	28149	28	22B
0005432628799	28149	29	23B
0005434267944	8735	1	2C
0005435960067	8735	2	3A
0005435960065	8735	3	3D
0005434267924	8735	4	4B
0005435960068	8735	5	6C
0005435960069	8735	6	7B
0005434267945	8735	7	19C
0005435960066	8735	8	20D
0005434267938	8735	9	21B
0005434267965	15262	1	1B
0005434267964	15262	2	2A
0005435960035	15262	3	3C
0005435960040	15262	4	3D
0005434267966	15262	5	4C
0005435960050	15262	6	5B
0005434267967	15262	7	19A
0005435960034	15262	8	20B
0005435960051	15262	9	21C
0005432675200	1196	1	1C
0005432675192	1196	2	1A
0005432693176	1196	3	1D
0005432675201	1196	4	2A
0005432677587	1196	5	2D
0005432693171	1196	6	2C
0005432675199	1196	7	3A
0005432873228	1196	8	3C
0005432693188	1196	9	4A
0005432677588	1196	10	4C
0005432693167	1196	11	5A
0005432693185	1196	12	4D
0005432693181	1196	13	5C
0005432693162	1196	14	5D
0005432693175	1196	15	6B
0005432693183	1196	16	6D
0005432675204	1196	17	6C
0005432675193	1196	18	6E
0005432675191	1196	19	7E
0005432693169	1196	20	8B
0005432693180	1196	21	9A
0005432675203	1196	22	9C
0005432693161	1196	23	10A
0005432675194	1196	24	10B
0005432693184	1196	25	10F
0005432693163	1196	26	11B
0005432693170	1196	27	11A
0005432693182	1196	28	11D
0005432675197	1196	29	12B
0005432693165	1196	30	12A
0005432693166	1196	31	12F
0005432677585	1196	32	13D
0005432675195	1196	33	13F
0005432693189	1196	34	14E
0005432873250	1196	35	14D
0005432693160	1196	36	14C
0005432693186	1196	37	14F
0005432693173	1196	38	15B
0005432873247	1196	39	15C
0005432873213	1196	40	15F
0005432693164	1196	41	16B
0005432873219	1196	42	16D
0005432675196	1196	43	17A
0005432693187	1196	44	17D
0005432675189	1196	45	17F
0005432873214	1196	46	17E
0005432693168	1196	47	18B
0005432675202	1196	48	18D
0005432693159	1196	49	18C
0005432693174	1196	50	18E
0005432873255	1196	51	19A
0005432693177	1196	52	19C
0005432677586	1196	53	19B
0005432873248	1196	54	19D
0005432675190	1196	55	20B
0005432873249	1196	56	20A
0005432693179	1196	57	21B
0005432693172	1196	58	21A
0005432675198	1196	59	20F
0005432693178	1196	60	21E
0005432675104	17485	1	1A
0005432692861	17485	2	1F
0005432692903	17485	3	3A
0005432692871	17485	4	2F
0005432692954	17485	5	3D
0005432692798	17485	6	3F
0005432692928	17485	7	4A
0005432675075	17485	8	5A
0005432693021	17485	9	5F
0005432675046	17485	10	5D
0005432873325	17485	11	6D
0005432692955	17485	12	6C
0005432675074	17485	13	7A
0005432675097	17485	14	6F
0005432873323	17485	15	8A
0005432873322	17485	16	8B
0005432692939	17485	17	8D
0005432677545	17485	18	8C
0005432675123	17485	19	9C
0005432675076	17485	20	10A
0005432692918	17485	21	10E
0005432692927	17485	22	11A
0005432675052	17485	23	10F
0005432675087	17485	24	11D
0005432692766	17485	25	11F
0005432692910	17485	26	12A
0005432677550	17485	27	12C
0005432692940	17485	28	12E
0005432692895	17485	29	13A
0005432692797	17485	30	13C
0005432675061	17485	31	13E
0005432692883	17485	32	13D
0005432873320	17485	33	13F
0005432675032	17485	34	14C
0005432692938	17485	35	14A
0005432675045	17485	36	14F
0005432693061	17485	37	14E
0005432693003	17485	38	15D
0005432692866	17485	39	15C
0005432873324	17485	40	16A
0005432677551	17485	41	15F
0005432873319	17485	42	16C
0005432873321	17485	43	16B
0005432675031	17485	44	16F
0005432692831	17485	45	17B
0005432692830	17485	46	17A
0005432692924	17485	47	17F
0005432692997	17485	48	18B
0005432692865	17485	49	18F
0005432692941	17485	50	18E
0005432692846	17485	51	18D
0005432692867	17485	52	19C
0005432675106	17485	53	19B
0005432675055	17485	54	19E
0005432692860	17485	55	19F
0005432675090	17485	56	20C
0005432692712	17485	57	20A
0005432692870	17485	58	20D
0005432675089	17485	59	21B
0005432692859	17485	60	21A
0005432675103	17485	61	21C
0005432692926	17485	62	21E
0005432692822	17485	63	21D
0005432692832	17485	64	21F
0005433156718	1124	1	1C
0005434435245	1124	2	2A
0005433156717	1124	3	2C
0005434435250	1124	4	3A
0005434435255	1124	5	3B
0005433156736	1124	6	3C
0005434435249	1124	7	3D
0005434435248	1124	8	4C
0005433156716	1124	9	5A
0005433156705	1124	10	6A
0005433156704	1124	11	6D
0005433156708	1124	12	7A
0005434435242	1124	13	18C
0005434435241	1124	14	18D
0005433156719	1124	15	19B
0005434435247	1124	16	19C
0005434435246	1124	17	19D
0005434435254	1124	18	20C
0005434435240	1124	19	20D
0005434435251	1124	20	21B
0005434435243	1124	21	21C
0005434435253	1124	22	21D
0005434435252	1124	23	22C
0005433156715	1124	24	23A
0005434435244	1124	25	23B
0005434435066	17306	1	1A
0005434435061	17306	2	1C
0005434435114	17306	3	2B
0005433156784	17306	4	3B
0005433156788	17306	5	3C
0005434435172	17306	6	3D
0005433156787	17306	7	4B
0005434435171	17306	8	5A
0005433156790	17306	9	6A
0005433156789	17306	10	7A
0005433156785	17306	11	7D
0005433156783	17306	12	18B
0005434435136	17306	13	18D
0005434435060	17306	14	19B
0005434435080	17306	15	19C
0005434435074	17306	16	19D
0005434435115	17306	17	20A
0005434435138	17306	18	20C
0005434435168	17306	19	21A
0005434435078	17306	20	22C
0005434435139	17306	21	22D
0005433156786	17306	22	23B
0005435928119	4075	1	2D
0005435086870	4075	2	3A
0005435928101	4075	3	3D
0005435928136	4075	4	4A
0005435086868	4075	5	5A
0005435086865	4075	6	6A
0005435086866	4075	7	6B
0005435928132	4075	8	18A
0005435086869	4075	9	18B
0005435086863	4075	10	19C
0005435928133	4075	11	20A
0005435086867	4075	12	20C
0005435086864	4075	13	21A
0005435928134	4075	14	22A
0005435086775	24433	1	1A
0005435928164	24433	2	1D
0005435928165	24433	3	2B
0005435928163	24433	4	3B
0005435086804	24433	5	4C
0005435928161	24433	6	6B
0005435928162	24433	7	7B
0005435086784	24433	8	18C
0005435086794	24433	9	19D
0005435086801	24433	10	21C
0005435086795	24433	11	23B
0005435551611	17009	1	2B
0005435551615	17009	2	3F
0005435551604	17009	3	3G
0005435551603	17009	4	4F
0005435098561	17009	5	9H
0005435098568	17009	6	11A
0005435098564	17009	7	12H
0005435551619	17009	8	14B
0005435098562	17009	9	14F
0005435551607	17009	10	15E
0005435098565	17009	11	16F
0005435551601	17009	12	17E
0005435551618	17009	13	18D
0005435551620	17009	14	19A
0005435551613	17009	15	19E
0005435551605	17009	16	19D
0005435551609	17009	17	20E
0005435551612	17009	18	20D
0005435551617	17009	19	20F
0005435551598	17009	20	22E
0005435098563	17009	21	24A
0005435551610	17009	22	24E
0005435098567	17009	23	27A
0005435551614	17009	24	27E
0005435098566	17009	25	28A
0005435551621	17009	26	28D
0005435551602	17009	27	31H
0005435098569	17009	28	32B
0005435551606	17009	29	33A
0005435551616	17009	30	32H
0005435551600	17009	31	35F
0005435551608	17009	32	35H
0005435551599	17009	33	38F
0005434626002	4868	1	6C
0005434626004	4868	2	6F
0005435907469	4868	3	8A
0005434626000	4868	4	9C
0005434626003	4868	5	9D
0005435907508	4868	6	9E
0005434625999	4868	7	10D
0005434625997	4868	8	10F
0005434626006	4868	9	11F
0005434625998	4868	10	12E
0005433194839	4868	11	13A
0005433194837	4868	12	14A
0005434626005	4868	13	14E
0005433194840	4868	14	18A
0005434626001	4868	15	18E
0005435907482	4868	16	19F
0005435907525	32933	1	1F
0005434625963	32933	2	3F
0005435907522	32933	3	5C
0005434625964	32933	4	6E
0005434625946	32933	5	7A
0005434625930	32933	6	7E
0005434625954	32933	7	7F
0005435907523	32933	8	9D
0005434625931	32933	9	9F
0005434625953	32933	10	10C
0005434625952	32933	11	10F
0005434625974	32933	12	15F
0005434625923	32933	13	17C
0005435907524	32933	14	17F
0005434625933	32933	15	19A
0005434625975	32933	16	19E
0005435785304	13766	1	1A
0005432195702	13766	2	1B
0005435785142	13766	3	1C
0005435785303	13766	4	1D
0005435785313	13766	5	2A
0005435785157	13766	6	2B
0005435785094	13766	7	2C
0005435785120	13766	8	2D
0005435785125	13766	9	3A
0005435785212	13766	10	3B
0005435785279	13766	11	3C
0005435785278	13766	12	3D
0005435785087	13766	13	4A
0005435785312	13766	14	4B
0005435785215	13766	15	4C
0005435785238	13766	16	4D
0005435785093	13766	17	5A
0005435785061	13766	18	5B
0005435785024	13766	19	5C
0005435785214	13766	20	5D
0005435785134	13766	21	6A
0005435785148	13766	22	6B
0005432195701	13766	23	6C
0005435785302	13766	24	6D
0005435785195	13766	25	7A
0005435785253	13766	26	7B
0005435785116	13766	27	7C
0005435787334	13766	28	7D
0005435785104	13766	29	18A
0005435787342	13766	30	18B
0005435785213	13766	31	18C
0005432195703	13766	32	18D
0005435785239	13766	33	19A
0005435784892	13766	34	19B
0005435785217	13766	35	19C
0005435785124	13766	36	19D
0005435785012	13766	37	20A
0005435785076	13766	38	20B
0005435785117	13766	39	20C
0005435785025	13766	40	20D
0005435785103	13766	41	21A
0005435785083	13766	42	21B
0005435785156	13766	43	21C
0005435785043	13766	44	21D
0005435785066	13766	45	22A
0005435785088	13766	46	22B
0005435785158	13766	47	22C
0005435785044	13766	48	22D
0005435785221	13766	49	23A
0005435785222	13766	50	23B
0005435785462	27412	1	1A
0005435785468	27412	2	1B
0005435785440	27412	3	1C
0005432190640	27412	4	1D
0005435785452	27412	5	2A
0005435785446	27412	6	2B
0005435785464	27412	7	2D
0005432190639	27412	8	3A
0005435785445	27412	9	3B
0005435785437	27412	10	3C
0005435785439	27412	11	3D
0005435937359	27412	12	4A
0005435787360	27412	13	4B
0005435937357	27412	14	4C
0005435937353	27412	15	4D
0005435785456	27412	16	5A
0005432190641	27412	17	5B
0005435937346	27412	18	5C
0005435785455	27412	19	6A
0005435785457	27412	20	6B
0005435785447	27412	21	6C
0005435785466	27412	22	6D
0005435785459	27412	23	7A
0005435785460	27412	24	7B
0005435785443	27412	25	7C
0005435937351	27412	26	7D
0005435785470	27412	27	18A
0005435785449	27412	28	18B
0005435937363	27412	29	18C
0005435785454	27412	30	18D
0005435785463	27412	31	19A
0005435785438	27412	32	19B
0005435785465	27412	33	19C
0005435785448	27412	34	19D
0005435785442	27412	35	20B
0005435937362	27412	36	20C
0005435785467	27412	37	20D
0005435785461	27412	38	21A
0005435785444	27412	39	21C
0005435785469	27412	40	21D
0005435785450	27412	41	22B
0005435785458	27412	42	22C
0005435785441	27412	43	22D
0005435785453	27412	44	23A
0005435785451	27412	45	23B
0005434407582	20268	1	1A
0005434407521	20268	2	1C
0005435311110	20268	3	1D
0005434407554	20268	4	1F
0005435311112	20268	5	2A
0005434407364	20268	6	2C
0005434407263	20268	7	2D
0005434407493	20268	8	2F
0005434407455	20268	9	3A
0005434407598	20268	10	3C
0005434407498	20268	11	3D
0005434407546	20268	12	3F
0005434407355	20268	13	4A
0005434407360	20268	14	4F
0005434407335	20268	15	5A
0005434407357	20268	16	5C
0005434407519	20268	17	5E
0005434407462	20268	18	5F
0005434407484	20268	19	6A
0005435311109	20268	20	6C
0005434407560	20268	21	6D
0005435311107	20268	22	6E
0005434407726	20268	23	7A
0005434407250	20268	24	7C
0005435311111	20268	25	7D
0005434407473	20268	26	7E
0005434407652	20268	27	7F
0005434407416	20268	28	8A
0005434407668	20268	29	8E
0005434407667	20268	30	8F
0005434407590	20268	31	9C
0005435311108	20268	32	9D
0005434407502	20268	33	9E
0005434407512	20268	34	9F
0005434407241	20268	35	10A
0005434407491	20268	36	10C
0005434407345	20268	37	10D
0005434407503	20268	38	10E
0005434407381	20268	39	10F
0005435311106	20268	40	11A
0005434407518	20268	41	11C
0005434407603	20268	42	11D
0005434407504	20268	43	11E
0005434407265	20268	44	11F
0005435311105	20268	45	12D
0005434407488	20268	46	13C
0005432058398	20268	47	13D
0005434407259	20268	48	13E
0005434407513	20268	49	14A
0005434407551	20268	50	14C
0005434407604	20268	51	14E
0005434407350	20268	52	15C
0005435311113	20268	53	15A
0005434407492	20268	54	15D
0005434407592	20268	55	15E
0005434407621	20268	56	15F
0005434407501	20268	57	16C
0005434407368	20268	58	16D
0005432058399	20268	59	16F
0005435311114	20268	60	17A
0005434407358	20268	61	17C
0005434407602	20268	62	17D
0005434407193	20268	63	17E
0005434407776	20268	64	17F
0005434407533	20268	65	18A
0005432058401	20268	66	18D
0005434407382	20268	67	18C
0005434407369	20268	68	18E
0005434407445	20268	69	18F
0005434407739	20268	70	19A
0005434407417	20268	71	19C
0005434407545	20268	72	19D
0005434407264	20268	73	19E
0005434407472	20268	74	19F
0005434407591	20268	75	20A
0005432058400	20268	76	20C
0005434407361	20268	77	20D
0005434407497	20268	78	20F
0005434408047	26983	1	1A
0005432153967	26983	2	1C
0005434408053	26983	3	1F
0005434407996	26983	4	2A
0005435310984	26983	5	2C
0005434408012	26983	6	2D
0005435311008	26983	7	2F
0005434408037	26983	8	3A
0005434408019	26983	9	3C
0005432153970	26983	10	3D
0005434408048	26983	11	3F
0005434408014	26983	12	4A
0005434408057	26983	13	4C
0005435311006	26983	14	4D
0005434408043	26983	15	4E
0005434408005	26983	16	4F
0005434408023	26983	17	5A
0005435310996	26983	18	5C
0005434408054	26983	19	5D
0005435310985	26983	20	5E
0005434408046	26983	21	5F
0005434408002	26983	22	6A
0005434408022	26983	23	6C
0005435311021	26983	24	6D
0005434408038	26983	25	6E
0005434407995	26983	26	6F
0005434408025	26983	27	7A
0005434408016	26983	28	7C
0005434408044	26983	29	7D
0005434408013	26983	30	7E
0005432153968	26983	31	8A
0005434408049	26983	32	8C
0005435311004	26983	33	8D
0005434408036	26983	34	8E
0005434408024	26983	35	8F
0005435310990	26983	36	9A
0005434408008	26983	37	9C
0005434408009	26983	38	9D
0005434408026	26983	39	9E
0005434408032	26983	40	9F
0005432153966	26983	41	10A
0005434408041	26983	42	10C
0005434407999	26983	43	10D
0005434408051	26983	44	10F
0005434408011	26983	45	11A
0005434408052	26983	46	11C
0005434408045	26983	47	11D
0005434408018	26983	48	11E
0005434408020	26983	49	11F
0005434408007	26983	50	12A
0005434408028	26983	51	12C
0005432153969	26983	52	12D
0005435311023	26983	53	12F
0005434408035	26983	54	13A
0005434408021	26983	55	13C
0005435310991	26983	56	13E
0005434408050	26983	57	13F
0005434408039	26983	58	14A
0005434407994	26983	59	14C
0005434408058	26983	60	14D
0005434408001	26983	61	14F
0005434408006	26983	62	15A
0005434408042	26983	63	15C
0005434408030	26983	64	15D
0005434408015	26983	65	15E
0005434408029	26983	66	15F
0005434408059	26983	67	16A
0005432153965	26983	68	16C
0005434408033	26983	69	16D
0005435310989	26983	70	16E
0005434408004	26983	71	16F
0005435310999	26983	72	17A
0005434408003	26983	73	17C
0005434408000	26983	74	17D
0005434408056	26983	75	17E
0005432153964	26983	76	17F
0005435311020	26983	77	18A
0005434408017	26983	78	18C
0005435310960	26983	79	18D
0005435311001	26983	80	18F
0005434408040	26983	81	19A
0005435311002	26983	82	19C
0005434408027	26983	83	19D
0005434407998	26983	84	19E
0005434408010	26983	85	19F
0005434407997	26983	86	20A
0005434408031	26983	87	20D
0005434408055	26983	88	20E
0005434408034	26983	89	20F
0005434319461	5714	1	1F
0005434319459	5714	2	3F
0005434319446	5714	3	4A
0005434319465	5714	4	4D
0005433123801	5714	5	5D
0005432109717	5714	6	6A
0005433123781	5714	7	6C
0005433123894	5714	8	6E
0005434319462	5714	9	7D
0005432109716	5714	10	8A
0005434319449	5714	11	8C
0005434319455	5714	12	8E
0005434319463	5714	13	9A
0005434319464	5714	14	9C
0005433123782	5714	15	9D
0005433123776	5714	16	10C
0005434319468	5714	17	10D
0005434319453	5714	18	11C
0005433123874	5714	19	12E
0005434319456	5714	20	12F
0005433123886	5714	21	13C
0005433123847	5714	22	13D
0005433123774	5714	23	13E
0005433123834	5714	24	14A
0005433123846	5714	25	14C
0005434319452	5714	26	15A
0005434319448	5714	27	15E
0005433123828	5714	28	15F
0005434319467	5714	29	16A
0005434319457	5714	30	16D
0005433123802	5714	31	17A
0005434319458	5714	32	17C
0005433123845	5714	33	17F
0005434319447	5714	34	18A
0005434319466	5714	35	18C
0005433123863	5714	36	18D
0005434319460	5714	37	18E
0005434319451	5714	38	18F
0005434319450	5714	39	19A
0005434319454	5714	40	19C
0005433123873	5714	41	19F
0005433123868	5714	42	20E
0005433124025	15707	1	2A
0005434319358	15707	2	4D
0005433124018	15707	3	7C
0005434319296	15707	4	7D
0005433124015	15707	5	7F
0005433124014	15707	6	8C
0005433124024	15707	7	8E
0005434319301	15707	8	9A
0005433124019	15707	9	10C
0005434319312	15707	10	12C
0005434319300	15707	11	12D
0005433124017	15707	12	14A
0005434319357	15707	13	14C
0005434319381	15707	14	14D
0005433124021	15707	15	15A
0005434312316	15707	16	15D
0005433124023	15707	17	16A
0005434319290	15707	18	17A
0005433124022	15707	19	17C
0005434319308	15707	20	17D
0005434319317	15707	21	17F
0005433124020	15707	22	18C
0005434319295	15707	23	18F
0005433124016	15707	24	19D
0005433124026	15707	25	19F
0005435220324	31743	1	1B
0005435220327	31743	2	3B
0005435220325	31743	3	3C
0005435220330	31743	4	7B
0005435219211	31743	5	7A
0005435219209	31743	6	7C
0005435220328	31743	7	18B
0005435219207	31743	8	18D
0005435219205	31743	9	19A
0005435219210	31743	10	19B
0005435219206	31743	11	19C
0005435220326	31743	12	20A
0005435219208	31743	13	21A
0005435220329	31743	14	22B
0005435220491	31743	15	23B
0005434189145	8988	1	1A
0005434484376	8988	2	3A
0005434484373	8988	3	3D
0005434484378	8988	4	5B
0005434189144	8988	5	6C
0005434484374	8988	6	7B
0005434484379	8988	7	7C
0005434189150	8988	8	18A
0005434484377	8988	9	21A
0005434189151	8988	10	21C
0005434484375	8988	11	21D
0005434484289	16657	1	2A
0005434189205	16657	2	2C
0005434189202	16657	3	4B
0005434484343	16657	4	6A
0005434189203	16657	5	6D
0005434189201	16657	6	7B
0005434189200	16657	7	7C
0005434189206	16657	8	18D
0005434484329	16657	9	20A
0005434484288	16657	10	20C
0005434484334	16657	11	20D
0005434189204	16657	12	23A
0005433124021	7596	1	1A
0005433124018	7596	2	1F
0005433124014	7596	3	3F
0005433124020	7596	4	5C
0005433124024	7596	5	9E
0005433124016	7596	6	10A
0005433124026	7596	7	10D
0005433124015	7596	8	12F
0005433722170	7596	9	14C
0005433124017	7596	10	14D
0005433124023	7596	11	14E
0005433124022	7596	12	15D
0005433124019	7596	13	16D
0005433124025	7596	14	20E
0005432693215	7595	1	1A
0005432693200	7595	2	1C
0005432693221	7595	3	1D
0005433450060	7595	4	1F
0005432721025	7595	5	2A
0005432721032	7595	6	2C
0005432693216	7595	7	2D
0005432721029	7595	8	2F
0005433450066	7595	9	3A
0005432721007	7595	10	3C
0005432693190	7595	11	3D
0005432721010	7595	12	3F
0005432721008	7595	13	4A
0005432693214	7595	14	4C
0005432693213	7595	15	4D
0005432721028	7595	16	4E
0005433450071	7595	17	4F
0005432693192	7595	18	5C
0005432721030	7595	19	5A
0005432721013	7595	20	5D
0005433450065	7595	21	5E
0005433450064	7595	22	5F
0005432071587	7595	23	6A
0005432693207	7595	24	6C
0005432693205	7595	25	6D
0005432693198	7595	26	6E
0005432693219	7595	27	6F
0005433450073	7595	28	7A
0005432721023	7595	29	7C
0005432693208	7595	30	7D
0005432721031	7595	31	7E
0005433450068	7595	32	7F
0005432693220	7595	33	8C
0005432693191	7595	34	8D
0005432721011	7595	35	8E
0005432693211	7595	36	8F
0005432693199	7595	37	9A
0005432693210	7595	38	9C
0005432721022	7595	39	9D
0005432693195	7595	40	9E
0005432693197	7595	41	10A
0005433450053	7595	42	10C
0005433450072	7595	43	10E
0005433450069	7595	44	10F
0005433450056	7595	45	11A
0005432693222	7595	46	11C
0005433450061	7595	47	11D
0005432721018	7595	48	11E
0005432721027	7595	49	11F
0005432693202	7595	50	12A
0005432693203	7595	51	12C
0005433450067	7595	52	12D
0005432721017	7595	53	12E
0005432693201	7595	54	13A
0005432721016	7595	55	13C
0005433450054	7595	56	13E
0005433450052	7595	57	13F
0005432721006	7595	58	14A
0005432693212	7595	59	14E
0005433450055	7595	60	14F
0005432721026	7595	61	15A
0005432071586	7595	62	15C
0005433450063	7595	63	15D
0005432721012	7595	64	15E
0005433450059	7595	65	15F
0005433450062	7595	66	16A
0005433450070	7595	67	16C
0005432693204	7595	68	16D
0005432693217	7595	69	16E
0005432721009	7595	70	17A
0005432693194	7595	71	17C
0005432721024	7595	72	17D
0005432693209	7595	73	17E
0005432693196	7595	74	17F
0005432721021	7595	75	18A
0005432721014	7595	76	18C
0005432071585	7595	77	18F
0005432693206	7595	78	19C
0005432721020	7595	79	19D
0005432693193	7595	80	19E
0005432721015	7595	81	19F
0005432721019	7595	82	20A
0005433450058	7595	83	20C
0005433450057	7595	84	20D
0005432693218	7595	85	20F
0005432692895	30272	1	1A
0005432693061	30272	2	1C
0005432692870	30272	3	1F
0005432692867	30272	4	2A
0005433449798	30272	5	2C
0005432692926	30272	6	3A
0005432692954	30272	7	3D
0005432692941	30272	8	3F
0005432692955	30272	9	4C
0005433449827	30272	10	4D
0005432693003	30272	11	4E
0005432692938	30272	12	5A
0005432692798	30272	13	5E
0005432692846	30272	14	5F
0005432692822	30272	15	6A
0005432692928	30272	16	6C
0005432692866	30272	17	6E
0005432692910	30272	18	7D
0005432692918	30272	19	7F
0005432692712	30272	20	8A
0005433449788	30272	21	8F
0005433450006	30272	22	9A
0005433449914	30272	23	9C
0005432692903	30272	24	9D
0005432692797	30272	25	9F
0005432692927	30272	26	10D
0005432692924	30272	27	10E
0005432692997	30272	28	10F
0005433450007	30272	29	11A
0005433449881	30272	30	11D
0005432692871	30272	31	12A
0005433449864	30272	32	12C
0005432692861	30272	33	12D
0005433449879	30272	34	12E
0005432692831	30272	35	13A
0005433449847	30272	36	13F
0005432692940	30272	37	14C
0005433449762	30272	38	14D
0005432693021	30272	39	15A
0005433449876	30272	40	15F
0005433449942	30272	41	16E
0005432692830	30272	42	16F
0005432692860	30272	43	17A
0005432692859	30272	44	17D
0005432692883	30272	45	17F
0005433449938	30272	46	18F
0005432692766	30272	47	19A
0005432692832	30272	48	19D
0005433449885	30272	49	19F
0005433449870	30272	50	20A
0005432692939	30272	51	20E
0005432692865	30272	52	20F
0005433123774	30271	1	1D
0005432720867	30271	2	1F
0005432720773	30271	3	2A
0005433123782	30271	4	2C
0005433123847	30271	5	2F
0005432720756	30271	6	3C
0005433722249	30271	7	3F
0005432720772	30271	8	4D
0005433123868	30271	9	4E
0005432720852	30271	10	5A
0005432720736	30271	11	6A
0005433722252	30271	12	6C
0005433123863	30271	13	6E
0005433123802	30271	14	7A
0005433123845	30271	15	7C
0005433722250	30271	16	7D
0005432720827	30271	17	7E
0005433123801	30271	18	7F
0005432720925	30271	19	8C
0005433722251	30271	20	8E
0005433123781	30271	21	9C
0005432720742	30271	22	9D
0005432720942	30271	23	9E
0005433123894	30271	24	9F
0005432720807	30271	25	10A
0005432720774	30271	26	10C
0005432720941	30271	27	10F
0005433722247	30271	28	11C
0005432720808	30271	29	11D
0005433123834	30271	30	11E
0005432720790	30271	31	12A
0005432720832	30271	32	12C
0005432720705	30271	33	12D
0005433123846	30271	34	12F
0005432720745	30271	35	13A
0005433722253	30271	36	14C
0005433123828	30271	37	14D
0005432720740	30271	38	14E
0005433123874	30271	39	14F
0005432720812	30271	40	15A
0005432720875	30271	41	15C
0005432720775	30271	42	15D
0005432720640	30271	43	15E
0005432720744	30271	44	15F
0005432720804	30271	45	16A
0005432720741	30271	46	16E
0005433123776	30271	47	17A
0005433123886	30271	48	17D
0005433123873	30271	49	17E
0005432720788	30271	50	17F
0005432720821	30271	51	18C
0005433722248	30271	52	18D
0005432720771	30271	53	18E
0005432720682	30271	54	18F
0005432720813	30271	55	19A
0005432720853	30271	56	19D
0005433722246	30271	57	19E
0005432720757	30271	58	19F
0005432720659	30271	59	20A
0005432720940	30271	60	20E
0005432720760	30271	61	20F
0005432927966	1406	1	1A
0005434586733	1406	2	1C
0005433193010	1406	3	1D
0005434586734	1406	4	2A
0005433525087	1406	5	2C
0005434586716	1406	6	2F
0005433525081	1406	7	3A
0005434514978	1406	8	3C
0005434514979	1406	9	3D
0005432271018	1406	10	3F
0005433193015	1406	11	4A
0005434586723	1406	12	4C
0005434586712	1406	13	4D
0005434586725	1406	14	4E
0005434586715	1406	15	5A
0005432927970	1406	16	5C
0005434586735	1406	17	5E
0005433192965	1406	18	5D
0005433724825	1406	19	5F
0005432927967	1406	20	6A
0005433525091	1406	21	6D
0005433193019	1406	22	6E
0005434586711	1406	23	6F
0005434586728	1406	24	7C
0005434586720	1406	25	7D
0005434586718	1406	26	7E
0005434586722	1406	27	8A
0005434586709	1406	28	8C
0005433525086	1406	29	8D
0005432271017	1406	30	8F
0005433192994	1406	31	9C
0005434586719	1406	32	9D
0005434586732	1406	33	9E
0005433525084	1406	34	9F
0005434586721	1406	35	10A
0005433193020	1406	36	10C
0005432271016	1406	37	10D
0005432927971	1406	38	10E
0005433193052	1406	39	10F
0005434586710	1406	40	11E
0005432968838	1406	41	11F
0005434586713	1406	42	12A
0005434586724	1406	43	12C
0005433724822	1406	44	12E
0005433193030	1406	45	12F
0005433525085	1406	46	13A
0005433192991	1406	47	13C
0005433525090	1406	48	13E
0005433525083	1406	49	13F
0005433193024	1406	50	14A
0005434586714	1406	51	14D
0005433525080	1406	52	14E
0005433525088	1406	53	14F
0005434586717	1406	54	15C
0005434586726	1406	55	15E
0005433724824	1406	56	15F
0005433525089	1406	57	16A
0005432927942	1406	58	16C
0005433193014	1406	59	16D
0005434586731	1406	60	16E
0005433193009	1406	61	16F
0005432271015	1406	62	17A
0005433193053	1406	63	17C
0005433525092	1406	64	17D
0005433525082	1406	65	17E
0005434586727	1406	66	18C
0005432927943	1406	67	18E
0005433724823	1406	68	19A
0005433192996	1406	69	19C
0005433192979	1406	70	19D
0005434586729	1406	71	19E
0005434586730	1406	72	20C
0005432927941	1406	73	20E
0005434586487	18502	1	1A
0005434586513	18502	2	1C
0005434586382	18502	3	1D
0005432928000	18502	4	1F
0005434586416	18502	5	2A
0005433193108	18502	6	2D
0005433193098	18502	7	2F
0005433724779	18502	8	3A
0005434586481	18502	9	3D
0005434586405	18502	10	4A
0005432928003	18502	11	4C
0005434586540	18502	12	4E
0005433193105	18502	13	4F
0005433193100	18502	14	5A
0005433524971	18502	15	5C
0005434586496	18502	16	5D
0005432968849	18502	17	5E
0005433524982	18502	18	5F
0005434586381	18502	19	6A
0005434586615	18502	20	6D
0005432928006	18502	21	6E
0005434586538	18502	22	6F
0005433193101	18502	23	7D
0005434586597	18502	24	7E
0005433525032	18502	25	7F
0005434514945	18502	26	8A
0005434586570	18502	27	8D
0005434586561	18502	28	8E
0005433193106	18502	29	8F
0005434586380	18502	30	9A
0005434586520	18502	31	9C
0005433524983	18502	32	9D
0005433193099	18502	33	9E
0005432928002	18502	34	9F
0005433524984	18502	35	10A
0005433524969	18502	36	10C
0005434586455	18502	37	10E
0005434586551	18502	38	10F
0005432928004	18502	39	11A
0005434586575	18502	40	11C
0005434586459	18502	41	11D
0005433193096	18502	42	11E
0005433524998	18502	43	12A
0005434586586	18502	44	12D
0005433193104	18502	45	12E
0005434586486	18502	46	12F
0005433724791	18502	47	13A
0005434586536	18502	48	13C
0005433193102	18502	49	13E
0005434586395	18502	50	14A
0005433524989	18502	51	14C
0005433193097	18502	52	14D
0005433724780	18502	53	14E
0005432968848	18502	54	14F
0005433724795	18502	55	15C
0005433193103	18502	56	15D
0005432928001	18502	57	16C
0005434586576	18502	58	16D
0005433525016	18502	59	16E
0005432968850	18502	60	16F
0005433524981	18502	61	17D
0005434514949	18502	62	17E
0005434586535	18502	63	17F
0005434586640	18502	64	18A
0005434586569	18502	65	18C
0005433524990	18502	66	18D
0005434586534	18502	67	18F
0005432928005	18502	68	18E
0005434586559	18502	69	19A
0005433193107	18502	70	19C
0005433193109	18502	71	19D
0005434586530	18502	72	19E
0005433525031	18502	73	19F
0005434586519	18502	74	20A
0005434586426	18502	75	20D
0005434586616	18502	76	20E
0005434586550	18502	77	20F
0005434344340	11450	1	1A
0005434344359	11450	2	1B
0005434344339	11450	3	1C
0005434344354	11450	4	1D
0005434142629	11450	5	2A
0005434344331	11450	6	2B
0005434344353	11450	7	2D
0005434344326	11450	8	3A
0005434344347	11450	9	3C
0005434344342	11450	10	3D
0005434344349	11450	11	4A
0005434344341	11450	12	4B
0005434344329	11450	13	4C
0005435305004	11450	14	4D
0005434344345	11450	15	5A
0005434344352	11450	16	5B
0005434344343	11450	17	5D
0005434344333	11450	18	5C
0005435305003	11450	19	6A
0005435305006	11450	20	6B
0005435305005	11450	21	6C
0005434344360	11450	22	6D
0005434344344	11450	23	7A
0005434344351	11450	24	7B
0005434344358	11450	25	7C
0005434344348	11450	26	7D
0005434344356	11450	27	18A
0005434344334	11450	28	18B
0005434344335	11450	29	18C
0005434344325	11450	30	19A
0005435302159	11450	31	19B
0005434142628	11450	32	19C
0005434142627	11450	33	19D
0005434344355	11450	34	20A
0005434344327	11450	35	20B
0005434344346	11450	36	20C
0005434344332	11450	37	20D
0005435302160	11450	38	21A
0005434344357	11450	39	21B
0005434344338	11450	40	21C
0005434344361	11450	41	21D
0005434344330	11450	42	22A
0005434344328	11450	43	22B
0005434344337	11450	44	22C
0005434344350	11450	45	22D
0005434344336	11450	46	23A
0005434142626	11450	47	23B
0005434344180	29794	1	1A
0005434344118	29794	2	1B
0005435305021	29794	3	1C
0005434344027	29794	4	1D
0005435305019	29794	5	2A
0005434344054	29794	6	2C
0005434343973	29794	7	2D
0005434343786	29794	8	3A
0005434344014	29794	9	3B
0005434344117	29794	10	3C
0005435305020	29794	11	3D
0005434343873	29794	12	4A
0005434344028	29794	13	4B
0005434344158	29794	14	4C
0005435304181	29794	15	4D
0005434344038	29794	16	5A
0005434343872	29794	17	5B
0005434344210	29794	18	5C
0005434343922	29794	19	5D
0005434343923	29794	20	6A
0005434344116	29794	21	6B
0005435304183	29794	22	6C
0005434142590	29794	23	6D
0005435304182	29794	24	7A
0005434343921	29794	25	7B
0005434344052	29794	26	7C
0005435304179	29794	27	7D
0005435305022	29794	28	18A
0005434142589	29794	29	18B
0005434344157	29794	30	18C
0005434344015	29794	31	18D
0005434344170	29794	32	19A
0005434344026	29794	33	19B
0005434343974	29794	34	19C
0005434343997	29794	35	19D
0005434344259	29794	36	20A
0005435304180	29794	37	20B
0005434344093	29794	38	20C
0005434142591	29794	39	20D
0005434344156	29794	40	21A
0005434343990	29794	41	21B
0005434343822	29794	42	21C
0005434344070	29794	43	21D
0005434344039	29794	44	22A
0005434344260	29794	45	22B
0005434343989	29794	46	22D
0005434343874	29794	47	23A
0005434344071	29794	48	23B
0005433415582	1278	1	2D
0005435824742	1278	2	2C
0005433415528	1278	3	2F
0005433415606	1278	4	3D
0005433415627	1278	5	4A
0005435824733	1278	6	4C
0005435824730	1278	7	4F
0005435824736	1278	8	4D
0005433415611	1278	9	5D
0005435824741	1278	10	5F
0005433415615	1278	11	6C
0005435824748	1278	12	6F
0005433415625	1278	13	7C
0005435824743	1278	14	7E
0005433415583	1278	15	7F
0005433415682	1278	16	8B
0005433415669	1278	17	8A
0005435824750	1278	18	9E
0005433415607	1278	19	10A
0005433415614	1278	20	10F
0005435824744	1278	21	11B
0005435824747	1278	22	11C
0005433415608	1278	23	11F
0005435824745	1278	24	11E
0005433415549	1278	25	12A
0005432284572	1278	26	12C
0005433415623	1278	27	12B
0005433415681	1278	28	12F
0005435824737	1278	29	13A
0005433415591	1278	30	13B
0005435824731	1278	31	13E
0005435824738	1278	32	14C
0005435824740	1278	33	14B
0005435824754	1278	34	14A
0005433415652	1278	35	14D
0005435824728	1278	36	14F
0005435824734	1278	37	14E
0005433415562	1278	38	15C
0005435824735	1278	39	16A
0005433415610	1278	40	16C
0005435824732	1278	41	16B
0005433415624	1278	42	16E
0005435824749	1278	43	17B
0005435824752	1278	44	17D
0005433415626	1278	45	17C
0005435824753	1278	46	17F
0005432284570	1278	47	17E
0005432284571	1278	48	18A
0005433415529	1278	49	18D
0005433415561	1278	50	19A
0005435824746	1278	51	19B
0005435824729	1278	52	19F
0005435824739	1278	53	20F
0005433415592	1278	54	20D
0005435824751	1278	55	21A
0005433415635	1278	56	21C
0005433415530	1278	57	21F
0005433415736	17978	1	1A
0005435824549	17978	2	2A
0005435824489	17978	3	1F
0005433415724	17978	4	3A
0005433415727	17978	5	2F
0005435824520	17978	6	4D
0005433415726	17978	7	6E
0005433415735	17978	8	6F
0005435824488	17978	9	7C
0005433415730	17978	10	7D
0005433415723	17978	11	7F
0005435824461	17978	12	9A
0005435824436	17978	13	9D
0005433415737	17978	14	10A
0005435824533	17978	15	10C
0005435824483	17978	16	10B
0005433415733	17978	17	11A
0005433415720	17978	18	10F
0005433415732	17978	19	11B
0005435824416	17978	20	12A
0005435824534	17978	21	12D
0005435824570	17978	22	12F
0005433415734	17978	23	13E
0005433415729	17978	24	14D
0005433415721	17978	25	14F
0005435824435	17978	26	15A
0005433415728	17978	27	15E
0005433415722	17978	28	16C
0005433415731	17978	29	16B
0005435824484	17978	30	16D
0005435824564	17978	31	16E
0005435824523	17978	32	17D
0005435824450	17978	33	17C
0005435824473	17978	34	18C
0005435824555	17978	35	19A
0005433415725	17978	36	19B
0005435824563	17978	37	20A
0005435824546	17978	38	20D
0005435824462	17978	39	21A
0005435824532	17978	40	20F
0005435824572	17978	41	21B
0005432784007	5637	1	1C
0005432784045	5637	2	1D
0005432784020	5637	3	2A
0005432784047	5637	4	2C
0005432784003	5637	5	2D
0005435242737	5637	6	2F
0005435242639	5637	7	3A
0005435242742	5637	8	3C
0005435242754	5637	9	3D
0005432784023	5637	10	3F
0005432784046	5637	11	4A
0005435242751	5637	12	4C
0005435242714	5637	13	4D
0005432784033	5637	14	4E
0005432784029	5637	15	5A
0005435242806	5637	16	5C
0005435242816	5637	17	5D
0005432784017	5637	18	5E
0005432784036	5637	19	5F
0005432784040	5637	20	6A
0005432784019	5637	21	6C
0005432784037	5637	22	6D
0005435476747	5637	23	6E
0005432784025	5637	24	6F
0005432783997	5637	25	7A
0005432784049	5637	26	7C
0005435242738	5637	27	7D
0005435242794	5637	28	7E
0005432784044	5637	29	7F
0005435242743	5637	30	8A
0005435242582	5637	31	8C
0005432784006	5637	32	8D
0005432784018	5637	33	8F
0005435242746	5637	34	9A
0005432784030	5637	35	9C
0005435476738	5637	36	9D
0005432784002	5637	37	9E
0005432783999	5637	38	9F
0005432784014	5637	39	10A
0005435242668	5637	40	10C
0005435476739	5637	41	10D
0005432784001	5637	42	10E
0005432784022	5637	43	10F
0005435242712	5637	44	11A
0005435476722	5637	45	11C
0005432784032	5637	46	11D
0005435242745	5637	47	11E
0005432784010	5637	48	11F
0005432784042	5637	49	12A
0005432784015	5637	50	12C
0005432144002	5637	51	12D
0005432784011	5637	52	12E
0005435242753	5637	53	12F
0005432784000	5637	54	13A
0005435242793	5637	55	13C
0005432784034	5637	56	13D
0005435242583	5637	57	13E
0005432784039	5637	58	13F
0005435242788	5637	59	14A
0005435242656	5637	60	14C
0005432784043	5637	61	14D
0005432784024	5637	62	14E
0005432784009	5637	63	14F
0005432784031	5637	64	15A
0005435242667	5637	65	15C
0005432784012	5637	66	15D
0005435476724	5637	67	15E
0005432784048	5637	68	15F
0005435242718	5637	69	16A
0005435476723	5637	70	16C
0005432784021	5637	71	16D
0005435242640	5637	72	16E
0005432784041	5637	73	16F
0005435242803	5637	74	17A
0005435242764	5637	75	17C
0005435242713	5637	76	17D
0005435242716	5637	77	17E
0005432784016	5637	78	17F
0005432784004	5637	79	18A
0005435242797	5637	80	18C
0005432783996	5637	81	18D
0005432784038	5637	82	18E
0005432784035	5637	83	18F
0005435476725	5637	84	19A
0005432784005	5637	85	19C
0005432784028	5637	86	19D
0005432783998	5637	87	19E
0005432784008	5637	88	19F
0005432784026	5637	89	20A
0005432784013	5637	90	20C
0005435242798	5637	91	20D
0005432784027	5637	92	20E
0005435242681	5637	93	20F
0005432783824	15356	1	1A
0005432783389	15356	2	1C
0005435242961	15356	3	1D
0005432783568	15356	4	1F
0005432783198	15356	5	2A
0005432783690	15356	6	2C
0005432783525	15356	7	2D
0005432783641	15356	8	2F
0005432783493	15356	9	3A
0005435476779	15356	10	3C
0005432783642	15356	11	3D
0005432783546	15356	12	3F
0005432783481	15356	13	4A
0005432783482	15356	14	4C
0005432783489	15356	15	4D
0005432783390	15356	16	4E
0005432783643	15356	17	4F
0005435242937	15356	18	5A
0005432783609	15356	19	5C
0005435242947	15356	20	5D
0005432783491	15356	21	5E
0005432783581	15356	22	5F
0005432783480	15356	23	6C
0005432783580	15356	24	6A
0005432783492	15356	25	6D
0005435242948	15356	26	6E
0005435242944	15356	27	6F
0005432783579	15356	28	7A
0005432783572	15356	29	7C
0005432783585	15356	30	7D
0005432783621	15356	31	7E
0005435476784	15356	32	7F
0005432783682	15356	33	8A
0005435476787	15356	34	8C
0005435242946	15356	35	8D
0005432783586	15356	36	8E
0005432783349	15356	37	8F
0005432783590	15356	38	9A
0005432783412	15356	39	9C
0005432783388	15356	40	9D
0005432783636	15356	41	9E
0005432783632	15356	42	9F
0005435242954	15356	43	10A
0005435476785	15356	44	10C
0005432783413	15356	45	10D
0005435242955	15356	46	10E
0005435242960	15356	47	10F
0005432783495	15356	48	11A
0005435242962	15356	49	11C
0005435242949	15356	50	11D
0005432783547	15356	51	11E
0005432783449	15356	52	11F
0005435476782	15356	53	12A
0005432783681	15356	54	12C
0005435242956	15356	55	12D
0005432783393	15356	56	12E
0005432783526	15356	57	12F
0005435476781	15356	58	13A
0005435242952	15356	59	13C
0005432783332	15356	60	13D
0005432783317	15356	61	13E
0005435242950	15356	62	13F
0005435476780	15356	63	14A
0005432783669	15356	64	14C
0005432783770	15356	65	14D
0005432783582	15356	66	14E
0005435242953	15356	67	14F
0005435242940	15356	68	15A
0005432783637	15356	69	15C
0005435242936	15356	70	15D
0005432783633	15356	71	15E
0005435242957	15356	72	16A
0005435476786	15356	73	15F
0005432783524	15356	74	16C
0005432783448	15356	75	16D
0005432783571	15356	76	16E
0005432783591	15356	77	16F
0005432783515	15356	78	17A
0005432783543	15356	79	17C
0005435242958	15356	80	17D
0005435242941	15356	81	17E
0005432783528	15356	82	17F
0005432783484	15356	83	18A
0005435242942	15356	84	18C
0005435242938	15356	85	18D
0005435476783	15356	86	18E
0005435242951	15356	87	18F
0005435242943	15356	88	19A
0005432783336	15356	89	19C
0005435242939	15356	90	19D
0005435242945	15356	91	19E
0005432783398	15356	92	19F
0005432783527	15356	93	20A
0005432783360	15356	94	20C
0005432783494	15356	95	20D
0005435242959	15356	96	20E
0005432783655	15356	97	20F
0005434463937	4349	1	1B
0005435850872	4349	2	1C
0005432848381	4349	3	1D
0005435850886	4349	4	2A
0005434463939	4349	5	2C
0005434462799	4349	6	2D
0005435850877	4349	7	3A
0005435850876	4349	8	3B
0005432848369	4349	9	3C
0005434462801	4349	10	3D
0005434462798	4349	11	4A
0005432848367	4349	12	5A
0005432848372	4349	13	6A
0005435850885	4349	14	6C
0005432848379	4349	15	7B
0005432848377	4349	16	7C
0005432848371	4349	17	7D
0005434462800	4349	18	18C
0005432848368	4349	19	18B
0005432848382	4349	20	19B
0005434463938	4349	21	20C
0005432848376	4349	22	20D
0005432848370	4349	23	21B
0005432848374	4349	24	21D
0005435850869	4349	25	22A
0005432848373	4349	26	22B
0005432848378	4349	27	22C
0005432848375	4349	28	22D
0005432848380	4349	29	23A
0005435850951	28865	1	1B
0005432848194	28865	2	2C
0005432848233	28865	3	3B
0005432848200	28865	4	4D
0005435850946	28865	5	5C
0005432848209	28865	6	5D
0005434461628	28865	7	6A
0005432848264	28865	8	6B
0005432848252	28865	9	6D
0005432848226	28865	10	7A
0005435850953	28865	11	7B
0005435850952	28865	12	7C
0005432848217	28865	13	7D
0005435850950	28865	14	18B
0005434461631	28865	15	19B
0005432848195	28865	16	19D
0005435850948	28865	17	20A
0005432848247	28865	18	21A
0005432848201	28865	19	21C
0005435850947	28865	20	22A
0005435850949	28865	21	22B
0005434925949	6243	1	1A
0005433497121	6243	2	1C
0005434925936	6243	3	1D
0005433497103	6243	4	1F
0005434925951	6243	5	2A
0005432075245	6243	6	2C
0005434925928	6243	7	2D
0005434925929	6243	8	2F
0005434443779	6243	9	3A
0005433497094	6243	10	3C
0005433497096	6243	11	3F
0005433497108	6243	12	4A
0005433497115	6243	13	4C
0005434925952	6243	14	4D
0005434925959	6243	15	4E
0005433497114	6243	16	4F
0005434443774	6243	17	5A
0005434925944	6243	18	5C
0005434925950	6243	19	5D
0005433497093	6243	20	5E
0005433497095	6243	21	5F
0005433497119	6243	22	6A
0005433497091	6243	23	6C
0005434443776	6243	24	6D
0005433497092	6243	25	6E
0005434443771	6243	26	6F
0005434925941	6243	27	7A
0005434925940	6243	28	7C
0005434925943	6243	29	7E
0005434443785	6243	30	7F
0005433497120	6243	31	8A
0005434443777	6243	32	8C
0005432075243	6243	33	8D
0005433497098	6243	34	8E
0005433497099	6243	35	8F
0005433497090	6243	36	9A
0005434443778	6243	37	9C
0005433497104	6243	38	9D
0005434925925	6243	39	9E
0005433497111	6243	40	9F
0005434925961	6243	41	10A
0005432075244	6243	42	10C
0005433497110	6243	43	10D
0005433497117	6243	44	10E
0005434925955	6243	45	10F
0005434925933	6243	46	11A
0005434925942	6243	47	11C
0005433497112	6243	48	11D
0005433497106	6243	49	11E
0005433497105	6243	50	11F
0005434925953	6243	51	12A
0005434925954	6243	52	12C
0005434925948	6243	53	12D
0005432075246	6243	54	12E
0005434925956	6243	55	12F
0005434925927	6243	56	13A
0005434443780	6243	57	13C
0005434925931	6243	58	13D
0005433497118	6243	59	13E
0005433497102	6243	60	13F
0005434443782	6243	61	14A
0005434925935	6243	62	14C
0005434925946	6243	63	14D
0005434443775	6243	64	14E
0005433497097	6243	65	14F
0005434925934	6243	66	15A
0005434925926	6243	67	15C
0005433497100	6243	68	15E
0005434443772	6243	69	15F
0005434925937	6243	70	16A
0005434925958	6243	71	16C
0005434925945	6243	72	16D
0005433497109	6243	73	16E
0005434925947	6243	74	16F
0005434925932	6243	75	17E
0005434443786	6243	76	17D
0005434925924	6243	77	17F
0005434925939	6243	78	18A
0005434443783	6243	79	18C
0005434925962	6243	80	18D
0005433497107	6243	81	18E
0005433497101	6243	82	18F
0005434443773	6243	83	19A
0005434443781	6243	84	19C
0005433497116	6243	85	19D
0005434925930	6243	86	19E
0005434925923	6243	87	19F
0005434925957	6243	88	20A
0005434925960	6243	89	20C
0005433497113	6243	90	20D
0005434925938	6243	91	20E
0005434443784	6243	92	20F
0005433496948	20327	1	1A
0005433496919	20327	2	1C
0005434925664	20327	3	1D
0005434925651	20327	4	1F
0005434443602	20327	5	2C
0005434925725	20327	6	2D
0005433496659	20327	7	2F
0005434443616	20327	8	3A
0005433496921	20327	9	3D
0005434925654	20327	10	3F
0005434925639	20327	11	4A
0005434925475	20327	12	4C
0005434443597	20327	13	4D
0005433496918	20327	14	4F
0005434925734	20327	15	5A
0005434925787	20327	16	5C
0005434925601	20327	17	5D
0005434925683	20327	18	5F
0005434925626	20327	19	6A
0005433496944	20327	20	6C
0005434925726	20327	21	6D
0005434925590	20327	22	6E
0005434443522	20327	23	6F
0005434925788	20327	24	7C
0005434443675	20327	25	7E
0005433496725	20327	26	8C
0005434925602	20327	27	8E
0005433496946	20327	28	8F
0005433496883	20327	29	9A
0005433496989	20327	30	9C
0005434443622	20327	31	9D
0005433496945	20327	32	9E
0005434443651	20327	33	9F
0005434443654	20327	34	10A
0005434925742	20327	35	10C
0005434443617	20327	36	10D
0005434443679	20327	37	10F
0005434443690	20327	38	11A
0005433496851	20327	39	11C
0005434925591	20327	40	11D
0005433496824	20327	41	11E
0005433497018	20327	42	11F
0005434925643	20327	43	12A
0005433496893	20327	44	12C
0005434925666	20327	45	12D
0005434925743	20327	46	12E
0005434925738	20327	47	12F
0005434443608	20327	48	13A
0005433496726	20327	49	13D
0005434925684	20327	50	13E
0005434443689	20327	51	13F
0005434925588	20327	52	14C
0005434925656	20327	53	14D
0005433496827	20327	54	14E
0005434443650	20327	55	14F
0005434925612	20327	56	15A
0005434925642	20327	57	15C
0005434925712	20327	58	15D
0005434925474	20327	59	15F
0005433496974	20327	60	16A
0005434443557	20327	61	16C
0005434443592	20327	62	16E
0005434925589	20327	63	16F
0005434925638	20327	64	17A
0005434443577	20327	65	17C
0005434925627	20327	66	17D
0005434925746	20327	67	17E
0005434443556	20327	68	17F
0005434925499	20327	69	18A
0005433496897	20327	70	18C
0005434443596	20327	71	19A
0005434925650	20327	72	19E
0005434925552	20327	73	19F
0005434925623	20327	74	20A
0005433496898	20327	75	20C
0005434925604	20327	76	20D
0005434925660	20327	77	20F
0005435242982	12160	1	1A
0005435242969	12160	2	1C
0005432783829	12160	3	1D
0005432783676	12160	4	1F
0005435242973	12160	5	2A
0005432783794	12160	6	2C
0005432783716	12160	7	2D
0005432783589	12160	8	2F
0005432783613	12160	9	3A
0005432783628	12160	10	3C
0005432783772	12160	11	3D
0005435242968	12160	12	3F
0005435242988	12160	13	4A
0005432783639	12160	14	4C
0005432783570	12160	15	4D
0005432783445	12160	16	4E
0005432783435	12160	17	4F
0005432783719	12160	18	5A
0005435242979	12160	19	5C
0005432783243	12160	20	5D
0005432783683	12160	21	5E
0005432783679	12160	22	5F
0005432783607	12160	23	6A
0005435242965	12160	24	6C
0005432783559	12160	25	6D
0005435242977	12160	26	6E
0005432783454	12160	27	6F
0005435242980	12160	28	7A
0005432783363	12160	29	7C
0005435242978	12160	30	7E
0005432783685	12160	31	7F
0005435242986	12160	32	8A
0005432783458	12160	33	8C
0005432783560	12160	34	8D
0005432783422	12160	35	8E
0005432783701	12160	36	8F
0005432783436	12160	37	9A
0005432783686	12160	38	9C
0005432783531	12160	39	9D
0005435242964	12160	40	9E
0005432783726	12160	41	9F
0005435242963	12160	42	10A
0005435242967	12160	43	10C
0005432783509	12160	44	10D
0005435242983	12160	45	10E
0005432783638	12160	46	10F
0005432783622	12160	47	11A
0005432783512	12160	48	11C
0005435242990	12160	49	11E
0005432783533	12160	50	11F
0005435242976	12160	51	12A
0005432783627	12160	52	12C
0005432783488	12160	53	12E
0005432783727	12160	54	12F
0005432783828	12160	55	13C
0005435242975	12160	56	13D
0005432783715	12160	57	13E
0005435242971	12160	58	13F
0005435242987	12160	59	14A
0005432783483	12160	60	14C
0005432783416	12160	61	14D
0005432783626	12160	62	14E
0005435242972	12160	63	14F
0005432783242	12160	64	15A
0005435242989	12160	65	15C
0005432783513	12160	66	15D
0005432783521	12160	67	15E
0005432783608	12160	68	15F
0005432783404	12160	69	16A
0005432783337	12160	70	16C
0005432783612	12160	71	16D
0005432783675	12160	72	16E
0005432783569	12160	73	16F
0005432783508	12160	74	17A
0005432783444	12160	75	17C
0005432783517	12160	76	17D
0005432783718	12160	77	17E
0005432783487	12160	78	17F
0005432783419	12160	79	18A
0005432783728	12160	80	18C
0005435242985	12160	81	18D
0005435242970	12160	82	18E
0005432783516	12160	83	18F
0005435242984	12160	84	19A
0005432783375	12160	85	19C
0005435242981	12160	86	19D
0005435242966	12160	87	19E
0005432783652	12160	88	19F
0005432783450	12160	89	20D
0005435242974	12160	90	20E
0005432783789	12160	91	20F
0005432783953	15429	1	1A
0005432783959	15429	2	1C
0005432783983	15429	3	1D
0005432783957	15429	4	1F
0005432783984	15429	5	2A
0005435242768	15429	6	2C
0005435242762	15429	7	2D
0005432783970	15429	8	2F
0005432783966	15429	9	3A
0005432783972	15429	10	3C
0005435242688	15429	11	3D
0005432783975	15429	12	3F
0005435242708	15429	13	4A
0005435242578	15429	14	4C
0005435242711	15429	15	4D
0005435242675	15429	16	4E
0005435242732	15429	17	4F
0005432783956	15429	18	5A
0005432783973	15429	19	5C
0005435242664	15429	20	5D
0005435242715	15429	21	5E
0005432783993	15429	22	6A
0005432783954	15429	23	6C
0005432783980	15429	24	6D
0005432783995	15429	25	6E
0005435242761	15429	26	6F
0005435242635	15429	27	7A
0005432783940	15429	28	7C
0005435242689	15429	29	7D
0005432783941	15429	30	7F
0005432783976	15429	31	8A
0005432783965	15429	32	8C
0005432783950	15429	33	8D
0005432783942	15429	34	8E
0005435242686	15429	35	8F
0005432783963	15429	36	9A
0005432783964	15429	37	9C
0005432783952	15429	38	9D
0005432783992	15429	39	9E
0005432783946	15429	40	9F
0005432783947	15429	41	10A
0005435242709	15429	42	10C
0005432783991	15429	43	10D
0005435242771	15429	44	10E
0005432783944	15429	45	10F
0005432783958	15429	46	11A
0005432783962	15429	47	11C
0005432783951	15429	48	11D
0005432783968	15429	49	11F
0005432783977	15429	50	12A
0005432783945	15429	51	12C
0005435242613	15429	52	12D
0005435242723	15429	53	12E
0005435242812	15429	54	12F
0005435242665	15429	55	13A
0005432783990	15429	56	13C
0005432783985	15429	57	13D
0005435242733	15429	58	13E
0005432783981	15429	59	13F
0005435242728	15429	60	14A
0005432783955	15429	61	14C
0005435242650	15429	62	14D
0005435242687	15429	63	14E
0005432783989	15429	64	14F
0005432783948	15429	65	15C
0005432783979	15429	66	15A
0005432783971	15429	67	15D
0005432783982	15429	68	15E
0005435242770	15429	69	15F
0005435242535	15429	70	16A
0005432783969	15429	71	16E
0005432783978	15429	72	17A
0005432783987	15429	73	17C
0005432783949	15429	74	17E
0005435242676	15429	75	18A
0005435242769	15429	76	18C
0005432783961	15429	77	18E
0005432783974	15429	78	18F
0005432783943	15429	79	19C
0005432783986	15429	80	19D
0005432783988	15429	81	19F
0005432783960	15429	82	20A
0005435242651	15429	83	20C
0005432783994	15429	84	20D
0005435242680	15429	85	20E
0005432783967	15429	86	20F
0005435913941	10080	1	1C
0005434877855	10080	2	1A
0005434877635	10080	3	1F
0005434877416	10080	4	2D
0005434877826	10080	5	2C
0005434877906	10080	6	3A
0005434877953	10080	7	2F
0005434877524	10080	8	3D
0005434877928	10080	9	3C
0005434877506	10080	10	4A
0005435913945	10080	11	3F
0005434877838	10080	12	4C
0005434877983	10080	13	4F
0005434877851	10080	14	5C
0005434877629	10080	15	5A
0005434878061	10080	16	5F
0005434877982	10080	17	5D
0005434877883	10080	18	6B
0005434878151	10080	19	6A
0005434877738	10080	20	6C
0005434877381	10080	21	6E
0005434877867	10080	22	7A
0005435913944	10080	23	6F
0005434878143	10080	24	7C
0005434878152	10080	25	7B
0005434877553	10080	26	7D
0005434877593	10080	27	7F
0005434878142	10080	28	7E
0005434877985	10080	29	8B
0005434877552	10080	30	8A
0005434877731	10080	31	8D
0005434877745	10080	32	8F
0005434877520	10080	33	8E
0005434877734	10080	34	9A
0005434877763	10080	35	9B
0005434877850	10080	36	9E
0005434877825	10080	37	9D
0005434877501	10080	38	10A
0005434877533	10080	39	10C
0005434877994	10080	40	10B
0005434877716	10080	41	10D
0005434877484	10080	42	11A
0005434877973	10080	43	11C
0005434877582	10080	44	11B
0005434877986	10080	45	11D
0005434877762	10080	46	11F
0005434877665	10080	47	12B
0005434878060	10080	48	12A
0005434877602	10080	49	12C
0005434878014	10080	50	12E
0005434877733	10080	51	12D
0005434877571	10080	52	13A
0005434878283	10080	53	12F
0005434877929	10080	54	13C
0005434877960	10080	55	13B
0005434878160	10080	56	13E
0005434877554	10080	57	13D
0005434877672	10080	58	13F
0005434877885	10080	59	14C
0005434877732	10080	60	14B
0005434878013	10080	61	14D
0005434877511	10080	62	14E
0005434878035	10080	63	15C
0005434877282	10080	64	15F
0005434877594	10080	65	15E
0005434877684	10080	66	15D
0005434877664	10080	67	16A
0005434877468	10080	68	16C
0005434877700	10080	69	16B
0005434878044	10080	70	16E
0005434877673	10080	71	16D
0005434877993	10080	72	17A
0005434877523	10080	73	17B
0005434877766	10080	74	17D
0005435913940	10080	75	17C
0005434910121	10080	76	17E
0005435913943	10080	77	18B
0005434877683	10080	78	18A
0005434877739	10080	79	17F
0005434877981	10080	80	18C
0005434878161	10080	81	18D
0005434877601	10080	82	19A
0005434910122	10080	83	18F
0005434878141	10080	84	19C
0005435913942	10080	85	19B
0005435913946	10080	86	19D
0005434878006	10080	87	19F
0005434877961	10080	88	20C
0005434877754	10080	89	20B
0005434877630	10080	90	20A
0005434877570	10080	91	20D
0005434878020	10080	92	20E
0005434878034	10080	93	21B
0005434910123	10080	94	21A
0005434878010	10080	95	21D
0005434877903	10080	96	21C
0005434877900	10080	97	21F
0005434877767	10080	98	21E
0005434878643	14621	1	1A
0005434910118	14621	2	1F
0005434878579	14621	3	1D
0005434878601	14621	4	1C
0005434878612	14621	5	2C
0005434878637	14621	6	2A
0005434878580	14621	7	2F
0005434758903	14621	8	2D
0005434878618	14621	9	3C
0005434878671	14621	10	3A
0005434878619	14621	11	3D
0005434878596	14621	12	3F
0005434878648	14621	13	4D
0005434878667	14621	14	4C
0005434878651	14621	15	5A
0005434878593	14621	16	4F
0005434878589	14621	17	5C
0005434878623	14621	18	5F
0005435913920	14621	19	6B
0005434878631	14621	20	6A
0005434878660	14621	21	6D
0005434878668	14621	22	6C
0005434878622	14621	23	7A
0005434878666	14621	24	6F
0005434878624	14621	25	7C
0005434878610	14621	26	7B
0005434878616	14621	27	7E
0005434878664	14621	28	7D
0005434878630	14621	29	8A
0005434910117	14621	30	7F
0005434878665	14621	31	8C
0005434878602	14621	32	8B
0005434878620	14621	33	8D
0005434878609	14621	34	8F
0005434878594	14621	35	8E
0005434878608	14621	36	9A
0005434878661	14621	37	9D
0005434878653	14621	38	9B
0005434878604	14621	39	9E
0005434878611	14621	40	10A
0005434878636	14621	41	9F
0005434878614	14621	42	10C
0005434878625	14621	43	10E
0005434878642	14621	44	10D
0005434878603	14621	45	11A
0005434878626	14621	46	10F
0005435913918	14621	47	11B
0005434878617	14621	48	11D
0005434878633	14621	49	11C
0005434878650	14621	50	11F
0005434878605	14621	51	11E
0005434878644	14621	52	12A
0005434878647	14621	53	12D
0005434878629	14621	54	12C
0005435913912	14621	55	12F
0005434878600	14621	56	12E
0005434878659	14621	57	13A
0005435913913	14621	58	13B
0005434878657	14621	59	13E
0005434758902	14621	60	13D
0005434878606	14621	61	14A
0005434878584	14621	62	13F
0005434878613	14621	63	14B
0005434878615	14621	64	14E
0005434878599	14621	65	14D
0005434878639	14621	66	15A
0005434878634	14621	67	15C
0005434878669	14621	68	15B
0005434878645	14621	69	15F
0005434878635	14621	70	15E
0005434878582	14621	71	15D
0005434910102	14621	72	16B
0005434878585	14621	73	16A
0005435913907	14621	74	16E
0005434878588	14621	75	16D
0005434878646	14621	76	16F
0005435913917	14621	77	17B
0005434878607	14621	78	17A
0005434878632	14621	79	17D
0005434878595	14621	80	17C
0005434878598	14621	81	17F
0005434878662	14621	82	17E
0005434878590	14621	83	18A
0005434878641	14621	84	18C
0005434878628	14621	85	18B
0005434878663	14621	86	18E
0005434878621	14621	87	18D
0005434878586	14621	88	19A
0005434758904	14621	89	18F
0005434878592	14621	90	19C
0005434878597	14621	91	19B
0005434878591	14621	92	19E
0005434878652	14621	93	19D
0005434878638	14621	94	20A
0005434878587	14621	95	19F
0005434878583	14621	96	20C
0005434878649	14621	97	20B
0005434878670	14621	98	20D
0005434878581	14621	99	20E
0005434878654	14621	100	21A
0005434878656	14621	101	20F
0005435913921	14621	102	21C
0005434878640	14621	103	21B
0005434878627	14621	104	21E
0005434878655	14621	105	21D
0005434878658	14621	106	21F
0005434251928	9264	1	1A
0005434251915	9264	2	1B
0005434251906	9264	3	1D
0005434251927	9264	4	3D
0005434251940	9264	5	4A
0005434251902	9264	6	4B
0005434251948	9264	7	4C
0005435660179	9264	8	4D
0005435660188	9264	9	5B
0005434251909	9264	10	5D
0005434251910	9264	11	6A
0005435660184	9264	12	6B
0005434251905	9264	13	7B
0005434251914	9264	14	7C
0005435660180	9264	15	7D
0005434251916	9264	16	18A
0005435660181	9264	17	18B
0005435660189	9264	18	19B
0005435660186	9264	19	20A
0005435660183	9264	20	20B
0005434251888	9264	21	21A
0005435660182	9264	22	21B
0005435660185	9264	23	21D
0005434251941	9264	24	22B
0005435660187	9264	25	22C
0005434251925	9264	26	22D
0005434252008	24672	1	1C
0005435660099	24672	2	2A
0005434252006	24672	3	2D
0005434252003	24672	4	3B
0005435660068	24672	5	3D
0005435660046	24672	6	4A
0005434252002	24672	7	4B
0005434252007	24672	8	5A
0005435660093	24672	9	6A
0005435660065	24672	10	6C
0005434252005	24672	11	6D
0005435660064	24672	12	7B
0005435660076	24672	13	18A
0005434252004	24672	14	20A
0005435660047	24672	15	21D
0005434252001	24672	16	22A
0005435660098	24672	17	22B
0005433680764	2766	1	1A
0005432966810	2766	2	1D
0005433680739	2766	3	1F
0005432966828	2766	4	2A
0005432966783	2766	5	2C
0005432966820	2766	6	2D
0005433680758	2766	7	2F
0005433684427	2766	8	3A
0005432966829	2766	9	3C
0005433680745	2766	10	3F
0005433680762	2766	11	4A
0005433680779	2766	12	4C
0005433680772	2766	13	4F
0005433680756	2766	14	5A
0005433680744	2766	15	5C
0005432966811	2766	16	5D
0005432966697	2766	17	5E
0005433680778	2766	18	5F
0005432222803	2766	19	6A
0005432222805	2766	20	6C
0005432966890	2766	21	6D
0005432966784	2766	22	6F
0005432966806	2766	23	7A
0005433680751	2766	24	7C
0005433680748	2766	25	7D
0005433680759	2766	26	7E
0005433680765	2766	27	7F
0005433680769	2766	28	8A
0005433680780	2766	29	8C
0005432966850	2766	30	8D
0005433680747	2766	31	8E
0005432966948	2766	32	8F
0005432966851	2766	33	9A
0005432966809	2766	34	9C
0005433680742	2766	35	9D
0005433680781	2766	36	9E
0005433680763	2766	37	9F
0005433680777	2766	38	10A
0005433680736	2766	39	10C
0005433680771	2766	40	10D
0005432966803	2766	41	10E
0005433680767	2766	42	10F
0005433680746	2766	43	11A
0005432966911	2766	44	11C
0005433680737	2766	45	11D
0005432966835	2766	46	11F
0005433680768	2766	47	12A
0005432222806	2766	48	12C
0005432966772	2766	49	12D
0005432966819	2766	50	12E
0005433680738	2766	51	12F
0005433680749	2766	52	13A
0005433680776	2766	53	13D
0005433680754	2766	54	13F
0005432966844	2766	55	14A
0005432966782	2766	56	14C
0005433680761	2766	57	14D
0005433680752	2766	58	14E
0005432966796	2766	59	14F
0005433684428	2766	60	15A
0005433680775	2766	61	15C
0005433680770	2766	62	15D
0005433680735	2766	63	15E
0005433680743	2766	64	15F
0005432966902	2766	65	16A
0005433680753	2766	66	16C
0005432966879	2766	67	16D
0005433680766	2766	68	16F
0005433680750	2766	69	17A
0005433680740	2766	70	17C
0005433680755	2766	71	17D
0005433680774	2766	72	17E
0005432966837	2766	73	17F
0005433680760	2766	74	18A
0005432222804	2766	75	18D
0005432966836	2766	76	18F
0005432966797	2766	77	18E
0005432222802	2766	78	19A
0005433680773	2766	79	19C
0005433680783	2766	80	19D
0005432966791	2766	81	19E
0005433680782	2766	82	19F
0005432966957	2766	83	20A
0005432222801	2766	84	20C
0005433680757	2766	85	20D
0005433680741	2766	86	20F
0005433687689	29189	1	1A
0005433680399	29189	2	1C
0005432967035	29189	3	1D
0005432967036	29189	4	1F
0005433680280	29189	5	2A
0005433680232	29189	6	2C
0005433687699	29189	7	2D
0005433680397	29189	8	3A
0005433680558	29189	9	3C
0005433680243	29189	10	3D
0005433680152	29189	11	3F
0005433680322	29189	12	4A
0005433680328	29189	13	4C
0005433687700	29189	14	4D
0005432967032	29189	15	4E
0005433680442	29189	16	4F
0005433687693	29189	17	5A
0005432967037	29189	18	5C
0005433680327	29189	19	5D
0005433680562	29189	20	5E
0005433680387	29189	21	5F
0005433680643	29189	22	6A
0005432005224	29189	23	6C
0005433680493	29189	24	6D
0005433680303	29189	25	6E
0005433680217	29189	26	6F
0005433680324	29189	27	7A
0005433680323	29189	28	7C
0005433680245	29189	29	7E
0005433680283	29189	30	7D
0005432967042	29189	31	7F
0005432967052	29189	32	8A
0005432967039	29189	33	8C
0005433680515	29189	34	8D
0005433680502	29189	35	8E
0005433687698	29189	36	8F
0005433680252	29189	37	9A
0005433680207	29189	38	9C
0005433680279	29189	39	9D
0005433680434	29189	40	9E
0005433680384	29189	41	9F
0005433680563	29189	42	10A
0005432967033	29189	43	10C
0005433680365	29189	44	10D
0005433680582	29189	45	10E
0005432967050	29189	46	10F
0005432967040	29189	47	11A
0005432967044	29189	48	11C
0005432967045	29189	49	11D
0005433680485	29189	50	11E
0005432967048	29189	51	11F
0005432967029	29189	52	12A
0005432967049	29189	53	12C
0005433680246	29189	54	12D
0005432967051	29189	55	12E
0005433680431	29189	56	12F
0005433680410	29189	57	13A
0005433680514	29189	58	13C
0005433680412	29189	59	13D
0005433680486	29189	60	13E
0005432967041	29189	61	13F
0005433680127	29189	62	14A
0005433684416	29189	63	14C
0005433680426	29189	64	14D
0005433680544	29189	65	14E
0005433680437	29189	66	14F
0005433680639	29189	67	15A
0005432005226	29189	68	15C
0005433690917	29189	69	15D
0005433680398	29189	70	15E
0005432967038	29189	71	15F
0005433690918	29189	72	16A
0005433680404	29189	73	16C
0005433680530	29189	74	16D
0005433680350	29189	75	16E
0005433680516	29189	76	16F
0005432967053	29189	77	17A
0005433690924	29189	78	17C
0005432967034	29189	79	17D
0005433690923	29189	80	17E
0005433680302	29189	81	17F
0005433680331	29189	82	18A
0005432967046	29189	83	18C
0005432967047	29189	84	18D
0005433680333	29189	85	18E
0005432967031	29189	86	18F
0005433680366	29189	87	19A
0005433680208	29189	88	19C
0005432967028	29189	89	19D
0005432967043	29189	90	19E
0005433680149	29189	91	19F
0005433680108	29189	92	20A
0005432967030	29189	93	20C
0005433680421	29189	94	20D
0005433680438	29189	95	20E
0005432005225	29189	96	20F
0005433614938	9313	1	1A
0005433633943	9313	2	1C
0005433614896	9313	3	1F
0005432755088	9313	4	1D
0005433633937	9313	5	2C
0005433614898	9313	6	2D
0005433614946	9313	7	3A
0005433614936	9313	8	2F
0005433614932	9313	9	3D
0005433614902	9313	10	3C
0005433577862	9313	11	3F
0005433614915	9313	12	4A
0005433633940	9313	13	4C
0005433614886	9313	14	4F
0005433614883	9313	15	4D
0005433614926	9313	16	5C
0005434163527	9313	17	5F
0005433614941	9313	18	5D
0005433633913	9313	19	6A
0005433614952	9313	20	6C
0005433633925	9313	21	6F
0005433633917	9313	22	6D
0005434152775	9313	23	7A
0005433614951	9313	24	7C
0005433614919	9313	25	8A
0005433633918	9313	26	7F
0005433614907	9313	27	8C
0005433614887	9313	28	8E
0005433614913	9313	29	8F
0005433633923	9313	30	9B
0005433633941	9313	31	9D
0005433614954	9313	32	9C
0005433614916	9313	33	9E
0005433633926	9313	34	10A
0005433614933	9313	35	9F
0005432755089	9313	36	10B
0005433614937	9313	37	10C
0005433577859	9313	38	10F
0005433614895	9313	39	10E
0005433614924	9313	40	11C
0005433633929	9313	41	11E
0005433614934	9313	42	11D
0005433633932	9313	43	11F
0005433614892	9313	44	12A
0005433614912	9313	45	12B
0005432145118	9313	46	12D
0005434153524	9313	47	13A
0005434152772	9313	48	12E
0005433614900	9313	49	13B
0005433614922	9313	50	13C
0005433614914	9313	51	13D
0005434272185	9313	52	13F
0005433633942	9313	53	13E
0005433633936	9313	54	14A
0005433633912	9313	55	14B
0005433577861	9313	56	14E
0005433633934	9313	57	14D
0005433614953	9313	58	14F
0005433633927	9313	59	15C
0005433633911	9313	60	15B
0005433614944	9313	61	15E
0005433614942	9313	62	15D
0005434163575	9313	63	15F
0005433614920	9313	64	16A
0005433614904	9313	65	16B
0005433614897	9313	66	16D
0005433633933	9313	67	16C
0005433633944	9313	68	16F
0005433614949	9313	69	16E
0005433577854	9313	70	17B
0005434163567	9313	71	17A
0005433633922	9313	72	17C
0005434163609	9313	73	17D
0005434269087	9313	74	17F
0005433614927	9313	75	17E
0005433577864	9313	76	18A
0005433614921	9313	77	18C
0005433633920	9313	78	18D
0005433633939	9313	79	18E
0005433633938	9313	80	19B
0005434163559	9313	81	18F
0005434163526	9313	82	19C
0005433577865	9313	83	19D
0005433614903	9313	84	19E
0005433633924	9313	85	20B
0005433614935	9313	86	20A
0005434163568	9313	87	20C
0005433633914	9313	88	20E
0005433614911	9313	89	20D
0005433614923	9313	90	20F
0005433614893	9313	91	21A
0005433614888	9313	92	21B
0005434272186	9313	93	21D
0005433614885	9313	94	21C
0005433614931	9313	95	21E
0005433614894	9313	96	22A
0005433614940	9313	97	22B
0005433614918	9313	98	22C
0005433614950	9313	99	22D
0005433614945	9313	100	22F
0005433614955	9313	101	22E
0005433614890	9313	102	23C
0005433577858	9313	103	23B
0005433633921	9313	104	24A
0005433633928	9313	105	24B
0005434163558	9313	106	24D
0005433614943	9313	107	24C
0005433614939	9313	108	24F
0005433633935	9313	109	24E
0005433614889	9313	110	25A
0005433633916	9313	111	25C
0005433633919	9313	112	25B
0005433614884	9313	113	25D
0005433614905	9313	114	25E
0005433577855	9313	115	26A
0005432755087	9313	116	25F
0005433633945	9313	117	26B
0005432756861	9313	118	26D
0005433577863	9313	119	26C
0005433577857	9313	120	26E
0005433614928	9313	121	27A
0005434152773	9313	122	27C
0005433614956	9313	123	27B
0005433614899	9313	124	27D
0005433614925	9313	125	27F
0005433614908	9313	126	28B
0005433614930	9313	127	28D
0005433614929	9313	128	28C
0005433614947	9313	129	28F
0005433614909	9313	130	29A
0005433614957	9313	131	29B
0005433633915	9313	132	29D
0005433614910	9313	133	29C
0005433577856	9313	134	29E
0005433633931	9313	135	29F
0005433614948	9313	136	30B
0005432756862	9313	137	30A
0005434163566	9313	138	30C
0005433577860	9313	139	30E
0005433633930	9313	140	30D
0005433614891	9313	141	31A
0005433614917	9313	142	31C
0005433614906	9313	143	31B
0005433577866	9313	144	31D
0005433614901	9313	145	31F
0005433577686	25245	1	1A
0005433614142	25245	2	1C
0005433614325	25245	3	1F
0005432751500	25245	4	1D
0005433614259	25245	5	2A
0005433614644	25245	6	2C
0005433633576	25245	7	2D
0005432755058	25245	8	3A
0005433614357	25245	9	2F
0005433614319	25245	10	3C
0005433633657	25245	11	3D
0005433633427	25245	12	4A
0005433614455	25245	13	3F
0005433614128	25245	14	4C
0005433614293	25245	15	4D
0005433633581	25245	16	5A
0005433633428	25245	17	4F
0005433614129	25245	18	5C
0005432755057	25245	19	5F
0005434152785	25245	20	5D
0005433577748	25245	21	6A
0005433633543	25245	22	6C
0005434152782	25245	23	6D
0005432751489	25245	24	7A
0005433614153	25245	25	6F
0005433614331	25245	26	7D
0005433614450	25245	27	7C
0005433614451	25245	28	7F
0005433633716	25245	29	8A
0005433614294	25245	30	8B
0005433633659	25245	31	8C
0005433614014	25245	32	8E
0005433614391	25245	33	9A
0005433633721	25245	34	9C
0005433614166	25245	35	9E
0005432751499	25245	36	9F
0005433577685	25245	37	10A
0005433633702	25245	38	10D
0005433577701	25245	39	10C
0005433614079	25245	40	11A
0005433614386	25245	41	10F
0005434152791	25245	42	11B
0005433614261	25245	43	11C
0005433614152	25245	44	11D
0005434152786	25245	45	11E
0005433633750	25245	46	12A
0005433633568	25245	47	11F
0005432755046	25245	48	12B
0005434152783	25245	49	12C
0005433577776	25245	50	12E
0005432755037	25245	51	12D
0005433633618	25245	52	12F
0005433614272	25245	53	13B
0005433577744	25245	54	13C
0005433577768	25245	55	13D
0005433633722	25245	56	13E
0005433614401	25245	57	14A
0005433614324	25245	58	13F
0005433614348	25245	59	14C
0005432751488	25245	60	14B
0005433614238	25245	61	14E
0005433614552	25245	62	14D
0005433633550	25245	63	14F
0005433614285	25245	64	15B
0005433614445	25245	65	15C
0005433614220	25245	66	15D
0005433614398	25245	67	15E
0005433614429	25245	68	15F
0005433614304	25245	69	16B
0005433633613	25245	70	16D
0005433614241	25245	71	16C
0005433577773	25245	72	16E
0005433633616	25245	73	16F
0005432755048	25245	74	17B
0005434152788	25245	75	17A
0005432755041	25245	76	17C
0005433614423	25245	77	17D
0005433633612	25245	78	17F
0005434152792	25245	79	17E
0005434152789	25245	80	18A
0005433614017	25245	81	18C
0005433633689	25245	82	18B
0005433614179	25245	83	18E
0005433614306	25245	84	18D
0005433633751	25245	85	19B
0005433633542	25245	86	18F
0005433577723	25245	87	19C
0005433614012	25245	88	19D
0005432751497	25245	89	20A
0005433614452	25245	90	19E
0005433614115	25245	91	20B
0005433614262	25245	92	20C
0005433614255	25245	93	20E
0005433633594	25245	94	20D
0005433614317	25245	95	20F
0005432751501	25245	96	21A
0005433614311	25245	97	21C
0005433633756	25245	98	21B
0005433633561	25245	99	21D
0005432751490	25245	100	21E
0005432755063	25245	101	22A
0005433577775	25245	102	21F
0005432751491	25245	103	22B
0005433577779	25245	104	22D
0005433614591	25245	105	22F
0005433633633	25245	106	22E
0005432755039	25245	107	23A
0005433633712	25245	108	23C
0005433614456	25245	109	23B
0005432755029	25245	110	23D
0005433577780	25245	111	23E
0005433614434	25245	112	24A
0005433614292	25245	113	23F
0005433614198	25245	114	24B
0005433614253	25245	115	24D
0005433633569	25245	116	24F
0005432755062	25245	117	24E
0005433614197	25245	118	25A
0005433614201	25245	119	25B
0005433614446	25245	120	25D
0005432755045	25245	121	25C
0005433614303	25245	122	25F
0005433614330	25245	123	25E
0005433614457	25245	124	26B
0005432751496	25245	125	26A
0005432751515	25245	126	26C
0005433614141	25245	127	26E
0005433633619	25245	128	26D
0005433614318	25245	129	26F
0005433613946	25245	130	27A
0005433614440	25245	131	27C
0005433614154	25245	132	27B
0005432755040	25245	133	27E
0005433614078	25245	134	27D
0005433577626	25245	135	28A
0005434152787	25245	136	27F
0005434152784	25245	137	28B
0005432755042	25245	138	28D
0005433614034	25245	139	28F
0005433633635	25245	140	29A
0005433614013	25245	141	29C
0005433614077	25245	142	29B
0005433633658	25245	143	29D
0005433614221	25245	144	29F
0005433614524	25245	145	29E
0005433614180	25245	146	30A
0005433614018	25245	147	30B
0005434152790	25245	148	30C
0005433614323	25245	149	30E
0005433614291	25245	150	30D
0005433633620	25245	151	30F
0005433633399	25245	152	31B
0005433577781	25245	153	31A
0005433613947	25245	154	31C
0005433614143	25245	155	31D
0005433633582	25245	156	31E
0005432184963	4198	1	1F
0005435947234	4198	2	2A
0005435986799	4198	3	4F
0005432184961	4198	4	5H
0005435947217	4198	5	13E
0005435986797	4198	6	14A
0005435947168	4198	7	14F
0005432571306	4198	8	18B
0005435947162	4198	9	19D
0005435947233	4198	10	21F
0005435856196	4198	11	21H
0005434271308	4198	12	22A
0005435947163	4198	13	23H
0005432571307	4198	14	24H
0005435947226	4198	15	25D
0005432571293	4198	16	25E
0005435947160	4198	17	25F
0005435947215	4198	18	30G
0005432571298	4198	19	31B
0005435947227	4198	20	31E
0005435947214	4198	21	31H
0005432571301	4198	22	32F
0005432571292	4198	23	34B
0005434271298	4198	24	34E
0005435787335	4198	25	34G
0005435986798	4198	26	35E
0005435947169	4198	27	36H
0005435986795	4198	28	37D
0005435986794	4198	29	37F
0005435986796	4198	30	38D
0005432184962	4198	31	38G
0005435947322	26563	1	2F
0005432571339	26563	2	5F
0005435856222	26563	3	11B
0005435856221	26563	4	12A
0005435856223	26563	5	13A
0005435947313	26563	6	13B
0005435947317	26563	7	13F
0005435947316	26563	8	14F
0005435947320	26563	9	18G
0005435947315	26563	10	19A
0005435947314	26563	11	19G
0005435856220	26563	12	20D
0005435947310	26563	13	20F
0005435947312	26563	14	23F
0005432571338	26563	15	24A
0005435947318	26563	16	23H
0005435947309	26563	17	28A
0005435947319	26563	18	30H
0005432571341	26563	19	31B
0005435947323	26563	20	31A
0005435947311	26563	21	35G
0005435947321	26563	22	37F
0005435787365	26563	23	38D
0005432571340	26563	24	38E
0005433569324	346	1	1A
0005432948169	346	2	1D
0005433569314	346	3	2A
0005433569343	346	4	1F
0005433569353	346	5	2C
0005432948228	346	6	3A
0005433569307	346	7	2F
0005432948335	346	8	3C
0005433569358	346	9	3D
0005433569356	346	10	4A
0005433074627	346	11	3F
0005433569347	346	12	4F
0005433569317	346	13	4D
0005433074706	346	14	5A
0005433074707	346	15	5C
0005433074592	346	16	5F
0005433074638	346	17	5D
0005433129253	346	18	6A
0005432238964	346	19	6D
0005432948290	346	20	6C
0005432948150	346	21	6F
0005433074414	346	22	7A
0005433569338	346	23	7C
0005433569329	346	24	7F
0005433074637	346	25	7D
0005433074449	346	26	8A
0005433074450	346	27	8E
0005433569344	346	28	8D
0005433074458	346	29	9A
0005433569334	346	30	8F
0005432948285	346	31	9C
0005432948167	346	32	9D
0005433569354	346	33	9F
0005432238959	346	34	9E
0005433569348	346	35	10B
0005433074587	346	36	10C
0005433569332	346	37	10E
0005433074673	346	38	10D
0005432948453	346	39	10F
0005433569316	346	40	11B
0005432948174	346	41	11A
0005433074554	346	42	11C
0005433134106	346	43	11E
0005432948226	346	44	11D
0005433074660	346	45	11F
0005432948347	346	46	12A
0005433569359	346	47	12B
0005433074456	346	48	12D
0005433074464	346	49	12C
0005433074459	346	50	12E
0005432948452	346	51	12F
0005433569318	346	52	13B
0005433569315	346	53	13A
0005433569350	346	54	13C
0005432948173	346	55	13D
0005433569330	346	56	13F
0005432948168	346	57	13E
0005433569333	346	58	14C
0005433129252	346	59	14B
0005433569339	346	60	14E
0005432238961	346	61	14D
0005432948220	346	62	15A
0005432948315	346	63	14F
0005432948229	346	64	15B
0005432948219	346	65	15C
0005433569349	346	66	15D
0005433569312	346	67	15E
0005433074511	346	68	16A
0005433569319	346	69	15F
0005433074470	346	70	16C
0005433569335	346	71	16B
0005432948165	346	72	16D
0005432948144	346	73	16F
0005433074578	346	74	17B
0005433569355	346	75	17A
0005433569311	346	76	17C
0005433569313	346	77	17D
0005432948204	346	78	17F
0005433074403	346	79	17E
0005433074597	346	80	18A
0005432948271	346	81	18B
0005433569304	346	82	18D
0005432948370	346	83	18C
0005433074652	346	84	18E
0005433569323	346	85	19C
0005433134103	346	86	19D
0005433569322	346	87	19E
0005433569357	346	88	20B
0005433074457	346	89	20A
0005433074692	346	90	20C
0005432238962	346	91	20E
0005433074552	346	92	20D
0005433074448	346	93	20F
0005433569346	346	94	21A
0005433569306	346	95	21C
0005433569305	346	96	21B
0005433074551	346	97	21D
0005433569309	346	98	22A
0005432948269	346	99	21F
0005433569320	346	100	22B
0005433569345	346	101	22D
0005432948099	346	102	22C
0005432948170	346	103	22E
0005433569340	346	104	23A
0005433134113	346	105	23C
0005433569325	346	106	23B
0005432948151	346	107	23D
0005433569301	346	108	23E
0005433569300	346	109	24A
0005433569331	346	110	23F
0005432948372	346	111	24C
0005433074469	346	112	24E
0005433074651	346	113	24D
0005432948263	346	114	24F
0005432948383	346	115	25A
0005433074626	346	116	25C
0005433569321	346	117	25B
0005433074718	346	118	25E
0005432948205	346	119	25D
0005433074486	346	120	25F
0005432948237	346	121	26B
0005432238960	346	122	26A
0005433074598	346	123	26D
0005433074687	346	124	26E
0005432948236	346	125	26F
0005433569336	346	126	27A
0005433569342	346	127	27C
0005433074708	346	128	27D
0005433569341	346	129	27F
0005433569302	346	130	27E
0005433074485	346	131	28B
0005432948166	346	132	28C
0005432948130	346	133	28E
0005433569303	346	134	28D
0005433074610	346	135	28F
0005433569351	346	136	29B
0005433569328	346	137	29C
0005433074426	346	138	29E
0005433569337	346	139	29F
0005432948227	346	140	30B
0005433569310	346	141	30A
0005432948314	346	142	30D
0005433074661	346	143	30C
0005433074563	346	144	30F
0005433569352	346	145	30E
0005433569326	346	146	31A
0005433569327	346	147	31C
0005432238963	346	148	31B
0005432948273	346	149	31E
0005432948291	346	150	31D
0005433569308	346	151	31F
0005432948609	11577	1	1A
0005432948601	11577	2	1C
0005433568624	11577	3	1D
0005432948634	11577	4	2A
0005433074830	11577	5	1F
0005432948608	11577	6	2D
0005433568473	11577	7	2C
0005432948605	11577	8	3A
0005433568649	11577	9	2F
0005432192331	11577	10	3D
0005432948623	11577	11	4A
0005433074818	11577	12	3F
0005433074827	11577	13	4D
0005433074819	11577	14	4C
0005433568633	11577	15	4F
0005433568727	11577	16	5A
0005433568600	11577	17	5D
0005433568611	11577	18	6A
0005432948627	11577	19	5F
0005433568567	11577	20	6C
0005433568506	11577	21	6F
0005432948618	11577	22	7A
0005433568482	11577	23	7D
0005433568687	11577	24	7C
0005433568574	11577	25	8A
0005432948635	11577	26	7F
0005433568726	11577	27	8B
0005433568766	11577	28	8C
0005433074822	11577	29	9A
0005433074837	11577	30	8F
0005433568428	11577	31	9B
0005433568676	11577	32	9C
0005433568721	11577	33	9D
0005433568731	11577	34	9F
0005433568707	11577	35	10A
0005433568746	11577	36	10B
0005433568581	11577	37	10D
0005432948626	11577	38	10C
0005433074834	11577	39	10E
0005433131725	11577	40	10F
0005433568566	11577	41	11B
0005433134157	11577	42	11A
0005433568734	11577	43	11C
0005433074833	11577	44	11D
0005433568736	11577	45	11E
0005433074809	11577	46	12A
0005433074817	11577	47	12B
0005432948602	11577	48	12C
0005433568718	11577	49	12E
0005433568583	11577	50	12D
0005433568541	11577	51	12F
0005433134158	11577	52	13B
0005433568780	11577	53	13A
0005433568685	11577	54	13F
0005433131728	11577	55	13E
0005432948617	11577	56	14A
0005433568667	11577	57	14B
0005432948604	11577	58	14D
0005432948624	11577	59	14C
0005433074815	11577	60	14F
0005433074836	11577	61	14E
0005433568540	11577	62	15A
0005433568392	11577	63	15C
0005432948638	11577	64	15B
0005433074835	11577	65	15E
0005432948598	11577	66	15D
0005433568759	11577	67	15F
0005433568725	11577	68	16A
0005433568632	11577	69	16B
0005433568547	11577	70	16D
0005432948637	11577	71	16C
0005432948630	11577	72	16E
0005433074813	11577	73	16F
0005432948631	11577	74	17A
0005433568618	11577	75	17B
0005433074826	11577	76	17E
0005432948619	11577	77	17D
0005433568481	11577	78	17F
0005433568691	11577	79	18B
0005432948614	11577	80	18D
0005433074829	11577	81	18E
0005433131727	11577	82	18F
0005432948639	11577	83	19B
0005433568619	11577	84	19C
0005433074811	11577	85	19E
0005433568657	11577	86	20B
0005432948611	11577	87	20A
0005432948607	11577	88	20C
0005433568705	11577	89	20D
0005433568805	11577	90	20F
0005432948603	11577	91	20E
0005433568647	11577	92	21A
0005432948600	11577	93	21D
0005432948606	11577	94	21C
0005433074820	11577	95	22A
0005432948599	11577	96	21F
0005432192333	11577	97	22B
0005432948625	11577	98	22C
0005432948622	11577	99	22E
0005432948613	11577	100	22D
0005433568505	11577	101	22F
0005433568784	11577	102	23A
0005433134156	11577	103	23C
0005433074816	11577	104	23B
0005432948629	11577	105	23F
0005433568565	11577	106	23E
0005433074831	11577	107	24A
0005433074824	11577	108	24B
0005433568769	11577	109	24D
0005432192332	11577	110	24C
0005433074812	11577	111	24E
0005433568730	11577	112	24F
0005433074823	11577	113	25A
0005433568699	11577	114	25C
0005433568621	11577	115	25D
0005433568634	11577	116	25E
0005433131726	11577	117	26A
0005432948633	11577	118	26B
0005433568749	11577	119	26C
0005433568706	11577	120	26D
0005433568568	11577	121	26F
0005433568735	11577	122	26E
0005433568620	11577	123	27B
0005432948612	11577	124	27A
0005433568703	11577	125	27C
0005433074828	11577	126	27D
0005432948615	11577	127	27F
0005432948610	11577	128	27E
0005433074821	11577	129	28A
0005433568648	11577	130	28C
0005432948616	11577	131	28B
0005433074814	11577	132	28D
0005433568460	11577	133	28E
0005433568650	11577	134	28F
0005432948621	11577	135	29A
0005433568664	11577	136	29C
0005433134155	11577	137	29B
0005432192334	11577	138	29D
0005433074832	11577	139	29E
0005432948636	11577	140	29F
0005433074810	11577	141	30B
0005432948632	11577	142	30C
0005433568737	11577	143	30E
0005432948628	11577	144	30D
0005433568758	11577	145	30F
0005433074825	11577	146	31A
0005433568635	11577	147	31C
0005433568733	11577	148	31B
0005432948620	11577	149	31D
0005433568781	11577	150	31F
0005434732975	10002	1	2B
0005434732976	10002	2	3B
0005433817485	10002	3	5A
0005433817487	10002	4	5B
0005433817486	10002	5	6A
0005433817446	13960	1	1A
0005434732994	13960	2	1B
0005433817439	13960	3	2A
0005433817438	13960	4	3B
0005434732995	13960	5	4A
0005433817447	13960	6	6A
0005434732996	13960	7	6B
0005432655583	2373	1	1A
0005433754443	2373	2	1C
0005432984786	2373	3	1B
0005435982502	2373	4	1F
0005435982487	2373	5	1H
0005435982494	2373	6	1G
0005435982504	2373	7	2A
0005432984797	2373	8	2C
0005433434667	2373	9	2B
0005433754457	2373	10	2F
0005433754456	2373	11	2H
0005433754480	2373	12	3B
0005432984991	2373	13	3A
0005432984911	2373	14	3F
0005435982491	2373	15	3C
0005433434492	2373	16	3G
0005435982520	2373	17	4A
0005433754477	2373	18	3H
0005432226084	2373	19	4B
0005435982498	2373	20	4C
0005432226086	2373	21	4G
0005433434607	2373	22	4H
0005432300288	2373	23	5B
0005432984857	2373	24	5A
0005432655588	2373	25	5C
0005432984908	2373	26	5G
0005435982509	2373	27	5F
0005432226082	2373	28	5H
0005435982510	2373	29	9A
0005433434515	2373	30	9H
0005435982515	2373	31	9G
0005435982519	2373	32	9B
0005433754449	2373	33	11B
0005435982526	2373	34	11E
0005432655585	2373	35	11D
0005432984837	2373	36	11F
0005433434568	2373	37	11G
0005433754482	2373	38	12A
0005432984947	2373	39	12B
0005432984942	2373	40	12E
0005432984997	2373	41	12D
0005433754452	2373	42	12G
0005435982512	2373	43	12F
0005433754473	2373	44	13B
0005432300290	2373	45	13A
0005433434591	2373	46	13D
0005432226080	2373	47	13E
0005433754442	2373	48	13G
0005435982486	2373	49	13F
0005435982499	2373	50	13H
0005432984965	2373	51	14B
0005433754454	2373	52	14A
0005433434499	2373	53	14E
0005433754437	2373	54	14D
0005435982493	2373	55	14F
0005433434480	2373	56	14G
0005433434518	2373	57	15A
0005433754466	2373	58	14H
0005432226083	2373	59	15B
0005433754475	2373	60	15G
0005433754458	2373	61	15F
0005433754433	2373	62	15E
0005433754469	2373	63	15H
0005433754474	2373	64	16A
0005433434606	2373	65	16E
0005432984856	2373	66	16F
0005433754434	2373	67	16H
0005432655594	2373	68	16G
0005435982489	2373	69	17B
0005433754462	2373	70	17A
0005435982503	2373	71	17F
0005432984798	2373	72	17E
0005432984955	2373	73	17G
0005432655584	2373	74	17H
0005435982485	2373	75	18B
0005432984847	2373	76	18A
0005433434566	2373	77	18E
0005433754476	2373	78	18D
0005433766657	2373	79	18F
0005432984954	2373	80	18G
0005432984981	2373	81	19A
0005433434498	2373	82	18H
0005433754439	2373	83	19B
0005435982501	2373	84	19E
0005433754432	2373	85	19D
0005435982492	2373	86	19F
0005435982522	2373	87	19G
0005432984933	2373	88	20A
0005433434625	2373	89	19H
0005432984838	2373	90	20B
0005435982511	2373	91	20D
0005433766658	2373	92	20G
0005432984868	2373	93	20F
0005432985061	2373	94	20E
0005433754448	2373	95	20H
0005433754444	2373	96	21A
0005433754438	2373	97	21D
0005432984996	2373	98	21B
0005433754441	2373	99	21E
0005432300289	2373	100	21F
0005432655591	2373	101	21H
0005432984982	2373	102	21G
0005435982523	2373	103	22B
0005433766656	2373	104	22A
0005433754459	2373	105	22D
0005432984912	2373	106	22F
0005435982524	2373	107	22E
0005433764688	2373	108	22G
0005433434559	2373	109	22H
0005432984929	2373	110	23A
0005433434565	2373	111	23E
0005433434514	2373	112	23D
0005433754484	2373	113	23F
0005433434564	2373	114	23H
0005433754464	2373	115	23G
0005432300286	2373	116	24A
0005432226081	2373	117	24B
0005432984968	2373	118	24E
0005435982517	2373	119	24D
0005432300287	2373	120	24F
0005433766655	2373	121	24G
0005433754430	2373	122	25D
0005432984990	2373	123	24H
0005432300285	2373	124	25E
0005435982516	2373	125	25F
0005433754471	2373	126	27B
0005433754460	2373	127	27F
0005432655592	2373	128	27E
0005433434589	2373	129	27H
0005433754479	2373	130	27G
0005432984898	2373	131	28A
0005433766654	2373	132	28D
0005432655590	2373	133	28B
0005433754440	2373	134	28E
0005433754470	2373	135	28G
0005433434524	2373	136	28F
0005433434588	2373	137	29A
0005433754451	2373	138	29B
0005432869481	2373	139	29E
0005432984880	2373	140	29G
0005433754453	2373	141	30A
0005433754447	2373	142	29H
0005433754431	2373	143	30E
0005435982505	2373	144	30D
0005433434626	2373	145	30B
0005432984879	2373	146	30G
0005432984948	2373	147	30F
0005435982496	2373	148	30H
0005432226085	2373	149	31B
0005432984897	2373	150	31A
0005433754472	2373	151	31D
0005433754467	2373	152	31F
0005433754435	2373	153	31E
0005432655589	2373	154	31G
0005432655586	2373	155	32A
0005435982514	2373	156	31H
0005433754468	2373	157	32B
0005433754478	2373	158	32E
0005435982506	2373	159	32D
0005433754455	2373	160	32F
0005435982490	2373	161	32H
0005432984869	2373	162	33A
0005435982525	2373	163	33B
0005433754450	2373	164	33E
0005435982488	2373	165	33D
0005433754486	2373	166	33G
0005433754463	2373	167	33F
0005433434523	2373	168	33H
0005433754481	2373	169	34B
0005432984989	2373	170	34A
0005435982508	2373	171	34D
0005433754485	2373	172	34E
0005435982513	2373	173	34F
0005432984928	2373	174	34H
0005435982521	2373	175	35B
0005432655587	2373	176	35A
0005432655593	2373	177	35G
0005435982507	2373	178	35F
0005432984983	2373	179	36A
0005433754446	2373	180	35H
0005433434590	2373	181	36D
0005433754445	2373	182	36B
0005433754483	2373	183	36F
0005433434592	2373	184	36E
0005435982500	2373	185	36G
0005433434593	2373	186	37A
0005432984934	2373	187	36H
0005432984967	2373	188	37B
0005433434458	2373	189	37D
0005432985107	2373	190	37F
0005433434479	2373	191	37E
0005435982495	2373	192	37H
0005433754465	2373	193	37G
0005433434567	2373	194	38A
0005433754436	2373	195	38D
0005435982497	2373	196	38B
0005433754461	2373	197	38E
0005432984896	2373	198	38G
0005432984913	2373	199	38F
0005432984941	2373	200	38H
0005435982518	2373	201	39E
0005433434497	2373	202	39D
0005433434576	2373	203	39F
0005433753863	26178	1	1A
0005433753960	26178	2	1B
0005432985227	26178	3	1F
0005432985214	26178	4	1H
0005433754172	26178	5	1G
0005432985206	26178	6	2A
0005433753925	26178	7	2C
0005435982264	26178	8	2B
0005432985199	26178	9	2F
0005432985202	26178	10	2G
0005432985217	26178	11	2H
0005433754078	26178	12	3B
0005433764675	26178	13	3A
0005433753989	26178	14	3F
0005435982025	26178	15	3C
0005435981915	26178	16	3H
0005435982176	26178	17	4A
0005435981982	26178	18	4F
0005432985226	26178	19	4G
0005435982083	26178	20	5A
0005435982177	26178	21	4H
0005435981862	26178	22	5C
0005433753717	26178	23	5G
0005433754059	26178	24	5F
0005432051142	26178	25	5H
0005433753847	26178	26	9H
0005432655480	26178	27	9G
0005432985220	26178	28	9B
0005433754075	26178	29	11A
0005435981964	26178	30	11B
0005432869549	26178	31	11D
0005433753815	26178	32	11F
0005433434794	26178	33	11E
0005432985211	26178	34	11H
0005433753949	26178	35	11G
0005433754072	26178	36	12A
0005435981950	26178	37	12B
0005433753921	26178	38	12E
0005433754118	26178	39	12D
0005432985210	26178	40	12G
0005433753928	26178	41	12F
0005433754197	26178	42	12H
0005432655421	26178	43	13A
0005433434808	26178	44	13D
0005435981772	26178	45	13B
0005432049482	26178	46	13F
0005433766624	26178	47	13E
0005433753805	26178	48	13G
0005435982265	26178	49	13H
0005433434799	26178	50	14B
0005435982085	26178	51	14A
0005433753719	26178	52	14D
0005433434812	26178	53	14E
0005433764679	26178	54	14G
0005435982112	26178	55	14H
0005435982140	26178	56	15D
0005435982128	26178	57	15B
0005433753929	26178	58	15E
0005433754117	26178	59	15F
0005433754091	26178	60	15G
0005435981989	26178	61	16A
0005433753848	26178	62	15H
0005435982301	26178	63	16D
0005433754061	26178	64	16F
0005432869547	26178	65	16H
0005433753964	26178	66	16G
0005432985224	26178	67	17A
0005432985218	26178	68	17B
0005433754028	26178	69	17E
0005435982072	26178	70	17G
0005432985209	26178	71	17F
0005433754097	26178	72	17H
0005433753930	26178	73	18A
0005432985216	26178	74	18E
0005433434804	26178	75	18D
0005432049478	26178	76	18F
0005433434798	26178	77	18G
0005433434806	26178	78	19A
0005433434792	26178	79	18H
0005432869548	26178	80	19B
0005432985213	26178	81	19D
0005433434810	26178	82	19F
0005433753718	26178	83	19E
0005435982079	26178	84	19G
0005432655453	26178	85	20A
0005435982013	26178	86	19H
0005433753997	26178	87	20B
0005433754090	26178	88	20E
0005432869550	26178	89	20D
0005435982068	26178	90	20F
0005433753898	26178	91	20H
0005432655479	26178	92	20G
0005435982082	26178	93	21B
0005432985198	26178	94	21A
0005433434811	26178	95	21D
0005435982022	26178	96	21E
0005433434790	26178	97	21G
0005432985219	26178	98	21F
0005435981863	26178	99	21H
0005433754096	26178	100	22A
0005432049479	26178	101	22D
0005435981935	26178	102	22B
0005433753864	26178	103	22F
0005432985215	26178	104	22E
0005433754045	26178	105	22G
0005435982300	26178	106	22H
0005433434795	26178	107	23A
0005433434788	26178	108	23E
0005432985201	26178	109	23D
0005434731189	26178	110	23F
0005434731190	26178	111	23G
0005433753966	26178	112	24A
0005432051140	26178	113	23H
0005432985212	26178	114	24B
0005432869552	26178	115	24E
0005435982033	26178	116	24D
0005435982048	26178	117	24F
0005432049477	26178	118	24H
0005433753816	26178	119	24G
0005433434784	26178	120	25D
0005433754077	26178	121	25E
0005433434805	26178	122	25F
0005433754099	26178	123	27B
0005432869546	26178	124	27A
0005433753934	26178	125	27D
0005433754067	26178	126	27F
0005432985228	26178	127	27E
0005435982017	26178	128	27G
0005433753994	26178	129	28A
0005433434802	26178	130	28D
0005435982097	26178	131	28B
0005432051141	26178	132	28F
0005432985222	26178	133	28E
0005433764678	26178	134	28G
0005433754035	26178	135	29A
0005433753996	26178	136	28H
0005433766629	26178	137	29D
0005432985221	26178	138	29B
0005433753817	26178	139	29E
0005432655445	26178	140	29G
0005433754006	26178	141	29F
0005433434796	26178	142	30B
0005432049480	26178	143	30D
0005432985225	26178	144	30E
0005433754062	26178	145	30G
0005433753639	26178	146	30H
0005432655387	26178	147	31A
0005433754200	26178	148	31D
0005433753933	26178	149	31F
0005433754088	26178	150	31E
0005433754060	26178	151	31G
0005433434793	26178	152	32A
0005433434786	26178	153	31H
0005435981864	26178	154	32B
0005435982111	26178	155	32F
0005435982045	26178	156	32E
0005435982031	26178	157	32H
0005433753716	26178	158	32G
0005434731187	26178	159	33B
0005435982306	26178	160	33D
0005435982373	26178	161	33G
0005433434787	26178	162	33F
0005432869551	26178	163	33H
0005435981978	26178	164	34B
0005433754089	26178	165	34D
0005435982069	26178	166	34E
0005433753887	26178	167	34G
0005435982305	26178	168	34F
0005435981865	26178	169	35A
0005433434800	26178	170	34H
0005433754029	26178	171	35B
0005433434801	26178	172	35D
0005432985203	26178	173	35E
0005432985229	26178	174	35G
0005432985223	26178	175	36A
0005432985204	26178	176	35H
0005433753935	26178	177	36B
0005434731188	26178	178	36E
0005432985207	26178	179	36D
0005435981977	26178	180	36F
0005432985208	26178	181	36G
0005433434797	26178	182	37A
0005432049481	26178	183	37B
0005433764674	26178	184	37E
0005433434807	26178	185	37D
0005435982032	26178	186	37F
0005435982024	26178	187	37H
0005433434809	26178	188	37G
0005433434791	26178	189	38A
0005432985200	26178	190	38B
0005435982021	26178	191	38E
0005433434789	26178	192	38G
0005433434785	26178	193	38F
0005433434803	26178	194	39D
0005433753963	26178	195	39F
0005432985205	26178	196	39E
0005433151195	1529	1	1A
0005433151296	1529	2	1D
0005433764656	1529	3	2A
0005432267925	1529	4	1F
0005433151280	1529	5	2C
0005433151317	1529	6	2D
0005434374836	1529	7	2F
0005434029643	1529	8	3A
0005434374817	1529	9	3D
0005433151316	1529	10	3C
0005433151384	1529	11	3F
0005434029642	1529	12	4A
0005433151306	1529	13	4B
0005434374839	1529	14	4C
0005433151116	1529	15	4E
0005433151153	1529	16	4D
0005433151416	1529	17	4F
0005432267926	1529	18	5A
0005433764657	1529	19	5C
0005433151282	1529	20	5B
0005433151245	1529	21	5D
0005434029648	1529	22	5F
0005433151248	1529	23	5E
0005433151338	1529	24	6A
0005433151276	1529	25	6B
0005433151154	1529	26	6C
0005433460446	1529	27	6D
0005433151265	1529	28	6E
0005434374824	1529	29	7A
0005434029647	1529	30	6F
0005434374842	1529	31	7B
0005433931426	1529	32	7C
0005433461598	1529	33	8A
0005433151200	1529	34	8B
0005433151312	1529	35	8C
0005433151287	1529	36	8E
0005433151243	1529	37	8D
0005434029635	1529	38	9A
0005434374825	1529	39	8F
0005434374843	1529	40	9C
0005434374821	1529	41	9B
0005433151335	1529	42	9D
0005434374818	1529	43	9F
0005434374834	1529	44	9E
0005433931456	1529	45	10B
0005434374838	1529	46	10E
0005432267921	1529	47	10D
0005433151324	1529	48	11A
0005433151319	1529	49	11B
0005433151155	1529	50	11F
0005433151421	1529	51	11E
0005434374832	1529	52	12A
0005433151226	1529	53	12B
0005434374829	1529	54	12D
0005432267923	1529	55	12E
0005433151415	1529	56	12F
0005433460445	1529	57	13B
0005434374828	1529	58	13A
0005433151344	1529	59	13D
0005434374830	1529	60	13C
0005434374815	1529	61	13E
0005433151459	1529	62	13F
0005433151295	1529	63	14B
0005433931440	1529	64	14A
0005434374841	1529	65	14C
0005432267920	1529	66	14D
0005433151351	1529	67	14E
0005433151244	1529	68	15A
0005433151274	1529	69	14F
0005434374837	1529	70	15B
0005434374835	1529	71	15D
0005433151346	1529	72	15F
0005434029636	1529	73	15E
0005433931442	1529	74	16A
0005432267924	1529	75	16B
0005433151264	1529	76	16C
0005433151138	1529	77	16F
0005434029644	1529	78	17B
0005433151297	1529	79	17C
0005432267927	1529	80	17D
0005433151325	1529	81	17F
0005433151460	1529	82	17E
0005434374827	1529	83	18A
0005433151152	1529	84	18B
0005434374820	1529	85	18C
0005433460447	1529	86	18D
0005434374814	1529	87	18E
0005433151345	1529	88	19B
0005433151115	1529	89	19D
0005434374845	1529	90	19C
0005433151326	1529	91	19E
0005433931441	1529	92	19F
0005433151263	1529	93	20A
0005433151417	1529	94	20B
0005433151286	1529	95	20D
0005434374833	1529	96	20E
0005434374826	1529	97	21A
0005433461597	1529	98	20F
0005434374831	1529	99	21B
0005434374816	1529	100	21C
0005433151281	1529	101	21D
0005434374812	1529	102	21E
0005434374823	1529	103	22A
0005433151201	1529	104	21F
0005433151275	1529	105	22C
0005432267922	1529	106	22B
0005434374844	1529	107	22D
0005433151277	1529	108	22F
0005433151151	1529	109	22E
0005434374813	1529	110	23A
0005434374840	1529	111	23B
0005433151196	1529	112	23C
0005434374819	1529	113	23E
0005433151343	1529	114	23D
0005434374822	1529	115	23F
0005433151549	20119	1	1C
0005434374474	20119	2	1A
0005433151546	20119	3	1D
0005433151566	20119	4	2A
0005433151548	20119	5	2F
0005434374587	20119	6	4C
0005433151547	20119	7	4B
0005434374627	20119	8	4D
0005433931476	20119	9	4E
0005434374466	20119	10	5A
0005434374599	20119	11	5C
0005433151551	20119	12	5B
0005434029667	20119	13	5D
0005434374510	20119	14	5F
0005434374321	20119	15	6B
0005433151538	20119	16	6A
0005433764688	20119	17	6C
0005433151552	20119	18	6E
0005434374570	20119	19	6F
0005433151567	20119	20	7B
0005434374407	20119	21	7C
0005433151545	20119	22	7E
0005433151542	20119	23	7D
0005434374564	20119	24	8A
0005434374464	20119	25	7F
0005433151543	20119	26	8B
0005433151557	20119	27	8C
0005434374406	20119	28	8E
0005433151536	20119	29	8D
0005434374505	20119	30	8F
0005434374344	20119	31	9A
0005433151532	20119	32	9C
0005434374555	20119	33	9D
0005434374443	20119	34	9F
0005434374315	20119	35	10B
0005433151555	20119	36	10E
0005434374457	20119	37	10D
0005434374465	20119	38	11A
0005434374444	20119	39	11D
0005432056316	20119	40	11C
0005432056313	20119	41	12A
0005434374552	20119	42	12C
0005433151535	20119	43	12B
0005433151541	20119	44	12E
0005434374405	20119	45	12D
0005433151559	20119	46	13A
0005434374610	20119	47	12F
0005434374523	20119	48	13C
0005432056314	20119	49	13D
0005434374345	20119	50	13E
0005433151563	20119	51	14A
0005433151554	20119	52	13F
0005434374565	20119	53	14C
0005433151544	20119	54	14B
0005434374456	20119	55	14D
0005434374322	20119	56	14F
0005434374374	20119	57	15B
0005433931475	20119	58	15A
0005433151562	20119	59	15C
0005433151533	20119	60	15E
0005434374542	20119	61	15F
0005434374581	20119	62	16B
0005433151540	20119	63	16C
0005433151560	20119	64	16D
0005433151565	20119	65	16F
0005434374450	20119	66	16E
0005434374511	20119	67	17A
0005433151556	20119	68	17B
0005434374334	20119	69	17C
0005433931477	20119	70	18C
0005433151534	20119	71	18F
0005434374316	20119	72	18E
0005433151564	20119	73	19C
0005434374477	20119	74	19D
0005434374478	20119	75	19F
0005433151550	20119	76	20A
0005434374566	20119	77	20C
0005433151558	20119	78	20B
0005433151561	20119	79	20D
0005434374522	20119	80	20F
0005434374323	20119	81	21A
0005434374571	20119	82	21C
0005434374475	20119	83	21B
0005434374298	20119	84	21D
0005433151537	20119	85	21F
0005432056315	20119	86	22B
0005434374441	20119	87	22A
0005433151553	20119	88	22C
0005434374473	20119	89	22E
0005434374259	20119	90	22D
0005434029668	20119	91	23A
0005433151539	20119	92	23C
0005434374553	20119	93	23D
0005434374479	20119	94	23F
0005432424617	513	1	1D
0005432424667	513	2	2D
0005432424665	513	3	3C
0005432424619	513	4	3F
0005432424651	513	5	3D
0005432424633	513	6	4D
0005432424628	513	7	5A
0005432424636	513	8	4F
0005432282897	513	9	5F
0005432282895	513	10	7A
0005432424621	513	11	7F
0005432424666	513	12	8B
0005432424629	513	13	8D
0005432424610	513	14	10A
0005432424650	513	15	10C
0005432424638	513	16	11E
0005432424611	513	17	12F
0005432424626	513	18	13C
0005432424657	513	19	13E
0005432424632	513	20	13F
0005432282893	513	21	14E
0005432424654	513	22	14D
0005432424645	513	23	15C
0005432424659	513	24	15E
0005432424643	513	25	17A
0005432424656	513	26	16F
0005432424655	513	27	17B
0005432424613	513	28	17F
0005432424634	513	29	18B
0005432282894	513	30	18E
0005432424612	513	31	19B
0005432282892	513	32	19E
0005432424631	513	33	20B
0005432424616	513	34	20A
0005432424618	513	35	20C
0005432424658	513	36	21E
0005432424661	513	37	22B
0005432424623	513	38	22C
0005432424660	513	39	22E
0005432424614	513	40	23B
0005432424622	513	41	23D
0005432424627	513	42	23E
0005432424664	513	43	24C
0005432424639	513	44	24E
0005432424640	513	45	24D
0005432424620	513	46	25A
0005432424624	513	47	25B
0005432424648	513	48	25C
0005432424663	513	49	25F
0005432424625	513	50	26A
0005432424649	513	51	26B
0005432424637	513	52	26D
0005432424630	513	53	26F
0005432424646	513	54	26E
0005432424644	513	55	27B
0005432424653	513	56	28A
0005432424641	513	57	28C
0005432424642	513	58	28B
0005432282896	513	59	28E
0005432424635	513	60	28F
0005432424662	513	61	29F
0005432424615	513	62	30B
0005432424647	513	63	30E
0005432424652	513	64	30F
0005434446503	12891	1	1A
0005434446504	12891	2	2F
0005432302346	12891	3	5F
0005433158140	12891	4	10B
0005433158141	12891	5	11A
0005434446498	12891	6	11E
0005433158139	12891	7	14E
0005434446505	12891	8	15F
0005434446506	12891	9	18F
0005433158137	12891	10	19C
0005433158136	12891	11	20B
0005434446511	12891	12	21F
0005432302348	12891	13	23B
0005434446513	12891	14	24B
0005432302345	12891	15	25B
0005432302347	12891	16	25C
0005434446512	12891	17	28C
0005433158138	12891	18	29D
0005432424178	12936	1	1A
0005432424225	12936	2	1F
0005432424201	12936	3	2C
0005432424172	12936	4	2D
0005432424207	12936	5	3F
0005432424128	12936	6	4F
0005432424210	12936	7	6F
0005432424147	12936	8	8B
0005432424114	12936	9	9D
0005432424170	12936	10	11F
0005432424214	12936	11	12D
0005432424218	12936	12	12C
0005432424191	12936	13	13A
0005432424224	12936	14	13D
0005432424230	12936	15	14D
0005432424136	12936	16	14E
0005432424162	12936	17	15B
0005432424228	12936	18	18B
0005432424167	12936	19	18C
0005432424204	12936	20	20A
0005432424153	12936	21	20D
0005432424219	12936	22	20F
0005432424203	12936	23	21D
0005432424213	12936	24	22C
0005432424166	12936	25	22E
0005432424175	12936	26	23C
0005432424173	12936	27	23E
0005432424174	12936	28	24E
0005432424209	12936	29	25D
0005432424198	12936	30	26B
0005432423984	12936	31	26D
0005432424014	12936	32	26F
0005432424229	12936	33	27B
0005432424188	12936	34	27D
0005432424184	12936	35	27F
0005432424148	12936	36	28B
0005432424171	12936	37	28D
0005432424137	12936	38	28C
0005432424205	12936	39	28E
0005432424127	12936	40	29B
0005432424179	12936	41	29C
0005432424223	12936	42	29E
0005432424192	12936	43	30F
0005432045620	433	1	1B
0005433684411	433	2	1F
0005434023998	433	3	1G
0005434735627	433	4	2A
0005433057656	433	5	2C
0005433057763	433	6	2B
0005434023999	433	7	2H
0005434023994	433	8	2G
0005433057949	433	9	2F
0005433057850	433	10	3A
0005433057668	433	11	3B
0005433057783	433	12	3G
0005434735642	433	13	4C
0005434029666	433	14	4G
0005434735660	433	15	4F
0005434024003	433	16	5A
0005434023985	433	17	4H
0005434735628	433	18	5B
0005433057777	433	19	5C
0005434023959	433	20	5G
0005434023958	433	21	5F
0005434023984	433	22	9G
0005434024009	433	23	11A
0005434023993	433	24	11D
0005433057672	433	25	11F
0005434029664	433	26	11H
0005434024023	433	27	12A
0005434024021	433	28	12E
0005434023986	433	29	12H
0005433057629	433	30	13A
0005434032038	433	31	13D
0005434023965	433	32	13G
0005433057865	433	33	13F
0005434023995	433	34	13H
0005433684413	433	35	14B
0005434024020	433	36	14D
0005434023961	433	37	14F
0005434023990	433	38	15A
0005434024004	433	39	14H
0005433057795	433	40	15E
0005434023978	433	41	15H
0005434735643	433	42	15G
0005434024013	433	43	16B
0005434023962	433	44	16A
0005432235671	433	45	16D
0005434024001	433	46	16E
0005434023967	433	47	16H
0005433684412	433	48	17B
0005432235670	433	49	17A
0005433057551	433	50	17D
0005434023969	433	51	17F
0005433057579	433	52	18A
0005434024024	433	53	18B
0005434023966	433	54	18F
0005434024006	433	55	18E
0005434024022	433	56	19A
0005434024019	433	57	19D
0005434023988	433	58	19E
0005434032039	433	59	19G
0005434024014	433	60	19H
0005433057578	433	61	20F
0005433929591	433	62	20H
0005434024015	433	63	21A
0005433057655	433	64	21B
0005433057758	433	65	21F
0005434023982	433	66	21E
0005434024025	433	67	21D
0005432235668	433	68	21G
0005433057888	433	69	21H
0005432235667	433	70	22D
0005434024005	433	71	23B
0005434024017	433	72	23E
0005434029665	433	73	23G
0005433057693	433	74	24B
0005434028308	433	75	24H
0005434735671	433	76	25D
0005433057803	433	77	27A
0005434023989	433	78	25F
0005434023979	433	79	27E
0005433057701	433	80	27D
0005434024010	433	81	28A
0005434023976	433	82	27H
0005434032041	433	83	28D
0005434023977	433	84	28G
0005434023980	433	85	29B
0005432045619	433	86	29F
0005432235672	433	87	29H
0005432235669	433	88	30A
0005434024011	433	89	30D
0005433057762	433	90	30G
0005433057634	433	91	31A
0005434023970	433	92	30H
0005434032040	433	93	31E
0005434023975	433	94	31F
0005434023971	433	95	31H
0005434023987	433	96	31G
0005433057776	433	97	32A
0005433057818	433	98	32B
0005434023996	433	99	32D
0005434024018	433	100	32F
0005434023963	433	101	32G
0005434024002	433	102	33D
0005434023973	433	103	33B
0005434024008	433	104	33F
0005434024016	433	105	33G
0005433057804	433	106	34A
0005434023964	433	107	34E
0005433057651	433	108	34F
0005434023972	433	109	35A
0005433057794	433	110	35D
0005434024007	433	111	35B
0005434023960	433	112	35F
0005433057630	433	113	35E
0005432235666	433	114	35G
0005434023997	433	115	36B
0005433057550	433	116	36F
0005434023981	433	117	37A
0005434024000	433	118	36H
0005434023983	433	119	37B
0005433057796	433	120	37E
0005433057719	433	121	37D
0005434023992	433	122	37F
0005433057851	433	123	37G
0005434024012	433	124	38A
0005434023968	433	125	38E
0005434028307	433	126	38D
0005433057696	433	127	38G
0005434023974	433	128	38F
0005433057808	433	129	39E
0005434029663	433	130	39D
0005434023991	433	131	39F
0005434023285	12699	1	1A
0005434023639	12699	2	1F
0005434023410	12699	3	1H
0005434023277	12699	4	1G
0005433058071	12699	5	2B
0005433058051	12699	6	2C
0005434023463	12699	7	2H
0005433058069	12699	8	2G
0005434023564	12699	9	3A
0005434023409	12699	10	3B
0005433684429	12699	11	3C
0005432156383	12699	12	4A
0005434023290	12699	13	3H
0005434029644	12699	14	4C
0005433058049	12699	15	4B
0005433058065	12699	16	4G
0005434023342	12699	17	4F
0005434735713	12699	18	4H
0005433058039	12699	19	5B
0005432157500	12699	20	5F
0005434023716	12699	21	5H
0005434023516	12699	22	9B
0005434023493	12699	23	9A
0005432156385	12699	24	9G
0005432156384	12699	25	11A
0005433684430	12699	26	9H
0005434735712	12699	27	11D
0005434023165	12699	28	11B
0005434023518	12699	29	11F
0005434023426	12699	30	11H
0005434023573	12699	31	11G
0005434023061	12699	32	12B
0005433058040	12699	33	12A
0005434023289	12699	34	12E
0005433058038	12699	35	12D
0005434023488	12699	36	12G
0005434023352	12699	37	12F
0005434023362	12699	38	13A
0005434735714	12699	39	13D
0005434029648	12699	40	13B
0005434023489	12699	41	13F
0005434023490	12699	42	13G
0005434023397	12699	43	13H
0005434023123	12699	44	14E
0005434023345	12699	45	14F
0005434028278	12699	46	14G
0005434028290	12699	47	15A
0005433058063	12699	48	14H
0005434023424	12699	49	15D
0005434029647	12699	50	15E
0005433058054	12699	51	15F
0005434023341	12699	52	15H
0005433058046	12699	53	16A
0005434023002	12699	54	16D
0005434023182	12699	55	16B
0005433058068	12699	56	16G
0005434023574	12699	57	16F
0005434023425	12699	58	16H
0005433058036	12699	59	17B
0005434023164	12699	60	17D
0005434031992	12699	61	17G
0005433058047	12699	62	17H
0005433058033	12699	63	18E
0005433058057	12699	64	18D
0005433058031	12699	65	18B
0005434023412	12699	66	18G
0005433058043	12699	67	19A
0005434023363	12699	68	19B
0005434023509	12699	69	19E
0005434028279	12699	70	19F
0005432157501	12699	71	19H
0005433058032	12699	72	20A
0005434023598	12699	73	20D
0005434735710	12699	74	20B
0005434028286	12699	75	20F
0005434023462	12699	76	20H
0005434023385	12699	77	21B
0005434023390	12699	78	21E
0005433058059	12699	79	21F
0005434023517	12699	80	21H
0005434023599	12699	81	22A
0005434028289	12699	82	22E
0005434023311	12699	83	22F
0005434029643	12699	84	23A
0005434023592	12699	85	23B
0005433058064	12699	86	23D
0005434023538	12699	87	23F
0005434023481	12699	88	23E
0005433058037	12699	89	23G
0005434735709	12699	90	24B
0005434023429	12699	91	24E
0005434023212	12699	92	24D
0005434023470	12699	93	24F
0005434023416	12699	94	24H
0005433058034	12699	95	24G
0005434023098	12699	96	25D
0005434023479	12699	97	25F
0005434023378	12699	98	27B
0005434023401	12699	99	27D
0005434023384	12699	100	27H
0005434023389	12699	101	27G
0005434023469	12699	102	28D
0005433058050	12699	103	28G
0005433058045	12699	104	29B
0005434023487	12699	105	29E
0005434022981	12699	106	29F
0005434029642	12699	107	30A
0005433929630	12699	108	30D
0005433058053	12699	109	30B
0005434023343	12699	110	30G
0005434031998	12699	111	30F
0005433929629	12699	112	31A
0005434023361	12699	113	31B
0005434023062	12699	114	31F
0005433058035	12699	115	31E
0005433058067	12699	116	31H
0005433058062	12699	117	32B
0005434029636	12699	118	32D
0005434023286	12699	119	32F
0005434023264	12699	120	32E
0005434023326	12699	121	32H
0005434023593	12699	122	32G
0005434023372	12699	123	33A
0005434023217	12699	124	33D
0005434023400	12699	125	33B
0005434023287	12699	126	34B
0005433058042	12699	127	34A
0005433058066	12699	128	34D
0005434023325	12699	129	34E
0005433058055	12699	130	34G
0005432156386	12699	131	34H
0005433058048	12699	132	35B
0005434023396	12699	133	35A
0005434023480	12699	134	35D
0005434023494	12699	135	35F
0005433058058	12699	136	35G
0005434023659	12699	137	35H
0005433058060	12699	138	36B
0005433058041	12699	139	36E
0005434028276	12699	140	36D
0005433058061	12699	141	36F
0005434023357	12699	142	37A
0005434031993	12699	143	36H
0005434031991	12699	144	37B
0005434023715	12699	145	37G
0005434735711	12699	146	37F
0005434023157	12699	147	37H
0005434023353	12699	148	38A
0005433929631	12699	149	38B
0005434023604	12699	150	38E
0005434029635	12699	151	38D
0005433058044	12699	152	38F
0005433058056	12699	153	38H
0005433058052	12699	154	38G
0005433058070	12699	155	39E
0005433527272	13816	1	1C
0005433529283	13816	2	1F
0005433529280	13816	3	2A
0005433529281	13816	4	3A
0005433529279	13816	5	2F
0005433529288	13816	6	4A
0005433527281	13816	7	6C
0005433527266	13816	8	7A
0005433529289	13816	9	8B
0005433529282	13816	10	8E
0005433527268	13816	11	9A
0005433527276	13816	12	9D
0005433527273	13816	13	10E
0005433529291	13816	14	11C
0005433527269	13816	15	11A
0005433527271	13816	16	12B
0005433527278	13816	17	12D
0005433529278	13816	18	13A
0005433529285	13816	19	13E
0005433527280	13816	20	13D
0005433527279	13816	21	14E
0005433527274	13816	22	15A
0005433527267	13816	23	15E
0005433529287	13816	24	16D
0005433527270	13816	25	17C
0005433527275	13816	26	18E
0005433529284	13816	27	19A
0005433527277	13816	28	19E
0005433529290	13816	29	19D
0005433529286	13816	30	19F
0005433527265	13816	31	21A
0005433529277	13816	32	21F
0005433533302	32452	1	1C
0005433533278	32452	2	2F
0005433529246	32452	3	3F
0005433529263	32452	4	4F
0005433529237	32452	5	5F
0005433529242	32452	6	6B
0005433533284	32452	7	6F
0005433533306	32452	8	8D
0005433529248	32452	9	9D
0005433529252	32452	10	10E
0005433533272	32452	11	10F
0005433533290	32452	12	11B
0005433533276	32452	13	11D
0005433533294	32452	14	11F
0005433533301	32452	15	12A
0005433533265	32452	16	12C
0005433533295	32452	17	12B
0005433529264	32452	18	12F
0005433529247	32452	19	13B
0005433529253	32452	20	13E
0005433529230	32452	21	13D
0005433533273	32452	22	14C
0005433529232	32452	23	15A
0005433529243	32452	24	15D
0005433533283	32452	25	17D
0005433533305	32452	26	17E
0005433529234	32452	27	18E
0005433529245	32452	28	19B
0005433529238	32452	29	19D
0005433529225	32452	30	20E
0005433533277	32452	31	21B
0005433529233	32452	32	21E
0005433923727	2131	1	1B
0005433923703	2131	2	1F
0005433035877	2131	3	1G
0005433923652	2131	4	2A
0005433923667	2131	5	2C
0005433923744	2131	6	2B
0005433923736	2131	7	2F
0005433923709	2131	8	2G
0005432044537	2131	9	3B
0005433923677	2131	10	3F
0005433923731	2131	11	3G
0005433035981	2131	12	4A
0005434028290	2131	13	3H
0005433036078	2131	14	4F
0005433923720	2131	15	4C
0005433923718	2131	16	4G
0005433929631	2131	17	4H
0005433923675	2131	18	5B
0005433923740	2131	19	5A
0005434028286	2131	20	5F
0005433923747	2131	21	5C
0005433036061	2131	22	5G
0005434028289	2131	23	5H
0005433923689	2131	24	9A
0005433923697	2131	25	11A
0005433923654	2131	26	11D
0005433923666	2131	27	11B
0005433923701	2131	28	11E
0005433036199	2131	29	11F
0005432231603	2131	30	12D
0005432044536	2131	31	12G
0005433036127	2131	32	12F
0005433923691	2131	33	12H
0005433035927	2131	34	13D
0005433923688	2131	35	13E
0005433923660	2131	36	13G
0005433923694	2131	37	13F
0005433036107	2131	38	14A
0005433035977	2131	39	13H
0005432231610	2131	40	14B
0005433931475	2131	41	14D
0005433923684	2131	42	14E
0005433036148	2131	43	14G
0005433923653	2131	44	15A
0005433923672	2131	45	15B
0005433036121	2131	46	15E
0005433923695	2131	47	15F
0005432044535	2131	48	15H
0005433923699	2131	49	15G
0005433923733	2131	50	16E
0005432231611	2131	51	16D
0005433036062	2131	52	16F
0005433036149	2131	53	16H
0005433036048	2131	54	16G
0005433035852	2131	55	17A
0005433923679	2131	56	17D
0005433923722	2131	57	17F
0005433923732	2131	58	17E
0005433035978	2131	59	17G
0005433923723	2131	60	18A
0005433035968	2131	61	17H
0005433923730	2131	62	18B
0005433923725	2131	63	18E
0005433923711	2131	64	18D
0005433036263	2131	65	18G
0005433923712	2131	66	18F
0005434028276	2131	67	18H
0005433036120	2131	68	19D
0005433036052	2131	69	19F
0005433923719	2131	70	19G
0005433923734	2131	71	19H
0005433923693	2131	72	20B
0005433923702	2131	73	20D
0005433036262	2131	74	20G
0005433923738	2131	75	20F
0005433923661	2131	76	21D
0005433931477	2131	77	21B
0005433923746	2131	78	21E
0005433923680	2131	79	21H
0005433923663	2131	80	22D
0005433036036	2131	81	22E
0005433875386	2131	82	22F
0005433035851	2131	83	23A
0005433923715	2131	84	22H
0005433036054	2131	85	22G
0005432044538	2131	86	23D
0005433923685	2131	87	23B
0005433036047	2131	88	23F
0005433923674	2131	89	23E
0005433923657	2131	90	23G
0005433923698	2131	91	23H
0005433036009	2131	92	24B
0005433923707	2131	93	24A
0005432231604	2131	94	24D
0005433035933	2131	95	24F
0005433923748	2131	96	24E
0005433923705	2131	97	24H
0005433923651	2131	98	24G
0005433923726	2131	99	25D
0005433035966	2131	100	25F
0005433923665	2131	101	25E
0005433923681	2131	102	27A
0005433929630	2131	103	27B
0005433923669	2131	104	27D
0005433923656	2131	105	27F
0005432231613	2131	106	27H
0005433923700	2131	107	27G
0005433923735	2131	108	28A
0005433036053	2131	109	28E
0005433036014	2131	110	28D
0005433923717	2131	111	28F
0005433923739	2131	112	28H
0005433923696	2131	113	29A
0005433923729	2131	114	29D
0005432231607	2131	115	29B
0005433923710	2131	116	29E
0005433929629	2131	117	29G
0005433923690	2131	118	29H
0005433923713	2131	119	30B
0005432231612	2131	120	30A
0005434028279	2131	121	30D
0005433036100	2131	122	30E
0005433036119	2131	123	30G
0005433923692	2131	124	30F
0005433923658	2131	125	30H
0005433923673	2131	126	31E
0005432749770	2131	127	31D
0005433923683	2131	128	31H
0005434028278	2131	129	31G
0005433923670	2131	130	32D
0005433923650	2131	131	32B
0005433923649	2131	132	32E
0005433931476	2131	133	32F
0005433923676	2131	134	32H
0005433036130	2131	135	32G
0005433923743	2131	136	33A
0005432231605	2131	137	33B
0005433923678	2131	138	33E
0005433036209	2131	139	33D
0005433923716	2131	140	33F
0005433923742	2131	141	33H
0005432231608	2131	142	34A
0005433923737	2131	143	34D
0005433035967	2131	144	34E
0005433036091	2131	145	34G
0005433923671	2131	146	34F
0005433036265	2131	147	35A
0005433923686	2131	148	34H
0005433923704	2131	149	35D
0005433923708	2131	150	35F
0005433923706	2131	151	35E
0005433923655	2131	152	35G
0005433036090	2131	153	36A
0005432231606	2131	154	36B
0005433035902	2131	155	36D
0005433923662	2131	156	36F
0005433923724	2131	157	36E
0005433923721	2131	158	36H
0005433923728	2131	159	36G
0005433035842	2131	160	37B
0005433923714	2131	161	37E
0005433036035	2131	162	37F
0005433036093	2131	163	37H
0005433036167	2131	164	37G
0005433875385	2131	165	38A
0005433923745	2131	166	38D
0005432231609	2131	167	38B
0005433923659	2131	168	38F
0005433923682	2131	169	38E
0005433923668	2131	170	38G
0005433923664	2131	171	38H
0005433923741	2131	172	39D
0005433923687	2131	173	39F
0005433922752	24113	1	1B
0005433036528	24113	2	1F
0005433923160	24113	3	1H
0005433923013	24113	4	1G
0005433036542	24113	5	2A
0005433923239	24113	6	2B
0005433922399	24113	7	2F
0005433036531	24113	8	2C
0005433036504	24113	9	2G
0005433929598	24113	10	2H
0005432749793	24113	11	3B
0005433922601	24113	12	3A
0005433923223	24113	13	3C
0005433036509	24113	14	3G
0005433922814	24113	15	3F
0005433931455	24113	16	4A
0005433929613	24113	17	4B
0005433036521	24113	18	4C
0005433922765	24113	19	4G
0005433922869	24113	20	4F
0005433922739	24113	21	4H
0005433036538	24113	22	5B
0005433036517	24113	23	5A
0005433036505	24113	24	5C
0005433036497	24113	25	5G
0005433922613	24113	26	5F
0005433922824	24113	27	5H
0005433922520	24113	28	9B
0005433923014	24113	29	9H
0005433922621	24113	30	9G
0005433923198	24113	31	11A
0005433922460	24113	32	11D
0005433036527	24113	33	11B
0005433036522	24113	34	11E
0005433931453	24113	35	11F
0005433929599	24113	36	11G
0005433036503	24113	37	11H
0005433922569	24113	38	12D
0005433922893	24113	39	12B
0005433036543	24113	40	12E
0005433923010	24113	41	12G
0005433922823	24113	42	13B
0005433929597	24113	43	13A
0005434028309	24113	44	13D
0005433922321	24113	45	13E
0005433036539	24113	46	13F
0005433036541	24113	47	13H
0005433036496	24113	48	14B
0005433036494	24113	49	14E
0005433923229	24113	50	14D
0005433036533	24113	51	14F
0005433922917	24113	52	14H
0005433922568	24113	53	14G
0005433922782	24113	54	15A
0005433923272	24113	55	15B
0005432206221	24113	56	15E
0005433922614	24113	57	15D
0005433922873	24113	58	15G
0005432207673	24113	59	15F
0005433922721	24113	60	16A
0005433036515	24113	61	15H
0005433036523	24113	62	16D
0005432206223	24113	63	16F
0005433036501	24113	64	16H
0005433922639	24113	65	17A
0005433922694	24113	66	17D
0005433922915	24113	67	17F
0005433931450	24113	68	17E
0005433036492	24113	69	17H
0005433929593	24113	70	18B
0005433036498	24113	71	18D
0005433923060	24113	72	18F
0005433036502	24113	73	18E
0005433922758	24113	74	19A
0005433036536	24113	75	18H
0005433922916	24113	76	19B
0005433036491	24113	77	19E
0005433923167	24113	78	19D
0005433036540	24113	79	19F
0005433922381	24113	80	19H
0005433922365	24113	81	19G
0005433922849	24113	82	20B
0005433929605	24113	83	20E
0005433922938	24113	84	20D
0005433923095	24113	85	20F
0005433922519	24113	86	20H
0005433929592	24113	87	21A
0005433922764	24113	88	21D
0005433922397	24113	89	21B
0005433922638	24113	90	21E
0005433923145	24113	91	21G
0005433922868	24113	92	21F
0005433922757	24113	93	21H
0005433036534	24113	94	22B
0005433923185	24113	95	22D
0005433922602	24113	96	22F
0005433922751	24113	97	22E
0005433923156	24113	98	22G
0005433923319	24113	99	23A
0005433036516	24113	100	23B
0005433923286	24113	101	23E
0005433922720	24113	102	23D
0005433922857	24113	103	23F
0005433922850	24113	104	23G
0005432207671	24113	105	23H
0005433036500	24113	106	24B
0005432207672	24113	107	24A
0005433922407	24113	108	24D
0005433922461	24113	109	24F
0005433923186	24113	110	24E
0005433923221	24113	111	24G
0005433922693	24113	112	25D
0005433036513	24113	113	24H
0005433922692	24113	114	25E
0005432206222	24113	115	27A
0005433036530	24113	116	25F
0005432206220	24113	117	27D
0005433922988	24113	118	27B
0005432749795	24113	119	27H
0005433036508	24113	120	28A
0005433036495	24113	121	28B
0005433923135	24113	122	28E
0005433036506	24113	123	28F
0005433923224	24113	124	28H
0005432206218	24113	125	28G
0005433922993	24113	126	29A
0005433036512	24113	127	29D
0005433929604	24113	128	29B
0005433922380	24113	129	29H
0005433036524	24113	130	30A
0005433036525	24113	131	30D
0005433036526	24113	132	30E
0005433929612	24113	133	30F
0005433931443	24113	134	30H
0005433923047	24113	135	31E
0005433923166	24113	136	31D
0005433922799	24113	137	31F
0005433922320	24113	138	31G
0005433922680	24113	139	32A
0005433036519	24113	140	31H
0005433036493	24113	141	32D
0005433922844	24113	142	32B
0005433036514	24113	143	32F
0005433036537	24113	144	32G
0005433922462	24113	145	33A
0005433036510	24113	146	33B
0005433036518	24113	147	33E
0005433923320	24113	148	33D
0005433923287	24113	149	33G
0005433922817	24113	150	33F
0005433922398	24113	151	33H
0005433923139	24113	152	34A
0005433922417	24113	153	34D
0005433931454	24113	154	34E
0005433036520	24113	155	34G
0005433923009	24113	156	35A
0005433036511	24113	157	35D
0005433922891	24113	158	35B
0005433922902	24113	159	35F
0005433922819	24113	160	35E
0005433036529	24113	161	36A
0005434028310	24113	162	35H
0005433036535	24113	163	36B
0005433922477	24113	164	36E
0005433923134	24113	165	36H
0005433922738	24113	166	36G
0005433922843	24113	167	37D
0005433036507	24113	168	37B
0005433922732	24113	169	37E
0005433922813	24113	170	37H
0005433036532	24113	171	37G
0005433922914	24113	172	38A
0005433922322	24113	173	38D
0005433922615	24113	174	38B
0005432206219	24113	175	38E
0005433923222	24113	176	38G
0005433923046	24113	177	38H
0005433922723	24113	178	39E
0005432749794	24113	179	39D
0005433036499	24113	180	39F
0005433180966	298	1	1A
0005434725923	298	2	1G
0005434725955	298	3	1D
0005434551471	298	4	1K
0005434726015	298	5	1H
0005434726010	298	6	2D
0005433180999	298	7	2C
0005434725921	298	8	2A
0005434725996	298	9	2H
0005433180896	298	10	2G
0005434726008	298	11	3A
0005433234049	298	12	2K
0005433766621	298	13	3D
0005434725973	298	14	3C
0005434551456	298	15	3G
0005433233980	298	16	4C
0005434032000	298	17	4A
0005433233834	298	18	3K
0005434725936	298	19	4G
0005432277861	298	20	4D
0005434725998	298	21	5A
0005434726000	298	22	4K
0005434726031	298	23	4H
0005434551439	298	24	5D
0005433233793	298	25	5C
0005434726013	298	26	5G
0005434725978	298	27	11A
0005434726020	298	28	5K
0005434551462	298	29	11E
0005434551481	298	30	11D
0005434725969	298	31	11C
0005433113527	298	32	11G
0005433233770	298	33	11F
0005434551447	298	34	11H
0005434302478	298	35	12C
0005434725981	298	36	12A
0005434551464	298	37	11K
0005433181038	298	38	12F
0005433126824	298	39	12E
0005433233886	298	40	12D
0005434551480	298	41	12G
0005433180982	298	42	13A
0005434726017	298	43	12K
0005434551453	298	44	12H
0005434725940	298	45	13C
0005434725918	298	46	13F
0005434551457	298	47	13E
0005434551486	298	48	13D
0005433180991	298	49	13H
0005433131693	298	50	13G
0005433180918	298	51	14C
0005434726034	298	52	13K
0005434726003	298	53	14E
0005433234030	298	54	14D
0005434551468	298	55	14G
0005433766608	298	56	14F
0005433113536	298	57	14H
0005434726006	298	58	15A
0005433233909	298	59	15F
0005433234027	298	60	15E
0005434726012	298	61	15D
0005433289832	298	62	15K
0005434551482	298	63	16D
0005433766607	298	64	16F
0005433181004	298	65	16E
0005432277868	298	66	16H
0005433180884	298	67	16G
0005434551485	298	68	17C
0005434551455	298	69	17A
0005434725945	298	70	16K
0005432277859	298	71	17E
0005434725913	298	72	17D
0005434725966	298	73	17G
0005434551459	298	74	17F
0005433181082	298	75	17K
0005434731185	298	76	17H
0005433181039	298	77	18C
0005435142630	298	78	18E
0005434725992	298	79	18G
0005433126841	298	80	18F
0005434725927	298	81	18J
0005434551438	298	82	19B
0005434726028	298	83	19A
0005434551492	298	84	18K
0005433181005	298	85	19D
0005433111483	298	86	19F
0005433233653	298	87	19E
0005434551461	298	88	19H
0005433233953	298	89	19G
0005433233922	298	90	20A
0005433289808	298	91	19K
0005433180895	298	92	19J
0005434031999	298	93	20C
0005433180974	298	94	20E
0005434551465	298	95	20D
0005434725943	298	96	20G
0005434725958	298	97	20K
0005434302475	298	98	20J
0005434725993	298	99	21B
0005434725997	298	100	21A
0005433233654	298	101	21C
0005434725939	298	102	21G
0005433234152	298	103	21F
0005433289794	298	104	21J
0005434031987	298	105	21H
0005434726005	298	106	22A
0005435142627	298	107	21K
0005433766606	298	108	22C
0005434551440	298	109	22B
0005434725976	298	110	22E
0005434725986	298	111	22D
0005434032004	298	112	22H
0005433180979	298	113	22G
0005434551472	298	114	22F
0005434551467	298	115	22K
0005435142637	298	116	22J
0005434725977	298	117	23B
0005434725980	298	118	23E
0005433180975	298	119	23D
0005433180951	298	120	23C
0005434726016	298	121	23H
0005434551488	298	122	23G
0005434725937	298	123	24D
0005433233978	298	124	23K
0005434551477	298	125	23J
0005434725919	298	126	24G
0005434725962	298	127	24F
0005434726022	298	128	25A
0005433766626	298	129	25D
0005434726030	298	130	25C
0005432277869	298	131	25B
0005434725926	298	132	25F
0005434725948	298	133	25E
0005433181011	298	134	25J
0005434725999	298	135	25H
0005433180978	298	136	25G
0005432277867	298	137	26A
0005433233908	298	138	25K
0005434725961	298	139	26C
0005434551466	298	140	26B
0005434725963	298	141	26E
0005433180973	298	142	26D
0005435142633	298	143	26F
0005433180892	298	144	26J
0005433234029	298	145	27B
0005434725987	298	146	27A
0005434726026	298	147	26K
0005433766627	298	148	27D
0005434725979	298	149	27C
0005433181036	298	150	27F
0005433180976	298	151	27E
0005433181066	298	152	27J
0005433233946	298	153	27G
0005433289818	298	154	27K
0005433180917	298	155	28C
0005434551470	298	156	28B
0005434551445	298	157	28E
0005434551444	298	158	28G
0005434725985	298	159	28F
0005433233617	298	160	28K
0005435142638	298	161	28J
0005433180990	298	162	28H
0005434725941	298	163	29A
0005433233923	298	164	29C
0005433181037	298	165	29B
0005433233963	298	166	29F
0005434725956	298	167	29E
0005433233945	298	168	29H
0005433234150	298	169	29G
0005434031995	298	170	30A
0005434726011	298	171	29K
0005433234062	298	172	30B
0005433233661	298	173	30E
0005433233529	298	174	30G
0005434551443	298	175	30F
0005433234077	298	176	30J
0005434725932	298	177	30H
0005434725968	298	178	31A
0005434725952	298	179	30K
0005434725942	298	180	31D
0005434551478	298	181	31C
0005434726009	298	182	31B
0005434551460	298	183	31F
0005434725989	298	184	31E
0005433233810	298	185	31J
0005434735706	298	186	31H
0005433233769	298	187	31G
0005434725916	298	188	32A
0005434725972	298	189	31K
0005434725949	298	190	32B
0005434726027	298	191	32E
0005433234087	298	192	32D
0005434726025	298	193	32C
0005433233928	298	194	32G
0005434551449	298	195	32K
0005433233736	298	196	32J
0005434551484	298	197	32H
0005432277862	298	198	33B
0005434725960	298	199	33A
0005434551489	298	200	33D
0005434551479	298	201	33C
0005434726004	298	202	33G
0005434551446	298	203	33F
0005434726029	298	204	33E
0005433233904	298	205	33H
0005434551491	298	206	34A
0005434725954	298	207	33K
0005434551442	298	208	34C
0005433113528	298	209	34B
0005435142636	298	210	34G
0005434725988	298	211	34F
0005433111498	298	212	34K
0005435142626	298	213	34J
0005433233931	298	214	34H
0005433233906	298	215	35B
0005434725970	298	216	35A
0005434725950	298	217	35D
0005433180955	298	218	35C
0005434551454	298	219	35F
0005434725983	298	220	35H
0005433233932	298	221	35G
0005434726033	298	222	35J
0005433234061	298	223	36C
0005434731184	298	224	36B
0005435142632	298	225	36E
0005433233751	298	226	36H
0005433234233	298	227	36G
0005432277870	298	228	36F
0005433289793	298	229	37B
0005434725971	298	230	37A
0005434735705	298	231	36K
0005435142634	298	232	37D
0005434735708	298	233	37C
0005434551450	298	234	37G
0005434725917	298	235	37F
0005433233971	298	236	37E
0005434725974	298	237	37J
0005434725929	298	238	37H
0005434302477	298	239	37K
0005434735707	298	240	38C
0005434551474	298	241	38B
0005433233874	298	242	38H
0005433766622	298	243	39B
0005435142631	298	244	39A
0005433233840	298	245	38K
0005433233865	298	246	39D
0005434725959	298	247	39C
0005434725925	298	248	39F
0005433180958	298	249	39E
0005433181020	298	250	39J
0005434551490	298	251	39H
0005434725975	298	252	39G
0005434726019	298	253	40A
0005433233734	298	254	39K
0005433233818	298	255	40C
0005434725994	298	256	40B
0005434726018	298	257	40E
0005433113532	298	258	40D
0005432277865	298	259	40H
0005434725967	298	260	40G
0005433233949	298	261	40F
0005434725965	298	262	40K
0005434725990	298	263	40J
0005434551483	298	264	41B
0005434725922	298	265	41A
0005434726002	298	266	41D
0005434725946	298	267	41C
0005433111484	298	268	41F
0005434551493	298	269	41E
0005435142635	298	270	41J
0005433181081	298	271	41G
0005434551476	298	272	41K
0005434725951	298	273	42C
0005434726007	298	274	42B
0005434551473	298	275	42A
0005434725924	298	276	42E
0005435142628	298	277	42D
0005434735704	298	278	42G
0005434551452	298	279	42F
0005434725947	298	280	42J
0005434551469	298	281	42H
0005433233952	298	282	43B
0005434726035	298	283	43A
0005434726032	298	284	42K
0005434551487	298	285	43D
0005433233979	298	286	43C
0005434725991	298	287	43F
0005433233811	298	288	43E
0005434725995	298	289	43H
0005433234012	298	290	43G
0005434725930	298	291	44A
0005434551441	298	292	43K
0005433180959	298	293	43J
0005434725957	298	294	44B
0005434725953	298	295	44E
0005433180967	298	296	44D
0005434725938	298	297	44H
0005434726023	298	298	44G
0005434551458	298	299	44J
0005432277863	298	300	45B
0005434725914	298	301	45A
0005434725915	298	302	44K
0005434032001	298	303	45C
0005434726014	298	304	45F
0005434725964	298	305	45E
0005433289815	298	306	45D
0005434725920	298	307	45G
0005434725944	298	308	45J
0005433233682	298	309	46C
0005433180964	298	310	46B
0005434725982	298	311	46E
0005433233991	298	312	46G
0005432277866	298	313	46F
0005434726001	298	314	46K
0005434551463	298	315	46J
0005433180920	298	316	46H
0005433233780	298	317	47C
0005434725935	298	318	47A
0005433233792	298	319	47E
0005434731186	298	320	47D
0005434726021	298	321	47F
0005433234085	298	322	47K
0005433234023	298	323	47H
0005434551475	298	324	48C
0005433180890	298	325	48F
0005434551451	298	326	48D
0005434302476	298	327	48H
0005434725933	298	328	48G
0005433233905	298	329	49A
0005434726024	298	330	48K
0005434725931	298	331	49E
0005432277860	298	332	49D
0005435142629	298	333	49K
0005434725928	298	334	49G
0005434725934	298	335	50C
0005433233864	298	336	50A
0005433181059	298	337	50E
0005432277864	298	338	50D
0005434725984	298	339	50G
0005435142639	298	340	50F
0005433180831	298	341	50K
0005433234028	298	342	50H
0005434726036	298	343	51E
0005434551448	298	344	51G
0005434551109	9831	1	1C
0005434725290	9831	2	1A
0005434550928	9831	3	1G
0005433289877	9831	4	1D
0005433234492	9831	5	1K
0005433234474	9831	6	1H
0005434725287	9831	7	2C
0005434725030	9831	8	2A
0005435142498	9831	9	2G
0005434550986	9831	10	2D
0005434724794	9831	11	3A
0005433181194	9831	12	2K
0005433181198	9831	13	2H
0005433234495	9831	14	3G
0005434724302	9831	15	3C
0005434735654	9831	16	3K
0005434725409	9831	17	3H
0005434724912	9831	18	4G
0005433234488	9831	19	4D
0005434725399	9831	20	4K
0005434725386	9831	21	4H
0005434735678	9831	22	5D
0005435142521	9831	23	5C
0005434724773	9831	24	5A
0005433234482	9831	25	5H
0005433234487	9831	26	5G
0005434551012	9831	27	11A
0005432199275	9831	28	5K
0005434725238	9831	29	11D
0005433234476	9831	30	11C
0005433234457	9831	31	11G
0005432199273	9831	32	11F
0005434735684	9831	33	11K
0005433181191	9831	34	12C
0005433234453	9831	35	12A
0005433234437	9831	36	12F
0005433234443	9831	37	12D
0005434724997	9831	38	12G
0005433234452	9831	39	12K
0005434724517	9831	40	13D
0005434302445	9831	41	13A
0005433181197	9831	42	13F
0005433126865	9831	43	13E
0005434735656	9831	44	13H
0005433129295	9831	45	13G
0005433113545	9831	46	14A
0005433766655	9831	47	13K
0005434725057	9831	48	14E
0005434550560	9831	49	14D
0005434725163	9831	50	14C
0005434725124	9831	51	14G
0005433234454	9831	52	14H
0005434724842	9831	53	15C
0005434550888	9831	54	15A
0005434724984	9831	55	15E
0005434725308	9831	56	15D
0005433181211	9831	57	15H
0005435142486	9831	58	15G
0005434725289	9831	59	15F
0005434725187	9831	60	15K
0005433126862	9831	61	16D
0005433234470	9831	62	16C
0005434725339	9831	63	16A
0005434550629	9831	64	16H
0005434724862	9831	65	16G
0005433234438	9831	66	17A
0005434550990	9831	67	16K
0005434725034	9831	68	17E
0005433289875	9831	69	17D
0005434724896	9831	70	17C
0005434724518	9831	71	17G
0005434551122	9831	72	17F
0005434724131	9831	73	17K
0005434724998	9831	74	17H
0005434550658	9831	75	18C
0005434725000	9831	76	18B
0005434550712	9831	77	18A
0005434724981	9831	78	18E
0005434725401	9831	79	18G
0005434735691	9831	80	18J
0005434725020	9831	81	18H
0005434032043	9831	82	19B
0005434725400	9831	83	19A
0005434725288	9831	84	19D
0005433129293	9831	85	19C
0005433181203	9831	86	19F
0005434724956	9831	87	19E
0005434724282	9831	88	19H
0005433234460	9831	89	19G
0005434725136	9831	90	20A
0005435142519	9831	91	19K
0005434725264	9831	92	19J
0005434724849	9831	93	20B
0005433234479	9831	94	20E
0005435142520	9831	95	20D
0005433234471	9831	96	20C
0005435142569	9831	97	20G
0005433234446	9831	98	20F
0005434725105	9831	99	20K
0005433234433	9831	100	20J
0005433181207	9831	101	20H
0005434550955	9831	102	21B
0005434551085	9831	103	21A
0005434735655	9831	104	21D
0005432199276	9831	105	21C
0005432199279	9831	106	21F
0005435142482	9831	107	21E
0005434724855	9831	108	21J
0005434724887	9831	109	21G
0005434724063	9831	110	22A
0005433181202	9831	111	21K
0005434724977	9831	112	22C
0005434550843	9831	113	22B
0005434725184	9831	114	22E
0005433234483	9831	115	22D
0005433234439	9831	116	22G
0005434550939	9831	117	22F
0005434724920	9831	118	22K
0005434725234	9831	119	22J
0005434724853	9831	120	23B
0005433234468	9831	121	23A
0005433234461	9831	122	23G
0005434724566	9831	123	23F
0005434550984	9831	124	23E
0005434550975	9831	125	23J
0005434735685	9831	126	23H
0005434032046	9831	127	23K
0005432199277	9831	128	24G
0005434735692	9831	129	24F
0005433289873	9831	130	24E
0005433234466	9831	131	25A
0005434550630	9831	132	25C
0005433181193	9831	133	25B
0005434724702	9831	134	25F
0005434724779	9831	135	25E
0005434725004	9831	136	25D
0005434550842	9831	137	25J
0005433234480	9831	138	25H
0005434724982	9831	139	26A
0005433234445	9831	140	26B
0005434724913	9831	141	26E
0005433289879	9831	142	26D
0005434550772	9831	143	26H
0005434725069	9831	144	26G
0005433234475	9831	145	26F
0005434725342	9831	146	26J
0005432199278	9831	147	27B
0005434551201	9831	148	27A
0005434550954	9831	149	26K
0005433234491	9831	150	27D
0005434724817	9831	151	27C
0005434724281	9831	152	27E
0005434724805	9831	153	27H
0005434724823	9831	154	27G
0005434724780	9831	155	27K
0005434724730	9831	156	27J
0005434735658	9831	157	28B
0005433289876	9831	158	28A
0005434551108	9831	159	28E
0005433181216	9831	160	28D
0005434551052	9831	161	28G
0005433234442	9831	162	28F
0005434735659	9831	163	28J
0005434725248	9831	164	28H
0005434725021	9831	165	29A
0005434724999	9831	166	28K
0005433234465	9831	167	29C
0005434724916	9831	168	29B
0005434550991	9831	169	29F
0005434725230	9831	170	29D
0005433234463	9831	171	29J
0005434550978	9831	172	29H
0005434725035	9831	173	29K
0005434550929	9831	174	30A
0005434551034	9831	175	30E
0005434724701	9831	176	30G
0005435142428	9831	177	30F
0005433181204	9831	178	30J
0005434725088	9831	179	30H
0005434724565	9831	180	31B
0005434724879	9831	181	31A
0005434724804	9831	182	31D
0005433234464	9831	183	31C
0005434550972	9831	184	31F
0005433234494	9831	185	31E
0005435142485	9831	186	31G
0005433766656	9831	187	32A
0005433234434	9831	188	31K
0005434725236	9831	189	32B
0005434032045	9831	190	32E
0005434550920	9831	191	32D
0005434724964	9831	192	32C
0005433181200	9831	193	32G
0005434724675	9831	194	32F
0005433181210	9831	195	32J
0005434551091	9831	196	32H
0005434032042	9831	197	33A
0005433181209	9831	198	33D
0005434725036	9831	199	33C
0005433234447	9831	200	33F
0005434724245	9831	201	33E
0005435142483	9831	202	33H
0005434724880	9831	203	33G
0005434725031	9831	204	33K
0005434551032	9831	205	33J
0005433766654	9831	206	34C
0005434550934	9831	207	34B
0005433126864	9831	208	34A
0005434550848	9831	209	34E
0005434725310	9831	210	34D
0005434725162	9831	211	34G
0005434551025	9831	212	34F
0005433234436	9831	213	34J
0005433766657	9831	214	34H
0005433234490	9831	215	35B
0005434724955	9831	216	35A
0005433234493	9831	217	35D
0005434551114	9831	218	35C
0005434550977	9831	219	35F
0005434551092	9831	220	35E
0005434551086	9831	221	35H
0005433181212	9831	222	35K
0005434735686	9831	223	36C
0005434725223	9831	224	36E
0005433129292	9831	225	36D
0005434725241	9831	226	36G
0005434725056	9831	227	36F
0005434724767	9831	228	36J
0005433234462	9831	229	36H
0005434550992	9831	230	37C
0005434032044	9831	231	37B
0005433234451	9831	232	37A
0005433234440	9831	233	37D
0005433234489	9831	234	37F
0005433181214	9831	235	37E
0005433234448	9831	236	37J
0005433234469	9831	237	37H
0005433129294	9831	238	37K
0005434550995	9831	239	38C
0005434724427	9831	240	38B
0005433234477	9831	241	38K
0005433181213	9831	242	38J
0005435142408	9831	243	38H
0005434550985	9831	244	39D
0005433181201	9831	245	39C
0005434725113	9831	246	39B
0005434724868	9831	247	39F
0005434725087	9831	248	39E
0005433234486	9831	249	39H
0005434724772	9831	250	39G
0005434724251	9831	251	40A
0005433234435	9831	252	39K
0005434550974	9831	253	39J
0005435142473	9831	254	40C
0005434725442	9831	255	40B
0005434724852	9831	256	40E
0005433234456	9831	257	40D
0005433129296	9831	258	40H
0005434725237	9831	259	40G
0005434551019	9831	260	40F
0005433234472	9831	261	40K
0005433234449	9831	262	41B
0005433234450	9831	263	41A
0005434551033	9831	264	41D
0005434725067	9831	265	41C
0005433234444	9831	266	41F
0005434550914	9831	267	41E
0005434550989	9831	268	41J
0005434724674	9831	269	41H
0005433234467	9831	270	41G
0005434725185	9831	271	42A
0005433234481	9831	272	41K
0005433181195	9831	273	42C
0005434724854	9831	274	42E
0005434725341	9831	275	42D
0005434550908	9831	276	42G
0005434724921	9831	277	42F
0005433234496	9831	278	42J
0005434725197	9831	279	42H
0005434725089	9831	280	43B
0005433289880	9831	281	42K
0005434724731	9831	282	43D
0005434725068	9831	283	43C
0005433234473	9831	284	43F
0005433289878	9831	285	43H
0005433126861	9831	286	44A
0005434725235	9831	287	43K
0005434550849	9831	288	43J
0005434550910	9831	289	44C
0005433234484	9831	290	44B
0005434725217	9831	291	44D
0005434551123	9831	292	44H
0005433126863	9831	293	44G
0005434725086	9831	294	44F
0005434550971	9831	295	44J
0005433181196	9831	296	45B
0005433181208	9831	297	45A
0005433181192	9831	298	44K
0005435142522	9831	299	45D
0005434724252	9831	300	45F
0005434724850	9831	301	45E
0005433766658	9831	302	45J
0005434550962	9831	303	45H
0005433234459	9831	304	45G
0005432199274	9831	305	46A
0005433234441	9831	306	45K
0005434551013	9831	307	46C
0005434724976	9831	308	46B
0005434724952	9831	309	46E
0005434725090	9831	310	46D
0005434725240	9831	311	46G
0005434550909	9831	312	46F
0005434551115	9831	313	46J
0005434550813	9831	314	46H
0005434724651	9831	315	47C
0005434550922	9831	316	47A
0005434550618	9831	317	47E
0005434725476	9831	318	47D
0005433181215	9831	319	47F
0005434724483	9831	320	47K
0005434550923	9831	321	47H
0005434725045	9831	322	48D
0005434725269	9831	323	48A
0005434724863	9831	324	48F
0005433234458	9831	325	48E
0005433234478	9831	326	48H
0005434550924	9831	327	48G
0005433181206	9831	328	49A
0005433181205	9831	329	48K
0005434735673	9831	330	49E
0005434550880	9831	331	49D
0005433234485	9831	332	49C
0005434551050	9831	333	49K
0005434550713	9831	334	49H
0005434551093	9831	335	50D
0005433289874	9831	336	50A
0005434550921	9831	337	50E
0005435142484	9831	338	50G
0005435142472	9831	339	50F
0005435142570	9831	340	50H
0005433113544	9831	341	51F
0005433181199	9831	342	51E
0005433234455	9831	343	51G
0005432528466	7739	1	1C
0005435213409	7739	2	1A
0005432528462	7739	3	1G
0005435213097	7739	4	1D
0005432528584	7739	5	1K
0005432528493	7739	6	1H
0005432069717	7739	7	2C
0005435213302	7739	8	2A
0005432528479	7739	9	2H
0005434067877	7739	10	2K
0005435212868	7739	11	3D
0005432528497	7739	12	3C
0005432528469	7739	13	3K
0005433656647	7739	14	3H
0005432528560	7739	15	4G
0005435212964	7739	16	4D
0005432528536	7739	17	4K
0005432535851	7739	18	5C
0005432528503	7739	19	5A
0005432528526	7739	20	5G
0005432528537	7739	21	5D
0005434067879	7739	22	11A
0005435212928	7739	23	5K
0005434067835	7739	24	11D
0005432528460	7739	25	11E
0005432528453	7739	26	11K
0005432528534	7739	27	11H
0005432528568	7739	28	11G
0005435213380	7739	29	12C
0005435212998	7739	30	12A
0005434067862	7739	31	12E
0005432535856	7739	32	12D
0005435213128	7739	33	12G
0005432528578	7739	34	13A
0005432528535	7739	35	12K
0005432150227	7739	36	12H
0005435213324	7739	37	13C
0005432069712	7739	38	13F
0005432528492	7739	39	13H
0005435213116	7739	40	13G
0005434067850	7739	41	14C
0005432528456	7739	42	13K
0005432528523	7739	43	14E
0005432528582	7739	44	14D
0005435212965	7739	45	14G
0005434067875	7739	46	14F
0005432069721	7739	47	14K
0005435725562	7739	48	14H
0005432528501	7739	49	15C
0005434067822	7739	50	15E
0005432528484	7739	51	15D
0005432528550	7739	52	15G
0005435213144	7739	53	15F
0005432069715	7739	54	16A
0005432528451	7739	55	15K
0005432528575	7739	56	15H
0005434067865	7739	57	16C
0005432528500	7739	58	16E
0005435213169	7739	59	16G
0005435213258	7739	60	17C
0005432528542	7739	61	17A
0005432069709	7739	62	16K
0005432069708	7739	63	17E
0005432069716	7739	64	17D
0005432528467	7739	65	17F
0005434067833	7739	66	18A
0005434067838	7739	67	17K
0005432528548	7739	68	17H
0005432528482	7739	69	18C
0005435213378	7739	70	18B
0005435213410	7739	71	18E
0005434067882	7739	72	18G
0005432528512	7739	73	18F
0005434067886	7739	74	18J
0005432528510	7739	75	18H
0005432150229	7739	76	18K
0005432528454	7739	77	19D
0005432537066	7739	78	19C
0005435213158	7739	79	19B
0005432528455	7739	80	19G
0005435213319	7739	81	19F
0005435213405	7739	82	19E
0005432528511	7739	83	19J
0005434067881	7739	84	19H
0005435213259	7739	85	19K
0005432528516	7739	86	20C
0005432528508	7739	87	20A
0005433656645	7739	88	20G
0005435212897	7739	89	20F
0005434067869	7739	90	20J
0005432069718	7739	91	20H
0005432528476	7739	92	21A
0005432528532	7739	93	20K
0005432528515	7739	94	21C
0005432528496	7739	95	21B
0005432528480	7739	96	21F
0005432528522	7739	97	21E
0005432528504	7739	98	21H
0005432528475	7739	99	21G
0005435213371	7739	100	22A
0005432528577	7739	101	21K
0005435213268	7739	102	21J
0005435213333	7739	103	22C
0005432528529	7739	104	22E
0005432528459	7739	105	22G
0005432528463	7739	106	22K
0005432528502	7739	107	22J
0005432528498	7739	108	22H
0005434067840	7739	109	23D
0005432535852	7739	110	23C
0005432069720	7739	111	23G
0005432528571	7739	112	23F
0005432528544	7739	113	23E
0005432528472	7739	114	23H
0005432528477	7739	115	24D
0005435725572	7739	116	23K
0005432150225	7739	117	23J
0005432528452	7739	118	24F
0005434067841	7739	119	24E
0005432528519	7739	120	25B
0005434067839	7739	121	25A
0005432528458	7739	122	24G
0005432528474	7739	123	25D
0005435213269	7739	124	25F
0005432535855	7739	125	25E
0005432528566	7739	126	25H
0005434067891	7739	127	25K
0005435213106	7739	128	25J
0005435213030	7739	129	26C
0005432528541	7739	130	26B
0005434067884	7739	131	26A
0005434067880	7739	132	26E
0005434067825	7739	133	26D
0005435212898	7739	134	26J
0005432528546	7739	135	26H
0005432528528	7739	136	27A
0005432528573	7739	137	27D
0005432528464	7739	138	27B
0005434067844	7739	139	27F
0005432528518	7739	140	27E
0005432528576	7739	141	27H
0005432528506	7739	142	27G
0005432528461	7739	143	28A
0005432528489	7739	144	27K
0005432528555	7739	145	28C
0005432528527	7739	146	28E
0005434067845	7739	147	28D
0005435213236	7739	148	28G
0005432150228	7739	149	28F
0005432528572	7739	150	28J
0005434067859	7739	151	28H
0005434067868	7739	152	28K
0005435212936	7739	153	29C
0005432528520	7739	154	29B
0005435212999	7739	155	29G
0005433656634	7739	156	29E
0005435725582	7739	157	29K
0005434067837	7739	158	29J
0005432528561	7739	159	30C
0005432528552	7739	160	30A
0005432150223	7739	161	30D
0005435212961	7739	162	30G
0005435213381	7739	163	30F
0005432528569	7739	164	30E
0005432528513	7739	165	30K
0005432528488	7739	166	30J
0005434067834	7739	167	30H
0005434067821	7739	168	31A
0005432528470	7739	169	31C
0005435212927	7739	170	31F
0005432528545	7739	171	31E
0005435213294	7739	172	31J
0005432428942	7739	173	31H
0005432528579	7739	174	31G
0005434067863	7739	175	32A
0005432528486	7739	176	31K
0005434067856	7739	177	32C
0005432528509	7739	178	32B
0005432528574	7739	179	32E
0005435213404	7739	180	32G
0005434067836	7739	181	32F
0005435213370	7739	182	32K
0005432069710	7739	183	32J
0005432428943	7739	184	32H
0005434067861	7739	185	33B
0005434067860	7739	186	33A
0005435213109	7739	187	33D
0005435212972	7739	188	33C
0005432528540	7739	189	33F
0005434067843	7739	190	33E
0005432528471	7739	191	33J
0005435213313	7739	192	33H
0005435725563	7739	193	33G
0005432528494	7739	194	34A
0005432528543	7739	195	34B
0005435213332	7739	196	34E
0005432528558	7739	197	34D
0005434067852	7739	198	34C
0005432528473	7739	199	34G
0005435213077	7739	200	34F
0005432537065	7739	201	34K
0005432528570	7739	202	35B
0005435213320	7739	203	35D
0005434067873	7739	204	35C
0005432528580	7739	205	35F
0005432528478	7739	206	35E
0005434067851	7739	207	35H
0005432069719	7739	208	35G
0005435213280	7739	209	35K
0005434067828	7739	210	35J
0005432537067	7739	211	36C
0005432528559	7739	212	36E
0005435213594	7739	213	36G
0005434067872	7739	214	36K
0005432069711	7739	215	36H
0005434067889	7739	216	37B
0005434067827	7739	217	37A
0005434067867	7739	218	37D
0005434067866	7739	219	37C
0005432528531	7739	220	37G
0005432528581	7739	221	37E
0005435213248	7739	222	37J
0005432528554	7739	223	37H
0005434067887	7739	224	38A
0005435213075	7739	225	37K
0005432528517	7739	226	38C
0005432528465	7739	227	38B
0005435213110	7739	228	38K
0005432528524	7739	229	38J
0005434067871	7739	230	39A
0005432528549	7739	231	39D
0005432069713	7739	232	39C
0005432535853	7739	233	39G
0005432528525	7739	234	39F
0005432069714	7739	235	39E
0005434067854	7739	236	39J
0005435213270	7739	237	39H
0005434067853	7739	238	40A
0005435213127	7739	239	39K
0005435213282	7739	240	40C
0005435212937	7739	241	40B
0005434067855	7739	242	40E
0005432150226	7739	243	40D
0005432528567	7739	244	40G
0005432528563	7739	245	40K
0005432528495	7739	246	40J
0005434067874	7739	247	41A
0005432528468	7739	248	41D
0005435213247	7739	249	41C
0005434067878	7739	250	41B
0005432533304	7739	251	41E
0005432535857	7739	252	41J
0005435213520	7739	253	41H
0005432069707	7739	254	41G
0005434067885	7739	255	41K
0005434067858	7739	256	42C
0005435213222	7739	257	42B
0005435213281	7739	258	42E
0005432528491	7739	259	42D
0005432533303	7739	260	42F
0005435213494	7739	261	42K
0005432528533	7739	262	42J
0005432528539	7739	263	42H
0005435213325	7739	264	43A
0005435213182	7739	265	43C
0005434067831	7739	266	43B
0005435213035	7739	267	43F
0005435213076	7739	268	43E
0005432150231	7739	269	43D
0005435213278	7739	270	43J
0005432528505	7739	271	43H
0005434067888	7739	272	44A
0005434067823	7739	273	44B
0005435213237	7739	274	44G
0005432528564	7739	275	44F
0005432528457	7739	276	44J
0005434067890	7739	277	44H
0005432528547	7739	278	45A
0005434067876	7739	279	45D
0005432528553	7739	280	45C
0005433656653	7739	281	45B
0005435213098	7739	282	45E
0005432528483	7739	283	45H
0005434067848	7739	284	45G
0005432150224	7739	285	46A
0005434067846	7739	286	45K
0005432528556	7739	287	46C
0005435213264	7739	288	46B
0005434067826	7739	289	46D
0005432528487	7739	290	46G
0005432528485	7739	291	46F
0005432528521	7739	292	46H
0005435725555	7739	293	47C
0005434067829	7739	294	47A
0005434067857	7739	295	46K
0005434067847	7739	296	47D
0005432528514	7739	297	47G
0005434067820	7739	298	47F
0005432528562	7739	299	47K
0005434067870	7739	300	47H
0005432528499	7739	301	48C
0005434067883	7739	302	48A
0005434067864	7739	303	48F
0005432528551	7739	304	48E
0005434067849	7739	305	48H
0005434067842	7739	306	49A
0005432528557	7739	307	48K
0005432428944	7739	308	49D
0005432528481	7739	309	49C
0005435212973	7739	310	49G
0005432535854	7739	311	49F
0005435213183	7739	312	49E
0005432528565	7739	313	49K
0005435213495	7739	314	49H
0005432528583	7739	315	50A
0005432528507	7739	316	50E
0005432528490	7739	317	50D
0005434067824	7739	318	50G
0005434067830	7739	319	50F
0005434067832	7739	320	51D
0005432528530	7739	321	50K
0005432528538	7739	322	50H
0005432150230	7739	323	51G
0005435097243	5360	1	1C
0005435424582	5360	2	1A
0005434244876	5360	3	1H
0005435614077	5360	4	1D
0005435424505	5360	5	2A
0005432363394	5360	6	1K
0005432133276	5360	7	2D
0005435614166	5360	8	2C
0005434344386	5360	9	2G
0005435614115	5360	10	3A
0005434244702	5360	11	2K
0005435424491	5360	12	3D
0005434344381	5360	13	3C
0005434244922	5360	14	3K
0005435614153	5360	15	3H
0005435424764	5360	16	4C
0005434344372	5360	17	4A
0005435424511	5360	18	4H
0005435614103	5360	19	4G
0005435614090	5360	20	4D
0005435424599	5360	21	5A
0005435490241	5360	22	4K
0005435614092	5360	23	5C
0005435424577	5360	24	5H
0005434344390	5360	25	5G
0005434573405	5360	26	5D
0005434344365	5360	27	11A
0005435614160	5360	28	5K
0005434244902	5360	29	11E
0005434344370	5360	30	11D
0005435424728	5360	31	11C
0005434344379	5360	32	11F
0005435614127	5360	33	11K
0005435614095	5360	34	11H
0005435614137	5360	35	11G
0005432133267	5360	36	12C
0005435319549	5360	37	12A
0005435614081	5360	38	12E
0005435614110	5360	39	12D
0005435614093	5360	40	12H
0005434344367	5360	41	12G
0005435614113	5360	42	13A
0005434344395	5360	43	12K
0005432133274	5360	44	13D
0005435424418	5360	45	13C
0005435424806	5360	46	13F
0005434344388	5360	47	13E
0005434344394	5360	48	13H
0005432133272	5360	49	13G
0005435424522	5360	50	14A
0005435614082	5360	51	13K
0005435380275	5360	52	14E
0005435424077	5360	53	14D
0005435424512	5360	54	14C
0005435424888	5360	55	14F
0005435424605	5360	56	14H
0005435302168	5360	57	15C
0005435380265	5360	58	15A
0005435614084	5360	59	14K
0005435614121	5360	60	15E
0005435424552	5360	61	15D
0005435424597	5360	62	15G
0005435614136	5360	63	15F
0005435614140	5360	64	16A
0005434244819	5360	65	15K
0005435097244	5360	66	15H
0005435490243	5360	67	16D
0005434244845	5360	68	16C
0005432133268	5360	69	16G
0005434244904	5360	70	16F
0005434344384	5360	71	16E
0005435424134	5360	72	16H
0005435614150	5360	73	17A
0005435424354	5360	74	16K
0005435614149	5360	75	17E
0005435305007	5360	76	17D
0005432133273	5360	77	17G
0005435380264	5360	78	17F
0005435614162	5360	79	17K
0005435614147	5360	80	17H
0005435614112	5360	81	18B
0005432841001	5360	82	18A
0005434573414	5360	83	18E
0005434344380	5360	84	18D
0005435614083	5360	85	18C
0005435424664	5360	86	18G
0005435424821	5360	87	18F
0005435614099	5360	88	18K
0005434244966	5360	89	18J
0005435614105	5360	90	18H
0005435614173	5360	91	19A
0005435424504	5360	92	19D
0005435097238	5360	93	19C
0005435614098	5360	94	19B
0005435319524	5360	95	19G
0005435614175	5360	96	19F
0005434244804	5360	97	19E
0005435424523	5360	98	19H
0005434244867	5360	99	19K
0005434573407	5360	100	19J
0005435555378	5360	101	20A
0005435614107	5360	102	20E
0005434244866	5360	103	20D
0005435424492	5360	104	20F
0005434244969	5360	105	20K
0005435424567	5360	106	20H
0005435614114	5360	107	21B
0005435097241	5360	108	21A
0005435424654	5360	109	21D
0005435555377	5360	110	21C
0005435424249	5360	111	21F
0005435424120	5360	112	21E
0005435424568	5360	113	21J
0005432363393	5360	114	21H
0005434244762	5360	115	21G
0005435424486	5360	116	22A
0005433719126	5360	117	21K
0005432133275	5360	118	22D
0005434244758	5360	119	22B
0005432133269	5360	120	22E
0005435614076	5360	121	22G
0005435424704	5360	122	22J
0005434573412	5360	123	22H
0005435614169	5360	124	23B
0005434244814	5360	125	23A
0005435424343	5360	126	22K
0005435424428	5360	127	23E
0005434573404	5360	128	23D
0005434573408	5360	129	23F
0005434244872	5360	130	23J
0005435614167	5360	131	23G
0005435424719	5360	132	23K
0005435424550	5360	133	24F
0005435424598	5360	134	24E
0005435424445	5360	135	25A
0005435614131	5360	136	25D
0005434344396	5360	137	25C
0005432047567	5360	138	25B
0005435305000	5360	139	25F
0005435424636	5360	140	25E
0005434244808	5360	141	25H
0005435097240	5360	142	25G
0005432133266	5360	143	26A
0005432133278	5360	144	25J
0005433719105	5360	145	26B
0005434344398	5360	146	26E
0005434344366	5360	147	26D
0005435042838	5360	148	26C
0005435614087	5360	149	26G
0005434244871	5360	150	26K
0005435042843	5360	151	26H
0005435614146	5360	152	27A
0005434244701	5360	153	27D
0005434244903	5360	154	27C
0005434573410	5360	155	27E
0005435614126	5360	156	27H
0005434244815	5360	157	27G
0005435614142	5360	158	27K
0005434344385	5360	159	27J
0005434244897	5360	160	28C
0005434344371	5360	161	28B
0005434244905	5360	162	28E
0005435424604	5360	163	28H
0005435424446	5360	164	28G
0005435614102	5360	165	28F
0005435614158	5360	166	28J
0005435424485	5360	167	29B
0005435614176	5360	168	29A
0005435424720	5360	169	28K
0005432363397	5360	170	29D
0005435614170	5360	171	29C
0005435614129	5360	172	29F
0005432047564	5360	173	29E
0005435614163	5360	174	29H
0005435424540	5360	175	29G
0005432133280	5360	176	30A
0005435614089	5360	177	29K
0005435097236	5360	178	29J
0005434244939	5360	179	30C
0005435614141	5360	180	30B
0005435490245	5360	181	30E
0005435424213	5360	182	30D
0005435614125	5360	183	30H
0005435424651	5360	184	30F
0005435614097	5360	185	30J
0005435614106	5360	186	31A
0005435614154	5360	187	30K
0005434344363	5360	188	31D
0005435614171	5360	189	31C
0005435319558	5360	190	31F
0005435424524	5360	191	31E
0005434244844	5360	192	31J
0005435424393	5360	193	31H
0005435614148	5360	194	31K
0005434244810	5360	195	32C
0005434244638	5360	196	32B
0005435424551	5360	197	32A
0005434344368	5360	198	32E
0005435614117	5360	199	32D
0005433719125	5360	200	32H
0005434344378	5360	201	32F
0005435424565	5360	202	32K
0005434573415	5360	203	32J
0005432841016	5360	204	33B
0005435097245	5360	205	33A
0005435424652	5360	206	33D
0005432363392	5360	207	33C
0005432047565	5360	208	33F
0005435424665	5360	209	33E
0005433719098	5360	210	33G
0005435614143	5360	211	34A
0005434344375	5360	212	33K
0005435424447	5360	213	33J
0005435424566	5360	214	34B
0005435614157	5360	215	34E
0005434344374	5360	216	34D
0005434244968	5360	217	34H
0005435614094	5360	218	34G
0005432133271	5360	219	34F
0005435424483	5360	220	34K
0005435097239	5360	221	34J
0005435424525	5360	222	35B
0005435097237	5360	223	35A
0005435424458	5360	224	35D
0005435097242	5360	225	35C
0005434244851	5360	226	35F
0005435614108	5360	227	35E
0005434344364	5360	228	35J
0005435614079	5360	229	35H
0005434344393	5360	230	35G
0005434244809	5360	231	35K
0005435614122	5360	232	36D
0005435424797	5360	233	36C
0005435424712	5360	234	36B
0005435614091	5360	235	36A
0005435424441	5360	236	36E
0005434344383	5360	237	36H
0005435614172	5360	238	36G
0005435424655	5360	239	36K
0005435424113	5360	240	37B
0005435614138	5360	241	37A
0005435424431	5360	242	37D
0005434344382	5360	243	37C
0005435614156	5360	244	37F
0005435614130	5360	245	37E
0005434573416	5360	246	37H
0005435302178	5360	247	37G
0005435319550	5360	248	38A
0005435614159	5360	249	37K
0005435424355	5360	250	37J
0005435614135	5360	251	38C
0005435319571	5360	252	38B
0005434573417	5360	253	38J
0005435614116	5360	254	38K
0005435424569	5360	255	39C
0005434244995	5360	256	39B
0005434573418	5360	257	39F
0005435490244	5360	258	39E
0005435614101	5360	259	39D
0005435424614	5360	260	39H
0005435614109	5360	261	39K
0005435302177	5360	262	40C
0005435614155	5360	263	40B
0005435424394	5360	264	40D
0005435042844	5360	265	40G
0005435424404	5360	266	40J
0005435614164	5360	267	40K
0005434344369	5360	268	41C
0005432363402	5360	269	41B
0005435614151	5360	270	41F
0005434344373	5360	271	41H
0005435614144	5360	272	41G
0005432133277	5360	273	42A
0005433719134	5360	274	41K
0005435614120	5360	275	41J
0005434344389	5360	276	42C
0005435614134	5360	277	42B
0005432133279	5360	278	42E
0005435424585	5360	279	42D
0005434344362	5360	280	42G
0005432047566	5360	281	42F
0005435424417	5360	282	42K
0005434344397	5360	283	42H
0005434344377	5360	284	43B
0005435614152	5360	285	43C
0005434244820	5360	286	43F
0005435614132	5360	287	43E
0005434573411	5360	288	43H
0005432363396	5360	289	43G
0005435424763	5360	290	44A
0005435614161	5360	291	43K
0005435614096	5360	292	43J
0005435424638	5360	293	44C
0005435319557	5360	294	44B
0005435614168	5360	295	44E
0005434573409	5360	296	44G
0005435614086	5360	297	44F
0005434244791	5360	298	44K
0005435424612	5360	299	44H
0005435614100	5360	300	45A
0005435424637	5360	301	45D
0005435614078	5360	302	45B
0005435614104	5360	303	45F
0005434244757	5360	304	45E
0005434244805	5360	305	45H
0005432363391	5360	306	45G
0005435614080	5360	307	45K
0005432840995	5360	308	45J
0005435614119	5360	309	46B
0005435424539	5360	310	46A
0005435614088	5360	311	46E
0005432133270	5360	312	46D
0005432841000	5360	313	46G
0005435424679	5360	314	46F
0005435614111	5360	315	46J
0005432363405	5360	316	46H
0005435614085	5360	317	47C
0005434344387	5360	318	46K
0005435614118	5360	319	47E
0005435424711	5360	320	47G
0005434344392	5360	321	47F
0005435614139	5360	322	47H
0005435424440	5360	323	48D
0005434244896	5360	324	48C
0005434244906	5360	325	48A
0005435424594	5360	326	48F
0005435490242	5360	327	48E
0005434244792	5360	328	48H
0005434344376	5360	329	48G
0005435424889	5360	330	49A
0005434344391	5360	331	48K
0005435614128	5360	332	49D
0005435614174	5360	333	49C
0005434573406	5360	334	49F
0005435097246	5360	335	49E
0005435424606	5360	336	49K
0005435614123	5360	337	49H
0005434573413	5360	338	49G
0005435614124	5360	339	50C
0005435424541	5360	340	50A
0005435380276	5360	341	50F
0005435614145	5360	342	50G
0005434244751	5360	343	51D
0005434244938	5360	344	50K
0005435614165	5360	345	51E
0005435614133	5360	346	51G
0005435612686	10882	1	1C
0005435613436	10882	2	1G
0005434344037	10882	3	1D
0005435613101	10882	4	2A
0005435425112	10882	5	1H
0005434245104	10882	6	2D
0005434656564	10882	7	2C
0005435304178	10882	8	2H
0005435613254	10882	9	2G
0005435425084	10882	10	3A
0005435425069	10882	11	2K
0005435425058	10882	12	3G
0005435613289	10882	13	3C
0005435097135	10882	14	3K
0005435097119	10882	15	3H
0005435613118	10882	16	4C
0005435097149	10882	17	4A
0005435304175	10882	18	4G
0005432363430	10882	19	4D
0005434343896	10882	20	4K
0005435490213	10882	21	5D
0005434344174	10882	22	5C
0005434343968	10882	23	5A
0005435613239	10882	24	5H
0005435613167	10882	25	11A
0005434343883	10882	26	5K
0005435613342	10882	27	11D
0005434245103	10882	28	11G
0005435612992	10882	29	11E
0005435613242	10882	30	11K
0005434344080	10882	31	12C
0005434573247	10882	32	12E
0005435425120	10882	33	12D
0005435425073	10882	34	12G
0005435305018	10882	35	12F
0005435613138	10882	36	12H
0005434245096	10882	37	13D
0005435425062	10882	38	13C
0005435425089	10882	39	13F
0005434344094	10882	40	13E
0005434573199	10882	41	13H
0005435613193	10882	42	13G
0005434245101	10882	43	14A
0005435097116	10882	44	13K
0005434245086	10882	45	14C
0005435097128	10882	46	14F
0005435425107	10882	47	14K
0005434573250	10882	48	14H
0005435612791	10882	49	14G
0005434656565	10882	50	15C
0005435613244	10882	51	15E
0005432363429	10882	52	15D
0005435612965	10882	53	15H
0005434573263	10882	54	15G
0005435097143	10882	55	15F
0005435425059	10882	56	15K
0005435305016	10882	57	16D
0005435613330	10882	58	16C
0005434343947	10882	59	16A
0005435613005	10882	60	16F
0005435425111	10882	61	16E
0005435612906	10882	62	16H
0005434245111	10882	63	16G
0005435490209	10882	64	17C
0005435613146	10882	65	17A
0005434344081	10882	66	17D
0005435613418	10882	67	17F
0005435490210	10882	68	17H
0005434343929	10882	69	18C
0005435425088	10882	70	18B
0005435425100	10882	71	18D
0005435613346	10882	72	18G
0005435612826	10882	73	18F
0005433719156	10882	74	18E
0005435612989	10882	75	18K
0005434343967	10882	76	18J
0005435425063	10882	77	18H
0005435425125	10882	78	19B
0005435491439	10882	79	19D
0005435490217	10882	80	19C
0005435613166	10882	81	19G
0005435612673	10882	82	20A
0005435613556	10882	83	19K
0005433719154	10882	84	19J
0005434245092	10882	85	20E
0005435304177	10882	86	20D
0005435319605	10882	87	20H
0005435612792	10882	88	20F
0005435612910	10882	89	20J
0005434343878	10882	90	20K
0005435425123	10882	91	21D
0005434344101	10882	92	21C
0005435613777	10882	93	21B
0005435425106	10882	94	21G
0005435097129	10882	95	21E
0005435613014	10882	96	21J
0005432363428	10882	97	21H
0005434245102	10882	98	22A
0005434245094	10882	99	21K
0005435613065	10882	100	22C
0005435612917	10882	101	22B
0005435425072	10882	102	22F
0005435613446	10882	103	22E
0005435425122	10882	104	22D
0005432166916	10882	105	22H
0005435425078	10882	106	22G
0005435613111	10882	107	22K
0005432166914	10882	108	22J
0005435425109	10882	109	23B
0005435425070	10882	110	23A
0005435612911	10882	111	23D
0005435425094	10882	112	23C
0005435425103	10882	113	23F
0005435613439	10882	114	23J
0005434344011	10882	115	23H
0005435097150	10882	116	24D
0005435612986	10882	117	23K
0005435425090	10882	118	24F
0005435042864	10882	119	24E
0005435319614	10882	120	25B
0005434344098	10882	121	25A
0005435425060	10882	122	25D
0005435425081	10882	123	25C
0005434245093	10882	124	25F
0005435319613	10882	125	25E
0005435425124	10882	126	25H
0005435613309	10882	127	25G
0005435319608	10882	128	25J
0005435612932	10882	129	26C
0005434344133	10882	130	26B
0005435425064	10882	131	26A
0005435425074	10882	132	26E
0005434245087	10882	133	26D
0005434245106	10882	134	26G
0005434245112	10882	135	26J
0005435613139	10882	136	27A
0005435555364	10882	137	26K
0005434245107	10882	138	27D
0005435613170	10882	139	27B
0005435613237	10882	140	27F
0005432841022	10882	141	27E
0005435612839	10882	142	27H
0005435612651	10882	143	27G
0005435425092	10882	144	27K
0005435613102	10882	145	27J
0005435425068	10882	146	28B
0005435319609	10882	147	28A
0005435425066	10882	148	28D
0005435613348	10882	149	28C
0005435555357	10882	150	28G
0005435612652	10882	151	28F
0005432363431	10882	152	28J
0005435612688	10882	153	28H
0005435425076	10882	154	29B
0005434344042	10882	155	29A
0005435555363	10882	156	28K
0005435097142	10882	157	29D
0005435425085	10882	158	29C
0005435612689	10882	159	29F
0005435613595	10882	160	29E
0005435491426	10882	161	29J
0005434343953	10882	162	29H
0005435613474	10882	163	29G
0005434344013	10882	164	30A
0005434245100	10882	165	29K
0005435425080	10882	166	30C
0005435425101	10882	167	30B
0005435612860	10882	168	30E
0005435613347	10882	169	30D
0005434573246	10882	170	30G
0005435613036	10882	171	30F
0005435425118	10882	172	30J
0005434344136	10882	173	31B
0005435097165	10882	174	30K
0005435613310	10882	175	31D
0005435612931	10882	176	31F
0005435613085	10882	177	31E
0005435097164	10882	178	31H
0005435425086	10882	179	32A
0005435425115	10882	180	31K
0005435613131	10882	181	32C
0005435425113	10882	182	32B
0005434344010	10882	183	32D
0005432165071	10882	184	32G
0005434245091	10882	185	32F
0005435612806	10882	186	32J
0005434573200	10882	187	32H
0005435613341	10882	188	33A
0005434245109	10882	189	32K
0005433719155	10882	190	33D
0005435425057	10882	191	33C
0005435613245	10882	192	33B
0005435425096	10882	193	33F
0005434245090	10882	194	33E
0005435612916	10882	195	33H
0005434343930	10882	196	34A
0005434573272	10882	197	33K
0005435612980	10882	198	34C
0005435319607	10882	199	34B
0005435612694	10882	200	34E
0005435613165	10882	201	34F
0005435491427	10882	202	34K
0005435613073	10882	203	34J
0005435613303	10882	204	35B
0005434344025	10882	205	35A
0005435097136	10882	206	35C
0005435613220	10882	207	35E
0005435425065	10882	208	35G
0005432165067	10882	209	36A
0005435613238	10882	210	35K
0005434343931	10882	211	35J
0005435612855	10882	212	36C
0005435613206	10882	213	36B
0005435612727	10882	214	36D
0005435319612	10882	215	36F
0005435425114	10882	216	36H
0005432165072	10882	217	37B
0005435612668	10882	218	37A
0005435612381	10882	219	36K
0005435613169	10882	220	37E
0005435613429	10882	221	37D
0005435425056	10882	222	37C
0005434343962	10882	223	37F
0005432165066	10882	224	37H
0005435425121	10882	225	37G
0005435425108	10882	226	37K
0005435042861	10882	227	37J
0005434573225	10882	228	38B
0005435613115	10882	229	38K
0005435425095	10882	230	38H
0005435613015	10882	231	39B
0005435319606	10882	232	39A
0005432166915	10882	233	39D
0005435425067	10882	234	39F
0005434245114	10882	235	39E
0005434343897	10882	236	39H
0005435425098	10882	237	39G
0005435097151	10882	238	39K
0005435425104	10882	239	39J
0005435425105	10882	240	40C
0005435613253	10882	241	40B
0005435612678	10882	242	40A
0005435613125	10882	243	40E
0005435612746	10882	244	40D
0005434245098	10882	245	40H
0005435425117	10882	246	40G
0005434245115	10882	247	40F
0005435304174	10882	248	41B
0005434344100	10882	249	41A
0005434245105	10882	250	40K
0005435613345	10882	251	41D
0005435425079	10882	252	41C
0005434343976	10882	253	41F
0005435097141	10882	254	41E
0005435612969	10882	255	41J
0005435612849	10882	256	41H
0005435612999	10882	257	42A
0005435613335	10882	258	41K
0005435425087	10882	259	42C
0005435613218	10882	260	42B
0005432165069	10882	261	42E
0005435304176	10882	262	42D
0005432165068	10882	263	42J
0005435613117	10882	264	42H
0005434245089	10882	265	43A
0005434245110	10882	266	43D
0005435612871	10882	267	43C
0005435613331	10882	268	43B
0005434343855	10882	269	43F
0005434573204	10882	270	43E
0005435425071	10882	271	43H
0005434245095	10882	272	43G
0005435613485	10882	273	44A
0005434344110	10882	274	43K
0005435425082	10882	275	43J
0005432165070	10882	276	44E
0005435042862	10882	277	44D
0005432841021	10882	278	44C
0005435425119	10882	279	44G
0005435613047	10882	280	44F
0005435613251	10882	281	44J
0005435305017	10882	282	44H
0005435613079	10882	283	45A
0005434343963	10882	284	44K
0005435425083	10882	285	45D
0005434343939	10882	286	45C
0005435425091	10882	287	45F
0005435612868	10882	288	45E
0005435425077	10882	289	45H
0005434245088	10882	290	45G
0005435319610	10882	291	46A
0005435555356	10882	292	45K
0005435425110	10882	293	45J
0005435613456	10882	294	46C
0005434343957	10882	295	46B
0005434573222	10882	296	46E
0005435613263	10882	297	46D
0005435613387	10882	298	46G
0005435425075	10882	299	46J
0005435613140	10882	300	46H
0005435042863	10882	301	47E
0005434245113	10882	302	47C
0005434343927	10882	303	47K
0005435613284	10882	304	47H
0005435425099	10882	305	48C
0005435613096	10882	306	48A
0005435613430	10882	307	48F
0005435613575	10882	308	48E
0005435319611	10882	309	48D
0005435425061	10882	310	48G
0005435613019	10882	311	49A
0005434344067	10882	312	48K
0005435613067	10882	313	49D
0005432166913	10882	314	49C
0005435613084	10882	315	49G
0005435425116	10882	316	49F
0005435425093	10882	317	49E
0005435425097	10882	318	49K
0005434245108	10882	319	49H
0005435425102	10882	320	50C
0005435613219	10882	321	50A
0005435612747	10882	322	50E
0005434245097	10882	323	50D
0005432165065	10882	324	50G
0005435612728	10882	325	51D
0005434343948	10882	326	50K
0005434245099	10882	327	50H
0005435612930	10882	328	51F
0005435612805	10882	329	51E
0005435613009	10882	330	51G
0005433805512	3278	1	1A
0005432459498	3278	2	1C
0005433805517	3278	3	1D
0005433507255	3278	4	2A
0005433805513	3278	5	1F
0005432459589	3278	6	2C
0005433805514	3278	7	2F
0005432459399	3278	8	2D
0005432459712	3278	9	3A
0005432459387	3278	10	3D
0005433805516	3278	11	3C
0005433633955	3278	12	3F
0005432181821	3278	13	4A
0005432459455	3278	14	4C
0005433507262	3278	15	4D
0005433805533	3278	16	5A
0005432181812	3278	17	4F
0005433507263	3278	18	5D
0005433805509	3278	19	5C
0005433805526	3278	20	5F
0005432459657	3278	21	6A
0005432181817	3278	22	6D
0005432459454	3278	23	6C
0005432459607	3278	24	6F
0005432459666	3278	25	7A
0005433633951	3278	26	7D
0005433805523	3278	27	7C
0005432459671	3278	28	8A
0005432459784	3278	29	7F
0005433805511	3278	30	8B
0005432181810	3278	31	8D
0005432459591	3278	32	8C
0005432459605	3278	33	8E
0005433507268	3278	34	9A
0005433633980	3278	35	8F
0005433805522	3278	36	9B
0005432459364	3278	37	9C
0005433633946	3278	38	9D
0005432181799	3278	39	9F
0005432181813	3278	40	9E
0005433633963	3278	41	10A
0005433633973	3278	42	10B
0005432459691	3278	43	10D
0005432459518	3278	44	10C
0005432459711	3278	45	10E
0005433633960	3278	46	10F
0005432459670	3278	47	11B
0005433633947	3278	48	11A
0005433633964	3278	49	11C
0005432459478	3278	50	11E
0005433633965	3278	51	11D
0005433633956	3278	52	12A
0005433507259	3278	53	11F
0005432459642	3278	54	12B
0005432459658	3278	55	12D
0005432459398	3278	56	12C
0005432181803	3278	57	12E
0005433507265	3278	58	12F
0005433633962	3278	59	13B
0005432459633	3278	60	13A
0005432459644	3278	61	13C
0005433633967	3278	62	13D
0005432181818	3278	63	13F
0005433633949	3278	64	13E
0005432459573	3278	65	14A
0005433805507	3278	66	14B
0005432181802	3278	67	14D
0005433507254	3278	68	14C
0005432181816	3278	69	14E
0005432181804	3278	70	14F
0005433805534	3278	71	15A
0005432459761	3278	72	15C
0005432181820	3278	73	15B
0005432459590	3278	74	15E
0005432459528	3278	75	15D
0005433633971	3278	76	16A
0005432459413	3278	77	15F
0005433633975	3278	78	16B
0005433507257	3278	79	16D
0005433805518	3278	80	16C
0005432181801	3278	81	16E
0005432181805	3278	82	16F
0005432459494	3278	83	17A
0005432459525	3278	84	17C
0005433805521	3278	85	17B
0005433805515	3278	86	17E
0005433633954	3278	87	17D
0005433805506	3278	88	17F
0005432181819	3278	89	18A
0005433633981	3278	90	18B
0005432181800	3278	91	18D
0005432459665	3278	92	18C
0005433633970	3278	93	18E
0005432459550	3278	94	18F
0005432459517	3278	95	19C
0005433805519	3278	96	19B
0005433805531	3278	97	19D
0005432459466	3278	98	20A
0005432459486	3278	99	19E
0005433633969	3278	100	20C
0005433633948	3278	101	20B
0005432459778	3278	102	20D
0005433507252	3278	103	20F
0005433633966	3278	104	20E
0005433805508	3278	105	21B
0005433805527	3278	106	21A
0005432459606	3278	107	21D
0005432459667	3278	108	21E
0005433507251	3278	109	21F
0005432459634	3278	110	22B
0005433507253	3278	111	22A
0005432459524	3278	112	22C
0005432459495	3278	113	22D
0005433507256	3278	114	22F
0005433507267	3278	115	22E
0005433633959	3278	116	23B
0005432181808	3278	117	23A
0005432181811	3278	118	23C
0005433507258	3278	119	23D
0005433507261	3278	120	23F
0005433633974	3278	121	23E
0005432459592	3278	122	24A
0005433633961	3278	123	24B
0005432459635	3278	124	24C
0005433633979	3278	125	24E
0005433633977	3278	126	24D
0005433805535	3278	127	24F
0005433507266	3278	128	25B
0005433507260	3278	129	25A
0005432459551	3278	130	25C
0005432459643	3278	131	25D
0005432459821	3278	132	25E
0005433805520	3278	133	26A
0005433633953	3278	134	25F
0005433805525	3278	135	26C
0005432181809	3278	136	26B
0005432181814	3278	137	26D
0005433507264	3278	138	26F
0005433633968	3278	139	27B
0005432459713	3278	140	27A
0005432459552	3278	141	27C
0005433633958	3278	142	27E
0005433633972	3278	143	27D
0005433805530	3278	144	28A
0005432459636	3278	145	27F
0005432459783	3278	146	28B
0005433633952	3278	147	28C
0005433805528	3278	148	28E
0005433633950	3278	149	28D
0005432459531	3278	150	28F
0005432181815	3278	151	29B
0005432459574	3278	152	29D
0005432181807	3278	153	29C
0005432459710	3278	154	29E
0005433805529	3278	155	30A
0005432459624	3278	156	29F
0005433805532	3278	157	30B
0005432459683	3278	158	30D
0005433805524	3278	159	30C
0005432181806	3278	160	30E
0005433633978	3278	161	30F
0005433633957	3278	162	31A
0005432459553	3278	163	31B
0005433633976	3278	164	31E
0005433805510	3278	165	31F
0005435885283	3277	1	2C
0005435885243	3277	2	3A
0005435885013	3277	3	4A
0005435885012	3277	4	4C
0005435884833	3277	5	4D
0005435885115	3277	6	5D
0005435885098	3277	7	8A
0005435884977	3277	8	8F
0005435885058	3277	9	9A
0005435884710	3277	10	10E
0005435885201	3277	11	11A
0005435885109	3277	12	10F
0005435885116	3277	13	11E
0005435884936	3277	14	13E
0005435885365	3277	15	14A
0005435885102	3277	16	13F
0005435884927	3277	17	14B
0005435885232	3277	18	14D
0005435885035	3277	19	15C
0005435885180	3277	20	16B
0005435885071	3277	21	16C
0005435884907	3277	22	16E
0005435885199	3277	23	16D
0005435885211	3277	24	17D
0005435885067	3277	25	17C
0005435884968	3277	26	19D
0005435884972	3277	27	19E
0005435885153	3277	28	20A
0005435884954	3277	29	20C
0005435885040	3277	30	20B
0005435885190	3277	31	20D
0005435885222	3277	32	20F
0005435884709	3277	33	21A
0005435884915	3277	34	21C
0005435885034	3277	35	21D
0005435884974	3277	36	22A
0005435885057	3277	37	22D
0005435884953	3277	38	22F
0005435885015	3277	39	23A
0005435885128	3277	40	23E
0005435884763	3277	41	24B
0005435884955	3277	42	24C
0005435885097	3277	43	24D
0005435885181	3277	44	24F
0005435885011	3277	45	25A
0005435885177	3277	46	25C
0005435885176	3277	47	26E
0005435885110	3277	48	26F
0005435884834	3277	49	27A
0005435885366	3277	50	27F
0005435885230	3277	51	28A
0005435885244	3277	52	28C
0005435884898	3277	53	28E
0005435884937	3277	54	30D
0005435884948	3277	55	31A
0005435885182	3277	56	31D
0005435885430	8220	1	1A
0005435885456	8220	2	1C
0005435885421	8220	3	1F
0005433507157	8220	4	1D
0005435885447	8220	5	2A
0005433507097	8220	6	2D
0005432460123	8220	7	2C
0005432460121	8220	8	3A
0005433507124	8220	9	2F
0005435885458	8220	10	3C
0005435885437	8220	11	3F
0005433507085	8220	12	3D
0005433507012	8220	13	4A
0005432460106	8220	14	4D
0005432460078	8220	15	4C
0005433507096	8220	16	4F
0005432460092	8220	17	5C
0005435885440	8220	18	5D
0005435885455	8220	19	6A
0005432460095	8220	20	5F
0005434326273	8220	21	6C
0005433507086	8220	22	7A
0005435885434	8220	23	6F
0005435885436	8220	24	7C
0005433507127	8220	25	7F
0005432460081	8220	26	8A
0005432460082	8220	27	8C
0005432460097	8220	28	8B
0005435885429	8220	29	8D
0005435885462	8220	30	8E
0005432460100	8220	31	8F
0005435885457	8220	32	9A
0005432460119	8220	33	9C
0005435885422	8220	34	9D
0005435885435	8220	35	9F
0005432042768	8220	36	9E
0005432460096	8220	37	10A
0005432460094	8220	38	10E
0005432460124	8220	39	11A
0005432042773	8220	40	10F
0005432460115	8220	41	11C
0005432460110	8220	42	11B
0005432460118	8220	43	11E
0005435885433	8220	44	11D
0005435885450	8220	45	12A
0005432460099	8220	46	11F
0005435885451	8220	47	12C
0005433507167	8220	48	12B
0005432460107	8220	49	12D
0005432460127	8220	50	13B
0005435885460	8220	51	13A
0005432460125	8220	52	13C
0005432460130	8220	53	13D
0005432042769	8220	54	13F
0005435885468	8220	55	13E
0005434312330	8220	56	14B
0005433507067	8220	57	14C
0005432460098	8220	58	14E
0005432460116	8220	59	14D
0005432460120	8220	60	15A
0005432460102	8220	61	14F
0005432042770	8220	62	15B
0005432460090	8220	63	15C
0005435885466	8220	64	15D
0005435885469	8220	65	16B
0005435885452	8220	66	16A
0005432460104	8220	67	16D
0005432460086	8220	68	16C
0005435885467	8220	69	16E
0005432042779	8220	70	17A
0005432460108	8220	71	16F
0005432460122	8220	72	17B
0005435885444	8220	73	17E
0005435885459	8220	74	17D
0005432460087	8220	75	18A
0005433507125	8220	76	18B
0005432460084	8220	77	18D
0005435885439	8220	78	18C
0005432042774	8220	79	18E
0005432460112	8220	80	19C
0005433507080	8220	81	20A
0005435885463	8220	82	20B
0005434312329	8220	83	20D
0005432460126	8220	84	20E
0005435885428	8220	85	21A
0005434326272	8220	86	21B
0005432460085	8220	87	21D
0005432460111	8220	88	21C
0005433507134	8220	89	21E
0005435885454	8220	90	22A
0005432460089	8220	91	21F
0005433507113	8220	92	22B
0005433507079	8220	93	22C
0005433507011	8220	94	22D
0005432460101	8220	95	22F
0005432460117	8220	96	23B
0005432042780	8220	97	23A
0005432042771	8220	98	23D
0005432460128	8220	99	23C
0005435885441	8220	100	23E
0005435885424	8220	101	24A
0005432460129	8220	102	24B
0005432042777	8220	103	24D
0005432460131	8220	104	24C
0005435885445	8220	105	24E
0005432042778	8220	106	24F
0005435885453	8220	107	25B
0005432042775	8220	108	25A
0005435885432	8220	109	25C
0005435885448	8220	110	25F
0005432460093	8220	111	26A
0005435885443	8220	112	26B
0005432460114	8220	113	26C
0005435885427	8220	114	26E
0005432460109	8220	115	26D
0005435885464	8220	116	26F
0005435885425	8220	117	27A
0005432460080	8220	118	27C
0005432460088	8220	119	27B
0005432460083	8220	120	27D
0005435885423	8220	121	28C
0005435885438	8220	122	28B
0005432460079	8220	123	28A
0005432042776	8220	124	28D
0005435885431	8220	125	28F
0005435885442	8220	126	29A
0005433507180	8220	127	29C
0005435885449	8220	128	29B
0005432460103	8220	129	29D
0005435885465	8220	130	29F
0005433507063	8220	131	29E
0005435885446	8220	132	30A
0005432042767	8220	133	30B
0005432042772	8220	134	30D
0005432460105	8220	135	30C
0005435885461	8220	136	30E
0005435885426	8220	137	30F
0005433507118	8220	138	31B
0005433507108	8220	139	31A
0005432460113	8220	140	31C
0005434312328	8220	141	31D
0005432460091	8220	142	31F
0005433507123	8220	143	31E
0005433633427	8204	1	1F
0005433805201	8204	2	2A
0005433633569	8204	3	2C
0005433805125	8204	4	3A
0005433805169	8204	5	3D
0005433633616	8204	6	4C
0005433633543	8204	7	5C
0005433633612	8204	8	5F
0005433633613	8204	9	6C
0005433633618	8204	10	7A
0005433805105	8204	11	6F
0005433805054	8204	12	7C
0005433805249	8204	13	7F
0005433805153	8204	14	7D
0005433805376	8204	15	8D
0005433805258	8204	16	9A
0005433633750	8204	17	9D
0005433633716	8204	18	9E
0005433633581	8204	19	9F
0005433805240	8204	20	10C
0005433805316	8204	21	12C
0005433633594	8204	22	12B
0005433633635	8204	23	12D
0005433805286	8204	24	12F
0005433633619	8204	25	13C
0005434143721	8204	26	13B
0005433805124	8204	27	13D
0005433805337	8204	28	13E
0005433805202	8204	29	14B
0005433805289	8204	30	14E
0005433805287	8204	31	14D
0005433805280	8204	32	14F
0005433805187	8204	33	15B
0005433805230	8204	34	15D
0005433805168	8204	35	15E
0005433633633	8204	36	16A
0005433633702	8204	37	17D
0005433805037	8204	38	17F
0005433805326	8204	39	17E
0005433805140	8204	40	18C
0005433805267	8204	41	18B
0005433805314	8204	42	18E
0005433633721	8204	43	18D
0005433805247	8204	44	18F
0005433805288	8204	45	19B
0005433633542	8204	46	19D
0005433805188	8204	47	19C
0005433805241	8204	48	20D
0005433633561	8204	49	20F
0005433633659	8204	50	21B
0005433633658	8204	51	22A
0005433805149	8204	52	22D
0005433633657	8204	53	22F
0005433805216	8204	54	22E
0005433633620	8204	55	23A
0005433805246	8204	56	23C
0005433633756	8204	57	23D
0005433633399	8204	58	23E
0005433805234	8204	59	24A
0005433633576	8204	60	24E
0005433633568	8204	61	24F
0005433633550	8204	62	25C
0005433633712	8204	63	25F
0005433805203	8204	64	26A
0005433805311	8204	65	26D
0005433633428	8204	66	26C
0005433805181	8204	67	27B
0005433805330	8204	68	27D
0005433633689	8204	69	28B
0005433805377	8204	70	28E
0005433805159	8204	71	28F
0005433805151	8204	72	29B
0005433805263	8204	73	29A
0005433633722	8204	74	29E
0005433633751	8204	75	30A
0005433805150	8204	76	30D
0005433805158	8204	77	30E
0005433633582	8204	78	31D
0005434271297	8204	79	31F
0005434183567	8288	1	17F
0005434183566	8288	2	21F
0005432383352	4575	1	1A
0005432383343	4575	2	1C
0005432383335	4575	3	1D
0005433454886	4575	4	1F
0005433722247	4575	5	2D
0005432727993	4575	6	2F
0005432727987	4575	7	3A
0005432383322	4575	8	3D
0005432383329	4575	9	3F
0005432727988	4575	10	4C
0005433722252	4575	11	4D
0005433722250	4575	12	4E
0005432383350	4575	13	5C
0005433722248	4575	14	5D
0005432383323	4575	15	5E
0005432383349	4575	16	5F
0005432727996	4575	17	6A
0005432383326	4575	18	6C
0005432727989	4575	19	6D
0005432383340	4575	20	6E
0005432383353	4575	21	6F
0005433722253	4575	22	7C
0005433454885	4575	23	7E
0005432383344	4575	24	8A
0005433454884	4575	25	8C
0005432383341	4575	26	8D
0005432383330	4575	27	8E
0005432383331	4575	28	9A
0005432383355	4575	29	9D
0005432383328	4575	30	9E
0005432383357	4575	31	10C
0005432383333	4575	32	10D
0005433722246	4575	33	11A
0005432383348	4575	34	11C
0005432383325	4575	35	11F
0005432383347	4575	36	12A
0005432383319	4575	37	12C
0005432383317	4575	38	12D
0005432383332	4575	39	12E
0005432383338	4575	40	13C
0005432383318	4575	41	13E
0005432727990	4575	42	13F
0005432383337	4575	43	14A
0005432383342	4575	44	14C
0005432383358	4575	45	14D
0005432383356	4575	46	14E
0005432383336	4575	47	14F
0005432727995	4575	48	15C
0005432383354	4575	49	15D
0005433722249	4575	50	15E
0005432727992	4575	51	15F
0005433722251	4575	52	16A
0005432727985	4575	53	16C
0005432383339	4575	54	16D
0005433453769	4575	55	16E
0005432727997	4575	56	17A
0005432383327	4575	57	17C
0005432383351	4575	58	17E
0005432383320	4575	59	18C
0005432383345	4575	60	18E
0005432727994	4575	61	18F
0005432383321	4575	62	19A
0005432383346	4575	63	19E
0005432383334	4575	64	19F
0005432383324	4575	65	20A
0005432727991	4575	66	20C
0005433454883	4575	67	20E
0005432727986	4575	68	20F
0005432727872	30137	1	1C
0005432382888	30137	2	1D
0005432383027	30137	3	2A
0005432382938	30137	4	2D
0005433451604	30137	5	2F
0005433722196	30137	6	3A
0005432727852	30137	7	3C
0005432382789	30137	8	3D
0005432382730	30137	9	3F
0005433451616	30137	10	4A
0005432727889	30137	11	4C
0005432382879	30137	12	4E
0005432382890	30137	13	4F
0005432382833	30137	14	5C
0005432727845	30137	15	5D
0005432382940	30137	16	5E
0005432382795	30137	17	5F
0005432382806	30137	18	6C
0005432727873	30137	19	6D
0005432382930	30137	20	6E
0005432727881	30137	21	6F
0005433722175	30137	22	7A
0005432383079	30137	23	7C
0005433722191	30137	24	7D
0005433722178	30137	25	7E
0005432382959	30137	26	8A
0005432382805	30137	27	8D
0005432383107	30137	28	9A
0005433722157	30137	29	9C
0005432727887	30137	30	9D
0005432382860	30137	31	9E
0005433722183	30137	32	9F
0005432727882	30137	33	10A
0005432727871	30137	34	10C
0005432383026	30137	35	10D
0005432727844	30137	36	10E
0005432382961	30137	37	10F
0005432382913	30137	38	11A
0005433722176	30137	39	11C
0005433722164	30137	40	11D
0005432382969	30137	41	11F
0005433722180	30137	42	12A
0005432382912	30137	43	12C
0005433722179	30137	44	12E
0005432727870	30137	45	12F
0005432727891	30137	46	14A
0005433722159	30137	47	14D
0005432727822	30137	48	15C
0005432382943	30137	49	15E
0005432382847	30137	50	15F
0005433194839	30137	51	16A
0005432727874	30137	52	16C
0005433194840	30137	53	16D
0005433194837	30137	54	16E
0005432727888	30137	55	16F
0005432382920	30137	56	17A
0005432382831	30137	57	17C
0005433722174	30137	58	17D
0005432383087	30137	59	17E
0005433722173	30137	60	17F
0005432382648	30137	61	18A
0005433722165	30137	62	18C
0005432382863	30137	63	18F
0005432382756	30137	64	19A
0005432382788	30137	65	19C
0005432382747	30137	66	19D
0005433722156	30137	67	19E
0005432727851	30137	68	20A
0005433722181	30137	69	20C
0005433722158	30137	70	20E
0005432382790	30137	71	20F
0005435541090	1747	1	1A
0005432925024	1747	2	1C
0005435529358	1747	3	1D
0005432925030	1747	4	1F
0005435541100	1747	5	2A
0005433516924	1747	6	2C
0005435541108	1747	7	2D
0005435541104	1747	8	2F
0005435541095	1747	9	3D
0005435541101	1747	10	3F
0005435529363	1747	11	4A
0005435529365	1747	12	4C
0005435541109	1747	13	4E
0005433516930	1747	14	4F
0005435541089	1747	15	5A
0005433516922	1747	16	5C
0005433516925	1747	17	5E
0005433516927	1747	18	6A
0005435541092	1747	19	6E
0005435541094	1747	20	7A
0005433516928	1747	21	7C
0005435529361	1747	22	7D
0005435529364	1747	23	7E
0005433516926	1747	24	7F
0005435541103	1747	25	8A
0005435529362	1747	26	8E
0005433516923	1747	27	8F
0005433516931	1747	28	9A
0005435529349	1747	29	9C
0005432925013	1747	30	10C
0005435529347	1747	31	10D
0005433516929	1747	32	10E
0005435529345	1747	33	10F
0005435541105	1747	34	11A
0005435529355	1747	35	11C
0005432925023	1747	36	12A
0005435529348	1747	37	12E
0005435529344	1747	38	12F
0005435529353	1747	39	13D
0005435541097	1747	40	13E
0005435541091	1747	41	14A
0005435541102	1747	42	14C
0005435529350	1747	43	14D
0005435541096	1747	44	14E
0005435541098	1747	45	15C
0005435529351	1747	46	15D
0005435541106	1747	47	15E
0005435529352	1747	48	15F
0005435529357	1747	49	16D
0005435529360	1747	50	16E
0005435529359	1747	51	17A
0005432294498	1747	52	17C
0005435529356	1747	53	17F
0005435541107	1747	54	18A
0005432925015	1747	55	18C
0005432925014	1747	56	18D
0005435541093	1747	57	18F
0005435529346	1747	58	19C
0005435529354	1747	59	19F
0005435541099	1747	60	20A
0005435517770	22026	1	1C
0005435517767	22026	2	1F
0005435540993	22026	3	2A
0005435540935	22026	4	2C
0005435540893	22026	5	2D
0005435540905	22026	6	2F
0005432925059	22026	7	3A
0005435517773	22026	8	3C
0005435540874	22026	9	3F
0005435517819	22026	10	4C
0005433516842	22026	11	4D
0005435517852	22026	12	4E
0005435540908	22026	13	4F
0005435517814	22026	14	5A
0005435517838	22026	15	5C
0005435540791	22026	16	5D
0005435517725	22026	17	5E
0005435540952	22026	18	6C
0005435540920	22026	19	6D
0005435540803	22026	20	6F
0005433516841	22026	21	7A
0005435540802	22026	22	7C
0005435540948	22026	23	7D
0005435540955	22026	24	7E
0005435540904	22026	25	7F
0005435517882	22026	26	8A
0005435517771	22026	27	8D
0005435540902	22026	28	8E
0005435517856	22026	29	8F
0005435540879	22026	30	9C
0005432925056	22026	31	9D
0005435540945	22026	32	9E
0005433516833	22026	33	9F
0005433516848	22026	34	10D
0005435540903	22026	35	10E
0005435540900	22026	36	10F
0005435517804	22026	37	11A
0005435540894	22026	38	11C
0005435517766	22026	39	11D
0005435517827	22026	40	11E
0005432925055	22026	41	12A
0005435540885	22026	42	12C
0005435540933	22026	43	12D
0005435540853	22026	44	12E
0005435540909	22026	45	12F
0005435540928	22026	46	13A
0005435540901	22026	47	13D
0005435540910	22026	48	13E
0005435517820	22026	49	13F
0005435540790	22026	50	14C
0005435517748	22026	51	14D
0005435540923	22026	52	14E
0005435540840	22026	53	14F
0005433516874	22026	54	15A
0005435540870	22026	55	15C
0005435540992	22026	56	15F
0005435540972	22026	57	16A
0005433516849	22026	58	16D
0005433516812	22026	59	16E
0005435540875	22026	60	16F
0005432925057	22026	61	17A
0005435540921	22026	62	17C
0005433516873	22026	63	17D
0005435517867	22026	64	17E
0005435540886	22026	65	17F
0005432925058	22026	66	18D
0005432925054	22026	67	18E
0005435517813	22026	68	18F
0005435540892	22026	69	19A
0005435540852	22026	70	19D
0005433516832	22026	71	19E
0005435540991	22026	72	19F
0005435517778	22026	73	20A
0005435517821	22026	74	20C
0005435540922	22026	75	20D
0005435517812	22026	76	20E
0005435517774	22026	77	20F
0005434458887	7379	1	1D
0005432839156	7379	2	1F
0005432839160	7379	3	2A
0005432839164	7379	4	2C
0005435252626	7379	5	2D
0005434458900	7379	6	2F
0005434458884	7379	7	3A
0005434458899	7379	8	3C
0005434458888	7379	9	3D
0005432839153	7379	10	3F
0005432839151	7379	11	4A
0005434664938	7379	12	4C
0005434458901	7379	13	4D
0005435252535	7379	14	4E
0005435252636	7379	15	4F
0005435252517	7379	16	5A
0005434664937	7379	17	5C
0005434458885	7379	18	5D
0005432073406	7379	19	5E
0005434664951	7379	20	5F
0005432839178	7379	21	6A
0005435252685	7379	22	6C
0005434458882	7379	23	6D
0005432839170	7379	24	6E
0005434458898	7379	25	6F
0005432839174	7379	26	7A
0005435491432	7379	27	7C
0005434458889	7379	28	7D
0005432839159	7379	29	7E
0005432073403	7379	30	8A
0005435252473	7379	31	8C
0005435252658	7379	32	8E
0005432839158	7379	33	8F
0005435252677	7379	34	9C
0005435252475	7379	35	9D
0005435252696	7379	36	9E
0005432839161	7379	37	9F
0005432839172	7379	38	10A
0005432073405	7379	39	10C
0005434458896	7379	40	10D
0005432839177	7379	41	10E
0005432839179	7379	42	10F
0005432839152	7379	43	11A
0005435252642	7379	44	11C
0005434458897	7379	45	11D
0005432823456	7379	46	11E
0005434458895	7379	47	11F
0005435252534	7379	48	12A
0005434458886	7379	49	12C
0005432839162	7379	50	12D
0005435252523	7379	51	13A
0005435252474	7379	52	13C
0005432839155	7379	53	13D
0005432073404	7379	54	13E
0005435252657	7379	55	13F
0005434458894	7379	56	14C
0005432839171	7379	57	14D
0005434458892	7379	58	14E
0005435252686	7379	59	14F
0005432839166	7379	60	15C
0005432841020	7379	61	15D
0005434458883	7379	62	15E
0005435252524	7379	63	15F
0005434458891	7379	64	16A
0005435252669	7379	65	16C
0005432823457	7379	66	16D
0005432841019	7379	67	16E
0005432839169	7379	68	16F
0005434458890	7379	69	17A
0005432839167	7379	70	17C
0005432839150	7379	71	17D
0005435252678	7379	72	17E
0005432839181	7379	73	18A
0005435252623	7379	74	18D
0005432839173	7379	75	18E
0005432839165	7379	76	18F
0005432839157	7379	77	19A
0005432839168	7379	78	19C
0005435252601	7379	79	19D
0005432839154	7379	80	19E
0005432839175	7379	81	19F
0005432839176	7379	82	20A
0005432839180	7379	83	20C
0005432839163	7379	84	20D
0005434458893	7379	85	20E
0005435252697	7379	86	20F
0005432823439	28902	1	1A
0005435252770	28902	2	1C
0005435491449	28902	3	1D
0005432839001	28902	4	1F
0005432838951	28902	5	2A
0005435252766	28902	6	2C
0005435252774	28902	7	2D
0005432838931	28902	8	2F
0005434458661	28902	9	3C
0005432839002	28902	10	4C
0005434458662	28902	11	4E
0005434458705	28902	12	4F
0005434458758	28902	13	5A
0005432838896	28902	14	5E
0005435252776	28902	15	5F
0005432838930	28902	16	6A
0005432823441	28902	17	6E
0005435252781	28902	18	6F
0005432001032	28902	19	7A
0005432838911	28902	20	7D
0005432838939	28902	21	7E
0005435252772	28902	22	7F
0005432838695	28902	23	8A
0005435252773	28902	24	8C
0005432839041	28902	25	8D
0005432001031	28902	26	8E
0005435252778	28902	27	9A
0005435252775	28902	28	9C
0005432823434	28902	29	9D
0005432839084	28902	30	10A
0005432838964	28902	31	10F
0005434458672	28902	32	11D
0005434458698	28902	33	11E
0005434458671	28902	34	12A
0005434458744	28902	35	12C
0005432823448	28902	36	12D
0005432838952	28902	37	12E
0005434458771	28902	38	12F
0005432838850	28902	39	13C
0005434458706	28902	40	13D
0005435252782	28902	41	13E
0005435252769	28902	42	14A
0005435252780	28902	43	14C
0005432838797	28902	44	14E
0005435252779	28902	45	14F
0005435252777	28902	46	15A
0005432838845	28902	47	15C
0005432838839	28902	48	15D
0005434458802	28902	49	15E
0005435252771	28902	50	15F
0005434458702	28902	51	16A
0005435252768	28902	52	16D
0005432838905	28902	53	16E
0005435252767	28902	54	16F
0005434458701	28902	55	17C
0005435491448	28902	56	17D
0005434458633	28902	57	17E
0005432838803	28902	58	17F
0005434458745	28902	59	18C
0005434458769	28902	60	18D
0005432838910	28902	61	19A
0005432838967	28902	62	19C
0005432838940	28902	63	19D
0005434458632	28902	64	19F
0005435252783	28902	65	20A
0005432839042	28902	66	20C
0005432838694	28902	67	20E
0005432838999	28902	68	20F
0005435990654	8776	1	2F
0005434276021	8776	2	3D
0005435990653	8776	3	4A
0005434276028	8776	4	5D
0005435990651	8776	5	6D
0005434276024	8776	6	6F
0005434276003	8776	7	7F
0005434276019	8776	8	8F
0005434276004	8776	9	9A
0005434276029	8776	10	10F
0005435990652	8776	11	13D
0005434276023	8776	12	15B
0005434276020	8776	13	15F
0005434276022	8776	14	16D
0005435990657	8776	15	17F
0005434276014	8776	16	18A
0005435990655	8776	17	20D
0005435990650	8776	18	21B
0005435990656	8776	19	21F
0005435990588	15739	1	7D
0005434276052	15739	2	8A
0005434276050	15739	3	13C
0005435990586	15739	4	13B
0005434276049	15739	5	15B
0005434276053	15739	6	17A
0005434276051	15739	7	18C
0005433468373	2100	1	1A
0005432909261	2100	2	1C
0005433468366	2100	3	1D
0005433468370	2100	4	2A
0005433468363	2100	5	2B
0005432909255	2100	6	2C
0005433468379	2100	7	2D
0005433468378	2100	8	3A
0005432909228	2100	9	4A
0005433468375	2100	10	4B
0005432909248	2100	11	4C
0005432909252	2100	12	4D
0005432909250	2100	13	5A
0005432909265	2100	14	5B
0005433468367	2100	15	5D
0005433468364	2100	16	6A
0005432909273	2100	17	6D
0005433468369	2100	18	18A
0005433468377	2100	19	18B
0005433468381	2100	20	18D
0005433468371	2100	21	19A
0005433468368	2100	22	19D
0005433468376	2100	23	20A
0005433468365	2100	24	20B
0005432909272	2100	25	20D
0005433468362	2100	26	21A
0005432909246	2100	27	21B
0005432909247	2100	28	21C
0005433468374	2100	29	21D
0005432909262	2100	30	22A
0005433468380	2100	31	22C
0005433468372	2100	32	23B
0005432360585	6367	1	1A
0005432062252	6367	2	1C
0005435176951	6367	3	1D
0005432360545	6367	4	1F
0005435176890	6367	5	2C
0005432360569	6367	6	2A
0005435176952	6367	7	2D
0005432360542	6367	8	2F
0005435177097	6367	9	3C
0005432360549	6367	10	3A
0005432062254	6367	11	3F
0005432360548	6367	12	4B
0005435176988	6367	13	4A
0005434149691	6367	14	4D
0005432360584	6367	15	4E
0005432360579	6367	16	5B
0005432360563	6367	17	5A
0005435177035	6367	18	5C
0005432360581	6367	19	5D
0005432360566	6367	20	5E
0005435723031	6367	21	5F
0005434149698	6367	22	6B
0005432062253	6367	23	6C
0005434149627	6367	24	6D
0005432360544	6367	25	6F
0005432360568	6367	26	6E
0005434149716	6367	27	7A
0005432336081	6367	28	7C
0005432360540	6367	29	7B
0005434149725	6367	30	7D
0005435177019	6367	31	8A
0005432360577	6367	32	8B
0005434149661	6367	33	8C
0005435176862	6367	34	8E
0005432360561	6367	35	8F
0005432360562	6367	36	9A
0005435177032	6367	37	9B
0005432360567	6367	38	9C
0005432062249	6367	39	9D
0005432360543	6367	40	9F
0005432360582	6367	41	9E
0005434149709	6367	42	10B
0005432336089	6367	43	10C
0005432360551	6367	44	10E
0005432360580	6367	45	10D
0005432336088	6367	46	11A
0005435176959	6367	47	11B
0005432336083	6367	48	11D
0005432360546	6367	49	11E
0005435177010	6367	50	11F
0005434149635	6367	51	12B
0005432363430	6367	52	12A
0005432336091	6367	53	12C
0005435490209	6367	54	12D
0005434149695	6367	55	12E
0005432360583	6367	56	12F
0005432360575	6367	57	13A
0005432062248	6367	58	13B
0005432363431	6367	59	13D
0005435177023	6367	60	13C
0005435177036	6367	61	13E
0005435490217	6367	62	13F
0005432336086	6367	63	14B
0005432336090	6367	64	14A
0005435177001	6367	65	14C
0005432360586	6367	66	14D
0005432360587	6367	67	14E
0005434149732	6367	68	15A
0005432360553	6367	69	14F
0005434149733	6367	70	15B
0005432336079	6367	71	15C
0005435176860	6367	72	15D
0005434149705	6367	73	16A
0005432360572	6367	74	15F
0005432336080	6367	75	16B
0005432360574	6367	76	16C
0005435176925	6367	77	16D
0005432360552	6367	78	16F
0005432360541	6367	79	16E
0005435176861	6367	80	17B
0005432360554	6367	81	17A
0005432360564	6367	82	17D
0005434149633	6367	83	17C
0005432360559	6367	84	17E
0005435176938	6367	85	18A
0005432360573	6367	86	17F
0005435176964	6367	87	18C
0005435176922	6367	88	18B
0005432360555	6367	89	18D
0005432360578	6367	90	18F
0005432360557	6367	91	19A
0005432360571	6367	92	19B
0005432336085	6367	93	19C
0005432360576	6367	94	19E
0005432363428	6367	95	19D
0005432360547	6367	96	19F
0005434149632	6367	97	20A
0005435490213	6367	98	20C
0005432360550	6367	99	20B
0005435490210	6367	100	20D
0005432360556	6367	101	20E
0005435176954	6367	102	20F
0005434149734	6367	103	21C
0005432360560	6367	104	21B
0005432062250	6367	105	21D
0005432336082	6367	106	21E
0005434149641	6367	107	21F
0005432062251	6367	108	22B
0005432360558	6367	109	22A
0005432336078	6367	110	22C
0005434149690	6367	111	22D
0005432360570	6367	112	22F
0005432336087	6367	113	22E
0005435177020	6367	114	23B
0005435176963	6367	115	23A
0005432363429	6367	116	23C
0005432336084	6367	117	23E
0005432360565	6367	118	23D
0005432360588	6367	119	23F
0005435723055	20996	1	1A
0005435177201	20996	2	1F
0005432360236	20996	3	2C
0005432359967	20996	4	2A
0005434149774	20996	5	2F
0005434149777	20996	6	3A
0005432360158	20996	7	3D
0005434149779	20996	8	3C
0005435177177	20996	9	4A
0005432336001	20996	10	3F
0005434149778	20996	11	4B
0005432360052	20996	12	4D
0005432335997	20996	13	4E
0005432360367	20996	14	4F
0005435723057	20996	15	5B
0005435177187	20996	16	5A
0005435177185	20996	17	5C
0005432359961	20996	18	5D
0005432360225	20996	19	5E
0005435177196	20996	20	5F
0005432335908	20996	21	6A
0005435177202	20996	22	6C
0005432335970	20996	23	6D
0005432360220	20996	24	6E
0005432360368	20996	25	7A
0005435177194	20996	26	6F
0005432360066	20996	27	7B
0005432052759	20996	28	7D
0005432335996	20996	29	7C
0005432360295	20996	30	7F
0005434149782	20996	31	7E
0005434149780	20996	32	8A
0005435177199	20996	33	8B
0005432360174	20996	34	8C
0005432335989	20996	35	8E
0005432360073	20996	36	8D
0005432360111	20996	37	8F
0005435177198	20996	38	9A
0005432360219	20996	39	9B
0005435177182	20996	40	9E
0005432360286	20996	41	9F
0005435177186	20996	42	10B
0005435177188	20996	43	10C
0005432360102	20996	44	10D
0005432335971	20996	45	11A
0005435177183	20996	46	10E
0005432360279	20996	47	11B
0005432363403	20996	48	11D
0005432360250	20996	49	11C
0005432360202	20996	50	11F
0005435177179	20996	51	11E
0005432335972	20996	52	12B
0005432360034	20996	53	12A
0005432360216	20996	54	12C
0005432335969	20996	55	12D
0005435177189	20996	56	12E
0005435723054	20996	57	12F
0005435177190	20996	58	13C
0005435177195	20996	59	13B
0005432360023	20996	60	13D
0005432335986	20996	61	13E
0005435177193	20996	62	13F
0005435177197	20996	63	14A
0005435177178	20996	64	14C
0005434149783	20996	65	14B
0005432360339	20996	66	14D
0005435723056	20996	67	14F
0005432360161	20996	68	14E
0005435177200	20996	69	15B
0005432360148	20996	70	15A
0005432360203	20996	71	15C
0005432360022	20996	72	15D
0005435490248	20996	73	15E
0005432360242	20996	74	16A
0005434149784	20996	75	15F
0005432360105	20996	76	16C
0005432360218	20996	77	16B
0005432360171	20996	78	16D
0005432336014	20996	79	16E
0005434149781	20996	80	17A
0005432360154	20996	81	16F
0005434149775	20996	82	17B
0005432052758	20996	83	17C
0005432363404	20996	84	17D
0005435177191	20996	85	17F
0005432360116	20996	86	18A
0005432360195	20996	87	18B
0005432335966	20996	88	18C
0005432359993	20996	89	18F
0005432360147	20996	90	19A
0005432360075	20996	91	19B
0005432360241	20996	92	19D
0005432360100	20996	93	19E
0005435177203	20996	94	19F
0005432335919	20996	95	20A
0005432360103	20996	96	20C
0005435177192	20996	97	20B
0005432335987	20996	98	20D
0005435490246	20996	99	21A
0005432336000	20996	100	20F
0005435177181	20996	101	21C
0005432360160	20996	102	21B
0005432360033	20996	103	21D
0005432335977	20996	104	21E
0005435490247	20996	105	21F
0005432360340	20996	106	22A
0005435177204	20996	107	22C
0005432360142	20996	108	22B
0005432360065	20996	109	22E
0005432360115	20996	110	22D
0005434149776	20996	111	22F
0005432360170	20996	112	23A
0005435177180	20996	113	23B
0005432360110	20996	114	23C
0005432335950	20996	115	23E
0005432360196	20996	116	23D
0005435177184	20996	117	23F
0005434458790	17708	1	1D
0005434458696	17708	2	2C
0005434458783	17708	3	3A
0005434458827	17708	4	3B
0005434448288	17708	5	3C
0005434458805	17708	6	3D
0005434458714	17708	7	4A
0005434458697	17708	8	4B
0005434458752	17708	9	4D
0005434458789	17708	10	4C
0005434458716	17708	11	5C
0005434448319	17708	12	6A
0005434458773	17708	13	6B
0005434186212	17708	14	6D
0005434458806	17708	15	7A
0005434461634	17708	16	7B
0005434458620	17708	17	7C
0005434458718	17708	18	7D
0005434458772	17708	19	18A
0005434448289	17708	20	18C
0005434458774	17708	21	18D
0005434458668	17708	22	19C
0005434461640	17708	23	19D
0005434458708	17708	24	20A
0005434458717	17708	25	20B
0005434461641	17708	26	20C
0005434448291	17708	27	20D
0005434458657	17708	28	21A
0005434186211	17708	29	21D
0005434448292	17708	30	22A
0005434458796	17708	31	22B
0005434463914	17708	32	22C
0005434458715	17708	33	23A
0005434186213	17708	34	23B
0005434463936	29083	1	1C
0005434448328	29083	2	1D
0005434458887	29083	3	2B
0005434458890	29083	4	2C
0005434458893	29083	5	2D
0005434458894	29083	6	3B
0005434458899	29083	7	3C
0005434458891	29083	8	4B
0005434448326	29083	9	5D
0005434458898	29083	10	6A
0005434458892	29083	11	6D
0005434458883	29083	12	7A
0005434458901	29083	13	7C
0005434458882	29083	14	18C
0005434458897	29083	15	18D
0005434458900	29083	16	19B
0005434458895	29083	17	20A
0005434458885	29083	18	20B
0005434186169	29083	19	21A
0005434458888	29083	20	21B
0005434458896	29083	21	21C
0005434458884	29083	22	21D
0005434448327	29083	23	22A
0005434458889	29083	24	22B
0005434462797	29083	25	22C
0005434458886	29083	26	23A
0005432604465	21460	1	1B
0005432604460	21460	2	1C
0005432604482	21460	3	2A
0005432604455	21460	4	2B
0005432604456	21460	5	2C
0005432604458	21460	6	3A
0005432604461	21460	7	3B
0005432604483	21460	8	3C
0005432604476	21460	9	3D
0005432604454	21460	10	4A
0005432604459	21460	11	4C
0005432604464	21460	12	4D
0005432604478	21460	13	5A
0005432604457	21460	14	5B
0005432604477	21460	15	5C
0005432604468	21460	16	5D
0005432604469	21460	17	6A
0005432604475	21460	18	6B
0005432604490	21460	19	6D
0005432604491	21460	20	7A
0005432604462	21460	21	7B
0005432604472	21460	22	7C
0005432604489	21460	23	7D
0005432604485	21460	24	18A
0005432604487	21460	25	18B
0005432604481	21460	26	18C
0005432604484	21460	27	19A
0005432604453	21460	28	19B
0005432604471	21460	29	19C
0005432604492	21460	30	20A
0005432604493	21460	31	20B
0005432604474	21460	32	20C
0005432604488	21460	33	20D
0005432604466	21460	34	21A
0005432604473	21460	35	21B
0005432604480	21460	36	21C
0005432604486	21460	37	21D
0005432604463	21460	38	22A
0005432604470	21460	39	22B
0005432604479	21460	40	22C
0005432604467	21460	41	23B
0005432604095	31709	1	1B
0005432604050	31709	2	1C
0005432604184	31709	3	2A
0005432604118	31709	4	2B
0005432604196	31709	5	2C
0005432604227	31709	6	3B
0005432604039	31709	7	3D
0005435221519	31709	8	4A
0005432604127	31709	9	4C
0005432604066	31709	10	4D
0005432604185	31709	11	5A
0005432604040	31709	12	5C
0005432604141	31709	13	5D
0005432604065	31709	14	6A
0005435221059	31709	15	6C
0005432604105	31709	16	6D
0005432604103	31709	17	7A
0005432604166	31709	18	7B
0005432604079	31709	19	7C
0005432604277	31709	20	18A
0005432604067	31709	21	18B
0005432604111	31709	22	18C
0005432604278	31709	23	18D
0005432604003	31709	24	19B
0005432604061	31709	25	19D
0005432604104	31709	26	20A
0005432604096	31709	27	20C
0005432604049	31709	28	20D
0005435221058	31709	29	21A
0005432604142	31709	30	21B
0005432604183	31709	31	21D
0005432604194	31709	32	22A
0005432604112	31709	33	22D
0005432604228	31709	34	23A
0005432604197	31709	35	23B
0005433293271	29593	1	1A
0005433293285	29593	2	1C
0005433293266	29593	3	3A
0005433293283	29593	4	3C
0005433293276	29593	5	4D
0005433293272	29593	6	5B
0005433293278	29593	7	5C
0005433293277	29593	8	5D
0005433293281	29593	9	6C
0005433293279	29593	10	7A
0005433293273	29593	11	7B
0005433293280	29593	12	7D
0005433293282	29593	13	18A
0005433293284	29593	14	18C
0005433293265	29593	15	20A
0005433293269	29593	16	21A
0005433293275	29593	17	21B
0005433293270	29593	18	22A
0005433293267	29593	19	22B
0005433293274	29593	20	22C
0005433293268	29593	21	23A
0005435257207	6683	1	1A
0005433473294	6683	2	1B
0005433473283	6683	3	1C
0005433473282	6683	4	1D
0005433473307	6683	5	2A
0005435257205	6683	6	2B
0005433473301	6683	7	2C
0005433473297	6683	8	2D
0005435257221	6683	9	3A
0005433473284	6683	10	3B
0005433473305	6683	11	3C
0005433473296	6683	12	3D
0005433473280	6683	13	4A
0005435257225	6683	14	4B
0005435257213	6683	15	4C
0005435257193	6683	16	4D
0005433473288	6683	17	5A
0005433473291	6683	18	5B
0005433473302	6683	19	5C
0005433473306	6683	20	5D
0005435257206	6683	21	6A
0005435257202	6683	22	6B
0005435257184	6683	23	6C
0005435257186	6683	24	6D
0005433473303	6683	25	7A
0005435257211	6683	26	7B
0005433473304	6683	27	7C
0005435257201	6683	28	7D
0005433473293	6683	29	18A
0005433473292	6683	30	18B
0005435257197	6683	31	18C
0005435257215	6683	32	18D
0005435257219	6683	33	19B
0005435257220	6683	34	19C
0005435257203	6683	35	19D
0005435257214	6683	36	20A
0005433473290	6683	37	20B
0005433473289	6683	38	20C
0005433473299	6683	39	20D
0005433473295	6683	40	21A
0005433473287	6683	41	21B
0005433473281	6683	42	21C
0005433473285	6683	43	21D
0005433473308	6683	44	22A
0005433473286	6683	45	22B
0005433473298	6683	46	22C
0005435257198	6683	47	22D
0005435257204	6683	48	23A
0005433473300	6683	49	23B
0005434606807	18894	1	1A
0005434606808	18894	2	2A
0005434606815	18894	3	6B
0005434606816	18894	4	6A
0005434606838	22392	1	2A
0005434606837	22392	2	5A
0005432747728	391	1	1A
0005432747716	391	2	1F
0005432747708	391	3	2C
0005432747712	391	4	2D
0005432747709	391	5	2F
0005432747697	391	6	3C
0005432890949	391	7	3F
0005432890990	391	8	4A
0005432747696	391	9	4C
0005432753314	391	10	4D
0005432747701	391	11	5E
0005432747727	391	12	6C
0005432747730	391	13	6D
0005432747717	391	14	6E
0005432890968	391	15	7A
0005432747726	391	16	7D
0005432747719	391	17	7E
0005432890792	391	18	7F
0005432747729	391	19	8A
0005432747721	391	20	8D
0005432747723	391	21	8E
0005432747698	391	22	8F
0005432753313	391	23	9A
0005432747700	391	24	9C
0005432890916	391	25	9D
0005433293205	391	26	9E
0005432751538	391	27	9F
0005432751537	391	28	10A
0005432890917	391	29	10C
0005435154599	391	30	10D
0005432747702	391	31	10E
0005432747694	391	32	10F
0005432747695	391	33	11C
0005433875365	391	34	11D
0005432890876	391	35	11E
0005432747711	391	36	11F
0005432890889	391	37	12A
0005432747725	391	38	12E
0005432747713	391	39	12F
0005432747704	391	40	13C
0005432747720	391	41	13D
0005432753312	391	42	13E
0005432747722	391	43	14A
0005432890963	391	44	14C
0005432890875	391	45	14D
0005432747714	391	46	14E
0005432890788	391	47	14F
0005432747724	391	48	15A
0005433293211	391	49	15C
0005432747715	391	50	16A
0005432890959	391	51	16C
0005432747710	391	52	16D
0005432747703	391	53	16F
0005432890850	391	54	17A
0005432749792	391	55	17C
0005432220021	391	56	17E
0005432753311	391	57	18A
0005432747706	391	58	18C
0005433875359	391	59	18D
0005432891034	391	60	18E
0005432747705	391	61	18F
0005432890893	391	62	19A
0005432891033	391	63	19C
0005432747731	391	64	19D
0005432747718	391	65	19E
0005432890927	391	66	19F
0005433293200	391	67	20C
0005432220020	391	68	20D
0005432747707	391	69	20E
0005432747699	391	70	20F
0005432747431	12054	1	1A
0005432747508	12054	2	1C
0005432747437	12054	3	1D
0005432747499	12054	4	1F
0005432753289	12054	5	2A
0005432891104	12054	6	2C
0005432891108	12054	7	2D
0005435627116	12054	8	2F
0005432747346	12054	9	3A
0005432747236	12054	10	3C
0005432891099	12054	11	3D
0005432747284	12054	12	3F
0005432747471	12054	13	4A
0005435627117	12054	14	4C
0005432747407	12054	15	4D
0005432891105	12054	16	4E
0005432747472	12054	17	4F
0005432891107	12054	18	5C
0005432747292	12054	19	5E
0005432747480	12054	20	5F
0005432756827	12054	21	6A
0005432747331	12054	22	6C
0005433875387	12054	23	6E
0005432747238	12054	24	6F
0005432747311	12054	25	7A
0005432747584	12054	26	7C
0005432749778	12054	27	7D
0005432747376	12054	28	8C
0005432747449	12054	29	8D
0005432747438	12054	30	8E
0005432747498	12054	31	8F
0005432747410	12054	32	9A
0005432756823	12054	33	9C
0005432891102	12054	34	9D
0005432747326	12054	35	9F
0005433875388	12054	36	10C
0005432891096	12054	37	10D
0005432891110	12054	38	10F
0005432891100	12054	39	11A
0005432891095	12054	40	11C
0005432891101	12054	41	11E
0005432747506	12054	42	11F
0005432747293	12054	43	12A
0005432747432	12054	44	12C
0005432891098	12054	45	12D
0005432756817	12054	46	12F
0005432747509	12054	47	13A
0005432891109	12054	48	13D
0005432747456	12054	49	13F
0005432747406	12054	50	14A
0005432747348	12054	51	14E
0005432747483	12054	52	14F
0005432891091	12054	53	15A
0005432747500	12054	54	15C
0005432747277	12054	55	15D
0005432756822	12054	56	15E
0005432747363	12054	57	15F
0005432891093	12054	58	16A
0005432747421	12054	59	16E
0005432747325	12054	60	16F
0005432891097	12054	61	17A
0005432756816	12054	62	17C
0005432756824	12054	63	17D
0005432747501	12054	64	17F
0005432891103	12054	65	18A
0005432891092	12054	66	18D
0005432747291	12054	67	18E
0005432747450	12054	68	18F
0005432891106	12054	69	19C
0005432747457	12054	70	19D
0005432891090	12054	71	19E
0005432891094	12054	72	19F
0005432747283	12054	73	20A
0005432747374	12054	74	20C
0005432747324	12054	75	20D
0005432747377	12054	76	20E
0005432927955	18965	1	1B
0005433525073	18965	2	2C
0005433531305	18965	3	2D
0005433531304	18965	4	3B
0005433525078	18965	5	4A
0005432927926	18965	6	4B
0005432927957	18965	7	4D
0005433533322	18965	8	6B
0005432927956	18965	9	7B
0005433533318	18965	10	7C
0005433525071	18965	11	18B
0005433531306	18965	12	19B
0005433525077	18965	13	19C
0005433533321	18965	14	19D
0005433525074	18965	15	20A
0005433525070	18965	16	20B
0005433525079	18965	17	21A
0005433525076	18965	18	21B
0005432927939	18965	19	21C
0005433525072	18965	20	21D
0005433533320	18965	21	22A
0005433533319	18965	22	23A
0005433525075	18965	23	23B
0005433524999	32497	1	1D
0005433525017	32497	2	2D
0005432928008	32497	3	4A
0005433525011	32497	4	4D
0005433525023	32497	5	5A
0005432928007	32497	6	5C
0005433527250	32497	7	6B
0005433524988	32497	8	6D
0005433527242	32497	9	7A
0005433524972	32497	10	18A
0005433527247	32497	11	7D
0005432928010	32497	12	18B
0005433525000	32497	13	18C
0005433527249	32497	14	18D
0005433525053	32497	15	19A
0005433525013	32497	16	19D
0005433527248	32497	17	20A
0005433525012	32497	18	20B
0005433524973	32497	19	20C
0005432928009	32497	20	20D
0005433525035	32497	21	21A
0005433525018	32497	22	21B
0005433525007	32497	23	21C
0005433527237	32497	24	22A
0005433527238	32497	25	22C
0005433527219	32497	26	22D
0005433524909	32497	27	23A
0005434824119	5288	1	1H
0005434824046	5288	2	1G
0005434824062	5288	3	1D
0005434824065	5288	4	1K
0005434824095	5288	5	2D
0005434824166	5288	6	2C
0005435386522	5288	7	2A
0005435150082	5288	8	2G
0005434824090	5288	9	2K
0005434824143	5288	10	3G
0005434824147	5288	11	3D
0005434824148	5288	12	3H
0005435372891	5288	13	4A
0005434824068	5288	14	4D
0005434824167	5288	15	4C
0005434824085	5288	16	4K
0005435735116	5288	17	4H
0005434831164	5288	18	5C
0005435372829	5288	19	5A
0005435373119	5288	20	5H
0005434664969	5288	21	5G
0005434824121	5288	22	5D
0005432121386	5288	23	11A
0005434831167	5288	24	5K
0005435150084	5288	25	11E
0005434824052	5288	26	11D
0005435299756	5288	27	11F
0005434824042	5288	28	11K
0005432121391	5288	29	11G
0005434824151	5288	30	12C
0005434824117	5288	31	12A
0005434824071	5288	32	12E
0005434824161	5288	33	12G
0005432121397	5288	34	12F
0005432121398	5288	35	12H
0005432396261	5288	36	13C
0005434824078	5288	37	13A
0005434824108	5288	38	13F
0005432121393	5288	39	13E
0005435373003	5288	40	13K
0005435373060	5288	41	13H
0005435386535	5288	42	13G
0005434824104	5288	43	14A
0005434824127	5288	44	14D
0005434824049	5288	45	14C
0005434824137	5288	46	14G
0005435386552	5288	47	14F
0005434824140	5288	48	14E
0005434824162	5288	49	14H
0005435304150	5288	50	15C
0005434824131	5288	51	14K
0005432121399	5288	52	15D
0005434824135	5288	53	15G
0005434824123	5288	54	15F
0005432121390	5288	55	15H
0005435372934	5288	56	16D
0005434664966	5288	57	16C
0005432396260	5288	58	16A
0005434824072	5288	59	16F
0005435372809	5288	60	16E
0005434824081	5288	61	16K
0005435373135	5288	62	16G
0005434824126	5288	63	17C
0005432121388	5288	64	17D
0005435372931	5288	65	17K
0005435372686	5288	66	17H
0005435386564	5288	67	18B
0005434824120	5288	68	18A
0005434824093	5288	69	18D
0005434824150	5288	70	18F
0005435372873	5288	71	18K
0005435373008	5288	72	18J
0005434824111	5288	73	19B
0005434824070	5288	74	19D
0005435373034	5288	75	19C
0005434824129	5288	76	19G
0005435372802	5288	77	19E
0005432396259	5288	78	19J
0005435373122	5288	79	19H
0005435735125	5288	80	20A
0005435373104	5288	81	19K
0005434824115	5288	82	20C
0005435373098	5288	83	20E
0005434824060	5288	84	20D
0005435299773	5288	85	20G
0005435386556	5288	86	20F
0005434824079	5288	87	20K
0005435373040	5288	88	21A
0005434824113	5288	89	21D
0005435386574	5288	90	21C
0005432396258	5288	91	21F
0005434824059	5288	92	21H
0005435373025	5288	93	22A
0005434824110	5288	94	22C
0005435372808	5288	95	22F
0005434824130	5288	96	22E
0005435372503	5288	97	22D
0005434824092	5288	98	22K
0005435661907	5288	99	22J
0005434824074	5288	100	23A
0005432394123	5288	101	23D
0005435150089	5288	102	23F
0005435372910	5288	103	23E
0005434824125	5288	104	23H
0005434824149	5288	105	23G
0005435372872	5288	106	24D
0005435373082	5288	107	23K
0005434824057	5288	108	25A
0005434664967	5288	109	24G
0005434824076	5288	110	25D
0005434824112	5288	111	25C
0005434824082	5288	112	25B
0005434824053	5288	113	25F
0005435372883	5288	114	25E
0005434824039	5288	115	25H
0005435150091	5288	116	25G
0005435372937	5288	117	26A
0005435372699	5288	118	25K
0005434824083	5288	119	26C
0005435373074	5288	120	26G
0005434824094	5288	121	26F
0005435304130	5288	122	26J
0005434824054	5288	123	26H
0005435373118	5288	124	27B
0005435299744	5288	125	26K
0005434824153	5288	126	27D
0005435735092	5288	127	27C
0005435373073	5288	128	27F
0005435661921	5288	129	27E
0005435661917	5288	130	27G
0005435372858	5288	131	28A
0005434824066	5288	132	27K
0005432121396	5288	133	27J
0005432121392	5288	134	28C
0005434824047	5288	135	28B
0005435372830	5288	136	28D
0005435373168	5288	137	28F
0005435372874	5288	138	28J
0005435299761	5288	139	29A
0005435372925	5288	140	28K
0005435373010	5288	141	29D
0005434824061	5288	142	29C
0005434824102	5288	143	29B
0005432121387	5288	144	29E
0005434824069	5288	145	29J
0005434828707	5288	146	30A
0005434824084	5288	147	29K
0005434664968	5288	148	30C
0005435373019	5288	149	30B
0005434824133	5288	150	30E
0005435372737	5288	151	30D
0005435372857	5288	152	30F
0005434824136	5288	153	30J
0005432121395	5288	154	31A
0005434824044	5288	155	31D
0005435150085	5288	156	31F
0005435150083	5288	157	31E
0005435735120	5288	158	31G
0005435372998	5288	159	31J
0005434824043	5288	160	32C
0005435150088	5288	161	32B
0005435372911	5288	162	32A
0005434824141	5288	163	32E
0005434824134	5288	164	32H
0005434824138	5288	165	32F
0005432394122	5288	166	32J
0005435372672	5288	167	33A
0005434824100	5288	168	32K
0005435373021	5288	169	33D
0005434824041	5288	170	33G
0005434824064	5288	171	33F
0005435299757	5288	172	33J
0005434824163	5288	173	33H
0005434824106	5288	174	34A
0005434824156	5288	175	33K
0005434824048	5288	176	34C
0005434824116	5288	177	34E
0005435372936	5288	178	34J
0005435386540	5288	179	34H
0005435372738	5288	180	35B
0005434824080	5288	181	35A
0005434824105	5288	182	35D
0005435150090	5288	183	35C
0005434824103	5288	184	35E
0005435373071	5288	185	35J
0005435372502	5288	186	35H
0005435373134	5288	187	36A
0005435372671	5288	188	35K
0005435372685	5288	189	36E
0005434824086	5288	190	36D
0005434831166	5288	191	37A
0005432394121	5288	192	37D
0005432121394	5288	193	37C
0005434824114	5288	194	37E
0005434824157	5288	195	37J
0005434828705	5288	196	38A
0005434824145	5288	197	38C
0005435735114	5288	198	38B
0005434824128	5288	199	38J
0005435386555	5288	200	38H
0005435150092	5288	201	39B
0005434824164	5288	202	39A
0005435373053	5288	203	38K
0005434824045	5288	204	39D
0005435372789	5288	205	39F
0005435373225	5288	206	39H
0005434824122	5288	207	39G
0005435372983	5288	208	40A
0005435386553	5288	209	39J
0005432121389	5288	210	40C
0005434824051	5288	211	40B
0005434824132	5288	212	40E
0005434824050	5288	213	40H
0005434824038	5288	214	40G
0005434824040	5288	215	40F
0005434824055	5288	216	40K
0005435373087	5288	217	40J
0005435150086	5288	218	41A
0005434831163	5288	219	41F
0005435299772	5288	220	41H
0005434824073	5288	221	41G
0005434824101	5288	222	42A
0005434824098	5288	223	41K
0005435373024	5288	224	42C
0005435373011	5288	225	42B
0005435372930	5288	226	42E
0005434824109	5288	227	42D
0005434824096	5288	228	42K
0005434824139	5288	229	42J
0005435372845	5288	230	43A
0005435372933	5288	231	43B
0005434824160	5288	232	43F
0005434824155	5288	233	43E
0005435386539	5288	234	43H
0005435372836	5288	235	43G
0005434664970	5288	236	43K
0005432823436	5288	237	44B
0005435150087	5288	238	44E
0005434824152	5288	239	44D
0005435735100	5288	240	44G
0005434824097	5288	241	44H
0005434824058	5288	242	44K
0005434824089	5288	243	45F
0005434824091	5288	244	45E
0005435373151	5288	245	45D
0005434824124	5288	246	45H
0005434824159	5288	247	45G
0005435372935	5288	248	45K
0005434824088	5288	249	46B
0005435372928	5288	250	46A
0005434831165	5288	251	46D
0005434828706	5288	252	46F
0005434824158	5288	253	46J
0005435372763	5288	254	46H
0005434824142	5288	255	47A
0005434824144	5288	256	47D
0005435372828	5288	257	47C
0005434824099	5288	258	47G
0005434824146	5288	259	47K
0005434824067	5288	260	47H
0005434824077	5288	261	48C
0005435372884	5288	262	48A
0005434824063	5288	263	48F
0005434824075	5288	264	48H
0005434824056	5288	265	48G
0005434824087	5288	266	49A
0005435735115	5288	267	48K
0005435299745	5288	268	49C
0005434824107	5288	269	49G
0005434824118	5288	270	49K
0005434824165	5288	271	50C
0005435372893	5288	272	50E
0005435372894	5288	273	50G
0005434824154	5288	274	50F
0005435372905	5288	275	51F
0005435373099	5288	276	51D
0005432823435	5288	277	51G
0005435735154	9926	1	1D
0005435661944	9926	2	1C
0005434823100	9926	3	1A
0005434823084	9926	4	1H
0005434823240	9926	5	1G
0005435299797	9926	6	2A
0005434822635	9926	7	1K
0005435373540	9926	8	2C
0005435373547	9926	9	2H
0005434823093	9926	10	2G
0005434823396	9926	11	3A
0005434822779	9926	12	2K
0005432396212	9926	13	3D
0005435373525	9926	14	3C
0005434822973	9926	15	3K
0005434822497	9926	16	3H
0005434822750	9926	17	4A
0005435299793	9926	18	4G
0005434828683	9926	19	4D
0005432823459	9926	20	5A
0005435373521	9926	21	4K
0005435735155	9926	22	4H
0005434822980	9926	23	5D
0005435373559	9926	24	5C
0005435373553	9926	25	5H
0005434558214	9926	26	5G
0005435373562	9926	27	11A
0005435373550	9926	28	5K
0005435373517	9926	29	11D
0005435373534	9926	30	11C
0005434558198	9926	31	11F
0005435373538	9926	32	11K
0005435149963	9926	33	11H
0005434823177	9926	34	11G
0005435179397	9926	35	12C
0005435373561	9926	36	12A
0005432203093	9926	37	12E
0005434823073	9926	38	12D
0005432400100	9926	39	12K
0005434822837	9926	40	12H
0005434822868	9926	41	13A
0005434822870	9926	42	13F
0005432203091	9926	43	13E
0005435149998	9926	44	13H
0005432396221	9926	45	13G
0005432400111	9926	46	14D
0005434822884	9926	47	14C
0005434823289	9926	48	14G
0005434822928	9926	49	14F
0005434823241	9926	50	14E
0005435149936	9926	51	14K
0005434822845	9926	52	15A
0005434823296	9926	53	15E
0005435373539	9926	54	15D
0005434822911	9926	55	15H
0005434823499	9926	56	15G
0005435373518	9926	57	15F
0005435302218	9926	58	16A
0005435661943	9926	59	15K
0005434823219	9926	60	16C
0005434558223	9926	61	16G
0005435149992	9926	62	16F
0005434823379	9926	63	16E
0005434823149	9926	64	16K
0005435149975	9926	65	16H
0005435386596	9926	66	17C
0005435149957	9926	67	17A
0005434823200	9926	68	17E
0005434822957	9926	69	17D
0005435149930	9926	70	17G
0005435373516	9926	71	17F
0005435373529	9926	72	17K
0005434823297	9926	73	17H
0005435661945	9926	74	18C
0005435373526	9926	75	18B
0005435373505	9926	76	18A
0005435299798	9926	77	18G
0005435149880	9926	78	18H
0005435149938	9926	79	19B
0005435373557	9926	80	19A
0005434823017	9926	81	18K
0005434822898	9926	82	19C
0005435373507	9926	83	19F
0005435373515	9926	84	19E
0005435149985	9926	85	19H
0005434822896	9926	86	19G
0005435735153	9926	87	20A
0005435373536	9926	88	20B
0005434822520	9926	89	20E
0005434823098	9926	90	20D
0005435373509	9926	91	20C
0005434822971	9926	92	20G
0005434822927	9926	93	20F
0005434822860	9926	94	20H
0005434822913	9926	95	21B
0005434822754	9926	96	21A
0005434822923	9926	97	20K
0005434823223	9926	98	21D
0005434823665	9926	99	21E
0005434823239	9926	100	21H
0005434822972	9926	101	21G
0005434823674	9926	102	22A
0005435373528	9926	103	21K
0005435149950	9926	104	22B
0005435373503	9926	105	22D
0005434823362	9926	106	22G
0005434823685	9926	107	22F
0005434822408	9926	108	22K
0005434823077	9926	109	22H
0005434831132	9926	110	23B
0005432203094	9926	111	23A
0005435373496	9926	112	23D
0005434822872	9926	113	23C
0005434823397	9926	114	23J
0005432396235	9926	115	23H
0005432396230	9926	116	24D
0005434831105	9926	117	24F
0005435373510	9926	118	24E
0005434558224	9926	119	25A
0005434823152	9926	120	24G
0005434822992	9926	121	25C
0005434823616	9926	122	25B
0005432203089	9926	123	25F
0005434828676	9926	124	25E
0005434823072	9926	125	25K
0005435373520	9926	126	25J
0005434822537	9926	127	26B
0005434823419	9926	128	26E
0005435373532	9926	129	26D
0005435373552	9926	130	26G
0005435299795	9926	131	26F
0005434822988	9926	132	26H
0005434823071	9926	133	26K
0005432823460	9926	134	27C
0005435373542	9926	135	27B
0005435149988	9926	136	27F
0005435149976	9926	137	27E
0005434831104	9926	138	27H
0005434831125	9926	139	27K
0005434823542	9926	140	27J
0005434823516	9926	141	28C
0005434822970	9926	142	28E
0005434823380	9926	143	28H
0005432400127	9926	144	28F
0005435373514	9926	145	28J
0005435373527	9926	146	29B
0005434823551	9926	147	29A
0005434822540	9926	148	28K
0005435373504	9926	149	29D
0005435373551	9926	150	29C
0005434828684	9926	151	29E
0005435373522	9926	152	29H
0005434823281	9926	153	29G
0005435302219	9926	154	29J
0005434823666	9926	155	30C
0005435735157	9926	156	30A
0005432203096	9926	157	30E
0005435373535	9926	158	30F
0005435299794	9926	159	30J
0005434823250	9926	160	31A
0005435735158	9926	161	30K
0005435149978	9926	162	31C
0005434822780	9926	163	31G
0005434823614	9926	164	31K
0005434822634	9926	165	31J
0005434823094	9926	166	32B
0005435373497	9926	167	32E
0005434823095	9926	168	32D
0005435735156	9926	169	32G
0005432203095	9926	170	32F
0005435373560	9926	171	32J
0005435373541	9926	172	32H
0005434823590	9926	173	33B
0005434822809	9926	174	33F
0005434822774	9926	175	33E
0005435373524	9926	176	33H
0005434822981	9926	177	33G
0005435373548	9926	178	33K
0005435373555	9926	179	34C
0005435373519	9926	180	34B
0005435149935	9926	181	34E
0005432203092	9926	182	34D
0005435386595	9926	183	34G
0005434823151	9926	184	34J
0005435661942	9926	185	34H
0005434823103	9926	186	35B
0005435373508	9926	187	35A
0005432400097	9926	188	34K
0005434823686	9926	189	35D
0005432823458	9926	190	35F
0005434822979	9926	191	35E
0005435149977	9926	192	35H
0005435373544	9926	193	36A
0005435373543	9926	194	35K
0005434823167	9926	195	36D
0005434831107	9926	196	36C
0005434823476	9926	197	36B
0005435373495	9926	198	36G
0005434831108	9926	199	36K
0005435302217	9926	200	36J
0005434822484	9926	201	37B
0005434823101	9926	202	37E
0005434822890	9926	203	37C
0005434822936	9926	204	37G
0005435373530	9926	205	37F
0005434823487	9926	206	37J
0005435373502	9926	207	37K
0005434822593	9926	208	38C
0005435373533	9926	209	38B
0005434664943	9926	210	38J
0005434823123	9926	211	39B
0005435373549	9926	212	39A
0005435149932	9926	213	38K
0005435373554	9926	214	39D
0005435373500	9926	215	39C
0005434822743	9926	216	39F
0005434831124	9926	217	39E
0005435386597	9926	218	39J
0005434823589	9926	219	39H
0005435373506	9926	220	39G
0005434822510	9926	221	40A
0005434823251	9926	222	39K
0005435373512	9926	223	40C
0005434823238	9926	224	40B
0005435149956	9926	225	40E
0005434822767	9926	226	40D
0005434823383	9926	227	40H
0005434823486	9926	228	40G
0005434822680	9926	229	40F
0005434558205	9926	230	40K
0005435149989	9926	231	41A
0005435149949	9926	232	41D
0005434822808	9926	233	41B
0005435149991	9926	234	41F
0005434822941	9926	235	41E
0005435373498	9926	236	41H
0005434823222	9926	237	41G
0005434822885	9926	238	42A
0005434822541	9926	239	41K
0005434831127	9926	240	42F
0005435373501	9926	241	42D
0005435149961	9926	242	42G
0005432396216	9926	243	42J
0005434831128	9926	244	42H
0005434822929	9926	245	43B
0005434822641	9926	246	43A
0005434823122	9926	247	42K
0005434558215	9926	248	43D
0005435373558	9926	249	43F
0005435149990	9926	250	43H
0005434823382	9926	251	43K
0005435373523	9926	252	43J
0005434822940	9926	253	44C
0005432400112	9926	254	44B
0005434822949	9926	255	44A
0005435149960	9926	256	44D
0005434823381	9926	257	44J
0005435149952	9926	258	44H
0005435149937	9926	259	44K
0005435149948	9926	260	45C
0005434823361	9926	261	45B
0005434822539	9926	262	45F
0005435302216	9926	263	45E
0005435373545	9926	264	45J
0005434823059	9926	265	45H
0005434823615	9926	266	45G
0005434822945	9926	267	45K
0005435373531	9926	268	46A
0005434823113	9926	269	46D
0005434822861	9926	270	46G
0005434822790	9926	271	46F
0005434823768	9926	272	46K
0005435373511	9926	273	46J
0005434823625	9926	274	46H
0005435149918	9926	275	47D
0005435373513	9926	276	47C
0005434823000	9926	277	48A
0005434823099	9926	278	47H
0005434831110	9926	279	48C
0005434822982	9926	280	48E
0005434823218	9926	281	48G
0005434822592	9926	282	48F
0005432400109	9926	283	49D
0005434822987	9926	284	49G
0005434823005	9926	285	49F
0005435299796	9926	286	49E
0005435149993	9926	287	49K
0005435149919	9926	288	49H
0005435373537	9926	289	50C
0005435373499	9926	290	50E
0005432203090	9926	291	50G
0005434823242	9926	292	50F
0005434822937	9926	293	50K
0005434823370	9926	294	51F
0005435373546	9926	295	51E
0005435373556	9926	296	51G
0005435082815	7009	1	1B
0005435082819	7009	2	2D
0005435082818	7009	3	3C
0005435790320	7009	4	3D
0005435082816	7009	5	5D
0005435082817	7009	6	6C
0005435082820	7009	7	7B
0005435790318	7009	8	18B
0005435790319	7009	9	18C
0005435082821	7009	10	19B
0005435082814	7009	11	20B
0005435082813	7009	12	20C
0005435082822	7009	13	22D
0005435082715	25999	1	1C
0005435082755	25999	2	2D
0005435082760	25999	3	5B
0005435082761	25999	4	6C
0005435082752	25999	5	18A
0005435082759	25999	6	19C
0005435082754	25999	7	20A
0005435082737	25999	8	21A
0005435082765	25999	9	21B
0005435082736	25999	10	22A
0005435082753	25999	11	23A
0005434214455	9533	1	1A
0005434214242	9533	2	1C
0005434756609	9533	3	1D
0005434756568	9533	4	1F
0005434214381	9533	5	2C
0005434756605	9533	6	2D
0005434756599	9533	7	2F
0005434214409	9533	8	3A
0005434214268	9533	9	3C
0005434214284	9533	10	3D
0005434756596	9533	11	3F
0005434214457	9533	12	4A
0005434214456	9533	13	4C
0005434756584	9533	14	4D
0005434756569	9533	15	4E
0005434756601	9533	16	4F
0005434214238	9533	17	5A
0005434756583	9533	18	5C
0005434214404	9533	19	5D
0005434756600	9533	20	5E
0005434214314	9533	21	5F
0005434214239	9533	22	6A
0005434214373	9533	23	6C
0005434756598	9533	24	6D
0005434756572	9533	25	6E
0005434214224	9533	26	6F
0005434214251	9533	27	7A
0005434756602	9533	28	7C
0005434756573	9533	29	7D
0005434214290	9533	30	7E
0005434214331	9533	31	7F
0005434756575	9533	32	8A
0005434214228	9533	33	8C
0005434756576	9533	34	8D
0005434214288	9533	35	8E
0005434756570	9533	36	8F
0005434214205	9533	37	9A
0005434756606	9533	38	9C
0005434214308	9533	39	9D
0005434214116	9533	40	9E
0005434756608	9533	41	9F
0005434756595	9533	42	10A
0005434214289	9533	43	10C
0005434756589	9533	44	10D
0005434756588	9533	45	10E
0005434756574	9533	46	10F
0005434756611	9533	47	11A
0005434214378	9533	48	11C
0005434756571	9533	49	11D
0005434214306	9533	50	11E
0005434756582	9533	51	11F
0005434756585	9533	52	12A
0005434214241	9533	53	12C
0005434756597	9533	54	12D
0005434756586	9533	55	12E
0005434214351	9533	56	12F
0005434756580	9533	57	13A
0005434756607	9533	58	13C
0005434214319	9533	59	13D
0005434756581	9533	60	13E
0005434214206	9533	61	13F
0005434214277	9533	62	14A
0005434756590	9533	63	14D
0005434214215	9533	64	14F
0005434214082	9533	65	15A
0005434756577	9533	66	15C
0005434214403	9533	67	15D
0005434214267	9533	68	15E
0005434214166	9533	69	15F
0005434214425	9533	70	16A
0005434214258	9533	71	16C
0005434214375	9533	72	16D
0005434756612	9533	73	16E
0005434214266	9533	74	16F
0005434214196	9533	75	17A
0005434214276	9533	76	17C
0005434756579	9533	77	17D
0005434756591	9533	78	17E
0005434756603	9533	79	17F
0005434214350	9533	80	18A
0005434756593	9533	81	18C
0005434756594	9533	82	18D
0005434214240	9533	83	18E
0005434214262	9533	84	18F
0005434756567	9533	85	19C
0005434756604	9533	86	19D
0005434214337	9533	87	19E
0005434214081	9533	88	19F
0005434756578	9533	89	20A
0005434214374	9533	90	20C
0005434756592	9533	91	20D
0005434756610	9533	92	20E
0005434756587	9533	93	20F
0005434214694	28601	1	1A
0005434214681	28601	2	1C
0005434214653	28601	3	1D
0005434214674	28601	4	1F
0005434214661	28601	5	2A
0005434214688	28601	6	2C
0005434756161	28601	7	2D
0005434756138	28601	8	2F
0005434214670	28601	9	3C
0005434214667	28601	10	3D
0005434756099	28601	11	3F
0005434756042	28601	12	4A
0005434214659	28601	13	4C
0005434756243	28601	14	4D
0005434214677	28601	15	4E
0005434756179	28601	16	4F
0005434214684	28601	17	5A
0005434214656	28601	18	5C
0005434756173	28601	19	5D
0005434214680	28601	20	5E
0005434214695	28601	21	5F
0005434756118	28601	22	6A
0005434756182	28601	23	6E
0005434756373	28601	24	6F
0005434756101	28601	25	7A
0005434214687	28601	26	7C
0005434214678	28601	27	7D
0005434756043	28601	28	7E
0005434756171	28601	29	7F
0005434214662	28601	30	8A
0005434214658	28601	31	8C
0005434756150	28601	32	8D
0005434756210	28601	33	8E
0005434214691	28601	34	8F
0005434214679	28601	35	9A
0005434214692	28601	36	9C
0005434214685	28601	37	9D
0005434214668	28601	38	9E
0005434214663	28601	39	9F
0005434756126	28601	40	10A
0005434214660	28601	41	10D
0005434756148	28601	42	10E
0005434214650	28601	43	10F
0005434214665	28601	44	11A
0005434756162	28601	45	11C
0005434214664	28601	46	11D
0005434214669	28601	47	11E
0005434214686	28601	48	11F
0005434756102	28601	49	12A
0005434755975	28601	50	12C
0005434756029	28601	51	12E
0005434756177	28601	52	12F
0005434214693	28601	53	13A
0005434756124	28601	54	13C
0005434755966	28601	55	13D
0005434756244	28601	56	13F
0005434214666	28601	57	14A
0005434756125	28601	58	14C
0005434756294	28601	59	14D
0005434214676	28601	60	14E
0005434756183	28601	61	14F
0005434214654	28601	62	15A
0005434214652	28601	63	15C
0005434756239	28601	64	15D
0005434756107	28601	65	15E
0005434756267	28601	66	15F
0005434756095	28601	67	16A
0005434214683	28601	68	16C
0005434214651	28601	69	16D
0005434756268	28601	70	16E
0005434214689	28601	71	16F
0005434756149	28601	72	17A
0005434214690	28601	73	17C
0005434756114	28601	74	17D
0005434214671	28601	75	17E
0005434756096	28601	76	17F
0005434756190	28601	77	18A
0005434756269	28601	78	18C
0005434214672	28601	79	18D
0005434214682	28601	80	18E
0005434214673	28601	81	18F
0005434756116	28601	82	19A
0005434214675	28601	83	19C
0005434214657	28601	84	19F
0005434756200	28601	85	20C
0005434214696	28601	86	20D
0005434214655	28601	87	20E
0005434756191	28601	88	20F
0005435100137	10812	1	1A
0005434760188	10812	2	1D
0005434760193	10812	3	3C
0005434760183	10812	4	4D
0005434760191	10812	5	19C
0005435100134	10812	6	21A
0005435100136	10812	7	21B
0005435100135	10812	8	21D
0005434760206	31840	1	1C
0005434760208	31840	2	3A
0005435100124	31840	3	3C
0005435100123	31840	4	4D
0005435100125	31840	5	21A
0005434760207	31840	6	22A
0005434639443	2006	1	1A
0005434639444	2006	2	1B
0005434639428	2006	3	1C
0005433202311	2006	4	1D
0005434639424	2006	5	2A
0005433202253	2006	6	2B
0005432290646	2006	7	2C
0005433202268	2006	8	2D
0005433202301	2006	9	3A
0005433202214	2006	10	3B
0005434639436	2006	11	3C
0005434639426	2006	12	3D
0005434639434	2006	13	4A
0005434639422	2006	14	4B
0005434639438	2006	15	4C
0005434639427	2006	16	4D
0005432290647	2006	17	5A
0005433202264	2006	18	5B
0005432290645	2006	19	5C
0005433202208	2006	20	5D
0005434639441	2006	21	6A
0005434639437	2006	22	6B
0005434639439	2006	23	6C
0005434639442	2006	24	6D
0005433202270	2006	25	7A
0005433202308	2006	26	7B
0005434639446	2006	27	7C
0005434639435	2006	28	7D
0005434639431	2006	29	18A
0005434639449	2006	30	18B
0005433202265	2006	31	18C
0005434639430	2006	32	18D
0005434639425	2006	33	19A
0005434639432	2006	34	19B
0005433202300	2006	35	19C
0005434639445	2006	36	19D
0005433202239	2006	37	20A
0005433202394	2006	38	20B
0005433202266	2006	39	20C
0005434639447	2006	40	20D
0005433202209	2006	41	21A
0005435948330	2006	42	21B
0005434639440	2006	43	21C
0005433202288	2006	44	21D
0005434639423	2006	45	22A
0005434639429	2006	46	22B
0005433202269	2006	47	22C
0005433202286	2006	48	22D
0005434639448	2006	49	23A
0005434639433	2006	50	23B
0005434639149	23265	1	1A
0005433202404	23265	2	1B
0005434639204	23265	3	1C
0005434639196	23265	4	2A
0005434639148	23265	5	2B
0005433202414	23265	6	2C
0005434639227	23265	7	2D
0005435948324	23265	8	3A
0005433202416	23265	9	3B
0005434639234	23265	10	3C
0005434639222	23265	11	3D
0005434639190	23265	12	4A
0005434639188	23265	13	4B
0005435948322	23265	14	4C
0005434639279	23265	15	4D
0005434639017	23265	16	5A
0005434639267	23265	17	5B
0005434639224	23265	18	5C
0005434639223	23265	19	5D
0005434639205	23265	20	6A
0005434639235	23265	21	6B
0005433202409	23265	22	6C
0005434639189	23265	23	6D
0005434639221	23265	24	7A
0005433202408	23265	25	7B
0005434639082	23265	26	7C
0005434639146	23265	27	7D
0005435948323	23265	28	18A
0005434639098	23265	29	18B
0005433202418	23265	30	18C
0005433202403	23265	31	18D
0005433202417	23265	32	19A
0005434639226	23265	33	19B
0005433202413	23265	34	19C
0005433202415	23265	35	19D
0005433202407	23265	36	20A
0005435948320	23265	37	20B
0005433202411	23265	38	20C
0005434639191	23265	39	21A
0005433202412	23265	40	21B
0005434639228	23265	41	21C
0005435948321	23265	42	21D
0005434639225	23265	43	22A
0005433202406	23265	44	22B
0005434639213	23265	45	22C
0005433202405	23265	46	22D
0005433202410	23265	47	23A
0005435948325	23265	48	23B
0005434600921	6061	1	1A
0005434600920	6061	2	1C
0005435326659	6061	3	1D
0005435326684	6061	4	1F
0005434600928	6061	5	2A
0005435326651	6061	6	2C
0005432111290	6061	7	2D
0005435326704	6061	8	2F
0005434600932	6061	9	3C
0005434600908	6061	10	4C
0005433531309	6061	11	4D
0005434600917	6061	12	4E
0005434600915	6061	13	4F
0005435326646	6061	14	5C
0005434600914	6061	15	5D
0005435326703	6061	16	5E
0005434600930	6061	17	6C
0005434600927	6061	18	6D
0005434600916	6061	19	6E
0005435326692	6061	20	6F
0005434600911	6061	21	7A
0005435326758	6061	22	7C
0005435326678	6061	23	7F
0005434600918	6061	24	8A
0005435326728	6061	25	8E
0005435326735	6061	26	8F
0005434600909	6061	27	9A
0005434600923	6061	28	10A
0005434600922	6061	29	10C
0005434600924	6061	30	10D
0005435326673	6061	31	11A
0005433531307	6061	32	11C
0005434600907	6061	33	11D
0005435326690	6061	34	11F
0005433533324	6061	35	12A
0005433533323	6061	36	12C
0005432111291	6061	37	12E
0005434600925	6061	38	12F
0005434600910	6061	39	13A
0005435326683	6061	40	13C
0005435326706	6061	41	14A
0005435326662	6061	42	14E
0005432111293	6061	43	15A
0005435326727	6061	44	15C
0005434600919	6061	45	15D
0005433531310	6061	46	15E
0005435326645	6061	47	15F
0005434600912	6061	48	16C
0005432111292	6061	49	16D
0005434600926	6061	50	16F
0005434600929	6061	51	17C
0005435326717	6061	52	17F
0005434600913	6061	53	18A
0005435326693	6061	54	18C
0005432111289	6061	55	18D
0005435326687	6061	56	18E
0005435326756	6061	57	19A
0005435326672	6061	58	19D
0005433531308	6061	59	19E
0005435326757	6061	60	19F
0005435326650	6061	61	20A
0005433533325	6061	62	20D
0005435326733	6061	63	20E
0005434600931	6061	64	20F
0005434600737	18566	1	1C
0005435326803	18566	2	2A
0005435326795	18566	3	2D
0005434600713	18566	4	3C
0005434600709	18566	5	3D
0005435326806	18566	6	4A
0005433531275	18566	7	4C
0005434600647	18566	8	4D
0005434600566	18566	9	5A
0005434600662	18566	10	6D
0005434600747	18566	11	7C
0005435326796	18566	12	7D
0005435326799	18566	13	7F
0005433531284	18566	14	8A
0005434600684	18566	15	8D
0005433531280	18566	16	8F
0005434600663	18566	17	9A
0005434600618	18566	18	9C
0005435326802	18566	19	9F
0005434600717	18566	20	10A
0005434600683	18566	21	10E
0005434600696	18566	22	10F
0005433531277	18566	23	11D
0005434600681	18566	24	12A
0005435326805	18566	25	12C
0005434600732	18566	26	12D
0005435326797	18566	27	12F
0005434600720	18566	28	13F
0005434600714	18566	29	14A
0005434600680	18566	30	14C
0005435326800	18566	31	14E
0005434600692	18566	32	15A
0005435326798	18566	33	15C
0005435326801	18566	34	15D
0005434600718	18566	35	15F
0005433531276	18566	36	16A
0005434600567	18566	37	16C
0005434600655	18566	38	16D
0005434600736	18566	39	16F
0005434600685	18566	40	17A
0005433531285	18566	41	17C
0005434600666	18566	42	17D
0005434600762	18566	43	18A
0005434600721	18566	44	18E
0005435326808	18566	45	18F
0005434600724	18566	46	19C
0005434600725	18566	47	19D
0005434600726	18566	48	19E
0005434600695	18566	49	20A
0005435326807	18566	50	20E
0005435326804	18566	51	20F
0005434551412	10672	1	1A
0005434551402	10672	2	1C
0005434558306	10672	3	1D
0005433180832	10672	4	1F
0005434551404	10672	5	2D
0005433180969	10672	6	2F
0005434558304	10672	7	3A
0005434551420	10672	8	3C
0005434551403	10672	9	3D
0005434551433	10672	10	3F
0005434551386	10672	11	4A
0005434551390	10672	12	4C
0005434551408	10672	13	4D
0005433180954	10672	14	4E
0005434551435	10672	15	4F
0005434551424	10672	16	5A
0005434551398	10672	17	5C
0005434551397	10672	18	5D
0005434551436	10672	19	5E
0005434551421	10672	20	5F
0005434551394	10672	21	6A
0005434551429	10672	22	6C
0005434551410	10672	23	6D
0005433180943	10672	24	6E
0005434551413	10672	25	6F
0005434551385	10672	26	7A
0005434551389	10672	27	7C
0005433180941	10672	28	7D
0005434551430	10672	29	7E
0005434551423	10672	30	7F
0005434551388	10672	31	8A
0005434551437	10672	32	8C
0005433180985	10672	33	8D
0005433180870	10672	34	8E
0005434551432	10672	35	8F
0005434551406	10672	36	9A
0005433180988	10672	37	9C
0005433180952	10672	38	9D
0005434551393	10672	39	9E
0005433180910	10672	40	9F
0005434551392	10672	41	10A
0005434558303	10672	42	10D
0005434551401	10672	43	10E
0005433180860	10672	44	10F
0005434551417	10672	45	11A
0005433181045	10672	46	11C
0005434551409	10672	47	11D
0005434551418	10672	48	11E
0005433180900	10672	49	11F
0005434551422	10672	50	12A
0005434551399	10672	51	12C
0005434551384	10672	52	12D
0005434551391	10672	53	12E
0005434551411	10672	54	12F
0005434558305	10672	55	13A
0005433180989	10672	56	13C
0005434551383	10672	57	13D
0005434551426	10672	58	13E
0005434551382	10672	59	13F
0005434551414	10672	60	14A
0005433180936	10672	61	14C
0005433180963	10672	62	14D
0005433180962	10672	63	14E
0005434554074	10672	64	14F
0005434551407	10672	65	15A
0005434551419	10672	66	15C
0005434551405	10672	67	15D
0005433180923	10672	68	15E
0005434551434	10672	69	15F
0005434551427	10672	70	16A
0005434551381	10672	71	16C
0005434551396	10672	72	16F
0005434551428	10672	73	17A
0005434551387	10672	74	17C
0005433180901	10672	75	17D
0005433180869	10672	76	17E
0005434551425	10672	77	17F
0005434551395	10672	78	18A
0005434558308	10672	79	18C
0005433180937	10672	80	18D
0005433180915	10672	81	18E
0005434551400	10672	82	18F
0005433180861	10672	83	19A
0005434551415	10672	84	19C
0005433181044	10672	85	19D
0005434551416	10672	86	19E
0005434558307	10672	87	19F
0005434551431	10672	88	20A
0005433180968	10672	89	20C
0005433180953	10672	90	20D
0005433180922	10672	91	20E
0005433181210	27735	1	1D
0005433181205	27735	2	3D
0005433181215	27735	3	5A
0005433181216	27735	4	6A
0005433181207	27735	5	6C
0005433181200	27735	6	7A
0005433181195	27735	7	7D
0005433181203	27735	8	8C
0005433181198	27735	9	8E
0005433181202	27735	10	10C
0005433181194	27735	11	10E
0005433181206	27735	12	12D
0005433181204	27735	13	12E
0005433181213	27735	14	12F
0005433181209	27735	15	14C
0005433181193	27735	16	14D
0005433181197	27735	17	14E
0005433181208	27735	18	14F
0005433181212	27735	19	16A
0005433181192	27735	20	17A
0005433181191	27735	21	18A
0005433181211	27735	22	18E
0005433181196	27735	23	19A
0005433181201	27735	24	19E
0005433181199	27735	25	20A
0005433181214	27735	26	20C
0005434551087	27769	1	1A
0005434550886	27769	2	1C
0005434551080	27769	3	1D
0005434558227	27769	4	1F
0005434558206	27769	5	2A
0005434554047	27769	6	2C
0005434550798	27769	7	2D
0005434551009	27769	8	3D
0005434551142	27769	9	3F
0005434550730	27769	10	4A
0005434558231	27769	11	4C
0005434551036	27769	12	4D
0005434550994	27769	13	4E
0005434550943	27769	14	4F
0005434550822	27769	15	5A
0005434550957	27769	16	5C
0005434551077	27769	17	5D
0005434551140	27769	18	5E
0005434550927	27769	19	5F
0005434550953	27769	20	6A
0005434551178	27769	21	6C
0005434550738	27769	22	6D
0005434551018	27769	23	6E
0005434551011	27769	24	6F
0005434550711	27769	25	7A
0005434550739	27769	26	7E
0005434550851	27769	27	7F
0005434550912	27769	28	8A
0005434551071	27769	29	8D
0005434550740	27769	30	8F
0005434551211	27769	31	9A
0005434550799	27769	32	9C
0005434551067	27769	33	9E
0005434550941	27769	34	9F
0005434550993	27769	35	10A
0005434551035	27769	36	10C
0005434550796	27769	37	10D
0005434551163	27769	38	10E
0005434551164	27769	39	10F
0005434551053	27769	40	11A
0005434551070	27769	41	11C
0005434550952	27769	42	11E
0005434550887	27769	43	12A
0005434551141	27769	44	12C
0005434550968	27769	45	12E
0005434551049	27769	46	12F
0005434551068	27769	47	13A
0005434550940	27769	48	13C
0005434551146	27769	49	13D
0005434551037	27769	50	13E
0005434551045	27769	51	14A
0005434558230	27769	52	14D
0005434551179	27769	53	14E
0005434551161	27769	54	14F
0005434550731	27769	55	15A
0005434550879	27769	56	15C
0005434550895	27769	57	15D
0005434550956	27769	58	15F
0005434551160	27769	59	16C
0005434551038	27769	60	16D
0005434551173	27769	61	16E
0005434550795	27769	62	17A
0005434551054	27769	63	17C
0005434551084	27769	64	17D
0005434550855	27769	65	17E
0005434550797	27769	66	18C
0005434550894	27769	67	18D
0005434550911	27769	68	18E
0005434550932	27769	69	18F
0005434551083	27769	70	19A
0005434550794	27769	71	19C
0005434558228	27769	72	19F
0005434550942	27769	73	20C
0005434551079	27769	74	20E
0005434551076	27769	75	20F
0005435254465	6139	1	1A
0005433459239	6139	2	3A
0005433459234	6139	3	3B
0005433459238	6139	4	4A
0005433459236	6139	5	5B
0005433459235	6139	6	6A
0005433459237	6139	7	6B
0005433459212	19330	1	1A
0005433459213	19330	2	2A
0005433459197	19330	3	1B
0005433459194	19330	4	2B
0005433459211	19330	5	3A
0005433459195	19330	6	3B
0005433459199	19330	7	4A
0005433459196	19330	8	4B
0005435254485	19330	9	5A
0005435254484	19330	10	5B
0005433459193	19330	11	6A
0005433459192	19330	12	6B
0005435682286	6722	1	1A
0005435217689	6722	2	1C
0005435682294	6722	3	1D
0005435682291	6722	4	2A
0005435720137	6722	5	2C
0005435720138	6722	6	2D
0005435437927	6722	7	2F
0005435682326	6722	8	3C
0005435682318	6722	9	3D
0005435220308	6722	10	3F
0005435437925	6722	11	4A
0005435682328	6722	12	4C
0005435437928	6722	13	4D
0005435682314	6722	14	4E
0005435682304	6722	15	4F
0005435682312	6722	16	5A
0005435682317	6722	17	5C
0005435682292	6722	18	5E
0005435221505	6722	19	5D
0005435682315	6722	20	5F
0005435682301	6722	21	6C
0005435437835	6722	22	6D
0005435437830	6722	23	6E
0005432136190	6722	24	6F
0005432136189	6722	25	7A
0005434828681	6722	26	7C
0005432136191	6722	27	7D
0005435221510	6722	28	7E
0005435682309	6722	29	7F
0005434828679	6722	30	8A
0005434828680	6722	31	8C
0005435661941	6722	32	8D
0005435682298	6722	33	8E
0005435437864	6722	34	8F
0005435220309	6722	35	9A
0005435437915	6722	36	9C
0005435682290	6722	37	9D
0005435682289	6722	38	9E
0005435630976	6722	39	9F
0005435682327	6722	40	10A
0005435220310	6722	41	10C
0005435682325	6722	42	10D
0005435682306	6722	43	10E
0005435437816	6722	44	10F
0005435682302	6722	45	11A
0005435682287	6722	46	11D
0005435682319	6722	47	11E
0005435682324	6722	48	11F
0005435437876	6722	49	12A
0005435682310	6722	50	12C
0005432136187	6722	51	12D
0005435682297	6722	52	12E
0005435682313	6722	53	12F
0005435630975	6722	54	13A
0005435682293	6722	55	13C
0005435682303	6722	56	13D
0005435630978	6722	57	13E
0005435437790	6722	58	14A
0005435630977	6722	59	14C
0005435661940	6722	60	14D
0005435437762	6722	61	15A
0005435437885	6722	62	15C
0005435437926	6722	63	15D
0005435682329	6722	64	15E
0005432136188	6722	65	15F
0005435682305	6722	66	16C
0005435217712	6722	67	16D
0005435682295	6722	68	16E
0005435682323	6722	69	16F
0005435682320	6722	70	17A
0005435682316	6722	71	17C
0005435720139	6722	72	17D
0005435682308	6722	73	17E
0005435682299	6722	74	17F
0005435661939	6722	75	18A
0005435437861	6722	76	18C
0005435437884	6722	77	18D
0005435437857	6722	78	18E
0005435437929	6722	79	18F
0005435682322	6722	80	19A
0005435437877	6722	81	19C
0005435682300	6722	82	19D
0005435682311	6722	83	19E
0005435217690	6722	84	19F
0005435437759	6722	85	20A
0005435682307	6722	86	20C
0005435682288	6722	87	20D
0005435682321	6722	88	20E
0005435682296	6722	89	20F
0005435681971	24586	1	1A
0005435438046	24586	2	1C
0005435681892	24586	3	1D
0005434828710	24586	4	1F
0005435681834	24586	5	2A
0005435682040	24586	6	2C
0005435681850	24586	7	2D
0005435681808	24586	8	2F
0005435438045	24586	9	3A
0005435682005	24586	10	3C
0005435438033	24586	11	3D
0005435438050	24586	12	3F
0005435681901	24586	13	4A
0005435681935	24586	14	4C
0005435681937	24586	15	4D
0005435438041	24586	16	4E
0005435438048	24586	17	4F
0005435438042	24586	18	5A
0005432305760	24586	19	5D
0005435438039	24586	20	5E
0005435681946	24586	21	5F
0005435681992	24586	22	6A
0005435681995	24586	23	6D
0005435681918	24586	24	6E
0005435720814	24586	25	6F
0005435682086	24586	26	7A
0005435438043	24586	27	7C
0005435719561	24586	28	7D
0005435661913	24586	29	7E
0005435681979	24586	30	8A
0005435681862	24586	31	7F
0005435681921	24586	32	8C
0005435682016	24586	33	8D
0005435682060	24586	34	8E
0005435682098	24586	35	8F
0005432305759	24586	36	9C
0005435438047	24586	37	9D
0005435661914	24586	38	9E
0005432305757	24586	39	9F
0005435682084	24586	40	10A
0005435681874	24586	41	10C
0005432533303	24586	42	10D
0005435438049	24586	43	10E
0005435682025	24586	44	10F
0005435681934	24586	45	11A
0005435438031	24586	46	11C
0005434828708	24586	47	11D
0005435438035	24586	48	11E
0005435681891	24586	49	11F
0005435720813	24586	50	12A
0005435438036	24586	51	12C
0005435681895	24586	52	12D
0005435438032	24586	53	12E
0005435719562	24586	54	13A
0005435682026	24586	55	13C
0005435682085	24586	56	13D
0005435681877	24586	57	13E
0005435681997	24586	58	13F
0005435438037	24586	59	14A
0005432305758	24586	60	14C
0005435682004	24586	61	14D
0005435681938	24586	62	14E
0005432533304	24586	63	14F
0005435438038	24586	64	15A
0005435438030	24586	65	15C
0005435438051	24586	66	15D
0005435681915	24586	67	15E
0005435681931	24586	68	15F
0005435438034	24586	69	16A
0005435438044	24586	70	16C
0005434828709	24586	71	16D
0005435681807	24586	72	16E
0005435681851	24586	73	16F
0005435681858	24586	74	17A
0005435681907	24586	75	17C
0005435681996	24586	76	17D
0005435681829	24586	77	17E
0005435681896	24586	78	18A
0005435682017	24586	79	18C
0005435681945	24586	80	18D
0005435681914	24586	81	18E
0005435682052	24586	82	18F
0005435438052	24586	83	19A
0005435682039	24586	84	19C
0005435682097	24586	85	19D
0005435681853	24586	86	19E
0005435681908	24586	87	19F
0005435681876	24586	88	20A
0005435438029	24586	89	20C
0005435438040	24586	90	20D
0005435682076	24586	91	20E
0005435681852	24586	92	20F
0005435126503	11501	1	1F
0005435126510	11501	2	2A
0005435126485	11501	3	2C
0005435126520	11501	4	3C
0005435126483	11501	5	3F
0005435126514	11501	6	4C
0005435126488	11501	7	4D
0005435126496	11501	8	4E
0005435126502	11501	9	5A
0005435126490	11501	10	5E
0005435105991	11501	11	6C
0005435126509	11501	12	6F
0005435126500	11501	13	7A
0005435126493	11501	14	7C
0005435126504	11501	15	7D
0005435126516	11501	16	7E
0005435126489	11501	17	7F
0005435126518	11501	18	8D
0005435126481	11501	19	8E
0005435558063	11501	20	9A
0005435126491	11501	21	9D
0005435126487	11501	22	10A
0005435126501	11501	23	10C
0005435126484	11501	24	10D
0005435126506	11501	25	11A
0005435126482	11501	26	11C
0005435126517	11501	27	11D
0005435126508	11501	28	11E
0005435558064	11501	29	12C
0005435126494	11501	30	12D
0005435126495	11501	31	13A
0005435126486	11501	32	13C
0005435126511	11501	33	13F
0005435126513	11501	34	14A
0005435126515	11501	35	14D
0005435126492	11501	36	14F
0005435105993	11501	37	15C
0005435126505	11501	38	15D
0005435126512	11501	39	15F
0005435105994	11501	40	16A
0005435126519	11501	41	18C
0005435126497	11501	42	18D
0005435105992	11501	43	18F
0005435126499	11501	44	19E
0005435126498	11501	45	20D
0005435126507	11501	46	20F
0005435126234	31908	1	1D
0005435126184	31908	2	2F
0005435126183	31908	3	3D
0005435126269	31908	4	4A
0005435126222	31908	5	4D
0005435126301	31908	6	4E
0005435558098	31908	7	5C
0005435126166	31908	8	5F
0005435126167	31908	9	6A
0005435125941	31908	10	6C
0005435126072	31908	11	6E
0005435126233	31908	12	6F
0005435126073	31908	13	7A
0005435126350	31908	14	7E
0005435126174	31908	15	8C
0005435126002	31908	16	9C
0005435126109	31908	17	10C
0005435126169	31908	18	11A
0005435126319	31908	19	11C
0005435558097	31908	20	13E
0005435126177	31908	21	14A
0005435126191	31908	22	15A
0005435126194	31908	23	15C
0005435126190	31908	24	15E
0005435126185	31908	25	16A
0005435126085	31908	26	17A
0005435126176	31908	27	17D
0005435126083	31908	28	18D
0005435105964	31908	29	18E
0005435126003	31908	30	18F
0005435126110	31908	31	19A
0005435126175	31908	32	19C
0005435126192	31908	33	20C
0005433398228	13539	1	1A
0005433398246	13539	2	1C
0005433398258	13539	3	1D
0005433398265	13539	4	1F
0005433398264	13539	5	2A
0005433398240	13539	6	2C
0005433398250	13539	7	2D
0005435732248	13539	8	3A
0005433398254	13539	9	3D
0005433398230	13539	10	3F
0005433398225	13539	11	4A
0005433398242	13539	12	4C
0005433398270	13539	13	4E
0005435732311	13539	14	4F
0005433398247	13539	15	5A
0005433398243	13539	16	5C
0005433398238	13539	17	5E
0005433398257	13539	18	5F
0005433398248	13539	19	6A
0005435732279	13539	20	6C
0005435732245	13539	21	6D
0005433398241	13539	22	6F
0005433398263	13539	23	7C
0005433398256	13539	24	7D
0005433398227	13539	25	7F
0005433398267	13539	26	8C
0005433398245	13539	27	8D
0005433398231	13539	28	8E
0005433398234	13539	29	9A
0005433398268	13539	30	9D
0005433398262	13539	31	9F
0005433398233	13539	32	10A
0005435732286	13539	33	10E
0005433398261	13539	34	11A
0005433398235	13539	35	11C
0005435732272	13539	36	11D
0005433398224	13539	37	11F
0005433398249	13539	38	12A
0005433398252	13539	39	12C
0005435732214	13539	40	12D
0005433398260	13539	41	12E
0005433398229	13539	42	12F
0005433398237	13539	43	13A
0005435732243	13539	44	13D
0005433398269	13539	45	14F
0005433398266	13539	46	15A
0005433398226	13539	47	15D
0005433398239	13539	48	15E
0005435732257	13539	49	15F
0005433398251	13539	50	16C
0005435732277	13539	51	16E
0005435732278	13539	52	17D
0005433398253	13539	53	17E
0005433398259	13539	54	17F
0005433398255	13539	55	18A
0005433398244	13539	56	18C
0005435732244	13539	57	18E
0005433398232	13539	58	18F
0005435732273	13539	59	19C
0005433398236	13539	60	19D
0005433398271	13539	61	20C
0005435732215	13539	62	20F
0005433397997	19407	1	1A
0005435732383	19407	2	1C
0005433397921	19407	3	1F
0005433397747	19407	4	2A
0005435732366	19407	5	2C
0005433397853	19407	6	2D
0005433398022	19407	7	3C
0005435732380	19407	8	3D
0005433397928	19407	9	3F
0005433397590	19407	10	4C
0005435732375	19407	11	4F
0005433397832	19407	12	5A
0005433397919	19407	13	5C
0005433397961	19407	14	5D
0005433397810	19407	15	5E
0005433397829	19407	16	5F
0005435732372	19407	17	6C
0005433397541	19407	18	6D
0005433397803	19407	19	7C
0005433397927	19407	20	7D
0005435732370	19407	21	7E
0005433397735	19407	22	7F
0005433397802	19407	23	8A
0005433397769	19407	24	8C
0005435732379	19407	25	8D
0005433397795	19407	26	8E
0005435732381	19407	27	9A
0005433397913	19407	28	9C
0005435732387	19407	29	9D
0005435732385	19407	30	9E
0005433397662	19407	31	10C
0005435732388	19407	32	10D
0005433397914	19407	33	10F
0005435732384	19407	34	11C
0005435732371	19407	35	11D
0005433398004	19407	36	11F
0005435732378	19407	37	12A
0005433397748	19407	38	12C
0005435732389	19407	39	12E
0005435732374	19407	40	12F
0005435732368	19407	41	13A
0005435732376	19407	42	13D
0005433397922	19407	43	14A
0005435732386	19407	44	14C
0005433397824	19407	45	14D
0005435732382	19407	46	14E
0005435732377	19407	47	14F
0005433397833	19407	48	15C
0005435732369	19407	49	15D
0005433397925	19407	50	15E
0005435732367	19407	51	15F
0005433397898	19407	52	16A
0005433397904	19407	53	16E
0005433397825	19407	54	17A
0005433397737	19407	55	17D
0005433397834	19407	56	17E
0005433397805	19407	57	18A
0005433397797	19407	58	18D
0005433397915	19407	59	18E
0005433397553	19407	60	18F
0005433397897	19407	61	19A
0005433397955	19407	62	19C
0005435732373	19407	63	19D
0005433397796	19407	64	19F
0005433397652	19407	65	20A
0005433397983	19407	66	20C
0005433397926	19407	67	20D
0005433397982	19407	68	20E
0005433398031	19407	69	20F
0005435925345	13155	1	1C
0005435925341	13155	2	1F
0005435068658	13155	3	2A
0005435068651	13155	4	2C
0005435068832	13155	5	2D
0005435068678	13155	6	3C
0005435068718	13155	7	4A
0005435068842	13155	8	4C
0005435925355	13155	9	4E
0005435068679	13155	10	5A
0005435068830	13155	11	5C
0005435925356	13155	12	5D
0005435925348	13155	13	5F
0005435068772	13155	14	6A
0005435068690	13155	15	6C
0005435068741	13155	16	6E
0005435925352	13155	17	6F
0005435068771	13155	18	7C
0005435068827	13155	19	7D
0005435925349	13155	20	7E
0005435925353	13155	21	7F
0005435068705	13155	22	8A
0005435068710	13155	23	8D
0005435068926	13155	24	9A
0005435068742	13155	25	9C
0005435925346	13155	26	9D
0005435068941	13155	27	9F
0005435068918	13155	28	10C
0005435925343	13155	29	10E
0005435068974	13155	30	11A
0005435068659	13155	31	11C
0005435068989	13155	32	11D
0005435068917	13155	33	12A
0005435068689	13155	34	12C
0005435068970	13155	35	12E
0005435068726	13155	36	13A
0005435925344	13155	37	13C
0005435068870	13155	38	14A
0005435068656	13155	39	14C
0005435068646	13155	40	14D
0005435068764	13155	41	15E
0005435068773	13155	42	16A
0005435068925	13155	43	16D
0005435068817	13155	44	16E
0005435068833	13155	45	16F
0005435068891	13155	46	17A
0005435068831	13155	47	17D
0005435925354	13155	48	18A
0005435068893	13155	49	18C
0005435069087	13155	50	18E
0005435925347	13155	51	18F
0005435068677	13155	52	19C
0005435925342	13155	53	19F
0005435925351	13155	54	20A
0005435068794	13155	55	20D
0005435925350	13155	56	20F
0005435069259	15489	1	1A
0005435069251	15489	2	1C
0005435069225	15489	3	1D
0005435069231	15489	4	2A
0005435069269	15489	5	2C
0005435069266	15489	6	2D
0005435069224	15489	7	3D
0005435069271	15489	8	3F
0005435069252	15489	9	4A
0005435069228	15489	10	4C
0005435069241	15489	11	4E
0005435069265	15489	12	4F
0005435069238	15489	13	5C
0005435069229	15489	14	5D
0005435925253	15489	15	5F
0005435069235	15489	16	6D
0005435925180	15489	17	6F
0005435069223	15489	18	7A
0005435069220	15489	19	7C
0005435069242	15489	20	7E
0005435925105	15489	21	8C
0005435069237	15489	22	8D
0005435069244	15489	23	9A
0005435069253	15489	24	9C
0005435069268	15489	25	9E
0005435069254	15489	26	9F
0005435069239	15489	27	10F
0005435069247	15489	28	11A
0005435069240	15489	29	11C
0005435069243	15489	30	11D
0005435925241	15489	31	11E
0005435069248	15489	32	11F
0005435069256	15489	33	12C
0005435069245	15489	34	12D
0005435069263	15489	35	12F
0005435069233	15489	36	13A
0005435925214	15489	37	13C
0005435069255	15489	38	13D
0005435069260	15489	39	13E
0005435925220	15489	40	13F
0005435069249	15489	41	14C
0005435069234	15489	42	14D
0005435069262	15489	43	14F
0005435069230	15489	44	15A
0005435925240	15489	45	15D
0005435069264	15489	46	15F
0005435069219	15489	47	16A
0005435069221	15489	48	16C
0005435069267	15489	49	16E
0005435069222	15489	50	16F
0005435069232	15489	51	17A
0005435925237	15489	52	17C
0005435069218	15489	53	17D
0005435925260	15489	54	17E
0005435069246	15489	55	18A
0005435069227	15489	56	18C
0005435925203	15489	57	18D
0005435925238	15489	58	18E
0005435069257	15489	59	18F
0005435069270	15489	60	19A
0005435925219	15489	61	19C
0005435069236	15489	62	19E
0005435925225	15489	63	19F
0005435069258	15489	64	20A
0005435069226	15489	65	20D
0005435069250	15489	66	20E
0005435069261	15489	67	20F
0005435808149	29491	1	1A
0005435808202	29491	2	1B
0005433407580	29491	3	1C
0005433407581	29491	4	1D
0005433407577	29491	5	2A
0005433407576	29491	6	2B
0005435808172	29491	7	2D
0005433407589	29491	8	3A
0005435808128	29491	9	3B
0005435808177	29491	10	3C
0005435808158	29491	11	3D
0005433407586	29491	12	4B
0005433407582	29491	13	4C
0005435808171	29491	14	4D
0005433407585	29491	15	5A
0005435808207	29491	16	5B
0005435808203	29491	17	5C
0005433407590	29491	18	6A
0005435808089	29491	19	6C
0005435808164	29491	20	6D
0005433407583	29491	21	7A
0005433407587	29491	22	7D
0005435808157	29491	23	18A
0005435808174	29491	24	18B
0005435808160	29491	25	18C
0005435808156	29491	26	18D
0005433407578	29491	27	19B
0005433407584	29491	28	19D
0005435808170	29491	29	20A
0005435808205	29491	30	20B
0005433407591	29491	31	20C
0005433407588	29491	32	20D
0005435808090	29491	33	21A
0005435808206	29491	34	21C
0005435808152	29491	35	21D
0005433407575	29491	36	22A
0005435808142	29491	37	22B
0005433407579	29491	38	22C
0005435808143	29491	39	22D
0005435808150	29491	40	23A
0005435808151	29491	41	23B
0005434756084	10720	1	1A
0005434756252	10720	2	1C
0005434756290	10720	3	1D
0005434756145	10720	4	1F
0005434214698	10720	5	2A
0005434214724	10720	6	2C
0005434214734	10720	7	2D
0005434214739	10720	8	2F
0005434214700	10720	9	3A
0005434756336	10720	10	3C
0005434214708	10720	11	3D
0005434214737	10720	12	3F
0005434214742	10720	13	4A
0005434214736	10720	14	4C
0005434756069	10720	15	4E
0005434214705	10720	16	4F
0005434214735	10720	17	5A
0005434214729	10720	18	5C
0005434214704	10720	19	5D
0005434756322	10720	20	5E
0005434214717	10720	21	5F
0005434214718	10720	22	6A
0005434214702	10720	23	6C
0005434756151	10720	24	6D
0005434756167	10720	25	6E
0005434756152	10720	26	7A
0005434214731	10720	27	7C
0005434214740	10720	28	7F
0005434214715	10720	29	8A
0005434214743	10720	30	8C
0005434756251	10720	31	8F
0005434214714	10720	32	9A
0005434756245	10720	33	9C
0005434756272	10720	34	9E
0005434214722	10720	35	9F
0005434756253	10720	36	10A
0005434214741	10720	37	10E
0005434756250	10720	38	10D
0005434756143	10720	39	10F
0005434756258	10720	40	11A
0005434214699	10720	41	11C
0005434214725	10720	42	11D
0005434214738	10720	43	11E
0005434214712	10720	44	11F
0005434756273	10720	45	12A
0005434214719	10720	46	12D
0005434214711	10720	47	12E
0005434214710	10720	48	12F
0005434214697	10720	49	13C
0005434756144	10720	50	13D
0005434756285	10720	51	13E
0005434214744	10720	52	13F
0005434214716	10720	53	14A
0005434756088	10720	54	14C
0005434756202	10720	55	14D
0005434214720	10720	56	14E
0005434214728	10720	57	15A
0005434756284	10720	58	15C
0005434756100	10720	59	15D
0005434756217	10720	60	15F
0005434756082	10720	61	16C
0005434214709	10720	62	16F
0005434756270	10720	63	17A
0005434214723	10720	64	17C
0005434214732	10720	65	17D
0005434214713	10720	66	17E
0005434214707	10720	67	18A
0005434756169	10720	68	18E
0005434214703	10720	69	18F
0005434214701	10720	70	19A
0005434756292	10720	71	19C
0005434214733	10720	72	19D
0005434214730	10720	73	19E
0005434214706	10720	74	19F
0005434214721	10720	75	20A
0005434214726	10720	76	20C
0005434214727	10720	77	20D
0005434756142	10720	78	20E
0005434756083	10720	79	20F
0005434214143	28669	1	1A
0005434214211	28669	2	1D
0005434756557	28669	3	1F
0005434214255	28669	4	2A
0005434214217	28669	5	2C
0005434214127	28669	6	2D
0005434756519	28669	7	3A
0005434756528	28669	8	3D
0005434214138	28669	9	4A
0005434214141	28669	10	4C
0005434756539	28669	11	4D
0005434756542	28669	12	4F
0005434756560	28669	13	5A
0005434756540	28669	14	5C
0005434756537	28669	15	5D
0005434756564	28669	16	5E
0005434756538	28669	17	6A
0005434756561	28669	18	6C
0005434214249	28669	19	6D
0005434756527	28669	20	6E
0005434214112	28669	21	6F
0005434756549	28669	22	7A
0005434756541	28669	23	7C
0005434214174	28669	24	7D
0005434756529	28669	25	7E
0005434214212	28669	26	7F
0005434214107	28669	27	8A
0005434214165	28669	28	8C
0005434756551	28669	29	8D
0005434756520	28669	30	8F
0005434756531	28669	31	9A
0005434214286	28669	32	9C
0005434756556	28669	33	9D
0005434214129	28669	34	9E
0005434756525	28669	35	9F
0005434756544	28669	36	10A
0005434214325	28669	37	10C
0005434214201	28669	38	10D
0005434756559	28669	39	10E
0005434756523	28669	40	10F
0005434756536	28669	41	11A
0005434756558	28669	42	11D
0005434756534	28669	43	11C
0005434756533	28669	44	11E
0005434214183	28669	45	11F
0005434214176	28669	46	12A
0005434756546	28669	47	12C
0005434214111	28669	48	12D
0005434756535	28669	49	12E
0005434756517	28669	50	12F
0005434756563	28669	51	13A
0005434214128	28669	52	13C
0005434756516	28669	53	13D
0005434214216	28669	54	13E
0005434756552	28669	55	13F
0005434756522	28669	56	14A
0005434756515	28669	57	14C
0005434756553	28669	58	14D
0005434756521	28669	59	14E
0005434214329	28669	60	14F
0005434756566	28669	61	15A
0005434214300	28669	62	15C
0005434756550	28669	63	15D
0005434214230	28669	64	15E
0005434214246	28669	65	16A
0005434756565	28669	66	16C
0005434214330	28669	67	16D
0005434214285	28669	68	16F
0005434756532	28669	69	17A
0005434756545	28669	70	17C
0005434214177	28669	71	17D
0005434756526	28669	72	17E
0005434214061	28669	73	17F
0005434756518	28669	74	18A
0005434756562	28669	75	18C
0005434756548	28669	76	18D
0005434214164	28669	77	18F
0005434756530	28669	78	19A
0005434214278	28669	79	19C
0005434756547	28669	80	19D
0005434214360	28669	81	19E
0005434756524	28669	82	19F
0005434756555	28669	83	20C
0005434756554	28669	84	20D
0005434756543	28669	85	20E
0005434214140	28669	86	20F
0005435007129	5477	1	1A
0005435040059	5477	2	1C
0005435040053	5477	3	1D
0005435042861	5477	4	1F
0005432125483	5477	5	2C
0005432125481	5477	6	2A
0005434229215	5477	7	2D
0005435040019	5477	8	2F
0005435007123	5477	9	3C
0005432125478	5477	10	3A
0005434229280	5477	11	3D
0005435040047	5477	12	3F
0005435040060	5477	13	4A
0005435040018	5477	14	4B
0005435040032	5477	15	4D
0005432125477	5477	16	4C
0005435040041	5477	17	4E
0005435040048	5477	18	4F
0005435040038	5477	19	5B
0005434229305	5477	20	5A
0005434229204	5477	21	5C
0005435040020	5477	22	5D
0005435007111	5477	23	5F
0005435040062	5477	24	5E
0005435039998	5477	25	6A
0005435040054	5477	26	6B
0005435040050	5477	27	6C
0005435040025	5477	28	6E
0005435040051	5477	29	6D
0005435007136	5477	30	6F
0005432125482	5477	31	7A
0005435040058	5477	32	7C
0005435007113	5477	33	7B
0005434229254	5477	34	7D
0005435040061	5477	35	7E
0005435007130	5477	36	8A
0005434229323	5477	37	7F
0005435040012	5477	38	8B
0005435040015	5477	39	8C
0005435007131	5477	40	8E
0005435040039	5477	41	8D
0005435040049	5477	42	9A
0005435040064	5477	43	8F
0005435007120	5477	44	9D
0005435040005	5477	45	9C
0005434229322	5477	46	9E
0005435040028	5477	47	9F
0005435007133	5477	48	10C
0005435039997	5477	49	10B
0005435040008	5477	50	10D
0005435007115	5477	51	10E
0005435007132	5477	52	11A
0005435043287	5477	53	11B
0005435040011	5477	54	11C
0005435040036	5477	55	11E
0005435040001	5477	56	11D
0005435007128	5477	57	11F
0005435040034	5477	58	12A
0005435007126	5477	59	12C
0005434229286	5477	60	12B
0005435007114	5477	61	12D
0005435040024	5477	62	12E
0005435007110	5477	63	12F
0005435007121	5477	64	13A
0005435040021	5477	65	13B
0005435040014	5477	66	13D
0005435040016	5477	67	13C
0005435040057	5477	68	13E
0005435039999	5477	69	14A
0005434229034	5477	70	13F
0005435040040	5477	71	14B
0005435040044	5477	72	14D
0005435042862	5477	73	14C
0005432125484	5477	74	14E
0005435040042	5477	75	15A
0005435040055	5477	76	14F
0005435040022	5477	77	15C
0005435007135	5477	78	15B
0005434229301	5477	79	15D
0005434229304	5477	80	15E
0005435040030	5477	81	15F
0005435007119	5477	82	16B
0005435007117	5477	83	16A
0005435040046	5477	84	16C
0005435042864	5477	85	16D
0005435040031	5477	86	16E
0005434229206	5477	87	17A
0005435040052	5477	88	16F
0005435040027	5477	89	17B
0005435040013	5477	90	17C
0005435040023	5477	91	17E
0005435040063	5477	92	17D
0005435007112	5477	93	17F
0005435007127	5477	94	18A
0005435040045	5477	95	18B
0005435040035	5477	96	18C
0005435040004	5477	97	18D
0005435040026	5477	98	18F
0005434229207	5477	99	18E
0005435007125	5477	100	19A
0005435007134	5477	101	19B
0005435040010	5477	102	19C
0005435007118	5477	103	19E
0005434229279	5477	104	20A
0005434229253	5477	105	19F
0005434229255	5477	106	20C
0005435040009	5477	107	20B
0005432125480	5477	108	20D
0005435040017	5477	109	20E
0005435007124	5477	110	20F
0005432125479	5477	111	21A
0005435040033	5477	112	21C
0005435042863	5477	113	21B
0005435040000	5477	114	21D
0005435040037	5477	115	21E
0005435040006	5477	116	22A
0005435040007	5477	117	21F
0005435040056	5477	118	22B
0005435040003	5477	119	22C
0005435043286	5477	120	22D
0005435007116	5477	121	22E
0005435040002	5477	122	23A
0005435040043	5477	123	22F
0005435007122	5477	124	23B
0005434229298	5477	125	23C
0005434229256	5477	126	23E
0005434229257	5477	127	23D
0005435040029	5477	128	23F
0005435006968	12970	1	1A
0005435039337	12970	2	1C
0005435006967	12970	3	1F
0005435042847	12970	4	1D
0005435039431	12970	5	2C
0005435006943	12970	6	2A
0005435039134	12970	7	2D
0005435039415	12970	8	2F
0005432304415	12970	9	3C
0005435039356	12970	10	3A
0005434229459	12970	11	3F
0005435039398	12970	12	4B
0005435039479	12970	13	4A
0005435039543	12970	14	4C
0005435039355	12970	15	4D
0005435039666	12970	16	4F
0005435006910	12970	17	5B
0005435039524	12970	18	5A
0005434229457	12970	19	5C
0005435039126	12970	20	5D
0005435039392	12970	21	5E
0005435039418	12970	22	6A
0005432304414	12970	23	5F
0005435006929	12970	24	6B
0005435043283	12970	25	6D
0005435039342	12970	26	6C
0005435006865	12970	27	6F
0005435039665	12970	28	6E
0005435006959	12970	29	7A
0005434229463	12970	30	7B
0005434229470	12970	31	7C
0005435006924	12970	32	7F
0005435006923	12970	33	7E
0005434229469	12970	34	8A
0005435039440	12970	35	8B
0005435377905	12970	36	8C
0005434229474	12970	37	8E
0005435039538	12970	38	8D
0005434229464	12970	39	8F
0005435039528	12970	40	9A
0005435039338	12970	41	9C
0005434229460	12970	42	9B
0005435039792	12970	43	9E
0005434229467	12970	44	9D
0005435006966	12970	45	9F
0005435039177	12970	46	10B
0005434229451	12970	47	10C
0005435039432	12970	48	10D
0005435039454	12970	49	11A
0005434229458	12970	50	10E
0005434229461	12970	51	11B
0005435039247	12970	52	11C
0005435006898	12970	53	11E
0005435039534	12970	54	11D
0005435039302	12970	55	12A
0005435039549	12970	56	12B
0005435006874	12970	57	12D
0005435006876	12970	58	12C
0005435042837	12970	59	12E
0005434229452	12970	60	12F
0005434229465	12970	61	13B
0005435039523	12970	62	13D
0005435006965	12970	63	13C
0005435039577	12970	64	13E
0005434229462	12970	65	13F
0005435039417	12970	66	14B
0005435006909	12970	67	14C
0005434229456	12970	68	14D
0005435006911	12970	69	14E
0005435006877	12970	70	14F
0005435039526	12970	71	15A
0005435039378	12970	72	15D
0005435039509	12970	73	15E
0005432304413	12970	74	16A
0005435006941	12970	75	15F
0005435039393	12970	76	16C
0005434229455	12970	77	16D
0005435039401	12970	78	16F
0005435039481	12970	79	16E
0005435006847	12970	80	17A
0005435039419	12970	81	17D
0005435039505	12970	82	18B
0005435043285	12970	83	18C
0005435039547	12970	84	18E
0005432304412	12970	85	18D
0005435039254	12970	86	19A
0005435039662	12970	87	18F
0005435039125	12970	88	19B
0005435039570	12970	89	19D
0005435039480	12970	90	19C
0005435006878	12970	91	19E
0005434229468	12970	92	20A
0005435007040	12970	93	20C
0005435006908	12970	94	20B
0005434229454	12970	95	20D
0005435039569	12970	96	20E
0005434229473	12970	97	21A
0005434229472	12970	98	20F
0005435006942	12970	99	21B
0005434229471	12970	100	21C
0005435039546	12970	101	21F
0005435039599	12970	102	21E
0005434229466	12970	103	22A
0005434229453	12970	104	22C
0005435039400	12970	105	22B
0005435007041	12970	106	22D
0005435039585	12970	107	22E
0005435039649	12970	108	23B
0005435039107	12970	109	23D
0005435006758	12970	110	23E
0005435039493	12970	111	23F
0005434426713	14884	1	1A
0005434426695	14884	2	1D
0005435902600	14884	3	2A
0005435902655	14884	4	2C
0005435902642	14884	5	2D
0005435902651	14884	6	2F
0005435902622	14884	7	3A
0005432188617	14884	8	3C
0005432188618	14884	9	3F
0005434426707	14884	10	4A
0005434426716	14884	11	4C
0005435902677	14884	12	4D
0005434426710	14884	13	4E
0005435902648	14884	14	5C
0005435902584	14884	15	5D
0005434426698	14884	16	5E
0005434426694	14884	17	5F
0005435902532	14884	18	6A
0005432188616	14884	19	7A
0005434411790	14884	20	7C
0005435902531	14884	21	7D
0005434426693	14884	22	7E
0005435902623	14884	23	7F
0005434426699	14884	24	8C
0005435902649	14884	25	8D
0005434426718	14884	26	8E
0005434426687	14884	27	8F
0005434426691	14884	28	9A
0005435554144	14884	29	9C
0005435554156	14884	30	9F
0005434426700	14884	31	10A
0005434426692	14884	32	10C
0005434426708	14884	33	10D
0005435902695	14884	34	10E
0005434411791	14884	35	11A
0005434426715	14884	36	11D
0005434426714	14884	37	11E
0005434426703	14884	38	11F
0005432188619	14884	39	12A
0005434426689	14884	40	12C
0005434426696	14884	41	12D
0005435902629	14884	42	12E
0005435554153	14884	43	13A
0005435902633	14884	44	13C
0005435902641	14884	45	13D
0005434426701	14884	46	13F
0005432188620	14884	47	14E
0005435902634	14884	48	14F
0005435902632	14884	49	15A
0005435902540	14884	50	15C
0005434426709	14884	51	15D
0005434426688	14884	52	15E
0005434426706	14884	53	16A
0005435554160	14884	54	16C
0005434426704	14884	55	16E
0005434426697	14884	56	16F
0005435902596	14884	57	17A
0005434426702	14884	58	17D
0005435902656	14884	59	17E
0005435902638	14884	60	18C
0005434411792	14884	61	18F
0005434426690	14884	62	19A
0005434426711	14884	63	19C
0005434426712	14884	64	19D
0005434426717	14884	65	19E
0005434411793	14884	66	19F
0005434426705	14884	67	20C
0005435902597	14884	68	20E
0005432059514	20207	1	1A
0005435902774	20207	2	1C
0005434426530	20207	3	1D
0005434411741	20207	4	1F
0005434426468	20207	5	2A
0005434426589	20207	6	2C
0005435902770	20207	7	2D
0005434411758	20207	8	2F
0005435902771	20207	9	4A
0005435554209	20207	10	4D
0005434426417	20207	11	5A
0005434426625	20207	12	5C
0005435902783	20207	13	5D
0005434426416	20207	14	5E
0005434426529	20207	15	5F
0005434426375	20207	16	6D
0005435902775	20207	17	6C
0005434426582	20207	18	6F
0005435902768	20207	19	7A
0005435902780	20207	20	7C
0005435902781	20207	21	7D
0005434411751	20207	22	8A
0005432059512	20207	23	8C
0005435902782	20207	24	8D
0005434426558	20207	25	8E
0005434426376	20207	26	8F
0005434426626	20207	27	9A
0005435902777	20207	28	9C
0005434426485	20207	29	9D
0005434426559	20207	30	9E
0005434426374	20207	31	9F
0005434426590	20207	32	10A
0005435554211	20207	33	10F
0005434426437	20207	34	11A
0005435902767	20207	35	11C
0005435554210	20207	36	11D
0005434426507	20207	37	11E
0005434411753	20207	38	11F
0005434426366	20207	39	12A
0005435902769	20207	40	12C
0005435554208	20207	41	12D
0005435902776	20207	42	12F
0005434426389	20207	43	13A
0005435902773	20207	44	13C
0005434426557	20207	45	13E
0005434426444	20207	46	14E
0005434426547	20207	47	14D
0005434426388	20207	48	15D
0005435902779	20207	49	15F
0005435902772	20207	50	16A
0005434426506	20207	51	16E
0005434426581	20207	52	16F
0005435554207	20207	53	17C
0005434411759	20207	54	17D
0005434426486	20207	55	17E
0005434426425	20207	56	17F
0005434426462	20207	57	18A
0005434426556	20207	58	18C
0005435902784	20207	59	18D
0005435902778	20207	60	18E
0005432059513	20207	61	19C
0005434426373	20207	62	19F
0005434411752	20207	63	20C
0005434426412	20207	64	20D
0005432300281	26507	1	1A
0005435982474	26507	2	1C
0005433434583	26507	3	1D
0005433434503	26507	4	1F
0005435982452	26507	5	2A
0005434270193	26507	6	2D
0005435982476	26507	7	2F
0005435982451	26507	8	3A
0005432300283	26507	9	3C
0005435982450	26507	10	3F
0005435982470	26507	11	4A
0005433434546	26507	12	4C
0005435982483	26507	13	4D
0005435982446	26507	14	4E
0005433434516	26507	15	4F
0005435982455	26507	16	5A
0005435982462	26507	17	5C
0005433434610	26507	18	5D
0005435982466	26507	19	5E
0005433434493	26507	20	5F
0005433434639	26507	21	6D
0005435982456	26507	22	6F
0005435982453	26507	23	6E
0005433434494	26507	24	7A
0005435982475	26507	25	7C
0005434273067	26507	26	7D
0005435982465	26507	27	7E
0005433434517	26507	28	7F
0005433434609	26507	29	8A
0005435982447	26507	30	8C
0005435982471	26507	31	8D
0005435982479	26507	32	8E
0005433434586	26507	33	8F
0005433434570	26507	34	9A
0005432300284	26507	35	9C
0005435982459	26507	36	9D
0005433434502	26507	37	9E
0005432300282	26507	38	9F
0005435982443	26507	39	10A
0005435982472	26507	40	10C
0005433434507	26507	41	10E
0005433434522	26507	42	10F
0005435982454	26507	43	11A
0005433434430	26507	44	11C
0005433434521	26507	45	11D
0005433434454	26507	46	11E
0005435982478	26507	47	11F
0005435982463	26507	48	12C
0005434270191	26507	49	12D
0005433434534	26507	50	12E
0005435982484	26507	51	12F
0005435982460	26507	52	13C
0005433434431	26507	53	13D
0005435982464	26507	54	13E
0005435982469	26507	55	14A
0005433434545	26507	56	14C
0005433434535	26507	57	14D
0005435982482	26507	58	14E
0005434273068	26507	59	14F
0005433434571	26507	60	15A
0005435982449	26507	61	15C
0005435982445	26507	62	15D
0005435982480	26507	63	15F
0005433434631	26507	64	16A
0005433434569	26507	65	16C
0005433434611	26507	66	16D
0005435982467	26507	67	16E
0005435982461	26507	68	16F
0005435982448	26507	69	17A
0005435982444	26507	70	17C
0005435982477	26507	71	17E
0005433434544	26507	72	17F
0005435982481	26507	73	18A
0005435982458	26507	74	18C
0005432300280	26507	75	18D
0005434270200	26507	76	18E
0005433434453	26507	77	19A
0005433434448	26507	78	19C
0005432300279	26507	79	19D
0005435982457	26507	80	19E
0005435982468	26507	81	20A
0005433434508	26507	82	20D
0005433434414	26507	83	20E
0005435982473	26507	84	20F
0005435982264	26727	1	1A
0005435982022	26727	2	1C
0005435981865	26727	3	1D
0005435981989	26727	4	1F
0005435982265	26727	5	2A
0005435982373	26727	6	2C
0005433434801	26727	7	2F
0005435982072	26727	8	3A
0005433434785	26727	9	3C
0005433434808	26727	10	3D
0005433434806	26727	11	3F
0005435981964	26727	12	4A
0005435982082	26727	13	4D
0005435982306	26727	14	4E
0005435982079	26727	15	4F
0005434270215	26727	16	5C
0005432051142	26727	17	5D
0005433434788	26727	18	5E
0005433434797	26727	19	5F
0005432051140	26727	20	6A
0005433434800	26727	21	6C
0005435981950	26727	22	6D
0005435981978	26727	23	6E
0005435982305	26727	24	6F
0005433434789	26727	25	7A
0005435982301	26727	26	7C
0005435982068	26727	27	7D
0005435981772	26727	28	7E
0005435981915	26727	29	7F
0005435982097	26727	30	8A
0005435982300	26727	31	8C
0005433434811	26727	32	8E
0005433434802	26727	33	8F
0005435981935	26727	34	9A
0005434271320	26727	35	9C
0005435982024	26727	36	9D
0005433434784	26727	37	9E
0005433434798	26727	38	9F
0005435982128	26727	39	10C
0005433434805	26727	40	10D
0005433434792	26727	41	10E
0005435981982	26727	42	10F
0005435981863	26727	43	11A
0005435982177	26727	44	11C
0005435982176	26727	45	11D
0005435982112	26727	46	11E
0005435982031	26727	47	11F
0005433434790	26727	48	12A
0005434270216	26727	49	12D
0005435981864	26727	50	12E
0005434271321	26727	51	13A
0005435982025	26727	52	12F
0005435982021	26727	53	13C
0005433434793	26727	54	13D
0005433434803	26727	55	13E
0005433434812	26727	56	14A
0005434269111	26727	57	14D
0005433434786	26727	58	14E
0005435982083	26727	59	14F
0005433434809	26727	60	15C
0005435982013	26727	61	15E
0005433434787	26727	62	15F
0005435981977	26727	63	16A
0005433434791	26727	64	16C
0005433434807	26727	65	16D
0005433434794	26727	66	16E
0005435981862	26727	67	17A
0005432051141	26727	68	17C
0005433434795	26727	69	17D
0005435982111	26727	70	17E
0005435982017	26727	71	17F
0005433434804	26727	72	18A
0005433434810	26727	73	18C
0005434269113	26727	74	18D
0005435982085	26727	75	18E
0005434269112	26727	76	18F
0005433434796	26727	77	19C
0005435982069	26727	78	19D
0005435982033	26727	79	19E
0005435982048	26727	80	19F
0005433434799	26727	81	20A
0005435982140	26727	82	20C
0005435982032	26727	83	20D
0005435982045	26727	84	20E
0005433686634	19520	1	1A
0005433686633	19520	2	1B
0005433687710	19520	3	1C
0005433686636	19520	4	2A
0005433687713	19520	5	2C
0005433687709	19520	6	2B
0005433686639	19520	7	2D
0005433685531	19520	8	3A
0005433686640	19520	9	3B
0005433685521	19520	10	3C
0005433686646	19520	11	3D
0005433687705	19520	12	4A
0005433685527	19520	13	4B
0005433687718	19520	14	4C
0005433685526	19520	15	4D
0005433687708	19520	16	5B
0005433687715	19520	17	5C
0005433685529	19520	18	5D
0005433687716	19520	19	6A
0005433686635	19520	20	6B
0005433687717	19520	21	6C
0005433686644	19520	22	6D
0005433685523	19520	23	7A
0005433687706	19520	24	7B
0005433686643	19520	25	7C
0005433687712	19520	26	7D
0005433686638	19520	27	18A
0005433685522	19520	28	18B
0005433687711	19520	29	18C
0005433687714	19520	30	18D
0005433686631	19520	31	19A
0005433686632	19520	32	19B
0005433686641	19520	33	19C
0005433687704	19520	34	19D
0005433685524	19520	35	20A
0005433686645	19520	36	20C
0005433686637	19520	37	20D
0005433685533	19520	38	21A
0005433685525	19520	39	21B
0005433685534	19520	40	21C
0005433685532	19520	41	21D
0005433685535	19520	42	22A
0005433685528	19520	43	22B
0005433685530	19520	44	22C
0005433686642	19520	45	23A
0005433687707	19520	46	23B
0005432857998	3143	1	1A
0005432584129	3143	2	1B
0005432584144	3143	3	1C
0005432584130	3143	4	1D
0005432858031	3143	5	2A
0005432858037	3143	6	2B
0005432584149	3143	7	2C
0005432858002	3143	8	2D
0005432584150	3143	9	3A
0005432584127	3143	10	3B
0005432584148	3143	11	3C
0005432584135	3143	12	3D
0005432584136	3143	13	4A
0005432584146	3143	14	4B
0005432858000	3143	15	4C
0005432584147	3143	16	4D
0005432584133	3143	17	5A
0005432584125	3143	18	5B
0005432858034	3143	19	5D
0005432584145	3143	20	6A
0005432584132	3143	21	6B
0005432584140	3143	22	6C
0005432584134	3143	23	7A
0005432584141	3143	24	7B
0005432584128	3143	25	7C
0005432216282	3143	26	7D
0005432858019	3143	27	18A
0005432584137	3143	28	18B
0005432857983	3143	29	18C
0005432858030	3143	30	18D
0005432858001	3143	31	19A
0005432584142	3143	32	19B
0005432216284	3143	33	19C
0005432857971	3143	34	19D
0005432857970	3143	35	20A
0005432584131	3143	36	20B
0005432858025	3143	37	20C
0005432584143	3143	38	20D
0005432858032	3143	39	21A
0005432216283	3143	40	21B
0005432858046	3143	41	21C
0005432858036	3143	42	21D
0005432584124	3143	43	22A
0005432858017	3143	44	22C
0005432584138	3143	45	22D
0005432584126	3143	46	23A
0005432584139	3143	47	23B
0005432584031	31477	1	1A
0005432583983	31477	2	1B
0005432584010	31477	3	1D
0005432583963	31477	4	2A
0005432858110	31477	5	2B
0005432583951	31477	6	2C
0005432858113	31477	7	2D
0005432583934	31477	8	3B
0005432584008	31477	9	4A
0005432583892	31477	10	3D
0005432584091	31477	11	4B
0005432583982	31477	12	4C
0005432858118	31477	13	5A
0005432583891	31477	14	5B
0005432858115	31477	15	5C
0005432583929	31477	16	5D
0005432583938	31477	17	6A
0005432858111	31477	18	6B
0005432583981	31477	19	6D
0005432583988	31477	20	7B
0005432858112	31477	21	7C
0005432583920	31477	22	7D
0005432583921	31477	23	18A
0005432583984	31477	24	18B
0005432583933	31477	25	18C
0005432858121	31477	26	18D
0005432583884	31477	27	19B
0005432583903	31477	28	19C
0005432583899	31477	29	19D
0005432584024	31477	30	20A
0005432583944	31477	31	20B
0005432583974	31477	32	20C
0005432858114	31477	33	20D
0005432584009	31477	34	21A
0005432858122	31477	35	21B
0005432584092	31477	36	21C
0005432858120	31477	37	22A
0005432858117	31477	38	22B
0005432858116	31477	39	22D
0005432858119	31477	40	23B
0005434943390	904	1	1A
0005434943387	904	2	1C
0005434943389	904	3	2C
0005433255075	904	4	6C
0005434943386	904	5	7B
0005433255110	904	6	18B
0005434943385	904	7	18D
0005434943388	904	8	21B
0005434943391	904	9	22A
0005434943392	904	10	22B
0005434943384	904	11	23A
0005434943352	16219	1	1A
0005433255145	16219	2	2C
0005434943306	16219	3	2D
0005434943348	16219	4	3C
0005434943329	16219	5	4A
0005434943341	16219	6	4B
0005434943305	16219	7	4D
0005434943327	16219	8	5B
0005434943308	16219	9	5C
0005434943326	16219	10	5D
0005433255144	16219	11	6B
0005434943325	16219	12	6C
0005433255143	16219	13	7B
0005433255142	16219	14	7C
0005434943328	16219	15	7D
0005434943337	16219	16	18A
0005434943297	16219	17	18C
0005434943351	16219	18	18D
0005433255140	16219	19	19C
0005433255141	16219	20	20B
0005433255138	16219	21	20D
0005434943307	16219	22	21D
0005433255139	16219	23	22B
0005434943330	16219	24	22C
0005433654801	4319	1	1C
0005433654799	4319	2	1D
0005433654811	4319	3	2F
0005435858548	4319	4	2D
0005435858516	4319	5	3C
0005433654803	4319	6	4C
0005433654792	4319	7	5D
0005435858539	4319	8	6D
0005435858538	4319	9	6C
0005435858525	4319	10	6F
0005433654806	4319	11	7B
0005433654791	4319	12	7D
0005435858544	4319	13	8F
0005433654809	4319	14	9A
0005435858529	4319	15	9D
0005435858549	4319	16	9F
0005433654790	4319	17	12A
0005433654804	4319	18	12F
0005433654795	4319	19	13C
0005433654805	4319	20	13E
0005433654813	4319	21	13D
0005433654796	4319	22	14B
0005433654807	4319	23	14E
0005435858528	4319	24	14D
0005433654798	4319	25	16A
0005435858531	4319	26	17B
0005433654808	4319	27	17A
0005433654797	4319	28	17D
0005433654793	4319	29	17C
0005433654800	4319	30	17E
0005433654810	4319	31	18D
0005433654794	4319	32	18E
0005435858497	4319	33	19A
0005435858498	4319	34	19C
0005433654812	4319	35	19B
0005435858530	4319	36	19E
0005435858527	4319	37	20D
0005435858543	4319	38	20C
0005433654802	4319	39	21D
0005433811632	14340	1	1A
0005433811644	27893	1	1A
0005433811635	27893	2	1B
0005433811636	27893	3	2A
0005433811642	27893	4	2B
0005433811634	27893	5	3A
0005433811640	27893	6	3B
0005433811637	27893	7	4A
0005433811638	27893	8	4B
0005433811639	27893	9	5A
0005433811633	27893	10	5B
0005433811641	27893	11	6A
0005433811643	27893	12	6B
0005433367747	21750	1	1A
0005435653235	21750	2	1C
0005433367870	21750	3	1D
0005433367634	21750	4	1F
0005435653208	21750	5	2A
0005435653200	21750	6	2D
0005435653234	21750	7	2F
0005433367805	21750	8	3A
0005435653192	21750	9	3D
0005435653217	21750	10	3F
0005435653216	21750	11	4A
0005435653232	21750	12	4C
0005435653215	21750	13	4D
0005433367635	21750	14	4E
0005433367599	21750	15	4F
0005435653225	21750	16	5A
0005435653209	21750	17	5C
0005435653222	21750	18	5D
0005433367709	21750	19	5E
0005435653207	21750	20	6A
0005435653221	21750	21	6C
0005435653193	21750	22	6D
0005435653206	21750	23	6E
0005435653212	21750	24	6F
0005435653201	21750	25	7A
0005433367678	21750	26	7C
0005435653198	21750	27	7D
0005435653197	21750	28	7E
0005435653224	21750	29	7F
0005433367804	21750	30	8A
0005435653219	21750	31	8D
0005433367555	21750	32	8E
0005435653195	21750	33	8F
0005435653229	21750	34	9A
0005433367554	21750	35	9F
0005435653202	21750	36	10D
0005435653236	21750	37	10E
0005435653220	21750	38	10F
0005433367467	21750	39	11A
0005433367713	21750	40	11D
0005435653213	21750	41	12D
0005433367661	21750	42	12E
0005433367601	21750	43	12F
0005435653210	21750	44	13A
0005435653228	21750	45	13C
0005435653205	21750	46	13D
0005435653199	21750	47	13E
0005435653214	21750	48	13F
0005433367676	21750	49	14A
0005435653211	21750	50	14C
0005435653226	21750	51	14D
0005433367701	21750	52	14E
0005433367651	21750	53	14F
0005435653203	21750	54	15C
0005433367660	21750	55	15D
0005433367528	21750	56	15E
0005433367600	21750	57	15F
0005433367658	21750	58	16A
0005433367677	21750	59	16C
0005433367730	21750	60	16E
0005433367761	21750	61	17A
0005433367779	21750	62	17C
0005433367675	21750	63	17D
0005435653194	21750	64	17E
0005433367650	21750	65	17F
0005433367646	21750	66	18A
0005435653231	21750	67	18C
0005433367702	21750	68	18D
0005435653233	21750	69	18E
0005435653196	21750	70	18F
0005433367746	21750	71	19C
0005433367686	21750	72	19E
0005435653218	21750	73	19F
0005435653204	21750	74	20A
0005435653227	21750	75	20C
0005435653230	21750	76	20D
0005433367728	21750	77	20E
0005435653223	21750	78	20F
0005432666396	9338	1	1A
0005433805535	9338	2	1H
0005434171012	9338	3	1G
0005435269721	9338	4	2A
0005435269714	9338	5	2F
0005433785088	9338	6	2C
0005433785103	9338	7	3A
0005434171047	9338	8	3C
0005433805514	9338	9	3B
0005435269696	9338	10	3F
0005433785080	9338	11	4A
0005433785106	9338	12	3H
0005433763268	9338	13	4B
0005434270198	9338	14	4C
0005432657462	9338	15	5F
0005433805517	9338	16	9A
0005433805534	9338	17	5H
0005432665282	9338	18	9B
0005433805512	9338	19	9G
0005433763264	9338	20	11E
0005434270190	9338	21	11D
0005433785079	9338	22	11F
0005433763269	9338	23	11G
0005433763270	9338	24	12B
0005435269716	9338	25	12G
0005433785104	9338	26	12F
0005435269732	9338	27	12H
0005434270205	9338	28	13A
0005433763258	9338	29	13B
0005433763271	9338	30	13E
0005433805530	9338	31	13F
0005433785090	9338	32	14B
0005432657461	9338	33	14A
0005434171040	9338	34	14E
0005435269720	9338	35	15A
0005433805506	9338	36	14H
0005434171053	9338	37	15D
0005433805529	9338	38	15E
0005432667462	9338	39	15G
0005435269745	9338	40	15F
0005434170995	9338	41	16A
0005435269682	9338	42	16E
0005435269717	9338	43	16F
0005433805516	9338	44	17A
0005433805520	9338	45	17D
0005433805528	9338	46	17B
0005432666398	9338	47	17E
0005435269741	9338	48	17G
0005433805533	9338	49	17H
0005434151692	9338	50	18A
0005435269697	9338	51	18B
0005434171046	9338	52	18E
0005432665283	9338	53	19A
0005433785091	9338	54	19B
0005434171059	9338	55	19E
0005434171061	9338	56	19D
0005433763262	9338	57	20A
0005433785096	9338	58	19H
0005435269715	9338	59	20E
0005434171060	9338	60	20D
0005433805524	9338	61	20G
0005435269744	9338	62	20F
0005435269677	9338	63	21B
0005434273065	9338	64	21A
0005435269742	9338	65	21F
0005434270196	9338	66	22B
0005433805508	9338	67	22A
0005435269704	9338	68	22D
0005433805532	9338	69	22F
0005433785092	9338	70	22H
0005433763265	9338	71	23B
0005433785076	9338	72	23E
0005433763259	9338	73	23G
0005433785089	9338	74	23F
0005433785078	9338	75	23H
0005433805515	9338	76	24B
0005433785094	9338	77	24E
0005433785095	9338	78	24F
0005435269726	9338	79	24H
0005433805527	9338	80	25E
0005435269702	9338	81	27B
0005432657460	9338	82	27E
0005432666397	9338	83	27G
0005433785085	9338	84	28A
0005433805518	9338	85	28B
0005433785084	9338	86	28E
0005433763263	9338	87	28D
0005433763267	9338	88	28G
0005433785100	9338	89	28F
0005433785087	9338	90	28H
0005433785086	9338	91	29D
0005434270197	9338	92	29E
0005433785081	9338	93	29G
0005435269731	9338	94	29H
0005433805523	9338	95	30B
0005433805521	9338	96	30A
0005433785097	9338	97	30D
0005433785098	9338	98	31A
0005433805507	9338	99	30H
0005433785107	9338	100	31B
0005434171062	9338	101	31D
0005433805531	9338	102	31F
0005435269681	9338	103	31G
0005433785108	9338	104	31H
0005435269727	9338	105	32A
0005434270199	9338	106	32E
0005433785082	9338	107	32F
0005433785102	9338	108	32H
0005433763266	9338	109	33A
0005433763257	9338	110	33D
0005435269705	9338	111	33E
0005434273066	9338	112	33G
0005433805510	9338	113	34D
0005433805525	9338	114	34F
0005432667463	9338	115	34E
0005435269683	9338	116	34G
0005433805526	9338	117	35B
0005433785083	9338	118	35A
0005433805522	9338	119	35D
0005433805509	9338	120	35E
0005433785077	9338	121	35G
0005433763261	9338	122	36B
0005433785093	9338	123	36D
0005433763260	9338	124	36F
0005434270204	9338	125	36H
0005434171041	9338	126	36G
0005434170985	9338	127	37A
0005433785099	9338	128	37D
0005433785109	9338	129	37B
0005434171054	9338	130	37E
0005433805511	9338	131	37F
0005433805519	9338	132	37H
0005434151689	9338	133	38A
0005433805513	9338	134	38B
0005434151690	9338	135	38D
0005433785105	9338	136	38F
0005435269680	9338	137	38H
0005433785101	9338	138	39E
0005434171120	26261	1	1C
0005433784744	26261	2	1B
0005433805249	26261	3	1F
0005434271319	26261	4	2A
0005433784696	26261	5	2C
0005434171109	26261	6	2G
0005433805311	26261	7	3A
0005435269770	26261	8	2H
0005433805286	26261	9	3B
0005433784835	26261	10	3F
0005434270212	26261	11	3G
0005433805216	26261	12	3H
0005433805326	26261	13	4B
0005434151715	26261	14	4F
0005434171117	26261	15	4C
0005433805289	26261	16	4H
0005433763174	26261	17	5A
0005433805288	26261	18	5C
0005433784761	26261	19	5G
0005432666382	26261	20	5F
0005433784653	26261	21	9A
0005433763085	26261	22	5H
0005434171108	26261	23	9B
0005433784836	26261	24	9H
0005434270213	26261	25	9G
0005433784672	26261	26	11B
0005434151714	26261	27	11A
0005433805188	26261	28	11F
0005433784907	26261	29	12D
0005433805263	26261	30	12B
0005434271318	26261	31	12E
0005433763063	26261	32	12G
0005433805159	26261	33	13B
0005433805316	26261	34	13F
0005433763119	26261	35	13E
0005434270214	26261	36	13H
0005432666367	26261	37	14D
0005433763097	26261	38	14H
0005433805234	26261	39	14F
0005433805241	26261	40	15D
0005433784775	26261	41	15B
0005433763134	26261	42	15F
0005433784832	26261	43	16A
0005432663015	26261	44	16B
0005433805314	26261	45	16E
0005433784762	26261	46	16G
0005433784758	26261	47	16F
0005432666368	26261	48	17A
0005433805280	26261	49	17D
0005433784787	26261	50	17B
0005435269767	26261	51	17E
0005434171107	26261	52	17F
0005433784675	26261	53	17G
0005433763136	26261	54	18A
0005433784688	26261	55	18D
0005433763175	26261	56	18E
0005433784803	26261	57	18G
0005434151716	26261	58	18F
0005433805140	26261	59	18H
0005433784776	26261	60	19E
0005433805124	26261	61	19F
0005433805203	26261	62	19H
0005433763145	26261	63	19G
0005433784786	26261	64	20A
0005433805377	26261	65	20D
0005433805037	26261	66	20F
0005432666369	26261	67	21B
0005433784770	26261	68	21D
0005433805150	26261	69	21E
0005433763144	26261	70	21G
0005433805054	26261	71	22A
0005433763143	26261	72	22B
0005433805105	26261	73	22G
0005433784695	26261	74	23A
0005432657429	26261	75	22H
0005432657444	26261	76	23B
0005433805376	26261	77	23D
0005434171115	26261	78	23E
0005434269109	26261	79	23G
0005434171110	26261	80	24E
0005434171121	26261	81	24D
0005433763096	26261	82	25D
0005433784906	26261	83	27B
0005433763086	26261	84	27E
0005433763176	26261	85	27G
0005433784851	26261	86	28D
0005433805337	26261	87	28G
0005434269110	26261	88	29A
0005433805330	26261	89	28H
0005433784676	26261	90	29D
0005433805202	26261	91	29E
0005433805168	26261	92	29F
0005433805149	26261	93	30A
0005433784785	26261	94	30D
0005433763177	26261	95	30B
0005433763118	26261	96	30E
0005433763189	26261	97	30F
0005433805230	26261	98	31A
0005435269771	26261	99	31B
0005433805125	26261	100	31D
0005434171111	26261	101	31F
0005433805246	26261	102	31E
0005433805158	26261	103	31G
0005435269769	26261	104	32A
0005433805267	26261	105	31H
0005433784685	26261	106	32F
0005434171112	26261	107	32E
0005433805187	26261	108	32H
0005433784702	26261	109	32G
0005434171113	26261	110	33A
0005434171106	26261	111	33E
0005433805240	26261	112	33D
0005433805287	26261	113	33G
0005433763138	26261	114	33F
0005435269772	26261	115	33H
0005434171119	26261	116	34D
0005433784686	26261	117	34B
0005434171114	26261	118	34H
0005433784780	26261	119	35B
0005432657443	26261	120	35D
0005433805151	26261	121	35E
0005435269773	26261	122	36A
0005433784667	26261	123	36F
0005433805181	26261	124	36G
0005434171116	26261	125	37A
0005433805153	26261	126	37D
0005433805201	26261	127	37B
0005433805258	26261	128	37F
0005433784759	26261	129	37G
0005435269768	26261	130	38B
0005434171118	26261	131	38A
0005433784769	26261	132	38G
0005434171105	26261	133	38F
0005433784834	26261	134	38H
0005433805169	26261	135	39D
0005433805247	26261	136	39F
0005433763215	26261	137	39E
0005435135691	4888	1	2C
0005435929629	4888	2	4A
0005435929640	4888	3	5B
0005435135688	4888	4	5D
0005435929618	4888	5	6C
0005435135690	4888	6	7B
0005435929637	4888	7	7D
0005435929636	4888	8	19A
0005435929630	4888	9	20A
0005435929628	4888	10	20D
0005435135689	4888	11	23A
0005435135631	33001	1	3D
0005435929655	33001	2	4C
0005435135657	33001	3	4D
0005435135640	33001	4	5C
0005435135632	33001	5	18D
0005435929653	33001	6	20C
0005435929654	33001	7	20D
0005434983306	9471	1	1C
0005434983307	9471	2	2B
0005434983305	9471	3	4A
0005434983309	9471	4	5A
0005434217937	9471	5	5D
0005434217936	9471	6	6C
0005434983310	9471	7	18A
0005434983308	9471	8	19A
0005434217960	9471	9	20A
0005434217961	9471	10	20C
0005434217966	9471	11	21B
0005434217959	9471	12	23B
0005434217987	27364	1	3B
0005434983282	27364	2	4B
0005434983275	27364	3	4D
0005434217985	27364	4	5C
0005434217983	27364	5	6D
0005434217984	27364	6	7D
0005434983283	27364	7	19C
0005434983273	27364	8	21A
0005434983274	27364	9	21C
0005434217986	27364	10	22C
0005433960568	24241	1	1A
0005433985720	24241	2	1B
0005433985771	24241	3	1C
0005433985580	24241	4	2F
0005433985699	24241	5	3B
0005433960557	24241	6	3C
0005433960534	24241	7	3H
0005433960541	24241	8	4C
0005433960558	24241	9	5A
0005433960565	24241	10	4H
0005433985740	24241	11	5F
0005433960489	24241	12	9B
0005433960464	24241	13	9A
0005433985697	24241	14	11A
0005433960332	24241	15	11E
0005433960476	24241	16	11D
0005433985630	24241	17	11F
0005433960509	24241	18	12A
0005433985549	24241	19	11H
0005433960281	24241	20	12D
0005433960535	24241	21	12E
0005433960542	24241	22	12F
0005433960583	24241	23	13B
0005433985728	24241	24	13A
0005433960443	24241	25	13G
0005433960490	24241	26	14A
0005433985647	24241	27	14B
0005433985746	24241	28	14D
0005433985631	24241	29	14E
0005433960571	24241	30	14H
0005433960468	24241	31	15D
0005433985623	24241	32	16A
0005433960386	24241	33	16E
0005433960605	24241	34	16D
0005433985551	24241	35	16G
0005433985812	24241	36	17D
0005433985705	24241	37	17F
0005433960388	24241	38	18A
0005433960331	24241	39	18E
0005433960477	24241	40	18H
0005433960582	24241	41	19B
0005433960559	24241	42	19D
0005433985790	24241	43	19G
0005433985657	24241	44	20D
0005433985690	24241	45	20H
0005433960580	24241	46	20G
0005433985620	24241	47	21A
0005433960625	24241	48	21D
0005433985741	24241	49	21E
0005433985710	24241	50	22B
0005433960448	24241	51	22D
0005433960404	24241	52	22G
0005433960507	24241	53	22H
0005433960330	24241	54	23G
0005433985649	24241	55	23F
0005433985721	24241	56	24H
0005433960508	24241	57	24G
0005433985711	24241	58	25D
0005433985642	24241	59	27E
0005433960401	24241	60	27F
0005433960470	24241	61	27G
0005433960359	24241	62	28A
0005433985656	24241	63	27H
0005433960609	24241	64	28B
0005433985645	24241	65	28G
0005433960579	24241	66	28F
0005433960393	24241	67	28H
0005433960289	24241	68	29B
0005433960395	24241	69	29F
0005433960479	24241	70	29H
0005433985787	24241	71	30D
0005433985644	24241	72	30E
0005433960392	24241	73	30G
0005433960482	24241	74	31A
0005433960494	24241	75	30H
0005433985636	24241	76	31B
0005433985619	24241	77	31F
0005433985789	24241	78	31E
0005433985727	24241	79	31H
0005433960449	24241	80	32B
0005433960555	24241	81	32D
0005433960465	24241	82	32G
0005433960467	24241	83	32F
0005433960478	24241	84	33A
0005433960411	24241	85	32H
0005433985646	24241	86	34A
0005433960592	24241	87	34D
0005433985726	24241	88	34F
0005433960556	24241	89	35A
0005433985698	24241	90	35F
0005433985665	24241	91	36A
0005433960394	24241	92	35H
0005433960375	24241	93	36B
0005433985658	24241	94	36E
0005433985666	24241	95	36F
0005433985786	24241	96	36G
0005433985650	24241	97	36H
0005433985550	24241	98	37B
0005433985801	24241	99	37D
0005433960472	24241	100	37G
0005433960469	24241	101	38B
0005433960358	24241	102	38A
0005433985584	24241	103	38E
0005433985751	24241	104	38H
0005433960493	24241	105	38G
0005433986100	25920	1	1A
0005433961049	25920	2	1B
0005433961082	25920	3	1F
0005433986082	25920	4	1G
0005433961058	25920	5	2A
0005433961085	25920	6	2F
0005433961040	25920	7	2C
0005433986085	25920	8	2H
0005433986111	25920	9	3B
0005433986091	25920	10	3F
0005433986129	25920	11	3C
0005433986090	25920	12	3G
0005433961050	25920	13	4F
0005433986127	25920	14	4G
0005433986113	25920	15	5A
0005433986116	25920	16	4H
0005433961079	25920	17	5G
0005433961062	25920	18	5H
0005433961075	25920	19	9A
0005433961091	25920	20	11D
0005433961066	25920	21	11F
0005433986102	25920	22	11E
0005433961056	25920	23	11G
0005433986114	25920	24	12A
0005433986081	25920	25	12D
0005433961087	25920	26	12H
0005433986110	25920	27	13A
0005433961093	25920	28	13D
0005433961089	25920	29	13G
0005433961106	25920	30	13F
0005433986126	25920	31	14A
0005433961067	25920	32	13H
0005433961078	25920	33	14B
0005433961053	25920	34	14D
0005433986118	25920	35	14G
0005433961095	25920	36	15A
0005433961109	25920	37	14H
0005433986095	25920	38	15B
0005433986096	25920	39	15D
0005433961045	25920	40	15H
0005433961043	25920	41	16D
0005433986117	25920	42	16E
0005433961044	25920	43	16F
0005433986078	25920	44	16G
0005433986099	25920	45	17B
0005433986088	25920	46	17D
0005433986077	25920	47	17F
0005433961107	25920	48	17G
0005433961068	25920	49	18B
0005433986089	25920	50	18A
0005433986121	25920	51	18D
0005433986104	25920	52	19A
0005433961103	25920	53	18H
0005433961097	25920	54	19D
0005433961092	25920	55	19G
0005433961090	25920	56	19F
0005433961035	25920	57	19H
0005433986122	25920	58	20A
0005433986124	25920	59	20E
0005433961101	25920	60	21A
0005433961069	25920	61	21D
0005433986120	25920	62	21F
0005433961104	25920	63	21H
0005433986076	25920	64	22B
0005433961063	25920	65	22G
0005433986097	25920	66	22F
0005433961102	25920	67	22H
0005433986128	25920	68	23B
0005433961038	25920	69	23A
0005433961047	25920	70	23E
0005433961055	25920	71	23D
0005433961037	25920	72	23H
0005433961064	25920	73	23G
0005433961080	25920	74	23F
0005433986101	25920	75	24A
0005433961088	25920	76	24F
0005433961060	25920	77	24E
0005433961084	25920	78	24H
0005433986112	25920	79	24G
0005433986092	25920	80	25E
0005433961074	25920	81	25F
0005433961073	25920	82	27D
0005433986103	25920	83	27B
0005433961072	25920	84	27G
0005433961039	25920	85	27F
0005433961054	25920	86	27E
0005433961094	25920	87	28B
0005433961046	25920	88	28E
0005433961071	25920	89	28H
0005433961098	25920	90	28G
0005433986105	25920	91	29B
0005433986123	25920	92	29E
0005433986086	25920	93	29D
0005433961086	25920	94	29F
0005433986125	25920	95	29G
0005433961061	25920	96	30A
0005433961081	25920	97	30D
0005433961036	25920	98	30B
0005433986087	25920	99	30F
0005433986083	25920	100	30E
0005433986093	25920	101	31A
0005433986108	25920	102	31D
0005433961076	25920	103	31F
0005433961100	25920	104	31E
0005433986115	25920	105	31H
0005433961070	25920	106	31G
0005433986098	25920	107	32A
0005433961108	25920	108	32F
0005433961041	25920	109	32H
0005433986084	25920	110	33A
0005433961096	25920	111	33E
0005433986119	25920	112	33F
0005433961105	25920	113	33H
0005433961051	25920	114	33G
0005433961077	25920	115	34A
0005433986080	25920	116	34G
0005433961042	25920	117	35B
0005433986079	25920	118	35A
0005433961065	25920	119	35D
0005433961057	25920	120	35F
0005433986106	25920	121	35G
0005433961059	25920	122	35H
0005433961034	25920	123	36D
0005433961083	25920	124	36H
0005433986094	25920	125	37A
0005433961099	25920	126	37E
0005433961048	25920	127	38A
0005433986109	25920	128	37H
0005433986107	25920	129	38G
0005433961052	25920	130	39E
0005433165867	955	1	1A
0005434480435	955	2	1B
0005434480432	955	3	1C
0005434480428	955	4	1D
0005434480420	955	5	2B
0005434480439	955	6	2C
0005434480442	955	7	2D
0005434480437	955	8	3A
0005434480438	955	9	3B
0005434480427	955	10	3D
0005434480444	955	11	3C
0005434480430	955	12	4A
0005434480436	955	13	4B
0005434480443	955	14	4C
0005433165865	955	15	4D
0005434480440	955	16	5A
0005433165826	955	17	5B
0005434480421	955	18	5C
0005433165810	955	19	6A
0005434480431	955	20	6C
0005434480422	955	21	6D
0005434480445	955	22	7A
0005433165832	955	23	7C
0005434480426	955	24	18A
0005434480419	955	25	18B
0005434480434	955	26	18C
0005434480433	955	27	18D
0005434480424	955	28	19A
0005433165923	955	29	19C
0005432269507	955	30	20A
0005433165922	955	31	20B
0005434480441	955	32	20C
0005434480423	955	33	20D
0005432269506	955	34	21A
0005433165803	955	35	21B
0005433165872	955	36	21C
0005433165866	955	37	22A
0005433165850	955	38	22B
0005434480429	955	39	22D
0005434480425	955	40	23A
0005433165825	955	41	23B
0005434480210	16570	1	1A
0005434480314	16570	2	1B
0005433165956	16570	3	1C
0005434480141	16570	4	1D
0005433165953	16570	5	2A
0005434480221	16570	6	2B
0005434480248	16570	7	2D
0005433165952	16570	8	3A
0005434480160	16570	9	3B
0005433165950	16570	10	3C
0005434480211	16570	11	3D
0005433165960	16570	12	4A
0005434480257	16570	13	4C
0005433165955	16570	14	4D
0005434480301	16570	15	5A
0005434480253	16570	16	5B
0005434480142	16570	17	5C
0005433165959	16570	18	5D
0005434480250	16570	19	6C
0005434480247	16570	20	6D
0005434480249	16570	21	7A
0005434480234	16570	22	7B
0005434480315	16570	23	7C
0005434480219	16570	24	7D
0005434480161	16570	25	18B
0005434480084	16570	26	18C
0005434480236	16570	27	18D
0005434480124	16570	28	19A
0005434480300	16570	29	19B
0005434480125	16570	30	19C
0005434480259	16570	31	19D
0005433165958	16570	32	20A
0005434480258	16570	33	20B
0005433165954	16570	34	20C
0005434480262	16570	35	20D
0005433165962	16570	36	21A
0005434480059	16570	37	21B
0005433165951	16570	38	21C
0005434480154	16570	39	21D
0005433165957	16570	40	22A
0005433165961	16570	41	22B
0005434480207	16570	42	22C
0005434480126	16570	43	22D
0005434480153	16570	44	23A
0005434480235	16570	45	23B
0005433872492	3216	1	1B
0005433872501	3216	2	1D
0005433872494	3216	3	3A
0005433872495	3216	4	3D
0005433872496	3216	5	4B
0005433872491	3216	6	5A
0005433872498	3216	7	5B
0005433872500	3216	8	6C
0005433872499	3216	9	7C
0005433872493	3216	10	19B
0005433872502	3216	11	19C
0005433872497	3216	12	21D
0005433872470	32547	1	1A
0005433872465	32547	2	1D
0005433872477	32547	3	2C
0005433872469	32547	4	3C
0005433872458	32547	5	5A
0005433872460	32547	6	7B
0005433872461	32547	7	18A
0005433872467	32547	8	18B
0005433872459	32547	9	18C
0005433872466	32547	10	19A
0005433872468	32547	11	19B
0005433872464	32547	12	20B
0005433872446	32547	13	20D
0005433872463	32547	14	21B
0005433872462	32547	15	22A
0005433872473	32547	16	22D
0005433872445	32547	17	23A
0005435142619	10354	1	1A
0005435150076	10354	2	1B
0005435386541	10354	3	1C
0005435386520	10354	4	1D
0005433289781	10354	5	2A
0005433289771	10354	6	2B
0005435150067	10354	7	2C
0005435150075	10354	8	2D
0005435150066	10354	9	3A
0005435142613	10354	10	3B
0005435150070	10354	11	3C
0005435142620	10354	12	3D
0005435150081	10354	13	4A
0005435142618	10354	14	4B
0005435142614	10354	15	4C
0005435150080	10354	16	4D
0005435386544	10354	17	5A
0005433289780	10354	18	5B
0005433289809	10354	19	5C
0005435150068	10354	20	5D
0005435142623	10354	21	6A
0005433289810	10354	22	6B
0005433289785	10354	23	6C
0005435386519	10354	24	6D
0005435142616	10354	25	7A
0005435386521	10354	26	7B
0005435150077	10354	27	7C
0005435142625	10354	28	18A
0005433289819	10354	29	18B
0005435142624	10354	30	18C
0005435150079	10354	31	18D
0005433289783	10354	32	19A
0005435142622	10354	33	19B
0005433289772	10354	34	19C
0005435150071	10354	35	19D
0005435386506	10354	36	20A
0005435386507	10354	37	20B
0005433289782	10354	38	20C
0005435386531	10354	39	20D
0005435150073	10354	40	21A
0005435150072	10354	41	21B
0005435142621	10354	42	21C
0005435142615	10354	43	21D
0005435142617	10354	44	22A
0005433289784	10354	45	22B
0005435150069	10354	46	22C
0005435150074	10354	47	22D
0005433289827	10354	48	23A
0005435150078	10354	49	23B
0005433289885	21962	1	1A
0005435142513	21962	2	1B
0005435142378	21962	3	1C
0005435149975	21962	4	1D
0005435149989	21962	5	2A
0005435149976	21962	6	2B
0005435142508	21962	7	2C
0005435149952	21962	8	2D
0005435149936	21962	9	3A
0005435142505	21962	10	3B
0005435142466	21962	11	3C
0005435149992	21962	12	3D
0005435149993	21962	13	4A
0005435149960	21962	14	4B
0005433289882	21962	15	4C
0005435149956	21962	16	4D
0005435149918	21962	17	5A
0005435142377	21962	18	5B
0005435149930	21962	19	5C
0005435386595	21962	20	5D
0005435149978	21962	21	6A
0005435149919	21962	22	6B
0005435386597	21962	23	6C
0005435142565	21962	24	6D
0005433289886	21962	25	7A
0005435149988	21962	26	7B
0005435142507	21962	27	7C
0005435142566	21962	28	7D
0005435149949	21962	29	18A
0005435149990	21962	30	18B
0005435149935	21962	31	18C
0005435149880	21962	32	18D
0005435149937	21962	33	19A
0005435149932	21962	34	19C
0005435149998	21962	35	19B
0005435149938	21962	36	19D
0005435386596	21962	37	20A
0005435149985	21962	38	20B
0005435149977	21962	39	20C
0005433289881	21962	40	20D
0005435142497	21962	41	21A
0005433289883	21962	42	21B
0005435149948	21962	43	21C
0005435142469	21962	44	21D
0005435149957	21962	45	22A
0005433289884	21962	46	22B
0005435149961	21962	47	22C
0005435149991	21962	48	22D
0005435149950	21962	49	23A
0005435149963	21962	50	23B
0005434573391	11199	1	1A
0005435545718	11199	2	1C
0005435502156	11199	3	1D
0005435529063	11199	4	1F
0005435502288	11199	5	2A
0005435545694	11199	6	2C
0005435319537	11199	7	2D
0005435502210	11199	8	2F
0005435502298	11199	9	3C
0005434573402	11199	10	3A
0005435502116	11199	11	3D
0005434573398	11199	12	3F
0005435529137	11199	13	4A
0005435529116	11199	14	4C
0005435502185	11199	15	4D
0005435529117	11199	16	4E
0005434573390	11199	17	4F
0005435502267	11199	18	5A
0005435319507	11199	19	5C
0005435319479	11199	20	5E
0005435502155	11199	21	5F
0005434573393	11199	22	6A
0005435529160	11199	23	6C
0005435502117	11199	24	6D
0005435319547	11199	25	6E
0005435529167	11199	26	6F
0005435529161	11199	27	7A
0005434573394	11199	28	7C
0005435502217	11199	29	7D
0005435545703	11199	30	7E
0005435529190	11199	31	7F
0005435319528	11199	32	8A
0005435529138	11199	33	8D
0005434573399	11199	34	8E
0005435545658	11199	35	8F
0005435545695	11199	36	9A
0005435319499	11199	37	9C
0005435502198	11199	38	9D
0005435502266	11199	39	9E
0005435529165	11199	40	9F
0005434573397	11199	41	10A
0005435529056	11199	42	10C
0005434573392	11199	43	10D
0005435529115	11199	44	10E
0005435319536	11199	45	10F
0005435545705	11199	46	11A
0005435529102	11199	47	11C
0005435502250	11199	48	11E
0005434573403	11199	49	11F
0005435545722	11199	50	12A
0005435545711	11199	51	12C
0005435502212	11199	52	12E
0005435502127	11199	53	13A
0005435545696	11199	54	13C
0005435529101	11199	55	13D
0005435529168	11199	56	13E
0005435545714	11199	57	13F
0005435502184	11199	58	14A
0005435545713	11199	59	14C
0005435319543	11199	60	14D
0005435529133	11199	61	14E
0005435545706	11199	62	14F
0005435319548	11199	63	15A
0005435529093	11199	64	15C
0005435502213	11199	65	15D
0005435529146	11199	66	15E
0005434573401	11199	67	15F
0005435529191	11199	68	16A
0005435529134	11199	69	16C
0005435502230	11199	70	16D
0005435529202	11199	71	16E
0005435529069	11199	72	16F
0005435502208	11199	73	17A
0005435502128	11199	74	17C
0005435502201	11199	75	17D
0005435545708	11199	76	17F
0005435502223	11199	77	18A
0005434573396	11199	78	18C
0005435545647	11199	79	18D
0005435319480	11199	80	18E
0005435529088	11199	81	18F
0005435529205	11199	82	19A
0005435319525	11199	83	19C
0005435529166	11199	84	19D
0005434573395	11199	85	19E
0005435529195	11199	86	19F
0005434573400	11199	87	20A
0005435502218	11199	88	20C
0005435529094	11199	89	20D
0005435545646	11199	90	20E
0005435319500	11199	91	20F
0005435502375	20950	1	1A
0005435502379	20950	2	1C
0005435517965	20950	3	1D
0005434573242	20950	4	2A
0005435517968	20950	5	2C
0005434573234	20950	6	2D
0005434573281	20950	7	2F
0005435502383	20950	8	3A
0005435517974	20950	9	3C
0005435517967	20950	10	3D
0005435502393	20950	11	4C
0005434573208	20950	12	4E
0005435502376	20950	13	5D
0005435502384	20950	14	5E
0005434573318	20950	15	5F
0005435502390	20950	16	6A
0005434573279	20950	17	6D
0005435502385	20950	18	6E
0005435502391	20950	19	6F
0005435502386	20950	20	7C
0005435517963	20950	21	7D
0005435517976	20950	22	7F
0005434573209	20950	23	8A
0005434573286	20950	24	8C
0005434573308	20950	25	8D
0005435502381	20950	26	8F
0005434573262	20950	27	9A
0005435517975	20950	28	9C
0005435502389	20950	29	9D
0005435319618	20950	30	9E
0005435502380	20950	31	9F
0005435319619	20950	32	10A
0005435502382	20950	33	10C
0005435517962	20950	34	10D
0005434573295	20950	35	10E
0005435508397	20950	36	11A
0005435517971	20950	37	11D
0005435502396	20950	38	11E
0005435517966	20950	39	11F
0005435517970	20950	40	12A
0005435508396	20950	41	12E
0005435517964	20950	42	12F
0005434573217	20950	43	13A
0005435319616	20950	44	13C
0005435502392	20950	45	13D
0005435319621	20950	46	13E
0005434573271	20950	47	14C
0005434573235	20950	48	14D
0005434573283	20950	49	14E
0005434573268	20950	50	14F
0005432291940	20950	51	15A
0005435319620	20950	52	15C
0005435517973	20950	53	15D
0005435319622	20950	54	15E
0005434573275	20950	55	15F
0005435502378	20950	56	16A
0005435508399	20950	57	16C
0005434573278	20950	58	16D
0005435502388	20950	59	16E
0005432291938	20950	60	16F
0005435502377	20950	61	17C
0005435517972	20950	62	17E
0005432291939	20950	63	18A
0005434573274	20950	64	18D
0005435517961	20950	65	18E
0005435319615	20950	66	18F
0005435502394	20950	67	19A
0005435502395	20950	68	19C
0005435517969	20950	69	19D
0005435502387	20950	70	19E
0005435508395	20950	71	19F
0005435508398	20950	72	20A
0005435319617	20950	73	20C
0005434573280	20950	74	20D
0005434573359	20950	75	20E
0005433927432	24312	1	1C
0005433927435	24312	2	1D
0005433927423	24312	3	2C
0005433927433	24312	4	2D
0005433927428	24312	5	3A
0005433927427	24312	6	3D
0005433927406	24312	7	4C
0005433683345	24312	8	4D
0005433927424	24312	9	5B
0005433927407	24312	10	5C
0005433683350	24312	11	6A
0005433683346	24312	12	6B
0005433927417	24312	13	6D
0005433683348	24312	14	6C
0005433683343	24312	15	7A
0005433683341	24312	16	7C
0005433927434	24312	17	18C
0005433683344	24312	18	19B
0005433927420	24312	19	19C
0005433927425	24312	20	19D
0005433683351	24312	21	20C
0005433683342	24312	22	20D
0005433927436	24312	23	21A
0005433683349	24312	24	21D
0005433683347	24312	25	22B
0005433683323	29289	1	1B
0005433927444	29289	2	1C
0005433927452	29289	3	1D
0005433683327	29289	4	2D
0005433683329	29289	5	3A
0005433683312	29289	6	3D
0005433927445	29289	7	7A
0005433683318	29289	8	7D
0005433927448	29289	9	18A
0005433927450	29289	10	18D
0005433927449	29289	11	19B
0005433927453	29289	12	20C
0005433927447	29289	13	20D
0005433683317	29289	14	21A
0005433927446	29289	15	21C
0005433927451	29289	16	22A
0005433683316	29289	17	23A
0005432692831	3005	1	2A
0005432692997	3005	2	2C
0005432692870	3005	3	3C
0005432692867	3005	4	3D
0005432692954	3005	5	3F
0005432692865	3005	6	4F
0005432693021	3005	7	5C
0005432692861	3005	8	5F
0005432692938	3005	9	6C
0005432693003	3005	10	6D
0005432692797	3005	11	6E
0005432692822	3005	12	7C
0005432692918	3005	13	7F
0005432692712	3005	14	8D
0005432692798	3005	15	8F
0005432692895	3005	16	9A
0005432692941	3005	17	9D
0005432693061	3005	18	9E
0005432692859	3005	19	9F
0005432692910	3005	20	10E
0005432692883	3005	21	11F
0005432692766	3005	22	13A
0005432692926	3005	23	13C
0005432692924	3005	24	13F
0005432692928	3005	25	14F
0005432692832	3005	26	15D
0005432692871	3005	27	16A
0005432692830	3005	28	16C
0005432692940	3005	29	16E
0005432692955	3005	30	16F
0005432692860	3005	31	17C
0005432692846	3005	32	17D
0005432692903	3005	33	17F
0005432692927	3005	34	17E
0005432692866	3005	35	19D
0005432692939	3005	36	20D
0005432706859	3001	1	1A
0005432217786	3001	2	1D
0005433123874	3001	3	1F
0005432880726	3001	4	2A
0005432880760	3001	5	2C
0005433123828	3001	6	2F
0005432706869	3001	7	3A
0005433123894	3001	8	3C
0005433123776	3001	9	3D
0005433123802	3001	10	4C
0005432706879	3001	11	4D
0005432706863	3001	12	5A
0005432706871	3001	13	5E
0005432706882	3001	14	6A
0005432880743	3001	15	5F
0005432880785	3001	16	6C
0005432706873	3001	17	6D
0005432706862	3001	18	6E
0005432880772	3001	19	6F
0005432706877	3001	20	7A
0005432706881	3001	21	7D
0005433194855	3001	22	7F
0005432706867	3001	23	8A
0005432706874	3001	24	8F
0005433123846	3001	25	9A
0005432706860	3001	26	9C
0005433123845	3001	27	10A
0005432706883	3001	28	10F
0005433194843	3001	29	11C
0005433123863	3001	30	11F
0005432217788	3001	31	12E
0005432706878	3001	32	12F
0005433123834	3001	33	13A
0005432880774	3001	34	13D
0005432880704	3001	35	13E
0005433123868	3001	36	14C
0005432706870	3001	37	14D
0005432706865	3001	38	14E
0005433123782	3001	39	14F
0005433123886	3001	40	15F
0005433123781	3001	41	16A
0005432706864	3001	42	16E
0005433123801	3001	43	16F
0005432706875	3001	44	17A
0005432706876	3001	45	17C
0005432880759	3001	46	17D
0005433123774	3001	47	17E
0005432217787	3001	48	17F
0005433123873	3001	49	18A
0005432706866	3001	50	18D
0005432706861	3001	51	18E
0005432706872	3001	52	18F
0005432880750	3001	53	19C
0005432706868	3001	54	19D
0005432880773	3001	55	19E
0005433123847	3001	56	19F
0005432880684	3001	57	20C
0005432880740	3001	58	20E
0005432706880	3001	59	20F
0005432880868	30012	1	1A
0005433123992	30012	2	1C
0005432693221	30012	3	1D
0005432706641	30012	4	1F
0005432706725	30012	5	2A
0005432693198	30012	6	2C
0005433123990	30012	7	2D
0005432693195	30012	8	2F
0005433123994	30012	9	3A
0005432693192	30012	10	3C
0005432693216	30012	11	3D
0005433124001	30012	12	3F
0005432706745	30012	13	4A
0005433124006	30012	14	4C
0005432693220	30012	15	4D
0005432693191	30012	16	4E
0005432693222	30012	17	4F
0005432693211	30012	18	5A
0005432706575	30012	19	5C
0005432706750	30012	20	5D
0005433124002	30012	21	5E
0005433123991	30012	22	5F
0005433124007	30012	23	6A
0005432880881	30012	24	6C
0005432693201	30012	25	6D
0005432706648	30012	26	6E
0005433123999	30012	27	7A
0005433123993	30012	28	6F
0005432693196	30012	29	7D
0005433123996	30012	30	7C
0005432880879	30012	31	7E
0005432880876	30012	32	7F
0005432880873	30012	33	8A
0005433124013	30012	34	8D
0005432880875	30012	35	8E
0005432693209	30012	36	8F
0005432706723	30012	37	9A
0005432693194	30012	38	9C
0005432693213	30012	39	9D
0005432880867	30012	40	9E
0005433124011	30012	41	9F
0005432706744	30012	42	10A
0005432706722	30012	43	10C
0005432693205	30012	44	10D
0005433124009	30012	45	10E
0005432880877	30012	46	10F
0005432880871	30012	47	11A
0005432706703	30012	48	11C
0005432693200	30012	49	11D
0005432706687	30012	50	11E
0005432693212	30012	51	11F
0005432693207	30012	52	12A
0005433124010	30012	53	12C
0005432706702	30012	54	12D
0005432693219	30012	55	12E
0005432706668	30012	56	12F
0005432693203	30012	57	13A
0005432880880	30012	58	13C
0005432706661	30012	59	13D
0005432706618	30012	60	13E
0005433123995	30012	61	13F
0005432880869	30012	62	14A
0005432693199	30012	63	14C
0005433124005	30012	64	14D
0005432706694	30012	65	14E
0005432693210	30012	66	14F
0005432706619	30012	67	15A
0005432693215	30012	68	15C
0005432706726	30012	69	15D
0005432880878	30012	70	15E
0005432693214	30012	71	15F
0005432693193	30012	72	16A
0005432880872	30012	73	16C
0005433123997	30012	74	16D
0005432693204	30012	75	16F
0005432693218	30012	76	16E
0005432693208	30012	77	17A
0005432693190	30012	78	17C
0005432693206	30012	79	17D
0005432706669	30012	80	17E
0005432693202	30012	81	17F
0005433124012	30012	82	18A
0005432706644	30012	83	18C
0005433124008	30012	84	18D
0005433124004	30012	85	18E
0005433123998	30012	86	18F
0005432706623	30012	87	19A
0005433124000	30012	88	19C
0005432880874	30012	89	19D
0005432880870	30012	90	19E
0005433124003	30012	91	19F
0005432706624	30012	92	20A
0005432706751	30012	93	20C
0005432706642	30012	94	20D
0005432693197	30012	95	20E
0005432693217	30012	96	20F
0005434979875	23694	1	1A
0005434988781	23694	2	1B
0005434979885	23694	3	1C
0005434979874	23694	4	1D
0005434979887	23694	5	2A
0005434979867	23694	6	2D
0005434979878	23694	7	3A
0005434988782	23694	8	3B
0005434988779	23694	9	4A
0005434979891	23694	10	4B
0005434979889	23694	11	4D
0005434988783	23694	12	5A
0005434979873	23694	13	5B
0005434979880	23694	14	5C
0005434979871	23694	15	5D
0005434988778	23694	16	6A
0005434988777	23694	17	6B
0005434979897	23694	18	6D
0005434979872	23694	19	7A
0005434979886	23694	20	7B
0005434979896	23694	21	7C
0005434979893	23694	22	18A
0005434979883	23694	23	18B
0005434979884	23694	24	18C
0005434979881	23694	25	18D
0005434979895	23694	26	19A
0005434979870	23694	27	19B
0005434988780	23694	28	20B
0005434979879	23694	29	20C
0005434979876	23694	30	20D
0005434979894	23694	31	21B
0005434979868	23694	32	21C
0005434979882	23694	33	21D
0005434979869	23694	34	22A
0005434979877	23694	35	22B
0005434979888	23694	36	22C
0005434979890	23694	37	22D
0005434979892	23694	38	23A
0005434979666	27526	1	1A
0005434979640	27526	2	1C
0005434979580	27526	3	1D
0005434988648	27526	4	2A
0005434979599	27526	5	2B
0005434979563	27526	6	2C
0005434979710	27526	7	2D
0005434988635	27526	8	3A
0005434979657	27526	9	3B
0005434988628	27526	10	3D
0005434988658	27526	11	4A
0005434979562	27526	12	4B
0005434979604	27526	13	4C
0005434979799	27526	14	4D
0005434979636	27526	15	5B
0005434979738	27526	16	5D
0005434988649	27526	17	6A
0005434979709	27526	18	6B
0005434979665	27526	19	6C
0005434979637	27526	20	6D
0005434979498	27526	21	7D
0005434979572	27526	22	18A
0005434988627	27526	23	18C
0005434979617	27526	24	18D
0005434979623	27526	25	19A
0005434979646	27526	26	19B
0005434979581	27526	27	19C
0005434979687	27526	28	19D
0005434979676	27526	29	20A
0005434979571	27526	30	20B
0005434979618	27526	31	20C
0005434988647	27526	32	20D
0005434979598	27526	33	21A
0005434988613	27526	34	21B
0005434979619	27526	35	21C
0005434988640	27526	36	21D
0005434979535	27526	37	22A
0005434979647	27526	38	22B
0005434979641	27526	39	22C
0005434988639	27526	40	22D
0005434979648	27526	41	23A
0005434302472	10245	1	7A
0005434302473	10245	2	19A
0005434302474	10245	3	21A
0005433113524	10245	4	23A
0005434302445	19625	1	18A
0005433113545	19625	2	21A
0005433113544	19625	3	22D
0005435069296	3549	1	1A
0005435069295	3549	2	1C
0005435069317	3549	3	1D
0005435069302	3549	4	1F
0005435069307	3549	5	2A
0005435069323	3549	6	2C
0005435069322	3549	7	2D
0005435925217	3549	8	2F
0005435069316	3549	9	3C
0005435718971	3549	10	3D
0005435925195	3549	11	3F
0005435939864	3549	12	4C
0005435069305	3549	13	4D
0005435069273	3549	14	4E
0005435925236	3549	15	4F
0005435069288	3549	16	5A
0005435925194	3549	17	5C
0005435069320	3549	18	5D
0005435718973	3549	19	5E
0005435069313	3549	20	5F
0005435718974	3549	21	6A
0005435718976	3549	22	6D
0005435069315	3549	23	6E
0005435925153	3549	24	6F
0005435939875	3549	25	7A
0005435925205	3549	26	7D
0005435069285	3549	27	7E
0005435069281	3549	28	7F
0005435069298	3549	29	8A
0005435069277	3549	30	8D
0005435939874	3549	31	8E
0005435069287	3549	32	9A
0005435069319	3549	33	9C
0005435069308	3549	34	9D
0005435069292	3549	35	9F
0005435069301	3549	36	10A
0005435718975	3549	37	10C
0005435069306	3549	38	10D
0005435069300	3549	39	10F
0005435069310	3549	40	11A
0005435069284	3549	41	11C
0005435925235	3549	42	11D
0005435069280	3549	43	11E
0005435069303	3549	44	11F
0005435069286	3549	45	12A
0005435718979	3549	46	12C
0005435069318	3549	47	12D
0005435069314	3549	48	12F
0005435069290	3549	49	13A
0005435069321	3549	50	13C
0005435069289	3549	51	13D
0005435069283	3549	52	13E
0005435069304	3549	53	14A
0005435718977	3549	54	14C
0005435069278	3549	55	14E
0005435069293	3549	56	14F
0005435069294	3549	57	15A
0005435925196	3549	58	15E
0005435069274	3549	59	15F
0005435718972	3549	60	16A
0005435069309	3549	61	16C
0005435925200	3549	62	16D
0005435069272	3549	63	16F
0005435069297	3549	64	17A
0005435069311	3549	65	17E
0005435069275	3549	66	17F
0005435069291	3549	67	18A
0005435939869	3549	68	18C
0005435069279	3549	69	18E
0005435925199	3549	70	18F
0005435069312	3549	71	19A
0005435925230	3549	72	19C
0005435718978	3549	73	19D
0005435069299	3549	74	20A
0005435069276	3549	75	20C
0005435069282	3549	76	20D
0005435925229	3549	77	20E
0005435939870	3549	78	20F
0005435068833	15312	1	1A
0005435068771	15312	2	1F
0005435925355	15312	3	2C
0005435925344	15312	4	2D
0005435925343	15312	5	2F
0005435068941	15312	6	3A
0005435925349	15312	7	3D
0005435939890	15312	8	3F
0005435068764	15312	9	4A
0005435068817	15312	10	5C
0005435068705	15312	11	5F
0005435925353	15312	12	6A
0005435068891	15312	13	6D
0005435068690	15312	14	6E
0005435068726	15312	15	6F
0005435939887	15312	16	7A
0005435939889	15312	17	7C
0005435925346	15312	18	7D
0005435925342	15312	19	7F
0005435939886	15312	20	8F
0005435939888	15312	21	9A
0005435925348	15312	22	9D
0005435925341	15312	23	9E
0005435068827	15312	24	9F
0005435068830	15312	25	10A
0005435068658	15312	26	10C
0005435068772	15312	27	10D
0005435068678	15312	28	10F
0005435068679	15312	29	11A
0005435068926	15312	30	11D
0005435925354	15312	31	11F
0005435068710	15312	32	12C
0005435068893	15312	33	12D
0005435068689	15312	34	12E
0005435068974	15312	35	12F
0005435068989	15312	36	13A
0005435925351	15312	37	13D
0005435068741	15312	38	13E
0005435068794	15312	39	14A
0005435068659	15312	40	14C
0005435925356	15312	41	14D
0005435068651	15312	42	14E
0005435068970	15312	43	15A
0005435068718	15312	44	15C
0005435068677	15312	45	15D
0005435068742	15312	46	16E
0005435068842	15312	47	16F
0005435068773	15312	48	17A
0005435068918	15312	49	17C
0005435068925	15312	50	17D
0005435925352	15312	51	17F
0005435068917	15312	52	18A
0005435068646	15312	53	18F
0005435068831	15312	54	19A
0005435069087	15312	55	19C
0005435068870	15312	56	19D
0005435068656	15312	57	19F
0005435925345	15312	58	20A
0005435068832	15312	59	20D
0005435925350	15312	60	20E
0005435925347	15312	61	20F
0005432660826	18115	1	1B
0005432658599	18115	2	3B
0005432659715	18115	3	4A
0005432660825	18115	4	6A
0005432667437	26373	1	1A
0005432664128	26373	2	2A
0005432664119	26373	3	3A
0005432660796	26373	4	4B
0005432664118	26373	5	4A
0005432667438	26373	6	5A
0005432667447	26373	7	5B
0005432660807	26373	8	6A
0005433101916	17	1	1D
0005433101771	17	2	1C
0005432919806	17	3	1A
0005432919704	17	4	2A
0005432677550	17	5	2C
0005433101946	17	6	2D
0005432901597	17	7	3A
0005433101808	17	8	3F
0005433101816	17	9	3D
0005432919667	17	10	4F
0005432391976	17	11	5A
0005432919829	17	12	5C
0005432901558	17	13	5D
0005432391984	17	14	6D
0005432901598	17	15	6C
0005432391973	17	16	7A
0005432919807	17	17	7C
0005433101789	17	18	7F
0005433101878	17	19	7D
0005432391979	17	20	8A
0005432919828	17	21	8B
0005433101846	17	22	8F
0005433101751	17	23	9B
0005432901575	17	24	9C
0005432391968	17	25	9E
0005432157501	17	26	9D
0005432919749	17	27	10A
0005433101749	17	28	9F
0005432901559	17	29	10B
0005432919859	17	30	10E
0005432901462	17	31	10F
0005432919803	17	32	11B
0005432391970	17	33	11A
0005433101978	17	34	11D
0005432919878	17	35	12A
0005433101872	17	36	12D
0005433101591	17	37	12F
0005433101729	17	38	13A
0005432919759	17	39	13F
0005433101756	17	40	13E
0005432901595	17	41	14B
0005432919805	17	42	14A
0005433101906	17	43	14C
0005433101902	17	44	14E
0005432391969	17	45	14D
0005433101671	17	46	15A
0005433101799	17	47	15C
0005432919810	17	48	16A
0005432901611	17	49	16D
0005433101952	17	50	16C
0005432391985	17	51	17A
0005433101711	17	52	17C
0005432901563	17	53	17E
0005433101964	17	54	17D
0005433101750	17	55	17F
0005433101800	17	56	18A
0005433101913	17	57	18C
0005432677545	17	58	18E
0005432901600	17	59	19B
0005432919748	17	60	19D
0005432901610	17	61	19E
0005432919851	17	62	20D
0005433101863	17	63	20F
0005432901527	17	64	20E
0005432919852	17	65	21A
0005433101977	17	66	21C
0005432919788	17	67	21B
0005432901494	17	68	21D
0005433101757	17	69	21E
0005432919842	17	70	22B
0005432901562	17	71	22D
0005432901564	17	72	22F
0005432901547	17	73	23B
0005433101694	17	74	23A
0005432901513	17	75	23D
0005433101731	17	76	24A
0005433101737	17	77	24B
0005433101793	17	78	24D
0005432919823	17	79	24E
0005433101914	17	80	25A
0005432391991	17	81	25C
0005432901546	17	82	25B
0005433101730	17	83	25F
0005433101984	17	84	26A
0005432919860	17	85	26C
0005433101876	17	86	26F
0005433101807	17	87	27C
0005432677551	17	88	27E
0005432919811	17	89	28B
0005432919735	17	90	28E
0005432391978	17	91	28D
0005432391974	17	92	29A
0005432391977	17	93	29C
0005433101923	17	94	29B
0005432919873	17	95	30A
0005433101767	17	96	30D
0005432391975	17	97	30F
0005432391990	17	98	31A
0005432157500	17	99	31D
0005433101962	17	100	31F
0005432391971	17	101	31E
0005432262096	18	1	1C
0005433687696	18	2	2C
0005432817603	18	3	2D
0005432817591	18	4	3C
0005433687694	18	5	3D
0005432262074	18	6	4A
0005432817584	18	7	4D
0005432817581	18	8	5A
0005432817592	18	9	4F
0005432262071	18	10	5C
0005432817583	18	11	6A
0005432817599	18	12	5F
0005432817576	18	13	6C
0005432289000	18	14	6F
0005432817596	18	15	8A
0005433690920	18	16	8C
0005432756826	18	17	8E
0005432262093	18	18	8F
0005432207670	18	19	9A
0005432262113	18	20	9E
0005433687695	18	21	9F
0005432817590	18	22	10D
0005432262110	18	23	11A
0005432262092	18	24	10F
0005432262083	18	25	11C
0005432262109	18	26	11F
0005432262089	18	27	11E
0005432262075	18	28	12B
0005432817582	18	29	12C
0005432262115	18	30	12E
0005432817589	18	31	12D
0005433690913	18	32	12F
0005432817595	18	33	13B
0005433690919	18	34	13A
0005432262076	18	35	14A
0005432753276	18	36	14B
0005432262090	18	37	14D
0005432262072	18	38	14E
0005432756815	18	39	14F
0005432817585	18	40	15D
0005432817597	18	41	15E
0005433690912	18	42	16D
0005432262073	18	43	16C
0005432262084	18	44	16F
0005432288998	18	45	16E
0005432817593	18	46	17B
0005432262107	18	47	17A
0005432817578	18	48	17C
0005432207669	18	49	17E
0005432262114	18	50	18A
0005432288999	18	51	17F
0005432262101	18	52	18C
0005432262077	18	53	18B
0005432262078	18	54	18F
0005432817605	18	55	19C
0005432817604	18	56	19B
0005432262080	18	57	19D
0005432817577	18	58	20A
0005432817600	18	59	20B
0005432817601	18	60	20D
0005433690921	18	61	21A
0005432262108	18	62	21C
0005432753284	18	63	21E
0005432262112	18	64	22A
0005432262086	18	65	21F
0005432817579	18	66	22B
0005432262105	18	67	22E
0005432753295	18	68	23A
0005432262082	18	69	23D
0005432262094	18	70	24A
0005432817602	18	71	23F
0005432262098	18	72	24B
0005432262111	18	73	24C
0005432753288	18	74	24E
0005432262097	18	75	24F
0005432817580	18	76	25A
0005432262081	18	77	25E
0005432262099	18	78	26D
0005432753275	18	79	26F
0005432817586	18	80	27A
0005432817588	18	81	27D
0005432262102	18	82	27F
0005432262088	18	83	27E
0005432817587	18	84	28B
0005432753285	18	85	28C
0005432262085	18	86	28E
0005432262095	18	87	28D
0005432262103	18	88	29D
0005432262091	18	89	29E
0005432262087	18	90	30A
0005432262100	18	91	30E
0005432817594	18	92	30D
0005432262104	18	93	30F
0005432817598	18	94	31A
0005432262079	18	95	31C
0005432262106	18	96	31E
0005432919936	8141	1	1A
0005432020375	8141	2	1F
0005432919942	8141	3	1D
0005432919945	8141	4	2C
0005433102341	8141	5	2D
0005432919947	8141	6	3A
0005432020366	8141	7	3D
0005433102345	8141	8	3C
0005433102389	8141	9	4A
0005433102351	8141	10	4C
0005432919938	8141	11	5A
0005433102350	8141	12	4F
0005433102360	8141	13	5C
0005433102348	8141	14	5F
0005433102357	8141	15	5D
0005432020378	8141	16	6A
0005432020382	8141	17	6C
0005432919948	8141	18	6F
0005432020371	8141	19	6D
0005433102355	8141	20	7A
0005432020383	8141	21	7C
0005433102393	8141	22	7F
0005432045621	8141	23	7D
0005433102365	8141	24	8A
0005432044535	8141	25	8B
0005433102344	8141	26	8C
0005432677591	8141	27	8E
0005432020368	8141	28	9C
0005432919934	8141	29	9D
0005432020361	8141	30	10A
0005432020359	8141	31	9F
0005433102386	8141	32	10B
0005432020356	8141	33	10C
0005432919950	8141	34	10E
0005433102372	8141	35	10F
0005432020365	8141	36	11A
0005433102354	8141	37	11C
0005432020373	8141	38	11E
0005432020364	8141	39	11F
0005433102356	8141	40	12B
0005433102384	8141	41	12D
0005433102342	8141	42	12C
0005433102349	8141	43	12E
0005433102374	8141	44	12F
0005432677592	8141	45	13C
0005432044536	8141	46	13E
0005432677593	8141	47	13D
0005432751541	8141	48	14A
0005433102353	8141	49	14C
0005432919939	8141	50	14B
0005433102358	8141	51	14D
0005432919949	8141	52	15A
0005432392013	8141	53	14F
0005433102343	8141	54	14E
0005432919940	8141	55	15B
0005432044538	8141	56	15D
0005433102347	8141	57	16D
0005432751539	8141	58	16C
0005432919946	8141	59	16E
0005433102385	8141	60	16F
0005433102346	8141	61	17B
0005432020374	8141	62	17A
0005432020355	8141	63	17C
0005433102361	8141	64	17D
0005433102362	8141	65	18A
0005433102379	8141	66	17F
0005433102382	8141	67	18B
0005432753315	8141	68	18D
0005432020381	8141	69	18C
0005433102366	8141	70	18E
0005433102368	8141	71	18F
0005432020369	8141	72	19C
0005432392012	8141	73	19D
0005432919933	8141	74	20A
0005432020363	8141	75	19E
0005432919941	8141	76	20C
0005433102378	8141	77	20E
0005433102364	8141	78	20D
0005432751540	8141	79	20F
0005432020376	8141	80	21A
0005433102352	8141	81	21C
0005432919935	8141	82	21B
0005433102387	8141	83	21D
0005433102340	8141	84	22A
0005433102383	8141	85	21F
0005432677590	8141	86	22C
0005433102381	8141	87	22E
0005432392010	8141	88	22D
0005433102377	8141	89	22F
0005432392011	8141	90	23A
0005432020358	8141	91	23C
0005432020379	8141	92	23F
0005432020372	8141	93	24B
0005432677589	8141	94	24D
0005432020370	8141	95	24E
0005432020357	8141	96	24F
0005433102391	8141	97	25B
0005433102388	8141	98	25D
0005432919944	8141	99	25E
0005432020362	8141	100	25F
0005433102373	8141	101	26D
0005433102390	8141	102	26F
0005432753316	8141	103	26E
0005433102392	8141	104	27B
0005433102369	8141	105	27C
0005432919943	8141	106	27E
0005433102370	8141	107	27D
0005433102376	8141	108	28A
0005432020367	8141	109	27F
0005432045622	8141	110	28D
0005432919931	8141	111	28E
0005433102359	8141	112	29B
0005432044537	8141	113	29A
0005432919932	8141	114	29C
0005432020360	8141	115	30B
0005432919937	8141	116	30A
0005433102363	8141	117	30C
0005433102380	8141	118	30E
0005433102375	8141	119	30D
0005432020377	8141	120	31A
0005433102367	8141	121	30F
0005432919951	8141	122	31D
0005432020380	8141	123	31F
0005433102371	8141	124	31E
0005432817283	8140	1	2D
0005432817380	8140	2	2C
0005434513565	8140	3	3A
0005432901685	8140	4	2F
0005432817309	8140	5	3D
0005434513566	8140	6	6D
0005432817351	8140	7	7A
0005432817349	8140	8	7C
0005432817354	8140	9	7F
0005432901687	8140	10	8D
0005432901679	8140	11	9C
0005432901673	8140	12	10B
0005432817357	8140	13	10F
0005432817265	8140	14	11A
0005432901677	8140	15	11C
0005432817241	8140	16	11D
0005432901671	8140	17	12E
0005432901682	8140	18	12F
0005432002085	8140	19	14D
0005432817388	8140	20	15B
0005432817452	8140	21	15A
0005432817322	8140	22	15D
0005432817284	8140	23	16C
0005434513575	8140	24	16F
0005432817221	8140	25	16E
0005432817240	8140	26	16D
0005432817300	8140	27	18A
0005432817287	8140	28	18D
0005434513559	8140	29	18C
0005432901678	8140	30	18E
0005432817350	8140	31	19D
0005432817266	8140	32	20F
0005432817257	8140	33	21A
0005432817205	8140	34	21C
0005432817293	8140	35	21E
0005432901680	8140	36	22B
0005434513560	8140	37	22C
0005432901684	8140	38	22F
0005432817413	8140	39	23C
0005432901674	8140	40	23E
0005432817308	8140	41	24B
0005432817321	8140	42	24D
0005432901676	8140	43	24F
0005432901681	8140	44	25D
0005432901683	8140	45	25E
0005432817397	8140	46	26F
0005432901688	8140	47	27A
0005432817313	8140	48	27D
0005432901686	8140	49	27E
0005432817437	8140	50	28F
0005432817356	8140	51	29D
0005432817495	8140	52	30E
0005432901675	8140	53	31A
0005432901672	8140	54	31C
0005432817256	8140	55	31D
0005432817329	8140	56	31E
0005433870739	9657	1	1A
0005433870740	9657	2	2B
0005434175706	9657	3	3A
0005434175705	9657	4	4A
0005434175707	9657	5	5A
0005433870741	9657	6	6B
0005434175769	32324	1	1A
0005434175771	32324	2	2A
0005434175770	32324	3	3A
0005433870728	32324	4	2B
0005433870726	32324	5	3B
0005433870727	32324	6	5B
0005434175772	32324	7	6A
0005434175768	32324	8	6B
0005435126521	3504	1	1C
0005434878633	3504	2	1G
0005435913912	3504	3	1D
0005434878653	3504	4	1H
0005434938218	3504	5	2C
0005435626248	3504	6	2H
0005432799573	3504	7	2G
0005435126531	3504	8	2D
0005434878598	3504	9	3A
0005435902720	3504	10	2K
0005434878657	3504	11	3C
0005434878582	3504	12	3K
0005434878610	3504	13	3H
0005435626249	3504	14	3G
0005434878666	3504	15	4C
0005434878662	3504	16	4A
0005435626244	3504	17	4G
0005434878634	3504	18	4D
0005435126558	3504	19	5A
0005435914692	3504	20	4K
0005434878626	3504	21	4H
0005434878621	3504	22	5C
0005432799569	3504	23	5G
0005434878631	3504	24	11A
0005435902561	3504	25	5K
0005435626260	3504	26	11F
0005435626261	3504	27	11E
0005434938227	3504	28	11H
0005434878639	3504	29	12C
0005434878628	3504	30	12A
0005434878588	3504	31	11K
0005435913913	3504	32	12E
0005435626259	3504	33	12D
0005434878664	3504	34	12G
0005434426736	3504	35	12F
0005432799566	3504	36	13A
0005435626251	3504	37	12K
0005434938216	3504	38	12H
0005434878583	3504	39	13C
0005434426722	3504	40	13E
0005434878635	3504	41	13H
0005434878607	3504	42	13G
0005434938230	3504	43	13K
0005434938214	3504	44	14E
0005435626258	3504	45	14K
0005434878650	3504	46	14H
0005435126549	3504	47	14G
0005435126539	3504	48	15C
0005432799568	3504	49	15A
0005434878667	3504	50	15F
0005434878617	3504	51	15E
0005434878580	3504	52	15D
0005434878640	3504	53	15G
0005432611729	3504	54	15K
0005432611730	3504	55	16D
0005434938221	3504	56	16C
0005435913921	3504	57	16A
0005434878638	3504	58	16F
0005434878659	3504	59	17A
0005435626252	3504	60	17E
0005435126548	3504	61	17D
0005435126552	3504	62	17C
0005435126532	3504	63	17K
0005432613877	3504	64	17H
0005432799576	3504	65	18A
0005432799585	3504	66	18E
0005435126547	3504	67	18D
0005432799564	3504	68	18C
0005434878614	3504	69	18G
0005434878660	3504	70	18F
0005434878612	3504	71	18K
0005434878654	3504	72	18J
0005435626253	3504	73	18H
0005435126525	3504	74	19D
0005434878609	3504	75	19F
0005435126541	3504	76	19H
0005434426734	3504	77	20A
0005434878658	3504	78	19K
0005435626263	3504	79	20C
0005434878651	3504	80	20B
0005434426737	3504	81	20E
0005435126551	3504	82	20D
0005435126522	3504	83	20G
0005434878655	3504	84	20K
0005432799570	3504	85	20H
0005434938213	3504	86	21B
0005434426740	3504	87	21A
0005434938217	3504	88	21C
0005434426730	3504	89	21G
0005435626241	3504	90	21F
0005434426732	3504	91	21E
0005434878584	3504	92	21H
0005435626246	3504	93	22A
0005435902626	3504	94	21K
0005434878619	3504	95	22D
0005434878641	3504	96	22C
0005434878608	3504	97	22E
0005435126529	3504	98	22G
0005434938232	3504	99	22J
0005434426729	3504	100	23B
0005432799567	3504	101	23A
0005435126534	3504	102	22K
0005434426727	3504	103	23E
0005434878669	3504	104	23D
0005435126550	3504	105	23C
0005434938220	3504	106	23J
0005434878656	3504	107	23H
0005434426741	3504	108	23G
0005434426738	3504	109	23K
0005432799562	3504	110	24F
0005435626243	3504	111	25A
0005432799575	3504	112	24G
0005435626264	3504	113	25F
0005435126544	3504	114	25H
0005432613879	3504	115	25G
0005434878581	3504	116	25K
0005432799584	3504	117	25J
0005434878627	3504	118	26A
0005435626245	3504	119	26G
0005434878611	3504	120	26F
0005434878579	3504	121	26J
0005432611728	3504	122	26H
0005434878648	3504	123	27B
0005434878625	3504	124	27A
0005435126542	3504	125	26K
0005432183476	3504	126	27E
0005434878670	3504	127	27J
0005434938222	3504	128	28B
0005432611726	3504	129	28E
0005434878585	3504	130	28D
0005434878620	3504	131	28G
0005435126559	3504	132	28F
0005435126555	3504	133	29A
0005434878599	3504	134	29C
0005435126562	3504	135	29B
0005434878595	3504	136	29E
0005435126556	3504	137	29H
0005434426724	3504	138	29G
0005434878632	3504	139	29K
0005432183477	3504	140	30C
0005434878661	3504	141	30B
0005435126545	3504	142	30A
0005434878623	3504	143	30D
0005435841818	3504	144	30G
0005432613881	3504	145	30K
0005435913918	3504	146	30H
0005435126561	3504	147	31B
0005432799587	3504	148	31A
0005435626242	3504	149	31D
0005434426743	3504	150	31C
0005432611727	3504	151	31F
0005435626256	3504	152	31H
0005434878649	3504	153	31G
0005435126546	3504	154	31K
0005435902673	3504	155	31J
0005434426742	3504	156	32B
0005435913920	3504	157	32A
0005434938223	3504	158	32E
0005432799581	3504	159	32D
0005434878606	3504	160	32F
0005434878592	3504	161	32H
0005434938215	3504	162	33B
0005435126527	3504	163	33A
0005435902599	3504	164	33F
0005434878601	3504	165	33E
0005435126526	3504	166	33H
0005434878613	3504	167	33G
0005434878629	3504	168	34A
0005434878652	3504	169	33K
0005434878594	3504	170	34B
0005432799574	3504	171	34G
0005435902591	3504	172	34F
0005435902692	3504	173	34K
0005434878589	3504	174	34J
0005435626255	3504	175	34H
0005432799583	3504	176	35A
0005434878637	3504	177	35D
0005432188622	3504	178	35C
0005435626254	3504	179	35F
0005432799571	3504	180	35E
0005434878663	3504	181	35G
0005435126543	3504	182	35J
0005434426747	3504	183	36D
0005435126524	3504	184	36E
0005434426719	3504	185	36H
0005434878647	3504	186	36F
0005434878668	3504	187	36K
0005434938228	3504	188	36J
0005434938219	3504	189	37B
0005434878645	3504	190	37A
0005434878605	3504	191	37D
0005432613878	3504	192	37C
0005435626257	3504	193	37E
0005434426725	3504	194	37J
0005434426731	3504	195	37G
0005434878646	3504	196	38A
0005435626265	3504	197	37K
0005435626247	3504	198	38C
0005435902700	3504	199	38B
0005434426739	3504	200	38J
0005434878593	3504	201	38H
0005434938231	3504	202	39B
0005435902590	3504	203	39A
0005434426721	3504	204	38K
0005435126538	3504	205	39C
0005435126530	3504	206	39F
0005434426746	3504	207	40A
0005432799579	3504	208	40B
0005434878630	3504	209	40E
0005435126540	3504	210	40D
0005432799565	3504	211	40F
0005432799588	3504	212	41B
0005434426745	3504	213	41A
0005432183475	3504	214	40K
0005435902672	3504	215	41D
0005434878644	3504	216	41F
0005434878624	3504	217	41H
0005435914691	3504	218	42C
0005434426723	3504	219	42B
0005434878603	3504	220	42A
0005432799586	3504	221	42E
0005434878597	3504	222	42D
0005434426728	3504	223	42H
0005432799572	3504	224	42F
0005434938226	3504	225	42J
0005435126536	3504	226	43B
0005434878591	3504	227	43A
0005434878618	3504	228	43D
0005434426726	3504	229	43F
0005434426733	3504	230	43E
0005434878665	3504	231	43H
0005434426720	3504	232	43K
0005435126528	3504	233	44B
0005435626240	3504	234	44E
0005434878616	3504	235	44D
0005435126535	3504	236	44H
0005435626262	3504	237	44G
0005434878604	3504	238	44F
0005432613880	3504	239	44J
0005435126537	3504	240	45A
0005434878590	3504	241	45C
0005432799580	3504	242	45E
0005434938229	3504	243	45J
0005435913907	3504	244	45H
0005434878615	3504	245	45G
0005435126523	3504	246	46A
0005434878636	3504	247	46E
0005434878602	3504	248	46G
0005435626250	3504	249	46J
0005434878600	3504	250	46H
0005435902539	3504	251	47C
0005432188621	3504	252	47A
0005434878586	3504	253	47E
0005434878642	3504	254	47D
0005434878671	3504	255	47H
0005435126560	3504	256	48A
0005434878596	3504	257	48F
0005432799582	3504	258	48E
0005435126557	3504	259	48D
0005435913917	3504	260	48G
0005435126553	3504	261	49A
0005434878622	3504	262	48K
0005435126533	3504	263	49E
0005432799577	3504	264	49D
0005434426744	3504	265	49C
0005432799578	3504	266	49F
0005435126554	3504	267	50C
0005432799563	3504	268	50A
0005434938225	3504	269	49K
0005434938224	3504	270	50E
0005434878643	3504	271	50F
0005434426735	3504	272	51F
0005434878587	3504	273	51G
0005432799335	14547	1	1H
0005435126088	14547	2	1G
0005434426582	14547	3	1D
0005435126220	14547	4	2D
0005435626060	14547	5	2C
0005434937966	14547	6	2H
0005432059514	14547	7	2K
0005434878034	14547	8	3G
0005432799261	14547	9	3D
0005434877501	14547	10	3H
0005434426376	14547	11	4C
0005434877767	14547	12	4A
0005434426373	14547	13	3K
0005435626031	14547	14	4D
0005435902779	14547	15	4K
0005432799251	14547	16	4H
0005435126291	14547	17	5C
0005434877672	14547	18	5A
0005434426530	14547	19	5H
0005435126238	14547	20	5G
0005435626083	14547	21	5D
0005434426558	14547	22	11A
0005432059513	14547	23	11C
0005434938129	14547	24	11G
0005432799344	14547	25	11F
0005435626054	14547	26	11E
0005434426374	14547	27	11H
0005435902771	14547	28	12A
0005432799279	14547	29	11K
0005435626069	14547	30	12D
0005434878010	14547	31	12H
0005435626052	14547	32	13D
0005434878151	14547	33	13F
0005435626033	14547	34	13E
0005434877985	14547	35	13G
0005434877381	14547	36	13K
0005432799206	14547	37	14F
0005434938121	14547	38	14K
0005434877511	14547	39	14H
0005434426506	14547	40	14G
0005434877960	14547	41	15C
0005434938105	14547	42	15A
0005435626067	14547	43	15D
0005434878141	14547	44	15G
0005434877570	14547	45	15F
0005432799351	14547	46	15K
0005435902767	14547	47	16D
0005434877763	14547	48	16C
0005432611696	14547	49	16A
0005434877630	14547	50	16E
0005434877733	14547	51	16H
0005434938159	14547	52	16G
0005435626068	14547	53	17A
0005434426425	14547	54	16K
0005435902768	14547	55	17E
0005434937967	14547	56	17G
0005432799403	14547	57	17F
0005434877754	14547	58	17K
0005435626066	14547	59	17H
0005434877994	14547	60	18B
0005434878020	14547	61	18H
0005434878013	14547	62	18G
0005434426589	14547	63	18J
0005434938103	14547	64	18K
0005435126011	14547	65	19D
0005434877554	14547	66	19C
0005435913945	14547	67	19F
0005432799237	14547	68	19G
0005435902775	14547	69	20A
0005434426416	14547	70	20C
0005434877745	14547	71	20B
0005434878160	14547	72	20D
0005435902778	14547	73	20G
0005435126143	14547	74	20J
0005434426412	14547	75	21A
0005434878142	14547	76	20K
0005434877885	14547	77	21D
0005434878060	14547	78	21C
0005435126106	14547	79	21G
0005434938104	14547	80	21E
0005434938160	14547	81	21K
0005435126047	14547	82	21J
0005434877953	14547	83	22C
0005435126209	14547	84	22B
0005435913942	14547	85	22D
0005434938106	14547	86	22H
0005432799375	14547	87	22G
0005435125971	14547	88	22K
0005434877416	14547	89	22J
0005435902777	14547	90	23B
0005434426559	14547	91	23G
0005434877520	14547	92	23H
0005434426389	14547	93	24D
0005434877762	14547	94	23K
0005434877739	14547	95	23J
0005435626064	14547	96	24E
0005434877961	14547	97	25B
0005435126117	14547	98	25A
0005434877850	14547	99	25C
0005434877929	14547	100	25F
0005434878006	14547	101	25E
0005435126264	14547	102	25H
0005434426417	14547	103	26C
0005434878143	14547	104	26E
0005435126136	14547	105	26G
0005432799230	14547	106	26J
0005435626082	14547	107	27B
0005435125956	14547	108	27A
0005434878283	14547	109	27D
0005434877766	14547	110	27C
0005434877973	14547	111	27E
0005435126094	14547	112	27G
0005435126056	14547	113	27K
0005435902769	14547	114	27J
0005434877731	14547	115	28B
0005435626034	14547	116	28D
0005434877983	14547	117	28C
0005434877673	14547	118	28F
0005434877524	14547	119	28H
0005432607558	14547	120	29B
0005434877282	14547	121	29A
0005432799314	14547	122	28K
0005435126133	14547	123	29D
0005432799329	14547	124	29C
0005434426485	14547	125	29F
0005434878014	14547	126	29E
0005432607559	14547	127	30A
0005434938056	14547	128	29K
0005435902781	14547	129	29J
0005434426581	14547	130	30B
0005432607546	14547	131	30E
0005434877594	14547	132	30D
0005435126113	14547	133	30G
0005434938062	14547	134	30K
0005435126201	14547	135	30J
0005432059512	14547	136	30H
0005434877683	14547	137	31B
0005432799243	14547	138	31A
0005435626050	14547	139	31D
0005435126010	14547	140	31F
0005434426437	14547	141	31E
0005435126144	14547	142	31G
0005434877867	14547	143	31K
0005435126095	14547	144	31J
0005435902773	14547	145	32C
0005435902770	14547	146	32A
0005434877838	14547	147	32D
0005434877738	14547	148	32H
0005435126046	14547	149	32J
0005434877593	14547	150	33A
0005435126140	14547	151	32K
0005435126221	14547	152	33D
0005435626081	14547	153	33C
0005434877716	14547	154	33F
0005435913940	14547	155	33E
0005434426468	14547	156	33G
0005434426486	14547	157	33K
0005434426529	14547	158	33J
0005434877552	14547	159	34C
0005435913943	14547	160	34E
0005432799305	14547	161	34K
0005432611697	14547	162	34J
0005434877906	14547	163	34H
0005434878061	14547	164	35A
0005434877900	14547	165	35B
0005434877484	14547	166	35F
0005434877602	14547	167	35E
0005432799188	14547	168	35H
0005432799233	14547	169	35K
0005434938093	14547	170	36A
0005434426626	14547	171	36F
0005435902772	14547	172	36E
0005434426556	14547	173	36D
0005434938094	14547	174	36G
0005435126108	14547	175	36J
0005434877986	14547	176	37B
0005435126062	14547	177	37A
0005434877523	14547	178	37E
0005435913946	14547	179	37C
0005435125955	14547	180	37G
0005435626053	14547	181	37F
0005435126025	14547	182	37H
0005434877700	14547	183	38B
0005434878161	14547	184	38A
0005434877855	14547	185	38K
0005432611690	14547	186	38J
0005435126093	14547	187	39A
0005435125940	14547	188	39D
0005434426375	14547	189	39C
0005434877664	14547	190	39F
0005434877851	14547	191	39E
0005434877629	14547	192	39K
0005435626048	14547	193	40C
0005432799399	14547	194	40B
0005435126114	14547	195	40D
0005434877732	14547	196	40H
0005434877982	14547	197	40G
0005432799256	14547	198	40F
0005435902780	14547	199	40K
0005435126200	14547	200	40J
0005434878152	14547	201	41A
0005434877993	14547	202	41D
0005432611693	14547	203	41C
0005435902776	14547	204	41F
0005434426388	14547	205	41E
0005434877665	14547	206	41H
0005434426557	14547	207	41G
0005434938119	14547	208	41K
0005435626027	14547	209	41J
0005434426462	14547	210	42C
0005434877582	14547	211	42B
0005434938122	14547	212	42A
0005435126107	14547	213	42E
0005434877883	14547	214	42D
0005435126252	14547	215	42G
0005434877903	14547	216	42F
0005434426625	14547	217	42H
0005434938073	14547	218	43A
0005434426547	14547	219	42K
0005435126154	14547	220	43D
0005434877825	14547	221	43C
0005434877826	14547	222	43B
0005434877928	14547	223	43H
0005432611698	14547	224	43G
0005432799257	14547	225	43J
0005435126026	14547	226	44B
0005435913944	14547	227	44E
0005432799315	14547	228	44D
0005434877684	14547	229	44G
0005435126126	14547	230	44F
0005435126135	14547	231	44K
0005435902784	14547	232	44H
0005432607544	14547	233	45B
0005435126063	14547	234	45D
0005434877506	14547	235	45C
0005432607557	14547	236	45F
0005434877981	14547	237	45E
0005432799408	14547	238	45H
0005435126155	14547	239	46A
0005434877533	14547	240	45K
0005435126084	14547	241	46B
0005434426366	14547	242	46C
0005434938127	14547	243	46H
0005435902774	14547	244	46G
0005434426507	14547	245	46J
0005435126141	14547	246	47A
0005434877734	14547	247	46K
0005434938044	14547	248	47E
0005432799258	14547	249	47D
0005434938082	14547	250	47C
0005432799407	14547	251	47F
0005432607561	14547	252	47H
0005434878035	14547	253	48D
0005432799302	14547	254	48C
0005434938083	14547	255	48A
0005435626059	14547	256	48H
0005434877571	14547	257	48G
0005434877635	14547	258	48F
0005434878044	14547	259	49C
0005435902782	14547	260	49A
0005432611685	14547	261	48K
0005434877553	14547	262	49D
0005434426444	14547	263	49G
0005434938128	14547	264	49E
0005434877601	14547	265	49K
0005434877468	14547	266	50C
0005435902783	14547	267	50A
0005432799382	14547	268	50E
0005435913941	14547	269	51D
0005435626028	14547	270	50K
0005434426590	14547	271	51F
0005434325699	3607	1	1B
0005434325697	3607	2	2C
0005434312327	3607	3	3A
0005434325700	3607	4	3C
0005434325698	3607	5	4C
0005434325692	3607	6	6B
0005435889846	3607	7	6C
0005434325701	3607	8	7A
0005434325695	3607	9	7D
0005434325696	3607	10	20A
0005434325693	3607	11	20C
0005434325694	3607	12	21B
0005435889870	3607	13	21A
0005434325702	3607	14	21D
0005434325691	3607	15	22B
0005435889878	3607	16	23B
0005435889920	15601	1	2A
0005434325662	15601	2	3B
0005434325598	15601	3	4A
0005435889921	15601	4	4B
0005434325616	15601	5	5B
0005435889919	15601	6	6A
0005435889924	15601	7	19A
0005434325625	15601	8	19D
0005434325622	15601	9	20A
0005434325628	15601	10	20C
0005434325620	15601	11	20D
0005434325629	15601	12	21B
0005435889923	15601	13	22D
0005435889922	15601	14	23A
0005435957757	634	1	1D
0005435957761	634	2	2B
0005435957759	634	3	2D
0005435957762	634	4	3A
0005435957770	634	5	3B
0005435957765	634	6	4A
0005433420378	634	7	4B
0005433420344	634	8	4D
0005433420379	634	9	5A
0005433420368	634	10	5B
0005435957763	634	11	6A
0005435957758	634	12	6C
0005433420404	634	13	7B
0005433420345	634	14	7C
0005433420377	634	15	18A
0005435957769	634	16	18B
0005435957767	634	17	18C
0005433420405	634	18	18D
0005435957768	634	19	19A
0005435957760	634	20	19D
0005433420364	634	21	20A
0005435957766	634	22	20C
0005433420362	634	23	20D
0005433420363	634	24	21B
0005435957764	634	25	22A
0005433420338	634	26	22C
0005433420299	634	27	23A
0005435957644	15199	1	1A
0005435957618	15199	2	2C
0005433420440	15199	3	2D
0005433420439	15199	4	3B
0005433420433	15199	5	3C
0005433420436	15199	6	4D
0005433420434	15199	7	5A
0005435957582	15199	8	6A
0005435957561	15199	9	6B
0005433420437	15199	10	6C
0005435957560	15199	11	7C
0005435957635	15199	12	7D
0005435957682	15199	13	18B
0005435957640	15199	14	19B
0005435957636	15199	15	20B
0005433420441	15199	16	21B
0005435957641	15199	17	22B
0005433420438	15199	18	22D
0005433420435	15199	19	23A
0005435216576	27257	1	1A
0005435219186	27257	2	1B
0005435219184	27257	3	1C
0005435219185	27257	4	1D
0005435219176	27257	5	2D
0005435219191	27257	6	4B
0005435216569	27257	7	4D
0005435219195	27257	8	6A
0005435219192	27257	9	7C
0005435216577	27257	10	18D
0005435221046	27257	11	19D
0005435219190	27257	12	20A
0005435216570	27257	13	21D
0005435219189	27257	14	22C
0005435216584	27257	15	22D
0005435219194	27257	16	23A
0005435219177	27257	17	23B
0005435217718	31782	1	2A
0005435216595	31782	2	3B
0005435218118	31782	3	4B
0005435218120	31782	4	5A
0005435216593	31782	5	5B
0005435216594	31782	6	6A
0005435216599	31782	7	7A
0005435217719	31782	8	7B
0005435218116	31782	9	7C
0005435217722	31782	10	7D
0005435217720	31782	11	18A
0005435217716	31782	12	18D
0005435216597	31782	13	19A
0005435216592	31782	14	19D
0005435217721	31782	15	21D
0005435217723	31782	16	22A
0005435216598	31782	17	22B
0005435218119	31782	18	22C
0005435217717	31782	19	22D
0005435218117	31782	20	23A
0005435216596	31782	21	23B
0005435629409	8946	1	2A
0005434247133	8946	2	3A
0005434247134	8946	3	6B
0005435629399	16095	1	1A
0005434247158	16095	2	1B
0005434247157	16095	3	3B
0005434467765	4020	1	1B
0005434467767	4020	2	2C
0005434467769	4020	3	4D
0005434467773	4020	4	7B
0005434467771	4020	5	18C
0005434467768	4020	6	19B
0005434467774	4020	7	20C
0005434467770	4020	8	20D
0005434467766	4020	9	22C
0005434467772	4020	10	23B
0005434467752	23202	1	2A
0005434467750	23202	2	3C
0005434467748	23202	3	6B
0005434467740	23202	4	7C
0005434467742	23202	5	7D
0005434467749	23202	6	18C
0005434467753	23202	7	19B
0005434467747	23202	8	21A
0005434467733	23202	9	21B
0005434467751	23202	10	22D
0005435933445	4428	1	1A
0005435163254	4428	2	1D
0005435933423	4428	3	2C
0005435163250	4428	4	2D
0005435933444	4428	5	3A
0005435163252	4428	6	3C
0005435163248	4428	7	3D
0005435933441	4428	8	4C
0005435163253	4428	9	4D
0005435163255	4428	10	5A
0005435163246	4428	11	5C
0005435163242	4428	12	6B
0005435163251	4428	13	7B
0005435163241	4428	14	7C
0005435163249	4428	15	7D
0005435933438	4428	16	18B
0005435933422	4428	17	18A
0005435163245	4428	18	18C
0005435163244	4428	19	19B
0005435933431	4428	20	19C
0005435163243	4428	21	20B
0005435933429	4428	22	20C
0005435933449	4428	23	20D
0005435933421	4428	24	21A
0005435163247	4428	25	21D
0005435163256	4428	26	22B
0005435163200	29503	1	2A
0005435933468	29503	2	2B
0005435163195	29503	3	2C
0005435933464	29503	4	2D
0005435163197	29503	5	3C
0005435163186	29503	6	4D
0005435163201	29503	7	5A
0005435933467	29503	8	6A
0005435163224	29503	9	6B
0005435163194	29503	10	6D
0005435933466	29503	11	7D
0005435933465	29503	12	19A
0005435933470	29503	13	19C
0005435933469	29503	14	19D
0005435163182	29503	15	21A
0005435163220	29503	16	22B
0005435163214	29503	17	23A
0005435229396	6843	1	1A
0005432646051	6843	2	1C
0005435229357	6843	3	1D
0005432646031	6843	4	1F
0005432646017	6843	5	2A
0005432646043	6843	6	2C
0005432646035	6843	7	2D
0005435229422	6843	8	2F
0005435229421	6843	9	3A
0005435229410	6843	10	3C
0005432646034	6843	11	3D
0005432646023	6843	12	3F
0005432646019	6843	13	4A
0005435229367	6843	14	4C
0005435229393	6843	15	4D
0005435229305	6843	16	4E
0005432646027	6843	17	4F
0005435229397	6843	18	5A
0005435229366	6843	19	5C
0005432646039	6843	20	5D
0005435229373	6843	21	5E
0005432646030	6843	22	5F
0005432646014	6843	23	6A
0005435229377	6843	24	6C
0005435229398	6843	25	6D
0005432645999	6843	26	6E
0005432646037	6843	27	6F
0005432646026	6843	28	7A
0005432646011	6843	29	7C
0005432646047	6843	30	7D
0005432646010	6843	31	7E
0005435229371	6843	32	7F
0005432646000	6843	33	8A
0005432646042	6843	34	8C
0005432646048	6843	35	8D
0005432646013	6843	36	8E
0005435229401	6843	37	8F
0005435229384	6843	38	9A
0005432646044	6843	39	9D
0005432646022	6843	40	9E
0005432646015	6843	41	9F
0005435229374	6843	42	10A
0005435229369	6843	43	10C
0005435229363	6843	44	10D
0005435229380	6843	45	10E
0005435229387	6843	46	10F
0005432646033	6843	47	11A
0005435229403	6843	48	11C
0005432646021	6843	49	11D
0005435229385	6843	50	11E
0005432646003	6843	51	12A
0005432646008	6843	52	12C
0005435229368	6843	53	12D
0005432646001	6843	54	12E
0005432646032	6843	55	12F
0005432646049	6843	56	13A
0005435229365	6843	57	13E
0005432646006	6843	58	13F
0005432646005	6843	59	14C
0005435229402	6843	60	14D
0005435229376	6843	61	14E
0005432646029	6843	62	14F
0005432646028	6843	63	15C
0005432646018	6843	64	15D
0005435229372	6843	65	15E
0005432646004	6843	66	15F
0005432646050	6843	67	16C
0005432646025	6843	68	16D
0005432646012	6843	69	16E
0005435229350	6843	70	16F
0005435229423	6843	71	17A
0005432646020	6843	72	17C
0005432646040	6843	73	17D
0005435229394	6843	74	17E
0005435229379	6843	75	17F
0005432646046	6843	76	18A
0005432646045	6843	77	18C
0005432646036	6843	78	18D
0005432646007	6843	79	18E
0005435229395	6843	80	19A
0005435229358	6843	81	19C
0005435229378	6843	82	19D
0005432646024	6843	83	19E
0005435229362	6843	84	19F
0005432646016	6843	85	20A
0005432646038	6843	86	20C
0005432646002	6843	87	20D
0005432646041	6843	88	20E
0005432646009	6843	89	20F
0005435797531	2853	1	1F
0005433404780	2853	2	2F
0005435797535	2853	3	3C
0005435797529	2853	4	3F
0005433404773	2853	5	6C
0005435797539	2853	6	6D
0005435797532	2853	7	8C
0005433404790	2853	8	8D
0005435797526	2853	9	9D
0005435797534	2853	10	10E
0005435797530	2853	11	11E
0005433404741	2853	12	12A
0005435797533	2853	13	13F
0005433404765	2853	14	15C
0005435797538	2853	15	15D
0005435797537	2853	16	16A
0005433404791	2853	17	17C
0005433404708	2853	18	18D
0005435797528	2853	19	18E
0005435797536	2853	20	19A
0005433404802	2853	21	19E
0005435797527	2853	22	20A
0005433404772	2853	23	20D
0005433404767	2853	24	20F
0005435797426	29335	1	1C
0005435797413	29335	2	5A
0005433404842	29335	3	5E
0005433404841	29335	4	7C
0005435797384	29335	5	7E
0005433404839	29335	6	7F
0005435797410	29335	7	8A
0005435797411	29335	8	9C
0005435797510	29335	9	10F
0005435797462	29335	10	11A
0005435797405	29335	11	13C
0005435797511	29335	12	13F
0005435797406	29335	13	14A
0005435797424	29335	14	14D
0005435797459	29335	15	14F
0005435797421	29335	16	15A
0005435797403	29335	17	15E
0005433404840	29335	18	16A
0005435797412	29335	19	16C
0005433404838	29335	20	17E
0005435797409	29335	21	17F
0005433404843	29335	22	18A
0005435797423	29335	23	19A
0005435797463	29335	24	19C
0005435376350	5806	1	4A
0005434948054	5810	1	1A
0005434948050	5810	2	1B
0005434948048	5810	3	2B
0005434948053	5810	4	2A
0005434948051	5810	5	3B
0005434948052	5810	6	5A
0005434948049	5810	7	5B
0005434948046	5810	8	6B
0005434948047	5810	9	6A
0005434948016	16342	1	1A
0005434947990	16342	2	2A
0005434947959	16342	3	1B
0005435376360	16342	4	3A
0005434947964	16342	5	3B
0005434947986	16342	6	4A
0005434947991	16342	7	4B
0005435376359	16342	8	5B
0005434948015	16342	9	5A
0005434947987	16342	10	6A
0005434947958	16342	11	6B
0005433961158	6966	1	1A
0005433961144	6966	2	1C
0005433961115	6966	3	1D
0005433961139	6966	4	1F
0005433961145	6966	5	2A
0005433961152	6966	6	2C
0005433961117	6966	7	2D
0005433961160	6966	8	3D
0005433961122	6966	9	4A
0005433961159	6966	10	4C
0005433961119	6966	11	4E
0005433961140	6966	12	5D
0005433961162	6966	13	5E
0005433961148	6966	14	6C
0005433961116	6966	15	6D
0005433961132	6966	16	6E
0005433961114	6966	17	6F
0005433961113	6966	18	7C
0005433961149	6966	19	7D
0005433961126	6966	20	7E
0005433961138	6966	21	7F
0005433961111	6966	22	8A
0005433961147	6966	23	8D
0005433961136	6966	24	8F
0005433961127	6966	25	9C
0005433961155	6966	26	9D
0005433961137	6966	27	9E
0005433961153	6966	28	10A
0005433961124	6966	29	10C
0005433961143	6966	30	10E
0005433961141	6966	31	10F
0005433961150	6966	32	11E
0005433961134	6966	33	12A
0005433961142	6966	34	12D
0005433961121	6966	35	12E
0005433961110	6966	36	13D
0005433961123	6966	37	13E
0005433961130	6966	38	13F
0005433961163	6966	39	14A
0005433961129	6966	40	14C
0005433961120	6966	41	14D
0005433961151	6966	42	14F
0005433961131	6966	43	15C
0005433961156	6966	44	15F
0005433961135	6966	45	16C
0005433961118	6966	46	16D
0005433961112	6966	47	16F
0005433961146	6966	48	17E
0005433961164	6966	49	17F
0005433961154	6966	50	19A
0005433961161	6966	51	19E
0005433961157	6966	52	19F
0005433961133	6966	53	20A
0005433961125	6966	54	20D
0005433961128	6966	55	20E
0005433960274	25733	1	1C
0005433960518	25733	2	1F
0005433960364	25733	3	3C
0005433960528	25733	4	3F
0005433960441	25733	5	4A
0005433960429	25733	6	4C
0005433960521	25733	7	5A
0005433960527	25733	8	5C
0005433960111	25733	9	5D
0005433960423	25733	10	5E
0005433960407	25733	11	6A
0005433960574	25733	12	6C
0005433960512	25733	13	6E
0005433960391	25733	14	7A
0005433960426	25733	15	7C
0005433960475	25733	16	7D
0005433960506	25733	17	7F
0005433960480	25733	18	8D
0005433960481	25733	19	8F
0005433960069	25733	20	9C
0005433960273	25733	21	9D
0005433960432	25733	22	9E
0005433960439	25733	23	9F
0005433960513	25733	24	10A
0005433960424	25733	25	10C
0005433960421	25733	26	10F
0005433960351	25733	27	11C
0005433960520	25733	28	11E
0005433960416	25733	29	11F
0005433960278	25733	30	12A
0005433960303	25733	31	12D
0005433960442	25733	32	12E
0005433960366	25733	33	13C
0005433960548	25733	34	13E
0005433960340	25733	35	14C
0005433960563	25733	36	14D
0005433960402	25733	37	14E
0005433960552	25733	38	14F
0005433960341	25733	39	15F
0005433960397	25733	40	16C
0005433960246	25733	41	16D
0005433960551	25733	42	16E
0005433960550	25733	43	16F
0005433960417	25733	44	17A
0005433960505	25733	45	17C
0005433960450	25733	46	17D
0005433960400	25733	47	18A
0005433960399	25733	48	18E
0005433960517	25733	49	18F
0005433960549	25733	50	19D
0005433960279	25733	51	20C
0005433960352	25733	52	20D
0005433960217	25733	53	20E
0005435082755	24533	1	1A
0005435082754	24533	2	1B
0005435082715	24533	3	2A
0005435082753	24533	4	2B
0005435082765	24533	5	3A
0005435082759	24533	6	3B
0005435082761	24533	7	4B
0005435082736	24533	8	5A
0005435082760	24533	9	5B
0005435082752	24533	10	6A
0005435082737	24533	11	6B
0005435082811	26148	1	1A
0005435082806	26148	2	1B
0005435082808	26148	3	2A
0005435082804	26148	4	2B
0005435082805	26148	5	4A
0005435082807	26148	6	5A
0005435082810	26148	7	4B
0005435082812	26148	8	5B
0005435082809	26148	9	6A
0005434245113	4983	1	1A
0005434245101	4983	2	1F
0005434245093	4983	3	2D
0005434245104	4983	4	2F
0005434245089	4983	5	3C
0005434245097	4983	6	4F
0005435286611	4983	7	5C
0005435286609	4983	8	6A
0005434245094	4983	9	7A
0005434245115	4983	10	7D
0005434245100	4983	11	8E
0005435286584	4983	12	8F
0005434245108	4983	13	9B
0005434245111	4983	14	9A
0005434245109	4983	15	9E
0005432166914	4983	16	10A
0005434245102	4983	17	9F
0005434245091	4983	18	10C
0005434245107	4983	19	11B
0005433534482	4983	20	11A
0005432166916	4983	21	12D
0005434245114	4983	22	12E
0005433534483	4983	23	13B
0005435286610	4983	24	13A
0005435286587	4983	25	13D
0005434245096	4983	26	14C
0005435286603	4983	27	14E
0005434245086	4983	28	15F
0005434245099	4983	29	16B
0005435286601	4983	30	16F
0005434245095	4983	31	19B
0005432166913	4983	32	20F
0005434245092	4983	33	22D
0005432166915	4983	34	23A
0005434245103	4983	35	23B
0005434245090	4983	36	24A
0005434245106	4983	37	25F
0005434245087	4983	38	27A
0005434245098	4983	39	27C
0005434245112	4983	40	27D
0005435286606	4983	41	28C
0005434245088	4983	42	29B
0005435286588	4983	43	29A
0005434245110	4983	44	29D
0005434245105	4983	45	29F
0005435286602	4983	46	30D
0005433615017	4982	1	1A
0005433614979	4982	2	1C
0005433614966	4982	3	1D
0005433785108	4982	4	2A
0005433785080	4982	5	1F
0005432105778	4982	6	2D
0005433614996	4982	7	2C
0005433614989	4982	8	3A
0005432665282	4982	9	2F
0005432105786	4982	10	3D
0005433614960	4982	11	3C
0005433615010	4982	12	3F
0005432105785	4982	13	4D
0005433614972	4982	14	4C
0005433785102	4982	15	4A
0005433785084	4982	16	4F
0005433614971	4982	17	5A
0005432105780	4982	18	5D
0005433614965	4982	19	5C
0005433615024	4982	20	6A
0005432105770	4982	21	5F
0005433785101	4982	22	6C
0005433785091	4982	23	6F
0005432105764	4982	24	6D
0005432105769	4982	25	7A
0005433615026	4982	26	7D
0005433785095	4982	27	7C
0005433614988	4982	28	7F
0005433615021	4982	29	8A
0005433785109	4982	30	8B
0005433615027	4982	31	8D
0005433614962	4982	32	8C
0005433785079	4982	33	8E
0005432105767	4982	34	9A
0005432666398	4982	35	8F
0005433785092	4982	36	9C
0005433785103	4982	37	9B
0005433615005	4982	38	9D
0005433785081	4982	39	9F
0005433785097	4982	40	9E
0005433614997	4982	41	10A
0005432105766	4982	42	10C
0005432105739	4982	43	10B
0005433614961	4982	44	10D
0005433614981	4982	45	10E
0005433615031	4982	46	10F
0005433614968	4982	47	11B
0005432105777	4982	48	11A
0005432105744	4982	49	11C
0005433614963	4982	50	11D
0005433615025	4982	51	11F
0005433615012	4982	52	11E
0005433614978	4982	53	12A
0005433615015	4982	54	12B
0005433615013	4982	55	12D
0005432105771	4982	56	12C
0005433614982	4982	57	12E
0005433614964	4982	58	12F
0005433614974	4982	59	13A
0005433614975	4982	60	13C
0005432105750	4982	61	13B
0005433785093	4982	62	13D
0005432105741	4982	63	13F
0005433615008	4982	64	13E
0005432105747	4982	65	14A
0005433614995	4982	66	14C
0005433785078	4982	67	14B
0005432105784	4982	68	14D
0005433614977	4982	69	14E
0005432666397	4982	70	14F
0005433615028	4982	71	15A
0005432105757	4982	72	15C
0005433615023	4982	73	15B
0005432105742	4982	74	15D
0005433614970	4982	75	15E
0005432105740	4982	76	16A
0005432105743	4982	77	15F
0005433614980	4982	78	16B
0005432105783	4982	79	16D
0005432105765	4982	80	16C
0005433785082	4982	81	16E
0005433614991	4982	82	17A
0005432105760	4982	83	16F
0005433614969	4982	84	17B
0005432145119	4982	85	17C
0005433785107	4982	86	17D
0005433785098	4982	87	17F
0005433785104	4982	88	17E
0005433615032	4982	89	18A
0005433785088	4982	90	18B
0005433785086	4982	91	18D
0005432145121	4982	92	18C
0005433785090	4982	93	18E
0005433785087	4982	94	18F
0005433785089	4982	95	19B
0005433615022	4982	96	19D
0005433615020	4982	97	19C
0005433614994	4982	98	19E
0005432105759	4982	99	20B
0005432105758	4982	100	20A
0005433615014	4982	101	20C
0005432105782	4982	102	20E
0005432105746	4982	103	20D
0005433614958	4982	104	20F
0005433785100	4982	105	21B
0005433785077	4982	106	21A
0005433615018	4982	107	21C
0005433614976	4982	108	21D
0005433614984	4982	109	21E
0005432105773	4982	110	21F
0005432105788	4982	111	22B
0005433785106	4982	112	22A
0005433614992	4982	113	22C
0005433614993	4982	114	22E
0005432105755	4982	115	22D
0005432105762	4982	116	22F
0005432105781	4982	117	23B
0005433615000	4982	118	23A
0005433615019	4982	119	23C
0005433615003	4982	120	23D
0005432105751	4982	121	23F
0005432667462	4982	122	23E
0005433615016	4982	123	24A
0005433614998	4982	124	24B
0005433615007	4982	125	24C
0005432105776	4982	126	24E
0005433614985	4982	127	24D
0005433785096	4982	128	24F
0005432145120	4982	129	25B
0005432105779	4982	130	25A
0005432105749	4982	131	25C
0005433615009	4982	132	25D
0005432105787	4982	133	25E
0005433615002	4982	134	26A
0005433614967	4982	135	25F
0005433614999	4982	136	26B
0005432105772	4982	137	26C
0005433614986	4982	138	26E
0005433614959	4982	139	26D
0005432105761	4982	140	27A
0005432105774	4982	141	26F
0005432105745	4982	142	27C
0005433614983	4982	143	27B
0005433785099	4982	144	27E
0005433615030	4982	145	27D
0005433615004	4982	146	27F
0005432105775	4982	147	28A
0005432105754	4982	148	28C
0005433614973	4982	149	28B
0005433785094	4982	150	28D
0005433615033	4982	151	29A
0005433785083	4982	152	28F
0005432105756	4982	153	28E
0005433615001	4982	154	29C
0005433614990	4982	155	29B
0005432666396	4982	156	29D
0005433785105	4982	157	29F
0005433615011	4982	158	29E
0005433785085	4982	159	30A
0005432665283	4982	160	30B
0005433614987	4982	161	30D
0005432105763	4982	162	30C
0005432105768	4982	163	30E
0005432105753	4982	164	30F
0005433785076	4982	165	31A
0005432667463	4982	166	31C
0005433615029	4982	167	31B
0005433615006	4982	168	31D
0005432105752	4982	169	31F
0005432105748	4982	170	31E
0005434229456	4980	1	1C
0005435006942	4980	2	1A
0005432335908	4980	3	1F
0005435006876	4980	4	1D
0005434229460	4980	5	2C
0005434265238	4980	6	2F
0005434265245	4980	7	2D
0005434265251	4980	8	3D
0005434265242	4980	9	3A
0005434229464	4980	10	3F
0005434149782	4980	11	4A
0005432336014	4980	12	4D
0005432335970	4980	13	4C
0005434173537	4980	14	5A
0005434265235	4980	15	4F
0005434229470	4980	16	5D
0005435006923	4980	17	6A
0005435006898	4980	18	5F
0005434229463	4980	19	6C
0005434312316	4980	20	6F
0005435006965	4980	21	6D
0005434149779	4980	22	7A
0005435006878	4980	23	7C
0005434229457	4980	24	7D
0005435007040	4980	25	8A
0005435006941	4980	26	7F
0005435007041	4980	27	8B
0005435269708	4980	28	8C
0005434229465	4980	29	8E
0005434265237	4980	30	9A
0005435006967	4980	31	9B
0005434265233	4980	32	9C
0005435269706	4980	33	9D
0005433685518	4980	34	9E
0005435006911	4980	35	10A
0005432335997	4980	36	9F
0005434149775	4980	37	10C
0005435269722	4980	38	10B
0005435006910	4980	39	10E
0005434149784	4980	40	10D
0005434229467	4980	41	10F
0005435269695	4980	42	11B
0005435006909	4980	43	11A
0005434265248	4980	44	11C
0005434265254	4980	45	11D
0005434265236	4980	46	12A
0005435269707	4980	47	11F
0005434265247	4980	48	12B
0005434229453	4980	49	12C
0005434173536	4980	50	12F
0005434265252	4980	51	13B
0005434149774	4980	52	13D
0005434265243	4980	53	13C
0005432335972	4980	54	13E
0005434149783	4980	55	14A
0005435006959	4980	56	14D
0005434265256	4980	57	14F
0005435269713	4980	58	14E
0005435006966	4980	59	15D
0005432335966	4980	60	15F
0005435269724	4980	61	15E
0005432335971	4980	62	16A
0005434229454	4980	63	16F
0005435006929	4980	64	17B
0005433815357	4980	65	17A
0005435269709	4980	66	17C
0005435006924	4980	67	17E
0005434149781	4980	68	17D
0005435269719	4980	69	17F
0005434229473	4980	70	18A
0005434229452	4980	71	18B
0005433685517	4980	72	18D
0005432335996	4980	73	18F
0005434229461	4980	74	19C
0005435006877	4980	75	19B
0005435006847	4980	76	19D
0005434149776	4980	77	19E
0005435006865	4980	78	20B
0005434149780	4980	79	20C
0005434149778	4980	80	20E
0005434229466	4980	81	21C
0005434229451	4980	82	21E
0005432336000	4980	83	22B
0005434265257	4980	84	22C
0005434173535	4980	85	22E
0005435006758	4980	86	22D
0005434265249	4980	87	23A
0005434229455	4980	88	23B
0005434229474	4980	89	23D
0005432335919	4980	90	23C
0005435006968	4980	91	23E
0005434229468	4980	92	23F
0005434265234	4980	93	24B
0005434265246	4980	94	24A
0005435269723	4980	95	24C
0005435269718	4980	96	24F
0005434149777	4980	97	25B
0005434229458	4980	98	25C
0005435006874	4980	99	25D
0005434265230	4980	100	25F
0005432335950	4980	101	25E
0005432335986	4980	102	26A
0005434265253	4980	103	26B
0005434229462	4980	104	26E
0005434173534	4980	105	26D
0005432335987	4980	106	27A
0005434265255	4980	107	27C
0005434265239	4980	108	27B
0005434229471	4980	109	27D
0005435006908	4980	110	27F
0005434229469	4980	111	28A
0005434229472	4980	112	28C
0005435006943	4980	113	28B
0005432335989	4980	114	28E
0005434229459	4980	115	28F
0005434265250	4980	116	29A
0005434265240	4980	117	29C
0005434265244	4980	118	29B
0005435269693	4980	119	29D
0005433815358	4980	120	29F
0005434265241	4980	121	30C
0005434265231	4980	122	30E
0005432336001	4980	123	31B
0005432335969	4980	124	31A
0005432335977	4980	125	31F
0005434265232	4980	126	31E
0005433784907	8530	1	1A
0005434245008	8530	2	2A
0005433784836	8530	3	2D
0005434244827	8530	4	3C
0005434244963	8530	5	4A
0005433784758	8530	6	4F
0005434244853	8530	7	4D
0005433784834	8530	8	5A
0005433784695	8530	9	5C
0005434244862	8530	10	5F
0005434244868	8530	11	6C
0005435269770	8530	12	7F
0005433784685	8530	13	8B
0005433784769	8530	14	8C
0005434244869	8530	15	9B
0005433784786	8530	16	9C
0005433784675	8530	17	10A
0005432663015	8530	18	10D
0005435269771	8530	19	11A
0005434244829	8530	20	10F
0005433784672	8530	21	11C
0005433784787	8530	22	11B
0005434244975	8530	23	12A
0005433784776	8530	24	12E
0005433784686	8530	25	13D
0005433784770	8530	26	14A
0005433784676	8530	27	14E
0005435269769	8530	28	15A
0005434245051	8530	29	15E
0005432666369	8530	30	15F
0005434244857	8530	31	16A
0005434244974	8530	32	16E
0005434244898	8530	33	16F
0005434244899	8530	34	17B
0005434244828	8530	35	17A
0005434244961	8530	36	17C
0005434244756	8530	37	17D
0005432666382	8530	38	18E
0005434244788	8530	39	18F
0005434245010	8530	40	19B
0005433784696	8530	41	20A
0005434244863	8530	42	20E
0005433784702	8530	43	21A
0005435269772	8530	44	21B
0005434244764	8530	45	21E
0005434244837	8530	46	22C
0005433784688	8530	47	22E
0005432666367	8530	48	23B
0005434244960	8530	49	23D
0005433784775	8530	50	23C
0005434244738	8530	51	23F
0005434244789	8530	52	24A
0005435269768	8530	53	24F
0005433784851	8530	54	25B
0005433784653	8530	55	25C
0005433784667	8530	56	25E
0005433784744	8530	57	26A
0005434244940	8530	58	26C
0005433784906	8530	59	26F
0005433784780	8530	60	27A
0005433784762	8530	61	27D
0005434244913	8530	62	27C
0005433784835	8530	63	27E
0005433784759	8530	64	28D
0005435269767	8530	65	28F
0005435269773	8530	66	29D
0005433784832	8530	67	29F
0005434244836	8530	68	30C
0005432666368	8530	69	30F
0005433784761	8530	70	30E
0005433784785	8530	71	31C
0005434244838	8530	72	31D
0005434245009	8530	73	31E
0005433784803	8530	74	31F
0005433614141	8531	1	1F
0005433614079	8531	2	1D
0005433614241	8531	3	2F
0005433614391	8531	4	3D
0005433614450	8531	5	4F
0005433614292	8531	6	5F
0005433614201	8531	7	6C
0005433614154	8531	8	7A
0005433614323	8531	9	6F
0005433614317	8531	10	7C
0005433614306	8531	11	8A
0005433614198	8531	12	8B
0005433614017	8531	13	8C
0005433614285	8531	14	8D
0005433614324	8531	15	9B
0005433614272	8531	16	9A
0005433613946	8531	17	9D
0005433614262	8531	18	10A
0005433614253	8531	19	10E
0005433614078	8531	20	11A
0005433614331	8531	21	10F
0005433614445	8531	22	11B
0005433614446	8531	23	11F
0005433614166	8531	24	12B
0005433614423	8531	25	12F
0005433614221	8531	26	13A
0005433614291	8531	27	13C
0005433614319	8531	28	13D
0005433614220	8531	29	14B
0005433614143	8531	30	15A
0005433614452	8531	31	14F
0005433614259	8531	32	15B
0005433614440	8531	33	15F
0005433614348	8531	34	16A
0005433614386	8531	35	16C
0005433614129	8531	36	16D
0005433614455	8531	37	17A
0005433614644	8531	38	16F
0005433614434	8531	39	17F
0005433614591	8531	40	18B
0005433614115	8531	41	18E
0005433614330	8531	42	18D
0005433614325	8531	43	18F
0005433614014	8531	44	19D
0005433614294	8531	45	19C
0005433614524	8531	46	19E
0005433614318	8531	47	20B
0005433613947	8531	48	21A
0005433614457	8531	49	21D
0005433614077	8531	50	21F
0005433614012	8531	51	22B
0005433614552	8531	52	22A
0005433614429	8531	53	22F
0005433614261	8531	54	22E
0005433614013	8531	55	23F
0005433614034	8531	56	23E
0005433614304	8531	57	24F
0005433614018	8531	58	24E
0005433614293	8531	59	25E
0005433614153	8531	60	26A
0005433614238	8531	61	26C
0005433614311	8531	62	26B
0005433614451	8531	63	26E
0005433614180	8531	64	27A
0005433614152	8531	65	27C
0005433614255	8531	66	27D
0005433614179	8531	67	28A
0005433614142	8531	68	28C
0005433614456	8531	69	28E
0005433614398	8531	70	29D
0005433614197	8531	71	29F
0005433614303	8531	72	30A
0005433614128	8531	73	30D
0005433614357	8531	74	31C
0005433614401	8531	75	31E
0005434265131	8532	1	1C
0005432035055	8532	2	1A
0005434264915	8532	3	1F
0005434229280	8532	4	1D
0005432035050	8532	5	2A
0005432336085	8532	6	2C
0005432035065	8532	7	2F
0005432336088	8532	8	2D
0005432047566	8532	9	3A
0005434265012	8532	10	3C
0005433815406	8532	11	3F
0005435007133	8532	12	3D
0005434229253	8532	13	4A
0005434265142	8532	14	4D
0005434265061	8532	15	4C
0005434149725	8532	16	5A
0005435007127	8532	17	5C
0005433690934	8532	18	5F
0005432047565	8532	19	5D
0005435007123	8532	20	6A
0005434149661	8532	21	6F
0005434229207	8532	22	6D
0005435007122	8532	23	7A
0005433815408	8532	24	7D
0005434229301	8532	25	7C
0005432035056	8532	26	7F
0005434229215	8532	27	8A
0005434149733	8532	28	8C
0005432035070	8532	29	8B
0005434264966	8532	30	8D
0005435007117	8532	31	8E
0005432336091	8532	32	8F
0005434264932	8532	33	9B
0005434265046	8532	34	9A
0005434264967	8532	35	9C
0005434173505	8532	36	9D
0005434229255	8532	37	9E
0005434265092	8532	38	10A
0005435007118	8532	39	9F
0005434265021	8532	40	10C
0005432336082	8532	41	10B
0005432035072	8532	42	10E
0005432336084	8532	43	10D
0005435007110	8532	44	11A
0005434149627	8532	45	10F
0005432336078	8532	46	11B
0005435007129	8532	47	11C
0005435007136	8532	48	11D
0005434229323	8532	49	11E
0005434265054	8532	50	12A
0005434149705	8532	51	11F
0005434265033	8532	52	12B
0005435007135	8532	53	12E
0005432336079	8532	54	12D
0005432035075	8532	55	12F
0005435007131	8532	56	13B
0005434173501	8532	57	13A
0005432035061	8532	58	13C
0005434265083	8532	59	13D
0005434149635	8532	60	13F
0005434173504	8532	61	13E
0005433815405	8532	62	14A
0005434149732	8532	63	14C
0005432035074	8532	64	14B
0005432336087	8532	65	14E
0005432035064	8532	66	15A
0005434265032	8532	67	14F
0005432035071	8532	68	15B
0005432035058	8532	69	15C
0005432035066	8532	70	15E
0005433688817	8532	71	15D
0005434229322	8532	72	15F
0005434265118	8532	73	16A
0005432047564	8532	74	16C
0005434149695	8532	75	16B
0005434265168	8532	76	16E
0005435007112	8532	77	16D
0005434265095	8532	78	17A
0005435007113	8532	79	16F
0005433688818	8532	80	17B
0005434264942	8532	81	17C
0005435007114	8532	82	17D
0005434149691	8532	83	17F
0005434149734	8532	84	17E
0005434265078	8532	85	18A
0005435007132	8532	86	18B
0005434264999	8532	87	18C
0005434265084	8532	88	18E
0005432035048	8532	89	18D
0005432035062	8532	90	18F
0005432035051	8532	91	19C
0005435007119	8532	92	19B
0005434265169	8532	93	19D
0005434149632	8532	94	19E
0005434229254	8532	95	20A
0005434265062	8532	96	20C
0005435007134	8532	97	20B
0005434229256	8532	98	20D
0005435007120	8532	99	20F
0005434149698	8532	100	21A
0005433815407	8532	101	21C
0005434265034	8532	102	21D
0005432035069	8532	103	21E
0005435007128	8532	104	22A
0005435007124	8532	105	21F
0005435007111	8532	106	22B
0005434265167	8532	107	22C
0005434229034	8532	108	22D
0005432336080	8532	109	22F
0005432035054	8532	110	22E
0005432035068	8532	111	23A
0005432035047	8532	112	23B
0005435007125	8532	113	23D
0005432035063	8532	114	23C
0005434229304	8532	115	23F
0005433534507	8532	116	24A
0005434265053	8532	117	24B
0005435007130	8532	118	24C
0005434229206	8532	119	24D
0005434264997	8532	120	24F
0005434229298	8532	121	24E
0005433690933	8532	122	25A
0005434229286	8532	123	25B
0005434229279	8532	124	25D
0005432336081	8532	125	25C
0005434149716	8532	126	25F
0005434265047	8532	127	25E
0005432035060	8532	128	26A
0005434265020	8532	129	26B
0005434265117	8532	130	26C
0005433689920	8532	131	26E
0005432035057	8532	132	26D
0005434229257	8532	133	26F
0005432336083	8532	134	27B
0005434265091	8532	135	27A
0005434229204	8532	136	27C
0005433534506	8532	137	27D
0005434149690	8532	138	27F
0005432035073	8532	139	27E
0005434265141	8532	140	28B
0005435007126	8532	141	28A
0005435007115	8532	142	28C
0005432035049	8532	143	28E
0005434264996	8532	144	28D
0005432047567	8532	145	29A
0005433689919	8532	146	28F
0005432035059	8532	147	29B
0005434149633	8532	148	29C
0005432035053	8532	149	29E
0005434229305	8532	150	29D
0005432336090	8532	151	29F
0005434149709	8532	152	30A
0005434265059	8532	153	30C
0005434149641	8532	154	30B
0005432035067	8532	155	30E
0005434264914	8532	156	30D
0005435007121	8532	157	30F
0005432035052	8532	158	31B
0005434264908	8532	159	31A
0005435007116	8532	160	31D
0005432336086	8532	161	31C
0005433815404	8532	162	31E
0005432336089	8532	163	31F
0005434639268	12595	1	1A
0005434639210	12595	2	1C
0005433202428	12595	3	2A
0005434639209	12595	4	2B
0005433202426	12595	5	2C
0005434639170	12595	6	2D
0005434639118	12595	7	3A
0005433202421	12595	8	3B
0005433202420	12595	9	3D
0005434639278	12595	10	4A
0005433202430	12595	11	4B
0005433202432	12595	12	4C
0005433202425	12595	13	4D
0005434639241	12595	14	5A
0005434639168	12595	15	5B
0005434639257	12595	16	5C
0005434639245	12595	17	5D
0005433202433	12595	18	6A
0005434639260	12595	19	6C
0005434639233	12595	20	6D
0005434639250	12595	21	7A
0005433202431	12595	22	7B
0005434639114	12595	23	7C
0005433202434	12595	24	7D
0005434639231	12595	25	18A
0005434639214	12595	26	18B
0005434639259	12595	27	18C
0005433202424	12595	28	18D
0005434639237	12595	29	19A
0005434639126	12595	30	19B
0005433202422	12595	31	19D
0005434639141	12595	32	20A
0005433202419	12595	33	20B
0005434639115	12595	34	20C
0005434639347	12595	35	21A
0005433202427	12595	36	21B
0005434639171	12595	37	21C
0005433202423	12595	38	21D
0005434639153	12595	39	22A
0005434639242	12595	40	22B
0005433202429	12595	41	22C
0005434639230	12595	42	22D
0005434639169	12595	43	23A
0005434639152	12595	44	23B
0005433202225	23394	1	1A
0005433202290	23394	2	1B
0005434639415	23394	3	1D
0005434639416	23394	4	2A
0005434639417	23394	5	2B
0005433202281	23394	6	2C
0005434639400	23394	7	3A
0005434639394	23394	8	3B
0005433202248	23394	9	3D
0005433202276	23394	10	4A
0005434639420	23394	11	4B
0005434639395	23394	12	4C
0005434639410	23394	13	4D
0005434639418	23394	14	5A
0005434639396	23394	15	5B
0005434639413	23394	16	5C
0005434639406	23394	17	5D
0005434639421	23394	18	6A
0005434639419	23394	19	6B
0005434639414	23394	20	6C
0005433202299	23394	21	6D
0005434639398	23394	22	7A
0005434639407	23394	23	7B
0005434639412	23394	24	7C
0005433202223	23394	25	7D
0005434639401	23394	26	18A
0005434639409	23394	27	18B
0005432290643	23394	28	18C
0005432290644	23394	29	18D
0005434639405	23394	30	19A
0005434639402	23394	31	19B
0005433202285	23394	32	19C
0005434639411	23394	33	20A
0005434639403	23394	34	20C
0005434639397	23394	35	20D
0005433202277	23394	36	21A
0005434639408	23394	37	21B
0005434639404	23394	38	21C
0005433202245	23394	39	21D
0005433202210	23394	40	22A
0005434639399	23394	41	22B
0005433202302	23394	42	23B
0005432328257	21097	1	1A
0005432328361	21097	2	1C
0005432328495	21097	3	1D
0005432328416	21097	4	2A
0005432328459	21097	5	2C
0005432328372	21097	6	2D
0005432328421	21097	7	2F
0005432328474	21097	8	3A
0005432382950	21097	9	3C
0005432328531	21097	10	3D
0005432382929	21097	11	3F
0005432328395	21097	12	4C
0005432382936	21097	13	4D
0005432328498	21097	14	4E
0005432382838	21097	15	4F
0005432054316	21097	16	5A
0005432328499	21097	17	5D
0005432328348	21097	18	5E
0005432054317	21097	19	5F
0005432328466	21097	20	6A
0005432328507	21097	21	6C
0005432328420	21097	22	6D
0005432382862	21097	23	6E
0005432328496	21097	24	6F
0005432328302	21097	25	7A
0005432328300	21097	26	7D
0005432328296	21097	27	7C
0005432383120	21097	28	7E
0005432382963	21097	29	7F
0005432328583	21097	30	8A
0005432383091	21097	31	8C
0005432328407	21097	32	8D
0005432328318	21097	33	8E
0005432328255	21097	34	8F
0005432382889	21097	35	9A
0005432382964	21097	36	9C
0005432328649	21097	37	9D
0005432382907	21097	38	9E
0005432328401	21097	39	10A
0005432328378	21097	40	10C
0005432054315	21097	41	10F
0005432382826	21097	42	11A
0005432382897	21097	43	11C
0005432382962	21097	44	11D
0005432328428	21097	45	11E
0005432328502	21097	46	12A
0005432328422	21097	47	12D
0005432328347	21097	48	12C
0005432382984	21097	49	13A
0005432382861	21097	50	13D
0005432328648	21097	51	13F
0005432328408	21097	52	14A
0005432382933	21097	53	14C
0005432382935	21097	54	14E
0005432328398	21097	55	14F
0005432383065	21097	56	15A
0005432383066	21097	57	15C
0005432328519	21097	58	15D
0005432383073	21097	59	15E
0005432328400	21097	60	15F
0005432328397	21097	61	16A
0005432382911	21097	62	16C
0005432382867	21097	63	16D
0005432328620	21097	64	16E
0005432382937	21097	65	16F
0005432328563	21097	66	17A
0005432328341	21097	67	17C
0005432328582	21097	68	17D
0005432328301	21097	69	17E
0005432382868	21097	70	17F
0005432382905	21097	71	18C
0005432328575	21097	72	18D
0005432328538	21097	73	18E
0005432328427	21097	74	19A
0005432382985	21097	75	19C
0005432328469	21097	76	19D
0005432328647	21097	77	19E
0005432328454	21097	78	19F
0005432328415	21097	79	20C
0005432328394	21097	80	20D
0005432382952	21097	81	20E
0005432328373	21097	82	20F
0005432287206	31235	1	1A
0005432383293	31235	2	1C
0005432287205	31235	3	1D
0005432328860	31235	4	1F
0005432328843	31235	5	2A
0005432328842	31235	6	2C
0005432383288	31235	7	2D
0005432328833	31235	8	2F
0005432383291	31235	9	3A
0005432328834	31235	10	3C
0005432328866	31235	11	3D
0005432383285	31235	12	3F
0005432328864	31235	13	4A
0005432328858	31235	14	4D
0005432383302	31235	15	4E
0005432328831	31235	16	5A
0005432383310	31235	17	5C
0005432383290	31235	18	5D
0005432383313	31235	19	5E
0005432328859	31235	20	5F
0005432328873	31235	21	6A
0005432383314	31235	22	6C
0005432383294	31235	23	6D
0005432328855	31235	24	6E
0005432328840	31235	25	7A
0005432383316	31235	26	7C
0005432383287	31235	27	7D
0005432328853	31235	28	7E
0005432328850	31235	29	7F
0005432383306	31235	30	8C
0005432328838	31235	31	8E
0005432328837	31235	32	8F
0005432848837	31235	33	9A
0005432328844	31235	34	9C
0005432328851	31235	35	9D
0005432383296	31235	36	9E
0005432383295	31235	37	9F
0005432328869	31235	38	10A
0005432287207	31235	39	10C
0005432328832	31235	40	10D
0005432328846	31235	41	10E
0005432383299	31235	42	11A
0005432328852	31235	43	11C
0005432383305	31235	44	11D
0005432328854	31235	45	11E
0005432328865	31235	46	11F
0005432328857	31235	47	12A
0005432383307	31235	48	12C
0005432328848	31235	49	12D
0005432383282	31235	50	12E
0005432383297	31235	51	12F
0005432328870	31235	52	13A
0005432383284	31235	53	13C
0005432328835	31235	54	13D
0005432383283	31235	55	13E
0005432383281	31235	56	13F
0005432328867	31235	57	14A
0005432383315	31235	58	14C
0005432287209	31235	59	14D
0005432328876	31235	60	14E
0005432328863	31235	61	14F
0005432383286	31235	62	15A
0005432328841	31235	63	15C
0005432383289	31235	64	15D
0005432287208	31235	65	15E
0005432328847	31235	66	15F
0005432383312	31235	67	16A
0005432383303	31235	68	16C
0005432383301	31235	69	16D
0005432328868	31235	70	16F
0005432328836	31235	71	16E
0005432383280	31235	72	17A
0005432328849	31235	73	17C
0005432328856	31235	74	17D
0005432383292	31235	75	17E
0005432328862	31235	76	17F
0005432328872	31235	77	18A
0005432383309	31235	78	18C
0005432383300	31235	79	18D
0005432383279	31235	80	18E
0005432383304	31235	81	18F
0005432383298	31235	82	19A
0005432328839	31235	83	19C
0005432328874	31235	84	19D
0005432328875	31235	85	19E
0005432328861	31235	86	19F
0005432383311	31235	87	20A
0005432328871	31235	88	20C
0005432328845	31235	89	20D
0005432383308	31235	90	20F
0005433642402	2484	1	1A
0005432953885	2484	2	1C
0005433642401	2484	3	2A
0005432953864	2484	4	2D
0005433642399	2484	5	2F
0005433642367	2484	6	3A
0005432953901	2484	7	3C
0005432953856	2484	8	3F
0005433642375	2484	9	4A
0005433642376	2484	10	4C
0005432953857	2484	11	4D
0005433642398	2484	12	4E
0005432953884	2484	13	4F
0005432953892	2484	14	5A
0005432953921	2484	15	5C
0005432953853	2484	16	5E
0005433642369	2484	17	5F
0005432953931	2484	18	6A
0005432953851	2484	19	6C
0005432953852	2484	20	6E
0005433642400	2484	21	6F
0005432953886	2484	22	7A
0005433642392	2484	23	7C
0005433642405	2484	24	7D
0005433642410	2484	25	7E
0005433642387	2484	26	7F
0005433642377	2484	27	8A
0005433642384	2484	28	8C
0005432953880	2484	29	8D
0005432953904	2484	30	8E
0005433642393	2484	31	8F
0005432953896	2484	32	9A
0005432953865	2484	33	9C
0005433642391	2484	34	9D
0005433642404	2484	35	10C
0005433642368	2484	36	10D
0005432953890	2484	37	10E
0005432953877	2484	38	10F
0005432953855	2484	39	11C
0005432953881	2484	40	11D
0005432953879	2484	41	12A
0005433642371	2484	42	12C
0005432953888	2484	43	12E
0005432953910	2484	44	12F
0005433642372	2484	45	13A
0005433642406	2484	46	13C
0005433642386	2484	47	13D
0005432953911	2484	48	13E
0005433642409	2484	49	13F
0005432953891	2484	50	14A
0005433642403	2484	51	14D
0005432953902	2484	52	15A
0005433642370	2484	53	14F
0005432953895	2484	54	15C
0005433642408	2484	55	15D
0005432953900	2484	56	15E
0005433642379	2484	57	15F
0005433642389	2484	58	16A
0005433642374	2484	59	16C
0005432953897	2484	60	16D
0005433642390	2484	61	16E
0005432953903	2484	62	16F
0005432953882	2484	63	17A
0005433642411	2484	64	17C
0005433642383	2484	65	17D
0005433642395	2484	66	17E
0005433642394	2484	67	17F
0005433642381	2484	68	18A
0005433642407	2484	69	18C
0005433642382	2484	70	18D
0005433642373	2484	71	18E
0005433642385	2484	72	18F
0005432953898	2484	73	19C
0005433642397	2484	74	19D
0005432953850	2484	75	19E
0005433642378	2484	76	19F
0005433642388	2484	77	20A
0005432953887	2484	78	20C
0005433642380	2484	79	20D
0005433642396	2484	80	20E
0005432953899	2484	81	20F
0005432424582	13271	1	1A
0005432424578	13271	2	3A
0005432424609	13271	3	3F
0005432424608	13271	4	4E
0005432424589	13271	5	5D
0005432424586	13271	6	5E
0005432424581	13271	7	5F
0005432424605	13271	8	6A
0005432424575	13271	9	7C
0005432424594	13271	10	7F
0005432424587	13271	11	8F
0005432424595	13271	12	9A
0005432424606	13271	13	9C
0005432424588	13271	14	9D
0005432424591	13271	15	9E
0005432424585	13271	16	10F
0005432424600	13271	17	11A
0005432424572	13271	18	11D
0005432424584	13271	19	11F
0005432424599	13271	20	12A
0005432424580	13271	21	13E
0005432424571	13271	22	14D
0005432424573	13271	23	14F
0005432424603	13271	24	15C
0005432424577	13271	25	15F
0005432424590	13271	26	16A
0005432424579	13271	27	16D
0005432424593	13271	28	17A
0005432424607	13271	29	17E
0005432424576	13271	30	17F
0005432424583	13271	31	18A
0005432424598	13271	32	18C
0005432424602	13271	33	18E
0005432424597	13271	34	18F
0005432424601	13271	35	19D
0005432424592	13271	36	20A
0005432424604	13271	37	20C
0005432424596	13271	38	20E
0005432424574	13271	39	20F
0005432424170	30724	1	1A
0005432424175	30724	2	1C
0005432424147	30724	3	2A
0005432424218	30724	4	2D
0005432424219	30724	5	3A
0005432424014	30724	6	3C
0005432424137	30724	7	4C
0005432424136	30724	8	4D
0005432424203	30724	9	4E
0005432424171	30724	10	4F
0005432424209	30724	11	5A
0005432424213	30724	12	5C
0005432424127	30724	13	5E
0005432424153	30724	14	6C
0005432424188	30724	15	6E
0005432424224	30724	16	7A
0005432424167	30724	17	7E
0005432424201	30724	18	8C
0005432424204	30724	19	8D
0005432424229	30724	20	9A
0005432424228	30724	21	10E
0005432424210	30724	22	11C
0005432424214	30724	23	11D
0005432424172	30724	24	12A
0005432424230	30724	25	13C
0005432424174	30724	26	13D
0005432424148	30724	27	13F
0005432424192	30724	28	14D
0005432424225	30724	29	14E
0005432424173	30724	30	15C
0005432424184	30724	31	15E
0005432424114	30724	32	16A
0005432424179	30724	33	16C
0005432424191	30724	34	17D
0005432424162	30724	35	17E
0005432424223	30724	36	17F
0005432424166	30724	37	18A
0005432423984	30724	38	18C
0005432424205	30724	39	18F
0005432424178	30724	40	19A
0005432424198	30724	41	19D
0005432424128	30724	42	20A
0005432424207	30724	43	20D
0005432901539	9633	1	1A
0005432822231	9633	2	1D
0005432901442	9633	3	1F
0005432817590	9633	4	2C
0005432901522	9633	5	2D
0005432817601	9633	6	2F
0005432817577	9633	7	3A
0005432901523	9633	8	3D
0005432817599	9633	9	4A
0005434157454	9633	10	4C
0005432288999	9633	11	4D
0005432817581	9633	12	4F
0005434157433	9633	13	5A
0005432822235	9633	14	5C
0005432901497	9633	15	6C
0005432817589	9633	16	6D
0005432901608	9633	17	6F
0005434186181	9633	18	7D
0005432817592	9633	19	7E
0005432817587	9633	20	7F
0005432817586	9633	21	8A
0005432901482	9633	22	8C
0005434157464	9633	23	8D
0005434186194	9633	24	8E
0005432822233	9633	25	8F
0005432817594	9633	26	9A
0005432901543	9633	27	9C
0005434157455	9633	28	9D
0005432817578	9633	29	9E
0005432901443	9633	30	9F
0005434157475	9633	31	10A
0005432901512	9633	32	10C
0005432901567	9633	33	10D
0005432817582	9633	34	10E
0005432817595	9633	35	10F
0005434186195	9633	36	11A
0005432822232	9633	37	11C
0005432817591	9633	38	11E
0005432817605	9633	39	12A
0005432817602	9633	40	12C
0005432901496	9633	41	12D
0005432817596	9633	42	12E
0005432817603	9633	43	13C
0005432901568	9633	44	13A
0005432817600	9633	45	13D
0005432817583	9633	46	14A
0005432817597	9633	47	14C
0005432817585	9633	48	14D
0005434157449	9633	49	14E
0005432901538	9633	50	15A
0005432288998	9633	51	14F
0005432817593	9633	52	15C
0005432822236	9633	53	15F
0005432817576	9633	54	16C
0005432289000	9633	55	16E
0005432817579	9633	56	16F
0005432822234	9633	57	17A
0005434448330	9633	58	17D
0005432817584	9633	59	17E
0005434448329	9633	60	17F
0005432901483	9633	61	18A
0005432901510	9633	62	18C
0005432817580	9633	63	18E
0005432822237	9633	64	18F
0005432817604	9633	65	19A
0005432901511	9633	66	19C
0005434448331	9633	67	19D
0005432901540	9633	68	20A
0005432901609	9633	69	20C
0005434157476	9633	70	20D
0005432817588	9633	71	20E
0005432817598	9633	72	20F
0005432901687	28999	1	1A
0005432817356	28999	2	1C
0005434448305	28999	3	1D
0005432901679	28999	4	1F
0005432817350	28999	5	2A
0005434157515	28999	6	2C
0005432817240	28999	7	2D
0005432817257	28999	8	3A
0005434157510	28999	9	3C
0005432817354	28999	10	3D
0005432822167	28999	11	3F
0005432817388	28999	12	4A
0005432901677	28999	13	4F
0005432817313	28999	14	5C
0005432817309	28999	15	5E
0005432817413	28999	16	6A
0005432817293	28999	17	6C
0005432901682	28999	18	6D
0005432002085	28999	19	6E
0005432817380	28999	20	6F
0005432817397	28999	21	7A
0005434157508	28999	22	7C
0005434157516	28999	23	7D
0005432901681	28999	24	7E
0005432901684	28999	25	7F
0005432817241	28999	26	8A
0005432901671	28999	27	8C
0005432817351	28999	28	8E
0005432817322	28999	29	9A
0005432901676	28999	30	9D
0005432901674	28999	31	9F
0005432817357	28999	32	10A
0005434157514	28999	33	10E
0005432817283	28999	34	10F
0005434448309	28999	35	11A
0005434157511	28999	36	11D
0005432901675	28999	37	11E
0005432817287	28999	38	11F
0005434448304	28999	39	12A
0005434157507	28999	40	12C
0005434186210	28999	41	12D
0005434157512	28999	42	12E
0005434157509	28999	43	12F
0005432817495	28999	44	13D
0005432817221	28999	45	13E
0005432817329	28999	46	13F
0005432817265	28999	47	14A
0005432901688	28999	48	14D
0005434448300	28999	49	14E
0005432822178	28999	50	14F
0005434186208	28999	51	15C
0005432901673	28999	52	15D
0005432822182	28999	53	15F
0005432817452	28999	54	16A
0005432817321	28999	55	16C
0005432901686	28999	56	16E
0005432817349	28999	57	17C
0005432817266	28999	58	17D
0005432817308	28999	59	17E
0005434157513	28999	60	18A
0005432901683	28999	61	18C
0005432901680	28999	62	18D
0005432817256	28999	63	18E
0005432817284	28999	64	18F
0005434186209	28999	65	19A
0005434448295	28999	66	19C
0005432817437	28999	67	19D
0005432817205	28999	68	19E
0005432901672	28999	69	20A
0005432901685	28999	70	20C
0005434157517	28999	71	20D
0005432817300	28999	72	20E
0005432901678	28999	73	20F
0005432613879	15129	1	1A
0005432611730	15129	2	1B
0005432613878	15129	3	2B
0005435841818	15129	4	2A
0005432611729	15129	5	3A
0005432611727	15129	6	3B
0005432613881	15129	7	4A
0005432613877	15129	8	4B
0005432611728	15129	9	5B
0005432613880	15129	10	6A
0005432611726	15129	11	6B
0005432607546	31628	1	1A
0005432611696	31628	2	1B
0005432607561	31628	3	2A
0005432611690	31628	4	2B
0005432607558	31628	5	3A
0005432611693	31628	6	4A
0005432611685	31628	7	3B
0005432607544	31628	8	4B
0005432611697	31628	9	5A
0005432607559	31628	10	5B
0005432611698	31628	11	6A
0005432607557	31628	12	6B
0005433569283	11887	1	1C
0005433569261	11887	2	1A
0005432948148	11887	3	1F
0005432948143	11887	4	2A
0005433569249	11887	5	2F
0005432948160	11887	6	2D
0005433569264	11887	7	2C
0005432948098	11887	8	3C
0005433569247	11887	9	3A
0005433569258	11887	10	3D
0005433569246	11887	11	3F
0005432947996	11887	12	4C
0005433569290	11887	13	4A
0005433569253	11887	14	4F
0005433569272	11887	15	5C
0005432948180	11887	16	5F
0005432948207	11887	17	5D
0005433569267	11887	18	6A
0005432948223	11887	19	6C
0005433569274	11887	20	6F
0005433569285	11887	21	6E
0005433569273	11887	22	6D
0005433569250	11887	23	7A
0005433569248	11887	24	7C
0005432948364	11887	25	7B
0005432948381	11887	26	7E
0005433569266	11887	27	7D
0005432948176	11887	28	8A
0005433569271	11887	29	7F
0005433569296	11887	30	8C
0005433569276	11887	31	8B
0005432948115	11887	32	8D
0005433569243	11887	33	8F
0005433569284	11887	34	8E
0005433569298	11887	35	9B
0005433569245	11887	36	9A
0005433569299	11887	37	9D
0005432948218	11887	38	9C
0005432948365	11887	39	9E
0005432948053	11887	40	10A
0005432948142	11887	41	10C
0005433569277	11887	42	10B
0005432948256	11887	43	10E
0005433569288	11887	44	10D
0005433569280	11887	45	10F
0005432948126	11887	46	11C
0005432948224	11887	47	11B
0005433569269	11887	48	11A
0005433569281	11887	49	11D
0005432948242	11887	50	11F
0005433569289	11887	51	12A
0005433569294	11887	52	12C
0005432948308	11887	53	12B
0005433569265	11887	54	12F
0005432948116	11887	55	12E
0005433569257	11887	56	12D
0005432948246	11887	57	13A
0005432948193	11887	58	13C
0005432948210	11887	59	13B
0005432948247	11887	60	13E
0005433569282	11887	61	13D
0005432948206	11887	62	14A
0005433569244	11887	63	13F
0005433569275	11887	64	14B
0005433569270	11887	65	14D
0005432948137	11887	66	14C
0005433569254	11887	67	14F
0005432948329	11887	68	14E
0005433569252	11887	69	15B
0005432948297	11887	70	15E
0005432948057	11887	71	15D
0005433569293	11887	72	16B
0005432948162	11887	73	16A
0005432948192	11887	74	15F
0005432948136	11887	75	16C
0005433569263	11887	76	16D
0005433569260	11887	77	17A
0005432948202	11887	78	16F
0005433569286	11887	79	16E
0005432948175	11887	80	17C
0005432948309	11887	81	17B
0005432948298	11887	82	17D
0005433569255	11887	83	17F
0005433569268	11887	84	17E
0005432948132	11887	85	18A
0005433569297	11887	86	18D
0005432948161	11887	87	18C
0005433569291	11887	88	18E
0005432948153	11887	89	19A
0005432948187	11887	90	18F
0005433569278	11887	91	19B
0005433569259	11887	92	19D
0005433569279	11887	93	19F
0005433569292	11887	94	19E
0005433569262	11887	95	20C
0005433569251	11887	96	20B
0005433569287	11887	97	20A
0005432948296	11887	98	20D
0005433569256	11887	99	20F
0005432948152	11887	100	20E
0005432948203	11887	101	21A
0005432948179	11887	102	21C
0005432948313	11887	103	21B
0005433569295	11887	104	21E
0005433569242	11887	105	21D
0005432948163	11887	106	21F
0005433568613	25284	1	1A
0005432948661	25284	2	1D
0005433568919	25284	3	1C
0005432948646	25284	4	2A
0005432948663	25284	5	1F
0005433568883	25284	6	2D
0005433568867	25284	7	2C
0005432948675	25284	8	3A
0005433568717	25284	9	2F
0005433568500	25284	10	3D
0005433568882	25284	11	3C
0005432948670	25284	12	3F
0005433568511	25284	13	4D
0005433568739	25284	14	4C
0005433568607	25284	15	4A
0005433568693	25284	16	4F
0005433568605	25284	17	5C
0005433568923	25284	18	5A
0005433568809	25284	19	5F
0005433568828	25284	20	5D
0005432948665	25284	21	6B
0005432948673	25284	22	6A
0005433568608	25284	23	6D
0005432948674	25284	24	6C
0005432948648	25284	25	6E
0005433568678	25284	26	6F
0005433568458	25284	27	7C
0005433568510	25284	28	7B
0005433568782	25284	29	7E
0005432948660	25284	30	7D
0005432948666	25284	31	8A
0005432948659	25284	32	8C
0005433568837	25284	33	8B
0005432948679	25284	34	8D
0005432948662	25284	35	8F
0005433568955	25284	36	9B
0005432948656	25284	37	9A
0005433568668	25284	38	9C
0005432948653	25284	39	9E
0005433568665	25284	40	10B
0005432948669	25284	41	10A
0005432948672	25284	42	9F
0005433568596	25284	43	10C
0005432948651	25284	44	10E
0005432948649	25284	45	10D
0005433568688	25284	46	10F
0005433568913	25284	47	11A
0005432948657	25284	48	11D
0005433568945	25284	49	11C
0005433568967	25284	50	11F
0005433568631	25284	51	11E
0005433568694	25284	52	12B
0005433568658	25284	53	12D
0005432948647	25284	54	12C
0005433568551	25284	55	12F
0005433568986	25284	56	12E
0005433568947	25284	57	13A
0005433568499	25284	58	13D
0005432948650	25284	59	13C
0005433568384	25284	60	13E
0005432948678	25284	61	13F
0005433568783	25284	62	14C
0005432948644	25284	63	14B
0005433568612	25284	64	14F
0005432948643	25284	65	14E
0005432948671	25284	66	15C
0005432948677	25284	67	15F
0005433568728	25284	68	15E
0005433568838	25284	69	15D
0005433568821	25284	70	16A
0005432948640	25284	71	16B
0005432948664	25284	72	16C
0005433568556	25284	73	16F
0005433568876	25284	74	16E
0005432948652	25284	75	17B
0005433568823	25284	76	17A
0005432948641	25284	77	17D
0005433568674	25284	78	17C
0005433568924	25284	79	17F
0005433568946	25284	80	17E
0005432948680	25284	81	18A
0005433568895	25284	82	18D
0005433568830	25284	83	18C
0005433568677	25284	84	18B
0005433568789	25284	85	18F
0005433568985	25284	86	18E
0005433568829	25284	87	19A
0005433568661	25284	88	19C
0005432948668	25284	89	19B
0005432948667	25284	90	19E
0005432948645	25284	91	19F
0005432948658	25284	92	20B
0005433568914	25284	93	20A
0005433568427	25284	94	20C
0005432948654	25284	95	20F
0005432948676	25284	96	20E
0005432948655	25284	97	20D
0005433568683	25284	98	21B
0005433568660	25284	99	21A
0005433568700	25284	100	21D
0005432948642	25284	101	21C
0005433568922	25284	102	21F
0005433568774	25284	103	21E
0005433812885	14463	1	1D
0005433808352	14463	2	2A
0005432430873	14463	3	2F
0005432430876	14463	4	3C
0005433808360	14463	5	4F
0005433812884	14463	6	4D
0005432430874	14463	7	5C
0005433812892	14463	8	5D
0005433808374	14463	9	5F
0005433812890	14463	10	6D
0005432430880	14463	11	6C
0005433808362	14463	12	7A
0005434026714	14463	13	7B
0005433808336	14463	14	9A
0005432430877	14463	15	9C
0005432430878	14463	16	10A
0005433808359	14463	17	10C
0005434026713	14463	18	10F
0005432430875	14463	19	11C
0005432430882	14463	20	13C
0005433808338	14463	21	13F
0005433808337	14463	22	14D
0005433812891	14463	23	15B
0005432430879	14463	24	15D
0005433808355	14463	25	16E
0005433812889	14463	26	16D
0005433808351	14463	27	17D
0005433812888	14463	28	17E
0005432430881	14463	29	18C
0005432430872	14463	30	18F
0005433808363	14463	31	19B
0005433808361	14463	32	19E
0005433808373	14463	33	19F
0005434026711	14463	34	20D
0005433808375	14463	35	20F
0005434026712	14463	36	20E
0005434026710	14463	37	21A
0005434026709	14463	38	21C
0005433808392	30823	1	2D
0005433812900	30823	2	2F
0005433808387	30823	3	3C
0005434026677	30823	4	3F
0005433808385	30823	5	5F
0005433812901	30823	6	6A
0005433808380	30823	7	6C
0005433808391	30823	8	6E
0005434026683	30823	9	7A
0005432430835	30823	10	7B
0005433812902	30823	11	8A
0005432430851	30823	12	8D
0005434026696	30823	13	8F
0005432430828	30823	14	8E
0005433808388	30823	15	9B
0005433812899	30823	16	9E
0005433812905	30823	17	9D
0005432430834	30823	18	9F
0005432430832	30823	19	10B
0005434026685	30823	20	10D
0005432430850	30823	21	10F
0005433812908	30823	22	11A
0005433812904	30823	23	11D
0005432430840	30823	24	12B
0005433812906	30823	25	12E
0005433808390	30823	26	12F
0005432430843	30823	27	13E
0005433808384	30823	28	14B
0005432430836	30823	29	14E
0005434026686	30823	30	16A
0005433808381	30823	31	16E
0005432430837	30823	32	17B
0005432430827	30823	33	17D
0005433812903	30823	34	18C
0005432430839	30823	35	18E
0005433808386	30823	36	18F
0005433808389	30823	37	19C
0005433808383	30823	38	19B
0005433812909	30823	39	19D
0005432430838	30823	40	20A
0005434026678	30823	41	20B
0005433812907	30823	42	20C
0005432430847	30823	43	21B
0005433808382	30823	44	21F
0005433808379	30823	45	21E
0005434654798	5407	1	1A
0005434654812	5407	2	1D
0005435340203	5407	3	2A
0005434654791	5407	4	2F
0005432114215	5407	5	3D
0005434654796	5407	6	3F
0005434654799	5407	7	4A
0005435555357	5407	8	4C
0005435340171	5407	9	4D
0005434654811	5407	10	4E
0005434654792	5407	11	4F
0005434654802	5407	12	5A
0005434654788	5407	13	5E
0005434654790	5407	14	5F
0005435340152	5407	15	6E
0005435340180	5407	16	7C
0005434654804	5407	17	7D
0005435340174	5407	18	7E
0005435340201	5407	19	8C
0005434654810	5407	20	9A
0005434654815	5407	21	9D
0005434654807	5407	22	9F
0005434654809	5407	23	10E
0005435555364	5407	24	10F
0005435340111	5407	25	11C
0005434654816	5407	26	11E
0005434654805	5407	27	11F
0005434654797	5407	28	12A
0005435340204	5407	29	12C
0005435340112	5407	30	12D
0005435340173	5407	31	12E
0005435340211	5407	32	12F
0005432114216	5407	33	13E
0005435340194	5407	34	13F
0005435340208	5407	35	14C
0005435340200	5407	36	14D
0005435555356	5407	37	14E
0005434654806	5407	38	15A
0005434654813	5407	39	15D
0005434656564	5407	40	15E
0005435555363	5407	41	15F
0005434654801	5407	42	16C
0005435340176	5407	43	17C
0005434654800	5407	44	17D
0005435340196	5407	45	17E
0005434656565	5407	46	18C
0005434654793	5407	47	18E
0005434654789	5407	48	19A
0005434654814	5407	49	19C
0005435340209	5407	50	19E
0005434654808	5407	51	19F
0005434654803	5407	52	20A
0005432114217	5407	53	20C
0005434654795	5407	54	20D
0005434654794	5407	55	20E
0005435340327	12556	1	1A
0005435340318	12556	2	1F
0005435340317	12556	3	2C
0005434654559	12556	4	3A
0005434654532	12556	5	3D
0005435340326	12556	6	3F
0005435340320	12556	7	4F
0005434654435	12556	8	5F
0005435340324	12556	9	6A
0005435555381	12556	10	6C
0005434654502	12556	11	6F
0005435340329	12556	12	7C
0005434654539	12556	13	7E
0005434654572	12556	14	7F
0005434654533	12556	15	8C
0005434654561	12556	16	9C
0005434654558	12556	17	9D
0005434654595	12556	18	10C
0005435340322	12556	19	10A
0005434654560	12556	20	10E
0005435340332	12556	21	10F
0005434654617	12556	22	11C
0005434654616	12556	23	11D
0005434654434	12556	24	11E
0005434654527	12556	25	11F
0005434654451	12556	26	12A
0005435340328	12556	27	12E
0005435340331	12556	28	12F
0005435555379	12556	29	13A
0005434654450	12556	30	13C
0005435340319	12556	31	13E
0005434654553	12556	32	14C
0005434654635	12556	33	14E
0005434654511	12556	34	14F
0005434654485	12556	35	15C
0005434654566	12556	36	15E
0005435340325	12556	37	16F
0005435340330	12556	38	17C
0005434654588	12556	39	17E
0005434654600	12556	40	17F
0005435340323	12556	41	18A
0005434654494	12556	42	18C
0005435555380	12556	43	18F
0005434654540	12556	44	20A
0005435340321	12556	45	20C
0005435340316	12556	46	20D
0005434654594	12556	47	20E
0005433716169	7438	1	1A
0005433716148	7438	2	1D
0005433716161	7438	3	1F
0005433716186	7438	4	2C
0005433716189	7438	5	2D
0005435266126	7438	6	2F
0005433722241	7438	7	4A
0005433716174	7438	8	4B
0005435266110	7438	9	4D
0005435266123	7438	10	4C
0005433716173	7438	11	4F
0005433722242	7438	12	5A
0005433656680	7438	13	5D
0005433716163	7438	14	5E
0005433719150	7438	15	6A
0005432428900	7438	16	5F
0005433690932	7438	17	6B
0005433716155	7438	18	6C
0005433716152	7438	19	6E
0005433722240	7438	20	7A
0005433716168	7438	21	6F
0005433689917	7438	22	7C
0005433716146	7438	23	7D
0005433722238	7438	24	7F
0005433722243	7438	25	8B
0005433716185	7438	26	8C
0005433716172	7438	27	8D
0005435266125	7438	28	8E
0005433716153	7438	29	9A
0005433716150	7438	30	9B
0005433716171	7438	31	9D
0005433688815	7438	32	10C
0005432428890	7438	33	10B
0005433716145	7438	34	10D
0005432428914	7438	35	10E
0005433716158	7438	36	11A
0005433716178	7438	37	11B
0005433716165	7438	38	11D
0005435266122	7438	39	11C
0005432428902	7438	40	11E
0005435266131	7438	41	12A
0005433719153	7438	42	11F
0005432428901	7438	43	12C
0005433716180	7438	44	12B
0005433716191	7438	45	12D
0005433716159	7438	46	12E
0005433716184	7438	47	12F
0005433716147	7438	48	13B
0005433716151	7438	49	13C
0005432428891	7438	50	13D
0005433688816	7438	51	13E
0005433716160	7438	52	13F
0005432078132	7438	53	14B
0005433716183	7438	54	14A
0005433656683	7438	55	14C
0005435266112	7438	56	14D
0005433716162	7438	57	14E
0005433716187	7438	58	15A
0005432078128	7438	59	15C
0005433719151	7438	60	15E
0005432078129	7438	61	16B
0005433716156	7438	62	16D
0005433716144	7438	63	17A
0005433716149	7438	64	17B
0005433722239	7438	65	17C
0005433719152	7438	66	17D
0005433716164	7438	67	17F
0005433716177	7438	68	18D
0005435266119	7438	69	19B
0005433716143	7438	70	19D
0005433716182	7438	71	20A
0005433716176	7438	72	20C
0005433716154	7438	73	20B
0005433716166	7438	74	20D
0005433716190	7438	75	20E
0005433722244	7438	76	20F
0005433716188	7438	77	21B
0005432078131	7438	78	21A
0005433656681	7438	79	21C
0005433716170	7438	80	21D
0005433656682	7438	81	21E
0005433722245	7438	82	22B
0005432078130	7438	83	22A
0005433716142	7438	84	22C
0005433716157	7438	85	22D
0005433689918	7438	86	22E
0005433716179	7438	87	23A
0005433716167	7438	88	22F
0005433716175	7438	89	23B
0005433716181	7438	90	23C
0005433722237	7438	91	23F
0005435266120	7438	92	23E
0005433656647	29219	1	1A
0005433715762	29219	2	1D
0005433715686	29219	3	2A
0005433715932	29219	4	2D
0005432428942	29219	5	2F
0005433715716	29219	6	3A
0005433715650	29219	7	3D
0005433715750	29219	8	3F
0005433715717	29219	9	4B
0005433715721	29219	10	4A
0005433715536	29219	11	4E
0005433715673	29219	12	5A
0005433715672	29219	13	5C
0005433715751	29219	14	5B
0005433715967	29219	15	5D
0005433715767	29219	16	5E
0005433715859	29219	17	5F
0005433715623	29219	18	6C
0005433715692	29219	19	6B
0005433715579	29219	20	7A
0005433719117	29219	21	6F
0005433715902	29219	22	7D
0005433715469	29219	23	7C
0005433715736	29219	24	7F
0005433685518	29219	25	7E
0005433715757	29219	26	8A
0005433715759	29219	27	8B
0005433715843	29219	28	8C
0005433719138	29219	29	8D
0005433715680	29219	30	8E
0005433715885	29219	31	9A
0005433656653	29219	32	9B
0005433715808	29219	33	9C
0005432006774	29219	34	9E
0005433715748	29219	35	10C
0005433715931	29219	36	10E
0005432006773	29219	37	10D
0005433715597	29219	38	11B
0005433715508	29219	39	11E
0005433715747	29219	40	11F
0005433715730	29219	41	12A
0005433715758	29219	42	12D
0005433715968	29219	43	12E
0005433715824	29219	44	12F
0005433715822	29219	45	13B
0005433715705	29219	46	13C
0005433715842	29219	47	13D
0005433715847	29219	48	13F
0005433719130	29219	49	14A
0005433685517	29219	50	14C
0005433715854	29219	51	14B
0005433715809	29219	52	14E
0005433715468	29219	53	14F
0005433715520	29219	54	15B
0005433719119	29219	55	15C
0005433715760	29219	56	15D
0005433715827	29219	57	15F
0005433715856	29219	58	15E
0005432428943	29219	59	16A
0005433715971	29219	60	16B
0005433715683	29219	61	16C
0005433719127	29219	62	16E
0005433719116	29219	63	16D
0005433722170	29219	64	16F
0005432006772	29219	65	17B
0005432428944	29219	66	17A
0005432006771	29219	67	17F
0005433715884	29219	68	18A
0005433715682	29219	69	18B
0005433715855	29219	70	18E
0005433715702	29219	71	18D
0005433715701	29219	72	18F
0005433715761	29219	73	19A
0005433656634	29219	74	19B
0005433715814	29219	75	19D
0005433715681	29219	76	19F
0005433715915	29219	77	20B
0005433715549	29219	78	20C
0005433715582	29219	79	20E
0005433715596	29219	80	21B
0005433715725	29219	81	21A
0005433715815	29219	82	21C
0005433715467	29219	83	22A
0005433719139	29219	84	22B
0005433715825	29219	85	22D
0005433715882	29219	86	22F
0005433715844	29219	87	23B
0005433715834	29219	88	23D
0005433656645	29219	89	23F
0005433715749	29219	90	23E
0005434095327	8654	1	1C
0005434182096	8654	2	2A
0005434095330	8654	3	2D
0005434095329	8654	4	3A
0005434095338	8654	5	3C
0005434095332	8654	6	3D
0005434095339	8654	7	5E
0005434095325	8654	8	6C
0005434182105	8654	9	6F
0005434182160	8654	10	7C
0005434182115	8654	11	7D
0005434095337	8654	12	7F
0005434182150	8654	13	8C
0005434095328	8654	14	9D
0005434182121	8654	15	9F
0005434182177	8654	16	10D
0005434095331	8654	17	14E
0005434095333	8654	18	14F
0005434182151	8654	19	15F
0005434095335	8654	20	17D
0005434182116	8654	21	17F
0005434095336	8654	22	19C
0005434182090	8654	23	19E
0005434095334	8654	24	20D
0005434095326	8654	25	20F
0005434182238	11626	1	2A
0005434095217	11626	2	3A
0005434095208	11626	3	3F
0005434095225	11626	4	4E
0005434095246	11626	5	6A
0005434183586	11626	6	6C
0005434095245	11626	7	8A
0005434095207	11626	8	8E
0005434182237	11626	9	8F
0005434182233	11626	10	9A
0005434182234	11626	11	9E
0005434182236	11626	12	9F
0005434182230	11626	13	10A
0005434095268	11626	14	10D
0005434182231	11626	15	10F
0005434182239	11626	16	11C
0005434182240	11626	17	11E
0005434095218	11626	18	12A
0005434095236	11626	19	13D
0005434095291	11626	20	13E
0005434095238	11626	21	14E
0005434182232	11626	22	15A
0005434095224	11626	23	15E
0005434095237	11626	24	15F
0005434184672	11626	25	16D
0005434143721	11626	26	16E
0005434095239	11626	27	16F
0005434095195	11626	28	17A
0005434182229	11626	29	17E
0005434184671	11626	30	18A
0005434095219	11626	31	19C
0005434182235	11626	32	19E
0005433397913	1439	1	1C
0005433397590	1439	2	1F
0005435732382	1439	3	2A
0005433397810	1439	4	2C
0005433397803	1439	5	2D
0005433397747	1439	6	2F
0005435732368	1439	7	3A
0005435732388	1439	8	3D
0005432906534	1439	9	3F
0005435732370	1439	10	4A
0005433397997	1439	11	4E
0005433397925	1439	12	5A
0005435732379	1439	13	5E
0005433456986	1439	14	5F
0005433397904	1439	15	6A
0005433397833	1439	16	6D
0005435732375	1439	17	6E
0005433397735	1439	18	7C
0005435732367	1439	19	7D
0005433397915	1439	20	8A
0005433397652	1439	21	8C
0005435732380	1439	22	8D
0005433397922	1439	23	8E
0005433397927	1439	24	9A
0005435732389	1439	25	9C
0005433397983	1439	26	9D
0005433397897	1439	27	9E
0005435732385	1439	28	9F
0005433397737	1439	29	10A
0005433397928	1439	30	10C
0005433398004	1439	31	10D
0005433397795	1439	32	10E
0005433456984	1439	33	10F
0005435732372	1439	34	11A
0005433398022	1439	35	11D
0005435732374	1439	36	11F
0005435732378	1439	37	12A
0005435732387	1439	38	12C
0005435732366	1439	39	12D
0005433397921	1439	40	12E
0005433397829	1439	41	12F
0005433397919	1439	42	13A
0005433456987	1439	43	13C
0005433397769	1439	44	13D
0005435732377	1439	45	13E
0005433397662	1439	46	13F
0005435732383	1439	47	14A
0005432906517	1439	48	14C
0005433397805	1439	49	14D
0005433397825	1439	50	14F
0005435732384	1439	51	15A
0005433397797	1439	52	15E
0005433397832	1439	53	15F
0005433397748	1439	54	16A
0005433397802	1439	55	16C
0005433397853	1439	56	16E
0005433397914	1439	57	16F
0005433397796	1439	58	17A
0005433397834	1439	59	17C
0005435732369	1439	60	17D
0005435732386	1439	61	17E
0005433397553	1439	62	17F
0005435732381	1439	63	18A
0005433456985	1439	64	18D
0005435732373	1439	65	18E
0005433397541	1439	66	18F
0005433398031	1439	67	19A
0005433397824	1439	68	19C
0005433397982	1439	69	19D
0005433397955	1439	70	19E
0005435732371	1439	71	19F
0005433397898	1439	72	20A
0005435732376	1439	73	20C
0005433397961	1439	74	20D
0005433397926	1439	75	20E
0005433398236	19257	1	1A
0005433398269	19257	2	1D
0005433398228	19257	3	1F
0005435732286	19257	4	2A
0005433398237	19257	5	2C
0005433398267	19257	6	3A
0005433398242	19257	7	3C
0005435732273	19257	8	3D
0005433398268	19257	9	3F
0005432906548	19257	10	4E
0005433398255	19257	11	4F
0005433398240	19257	12	5A
0005433398253	19257	13	5D
0005435732278	19257	14	5F
0005433398231	19257	15	6A
0005433398230	19257	16	7A
0005433398248	19257	17	7D
0005433398271	19257	18	7F
0005432906547	19257	19	8C
0005433398224	19257	20	8F
0005433398261	19257	21	9A
0005433398234	19257	22	9C
0005433398262	19257	23	9D
0005435732272	19257	24	9E
0005435732248	19257	25	9F
0005433398257	19257	26	10A
0005433398233	19257	27	10D
0005432906546	19257	28	10F
0005433398252	19257	29	11E
0005433398264	19257	30	11F
0005433398270	19257	31	12A
0005433398243	19257	32	12C
0005435732245	19257	33	12D
0005433398241	19257	34	12E
0005435732243	19257	35	12F
0005433398245	19257	36	13A
0005433398259	19257	37	13C
0005435732215	19257	38	13D
0005435732214	19257	39	13F
0005433398251	19257	40	14C
0005433398225	19257	41	14D
0005433398238	19257	42	14E
0005435732257	19257	43	14F
0005435732279	19257	44	15A
0005435732244	19257	45	15C
0005433398229	19257	46	15D
0005432906545	19257	47	15E
0005433398244	19257	48	16A
0005433398265	19257	49	16C
0005433398263	19257	50	16E
0005433398249	19257	51	16F
0005433398232	19257	52	17C
0005433398226	19257	53	17A
0005435732277	19257	54	17D
0005433398246	19257	55	17E
0005433398266	19257	56	17F
0005435732311	19257	57	18C
0005433398239	19257	58	18E
0005433398254	19257	59	18F
0005433398256	19257	60	19A
0005433398247	19257	61	19C
0005433398260	19257	62	19D
0005432906544	19257	63	19E
0005433398227	19257	64	20C
0005433398250	19257	65	20D
0005433398258	19257	66	20E
0005433398235	19257	67	20F
0005434443596	17361	1	1B
0005434443556	17361	2	1C
0005434443679	17361	3	1D
0005434443617	17361	4	2A
0005434443577	17361	5	2B
0005434443597	17361	6	2D
0005434443654	17361	7	3C
0005434443557	17361	8	3D
0005434443651	17361	9	5C
0005434443650	17361	10	6B
0005434443616	17361	11	6D
0005434443622	17361	12	7B
0005434443592	17361	13	7C
0005434443689	17361	14	7D
0005434443608	17361	15	21A
0005434443522	17361	16	21C
0005434443602	17361	17	21D
0005434443690	17361	18	22C
0005434443675	17361	19	23B
0005434443764	20564	1	1A
0005434443769	20564	2	1C
0005434443755	20564	3	1D
0005434443756	20564	4	2B
0005434443762	20564	5	3A
0005434443768	20564	6	3C
0005434443766	20564	7	5A
0005434443765	20564	8	5C
0005434443770	20564	9	6C
0005434443759	20564	10	7A
0005434443757	20564	11	7C
0005434443758	20564	12	18A
0005434443760	20564	13	19C
0005434443761	20564	14	20A
0005434443763	20564	15	20C
0005434443767	20564	16	23A
0005434954623	7282	1	2A
0005434954626	7282	2	2B
0005434954625	7282	3	3A
0005434954622	7282	4	4B
0005434954624	7282	5	6B
0005435377590	28334	1	1A
0005435377588	28334	2	2A
0005434954594	28334	3	3A
0005434954600	28334	4	3B
0005435377589	28334	5	4B
0005434954580	28334	6	6A
0005434326272	4471	1	1C
0005435893571	4471	2	1D
0005434183578	4471	3	2A
0005435893579	4471	4	2B
0005434326273	4471	5	2C
0005434351744	4471	6	2D
0005435893623	4471	7	3D
0005434351746	4471	8	4A
0005434351750	4471	9	5A
0005434351751	4471	10	5B
0005434351743	4471	11	6A
0005434351748	4471	12	6B
0005434351740	4471	13	7D
0005434351745	4471	14	18B
0005435893630	4471	15	18C
0005435893624	4471	16	18D
0005434351747	4471	17	19B
0005434351749	4471	18	20B
0005435893620	4471	19	21A
0005434183572	4471	20	21C
0005434351742	4471	21	21D
0005435893631	4471	22	22B
0005434351741	4471	23	22C
0005434351671	29664	1	1A
0005435893656	29664	2	1D
0005435893661	29664	3	2B
0005434351663	29664	4	3C
0005434351673	29664	5	3D
0005435893660	29664	6	4D
0005435893658	29664	7	7C
0005435893662	29664	8	18B
0005434351672	29664	9	20B
0005434351654	29664	10	21B
0005435893659	29664	11	21D
0005434351655	29664	12	22A
0005435893657	29664	13	22C
0005434446526	1067	1	1A
0005433342524	1067	2	1C
0005433269678	1067	3	1H
0005433342880	1067	4	2A
0005435092114	1067	5	3A
0005433341823	1067	6	2H
0005433463909	1067	7	3B
0005433342904	1067	8	3F
0005433342489	1067	9	3C
0005433342554	1067	10	3G
0005433342530	1067	11	4A
0005433342311	1067	12	4B
0005433342903	1067	13	4F
0005435092109	1067	14	4C
0005433342885	1067	15	5F
0005435092110	1067	16	5H
0005433342697	1067	17	9H
0005434446528	1067	18	9G
0005432293219	1067	19	9B
0005433342394	1067	20	11B
0005435092113	1067	21	11F
0005433462754	1067	22	11H
0005433342604	1067	23	12A
0005433342525	1067	24	12D
0005433463908	1067	25	12B
0005433342907	1067	26	12E
0005433342740	1067	27	12G
0005433342533	1067	28	13A
0005433342614	1067	29	12H
0005433342692	1067	30	13D
0005433342443	1067	31	13E
0005433342098	1067	32	13G
0005433159299	1067	33	13F
0005433342947	1067	34	14B
0005433342870	1067	35	14A
0005433342717	1067	36	14D
0005433342400	1067	37	14F
0005433342652	1067	38	14E
0005433269702	1067	39	14G
0005433269681	1067	40	15A
0005433342599	1067	41	15B
0005433269679	1067	42	15D
0005433342313	1067	43	15G
0005433342184	1067	44	16A
0005433342575	1067	45	15H
0005433342457	1067	46	16B
0005433342613	1067	47	16G
0005433342503	1067	48	16F
0005433342471	1067	49	16H
0005432293217	1067	50	17A
0005433342470	1067	51	17B
0005433342587	1067	52	17E
0005433342629	1067	53	17G
0005433342884	1067	54	17H
0005433342442	1067	55	18A
0005433342675	1067	56	18E
0005434446527	1067	57	18D
0005433342565	1067	58	18B
0005433342441	1067	59	18G
0005433342203	1067	60	19B
0005433342202	1067	61	19A
0005433462756	1067	62	19D
0005433342650	1067	63	19F
0005433342869	1067	64	19G
0005433342532	1067	65	20B
0005433342888	1067	66	20D
0005433342796	1067	67	20G
0005435092116	1067	68	20F
0005433342399	1067	69	21A
0005433342546	1067	70	21B
0005433341893	1067	71	21G
0005433342707	1067	72	21H
0005433342905	1067	73	22D
0005433342220	1067	74	22E
0005433343211	1067	75	22F
0005433342628	1067	76	23B
0005433342488	1067	77	24A
0005433342795	1067	78	23H
0005433342889	1067	79	24D
0005433342492	1067	80	24G
0005433342930	1067	81	24H
0005435092112	1067	82	25F
0005433341824	1067	83	27A
0005433342545	1067	84	27E
0005433342152	1067	85	28A
0005433159300	1067	86	27H
0005433342551	1067	87	28D
0005435545768	1067	88	28F
0005433269701	1067	89	29A
0005435092111	1067	90	29D
0005433342487	1067	91	29B
0005433463910	1067	92	29E
0005433342881	1067	93	29F
0005433342850	1067	94	29H
0005433342949	1067	95	30E
0005433342151	1067	96	30G
0005433342781	1067	97	31A
0005433342620	1067	98	30H
0005433342002	1067	99	31B
0005433342431	1067	100	31D
0005433342097	1067	101	31F
0005433342322	1067	102	31E
0005433342415	1067	103	31G
0005433342206	1067	104	31H
0005435545769	1067	105	32D
0005433342522	1067	106	32B
0005433342693	1067	107	32E
0005433342609	1067	108	32F
0005433342648	1067	109	33A
0005433342882	1067	110	32H
0005434446525	1067	111	33E
0005432293218	1067	112	33D
0005433343212	1067	113	33G
0005433342586	1067	114	34A
0005433342223	1067	115	34D
0005435092117	1067	116	34E
0005433342502	1067	117	34G
0005433342414	1067	118	34H
0005433342948	1067	119	35D
0005433342780	1067	120	35H
0005433342001	1067	121	36B
0005433342879	1067	122	36E
0005435092115	1067	123	36F
0005433342674	1067	124	36H
0005433342791	1067	125	36G
0005433462755	1067	126	37D
0005433342624	1067	127	37E
0005433343205	1067	128	38A
0005433342133	1067	129	38D
0005435092108	1067	130	38B
0005433342906	1067	131	38H
0005433342787	1067	132	39E
0005433343434	17048	1	1A
0005433343416	17048	2	1C
0005435092067	17048	3	1G
0005433343430	17048	4	2A
0005433343423	17048	5	2C
0005433159321	17048	6	2B
0005433159320	17048	7	2F
0005433269737	17048	8	3A
0005433343491	17048	9	2H
0005435508259	17048	10	3C
0005433343497	17048	11	3G
0005434445235	17048	12	3F
0005433343437	17048	13	4B
0005433343478	17048	14	4A
0005434445226	17048	15	4G
0005433343417	17048	16	5A
0005433343440	17048	17	4H
0005435092039	17048	18	5B
0005434445233	17048	19	5C
0005433343419	17048	20	9H
0005435508320	17048	21	9G
0005433343460	17048	22	11B
0005433343467	17048	23	11A
0005433343508	17048	24	11E
0005433343480	17048	25	11F
0005433343414	17048	26	11H
0005433343459	17048	27	11G
0005433343481	17048	28	12A
0005433343494	17048	29	12B
0005435508294	17048	30	12E
0005433343448	17048	31	12F
0005433343449	17048	32	12H
0005433343439	17048	33	12G
0005433343498	17048	34	13A
0005433343420	17048	35	13G
0005435508308	17048	36	13F
0005433343514	17048	37	14F
0005433343495	17048	38	14E
0005433343477	17048	39	14H
0005435508362	17048	40	15B
0005435508319	17048	41	15A
0005433343482	17048	42	15E
0005435508341	17048	43	15H
0005435508307	17048	44	16D
0005433343458	17048	45	17A
0005433343426	17048	46	17B
0005433343428	17048	47	17D
0005433343507	17048	48	17F
0005433343446	17048	49	17G
0005433343433	17048	50	17H
0005433343465	17048	51	18B
0005433343474	17048	52	18F
0005433343483	17048	53	18H
0005433343442	17048	54	19B
0005433343503	17048	55	19F
0005433343425	17048	56	19G
0005434445237	17048	57	19H
0005433343486	17048	58	20E
0005433343415	17048	59	20D
0005435092020	17048	60	20F
0005433343511	17048	61	20H
0005433343512	17048	62	20G
0005433343429	17048	63	21B
0005433343421	17048	64	21E
0005433343513	17048	65	21G
0005433343466	17048	66	21F
0005433343476	17048	67	21H
0005433343501	17048	68	22B
0005433343487	17048	69	22E
0005433343445	17048	70	22F
0005433269741	17048	71	23A
0005433343469	17048	72	23D
0005433343462	17048	73	23F
0005433343489	17048	74	23G
0005433343500	17048	75	24A
0005433343447	17048	76	24B
0005435092038	17048	77	24D
0005433343492	17048	78	24G
0005433343424	17048	79	25D
0005433343443	17048	80	24H
0005435508281	17048	81	25E
0005433343427	17048	82	27B
0005433343450	17048	83	27F
0005435508321	17048	84	27E
0005433269740	17048	85	27H
0005435508336	17048	86	28A
0005435508278	17048	87	28D
0005433343484	17048	88	28E
0005433343441	17048	89	29D
0005433343422	17048	90	29B
0005433343435	17048	91	29E
0005433343438	17048	92	30B
0005433343472	17048	93	30D
0005433343493	17048	94	30E
0005433343505	17048	95	30H
0005433343479	17048	96	31B
0005433343431	17048	97	31A
0005433343454	17048	98	31E
0005433343456	17048	99	31G
0005433269738	17048	100	32A
0005433343453	17048	101	31H
0005433343436	17048	102	32B
0005433343510	17048	103	32E
0005433269739	17048	104	33D
0005433343451	17048	105	33B
0005435508295	17048	106	33E
0005433343452	17048	107	33F
0005433343490	17048	108	33H
0005433343470	17048	109	33G
0005433343457	17048	110	34A
0005435508289	17048	111	34D
0005433343473	17048	112	34B
0005435508282	17048	113	34E
0005433343464	17048	114	35A
0005433343509	17048	115	34H
0005433343502	17048	116	35D
0005433343432	17048	117	35E
0005433343485	17048	118	35F
0005433343471	17048	119	35H
0005433343506	17048	120	36B
0005433343444	17048	121	36D
0005433343461	17048	122	36G
0005433343488	17048	123	37A
0005434445234	17048	124	36H
0005433343455	17048	125	37D
0005433343463	17048	126	37F
0005433343499	17048	127	38A
0005433343468	17048	128	38B
0005434445227	17048	129	38E
0005433343504	17048	130	38D
0005433343496	17048	131	38G
0005433343418	17048	132	38F
0005433343475	17048	133	39F
0005435508322	17048	134	39E
0005432390001	18264	1	1C
0005432390044	18264	2	1F
0005432390039	18264	3	2A
0005432390093	18264	4	2D
0005432391977	18264	5	2C
0005432390050	18264	6	3C
0005432390118	18264	7	4A
0005432851930	18264	8	4D
0005432390034	18264	9	4C
0005432851933	18264	10	4F
0005432391971	18264	11	5F
0005432391985	18264	12	6B
0005432390018	18264	13	6A
0005432390067	18264	14	6D
0005432390058	18264	15	6C
0005432391975	18264	16	6E
0005432390073	18264	17	7A
0005432391984	18264	18	7C
0005432391990	18264	19	8A
0005432390047	18264	20	7F
0005432390109	18264	21	8E
0005432390077	18264	22	8D
0005432391976	18264	23	8C
0005432851940	18264	24	8F
0005432851949	18264	25	9A
0005432390092	18264	26	9C
0005432851946	18264	27	9E
0005432851928	18264	28	10B
0005432389974	18264	29	10D
0005432390131	18264	30	10F
0005432390064	18264	31	10E
0005432391973	18264	32	11B
0005432390076	18264	33	11D
0005432390000	18264	34	11C
0005432391970	18264	35	11F
0005432391968	18264	36	11E
0005432851927	18264	37	12B
0005432851937	18264	38	12A
0005432851941	18264	39	12D
0005432390024	18264	40	12C
0005432390059	18264	41	12E
0005432851934	18264	42	13A
0005432390049	18264	43	13B
0005432851929	18264	44	13D
0005432390075	18264	45	14A
0005432390114	18264	46	13F
0005432851948	18264	47	14C
0005432851947	18264	48	14B
0005432390057	18264	49	14D
0005432851944	18264	50	14F
0005432390133	18264	51	14E
0005432390119	18264	52	15B
0005432390046	18264	53	15D
0005432390132	18264	54	16B
0005432851932	18264	55	16C
0005432390080	18264	56	16E
0005432390011	18264	57	16D
0005432391991	18264	58	17D
0005432851926	18264	59	18B
0005432851939	18264	60	18A
0005432390048	18264	61	17F
0005432391969	18264	62	18C
0005432851945	18264	63	18E
0005432391974	18264	64	19A
0005432391979	18264	65	18F
0005432389980	18264	66	19C
0005432851943	18264	67	19B
0005432390117	18264	68	19D
0005432851931	18264	69	19E
0005432851938	18264	70	20F
0005432851935	18264	71	21A
0005432391978	18264	72	21C
0005432851942	18264	73	21B
0005432851936	18264	74	21D
0005432390045	18264	75	21F
0005434067239	12779	1	1A
0005432159877	12779	2	1D
0005433812910	12779	3	1C
0005434067083	12779	4	1F
0005434067009	12779	5	2C
0005434067024	12779	6	2A
0005432159876	12779	7	2D
0005434067470	12779	8	2F
0005434067088	12779	9	3C
0005434067393	12779	10	3A
0005434067347	12779	11	3D
0005434081777	12779	12	3F
0005434081745	12779	13	4B
0005434067193	12779	14	4A
0005434067156	12779	15	4D
0005434067308	12779	16	4C
0005434067288	12779	17	4E
0005434067201	12779	18	5A
0005434081724	12779	19	4F
0005434067403	12779	20	5B
0005434067256	12779	21	5D
0005432159875	12779	22	5E
0005434067034	12779	23	6A
0005434066981	12779	24	5F
0005432161162	12779	25	6C
0005434067469	12779	26	6B
0005434066911	12779	27	6D
0005434066929	12779	28	6E
0005434081813	12779	29	7A
0005434067068	12779	30	6F
0005434081786	12779	31	7B
0005434067200	12779	32	7C
0005434067025	12779	33	7D
0005434067087	12779	34	7F
0005434067023	12779	35	8A
0005434081685	12779	36	8C
0005432433702	12779	37	8D
0005434067494	12779	38	8F
0005434066979	12779	39	8E
0005434067299	12779	40	9A
0005434067476	12779	41	9B
0005432433698	12779	42	9C
0005434067033	12779	43	9E
0005434067394	12779	44	9D
0005434081713	12779	45	9F
0005434066978	12779	46	10B
0005433989750	12779	47	10C
0005434081712	12779	48	10D
0005434081696	12779	49	11A
0005432433703	12779	50	10E
0005434067346	12779	51	11B
0005434067436	12779	52	11C
0005434026692	12779	53	11D
0005434081684	12779	54	12A
0005434067202	12779	55	11E
0005433989731	12779	56	12B
0005434067102	12779	57	12D
0005434066910	12779	58	12C
0005434067032	12779	59	12E
0005434067074	12779	60	12F
0005434067133	12779	61	13B
0005434067307	12779	62	13A
0005432433701	12779	63	13C
0005434067108	12779	64	13E
0005434067158	12779	65	13D
0005434067198	12779	66	13F
0005434067370	12779	67	14B
0005432159878	12779	68	14A
0005434067130	12779	69	14D
0005434066989	12779	70	14C
0005434081779	12779	71	14E
0005434067103	12779	72	14F
0005432433699	12779	73	15B
0005434067161	12779	74	15A
0005434081640	12779	75	15C
0005434081785	12779	76	15D
0005433989730	12779	77	15F
0005434067287	12779	78	15E
0005434081815	12779	79	16A
0005434067160	12779	80	16B
0005434081793	12779	81	16C
0005434067035	12779	82	16D
0005434067148	12779	83	16E
0005434081689	12779	84	17A
0005433989739	12779	85	16F
0005434081792	12779	86	17B
0005434067404	12779	87	17D
0005432433700	12779	88	17C
0005434081782	12779	89	17F
0005434081814	12779	90	17E
0005434067121	12779	91	18A
0005434067455	12779	92	18B
0005434067356	12779	93	18C
0005434067306	12779	94	18D
0005433989732	12779	95	18F
0005434067044	12779	96	18E
0005434067112	12779	97	19B
0005432161161	12779	98	19D
0005434067223	12779	99	19C
0005434066990	12779	100	19E
0005434081780	12779	101	19F
0005434066770	12779	102	20A
0005434067107	12779	103	20B
0005434067419	12779	104	20D
0005434081781	12779	105	20C
0005434067218	12779	106	20E
0005434067495	12779	107	20F
0005434067109	12779	108	21B
0005434067199	12779	109	21A
0005432161160	12779	110	21C
0005434066901	12779	111	21D
0005434067186	12779	112	21E
0005433989738	12779	113	22A
0005434067241	12779	114	21F
0005434081741	12779	115	22B
0005432159874	12779	116	22C
0005434067207	12779	117	22D
0005434067310	12779	118	22F
0005434067298	12779	119	22E
0005434081639	12779	120	23A
0005434081725	12779	121	23C
0005434066991	12779	122	23B
0005434026691	12779	123	23D
0005434066909	12779	124	23F
0005434067754	30664	1	1A
0005434081983	30664	2	1C
0005434067816	30664	3	1D
0005434067785	30664	4	2A
0005432433626	30664	5	1F
0005434067770	30664	6	2C
0005432150220	30664	7	2D
0005434067795	30664	8	2F
0005434067775	30664	9	3A
0005434081957	30664	10	3D
0005434081965	30664	11	3C
0005434081966	30664	12	3F
0005434067804	30664	13	4B
0005434081971	30664	14	4A
0005434067769	30664	15	4D
0005434067761	30664	16	4C
0005434067809	30664	17	4E
0005432150215	30664	18	4F
0005434067757	30664	19	5A
0005434067793	30664	20	5C
0005432150217	30664	21	5B
0005434067790	30664	22	5D
0005434067817	30664	23	5E
0005434081960	30664	24	5F
0005434067801	30664	25	6B
0005434067753	30664	26	6A
0005434081979	30664	27	6C
0005434081984	30664	28	6D
0005434081975	30664	29	6F
0005434067776	30664	30	6E
0005434067748	30664	31	7A
0005434081980	30664	32	7B
0005434067810	30664	33	7C
0005434067758	30664	34	7D
0005434081954	30664	35	7E
0005434067772	30664	36	8A
0005434067765	30664	37	7F
0005434081955	30664	38	8B
0005434081958	30664	39	8C
0005434067763	30664	40	8E
0005434067818	30664	41	8D
0005432186881	30664	42	8F
0005434067777	30664	43	9A
0005432433659	30664	44	9B
0005434067756	30664	45	9C
0005434067760	30664	46	9D
0005433989783	30664	47	9F
0005434067805	30664	48	9E
0005434081981	30664	49	10C
0005434067812	30664	50	10B
0005434081967	30664	51	10D
0005432433679	30664	52	11A
0005434067767	30664	53	10E
0005434081969	30664	54	11B
0005434067774	30664	55	11C
0005434081978	30664	56	11E
0005434067806	30664	57	11D
0005434067768	30664	58	11F
0005434067771	30664	59	12B
0005434067783	30664	60	12C
0005434081963	30664	61	12D
0005434067766	30664	62	12E
0005434067773	30664	63	13A
0005434067792	30664	64	13B
0005434081959	30664	65	13D
0005434067789	30664	66	13C
0005434067787	30664	67	13E
0005434081968	30664	68	14A
0005432150222	30664	69	13F
0005434067779	30664	70	14B
0005434067811	30664	71	14C
0005434067815	30664	72	14D
0005434067786	30664	73	14E
0005434067796	30664	74	14F
0005432433677	30664	75	15B
0005434067797	30664	76	15A
0005432150221	30664	77	15D
0005434067750	30664	78	15C
0005432150219	30664	79	15F
0005434081962	30664	80	15E
0005434081973	30664	81	16A
0005433989786	30664	82	16D
0005434067802	30664	83	16C
0005434081970	30664	84	16B
0005434067800	30664	85	16F
0005434067794	30664	86	17B
0005432433678	30664	87	17C
0005432433666	30664	88	17E
0005434067762	30664	89	17D
0005434081974	30664	90	17F
0005434067751	30664	91	18A
0005434081961	30664	92	18B
0005434067755	30664	93	18D
0005432150218	30664	94	18C
0005434067782	30664	95	18E
0005434067798	30664	96	19A
0005434067747	30664	97	18F
0005433989785	30664	98	19B
0005432150216	30664	99	19D
0005434067780	30664	100	19C
0005434067764	30664	101	19E
0005434081972	30664	102	19F
0005434067788	30664	103	20B
0005432433643	30664	104	20A
0005433989787	30664	105	20C
0005434067799	30664	106	20E
0005434067803	30664	107	20D
0005434081982	30664	108	20F
0005434081977	30664	109	21B
0005434067791	30664	110	21A
0005434067752	30664	111	21C
0005434067814	30664	112	21D
0005434067759	30664	113	21E
0005434067784	30664	114	21F
0005434067749	30664	115	22A
0005434067778	30664	116	22C
0005434081964	30664	117	22B
0005434067819	30664	118	22D
0005434067781	30664	119	22F
0005434081956	30664	120	22E
0005434067808	30664	121	23A
0005433989784	30664	122	23B
0005434067807	30664	123	23C
0005434067813	30664	124	23F
0005434081976	30664	125	23E
0005433686617	19363	1	1A
0005433689902	19363	2	1B
0005433686603	19363	3	1C
0005433689890	19363	4	1D
0005433689900	19363	5	2A
0005433686612	19363	6	2D
0005433686610	19363	7	3C
0005433686618	19363	8	4A
0005433689894	19363	9	6A
0005433689903	19363	10	6B
0005433689905	19363	11	7A
0005433689897	19363	12	7D
0005433689891	19363	13	18C
0005433686616	19363	14	18D
0005433689904	19363	15	19A
0005433686611	19363	16	19C
0005433689892	19363	17	19D
0005433686613	19363	18	20C
0005433689896	19363	19	20D
0005433686621	19363	20	21B
0005433689893	19363	21	21D
0005433686627	19363	22	22B
0005433689895	19363	23	22C
0005433686615	19363	24	23A
0005433686622	19363	25	23B
0005435725614	5526	1	1A
0005435462228	5526	2	1B
0005435462230	5526	3	1F
0005435766490	5526	4	1C
0005432140476	5526	5	1H
0005434831112	5526	6	1G
0005435766440	5526	7	2A
0005434264957	5526	8	2F
0005434831120	5526	9	2C
0005435766434	5526	10	3A
0005435462209	5526	11	2H
0005435462227	5526	12	3B
0005434265056	5526	13	3C
0005435766450	5526	14	3G
0005434264982	5526	15	4A
0005435766487	5526	16	3H
0005435462087	5526	17	4B
0005435462363	5526	18	4C
0005435462201	5526	19	4G
0005435766503	5526	20	4H
0005435766470	5526	21	5B
0005435725616	5526	22	5C
0005435766442	5526	23	5G
0005435766432	5526	24	5H
0005434264956	5526	25	9B
0005435766427	5526	26	9H
0005434264979	5526	27	9G
0005435766502	5526	28	11A
0005435766431	5526	29	11B
0005435766479	5526	30	11E
0005435462323	5526	31	11F
0005435766437	5526	32	12A
0005435462231	5526	33	11H
0005435462342	5526	34	12E
0005435462355	5526	35	12D
0005435766443	5526	36	12G
0005435766471	5526	37	12F
0005435766462	5526	38	13B
0005435462108	5526	39	13A
0005435766467	5526	40	13F
0005434831117	5526	41	13G
0005435766457	5526	42	14A
0005435462074	5526	43	13H
0005435722064	5526	44	14B
0005435462301	5526	45	14D
0005435766496	5526	46	14E
0005435766460	5526	47	14G
0005435462313	5526	48	14H
0005434831119	5526	49	15E
0005435766480	5526	50	15D
0005435766489	5526	51	15F
0005435766458	5526	52	15H
0005432535811	5526	53	15G
0005435766494	5526	54	16A
0005434264971	5526	55	16B
0005432140481	5526	56	16E
0005435766459	5526	57	16D
0005435735151	5526	58	16F
0005435735148	5526	59	16H
0005432140483	5526	60	16G
0005435766465	5526	61	17A
0005435766438	5526	62	17D
0005435766466	5526	63	17B
0005434264958	5526	64	17F
0005433529293	5526	65	17E
0005432140477	5526	66	18A
0005435766474	5526	67	17H
0005435766475	5526	68	18B
0005433529294	5526	69	18D
0005433527284	5526	70	18F
0005435722065	5526	71	18E
0005434264944	5526	72	18G
0005435462226	5526	73	19A
0005434265022	5526	74	18H
0005435462037	5526	75	19B
0005435735150	5526	76	19E
0005435766448	5526	77	19D
0005435462221	5526	78	19F
0005435462356	5526	79	19G
0005435766456	5526	80	19H
0005435462288	5526	81	20D
0005435462237	5526	82	20B
0005434831118	5526	83	20G
0005435725617	5526	84	21A
0005435766447	5526	85	20H
0005435735149	5526	86	21D
0005435766454	5526	87	21B
0005435766429	5526	88	21F
0005435766433	5526	89	21E
0005433527282	5526	90	21G
0005435766498	5526	91	21H
0005434265057	5526	92	22A
0005435766499	5526	93	22D
0005435766469	5526	94	22E
0005435766444	5526	95	22G
0005434265082	5526	96	23B
0005435462211	5526	97	23D
0005435766492	5526	98	23F
0005435766491	5526	99	23E
0005435766493	5526	100	23G
0005434264995	5526	101	23H
0005435766441	5526	102	24B
0005435462210	5526	103	24A
0005435462364	5526	104	24E
0005435462167	5526	105	24D
0005434264884	5526	106	24H
0005432140479	5526	107	24G
0005432140480	5526	108	25E
0005432140482	5526	109	27A
0005435462343	5526	110	27B
0005432535810	5526	111	27E
0005435462086	5526	112	27D
0005435766483	5526	113	27F
0005432535804	5526	114	27H
0005435766428	5526	115	27G
0005434264919	5526	116	28A
0005432140478	5526	117	28B
0005435766436	5526	118	28D
0005435766430	5526	119	28E
0005435766473	5526	120	28G
0005435766446	5526	121	29A
0005435766455	5526	122	28H
0005435462222	5526	123	29D
0005435725615	5526	124	29B
0005434264983	5526	125	29E
0005434264918	5526	126	29G
0005435462311	5526	127	29F
0005435766482	5526	128	30A
0005435766495	5526	129	30D
0005435462238	5526	130	30B
0005435462229	5526	131	30E
0005434264943	5526	132	30G
0005435766477	5526	133	30F
0005432535803	5526	134	30H
0005434265049	5526	135	31A
0005435766445	5526	136	31E
0005435766497	5526	137	31D
0005435766485	5526	138	31G
0005435766468	5526	139	32D
0005435735152	5526	140	32B
0005435766500	5526	141	32E
0005435766478	5526	142	32F
0005435766451	5526	143	32H
0005435766439	5526	144	32G
0005434265081	5526	145	33A
0005435462287	5526	146	33B
0005433527283	5526	147	33E
0005434831086	5526	148	33D
0005435766476	5526	149	33F
0005435722063	5526	150	33H
0005435723053	5526	151	34A
0005435766486	5526	152	34D
0005434265013	5526	153	34B
0005435766453	5526	154	34F
0005435043277	5526	155	34E
0005433529292	5526	156	34G
0005435766472	5526	157	35A
0005435462286	5526	158	34H
0005434265048	5526	159	35B
0005435722066	5526	160	35D
0005434831126	5526	161	35E
0005435462299	5526	162	35G
0005435766481	5526	163	36A
0005435462410	5526	164	35H
0005434264980	5526	165	36B
0005434831087	5526	166	36E
0005435766449	5526	167	36D
0005435766484	5526	168	36F
0005435766501	5526	169	36H
0005435766452	5526	170	36G
0005434264994	5526	171	37B
0005435462258	5526	172	37E
0005435766488	5526	173	37D
0005435766461	5526	174	37H
0005435462307	5526	175	37G
0005435766463	5526	176	38A
0005435766464	5526	177	38B
0005433529295	5526	178	38E
0005434265050	5526	179	38D
0005435766435	5526	180	38G
0005435725618	5526	181	38F
0005435462295	5526	182	39D
0005435765697	13494	1	1A
0005435462591	13494	2	1B
0005435462571	13494	3	1F
0005432535852	13494	4	1C
0005435462569	13494	5	1G
0005435765813	13494	6	2B
0005434265233	13494	7	2F
0005435462592	13494	8	2C
0005435765875	13494	9	2H
0005435766210	13494	10	2G
0005435765750	13494	11	3A
0005435765881	13494	12	3B
0005434265248	13494	13	3C
0005434831172	13494	14	3G
0005434265254	13494	15	3H
0005435765811	13494	16	4B
0005434265239	13494	17	4F
0005435766023	13494	18	4G
0005435462600	13494	19	5A
0005434265242	13494	20	4H
0005434831171	13494	21	5C
0005435725563	13494	22	5G
0005435765854	13494	23	5H
0005434265256	13494	24	9B
0005435765810	13494	25	9H
0005435462572	13494	26	9G
0005435765892	13494	27	11A
0005435462577	13494	28	11B
0005434265252	13494	29	11E
0005435765801	13494	30	11D
0005435462593	13494	31	11G
0005435765759	13494	32	11H
0005435765696	13494	33	12A
0005432194525	13494	34	12B
0005434831169	13494	35	12F
0005435766074	13494	36	12H
0005435765725	13494	37	12G
0005434265250	13494	38	13B
0005435766035	13494	39	13D
0005434265241	13494	40	13E
0005435043287	13494	41	13F
0005435462573	13494	42	14B
0005435462590	13494	43	14A
0005435765869	13494	44	14F
0005435462581	13494	45	14G
0005435765907	13494	46	15A
0005435723031	13494	47	14H
0005434265245	13494	48	15D
0005434265240	13494	49	16A
0005435765995	13494	50	15H
0005435765891	13494	51	16D
0005435765899	13494	52	16B
0005435462583	13494	53	16G
0005435462584	13494	54	16F
0005434265243	13494	55	16H
0005435765890	13494	56	17A
0005435462578	13494	57	17E
0005435765741	13494	58	17D
0005435462574	13494	59	17H
0005435765743	13494	60	18D
0005435722034	13494	61	18F
0005432535855	13494	62	18E
0005435462595	13494	63	18H
0005434265253	13494	64	19B
0005434265249	13494	65	19A
0005435462596	13494	66	19E
0005432194526	13494	67	19D
0005432535854	13494	68	19F
0005435765963	13494	69	19G
0005435765742	13494	70	20A
0005435462597	13494	71	19H
0005435765916	13494	72	20B
0005435766073	13494	73	20D
0005435765549	13494	74	20G
0005435462602	13494	75	21A
0005435766029	13494	76	20H
0005435765967	13494	77	21D
0005435766038	13494	78	21E
0005435725582	13494	79	21G
0005435462570	13494	80	21F
0005435765985	13494	81	22A
0005435766064	13494	82	21H
0005435462579	13494	83	22D
0005434265231	13494	84	22B
0005435722026	13494	85	22E
0005435765783	13494	86	22F
0005435766133	13494	87	23B
0005435766039	13494	88	23A
0005435462594	13494	89	23E
0005435765782	13494	90	23D
0005435765814	13494	91	23F
0005435462598	13494	92	24B
0005435765760	13494	93	24A
0005435765947	13494	94	24D
0005435462599	13494	95	24F
0005435725555	13494	96	24E
0005435765835	13494	97	24G
0005434265247	13494	98	24H
0005435766181	13494	99	25E
0005432535856	13494	100	25D
0005434831168	13494	101	27A
0005435766095	13494	102	25F
0005435765868	13494	103	27B
0005435462587	13494	104	27E
0005432194528	13494	105	27D
0005434265246	13494	106	27F
0005432535857	13494	107	27G
0005434265257	13494	108	28A
0005435766146	13494	109	27H
0005435766141	13494	110	28E
0005434831170	13494	111	28D
0005435765917	13494	112	28F
0005435722035	13494	113	28G
0005435462586	13494	114	29A
0005434265244	13494	115	29D
0005435735121	13494	116	29B
0005434265230	13494	117	29F
0005435462603	13494	118	29E
0005434265237	13494	119	29G
0005435766030	13494	120	30A
0005434265236	13494	121	30B
0005435766016	13494	122	30F
0005434265234	13494	123	30E
0005435765948	13494	124	30H
0005435765784	13494	125	31A
0005435725572	13494	126	31E
0005435462580	13494	127	31G
0005435043286	13494	128	31H
0005435765982	13494	129	32A
0005435462604	13494	130	32D
0005435765980	13494	131	32F
0005435766079	13494	132	32E
0005435765992	13494	133	32H
0005434265232	13494	134	33A
0005435766132	13494	135	33D
0005434265238	13494	136	33B
0005432535851	13494	137	33E
0005435765987	13494	138	33G
0005435765802	13494	139	33H
0005435765971	13494	140	34A
0005435765889	13494	141	34D
0005435765996	13494	142	34F
0005435765986	13494	143	34E
0005435766005	13494	144	34G
0005435765550	13494	145	34H
0005435765858	13494	146	35B
0005435462585	13494	147	35A
0005435765874	13494	148	35D
0005434265235	13494	149	35F
0005435765984	13494	150	35E
0005435462588	13494	151	35G
0005435722045	13494	152	36A
0005435462575	13494	153	35H
0005435722044	13494	154	36B
0005435765754	13494	155	36E
0005434265251	13494	156	36D
0005434831173	13494	157	36F
0005435765981	13494	158	36G
0005434265255	13494	159	37A
0005435462576	13494	160	36H
0005435462605	13494	161	37D
0005432535853	13494	162	37B
0005435765887	13494	163	37E
0005435462582	13494	164	37F
0005435725562	13494	165	37H
0005435766142	13494	166	38E
0005435765962	13494	167	38D
0005435765910	13494	168	38G
0005435765832	13494	169	38F
0005432194527	13494	170	38H
0005435462601	13494	171	39D
0005435462589	13494	172	39F
0005434602883	18724	1	2B
0005434602888	18724	2	4A
0005434602894	18724	3	5B
0005434602882	18724	4	6B
0005434604878	18723	1	1A
0005434513590	18723	2	1B
0005434513588	18723	3	2A
0005434513591	18723	4	2B
0005434513589	18723	5	3A
0005434604875	18723	6	3B
0005434514975	18723	7	4A
0005434604879	18723	8	4B
0005434604877	18723	9	5B
0005434514977	18723	10	6A
0005434514976	18723	11	6B
0005434602907	19205	1	2A
0005434602908	19205	2	1B
0005434602906	19205	3	2B
0005434514956	19205	4	3A
0005434602910	19205	5	3B
0005434514955	19205	6	4A
0005434514952	19205	7	4B
0005434602909	19205	8	5A
0005434602905	19205	9	5B
0005434514953	19205	10	6A
0005435844335	25093	1	1A
0005432649375	25093	2	1D
0005432632671	25093	3	2A
0005435844329	25093	4	2F
0005432649383	25093	5	3F
0005435844333	25093	6	4C
0005435844332	25093	7	4F
0005435844327	25093	8	5A
0005435846264	25093	9	5D
0005435846265	25093	10	6C
0005432649353	25093	11	6D
0005435846266	25093	12	6E
0005432632731	25093	13	6F
0005432649365	25093	14	7C
0005432632667	25093	15	7D
0005432649369	25093	16	7F
0005435846267	25093	17	8A
0005432649384	25093	18	8C
0005432649354	25093	19	8F
0005435846263	25093	20	9A
0005435844337	25093	21	9C
0005435844336	25093	22	9E
0005432632675	25093	23	9F
0005432632699	25093	24	10E
0005435844334	25093	25	10F
0005432649380	25093	26	11D
0005435844328	25093	27	11E
0005432632661	25093	28	11F
0005432649389	25093	29	12D
0005435846262	25093	30	13D
0005435844331	25093	31	13E
0005432649376	25093	32	14C
0005432649374	25093	33	15C
0005432632643	25093	34	16C
0005432632672	25093	35	17A
0005435846269	25093	36	17C
0005432649352	25093	37	17F
0005435844330	25093	38	18A
0005432649386	25093	39	18C
0005432632660	25093	40	18F
0005432649379	25093	41	19E
0005435846268	25093	42	20C
0005432649366	25093	43	20D
0005432632694	25093	44	20E
0005433008413	1787	1	1C
0005433285179	1787	2	1D
0005433008609	1787	3	1F
0005433008486	1787	4	2A
0005433008414	1787	5	2C
0005433008443	1787	6	2D
0005433285262	1787	7	2F
0005433008395	1787	8	3A
0005433008510	1787	9	3C
0005433285280	1787	10	3D
0005433008352	1787	11	3F
0005433008350	1787	12	4C
0005433285158	1787	13	4D
0005433810568	1787	14	4F
0005433285075	1787	15	5A
0005433008397	1787	16	5C
0005433008253	1787	17	5D
0005433008525	1787	18	5E
0005433008459	1787	19	5F
0005432295890	1787	20	6A
0005433285115	1787	21	6C
0005433285169	1787	22	6D
0005433008386	1787	23	6E
0005433008384	1787	24	6F
0005432295889	1787	25	7A
0005433008478	1787	26	7C
0005433285196	1787	27	7D
0005433008351	1787	28	7E
0005433008390	1787	29	7F
0005433008307	1787	30	8A
0005433008467	1787	31	8C
0005432295891	1787	32	8D
0005433008208	1787	33	8F
0005433008446	1787	34	9A
0005433008509	1787	35	9C
0005433008385	1787	36	9E
0005433008358	1787	37	9F
0005433285152	1787	38	10A
0005433285323	1787	39	10C
0005433008411	1787	40	10D
0005433008517	1787	41	10E
0005433285233	1787	42	10F
0005433285187	1787	43	11A
0005433008548	1787	44	11C
0005433008477	1787	45	11D
0005433285263	1787	46	11F
0005433285195	1787	47	12A
0005433285080	1787	48	12C
0005433008394	1787	49	12D
0005433008249	1787	50	12E
0005433008323	1787	51	12F
0005433008472	1787	52	13A
0005433285151	1787	53	13C
0005433810569	1787	54	13D
0005433008248	1787	55	13E
0005433810570	1787	56	13F
0005433008468	1787	57	14C
0005433008368	1787	58	14D
0005433008523	1787	59	14E
0005433810567	1787	60	14F
0005433285221	1787	61	15A
0005433810571	1787	62	15C
0005433008322	1787	63	15D
0005433285188	1787	64	15E
0005433285199	1787	65	15F
0005433008412	1787	66	16C
0005433008369	1787	67	16D
0005433008326	1787	68	17C
0005433285113	1787	69	17D
0005433285130	1787	70	17F
0005433285261	1787	71	18C
0005433008393	1787	72	18D
0005433008579	1787	73	18E
0005433008339	1787	74	18F
0005433008458	1787	75	19A
0005433285258	1787	76	19C
0005433008547	1787	77	19D
0005433008349	1787	78	19E
0005433008389	1787	79	19F
0005433008608	1787	80	20A
0005433285074	1787	81	20C
0005433008447	1787	82	20D
0005433285219	1787	83	20E
0005433008281	1787	84	20F
0005433285402	22585	1	1C
0005433285395	22585	2	1D
0005433285405	22585	3	2A
0005433285420	22585	4	2C
0005433008757	22585	5	2D
0005433285406	22585	6	3C
0005433008788	22585	7	3D
0005433008753	22585	8	3F
0005433008763	22585	9	4A
0005433008789	22585	10	4C
0005433285415	22585	11	4D
0005433008783	22585	12	4F
0005433008769	22585	13	5A
0005433285410	22585	14	5C
0005433008764	22585	15	5F
0005433285408	22585	16	6A
0005433008775	22585	17	6E
0005433008760	22585	18	6F
0005433285401	22585	19	7A
0005433285400	22585	20	7D
0005433008765	22585	21	7F
0005433285423	22585	22	8A
0005433285409	22585	23	8C
0005433285393	22585	24	8D
0005433285418	22585	25	8E
0005433285413	22585	26	8F
0005433285396	22585	27	9A
0005433008779	22585	28	9D
0005433008767	22585	29	9E
0005433008785	22585	30	9F
0005433008778	22585	31	10C
0005433008768	22585	32	10D
0005433008774	22585	33	10E
0005433008777	22585	34	10F
0005433008786	22585	35	11A
0005433008773	22585	36	11C
0005433008780	22585	37	11D
0005433285417	22585	38	11E
0005433285392	22585	39	11F
0005433008791	22585	40	12A
0005433008795	22585	41	12C
0005433285421	22585	42	12D
0005433285422	22585	43	12E
0005433285416	22585	44	12F
0005433008784	22585	45	13A
0005433008794	22585	46	13C
0005433008756	22585	47	13D
0005433008772	22585	48	13E
0005433008787	22585	49	13F
0005433285412	22585	50	14A
0005433008751	22585	51	14C
0005433285403	22585	52	14D
0005433008762	22585	53	14E
0005433008770	22585	54	14F
0005433008796	22585	55	15A
0005433008761	22585	56	15D
0005433008754	22585	57	15E
0005433008766	22585	58	16A
0005433285419	22585	59	16C
0005433008790	22585	60	16D
0005433008758	22585	61	16E
0005433285399	22585	62	16F
0005433008793	22585	63	17A
0005433285411	22585	64	17C
0005433285398	22585	65	17D
0005433285414	22585	66	17F
0005433008776	22585	67	18A
0005433008792	22585	68	18C
0005433285407	22585	69	18D
0005433008759	22585	70	18E
0005433285394	22585	71	18F
0005433008750	22585	72	19C
0005433008755	22585	73	19D
0005433008782	22585	74	19E
0005433285404	22585	75	19F
0005433008752	22585	76	20A
0005433008771	22585	77	20C
0005433008781	22585	78	20E
0005433285397	22585	79	20F
0005432756857	25335	1	1C
0005432756847	25335	2	1D
0005434152780	25335	3	1F
0005432756856	25335	4	2A
0005432755086	25335	5	2C
0005432756845	25335	6	4A
0005434152777	25335	7	4F
0005432755081	25335	8	5A
0005432755080	25335	9	5C
0005434152779	25335	10	6C
0005432755076	25335	11	6E
0005432756848	25335	12	7A
0005432756851	25335	13	8A
0005432755075	25335	14	8E
0005432756852	25335	15	9F
0005432755078	25335	16	10D
0005432756855	25335	17	10E
0005432756849	25335	18	11C
0005434152774	25335	19	12A
0005432756846	25335	20	12C
0005432756853	25335	21	12D
0005434152776	25335	22	12F
0005432756850	25335	23	13D
0005434153529	25335	24	13F
0005434152778	25335	25	15A
0005432755085	25335	26	15E
0005432755082	25335	27	16A
0005432756860	25335	28	16C
0005434153525	25335	29	16E
0005432756854	25335	30	16F
0005432755079	25335	31	17D
0005432755074	25335	32	18C
0005432756858	25335	33	18F
0005432755083	25335	34	19A
0005432756859	25335	35	19D
0005432755084	25335	36	19E
0005432755073	25335	37	20E
0005432755077	25335	38	20F
0005433846952	5570	1	1C
0005433846930	5570	2	1A
0005433846938	5570	3	1D
0005433846922	5570	4	2A
0005433846962	5570	5	2F
0005435282340	5570	6	2D
0005435282377	5570	7	2C
0005433815403	5570	8	3A
0005433846972	5570	9	3D
0005433846924	5570	10	3C
0005433846927	5570	11	4C
0005433846963	5570	12	5C
0005433846945	5570	13	5A
0005433846956	5570	14	5F
0005432081535	5570	15	5D
0005433846960	5570	16	6B
0005435282393	5570	17	6A
0005433846935	5570	18	6D
0005433846939	5570	19	7A
0005433846973	5570	20	7C
0005433846955	5570	21	7B
0005435282505	5570	22	7E
0005433846965	5570	23	7D
0005435282346	5570	24	8A
0005433846950	5570	25	7F
0005433815400	5570	26	8C
0005435282402	5570	27	8B
0005433846940	5570	28	8D
0005433846923	5570	29	8F
0005433846937	5570	30	8E
0005434173507	5570	31	9A
0005433846947	5570	32	9C
0005435282434	5570	33	9B
0005433846948	5570	34	9F
0005432081532	5570	35	9D
0005433846942	5570	36	10A
0005433846958	5570	37	10C
0005433846944	5570	38	10B
0005433846933	5570	39	10E
0005433846976	5570	40	10D
0005433846951	5570	41	11A
0005433815402	5570	42	11D
0005432081537	5570	43	11C
0005433846957	5570	44	11F
0005433846934	5570	45	12B
0005435282442	5570	46	12A
0005433846925	5570	47	12D
0005433846918	5570	48	12C
0005433846921	5570	49	12E
0005433846943	5570	50	13A
0005433815401	5570	51	12F
0005433846926	5570	52	13C
0005433846928	5570	53	13E
0005434173506	5570	54	13F
0005433846959	5570	55	14B
0005435282371	5570	56	14A
0005433846971	5570	57	14D
0005435282452	5570	58	14C
0005435282374	5570	59	14E
0005433846964	5570	60	15B
0005433846967	5570	61	15A
0005433846954	5570	62	15D
0005433846970	5570	63	15E
0005435282275	5570	64	16A
0005432081534	5570	65	16B
0005433846932	5570	66	16D
0005434173489	5570	67	16F
0005433846919	5570	68	17B
0005433846968	5570	69	17D
0005433846949	5570	70	17C
0005433846969	5570	71	17F
0005433846953	5570	72	17E
0005435282347	5570	73	18A
0005433846936	5570	74	18C
0005433846929	5570	75	18B
0005433846941	5570	76	18E
0005433846920	5570	77	18D
0005433846966	5570	78	18F
0005432081538	5570	79	19E
0005433846946	5570	80	19D
0005432081533	5570	81	19F
0005435282297	5570	82	20B
0005433846974	5570	83	20A
0005435282449	5570	84	20C
0005434173525	5570	85	20F
0005435282364	5570	86	20E
0005435282451	5570	87	20D
0005432081536	5570	88	21A
0005433846977	5570	89	21C
0005433846931	5570	90	21B
0005433846975	5570	91	21E
0005433846961	5570	92	21F
0005433815357	13859	1	1C
0005433846524	13859	2	1A
0005433846242	13859	3	1F
0005435282615	13859	4	1D
0005435282612	13859	5	2A
0005433846464	13859	6	2D
0005433846363	13859	7	2C
0005433846236	13859	8	2F
0005433846124	13859	9	3C
0005435282617	13859	10	4A
0005434173536	13859	11	3F
0005435282606	13859	12	4C
0005435282608	13859	13	4F
0005433846610	13859	14	4D
0005433846572	13859	15	5C
0005433846429	13859	16	5A
0005434173537	13859	17	5F
0005435282610	13859	18	5D
0005433846545	13859	19	6E
0005435282595	13859	20	7A
0005433846404	13859	21	6F
0005433846511	13859	22	7C
0005433846310	13859	23	7B
0005433846391	13859	24	7E
0005435282599	13859	25	7D
0005435282596	13859	26	8A
0005433846342	13859	27	7F
0005433846387	13859	28	8C
0005433846553	13859	29	8B
0005433846410	13859	30	8D
0005435282592	13859	31	8F
0005433846444	13859	32	8E
0005433846571	13859	33	9A
0005433846285	13859	34	9C
0005433815358	13859	35	9B
0005433846377	13859	36	9E
0005433846268	13859	37	9D
0005433846638	13859	38	10A
0005433846324	13859	39	9F
0005435282601	13859	40	10C
0005433846361	13859	41	10E
0005435282616	13859	42	10D
0005433846544	13859	43	10F
0005432003714	13859	44	11B
0005433846203	13859	45	11A
0005432003712	13859	46	11D
0005433846074	13859	47	11C
0005433846411	13859	48	11F
0005435282609	13859	49	11E
0005433846226	13859	50	12B
0005433846530	13859	51	12A
0005433846376	13859	52	12D
0005433846536	13859	53	12C
0005433846738	13859	54	12E
0005433846406	13859	55	13B
0005435282605	13859	56	13C
0005435282613	13859	57	13E
0005433846473	13859	58	13D
0005433846412	13859	59	14A
0005433846549	13859	60	13F
0005435282607	13859	61	14C
0005433846668	13859	62	14B
0005435282611	13859	63	14D
0005433846335	13859	64	14F
0005433846393	13859	65	14E
0005435282602	13859	66	15A
0005433846543	13859	67	15D
0005435282598	13859	68	15C
0005435282604	13859	69	15B
0005435282593	13859	70	15E
0005433846360	13859	71	16A
0005435282614	13859	72	15F
0005433846470	13859	73	16B
0005433846443	13859	74	16F
0005433846405	13859	75	16E
0005433846669	13859	76	17B
0005433846600	13859	77	17A
0005433846243	13859	78	17D
0005435282594	13859	79	17C
0005433846359	13859	80	17F
0005433846537	13859	81	17E
0005433846570	13859	82	18A
0005435282600	13859	83	18D
0005433846513	13859	84	18C
0005433846128	13859	85	18B
0005433846311	13859	86	18E
0005434173534	13859	87	19A
0005433846554	13859	88	19C
0005433846531	13859	89	19E
0005434173535	13859	90	19D
0005433846667	13859	91	19F
0005433846436	13859	92	20B
0005433846576	13859	93	20A
0005433846340	13859	94	20D
0005433846325	13859	95	20C
0005435282603	13859	96	21A
0005432003713	13859	97	20F
0005433846512	13859	98	21C
0005435282597	13859	99	21B
0005433846508	13859	100	21E
0005433846341	13859	101	21D
0005434620674	7799	1	1C
0005434620673	7799	2	1D
0005434620667	7799	3	2B
0005435332300	7799	4	2C
0005435332297	7799	5	2D
0005435332291	7799	6	3A
0005434620672	7799	7	3B
0005434620666	7799	8	4A
0005434620682	7799	9	4C
0005434620670	7799	10	4D
0005434620684	7799	11	5B
0005434620675	7799	12	5D
0005435332292	7799	13	6A
0005434620679	7799	14	6C
0005435332279	7799	15	6B
0005434620668	7799	16	6D
0005435332299	7799	17	7A
0005435332286	7799	18	7B
0005434620685	7799	19	7C
0005434620680	7799	20	18A
0005434620665	7799	21	18C
0005434620678	7799	22	18D
0005435332298	7799	23	19C
0005435332280	7799	24	19D
0005434620677	7799	25	20A
0005434620683	7799	26	20C
0005434620671	7799	27	21A
0005432112525	7799	28	21C
0005434620676	7799	29	21D
0005434620669	7799	30	22A
0005434620664	7799	31	22B
0005434620681	7799	32	22C
0005434620515	32993	1	1A
0005434620531	32993	2	1B
0005434620514	32993	3	1D
0005435332375	32993	4	1C
0005435332379	32993	5	2A
0005434620399	32993	6	2B
0005434620483	32993	7	3A
0005434620519	32993	8	3B
0005434620465	32993	9	3C
0005435332378	32993	10	3D
0005435332373	32993	11	4A
0005435332371	32993	12	4B
0005434620496	32993	13	4C
0005434620464	32993	14	4D
0005434620599	32993	15	5D
0005434620400	32993	16	6B
0005434620564	32993	17	7B
0005435332377	32993	18	7D
0005434620513	32993	19	18A
0005434620448	32993	20	18B
0005434620529	32993	21	18C
0005434620498	32993	22	18D
0005434620418	32993	23	19B
0005434620601	32993	24	19C
0005434620497	32993	25	19D
0005435332374	32993	26	20B
0005434620492	32993	27	20C
0005434620500	32993	28	20D
0005434620462	32993	29	21A
0005434620484	32993	30	21B
0005434620489	32993	31	21C
0005434620450	32993	32	21D
0005435332376	32993	33	22A
0005435332380	32993	34	22B
0005435332370	32993	35	22C
0005434620600	32993	36	23A
0005435332372	32993	37	23B
0005435785490	4299	1	1A
0005435785499	4299	2	1C
0005435785476	4299	3	1D
0005434994058	4299	4	1F
0005434994057	4299	5	2A
0005435785491	4299	6	2C
0005435785487	4299	7	2D
0005435785482	4299	8	3A
0005435785495	4299	9	3C
0005435785506	4299	10	3D
0005435785478	4299	11	3F
0005435785485	4299	12	4A
0005435785474	4299	13	4E
0005435787364	4299	14	4F
0005434994061	4299	15	5A
0005435785473	4299	16	5C
0005435785497	4299	17	5E
0005435918661	4299	18	6A
0005435785500	4299	19	6E
0005435787361	4299	20	7E
0005435785472	4299	21	8A
0005435785481	4299	22	8E
0005435785479	4299	23	9D
0005435785493	4299	24	9F
0005435937356	4299	25	10A
0005435785477	4299	26	10D
0005435918612	4299	27	10E
0005435785498	4299	28	10F
0005435785475	4299	29	11A
0005435937349	4299	30	11E
0005435785488	4299	31	12C
0005434994063	4299	32	12D
0005435785504	4299	33	12E
0005435918650	4299	34	12F
0005435785484	4299	35	13A
0005435785503	4299	36	13C
0005432190645	4299	37	13D
0005435785505	4299	38	13E
0005435787362	4299	39	14A
0005432190643	4299	40	14D
0005435785483	4299	41	14E
0005435785471	4299	42	14F
0005435785480	4299	43	15A
0005434994064	4299	44	15C
0005434994059	4299	45	15D
0005435937337	4299	46	15E
0005435785489	4299	47	15F
0005435785492	4299	48	16D
0005434994060	4299	49	16F
0005435785502	4299	50	17A
0005435785494	4299	51	17C
0005432190644	4299	52	17E
0005435785486	4299	53	18C
0005435918642	4299	54	18D
0005434994062	4299	55	19D
0005435785496	4299	56	19F
0005435785501	4299	57	20A
0005432190642	4299	58	20D
0005435787363	4299	59	20F
0005434993972	27310	1	1C
0005435785064	27310	2	1D
0005435785107	27310	3	1F
0005435918672	27310	4	2A
0005435785108	27310	5	2C
0005435918677	27310	6	2F
0005435918675	27310	7	3A
0005435785194	27310	8	3C
0005435785067	27310	9	3D
0005435937399	27310	10	3F
0005435785074	27310	11	4A
0005435785176	27310	12	4D
0005435785026	27310	13	4E
0005435785162	27310	14	4F
0005435787335	27310	15	5D
0005432195700	27310	16	5E
0005435918676	27310	17	5F
0005435785123	27310	18	6A
0005434993936	27310	19	6C
0005435785111	27310	20	6D
0005435785075	27310	21	7A
0005435937395	27310	22	7C
0005435785248	27310	23	7D
0005434994007	27310	24	7E
0005435785100	27310	25	8A
0005434993980	27310	26	8D
0005435785136	27310	27	8E
0005435785245	27310	28	8F
0005434993971	27310	29	9E
0005435918674	27310	30	9F
0005435785053	27310	31	10A
0005435785277	27310	32	10C
0005435785054	27310	33	10D
0005435785090	27310	34	11C
0005435785146	27310	35	11D
0005434994006	27310	36	11E
0005435785230	27310	37	11F
0005435785099	27310	38	12A
0005435785133	27310	39	12D
0005435784982	27310	40	12E
0005435785071	27310	41	12F
0005435937398	27310	42	13D
0005434994008	27310	43	13E
0005435785106	27310	44	13F
0005435785246	27310	45	14A
0005432195699	27310	46	14D
0005435785038	27310	47	14E
0005435785014	27310	48	14F
0005435785063	27310	49	15C
0005435937394	27310	50	15D
0005435785003	27310	51	15E
0005435937393	27310	52	16A
0005435785126	27310	53	16C
0005434993978	27310	54	17D
0005435785001	27310	55	17F
0005434993979	27310	56	18A
0005435937397	27310	57	18D
0005435784993	27310	58	18F
0005435937396	27310	59	19A
0005435785145	27310	60	19C
0005435785247	27310	61	19E
0005435918673	27310	62	20C
0005432146206	19880	1	3B
0005432146205	19880	2	20C
0005433451627	4721	1	1C
0005434081985	4721	2	1B
0005432571337	4721	3	1F
0005432567841	4721	4	1G
0005432170415	4721	5	2A
0005432567885	4721	6	1H
0005432567894	4721	7	2H
0005432460031	4721	8	2G
0005432460029	4721	9	3B
0005432567865	4721	10	3C
0005432567887	4721	11	3G
0005432460035	4721	12	3H
0005432567901	4721	13	4C
0005432460039	4721	14	4G
0005432170413	4721	15	4F
0005432460063	4721	16	5B
0005434082000	4721	17	5A
0005432460033	4721	18	5C
0005432567858	4721	19	5G
0005432567868	4721	20	5F
0005432460043	4721	21	9A
0005432567884	4721	22	5H
0005432170411	4721	23	9G
0005432567888	4721	24	9B
0005432567857	4721	25	11B
0005432567846	4721	26	11F
0005432567870	4721	27	11E
0005432186883	4721	28	11H
0005432460060	4721	29	11G
0005432571335	4721	30	12B
0005433726112	4721	31	12E
0005432567898	4721	32	12G
0005432460037	4721	33	12F
0005432460046	4721	34	13A
0005433452748	4721	35	13E
0005432567879	4721	36	13G
0005432567861	4721	37	14D
0005434081990	4721	38	14F
0005432460069	4721	39	14E
0005434082003	4721	40	14G
0005432460075	4721	41	14H
0005434082007	4721	42	15B
0005432460071	4721	43	15D
0005432460027	4721	44	15H
0005434082005	4721	45	15G
0005432567896	4721	46	16B
0005432460044	4721	47	16A
0005434081996	4721	48	16D
0005432460070	4721	49	16F
0005432567871	4721	50	16E
0005432567860	4721	51	16G
0005432460064	4721	52	17B
0005432460059	4721	53	17A
0005432460052	4721	54	17E
0005432460049	4721	55	17G
0005432567886	4721	56	17F
0005432567889	4721	57	17H
0005432567895	4721	58	18B
0005432567878	4721	59	18A
0005432567852	4721	60	18D
0005434081991	4721	61	18F
0005432567897	4721	62	18E
0005432460026	4721	63	18G
0005432460061	4721	64	18H
0005432460065	4721	65	19B
0005432567844	4721	66	19A
0005432460047	4721	67	19E
0005434082004	4721	68	20E
0005432567892	4721	69	20D
0005432567872	4721	70	20F
0005432571336	4721	71	20H
0005432460042	4721	72	20G
0005432170416	4721	73	21A
0005434081988	4721	74	21D
0005432460045	4721	75	21E
0005432567863	4721	76	21G
0005432567862	4721	77	21F
0005432170412	4721	78	22B
0005432567877	4721	79	22A
0005432460057	4721	80	22D
0005432460036	4721	81	22F
0005432567843	4721	82	22G
0005432460028	4721	83	23B
0005432460055	4721	84	23D
0005432460053	4721	85	23F
0005432460072	4721	86	23E
0005432460048	4721	87	24A
0005432567845	4721	88	24G
0005434081986	4721	89	24F
0005432567876	4721	90	25D
0005432460077	4721	91	24H
0005432460050	4721	92	25E
0005432567853	4721	93	27A
0005432567848	4721	94	25F
0005432460025	4721	95	27B
0005432567842	4721	96	27E
0005432186882	4721	97	27H
0005434081995	4721	98	27G
0005432460074	4721	99	28A
0005432567851	4721	100	28B
0005432567873	4721	101	28E
0005432567866	4721	102	28D
0005434082001	4721	103	28F
0005434081999	4721	104	28G
0005432567864	4721	105	28H
0005434081994	4721	106	29D
0005432460067	4721	107	29E
0005432460058	4721	108	29H
0005432567880	4721	109	30A
0005432460056	4721	110	30D
0005432460038	4721	111	30F
0005432567883	4721	112	30H
0005432567847	4721	113	31A
0005433451626	4721	114	31F
0005434082006	4721	115	31E
0005432460034	4721	116	31G
0005432567881	4721	117	32A
0005432186885	4721	118	32D
0005432567850	4721	119	32B
0005432460066	4721	120	32F
0005432567869	4721	121	32E
0005434081987	4721	122	32H
0005434081989	4721	123	32G
0005433452747	4721	124	33A
0005432460062	4721	125	33D
0005432460032	4721	126	33B
0005432567855	4721	127	33E
0005432567875	4721	128	33F
0005432567893	4721	129	33G
0005433726113	4721	130	34B
0005434081998	4721	131	34A
0005432170410	4721	132	34F
0005432567839	4721	133	34G
0005432460030	4721	134	35A
0005432460040	4721	135	35D
0005432186884	4721	136	35B
0005432567856	4721	137	35F
0005432567854	4721	138	35G
0005432460054	4721	139	36A
0005432567849	4721	140	36F
0005434081993	4721	141	36E
0005432460076	4721	142	36G
0005434081992	4721	143	37A
0005432567890	4721	144	36H
0005432567882	4721	145	37D
0005434082002	4721	146	37B
0005432460073	4721	147	37E
0005432567867	4721	148	37F
0005432460068	4721	149	37H
0005432567891	4721	150	37G
0005432567859	4721	151	38A
0005432460041	4721	152	38D
0005432567840	4721	153	38B
0005432571334	4721	154	38E
0005432170414	4721	155	38G
0005432567874	4721	156	38F
0005432567900	4721	157	38H
0005432460051	4721	158	39E
0005432567899	4721	159	39D
0005434081997	4721	160	39F
0005432567523	30550	1	1B
0005432567283	30550	2	1F
0005432571287	30550	3	2A
0005432459461	30550	4	1H
0005432567300	30550	5	2B
0005432459759	30550	6	2C
0005432459680	30550	7	3A
0005432567256	30550	8	2H
0005432567498	30550	9	3B
0005432161161	30550	10	3G
0005432459718	30550	11	4A
0005432567484	30550	12	3H
0005432213619	30550	13	4F
0005434081782	30550	14	4C
0005432459842	30550	15	4H
0005434081696	30550	16	5B
0005432567454	30550	17	5C
0005432459672	30550	18	5G
0005432567104	30550	19	5H
0005432571308	30550	20	9G
0005432459755	30550	21	11A
0005432459771	30550	22	9H
0005432459697	30550	23	11D
0005432459411	30550	24	12A
0005434081785	30550	25	12B
0005432459549	30550	26	12E
0005432567302	30550	27	13D
0005432567028	30550	28	13B
0005433452725	30550	29	13G
0005432459839	30550	30	13F
0005432459596	30550	31	13H
0005434081712	30550	32	14B
0005432567468	30550	33	14A
0005432459748	30550	34	14D
0005432567103	30550	35	14E
0005432567236	30550	36	14G
0005432459812	30550	37	15A
0005433452729	30550	38	15E
0005434081741	30550	39	15D
0005434081725	30550	40	15H
0005433452730	30550	41	16A
0005432459810	30550	42	16B
0005432459544	30550	43	16G
0005432567636	30550	44	16H
0005432567255	30550	45	17B
0005434081793	30550	46	17A
0005432459722	30550	47	17D
0005432459811	30550	48	17F
0005434081684	30550	49	17G
0005432459575	30550	50	17H
0005432567460	30550	51	18E
0005432459443	30550	52	18G
0005432459568	30550	53	18F
0005432567473	30550	54	18H
0005432567506	30550	55	19D
0005433454864	30550	56	19F
0005432459645	30550	57	19E
0005432567257	30550	58	19H
0005432459442	30550	59	20A
0005432567282	30550	60	20B
0005432567424	30550	61	20E
0005434081640	30550	62	20G
0005432459491	30550	63	21A
0005432459699	30550	64	20H
0005434081685	30550	65	21D
0005432567479	30550	66	21E
0005434081779	30550	67	21F
0005432567324	30550	68	22D
0005434081780	30550	69	22B
0005432567577	30550	70	22E
0005432567505	30550	71	22G
0005432459462	30550	72	23A
0005434081781	30550	73	22H
0005432567301	30550	74	23D
0005432459620	30550	75	23B
0005432567390	30550	76	23F
0005432567478	30550	77	23H
0005432459534	30550	78	24B
0005432459621	30550	79	24E
0005432567281	30550	80	24G
0005432567483	30550	81	24F
0005432571305	30550	82	25E
0005434081815	30550	83	27A
0005432567459	30550	84	27B
0005432459717	30550	85	27D
0005434081814	30550	86	27F
0005432459396	30550	87	27E
0005432459577	30550	88	27G
0005432567235	30550	89	28A
0005434081792	30550	90	27H
0005432459686	30550	91	28B
0005432459731	30550	92	28E
0005432459681	30550	93	28D
0005432213623	30550	94	28F
0005432459687	30550	95	29A
0005432567123	30550	96	29D
0005432459843	30550	97	29B
0005432567325	30550	98	29H
0005432567457	30550	99	29G
0005434081689	30550	100	30A
0005432459543	30550	101	30E
0005434081813	30550	102	30D
0005432459716	30550	103	30B
0005434081777	30550	104	30G
0005432161160	30550	105	31F
0005432567237	30550	106	31E
0005432459616	30550	107	31G
0005432567474	30550	108	32A
0005432567187	30550	109	32B
0005432567485	30550	110	32E
0005432161162	30550	111	32H
0005432459679	30550	112	33D
0005432459556	30550	113	33B
0005432459728	30550	114	33E
0005433454867	30550	115	33G
0005432459760	30550	116	33F
0005432459395	30550	117	34B
0005432567364	30550	118	34A
0005432567228	30550	119	34D
0005434081639	30550	120	34E
0005432571299	30550	121	34G
0005434081745	30550	122	35A
0005433454869	30550	123	34H
0005432459723	30550	124	35E
0005432567372	30550	125	35D
0005434081786	30550	126	35F
0005432567190	30550	127	35G
0005432213621	30550	128	35H
0005432213622	30550	129	36B
0005432459698	30550	130	36A
0005432213620	30550	131	36D
0005433454868	30550	132	36F
0005432567438	30550	133	36H
0005432459420	30550	134	36G
0005432459497	30550	135	37B
0005432567157	30550	136	37D
0005432567401	30550	137	37F
0005432459576	30550	138	37H
0005432459533	30550	139	38A
0005434081724	30550	140	38B
0005432459779	30550	141	38E
0005434081713	30550	142	38G
0005432459790	30550	143	38H
0005432567354	30550	144	39E
0005435722065	13670	1	3A
0005435722064	13670	2	3B
0005435722066	13670	3	5B
0005435722063	13670	4	6A
0005435722053	21186	1	1B
0005435720131	21186	2	3B
0005435722052	21186	3	4A
0005432295889	22785	1	2D
0005432295890	22785	2	20C
0005432295891	22785	3	23A
0005433343527	11106	1	1A
0005435508292	11106	2	1C
0005433343518	11106	3	1D
0005433343560	11106	4	2C
0005433343547	11106	5	2A
0005435508288	11106	6	2D
0005433343568	11106	7	2F
0005433343590	11106	8	3A
0005433343581	11106	9	3D
0005433343584	11106	10	3C
0005433343532	11106	11	4A
0005433343564	11106	12	4B
0005435508284	11106	13	4D
0005433343587	11106	14	4C
0005435097229	11106	15	4E
0005433343615	11106	16	5A
0005433343525	11106	17	4F
0005433343536	11106	18	5B
0005433343583	11106	19	5C
0005435380280	11106	20	5D
0005433343598	11106	21	5E
0005433343573	11106	22	5F
0005433343595	11106	23	6B
0005433343541	11106	24	6A
0005435097232	11106	25	6C
0005433343556	11106	26	6D
0005433343570	11106	27	6E
0005433343561	11106	28	7A
0005435508293	11106	29	6F
0005433343533	11106	30	7B
0005433343604	11106	31	7C
0005433343548	11106	32	7E
0005433343519	11106	33	7D
0005433343569	11106	34	8A
0005433343592	11106	35	7F
0005433343545	11106	36	8B
0005433343540	11106	37	8C
0005433343558	11106	38	8E
0005433343572	11106	39	8D
0005435097235	11106	40	8F
0005433343516	11106	41	9A
0005433343529	11106	42	9B
0005433343575	11106	43	9D
0005433343588	11106	44	9C
0005433343574	11106	45	9E
0005433343579	11106	46	9F
0005433343614	11106	47	10B
0005435508280	11106	48	10C
0005433343600	11106	49	10E
0005433343578	11106	50	10D
0005435508285	11106	51	11A
0005433343554	11106	52	11C
0005433343550	11106	53	11B
0005433343517	11106	54	11D
0005433343528	11106	55	11E
0005433343608	11106	56	11F
0005433343605	11106	57	12A
0005433343539	11106	58	12C
0005435097231	11106	59	12B
0005433343534	11106	60	12E
0005433343553	11106	61	12D
0005433343542	11106	62	12F
0005433343551	11106	63	13A
0005433343557	11106	64	13C
0005433343606	11106	65	13B
0005433343601	11106	66	13E
0005433343526	11106	67	13D
0005433343566	11106	68	13F
0005433343531	11106	69	14B
0005433343589	11106	70	14A
0005433343520	11106	71	14C
0005433343582	11106	72	14D
0005433343577	11106	73	14E
0005433343580	11106	74	14F
0005433343546	11106	75	15A
0005433343613	11106	76	15C
0005433343523	11106	77	15B
0005433343559	11106	78	15D
0005433343563	11106	79	15E
0005435380279	11106	80	16A
0005433343535	11106	81	15F
0005435097230	11106	82	16B
0005435380278	11106	83	16C
0005433343609	11106	84	16E
0005433343515	11106	85	16D
0005433343597	11106	86	16F
0005433343538	11106	87	17A
0005435097234	11106	88	17B
0005433343610	11106	89	17C
0005433343616	11106	90	17D
0005433343602	11106	91	17E
0005433343586	11106	92	18A
0005435097233	11106	93	17F
0005433343612	11106	94	18B
0005435508253	11106	95	18D
0005433343591	11106	96	18C
0005435380277	11106	97	18F
0005433343543	11106	98	18E
0005433343593	11106	99	19B
0005433343585	11106	100	19A
0005433343611	11106	101	19C
0005433343521	11106	102	19E
0005433343571	11106	103	19D
0005433343562	11106	104	19F
0005435097225	11106	105	20B
0005433343596	11106	106	20D
0005433343555	11106	107	20C
0005435508274	11106	108	20E
0005433343565	11106	109	21A
0005433343567	11106	110	20F
0005433343522	11106	111	21B
0005433343549	11106	112	21C
0005433343599	11106	113	21D
0005433343607	11106	114	21E
0005433343576	11106	115	22A
0005433343537	11106	116	21F
0005433343544	11106	117	22C
0005433343594	11106	118	22B
0005435508252	11106	119	22D
0005435097228	11106	120	22F
0005433343530	11106	121	22E
0005435097226	11106	122	23A
0005433343552	11106	123	23C
0005435380270	11106	124	23B
0005435097227	11106	125	23D
0005433343603	11106	126	23F
0005433343524	11106	127	23E
0005435097189	17102	1	1C
0005435380312	17102	2	1A
0005433342613	17102	3	1D
0005435097173	17102	4	1F
0005433342795	17102	5	2A
0005433341893	17102	6	2D
0005433342796	17102	7	2C
0005433342881	17102	8	2F
0005433342740	17102	9	3A
0005433342888	17102	10	3D
0005433342907	17102	11	3C
0005432293219	17102	12	3F
0005433342414	17102	13	4A
0005435380314	17102	14	4B
0005433342470	17102	15	4D
0005435097146	17102	16	4E
0005433342203	17102	17	4F
0005433343211	17102	18	5A
0005433342717	17102	19	5C
0005433341823	17102	20	5B
0005433342151	17102	21	5D
0005435380311	17102	22	5E
0005433342206	17102	23	6A
0005435545769	17102	24	5F
0005433342624	17102	25	6B
0005433342457	17102	26	6C
0005435097171	17102	27	6D
0005433342001	17102	28	6E
0005435545768	17102	29	7A
0005433342614	17102	30	6F
0005433342488	17102	31	7B
0005433342906	17102	32	7C
0005433342489	17102	33	7D
0005433342628	17102	34	7F
0005433342202	17102	35	7E
0005433342184	17102	36	8B
0005433342850	17102	37	8A
0005433342554	17102	38	8D
0005433342220	17102	39	8C
0005433342525	17102	40	8E
0005433342889	17102	41	9A
0005432293217	17102	42	8F
0005433342431	17102	43	9B
0005433341824	17102	44	9D
0005433342503	17102	45	9C
0005433342442	17102	46	9E
0005433342879	17102	47	9F
0005433342530	17102	48	10B
0005433342693	17102	49	10C
0005433342551	17102	50	10D
0005433342313	17102	51	11A
0005433342880	17102	52	10E
0005433342599	17102	53	11B
0005435097200	17102	54	11C
0005433342674	17102	55	11E
0005435380313	17102	56	11D
0005433342882	17102	57	11F
0005433342629	17102	58	12A
0005433342152	17102	59	12C
0005433342791	17102	60	12B
0005433342546	17102	61	12D
0005432293218	17102	62	12E
0005435097187	17102	63	12F
0005433342787	17102	64	13B
0005433342692	17102	65	13A
0005435097161	17102	66	13C
0005433342098	17102	67	13E
0005433342545	17102	68	13F
0005433342311	17102	69	14B
0005433342903	17102	70	14A
0005433342565	17102	71	14C
0005433342948	17102	72	14D
0005433342884	17102	73	14E
0005433342524	17102	74	14F
0005433342575	17102	75	15B
0005435097123	17102	76	15A
0005433342487	17102	77	15C
0005433342609	17102	78	15E
0005433342930	17102	79	15D
0005433342781	17102	80	15F
0005433342587	17102	81	16B
0005433342904	17102	82	16A
0005433343212	17102	83	16C
0005435097147	17102	84	16D
0005433342322	17102	85	16E
0005433342697	17102	86	17A
0005433342471	17102	87	16F
0005433342532	17102	88	17B
0005433342650	17102	89	17D
0005433342869	17102	90	17C
0005433342780	17102	91	17F
0005433342885	17102	92	17E
0005433342492	17102	93	18A
0005433342675	17102	94	18B
0005433342394	17102	95	18C
0005433342586	17102	96	18D
0005435097124	17102	97	18F
0005433342502	17102	98	18E
0005433342620	17102	99	19A
0005435097201	17102	100	19B
0005433342870	17102	101	19C
0005433342905	17102	102	19E
0005433342652	17102	103	19D
0005435097172	17102	104	19F
0005433342400	17102	105	20A
0005435097166	17102	106	20B
0005435097179	17102	107	20C
0005435380315	17102	108	20E
0005435097159	17102	109	20D
0005433342949	17102	110	20F
0005435097148	17102	111	21A
0005433342707	17102	112	21C
0005433342947	17102	113	21B
0005433342522	17102	114	21D
0005435097157	17102	115	21E
0005433342133	17102	116	22A
0005435097186	17102	117	21F
0005433342097	17102	118	22C
0005433342415	17102	119	22B
0005433342441	17102	120	22D
0005433342002	17102	121	22F
0005433343205	17102	122	22E
0005433342533	17102	123	23A
0005433342443	17102	124	23B
0005433342399	17102	125	23C
0005433342223	17102	126	23E
0005433342648	17102	127	23D
0005433342604	17102	128	23F
0005433507263	9114	1	2A
0005432919820	9114	2	2D
0005432919789	9114	3	3A
0005432919716	9114	4	3C
0005433481199	9114	5	3D
0005433507254	9114	6	4C
0005432919743	9114	7	4D
0005432919738	9114	8	5C
0005432919787	9114	9	5D
0005432919715	9114	10	5E
0005433507265	9114	11	6A
0005432919742	9114	12	6D
0005432919821	9114	13	6E
0005433507253	9114	14	7C
0005432919745	9114	15	7D
0005432919740	9114	16	8A
0005432919714	9114	17	8E
0005433507256	9114	18	8F
0005433481201	9114	19	9D
0005433481197	9114	20	9E
0005433481200	9114	21	10D
0005433481202	9114	22	10E
0005432919794	9114	23	11A
0005432919741	9114	24	11C
0005433507267	9114	25	11D
0005433507252	9114	26	11E
0005433481195	9114	27	12A
0005433507258	9114	28	12F
0005433507266	9114	29	13A
0005432919729	9114	30	13C
0005432919771	9114	31	13D
0005433507257	9114	32	13F
0005432919819	9114	33	14A
0005432919767	9114	34	14C
0005432919688	9114	35	14F
0005432919786	9114	36	15E
0005433507261	9114	37	16C
0005433507262	9114	38	16D
0005433507268	9114	39	16F
0005433507255	9114	40	17D
0005433481198	9114	41	17E
0005432919774	9114	42	18C
0005433481196	9114	43	18D
0005433507259	9114	44	18E
0005432919730	9114	45	18F
0005433481194	9114	46	19A
0005433507264	9114	47	19C
0005433507260	9114	48	19F
0005432919744	9114	49	20A
0005432919812	9114	50	20C
0005432919775	9114	51	20D
0005433507251	9114	52	20E
0005432919765	9114	53	20F
0005432919971	20486	1	1F
0005433481153	20486	2	4D
0005432919970	20486	3	4E
0005433481185	20486	4	5A
0005432919959	20486	5	5C
0005433481109	20486	6	6C
0005432919952	20486	7	6D
0005433507126	20486	8	6E
0005432919973	20486	9	6F
0005432919963	20486	10	7D
0005432919967	20486	11	7E
0005432919964	20486	12	8A
0005432919953	20486	13	8D
0005433481143	20486	14	8E
0005433507092	20486	15	9F
0005433507094	20486	16	10C
0005432919968	20486	17	10D
0005432919956	20486	18	10F
0005433481132	20486	19	11D
0005432919958	20486	20	11E
0005433481158	20486	21	12A
0005432919961	20486	22	12C
0005433507100	20486	23	12D
0005433507132	20486	24	12E
0005432919972	20486	25	12F
0005432919957	20486	26	13C
0005432919965	20486	27	13D
0005432919962	20486	28	13E
0005433481159	20486	29	14F
0005433481110	20486	30	15A
0005433507119	20486	31	15D
0005433481118	20486	32	16A
0005432919960	20486	33	16E
0005432919955	20486	34	16F
0005433507117	20486	35	18D
0005432919966	20486	36	18F
0005432919954	20486	37	19A
0005433507116	20486	38	19F
0005432919969	20486	39	20A
0005433507027	20486	40	20E
0005432394120	10213	1	1A
0005432394116	10213	2	1B
0005432396257	10213	3	2B
0005432394119	10213	4	3B
0005432396255	10213	5	3A
0005432396256	10213	6	4A
0005432394118	10213	7	4B
0005432394114	10213	8	5A
0005432394117	10213	9	5B
0005432394115	10213	10	6A
0005432396254	10213	11	6B
0005432396230	18359	1	1A
0005432396212	18359	2	1B
0005432400097	18359	3	2A
0005432400109	18359	4	2B
0005432400127	18359	5	3A
0005435179397	18359	6	3B
0005432396216	18359	7	4A
0005432400111	18359	8	4B
0005432396221	18359	9	5B
0005432400100	18359	10	5A
0005432396235	18359	11	6A
0005432400112	18359	12	6B
0005435626082	11018	1	1C
0005435126046	11018	2	1D
0005435126221	11018	3	1F
0005435126063	11018	4	2A
0005435554180	11018	5	2C
0005434411796	11018	6	2D
0005435626060	11018	7	2F
0005435126135	11018	8	3D
0005435126084	11018	9	3F
0005435126140	11018	10	4A
0005435626034	11018	11	4C
0005435126025	11018	12	4E
0005435626048	11018	13	4F
0005435126264	11018	14	5A
0005435126093	11018	15	5C
0005435126047	11018	16	5E
0005435126238	11018	17	5F
0005435626033	11018	18	6D
0005435125940	11018	19	6E
0005435126106	11018	20	6F
0005435126062	11018	21	7A
0005435125955	11018	22	7C
0005435626050	11018	23	7D
0005435126220	11018	24	7F
0005435126143	11018	25	8C
0005435126133	11018	26	8D
0005435126108	11018	27	8E
0005435626083	11018	28	8F
0005435126056	11018	29	9A
0005435626027	11018	30	9C
0005435556682	11018	31	9D
0005435126088	11018	32	9E
0005435126094	11018	33	10A
0005435626053	11018	34	10C
0005435626067	11018	35	10D
0005435626028	11018	36	10E
0005435126126	11018	37	11A
0005435125971	11018	38	11C
0005435126155	11018	39	11D
0005435126026	11018	40	11E
0005435126010	11018	41	11F
0005435126136	11018	42	12A
0005435626081	11018	43	12D
0005435554155	11018	44	12E
0005434928311	11018	45	12F
0005435126209	11018	46	13A
0005435554184	11018	47	13C
0005435554159	11018	48	13D
0005434411795	11018	49	13E
0005434411797	11018	50	13F
0005435554167	11018	51	14A
0005435126144	11018	52	14C
0005435556683	11018	53	14D
0005435626031	11018	54	14E
0005435626054	11018	55	14F
0005434411794	11018	56	15A
0005435126291	11018	57	15C
0005435126113	11018	58	15D
0005435126252	11018	59	15E
0005435126201	11018	60	16A
0005435126114	11018	61	16C
0005435626059	11018	62	16E
0005435126117	11018	63	16F
0005434928312	11018	64	17A
0005435554154	11018	65	17D
0005435126095	11018	66	17E
0005435126141	11018	67	17F
0005435626064	11018	68	18A
0005435554157	11018	69	18C
0005435126154	11018	70	18D
0005435626066	11018	71	18E
0005435626068	11018	72	18F
0005435556668	11018	73	19A
0005434928310	11018	74	19C
0005435126011	11018	75	19D
0005435626069	11018	76	19E
0005435626052	11018	77	19F
0005435126200	11018	78	20A
0005435126107	11018	79	20D
0005435125956	11018	80	20E
0005435554185	11018	81	20F
0005435626248	14763	1	1A
0005435126548	14763	2	1C
0005435126529	14763	3	1F
0005435126527	14763	4	2A
0005435126522	14763	5	2C
0005435126523	14763	6	2D
0005435626252	14763	7	2F
0005435126557	14763	8	3A
0005435626258	14763	9	3C
0005435126544	14763	10	3D
0005434411757	14763	11	3F
0005435126554	14763	12	4A
0005435626246	14763	13	4C
0005435126545	14763	14	4D
0005435126534	14763	15	4F
0005435126524	14763	16	5A
0005435126562	14763	17	5D
0005435626251	14763	18	5E
0005435554202	14763	19	5F
0005435556704	14763	20	6C
0005435626262	14763	21	6D
0005435626256	14763	22	6E
0005435626254	14763	23	7A
0005435126530	14763	24	7C
0005435626260	14763	25	7D
0005435626261	14763	26	7E
0005435126547	14763	27	7F
0005435626243	14763	28	8C
0005435626250	14763	29	8D
0005435626255	14763	30	8E
0005435126537	14763	31	8F
0005435626240	14763	32	9A
0005435126549	14763	33	9C
0005435126541	14763	34	9D
0005435626249	14763	35	9F
0005435126532	14763	36	10A
0005434928290	14763	37	10C
0005435126553	14763	38	10E
0005435626264	14763	39	10D
0005435626244	14763	40	10F
0005435556703	14763	41	11A
0005435126556	14763	42	11C
0005435126559	14763	43	11D
0005435126525	14763	44	11E
0005435554206	14763	45	11F
0005435126526	14763	46	12C
0005434411770	14763	47	12E
0005435626259	14763	48	13A
0005434411763	14763	49	13C
0005435126536	14763	50	13D
0005435626253	14763	51	13E
0005434411769	14763	52	13F
0005435126533	14763	53	14A
0005435626263	14763	54	14C
0005435126528	14763	55	14E
0005435126542	14763	56	14F
0005435626241	14763	57	15A
0005435626257	14763	58	15C
0005435126539	14763	59	15D
0005435126552	14763	60	15E
0005435126560	14763	61	16A
0005435554204	14763	62	16C
0005435126558	14763	63	16D
0005434928291	14763	64	16E
0005435626245	14763	65	16F
0005435554203	14763	66	17A
0005435626242	14763	67	17C
0005435626247	14763	68	17D
0005435126531	14763	69	17E
0005434411762	14763	70	17F
0005435126555	14763	71	18C
0005435126551	14763	72	18D
0005435126535	14763	73	18E
0005435126561	14763	74	18F
0005435126538	14763	75	19A
0005435126550	14763	76	19C
0005435556702	14763	77	19D
0005435126543	14763	78	19E
0005435126521	14763	79	19F
0005435126546	14763	80	20C
0005435626265	14763	81	20D
0005435126540	14763	82	20E
0005435554205	14763	83	20F
0005435715546	7118	1	1C
0005435216570	7118	2	1D
0005435443234	7118	3	2D
0005435715536	7118	4	2F
0005432398213	7118	5	3F
0005435715540	7118	6	4C
0005435443258	7118	7	4E
0005435715542	7118	8	4F
0005435715544	7118	9	5C
0005435715545	7118	10	6D
0005435443283	7118	11	6F
0005435715543	7118	12	7C
0005435179387	7118	13	7F
0005435443235	7118	14	8E
0005435216577	7118	15	8F
0005435715541	7118	16	9D
0005435715534	7118	17	9E
0005432398214	7118	18	10C
0005435715531	7118	19	10F
0005432398211	7118	20	11E
0005435219194	7118	21	11F
0005435715532	7118	22	12A
0005432400141	7118	23	12D
0005435715530	7118	24	12E
0005435216576	7118	25	13A
0005435715533	7118	26	13E
0005435715537	7118	27	13F
0005432400140	7118	28	14C
0005435219192	7118	29	14F
0005435443247	7118	30	15D
0005435443223	7118	31	15E
0005435178487	7118	32	16A
0005432398215	7118	33	16C
0005435715529	7118	34	16D
0005435179391	7118	35	16E
0005435216584	7118	36	17C
0005435443236	7118	37	17E
0005435443270	7118	38	17F
0005435178488	7118	39	18A
0005435715538	7118	40	18C
0005435443294	7118	41	19A
0005435219195	7118	42	19C
0005432400142	7118	43	19D
0005435715539	7118	44	20C
0005432398212	7118	45	20D
0005435715535	7118	46	20E
0005435178996	27060	1	1A
0005435715408	27060	2	1F
0005435715374	27060	3	2D
0005435443356	27060	4	3C
0005432398165	27060	5	4F
0005435715375	27060	6	5E
0005435443353	27060	7	6A
0005435443349	27060	8	6C
0005435443351	27060	9	6D
0005435715383	27060	10	6F
0005435715392	27060	11	7E
0005435443357	27060	12	7F
0005435443355	27060	13	9C
0005432398178	27060	14	9D
0005435715460	27060	15	10E
0005435715370	27060	16	11C
0005435715432	27060	17	11D
0005435715409	27060	18	12C
0005432398189	27060	19	13C
0005432398163	27060	20	14E
0005435443350	27060	21	15A
0005435715431	27060	22	15E
0005435443354	27060	23	16D
0005435715452	27060	24	17A
0005435715393	27060	25	16F
0005432398177	27060	26	17C
0005435178501	27060	27	17D
0005435443352	27060	28	17F
0005432398176	27060	29	18C
0005432398173	27060	30	18E
0005435178997	27060	31	19C
0005435715461	27060	32	19D
0005432394067	27060	33	19E
0005435715428	27060	34	20F
0005434084949	2726	1	1A
0005434084952	2726	2	2A
0005434084950	2726	3	1B
0005434084951	2726	4	3A
0005433060409	2726	5	3B
0005434084948	2726	6	4A
0005433060410	2726	7	4B
0005433060397	2726	8	5B
0005433060411	2726	9	6B
0005433060423	28486	1	1A
0005433060424	28486	2	2B
0005434084897	28486	3	3B
0005434084889	28486	4	5A
0005433060425	28486	5	5B
0005435540929	11389	1	1A
0005435540876	11389	2	1F
0005435517909	11389	3	2A
0005435517842	11389	4	2D
0005435540872	11389	5	3A
0005435540987	11389	6	5A
0005435517802	11389	7	5D
0005435540953	11389	8	6A
0005435517763	11389	9	7D
0005435517908	11389	10	7F
0005435517841	11389	11	8A
0005435517799	11389	12	8C
0005435540975	11389	13	8E
0005435517810	11389	14	8F
0005435540899	11389	15	9C
0005435540883	11389	16	9F
0005435517836	11389	17	10C
0005435517780	11389	18	10E
0005435517853	11389	19	11C
0005435517874	11389	20	11D
0005435517850	11389	21	12D
0005435517870	11389	22	13A
0005435540986	11389	23	13E
0005435540881	11389	24	14E
0005435540954	11389	25	15A
0005435517843	11389	26	15E
0005435540884	11389	27	15F
0005435517854	11389	28	16C
0005435540938	11389	29	16F
0005435540944	11389	30	17C
0005435517801	11389	31	17D
0005435517860	11389	32	17E
0005435540915	11389	33	18A
0005435540934	11389	34	18D
0005435540871	11389	35	19C
0005435517875	11389	36	19E
0005435540882	11389	37	20A
0005435517859	11389	38	20C
0005435517835	11389	39	20E
0005435529337	22243	1	1C
0005435541068	22243	2	1D
0005435541082	22243	3	4A
0005435529341	22243	4	4E
0005435541074	22243	5	5A
0005435541086	22243	6	5D
0005435529342	22243	7	5F
0005435541080	22243	8	6A
0005435541088	22243	9	6D
0005435529343	22243	10	6E
0005435541069	22243	11	6F
0005435529326	22243	12	7E
0005435529325	22243	13	8C
0005435529327	22243	14	9A
0005435529332	22243	15	9C
0005435541067	22243	16	9D
0005435541081	22243	17	9E
0005435529323	22243	18	9F
0005435541078	22243	19	10C
0005435541083	22243	20	10D
0005435529336	22243	21	10E
0005435541077	22243	22	10F
0005435541085	22243	23	11A
0005435529338	22243	24	11D
0005432294496	22243	25	12A
0005435541073	22243	26	13D
0005435529329	22243	27	13E
0005435529328	22243	28	14D
0005435541072	22243	29	14E
0005432294494	22243	30	14F
0005435541071	22243	31	15A
0005435529340	22243	32	15D
0005432294497	22243	33	15E
0005435529331	22243	34	16A
0005435529324	22243	35	16D
0005435529335	22243	36	16E
0005435541087	22243	37	16F
0005435541076	22243	38	17C
0005435541066	22243	39	17D
0005435529333	22243	40	18A
0005432294495	22243	41	18C
0005435541070	22243	42	18D
0005435529322	22243	43	18E
0005435529330	22243	44	18F
0005435529334	22243	45	19A
0005435541084	22243	46	19C
0005435529339	22243	47	19D
0005435541075	22243	48	19E
0005435541079	22243	49	19F
0005434907491	2270	1	1A
0005434907505	2270	2	1C
0005434907522	2270	3	1D
0005433251157	2270	4	1F
0005434907500	2270	5	2A
0005434907515	2270	6	2C
0005434907486	2270	7	2D
0005433251345	2270	8	2F
0005434907493	2270	9	3A
0005434907532	2270	10	3D
0005434907511	2270	11	3F
0005434907508	2270	12	4A
0005434907530	2270	13	4C
0005433251259	2270	14	4E
0005433251430	2270	15	4D
0005433251446	2270	16	4F
0005434907504	2270	17	5A
0005434907506	2270	18	5C
0005434907492	2270	19	5D
0005434907502	2270	20	5E
0005434907520	2270	21	5F
0005434907512	2270	22	6A
0005433251332	2270	23	6C
0005434907527	2270	24	6D
0005434907517	2270	25	6E
0005433251355	2270	26	6F
0005434907525	2270	27	7A
0005433251299	2270	28	7C
0005433251258	2270	29	7D
0005434907487	2270	30	7E
0005434907490	2270	31	7F
0005433251457	2270	32	8A
0005434907518	2270	33	8C
0005434907489	2270	34	8E
0005433400980	2270	35	8F
0005434907529	2270	36	9A
0005434907519	2270	37	9C
0005434907499	2270	38	9D
0005434907510	2270	39	9E
0005433251344	2270	40	9F
0005433251311	2270	41	10C
0005433251406	2270	42	10D
0005433400984	2270	43	10E
0005434907495	2270	44	10F
0005434907494	2270	45	11A
0005433251356	2270	46	11C
0005433251313	2270	47	11E
0005433251431	2270	48	11F
0005433251235	2270	49	12A
0005433251424	2270	50	12C
0005433251398	2270	51	12D
0005434907498	2270	52	12E
0005433251400	2270	53	12F
0005433251316	2270	54	13A
0005433251314	2270	55	13C
0005434907514	2270	56	13D
0005434907488	2270	57	13E
0005433251366	2270	58	13F
0005433251399	2270	59	14A
0005434907528	2270	60	14C
0005434907533	2270	61	14D
0005433400963	2270	62	14F
0005433251310	2270	63	15A
0005433400981	2270	64	15C
0005434907521	2270	65	15D
0005433251415	2270	66	15E
0005434907531	2270	67	15F
0005434907507	2270	68	16A
0005433251396	2270	69	16C
0005433251444	2270	70	16D
0005434907524	2270	71	16E
0005433251312	2270	72	17A
0005434907497	2270	73	17C
0005433251222	2270	74	17D
0005433251437	2270	75	17E
0005434907516	2270	76	17F
0005434907501	2270	77	18C
0005433251351	2270	78	18D
0005433251429	2270	79	18E
0005433251303	2270	80	18F
0005433251315	2270	81	19A
0005434907509	2270	82	19D
0005434907523	2270	83	19C
0005433251260	2270	84	19E
0005433251432	2270	85	19F
0005434907496	2270	86	20A
0005434907513	2270	87	20C
0005434907503	2270	88	20D
0005433251438	2270	89	20E
0005434907526	2270	90	20F
0005433251606	25575	1	1A
0005433251608	25575	2	1C
0005434907069	25575	3	1D
0005433251596	25575	4	2A
0005434906978	25575	5	2C
0005434906926	25575	6	2D
0005434906987	25575	7	2F
0005434906900	25575	8	3A
0005433251601	25575	9	3C
0005434907079	25575	10	3D
0005433251621	25575	11	3F
0005434907055	25575	12	4A
0005433400994	25575	13	4C
0005434907040	25575	14	4D
0005433251618	25575	15	4E
0005434907072	25575	16	4F
0005433251614	25575	17	5A
0005434907026	25575	18	5C
0005434906904	25575	19	5D
0005433251622	25575	20	5E
0005434906984	25575	21	5F
0005433251617	25575	22	6A
0005433251609	25575	23	6C
0005434907019	25575	24	6D
0005434907011	25575	25	6F
0005433251623	25575	26	7A
0005434906903	25575	27	7C
0005434906959	25575	28	7D
0005434907002	25575	29	7F
0005433400995	25575	30	8A
0005434906982	25575	31	8C
0005433251594	25575	32	8D
0005433251603	25575	33	8E
0005434907074	25575	34	9A
0005434906977	25575	35	9C
0005434906983	25575	36	9D
0005434906875	25575	37	9E
0005433251605	25575	38	9F
0005433251597	25575	39	10A
0005434907004	25575	40	10C
0005434907021	25575	41	10D
0005433251591	25575	42	10E
0005434907037	25575	43	10F
0005434907000	25575	44	11A
0005434906877	25575	45	11C
0005434907003	25575	46	11D
0005434907046	25575	47	11E
0005433251592	25575	48	11F
0005434906850	25575	49	12A
0005433251604	25575	50	12C
0005433251598	25575	51	12D
0005434907005	25575	52	12E
0005434907038	25575	53	12F
0005434907022	25575	54	13A
0005434906990	25575	55	13C
0005433251600	25575	56	13D
0005434907056	25575	57	13E
0005434907045	25575	58	13F
0005433251593	25575	59	14A
0005434906958	25575	60	14C
0005433251607	25575	61	14D
0005433400996	25575	62	14E
0005434907020	25575	63	15A
0005433251620	25575	64	15C
0005433400997	25575	65	15D
0005434906912	25575	66	15E
0005434907010	25575	67	15F
0005434907054	25575	68	16A
0005434907012	25575	69	16C
0005434907044	25575	70	16D
0005433251611	25575	71	16E
0005433251612	25575	72	16F
0005434907023	25575	73	17A
0005434906885	25575	74	17C
0005433251616	25575	75	17D
0005433251610	25575	76	17E
0005434906878	25575	77	17F
0005434906948	25575	78	18A
0005433251595	25575	79	18C
0005433251599	25575	80	18D
0005434906681	25575	81	18E
0005434906923	25575	82	18F
0005433251619	25575	83	19A
0005434906899	25575	84	19D
0005433251615	25575	85	19E
0005434906682	25575	86	19F
0005434907081	25575	87	20A
0005434906941	25575	88	20C
0005433251613	25575	89	20D
0005433251602	25575	90	20E
0005434906986	25575	91	20F
0005432862259	2516	1	1C
0005432862304	2516	2	2A
0005432621091	2516	3	2C
0005432862245	2516	4	3B
0005432862223	2516	5	3C
0005432621099	2516	6	4A
0005432862280	2516	7	4C
0005432621096	2516	8	4D
0005432621102	2516	9	5A
0005432621101	2516	10	6B
0005432621092	2516	11	6C
0005432621103	2516	12	7A
0005432621100	2516	13	7B
0005432621094	2516	14	18C
0005432621093	2516	15	20A
0005432621097	2516	16	20B
0005432862254	2516	17	20C
0005432621098	2516	18	21B
0005432621095	2516	19	22A
0005432862288	2516	20	23A
0005432862337	28079	1	1C
0005432620922	28079	2	2B
0005432862333	28079	3	3B
0005432862331	28079	4	7B
0005432620993	28079	5	7D
0005432620975	28079	6	18A
0005432620921	28079	7	18D
0005432620918	28079	8	19C
0005432862330	28079	9	20B
0005432862336	28079	10	20C
0005432862332	28079	11	21B
0005432620957	28079	12	21C
0005432620919	28079	13	21D
0005432862334	28079	14	23A
0005432862335	28079	15	23B
0005434191262	32876	1	3F
0005434191258	32876	2	4F
0005434191254	32876	3	9D
0005434191267	32876	4	11D
0005434191269	32876	5	12D
0005434191272	32876	6	13D
0005434191259	32876	7	14D
0005434191266	32876	8	15D
0005434191255	32876	9	16A
0005434191270	32876	10	18A
0005433452747	31096	1	1A
0005433451627	31096	2	1B
0005433452748	31096	3	5B
0005433451626	31096	4	6A
0005433452725	31410	1	2B
0005433452730	31410	2	3A
0005433452729	31410	3	3B
0005433454867	31410	4	4A
0005433454864	31410	5	4B
0005433454869	31410	6	5B
0005433454868	31410	7	6B
0005434184656	11994	1	1A
0005434142575	11994	2	3D
0005433129252	11994	3	4A
0005433134113	11994	4	4B
0005433134103	11994	5	4C
0005433129253	11994	6	7B
0005434184653	11994	7	7C
0005434142574	11994	8	7D
0005433134106	11994	9	20B
0005434142593	11994	10	21A
0005434142596	11994	11	21B
0005433134156	29815	1	2B
0005433131728	29815	2	2C
0005434142624	29815	3	3B
0005434183588	29815	4	4D
0005434142623	29815	5	5B
0005434184673	29815	6	5D
0005434184674	29815	7	6A
0005434142622	29815	8	6B
0005433131726	29815	9	19A
0005433134155	29815	10	19C
0005434183587	29815	11	20A
0005433134158	29815	12	21C
0005433131725	29815	13	21D
0005433134157	29815	14	22B
0005433131727	29815	15	22D
0005434142625	29815	16	23A
0005434183589	29815	17	23B
0005435798947	1604	1	1D
0005435798951	1604	2	3A
0005435798952	1604	3	3B
0005435798958	1604	4	5C
0005435798949	1604	5	6A
0005435798954	1604	6	6C
0005435798959	1604	7	6D
0005435798946	1604	8	7C
0005435798957	1604	9	19D
0005435798960	1604	10	20A
0005435798956	1604	11	20B
0005435798955	1604	12	21C
0005435798950	1604	13	22A
0005435798953	1604	14	22B
0005435798948	1604	15	23B
0005435697444	16501	1	1A
0005435697445	16501	2	1B
0005435697429	16501	3	1C
0005435935020	16501	4	2A
0005435697432	16501	5	2B
0005435935028	16501	6	2C
0005435697424	16501	7	2D
0005435697421	16501	8	3B
0005435697436	16501	9	3C
0005435697417	16501	10	3D
0005435697438	16501	11	4A
0005435697419	16501	12	4B
0005435697418	16501	13	4C
0005435697423	16501	14	4D
0005435697433	16501	15	5C
0005435697440	16501	16	5D
0005435697443	16501	17	6B
0005435697420	16501	18	6D
0005435935029	16501	19	7C
0005435697442	16501	20	7D
0005435697439	16501	21	18B
0005435697426	16501	22	18C
0005435697430	16501	23	19A
0005435697431	16501	24	19B
0005435697428	16501	25	19C
0005435697427	16501	26	20B
0005435697434	16501	27	20C
0005435697437	16501	28	20D
0005435697422	16501	29	21C
0005435697441	16501	30	22A
0005435697425	16501	31	22C
0005435697435	16501	32	23A
0005435697232	24724	1	1A
0005435697200	24724	2	1C
0005435697230	24724	3	1D
0005435697264	24724	4	2A
0005435697137	24724	5	2B
0005435935059	24724	6	2D
0005435697237	24724	7	3B
0005435697163	24724	8	3C
0005435697284	24724	9	4A
0005435697282	24724	10	4D
0005435935061	24724	11	5B
0005435935060	24724	12	6D
0005435697320	24724	13	7B
0005435697256	24724	14	7C
0005435697356	24724	15	7D
0005435697231	24724	16	19C
0005435697283	24724	17	20A
0005435697198	24724	18	20B
0005435697318	24724	19	21B
0005435697188	24724	20	21A
0005435697195	24724	21	21D
0005435697196	24724	22	22A
0005435697201	24724	23	22B
0005435697271	24724	24	22C
0005435697266	24724	25	23A
0005435697315	24724	26	23B
0005433724819	18815	1	1A
0005433724821	18815	2	2A
0005433724820	18815	3	2B
0005433724800	21606	1	1A
0005433724801	21606	2	1B
0005433724790	21606	3	2B
0005433724789	21606	4	3A
0005432968852	21606	5	4B
0005432968851	21606	6	5B
0005433724787	21606	7	6A
0005433724794	21606	8	6B
0005434087535	7293	1	1A
0005434138491	7293	2	1C
0005434138479	7293	3	1D
0005434138550	7293	4	1F
0005434138470	7293	5	2A
0005434138496	7293	6	2C
0005434138490	7293	7	2D
0005434138503	7293	8	2F
0005434138512	7293	9	3A
0005434138474	7293	10	3C
0005434138543	7293	11	3D
0005434138504	7293	12	3F
0005434138481	7293	13	4A
0005434138540	7293	14	4C
0005434138538	7293	15	4D
0005434138499	7293	16	4E
0005434138546	7293	17	4F
0005434087531	7293	18	5A
0005434138518	7293	19	5C
0005434138537	7293	20	5D
0005434138524	7293	21	5E
0005434138508	7293	22	5F
0005434138507	7293	23	6A
0005434138521	7293	24	6C
0005434138532	7293	25	6D
0005434138533	7293	26	6E
0005434138480	7293	27	6F
0005434138486	7293	28	7D
0005434138530	7293	29	7E
0005434138547	7293	30	7F
0005434087533	7293	31	8A
0005434138489	7293	32	8C
0005434138492	7293	33	8D
0005434138542	7293	34	8E
0005434138536	7293	35	8F
0005434138488	7293	36	9A
0005434138495	7293	37	9E
0005434138548	7293	38	9F
0005434138551	7293	39	10A
0005434138534	7293	40	10C
0005434138483	7293	41	10D
0005434138523	7293	42	10E
0005434138525	7293	43	10F
0005434138535	7293	44	11C
0005434138516	7293	45	11A
0005434138527	7293	46	11D
0005434138539	7293	47	11E
0005434138477	7293	48	11F
0005434138552	7293	49	12A
0005434138472	7293	50	12D
0005434138519	7293	51	12E
0005434138511	7293	52	12F
0005434087534	7293	53	13A
0005434138476	7293	54	13C
0005434138528	7293	55	13D
0005434138505	7293	56	13E
0005434138498	7293	57	13F
0005434138497	7293	58	14A
0005434138517	7293	59	14C
0005434138545	7293	60	14D
0005434138482	7293	61	14E
0005434138531	7293	62	14F
0005434138544	7293	63	15A
0005434138502	7293	64	15C
0005434087536	7293	65	15D
0005434087532	7293	66	15E
0005434138500	7293	67	15F
0005434138541	7293	68	16A
0005434138513	7293	69	16C
0005434138514	7293	70	16D
0005434138493	7293	71	16E
0005434138485	7293	72	16F
0005434138510	7293	73	17A
0005434138515	7293	74	17C
0005434138501	7293	75	17D
0005434138549	7293	76	17E
0005434138471	7293	77	18A
0005434138506	7293	78	18C
0005434138487	7293	79	18D
0005434138529	7293	80	18E
0005434138494	7293	81	18F
0005434138473	7293	82	19A
0005434138475	7293	83	19C
0005434138522	7293	84	19D
0005434138526	7293	85	19E
0005434138509	7293	86	20A
0005434138520	7293	87	20C
0005434138478	7293	88	20D
0005434138484	7293	89	20E
0005434137677	28532	1	1A
0005434137703	28532	2	1D
0005434137563	28532	3	1C
0005434137725	28532	4	1F
0005434137788	28532	5	2A
0005434137870	28532	6	2C
0005434137658	28532	7	2D
0005434137564	28532	8	2F
0005434137659	28532	9	3A
0005434137592	28532	10	3C
0005434137859	28532	11	3D
0005434137336	28532	12	3F
0005434087495	28532	13	4A
0005434137671	28532	14	4C
0005434137745	28532	15	4D
0005434137786	28532	16	4E
0005434137794	28532	17	4F
0005434137799	28532	18	5A
0005434137672	28532	19	5C
0005434137681	28532	20	5D
0005434087476	28532	21	5E
0005434087475	28532	22	6A
0005434137789	28532	23	6C
0005434137878	28532	24	6D
0005434137850	28532	25	6E
0005434137839	28532	26	6F
0005434137840	28532	27	7A
0005434137691	28532	28	7C
0005434137568	28532	29	7D
0005434137857	28532	30	7E
0005434137818	28532	31	7F
0005434137634	28532	32	8A
0005434137245	28532	33	8C
0005434137849	28532	34	8D
0005434137244	28532	35	8F
0005434137555	28532	36	9A
0005434087508	28532	37	9C
0005434137660	28532	38	9D
0005434137695	28532	39	9E
0005434137761	28532	40	9F
0005434137573	28532	41	10C
0005434137523	28532	42	10D
0005434087502	28532	43	10E
0005434137743	28532	44	10F
0005434137755	28532	45	11A
0005434137654	28532	46	11D
0005434137653	28532	47	11E
0005434137377	28532	48	11F
0005434137376	28532	49	12C
0005434137429	28532	50	12D
0005434137495	28532	51	12E
0005434137865	28532	52	12F
0005434087503	28532	53	13C
0005434137676	28532	54	13D
0005434087494	28532	55	13F
0005434137847	28532	56	14A
0005434137449	28532	57	14C
0005434137889	28532	58	14D
0005434137524	28532	59	14E
0005434137582	28532	60	14F
0005434137611	28532	61	15A
0005434137845	28532	62	15C
0005434137792	28532	63	15D
0005434137556	28532	64	15E
0005434137754	28532	65	15F
0005434137762	28532	66	16A
0005434137567	28532	67	16C
0005434137243	28532	68	16D
0005434137442	28532	69	16F
0005434137423	28532	70	17A
0005434137744	28532	71	17C
0005434137800	28532	72	17D
0005434137540	28532	73	17E
0005434137696	28532	74	17F
0005434137879	28532	75	18A
0005434137802	28532	76	18C
0005434137773	28532	77	18D
0005434137692	28532	78	18E
0005434137752	28532	79	18F
0005434137690	28532	80	19A
0005434137614	28532	81	19C
0005434137633	28532	82	19D
0005434137518	28532	83	19E
0005434137583	28532	84	19F
0005434087504	28532	85	20A
0005434137584	28532	86	20C
0005434137785	28532	87	20D
0005434137637	28532	88	20E
0005434137359	28532	89	20F
0005434610243	1911	1	1A
0005433407508	1911	2	1B
0005435808278	1911	3	1D
0005434610244	1911	4	2B
0005433407532	1911	5	3B
0005435808280	1911	6	4B
0005435808281	1911	7	4C
0005435808276	1911	8	5A
0005433407553	1911	9	5C
0005435808277	1911	10	6B
0005434610242	1911	11	6D
0005434610245	1911	12	7D
0005435808275	1911	13	18A
0005435808282	1911	14	18D
0005435808283	1911	15	19A
0005435808279	1911	16	19D
0005435808274	1911	17	21D
0005434610201	23099	1	1B
0005434610219	23099	2	2D
0005434610202	23099	3	3C
0005434610212	23099	4	19C
0005434610214	23099	5	20B
0005434610215	23099	6	20D
0005434503850	16687	1	1B
0005434503796	16687	2	1C
0005434503876	16687	3	2A
0005434504043	16687	4	2B
0005434503924	16687	5	2C
0005434503925	16687	6	2D
0005434503895	16687	7	3A
0005434504055	16687	8	3B
0005434504029	16687	9	3C
0005434503915	16687	10	3D
0005434503783	16687	11	4A
0005434503961	16687	12	4B
0005434503884	16687	13	4C
0005434503879	16687	14	4D
0005434503973	16687	15	5A
0005434504084	16687	16	5B
0005434503799	16687	17	5C
0005434503900	16687	18	5D
0005434503914	16687	19	6A
0005434503825	16687	20	6B
0005434503967	16687	21	6C
0005434503784	16687	22	6D
0005434503885	16687	23	7A
0005434503841	16687	24	7B
0005434503968	16687	25	7C
0005434503983	16687	26	7D
0005434503985	16687	27	18A
0005434503894	16687	28	18B
0005434503822	16687	29	18C
0005434504040	16687	30	18D
0005434503798	16687	31	19A
0005434504056	16687	32	19B
0005434503899	16687	33	19C
0005434503867	16687	34	19D
0005434503987	16687	35	20A
0005434503821	16687	36	20B
0005434504041	16687	37	20C
0005434503737	16687	38	20D
0005434504005	16687	39	21B
0005434504050	16687	40	21A
0005434503795	16687	41	21C
0005434504039	16687	42	21D
0005434503756	16687	43	22A
0005434503988	16687	44	22B
0005434503986	16687	45	22C
0005434503738	16687	46	22D
0005434504042	16687	47	23A
0005434503984	16687	48	23B
0005434504294	22896	1	1B
0005434504286	22896	2	1C
0005434504291	22896	3	1D
0005434504297	22896	4	2A
0005434504266	22896	5	2B
0005434504281	22896	6	3B
0005434504269	22896	7	3C
0005434504296	22896	8	3D
0005434504288	22896	9	4B
0005434504261	22896	10	4C
0005434504275	22896	11	4D
0005434504280	22896	12	5A
0005434504289	22896	13	5B
0005434504274	22896	14	5C
0005434504299	22896	15	5D
0005434504262	22896	16	6A
0005434504264	22896	17	6B
0005434504279	22896	18	6C
0005434504282	22896	19	6D
0005434504277	22896	20	7A
0005434504270	22896	21	7B
0005434504290	22896	22	7C
0005434504272	22896	23	7D
0005434504268	22896	24	18B
0005434504278	22896	25	18D
0005434504287	22896	26	19A
0005434504267	22896	27	19B
0005434504276	22896	28	20A
0005434504284	22896	29	20B
0005434504263	22896	30	20C
0005434504300	22896	31	20D
0005434504285	22896	32	21A
0005434504295	22896	33	21B
0005434504293	22896	34	21C
0005434504283	22896	35	21D
0005434504265	22896	36	22A
0005434504298	22896	37	22B
0005434504292	22896	38	22D
0005434504273	22896	39	23B
0005434504271	22896	40	23A
0005434608320	6501	1	1A
0005434608322	6501	2	2B
0005434608318	6501	3	3B
0005434608329	6501	4	3C
0005434608324	6501	5	4B
0005434608333	6501	6	6C
0005434608337	6501	7	6D
0005434608336	6501	8	7A
0005434608330	6501	9	7C
0005434608319	6501	10	18C
0005434608328	6501	11	19A
0005434608338	6501	12	19B
0005434608331	6501	13	19C
0005434608325	6501	14	20A
0005434608327	6501	15	20C
0005434608321	6501	16	20D
0005434608326	6501	17	21B
0005434608332	6501	18	21C
0005434608323	6501	19	21D
0005434608335	6501	20	22C
0005434608334	6501	21	23A
0005434608304	22493	1	1B
0005434608284	22493	2	1C
0005434608288	22493	3	2D
0005434608315	22493	4	3A
0005434608300	22493	5	3D
0005434608289	22493	6	4B
0005434608292	22493	7	5A
0005434608291	22493	8	6A
0005434608298	22493	9	7A
0005434608281	22493	10	7B
0005434608293	22493	11	7C
0005434608282	22493	12	18C
0005434608314	22493	13	18D
0005434608297	22493	14	19A
0005434608295	22493	15	20A
0005434608285	22493	16	20D
0005434608283	22493	17	21A
0005434608299	22493	18	21D
0005434608296	22493	19	22B
0005434608305	22493	20	23A
0005434608290	22493	21	23B
0005433266666	2183	1	1A
0005435078412	2183	2	1C
0005433266652	2183	3	2B
0005435078405	2183	4	3C
0005435078401	2183	5	4A
0005435078410	2183	6	4D
0005435078409	2183	7	5D
0005435078413	2183	8	6A
0005433266653	2183	9	7B
0005433266665	2183	10	7C
0005435078408	2183	11	18B
0005435078404	2183	12	18C
0005435078406	2183	13	19B
0005435078407	2183	14	19C
0005435078411	2183	15	20C
0005433266651	2183	16	20D
0005435078399	2183	17	21B
0005435078402	2183	18	22A
0005435078400	2183	19	22D
0005435078403	2183	20	22C
0005433266758	24353	1	1C
0005435078290	24353	2	2A
0005433266760	24353	3	2C
0005435078261	24353	4	2D
0005433266762	24353	5	3B
0005433266763	24353	6	4A
0005435078260	24353	7	4B
0005433266757	24353	8	4C
0005435078325	24353	9	5C
0005435078288	24353	10	7B
0005435078241	24353	11	18B
0005435078304	24353	12	18C
0005433266759	24353	13	19B
0005435078273	24353	14	19D
0005435078250	24353	15	20A
0005433266761	24353	16	20B
0005435078351	24353	17	20C
0005435078283	24353	18	20D
0005435078248	24353	19	21A
0005433266765	24353	20	21B
0005433266764	24353	21	21C
0005435078249	24353	22	22B
0005434988790	6652	1	4A
0005434988788	6652	2	5B
0005434988789	6652	3	5D
0005434988786	6652	4	7A
0005435803275	6652	5	7B
0005435803276	6652	6	18D
0005434988785	6652	7	19B
0005434988784	6652	8	20B
0005434988787	6652	9	23A
0005435803274	6652	10	23B
0005434988664	23636	1	1D
0005434988641	23636	2	2D
0005434988646	23636	3	5A
0005434988650	23636	4	5B
0005434988666	23636	5	7B
0005434988661	23636	6	19A
0005434988659	23636	7	19C
0005435803264	23636	8	22B
0005434988660	23636	9	22D
0005432383318	30511	1	1A
0005432383338	30511	2	1C
0005433450062	30511	3	1F
0005433450059	30511	4	2C
0005433450068	30511	5	2F
0005432383326	30511	6	3A
0005432383349	30511	7	3C
0005432383344	30511	8	4C
0005433450063	30511	9	4D
0005433453769	30511	10	4E
0005433450056	30511	11	4F
0005433450070	30511	12	5A
0005433450067	30511	13	5E
0005432383320	30511	14	5F
0005433454884	30511	15	6A
0005433450058	30511	16	6C
0005432383330	30511	17	6D
0005433450060	30511	18	6E
0005432383350	30511	19	6F
0005432383336	30511	20	7A
0005432383339	30511	21	7C
0005432383317	30511	22	7F
0005433450055	30511	23	8C
0005432383323	30511	24	8D
0005432383341	30511	25	8E
0005433450065	30511	26	8F
0005433454886	30511	27	9A
0005433454883	30511	28	9D
0005433450053	30511	29	9E
0005432383355	30511	30	9F
0005432383347	30511	31	10C
0005432383334	30511	32	10F
0005432383332	30511	33	11A
0005432383356	30511	34	11C
0005432383345	30511	35	11D
0005432383343	30511	36	11F
0005432383324	30511	37	12A
0005433450071	30511	38	12C
0005432383357	30511	39	12D
0005432383328	30511	40	12F
0005432383353	30511	41	13C
0005432383331	30511	42	13D
0005432383321	30511	43	13E
0005432383340	30511	44	13F
0005432383351	30511	45	14A
0005432383319	30511	46	14D
0005432383322	30511	47	14E
0005433450073	30511	48	15A
0005432383342	30511	49	15C
0005432383346	30511	50	15E
0005433450069	30511	51	16A
0005432383327	30511	52	16C
0005432383354	30511	53	16D
0005433450064	30511	54	16E
0005432383333	30511	55	17D
0005432383352	30511	56	17E
0005432383325	30511	57	17F
0005433450066	30511	58	18A
0005433450061	30511	59	18C
0005433450052	30511	60	18D
0005433450072	30511	61	18E
0005432383337	30511	62	18F
0005432383329	30511	63	19A
0005433454885	30511	64	19C
0005432383358	30511	65	19D
0005433450054	30511	66	19E
0005433450057	30511	67	19F
0005432383335	30511	68	20D
0005432383348	30511	69	20F
0005433449881	31296	1	1F
0005432382779	31296	2	2A
0005432383123	31296	3	2C
0005432382901	31296	4	2D
0005433450007	31296	5	3A
0005432383001	31296	6	3D
0005433449798	31296	7	3F
0005432382977	31296	8	4E
0005432382777	31296	9	4F
0005432383075	31296	10	5A
0005432382900	31296	11	5C
0005433449942	31296	12	5D
0005433449876	31296	13	5E
0005433450006	31296	14	5F
0005432382844	31296	15	6A
0005432382945	31296	16	6C
0005432382733	31296	17	6D
0005432382947	31296	18	6E
0005433449762	31296	19	7A
0005432382949	31296	20	7C
0005432382989	31296	21	7D
0005432382859	31296	22	8A
0005432382921	31296	23	8C
0005433449847	31296	24	8D
0005432383074	31296	25	8E
0005433449879	31296	26	9A
0005432382909	31296	27	9F
0005432382953	31296	28	10C
0005432382902	31296	29	10D
0005432382827	31296	30	10E
0005432382873	31296	31	10F
0005432382787	31296	32	11C
0005432382759	31296	33	11D
0005433449827	31296	34	11E
0005432382755	31296	35	12A
0005432382855	31296	36	12C
0005432382736	31296	37	12D
0005432383002	31296	38	12E
0005432382781	31296	39	12F
0005433449885	31296	40	13A
0005433449914	31296	41	13C
0005432382780	31296	42	13D
0005432382925	31296	43	13E
0005432383124	31296	44	13F
0005432383122	31296	45	14C
0005433451609	31296	46	14E
0005432383088	31296	47	15C
0005432382946	31296	48	15D
0005433449788	31296	49	15E
0005433453759	31296	50	15F
0005432382954	31296	51	16A
0005432382908	31296	52	16E
0005433449938	31296	53	16F
0005432382881	31296	54	17C
0005432382926	31296	55	17D
0005432382922	31296	56	17F
0005432382835	31296	57	18A
0005432382978	31296	58	18C
0005432382948	31296	59	18D
0005432382778	31296	60	18F
0005432383168	31296	61	19A
0005433449864	31296	62	19F
0005432382903	31296	63	20C
0005433453760	31296	64	20E
0005433449870	31296	65	20F
0005433788217	20822	1	1A
0005435548452	20822	2	1B
0005433788218	20822	3	1C
0005435548440	20822	4	2B
0005435548428	20822	5	2C
0005433788212	20822	6	3A
0005435548460	20822	7	3D
0005433788210	20822	8	4A
0005433788216	20822	9	5A
0005435548464	20822	10	5B
0005433788209	20822	11	5D
0005435548427	20822	12	6C
0005435548467	20822	13	7A
0005433788208	20822	14	7B
0005435548453	20822	15	7C
0005435548448	20822	16	18D
0005433788215	20822	17	19A
0005433788214	20822	18	19B
0005433788207	20822	19	19C
0005433788213	20822	20	20A
0005433788206	20822	21	20D
0005435548454	20822	22	21B
0005435548449	20822	23	22C
0005433788211	20822	24	23A
0005435548444	20822	25	22D
0005433126805	10768	1	2B
0005433126811	10768	2	2D
0005433131663	10768	3	3A
0005435299748	10768	4	3B
0005433131697	10768	5	3C
0005435299747	10768	6	4A
0005433126822	10768	7	4B
0005435299739	10768	8	4D
0005433126809	10768	9	5C
0005433126806	10768	10	7B
0005433126810	10768	11	18A
0005433126830	10768	12	18B
0005435299762	10768	13	18D
0005435299721	10768	14	19C
0005433126803	10768	15	22B
0005435299749	10768	16	23A
0005433126867	29746	1	1B
0005435299799	29746	2	1C
0005433126869	29746	3	1D
0005433126870	29746	4	2A
0005435302223	29746	5	2C
0005435299800	29746	6	3C
0005433129297	29746	7	4C
0005435302221	29746	8	6A
0005433129300	29746	9	7A
0005433126866	29746	10	7B
0005433126868	29746	11	19A
0005435299801	29746	12	19B
0005435302224	29746	13	20B
0005435302220	29746	14	20C
0005433129298	29746	15	21B
0005435299802	29746	16	22A
0005433129299	29746	17	22B
0005435302222	29746	18	22D
0005433110027	2424	1	1A
0005433110061	2424	2	1B
0005434287391	2424	3	1C
0005433110039	2424	4	1D
0005432264485	2424	5	2A
0005433110021	2424	6	2B
0005433110005	2424	7	2C
0005434287373	2424	8	2D
0005433110095	2424	9	3A
0005434287375	2424	10	3B
0005433110026	2424	11	3C
0005432264484	2424	12	3D
0005433110041	2424	13	4A
0005433110022	2424	14	4B
0005434287383	2424	15	4C
0005433110006	2424	16	4D
0005433110025	2424	17	5C
0005434287376	2424	18	5D
0005434287379	2424	19	6B
0005434287385	2424	20	6A
0005434287372	2424	21	6C
0005434287389	2424	22	6D
0005434287378	2424	23	7A
0005434287371	2424	24	7B
0005434287384	2424	25	7C
0005434287388	2424	26	7D
0005433109973	2424	27	18A
0005434287381	2424	28	18B
0005433110019	2424	29	18D
0005433110016	2424	30	19A
0005434287386	2424	31	19B
0005434287380	2424	32	19C
0005433109990	2424	33	19D
0005433110040	2424	34	20A
0005434287374	2424	35	20C
0005434287382	2424	36	20D
0005434287387	2424	37	21B
0005434287390	2424	38	21D
0005432264486	2424	39	22A
0005433110014	2424	40	22B
0005434287377	2424	41	22D
0005434287392	2424	42	23A
0005433110097	26834	1	1B
0005434287253	26834	2	1C
0005433110107	26834	3	2A
0005434287088	26834	4	2B
0005434287120	26834	5	2C
0005433110098	26834	6	2D
0005434287169	26834	7	3C
0005434287119	26834	8	3D
0005433110105	26834	9	4B
0005433110101	26834	10	4C
0005434287172	26834	11	5A
0005433110102	26834	12	5C
0005434287199	26834	13	5D
0005434287200	26834	14	6A
0005434287146	26834	15	6B
0005433110109	26834	16	6C
0005433110108	26834	17	6D
0005434287107	26834	18	7B
0005434287252	26834	19	7C
0005433110104	26834	20	7D
0005433110100	26834	21	18A
0005434287145	26834	22	18B
0005434287112	26834	23	18D
0005433110099	26834	24	19B
0005434287225	26834	25	19D
0005434287173	26834	26	20C
0005434287241	26834	27	20D
0005434287211	26834	28	21A
0005433110106	26834	29	21D
0005434287152	26834	30	22A
0005434287191	26834	31	22C
0005433110103	26834	32	22D
0005434269093	25444	1	2A
0005435856220	25444	2	2B
0005435856222	25444	3	2C
0005435856223	25444	4	2D
0005434272182	25444	5	7D
0005434272178	25444	6	18A
0005435856221	25444	7	18C
0005434272180	25444	8	19D
0005434272179	25444	9	21C
0005434269089	25444	10	22C
0005434272198	26673	1	1C
0005435854045	26673	2	2C
0005435856171	26673	3	2D
0005435854046	26673	4	3A
0005435856179	26673	5	3D
0005435856172	26673	6	4A
0005435856177	26673	7	6B
0005434273083	26673	8	6D
0005435856178	26673	9	18A
0005435856191	26673	10	19C
0005435856180	26673	11	20C
0005435856186	26673	12	21D
0005435854048	26673	13	22A
0005434273082	26673	14	22B
0005434273081	26673	15	23B
0005434520221	19079	1	1A
0005435314844	19079	2	1B
0005434520194	19079	3	1C
0005434520235	19079	4	2A
0005434520245	19079	5	2B
0005434520262	19079	6	2C
0005434520231	19079	7	2D
0005434520217	19079	8	3A
0005435314850	19079	9	3B
0005435314849	19079	10	3C
0005434520211	19079	11	3D
0005434520238	19079	12	4A
0005435314845	19079	13	4B
0005435314851	19079	14	4C
0005435314846	19079	15	4D
0005435314848	19079	16	5B
0005434520263	19079	17	5D
0005434520230	19079	18	6A
0005435314854	19079	19	6B
0005434520220	19079	20	6C
0005434520186	19079	21	6D
0005435314847	19079	22	7A
0005434520198	19079	23	7B
0005434520212	19079	24	7C
0005434520195	19079	25	7D
0005434520222	19079	26	18B
0005435314852	19079	27	18C
0005434520233	19079	28	18D
0005434520244	19079	29	19A
0005434520243	19079	30	19B
0005435314853	19079	31	19C
0005434520236	19079	32	19D
0005434520197	19079	33	20A
0005434520239	19079	34	20B
0005435314855	19079	35	20C
0005434520232	19079	36	20D
0005434520156	19079	37	21A
0005435314856	19079	38	21B
0005435314857	19079	39	21C
0005434520189	19079	40	21D
0005434520229	19079	41	22A
0005434520196	19079	42	22B
0005434520237	19079	43	22C
0005434520193	19079	44	22D
0005435314858	19079	45	23A
0005434520213	19079	46	23B
0005433874365	7795	1	2D
0005433874361	7795	2	3B
0005433874369	7795	3	5C
0005433874362	7795	4	6C
0005433874368	7795	5	7A
0005433874363	7795	6	19A
0005433874367	7795	7	19D
0005433874360	7795	8	20B
0005433874366	7795	9	20D
0005433874359	7795	10	21C
0005433874364	7795	11	23A
0005433874327	32640	1	1A
0005433874330	32640	2	1B
0005433874321	32640	3	2B
0005433874326	32640	4	5D
0005433874337	32640	5	7D
0005433874336	32640	6	20C
0005433874335	32640	7	22C
0005433868620	4797	1	1A
0005433868622	4797	2	1B
0005435860469	4797	3	1C
0005433868594	4797	4	1D
0005433868625	4797	5	2A
0005433868606	4797	6	2C
0005433868611	4797	7	3B
0005433868607	4797	8	3D
0005433868608	4797	9	4A
0005435860455	4797	10	4B
0005433868609	4797	11	4C
0005433868627	4797	12	4D
0005433868626	4797	13	5A
0005433868628	4797	14	5B
0005433868610	4797	15	5D
0005433868623	4797	16	6A
0005433868605	4797	17	6B
0005433868617	4797	18	6C
0005433868600	4797	19	6D
0005433868621	4797	20	7A
0005433868624	4797	21	7D
0005433868612	4797	22	18A
0005433868601	4797	23	18B
0005433868616	4797	24	18D
0005433868599	4797	25	19A
0005433868603	4797	26	19B
0005433868619	4797	27	19C
0005433868618	4797	28	20A
0005433868615	4797	29	20B
0005433868614	4797	30	20D
0005433868602	4797	31	20C
0005433868596	4797	32	21B
0005433868613	4797	33	21C
0005433868604	4797	34	21D
0005433868629	4797	35	22A
0005433868595	4797	36	22C
0005433868598	4797	37	23A
0005433868597	4797	38	23B
0005433868256	32613	1	1B
0005433868173	32613	2	1C
0005433868241	32613	3	1D
0005433868161	32613	4	2A
0005433868213	32613	5	2C
0005433868281	32613	6	2B
0005433868126	32613	7	2D
0005433868338	32613	8	3A
0005433868214	32613	9	3B
0005433868280	32613	10	3C
0005433868310	32613	11	3D
0005433868153	32613	12	4B
0005433868137	32613	13	4C
0005433868218	32613	14	4D
0005433868138	32613	15	5B
0005433868227	32613	16	5C
0005433868190	32613	17	5D
0005433868136	32613	18	6A
0005433868236	32613	19	6B
0005433868175	32613	20	6C
0005433868276	32613	21	6D
0005433868216	32613	22	7A
0005433868275	32613	23	7B
0005433868144	32613	24	7C
0005433868124	32613	25	7D
0005433868189	32613	26	18A
0005433868184	32613	27	18B
0005433868152	32613	28	18C
0005433868222	32613	29	18D
0005433868185	32613	30	19A
0005433868242	32613	31	19B
0005433868339	32613	32	19D
0005433868095	32613	33	20A
0005433868362	32613	34	20B
0005435860502	32613	35	20C
0005433868174	32613	36	20D
0005433868253	32613	37	21A
0005433868363	32613	38	21B
0005433868199	32613	39	21C
0005433868314	32613	40	21D
0005433868104	32613	41	22A
0005433867963	32613	42	22B
0005435860503	32613	43	22C
0005433868139	32613	44	22D
0005433868337	32613	45	23A
0005433868308	32613	46	23B
0005435911414	3430	1	1A
0005435911394	3430	2	1C
0005434460514	3430	3	2B
0005434460515	3430	4	2C
0005435911386	3430	5	2D
0005434663460	3430	6	3A
0005435911425	3430	7	3C
0005435911415	3430	8	3D
0005434663459	3430	9	4A
0005434663465	3430	10	4C
0005434461656	3430	11	4D
0005435911423	3430	12	5B
0005434460516	3430	13	7A
0005434663469	3430	14	7B
0005434663466	3430	15	7D
0005434663468	3430	16	18B
0005434663470	3430	17	18D
0005434663464	3430	18	19D
0005434663462	3430	19	20C
0005434663471	3430	20	20D
0005435911424	3430	21	21A
0005434663463	3430	22	21B
0005434461655	3430	23	21C
0005434663461	3430	24	22A
0005434663467	3430	25	22C
0005435911420	3430	26	22D
0005434460484	12484	1	1A
0005434663299	12484	2	1B
0005434462777	12484	3	1C
0005434462778	12484	4	1D
0005435911484	12484	5	2A
0005434663297	12484	6	2B
0005435911480	12484	7	2C
0005434462776	12484	8	2D
0005434460494	12484	9	3A
0005434460493	12484	10	3C
0005434462782	12484	11	3D
0005435911483	12484	12	4A
0005434663366	12484	13	4B
0005435911479	12484	14	4C
0005434462781	12484	15	5A
0005434663364	12484	16	5B
0005435911482	12484	17	5C
0005435911481	12484	18	5D
0005434460487	12484	19	6B
0005435911486	12484	20	6C
0005434663365	12484	21	7A
0005434462761	12484	22	7B
0005434462768	12484	23	7D
0005434663387	12484	24	18D
0005434462779	12484	25	19A
0005434663418	12484	26	19C
0005434460497	12484	27	20B
0005434663396	12484	28	21C
0005434460479	12484	29	22B
0005434663298	12484	30	22C
0005435911485	12484	31	23A
0005434462774	12484	32	23B
0005433868280	14493	1	1A
0005433868175	14493	2	1B
0005433868281	14493	3	1C
0005433868241	14493	4	1D
0005433868253	14493	5	2A
0005433868137	14493	6	2B
0005433868216	14493	7	2D
0005433868184	14493	8	3A
0005433868126	14493	9	3B
0005433868190	14493	10	3C
0005433868337	14493	11	3D
0005433868227	14493	12	4A
0005433868338	14493	13	4B
0005433868363	14493	14	4C
0005433868138	14493	15	4D
0005433868214	14493	16	5A
0005433868185	14493	17	5B
0005433868276	14493	18	5C
0005435860502	14493	19	5D
0005433868152	14493	20	6A
0005433868153	14493	21	6B
0005433868236	14493	22	6C
0005433868339	14493	23	6D
0005435860503	14493	24	7A
0005433868139	14493	25	7B
0005433868173	14493	26	7C
0005433868189	14493	27	7D
0005433867963	14493	28	18A
0005433868222	14493	29	18B
0005433868308	14493	30	18C
0005433868136	14493	31	19A
0005433868314	14493	32	19B
0005433868362	14493	33	19C
0005433868161	14493	34	19D
0005433868256	14493	35	20A
0005433868199	14493	36	20B
0005433868174	14493	37	20D
0005433868242	14493	38	21A
0005433868124	14493	39	21B
0005433868144	14493	40	21D
0005433868104	14493	41	22A
0005433868218	14493	42	22B
0005433868095	14493	43	22C
0005433868275	14493	44	22D
0005433868310	14493	45	23A
0005433868213	14493	46	23B
0005433868564	32654	1	1A
0005433868576	32654	2	1B
0005433868581	32654	3	1C
0005433868561	32654	4	1D
0005435860456	32654	5	2A
0005433868570	32654	6	2B
0005433868566	32654	7	2C
0005433868589	32654	8	2D
0005433868583	32654	9	3A
0005433868573	32654	10	3B
0005433868582	32654	11	4B
0005433868590	32654	12	4C
0005433868579	32654	13	4D
0005433868592	32654	14	5A
0005433868555	32654	15	5B
0005433868588	32654	16	5C
0005433868559	32654	17	5D
0005433868568	32654	18	6A
0005433868563	32654	19	6B
0005433868586	32654	20	6C
0005433868591	32654	21	6D
0005433868585	32654	22	7A
0005433868562	32654	23	7B
0005435860458	32654	24	7C
0005433868569	32654	25	7D
0005433868567	32654	26	18A
0005433868558	32654	27	18B
0005433868572	32654	28	18C
0005433868575	32654	29	18D
0005435860457	32654	30	19A
0005433868574	32654	31	19B
0005433868552	32654	32	19C
0005433868571	32654	33	19D
0005433868557	32654	34	20A
0005433868587	32654	35	20B
0005433868577	32654	36	20C
0005433868565	32654	37	20D
0005433868553	32654	38	21A
0005433868578	32654	39	21B
0005433868593	32654	40	21C
0005433868554	32654	41	21D
0005433868556	32654	42	22A
0005433868584	32654	43	22B
0005433868580	32654	44	22C
0005435860466	32654	45	22D
0005433868560	32654	46	23B
0005432799230	12118	1	1A
0005432799257	12118	2	2B
0005432799399	12118	3	2C
0005432799188	12118	4	2D
0005432799403	12118	5	3A
0005432799279	12118	6	3B
0005432799344	12118	7	3C
0005432799261	12118	8	4B
0005432799315	12118	9	4C
0005432799375	12118	10	5A
0005432799335	12118	11	6A
0005432799305	12118	12	6D
0005432799407	12118	13	7B
0005432799329	12118	14	7D
0005432799408	12118	15	18A
0005432799251	12118	16	18B
0005432799382	12118	17	18C
0005432799256	12118	18	18D
0005432799302	12118	19	19A
0005432799243	12118	20	20C
0005432799351	12118	21	21C
0005432799206	12118	22	21D
0005432799314	12118	23	22A
0005432799233	12118	24	22B
0005432799258	12118	25	22C
0005432799237	12118	26	23B
0005432799540	14791	1	1A
0005432799537	14791	2	1B
0005432799536	14791	3	1C
0005432799545	14791	4	2A
0005432799541	14791	5	2B
0005432799556	14791	6	2D
0005432799558	14791	7	3A
0005432799534	14791	8	3C
0005432799548	14791	9	3D
0005432799551	14791	10	4A
0005432799533	14791	11	4B
0005432799535	14791	12	4C
0005432799546	14791	13	4D
0005432799543	14791	14	5A
0005432799538	14791	15	5B
0005432799560	14791	16	5C
0005432799544	14791	17	5D
0005432799532	14791	18	7A
0005432799552	14791	19	7D
0005432799549	14791	20	18B
0005432799561	14791	21	19A
0005432799547	14791	22	19B
0005432799554	14791	23	20A
0005432799550	14791	24	20B
0005432799531	14791	25	20C
0005432799542	14791	26	20D
0005432799553	14791	27	21B
0005432799559	14791	28	21D
0005432799557	14791	29	22A
0005432799539	14791	30	22B
0005432799555	14791	31	22D
0005434408025	7062	1	1A
0005434408011	7062	2	1C
0005435293283	7062	3	1D
0005434408013	7062	4	2A
0005434408001	7062	5	1F
0005435310989	7062	6	2D
0005434408047	7062	7	2C
0005434408034	7062	8	3A
0005435293156	7062	9	2F
0005435310960	7062	10	3D
0005434299653	7062	11	3C
0005434407996	7062	12	3F
0005432153970	7062	13	4A
0005435311004	7062	14	4C
0005434408026	7062	15	4B
0005434408024	7062	16	4D
0005434408022	7062	17	4E
0005435293159	7062	18	4F
0005435293215	7062	19	5A
0005434407994	7062	20	5B
0005434299667	7062	21	5D
0005434408002	7062	22	5C
0005434408057	7062	23	5E
0005435310999	7062	24	5F
0005434408053	7062	25	6B
0005432153967	7062	26	6A
0005434408017	7062	27	6C
0005434408044	7062	28	6E
0005434299665	7062	29	6D
0005434408008	7062	30	7A
0005435311006	7062	31	6F
0005432153965	7062	32	7B
0005435293166	7062	33	7C
0005434407997	7062	34	7E
0005434407999	7062	35	7D
0005434408003	7062	36	8A
0005435310996	7062	37	7F
0005435311008	7062	38	8B
0005434408052	7062	39	8C
0005434408049	7062	40	8D
0005435293152	7062	41	8F
0005434299662	7062	42	9A
0005434299657	7062	43	9B
0005434408058	7062	44	9C
0005434408014	7062	45	9E
0005434299669	7062	46	9D
0005435311001	7062	47	9F
0005434408023	7062	48	10B
0005434299658	7062	49	10C
0005434299661	7062	50	10E
0005434408048	7062	51	10D
0005432153964	7062	52	11A
0005434408012	7062	53	11B
0005434408040	7062	54	11D
0005434408010	7062	55	11E
0005434408020	7062	56	11F
0005434408056	7062	57	12A
0005434407995	7062	58	12C
0005434408019	7062	59	12B
0005434408031	7062	60	12D
0005434408006	7062	61	12E
0005434408029	7062	62	12F
0005434408035	7062	63	13B
0005434408042	7062	64	13A
0005434408018	7062	65	13C
0005434408036	7062	66	13D
0005434408038	7062	67	13E
0005434408004	7062	68	13F
0005434408039	7062	69	14B
0005434299664	7062	70	14A
0005434408043	7062	71	14C
0005435293157	7062	72	14D
0005434299654	7062	73	14E
0005432153968	7062	74	15A
0005434408033	7062	75	14F
0005432153969	7062	76	15B
0005434408016	7062	77	15C
0005434299651	7062	78	15D
0005435310984	7062	79	15F
0005434408050	7062	80	15E
0005434299652	7062	81	16B
0005435310985	7062	82	16A
0005435293285	7062	83	16C
0005434408041	7062	84	16D
0005435311020	7062	85	16E
0005434408037	7062	86	17A
0005434299656	7062	87	16F
0005434408000	7062	88	17B
0005432153966	7062	89	17D
0005434408054	7062	90	17C
0005434299660	7062	91	17F
0005434299668	7062	92	17E
0005434408021	7062	93	18A
0005434408051	7062	94	18B
0005434299655	7062	95	18D
0005434299650	7062	96	18C
0005434408005	7062	97	18F
0005434299648	7062	98	18E
0005434408032	7062	99	19A
0005434299666	7062	100	19B
0005435293214	7062	101	19D
0005434299646	7062	102	19C
0005435311002	7062	103	19E
0005435293178	7062	104	19F
0005435293185	7062	105	20A
0005432108260	7062	106	20B
0005434408007	7062	107	20D
0005434408027	7062	108	20C
0005435311023	7062	109	20E
0005435310991	7062	110	20F
0005434408009	7062	111	21A
0005434299663	7062	112	21B
0005434299659	7062	113	21D
0005434299647	7062	114	21C
0005432108261	7062	115	21E
0005434408045	7062	116	22A
0005435310990	7062	117	21F
0005434408055	7062	118	22B
0005435311021	7062	119	22C
0005434299649	7062	120	22D
0005434407998	7062	121	22F
0005434408046	7062	122	22E
0005434408030	7062	123	23B
0005434408015	7062	124	23A
0005434408028	7062	125	23D
0005434408059	7062	126	23C
0005435293158	7062	127	23E
0005435293284	7062	128	23F
0005434299564	26908	1	1C
0005434407633	26908	2	1A
0005432058394	26908	3	1F
0005434407412	26908	4	1D
0005434407471	26908	5	2C
0005434407404	26908	6	2A
0005434299400	26908	7	2D
0005434407611	26908	8	2F
0005434407396	26908	9	3C
0005435311104	26908	10	3A
0005435293311	26908	11	3D
0005434407640	26908	12	3F
0005434407397	26908	13	4A
0005434299401	26908	14	4C
0005434407499	26908	15	4B
0005434407571	26908	16	4E
0005434407252	26908	17	5C
0005434407390	26908	18	5B
0005434407411	26908	19	5F
0005435293307	26908	20	6A
0005434407517	26908	21	6C
0005434407589	26908	22	6B
0005434407458	26908	23	6D
0005434407672	26908	24	6F
0005435293310	26908	25	6E
0005434407441	26908	26	7B
0005434407231	26908	27	7E
0005432058393	26908	28	7D
0005434299480	26908	29	7F
0005434407319	26908	30	8B
0005434299413	26908	31	8A
0005434299474	26908	32	8C
0005434407253	26908	33	8E
0005434407487	26908	34	8D
0005434407315	26908	35	8F
0005435293304	26908	36	9A
0005434407384	26908	37	9D
0005435311103	26908	38	9C
0005434407385	26908	39	9F
0005435293306	26908	40	9E
0005434407440	26908	41	10B
0005434407663	26908	42	10C
0005434299465	26908	43	10E
0005432058397	26908	44	10D
0005434407363	26908	45	11A
0005434407683	26908	46	11C
0005434407302	26908	47	11B
0005434299563	26908	48	11D
0005434299412	26908	49	11E
0005434407394	26908	50	11F
0005434407230	26908	51	12A
0005435311098	26908	52	12B
0005435311096	26908	53	12C
0005434407052	26908	54	12E
0005435311101	26908	55	12D
0005434407433	26908	56	12F
0005434407459	26908	57	13A
0005434407444	26908	58	13B
0005434299473	26908	59	13D
0005434407541	26908	60	13C
0005434407648	26908	61	13E
0005434407439	26908	62	14B
0005434407377	26908	63	14A
0005434407448	26908	64	14C
0005434407632	26908	65	14D
0005435311102	26908	66	14E
0005435293309	26908	67	14F
0005434407274	26908	68	15A
0005435293303	26908	69	15C
0005434407694	26908	70	15B
0005434299434	26908	71	15D
0005434407320	26908	72	15E
0005434407300	26908	73	15F
0005434407515	26908	74	16D
0005434407450	26908	75	16C
0005435293301	26908	76	16B
0005434407428	26908	77	16F
0005434407121	26908	78	16E
0005435293308	26908	79	17A
0005432058396	26908	80	17B
0005434407673	26908	81	17C
0005434407233	26908	82	17D
0005434407272	26908	83	17F
0005434299598	26908	84	17E
0005435311097	26908	85	18A
0005435311100	26908	86	18B
0005434407463	26908	87	18D
0005434407210	26908	88	18C
0005434407624	26908	89	18F
0005434407610	26908	90	18E
0005434407649	26908	91	19A
0005435311095	26908	92	19B
0005434407500	26908	93	19C
0005434407510	26908	94	19E
0005435293302	26908	95	19D
0005434299475	26908	96	20A
0005434407586	26908	97	20C
0005432058395	26908	98	20E
0005434407476	26908	99	20D
0005435293299	26908	100	20F
0005435293300	26908	101	21B
0005435293298	26908	102	21A
0005434407451	26908	103	21C
0005434407542	26908	104	21D
0005434407301	26908	105	21E
0005434407467	26908	106	22A
0005434299433	26908	107	21F
0005434407516	26908	108	22B
0005434407427	26908	109	22C
0005434407623	26908	110	22E
0005435311094	26908	111	22D
0005435311099	26908	112	22F
0005434407299	26908	113	23B
0005434407410	26908	114	23A
0005434407207	26908	115	23C
0005435293305	26908	116	23D
0005434407334	26908	117	23E
0005434407622	26908	118	23F
0005432604526	6457	1	1A
0005432604498	6457	2	1B
0005432604501	6457	3	1C
0005432604513	6457	4	1D
0005432604521	6457	5	2A
0005432604505	6457	6	2B
0005432604517	6457	7	2C
0005432604519	6457	8	3A
0005432604532	6457	9	3B
0005432604506	6457	10	3C
0005432604522	6457	11	3D
0005432604495	6457	12	4A
0005432604507	6457	13	4B
0005432604528	6457	14	4C
0005432604515	6457	15	4D
0005432604516	6457	16	5B
0005434512131	6457	17	5C
0005432604510	6457	18	5D
0005434512130	6457	19	6A
0005432604533	6457	20	6B
0005432604523	6457	21	6C
0005432604497	6457	22	6D
0005434512132	6457	23	7A
0005432604514	6457	24	7B
0005432604531	6457	25	7C
0005432604502	6457	26	7D
0005434512129	6457	27	18A
0005432604503	6457	28	18B
0005432604525	6457	29	18C
0005432604508	6457	30	18D
0005432604524	6457	31	19A
0005435218111	6457	32	19C
0005432604504	6457	33	19D
0005432604499	6457	34	20A
0005432604527	6457	35	20B
0005432604512	6457	36	20C
0005435218110	6457	37	20D
0005432604509	6457	38	21A
0005432604518	6457	39	21B
0005432604496	6457	40	21C
0005432604494	6457	41	21D
0005432604500	6457	42	22A
0005432604529	6457	43	22B
0005432604530	6457	44	22C
0005432604511	6457	45	22D
0005432604520	6457	46	23B
0005432604184	21380	1	1A
0005434512096	21380	2	1B
0005435221059	21380	3	1C
0005432604196	21380	4	1D
0005432604111	21380	5	2A
0005434512114	21380	6	2B
0005434512108	21380	7	2C
0005434512058	21380	8	2D
0005432604103	21380	9	3B
0005432604166	21380	10	3C
0005432604049	21380	11	3D
0005432604141	21380	12	4A
0005432604194	21380	13	4C
0005432604105	21380	14	4D
0005432604050	21380	15	5A
0005432604277	21380	16	5C
0005432604039	21380	17	5D
0005432604183	21380	18	6A
0005432604095	21380	19	6B
0005432604003	21380	20	6C
0005432604185	21380	21	7A
0005432604142	21380	22	7B
0005432604065	21380	23	7D
0005432604040	21380	24	18A
0005434512107	21380	25	18B
0005432604227	21380	26	18C
0005432604197	21380	27	18D
0005432604079	21380	28	19A
0005434512057	21380	29	19B
0005435221519	21380	30	19C
0005432604067	21380	31	19D
0005432604104	21380	32	20A
0005435221058	21380	33	20B
0005432604066	21380	34	20C
0005432604278	21380	35	21A
0005434512093	21380	36	21B
0005432604061	21380	37	21C
0005432604096	21380	38	21D
0005432604112	21380	39	22B
0005434512109	21380	40	22A
0005432604228	21380	41	22C
0005432604118	21380	42	23A
0005432604127	21380	43	23B
0005434906958	14971	1	1A
0005434906977	14971	2	1C
0005434907002	14971	3	1D
0005433251606	14971	4	2A
0005434907012	14971	5	2C
0005434907020	14971	6	2D
0005433251604	14971	7	3A
0005433251591	14971	8	3C
0005434906982	14971	9	3D
0005434906941	14971	10	3F
0005434906987	14971	11	4A
0005434906682	14971	12	4C
0005433251603	14971	13	4E
0005433251597	14971	14	4F
0005434906885	14971	15	5A
0005434907055	14971	16	5C
0005434906959	14971	17	5D
0005434906984	14971	18	5E
0005434907038	14971	19	5F
0005434907010	14971	20	6A
0005433251623	14971	21	6C
0005434906903	14971	22	6D
0005434907000	14971	23	6E
0005433251612	14971	24	6F
0005434907019	14971	25	7A
0005434906983	14971	26	7C
0005433251613	14971	27	7D
0005434907054	14971	28	7E
0005433251621	14971	29	7F
0005434906986	14971	30	8A
0005434907011	14971	31	8C
0005433251618	14971	32	8D
0005434906912	14971	33	8E
0005433251593	14971	34	9A
0005433251598	14971	35	9D
0005434906875	14971	36	9E
0005434907045	14971	37	9F
0005433251611	14971	38	10A
0005433251605	14971	39	10C
0005434907056	14971	40	10D
0005434906948	14971	41	10E
0005434907069	14971	42	10F
0005434906878	14971	43	11A
0005434906926	14971	44	11C
0005434907004	14971	45	11D
0005434906900	14971	46	11E
0005433251601	14971	47	11F
0005433251619	14971	48	12A
0005433251615	14971	49	12C
0005434907079	14971	50	12D
0005434907081	14971	51	12E
0005434906904	14971	52	12F
0005434906850	14971	53	13A
0005433251609	14971	54	13C
0005433251592	14971	55	13D
0005434907072	14971	56	13E
0005434907046	14971	57	13F
0005434907003	14971	58	14A
0005434907074	14971	59	14C
0005433251607	14971	60	14D
0005433251616	14971	61	14E
0005433251608	14971	62	15A
0005433251617	14971	63	15C
0005434906923	14971	64	15D
0005433251600	14971	65	15E
0005434906899	14971	66	15F
0005433251614	14971	67	16A
0005434906877	14971	68	16D
0005434907040	14971	69	16C
0005433251620	14971	70	16E
0005434906978	14971	71	17A
0005433251599	14971	72	17C
0005434906681	14971	73	17D
0005434907021	14971	74	17F
0005433251610	14971	75	18A
0005434906990	14971	76	18D
0005434907023	14971	77	18E
0005433251596	14971	78	18F
0005433251595	14971	79	19C
0005434907037	14971	80	19D
0005434907005	14971	81	19E
0005434907044	14971	82	19F
0005433251594	14971	83	20A
0005434907022	14971	84	20C
0005433251602	14971	85	20D
0005434907026	14971	86	20E
0005433251622	14971	87	20F
0005433251440	25877	1	1A
0005434907441	25877	2	1C
0005434907465	25877	3	1F
0005434907457	25877	4	2A
0005434907475	25877	5	2C
0005433251354	25877	6	2D
0005434907483	25877	7	2F
0005433251298	25877	8	3A
0005434907454	25877	9	3C
0005434907443	25877	10	3D
0005434907479	25877	11	3F
0005433251384	25877	12	4C
0005434907462	25877	13	4D
0005434907458	25877	14	4E
0005433251422	25877	15	4F
0005434907461	25877	16	5A
0005433251294	25877	17	5C
0005434907471	25877	18	5D
0005433251287	25877	19	5E
0005434907440	25877	20	6A
0005434907439	25877	21	6C
0005434907456	25877	22	6D
0005433251302	25877	23	6E
0005433251295	25877	24	6F
0005434907481	25877	25	7C
0005433251206	25877	26	7D
0005434907446	25877	27	7E
0005434907473	25877	28	7F
0005433251342	25877	29	8A
0005433251373	25877	30	8C
0005434907472	25877	31	8D
0005434907467	25877	32	8E
0005433251363	25877	33	8F
0005434907453	25877	34	9A
0005433251374	25877	35	9C
0005434907464	25877	36	9D
0005434907442	25877	37	9E
0005433251375	25877	38	9F
0005434907482	25877	39	10A
0005434907444	25877	40	10D
0005434907459	25877	41	10E
0005434907477	25877	42	10F
0005433251394	25877	43	11A
0005433251369	25877	44	11C
0005434907437	25877	45	11D
0005433251333	25877	46	11E
0005433251284	25877	47	11F
0005434907480	25877	48	12A
0005433251385	25877	49	12D
0005434907484	25877	50	12F
0005433251350	25877	51	13A
0005433251309	25877	52	13C
0005434907469	25877	53	13D
0005434907438	25877	54	13E
0005433251317	25877	55	13F
0005434907485	25877	56	14A
0005433251370	25877	57	14C
0005433251301	25877	58	14D
0005433251393	25877	59	14E
0005434907455	25877	60	14F
0005433251368	25877	61	15A
0005434907466	25877	62	15C
0005434907445	25877	63	15D
0005433251308	25877	64	15F
0005434907476	25877	65	16A
0005434907468	25877	66	16C
0005434907436	25877	67	16D
0005434907449	25877	68	16E
0005433251205	25877	69	16F
0005434907474	25877	70	17A
0005434907470	25877	71	17C
0005433251362	25877	72	17D
0005434907460	25877	73	17F
0005433251300	25877	74	18D
0005434907450	25877	75	18E
0005434907451	25877	76	18F
0005433251318	25877	77	19A
0005434907463	25877	78	19C
0005433251372	25877	79	19D
0005434907478	25877	80	19E
0005434907448	25877	81	19F
0005434907452	25877	82	20A
0005433251290	25877	83	20C
0005433251423	25877	84	20D
0005433251274	25877	85	20E
0005434907447	25877	86	20F
0005432607571	22476	1	1A
0005432609744	22476	2	1B
0005432607577	22476	3	1C
0005432609740	22476	4	1D
0005432607568	22476	5	2C
0005432609732	22476	6	2D
0005432609737	22476	7	3A
0005432607569	22476	8	3B
0005432607567	22476	9	3C
0005435842320	22476	10	3D
0005432609741	22476	11	4A
0005435842322	22476	12	4B
0005432607572	22476	13	4C
0005432609731	22476	14	4D
0005432607574	22476	15	5A
0005435841465	22476	16	5C
0005435842321	22476	17	5D
0005432609743	22476	18	6A
0005432609735	22476	19	6B
0005432609736	22476	20	6C
0005432607575	22476	21	6D
0005432609746	22476	22	7A
0005435841466	22476	23	7B
0005435841469	22476	24	7C
0005432607576	22476	25	7D
0005432609730	22476	26	18A
0005432607570	22476	27	18B
0005432607581	22476	28	18C
0005435841475	22476	29	18D
0005435841468	22476	30	19A
0005432609745	22476	31	19B
0005432607573	22476	32	19C
0005432609739	22476	33	19D
0005432607578	22476	34	20A
0005432609738	22476	35	20B
0005432607580	22476	36	20C
0005432607579	22476	37	20D
0005432607582	22476	38	21A
0005432607566	22476	39	21B
0005435842323	22476	40	21C
0005435841471	22476	41	21D
0005432609733	22476	42	22A
0005432609742	22476	43	22B
0005435841467	22476	44	22D
0005432609734	22476	45	23A
0005432613838	31733	1	1C
0005432613827	31733	2	1D
0005432613834	31733	3	2A
0005432609699	31733	4	3A
0005432613826	31733	5	3B
0005432609703	31733	6	3D
0005432613818	31733	7	4A
0005432609701	31733	8	4B
0005432609714	31733	9	4C
0005432613819	31733	10	4D
0005432613855	31733	11	5A
0005432613844	31733	12	6A
0005432613820	31733	13	6C
0005432613825	31733	14	6D
0005432609694	31733	15	7A
0005432609704	31733	16	7C
0005432613821	31733	17	7D
0005432613828	31733	18	18A
0005432613833	31733	19	18B
0005432613816	31733	20	18C
0005432613837	31733	21	18D
0005432613839	31733	22	19A
0005432609678	31733	23	19B
0005432613817	31733	24	19C
0005432613822	31733	25	20A
0005432613840	31733	26	20C
0005432609683	31733	27	20B
0005432609706	31733	28	20D
0005432609700	31733	29	21C
0005432609679	31733	30	21D
0005432609680	31733	31	22A
0005432609707	31733	32	22B
0005432609682	31733	33	22C
0005432609709	31733	34	22D
0005432613853	31733	35	23A
0005432609686	31733	36	23B
0005433008807	14204	1	1A
0005433008823	14204	2	1C
0005433008800	14204	3	1D
0005433008802	14204	4	2C
0005433008815	14204	5	2D
0005433008817	14204	6	3A
0005433810514	14204	7	3D
0005433008805	14204	8	5A
0005433008826	14204	9	5C
0005433008814	14204	10	5D
0005433008834	14204	11	5E
0005433008840	14204	12	6A
0005433008820	14204	13	6C
0005433008830	14204	14	6E
0005433008833	14204	15	7A
0005433810512	14204	16	7C
0005433008816	14204	17	8A
0005433008829	14204	18	8C
0005433008835	14204	19	8E
0005433008831	14204	20	8F
0005433008838	14204	21	9C
0005433008842	14204	22	10A
0005433008843	14204	23	10C
0005433008841	14204	24	11C
0005433008825	14204	25	11E
0005433008803	14204	26	12A
0005433008801	14204	27	12C
0005433008808	14204	28	12D
0005433008811	14204	29	12F
0005433008837	14204	30	13A
0005433008839	14204	31	13C
0005433008827	14204	32	13D
0005433008822	14204	33	13E
0005433008809	14204	34	14C
0005433008812	14204	35	14E
0005433008806	14204	36	14F
0005433008832	14204	37	15C
0005433008821	14204	38	16A
0005433008799	14204	39	16C
0005433008828	14204	40	16D
0005433008824	14204	41	16E
0005433008810	14204	42	16F
0005433008836	14204	43	17D
0005433008813	14204	44	17F
0005433008798	14204	45	18C
0005433008819	14204	46	18F
0005433008818	14204	47	19A
0005433008797	14204	48	19F
0005433810513	14204	49	20D
0005433008804	14204	50	20E
0005433008519	22827	1	1A
0005433008286	22827	2	3A
0005433008505	22827	3	3C
0005433008513	22827	4	3D
0005433008494	22827	5	3F
0005433008355	22827	6	4A
0005433008309	22827	7	4C
0005433008435	22827	8	4D
0005433008257	22827	9	4F
0005433008341	22827	10	5A
0005433008491	22827	11	5E
0005433008178	22827	12	5F
0005433008439	22827	13	6A
0005433008340	22827	14	6E
0005433008512	22827	15	6F
0005433008308	22827	16	7A
0005433008480	22827	17	7C
0005433008440	22827	18	7D
0005433008314	22827	19	7E
0005433008503	22827	20	8A
0005433008437	22827	21	8E
0005433008333	22827	22	9C
0005433008490	22827	23	9D
0005433008148	22827	24	9F
0005433008371	22827	25	10C
0005433008194	22827	26	10D
0005433008370	22827	27	10E
0005433008506	22827	28	10F
0005433008367	22827	29	11C
0005433008492	22827	30	12A
0005433008469	22827	31	12C
0005433008438	22827	32	12E
0005433008436	22827	33	13A
0005433008287	22827	34	13E
0005433008149	22827	35	13F
0005433008302	22827	36	14A
0005433008366	22827	37	14C
0005433810566	22827	38	15A
0005433008263	22827	39	15F
0005433008457	22827	40	16A
0005433008500	22827	41	16E
0005433008504	22827	42	16F
0005433008342	22827	43	17E
0005433008464	22827	44	18A
0005433008507	22827	45	18D
0005433008460	22827	46	18E
0005433008324	22827	47	19A
0005433008216	22827	48	19F
0005433008429	22827	49	20E
0005434925590	14953	1	1A
0005434925684	14953	2	1C
0005434925623	14953	3	2C
0005434925746	14953	4	2D
0005434925664	14953	5	3A
0005434925602	14953	6	3D
0005434925725	14953	7	4A
0005434925589	14953	8	4D
0005434925638	14953	9	4F
0005434925654	14953	10	5D
0005434925742	14953	11	6C
0005434925788	14953	12	6D
0005434925743	14953	13	7C
0005434925552	14953	14	8C
0005434925601	14953	15	9A
0005434925726	14953	16	9C
0005434925474	14953	17	9E
0005434925712	14953	18	10D
0005434925660	14953	19	11A
0005434925626	14953	20	11C
0005434925734	14953	21	11E
0005434925683	14953	22	13C
0005434925588	14953	23	13F
0005434925642	14953	24	14A
0005434925604	14953	25	14D
0005434925656	14953	26	14E
0005434925650	14953	27	15D
0005434925787	14953	28	16E
0005434925475	14953	29	16F
0005434925738	14953	30	17A
0005434925651	14953	31	17D
0005434925639	14953	32	17F
0005434925666	14953	33	18A
0005434925499	14953	34	18C
0005434925612	14953	35	19C
0005434925643	14953	36	19F
0005434925627	14953	37	20C
0005434925591	14953	38	20F
0005434925889	20500	1	1F
0005434925922	20500	2	2C
0005434925917	20500	3	2D
0005434925896	20500	4	3C
0005434925885	20500	5	4C
0005434925888	20500	6	4D
0005434925898	20500	7	5C
0005434925884	20500	8	5D
0005434925907	20500	9	5E
0005434925914	20500	10	6C
0005434925904	20500	11	6E
0005434925908	20500	12	7D
0005434925890	20500	13	7E
0005434925899	20500	14	8A
0005434925892	20500	15	8C
0005434925902	20500	16	9A
0005434925895	20500	17	9C
0005434925903	20500	18	10C
0005434925921	20500	19	10D
0005434925918	20500	20	11E
0005434925893	20500	21	11F
0005434925919	20500	22	12D
0005434925883	20500	23	12E
0005434925887	20500	24	12F
0005434925911	20500	25	13C
0005434925891	20500	26	13F
0005434925886	20500	27	14A
0005434925909	20500	28	14F
0005434925900	20500	29	15A
0005434925912	20500	30	15F
0005434925915	20500	31	16C
0005434925897	20500	32	16D
0005434925906	20500	33	17C
0005434925910	20500	34	17E
0005434925913	20500	35	18F
0005434925916	20500	36	19D
0005434925894	20500	37	19E
0005434925905	20500	38	20A
0005434925920	20500	39	20D
0005434925901	20500	40	20F
0005435999172	15845	1	1B
0005435487940	15845	2	1C
0005435487928	15845	3	1D
0005435999236	15845	4	2A
0005435999155	15845	5	2B
0005435999145	15845	6	2C
0005435487931	15845	7	2D
0005435487932	15845	8	3A
0005435999230	15845	9	3B
0005435999099	15845	10	3C
0005435999171	15845	11	3D
0005435999223	15845	12	4A
0005435487923	15845	13	4B
0005435999100	15845	14	4C
0005435487937	15845	15	4D
0005435487924	15845	16	5A
0005435487930	15845	17	5B
0005435999115	15845	18	5C
0005435999154	15845	19	6A
0005435999142	15845	20	6B
0005435999196	15845	21	6D
0005435999129	15845	22	7B
0005435487922	15845	23	7C
0005435999170	15845	24	7D
0005435999177	15845	25	18A
0005435487919	15845	26	18C
0005435487925	15845	27	18D
0005435999098	15845	28	19A
0005435487938	15845	29	19B
0005435999194	15845	30	19C
0005435487926	15845	31	19D
0005435487934	15845	32	20A
0005435999114	15845	33	20B
0005435999195	15845	34	20C
0005435999146	15845	35	20D
0005435999156	15845	36	21A
0005435487929	15845	37	21B
0005435487936	15845	38	21C
0005435487921	15845	39	22A
0005435487920	15845	40	22B
0005435487939	15845	41	22C
0005435487927	15845	42	22D
0005435487935	15845	43	23A
0005435487933	15845	44	23B
0005435487733	19694	1	1A
0005435487698	19694	2	1C
0005435487758	19694	3	1B
0005435999318	19694	4	1D
0005435999310	19694	5	2A
0005435999306	19694	6	2B
0005435999313	19694	7	2C
0005435487674	19694	8	2D
0005435999304	19694	9	3A
0005435999314	19694	10	3B
0005435999320	19694	11	3C
0005435999322	19694	12	3D
0005435487666	19694	13	4A
0005435487704	19694	14	4B
0005435999309	19694	15	4C
0005435487697	19694	16	4D
0005435999321	19694	17	5A
0005435487655	19694	18	5B
0005435487717	19694	19	5C
0005435999316	19694	20	5D
0005435999302	19694	21	6B
0005435487761	19694	22	6C
0005435487739	19694	23	6D
0005435999317	19694	24	7A
0005435999307	19694	25	7B
0005435487757	19694	26	7C
0005435487738	19694	27	7D
0005435999311	19694	28	18B
0005435487762	19694	29	18C
0005435999301	19694	30	18D
0005435487740	19694	31	19A
0005435487732	19694	32	19B
0005435999305	19694	33	19C
0005435999315	19694	34	20A
0005435487648	19694	35	20B
0005435999308	19694	36	20C
0005435487675	19694	37	20D
0005435487693	19694	38	21A
0005435487640	19694	39	21B
0005435999300	19694	40	21C
0005435487635	19694	41	21D
0005435487659	19694	42	22A
0005435487703	19694	43	22B
0005435999303	19694	44	22C
0005435999312	19694	45	22D
0005435999319	19694	46	23A
0005435487720	19694	47	23B
0005432660827	5975	1	1C
0005435839579	5975	2	4A
0005435839584	5975	3	5C
0005435472697	5975	4	5F
0005435839585	5975	5	6B
0005435472708	5975	6	6E
0005435472690	5975	7	6D
0005435472706	5975	8	7B
0005435472765	5975	9	7A
0005435472673	5975	10	7E
0005435839562	5975	11	8A
0005435839578	5975	12	8B
0005432659717	5975	13	8C
0005432659718	5975	14	9B
0005435839589	5975	15	9A
0005435839564	5975	16	10A
0005435839587	5975	17	10C
0005435839590	5975	18	10D
0005432537039	5975	19	11A
0005435472741	5975	20	11B
0005435839580	5975	21	11D
0005435839581	5975	22	12B
0005432659716	5975	23	12E
0005432658601	5975	24	12D
0005432142265	5975	25	13B
0005435839572	5975	26	13E
0005435472790	5975	27	13D
0005435839576	5975	28	14A
0005435839571	5975	29	14B
0005435839570	5975	30	14E
0005435839569	5975	31	15B
0005435839565	5975	32	15A
0005435839575	5975	33	15C
0005435839588	5975	34	15E
0005435839574	5975	35	15D
0005435839582	5975	36	16A
0005435839567	5975	37	16E
0005432142267	5975	38	16D
0005435472698	5975	39	16F
0005435839573	5975	40	17B
0005435839566	5975	41	17D
0005435472691	5975	42	18B
0005432142264	5975	43	18A
0005432658600	5975	44	18E
0005435839563	5975	45	18F
0005435472633	5975	46	19B
0005435472699	5975	47	19D
0005435839583	5975	48	20A
0005435839577	5975	49	19E
0005435472714	5975	50	20B
0005432660828	5975	51	20F
0005435839568	5975	52	21A
0005435839586	5975	53	21E
0005432142266	5975	54	21F
0005435472871	18089	1	1C
0005435839235	18089	2	1A
0005435839418	18089	3	2C
0005432537068	18089	4	1F
0005435472882	18089	5	3D
0005435839460	18089	6	3C
0005432660804	18089	7	4A
0005432664120	18089	8	3F
0005435839362	18089	9	4D
0005435839315	18089	10	4C
0005432660805	18089	11	4F
0005435472868	18089	12	5C
0005435839312	18089	13	5A
0005435839230	18089	14	5F
0005435839387	18089	15	5D
0005435472877	18089	16	6A
0005435472879	18089	17	6E
0005435839439	18089	18	7A
0005435472870	18089	19	6F
0005435839259	18089	20	7B
0005435472872	18089	21	7E
0005435839361	18089	22	8A
0005435839311	18089	23	7F
0005435839231	18089	24	8C
0005435839274	18089	25	8B
0005435839188	18089	26	8E
0005435839378	18089	27	8D
0005435472880	18089	28	8F
0005435839343	18089	29	9B
0005435839469	18089	30	9E
0005435839304	18089	31	10A
0005435472869	18089	32	10C
0005435839275	18089	33	10B
0005435472876	18089	34	10D
0005435839270	18089	35	10F
0005435839317	18089	36	11C
0005435839257	18089	37	11F
0005435839339	18089	38	11E
0005435839374	18089	39	12B
0005435472875	18089	40	12A
0005435839318	18089	41	12F
0005435839371	18089	42	13C
0005435472881	18089	43	13D
0005435839289	18089	44	14A
0005435839381	18089	45	13F
0005435839232	18089	46	14B
0005435839279	18089	47	14C
0005435839363	18089	48	14E
0005435839515	18089	49	15A
0005435839341	18089	50	15F
0005432667441	18089	51	15E
0005435839333	18089	52	16B
0005435839271	18089	53	16E
0005432537069	18089	54	16F
0005435839240	18089	55	17A
0005435839375	18089	56	17D
0005435839278	18089	57	17C
0005435839367	18089	58	17F
0005435472874	18089	59	18A
0005435472878	18089	60	18D
0005435839379	18089	61	18C
0005435839272	18089	62	18E
0005435839380	18089	63	18F
0005435839468	18089	64	19B
0005435472873	18089	65	19F
0005435839370	18089	66	19E
0005435839303	18089	67	20B
0005435839386	18089	68	20D
0005435472867	18089	69	20E
0005435839385	18089	70	21A
0005435839342	18089	71	21C
0005432537070	18089	72	21D
0005435839258	18089	73	21F
0005433463910	17265	1	2A
0005433462748	17265	2	3G
0005433463909	17265	3	4F
0005433462756	17265	4	5F
0005433463903	17265	5	13A
0005433463899	17265	6	13F
0005433463901	17265	7	15H
0005433463904	17265	8	16E
0005433463898	17265	9	16H
0005433462754	17265	10	18F
0005433462749	17265	11	19G
0005433463900	17265	12	19H
0005433463907	17265	13	23F
0005433462747	17265	14	25D
0005433462746	17265	15	27F
0005433462755	17265	16	28D
0005433463906	17265	17	28F
0005433462743	17265	18	29B
0005433463908	17265	19	29E
0005433463895	17265	20	31G
0005433462744	17265	21	32B
0005433462750	17265	22	33D
0005433463896	17265	23	33F
0005433462753	17265	24	33G
0005433462742	17265	25	34B
0005433463902	17265	26	35F
0005433463897	17265	27	36B
0005433462745	17265	28	36D
0005433463905	17265	29	36G
0005433462752	17265	30	36H
0005433462751	17265	31	37E
0005435103954	23053	1	5A
0005433285262	23053	2	4F
0005433285158	23053	3	6D
0005435103957	23053	4	7E
0005433285113	23053	5	7F
0005433285199	23053	6	8A
0005433285258	23053	7	8C
0005433285130	23053	8	9C
0005433285074	23053	9	9D
0005433285080	23053	10	10C
0005433285152	23053	11	10E
0005435103958	23053	12	11D
0005433285263	23053	13	12A
0005433285169	23053	14	13C
0005433285221	23053	15	13D
0005435103960	23053	16	14B
0005435103959	23053	17	14A
0005433285188	23053	18	15D
0005433285219	23053	19	16F
0005433285187	23053	20	17A
0005435103956	23053	21	17C
0005433285196	23053	22	19B
0005433285179	23053	23	20A
0005433285261	23053	24	20D
0005433285233	23053	25	21B
0005433285195	23053	26	21C
0005433285280	23053	27	21D
0005433285075	23053	28	22A
0005435103961	23053	29	22C
0005433285151	23053	30	22D
0005435103955	23053	31	22F
0005433285323	23053	32	23A
0005433285115	23053	33	23D
0005433285448	32071	1	2C
0005433285441	32071	2	2A
0005433285442	32071	3	4C
0005433285429	32071	4	4E
0005433285454	32071	5	7D
0005433285450	32071	6	7F
0005433285435	32071	7	8D
0005433285449	32071	8	10B
0005433285452	32071	9	10D
0005433285428	32071	10	11F
0005433285439	32071	11	12A
0005435103862	32071	12	12B
0005433285431	32071	13	12E
0005433285453	32071	14	12D
0005435103854	32071	15	12F
0005435103835	32071	16	14A
0005433285432	32071	17	13F
0005433285426	32071	18	14B
0005433285430	32071	19	14E
0005433285451	32071	20	15B
0005435103855	32071	21	15C
0005433285425	32071	22	16B
0005433285445	32071	23	16C
0005433285433	32071	24	16E
0005433285427	32071	25	17A
0005433285440	32071	26	17B
0005433285446	32071	27	18E
0005433285444	32071	28	18D
0005433285455	32071	29	19C
0005433285424	32071	30	20C
0005433285436	32071	31	21A
0005433285438	32071	32	21C
0005433285437	32071	33	21F
0005433285434	32071	34	22B
0005433285443	32071	35	22C
0005433285447	32071	36	23B
0005435103859	32071	37	23E
0005432527685	30618	1	1G
0005434067480	30618	2	2A
0005435630983	30618	3	1H
0005435213915	30618	4	2G
0005432527400	30618	5	2D
0005434067374	30618	6	3A
0005432159881	30618	7	2K
0005432527564	30618	8	2H
0005435725625	30618	9	3D
0005434067474	30618	10	3C
0005434067205	30618	11	3H
0005435213900	30618	12	4C
0005435213882	30618	13	4A
0005432527386	30618	14	4G
0005435213918	30618	15	4D
0005434067080	30618	16	4K
0005432528050	30618	17	5C
0005432527512	30618	18	5A
0005434067587	30618	19	5H
0005432527487	30618	20	5G
0005434067079	30618	21	11E
0005435213886	30618	22	11C
0005432527712	30618	23	11G
0005434067273	30618	24	11F
0005432527110	30618	25	11H
0005432527699	30618	26	12C
0005435213856	30618	27	12A
0005432527754	30618	28	11K
0005435213919	30618	29	12E
0005434067175	30618	30	12D
0005432527572	30618	31	12G
0005432527710	30618	32	12F
0005434067226	30618	33	12K
0005432527547	30618	34	12H
0005432527331	30618	35	13D
0005432526986	30618	36	13C
0005434067335	30618	37	13F
0005432535812	30618	38	13E
0005434067267	30618	39	13H
0005432527563	30618	40	13G
0005435213887	30618	41	13K
0005432527228	30618	42	14E
0005434067167	30618	43	14D
0005435213906	30618	44	14C
0005434067411	30618	45	14K
0005434067543	30618	46	14H
0005432537063	30618	47	14G
0005435213920	30618	48	15C
0005432527630	30618	49	15A
0005435213873	30618	50	15E
0005432527172	30618	51	15D
0005432528022	30618	52	15H
0005432528007	30618	53	15G
0005434067123	30618	54	15F
0005434067625	30618	55	16A
0005432527150	30618	56	15K
0005432537051	30618	57	16D
0005434067060	30618	58	16C
0005432527405	30618	59	16F
0005434067599	30618	60	16E
0005432527556	30618	61	16K
0005432527391	30618	62	16H
0005432527189	30618	63	16G
0005435213869	30618	64	17G
0005434067224	30618	65	17K
0005435213908	30618	66	18C
0005435213876	30618	67	18B
0005435213854	30618	68	18A
0005434067536	30618	69	18E
0005432535796	30618	70	18D
0005432211535	30618	71	18H
0005432527651	30618	72	18G
0005432159879	30618	73	18F
0005432537049	30618	74	18J
0005432527254	30618	75	19A
0005432527149	30618	76	18K
0005432527779	30618	77	19C
0005432535797	30618	78	19F
0005434067168	30618	79	19E
0005434067261	30618	80	19H
0005432211536	30618	81	19G
0005434067418	30618	82	19K
0005432527675	30618	83	19J
0005432527587	30618	84	20A
0005435213917	30618	85	20E
0005435213863	30618	86	20D
0005434067373	30618	87	20C
0005434067260	30618	88	20G
0005434067217	30618	89	20F
0005432527595	30618	90	20K
0005432527459	30618	91	20H
0005432527691	30618	92	21B
0005432527826	30618	93	21D
0005432527695	30618	94	21C
0005435213896	30618	95	21F
0005432527280	30618	96	21E
0005435213859	30618	97	21J
0005435213870	30618	98	22A
0005435213861	30618	99	22C
0005432527510	30618	100	22E
0005432527692	30618	101	22D
0005435213888	30618	102	22H
0005434067545	30618	103	22G
0005432537048	30618	104	22F
0005432527594	30618	105	22K
0005435213922	30618	106	23B
0005432527163	30618	107	23A
0005435213884	30618	108	23E
0005435725628	30618	109	23C
0005435213911	30618	110	23G
0005432527111	30618	111	23F
0005434067215	30618	112	23H
0005435213891	30618	113	24D
0005432526852	30618	114	23K
0005435213889	30618	115	24F
0005432527401	30618	116	24E
0005435213860	30618	117	25A
0005434067568	30618	118	24G
0005435213874	30618	119	25C
0005432537050	30618	120	25B
0005432527511	30618	121	25F
0005435213878	30618	122	25D
0005432527207	30618	123	25H
0005434067127	30618	124	26A
0005434067031	30618	125	25K
0005434067326	30618	126	25J
0005435213877	30618	127	26C
0005432535802	30618	128	26D
0005432527473	30618	129	26G
0005432527586	30618	130	26F
0005432527025	30618	131	26K
0005432527778	30618	132	26J
0005434067220	30618	133	26H
0005434067304	30618	134	27C
0005432527800	30618	135	27B
0005432527566	30618	136	27E
0005434067499	30618	137	27D
0005435213923	30618	138	27H
0005434067544	30618	139	27K
0005432535828	30618	140	28C
0005432527299	30618	141	28B
0005432527520	30618	142	28A
0005432211541	30618	143	28E
0005432527390	30618	144	28D
0005432527206	30618	145	28G
0005435213905	30618	146	28F
0005434067452	30618	147	28J
0005435213899	30618	148	28H
0005435213901	30618	149	29B
0005432537064	30618	150	29A
0005435213885	30618	151	28K
0005434067110	30618	152	29D
0005435213907	30618	153	29F
0005432527231	30618	154	29E
0005434067506	30618	155	29G
0005432527443	30618	156	29K
0005432527596	30618	157	29J
0005432527436	30618	158	30C
0005435213865	30618	159	30B
0005434067566	30618	160	30A
0005432527871	30618	161	30E
0005434067227	30618	162	30D
0005432527410	30618	163	30G
0005433656688	30618	164	30F
0005432527716	30618	165	30J
0005432527774	30618	166	30H
0005432527339	30618	167	31A
0005434067178	30618	168	30K
0005435213904	30618	169	31D
0005432211539	30618	170	31C
0005434067216	30618	171	31B
0005434067225	30618	172	31G
0005433656687	30618	173	31F
0005434067188	30618	174	31H
0005432527347	30618	175	32A
0005432527713	30618	176	31K
0005432527202	30618	177	31J
0005432527507	30618	178	32C
0005432527946	30618	179	32E
0005435213864	30618	180	32D
0005435213903	30618	181	32F
0005432527642	30618	182	32K
0005432533273	30618	183	32J
0005432527458	30618	184	32H
0005435213857	30618	185	33B
0005432527063	30618	186	33A
0005435213916	30618	187	33D
0005434067412	30618	188	33C
0005434067284	30618	189	33F
0005432527073	30618	190	33E
0005434067219	30618	191	33J
0005432527464	30618	192	33G
0005435213879	30618	193	34A
0005432526851	30618	194	34B
0005434067008	30618	195	34E
0005434067116	30618	196	34D
0005435213892	30618	197	34C
0005435213872	30618	198	34G
0005435213875	30618	199	34F
0005432527736	30618	200	34J
0005432527463	30618	201	34H
0005432527188	30618	202	35B
0005435213862	30618	203	35A
0005432527881	30618	204	34K
0005434067371	30618	205	35C
0005432527253	30618	206	35F
0005434067485	30618	207	35E
0005432527694	30618	208	35J
0005435630984	30618	209	35G
0005432527554	30618	210	36A
0005432527415	30618	211	35K
0005435213909	30618	212	36C
0005432527437	30618	213	36E
0005435213898	30618	214	36G
0005432527773	30618	215	36F
0005432527731	30618	216	36J
0005434067314	30618	217	37B
0005435213912	30618	218	37A
0005432527631	30618	219	36K
0005432527340	30618	220	37E
0005432527815	30618	221	37D
0005434067221	30618	222	37C
0005434067316	30618	223	37F
0005434067039	30618	224	37J
0005432527387	30618	225	37H
0005434067303	30618	226	37G
0005432527431	30618	227	38A
0005434067325	30618	228	37K
0005434067588	30618	229	38B
0005435725627	30618	230	38J
0005432527486	30618	231	38H
0005434067242	30618	232	38K
0005432527661	30618	233	39D
0005432527182	30618	234	39C
0005435213910	30618	235	39B
0005435213894	30618	236	39F
0005435213868	30618	237	39H
0005433656689	30618	238	39G
0005434067331	30618	239	40A
0005432527555	30618	240	39K
0005434067315	30618	241	39J
0005435630982	30618	242	40C
0005435213913	30618	243	40E
0005432211540	30618	244	40F
0005435213855	30618	245	40K
0005435213897	30618	246	40H
0005435213881	30618	247	41B
0005435213866	30618	248	41A
0005434066962	30618	249	41D
0005432527118	30618	250	41F
0005434067149	30618	251	41E
0005434067537	30618	252	41J
0005434067332	30618	253	41H
0005434067211	30618	254	41G
0005432527485	30618	255	42A
0005435725626	30618	256	41K
0005432526956	30618	257	42C
0005432527771	30618	258	42G
0005432527124	30618	259	42F
0005432527230	30618	260	42K
0005435213858	30618	261	42H
0005432527795	30618	262	43B
0005432537046	30618	263	43A
0005432537052	30618	264	43F
0005435213902	30618	265	43E
0005435213893	30618	266	43D
0005432211542	30618	267	43J
0005434067268	30618	268	43H
0005432527298	30618	269	44C
0005432528029	30618	270	44B
0005432159882	30618	271	44E
0005432527344	30618	272	44D
0005432526746	30618	273	44H
0005434066961	30618	274	44G
0005434067305	30618	275	44K
0005432159880	30618	276	44J
0005432527076	30618	277	45A
0005432527709	30618	278	45C
0005435213890	30618	279	45E
0005432526957	30618	280	45H
0005432527792	30618	281	45G
0005434067327	30618	282	46A
0005434067417	30618	283	45K
0005434067285	30618	284	45J
0005434067173	30618	285	46C
0005434067243	30618	286	46E
0005432526896	30618	287	46D
0005434067187	30618	288	46F
0005434067286	30618	289	46J
0005432527240	30618	290	46H
0005432528049	30618	291	47C
0005435213914	30618	292	47A
0005434067363	30618	293	46K
0005435213921	30618	294	47E
0005432527793	30618	295	47D
0005434067244	30618	296	47G
0005432526850	30618	297	47F
0005432528103	30618	298	47K
0005432527442	30618	299	47H
0005432527131	30618	300	48C
0005435213895	30618	301	48A
0005435213867	30618	302	48F
0005432527643	30618	303	48H
0005432527546	30618	304	49A
0005435213880	30618	305	48K
0005434067313	30618	306	49D
0005432527652	30618	307	49C
0005432211537	30618	308	49G
0005432528006	30618	309	49F
0005432211538	30618	310	49E
0005434067117	30618	311	49K
0005432527794	30618	312	50A
0005435213883	30618	313	50E
0005435213871	30618	314	50D
0005432527521	30618	315	50F
0005434067222	30618	316	51D
0005434067341	30618	317	50K
0005433656690	30618	318	51F
0005432537047	30618	319	51G
0005435652860	24855	1	1A
0005435652911	24855	2	1C
0005433368092	24855	3	1D
0005435652855	24855	4	2A
0005435652794	24855	5	2C
0005433368072	24855	6	2D
0005433368067	24855	7	2F
0005435652793	24855	8	3A
0005435652750	24855	9	3D
0005433368071	24855	10	3F
0005435652730	24855	11	4A
0005435652679	24855	12	4C
0005435652914	24855	13	4D
0005433368077	24855	14	4E
0005433368098	24855	15	4F
0005435652885	24855	16	5A
0005435652790	24855	17	5C
0005435652785	24855	18	5E
0005435652903	24855	19	5F
0005433368075	24855	20	6A
0005433368101	24855	21	6C
0005433368079	24855	22	6D
0005433368064	24855	23	6E
0005433368085	24855	24	6F
0005435652833	24855	25	7A
0005435652892	24855	26	7D
0005433368100	24855	27	7E
0005433368086	24855	28	7F
0005433368066	24855	29	8A
0005433368065	24855	30	8C
0005435652728	24855	31	8D
0005435652866	24855	32	8E
0005433368095	24855	33	8F
0005433368068	24855	34	9A
0005433368074	24855	35	9D
0005433368073	24855	36	9F
0005435652865	24855	37	10A
0005435652765	24855	38	10C
0005435652913	24855	39	10D
0005435652708	24855	40	10E
0005435652711	24855	41	10F
0005435652627	24855	42	11A
0005435652898	24855	43	11C
0005435652909	24855	44	11D
0005435652891	24855	45	11F
0005433368094	24855	46	12D
0005433368091	24855	47	12E
0005435652910	24855	48	12F
0005435652901	24855	49	13A
0005435652703	24855	50	13C
0005435652859	24855	51	13D
0005435652722	24855	52	13E
0005435652834	24855	53	13F
0005433368087	24855	54	14A
0005433368093	24855	55	14C
0005435652912	24855	56	14D
0005435652680	24855	57	14E
0005433368063	24855	58	14F
0005435652739	24855	59	15A
0005435652775	24855	60	15C
0005435652893	24855	61	15D
0005433368076	24855	62	15E
0005435652784	24855	63	15F
0005433368097	24855	64	16A
0005435652902	24855	65	16C
0005435652729	24855	66	16D
0005433368069	24855	67	16E
0005435652709	24855	68	16F
0005433368081	24855	69	17A
0005435652727	24855	70	17C
0005433368090	24855	71	17D
0005433368082	24855	72	17E
0005433368089	24855	73	17F
0005435652869	24855	74	18A
0005435652882	24855	75	18C
0005433368102	24855	76	18D
0005435652641	24855	77	18E
0005433368078	24855	78	18F
0005435652823	24855	79	19A
0005433368084	24855	80	19C
0005433368096	24855	81	19D
0005433368083	24855	82	19E
0005433368070	24855	83	19F
0005433368088	24855	84	20A
0005435652716	24855	85	20C
0005433368080	24855	86	20D
0005433368099	24855	87	20E
0005435652856	24855	88	20F
0005434979958	2042	1	1B
0005434979938	2042	2	1D
0005435801710	2042	3	2A
0005434979956	2042	4	2B
0005434979931	2042	5	2C
0005434979944	2042	6	2D
0005434979933	2042	7	3A
0005434979930	2042	8	3B
0005434979959	2042	9	3C
0005434979941	2042	10	4A
0005434979929	2042	11	4B
0005434979936	2042	12	4D
0005434979949	2042	13	5B
0005434979950	2042	14	5C
0005434979947	2042	15	6A
0005434979935	2042	16	6B
0005434979945	2042	17	6D
0005434979932	2042	18	7A
0005434979946	2042	19	7D
0005434979954	2042	20	18A
0005434979937	2042	21	18C
0005434979940	2042	22	18D
0005434979955	2042	23	19A
0005434979951	2042	24	19B
0005435801712	2042	25	19C
0005434979953	2042	26	19D
0005434979942	2042	27	20B
0005434979934	2042	28	20C
0005435801711	2042	29	21A
0005435801713	2042	30	21B
0005434979952	2042	31	21C
0005434979948	2042	32	22A
0005434979943	2042	33	22B
0005434979957	2042	34	22D
0005434979939	2042	35	23B
0005434979598	23524	1	1A
0005434979619	23524	2	1C
0005434979647	23524	3	2A
0005434979599	23524	4	2B
0005435801688	23524	5	3C
0005434979738	23524	6	4A
0005434979641	23524	7	4C
0005434979646	23524	8	4D
0005434979640	23524	9	5A
0005434979665	23524	10	5B
0005434979604	23524	11	5D
0005434979623	23524	12	6A
0005434979563	23524	13	6B
0005434979581	23524	14	6C
0005434979562	23524	15	7B
0005434979617	23524	16	7C
0005434979571	23524	17	7D
0005434979636	23524	18	18B
0005434979676	23524	19	18C
0005434979572	23524	20	18D
0005434979799	23524	21	19A
0005435801694	23524	22	19B
0005434979637	23524	23	19C
0005434979580	23524	24	19D
0005434979666	23524	25	20A
0005434979710	23524	26	20B
0005434979498	23524	27	20C
0005434979687	23524	28	21A
0005434979535	23524	29	21B
0005434979657	23524	30	21C
0005435801693	23524	31	22B
0005434979618	23524	32	22C
0005435801680	23524	33	22D
0005434979648	23524	34	23A
0005434979709	23524	35	23B
0005434952549	2649	1	1A
0005434952550	2649	2	3A
0005434952551	2649	3	5A
0005434952548	2649	4	6A
0005433256419	2650	1	1A
0005433256418	2650	2	5A
0005433256410	2650	3	6B
0005434952531	28227	1	1A
0005433256434	28227	2	1B
0005433256432	28227	3	4A
0005433256433	28227	4	4B
0005433256435	28227	5	5B
0005434952512	28227	6	6A
0005433112383	19736	1	1B
0005433112382	19736	2	2B
0005433111517	19736	3	3A
0005433111519	19736	4	5A
0005433111518	19736	5	6A
0005434137710	11930	1	1C
0005434137714	11930	2	1F
0005434137967	11930	3	2A
0005434137390	11930	4	2F
0005434138126	11930	5	3A
0005434138040	11930	6	3C
0005434137873	11930	7	3D
0005434137771	11930	8	3F
0005434137684	11930	9	4A
0005434137748	11930	10	4C
0005434138033	11930	11	4D
0005434138009	11930	12	4E
0005434138100	11930	13	5A
0005434137644	11930	14	5C
0005434137742	11930	15	5E
0005434137814	11930	16	5F
0005434138097	11930	17	6C
0005434137643	11930	18	6D
0005434138019	11930	19	6E
0005434137846	11930	20	7A
0005434137680	11930	21	7C
0005434137716	11930	22	7D
0005434138134	11930	23	7E
0005434137715	11930	24	7F
0005434137717	11930	25	8A
0005434137815	11930	26	8C
0005434137304	11930	27	8D
0005434137779	11930	28	8E
0005434138011	11930	29	8F
0005434138086	11930	30	9A
0005434137985	11930	31	9C
0005434137968	11930	32	9D
0005434138092	11930	33	9E
0005434138012	11930	34	9F
0005434138221	11930	35	10A
0005434137934	11930	36	10C
0005434137747	11930	37	10D
0005434137705	11930	38	10E
0005434137987	11930	39	10F
0005434137813	11930	40	11A
0005434137949	11930	41	11C
0005434137951	11930	42	11D
0005434138265	11930	43	11E
0005434137917	11930	44	12A
0005434138124	11930	45	12C
0005434137780	11930	46	12D
0005434137882	11930	47	12E
0005434137816	11930	48	12F
0005434137812	11930	49	13A
0005434137704	11930	50	13C
0005434138021	11930	51	13D
0005434137883	11930	52	13E
0005434138008	11930	53	13F
0005434137990	11930	54	14C
0005434137709	11930	55	14A
0005434137756	11930	56	14D
0005434137933	11930	57	14E
0005434138200	11930	58	15A
0005434137912	11930	59	15C
0005434138101	11930	60	15D
0005434137729	11930	61	15E
0005434137983	11930	62	16A
0005434138010	11930	63	16C
0005434138085	11930	64	16D
0005434138093	11930	65	16E
0005434137988	11930	66	16F
0005434137685	11930	67	17A
0005434137731	11930	68	17C
0005434137911	11930	69	17D
0005434138191	11930	70	17E
0005434137706	11930	71	17F
0005434137989	11930	72	18C
0005434137682	11930	73	18E
0005434138199	11930	74	18F
0005434137642	11930	75	19A
0005434137683	11930	76	19C
0005434137881	11930	77	19D
0005434137843	11930	78	19E
0005434138003	11930	79	19F
0005434137984	11930	80	20C
0005434137730	11930	81	20F
0005434138518	28767	1	1A
0005434138513	28767	2	1C
0005434138547	28767	3	1D
0005434138530	28767	4	1F
0005434138525	28767	5	2A
0005434138480	28767	6	2C
0005434138532	28767	7	2D
0005434138471	28767	8	2F
0005434138491	28767	9	3A
0005434138533	28767	10	3C
0005434138539	28767	11	3D
0005434138507	28767	12	3F
0005434138482	28767	13	4A
0005434138544	28767	14	4C
0005434138500	28767	15	4D
0005434138526	28767	16	4F
0005434138488	28767	17	5A
0005434138515	28767	18	5C
0005434138503	28767	19	5D
0005434138495	28767	20	5E
0005434138523	28767	21	5F
0005434138514	28767	22	6A
0005434138505	28767	23	6D
0005434138548	28767	24	6E
0005434138531	28767	25	6F
0005434138481	28767	26	7A
0005434138499	28767	27	7D
0005434138510	28767	28	7F
0005434138511	28767	29	8A
0005434138551	28767	30	8C
0005434138529	28767	31	8D
0005434138474	28767	32	8F
0005434138542	28767	33	9A
0005434138535	28767	34	9C
0005434138473	28767	35	9D
0005434138489	28767	36	9E
0005434138478	28767	37	9F
0005434138487	28767	38	10A
0005434138521	28767	39	10C
0005434138534	28767	40	10D
0005434138501	28767	41	10E
0005434138541	28767	42	10F
0005434138540	28767	43	11A
0005434138497	28767	44	11E
0005434138543	28767	45	11F
0005434138546	28767	46	12A
0005434138492	28767	47	12C
0005434138506	28767	48	12D
0005434138483	28767	49	13A
0005434138512	28767	50	13C
0005434138504	28767	51	13D
0005434138470	28767	52	13E
0005434138498	28767	53	13F
0005434138552	28767	54	14A
0005434138528	28767	55	14C
0005434138484	28767	56	14E
0005434138545	28767	57	14F
0005434138537	28767	58	15C
0005434138524	28767	59	15D
0005434138475	28767	60	15E
0005434138479	28767	61	16A
0005434138536	28767	62	16C
0005434138490	28767	63	16D
0005434138476	28767	64	16E
0005434138477	28767	65	16F
0005434138485	28767	66	17A
0005434138517	28767	67	17C
0005434138550	28767	68	17E
0005434138496	28767	69	17F
0005434138502	28767	70	18A
0005434138522	28767	71	18C
0005434138493	28767	72	18E
0005434138549	28767	73	18F
0005434138486	28767	74	19A
0005434138494	28767	75	19C
0005434138527	28767	76	19D
0005434138519	28767	77	19E
0005434138520	28767	78	19F
0005434138508	28767	79	20A
0005434138472	28767	80	20C
0005434138509	28767	81	20D
0005434138538	28767	82	20E
0005434138516	28767	83	20F
0005433538911	6793	1	1B
0005433538910	6793	2	1C
0005433538917	6793	3	2B
0005433538918	6793	4	4C
0005433538919	6793	5	7B
0005433538915	6793	6	7C
0005435259749	6793	7	18A
0005435259739	6793	8	18D
0005433534508	6793	9	19B
0005433538914	6793	10	19C
0005433538912	6793	11	20A
0005433538913	6793	12	21B
0005433534509	6793	13	21C
0005433534510	6793	14	21D
0005433538916	6793	15	23B
0005433538804	25000	1	1A
0005433538844	25000	2	1B
0005435259781	25000	3	2A
0005435259778	25000	4	2C
0005435259779	25000	5	2D
0005433534487	25000	6	3A
0005433538823	25000	7	3B
0005435259780	25000	8	4B
0005433538848	25000	9	5B
0005433534489	25000	10	6C
0005433534490	25000	11	7A
0005433538819	25000	12	18B
0005433538853	25000	13	20A
0005433534486	25000	14	20D
0005433538810	25000	15	21D
0005435259777	25000	16	22B
0005433511994	819	1	2A
0005433511993	819	2	2B
0005433511996	819	3	3C
0005432922517	819	4	4C
0005433511992	819	5	5B
0005433511995	819	6	7B
0005432922519	819	7	19A
0005432922518	819	8	20B
0005432922516	819	9	20C
0005433511991	819	10	21A
0005433511998	819	11	21B
0005433511997	819	12	21C
0005432922544	16140	1	2B
0005433511914	16140	2	3A
0005432922545	16140	3	6A
0005433511920	16140	4	20A
0005432922546	16140	5	22C
0005432922547	16140	6	23A
0005435697494	3650	1	1A
0005434950554	3650	2	1B
0005435697496	3650	3	1C
0005435697498	3650	4	2A
0005435697485	3650	5	2B
0005435697489	3650	6	2C
0005435697500	3650	7	2D
0005435697476	3650	8	3A
0005435697497	3650	9	3B
0005435697491	3650	10	3D
0005434950553	3650	11	4A
0005435935034	3650	12	4B
0005435697502	3650	13	4C
0005435697479	3650	14	5A
0005435935033	3650	15	5B
0005435697495	3650	16	5C
0005435697481	3650	17	6A
0005435697480	3650	18	6B
0005435697475	3650	19	6C
0005435916154	3650	20	6D
0005435697499	3650	21	7A
0005435697487	3650	22	7B
0005435697492	3650	23	7C
0005435697477	3650	24	7D
0005435697484	3650	25	18A
0005435697482	3650	26	18B
0005435697486	3650	27	18C
0005435697490	3650	28	19A
0005435697483	3650	29	19B
0005435697493	3650	30	19C
0005434950552	3650	31	19D
0005435935021	3650	32	20A
0005434950551	3650	33	20B
0005435697488	3650	34	21C
0005435697503	3650	35	22A
0005435697478	3650	36	22B
0005435697501	3650	37	23A
0005435697474	3650	38	23B
0005435697231	16301	1	1A
0005435916183	16301	2	1B
0005435697256	16301	3	1D
0005435697264	16301	4	3A
0005435697201	16301	5	3B
0005435697284	16301	6	3C
0005434950502	16301	7	3D
0005435697200	16301	8	4A
0005435697320	16301	9	4B
0005435916181	16301	10	4D
0005435697188	16301	11	5A
0005435935060	16301	12	5B
0005435935059	16301	13	5C
0005435916182	16301	14	6B
0005435697315	16301	15	7D
0005435697318	16301	16	18B
0005435697266	16301	17	18D
0005435697282	16301	18	19A
0005435697196	16301	19	19B
0005435697232	16301	20	19C
0005435697237	16301	21	20B
0005435697283	16301	22	20C
0005435697137	16301	23	21B
0005435697356	16301	24	21C
0005435697271	16301	25	22A
0005435697195	16301	26	22B
0005435697198	16301	27	22C
0005435697163	16301	28	22D
0005435697230	16301	29	23A
0005435935061	16301	30	23B
0005432607587	3978	1	1A
0005433519481	3978	2	1B
0005432607589	3978	3	1D
0005432607588	3978	4	2A
0005434606847	3978	5	2C
0005434606846	3978	6	3A
0005434606845	3978	7	3C
0005434604916	3978	8	4A
0005432609753	3978	9	4C
0005435904705	3978	10	6A
0005432609754	3978	11	6C
0005433519482	3978	12	7A
0005435853602	3978	13	7C
0005435842325	3978	14	7D
0005435841472	3978	15	18A
0005434604915	3978	16	19A
0005435841474	3978	17	19B
0005434604917	3978	18	19C
0005433519483	3978	19	19D
0005435842324	3978	20	20B
0005435841473	3978	21	21B
0005432609752	3978	22	22C
0005432607586	3978	23	22D
0005433519456	22086	1	1A
0005433519458	22086	2	1B
0005432609709	22086	3	1D
0005432609703	22086	4	2A
0005432609704	22086	5	2C
0005434606815	22086	6	2B
0005432613833	22086	7	2D
0005432609714	22086	8	3A
0005432609694	22086	9	3B
0005432613828	22086	10	3C
0005432613822	22086	11	3D
0005432613821	22086	12	4A
0005432609680	22086	13	4B
0005432613844	22086	14	4C
0005432609701	22086	15	4D
0005433519442	22086	16	5A
0005432613818	22086	17	5B
0005432609686	22086	18	5C
0005432613855	22086	19	5D
0005432613853	22086	20	6A
0005432613827	22086	21	6C
0005434606816	22086	22	7A
0005432613839	22086	23	7B
0005434606808	22086	24	7C
0005432609683	22086	25	18A
0005432609699	22086	26	18B
0005432613817	22086	27	18C
0005432613816	22086	28	18D
0005432613834	22086	29	19A
0005432613837	22086	30	19B
0005432609700	22086	31	19C
0005434606807	22086	32	19D
0005432613819	22086	33	20A
0005432609679	22086	34	20B
0005432609678	22086	35	20C
0005433519430	22086	36	20D
0005433519457	22086	37	21A
0005432613826	22086	38	21B
0005432613840	22086	39	21C
0005432609682	22086	40	21D
0005432609707	22086	41	22B
0005432613825	22086	42	22C
0005432613838	22086	43	22D
0005432609706	22086	44	23A
0005432613820	22086	45	23B
0005433348978	711	1	1B
0005433348977	711	2	2A
0005433348951	711	3	3A
0005435628738	711	4	4A
0005435628737	711	5	4B
0005433348972	711	6	5B
0005433348964	711	7	6A
0005433348971	711	8	6B
0005433349017	15879	1	1A
0005433349022	15879	2	1B
0005435628713	15879	3	2A
0005433349021	15879	4	2B
0005433349018	15879	5	4B
0005433349020	15879	6	6A
0005433349019	15879	7	6B
0005434446526	17181	1	1A
0005434446528	17181	2	4A
0005433159299	17181	3	5A
0005434446525	17181	4	5B
0005434446527	17181	5	6A
0005433159300	17181	6	6B
0005433159326	17596	1	1A
0005434445229	17596	2	2A
0005434445242	17596	3	3A
0005434445241	17596	4	4B
0005433159327	17596	5	5A
0005433159324	17596	6	5B
0005433159325	17596	7	6B
0005435132941	7866	1	4D
0005435383143	7866	2	5A
0005435132936	7866	3	5C
0005435132942	7866	4	6A
0005435132935	7866	5	7B
0005435132932	7866	6	18D
0005435132933	7866	7	19D
0005435132940	7866	8	20C
0005435132937	7866	9	21D
0005435132938	7866	10	22A
0005435132939	7866	11	22B
0005435132934	7866	12	23B
0005435132827	33109	1	2A
0005435132868	33109	2	2D
0005435383177	33109	3	3B
0005435383180	33109	4	4B
0005435383178	33109	5	5A
0005435132834	33109	6	5D
0005435132840	33109	7	6B
0005435383181	33109	8	6C
0005435383182	33109	9	18A
0005435132826	33109	10	18C
0005435383176	33109	11	18D
0005435132861	33109	12	19A
0005435383179	33109	13	20A
0005435132878	33109	14	23A
0005435811097	4411	1	1C
0005435811103	4411	2	1A
0005435938870	4411	3	2F
0005435811101	4411	4	6B
0005435938875	4411	5	7F
0005435811102	4411	6	8B
0005435811099	4411	7	9F
0005435811098	4411	8	10E
0005435811105	4411	9	10F
0005435938867	4411	10	11E
0005435811100	4411	11	12A
0005435938876	4411	12	12B
0005435938869	4411	13	13F
0005435938882	4411	14	15D
0005435811096	4411	15	17D
0005435938871	4411	16	18C
0005435938868	4411	17	18F
0005435811104	4411	18	19C
0005435938874	4411	19	21B
0005435938902	29444	1	1D
0005435938899	29444	2	5A
0005435811079	29444	3	6D
0005435938901	29444	4	6C
0005435938897	29444	5	6E
0005435811042	29444	6	7C
0005435811055	29444	7	7D
0005435811052	29444	8	10A
0005435811040	29444	9	10E
0005435938898	29444	10	10F
0005435938900	29444	11	12A
0005435811060	29444	12	12D
0005435811062	29444	13	12C
0005435811057	29444	14	14C
0005435811050	29444	15	14B
0005435811039	29444	16	14E
0005435938903	29444	17	16C
0005435811047	29444	18	16B
0005435811078	29444	19	16D
0005435811063	29444	20	19D
0005435811056	29444	21	20B
0005435811053	29444	22	21E
0005435811049	29444	23	21F
0005435390208	7479	1	1B
0005435160366	7479	2	2D
0005435160357	7479	3	3A
0005435160360	7479	4	3C
0005435160363	7479	5	4A
0005435160355	7479	6	4B
0005435160358	7479	7	4C
0005435160362	7479	8	7A
0005435160359	7479	9	7B
0005435160364	7479	10	7C
0005435160365	7479	11	18A
0005435390224	7479	12	18C
0005435390223	7479	13	20A
0005435160361	7479	14	20C
0005435390220	7479	15	20D
0005435390212	7479	16	22B
0005435390203	7479	17	22C
0005435160356	7479	18	23A
0005435160291	29560	1	1A
0005435160273	29560	2	2B
0005435160262	29560	3	2D
0005435160306	29560	4	3B
0005435160263	29560	5	3C
0005435390277	29560	6	5A
0005435160305	29560	7	6B
0005435160307	29560	8	6C
0005435390278	29560	9	7B
0005435390276	29560	10	18A
0005435390279	29560	11	18B
0005435160290	29560	12	19A
0005435160260	29560	13	19C
0005435160256	29560	14	19D
0005435390275	29560	15	20A
0005435160242	29560	16	20C
0005435160241	29560	17	20D
0005435160264	29560	18	21C
0005435160309	29560	19	22A
0005432394089	18454	1	4A
0005432398185	18454	2	5A
0005432398184	18454	3	6A
0005435178502	18454	4	5B
0005435178503	18454	5	6B
0005432398212	27152	1	1A
0005432400142	27152	2	1B
0005435178487	27152	3	2A
0005435179391	27152	4	2B
0005432398213	27152	5	3A
0005432398215	27152	6	3B
0005432398214	27152	7	4A
0005435179387	27152	8	4B
0005432400140	27152	9	5A
0005432400141	27152	10	5B
0005435178488	27152	11	6A
0005432398211	27152	12	6B
0005434191268	9744	1	2B
0005434191271	9744	2	3B
0005434504376	6556	1	1A
0005434504344	6556	2	1C
0005434504379	6556	3	1D
0005434504355	6556	4	2A
0005435103975	6556	5	2C
0005434504342	6556	6	3F
0005434504365	6556	7	4A
0005435103974	6556	8	4C
0005434504360	6556	9	4E
0005434504345	6556	10	5E
0005434504370	6556	11	5F
0005434504371	6556	12	6D
0005434504357	6556	13	6E
0005435103969	6556	14	6F
0005434504380	6556	15	7E
0005434504368	6556	16	7F
0005434504351	6556	17	8C
0005434504349	6556	18	8E
0005434504377	6556	19	9D
0005434504347	6556	20	10A
0005434504359	6556	21	10C
0005434504378	6556	22	10D
0005434504358	6556	23	11C
0005435103971	6556	24	11D
0005434504367	6556	25	11E
0005434504352	6556	26	11F
0005434504353	6556	27	12C
0005435103968	6556	28	12E
0005435103973	6556	29	12F
0005434504381	6556	30	13A
0005435103976	6556	31	13D
0005435103978	6556	32	13F
0005434504361	6556	33	14A
0005434504363	6556	34	14C
0005434504343	6556	35	14E
0005434504382	6556	36	15A
0005434504375	6556	37	15D
0005434504346	6556	38	16A
0005434504372	6556	39	16C
0005435103970	6556	40	16D
0005434504350	6556	41	17C
0005434504354	6556	42	17D
0005434504366	6556	43	17F
0005434504373	6556	44	18A
0005434504374	6556	45	18C
0005434504369	6556	46	18D
0005434504364	6556	47	18E
0005435103972	6556	48	18F
0005435103977	6556	49	19A
0005434504362	6556	50	19C
0005434504348	6556	51	19D
0005434504356	6556	52	19F
0005434504043	22684	1	1A
0005435103859	22684	2	1D
0005434503900	22684	3	2A
0005434504042	22684	4	1F
0005434503850	22684	5	2D
0005434503885	22684	6	2F
0005434503987	22684	7	3D
0005434504055	22684	8	5F
0005434503985	22684	9	6D
0005434503894	22684	10	6E
0005434503825	22684	11	7E
0005434503795	22684	12	7F
0005435103855	22684	13	8C
0005434503988	22684	14	8E
0005434503867	22684	15	8F
0005434503915	22684	16	9D
0005434504029	22684	17	9F
0005434503798	22684	18	10A
0005434504041	22684	19	10C
0005434503925	22684	20	10E
0005434503961	22684	21	11A
0005434503984	22684	22	11C
0005434503986	22684	23	11E
0005434503821	22684	24	11F
0005434503756	22684	25	12C
0005434504056	22684	26	12D
0005434503799	22684	27	12E
0005434503895	22684	28	12F
0005434503876	22684	29	13A
0005434503924	22684	30	13C
0005434504039	22684	31	13E
0005434503841	22684	32	14C
0005434503967	22684	33	14D
0005434503737	22684	34	14F
0005434503784	22684	35	15A
0005434503822	22684	36	15C
0005434503973	22684	37	15E
0005434503968	22684	38	16A
0005434503738	22684	39	16C
0005434504040	22684	40	16E
0005434504084	22684	41	16F
0005434503884	22684	42	17A
0005434504050	22684	43	17C
0005435103862	22684	44	17D
0005434503796	22684	45	17F
0005434503914	22684	46	18C
0005435103854	22684	47	18D
0005434504005	22684	48	18E
0005435103835	22684	49	18F
0005434503983	22684	50	19C
0005434503899	22684	51	19F
0005434503783	22684	52	20E
0005434503879	22684	53	20F
0005435800101	21305	1	1B
0005435800084	21305	2	2A
0005435800097	21305	3	2C
0005435800096	21305	4	4A
0005435800090	21305	5	4C
0005435800082	21305	6	5B
0005435800091	21305	7	7A
0005435800086	21305	8	7C
0005435800093	21305	9	7D
0005435800095	21305	10	18A
0005435800094	21305	11	20B
0005435800092	21305	12	20D
0005435800083	21305	13	21B
0005435800085	21305	14	22D
0005435653274	1650	1	1A
0005433367704	1650	2	1C
0005435653262	1650	3	1D
0005433367700	1650	4	1F
0005433367867	1650	5	2F
0005435653289	1650	6	3A
0005433367759	1650	7	3C
0005433367706	1650	8	3D
0005435653294	1650	9	3F
0005433367649	1650	10	4A
0005433367823	1650	11	4C
0005433367760	1650	12	4D
0005433367721	1650	13	4E
0005433367572	1650	14	4F
0005433367826	1650	15	5A
0005435653267	1650	16	5C
0005435653279	1650	17	5E
0005435653292	1650	18	5F
0005435653266	1650	19	6A
0005435653290	1650	20	6C
0005433367857	1650	21	7A
0005435653281	1650	22	7C
0005433367687	1650	23	7D
0005435653286	1650	24	7E
0005433367745	1650	25	7F
0005435653276	1650	26	8A
0005433367705	1650	27	8C
0005433367643	1650	28	8D
0005435653285	1650	29	8F
0005435653284	1650	30	9A
0005435653271	1650	31	9C
0005435653283	1650	32	9D
0005433367602	1650	33	9F
0005435653277	1650	34	10A
0005433367744	1650	35	10C
0005433367822	1650	36	10D
0005433367727	1650	37	10F
0005435653275	1650	38	11A
0005435653280	1650	39	11D
0005433367722	1650	40	11E
0005433367628	1650	41	12A
0005433367688	1650	42	12E
0005435653278	1650	43	12F
0005433367832	1650	44	13C
0005435653273	1650	45	13E
0005435653268	1650	46	13F
0005433367796	1650	47	14A
0005435653264	1650	48	14C
0005435653293	1650	49	14D
0005435653288	1650	50	15A
0005435653291	1650	51	15D
0005433367726	1650	52	15F
0005433367606	1650	53	16C
0005433367611	1650	54	16D
0005433367571	1650	55	16E
0005433367821	1650	56	17C
0005433367854	1650	57	17D
0005435653272	1650	58	17E
0005433367819	1650	59	17F
0005433367752	1650	60	18A
0005435653282	1650	61	18C
0005435653265	1650	62	18D
0005435653287	1650	63	18E
0005435653263	1650	64	18F
0005433367825	1650	65	19C
0005433367849	1650	66	19D
0005433367907	1650	67	19E
0005435653269	1650	68	19F
0005433367607	1650	69	20C
0005435653270	1650	70	20D
0005433367845	1650	71	20E
0005433367850	1650	72	20F
0005433368065	21667	1	1A
0005433368070	21667	2	1C
0005435652892	21667	3	1D
0005435652727	21667	4	1F
0005435652856	21667	5	2C
0005435652859	21667	6	2D
0005433368067	21667	7	2F
0005433368087	21667	8	3C
0005435652834	21667	9	3D
0005435652790	21667	10	3F
0005435652750	21667	11	4A
0005435652765	21667	12	4C
0005435652711	21667	13	4D
0005435652703	21667	14	4E
0005433368081	21667	15	4F
0005433368099	21667	16	5A
0005433368080	21667	17	5C
0005435652909	21667	18	5D
0005435652794	21667	19	5E
0005435652898	21667	20	5F
0005433368095	21667	21	6A
0005433368094	21667	22	6C
0005435652627	21667	23	6D
0005433368102	21667	24	6F
0005433368063	21667	25	7A
0005435652784	21667	26	7C
0005433368074	21667	27	7D
0005435652722	21667	28	7E
0005435652709	21667	29	7F
0005435652855	21667	30	8A
0005435652901	21667	31	8C
0005433368096	21667	32	8D
0005435652882	21667	33	8E
0005435652823	21667	34	8F
0005435652912	21667	35	9A
0005435652903	21667	36	9C
0005433368084	21667	37	9D
0005433368066	21667	38	9E
0005435652679	21667	39	9F
0005435652891	21667	40	10A
0005433368082	21667	41	10C
0005435652716	21667	42	10E
0005433368097	21667	43	10F
0005435652910	21667	44	11A
0005435652729	21667	45	11C
0005435652708	21667	46	11D
0005435652775	21667	47	11E
0005435652730	21667	48	11F
0005433368071	21667	49	12A
0005435652785	21667	50	12C
0005435652865	21667	51	12D
0005433368079	21667	52	12E
0005433368088	21667	53	12F
0005433368098	21667	54	13A
0005433368093	21667	55	13D
0005433368085	21667	56	13E
0005435652913	21667	57	13F
0005433368086	21667	58	14C
0005435652793	21667	59	14E
0005433368083	21667	60	14D
0005433368068	21667	61	14F
0005433368075	21667	62	15A
0005433368064	21667	63	15C
0005433368078	21667	64	15D
0005433368072	21667	65	15E
0005433368090	21667	66	15F
0005433368100	21667	67	16A
0005433368089	21667	68	16C
0005435652680	21667	69	16E
0005435652728	21667	70	16D
0005433368077	21667	71	16F
0005435652866	21667	72	17A
0005435652739	21667	73	17D
0005435652860	21667	74	17E
0005433368101	21667	75	18A
0005433368076	21667	76	18C
0005435652833	21667	77	18D
0005435652911	21667	78	18E
0005435652893	21667	79	18F
0005433368091	21667	80	19A
0005435652914	21667	81	19C
0005433368073	21667	82	19D
0005433368069	21667	83	19E
0005433368092	21667	84	19F
0005435652869	21667	85	20A
0005435652641	21667	86	20D
0005435652885	21667	87	20E
0005435652902	21667	88	20F
0005433986198	4171	1	1A
0005433986211	4171	2	1D
0005433986210	4171	3	1F
0005433986193	4171	4	2A
0005433986209	4171	5	3A
0005433986218	4171	6	3C
0005433986199	4171	7	3D
0005433986176	4171	8	4A
0005433986183	4171	9	5A
0005433986212	4171	10	5C
0005433986192	4171	11	5F
0005433986196	4171	12	6A
0005433986201	4171	13	6C
0005433986187	4171	14	6F
0005433986194	4171	15	7A
0005435788783	4171	16	7E
0005433986217	4171	17	8C
0005433986184	4171	18	8E
0005433986200	4171	19	9C
0005433986190	4171	20	9D
0005433986189	4171	21	9F
0005433986207	4171	22	10D
0005433986214	4171	23	11C
0005433986197	4171	24	11D
0005433986186	4171	25	12E
0005433986202	4171	26	13C
0005433986185	4171	27	13D
0005433986177	4171	28	13E
0005433986206	4171	29	13F
0005433986204	4171	30	14D
0005433986215	4171	31	14F
0005433986182	4171	32	15A
0005433986178	4171	33	15C
0005435788785	4171	34	15D
0005433986191	4171	35	15E
0005433986208	4171	36	16E
0005433986180	4171	37	16F
0005433986213	4171	38	17D
0005433986216	4171	39	17E
0005433986205	4171	40	18A
0005433986203	4171	41	18E
0005433986188	4171	42	18F
0005433986179	4171	43	19F
0005433986181	4171	44	20A
0005433986195	4171	45	20D
0005435788784	4171	46	20F
0005433985714	25652	1	2C
0005433985712	25652	2	2D
0005433985651	25652	3	2F
0005433985752	25652	4	3A
0005433985560	25652	5	3D
0005433985688	25652	6	3F
0005433985687	25652	7	4A
0005433985680	25652	8	4C
0005433985685	25652	9	4D
0005433985692	25652	10	5A
0005433985431	25652	11	5F
0005433985691	25652	12	6E
0005433985753	25652	13	6F
0005433985668	25652	14	7C
0005433985585	25652	15	7D
0005433985709	25652	16	7E
0005433985432	25652	17	7F
0005435788769	25652	18	8A
0005433985535	25652	19	8C
0005433985678	25652	20	8D
0005433985677	25652	21	9C
0005433985648	25652	22	9D
0005433985737	25652	23	10E
0005433985624	25652	24	11D
0005433985755	25652	25	11E
0005433985713	25652	26	11F
0005433985679	25652	27	12C
0005433985652	25652	28	13C
0005433985542	25652	29	13F
0005433985689	25652	30	14C
0005433985722	25652	31	14D
0005433985475	25652	32	15D
0005433985569	25652	33	15F
0005433985590	25652	34	16A
0005435788765	25652	35	16C
0005433985534	25652	36	16D
0005433985672	25652	37	16E
0005433985667	25652	38	16F
0005433985476	25652	39	17D
0005433985541	25652	40	18E
0005433985686	25652	41	19E
0005433985684	25652	42	19F
0005433985693	25652	43	20E
0005435720821	21255	1	1C
0005435719563	21255	2	2B
0005435719565	21255	3	2D
0005435720820	21255	4	5C
0005435720139	24772	1	20A
0005435720137	24772	2	22A
0005435720138	24772	3	22B
0005433168347	1624	1	1A
0005434509181	1624	2	1B
0005433168359	1624	3	1C
0005434509186	1624	4	2B
0005433168346	1624	5	3B
0005434509187	1624	6	3C
0005433168339	1624	7	3D
0005434509191	1624	8	4A
0005433168350	1624	9	4C
0005434509182	1624	10	4D
0005434509185	1624	11	5A
0005434509188	1624	12	5C
0005433168345	1624	13	7C
0005433168349	1624	14	7D
0005434509184	1624	15	18C
0005433168342	1624	16	18D
0005433168370	1624	17	19B
0005433168354	1624	18	19D
0005434509190	1624	19	20A
0005434509183	1624	20	20B
0005434509193	1624	21	20D
0005433168344	1624	22	21A
0005434509192	1624	23	21B
0005433168355	1624	24	21D
0005434509189	1624	25	22D
0005433168343	1624	26	23A
0005432663016	17827	1	1C
0005432664122	17827	2	1F
0005432655504	17827	3	3A
0005432655518	17827	4	4E
0005432655498	17827	5	4F
0005432869563	17827	6	5A
0005432667454	17827	7	5C
0005432869560	17827	8	6A
0005432658579	17827	9	6C
0005432655517	17827	10	6D
0005432658592	17827	11	6E
0005432665273	17827	12	7D
0005432869566	17827	13	8A
0005432869567	17827	14	9A
0005432655481	17827	15	9D
0005432666374	17827	16	9E
0005432655493	17827	17	10A
0005432655448	17827	18	10E
0005432655505	17827	19	12E
0005434151721	17827	20	13A
0005432869561	17827	21	13D
0005432667455	17827	22	14C
0005434151722	17827	23	14E
0005432655497	17827	24	14F
0005432655492	17827	25	15C
0005432659704	17827	26	15F
0005432665274	17827	27	16D
0005432655447	17827	28	16E
0005432655455	17827	29	17C
0005432660810	17827	30	17E
0005432869565	17827	31	18A
0005432665275	17827	32	18E
0005432659703	17827	33	18F
0005432869562	17827	34	19A
0005432667444	17827	35	19E
0005432655488	17827	36	20A
0005432660809	17827	37	20C
0005432869564	17827	38	20D
0005432655582	26335	1	1A
0005432666397	26335	2	1F
0005432667462	26335	3	4A
0005432655574	26335	4	4E
0005432667463	26335	5	4F
0005432869499	26335	6	5C
0005432869483	26335	7	5E
0005434151689	26335	8	6E
0005432655572	26335	9	6F
0005432655571	26335	10	7A
0005432658599	26335	11	7C
0005432660826	26335	12	9F
0005432869497	26335	13	10C
0005432666398	26335	14	10E
0005432655576	26335	15	11A
0005432655577	26335	16	11C
0005434151692	26335	17	11F
0005432655581	26335	18	12A
0005432657462	26335	19	12C
0005432655578	26335	20	13C
0005432666396	26335	21	13D
0005432665283	26335	22	14D
0005432869496	26335	23	14E
0005432655575	26335	24	15C
0005432657460	26335	25	16F
0005432660825	26335	26	17A
0005432655579	26335	27	17C
0005432655580	26335	28	17E
0005432655573	26335	29	17F
0005432869500	26335	30	18C
0005432659715	26335	31	18E
0005434151690	26335	32	19A
0005432665282	26335	33	19F
0005432869495	26335	34	20A
0005432869492	26335	35	20C
0005432657461	26335	36	20D
0005432869456	26335	37	20F
0005432866052	25057	1	2A
0005432639029	25057	2	1F
0005432639060	25057	3	2F
0005432866050	25057	4	4C
0005432639077	25057	5	4D
0005432639076	25057	6	4E
0005432866055	25057	7	5F
0005432639100	25057	8	6A
0005432866045	25057	9	7A
0005432866049	25057	10	7C
0005432866056	25057	11	8E
0005432639047	25057	12	8F
0005432639046	25057	13	11D
0005432866047	25057	14	11E
0005432639104	25057	15	11F
0005432866044	25057	16	12C
0005432639063	25057	17	13C
0005432866046	25057	18	13D
0005432639071	25057	19	14C
0005432639083	25057	20	15C
0005432866051	25057	21	15E
0005432639082	25057	22	16C
0005432639043	25057	23	16E
0005432866057	25057	24	16F
0005432866048	25057	25	17D
0005432866053	25057	26	18C
0005432639042	25057	27	18E
0005432866054	25057	28	19D
0005432639103	25057	29	20A
0005432639106	25057	30	20C
0005432905124	3107	1	1D
0005432328965	3107	2	1F
0005432328935	3107	3	2A
0005432905134	3107	4	2D
0005432328927	3107	5	2F
0005432328928	3107	6	3A
0005432328937	3107	7	3C
0005432328929	3107	8	3D
0005432905109	3107	9	3F
0005433438918	3107	10	4A
0005432328932	3107	11	4C
0005432328938	3107	12	4D
0005433438917	3107	13	4E
0005433438922	3107	14	5A
0005432328943	3107	15	5C
0005432328930	3107	16	5D
0005432328941	3107	17	5E
0005432328966	3107	18	5F
0005433438916	3107	19	6C
0005432328968	3107	20	6E
0005433438915	3107	21	6F
0005432328945	3107	22	7A
0005432328961	3107	23	7C
0005432905122	3107	24	7D
0005432328970	3107	25	7E
0005432328969	3107	26	7F
0005432328946	3107	27	8A
0005432328940	3107	28	8C
0005433438919	3107	29	8D
0005433438923	3107	30	8E
0005432328950	3107	31	8F
0005432328953	3107	32	9A
0005432328960	3107	33	9C
0005432328959	3107	34	9D
0005432328934	3107	35	9F
0005432328933	3107	36	10C
0005432328955	3107	37	10D
0005432328939	3107	38	10E
0005433438924	3107	39	10F
0005432328942	3107	40	11C
0005432328963	3107	41	11D
0005432328952	3107	42	11E
0005432328948	3107	43	12A
0005432905123	3107	44	12C
0005432328944	3107	45	12E
0005432905100	3107	46	13D
0005432287214	3107	47	13E
0005433438925	3107	48	13F
0005433438913	3107	49	14A
0005432287217	3107	50	14C
0005432328954	3107	51	14D
0005432905116	3107	52	14E
0005432905107	3107	53	15C
0005432287215	3107	54	15D
0005433438921	3107	55	15E
0005432905108	3107	56	16C
0005432328962	3107	57	16E
0005432287216	3107	58	16F
0005432328931	3107	59	17A
0005432328947	3107	60	17C
0005433438920	3107	61	17D
0005432287218	3107	62	18C
0005432328956	3107	63	18D
0005432328967	3107	64	18E
0005432328957	3107	65	18F
0005432328958	3107	66	19A
0005432328936	3107	67	19C
0005433438914	3107	68	19D
0005432328951	3107	69	19F
0005432905114	3107	70	20A
0005432328964	3107	71	20C
0005432328949	3107	72	20D
0005432328926	3107	73	20E
0005432328637	31140	1	1A
0005432328521	31140	2	1C
0005432905152	31140	3	1F
0005432328453	31140	4	2C
0005432328586	31140	5	2F
0005433438842	31140	6	3C
0005432054321	31140	7	3D
0005432328624	31140	8	3F
0005432328565	31140	9	4A
0005432328497	31140	10	4C
0005432328556	31140	11	4D
0005432328529	31140	12	4E
0005432328451	31140	13	5C
0005432905158	31140	14	5D
0005432328669	31140	15	5E
0005432054320	31140	16	6D
0005432328627	31140	17	6E
0005432328555	31140	18	6F
0005432328625	31140	19	7C
0005432328629	31140	20	7E
0005433438849	31140	21	7F
0005432328439	31140	22	8C
0005432328535	31140	23	8D
0005432328530	31140	24	8E
0005432328293	31140	25	8F
0005432328545	31140	26	9A
0005432328539	31140	27	9C
0005432328468	31140	28	9D
0005432328484	31140	29	9E
0005432328551	31140	30	9F
0005432328683	31140	31	10A
0005432328560	31140	32	10C
0005432328524	31140	33	10D
0005432054322	31140	34	10E
0005432328403	31140	35	10F
0005432328452	31140	36	11A
0005432328467	31140	37	11C
0005432328517	31140	38	11D
0005432328534	31140	39	11E
0005432328552	31140	40	11F
0005432905156	31140	41	12C
0005433438843	31140	42	12D
0005432905153	31140	43	12E
0005432328525	31140	44	13A
0005432328569	31140	45	13C
0005432328492	31140	46	13D
0005433438812	31140	47	13E
0005432054318	31140	48	13F
0005432328446	31140	49	14A
0005432328587	31140	50	14C
0005432328485	31140	51	14F
0005432328561	31140	52	15A
0005432328576	31140	53	15C
0005432328337	31140	54	15D
0005432328404	31140	55	15F
0005432905154	31140	56	16C
0005432328501	31140	57	16E
0005432328537	31140	58	16F
0005432328479	31140	59	17D
0005432905157	31140	60	17E
0005432328544	31140	61	17F
0005432328668	31140	62	18A
0005432328543	31140	63	18C
0005432328438	31140	64	18F
0005432328377	31140	65	19A
0005432328414	31140	66	19C
0005432905155	31140	67	19D
0005432328458	31140	68	19E
0005432328533	31140	69	20C
0005432328508	31140	70	20E
0005432054319	31140	71	20F
0005434309818	6199	1	1C
0005432146211	6199	2	1D
0005435487780	6199	3	2C
0005435487838	6199	4	2A
0005435487726	6199	5	2F
0005435297004	6199	6	3A
0005434309819	6199	7	3D
0005435487837	6199	8	3F
0005435487743	6199	9	4A
0005434309817	6199	10	4C
0005434309811	6199	11	4F
0005435999348	6199	12	5B
0005435487753	6199	13	5F
0005435487665	6199	14	6C
0005435487760	6199	15	6D
0005435487664	6199	16	6E
0005435297016	6199	17	6F
0005435487661	6199	18	7C
0005434309821	6199	19	7E
0005435487803	6199	20	8A
0005435487678	6199	21	8D
0005435999353	6199	22	8F
0005435297010	6199	23	8E
0005435999335	6199	24	9A
0005435999352	6199	25	9C
0005434309808	6199	26	9D
0005435487690	6199	27	9F
0005435297015	6199	28	9E
0005435297013	6199	29	10C
0005435487763	6199	30	10B
0005435999347	6199	31	10D
0005435297036	6199	32	11B
0005435999346	6199	33	11C
0005435999350	6199	34	11E
0005435999338	6199	35	11D
0005435487759	6199	36	11F
0005435999343	6199	37	12B
0005435999342	6199	38	12C
0005435297014	6199	39	12E
0005435297023	6199	40	13A
0005435999340	6199	41	13B
0005434309810	6199	42	13D
0005435999349	6199	43	13E
0005434309816	6199	44	13F
0005434309809	6199	45	14A
0005435297005	6199	46	14B
0005434309813	6199	47	14F
0005435999354	6199	48	15C
0005435999336	6199	49	15D
0005435999337	6199	50	15F
0005435297059	6199	51	16B
0005435999351	6199	52	16A
0005434309820	6199	53	16C
0005435999355	6199	54	16E
0005434309815	6199	55	17A
0005435297047	6199	56	16F
0005435999345	6199	57	17C
0005435487752	6199	58	17D
0005434309812	6199	59	17F
0005435487725	6199	60	18A
0005435999356	6199	61	18C
0005432146210	6199	62	18B
0005434309814	6199	63	18E
0005432146209	6199	64	18F
0005435999344	6199	65	19B
0005435487728	6199	66	20B
0005435999339	6199	67	20E
0005435297058	6199	68	20F
0005435487705	6199	69	21A
0005435297011	6199	70	21C
0005435999341	6199	71	21B
0005435487713	6199	72	23F
0005435999129	19558	1	1A
0005435487922	19558	2	1D
0005435487939	19558	3	2F
0005435297095	19558	4	2D
0005435999098	19558	5	3D
0005434309672	19558	6	3F
0005434309673	19558	7	4C
0005434309730	19558	8	4B
0005435999230	19558	9	4E
0005435487920	19558	10	5B
0005435999195	19558	11	5A
0005435999196	19558	12	5C
0005435297098	19558	13	5D
0005435487933	19558	14	5F
0005435999172	19558	15	6A
0005435999223	19558	16	6C
0005434309676	19558	17	6B
0005435487929	19558	18	6F
0005435297094	19558	19	7E
0005435487925	19558	20	7F
0005434309630	19558	21	8B
0005434309631	19558	22	8F
0005435999177	19558	23	9D
0005435999154	19558	24	9F
0005434309748	19558	25	10C
0005435487938	19558	26	10D
0005435487927	19558	27	11A
0005434309678	19558	28	10E
0005434309658	19558	29	11C
0005435999145	19558	30	11D
0005435487931	19558	31	11F
0005435999100	19558	32	12B
0005435487924	19558	33	13A
0005435487935	19558	34	13B
0005434309718	19558	35	13C
0005434309670	19558	36	13D
0005435999155	19558	37	14A
0005435487940	19558	38	14D
0005435999146	19558	39	14C
0005435999142	19558	40	14E
0005434309596	19558	41	14F
0005435999115	19558	42	15C
0005435297093	19558	43	15E
0005435487926	19558	44	16A
0005434309677	19558	45	16B
0005434309693	19558	46	16C
0005435487923	19558	47	16D
0005435999114	19558	48	16E
0005435999156	19558	49	17A
0005435999171	19558	50	16F
0005435999236	19558	51	17B
0005435999194	19558	52	18A
0005435999170	19558	53	18C
0005435487937	19558	54	19A
0005435297097	19558	55	19C
0005435487934	19558	56	19D
0005435487928	19558	57	20A
0005435487936	19558	58	20C
0005434309671	19558	59	20B
0005435487919	19558	60	20E
0005435487930	19558	61	21A
0005435999099	19558	62	21C
0005435487932	19558	63	21B
0005435487921	19558	64	21D
0005435297092	19558	65	22B
0005435297096	19558	66	23B
0005435518007	1578	1	1A
0005435502420	1578	2	1C
0005435517997	1578	3	1F
0005434565983	1578	4	2C
0005434565989	1578	5	2D
0005434565988	1578	6	2F
0005435502422	1578	7	3F
0005434565992	1578	8	4C
0005435502438	1578	9	4D
0005435518015	1578	10	4E
0005435508406	1578	11	4F
0005434565980	1578	12	5A
0005432291942	1578	13	5C
0005435502436	1578	14	5D
0005435508410	1578	15	5E
0005435508409	1578	16	5F
0005435518006	1578	17	6C
0005435508408	1578	18	6D
0005435502430	1578	19	6E
0005435518002	1578	20	7A
0005435502426	1578	21	7C
0005434565987	1578	22	7E
0005435517998	1578	23	7F
0005433186060	1578	24	8A
0005435518008	1578	25	8C
0005435508413	1578	26	8D
0005435518004	1578	27	8F
0005435502433	1578	28	9A
0005435502437	1578	29	9C
0005435518011	1578	30	9D
0005435502435	1578	31	9E
0005435502425	1578	32	9F
0005435508416	1578	33	10A
0005435502428	1578	34	10C
0005435518005	1578	35	10D
0005434565993	1578	36	10E
0005435508411	1578	37	10F
0005434565982	1578	38	11A
0005435517999	1578	39	11D
0005433186106	1578	40	11F
0005435502429	1578	41	12C
0005435518014	1578	42	12D
0005435502431	1578	43	12E
0005435502440	1578	44	12F
0005435518001	1578	45	13A
0005434565986	1578	46	13C
0005433186097	1578	47	13D
0005435508407	1578	48	13E
0005432291943	1578	49	13F
0005435518013	1578	50	14A
0005433186107	1578	51	14C
0005435502423	1578	52	14D
0005434565984	1578	53	14F
0005435502427	1578	54	15C
0005435518012	1578	55	15E
0005435508415	1578	56	16A
0005435502439	1578	57	16C
0005435518010	1578	58	16D
0005435518009	1578	59	16F
0005435502424	1578	60	17D
0005434565990	1578	61	18A
0005435518000	1578	62	18C
0005435502434	1578	63	18D
0005435518003	1578	64	18F
0005435508412	1578	65	19A
0005435502432	1578	66	19C
0005435508414	1578	67	19D
0005434565981	1578	68	20A
0005434565991	1578	69	20C
0005434565985	1578	70	20D
0005435502421	1578	71	20E
0005435545706	20879	1	1A
0005435529133	20879	2	1D
0005435529191	20879	3	2A
0005435502298	20879	4	2C
0005435529134	20879	5	2D
0005434565892	20879	6	2F
0005435529101	20879	7	3A
0005435502117	20879	8	3C
0005435529190	20879	9	3D
0005433186166	20879	10	3F
0005435502266	20879	11	4C
0005435545694	20879	12	4D
0005435529063	20879	13	4E
0005435502210	20879	14	4F
0005435545708	20879	15	5A
0005435529167	20879	16	5C
0005435545696	20879	17	5E
0005435502213	20879	18	5F
0005435502184	20879	19	6A
0005433186161	20879	20	6C
0005435529138	20879	21	6E
0005433186164	20879	22	6F
0005435545713	20879	23	7A
0005435502128	20879	24	7C
0005435545647	20879	25	7D
0005435529088	20879	26	7E
0005435502198	20879	27	7F
0005435545711	20879	28	8A
0005435545703	20879	29	8D
0005434565821	20879	30	8E
0005435529195	20879	31	8F
0005434565822	20879	32	9A
0005435502223	20879	33	9C
0005435502185	20879	34	9E
0005435502267	20879	35	9F
0005435502212	20879	36	10A
0005435529166	20879	37	10D
0005435545695	20879	38	10E
0005435502127	20879	39	10F
0005435545722	20879	40	11A
0005433186167	20879	41	11C
0005435529202	20879	42	11D
0005435502155	20879	43	11F
0005435529160	20879	44	12A
0005435529205	20879	45	12C
0005435502156	20879	46	12D
0005434565868	20879	47	12E
0005435502288	20879	48	12F
0005434565823	20879	49	13A
0005435529102	20879	50	13E
0005435529115	20879	51	13F
0005435529168	20879	52	14A
0005435502250	20879	53	14C
0005435545646	20879	54	14D
0005435545714	20879	55	14E
0005434565884	20879	56	14F
0005435529117	20879	57	15A
0005435529161	20879	58	15D
0005435545658	20879	59	15E
0005435502208	20879	60	15F
0005433186163	20879	61	16C
0005435529093	20879	62	16D
0005435502201	20879	63	16E
0005434565824	20879	64	16F
0005435545718	20879	65	17C
0005433186168	20879	66	17D
0005435545705	20879	67	17E
0005435529069	20879	68	17F
0005435529056	20879	69	18A
0005435502218	20879	70	18C
0005435529165	20879	71	18D
0005435502230	20879	72	18E
0005433186162	20879	73	18F
0005435529116	20879	74	19A
0005433186165	20879	75	19C
0005435502116	20879	76	19E
0005435529094	20879	77	19F
0005435529137	20879	78	20A
0005434565883	20879	79	20C
0005434565877	20879	80	20D
0005435502217	20879	81	20E
0005435529146	20879	82	20F
0005435153780	3930	1	2A
0005435153776	3930	2	4C
0005435153775	3930	3	7D
0005435931605	3930	4	20B
0005435153777	3930	5	21D
0005435153778	3930	6	22A
0005435153779	3930	7	22B
0005435153774	3930	8	22D
0005435153698	21870	1	2B
0005435153697	21870	2	2C
0005435153712	21870	3	3D
0005435931620	21870	4	4A
0005435153726	21870	5	4C
0005435931621	21870	6	6B
0005435931622	21870	7	18D
0005435153717	21870	8	19D
0005435153739	21870	9	20A
0005435931623	21870	10	21A
0005432628933	7197	1	1D
0005432628924	7197	2	2B
0005432628920	7197	3	3A
0005432628928	7197	4	2D
0005432628925	7197	5	3D
0005432628930	7197	6	5B
0005432628919	7197	7	6A
0005432628921	7197	8	6B
0005432628922	7197	9	18A
0005435225526	7197	10	18B
0005435225580	7197	11	19C
0005432628927	7197	12	19D
0005432628923	7197	13	20B
0005432628931	7197	14	20D
0005435225525	7197	15	21B
0005432628929	7197	16	21D
0005432628934	7197	17	22A
0005432628932	7197	18	22C
0005435225544	7197	19	22D
0005432628926	7197	20	23A
0005432628834	28096	1	1A
0005432628825	28096	2	1D
0005435225629	28096	3	2C
0005432628736	28096	4	3C
0005432628838	28096	5	4A
0005435225626	28096	6	4B
0005432628870	28096	7	4D
0005432628820	28096	8	5A
0005435225631	28096	9	6A
0005435225632	28096	10	6B
0005432628847	28096	11	6D
0005432628821	28096	12	7A
0005435225624	28096	13	7D
0005432628861	28096	14	18B
0005432628789	28096	15	18D
0005435225630	28096	16	20A
0005432628850	28096	17	20C
0005435225625	28096	18	20D
0005435225627	28096	19	21C
0005435225628	28096	20	21D
0005432628833	28096	21	22A
0005432628869	28096	22	22B
0005432628835	28096	23	22C
0005432628826	28096	24	23B
0005434267947	8718	1	1C
0005435960071	8718	2	19A
0005435960070	8718	3	19B
0005435960072	8718	4	20A
0005434267946	8718	5	22B
0005435960073	8718	6	23B
0005434267969	15242	1	3C
0005434267972	15242	2	3D
0005435960042	15242	3	5A
0005434267968	15242	4	6A
0005435960043	15242	5	7B
0005434267973	15242	6	18B
0005434267971	15242	7	18C
0005435960037	15242	8	18D
0005434267970	15242	9	19D
0005432677592	1211	1	1A
0005432675212	1211	2	1F
0005432693195	1211	3	2F
0005432873271	1211	4	2D
0005432693219	1211	5	3A
0005432873267	1211	6	3C
0005432873268	1211	7	4D
0005432675213	1211	8	4C
0005432693207	1211	9	5C
0005432675210	1211	10	5A
0005432693210	1211	11	5D
0005432675207	1211	12	6A
0005432677593	1211	13	6D
0005432675209	1211	14	7A
0005432693201	1211	15	6F
0005432693206	1211	16	7B
0005432873280	1211	17	7E
0005432693200	1211	18	8A
0005432693212	1211	19	8B
0005432675217	1211	20	9A
0005432693216	1211	21	9D
0005432677590	1211	22	9C
0005432693214	1211	23	9E
0005432677589	1211	24	10A
0005432693213	1211	25	10C
0005432693218	1211	26	10B
0005432675211	1211	27	10E
0005432693217	1211	28	10D
0005432675215	1211	29	11C
0005432677591	1211	30	11B
0005432675206	1211	31	11E
0005432693220	1211	32	12B
0005432675219	1211	33	12A
0005432693222	1211	34	12C
0005432693191	1211	35	12D
0005432873272	1211	36	13A
0005432693221	1211	37	13C
0005432693211	1211	38	13D
0005432873270	1211	39	14A
0005432675205	1211	40	14C
0005432693199	1211	41	14B
0005432675221	1211	42	14E
0005432873273	1211	43	14D
0005432693202	1211	44	15D
0005432693192	1211	45	15C
0005432675218	1211	46	15B
0005432675208	1211	47	16C
0005432693196	1211	48	16B
0005432693203	1211	49	17A
0005432693190	1211	50	16F
0005432693209	1211	51	17D
0005432693197	1211	52	17E
0005432693193	1211	53	18E
0005432873269	1211	54	19A
0005432693198	1211	55	19C
0005432693204	1211	56	19D
0005432675220	1211	57	20B
0005432693208	1211	58	20D
0005432693215	1211	59	20C
0005432693205	1211	60	20E
0005432873279	1211	61	21A
0005432693194	1211	62	21C
0005432675216	1211	63	21E
0005432675214	1211	64	21D
0005432675098	17494	1	2A
0005432675110	17494	2	2F
0005432692827	17494	3	2D
0005432675113	17494	4	2C
0005432693046	17494	5	3A
0005432675109	17494	6	3D
0005432674998	17494	7	3F
0005432677544	17494	8	4D
0005432873332	17494	9	4C
0005432692980	17494	10	4A
0005432692991	17494	11	4F
0005432675069	17494	12	5D
0005432692984	17494	13	6D
0005432693000	17494	14	6C
0005432675057	17494	15	6F
0005432873333	17494	16	7C
0005432677538	17494	17	7B
0005432692840	17494	18	7F
0005432692786	17494	19	8C
0005432675079	17494	20	8B
0005432692826	17494	21	8A
0005432692784	17494	22	8D
0005432692935	17494	23	9B
0005432692969	17494	24	9E
0005432677537	17494	25	10A
0005432693006	17494	26	9F
0005432692925	17494	27	10C
0005432675064	17494	28	10B
0005432692986	17494	29	10E
0005432873330	17494	30	10D
0005432675091	17494	31	11A
0005432692839	17494	32	11D
0005432675112	17494	33	12A
0005432675058	17494	34	13A
0005432873329	17494	35	12F
0005432692894	17494	36	13E
0005432692785	17494	37	14C
0005432692897	17494	38	14E
0005432692929	17494	39	14F
0005432692946	17494	40	15B
0005432692853	17494	41	15A
0005432692898	17494	42	16A
0005432692787	17494	43	16C
0005432677560	17494	44	16B
0005432675111	17494	45	16D
0005432692854	17494	46	16E
0005432692848	17494	47	17A
0005432873328	17494	48	17C
0005432692934	17494	49	18A
0005432692937	17494	50	18C
0005432692694	17494	51	18D
0005432692900	17494	52	19D
0005432692906	17494	53	20A
0005432873331	17494	54	19E
0005432675068	17494	55	20B
0005432873327	17494	56	20C
0005432873326	17494	57	20E
0005432677561	17494	58	21B
0005432692990	17494	59	21D
0005434435260	1109	1	1A
0005433156743	1109	2	1C
0005433156735	1109	3	1D
0005433156722	1109	4	3C
0005434435262	1109	5	3D
0005434435267	1109	6	4A
0005434435258	1109	7	4B
0005433156744	1109	8	4C
0005434435265	1109	9	4D
0005434435257	1109	10	5A
0005433156726	1109	11	5C
0005434435271	1109	12	5D
0005434435264	1109	13	6A
0005434435259	1109	14	6D
0005434435269	1109	15	7A
0005433156678	1109	16	7D
0005434435268	1109	17	18D
0005434435270	1109	18	19B
0005434435266	1109	19	19D
0005433156709	1109	20	20D
0005434435256	1109	21	21B
0005433156734	1109	22	21C
0005433156729	1109	23	22C
0005434435263	1109	24	22D
0005434435261	1109	25	23A
0005433156730	1109	26	23B
0005433156792	17287	1	2C
0005434435176	17287	2	2D
0005434435140	17287	3	4A
0005433156798	17287	4	4B
0005433156797	17287	5	4C
0005433156793	17287	6	5C
0005434435105	17287	7	5D
0005433156794	17287	8	6B
0005433156795	17287	9	6C
0005434435069	17287	10	7A
0005434435160	17287	11	18A
0005434435178	17287	12	18D
0005433156796	17287	13	19A
0005434435180	17287	14	19B
0005434435113	17287	15	20D
0005434435081	17287	16	21A
0005434435079	17287	17	21B
0005433156799	17287	18	21C
0005434435147	17287	19	21D
0005433156791	17287	20	22B
0005434435150	17287	21	22D
0005435086876	4094	1	1D
0005435086877	4094	2	2B
0005435928131	4094	3	3A
0005435928111	4094	4	3D
0005435086875	4094	5	6A
0005435086874	4094	6	6D
0005435086872	4094	7	7A
0005435086871	4094	8	18A
0005435086873	4094	9	18B
0005435928130	4094	10	19A
0005435086879	4094	11	20D
0005435928112	4094	12	21A
0005435086878	4094	13	21C
0005435928169	24405	1	3D
0005435928166	24405	2	4B
0005435928168	24405	3	4D
0005435086797	24405	4	7B
0005435928170	24405	5	7C
0005435928172	24405	6	20C
0005435086812	24405	7	21A
0005435928171	24405	8	22B
0005435086796	24405	9	23A
0005435928167	24405	10	23B
0005434964338	1317	1	1C
0005434964326	1317	2	1B
0005434964343	1317	3	1F
0005433261517	1317	4	1G
0005432279284	1317	5	2B
0005432279283	1317	6	2F
0005433261464	1317	7	3C
0005434964327	1317	8	3G
0005433261487	1317	9	4B
0005433261519	1317	10	4G
0005434964321	1317	11	5F
0005433261532	1317	12	5C
0005434964317	1317	13	5H
0005434964340	1317	14	9A
0005433261520	1317	15	11A
0005434964337	1317	16	11G
0005434964335	1317	17	12A
0005433261507	1317	18	11H
0005433261496	1317	19	12D
0005433261497	1317	20	12H
0005434964334	1317	21	13E
0005434964309	1317	22	14E
0005433261534	1317	23	14H
0005434964341	1317	24	14G
0005434964329	1317	25	15D
0005434964308	1317	26	15F
0005432279282	1317	27	16D
0005434964315	1317	28	17H
0005432279281	1317	29	18B
0005434964330	1317	30	18F
0005433261538	1317	31	19A
0005434964332	1317	32	19E
0005433261547	1317	33	19H
0005434964313	1317	34	20A
0005433261516	1317	35	20B
0005434964311	1317	36	21D
0005434964328	1317	37	21F
0005434964314	1317	38	22B
0005434964336	1317	39	22E
0005434964323	1317	40	22G
0005433261504	1317	41	23E
0005434964325	1317	42	24D
0005434964305	1317	43	24G
0005434964312	1317	44	27H
0005434964324	1317	45	27G
0005434964331	1317	46	28F
0005433261554	1317	47	28H
0005433261535	1317	48	29A
0005434964342	1317	49	29D
0005433261525	1317	50	30A
0005433261569	1317	51	30G
0005434964322	1317	52	30H
0005433261523	1317	53	31B
0005434964307	1317	54	31A
0005434964306	1317	55	31E
0005433261495	1317	56	32B
0005433261546	1317	57	32F
0005433261522	1317	58	32E
0005434964310	1317	59	34E
0005434964320	1317	60	34G
0005432279280	1317	61	35A
0005433261518	1317	62	35G
0005433261570	1317	63	36B
0005434964339	1317	64	36A
0005434964333	1317	65	36E
0005434964318	1317	66	37B
0005433261561	1317	67	38A
0005434964319	1317	68	38D
0005434964316	1317	69	38F
0005433261521	1317	70	39D
0005434964146	18246	1	1A
0005434964190	18246	2	1C
0005433261613	18246	3	2A
0005434964144	18246	4	2B
0005434964165	18246	5	3C
0005434964145	18246	6	3G
0005434964093	18246	7	4A
0005434964253	18246	8	4B
0005434964202	18246	9	4F
0005434964097	18246	10	5B
0005433261624	18246	11	5A
0005434964048	18246	12	5F
0005433261609	18246	13	5C
0005433261626	18246	14	9B
0005433261612	18246	15	11A
0005433261610	18246	16	11F
0005434964130	18246	17	12A
0005433261614	18246	18	12D
0005434964098	18246	19	12G
0005434964187	18246	20	13A
0005433261617	18246	21	13D
0005434964178	18246	22	13B
0005434964194	18246	23	13E
0005434964153	18246	24	13H
0005433261611	18246	25	14B
0005433261616	18246	26	14D
0005433261608	18246	27	14G
0005434964125	18246	28	15D
0005433261622	18246	29	15F
0005434964148	18246	30	17B
0005433261619	18246	31	17F
0005434964100	18246	32	17G
0005434964185	18246	33	18B
0005434964155	18246	34	19A
0005434964071	18246	35	19B
0005434964055	18246	36	20H
0005433261621	18246	37	21G
0005434964072	18246	38	22A
0005433261618	18246	39	22F
0005433261623	18246	40	23B
0005434964210	18246	41	24E
0005434964081	18246	42	24G
0005434964166	18246	43	25D
0005434964193	18246	44	25E
0005433261620	18246	45	27E
0005434964154	18246	46	28E
0005434964150	18246	47	28D
0005434964189	18246	48	29D
0005434964167	18246	49	30E
0005434964151	18246	50	31E
0005434964195	18246	51	31H
0005433261625	18246	52	32B
0005434964188	18246	53	32E
0005434964186	18246	54	33A
0005434964129	18246	55	33B
0005434964061	18246	56	33G
0005434964147	18246	57	33F
0005434964133	18246	58	34G
0005434964134	18246	59	34F
0005434964022	18246	60	35B
0005434964132	18246	61	35F
0005434964152	18246	62	36B
0005434964203	18246	63	36A
0005433261615	18246	64	37F
0005434964171	18246	65	37G
0005435907500	4855	1	1D
0005433194855	4855	2	4E
0005434626013	4855	3	5A
0005434626007	4855	4	5E
0005434626014	4855	5	6A
0005434626016	4855	6	6E
0005434626008	4855	7	6F
0005434626015	4855	8	9A
0005434626010	4855	9	9C
0005433194843	4855	10	10C
0005435907492	4855	11	11A
0005434626009	4855	12	11F
0005434626012	4855	13	12F
0005435907501	4855	14	13A
0005435907486	4855	15	13D
0005435907507	4855	16	13F
0005435907487	4855	17	18C
0005434626011	4855	18	18F
0005435907499	4855	19	19C
0005435907505	4855	20	20C
0005435907491	4855	21	20F
0005434625965	32912	1	1D
0005434625918	32912	2	1F
0005435907528	32912	3	3D
0005435907529	32912	4	4C
0005435907527	32912	5	6C
0005434625922	32912	6	7C
0005435907526	32912	7	7F
0005434625924	32912	8	10C
0005434625919	32912	9	11A
0005434625951	32912	10	11E
0005434625960	32912	11	13C
0005433194861	32912	12	13D
0005434625938	32912	13	14A
0005434625937	32912	14	15C
0005434625945	32912	15	15E
0005435907530	32912	16	16A
0005434625959	32912	17	18F
0005435907531	32912	18	20D
0005435785233	13802	1	1A
0005435785232	13802	2	1B
0005435785069	13802	3	1C
0005435785174	13802	4	1D
0005435785029	13802	5	2A
0005435785197	13802	6	2B
0005435785236	13802	7	2C
0005435785079	13802	8	2D
0005435785235	13802	9	3A
0005435785160	13802	10	3B
0005435785265	13802	11	3C
0005435787341	13802	12	3D
0005435787327	13802	13	4A
0005435785030	13802	14	4B
0005435785163	13802	15	4C
0005435785191	13802	16	4D
0005435785200	13802	17	5A
0005435785180	13802	18	5B
0005435785164	13802	19	5D
0005435785280	13802	20	6A
0005435785080	13802	21	6B
0005435785231	13802	22	6C
0005435787353	13802	23	6D
0005435785256	13802	24	7A
0005435787337	13802	25	7B
0005435785266	13802	26	7C
0005435784991	13802	27	7D
0005435785186	13802	28	18A
0005435785155	13802	29	18B
0005435937401	13802	30	18C
0005435785140	13802	31	18D
0005435785165	13802	32	19A
0005435785229	13802	33	19B
0005435785198	13802	34	19C
0005435787351	13802	35	19D
0005435785255	13802	36	20A
0005435785324	13802	37	20B
0005435787336	13802	38	20C
0005435937400	13802	39	20D
0005435785241	13802	40	21A
0005435785141	13802	41	21B
0005432195704	13802	42	21C
0005435785154	13802	43	21D
0005435785068	13802	44	22A
0005435785072	13802	45	22B
0005435785139	13802	46	22C
0005435785073	13802	47	22D
0005435785234	13802	48	23A
0005435787352	13802	49	23B
0005435937356	27397	1	1A
0005435785478	27397	2	1B
0005435785482	27397	3	1C
0005435785480	27397	4	1D
0005435785499	27397	5	2A
0005432190644	27397	6	2B
0005435785473	27397	7	2D
0005435785500	27397	8	3A
0005435785472	27397	9	3B
0005435785493	27397	10	3C
0005435785506	27397	11	3D
0005435937349	27397	12	4A
0005435785477	27397	13	4B
0005435785486	27397	14	4C
0005435785474	27397	15	4D
0005435785483	27397	16	5A
0005435785498	27397	17	5B
0005432190645	27397	18	5C
0005435785501	27397	19	5D
0005435785475	27397	20	6A
0005435787363	27397	21	6B
0005435785485	27397	22	6C
0005435785492	27397	23	6D
0005435785504	27397	24	7A
0005435787362	27397	25	7B
0005435785505	27397	26	7C
0005435785488	27397	27	7D
0005435785479	27397	28	18A
0005435785481	27397	29	18B
0005435785476	27397	30	18C
0005432190642	27397	31	18D
0005435785489	27397	32	19A
0005435785497	27397	33	19B
0005435785491	27397	34	19C
0005435785494	27397	35	19D
0005435785496	27397	36	20A
0005435787364	27397	37	20C
0005435785484	27397	38	20B
0005435785502	27397	39	20D
0005435785490	27397	40	21A
0005435787361	27397	41	21B
0005432190643	27397	42	21D
0005435785487	27397	43	22A
0005435785471	27397	44	22B
0005435785503	27397	45	22D
0005435785495	27397	46	23A
0005435937337	27397	47	23B
0005435311131	20283	1	1A
0005434407655	20283	2	1C
0005434407704	20283	3	1D
0005434407547	20283	4	1F
0005434407405	20283	5	2A
0005434407567	20283	6	2C
0005434407654	20283	7	2D
0005435311124	20283	8	2F
0005434407469	20283	9	3A
0005434407664	20283	10	3D
0005434407579	20283	11	3F
0005434407531	20283	12	4A
0005435311126	20283	13	4C
0005434407737	20283	14	4E
0005434407614	20283	15	4F
0005434407716	20283	16	5C
0005434407482	20283	17	5D
0005435311120	20283	18	5F
0005435311137	20283	19	6A
0005434407336	20283	20	6C
0005434407419	20283	21	6D
0005434407424	20283	22	6E
0005434407701	20283	23	6F
0005434407662	20283	24	7A
0005434407468	20283	25	7C
0005434407717	20283	26	7D
0005435311128	20283	27	7F
0005435311136	20283	28	8A
0005434407406	20283	29	8C
0005434407580	20283	30	8D
0005434407425	20283	31	8F
0005435311115	20283	32	9A
0005434407732	20283	33	9C
0005434407349	20283	34	9D
0005434407339	20283	35	9E
0005434407712	20283	36	9F
0005434407511	20283	37	10A
0005434407393	20283	38	10C
0005434407607	20283	39	10E
0005434407731	20283	40	10F
0005435311133	20283	41	11A
0005434407532	20283	42	11C
0005435311135	20283	43	11D
0005432058403	20283	44	11E
0005434407615	20283	45	11F
0005434407514	20283	46	12A
0005434407733	20283	47	12D
0005435311117	20283	48	12E
0005435311129	20283	49	12F
0005435311130	20283	50	13A
0005434407338	20283	51	13C
0005434407574	20283	52	13D
0005435311116	20283	53	13E
0005434407522	20283	54	13F
0005434407599	20283	55	14A
0005434407534	20283	56	14C
0005434407544	20283	57	14D
0005432058404	20283	58	14E
0005434407606	20283	59	14F
0005435311123	20283	60	15A
0005432058402	20283	61	15C
0005434407526	20283	62	15D
0005435311125	20283	63	15F
0005434407432	20283	64	16A
0005434407578	20283	65	16C
0005434407306	20283	66	17A
0005435311127	20283	67	17C
0005434407548	20283	68	17D
0005434407600	20283	69	17E
0005434407605	20283	70	18A
0005435311118	20283	71	18C
0005435311122	20283	72	18D
0005435311134	20283	73	18E
0005434407746	20283	74	18F
0005434407705	20283	75	19A
0005434407617	20283	76	19C
0005434407575	20283	77	19D
0005434407356	20283	78	19F
0005435311119	20283	79	20A
0005435311121	20283	80	20C
0005435311132	20283	81	20D
0005434407556	20283	82	20E
0005434407415	20283	83	20F
0005432153971	27007	1	1A
0005434408064	27007	2	1C
0005434408089	27007	3	1D
0005434408060	27007	4	2A
0005435310995	27007	5	1F
0005434408087	27007	6	2C
0005434408081	27007	7	2D
0005435311009	27007	8	2F
0005435310964	27007	9	3A
0005435310974	27007	10	3C
0005434408117	27007	11	3D
0005432153974	27007	12	3F
0005432153972	27007	13	4C
0005434408078	27007	14	4D
0005434408105	27007	15	4E
0005432153973	27007	16	4F
0005435310994	27007	17	5A
0005435311011	27007	18	5D
0005434408104	27007	19	5C
0005434408121	27007	20	5E
0005434408111	27007	21	5F
0005435311000	27007	22	6A
0005432153975	27007	23	6C
0005434408085	27007	24	6D
0005434408068	27007	25	6E
0005434408100	27007	26	6F
0005434408086	27007	27	7A
0005434408093	27007	28	7C
0005432153978	27007	29	7D
0005434408070	27007	30	7E
0005434408074	27007	31	7F
0005435310978	27007	32	8A
0005434408109	27007	33	8C
0005434408072	27007	34	8D
0005434408083	27007	35	8E
0005434408088	27007	36	8F
0005434408113	27007	37	9A
0005434408098	27007	38	9C
0005434408066	27007	39	9D
0005435311012	27007	40	9E
0005434408080	27007	41	9F
0005434408110	27007	42	10A
0005434408119	27007	43	10C
0005434408107	27007	44	10D
0005434408115	27007	45	10E
0005434408114	27007	46	10F
0005434408122	27007	47	11A
0005435310965	27007	48	11C
0005435311005	27007	49	11D
0005434408061	27007	50	11E
0005434408095	27007	51	11F
0005435311007	27007	52	12A
0005434408075	27007	53	12C
0005434408091	27007	54	12D
0005434408097	27007	55	12E
0005434408099	27007	56	12F
0005432153977	27007	57	13A
0005434408063	27007	58	13C
0005432153976	27007	59	13D
0005434408082	27007	60	13F
0005434408120	27007	61	14C
0005435311017	27007	62	14E
0005435310975	27007	63	14F
0005434408118	27007	64	15A
0005434408077	27007	65	15C
0005434408071	27007	66	15D
0005434408108	27007	67	15E
0005434408125	27007	68	15F
0005434408069	27007	69	16A
0005434408103	27007	70	16D
0005434408112	27007	71	16E
0005434408084	27007	72	16F
0005434408090	27007	73	17A
0005434408092	27007	74	17C
0005434408073	27007	75	17D
0005434408124	27007	76	17E
0005434408079	27007	77	17F
0005434408065	27007	78	18A
0005434408123	27007	79	18C
0005434408116	27007	80	18D
0005435310997	27007	81	18E
0005434408094	27007	82	18F
0005434408067	27007	83	19A
0005434408102	27007	84	19C
0005435311016	27007	85	19D
0005434408101	27007	86	19E
0005434408096	27007	87	19F
0005434408076	27007	88	20A
0005434408062	27007	89	20C
0005434408106	27007	90	20D
0005434311229	5716	1	1C
0005434319476	5716	2	1D
0005433123833	5716	3	2C
0005433123844	5716	4	3A
0005434319482	5716	5	3D
0005433123890	5716	6	4A
0005434319473	5716	7	4C
0005433123805	5716	8	4F
0005434319474	5716	9	5C
0005434319470	5716	10	5D
0005433123822	5716	11	6F
0005433123752	5716	12	7E
0005433123835	5716	13	8A
0005433123905	5716	14	8E
0005434319471	5716	15	9A
0005434311231	5716	16	9D
0005434319477	5716	17	9E
0005434319485	5716	18	10C
0005433123870	5716	19	10D
0005434319479	5716	20	10F
0005433123759	5716	21	11A
0005433123843	5716	22	11D
0005434319469	5716	23	11F
0005434319472	5716	24	12D
0005433123810	5716	25	13F
0005433123910	5716	26	14A
0005434319486	5716	27	14F
0005434311232	5716	28	15A
0005434319480	5716	29	15C
0005434319487	5716	30	15E
0005432109718	5716	31	15D
0005434319483	5716	32	16F
0005433123891	5716	33	17A
0005433123753	5716	34	17C
0005434319484	5716	35	17D
0005433123816	5716	36	17E
0005434319481	5716	37	17F
0005434319475	5716	38	18C
0005434319478	5716	39	18F
0005433123817	5716	40	19C
0005433123832	5716	41	19D
0005434311230	5716	42	19E
0005433123889	5716	43	20A
0005433124047	15678	1	1D
0005433124049	15678	2	1F
0005433124032	15678	3	2A
0005434319329	15678	4	2D
0005434319305	15678	5	2F
0005434319321	15678	6	3C
0005434319396	15678	7	5C
0005433124048	15678	8	5E
0005434319325	15678	9	6C
0005434312313	15678	10	6F
0005434311216	15678	11	7C
0005433124027	15678	12	7D
0005434319320	15678	13	7F
0005434319319	15678	14	8C
0005434312312	15678	15	8E
0005433124038	15678	16	9A
0005433124045	15678	17	9C
0005433124029	15678	18	9D
0005433124037	15678	19	10A
0005433124042	15678	20	10E
0005433124028	15678	21	11A
0005433124030	15678	22	11C
0005434319362	15678	23	11E
0005434319322	15678	24	11F
0005433124033	15678	25	12D
0005434319391	15678	26	12C
0005433124031	15678	27	12E
0005433124036	15678	28	12F
0005433124050	15678	29	13D
0005434319307	15678	30	13E
0005433124041	15678	31	14E
0005434319402	15678	32	15C
0005434319306	15678	33	15D
0005434319326	15678	34	15E
0005433124043	15678	35	16A
0005434319363	15678	36	16C
0005433124046	15678	37	16E
0005433124035	15678	38	16F
0005434311209	15678	39	17A
0005433124039	15678	40	17C
0005434319379	15678	41	17D
0005434319348	15678	42	18E
0005434319380	15678	43	18F
0005434319299	15678	44	19A
0005433124044	15678	45	19C
0005434319359	15678	46	19D
0005433124040	15678	47	20A
0005433124034	15678	48	20C
0005435220310	24973	1	1C
0005435221510	24973	2	2C
0005435221509	24973	3	4C
0005435220303	24973	4	5A
0005435221507	24973	5	5B
0005435217712	24973	6	5C
0005435220296	24973	7	6B
0005435221508	24973	8	6D
0005435220309	24973	9	7A
0005435221505	24973	10	7D
0005435220308	24973	11	18D
0005435217690	24973	12	19C
0005435217689	24973	13	19D
0005435220318	24973	14	22B
0005435217705	24973	15	22D
0005434484380	8986	1	1C
0005434484383	8986	2	2B
0005434189142	8986	3	2D
0005434484382	8986	4	5B
0005434484385	8986	5	7D
0005434189162	8986	6	18B
0005434189181	8986	7	19A
0005434484384	8986	8	19D
0005434484381	8986	9	21D
0005434189141	8986	10	22A
0005434189207	16644	1	2A
0005434484331	16644	2	2C
0005434189210	16644	3	3C
0005434484317	16644	4	4A
0005434484319	16644	5	5B
0005434484330	16644	6	7A
0005434189211	16644	7	19A
0005434189208	16644	8	20D
0005434484318	16644	9	21B
0005434189209	16644	10	23B
0005433124045	7574	1	1A
0005433722186	7574	2	1D
0005433124039	7574	3	2A
0005433722224	7574	4	3F
0005433124030	7574	5	4D
0005433722219	7574	6	5C
0005433722207	7574	7	5D
0005433124042	7574	8	6C
0005433722208	7574	9	6F
0005433722184	7574	10	7D
0005433722172	7574	11	8A
0005433124048	7574	12	8C
0005433124046	7574	13	8D
0005433124036	7574	14	8E
0005433722213	7574	15	9C
0005433722185	7574	16	9E
0005433124032	7574	17	9F
0005433124047	7574	18	10C
0005433124049	7574	19	10F
0005433124038	7574	20	11A
0005433124028	7574	21	11D
0005433722171	7574	22	11E
0005433124033	7574	23	12C
0005433124040	7574	24	12D
0005433722214	7574	25	13C
0005433722203	7574	26	13F
0005433722220	7574	27	14A
0005433124035	7574	28	14D
0005433124027	7574	29	14E
0005433124044	7574	30	15A
0005433124029	7574	31	15D
0005433124050	7574	32	15F
0005433722195	7574	33	16A
0005433722218	7574	34	16D
0005433124041	7574	35	17E
0005433722210	7574	36	18A
0005433722221	7574	37	18E
0005433124034	7574	38	19C
0005433124037	7574	39	20A
0005433722182	7574	40	20C
0005433124031	7574	41	20E
0005433124043	7574	42	20F
0005433450079	7575	1	1A
0005432721051	7575	2	1D
0005432071590	7575	3	1F
0005432693228	7575	4	2A
0005433450095	7575	5	2C
0005432721034	7575	6	2D
0005432693249	7575	7	2F
0005432721055	7575	8	3A
0005432721038	7575	9	3D
0005432693247	7575	10	3F
0005432721046	7575	11	4A
0005433450082	7575	12	4C
0005433450077	7575	13	4D
0005432693230	7575	14	4E
0005432693242	7575	15	4F
0005432693234	7575	16	5C
0005433450078	7575	17	5D
0005432693246	7575	18	5E
0005432693245	7575	19	5F
0005433450074	7575	20	6A
0005432721054	7575	21	6D
0005432693236	7575	22	6E
0005432721048	7575	23	6F
0005432693248	7575	24	7A
0005432721058	7575	25	7C
0005432693226	7575	26	7D
0005432693227	7575	27	7E
0005432693239	7575	28	7F
0005432721042	7575	29	8A
0005433450087	7575	30	8C
0005432721053	7575	31	8D
0005433450075	7575	32	8E
0005432693223	7575	33	8F
0005432721047	7575	34	9A
0005432693235	7575	35	9C
0005432693244	7575	36	9D
0005433450094	7575	37	9E
0005433450090	7575	38	9F
0005432693250	7575	39	10A
0005433450093	7575	40	10C
0005432721050	7575	41	10D
0005433450076	7575	42	10E
0005433450084	7575	43	10F
0005432721049	7575	44	11C
0005432721036	7575	45	11D
0005433450089	7575	46	11E
0005432721052	7575	47	11F
0005432721040	7575	48	12A
0005432693229	7575	49	12C
0005432693233	7575	50	12D
0005433450081	7575	51	12E
0005432071588	7575	52	12F
0005432693238	7575	53	13A
0005432693232	7575	54	13C
0005432721044	7575	55	13D
0005432693240	7575	56	13E
0005433450080	7575	57	13F
0005432071589	7575	58	14A
0005432721041	7575	59	14E
0005432721043	7575	60	14F
0005433450085	7575	61	15A
0005432721033	7575	62	15C
0005432693243	7575	63	15D
0005433450092	7575	64	15F
0005432721035	7575	65	16A
0005432693237	7575	66	16E
0005432693225	7575	67	16F
0005432693231	7575	68	17A
0005432693251	7575	69	17D
0005432721045	7575	70	18C
0005432693224	7575	71	18D
0005433450088	7575	72	18E
0005432693252	7575	73	18F
0005432721057	7575	74	19A
0005433450091	7575	75	19C
0005432721059	7575	76	19D
0005432721037	7575	77	19E
0005433450086	7575	78	20A
0005432721056	7575	79	20C
0005433450083	7575	80	20D
0005432721039	7575	81	20E
0005432693241	7575	82	20F
0005432692826	30278	1	1A
0005432692894	30278	2	1C
0005432692980	30278	3	2C
0005433449891	30278	4	2D
0005433449975	30278	5	3A
0005433449919	30278	6	3C
0005432692897	30278	7	3F
0005433449907	30278	8	4D
0005432692787	30278	9	4F
0005433449920	30278	10	5A
0005433449904	30278	11	5C
0005432692785	30278	12	5F
0005432692937	30278	13	6A
0005432692694	30278	14	6E
0005432692900	30278	15	6F
0005433449823	30278	16	7A
0005432692929	30278	17	7C
0005432692853	30278	18	7D
0005433449873	30278	19	7E
0005432692986	30278	20	7F
0005433449800	30278	21	8A
0005432692935	30278	22	8C
0005432692898	30278	23	8E
0005432692786	30278	24	8F
0005433449859	30278	25	9A
0005432692946	30278	26	9C
0005433449845	30278	27	9D
0005432692848	30278	28	10C
0005433449852	30278	29	10D
0005432693006	30278	30	10E
0005433449860	30278	31	11C
0005432692906	30278	32	11E
0005432692969	30278	33	11F
0005433449918	30278	34	12A
0005433449903	30278	35	12C
0005433449925	30278	36	13A
0005432692990	30278	37	13E
0005432692991	30278	38	13F
0005433449906	30278	39	14D
0005432692925	30278	40	15A
0005432692827	30278	41	15C
0005433449824	30278	42	15D
0005432693000	30278	43	15E
0005433449863	30278	44	15F
0005432692934	30278	45	16C
0005433449851	30278	46	16F
0005432692840	30278	47	17A
0005433449952	30278	48	17C
0005433449854	30278	49	18C
0005433449853	30278	50	18D
0005432692984	30278	51	18F
0005432692854	30278	52	19A
0005432693046	30278	53	19D
0005432692784	30278	54	19F
0005432692839	30278	55	20E
0005433449951	30278	56	20F
0005433722256	30279	1	1A
0005432720864	30279	2	1D
0005432720818	30279	3	1F
0005432720869	30279	4	2A
0005433123759	30279	5	3C
0005432720891	30279	6	3F
0005433722262	30279	7	4C
0005433123835	30279	8	4D
0005433123752	30279	9	4F
0005433123805	30279	10	5A
0005432720861	30279	11	5C
0005432720825	30279	12	5D
0005433722258	30279	13	5E
0005432720990	30279	14	5F
0005433722264	30279	15	6A
0005433123817	30279	16	6C
0005432720727	30279	17	6D
0005433123832	30279	18	7C
0005433722254	30279	19	7E
0005433123843	30279	20	7F
0005432720877	30279	21	8A
0005433722260	30279	22	8C
0005432720911	30279	23	8D
0005433123905	30279	24	8E
0005432720809	30279	25	8F
0005433123870	30279	26	9C
0005432720868	30279	27	9D
0005432720860	30279	28	9E
0005432720847	30279	29	9F
0005432720909	30279	30	10A
0005432720843	30279	31	11A
0005432720851	30279	32	11C
0005433722259	30279	33	11D
0005432720798	30279	34	11E
0005433722263	30279	35	11F
0005433123822	30279	36	12A
0005433722255	30279	37	12D
0005432720910	30279	38	12E
0005432720844	30279	39	13C
0005433722265	30279	40	13D
0005433123816	30279	41	13E
0005433123889	30279	42	13F
0005432720824	30279	43	14A
0005433123753	30279	44	14C
0005433722269	30279	45	14D
0005433722261	30279	46	14E
0005433123910	30279	47	15A
0005433123833	30279	48	15C
0005433722266	30279	49	15D
0005433123891	30279	50	15E
0005433722268	30279	51	16C
0005433722257	30279	52	16D
0005433123890	30279	53	16E
0005432720754	30279	54	17C
0005432720743	30279	55	17D
0005432720714	30279	56	18A
0005432720951	30279	57	18C
0005432720982	30279	58	18D
0005433123844	30279	59	18E
0005432720826	30279	60	18F
0005432720750	30279	61	19A
0005432720866	30279	62	19D
0005432720819	30279	63	19F
0005433722267	30279	64	20C
0005433123810	30279	65	20E
0005432720865	30279	66	20F
0005433525093	1391	1	1C
0005432927959	1391	2	1D
0005434586753	1391	3	1F
0005433192980	1391	4	2C
0005434586745	1391	5	2F
0005432271020	1391	6	3C
0005433525098	1391	7	3D
0005434586754	1391	8	4A
0005434586744	1391	9	4C
0005433193012	1391	10	4D
0005432271019	1391	11	4E
0005433193033	1391	12	5C
0005433193001	1391	13	5E
0005432927980	1391	14	6A
0005433193013	1391	15	6C
0005433525095	1391	16	6D
0005434586757	1391	17	6E
0005434586738	1391	18	6F
0005433193021	1391	19	7A
0005433525094	1391	20	7C
0005434586760	1391	21	7D
0005433724828	1391	22	7E
0005434586748	1391	23	8A
0005434586752	1391	24	7F
0005432927974	1391	25	8C
0005434586736	1391	26	8D
0005434586742	1391	27	8E
0005433724829	1391	28	9C
0005434513593	1391	29	9D
0005434586759	1391	30	9F
0005433525096	1391	31	10C
0005432927958	1391	32	10D
0005434586761	1391	33	10E
0005433525101	1391	34	10F
0005433193044	1391	35	11C
0005433525097	1391	36	11D
0005432927979	1391	37	11F
0005433193034	1391	38	12A
0005434586741	1391	39	12C
0005434514980	1391	40	12E
0005434514983	1391	41	12D
0005433193002	1391	42	13D
0005434586743	1391	43	13E
0005434513592	1391	44	14C
0005434586739	1391	45	14D
0005434586751	1391	46	14E
0005434586749	1391	47	15A
0005434586750	1391	48	15C
0005433193060	1391	49	15D
0005434586756	1391	50	15E
0005432927953	1391	51	15F
0005433192983	1391	52	16A
0005433525099	1391	53	16C
0005433724827	1391	54	16D
0005433525100	1391	55	16E
0005434586747	1391	56	17A
0005434586758	1391	57	17C
0005433724830	1391	58	17E
0005433192988	1391	59	17F
0005433724826	1391	60	18A
0005434586746	1391	61	18C
0005434513594	1391	62	18E
0005434514982	1391	63	18F
0005434586740	1391	64	19E
0005434514981	1391	65	20A
0005434586755	1391	66	20C
0005434586737	1391	67	20D
0005434586762	1391	68	20E
0005433192973	1391	69	20F
0005433193122	18550	1	1A
0005433724789	18550	2	1C
0005433193118	18550	3	1F
0005434586607	18550	4	2A
0005433525018	18550	5	2C
0005434586554	18550	6	2D
0005434586532	18550	7	3A
0005433724801	18550	8	3C
0005434586614	18550	9	3D
0005434514955	18550	10	4A
0005434586499	18550	11	4D
0005434586399	18550	12	4E
0005433525023	18550	13	4F
0005434586492	18550	14	5C
0005434586601	18550	15	5A
0005434586457	18550	16	5D
0005433525017	18550	17	5E
0005434514956	18550	18	6A
0005433193115	18550	19	6C
0005432968852	18550	20	7A
0005433525035	18550	21	7D
0005433724794	18550	22	7F
0005433524909	18550	23	8C
0005434586546	18550	24	8D
0005432928008	18550	25	8E
0005434586447	18550	26	9A
0005434514952	18550	27	9C
0005433724787	18550	28	9E
0005434586574	18550	29	9F
0005433193113	18550	30	10F
0005433193116	18550	31	11A
0005433193110	18550	32	11C
0005434586458	18550	33	11E
0005433193112	18550	34	12A
0005433524972	18550	35	12C
0005432928010	18550	36	12D
0005434586456	18550	37	12E
0005434586474	18550	38	12F
0005433524973	18550	39	13A
0005434586564	18550	40	13D
0005433724790	18550	41	13E
0005434514953	18550	42	13F
0005433193123	18550	43	14A
0005433193120	18550	44	14C
0005433193117	18550	45	14E
0005433193114	18550	46	15C
0005434586433	18550	47	15D
0005433525053	18550	48	15E
0005434586489	18550	49	15F
0005433525013	18550	50	16C
0005433525012	18550	51	16D
0005434586498	18550	52	16F
0005434586565	18550	53	16E
0005434586533	18550	54	17A
0005433193111	18550	55	17C
0005434586398	18550	56	17D
0005433524988	18550	57	17E
0005433525000	18550	58	18A
0005432928009	18550	59	18C
0005434586488	18550	60	18D
0005433524999	18550	61	18E
0005433193121	18550	62	18F
0005433525007	18550	63	19A
0005434586527	18550	64	19C
0005434586385	18550	65	19D
0005434586602	18550	66	19E
0005434586563	18550	67	19F
0005432968851	18550	68	20A
0005433525011	18550	69	20C
0005433193119	18550	70	20D
0005432928007	18550	71	20E
0005433724800	18550	72	20F
0005434344371	11433	1	1A
0005434344368	11433	2	1B
0005434344372	11433	3	1C
0005434344382	11433	4	1D
0005434142633	11433	5	2A
0005434344374	11433	6	2C
0005435302168	11433	7	2B
0005434344364	11433	8	2D
0005435302177	11433	9	3A
0005434344377	11433	10	3B
0005434344392	11433	11	3C
0005434344376	11433	12	3D
0005434344369	11433	13	4A
0005434344390	11433	14	4B
0005434142630	11433	15	4C
0005434344391	11433	16	4D
0005434344380	11433	17	5A
0005434344367	11433	18	5B
0005434142634	11433	19	5C
0005434142631	11433	20	5D
0005434142632	11433	21	6A
0005434344389	11433	22	6B
0005434344398	11433	23	6C
0005434344370	11433	24	6D
0005434344393	11433	25	7A
0005434344397	11433	26	7C
0005434344366	11433	27	7B
0005434344383	11433	28	7D
0005434344395	11433	29	18A
0005434344365	11433	30	18B
0005434344388	11433	31	18C
0005434344396	11433	32	18D
0005434344373	11433	33	19A
0005434344363	11433	34	19C
0005434344394	11433	35	19D
0005434344375	11433	36	20A
0005434344378	11433	37	20B
0005435305007	11433	38	20C
0005435305000	11433	39	21A
0005434344384	11433	40	21B
0005434344362	11433	41	21C
0005434344386	11433	42	21D
0005435302178	11433	43	22A
0005434344381	11433	44	22B
0005434344385	11433	45	22C
0005434344387	11433	46	22D
0005434344379	11433	47	23B
0005434344104	29787	1	1A
0005434344175	29787	2	1B
0005434142575	29787	3	1C
0005434343999	29787	4	1D
0005434142593	29787	5	2A
0005434344062	29787	6	2B
0005434343995	29787	7	2C
0005434344040	29787	8	2D
0005434344107	29787	9	3A
0005434344073	29787	10	3B
0005434344234	29787	11	3C
0005434344046	29787	12	3D
0005434142574	29787	13	4A
0005434344124	29787	14	4B
0005434344060	29787	15	4C
0005434344251	29787	16	4D
0005434344108	29787	17	5A
0005435304184	29787	18	5B
0005434344024	29787	19	5D
0005434142596	29787	20	6A
0005434344130	29787	21	6B
0005434344131	29787	22	6C
0005434343972	29787	23	6D
0005434344012	29787	24	7A
0005435305023	29787	25	7B
0005434343935	29787	26	7C
0005434344115	29787	27	7D
0005434344000	29787	28	18A
0005434344173	29787	29	18B
0005434344072	29787	30	18C
0005434344019	29787	31	18D
0005434344047	29787	32	19A
0005434343842	29787	33	19B
0005434343994	29787	34	19C
0005434344121	29787	35	19D
0005435305025	29787	36	20A
0005434343918	29787	37	20B
0005435304185	29787	38	20C
0005434343919	29787	39	20D
0005434344123	29787	40	21A
0005434344252	29787	41	21B
0005434344053	29787	42	21C
0005435305024	29787	43	21D
0005434344122	29787	44	22A
0005434344068	29787	45	22B
0005434343988	29787	46	22C
0005435304186	29787	47	22D
0005434344103	29787	48	23A
0005434343934	29787	49	23B
0005435824758	1303	1	1F
0005435824769	1303	2	2F
0005435824762	1303	3	2C
0005435824760	1303	4	3A
0005433415650	1303	5	3C
0005433415555	1303	6	4A
0005435824779	1303	7	3F
0005433415571	1303	8	4D
0005433415641	1303	9	5C
0005433415672	1303	10	5A
0005433415640	1303	11	6B
0005435824759	1303	12	6E
0005433415617	1303	13	7A
0005433415659	1303	14	6F
0005435824768	1303	15	7B
0005435824761	1303	16	8A
0005435824782	1303	17	8F
0005435824781	1303	18	9C
0005435824757	1303	19	10B
0005435824773	1303	20	10C
0005433415671	1303	21	11A
0005432284574	1303	22	11F
0005433415696	1303	23	11E
0005435824774	1303	24	12E
0005435824777	1303	25	13A
0005433415658	1303	26	13B
0005435824767	1303	27	13F
0005432284573	1303	28	14C
0005433415590	1303	29	14F
0005433415656	1303	30	14E
0005433415697	1303	31	15B
0005435824772	1303	32	15A
0005432284575	1303	33	15C
0005435824778	1303	34	15F
0005435824780	1303	35	16C
0005433415695	1303	36	16D
0005435824763	1303	37	16F
0005435824764	1303	38	17B
0005435824765	1303	39	17D
0005435824775	1303	40	18B
0005433415690	1303	41	18E
0005433415589	1303	42	18F
0005433415657	1303	43	19C
0005435824770	1303	44	19E
0005435824771	1303	45	20A
0005435824755	1303	46	20D
0005433415647	1303	47	20C
0005433415651	1303	48	20F
0005435824766	1303	49	21A
0005435824756	1303	50	21C
0005433415649	1303	51	21E
0005435824776	1303	52	21D
0005433415742	18011	1	1A
0005435824538	18011	2	3A
0005435824502	18011	3	3D
0005435824658	18011	4	4A
0005435824486	18011	5	4F
0005435824680	18011	6	5C
0005433415749	18011	7	6B
0005433415752	18011	8	7D
0005433415745	18011	9	8A
0005435824621	18011	10	7F
0005435824639	18011	11	8B
0005433415746	18011	12	8E
0005435824496	18011	13	9A
0005435824487	18011	14	10A
0005435824519	18011	15	10C
0005435824513	18011	16	10D
0005435824497	18011	17	10F
0005435824640	18011	18	11C
0005435824463	18011	19	11F
0005435824550	18011	20	11E
0005433415738	18011	21	12C
0005433415747	18011	22	14A
0005433415741	18011	23	14B
0005435824531	18011	24	14C
0005435824501	18011	25	14E
0005433415751	18011	26	15A
0005433415739	18011	27	15C
0005433415750	18011	28	15E
0005433415744	18011	29	16C
0005435824464	18011	30	16F
0005435824571	18011	31	16E
0005435824615	18011	32	17F
0005435824588	18011	33	17E
0005433415748	18011	34	18A
0005435824384	18011	35	18E
0005435824490	18011	36	18F
0005435824582	18011	37	19D
0005435824593	18011	38	19E
0005435824393	18011	39	20C
0005433415743	18011	40	20E
0005435824539	18011	41	21A
0005435824522	18011	42	20F
0005435824551	18011	43	21E
0005433415740	18011	44	21F
0005434461654	12576	1	1B
0005434460510	12576	2	4C
0005434460513	12576	3	4D
0005434461656	12576	4	5C
0005434460509	12576	5	5D
0005434461652	12576	6	6D
0005434461651	12576	7	7C
0005434460512	12576	8	7D
0005434460515	12576	9	18C
0005434461655	12576	10	19B
0005434460511	12576	11	20C
0005434460516	12576	12	20D
0005434461653	12576	13	21B
0005434460514	12576	14	23A
0005432784050	5642	1	1A
0005432784065	5642	2	1C
0005432784077	5642	3	1D
0005432784061	5642	4	1F
0005435242710	5642	5	2A
0005432784074	5642	6	2C
0005435242804	5642	7	2D
0005432784071	5642	8	2F
0005432784072	5642	9	3A
0005432784070	5642	10	3C
0005432784105	5642	11	3D
0005432784096	5642	12	3F
0005435242590	5642	13	4A
0005432784078	5642	14	4C
0005432784055	5642	15	4D
0005432784079	5642	16	4E
0005432784066	5642	17	4F
0005435476718	5642	18	5A
0005432784082	5642	19	5C
0005432784094	5642	20	5D
0005435242734	5642	21	5E
0005432784062	5642	22	5F
0005432784091	5642	23	6A
0005432784098	5642	24	6C
0005432784058	5642	25	6D
0005432784067	5642	26	7A
0005432784095	5642	27	6F
0005435242818	5642	28	7C
0005432784085	5642	29	7D
0005432784080	5642	30	7E
0005432784057	5642	31	7F
0005435242807	5642	32	8A
0005435242739	5642	33	8C
0005432784100	5642	34	8D
0005435242703	5642	35	8E
0005435242704	5642	36	9A
0005435242700	5642	37	9C
0005432784052	5642	38	9D
0005435242736	5642	39	9E
0005432144003	5642	40	9F
0005432784083	5642	41	10A
0005435242767	5642	42	10C
0005432784086	5642	43	10D
0005435242799	5642	44	10E
0005432784092	5642	45	10F
0005432784068	5642	46	11A
0005432784075	5642	47	11C
0005432144005	5642	48	11D
0005435242840	5642	49	11E
0005432784102	5642	50	11F
0005435242740	5642	51	12A
0005432784104	5642	52	12C
0005432784081	5642	53	12D
0005432784053	5642	54	12E
0005432784087	5642	55	12F
0005432784088	5642	56	13C
0005435242805	5642	57	13D
0005432784084	5642	58	13E
0005432784059	5642	59	13F
0005435242832	5642	60	14A
0005432144004	5642	61	14C
0005435242755	5642	62	14D
0005432784097	5642	63	14E
0005435242757	5642	64	14F
0005432144006	5642	65	15A
0005432784093	5642	66	15C
0005435242735	5642	67	15D
0005432784056	5642	68	15E
0005435242758	5642	69	15F
0005435476719	5642	70	16A
0005435242819	5642	71	16C
0005435242702	5642	72	16D
0005432784089	5642	73	16E
0005432784063	5642	74	16F
0005435242744	5642	75	17A
0005435476761	5642	76	17C
0005432784103	5642	77	17E
0005432784054	5642	78	17F
0005432784101	5642	79	18A
0005435476727	5642	80	18C
0005432784090	5642	81	18D
0005432784051	5642	82	18E
0005432784073	5642	83	18F
0005435242831	5642	84	19A
0005432784064	5642	85	19C
0005432784060	5642	86	19D
0005432784076	5642	87	19E
0005435242699	5642	88	19F
0005432784099	5642	89	20A
0005435242701	5642	90	20C
0005432784069	5642	91	20D
0005432144007	5642	92	20F
0005432783727	15348	1	1A
0005432783608	15348	2	1C
0005432783794	15348	3	1D
0005435242987	15348	4	1F
0005435242977	15348	5	2A
0005432783404	15348	6	2C
0005432783638	15348	7	2D
0005432783454	15348	8	2F
0005432783419	15348	9	3A
0005432783521	15348	10	3C
0005435242966	15348	11	3D
0005435242986	15348	12	3F
0005432783652	15348	13	4A
0005435476789	15348	14	4C
0005432783726	15348	15	4D
0005432783829	15348	16	4E
0005435242964	15348	17	4F
0005435242973	15348	18	5A
0005432783243	15348	19	5C
0005432783487	15348	20	5D
0005432783675	15348	21	5E
0005432783516	15348	22	5F
0005432783375	15348	23	6A
0005435476790	15348	24	6C
0005435242988	15348	25	6D
0005432783445	15348	26	6E
0005432783508	15348	27	6F
0005435242969	15348	28	7A
0005432783676	15348	29	7C
0005435476791	15348	30	7D
0005432783728	15348	31	7E
0005432783444	15348	32	8A
0005435242984	15348	33	7F
0005432783686	15348	34	8C
0005432783450	15348	35	8D
0005435242980	15348	36	8E
0005435242979	15348	37	8F
0005435242965	15348	38	9A
0005435242971	15348	39	9C
0005432783639	15348	40	9D
0005432783513	15348	41	9E
0005432783531	15348	42	9F
0005432783716	15348	43	10A
0005432783612	15348	44	10C
0005435242972	15348	45	10D
0005432783512	15348	46	10E
0005435242976	15348	47	10F
0005435242978	15348	48	11A
0005435242968	15348	49	11C
0005432783242	15348	50	11D
0005435242970	15348	51	11E
0005435242981	15348	52	11F
0005432783488	15348	53	12A
0005432783589	15348	54	12C
0005435242975	15348	55	12D
0005435242983	15348	56	12E
0005432783435	15348	57	12F
0005432783627	15348	58	13A
0005435242990	15348	59	13C
0005432783683	15348	60	13E
0005435242989	15348	61	13F
0005432783772	15348	62	14A
0005435242985	15348	63	14C
0005432783416	15348	64	14D
0005432783719	15348	65	14E
0005432783458	15348	66	14F
0005432783570	15348	67	15A
0005432783715	15348	68	15C
0005432783483	15348	69	15D
0005432783718	15348	70	15E
0005432783679	15348	71	15F
0005432783622	15348	72	16A
0005432783533	15348	73	16C
0005435476788	15348	74	16D
0005435242982	15348	75	16E
0005432783559	15348	76	16F
0005432783422	15348	77	17A
0005435242967	15348	78	17C
0005432783569	15348	79	17D
0005432783517	15348	80	17E
0005435242963	15348	81	17F
0005432783436	15348	82	18A
0005432783613	15348	83	18C
0005432783509	15348	84	18D
0005432783363	15348	85	18E
0005432783685	15348	86	18F
0005432783828	15348	87	19A
0005432783789	15348	88	19C
0005432783701	15348	89	19D
0005432783626	15348	90	19E
0005435242974	15348	91	19F
0005432783560	15348	92	20A
0005432783607	15348	93	20C
0005432783337	15348	94	20D
0005432783628	15348	95	20E
0005435850870	4380	1	1A
0005432848386	4380	2	2B
0005432848385	4380	3	2C
0005434463941	4380	4	2D
0005432848388	4380	5	3C
0005435850895	4380	6	3D
0005435850858	4380	7	4B
0005435850896	4380	8	4D
0005435850887	4380	9	5D
0005435850871	4380	10	7A
0005432848391	4380	11	7C
0005432848393	4380	12	7D
0005434463940	4380	13	18A
0005432848394	4380	14	18B
0005432848387	4380	15	18C
0005432848384	4380	16	18D
0005432848396	4380	17	19A
0005435850892	4380	18	19C
0005435850911	4380	19	19D
0005432848395	4380	20	20A
0005432848390	4380	21	20B
0005432848392	4380	22	20D
0005435850891	4380	23	21A
0005435850859	4380	24	21C
0005432848383	4380	25	21D
0005434462802	4380	26	22C
0005432848389	4380	27	22D
0005434462803	4380	28	23B
0005435850962	28866	1	1A
0005435850958	28866	2	1C
0005435850954	28866	3	1D
0005432848253	28866	4	2A
0005435850963	28866	5	2C
0005432848311	28866	6	3A
0005435850957	28866	7	3D
0005435850961	28866	8	4D
0005435850956	28866	9	5C
0005432848224	28866	10	5B
0005432848301	28866	11	5D
0005432848205	28866	12	6B
0005432848288	28866	13	6C
0005435850960	28866	14	6D
0005435850955	28866	15	7A
0005434461634	28866	16	7C
0005434463914	28866	17	7D
0005432848204	28866	18	18A
0005435850959	28866	19	18B
0005432848298	28866	20	18C
0005432848232	28866	21	18D
0005432848287	28866	22	19C
0005432848241	28866	23	19D
0005432848305	28866	24	20A
0005432848210	28866	25	20B
0005434461640	28866	26	20C
0005434461641	28866	27	21C
0005432848291	28866	28	22C
0005432848225	28866	29	22D
0005432848271	28866	30	23A
0005434443804	6306	1	1A
0005434925969	6306	2	2A
0005432075250	6306	3	2C
0005434925967	6306	4	2D
0005433497143	6306	5	2F
0005433497123	6306	6	3A
0005434925975	6306	7	3C
0005433497137	6306	8	3D
0005434925983	6306	9	3F
0005434925963	6306	10	4A
0005434925977	6306	11	4C
0005433497150	6306	12	4D
0005433497135	6306	13	4E
0005433497152	6306	14	4F
0005433497144	6306	15	5A
0005433497153	6306	16	5C
0005433497145	6306	17	5D
0005434443802	6306	18	5E
0005434925965	6306	19	6A
0005432075248	6306	20	6C
0005433497147	6306	21	6E
0005434925973	6306	22	6F
0005433497146	6306	23	7A
0005433497141	6306	24	7C
0005434925976	6306	25	7D
0005434443794	6306	26	7E
0005434443788	6306	27	7F
0005434925984	6306	28	8C
0005433497129	6306	29	8F
0005434925982	6306	30	9A
0005434925964	6306	31	9C
0005433497133	6306	32	9D
0005434925987	6306	33	9E
0005433497148	6306	34	9F
0005432075249	6306	35	10A
0005433497138	6306	36	10C
0005433497140	6306	37	10D
0005434925971	6306	38	10F
0005433497136	6306	39	11C
0005434925980	6306	40	11D
0005433497132	6306	41	11E
0005434443795	6306	42	11F
0005434443801	6306	43	12A
0005433497139	6306	44	12C
0005433497131	6306	45	12D
0005432075251	6306	46	12E
0005434925968	6306	47	12F
0005434443791	6306	48	13A
0005434443796	6306	49	13C
0005432075247	6306	50	13D
0005433497127	6306	51	13E
0005434443798	6306	52	13F
0005433497126	6306	53	14A
0005434925978	6306	54	14C
0005434443789	6306	55	14D
0005433497134	6306	56	14F
0005433497122	6306	57	15A
0005434925986	6306	58	15C
0005434443803	6306	59	15D
0005434925988	6306	60	15E
0005434443799	6306	61	15F
0005433497124	6306	62	16A
0005434443793	6306	63	16C
0005433497149	6306	64	16D
0005434443790	6306	65	16E
0005434443797	6306	66	16F
0005433497130	6306	67	17A
0005434925985	6306	68	17C
0005434925972	6306	69	17D
0005434443787	6306	70	17E
0005434925970	6306	71	18C
0005434443792	6306	72	18D
0005433497128	6306	73	18E
0005433497125	6306	74	18F
0005433497142	6306	75	19C
0005434925981	6306	76	19D
0005434925966	6306	77	19F
0005434925974	6306	78	20C
0005433497151	6306	79	20D
0005434925979	6306	80	20E
0005434443800	6306	81	20F
0005433496928	20310	1	1A
0005434443632	20310	2	1C
0005434443668	20310	3	1F
0005433496925	20310	4	2A
0005434925617	20310	5	2C
0005434443660	20310	6	2D
0005434443700	20310	7	2F
0005434443580	20310	8	3A
0005434925616	20310	9	3C
0005433496854	20310	10	3D
0005433496775	20310	11	4A
0005434925615	20310	12	4C
0005434925630	20310	13	4D
0005434443581	20310	14	4F
0005434443606	20310	15	5C
0005434925614	20310	16	5D
0005433497020	20310	17	5E
0005433496822	20310	18	5F
0005434443647	20310	19	6E
0005433496752	20310	20	6F
0005434925653	20310	21	7A
0005434443641	20310	22	7D
0005434925634	20310	23	7E
0005434925700	20310	24	7F
0005434443569	20310	25	8A
0005434443644	20310	26	8D
0005434443708	20310	27	8E
0005434925682	20310	28	9A
0005434443633	20310	29	9C
0005434443605	20310	30	9F
0005433496737	20310	31	10A
0005434925477	20310	32	10C
0005433496872	20310	33	10D
0005434925706	20310	34	10E
0005434925637	20310	35	10F
0005433496969	20310	36	11C
0005433496947	20310	37	11D
0005434925528	20310	38	11E
0005434443667	20310	39	11F
0005434925550	20310	40	12A
0005434925519	20310	41	12C
0005433496999	20310	42	12D
0005433496750	20310	43	12E
0005434925496	20310	44	12F
0005434925670	20310	45	13A
0005433496965	20310	46	13C
0005434443552	20310	47	13D
0005434925701	20310	48	13E
0005433496849	20310	49	13F
0005434925628	20310	50	14C
0005433496873	20310	51	14D
0005434925705	20310	52	14E
0005434925629	20310	53	14F
0005433496818	20310	54	15A
0005434925549	20310	55	15C
0005434925478	20310	56	15D
0005433496823	20310	57	15E
0005434925535	20310	58	15F
0005434443584	20310	59	16C
0005433496751	20310	60	16F
0005434925526	20310	61	17A
0005433496753	20310	62	17C
0005434925672	20310	63	17D
0005434925631	20310	64	17E
0005433496913	20310	65	18C
0005433496736	20310	66	18D
0005433496835	20310	67	18E
0005434925633	20310	68	18F
0005434443583	20310	69	19A
0005434925581	20310	70	19C
0005434925702	20310	71	19D
0005433497021	20310	72	19E
0005434925579	20310	73	19F
0005434925551	20310	74	20A
0005434925671	20310	75	20C
0005434443722	20310	76	20D
0005434925632	20310	77	20E
0005435242997	12171	1	1A
0005432783366	12171	2	1C
0005435243002	12171	3	1D
0005432783502	12171	4	2A
0005432783922	12171	5	2D
0005435243009	12171	6	2F
0005432783773	12171	7	3A
0005432783854	12171	8	3C
0005432783551	12171	9	3D
0005435243017	12171	10	3F
0005432783548	12171	11	4A
0005435242993	12171	12	4C
0005435242994	12171	13	4D
0005432783672	12171	14	4E
0005435243018	12171	15	4F
0005432783692	12171	16	5A
0005432783414	12171	17	5E
0005432783557	12171	18	5F
0005432783490	12171	19	6A
0005435243011	12171	20	6C
0005432783577	12171	21	6F
0005435243006	12171	22	7C
0005432783556	12171	23	7D
0005435243005	12171	24	8A
0005435242996	12171	25	8C
0005435243010	12171	26	8E
0005435243000	12171	27	8F
0005432783671	12171	28	9C
0005432783475	12171	29	9D
0005432783673	12171	30	9E
0005432783725	12171	31	10A
0005432783696	12171	32	10C
0005435243015	12171	33	10D
0005432783578	12171	34	10E
0005432783752	12171	35	11A
0005432783813	12171	36	11C
0005432783233	12171	37	11D
0005435242992	12171	38	11E
0005432783656	12171	39	12A
0005432783798	12171	40	12C
0005432783505	12171	41	12D
0005435242991	12171	42	12E
0005435243003	12171	43	12F
0005432783693	12171	44	13A
0005432783552	12171	45	13C
0005432783634	12171	46	13D
0005432783324	12171	47	13F
0005435242998	12171	48	14A
0005435243004	12171	49	14C
0005432783625	12171	50	14D
0005432783694	12171	51	14E
0005432783322	12171	52	15A
0005435243001	12171	53	15C
0005432783503	12171	54	15D
0005432783651	12171	55	15E
0005435242995	12171	56	15F
0005435243008	12171	57	16C
0005432783497	12171	58	16D
0005432783763	12171	59	16E
0005432783496	12171	60	16F
0005435242999	12171	61	17A
0005432783739	12171	62	17D
0005432783379	12171	63	17F
0005432783762	12171	64	18A
0005435243013	12171	65	18D
0005432783530	12171	66	18E
0005435243016	12171	67	18F
0005435243012	12171	68	19A
0005435243007	12171	69	19D
0005432783323	12171	70	19F
0005432783700	12171	71	20A
0005432783504	12171	72	20C
0005435243014	12171	73	20D
0005432783695	12171	74	20F
0005432784040	15430	1	1A
0005435242713	15430	2	1C
0005435242753	15430	3	1D
0005432784038	15430	4	1F
0005435242798	15430	5	2A
0005432784018	15430	6	2C
0005435242751	15430	7	2D
0005435242681	15430	8	2F
0005432784019	15430	9	3A
0005435242793	15430	10	3C
0005432784042	15430	11	3F
0005435242582	15430	12	4A
0005435242737	15430	13	4C
0005432783998	15430	14	4D
0005432784034	15430	15	4E
0005432784014	15430	16	4F
0005432784023	15430	17	5A
0005432784049	15430	18	5C
0005435242667	15430	19	5D
0005432784046	15430	20	5E
0005435242738	15430	21	5F
0005432784000	15430	22	6A
0005432784009	15430	23	6C
0005435242764	15430	24	6D
0005435242583	15430	25	6E
0005432784003	15430	26	6F
0005432784036	15430	27	7C
0005432783996	15430	28	7D
0005435242716	15430	29	8A
0005432784043	15430	30	8C
0005432784010	15430	31	8E
0005435242714	15430	32	8F
0005432783999	15430	33	9A
0005432784008	15430	34	9C
0005432784001	15430	35	9E
0005432784024	15430	36	9F
0005435242746	15430	37	10C
0005432784039	15430	38	10D
0005435242797	15430	39	11C
0005432784029	15430	40	11D
0005432784005	15430	41	11E
0005432784017	15430	42	11F
0005432784026	15430	43	12A
0005432784045	15430	44	12C
0005432784016	15430	45	12D
0005432784032	15430	46	12E
0005435242754	15430	47	12F
0005435242639	15430	48	13A
0005435242640	15430	49	13C
0005435242718	15430	50	13D
0005432784007	15430	51	13E
0005432784012	15430	52	13F
0005432784041	15430	53	14A
0005435242656	15430	54	14C
0005432784020	15430	55	14D
0005432784028	15430	56	14E
0005432783997	15430	57	14F
0005435242745	15430	58	15A
0005432784004	15430	59	15C
0005432784044	15430	60	15D
0005435242794	15430	61	15E
0005435242803	15430	62	15F
0005432784025	15430	63	16A
0005435242816	15430	64	16C
0005432784030	15430	65	16D
0005432784047	15430	66	16E
0005432784027	15430	67	16F
0005432784015	15430	68	17A
0005432784037	15430	69	17C
0005432784011	15430	70	17D
0005432784031	15430	71	17E
0005432784035	15430	72	17F
0005435242742	15430	73	18A
0005435242743	15430	74	18C
0005435242712	15430	75	18D
0005432784033	15430	76	18E
0005435242668	15430	77	18F
0005432784048	15430	78	19A
0005432784002	15430	79	19C
0005432784006	15430	80	19D
0005432784021	15430	81	20A
0005432784013	15430	82	19F
0005432784022	15430	83	20C
0005435242806	15430	84	20E
0005435242788	15430	85	20F
0005434878096	10103	1	1C
0005434877882	10103	2	1A
0005434877821	10103	3	1D
0005434878173	10103	4	2A
0005434878018	10103	5	1F
0005434878056	10103	6	2F
0005434878024	10103	7	2C
0005434877720	10103	8	3C
0005434758887	10103	9	3A
0005434878332	10103	10	3D
0005434877822	10103	11	4A
0005434910127	10103	12	3F
0005434910128	10103	13	4C
0005434878026	10103	14	4D
0005434878333	10103	15	5C
0005434877945	10103	16	5A
0005434877697	10103	17	5F
0005434877910	10103	18	6A
0005434877443	10103	19	6D
0005434877947	10103	20	6C
0005434877761	10103	21	6F
0005434878001	10103	22	6E
0005434878003	10103	23	7A
0005434878167	10103	24	7C
0005434877695	10103	25	7B
0005434877933	10103	26	7E
0005434877909	10103	27	7D
0005434878170	10103	28	7F
0005434877458	10103	29	8B
0005434878027	10103	30	8C
0005434877704	10103	31	8F
0005434878250	10103	32	8E
0005434877354	10103	33	9A
0005434878087	10103	34	9D
0005434877164	10103	35	9C
0005434877966	10103	36	9B
0005434878174	10103	37	9E
0005434878433	10103	38	10A
0005434878199	10103	39	9F
0005435913947	10103	40	10B
0005434877747	10103	41	10E
0005435913953	10103	42	10F
0005434877626	10103	43	11B
0005434877698	10103	44	11A
0005434877785	10103	45	11D
0005434877944	10103	46	11C
0005434877536	10103	47	11F
0005434878295	10103	48	12B
0005435913950	10103	49	12D
0005434877703	10103	50	12C
0005434877661	10103	51	12F
0005434878354	10103	52	12E
0005435913952	10103	53	13A
0005434877751	10103	54	13C
0005435913951	10103	55	13B
0005434878132	10103	56	13D
0005434877353	10103	57	14A
0005434878432	10103	58	13F
0005434877923	10103	59	14D
0005434877696	10103	60	14F
0005434878075	10103	61	14E
0005434877956	10103	62	15B
0005434877705	10103	63	15A
0005434878055	10103	64	15C
0005434878175	10103	65	15E
0005434878198	10103	66	15D
0005434877719	10103	67	16A
0005434878086	10103	68	15F
0005434910124	10103	69	16C
0005434758882	10103	70	16B
0005434758881	10103	71	16E
0005434910126	10103	72	17A
0005435913948	10103	73	16F
0005434877750	10103	74	17B
0005434878081	10103	75	17D
0005434877780	10103	76	17C
0005434877686	10103	77	17E
0005434878009	10103	78	18B
0005435913949	10103	79	18A
0005434877948	10103	80	17F
0005435913954	10103	81	18C
0005434877788	10103	82	18F
0005434878002	10103	83	18E
0005434910125	10103	84	18D
0005434878251	10103	85	19B
0005434878249	10103	86	19D
0005434878202	10103	87	20A
0005434878023	10103	88	19F
0005434877907	10103	89	19E
0005434878220	10103	90	20B
0005434877848	10103	91	20D
0005434878117	10103	92	20C
0005434877881	10103	93	20F
0005434877537	10103	94	20E
0005434877837	10103	95	21C
0005434878085	10103	96	21B
0005434877784	10103	97	21E
0005434878221	10103	98	21D
0005434877899	10103	99	21F
0005434878681	14614	1	1C
0005434878690	14614	2	1D
0005434878731	14614	3	2C
0005434878703	14614	4	2A
0005434878702	14614	5	1F
0005434878697	14614	6	2D
0005434878684	14614	7	3A
0005434878700	14614	8	2F
0005434878740	14614	9	4A
0005434878709	14614	10	3F
0005434878765	14614	11	3D
0005434878723	14614	12	4D
0005434878678	14614	13	4C
0005434878705	14614	14	4F
0005434878729	14614	15	5A
0005434878757	14614	16	5F
0005434878682	14614	17	5D
0005434878683	14614	18	6B
0005434878716	14614	19	6A
0005434878730	14614	20	6C
0005434878706	14614	21	6E
0005435913919	14614	22	7A
0005434878743	14614	23	6F
0005434878724	14614	24	7C
0005434878744	14614	25	7B
0005434878714	14614	26	7E
0005434878733	14614	27	7D
0005434878677	14614	28	8A
0005434878722	14614	29	7F
0005434878752	14614	30	8B
0005434878674	14614	31	8D
0005434878701	14614	32	8F
0005434878761	14614	33	8E
0005434878747	14614	34	9A
0005434878735	14614	35	9D
0005434878680	14614	36	9C
0005434878712	14614	37	9B
0005434878675	14614	38	9F
0005434878688	14614	39	9E
0005434878726	14614	40	10A
0005434878766	14614	41	10C
0005434878763	14614	42	10E
0005434878755	14614	43	10D
0005434878762	14614	44	11A
0005434910103	14614	45	10F
0005434878695	14614	46	11D
0005434878698	14614	47	11C
0005434758906	14614	48	11F
0005434878707	14614	49	11E
0005434878710	14614	50	12B
0005434878751	14614	51	12A
0005434878692	14614	52	12C
0005434878689	14614	53	12F
0005434878750	14614	54	12D
0005434878685	14614	55	13B
0005434878691	14614	56	13A
0005434878679	14614	57	13D
0005435913896	14614	58	13F
0005434878718	14614	59	13E
0005434878727	14614	60	14C
0005434878720	14614	61	14B
0005434878704	14614	62	14E
0005434878715	14614	63	14F
0005434878699	14614	64	15B
0005434878732	14614	65	15A
0005434878728	14614	66	15D
0005434878742	14614	67	15C
0005434878676	14614	68	15E
0005434878721	14614	69	16B
0005434878764	14614	70	16A
0005434878759	14614	71	15F
0005434878717	14614	72	16E
0005434878738	14614	73	16D
0005434878739	14614	74	16C
0005434878749	14614	75	16F
0005434878737	14614	76	17B
0005434878708	14614	77	17A
0005434758905	14614	78	17D
0005434878686	14614	79	17C
0005434878673	14614	80	17E
0005434878713	14614	81	18B
0005434878696	14614	82	18A
0005434878687	14614	83	18C
0005434878734	14614	84	18E
0005434878753	14614	85	18D
0005434878756	14614	86	19A
0005434878711	14614	87	18F
0005434878754	14614	88	19B
0005434878745	14614	89	19D
0005434878760	14614	90	19F
0005434878725	14614	91	19E
0005434878741	14614	92	20B
0005434878758	14614	93	20A
0005434878719	14614	94	20D
0005434878672	14614	95	20C
0005434878694	14614	96	20E
0005434878746	14614	97	21A
0005434878748	14614	98	21D
0005434878736	14614	99	21C
0005434878693	14614	100	21F
0005434910104	14614	101	21E
0005434251946	9215	1	1A
0005435660196	9215	2	2B
0005435660191	9215	3	2C
0005435660201	9215	4	3D
0005434251988	9215	5	4A
0005434251978	9215	6	5D
0005435660193	9215	7	6A
0005435660200	9215	8	6C
0005435660192	9215	9	18A
0005435660198	9215	10	18B
0005435660194	9215	11	18D
0005434251961	9215	12	20A
0005435660199	9215	13	20B
0005435660197	9215	14	21C
0005435660190	9215	15	22A
0005435660195	9215	16	22C
0005434251979	9215	17	23B
0005434252010	24658	1	1C
0005435660105	24658	2	1D
0005435660042	24658	3	2A
0005435660063	24658	4	2C
0005434252016	24658	5	3B
0005434252018	24658	6	3D
0005434252011	24658	7	4B
0005435660102	24658	8	5A
0005435660103	24658	9	5C
0005434252017	24658	10	6D
0005435660137	24658	11	7C
0005435660085	24658	12	18B
0005434252012	24658	13	18D
0005434252015	24658	14	19B
0005434252013	24658	15	20A
0005434252009	24658	16	20C
0005435660041	24658	17	21D
0005434252014	24658	18	22B
0005432966916	2801	1	1A
0005432966818	2801	2	1C
0005433680788	2801	3	1D
0005433680812	2801	4	1F
0005433680831	2801	5	2A
0005433680784	2801	6	2C
0005433680802	2801	7	2D
0005433680819	2801	8	2F
0005432966761	2801	9	3A
0005432966863	2801	10	3C
0005432966853	2801	11	3D
0005433680805	2801	12	3F
0005432966847	2801	13	4A
0005433680813	2801	14	4D
0005433680820	2801	15	4E
0005432966915	2801	16	4F
0005433680806	2801	17	5A
0005433680800	2801	18	5C
0005433680796	2801	19	5D
0005433680827	2801	20	5E
0005432222811	2801	21	5F
0005433680823	2801	22	6A
0005432966747	2801	23	6C
0005433680833	2801	24	6D
0005432222809	2801	25	6E
0005433680786	2801	26	6F
0005432966845	2801	27	7A
0005433680790	2801	28	7C
0005433680791	2801	29	7D
0005433680792	2801	30	7E
0005433680799	2801	31	7F
0005433680816	2801	32	8C
0005433680824	2801	33	8D
0005433680795	2801	34	8E
0005432966882	2801	35	8F
0005433680808	2801	36	9A
0005432966821	2801	37	9C
0005432966917	2801	38	9E
0005432966857	2801	39	9F
0005433680821	2801	40	10A
0005433680815	2801	41	10C
0005432966913	2801	42	10D
0005432966912	2801	43	10E
0005433680825	2801	44	10F
0005432966838	2801	45	11A
0005433680810	2801	46	11C
0005432966763	2801	47	11D
0005433680826	2801	48	11E
0005433680797	2801	49	11F
0005432966874	2801	50	12A
0005432222808	2801	51	12C
0005432966883	2801	52	12D
0005433680794	2801	53	12E
0005433680829	2801	54	12F
0005433680789	2801	55	13A
0005432222810	2801	56	13C
0005432966846	2801	57	13D
0005432966794	2801	58	13F
0005433680811	2801	59	14A
0005432966746	2801	60	14C
0005432966762	2801	61	14D
0005433680817	2801	62	14E
0005432966932	2801	63	14F
0005433680793	2801	64	15A
0005432966884	2801	65	15C
0005432222807	2801	66	15F
0005433684429	2801	67	16A
0005433680801	2801	68	16C
0005432966795	2801	69	16E
0005433680822	2801	70	16F
0005433680818	2801	71	17A
0005433680798	2801	72	17C
0005432966856	2801	73	17D
0005433684430	2801	74	17E
0005432966832	2801	75	18A
0005432966748	2801	76	18C
0005433680785	2801	77	18E
0005433680807	2801	78	18F
0005432966691	2801	79	19A
0005433680803	2801	80	19C
0005433680832	2801	81	19D
0005433680809	2801	82	19E
0005433680830	2801	83	19F
0005433680814	2801	84	20A
0005433680787	2801	85	20C
0005432966774	2801	86	20D
0005433680828	2801	87	20E
0005433680804	2801	88	20F
0005433680464	29146	1	1A
0005433680447	29146	2	1D
0005433680674	29146	3	2A
0005433680501	29146	4	2D
0005432967059	29146	5	2F
0005433680460	29146	6	3A
0005433680532	29146	7	3C
0005433680346	29146	8	3D
0005432967056	29146	9	3F
0005432967067	29146	10	4A
0005433680414	29146	11	4C
0005433680381	29146	12	4D
0005432967058	29146	13	4E
0005432967079	29146	14	4F
0005433680417	29146	15	5A
0005432967062	29146	16	5D
0005432967054	29146	17	5E
0005433680463	29146	18	6A
0005433680451	29146	19	6C
0005432967075	29146	20	6D
0005432967069	29146	21	6F
0005432967071	29146	22	7A
0005433680522	29146	23	7C
0005433680496	29146	24	7D
0005432967061	29146	25	7E
0005433680446	29146	26	7F
0005432967066	29146	27	8A
0005433680459	29146	28	8C
0005433680160	29146	29	8D
0005432967076	29146	30	8F
0005433680117	29146	31	8E
0005433680268	29146	32	9C
0005433680461	29146	33	9A
0005433680306	29146	34	9D
0005432005229	29146	35	9E
0005433680478	29146	36	9F
0005432967072	29146	37	10A
0005433680524	29146	38	10C
0005433680413	29146	39	10D
0005433680528	29146	40	10E
0005432967073	29146	41	11A
0005433680318	29146	42	11C
0005433680449	29146	43	11F
0005433680273	29146	44	12C
0005432967065	29146	45	12E
0005433684418	29146	46	13A
0005433680148	29146	47	13C
0005432967060	29146	48	13D
0005433680450	29146	49	13F
0005433680348	29146	50	14C
0005433680439	29146	51	14E
0005433680311	29146	52	14F
0005432005228	29146	53	15A
0005433680448	29146	54	15C
0005432967070	29146	55	15D
0005432967057	29146	56	15E
0005433680445	29146	57	16A
0005432967078	29146	58	16C
0005433680581	29146	59	16D
0005433680394	29146	60	16E
0005433680444	29146	61	16F
0005433680276	29146	62	17A
0005432967077	29146	63	17C
0005433684417	29146	64	17D
0005432967074	29146	65	17E
0005432967063	29146	66	17F
0005432967068	29146	67	18A
0005432967055	29146	68	18C
0005433680393	29146	69	18D
0005433680156	29146	70	18E
0005432005227	29146	71	18F
0005433680580	29146	72	19A
0005433680349	29146	73	19C
0005433680455	29146	74	19D
0005433680458	29146	75	19E
0005433680523	29146	76	20C
0005432967064	29146	77	20D
0005433680506	29146	78	20E
0005433633962	9325	1	1A
0005432755091	9325	2	1C
0005433615020	9325	3	1F
0005433615016	9325	4	1D
0005433633976	9325	5	2A
0005433615027	9325	6	2D
0005433614975	9325	7	2C
0005433615007	9325	8	2F
0005433615006	9325	9	3C
0005433614963	9325	10	3D
0005433614972	9325	11	4A
0005434163570	9325	12	3F
0005433633974	9325	13	4C
0005434163579	9325	14	4F
0005434163591	9325	15	4D
0005433615010	9325	16	6A
0005433614995	9325	17	5F
0005433614993	9325	18	6C
0005433615012	9325	19	6F
0005433615024	9325	20	7A
0005433615021	9325	21	7C
0005432756864	9325	22	7F
0005433615015	9325	23	7D
0005433633958	9325	24	8A
0005433577874	9325	25	8B
0005433614990	9325	26	8D
0005433633948	9325	27	8C
0005433614967	9325	28	8F
0005433614997	9325	29	8E
0005433633963	9325	30	9A
0005433615032	9325	31	9C
0005433614959	9325	32	9F
0005433633947	9325	33	9E
0005432145120	9325	34	10A
0005433577877	9325	35	10C
0005433633981	9325	36	10E
0005433577876	9325	37	10D
0005433633973	9325	38	10F
0005433633971	9325	39	11A
0005433615033	9325	40	11C
0005433615011	9325	41	11B
0005433614970	9325	42	11E
0005433633979	9325	43	11D
0005434163561	9325	44	11F
0005433615031	9325	45	12A
0005434163578	9325	46	12D
0005433615003	9325	47	13A
0005433615018	9325	48	12F
0005433577870	9325	49	12E
0005433614985	9325	50	13B
0005432755092	9325	51	13D
0005433614996	9325	52	13E
0005433633954	9325	53	14A
0005432755090	9325	54	13F
0005433614986	9325	55	14B
0005433633956	9325	56	14C
0005433633952	9325	57	14E
0005433577881	9325	58	14F
0005433614988	9325	59	15B
0005433615005	9325	60	15A
0005434163569	9325	61	15C
0005433633970	9325	62	15E
0005433633975	9325	63	15D
0005433615004	9325	64	15F
0005433614980	9325	65	16A
0005433577868	9325	66	16C
0005433633969	9325	67	16B
0005433615013	9325	68	16D
0005433615028	9325	69	16E
0005433614971	9325	70	17A
0005433615030	9325	71	17C
0005433615017	9325	72	17B
0005433614989	9325	73	17D
0005434163590	9325	74	17F
0005433633950	9325	75	17E
0005433615001	9325	76	18A
0005433614976	9325	77	18B
0005433614984	9325	78	18C
0005433614983	9325	79	18E
0005433633972	9325	80	18D
0005433633959	9325	81	18F
0005433577878	9325	82	19C
0005434272184	9325	83	19B
0005432145119	9325	84	19D
0005433615029	9325	85	19E
0005433614998	9325	86	20D
0005433614968	9325	87	20C
0005433633964	9325	88	20B
0005433577871	9325	89	20F
0005433633966	9325	90	21D
0005433614994	9325	91	21F
0005433577875	9325	92	21E
0005433633946	9325	93	22A
0005433633978	9325	94	22B
0005432145121	9325	95	22D
0005433614978	9325	96	22E
0005433615019	9325	97	23A
0005433614999	9325	98	23C
0005433577879	9325	99	23B
0005434163562	9325	100	23F
0005433615002	9325	101	23E
0005433615022	9325	102	24A
0005433633965	9325	103	24B
0005433633957	9325	104	24C
0005433614982	9325	105	24D
0005433614979	9325	106	24F
0005433614974	9325	107	24E
0005433614992	9325	108	25A
0005433614977	9325	109	25C
0005433633967	9325	110	25B
0005433614958	9325	111	25D
0005433577869	9325	112	25E
0005433615026	9325	113	26A
0005433614966	9325	114	25F
0005433614960	9325	115	26B
0005433633951	9325	116	26D
0005433577880	9325	117	26C
0005433614961	9325	118	26E
0005433633949	9325	119	26F
0005433615023	9325	120	27B
0005433614981	9325	121	27A
0005433614965	9325	122	27D
0005433633977	9325	123	27C
0005434163577	9325	124	27F
0005433615014	9325	125	27E
0005433614991	9325	126	28A
0005433577873	9325	127	28B
0005432756865	9325	128	28C
0005433615025	9325	129	28E
0005433577872	9325	130	28D
0005433633953	9325	131	28F
0005433615009	9325	132	29B
0005433614964	9325	133	29A
0005433633968	9325	134	29C
0005433577867	9325	135	29D
0005433614969	9325	136	29E
0005433633955	9325	137	30A
0005433614973	9325	138	29F
0005433615000	9325	139	30B
0005432755093	9325	140	30C
0005434163572	9325	141	30E
0005433615008	9325	142	30D
0005433633980	9325	143	30F
0005433633960	9325	144	31A
0005433614962	9325	145	31C
0005433633961	9325	146	31B
0005434163586	9325	147	31E
0005433614987	9325	148	31D
0005432756863	9325	149	31F
0005433614489	25267	1	1A
0005433633680	25267	2	1C
0005433633652	25267	3	2D
0005433633672	25267	4	2C
0005433614413	25267	5	2A
0005433614117	25267	6	3A
0005433614414	25267	7	2F
0005434163658	25267	8	3C
0005433633575	25267	9	3F
0005434273083	25267	10	3D
0005433614404	25267	11	4A
0005433614728	25267	12	4D
0005433577765	25267	13	4C
0005433633632	25267	14	5A
0005433614399	25267	15	5C
0005434163657	25267	16	5F
0005433614352	25267	17	5D
0005433614252	25267	18	6C
0005433633741	25267	19	6F
0005433614713	25267	20	6D
0005434163654	25267	21	7A
0005433633673	25267	22	7C
0005433577745	25267	23	8C
0005434272198	25267	24	8B
0005433577823	25267	25	8D
0005433633532	25267	26	8E
0005433614191	25267	27	9A
0005433633593	25267	28	9D
0005433633588	25267	29	10A
0005434163653	25267	30	10C
0005433614648	25267	31	10B
0005433614346	25267	32	10D
0005433633696	25267	33	10E
0005433614011	25267	34	10F
0005433614432	25267	35	11B
0005433633678	25267	36	11A
0005433614256	25267	37	11C
0005433614488	25267	38	11D
0005433614612	25267	39	11E
0005433614274	25267	40	12A
0005434273082	25267	41	11F
0005433614410	25267	42	12B
0005433633549	25267	43	12C
0005433614402	25267	44	12E
0005433614570	25267	45	12F
0005433614362	25267	46	13B
0005433614212	25267	47	13A
0005433633744	25267	48	13D
0005433577796	25267	49	13F
0005433577767	25267	50	13E
0005433614360	25267	51	14B
0005434163650	25267	52	14A
0005433577771	25267	53	14C
0005433614465	25267	54	14E
0005433577766	25267	55	14D
0005433577692	25267	56	15B
0005433614649	25267	57	15A
0005433577772	25267	58	15C
0005433614370	25267	59	15D
0005433613995	25267	60	15F
0005433614160	25267	61	16A
0005434163652	25267	62	16D
0005433633701	25267	63	16C
0005433614420	25267	64	16E
0005433614273	25267	65	16F
0005433577699	25267	66	17B
0005434163651	25267	67	17A
0005433633733	25267	68	17C
0005433614390	25267	69	17D
0005433614730	25267	70	17F
0005433633723	25267	71	17E
0005433633697	25267	72	18A
0005433614368	25267	73	18B
0005433633585	25267	74	18C
0005433577700	25267	75	18E
0005433633683	25267	76	19B
0005433633718	25267	77	18F
0005433614250	25267	78	19D
0005433577797	25267	79	19C
0005434163648	25267	80	20A
0005434163649	25267	81	19E
0005433633757	25267	82	20B
0005433614714	25267	83	20C
0005433614342	25267	84	20E
0005434163655	25267	85	20D
0005433614526	25267	86	20F
0005433614343	25267	87	21A
0005433614393	25267	88	21C
0005433614369	25267	89	21D
0005433614458	25267	90	21E
0005433633703	25267	91	22A
0005433614609	25267	92	21F
0005433614656	25267	93	22B
0005433577774	25267	94	22C
0005433633574	25267	95	22D
0005433614396	25267	96	22F
0005433577735	25267	97	22E
0005433614419	25267	98	23C
0005433633653	25267	99	23B
0005433633684	25267	100	23E
0005433614478	25267	101	23F
0005433614403	25267	102	24B
0005433614267	25267	103	24C
0005433633759	25267	104	24D
0005433614344	25267	105	24F
0005433633665	25267	106	25B
0005433633713	25267	107	25A
0005433614361	25267	108	25F
0005433577693	25267	109	25E
0005433614345	25267	110	26B
0005433614431	25267	111	26A
0005434273081	25267	112	26C
0005433633758	25267	113	26F
0005433614203	25267	114	26E
0005433633617	25267	115	27A
0005433614190	25267	116	27B
0005433577822	25267	117	27D
0005433614613	25267	118	27F
0005433614394	25267	119	27E
0005433633608	25267	120	28A
0005433614466	25267	121	28B
0005433614729	25267	122	28D
0005433614411	25267	123	28C
0005433633551	25267	124	28F
0005433614467	25267	125	29A
0005433633694	25267	126	29E
0005433633587	25267	127	29D
0005433633668	25267	128	29C
0005433633681	25267	129	29F
0005433614571	25267	130	30A
0005433577750	25267	131	30B
0005433614459	25267	132	30E
0005433614367	25267	133	30D
0005433614616	25267	134	30F
0005433614573	25267	135	31A
0005433614468	25267	136	31C
0005433633700	25267	137	31D
0005433614251	25267	138	31E
0005434163656	25267	139	31F
0005435856201	4245	1	1A
0005432184965	4245	2	2F
0005435947171	4245	3	3F
0005435787342	4245	4	3H
0005435856199	4245	5	4G
0005435947209	4245	6	5B
0005435854058	4245	7	5C
0005435856188	4245	8	5H
0005435947152	4245	9	12D
0005435947232	4245	10	12H
0005435947237	4245	11	13E
0005435947213	4245	12	13G
0005435856200	4245	13	14A
0005435947221	4245	14	14E
0005435947181	4245	15	15A
0005435947203	4245	16	15E
0005435947180	4245	17	15D
0005435947195	4245	18	15G
0005432184966	4245	19	17H
0005435947183	4245	20	18D
0005435947222	4245	21	19E
0005432571308	4245	22	20A
0005435947125	4245	23	21E
0005435947204	4245	24	21F
0005435947208	4245	25	23A
0005434271297	4245	26	24A
0005432571305	4245	27	24F
0005435856183	4245	28	24E
0005435854055	4245	29	24G
0005435854056	4245	30	27G
0005435947240	4245	31	29F
0005435856184	4245	32	29H
0005435787334	4245	33	31A
0005435854057	4245	34	31F
0005435947172	4245	35	32A
0005432184964	4245	36	32G
0005435947223	4245	37	34D
0005435856189	4245	38	35A
0005435947220	4245	39	35D
0005432571299	4245	40	36D
0005435947238	4245	41	36F
0005432571287	4245	42	38H
0005435947212	4245	43	39F
0005435856225	26562	1	1A
0005435947338	26562	2	2G
0005435986770	26562	3	5A
0005435947339	26562	4	5B
0005435856228	26562	5	11A
0005432571342	26562	6	11H
0005435787366	26562	7	13H
0005435947328	26562	8	14G
0005435986758	26562	9	15D
0005435986769	26562	10	17E
0005435986718	26562	11	18A
0005435986746	26562	12	18F
0005435947325	26562	13	19A
0005435856224	26562	14	19B
0005435947327	26562	15	19G
0005432571343	26562	16	21B
0005435856226	26562	17	22F
0005435947326	26562	18	22H
0005435856227	26562	19	23E
0005435947331	26562	20	24B
0005435947330	26562	21	24F
0005435947337	26562	22	24G
0005435947329	26562	23	25E
0005435947333	26562	24	28D
0005435986721	26562	25	30E
0005435947335	26562	26	32A
0005435986723	26562	27	32F
0005432571344	26562	28	33A
0005435947336	26562	29	33D
0005435947334	26562	30	33B
0005435787367	26562	31	33G
0005435947324	26562	32	35B
0005435947332	26562	33	36G
0005432571345	26562	34	38A
0005433074600	351	1	1A
0005432948348	351	2	1C
0005433569369	351	3	1F
0005433074440	351	4	1D
0005433074657	351	5	2A
0005433569403	351	6	2C
0005433569399	351	7	2D
0005432238965	351	8	3A
0005432948382	351	9	2F
0005433074745	351	10	3D
0005433569366	351	11	3C
0005432948212	351	12	3F
0005433569384	351	13	4A
0005433569393	351	14	4C
0005433569387	351	15	4F
0005433074570	351	16	4D
0005433569415	351	17	5A
0005432948234	351	18	5C
0005432948125	351	19	5D
0005433074556	351	20	6A
0005432238972	351	21	6D
0005433569408	351	22	6C
0005433569394	351	23	6F
0005433569392	351	24	7A
0005433569361	351	25	7C
0005433569419	351	26	7D
0005433569371	351	27	8A
0005433074645	351	28	8B
0005433569417	351	29	8C
0005433074609	351	30	8E
0005433569390	351	31	8F
0005432948123	351	32	9B
0005432948233	351	33	9A
0005433569405	351	34	9C
0005433074729	351	35	9D
0005432948213	351	36	9E
0005433074654	351	37	10A
0005433569368	351	38	10B
0005432238969	351	39	10D
0005433569395	351	40	10C
0005433074442	351	41	10E
0005433569372	351	42	10F
0005433569381	351	43	11A
0005433129262	351	44	11C
0005433569426	351	45	11B
0005433569367	351	46	11D
0005433569424	351	47	11F
0005433569391	351	48	11E
0005432948326	351	49	12A
0005433074670	351	50	12B
0005433569400	351	51	12C
0005432948245	351	52	12E
0005433074569	351	53	12D
0005432948360	351	54	12F
0005433074612	351	55	13A
0005433569416	351	56	13C
0005432948385	351	57	13B
0005433569425	351	58	13D
0005432948343	351	59	13E
0005433569377	351	60	13F
0005433569396	351	61	14C
0005433074622	351	62	14B
0005433569409	351	63	14A
0005432948301	351	64	14E
0005432948363	351	65	14D
0005433569422	351	66	14F
0005432948124	351	67	15B
0005433569414	351	68	15A
0005433569373	351	69	15C
0005433134131	351	70	15D
0005433074746	351	71	15F
0005433569397	351	72	15E
0005432948275	351	73	16A
0005433074441	351	74	16B
0005433569389	351	75	16D
0005433074691	351	76	16C
0005432948240	351	77	16E
0005433569411	351	78	17A
0005433129264	351	79	16F
0005432948443	351	80	17B
0005433569404	351	81	17C
0005433569386	351	82	17E
0005433569402	351	83	17D
0005433074693	351	84	17F
0005433074620	351	85	18A
0005433569382	351	86	18C
0005433569412	351	87	18B
0005432948299	351	88	18E
0005433074779	351	89	19C
0005433074665	351	90	19B
0005433569364	351	91	19D
0005433134111	351	92	19E
0005433074639	351	93	20B
0005432948342	351	94	20A
0005433569378	351	95	20C
0005433074653	351	96	20D
0005432948241	351	97	20F
0005432948357	351	98	20E
0005433569376	351	99	21A
0005433074643	351	100	21B
0005433569421	351	101	21D
0005433569413	351	102	21C
0005432238971	351	103	21F
0005433074781	351	104	21E
0005433569406	351	105	22B
0005433569427	351	106	22A
0005432948344	351	107	22C
0005433569401	351	108	22E
0005433569379	351	109	22F
0005432948334	351	110	23A
0005432948330	351	111	23C
0005433569410	351	112	23B
0005433074621	351	113	23D
0005433569365	351	114	23E
0005432948371	351	115	23F
0005432948274	351	116	24B
0005433569407	351	117	24A
0005432238970	351	118	24D
0005432948353	351	119	24C
0005433569374	351	120	24E
0005433074780	351	121	24F
0005432948351	351	122	25B
0005432948316	351	123	25A
0005432948413	351	124	25C
0005433569385	351	125	25D
0005432238966	351	126	25E
0005433569418	351	127	26A
0005433074439	351	128	25F
0005433569423	351	129	26B
0005433569420	351	130	26C
0005433569375	351	131	26E
0005433074669	351	132	26D
0005433129268	351	133	27A
0005433569398	351	134	26F
0005432948282	351	135	27C
0005432948355	351	136	27B
0005432948249	351	137	27D
0005433569363	351	138	27F
0005432948221	351	139	27E
0005433569370	351	140	28A
0005433569388	351	141	28C
0005432948349	351	142	28B
0005433074694	351	143	28E
0005432948436	351	144	29A
0005433074603	351	145	28F
0005433074499	351	146	29B
0005432948356	351	147	29C
0005433074625	351	148	29E
0005432238968	351	149	29D
0005433129265	351	150	29F
0005432948384	351	151	30B
0005433074604	351	152	30A
0005433569360	351	153	30C
0005432238967	351	154	30D
0005433569380	351	155	31A
0005432948350	351	156	30F
0005433569383	351	157	30E
0005433074504	351	158	31B
0005433569362	351	159	31C
0005433074608	351	160	31D
0005432948157	351	161	31E
0005433568945	11607	1	1D
0005433568556	11607	2	1C
0005433568458	11607	3	2C
0005432948663	11607	4	2A
0005432948674	11607	5	2D
0005432948642	11607	6	3A
0005432948655	11607	7	2F
0005432192337	11607	8	3D
0005433568883	11607	9	3C
0005433134162	11607	10	3F
0005433568789	11607	11	4A
0005433074859	11607	12	4C
0005432192336	11607	13	4D
0005433074864	11607	14	5A
0005433131731	11607	15	4F
0005433134163	11607	16	5C
0005433568837	11607	17	5F
0005432948679	11607	18	5D
0005433074855	11607	19	6A
0005432948665	11607	20	6D
0005433134161	11607	21	6C
0005433568613	11607	22	6F
0005433074858	11607	23	7A
0005433568677	11607	24	7D
0005433074854	11607	25	7C
0005433074847	11607	26	8A
0005433568919	11607	27	8C
0005432948673	11607	28	8B
0005433568683	11607	29	8E
0005433568922	11607	30	8D
0005432948647	11607	31	9B
0005433131732	11607	32	9A
0005433568607	11607	33	9C
0005433568511	11607	34	9E
0005433568955	11607	35	9F
0005433074865	11607	36	10A
0005433074866	11607	37	10B
0005433568914	11607	38	10C
0005433074856	11607	39	10E
0005433074839	11607	40	10D
0005432948652	11607	41	11A
0005433134159	11607	42	11B
0005433568967	11607	43	11C
0005432948640	11607	44	11D
0005432192335	11607	45	11F
0005433131730	11607	46	11E
0005433131729	11607	47	12C
0005433568913	11607	48	12B
0005433568774	11607	49	12D
0005432948668	11607	50	12E
0005432948649	11607	51	12F
0005433568728	11607	52	13B
0005433568895	11607	53	13A
0005433568882	11607	54	13E
0005433568668	11607	55	13D
0005433568551	11607	56	13C
0005433568947	11607	57	13F
0005433568700	11607	58	14A
0005433568693	11607	59	14B
0005433568499	11607	60	14D
0005433568658	11607	61	14C
0005433568829	11607	62	15A
0005432948664	11607	63	14F
0005433568830	11607	64	15C
0005433074849	11607	65	15B
0005433568500	11607	66	15D
0005432948662	11607	67	15E
0005432948670	11607	68	16A
0005432948680	11607	69	16B
0005432948658	11607	70	16E
0005432948676	11607	71	17A
0005433568946	11607	72	16F
0005433568838	11607	73	17B
0005433074853	11607	74	17C
0005432948648	11607	75	17E
0005433568661	11607	76	17D
0005433074842	11607	77	18A
0005432948661	11607	78	18B
0005432948651	11607	79	18C
0005433074851	11607	80	18E
0005433568923	11607	81	18D
0005432948669	11607	82	18F
0005432948667	11607	83	19B
0005433074841	11607	84	19D
0005433568821	11607	85	19C
0005432948656	11607	86	19E
0005432948650	11607	87	20B
0005432948644	11607	88	20A
0005433074862	11607	89	20E
0005432948641	11607	90	20D
0005433568665	11607	91	21A
0005433568660	11607	92	20F
0005432948654	11607	93	21C
0005433134160	11607	94	21D
0005432948660	11607	95	21F
0005433074840	11607	96	21E
0005432948666	11607	97	22A
0005433131733	11607	98	22B
0005433568924	11607	99	22C
0005433568783	11607	100	22E
0005432948653	11607	101	23B
0005433074861	11607	102	23A
0005433074852	11607	103	23D
0005433568739	11607	104	23C
0005433568688	11607	105	23F
0005433074846	11607	106	23E
0005432948678	11607	107	24B
0005433074843	11607	108	24C
0005433568608	11607	109	24E
0005433568510	11607	110	24D
0005433568674	11607	111	24F
0005432948672	11607	112	25A
0005433568986	11607	113	25B
0005433568596	11607	114	25D
0005432948645	11607	115	25C
0005433568427	11607	116	25E
0005433074860	11607	117	26A
0005433568876	11607	118	26B
0005432948677	11607	119	26D
0005433568631	11607	120	26C
0005433074863	11607	121	26E
0005433568694	11607	122	27A
0005433568782	11607	123	27B
0005433568809	11607	124	27D
0005433568605	11607	125	27C
0005433074857	11607	126	27E
0005433568985	11607	127	28B
0005433074838	11607	128	28D
0005432948643	11607	129	28E
0005433568717	11607	130	28F
0005433074850	11607	131	29A
0005433074844	11607	132	29C
0005433568678	11607	133	29D
0005433568612	11607	134	29E
0005432948646	11607	135	30A
0005432948671	11607	136	29F
0005433568823	11607	137	30B
0005433568867	11607	138	30D
0005433074848	11607	139	30C
0005433074845	11607	140	30E
0005432948659	11607	141	30F
0005432948657	11607	142	31C
0005432948675	11607	143	31D
0005433568828	11607	144	31E
0005433568384	11607	145	31F
0005433817489	9986	1	1A
0005434732970	9986	2	1B
0005434732978	9986	3	2A
0005434732964	9986	4	2B
0005434732965	9986	5	3A
0005434732969	9986	6	3B
0005433817488	9986	7	4A
0005434732973	9986	8	4B
0005434732979	9986	9	5A
0005433817491	9986	10	5B
0005433817490	9986	11	6A
0005434732972	9986	12	6B
0005434733000	13922	1	1A
0005434732999	13922	2	4B
0005434732997	13922	3	5A
0005433817463	13922	4	6A
0005434732998	13922	5	5B
0005433817461	13922	6	6B
0005433754524	2330	1	1A
0005432984977	2330	2	1B
0005432226092	2330	3	1F
0005433434674	2330	4	1C
0005433754500	2330	5	1H
0005433754507	2330	6	1G
0005435982555	2330	7	2A
0005432984904	2330	8	2B
0005432984761	2330	9	2F
0005433434554	2330	10	2C
0005433754491	2330	11	2G
0005433754487	2330	12	3A
0005435982564	2330	13	2H
0005435982539	2330	14	3C
0005432985012	2330	15	3G
0005432226091	2330	16	3F
0005433754505	2330	17	4A
0005432984762	2330	18	3H
0005433754519	2330	19	4B
0005433434596	2330	20	4F
0005435982534	2330	21	4C
0005435982529	2330	22	4G
0005433434597	2330	23	4H
0005433434482	2330	24	5B
0005432869490	2330	25	5A
0005435982568	2330	26	5C
0005432655595	2330	27	5G
0005435982541	2330	28	5F
0005433754511	2330	29	5H
0005432226088	2330	30	9B
0005433434572	2330	31	9A
0005433434574	2330	32	9G
0005432985003	2330	33	11A
0005433754488	2330	34	9H
0005433434562	2330	35	11B
0005433434527	2330	36	11D
0005434731148	2330	37	11F
0005432984850	2330	38	11E
0005433754522	2330	39	11H
0005432869491	2330	40	11G
0005435982557	2330	41	12A
0005435982537	2330	42	12D
0005432984962	2330	43	12B
0005433434594	2330	44	12E
0005435982532	2330	45	12F
0005432985059	2330	46	12H
0005435982536	2330	47	12G
0005432655603	2330	48	13A
0005433764691	2330	49	13D
0005433434599	2330	50	13B
0005433754542	2330	51	13E
0005433754489	2330	52	13G
0005435982540	2330	53	13F
0005434731161	2330	54	13H
0005435982528	2330	55	14B
0005433754502	2330	56	14A
0005433754506	2330	57	14E
0005432984993	2330	58	14D
0005433754490	2330	59	14F
0005432984930	2330	60	14H
0005433434471	2330	61	14G
0005434731150	2330	62	15A
0005433754543	2330	63	15D
0005435982558	2330	64	15B
0005432984963	2330	65	15E
0005433434619	2330	66	15G
0005433754534	2330	67	15F
0005433434587	2330	68	15H
0005435982535	2330	69	16B
0005433754516	2330	70	16A
0005432655606	2330	71	16D
0005433754533	2330	72	16E
0005433754525	2330	73	16G
0005435982538	2330	74	16F
0005433754536	2330	75	16H
0005433754535	2330	76	17B
0005433434621	2330	77	17A
0005432300295	2330	78	17D
0005432984903	2330	79	17F
0005432984836	2330	80	17E
0005433434715	2330	81	17G
0005432985016	2330	82	18A
0005433434561	2330	83	17H
0005433434483	2330	84	18B
0005435982560	2330	85	18D
0005432655597	2330	86	18E
0005435982544	2330	87	18G
0005435982551	2330	88	18F
0005433754537	2330	89	18H
0005435982542	2330	90	19B
0005432655598	2330	91	19A
0005435982548	2330	92	19E
0005432984923	2330	93	19D
0005432655602	2330	94	19F
0005433754517	2330	95	19G
0005435982566	2330	96	20A
0005433754529	2330	97	19H
0005433754514	2330	98	20D
0005432300292	2330	99	20B
0005432226093	2330	100	20E
0005434731149	2330	101	20G
0005433754520	2330	102	20F
0005433434595	2330	103	20H
0005432984992	2330	104	21A
0005432655605	2330	105	21D
0005433754545	2330	106	21B
0005433754509	2330	107	21E
0005435982545	2330	108	21G
0005435982533	2330	109	21F
0005433754494	2330	110	21H
0005434731151	2330	111	22B
0005432984976	2330	112	22A
0005433754531	2330	113	22D
0005435982549	2330	114	22F
0005432300293	2330	115	22E
0005432869504	2330	116	22G
0005432985004	2330	117	22H
0005433754499	2330	118	23B
0005432984961	2330	119	23A
0005432984975	2330	120	23F
0005433754495	2330	121	23E
0005432655604	2330	122	23H
0005433754521	2330	123	23G
0005433754540	2330	124	24B
0005433754539	2330	125	24A
0005435982550	2330	126	24E
0005433766660	2330	127	24D
0005433434575	2330	128	24F
0005435982561	2330	129	24G
0005435982556	2330	130	24H
0005432985060	2330	131	25E
0005432984964	2330	132	25D
0005432300294	2330	133	27A
0005433754497	2330	134	25F
0005433764690	2330	135	27B
0005433434629	2330	136	27E
0005435982563	2330	137	27D
0005433434636	2330	138	27F
0005432984937	2330	139	27H
0005433434662	2330	140	27G
0005432984819	2330	141	28A
0005433434449	2330	142	28B
0005433754492	2330	143	28E
0005432984931	2330	144	28F
0005435982543	2330	145	28H
0005432655600	2330	146	29A
0005432869511	2330	147	29D
0005433754518	2330	148	29B
0005435982565	2330	149	29E
0005433754513	2330	150	29G
0005433434580	2330	151	29F
0005435982547	2330	152	30A
0005432226089	2330	153	29H
0005432226087	2330	154	30D
0005433754501	2330	155	30B
0005432655601	2330	156	30F
0005435982570	2330	157	30E
0005435982554	2330	158	30G
0005433754538	2330	159	31A
0005433434526	2330	160	30H
0005433754544	2330	161	31B
0005433764689	2330	162	31D
0005432300291	2330	163	31F
0005435982546	2330	164	31E
0005434731162	2330	165	31H
0005433754541	2330	166	31G
0005435982559	2330	167	32A
0005433754496	2330	168	32B
0005433754510	2330	169	32E
0005432869510	2330	170	32D
0005433434563	2330	171	32F
0005433434470	2330	172	32G
0005433754526	2330	173	33A
0005433754523	2330	174	32H
0005433754493	2330	175	33D
0005435982530	2330	176	33B
0005435982552	2330	177	33E
0005433754512	2330	178	33F
0005433754504	2330	179	33H
0005433434450	2330	180	34B
0005432655596	2330	181	34A
0005433766659	2330	182	34D
0005433754498	2330	183	34F
0005433434630	2330	184	34E
0005433754528	2330	185	34G
0005432984846	2330	186	35A
0005433434573	2330	187	34H
0005433754532	2330	188	35B
0005433434620	2330	189	35D
0005432869519	2330	190	35E
0005432984845	2330	191	35G
0005435982531	2330	192	35F
0005432984988	2330	193	35H
0005432985162	2330	194	36B
0005432984875	2330	195	36D
0005432869489	2330	196	36F
0005432300296	2330	197	36E
0005432984818	2330	198	36G
0005432226090	2330	199	37A
0005435982527	2330	200	36H
0005432985102	2330	201	37D
0005432869520	2330	202	37B
0005433754503	2330	203	37E
0005433766661	2330	204	37F
0005433754530	2330	205	37H
0005432984922	2330	206	37G
0005435982562	2330	207	38A
0005432655599	2330	208	38D
0005433754527	2330	209	38B
0005433754508	2330	210	38E
0005435982553	2330	211	38G
0005433754515	2330	212	38F
0005435982569	2330	213	38H
0005435982567	2330	214	39D
0005432984994	2330	215	39F
0005432984876	2330	216	39E
0005435982091	26173	1	1A
0005432985236	26173	2	1C
0005432985246	26173	3	1B
0005432655475	26173	4	1F
0005433434818	26173	5	1H
0005433434830	26173	6	1G
0005433434814	26173	7	2A
0005433764670	26173	8	2C
0005435982231	26173	9	2B
0005432985243	26173	10	2F
0005433754047	26173	11	2G
0005435982003	26173	12	3A
0005432985234	26173	13	2H
0005435982153	26173	14	3B
0005435982163	26173	15	3F
0005435982065	26173	16	3C
0005433754005	26173	17	3G
0005433753766	26173	18	3H
0005433753948	26173	19	4B
0005432985252	26173	20	4A
0005433764669	26173	21	4F
0005432655478	26173	22	4C
0005432655477	26173	23	4G
0005432985254	26173	24	5A
0005432985238	26173	25	4H
0005433754002	26173	26	5B
0005433434838	26173	27	5C
0005433754048	26173	28	5G
0005433754119	26173	29	5F
0005432869559	26173	30	5H
0005435982120	26173	31	9A
0005435982392	26173	32	9H
0005435982133	26173	33	9G
0005433434840	26173	34	9B
0005433753976	26173	35	11A
0005433754066	26173	36	11B
0005432051145	26173	37	11E
0005435982131	26173	38	11D
0005432985263	26173	39	11H
0005432985232	26173	40	11G
0005432985239	26173	41	12A
0005433754269	26173	42	12D
0005433764676	26173	43	12B
0005432985249	26173	44	12E
0005435982156	26173	45	12G
0005435982055	26173	46	12F
0005435982134	26173	47	12H
0005432655422	26173	48	13D
0005432869556	26173	49	13B
0005435982185	26173	50	13E
0005435982162	26173	51	13G
0005433754031	26173	52	13H
0005435982023	26173	53	14B
0005433766633	26173	54	14A
0005433753905	26173	55	14D
0005435982215	26173	56	14E
0005433753981	26173	57	14H
0005433434836	26173	58	14G
0005433754120	26173	59	14F
0005433754270	26173	60	15A
0005433754209	26173	61	15D
0005432051143	26173	62	15B
0005432049483	26173	63	15F
0005433434817	26173	64	15H
0005435982193	26173	65	15G
0005432655450	26173	66	16B
0005433754316	26173	67	16A
0005433754004	26173	68	16E
0005433754040	26173	69	16G
0005433753765	26173	70	16F
0005433753757	26173	71	16H
0005433753962	26173	72	17B
0005432985241	26173	73	17A
0005433754063	26173	74	17F
0005432985231	26173	75	17E
0005433754100	26173	76	17G
0005433753951	26173	77	18A
0005433434839	26173	78	17H
0005432985250	26173	79	18D
0005432985242	26173	80	18B
0005432985253	26173	81	18F
0005433434837	26173	82	18E
0005435982186	26173	83	18G
0005433754182	26173	84	19A
0005432985240	26173	85	18H
0005433434832	26173	86	19B
0005433434816	26173	87	19E
0005433753944	26173	88	19D
0005432655506	26173	89	19F
0005432985260	26173	90	19H
0005433753983	26173	91	19G
0005432869554	26173	92	20A
0005433753974	26173	93	20B
0005433434827	26173	94	20E
0005433753982	26173	95	20D
0005435982132	26173	96	20F
0005434731194	26173	97	20H
0005432985230	26173	98	20G
0005435982094	26173	99	21A
0005435982184	26173	100	21B
0005433434824	26173	101	21E
0005433434815	26173	102	21D
0005433434820	26173	103	21G
0005435982192	26173	104	21F
0005435982187	26173	105	21H
0005432985237	26173	106	22B
0005432985245	26173	107	22A
0005435982121	26173	108	22D
0005433753987	26173	109	22F
0005435982099	26173	110	22E
0005433754162	26173	111	22G
0005432655438	26173	112	22H
0005435982144	26173	113	23A
0005433434826	26173	114	23E
0005434731192	26173	115	23D
0005433434823	26173	116	23B
0005433753711	26173	117	23F
0005435982189	26173	118	23H
0005435982026	26173	119	24B
0005433754073	26173	120	24A
0005433754207	26173	121	24E
0005435982230	26173	122	24D
0005433434821	26173	123	24F
0005433434841	26173	124	24G
0005432985255	26173	125	25D
0005435982116	26173	126	24H
0005434731193	26173	127	25E
0005432985247	26173	128	27A
0005435982195	26173	129	25F
0005432985258	26173	130	27B
0005432655489	26173	131	27D
0005435982108	26173	132	27F
0005433754211	26173	133	27H
0005432985257	26173	134	27G
0005433434813	26173	135	28A
0005432985244	26173	136	28B
0005433754133	26173	137	28E
0005435982391	26173	138	28D
0005433754030	26173	139	28G
0005435982165	26173	140	28F
0005433753810	26173	141	28H
0005432985251	26173	142	29A
0005433754016	26173	143	29B
0005432051144	26173	144	29E
0005433434833	26173	145	29D
0005432869557	26173	146	29G
0005432985233	26173	147	29F
0005435982145	26173	148	29H
0005432655442	26173	149	30A
0005433754074	26173	150	30D
0005433754130	26173	151	30B
0005432655457	26173	152	30F
0005432869553	26173	153	30H
0005433754131	26173	154	30G
0005433753977	26173	155	31A
0005435982109	26173	156	31B
0005435982135	26173	157	31E
0005435982178	26173	158	31D
0005435981992	26173	159	31F
0005432869558	26173	160	31H
0005435982222	26173	161	32A
0005435982148	26173	162	32B
0005433434835	26173	163	32E
0005432655496	26173	164	32D
0005432985248	26173	165	32F
0005435982092	26173	166	32H
0005432655463	26173	167	32G
0005435982138	26173	168	33A
0005432985256	26173	169	33D
0005433753767	26173	170	33B
0005433434819	26173	171	33E
0005432655476	26173	172	33F
0005433753984	26173	173	33H
0005433754194	26173	174	34A
0005432869555	26173	175	34D
0005433766634	26173	176	34B
0005433753947	26173	177	34F
0005433754003	26173	178	34E
0005432985259	26173	179	34G
0005433754206	26173	180	34H
0005435982194	26173	181	35A
0005433434831	26173	182	35D
0005432985262	26173	183	35B
0005433434825	26173	184	35F
0005433753922	26173	185	35E
0005433434834	26173	186	35G
0005434731191	26173	187	35H
0005433434822	26173	188	36B
0005432985261	26173	189	36A
0005433753923	26173	190	36D
0005433434829	26173	191	36F
0005435982122	26173	192	36H
0005433754092	26173	193	36G
0005435982137	26173	194	37B
0005435982136	26173	195	37E
0005433754009	26173	196	37D
0005432985235	26173	197	37G
0005433754304	26173	198	37H
0005432655437	26173	199	38A
0005433753980	26173	200	38B
0005433753936	26173	201	38E
0005433754101	26173	202	38D
0005432655460	26173	203	38G
0005435982188	26173	204	38F
0005435982095	26173	205	39D
0005433753988	26173	206	38H
0005433754315	26173	207	39F
0005433434828	26173	208	39E
0005434374883	1482	1	1A
0005433764675	1482	2	1D
0005434374877	1482	3	1F
0005433461600	1482	4	2C
0005434374884	1482	5	2D
0005434374880	1482	6	2F
0005433151322	1482	7	3C
0005433151311	1482	8	3A
0005433151318	1482	9	3F
0005433151434	1482	10	4D
0005434374887	1482	11	4E
0005434374881	1482	12	5B
0005433151382	1482	13	5C
0005434374865	1482	14	5D
0005432267930	1482	15	5E
0005433151321	1482	16	6A
0005433764679	1482	17	5F
0005434374889	1482	18	6B
0005433151292	1482	19	6C
0005433151320	1482	20	6D
0005433151191	1482	21	6E
0005434374876	1482	22	7C
0005433151332	1482	23	7B
0005433764674	1482	24	7D
0005433151279	1482	25	7F
0005434374875	1482	26	8A
0005433151412	1482	27	8C
0005434374851	1482	28	8F
0005433764678	1482	29	8E
0005434374871	1482	30	9A
0005434374893	1482	31	9B
0005433151289	1482	32	9C
0005433460448	1482	33	9F
0005434374891	1482	34	9E
0005434374882	1482	35	10C
0005433461601	1482	36	10E
0005432267933	1482	37	11A
0005433151396	1482	38	11B
0005434374886	1482	39	11D
0005434374859	1482	40	11C
0005434374885	1482	41	11E
0005434374867	1482	42	11F
0005434374862	1482	43	12B
0005433151241	1482	44	12A
0005433151360	1482	45	12D
0005434374854	1482	46	12E
0005433151291	1482	47	12F
0005434374868	1482	48	13A
0005433151389	1482	49	13C
0005434374850	1482	50	13B
0005434374855	1482	51	13D
0005434374869	1482	52	13E
0005434374860	1482	53	14C
0005434374858	1482	54	14B
0005432267932	1482	55	14D
0005434374892	1482	56	14E
0005434374861	1482	57	14F
0005434374857	1482	58	15B
0005434374864	1482	59	15A
0005433931450	1482	60	15C
0005434374872	1482	61	15D
0005434374878	1482	62	15E
0005433931443	1482	63	16A
0005432267928	1482	64	16B
0005433151242	1482	65	16C
0005434374888	1482	66	16E
0005434374853	1482	67	16D
0005433151436	1482	68	16F
0005433931453	1482	69	17B
0005433151448	1482	70	17C
0005433931454	1482	71	17E
0005433461599	1482	72	17D
0005434374890	1482	73	18A
0005433151305	1482	74	18B
0005433151394	1482	75	18D
0005434374874	1482	76	18E
0005434374852	1482	77	18F
0005434374879	1482	78	19A
0005434374846	1482	79	19D
0005433151290	1482	80	19C
0005432267931	1482	81	19E
0005433151381	1482	82	19F
0005434374863	1482	83	20D
0005434374856	1482	84	20E
0005434374866	1482	85	21B
0005434374849	1482	86	21A
0005433151393	1482	87	21C
0005433151357	1482	88	21D
0005434374870	1482	89	21F
0005433151390	1482	90	21E
0005434374848	1482	91	22B
0005433931455	1482	92	22A
0005433151403	1482	93	22C
0005433151341	1482	94	22D
0005433151429	1482	95	22E
0005434374873	1482	96	23B
0005434374847	1482	97	23A
0005432267929	1482	98	23F
0005434374272	20109	1	1A
0005434374370	20109	2	1C
0005433151598	20109	3	1F
0005433151584	20109	4	2D
0005434374425	20109	5	3C
0005433151595	20109	6	3F
0005433151572	20109	7	4A
0005434374530	20109	8	4C
0005433151570	20109	9	4E
0005433151579	20109	10	4F
0005433151594	20109	11	5A
0005434374167	20109	12	5B
0005433151582	20109	13	5C
0005434374515	20109	14	5E
0005432056319	20109	15	6A
0005434374514	20109	16	5F
0005433931481	20109	17	6B
0005434374586	20109	18	6C
0005434374401	20109	19	6D
0005434374168	20109	20	7A
0005434374371	20109	21	7C
0005433151589	20109	22	7E
0005434374550	20109	23	7D
0005433151591	20109	24	8A
0005434374420	20109	25	8B
0005434374578	20109	26	8C
0005434374545	20109	27	8D
0005434374400	20109	28	8E
0005433151577	20109	29	9A
0005433151585	20109	30	8F
0005434374219	20109	31	9B
0005434374489	20109	32	9C
0005433151569	20109	33	10C
0005434374440	20109	34	10B
0005432056318	20109	35	10D
0005432056317	20109	36	10E
0005433151599	20109	37	11C
0005434374402	20109	38	11B
0005434374476	20109	39	11D
0005434374604	20109	40	11F
0005433151597	20109	41	12B
0005434374532	20109	42	12A
0005434374567	20109	43	12C
0005433764691	20109	44	12E
0005434374363	20109	45	13A
0005434374562	20109	46	13C
0005434374408	20109	47	13B
0005433151580	20109	48	13D
0005433931479	20109	49	13E
0005433151571	20109	50	14A
0005434374513	20109	51	13F
0005433151574	20109	52	14B
0005434374531	20109	53	14D
0005433151601	20109	54	14C
0005434374341	20109	55	14F
0005434374424	20109	56	15B
0005434374411	20109	57	15C
0005434374338	20109	58	15E
0005434029669	20109	59	16A
0005434374166	20109	60	15F
0005434029670	20109	61	16B
0005433151575	20109	62	16C
0005433764689	20109	63	16D
0005434374497	20109	64	16F
0005433931478	20109	65	16E
0005434374543	20109	66	17A
0005434374404	20109	67	17B
0005433151587	20109	68	17D
0005433764690	20109	69	17F
0005433931480	20109	70	17E
0005434374534	20109	71	18A
0005434374563	20109	72	18B
0005433151592	20109	73	18D
0005433151576	20109	74	18C
0005433151590	20109	75	18F
0005434374480	20109	76	18E
0005433151568	20109	77	19A
0005434374463	20109	78	19C
0005434374593	20109	79	19B
0005434374628	20109	80	19D
0005434374502	20109	81	19E
0005433151593	20109	82	19F
0005434374592	20109	83	20A
0005433151586	20109	84	20C
0005434374313	20109	85	20B
0005434374481	20109	86	20D
0005434374314	20109	87	20F
0005433151578	20109	88	21B
0005434374576	20109	89	21C
0005433151573	20109	90	21D
0005433151581	20109	91	21E
0005434374369	20109	92	22A
0005434374512	20109	93	21F
0005432056320	20109	94	22B
0005433151583	20109	95	22D
0005433151596	20109	96	22E
0005434374614	20109	97	23A
0005434374544	20109	98	22F
0005434374533	20109	99	23B
0005433151588	20109	100	23C
0005433151600	20109	101	23D
0005434374501	20109	102	23F
0005432424670	551	1	1C
0005432424678	551	2	1A
0005432424692	551	3	1D
0005432424695	551	4	3F
0005432424709	551	5	3D
0005432424677	551	6	4C
0005432424707	551	7	4F
0005432424694	551	8	5C
0005432282899	551	9	5D
0005432424697	551	10	6A
0005432424698	551	11	7A
0005432424680	551	12	8C
0005432424711	551	13	8B
0005432424693	551	14	8E
0005432424714	551	15	9D
0005432424708	551	16	10A
0005432424673	551	17	10B
0005432424706	551	18	10D
0005432424668	551	19	10F
0005432424704	551	20	11B
0005432424703	551	21	11A
0005432424696	551	22	12A
0005432424679	551	23	14E
0005432424702	551	24	14D
0005432424686	551	25	14F
0005432424683	551	26	15C
0005432424687	551	27	15D
0005432424689	551	28	16A
0005432424671	551	29	17A
0005432282898	551	30	18C
0005432282901	551	31	18B
0005432424674	551	32	18D
0005432424685	551	33	20F
0005432424699	551	34	21B
0005432424681	551	35	21D
0005432424688	551	36	21E
0005432424682	551	37	22D
0005432424672	551	38	23B
0005432282900	551	39	23D
0005432424691	551	40	24C
0005432424710	551	41	24F
0005432282903	551	42	25E
0005432424690	551	43	26D
0005432424700	551	44	26C
0005432424713	551	45	26E
0005432424669	551	46	27E
0005432282902	551	47	28B
0005432424701	551	48	28E
0005432424676	551	49	29E
0005432424675	551	50	30A
0005432424705	551	51	29F
0005432282904	551	52	30E
0005432424684	551	53	31E
0005432424712	551	54	31F
0005432302349	12889	1	4D
0005432302352	12889	2	16F
0005432302350	12889	3	19D
0005432302351	12889	4	29F
0005432424251	12934	1	1D
0005432424248	12934	2	1F
0005432424269	12934	3	2C
0005432424131	12934	4	2D
0005432424282	12934	5	3A
0005432424245	12934	6	4A
0005432424235	12934	7	3F
0005432424215	12934	8	4C
0005432424211	12934	9	4D
0005432424250	12934	10	5A
0005432424206	12934	11	5C
0005432424140	12934	12	6A
0005432424182	12934	13	6C
0005432424168	12934	14	6D
0005432424279	12934	15	8A
0005432424237	12934	16	9B
0005432424070	12934	17	9D
0005432424216	12934	18	10B
0005432424220	12934	19	11F
0005432424142	12934	20	12A
0005432424186	12934	21	12C
0005432424221	12934	22	12D
0005432424177	12934	23	13B
0005432424164	12934	24	13D
0005432424287	12934	25	13F
0005432424290	12934	26	14D
0005432424023	12934	27	14E
0005432424264	12934	28	15A
0005432424185	12934	29	15C
0005432424317	12934	30	15B
0005432424199	12934	31	16D
0005432424085	12934	32	16F
0005432424249	12934	33	17C
0005432424288	12934	34	17D
0005432424246	12934	35	18C
0005432424236	12934	36	18E
0005432424289	12934	37	19B
0005432424265	12934	38	19D
0005432424190	12934	39	19E
0005432424253	12934	40	20F
0005432424132	12934	41	21A
0005432424064	12934	42	21C
0005432424280	12934	43	21D
0005432424311	12934	44	22C
0005432424244	12934	45	23C
0005432424276	12934	46	23D
0005432424176	12934	47	24B
0005432424271	12934	48	24A
0005432424222	12934	49	24C
0005432424086	12934	50	24D
0005432424316	12934	51	25D
0005432424238	12934	52	26B
0005432424165	12934	53	26E
0005432424071	12934	54	27B
0005432424087	12934	55	27E
0005432424266	12934	56	27C
0005432424208	12934	57	28A
0005432424270	12934	58	28D
0005432424283	12934	59	28C
0005432424217	12934	60	28E
0005432424155	12934	61	28F
0005432424106	12934	62	29A
0005432424130	12934	63	30D
0005432424141	12934	64	30C
0005432424255	12934	65	31A
0005432424212	12934	66	31D
0005434024037	474	1	1B
0005433057884	474	2	1F
0005434024056	474	3	1G
0005434024050	474	4	2A
0005434024093	474	5	1H
0005433057585	474	6	2C
0005433057819	474	7	2B
0005433057614	474	8	2F
0005434024062	474	9	2H
0005434735691	474	10	2G
0005433057583	474	11	3A
0005434735686	474	12	3B
0005433057829	474	13	3F
0005434024094	474	14	3G
0005433929593	474	15	4A
0005434024082	474	16	3H
0005434024048	474	17	4B
0005434024064	474	18	4F
0005434735658	474	19	4C
0005434032046	474	20	4G
0005433684416	474	21	5A
0005434024040	474	22	5C
0005434024028	474	23	5G
0005434024043	474	24	5F
0005433929605	474	25	5H
0005432235680	474	26	9B
0005433057789	474	27	9A
0005434032045	474	28	9G
0005434024053	474	29	11B
0005434024087	474	30	11A
0005433057883	474	31	11D
0005433057654	474	32	11G
0005434024090	474	33	11F
0005434024031	474	34	11E
0005433057909	474	35	11H
0005433057828	474	36	12A
0005433057870	474	37	12D
0005434024061	474	38	12B
0005433057653	474	39	12E
0005433057866	474	40	12F
0005433057797	474	41	12G
0005434024049	474	42	13D
0005433057661	474	43	13E
0005434024068	474	44	13F
0005434735654	474	45	13H
0005433057801	474	46	13G
0005433057852	474	47	14D
0005433057867	474	48	14B
0005432235679	474	49	14F
0005434024085	474	50	14H
0005434024089	474	51	14G
0005433057788	474	52	15A
0005433057905	474	53	15D
0005434024046	474	54	15F
0005434735659	474	55	15H
0005434024058	474	56	15G
0005434028309	474	57	16A
0005434024051	474	58	16D
0005434735656	474	59	16B
0005434024091	474	60	16E
0005433057704	474	61	16G
0005434024032	474	62	17A
0005434024074	474	63	17B
0005433057662	474	64	17D
0005433057778	474	65	17E
0005434024045	474	66	17G
0005433058010	474	67	17F
0005432235673	474	68	17H
0005434735684	474	69	18B
0005433057712	474	70	18D
0005434024083	474	71	18E
0005434024027	474	72	18G
0005433057780	474	73	18H
0005434024060	474	74	19B
0005434024044	474	75	19D
0005434024075	474	76	19F
0005434024092	474	77	19E
0005434735655	474	78	19G
0005433057741	474	79	20B
0005433057584	474	80	20D
0005434028310	474	81	20F
0005433929604	474	82	20H
0005432045621	474	83	20G
0005434024035	474	84	21A
0005434024042	474	85	21B
0005433057740	474	86	21E
0005434024071	474	87	21D
0005433057906	474	88	21G
0005433929612	474	89	21F
0005433057948	474	90	22A
0005434024057	474	91	22D
0005432235678	474	92	22F
0005434024039	474	93	22H
0005433929597	474	94	23B
0005434024054	474	95	23A
0005434735678	474	96	23D
0005434024026	474	97	23F
0005434024079	474	98	23H
0005434024066	474	99	23G
0005434024034	474	100	24A
0005433057605	474	101	24F
0005434735685	474	102	24E
0005432045622	474	103	24G
0005433057869	474	104	25D
0005434024067	474	105	25F
0005434024086	474	106	27D
0005433057885	474	107	27G
0005434024072	474	108	27F
0005433057742	474	109	28A
0005433057871	474	110	27H
0005433057836	474	111	28B
0005432235674	474	112	28E
0005433057986	474	113	28D
0005433057730	474	114	28F
0005432235676	474	115	28H
0005434024076	474	116	28G
0005434024073	474	117	29A
0005434024059	474	118	29D
0005434024029	474	119	29B
0005434024047	474	120	29E
0005433929599	474	121	29F
0005434024065	474	122	29H
0005433057586	474	123	30B
0005434024036	474	124	30A
0005433057816	474	125	30E
0005434024063	474	126	30H
0005433929613	474	127	31B
0005434032042	474	128	31A
0005433057941	474	129	31D
0005433057615	474	130	31F
0005432235677	474	131	31E
0005433057781	474	132	31H
0005433057904	474	133	32D
0005434024084	474	134	32B
0005434029667	474	135	32A
0005434024077	474	136	32E
0005434024052	474	137	32F
0005434024070	474	138	32H
0005434024081	474	139	32G
0005434024055	474	140	33A
0005433058009	474	141	33B
0005434024069	474	142	33E
0005433057840	474	143	33H
0005434024095	474	144	33G
0005434024041	474	145	34A
0005433929598	474	146	34D
0005433057606	474	147	34F
0005433058008	474	148	34G
0005434024096	474	149	35A
0005433057872	474	150	35D
0005434024038	474	151	35G
0005433057802	474	152	35F
0005433057729	474	153	36B
0005434032043	474	154	36A
0005434024030	474	155	36D
0005434735673	474	156	36F
0005434032044	474	157	36G
0005434024078	474	158	37A
0005433057830	474	159	37D
0005432235675	474	160	37B
0005434735692	474	161	37H
0005433929592	474	162	38A
0005434029668	474	163	38B
0005433057424	474	164	38E
0005433057835	474	165	38D
0005433057815	474	166	38H
0005434024033	474	167	38G
0005434024088	474	168	39D
0005434024080	474	169	39F
0005433057790	474	170	39E
0005434023468	12673	1	1A
0005434023528	12673	2	1C
0005434023318	12673	3	1H
0005434032011	12673	4	2B
0005434023282	12673	5	2C
0005434023337	12673	6	3A
0005434023503	12673	7	3B
0005434023293	12673	8	3C
0005433058105	12673	9	3G
0005433058098	12673	10	3F
0005434023219	12673	11	3H
0005434023347	12673	12	4A
0005434023635	12673	13	4C
0005434023371	12673	14	4F
0005434023283	12673	15	5F
0005433058079	12673	16	5H
0005433058091	12673	17	9G
0005434023607	12673	18	11A
0005434023495	12673	19	11B
0005433058104	12673	20	11E
0005434023338	12673	21	11D
0005433058097	12673	22	11F
0005433058073	12673	23	11H
0005434023452	12673	24	12D
0005434023349	12673	25	12E
0005434023498	12673	26	12F
0005432156390	12673	27	12G
0005433058089	12673	28	13B
0005434023482	12673	29	13A
0005433058083	12673	30	13G
0005433929632	12673	31	13H
0005432156389	12673	32	14A
0005433058076	12673	33	14H
0005434023539	12673	34	15B
0005434023526	12673	35	15H
0005434028295	12673	36	15G
0005433058075	12673	37	16B
0005433058094	12673	38	16A
0005434023769	12673	39	16E
0005434023483	12673	40	16F
0005434023523	12673	41	16H
0005434735717	12673	42	17D
0005434023673	12673	43	17B
0005434028285	12673	44	17F
0005434028296	12673	45	17E
0005434023379	12673	46	17G
0005434023642	12673	47	17H
0005434023456	12673	48	18B
0005434023300	12673	49	18A
0005433058102	12673	50	18F
0005434023403	12673	51	19A
0005434023373	12673	52	18H
0005434023446	12673	53	19E
0005433058090	12673	54	19F
0005434023474	12673	55	19G
0005434023244	12673	56	19H
0005434023546	12673	57	20D
0005433058108	12673	58	20B
0005433058085	12673	59	20E
0005433929636	12673	60	20G
0005433058082	12673	61	20H
0005433058101	12673	62	21B
0005434023545	12673	63	21F
0005433058077	12673	64	21H
0005434023502	12673	65	22A
0005433058074	12673	66	22B
0005433058092	12673	67	22E
0005434023527	12673	68	22G
0005433058081	12673	69	22F
0005434023348	12673	70	23B
0005433684432	12673	71	23A
0005433058088	12673	72	23E
0005433929633	12673	73	23D
0005434028272	12673	74	23G
0005434023196	12673	75	24A
0005434023496	12673	76	23H
0005433058106	12673	77	24B
0005434032013	12673	78	24E
0005434023484	12673	79	24D
0005433058111	12673	80	24F
0005434735716	12673	81	24G
0005434032012	12673	82	25D
0005433058095	12673	83	24H
0005434023374	12673	84	25E
0005432156387	12673	85	27A
0005434023580	12673	86	25F
0005433058107	12673	87	27B
0005434023568	12673	88	27E
0005433058087	12673	89	27D
0005434023529	12673	90	27F
0005434023501	12673	91	27H
0005434023299	12673	92	27G
0005433058096	12673	93	28A
0005434023252	12673	94	28B
0005433058103	12673	95	28D
0005434023354	12673	96	28H
0005434032007	12673	97	28G
0005434023333	12673	98	29D
0005433058080	12673	99	29E
0005434023643	12673	100	29G
0005434023245	12673	101	30B
0005434023608	12673	102	30A
0005434023332	12673	103	30E
0005433058086	12673	104	30F
0005434023499	12673	105	31B
0005434735719	12673	106	31D
0005433058084	12673	107	31F
0005432157502	12673	108	31E
0005433058113	12673	109	31G
0005434023515	12673	110	31H
0005433058072	12673	111	32D
0005434023346	12673	112	32B
0005434032010	12673	113	32E
0005433058099	12673	114	32H
0005433058110	12673	115	32G
0005434023569	12673	116	33D
0005434023344	12673	117	33H
0005433058109	12673	118	33G
0005434023636	12673	119	34A
0005434023350	12673	120	34D
0005434023461	12673	121	34B
0005434023547	12673	122	34H
0005433058093	12673	123	34G
0005433058100	12673	124	35D
0005434023522	12673	125	35E
0005433684431	12673	126	35G
0005434023284	12673	127	35H
0005433058112	12673	128	36B
0005433929635	12673	129	36D
0005434735715	12673	130	36E
0005434023623	12673	131	36H
0005433929634	12673	132	36G
0005434023514	12673	133	37A
0005434023485	12673	134	37B
0005433058078	12673	135	37D
0005432156388	12673	136	37E
0005434023391	12673	137	37H
0005434735718	12673	138	38B
0005434023556	12673	139	38F
0005434023298	12673	140	38H
0005434023455	12673	141	38G
0005434023370	12673	142	39E
0005433036079	2147	1	1F
0005433923786	2147	2	1G
0005433923768	2147	3	2A
0005433875388	2147	4	1H
0005433036073	2147	5	2C
0005433923804	2147	6	2B
0005433923838	2147	7	2H
0005433923757	2147	8	2G
0005433931478	2147	9	3C
0005433036158	2147	10	3B
0005433923816	2147	11	3A
0005433035817	2147	12	3F
0005433035984	2147	13	4B
0005432749778	2147	14	4A
0005433035816	2147	15	4F
0005433923803	2147	16	4C
0005433923806	2147	17	4G
0005433036110	2147	18	4H
0005433923755	2147	19	5B
0005433923796	2147	20	5C
0005433923764	2147	21	5G
0005433035970	2147	22	5F
0005433036145	2147	23	5H
0005433035997	2147	24	9B
0005433929636	2147	25	9G
0005433036113	2147	26	11A
0005433923784	2147	27	11B
0005433923807	2147	28	11D
0005433923773	2147	29	11F
0005433923751	2147	30	11H
0005433923787	2147	31	11G
0005433923812	2147	32	12B
0005433923823	2147	33	12A
0005432231614	2147	34	12D
0005433923763	2147	35	12E
0005433035998	2147	36	12G
0005433036181	2147	37	13A
0005433923822	2147	38	13D
0005433923841	2147	39	13E
0005433923780	2147	40	13F
0005433923818	2147	41	13H
0005433923821	2147	42	14B
0005433923808	2147	43	14D
0005432231616	2147	44	14F
0005433931481	2147	45	14G
0005433929634	2147	46	15A
0005433036287	2147	47	15D
0005433923809	2147	48	15B
0005432231623	2147	49	15E
0005433036160	2147	50	15F
0005432231617	2147	51	15H
0005433923753	2147	52	15G
0005433923785	2147	53	16A
0005433036172	2147	54	16B
0005433923802	2147	55	16E
0005433035963	2147	56	16D
0005433923837	2147	57	16F
0005433923758	2147	58	16H
0005433923801	2147	59	16G
0005433035985	2147	60	17A
0005433923750	2147	61	17D
0005433923829	2147	62	17B
0005433923805	2147	63	17E
0005433923769	2147	64	17G
0005432231620	2147	65	17F
0005433923830	2147	66	17H
0005433036104	2147	67	18B
0005433035840	2147	68	18A
0005433036202	2147	69	18D
0005433036092	2147	70	18G
0005433036348	2147	71	19A
0005432231624	2147	72	18H
0005433036111	2147	73	19E
0005433923795	2147	74	19D
0005433035910	2147	75	19H
0005433923766	2147	76	19G
0005433923832	2147	77	20A
0005433923824	2147	78	20B
0005433036213	2147	79	20G
0005433923774	2147	80	20F
0005433035964	2147	81	20H
0005433929633	2147	82	21B
0005433923834	2147	83	21A
0005433923820	2147	84	21D
0005433923749	2147	85	21E
0005433036123	2147	86	21G
0005433923835	2147	87	21F
0005433036156	2147	88	21H
0005433923819	2147	89	22B
0005434028296	2147	90	22D
0005433931479	2147	91	22G
0005433923798	2147	92	22F
0005432044539	2147	93	23A
0005433036361	2147	94	22H
0005433035839	2147	95	23B
0005433923782	2147	96	23D
0005433036161	2147	97	23F
0005433923770	2147	98	23E
0005433036157	2147	99	23G
0005433923828	2147	100	23H
0005433875387	2147	101	24B
0005433036270	2147	102	24F
0005433929635	2147	103	24E
0005432231621	2147	104	24H
0005433923843	2147	105	24G
0005433036203	2147	106	25D
0005434028295	2147	107	25E
0005433035986	2147	108	27A
0005433923839	2147	109	25F
0005433923793	2147	110	27E
0005433036318	2147	111	27D
0005433923760	2147	112	27F
0005433923765	2147	113	27G
0005433923775	2147	114	28A
0005432231615	2147	115	27H
0005433923778	2147	116	28D
0005432231622	2147	117	28E
0005433036288	2147	118	28G
0005433923811	2147	119	28F
0005432231619	2147	120	28H
0005433923810	2147	121	29A
0005433036173	2147	122	29D
0005432231618	2147	123	29B
0005433036347	2147	124	29E
0005433923772	2147	125	29F
0005433923840	2147	126	29H
0005433923771	2147	127	30A
0005433923842	2147	128	30D
0005433923776	2147	129	30F
0005433036159	2147	130	30E
0005434028272	2147	131	30G
0005433923792	2147	132	31B
0005433931480	2147	133	31E
0005433923817	2147	134	31D
0005433923791	2147	135	31F
0005433923799	2147	136	31G
0005433923788	2147	137	32B
0005433036434	2147	138	32E
0005433923826	2147	139	32D
0005433923844	2147	140	32F
0005433923836	2147	141	32H
0005433923767	2147	142	32G
0005433923800	2147	143	33A
0005433923756	2147	144	33D
0005434028285	2147	145	33B
0005433923783	2147	146	33E
0005433923831	2147	147	33H
0005433923813	2147	148	33G
0005433923762	2147	149	34A
0005433923777	2147	150	34F
0005433923779	2147	151	34G
0005433923781	2147	152	34H
0005433036103	2147	153	35B
0005433923814	2147	154	35D
0005433923754	2147	155	35F
0005433036271	2147	156	35E
0005433923845	2147	157	35H
0005433036264	2147	158	36A
0005433923789	2147	159	36D
0005433923761	2147	160	36E
0005433923833	2147	161	36G
0005433923752	2147	162	37A
0005433923825	2147	163	36H
0005433036106	2147	164	37D
0005433923759	2147	165	37F
0005433923815	2147	166	37H
0005433923790	2147	167	37G
0005433929632	2147	168	38A
0005433036029	2147	169	38B
0005433923794	2147	170	38E
0005433923827	2147	171	38H
0005433036112	2147	172	38G
0005433923797	2147	173	39D
0005433035983	2147	174	39F
0005433922932	24137	1	1A
0005433036590	24137	2	1B
0005433923071	24137	3	1F
0005433923100	24137	4	1G
0005433923138	24137	5	2A
0005432206227	24137	6	1H
0005433922913	24137	7	2B
0005432207675	24137	8	2F
0005433923206	24137	9	2H
0005433036564	24137	10	2G
0005433036581	24137	11	3C
0005433922645	24137	12	3B
0005433923091	24137	13	3G
0005433036594	24137	14	3F
0005432206225	24137	15	4B
0005433923204	24137	16	4G
0005433929594	24137	17	5A
0005433036566	24137	18	4H
0005433931444	24137	19	5B
0005433923092	24137	20	5F
0005433923107	24137	21	5G
0005433036574	24137	22	9H
0005433922987	24137	23	9G
0005433922997	24137	24	11A
0005433923003	24137	25	11B
0005433923016	24137	26	11D
0005432207676	24137	27	12A
0005433036576	24137	28	11H
0005433923176	24137	29	12D
0005433923330	24137	30	12E
0005433036573	24137	31	13B
0005433923106	24137	32	13A
0005433923005	24137	33	13D
0005433923148	24137	34	13E
0005433931460	24137	35	13F
0005433922527	24137	36	13H
0005433036558	24137	37	14B
0005432207674	24137	38	14A
0005433036555	24137	39	14G
0005433922767	24137	40	14F
0005433922974	24137	41	14H
0005432206226	24137	42	15E
0005433922574	24137	43	15H
0005433923171	24137	44	15G
0005433922583	24137	45	16A
0005433923072	24137	46	16D
0005433036595	24137	47	16H
0005434028312	24137	48	17B
0005433922629	24137	49	17A
0005433922661	24137	50	17D
0005432749796	24137	51	17E
0005433922983	24137	52	18A
0005433922899	24137	53	17H
0005433922876	24137	54	18B
0005433036567	24137	55	18D
0005433922906	24137	56	18E
0005433036549	24137	57	18G
0005433922646	24137	58	18H
0005433922892	24137	59	19A
0005433036560	24137	60	19E
0005433036559	24137	61	19F
0005433922882	24137	62	19G
0005433922374	24137	63	20A
0005433036546	24137	64	20D
0005433036545	24137	65	20B
0005433036584	24137	66	20E
0005434028311	24137	67	20G
0005433036570	24137	68	20F
0005433922546	24137	69	21A
0005433036544	24137	70	20H
0005433036582	24137	71	21D
0005433923241	24137	72	21B
0005433922859	24137	73	21E
0005433922731	24137	74	21G
0005433036571	24137	75	22B
0005433929595	24137	76	22D
0005433036557	24137	77	22F
0005433036585	24137	78	22E
0005433036586	24137	79	22G
0005433923118	24137	80	23A
0005433036591	24137	81	23D
0005433922912	24137	82	23B
0005434028313	24137	83	23G
0005433922934	24137	84	23H
0005433922958	24137	85	24B
0005433036550	24137	86	24E
0005433036575	24137	87	24F
0005433036577	24137	88	25D
0005433922798	24137	89	24H
0005433923143	24137	90	25E
0005433922628	24137	91	25F
0005433922845	24137	92	27B
0005433929610	24137	93	27A
0005433922874	24137	94	27F
0005433922973	24137	95	27G
0005433036579	24137	96	28A
0005433922870	24137	97	27H
0005433036589	24137	98	28B
0005433922900	24137	99	28E
0005433922984	24137	100	28F
0005433036580	24137	101	28H
0005433036553	24137	102	28G
0005433923051	24137	103	29B
0005433923004	24137	104	29D
0005433922808	24137	105	29F
0005432206228	24137	106	30A
0005433036551	24137	107	29H
0005433036569	24137	108	30D
0005433036554	24137	109	30B
0005433036593	24137	110	30F
0005433923017	24137	111	30E
0005432749797	24137	112	30H
0005433036563	24137	113	30G
0005433923242	24137	114	31F
0005433922871	24137	115	31E
0005432749798	24137	116	31H
0005433923067	24137	117	32D
0005433922778	24137	118	32E
0005433923170	24137	119	32F
0005433036548	24137	120	32H
0005433929600	24137	121	33A
0005433036556	24137	122	33D
0005433922951	24137	123	33B
0005433036572	24137	124	33E
0005433036552	24137	125	33G
0005433922766	24137	126	33F
0005433036597	24137	127	34A
0005433036592	24137	128	34B
0005433036565	24137	129	34E
0005433036562	24137	130	35A
0005433923137	24137	131	35E
0005433923172	24137	132	35D
0005433036561	24137	133	35B
0005433036596	24137	134	35F
0005432206224	24137	135	35G
0005433922858	24137	136	36B
0005433929602	24137	137	36A
0005433922901	24137	138	36D
0005433923442	24137	139	36H
0005433922730	24137	140	36G
0005433036587	24137	141	37E
0005433923207	24137	142	37D
0005433036583	24137	143	37F
0005433922718	24137	144	37H
0005433036547	24137	145	37G
0005433922877	24137	146	38B
0005433036588	24137	147	38A
0005433922779	24137	148	38E
0005433923099	24137	149	38D
0005433036568	24137	150	38F
0005433922957	24137	151	38H
0005433036578	24137	152	38G
0005433922804	24137	153	39D
0005433923140	24137	154	39F
0005432277880	247	1	1A
0005433180921	247	2	1D
0005433233868	247	3	1K
0005434302481	247	4	1H
0005434726086	247	5	2D
0005433181100	247	6	2C
0005434726109	247	7	2A
0005434726097	247	8	2H
0005434551502	247	9	2K
0005434726137	247	10	3C
0005434551545	247	11	3G
0005434726038	247	12	4C
0005433233786	247	13	4A
0005434551517	247	14	3K
0005433234210	247	15	4G
0005433181046	247	16	4D
0005434726123	247	17	4K
0005435142650	247	18	4H
0005433126825	247	19	5C
0005434726139	247	20	5H
0005434726127	247	21	5G
0005433111499	247	22	5D
0005434726037	247	23	5K
0005433234252	247	24	11D
0005434726078	247	25	11C
0005433233598	247	26	11F
0005433180998	247	27	11E
0005434726160	247	28	11K
0005434726083	247	29	11H
0005434726115	247	30	11G
0005434726048	247	31	12C
0005434551521	247	32	12A
0005434551523	247	33	12E
0005433234115	247	34	12D
0005434726056	247	35	12H
0005435142649	247	36	12G
0005434726136	247	37	12F
0005433289817	247	38	12K
0005434551527	247	39	13C
0005434726059	247	40	13A
0005434551503	247	41	13G
0005434726141	247	42	13F
0005434726090	247	43	13E
0005433233597	247	44	14A
0005432277877	247	45	13K
0005434551495	247	46	14D
0005434726069	247	47	14C
0005434726058	247	48	14F
0005433111496	247	49	14E
0005434726066	247	50	14K
0005433233665	247	51	14G
0005434726068	247	52	15D
0005433289820	247	53	15A
0005434551522	247	54	15E
0005433234140	247	55	15H
0005434551511	247	56	15G
0005433180984	247	57	15K
0005434551544	247	58	16C
0005434551513	247	59	16A
0005432277881	247	60	16F
0005433233997	247	61	16H
0005434726084	247	62	17C
0005433181047	247	63	17A
0005434031992	247	64	16K
0005434726051	247	65	17E
0005434726116	247	66	17D
0005434726080	247	67	17G
0005432277876	247	68	17F
0005433233889	247	69	17K
0005434551538	247	70	17H
0005433181048	247	71	18B
0005434302479	247	72	18A
0005434726095	247	73	18E
0005432277879	247	74	18D
0005434726114	247	75	18H
0005434726129	247	76	19B
0005433233970	247	77	19D
0005434726047	247	78	19G
0005434551497	247	79	19F
0005434726134	247	80	19E
0005434726075	247	81	20A
0005434726054	247	82	19K
0005434302483	247	83	19J
0005434726138	247	84	20C
0005433180997	247	85	20E
0005434731190	247	86	20D
0005433126839	247	87	20H
0005433233869	247	88	20G
0005433111501	247	89	20F
0005434726091	247	90	20K
0005434726042	247	91	20J
0005433234261	247	92	21B
0005434031998	247	93	21A
0005433131689	247	94	21D
0005433234324	247	95	21C
0005432277872	247	96	21H
0005433233857	247	97	22A
0005434726133	247	98	21K
0005434726077	247	99	21J
0005434731188	247	100	22B
0005434551506	247	101	22E
0005433233788	247	102	22D
0005434726046	247	103	22G
0005434726128	247	104	22F
0005433111500	247	105	22J
0005434731189	247	106	23B
0005432277875	247	107	23E
0005434726055	247	108	23D
0005433181095	247	109	23C
0005434726117	247	110	23G
0005434726108	247	111	24D
0005434726053	247	112	23K
0005433131690	247	113	23J
0005433180948	247	114	24F
0005434726063	247	115	24E
0005435142651	247	116	25B
0005433234141	247	117	25A
0005434726100	247	118	24G
0005433233657	247	119	25C
0005434735712	247	120	25E
0005434551494	247	121	25H
0005434735711	247	122	25G
0005434551515	247	123	26A
0005434551499	247	124	25K
0005434726040	247	125	26B
0005432277871	247	126	26E
0005434726152	247	127	26C
0005434551537	247	128	26G
0005433233966	247	129	26F
0005433234019	247	130	26K
0005434551542	247	131	26H
0005434735710	247	132	27A
0005434551534	247	133	27C
0005433234017	247	134	27F
0005434726062	247	135	27E
0005434726081	247	136	27D
0005435142653	247	137	27H
0005434726131	247	138	27G
0005433126817	247	139	28A
0005434726088	247	140	27K
0005434726070	247	141	27J
0005435142644	247	142	28E
0005434551519	247	143	28D
0005435142646	247	144	28C
0005434551524	247	145	28G
0005434551531	247	146	28K
0005435142642	247	147	28J
0005434726147	247	148	28H
0005433234099	247	149	29A
0005434551548	247	150	29D
0005434726132	247	151	29C
0005434726110	247	152	29B
0005435142643	247	153	29E
0005432277873	247	154	29J
0005433234098	247	155	29H
0005433234094	247	156	29G
0005434726067	247	157	29K
0005434726158	247	158	30B
0005434726103	247	159	30A
0005434735713	247	160	30E
0005434551529	247	161	30D
0005434551508	247	162	30H
0005433234018	247	163	30G
0005434551536	247	164	30F
0005434551518	247	165	30J
0005434726101	247	166	31A
0005433180977	247	167	30K
0005433234033	247	168	31D
0005433131670	247	169	31C
0005434726071	247	170	31F
0005434551528	247	171	31E
0005435142647	247	172	31H
0005434726076	247	173	32A
0005433126826	247	174	31K
0005433234032	247	175	31J
0005433766629	247	176	32B
0005434726079	247	177	32E
0005434726092	247	178	32D
0005434726039	247	179	32F
0005434735709	247	180	32H
0005434726126	247	181	33B
0005434726125	247	182	33A
0005434726155	247	183	32K
0005434726072	247	184	33C
0005434726120	247	185	33G
0005434726102	247	186	33F
0005435142640	247	187	33E
0005434726065	247	188	33H
0005432277878	247	189	33K
0005434726112	247	190	33J
0005434726157	247	191	34C
0005434726057	247	192	34B
0005434726087	247	193	34A
0005433234020	247	194	34E
0005433234262	247	195	34F
0005434726148	247	196	34J
0005434726041	247	197	34H
0005434551501	247	198	34K
0005434551500	247	199	35C
0005433233885	247	200	35H
0005433181022	247	201	35G
0005433234053	247	202	36A
0005434551539	247	203	35K
0005433131691	247	204	36C
0005434551520	247	205	36B
0005434726145	247	206	36E
0005434726085	247	207	36D
0005434726154	247	208	36G
0005433233962	247	209	36F
0005434726050	247	210	36K
0005432277883	247	211	37A
0005434551504	247	212	37D
0005434726098	247	213	37C
0005434726049	247	214	37G
0005434726124	247	215	37F
0005434726064	247	216	37E
0005434726060	247	217	37H
0005434726074	247	218	38A
0005434031991	247	219	37K
0005433233961	247	220	37J
0005434726122	247	221	38C
0005434726156	247	222	38B
0005434726113	247	223	38J
0005434551514	247	224	38H
0005434726146	247	225	39A
0005435142641	247	226	39D
0005435142648	247	227	39C
0005433289821	247	228	39F
0005433234031	247	229	39E
0005433233954	247	230	39J
0005433126840	247	231	40A
0005434726104	247	232	39K
0005434726106	247	233	40C
0005434726045	247	234	40B
0005434726135	247	235	40E
0005433181043	247	236	40D
0005434551535	247	237	40G
0005434726043	247	238	40H
0005434726099	247	239	41B
0005434726151	247	240	41A
0005433234100	247	241	40K
0005434726044	247	242	41F
0005433766624	247	243	41E
0005434551533	247	244	41J
0005434551509	247	245	41H
0005433126816	247	246	41G
0005433180983	247	247	41K
0005434726089	247	248	42C
0005432277884	247	249	42E
0005434551512	247	250	42D
0005434726061	247	251	42G
0005433234024	247	252	42J
0005434551543	247	253	42H
0005434726118	247	254	43A
0005434726153	247	255	43D
0005434726052	247	256	43F
0005434551516	247	257	43G
0005433113531	247	258	43K
0005433233815	247	259	43J
0005434551505	247	260	44C
0005434551546	247	261	44B
0005433289849	247	262	44A
0005435142645	247	263	44E
0005434551510	247	264	44D
0005434551526	247	265	44H
0005434731187	247	266	44F
0005435142652	247	267	44K
0005434726105	247	268	44J
0005433234001	247	269	45B
0005434031993	247	270	45A
0005434726150	247	271	45D
0005433233861	247	272	45C
0005434551541	247	273	45F
0005432277874	247	274	45H
0005434726143	247	275	46A
0005434551496	247	276	45K
0005433233890	247	277	45J
0005434726144	247	278	46E
0005434302480	247	279	46D
0005434726159	247	280	46C
0005433233727	247	281	46F
0005433180949	247	282	46J
0005434551498	247	283	46K
0005434726142	247	284	47E
0005434726149	247	285	47D
0005434551540	247	286	47C
0005432277882	247	287	47G
0005434726121	247	288	47F
0005434726111	247	289	47K
0005434726119	247	290	47H
0005434726140	247	291	48D
0005434551525	247	292	48C
0005433233907	247	293	48A
0005434302482	247	294	48E
0005434726093	247	295	48G
0005434726073	247	296	49A
0005434726107	247	297	49D
0005433234054	247	298	49K
0005434551530	247	299	49H
0005434735714	247	300	49G
0005434726096	247	301	50A
0005434551549	247	302	50E
0005434551532	247	303	50D
0005434726130	247	304	50G
0005434551507	247	305	50F
0005434726094	247	306	50K
0005434551547	247	307	50H
0005434726082	247	308	51G
0005434724586	9849	1	1D
0005433234548	9849	2	1C
0005433234537	9849	3	1A
0005434551045	9849	4	1H
0005433234550	9849	5	1G
0005434725394	9849	6	1K
0005433181234	9849	7	2C
0005434724420	9849	8	2A
0005434724827	9849	9	2G
0005434032048	9849	10	2D
0005434725051	9849	11	3A
0005434724601	9849	12	2K
0005434735665	9849	13	2H
0005434725119	9849	14	3G
0005433234523	9849	15	3D
0005434731162	9849	16	3H
0005433181235	9849	17	4C
0005433234532	9849	18	4A
0005433234500	9849	19	4G
0005434724946	9849	20	4D
0005434725361	9849	21	5A
0005434551068	9849	22	4K
0005434724671	9849	23	4H
0005433234511	9849	24	5D
0005433234554	9849	25	5C
0005434725044	9849	26	5H
0005433181227	9849	27	5G
0005434724886	9849	28	11A
0005434725444	9849	29	5K
0005433234525	9849	30	11D
0005434724699	9849	31	11C
0005434725156	9849	32	11G
0005434724551	9849	33	11F
0005434724550	9849	34	11E
0005434550894	9849	35	11K
0005434550740	9849	36	11H
0005434302454	9849	37	12C
0005433181230	9849	38	12A
0005434725244	9849	39	12E
0005434731149	9849	40	12D
0005433181223	9849	41	12G
0005434724766	9849	42	12K
0005433234514	9849	43	12H
0005434725158	9849	44	13D
0005434725120	9849	45	13C
0005433234504	9849	46	13A
0005434550956	9849	47	13E
0005434550879	9849	48	13H
0005433181225	9849	49	13G
0005434731151	9849	50	14C
0005434725157	9849	51	14A
0005433181220	9849	52	13K
0005434551071	9849	53	14D
0005434725043	9849	54	14G
0005433234505	9849	55	14F
0005434725099	9849	56	14E
0005434724777	9849	57	14H
0005432199283	9849	58	15C
0005433181232	9849	59	15A
0005432199282	9849	60	15E
0005434725015	9849	61	15D
0005434725082	9849	62	15G
0005435142513	9849	63	15F
0005434731148	9849	64	16A
0005434725268	9849	65	15K
0005433234556	9849	66	16D
0005434302453	9849	67	16C
0005434302446	9849	68	16F
0005434551080	9849	69	16E
0005433234517	9849	70	16K
0005433234522	9849	71	16H
0005434725174	9849	72	16G
0005434550711	9849	73	17A
0005433234513	9849	74	17E
0005434724723	9849	75	17D
0005434725357	9849	76	17C
0005434725167	9849	77	17F
0005434724570	9849	78	18A
0005433766660	9849	79	17K
0005435142566	9849	80	17H
0005434551038	9849	81	18C
0005433234502	9849	82	18B
0005433181241	9849	83	18E
0005434725206	9849	84	18D
0005433234549	9849	85	18F
0005434302430	9849	86	18K
0005434551163	9849	87	18J
0005434551179	9849	88	19B
0005435142466	9849	89	19A
0005433234534	9849	90	19D
0005434550738	9849	91	19C
0005434725443	9849	92	19F
0005433234499	9849	93	19E
0005434724811	9849	94	19J
0005433234551	9849	95	19H
0005434724923	9849	96	20A
0005433234516	9849	97	20C
0005434725112	9849	98	20B
0005434550795	9849	99	20E
0005434725100	9849	100	20D
0005433234546	9849	101	20H
0005434724870	9849	102	20G
0005433234542	9849	103	20F
0005434550886	9849	104	20K
0005434725070	9849	105	20J
0005434725741	9849	106	21B
0005434551067	9849	107	21A
0005433181221	9849	108	21E
0005434550855	9849	109	21D
0005434725117	9849	110	21C
0005434724770	9849	111	21H
0005434725427	9849	112	21G
0005434550952	9849	113	22A
0005434551160	9849	114	21K
0005434551083	9849	115	22C
0005434550927	9849	116	22F
0005434550932	9849	117	22E
0005434725273	9849	118	22D
0005433181218	9849	119	22H
0005433181222	9849	120	22G
0005433766661	9849	121	22K
0005434725282	9849	122	22J
0005434725309	9849	123	23B
0005434550953	9849	124	23A
0005434550993	9849	125	23C
0005433181240	9849	126	23F
0005434724622	9849	127	23E
0005434550730	9849	128	23H
0005434550799	9849	129	23G
0005433113547	9849	130	24D
0005434550822	9849	131	24F
0005434551037	9849	132	25B
0005433126870	9849	133	25A
0005434550739	9849	134	24G
0005433181219	9849	135	25C
0005434724949	9849	136	25F
0005432199281	9849	137	25E
0005433234526	9849	138	25H
0005434550851	9849	139	25G
0005434551087	9849	140	25K
0005433129297	9849	141	25J
0005434550943	9849	142	26B
0005434551009	9849	143	26A
0005434725284	9849	144	26E
0005434724593	9849	145	26D
0005433234518	9849	146	26G
0005434725426	9849	147	26J
0005433126868	9849	148	27B
0005433234535	9849	149	27A
0005434724509	9849	150	26K
0005433234507	9849	151	27F
0005434550794	9849	152	27D
0005434724950	9849	153	27H
0005434551053	9849	154	27G
0005434550968	9849	155	27K
0005434032051	9849	156	28C
0005433181224	9849	157	28B
0005434725083	9849	158	28A
0005434302447	9849	159	28G
0005435142508	9849	160	28J
0005433181226	9849	161	28H
0005434551035	9849	162	29B
0005433181229	9849	163	29A
0005434725186	9849	164	28K
0005435142505	9849	165	29F
0005434725183	9849	166	29E
0005434724876	9849	167	29D
0005434724602	9849	168	29H
0005434551161	9849	169	29G
0005434551011	9849	170	29K
0005434724623	9849	171	29J
0005433234558	9849	172	30C
0005434551077	9849	173	30B
0005434551140	9849	174	30A
0005434550798	9849	175	30E
0005434550994	9849	176	30D
0005432199284	9849	177	30H
0005433234531	9849	178	30G
0005434725359	9849	179	30J
0005434724841	9849	180	31A
0005433126867	9849	181	31D
0005434724446	9849	182	31C
0005434550796	9849	183	31B
0005434731150	9849	184	31F
0005434725381	9849	185	31E
0005434724836	9849	186	31J
0005433234529	9849	187	31H
0005433234497	9849	188	31K
0005434551018	9849	189	32C
0005433234555	9849	190	32B
0005433234559	9849	191	32A
0005433181237	9849	192	32E
0005434550940	9849	193	32D
0005434725227	9849	194	32G
0005434725168	9849	195	32F
0005434724510	9849	196	32K
0005434725014	9849	197	32J
0005434725405	9849	198	32H
0005433289881	9849	199	33B
0005433234527	9849	200	33D
0005433129300	9849	201	33C
0005433234547	9849	202	33F
0005434550731	9849	203	33E
0005434551164	9849	204	33J
0005434302455	9849	205	33H
0005433234560	9849	206	33G
0005434725171	9849	207	33K
0005434551079	9849	208	34C
0005434724966	9849	209	34B
0005434725047	9849	210	34A
0005434725172	9849	211	34E
0005434724724	9849	212	34D
0005433234506	9849	213	34F
0005434725358	9849	214	34J
0005434725098	9849	215	34H
0005433234557	9849	216	35B
0005434725022	9849	217	35A
0005434724924	9849	218	34K
0005434551084	9849	219	35D
0005433289885	9849	220	35E
0005434725406	9849	221	35H
0005433234521	9849	222	35G
0005434551076	9849	223	35K
0005432199286	9849	224	36C
0005434725081	9849	225	36B
0005433129298	9849	226	36D
0005434551054	9849	227	36G
0005435142378	9849	228	36F
0005434032047	9849	229	36K
0005434725271	9849	230	36J
0005434731161	9849	231	36H
0005434551211	9849	232	37A
0005433234498	9849	233	37D
0005434302443	9849	234	37C
0005433234503	9849	235	37G
0005434032049	9849	236	37F
0005433234553	9849	237	37E
0005433234541	9849	238	37J
0005433289886	9849	239	37H
0005434551036	9849	240	37K
0005434725200	9849	241	38C
0005435142565	9849	242	38K
0005433181236	9849	243	38J
0005434735663	9849	244	39D
0005434550942	9849	245	39C
0005433181242	9849	246	39E
0005434725182	9849	247	39H
0005434550957	9849	248	39G
0005434725218	9849	249	39K
0005433181238	9849	250	39J
0005435142377	9849	251	40E
0005434724871	9849	252	40D
0005434724374	9849	253	40H
0005433234508	9849	254	40G
0005433234538	9849	255	40F
0005433234544	9849	256	40K
0005434724948	9849	257	41A
0005434551178	9849	258	41D
0005434724965	9849	259	41C
0005433289883	9849	260	41B
0005434302438	9849	261	41F
0005433181217	9849	262	41H
0005433289882	9849	263	42A
0005434551146	9849	264	41K
0005434735666	9849	265	41J
0005434550941	9849	266	42C
0005433234501	9849	267	42B
0005434735657	9849	268	42E
0005434724756	9849	269	42D
0005434724930	9849	270	42G
0005433126866	9849	271	42F
0005435142497	9849	272	42K
0005433234545	9849	273	42H
0005433113546	9849	274	43B
0005434724524	9849	275	43A
0005434725372	9849	276	43D
0005435142469	9849	277	43C
0005433234528	9849	278	43F
0005434550797	9849	279	43E
0005433129299	9849	280	43H
0005434551173	9849	281	43G
0005433234520	9849	282	44A
0005433181228	9849	283	43K
0005434550911	9849	284	43J
0005434550887	9849	285	44C
0005434725360	9849	286	44B
0005432199285	9849	287	44E
0005433234533	9849	288	44D
0005432199280	9849	289	44G
0005433766659	9849	290	44F
0005434725382	9849	291	44H
0005433234543	9849	292	45B
0005433234552	9849	293	45A
0005434725050	9849	294	44K
0005434550912	9849	295	45C
0005433234539	9849	296	45F
0005434725042	9849	297	45E
0005433126869	9849	298	45D
0005433234515	9849	299	45H
0005433234536	9849	300	45G
0005433234509	9849	301	45K
0005434725283	9849	302	45J
0005434725318	9849	303	46C
0005434725097	9849	304	46A
0005433234519	9849	305	46D
0005434551141	9849	306	46G
0005433181233	9849	307	46F
0005433234540	9849	308	46H
0005434725272	9849	309	47A
0005434551142	9849	310	46K
0005434551070	9849	311	47D
0005434725255	9849	312	47G
0005434032050	9849	313	47F
0005434725231	9849	314	47E
0005434725054	9849	315	47K
0005434724523	9849	316	47H
0005434724945	9849	317	48C
0005434735664	9849	318	48A
0005433181231	9849	319	48E
0005435142507	9849	320	48D
0005434725204	9849	321	48H
0005433234512	9849	322	49A
0005434550895	9849	323	48K
0005434725128	9849	324	49D
0005434724975	9849	325	49C
0005434724461	9849	326	49G
0005434725133	9849	327	49F
0005434551049	9849	328	49E
0005433289884	9849	329	49K
0005433234530	9849	330	50C
0005434725160	9849	331	50A
0005433234524	9849	332	50E
0005434725159	9849	333	50D
0005434725614	9849	334	50H
0005434725216	9849	335	50G
0005434725116	9849	336	50F
0005433181239	9849	337	51D
0005434724778	9849	338	50K
0005433234510	9849	339	51F
0005434725731	9849	340	51E
0005434067902	7770	1	1C
0005434067949	7770	2	1A
0005432528601	7770	3	1G
0005434067937	7770	4	1D
0005432537069	7770	5	1K
0005432528637	7770	6	1H
0005432528618	7770	7	2D
0005435213132	7770	8	2C
0005432528600	7770	9	2A
0005432528635	7770	10	2H
0005435213092	7770	11	3A
0005432528692	7770	12	2K
0005432069722	7770	13	3D
0005432535860	7770	14	3C
0005432528715	7770	15	3K
0005432528673	7770	16	3H
0005435213055	7770	17	4C
0005435213462	7770	18	4D
0005432150237	7770	19	4H
0005432533306	7770	20	5D
0005435213242	7770	21	5C
0005434067896	7770	22	5A
0005435213180	7770	23	5H
0005435213391	7770	24	11A
0005434067930	7770	25	5K
0005434067917	7770	26	11E
0005432528626	7770	27	11D
0005432528680	7770	28	11C
0005435212939	7770	29	11F
0005434067911	7770	30	11H
0005432150236	7770	31	11G
0005432528643	7770	32	11K
0005432528679	7770	33	12E
0005432428947	7770	34	12D
0005432528603	7770	35	12G
0005434067918	7770	36	12F
0005435213421	7770	37	13A
0005432528656	7770	38	12K
0005434067931	7770	39	12H
0005435213200	7770	40	13D
0005435213347	7770	41	13C
0005434067910	7770	42	13F
0005432528697	7770	43	13E
0005435213251	7770	44	13H
0005432528657	7770	45	13G
0005434067956	7770	46	14A
0005432528665	7770	47	13K
0005435213311	7770	48	14C
0005432528599	7770	49	14G
0005435213204	7770	50	14F
0005432069732	7770	51	14E
0005434067908	7770	52	14K
0005432150238	7770	53	14H
0005432528597	7770	54	15C
0005432528659	7770	55	15A
0005434067895	7770	56	15E
0005435213159	7770	57	15D
0005435213228	7770	58	16A
0005434067941	7770	59	15K
0005435212980	7770	60	15H
0005434067950	7770	61	16C
0005435213440	7770	62	16F
0005432428946	7770	63	16E
0005433656659	7770	64	16D
0005432528591	7770	65	16H
0005435213254	7770	66	16G
0005434067924	7770	67	17A
0005435213285	7770	68	16K
0005432528663	7770	69	17D
0005432069729	7770	70	17G
0005432528632	7770	71	17F
0005435213027	7770	72	17E
0005432528619	7770	73	18A
0005434067921	7770	74	17K
0005432069737	7770	75	18B
0005435213396	7770	76	18E
0005435213364	7770	77	18C
0005434067954	7770	78	18F
0005435213093	7770	79	18J
0005434067958	7770	80	18H
0005432528687	7770	81	19B
0005435213193	7770	82	19A
0005432069728	7770	83	18K
0005432528675	7770	84	19D
0005432528605	7770	85	19F
0005432528640	7770	86	19E
0005432528633	7770	87	19J
0005432528592	7770	88	19H
0005435213279	7770	89	19G
0005435630951	7770	90	20A
0005434067963	7770	91	19K
0005432528701	7770	92	20C
0005432528621	7770	93	20B
0005432150233	7770	94	20E
0005432150235	7770	95	20G
0005432528606	7770	96	20F
0005432528712	7770	97	20J
0005435213545	7770	98	20H
0005435213546	7770	99	21B
0005432528671	7770	100	21A
0005434067951	7770	101	21D
0005432528624	7770	102	21C
0005432528667	7770	103	21F
0005434067897	7770	104	21E
0005432528617	7770	105	21J
0005434067914	7770	106	21H
0005435213473	7770	107	21G
0005435213028	7770	108	22A
0005432528589	7770	109	21K
0005435213373	7770	110	22C
0005435213184	7770	111	22B
0005434067932	7770	112	22E
0005432528684	7770	113	22D
0005432528688	7770	114	22H
0005432069724	7770	115	22G
0005432528607	7770	116	22F
0005435213212	7770	117	22K
0005432528641	7770	118	22J
0005432528685	7770	119	23B
0005432528706	7770	120	23E
0005432528629	7770	121	23C
0005432528652	7770	122	23G
0005434067929	7770	123	23H
0005434067915	7770	124	23K
0005434067906	7770	125	23J
0005432528595	7770	126	24G
0005432150232	7770	127	24F
0005432528616	7770	128	25B
0005435213265	7770	129	25A
0005434067960	7770	130	25C
0005432528664	7770	131	25F
0005432528698	7770	132	25E
0005434067900	7770	133	25D
0005432537068	7770	134	25H
0005435213307	7770	135	25G
0005432528708	7770	136	26A
0005435213360	7770	137	25K
0005434067935	7770	138	25J
0005432528696	7770	139	26C
0005435213482	7770	140	26B
0005432528705	7770	141	26E
0005432528666	7770	142	26D
0005432528662	7770	143	26G
0005434067909	7770	144	26K
0005434067916	7770	145	26H
0005434067934	7770	146	27B
0005432535859	7770	147	27A
0005432428945	7770	148	27C
0005435213090	7770	149	27F
0005432528604	7770	150	27E
0005434067926	7770	151	27D
0005435213383	7770	152	27H
0005435213227	7770	153	27G
0005432528694	7770	154	27K
0005434067912	7770	155	28B
0005432528610	7770	156	28A
0005432528713	7770	157	28E
0005435213361	7770	158	28D
0005432528711	7770	159	28G
0005432528602	7770	160	28F
0005435213246	7770	161	28K
0005435213342	7770	162	28J
0005434067933	7770	163	28H
0005434067944	7770	164	29A
0005432528625	7770	165	29D
0005432069727	7770	166	29C
0005435213538	7770	167	29B
0005432528587	7770	168	29E
0005435213160	7770	169	29H
0005432528718	7770	170	29G
0005432528660	7770	171	29K
0005435213063	7770	172	29J
0005435213189	7770	173	30C
0005434067928	7770	174	30B
0005435213481	7770	175	30A
0005432528647	7770	176	30E
0005432528703	7770	177	30D
0005432528704	7770	178	30G
0005434067964	7770	179	30F
0005432528590	7770	180	30J
0005435213399	7770	181	30H
0005432528683	7770	182	31B
0005433656656	7770	183	31A
0005432150239	7770	184	30K
0005435213202	7770	185	31D
0005435213379	7770	186	31C
0005432528677	7770	187	31F
0005434067957	7770	188	31E
0005432528716	7770	189	31H
0005432528639	7770	190	31G
0005432528654	7770	191	31K
0005434067925	7770	192	32C
0005432528658	7770	193	32A
0005432528651	7770	194	32E
0005435213470	7770	195	32D
0005432528676	7770	196	32K
0005432528693	7770	197	32J
0005432535858	7770	198	32H
0005435213129	7770	199	33A
0005432528614	7770	200	33C
0005434067942	7770	201	33B
0005432069726	7770	202	33G
0005435213304	7770	203	33F
0005434067899	7770	204	33J
0005435630952	7770	205	33H
0005434067962	7770	206	34A
0005432528644	7770	207	33K
0005432069731	7770	208	34C
0005435212982	7770	209	34B
0005432528648	7770	210	34D
0005432528646	7770	211	34G
0005435213710	7770	212	34J
0005434067961	7770	213	35B
0005435213400	7770	214	35A
0005435213229	7770	215	34K
0005432528613	7770	216	35D
0005432069736	7770	217	35C
0005435213327	7770	218	35F
0005432150234	7770	219	35J
0005435213406	7770	220	35G
0005434067919	7770	221	36A
0005434067947	7770	222	35K
0005435213519	7770	223	36C
0005432528615	7770	224	36B
0005432528598	7770	225	36E
0005434067892	7770	226	36D
0005435213415	7770	227	36H
0005433656652	7770	228	36G
0005434067953	7770	229	36K
0005435213431	7770	230	36J
0005435213461	7770	231	37B
0005432533305	7770	232	37A
0005432528710	7770	233	37E
0005434067905	7770	234	37D
0005434067920	7770	235	37C
0005432528620	7770	236	37G
0005434067898	7770	237	37J
0005432528707	7770	238	38A
0005432528668	7770	239	37K
0005432528638	7770	240	38C
0005432528669	7770	241	38B
0005432528612	7770	242	38J
0005432528588	7770	243	39A
0005434067940	7770	244	38K
0005435213206	7770	245	39D
0005432528670	7770	246	39C
0005432528689	7770	247	39B
0005435213020	7770	248	39F
0005435213287	7770	249	39H
0005432528690	7770	250	39G
0005432069734	7770	251	39K
0005432528702	7770	252	39J
0005434067955	7770	253	40C
0005432528585	7770	254	40B
0005435213329	7770	255	40D
0005434067907	7770	256	40G
0005435213384	7770	257	40H
0005432528714	7770	258	41B
0005432528700	7770	259	41A
0005432528594	7770	260	40K
0005434067952	7770	261	41D
0005432528681	7770	262	41F
0005432528623	7770	263	41E
0005434067903	7770	264	41H
0005432528682	7770	265	41G
0005432528695	7770	266	42A
0005432528709	7770	267	41J
0005434067904	7770	268	42C
0005435213211	7770	269	42B
0005432528596	7770	270	42F
0005433656646	7770	271	42D
0005435213432	7770	272	42H
0005432528650	7770	273	42G
0005432528678	7770	274	42K
0005432069735	7770	275	43A
0005432535861	7770	276	43D
0005433656651	7770	277	43B
0005432069733	7770	278	43F
0005434067945	7770	279	43E
0005434067948	7770	280	43H
0005434067922	7770	281	43G
0005434067894	7770	282	43K
0005435213253	7770	283	43J
0005432533307	7770	284	44C
0005432528631	7770	285	44B
0005432528661	7770	286	44E
0005435213198	7770	287	44D
0005432528608	7770	288	44H
0005435213372	7770	289	44G
0005435213241	7770	290	44K
0005434067913	7770	291	44J
0005432528636	7770	292	45A
0005432528672	7770	293	45D
0005434067927	7770	294	45C
0005434067893	7770	295	45F
0005432528634	7770	296	45E
0005432069730	7770	297	45G
0005434067901	7770	298	45K
0005432528686	7770	299	45J
0005435725577	7770	300	46C
0005434067959	7770	301	46B
0005432528611	7770	302	46A
0005434067936	7770	303	46E
0005435213422	7770	304	46D
0005432528655	7770	305	46G
0005432069725	7770	306	46F
0005432528627	7770	307	46J
0005434067939	7770	308	46H
0005432528628	7770	309	47C
0005432528653	7770	310	47A
0005432528609	7770	311	47D
0005432528593	7770	312	47G
0005434067946	7770	313	47F
0005434067938	7770	314	47K
0005435213245	7770	315	47H
0005435630942	7770	316	48A
0005432528642	7770	317	48F
0005435213244	7770	318	48E
0005432528622	7770	319	48H
0005435213547	7770	320	48G
0005435213328	7770	321	49A
0005432537070	7770	322	48K
0005432528649	7770	323	49E
0005435213608	7770	324	49D
0005432528717	7770	325	49F
0005432528699	7770	326	49K
0005432528674	7770	327	49H
0005432528645	7770	328	50C
0005434067943	7770	329	50E
0005432528630	7770	330	50H
0005435213190	7770	331	50G
0005435213252	7770	332	50F
0005434067923	7770	333	51D
0005435212981	7770	334	50K
0005432528586	7770	335	51F
0005432528691	7770	336	51E
0005432069723	7770	337	51G
0005432133285	5307	1	1C
0005434244961	5307	2	1G
0005434573432	5307	3	1D
0005435614195	5307	4	2A
0005435097250	5307	5	2H
0005434244828	5307	6	2G
0005435614251	5307	7	2D
0005435614222	5307	8	3A
0005435424634	5307	9	2K
0005435424819	5307	10	3D
0005434573424	5307	11	3K
0005435097247	5307	12	3H
0005435302183	5307	13	3G
0005435424212	5307	14	4C
0005435614207	5307	15	4A
0005435042847	5307	16	4G
0005435302188	5307	17	4D
0005435319476	5307	18	5A
0005435614194	5307	19	5D
0005435614208	5307	20	5C
0005435614297	5307	21	5G
0005435614218	5307	22	11A
0005435614262	5307	23	5K
0005434244827	5307	24	5H
0005432363404	5307	25	11E
0005435614197	5307	26	11D
0005435424893	5307	27	11C
0005435424818	5307	28	11G
0005435319580	5307	29	11F
0005434344428	5307	30	11K
0005435614257	5307	31	11H
0005434344402	5307	32	12C
0005435614178	5307	33	12A
0005435424576	5307	34	12E
0005435614236	5307	35	12D
0005435424477	5307	36	12G
0005435097256	5307	37	12F
0005434244837	5307	38	13A
0005435614271	5307	39	12K
0005435614203	5307	40	12H
0005432133294	5307	41	13D
0005435424847	5307	42	13C
0005435614291	5307	43	13F
0005433719119	5307	44	13E
0005435614200	5307	45	13G
0005435424798	5307	46	14A
0005435302187	5307	47	13K
0005435424676	5307	48	14D
0005435319581	5307	49	14C
0005435424671	5307	50	14G
0005435614254	5307	51	14F
0005435614315	5307	52	14E
0005435614303	5307	53	14H
0005435614226	5307	54	15C
0005432133284	5307	55	15A
0005434344409	5307	56	15F
0005432133295	5307	57	15E
0005434344434	5307	58	15D
0005434244899	5307	59	15G
0005435614232	5307	60	16A
0005435614264	5307	61	15K
0005435424811	5307	62	16C
0005435555381	5307	63	16F
0005434244898	5307	64	16K
0005434245009	5307	65	16H
0005435042837	5307	66	16G
0005432133283	5307	67	17A
0005435614224	5307	68	17E
0005435614279	5307	69	17D
0005432133290	5307	70	17C
0005435614231	5307	71	17G
0005434344426	5307	72	17F
0005434344432	5307	73	18A
0005435614280	5307	74	17K
0005435614210	5307	75	18C
0005432047568	5307	76	18B
0005435424751	5307	77	18E
0005435614281	5307	78	18D
0005435614192	5307	79	18G
0005434344415	5307	80	18F
0005434244789	5307	81	18K
0005435424518	5307	82	18J
0005434344435	5307	83	18H
0005434244829	5307	84	19B
0005434573427	5307	85	19A
0005435614290	5307	86	19C
0005434244975	5307	87	19G
0005435424621	5307	88	19F
0005433719117	5307	89	19H
0005435614177	5307	90	19K
0005434573421	5307	91	19J
0005434244838	5307	92	20B
0005434244862	5307	93	20E
0005435614228	5307	94	20D
0005435614260	5307	95	20G
0005435614204	5307	96	20F
0005435490246	5307	97	20K
0005432047569	5307	98	20J
0005435614299	5307	99	20H
0005435614294	5307	100	21A
0005435319596	5307	101	21D
0005432133281	5307	102	21C
0005435097255	5307	103	21E
0005435614277	5307	104	21H
0005435614182	5307	105	21G
0005435424848	5307	106	21K
0005432133289	5307	107	22B
0005435424574	5307	108	22F
0005434573433	5307	109	22E
0005435614215	5307	110	22D
0005434573420	5307	111	22G
0005433719139	5307	112	22K
0005435424449	5307	113	22J
0005435614255	5307	114	22H
0005434344410	5307	115	23B
0005434244738	5307	116	23D
0005435614205	5307	117	23C
0005434245008	5307	118	23F
0005435614263	5307	119	23E
0005433719127	5307	120	23J
0005435491448	5307	121	23H
0005435614242	5307	122	23K
0005435614191	5307	123	24F
0005435491449	5307	124	24E
0005434244963	5307	125	24D
0005435614258	5307	126	25B
0005434344406	5307	127	24G
0005435424536	5307	128	25D
0005435614273	5307	129	25C
0005435614198	5307	130	25F
0005434573431	5307	131	25E
0005435614193	5307	132	25J
0005435614234	5307	133	25H
0005435319582	5307	134	25G
0005435424669	5307	135	26A
0005435614274	5307	136	25K
0005434344427	5307	137	26B
0005432133293	5307	138	26E
0005435614256	5307	139	26D
0005435302184	5307	140	26C
0005435614225	5307	141	26G
0005435424456	5307	142	26F
0005434344416	5307	143	26K
0005434344423	5307	144	26J
0005434344431	5307	145	27B
0005432133292	5307	146	27A
0005434344404	5307	147	27D
0005435424805	5307	148	27C
0005435614233	5307	149	27F
0005435614221	5307	150	27E
0005435424773	5307	151	27H
0005435614186	5307	152	27G
0005435424544	5307	153	28A
0005435614306	5307	154	27K
0005435614286	5307	155	27J
0005434244863	5307	156	28C
0005432133296	5307	157	28B
0005435424861	5307	158	28E
0005435302182	5307	159	28D
0005435614189	5307	160	28G
0005434344399	5307	161	28F
0005435424894	5307	162	28H
0005435424450	5307	163	29A
0005435424677	5307	164	28K
0005435424668	5307	165	29D
0005435614265	5307	166	29C
0005434573422	5307	167	29F
0005435614305	5307	168	29J
0005435614184	5307	169	29H
0005434244869	5307	170	29G
0005434245010	5307	171	30A
0005435614308	5307	172	29K
0005435097253	5307	173	30C
0005435424578	5307	174	30E
0005434244940	5307	175	30D
0005432047570	5307	176	30G
0005435614266	5307	177	30F
0005435614272	5307	178	30K
0005433719116	5307	179	30J
0005434344412	5307	180	31A
0005432133282	5307	181	31C
0005435614217	5307	182	31B
0005434344401	5307	183	31F
0005435614216	5307	184	31E
0005435614240	5307	185	31D
0005435097254	5307	186	31H
0005434573419	5307	187	31G
0005435614287	5307	188	31K
0005434344436	5307	189	31J
0005434344417	5307	190	32B
0005435614213	5307	191	32E
0005435424622	5307	192	32D
0005435614190	5307	193	32C
0005435424435	5307	194	32G
0005435424533	5307	195	32F
0005434573426	5307	196	32J
0005435424478	5307	197	32H
0005435614278	5307	198	33B
0005435614196	5307	199	33A
0005435614241	5307	200	33D
0005435614314	5307	201	33C
0005435380286	5307	202	33F
0005435614311	5307	203	33E
0005435614296	5307	204	33J
0005435424645	5307	205	33H
0005435614292	5307	206	33G
0005434573428	5307	207	33K
0005434344413	5307	208	34B
0005435424649	5307	209	34E
0005435614238	5307	210	34D
0005435614202	5307	211	34C
0005435555380	5307	212	34G
0005435424809	5307	213	34F
0005432363403	5307	214	34K
0005435614301	5307	215	34J
0005435380287	5307	216	34H
0005435614237	5307	217	35A
0005434344421	5307	218	35D
0005434344420	5307	219	35C
0005435424613	5307	220	35B
0005435614227	5307	221	35F
0005434244857	5307	222	35E
0005435614289	5307	223	35J
0005435614285	5307	224	35G
0005435555379	5307	225	35K
0005434244756	5307	226	36B
0005435424573	5307	227	36A
0005434344418	5307	228	36F
0005435319527	5307	229	36E
0005435614282	5307	230	36D
0005435614252	5307	231	36H
0005433719138	5307	232	36K
0005435424464	5307	233	36J
0005435319477	5307	234	37C
0005435614206	5307	235	37B
0005435614229	5307	236	37A
0005435614247	5307	237	37G
0005435614295	5307	238	37F
0005434573423	5307	239	37E
0005434344400	5307	240	37J
0005434344407	5307	241	37H
0005435614250	5307	242	38A
0005435614201	5307	243	37K
0005435614183	5307	244	38C
0005435614230	5307	245	38B
0005435490248	5307	246	38K
0005435097248	5307	247	38J
0005434344419	5307	248	38H
0005435302167	5307	249	39B
0005432133291	5307	250	39A
0005435614246	5307	251	39D
0005435424520	5307	252	39C
0005435424635	5307	253	39F
0005434344424	5307	254	39E
0005434573429	5307	255	39J
0005435614259	5307	256	39H
0005435614209	5307	257	39G
0005435614235	5307	258	39K
0005435614179	5307	259	40C
0005435614223	5307	260	40F
0005435614211	5307	261	40E
0005434244960	5307	262	40D
0005435097249	5307	263	40G
0005435614180	5307	264	40K
0005435424832	5307	265	40J
0005434344414	5307	266	40H
0005434244764	5307	267	41A
0005434244836	5307	268	41D
0005434344403	5307	269	41C
0005435614302	5307	270	41F
0005435614268	5307	271	41E
0005435424521	5307	272	41J
0005434244868	5307	273	41H
0005435614249	5307	274	41G
0005435614309	5307	275	42A
0005435614269	5307	276	41K
0005435097251	5307	277	42B
0005435614187	5307	278	42D
0005435614270	5307	279	42G
0005435614181	5307	280	42J
0005435424600	5307	281	42H
0005435424774	5307	282	43B
0005435097252	5307	283	43A
0005435424750	5307	284	43D
0005435614276	5307	285	43C
0005432133286	5307	286	43F
0005435424740	5307	287	43E
0005435614288	5307	288	43H
0005435614298	5307	289	44A
0005435614214	5307	290	43K
0005435614300	5307	291	44B
0005435614199	5307	292	44E
0005434344405	5307	293	44D
0005435614248	5307	294	44C
0005435424775	5307	295	44G
0005435614220	5307	296	44F
0005435614212	5307	297	44H
0005435424667	5307	298	45B
0005435614253	5307	299	45A
0005434344433	5307	300	44K
0005435614313	5307	301	45D
0005435614244	5307	302	45C
0005434245051	5307	303	45G
0005435424546	5307	304	45F
0005435614243	5307	305	45E
0005435424716	5307	306	45H
0005435614245	5307	307	45K
0005435424575	5307	308	45J
0005434244913	5307	309	46B
0005435614267	5307	310	46A
0005434573430	5307	311	46E
0005435424607	5307	312	46D
0005435614261	5307	313	46G
0005435424688	5307	314	46F
0005435614307	5307	315	46K
0005434344425	5307	316	46J
0005432133287	5307	317	46H
0005435614283	5307	318	47C
0005434344411	5307	319	47A
0005435424661	5307	320	47G
0005434244853	5307	321	47F
0005435614304	5307	322	47E
0005435319573	5307	323	47K
0005432133288	5307	324	47H
0005434344408	5307	325	48D
0005435424812	5307	326	48C
0005435614188	5307	327	48A
0005435614239	5307	328	48E
0005435614275	5307	329	48H
0005435614219	5307	330	48G
0005435424768	5307	331	48K
0005435614284	5307	332	49D
0005434244974	5307	333	49C
0005434244788	5307	334	49G
0005435302164	5307	335	49F
0005435424250	5307	336	49E
0005434344430	5307	337	49K
0005435424545	5307	338	50C
0005435614293	5307	339	50A
0005433719130	5307	340	50F
0005434344422	5307	341	50E
0005435490247	5307	342	50D
0005435614310	5307	343	50G
0005435614312	5307	344	51D
0005434573425	5307	345	50K
0005434344429	5307	346	50H
0005435424465	5307	347	51F
0005435424285	5307	348	51E
0005435614185	5307	349	51G
0005435613323	10884	1	1C
0005435613213	10884	2	1A
0005435425152	10884	3	1G
0005435613174	10884	4	1D
0005434245139	10884	5	1K
0005434344054	10884	6	1H
0005435425182	10884	7	2C
0005434245131	10884	8	2A
0005434245125	10884	9	2H
0005435425158	10884	10	2G
0005435613313	10884	11	3A
0005435613091	10884	12	2K
0005435319621	10884	13	3D
0005435304183	10884	14	3K
0005435613062	10884	15	3H
0005434245137	10884	16	3G
0005434344014	10884	17	4C
0005435425137	10884	18	4A
0005434573217	10884	19	4D
0005435425193	10884	20	5A
0005435612944	10884	21	4H
0005434245145	10884	22	5D
0005435613040	10884	23	5G
0005435425144	10884	24	11A
0005434245129	10884	25	5K
0005434343989	10884	26	5H
0005435612948	10884	27	11C
0005435380314	10884	28	11F
0005435097200	10884	29	11E
0005435425196	10884	30	11K
0005435612945	10884	31	11H
0005435613106	10884	32	12C
0005435613363	10884	33	12A
0005435425175	10884	34	12E
0005435613200	10884	35	12H
0005435613144	10884	36	12G
0005434573308	10884	37	12F
0005434245136	10884	38	13A
0005435612720	10884	39	12K
0005435425147	10884	40	13D
0005435491429	10884	41	13G
0005433719158	10884	42	13F
0005435612553	10884	43	13E
0005435425128	10884	44	13H
0005435425134	10884	45	14A
0005433719160	10884	46	13K
0005432166919	10884	47	14D
0005434344260	10884	48	14G
0005435425176	10884	49	14F
0005435612995	10884	50	14E
0005435612971	10884	51	14H
0005435304180	10884	52	15A
0005434245143	10884	53	15E
0005435425179	10884	54	15D
0005435612775	10884	55	15G
0005434245133	10884	56	15F
0005434573281	10884	57	15K
0005435612968	10884	58	16D
0005435425131	10884	59	16C
0005435319622	10884	60	16F
0005435612929	10884	61	16E
0005434656568	10884	62	16H
0005434245142	10884	63	16G
0005435425163	10884	64	17C
0005432165078	10884	65	16K
0005435305020	10884	66	17E
0005434344158	10884	67	17D
0005435613160	10884	68	17G
0005435613355	10884	69	17F
0005434573274	10884	70	18A
0005435613090	10884	71	17K
0005435613188	10884	72	17H
0005435612797	10884	73	18C
0005435613226	10884	74	18E
0005434344026	10884	75	18D
0005435425167	10884	76	18H
0005434573295	10884	77	18G
0005434573271	10884	78	18J
0005435425166	10884	79	19B
0005434343921	10884	80	19A
0005435425129	10884	81	18K
0005435319618	10884	82	19D
0005434245127	10884	83	19C
0005434343873	10884	84	19F
0005434245140	10884	85	19E
0005435425126	10884	86	19H
0005435613108	10884	87	19G
0005435612922	10884	88	19K
0005432166920	10884	89	19J
0005432841023	10884	90	20B
0005435613061	10884	91	20A
0005435097189	10884	92	20D
0005435613370	10884	93	20C
0005435425189	10884	94	20G
0005435613240	10884	95	20F
0005435425171	10884	96	20K
0005434343997	10884	97	20J
0005435613148	10884	98	20H
0005435380313	10884	99	21B
0005435425159	10884	100	21A
0005434344038	10884	101	21C
0005435490226	10884	102	21E
0005434656567	10884	103	21J
0005435425162	10884	104	21H
0005434344071	10884	105	21G
0005434573209	10884	106	22A
0005435613279	10884	107	21K
0005435612919	10884	108	22C
0005434245130	10884	109	22E
0005435425177	10884	110	22D
0005435425173	10884	111	22G
0005434343990	10884	112	22F
0005435425138	10884	113	22K
0005435305019	10884	114	22J
0005434245119	10884	115	22H
0005435425191	10884	116	23B
0005435097201	10884	117	23A
0005435612869	10884	118	23D
0005435613187	10884	119	23C
0005435425169	10884	120	23F
0005435425168	10884	121	23E
0005435613282	10884	122	23J
0005435425180	10884	123	23H
0005435490225	10884	124	24D
0005435613003	10884	125	23K
0005435612933	10884	126	24E
0005434573235	10884	127	25A
0005435425127	10884	128	24G
0005435612921	10884	129	25D
0005435613288	10884	130	25C
0005434573242	10884	131	25F
0005435319619	10884	132	25E
0005434344039	10884	133	25H
0005435425132	10884	134	25G
0005435042865	10884	135	25K
0005432165074	10884	136	25J
0005435613257	10884	137	26C
0005435425160	10884	138	26E
0005435097157	10884	139	26D
0005435425151	10884	140	26G
0005435097171	10884	141	26F
0005435380311	10884	142	26K
0005434344070	10884	143	26J
0005434245135	10884	144	26H
0005435425148	10884	145	27B
0005435612644	10884	146	27A
0005435612994	10884	147	27C
0005435613362	10884	148	27E
0005434344116	10884	149	27J
0005435425146	10884	150	27H
0005434573208	10884	151	27G
0005435425153	10884	152	28A
0005435613011	10884	153	28C
0005434573359	10884	154	28B
0005434343973	10884	155	28E
0005435425178	10884	156	28D
0005435425150	10884	157	28F
0005435097186	10884	158	28J
0005434245120	10884	159	29A
0005435613314	10884	160	29D
0005434344156	10884	161	29C
0005435425149	10884	162	29B
0005435097123	10884	163	29F
0005434245116	10884	164	29E
0005435613366	10884	165	29H
0005434343974	10884	166	29G
0005435097179	10884	167	29K
0005435612981	10884	168	30C
0005435380312	10884	169	30B
0005432165077	10884	170	30A
0005435491433	10884	171	30E
0005434344259	10884	172	30D
0005435612495	10884	173	30G
0005435425181	10884	174	30F
0005435612552	10884	175	30J
0005434245123	10884	176	30H
0005435425157	10884	177	31A
0005435613269	10884	178	30K
0005435490212	10884	179	31C
0005435613173	10884	180	31G
0005433719157	10884	181	32A
0005435612970	10884	182	31K
0005435425164	10884	183	31J
0005435555360	10884	184	32C
0005435425172	10884	185	32B
0005432165076	10884	186	32E
0005434245126	10884	187	32D
0005435612798	10884	188	32F
0005434245146	10884	189	32J
0005435425136	10884	190	32H
0005435613324	10884	191	33A
0005435613063	10884	192	32K
0005432166918	10884	193	33C
0005434245117	10884	194	33B
0005434343872	10884	195	33F
0005434245118	10884	196	33E
0005435425140	10884	197	33H
0005432841024	10884	198	33G
0005435613365	10884	199	33K
0005434245138	10884	200	33J
0005434245134	10884	201	34C
0005435097161	10884	202	34B
0005435425141	10884	203	34A
0005435425139	10884	204	34E
0005435425192	10884	205	34D
0005435613212	10884	206	34G
0005434343923	10884	207	34F
0005435425185	10884	208	34K
0005435319615	10884	209	34H
0005434344118	10884	210	35B
0005435612859	10884	211	35A
0005435555361	10884	212	35D
0005434573268	10884	213	35F
0005435425156	10884	214	35E
0005435425143	10884	215	35H
0005434343874	10884	216	35G
0005435097147	10884	217	35K
0005435305021	10884	218	36B
0005434656566	10884	219	36E
0005435613280	10884	220	36D
0005435612822	10884	221	36G
0005435612946	10884	222	36F
0005434344052	10884	223	36J
0005435425197	10884	224	36H
0005435613250	10884	225	36K
0005434343822	10884	226	37D
0005435425170	10884	227	37C
0005435425187	10884	228	37E
0005435613175	10884	229	37H
0005435425133	10884	230	37G
0005435425188	10884	231	38A
0005434344093	10884	232	37J
0005435612821	10884	233	38C
0005435613278	10884	234	38B
0005434573279	10884	235	38K
0005434245128	10884	236	38J
0005435304182	10884	237	38H
0005435612958	10884	238	39A
0005434573234	10884	239	39D
0005435613189	10884	240	39C
0005435613058	10884	241	39B
0005432166917	10884	242	39F
0005435613128	10884	243	39E
0005435613195	10884	244	39J
0005435612950	10884	245	39H
0005434573278	10884	246	40A
0005432363432	10884	247	39K
0005435613249	10884	248	40C
0005435612719	10884	249	40E
0005434344015	10884	250	40D
0005435425161	10884	251	40H
0005435613176	10884	252	40G
0005432165073	10884	253	40F
0005435612972	10884	254	40J
0005434343786	10884	255	41A
0005435425142	10884	256	41D
0005435097173	10884	257	41C
0005435319617	10884	258	41B
0005434573280	10884	259	41G
0005435613004	10884	260	41F
0005435612918	10884	261	41E
0005435613186	10884	262	41H
0005435425135	10884	263	42A
0005435097146	10884	264	41K
0005435425184	10884	265	41J
0005434245124	10884	266	42B
0005434344027	10884	267	42E
0005435612947	10884	268	42D
0005435425195	10884	269	42G
0005435613136	10884	270	42F
0005434344170	10884	271	42J
0005434573318	10884	272	42H
0005435612984	10884	273	43B
0005434573275	10884	274	43A
0005435319620	10884	275	42K
0005435613287	10884	276	43D
0005434245122	10884	277	43C
0005433719159	10884	278	43F
0005435319616	10884	279	43E
0005435613315	10884	280	43J
0005434344180	10884	281	43H
0005435425183	10884	282	43G
0005435612858	10884	283	44A
0005435491431	10884	284	43K
0005435097159	10884	285	44C
0005434344028	10884	286	44B
0005435612979	10884	287	44E
0005435097172	10884	288	44J
0005435613178	10884	289	44H
0005435097124	10884	290	45B
0005432363433	10884	291	45A
0005432165080	10884	292	44K
0005435425194	10884	293	45D
0005434245132	10884	294	45C
0005435425154	10884	295	45F
0005432165075	10884	296	45J
0005435425130	10884	297	45H
0005435612643	10884	298	45G
0005435613055	10884	299	46A
0005434245144	10884	300	45K
0005435613149	10884	301	46B
0005435490203	10884	302	46E
0005434343922	10884	303	46D
0005435425165	10884	304	46G
0005432165079	10884	305	46K
0005435425174	10884	306	46J
0005435613130	10884	307	46H
0005435097187	10884	308	47A
0005435304181	10884	309	47D
0005435425145	10884	310	47C
0005434245141	10884	311	47G
0005434245121	10884	312	47K
0005434573283	10884	313	47H
0005435097166	10884	314	48C
0005434344117	10884	315	48A
0005435613241	10884	316	48E
0005435425155	10884	317	49A
0005435613199	10884	318	49E
0005435613190	10884	319	49D
0005435612776	10884	320	49C
0005435305022	10884	321	49F
0005435380315	10884	322	50C
0005435425186	10884	323	49K
0005435613089	10884	324	50E
0005434573286	10884	325	50D
0005435097148	10884	326	50H
0005435613143	10884	327	50G
0005434344210	10884	328	50F
0005435304179	10884	329	51D
0005435425190	10884	330	50K
0005434344157	10884	331	51F
0005434573262	10884	332	51E
0005435612781	10884	333	51G
0005433805546	3269	1	1A
0005432459790	3269	2	1C
0005432459723	3269	3	1F
0005432459698	3269	4	1D
0005433805549	3269	5	2A
0005433507279	3269	6	2C
0005433805571	3269	7	2F
0005433634000	3269	8	2D
0005432459544	3269	9	3A
0005432459812	3269	10	3D
0005432459687	3269	11	3C
0005433805548	3269	12	4A
0005433805538	3269	13	3F
0005432459420	3269	14	4D
0005433805554	3269	15	4C
0005432181828	3269	16	5A
0005433634003	3269	17	4F
0005432459443	3269	18	5D
0005432181829	3269	19	5C
0005432459731	3269	20	5F
0005433805555	3269	21	6A
0005433805545	3269	22	6D
0005433633986	3269	23	6C
0005433805552	3269	24	6F
0005433805556	3269	25	7A
0005433507284	3269	26	7D
0005433805559	3269	27	7C
0005433805562	3269	28	8A
0005433805537	3269	29	7F
0005432459842	3269	30	8B
0005432181838	3269	31	8C
0005433633987	3269	32	8E
0005433634008	3269	33	8D
0005433633990	3269	34	9A
0005433507270	3269	35	8F
0005432459396	3269	36	9B
0005432459568	3269	37	9C
0005433634007	3269	38	9D
0005432459442	3269	39	9F
0005432181830	3269	40	9E
0005433805564	3269	41	10A
0005433507273	3269	42	10B
0005433805572	3269	43	10C
0005432459672	3269	44	10E
0005432181831	3269	45	10D
0005433633998	3269	46	10F
0005433805536	3269	47	11B
0005433633984	3269	48	11A
0005433805550	3269	49	11C
0005432459728	3269	50	11D
0005433634014	3269	51	11F
0005433805568	3269	52	11E
0005433805542	3269	53	12A
0005433634013	3269	54	12B
0005433507286	3269	55	12C
0005432181833	3269	56	12E
0005433634015	3269	57	12D
0005433633995	3269	58	12F
0005433633989	3269	59	13B
0005432459679	3269	60	13A
0005432459549	3269	61	13D
0005432459748	3269	62	13E
0005432459755	3269	63	14A
0005433634004	3269	64	13F
0005432459699	3269	65	14C
0005433805553	3269	66	14B
0005432181822	3269	67	14D
0005433507271	3269	68	14E
0005432459621	3269	69	14F
0005432459686	3269	70	15B
0005432181823	3269	71	15A
0005433633997	3269	72	15C
0005433634002	3269	73	15E
0005433634005	3269	74	15D
0005433633993	3269	75	16A
0005432181832	3269	76	15F
0005433507282	3269	77	16B
0005432181839	3269	78	16D
0005433805560	3269	79	16C
0005432459839	3269	80	16E
0005432459811	3269	81	17A
0005432459771	3269	82	16F
0005433633982	3269	83	17B
0005432459461	3269	84	17E
0005432181841	3269	85	17D
0005432459616	3269	86	17F
0005433805565	3269	87	18A
0005432459462	3269	88	18C
0005433633994	3269	89	18B
0005433507272	3269	90	18D
0005433805539	3269	91	18E
0005433634001	3269	92	19B
0005433805544	3269	93	18F
0005433633992	3269	94	19C
0005432459779	3269	95	19D
0005432459716	3269	96	20A
0005433633985	3269	97	19E
0005432181827	3269	98	20C
0005433805570	3269	99	20B
0005433805566	3269	100	20D
0005432181824	3269	101	20E
0005432459680	3269	102	21B
0005432459760	3269	103	21A
0005432459620	3269	104	20F
0005432181835	3269	105	21D
0005433633988	3269	106	21C
0005432459533	3269	107	21E
0005432459497	3269	108	22A
0005432181842	3269	109	21F
0005433805561	3269	110	22B
0005432459645	3269	111	22C
0005433507283	3269	112	22E
0005433634011	3269	113	22D
0005433507275	3269	114	22F
0005433805541	3269	115	23B
0005433634010	3269	116	23D
0005432459697	3269	117	23F
0005432459395	3269	118	23E
0005433633983	3269	119	24A
0005432181825	3269	120	24B
0005432459681	3269	121	24C
0005433507277	3269	122	24E
0005433805551	3269	123	24D
0005432459722	3269	124	24F
0005432181834	3269	125	25A
0005432459543	3269	126	25B
0005433507278	3269	127	25D
0005433633999	3269	128	25C
0005432459843	3269	129	25E
0005432459575	3269	130	26A
0005432459534	3269	131	25F
0005432459596	3269	132	26B
0005433507269	3269	133	26D
0005433805567	3269	134	26C
0005432459577	3269	135	26E
0005432459717	3269	136	26F
0005433805543	3269	137	27A
0005433633991	3269	138	27B
0005433507281	3269	139	27C
0005433805569	3269	140	27E
0005432181836	3269	141	28A
0005432459491	3269	142	27F
0005433634009	3269	143	28B
0005433805547	3269	144	28C
0005433805540	3269	145	28E
0005433805563	3269	146	28D
0005432459810	3269	147	28F
0005433507276	3269	148	29A
0005432459411	3269	149	29C
0005433507280	3269	150	29B
0005433507285	3269	151	29D
0005433633996	3269	152	29F
0005432459576	3269	153	29E
0005433507274	3269	154	30A
0005432459556	3269	155	30B
0005432459759	3269	156	30D
0005432181826	3269	157	30C
0005433805557	3269	158	30E
0005433805558	3269	159	30F
0005432181840	3269	160	31B
0005432459718	3269	161	31A
0005432181837	3269	162	31C
0005433634006	3269	163	31E
0005433634012	3269	164	31D
0005435885033	3268	1	1A
0005435885160	3268	2	2C
0005435885157	3268	3	3A
0005435885021	3268	4	4A
0005435885170	3268	5	4F
0005435885256	3268	6	5F
0005435885210	3268	7	7C
0005435884914	3268	8	8D
0005435885316	3268	9	9D
0005435885112	3268	10	9F
0005435885248	3268	11	10A
0005435884851	3268	12	11D
0005435885186	3268	13	11E
0005435885113	3268	14	12C
0005435885044	3268	15	12B
0005435885250	3268	16	12F
0005435884888	3268	17	13E
0005435885161	3268	18	14A
0005435885249	3268	19	14C
0005435885209	3268	20	14E
0005435885095	3268	21	14D
0005435884890	3268	22	15A
0005435885084	3268	23	15F
0005435885140	3268	24	17E
0005435885045	3268	25	17F
0005435885094	3268	26	18C
0005435885178	3268	27	20A
0005435885213	3268	28	20E
0005435885174	3268	29	21D
0005435885167	3268	30	21F
0005435884887	3268	31	22C
0005435885022	3268	32	25B
0005435885200	3268	33	25D
0005435885301	3268	34	26E
0005435885172	3268	35	26F
0005435885048	3268	36	27C
0005435885134	3268	37	27F
0005435885049	3268	38	29C
0005435885043	3268	39	29F
0005435885055	3268	40	30A
0005435885302	3268	41	30F
0005435885173	3268	42	31C
0005435885093	3268	43	31D
0005435885502	8171	1	1C
0005435885480	8171	2	1A
0005435885516	8171	3	1D
0005435885513	8171	4	2A
0005432042788	8171	5	2C
0005432460178	8171	6	2D
0005432042794	8171	7	3A
0005435885479	8171	8	2F
0005432042782	8171	9	3D
0005432460174	8171	10	3F
0005432460147	8171	11	4C
0005435885514	8171	12	4F
0005432460163	8171	13	4D
0005435885485	8171	14	5C
0005435885517	8171	15	5A
0005432460149	8171	16	5D
0005435885515	8171	17	6A
0005432460141	8171	18	6F
0005432042781	8171	19	6D
0005432460138	8171	20	7A
0005432042792	8171	21	7D
0005435885483	8171	22	7C
0005435885477	8171	23	7F
0005435885482	8171	24	8C
0005435885478	8171	25	8B
0005435885497	8171	26	8D
0005432460166	8171	27	8E
0005432460183	8171	28	9A
0005434312332	8171	29	8F
0005435885498	8171	30	9B
0005432460144	8171	31	9C
0005435885525	8171	32	9D
0005432460136	8171	33	9E
0005433507027	8171	34	10A
0005432460151	8171	35	10B
0005432460167	8171	36	10C
0005432460182	8171	37	11A
0005435885528	8171	38	10F
0005434312331	8171	39	11C
0005432460155	8171	40	11B
0005432042795	8171	41	11D
0005435885523	8171	42	11F
0005432460179	8171	43	12A
0005435885481	8171	44	12D
0005432042789	8171	45	12C
0005432042784	8171	46	12E
0005432460164	8171	47	13A
0005432042786	8171	48	12F
0005432460154	8171	49	13B
0005433507092	8171	50	13C
0005435885518	8171	51	13E
0005432460169	8171	52	13D
0005435885484	8171	53	13F
0005435885524	8171	54	14A
0005432460148	8171	55	14B
0005435885491	8171	56	14D
0005435885489	8171	57	14C
0005432460158	8171	58	14E
0005432460180	8171	59	14F
0005435885471	8171	60	15A
0005432460153	8171	61	15C
0005432460143	8171	62	15E
0005435885519	8171	63	15D
0005432460184	8171	64	16A
0005435885476	8171	65	15F
0005435885472	8171	66	16B
0005435885486	8171	67	16D
0005435885470	8171	68	16E
0005432460132	8171	69	16F
0005433507132	8171	70	17B
0005435885494	8171	71	17A
0005432460165	8171	72	17C
0005433507126	8171	73	17D
0005435885493	8171	74	17F
0005435885508	8171	75	18A
0005433507116	8171	76	18D
0005435885521	8171	77	18E
0005432460172	8171	78	19B
0005435885501	8171	79	18F
0005432460137	8171	80	19C
0005432042785	8171	81	19D
0005432460177	8171	82	19E
0005432460133	8171	83	20B
0005432460150	8171	84	20A
0005432042791	8171	85	20D
0005432042790	8171	86	20C
0005432042793	8171	87	20F
0005435885487	8171	88	20E
0005432460139	8171	89	21A
0005435885495	8171	90	21C
0005432460170	8171	91	21B
0005432460162	8171	92	21E
0005435885505	8171	93	22A
0005435885490	8171	94	21F
0005432042783	8171	95	22B
0005432460157	8171	96	22C
0005432460175	8171	97	22E
0005435885527	8171	98	22D
0005432460145	8171	99	22F
0005432460135	8171	100	23A
0005432460142	8171	101	23E
0005435885475	8171	102	23F
0005432460161	8171	103	24B
0005432460171	8171	104	24A
0005435885473	8171	105	24C
0005432460160	8171	106	24E
0005433507100	8171	107	24F
0005432460146	8171	108	25B
0005435885510	8171	109	25C
0005435885529	8171	110	25E
0005435885522	8171	111	25F
0005432460181	8171	112	26B
0005435885507	8171	113	26D
0005435885509	8171	114	26E
0005433507119	8171	115	26F
0005432460173	8171	116	27B
0005433507117	8171	117	27C
0005432460140	8171	118	27D
0005432460168	8171	119	27F
0005435885503	8171	120	28A
0005432460159	8171	121	28B
0005432460134	8171	122	28D
0005435885499	8171	123	28F
0005432460152	8171	124	28E
0005435885511	8171	125	29A
0005435885488	8171	126	29C
0005435885500	8171	127	29B
0005435885506	8171	128	29D
0005435885512	8171	129	29F
0005432460156	8171	130	29E
0005435885526	8171	131	30D
0005432042787	8171	132	30C
0005435885496	8171	133	30E
0005435885474	8171	134	30F
0005432460176	8171	135	31B
0005435885520	8171	136	31A
0005433507094	8171	137	31C
0005435885492	8171	138	31D
0005435885504	8171	139	31F
0005433633723	8164	1	1A
0005433805133	8164	2	1F
0005433633684	8164	3	2C
0005433805183	8164	4	2D
0005433633678	8164	5	3A
0005433633744	8164	6	3F
0005433633574	8164	7	4D
0005433633593	8164	8	5A
0005433805209	8164	9	5F
0005433805252	8164	10	6C
0005433805248	8164	11	6F
0005433633585	8164	12	7D
0005433805414	8164	13	8E
0005433805087	8164	14	9D
0005433805397	8164	15	10A
0005433633759	8164	16	10B
0005433805192	8164	17	10D
0005433805382	8164	18	10E
0005433633549	8164	19	11A
0005433633587	8164	20	11C
0005433633694	8164	21	11E
0005433633632	8164	22	12B
0005433805250	8164	23	12C
0005433633683	8164	24	13A
0005433633532	8164	25	13C
0005433805275	8164	26	13B
0005433633588	8164	27	13D
0005433633672	8164	28	13F
0005434143711	8164	29	13E
0005433805191	8164	30	14C
0005434143717	8164	31	14D
0005433805193	8164	32	14F
0005433633680	8164	33	15B
0005433805251	8164	34	15C
0005433805229	8164	35	15F
0005433633575	8164	36	17A
0005433633668	8164	37	17C
0005433633701	8164	38	17D
0005433805325	8164	39	17F
0005433805357	8164	40	18A
0005433633652	8164	41	18B
0005433805283	8164	42	18E
0005433633696	8164	43	18F
0005433633741	8164	44	19C
0005434271302	8164	45	19E
0005434143724	8164	46	20C
0005433805224	8164	47	20D
0005433633758	8164	48	20F
0005433633697	8164	49	20E
0005433805348	8164	50	22B
0005433805160	8164	51	22A
0005433633673	8164	52	22C
0005433633617	8164	53	23A
0005433633551	8164	54	23D
0005433805226	8164	55	23E
0005434271303	8164	56	24A
0005433805088	8164	57	24B
0005433805184	8164	58	24D
0005433633703	8164	59	24F
0005433805174	8164	60	25D
0005433633757	8164	61	25F
0005433805210	8164	62	26D
0005433633665	8164	63	26C
0005433805211	8164	64	27C
0005433633733	8164	65	27B
0005433633608	8164	66	27F
0005433805225	8164	67	28B
0005434271307	8164	68	29A
0005433805322	8164	69	29D
0005433633718	8164	70	29F
0005434143710	8164	71	30B
0005433633653	8164	72	30E
0005433805298	8164	73	31B
0005433633700	8164	74	31A
0005433633713	8164	75	31C
0005433633681	8164	76	31E
0005434183573	8337	1	9D
0005434183580	8337	2	17D
0005432383374	4679	1	1A
0005432728009	4679	2	1D
0005432383367	4679	3	2A
0005433453771	4679	4	2C
0005433722266	4679	5	2D
0005433722256	4679	6	2F
0005432383362	4679	7	3C
0005432383395	4679	8	3F
0005432383373	4679	9	4A
0005433722267	4679	10	4C
0005432383401	4679	11	4F
0005432383375	4679	12	5A
0005432383391	4679	13	5D
0005432383369	4679	14	5E
0005432728007	4679	15	6A
0005432383399	4679	16	6C
0005433454887	4679	17	6D
0005433722259	4679	18	6E
0005432728010	4679	19	7A
0005433722263	4679	20	7C
0005432383380	4679	21	7D
0005432383377	4679	22	7E
0005432383376	4679	23	7F
0005433453770	4679	24	8A
0005432383365	4679	25	8C
0005432383372	4679	26	8D
0005433722257	4679	27	8E
0005432383382	4679	28	9A
0005432383383	4679	29	9C
0005432383363	4679	30	9D
0005432383371	4679	31	9E
0005432383396	4679	32	9F
0005432728000	4679	33	10A
0005432728006	4679	34	10C
0005432383390	4679	35	10D
0005432727998	4679	36	10E
0005432728001	4679	37	10F
0005432383359	4679	38	11A
0005433722258	4679	39	11C
0005432383397	4679	40	11D
0005432383392	4679	41	12A
0005433722255	4679	42	12C
0005432383384	4679	43	12D
0005432383394	4679	44	12E
0005432727999	4679	45	12F
0005432383360	4679	46	13A
0005432383364	4679	47	13C
0005432728003	4679	48	13D
0005432383389	4679	49	13E
0005432728005	4679	50	13F
0005432383379	4679	51	14A
0005433722268	4679	52	14C
0005433722262	4679	53	14D
0005432383378	4679	54	14F
0005432383366	4679	55	15A
0005432383385	4679	56	15C
0005432383398	4679	57	15D
0005432383388	4679	58	15E
0005432728008	4679	59	16A
0005433722261	4679	60	16C
0005433722265	4679	61	16E
0005432728004	4679	62	16F
0005432728002	4679	63	17C
0005432383381	4679	64	17D
0005432383370	4679	65	17E
0005432383386	4679	66	18A
0005433722254	4679	67	18C
0005433722264	4679	68	18E
0005433722269	4679	69	18F
0005433722260	4679	70	19A
0005432383368	4679	71	19E
0005432383387	4679	72	20A
0005432383393	4679	73	20C
0005432383400	4679	74	20D
0005432383361	4679	75	20F
0005433453759	30257	1	1A
0005432727940	30257	2	1C
0005432382926	30257	3	1F
0005432382827	30257	4	2A
0005432382925	30257	5	2D
0005432382901	30257	6	3C
0005432382780	30257	7	3D
0005432383088	30257	8	3F
0005432383075	30257	9	4A
0005432727939	30257	10	4C
0005432382844	30257	11	4D
0005432382909	30257	12	4E
0005432727883	30257	13	5A
0005432382779	30257	14	5C
0005433194843	30257	15	5D
0005432382945	30257	16	5E
0005432382978	30257	17	6E
0005432382873	30257	18	6F
0005432383001	30257	19	7A
0005432727938	30257	20	7C
0005432727923	30257	21	7D
0005432727921	30257	22	7E
0005432382902	30257	23	7F
0005432382736	30257	24	8A
0005432727900	30257	25	8C
0005432383168	30257	26	8D
0005432382977	30257	27	8E
0005432383122	30257	28	8F
0005432382908	30257	29	9A
0005432382759	30257	30	9C
0005432727914	30257	31	9D
0005432382855	30257	32	9E
0005432727795	30257	33	9F
0005432382989	30257	34	10A
0005432382921	30257	35	10D
0005432382903	30257	36	10E
0005432727924	30257	37	10F
0005432727884	30257	38	11A
0005432727919	30257	39	11E
0005432727868	30257	40	12A
0005433451609	30257	41	12D
0005432727899	30257	42	12E
0005432727916	30257	43	12F
0005432382954	30257	44	13A
0005433194855	30257	45	13C
0005432382948	30257	46	13E
0005432382859	30257	47	13F
0005432382922	30257	48	14D
0005432382881	30257	49	14F
0005432382781	30257	50	15A
0005432727920	30257	51	15C
0005432727913	30257	52	15E
0005432727877	30257	53	15F
0005432383124	30257	54	16A
0005432382755	30257	55	16C
0005432382778	30257	56	16D
0005432382900	30257	57	16E
0005432727937	30257	58	16F
0005432382787	30257	59	17A
0005432727796	30257	60	17C
0005432727878	30257	61	17E
0005432382733	30257	62	17F
0005432383074	30257	63	18A
0005432382953	30257	64	18C
0005433453760	30257	65	18E
0005432383123	30257	66	18F
0005432383002	30257	67	19A
0005432382835	30257	68	19D
0005432382947	30257	69	19E
0005432382946	30257	70	19F
0005432382777	30257	71	20A
0005432382949	30257	72	20C
0005432727942	30257	73	20D
0005433722170	30257	74	20F
0005435541119	1740	1	1A
0005435541118	1740	2	2A
0005433516934	1740	3	2D
0005432925022	1740	4	4A
0005435529375	1740	5	4C
0005435529385	1740	6	4D
0005435541120	1740	7	5A
0005435529377	1740	8	5C
0005435541126	1740	9	5D
0005435541110	1740	10	5E
0005435529373	1740	11	5F
0005435529376	1740	12	6A
0005435529384	1740	13	6C
0005432925021	1740	14	6F
0005435529378	1740	15	7A
0005433516937	1740	16	7C
0005435541124	1740	17	7D
0005432294500	1740	18	7E
0005433516938	1740	19	7F
0005435541115	1740	20	8A
0005435541112	1740	21	8C
0005435529368	1740	22	8F
0005433516933	1740	23	9A
0005435541121	1740	24	9C
0005435541122	1740	25	9E
0005435529382	1740	26	10A
0005435541117	1740	27	10C
0005435541116	1740	28	10E
0005435529379	1740	29	10F
0005435541114	1740	30	11C
0005435541129	1740	31	11D
0005435529386	1740	32	11F
0005435541123	1740	33	12D
0005435529371	1740	34	13A
0005435529383	1740	35	13C
0005435529367	1740	36	13D
0005435541130	1740	37	13F
0005435529372	1740	38	14C
0005435529374	1740	39	14D
0005433516939	1740	40	14E
0005432294499	1740	41	15A
0005435541128	1740	42	15D
0005435541131	1740	43	15E
0005433516932	1740	44	16A
0005432925025	1740	45	16C
0005435529370	1740	46	16D
0005432925036	1740	47	16E
0005435529380	1740	48	17A
0005433516935	1740	49	17C
0005433516940	1740	50	17E
0005433516936	1740	51	18A
0005432294501	1740	52	18D
0005435541127	1740	53	19A
0005435541125	1740	54	19C
0005435529387	1740	55	19D
0005435529366	1740	56	19E
0005435529381	1740	57	19F
0005435541111	1740	58	20C
0005435541113	1740	59	20E
0005435529369	1740	60	20F
0005435540899	22000	1	1A
0005432925063	22000	2	1C
0005435517850	22000	3	1D
0005435540884	22000	4	1F
0005435540872	22000	5	2A
0005435540986	22000	6	2C
0005433516826	22000	7	2D
0005435517799	22000	8	2F
0005433516824	22000	9	3A
0005435517908	22000	10	3D
0005432925060	22000	11	4A
0005432925061	22000	12	5D
0005432925064	22000	13	5F
0005435540876	22000	14	6C
0005435517842	22000	15	6D
0005435517802	22000	16	7A
0005435517843	22000	17	7D
0005435540975	22000	18	7F
0005435517780	22000	19	8C
0005435540987	22000	20	8D
0005435540954	22000	21	8E
0005435540871	22000	22	9A
0005435540944	22000	23	9C
0005435517870	22000	24	9D
0005435517853	22000	25	9F
0005433516850	22000	26	10D
0005435517909	22000	27	10E
0005435517810	22000	28	10F
0005435517801	22000	29	11D
0005435517859	22000	30	12C
0005433516816	22000	31	12D
0005435517860	22000	32	13A
0005435540938	22000	33	13C
0005435540929	22000	34	13E
0005433516825	22000	35	13F
0005435540934	22000	36	14A
0005435540915	22000	37	14D
0005435540881	22000	38	14F
0005432925062	22000	39	15C
0005433516815	22000	40	16C
0005435540882	22000	41	16D
0005435517854	22000	42	16E
0005435517841	22000	43	17A
0005435540953	22000	44	17D
0005435517835	22000	45	17E
0005435517763	22000	46	18D
0005435517875	22000	47	18E
0005435517874	22000	48	18F
0005435517836	22000	49	19D
0005435540883	22000	50	19F
0005435252664	7409	1	1A
0005435252628	7409	2	1C
0005435252608	7409	3	1D
0005434664943	7409	4	1F
0005432839202	7409	5	2A
0005434458916	7409	6	2F
0005432839203	7409	7	3A
0005432839198	7409	8	3C
0005435252593	7409	9	3D
0005434458920	7409	10	3F
0005432839190	7409	11	4A
0005434458919	7409	12	4C
0005432839201	7409	13	4D
0005434458917	7409	14	4E
0005434458913	7409	15	4F
0005432839193	7409	16	5A
0005432839184	7409	17	5C
0005432073409	7409	18	5D
0005435252643	7409	19	5E
0005432839191	7409	20	5F
0005435491439	7409	21	6A
0005435252665	7409	22	6C
0005432073408	7409	23	6D
0005432839208	7409	24	6F
0005432839186	7409	25	7A
0005435491426	7409	26	7C
0005435252609	7409	27	7D
0005435252607	7409	28	7E
0005435252547	7409	29	7F
0005432839206	7409	30	8A
0005432839205	7409	31	8C
0005432839196	7409	32	8E
0005435252610	7409	33	9A
0005435252644	7409	34	9C
0005432839200	7409	35	9D
0005432839210	7409	36	9E
0005435252683	7409	37	10A
0005432841021	7409	38	10C
0005432839194	7409	39	10D
0005435252695	7409	40	10E
0005435252594	7409	41	10F
0005435491427	7409	42	11A
0005435252546	7409	43	11C
0005432839207	7409	44	11D
0005434458904	7409	45	11F
0005432839185	7409	46	12A
0005434458914	7409	47	12C
0005432823460	7409	48	12D
0005432839188	7409	49	12E
0005432839209	7409	50	12F
0005432073407	7409	51	13A
0005434458903	7409	52	13C
0005432839189	7409	53	13D
0005432839199	7409	54	13F
0005432839192	7409	55	14A
0005432841022	7409	56	14C
0005432839197	7409	57	14D
0005435252645	7409	58	14E
0005434458915	7409	59	14F
0005432839195	7409	60	15C
0005434458910	7409	61	15D
0005435252629	7409	62	16A
0005435252575	7409	63	16C
0005434458922	7409	64	16D
0005434458912	7409	65	16E
0005432839187	7409	66	16F
0005434458923	7409	67	17A
0005434458906	7409	68	17E
0005432839211	7409	69	17F
0005432839182	7409	70	18A
0005434458911	7409	71	18C
0005434458909	7409	72	18D
0005434458907	7409	73	18E
0005434458902	7409	74	18F
0005432823458	7409	75	19A
0005432823459	7409	76	19C
0005434458905	7409	77	19D
0005434458921	7409	78	19E
0005435252646	7409	79	19F
0005434458908	7409	80	20A
0005432839204	7409	81	20C
0005432839183	7409	82	20D
0005434458918	7409	83	20F
0005432838961	28928	1	1A
0005434458783	28928	2	1C
0005435491450	28928	3	1D
0005435252800	28928	4	1F
0005432839027	28928	5	2A
0005432838946	28928	6	2C
0005435252796	28928	7	2D
0005432823438	28928	8	2F
0005435252792	28928	9	3A
0005434458796	28928	10	3C
0005432838974	28928	11	3D
0005434458805	28928	12	3F
0005435252795	28928	13	4A
0005432838993	28928	14	4C
0005435252784	28928	15	4D
0005432839060	28928	16	4E
0005435252802	28928	17	4F
0005434458657	28928	18	5A
0005432838968	28928	19	5C
0005432839000	28928	20	5D
0005432838950	28928	21	5E
0005435252798	28928	22	5F
0005435491451	28928	23	6A
0005435252801	28928	24	6C
0005432838992	28928	25	6D
0005434458773	28928	26	6E
0005432838798	28928	27	6F
0005432838884	28928	28	7A
0005434458668	28928	29	7C
0005432841006	28928	30	7D
0005432001033	28928	31	7E
0005432841015	28928	32	8A
0005435252787	28928	33	8D
0005434458620	28928	34	8E
0005432838971	28928	35	8F
0005434458708	28928	36	9A
0005434664972	28928	37	9C
0005432838975	28928	38	9D
0005435252789	28928	39	9E
0005434458789	28928	40	9F
0005432001035	28928	41	10A
0005432838972	28928	42	10C
0005434458790	28928	43	10D
0005435252793	28928	44	10E
0005432838770	28928	45	11A
0005432841003	28928	46	11E
0005434458715	28928	47	12C
0005435252785	28928	48	12D
0005432839012	28928	49	12E
0005435252794	28928	50	12F
0005432839010	28928	51	13C
0005434458774	28928	52	13D
0005432839074	28928	53	13E
0005432838977	28928	54	13F
0005434458827	28928	55	14A
0005435252790	28928	56	14C
0005432838994	28928	57	14D
0005432839035	28928	58	14E
0005434458697	28928	59	14F
0005432001034	28928	60	15A
0005434458772	28928	61	15D
0005435252799	28928	62	15E
0005434458716	28928	63	15F
0005432838954	28928	64	16A
0005432839061	28928	65	16C
0005434458752	28928	66	16D
0005434458696	28928	67	17A
0005434458718	28928	68	17C
0005434664973	28928	69	17D
0005434458717	28928	70	17E
0005435252791	28928	71	17F
0005434458714	28928	72	18A
0005434664971	28928	73	18C
0005432838769	28928	74	18D
0005435252797	28928	75	18E
0005432839026	28928	76	18F
0005432838885	28928	77	19A
0005435491452	28928	78	19D
0005435252786	28928	79	20A
0005432823437	28928	80	20C
0005435252788	28928	81	20E
0005434458806	28928	82	20F
0005434276016	8787	1	2F
0005434276005	8787	2	6C
0005434276012	8787	3	8A
0005435990658	8787	4	10B
0005434276011	8787	5	12B
0005434276013	8787	6	12A
0005435990663	8787	7	13C
0005435990662	8787	8	14D
0005435990661	8787	9	15F
0005435990659	8787	10	16F
0005435990660	8787	11	19C
0005434276015	8787	12	20B
0005435990602	15754	1	3A
0005435990579	15754	2	4D
0005435990593	15754	3	5F
0005434276056	15754	4	5D
0005434276057	15754	5	8B
0005435990603	15754	6	8C
0005434276058	15754	7	9C
0005435990592	15754	8	10D
0005434276059	15754	9	13B
0005434276054	15754	10	13F
0005434276055	15754	11	15D
0005435990615	15754	12	16A
0005435990580	15754	13	16F
0005435990591	15754	14	16E
0005435990619	15754	15	17F
0005433476889	20616	1	1C
0005433476875	20616	2	2B
0005432427154	20616	3	3D
0005433476874	20616	4	4C
0005433476888	20616	5	19B
0005433476887	20616	6	20A
0005432427153	20616	7	20B
0005432427152	20616	8	21B
0005432427151	20616	9	22C
0005433476890	20616	10	23B
0005432427136	30845	1	1B
0005433476902	30845	2	3D
0005433476901	30845	3	4A
0005433476903	30845	4	5B
0005433476904	30845	5	5D
0005433476906	30845	6	6A
0005432427133	30845	7	6C
0005432427137	30845	8	7C
0005433476905	30845	9	18D
0005432360629	6410	1	1C
0005432360597	6410	2	1A
0005432360626	6410	3	1D
0005432360592	6410	4	2C
0005435177005	6410	5	2A
0005435177018	6410	6	2D
0005432360599	6410	7	2F
0005435176993	6410	8	3A
0005432360630	6410	9	3F
0005432360598	6410	10	3D
0005432360608	6410	11	4B
0005435177147	6410	12	4D
0005432062256	6410	13	4C
0005432336093	6410	14	4E
0005435177101	6410	15	5A
0005435177087	6410	16	4F
0005432360589	6410	17	5C
0005435176990	6410	18	5B
0005432360625	6410	19	5D
0005435177109	6410	20	5E
0005432360591	6410	21	6A
0005435177014	6410	22	5F
0005432360637	6410	23	6B
0005432062255	6410	24	6C
0005435177024	6410	25	6D
0005432360610	6410	26	6F
0005434149630	6410	27	6E
0005435177006	6410	28	7A
0005435177100	6410	29	7B
0005432360590	6410	30	7C
0005432062259	6410	31	7E
0005435176995	6410	32	7F
0005432360632	6410	33	8B
0005432336095	6410	34	8A
0005432360603	6410	35	8C
0005432360601	6410	36	8E
0005432360622	6410	37	8F
0005435177030	6410	38	9A
0005432363432	6410	39	9B
0005432360605	6410	40	9C
0005432360600	6410	41	9D
0005435176996	6410	42	10B
0005432336096	6410	43	10C
0005432360621	6410	44	10E
0005432360614	6410	45	10D
0005435177065	6410	46	11B
0005432336099	6410	47	11D
0005432336098	6410	48	11C
0005435177017	6410	49	11E
0005432336094	6410	50	11F
0005432336100	6410	51	12B
0005435177015	6410	52	12A
0005435177059	6410	53	12D
0005435723035	6410	54	12E
0005435176994	6410	55	12F
0005432360595	6410	56	13A
0005432360613	6410	57	13C
0005435176821	6410	58	13B
0005435176929	6410	59	14A
0005432360596	6410	60	13F
0005435177056	6410	61	14C
0005432360606	6410	62	14D
0005432360618	6410	63	14E
0005435490212	6410	64	15A
0005432360628	6410	65	14F
0005434149662	6410	66	15C
0005432360615	6410	67	15B
0005432360617	6410	68	15F
0005435177031	6410	69	15E
0005435176823	6410	70	16A
0005432360634	6410	71	16C
0005435176935	6410	72	16D
0005432363433	6410	73	16F
0005432360633	6410	74	16E
0005432360604	6410	75	17B
0005432062257	6410	76	17C
0005435176822	6410	77	17E
0005432360593	6410	78	17F
0005432062258	6410	79	18A
0005435177002	6410	80	18C
0005435490203	6410	81	18E
0005434149675	6410	82	19A
0005432360623	6410	83	18F
0005432360636	6410	84	19B
0005432360627	6410	85	19C
0005432360631	6410	86	19F
0005434149684	6410	87	19E
0005435723036	6410	88	20A
0005432360607	6410	89	20C
0005432360619	6410	90	20B
0005432360638	6410	91	20D
0005432360594	6410	92	20E
0005432360624	6410	93	20F
0005435177013	6410	94	21B
0005435490225	6410	95	21A
0005435490226	6410	96	21C
0005432336097	6410	97	21D
0005432360612	6410	98	21E
0005432360609	6410	99	22A
0005432360611	6410	100	21F
0005435176989	6410	101	22B
0005435177025	6410	102	22C
0005432360635	6410	103	22D
0005435176992	6410	104	22E
0005432360602	6410	105	23A
0005432336101	6410	106	22F
0005432360616	6410	107	23B
0005432360620	6410	108	23D
0005432336092	6410	109	23F
0005432360290	21007	1	1A
0005432360229	21007	2	1C
0005435177225	21007	3	1D
0005435177210	21007	4	1F
0005432335976	21007	5	2C
0005432360213	21007	6	2A
0005432360287	21007	7	2D
0005435177228	21007	8	2F
0005432363418	21007	9	3C
0005435177224	21007	10	3A
0005432363411	21007	11	3D
0005435177219	21007	12	3F
0005435177221	21007	13	4A
0005432360204	21007	14	4C
0005432363420	21007	15	4B
0005432360288	21007	16	4E
0005432360496	21007	17	4F
0005434149786	21007	18	5B
0005432360272	21007	19	5C
0005432360497	21007	20	5D
0005432052761	21007	21	5E
0005432336031	21007	22	6A
0005434149795	21007	23	6B
0005435177220	21007	24	6D
0005435177217	21007	25	6E
0005435490252	21007	26	6F
0005432360053	21007	27	7C
0005432360244	21007	28	7B
0005432360422	21007	29	7D
0005432336003	21007	30	7F
0005432360291	21007	31	7E
0005435177218	21007	32	8A
0005432360072	21007	33	8B
0005432336030	21007	34	8D
0005434149790	21007	35	8E
0005435177215	21007	36	9A
0005432363408	21007	37	9C
0005432363401	21007	38	9B
0005432360289	21007	39	9D
0005432360118	21007	40	9E
0005432336036	21007	41	9F
0005435177205	21007	42	10B
0005435177213	21007	43	10D
0005432360277	21007	44	10C
0005435177208	21007	45	10E
0005435177207	21007	46	11A
0005432360369	21007	47	11B
0005432360210	21007	48	11D
0005432360047	21007	49	11C
0005435177212	21007	50	11E
0005432363406	21007	51	11F
0005435490250	21007	52	12B
0005434149787	21007	53	12C
0005432360278	21007	54	12D
0005432360157	21007	55	12E
0005432359921	21007	56	12F
0005432360070	21007	57	13A
0005432360254	21007	58	13B
0005435177226	21007	59	13E
0005435177227	21007	60	13F
0005435177206	21007	61	14B
0005434149789	21007	62	14A
0005432052760	21007	63	14C
0005435177211	21007	64	14D
0005432360260	21007	65	14E
0005432360121	21007	66	14F
0005432363419	21007	67	15B
0005432360211	21007	68	15C
0005432360212	21007	69	15D
0005432360155	21007	70	15E
0005435177230	21007	71	16A
0005432360243	21007	72	15F
0005435177222	21007	73	16C
0005432360127	21007	74	16B
0005432335998	21007	75	16D
0005432360153	21007	76	16E
0005432363407	21007	77	17A
0005435490249	21007	78	16F
0005432360305	21007	79	17B
0005432360245	21007	80	17C
0005432335931	21007	81	17F
0005435177209	21007	82	17E
0005434149792	21007	83	18A
0005432360194	21007	84	18B
0005435177232	21007	85	18D
0005432360423	21007	86	18C
0005432360156	21007	87	18F
0005434149785	21007	88	19A
0005434149793	21007	89	19B
0005432052762	21007	90	19D
0005432363410	21007	91	19C
0005432360232	21007	92	19F
0005432363421	21007	93	19E
0005432360002	21007	94	20A
0005435177214	21007	95	20C
0005435490251	21007	96	20E
0005435177229	21007	97	20D
0005434149791	21007	98	21A
0005432360235	21007	99	20F
0005435177216	21007	100	21B
0005434149788	21007	101	21D
0005432336004	21007	102	21C
0005432336043	21007	103	21E
0005432360193	21007	104	22A
0005432360087	21007	105	21F
0005432360071	21007	106	22C
0005432336044	21007	107	22D
0005432363422	21007	108	22E
0005435177231	21007	109	23A
0005432360021	21007	110	22F
0005435177223	21007	111	23B
0005434149794	21007	112	23D
0005432360003	21007	113	23C
0005432336005	21007	114	23E
0005434149796	21007	115	23F
0005434458743	17726	1	1A
0005434458765	17726	2	1B
0005434186214	17726	3	1C
0005434458738	17726	4	1D
0005434458740	17726	5	2A
0005434458723	17726	6	3A
0005434458795	17726	7	3B
0005434463916	17726	8	3C
0005434458728	17726	9	3D
0005434448312	17726	10	4B
0005434463915	17726	11	4C
0005434458816	17726	12	4D
0005434458724	17726	13	5A
0005434458850	17726	14	6B
0005434458721	17726	15	6C
0005434458691	17726	16	6D
0005434186215	17726	17	7A
0005434463921	17726	18	7D
0005434463917	17726	19	18B
0005434458679	17726	20	18C
0005434458707	17726	21	18D
0005434463929	17726	22	19A
0005434458692	17726	23	19B
0005434458722	17726	24	20A
0005434463926	17726	25	20B
0005434458730	17726	26	20D
0005434458784	17726	27	21C
0005434458729	17726	28	21D
0005434458830	17726	29	22A
0005434448296	17726	30	22B
0005434458770	17726	31	22C
0005434458739	17726	32	23A
0005434458812	17726	33	23B
0005434462798	29109	1	1A
0005434458912	29109	2	1B
0005434463937	29109	3	1C
0005434448331	29109	4	1D
0005434458910	29109	5	2B
0005434186181	29109	6	2C
0005434458902	29109	7	2D
0005434186194	29109	8	3A
0005434458916	29109	9	4A
0005434462799	29109	10	4C
0005434462800	29109	11	4D
0005434458919	29109	12	5B
0005434448330	29109	13	5C
0005434458909	29109	14	5D
0005434458906	29109	15	6A
0005434458904	29109	16	6C
0005434463938	29109	17	6D
0005434186195	29109	18	7B
0005434458922	29109	19	7C
0005434458923	29109	20	18A
0005434458921	29109	21	18B
0005434458908	29109	22	18C
0005434448329	29109	23	18D
0005434458911	29109	24	19A
0005434458914	29109	25	19D
0005434458915	29109	26	20A
0005434463939	29109	27	20D
0005434462801	29109	28	21A
0005434458918	29109	29	21C
0005434458903	29109	30	21D
0005434458917	29109	31	22A
0005434458913	29109	32	22B
0005434458920	29109	33	22C
0005434458907	29109	34	23A
0005434458905	29109	35	23B
0005432604507	21453	1	1A
0005432604531	21453	2	1B
0005432604511	21453	3	1C
0005432604527	21453	4	2A
0005432604523	21453	5	2B
0005432604521	21453	6	2C
0005435218110	21453	7	2D
0005432604533	21453	8	3A
0005432604508	21453	9	3C
0005432604515	21453	10	4B
0005435218111	21453	11	4A
0005432604530	21453	12	4C
0005432604529	21453	13	4D
0005432604519	21453	14	5A
0005432604532	21453	15	5B
0005432604494	21453	16	5C
0005432604518	21453	17	5D
0005432604528	21453	18	6A
0005432604495	21453	19	6D
0005432604509	21453	20	7A
0005432604517	21453	21	7B
0005432604513	21453	22	7C
0005432604525	21453	23	7D
0005432604497	21453	24	18A
0005432604504	21453	25	18B
0005432604522	21453	26	18C
0005432604500	21453	27	18D
0005432604502	21453	28	19A
0005432604526	21453	29	19B
0005432604499	21453	30	19C
0005432604514	21453	31	20A
0005432604506	21453	32	20C
0005432604516	21453	33	21A
0005432604498	21453	34	21B
0005432604512	21453	35	21C
0005432604520	21453	36	21D
0005432604501	21453	37	22A
0005432604496	21453	38	22B
0005432604510	21453	39	22C
0005432604503	21453	40	22D
0005432604524	21453	41	23A
0005432604505	21453	42	23B
0005432604327	31655	1	1B
0005432604217	31655	2	1C
0005432604215	31655	3	2C
0005432604125	31655	4	2D
0005432604123	31655	5	3A
0005432604116	31655	6	3B
0005432604216	31655	7	3D
0005432604176	31655	8	4A
0005432604174	31655	9	4B
0005432604202	31655	10	4C
0005432604075	31655	11	4D
0005432604164	31655	12	5B
0005432604250	31655	13	5C
0005432604251	31655	14	5D
0005432604124	31655	15	6A
0005432604328	31655	16	6B
0005432604115	31655	17	6C
0005432603991	31655	18	6D
0005432604089	31655	19	7B
0005432603940	31655	20	7D
0005432604312	31655	21	18A
0005432604126	31655	22	18B
0005435221520	31655	23	18C
0005432604173	31655	24	18D
0005432604254	31655	25	19D
0005432604203	31655	26	20A
0005432604321	31655	27	20B
0005432604255	31655	28	20C
0005435221521	31655	29	20D
0005432604189	31655	30	21A
0005432604163	31655	31	21B
0005435221060	31655	32	21C
0005435221061	31655	33	22A
0005432604188	31655	34	22B
0005432604165	31655	35	22C
0005432604088	31655	36	22D
0005432604187	31655	37	23A
0005432604150	31655	38	23B
0005433293200	12319	1	1C
0005433293220	12319	2	2C
0005433293194	12319	3	3B
0005435154599	12319	4	6A
0005433293195	12319	5	6B
0005433293226	12319	6	18A
0005433293221	12319	7	19A
0005433293208	12319	8	19D
0005433293205	12319	9	20A
0005433293206	12319	10	20B
0005433293199	12319	11	20D
0005433293211	12319	12	22A
0005433293227	12319	13	22B
0005434606813	18859	1	2A
0005434606812	18859	2	1B
0005434606805	18859	3	3A
0005434606818	18859	4	3B
0005434606804	18859	5	4A
0005434606789	18859	6	4B
0005434603019	18859	7	5A
0005434606803	18859	8	5B
0005434606817	18859	9	6B
0005434606839	22300	1	1A
0005434604911	22300	2	1B
0005434606840	22300	3	2A
0005434604909	22300	4	2B
0005434604913	22300	5	3A
0005434604912	22300	6	3B
0005434604910	22300	7	4A
0005434606844	22300	8	4B
0005434606843	22300	9	5A
0005434606841	22300	10	5B
0005434606842	22300	11	6A
0005434604914	22300	12	6B
0005432890992	388	1	1A
0005432747750	388	2	1C
0005435154601	388	3	2A
0005432890923	388	4	2C
0005432747741	388	5	2D
0005433293233	388	6	2F
0005432891017	388	7	3A
0005432747766	388	8	3C
0005432747764	388	9	3D
0005432747754	388	10	3F
0005433293216	388	11	4A
0005432747758	388	12	4C
0005432220025	388	13	4E
0005432747744	388	14	5A
0005432749794	388	15	5D
0005432747735	388	16	5E
0005432747745	388	17	5F
0005433293230	388	18	6C
0005432747765	388	19	6D
0005432747753	388	20	6E
0005432747737	388	21	6F
0005432890958	388	22	7A
0005432747736	388	23	7C
0005432747761	388	24	7D
0005435154600	388	25	7F
0005432747748	388	26	8A
0005432747752	388	27	8C
0005432747755	388	28	8D
0005432747746	388	29	8F
0005432747738	388	30	8E
0005432220023	388	31	9C
0005432747769	388	32	9D
0005432747760	388	33	9F
0005432747756	388	34	10A
0005432747734	388	35	10C
0005432747740	388	36	10D
0005433293235	388	37	10E
0005432747770	388	38	10F
0005432747771	388	39	11A
0005433293241	388	40	11C
0005432220024	388	41	11D
0005432747759	388	42	11E
0005433293234	388	43	12A
0005432753316	388	44	12C
0005432747747	388	45	12D
0005433293240	388	46	12E
0005432749793	388	47	12F
0005432751539	388	48	13A
0005432749795	388	49	13C
0005432890890	388	50	13E
0005433293239	388	51	14C
0005432751541	388	52	14D
0005432747762	388	53	14E
0005432890891	388	54	14F
0005432220022	388	55	15A
0005432890993	388	56	15C
0005432747767	388	57	15E
0005433293215	388	58	15F
0005433293214	388	59	16C
0005432753315	388	60	16D
0005432747732	388	61	17A
0005433293219	388	62	17D
0005433293232	388	63	17E
0005432747751	388	64	17F
0005432747739	388	65	18A
0005432747742	388	66	18C
0005432890952	388	67	18D
0005432747768	388	68	18F
0005432747757	388	69	19C
0005432890989	388	70	19D
0005432747733	388	71	19E
0005432747743	388	72	19F
0005432747749	388	73	20A
0005432747763	388	74	20C
0005432890915	388	75	20E
0005432751540	388	76	20F
0005432891121	12033	1	1A
0005432747415	12033	2	1D
0005432747519	12033	3	1F
0005432747388	12033	4	2A
0005432747381	12033	5	2C
0005432747435	12033	6	2D
0005432747414	12033	7	2F
0005432747492	12033	8	3A
0005432747401	12033	9	3C
0005432747434	12033	10	3D
0005432747488	12033	11	3F
0005433293274	12033	12	4A
0005433293280	12033	13	4C
0005432747400	12033	14	4D
0005433293278	12033	15	4E
0005432891126	12033	16	4F
0005433293271	12033	17	5A
0005432747524	12033	18	5C
0005433293275	12033	19	5D
0005432747440	12033	20	5E
0005432891125	12033	21	5F
0005432214815	12033	22	6A
0005433293265	12033	23	6C
0005432753279	12033	24	6D
0005433293284	12033	25	6E
0005432214813	12033	26	6F
0005432747504	12033	27	7A
0005433293272	12033	28	7C
0005432747507	12033	29	7D
0005433875390	12033	30	7E
0005432891127	12033	31	7F
0005432891113	12033	32	8A
0005433293279	12033	33	8C
0005432747389	12033	34	8D
0005432747642	12033	35	8E
0005432747489	12033	36	8F
0005433293285	12033	37	9A
0005432214816	12033	38	9C
0005432891115	12033	39	9D
0005432891116	12033	40	9E
0005432747460	12033	41	9F
0005433293283	12033	42	10C
0005432747442	12033	43	10D
0005433875389	12033	44	10E
0005432747511	12033	45	10F
0005432753298	12033	46	11A
0005433293269	12033	47	11C
0005432891117	12033	48	11D
0005432747538	12033	49	11E
0005432891118	12033	50	11F
0005432891124	12033	51	12A
0005432747274	12033	52	12C
0005432747467	12033	53	12D
0005432747396	12033	54	12E
0005432891128	12033	55	12F
0005432747531	12033	56	13A
0005433293277	12033	57	13D
0005432756834	12033	58	13E
0005433293270	12033	59	13F
0005432747512	12033	60	14A
0005432747266	12033	61	14D
0005432891120	12033	62	14E
0005433293267	12033	63	14F
0005433293273	12033	64	15A
0005432891114	12033	65	15C
0005432747441	12033	66	15D
0005432747493	12033	67	15F
0005432747539	12033	68	16A
0005433293276	12033	69	16C
0005433293266	12033	70	16D
0005432747382	12033	71	16E
0005432891129	12033	72	16F
0005432747368	12033	73	17A
0005432747562	12033	74	17C
0005432891111	12033	75	17D
0005433293268	12033	76	17E
0005433293281	12033	77	17F
0005432747378	12033	78	18C
0005432747523	12033	79	18D
0005432891130	12033	80	18E
0005432891123	12033	81	18F
0005432747481	12033	82	19A
0005433293282	12033	83	19C
0005432891119	12033	84	19D
0005432747537	12033	85	19E
0005432747379	12033	86	19F
0005432214814	12033	87	20A
0005432891112	12033	88	20C
0005432891122	12033	89	20D
0005432747540	12033	90	20E
0005432747513	12033	91	20F
0005432927966	18951	1	1A
0005432927943	18951	2	1B
0005433525090	18951	3	1C
0005433531310	18951	4	1D
0005433533324	18951	5	2A
0005432927970	18951	6	3A
0005433525081	18951	7	3C
0005432927942	18951	8	4B
0005433525089	18951	9	4C
0005433525082	18951	10	5A
0005433525080	18951	11	6A
0005433531307	18951	12	6B
0005433525088	18951	13	6D
0005432927941	18951	14	7B
0005433525092	18951	15	7C
0005433533323	18951	16	7D
0005433531309	18951	17	18C
0005433531308	18951	18	19A
0005433525087	18951	19	19B
0005433533325	18951	20	19D
0005433525085	18951	21	20B
0005433525083	18951	22	20D
0005433525091	18951	23	21A
0005432927971	18951	24	21B
0005432927967	18951	25	21D
0005433525086	18951	26	22C
0005433525084	18951	27	23B
0005433524974	32488	1	1A
0005433527235	32488	2	1D
0005432928017	32488	3	2B
0005433531273	32488	4	2D
0005432928014	32488	5	3A
0005433531289	32488	6	3B
0005433531283	32488	7	3D
0005433531281	32488	8	4A
0005432928013	32488	9	4B
0005433524979	32488	10	4C
0005433524995	32488	11	5B
0005433524992	32488	12	5D
0005432928015	32488	13	6B
0005433525010	32488	14	6D
0005433527236	32488	15	7B
0005433525009	32488	16	7C
0005432928011	32488	17	7D
0005433527243	32488	18	18B
0005433531303	32488	19	18C
0005433525024	32488	20	18D
0005433527244	32488	21	19A
0005433524993	32488	22	19C
0005433531302	32488	23	19D
0005433524975	32488	24	20B
0005433525015	32488	25	20C
0005433525014	32488	26	21A
0005432928012	32488	27	21B
0005433524991	32488	28	21C
0005432928016	32488	29	23B
0005434824291	5275	1	1D
0005435372770	5275	2	1A
0005434558324	5275	3	1G
0005435373046	5275	4	1K
0005435372921	5275	5	2D
0005435661913	5275	6	2C
0005434824205	5275	7	2A
0005434824172	5275	8	2G
0005435150097	5275	9	3A
0005434824271	5275	10	2H
0005434824217	5275	11	3D
0005434824297	5275	12	3K
0005435661914	5275	13	3H
0005434824241	5275	14	4A
0005434824242	5275	15	4G
0005432823448	5275	16	4C
0005435372907	5275	17	4K
0005435372797	5275	18	5D
0005432121403	5275	19	5C
0005434824246	5275	20	5A
0005432823434	5275	21	5H
0005434824274	5275	22	5G
0005434824174	5275	23	11A
0005434824224	5275	24	5K
0005434824294	5275	25	11D
0005435373013	5275	26	11F
0005434824286	5275	27	11E
0005435372906	5275	28	11K
0005435299733	5275	29	11G
0005434824267	5275	30	12F
0005435386554	5275	31	12E
0005434824251	5275	32	12D
0005435373037	5275	33	12H
0005434824218	5275	34	12G
0005432396266	5275	35	12K
0005435372888	5275	36	13C
0005432121406	5275	37	13F
0005435372880	5275	38	13E
0005435373256	5275	39	13H
0005434558311	5275	40	13G
0005432823441	5275	41	14A
0005434824264	5275	42	13K
0005434824275	5275	43	14D
0005435299765	5275	44	14C
0005435372664	5275	45	14F
0005434824170	5275	46	14H
0005434824255	5275	47	14G
0005435304145	5275	48	15C
0005434824284	5275	49	15A
0005434824263	5275	50	15E
0005434824212	5275	51	15D
0005435386546	5275	52	15G
0005434824193	5275	53	15F
0005434558318	5275	54	15K
0005434824289	5275	55	16C
0005434824206	5275	56	16F
0005435150094	5275	57	16E
0005435304141	5275	58	16K
0005435373048	5275	59	16G
0005435179689	5275	60	17C
0005434824237	5275	61	17A
0005435373203	5275	62	17G
0005434824204	5275	63	17F
0005434824254	5275	64	17K
0005435299751	5275	65	17H
0005434824169	5275	66	18C
0005434824269	5275	67	18B
0005434824287	5275	68	18A
0005434824220	5275	69	18D
0005434824285	5275	70	18F
0005432396264	5275	71	18E
0005432121411	5275	72	18H
0005434824177	5275	73	19B
0005434558313	5275	74	19A
0005435386536	5275	75	19D
0005434824229	5275	76	19H
0005434824225	5275	77	19K
0005432823439	5275	78	20C
0005435372612	5275	79	20B
0005435735121	5275	80	20A
0005434824233	5275	81	20D
0005434824281	5275	82	20F
0005434831170	5275	83	20K
0005434824197	5275	84	20J
0005435373009	5275	85	20H
0005435386563	5275	86	21B
0005434824276	5275	87	21A
0005435372988	5275	88	21G
0005434824261	5275	89	21E
0005434824249	5275	90	21J
0005434824200	5275	91	22D
0005435373187	5275	92	22F
0005434831172	5275	93	22E
0005435150105	5275	94	22G
0005434824182	5275	95	22K
0005434824219	5275	96	22H
0005435299776	5275	97	23B
0005434824260	5275	98	23C
0005435299758	5275	99	23K
0005434824234	5275	100	24F
0005434824226	5275	101	25D
0005434558316	5275	102	25C
0005435386562	5275	103	25F
0005434824185	5275	104	25E
0005434824232	5275	105	25H
0005432121402	5275	106	25J
0005435372856	5275	107	26C
0005434824290	5275	108	26B
0005434831171	5275	109	26A
0005434824256	5275	110	26E
0005435372834	5275	111	26D
0005434824288	5275	112	26G
0005435150095	5275	113	26F
0005435373031	5275	114	26K
0005434824203	5275	115	27B
0005434824201	5275	116	27A
0005434824199	5275	117	27D
0005434558322	5275	118	27C
0005435299759	5275	119	27E
0005432396265	5275	120	27H
0005435299782	5275	121	28A
0005435373001	5275	122	27K
0005432121400	5275	123	27J
0005434824168	5275	124	28C
0005435373072	5275	125	28B
0005432121412	5275	126	28E
0005432394126	5275	127	28D
0005434824179	5275	128	28G
0005432121404	5275	129	28F
0005434824253	5275	130	28K
0005434824296	5275	131	28J
0005434824298	5275	132	28H
0005435373162	5275	133	29A
0005434824282	5275	134	29D
0005435150102	5275	135	29C
0005435372966	5275	136	29E
0005434824208	5275	137	29J
0005434824266	5275	138	29G
0005435373249	5275	139	30A
0005435299764	5275	140	29K
0005435150093	5275	141	30C
0005435372997	5275	142	30B
0005432121413	5275	143	30E
0005434824240	5275	144	30D
0005435299753	5275	145	30G
0005432394125	5275	146	30F
0005434824262	5275	147	30J
0005434824176	5275	148	30K
0005432121407	5275	149	31C
0005435386547	5275	150	31F
0005434824184	5275	151	31E
0005434824293	5275	152	31H
0005435150101	5275	153	32A
0005434824268	5275	154	31K
0005434824223	5275	155	31J
0005434824171	5275	156	32B
0005434824247	5275	157	32E
0005434824178	5275	158	32H
0005435299775	5275	159	32G
0005434824214	5275	160	33D
0005434824194	5275	161	33C
0005435299768	5275	162	33F
0005434824195	5275	163	33G
0005434558320	5275	164	34C
0005435373323	5275	165	34B
0005435372832	5275	166	34E
0005435372987	5275	167	34D
0005434831169	5275	168	34H
0005434824259	5275	169	34K
0005435150099	5275	170	34J
0005435373000	5275	171	35D
0005434824239	5275	172	35C
0005434824252	5275	173	35G
0005434824279	5275	174	35F
0005434824181	5275	175	35E
0005434824243	5275	176	35H
0005434824273	5275	177	36A
0005435304140	5275	178	36E
0005432396263	5275	179	36D
0005434824227	5275	180	36G
0005435150096	5275	181	36K
0005434824283	5275	182	36J
0005434828710	5275	183	36H
0005434824236	5275	184	37B
0005434824235	5275	185	37A
0005434824192	5275	186	37D
0005434824209	5275	187	37F
0005434824258	5275	188	37E
0005434824198	5275	189	37G
0005434824238	5275	190	38A
0005434558323	5275	191	37J
0005435373022	5275	192	38B
0005435372513	5275	193	38H
0005434824280	5275	194	39A
0005434824248	5275	195	38K
0005434824265	5275	196	39C
0005434824250	5275	197	39B
0005434824270	5275	198	39E
0005434824245	5275	199	39D
0005434824216	5275	200	39J
0005435372924	5275	201	39H
0005435150104	5275	202	39G
0005432396262	5275	203	40A
0005434824196	5275	204	39K
0005434824244	5275	205	40C
0005435372932	5275	206	40F
0005434828709	5275	207	40D
0005434824230	5275	208	40H
0005434824222	5275	209	40J
0005435372920	5275	210	41B
0005435372917	5275	211	41D
0005432394124	5275	212	41C
0005435299769	5275	213	41G
0005434558314	5275	214	41E
0005435372963	5275	215	41J
0005432394127	5275	216	42A
0005435299763	5275	217	41K
0005434558312	5275	218	42C
0005434824190	5275	219	42B
0005434824188	5275	220	42E
0005434824295	5275	221	42D
0005434828708	5275	222	42H
0005435304139	5275	223	42G
0005434824211	5275	224	42F
0005434824257	5275	225	42K
0005435373047	5275	226	43A
0005434824180	5275	227	43D
0005434824272	5275	228	43B
0005434558317	5275	229	43E
0005432121409	5275	230	43H
0005434824231	5275	231	43G
0005434831168	5275	232	43K
0005434824173	5275	233	43J
0005432121405	5275	234	44B
0005434824221	5275	235	44A
0005435373036	5275	236	44E
0005434831173	5275	237	44D
0005432121410	5275	238	44H
0005435373012	5275	239	44G
0005434824191	5275	240	45A
0005434824278	5275	241	45C
0005434824186	5275	242	45B
0005435150098	5275	243	45E
0005435373257	5275	244	45H
0005434824210	5275	245	45G
0005435372944	5275	246	45K
0005435150103	5275	247	46C
0005434558315	5275	248	46B
0005435299760	5275	249	46E
0005435372908	5275	250	46G
0005435372979	5275	251	46F
0005435372978	5275	252	46J
0005435178990	5275	253	47A
0005434558309	5275	254	46K
0005432121408	5275	255	47E
0005434824189	5275	256	47D
0005432121401	5275	257	47C
0005435373147	5275	258	47F
0005435372972	5275	259	47K
0005434824213	5275	260	47H
0005435373152	5275	261	48D
0005434824207	5275	262	48C
0005435150100	5275	263	48F
0005434824183	5275	264	48H
0005434824292	5275	265	48G
0005434824277	5275	266	49A
0005434558319	5275	267	48K
0005434558310	5275	268	49C
0005434824215	5275	269	49G
0005434824202	5275	270	49K
0005435373324	5275	271	50C
0005435299752	5275	272	50A
0005434558321	5275	273	50E
0005435386549	5275	274	50D
0005435373064	5275	275	50G
0005434824228	5275	276	50F
0005434824187	5275	277	51F
0005434824175	5275	278	51E
0005434822904	9907	1	1C
0005434822535	9907	2	1H
0005432400106	9907	3	1G
0005435302221	9907	4	2H
0005435373611	9907	5	2D
0005434823311	9907	6	3A
0005434823454	9907	7	2K
0005435373627	9907	8	3D
0005432400099	9907	9	3C
0005435373602	9907	10	3K
0005435373615	9907	11	3G
0005435302220	9907	12	4A
0005434823070	9907	13	4G
0005434558228	9907	14	5A
0005434823887	9907	15	4H
0005435735159	9907	16	5D
0005435373616	9907	17	5C
0005435735161	9907	18	5H
0005434822622	9907	19	5G
0005435373598	9907	20	5K
0005434822876	9907	21	11C
0005435373583	9907	22	11G
0005435149958	9907	23	11E
0005434823336	9907	24	11H
0005434823090	9907	25	12C
0005434823337	9907	26	12A
0005435149925	9907	27	11K
0005434823546	9907	28	12E
0005434823075	9907	29	12D
0005435149980	9907	30	12H
0005434823155	9907	31	12G
0005434823456	9907	32	12K
0005434822558	9907	33	13D
0005434822878	9907	34	13C
0005434822529	9907	35	13E
0005434822745	9907	36	13K
0005434822965	9907	37	13H
0005434823286	9907	38	13G
0005434823341	9907	39	14A
0005435373582	9907	40	14D
0005434822742	9907	41	14C
0005434823069	9907	42	14F
0005434822776	9907	43	14E
0005435735162	9907	44	14H
0005435149968	9907	45	15C
0005435373612	9907	46	15A
0005435373577	9907	47	14K
0005434823040	9907	48	15E
0005435373574	9907	49	15G
0005434822926	9907	50	15F
0005434822852	9907	51	16A
0005434822621	9907	52	15K
0005432203101	9907	53	16D
0005432823461	9907	54	16C
0005435386600	9907	55	16F
0005435373580	9907	56	16K
0005434823557	9907	57	16H
0005434823283	9907	58	17A
0005434823159	9907	59	17E
0005435302224	9907	60	17D
0005435373585	9907	61	17C
0005432203100	9907	62	17G
0005434823515	9907	63	17F
0005435373620	9907	64	17K
0005434823088	9907	65	17H
0005435373576	9907	66	18C
0005434823164	9907	67	18B
0005434822931	9907	68	18E
0005434823161	9907	69	18G
0005434823050	9907	70	18H
0005435373625	9907	71	19A
0005434822559	9907	72	18K
0005432396226	9907	73	19D
0005434823451	9907	74	19C
0005434823800	9907	75	19F
0005434823746	9907	76	19E
0005434823126	9907	77	19J
0005434823731	9907	78	19H
0005434822854	9907	79	19G
0005434823801	9907	80	19K
0005435373563	9907	81	20C
0005434823760	9907	82	20B
0005434822493	9907	83	20E
0005434822636	9907	84	20D
0005435386603	9907	85	20H
0005434822681	9907	86	20G
0005434823163	9907	87	20F
0005434822696	9907	88	20J
0005434823346	9907	89	21B
0005435373590	9907	90	21A
0005435373595	9907	91	21C
0005434823647	9907	92	21F
0005435661946	9907	93	21E
0005434823452	9907	94	21J
0005434823595	9907	95	21H
0005434822609	9907	96	21G
0005432396227	9907	97	21K
0005435373617	9907	98	22B
0005435373570	9907	99	22E
0005434822775	9907	100	22D
0005434822952	9907	101	22G
0005434823127	9907	102	22F
0005434823453	9907	103	22J
0005434822930	9907	104	23B
0005434823037	9907	105	23A
0005434823271	9907	106	23D
0005435373578	9907	107	23C
0005432203097	9907	108	23E
0005432396234	9907	109	23J
0005434823338	9907	110	23G
0005434822838	9907	111	24G
0005434822758	9907	112	24E
0005435373608	9907	113	25B
0005434822491	9907	114	25D
0005435373569	9907	115	25C
0005434823514	9907	116	25E
0005435373626	9907	117	25H
0005432203102	9907	118	25G
0005434822604	9907	119	25J
0005435373593	9907	120	26C
0005434823292	9907	121	26B
0005434828689	9907	122	26A
0005434823536	9907	123	26E
0005435299800	9907	124	26H
0005434823036	9907	125	26G
0005435373618	9907	126	26F
0005435386602	9907	127	26K
0005434828697	9907	128	26J
0005434823284	9907	129	27A
0005434823154	9907	130	27B
0005434823285	9907	131	27E
0005435373564	9907	132	27D
0005434822528	9907	133	27J
0005434822501	9907	134	27K
0005434823748	9907	135	28B
0005435149959	9907	136	28A
0005435149955	9907	137	28D
0005434823039	9907	138	28C
0005432400098	9907	139	28G
0005434823527	9907	140	28E
0005434664956	9907	141	28J
0005435149969	9907	142	28H
0005434822560	9907	143	29A
0005434823740	9907	144	28K
0005435373589	9907	145	29C
0005432203098	9907	146	29B
0005434822757	9907	147	29F
0005434831129	9907	148	29J
0005434823282	9907	149	29H
0005435373571	9907	150	29G
0005434822950	9907	151	29K
0005434823267	9907	152	30B
0005435179398	9907	153	30E
0005434822948	9907	154	30H
0005434558206	9907	155	30G
0005435149967	9907	156	30K
0005434823426	9907	157	31A
0005434831141	9907	158	31D
0005435373575	9907	159	31C
0005434823395	9907	160	31B
0005434822731	9907	161	31F
0005432203103	9907	162	31E
0005435373579	9907	163	31H
0005434822954	9907	164	31K
0005435386598	9907	165	32C
0005434822527	9907	166	32B
0005434822866	9907	167	32E
0005434822951	9907	168	32D
0005434822964	9907	169	32F
0005434823182	9907	170	32K
0005435149970	9907	171	32H
0005434822729	9907	172	33A
0005434828688	9907	173	33D
0005434823696	9907	174	33C
0005435373599	9907	175	33E
0005435150004	9907	176	33H
0005435373591	9907	177	33G
0005435373621	9907	178	33K
0005434558231	9907	179	34A
0005434823537	9907	180	34E
0005434823112	9907	181	34D
0005435373613	9907	182	34G
0005434823364	9907	183	34F
0005435373581	9907	184	34J
0005435150007	9907	185	35A
0005435373565	9907	186	35C
0005435302222	9907	187	35F
0005435386601	9907	188	35E
0005434823493	9907	189	35J
0005435373600	9907	190	35G
0005435373584	9907	191	35K
0005434822955	9907	192	36D
0005435373596	9907	193	36C
0005434823270	9907	194	36B
0005435373623	9907	195	36F
0005434822942	9907	196	36E
0005434822740	9907	197	36G
0005435373566	9907	198	36J
0005435373603	9907	199	36H
0005434558227	9907	200	37B
0005435373622	9907	201	37C
0005435373624	9907	202	37G
0005435373619	9907	203	37F
0005434558230	9907	204	37E
0005434822853	9907	205	37J
0005434822553	9907	206	38C
0005435299799	9907	207	38B
0005435373587	9907	208	38J
0005435373592	9907	209	39A
0005434822561	9907	210	38K
0005435373614	9907	211	39C
0005434823174	9907	212	39G
0005435373573	9907	213	39J
0005435149981	9907	214	40C
0005434822228	9907	215	40B
0005435179697	9907	216	40A
0005434822637	9907	217	40D
0005434822536	9907	218	40F
0005434822865	9907	219	40J
0005434823162	9907	220	41B
0005434823121	9907	221	41A
0005435373605	9907	222	41D
0005434823074	9907	223	41C
0005435373594	9907	224	41F
0005434831130	9907	225	41J
0005434822229	9907	226	41H
0005435373568	9907	227	41G
0005434831131	9907	228	41K
0005434823087	9907	229	42B
0005434828687	9907	230	42A
0005434822490	9907	231	42E
0005434823076	9907	232	42D
0005432203099	9907	233	42F
0005434822741	9907	234	42J
0005435735160	9907	235	42H
0005435299801	9907	236	43B
0005434822425	9907	237	43A
0005434822959	9907	238	42K
0005435373567	9907	239	43C
0005434822426	9907	240	43F
0005434822960	9907	241	43E
0005434823269	9907	242	43H
0005435150025	9907	243	43G
0005435149983	9907	244	43K
0005434831136	9907	245	44C
0005435373610	9907	246	44A
0005435149924	9907	247	44G
0005435373609	9907	248	44F
0005434664958	9907	249	44J
0005434822427	9907	250	44H
0005432400105	9907	251	45B
0005435299802	9907	252	45A
0005434822947	9907	253	44K
0005435661947	9907	254	45D
0005435373607	9907	255	45F
0005434823268	9907	256	45E
0005434823128	9907	257	45H
0005432396229	9907	258	45G
0005434823492	9907	259	46A
0005435373606	9907	260	45K
0005434823183	9907	261	45J
0005434823759	9907	262	46E
0005435386604	9907	263	46G
0005434823329	9907	264	46F
0005435373601	9907	265	46J
0005435302223	9907	266	46H
0005434823153	9907	267	47C
0005434822932	9907	268	47A
0005434823038	9907	269	47D
0005435373597	9907	270	47G
0005435149982	9907	271	47F
0005435386599	9907	272	47K
0005435373604	9907	273	47H
0005434822839	9907	274	48C
0005434822552	9907	275	48A
0005435373572	9907	276	48F
0005434822795	9907	277	48D
0005434822946	9907	278	48H
0005434823464	9907	279	49A
0005434823124	9907	280	48K
0005434822666	9907	281	49D
0005434823209	9907	282	49C
0005434823067	9907	283	49G
0005435373588	9907	284	49F
0005434823195	9907	285	49K
0005435373586	9907	286	49H
0005434822989	9907	287	50A
0005434664959	9907	288	50E
0005434822925	9907	289	50D
0005434822610	9907	290	50H
0005434823741	9907	291	50F
0005434823310	9907	292	51D
0005434828685	9907	293	50K
0005434823042	9907	294	51F
0005434823298	9907	295	51E
0005434823208	9907	296	51G
0005435082823	7015	1	1D
0005435082831	7015	2	6C
0005435082826	7015	3	7B
0005435790321	7015	4	7D
0005435082829	7015	5	18A
0005435082827	7015	6	19A
0005435082824	7015	7	20B
0005435790322	7015	8	21A
0005435082828	7015	9	21B
0005435082830	7015	10	21D
0005435082825	7015	11	22C
0005435082747	26020	1	1A
0005435082686	26020	2	2A
0005435082720	26020	3	2B
0005435790301	26020	4	2D
0005435082769	26020	5	3A
0005435082782	26020	6	4D
0005435082773	26020	7	5D
0005435082685	26020	8	6A
0005435082777	26020	9	6C
0005435082783	26020	10	18C
0005434214256	9569	1	1C
0005434214265	9569	2	1D
0005434756617	9569	3	1F
0005434756629	9569	4	2A
0005434214169	9569	5	2C
0005434756655	9569	6	2D
0005434756653	9569	7	2F
0005434756639	9569	8	3A
0005434756618	9569	9	3C
0005434214151	9569	10	3D
0005434214168	9569	11	3F
0005434214477	9569	12	4A
0005434756620	9569	13	4C
0005434214323	9569	14	4D
0005434214435	9569	15	4E
0005434756626	9569	16	4F
0005434214344	9569	17	5A
0005434214321	9569	18	5C
0005434756638	9569	19	5D
0005434756630	9569	20	5E
0005434756647	9569	21	5F
0005434756649	9569	22	6A
0005434214408	9569	23	6C
0005434756631	9569	24	6D
0005434756619	9569	25	6E
0005434756657	9569	26	6F
0005434756648	9569	27	7A
0005434756634	9569	28	7C
0005434756621	9569	29	7D
0005434214452	9569	30	7E
0005434214370	9569	31	7F
0005434756641	9569	32	8A
0005434214371	9569	33	8C
0005434756662	9569	34	8D
0005434214461	9569	35	8E
0005434214282	9569	36	8F
0005434214462	9569	37	9A
0005434756622	9569	38	9C
0005434214451	9569	39	9D
0005434214296	9569	40	9E
0005434214324	9569	41	9F
0005434756636	9569	42	10A
0005434756652	9569	43	10C
0005434756650	9569	44	10D
0005434756627	9569	45	10F
0005434214244	9569	46	11A
0005434756643	9569	47	11C
0005434214135	9569	48	11D
0005434756658	9569	49	11E
0005434756659	9569	50	11F
0005434756642	9569	51	12A
0005434214347	9569	52	12C
0005434214570	9569	53	12D
0005434214180	9569	54	12E
0005434756632	9569	55	12F
0005434756616	9569	56	13A
0005434756628	9569	57	13C
0005434756664	9569	58	13D
0005434214450	9569	59	13E
0005434214113	9569	60	13F
0005434214134	9569	61	14A
0005434214191	9569	62	14C
0005434756624	9569	63	14D
0005434756651	9569	64	14E
0005434756646	9569	65	14F
0005434756625	9569	66	15A
0005434214297	9569	67	15C
0005434756615	9569	68	15D
0005434214147	9569	69	15E
0005434214155	9569	70	15F
0005434214434	9569	71	16A
0005434756637	9569	72	16C
0005434214345	9569	73	16D
0005434756614	9569	74	16E
0005434214359	9569	75	16F
0005434756644	9569	76	17A
0005434214263	9569	77	17C
0005434756613	9569	78	17D
0005434756660	9569	79	17E
0005434756654	9569	80	17F
0005434756623	9569	81	18A
0005434756645	9569	82	18C
0005434756661	9569	83	18D
0005434214458	9569	84	18E
0005434756635	9569	85	18F
0005434214279	9569	86	19A
0005434756633	9569	87	19C
0005434756640	9569	88	19E
0005434214136	9569	89	19F
0005434214429	9569	90	20A
0005434214283	9569	91	20C
0005434756656	9569	92	20D
0005434756663	9569	93	20E
0005434214292	9569	94	20F
0005434214713	28634	1	1A
0005434756258	28634	2	1C
0005434756152	28634	3	1D
0005434214726	28634	4	1F
0005434756083	28634	5	2A
0005434214715	28634	6	2C
0005434756144	28634	7	2F
0005434214709	28634	8	3A
0005434214721	28634	9	3C
0005434214708	28634	10	3F
0005434756273	28634	11	4A
0005434214705	28634	12	4C
0005434214698	28634	13	4D
0005434214737	28634	14	4E
0005434214741	28634	15	4F
0005434756169	28634	16	5D
0005434214718	28634	17	5C
0005434214730	28634	18	5E
0005434214731	28634	19	6A
0005434756217	28634	20	6C
0005434756202	28634	21	6D
0005434756100	28634	22	6E
0005434214701	28634	23	6F
0005434214707	28634	24	7A
0005434214719	28634	25	7C
0005434756151	28634	26	7D
0005434214711	28634	27	7E
0005434214742	28634	28	7F
0005434756322	28634	29	8A
0005434756084	28634	30	8C
0005434214728	28634	31	8D
0005434756290	28634	32	8F
0005434214744	28634	33	9C
0005434214738	28634	34	9D
0005434214724	28634	35	9E
0005434756167	28634	36	10A
0005434756142	28634	37	10C
0005434214727	28634	38	11A
0005434756251	28634	39	11C
0005434214729	28634	40	11D
0005434756252	28634	41	11E
0005434214700	28634	42	11F
0005434756088	28634	43	12A
0005434214703	28634	44	12C
0005434756292	28634	45	12D
0005434214735	28634	46	12E
0005434214743	28634	47	13A
0005434214717	28634	48	13C
0005434756272	28634	49	13D
0005434756143	28634	50	13E
0005434756285	28634	51	13F
0005434756253	28634	52	14A
0005434214740	28634	53	14D
0005434756336	28634	54	14E
0005434214725	28634	55	14F
0005434756145	28634	56	15A
0005434214733	28634	57	15C
0005434214699	28634	58	15D
0005434214736	28634	59	15E
0005434756245	28634	60	15F
0005434214732	28634	61	16A
0005434214720	28634	62	16D
0005434214739	28634	63	16E
0005434214716	28634	64	16F
0005434214702	28634	65	17A
0005434214704	28634	66	17C
0005434756069	28634	67	17E
0005434214723	28634	68	17F
0005434214734	28634	69	18A
0005434214697	28634	70	18C
0005434214706	28634	71	18E
0005434214710	28634	72	18F
0005434756284	28634	73	19A
0005434214714	28634	74	19D
0005434214712	28634	75	19E
0005434214722	28634	76	20A
0005434756082	28634	77	20C
0005434756270	28634	78	20D
0005434756250	28634	79	20E
0005435100139	10839	1	3B
0005434760189	10839	2	4C
0005434760190	10839	3	4D
0005435100138	10839	4	19A
0005434760180	10839	5	21D
0005434760209	31841	1	2C
0005434760210	31841	2	18C
0005435100118	31841	3	20C
0005434639459	1967	1	1A
0005434639453	1967	2	1B
0005433202327	1967	3	1C
0005433202294	1967	4	1D
0005433202312	1967	5	2A
0005434639474	1967	6	2B
0005434639460	1967	7	2C
0005434639451	1967	8	2D
0005434639454	1967	9	3A
0005434639462	1967	10	3B
0005434639450	1967	11	3C
0005433202287	1967	12	3D
0005432290649	1967	13	4A
0005433202272	1967	14	4B
0005434639457	1967	15	4C
0005433202292	1967	16	4D
0005434639456	1967	17	5B
0005434639465	1967	18	5C
0005435948331	1967	19	5D
0005433202337	1967	20	6A
0005433202291	1967	21	6B
0005434639467	1967	22	6C
0005432290648	1967	23	6D
0005433202307	1967	24	7A
0005434639476	1967	25	7B
0005434639461	1967	26	7C
0005434639468	1967	27	7D
0005433202326	1967	28	18A
0005434639473	1967	29	18C
0005432290650	1967	30	19A
0005434639470	1967	31	19B
0005433202328	1967	32	19C
0005434639463	1967	33	19D
0005434639464	1967	34	20A
0005434639475	1967	35	20B
0005434639471	1967	36	20C
0005434639469	1967	37	20D
0005435948332	1967	38	21A
0005434639472	1967	39	21B
0005434639458	1967	40	21C
0005433202271	1967	41	21D
0005433202289	1967	42	22A
0005433202310	1967	43	22B
0005434639466	1967	44	22C
0005434639452	1967	45	22D
0005434639455	1967	46	23A
0005434639168	23293	1	1A
0005433202427	23293	2	1B
0005434639347	23293	3	1C
0005434639250	23293	4	1D
0005434639230	23293	5	2A
0005433202423	23293	6	2B
0005433202422	23293	7	2C
0005433202426	23293	8	3A
0005433202425	23293	9	3C
0005434639118	23293	10	3B
0005434639214	23293	11	3D
0005434639242	23293	12	4A
0005434639209	23293	13	4B
0005433202429	23293	14	4C
0005434639245	23293	15	4D
0005434639114	23293	16	5A
0005434639257	23293	17	5B
0005434639115	23293	18	5C
0005433202430	23293	19	5D
0005434639153	23293	20	6A
0005434639152	23293	21	6B
0005434639237	23293	22	6D
0005434639259	23293	23	7A
0005434639241	23293	24	7B
0005433202419	23293	25	7C
0005434639210	23293	26	7D
0005433202428	23293	27	18A
0005434639170	23293	28	18B
0005434639169	23293	29	18C
0005434639260	23293	30	18D
0005434639231	23293	31	19A
0005433202432	23293	32	19B
0005433202433	23293	33	19D
0005434639233	23293	34	20A
0005433202434	23293	35	20B
0005433202420	23293	36	20D
0005434639171	23293	37	21A
0005433202424	23293	38	21B
0005433202431	23293	39	21C
0005434639268	23293	40	22A
0005433202421	23293	41	22B
0005434639126	23293	42	22C
0005435948326	23293	43	22D
0005434639141	23293	44	23A
0005434639278	23293	45	23B
0005435326712	6066	1	1A
0005434600950	6066	2	1C
0005434600958	6066	3	2A
0005433531314	6066	4	2C
0005432111296	6066	5	2F
0005433531313	6066	6	3C
0005434600935	6066	7	4A
0005434600955	6066	8	4C
0005434600961	6066	9	5C
0005434600949	6066	10	6D
0005434600937	6066	11	6E
0005434600952	6066	12	7A
0005434600954	6066	13	7F
0005435326711	6066	14	8A
0005434600960	6066	15	8D
0005434600956	6066	16	9C
0005435326718	6066	17	9D
0005435326695	6066	18	9F
0005434600941	6066	19	10C
0005433533330	6066	20	10D
0005433533329	6066	21	10F
0005435326759	6066	22	11A
0005433531311	6066	23	11C
0005433533327	6066	24	11E
0005434600951	6066	25	11F
0005435326688	6066	26	12C
0005434600942	6066	27	12A
0005433533328	6066	28	12E
0005434600946	6066	29	13C
0005433533326	6066	30	13F
0005435326674	6066	31	14A
0005434600938	6066	32	14D
0005434600962	6066	33	14E
0005434600948	6066	34	14F
0005434600940	6066	35	15A
0005434600957	6066	36	15C
0005434600947	6066	37	15E
0005435326719	6066	38	15F
0005434600939	6066	39	16D
0005432111294	6066	40	16E
0005433531312	6066	41	16F
0005434600945	6066	42	17C
0005432111295	6066	43	17F
0005434600943	6066	44	18C
0005434600936	6066	45	18E
0005435326689	6066	46	19C
0005434600934	6066	47	19D
0005434600933	6066	48	19F
0005434600959	6066	49	20A
0005435326694	6066	50	20C
0005434600944	6066	51	20E
0005434600953	6066	52	20F
0005434600689	18564	1	1D
0005434600811	18564	2	2D
0005435326818	18564	3	2F
0005434600734	18564	4	3C
0005433527237	18564	5	3F
0005434600620	18564	6	4C
0005435326815	18564	7	4D
0005435326822	18564	8	5A
0005434600711	18564	9	5C
0005435326819	18564	10	6E
0005433527247	18564	11	6F
0005435326809	18564	12	7D
0005435326816	18564	13	7E
0005434600758	18564	14	8C
0005434600809	18564	15	8D
0005434600668	18564	16	8E
0005433527219	18564	17	8F
0005434600588	18564	18	9A
0005435326811	18564	19	9C
0005434600810	18564	20	9E
0005434600658	18564	21	10E
0005433527249	18564	22	10F
0005434600634	18564	23	11A
0005434600712	18564	24	11C
0005434600704	18564	25	12A
0005434600772	18564	26	12E
0005434600691	18564	27	12F
0005433527250	18564	28	13A
0005433527242	18564	29	13C
0005435326820	18564	30	13D
0005434600617	18564	31	13E
0005435326810	18564	32	13F
0005435326817	18564	33	14A
0005434600719	18564	34	14D
0005434600777	18564	35	14E
0005434600640	18564	36	15A
0005434600629	18564	37	15C
0005433527248	18564	38	15E
0005434600715	18564	39	16E
0005434600587	18564	40	16F
0005434600791	18564	41	17A
0005435326821	18564	42	17C
0005435326812	18564	43	18D
0005434600690	18564	44	19C
0005434600753	18564	45	19D
0005434600778	18564	46	19F
0005435326814	18564	47	20A
0005434600703	18564	48	20C
0005435326813	18564	49	20D
0005434600642	18564	50	20E
0005433527238	18564	51	20F
0005433180892	10630	1	1A
0005434551461	10630	2	1C
0005434551480	10630	3	1D
0005433181082	10630	4	1F
0005434551450	10630	5	2A
0005434554075	10630	6	2C
0005433181038	10630	7	2D
0005433180920	10630	8	2F
0005434551446	10630	9	3A
0005434551465	10630	10	3C
0005433180979	10630	11	3D
0005433180896	10630	12	3F
0005434551487	10630	13	4A
0005434551456	10630	14	4C
0005433180895	10630	15	4D
0005434551470	10630	16	4E
0005434551464	10630	17	4F
0005433180966	10630	18	5A
0005434551463	10630	19	5C
0005433180955	10630	20	5D
0005434551481	10630	21	5E
0005434551462	10630	22	5F
0005433181005	10630	23	6A
0005433181036	10630	24	6C
0005433180982	10630	25	6D
0005434551482	10630	26	6E
0005434551451	10630	27	6F
0005434551460	10630	28	7A
0005434551455	10630	29	7C
0005433180976	10630	30	7D
0005434551491	10630	31	7E
0005433181039	10630	32	8A
0005434551468	10630	33	8C
0005434551459	10630	34	8D
0005434551441	10630	35	8E
0005434551474	10630	36	8F
0005434551490	10630	37	9A
0005433180951	10630	38	9C
0005434551486	10630	39	9D
0005433180884	10630	40	9E
0005433180991	10630	41	9F
0005433180831	10630	42	10A
0005433180999	10630	43	10C
0005433180990	10630	44	10D
0005434551475	10630	45	10E
0005433180918	10630	46	10F
0005434551439	10630	47	11A
0005433181020	10630	48	11C
0005434551452	10630	49	11D
0005434554076	10630	50	11E
0005433181037	10630	51	11F
0005434551476	10630	52	12A
0005434551472	10630	53	12C
0005433180975	10630	54	12D
0005433180890	10630	55	12E
0005433180967	10630	56	12F
0005434551448	10630	57	13A
0005434551467	10630	58	13C
0005434551445	10630	59	13D
0005434551454	10630	60	13E
0005433180958	10630	61	13F
0005433181081	10630	62	14A
0005434551484	10630	63	14C
0005434551478	10630	64	14D
0005434551466	10630	65	14E
0005434551440	10630	66	14F
0005433181004	10630	67	15A
0005434551457	10630	68	15C
0005434551493	10630	69	15D
0005434551471	10630	70	15E
0005434551479	10630	71	15F
0005433180917	10630	72	16A
0005433180973	10630	73	16C
0005434551438	10630	74	16D
0005434551488	10630	75	16E
0005433180964	10630	76	16F
0005434551469	10630	77	17A
0005434551485	10630	78	17C
0005433181059	10630	79	17D
0005434551453	10630	80	17E
0005434551447	10630	81	17F
0005434551449	10630	82	18A
0005434551444	10630	83	18C
0005433181066	10630	84	18D
0005434551473	10630	85	18E
0005434551477	10630	86	18F
0005434551483	10630	87	19A
0005433180978	10630	88	19C
0005433180974	10630	89	19D
0005434551442	10630	90	19E
0005434551443	10630	91	19F
0005433180959	10630	92	20A
0005434551489	10630	93	20C
0005434551492	10630	94	20D
0005434551458	10630	95	20E
0005433181011	10630	96	20F
0005433181232	27728	1	2A
0005433181223	27728	2	3A
0005433181237	27728	3	4D
0005433181226	27728	4	6D
0005433181238	27728	5	7A
0005433181236	27728	6	7F
0005433181221	27728	7	9A
0005433181217	27728	8	9D
0005433181224	27728	9	9E
0005433181225	27728	10	10D
0005433181240	27728	11	10F
0005433181242	27728	12	11D
0005433181220	27728	13	12D
0005433181219	27728	14	12E
0005433181218	27728	15	13E
0005433181231	27728	16	14E
0005433181235	27728	17	14F
0005433181222	27728	18	15C
0005433181239	27728	19	16C
0005433181227	27728	20	17A
0005433181228	27728	21	17F
0005433181229	27728	22	18A
0005433181234	27728	23	18D
0005433181241	27728	24	19D
0005433181230	27728	25	19E
0005433181233	27728	26	20F
0005434551021	27729	1	1F
0005434558263	27729	2	2A
0005434551167	27729	3	2C
0005434551220	27729	4	2D
0005434550827	27729	5	3A
0005434551195	27729	6	3C
0005434551262	27729	7	3F
0005434550966	27729	8	4A
0005434550981	27729	9	4C
0005434550938	27729	10	4F
0005434554056	27729	11	5A
0005434551180	27729	12	5D
0005434551135	27729	13	5E
0005434551117	27729	14	5F
0005434550983	27729	15	6D
0005434550869	27729	16	6E
0005434551138	27729	17	6F
0005434550899	27729	18	7C
0005434550967	27729	19	8A
0005434550999	27729	20	8D
0005434550925	27729	21	8E
0005434550963	27729	22	9C
0005434551026	27729	23	9D
0005434551105	27729	24	9E
0005434551196	27729	25	9F
0005434550973	27729	26	10A
0005434550919	27729	27	10C
0005434554055	27729	28	10D
0005434554057	27729	29	10E
0005434551181	27729	30	10F
0005434551116	27729	31	11A
0005434550937	27729	32	11C
0005434550988	27729	33	11D
0005434550856	27729	34	11E
0005434550982	27729	35	12A
0005434551136	27729	36	12C
0005434551022	27729	37	12D
0005434551205	27729	38	12F
0005434550916	27729	39	13A
0005434551199	27729	40	13C
0005434551066	27729	41	13D
0005434550945	27729	42	13F
0005434550820	27729	43	14A
0005434551308	27729	44	14C
0005434550900	27729	45	14E
0005434551206	27729	46	15D
0005434550918	27729	47	15F
0005434551143	27729	48	16C
0005434551010	27729	49	16E
0005434551253	27729	50	16F
0005434551095	27729	51	17D
0005434551106	27729	52	18C
0005434550901	27729	53	18F
0005434550936	27729	54	19A
0005434550821	27729	55	19E
0005434551096	27729	56	19F
0005434551137	27729	57	20C
0005434551207	27729	58	20D
0005434551182	27729	59	20E
0005434551131	27729	60	20F
0005433459242	6144	1	2A
0005433459240	6144	2	2B
0005433459241	6144	3	4B
0005433459205	19291	1	1A
0005433459204	19291	2	1B
0005435254487	19291	3	3A
0005433459208	19291	4	4A
0005433459207	19291	5	4B
0005433459206	19291	6	5A
0005435254486	19291	7	5B
0005433459203	19291	8	6B
0005435220311	6754	1	1A
0005432533288	6754	2	1C
0005435437800	6754	3	1D
0005435682348	6754	4	2A
0005435682343	6754	5	2C
0005435437873	6754	6	2D
0005435437912	6754	7	2F
0005435682345	6754	8	3A
0005435437889	6754	9	3C
0005435437805	6754	10	3D
0005435682332	6754	11	3F
0005435437833	6754	12	4A
0005435437892	6754	13	4C
0005435217703	6754	14	4E
0005435682353	6754	15	4F
0005432136196	6754	16	5A
0005434828683	6754	17	5C
0005435682347	6754	18	5D
0005435437936	6754	19	5F
0005435437832	6754	20	6A
0005434828684	6754	21	6C
0005435682335	6754	22	6D
0005435220305	6754	23	6E
0005435682338	6754	24	6F
0005435437841	6754	25	7C
0005435682346	6754	26	7E
0005435682331	6754	27	7F
0005435630981	6754	28	8A
0005435630979	6754	29	8C
0005435682358	6754	30	8D
0005435220315	6754	31	8E
0005435437980	6754	32	8F
0005435437888	6754	33	9A
0005435682361	6754	34	9C
0005435682341	6754	35	9D
0005435437999	6754	36	9E
0005435437866	6754	37	9F
0005435682349	6754	38	10A
0005435682351	6754	39	10C
0005435437891	6754	40	10E
0005435437893	6754	41	10F
0005435217701	6754	42	11A
0005435437874	6754	43	11C
0005435437806	6754	44	11D
0005435682359	6754	45	11E
0005432136192	6754	46	11F
0005435682344	6754	47	12A
0005432533274	6754	48	12C
0005435661942	6754	49	12D
0005435682355	6754	50	12E
0005435682356	6754	51	12F
0005435682352	6754	52	13C
0005435682334	6754	53	13D
0005435437863	6754	54	13E
0005435437894	6754	55	13F
0005435661943	6754	56	14A
0005432533287	6754	57	14C
0005435437872	6754	58	14D
0005435437799	6754	59	14E
0005432136194	6754	60	14F
0005432136195	6754	61	15A
0005435682339	6754	62	15C
0005435682357	6754	63	15D
0005435682350	6754	64	15E
0005432136193	6754	65	15F
0005435682330	6754	66	16D
0005435682336	6754	67	16E
0005435221513	6754	68	16F
0005435217702	6754	69	17A
0005435682337	6754	70	17C
0005435661945	6754	71	17D
0005435437907	6754	72	17E
0005435682342	6754	73	17F
0005434828676	6754	74	18A
0005435437850	6754	75	18D
0005435630980	6754	76	18E
0005435437887	6754	77	18F
0005435437865	6754	78	19C
0005435682333	6754	79	19D
0005435661944	6754	80	19E
0005435437840	6754	81	19F
0005435682340	6754	82	20A
0005435682354	6754	83	20C
0005435682360	6754	84	20D
0005435220314	6754	85	20F
0005435220324	24602	1	1A
0005435719568	24602	2	1C
0005435220329	24602	3	1D
0005435438072	24602	4	1F
0005435682015	24602	5	2A
0005435219207	24602	6	2C
0005435682034	24602	7	2D
0005435438055	24602	8	3A
0005435220328	24602	9	3C
0005435438053	24602	10	3D
0005435438060	24602	11	3F
0005435438063	24602	12	4A
0005435682007	24602	13	4C
0005435438071	24602	14	4D
0005435219209	24602	15	4E
0005435681964	24602	16	4F
0005435220327	24602	17	5A
0005435682002	24602	18	5C
0005435438059	24602	19	5D
0005435681924	24602	20	5E
0005435719567	24602	21	5F
0005435438065	24602	22	6A
0005435438056	24602	23	6C
0005435681904	24602	24	6E
0005435682197	24602	25	6F
0005435682083	24602	26	7A
0005435438066	24602	27	7C
0005432533306	24602	28	7D
0005435438064	24602	29	7E
0005435438067	24602	30	7F
0005435681923	24602	31	8A
0005432533307	24602	32	8D
0005435681880	24602	33	8E
0005435438062	24602	34	9A
0005435681870	24602	35	9C
0005435681887	24602	36	9D
0005435438058	24602	37	9E
0005435681976	24602	38	9F
0005435681953	24602	39	10A
0005432305761	24602	40	10C
0005435682106	24602	41	10D
0005435682036	24602	42	10E
0005435682009	24602	43	11A
0005434828711	24602	44	10F
0005435682082	24602	45	11C
0005435682081	24602	46	11D
0005435219208	24602	47	11E
0005435681952	24602	48	11F
0005435219210	24602	49	12A
0005435681949	24602	50	12C
0005435682033	24602	51	12D
0005435220491	24602	52	12F
0005432533305	24602	53	13A
0005435682035	24602	54	13C
0005435219211	24602	55	13E
0005435681869	24602	56	13F
0005434828712	24602	57	14A
0005432305762	24602	58	14C
0005435682183	24602	59	14D
0005435681960	24602	60	14E
0005435661926	24602	61	14F
0005435630942	24602	62	15A
0005435219205	24602	63	15C
0005435681783	24602	64	15D
0005435630951	24602	65	15E
0005435220326	24602	66	15F
0005435438070	24602	67	16A
0005435438057	24602	68	16C
0005435438054	24602	69	16D
0005435681985	24602	70	16E
0005435681890	24602	71	16F
0005435681948	24602	72	17A
0005435661923	24602	73	17C
0005435219206	24602	74	17D
0005435661922	24602	75	17E
0005435220330	24602	76	17F
0005435438068	24602	77	18A
0005435681991	24602	78	18C
0005435438073	24602	79	18D
0005435630952	24602	80	18E
0005435682089	24602	81	18F
0005435681872	24602	82	19A
0005435681927	24602	83	19D
0005435438069	24602	84	19E
0005435438061	24602	85	19F
0005435681893	24602	86	20A
0005435681889	24602	87	20C
0005435661927	24602	88	20D
0005435682095	24602	89	20E
0005435220325	24602	90	20F
0005435126554	11542	1	1C
0005435126557	11542	2	1D
0005435126523	11542	3	2A
0005435558068	11542	4	2C
0005435126559	11542	5	2D
0005435558067	11542	6	2F
0005435126548	11542	7	3C
0005435098566	11542	8	3D
0005435105995	11542	9	3F
0005435126555	11542	10	4A
0005435126538	11542	11	4D
0005435126530	11542	12	4E
0005435126534	11542	13	5A
0005435126537	11542	14	5C
0005435126525	11542	15	5D
0005435558088	11542	16	6D
0005435126529	11542	17	6E
0005435558078	11542	18	7A
0005435126528	11542	19	7E
0005435126522	11542	20	7F
0005435126532	11542	21	8D
0005435126558	11542	22	9A
0005435126545	11542	23	9C
0005435126542	11542	24	9D
0005435126550	11542	25	9F
0005435558087	11542	26	10A
0005435126549	11542	27	10D
0005435126544	11542	28	10E
0005435126546	11542	29	10F
0005435098563	11542	30	11A
0005435558080	11542	31	11F
0005435126561	11542	32	12A
0005435126533	11542	33	12C
0005435126553	11542	34	12D
0005435126562	11542	35	12F
0005435126536	11542	36	13A
0005435558079	11542	37	13C
0005435126539	11542	38	13D
0005435098561	11542	39	13F
0005435098568	11542	40	14C
0005435126521	11542	41	14D
0005435126531	11542	42	14F
0005435558070	11542	43	15C
0005435126556	11542	44	15E
0005435126524	11542	45	15F
0005435126547	11542	46	16A
0005435126551	11542	47	16C
0005435126541	11542	48	16E
0005435098564	11542	49	16F
0005435098567	11542	50	17A
0005435126526	11542	51	17C
0005435126540	11542	52	17D
0005435098562	11542	53	17E
0005435126535	11542	54	17F
0005435105996	11542	55	18D
0005435126543	11542	56	18E
0005435126527	11542	57	18F
0005435098565	11542	58	19A
0005435098569	11542	59	19D
0005435126560	11542	60	20D
0005435126552	11542	61	20E
0005435126262	31878	1	1A
0005435126309	31878	2	1C
0005435126343	31878	3	1D
0005435105978	31878	4	2A
0005435126139	31878	5	1F
0005435098542	31878	6	2D
0005435098543	31878	7	2F
0005435126218	31878	8	3A
0005435126305	31878	9	3C
0005435126403	31878	10	3D
0005435126418	31878	11	4A
0005435126163	31878	12	4D
0005435126329	31878	13	4F
0005435126323	31878	14	5C
0005435126129	31878	15	5D
0005435126179	31878	16	5F
0005435126203	31878	17	6A
0005435126439	31878	18	6E
0005435126378	31878	19	7C
0005435126248	31878	20	8C
0005435126130	31878	21	8F
0005435098548	31878	22	9A
0005435126377	31878	23	9D
0005435098547	31878	24	9F
0005435126279	31878	25	10A
0005435126308	31878	26	10C
0005435126211	31878	27	10E
0005435126273	31878	28	10F
0005435126328	31878	29	11E
0005435126170	31878	30	11F
0005435126087	31878	31	12C
0005435558099	31878	32	12D
0005435125936	31878	33	12E
0005435126165	31878	34	13C
0005435098549	31878	35	13D
0005435558100	31878	36	13F
0005435126263	31878	37	14A
0005435126202	31878	38	14D
0005435126304	31878	39	15A
0005435126224	31878	40	15C
0005435126122	31878	41	15D
0005435126150	31878	42	15F
0005435126345	31878	43	16A
0005435126086	31878	44	16E
0005435126261	31878	45	16F
0005435126260	31878	46	17C
0005435098550	31878	47	17D
0005435126402	31878	48	17E
0005435126164	31878	49	18A
0005435126024	31878	50	18D
0005435126344	31878	51	18E
0005435126121	31878	52	19A
0005435126282	31878	53	19D
0005435126287	31878	54	19E
0005435126186	31878	55	20A
0005435126023	31878	56	20C
0005435126390	31878	57	20D
0005435126296	31878	58	20E
0005435126338	31878	59	20F
0005433398280	13534	1	1A
0005435732271	13534	2	1C
0005433398299	13534	3	1D
0005433398300	13534	4	1F
0005433398291	13534	5	2C
0005435732293	13534	6	2D
0005433398293	13534	7	2F
0005433398278	13534	8	3C
0005435732260	13534	9	3D
0005433398317	13534	10	4A
0005433398284	13534	11	4D
0005435732236	13534	12	4E
0005433398298	13534	13	4F
0005433398296	13534	14	5C
0005433398282	13534	15	5E
0005435732263	13534	16	5F
0005435732250	13534	17	6A
0005433398321	13534	18	6C
0005435732239	13534	19	6E
0005433398318	13534	20	6F
0005433398305	13534	21	7C
0005433398274	13534	22	7E
0005435732315	13534	23	8F
0005433398303	13534	24	9C
0005435732313	13534	25	9F
0005433398316	13534	26	10A
0005433398283	13534	27	10C
0005433398281	13534	28	10D
0005433398294	13534	29	11A
0005433398292	13534	30	11C
0005435732294	13534	31	11E
0005433398304	13534	32	12D
0005435732238	13534	33	12F
0005433398313	13534	34	13A
0005433398272	13534	35	13C
0005433398288	13534	36	13D
0005433398295	13534	37	13E
0005433398315	13534	38	13F
0005433398312	13534	39	14A
0005433398279	13534	40	14D
0005433398290	13534	41	14E
0005433398320	13534	42	15A
0005433398301	13534	43	15C
0005433398311	13534	44	15E
0005433398276	13534	45	15F
0005433398309	13534	46	16A
0005433398287	13534	47	16D
0005435732314	13534	48	16F
0005435732251	13534	49	17A
0005433398297	13534	50	17C
0005433398306	13534	51	17D
0005433398286	13534	52	17E
0005433398302	13534	53	17F
0005433398314	13534	54	18A
0005433398319	13534	55	18C
0005433398310	13534	56	18D
0005435732237	13534	57	18F
0005433398277	13534	58	19A
0005433398275	13534	59	19C
0005433398285	13534	60	19D
0005433398308	13534	61	19E
0005433398307	13534	62	20A
0005433398273	13534	63	20E
0005433398289	13534	64	20F
0005433397964	19427	1	1F
0005433397846	19427	2	2A
0005433397911	19427	3	2C
0005433397889	19427	4	2D
0005433397912	19427	5	3C
0005433397871	19427	6	3D
0005433397909	19427	7	4A
0005433398074	19427	8	4C
0005433397814	19427	9	4D
0005433397815	19427	10	4E
0005433397888	19427	11	5A
0005433397866	19427	12	5E
0005433397935	19427	13	5D
0005433397892	19427	14	5F
0005433398050	19427	15	6C
0005432297289	19427	16	6D
0005433397770	19427	17	6F
0005433397857	19427	18	7A
0005433397843	19427	19	7C
0005433398067	19427	20	7E
0005433397865	19427	21	7F
0005432297290	19427	22	8C
0005433397687	19427	23	8D
0005433397751	19427	24	9A
0005433397875	19427	25	9C
0005433397954	19427	26	9E
0005433398015	19427	27	10A
0005433398080	19427	28	10D
0005433398032	19427	29	10E
0005433398040	19427	30	11A
0005433397884	19427	31	11C
0005433398073	19427	32	11D
0005433397783	19427	33	11E
0005433397861	19427	34	11F
0005433397838	19427	35	12A
0005433397878	19427	36	12D
0005433397929	19427	37	12E
0005433397860	19427	38	12F
0005433397778	19427	39	13A
0005433397894	19427	40	13C
0005433398168	19427	41	13E
0005433397779	19427	42	13F
0005433397459	19427	43	14D
0005433397885	19427	44	14F
0005433397893	19427	45	15C
0005433397934	19427	46	16A
0005433397949	19427	47	16C
0005433398072	19427	48	16D
0005433397981	19427	49	16F
0005433397872	19427	50	17C
0005433397895	19427	51	17D
0005433397943	19427	52	17E
0005433397890	19427	53	17F
0005433397828	19427	54	18A
0005433397750	19427	55	18C
0005433397821	19427	56	18F
0005433397953	19427	57	19A
0005432297291	19427	58	19C
0005433397910	19427	59	19D
0005433397816	19427	60	19E
0005433397858	19427	61	19F
0005433397782	19427	62	20A
0005433397950	19427	63	20E
0005435925359	13134	1	1C
0005435068816	13134	2	2A
0005435068811	13134	3	2C
0005435068411	13134	4	2D
0005435069045	13134	5	2F
0005435925362	13134	6	3C
0005435068856	13134	7	3D
0005435068801	13134	8	3F
0005435069159	13134	9	4A
0005435068950	13134	10	4C
0005435068997	13134	11	4D
0005435068798	13134	12	4E
0005435068998	13134	13	4F
0005435068800	13134	14	5A
0005435068791	13134	15	5C
0005435068841	13134	16	5D
0005435068949	13134	17	5E
0005435068740	13134	18	5F
0005435068866	13134	19	6A
0005435068857	13134	20	6C
0005435068790	13134	21	6D
0005435068674	13134	22	6F
0005435068675	13134	23	7A
0005435068628	13134	24	7C
0005435068667	13134	25	7E
0005435925358	13134	26	7F
0005435068792	13134	27	8A
0005435068808	13134	28	8C
0005435068739	13134	29	8D
0005435925357	13134	30	8E
0005435069062	13134	31	8F
0005435068839	13134	32	9A
0005435068935	13134	33	9C
0005435068848	13134	34	9D
0005435068637	13134	35	9E
0005435068410	13134	36	10A
0005435068934	13134	37	10C
0005435925363	13134	38	10D
0005435069074	13134	39	10E
0005435068913	13134	40	10F
0005435068980	13134	41	11C
0005435925360	13134	42	11E
0005435068840	13134	43	12A
0005435925361	13134	44	12D
0005435068921	13134	45	12F
0005435068953	13134	46	13A
0005435068807	13134	47	13C
0005435068814	13134	48	13D
0005435925364	13134	49	14A
0005435068885	13134	50	14C
0005435069007	13134	51	14D
0005435068855	13134	52	14E
0005435068813	13134	53	14F
0005435068719	13134	54	15A
0005435068880	13134	55	15D
0005435068938	13134	56	16A
0005435068793	13134	57	16C
0005435068755	13134	58	16D
0005435068993	13134	59	16E
0005435068954	13134	60	16F
0005435068847	13134	61	17A
0005435068752	13134	62	17C
0005435068815	13134	63	17E
0005435068629	13134	64	18A
0005435068756	13134	65	18C
0005435068933	13134	66	18D
0005435068881	13134	67	18F
0005435068810	13134	68	19C
0005435068858	13134	69	19E
0005435068854	13134	70	19F
0005435069158	13134	71	20A
0005435068720	13134	72	20C
0005435068638	13134	73	20D
0005435069282	15475	1	1A
0005435925217	15475	2	1C
0005435069323	15475	3	1F
0005435069292	15475	4	2A
0005435069285	15475	5	2C
0005435069280	15475	6	2D
0005435069319	15475	7	3A
0005435069288	15475	8	3C
0005435925199	15475	9	3D
0005435069297	15475	10	3F
0005435069272	15475	11	4A
0005435069302	15475	12	4D
0005435069322	15475	13	4E
0005435925196	15475	14	5C
0005435925230	15475	15	5A
0005435925194	15475	16	5D
0005435069284	15475	17	5F
0005435069309	15475	18	6A
0005435069305	15475	19	6C
0005435069291	15475	20	6F
0005435069314	15475	21	7A
0005435069318	15475	22	7C
0005435069294	15475	23	7D
0005435069316	15475	24	7F
0005435069320	15475	25	8A
0005435069313	15475	26	8D
0005435069298	15475	27	8E
0005435069303	15475	28	8F
0005435069301	15475	29	9C
0005435069277	15475	30	9D
0005435069321	15475	31	9F
0005435069287	15475	32	10A
0005435069290	15475	33	10E
0005435069278	15475	34	10F
0005435069274	15475	35	11C
0005435925195	15475	36	11D
0005435069293	15475	37	11F
0005435069300	15475	38	12A
0005435069295	15475	39	12C
0005435069307	15475	40	13C
0005435069279	15475	41	13E
0005435069286	15475	42	13F
0005435925200	15475	43	14A
0005435925153	15475	44	14C
0005435069276	15475	45	14D
0005435069317	15475	46	14E
0005435069311	15475	47	14F
0005435069283	15475	48	15C
0005435925236	15475	49	15E
0005435069296	15475	50	16A
0005435069299	15475	51	16D
0005435069306	15475	52	16E
0005435069312	15475	53	17A
0005435069310	15475	54	17C
0005435069315	15475	55	17D
0005435069289	15475	56	17F
0005435069304	15475	57	18A
0005435925229	15475	58	18C
0005435069273	15475	59	18D
0005435069275	15475	60	18E
0005435925235	15475	61	18F
0005435925205	15475	62	19C
0005435069281	15475	63	19F
0005435069308	15475	64	20A
0005435808271	23189	1	1B
0005435808265	23189	2	1C
0005435808276	23189	3	1D
0005433407522	23189	4	2B
0005433407547	23189	5	2C
0005433407553	23189	6	2D
0005435808279	23189	7	3A
0005435808269	23189	8	3C
0005433407523	23189	9	3D
0005435808272	23189	10	4B
0005435808263	23189	11	4D
0005435808277	23189	12	5B
0005435808275	23189	13	5C
0005433407548	23189	14	5D
0005435808264	23189	15	6A
0005435808273	23189	16	6B
0005435808270	23189	17	6C
0005435808281	23189	18	6D
0005433407549	23189	19	7A
0005433407550	23189	20	7C
0005435808266	23189	21	18C
0005433407532	23189	22	18D
0005435808268	23189	23	19C
0005433407515	23189	24	19D
0005435808282	23189	25	20C
0005435808280	23189	26	21A
0005435808278	23189	27	21C
0005433407511	23189	28	21D
0005433407508	23189	29	22A
0005435808274	23189	30	22B
0005435808267	23189	31	22C
0005433407514	23189	32	23A
0005435808283	23189	33	23B
0005434214772	10732	1	1D
0005434756137	10732	2	1F
0005434214790	10732	3	2A
0005434756192	10732	4	2C
0005434214749	10732	5	2D
0005434214759	10732	6	2F
0005434756176	10732	7	3A
0005434756175	10732	8	3D
0005434756277	10732	9	3F
0005434214761	10732	10	4A
0005434214751	10732	11	4C
0005434756303	10732	12	4D
0005434756080	10732	13	4E
0005434214768	10732	14	4F
0005434756206	10732	15	5A
0005434756225	10732	16	5C
0005434756278	10732	17	5D
0005434756189	10732	18	5E
0005434214787	10732	19	5F
0005434756208	10732	20	6A
0005434214756	10732	21	6C
0005434756147	10732	22	6D
0005434214765	10732	23	6E
0005434756194	10732	24	6F
0005434214771	10732	25	7A
0005434214760	10732	26	7C
0005434214769	10732	27	7D
0005434214755	10732	28	7E
0005434214789	10732	29	7F
0005434214745	10732	30	8C
0005434756226	10732	31	8D
0005434214786	10732	32	8E
0005434214783	10732	33	8F
0005434756207	10732	34	9A
0005434214774	10732	35	9C
0005434214775	10732	36	9D
0005434214777	10732	37	9E
0005434756281	10732	38	9F
0005434756234	10732	39	10A
0005434214779	10732	40	10C
0005434214780	10732	41	10D
0005434214757	10732	42	10E
0005434214747	10732	43	10F
0005434214764	10732	44	11A
0005434214776	10732	45	11C
0005434214791	10732	46	12A
0005434214773	10732	47	12C
0005434756214	10732	48	12D
0005434214781	10732	49	12E
0005434756165	10732	50	12F
0005434214767	10732	51	13A
0005434214766	10732	52	13C
0005434214746	10732	53	13D
0005434756132	10732	54	13E
0005434214763	10732	55	13F
0005434756199	10732	56	14A
0005434756213	10732	57	14C
0005434214784	10732	58	14D
0005434756310	10732	59	14E
0005434756166	10732	60	15A
0005434214770	10732	61	15C
0005434214785	10732	62	15D
0005434214788	10732	63	15E
0005434214754	10732	64	15F
0005434214778	10732	65	16A
0005434756224	10732	66	16C
0005434756304	10732	67	16D
0005434756212	10732	68	16E
0005434756291	10732	69	16F
0005434756204	10732	70	17A
0005434756131	10732	71	17C
0005434214792	10732	72	17F
0005434214752	10732	73	17E
0005434756123	10732	74	18C
0005434756198	10732	75	18D
0005434756081	10732	76	18E
0005434756309	10732	77	18F
0005434214758	10732	78	19C
0005434756203	10732	79	19D
0005434214750	10732	80	19E
0005434214753	10732	81	19F
0005434214762	10732	82	20A
0005434756220	10732	83	20C
0005434214782	10732	84	20D
0005434756241	10732	85	20E
0005434214748	10732	86	20F
0005434756574	28707	1	1A
0005434756592	28707	2	1C
0005434214350	28707	3	1D
0005434756595	28707	4	2A
0005434214457	28707	5	2C
0005434756612	28707	6	2D
0005434756580	28707	7	2F
0005434756567	28707	8	3A
0005434214404	28707	9	3C
0005434756571	28707	10	3D
0005434756591	28707	11	3F
0005434214224	28707	12	4A
0005434756585	28707	13	4C
0005434214403	28707	14	4D
0005434756584	28707	15	4E
0005434756577	28707	16	4F
0005434214239	28707	17	5A
0005434214277	28707	18	5C
0005434756578	28707	19	5D
0005434214262	28707	20	5E
0005434214331	28707	21	5F
0005434756587	28707	22	6A
0005434756598	28707	23	6C
0005434214206	28707	24	6D
0005434214251	28707	25	6E
0005434756607	28707	26	6F
0005434756594	28707	27	7A
0005434214238	28707	28	7C
0005434214082	28707	29	7D
0005434214242	28707	30	7E
0005434756610	28707	31	7F
0005434214241	28707	32	8C
0005434214378	28707	33	8D
0005434214284	28707	34	8E
0005434756583	28707	35	8F
0005434756597	28707	36	9A
0005434214268	28707	37	9C
0005434214266	28707	38	9D
0005434756593	28707	39	9E
0005434214374	28707	40	9F
0005434214116	28707	41	10A
0005434214267	28707	42	10C
0005434756570	28707	43	10D
0005434214215	28707	44	10E
0005434756601	28707	45	10F
0005434214337	28707	46	11A
0005434756573	28707	47	11C
0005434214306	28707	48	11D
0005434756586	28707	49	11E
0005434214319	28707	50	11F
0005434756602	28707	51	12A
0005434214375	28707	52	12C
0005434756581	28707	53	12E
0005434214240	28707	54	12F
0005434214288	28707	55	13A
0005434214314	28707	56	13C
0005434756609	28707	57	13D
0005434214228	28707	58	13E
0005434756572	28707	59	13F
0005434756589	28707	60	14A
0005434756608	28707	61	14C
0005434214373	28707	62	14D
0005434214351	28707	63	14E
0005434214409	28707	64	14F
0005434756596	28707	65	15A
0005434756576	28707	66	15C
0005434214081	28707	67	15D
0005434214166	28707	68	15E
0005434756569	28707	69	15F
0005434756611	28707	70	16A
0005434214276	28707	71	16C
0005434214290	28707	72	16D
0005434756590	28707	73	16E
0005434756600	28707	74	16F
0005434756579	28707	75	17A
0005434756588	28707	76	17C
0005434214425	28707	77	17D
0005434756603	28707	78	17E
0005434214196	28707	79	17F
0005434756606	28707	80	18C
0005434756568	28707	81	18D
0005434214308	28707	82	18E
0005434214381	28707	83	18F
0005434756605	28707	84	19A
0005434214205	28707	85	19C
0005434214456	28707	86	19D
0005434756582	28707	87	19E
0005434214455	28707	88	19F
0005434756599	28707	89	20A
0005434214289	28707	90	20C
0005434756575	28707	91	20D
0005434214258	28707	92	20E
0005434756604	28707	93	20F
0005432125489	5432	1	1A
0005435040120	5432	2	1C
0005435007155	5432	3	1F
0005434229327	5432	4	1D
0005435040095	5432	5	2A
0005434229287	5432	6	2C
0005435040078	5432	7	2D
0005432125491	5432	8	2F
0005434229198	5432	9	3C
0005435040122	5432	10	3A
0005435007150	5432	11	3D
0005435040077	5432	12	3F
0005435007154	5432	13	4A
0005435040081	5432	14	4B
0005435040085	5432	15	4D
0005435007145	5432	16	4C
0005434229297	5432	17	4E
0005435007140	5432	18	4F
0005435040108	5432	19	5A
0005435007137	5432	20	5C
0005435007138	5432	21	5B
0005435040068	5432	22	5D
0005435007139	5432	23	5E
0005434229317	5432	24	5F
0005432125488	5432	25	6A
0005435007149	5432	26	6C
0005435007160	5432	27	6B
0005435040089	5432	28	6D
0005435040114	5432	29	6F
0005435007146	5432	30	6E
0005435040128	5432	31	7A
0005435040111	5432	32	7C
0005435007151	5432	33	7B
0005435040106	5432	34	7D
0005432125486	5432	35	7E
0005435040072	5432	36	8A
0005435040071	5432	37	7F
0005435040094	5432	38	8B
0005434229165	5432	39	8C
0005435007157	5432	40	8D
0005435007142	5432	41	8F
0005432125492	5432	42	8E
0005435043288	5432	43	9A
0005435040099	5432	44	9B
0005434229326	5432	45	9C
0005434229343	5432	46	9F
0005435040067	5432	47	9E
0005434229316	5432	48	10B
0005435040113	5432	49	10D
0005435040126	5432	50	10C
0005435007152	5432	51	10E
0005435040086	5432	52	11A
0005435040101	5432	53	11B
0005435040082	5432	54	11C
0005435040117	5432	55	11D
0005435040070	5432	56	11F
0005435040131	5432	57	11E
0005435040103	5432	58	12A
0005435007148	5432	59	12C
0005435040119	5432	60	12B
0005435040100	5432	61	12D
0005435040112	5432	62	12E
0005435040102	5432	63	12F
0005435007156	5432	64	13B
0005434229378	5432	65	13A
0005435007153	5432	66	13C
0005434229331	5432	67	13D
0005434229284	5432	68	13E
0005435040118	5432	69	13F
0005435007158	5432	70	14B
0005435040092	5432	71	14A
0005435040109	5432	72	14C
0005434229274	5432	73	14D
0005434229307	5432	74	14E
0005435040115	5432	75	15A
0005435040123	5432	76	14F
0005435040080	5432	77	15B
0005435040084	5432	78	15C
0005435040124	5432	79	15D
0005434229344	5432	80	15E
0005435040074	5432	81	16A
0005435040107	5432	82	16B
0005435040073	5432	83	16C
0005435040104	5432	84	16D
0005435040075	5432	85	16E
0005435040097	5432	86	17A
0005434229278	5432	87	16F
0005435040076	5432	88	17B
0005435040083	5432	89	17C
0005434229347	5432	90	17E
0005435040096	5432	91	17D
0005435043289	5432	92	17F
0005435040105	5432	93	18A
0005435040127	5432	94	18B
0005434229269	5432	95	18C
0005435040091	5432	96	18E
0005435040121	5432	97	18D
0005435040129	5432	98	18F
0005435040069	5432	99	19A
0005435040110	5432	100	19B
0005435040116	5432	101	19D
0005434229290	5432	102	19C
0005435007144	5432	103	19F
0005435040098	5432	104	19E
0005435040088	5432	105	20B
0005432125487	5432	106	20A
0005435007143	5432	107	20C
0005434229289	5432	108	20D
0005435040130	5432	109	20E
0005435040093	5432	110	21A
0005435040125	5432	111	21C
0005434229273	5432	112	21B
0005435040079	5432	113	21D
0005434229333	5432	114	21F
0005432125490	5432	115	21E
0005434229281	5432	116	22A
0005435040065	5432	117	22B
0005435040066	5432	118	22C
0005432125485	5432	119	22D
0005435007141	5432	120	22E
0005435007147	5432	121	23A
0005435040090	5432	122	22F
0005435042865	5432	123	23B
0005434229332	5432	124	23C
0005435007159	5432	125	23E
0005435040087	5432	126	23D
0005434229272	5432	127	23F
0005434229484	12975	1	1A
0005432304420	12975	2	1C
0005435006969	12975	3	1F
0005435039608	12975	4	1D
0005435039289	12975	5	2C
0005435006833	12975	6	2A
0005435006905	12975	7	2D
0005435039711	12975	8	2F
0005435039359	12975	9	3C
0005435039221	12975	10	3A
0005435007012	12975	11	3D
0005435039592	12975	12	3F
0005435039591	12975	13	4A
0005435006958	12975	14	4C
0005435039471	12975	15	4B
0005435039568	12975	16	4D
0005435039598	12975	17	4E
0005435042848	12975	18	4F
0005435039531	12975	19	5A
0005432304419	12975	20	5C
0005435039495	12975	21	5D
0005434229489	12975	22	5E
0005435006832	12975	23	5F
0005435039467	12975	24	6B
0005435039290	12975	25	6A
0005435006936	12975	26	6C
0005435039597	12975	27	6D
0005435039857	12975	28	6E
0005435006994	12975	29	7A
0005435039487	12975	30	6F
0005434229482	12975	31	7B
0005434229490	12975	32	7C
0005435006871	12975	33	7D
0005435042842	12975	34	7F
0005435006866	12975	35	7E
0005435039544	12975	36	8A
0005435006933	12975	37	8B
0005435039462	12975	38	8C
0005435039723	12975	39	8E
0005435006926	12975	40	8D
0005435007013	12975	41	8F
0005434229479	12975	42	9A
0005435006976	12975	43	9B
0005435039699	12975	44	9C
0005435039466	12975	45	9E
0005434229495	12975	46	9D
0005435039851	12975	47	9F
0005435039508	12975	48	10C
0005434229477	12975	49	10B
0005434229487	12975	50	10D
0005435039484	12975	51	10E
0005435006925	12975	52	11A
0005435039410	12975	53	11C
0005435006977	12975	54	11B
0005435039688	12975	55	11E
0005434229485	12975	56	11D
0005432304416	12975	57	11F
0005435039488	12975	58	12A
0005435039340	12975	59	12B
0005435039414	12975	60	12C
0005435039714	12975	61	12E
0005435039499	12975	62	12D
0005434229497	12975	63	12F
0005434229494	12975	64	13B
0005434229481	12975	65	13A
0005432304417	12975	66	13C
0005434229478	12975	67	13E
0005435006972	12975	68	13D
0005435039656	12975	69	13F
0005435039455	12975	70	14A
0005435039658	12975	71	14B
0005435039485	12975	72	14D
0005434229480	12975	73	14C
0005434229496	12975	74	14F
0005435039541	12975	75	14E
0005435039498	12975	76	15A
0005435039434	12975	77	15B
0005435006891	12975	78	15C
0005434229475	12975	79	15D
0005435039497	12975	80	15F
0005435006901	12975	81	15E
0005435039587	12975	82	16A
0005435006971	12975	83	16B
0005435039596	12975	84	16C
0005434229488	12975	85	16D
0005434229476	12975	86	16E
0005435007003	12975	87	17A
0005435039291	12975	88	16F
0005435039609	12975	89	17B
0005435039490	12975	90	17D
0005435039512	12975	91	17C
0005435006993	12975	92	17E
0005434229493	12975	93	17F
0005435006986	12975	94	18A
0005434229491	12975	95	18B
0005435039444	12975	96	18D
0005435039510	12975	97	18C
0005435039435	12975	98	18E
0005434229486	12975	99	18F
0005435039339	12975	100	19A
0005435039657	12975	101	19B
0005435039540	12975	102	19D
0005435039465	12975	103	19C
0005435006978	12975	104	19E
0005435039660	12975	105	19F
0005435006964	12975	106	20A
0005435039595	12975	107	20B
0005434229483	12975	108	20D
0005435006947	12975	109	20C
0005435039689	12975	110	20E
0005432304418	12975	111	20F
0005434229492	12975	112	21B
0005435039605	12975	113	21A
0005435039715	12975	114	21C
0005435039713	12975	115	21D
0005435043282	12975	116	21E
0005435039441	12975	117	21F
0005435039712	12975	118	22B
0005435039850	12975	119	22A
0005435006946	12975	120	22C
0005435006892	12975	121	22E
0005435006902	12975	122	22D
0005435039511	12975	123	22F
0005435039486	12975	124	23A
0005435039411	12975	125	23B
0005435039661	12975	126	23C
0005435039433	12975	127	23E
0005435039358	12975	128	23D
0005435039556	12975	129	23F
0005435554154	14906	1	1A
0005435902591	14906	2	1D
0005434426747	14906	3	2F
0005434411796	14906	4	3A
0005435554184	14906	5	3C
0005432188621	14906	6	3D
0005434426731	14906	7	3F
0005434426733	14906	8	4A
0005435902561	14906	9	4D
0005434426724	14906	10	4E
0005435554167	14906	11	4F
0005434426741	14906	12	5C
0005434426740	14906	13	5D
0005434426730	14906	14	5E
0005435902720	14906	15	5F
0005434426721	14906	16	6A
0005434426735	14906	17	6E
0005434426727	14906	18	7A
0005434426743	14906	19	7E
0005432188622	14906	20	8A
0005434426739	14906	21	8C
0005434426725	14906	22	8D
0005434411797	14906	23	8F
0005434426720	14906	24	9A
0005435554157	14906	25	9C
0005434426734	14906	26	9D
0005434426745	14906	27	9E
0005434426722	14906	28	9F
0005434426737	14906	29	10C
0005434426744	14906	30	10E
0005435902626	14906	31	10F
0005435902599	14906	32	11D
0005434426738	14906	33	11E
0005434426729	14906	34	12D
0005435554185	14906	35	12F
0005434426726	14906	36	13A
0005434426719	14906	37	13D
0005434426742	14906	38	13E
0005435554159	14906	39	13F
0005435554180	14906	40	15A
0005434426732	14906	41	15F
0005434411794	14906	42	16C
0005435554155	14906	43	16D
0005434426723	14906	44	16E
0005435902673	14906	45	16F
0005434411795	14906	46	17A
0005434426736	14906	47	17E
0005434426728	14906	48	18C
0005435902672	14906	49	18E
0005435902539	14906	50	18F
0005435902590	14906	51	19E
0005435902692	14906	52	19F
0005434426746	14906	53	20A
0005435902700	14906	54	20D
0005435554212	20210	1	1F
0005434426545	20210	2	2A
0005434426477	20210	3	2C
0005434426610	20210	4	2D
0005434426570	20210	5	2F
0005434426654	20210	6	3D
0005435554215	20210	7	4A
0005434426542	20210	8	4C
0005435902787	20210	9	5E
0005434426555	20210	10	6A
0005434426487	20210	11	6D
0005434426435	20210	12	7A
0005435902793	20210	13	8A
0005434426523	20210	14	8C
0005434426587	20210	15	8D
0005434426492	20210	16	8E
0005435902802	20210	17	9A
0005435902797	20210	18	9C
0005435554214	20210	19	9E
0005434411765	20210	20	9F
0005434426378	20210	21	10A
0005435902799	20210	22	10C
0005434426395	20210	23	10D
0005435902791	20210	24	10E
0005432059515	20210	25	10F
0005434426618	20210	26	11C
0005435902792	20210	27	11D
0005435902789	20210	28	11F
0005434426568	20210	29	12A
0005434426566	20210	30	12E
0005434426436	20210	31	12F
0005434426473	20210	32	13C
0005434426491	20210	33	14C
0005435902785	20210	34	14D
0005435902801	20210	35	14E
0005434426571	20210	36	15C
0005435902794	20210	37	15E
0005435554213	20210	38	16A
0005434426510	20210	39	16C
0005435902800	20210	40	16D
0005435902803	20210	41	16F
0005435902786	20210	42	17A
0005434426653	20210	43	17D
0005434426569	20210	44	17F
0005435902790	20210	45	18A
0005435554216	20210	46	18C
0005435554217	20210	47	18E
0005434426522	20210	48	18F
0005435902795	20210	49	19A
0005434426521	20210	50	19C
0005434411747	20210	51	19E
0005435902788	20210	52	19F
0005435902796	20210	53	20D
0005434426588	20210	54	20E
0005435902798	20210	55	20F
0005433726084	21656	1	1F
0005433726064	21656	2	2C
0005433726078	21656	3	2D
0005433726080	21656	4	3C
0005433726082	21656	5	6B
0005433726074	21656	6	6D
0005433726083	21656	7	7A
0005433726088	21656	8	8E
0005433726075	21656	9	9A
0005433726085	21656	10	11D
0005433726090	21656	11	12C
0005433726065	21656	12	14B
0005433726087	21656	13	15E
0005433726089	21656	14	15D
0005433726092	21656	15	16B
0005433726073	21656	16	19C
0005433726077	21656	17	19E
0005433726081	21656	18	20B
0005433726091	21656	19	22C
0005433434591	26537	1	1A
0005435982499	26537	2	1C
0005432300286	26537	3	1D
0005432300289	26537	4	1F
0005433434606	26537	5	2A
0005435982491	26537	6	2D
0005435982487	26537	7	2F
0005434270205	26537	8	3A
0005434273065	26537	9	3C
0005435982514	26537	10	3D
0005433434498	26537	11	3F
0005434270196	26537	12	4A
0005435982488	26537	13	4C
0005433434667	26537	14	4D
0005433434568	26537	15	4E
0005435982507	26537	16	4F
0005435982490	26537	17	5A
0005435982512	26537	18	5C
0005433434626	26537	19	5D
0005432300285	26537	20	5E
0005435982485	26537	21	6A
0005435982509	26537	22	6C
0005433434590	26537	23	6D
0005434270190	26537	24	6E
0005433434593	26537	25	6F
0005434273066	26537	26	7A
0005432300290	26537	27	7C
0005433434497	26537	28	7D
0005435982520	26537	29	7E
0005433434458	26537	30	7F
0005433434564	26537	31	8A
0005435982526	26537	32	8D
0005435982498	26537	33	8E
0005433434524	26537	34	8F
0005435982500	26537	35	9A
0005435982515	26537	36	9C
0005433434480	26537	37	9D
0005435982516	26537	38	9E
0005435982494	26537	39	9F
0005433434565	26537	40	10A
0005435982505	26537	41	10C
0005433434479	26537	42	10E
0005433434589	26537	43	10F
0005433434492	26537	44	11A
0005433434514	26537	45	11D
0005434270198	26537	46	11E
0005435982501	26537	47	12A
0005434270197	26537	48	11F
0005433434499	26537	49	12C
0005435982503	26537	50	12D
0005434270204	26537	51	12E
0005435982496	26537	52	12F
0005435982521	26537	53	13A
0005435982502	26537	54	13C
0005432300288	26537	55	13D
0005432300287	26537	56	13E
0005433434592	26537	57	13F
0005435982524	26537	58	14C
0005433434576	26537	59	14D
0005434270199	26537	60	14E
0005433434588	26537	61	14F
0005435982497	26537	62	15A
0005435982525	26537	63	15C
0005435982513	26537	64	15D
0005435982518	26537	65	15E
0005435982508	26537	66	15F
0005435982489	26537	67	16A
0005435982517	26537	68	16D
0005435982522	26537	69	16E
0005433434566	26537	70	16F
0005435982486	26537	71	17A
0005435982493	26537	72	17C
0005433434523	26537	73	17D
0005433434515	26537	74	17F
0005435982511	26537	75	18A
0005435982495	26537	76	18C
0005435982492	26537	77	18D
0005433434607	26537	78	18F
0005433434625	26537	79	19C
0005435982519	26537	80	19D
0005433434559	26537	81	19E
0005435982510	26537	82	19F
0005435982504	26537	83	20A
0005435982523	26537	84	20C
0005433434567	26537	85	20D
0005433434518	26537	86	20E
0005435982506	26537	87	20F
0005435982184	26701	1	1A
0005435982156	26701	2	1C
0005433434839	26701	3	1D
0005433434838	26701	4	1F
0005433434836	26701	5	2A
0005435982192	26701	6	2C
0005432051145	26701	7	2D
0005435982108	26701	8	2F
0005435982023	26701	9	3A
0005434271323	26701	10	3D
0005435982215	26701	11	3F
0005435982135	26701	12	4A
0005435982187	26701	13	4C
0005434270217	26701	14	4D
0005435982131	26701	15	4E
0005435982163	26701	16	4F
0005435982095	26701	17	5A
0005435982222	26701	18	5C
0005433434815	26701	19	5E
0005435982109	26701	20	5F
0005433434840	26701	21	6C
0005433434830	26701	22	6D
0005435982185	26701	23	6E
0005435982133	26701	24	6F
0005435982391	26701	25	7A
0005433434823	26701	26	7C
0005435982026	26701	27	7D
0005433434819	26701	28	7E
0005433434820	26701	29	7F
0005434271322	26701	30	8A
0005432051144	26701	31	8C
0005435982099	26701	32	8D
0005435982162	26701	33	8E
0005435982153	26701	34	8F
0005435982116	26701	35	9A
0005433434824	26701	36	9C
0005433434821	26701	37	9D
0005435982194	26701	38	9E
0005433434817	26701	39	9F
0005435982137	26701	40	10A
0005432051143	26701	41	10C
0005433434818	26701	42	10D
0005434270218	26701	43	10E
0005435982193	26701	44	10F
0005433434816	26701	45	11A
0005435982003	26701	46	11C
0005433434831	26701	47	11D
0005435982165	26701	48	11E
0005435982188	26701	49	11F
0005435982121	26701	50	12A
0005435982138	26701	51	12C
0005433434822	26701	52	12D
0005435982065	26701	53	12E
0005433434832	26701	54	12F
0005434269114	26701	55	13C
0005435982092	26701	56	13D
0005433434841	26701	57	14A
0005435982231	26701	58	14D
0005435982120	26701	59	14E
0005433434825	26701	60	14F
0005435982055	26701	61	15A
0005433434835	26701	62	15C
0005433434813	26701	63	15D
0005435982132	26701	64	15E
0005435982230	26701	65	15F
0005433434834	26701	66	16A
0005435982094	26701	67	16C
0005435982148	26701	68	16D
0005435982186	26701	69	16E
0005435982178	26701	70	16F
0005435982392	26701	71	17A
0005435982195	26701	72	17C
0005435982189	26701	73	17D
0005435982122	26701	74	17F
0005433434827	26701	75	18C
0005435981992	26701	76	18D
0005435982091	26701	77	18E
0005433434828	26701	78	18F
0005433434826	26701	79	19A
0005433434829	26701	80	19C
0005435982136	26701	81	19D
0005434269115	26701	82	19E
0005435982144	26701	83	19F
0005433434814	26701	84	20A
0005435982145	26701	85	20C
0005433434833	26701	86	20D
0005433434837	26701	87	20E
0005435982134	26701	88	20F
0005432584171	3188	1	1A
0005432584174	3188	2	1C
0005432584173	3188	3	1D
0005432584164	3188	4	2A
0005432858014	3188	5	2B
0005432584159	3188	6	2C
0005432584162	3188	7	2D
0005432584158	3188	8	3A
0005432858012	3188	9	3B
0005432857999	3188	10	3C
0005432584151	3188	11	3D
0005432584160	3188	12	5A
0005432858045	3188	13	5B
0005432216287	3188	14	5C
0005432584152	3188	15	5D
0005432584167	3188	16	6A
0005432584153	3188	17	6C
0005432584163	3188	18	6D
0005432858020	3188	19	7A
0005432584172	3188	20	7B
0005432584154	3188	21	7C
0005432858010	3188	22	7D
0005432858006	3188	23	18A
0005432858015	3188	24	18B
0005432584168	3188	25	18C
0005432858005	3188	26	18D
0005432584166	3188	27	19A
0005432584157	3188	28	19C
0005432858011	3188	29	19D
0005432216286	3188	30	20B
0005432858044	3188	31	20C
0005432584156	3188	32	20D
0005432584155	3188	33	21A
0005432584169	3188	34	21B
0005432216288	3188	35	21C
0005432584161	3188	36	21D
0005432584175	3188	37	22A
0005432584170	3188	38	22B
0005432858004	3188	39	22C
0005432584165	3188	40	23A
0005432216285	3188	41	23B
0005432583916	31513	1	1A
0005432858127	31513	2	1C
0005432584021	31513	3	2D
0005432858132	31513	4	3A
0005432858123	31513	5	3B
0005432858126	31513	6	3C
0005432858133	31513	7	3D
0005432583872	31513	8	4A
0005432858128	31513	9	4C
0005432583970	31513	10	5A
0005432858134	31513	11	5B
0005432583958	31513	12	5C
0005432858131	31513	13	5D
0005432584000	31513	14	6A
0005432858125	31513	15	7A
0005432583941	31513	16	7B
0005432583868	31513	17	7D
0005432583917	31513	18	18A
0005432584019	31513	19	18C
0005432583960	31513	20	19A
0005432583867	31513	21	19B
0005432583972	31513	22	19D
0005432583871	31513	23	20A
0005432583959	31513	24	20C
0005432583942	31513	25	20D
0005432858130	31513	26	21A
0005432858129	31513	27	21D
0005432584013	31513	28	22B
0005432583971	31513	29	22C
0005432583869	31513	30	22D
0005432858124	31513	31	23A
0005432583973	31513	32	23B
0005434943396	902	1	1A
0005434943401	902	2	3C
0005434943397	902	3	6A
0005434943394	902	4	6B
0005433255111	902	5	6D
0005434943400	902	6	7B
0005433255098	902	7	18B
0005433255084	902	8	18D
0005434943402	902	9	19A
0005434943393	902	10	19D
0005433255097	902	11	20B
0005434943398	902	12	21A
0005434943399	902	13	21B
0005434943395	902	14	22D
0005434943354	16245	1	1A
0005434943355	16245	2	1B
0005433255148	16245	3	4A
0005433255146	16245	4	6C
0005433255149	16245	5	6D
0005434943344	16245	6	18B
0005434943347	16245	7	20A
0005434943323	16245	8	21B
0005434943343	16245	9	23A
0005433255147	16245	10	23B
0005433811625	14358	1	1A
0005433811631	14358	2	2A
0005433811624	14358	3	6A
0005433811628	14358	4	6B
0005435653248	21777	1	1A
0005433367750	21777	2	1C
0005433367672	21777	3	1D
0005433367748	21777	4	2A
0005433367711	21777	5	2C
0005435653251	21777	6	2D
0005433367718	21777	7	2F
0005433367855	21777	8	3A
0005433367770	21777	9	3C
0005433367790	21777	10	3F
0005433367731	21777	11	4A
0005433367659	21777	12	4C
0005435653242	21777	13	4D
0005433367758	21777	14	4E
0005435653244	21777	15	4F
0005433367734	21777	16	5C
0005433367733	21777	17	5D
0005433367505	21777	18	5E
0005433367673	21777	19	5F
0005433367817	21777	20	6A
0005435653245	21777	21	6C
0005435653257	21777	22	6D
0005433367751	21777	23	6F
0005433367776	21777	24	7A
0005435653254	21777	25	7C
0005433367506	21777	26	7D
0005433367717	21777	27	7F
0005433367693	21777	28	8A
0005433367604	21777	29	8C
0005433367691	21777	30	8D
0005433367712	21777	31	8F
0005433367703	21777	32	9A
0005433367682	21777	33	9C
0005435653241	21777	34	9D
0005433367732	21777	35	9E
0005433367605	21777	36	9F
0005433367808	21777	37	10A
0005433367766	21777	38	10C
0005435653253	21777	39	10D
0005435653247	21777	40	10E
0005433367724	21777	41	10F
0005435653255	21777	42	11A
0005433367856	21777	43	11D
0005433367753	21777	44	12E
0005435653260	21777	45	12F
0005433367694	21777	46	13A
0005435653258	21777	47	13C
0005433367775	21777	48	13D
0005433367656	21777	49	13E
0005433367683	21777	50	14A
0005433367853	21777	51	14C
0005435653256	21777	52	14D
0005433367692	21777	53	14E
0005433367729	21777	54	15A
0005435653261	21777	55	15C
0005433367769	21777	56	15D
0005433367765	21777	57	15E
0005435653243	21777	58	15F
0005433367789	21777	59	16A
0005433367574	21777	60	16C
0005435653252	21777	61	16D
0005435653238	21777	62	16E
0005435653246	21777	63	16F
0005435653239	21777	64	17A
0005435653259	21777	65	17C
0005433367679	21777	66	17E
0005435653249	21777	67	17F
0005435653250	21777	68	18A
0005433367749	21777	69	18C
0005433367818	21777	70	18F
0005433367852	21777	71	19A
0005435653240	21777	72	19C
0005433367807	21777	73	19F
0005433367627	21777	74	20A
0005433367798	21777	75	20C
0005435653237	21777	76	20D
0005433785131	9344	1	1C
0005433785151	9344	2	1G
0005433805552	9344	3	2A
0005433805571	9344	4	2F
0005433805549	9344	5	3A
0005434170980	9344	6	3F
0005433763285	9344	7	4A
0005433805542	9344	8	3H
0005433763275	9344	9	4B
0005433785148	9344	10	4C
0005433785146	9344	11	4F
0005433785130	9344	12	5A
0005433805547	9344	13	5B
0005433805553	9344	14	5G
0005433805541	9344	15	9A
0005433785129	9344	16	9H
0005432657465	9344	17	9B
0005433763277	9344	18	11B
0005433785144	9344	19	11E
0005433805565	9344	20	11H
0005432657463	9344	21	12D
0005433785117	9344	22	12H
0005433785112	9344	23	13A
0005432665284	9344	24	14A
0005433805563	9344	25	13H
0005433763282	9344	26	14D
0005435269695	9344	27	14E
0005433805548	9344	28	14F
0005433785122	9344	29	15B
0005435269709	9344	30	15D
0005435269708	9344	31	15G
0005434273072	9344	32	16A
0005433785124	9344	33	16D
0005433785110	9344	34	16B
0005433785120	9344	35	16G
0005433785147	9344	36	17A
0005433805551	9344	37	17D
0005435269724	9344	38	17F
0005433805538	9344	39	17E
0005433805546	9344	40	17G
0005434171008	9344	41	18A
0005433785134	9344	42	18D
0005433763284	9344	43	18F
0005434171006	9344	44	18E
0005434170929	9344	45	19A
0005433805560	9344	46	18H
0005434171042	9344	47	19E
0005433805539	9344	48	20A
0005433785139	9344	49	20D
0005433805545	9344	50	20B
0005433785125	9344	51	20E
0005433805568	9344	52	20H
0005434151691	9344	53	21A
0005433763274	9344	54	21B
0005435269706	9344	55	21E
0005435269713	9344	56	21D
0005434171039	9344	57	21G
0005433805537	9344	58	21F
0005433785115	9344	59	21H
0005434171045	9344	60	22D
0005433805561	9344	61	22F
0005433763280	9344	62	22E
0005432657464	9344	63	22G
0005433785140	9344	64	23E
0005433785116	9344	65	23G
0005433785136	9344	66	23F
0005433785143	9344	67	24A
0005432666399	9344	68	23H
0005433805558	9344	69	24E
0005433785142	9344	70	24D
0005433805554	9344	71	24F
0005433785118	9344	72	24G
0005433785121	9344	73	25F
0005433805564	9344	74	25D
0005433785145	9344	75	27E
0005433805540	9344	76	27G
0005434170979	9344	77	27F
0005433763286	9344	78	27H
0005435269723	9344	79	28B
0005433805544	9344	80	28D
0005435269722	9344	81	28F
0005433805570	9344	82	28H
0005434171090	9344	83	29D
0005433785141	9344	84	29B
0005433785138	9344	85	29F
0005433763276	9344	86	29G
0005432665285	9344	87	29H
0005433785111	9344	88	30A
0005433805559	9344	89	30G
0005434273074	9344	90	31B
0005433785132	9344	91	31A
0005433805543	9344	92	31F
0005433763283	9344	93	32A
0005433805569	9344	94	32B
0005435269707	9344	95	32D
0005433763281	9344	96	32E
0005434151699	9344	97	32G
0005435269718	9344	98	33A
0005433785126	9344	99	32H
0005433785119	9344	100	33B
0005433785135	9344	101	33D
0005433805572	9344	102	33H
0005433785114	9344	103	33G
0005433785113	9344	104	34B
0005435269693	9344	105	34A
0005433805556	9344	106	34D
0005433805550	9344	107	34E
0005433785150	9344	108	34F
0005433763279	9344	109	34H
0005433785123	9344	110	35B
0005434171007	9344	111	35A
0005433763278	9344	112	35E
0005433763273	9344	113	35G
0005433805557	9344	114	35H
0005434273073	9344	115	36D
0005433805562	9344	116	36F
0005433763272	9344	117	36E
0005433785152	9344	118	37D
0005432667464	9344	119	37B
0005435269719	9344	120	37F
0005433785133	9344	121	37H
0005433805567	9344	122	37G
0005433785137	9344	123	38A
0005433805555	9344	124	38B
0005433805536	9344	125	38E
0005433785127	9344	126	38D
0005434170930	9344	127	38F
0005433785149	9344	128	38H
0005433785128	9344	129	39D
0005433805566	9344	130	39E
0005433805133	26240	1	1A
0005433784768	26240	2	1F
0005433763110	26240	3	1G
0005433763125	26240	4	2A
0005433784828	26240	5	2B
0005433784807	26240	6	2C
0005434171126	26240	7	2F
0005433784957	26240	8	3A
0005433805210	26240	9	2H
0005432659698	26240	10	3C
0005433784729	26240	11	3F
0005434171129	26240	12	4B
0005433805397	26240	13	4C
0005434171130	26240	14	4G
0005434270216	26240	15	5B
0005433763148	26240	16	5A
0005433763157	26240	17	5C
0005433784717	26240	18	5F
0005434171134	26240	19	9A
0005434151717	26240	20	9B
0005433805088	26240	21	11A
0005433805224	26240	22	9H
0005432659693	26240	23	11E
0005435269774	26240	24	11D
0005434151718	26240	25	11F
0005435269775	26240	26	11H
0005433763129	26240	27	12A
0005433805251	26240	28	12D
0005433784865	26240	29	12B
0005434171124	26240	30	12E
0005433784778	26240	31	12F
0005433784773	26240	32	12G
0005434171122	26240	33	13F
0005434171123	26240	34	13E
0005432666387	26240	35	13H
0005432657427	26240	36	13G
0005433784823	26240	37	14A
0005433805250	26240	38	14F
0005433763132	26240	39	14G
0005433784774	26240	40	15B
0005433784816	26240	41	15E
0005433805275	26240	42	16E
0005433784919	26240	43	16G
0005433784526	26240	44	17B
0005433784968	26240	45	17F
0005434151719	26240	46	17H
0005433784877	26240	47	18B
0005433784772	26240	48	18A
0005433805160	26240	49	18F
0005433805414	26240	50	18E
0005433805226	26240	51	18G
0005433784918	26240	52	19B
0005434171127	26240	53	19A
0005433763109	26240	54	19D
0005433805322	26240	55	19G
0005433784689	26240	56	20D
0005434171132	26240	57	20E
0005434171133	26240	58	20G
0005433763126	26240	59	21A
0005434171131	26240	60	20H
0005432657442	26240	61	21D
0005433763128	26240	62	21B
0005433805298	26240	63	21E
0005435269776	26240	64	21F
0005433805184	26240	65	21H
0005433763149	26240	66	22A
0005433805357	26240	67	22F
0005433763173	26240	68	22G
0005433784829	26240	69	23B
0005433763181	26240	70	23G
0005432666379	26240	71	24B
0005433763133	26240	72	24D
0005434271321	26240	73	24E
0005432657428	26240	74	24H
0005433805348	26240	75	25D
0005433805193	26240	76	25F
0005433784866	26240	77	27B
0005433784956	26240	78	27E
0005433805183	26240	79	27F
0005433784815	26240	80	27H
0005433784730	26240	81	28D
0005433805248	26240	82	28E
0005433763179	26240	83	28H
0005434271320	26240	84	28G
0005434171135	26240	85	29A
0005432659692	26240	86	29B
0005433805191	26240	87	29E
0005433805174	26240	88	29F
0005433805211	26240	89	29H
0005432666378	26240	90	30B
0005434270215	26240	91	30A
0005433784767	26240	92	30D
0005433784821	26240	93	30G
0005434269113	26240	94	31A
0005432659694	26240	95	30H
0005433784902	26240	96	31F
0005433805252	26240	97	31G
0005433784814	26240	98	32F
0005433784723	26240	99	32E
0005432666377	26240	100	32H
0005433763153	26240	101	33A
0005433805229	26240	102	33D
0005433805087	26240	103	33B
0005433784833	26240	104	33E
0005434269112	26240	105	33G
0005433805382	26240	106	33F
0005433784859	26240	107	34B
0005432657426	26240	108	34D
0005433805283	26240	109	34H
0005433784721	26240	110	35B
0005433784899	26240	111	35A
0005433805225	26240	112	35E
0005432666366	26240	113	35G
0005433805209	26240	114	36A
0005433784722	26240	115	36D
0005434151720	26240	116	36F
0005434171128	26240	117	37D
0005433784680	26240	118	37B
0005432659697	26240	119	37E
0005433784895	26240	120	37F
0005434171125	26240	121	37H
0005432657441	26240	122	37G
0005433805192	26240	123	38D
0005433763124	26240	124	38B
0005433784969	26240	125	38E
0005433785021	26240	126	38F
0005433805325	26240	127	38H
0005433784943	26240	128	38G
0005434269111	26240	129	39D
0005433784808	26240	130	39F
0005435929635	4929	1	1D
0005435135695	4929	2	2C
0005435929638	4929	3	4A
0005435135692	4929	4	5A
0005435929627	4929	5	18A
0005435929626	4929	6	19B
0005435929623	4929	7	20A
0005435135696	4929	8	20D
0005435135694	4929	9	21D
0005435135693	4929	10	22A
0005435135666	33032	1	1B
0005435135649	33032	2	1C
0005435929656	33032	3	2C
0005435135665	33032	4	4B
0005435929658	33032	5	5A
0005435135651	33032	6	7B
0005435135650	33032	7	7C
0005435135627	33032	8	18A
0005435929657	33032	9	19B
0005435135652	33032	10	19C
0005435135675	33032	11	20C
0005435135658	33032	12	20D
0005434217951	9501	1	1C
0005434983316	9501	2	2C
0005434217945	9501	3	3A
0005434217932	9501	4	3B
0005434983315	9501	5	4D
0005434983314	9501	6	5D
0005434983313	9501	7	19A
0005434983312	9501	8	19C
0005434983311	9501	9	23A
0005434217950	9501	10	23B
0005434217989	27342	1	6C
0005434983254	27342	2	7B
0005434983276	27342	3	7D
0005434217990	27342	4	18A
0005434217988	27342	5	18C
0005434983277	27342	6	19C
0005434983253	27342	7	21D
0005433960567	24261	1	1A
0005433960486	24261	2	1B
0005433985652	24261	3	1G
0005433960590	24261	4	2C
0005433960645	24261	5	2G
0005433960266	24261	6	3C
0005433985753	24261	7	3H
0005433985714	24261	8	4A
0005433960643	24261	9	4F
0005433985693	24261	10	5A
0005433985691	24261	11	4H
0005433960647	24261	12	5F
0005433985677	24261	13	5H
0005433960338	24261	14	9A
0005433960491	24261	15	9H
0005433960636	24261	16	11D
0005433960656	24261	17	11F
0005433960662	24261	18	11G
0005433960602	24261	19	12E
0005433960601	24261	20	12D
0005433960384	24261	21	12G
0005433960638	24261	22	13B
0005433960447	24261	23	13E
0005433985651	24261	24	13G
0005433985680	24261	25	14B
0005433960576	24261	26	14A
0005433960444	24261	27	14H
0005433960578	24261	28	14G
0005433960614	24261	29	15B
0005433960577	24261	30	15E
0005433960627	24261	31	15H
0005433985685	24261	32	16A
0005433960640	24261	33	16E
0005433960644	24261	34	16H
0005433960403	24261	35	17A
0005433985476	24261	36	17D
0005433985722	24261	37	17B
0005433960630	24261	38	17F
0005433960598	24261	39	17E
0005433960591	24261	40	18D
0005433960496	24261	41	18B
0005433960485	24261	42	18F
0005433960515	24261	43	18E
0005433960445	24261	44	18H
0005433960566	24261	45	19B
0005433960587	24261	46	19A
0005433985686	24261	47	19F
0005433960655	24261	48	19G
0005433985687	24261	49	19H
0005433960420	24261	50	20E
0005433960589	24261	51	20H
0005433985431	24261	52	21A
0005433985590	24261	53	21B
0005433960616	24261	54	21E
0005433960497	24261	55	21F
0005433985667	24261	56	22E
0005433985678	24261	57	22G
0005433960537	24261	58	23D
0005433985755	24261	59	23F
0005433985684	24261	60	23H
0005433960613	24261	61	24F
0005433985569	24261	62	25D
0005433985689	24261	63	24H
0005433960554	24261	64	25E
0005433960498	24261	65	27B
0005433985668	24261	66	27A
0005433960637	24261	67	27D
0005433985475	24261	68	27H
0005433960540	24261	69	28A
0005433960389	24261	70	28D
0005433960514	24261	71	28B
0005433985534	24261	72	28G
0005433985624	24261	73	29E
0005433985713	24261	74	29H
0005433960385	24261	75	30B
0005433960536	24261	76	30A
0005433960446	24261	77	30D
0005433985648	24261	78	30F
0005433985535	24261	79	30E
0005433960463	24261	80	30G
0005433985432	24261	81	31B
0005433960492	24261	82	31D
0005433960484	24261	83	31G
0005433960337	24261	84	32D
0005433985542	24261	85	32A
0005433960639	24261	86	32F
0005433960573	24261	87	32H
0005433960412	24261	88	33A
0005433985679	24261	89	33D
0005433985737	24261	90	33E
0005433985692	24261	91	33F
0005433960606	24261	92	34B
0005433960572	24261	93	34D
0005433985688	24261	94	34F
0005433960539	24261	95	34E
0005433985585	24261	96	34G
0005433960608	24261	97	35A
0005433985560	24261	98	35H
0005433985752	24261	99	36B
0005433960654	24261	100	36E
0005433960657	24261	101	36D
0005433985709	24261	102	36F
0005433985672	24261	103	36H
0005433960617	24261	104	37E
0005433960615	24261	105	37F
0005433985712	24261	106	38E
0005433985541	24261	107	38F
0005433960501	24261	108	38G
0005433961146	25960	1	1C
0005433961139	25960	2	1B
0005433961143	25960	3	1F
0005433986166	25960	4	2A
0005433961154	25960	5	1H
0005433986152	25960	6	2H
0005433986146	25960	7	2G
0005433986172	25960	8	3A
0005433986140	25960	9	3F
0005433961125	25960	10	3G
0005433961132	25960	11	4A
0005433986139	25960	12	4C
0005433986168	25960	13	5B
0005433961115	25960	14	5A
0005433986132	25960	15	5C
0005433961160	25960	16	9B
0005433961150	25960	17	11A
0005433986134	25960	18	11E
0005433986160	25960	19	11D
0005433986174	25960	20	11F
0005433961120	25960	21	11H
0005433961111	25960	22	12G
0005433986161	25960	23	13A
0005433986159	25960	24	13D
0005433986131	25960	25	13B
0005433961141	25960	26	13G
0005433961137	25960	27	14A
0005433961148	25960	28	14D
0005433986138	25960	29	14F
0005433986155	25960	30	15B
0005433986167	25960	31	15F
0005433986141	25960	32	15H
0005433961153	25960	33	15G
0005433961145	25960	34	16A
0005433961138	25960	35	17B
0005433961147	25960	36	17A
0005433961161	25960	37	17D
0005433961122	25960	38	17E
0005433986173	25960	39	18A
0005433986162	25960	40	17H
0005433986156	25960	41	18D
0005433986169	25960	42	18F
0005433961156	25960	43	18G
0005433961126	25960	44	18H
0005433961134	25960	45	19E
0005433986157	25960	46	19D
0005433961110	25960	47	19H
0005433986144	25960	48	20D
0005433986130	25960	49	20G
0005433961142	25960	50	20F
0005433986164	25960	51	21B
0005433961130	25960	52	21D
0005433961114	25960	53	21H
0005433986145	25960	54	22A
0005433986136	25960	55	22F
0005433961121	25960	56	22G
0005433961116	25960	57	22H
0005433961123	25960	58	23A
0005433961124	25960	59	23G
0005433986150	25960	60	24A
0005433961129	25960	61	23H
0005433986149	25960	62	24D
0005433961117	25960	63	24F
0005433961164	25960	64	27A
0005433961119	25960	65	27D
0005433986143	25960	66	27F
0005433961127	25960	67	28A
0005433961157	25960	68	28B
0005433961113	25960	69	29B
0005433961135	25960	70	29G
0005433961149	25960	71	29H
0005433961128	25960	72	30B
0005433986133	25960	73	30E
0005433986135	25960	74	30G
0005433961159	25960	75	30H
0005433986158	25960	76	31E
0005433986170	25960	77	31D
0005433986147	25960	78	31G
0005433986163	25960	79	31H
0005433961136	25960	80	33A
0005433961163	25960	81	33H
0005433986151	25960	82	34F
0005433961131	25960	83	34E
0005433986137	25960	84	34G
0005433961155	25960	85	34H
0005433961133	25960	86	35D
0005433986148	25960	87	35B
0005433961140	25960	88	35G
0005433961144	25960	89	35H
0005433961112	25960	90	36B
0005433986165	25960	91	36F
0005433986153	25960	92	37B
0005433961158	25960	93	37D
0005433986171	25960	94	37F
0005433961162	25960	95	37G
0005433986142	25960	96	38B
0005433961152	25960	97	38E
0005433986154	25960	98	38F
0005433986175	25960	99	38H
0005433961151	25960	100	39E
0005433961118	25960	101	39F
0005433165902	947	1	1A
0005434480464	947	2	1B
0005434480458	947	3	1C
0005433165857	947	4	1D
0005434480456	947	5	2A
0005433165809	947	6	2B
0005434480448	947	7	2C
0005433165835	947	8	2D
0005434480446	947	9	3A
0005434480452	947	10	3B
0005432269509	947	11	3C
0005434480453	947	12	3D
0005434480451	947	13	4A
0005433165834	947	14	4B
0005433165836	947	15	4C
0005432269510	947	16	4D
0005433165858	947	17	5A
0005433165891	947	18	5B
0005434480466	947	19	5C
0005433165908	947	20	5D
0005434480463	947	21	6A
0005433165833	947	22	6B
0005434480460	947	23	6C
0005433165897	947	24	6D
0005434480454	947	25	7A
0005434480455	947	26	7B
0005433165846	947	27	7C
0005434480449	947	28	7D
0005433165916	947	29	18A
0005434480447	947	30	18B
0005433165915	947	31	18C
0005433165907	947	32	18D
0005433165845	947	33	19B
0005434480462	947	34	19C
0005434480459	947	35	19D
0005433165808	947	36	20A
0005434480469	947	37	20B
0005434480457	947	38	20C
0005434480467	947	39	20D
0005434480468	947	40	21A
0005434480450	947	41	21B
0005433165898	947	42	21C
0005432269508	947	43	21D
0005434480461	947	44	22B
0005434480465	947	45	22C
0005433165807	947	46	22D
0005433165906	947	47	23A
0005433165853	947	48	23B
0005434480188	16551	1	1C
0005434480336	16551	2	1D
0005433165965	16551	3	2B
0005434480187	16551	4	2D
0005434480298	16551	5	3A
0005434480265	16551	6	3C
0005433165976	16551	7	3D
0005433165974	16551	8	4B
0005433165966	16551	9	4C
0005433165967	16551	10	4D
0005433165969	16551	11	5A
0005434480169	16551	12	5C
0005433165971	16551	13	5D
0005434480280	16551	14	6A
0005434480173	16551	15	6C
0005434480239	16551	16	6B
0005433165973	16551	17	7B
0005433165975	16551	18	7C
0005433165964	16551	19	7D
0005434480272	16551	20	18A
0005434480328	16551	21	18D
0005434480128	16551	22	19A
0005434480266	16551	23	19C
0005434480267	16551	24	19D
0005433165968	16551	25	20B
0005433165963	16551	26	20C
0005434480225	16551	27	21A
0005434480192	16551	28	21C
0005434480279	16551	29	21D
0005434480278	16551	30	22A
0005434480233	16551	31	22B
0005434480174	16551	32	22C
0005433165970	16551	33	22D
0005433165972	16551	34	23B
0005435150088	10352	1	1A
0005435386555	10352	2	1B
0005433289794	10352	3	1C
0005435150087	10352	4	1D
0005435142634	10352	5	2A
0005435386564	10352	6	2B
0005435150091	10352	7	2D
0005435386535	10352	8	3A
0005435142631	10352	9	3B
0005435142638	10352	10	3D
0005433289818	10352	11	4A
0005433289793	10352	12	4C
0005435386552	10352	13	5A
0005435142632	10352	14	5B
0005435150089	10352	15	5C
0005435142629	10352	16	5D
0005435386540	10352	17	6B
0005435386553	10352	18	6D
0005435150090	10352	19	7A
0005435142637	10352	20	7B
0005435386556	10352	21	7C
0005435150082	10352	22	7D
0005433289832	10352	23	18A
0005435142626	10352	24	18B
0005433289808	10352	25	18C
0005435150092	10352	26	19A
0005435150086	10352	27	19B
0005435386539	10352	28	19C
0005435142627	10352	29	19D
0005435386522	10352	30	20A
0005435142636	10352	31	20B
0005435150085	10352	32	20C
0005435142635	10352	33	20D
0005435386574	10352	34	21A
0005435142639	10352	35	21B
0005435142628	10352	36	21C
0005435142630	10352	37	21D
0005433289815	10352	38	22A
0005435142633	10352	39	22D
0005435150084	10352	40	23A
0005435150083	10352	41	23B
0005433289894	21936	1	1A
0005433289889	21936	2	1B
0005435149955	21936	3	1C
0005435149924	21936	4	1D
0005435150025	21936	5	2B
0005435149970	21936	6	2C
0005435149959	21936	7	2D
0005435149981	21936	8	3C
0005435149982	21936	9	3D
0005433289887	21936	10	4A
0005435386602	21936	11	4B
0005435386598	21936	12	4C
0005433289892	21936	13	4D
0005435149958	21936	14	5B
0005435150007	21936	15	5D
0005435149980	21936	16	6A
0005433289891	21936	17	6B
0005435149969	21936	18	6C
0005435142532	21936	19	6D
0005435386600	21936	20	7B
0005435149983	21936	21	7C
0005435142506	21936	22	7D
0005435142503	21936	23	18A
0005435386599	21936	24	18B
0005435386601	21936	25	18D
0005435386604	21936	26	19A
0005435149968	21936	27	19B
0005435142504	21936	28	19C
0005435149925	21936	29	19D
0005435142610	21936	30	20A
0005433289893	21936	31	20B
0005435149967	21936	32	20C
0005435142551	21936	33	20D
0005435386603	21936	34	21B
0005433289890	21936	35	21C
0005435142518	21936	36	21D
0005433289888	21936	37	22A
0005435150004	21936	38	22B
0005435142533	21936	39	23A
0005435502197	11205	1	1A
0005435502289	11205	2	1C
0005435545682	11205	3	1F
0005435319549	11205	4	2A
0005435502244	11205	5	2F
0005435502253	11205	6	3A
0005435529150	11205	7	3D
0005435502245	11205	8	3F
0005434573408	11205	9	4A
0005435502129	11205	10	4C
0005435502282	11205	11	4D
0005434573417	11205	12	4E
0005435529148	11205	13	5A
0005435502199	11205	14	5C
0005434573406	11205	15	5D
0005435529090	11205	16	5E
0005435502177	11205	17	5F
0005435502297	11205	18	6A
0005435529114	11205	19	6C
0005435545685	11205	20	6D
0005435502248	11205	21	6F
0005435502221	11205	22	7A
0005435545702	11205	23	7C
0005435319524	11205	24	7D
0005435502236	11205	25	7F
0005435529175	11205	26	8C
0005435502256	11205	27	8D
0005435529185	11205	28	8E
0005435502366	11205	29	8F
0005435502243	11205	30	9A
0005435545700	11205	31	9C
0005435529184	11205	32	9E
0005435319571	11205	33	9F
0005435529233	11205	34	10A
0005434573415	11205	35	10D
0005435319558	11205	36	10E
0005435545675	11205	37	10F
0005435502255	11205	38	11A
0005435529174	11205	39	11C
0005435529149	11205	40	11E
0005435502142	11205	41	11F
0005435319550	11205	42	12A
0005434573407	11205	43	12C
0005434573411	11205	44	12F
0005435529232	11205	45	13A
0005435529206	11205	46	13D
0005435502313	11205	47	13F
0005434573404	11205	48	14A
0005434573414	11205	49	14C
0005435502143	11205	50	14D
0005435502287	11205	51	14F
0005434573412	11205	52	15C
0005434573405	11205	53	15D
0005435502235	11205	54	15E
0005435529158	11205	55	15F
0005435319557	11205	56	16A
0005435529187	11205	57	16C
0005435545693	11205	58	16E
0005435502268	11205	59	16F
0005435529119	11205	60	17A
0005435529089	11205	61	17C
0005435545701	11205	62	17D
0005434573409	11205	63	17F
0005435502335	11205	64	18A
0005435502222	11205	65	18C
0005434573416	11205	66	18D
0005435502200	11205	67	18E
0005435502308	11205	68	18F
0005435545676	11205	69	19C
0005434573418	11205	70	19D
0005435502229	11205	71	19E
0005435502317	11205	72	19F
0005434573410	11205	73	20A
0005435529097	11205	74	20C
0005434573413	11205	75	20D
0005435502340	11205	76	20E
0005435529225	11205	77	20F
0005435517981	20910	1	1A
0005435502400	20910	2	1C
0005435517993	20910	3	1F
0005435517996	20910	4	2A
0005435319623	20910	5	2D
0005435502407	20910	6	3A
0005435517990	20910	7	3C
0005435502410	20910	8	4A
0005435319630	20910	9	4C
0005435517991	20910	10	4D
0005435517989	20910	11	5A
0005435517985	20910	12	5D
0005435517987	20910	13	5F
0005435517980	20910	14	6A
0005434573273	20910	15	6E
0005435502411	20910	16	7A
0005434573309	20910	17	7D
0005435319624	20910	18	7E
0005435502414	20910	19	7F
0005435502409	20910	20	8C
0005435508400	20910	21	8E
0005435517979	20910	22	8F
0005435508401	20910	23	9A
0005434573293	20910	24	9C
0005435502404	20910	25	9D
0005435508402	20910	26	9E
0005435502413	20910	27	9F
0005435502398	20910	28	10A
0005435517986	20910	29	10C
0005435517977	20910	30	10E
0005434573346	20910	31	10F
0005434573282	20910	32	11A
0005435508405	20910	33	11D
0005435502419	20910	34	11E
0005435502402	20910	35	11F
0005435502397	20910	36	12A
0005435502417	20910	37	12C
0005435502403	20910	38	12D
0005435319626	20910	39	12E
0005435502401	20910	40	12F
0005435517988	20910	41	13A
0005434573257	20910	42	13E
0005435508403	20910	43	13F
0005435319631	20910	44	14C
0005434573307	20910	45	14D
0005434573265	20910	46	14E
0005435319629	20910	47	14F
0005435517982	20910	48	15A
0005435319625	20910	49	15C
0005435319627	20910	50	15D
0005435517983	20910	51	15E
0005435517994	20910	52	15F
0005435517992	20910	53	16C
0005434573270	20910	54	16D
0005434573289	20910	55	16E
0005435502399	20910	56	16F
0005435502415	20910	57	17A
0005435508404	20910	58	17C
0005434573287	20910	59	17D
0005435502406	20910	60	17E
0005434573255	20910	61	17F
0005435502416	20910	62	18A
0005434573256	20910	63	18C
0005434573313	20910	64	18D
0005435319628	20910	65	18E
0005435502405	20910	66	18F
0005435502418	20910	67	19A
0005435517995	20910	68	19C
0005435517984	20910	69	19D
0005435502408	20910	70	19E
0005432291941	20910	71	20A
0005434573345	20910	72	20C
0005435502412	20910	73	20E
0005435517978	20910	74	20F
0005432692827	2984	1	1A
0005432693046	2984	2	1C
0005432692898	2984	3	2D
0005432692784	2984	4	3A
0005432692990	2984	5	3F
0005432692853	2984	6	4A
0005432692984	2984	7	4D
0005432692894	2984	8	5A
0005432692929	2984	9	5D
0005432692839	2984	10	5F
0005432692906	2984	11	6E
0005432692935	2984	12	7A
0005432692694	2984	13	7C
0005432692840	2984	14	8A
0005432692787	2984	15	8C
0005432692786	2984	16	8D
0005432692897	2984	17	9E
0005432692900	2984	18	10A
0005432692785	2984	19	10D
0005432692980	2984	20	11A
0005432692969	2984	21	11D
0005432692826	2984	22	11F
0005432692946	2984	23	12E
0005432692937	2984	24	13A
0005432692986	2984	25	13D
0005432692848	2984	26	14F
0005432693006	2984	27	15F
0005432692854	2984	28	17F
0005432693000	2984	29	18A
0005432692934	2984	30	19A
0005432692991	2984	31	19F
0005432692925	2984	32	20A
0005433194834	2987	1	1C
0005432880800	2987	2	1D
0005433123843	2987	3	1F
0005432706894	2987	4	2A
0005432706908	2987	5	2C
0005433123891	2987	6	2D
0005432880789	2987	7	2F
0005432880716	2987	8	3A
0005432880756	2987	9	3C
0005433123805	2987	10	3F
0005432706901	2987	11	4A
0005433123832	2987	12	4D
0005432706886	2987	13	5A
0005433123810	2987	14	5C
0005433194857	2987	15	5D
0005433123870	2987	16	5E
0005432217792	2987	17	5F
0005433194836	2987	18	6A
0005432217790	2987	19	6C
0005432880766	2987	20	6E
0005432706884	2987	21	7A
0005432880725	2987	22	7F
0005433123844	2987	23	8D
0005432706898	2987	24	9A
0005432706896	2987	25	9C
0005432706887	2987	26	9D
0005433123816	2987	27	9E
0005432706892	2987	28	9F
0005432706891	2987	29	10A
0005433194847	2987	30	10C
0005432706905	2987	31	10D
0005432706903	2987	32	10E
0005433123753	2987	33	11C
0005433123759	2987	34	11D
0005432880722	2987	35	11E
0005432706899	2987	36	11F
0005432706888	2987	37	12A
0005433123822	2987	38	12C
0005432706895	2987	39	12D
0005433123833	2987	40	12F
0005432706909	2987	41	13D
0005433123889	2987	42	13E
0005433194845	2987	43	13F
0005432706890	2987	44	14A
0005432706889	2987	45	14C
0005433123835	2987	46	14E
0005432706893	2987	47	14F
0005432706897	2987	48	15C
0005432706902	2987	49	15E
0005433123752	2987	50	15F
0005432706907	2987	51	16C
0005432880749	2987	52	16D
0005432706906	2987	53	16F
0005432880801	2987	54	17A
0005432880724	2987	55	17C
0005432880784	2987	56	17D
0005433123910	2987	57	17E
0005433123905	2987	58	17F
0005432880767	2987	59	18A
0005432706885	2987	60	18D
0005432706900	2987	61	18E
0005433123890	2987	62	18F
0005432217791	2987	63	19C
0005432217789	2987	64	19F
0005433123817	2987	65	20C
0005432880768	2987	66	20D
0005432706904	2987	67	20E
0005432693237	29927	1	1A
0005432880895	29927	2	1C
0005432693250	29927	3	1D
0005432706765	29927	4	1F
0005432706829	29927	5	2A
0005432693225	29927	6	2C
0005432706805	29927	7	2D
0005432706713	29927	8	2F
0005433124026	29927	9	3A
0005432706626	29927	10	3C
0005432706794	29927	11	3D
0005433124025	29927	12	3F
0005432880889	29927	13	4A
0005432706749	29927	14	4C
0005432706699	29927	15	4D
0005432880892	29927	16	4E
0005432693224	29927	17	4F
0005432706647	29927	18	5A
0005432706742	29927	19	5C
0005433124019	29927	20	5D
0005432693228	29927	21	5E
0005432706620	29927	22	5F
0005432693246	29927	23	6A
0005432880883	29927	24	6C
0005432693229	29927	25	6D
0005432693241	29927	26	6E
0005432706674	29927	27	6F
0005432693242	29927	28	7A
0005432706729	29927	29	7C
0005432706828	29927	30	7D
0005432706698	29927	31	7E
0005432880886	29927	32	7F
0005432706804	29927	33	8A
0005432693248	29927	34	8C
0005432706736	29927	35	8D
0005432706760	29927	36	8E
0005432706743	29927	37	8F
0005433124021	29927	38	9A
0005433124023	29927	39	9C
0005432693247	29927	40	9D
0005432880887	29927	41	9E
0005432706657	29927	42	9F
0005432693227	29927	43	10A
0005433124015	29927	44	10C
0005432693240	29927	45	10D
0005432706658	29927	46	10E
0005432693243	29927	47	10F
0005432706788	29927	48	11A
0005432706730	29927	49	11C
0005432706673	29927	50	11D
0005433124024	29927	51	11E
0005432706741	29927	52	11F
0005432706766	29927	53	12A
0005432693232	29927	54	12C
0005433124016	29927	55	12D
0005433124017	29927	56	12E
0005433124022	29927	57	12F
0005432706676	29927	58	13A
0005433124018	29927	59	13C
0005432880891	29927	60	13D
0005432880890	29927	61	13E
0005432693244	29927	62	13F
0005432706799	29927	63	14A
0005432706747	29927	64	14C
0005432880885	29927	65	14D
0005432706775	29927	66	14E
0005432880882	29927	67	14F
0005432706806	29927	68	15A
0005432693238	29927	69	15C
0005432706714	29927	70	15D
0005432693234	29927	71	15E
0005433124020	29927	72	15F
0005432693236	29927	73	16A
0005432693251	29927	74	16C
0005432693223	29927	75	16D
0005432880884	29927	76	16E
0005432706679	29927	77	17A
0005432706827	29927	78	17C
0005432880893	29927	79	17D
0005432693249	29927	80	17E
0005432880888	29927	81	17F
0005432706735	29927	82	18A
0005432693239	29927	83	18C
0005432693226	29927	84	18D
0005432693245	29927	85	18E
0005432706664	29927	86	18F
0005432693252	29927	87	19A
0005432693235	29927	88	19C
0005433124014	29927	89	19E
0005432706680	29927	90	19F
0005432880896	29927	91	20A
0005432880894	29927	92	20C
0005432693233	29927	93	20D
0005432693231	29927	94	20E
0005432693230	29927	95	20F
0005434979926	23665	1	1A
0005434988789	23665	2	1B
0005434979898	23665	3	1C
0005434979907	23665	4	2B
0005434979908	23665	5	2C
0005434979921	23665	6	3A
0005434979911	23665	7	3B
0005434979927	23665	8	3C
0005434979923	23665	9	3D
0005434988790	23665	10	4A
0005434988787	23665	11	4B
0005434979901	23665	12	4C
0005434979913	23665	13	5A
0005434979917	23665	14	5B
0005434979925	23665	15	5C
0005434979915	23665	16	5D
0005434979909	23665	17	6A
0005434979924	23665	18	6B
0005434979918	23665	19	6C
0005434979905	23665	20	6D
0005434979899	23665	21	7B
0005434979906	23665	22	7C
0005434979910	23665	23	7D
0005434979900	23665	24	18B
0005434979928	23665	25	18D
0005434979916	23665	26	19A
0005434988786	23665	27	19C
0005434979904	23665	28	19D
0005434988784	23665	29	20B
0005434979903	23665	30	20C
0005434979902	23665	31	21A
0005434988785	23665	32	21B
0005434979914	23665	33	21C
0005434979920	23665	34	21D
0005434979919	23665	35	22B
0005434979912	23665	36	22C
0005434979922	23665	37	22D
0005434988788	23665	38	23A
0005434979628	27576	1	1A
0005434979558	27576	2	1B
0005434979726	27576	3	1C
0005434988676	27576	4	1D
0005434979601	27576	5	2B
0005434988662	27576	6	2A
0005434979673	27576	7	3A
0005434979697	27576	8	3B
0005434979639	27576	9	3C
0005434988670	27576	10	3D
0005434979848	27576	11	4A
0005434979761	27576	12	4B
0005434988673	27576	13	4D
0005434979638	27576	14	5A
0005434979675	27576	15	5C
0005434979579	27576	16	5D
0005434979698	27576	17	6A
0005434988672	27576	18	6B
0005434979674	27576	19	6C
0005434988699	27576	20	6D
0005434979692	27576	21	7A
0005434988663	27576	22	7B
0005434979633	27576	23	7D
0005434979622	27576	24	18A
0005434979702	27576	25	18B
0005434979632	27576	26	18C
0005434979758	27576	27	18D
0005434979600	27576	28	19A
0005434988698	27576	29	19B
0005434979605	27576	30	19D
0005434979693	27576	31	19C
0005434988700	27576	32	20A
0005434988701	27576	33	20D
0005434988637	27576	34	21A
0005434979843	27576	35	21B
0005434979659	27576	36	21C
0005434988689	27576	37	21D
0005434979663	27576	38	22A
0005434988669	27576	39	22B
0005434979627	27576	40	22C
0005434979711	27576	41	23A
0005434988691	27576	42	23B
0005433113527	10260	1	2A
0005434302475	10260	2	2C
0005433111498	10260	3	4C
0005434302477	10260	4	5C
0005434302476	10260	5	6A
0005433111483	10260	6	7D
0005434302478	10260	7	18B
0005433113536	10260	8	19D
0005433113532	10260	9	20D
0005433113528	10260	10	21A
0005433111484	10260	11	22D
0005433113547	19599	1	1B
0005433113546	19599	2	3A
0005434302438	19599	3	7A
0005434302454	19599	4	7C
0005434302430	19599	5	18A
0005434302453	19599	6	18D
0005434302446	19599	7	19D
0005434302443	19599	8	22B
0005434302447	19599	9	22C
0005434302455	19599	10	23B
0005435069324	3535	1	1A
0005435069363	3535	2	1C
0005435925250	3535	3	1D
0005435069339	3535	4	1F
0005435925249	3535	5	2C
0005435069340	3535	6	2D
0005435069372	3535	7	3C
0005435069344	3535	8	3D
0005435718985	3535	9	3F
0005435069355	3535	10	4A
0005435069332	3535	11	4C
0005435069328	3535	12	4D
0005435069346	3535	13	4E
0005435925221	3535	14	4F
0005435069366	3535	15	5A
0005435069342	3535	16	5C
0005435925245	3535	17	5D
0005435069330	3535	18	5E
0005435069338	3535	19	6A
0005435069359	3535	20	6C
0005435925268	3535	21	6F
0005435069357	3535	22	7A
0005435069349	3535	23	7D
0005435069343	3535	24	7E
0005435069348	3535	25	7F
0005435069370	3535	26	8C
0005435925222	3535	27	8D
0005435718980	3535	28	9A
0005435069334	3535	29	9C
0005435925270	3535	30	9D
0005435069351	3535	31	9E
0005435925209	3535	32	10A
0005435925246	3535	33	10D
0005435069353	3535	34	10E
0005435069373	3535	35	10F
0005435718983	3535	36	11D
0005435925256	3535	37	11E
0005435069369	3535	38	11F
0005435069362	3535	39	12C
0005435069336	3535	40	12D
0005435925207	3535	41	12E
0005435069335	3535	42	12F
0005435069367	3535	43	13A
0005435939872	3535	44	13D
0005435069350	3535	45	13E
0005435925252	3535	46	13F
0005435718986	3535	47	14A
0005435718984	3535	48	14C
0005435925269	3535	49	14D
0005435069358	3535	50	14E
0005435925247	3535	51	14F
0005435069333	3535	52	15A
0005435718981	3535	53	15C
0005435069365	3535	54	15D
0005435069345	3535	55	15E
0005435069374	3535	56	15F
0005435925239	3535	57	16A
0005435069361	3535	58	16C
0005435069347	3535	59	16F
0005435718982	3535	60	17A
0005435925244	3535	61	17C
0005435069352	3535	62	17D
0005435069356	3535	63	17E
0005435069360	3535	64	17F
0005435069325	3535	65	18A
0005435069368	3535	66	18C
0005435069341	3535	67	18D
0005435069371	3535	68	18E
0005435069329	3535	69	18F
0005435069364	3535	70	19C
0005435069376	3535	71	19A
0005435069327	3535	72	19D
0005435925208	3535	73	19E
0005435939871	3535	74	19F
0005435069354	3535	75	20A
0005435069337	3535	76	20C
0005435069375	3535	77	20D
0005435069326	3535	78	20E
0005435069331	3535	79	20F
0005435068739	15330	1	1A
0005435068755	15330	2	1C
0005435068790	15330	3	1F
0005435068998	15330	4	2A
0005435068793	15330	5	2C
0005435068848	15330	6	2F
0005435068885	15330	7	3F
0005435068411	15330	8	4A
0005435069062	15330	9	4C
0005435925363	15330	10	4E
0005435068808	15330	11	4F
0005435068667	15330	12	5A
0005435068938	15330	13	5C
0005435925361	15330	14	5E
0005435068847	15330	15	5F
0005435925362	15330	16	6A
0005435068881	15330	17	6C
0005435068816	15330	18	6D
0005435925357	15330	19	6E
0005435068410	15330	20	6F
0005435068913	15330	21	7C
0005435068814	15330	22	7D
0005435068798	15330	23	7F
0005435068674	15330	24	8C
0005435068719	15330	25	8D
0005435068791	15330	26	8E
0005435068997	15330	27	8F
0005435068675	15330	28	9A
0005435069159	15330	29	9C
0005435069158	15330	30	9D
0005435068949	15330	31	9E
0005435068935	15330	32	10A
0005435068841	15330	33	10C
0005435068740	15330	34	10D
0005435068801	15330	35	10E
0005435925359	15330	36	10F
0005435068756	15330	37	11A
0005435068933	15330	38	11D
0005435068813	15330	39	11E
0005435068810	15330	40	11F
0005435068840	15330	41	12A
0005435069007	15330	42	12C
0005435068993	15330	43	12D
0005435068953	15330	44	12E
0005435068811	15330	45	12F
0005435068629	15330	46	13A
0005435068720	15330	47	13E
0005435068934	15330	48	14A
0005435068839	15330	49	14D
0005435068857	15330	50	14F
0005435925364	15330	51	15A
0005435068628	15330	52	15C
0005435068866	15330	53	15D
0005435068638	15330	54	16A
0005435925360	15330	55	16D
0005435068954	15330	56	16E
0005435068856	15330	57	16F
0005435068880	15330	58	17A
0005435068950	15330	59	17C
0005435925358	15330	60	17D
0005435068854	15330	61	17E
0005435068921	15330	62	17F
0005435068800	15330	63	18A
0005435068807	15330	64	18C
0005435068792	15330	65	18D
0005435068815	15330	66	18E
0005435068855	15330	67	19C
0005435069045	15330	68	19D
0005435068980	15330	69	19E
0005435068752	15330	70	19F
0005435068637	15330	71	20C
0005435069074	15330	72	20D
0005435068858	15330	73	20E
0005432660828	18117	1	2A
0005432659718	18117	2	2B
0005432660827	18117	3	4A
0005432658600	18117	4	4B
0005432658601	18117	5	5B
0005432659717	18117	6	6A
0005432659716	18117	7	6B
0005432660802	26363	1	1A
0005432667445	26363	2	2A
0005432667449	26363	3	3A
0005432667448	26363	4	3B
0005432667440	26363	5	4B
0005432667446	26363	6	5B
0005432664125	26363	7	6B
0005432660806	26363	8	6A
0005432901515	36	1	1A
0005433101858	36	2	1D
0005432157502	36	3	2D
0005433101896	36	4	2C
0005433101992	36	5	2A
0005432901571	36	6	3A
0005433102002	36	7	2F
0005432901594	36	8	3D
0005433102006	36	9	3C
0005433102007	36	10	3F
0005433101854	36	11	4D
0005433101997	36	12	5D
0005433101882	36	13	6A
0005433101955	36	14	6C
0005432677537	36	15	6D
0005433101953	36	16	7C
0005432901545	36	17	8D
0005432901566	36	18	8C
0005433101790	36	19	8E
0005433102005	36	20	8F
0005433101958	36	21	9C
0005433101983	36	22	10A
0005433101907	36	23	9F
0005433101945	36	24	10C
0005432901514	36	25	10B
0005432919758	36	26	10D
0005432919768	36	27	10E
0005432919772	36	28	11A
0005432919808	36	29	10F
0005433101897	36	30	11E
0005433101987	36	31	12A
0005433101908	36	32	11F
0005433101894	36	33	12B
0005432901593	36	34	12D
0005433101927	36	35	12E
0005432919799	36	36	13A
0005432919869	36	37	13D
0005433101951	36	38	13E
0005432677560	36	39	14A
0005432677544	36	40	14B
0005433101956	36	41	14C
0005433101922	36	42	15A
0005432919857	36	43	14F
0005433101957	36	44	14E
0005433101779	36	45	15B
0005433101973	36	46	15E
0005433101925	36	47	16A
0005433101888	36	48	16B
0005433101932	36	49	16C
0005432919773	36	50	16E
0005433101712	36	51	16D
0005432919754	36	52	16F
0005432901592	36	53	17A
0005433102001	36	54	17C
0005433101889	36	55	17E
0005433101954	36	56	17D
0005432919868	36	57	18A
0005433101940	36	58	18B
0005432901555	36	59	18D
0005433101905	36	60	18F
0005432919813	36	61	19B
0005433101681	36	62	19D
0005432919793	36	63	19C
0005433101959	36	64	19E
0005432677538	36	65	20A
0005433102012	36	66	20C
0005433101989	36	67	20B
0005432919757	36	68	20E
0005433101926	36	69	20D
0005433101971	36	70	21D
0005433101974	36	71	21E
0005433101988	36	72	22B
0005433101869	36	73	22D
0005432919858	36	74	23A
0005432919874	36	75	23C
0005433101921	36	76	23B
0005432919800	36	77	23E
0005433101765	36	78	24B
0005432919770	36	79	24C
0005433102011	36	80	24D
0005433102008	36	81	24F
0005433101713	36	82	25B
0005432919776	36	83	25A
0005432919763	36	84	25E
0005432919755	36	85	26A
0005433101904	36	86	26B
0005432919760	36	87	26E
0005432677561	36	88	27C
0005433101931	36	89	27F
0005433101764	36	90	27E
0005433101944	36	91	28C
0005432901573	36	92	28A
0005432901544	36	93	28D
0005432901481	36	94	28E
0005433101995	36	95	29C
0005433101963	36	96	29E
0005432901570	36	97	30B
0005433101939	36	98	31D
0005432262120	37	1	1A
0005432262127	37	2	1D
0005432262139	37	3	1F
0005432262130	37	4	2C
0005432262147	37	5	2F
0005433690924	37	6	3D
0005432262136	37	7	3F
0005432817625	37	8	5D
0005432262140	37	9	6A
0005432207672	37	10	7A
0005432262132	37	11	7C
0005432262153	37	12	7F
0005432262152	37	13	8A
0005432262137	37	14	8B
0005432262154	37	15	8D
0005432262159	37	16	8E
0005432262133	37	17	9A
0005432289002	37	18	8F
0005432289004	37	19	9C
0005432262161	37	20	9B
0005432262155	37	21	9D
0005432262131	37	22	9F
0005432817626	37	23	9E
0005432262134	37	24	10D
0005433687699	37	25	10C
0005432262148	37	26	10F
0005432756824	37	27	11C
0005432262126	37	28	11D
0005432262160	37	29	11E
0005432817613	37	30	12A
0005432817623	37	31	11F
0005432262125	37	32	12B
0005433687698	37	33	12E
0005432262143	37	34	12D
0005432817608	37	35	13A
0005432817635	37	36	13C
0005432262158	37	37	13D
0005432262135	37	38	13F
0005432262146	37	39	14B
0005432262124	37	40	14C
0005432817615	37	41	14D
0005432817622	37	42	14F
0005432756822	37	43	15E
0005432817632	37	44	16A
0005433690923	37	45	15F
0005433690917	37	46	16B
0005432262116	37	47	16D
0005432817631	37	48	16E
0005432262122	37	49	16F
0005432756823	37	50	17D
0005432817614	37	51	17F
0005432207673	37	52	18C
0005432817627	37	53	18E
0005432262157	37	54	18F
0005433687700	37	55	19B
0005432262156	37	56	19D
0005432262150	37	57	19C
0005432262141	37	58	19E
0005432817620	37	59	20C
0005432207671	37	60	20F
0005432817633	37	61	20E
0005432262142	37	62	21D
0005432817607	37	63	21C
0005432756827	37	64	21E
0005432817618	37	65	22A
0005432262123	37	66	22E
0005432756817	37	67	22D
0005432289001	37	68	23B
0005432817617	37	69	23C
0005432817630	37	70	23D
0005432817612	37	71	23E
0005432817624	37	72	24A
0005432262118	37	73	24E
0005432756816	37	74	25A
0005432817619	37	75	25B
0005432262129	37	76	25F
0005432817611	37	77	25E
0005432262162	37	78	26A
0005432262145	37	79	26B
0005432817634	37	80	26E
0005432262128	37	81	27A
0005433687689	37	82	27C
0005432262144	37	83	27E
0005432817629	37	84	27F
0005432262149	37	85	28B
0005432817616	37	86	28E
0005432753289	37	87	28F
0005432262117	37	88	29E
0005432262119	37	89	30A
0005433690918	37	90	29F
0005432817609	37	91	30B
0005432262121	37	92	30D
0005432817610	37	93	30E
0005433687693	37	94	30F
0005432262138	37	95	31A
0005432817621	37	96	31C
0005432289003	37	97	31B
0005432817606	37	98	31E
0005432817628	37	99	31D
0005432262151	37	100	31F
0005433102438	7918	1	1A
0005432919965	7918	2	1C
0005432919960	7918	3	2C
0005432392017	7918	4	2A
0005433102403	7918	5	2F
0005432919957	7918	6	2D
0005432020405	7918	7	3A
0005433102431	7918	8	3D
0005433102434	7918	9	3C
0005433102440	7918	10	4D
0005433102420	7918	11	4C
0005433102400	7918	12	5A
0005432020403	7918	13	4F
0005433102399	7918	14	5F
0005432020387	7918	15	6A
0005433102422	7918	16	6C
0005432020404	7918	17	6D
0005433102427	7918	18	7A
0005433102429	7918	19	6F
0005433102421	7918	20	7C
0005433102397	7918	21	7D
0005433102407	7918	22	8A
0005432919954	7918	23	8B
0005433102412	7918	24	8C
0005432753319	7918	25	8E
0005432919956	7918	26	8F
0005432020398	7918	27	9B
0005432919966	7918	28	9C
0005433102428	7918	29	9D
0005432392014	7918	30	9F
0005432753318	7918	31	10A
0005432020386	7918	32	10C
0005433102411	7918	33	10D
0005433102416	7918	34	10E
0005432919968	7918	35	10F
0005433102441	7918	36	11B
0005432392016	7918	37	11A
0005432020392	7918	38	11C
0005432020396	7918	39	11E
0005432020389	7918	40	12A
0005432919964	7918	41	11F
0005433102402	7918	42	12B
0005433102414	7918	43	12C
0005432045623	7918	44	12E
0005432020390	7918	45	13A
0005433102413	7918	46	13B
0005433102418	7918	47	13D
0005433102436	7918	48	13F
0005432919973	7918	49	13E
0005432020393	7918	50	14C
0005432020397	7918	51	14E
0005433102425	7918	52	14D
0005433102435	7918	53	15B
0005432020391	7918	54	15A
0005433102405	7918	55	15C
0005433102404	7918	56	15F
0005432919955	7918	57	16B
0005432919971	7918	58	16D
0005432753317	7918	59	17A
0005432751544	7918	60	17B
0005432919963	7918	61	17C
0005433102408	7918	62	17D
0005432919952	7918	63	17E
0005433102401	7918	64	18B
0005433102395	7918	65	18E
0005432045624	7918	66	18F
0005433102439	7918	67	19B
0005432677595	7918	68	20A
0005433102423	7918	69	20C
0005433102430	7918	70	20E
0005433102396	7918	71	21B
0005432919953	7918	72	21A
0005433102424	7918	73	21D
0005432751543	7918	74	21C
0005432020401	7918	75	21E
0005432020385	7918	76	22A
0005433102419	7918	77	21F
0005432919970	7918	78	22B
0005432020399	7918	79	22D
0005432020388	7918	80	22F
0005432919972	7918	81	22E
0005432020409	7918	82	23A
0005433102406	7918	83	23B
0005433102398	7918	84	23D
0005432919962	7918	85	23E
0005432020394	7918	86	23F
0005432677594	7918	87	24C
0005432751542	7918	88	24E
0005433102410	7918	89	24F
0005433102415	7918	90	25B
0005432392015	7918	91	25A
0005433102394	7918	92	25C
0005432919969	7918	93	25E
0005432919967	7918	94	26D
0005432020408	7918	95	26E
0005432919961	7918	96	27A
0005432020402	7918	97	27B
0005432020407	7918	98	27D
0005432020395	7918	99	27C
0005433102409	7918	100	27F
0005433102417	7918	101	27E
0005432677596	7918	102	28B
0005433102426	7918	103	28F
0005432919959	7918	104	29A
0005432020400	7918	105	29C
0005432020384	7918	106	29F
0005433102437	7918	107	29E
0005432044539	7918	108	30A
0005433102432	7918	109	30B
0005432919958	7918	110	30E
0005433102433	7918	111	31A
0005432751545	7918	112	31C
0005432753320	7918	113	31D
0005432020406	7918	114	31E
0005432002087	8099	1	1C
0005432901692	8099	2	1A
0005432901694	8099	3	2A
0005432817345	8099	4	2F
0005432817396	8099	5	5A
0005432817465	8099	6	5D
0005432901691	8099	7	7D
0005432817295	8099	8	9A
0005432817304	8099	9	9C
0005432817279	8099	10	11B
0005432817395	8099	11	11C
0005432901695	8099	12	11E
0005432817459	8099	13	12A
0005432817377	8099	14	12C
0005432817344	8099	15	14E
0005432817355	8099	16	14D
0005432817508	8099	17	15B
0005432817424	8099	18	15A
0005432817277	8099	19	15C
0005432901693	8099	20	17A
0005432817338	8099	21	17D
0005432817408	8099	22	18D
0005432817429	8099	23	18E
0005432817318	8099	24	18F
0005432817305	8099	25	19D
0005432901703	8099	26	20A
0005432817412	8099	27	20D
0005432817340	8099	28	20F
0005432817460	8099	29	21A
0005432817373	8099	30	21C
0005432901704	8099	31	21B
0005432002086	8099	32	22D
0005432817420	8099	33	22E
0005432817422	8099	34	23E
0005432901702	8099	35	24B
0005432901699	8099	36	24E
0005432817278	8099	37	25D
0005432901700	8099	38	25E
0005432901690	8099	39	26A
0005432817319	8099	40	26F
0005432817423	8099	41	27C
0005432901701	8099	42	27D
0005432817220	8099	43	27E
0005432817466	8099	44	28B
0005432901698	8099	45	28E
0005432901706	8099	46	28D
0005432817456	8099	47	28F
0005432817187	8099	48	29D
0005432817339	8099	49	29E
0005432901696	8099	50	30A
0005432901697	8099	51	30B
0005432901705	8099	52	30C
0005432817252	8099	53	31A
0005432901689	8099	54	31E
0005434175725	9639	1	1A
0005434175715	9639	2	1B
0005433870742	9639	3	3B
0005434175729	9639	4	5B
0005434175733	9639	5	6A
0005433870718	32320	1	1B
0005433870719	32320	2	2A
0005434175774	32320	3	3A
0005434175776	32320	4	3B
0005433870724	32320	5	4B
0005434175775	32320	6	5A
0005434175773	32320	7	5B
0005433870717	32320	8	6A
0005434938249	3510	1	1C
0005434878679	3510	2	1A
0005434878721	3510	3	1H
0005434878728	3510	4	1D
0005434938246	3510	5	1K
0005432799593	3510	6	2C
0005434878762	3510	7	2A
0005434938235	3510	8	2H
0005434426753	3510	9	2D
0005434938242	3510	10	2K
0005434878760	3510	11	3K
0005435902578	3510	12	3G
0005434426763	3510	13	4A
0005435126582	3510	14	4G
0005432613882	3510	15	4K
0005434938236	3510	16	4H
0005434878696	3510	17	5A
0005435126581	3510	18	5H
0005434878697	3510	19	11C
0005434878759	3510	20	11G
0005434878727	3510	21	11E
0005435126563	3510	22	11K
0005434938245	3510	23	11H
0005434878690	3510	24	12C
0005434938244	3510	25	12A
0005434426752	3510	26	12E
0005435902643	3510	27	12D
0005434878723	3510	28	12G
0005434426750	3510	29	12F
0005435126567	3510	30	12H
0005434878758	3510	31	13D
0005434938237	3510	32	13E
0005435902681	3510	33	13H
0005435126596	3510	34	13G
0005435626282	3510	35	14A
0005435902663	3510	36	14E
0005435902549	3510	37	14D
0005434878687	3510	38	14C
0005435626267	3510	39	14G
0005432799597	3510	40	14K
0005435626268	3510	41	15D
0005434878689	3510	42	15F
0005435902613	3510	43	15K
0005434878706	3510	44	15H
0005432799604	3510	45	16D
0005435902635	3510	46	16A
0005435126597	3510	47	16E
0005434878672	3510	48	16K
0005432799611	3510	49	16G
0005434878710	3510	50	17C
0005434878765	3510	51	17A
0005434938247	3510	52	17E
0005434878731	3510	53	17D
0005434878742	3510	54	17G
0005434878753	3510	55	17F
0005434426764	3510	56	17K
0005434878717	3510	57	18C
0005434878743	3510	58	18A
0005434878763	3510	59	18G
0005435902628	3510	60	18J
0005434878699	3510	61	19A
0005434426770	3510	62	19D
0005434878693	3510	63	19C
0005434878707	3510	64	19F
0005435126572	3510	65	19E
0005434878766	3510	66	19G
0005434878757	3510	67	19K
0005435126599	3510	68	19J
0005435626273	3510	69	20B
0005435126570	3510	70	20A
0005432799591	3510	71	20D
0005434878730	3510	72	20C
0005432188624	3510	73	20G
0005435126591	3510	74	20J
0005434878673	3510	75	20H
0005434938241	3510	76	21B
0005435126566	3510	77	21D
0005435126598	3510	78	21E
0005435626285	3510	79	21G
0005434426760	3510	80	22A
0005432799607	3510	81	22C
0005432799598	3510	82	22B
0005432611732	3510	83	22F
0005434426749	3510	84	22E
0005434938234	3510	85	22D
0005434426759	3510	86	22H
0005434878749	3510	87	22G
0005435126586	3510	88	22J
0005432799610	3510	89	23B
0005435126600	3510	90	23A
0005434426774	3510	91	22K
0005434878719	3510	92	23D
0005434426748	3510	93	23C
0005434878708	3510	94	23G
0005434426754	3510	95	23F
0005435626281	3510	96	23H
0005434878755	3510	97	24D
0005434878751	3510	98	23J
0005434426762	3510	99	24F
0005434878737	3510	100	24E
0005434878741	3510	101	25A
0005435126601	3510	102	25D
0005435626278	3510	103	25C
0005434878745	3510	104	25B
0005432799590	3510	105	25F
0005435126604	3510	106	25E
0005435126588	3510	107	25H
0005434938239	3510	108	25G
0005435902668	3510	109	26C
0005435126575	3510	110	26B
0005434426757	3510	111	26A
0005434878705	3510	112	26E
0005434878674	3510	113	26D
0005435902669	3510	114	26G
0005434878744	3510	115	26F
0005435126574	3510	116	26J
0005434878720	3510	117	26H
0005434878702	3510	118	27A
0005435126579	3510	119	26K
0005435126573	3510	120	27C
0005434938251	3510	121	27E
0005435126568	3510	122	27H
0005435126583	3510	123	27K
0005435902683	3510	124	27J
0005435902575	3510	125	28B
0005434878695	3510	126	28D
0005432799616	3510	127	28C
0005434878682	3510	128	28F
0005435626283	3510	129	28J
0005435126564	3510	130	28H
0005434938252	3510	131	29A
0005434878683	3510	132	29C
0005434426766	3510	133	29J
0005435902636	3510	134	29H
0005434878722	3510	135	29G
0005434878726	3510	136	29K
0005435626269	3510	137	30C
0005435902660	3510	138	30E
0005435626272	3510	139	30D
0005432799615	3510	140	30F
0005435626274	3510	141	30J
0005434426773	3510	142	30H
0005435126595	3510	143	31B
0005432799606	3510	144	30K
0005432799595	3510	145	31D
0005435126585	3510	146	31C
0005435626271	3510	147	31F
0005434426776	3510	148	31E
0005435902684	3510	149	31G
0005434938243	3510	150	31K
0005434878748	3510	151	32C
0005432799613	3510	152	32E
0005434878750	3510	153	32D
0005434878698	3510	154	32G
0005434878735	3510	155	32K
0005434878714	3510	156	32J
0005432799608	3510	157	32H
0005434938238	3510	158	33B
0005435902670	3510	159	33A
0005432613883	3510	160	33C
0005432799599	3510	161	33G
0005434878732	3510	162	33F
0005435126578	3510	163	33E
0005432799603	3510	164	33H
0005434426765	3510	165	34B
0005434878680	3510	166	34C
0005434878718	3510	167	34G
0005435626276	3510	168	34F
0005435913919	3510	169	34E
0005435626279	3510	170	34J
0005435126569	3510	171	35A
0005434878703	3510	172	34K
0005434426771	3510	173	35B
0005432188623	3510	174	35J
0005434878725	3510	175	36A
0005435626277	3510	176	35K
0005434426751	3510	177	36C
0005434878712	3510	178	36F
0005432613884	3510	179	36E
0005435126602	3510	180	36D
0005434878761	3510	181	36H
0005435626286	3510	182	36G
0005435126565	3510	183	36K
0005434938233	3510	184	37B
0005434878740	3510	185	37E
0005435126577	3510	186	37D
0005435902657	3510	187	37C
0005435126593	3510	188	37F
0005434426769	3510	189	37H
0005435841090	3510	190	38A
0005432799589	3510	191	37K
0005434878734	3510	192	39A
0005434426761	3510	193	38K
0005432799602	3510	194	39D
0005434878752	3510	195	39C
0005435626284	3510	196	39B
0005432799596	3510	197	40A
0005434426767	3510	198	39K
0005434878724	3510	199	39J
0005434878691	3510	200	40C
0005435126589	3510	201	40B
0005435902576	3510	202	40D
0005432799592	3510	203	40F
0005434878681	3510	204	40J
0005434878694	3510	205	40H
0005435902577	3510	206	41A
0005434878736	3510	207	41D
0005435626280	3510	208	41C
0005434878688	3510	209	41F
0005435126594	3510	210	41K
0005432611731	3510	211	42B
0005435626270	3510	212	42D
0005435902685	3510	213	42H
0005434878756	3510	214	42G
0005434878701	3510	215	42F
0005432799614	3510	216	42J
0005432799594	3510	217	43A
0005432188625	3510	218	43D
0005432799605	3510	219	43C
0005434878692	3510	220	43F
0005435126603	3510	221	43E
0005434938250	3510	222	43J
0005435126587	3510	223	43H
0005434878709	3510	224	43G
0005434878711	3510	225	43K
0005434878704	3510	226	44B
0005434878678	3510	227	44A
0005435126576	3510	228	44E
0005432799601	3510	229	44D
0005434426758	3510	230	44H
0005435841819	3510	231	44J
0005435626266	3510	232	45A
0005434878754	3510	233	45C
0005434426768	3510	234	45E
0005434878716	3510	235	45D
0005434878685	3510	236	45H
0005434878733	3510	237	46A
0005434878739	3510	238	45K
0005435902658	3510	239	46B
0005434878729	3510	240	46E
0005432799612	3510	241	46D
0005434938248	3510	242	46C
0005434426772	3510	243	46G
0005434426755	3510	244	46F
0005434878715	3510	245	46J
0005432183478	3510	246	46H
0005435126584	3510	247	47A
0005434878713	3510	248	46K
0005432611733	3510	249	47E
0005434878700	3510	250	47D
0005434878675	3510	251	47C
0005434426777	3510	252	47G
0005434426756	3510	253	47K
0005435913896	3510	254	47H
0005434426775	3510	255	48D
0005435126590	3510	256	48C
0005435126571	3510	257	48A
0005434878677	3510	258	48E
0005435626275	3510	259	48H
0005434878684	3510	260	48G
0005435126580	3510	261	48F
0005435902627	3510	262	49A
0005434878738	3510	263	49G
0005434878747	3510	264	49F
0005434878686	3510	265	49E
0005434878746	3510	266	49H
0005432799600	3510	267	50A
0005432799609	3510	268	50E
0005435902637	3510	269	50D
0005434878676	3510	270	50G
0005434938240	3510	271	50F
0005432799617	3510	272	51D
0005435902630	3510	273	50H
0005434878764	3510	274	51E
0005435126592	3510	275	51G
0005434426521	14571	1	1C
0005432607548	14571	2	1A
0005434878199	14571	3	1D
0005434426570	14571	4	1K
0005435626093	14571	5	1H
0005435902786	14571	6	2D
0005435626129	14571	7	2C
0005434878003	14571	8	2A
0005432799274	14571	9	2K
0005432799312	14571	10	2H
0005434877751	14571	11	3K
0005434938071	14571	12	4A
0005434877821	14571	13	4G
0005434878174	14571	14	5A
0005434937959	14571	15	5C
0005435126002	14571	16	5G
0005432611711	14571	17	11A
0005432799359	14571	18	5K
0005434877881	14571	19	11E
0005434938072	14571	20	11C
0005434877780	14571	21	11K
0005435902803	14571	22	11G
0005434426542	14571	23	12D
0005432799437	14571	24	12G
0005432799311	14571	25	12F
0005435913947	14571	26	12K
0005435902788	14571	27	12H
0005435126222	14571	28	13D
0005434878018	14571	29	13F
0005434877747	14571	30	13E
0005434878056	14571	31	13H
0005435626089	14571	32	13G
0005434878085	14571	33	14A
0005432799227	14571	34	13K
0005435626072	14571	35	14E
0005435626047	14571	36	14D
0005434426522	14571	37	14G
0005434877696	14571	38	14F
0005434877947	14571	39	14H
0005434426588	14571	40	14K
0005435126073	14571	41	15E
0005434877720	14571	42	15D
0005435126169	14571	43	15F
0005432799308	14571	44	16A
0005435913954	14571	45	15K
0005432611707	14571	46	16C
0005432799341	14571	47	16H
0005434878026	14571	48	16G
0005435902802	14571	49	17C
0005434877882	14571	50	17A
0005435913951	14571	51	17D
0005434877443	14571	52	17G
0005435626115	14571	53	17F
0005432799330	14571	54	18A
0005432799368	14571	55	17H
0005434877822	14571	56	18C
0005435626116	14571	57	18H
0005432799361	14571	58	18F
0005434878332	14571	59	18J
0005434938027	14571	60	19A
0005434878433	14571	61	19D
0005432799352	14571	62	19C
0005434877354	14571	63	19G
0005435126183	14571	64	19F
0005434877536	14571	65	19E
0005435902793	14571	66	19H
0005435626136	14571	67	19K
0005435902795	14571	68	20B
0005434877750	14571	69	20A
0005432799334	14571	70	20D
0005432799332	14571	71	20G
0005435626046	14571	72	20K
0005434878087	14571	73	20J
0005434878132	14571	74	20H
0005435126176	14571	75	21B
0005435126003	14571	76	21A
0005432799249	14571	77	21D
0005432799415	14571	78	21F
0005434878175	14571	79	21E
0005435914700	14571	80	22A
0005434877458	14571	81	22E
0005435902800	14571	82	22D
0005435902789	14571	83	22K
0005432799350	14571	84	22J
0005434877944	14571	85	23B
0005435126184	14571	86	23G
0005434877909	14571	87	23H
0005435626105	14571	88	24D
0005434878001	14571	89	25D
0005435126191	14571	90	25C
0005435126190	14571	91	25B
0005434878221	14571	92	25E
0005434878075	14571	93	25H
0005435913948	14571	94	25G
0005435902791	14571	95	26C
0005435913950	14571	96	26B
0005434878202	14571	97	26E
0005434877705	14571	98	26D
0005435126177	14571	99	26J
0005432611702	14571	100	26H
0005432799239	14571	101	27A
0005434426545	14571	102	26K
0005434877761	14571	103	27D
0005435902796	14571	104	27B
0005434426477	14571	105	27F
0005434426569	14571	106	27E
0005434938088	14571	107	27H
0005432799224	14571	108	27G
0005432607553	14571	109	27K
0005434878027	14571	110	27J
0005434877719	14571	111	28B
0005435126174	14571	112	28A
0005435626117	14571	113	28E
0005432799421	14571	114	28D
0005434878002	14571	115	28F
0005435626051	14571	116	28J
0005434426587	14571	117	28H
0005432799384	14571	118	29A
0005434878295	14571	119	29D
0005434426378	14571	120	29C
0005434878167	14571	121	29H
0005434877704	14571	122	29K
0005432799223	14571	123	30C
0005432611692	14571	124	30B
0005434426653	14571	125	30D
0005435126109	14571	126	30G
0005435902792	14571	127	30J
0005434877788	14571	128	31A
0005434877686	14571	129	30K
0005435126072	14571	130	31D
0005434426436	14571	131	31C
0005432799439	14571	132	31B
0005432799385	14571	133	31F
0005435126185	14571	134	31E
0005435126085	14571	135	31H
0005432607545	14571	136	31G
0005435126166	14571	137	32A
0005435126319	14571	138	31K
0005435902785	14571	139	32B
0005435626085	14571	140	32D
0005435126083	14571	141	32G
0005434426523	14571	142	32F
0005434426491	14571	143	32J
0005435913952	14571	144	32H
0005434878354	14571	145	33A
0005435902790	14571	146	33C
0005434877697	14571	147	33B
0005435126233	14571	148	33G
0005435126110	14571	149	33H
0005432611701	14571	150	34A
0005432799280	14571	151	33K
0005434426435	14571	152	33J
0005434878024	14571	153	34C
0005434878023	14571	154	34E
0005432799400	14571	155	34D
0005434426566	14571	156	34J
0005435902787	14571	157	34H
0005434878173	14571	158	35B
0005432799295	14571	159	35D
0005435626073	14571	160	35F
0005434426571	14571	161	35J
0005435125941	14571	162	35G
0005435902801	14571	163	36A
0005435902799	14571	164	36E
0005434877910	14571	165	36D
0005434877785	14571	166	36F
0005434426473	14571	167	36H
0005435913949	14571	168	37C
0005434878220	14571	169	36K
0005432799240	14571	170	37D
0005432799349	14571	171	37E
0005432607560	14571	172	37H
0005434877695	14571	173	37K
0005434877966	14571	174	38C
0005434877837	14571	175	38B
0005435126194	14571	176	38J
0005434426654	14571	177	39B
0005434938022	14571	178	39D
0005434938180	14571	179	39C
0005435126167	14571	180	39F
0005434938086	14571	181	39E
0005434938026	14571	182	40A
0005434426568	14571	183	39K
0005432799491	14571	184	40B
0005435626130	14571	185	40D
0005434877784	14571	186	40H
0005434877537	14571	187	40G
0005435126269	14571	188	41B
0005434877164	14571	189	41A
0005434877907	14571	190	41F
0005432799226	14571	191	41E
0005434878198	14571	192	41J
0005434878096	14571	193	41H
0005432607549	14571	194	42C
0005434877933	14571	195	42B
0005434878086	14571	196	42F
0005434938179	14571	197	42E
0005432799327	14571	198	42D
0005432799195	14571	199	42H
0005435902794	14571	200	43A
0005434877956	14571	201	42K
0005435626111	14571	202	43D
0005434877848	14571	203	43F
0005434877698	14571	204	43H
0005434877923	14571	205	43G
0005435902797	14571	206	43J
0005434878250	14571	207	44C
0005434877353	14571	208	44B
0005434426610	14571	209	44A
0005434426395	14571	210	44E
0005434938055	14571	211	44D
0005432799196	14571	212	44J
0005435126350	14571	213	44H
0005434878009	14571	214	45B
0005434426487	14571	215	45A
0005432799383	14571	216	44K
0005434426492	14571	217	45D
0005435126234	14571	218	45C
0005434878081	14571	219	45H
0005434878333	14571	220	45G
0005434877899	14571	221	45K
0005432611710	14571	222	45J
0005434877626	14571	223	46B
0005432799426	14571	224	46E
0005434878170	14571	225	46G
0005432799490	14571	226	46F
0005432799331	14571	227	46K
0005432799194	14571	228	46J
0005435902798	14571	229	47A
0005435626029	14571	230	47D
0005435126175	14571	231	47E
0005435913953	14571	232	47H
0005434426510	14571	233	48D
0005434878251	14571	234	48C
0005432799313	14571	235	48H
0005432059515	14571	236	48G
0005434877703	14571	237	49C
0005434426555	14571	238	48K
0005434877661	14571	239	49G
0005435126301	14571	240	49F
0005434877945	14571	241	49E
0005432799333	14571	242	49K
0005432799538	14571	243	49H
0005434878249	14571	244	50A
0005434878055	14571	245	50E
0005434877948	14571	246	50D
0005434878117	14571	247	50K
0005434426618	14571	248	50H
0005435126192	14571	249	51F
0005434878432	14571	250	51D
0005432611691	14571	251	51G
0005434312329	3620	1	2B
0005434325714	3620	2	2C
0005434325706	3620	3	3B
0005434325715	3620	4	3C
0005434325713	3620	5	4D
0005434325709	3620	6	5B
0005435889849	3620	7	5D
0005434325705	3620	8	6B
0005434312330	3620	9	7B
0005434325712	3620	10	18A
0005434325703	3620	11	18C
0005434325704	3620	12	19A
0005434325716	3620	13	20B
0005435889864	3620	14	20C
0005434325711	3620	15	20D
0005434325707	3620	16	21A
0005434312328	3620	17	21C
0005434325710	3620	18	22C
0005434325708	3620	19	22D
0005434325614	15594	1	1B
0005435889928	15594	2	1C
0005434325615	15594	3	1D
0005434325624	15594	4	2B
0005434325654	15594	5	2C
0005434325603	15594	6	3A
0005435889927	15594	7	4A
0005435889925	15594	8	4B
0005434325660	15594	9	5A
0005434325608	15594	10	6B
0005435889926	15594	11	6C
0005434325607	15594	12	7B
0005434325633	15594	13	7D
0005434325632	15594	14	18A
0005434325577	15594	15	19B
0005434325601	15594	16	20B
0005434325602	15594	17	21D
0005435889930	15594	18	22A
0005435889929	15594	19	23B
0005435957783	635	1	1A
0005433420366	635	2	1B
0005435957777	635	3	1D
0005433420361	635	4	2B
0005435957778	635	5	3A
0005433420367	635	6	3B
0005435957779	635	7	4B
0005433420359	635	8	4C
0005433420382	635	9	5B
0005435957784	635	10	6A
0005435957776	635	11	6B
0005435957781	635	12	6C
0005435957773	635	13	6D
0005435957782	635	14	7A
0005433420358	635	15	7D
0005435957775	635	16	18A
0005433420374	635	17	18B
0005435957772	635	18	19A
0005433420375	635	19	19B
0005433420376	635	20	19C
0005433420357	635	21	19D
0005435957780	635	22	20B
0005435957771	635	23	21B
0005435957785	635	24	21D
0005435957774	635	25	22C
0005433420360	635	26	23B
0005433420443	15154	1	1D
0005435957702	15154	2	3A
0005435957652	15154	3	3C
0005435957658	15154	4	3D
0005433420444	15154	5	4A
0005435957622	15154	6	4B
0005435957703	15154	7	5A
0005435957653	15154	8	5C
0005435957623	15154	9	5D
0005435957663	15154	10	6B
0005435957648	15154	11	6C
0005433420446	15154	12	7B
0005433420442	15154	13	7C
0005433420447	15154	14	18A
0005433420445	15154	15	18B
0005435957662	15154	16	18C
0005433420449	15154	17	19C
0005435957661	15154	18	20A
0005435957659	15154	19	21C
0005435957649	15154	20	22B
0005435957664	15154	21	22D
0005433420448	15154	22	23A
0005434995287	23997	1	1D
0005434995294	23997	2	4E
0005434995295	23997	3	6C
0005434995293	23997	4	7A
0005434995291	23997	5	9A
0005434995292	23997	6	12C
0005434995296	23997	7	14C
0005434995290	23997	8	16E
0005434995284	23997	9	16F
0005434995308	23997	10	17D
0005434995289	23997	11	17F
0005434995286	23997	12	19A
0005434995285	23997	13	20C
0005434995288	23997	14	21C
0005434995309	23997	15	22D
0005434247141	8924	1	3B
0005434247144	8924	2	4A
0005434247146	8924	3	5A
0005434247142	8924	4	6B
0005435629395	16107	1	1B
0005434247159	16107	2	4A
0005434247161	16107	3	4B
0005434247160	16107	4	6B
0005435797542	2851	1	1A
0005435797553	2851	2	3C
0005435797547	2851	3	3F
0005435797540	2851	4	4D
0005435797548	2851	5	5E
0005433404807	2851	6	6A
0005435797541	2851	7	6E
0005433404817	2851	8	6F
0005433404776	2851	9	8A
0005433404778	2851	10	8D
0005433404816	2851	11	9D
0005435797551	2851	12	11A
0005435797552	2851	13	11C
0005435797546	2851	14	12C
0005435797550	2851	15	12D
0005433404818	2851	16	12E
0005433404779	2851	17	16D
0005435797549	2851	18	16F
0005435797545	2851	19	17F
0005433404796	2851	20	18F
0005435797544	2851	21	19A
0005435797554	2851	22	19C
0005433404781	2851	23	19E
0005435797543	2851	24	20E
0005435797436	29353	1	1C
0005435797444	29353	2	3D
0005433404849	29353	3	5D
0005435797448	29353	4	5E
0005435797471	29353	5	5F
0005433404852	29353	6	6C
0005433404846	29353	7	6D
0005435797454	29353	8	6F
0005435797369	29353	9	7D
0005433404845	29353	10	8A
0005435797453	29353	11	8E
0005435797431	29353	12	9D
0005433404850	29353	13	9E
0005435797449	29353	14	10E
0005435797441	29353	15	10F
0005435797359	29353	16	11D
0005435797443	29353	17	12D
0005435797483	29353	18	13A
0005433404851	29353	19	14C
0005435797477	29353	20	14E
0005435797482	29353	21	14F
0005433404847	29353	22	15A
0005433404844	29353	23	15D
0005435797430	29353	24	16A
0005435797478	29353	25	16D
0005433404848	29353	26	16E
0005435797428	29353	27	17A
0005435797442	29353	28	19E
0005435797440	29353	29	20C
0005435797358	29353	30	20D
0005434948057	5848	1	1A
0005434948055	5848	2	1B
0005434948058	5848	3	2A
0005434948063	5848	4	4A
0005434948061	5848	5	4B
0005434948060	5848	6	5A
0005434948059	5848	7	5B
0005434948062	5848	8	6A
0005434948056	5848	9	6B
0005435376363	16338	1	1A
0005435376364	16338	2	1B
0005434947996	16338	3	2A
0005434947999	16338	4	2B
0005435376361	16338	5	3A
0005435376362	16338	6	4A
0005434947997	16338	7	5A
0005435376365	16338	8	6A
0005434948014	16338	9	6B
0005433961200	6944	1	1F
0005433961204	6944	2	2A
0005433961207	6944	3	2D
0005433961198	6944	4	3C
0005433961197	6944	5	3F
0005433961208	6944	6	4A
0005433961179	6944	7	5A
0005433961199	6944	8	5C
0005433961170	6944	9	5D
0005433961196	6944	10	6C
0005433961178	6944	11	6D
0005433961181	6944	12	6E
0005433961182	6944	13	7C
0005433961180	6944	14	7E
0005433961167	6944	15	8C
0005433961205	6944	16	8E
0005433961177	6944	17	8F
0005433961171	6944	18	10A
0005433961190	6944	19	10D
0005433961172	6944	20	11A
0005433961210	6944	21	11C
0005433961211	6944	22	11D
0005433961175	6944	23	11E
0005433961194	6944	24	11F
0005433961209	6944	25	12A
0005433961174	6944	26	13E
0005433961193	6944	27	14C
0005433961186	6944	28	14D
0005433961184	6944	29	14F
0005433961189	6944	30	15A
0005433961187	6944	31	15D
0005433961202	6944	32	15F
0005433961195	6944	33	16C
0005433961166	6944	34	16E
0005433961185	6944	35	17A
0005433961201	6944	36	17C
0005433961192	6944	37	17D
0005433961191	6944	38	17E
0005433961203	6944	39	17F
0005433961169	6944	40	18A
0005433961176	6944	41	18D
0005433961206	6944	42	18F
0005433961183	6944	43	19C
0005433961173	6944	44	19D
0005433961188	6944	45	19F
0005433961165	6944	46	20E
0005433961168	6944	47	20F
0005433960605	25771	1	1C
0005433960401	25771	2	2A
0005433960592	25771	3	2C
0005433960468	25771	4	2F
0005433960494	25771	5	3C
0005433960556	25771	6	3D
0005433960465	25771	7	4A
0005433960358	25771	8	4E
0005433960508	25771	9	4F
0005433960482	25771	10	5A
0005433960449	25771	11	5C
0005433960558	25771	12	5D
0005433960580	25771	13	5E
0005433960477	25771	14	6A
0005433960464	25771	15	6D
0005433960609	25771	16	6F
0005433960571	25771	17	7D
0005433960490	25771	18	7E
0005433960507	25771	19	7F
0005433960557	25771	20	8A
0005433960448	25771	21	8F
0005433960331	25771	22	9A
0005433960404	25771	23	9C
0005433960443	25771	24	9E
0005433960395	25771	25	9F
0005433960541	25771	26	10A
0005433960582	25771	27	10C
0005433960559	25771	28	10D
0005433960534	25771	29	10E
0005433960467	25771	30	10F
0005433960625	25771	31	11C
0005433960478	25771	32	11F
0005433960565	25771	33	12C
0005433960330	25771	34	12D
0005433960386	25771	35	13A
0005433960472	25771	36	13C
0005433960281	25771	37	13D
0005433960476	25771	38	13F
0005433960542	25771	39	14F
0005433960469	25771	40	15C
0005433960388	25771	41	15D
0005433960332	25771	42	15F
0005433960489	25771	43	16C
0005433960509	25771	44	16E
0005433960493	25771	45	16F
0005433960470	25771	46	17F
0005433960579	25771	47	18A
0005433960555	25771	48	18D
0005433960411	25771	49	18E
0005433960289	25771	50	18F
0005433960583	25771	51	19A
0005433960375	25771	52	19C
0005433960479	25771	53	19D
0005433960394	25771	54	19E
0005433960568	25771	55	19F
0005433960393	25771	56	20C
0005433960535	25771	57	20D
0005433960392	25771	58	20E
0005433960359	25771	59	20F
0005435082720	24463	1	1A
0005435082782	24463	2	1B
0005435082685	24463	3	3A
0005435082783	24463	4	3B
0005435082686	24463	5	4A
0005435082773	24463	6	4B
0005435082777	24463	7	5A
0005435082769	24463	8	6A
0005435082747	24463	9	6B
0005435082813	26111	1	1B
0005435082819	26111	2	2A
0005435082820	26111	3	2B
0005435082814	26111	4	3A
0005435082821	26111	5	3B
0005435082818	26111	6	4B
0005435082816	26111	7	4A
0005435082815	26111	8	5A
0005435082817	26111	9	5B
0005435082822	26111	10	6A
0005435286620	4950	1	1A
0005435286623	4950	2	2C
0005434245132	4950	3	4C
0005433534487	4950	4	5A
0005434245139	4950	5	5C
0005435286621	4950	6	6A
0005434245129	4950	7	6C
0005434245122	4950	8	7C
0005435286622	4950	9	9B
0005434245135	4950	10	9F
0005434245128	4950	11	10C
0005432166919	4950	12	10F
0005434245136	4950	13	11B
0005434245116	4950	14	11E
0005434245145	4950	15	13B
0005433534486	4950	16	13C
0005434245131	4950	17	16C
0005433534490	4950	18	17D
0005434245120	4950	19	18C
0005433534489	4950	20	18E
0005434245146	4950	21	18D
0005434245119	4950	22	19C
0005434245124	4950	23	20A
0005434245125	4950	24	19E
0005434245118	4950	25	20C
0005434245117	4950	26	20E
0005434245144	4950	27	20D
0005434245138	4950	28	21D
0005434245133	4950	29	22C
0005432166920	4950	30	22F
0005434245137	4950	31	23A
0005432166918	4950	32	23E
0005434245143	4950	33	24D
0005434245142	4950	34	24C
0005434245121	4950	35	24F
0005434245130	4950	36	25B
0005435286597	4950	37	26D
0005432166917	4950	38	26F
0005434245126	4950	39	29B
0005434245127	4950	40	29A
0005434245123	4950	41	29D
0005434245141	4950	42	29E
0005434245134	4950	43	29F
0005434245140	4950	44	31F
0005433785148	4951	1	1A
0005433785134	4951	2	1C
0005432105797	4951	3	1D
0005433615042	4951	4	2A
0005433785115	4951	5	1F
0005433615079	4951	6	2C
0005432105817	4951	7	2F
0005433785135	4951	8	2D
0005433615066	4951	9	3A
0005433615069	4951	10	3C
0005432665285	4951	11	3F
0005433615085	4951	12	3D
0005433615082	4951	13	4A
0005433785116	4951	14	4C
0005433615043	4951	15	4F
0005433615103	4951	16	4D
0005433615036	4951	17	5A
0005432105829	4951	18	5C
0005433785144	4951	19	5F
0005433785117	4951	20	5D
0005432105804	4951	21	6A
0005433785132	4951	22	6C
0005433785125	4951	23	6D
0005432145122	4951	24	7A
0005432105830	4951	25	6F
0005433615102	4951	26	7C
0005433615090	4951	27	7F
0005432105798	4951	28	7D
0005433615047	4951	29	8A
0005433615053	4951	30	8B
0005432105836	4951	31	8D
0005433785131	4951	32	8C
0005433615048	4951	33	8E
0005432105801	4951	34	9A
0005433615084	4951	35	8F
0005433785113	4951	36	9B
0005433615097	4951	37	9C
0005433785142	4951	38	9E
0005432105794	4951	39	9D
0005433615104	4951	40	9F
0005433785127	4951	41	10A
0005432105833	4951	42	10B
0005433615093	4951	43	10D
0005433615051	4951	44	10C
0005433615107	4951	45	10E
0005433615096	4951	46	11A
0005433615092	4951	47	10F
0005432105818	4951	48	11B
0005433615068	4951	49	11C
0005433615039	4951	50	11D
0005433615070	4951	51	11F
0005432105795	4951	52	11E
0005433615105	4951	53	12A
0005432105813	4951	54	12B
0005433615076	4951	55	12C
0005433785151	4951	56	12E
0005432105828	4951	57	12D
0005433615049	4951	58	12F
0005433785114	4951	59	13A
0005432105793	4951	60	13C
0005433615041	4951	61	13B
0005432105812	4951	62	13D
0005433785120	4951	63	13F
0005433785128	4951	64	13E
0005433615098	4951	65	14A
0005433615040	4951	66	14C
0005433785136	4951	67	14B
0005433785124	4951	68	14E
0005433615054	4951	69	14D
0005432105823	4951	70	14F
0005433785119	4951	71	15A
0005433785126	4951	72	15C
0005432105791	4951	73	15B
0005433615062	4951	74	15D
0005433785139	4951	75	15E
0005433785133	4951	76	16A
0005432105810	4951	77	15F
0005433615059	4951	78	16B
0005432105832	4951	79	16D
0005433615056	4951	80	16C
0005433785110	4951	81	16E
0005433615081	4951	82	16F
0005432105796	4951	83	17B
0005432105809	4951	84	17A
0005433615037	4951	85	17C
0005433785111	4951	86	17D
0005432105827	4951	87	17E
0005433615100	4951	88	18A
0005433615091	4951	89	17F
0005433615072	4951	90	18B
0005433615045	4951	91	18D
0005433615052	4951	92	18C
0005432105799	4951	93	18E
0005433615094	4951	94	18F
0005433785112	4951	95	19B
0005432105831	4951	96	19E
0005432105789	4951	97	19D
0005433615067	4951	98	19C
0005433615038	4951	99	20A
0005433785130	4951	100	20B
0005432105811	4951	101	20C
0005433615063	4951	102	20E
0005433615071	4951	103	20D
0005433615057	4951	104	20F
0005433615080	4951	105	21A
0005433615073	4951	106	21C
0005433615086	4951	107	21B
0005432105814	4951	108	21D
0005433615044	4951	109	21E
0005433615095	4951	110	21F
0005432105825	4951	111	22B
0005433785150	4951	112	22A
0005433785146	4951	113	22C
0005433785143	4951	114	22E
0005433615078	4951	115	22D
0005432105815	4951	116	22F
0005433615046	4951	117	23B
0005433615101	4951	118	23A
0005433615061	4951	119	23D
0005433785152	4951	120	23C
0005432105807	4951	121	23F
0005432666399	4951	122	23E
0005432105808	4951	123	24A
0005433785147	4951	124	24B
0005433785141	4951	125	24C
0005433785138	4951	126	24D
0005433615077	4951	127	24F
0005432665284	4951	128	24E
0005433615074	4951	129	25B
0005432105800	4951	130	25A
0005433785145	4951	131	25C
0005433615089	4951	132	25D
0005433785122	4951	133	25F
0005432105806	4951	134	25E
0005433785118	4951	135	26A
0005432105802	4951	136	26B
0005432105826	4951	137	26D
0005433785140	4951	138	26C
0005432105790	4951	139	26F
0005432105835	4951	140	26E
0005433615106	4951	141	27B
0005433615035	4951	142	27A
0005432105792	4951	143	27C
0005433615034	4951	144	27D
0005432667464	4951	145	27E
0005433615058	4951	146	28A
0005433615087	4951	147	27F
0005433615050	4951	148	28C
0005432105816	4951	149	28B
0005433615075	4951	150	28D
0005432105805	4951	151	28E
0005433785123	4951	152	28F
0005433615088	4951	153	29A
0005433615060	4951	154	29C
0005433785149	4951	155	29B
0005433615064	4951	156	29D
0005432105824	4951	157	29E
0005433615055	4951	158	30A
0005432105819	4951	159	29F
0005433785137	4951	160	30B
0005432105803	4951	161	30D
0005432105834	4951	162	30C
0005433615083	4951	163	30F
0005433785121	4951	164	30E
0005433785129	4951	165	31B
0005432105820	4951	166	31A
0005432105821	4951	167	31C
0005433615065	4951	168	31E
0005432105822	4951	169	31D
0005433615099	4951	170	31F
0005435006871	4953	1	1A
0005434229482	4953	2	1C
0005434229475	4953	3	1F
0005433688807	4953	4	1D
0005434229476	4953	5	2A
0005435006901	4953	6	3A
0005434265261	4953	7	2F
0005435006964	4953	8	3D
0005434229484	4953	9	4C
0005435006866	4953	10	4D
0005434311209	4953	11	5A
0005435007013	4953	12	4F
0005435006902	4953	13	5C
0005435269700	4953	14	5F
0005435006994	4953	15	5D
0005435269735	4953	16	6A
0005435269734	4953	17	6C
0005434229478	4953	18	6F
0005434265279	4953	19	6D
0005434265259	4953	20	7C
0005434265263	4953	21	7D
0005434265282	4953	22	8A
0005434149790	4953	23	8B
0005434265262	4953	24	8E
0005435006925	4953	25	8F
0005434265276	4953	26	9C
0005435006986	4953	27	9B
0005434229479	4953	28	9E
0005433688806	4953	29	9F
0005434265258	4953	30	10A
0005434229494	4953	31	10B
0005434229493	4953	32	10C
0005434229490	4953	33	10F
0005435269740	4953	34	11A
0005434229481	4953	35	11B
0005434265266	4953	36	11D
0005435006993	4953	37	11C
0005432336036	4953	38	11E
0005434265267	4953	39	11F
0005432335976	4953	40	12B
0005434265269	4953	41	12E
0005434229488	4953	42	12F
0005434173538	4953	43	13C
0005435269725	4953	44	13B
0005432336031	4953	45	13D
0005435269737	4953	46	13E
0005434149789	4953	47	14A
0005435006969	4953	48	14C
0005435006971	4953	49	14B
0005435006936	4953	50	14E
0005435269710	4953	51	14D
0005434149795	4953	52	14F
0005434173541	4953	53	15A
0005434265265	4953	54	15C
0005434312312	4953	55	15E
0005435269730	4953	56	15D
0005435269711	4953	57	15F
0005434265268	4953	58	16B
0005434229497	4953	59	16D
0005435006958	4953	60	16C
0005435269692	4953	61	16E
0005435006978	4953	62	17C
0005434265270	4953	63	17B
0005432336044	4953	64	17D
0005434149791	4953	65	18A
0005434229492	4953	66	18C
0005435006891	4953	67	18D
0005435269739	4953	68	18E
0005435006833	4953	69	18F
0005435007012	4953	70	19C
0005432336005	4953	71	19B
0005434173540	4953	72	19D
0005433685519	4953	73	19E
0005434265274	4953	74	20B
0005432336043	4953	75	20E
0005432336003	4953	76	21B
0005435006946	4953	77	21F
0005434149786	4953	78	21E
0005435006972	4953	79	21D
0005435269701	4953	80	22A
0005432336030	4953	81	22D
0005434229489	4953	82	22C
0005435006977	4953	83	23B
0005434149796	4953	84	23A
0005435006832	4953	85	23D
0005434265272	4953	86	23E
0005435006933	4953	87	23F
0005434149785	4953	88	24B
0005435269738	4953	89	24A
0005435006976	4953	90	24C
0005435006892	4953	91	24E
0005434229485	4953	92	24F
0005434265280	4953	93	25A
0005434149794	4953	94	25C
0005434173542	4953	95	25B
0005435006926	4953	96	25D
0005434265275	4953	97	25F
0005432335931	4953	98	25E
0005434265273	4953	99	26A
0005434173539	4953	100	26B
0005434149788	4953	101	26D
0005434265278	4953	102	26C
0005435006947	4953	103	26F
0005433688792	4953	104	27A
0005434265277	4953	105	27C
0005434229496	4953	106	27B
0005434265281	4953	107	27D
0005434229480	4953	108	27F
0005432336004	4953	109	27E
0005435269736	4953	110	28A
0005434229495	4953	111	28C
0005434229487	4953	112	28B
0005434312313	4953	113	28D
0005434311216	4953	114	28E
0005434265271	4953	115	28F
0005435007003	4953	116	29B
0005435269699	4953	117	29A
0005434265264	4953	118	29C
0005434229477	4953	119	29D
0005432335998	4953	120	29E
0005434149787	4953	121	30A
0005434149792	4953	122	29F
0005434229483	4953	123	30C
0005434149793	4953	124	30E
0005435006905	4953	125	31B
0005434265283	4953	126	31A
0005434265260	4953	127	31C
0005434229491	4953	128	31D
0005435269712	4953	129	31E
0005434229486	4953	130	31F
0005434244923	8550	1	2C
0005433784918	8550	2	2F
0005434245013	8550	3	2D
0005434244748	8550	4	3A
0005432659698	8550	5	3C
0005434244943	8550	6	4A
0005433784816	8550	7	4D
0005434244924	8550	8	4F
0005434244895	8550	9	5F
0005433784828	8550	10	6A
0005434244918	8550	11	6C
0005433784723	8550	12	7C
0005433784943	8550	13	7F
0005433784730	8550	14	8A
0005433784968	8550	15	8B
0005434244811	8550	16	8F
0005433784808	8550	17	9A
0005434244933	8550	18	9C
0005433784774	8550	19	9E
0005433784902	8550	20	10A
0005432666377	8550	21	10C
0005432666387	8550	22	10B
0005434244886	8550	23	11C
0005433785021	8550	24	11B
0005433784772	8550	25	11E
0005433784969	8550	26	12B
0005433784767	8550	27	12A
0005434244855	8550	28	12C
0005434244835	8550	29	12E
0005434244951	8550	30	12F
0005434244928	8550	31	13C
0005432666366	8550	32	14B
0005434244879	8550	33	14E
0005432659692	8550	34	15E
0005433784877	8550	35	16A
0005432659697	8550	36	16E
0005433784823	8550	37	16F
0005433784717	8550	38	17B
0005434244875	8550	39	17F
0005433784956	8550	40	17E
0005433784689	8550	41	18A
0005435269774	8550	42	18B
0005434244934	8550	43	18D
0005432659693	8550	44	18C
0005434244812	8550	45	18F
0005433784895	8550	46	19B
0005433784957	8550	47	19E
0005433784829	8550	48	20D
0005434244849	8550	49	21C
0005433784778	8550	50	21B
0005433784526	8550	51	21F
0005433784919	8550	52	22B
0005434245003	8550	53	22D
0005433784815	8550	54	22C
0005434244740	8550	55	23B
0005433784899	8550	56	23D
0005433784768	8550	57	23E
0005435269775	8550	58	24B
0005433784721	8550	59	24A
0005434244942	8550	60	24C
0005434244885	8550	61	24F
0005433784773	8550	62	25C
0005433784807	8550	63	25D
0005434244826	8550	64	25E
0005432659694	8550	65	26A
0005433784865	8550	66	25F
0005434244856	8550	67	26B
0005435269776	8550	68	26D
0005433784729	8550	69	26F
0005434245004	8550	70	26E
0005433784814	8550	71	28B
0005434244848	8550	72	28E
0005432666379	8550	73	28D
0005433784680	8550	74	28F
0005434244847	8550	75	29A
0005433784833	8550	76	29B
0005433784722	8550	77	29E
0005432666378	8550	78	30B
0005433784821	8550	79	30C
0005434244739	8550	80	30D
0005434244894	8550	81	31A
0005433784866	8550	82	30F
0005433784859	8550	83	31E
0005434244878	8550	84	31F
0005433614399	8551	1	1A
0005433614413	8551	2	1C
0005433614570	8551	3	2F
0005433614432	8551	4	2D
0005433614252	8551	5	4A
0005433613995	8551	6	3F
0005433614656	8551	7	5A
0005433614419	8551	8	5F
0005433614431	8551	9	7D
0005433614190	8551	10	8A
0005433614612	8551	11	8E
0005433614256	8551	12	9F
0005433614411	8551	13	10B
0005433614465	8551	14	11A
0005433614345	8551	15	11D
0005433614616	8551	16	11F
0005433614609	8551	17	12B
0005433614478	8551	18	12E
0005433614402	8551	19	12F
0005433614267	8551	20	13A
0005433614468	8551	21	13D
0005433614343	8551	22	13F
0005433614648	8551	23	13E
0005433614526	8551	24	14A
0005433614390	8551	25	14C
0005433614117	8551	26	14D
0005433614613	8551	27	14F
0005433614571	8551	28	15B
0005433614467	8551	29	15A
0005433614414	8551	30	15D
0005433614410	8551	31	15E
0005433614191	8551	32	16B
0005433614342	8551	33	17C
0005433614396	8551	34	17D
0005433614251	8551	35	17F
0005433614274	8551	36	18B
0005433614011	8551	37	18E
0005433614370	8551	38	19B
0005433614352	8551	39	19D
0005433614368	8551	40	19C
0005433614403	8551	41	19E
0005433614346	8551	42	21F
0005433614459	8551	43	22B
0005433614420	8551	44	22D
0005433614714	8551	45	22C
0005433614367	8551	46	23C
0005433614361	8551	47	23F
0005433614466	8551	48	24C
0005433614360	8551	49	24B
0005433614404	8551	50	24A
0005433614212	8551	51	25A
0005433614394	8551	52	25C
0005433614393	8551	53	25D
0005433614489	8551	54	26B
0005433614273	8551	55	26E
0005433614728	8551	56	26D
0005433614362	8551	57	27A
0005433614573	8551	58	27F
0005433614730	8551	59	27E
0005433614649	8551	60	28B
0005433614729	8551	61	28C
0005433614160	8551	62	28F
0005433614250	8551	63	29A
0005433614369	8551	64	29B
0005433614203	8551	65	29F
0005433614344	8551	66	30D
0005433614488	8551	67	31B
0005433614458	8551	68	31A
0005433614713	8551	69	31C
0005434149675	8552	1	1A
0005434264950	8552	2	1C
0005432336099	8552	3	1D
0005434265006	8552	4	2A
0005432047569	8552	5	1F
0005432035080	8552	6	2D
0005434311232	8552	7	2C
0005435286658	8552	8	2F
0005434229344	8552	9	3A
0005432035094	8552	10	3C
0005435286657	8552	11	3F
0005435007139	8552	12	3D
0005434265009	8552	13	4A
0005432035076	8552	14	4C
0005433688819	8552	15	4F
0005434229378	8552	16	5A
0005435007147	8552	17	5C
0005434229297	8552	18	5D
0005432035083	8552	19	5F
0005432336095	8552	20	6C
0005435007141	8552	21	6F
0005434149684	8552	22	6D
0005432035093	8552	23	7A
0005432035103	8552	24	7C
0005433815413	8552	25	7F
0005435007145	8552	26	8A
0005434173514	8552	27	8B
0005434173508	8552	28	8D
0005432035097	8552	29	8C
0005434265042	8552	30	8E
0005435007159	8552	31	8F
0005434265010	8552	32	9A
0005432035102	8552	33	9C
0005432035081	8552	34	9B
0005433815410	8552	35	9E
0005434264877	8552	36	9D
0005432035099	8552	37	9F
0005432035086	8552	38	10A
0005434229317	8552	39	10B
0005435007143	8552	40	10D
0005434173502	8552	41	10C
0005435007146	8552	42	10E
0005435286652	8552	43	10F
0005434264970	8552	44	11A
0005432035101	8552	45	11E
0005435007156	8552	46	11D
0005435007157	8552	47	11C
0005435286659	8552	48	11F
0005434265028	8552	49	12A
0005435007160	8552	50	12B
0005432035078	8552	51	12C
0005432035098	8552	52	12E
0005434229343	8552	53	12D
0005434229278	8552	54	12F
0005434265041	8552	55	13B
0005433815412	8552	56	13A
0005434265113	8552	57	13C
0005435007154	8552	58	13D
0005434265088	8552	59	13F
0005432035087	8552	60	13E
0005433690935	8552	61	14A
0005432035091	8552	62	14B
0005434311229	8552	63	14D
0005432035092	8552	64	14C
0005433534510	8552	65	14E
0005434264951	8552	66	14F
0005434229284	8552	67	15A
0005433688820	8552	68	15C
0005432047568	8552	69	15D
0005434149630	8552	70	15E
0005432035096	8552	71	16A
0005432336096	8552	72	16C
0005434311231	8552	73	16B
0005432035084	8552	74	16D
0005433815409	8552	75	16E
0005434264976	8552	76	17A
0005434229281	8552	77	16F
0005432035082	8552	78	17C
0005434265116	8552	79	17B
0005433815411	8552	80	17D
0005432047570	8552	81	17F
0005433689922	8552	82	17E
0005434229331	8552	83	18A
0005434149662	8552	84	18B
0005434265016	8552	85	18C
0005432336101	8552	86	18D
0005433534509	8552	87	18E
0005434265035	8552	88	19C
0005435007142	8552	89	19B
0005433534508	8552	90	19D
0005434265015	8552	91	19E
0005434265126	8552	92	20A
0005435007140	8552	93	20C
0005434265127	8552	94	20B
0005435007153	8552	95	20D
0005434229165	8552	96	20F
0005435007144	8552	97	20E
0005435007149	8552	98	21A
0005432035095	8552	99	21C
0005432336098	8552	100	21B
0005432336094	8552	101	21D
0005433690936	8552	102	21E
0005434229326	8552	103	22A
0005435007155	8552	104	21F
0005434264998	8552	105	22B
0005432035100	8552	106	22C
0005432035104	8552	107	22D
0005432035085	8552	108	22F
0005434311230	8552	109	23A
0005434264879	8552	110	23B
0005434229289	8552	111	23D
0005435007150	8552	112	23C
0005432035077	8552	113	23E
0005434229327	8552	114	24A
0005434265099	8552	115	23F
0005434264952	8552	116	24B
0005435007137	8552	117	24C
0005434265089	8552	118	24E
0005435286654	8552	119	24D
0005432336097	8552	120	24F
0005434264989	8552	121	25B
0005432035088	8552	122	25A
0005435286653	8552	123	25E
0005434229332	8552	124	25D
0005435286656	8552	125	25F
0005432336100	8552	126	26A
0005432035089	8552	127	26C
0005434229269	8552	128	26B
0005432035079	8552	129	26D
0005434229290	8552	130	26F
0005434265112	8552	131	26E
0005434229316	8552	132	27A
0005434264878	8552	133	27B
0005434173488	8552	134	27D
0005434229333	8552	135	27E
0005435007138	8552	136	28A
0005434229272	8552	137	28B
0005434264975	8552	138	28D
0005432336093	8552	139	28C
0005434173503	8552	140	28E
0005432336092	8552	141	28F
0005432035090	8552	142	29A
0005434173500	8552	143	29B
0005434229198	8552	144	29F
0005433689921	8552	145	29E
0005435007158	8552	146	30A
0005435007151	8552	147	30B
0005435286655	8552	148	30D
0005434229287	8552	149	30C
0005435007148	8552	150	30E
0005435007152	8552	151	30F
0005434265087	8552	152	31A
0005434229273	8552	153	31C
0005434229274	8552	154	31B
0005434229307	8552	155	31D
0005434229347	8552	156	31F
0005434639101	12619	1	1A
0005434639280	12619	2	1C
0005434639298	12619	3	2A
0005434639206	12619	4	2B
0005434639305	12619	5	2C
0005434639256	12619	6	2D
0005433202449	12619	7	3A
0005433202443	12619	8	3B
0005434639211	12619	9	3C
0005433202446	12619	10	4A
0005434639184	12619	11	4C
0005434639304	12619	12	5A
0005434639361	12619	13	5D
0005434639167	12619	14	6A
0005433202445	12619	15	6B
0005433202440	12619	16	6C
0005433202444	12619	17	7A
0005433202448	12619	18	7B
0005434639251	12619	19	7C
0005433202439	12619	20	7D
0005433202441	12619	21	18B
0005434639282	12619	22	18C
0005433202437	12619	23	18D
0005434639067	12619	24	19B
0005434639271	12619	25	19C
0005434639281	12619	26	19D
0005434639265	12619	27	20A
0005433202435	12619	28	20C
0005434639183	12619	29	20D
0005433202450	12619	30	21A
0005434639123	12619	31	21B
0005434639261	12619	32	21C
0005433202447	12619	33	21D
0005433202442	12619	34	22A
0005434639122	12619	35	22C
0005434639100	12619	36	22D
0005433202436	12619	37	23A
0005433202438	12619	38	23B
0005434639424	23365	1	1A
0005433202209	23365	2	1B
0005433202300	23365	3	1C
0005433202266	23365	4	1D
0005433202208	23365	5	2A
0005432290645	23365	6	2B
0005434639422	23365	7	2C
0005434639440	23365	8	2D
0005434639428	23365	9	3A
0005434639445	23365	10	3B
0005433202311	23365	11	3C
0005434639427	23365	12	3D
0005434639441	23365	13	4A
0005433202288	23365	14	4B
0005434639436	23365	15	4C
0005434639437	23365	16	4D
0005433202301	23365	17	5A
0005432290646	23365	18	5B
0005434639431	23365	19	5C
0005434639430	23365	20	5D
0005432290647	23365	21	6A
0005433202265	23365	22	6B
0005434639434	23365	23	6C
0005433202286	23365	24	6D
0005434639439	23365	25	7A
0005434639438	23365	26	7B
0005434639423	23365	27	7C
0005434639432	23365	28	7D
0005434639435	23365	29	18A
0005433202264	23365	30	18B
0005434639433	23365	31	18C
0005433202239	23365	32	18D
0005433202308	23365	33	19A
0005433202269	23365	34	19B
0005434639442	23365	35	19C
0005434639447	23365	36	19D
0005433202214	23365	37	20A
0005433202394	23365	38	20B
0005434639446	23365	39	20C
0005433202253	23365	40	20D
0005434639426	23365	41	21A
0005434639443	23365	42	21B
0005434639429	23365	43	21C
0005433202268	23365	44	21D
0005433202270	23365	45	22A
0005434639448	23365	46	22B
0005434639444	23365	47	22C
0005434639449	23365	48	23A
0005434639425	23365	49	23B
0005432328414	21102	1	1A
0005432328543	21102	2	1C
0005432382975	21102	3	1D
0005432328377	21102	4	1F
0005432328627	21102	5	2A
0005432328438	21102	6	2C
0005432382990	21102	7	2D
0005432328576	21102	8	2F
0005432382981	21102	9	3A
0005432382887	21102	10	3C
0005432328683	21102	11	3D
0005432383010	21102	12	3F
0005432328439	21102	13	4A
0005432328446	21102	14	4C
0005432382810	21102	15	4D
0005432328479	21102	16	4E
0005432328586	21102	17	4F
0005432383023	21102	18	5A
0005432328492	21102	19	5C
0005432383080	21102	20	5D
0005432382997	21102	21	5E
0005432328669	21102	22	5F
0005432328535	21102	23	6A
0005432383037	21102	24	6C
0005432328625	21102	25	6D
0005432382934	21102	26	6E
0005432328485	21102	27	6F
0005432328545	21102	28	7A
0005432383024	21102	29	7C
0005432382886	21102	30	7D
0005432383028	21102	31	7E
0005432382917	21102	32	7F
0005432382960	21102	33	8A
0005432382982	21102	34	8C
0005432328508	21102	35	8D
0005432328468	21102	36	8E
0005432054318	21102	37	8F
0005432328404	21102	38	9A
0005432328529	21102	39	9C
0005432328403	21102	40	9D
0005432328551	21102	41	9E
0005432383025	21102	42	9F
0005432382931	21102	43	10A
0005432382872	21102	44	10C
0005432328337	21102	45	10D
0005432328525	21102	46	10E
0005432383081	21102	47	10F
0005432328517	21102	48	11A
0005432328530	21102	49	11C
0005432054320	21102	50	11D
0005432328539	21102	51	11E
0005432383038	21102	52	11F
0005432328293	21102	53	12A
0005432328458	21102	54	12C
0005432328452	21102	55	12D
0005432328534	21102	56	12E
0005432382885	21102	57	12F
0005432382892	21102	58	13A
0005432383021	21102	59	13C
0005432328453	21102	60	13D
0005432054319	21102	61	13E
0005432328544	21102	62	13F
0005432328624	21102	63	14A
0005432383029	21102	64	14C
0005432383085	21102	65	14D
0005432328565	21102	66	14E
0005432328637	21102	67	14F
0005432382916	21102	68	15A
0005432328560	21102	69	15C
0005432328484	21102	70	15D
0005432382852	21102	71	15E
0005432328668	21102	72	15F
0005432383056	21102	73	16A
0005432328555	21102	74	16C
0005432382976	21102	75	16D
0005432328552	21102	76	16E
0005432328556	21102	77	16F
0005432328569	21102	78	17A
0005432054322	21102	79	17C
0005432328501	21102	80	17D
0005432328451	21102	81	17E
0005432328533	21102	82	17F
0005432328537	21102	83	18A
0005432328587	21102	84	18C
0005432382851	21102	85	18D
0005432328629	21102	86	18E
0005432054321	21102	87	18F
0005432383031	21102	88	19A
0005432328521	21102	89	19C
0005432328561	21102	90	19D
0005432328524	21102	91	19E
0005432328497	21102	92	19F
0005432382870	21102	93	20A
0005432383032	21102	94	20C
0005432382869	21102	95	20D
0005432383060	21102	96	20E
0005432328467	21102	97	20F
0005432328925	31221	1	1A
0005432383355	31221	2	1C
0005432287210	31221	3	1D
0005432383333	31221	4	1F
0005432383325	31221	5	2A
0005432328883	31221	6	2C
0005432287211	31221	7	2D
0005432383334	31221	8	2F
0005432328885	31221	9	3A
0005432383347	31221	10	3C
0005432328903	31221	11	3D
0005432328914	31221	12	3F
0005432287212	31221	13	4A
0005432383340	31221	14	4C
0005432328896	31221	15	4D
0005432383331	31221	16	4E
0005432328918	31221	17	4F
0005432328911	31221	18	5A
0005432328894	31221	19	5C
0005432383335	31221	20	5D
0005432383330	31221	21	5E
0005432383356	31221	22	5F
0005432328912	31221	23	6A
0005432328920	31221	24	6C
0005432328882	31221	25	6D
0005432328897	31221	26	6E
0005432383337	31221	27	6F
0005432328886	31221	28	7A
0005432328884	31221	29	7C
0005432328879	31221	30	7D
0005432383343	31221	31	7E
0005432383348	31221	32	7F
0005432383318	31221	33	8A
0005432328877	31221	34	8C
0005432328895	31221	35	8D
0005432328893	31221	36	8E
0005432328922	31221	37	8F
0005432383326	31221	38	9A
0005432328878	31221	39	9C
0005432383339	31221	40	9D
0005432328890	31221	41	9E
0005432383320	31221	42	9F
0005432383322	31221	43	10A
0005432328909	31221	44	10C
0005432383324	31221	45	10D
0005432383329	31221	46	10E
0005432383328	31221	47	10F
0005432383321	31221	48	11A
0005432383353	31221	49	11C
0005432383345	31221	50	11D
0005432328923	31221	51	11E
0005432287213	31221	52	11F
0005432328888	31221	53	12A
0005432383319	31221	54	12C
0005432383354	31221	55	12D
0005432383341	31221	56	12E
0005432383327	31221	57	12F
0005432328906	31221	58	13C
0005432383338	31221	59	13A
0005432328900	31221	60	13D
0005432328910	31221	61	13E
0005432328915	31221	62	13F
0005432328889	31221	63	14A
0005432328916	31221	64	14C
0005432328908	31221	65	14D
0005432383323	31221	66	14E
0005432328880	31221	67	14F
0005432328891	31221	68	15A
0005432328905	31221	69	15C
0005432383342	31221	70	15D
0005432328917	31221	71	15E
0005432328919	31221	72	15F
0005432383358	31221	73	16C
0005432328904	31221	74	16D
0005432328881	31221	75	16E
0005432383317	31221	76	16F
0005432328921	31221	77	17A
0005432328902	31221	78	17C
0005432328924	31221	79	17D
0005432328907	31221	80	17E
0005432328887	31221	81	17F
0005432383346	31221	82	18A
0005432328898	31221	83	18D
0005432383349	31221	84	18E
0005432383336	31221	85	18F
0005432383351	31221	86	19A
0005432328899	31221	87	19C
0005432328892	31221	88	19D
0005432328913	31221	89	19E
0005432383350	31221	90	19F
0005432383344	31221	91	20A
0005432383352	31221	92	20C
0005432328901	31221	93	20D
0005432383332	31221	94	20E
0005432383357	31221	95	20F
0005432424652	13355	1	1A
0005432424666	13355	2	1C
0005432424612	13355	3	1D
0005432424646	13355	4	1F
0005432424641	13355	5	2C
0005432424644	13355	6	2D
0005432424610	13355	7	3A
0005432424616	13355	8	3C
0005432424647	13355	9	3F
0005432424640	13355	10	4C
0005432424611	13355	11	4D
0005432424613	13355	12	4F
0005432424654	13355	13	5C
0005432424660	13355	14	5D
0005432424653	13355	15	5E
0005432424648	13355	16	5F
0005432424658	13355	17	6A
0005432424617	13355	18	6C
0005432424620	13355	19	6E
0005432424631	13355	20	6F
0005432424615	13355	21	7F
0005432424625	13355	22	8A
0005432424628	13355	23	9A
0005432424636	13355	24	9C
0005432424639	13355	25	9F
0005432424667	13355	26	10E
0005432424650	13355	27	10F
0005432424656	13355	28	11A
0005432424627	13355	29	11C
0005432424614	13355	30	11D
0005432424632	13355	31	11E
0005432424642	13355	32	12F
0005432424626	13355	33	13A
0005432424622	13355	34	13D
0005432424637	13355	35	13E
0005432424621	13355	36	13F
0005432424645	13355	37	14C
0005432424619	13355	38	14D
0005432424633	13355	39	14E
0005432424623	13355	40	15A
0005432424659	13355	41	15C
0005432424649	13355	42	15E
0005432424665	13355	43	16A
0005432424638	13355	44	16C
0005432424651	13355	45	16E
0005432424630	13355	46	16F
0005432424661	13355	47	17C
0005432424657	13355	48	17E
0005432424618	13355	49	18A
0005432424663	13355	50	18C
0005432424635	13355	51	18D
0005432424624	13355	52	18F
0005432424629	13355	53	19A
0005432424662	13355	54	19C
0005432424664	13355	55	19D
0005432424634	13355	56	19F
0005432424655	13355	57	20A
0005432424643	13355	58	20E
0005432424236	30705	1	1A
0005432424251	30705	2	1C
0005432424217	30705	3	1F
0005432424266	30705	4	2A
0005432424276	30705	5	2C
0005432424208	30705	6	2D
0005432424244	30705	7	2F
0005432424238	30705	8	3A
0005432424280	30705	9	3C
0005432424130	30705	10	3D
0005432424311	30705	11	3F
0005432424168	30705	12	4A
0005432424221	30705	13	4D
0005432424142	30705	14	5A
0005432424071	30705	15	5D
0005432424222	30705	16	5E
0005432424206	30705	17	5F
0005432424235	30705	18	6A
0005432424176	30705	19	6C
0005432424106	30705	20	6E
0005432424248	30705	21	6F
0005432424279	30705	22	7A
0005432424249	30705	23	7C
0005432424155	30705	24	7D
0005432424164	30705	25	7F
0005432424131	30705	26	8C
0005432424290	30705	27	8D
0005432424141	30705	28	9A
0005432424190	30705	29	9F
0005432424199	30705	30	10C
0005432424250	30705	31	10D
0005432424177	30705	32	10E
0005432424287	30705	33	10F
0005432424271	30705	34	11A
0005432424220	30705	35	11C
0005432424185	30705	36	11E
0005432424316	30705	37	11F
0005432424245	30705	38	12A
0005432424269	30705	39	12D
0005432424237	30705	40	12F
0005432424070	30705	41	13D
0005432424132	30705	42	13E
0005432424085	30705	43	13F
0005432424211	30705	44	14A
0005432424215	30705	45	14C
0005432424064	30705	46	14E
0005432424023	30705	47	15C
0005432424288	30705	48	15D
0005432424087	30705	49	15E
0005432424289	30705	50	15F
0005432424246	30705	51	16A
0005432424182	30705	52	16F
0005432424140	30705	53	17A
0005432424317	30705	54	17D
0005432424186	30705	55	17F
0005432424253	30705	56	18A
0005432424264	30705	57	18C
0005432424212	30705	58	18D
0005432424086	30705	59	18E
0005432424270	30705	60	18F
0005432424265	30705	61	19C
0005432424216	30705	62	19D
0005432424255	30705	63	19E
0005432424165	30705	64	19F
0005432424282	30705	65	20A
0005432424283	30705	66	20F
0005432817619	9621	1	1C
0005432817630	9621	2	2C
0005432822245	9621	3	2F
0005432817632	9621	4	3D
0005432822241	9621	5	3F
0005432901564	9621	6	4C
0005432817623	9621	7	4D
0005432817608	9621	8	4F
0005432901611	9621	9	5A
0005432901462	9621	10	5C
0005432817631	9621	11	5D
0005432817606	9621	12	6C
0005432817610	9621	13	6E
0005432817614	9621	14	6F
0005432817624	9621	15	7A
0005432817627	9621	16	7C
0005432289003	9621	17	7D
0005432901610	9621	18	7F
0005432817621	9621	19	8A
0005432817633	9621	20	8D
0005432817609	9621	21	8E
0005434448332	9621	22	8F
0005434186180	9621	23	9A
0005434448333	9621	24	9C
0005432289004	9621	25	9D
0005434186200	9621	26	9E
0005432901562	9621	27	9F
0005432817607	9621	28	10C
0005434157445	9621	29	10D
0005432822239	9621	30	10E
0005432817629	9621	31	11A
0005432289001	9621	32	11C
0005434448334	9621	33	11D
0005432817612	9621	34	11E
0005432901575	9621	35	11F
0005432901527	9621	36	12C
0005432817616	9621	37	12D
0005434157446	9621	38	12E
0005432817615	9621	39	12F
0005432901595	9621	40	13A
0005434186203	9621	41	13C
0005432901558	9621	42	13D
0005432901494	9621	43	13E
0005432822238	9621	44	13F
0005432822243	9621	45	14A
0005432901598	9621	46	14C
0005432901547	9621	47	14E
0005432901559	9621	48	14F
0005432822242	9621	49	15A
0005432817613	9621	50	15C
0005432822244	9621	51	15D
0005432817622	9621	52	15E
0005432817617	9621	53	16A
0005432817634	9621	54	16C
0005432817628	9621	55	16E
0005432901597	9621	56	17A
0005432901546	9621	57	17C
0005432289002	9621	58	17E
0005432901513	9621	59	17F
0005432817611	9621	60	18A
0005432817620	9621	61	18C
0005432817626	9621	62	18D
0005432817635	9621	63	18F
0005432901600	9621	64	19A
0005432817625	9621	65	19F
0005432817618	9621	66	20C
0005432822240	9621	67	20D
0005432901563	9621	68	20E
0005432901697	28965	1	1A
0005432901701	28965	2	1C
0005432817459	28965	3	1F
0005432817395	28965	4	2F
0005432817344	28965	5	3C
0005432817187	28965	6	3D
0005432817422	28965	7	3F
0005432817377	28965	8	4A
0005432817423	28965	9	4D
0005432817278	28965	10	4E
0005432901696	28965	11	5A
0005432817396	28965	12	5C
0005432822179	28965	13	5D
0005434157519	28965	14	5E
0005432817318	28965	15	5F
0005432901691	28965	16	6A
0005432822177	28965	17	6D
0005432817279	28965	18	6E
0005432822174	28965	19	6F
0005434186211	28965	20	7A
0005432817220	28965	21	7D
0005432822180	28965	22	7F
0005434448319	28965	23	8A
0005432817295	28965	24	8C
0005432817340	28965	25	8D
0005432822175	28965	26	8E
0005432817277	28965	27	8F
0005432901704	28965	28	9A
0005432002086	28965	29	9C
0005432901698	28965	30	9D
0005432822176	28965	31	9E
0005434448288	28965	32	9F
0005432817412	28965	33	10D
0005432901705	28965	34	10E
0005432901699	28965	35	10F
0005432822185	28965	36	11A
0005432817465	28965	37	11C
0005434448291	28965	38	11D
0005432817420	28965	39	11E
0005432901689	28965	40	11F
0005434157518	28965	41	12A
0005432817304	28965	42	12C
0005434157520	28965	43	12D
0005432817460	28965	44	12E
0005432817338	28965	45	12F
0005432817466	28965	46	13A
0005432817345	28965	47	13C
0005432901703	28965	48	13D
0005432822193	28965	49	13E
0005432002087	28965	50	13F
0005434186213	28965	51	14A
0005432901695	28965	52	14C
0005432901692	28965	53	14E
0005432901690	28965	54	14F
0005432817319	28965	55	15A
0005432817456	28965	56	15D
0005434448292	28965	57	15E
0005432901694	28965	58	15F
0005432817424	28965	59	16A
0005432817373	28965	60	16C
0005432817429	28965	61	16D
0005432817508	28965	62	16E
0005432901706	28965	63	16F
0005432901700	28965	64	17D
0005432817305	28965	65	17C
0005432817355	28965	66	17E
0005434186212	28965	67	18D
0005432822184	28965	68	18F
0005432901693	28965	69	19A
0005432901702	28965	70	19D
0005434157522	28965	71	19E
0005432817339	28965	72	19F
0005434448289	28965	73	20C
0005432817408	28965	74	20D
0005434157521	28965	75	20E
0005432817252	28965	76	20F
0005432613884	15091	1	1A
0005432611732	15091	2	1B
0005435841819	15091	3	2B
0005432611731	15091	4	3B
0005435841090	15091	5	4B
0005432611733	15091	6	6A
0005432613882	15091	7	5B
0005432613883	15091	8	6B
0005432607560	31573	1	1A
0005432611710	31573	2	1B
0005432611692	31573	3	2A
0005432607548	31573	4	2B
0005432611707	31573	5	3A
0005432611702	31573	6	4A
0005432611691	31573	7	3B
0005432607545	31573	8	5A
0005432607553	31573	9	4B
0005432611711	31573	10	5B
0005432611701	31573	11	6A
0005432607549	31573	12	6B
0005433569347	11860	1	1C
0005433569346	11860	2	1A
0005432948150	11860	3	1D
0005433569342	11860	4	2A
0005432948151	11860	5	1F
0005433569359	11860	6	2D
0005432948229	11860	7	3A
0005433569329	11860	8	2F
0005432948219	11860	9	3C
0005432948314	11860	10	4A
0005433569350	11860	11	3F
0005433569317	11860	12	4C
0005433569336	11860	13	4F
0005432948290	11860	14	4D
0005433569316	11860	15	5C
0005432948166	11860	16	5F
0005432948372	11860	17	5D
0005433569348	11860	18	6B
0005432948269	11860	19	6A
0005432948335	11860	20	6F
0005432948291	11860	21	6E
0005433569319	11860	22	6D
0005433569310	11860	23	7A
0005433569321	11860	24	7C
0005432948220	11860	25	7B
0005432948144	11860	26	7E
0005433569314	11860	27	7D
0005433569339	11860	28	7F
0005433569326	11860	29	8C
0005433569351	11860	30	8B
0005433569311	11860	31	8A
0005433569324	11860	32	8D
0005432948315	11860	33	8F
0005433569313	11860	34	8E
0005433569343	11860	35	9B
0005432948174	11860	36	9A
0005433569334	11860	37	9C
0005432948370	11860	38	9D
0005432948228	11860	39	10A
0005433569332	11860	40	9F
0005433569304	11860	41	10C
0005432948271	11860	42	10B
0005433569309	11860	43	10E
0005433569312	11860	44	11A
0005432948452	11860	45	10F
0005433569353	11860	46	11C
0005433569331	11860	47	11B
0005433569355	11860	48	11D
0005433569302	11860	49	11F
0005433569300	11860	50	11E
0005432948383	11860	51	12B
0005433569341	11860	52	12A
0005433569335	11860	53	12C
0005433569303	11860	54	12E
0005433569338	11860	55	13A
0005433569358	11860	56	12F
0005432948273	11860	57	13C
0005432948165	11860	58	13D
0005433569315	11860	59	13F
0005432948236	11860	60	14B
0005433569349	11860	61	14A
0005432948227	11860	62	14D
0005433569340	11860	63	14C
0005432948263	11860	64	14F
0005432948205	11860	65	14E
0005433569323	11860	66	15A
0005433569327	11860	67	15D
0005433569344	11860	68	15E
0005433569322	11860	69	16A
0005433569308	11860	70	15F
0005432948173	11860	71	16C
0005432948167	11860	72	16D
0005433569306	11860	73	16F
0005433569357	11860	74	17C
0005433569354	11860	75	17B
0005433569325	11860	76	17A
0005433569318	11860	77	17D
0005432948130	11860	78	17E
0005432948347	11860	79	18B
0005432948168	11860	80	18A
0005432948099	11860	81	17F
0005432948453	11860	82	18C
0005433569337	11860	83	18E
0005433569301	11860	84	19A
0005433569328	11860	85	19C
0005433569356	11860	86	19B
0005433569330	11860	87	19D
0005432948226	11860	88	19F
0005432948237	11860	89	20B
0005432948285	11860	90	20A
0005432948204	11860	91	20C
0005433569352	11860	92	20F
0005433569307	11860	93	20D
0005432948170	11860	94	21A
0005433569345	11860	95	21C
0005432948169	11860	96	21B
0005433569320	11860	97	21E
0005433569333	11860	98	21D
0005433569305	11860	99	21F
0005433568704	25306	1	1C
0005432948712	25306	2	1A
0005432948714	25306	3	1F
0005433568870	25306	4	1D
0005432948716	25306	5	2C
0005432948697	25306	6	2A
0005433568720	25306	7	2D
0005433568747	25306	8	3A
0005432948720	25306	9	2F
0005433568655	25306	10	3D
0005433568684	25306	11	3C
0005433568639	25306	12	4A
0005433568778	25306	13	3F
0005432948701	25306	14	4C
0005432948695	25306	15	4F
0005433568459	25306	16	4D
0005433568888	25306	17	5C
0005433568792	25306	18	5A
0005433568656	25306	19	5F
0005432948722	25306	20	5D
0005432948717	25306	21	6B
0005433568689	25306	22	6A
0005433568818	25306	23	6C
0005433568491	25306	24	6E
0005433568833	25306	25	7B
0005433568815	25306	26	7A
0005433568742	25306	27	6F
0005433568673	25306	28	7E
0005433568584	25306	29	7D
0005432948690	25306	30	8A
0005433568887	25306	31	7F
0005432948702	25306	32	8B
0005432948685	25306	33	8E
0005433568817	25306	34	8D
0005433568744	25306	35	8F
0005432948689	25306	36	9B
0005432948705	25306	37	9C
0005433568714	25306	38	9F
0005432948684	25306	39	9E
0005433568625	25306	40	10A
0005432948681	25306	41	10C
0005433568909	25306	42	10B
0005432948699	25306	43	10E
0005433568627	25306	44	10D
0005432948719	25306	45	11A
0005432948682	25306	46	10F
0005433568816	25306	47	11B
0005432948686	25306	48	11D
0005433568860	25306	49	11C
0005433568910	25306	50	11F
0005433568795	25306	51	11E
0005432948708	25306	52	12B
0005432948710	25306	53	12A
0005432948715	25306	54	12C
0005433568797	25306	55	12F
0005432948713	25306	56	12E
0005433568760	25306	57	12D
0005432948711	25306	58	13A
0005433568806	25306	59	13B
0005432948691	25306	60	13D
0005432948688	25306	61	13F
0005433568640	25306	62	14C
0005433568791	25306	63	14B
0005432948706	25306	64	14D
0005432948696	25306	65	14F
0005433568722	25306	66	14E
0005432948709	25306	67	15B
0005433568779	25306	68	15A
0005432948700	25306	69	15D
0005433568798	25306	70	15C
0005433568920	25306	71	15F
0005433568622	25306	72	15E
0005433568800	25306	73	16A
0005433568748	25306	74	16C
0005432948703	25306	75	16B
0005433568669	25306	76	16E
0005433568710	25306	77	16D
0005432948693	25306	78	17A
0005433568803	25306	79	17C
0005433568761	25306	80	17B
0005433568659	25306	81	17D
0005432948707	25306	82	17F
0005433568626	25306	83	17E
0005432948694	25306	84	18C
0005432948698	25306	85	18B
0005433568696	25306	86	18E
0005432948721	25306	87	18D
0005433568804	25306	88	19A
0005433568711	25306	89	18F
0005433568719	25306	90	19B
0005433568827	25306	91	19D
0005432948683	25306	92	19C
0005433568866	25306	93	20A
0005433568871	25306	94	19F
0005432948692	25306	95	20B
0005433568762	25306	96	20D
0005433568777	25306	97	20C
0005433568741	25306	98	20E
0005432948704	25306	99	21B
0005432948718	25306	100	21A
0005432948687	25306	101	20F
0005433568849	25306	102	21E
0005433568850	25306	103	21D
0005433811619	27942	1	3A
0005433811625	27942	2	5D
0005433811631	27942	3	6A
0005433811620	27942	4	12B
0005433811624	27942	5	12F
0005433811622	27942	6	14B
0005433811616	27942	7	14D
0005433811632	27942	8	15B
0005433811617	27942	9	16E
0005433811623	27942	10	16F
0005433811621	27942	11	17B
0005433811628	27942	12	17C
0005433811618	27942	13	18E
0005433811630	27942	14	19F
0005434654837	5396	1	1A
0005434654826	5396	2	1D
0005434654822	5396	3	1F
0005434654823	5396	4	2A
0005434654842	5396	5	2C
0005435340238	5396	6	3A
0005432114220	5396	7	3D
0005434654833	5396	8	3F
0005435340166	5396	9	4A
0005434654828	5396	10	4C
0005435340161	5396	11	4D
0005434654845	5396	12	4F
0005434654838	5396	13	5C
0005434654821	5396	14	5D
0005434654839	5396	15	5E
0005434654820	5396	16	5F
0005435340217	5396	17	6A
0005434654843	5396	18	6D
0005435340210	5396	19	6F
0005435340226	5396	20	7F
0005432114219	5396	21	8A
0005434656567	5396	22	8E
0005435340239	5396	23	9C
0005434654817	5396	24	9D
0005434654844	5396	25	10A
0005435340218	5396	26	10C
0005434654825	5396	27	11C
0005434654831	5396	28	11F
0005435340205	5396	29	12A
0005434654819	5396	30	12D
0005432114218	5396	31	12E
0005434656568	5396	32	12F
0005435340221	5396	33	13C
0005434654846	5396	34	14D
0005434654827	5396	35	14F
0005435340253	5396	36	15C
0005435555360	5396	37	15D
0005434654847	5396	38	15E
0005435340215	5396	39	16C
0005435340222	5396	40	16D
0005435340158	5396	41	16E
0005434654832	5396	42	17A
0005435340202	5396	43	17C
0005435555361	5396	44	17D
0005434654840	5396	45	17E
0005434654834	5396	46	18C
0005434654829	5396	47	18D
0005434654836	5396	48	18F
0005434656566	5396	49	19A
0005434654818	5396	50	19D
0005434654824	5396	51	19E
0005434654835	5396	52	20A
0005434654841	5396	53	20C
0005434654830	5396	54	20D
0005435340175	5396	55	20F
0005435340341	12527	1	1C
0005434654620	12527	2	1F
0005435340342	12527	3	2A
0005434654574	12527	4	2C
0005434654666	12527	5	3A
0005434654628	12527	6	3D
0005434654519	12527	7	4A
0005434654603	12527	8	4C
0005434654618	12527	9	4D
0005434654619	12527	10	4E
0005435340333	12527	11	4F
0005434654640	12527	12	5D
0005435340344	12527	13	5E
0005434654660	12527	14	5F
0005434654491	12527	15	6A
0005434654667	12527	16	6D
0005435340339	12527	17	6C
0005434654492	12527	18	6E
0005434654624	12527	19	6F
0005435340337	12527	20	7E
0005435340346	12527	21	7F
0005434654565	12527	22	8D
0005434654639	12527	23	8E
0005435340345	12527	24	9D
0005434654683	12527	25	9E
0005434654604	12527	26	10C
0005434654411	12527	27	10E
0005435340335	12527	28	11A
0005434654556	12527	29	10F
0005434654659	12527	30	11C
0005434654664	12527	31	11D
0005434654634	12527	32	11F
0005435340340	12527	33	12C
0005434654410	12527	34	12D
0005435340338	12527	35	12F
0005434654520	12527	36	13A
0005434654638	12527	37	13E
0005434654589	12527	38	14C
0005434654672	12527	39	14D
0005434654412	12527	40	14E
0005434654437	12527	41	14F
0005434654725	12527	42	15A
0005434654575	12527	43	15E
0005434654621	12527	44	16E
0005435340343	12527	45	16F
0005434654673	12527	46	17A
0005434654521	12527	47	17C
0005435340334	12527	48	17F
0005434654605	12527	49	18A
0005434654493	12527	50	18C
0005435340336	12527	51	18D
0005434654590	12527	52	18F
0005434654724	12527	53	19C
0005434654625	12527	54	19D
0005434654606	12527	55	19F
0005435340347	12527	56	20A
0005434654518	12527	57	20D
0005434654592	12527	58	20E
0005434654637	12527	59	20F
0005432428912	7447	1	1C
0005433716222	7447	2	1D
0005433690934	7447	3	1F
0005435266121	7447	4	2A
0005433716215	7447	5	2D
0005433716233	7447	6	2C
0005433722253	7447	7	3A
0005433716232	7447	8	2F
0005435266129	7447	9	3C
0005433716213	7447	10	3F
0005435266128	7447	11	3D
0005433716227	7447	12	4A
0005433716196	7447	13	4C
0005433716207	7447	14	4E
0005433716220	7447	15	4F
0005433716192	7447	16	5A
0005433722247	7447	17	5C
0005433716236	7447	18	5D
0005433716202	7447	19	5E
0005433716208	7447	20	6B
0005433716239	7447	21	6A
0005432078136	7447	22	6C
0005433716214	7447	23	6D
0005433716229	7447	24	6E
0005433719156	7447	25	7B
0005433716228	7447	26	7C
0005433716200	7447	27	7D
0005433716195	7447	28	7E
0005433722249	7447	29	8C
0005433716210	7447	30	8F
0005432428911	7447	31	9A
0005433716242	7447	32	9B
0005433716225	7447	33	9D
0005435266132	7447	34	9F
0005433722246	7447	35	10C
0005433689920	7447	36	10D
0005433716212	7447	37	11A
0005432078137	7447	38	11C
0005433716204	7447	39	11B
0005433716241	7447	40	11D
0005433688817	7447	41	12A
0005433716240	7447	42	12B
0005433716194	7447	43	12D
0005433716221	7447	44	12C
0005433722251	7447	45	12F
0005433716237	7447	46	13B
0005433690933	7447	47	13A
0005433722248	7447	48	13C
0005433719154	7447	49	13D
0005433716197	7447	50	13E
0005433716216	7447	51	14A
0005435266118	7447	52	14B
0005433716205	7447	53	14E
0005432078134	7447	54	14D
0005433716218	7447	55	15B
0005432078135	7447	56	15A
0005433716231	7447	57	15E
0005433716198	7447	58	15D
0005433719155	7447	59	15F
0005433716226	7447	60	16B
0005435266133	7447	61	16C
0005433656684	7447	62	17A
0005435266127	7447	63	17C
0005433716206	7447	64	17D
0005433716203	7447	65	17E
0005433716193	7447	66	17F
0005432078138	7447	67	18F
0005433716211	7447	68	19B
0005433716223	7447	69	19C
0005433716209	7447	70	19E
0005433716201	7447	71	19D
0005433656686	7447	72	20B
0005432078133	7447	73	20A
0005433716235	7447	74	20D
0005433716238	7447	75	20E
0005433656685	7447	76	20F
0005433722250	7447	77	21C
0005433716217	7447	78	21B
0005433722252	7447	79	21D
0005433716230	7447	80	22A
0005435266130	7447	81	22B
0005433716199	7447	82	22C
0005433716234	7447	83	22E
0005433716219	7447	84	22F
0005433716224	7447	85	23B
0005433688818	7447	86	23D
0005433689919	7447	87	23F
0005433722218	29238	1	1A
0005433715799	29238	2	1F
0005433715972	29238	3	2D
0005433715816	29238	4	3A
0005433722219	29238	5	3D
0005433685519	29238	6	3C
0005435266165	29238	7	4A
0005433715694	29238	8	4B
0005433715496	29238	9	4E
0005433715864	29238	10	5A
0005435266159	29238	11	5C
0005433715800	29238	12	5D
0005433715497	29238	13	5F
0005433715585	29238	14	6B
0005432428947	29238	15	6E
0005433715563	29238	16	6F
0005432006775	29238	17	7C
0005433722220	29238	18	7B
0005433656656	29238	19	8A
0005432428946	29238	20	7F
0005435266162	29238	21	8C
0005433715719	29238	22	8D
0005433715498	29238	23	8F
0005433722172	29238	24	9A
0005433715718	29238	25	9B
0005433722186	29238	26	9C
0005433722224	29238	27	9E
0005433656659	29238	28	9F
0005433722213	29238	29	10D
0005433715877	29238	30	10C
0005433715861	29238	31	10E
0005433715928	29238	32	11B
0005433722195	29238	33	11C
0005435266163	29238	34	11E
0005433722184	29238	35	11D
0005433715820	29238	36	11F
0005433722208	29238	37	12B
0005433715787	29238	38	12A
0005433722171	29238	39	12C
0005433715801	29238	40	12D
0005433715653	29238	41	12E
0005433719122	29238	42	13B
0005433688792	29238	43	13A
0005433722221	29238	44	13C
0005433715545	29238	45	13E
0005433722207	29238	46	13F
0005433722210	29238	47	14D
0005433715821	29238	48	14C
0005433722214	29238	49	14E
0005433715720	29238	50	14F
0005433715973	29238	51	15B
0005433715846	29238	52	15C
0005433656651	29238	53	15E
0005433715487	29238	54	16A
0005433715495	29238	55	15F
0005433688807	29238	56	16B
0005433715745	29238	57	16C
0005435266166	29238	58	16D
0005435266161	29238	59	16F
0005435266160	29238	60	16E
0005433715865	29238	61	17E
0005432428945	29238	62	18A
0005433715728	29238	63	18B
0005433715693	29238	64	18D
0005432006778	29238	65	19B
0005433656652	29238	66	19C
0005433656646	29238	67	19E
0005433715729	29238	68	19D
0005433715828	29238	69	19F
0005433715904	29238	70	20D
0005432006777	29238	71	20E
0005433722182	29238	72	20F
0005435266164	29238	73	21B
0005432006776	29238	74	21A
0005433688806	29238	75	21C
0005433722203	29238	76	22A
0005433722185	29238	77	21F
0005433715712	29238	78	22D
0005433715819	29238	79	22F
0005433715845	29238	80	23B
0005435266167	29238	81	23E
0005433715640	29238	82	23D
0005434182104	8696	1	1F
0005434095341	8696	2	2A
0005434095355	8696	3	2D
0005434095354	8696	4	2F
0005434182141	8696	5	4A
0005434182131	8696	6	4C
0005434182149	8696	7	4F
0005434184660	8696	8	5A
0005434182181	8696	9	5C
0005434182156	8696	10	5F
0005434095352	8696	11	6A
0005434184662	8696	12	6C
0005434182188	8696	13	6E
0005434182147	8696	14	7C
0005434182130	8696	15	7D
0005434182118	8696	16	7E
0005434184661	8696	17	7F
0005434182126	8696	18	8D
0005434182187	8696	19	8E
0005434095349	8696	20	8F
0005434095347	8696	21	9C
0005434182164	8696	22	9D
0005434095342	8696	23	9E
0005434182174	8696	24	10F
0005434095343	8696	25	11D
0005434182196	8696	26	12A
0005434095350	8696	27	12C
0005434095356	8696	28	12D
0005434095348	8696	29	14F
0005434095345	8696	30	15E
0005434095340	8696	31	16D
0005434182153	8696	32	16E
0005434182154	8696	33	16F
0005434095351	8696	34	17A
0005434182152	8696	35	17C
0005434095346	8696	36	18A
0005434182173	8696	37	18C
0005434095353	8696	38	19D
0005434095344	8696	39	19F
0005434182148	8696	40	20C
0005434182142	8696	41	20D
0005434182103	8696	42	20E
0005434095209	11682	1	1C
0005434182247	11682	2	1D
0005434095196	11682	3	2C
0005434183588	11682	4	2F
0005434182246	11682	5	4E
0005434095136	11682	6	4F
0005434095197	11682	7	6A
0005434095221	11682	8	6C
0005434184674	11682	9	6E
0005434182248	11682	10	7C
0005434143717	11682	11	7D
0005434095223	11682	12	7E
0005434095186	11682	13	7F
0005434182241	11682	14	8D
0005434095255	11682	15	8E
0005434182243	11682	16	9F
0005434095222	11682	17	10D
0005434095185	11682	18	10E
0005434182245	11682	19	11E
0005434095254	11682	20	11F
0005434183589	11682	21	12E
0005434095257	11682	22	13A
0005434095178	11682	23	13E
0005434095177	11682	24	14C
0005434182249	11682	25	15A
0005434182252	11682	26	15C
0005434184673	11682	27	15D
0005434143711	11682	28	15E
0005434183587	11682	29	15F
0005434143724	11682	30	16A
0005434095220	11682	31	16C
0005434182251	11682	32	16D
0005434182244	11682	33	17C
0005434182250	11682	34	17F
0005434143710	11682	35	19A
0005434182242	11682	36	20D
0005433397885	1453	1	1A
0005433398050	1453	2	1C
0005433397770	1453	3	1D
0005433397934	1453	4	1F
0005433397843	1453	5	2A
0005433397954	1453	6	2C
0005433397865	1453	7	2D
0005433397964	1453	8	3C
0005433456990	1453	9	3D
0005433397935	1453	10	3F
0005433397828	1453	11	4D
0005433456992	1453	12	5A
0005433398080	1453	13	5C
0005433397949	1453	14	5E
0005432906520	1453	15	5F
0005433397953	1453	16	6A
0005433397878	1453	17	6C
0005433456993	1453	18	6D
0005433398015	1453	19	6E
0005433397871	1453	20	7C
0005433397872	1453	21	7F
0005433397943	1453	22	8A
0005433397857	1453	23	8D
0005433397814	1453	24	8F
0005433397950	1453	25	9A
0005433398168	1453	26	9C
0005433397895	1453	27	9D
0005433397778	1453	28	9E
0005433397909	1453	29	10A
0005433397910	1453	30	10C
0005433397875	1453	31	10D
0005432297291	1453	32	10E
0005433397860	1453	33	10F
0005433397861	1453	34	11A
0005432906528	1453	35	11D
0005433397911	1453	36	11F
0005433397782	1453	37	12A
0005433398072	1453	38	12C
0005433456991	1453	39	12D
0005433397858	1453	40	12F
0005433397846	1453	41	13A
0005433397894	1453	42	13C
0005433398067	1453	43	13E
0005433398040	1453	44	14A
0005433397783	1453	45	13F
0005433397815	1453	46	14D
0005433397893	1453	47	14E
0005432297289	1453	48	14F
0005433397750	1453	49	15A
0005433398074	1453	50	15C
0005433397751	1453	51	15D
0005433397981	1453	52	15E
0005433398073	1453	53	15F
0005433397779	1453	54	16A
0005433397884	1453	55	16C
0005433397816	1453	56	16D
0005433397687	1453	57	17A
0005433397821	1453	58	17C
0005432297290	1453	59	17E
0005433397889	1453	60	18A
0005433397888	1453	61	18C
0005433397459	1453	62	18D
0005433456989	1453	63	18E
0005433398032	1453	64	18F
0005433397838	1453	65	19C
0005432906529	1453	66	19E
0005433456988	1453	67	19F
0005433397890	1453	68	20A
0005433397866	1453	69	20C
0005433397892	1453	70	20D
0005433397929	1453	71	20E
0005433397912	1453	72	20F
0005433398281	19255	1	1A
0005433398274	19255	2	1D
0005433398276	19255	3	1F
0005433398279	19255	4	2A
0005433398278	19255	5	2C
0005433398302	19255	6	2F
0005433456959	19255	7	3A
0005433398306	19255	8	3C
0005433398305	19255	9	3F
0005433398301	19255	10	4A
0005435732237	19255	11	4C
0005433398284	19255	12	4D
0005435732293	19255	13	5C
0005433398296	19255	14	5D
0005433398311	19255	15	6A
0005433398283	19255	16	6C
0005433398286	19255	17	6F
0005433398317	19255	18	6E
0005433398292	19255	19	7A
0005433398303	19255	20	7D
0005433398316	19255	21	7E
0005435732313	19255	22	7F
0005433398308	19255	23	8A
0005433398320	19255	24	8C
0005435732238	19255	25	8D
0005435732294	19255	26	8E
0005435732239	19255	27	9A
0005433398304	19255	28	9D
0005433398299	19255	29	10A
0005433456948	19255	30	10C
0005433398290	19255	31	10D
0005433398321	19255	32	10E
0005435732263	19255	33	10F
0005433398289	19255	34	11A
0005433398309	19255	35	11C
0005433398294	19255	36	11E
0005435732250	19255	37	11F
0005433398282	19255	38	12A
0005433398287	19255	39	12D
0005433398297	19255	40	12E
0005433398293	19255	41	12F
0005433398273	19255	42	13A
0005435732260	19255	43	13C
0005433398272	19255	44	13F
0005433398310	19255	45	14A
0005433398300	19255	46	14C
0005433398285	19255	47	14D
0005433398315	19255	48	14E
0005435732315	19255	49	15A
0005435732314	19255	50	15C
0005433398277	19255	51	15E
0005433398314	19255	52	16A
0005433398291	19255	53	16E
0005433398280	19255	54	16F
0005435732236	19255	55	17A
0005433398288	19255	56	17E
0005433398319	19255	57	17F
0005433398313	19255	58	18A
0005433398318	19255	59	18C
0005433398295	19255	60	18D
0005433398298	19255	61	18E
0005433398275	19255	62	19C
0005433398307	19255	63	19E
0005433456947	19255	64	19F
0005435732271	19255	65	20A
0005435732251	19255	66	20C
0005433398312	19255	67	20F
0005434443660	17337	1	1B
0005434443633	17337	2	1D
0005434443606	17337	3	2B
0005434443569	17337	4	2D
0005434443605	17337	5	3C
0005434443722	17337	6	4B
0005434443641	17337	7	6A
0005434443700	17337	8	6B
0005434443667	17337	9	6C
0005434443583	17337	10	7A
0005434443708	17337	11	7B
0005434443584	17337	12	7D
0005434443581	17337	13	20C
0005434443580	17337	14	21C
0005434443647	17337	15	21D
0005434443644	17337	16	22A
0005434443552	17337	17	22B
0005434443632	17337	18	22C
0005434443668	17337	19	23B
0005434443779	20600	1	1B
0005434443782	20600	2	2C
0005434443772	20600	3	3B
0005434443781	20600	4	4A
0005434443773	20600	5	4D
0005434443778	20600	6	5A
0005434443784	20600	7	6B
0005434443775	20600	8	6C
0005434443786	20600	9	7B
0005434443776	20600	10	18B
0005434443783	20600	11	18D
0005434443785	20600	12	19A
0005434443777	20600	13	19B
0005434443774	20600	14	20C
0005434443771	20600	15	21B
0005434443780	20600	16	21D
0005434954627	7258	1	1A
0005435377569	7258	2	2B
0005435377576	7258	3	3A
0005434954630	7258	4	4A
0005435377568	7258	5	4B
0005434954628	7258	6	5B
0005434954629	7258	7	6A
0005434954604	28310	1	1A
0005434954598	28310	2	1B
0005434954593	28310	3	2B
0005435377591	28310	4	4A
0005434954592	28310	5	5A
0005435377592	28310	6	5B
0005434954605	28310	7	6B
0005434954606	28310	8	6A
0005435893618	4479	1	1B
0005434351753	4479	2	3C
0005435893602	4479	3	4C
0005434351759	4479	4	4D
0005435893609	4479	5	5C
0005434351752	4479	6	5D
0005434351764	4479	7	6B
0005434351762	4479	8	6D
0005435893603	4479	9	7A
0005434183567	4479	10	7C
0005434351763	4479	11	18C
0005434351754	4479	12	19D
0005434351760	4479	13	20A
0005434351756	4479	14	20D
0005434351757	4479	15	21B
0005434351761	4479	16	22A
0005434351755	4479	17	22C
0005435893608	4479	18	22D
0005434351758	4479	19	23A
0005434183566	4479	20	23B
0005434351628	29686	1	1D
0005434351627	29686	2	2B
0005434351617	29686	3	2D
0005434351695	29686	4	3B
0005434351657	29686	5	4D
0005435893665	29686	6	5B
0005434351629	29686	7	6B
0005435893668	29686	8	6C
0005435893667	29686	9	18B
0005435893664	29686	10	19A
0005434351635	29686	11	19B
0005434351626	29686	12	19C
0005434351636	29686	13	19D
0005435893670	29686	14	20A
0005435893669	29686	15	20B
0005434351656	29686	16	21B
0005435893663	29686	17	21C
0005434351625	29686	18	22A
0005435893666	29686	19	22C
0005434351618	29686	20	23B
0005434445256	1086	1	1A
0005433342365	1086	2	1B
0005433342932	1086	3	3A
0005433342611	1086	4	3C
0005433342945	1086	5	3B
0005433343091	1086	6	3H
0005435545780	1086	7	4A
0005433159310	1086	8	4C
0005433159311	1086	9	4G
0005433342051	1086	10	4H
0005433342997	1086	11	5C
0005433342435	1086	12	5G
0005433342567	1086	13	5H
0005433342662	1086	14	9B
0005433342732	1086	15	9G
0005435545771	1086	16	11B
0005434446532	1086	17	11E
0005435545774	1086	18	11F
0005433342684	1086	19	11H
0005433342853	1086	20	12A
0005433342685	1086	21	12E
0005433342531	1086	22	13A
0005432293220	1086	23	12G
0005433342996	1086	24	13B
0005433342343	1086	25	13E
0005435545778	1086	26	13G
0005433342748	1086	27	14B
0005433342734	1086	28	14A
0005433342805	1086	29	14D
0005433342411	1086	30	15A
0005433342568	1086	31	14H
0005433158121	1086	32	15H
0005433342329	1086	33	15G
0005433342987	1086	34	16A
0005435092119	1086	35	16D
0005434445257	1086	36	16B
0005435545782	1086	37	16E
0005433342801	1086	38	16F
0005433342314	1086	39	16H
0005433269694	1086	40	17B
0005433342328	1086	41	17A
0005433343095	1086	42	17E
0005433342728	1086	43	18A
0005433342723	1086	44	18D
0005433342463	1086	45	18G
0005433342729	1086	46	18H
0005434446529	1086	47	19B
0005435092123	1086	48	19A
0005435092121	1086	49	19D
0005435092127	1086	50	19E
0005433343186	1086	51	19H
0005435545772	1086	52	19G
0005433342803	1086	53	20D
0005433342724	1086	54	20F
0005433342407	1086	55	21B
0005433342810	1086	56	21E
0005435092122	1086	57	21G
0005433342774	1086	58	21F
0005433342741	1086	59	21H
0005433342769	1086	60	22E
0005433342207	1086	61	22G
0005433463912	1086	62	23A
0005435092120	1086	63	22H
0005433342851	1086	64	23B
0005433342295	1086	65	23D
0005433342804	1086	66	23F
0005433342458	1086	67	23E
0005433342208	1086	68	23G
0005433342811	1086	69	24A
0005433342806	1086	70	24F
0005433342588	1086	71	24H
0005433342981	1086	72	25E
0005435092118	1086	73	27A
0005433342434	1086	74	27B
0005433342377	1086	75	27E
0005433342944	1086	76	27D
0005433343048	1086	77	27F
0005435545770	1086	78	27H
0005435092124	1086	79	27G
0005433342800	1086	80	28B
0005433342612	1086	81	28E
0005435092126	1086	82	28F
0005433342686	1086	83	28H
0005433342802	1086	84	28G
0005433342852	1086	85	29A
0005435545783	1086	86	29D
0005435545781	1086	87	29B
0005433342968	1086	88	29F
0005433462758	1086	89	29H
0005433342749	1086	90	30A
0005433342733	1086	91	30D
0005433342797	1086	92	30B
0005433342566	1086	93	30E
0005433342453	1086	94	30G
0005433342823	1086	95	30H
0005433342874	1086	96	31B
0005433342742	1086	97	31F
0005433343185	1086	98	31E
0005435545775	1086	99	31G
0005433342513	1086	100	32A
0005433342589	1086	101	31H
0005433342873	1086	102	32E
0005433342998	1086	103	32D
0005433342992	1086	104	32F
0005433342647	1086	105	32G
0005435092125	1086	106	32H
0005433342584	1086	107	33B
0005433342452	1086	108	33E
0005433269692	1086	109	33F
0005435545777	1086	110	33H
0005433342597	1086	111	34A
0005435545773	1086	112	34D
0005432293221	1086	113	34B
0005433342645	1086	114	35A
0005433342808	1086	115	34H
0005433342898	1086	116	35B
0005435545784	1086	117	35D
0005433342798	1086	118	35E
0005433158120	1086	119	35F
0005433269693	1086	120	36A
0005434446530	1086	121	35H
0005433342547	1086	122	36B
0005433462757	1086	123	36D
0005433342406	1086	124	36F
0005433343001	1086	125	36H
0005433342988	1086	126	36G
0005433463911	1086	127	37A
0005433342610	1086	128	37B
0005433342991	1086	129	37D
0005433342050	1086	130	37F
0005433342357	1086	131	37G
0005434446531	1086	132	38A
0005433342745	1086	133	37H
0005435545776	1086	134	38B
0005433342540	1086	135	38F
0005435545779	1086	136	38G
0005433342809	1086	137	39E
0005433343536	17023	1	1A
0005433343544	17023	2	1C
0005433343600	17023	3	1B
0005433343580	17023	4	1H
0005433343597	17023	5	1G
0005433343589	17023	6	2A
0005433343551	17023	7	2B
0005433343530	17023	8	2F
0005433343534	17023	9	2C
0005433343520	17023	10	2H
0005433343606	17023	11	3C
0005433343572	17023	12	3B
0005433343531	17023	13	3F
0005433343547	17023	14	3G
0005433343614	17023	15	4A
0005435092059	17023	16	3H
0005433343575	17023	17	4C
0005433343542	17023	18	4B
0005433343616	17023	19	4G
0005433343557	17023	20	4F
0005433343527	17023	21	4H
0005433343539	17023	22	5B
0005433343540	17023	23	5G
0005433343535	17023	24	5F
0005433269747	17023	25	9G
0005433343574	17023	26	9H
0005433343608	17023	27	11B
0005433343529	17023	28	11E
0005433343594	17023	29	11F
0005435092042	17023	30	11H
0005433343582	17023	31	11G
0005435508252	17023	32	12A
0005433343565	17023	33	12D
0005435508274	17023	34	12B
0005435092019	17023	35	12E
0005433343543	17023	36	12F
0005433343553	17023	37	12H
0005433343590	17023	38	13B
0005433343605	17023	39	13E
0005435508292	17023	40	13G
0005433343577	17023	41	14A
0005433343515	17023	42	14F
0005433343538	17023	43	14G
0005433343607	17023	44	15A
0005433343550	17023	45	15D
0005433343613	17023	46	15F
0005433343554	17023	47	16B
0005433343555	17023	48	16E
0005433343609	17023	49	16F
0005433343588	17023	50	16H
0005433343581	17023	51	17A
0005433343556	17023	52	17D
0005433343591	17023	53	17B
0005433343528	17023	54	17E
0005433343592	17023	55	17G
0005433343562	17023	56	18B
0005435092062	17023	57	18E
0005433343585	17023	58	18G
0005435508284	17023	59	18F
0005433343519	17023	60	19A
0005435092044	17023	61	18H
0005435508285	17023	62	19E
0005433343566	17023	63	19H
0005433343601	17023	64	19G
0005433343602	17023	65	20D
0005433343525	17023	66	20B
0005433343599	17023	67	20E
0005433343532	17023	68	20F
0005433343516	17023	69	20G
0005433343579	17023	70	21E
0005433343545	17023	71	21D
0005433343593	17023	72	21F
0005433343604	17023	73	21H
0005433343563	17023	74	22B
0005433343596	17023	75	22A
0005435092008	17023	76	22G
0005433343523	17023	77	22H
0005435092014	17023	78	23B
0005433343549	17023	79	23D
0005435508280	17023	80	23F
0005433343564	17023	81	23G
0005433343595	17023	82	24B
0005435508293	17023	83	24F
0005433343584	17023	84	24E
0005433343611	17023	85	24G
0005433343561	17023	86	24H
0005435508288	17023	87	27E
0005433343552	17023	88	27F
0005433343526	17023	89	28B
0005433343576	17023	90	28E
0005435092024	17023	91	28D
0005433343570	17023	92	28F
0005433343603	17023	93	28H
0005433343560	17023	94	29G
0005433343568	17023	95	29F
0005433343517	17023	96	30B
0005435092027	17023	97	30A
0005433343573	17023	98	30F
0005433343533	17023	99	31D
0005433343558	17023	100	31F
0005433269743	17023	101	31H
0005435092045	17023	102	31G
0005433159322	17023	103	32B
0005433343559	17023	104	32E
0005435092025	17023	105	32F
0005433343571	17023	106	32H
0005433343598	17023	107	33B
0005433343615	17023	108	33E
0005433159323	17023	109	33G
0005433343612	17023	110	34B
0005433343541	17023	111	34F
0005433343587	17023	112	34E
0005433343567	17023	113	34G
0005433343586	17023	114	34H
0005435092026	17023	115	35E
0005433343537	17023	116	35D
0005433269745	17023	117	36A
0005433343521	17023	118	35H
0005433343522	17023	119	36B
0005433269742	17023	120	36E
0005433343583	17023	121	36D
0005433343518	17023	122	36F
0005433343546	17023	123	37D
0005433343578	17023	124	37F
0005433269744	17023	125	37E
0005433343569	17023	126	38A
0005433269746	17023	127	37H
0005433343548	17023	128	38G
0005435508253	17023	129	38F
0005433343610	17023	130	38H
0005433343524	17023	131	39F
0005434067178	12795	1	1A
0005434067242	12795	2	1C
0005434067060	12795	3	1F
0005434067374	12795	4	1D
0005434067341	12795	5	2C
0005434067217	12795	6	2A
0005434067167	12795	7	2F
0005434081811	12795	8	2D
0005434026693	12795	9	3A
0005434067244	12795	10	3D
0005434067080	12795	11	3C
0005434026697	12795	12	3F
0005434067220	12795	13	4A
0005434067261	12795	14	4C
0005432161163	12795	15	4B
0005434081743	12795	16	4D
0005434081728	12795	17	4E
0005434067123	12795	18	4F
0005434067116	12795	19	5A
0005434067211	12795	20	5C
0005434067079	12795	21	5B
0005434067227	12795	22	5D
0005434067418	12795	23	5E
0005434067587	12795	24	6A
0005434067149	12795	25	5F
0005432433708	12795	26	6C
0005434067331	12795	27	6B
0005434067219	12795	28	6E
0005434081812	12795	29	7A
0005433812911	12795	30	6F
0005434067304	12795	31	7B
0005433812912	12795	32	7C
0005432433706	12795	33	7D
0005434067303	12795	34	7F
0005434067173	12795	35	7E
0005434067315	12795	36	8A
0005434067371	12795	37	8B
0005434067039	12795	38	8C
0005434067205	12795	39	8D
0005434067216	12795	40	8E
0005434081847	12795	41	9A
0005434067188	12795	42	9B
0005434067543	12795	43	9D
0005434067474	12795	44	9C
0005432159880	12795	45	9F
0005434067268	12795	46	9E
0005434081734	12795	47	10C
0005434067305	12795	48	10B
0005434067335	12795	49	10D
0005433812913	12795	50	11A
0005434067286	12795	51	10E
0005434067313	12795	52	11B
0005434067325	12795	53	11D
0005432159879	12795	54	11C
0005434081825	12795	55	11F
0005434067273	12795	56	11E
0005434067499	12795	57	12A
0005434081775	12795	58	12B
0005434067599	12795	59	12C
0005434081809	12795	60	12E
0005434067373	12795	61	12D
0005434067588	12795	62	12F
0005434081824	12795	63	13A
0005434026694	12795	64	13B
0005434067222	12795	65	13C
0005434081802	12795	66	13E
0005434066961	12795	67	13D
0005434067537	12795	68	14A
0005434067031	12795	69	13F
0005434067127	12795	70	14C
0005432433705	12795	71	14B
0005434067168	12795	72	14D
0005434081803	12795	73	14E
0005434067187	12795	74	15A
0005434081818	12795	75	14F
0005434067260	12795	76	15B
0005432433704	12795	77	15C
0005434067568	12795	78	15D
0005434067284	12795	79	15E
0005434067243	12795	80	15F
0005434081770	12795	81	16A
0005434067175	12795	82	16C
0005434067506	12795	83	16B
0005434067536	12795	84	16D
0005434066962	12795	85	16E
0005434081846	12795	86	17A
0005434067412	12795	87	17B
0005434081774	12795	88	17C
0005434067411	12795	89	17D
0005434067224	12795	90	17F
0005434081776	12795	91	17E
0005434067332	12795	92	18A
0005434067008	12795	93	18B
0005434067314	12795	94	18C
0005432159882	12795	95	18D
0005434081808	12795	96	18F
0005434067267	12795	97	18E
0005432433707	12795	98	19A
0005434067285	12795	99	19C
0005433989747	12795	100	19B
0005434067363	12795	101	19D
0005434067117	12795	102	19F
0005434067417	12795	103	19E
0005434067215	12795	104	20A
0005434067545	12795	105	20B
0005434067326	12795	106	20D
0005433989744	12795	107	20E
0005434067110	12795	108	21A
0005434081827	12795	109	20F
0005434067226	12795	110	21C
0005434081807	12795	111	21B
0005434067225	12795	112	21D
0005434067452	12795	113	21E
0005434067480	12795	114	22B
0005434067485	12795	115	22A
0005434067221	12795	116	22C
0005434067544	12795	117	22D
0005434081757	12795	118	22F
0005432161164	12795	119	22E
0005434067316	12795	120	23B
0005433989755	12795	121	23A
0005434067327	12795	122	23C
0005434067625	12795	123	23E
0005432159881	12795	124	23D
0005434067566	12795	125	23F
0005432150224	30674	1	1A
0005433989788	30674	2	1C
0005434067849	30674	3	1D
0005434067883	30674	4	1F
0005434026713	30674	5	2A
0005434067859	30674	6	2D
0005433989791	30674	7	2C
0005433812889	30674	8	3A
0005434082007	30674	9	2F
0005434082005	30674	10	3C
0005434081993	30674	11	3F
0005434067839	30674	12	3D
0005434067853	30674	13	4B
0005434082006	30674	14	4A
0005434067870	30674	15	4C
0005434067886	30674	16	4D
0005432186884	30674	17	4E
0005434067829	30674	18	4F
0005434067847	30674	19	5A
0005434067820	30674	20	5C
0005433812892	30674	21	5B
0005434067830	30674	22	5D
0005434067878	30674	23	5E
0005434067857	30674	24	5F
0005434082003	30674	25	6A
0005434067841	30674	26	6C
0005434067867	30674	27	6B
0005432433641	30674	28	6D
0005434067876	30674	29	6F
0005432150226	30674	30	6E
0005434067850	30674	31	7B
0005434067879	30674	32	7A
0005434081986	30674	33	7C
0005434067888	30674	34	7E
0005434067871	30674	35	7D
0005433989792	30674	36	7F
0005434067887	30674	37	8A
0005433989789	30674	38	8B
0005434067832	30674	39	8C
0005434067824	30674	40	8E
0005433812885	30674	41	8D
0005434067825	30674	42	8F
0005433812891	30674	43	9A
0005434067882	30674	44	9B
0005434026711	30674	45	9C
0005434082000	30674	46	9E
0005432150227	30674	47	9D
0005432186883	30674	48	9F
0005434067891	30674	49	10B
0005434081998	30674	50	10C
0005434067873	30674	51	10E
0005434081999	30674	52	10D
0005434067826	30674	53	11A
0005434067872	30674	54	11B
0005434081990	30674	55	11C
0005434067822	30674	56	11E
0005434067846	30674	57	11D
0005434067827	30674	58	11F
0005434067845	30674	59	12A
0005434081989	30674	60	12B
0005434082001	30674	61	12C
0005434081991	30674	62	12E
0005433989793	30674	63	12D
0005434067885	30674	64	12F
0005434067865	30674	65	13A
0005434067855	30674	66	13B
0005433989790	30674	67	13D
0005434081992	30674	68	13C
0005434067860	30674	69	13F
0005434067884	30674	70	13E
0005432150225	30674	71	14B
0005434067836	30674	72	14A
0005434067874	30674	73	14D
0005432186882	30674	74	14C
0005434067837	30674	75	14E
0005434067852	30674	76	14F
0005432150229	30674	77	15A
0005434081994	30674	78	15C
0005434026709	30674	79	15B
0005434067889	30674	80	15D
0005434067831	30674	81	15E
0005432433680	30674	82	16A
0005434067828	30674	83	15F
0005432433670	30674	84	16C
0005434082004	30674	85	16B
0005434067848	30674	86	16D
0005434067866	30674	87	16F
0005434067834	30674	88	16E
0005434081985	30674	89	17A
0005432150223	30674	90	17B
0005434067890	30674	91	17C
0005433812884	30674	92	17D
0005434067862	30674	93	17F
0005434067877	30674	94	17E
0005433812888	30674	95	18A
0005434081996	30674	96	18B
0005434081988	30674	97	18C
0005434067864	30674	98	18E
0005432150228	30674	99	18D
0005434067838	30674	100	18F
0005434067842	30674	101	19A
0005434067856	30674	102	19B
0005433812890	30674	103	19C
0005434081987	30674	104	19D
0005434067861	30674	105	19F
0005432150230	30674	106	19E
0005434067863	30674	107	20A
0005434067868	30674	108	20C
0005434082002	30674	109	20B
0005434067881	30674	110	20D
0005434067835	30674	111	20E
0005434067833	30674	112	20F
0005434081997	30674	113	21B
0005434067821	30674	114	21A
0005434067843	30674	115	21C
0005434067844	30674	116	21D
0005434067854	30674	117	21E
0005434067840	30674	118	21F
0005434081995	30674	119	22B
0005434067858	30674	120	22A
0005434026714	30674	121	22C
0005434067880	30674	122	22D
0005434026712	30674	123	22E
0005434067875	30674	124	23A
0005432150231	30674	125	22F
0005434026710	30674	126	23B
0005434067823	30674	127	23D
0005432186885	30674	128	23C
0005434067851	30674	129	23E
0005434067869	30674	130	23F
0005435766518	5486	1	1B
0005435462395	5486	2	1F
0005435766556	5486	3	1C
0005435766550	5486	4	2A
0005435725624	5486	5	1H
0005435723054	5486	6	2B
0005435735156	5486	7	2C
0005434831104	5486	8	2F
0005432535801	5486	9	3A
0005435766532	5486	10	2H
0005435766535	5486	11	3F
0005435766547	5486	12	3C
0005435462265	5486	13	3H
0005435462408	5486	14	3G
0005435766538	5486	15	4B
0005435766513	5486	16	4A
0005435720826	5486	17	4F
0005433527285	5486	18	4C
0005435766520	5486	19	4G
0005432535827	5486	20	5A
0005435723056	5486	21	4H
0005435462373	5486	22	5B
0005435725623	5486	23	5F
0005435766504	5486	24	5C
0005433529298	5486	25	5G
0005435766527	5486	26	5H
0005435766559	5486	27	9B
0005434265142	5486	28	9G
0005435462388	5486	29	11A
0005435766533	5486	30	9H
0005434265046	5486	31	11D
0005435735157	5486	32	11B
0005434831110	5486	33	11E
0005434265084	5486	34	11G
0005435723055	5486	35	11F
0005435766549	5486	36	12B
0005432140488	5486	37	12E
0005435462253	5486	38	12H
0005434831128	5486	39	12G
0005434831125	5486	40	13B
0005435766508	5486	41	13A
0005435766522	5486	42	13D
0005433529299	5486	43	13E
0005434831107	5486	44	13G
0005435766506	5486	45	13F
0005435735158	5486	46	13H
0005435766526	5486	47	14G
0005435766530	5486	48	15B
0005434265012	5486	49	15A
0005435462205	5486	50	15E
0005434831124	5486	51	15D
0005433527286	5486	52	15G
0005435462320	5486	53	15F
0005435766539	5486	54	15H
0005435766548	5486	55	16D
0005435725622	5486	56	16E
0005435462429	5486	57	16G
0005435723057	5486	58	16F
0005435766540	5486	59	16H
0005434265168	5486	60	17A
0005435766536	5486	61	17D
0005435766544	5486	62	17B
0005434264966	5486	63	17F
0005432140491	5486	64	17E
0005435766557	5486	65	17G
0005435766534	5486	66	18A
0005435766560	5486	67	17H
0005434264997	5486	68	18D
0005435766511	5486	69	18E
0005435462279	5486	70	18G
0005435462319	5486	71	18F
0005435766529	5486	72	19A
0005435462296	5486	73	19D
0005435462280	5486	74	19B
0005435462255	5486	75	19E
0005435462315	5486	76	19F
0005435462366	5486	77	19G
0005435766555	5486	78	20A
0005435766553	5486	79	19H
0005432140489	5486	80	20D
0005435462370	5486	81	20B
0005435766519	5486	82	20E
0005434264908	5486	83	20H
0005432140484	5486	84	20G
0005434265021	5486	85	21A
0005435462386	5486	86	21D
0005435766542	5486	87	21B
0005434265167	5486	88	21G
0005435766505	5486	89	21F
0005435462424	5486	90	22A
0005435766537	5486	91	21H
0005434265118	5486	92	22B
0005434831105	5486	93	22F
0005435766517	5486	94	22E
0005433529296	5486	95	22G
0005432140486	5486	96	23A
0005434264942	5486	97	22H
0005435722067	5486	98	23B
0005435766507	5486	99	23D
0005432535815	5486	100	23F
0005434265141	5486	101	23G
0005435043283	5486	102	23H
0005435462277	5486	103	24B
0005435462316	5486	104	24D
0005434264996	5486	105	24F
0005435462385	5486	106	24G
0005435735154	5486	107	25E
0005432535832	5486	108	27A
0005432140485	5486	109	25F
0005435766509	5486	110	27B
0005435766521	5486	111	27E
0005434265033	5486	112	27D
0005435462089	5486	113	27F
0005434265095	5486	114	27G
0005433527288	5486	115	28A
0005435462194	5486	116	28D
0005435766523	5486	117	28B
0005434265062	5486	118	28E
0005434265032	5486	119	28G
0005435462239	5486	120	28F
0005434265078	5486	121	28H
0005435766510	5486	122	29D
0005433527287	5486	123	29B
0005435766512	5486	124	29E
0005434264967	5486	125	29H
0005434265131	5486	126	29G
0005434265059	5486	127	30A
0005435766552	5486	128	30E
0005434265083	5486	129	30D
0005435725620	5486	130	30B
0005434264914	5486	131	30F
0005434265117	5486	132	30G
0005435043285	5486	133	30H
0005434265169	5486	134	31B
0005435766543	5486	135	31A
0005435462381	5486	136	31F
0005435766525	5486	137	31E
0005435725619	5486	138	31G
0005435725621	5486	139	31H
0005435735155	5486	140	32A
0005435735153	5486	141	32E
0005434264915	5486	142	32F
0005432535799	5486	143	32G
0005435766515	5486	144	33A
0005434265091	5486	145	32H
0005434265092	5486	146	33D
0005434264999	5486	147	33B
0005435462191	5486	148	33E
0005432140487	5486	149	33F
0005432535816	5486	150	33H
0005435766545	5486	151	33G
0005434831132	5486	152	34B
0005435462283	5486	153	34A
0005434831127	5486	154	34D
0005434264932	5486	155	34E
0005434265034	5486	156	35A
0005434265054	5486	157	34H
0005435462300	5486	158	35B
0005434265047	5486	159	35D
0005435462007	5486	160	35F
0005435766514	5486	161	35G
0005434831108	5486	162	36B
0005432535800	5486	163	36A
0005435766551	5486	164	36E
0005434265020	5486	165	36D
0005432140492	5486	166	36G
0005435766528	5486	167	37A
0005435766546	5486	168	36H
0005433529297	5486	169	37B
0005435766524	5486	170	37E
0005435766541	5486	171	37D
0005434265061	5486	172	37F
0005435766558	5486	173	37G
0005434265053	5486	174	38B
0005435766531	5486	175	38A
0005435462198	5486	176	38D
0005435766554	5486	177	38E
0005432140490	5486	178	38H
0005435766516	5486	179	38G
0005435462346	5486	180	39D
0005433533301	13497	1	1A
0005435766076	13497	2	1C
0005434265258	13497	3	1B
0005435765893	13497	4	1F
0005435766001	13497	5	1G
0005435766085	13497	6	2A
0005435462642	13497	7	2B
0005435462612	13497	8	2F
0005435462640	13497	9	2C
0005434265272	13497	10	2H
0005435462615	13497	11	2G
0005435462618	13497	12	3A
0005433533265	13497	13	3C
0005432194529	13497	14	3F
0005434265275	13497	15	3H
0005432535860	13497	16	3G
0005435765870	13497	17	4B
0005435765842	13497	18	4A
0005435765918	13497	19	4G
0005435462637	13497	20	4F
0005433529247	13497	21	5A
0005435462630	13497	22	4H
0005435765773	13497	23	5C
0005433529232	13497	24	5G
0005435765830	13497	25	9B
0005434265266	13497	26	9A
0005435720131	13497	27	9G
0005435462610	13497	28	9H
0005435462616	13497	29	11B
0005435462644	13497	30	11A
0005434265283	13497	31	11E
0005434265276	13497	32	11D
0005433529237	13497	33	11F
0005435765964	13497	34	11G
0005435462628	13497	35	12A
0005435462639	13497	36	11H
0005435765975	13497	37	12B
0005434831177	13497	38	12E
0005434265277	13497	39	12G
0005432194531	13497	40	12F
0005435765974	13497	41	12H
0005434265262	13497	42	13A
0005435462632	13497	43	13D
0005433529263	13497	44	13B
0005435462620	13497	45	13F
0005433533305	13497	46	13E
0005435766071	13497	47	14A
0005435462614	13497	48	13H
0005435462606	13497	49	14B
0005435766093	13497	50	14D
0005433533294	13497	51	14F
0005434831175	13497	52	14H
0005435765791	13497	53	15E
0005435462633	13497	54	15F
0005435462635	13497	55	15G
0005435462617	13497	56	16A
0005435766015	13497	57	15H
0005434831174	13497	58	16D
0005435765915	13497	59	16B
0005433533290	13497	60	16E
0005435765929	13497	61	16G
0005435765871	13497	62	16F
0005435765865	13497	63	17A
0005435765968	13497	64	17D
0005435722053	13497	65	17B
0005432535858	13497	66	17G
0005432535861	13497	67	17F
0005435766043	13497	68	17H
0005432194533	13497	69	18A
0005435735117	13497	70	18E
0005434265270	13497	71	18D
0005435462638	13497	72	18F
0005435766026	13497	73	18H
0005433533283	13497	74	18G
0005435735129	13497	75	19B
0005434265264	13497	76	19E
0005435765896	13497	77	19D
0005433533277	13497	78	19H
0005435765990	13497	79	19G
0005435462609	13497	80	20A
0005434265280	13497	81	20B
0005435735122	13497	82	20E
0005435766090	13497	83	20D
0005435765774	13497	84	20G
0005435765894	13497	85	20F
0005433529246	13497	86	20H
0005435765834	13497	87	21B
0005434265259	13497	88	21D
0005435462627	13497	89	21E
0005435766091	13497	90	21G
0005433533284	13497	91	21F
0005434265269	13497	92	21H
0005435462641	13497	93	22A
0005435722052	13497	94	22D
0005432194532	13497	95	22B
0005433529252	13497	96	22F
0005435462619	13497	97	22E
0005435462622	13497	98	23A
0005435766088	13497	99	22H
0005435462629	13497	100	22G
0005435765931	13497	101	23B
0005433533276	13497	102	23E
0005434265282	13497	103	23D
0005433533278	13497	104	23F
0005434265273	13497	105	23G
0005435766094	13497	106	24A
0005435766087	13497	107	23H
0005435765883	13497	108	24B
0005435765895	13497	109	24E
0005435766089	13497	110	24D
0005434265278	13497	111	25D
0005435735127	13497	112	24H
0005435765942	13497	113	27A
0005434265261	13497	114	25F
0005435462643	13497	115	27B
0005434265265	13497	116	27D
0005435766047	13497	117	27F
0005435462631	13497	118	27G
0005433533295	13497	119	27H
0005435735138	13497	120	28B
0005435765901	13497	121	28D
0005435462611	13497	122	28F
0005433529233	13497	123	28E
0005433529243	13497	124	28H
0005434265263	13497	125	28G
0005435766096	13497	126	29A
0005435766083	13497	127	29D
0005432535859	13497	128	29B
0005434265260	13497	129	29E
0005435723036	13497	130	29G
0005435735133	13497	131	29H
0005433533272	13497	132	30A
0005434265271	13497	133	30D
0005435765991	13497	134	30F
0005435723035	13497	135	30G
0005435462607	13497	136	30H
0005435462626	13497	137	31B
0005435765936	13497	138	31E
0005435766072	13497	139	31F
0005432194530	13497	140	32A
0005435766086	13497	141	31H
0005435766084	13497	142	32B
0005435462613	13497	143	32E
0005435765940	13497	144	32D
0005433529238	13497	145	32F
0005435766075	13497	146	33A
0005433529245	13497	147	32H
0005435765989	13497	148	33E
0005434265267	13497	149	33D
0005435462624	13497	150	33G
0005433529248	13497	151	33F
0005435765930	13497	152	33H
0005435462625	13497	153	34B
0005435735124	13497	154	34A
0005435043289	13497	155	34D
0005435462621	13497	156	34E
0005435735130	13497	157	34G
0005435462636	13497	158	34F
0005433529230	13497	159	34H
0005435043288	13497	160	35B
0005434265281	13497	161	35D
0005433533306	13497	162	35F
0005433529253	13497	163	35E
0005433529234	13497	164	35G
0005435766092	13497	165	36A
0005435766077	13497	166	35H
0005435462623	13497	167	36B
0005433529225	13497	168	36E
0005435766044	13497	169	36F
0005434265279	13497	170	36H
0005435765775	13497	171	36G
0005435735123	13497	172	37A
0005435462608	13497	173	37E
0005433529242	13497	174	37F
0005435462634	13497	175	37G
0005433533302	13497	176	38B
0005433533273	13497	177	38A
0005434265268	13497	178	37H
0005434831176	13497	179	38E
0005435765973	13497	180	39D
0005433529264	13497	181	38H
0005434265274	13497	182	38G
0005435725577	13497	183	39F
0005434602898	18690	1	1A
0005434602897	18690	2	3B
0005434602891	18690	3	4B
0005434604883	18683	1	1A
0005434604887	18683	2	1B
0005434604884	18683	3	2B
0005434514979	18683	4	3A
0005434604885	18683	5	3B
0005434604880	18683	6	5A
0005434514978	18683	7	5B
0005434514966	19217	1	2A
0005434514967	19217	2	4A
0005434514968	19217	3	6B
0005435846239	4118	1	1A
0005435846237	4118	2	1D
0005432649431	4118	3	1F
0005435846249	4118	4	3A
0005435844307	4118	5	3C
0005432649427	4118	6	3F
0005432632782	4118	7	4A
0005435844303	4118	8	4C
0005435846230	4118	9	4E
0005432632776	4118	10	4F
0005435844311	4118	11	5C
0005432649430	4118	12	5E
0005435846228	4118	13	5F
0005435844301	4118	14	6D
0005435846231	4118	15	7A
0005432632777	4118	16	7C
0005432632779	4118	17	8A
0005432632772	4118	18	8D
0005432632773	4118	19	8E
0005435846229	4118	20	8F
0005432632771	4118	21	9A
0005432649429	4118	22	9D
0005432649435	4118	23	9F
0005435846235	4118	24	10A
0005435844289	4118	25	10C
0005435844302	4118	26	11C
0005432632775	4118	27	11E
0005432649437	4118	28	12A
0005432632774	4118	29	12C
0005435844308	4118	30	12E
0005435846248	4118	31	13D
0005432632769	4118	32	13E
0005435846227	4118	33	13F
0005432632768	4118	34	14A
0005435844288	4118	35	14D
0005432649434	4118	36	15C
0005432649432	4118	37	15E
0005435844300	4118	38	15F
0005432632778	4118	39	16C
0005435844309	4118	40	16D
0005432632781	4118	41	16F
0005432649436	4118	42	17A
0005435846238	4118	43	17D
0005435844285	4118	44	18A
0005432649433	4118	45	18C
0005432632780	4118	46	18F
0005432632770	4118	47	19E
0005435844312	4118	48	19F
0005432649428	4118	49	20D
0005433285090	1795	1	1C
0005433008597	1795	2	1F
0005433285243	1795	3	2A
0005433285251	1795	4	2C
0005433285232	1795	5	2F
0005433008363	1795	6	2D
0005433008588	1795	7	3A
0005433810574	1795	8	3D
0005433285266	1795	9	3F
0005433008462	1795	10	4A
0005433008514	1795	11	4C
0005433008522	1795	12	4D
0005433008598	1795	13	4E
0005432295892	1795	14	4F
0005433008267	1795	15	5D
0005433285267	1795	16	5E
0005433285148	1795	17	6A
0005433008285	1795	18	6C
0005433810573	1795	19	6E
0005433008607	1795	20	6F
0005433008252	1795	21	7A
0005433285086	1795	22	7C
0005433285320	1795	23	7D
0005433008574	1795	24	7E
0005433285142	1795	25	7F
0005433008165	1795	26	8C
0005433285111	1795	27	8D
0005433810576	1795	28	9A
0005433008476	1795	29	9C
0005433285252	1795	30	9D
0005433810575	1795	31	9E
0005433285304	1795	32	9F
0005433008450	1795	33	10C
0005433008400	1795	34	10D
0005433008493	1795	35	10E
0005433008251	1795	36	10F
0005433285356	1795	37	11A
0005433008166	1795	38	11C
0005433285165	1795	39	11D
0005433285305	1795	40	11E
0005433285175	1795	41	11F
0005433285091	1795	42	12A
0005433285224	1795	43	12C
0005433285178	1795	44	12D
0005433285180	1795	45	12E
0005433285302	1795	46	12F
0005432295893	1795	47	13A
0005433285144	1795	48	13D
0005433285143	1795	49	13E
0005433008565	1795	50	13F
0005433008445	1795	51	14A
0005433285138	1795	52	14C
0005433285117	1795	53	14D
0005433285157	1795	54	14F
0005433285176	1795	55	15A
0005433285139	1795	56	15C
0005433285290	1795	57	15D
0005433008425	1795	58	15E
0005433810572	1795	59	15F
0005433008268	1795	60	16A
0005433008558	1795	61	16C
0005433008576	1795	62	16D
0005433008672	1795	63	16E
0005433285209	1795	64	16F
0005433285116	1795	65	17C
0005433285355	1795	66	17D
0005433008417	1795	67	17E
0005433008244	1795	68	18A
0005433285319	1795	69	18C
0005433810577	1795	70	18D
0005433285149	1795	71	18F
0005433285146	1795	72	19A
0005433008653	1795	73	19C
0005433008652	1795	74	19D
0005433008262	1795	75	19E
0005433008261	1795	76	19F
0005433285177	1795	77	20A
0005433285166	1795	78	20C
0005433008692	1795	79	20D
0005433008465	1795	80	20E
0005433008489	1795	81	20F
0005433008843	22525	1	1D
0005433285436	22525	2	1F
0005433008803	22525	3	2A
0005433008840	22525	4	2C
0005433008807	22525	5	2D
0005433810514	22525	6	2F
0005433008802	22525	7	3A
0005433285427	22525	8	3C
0005433008832	22525	9	3D
0005433285446	22525	10	3F
0005433285430	22525	11	4C
0005433008823	22525	12	4D
0005433008813	22525	13	4E
0005433008824	22525	14	4F
0005433008814	22525	15	5A
0005433008805	22525	16	5D
0005433008812	22525	17	5E
0005433285443	22525	18	5F
0005433285424	22525	19	6C
0005433008818	22525	20	6D
0005433285438	22525	21	6E
0005433008841	22525	22	6F
0005433008804	22525	23	7A
0005433008798	22525	24	7C
0005433285454	22525	25	7D
0005433285442	22525	26	7F
0005433008816	22525	27	8A
0005433285450	22525	28	8C
0005433285440	22525	29	8D
0005433285428	22525	30	8E
0005433008837	22525	31	8F
0005433008815	22525	32	9C
0005433008808	22525	33	9D
0005433285451	22525	34	9E
0005433008838	22525	35	9F
0005433285447	22525	36	10C
0005433008835	22525	37	10D
0005433008799	22525	38	10E
0005433008828	22525	39	11A
0005433285431	22525	40	11C
0005433285455	22525	41	11D
0005433008800	22525	42	11E
0005433008829	22525	43	11F
0005433008797	22525	44	12A
0005433008825	22525	45	12C
0005433285434	22525	46	12D
0005433008834	22525	47	12E
0005433008810	22525	48	12F
0005433008821	22525	49	13C
0005433008819	22525	50	13A
0005433008801	22525	51	13D
0005433285437	22525	52	13E
0005433285433	22525	53	13F
0005433285444	22525	54	14A
0005433008836	22525	55	14C
0005433285439	22525	56	14D
0005433285432	22525	57	14E
0005433008842	22525	58	14F
0005433008827	22525	59	15A
0005433008811	22525	60	15D
0005433285435	22525	61	15F
0005433810512	22525	62	16A
0005433285429	22525	63	16C
0005433008822	22525	64	16D
0005433008830	22525	65	16E
0005433008826	22525	66	16F
0005433008806	22525	67	17A
0005433008809	22525	68	17D
0005433285425	22525	69	17E
0005433008839	22525	70	17F
0005433008817	22525	71	18A
0005433285452	22525	72	18C
0005433285445	22525	73	18E
0005433285448	22525	74	18F
0005433285426	22525	75	19C
0005433008833	22525	76	19D
0005433008820	22525	77	19E
0005433285449	22525	78	19F
0005433285441	22525	79	20A
0005433810513	22525	80	20C
0005433285453	22525	81	20E
0005433008831	22525	82	20F
0005435282410	5549	1	1C
0005433846986	5549	2	1A
0005433847020	5549	3	1F
0005435282444	5549	4	1D
0005433846995	5549	5	2A
0005435282423	5549	6	2D
0005433847000	5549	7	2C
0005434173504	5549	8	3A
0005433846984	5549	9	2F
0005433847008	5549	10	3D
0005433847013	5549	11	3C
0005435282319	5549	12	4A
0005433847001	5549	13	3F
0005433847035	5549	14	4C
0005435282441	5549	15	4F
0005435282411	5549	16	5C
0005435282383	5549	17	5A
0005433847023	5549	18	5F
0005435282396	5549	19	5D
0005433815408	5549	20	6B
0005433846989	5549	21	6A
0005433847018	5549	22	6D
0005433847003	5549	23	6C
0005433847010	5549	24	6E
0005433846988	5549	25	7A
0005433847037	5549	26	6F
0005432081543	5549	27	7C
0005435282457	5549	28	7B
0005433847036	5549	29	7E
0005433815404	5549	30	7D
0005433846979	5549	31	8A
0005435282412	5549	32	7F
0005433846987	5549	33	8B
0005433815405	5549	34	8D
0005433847028	5549	35	8C
0005432081539	5549	36	8F
0005433847009	5549	37	8E
0005433847022	5549	38	9A
0005433846994	5549	39	9D
0005433846978	5549	40	9C
0005433846999	5549	41	9F
0005433847030	5549	42	9E
0005435282407	5549	43	10B
0005432081542	5549	44	10A
0005435282310	5549	45	10E
0005435282397	5549	46	10D
0005433847027	5549	47	11A
0005435282288	5549	48	10F
0005435282456	5549	49	11B
0005435282503	5549	50	11D
0005434173501	5549	51	11C
0005433846997	5549	52	11F
0005435282421	5549	53	11E
0005433847016	5549	54	12B
0005435282422	5549	55	12D
0005432081545	5549	56	12C
0005433847015	5549	57	12E
0005433847029	5549	58	12F
0005433847034	5549	59	13C
0005435282473	5549	60	13B
0005433846982	5549	61	13E
0005433847005	5549	62	13D
0005433846985	5549	63	14A
0005435282394	5549	64	13F
0005435282320	5549	65	14B
0005433815406	5549	66	14D
0005433846993	5549	67	14C
0005433846981	5549	68	14F
0005434173505	5549	69	14E
0005433847002	5549	70	15B
0005433847004	5549	71	15A
0005433846991	5549	72	15C
0005433846980	5549	73	15E
0005435282370	5549	74	15D
0005435282492	5549	75	16A
0005435282400	5549	76	15F
0005435282293	5549	77	16C
0005433847012	5549	78	16B
0005435282318	5549	79	16E
0005433847011	5549	80	16D
0005435282500	5549	81	16F
0005432081541	5549	82	17B
0005433847024	5549	83	17A
0005433847006	5549	84	17D
0005433846983	5549	85	17C
0005435282493	5549	86	17F
0005433846998	5549	87	17E
0005435282472	5549	88	18B
0005433815407	5549	89	18A
0005433847033	5549	90	18C
0005433847021	5549	91	18E
0005433846990	5549	92	18D
0005433847026	5549	93	19A
0005433846992	5549	94	18F
0005433847031	5549	95	19C
0005433847032	5549	96	19B
0005435282510	5549	97	19E
0005435282408	5549	98	19D
0005433847019	5549	99	20A
0005435282369	5549	100	19F
0005435282388	5549	101	20B
0005433846996	5549	102	20D
0005432081540	5549	103	20C
0005435282395	5549	104	20E
0005435282420	5549	105	21B
0005433847014	5549	106	21A
0005433847007	5549	107	20F
0005435282401	5549	108	21D
0005433847017	5549	109	21C
0005433847025	5549	110	21F
0005432081544	5549	111	21E
0005433846302	13840	1	1C
0005433846619	13840	2	1A
0005433846499	13840	3	1D
0005433846394	13840	4	2C
0005433846588	13840	5	2A
0005433846407	13840	6	2D
0005433846604	13840	7	3A
0005433846497	13840	8	2F
0005432003716	13840	9	3C
0005433846542	13840	10	3F
0005432003718	13840	11	3D
0005435282634	13840	12	4C
0005435282642	13840	13	4A
0005433846476	13840	14	4F
0005433846369	13840	15	4D
0005435282623	13840	16	5C
0005432003717	13840	17	5A
0005433846618	13840	18	5F
0005433846648	13840	19	5D
0005435282625	13840	20	6A
0005435282618	13840	21	6C
0005433846586	13840	22	6B
0005433846724	13840	23	6E
0005433846415	13840	24	6D
0005433846594	13840	25	6F
0005433846486	13840	26	7C
0005433846734	13840	27	7B
0005433846421	13840	28	7D
0005433846587	13840	29	8A
0005433846392	13840	30	7F
0005433846541	13840	31	7E
0005435282639	13840	32	8B
0005435282627	13840	33	8D
0005433846307	13840	34	8C
0005435282626	13840	35	8F
0005433846423	13840	36	8E
0005433846370	13840	37	9A
0005433846408	13840	38	9C
0005433846631	13840	39	9B
0005435282640	13840	40	9E
0005433846525	13840	41	9D
0005433846647	13840	42	10A
0005433846489	13840	43	9F
0005435282633	13840	44	10C
0005435282630	13840	45	10B
0005435282636	13840	46	10E
0005433846439	13840	47	10D
0005433846589	13840	48	10F
0005435282644	13840	49	11A
0005435282619	13840	50	11D
0005433846552	13840	51	11C
0005433846617	13840	52	12B
0005433846271	13840	53	12A
0005433846632	13840	54	12C
0005433846641	13840	55	12E
0005434173540	13840	56	12D
0005435282643	13840	57	13A
0005435282629	13840	58	12F
0005433846477	13840	59	13C
0005433846460	13840	60	13B
0005433846680	13840	61	13E
0005434173542	13840	62	13D
0005433846681	13840	63	14A
0005433846491	13840	64	13F
0005435282621	13840	65	14B
0005433846471	13840	66	14D
0005433846442	13840	67	14C
0005433846516	13840	68	15B
0005433846495	13840	69	15A
0005435282638	13840	70	15C
0005433846521	13840	71	15E
0005433846566	13840	72	15D
0005433846567	13840	73	16A
0005433846622	13840	74	15F
0005433846469	13840	75	16C
0005433846480	13840	76	16B
0005433846306	13840	77	16E
0005435282632	13840	78	16D
0005435282635	13840	79	17A
0005433846488	13840	80	16F
0005434173539	13840	81	17C
0005435282620	13840	82	17B
0005433846590	13840	83	17D
0005435282637	13840	84	17F
0005433846642	13840	85	17E
0005432003719	13840	86	18B
0005435282622	13840	87	18A
0005433846595	13840	88	18D
0005433846509	13840	89	18C
0005433846303	13840	90	18E
0005435282628	13840	91	19A
0005433846550	13840	92	18F
0005435282624	13840	93	19C
0005433846323	13840	94	19B
0005435282641	13840	95	19D
0005434173541	13840	96	19E
0005433846468	13840	97	20B
0005433846496	13840	98	20A
0005433846761	13840	99	20D
0005433846762	13840	100	20C
0005433846551	13840	101	20F
0005433846459	13840	102	21B
0005434173538	13840	103	21A
0005433846498	13840	104	21D
0005435282631	13840	105	21C
0005432003715	13840	106	21E
0005433846419	13840	107	21F
0005434620702	7807	1	1A
0005432112526	7807	2	1B
0005435332344	7807	3	1D
0005435332342	7807	4	2D
0005435332270	7807	5	3A
0005432112527	7807	6	3B
0005434620693	7807	7	3C
0005434620700	7807	8	4A
0005434620697	7807	9	4B
0005434620692	7807	10	4C
0005434620694	7807	11	4D
0005434620696	7807	12	5A
0005434620705	7807	13	5B
0005434620699	7807	14	5C
0005434620704	7807	15	5D
0005434620687	7807	16	6B
0005435332334	7807	17	6D
0005432112528	7807	18	7D
0005434620695	7807	19	18A
0005434620690	7807	20	18B
0005434620686	7807	21	18C
0005434620689	7807	22	19A
0005435332269	7807	23	19C
0005435332296	7807	24	19D
0005434620698	7807	25	20A
0005435332333	7807	26	20D
0005435332271	7807	27	21A
0005435332343	7807	28	21B
0005434620701	7807	29	22A
0005434620691	7807	30	22B
0005434620703	7807	31	22C
0005434620688	7807	32	23A
0005434620523	32984	1	1A
0005435332382	32984	2	1C
0005434620467	32984	3	1D
0005434620475	32984	4	2A
0005434620541	32984	5	2C
0005434620574	32984	6	2B
0005434620521	32984	7	2D
0005435332386	32984	8	3A
0005434620621	32984	9	3B
0005434620406	32984	10	3C
0005434620527	32984	11	3D
0005434620573	32984	12	4A
0005435332385	32984	13	5A
0005435332387	32984	14	5B
0005434620481	32984	15	5C
0005434620528	32984	16	5D
0005435332390	32984	17	6A
0005434620548	32984	18	6B
0005434620438	32984	19	6C
0005434620502	32984	20	6D
0005435332388	32984	21	7B
0005434620526	32984	22	7C
0005434620530	32984	23	7D
0005434620554	32984	24	18C
0005434620522	32984	25	18D
0005434620486	32984	26	19A
0005434620456	32984	27	19B
0005434620520	32984	28	19C
0005435332383	32984	29	19D
0005435332389	32984	30	20B
0005434620584	32984	31	20C
0005434620474	32984	32	20D
0005434620546	32984	33	21C
0005434620518	32984	34	21D
0005435332381	32984	35	22B
0005435332384	32984	36	22D
0005434620501	32984	37	23A
0005434620457	32984	38	23B
0005435785515	4310	1	1A
0005435785535	4310	2	1C
0005435785510	4310	3	1D
0005434994076	4310	4	2A
0005432190651	4310	5	2C
0005432190647	4310	6	2D
0005435785524	4310	7	3C
0005435785542	4310	8	3D
0005435785529	4310	9	3F
0005435785534	4310	10	4E
0005434994070	4310	11	4F
0005435785513	4310	12	5A
0005435785527	4310	13	5C
0005435937354	4310	14	5D
0005435918671	4310	15	5F
0005435785519	4310	16	6C
0005435785511	4310	17	6D
0005434994074	4310	18	6F
0005435785520	4310	19	7C
0005432190649	4310	20	7D
0005435785536	4310	21	7E
0005434994068	4310	22	7F
0005435785508	4310	23	8A
0005435918640	4310	24	8C
0005434994065	4310	25	8E
0005435785530	4310	26	8F
0005432190650	4310	27	9C
0005435918639	4310	28	9A
0005435937360	4310	29	9D
0005434994066	4310	30	9E
0005435785540	4310	31	9F
0005435785516	4310	32	10A
0005432190646	4310	33	10C
0005435918625	4310	34	10F
0005435785528	4310	35	11A
0005432190648	4310	36	11C
0005435785521	4310	37	11E
0005435785531	4310	38	12C
0005434994071	4310	39	12D
0005435918653	4310	40	12E
0005435787365	4310	41	12F
0005435785514	4310	42	13D
0005435785541	4310	43	13F
0005435785512	4310	44	14D
0005434994073	4310	45	14F
0005434994067	4310	46	15A
0005435785518	4310	47	15C
0005435785507	4310	48	15E
0005435785522	4310	49	16A
0005434994072	4310	50	16D
0005434994069	4310	51	16C
0005435785517	4310	52	16E
0005435785538	4310	53	17A
0005435937361	4310	54	17F
0005435785532	4310	55	18C
0005435785523	4310	56	18D
0005435785526	4310	57	18E
0005435785509	4310	58	18F
0005435785539	4310	59	19D
0005435785525	4310	60	19F
0005435937355	4310	61	20A
0005435785533	4310	62	20D
0005434994075	4310	63	20E
0005435785537	4310	64	20F
0005432195703	27331	1	1A
0005434993985	27331	2	1C
0005435785238	27331	3	1D
0005435785044	27331	4	2A
0005435785012	27331	5	2D
0005435785124	27331	6	2F
0005435785215	27331	7	3A
0005435785103	27331	8	3D
0005435785213	27331	9	4C
0005434994002	27331	10	4D
0005435785157	27331	11	4F
0005435918680	27331	12	5A
0005432195702	27331	13	5C
0005435784892	27331	14	5D
0005434993984	27331	15	5E
0005435785195	27331	16	6A
0005435785083	27331	17	6C
0005434993969	27331	18	6D
0005435785214	27331	19	6E
0005434993952	27331	20	6F
0005432195701	27331	21	7C
0005435785094	27331	22	7D
0005435785104	27331	23	7E
0005435918679	27331	24	7F
0005435785222	27331	25	8A
0005435785278	27331	26	8D
0005435785024	27331	27	8C
0005435787334	27331	28	8F
0005435785217	27331	29	9A
0005435785087	27331	30	9C
0005434994015	27331	31	9F
0005435785253	27331	32	10A
0005435785061	27331	33	10C
0005435785076	27331	34	10D
0005434993990	27331	35	10E
0005435785120	27331	36	10F
0005435785142	27331	37	11A
0005434993991	27331	38	11D
0005435787342	27331	39	11E
0005435785212	27331	40	12A
0005435785125	27331	41	12C
0005434993983	27331	42	12D
0005435785134	27331	43	12E
0005435785158	27331	44	12F
0005435785025	27331	45	13A
0005435785148	27331	46	13C
0005434994000	27331	47	13D
0005434994003	27331	48	13E
0005434993988	27331	49	14A
0005434993953	27331	50	14F
0005434994011	27331	51	15A
0005435785304	27331	52	15C
0005435785043	27331	53	15D
0005435785088	27331	54	15E
0005435785239	27331	55	15F
0005435785302	27331	56	16A
0005435785066	27331	57	16C
0005435785156	27331	58	16D
0005435918678	27331	59	16E
0005435918681	27331	60	16F
0005434993954	27331	61	17C
0005435785117	27331	62	17D
0005435785312	27331	63	17E
0005435785093	27331	64	18C
0005435785313	27331	65	18E
0005435785303	27331	66	19C
0005435785116	27331	67	19D
0005435785221	27331	68	19E
0005434993970	27331	69	19F
0005434993989	27331	70	20C
0005435785279	27331	71	20F
0005432146207	19898	1	7D
0005432146208	19898	2	19C
0005432567919	4712	1	1A
0005434082029	4712	2	1F
0005432460111	4712	3	1G
0005432567931	4712	4	2A
0005432571339	4712	5	1H
0005434082020	4712	6	2F
0005432567923	4712	7	2G
0005434082019	4712	8	3A
0005432567943	4712	9	2H
0005432567911	4712	10	3B
0005432460118	4712	11	3F
0005432567905	4712	12	3C
0005432460123	4712	13	4A
0005432460083	4712	14	3H
0005432460108	4712	15	4B
0005432460109	4712	16	4F
0005432170421	4712	17	4C
0005432460124	4712	18	4G
0005432460131	4712	19	4H
0005432567963	4712	20	5B
0005432460093	4712	21	5A
0005432186891	4712	22	5C
0005432567951	4712	23	5F
0005434082022	4712	24	9A
0005432460099	4712	25	5H
0005432460125	4712	26	9B
0005432460100	4712	27	9G
0005432186890	4712	28	11A
0005434082030	4712	29	9H
0005432567940	4712	30	11E
0005432567946	4712	31	11D
0005434082018	4712	32	11F
0005432567932	4712	33	12F
0005434082013	4712	34	12E
0005432460119	4712	35	12D
0005432567937	4712	36	13A
0005432186888	4712	37	13B
0005432460115	4712	38	13E
0005434082016	4712	39	13D
0005432571341	4712	40	13G
0005433726116	4712	41	14B
0005432571338	4712	42	14A
0005432567955	4712	43	14D
0005432567958	4712	44	14F
0005432460106	4712	45	14E
0005432460102	4712	46	14G
0005432567906	4712	47	15D
0005432460079	4712	48	15B
0005433451629	4712	49	15A
0005432567957	4712	50	15E
0005433726115	4712	51	15F
0005432567918	4712	52	15H
0005432567941	4712	53	15G
0005434082026	4712	54	16B
0005432567947	4712	55	16A
0005434082028	4712	56	16E
0005434082011	4712	57	16D
0005432567928	4712	58	16F
0005432170419	4712	59	16H
0005432567945	4712	60	17D
0005432460110	4712	61	17B
0005432567913	4712	62	17F
0005434082032	4712	63	17E
0005432460081	4712	64	17H
0005432460092	4712	65	18B
0005434082009	4712	66	18A
0005432460130	4712	67	18D
0005432460084	4712	68	18F
0005432460107	4712	69	18E
0005432567915	4712	70	18G
0005432460098	4712	71	19A
0005433726114	4712	72	18H
0005432460126	4712	73	19B
0005432567917	4712	74	19D
0005432460121	4712	75	19F
0005432460088	4712	76	19E
0005432567953	4712	77	19G
0005432567926	4712	78	19H
0005432567956	4712	79	20B
0005432567930	4712	80	20E
0005432460117	4712	81	20D
0005432460096	4712	82	20F
0005432460116	4712	83	20H
0005432460090	4712	84	20G
0005432567934	4712	85	21A
0005433451630	4712	86	21D
0005432567949	4712	87	21F
0005432460129	4712	88	21H
0005432186889	4712	89	21G
0005434082010	4712	90	22A
0005432567909	4712	91	22D
0005434082031	4712	92	22B
0005432460127	4712	93	22F
0005432567929	4712	94	22E
0005432460085	4712	95	22G
0005434082027	4712	96	22H
0005432567962	4712	97	23A
0005432460128	4712	98	23D
0005432460101	4712	99	23F
0005432460097	4712	100	24A
0005432567927	4712	101	24E
0005432567916	4712	102	24D
0005432567903	4712	103	25D
0005434082023	4712	104	24H
0005432460089	4712	105	25E
0005432567959	4712	106	27B
0005432567904	4712	107	27A
0005432460113	4712	108	27E
0005434082008	4712	109	27D
0005432567914	4712	110	27F
0005432460080	4712	111	27G
0005434082033	4712	112	27H
0005432567938	4712	113	28E
0005434082021	4712	114	28H
0005434082014	4712	115	29A
0005432567961	4712	116	29B
0005432186887	4712	117	29F
0005432460078	4712	118	29D
0005432460086	4712	119	29H
0005433451628	4712	120	30D
0005432567924	4712	121	30F
0005432460095	4712	122	31A
0005432567908	4712	123	30H
0005432567960	4712	124	31B
0005432567925	4712	125	31D
0005432567954	4712	126	31F
0005432186886	4712	127	32A
0005432460091	4712	128	32B
0005432460112	4712	129	32G
0005432567948	4712	130	32F
0005433452750	4712	131	32E
0005432567910	4712	132	33A
0005432170417	4712	133	33B
0005432170422	4712	134	33E
0005434082015	4712	135	33D
0005432567921	4712	136	33F
0005432460122	4712	137	33H
0005432567942	4712	138	33G
0005432567935	4712	139	34B
0005432460087	4712	140	34A
0005432567950	4712	141	34D
0005434082012	4712	142	34F
0005434082025	4712	143	35B
0005432170420	4712	144	35A
0005432567933	4712	145	35E
0005432567907	4712	146	35G
0005432460120	4712	147	35F
0005432571340	4712	148	35H
0005432460103	4712	149	36D
0005432567944	4712	150	36F
0005432460104	4712	151	36E
0005432567920	4712	152	36G
0005432567902	4712	153	37A
0005432460114	4712	154	36H
0005432567939	4712	155	37D
0005434082017	4712	156	37B
0005432567952	4712	157	37E
0005434082024	4712	158	37G
0005432460082	4712	159	37F
0005433452749	4712	160	37H
0005432567936	4712	161	38B
0005432170423	4712	162	38D
0005432567922	4712	163	38G
0005432460105	4712	164	38F
0005432567912	4712	165	38H
0005432170418	4712	166	39E
0005432460094	4712	167	39F
0005432567394	30517	1	1A
0005432459751	30517	2	1C
0005432567268	30517	3	1F
0005434081775	30517	4	1G
0005434081809	30517	5	2A
0005432567576	30517	6	1H
0005432567731	30517	7	2C
0005432213624	30517	8	2B
0005432459675	30517	9	2F
0005434081824	30517	10	3A
0005432567543	30517	11	3C
0005432459647	30517	12	3G
0005432459626	30517	13	3H
0005434081757	30517	14	4G
0005432161164	30517	15	4F
0005432459786	30517	16	5A
0005432567529	30517	17	5F
0005434081847	30517	18	9B
0005432459714	30517	19	9G
0005432459785	30517	20	11A
0005432567269	30517	21	9H
0005432459855	30517	22	11B
0005432459482	30517	23	11E
0005432567604	30517	24	11D
0005432567605	30517	25	11F
0005432567414	30517	26	11G
0005432459673	30517	27	12B
0005432567418	30517	28	12D
0005432567477	30517	29	12F
0005434081825	30517	30	13A
0005432459651	30517	31	13B
0005432567586	30517	32	13E
0005432567645	30517	33	13F
0005432567742	30517	34	13H
0005432567573	30517	35	14B
0005432567431	30517	36	14A
0005432459770	30517	37	14E
0005432567610	30517	38	14G
0005432459736	30517	39	15A
0005432567333	30517	40	14H
0005432571317	30517	41	15B
0005432567309	30517	42	15E
0005432459715	30517	43	15F
0005432567481	30517	44	16A
0005434081846	30517	45	16B
0005434081743	30517	46	16G
0005432567555	30517	47	16F
0005434081728	30517	48	17A
0005432567723	30517	49	17B
0005432567271	30517	50	17E
0005432567272	30517	51	17H
0005432459776	30517	52	18E
0005432459625	30517	53	18D
0005432567575	30517	54	18F
0005432571321	30517	55	18G
0005432459566	30517	56	19B
0005434081811	30517	57	19A
0005432459827	30517	58	19D
0005432567743	30517	59	19H
0005434081803	30517	60	20A
0005432567565	30517	61	20E
0005432571319	30517	62	20F
0005432567432	30517	63	21A
0005432567391	30517	64	21B
0005434081802	30517	65	21G
0005432459854	30517	66	22A
0005432567417	30517	67	22B
0005432567509	30517	68	22F
0005434081776	30517	69	22E
0005432567574	30517	70	23A
0005432213625	30517	71	23E
0005432459541	30517	72	23G
0005432567395	30517	73	23F
0005432459737	30517	74	23H
0005432459483	30517	75	24B
0005432459555	30517	76	24A
0005432567303	30517	77	24D
0005432567311	30517	78	24F
0005432567524	30517	79	24E
0005432567499	30517	80	24G
0005432567470	30517	81	25D
0005432567337	30517	82	24H
0005432459720	30517	83	25F
0005432571318	30517	84	27D
0005432571297	30517	85	27B
0005432459648	30517	86	27G
0005432460055	30517	87	28A
0005434081774	30517	88	27H
0005432459835	30517	89	28F
0005434081807	30517	90	28G
0005434081770	30517	91	29G
0005432567504	30517	92	29H
0005434081734	30517	93	30B
0005432459745	30517	94	30A
0005432459567	30517	95	30G
0005432567482	30517	96	30F
0005432459674	30517	97	30H
0005432459739	30517	98	31E
0005432567488	30517	99	31F
0005432567392	30517	100	32A
0005432459738	30517	101	31H
0005432459772	30517	102	32B
0005432567323	30517	103	32E
0005432567566	30517	104	32H
0005434081827	30517	105	33E
0005432459503	30517	106	33D
0005434081818	30517	107	33F
0005432567501	30517	108	34D
0005432567510	30517	109	34B
0005432567578	30517	110	34F
0005432459769	30517	111	34G
0005432567217	30517	112	34H
0005432567609	30517	113	35B
0005432459795	30517	114	35D
0005432459775	30517	115	36B
0005434081812	30517	116	36D
0005432459729	30517	117	36E
0005432567585	30517	118	36G
0005432571320	30517	119	36H
0005434081808	30517	120	37B
0005432213626	30517	121	37E
0005433454875	30517	122	37G
0005432567490	30517	123	37F
0005433454874	30517	124	37H
0005432567500	30517	125	38D
0005432567699	30517	126	38F
0005432567308	30517	127	38H
0005432161163	30517	128	39F
0005432567567	30517	129	39E
0005435722067	13616	1	1B
0005435720826	13616	2	3A
0005435722050	21131	1	2A
0005435722049	21131	2	3B
0005435722046	21131	3	4B
0005435722048	21131	4	6A
0005432295892	22814	1	2D
0005432295893	22814	2	6B
0005433343626	11073	1	1C
0005433343624	11073	2	1A
0005433343691	11073	3	1D
0005433343628	11073	4	1F
0005433343650	11073	5	2C
0005435097246	11073	6	2A
0005433343637	11073	7	2D
0005433343700	11073	8	2F
0005433343652	11073	9	3A
0005433343630	11073	10	3C
0005433343712	11073	11	3F
0005433343695	11073	12	4A
0005433343669	11073	13	4C
0005433343707	11073	14	4B
0005433343642	11073	15	4D
0005435508316	11073	16	4E
0005433343617	11073	17	5A
0005433343689	11073	18	4F
0005433343682	11073	19	5B
0005433343640	11073	20	5D
0005433343658	11073	21	5C
0005433343713	11073	22	5F
0005433343618	11073	23	5E
0005435508324	11073	24	6B
0005433343715	11073	25	6A
0005433343622	11073	26	6C
0005433343690	11073	27	6D
0005433343638	11073	28	6E
0005433343716	11073	29	7A
0005433343688	11073	30	6F
0005433343673	11073	31	7B
0005433343701	11073	32	7D
0005435508347	11073	33	7C
0005435380264	11073	34	7E
0005433343703	11073	35	8A
0005433343625	11073	36	7F
0005433343681	11073	37	8B
0005435097241	11073	38	8C
0005433343668	11073	39	8E
0005433343680	11073	40	8D
0005433343623	11073	41	8F
0005435508348	11073	42	9A
0005435508317	11073	43	9B
0005435097244	11073	44	9D
0005433343675	11073	45	9C
0005433343678	11073	46	9E
0005433343662	11073	47	9F
0005433343671	11073	48	10B
0005433343645	11073	49	10D
0005433343631	11073	50	10C
0005433343704	11073	51	10E
0005433343709	11073	52	11A
0005433343664	11073	53	11B
0005433343717	11073	54	11C
0005433343670	11073	55	11E
0005433343651	11073	56	11F
0005433343653	11073	57	12A
0005435097237	11073	58	12C
0005433343683	11073	59	12B
0005433343687	11073	60	12D
0005433343698	11073	61	12E
0005435380276	11073	62	12F
0005433343656	11073	63	13A
0005435508340	11073	64	13C
0005433343710	11073	65	13B
0005433343632	11073	66	13D
0005433343644	11073	67	13E
0005435508339	11073	68	14A
0005433343641	11073	69	13F
0005435097242	11073	70	14B
0005433343665	11073	71	14D
0005433343646	11073	72	14C
0005433343696	11073	73	14E
0005433343699	11073	74	14F
0005435380265	11073	75	15B
0005433343679	11073	76	15A
0005433343676	11073	77	15C
0005433343620	11073	78	15D
0005433343659	11073	79	15E
0005433343660	11073	80	16A
0005433343667	11073	81	15F
0005433343643	11073	82	16B
0005433343634	11073	83	16C
0005433343706	11073	84	16D
0005433343686	11073	85	16F
0005433343684	11073	86	16E
0005435097243	11073	87	17A
0005435508337	11073	88	17B
0005433343619	11073	89	17C
0005433343639	11073	90	17E
0005433343627	11073	91	17D
0005433343693	11073	92	17F
0005433343705	11073	93	18A
0005433343647	11073	94	18C
0005433343663	11073	95	18B
0005435380275	11073	96	18D
0005433343685	11073	97	18E
0005433343692	11073	98	18F
0005433343702	11073	99	19A
0005433343655	11073	100	19B
0005433343694	11073	101	19C
0005435508345	11073	102	19E
0005433343666	11073	103	19D
0005435097240	11073	104	19F
0005433343648	11073	105	20B
0005433343697	11073	106	20A
0005435508344	11073	107	20C
0005433343677	11073	108	20D
0005433343714	11073	109	20E
0005433343621	11073	110	20F
0005433343711	11073	111	21B
0005433343672	11073	112	21A
0005435097245	11073	113	21C
0005435097239	11073	114	21D
0005433343661	11073	115	21F
0005435508315	11073	116	21E
0005433343629	11073	117	22A
0005433343708	11073	118	22B
0005435508350	11073	119	22C
0005433343633	11073	120	22D
0005433343649	11073	121	22F
0005435097236	11073	122	22E
0005433343636	11073	123	23A
0005433343635	11073	124	23B
0005433343657	11073	125	23C
0005435097238	11073	126	23E
0005433343674	11073	127	23D
0005433343654	11073	128	23F
0005433342357	17099	1	1A
0005433342610	17099	2	1C
0005433342806	17099	3	1D
0005433342996	17099	4	1F
0005433342407	17099	5	2A
0005433342749	17099	6	2D
0005433342328	17099	7	2C
0005433342932	17099	8	2F
0005435545778	17099	9	3C
0005433342981	17099	10	3A
0005433343185	17099	11	3D
0005433342662	17099	12	3F
0005435545782	17099	13	4B
0005433342874	17099	14	4A
0005433342329	17099	15	4D
0005435380320	17099	16	4C
0005433342314	17099	17	4E
0005433343091	17099	18	4F
0005433342732	17099	19	5B
0005433343186	17099	20	5A
0005433342724	17099	21	5C
0005433342434	17099	22	5D
0005433342208	17099	23	5E
0005433342798	17099	24	5F
0005433342873	17099	25	6B
0005433342540	17099	26	6A
0005433342809	17099	27	6C
0005433342612	17099	28	6D
0005435380317	17099	29	6E
0005433342453	17099	30	7A
0005433342988	17099	31	6F
0005433342945	17099	32	7B
0005433343001	17099	33	7F
0005433342295	17099	34	7E
0005433342597	17099	35	8A
0005432293221	17099	36	8B
0005433342997	17099	37	8D
0005433342463	17099	38	8C
0005433342584	17099	39	8F
0005433342774	17099	40	8E
0005433342531	17099	41	9A
0005433342685	17099	42	9B
0005435097194	17099	43	9D
0005433342568	17099	44	9E
0005433342728	17099	45	9F
0005433342797	17099	46	10C
0005433342801	17099	47	10B
0005433343095	17099	48	10D
0005433342050	17099	49	10E
0005433342748	17099	50	11A
0005433342823	17099	51	11B
0005433342853	17099	52	11C
0005433342733	17099	53	11E
0005433342645	17099	54	11D
0005433342647	17099	55	11F
0005433342734	17099	56	12A
0005433342808	17099	57	12B
0005433342458	17099	58	12D
0005433342742	17099	59	12C
0005435097170	17099	60	12E
0005433342377	17099	61	12F
0005433342810	17099	62	13A
0005435097184	17099	63	13B
0005433342452	17099	64	13C
0005435545784	17099	65	13E
0005435545776	17099	66	13F
0005433342588	17099	67	14B
0005435380321	17099	68	14A
0005435545779	17099	69	14C
0005435545774	17099	70	14D
0005433342411	17099	71	14F
0005435545771	17099	72	14E
0005433342800	17099	73	15C
0005433342741	17099	74	15B
0005435097153	17099	75	15D
0005433342684	17099	76	15F
0005433342723	17099	77	15E
0005433342805	17099	78	16A
0005433342769	17099	79	16B
0005433342547	17099	80	16C
0005435380319	17099	81	16D
0005433342435	17099	82	16F
0005433342513	17099	83	16E
0005435097183	17099	84	17A
0005435097160	17099	85	17B
0005435097133	17099	86	17C
0005433342567	17099	87	17D
0005433342803	17099	88	17F
0005433342802	17099	89	17E
0005433342343	17099	90	18A
0005433342811	17099	91	18B
0005433342686	17099	92	18C
0005433342851	17099	93	18E
0005433342207	17099	94	18D
0005435380316	17099	95	18F
0005433342987	17099	96	19B
0005433342968	17099	97	19A
0005433342611	17099	98	19C
0005435545775	17099	99	19E
0005433342998	17099	100	19D
0005432293220	17099	101	19F
0005433342589	17099	102	20B
0005433342566	17099	103	20A
0005435545772	17099	104	20C
0005433342992	17099	105	20D
0005435545781	17099	106	20E
0005435545773	17099	107	20F
0005433342804	17099	108	21B
0005435545780	17099	109	21A
0005433342898	17099	110	21C
0005433342852	17099	111	21D
0005435545777	17099	112	21E
0005433342745	17099	113	21F
0005435380318	17099	114	22A
0005433342365	17099	115	22C
0005433342729	17099	116	22B
0005433343048	17099	117	22D
0005433342051	17099	118	22E
0005433342991	17099	119	22F
0005433342944	17099	120	23B
0005435545783	17099	121	23A
0005435097185	17099	122	23C
0005435380322	17099	123	23D
0005435545770	17099	124	23F
0005433342406	17099	125	23E
0005432919748	9071	1	1A
0005432919735	9071	2	1C
0005433507270	9071	3	1F
0005433507279	9071	4	2A
0005432919806	9071	5	2D
0005432919851	9071	6	2F
0005433507280	9071	7	3A
0005433507275	9071	8	3C
0005433507271	9071	9	3F
0005433481204	9071	10	4A
0005432919807	9071	11	4F
0005433507273	9071	12	5A
0005432919749	9071	13	5D
0005432919805	9071	14	5E
0005432919811	9071	15	5F
0005432919842	9071	16	6C
0005432919878	9071	17	7C
0005432919828	9071	18	7D
0005434158967	9071	19	7E
0005432919859	9071	20	8A
0005432919852	9071	21	8C
0005432919759	9071	22	8E
0005432919829	9071	23	9C
0005433507278	9071	24	9D
0005433507282	9071	25	9E
0005433481210	9071	26	9F
0005433507286	9071	27	10A
0005433481207	9071	28	10D
0005433507283	9071	29	10E
0005432919667	9071	30	10F
0005432919788	9071	31	11D
0005432919873	9071	32	12E
0005432919860	9071	33	13A
0005432919823	9071	34	14C
0005433507277	9071	35	14E
0005433507272	9071	36	15D
0005433507281	9071	37	15E
0005433481206	9071	38	15F
0005433507285	9071	39	16D
0005432919704	9071	40	17A
0005433507284	9071	41	17C
0005433481208	9071	42	17D
0005432919810	9071	43	18D
0005433481209	9071	44	18E
0005433507274	9071	45	19A
0005433481203	9071	46	19C
0005433507269	9071	47	19D
0005433481205	9071	48	19F
0005433507276	9071	49	20D
0005432919803	9071	50	20E
0005432919983	20492	1	1D
0005432919976	20492	2	1F
0005432919987	20492	3	2A
0005433481140	20492	4	3A
0005433507044	20492	5	3C
0005432919994	20492	6	3F
0005433481142	20492	7	4A
0005434158988	20492	8	4C
0005432919992	20492	9	4D
0005433507151	20492	10	4E
0005433481127	20492	11	4F
0005433507081	20492	12	5D
0005433507129	20492	13	5E
0005433481148	20492	14	5F
0005433507121	20492	15	6C
0005434158989	20492	16	6E
0005434158985	20492	17	6D
0005433481137	20492	18	6F
0005432919995	20492	19	7C
0005432919980	20492	20	7F
0005433507138	20492	21	8A
0005433481151	20492	22	8E
0005432919985	20492	23	8F
0005432919975	20492	24	9A
0005432919978	20492	25	10A
0005434158984	20492	26	10E
0005433481150	20492	27	10F
0005433507114	20492	28	11A
0005433507115	20492	29	11D
0005432919977	20492	30	11E
0005433507099	20492	31	11F
0005432919991	20492	32	12D
0005433481149	20492	33	12E
0005434158987	20492	34	12F
0005432919984	20492	35	13A
0005433507152	20492	36	13C
0005433507101	20492	37	13D
0005433507137	20492	38	13F
0005433507168	20492	39	14D
0005433507227	20492	40	14F
0005433507093	20492	41	15A
0005433507112	20492	42	15C
0005433507228	20492	43	15D
0005432919986	20492	44	15F
0005433507070	20492	45	16E
0005432919989	20492	46	16F
0005432919990	20492	47	17A
0005433507131	20492	48	17C
0005433481125	20492	49	17D
0005434158986	20492	50	17E
0005432919982	20492	51	17F
0005432919974	20492	52	18A
0005433481141	20492	53	18E
0005433481134	20492	54	19A
0005432919988	20492	55	19C
0005432919981	20492	56	19D
0005433481154	20492	57	19E
0005432919993	20492	58	20D
0005432919979	20492	59	20E
0005432396261	10163	1	1A
0005432396260	10163	2	2B
0005432394123	10163	3	3A
0005432396259	10163	4	5A
0005432396258	10163	5	5B
0005432394122	10163	6	6A
0005432394121	10163	7	6B
0005432396229	18388	1	1A
0005432400098	18388	2	1B
0005432396234	18388	3	2A
0005432400105	18388	4	2B
0005435179398	18388	5	3A
0005432400106	18388	6	4A
0005435179697	18388	7	5B
0005432396226	18388	8	5A
0005432400099	18388	9	6A
0005432396227	18388	10	6B
0005435126169	10946	1	1C
0005435626105	10946	2	1F
0005435626115	10946	3	2A
0005435126222	10946	4	2C
0005435554169	10946	5	2D
0005435626072	10946	6	2F
0005435126190	10946	7	3A
0005435126003	10946	8	4E
0005435126072	10946	9	4F
0005435126234	10946	10	5D
0005435554150	10946	11	6A
0005435626111	10946	12	6C
0005435554171	10946	13	6D
0005435626129	10946	14	6F
0005435126109	10946	15	7A
0005435126085	10946	16	7C
0005435126167	10946	17	7D
0005435126073	10946	18	7E
0005435626085	10946	19	7F
0005435126083	10946	20	8A
0005435126184	10946	21	8D
0005435554165	10946	22	8E
0005435126350	10946	23	8F
0005435626130	10946	24	9A
0005434411803	10946	25	9C
0005434411800	10946	26	9D
0005435556695	10946	27	9E
0005435126301	10946	28	10C
0005434411802	10946	29	10D
0005435554149	10946	30	10E
0005435125941	10946	31	10F
0005435626116	10946	32	11A
0005435626046	10946	33	11C
0005435626073	10946	34	11E
0005435126194	10946	35	11F
0005435126269	10946	36	12A
0005434411801	10946	37	12C
0005435126175	10946	38	12D
0005435626089	10946	39	12E
0005435626136	10946	40	13A
0005435126319	10946	41	13E
0005435126176	10946	42	13F
0005435554172	10946	43	14A
0005435126191	10946	44	14C
0005435554170	10946	45	14D
0005435126185	10946	46	14E
0005435626093	10946	47	14F
0005435126177	10946	48	15A
0005434411798	10946	49	15C
0005435554152	10946	50	15D
0005435126002	10946	51	15E
0005434928315	10946	52	15F
0005435126110	10946	53	16A
0005435554168	10946	54	16C
0005434928313	10946	55	16E
0005435126233	10946	56	17E
0005435554151	10946	57	17F
0005435126183	10946	58	18A
0005435554177	10946	59	18D
0005434411799	10946	60	18E
0005435626047	10946	61	18F
0005435126166	10946	62	19A
0005435626051	10946	63	19C
0005435554166	10946	64	19E
0005435126174	10946	65	19F
0005435556696	10946	66	20A
0005435626029	10946	67	20C
0005435126192	10946	68	20D
0005435626117	10946	69	20E
0005434928314	10946	70	20F
0005435554208	14735	1	1A
0005435126585	14735	2	1C
0005435126591	14735	3	1D
0005434928292	14735	4	1F
0005435126571	14735	5	2A
0005435626275	14735	6	2D
0005435126587	14735	7	2F
0005435126586	14735	8	3A
0005434411758	14735	9	3C
0005435626282	14735	10	3D
0005435556705	14735	11	3F
0005435126602	14735	12	4A
0005434411753	14735	13	4C
0005435126568	14735	14	4D
0005435626280	14735	15	4E
0005435126596	14735	16	4F
0005435626277	14735	17	5E
0005434411751	14735	18	5F
0005435626267	14735	19	6A
0005435126604	14735	20	6C
0005435126576	14735	21	6D
0005434928297	14735	22	6E
0005435126601	14735	23	7D
0005435126577	14735	24	7E
0005435554209	14735	25	7F
0005435626284	14735	26	8A
0005435626271	14735	27	8C
0005435626276	14735	28	8E
0005435126583	14735	29	8F
0005434928299	14735	30	9A
0005435626269	14735	31	9C
0005435126579	14735	32	9D
0005435126572	14735	33	9E
0005435554207	14735	34	9F
0005435554211	14735	35	10A
0005435126570	14735	36	10C
0005435126584	14735	37	10D
0005435626278	14735	38	10E
0005435126603	14735	39	10F
0005435626274	14735	40	11A
0005435126599	14735	41	11C
0005435126594	14735	42	11D
0005435126592	14735	43	11E
0005434411759	14735	44	11F
0005435626272	14735	45	12A
0005435556706	14735	46	12C
0005435126566	14735	47	12D
0005434411741	14735	48	12F
0005435626270	14735	49	13A
0005435126567	14735	50	13C
0005435126578	14735	51	13F
0005435626266	14735	52	14A
0005435126574	14735	53	14C
0005435126565	14735	54	14D
0005435626286	14735	55	14E
0005435126569	14735	56	14F
0005435126589	14735	57	15A
0005435626283	14735	58	15C
0005435126593	14735	59	15D
0005435126564	14735	60	15E
0005435126590	14735	61	16C
0005435126573	14735	62	16D
0005435126581	14735	63	16E
0005435626281	14735	64	17C
0005435126575	14735	65	17A
0005435126582	14735	66	17E
0005435626273	14735	67	17F
0005434928298	14735	68	18D
0005435126563	14735	69	18E
0005435554210	14735	70	18F
0005435126595	14735	71	19A
0005435626285	14735	72	19C
0005435626279	14735	73	19D
0005435126598	14735	74	19E
0005435126597	14735	75	19F
0005435626268	14735	76	20A
0005435126588	14735	77	20C
0005434411752	14735	78	20D
0005435126580	14735	79	20E
0005435126600	14735	80	20F
0005435443221	7143	1	1C
0005435715554	7143	2	1D
0005435221050	7143	3	2A
0005435221051	7143	4	2C
0005432400145	7143	5	3F
0005435715548	7143	6	4A
0005435715550	7143	7	4F
0005435715551	7143	8	5A
0005432400146	7143	9	5C
0005435443317	7143	10	5E
0005435715557	7143	11	5F
0005435715553	7143	12	6C
0005435443305	7143	13	6F
0005435715559	7143	14	7A
0005435178491	7143	15	7D
0005435443310	7143	16	8C
0005432398216	7143	17	8F
0005435715547	7143	18	9C
0005435715560	7143	19	9E
0005435443304	7143	20	10D
0005435715552	7143	21	11A
0005435443275	7143	22	12A
0005435715563	7143	23	12D
0005435443296	7143	24	12E
0005435715556	7143	25	12F
0005435715562	7143	26	14F
0005435443253	7143	27	15A
0005435715561	7143	28	15C
0005435715558	7143	29	15D
0005435715555	7143	30	16A
0005435443302	7143	31	16C
0005435443308	7143	32	16E
0005432398217	7143	33	16F
0005435178492	7143	34	17A
0005432400144	7143	35	17E
0005435715549	7143	36	18A
0005435443318	7143	37	18D
0005435443301	7143	38	18F
0005432398218	7143	39	19A
0005435219196	7143	40	19D
0005432400143	7143	41	19E
0005435216593	27104	1	1A
0005432394073	27104	2	1C
0005435715373	27104	3	1D
0005435216598	27104	4	1F
0005435715395	27104	5	2A
0005435216592	27104	6	3A
0005435715318	27104	7	4C
0005432394087	27104	8	4D
0005435216594	27104	9	4E
0005432394086	27104	10	5A
0005435443361	27104	11	5E
0005435217718	27104	12	5F
0005435218116	27104	13	6D
0005435218119	27104	14	6E
0005432394074	27104	15	7C
0005435443363	27104	16	7D
0005435218120	27104	17	7F
0005435443359	27104	18	8A
0005432394085	27104	19	8E
0005435216599	27104	20	9A
0005432398182	27104	21	9C
0005435217720	27104	22	9D
0005435218118	27104	23	9E
0005435715389	27104	24	10A
0005435217719	27104	25	10C
0005435715317	27104	26	11A
0005435443364	27104	27	11E
0005435443362	27104	28	11F
0005435216597	27104	29	12F
0005435715379	27104	30	13A
0005435218117	27104	31	13C
0005435217721	27104	32	13E
0005435217723	27104	33	13F
0005432398183	27104	34	14F
0005432394084	27104	35	15A
0005432394094	27104	36	15E
0005432394096	27104	37	15F
0005435715396	27104	38	16A
0005432394095	27104	39	16D
0005435443365	27104	40	16C
0005435715413	27104	41	16E
0005435443360	27104	42	16F
0005435217717	27104	43	17C
0005435443358	27104	44	17F
0005435217716	27104	45	18A
0005435216596	27104	46	18D
0005435715372	27104	47	19C
0005435216595	27104	48	19D
0005435217722	27104	49	19E
0005432398179	27104	50	20A
0005433060419	2708	1	1A
0005434084953	2708	2	1B
0005433060402	2708	3	3A
0005434084954	2708	4	2B
0005433060395	2708	5	3B
0005434084957	2708	6	5A
0005433060418	2708	7	4B
0005434084956	2708	8	5B
0005433060398	2708	9	6A
0005434084955	2708	10	6B
0005434084917	28509	1	2A
0005433060427	28509	2	2B
0005434084919	28509	3	3A
0005433060426	28509	4	4A
0005435548455	11176	1	1A
0005435548466	11176	2	1B
0005433788233	11176	3	1C
0005435548469	11176	4	2B
0005433788220	11176	5	2D
0005433788225	11176	6	3A
0005435548474	11176	7	3B
0005435548462	11176	8	4B
0005435548465	11176	9	4D
0005433788231	11176	10	5A
0005433788227	11176	11	5C
0005435548461	11176	12	5D
0005435548456	11176	13	6B
0005435548470	11176	14	6C
0005433788223	11176	15	6D
0005433788230	11176	16	7B
0005433788222	11176	17	7C
0005435548468	11176	18	7D
0005433788232	11176	19	18A
0005433788234	11176	20	18B
0005435548451	11176	21	18D
0005433788229	11176	22	19A
0005433788228	11176	23	19D
0005435548450	11176	24	20B
0005435548457	11176	25	20D
0005435548458	11176	26	21B
0005433788219	11176	27	21D
0005433788226	11176	28	22A
0005433788221	11176	29	22C
0005433788224	11176	30	23A
0005435548506	20671	1	1B
0005433788176	20671	2	2A
0005435548511	20671	3	3D
0005433788180	20671	4	4B
0005433788161	20671	5	6C
0005435548508	20671	6	6D
0005435548510	20671	7	7A
0005433788189	20671	8	7B
0005433788178	20671	9	7D
0005435548509	20671	10	18A
0005435548512	20671	11	18B
0005435548505	20671	12	18C
0005433788162	20671	13	19A
0005433788169	20671	14	19D
0005435548513	20671	15	21A
0005433788164	20671	16	21C
0005433788163	20671	17	21D
0005433788179	20671	18	22C
0005435548507	20671	19	23B
0005435517945	11394	1	1A
0005435517910	11394	2	1D
0005435517822	11394	3	2D
0005435540943	11394	4	3D
0005435540941	11394	5	4C
0005435517818	11394	6	4D
0005435517830	11394	7	5D
0005435540964	11394	8	5F
0005435517931	11394	9	6C
0005435540896	11394	10	6F
0005435517786	11394	11	7D
0005435540855	11394	12	7E
0005435540940	11394	13	8A
0005435540960	11394	14	8D
0005435517840	11394	15	9D
0005435540897	11394	16	10C
0005435517911	11394	17	10F
0005435517759	11394	18	12D
0005435540967	11394	19	13E
0005435517758	11394	20	14A
0005435517930	11394	21	14C
0005435517832	11394	22	14E
0005435517839	11394	23	15D
0005435517831	11394	24	15E
0005435517826	11394	25	16A
0005435517892	11394	26	16F
0005435517881	11394	27	17F
0005435517879	11394	28	18A
0005435540918	11394	29	18F
0005435541076	11394	30	19A
0005435540895	11394	31	19E
0005435540919	11394	32	20C
0005435540973	11394	33	20D
0005435540835	11394	34	20E
0005435541094	22234	1	1A
0005435541102	22234	2	1C
0005435529351	22234	3	2C
0005435529348	22234	4	2D
0005435541096	22234	5	3A
0005435541091	22234	6	3C
0005435541099	22234	7	3D
0005435529355	22234	8	4C
0005435541105	22234	9	4D
0005435541089	22234	10	4F
0005435529356	22234	11	5D
0005435541092	22234	12	6A
0005435541108	22234	13	7A
0005435541093	22234	14	7E
0005435529347	22234	15	7F
0005435541100	22234	16	8E
0005435529350	22234	17	8F
0005435529354	22234	18	9C
0005435529353	22234	19	9D
0005435541101	22234	20	9F
0005435529362	22234	21	10C
0005435529363	22234	22	10E
0005435541098	22234	23	11C
0005435529365	22234	24	11D
0005435529346	22234	25	12A
0005435529359	22234	26	12F
0005432294498	22234	27	13A
0005435529352	22234	28	13D
0005435529349	22234	29	14A
0005435541104	22234	30	14D
0005435541107	22234	31	14E
0005435529345	22234	32	14F
0005435529358	22234	33	15E
0005435529364	22234	34	16A
0005435541090	22234	35	16E
0005435541095	22234	36	16F
0005435529357	22234	37	17A
0005435529344	22234	38	17C
0005435541109	22234	39	17E
0005435541103	22234	40	18F
0005435541106	22234	41	19E
0005435529361	22234	42	20D
0005435541097	22234	43	20E
0005435529360	22234	44	20F
0005434907592	2314	1	1A
0005434907573	2314	2	1C
0005433251377	2314	3	1D
0005433251452	2314	4	1F
0005433251327	2314	5	2A
0005434907555	2314	6	2D
0005434907589	2314	7	3A
0005433251460	2314	8	3C
0005434907568	2314	9	3D
0005434907562	2314	10	3F
0005434907549	2314	11	4A
0005434907551	2314	12	4C
0005434907582	2314	13	4E
0005434907584	2314	14	4F
0005434907543	2314	15	5A
0005434907546	2314	16	5C
0005434907559	2314	17	5D
0005434907576	2314	18	5E
0005433400977	2314	19	6A
0005434907541	2314	20	6C
0005434907577	2314	21	6D
0005434907593	2314	22	6E
0005433251518	2314	23	6F
0005433251482	2314	24	7A
0005434907548	2314	25	7C
0005434907585	2314	26	7D
0005434907547	2314	27	7E
0005434907534	2314	28	7F
0005434907542	2314	29	8A
0005434907550	2314	30	8C
0005434907597	2314	31	8D
0005433251409	2314	32	8E
0005433251483	2314	33	9A
0005434907565	2314	34	9C
0005434907567	2314	35	9E
0005434907563	2314	36	9F
0005433251371	2314	37	10A
0005434907536	2314	38	10C
0005434907553	2314	39	10D
0005434907586	2314	40	10E
0005434907561	2314	41	10F
0005434907544	2314	42	11A
0005434907569	2314	43	11C
0005434907538	2314	44	11E
0005433251339	2314	45	11F
0005434907583	2314	46	12A
0005434907588	2314	47	12C
0005434907578	2314	48	12D
0005434907535	2314	49	12E
0005434907539	2314	50	12F
0005434907566	2314	51	13D
0005434907572	2314	52	13E
0005434907596	2314	53	13F
0005434907574	2314	54	14E
0005434907552	2314	55	14F
0005434907570	2314	56	15A
0005433251341	2314	57	15C
0005434907571	2314	58	15D
0005433251522	2314	59	15E
0005434907545	2314	60	15F
0005434907556	2314	61	16A
0005433251391	2314	62	16D
0005434907581	2314	63	16E
0005433251416	2314	64	16F
0005434907537	2314	65	17A
0005434907564	2314	66	17C
0005434907575	2314	67	17D
0005433251397	2314	68	17E
0005433400979	2314	69	17F
0005434907590	2314	70	18A
0005433251380	2314	71	18C
0005434907587	2314	72	18D
0005434907591	2314	73	18E
0005434907580	2314	74	18F
0005434907594	2314	75	19A
0005434907554	2314	76	19C
0005434907579	2314	77	19D
0005434907557	2314	78	19E
0005433251272	2314	79	19F
0005434907560	2314	80	20A
0005434907540	2314	81	20C
0005434907595	2314	82	20D
0005433251379	2314	83	20E
0005434907558	2314	84	20F
0005433251639	25586	1	1A
0005434907029	25586	2	1C
0005433251640	25586	3	1D
0005433251625	25586	4	1F
0005434907053	25586	5	2A
0005433251646	25586	6	2C
0005434907039	25586	7	2D
0005434906884	25586	8	2F
0005434906967	25586	9	3A
0005434906936	25586	10	3C
0005434907128	25586	11	3D
0005434906778	25586	12	3F
0005434907086	25586	13	4A
0005433251650	25586	14	4C
0005434906962	25586	15	4D
0005434907070	25586	16	4E
0005433251631	25586	17	4F
0005434906883	25586	18	5A
0005434907110	25586	19	5C
0005433251637	25586	20	5D
0005434906735	25586	21	5E
0005434907027	25586	22	5F
0005433251647	25586	23	6A
0005434907097	25586	24	6C
0005434907024	25586	25	6E
0005434906979	25586	26	6F
0005433251652	25586	27	7A
0005434907109	25586	28	7C
0005433251630	25586	29	7D
0005433251634	25586	30	7E
0005434907146	25586	31	7F
0005433400998	25586	32	8A
0005434907096	25586	33	8C
0005434906975	25586	34	8D
0005433251628	25586	35	8E
0005434907073	25586	36	8F
0005433251641	25586	37	9C
0005434906932	25586	38	9D
0005434906841	25586	39	9E
0005434906961	25586	40	9F
0005434906888	25586	41	10A
0005434907051	25586	42	10C
0005434907085	25586	43	10D
0005434907142	25586	44	10E
0005433251644	25586	45	10F
0005434906974	25586	46	11A
0005433251629	25586	47	11C
0005434907078	25586	48	11D
0005434907107	25586	49	11E
0005433251635	25586	50	12A
0005434906920	25586	51	12C
0005434906960	25586	52	12D
0005434906969	25586	53	13A
0005433251627	25586	54	13C
0005434907145	25586	55	13D
0005433400999	25586	56	13E
0005433251633	25586	57	13F
0005434906937	25586	58	14C
0005434907087	25586	59	14A
0005433251648	25586	60	14D
0005433251624	25586	61	14F
0005433251651	25586	62	15C
0005434907032	25586	63	15D
0005433251645	25586	64	15E
0005433251642	25586	65	15F
0005434907098	25586	66	16A
0005433251649	25586	67	16C
0005434906842	25586	68	16D
0005434907050	25586	69	16E
0005434906861	25586	70	17A
0005433251636	25586	71	17C
0005433251643	25586	72	17D
0005433401000	25586	73	17E
0005433401001	25586	74	17F
0005434906968	25586	75	18A
0005434907141	25586	76	18D
0005433251653	25586	77	18C
0005434907091	25586	78	18E
0005433251626	25586	79	18F
0005434907077	25586	80	19A
0005434907132	25586	81	19D
0005433251638	25586	82	19E
0005434907106	25586	83	19F
0005434907028	25586	84	20A
0005433251632	25586	85	20C
0005434906897	25586	86	20D
0005434907043	25586	87	20E
0005434906994	25586	88	20F
0005432621109	2536	1	1C
0005432621118	2536	2	1D
0005432621117	2536	3	2D
0005432621105	2536	4	4C
0005432621110	2536	5	4D
0005432621107	2536	6	5C
0005432621113	2536	7	6A
0005432862295	2536	8	6D
0005432862292	2536	9	18D
0005432621112	2536	10	19D
0005432621116	2536	11	20A
0005432862274	2536	12	20C
0005432621104	2536	13	20D
0005432621114	2536	14	21B
0005432862291	2536	15	21C
0005432621111	2536	16	21D
0005432621106	2536	17	22A
0005432862311	2536	18	22C
0005432621108	2536	19	23A
0005432621115	2536	20	23B
0005432862345	28046	1	2B
0005432862343	28046	2	2C
0005432621009	28046	3	3D
0005432620989	28046	4	4B
0005432862338	28046	5	4D
0005432620976	28046	6	6A
0005432620956	28046	7	7C
0005432620990	28046	8	7D
0005432862344	28046	9	18A
0005432620952	28046	10	19A
0005432862341	28046	11	19B
0005432620955	28046	12	19D
0005432862340	28046	13	20A
0005432621010	28046	14	21A
0005432862342	28046	15	21B
0005432862339	28046	16	21D
0005432620962	28046	17	22C
0005432620898	28046	18	22D
0005432620972	28046	19	23B
0005434097482	13041	1	1B
0005434097483	13041	2	5A
0005433452749	30983	1	1B
0005433452750	30983	2	3A
0005433451628	30983	3	5A
0005433451629	30983	4	5B
0005433451630	30983	5	6B
0005433454875	31401	1	2A
0005433454874	31401	2	2B
0005433129264	12023	1	1A
0005433129262	12023	2	1B
0005433134111	12023	3	4B
0005433134131	12023	4	6A
0005434142607	12023	5	6C
0005434142603	12023	6	6D
0005433129268	12023	7	18C
0005434142608	12023	8	19A
0005434142588	12023	9	19B
0005433129265	12023	10	20A
0005434142605	12023	11	20B
0005434142606	12023	12	20D
0005434142604	12023	13	22C
0005434142628	29809	1	1A
0005433134160	29809	2	1B
0005433134162	29809	3	1C
0005433131733	29809	4	2A
0005434184675	29809	5	2D
0005433134161	29809	6	3A
0005433134163	29809	7	4A
0005434326270	29809	8	4B
0005434326266	29809	9	5A
0005434326267	29809	10	5C
0005433134159	29809	11	6B
0005434142626	29809	12	6C
0005434184676	29809	13	7D
0005433131732	29809	14	18A
0005434183590	29809	15	18B
0005434326271	29809	16	18C
0005433131730	29809	17	20C
0005433131731	29809	18	20D
0005434142629	29809	19	21A
0005433131729	29809	20	22B
0005434142627	29809	21	22D
0005435798924	21301	1	1B
0005435798942	21301	2	1C
0005435798921	21301	3	2A
0005435798931	21301	4	4A
0005435798928	21301	5	4D
0005435798941	21301	6	5A
0005435798918	21301	7	5D
0005435798920	21301	8	7B
0005435798939	21301	9	18A
0005435798940	21301	10	19B
0005435798917	21301	11	19C
0005435798932	21301	12	20C
0005435798929	21301	13	22C
0005435798916	21301	14	22D
0005435697464	16467	1	3B
0005435935048	16467	2	3D
0005435697467	16467	3	4A
0005435697452	16467	4	4C
0005435697466	16467	5	4D
0005435697447	16467	6	5B
0005435697465	16467	7	5D
0005435697460	16467	8	6A
0005435697470	16467	9	6B
0005435697454	16467	10	6D
0005435697471	16467	11	7A
0005435697448	16467	12	7B
0005435697473	16467	13	7C
0005435697449	16467	14	7D
0005435697472	16467	15	18A
0005435697463	16467	16	18B
0005435697450	16467	17	18C
0005435697461	16467	18	19B
0005435697453	16467	19	19D
0005435697458	16467	20	20A
0005435697456	16467	21	20B
0005435697459	16467	22	20C
0005435697462	16467	23	20D
0005435697446	16467	24	21A
0005435697451	16467	25	21B
0005435697468	16467	26	21C
0005435697469	16467	27	21D
0005435697457	16467	28	22A
0005435697455	16467	29	22B
0005435935035	16467	30	22C
0005435697265	24714	1	1B
0005435697212	24714	2	2B
0005435697236	24714	3	2D
0005435697145	24714	4	3A
0005435697245	24714	5	3C
0005435697111	24714	6	3D
0005435935063	24714	7	4A
0005435697178	24714	8	4B
0005435697307	24714	9	4D
0005435697292	24714	10	5B
0005435697208	24714	11	5C
0005435697050	24714	12	5D
0005435697181	24714	13	6A
0005435697027	24714	14	6B
0005435697252	24714	15	6D
0005435697177	24714	16	7A
0005435697306	24714	17	7B
0005435697281	24714	18	7C
0005435697210	24714	19	7D
0005435697211	24714	20	18A
0005435697051	24714	21	19B
0005435697235	24714	22	19C
0005435697112	24714	23	19D
0005435697185	24714	24	20B
0005435935064	24714	25	20C
0005435697174	24714	26	20D
0005435935062	24714	27	21A
0005435697313	24714	28	21C
0005435697182	24714	29	21D
0005435697333	24714	30	22D
0005435697209	24714	31	23B
0005433724825	18763	1	1B
0005433724823	18763	2	2B
0005433724822	18763	3	4A
0005432968838	18763	4	5B
0005433724824	18763	5	6B
0005433724803	21604	1	1B
0005433724816	21604	2	3A
0005433724805	21604	3	2B
0005433724774	21604	4	4A
0005432968853	21604	5	4B
0005432968854	21604	6	6A
0005433724804	21604	7	6B
0005434138567	7296	1	1A
0005434138580	7296	2	1F
0005434138617	7296	3	2A
0005434138626	7296	4	2C
0005434138586	7296	5	2D
0005434138631	7296	6	2F
0005434138583	7296	7	3A
0005434138612	7296	8	3C
0005434138597	7296	9	3D
0005434138576	7296	10	4C
0005434138590	7296	11	4D
0005434138606	7296	12	4E
0005434087537	7296	13	4F
0005434087539	7296	14	5A
0005434138577	7296	15	5C
0005434138592	7296	16	5D
0005434138573	7296	17	5E
0005434138614	7296	18	5F
0005434138623	7296	19	6A
0005434138553	7296	20	6C
0005434138578	7296	21	6D
0005434138599	7296	22	6E
0005434138610	7296	23	6F
0005434138595	7296	24	7C
0005434087541	7296	25	7D
0005434138600	7296	26	7F
0005434138559	7296	27	8A
0005434138579	7296	28	8D
0005434138594	7296	29	8F
0005434138574	7296	30	9A
0005434138568	7296	31	9C
0005434138570	7296	32	9D
0005434138563	7296	33	9F
0005434138628	7296	34	10A
0005434138565	7296	35	10C
0005434138621	7296	36	10D
0005434138615	7296	37	10E
0005434138571	7296	38	11A
0005434138584	7296	39	11C
0005434138608	7296	40	11D
0005434138601	7296	41	11E
0005434138591	7296	42	12A
0005434087540	7296	43	12C
0005434138619	7296	44	12D
0005434138604	7296	45	12E
0005434138555	7296	46	12F
0005434138607	7296	47	13A
0005434138575	7296	48	13C
0005434138620	7296	49	13D
0005434138557	7296	50	13E
0005434138582	7296	51	13F
0005434138603	7296	52	14A
0005434138624	7296	53	14C
0005434138564	7296	54	14D
0005434138622	7296	55	14E
0005434138605	7296	56	14F
0005434138556	7296	57	15A
0005434087542	7296	58	15C
0005434138587	7296	59	15D
0005434138593	7296	60	15E
0005434138566	7296	61	15F
0005434138588	7296	62	16A
0005434138611	7296	63	16D
0005434138609	7296	64	16E
0005434138581	7296	65	16F
0005434138558	7296	66	17A
0005434138596	7296	67	17C
0005434138627	7296	68	17D
0005434138569	7296	69	17E
0005434138625	7296	70	17F
0005434138554	7296	71	18A
0005434138562	7296	72	18C
0005434138572	7296	73	18D
0005434138602	7296	74	18E
0005434138616	7296	75	18F
0005434138630	7296	76	19A
0005434138585	7296	77	19C
0005434138589	7296	78	19D
0005434138613	7296	79	19E
0005434087538	7296	80	19F
0005434138629	7296	81	20A
0005434138618	7296	82	20C
0005434138561	7296	83	20D
0005434138598	7296	84	20E
0005434138560	7296	85	20F
0005434137649	28537	1	1A
0005434137496	28537	2	1D
0005434137751	28537	3	1F
0005434137661	28537	4	2A
0005434137866	28537	5	2C
0005434137410	28537	6	2D
0005434137475	28537	7	2F
0005434137409	28537	8	3A
0005434137678	28537	9	3C
0005434137760	28537	10	3D
0005434137720	28537	11	3F
0005434137753	28537	12	4A
0005434137719	28537	13	4C
0005434138068	28537	14	4D
0005434137830	28537	15	4E
0005434137617	28537	16	4F
0005434137663	28537	17	5A
0005434137485	28537	18	5C
0005434137541	28537	19	5D
0005434138001	28537	20	5E
0005434137545	28537	21	5F
0005434137713	28537	22	6A
0005434137723	28537	23	6C
0005434137768	28537	24	6D
0005434137486	28537	25	6E
0005434137961	28537	26	6F
0005434137550	28537	27	7A
0005434137974	28537	28	7C
0005434137578	28537	29	7D
0005434137767	28537	30	7E
0005434137856	28537	31	7F
0005434137625	28537	32	8A
0005434137307	28537	33	8C
0005434137952	28537	34	8D
0005434137894	28537	35	8E
0005434137497	28537	36	8F
0005434137787	28537	37	9A
0005434137669	28537	38	9C
0005434137944	28537	39	9D
0005434137549	28537	40	9F
0005434137626	28537	41	9E
0005434137620	28537	42	10A
0005434137877	28537	43	10C
0005434138015	28537	44	10D
0005434087492	28537	45	10E
0005434137777	28537	46	10F
0005434137769	28537	47	11A
0005434137981	28537	48	11C
0005434137759	28537	49	11D
0005434137662	28537	50	11E
0005434137975	28537	51	11F
0005434137776	28537	52	12A
0005434137931	28537	53	12C
0005434137631	28537	54	12D
0005434137941	28537	55	12E
0005434137871	28537	56	12F
0005434137996	28537	57	13A
0005434137616	28537	58	13C
0005434137621	28537	59	13D
0005434137798	28537	60	13E
0005434137721	28537	61	13F
0005434137829	28537	62	14A
0005434137542	28537	63	14C
0005434137885	28537	64	14D
0005434137886	28537	65	14E
0005434137929	28537	66	14F
0005434137995	28537	67	15A
0005434137577	28537	68	15C
0005434137612	28537	69	15D
0005434137576	28537	70	15E
0005434137619	28537	71	15F
0005434137766	28537	72	16A
0005434137618	28537	73	16C
0005434137322	28537	74	16D
0005434137358	28537	75	16E
0005434137632	28537	76	16F
0005434137722	28537	77	17A
0005434137726	28537	78	17C
0005434137306	28537	79	17D
0005434137630	28537	80	17E
0005434137932	28537	81	17F
0005434137646	28537	82	18C
0005434137724	28537	83	18D
0005434137647	28537	84	18E
0005434137848	28537	85	18F
0005434137969	28537	86	19A
0005434137624	28537	87	19C
0005434137305	28537	88	19D
0005434087491	28537	89	19E
0005434138020	28537	90	19F
0005434138014	28537	91	20A
0005434087511	28537	92	20C
0005434137740	28537	93	20D
0005434137321	28537	94	20E
0005434137893	28537	95	20F
0005435808292	1936	1	1A
0005434610249	1936	2	1D
0005433407541	1936	3	2A
0005435808289	1936	4	2B
0005434610247	1936	5	3B
0005433407542	1936	6	3C
0005435808290	1936	7	4C
0005435808285	1936	8	4D
0005433407530	1936	9	5A
0005434610248	1936	10	5B
0005435808288	1936	11	5D
0005435808287	1936	12	6A
0005433407563	1936	13	6B
0005435808293	1936	14	6C
0005435808291	1936	15	7D
0005434610246	1936	16	18B
0005433407544	1936	17	19C
0005433407538	1936	18	19D
0005433407518	1936	19	20A
0005435808284	1936	20	20B
0005433407561	1936	21	20C
0005435808294	1936	22	20D
0005433407531	1936	23	21A
0005433407562	1936	24	21B
0005433407543	1936	25	22D
0005435808286	1936	26	23A
0005435808090	23084	1	1A
0005435808160	23084	2	1B
0005434610209	23084	3	1C
0005435808172	23084	4	1D
0005435808203	23084	5	2A
0005433407591	23084	6	2B
0005433407581	23084	7	2C
0005434610197	23084	8	3A
0005435808157	23084	9	3B
0005435808151	23084	10	3C
0005433407585	23084	11	3D
0005433407579	23084	12	4B
0005433407584	23084	13	4C
0005435808202	23084	14	4D
0005435808206	23084	15	5B
0005435808171	23084	16	5C
0005433407577	23084	17	5D
0005433407586	23084	18	6B
0005433407583	23084	19	6C
0005433407589	23084	20	6D
0005435808089	23084	21	7B
0005433407580	23084	22	7C
0005435808149	23084	23	7D
0005433407575	23084	24	18A
0005435808156	23084	25	18B
0005435808170	23084	26	18C
0005435808143	23084	27	18D
0005433407588	23084	28	19A
0005435808128	23084	29	19B
0005434610221	23084	30	19C
0005435808205	23084	31	19D
0005435808177	23084	32	20A
0005435808174	23084	33	20B
0005435808158	23084	34	20C
0005435808152	23084	35	20D
0005435808150	23084	36	21A
0005433407578	23084	37	21B
0005433407582	23084	38	21C
0005435808207	23084	39	21D
0005433407576	23084	40	22B
0005435808142	23084	41	22C
0005433407590	23084	42	22D
0005435808164	23084	43	23A
0005433407587	23084	44	23B
0005434503966	16702	1	1B
0005434503896	16702	2	1C
0005434503948	16702	3	2A
0005434503794	16702	4	2B
0005434504101	16702	5	2C
0005434504089	16702	6	3A
0005434503991	16702	7	2D
0005434504059	16702	8	3B
0005434504027	16702	9	3C
0005434503923	16702	10	3D
0005434504032	16702	11	4C
0005434504098	16702	12	4D
0005434504090	16702	13	5B
0005434504053	16702	14	6A
0005434503897	16702	15	6B
0005434503837	16702	16	6C
0005434503929	16702	17	7B
0005434503833	16702	18	7C
0005434504052	16702	19	7D
0005434504085	16702	20	18A
0005434504136	16702	21	18B
0005434503962	16702	22	18D
0005434504164	16702	23	19C
0005434504000	16702	24	20A
0005434503930	16702	25	20D
0005434504094	16702	26	21A
0005434504096	16702	27	21B
0005434504028	16702	28	21C
0005434504031	16702	29	21D
0005434503919	16702	30	22B
0005434503741	16702	31	22C
0005434503999	16702	32	22D
0005434504060	16702	33	23B
0005434504335	22925	1	1A
0005434504303	22925	2	1B
0005434504301	22925	3	1C
0005434504330	22925	4	1D
0005434504315	22925	5	2B
0005434504320	22925	6	2C
0005434504316	22925	7	2D
0005434504321	22925	8	3A
0005434504307	22925	9	3C
0005434504337	22925	10	3D
0005434504334	22925	11	4A
0005434504323	22925	12	4B
0005434504311	22925	13	4C
0005434504327	22925	14	4D
0005434504338	22925	15	5B
0005434504313	22925	16	5D
0005434504333	22925	17	6A
0005434504319	22925	18	6B
0005434504332	22925	19	6C
0005434504309	22925	20	6D
0005434504318	22925	21	7A
0005434504341	22925	22	7B
0005434504322	22925	23	7C
0005434504336	22925	24	7D
0005434504314	22925	25	18B
0005434504310	22925	26	18D
0005434504308	22925	27	19A
0005434504326	22925	28	19B
0005434504304	22925	29	19C
0005434504302	22925	30	19D
0005434504312	22925	31	20A
0005434504331	22925	32	20B
0005434504328	22925	33	20C
0005434504340	22925	34	20D
0005434504329	22925	35	21B
0005434504305	22925	36	21C
0005434504317	22925	37	21D
0005434504325	22925	38	22A
0005434504324	22925	39	22C
0005434504306	22925	40	23A
0005434504339	22925	41	23B
0005433266704	2214	1	1A
0005435078420	2214	2	2B
0005433266728	2214	3	2C
0005435078422	2214	4	3B
0005435078415	2214	5	3C
0005435078416	2214	6	3D
0005433266713	2214	7	4A
0005433266690	2214	8	5A
0005435078414	2214	9	5B
0005435078427	2214	10	5D
0005435078418	2214	11	6D
0005435078419	2214	12	7A
0005433266686	2214	13	7C
0005435078428	2214	14	18A
0005435078423	2214	15	18C
0005435078417	2214	16	18D
0005433266674	2214	17	19C
0005435078424	2214	18	20A
0005433266714	2214	19	20B
0005435078425	2214	20	20D
0005435078429	2214	21	21A
0005433266705	2214	22	21B
0005435078426	2214	23	21D
0005433266727	2214	24	22A
0005433266691	2214	25	22C
0005433266656	2214	26	22D
0005435078421	2214	27	23B
0005435078313	24335	1	1B
0005433266769	24335	2	2A
0005435078301	24335	3	2B
0005435078251	24335	4	2C
0005433266773	24335	5	3B
0005435078289	24335	6	3D
0005433266771	24335	7	4C
0005435078374	24335	8	4D
0005433266768	24335	9	5C
0005435078349	24335	10	6B
0005435078315	24335	11	6A
0005435078305	24335	12	6C
0005433266770	24335	13	7B
0005433266774	24335	14	7D
0005435078253	24335	15	18A
0005435078232	24335	16	19C
0005435078295	24335	17	19D
0005433266772	24335	18	20A
0005433266766	24335	19	20B
0005435078234	24335	20	20C
0005435078300	24335	21	21A
0005433266775	24335	22	21B
0005435078332	24335	23	21D
0005433266767	24335	24	22B
0005435078252	24335	25	22C
0005435078233	24335	26	22D
0005435078333	24335	27	23A
0005435464498	6612	1	1A
0005434988798	6612	2	1C
0005434988793	6612	3	2D
0005435464501	6612	4	3A
0005434988799	6612	5	3B
0005435464504	6612	6	3C
0005435464503	6612	7	4A
0005434988796	6612	8	4C
0005435803277	6612	9	6B
0005434988795	6612	10	7A
0005434988797	6612	11	7B
0005435464502	6612	12	18B
0005434988792	6612	13	19C
0005435803278	6612	14	20B
0005434988791	6612	15	21D
0005434988794	6612	16	22A
0005434988658	23616	1	2D
0005434988647	23616	2	3C
0005434988635	23616	3	4A
0005434988613	23616	4	4D
0005434988627	23616	5	5C
0005434988640	23616	6	5D
0005435464517	23616	7	6C
0005434988628	23616	8	7B
0005435464516	23616	9	7C
0005434988649	23616	10	7D
0005434988639	23616	11	18B
0005435803249	23616	12	19A
0005434988648	23616	13	20B
0005435803252	23616	14	21A
0005435464518	23616	15	23A
0005433450092	30491	1	1C
0005432383380	30491	2	1D
0005432383360	30491	3	2A
0005432383376	30491	4	2C
0005433453771	30491	5	3C
0005433450074	30491	6	3D
0005432383398	30491	7	3F
0005432383391	30491	8	4A
0005433454887	30491	9	4D
0005432383397	30491	10	4E
0005433450075	30491	11	5A
0005433450090	30491	12	5C
0005432383399	30491	13	5D
0005433450089	30491	14	5E
0005432383369	30491	15	5F
0005432383362	30491	16	6A
0005432383383	30491	17	7C
0005432383393	30491	18	7D
0005432383382	30491	19	7E
0005432383395	30491	20	7F
0005432383373	30491	21	8C
0005433450095	30491	22	8D
0005432383386	30491	23	9A
0005432383401	30491	24	9C
0005433450078	30491	25	9D
0005433453770	30491	26	9E
0005433450079	30491	27	9F
0005432383400	30491	28	10C
0005432383367	30491	29	10E
0005432383364	30491	30	11A
0005432383371	30491	31	11C
0005432383378	30491	32	11E
0005433450082	30491	33	11D
0005433450083	30491	34	11F
0005432383385	30491	35	12A
0005432383389	30491	36	12C
0005433450094	30491	37	12D
0005433450091	30491	38	12E
0005432383363	30491	39	12F
0005432383377	30491	40	13C
0005432383359	30491	41	13D
0005432383375	30491	42	13E
0005432383384	30491	43	14C
0005432383392	30491	44	14D
0005433450093	30491	45	14E
0005432383366	30491	46	15A
0005432383394	30491	47	15C
0005433450081	30491	48	15D
0005433450076	30491	49	16A
0005432383396	30491	50	15F
0005432383390	30491	51	16C
0005433450086	30491	52	16D
0005433450084	30491	53	16F
0005432383379	30491	54	17D
0005432383388	30491	55	17E
0005433450080	30491	56	17F
0005433450085	30491	57	18A
0005432383365	30491	58	18C
0005432383370	30491	59	18D
0005433450077	30491	60	18E
0005432383372	30491	61	18F
0005433450088	30491	62	19A
0005432383368	30491	63	19C
0005432383381	30491	64	19D
0005432383361	30491	65	19E
0005432383374	30491	66	19F
0005433450087	30491	67	20C
0005432383387	30491	68	20E
0005433449919	31318	1	1A
0005432382897	31318	2	1C
0005433453744	31318	3	2D
0005432383120	31318	4	2F
0005433449951	31318	5	3D
0005432382950	31318	6	3F
0005433449859	31318	7	4A
0005432382907	31318	8	4C
0005432382933	31318	9	4D
0005432382929	31318	10	4E
0005432382952	31318	11	4F
0005433449852	31318	12	5C
0005433449925	31318	13	5F
0005433453743	31318	14	6D
0005433449920	31318	15	6E
0005432383065	31318	16	6F
0005433449845	31318	17	7A
0005432383091	31318	18	7D
0005432382826	31318	19	8E
0005432382984	31318	20	9A
0005433449952	31318	21	9C
0005432383066	31318	22	9D
0005433451608	31318	23	9F
0005433449863	31318	24	10C
0005432382911	31318	25	10D
0005433449903	31318	26	11D
0005433449800	31318	27	11E
0005432382905	31318	28	11F
0005432382962	31318	29	12C
0005432382868	31318	30	12D
0005433449854	31318	31	12F
0005432382867	31318	32	13A
0005432382985	31318	33	13C
0005432382889	31318	34	13F
0005433449853	31318	35	14A
0005433449891	31318	36	14C
0005432382936	31318	37	14F
0005433449975	31318	38	15A
0005432382935	31318	39	15C
0005433453750	31318	40	15D
0005433449851	31318	41	15E
0005433449907	31318	42	16D
0005433449824	31318	43	17A
0005432383073	31318	44	17D
0005433449906	31318	45	17E
0005433449823	31318	46	17F
0005432382937	31318	47	18C
0005433449904	31318	48	18E
0005432382838	31318	49	18F
0005433449860	31318	50	19A
0005432382964	31318	51	19D
0005433449918	31318	52	20A
0005433449873	31318	53	20C
0005432382963	31318	54	20D
0005432382862	31318	55	20E
0005432382861	31318	56	20F
0005433126824	10800	1	1C
0005435299772	10800	2	3A
0005435304130	10800	3	3D
0005433131693	10800	4	4A
0005435304150	10800	5	4B
0005435299756	10800	6	5A
0005435299757	10800	7	18B
0005435299773	10800	8	19D
0005435299744	10800	9	20C
0005435299761	10800	10	21C
0005433126841	10800	11	22A
0005435299745	10800	12	22C
0005435302228	29713	1	1A
0005435299804	29713	2	1B
0005433129304	29713	3	1C
0005433126873	29713	4	1D
0005435302227	29713	5	2C
0005433129306	29713	6	2D
0005433129303	29713	7	3B
0005433126874	29713	8	4B
0005435299803	29713	9	6A
0005435299806	29713	10	6B
0005433129302	29713	11	6C
0005435299805	29713	12	18A
0005433129305	29713	13	19B
0005435302225	29713	14	19D
0005433129301	29713	15	20B
0005435302226	29713	16	20D
0005433126872	29713	17	22B
0005433126871	29713	18	23B
0005434287393	2418	1	1A
0005434287404	2418	2	1B
0005434287403	2418	3	1D
0005433110002	2418	4	2A
0005434287400	2418	5	2B
0005434287409	2418	6	2C
0005433110092	2418	7	3A
0005433109965	2418	8	3B
0005434287398	2418	9	3D
0005434287399	2418	10	4C
0005432264487	2418	11	5A
0005433110013	2418	12	5B
0005434287407	2418	13	5D
0005432264488	2418	14	6A
0005433109964	2418	15	6B
0005433110053	2418	16	6D
0005433110004	2418	17	7A
0005434287405	2418	18	7B
0005434287401	2418	19	7C
0005434287396	2418	20	7D
0005433110056	2418	21	18A
0005434287413	2418	22	18B
0005433110024	2418	23	19B
0005434287414	2418	24	19C
0005434287397	2418	25	19D
0005433110057	2418	26	20A
0005433110093	2418	27	20B
0005434287410	2418	28	20C
0005433110003	2418	29	20D
0005434287394	2418	30	21A
0005434287395	2418	31	21B
0005434287402	2418	32	21C
0005434287408	2418	33	22A
0005433110062	2418	34	22B
0005434287411	2418	35	22C
0005434287406	2418	36	23A
0005434287412	2418	37	23B
0005434287110	26833	1	1C
0005434287272	26833	2	1D
0005433110114	26833	3	2A
0005434287285	26833	4	2B
0005433110120	26833	5	2D
0005434287239	26833	6	2C
0005434287203	26833	7	3A
0005434287274	26833	8	3B
0005434287284	26833	9	3C
0005434287273	26833	10	4A
0005434287141	26833	11	4C
0005433110121	26833	12	5A
0005434287236	26833	13	6A
0005433110115	26833	14	6B
0005434287201	26833	15	6C
0005434287288	26833	16	6D
0005434287083	26833	17	7A
0005433110111	26833	18	7B
0005434287205	26833	19	7C
0005433110117	26833	20	18A
0005434287187	26833	21	18B
0005434287207	26833	22	18C
0005433110118	26833	23	18D
0005433110112	26833	24	19B
0005434287109	26833	25	19C
0005434287212	26833	26	19D
0005433110119	26833	27	20B
0005434287140	26833	28	20C
0005433110113	26833	29	20D
0005433110110	26833	30	21A
0005434287139	26833	31	21D
0005434287194	26833	32	22B
0005434287204	26833	33	22C
0005433110116	26833	34	22D
0005435856225	25460	1	2C
0005434269087	25460	2	3A
0005435856226	25460	3	4A
0005435856224	25460	4	5C
0005434272185	25460	5	6A
0005435856228	25460	6	7D
0005435856227	25460	7	18A
0005434272186	25460	8	18D
0005435856173	26662	1	1A
0005435854053	26662	2	3A
0005435854050	26662	3	3B
0005434272199	26662	4	4B
0005434273085	26662	5	5B
0005435856158	26662	6	5C
0005435854054	26662	7	6A
0005434273084	26662	8	18B
0005435854049	26662	9	18C
0005434272200	26662	10	21C
0005435854052	26662	11	22A
0005433868641	4808	1	1A
0005433868650	4808	2	1B
0005433868653	4808	3	1D
0005433868654	4808	4	2B
0005433868632	4808	5	2A
0005433868644	4808	6	2C
0005433868655	4808	7	2D
0005433868659	4808	8	3A
0005433868663	4808	9	3B
0005433868666	4808	10	3C
0005435860477	4808	11	3D
0005433868631	4808	12	4A
0005433868664	4808	13	4B
0005433868661	4808	14	4C
0005435860462	4808	15	5A
0005433868667	4808	16	5B
0005435860476	4808	17	5C
0005433868634	4808	18	5D
0005433868652	4808	19	6A
0005435860472	4808	20	6B
0005433868640	4808	21	6C
0005433868642	4808	22	6D
0005433868665	4808	23	7A
0005433868638	4808	24	7B
0005433868657	4808	25	7C
0005435860475	4808	26	7D
0005433868669	4808	27	18A
0005433868647	4808	28	18B
0005433868643	4808	29	18C
0005433868636	4808	30	19A
0005433868658	4808	31	19B
0005433868649	4808	32	19C
0005433868648	4808	33	19D
0005433868635	4808	34	20A
0005433868630	4808	35	20B
0005433868639	4808	36	20C
0005433868660	4808	37	20D
0005433868668	4808	38	21A
0005433868645	4808	39	21B
0005433868637	4808	40	21C
0005433868633	4808	41	21D
0005433868646	4808	42	22A
0005433868662	4808	43	22B
0005435860471	4808	44	22C
0005433868656	4808	45	23A
0005433868651	4808	46	23B
0005433868179	32583	1	1A
0005433868220	32583	2	1B
0005433868201	32583	3	1C
0005433868024	32583	4	1D
0005433868393	32583	5	2A
0005435860506	32583	6	2B
0005433868324	32583	7	2D
0005433868316	32583	8	3A
0005433868402	32583	9	3B
0005433868251	32583	10	3C
0005433868290	32583	11	3D
0005433868266	32583	12	4A
0005433868056	32583	13	4B
0005433868413	32583	14	4C
0005433868255	32583	15	4D
0005433868128	32583	16	5A
0005433868264	32583	17	5B
0005433868145	32583	18	5C
0005433868033	32583	19	5D
0005435860504	32583	20	6A
0005433868221	32583	21	6B
0005433868211	32583	22	6C
0005433868122	32583	23	6D
0005433868254	32583	24	7B
0005435860505	32583	25	7C
0005433868217	32583	26	7D
0005433868200	32583	27	18A
0005433868219	32583	28	18B
0005435860507	32583	29	18C
0005433868267	32583	30	18D
0005433868150	32583	31	19A
0005433868223	32583	32	19B
0005433868180	32583	33	19C
0005433868325	32583	34	20A
0005433868212	32583	35	20C
0005433868034	32583	36	20D
0005433868224	32583	37	21A
0005433868268	32583	38	21B
0005433868235	32583	39	21C
0005433868265	32583	40	21D
0005433868228	32583	41	22B
0005433868291	32583	42	22C
0005433868412	32583	43	22D
0005433868025	32583	44	23B
0005435911430	3410	1	1A
0005435911454	3410	2	1B
0005434663479	3410	3	2B
0005435911403	3410	4	3A
0005434663472	3410	5	3B
0005435911402	3410	6	4A
0005435911407	3410	7	4C
0005434663477	3410	8	4D
0005434663485	3410	9	5B
0005435911431	3410	10	6B
0005434461658	3410	11	6C
0005434663475	3410	12	6D
0005434663474	3410	13	7A
0005434663482	3410	14	7D
0005434663473	3410	15	18A
0005434663484	3410	16	18B
0005434461659	3410	17	18C
0005435911446	3410	18	19A
0005434663478	3410	19	19B
0005435911465	3410	20	20C
0005434663480	3410	21	21A
0005434663481	3410	22	22A
0005434461657	3410	23	22B
0005434663476	3410	24	22C
0005434663483	3410	25	22D
0005434460517	3410	26	23B
0005434663361	12495	1	1B
0005434663322	12495	2	2A
0005434663352	12495	3	2B
0005435911490	12495	4	2D
0005435911491	12495	5	4C
0005435911487	12495	6	4D
0005434663383	12495	7	5A
0005435911492	12495	8	5B
0005435911494	12495	9	5C
0005435911488	12495	10	5D
0005434663360	12495	11	7A
0005435911493	12495	12	7B
0005434663336	12495	13	21B
0005434663323	12495	14	22D
0005435911489	12495	15	23B
0005433868211	14475	1	1A
0005433868217	14475	2	1B
0005433868255	14475	3	1D
0005433868254	14475	4	1C
0005433868393	14475	5	2A
0005433868265	14475	6	2B
0005433868056	14475	7	2C
0005435860506	14475	8	2D
0005433868180	14475	9	3A
0005433868266	14475	10	3B
0005433868122	14475	11	3C
0005433868145	14475	12	4A
0005433868201	14475	13	4B
0005433868220	14475	14	4C
0005433868267	14475	15	4D
0005433868290	14475	16	5A
0005433868219	14475	17	5B
0005433868402	14475	18	5C
0005433868128	14475	19	5D
0005433868235	14475	20	6A
0005435860505	14475	21	6C
0005433868224	14475	22	6D
0005433868324	14475	23	7A
0005433868034	14475	24	7B
0005433868025	14475	25	7C
0005433868033	14475	26	7D
0005433868221	14475	27	18A
0005433868264	14475	28	18C
0005433868316	14475	29	18D
0005435860507	14475	30	19A
0005433868024	14475	31	19B
0005433868179	14475	32	19C
0005433868200	14475	33	19D
0005433868413	14475	34	20A
0005433868251	14475	35	20B
0005433868325	14475	36	20C
0005433868150	14475	37	21B
0005433868212	14475	38	21D
0005433868412	14475	39	22A
0005433868268	14475	40	22B
0005433868228	14475	41	22C
0005433868291	14475	42	22D
0005433868223	14475	43	23A
0005435860504	14475	44	23B
0005433868599	32677	1	1B
0005433868619	32677	2	1C
0005433868627	32677	3	1D
0005433868601	32677	4	2A
0005433868629	32677	5	2C
0005433868628	32677	6	3A
0005433868603	32677	7	3B
0005433868617	32677	8	3C
0005433868622	32677	9	4A
0005433868618	32677	10	4B
0005435860455	32677	11	4C
0005433868600	32677	12	5B
0005433868604	32677	13	5C
0005433868620	32677	14	5D
0005433868605	32677	15	6A
0005433868624	32677	16	6B
0005433868607	32677	17	6D
0005433868609	32677	18	7A
0005433868623	32677	19	7B
0005433868612	32677	20	7D
0005433868594	32677	21	18A
0005433868613	32677	22	18B
0005433868621	32677	23	18C
0005433868597	32677	24	18D
0005433868611	32677	25	19A
0005433868616	32677	26	19B
0005433868608	32677	27	19C
0005433868606	32677	28	20A
0005433868614	32677	29	20B
0005433868610	32677	30	20C
0005433868602	32677	31	21A
0005433868615	32677	32	21C
0005433868598	32677	33	22A
0005433868626	32677	34	22B
0005433868625	32677	35	22C
0005435860469	32677	36	22D
0005433868595	32677	37	23A
0005433868596	32677	38	23B
0005432799439	12104	1	1A
0005432799308	12104	2	1B
0005432799350	12104	3	1C
0005432799333	12104	4	2A
0005432799368	12104	5	2B
0005432799194	12104	6	2C
0005432799332	12104	7	2D
0005432799415	12104	8	3A
0005432799341	12104	9	3B
0005432799195	12104	10	3C
0005432799384	12104	11	4A
0005432799311	12104	12	4B
0005432799385	12104	13	4C
0005432799295	12104	14	4D
0005432799426	12104	15	5A
0005432799421	12104	16	5C
0005432799239	12104	17	5D
0005432799330	12104	18	6A
0005432799327	12104	19	6B
0005432799226	12104	20	6C
0005432799240	12104	21	6D
0005432799349	12104	22	7A
0005432799491	12104	23	7C
0005432799359	12104	24	7D
0005432799352	12104	25	18A
0005432799313	12104	26	18B
0005432799227	12104	27	18D
0005432799274	12104	28	19A
0005432799196	12104	29	19B
0005432799334	12104	30	19C
0005432799312	12104	31	20A
0005432799224	12104	32	20B
0005432799249	12104	33	20C
0005432799400	12104	34	20D
0005432799437	12104	35	21A
0005432799331	12104	36	21C
0005432799280	12104	37	21D
0005432799361	12104	38	22A
0005432799538	12104	39	22B
0005432799490	12104	40	22C
0005432799223	12104	41	22D
0005432799383	12104	42	23A
0005432799570	14820	1	1B
0005432799579	14820	2	2C
0005432799566	14820	3	2D
0005432799588	14820	4	3B
0005432799580	14820	5	3C
0005432799587	14820	6	4A
0005432799564	14820	7	4B
0005432799578	14820	8	4C
0005432799576	14820	9	5C
0005432799563	14820	10	5D
0005432799581	14820	11	6D
0005432799584	14820	12	7B
0005432799572	14820	13	7C
0005432799575	14820	14	18A
0005432799577	14820	15	18B
0005432799565	14820	16	18C
0005432799568	14820	17	18D
0005432799569	14820	18	19A
0005432799586	14820	19	20B
0005432799562	14820	20	20C
0005432799573	14820	21	20D
0005432799583	14820	22	21A
0005432799582	14820	23	21C
0005432799574	14820	24	22B
0005432799567	14820	25	22C
0005432799571	14820	26	22D
0005432799585	14820	27	23B
0005434408076	7089	1	1A
0005435310997	7089	2	1C
0005434408060	7089	3	1D
0005434408113	7089	4	2A
0005434299691	7089	5	1F
0005435310975	7089	6	2C
0005434408081	7089	7	2D
0005434408084	7089	8	2F
0005432108263	7089	9	3C
0005432153972	7089	10	3A
0005432153976	7089	11	3D
0005434408118	7089	12	3F
0005434408062	7089	13	4A
0005434299675	7089	14	4B
0005434408121	7089	15	4D
0005434299681	7089	16	4C
0005434408119	7089	17	4E
0005434408071	7089	18	4F
0005434299686	7089	19	5B
0005434408085	7089	20	5A
0005435311012	7089	21	5C
0005434408082	7089	22	5D
0005434299682	7089	23	5E
0005432153977	7089	24	6A
0005434408125	7089	25	5F
0005434408120	7089	26	6B
0005434299688	7089	27	6C
0005435293235	7089	28	6D
0005434408069	7089	29	6E
0005434299689	7089	30	7A
0005432153971	7089	31	6F
0005434408103	7089	32	7B
0005434299676	7089	33	7C
0005434408122	7089	34	7E
0005434408075	7089	35	7D
0005435293199	7089	36	8A
0005435311005	7089	37	7F
0005435293212	7089	38	8B
0005434408083	7089	39	8D
0005434408115	7089	40	8C
0005434408073	7089	41	8E
0005435293202	7089	42	8F
0005435310964	7089	43	9A
0005434299685	7089	44	9B
0005435293240	7089	45	9C
0005434408101	7089	46	9E
0005434408104	7089	47	9D
0005434408111	7089	48	9F
0005434408098	7089	49	10B
0005435293229	7089	50	10C
0005434408091	7089	51	10D
0005434299680	7089	52	11A
0005432153974	7089	53	10E
0005435310974	7089	54	11B
0005434408096	7089	55	11D
0005434408067	7089	56	11C
0005434299673	7089	57	11E
0005434299677	7089	58	11F
0005434408089	7089	59	12A
0005434299684	7089	60	12C
0005435293200	7089	61	12B
0005435293205	7089	62	12E
0005434299679	7089	63	12D
0005435310995	7089	64	12F
0005434299678	7089	65	13B
0005435311011	7089	66	13A
0005434299672	7089	67	13C
0005434408063	7089	68	13E
0005434408099	7089	69	13D
0005432153978	7089	70	13F
0005434408077	7089	71	14B
0005434408064	7089	72	14A
0005435311007	7089	73	14D
0005432108264	7089	74	14C
0005434299674	7089	75	14E
0005435310994	7089	76	14F
0005435311009	7089	77	15B
0005435311000	7089	78	15A
0005435311016	7089	79	15D
0005434408110	7089	80	15C
0005434408079	7089	81	15F
0005434408068	7089	82	15E
0005434408093	7089	83	16A
0005434299683	7089	84	16B
0005434408097	7089	85	16D
0005434408112	7089	86	16C
0005434408106	7089	87	16F
0005434408092	7089	88	16E
0005434408124	7089	89	17A
0005434299693	7089	90	17B
0005434408102	7089	91	17C
0005434408105	7089	92	17D
0005435293201	7089	93	17F
0005434408107	7089	94	17E
0005434408114	7089	95	18A
0005434408087	7089	96	18B
0005434408123	7089	97	18D
0005434408072	7089	98	18C
0005434408070	7089	99	18F
0005434408117	7089	100	18E
0005432153975	7089	101	19A
0005434408108	7089	102	19C
0005434408116	7089	103	19B
0005434408078	7089	104	19D
0005434408074	7089	105	19E
0005434299670	7089	106	19F
0005434408086	7089	107	20A
0005434408090	7089	108	20C
0005434408066	7089	109	20B
0005434408094	7089	110	20D
0005435293209	7089	111	20E
0005434408061	7089	112	20F
0005434299687	7089	113	21A
0005434408080	7089	114	21C
0005434408109	7089	115	21B
0005434299692	7089	116	21D
0005434408088	7089	117	21E
0005434299671	7089	118	21F
0005435310965	7089	119	22A
0005434408065	7089	120	22C
0005435293241	7089	121	22B
0005435293204	7089	122	22D
0005435310978	7089	123	22E
0005435311017	7089	124	22F
0005434408100	7089	125	23B
0005432108262	7089	126	23A
0005435293228	7089	127	23C
0005434408095	7089	128	23D
0005432153973	7089	129	23F
0005434299690	7089	130	23E
0005432058401	26909	1	1A
0005435293322	26909	2	1C
0005434299514	26909	3	1F
0005434299541	26909	4	1D
0005434407545	26909	5	2C
0005434407491	26909	6	2D
0005435311113	26909	7	2F
0005434299432	26909	8	3A
0005434299491	26909	9	3C
0005434299425	26909	10	3F
0005435311105	26909	11	4A
0005434407445	26909	12	4B
0005434407604	26909	13	4D
0005434299553	26909	14	4C
0005434407602	26909	15	4E
0005434407360	26909	16	5A
0005434407501	26909	17	4F
0005434299535	26909	18	5B
0005434407560	26909	19	5C
0005434407361	26909	20	5E
0005434407590	26909	21	5F
0005435311106	26909	22	6B
0005434407776	26909	23	6A
0005434407335	26909	24	6C
0005434407667	26909	25	6D
0005434407368	26909	26	6E
0005434407726	26909	27	7A
0005435311108	26909	28	6F
0005434407739	26909	29	7C
0005434407493	26909	30	7B
0005434407241	26909	31	7D
0005432058399	26909	32	7F
0005434299467	26909	33	7E
0005435293319	26909	34	8A
0005434299460	26909	35	8B
0005434407259	26909	36	8C
0005434299550	26909	37	8E
0005434299461	26909	38	8D
0005434299544	26909	39	8F
0005434299574	26909	40	9A
0005435293318	26909	41	9B
0005435311107	26909	42	9D
0005434407350	26909	43	9C
0005434407513	26909	44	9E
0005434407652	26909	45	10B
0005434407592	26909	46	10C
0005434407364	26909	47	10D
0005434407473	26909	48	10E
0005434407503	26909	49	11B
0005434299533	26909	50	11D
0005435311112	26909	51	11C
0005434299438	26909	52	11E
0005434407263	26909	53	11F
0005434299552	26909	54	12A
0005434407621	26909	55	12B
0005435311114	26909	56	12D
0005434407668	26909	57	12C
0005435293314	26909	58	12E
0005434407345	26909	59	12F
0005434299545	26909	60	13B
0005435293317	26909	61	13A
0005434407382	26909	62	13D
0005435311111	26909	63	13C
0005434407498	26909	64	13E
0005434407488	26909	65	13F
0005434407357	26909	66	14B
0005435311110	26909	67	14C
0005434407554	26909	68	14F
0005434407416	26909	69	14E
0005434407417	26909	70	15A
0005434299518	26909	71	15B
0005434407521	26909	72	15D
0005434407250	26909	73	15E
0005435293313	26909	74	15F
0005434407519	26909	75	16B
0005434407462	26909	76	16A
0005434407265	26909	77	16C
0005435293312	26909	78	16D
0005434407472	26909	79	16E
0005434407504	26909	80	17A
0005434299481	26909	81	16F
0005434299549	26909	82	17B
0005434407591	26909	83	17C
0005434407603	26909	84	17D
0005434407381	26909	85	17E
0005435311109	26909	86	18A
0005434407358	26909	87	18B
0005434407193	26909	88	18D
0005434407582	26909	89	18C
0005434407264	26909	90	18E
0005434407369	26909	91	18F
0005434299494	26909	92	19A
0005435293315	26909	93	19C
0005434407355	26909	94	19B
0005434407455	26909	95	19D
0005434407598	26909	96	19F
0005434299479	26909	97	20A
0005435293320	26909	98	20C
0005435293323	26909	99	20B
0005434407518	26909	100	20E
0005434407492	26909	101	20F
0005434407551	26909	102	21B
0005435293321	26909	103	21A
0005434299490	26909	104	21C
0005434407546	26909	105	21D
0005434407512	26909	106	21F
0005435293324	26909	107	21E
0005432058400	26909	108	22B
0005434407533	26909	109	22D
0005432058398	26909	110	23B
0005435293316	26909	111	23C
0005434407484	26909	112	23D
0005434407502	26909	113	23F
0005434407497	26909	114	23E
0005432604552	6429	1	1A
0005432604540	6429	2	1B
0005432604575	6429	3	1C
0005432604564	6429	4	1D
0005432604566	6429	5	2A
0005434512135	6429	6	2B
0005432604538	6429	7	2C
0005432604563	6429	8	2D
0005432604560	6429	9	3A
0005432604535	6429	10	3B
0005432604570	6429	11	3C
0005432604556	6429	12	3D
0005434512133	6429	13	4A
0005432604569	6429	14	4B
0005432604568	6429	15	4C
0005432604551	6429	16	4D
0005432604555	6429	17	5A
0005432604546	6429	18	5B
0005432604565	6429	19	5C
0005432604548	6429	20	6A
0005432604574	6429	21	6B
0005432604572	6429	22	6C
0005432604547	6429	23	6D
0005432604544	6429	24	7A
0005432604549	6429	25	7B
0005432604553	6429	26	7C
0005432604571	6429	27	7D
0005432604550	6429	28	18A
0005432604545	6429	29	18B
0005432604554	6429	30	18C
0005432604567	6429	31	19A
0005432604559	6429	32	19C
0005432604542	6429	33	19D
0005434512134	6429	34	20A
0005432604573	6429	35	20B
0005432604562	6429	36	20C
0005432604576	6429	37	20D
0005432604558	6429	38	21A
0005432604541	6429	39	21B
0005432604537	6429	40	21C
0005432604543	6429	41	21D
0005432604561	6429	42	22A
0005432604536	6429	43	22B
0005432604534	6429	44	22C
0005432604557	6429	45	22D
0005432604539	6429	46	23A
0005435221521	21392	1	1A
0005435221061	21392	2	1B
0005432604327	21392	3	1C
0005432604202	21392	4	1D
0005432603991	21392	5	2A
0005432604187	21392	6	2B
0005432604189	21392	7	2D
0005432604328	21392	8	2C
0005432604251	21392	9	3A
0005432604217	21392	10	3B
0005434512101	21392	11	3D
0005434512104	21392	12	4A
0005434512102	21392	13	4B
0005432604165	21392	14	4C
0005434512103	21392	15	4D
0005432604075	21392	16	5A
0005432604176	21392	17	5B
0005432604124	21392	18	5C
0005432604164	21392	19	5D
0005435221060	21392	20	6A
0005432604089	21392	21	6B
0005432603940	21392	22	6D
0005432604123	21392	23	7A
0005432604125	21392	24	7B
0005432604312	21392	25	7D
0005432604173	21392	26	18A
0005432604126	21392	27	18B
0005432604215	21392	28	18C
0005434512081	21392	29	19A
0005435221520	21392	30	19B
0005432604250	21392	31	19D
0005432604116	21392	32	20A
0005432604188	21392	33	20C
0005432604163	21392	34	20D
0005432604088	21392	35	21A
0005432604321	21392	36	21B
0005432604174	21392	37	21C
0005432604216	21392	38	21D
0005432604203	21392	39	22A
0005432604150	21392	40	22B
0005432604115	21392	41	22C
0005432604254	21392	42	23A
0005434512105	21392	43	22D
0005432604255	21392	44	23B
0005433251637	15000	1	1A
0005433251641	15000	2	1C
0005433251649	15000	3	1D
0005434906960	15000	4	1F
0005434907107	15000	5	2A
0005433251640	15000	6	2C
0005434907029	15000	7	2D
0005433251631	15000	8	2F
0005434907110	15000	9	3A
0005434906968	15000	10	3C
0005434907132	15000	11	3D
0005434907091	15000	12	3F
0005434907097	15000	13	4A
0005433251626	15000	14	4C
0005434907078	15000	15	4D
0005434907145	15000	16	5A
0005434906936	15000	17	5C
0005434906778	15000	18	5D
0005434907087	15000	19	5E
0005434907032	15000	20	5F
0005434907098	15000	21	6A
0005434906937	15000	22	6C
0005433251629	15000	23	6D
0005434906735	15000	24	6E
0005433251636	15000	25	6F
0005433251646	15000	26	7A
0005434906841	15000	27	7C
0005434906994	15000	28	7D
0005434906974	15000	29	7E
0005433251650	15000	30	7F
0005434907053	15000	31	8A
0005434906961	15000	32	8C
0005434906962	15000	33	8D
0005434907073	15000	34	8E
0005434907027	15000	35	8F
0005434907128	15000	36	9A
0005434907039	15000	37	9C
0005434906920	15000	38	9D
0005434906969	15000	39	9E
0005433251639	15000	40	9F
0005433251651	15000	41	10C
0005433251643	15000	42	10D
0005434907024	15000	43	10E
0005434907086	15000	44	10F
0005433251635	15000	45	11A
0005433251645	15000	46	11C
0005434907146	15000	47	11D
0005433251624	15000	48	12A
0005433251647	15000	49	12C
0005433251642	15000	50	12D
0005434906883	15000	51	13A
0005433251652	15000	52	13C
0005434906975	15000	53	13D
0005433251630	15000	54	13E
0005434907050	15000	55	13F
0005434907070	15000	56	14A
0005433251627	15000	57	14C
0005434907109	15000	58	14F
0005434907028	15000	59	15C
0005434906897	15000	60	15A
0005434907096	15000	61	15D
0005433251628	15000	62	15E
0005434906967	15000	63	15F
0005434907106	15000	64	16A
0005434906842	15000	65	16D
0005433251638	15000	66	16E
0005433251634	15000	67	16F
0005433251653	15000	68	17A
0005434907051	15000	69	17C
0005433251644	15000	70	17D
0005434907077	15000	71	17E
0005433251632	15000	72	17F
0005434906979	15000	73	18A
0005434906884	15000	74	18D
0005434907141	15000	75	18C
0005433251633	15000	76	18E
0005434907085	15000	77	18F
0005434906888	15000	78	19D
0005433251625	15000	79	19C
0005433251648	15000	80	19E
0005434906861	15000	81	19F
0005434907142	15000	82	20D
0005434907043	15000	83	20E
0005434906932	15000	84	20F
0005433251429	25869	1	1A
0005433251444	25869	2	1C
0005433251303	25869	3	1D
0005434907504	25869	4	1F
0005434907489	25869	5	2A
0005434907502	25869	6	2C
0005434907508	25869	7	2D
0005434907488	25869	8	3A
0005433251259	25869	9	3C
0005434907527	25869	10	3D
0005434907522	25869	11	3F
0005433251406	25869	12	4A
0005433251396	25869	13	4C
0005433251235	25869	14	4D
0005434907520	25869	15	4E
0005434907512	25869	16	4F
0005434907530	25869	17	5A
0005433251344	25869	18	5C
0005433251311	25869	19	5D
0005433251310	25869	20	5F
0005434907495	25869	21	6A
0005434907509	25869	22	6C
0005434907510	25869	23	6D
0005434907529	25869	24	6E
0005433251356	25869	25	6F
0005433251157	25869	26	7A
0005433251332	25869	27	7D
0005434907498	25869	28	7F
0005433251312	25869	29	8A
0005433251299	25869	30	8C
0005433251258	25869	31	8D
0005433251431	25869	32	8E
0005433251315	25869	33	8F
0005434907518	25869	34	9A
0005434907487	25869	35	9C
0005434907492	25869	36	9D
0005434907526	25869	37	9E
0005433251457	25869	38	9F
0005434907533	25869	39	10A
0005434907497	25869	40	10C
0005434907499	25869	41	10E
0005434907528	25869	42	10D
0005434907490	25869	43	10F
0005433251351	25869	44	11A
0005434907513	25869	45	11C
0005434907521	25869	46	11F
0005433251398	25869	47	12A
0005434907531	25869	48	12D
0005434907507	25869	49	12E
0005433251222	25869	50	12F
0005434907511	25869	51	13A
0005434907506	25869	52	13D
0005433251355	25869	53	13E
0005434907524	25869	54	13F
0005433251415	25869	55	14A
0005434907523	25869	56	14C
0005433251438	25869	57	14D
0005434907494	25869	58	14E
0005434907515	25869	59	14F
0005434907514	25869	60	15A
0005433251424	25869	61	15C
0005434907503	25869	62	15D
0005434907486	25869	63	15F
0005434907519	25869	64	16A
0005433251260	25869	65	16C
0005433251366	25869	66	16D
0005433251314	25869	67	16F
0005433251399	25869	68	17A
0005434907491	25869	69	17C
0005434907532	25869	70	17D
0005433251432	25869	71	17E
0005434907496	25869	72	17F
0005433251430	25869	73	18C
0005434907493	25869	74	18D
0005433251446	25869	75	18E
0005434907505	25869	76	18F
0005433251400	25869	77	19A
0005433251313	25869	78	19C
0005433251316	25869	79	19D
0005434907500	25869	80	19E
0005434907517	25869	81	19F
0005434907501	25869	82	20A
0005433251437	25869	83	20C
0005434907525	25869	84	20D
0005434907516	25869	85	20E
0005433251345	25869	86	20F
0005433008855	14179	1	1D
0005433008873	14179	2	1F
0005433008881	14179	3	2D
0005433008878	14179	4	3A
0005433008887	14179	5	3D
0005433008868	14179	6	4C
0005433008859	14179	7	4D
0005433008858	14179	8	4E
0005433008860	14179	9	4F
0005433008880	14179	10	5E
0005433008850	14179	11	5F
0005433008867	14179	12	6A
0005433008844	14179	13	6F
0005433008871	14179	14	7A
0005433008863	14179	15	8A
0005433008862	14179	16	8F
0005433008856	14179	17	9A
0005433008847	14179	18	9C
0005433008866	14179	19	10E
0005433008845	14179	20	10F
0005433008876	14179	21	11A
0005433008854	14179	22	11C
0005433008888	14179	23	11D
0005433008848	14179	24	11F
0005433008874	14179	25	12D
0005433008879	14179	26	12E
0005433008889	14179	27	13A
0005433008877	14179	28	13C
0005433008852	14179	29	14C
0005433008864	14179	30	14D
0005433008872	14179	31	14F
0005433008875	14179	32	15C
0005433008846	14179	33	15E
0005433008865	14179	34	16A
0005433810517	14179	35	16C
0005433008883	14179	36	16D
0005433008851	14179	37	16E
0005433008857	14179	38	16F
0005433008861	14179	39	17E
0005433008886	14179	40	17F
0005433008849	14179	41	19A
0005433008869	14179	42	19C
0005433008853	14179	43	19D
0005433008870	14179	44	19E
0005433008885	14179	45	20D
0005433008882	14179	46	20E
0005433008884	14179	47	20F
0005433008326	22851	1	1C
0005433008307	22851	2	1F
0005433008478	22851	3	2A
0005433008358	22851	4	2C
0005433008352	22851	5	2D
0005433008509	22851	6	3A
0005433008486	22851	7	4A
0005433008384	22851	8	4D
0005433008411	22851	9	4E
0005433008517	22851	10	4F
0005433008253	22851	11	5C
0005433008458	22851	12	5D
0005433008477	22851	13	5E
0005433008413	22851	14	5F
0005433008368	22851	15	6C
0005433008608	22851	16	6E
0005433008339	22851	17	7C
0005433008350	22851	18	7D
0005433810571	22851	19	7F
0005433008385	22851	20	8A
0005433008414	22851	21	8E
0005433008609	22851	22	8F
0005433008351	22851	23	9D
0005433008281	22851	24	9F
0005433810569	22851	25	10C
0005433008386	22851	26	10E
0005433008467	22851	27	10F
0005433008579	22851	28	11A
0005433008446	22851	29	11E
0005433008472	22851	30	12A
0005433008322	22851	31	12C
0005433008510	22851	32	12D
0005433008390	22851	33	12E
0005433008389	22851	34	13A
0005433008447	22851	35	14C
0005433008443	22851	36	14D
0005433008547	22851	37	14F
0005433008248	22851	38	15D
0005433810568	22851	39	16A
0005433810567	22851	40	16C
0005433008349	22851	41	16D
0005433008323	22851	42	16E
0005433008369	22851	43	17A
0005433008208	22851	44	17C
0005433008525	22851	45	17E
0005433008459	22851	46	17F
0005433810570	22851	47	18A
0005433008397	22851	48	18C
0005433008412	22851	49	18E
0005433008249	22851	50	19A
0005433008395	22851	51	19C
0005433008393	22851	52	19D
0005433008523	22851	53	19E
0005433008548	22851	54	20D
0005433008394	22851	55	20E
0005433008468	22851	56	20F
0005435718926	15519	1	1C
0005435718965	15519	2	1D
0005435718950	15519	3	1F
0005435718975	15519	4	2A
0005435718958	15519	5	2C
0005435718973	15519	6	3C
0005435718938	15519	7	3D
0005435718978	15519	8	4C
0005435718930	15519	9	4E
0005435718941	15519	10	4F
0005435718960	15519	11	5A
0005435718927	15519	12	5D
0005435718925	15519	13	5E
0005435718933	15519	14	5F
0005435718951	15519	15	6A
0005435718946	15519	16	6E
0005435718952	15519	17	7A
0005435718954	15519	18	7D
0005435718970	15519	19	7E
0005435718979	15519	20	7F
0005435718939	15519	21	8A
0005435718942	15519	22	8D
0005435718961	15519	23	8F
0005435718976	15519	24	9A
0005435718953	15519	25	9C
0005435718967	15519	26	10C
0005435718969	15519	27	11A
0005435718966	15519	28	11D
0005435718948	15519	29	11E
0005435718945	15519	30	11F
0005435718957	15519	31	12A
0005435718932	15519	32	12D
0005435718962	15519	33	13A
0005435718923	15519	34	13C
0005435718971	15519	35	13D
0005435718972	15519	36	13E
0005435718934	15519	37	13F
0005435718974	15519	38	14C
0005435718963	15519	39	14D
0005435718955	15519	40	14F
0005435718928	15519	41	15A
0005435718924	15519	42	15C
0005435718931	15519	43	15E
0005435718956	15519	44	16C
0005435718947	15519	45	16E
0005435718943	15519	46	16F
0005435718921	15519	47	17C
0005435718949	15519	48	17D
0005435718964	15519	49	17F
0005435718929	15519	50	18A
0005435718940	15519	51	18C
0005435718922	15519	52	18D
0005435718937	15519	53	19A
0005435718935	15519	54	19C
0005435718944	15519	55	19E
0005435718936	15519	56	20A
0005435718959	15519	57	20C
0005435718968	15519	58	20D
0005435718977	15519	59	20F
0005434925519	14913	1	1C
0005434925628	14913	2	3A
0005434925705	14913	3	4F
0005434925672	14913	4	5D
0005434925701	14913	5	5E
0005434925637	14913	6	6A
0005434925702	14913	7	6C
0005434925477	14913	8	6D
0005434925670	14913	9	6F
0005434925550	14913	10	7A
0005434925682	14913	11	7C
0005434925700	14913	12	8A
0005434925631	14913	13	8C
0005434925706	14913	14	8D
0005434925629	14913	15	9A
0005434925653	14913	16	9F
0005434925579	14913	17	10E
0005434925478	14913	18	11E
0005434925616	14913	19	11F
0005434925614	14913	20	12F
0005434925581	14913	21	13F
0005434925615	14913	22	14A
0005434925633	14913	23	14E
0005434925634	14913	24	15E
0005434925671	14913	25	15F
0005434925630	14913	26	16D
0005434925535	14913	27	16F
0005434925549	14913	28	17C
0005434925496	14913	29	18C
0005434925528	14913	30	18E
0005434925632	14913	31	18F
0005434925617	14913	32	19E
0005434925551	14913	33	20A
0005434925526	14913	34	20C
0005434925942	20553	1	2A
0005434925950	20553	2	3A
0005434925959	20553	3	3C
0005434925938	20553	4	3F
0005434925936	20553	5	4D
0005434925961	20553	6	4E
0005434925934	20553	7	4F
0005434925958	20553	8	5D
0005434925957	20553	9	5E
0005434925928	20553	10	5F
0005434925951	20553	11	6A
0005434925953	20553	12	6F
0005434925954	20553	13	7C
0005434925924	20553	14	7E
0005434925939	20553	15	8A
0005434925923	20553	16	9A
0005434925940	20553	17	9C
0005434925935	20553	18	9D
0005434925945	20553	19	10A
0005434925949	20553	20	10D
0005434925933	20553	21	10E
0005434925932	20553	22	10F
0005434925948	20553	23	11F
0005434925929	20553	24	12A
0005434925931	20553	25	13C
0005434925925	20553	26	13E
0005434925962	20553	27	13F
0005434925941	20553	28	14A
0005434925956	20553	29	14C
0005434925937	20553	30	15A
0005434925930	20553	31	16F
0005434925947	20553	32	17A
0005434925955	20553	33	17C
0005434925926	20553	34	17D
0005434925952	20553	35	17E
0005434925946	20553	36	18E
0005434925927	20553	37	18F
0005434925943	20553	38	19C
0005434925944	20553	39	20D
0005434925960	20553	40	20E
0005435487958	15847	1	1A
0005435999185	15847	2	1B
0005435487946	15847	3	1D
0005435487962	15847	4	2C
0005435487957	15847	5	2D
0005435487955	15847	6	3A
0005435487950	15847	7	3B
0005435487953	15847	8	3C
0005435487951	15847	9	3D
0005435487942	15847	10	4A
0005435999140	15847	11	4B
0005435999148	15847	12	4D
0005435487959	15847	13	5A
0005435487947	15847	14	5B
0005435999147	15847	15	5C
0005435487944	15847	16	6B
0005435487943	15847	17	6C
0005435487945	15847	18	7B
0005435487961	15847	19	7C
0005435487956	15847	20	7D
0005435999130	15847	21	18A
0005435999132	15847	22	18B
0005435999131	15847	23	19C
0005435999184	15847	24	19D
0005435487963	15847	25	20A
0005435999190	15847	26	20D
0005435487949	15847	27	20C
0005435999173	15847	28	21C
0005435487960	15847	29	21D
0005435487954	15847	30	22A
0005435487952	15847	31	22B
0005435999189	15847	32	22C
0005435999144	15847	33	22D
0005435487948	15847	34	23A
0005435487941	15847	35	23B
0005435487723	19704	1	1B
0005435487692	19704	2	1D
0005435487730	19704	3	2D
0005435999325	19704	4	3A
0005435999334	19704	5	3B
0005435999327	19704	6	3C
0005435487829	19704	7	3D
0005435999333	19704	8	4C
0005435487737	19704	9	4D
0005435999324	19704	10	5A
0005435487594	19704	11	5B
0005435999332	19704	12	5C
0005435999331	19704	13	6A
0005435487724	19704	14	6B
0005435999330	19704	15	6C
0005435999329	19704	16	6D
0005435487771	19704	17	7A
0005435487722	19704	18	7B
0005435999328	19704	19	7D
0005435487792	19704	20	18A
0005435487630	19704	21	18B
0005435487793	19704	22	18C
0005435487805	19704	23	18D
0005435999323	19704	24	19B
0005435487719	19704	25	19D
0005435487736	19704	26	20A
0005435487721	19704	27	20B
0005435487712	19704	28	20C
0005435999326	19704	29	20D
0005435487593	19704	30	21A
0005435487729	19704	31	21B
0005435487654	19704	32	21D
0005435487653	19704	33	22D
0005435839616	5977	1	1C
0005435839610	5977	2	1A
0005435472693	5977	3	1F
0005435472680	5977	4	2D
0005435839599	5977	5	3A
0005435839596	5977	6	3D
0005432660830	5977	7	3C
0005435839620	5977	8	3F
0005432658604	5977	9	4C
0005435839619	5977	10	5A
0005432142269	5977	11	5D
0005435839613	5977	12	6B
0005435472694	5977	13	7A
0005432659719	5977	14	8A
0005435839602	5977	15	7E
0005435839612	5977	16	8B
0005435839617	5977	17	8D
0005435839601	5977	18	8F
0005432658605	5977	19	9C
0005432142268	5977	20	9E
0005435839595	5977	21	10D
0005435839591	5977	22	11C
0005435472681	5977	23	11B
0005435839607	5977	24	11F
0005435839605	5977	25	11E
0005432537053	5977	26	12D
0005435472679	5977	27	12F
0005435839604	5977	28	13C
0005432658602	5977	29	13F
0005432537057	5977	30	14B
0005435839609	5977	31	14C
0005435839615	5977	32	15D
0005432658603	5977	33	16B
0005435472785	5977	34	16C
0005435839603	5977	35	17C
0005435839608	5977	36	17F
0005432660829	5977	37	18B
0005435839618	5977	38	18D
0005435472755	5977	39	18E
0005435839598	5977	40	19C
0005435472663	5977	41	19D
0005435839600	5977	42	19F
0005435839611	5977	43	20C
0005435839614	5977	44	20B
0005435839592	5977	45	20F
0005435839593	5977	46	20E
0005435839606	5977	47	21C
0005435839594	5977	48	21B
0005435839597	5977	49	21F
0005435839450	18082	1	2D
0005435472886	18082	2	3C
0005435839431	18082	3	3F
0005435839454	18082	4	4C
0005435472884	18082	5	4F
0005435839314	18082	6	5C
0005435839352	18082	7	6B
0005435839364	18082	8	6C
0005432660796	18082	9	6E
0005435839426	18082	10	7A
0005435472897	18082	11	6F
0005435839384	18082	12	7D
0005435839313	18082	13	8B
0005435472888	18082	14	8A
0005435839414	18082	15	8D
0005435839288	18082	16	8E
0005435839435	18082	17	9B
0005435472899	18082	18	9D
0005435472887	18082	19	9E
0005435839336	18082	20	10E
0005435839345	18082	21	10D
0005432664119	18082	22	10F
0005435472895	18082	23	11F
0005435472892	18082	24	12B
0005435472896	18082	25	14A
0005435472894	18082	26	13E
0005435839451	18082	27	14C
0005435839344	18082	28	15B
0005435472891	18082	29	15A
0005432664128	18082	30	15C
0005435839430	18082	31	16A
0005432660807	18082	32	15F
0005435839316	18082	33	16B
0005432667437	18082	34	16D
0005435472890	18082	35	17D
0005435839406	18082	36	18D
0005435839404	18082	37	18C
0005432667438	18082	38	18B
0005435472883	18082	39	18E
0005435839405	18082	40	19A
0005432664118	18082	41	20C
0005435472898	18082	42	20D
0005435472885	18082	43	20F
0005435472893	18082	44	20E
0005435839438	18082	45	21B
0005432537071	18082	46	21A
0005435839351	18082	47	21D
0005432667447	18082	48	21C
0005435472889	18082	49	21E
0005433285355	23026	1	1A
0005433285177	23026	2	1D
0005433285320	23026	3	4B
0005433285209	23026	4	4D
0005433285251	23026	5	5A
0005433285143	23026	6	5B
0005435103962	23026	7	5D
0005433285305	23026	8	5F
0005433285146	23026	9	6C
0005433285304	23026	10	6B
0005433285086	23026	11	6D
0005433285266	23026	12	7D
0005435103965	23026	13	8A
0005435103966	23026	14	8D
0005433285116	23026	15	9A
0005433285319	23026	16	11C
0005433285165	23026	17	12A
0005433285166	23026	18	12B
0005433285180	23026	19	13C
0005433285178	23026	20	14C
0005435103963	23026	21	14D
0005433285232	23026	22	14E
0005433285157	23026	23	15C
0005433285090	23026	24	15E
0005433285176	23026	25	16A
0005433285117	23026	26	16E
0005433285290	23026	27	17B
0005433285267	23026	28	17C
0005433285139	23026	29	17D
0005433285224	23026	30	18C
0005433285302	23026	31	18E
0005433285175	23026	32	19A
0005433285149	23026	33	19E
0005433285144	23026	34	20C
0005433285138	23026	35	20B
0005433285148	23026	36	20F
0005433285252	23026	37	21B
0005435103964	23026	38	21E
0005433285142	23026	39	22B
0005433285091	23026	40	22C
0005433285111	23026	41	22E
0005433285356	23026	42	23A
0005435103967	23026	43	23D
0005433285243	23026	44	23E
0005433285483	32077	1	1A
0005433285478	32077	2	1D
0005435103883	32077	3	1F
0005435103889	32077	4	2D
0005433285480	32077	5	2F
0005435103897	32077	6	4D
0005433285467	32077	7	4C
0005433285463	32077	8	4E
0005435103900	32077	9	4F
0005433285460	32077	10	5E
0005435103890	32077	11	6B
0005433285471	32077	12	6A
0005435103858	32077	13	7F
0005433285476	32077	14	7E
0005433285464	32077	15	8B
0005433285456	32077	16	9A
0005433285466	32077	17	9E
0005433285462	32077	18	10B
0005433285475	32077	19	10D
0005435103894	32077	20	10C
0005433285458	32077	21	12E
0005433285487	32077	22	13C
0005433285474	32077	23	14C
0005433285469	32077	24	15B
0005433285459	32077	25	15A
0005435103895	32077	26	15C
0005433285465	32077	27	15F
0005433285484	32077	28	15E
0005433285468	32077	29	16A
0005435103882	32077	30	16B
0005435103892	32077	31	16D
0005433285472	32077	32	17A
0005435103898	32077	33	16F
0005433285486	32077	34	17E
0005433285457	32077	35	18A
0005435103875	32077	36	18E
0005433285485	32077	37	18D
0005435103874	32077	38	19C
0005433285482	32077	39	19F
0005433285481	32077	40	20A
0005433285473	32077	41	20C
0005433285461	32077	42	20F
0005435103857	32077	43	22F
0005433285479	32077	44	22E
0005433285477	32077	45	23A
0005433285470	32077	46	23C
0005432892742	1475	1	1C
0005432802504	1475	2	3C
0005432802503	1475	3	4A
0005432892752	1475	4	3F
0005432892743	1475	5	4C
0005432802530	1475	6	4F
0005432892749	1475	7	5D
0005432802528	1475	8	6C
0005432892730	1475	9	6B
0005432802515	1475	10	6E
0005432802505	1475	11	7A
0005432802519	1475	12	6F
0005433112351	1475	13	7C
0005432802525	1475	14	7E
0005432802506	1475	15	7D
0005432892735	1475	16	8C
0005432892734	1475	17	8E
0005433112355	1475	18	9A
0005433112356	1475	19	9C
0005432892738	1475	20	9B
0005432802501	1475	21	9E
0005432802529	1475	22	10A
0005433112360	1475	23	10C
0005432892748	1475	24	10B
0005432802522	1475	25	11A
0005432802527	1475	26	10F
0005432802514	1475	27	10E
0005432892727	1475	28	11B
0005432802523	1475	29	11E
0005432892741	1475	30	11D
0005432802513	1475	31	11C
0005432892731	1475	32	12B
0005432892744	1475	33	12A
0005432802509	1475	34	12D
0005432802517	1475	35	13A
0005432892726	1475	36	12F
0005432802520	1475	37	13B
0005432892733	1475	38	13D
0005432892728	1475	39	14A
0005432802526	1475	40	13F
0005432892736	1475	41	14C
0005432892737	1475	42	14F
0005432802516	1475	43	14E
0005433112353	1475	44	15B
0005432892751	1475	45	15A
0005432892739	1475	46	15C
0005432802531	1475	47	15F
0005432802511	1475	48	16A
0005432892750	1475	49	16B
0005432802521	1475	50	16E
0005433112358	1475	51	16D
0005433112357	1475	52	16F
0005433112359	1475	53	17C
0005432802510	1475	54	17F
0005432892740	1475	55	17E
0005433112354	1475	56	18B
0005433112361	1475	57	18E
0005432802512	1475	58	18D
0005432802502	1475	59	19B
0005432892732	1475	60	19D
0005433112352	1475	61	20A
0005432802518	1475	62	20D
0005432802507	1475	63	20F
0005432802524	1475	64	21A
0005432802508	1475	65	21D
0005433475686	23858	1	1A
0005433475680	23858	2	1B
0005435852590	23858	3	1C
0005433475689	23858	4	2A
0005433475677	23858	5	2B
0005435852585	23858	6	2C
0005435852589	23858	7	3A
0005433475697	23858	8	3B
0005433475695	23858	9	3C
0005433475704	23858	10	4A
0005433475679	23858	11	4B
0005433475694	23858	12	4D
0005435852593	23858	13	5B
0005433475685	23858	14	6B
0005433475690	23858	15	6D
0005433475703	23858	16	7D
0005433475691	23858	17	18A
0005435852587	23858	18	18B
0005435852588	23858	19	18D
0005435852592	23858	20	19A
0005433475676	23858	21	19C
0005435852591	23858	22	20B
0005433475696	23858	23	20D
0005433475702	23858	24	21A
0005435852586	23858	25	22C
0005435852584	23858	26	23B
0005432533275	30633	1	1A
0005435213970	30633	2	1G
0005432527813	30633	3	1D
0005434067115	30633	4	1K
0005432527676	30633	5	2D
0005432527534	30633	6	2A
0005434067415	30633	7	2G
0005432527789	30633	8	2K
0005435213934	30633	9	3G
0005432527822	30633	10	3C
0005432211546	30633	11	3H
0005434067596	30633	12	4C
0005434067259	30633	13	4A
0005432528147	30633	14	4G
0005435213981	30633	15	4D
0005432159887	30633	16	4K
0005432527293	30633	17	4H
0005434067489	30633	18	5C
0005432527272	30633	19	5H
0005435213982	30633	20	5D
0005435213989	30633	21	11A
0005432527462	30633	22	11E
0005434067155	30633	23	11D
0005432535809	30633	24	11C
0005434067416	30633	25	11G
0005432527776	30633	26	11H
0005435213968	30633	27	12C
0005432535821	30633	28	12E
0005434067177	30633	29	12D
0005434067322	30633	30	12G
0005435213945	30633	31	12F
0005432527351	30633	32	13A
0005432527006	30633	33	12K
0005432527265	30633	34	12H
0005435213977	30633	35	13D
0005435213966	30633	36	13C
0005434067255	30633	37	13F
0005432159884	30633	38	13E
0005435213991	30633	39	13G
0005432535823	30633	40	14A
0005432527867	30633	41	13K
0005434067214	30633	42	14E
0005432159883	30633	43	14D
0005432527091	30633	44	14C
0005435213979	30633	45	14G
0005435213949	30633	46	14F
0005432527514	30633	47	14K
0005432527982	30633	48	14H
0005432527523	30633	49	15C
0005432527553	30633	50	15A
0005435213937	30633	51	15E
0005434067431	30633	52	15D
0005434067094	30633	53	15H
0005435213974	30633	54	15G
0005432527513	30633	55	15F
0005434067277	30633	56	16A
0005432527452	30633	57	15K
0005432527484	30633	58	16D
0005435213976	30633	59	16F
0005432527812	30633	60	16E
0005434067497	30633	61	16K
0005432527143	30633	62	16H
0005432533290	30633	63	16G
0005435213944	30633	64	17A
0005435213990	30633	65	17E
0005432527428	30633	66	17D
0005432527836	30633	67	17C
0005434067228	30633	68	17G
0005435213983	30633	69	17H
0005432527711	30633	70	18A
0005435213972	30633	71	18E
0005432528254	30633	72	18D
0005435213933	30633	73	18C
0005432527764	30633	74	18G
0005432527561	30633	75	18F
0005432527560	30633	76	18J
0005435213950	30633	77	19B
0005434067594	30633	78	18K
0005432527629	30633	79	19D
0005432527593	30633	80	19C
0005432527740	30633	81	19G
0005432527841	30633	82	19F
0005434067104	30633	83	19E
0005432527352	30633	84	19H
0005434067247	30633	85	19K
0005432535820	30633	86	19J
0005432527610	30633	87	20C
0005432527705	30633	88	20B
0005434067278	30633	89	20E
0005435213951	30633	90	20G
0005432533280	30633	91	20F
0005434067390	30633	92	20K
0005432535817	30633	93	20H
0005432527621	30633	94	21A
0005432527505	30633	95	21D
0005432527850	30633	96	21C
0005432528253	30633	97	21F
0005432527739	30633	98	21H
0005432527738	30633	99	21G
0005432527420	30633	100	21J
0005432528177	30633	101	22C
0005432527271	30633	102	22B
0005432211548	30633	103	22D
0005434067245	30633	104	22J
0005432527837	30633	105	22H
0005435725631	30633	106	23A
0005432527623	30633	107	23D
0005434067444	30633	108	23G
0005435213958	30633	109	23E
0005435213973	30633	110	23J
0005432528229	30633	111	23H
0005434067038	30633	112	23K
0005432527455	30633	113	24G
0005432527004	30633	114	25A
0005434067240	30633	115	25B
0005432527349	30633	116	25F
0005435213924	30633	117	25E
0005432527942	30633	118	25H
0005435213935	30633	119	25G
0005434067195	30633	120	25K
0005435630986	30633	121	25J
0005432527540	30633	122	26B
0005435213929	30633	123	26D
0005435213992	30633	124	26F
0005432527395	30633	125	26K
0005432527763	30633	126	26J
0005432527811	30633	127	26H
0005432527541	30633	128	27A
0005435630987	30633	129	27D
0005435213941	30633	130	27F
0005434067145	30633	131	27G
0005432527820	30633	132	28A
0005432527760	30633	133	27K
0005435213936	30633	134	28B
0005434067423	30633	135	28E
0005432527943	30633	136	28D
0005434067365	30633	137	28C
0005434067252	30633	138	28G
0005432527516	30633	139	28F
0005432527761	30633	140	28J
0005434067424	30633	141	28H
0005435213931	30633	142	29A
0005432428913	30633	143	28K
0005432527937	30633	144	29C
0005432527404	30633	145	29B
0005434067309	30633	146	29E
0005435213930	30633	147	29H
0005432159886	30633	148	29G
0005432526894	30633	149	29K
0005435213932	30633	150	30C
0005435213946	30633	151	30B
0005432211547	30633	152	30A
0005435213954	30633	153	30D
0005435213986	30633	154	30G
0005435213939	30633	155	30J
0005435725632	30633	156	30H
0005435213987	30633	157	31A
0005432527796	30633	158	30K
0005435213953	30633	159	31D
0005432528083	30633	160	31B
0005432527913	30633	161	31F
0005434067007	30633	162	31H
0005435213928	30633	163	31J
0005434067317	30633	164	32C
0005435213940	30633	165	32B
0005432527821	30633	166	32A
0005432527877	30633	167	32D
0005435213985	30633	168	32G
0005432527483	30633	169	32J
0005432527122	30633	170	32H
0005434067085	30633	171	33B
0005432527409	30633	172	33A
0005435213926	30633	173	33D
0005432527408	30633	174	33C
0005432528134	30633	175	33F
0005432527494	30633	176	33E
0005432527407	30633	177	33H
0005435213961	30633	178	33G
0005432527266	30633	179	33K
0005434067484	30633	180	34C
0005433656692	30633	181	34B
0005435213925	30633	182	34E
0005432527522	30633	183	34D
0005432428892	30633	184	34H
0005432533285	30633	185	34G
0005435213938	30633	186	35A
0005434067385	30633	187	35B
0005435630985	30633	188	35G
0005435213927	30633	189	35F
0005435213960	30633	190	35E
0005432527825	30633	191	36A
0005434067493	30633	192	36C
0005434067447	30633	193	36B
0005434067408	30633	194	36D
0005432527394	30633	195	36F
0005432527269	30633	196	36K
0005432528136	30633	197	36J
0005434067176	30633	198	37B
0005432527616	30633	199	37A
0005432527609	30633	200	37C
0005432527539	30633	201	37F
0005432527704	30633	202	37E
0005435725629	30633	203	37H
0005434067448	30633	204	37G
0005432527533	30633	205	38A
0005432535822	30633	206	37J
0005435213984	30633	207	38B
0005434067397	30633	208	39A
0005435213969	30633	209	38K
0005432527909	30633	210	39D
0005434067229	30633	211	39C
0005435213957	30633	212	39B
0005435213952	30633	213	39F
0005432527392	30633	214	39E
0005432527524	30633	215	39J
0005432211543	30633	216	39H
0005432527832	30633	217	39G
0005435213962	30633	218	39K
0005434067384	30633	219	40C
0005432527350	30633	220	40B
0005432527245	30633	221	40A
0005432211549	30633	222	40D
0005432527759	30633	223	40H
0005432527970	30633	224	40G
0005434067445	30633	225	40F
0005435213965	30633	226	40K
0005432535826	30633	227	41B
0005435213943	30633	228	41A
0005432527819	30633	229	41D
0005432528082	30633	230	41C
0005432527457	30633	231	41F
0005434067037	30633	232	41E
0005432527559	30633	233	41G
0005432535818	30633	234	42A
0005435213955	30633	235	41K
0005435213948	30633	236	42B
0005434066762	30633	237	42E
0005432527454	30633	238	42C
0005432527735	30633	239	42G
0005432527622	30633	240	42F
0005432527971	30633	241	42J
0005434067571	30633	242	42H
0005432527489	30633	243	43B
0005432527453	30633	244	43A
0005432533281	30633	245	42K
0005432527981	30633	246	43D
0005432527878	30633	247	43C
0005432428893	30633	248	43G
0005432527653	30633	249	43F
0005435213964	30633	250	43K
0005432527644	30633	251	44C
0005432527005	30633	252	44B
0005435213967	30633	253	44E
0005432211544	30633	254	44D
0005434067296	30633	255	44F
0005432527944	30633	256	44K
0005432528158	30633	257	44J
0005432527628	30633	258	44H
0005434067321	30633	259	45B
0005435213947	30633	260	45A
0005432535825	30633	261	45C
0005432527922	30633	262	45F
0005435725630	30633	263	45E
0005434067232	30633	264	45D
0005435213975	30633	265	45J
0005434067407	30633	266	45H
0005432527657	30633	267	45G
0005432527528	30633	268	45K
0005432533286	30633	269	46C
0005432527829	30633	270	46B
0005432527429	30633	271	46A
0005435213988	30633	272	46D
0005433656691	30633	273	46G
0005434067297	30633	274	46F
0005435213980	30633	275	46K
0005432527262	30633	276	46J
0005432527259	30633	277	47D
0005432527530	30633	278	47G
0005435213971	30633	279	47F
0005432159885	30633	280	47K
0005432528095	30633	281	47H
0005432528133	30633	282	48C
0005432527427	30633	283	48A
0005432528005	30633	284	48F
0005432211545	30633	285	48E
0005434067395	30633	286	48D
0005432527295	30633	287	48H
0005434067318	30633	288	48G
0005435213963	30633	289	49A
0005435213942	30633	290	48K
0005432527419	30633	291	49D
0005432533289	30633	292	49C
0005435213978	30633	293	49G
0005432527294	30633	294	49K
0005434067392	30633	295	50C
0005435213959	30633	296	50A
0005434067276	30633	297	50E
0005432527270	30633	298	50D
0005434067334	30633	299	50G
0005435725633	30633	300	50F
0005433656693	30633	301	51D
0005434067351	30633	302	50H
0005435213956	30633	303	51F
0005432527904	30633	304	51E
0005435652752	24865	1	1A
0005435652883	24865	2	1C
0005433368129	24865	3	1D
0005433368137	24865	4	1F
0005433368126	24865	5	2A
0005435652874	24865	6	2D
0005435652983	24865	7	2F
0005435652973	24865	8	3A
0005433368104	24865	9	3C
0005433368118	24865	10	3D
0005435652594	24865	11	3F
0005433368110	24865	12	4A
0005435652964	24865	13	4C
0005433368116	24865	14	4D
0005435652971	24865	15	4E
0005435652951	24865	16	4F
0005435652960	24865	17	5A
0005433368130	24865	18	5C
0005435652873	24865	19	5D
0005435652884	24865	20	5E
0005435652929	24865	21	6A
0005433368124	24865	22	5F
0005435652861	24865	23	6C
0005435652968	24865	24	6D
0005433368114	24865	25	6E
0005433368103	24865	26	6F
0005435652916	24865	27	7A
0005433368132	24865	28	7C
0005433368115	24865	29	7D
0005435652871	24865	30	7E
0005433368122	24865	31	8A
0005435652838	24865	32	8C
0005435652857	24865	33	8D
0005433368139	24865	34	8F
0005435652946	24865	35	9A
0005433368121	24865	36	9C
0005433368120	24865	37	9D
0005435652875	24865	38	9E
0005433368113	24865	39	9F
0005435652693	24865	40	10A
0005433368138	24865	41	10C
0005435652900	24865	42	10E
0005433368134	24865	43	11A
0005435652970	24865	44	11C
0005433368128	24865	45	11D
0005435652921	24865	46	11E
0005433368108	24865	47	11F
0005435652753	24865	48	12A
0005435652978	24865	49	12C
0005435652950	24865	50	12D
0005435652942	24865	51	12E
0005435652757	24865	52	12F
0005435652949	24865	53	13C
0005433368106	24865	54	13D
0005433368125	24865	55	13E
0005435652799	24865	56	13F
0005433368136	24865	57	14C
0005433368135	24865	58	14D
0005435652979	24865	59	14E
0005435652798	24865	60	14F
0005433368131	24865	61	15A
0005435652980	24865	62	15C
0005435652927	24865	63	15E
0005435652928	24865	64	15F
0005435652767	24865	65	16A
0005433368111	24865	66	16D
0005433368117	24865	67	16E
0005435652987	24865	68	16F
0005435652870	24865	69	17A
0005435652890	24865	70	17C
0005435652977	24865	71	17D
0005435652879	24865	72	17E
0005435652969	24865	73	17F
0005435652915	24865	74	18A
0005433368123	24865	75	18C
0005433368112	24865	76	18D
0005433368107	24865	77	18E
0005433368109	24865	78	18F
0005435652858	24865	79	19A
0005435652954	24865	80	19C
0005435652877	24865	81	19D
0005433368127	24865	82	19E
0005433368119	24865	83	19F
0005433368133	24865	84	20A
0005435652876	24865	85	20C
0005435652899	24865	86	20D
0005433368105	24865	87	20E
0005435652593	24865	88	20F
0005434979971	2070	1	1A
0005434979973	2070	2	1D
0005434979974	2070	3	2A
0005434979979	2070	4	2B
0005434979981	2070	5	2C
0005435801714	2070	6	2D
0005434979964	2070	7	3B
0005434979967	2070	8	3C
0005434979987	2070	9	4A
0005434979963	2070	10	5A
0005434979978	2070	11	5B
0005434979980	2070	12	6A
0005434979970	2070	13	6B
0005434979972	2070	14	6C
0005434979988	2070	15	6D
0005434979989	2070	16	7A
0005434979982	2070	17	7C
0005434979977	2070	18	7D
0005434979984	2070	19	18B
0005434979961	2070	20	18C
0005434979968	2070	21	18D
0005434979985	2070	22	19A
0005434979990	2070	23	19B
0005434979962	2070	24	19C
0005434979986	2070	25	20A
0005434979966	2070	26	20D
0005434979976	2070	27	21A
0005435801715	2070	28	21B
0005434979983	2070	29	21C
0005434979960	2070	30	22A
0005434979975	2070	31	22B
0005434979965	2070	32	23A
0005434979969	2070	33	23B
0005434979663	23533	1	1A
0005434979628	23533	2	1B
0005434979848	23533	3	1D
0005434979692	23533	4	2B
0005435801686	23533	5	2C
0005434979674	23533	6	2D
0005434979600	23533	7	3A
0005434979758	23533	8	3B
0005434979843	23533	9	3D
0005434979659	23533	10	4A
0005434979627	23533	11	4C
0005434979632	23533	12	4D
0005435801681	23533	13	5C
0005434979675	23533	14	5D
0005434979633	23533	15	6D
0005434979673	23533	16	7A
0005434979761	23533	17	7D
0005434979702	23533	18	18A
0005434979605	23533	19	18B
0005434979601	23533	20	18C
0005434979697	23533	21	18D
0005434979638	23533	22	19A
0005434979639	23533	23	19B
0005434979622	23533	24	19C
0005435801685	23533	25	19D
0005434979579	23533	26	20A
0005434979711	23533	27	20C
0005434979693	23533	28	21A
0005435801682	23533	29	21D
0005434979698	23533	30	22A
0005434979726	23533	31	22B
0005434979558	23533	32	23A
0005434952555	2627	1	1A
0005434952554	2627	2	4A
0005434952552	2627	3	5B
0005434952553	2627	4	6B
0005433256424	2596	1	4A
0005434952501	28236	1	1A
0005434952522	28236	2	3A
0005433256436	28236	3	5B
0005434302866	19731	1	1A
0005434302868	19731	2	2A
0005434302872	19731	3	2B
0005433112384	19731	4	3A
0005434302865	19731	5	4A
0005434302867	19731	6	4B
0005433112385	19731	7	5A
0005434302871	19731	8	5B
0005433111520	19731	9	6A
0005433112351	20024	1	1A
0005433112356	20024	2	1B
0005433112357	20024	3	2A
0005433112359	20024	4	2B
0005433112361	20024	5	3A
0005433112358	20024	6	3B
0005433112354	20024	7	4A
0005433112355	20024	8	5A
0005433112360	20024	9	5B
0005433112353	20024	10	6A
0005433112352	20024	11	6B
0005434138147	11971	1	1A
0005434137950	11971	2	1C
0005434137821	11971	3	1D
0005434137938	11971	4	1F
0005434138171	11971	5	2A
0005434137888	11971	6	2C
0005434137765	11971	7	2D
0005434138024	11971	8	2F
0005434138174	11971	9	3A
0005434137701	11971	10	3C
0005434138260	11971	11	3D
0005434137746	11971	12	3F
0005434137928	11971	13	4A
0005434137593	11971	14	4C
0005434137942	11971	15	4D
0005434137793	11971	16	4E
0005434137927	11971	17	4F
0005434138246	11971	18	5A
0005434137909	11971	19	5C
0005434138123	11971	20	5D
0005434138120	11971	21	5E
0005434137775	11971	22	5F
0005434137749	11971	23	6A
0005434137991	11971	24	6C
0005434137979	11971	25	6D
0005434138051	11971	26	6E
0005434138146	11971	27	6F
0005434138217	11971	28	7A
0005434137772	11971	29	7C
0005434137861	11971	30	7D
0005434137810	11971	31	7E
0005434137908	11971	32	7F
0005434137828	11971	33	8A
0005434137864	11971	34	8C
0005434137811	11971	35	8D
0005434137945	11971	36	8E
0005434137833	11971	37	8F
0005434137574	11971	38	9A
0005434137897	11971	39	9C
0005434138057	11971	40	9D
0005434138005	11971	41	9F
0005434137956	11971	42	10D
0005434137887	11971	43	10E
0005434137946	11971	44	10F
0005434137806	11971	45	11A
0005434137728	11971	46	11C
0005434137666	11971	47	11D
0005434137980	11971	48	11E
0005434137844	11971	49	11F
0005434137838	11971	50	12A
0005434137884	11971	51	12C
0005434137914	11971	52	12E
0005434137820	11971	53	12F
0005434138241	11971	54	13A
0005434138070	11971	55	13C
0005434138038	11971	56	13D
0005434137832	11971	57	13E
0005434137943	11971	58	13F
0005434137819	11971	59	14A
0005434137774	11971	60	14C
0005434138129	11971	61	14E
0005434137937	11971	62	15A
0005434137702	11971	63	15D
0005434138177	11971	64	15E
0005434137700	11971	65	15F
0005434137790	11971	66	16A
0005434138178	11971	67	16D
0005434137770	11971	68	16F
0005434138067	11971	69	17A
0005434137955	11971	70	17C
0005434137907	11971	71	17D
0005434138058	11971	72	17E
0005434138022	11971	73	17F
0005434138327	11971	74	18A
0005434138329	11971	75	18C
0005434137973	11971	76	18D
0005434137604	11971	77	18E
0005434137935	11971	78	19A
0005434137826	11971	79	19C
0005434138066	11971	80	19D
0005434138115	11971	81	19E
0005434137982	11971	82	19F
0005434137913	11971	83	20A
0005434138175	11971	84	20C
0005434138004	11971	85	20D
0005434137750	11971	86	20E
0005434138170	11971	87	20F
0005434138563	28754	1	1A
0005434138621	28754	2	1D
0005434138570	28754	3	2A
0005434138619	28754	4	2C
0005434138604	28754	5	2D
0005434138624	28754	6	2F
0005434138579	28754	7	3C
0005434138603	28754	8	3D
0005434138626	28754	9	4A
0005434138622	28754	10	4C
0005434138628	28754	11	4D
0005434138584	28754	12	4F
0005434138589	28754	13	5A
0005434138593	28754	14	5D
0005434138630	28754	15	5E
0005434138564	28754	16	5F
0005434138598	28754	17	6A
0005434138559	28754	18	6C
0005434138565	28754	19	6D
0005434138573	28754	20	6E
0005434138557	28754	21	6F
0005434138614	28754	22	7C
0005434138609	28754	23	7E
0005434138562	28754	24	7F
0005434138576	28754	25	8A
0005434138595	28754	26	8C
0005434138586	28754	27	8D
0005434138590	28754	28	8E
0005434138601	28754	29	8F
0005434138578	28754	30	9A
0005434138567	28754	31	9C
0005434138611	28754	32	9D
0005434138597	28754	33	9E
0005434138561	28754	34	9F
0005434138558	28754	35	10A
0005434138613	28754	36	10C
0005434138554	28754	37	10D
0005434138599	28754	38	10E
0005434138582	28754	39	11C
0005434138560	28754	40	11D
0005434138623	28754	41	11E
0005434138587	28754	42	11F
0005434138585	28754	43	12A
0005434138588	28754	44	12C
0005434138615	28754	45	12D
0005434138606	28754	46	12E
0005434138555	28754	47	12F
0005434138602	28754	48	13A
0005434138625	28754	49	13C
0005434138577	28754	50	13E
0005434138594	28754	51	13F
0005434138592	28754	52	14A
0005434138612	28754	53	14C
0005434138610	28754	54	14D
0005434138575	28754	55	14E
0005434138574	28754	56	14F
0005434138607	28754	57	15C
0005434138581	28754	58	15D
0005434138566	28754	59	15E
0005434138553	28754	60	15F
0005434138600	28754	61	16C
0005434138618	28754	62	16D
0005434138620	28754	63	16E
0005434138556	28754	64	16F
0005434138627	28754	65	17A
0005434138583	28754	66	17C
0005434138617	28754	67	17D
0005434138605	28754	68	17E
0005434138596	28754	69	17F
0005434138572	28754	70	18C
0005434138591	28754	71	18F
0005434138568	28754	72	19A
0005434138608	28754	73	19C
0005434138580	28754	74	19D
0005434138631	28754	75	19E
0005434138569	28754	76	20A
0005434138571	28754	77	20C
0005434138616	28754	78	20D
0005434138629	28754	79	20F
0005434466483	6590	1	1C
0005434466488	6590	2	2A
0005435312794	6590	3	3C
0005434466485	6590	4	3B
0005435312798	6590	5	3D
0005434466478	6590	6	4C
0005434466489	6590	7	4D
0005435312801	6590	8	5C
0005434466484	6590	9	6B
0005435312793	6590	10	6C
0005434466486	6590	11	6D
0005434466487	6590	12	7A
0005435312795	6590	13	7C
0005435312792	6590	14	7D
0005434466480	6590	15	18B
0005434466482	6590	16	19A
0005435312803	6590	17	19D
0005435312802	6590	18	20B
0005434466492	6590	19	20D
0005434466491	6590	20	21B
0005435312797	6590	21	21D
0005434466481	6590	22	22A
0005434466490	6590	23	22B
0005434466479	6590	24	22C
0005435312796	6590	25	22D
0005434466493	6590	26	23B
0005433534512	6810	1	1B
0005435259735	6810	2	2A
0005433538926	6810	3	3B
0005435259745	6810	4	4B
0005433538921	6810	5	4C
0005433538925	6810	6	5A
0005435259751	6810	7	5B
0005435259744	6810	8	6A
0005435259736	6810	9	6B
0005433538920	6810	10	7A
0005433538927	6810	11	7B
0005433538924	6810	12	7D
0005435259753	6810	13	18B
0005433538922	6810	14	19B
0005435259752	6810	15	20D
0005433538923	6810	16	21A
0005433534511	6810	17	22C
0005433538835	25050	1	1D
0005433538839	25050	2	2C
0005433538842	25050	3	3A
0005433538871	25050	4	3B
0005433534492	25050	5	5C
0005433538877	25050	6	6A
0005433538873	25050	7	6D
0005435259782	25050	8	18B
0005433534497	25050	9	19A
0005433538836	25050	10	19D
0005435259784	25050	11	20B
0005433534488	25050	12	20C
0005433538840	25050	13	21A
0005433538838	25050	14	21C
0005433534500	25050	15	22A
0005433538874	25050	16	22B
0005435259785	25050	17	22D
0005435259783	25050	18	23B
0005433512000	834	1	1C
0005432922514	834	2	1D
0005432922509	834	3	3C
0005433512005	834	4	6B
0005433512004	834	5	7B
0005433512002	834	6	18A
0005433511999	834	7	20A
0005433512006	834	8	20B
0005433512001	834	9	20C
0005433512003	834	10	21C
0005432922510	834	11	22A
0005433512007	834	12	22B
0005433511952	16171	1	1C
0005433511939	16171	2	1D
0005433511906	16171	3	2A
0005432922548	16171	4	2C
0005433511930	16171	5	2D
0005433511922	16171	6	4A
0005433511931	16171	7	4C
0005432922549	16171	8	5C
0005433511946	16171	9	6C
0005432922550	16171	10	7A
0005433511938	16171	11	7C
0005433511951	16171	12	19B
0005432922551	16171	13	19C
0005432922553	16171	14	21A
0005433511907	16171	15	22A
0005432922552	16171	16	22C
0005433475735	4036	1	1A
0005435852554	4036	2	2D
0005433475728	4036	3	3A
0005433475736	4036	4	4C
0005433475731	4036	5	5D
0005433475729	4036	6	6C
0005435852577	4036	7	7A
0005433475733	4036	8	18D
0005433475732	4036	9	19C
0005435852576	4036	10	20A
0005433475734	4036	11	20B
0005435852578	4036	12	20D
0005433475730	4036	13	21D
0005435697524	3677	1	1B
0005435697507	3677	2	2A
0005435697528	3677	3	2B
0005435697514	3677	4	2C
0005434950555	3677	5	2D
0005435697512	3677	6	3B
0005434950559	3677	7	3C
0005435697504	3677	8	3D
0005435697516	3677	9	4A
0005435916152	3677	10	4B
0005435697520	3677	11	4C
0005435697522	3677	12	4D
0005435935047	3677	13	5B
0005435697515	3677	14	5C
0005435916153	3677	15	5D
0005435697510	3677	16	6A
0005435697531	3677	17	6B
0005435935054	3677	18	6D
0005434950557	3677	19	7A
0005435697506	3677	20	7C
0005435697530	3677	21	7D
0005435697519	3677	22	18A
0005435697527	3677	23	18C
0005435935042	3677	24	18D
0005435697508	3677	25	19A
0005434950558	3677	26	19C
0005435697521	3677	27	19D
0005435697526	3677	28	20A
0005435916160	3677	29	20B
0005435697509	3677	30	20C
0005435697505	3677	31	20D
0005435697511	3677	32	21A
0005435697525	3677	33	21B
0005435697523	3677	34	21C
0005435697518	3677	35	22B
0005435697517	3677	36	22C
0005435697529	3677	37	22D
0005435697513	3677	38	23A
0005434950556	3677	39	23B
0005434950508	16280	1	1A
0005435697051	16280	2	1B
0005435697111	16280	3	1D
0005434950504	16280	4	1C
0005434950497	16280	5	2A
0005435916185	16280	6	2C
0005435697050	16280	7	2D
0005435916186	16280	8	3A
0005435697211	16280	9	3B
0005435697292	16280	10	3C
0005435697235	16280	11	3D
0005435697265	16280	12	4A
0005435697306	16280	13	4B
0005435697182	16280	14	4C
0005435697177	16280	15	4D
0005435697212	16280	16	5A
0005435697185	16280	17	5B
0005435697236	16280	18	5C
0005435697208	16280	19	5D
0005435935062	16280	20	6A
0005434950506	16280	21	6B
0005434950486	16280	22	6C
0005434950505	16280	23	6D
0005435935064	16280	24	7A
0005435935063	16280	25	7B
0005435697145	16280	26	7C
0005435697333	16280	27	7D
0005435697112	16280	28	18A
0005435697210	16280	29	18B
0005434950496	16280	30	18C
0005435697174	16280	31	18D
0005434950518	16280	32	19A
0005435697307	16280	33	19B
0005435916184	16280	34	19C
0005435916187	16280	35	19D
0005435697313	16280	36	20A
0005435916188	16280	37	20B
0005435697252	16280	38	20C
0005435697181	16280	39	21B
0005435697209	16280	40	21C
0005434950503	16280	41	22A
0005434950514	16280	42	22B
0005435697281	16280	43	22C
0005435697027	16280	44	22D
0005435697178	16280	45	23A
0005435697245	16280	46	23B
0005432607592	3959	1	1C
0005433519486	3959	2	2A
0005432609757	3959	3	2B
0005432609755	3959	4	2C
0005433519487	3959	5	3D
0005432609756	3959	6	4C
0005434604918	3959	7	5A
0005433519488	3959	8	5C
0005433519484	3959	9	5D
0005434606850	3959	10	6A
0005432607591	3959	11	7A
0005432607590	3959	12	7B
0005435842326	3959	13	7C
0005434606848	3959	14	7D
0005434604919	3959	15	18A
0005432609758	3959	16	18D
0005432609759	3959	17	19B
0005434606849	3959	18	20B
0005432607593	3959	19	21D
0005433519485	3959	20	22A
0005434606851	3959	21	23A
0005434606803	22065	1	1A
0005433519440	22065	2	1B
0005435853621	22065	3	1C
0005433519464	22065	4	2A
0005433519463	22065	5	2B
0005433519443	22065	6	3A
0005433519438	22065	7	3B
0005434606817	22065	8	4D
0005434606812	22065	9	6D
0005435853622	22065	10	7D
0005433519459	22065	11	18A
0005434606818	22065	12	18B
0005434606813	22065	13	19A
0005434606805	22065	14	19B
0005434603019	22065	15	19C
0005433519437	22065	16	19D
0005435853623	22065	17	20C
0005434606804	22065	18	22A
0005434606789	22065	19	22C
0005433519444	22065	20	23A
0005435628743	770	1	1A
0005433348965	770	2	1B
0005433348959	770	3	2A
0005435628740	770	4	2B
0005433348953	770	5	3A
0005435628739	770	6	3B
0005435628741	770	7	4A
0005435628742	770	8	4B
0005433348979	770	9	5A
0005433348966	770	10	6A
0005433348970	770	11	6B
0005435628709	15956	1	1A
0005433349026	15956	2	1B
0005435628712	15956	3	2A
0005433349027	15956	4	3B
0005433349028	15956	5	4B
0005433349024	15956	6	5A
0005433349023	15956	7	5B
0005433349025	15956	8	6A
0005435628710	15956	9	6B
0005434445257	17161	1	1A
0005433158120	17161	2	1B
0005433159311	17161	3	2A
0005434446530	17161	4	2B
0005433158121	17161	5	3A
0005434446532	17161	6	3B
0005434446529	17161	7	4B
0005434445256	17161	8	5B
0005433159310	17161	9	6A
0005434446531	17161	10	6B
0005434445231	17646	1	2A
0005434445232	17646	2	4B
0005433159328	17646	3	5A
0005435383131	7885	1	1B
0005435383136	7885	2	1C
0005435383125	7885	3	2A
0005435383139	7885	4	2B
0005435383145	7885	5	2C
0005435132951	7885	6	2D
0005435383144	7885	7	3A
0005435132952	7885	8	4A
0005435383151	7885	9	4D
0005435132953	7885	10	6C
0005435132950	7885	11	7B
0005435383152	7885	12	7C
0005435132949	7885	13	7D
0005435383120	7885	14	18D
0005435383124	7885	15	19A
0005435383130	7885	16	20A
0005435132948	7885	17	20B
0005435132943	7885	18	20C
0005435132944	7885	19	22A
0005435132946	7885	20	22B
0005435132945	7885	21	22C
0005435132947	7885	22	22D
0005435383185	33115	1	1A
0005435132845	33115	2	1C
0005435132854	33115	3	2A
0005435132848	33115	4	2B
0005435132859	33115	5	2C
0005435132842	33115	6	3A
0005435132849	33115	7	3B
0005435132846	33115	8	3C
0005435132870	33115	9	4B
0005435383186	33115	10	5A
0005435132869	33115	11	6B
0005435383184	33115	12	6A
0005435132860	33115	13	18B
0005435132862	33115	14	18A
0005435132847	33115	15	19B
0005435132873	33115	16	19D
0005435383183	33115	17	20A
0005435132841	33115	18	20B
0005435132863	33115	19	21D
0005435132820	33115	20	22D
0005435160370	7489	1	1C
0005435160372	7489	2	2D
0005435160377	7489	3	3A
0005435160368	7489	4	4A
0005435160367	7489	5	4C
0005435160376	7489	6	4D
0005435160373	7489	7	5A
0005435390227	7489	8	6A
0005435390205	7489	9	6C
0005435390241	7489	10	7A
0005435160375	7489	11	19B
0005435390242	7489	12	19C
0005435160374	7489	13	19D
0005435390219	7489	14	20B
0005435390226	7489	15	21B
0005435160369	7489	16	22A
0005435160371	7489	17	22B
0005435390206	7489	18	23A
0005435160297	29565	1	2B
0005435160338	29565	2	2C
0005435390283	29565	3	3C
0005435160312	29565	4	3D
0005435160304	29565	5	4A
0005435390281	29565	6	4B
0005435390282	29565	7	4C
0005435390280	29565	8	4D
0005435390285	29565	9	5B
0005435390286	29565	10	6A
0005435160277	29565	11	6B
0005435160311	29565	12	18B
0005435160270	29565	13	19B
0005435160269	29565	14	19C
0005435390284	29565	15	20A
0005435160310	29565	16	22A
0005435160220	29565	17	22D
0005435160298	29565	18	23A
0005435160303	29565	19	23B
0005432398186	18466	1	1A
0005432394088	18466	2	1B
0005432394083	18466	3	2A
0005432398180	18466	4	2B
0005432394101	18466	5	3B
0005432398193	18466	6	4A
0005432398192	18466	7	4B
0005435178505	18466	8	5A
0005432398187	18466	9	5B
0005435178504	18466	10	6A
0005432398195	18466	11	6B
0005435178491	27151	1	1B
0005432400143	27151	2	2A
0005435178492	27151	3	2B
0005432400144	27151	4	3A
0005432398218	27151	5	3B
0005432400146	27151	6	4A
0005432400145	27151	7	4B
0005432398217	27151	8	6A
0005432398216	27151	9	6B
0005432639206	2233	1	1D
0005432639201	2233	2	2A
0005432865978	2233	3	2C
0005432639213	2233	4	2D
0005432865960	2233	5	2F
0005432866003	2233	6	3A
0005432865972	2233	7	3C
0005432639216	2233	8	3D
0005432639193	2233	9	4A
0005432639212	2233	10	4C
0005432866004	2233	11	4D
0005432639209	2233	12	4F
0005432639184	2233	13	5A
0005432866024	2233	14	5C
0005432639211	2233	15	5D
0005432639200	2233	16	5E
0005432865969	2233	17	5F
0005432866000	2233	18	6C
0005432865951	2233	19	7A
0005432639219	2233	20	7C
0005432866005	2233	21	7E
0005432639215	2233	22	8A
0005432865990	2233	23	8C
0005432866029	2233	24	8D
0005432865986	2233	25	9C
0005432639192	2233	26	9E
0005432639196	2233	27	9F
0005432639183	2233	28	10A
0005432639187	2233	29	10D
0005432639188	2233	30	10F
0005432865964	2233	31	11C
0005432865966	2233	32	11D
0005432639204	2233	33	11E
0005432639197	2233	34	12C
0005432639191	2233	35	12E
0005432865947	2233	36	12F
0005432865965	2233	37	13A
0005432639186	2233	38	13C
0005432639208	2233	39	13D
0005432866001	2233	40	14A
0005432866002	2233	41	14C
0005432639189	2233	42	14D
0005432865989	2233	43	14E
0005432639205	2233	44	14F
0005432865979	2233	45	15A
0005432639218	2233	46	15C
0005432639217	2233	47	15D
0005432865981	2233	48	15E
0005432639195	2233	49	15F
0005432639203	2233	50	16A
0005432865997	2233	51	16D
0005432865974	2233	52	16E
0005432865987	2233	53	16F
0005432639202	2233	54	17C
0005432865988	2233	55	17E
0005432639190	2233	56	18A
0005432639194	2233	57	18C
0005432639185	2233	58	18D
0005432865980	2233	59	18E
0005432639207	2233	60	18F
0005432639199	2233	61	19A
0005432639210	2233	62	19D
0005432639214	2233	63	19E
0005432639198	2233	64	20C
0005432865973	2233	65	20E
0005432865982	2233	66	20F
0005434191265	9755	1	2B
0005434191263	9755	2	4B
0005434191264	9755	3	5A
0005435103982	6527	1	2D
0005434504422	6527	2	2F
0005434504399	6527	3	3A
0005434504423	6527	4	3D
0005435103981	6527	5	3F
0005434504417	6527	6	4D
0005434504419	6527	7	5C
0005434504392	6527	8	5D
0005434504385	6527	9	5F
0005434504401	6527	10	6C
0005434504396	6527	11	6E
0005434504388	6527	12	6D
0005434504420	6527	13	6F
0005434504415	6527	14	7A
0005434504404	6527	15	7C
0005435103979	6527	16	7D
0005434504390	6527	17	8C
0005434504403	6527	18	8D
0005434504414	6527	19	9D
0005434504402	6527	20	9E
0005434504411	6527	21	10A
0005434504384	6527	22	10C
0005434504410	6527	23	10D
0005434504387	6527	24	11E
0005434504400	6527	25	11F
0005434504394	6527	26	12E
0005434504406	6527	27	12F
0005434504391	6527	28	13E
0005434504421	6527	29	14C
0005434504407	6527	30	14D
0005434504398	6527	31	15D
0005434504393	6527	32	15E
0005434504386	6527	33	15F
0005434504416	6527	34	16A
0005434504389	6527	35	16C
0005434504418	6527	36	16D
0005434504412	6527	37	16F
0005435103980	6527	38	17A
0005434504408	6527	39	17D
0005434504413	6527	40	17F
0005434504395	6527	41	18A
0005434504409	6527	42	19E
0005434504383	6527	43	20C
0005434504397	6527	44	20D
0005434504405	6527	45	20E
0005434504164	22670	1	1F
0005434504031	22670	2	2A
0005434503837	22670	3	2D
0005435103889	22670	4	2F
0005435103895	22670	5	3A
0005434503966	22670	6	3C
0005435103874	22670	7	3D
0005434503833	22670	8	4C
0005434503741	22670	9	4D
0005435103892	22670	10	4E
0005434504052	22670	11	5A
0005435103894	22670	12	5C
0005434503896	22670	13	5D
0005434503948	22670	14	6E
0005434503991	22670	15	7F
0005434503929	22670	16	8A
0005434504096	22670	17	8C
0005435103883	22670	18	8E
0005435103890	22670	19	9A
0005434503794	22670	20	10A
0005434503923	22670	21	10E
0005434504000	22670	22	10F
0005434504089	22670	23	11A
0005435103900	22670	24	11C
0005434504060	22670	25	11D
0005434504094	22670	26	11F
0005435103897	22670	27	12A
0005435103898	22670	28	12D
0005434503999	22670	29	13A
0005435103875	22670	30	13E
0005434504028	22670	31	14A
0005435103882	22670	32	14C
0005434504032	22670	33	14D
0005434504090	22670	34	14F
0005434504085	22670	35	15A
0005434503897	22670	36	15C
0005434504098	22670	37	15E
0005434504136	22670	38	16A
0005434503930	22670	39	16F
0005434504059	22670	40	17E
0005435103858	22670	41	18D
0005434504053	22670	42	19C
0005435103857	22670	43	19F
0005434503962	22670	44	20A
0005434504101	22670	45	20C
0005434503919	22670	46	20D
0005434504027	22670	47	20F
0005435800117	6426	1	1D
0005435800113	6426	2	3A
0005435800125	6426	3	3B
0005435800123	6426	4	4C
0005435800120	6426	5	5D
0005435800127	6426	6	6A
0005435800119	6426	7	7B
0005435800114	6426	8	7A
0005435800118	6426	9	7D
0005435800121	6426	10	18B
0005435800116	6426	11	18C
0005435800128	6426	12	21A
0005435800122	6426	13	21B
0005435800124	6426	14	21C
0005435800126	6426	15	22A
0005435800115	6426	16	23B
0005435653305	1651	1	1C
0005433367773	1651	2	1D
0005435653342	1651	3	1F
0005435653314	1651	4	2C
0005435653337	1651	5	2D
0005433367763	1651	6	2F
0005435653327	1651	7	3A
0005435653301	1651	8	3C
0005435653340	1651	9	3D
0005435653312	1651	10	4C
0005435653303	1651	11	4D
0005435653332	1651	12	4F
0005435653309	1651	13	5A
0005433367902	1651	14	5C
0005435653298	1651	15	5D
0005435653299	1651	16	5E
0005435653297	1651	17	5F
0005435653320	1651	18	6A
0005433367924	1651	19	6C
0005435653341	1651	20	6D
0005435653344	1651	21	6E
0005435653333	1651	22	7A
0005433367788	1651	23	7C
0005435653302	1651	24	7D
0005435653329	1651	25	7E
0005435653313	1651	26	8A
0005435653346	1651	27	8D
0005435653323	1651	28	8E
0005435653338	1651	29	8F
0005433367886	1651	30	9A
0005433367617	1651	31	9C
0005433367767	1651	32	9D
0005433367762	1651	33	9E
0005435653330	1651	34	9F
0005435653306	1651	35	10D
0005435653315	1651	36	10F
0005435653331	1651	37	11A
0005433367735	1651	38	11C
0005435653322	1651	39	11D
0005433367768	1651	40	11E
0005435653319	1651	41	11F
0005433367684	1651	42	12A
0005433367847	1651	43	12C
0005433367618	1651	44	12D
0005435653307	1651	45	12E
0005435653295	1651	46	12F
0005435653343	1651	47	13A
0005435653336	1651	48	13E
0005435653321	1651	49	13F
0005433367738	1651	50	14A
0005435653304	1651	51	14C
0005433367810	1651	52	14D
0005435653345	1651	53	14E
0005435653308	1651	54	14F
0005433367846	1651	55	15A
0005435653310	1651	56	15C
0005433367802	1651	57	15E
0005435653347	1651	58	15F
0005435653335	1651	59	16A
0005435653348	1651	60	16C
0005435653316	1651	61	16F
0005433367685	1651	62	17A
0005435653317	1651	63	17C
0005435653318	1651	64	17D
0005433367887	1651	65	17F
0005433367756	1651	66	18A
0005435653328	1651	67	18C
0005435653324	1651	68	18E
0005433367698	1651	69	18F
0005435653296	1651	70	19A
0005435653300	1651	71	19C
0005435653339	1651	72	19D
0005433367809	1651	73	19E
0005433367934	1651	74	19F
0005435653325	1651	75	20A
0005435653311	1651	76	20D
0005435653326	1651	77	20E
0005435653334	1651	78	20F
0005435652949	21691	1	1A
0005435652594	21691	2	1D
0005435652883	21691	3	1F
0005435652983	21691	4	2A
0005435652928	21691	5	2C
0005435652767	21691	6	2D
0005433368113	21691	7	2F
0005433368127	21691	8	3A
0005435652929	21691	9	3C
0005435652858	21691	10	3F
0005435652900	21691	11	3D
0005435652752	21691	12	4A
0005433368114	21691	13	4C
0005433368111	21691	14	4D
0005435652884	21691	15	4E
0005433368138	21691	16	5A
0005433368139	21691	17	5C
0005435652921	21691	18	5F
0005435652593	21691	19	6A
0005435652876	21691	20	6C
0005435652877	21691	21	6D
0005435652799	21691	22	6E
0005435652942	21691	23	6F
0005433368118	21691	24	7A
0005433368117	21691	25	7C
0005435652970	21691	26	7D
0005433368135	21691	27	7E
0005433368115	21691	28	7F
0005435652890	21691	29	8A
0005435652693	21691	30	8C
0005435652946	21691	31	8D
0005433368122	21691	32	8E
0005435652873	21691	33	8F
0005435652954	21691	34	9A
0005433368121	21691	35	9C
0005435652971	21691	36	9D
0005435652870	21691	37	9F
0005435652960	21691	38	10A
0005433368126	21691	39	10C
0005435652927	21691	40	10D
0005433368125	21691	41	10E
0005435652964	21691	42	10F
0005433368137	21691	43	11A
0005433368119	21691	44	11C
0005435652915	21691	45	11D
0005433368124	21691	46	11E
0005435652838	21691	47	11F
0005433368131	21691	48	12A
0005435652968	21691	49	12C
0005433368136	21691	50	12D
0005435652874	21691	51	12E
0005435652977	21691	52	12F
0005435652757	21691	53	13A
0005433368112	21691	54	13D
0005435652950	21691	55	13E
0005433368109	21691	56	14A
0005435652979	21691	57	14C
0005433368116	21691	58	14D
0005433368110	21691	59	14E
0005435652857	21691	60	14F
0005435652879	21691	61	15A
0005435652978	21691	62	15C
0005433368120	21691	63	15D
0005433368132	21691	64	15E
0005435652753	21691	65	15F
0005433368134	21691	66	16A
0005435652951	21691	67	16C
0005435652875	21691	68	16D
0005433368123	21691	69	16E
0005433368128	21691	70	16F
0005433368104	21691	71	17C
0005435652798	21691	72	17D
0005433368130	21691	73	17E
0005435652987	21691	74	17F
0005435652980	21691	75	18A
0005435652969	21691	76	18C
0005435652861	21691	77	18D
0005435652973	21691	78	18E
0005433368107	21691	79	18F
0005433368106	21691	80	19A
0005433368108	21691	81	19C
0005433368103	21691	82	19D
0005435652871	21691	83	19E
0005435652916	21691	84	19F
0005433368133	21691	85	20A
0005433368105	21691	86	20C
0005433368129	21691	87	20D
0005435652899	21691	88	20F
0005435627118	23809	1	5B
0005435312822	23223	1	1A
0005434466456	23223	2	1D
0005434466481	23223	3	2C
0005434466457	23223	4	2D
0005434466443	23223	5	3B
0005435312820	23223	6	3D
0005434466450	23223	7	6A
0005434466455	23223	8	6D
0005434466439	23223	9	7A
0005434466433	23223	10	7B
0005435312821	23223	11	7C
0005434466454	23223	12	18A
0005435312819	23223	13	18B
0005434466434	23223	14	19C
0005434466444	23223	15	20B
0005435312818	23223	16	20D
0005434466440	23223	17	21A
0005435312817	23223	18	21B
0005435788786	4155	1	1A
0005433986233	4155	2	1C
0005433986252	4155	3	1D
0005433986247	4155	4	1F
0005435788788	4155	5	2A
0005433986229	4155	6	2C
0005433986242	4155	7	2F
0005433986228	4155	8	3A
0005433986223	4155	9	3C
0005433986239	4155	10	3D
0005433986243	4155	11	4A
0005433986225	4155	12	4D
0005433986234	4155	13	4E
0005433986220	4155	14	5D
0005433986224	4155	15	5F
0005435788789	4155	16	6C
0005433986250	4155	17	6E
0005433986240	4155	18	7C
0005433986251	4155	19	7D
0005433986227	4155	20	7E
0005433986258	4155	21	8F
0005433986245	4155	22	9A
0005433986222	4155	23	10A
0005433986231	4155	24	10C
0005433986241	4155	25	11D
0005433986232	4155	26	11E
0005433986238	4155	27	12A
0005433986249	4155	28	12F
0005433986236	4155	29	13E
0005433986255	4155	30	14A
0005433986246	4155	31	14E
0005433986219	4155	32	14F
0005433986254	4155	33	15C
0005433986253	4155	34	16A
0005433986248	4155	35	16D
0005433986256	4155	36	16F
0005433986230	4155	37	18C
0005433986257	4155	38	18D
0005433986244	4155	39	18F
0005433986235	4155	40	19A
0005433986221	4155	41	19D
0005433986237	4155	42	19E
0005435788787	4155	43	20C
0005433986226	4155	44	20F
0005433985809	25681	1	1A
0005433985707	25681	2	1C
0005433985828	25681	3	1D
0005433985810	25681	4	3C
0005433985700	25681	5	3D
0005433985633	25681	6	4A
0005433985928	25681	7	4C
0005433985634	25681	8	4E
0005433985732	25681	9	5C
0005433985696	25681	10	5D
0005433985655	25681	11	5E
0005433985716	25681	12	6A
0005433985858	25681	13	6C
0005433985841	25681	14	6E
0005433985871	25681	15	7C
0005433985731	25681	16	7E
0005433985629	25681	17	7F
0005433985730	25681	18	8D
0005433985695	25681	19	8F
0005433985811	25681	20	9C
0005433985607	25681	21	9F
0005433985628	25681	22	10C
0005433985807	25681	23	10F
0005433985855	25681	24	11C
0005433986021	25681	25	11D
0005433985729	25681	26	11F
0005433985708	25681	27	12C
0005433985872	25681	28	12D
0005433985706	25681	29	13C
0005433985818	25681	30	14A
0005435788766	25681	31	14C
0005433985870	25681	32	14D
0005433985608	25681	33	14E
0005433985723	25681	34	14F
0005433985833	25681	35	15C
0005433985641	25681	36	15D
0005433985773	25681	37	15F
0005433985719	25681	38	16A
0005433985654	25681	39	16D
0005433985694	25681	40	16E
0005433985739	25681	41	18A
0005433985759	25681	42	18F
0005433985622	25681	43	19C
0005433985701	25681	44	19D
0005433985635	25681	45	19F
0005433985814	25681	46	20A
0005433985930	25681	47	20C
0005433985819	25681	48	20E
0005433986040	25681	49	20F
0005434509115	21337	1	1A
0005434509108	21337	2	1B
0005434509142	21337	3	1C
0005434509148	21337	4	1D
0005434509140	21337	5	2A
0005434509138	21337	6	2B
0005434509114	21337	7	2C
0005434509123	21337	8	2D
0005434509120	21337	9	3A
0005434509143	21337	10	3C
0005434509127	21337	11	4B
0005434509141	21337	12	4C
0005433168396	21337	13	4D
0005434509136	21337	14	5A
0005433168397	21337	15	5C
0005433168393	21337	16	6D
0005433168399	21337	17	7B
0005434509111	21337	18	7C
0005434509117	21337	19	18A
0005433168400	21337	20	18C
0005433168395	21337	21	18D
0005433168398	21337	22	19A
0005434509147	21337	23	19D
0005433168401	21337	24	20A
0005434509112	21337	25	21A
0005433168394	21337	26	21B
0005434509137	21337	27	21C
0005434509129	21337	28	22A
0005434509126	21337	29	22B
0005434509128	21337	30	22D
0005434509121	21337	31	23B
0005432655482	17820	1	1A
0005432667450	17820	2	1C
0005432655508	17820	3	1F
0005432661914	17820	4	2A
0005432661915	17820	5	2D
0005432869568	17820	6	2F
0005434151725	17820	7	3A
0005432655485	17820	8	3D
0005432655502	17820	9	3F
0005434151724	17820	10	4D
0005432869571	17820	11	5E
0005432660813	17820	12	5F
0005432657448	17820	13	6F
0005432659696	17820	14	7D
0005432655490	17820	15	7F
0005432869570	17820	16	8A
0005432659705	17820	17	8F
0005432657450	17820	18	9C
0005432655544	17820	19	9D
0005432655510	17820	20	10A
0005432655532	17820	21	10C
0005432655545	17820	22	10D
0005432655507	17820	23	10F
0005432658587	17820	24	11A
0005432655487	17820	25	11E
0005434151723	17820	26	11F
0005432661923	17820	27	12C
0005432869569	17820	28	12D
0005432655491	17820	29	13C
0005432655486	17820	30	13D
0005432667452	17820	31	13E
0005432655509	17820	32	13F
0005432655514	17820	33	14A
0005432655467	17820	34	14D
0005432659695	17820	35	15A
0005432658589	17820	36	15D
0005432655483	17820	37	15F
0005432660814	17820	38	16A
0005432660818	17820	39	16D
0005432655503	17820	40	17A
0005432655501	17820	41	17E
0005432658585	17820	42	17F
0005432660817	17820	43	18C
0005432667451	17820	44	18D
0005432666380	17820	45	18F
0005432655533	17820	46	19A
0005432655500	17820	47	19D
0005432658586	17820	48	20A
0005432659706	17820	49	20C
0005432869572	17820	50	20D
0005434151691	26306	1	2C
0005432667464	26306	2	2F
0005432658600	26306	3	3C
0005432659718	26306	4	3F
0005432660828	26306	5	4F
0005432655583	26306	6	5A
0005432659716	26306	7	5E
0005432659717	26306	8	6A
0005432655586	26306	9	6C
0005432657465	26306	10	6F
0005432665284	26306	11	7A
0005434151699	26306	12	7F
0005432655591	26306	13	8C
0005432655585	26306	14	8E
0005432657464	26306	15	9C
0005432658601	26306	16	10A
0005432869481	26306	17	10C
0005432655594	26306	18	10D
0005432657463	26306	19	10F
0005432655587	26306	20	11C
0005432655584	26306	21	12C
0005432655589	26306	22	13D
0005432655593	26306	23	13F
0005432655588	26306	24	16C
0005432660827	26306	25	17C
0005432665285	26306	26	17E
0005432655590	26306	27	19A
0005432666399	26306	28	19F
0005432655592	26306	29	20C
0005433438928	3070	1	1A
0005432328971	3070	2	1D
0005432328994	3070	3	2A
0005432287219	3070	4	2C
0005433438935	3070	5	2F
0005432328976	3070	6	3A
0005433438932	3070	7	3C
0005432329017	3070	8	4A
0005432328986	3070	9	4D
0005432905099	3070	10	4E
0005433438933	3070	11	4F
0005432328972	3070	12	5C
0005432329013	3070	13	5D
0005432328983	3070	14	5E
0005432329003	3070	15	5F
0005432328992	3070	16	6A
0005432328984	3070	17	6C
0005432329001	3070	18	7C
0005432329012	3070	19	7D
0005433438934	3070	20	7E
0005432287224	3070	21	7F
0005432329004	3070	22	8A
0005432329007	3070	23	8C
0005432328979	3070	24	8E
0005432328995	3070	25	8F
0005432328981	3070	26	9A
0005432328998	3070	27	9D
0005432328978	3070	28	9E
0005432328987	3070	29	9F
0005433438930	3070	30	10A
0005432329015	3070	31	10C
0005432329008	3070	32	10D
0005432329016	3070	33	10E
0005432328996	3070	34	10F
0005432328990	3070	35	11A
0005432329002	3070	36	11D
0005432287220	3070	37	11E
0005432329014	3070	38	11F
0005433438926	3070	39	12A
0005432329000	3070	40	12C
0005432328989	3070	41	12E
0005432328975	3070	42	12F
0005432329010	3070	43	13A
0005433438929	3070	44	13C
0005432329009	3070	45	13F
0005433438931	3070	46	14C
0005432287222	3070	47	14E
0005432329011	3070	48	14F
0005433438936	3070	49	15C
0005432905118	3070	50	15D
0005432287221	3070	51	15E
0005432905127	3070	52	15F
0005432328980	3070	53	16A
0005432328982	3070	54	16D
0005432328973	3070	55	16E
0005433438927	3070	56	16F
0005432287225	3070	57	17C
0005432328977	3070	58	17D
0005432329006	3070	59	17E
0005432328985	3070	60	18A
0005432328991	3070	61	18C
0005432328999	3070	62	18D
0005432328993	3070	63	18E
0005432328974	3070	64	19F
0005432328988	3070	65	20A
0005432287223	3070	66	20D
0005432329005	3070	67	20E
0005432328997	3070	68	20F
0005432328638	31125	1	1A
0005432328675	31125	2	1C
0005432328527	31125	3	1F
0005432905161	31125	4	2A
0005432328591	31125	5	2C
0005432328597	31125	6	2D
0005432328677	31125	7	2F
0005432905164	31125	8	3A
0005432328578	31125	9	3D
0005432328577	31125	10	3F
0005432328548	31125	11	4C
0005432328674	31125	12	4D
0005432328461	31125	13	4E
0005432328433	31125	14	4F
0005432054323	31125	15	5A
0005432905162	31125	16	5C
0005432328596	31125	17	5D
0005433438879	31125	18	5F
0005432328520	31125	19	6C
0005432328413	31125	20	6F
0005432328614	31125	21	7A
0005433438841	31125	22	7D
0005432328526	31125	23	7F
0005432054325	31125	24	8A
0005432328603	31125	25	8C
0005432328488	31125	26	8F
0005432328636	31125	27	9D
0005432328686	31125	28	9E
0005432328460	31125	29	9F
0005432328678	31125	30	10C
0005432905163	31125	31	10D
0005432328374	31125	32	10E
0005432328547	31125	33	11A
0005432328613	31125	34	11C
0005432328622	31125	35	11E
0005432328713	31125	36	11F
0005432328368	31125	37	12A
0005432328764	31125	38	12D
0005432328371	31125	39	12E
0005432328581	31125	40	12F
0005432328590	31125	41	13A
0005432905160	31125	42	13C
0005432328523	31125	43	13D
0005432328573	31125	44	13E
0005432328522	31125	45	14C
0005432054324	31125	46	14D
0005432328437	31125	47	14E
0005432328667	31125	48	15A
0005432328685	31125	49	15C
0005432328334	31125	50	15D
0005432328434	31125	51	15F
0005432905159	31125	52	16A
0005433438851	31125	53	16C
0005432328661	31125	54	16E
0005432328602	31125	55	16F
0005432328704	31125	56	17C
0005432328482	31125	57	17F
0005432328628	31125	58	18C
0005432328705	31125	59	18D
0005432328594	31125	60	18F
0005432328666	31125	61	19C
0005433438859	31125	62	19D
0005432328694	31125	63	19E
0005433438880	31125	64	20A
0005432328549	31125	65	20E
0005433438865	31125	66	20F
0005435487788	6184	1	1A
0005434309835	6184	2	1C
0005432146213	6184	3	2A
0005435999357	6184	4	1F
0005434309833	6184	5	2D
0005435487727	6184	6	2F
0005434309824	6184	7	3A
0005434309834	6184	8	3D
0005435487741	6184	9	3F
0005435487787	6184	10	4C
0005435297029	6184	11	4D
0005434309825	6184	12	5B
0005434309822	6184	13	5A
0005435999377	6184	14	5C
0005435999366	6184	15	5D
0005434309829	6184	16	6A
0005435999362	6184	17	6C
0005435999363	6184	18	6D
0005435297045	6184	19	6E
0005435297044	6184	20	6F
0005435999364	6184	21	7A
0005435487755	6184	22	7C
0005435487820	6184	23	8D
0005435297054	6184	24	9A
0005435999369	6184	25	9D
0005435999371	6184	26	10B
0005435297057	6184	27	11E
0005435999370	6184	28	11D
0005435487818	6184	29	12A
0005435999367	6184	30	12F
0005435999365	6184	31	13C
0005435999360	6184	32	14B
0005434309823	6184	33	14C
0005434309826	6184	34	14D
0005435487821	6184	35	15A
0005435297030	6184	36	15B
0005435999378	6184	37	15D
0005435487689	6184	38	15E
0005434309827	6184	39	16A
0005435999373	6184	40	16E
0005435999368	6184	41	16F
0005435999379	6184	42	17B
0005435487696	6184	43	17D
0005435487676	6184	44	17F
0005435999358	6184	45	18A
0005435487701	6184	46	18C
0005435999376	6184	47	18E
0005435999361	6184	48	18D
0005435487806	6184	49	18F
0005434309832	6184	50	19C
0005435487742	6184	51	19D
0005434309828	6184	52	19E
0005432146212	6184	53	20C
0005435487749	6184	54	20D
0005435999380	6184	55	21C
0005435999375	6184	56	21D
0005435999374	6184	57	21E
0005435487807	6184	58	22C
0005435487770	6184	59	22E
0005435999372	6184	60	22D
0005434309830	6184	61	23A
0005435487746	6184	62	23C
0005434309831	6184	63	23E
0005435999359	6184	64	23F
0005435487955	19572	1	1C
0005435999189	19572	2	1D
0005435487947	19572	3	2C
0005435297104	19572	4	2F
0005435487949	19572	5	3D
0005434309681	19572	6	3F
0005434309682	19572	7	4B
0005434309690	19572	8	4D
0005435297102	19572	9	4F
0005435487945	19572	10	5B
0005435487944	19572	11	5D
0005435487953	19572	12	5E
0005434309751	19572	13	5F
0005435487959	19572	14	6C
0005434309696	19572	15	6B
0005435999130	19572	16	6D
0005435487954	19572	17	6E
0005434309687	19572	18	7B
0005435487960	19572	19	7A
0005435297103	19572	20	7D
0005435487948	19572	21	7F
0005434309663	19572	22	8B
0005434309686	19572	23	8D
0005435487950	19572	24	8C
0005434309679	19572	25	8F
0005435487956	19572	26	9C
0005435999184	19572	27	9B
0005435487961	19572	28	9F
0005435297099	19572	29	10B
0005434309747	19572	30	10E
0005435999173	19572	31	11A
0005435999185	19572	32	11C
0005434309674	19572	33	12C
0005435999132	19572	34	12F
0005435297101	19572	35	13C
0005434309743	19572	36	13E
0005435487946	19572	37	13F
0005435487957	19572	38	15F
0005435487963	19572	39	16B
0005435297100	19572	40	16E
0005435999148	19572	41	17A
0005435487962	19572	42	17C
0005434309742	19572	43	17D
0005434309750	19572	44	17E
0005434309732	19572	45	18C
0005435999131	19572	46	18D
0005435487942	19572	47	18F
0005435487958	19572	48	19B
0005435297106	19572	49	19C
0005435487941	19572	50	19E
0005435297105	19572	51	20B
0005435487952	19572	52	20F
0005435999147	19572	53	21C
0005435999190	19572	54	21F
0005435999140	19572	55	22A
0005435487951	19572	56	22E
0005435487943	19572	57	23A
0005435999144	19572	58	23B
0005434309664	19572	59	23D
0005434446509	17554	1	3C
0005433158144	17554	2	3D
0005433158143	17554	3	5C
0005434446508	17554	4	5D
0005434446515	17554	5	6B
0005433158145	17554	6	18D
0005434446507	17554	7	20A
0005433158142	17554	8	21C
0005434446510	17554	9	22B
0005433158146	17554	10	23A
0005435502445	1545	1	1A
0005434565995	1545	2	1C
0005435508423	1545	3	1D
0005434566005	1545	4	1F
0005434566007	1545	5	2A
0005435518019	1545	6	2C
0005435518020	1545	7	2D
0005433186090	1545	8	2F
0005434566001	1545	9	3C
0005435502452	1545	10	3D
0005435518026	1545	11	4A
0005435508424	1545	12	4D
0005434566003	1545	13	4F
0005435502456	1545	14	5A
0005435502444	1545	15	5C
0005434565997	1545	16	5D
0005435502459	1545	17	5E
0005433186092	1545	18	5F
0005435508419	1545	19	6C
0005433186083	1545	20	6D
0005435502462	1545	21	6F
0005434566004	1545	22	7C
0005434565996	1545	23	7D
0005435518017	1545	24	7E
0005433186114	1545	25	7F
0005435518027	1545	26	8A
0005434565998	1545	27	8C
0005435508417	1545	28	8D
0005432291947	1545	29	8E
0005435508420	1545	30	9C
0005435508426	1545	31	9E
0005434565994	1545	32	9F
0005432291945	1545	33	10A
0005435518024	1545	34	10D
0005435518018	1545	35	10E
0005432291946	1545	36	11A
0005434566006	1545	37	11D
0005435508425	1545	38	11E
0005435502448	1545	39	11F
0005435518022	1545	40	12A
0005435518023	1545	41	12C
0005435502457	1545	42	12D
0005435502460	1545	43	12E
0005435502461	1545	44	12F
0005435502449	1545	45	13A
0005435502451	1545	46	13C
0005435518025	1545	47	13D
0005435502441	1545	48	13F
0005435502442	1545	49	14A
0005435508421	1545	50	14D
0005435508429	1545	51	14E
0005433186082	1545	52	14F
0005432291944	1545	53	15A
0005435502450	1545	54	15E
0005435508422	1545	55	15F
0005433186111	1545	56	16A
0005435518021	1545	57	16C
0005435508418	1545	58	16D
0005435502458	1545	59	16F
0005435518016	1545	60	17A
0005433186116	1545	61	17C
0005435508428	1545	62	17D
0005433186100	1545	63	17E
0005435502446	1545	64	18A
0005434566002	1545	65	18D
0005434566000	1545	66	18F
0005435502447	1545	67	19A
0005435508427	1545	68	19C
0005435502454	1545	69	19D
0005433186115	1545	70	19E
0005434565999	1545	71	19F
0005433186105	1545	72	20A
0005435502443	1545	73	20C
0005435502455	1545	74	20D
0005435502453	1545	75	20E
0005433186104	1545	76	20F
0005435502268	20876	1	1A
0005435502243	20876	2	1C
0005435502197	20876	3	1D
0005435529114	20876	4	1F
0005435502289	20876	5	2A
0005435529150	20876	6	2C
0005435545700	20876	7	2D
0005435529148	20876	8	2F
0005433186170	20876	9	3C
0005435545693	20876	10	3F
0005435502221	20876	11	4A
0005433186173	20876	12	4C
0005435502200	20876	13	4D
0005435545701	20876	14	4E
0005435502142	20876	15	4F
0005434565881	20876	16	5A
0005435529174	20876	17	5D
0005435502143	20876	18	5F
0005435529089	20876	19	6A
0005435502317	20876	20	6C
0005435502308	20876	21	6D
0005435529149	20876	22	6E
0005434565880	20876	23	6F
0005435529225	20876	24	7A
0005433186176	20876	25	7C
0005435502236	20876	26	7F
0005435545702	20876	27	8A
0005433186169	20876	28	8C
0005435502282	20876	29	8E
0005434565910	20876	30	9A
0005435502229	20876	31	9C
0005433186174	20876	32	9D
0005435502245	20876	33	9E
0005435545675	20876	34	9F
0005435502340	20876	35	10C
0005435529090	20876	36	10D
0005435502287	20876	37	10F
0005434565909	20876	38	11A
0005435502248	20876	39	11C
0005433186171	20876	40	11D
0005435502256	20876	41	11F
0005435502235	20876	42	12C
0005434565929	20876	43	12D
0005435502255	20876	44	12F
0005434565879	20876	45	13A
0005433186177	20876	46	13C
0005435529175	20876	47	13D
0005435529185	20876	48	13E
0005435502297	20876	49	13F
0005435502129	20876	50	14D
0005435502335	20876	51	14E
0005434565917	20876	52	14F
0005435529158	20876	53	15C
0005435529206	20876	54	15D
0005434565918	20876	55	15E
0005435502244	20876	56	15F
0005435502222	20876	57	16A
0005435545682	20876	58	16C
0005435529232	20876	59	16D
0005435545676	20876	60	16E
0005434565908	20876	61	16F
0005434565856	20876	62	17A
0005433186172	20876	63	17C
0005435502366	20876	64	17D
0005435529184	20876	65	17F
0005435529187	20876	66	18A
0005434565855	20876	67	18C
0005435502199	20876	68	18D
0005435529097	20876	69	18E
0005435502177	20876	70	18F
0005434565832	20876	71	19A
0005435529119	20876	72	19C
0005434565831	20876	73	19D
0005435502253	20876	74	19E
0005435529233	20876	75	19F
0005435545685	20876	76	20C
0005433186175	20876	77	20D
0005435502313	20876	78	20E
0005435153783	3924	1	4D
0005435931585	3924	2	6D
0005435153781	3924	3	7B
0005435153786	3924	4	18A
0005435153784	3924	5	18B
0005435931591	3924	6	18D
0005435153788	3924	7	19D
0005435153787	3924	8	20B
0005435931584	3924	9	21A
0005435153789	3924	10	22C
0005435153782	3924	11	22D
0005435153785	3924	12	23B
0005435153714	21871	1	1A
0005435931626	21871	2	5C
0005435153713	21871	3	6A
0005435153731	21871	4	6B
0005435153725	21871	5	18A
0005435153728	21871	6	18C
0005435931625	21871	7	19B
0005435931624	21871	8	21B
0005435153745	21871	9	22B
0005432628947	7192	1	1C
0005432628943	7192	2	1D
0005432628948	7192	3	2A
0005432628936	7192	4	3D
0005435225554	7192	5	4A
0005435225575	7192	6	4C
0005435225560	7192	7	6A
0005432628938	7192	8	6C
0005432628946	7192	9	7B
0005432628941	7192	10	18A
0005432628940	7192	11	18B
0005432628939	7192	12	18C
0005432628944	7192	13	19B
0005432628937	7192	14	21A
0005432628942	7192	15	21B
0005432628935	7192	16	21D
0005435225582	7192	17	22C
0005432628945	7192	18	23B
0005432628804	28102	1	1A
0005432628814	28102	2	1B
0005432628898	28102	3	1C
0005432628822	28102	4	1D
0005432628771	28102	5	2A
0005435225635	28102	6	2B
0005432628803	28102	7	2C
0005432628802	28102	8	3A
0005432628815	28102	9	3B
0005432628830	28102	10	3D
0005432628784	28102	11	4B
0005432628897	28102	12	4C
0005435225639	28102	13	4D
0005432628857	28102	14	5A
0005432628772	28102	15	5B
0005432628879	28102	16	5C
0005432628827	28102	17	6B
0005432628805	28102	18	7A
0005432628823	28102	19	7B
0005435225636	28102	20	7D
0005432628853	28102	21	18C
0005435225638	28102	22	18D
0005435225634	28102	23	19A
0005432628851	28102	24	19B
0005435225633	28102	25	19C
0005432628816	28102	26	20A
0005435225637	28102	27	21C
0005432628806	28102	28	21D
0005432628836	28102	29	22A
0005432628862	28102	30	22C
0005432628844	28102	31	22D
0005432628775	28102	32	23B
0005435960075	8730	1	1C
0005435960076	8730	2	2D
0005434267960	8730	3	5B
0005434267948	8730	4	18D
0005435960074	8730	5	20D
0005434267975	15229	1	2A
0005435960049	15229	2	2C
0005434267974	15229	3	4B
0005435960032	15229	4	7C
0005435960036	15229	5	18C
0005432693234	1219	1	1C
0005432693225	1219	2	1A
0005432675227	1219	3	1D
0005432693252	1219	4	2C
0005432693247	1219	5	2A
0005432677595	1219	6	3A
0005432693242	1219	7	2F
0005432693245	1219	8	3C
0005432873310	1219	9	4A
0005432675230	1219	10	4F
0005432693250	1219	11	6B
0005432675231	1219	12	6F
0005432675223	1219	13	6E
0005432693238	1219	14	6D
0005432873274	1219	15	7B
0005432693249	1219	16	7A
0005432693243	1219	17	7C
0005432675222	1219	18	7E
0005432693226	1219	19	8D
0005432873288	1219	20	9A
0005432693246	1219	21	9D
0005432693227	1219	22	9C
0005432693232	1219	23	10A
0005432675232	1219	24	10C
0005432675228	1219	25	11D
0005432693223	1219	26	12C
0005432693244	1219	27	13B
0005432675226	1219	28	13E
0005432693248	1219	29	14C
0005432693228	1219	30	14D
0005432693231	1219	31	15C
0005432675224	1219	32	15B
0005432677594	1219	33	16B
0005432693230	1219	34	16F
0005432693233	1219	35	17A
0005432675233	1219	36	17D
0005432693237	1219	37	17C
0005432675225	1219	38	17F
0005432693224	1219	39	18B
0005432693241	1219	40	18A
0005432693229	1219	41	19A
0005432675234	1219	42	19C
0005432675235	1219	43	19B
0005432677596	1219	44	19D
0005432693251	1219	45	19F
0005432675229	1219	46	20B
0005432693239	1219	47	20A
0005432693236	1219	48	20D
0005432693240	1219	49	21A
0005432693235	1219	50	21F
0005432873335	17466	1	1A
0005432692953	17466	2	1F
0005432693001	17466	3	4A
0005432693026	17466	4	4C
0005432675116	17466	5	4F
0005432693065	17466	6	5A
0005432692930	17466	7	5F
0005432675142	17466	8	5D
0005432873336	17466	9	6B
0005432675093	17466	10	6C
0005432692904	17466	11	6E
0005432873337	17466	12	6D
0005432873339	17466	13	7E
0005432693023	17466	14	7D
0005432692978	17466	15	8B
0005432692907	17466	16	8D
0005432692908	17466	17	8F
0005432675135	17466	18	9A
0005432873338	17466	19	9C
0005432693088	17466	20	9E
0005432692981	17466	21	10B
0005432693057	17466	22	10D
0005432675115	17466	23	10F
0005432692979	17466	24	10E
0005432693025	17466	25	11A
0005432692864	17466	26	11C
0005432693084	17466	27	12A
0005432692971	17466	28	12C
0005432693027	17466	29	12F
0005432873340	17466	30	13C
0005432693041	17466	31	13E
0005432692773	17466	32	14A
0005432675088	17466	33	14C
0005432692977	17466	34	14F
0005432693087	17466	35	15A
0005432692896	17466	36	15E
0005432692952	17466	37	16A
0005432675080	17466	38	15F
0005432675153	17466	39	16C
0005432692970	17466	40	16D
0005432692999	17466	41	16F
0005432677577	17466	42	17C
0005432873334	17466	43	17F
0005432692909	17466	44	18B
0005432693010	17466	45	18C
0005432675081	17466	46	18E
0005432692960	17466	47	18D
0005432675129	17466	48	19C
0005432692998	17466	49	19A
0005432693002	17466	50	19F
0005432692931	17466	51	20A
0005432675099	17466	52	20D
0005432675141	17466	53	20C
0005432693030	17466	54	20E
0005432693060	17466	55	21C
0005432693040	17466	56	21E
0005433156756	1114	1	2B
0005434435272	1114	2	2C
0005434435282	1114	3	3A
0005434435278	1114	4	3B
0005433156720	1114	5	4A
0005434435283	1114	6	4C
0005434435276	1114	7	5A
0005434435284	1114	8	5D
0005434435281	1114	9	5C
0005433156751	1114	10	7A
0005434435277	1114	11	7B
0005434435273	1114	12	7C
0005433156752	1114	13	7D
0005433156757	1114	14	18B
0005433156738	1114	15	19C
0005433156748	1114	16	19D
0005434435286	1114	17	20B
0005434435279	1114	18	20C
0005434435274	1114	19	20D
0005434435280	1114	20	21B
0005433156721	1114	21	22A
0005434435285	1114	22	22B
0005433156737	1114	23	22C
0005434435275	1114	24	23A
0005433156750	1114	25	23B
0005433156806	17307	1	1A
0005433156805	17307	2	2A
0005433156804	17307	3	2D
0005434435137	17307	4	3B
0005434435110	17307	5	4A
0005434435109	17307	6	4B
0005433156807	17307	7	4C
0005434435072	17307	8	4D
0005434435173	17307	9	5A
0005433156808	17307	10	5B
0005434435161	17307	11	6A
0005434435193	17307	12	6B
0005434435164	17307	13	7A
0005434435133	17307	14	7B
0005433156803	17307	15	19B
0005434435134	17307	16	19C
0005434435154	17307	17	20C
0005433156801	17307	18	20D
0005434435145	17307	19	21A
0005434435132	17307	20	21B
0005434435185	17307	21	21C
0005434435146	17307	22	21D
0005433156800	17307	23	22B
0005433156802	17307	24	22C
0005434435194	17307	25	23A
0005434435165	17307	26	23B
0005435928151	4085	1	2A
0005435086880	4085	2	6B
0005435928141	4085	3	7A
0005435928142	4085	4	18B
0005435928150	4085	5	18C
0005435928143	4085	6	19A
0005435086881	4085	7	19B
0005435928127	4085	8	19C
0005435086883	4085	9	20C
0005435086884	4085	10	21A
0005435086882	4085	11	22C
0005435086885	4085	12	23A
0005435928174	24430	1	1A
0005435086771	24430	2	1B
0005435086853	24430	3	2B
0005435086818	24430	4	3C
0005435086820	24430	5	4D
0005435086798	24430	6	6C
0005435086823	24430	7	7B
0005435928173	24430	8	7D
0005435086816	24430	9	19A
0005435928175	24430	10	19D
0005435086817	24430	11	20B
0005433373521	2454	1	1A
0005435706463	2454	2	1D
0005433373513	2454	3	1F
0005435706469	2454	4	2A
0005433373490	2454	5	2C
0005435706449	2454	6	2D
0005435706493	2454	7	3C
0005435706470	2454	8	3D
0005435706460	2454	9	3F
0005435706480	2454	10	4A
0005435706466	2454	11	4C
0005435706453	2454	12	4D
0005435706477	2454	13	4E
0005433373514	2454	14	4F
0005435706482	2454	15	5A
0005433373500	2454	16	5C
0005433373528	2454	17	5D
0005433373476	2454	18	5F
0005433373520	2454	19	6A
0005435706462	2454	20	6C
0005435706478	2454	21	6D
0005433373560	2454	22	6E
0005435706465	2454	23	6F
0005433373458	2454	24	7A
0005435706455	2454	25	7C
0005433373512	2454	26	7D
0005435706474	2454	27	7E
0005435706456	2454	28	7F
0005435706481	2454	29	8A
0005435706498	2454	30	8C
0005435706450	2454	31	8D
0005433373487	2454	32	8F
0005435706497	2454	33	9A
0005435706492	2454	34	9C
0005435706483	2454	35	9D
0005435706454	2454	36	9E
0005433373488	2454	37	10A
0005433373489	2454	38	10D
0005435706491	2454	39	10E
0005433373501	2454	40	11C
0005433373525	2454	41	11D
0005435706458	2454	42	11E
0005435706461	2454	43	11F
0005433373526	2454	44	12A
0005435706471	2454	45	12D
0005435706475	2454	46	12E
0005433373559	2454	47	12F
0005435706489	2454	48	13C
0005435706476	2454	49	13D
0005435706495	2454	50	13E
0005435706467	2454	51	13F
0005433373446	2454	52	14A
0005435706490	2454	53	14C
0005433373496	2454	54	14D
0005433373504	2454	55	14E
0005433373552	2454	56	15A
0005435706459	2454	57	15C
0005433373515	2454	58	15D
0005433373503	2454	59	16A
0005435706484	2454	60	16C
0005435706494	2454	61	16D
0005435706486	2454	62	17A
0005433373477	2454	63	17C
0005435706488	2454	64	17D
0005435706472	2454	65	17E
0005435706479	2454	66	17F
0005435706485	2454	67	18A
0005433373522	2454	68	18C
0005435706457	2454	69	18D
0005435706452	2454	70	18E
0005433373475	2454	71	18F
0005433373494	2454	72	19A
0005433373516	2454	73	19C
0005435706464	2454	74	19D
0005435706496	2454	75	19E
0005435706451	2454	76	19F
0005435706468	2454	77	20A
0005433373527	2454	78	20C
0005435706473	2454	79	20D
0005435706487	2454	80	20E
0005433373502	2454	81	20F
0005435706297	27043	1	1A
0005435706315	27043	2	1C
0005433373594	27043	3	1D
0005435706347	27043	4	2D
0005433373591	27043	5	3C
0005435706311	27043	6	3F
0005433373597	27043	7	4C
0005433373573	27043	8	4D
0005433373587	27043	9	4E
0005435706384	27043	10	4F
0005435706427	27043	11	5C
0005435706404	27043	12	5D
0005433373593	27043	13	5E
0005435706351	27043	14	5F
0005433373589	27043	15	6D
0005435706428	27043	16	6E
0005435706285	27043	17	6F
0005435706340	27043	18	7A
0005435706292	27043	19	7D
0005435706379	27043	20	7E
0005435706408	27043	21	8A
0005433373575	27043	22	8C
0005435706308	27043	23	8D
0005433373596	27043	24	8E
0005433373582	27043	25	8F
0005435706310	27043	26	9A
0005435706306	27043	27	9D
0005435706334	27043	28	9E
0005435706339	27043	29	10A
0005433373581	27043	30	10C
0005435706323	27043	31	10D
0005435706269	27043	32	10E
0005433373580	27043	33	10F
0005433373584	27043	34	11C
0005435706358	27043	35	11E
0005433373574	27043	36	11F
0005433373585	27043	37	12A
0005435706426	27043	38	12C
0005433373590	27043	39	12D
0005433373577	27043	40	12E
0005435706378	27043	41	12F
0005433373592	27043	42	13C
0005435706270	27043	43	13D
0005435706369	27043	44	13E
0005435706333	27043	45	13F
0005435706268	27043	46	14A
0005435706392	27043	47	14C
0005435706391	27043	48	14D
0005433373598	27043	49	14E
0005435706350	27043	50	14F
0005435706330	27043	51	15A
0005433373576	27043	52	15C
0005435706290	27043	53	15E
0005433373588	27043	54	15F
0005435706277	27043	55	16A
0005433373572	27043	56	16E
0005435706380	27043	57	17A
0005435706385	27043	58	17C
0005433373595	27043	59	17E
0005435706393	27043	60	17F
0005435706394	27043	61	18A
0005435706356	27043	62	18F
0005435706370	27043	63	19A
0005433373586	27043	64	19C
0005433373579	27043	65	19D
0005435706291	27043	66	19E
0005435706307	27043	67	19F
0005435706327	27043	68	20A
0005433373583	27043	69	20D
0005433373578	27043	70	20E
0005435907485	4824	1	1C
0005435907503	4824	2	1A
0005433194845	4824	3	1D
0005434626021	4824	4	1F
0005433194847	4824	5	2A
0005435907481	4824	6	2C
0005435907494	4824	7	2D
0005434626020	4824	8	4D
0005433194857	4824	9	5A
0005435907514	4824	10	5D
0005433194836	4824	11	5E
0005435907506	4824	12	5F
0005434626024	4824	13	6D
0005434626019	4824	14	7F
0005435907513	4824	15	9D
0005434626022	4824	16	10C
0005434626023	4824	17	10F
0005434626026	4824	18	15A
0005434626025	4824	19	16A
0005434626018	4824	20	17A
0005435907504	4824	21	17D
0005434626017	4824	22	20A
0005433194834	4824	23	20D
0005434625936	32905	1	3D
0005435907537	32905	2	4A
0005433194874	32905	3	4C
0005435907532	32905	4	4F
0005435907535	32905	5	5F
0005433194869	32905	6	6A
0005433194863	32905	7	6F
0005434625950	32905	8	7E
0005433194870	32905	9	7F
0005434625985	32905	10	8C
0005435907533	32905	11	8E
0005433194875	32905	12	8F
0005433194868	32905	13	10E
0005433194873	32905	14	11A
0005433194866	32905	15	11C
0005434625984	32905	16	11E
0005433194871	32905	17	11F
0005434625983	32905	18	13C
0005433194864	32905	19	13F
0005434625956	32905	20	14E
0005434625942	32905	21	14F
0005434625955	32905	22	15D
0005434625943	32905	23	15E
0005433194872	32905	24	16F
0005435907534	32905	25	17A
0005433194867	32905	26	17C
0005435907536	32905	27	17E
0005434625949	32905	28	18C
0005433194862	32905	29	19F
0005433194865	32905	30	20E
0005434625940	32905	31	20F
0005435785357	13798	1	1A
0005435785306	13798	2	1C
0005435785305	13798	3	1D
0005435785352	13798	4	2A
0005435785185	13798	5	2B
0005435785159	13798	6	2C
0005435787350	13798	7	2D
0005435785257	13798	8	3A
0005435937404	13798	9	3B
0005435785192	13798	10	3C
0005435937403	13798	11	3D
0005435785272	13798	12	4B
0005435937405	13798	13	5A
0005435785358	13798	14	5B
0005435785351	13798	15	5C
0005432195706	13798	16	5D
0005435937409	13798	17	6A
0005435787343	13798	18	6B
0005435785178	13798	19	6C
0005435785209	13798	20	6D
0005432195707	13798	21	7A
0005435785175	13798	22	7C
0005432195705	13798	23	7D
0005435785291	13798	24	18A
0005435785147	13798	25	18B
0005435785184	13798	26	18D
0005435785258	13798	27	19A
0005435937402	13798	28	19B
0005435785395	13798	29	19C
0005435785190	13798	30	19D
0005435785189	13798	31	20B
0005435785311	13798	32	20C
0005435785205	13798	33	21A
0005435785292	13798	34	21B
0005435785307	13798	35	21C
0005435937406	13798	36	21D
0005435937408	13798	37	22A
0005435785206	13798	38	22B
0005435785262	13798	39	22C
0005435785237	13798	40	22D
0005435937407	13798	41	23A
0005435785271	13798	42	23B
0005435785520	27406	1	1A
0005435785517	27406	2	1B
0005435785521	27406	3	1C
0005435785531	27406	4	1D
0005435785541	27406	5	2A
0005435785519	27406	6	2B
0005432190648	27406	7	2C
0005435785512	27406	8	2D
0005435785539	27406	9	3A
0005435785514	27406	10	3B
0005435785538	27406	11	3C
0005432190650	27406	12	3D
0005435785537	27406	13	4A
0005435785508	27406	14	4B
0005435785527	27406	15	4C
0005435785511	27406	16	4D
0005435937360	27406	17	5A
0005435785528	27406	18	5B
0005435785542	27406	19	5C
0005435787365	27406	20	5D
0005435785509	27406	21	6A
0005435785530	27406	22	6B
0005435785533	27406	23	6C
0005435785526	27406	24	6D
0005435785529	27406	25	7A
0005435785518	27406	26	7C
0005435785540	27406	27	7D
0005435785524	27406	28	18B
0005432190646	27406	29	18C
0005435785534	27406	30	18D
0005435937355	27406	31	19A
0005435937361	27406	32	19B
0005432190647	27406	33	19C
0005435785507	27406	34	19D
0005432190651	27406	35	20A
0005435785510	27406	36	20B
0005435785532	27406	37	20D
0005435785535	27406	38	21A
0005435785516	27406	39	21B
0005435785523	27406	40	21C
0005435937354	27406	41	21D
0005435785513	27406	42	22A
0005435785515	27406	43	22B
0005435785525	27406	44	22C
0005432190649	27406	45	22D
0005435785536	27406	46	23A
0005435785522	27406	47	23B
0005434407576	20292	1	1A
0005434407475	20292	2	1C
0005434407760	20292	3	1D
0005434407795	20292	4	1F
0005434407691	20292	5	2C
0005435311138	20292	6	2D
0005434407594	20292	7	2F
0005434407730	20292	8	3A
0005434407536	20292	9	3C
0005434407506	20292	10	3D
0005434407581	20292	11	3F
0005434407430	20292	12	4A
0005434407755	20292	13	4C
0005434407523	20292	14	4D
0005434407836	20292	15	4E
0005434407466	20292	16	4F
0005434407790	20292	17	5A
0005434407535	20292	18	5C
0005434407788	20292	19	5D
0005434407434	20292	20	5E
0005434407399	20292	21	5F
0005434407284	20292	22	6A
0005434407285	20292	23	6C
0005434407572	20292	24	6D
0005434407166	20292	25	6F
0005434407524	20292	26	7A
0005434407690	20292	27	7C
0005434407921	20292	28	7E
0005434407367	20292	29	7F
0005434407674	20292	30	8A
0005434407985	20292	31	8C
0005434407843	20292	32	8D
0005434407329	20292	33	8E
0005434407666	20292	34	8F
0005434407507	20292	35	9A
0005434407465	20292	36	9C
0005434407612	20292	37	9D
0005434407565	20292	38	9E
0005434407645	20292	39	9F
0005434407520	20292	40	10A
0005434407764	20292	41	10D
0005434407653	20292	42	10E
0005434407734	20292	43	11A
0005434407842	20292	44	11C
0005434407812	20292	45	11D
0005434407669	20292	46	11E
0005434407750	20292	47	11F
0005434407559	20292	48	12A
0005434407283	20292	49	12C
0005434407387	20292	50	12E
0005434407660	20292	51	12F
0005434407366	20292	52	13A
0005434407464	20292	53	13C
0005434407625	20292	54	13D
0005434407735	20292	55	13E
0005434407692	20292	56	13F
0005434407435	20292	57	14A
0005434407327	20292	58	14D
0005434407505	20292	59	14E
0005434407398	20292	60	14F
0005434407282	20292	61	15A
0005434407490	20292	62	15C
0005434407326	20292	63	15D
0005434407639	20292	64	15E
0005434407901	20292	65	16A
0005434407828	20292	66	15F
0005434407665	20292	67	16C
0005432058405	20292	68	16D
0005432058408	20292	69	16E
0005434407763	20292	70	17A
0005434408036	20292	71	17C
0005434407710	20292	72	17E
0005432058407	20292	73	17F
0005434407414	20292	74	18A
0005432058406	20292	75	18C
0005434407837	20292	76	18D
0005434407789	20292	77	18E
0005434407446	20292	78	18F
0005434407386	20292	79	19A
0005434407431	20292	80	19C
0005434407325	20292	81	19D
0005434407711	20292	82	19E
0005434407696	20292	83	20A
0005434407768	20292	84	20C
0005434407723	20292	85	20D
0005434407221	20292	86	20E
0005434407429	20292	87	20F
0005434408164	26968	1	1A
0005434408188	26968	2	1C
0005432153984	26968	3	1F
0005434408153	26968	4	2A
0005434408169	26968	5	2C
0005434408183	26968	6	2D
0005434408174	26968	7	2F
0005434408167	26968	8	3C
0005434408168	26968	9	4A
0005435311036	26968	10	4C
0005434408152	26968	11	4D
0005432153980	26968	12	4E
0005434408127	26968	13	4F
0005434408161	26968	14	5C
0005434408144	26968	15	5D
0005434408150	26968	16	5E
0005434408170	26968	17	5F
0005435311013	26968	18	6A
0005434408159	26968	19	6C
0005434408133	26968	20	6D
0005434408175	26968	21	6E
0005434408149	26968	22	7A
0005434408180	26968	23	7D
0005435311034	26968	24	7E
0005434408129	26968	25	7F
0005434408148	26968	26	8A
0005432153981	26968	27	8C
0005434408156	26968	28	8D
0005434408140	26968	29	8E
0005434408178	26968	30	8F
0005434408160	26968	31	9C
0005435310988	26968	32	9E
0005434408130	26968	33	9F
0005434408158	26968	34	10A
0005434408171	26968	35	10C
0005434408137	26968	36	10E
0005434408126	26968	37	10F
0005434408157	26968	38	11A
0005434408181	26968	39	11C
0005432153983	26968	40	11D
0005434408138	26968	41	11E
0005434408151	26968	42	11F
0005434408184	26968	43	12A
0005434408142	26968	44	12C
0005434408176	26968	45	12E
0005434408141	26968	46	12F
0005435311033	26968	47	13A
0005435311029	26968	48	13C
0005434408173	26968	49	13D
0005434408146	26968	50	13E
0005434408165	26968	51	13F
0005434408143	26968	52	14A
0005434408155	26968	53	14C
0005434408162	26968	54	14D
0005435311026	26968	55	14E
0005434408179	26968	56	14F
0005434408172	26968	57	15A
0005434408135	26968	58	15C
0005434408163	26968	59	15D
0005434408166	26968	60	15E
0005434408186	26968	61	15F
0005434408134	26968	62	16A
0005434408147	26968	63	16C
0005434408139	26968	64	17C
0005434408185	26968	65	17D
0005434408177	26968	66	17E
0005434408136	26968	67	17F
0005434408182	26968	68	18A
0005434408145	26968	69	18D
0005435311035	26968	70	18F
0005435311045	26968	71	19A
0005432153982	26968	72	19C
0005434408154	26968	73	19D
0005432153979	26968	74	19E
0005435311022	26968	75	19F
0005434408132	26968	76	20C
0005434408128	26968	77	20D
0005434408131	26968	78	20E
0005434408187	26968	79	20F
0005434319502	5719	1	1A
0005434319491	5719	2	1F
0005433123862	5719	3	2A
0005433123857	5719	4	2D
0005434319497	5719	5	3D
0005433123869	5719	6	4A
0005433123892	5719	7	4C
0005433123968	5719	8	4D
0005433123977	5719	9	5A
0005433123836	5719	10	5E
0005434319501	5719	11	6A
0005434319493	5719	12	6C
0005433123903	5719	13	7C
0005434319492	5719	14	7E
0005433123880	5719	15	7F
0005434319496	5719	16	8A
0005434319499	5719	17	8D
0005434319500	5719	18	8F
0005433123913	5719	19	9C
0005434319495	5719	20	9D
0005433123976	5719	21	9E
0005433123825	5719	22	10A
0005434319488	5719	23	10E
0005433123837	5719	24	10F
0005433123860	5719	25	11F
0005433123824	5719	26	12E
0005432109720	5719	27	12F
0005433123859	5719	28	13A
0005433123803	5719	29	13F
0005434311233	5719	30	14C
0005433123904	5719	31	14E
0005433123887	5719	32	15A
0005433123879	5719	33	15C
0005433123864	5719	34	15D
0005434319494	5719	35	15E
0005434319503	5719	36	16A
0005434319490	5719	37	16C
0005434319498	5719	38	16E
0005433123896	5719	39	17E
0005433123861	5719	40	17F
0005434319489	5719	41	18A
0005433123852	5719	42	18C
0005433123898	5719	43	18D
0005433123888	5719	44	18F
0005433123893	5719	45	19A
0005432109719	5719	46	19F
0005432109721	5719	47	20A
0005433123882	5719	48	20F
0005434312309	15681	1	1C
0005434319376	15681	2	1D
0005433124062	15681	3	1F
0005434319393	15681	4	2A
0005433124071	15681	5	2C
0005434319382	15681	6	2F
0005434311213	15681	7	5E
0005434319324	15681	8	6A
0005434319374	15681	9	6C
0005434311214	15681	10	6E
0005433124067	15681	11	6F
0005433124053	15681	12	8D
0005433124052	15681	13	8E
0005433124063	15681	14	9E
0005433124068	15681	15	10C
0005433124061	15681	16	10E
0005433124072	15681	17	11A
0005433124065	15681	18	11D
0005433124060	15681	19	12C
0005434319244	15681	20	12D
0005434319375	15681	21	12E
0005433124069	15681	22	12F
0005433124058	15681	23	13E
0005433124070	15681	24	14C
0005434312310	15681	25	14D
0005434319377	15681	26	14F
0005433124057	15681	27	15C
0005433124051	15681	28	15D
0005433124055	15681	29	16C
0005434319340	15681	30	16D
0005434319323	15681	31	16E
0005433124073	15681	32	17C
0005433124059	15681	33	17D
0005433124054	15681	34	18A
0005434319367	15681	35	18D
0005433124056	15681	36	19E
0005433124066	15681	37	20A
0005434311215	15681	38	20C
0005433124064	15681	39	20F
0005435220333	31738	1	2D
0005435220331	31738	2	4A
0005435220334	31738	3	4D
0005435219215	31738	4	5A
0005435220332	31738	5	6A
0005435219212	31738	6	20A
0005435220492	31738	7	22C
0005435219214	31738	8	22D
0005435219213	31738	9	23A
0005434484387	8985	1	1B
0005434484386	8985	2	1C
0005434484392	8985	3	3C
0005434189152	8985	4	4C
0005434189176	8985	5	4D
0005434189175	8985	6	5B
0005434484393	8985	7	5C
0005434189169	8985	8	6B
0005434189173	8985	9	7A
0005434189174	8985	10	7B
0005434189167	8985	11	18A
0005434189172	8985	12	18C
0005434189168	8985	13	18D
0005434484389	8985	14	20D
0005434484388	8985	15	21B
0005434189177	8985	16	21C
0005434484391	8985	17	22D
0005434484390	8985	18	23A
0005434484304	16640	1	1A
0005434484338	16640	2	1B
0005434189215	16640	3	1D
0005434484341	16640	4	2A
0005434484351	16640	5	3C
0005434189217	16640	6	4C
0005434484346	16640	7	4D
0005434484321	16640	8	5D
0005434484342	16640	9	6A
0005434189216	16640	10	6D
0005434189214	16640	11	7A
0005434484313	16640	12	19A
0005434484306	16640	13	19B
0005434484333	16640	14	21B
0005434189213	16640	15	21C
0005434484305	16640	16	21D
0005434484320	16640	17	23A
0005434189212	16640	18	23B
0005433124069	7624	1	1D
0005433124058	7624	2	2F
0005433124064	7624	3	3C
0005433124054	7624	4	3D
0005433124072	7624	5	4C
0005433124068	7624	6	4D
0005433124063	7624	7	5F
0005433124051	7624	8	6A
0005433722189	7624	9	6E
0005433722198	7624	10	7E
0005433124067	7624	11	9E
0005433124057	7624	12	10C
0005433124062	7624	13	10F
0005433124052	7624	14	11D
0005433722177	7624	15	11F
0005433124070	7624	16	13E
0005433124073	7624	17	14A
0005433722168	7624	18	14C
0005433722190	7624	19	14D
0005433124059	7624	20	15D
0005433722188	7624	21	15F
0005433124055	7624	22	16C
0005433124061	7624	23	16F
0005433124065	7624	24	17E
0005433124056	7624	25	18A
0005433124053	7624	26	18D
0005433124066	7624	27	18E
0005433124060	7624	28	18F
0005433722197	7624	29	19A
0005433124071	7624	30	20D
0005432721062	7625	1	1A
0005432721065	7625	2	1C
0005432721064	7625	3	1D
0005432721072	7625	4	1F
0005432071592	7625	5	2A
0005432693254	7625	6	2C
0005432693276	7625	7	2F
0005433450101	7625	8	3A
0005432721071	7625	9	3D
0005432693257	7625	10	3F
0005433450109	7625	11	4A
0005433450103	7625	12	4D
0005432693269	7625	13	4E
0005432721073	7625	14	4F
0005432693272	7625	15	5A
0005433450096	7625	16	5C
0005432693262	7625	17	5D
0005432693277	7625	18	5F
0005432693270	7625	19	6A
0005432721068	7625	20	6C
0005432721085	7625	21	6E
0005433450100	7625	22	6F
0005432721076	7625	23	7A
0005432721083	7625	24	7C
0005432693271	7625	25	7D
0005432693280	7625	26	7E
0005432721060	7625	27	7F
0005432693275	7625	28	8A
0005432721069	7625	29	8C
0005433450104	7625	30	8D
0005432721066	7625	31	8E
0005433450097	7625	32	8F
0005432721061	7625	33	9A
0005432693281	7625	34	9C
0005432721074	7625	35	9D
0005432721070	7625	36	9F
0005432693264	7625	37	10A
0005433450105	7625	38	10C
0005432721079	7625	39	10E
0005432693278	7625	40	10F
0005432721080	7625	41	11A
0005433450111	7625	42	11C
0005432071591	7625	43	11E
0005433450113	7625	44	11F
0005432693279	7625	45	12A
0005432693256	7625	46	12C
0005433450108	7625	47	12D
0005432693255	7625	48	12E
0005432693261	7625	49	13A
0005432721078	7625	50	13C
0005432693253	7625	51	13D
0005432721084	7625	52	13E
0005432693259	7625	53	13F
0005433450114	7625	54	14A
0005433450110	7625	55	14C
0005433450118	7625	56	14D
0005433450106	7625	57	14E
0005432721077	7625	58	15A
0005432693263	7625	59	15C
0005432693267	7625	60	15D
0005433450099	7625	61	15E
0005432693268	7625	62	15F
0005432071593	7625	63	16C
0005433450116	7625	64	16D
0005432721081	7625	65	16E
0005432693265	7625	66	16F
0005432693284	7625	67	17A
0005433450098	7625	68	17C
0005432721063	7625	69	17D
0005432721075	7625	70	17E
0005432693282	7625	71	17F
0005433450115	7625	72	18A
0005432721082	7625	73	18C
0005433450117	7625	74	18E
0005432693258	7625	75	18F
0005433450102	7625	76	19A
0005432693266	7625	77	19C
0005432693260	7625	78	19D
0005432693273	7625	79	19E
0005432721086	7625	80	19F
0005432693283	7625	81	20A
0005432721067	7625	82	20C
0005433450107	7625	83	20D
0005433450112	7625	84	20E
0005432693274	7625	85	20F
0005432693084	30287	1	1A
0005433449981	30287	2	1C
0005433449926	30287	3	1F
0005433449880	30287	4	2A
0005432693087	30287	5	2C
0005432692931	30287	6	3C
0005433449973	30287	7	4D
0005432692978	30287	8	4F
0005433449930	30287	9	5C
0005432692907	30287	10	5D
0005433449910	30287	11	5F
0005432692981	30287	12	6D
0005432692896	30287	13	6E
0005432693057	30287	14	6F
0005432692953	30287	15	7A
0005432693088	30287	16	7D
0005433449970	30287	17	7F
0005433450005	30287	18	8A
0005432693040	30287	19	8C
0005433449969	30287	20	8D
0005432692864	30287	21	8E
0005432693001	30287	22	9F
0005432692904	30287	23	10E
0005433450002	30287	24	11C
0005432693010	30287	25	11D
0005432692960	30287	26	11E
0005432693065	30287	27	12A
0005432693060	30287	28	12C
0005433449913	30287	29	12D
0005432692971	30287	30	12E
0005432693030	30287	31	12F
0005433449909	30287	32	13C
0005432692930	30287	33	13D
0005432692970	30287	34	13E
0005433449980	30287	35	13F
0005432692979	30287	36	14C
0005432692998	30287	37	14E
0005432692977	30287	38	14D
0005432693023	30287	39	14F
0005432692909	30287	40	15A
0005432693002	30287	41	15C
0005432692773	30287	42	15E
0005433449927	30287	43	15F
0005432693041	30287	44	17A
0005432692908	30287	45	17C
0005433449929	30287	46	17E
0005433449965	30287	47	17F
0005432692952	30287	48	18C
0005433449972	30287	49	18D
0005433450001	30287	50	18F
0005432692999	30287	51	19A
0005432693025	30287	52	19C
0005432693026	30287	53	19E
0005433449908	30287	54	20D
0005432693027	30287	55	20E
0005433123977	30288	1	1F
0005432720830	30288	2	2D
0005433123879	30288	3	2F
0005432720943	30288	4	3D
0005433123880	30288	5	4A
0005433123888	30288	6	4C
0005433123836	30288	7	4D
0005432720886	30288	8	4E
0005433123857	30288	9	4F
0005432720907	30288	10	5C
0005432720711	30288	11	5D
0005433722271	30288	12	5E
0005433123824	30288	13	5F
0005432720878	30288	14	6C
0005432720816	30288	15	6E
0005432720905	30288	16	7C
0005433123803	30288	17	7D
0005433123896	30288	18	8D
0005433123837	30288	19	8E
0005433123869	30288	20	8F
0005432720747	30288	21	9A
0005433123882	30288	22	9D
0005433123861	30288	23	10A
0005432720889	30288	24	10D
0005433722270	30288	25	10E
0005433123893	30288	26	11A
0005433123968	30288	27	11E
0005433123862	30288	28	12E
0005433123903	30288	29	13D
0005433123913	30288	30	14C
0005433123825	30288	31	14E
0005433123892	30288	32	15A
0005432720874	30288	33	15C
0005432720834	30288	34	15D
0005433123887	30288	35	15E
0005432720831	30288	36	16A
0005433123859	30288	37	16D
0005432720858	30288	38	16F
0005432720823	30288	39	17A
0005432720890	30288	40	17C
0005432720829	30288	41	17D
0005433123852	30288	42	17F
0005433123904	30288	43	18A
0005432720912	30288	44	18C
0005432720822	30288	45	18D
0005432720903	30288	46	18E
0005433123898	30288	47	19C
0005432720835	30288	48	19E
0005432720906	30288	49	20A
0005433123864	30288	50	20C
0005433123976	30288	51	20E
0005433123860	30288	52	20F
0005432271023	1371	1	1A
0005434586778	1371	2	1C
0005433724831	1371	3	1D
0005433193027	1371	4	1F
0005433525102	1371	5	2C
0005434514984	1371	6	2D
0005434586777	1371	7	3C
0005433525112	1371	8	3D
0005434586772	1371	9	3F
0005433525104	1371	10	4A
0005434514985	1371	11	4C
0005432927977	1371	12	4F
0005434513595	1371	13	5C
0005434586787	1371	14	5D
0005433525106	1371	15	5E
0005434586770	1371	16	5F
0005434586775	1371	17	6C
0005433724835	1371	18	6D
0005434586774	1371	19	6E
0005434586782	1371	20	7A
0005434586766	1371	21	7C
0005434586780	1371	22	7D
0005432927962	1371	23	7E
0005434586785	1371	24	8A
0005433525110	1371	25	8D
0005432927963	1371	26	8E
0005433193000	1371	27	8F
0005434586776	1371	28	9C
0005433193057	1371	29	9D
0005434586763	1371	30	10A
0005433525105	1371	31	10D
0005433193028	1371	32	10E
0005434586788	1371	33	10F
0005433525109	1371	34	11C
0005432271022	1371	35	11D
0005432968837	1371	36	11F
0005434586781	1371	37	12A
0005433724832	1371	38	12C
0005432927961	1371	39	12D
0005434586771	1371	40	12E
0005433193029	1371	41	13A
0005433525108	1371	42	13C
0005432271021	1371	43	13D
0005434586786	1371	44	14C
0005434586768	1371	45	14E
0005434513597	1371	46	15C
0005434586764	1371	47	15D
0005434586765	1371	48	15E
0005434586783	1371	49	15F
0005433525103	1371	50	16A
0005433525111	1371	51	16C
0005432927998	1371	52	16D
0005434586779	1371	53	17A
0005433724834	1371	54	17C
0005433193059	1371	55	17D
0005434586767	1371	56	17E
0005434586769	1371	57	17F
0005432927997	1371	58	18A
0005433193018	1371	59	18D
0005434513596	1371	60	19A
0005433724833	1371	61	19C
0005434586784	1371	62	19D
0005432927960	1371	63	19E
0005433193058	1371	64	20D
0005433525107	1371	65	20E
0005434586773	1371	66	20F
0005433524995	18525	1	1A
0005434586556	18525	2	1C
0005433193133	18525	3	1F
0005432928011	18525	4	2D
0005433525009	18525	5	2F
0005434586606	18525	6	3C
0005433724804	18525	7	4C
0005433524974	18525	8	4D
0005434586594	18525	9	4F
0005434586590	18525	10	5A
0005433193136	18525	11	5C
0005432928016	18525	12	5D
0005433193126	18525	13	6C
0005434586585	18525	14	6D
0005432928015	18525	15	6E
0005433193134	18525	16	6F
0005434586558	18525	17	7C
0005433525024	18525	18	7E
0005432928013	18525	19	8A
0005433724803	18525	20	8C
0005433524979	18525	21	8D
0005433193124	18525	22	8F
0005434586544	18525	23	9A
0005433724774	18525	24	9D
0005433524993	18525	25	9E
0005434514966	18525	26	9F
0005434586545	18525	27	10F
0005433193127	18525	28	11A
0005433525015	18525	29	11D
0005433193128	18525	30	11F
0005433193135	18525	31	12E
0005433193130	18525	32	12F
0005433193129	18525	33	13A
0005434586521	18525	34	13E
0005434514968	18525	35	13F
0005433524975	18525	36	14A
0005433193137	18525	37	14C
0005434586578	18525	38	14E
0005432968853	18525	39	14F
0005432928014	18525	40	15D
0005434586557	18525	41	15F
0005434586549	18525	42	16C
0005433724805	18525	43	16D
0005434586592	18525	44	16E
0005433524991	18525	45	16F
0005434586553	18525	46	17A
0005434586484	18525	47	17C
0005432928012	18525	48	17D
0005434586548	18525	49	17E
0005432968854	18525	50	17F
0005434586512	18525	51	18A
0005434586543	18525	52	18C
0005433193132	18525	53	18D
0005433193131	18525	54	18E
0005433193125	18525	55	18F
0005433524992	18525	56	19C
0005432928017	18525	57	19D
0005434514967	18525	58	19E
0005433724816	18525	59	20A
0005434586483	18525	60	20D
0005433525010	18525	61	20E
0005433525014	18525	62	20F
0005434344436	11453	1	1A
0005434344402	11453	2	1B
0005434344399	11453	3	1C
0005434344410	11453	4	1D
0005434344431	11453	5	2A
0005434142639	11453	6	2B
0005434344421	11453	7	2C
0005434344433	11453	8	2D
0005434344434	11453	9	3A
0005434344411	11453	10	3B
0005434344412	11453	11	3C
0005434344400	11453	12	3D
0005435302188	11453	13	4A
0005434344423	11453	14	4B
0005434344419	11453	15	4D
0005434344426	11453	16	4C
0005434344414	11453	17	5A
0005435302184	11453	18	5B
0005435302167	11453	19	5C
0005434344418	11453	20	5D
0005434344408	11453	21	6A
0005434344416	11453	22	6B
0005434344422	11453	23	6C
0005434344427	11453	24	6D
0005434344401	11453	25	7A
0005434344404	11453	26	7B
0005435302164	11453	27	7C
0005434344415	11453	28	7D
0005434344405	11453	29	18A
0005434344407	11453	30	18B
0005434344429	11453	31	18C
0005434344435	11453	32	18D
0005434344413	11453	33	19A
0005435302187	11453	34	19B
0005434344406	11453	35	19C
0005434142636	11453	36	19D
0005434344417	11453	37	20A
0005434344403	11453	38	20B
0005434344424	11453	39	20C
0005434344420	11453	40	20D
0005435302183	11453	41	21A
0005434142637	11453	42	21B
0005434344432	11453	43	21C
0005435302182	11453	44	21D
0005434344428	11453	45	22A
0005434344425	11453	46	22B
0005434142635	11453	47	22C
0005434142638	11453	48	22D
0005434344430	11453	49	23A
0005434344409	11453	50	23B
0005434142607	29761	1	1A
0005434343977	29761	2	1B
0005434142604	29761	3	1C
0005434344055	29761	4	1D
0005434343969	29761	5	2A
0005434344176	29761	6	2B
0005434344034	29761	7	2C
0005434344079	29761	8	2D
0005434142605	29761	9	3A
0005434142606	29761	10	3B
0005434344167	29761	11	3C
0005434344007	29761	12	3D
0005434344134	29761	13	4A
0005434344091	29761	14	4B
0005434344056	29761	15	4C
0005434344069	29761	16	4D
0005434344114	29761	17	5A
0005434344092	29761	18	5B
0005434344181	29761	19	5C
0005434344086	29761	20	5D
0005434344029	29761	21	6A
0005434344168	29761	22	6B
0005434344084	29761	23	6C
0005434344160	29761	24	6D
0005434343928	29761	25	7A
0005434344064	29761	26	7B
0005434344163	29761	27	7C
0005434344146	29761	28	7D
0005434344141	29761	29	18A
0005434344216	29761	30	18B
0005434344148	29761	31	18C
0005434344161	29761	32	18D
0005434344008	29761	33	19A
0005434344109	29761	34	19B
0005434344001	29761	35	19C
0005434344020	29761	36	19D
0005434142603	29761	37	20A
0005434344036	29761	38	20B
0005434344143	29761	39	20C
0005434344119	29761	40	20D
0005434344144	29761	41	21A
0005434142588	29761	42	21B
0005434344215	29761	43	21C
0005434344203	29761	44	21D
0005434344147	29761	45	22A
0005435304187	29761	46	22B
0005434344035	29761	47	22C
0005434142608	29761	48	22D
0005434344090	29761	49	23A
0005434344065	29761	50	23B
0005435824806	1281	1	1A
0005435824785	1281	2	3A
0005435824805	1281	3	2F
0005435824786	1281	4	3F
0005435824788	1281	5	4C
0005433415605	1281	6	4F
0005433415673	1281	7	5A
0005435824783	1281	8	6E
0005433415558	1281	9	7A
0005435824802	1281	10	6F
0005435824807	1281	11	7C
0005435824800	1281	12	8D
0005435824801	1281	13	9B
0005432284576	1281	14	9D
0005435824790	1281	15	9C
0005435824794	1281	16	9F
0005433415622	1281	17	10B
0005435824793	1281	18	10D
0005435824799	1281	19	11C
0005435824797	1281	20	11E
0005435824808	1281	21	12A
0005435824789	1281	22	12D
0005435824809	1281	23	12E
0005435824798	1281	24	13B
0005433415587	1281	25	13A
0005432284578	1281	26	13C
0005435824803	1281	27	14C
0005435824795	1281	28	14E
0005433415668	1281	29	15A
0005435824792	1281	30	15C
0005432284577	1281	31	16B
0005433415588	1281	32	16E
0005435824791	1281	33	17B
0005433415560	1281	34	17F
0005433415559	1281	35	19C
0005435824784	1281	36	20A
0005433415632	1281	37	20B
0005435824796	1281	38	20C
0005435824787	1281	39	21A
0005435824804	1281	40	21C
0005433415631	1281	41	21B
0005435824528	17972	1	1A
0005433415760	17972	2	2D
0005433415765	17972	3	3A
0005433415754	17972	4	2F
0005435824561	17972	5	3F
0005433415767	17972	6	6B
0005435824491	17972	7	6D
0005435824517	17972	8	6C
0005435824535	17972	9	7A
0005433415768	17972	10	7C
0005433415753	17972	11	8A
0005435824661	17972	12	8C
0005435824595	17972	13	9A
0005435824710	17972	14	9C
0005433415758	17972	15	10A
0005435824605	17972	16	9F
0005435824396	17972	17	10C
0005435824610	17972	18	10F
0005435824557	17972	19	11B
0005435824465	17972	20	12C
0005435824709	17972	21	12E
0005435824466	17972	22	13A
0005435824636	17972	23	13D
0005433415762	17972	24	14A
0005435824679	17972	25	15B
0005435824569	17972	26	15C
0005433415761	17972	27	16A
0005433415759	17972	28	16D
0005433415763	17972	29	16F
0005433415766	17972	30	17A
0005435824613	17972	31	18D
0005435824562	17972	32	19C
0005435824609	17972	33	19B
0005435824594	17972	34	20A
0005433415764	17972	35	19F
0005433415755	17972	36	20D
0005435824665	17972	37	21B
0005433415757	17972	38	21A
0005433415756	17972	39	21C
0005435824587	17972	40	21E
0005435242556	5631	1	1A
0005432784151	5631	2	1C
0005435476735	5631	3	1F
0005432784126	5631	4	2A
0005432784120	5631	5	2C
0005432784108	5631	6	2D
0005432784136	5631	7	2F
0005432784155	5631	8	3A
0005432784129	5631	9	3C
0005435242777	5631	10	3F
0005435476742	5631	11	4A
0005432784114	5631	12	4E
0005432784121	5631	13	4F
0005435242796	5631	14	5A
0005432784119	5631	15	5C
0005432784118	5631	16	5D
0005432784140	5631	17	5E
0005435476681	5631	18	5F
0005432784122	5631	19	6A
0005435242705	5631	20	6C
0005432784134	5631	21	6D
0005435242642	5631	22	6E
0005435476733	5631	23	6F
0005435242731	5631	24	7A
0005432784146	5631	25	7C
0005435242841	5631	26	7D
0005435242652	5631	27	7E
0005432784138	5631	28	7F
0005432784158	5631	29	8A
0005432784159	5631	30	8C
0005432784112	5631	31	8D
0005432784124	5631	32	8E
0005432784109	5631	33	8F
0005435242848	5631	34	9A
0005432784148	5631	35	9C
0005435242784	5631	36	9D
0005432784116	5631	37	9E
0005432144008	5631	38	9F
0005432784110	5631	39	10A
0005432784123	5631	40	10C
0005435242795	5631	41	10D
0005432784128	5631	42	10E
0005432784139	5631	43	11A
0005435242693	5631	44	11D
0005435242814	5631	45	11E
0005435242741	5631	46	11F
0005432784115	5631	47	12A
0005432784133	5631	48	12C
0005435242876	5631	49	12D
0005432784157	5631	50	12E
0005432784142	5631	51	12F
0005432784117	5631	52	13A
0005432784135	5631	53	13C
0005435242707	5631	54	13D
0005435242730	5631	55	13E
0005432784152	5631	56	13F
0005432784111	5631	57	14C
0005432784147	5631	58	14D
0005435242783	5631	59	14E
0005435476741	5631	60	14F
0005432784143	5631	61	15A
0005435242729	5631	62	15C
0005432784125	5631	63	15D
0005432784131	5631	64	15E
0005432144009	5631	65	15F
0005432784130	5631	66	16A
0005432784153	5631	67	16C
0005435242813	5631	68	16D
0005432784132	5631	69	16E
0005432784149	5631	70	16F
0005432784106	5631	71	17A
0005432784107	5631	72	17C
0005432784144	5631	73	17D
0005435476734	5631	74	17E
0005435242726	5631	75	18A
0005435476726	5631	76	18C
0005435242776	5631	77	18D
0005435476752	5631	78	18E
0005432784113	5631	79	18F
0005432784127	5631	80	19A
0005432784156	5631	81	19D
0005432784154	5631	82	19C
0005435242725	5631	83	19E
0005435242817	5631	84	19F
0005432784137	5631	85	20A
0005432784141	5631	86	20C
0005435242692	5631	87	20D
0005432784150	5631	88	20E
0005432784145	5631	89	20F
0005432783739	15379	1	1A
0005432783725	15379	2	1C
0005435243014	15379	3	1D
0005432783504	15379	4	1F
0005432783366	15379	5	2A
0005432783651	15379	6	2C
0005435243001	15379	7	2D
0005432783530	15379	8	2F
0005432783475	15379	9	3A
0005432783556	15379	10	3C
0005435243015	15379	11	3D
0005435243011	15379	12	3F
0005432783414	15379	13	4A
0005432783854	15379	14	4C
0005435243009	15379	15	4D
0005432783502	15379	16	4E
0005435242995	15379	17	5A
0005432783625	15379	18	5C
0005432783496	15379	19	5E
0005432783773	15379	20	5D
0005435243006	15379	21	5F
0005432783551	15379	22	6A
0005435243000	15379	23	6C
0005432783233	15379	24	6D
0005435476794	15379	25	6E
0005435476795	15379	26	6F
0005435243002	15379	27	7A
0005435243013	15379	28	7C
0005435242997	15379	29	7D
0005435476796	15379	30	7E
0005435243016	15379	31	7F
0005432783694	15379	32	8A
0005432783763	15379	33	8C
0005435476798	15379	34	8D
0005432783673	15379	35	8E
0005432783693	15379	36	8F
0005435242999	15379	37	9A
0005432783700	15379	38	9C
0005432783497	15379	39	9D
0005432783696	15379	40	9E
0005432783577	15379	41	9F
0005435243012	15379	42	10A
0005435243005	15379	43	10D
0005432783695	15379	44	10F
0005432783324	15379	45	11A
0005432783752	15379	46	11C
0005432783762	15379	47	11D
0005435476802	15379	48	11E
0005435243017	15379	49	11F
0005432783490	15379	50	12A
0005432783323	15379	51	12C
0005435476792	15379	52	12E
0005432783634	15379	53	13A
0005432783322	15379	54	13C
0005432783671	15379	55	13D
0005435476797	15379	56	13F
0005435242994	15379	57	14A
0005432783692	15379	58	14C
0005432783798	15379	59	14D
0005435242993	15379	60	14E
0005432783922	15379	61	14F
0005435243007	15379	62	15A
0005435476793	15379	63	15C
0005432783552	15379	64	15D
0005435243018	15379	65	15E
0005435243008	15379	66	15F
0005432783656	15379	67	16A
0005435243004	15379	68	16C
0005435243003	15379	69	16D
0005432783672	15379	70	16E
0005435242996	15379	71	16F
0005435476799	15379	72	17A
0005435242991	15379	73	17C
0005432783813	15379	74	17D
0005435476801	15379	75	17E
0005435243010	15379	76	17F
0005432783505	15379	77	18C
0005435242992	15379	78	18F
0005432783557	15379	79	19C
0005435476800	15379	80	19D
0005435242998	15379	81	19E
0005432783379	15379	82	19F
0005432783578	15379	83	20A
0005432783548	15379	84	20C
0005432783503	15379	85	20F
0005435850925	4392	1	1A
0005432848406	4392	2	1B
0005432848398	4392	3	2A
0005435850912	4392	4	2B
0005432848404	4392	5	2C
0005432848401	4392	6	2D
0005432848409	4392	7	3B
0005432848397	4392	8	4B
0005434463943	4392	9	4D
0005432848405	4392	10	5A
0005435850904	4392	11	5B
0005434462804	4392	12	6A
0005432848408	4392	13	6C
0005435850913	4392	14	19B
0005432848402	4392	15	20A
0005432848403	4392	16	20B
0005435850831	4392	17	20C
0005434463942	4392	18	20D
0005432848400	4392	19	21A
0005432848399	4392	20	21B
0005435850884	4392	21	22A
0005435850914	4392	22	22C
0005432848407	4392	23	23A
0005432848410	4392	24	23B
0005434463917	28835	1	1A
0005435850971	28835	2	1B
0005435850969	28835	3	1D
0005435850965	28835	4	2B
0005432848164	28835	5	3B
0005434463916	28835	6	3D
0005435850964	28835	7	4B
0005432848308	28835	8	4D
0005432848297	28835	9	5A
0005434463929	28835	10	5B
0005432848314	28835	11	5C
0005432848258	28835	12	6A
0005432848263	28835	13	7C
0005435850966	28835	14	7B
0005435850967	28835	15	7D
0005434463921	28835	16	18A
0005432848257	28835	17	18B
0005432848284	28835	18	19C
0005435850968	28835	19	19D
0005432848262	28835	20	20A
0005435850972	28835	21	20C
0005435850970	28835	22	20D
0005432848315	28835	23	21A
0005434463915	28835	24	21B
0005432848303	28835	25	21C
0005432848259	28835	26	22A
0005434463926	28835	27	23A
0005433497178	6258	1	1A
0005434443812	6258	2	1C
0005433497160	6258	3	1D
0005433497161	6258	4	1F
0005434926019	6258	5	2A
0005433497184	6258	6	2C
0005434443807	6258	7	2D
0005433497177	6258	8	2F
0005433497156	6258	9	3A
0005434925990	6258	10	3C
0005434925999	6258	11	3D
0005434443810	6258	12	3F
0005434925991	6258	13	4A
0005433497167	6258	14	4C
0005433497166	6258	15	4E
0005433497164	6258	16	4F
0005434443809	6258	17	5A
0005434925998	6258	18	5C
0005433497158	6258	19	5D
0005433497159	6258	20	5E
0005433497182	6258	21	6A
0005434443806	6258	22	6C
0005433497162	6258	23	6D
0005433497175	6258	24	6E
0005434926022	6258	25	6F
0005433497157	6258	26	7A
0005433497180	6258	27	7C
0005434926021	6258	28	7D
0005433497179	6258	29	7F
0005433497176	6258	30	8A
0005434926010	6258	31	8C
0005433497170	6258	32	8D
0005434925993	6258	33	8E
0005434925992	6258	34	8F
0005434926008	6258	35	9A
0005434926007	6258	36	9C
0005434443808	6258	37	9D
0005434926006	6258	38	9E
0005434926015	6258	39	10A
0005433497154	6258	40	9F
0005433497165	6258	41	10C
0005434443817	6258	42	10D
0005433497185	6258	43	10E
0005434443811	6258	44	11A
0005434926002	6258	45	11C
0005433497169	6258	46	11D
0005434925997	6258	47	11E
0005434926011	6258	48	11F
0005433497163	6258	49	12A
0005434926023	6258	50	12C
0005434926001	6258	51	12D
0005434926020	6258	52	12E
0005433497172	6258	53	12F
0005433497155	6258	54	13A
0005433497168	6258	55	13D
0005434926000	6258	56	13E
0005433497183	6258	57	13F
0005434926016	6258	58	14A
0005433497173	6258	59	14C
0005434925994	6258	60	14D
0005434925989	6258	61	14E
0005433497171	6258	62	15A
0005434926013	6258	63	15C
0005433497174	6258	64	15F
0005433497181	6258	65	16A
0005434926003	6258	66	16C
0005434926024	6258	67	16E
0005434925996	6258	68	16F
0005434443816	6258	69	17A
0005434443813	6258	70	17C
0005432075252	6258	71	17D
0005434926014	6258	72	17E
0005434926004	6258	73	17F
0005434926009	6258	74	18A
0005434926005	6258	75	18C
0005434443805	6258	76	18D
0005434443814	6258	77	18E
0005434926018	6258	78	18F
0005434926025	6258	79	19A
0005434925995	6258	80	19D
0005434443815	6258	81	19E
0005432075253	6258	82	19F
0005434443818	6258	83	20A
0005434926017	6258	84	20D
0005434926012	6258	85	20E
0005434443819	6258	86	20F
0005433496905	20357	1	1A
0005434925595	20357	2	1C
0005433496954	20357	3	1D
0005434925729	20357	4	1F
0005434925740	20357	5	2A
0005433496870	20357	6	2C
0005433496977	20357	7	2D
0005434925665	20357	8	2F
0005433496882	20357	9	3A
0005434443620	20357	10	3C
0005434443619	20357	11	3D
0005433496976	20357	12	3F
0005433496943	20357	13	4A
0005434443621	20357	14	4C
0005433496899	20357	15	4D
0005434925704	20357	16	4E
0005433496896	20357	17	4F
0005433496960	20357	18	5A
0005434925735	20357	19	5C
0005433497001	20357	20	5D
0005434925741	20357	21	5E
0005434925693	20357	22	5F
0005434443662	20357	23	6A
0005433496875	20357	24	6C
0005434443610	20357	25	6D
0005434443691	20357	26	6E
0005433496982	20357	27	6F
0005434925694	20357	28	7A
0005434925541	20357	29	7C
0005434443652	20357	30	7D
0005434443613	20357	31	7F
0005433496929	20357	32	8A
0005434925544	20357	33	8C
0005433496879	20357	34	8D
0005433496911	20357	35	8E
0005434443653	20357	36	8F
0005434925624	20357	37	9C
0005434443685	20357	38	9D
0005433496959	20357	39	9E
0005434925728	20357	40	9F
0005434443618	20357	41	10A
0005433496941	20357	42	10C
0005434443686	20357	43	10D
0005434443646	20357	44	10E
0005434925677	20357	45	10F
0005434925727	20357	46	11A
0005433496874	20357	47	11C
0005433496900	20357	48	11E
0005433496981	20357	49	11F
0005433496961	20357	50	12A
0005433496909	20357	51	12C
0005434925724	20357	52	12D
0005434443642	20357	53	12E
0005434925652	20357	54	12F
0005434443612	20357	55	13A
0005434925732	20357	56	13C
0005433496942	20357	57	13E
0005434925713	20357	58	13F
0005433496978	20357	59	14A
0005434925667	20357	60	14C
0005434443640	20357	61	14E
0005433496784	20357	62	14F
0005434925580	20357	63	15A
0005434443656	20357	64	15C
0005434443661	20357	65	15D
0005433496914	20357	66	15E
0005434443664	20357	67	15F
0005433496912	20357	68	16A
0005434925625	20357	69	16C
0005433496810	20357	70	16D
0005433496940	20357	71	16E
0005434443611	20357	72	16F
0005434925721	20357	73	17A
0005434925678	20357	74	17C
0005433496956	20357	75	17E
0005433496780	20357	76	17F
0005434443682	20357	77	18A
0005434443643	20357	78	18C
0005433496797	20357	79	18D
0005434925676	20357	80	18F
0005434925540	20357	81	19A
0005433497056	20357	82	19C
0005434443715	20357	83	19E
0005434925707	20357	84	19F
0005434925685	20357	85	20C
0005434443609	20357	86	20E
0005434443736	20357	87	20F
0005435243033	12212	1	1A
0005435243022	12212	2	1C
0005432783736	12212	3	1D
0005432783766	12212	4	1F
0005432783698	12212	5	2A
0005435243036	12212	6	2C
0005432783462	12212	7	2D
0005432783614	12212	8	2F
0005432783648	12212	9	3A
0005432783709	12212	10	3C
0005432783558	12212	11	3D
0005432783611	12212	12	3F
0005435243025	12212	13	4A
0005432783606	12212	14	4C
0005432783539	12212	15	4D
0005432783610	12212	16	4E
0005432783615	12212	17	4F
0005435243038	12212	18	5A
0005432783677	12212	19	5C
0005435243021	12212	20	5D
0005435243043	12212	21	5E
0005432783697	12212	22	5F
0005432783650	12212	23	6A
0005432783802	12212	24	6C
0005435243039	12212	25	6D
0005432783354	12212	26	6E
0005432783604	12212	27	6F
0005432783602	12212	28	7A
0005435243023	12212	29	7C
0005435243040	12212	30	7D
0005435243019	12212	31	7E
0005432783814	12212	32	7F
0005435243028	12212	33	8A
0005432783619	12212	34	8C
0005432783767	12212	35	8D
0005435243037	12212	36	8E
0005432783832	12212	37	9A
0005432783601	12212	38	9C
0005432783760	12212	39	9F
0005432783600	12212	40	10A
0005432783544	12212	41	10C
0005432783674	12212	42	10D
0005432783815	12212	43	10E
0005432783593	12212	44	10F
0005432783649	12212	45	11A
0005432783665	12212	46	11C
0005432783771	12212	47	11D
0005432783605	12212	48	11E
0005432783790	12212	49	11F
0005435243045	12212	50	12A
0005432783907	12212	51	12C
0005435243026	12212	52	12D
0005435243031	12212	53	12E
0005432783720	12212	54	13A
0005432783759	12212	55	13C
0005432783747	12212	56	13D
0005432783737	12212	57	13F
0005435243032	12212	58	14A
0005432783594	12212	59	14C
0005435243035	12212	60	14D
0005432783777	12212	61	14E
0005432783670	12212	62	14F
0005432783738	12212	63	15A
0005432783733	12212	64	15D
0005432783522	12212	65	15E
0005432783532	12212	66	15F
0005435243029	12212	67	16D
0005432783451	12212	68	16E
0005432783554	12212	69	16F
0005435243027	12212	70	17A
0005432783856	12212	71	17C
0005432783452	12212	72	17D
0005435243034	12212	73	17E
0005435243044	12212	74	17F
0005432783908	12212	75	18A
0005435243041	12212	76	18C
0005432783523	12212	77	18D
0005432783710	12212	78	18F
0005432783878	12212	79	19A
0005432783816	12212	80	19C
0005432783796	12212	81	19D
0005435243020	12212	82	20A
0005432783666	12212	83	20C
0005435243042	12212	84	20D
0005435243024	12212	85	20E
0005435243030	12212	86	20F
0005432784075	15432	1	1A
0005432784071	15432	2	1D
0005432784059	15432	3	1F
0005432784050	15432	4	2A
0005432784056	15432	5	2C
0005435242807	15432	6	2D
0005432784078	15432	7	2F
0005432784095	15432	8	3A
0005432784072	15432	9	3C
0005435242755	15432	10	3D
0005432784067	15432	11	3F
0005432784084	15432	12	4A
0005432784104	15432	13	4C
0005432784079	15432	14	4D
0005435242590	15432	15	4E
0005432784097	15432	16	4F
0005432784105	15432	17	5A
0005432784077	15432	18	5C
0005432784080	15432	19	5D
0005432784065	15432	20	5E
0005432784063	15432	21	5F
0005432784099	15432	22	6A
0005432784073	15432	23	6C
0005432784092	15432	24	6F
0005432784093	15432	25	7A
0005435242799	15432	26	7D
0005435242805	15432	27	8A
0005432784066	15432	28	8C
0005432784053	15432	29	8E
0005435242757	15432	30	8F
0005432784090	15432	31	9A
0005432784100	15432	32	9C
0005432784054	15432	33	9D
0005435242744	15432	34	9F
0005435242739	15432	35	10C
0005435242710	15432	36	10D
0005435242840	15432	37	10E
0005432784069	15432	38	10F
0005435242819	15432	39	11A
0005435242740	15432	40	11C
0005432784096	15432	41	11D
0005432784098	15432	42	11E
0005432784101	15432	43	11F
0005435242818	15432	44	12A
0005435242804	15432	45	12C
0005435242735	15432	46	12D
0005432784074	15432	47	12E
0005435242704	15432	48	12F
0005432784076	15432	49	13D
0005432784070	15432	50	13E
0005432784085	15432	51	13F
0005435242831	15432	52	14A
0005435242767	15432	53	14C
0005435242700	15432	54	14D
0005432784055	15432	55	14E
0005432784094	15432	56	14F
0005435242703	15432	57	15A
0005432784060	15432	58	15D
0005435242701	15432	59	15E
0005432784089	15432	60	15F
0005432784058	15432	61	16C
0005432784088	15432	62	16D
0005435242736	15432	63	16E
0005432784081	15432	64	16F
0005432784052	15432	65	17A
0005432784061	15432	66	17C
0005435242699	15432	67	17D
0005435242832	15432	68	17E
0005432784103	15432	69	18A
0005432784091	15432	70	18C
0005432784064	15432	71	18D
0005432784068	15432	72	18E
0005432784087	15432	73	18F
0005432784051	15432	74	19A
0005435242734	15432	75	19C
0005432784083	15432	76	19D
0005432784086	15432	77	19E
0005432784102	15432	78	19F
0005435242702	15432	79	20A
0005432784057	15432	80	20C
0005432784062	15432	81	20D
0005435242758	15432	82	20E
0005432784082	15432	83	20F
0005434878286	10068	1	1C
0005434878069	10068	2	1A
0005434878204	10068	3	1D
0005434877926	10068	4	2A
0005434878091	10068	5	1F
0005434878036	10068	6	2D
0005434877959	10068	7	2C
0005434878052	10068	8	3A
0005434877955	10068	9	2F
0005434877949	10068	10	3C
0005434877997	10068	11	4A
0005434878256	10068	12	3F
0005434878019	10068	13	3D
0005434758897	10068	14	4D
0005434877916	10068	15	4C
0005434758889	10068	16	5A
0005434877644	10068	17	4F
0005434877958	10068	18	5C
0005434877840	10068	19	5F
0005434877671	10068	20	5D
0005434877940	10068	21	6B
0005434877911	10068	22	6A
0005434878095	10068	23	6D
0005434877889	10068	24	6C
0005434877968	10068	25	6E
0005434878017	10068	26	7A
0005434878025	10068	27	6F
0005434878129	10068	28	7C
0005434877654	10068	29	7B
0005434877815	10068	30	7E
0005434878183	10068	31	7D
0005434877935	10068	32	8A
0005434877813	10068	33	7F
0005434877652	10068	34	8B
0005434877996	10068	35	8D
0005434758890	10068	36	8C
0005434758884	10068	37	8F
0005434877814	10068	38	8E
0005434878046	10068	39	9A
0005434878157	10068	40	9C
0005434878300	10068	41	9B
0005434878016	10068	42	9E
0005434878066	10068	43	9D
0005434878098	10068	44	10A
0005434878064	10068	45	9F
0005434878112	10068	46	10C
0005434878299	10068	47	10B
0005434878193	10068	48	10D
0005434878065	10068	49	11A
0005434878047	10068	50	10F
0005434878094	10068	51	10E
0005434877795	10068	52	11B
0005434758896	10068	53	11D
0005434878045	10068	54	11C
0005434877180	10068	55	11E
0005434758898	10068	56	12B
0005434878130	10068	57	12A
0005434878038	10068	58	12D
0005434878186	10068	59	12C
0005434878285	10068	60	12F
0005434877455	10068	61	12E
0005434877963	10068	62	13B
0005434878111	10068	63	13A
0005434877888	10068	64	13C
0005434877934	10068	65	13E
0005434878279	10068	66	13D
0005434877590	10068	67	14A
0005434877962	10068	68	13F
0005434878253	10068	69	14B
0005434878171	10068	70	14D
0005434877998	10068	71	14C
0005434877798	10068	72	14F
0005434878059	10068	73	14E
0005434877591	10068	74	15B
0005434877770	10068	75	15A
0005434877181	10068	76	15C
0005434877927	10068	77	15E
0005434877939	10068	78	15D
0005434877938	10068	79	16A
0005434877930	10068	80	15F
0005434878106	10068	81	16C
0005434877513	10068	82	16B
0005434877925	10068	83	16E
0005434877954	10068	84	16D
0005434758891	10068	85	17A
0005434877924	10068	86	16F
0005434878101	10068	87	17C
0005434758895	10068	88	17B
0005434877846	10068	89	17D
0005434877984	10068	90	17E
0005434877891	10068	91	18A
0005434877812	10068	92	17F
0005434877970	10068	93	18D
0005434877771	10068	94	18C
0005434878093	10068	95	18B
0005434878099	10068	96	18E
0005434878260	10068	97	19A
0005434877512	10068	98	18F
0005434877912	10068	99	19C
0005434878037	10068	100	19B
0005434878137	10068	101	19D
0005434877676	10068	102	19F
0005434878136	10068	103	19E
0005434877836	10068	104	20B
0005434877946	10068	105	20D
0005434878145	10068	106	20C
0005434878118	10068	107	20F
0005434877799	10068	108	20E
0005434878252	10068	109	21A
0005434878050	10068	110	21C
0005434877887	10068	111	21B
0005434877779	10068	112	21E
0005434877835	10068	113	21D
0005434878053	10068	114	21F
0005434878845	14629	1	1C
0005434878851	14629	2	1A
0005434878773	14629	3	1F
0005434878822	14629	4	1D
0005434878792	14629	5	2C
0005434878776	14629	6	2D
0005434878815	14629	7	3A
0005434878839	14629	8	2F
0005434910107	14629	9	3D
0005434878802	14629	10	3C
0005434878861	14629	11	4A
0005434878789	14629	12	3F
0005434878794	14629	13	4C
0005434878826	14629	14	4F
0005434878781	14629	15	4D
0005434878846	14629	16	5D
0005434878827	14629	17	5C
0005434878779	14629	18	5A
0005434878820	14629	19	5F
0005434878836	14629	20	6B
0005434878806	14629	21	6A
0005435913903	14629	22	6D
0005434878787	14629	23	6C
0005434878830	14629	24	6E
0005434878767	14629	25	7A
0005434878803	14629	26	7B
0005434878807	14629	27	7E
0005434878854	14629	28	7D
0005434878837	14629	29	7F
0005434878770	14629	30	8C
0005434878850	14629	31	8B
0005434878831	14629	32	8A
0005434878771	14629	33	8D
0005434878805	14629	34	8F
0005434878813	14629	35	9B
0005434878777	14629	36	9A
0005434878823	14629	37	9D
0005434878808	14629	38	9C
0005434878844	14629	39	9E
0005434878848	14629	40	10A
0005434878798	14629	41	9F
0005434878838	14629	42	10C
0005434878772	14629	43	10B
0005434878811	14629	44	10E
0005434878790	14629	45	10D
0005434878849	14629	46	10F
0005434878821	14629	47	11B
0005434878818	14629	48	11A
0005434878856	14629	49	11D
0005434878804	14629	50	11C
0005435913915	14629	51	11F
0005434878793	14629	52	11E
0005434878833	14629	53	12B
0005434878858	14629	54	12A
0005434878814	14629	55	12D
0005434878853	14629	56	12C
0005434878788	14629	57	12F
0005434878783	14629	58	12E
0005434878817	14629	59	13A
0005434878840	14629	60	13B
0005434878801	14629	61	13E
0005434878810	14629	62	13D
0005434878780	14629	63	14A
0005434878835	14629	64	13F
0005434878828	14629	65	14B
0005434878843	14629	66	14D
0005434878799	14629	67	14F
0005434878829	14629	68	14E
0005434878855	14629	69	15A
0005434878784	14629	70	15D
0005434878769	14629	71	15C
0005434878812	14629	72	15B
0005435913909	14629	73	15E
0005434878797	14629	74	16B
0005434878791	14629	75	16A
0005434878809	14629	76	15F
0005434878785	14629	77	16C
0005435913914	14629	78	16D
0005434878795	14629	79	17A
0005434758908	14629	80	16E
0005434878825	14629	81	17C
0005434878775	14629	82	17B
0005434878860	14629	83	17D
0005434878774	14629	84	17E
0005434758907	14629	85	18B
0005434878841	14629	86	18A
0005434878816	14629	87	17F
0005434878857	14629	88	18C
0005434878847	14629	89	18E
0005434878796	14629	90	18D
0005434878824	14629	91	19A
0005434878768	14629	92	18F
0005434878852	14629	93	19B
0005434878800	14629	94	19E
0005434878832	14629	95	19D
0005434878859	14629	96	19C
0005435913904	14629	97	19F
0005435913916	14629	98	20B
0005434878782	14629	99	20D
0005434878778	14629	100	20C
0005434878819	14629	101	20F
0005434878842	14629	102	20E
0005434878834	14629	103	21A
0005434878786	14629	104	21E
0005435660210	9251	1	1C
0005435660211	9251	2	1D
0005435660206	9251	3	2B
0005435660204	9251	4	2C
0005434251903	9251	5	3A
0005434251957	9251	6	3B
0005435660209	9251	7	3D
0005434251952	9251	8	4C
0005435660205	9251	9	4D
0005434251936	9251	10	5A
0005434251971	9251	11	5B
0005434251956	9251	12	5C
0005434251932	9251	13	6B
0005434251955	9251	14	7B
0005434251967	9251	15	7C
0005434251953	9251	16	19B
0005435660208	9251	17	19C
0005435660202	9251	18	19D
0005434251935	9251	19	20B
0005435660203	9251	20	21D
0005435660207	9251	21	22A
0005434251933	9251	22	22C
0005435660212	9251	23	23A
0005435660116	24670	1	1C
0005434252028	24670	2	2A
0005435660143	24670	3	2C
0005434252024	24670	4	3C
0005435660144	24670	5	3D
0005435660148	24670	6	4B
0005435660130	24670	7	4C
0005434252023	24670	8	5A
0005435660141	24670	9	5C
0005434252027	24670	10	5D
0005435660151	24670	11	6D
0005434252026	24670	12	7A
0005435660117	24670	13	7C
0005435660095	24670	14	18D
0005434252022	24670	15	19A
0005434252025	24670	16	19B
0005434252021	24670	17	19C
0005434252019	24670	18	20D
0005435660097	24670	19	21A
0005435660096	24670	20	22A
0005434252020	24670	21	22D
0005435660140	24670	22	23B
0005433680846	2806	1	1A
0005433680851	2806	2	1C
0005433680838	2806	3	1F
0005433680874	2806	4	2A
0005433680857	2806	5	2D
0005433680872	2806	6	2F
0005433680873	2806	7	3A
0005433680871	2806	8	3C
0005432966973	2806	9	3D
0005432222812	2806	10	3F
0005432966946	2806	11	4C
0005432966831	2806	12	4D
0005432966834	2806	13	4E
0005432966899	2806	14	5A
0005432966893	2806	15	5C
0005432966833	2806	16	5D
0005433680875	2806	17	5E
0005433680849	2806	18	5F
0005433680850	2806	19	6A
0005433680860	2806	20	6C
0005433680843	2806	21	6D
0005433680877	2806	22	6E
0005433680853	2806	23	6F
0005432222813	2806	24	7A
0005433684432	2806	25	7E
0005433680866	2806	26	7F
0005432966947	2806	27	8A
0005433680848	2806	28	8C
0005432222814	2806	29	8D
0005432966814	2806	30	8E
0005433680847	2806	31	8F
0005433680845	2806	32	9A
0005433680839	2806	33	9C
0005433680844	2806	34	9D
0005432966934	2806	35	9E
0005432966823	2806	36	10A
0005433680865	2806	37	10C
0005433680842	2806	38	10D
0005432966943	2806	39	10E
0005433680878	2806	40	10F
0005433680880	2806	41	11A
0005432966867	2806	42	11C
0005433680864	2806	43	11D
0005433680861	2806	44	11E
0005433680835	2806	45	12A
0005433680834	2806	46	12C
0005432966876	2806	47	12E
0005433680840	2806	48	12F
0005432966862	2806	49	13A
0005433680841	2806	50	13C
0005432222816	2806	51	13D
0005433680855	2806	52	13E
0005433680836	2806	53	13F
0005433684431	2806	54	14A
0005433680837	2806	55	14C
0005432966813	2806	56	14D
0005433680854	2806	57	14E
0005433680869	2806	58	14F
0005433680876	2806	59	15C
0005433680858	2806	60	15D
0005432966875	2806	61	15F
0005432966849	2806	62	16A
0005433680879	2806	63	16D
0005432966858	2806	64	16C
0005433680862	2806	65	16E
0005432966807	2806	66	17A
0005432967018	2806	67	17C
0005433680870	2806	68	17D
0005433680852	2806	69	17E
0005432966881	2806	70	17F
0005433680867	2806	71	18A
0005432966922	2806	72	18C
0005433680881	2806	73	18F
0005433680856	2806	74	19A
0005432966895	2806	75	19E
0005432222815	2806	76	19F
0005433680863	2806	77	20A
0005433680859	2806	78	20C
0005432966894	2806	79	20D
0005433680868	2806	80	20E
0005433680492	29183	1	1D
0005433680347	29183	2	1F
0005433680253	29183	3	2C
0005433680775	29183	4	2D
0005432967098	29183	5	2F
0005432967094	29183	6	3C
0005433680541	29183	7	3A
0005432967092	29183	8	3D
0005433680314	29183	9	4A
0005432967097	29183	10	4C
0005433680307	29183	11	4E
0005433680513	29183	12	4F
0005433680510	29183	13	5A
0005433680560	29183	14	5C
0005432967100	29183	15	5D
0005433680499	29183	16	5E
0005433680402	29183	17	5F
0005433680631	29183	18	6A
0005432967087	29183	19	6C
0005432967090	29183	20	6E
0005432967081	29183	21	6F
0005433680292	29183	22	7D
0005432967096	29183	23	7E
0005432967085	29183	24	7F
0005432967102	29183	25	8A
0005432005230	29183	26	8C
0005433680157	29183	27	8D
0005433680568	29183	28	8E
0005433680666	29183	29	8F
0005433680256	29183	30	9C
0005432967093	29183	31	9D
0005432967101	29183	32	9F
0005433680561	29183	33	10A
0005432967089	29183	34	10C
0005433680567	29183	35	10D
0005433680537	29183	36	10E
0005432967086	29183	37	10F
0005433680474	29183	38	11A
0005432967083	29183	39	11C
0005433687690	29183	40	11F
0005432967095	29183	41	12A
0005433680572	29183	42	12C
0005432967103	29183	43	12D
0005433680436	29183	44	12E
0005433680500	29183	45	12F
0005433680664	29183	46	13A
0005433680477	29183	47	13C
0005433680291	29183	48	13D
0005433680254	29183	49	13E
0005433680573	29183	50	13F
0005432967084	29183	51	14A
0005433680637	29183	52	14D
0005432967099	29183	53	14E
0005432967104	29183	54	14F
0005432967080	29183	55	15D
0005432967105	29183	56	15C
0005433680495	29183	57	15E
0005433680536	29183	58	16C
0005433680494	29183	59	16D
0005433680509	29183	60	16F
0005432005231	29183	61	17A
0005433680725	29183	62	17C
0005433680255	29183	63	17D
0005433687691	29183	64	18C
0005433680697	29183	65	18D
0005433680475	29183	66	18E
0005433680540	29183	67	18F
0005433680665	29183	68	19C
0005433680630	29183	69	19D
0005432967091	29183	70	19E
0005432967106	29183	71	19F
0005432967082	29183	72	20A
0005432967088	29183	73	20E
0005433680290	29183	74	20F
0005434269092	9299	1	1C
0005433634004	9299	2	1D
0005433633988	9299	3	2A
0005433633993	9299	4	1F
0005434163565	9299	5	2C
0005433615056	9299	6	2F
0005434269101	9299	7	3A
0005434163611	9299	8	3D
0005433634013	9299	9	4A
0005433577888	9299	10	4C
0005433633989	9299	11	4F
0005434163603	9299	12	4D
0005433634003	9299	13	5C
0005433577894	9299	14	5F
0005433577890	9299	15	6C
0005433615106	9299	16	6F
0005433615084	9299	17	6D
0005433577886	9299	18	7D
0005433615059	9299	19	7C
0005433615102	9299	20	8A
0005433633994	9299	21	8B
0005433633997	9299	22	8C
0005433615034	9299	23	8E
0005433615099	9299	24	8D
0005433615103	9299	25	8F
0005433615067	9299	26	9B
0005433615098	9299	27	9A
0005433615040	9299	28	9C
0005432145122	9299	29	9D
0005433615047	9299	30	9E
0005433615085	9299	31	10A
0005433615048	9299	32	9F
0005433615045	9299	33	10B
0005433577882	9299	34	10D
0005433615071	9299	35	10E
0005433634010	9299	36	11B
0005433634014	9299	37	11A
0005433615064	9299	38	11C
0005433633996	9299	39	11D
0005433615065	9299	40	11E
0005433634009	9299	41	12A
0005433615080	9299	42	12B
0005433615038	9299	43	12D
0005433633983	9299	44	12C
0005434163605	9299	45	12F
0005433577893	9299	46	13A
0005434163612	9299	47	13C
0005433615073	9299	48	13B
0005433615052	9299	49	13D
0005433633991	9299	50	13E
0005434272183	9299	51	14A
0005433615046	9299	52	13F
0005432756866	9299	53	14B
0005433633987	9299	54	14C
0005432755096	9299	55	14E
0005433615043	9299	56	14D
0005433577883	9299	57	14F
0005433615042	9299	58	15B
0005433615101	9299	59	15A
0005433634002	9299	60	15C
0005433615037	9299	61	15D
0005433615089	9299	62	15E
0005433615036	9299	63	16A
0005433615095	9299	64	15F
0005433615070	9299	65	16B
0005432755094	9299	66	16D
0005433634011	9299	67	16E
0005433615082	9299	68	17B
0005433615083	9299	69	17C
0005433615041	9299	70	17E
0005433633992	9299	71	17D
0005433634008	9299	72	17F
0005433634000	9299	73	18A
0005433633984	9299	74	18B
0005433633985	9299	75	18D
0005433615075	9299	76	18E
0005433615057	9299	77	19B
0005433615044	9299	78	18F
0005433633986	9299	79	19D
0005433615104	9299	80	19C
0005433615088	9299	81	19E
0005433615100	9299	82	20B
0005432756868	9299	83	20A
0005432755095	9299	84	20C
0005433633995	9299	85	20E
0005433634012	9299	86	20D
0005433577895	9299	87	20F
0005432756867	9299	88	21A
0005433615096	9299	89	21C
0005433615093	9299	90	21B
0005433633982	9299	91	21E
0005433615078	9299	92	21F
0005434163597	9299	93	22B
0005433615058	9299	94	22A
0005433577891	9299	95	22C
0005433615090	9299	96	22F
0005433615035	9299	97	22E
0005433615066	9299	98	23C
0005433615074	9299	99	23D
0005433615097	9299	100	23F
0005433615092	9299	101	24A
0005433615039	9299	102	24B
0005434163587	9299	103	24C
0005433634006	9299	104	24E
0005434163602	9299	105	24D
0005433615055	9299	106	24F
0005433615072	9299	107	25A
0005433615060	9299	108	25C
0005433615053	9299	109	25D
0005433633990	9299	110	25E
0005433615068	9299	111	26A
0005434163598	9299	112	25F
0005433633999	9299	113	26C
0005433577892	9299	114	26D
0005433615076	9299	115	26F
0005433577884	9299	116	26E
0005433615063	9299	117	27B
0005433634007	9299	118	27A
0005433615079	9299	119	27C
0005433577887	9299	120	27E
0005433615061	9299	121	27D
0005433615051	9299	122	27F
0005433615094	9299	123	28A
0005433615049	9299	124	28B
0005433615081	9299	125	28C
0005433615086	9299	126	28E
0005433615069	9299	127	28F
0005433634001	9299	128	29A
0005433615087	9299	129	29C
0005433615054	9299	130	29B
0005433577889	9299	131	29D
0005433634005	9299	132	29E
0005433615062	9299	133	29F
0005433615107	9299	134	30B
0005433634015	9299	135	30A
0005433615105	9299	136	30D
0005433577885	9299	137	30C
0005433615077	9299	138	30E
0005433633998	9299	139	31C
0005433615050	9299	140	31B
0005434163604	9299	141	31D
0005433615091	9299	142	31F
0005434153527	9299	143	31E
0005434272199	25248	1	1D
0005434163665	25248	2	1C
0005433614100	25248	3	1A
0005433614289	25248	4	1F
0005433633539	25248	5	2C
0005433633860	25248	6	2A
0005433633821	25248	7	3A
0005433577727	25248	8	2F
0005433577785	25248	9	3C
0005433577749	25248	10	3D
0005433633746	25248	11	4A
0005433614363	25248	12	3F
0005433577740	25248	13	4C
0005433577798	25248	14	4D
0005433614501	25248	15	5C
0005433577801	25248	16	5D
0005433614338	25248	17	6A
0005433614275	25248	18	5F
0005433614237	25248	19	6C
0005433577756	25248	20	6D
0005434273084	25248	21	7A
0005433614327	25248	22	6F
0005433614642	25248	23	7C
0005434163659	25248	24	7F
0005433614425	25248	25	7D
0005433614225	25248	26	8C
0005433614183	25248	27	8B
0005433614463	25248	28	8D
0005433633666	25248	29	8E
0005434163663	25248	30	9A
0005433633584	25248	31	9C
0005433577787	25248	32	9D
0005433614333	25248	33	9E
0005433577739	25248	34	10A
0005433614286	25248	35	9F
0005433614562	25248	36	10C
0005433633783	25248	37	10B
0005433577732	25248	38	10E
0005434163669	25248	39	10F
0005433614374	25248	40	11C
0005433577789	25248	41	11D
0005433633761	25248	42	12A
0005434163668	25248	43	11F
0005433577737	25248	44	12B
0005433577800	25248	45	12C
0005433633606	25248	46	12D
0005433614161	25248	47	12F
0005433614641	25248	48	13A
0005433614603	25248	49	13C
0005434163664	25248	50	13D
0005433614539	25248	51	13E
0005433577674	25248	52	13F
0005433633602	25248	53	14B
0005435854061	25248	54	14E
0005433614498	25248	55	14D
0005433614307	25248	56	14F
0005433633859	25248	57	15A
0005433614387	25248	58	15B
0005433614381	25248	59	15D
0005433614653	25248	60	15F
0005433614326	25248	61	15E
0005433577758	25248	62	16A
0005433614224	25248	63	16B
0005433614389	25248	64	17A
0005433614494	25248	65	17C
0005433577682	25248	66	17D
0005434163666	25248	67	17E
0005433614619	25248	68	18A
0005433614305	25248	69	17F
0005433633864	25248	70	18B
0005433633671	25248	71	18C
0005433633622	25248	72	18E
0005433614412	25248	73	18D
0005433633400	25248	74	18F
0005433633679	25248	75	19B
0005433614415	25248	76	19C
0005433633695	25248	77	19E
0005435854062	25248	78	20A
0005433614443	25248	79	20C
0005433633570	25248	80	20B
0005433614328	25248	81	20D
0005434163660	25248	82	20F
0005433614421	25248	83	21A
0005433633605	25248	84	21C
0005433633734	25248	85	21D
0005433614496	25248	86	21E
0005433614375	25248	87	21F
0005433577761	25248	88	22C
0005433633749	25248	89	22E
0005433614515	25248	90	22D
0005434273085	25248	91	22F
0005433614288	25248	92	23B
0005433614332	25248	93	23D
0005433614652	25248	94	23E
0005433577786	25248	95	23F
0005433614236	25248	96	24B
0005433614301	25248	97	24A
0005433577759	25248	98	24C
0005433633577	25248	99	24E
0005433614382	25248	100	24D
0005433614433	25248	101	24F
0005433614618	25248	102	25B
0005433577728	25248	103	25C
0005433577733	25248	104	25F
0005433633747	25248	105	26B
0005433614287	25248	106	26D
0005433633861	25248	107	26F
0005433614495	25248	108	27A
0005433577738	25248	109	27C
0005433633603	25248	110	27B
0005433577821	25248	111	27E
0005433614462	25248	112	27D
0005433614582	25248	113	28A
0005433577763	25248	114	27F
0005433614424	25248	115	28D
0005433614497	25248	116	28C
0005434163661	25248	117	28F
0005433633743	25248	118	29B
0005434272200	25248	119	29A
0005433633782	25248	120	29C
0005434163667	25248	121	29D
0005433614383	25248	122	29E
0005433577762	25248	123	30B
0005434163662	25248	124	30D
0005433577752	25248	125	30C
0005433614388	25248	126	30E
0005433614397	25248	127	30F
0005433614019	25248	128	31A
0005433577751	25248	129	31C
0005433633769	25248	130	31B
0005433633651	25248	131	31D
0005433614101	25248	132	31F
0005435856170	4218	1	1A
0005435947189	4218	2	1C
0005434271302	4218	3	4C
0005435947249	4218	4	5C
0005435947252	4218	5	11A
0005435856174	4218	6	11G
0005432571318	4218	7	12G
0005435787351	4218	8	12H
0005435986800	4218	9	13E
0005435856190	4218	10	15B
0005435856175	4218	11	16G
0005435947202	4218	12	16H
0005435947250	4218	13	18B
0005434271307	4218	14	19A
0005435856193	4218	15	19E
0005435787327	4218	16	20A
0005435856192	4218	17	20G
0005434271303	4218	18	21A
0005435787352	4218	19	21F
0005432571319	4218	20	22E
0005432571321	4218	21	23D
0005432184967	4218	22	24G
0005435947224	4218	23	25F
0005435947263	4218	24	28D
0005435787337	4218	25	28E
0005432571320	4218	26	30B
0005432571297	4218	27	32A
0005435947248	4218	28	32H
0005432571317	4218	29	33B
0005435947179	4218	30	33E
0005435787353	4218	31	33G
0005435787336	4218	32	34A
0005432184969	4218	33	35B
0005432184968	4218	34	35G
0005435787341	4218	35	36G
0005435856231	26575	1	1C
0005432571346	26575	2	2A
0005435986720	26575	3	2G
0005435986719	26575	4	3C
0005435947351	26575	5	11B
0005435947344	26575	6	11H
0005435986739	26575	7	12E
0005432571350	26575	8	12H
0005435947352	26575	9	13F
0005435947345	26575	10	14F
0005435947353	26575	11	15F
0005432571349	26575	12	15G
0005435856230	26575	13	16E
0005435947350	26575	14	17B
0005435787370	26575	15	17H
0005435947348	26575	16	18F
0005435856229	26575	17	19D
0005435986726	26575	18	21H
0005432571348	26575	19	22B
0005435856232	26575	20	22H
0005435787368	26575	21	23G
0005435947346	26575	22	24B
0005435947347	26575	23	24A
0005432571347	26575	24	28G
0005435986717	26575	25	29H
0005435787369	26575	26	30F
0005435947349	26575	27	31B
0005435947340	26575	28	32B
0005435986716	26575	29	34B
0005435947342	26575	30	36A
0005435947341	26575	31	37D
0005435947343	26575	32	38D
0005433074778	355	1	1A
0005433569438	355	2	1C
0005433129259	355	3	1F
0005433074584	355	4	1D
0005433074555	355	5	2C
0005433569447	355	6	2A
0005432948421	355	7	2F
0005432948328	355	8	2D
0005432948305	355	9	3A
0005433074601	355	10	3D
0005432948258	355	11	3C
0005432948386	355	12	3F
0005433569455	355	13	4A
0005433129267	355	14	4C
0005432948479	355	15	4F
0005433074635	355	16	5C
0005432948320	355	17	5A
0005432948377	355	18	5D
0005433569468	355	19	6A
0005432948215	355	20	5F
0005433074591	355	21	6C
0005433074659	355	22	7A
0005433074560	355	23	7C
0005433074690	355	24	7F
0005433074636	355	25	7D
0005433074644	355	26	8B
0005432948399	355	27	8D
0005433569434	355	28	8C
0005432948380	355	29	8E
0005433134127	355	30	9A
0005433569461	355	31	8F
0005432948388	355	32	9B
0005432238979	355	33	9C
0005433569462	355	34	9D
0005433134128	355	35	9F
0005433569444	355	36	10A
0005432948433	355	37	10C
0005432948295	355	38	10B
0005433134115	355	39	10D
0005432948331	355	40	10F
0005433569436	355	41	11B
0005433569432	355	42	11A
0005432948332	355	43	11C
0005433569457	355	44	11D
0005432948460	355	45	11E
0005433569454	355	46	12A
0005433569456	355	47	11F
0005432948488	355	48	12B
0005432238974	355	49	12D
0005433569431	355	50	12C
0005433569453	355	51	12E
0005433074799	355	52	13A
0005433569460	355	53	12F
0005433569445	355	54	13C
0005432948214	355	55	13B
0005432948304	355	56	13D
0005433569459	355	57	13E
0005433129242	355	58	13F
0005432948201	355	59	14B
0005432948239	355	60	14C
0005432948303	355	61	14E
0005433129263	355	62	15B
0005433569463	355	63	15A
0005432948327	355	64	15C
0005433074585	355	65	15D
0005433569446	355	66	16A
0005433074614	355	67	15F
0005433569442	355	68	16C
0005433129283	355	69	16B
0005432948251	355	70	16E
0005433074576	355	71	16D
0005433569469	355	72	17A
0005433569443	355	73	17B
0005432948469	355	74	17C
0005432948323	355	75	17E
0005433569471	355	76	17D
0005432948486	355	77	17F
0005432948324	355	78	18A
0005432948362	355	79	18B
0005433569441	355	80	18D
0005433074495	355	81	18C
0005433074564	355	82	18E
0005433074738	355	83	18F
0005432948487	355	84	19C
0005433569470	355	85	19B
0005433569439	355	86	19D
0005432948287	355	87	20A
0005433129241	355	88	20B
0005433074577	355	89	20C
0005433074454	355	90	20E
0005433569448	355	91	20D
0005432948361	355	92	21B
0005432948325	355	93	21A
0005432948403	355	94	21C
0005433134122	355	95	21D
0005432948517	355	96	21E
0005433074727	355	97	22A
0005433569449	355	98	21F
0005433074615	355	99	22B
0005432948276	355	100	22C
0005433129282	355	101	22D
0005433569435	355	102	22F
0005432948302	355	103	23A
0005432948404	355	104	23B
0005432948189	355	105	23D
0005433074496	355	106	23C
0005433569452	355	107	23E
0005432238976	355	108	23F
0005432948252	355	109	24B
0005432948200	355	110	24D
0005432948319	355	111	24C
0005433569440	355	112	24F
0005433569450	355	113	24E
0005433569467	355	114	25B
0005433569466	355	115	25A
0005432948199	355	116	25C
0005433074561	355	117	25D
0005432238978	355	118	25F
0005433074647	355	119	25E
0005433074632	355	120	26A
0005432948307	355	121	26B
0005432948257	355	122	26D
0005433074800	355	123	26C
0005432948277	355	124	26E
0005433074737	355	125	26F
0005433569465	355	126	27B
0005433129258	355	127	27A
0005432238973	355	128	27D
0005433569430	355	129	27C
0005433569433	355	130	27E
0005432948398	355	131	27F
0005433134114	355	132	28B
0005433569464	355	133	28A
0005433569437	355	134	28C
0005433074658	355	135	28E
0005432948387	355	136	28D
0005432948278	355	137	29A
0005433074648	355	138	28F
0005432948333	355	139	29B
0005432238975	355	140	29C
0005433129257	355	141	29E
0005433569451	355	142	29D
0005433569428	355	143	29F
0005432948354	355	144	30B
0005432948438	355	145	30A
0005433134116	355	146	30C
0005432238977	355	147	30E
0005432948440	355	148	30D
0005433134107	355	149	31A
0005433074646	355	150	30F
0005432948439	355	151	31C
0005433569458	355	152	31B
0005433074736	355	153	31D
0005433569429	355	154	31F
0005433074728	355	155	31E
0005433568804	11596	1	1C
0005433568696	11596	2	1A
0005433568815	11596	3	1F
0005432948721	11596	4	1D
0005433568778	11596	5	2A
0005433131737	11596	6	2C
0005433568871	11596	7	2D
0005433074893	11596	8	3A
0005433568795	11596	9	2F
0005432948683	11596	10	3C
0005432948691	11596	11	3F
0005433074894	11596	12	3D
0005433134164	11596	13	4A
0005432948704	11596	14	4F
0005433568792	11596	15	4D
0005433568797	11596	16	5A
0005433568625	11596	17	5C
0005433074867	11596	18	5D
0005433074884	11596	19	6A
0005433568849	11596	20	6C
0005433074878	11596	21	6F
0005433568684	11596	22	7C
0005433568920	11596	23	7F
0005433568817	11596	24	7D
0005433568850	11596	25	8A
0005432948710	11596	26	8B
0005433568710	11596	27	8E
0005433568711	11596	28	8D
0005433568673	11596	29	8F
0005433131735	11596	30	9A
0005433134167	11596	31	9C
0005433074871	11596	32	9E
0005433074868	11596	33	9D
0005433074888	11596	34	9F
0005433074876	11596	35	10A
0005433074887	11596	36	10C
0005432192339	11596	37	10B
0005433074886	11596	38	11A
0005432192338	11596	39	10F
0005433568622	11596	40	10E
0005432948693	11596	41	11B
0005433568798	11596	42	11D
0005433074869	11596	43	11C
0005432948711	11596	44	11F
0005433074880	11596	45	11E
0005433568720	11596	46	12A
0005433568640	11596	47	12C
0005433568860	11596	48	12B
0005432948688	11596	49	12E
0005433568909	11596	50	12D
0005433568800	11596	51	12F
0005433568627	11596	52	13B
0005433568741	11596	53	13A
0005432192340	11596	54	13C
0005432948718	11596	55	13E
0005433074870	11596	56	14A
0005433568584	11596	57	13F
0005433568803	11596	58	14B
0005432948696	11596	59	14C
0005432948714	11596	60	14E
0005433568626	11596	61	14D
0005433134166	11596	62	15A
0005433568818	11596	63	15B
0005433568655	11596	64	15C
0005433568491	11596	65	15D
0005433074883	11596	66	15E
0005433131736	11596	67	16A
0005433568866	11596	68	16C
0005433568744	11596	69	16B
0005432948684	11596	70	16E
0005433074885	11596	71	17A
0005433568887	11596	72	17C
0005433074873	11596	73	17B
0005432948690	11596	74	17D
0005433131734	11596	75	17E
0005432948712	11596	76	18A
0005432948707	11596	77	17F
0005433568639	11596	78	18C
0005433568459	11596	79	18B
0005433568747	11596	80	18D
0005432948685	11596	81	18E
0005433568656	11596	82	19B
0005433568910	11596	83	19C
0005432948713	11596	84	19D
0005433074872	11596	85	19E
0005433134165	11596	86	20B
0005432948720	11596	87	20A
0005432948697	11596	88	20C
0005432948705	11596	89	20E
0005433568704	11596	90	20F
0005433568659	11596	91	21B
0005433131738	11596	92	21D
0005433568777	11596	93	22A
0005433568827	11596	94	21F
0005432948703	11596	95	22B
0005432948701	11596	96	22C
0005433074877	11596	97	22D
0005432948717	11596	98	22F
0005432948719	11596	99	22E
0005433074875	11596	100	23B
0005433568791	11596	101	23A
0005433074882	11596	102	23C
0005433074889	11596	103	23D
0005433134168	11596	104	23E
0005433074896	11596	105	24A
0005433568761	11596	106	23F
0005432948687	11596	107	24B
0005432948709	11596	108	24D
0005432948695	11596	109	24C
0005432948694	11596	110	24F
0005433568669	11596	111	24E
0005433568870	11596	112	25A
0005433568722	11596	113	25C
0005433568888	11596	114	25D
0005433568779	11596	115	25E
0005433568760	11596	116	25F
0005432948689	11596	117	26B
0005433568742	11596	118	26A
0005432948700	11596	119	26D
0005433568806	11596	120	26C
0005433568689	11596	121	26F
0005432948686	11596	122	27B
0005432948681	11596	123	27A
0005432948699	11596	124	27C
0005433568748	11596	125	27F
0005432948715	11596	126	27E
0005432948708	11596	127	28A
0005433074881	11596	128	28B
0005433074874	11596	129	28C
0005432948722	11596	130	28E
0005432948702	11596	131	28D
0005433568714	11596	132	28F
0005433074879	11596	133	29B
0005433074895	11596	134	29A
0005432948692	11596	135	29D
0005432948706	11596	136	29E
0005432948682	11596	137	30A
0005433568833	11596	138	30B
0005433568816	11596	139	30D
0005433074891	11596	140	30C
0005433074890	11596	141	30F
0005433568719	11596	142	30E
0005432948716	11596	143	31A
0005433074892	11596	144	31E
0005433568762	11596	145	31D
0005432948698	11596	146	31F
0005433817493	10007	1	3A
0005433817492	10007	2	4B
0005433817494	10007	3	5A
0005433817495	10007	4	5B
0005433817448	13895	1	1B
0005434733004	13895	2	2B
0005434733003	13895	3	3A
0005434733001	13895	4	3B
0005433817464	13895	5	4A
0005434733002	13895	6	6A
0005433817467	13895	7	6B
0005435982590	2346	1	1A
0005433434645	2346	2	1B
0005433754553	2346	3	1H
0005432984909	2346	4	2A
0005433754558	2346	5	2C
0005433434615	2346	6	2B
0005432985111	2346	7	2F
0005433754591	2346	8	2G
0005432985037	2346	9	3A
0005435982605	2346	10	2H
0005435982597	2346	11	3B
0005435982606	2346	12	3C
0005432985130	2346	13	3G
0005435982609	2346	14	4A
0005433754564	2346	15	4C
0005435982603	2346	16	4B
0005433434600	2346	17	4G
0005433754569	2346	18	5A
0005435982598	2346	19	4H
0005432985025	2346	20	5B
0005435982574	2346	21	5C
0005432655618	2346	22	5G
0005432985122	2346	23	5F
0005433764693	2346	24	5H
0005432985126	2346	25	9B
0005433434520	2346	26	9G
0005433754593	2346	27	11A
0005435982610	2346	28	9H
0005432869516	2346	29	11B
0005433434669	2346	30	11D
0005433434601	2346	31	11F
0005433754599	2346	32	11H
0005435982594	2346	33	11G
0005435982615	2346	34	12A
0005433754567	2346	35	12D
0005433434608	2346	36	12E
0005432300301	2346	37	12F
0005432984780	2346	38	12H
0005433434476	2346	39	12G
0005433434577	2346	40	13A
0005435982602	2346	41	13D
0005435982593	2346	42	13F
0005434731156	2346	43	13E
0005432655614	2346	44	13G
0005433434666	2346	45	14A
0005432985125	2346	46	13H
0005435982572	2346	47	14B
0005435982580	2346	48	14D
0005435982595	2346	49	14F
0005433434474	2346	50	14E
0005434731159	2346	51	14G
0005432985043	2346	52	15A
0005432985078	2346	53	15D
0005433754552	2346	54	15B
0005433434496	2346	55	15F
0005432655612	2346	56	15E
0005433754582	2346	57	15H
0005433434719	2346	58	16B
0005433754556	2346	59	16E
0005432985121	2346	60	16D
0005432985100	2346	61	16G
0005433754600	2346	62	16F
0005435982607	2346	63	16H
0005432300302	2346	64	17A
0005433434617	2346	65	17D
0005435982577	2346	66	17B
0005435982589	2346	67	17F
0005435982579	2346	68	17G
0005432985129	2346	69	17H
0005432226098	2346	70	18B
0005433754549	2346	71	18A
0005433754560	2346	72	18D
0005432985092	2346	73	18F
0005433434495	2346	74	18E
0005432985079	2346	75	19A
0005433434686	2346	76	19B
0005435982611	2346	77	19D
0005433754583	2346	78	19F
0005433754576	2346	79	19E
0005434731144	2346	80	19G
0005435982617	2346	81	20A
0005433754566	2346	82	19H
0005433766665	2346	83	20B
0005435982618	2346	84	20D
0005432984966	2346	85	20F
0005432985044	2346	86	20E
0005433434542	2346	87	20H
0005432985036	2346	88	20G
0005433754581	2346	89	21A
0005432985024	2346	90	21D
0005435982619	2346	91	21B
0005432655610	2346	92	21E
0005432226097	2346	93	21F
0005432985131	2346	94	21H
0005433754559	2346	95	21G
0005433754568	2346	96	22B
0005435982600	2346	97	22A
0005432300300	2346	98	22D
0005433754589	2346	99	22E
0005433434578	2346	100	22G
0005432226096	2346	101	22F
0005435982571	2346	102	22H
0005435982601	2346	103	23B
0005432984910	2346	104	23A
0005435982612	2346	105	23E
0005432655615	2346	106	23D
0005433754565	2346	107	23F
0005435982604	2346	108	23G
0005433434703	2346	109	23H
0005433754551	2346	110	24B
0005434731137	2346	111	24A
0005433754585	2346	112	24D
0005435982578	2346	113	24E
0005435982614	2346	114	24G
0005432984779	2346	115	25D
0005433754580	2346	116	24H
0005435982581	2346	117	27A
0005435982576	2346	118	25F
0005433754555	2346	119	27B
0005433754579	2346	120	27D
0005435982591	2346	121	27F
0005435982584	2346	122	27E
0005435982599	2346	123	27G
0005433754571	2346	124	28A
0005433434718	2346	125	27H
0005432655609	2346	126	28D
0005433766662	2346	127	28B
0005435982586	2346	128	28F
0005435982608	2346	129	28E
0005432300298	2346	130	28G
0005435982592	2346	131	29A
0005433754557	2346	132	28H
0005433754584	2346	133	29F
0005433754601	2346	134	29E
0005433434665	2346	135	29D
0005433434475	2346	136	29G
0005433754573	2346	137	29H
0005432226094	2346	138	30B
0005432984959	2346	139	30D
0005433754546	2346	140	30F
0005433754598	2346	141	30E
0005433754596	2346	142	30G
0005433754586	2346	143	31A
0005435982585	2346	144	30H
0005433754574	2346	145	31B
0005433754590	2346	146	31E
0005432655613	2346	147	31D
0005432226095	2346	148	31F
0005434731143	2346	149	31H
0005433754578	2346	150	31G
0005433766664	2346	151	32A
0005432300299	2346	152	32D
0005435982583	2346	153	32E
0005433754587	2346	154	32F
0005435982616	2346	155	32H
0005433434560	2346	156	33A
0005433754577	2346	157	33B
0005432869506	2346	158	33E
0005433754547	2346	159	33D
0005432984919	2346	160	33F
0005432655611	2346	161	33G
0005435982587	2346	162	34D
0005432300297	2346	163	34B
0005432985005	2346	164	34F
0005433754588	2346	165	34E
0005435982575	2346	166	34G
0005433754572	2346	167	34H
0005435982588	2346	168	35B
0005433766663	2346	169	35A
0005434731152	2346	170	35E
0005433764692	2346	171	35D
0005433754554	2346	172	35H
0005433754548	2346	173	35G
0005433754575	2346	174	35F
0005433754561	2346	175	36B
0005432984949	2346	176	36E
0005433754550	2346	177	36D
0005433434525	2346	178	36F
0005435982613	2346	179	36H
0005435982582	2346	180	36G
0005435982573	2346	181	37D
0005433754594	2346	182	37B
0005432655617	2346	183	37A
0005434731158	2346	184	37E
0005433754592	2346	185	37G
0005432869505	2346	186	37F
0005432655607	2346	187	37H
0005432985006	2346	188	38B
0005435982596	2346	189	38A
0005432655616	2346	190	38D
0005433754562	2346	191	38E
0005432655608	2346	192	38F
0005433754570	2346	193	38H
0005433754597	2346	194	38G
0005433754595	2346	195	39F
0005433754563	2346	196	39E
0005432655497	26158	1	1A
0005433753862	26158	2	1B
0005432985281	26158	3	1F
0005433434870	26158	4	1C
0005432985267	26158	5	1G
0005432985291	26158	6	2A
0005433434861	26158	7	1H
0005432869565	26158	8	2B
0005432869567	26158	9	2F
0005435982093	26158	10	2G
0005435982181	26158	11	3A
0005435982214	26158	12	2H
0005433754145	26158	13	3C
0005432985283	26158	14	3B
0005432985286	26158	15	3G
0005432985275	26158	16	3F
0005435982237	26158	17	3H
0005432655518	26158	18	4B
0005432985270	26158	19	4A
0005433434860	26158	20	4F
0005433766620	26158	21	4C
0005433753909	26158	22	4G
0005433754205	26158	23	4H
0005433434851	26158	24	5B
0005433754137	26158	25	5A
0005433434866	26158	26	5C
0005432655517	26158	27	5F
0005433434862	26158	28	9A
0005432051147	26158	29	5H
0005432985288	26158	30	9B
0005434731197	26158	31	9G
0005432049487	26158	32	11A
0005433434846	26158	33	9H
0005433754239	26158	34	11B
0005435982238	26158	35	11D
0005432655505	26158	36	11F
0005435982130	26158	37	11E
0005435982182	26158	38	11G
0005433434859	26158	39	12A
0005433434854	26158	40	11H
0005435982073	26158	41	12B
0005433434843	26158	42	12E
0005433753806	26158	43	12D
0005432985266	26158	44	12F
0005433753807	26158	45	12G
0005432051148	26158	46	13A
0005433754086	26158	47	13D
0005433753958	26158	48	13B
0005432985295	26158	49	13F
0005432985278	26158	50	13E
0005435982281	26158	51	13H
0005432051149	26158	52	14B
0005432985289	26158	53	14A
0005433434848	26158	54	14D
0005435982075	26158	55	14E
0005432985293	26158	56	14G
0005435982101	26158	57	14F
0005433434855	26158	58	15A
0005432985282	26158	59	14H
0005432655498	26158	60	15B
0005435982282	26158	61	15E
0005435982157	26158	62	15D
0005433766631	26158	63	15G
0005432985284	26158	64	15F
0005433754079	26158	65	16E
0005433754155	26158	66	16D
0005435982269	26158	67	16F
0005432985274	26158	68	16H
0005433753965	26158	69	16G
0005434731199	26158	70	17A
0005432655493	26158	71	17D
0005435982127	26158	72	17B
0005432655447	26158	73	17E
0005435982125	26158	74	17G
0005433434857	26158	75	17F
0005433753918	26158	76	17H
0005435982098	26158	77	18A
0005432985287	26158	78	18E
0005435982090	26158	79	18F
0005432985268	26158	80	18G
0005435982225	26158	81	19A
0005433753959	26158	82	18H
0005433434842	26158	83	19B
0005433754261	26158	84	19E
0005433754154	26158	85	19D
0005432985280	26158	86	19F
0005433434863	26158	87	19H
0005435982196	26158	88	19G
0005435981972	26158	89	20A
0005433754138	26158	90	20D
0005435982126	26158	91	20B
0005433754087	26158	92	20E
0005433434844	26158	93	20F
0005433753804	26158	94	20H
0005433754134	26158	95	20G
0005432655481	26158	96	21B
0005433766619	26158	97	21A
0005433754242	26158	98	21D
0005433753910	26158	99	21E
0005433434847	26158	100	21F
0005435982113	26158	101	21H
0005433754272	26158	102	21G
0005433753919	26158	103	22B
0005435982262	26158	104	22A
0005433754198	26158	105	22D
0005435982052	26158	106	22F
0005433754168	26158	107	22E
0005432655448	26158	108	22H
0005435982076	26158	109	23B
0005432049486	26158	110	23D
0005432869562	26158	111	23F
0005433434865	26158	112	23E
0005432869561	26158	113	23G
0005433754022	26158	114	23H
0005432869560	26158	115	24B
0005432869566	26158	116	24A
0005433753985	26158	117	24E
0005433434867	26158	118	24D
0005432985273	26158	119	24F
0005435981971	26158	120	24H
0005435982197	26158	121	24G
0005433754271	26158	122	25D
0005433754196	26158	123	25E
0005435982059	26158	124	25F
0005432985294	26158	125	27B
0005432985292	26158	126	27A
0005433753941	26158	127	27E
0005435982285	26158	128	27D
0005435982205	26158	129	27F
0005432051146	26158	130	27G
0005433434856	26158	131	28A
0005433754021	26158	132	27H
0005435982057	26158	133	28D
0005433434858	26158	134	28B
0005433753855	26158	135	28F
0005433754102	26158	136	28G
0005433754189	26158	137	29A
0005433434849	26158	138	28H
0005435981919	26158	139	29D
0005433434853	26158	140	29B
0005433754000	26158	141	29F
0005432985272	26158	142	29E
0005433754038	26158	143	29G
0005434731196	26158	144	29H
0005433766616	26158	145	30B
0005432985277	26158	146	30A
0005435982183	26158	147	30D
0005432985269	26158	148	30E
0005435982018	26158	149	30G
0005432869564	26158	150	30F
0005433434845	26158	151	30H
0005435981988	26158	152	31B
0005433754139	26158	153	31A
0005433434864	26158	154	31E
0005435982315	26158	155	31F
0005433766632	26158	156	31H
0005435982286	26158	157	31G
0005432985276	26158	158	32A
0005432049484	26158	159	32D
0005435982204	26158	160	32B
0005435982161	26158	161	32E
0005435982206	26158	162	32G
0005433434852	26158	163	32F
0005433434868	26158	164	32H
0005433753854	26158	165	33A
0005433434869	26158	166	33B
0005434731195	26158	167	33E
0005433754254	26158	168	33G
0005433754036	26158	169	33F
0005433766615	26158	170	33H
0005433753917	26158	171	34A
0005432985271	26158	172	34D
0005432985264	26158	173	34G
0005435982084	26158	174	34F
0005433754135	26158	175	35A
0005433753803	26158	176	34H
0005433753946	26158	177	35B
0005432985279	26158	178	35E
0005433754144	26158	179	35D
0005433753884	26158	180	35F
0005435982058	26158	181	35G
0005432985285	26158	182	36A
0005432655455	26158	183	35H
0005433754023	26158	184	36B
0005432655488	26158	185	36D
0005432985265	26158	186	36F
0005432655504	26158	187	36E
0005435982271	26158	188	37A
0005435982314	26158	189	37B
0005435982171	26158	190	37E
0005432985290	26158	191	37D
0005435982270	26158	192	37F
0005435982053	26158	193	37G
0005432049485	26158	194	38A
0005435982229	26158	195	37H
0005433754210	26158	196	38B
0005435982158	26158	197	38E
0005432655492	26158	198	38D
0005432869563	26158	199	38G
0005433753945	26158	200	38F
0005433434850	26158	201	38H
0005434731198	26158	202	39E
0005435982100	26158	203	39D
0005434374931	1483	1	1A
0005434374940	1483	2	1F
0005434374909	1483	3	2C
0005432267939	1483	4	2A
0005434374922	1483	5	3A
0005433460450	1483	6	3D
0005434374896	1483	7	3F
0005433764669	1483	8	4B
0005434374902	1483	9	4C
0005434374913	1483	10	4D
0005433764670	1483	11	4E
0005433151400	1483	12	4F
0005434374930	1483	13	5A
0005433461602	1483	14	5C
0005432267937	1483	15	5E
0005434374918	1483	16	6A
0005434374945	1483	17	5F
0005434374923	1483	18	6B
0005434374899	1483	19	6E
0005432267940	1483	20	6D
0005433151353	1483	21	6C
0005434374914	1483	22	6F
0005432267934	1483	23	7B
0005433151354	1483	24	7A
0005434374915	1483	25	7E
0005433151329	1483	26	7F
0005434374933	1483	27	8B
0005434374924	1483	28	8A
0005434374900	1483	29	8E
0005432267938	1483	30	8D
0005433151258	1483	31	8F
0005434374950	1483	32	9B
0005434374938	1483	33	9C
0005433151330	1483	34	9E
0005433151503	1483	35	9D
0005433151211	1483	36	9F
0005433460449	1483	37	10D
0005434029645	1483	38	10C
0005434374932	1483	39	10E
0005433151420	1483	40	11A
0005434374907	1483	41	11C
0005433151331	1483	42	11B
0005433151477	1483	43	11D
0005433151409	1483	44	11F
0005433151410	1483	45	11E
0005434374943	1483	46	12A
0005434374936	1483	47	12B
0005433151482	1483	48	12D
0005433931444	1483	49	12C
0005434374905	1483	50	12E
0005434374946	1483	51	12F
0005434374941	1483	52	13A
0005432267935	1483	53	13C
0005434374908	1483	54	13B
0005433151413	1483	55	13E
0005434374935	1483	56	13F
0005434374919	1483	57	14A
0005433151350	1483	58	14C
0005433151395	1483	59	14D
0005434374948	1483	60	15D
0005433151358	1483	61	15E
0005434374921	1483	62	15F
0005433151504	1483	63	16B
0005434374904	1483	64	16A
0005434374901	1483	65	16C
0005433151455	1483	66	16E
0005433151374	1483	67	16D
0005433151328	1483	68	17A
0005433151414	1483	69	17B
0005433151373	1483	70	17C
0005434374947	1483	71	17D
0005433151525	1483	72	17E
0005434374917	1483	73	17F
0005434374928	1483	74	18B
0005434374949	1483	75	18D
0005433151327	1483	76	18C
0005434374916	1483	77	18E
0005434374920	1483	78	18F
0005434029641	1483	79	19A
0005434374903	1483	80	19B
0005434374927	1483	81	19D
0005433931460	1483	82	19C
0005434374910	1483	83	19F
0005434374906	1483	84	19E
0005434374911	1483	85	20B
0005433151441	1483	86	20A
0005434374898	1483	87	20D
0005434374944	1483	88	20C
0005434374939	1483	89	20F
0005434374937	1483	90	21B
0005434374929	1483	91	21C
0005432267936	1483	92	21D
0005434374894	1483	93	21F
0005433764676	1483	94	21E
0005434374926	1483	95	22A
0005434374912	1483	96	22B
0005433151210	1483	97	22C
0005433151442	1483	98	22D
0005433151401	1483	99	22F
0005434374934	1483	100	22E
0005434374895	1483	101	23B
0005434374897	1483	102	23C
0005434374925	1483	103	23D
0005434374942	1483	104	23F
0005433151604	20105	1	1A
0005433931483	20105	2	1C
0005434374607	20105	3	2A
0005433151602	20105	4	1F
0005434029672	20105	5	2C
0005434374556	20105	6	2D
0005433151612	20105	7	2F
0005433151621	20105	8	3A
0005433151634	20105	9	3D
0005434374346	20105	10	4A
0005433151633	20105	11	4B
0005433151616	20105	12	4D
0005434029671	20105	13	4C
0005434374446	20105	14	5B
0005433151617	20105	15	5E
0005434374664	20105	16	6A
0005433151624	20105	17	5F
0005434374393	20105	18	6B
0005434374490	20105	19	6C
0005433151618	20105	20	6D
0005434374540	20105	21	6F
0005433151607	20105	22	7B
0005433151620	20105	23	7C
0005434374606	20105	24	7D
0005434374554	20105	25	7F
0005434374778	20105	26	8B
0005434374692	20105	27	8A
0005434374676	20105	28	8C
0005433151629	20105	29	8D
0005433151608	20105	30	8F
0005434374261	20105	31	9A
0005433151630	20105	32	9B
0005434374347	20105	33	9E
0005433151613	20105	34	9F
0005434029673	20105	35	10B
0005434374263	20105	36	10E
0005434374423	20105	37	11A
0005433151631	20105	38	11B
0005434374625	20105	39	11E
0005433151606	20105	40	11F
0005434374670	20105	41	12B
0005433151632	20105	42	12A
0005434374526	20105	43	12C
0005433151610	20105	44	12D
0005433151615	20105	45	12E
0005434374429	20105	46	12F
0005434374557	20105	47	13D
0005433151619	20105	48	13C
0005433931482	20105	49	13E
0005432056322	20105	50	14A
0005434374439	20105	51	14B
0005433931484	20105	52	14C
0005434374579	20105	53	14E
0005434374580	20105	54	15A
0005434374499	20105	55	14F
0005434374496	20105	56	15C
0005433151611	20105	57	15B
0005434374589	20105	58	15D
0005434374583	20105	59	15E
0005433151623	20105	60	15F
0005433151636	20105	61	16A
0005434374498	20105	62	16E
0005432056321	20105	63	16D
0005433151628	20105	64	16F
0005433764693	20105	65	17B
0005434374418	20105	66	17C
0005433151614	20105	67	17E
0005433151626	20105	68	17F
0005434374691	20105	69	18A
0005434374654	20105	70	18C
0005432056324	20105	71	18B
0005434374584	20105	72	18E
0005432056323	20105	73	18F
0005433151637	20105	74	19A
0005434374613	20105	75	19C
0005433151603	20105	76	19D
0005434374527	20105	77	19F
0005433764692	20105	78	19E
0005434374262	20105	79	20C
0005433151605	20105	80	20B
0005434374560	20105	81	20D
0005433151627	20105	82	20E
0005434374541	20105	83	20F
0005434374591	20105	84	21B
0005434374609	20105	85	22A
0005433151635	20105	86	21F
0005434374428	20105	87	22B
0005433151609	20105	88	22C
0005433151625	20105	89	22D
0005434374558	20105	90	22E
0005434374500	20105	91	22F
0005434374245	20105	92	23A
0005434374608	20105	93	23C
0005434374602	20105	94	23D
0005433151622	20105	95	23F
0005432424756	534	1	1C
0005432424775	534	2	2C
0005432282907	534	3	3C
0005432424773	534	4	3F
0005432282908	534	5	4D
0005432282911	534	6	4F
0005432282912	534	7	5C
0005432424753	534	8	6A
0005432424761	534	9	7D
0005432424762	534	10	8A
0005432424752	534	11	8B
0005432424764	534	12	8D
0005432424759	534	13	8F
0005432424738	534	14	9B
0005432282909	534	15	9C
0005432424748	534	16	9F
0005432424723	534	17	9E
0005432424732	534	18	10B
0005432424719	534	19	10D
0005432424725	534	20	10C
0005432282906	534	21	10F
0005432424742	534	22	10E
0005432424749	534	23	11A
0005432424720	534	24	11D
0005432424727	534	25	11C
0005432424734	534	26	12B
0005432424770	534	27	12C
0005432424746	534	28	12E
0005432424754	534	29	12D
0005432424772	534	30	14A
0005432424724	534	31	14C
0005432424750	534	32	14F
0005432424763	534	33	15A
0005432424733	534	34	15D
0005432424765	534	35	15E
0005432424717	534	36	16B
0005432424729	534	37	16E
0005432424736	534	38	16F
0005432424744	534	39	17B
0005432424726	534	40	18B
0005432424747	534	41	18C
0005432424740	534	42	19B
0005432424728	534	43	21A
0005432424760	534	44	21C
0005432424758	534	45	21B
0005432424767	534	46	21E
0005432424721	534	47	21F
0005432424737	534	48	22B
0005432424731	534	49	23A
0005432424741	534	50	23D
0005432282913	534	51	23E
0005432424735	534	52	24A
0005432424769	534	53	24C
0005432424766	534	54	25A
0005432282905	534	55	25F
0005432282910	534	56	26B
0005432424715	534	57	26F
0005432424722	534	58	27B
0005432424739	534	59	27A
0005432424718	534	60	27E
0005432424755	534	61	28B
0005432424768	534	62	28D
0005432424771	534	63	28F
0005432424716	534	64	29C
0005432424751	534	65	29D
0005432424745	534	66	30E
0005432424774	534	67	30F
0005432424743	534	68	31D
0005432424757	534	69	31E
0005432424730	534	70	31F
0005434446509	12869	1	4C
0005434446515	12869	2	5F
0005434446507	12869	3	6D
0005432302353	12869	4	8F
0005433158142	12869	5	16B
0005434446510	12869	6	18D
0005433158146	12869	7	22B
0005432302355	12869	8	23D
0005432302354	12869	9	24C
0005433158144	12869	10	26F
0005433158145	12869	11	27F
0005434446508	12869	12	28C
0005433158143	12869	13	29A
0005432424187	12866	1	2D
0005432424305	12866	2	4C
0005432424242	12866	3	6C
0005432424254	12866	4	9D
0005432424195	12866	5	9F
0005432424200	12866	6	10B
0005432424278	12866	7	11A
0005432424299	12866	8	10F
0005432424125	12866	9	11D
0005432424296	12866	10	13C
0005432424302	12866	11	13F
0005432424321	12866	12	13E
0005432424181	12866	13	14A
0005432424194	12866	14	14C
0005432424126	12866	15	14B
0005432424295	12866	16	14E
0005432424319	12866	17	15A
0005432424259	12866	18	15B
0005432424239	12866	19	16C
0005432424101	12866	20	17C
0005432424088	12866	21	17B
0005432424183	12866	22	17F
0005432424300	12866	23	18C
0005432424306	12866	24	18B
0005432424100	12866	25	18D
0005432424256	12866	26	19D
0005432424260	12866	27	20E
0005432424267	12866	28	21B
0005432424117	12866	29	21C
0005432424118	12866	30	22D
0005432424241	12866	31	22C
0005432424257	12866	32	22E
0005432424098	12866	33	24B
0005432424124	12866	34	24A
0005432424314	12866	35	24C
0005432424154	12866	36	24E
0005432424045	12866	37	25C
0005432424099	12866	38	25E
0005432424286	12866	39	26A
0005432424292	12866	40	26C
0005432424322	12866	41	27C
0005432424323	12866	42	27E
0005432424307	12866	43	28D
0005432424301	12866	44	28F
0005432424202	12866	45	29D
0005432424285	12866	46	30D
0005432424180	12866	47	31C
0005432424193	12866	48	31D
0005434024129	479	1	1A
0005433057721	479	2	1F
0005433057756	479	3	1C
0005434024121	479	4	1H
0005434024135	479	5	2A
0005433057838	479	6	2C
0005433929594	479	7	2B
0005434024143	479	8	2F
0005433057824	479	9	2G
0005434024104	479	10	2H
0005433057791	479	11	3B
0005434024147	479	12	3C
0005433057813	479	13	3G
0005433057702	479	14	3F
0005433057938	479	15	4A
0005434024151	479	16	3H
0005434024100	479	17	4B
0005433057952	479	18	4C
0005433057823	479	19	4G
0005433057879	479	20	4F
0005434024162	479	21	5A
0005434024120	479	22	4H
0005433057800	479	23	5B
0005434024138	479	24	5G
0005433057977	479	25	9A
0005434029670	479	26	9B
0005434032048	479	27	11A
0005434024140	479	28	11B
0005434032051	479	29	11E
0005433057784	479	30	11D
0005434024125	479	31	11F
0005433057724	479	32	12A
0005434024119	479	33	12D
0005432235681	479	34	12F
0005434024157	479	35	12E
0005432235684	479	36	12H
0005434024154	479	37	13A
0005434024161	479	38	13D
0005433057660	479	39	13B
0005433057676	479	40	13F
0005434032047	479	41	14A
0005432235687	479	42	13G
0005434024099	479	43	14E
0005433057897	479	44	14D
0005433057939	479	45	14F
0005434024131	479	46	14G
0005434032050	479	47	15A
0005433057847	479	48	14H
0005434024123	479	49	15B
0005434024139	479	50	15E
0005434024106	479	51	15F
0005434024134	479	52	15H
0005434024105	479	53	15G
0005433057632	479	54	16A
0005433057822	479	55	16B
0005433057907	479	56	16E
0005433058053	479	57	16D
0005434024124	479	58	16G
0005433058005	479	59	16F
0005434024110	479	60	16H
0005434735657	479	61	17A
0005432235688	479	62	17G
0005432235683	479	63	17F
0005434028313	479	64	17H
0005434024164	479	65	18G
0005434024126	479	66	18F
0005434024159	479	67	19A
0005434024158	479	68	18H
0005433057713	479	69	19B
0005433057699	479	70	19D
0005434024146	479	71	19G
0005434024116	479	72	19F
0005434735666	479	73	19E
0005433058041	479	74	19H
0005433929610	479	75	20A
0005433057799	479	76	20B
0005433057793	479	77	20E
0005433057798	479	78	20F
0005433057862	479	79	21B
0005434024111	479	80	21E
0005434024156	479	81	21D
0005434024149	479	82	21G
0005434735663	479	83	22A
0005434024097	479	84	21H
0005433929602	479	85	22B
0005433057856	479	86	22F
0005433057951	479	87	22E
0005434024132	479	88	22G
0005434024101	479	89	23A
0005433057860	479	90	23D
0005434024108	479	91	23E
0005434024107	479	92	24A
0005434024153	479	93	24D
0005434024102	479	94	24E
0005434024145	479	95	24H
0005433057880	479	96	25D
0005434024150	479	97	27B
0005434024103	479	98	27A
0005434024160	479	99	27E
0005434024117	479	100	27F
0005434024114	479	101	27H
0005434024148	479	102	28A
0005433057861	479	103	28D
0005434024113	479	104	28E
0005433057782	479	105	28F
0005434024137	479	106	28H
0005433057698	479	107	28G
0005434024152	479	108	29A
0005434028312	479	109	29D
0005434024155	479	110	29B
0005434028311	479	111	29G
0005434024127	479	112	30A
0005433684417	479	113	30E
0005434024133	479	114	30D
0005434032049	479	115	31B
0005433929600	479	116	31D
0005433684418	479	117	31F
0005433057832	479	118	31E
0005434024109	479	119	31H
0005434024130	479	120	31G
0005433057928	479	121	32A
0005433057849	479	122	32B
0005433057787	479	123	32D
0005433057931	479	124	32F
0005434024122	479	125	32E
0005432235686	479	126	32H
0005433058042	479	127	32G
0005433057792	479	128	33D
0005433057633	479	129	33B
0005434024163	479	130	33E
0005432235682	479	131	33G
0005433057959	479	132	33F
0005434024112	479	133	34B
0005433057723	479	134	34D
0005433057644	479	135	34E
0005434029669	479	136	34G
0005434735664	479	137	34F
0005433057957	479	138	35A
0005433929595	479	139	34H
0005434024142	479	140	35B
0005432235685	479	141	35G
0005434024144	479	142	35H
0005433057755	479	143	36B
0005434735665	479	144	36D
0005433057805	479	145	36H
0005434024115	479	146	36G
0005434024118	479	147	36F
0005433057786	479	148	37A
0005434024136	479	149	37B
0005434024128	479	150	37E
0005434024098	479	151	37G
0005434024141	479	152	38G
0005432045624	479	153	38F
0005433057857	479	154	38H
0005433057785	479	155	39D
0005432045623	479	156	39E
0005434023594	12663	1	1A
0005433058118	12663	2	1B
0005433058126	12663	3	1F
0005432156397	12663	4	2B
0005434023584	12663	5	2G
0005433058145	12663	6	3B
0005433929639	12663	7	3F
0005434023618	12663	8	3G
0005434023670	12663	9	4C
0005434023492	12663	10	4B
0005433058134	12663	11	4A
0005433058133	12663	12	4F
0005433058127	12663	13	5A
0005433058147	12663	14	5B
0005434023427	12663	15	5C
0005434023314	12663	16	5F
0005434023550	12663	17	5H
0005434023740	12663	18	9B
0005433058122	12663	19	11A
0005433058139	12663	20	11B
0005434023315	12663	21	11D
0005433058116	12663	22	11G
0005433058136	12663	23	11F
0005434023317	12663	24	11H
0005432156391	12663	25	12E
0005434023544	12663	26	12G
0005433929641	12663	27	13D
0005433684433	12663	28	13F
0005434023590	12663	29	13E
0005433684434	12663	30	13H
0005434023591	12663	31	14B
0005434023622	12663	32	14E
0005434735723	12663	33	14D
0005434023535	12663	34	14G
0005434023664	12663	35	15A
0005433058141	12663	36	14H
0005433058129	12663	37	15D
0005434023808	12663	38	15F
0005434029641	12663	39	15G
0005434023674	12663	40	16A
0005433058149	12663	41	16B
0005434023728	12663	42	16F
0005434023803	12663	43	16H
0005432156396	12663	44	16G
0005433058146	12663	45	17D
0005433058153	12663	46	17E
0005434023577	12663	47	18B
0005433058143	12663	48	18D
0005434023621	12663	49	18E
0005434023534	12663	50	18F
0005434032024	12663	51	19A
0005434032023	12663	52	19E
0005434023671	12663	53	19D
0005434032017	12663	54	19F
0005433058148	12663	55	19H
0005433058119	12663	56	20A
0005434735720	12663	57	20B
0005434023504	12663	58	20H
0005434023846	12663	59	20G
0005433058123	12663	60	21B
0005434735721	12663	61	21E
0005434023633	12663	62	21D
0005434023845	12663	63	21G
0005433929637	12663	64	21F
0005433058135	12663	65	21H
0005434023413	12663	66	22A
0005434023135	12663	67	22B
0005434023612	12663	68	22E
0005434023578	12663	69	22F
0005434023691	12663	70	23B
0005433058132	12663	71	23A
0005432156395	12663	72	23E
0005432157504	12663	73	23F
0005434023587	12663	74	24A
0005433058140	12663	75	24D
0005434032014	12663	76	24F
0005434023540	12663	77	25D
0005434023491	12663	78	24H
0005433058138	12663	79	27A
0005434023312	12663	80	25F
0005433929640	12663	81	27B
0005434023551	12663	82	27E
0005434032016	12663	83	27G
0005434032018	12663	84	27F
0005434023610	12663	85	27H
0005433929638	12663	86	28A
0005434032022	12663	87	28D
0005434023597	12663	88	28B
0005434023466	12663	89	28E
0005434023505	12663	90	28H
0005434023134	12663	91	29A
0005434023611	12663	92	29F
0005433058121	12663	93	29H
0005434735722	12663	94	29G
0005434023615	12663	95	30A
0005434735724	12663	96	30B
0005434023585	12663	97	30F
0005434023440	12663	98	31A
0005434023807	12663	99	30H
0005434023477	12663	100	31B
0005434023508	12663	101	31F
0005433058128	12663	102	31E
0005434023554	12663	103	31G
0005433058144	12663	104	32A
0005434023762	12663	105	32B
0005433058124	12663	106	32E
0005434023729	12663	107	32F
0005432156393	12663	108	32H
0005433058152	12663	109	33B
0005432156392	12663	110	33D
0005433058115	12663	111	33G
0005434023555	12663	112	34A
0005432157503	12663	113	33H
0005434023478	12663	114	34D
0005433058131	12663	115	34B
0005434023530	12663	116	34E
0005434023583	12663	117	34H
0005434023316	12663	118	35B
0005434023572	12663	119	35E
0005433058150	12663	120	35D
0005433058142	12663	121	35F
0005433058114	12663	122	35G
0005433058130	12663	123	35H
0005434023802	12663	124	36A
0005434023442	12663	125	36E
0005434023595	12663	126	36D
0005434032030	12663	127	36F
0005433058117	12663	128	36H
0005433058120	12663	129	36G
0005434029645	12663	130	37A
0005434023675	12663	131	37B
0005434023443	12663	132	37E
0005433058151	12663	133	37D
0005434023634	12663	134	37G
0005434023665	12663	135	37F
0005434023582	12663	136	37H
0005434032029	12663	137	38G
0005432156394	12663	138	38F
0005433058125	12663	139	38H
0005433058137	12663	140	39E
0005434023600	12663	141	39D
0005433036206	2120	1	1B
0005433923852	2120	2	1A
0005433923905	2120	3	1C
0005433923938	2120	4	1G
0005433036205	2120	5	2A
0005433923917	2120	6	2B
0005433923929	2120	7	2F
0005433923937	2120	8	2C
0005433923888	2120	9	2H
0005433036311	2120	10	2G
0005433923921	2120	11	3A
0005433036131	2120	12	3B
0005433923863	2120	13	3F
0005433923920	2120	14	3C
0005433036081	2120	15	3G
0005433036207	2120	16	4A
0005433923849	2120	17	3H
0005432231629	2120	18	4B
0005433036169	2120	19	4C
0005433035938	2120	20	4G
0005433923902	2120	21	4F
0005433036128	2120	22	5B
0005432231631	2120	23	5A
0005433923940	2120	24	5F
0005433036211	2120	25	5C
0005433036296	2120	26	5G
0005433875390	2120	27	5H
0005433923893	2120	28	9B
0005433036260	2120	29	9A
0005433923855	2120	30	9G
0005433036266	2120	31	9H
0005433923862	2120	32	11B
0005433036013	2120	33	11E
0005432231626	2120	34	11D
0005433923927	2120	35	11F
0005433036368	2120	36	11G
0005433035899	2120	37	12B
0005433923898	2120	38	12E
0005433923934	2120	39	12D
0005433036183	2120	40	12G
0005433923922	2120	41	12H
0005433923890	2120	42	13B
0005433923880	2120	43	13A
0005433036367	2120	44	13D
0005433923887	2120	45	13G
0005433923892	2120	46	13F
0005433923909	2120	47	13H
0005433923907	2120	48	14B
0005433036056	2120	49	14A
0005433036023	2120	50	14D
0005433923848	2120	51	14E
0005433036195	2120	52	14H
0005433923926	2120	53	14G
0005433923924	2120	54	15A
0005433923912	2120	55	15D
0005433036290	2120	56	15H
0005433923856	2120	57	15G
0005433923896	2120	58	16A
0005433929639	2120	59	16B
0005433036016	2120	60	16E
0005433036224	2120	61	16G
0005433923911	2120	62	16F
0005433036407	2120	63	16H
0005433875389	2120	64	17A
0005433036059	2120	65	17D
0005433923901	2120	66	17B
0005433923861	2120	67	17E
0005433923857	2120	68	17G
0005433923919	2120	69	17F
0005433923941	2120	70	17H
0005433923864	2120	71	18A
0005433923889	2120	72	18B
0005433923868	2120	73	18G
0005433036228	2120	74	18F
0005433036342	2120	75	18H
0005433923870	2120	76	19B
0005433923908	2120	77	19A
0005433036295	2120	78	19E
0005432044541	2120	79	19D
0005432231632	2120	80	19G
0005433923923	2120	81	20A
0005433036201	2120	82	19H
0005433923875	2120	83	20E
0005433923895	2120	84	20F
0005433036068	2120	85	20G
0005433036242	2120	86	21A
0005433036240	2120	87	21D
0005433923867	2120	88	21E
0005433923858	2120	89	21F
0005433036216	2120	90	21H
0005433923915	2120	91	21G
0005433923891	2120	92	22B
0005433036012	2120	93	22A
0005432231625	2120	94	22D
0005433923865	2120	95	22F
0005433036176	2120	96	22E
0005433923885	2120	97	22G
0005433923914	2120	98	23A
0005433923913	2120	99	22H
0005433036291	2120	100	23B
0005433923886	2120	101	23D
0005433929641	2120	102	23F
0005433923899	2120	103	23H
0005433036223	2120	104	24E
0005433923866	2120	105	24D
0005433036049	2120	106	24G
0005433036355	2120	107	25D
0005433036259	2120	108	27A
0005433923854	2120	109	25F
0005433923932	2120	110	27B
0005433923910	2120	111	27D
0005433923846	2120	112	27E
0005433036178	2120	113	27H
0005433923851	2120	114	27G
0005433923928	2120	115	28A
0005433036124	2120	116	28B
0005432044540	2120	117	28E
0005433923903	2120	118	28D
0005432231627	2120	119	28F
0005433931482	2120	120	28G
0005433036217	2120	121	29A
0005433036132	2120	122	28H
0005433923882	2120	123	29D
0005433923860	2120	124	29B
0005433923897	2120	125	29E
0005433923859	2120	126	29G
0005433923935	2120	127	29F
0005433923884	2120	128	29H
0005433036239	2120	129	30B
0005433036050	2120	130	30A
0005433923874	2120	131	30D
0005433923925	2120	132	30E
0005433929640	2120	133	30G
0005433929637	2120	134	31A
0005433923906	2120	135	30H
0005433036200	2120	136	31B
0005433923871	2120	137	31E
0005433923883	2120	138	31D
0005433036210	2120	139	31F
0005433923904	2120	140	31G
0005433036168	2120	141	31H
0005433923879	2120	142	32D
0005433036289	2120	143	32B
0005433036051	2120	144	32E
0005432231633	2120	145	32G
0005433923930	2120	146	33A
0005433035791	2120	147	32H
0005433923853	2120	148	33D
0005433931483	2120	149	33E
0005433923873	2120	150	33F
0005432044542	2120	151	33H
0005433923850	2120	152	34A
0005433035937	2120	153	34D
0005433929638	2120	154	34B
0005433923900	2120	155	34E
0005433036085	2120	156	34G
0005433923876	2120	157	34F
0005433923916	2120	158	35A
0005433923918	2120	159	34H
0005433923894	2120	160	35D
0005433923933	2120	161	35E
0005433036184	2120	162	35G
0005433036379	2120	163	35F
0005433923878	2120	164	35H
0005433036294	2120	165	36A
0005433923872	2120	166	36D
0005432231630	2120	167	36F
0005433923847	2120	168	36H
0005432231635	2120	169	36G
0005433923931	2120	170	37A
0005433923936	2120	171	37B
0005433036215	2120	172	37E
0005433923881	2120	173	37D
0005433036378	2120	174	37G
0005433931484	2120	175	37F
0005433923942	2120	176	37H
0005433035936	2120	177	38A
0005433923939	2120	178	38D
0005433036022	2120	179	38E
0005432231628	2120	180	38G
0005433036129	2120	181	38F
0005433923869	2120	182	38H
0005433923877	2120	183	39E
0005432231634	2120	184	39D
0005432207677	24123	1	1A
0005433923467	24123	2	1B
0005433036646	24123	3	1F
0005433923468	24123	4	1C
0005433923277	24123	5	1H
0005433036602	24123	6	1G
0005433923190	24123	7	2A
0005433923472	24123	8	2B
0005433875375	24123	9	2G
0005433923113	24123	10	2F
0005433922971	24123	11	3A
0005433036616	24123	12	2H
0005433923126	24123	13	3B
0005433922976	24123	14	3F
0005433036624	24123	15	3C
0005433036649	24123	16	3G
0005433923127	24123	17	3H
0005433922879	24123	18	4B
0005433036635	24123	19	4A
0005433922894	24123	20	4C
0005433922979	24123	21	4G
0005432749799	24123	22	5A
0005433036608	24123	23	4H
0005433923471	24123	24	5B
0005433036603	24123	25	5C
0005433931458	24123	26	5G
0005433923147	24123	27	5H
0005433931459	24123	28	9G
0005433922959	24123	29	11A
0005433923218	24123	30	9H
0005433036650	24123	31	11B
0005433922641	24123	32	11E
0005432206229	24123	33	11D
0005433922941	24123	34	11F
0005433923087	24123	35	11G
0005434028315	24123	36	12A
0005433923369	24123	37	12D
0005433922878	24123	38	12F
0005433036621	24123	39	12E
0005433923358	24123	40	12H
0005433036652	24123	41	12G
0005433036642	24123	42	13D
0005433923012	24123	43	13B
0005433923265	24123	44	13E
0005433923112	24123	45	13G
0005433923285	24123	46	14B
0005433036610	24123	47	14D
0005432206231	24123	48	14E
0005433923189	24123	49	14H
0005433922925	24123	50	14G
0005433922587	24123	51	15D
0005433922586	24123	52	15A
0005433036631	24123	53	15E
0005433923125	24123	54	15G
0005432206232	24123	55	15F
0005433036640	24123	56	15H
0005433036644	24123	57	16B
0005433923175	24123	58	16D
0005433923181	24123	59	16G
0005433923146	24123	60	16F
0005433036622	24123	61	16H
0005434028314	24123	62	17B
0005433923260	24123	63	17A
0005433036634	24123	64	17D
0005433036648	24123	65	17G
0005433922846	24123	66	18B
0005433922964	24123	67	18A
0005433923188	24123	68	18D
0005433923217	24123	69	18E
0005433923234	24123	70	18G
0005433036627	24123	71	19A
0005433923182	24123	72	18H
0005433036619	24123	73	19D
0005433036615	24123	74	19H
0005433923523	24123	75	19G
0005433036643	24123	76	20A
0005433036617	24123	77	20B
0005433923362	24123	78	20E
0005433922944	24123	79	20D
0005433036641	24123	80	20F
0005433036636	24123	81	20H
0005433923366	24123	82	20G
0005433923524	24123	83	21A
0005433923252	24123	84	21B
0005433923165	24123	85	21D
0005433922956	24123	86	21F
0005433036598	24123	87	21H
0005433923264	24123	88	22A
0005433036630	24123	89	22F
0005433929858	24123	90	22E
0005433923076	24123	91	22G
0005433036639	24123	92	23A
0005433923077	24123	93	22H
0005433036605	24123	94	23E
0005433922960	24123	95	23F
0005433923302	24123	96	23G
0005433036647	24123	97	24A
0005433036620	24123	98	23H
0005433036599	24123	99	24B
0005432207678	24123	100	24D
0005433036612	24123	101	24F
0005433923097	24123	102	24H
0005433922942	24123	103	24G
0005433923078	24123	104	25E
0005433922863	24123	105	27A
0005433922937	24123	106	27B
0005433923459	24123	107	27E
0005433036600	24123	108	27F
0005433923133	24123	109	27H
0005433923029	24123	110	28D
0005433036611	24123	111	28B
0005433922875	24123	112	28E
0005433036623	24123	113	28G
0005433922889	24123	114	28F
0005433923516	24123	115	28H
0005433036604	24123	116	29A
0005433036632	24123	117	29D
0005433036618	24123	118	29B
0005433922625	24123	119	29F
0005433923037	24123	120	30B
0005433923235	24123	121	30A
0005433923445	24123	122	30E
0005433923026	24123	123	30G
0005432206230	24123	124	30F
0005433036613	24123	125	30H
0005433922818	24123	126	31D
0005433036637	24123	127	31H
0005433923096	24123	128	31G
0005433923296	24123	129	32E
0005433036628	24123	130	32D
0005433036638	24123	131	32F
0005433923068	24123	132	32H
0005433875376	24123	133	33A
0005433923073	24123	134	33D
0005433922561	24123	135	33B
0005433923517	24123	136	33E
0005433923449	24123	137	33G
0005433036607	24123	138	33H
0005433036633	24123	139	34D
0005433922966	24123	140	34E
0005432206234	24123	141	34G
0005433922967	24123	142	35A
0005433923161	24123	143	34H
0005433922895	24123	144	35B
0005433036614	24123	145	35D
0005433036625	24123	146	35F
0005433922705	24123	147	35E
0005432206233	24123	148	35G
0005433036626	24123	149	35H
0005433923280	24123	150	36B
0005433922961	24123	151	36D
0005433922977	24123	152	36F
0005433922936	24123	153	37A
0005433036606	24123	154	36H
0005433036629	24123	155	37B
0005433923250	24123	156	37E
0005433923075	24123	157	37D
0005433923275	24123	158	37F
0005433036601	24123	159	38A
0005433875374	24123	160	38B
0005433036651	24123	161	38E
0005433923261	24123	162	38D
0005433923081	24123	163	38F
0005433036609	24123	164	39D
0005433036645	24123	165	38H
0005433923458	24123	166	39F
0005433922820	24123	167	39E
0005433233995	276	1	1D
0005432277886	276	2	1C
0005433289829	276	3	1A
0005433234045	276	4	1G
0005433233911	276	5	1K
0005433234095	276	6	1H
0005433181002	276	7	2C
0005434726259	276	8	2A
0005434551555	276	9	2H
0005434726227	276	10	2G
0005433234051	276	11	3A
0005433234359	276	12	2K
0005434726265	276	13	3G
0005433234035	276	14	3D
0005433234164	276	15	3C
0005433126831	276	16	3H
0005434726179	276	17	4C
0005433233719	276	18	4A
0005433233930	276	19	3K
0005434551592	276	20	4G
0005434551593	276	21	4D
0005434726219	276	22	4K
0005433233986	276	23	4H
0005432277885	276	24	5C
0005434731194	276	25	5A
0005434551550	276	26	5H
0005434726256	276	27	5G
0005434032007	276	28	5D
0005434726260	276	29	11A
0005433234000	276	30	5K
0005433234129	276	31	11D
0005433233999	276	32	11C
0005434551581	276	33	11F
0005434726178	276	34	11E
0005433234385	276	35	11H
0005434551602	276	36	11G
0005433181035	276	37	12C
0005433234034	276	38	12A
0005434726170	276	39	11K
0005434302484	276	40	12E
0005433181031	276	41	12D
0005434726172	276	42	12H
0005434726275	276	43	12G
0005434726245	276	44	12F
0005434726189	276	45	13C
0005434726218	276	46	13A
0005434726210	276	47	13G
0005433289807	276	48	13E
0005434726217	276	49	13K
0005435142667	276	50	13H
0005433126847	276	51	14A
0005432277892	276	52	14D
0005433234074	276	53	14C
0005434726184	276	54	14G
0005434551562	276	55	14F
0005434726205	276	56	14E
0005434726237	276	57	14K
0005434302486	276	58	15C
0005434726276	276	59	15A
0005433181124	276	60	15D
0005434551580	276	61	15H
0005434726258	276	62	15G
0005434726221	276	63	15F
0005433234013	276	64	16A
0005434551598	276	65	15K
0005434551563	276	66	16D
0005434032010	276	67	16F
0005434726255	276	68	16E
0005434726162	276	69	16H
0005433234006	276	70	16G
0005434551594	276	71	17C
0005433234109	276	72	17A
0005433181026	276	73	16K
0005434551560	276	74	17E
0005433234363	276	75	17G
0005434735716	276	76	17F
0005432277897	276	77	17K
0005433181061	276	78	17H
0005435142659	276	79	18C
0005434551582	276	80	18B
0005434551600	276	81	18A
0005433181034	276	82	18E
0005433131685	276	83	18F
0005434726263	276	84	18J
0005434731191	276	85	18H
0005434551577	276	86	19B
0005434726261	276	87	19A
0005433234072	276	88	19C
0005434726212	276	89	19F
0005433233755	276	90	19E
0005433234025	276	91	19D
0005434726161	276	92	19H
0005434726246	276	93	19G
0005433234046	276	94	20A
0005434551569	276	95	19K
0005433234165	276	96	20B
0005435142663	276	97	20E
0005434726229	276	98	20D
0005434551558	276	99	20G
0005433233887	276	100	20F
0005434726249	276	101	20J
0005434726166	276	102	20H
0005434726171	276	103	21A
0005433233783	276	104	20K
0005433289805	276	105	21D
0005433126836	276	106	21C
0005433234149	276	107	21F
0005433126828	276	108	21E
0005434726198	276	109	21J
0005433234364	276	110	21G
0005433234258	276	111	22A
0005433181057	276	112	21K
0005434726163	276	113	22B
0005434726234	276	114	22E
0005433233994	276	115	22D
0005433289826	276	116	22G
0005434726206	276	117	22F
0005434726282	276	118	22K
0005434726266	276	119	22J
0005434551567	276	120	22H
0005433234110	276	121	23B
0005434726196	276	122	23A
0005433181030	276	123	23D
0005435142662	276	124	23G
0005433233973	276	125	23F
0005433131687	276	126	23E
0005434726213	276	127	23H
0005434726180	276	128	24D
0005434726277	276	129	23K
0005434551578	276	130	23J
0005434726200	276	131	24E
0005434726223	276	132	25A
0005435142657	276	133	24G
0005434551571	276	134	25D
0005434726204	276	135	25C
0005434726225	276	136	25B
0005434726250	276	137	25F
0005434726201	276	138	25E
0005434726199	276	139	25H
0005434726267	276	140	25G
0005434551586	276	141	25J
0005432277893	276	142	26C
0005434731192	276	143	26B
0005433766633	276	144	26E
0005433180994	276	145	26D
0005434726190	276	146	26G
0005434551579	276	147	26F
0005435142654	276	148	26K
0005434726220	276	149	26J
0005434726175	276	150	26H
0005433233756	276	151	27B
0005435142665	276	152	27A
0005434726203	276	153	27C
0005434726244	276	154	27F
0005433180945	276	155	27E
0005434726243	276	156	27J
0005432277890	276	157	27G
0005433234362	276	158	28A
0005433181060	276	159	27K
0005433234162	276	160	28B
0005434726202	276	161	28E
0005434726183	276	162	28D
0005434726242	276	163	28C
0005435142660	276	164	28G
0005434551603	276	165	28F
0005433234097	276	166	28J
0005434551604	276	167	29A
0005433289824	276	168	28K
0005433234111	276	169	29C
0005433233983	276	170	29B
0005434726247	276	171	29F
0005434726207	276	172	29E
0005434551554	276	173	29D
0005433289828	276	174	29H
0005433233996	276	175	29G
0005434726269	276	176	29K
0005433234026	276	177	29J
0005433233891	276	178	30C
0005433181074	276	179	30B
0005433131700	276	180	30A
0005434551576	276	181	30E
0005434551552	276	182	30D
0005434551561	276	183	30G
0005433289825	276	184	30K
0005434726284	276	185	30J
0005434726191	276	186	30H
0005433234259	276	187	31B
0005433233972	276	188	31A
0005434726273	276	189	31D
0005434032012	276	190	31C
0005433126835	276	191	31F
0005434726278	276	192	31E
0005434551559	276	193	31J
0005434551584	276	194	31H
0005434726231	276	195	31G
0005433181006	276	196	32A
0005434735719	276	197	31K
0005434726224	276	198	32C
0005432277891	276	199	32E
0005435142666	276	200	32D
0005434726214	276	201	32G
0005434726174	276	202	32F
0005433234059	276	203	32K
0005434726187	276	204	32J
0005433233888	276	205	32H
0005433289823	276	206	33B
0005433234052	276	207	33A
0005434726194	276	208	33C
0005433234044	276	209	33F
0005434726192	276	210	33D
0005435142658	276	211	33H
0005433234365	276	212	33G
0005433131688	276	213	33K
0005434726215	276	214	33J
0005433233860	276	215	34B
0005433111502	276	216	34A
0005433234360	276	217	34E
0005434726195	276	218	34D
0005434551551	276	219	34C
0005434551589	276	220	34H
0005434726239	276	221	35A
0005434726286	276	222	34K
0005433234130	276	223	35C
0005433131684	276	224	35B
0005433181033	276	225	35F
0005434726252	276	226	35E
0005433180946	276	227	35J
0005434551599	276	228	35H
0005434731193	276	229	35G
0005434726254	276	230	36A
0005434726233	276	231	35K
0005434551595	276	232	36D
0005432277887	276	233	36C
0005434726240	276	234	36B
0005434726248	276	235	36H
0005434551585	276	236	36F
0005434726197	276	237	36J
0005433234050	276	238	37B
0005434726193	276	239	37D
0005434726176	276	240	37C
0005434551590	276	241	37F
0005434302487	276	242	37E
0005434726208	276	243	37J
0005434726285	276	244	37H
0005434551601	276	245	37G
0005434551553	276	246	38A
0005433289804	276	247	37K
0005433234335	276	248	38C
0005434726209	276	249	38B
0005433233750	276	250	38J
0005435142661	276	251	38H
0005434726270	276	252	39A
0005433234064	276	253	39D
0005432277895	276	254	39C
0005434551588	276	255	39F
0005434726222	276	256	39E
0005434551587	276	257	39H
0005433131698	276	258	39G
0005434032013	276	259	40A
0005434726235	276	260	39K
0005433181027	276	261	39J
0005434726268	276	262	40C
0005433233929	276	263	40B
0005434551575	276	264	40E
0005434726279	276	265	40D
0005433131686	276	266	40G
0005434726232	276	267	40F
0005433181025	276	268	40H
0005434551570	276	269	41A
0005435142656	276	270	41E
0005432277896	276	271	41D
0005433181073	276	272	41C
0005433233985	276	273	41F
0005434551596	276	274	41H
0005434551574	276	275	41G
0005433234043	276	276	41K
0005434726216	276	277	42C
0005433766634	276	278	42B
0005434726262	276	279	42A
0005433180965	276	280	42E
0005433126827	276	281	42D
0005432277898	276	282	42G
0005434726167	276	283	42J
0005433233799	276	284	42H
0005433181029	276	285	43A
0005433181021	276	286	42K
0005433233859	276	287	43D
0005434735717	276	288	43C
0005434726185	276	289	43B
0005434726281	276	290	43F
0005434726251	276	291	43E
0005434726257	276	292	43H
0005434551565	276	293	43G
0005434726182	276	294	44A
0005434726165	276	295	43K
0005434726280	276	296	43J
0005434726271	276	297	44C
0005434551583	276	298	44B
0005433234057	276	299	44E
0005434735718	276	300	44D
0005433181058	276	301	44G
0005434726186	276	302	44F
0005433234163	276	303	44J
0005434551591	276	304	44H
0005434726238	276	305	45A
0005434551557	276	306	44K
0005435142655	276	307	45D
0005434551568	276	308	45C
0005432277889	276	309	45B
0005434726168	276	310	45F
0005433131699	276	311	45E
0005433181028	276	312	45H
0005433289806	276	313	45G
0005433181014	276	314	46A
0005433234172	276	315	45K
0005434726181	276	316	45J
0005433234071	276	317	46C
0005433233976	276	318	46B
0005434726226	276	319	46E
0005434726272	276	320	46D
0005434551566	276	321	46H
0005433234257	276	322	46G
0005434032011	276	323	46F
0005434735715	276	324	46K
0005434726264	276	325	46J
0005433234171	276	326	47C
0005433234336	276	327	47A
0005434726236	276	328	47D
0005433233875	276	329	47G
0005432277888	276	330	47F
0005434551573	276	331	47K
0005434726211	276	332	47H
0005434726164	276	333	48C
0005434726283	276	334	48F
0005433180960	276	335	48E
0005432277894	276	336	48D
0005434551597	276	337	48H
0005433234161	276	338	49A
0005434726188	276	339	48K
0005434726230	276	340	49D
0005433181003	276	341	49C
0005434726241	276	342	49G
0005434551556	276	343	49F
0005434726253	276	344	49K
0005434551564	276	345	49H
0005434726228	276	346	50C
0005434302485	276	347	50A
0005434726169	276	348	50F
0005433113539	276	349	50E
0005435142664	276	350	50G
0005434726274	276	351	51D
0005434726173	276	352	50K
0005434551572	276	353	50H
0005433126846	276	354	51F
0005434726177	276	355	51E
0005434725252	9878	1	1C
0005434725956	9878	2	1A
0005434724360	9878	3	1K
0005433234569	9878	4	1H
0005432199293	9878	5	2D
0005433113618	9878	6	2C
0005434725418	9878	7	2A
0005434725303	9878	8	2H
0005434724843	9878	9	2G
0005434551026	9878	10	3A
0005433181255	9878	11	3G
0005433113548	9878	12	3D
0005433234615	9878	13	3C
0005434550856	9878	14	3H
0005434725446	9878	15	4C
0005432199290	9878	16	4G
0005433234567	9878	17	4D
0005433234563	9878	18	4K
0005433234613	9878	19	4H
0005434551116	9878	20	5C
0005433181253	9878	21	5A
0005434551181	9878	22	5H
0005433234610	9878	23	5G
0005434551308	9878	24	5D
0005434551182	9878	25	11A
0005434725417	9878	26	5K
0005434550982	9878	27	11D
0005434550821	9878	28	11C
0005434725647	9878	29	11G
0005434032052	9878	30	11F
0005433181249	9878	31	11E
0005433234578	9878	32	11H
0005434550945	9878	33	12C
0005434551262	9878	34	12A
0005434550925	9878	35	11K
0005433234598	9878	36	12F
0005434302444	9878	37	12E
0005434725362	9878	38	12D
0005434550827	9878	39	12G
0005434550988	9878	40	13A
0005433234607	9878	41	12K
0005434725260	9878	42	12H
0005434550981	9878	43	13C
0005434724867	9878	44	13D
0005433289888	9878	45	13H
0005434724938	9878	46	13G
0005434725527	9878	47	14A
0005434550973	9878	48	13K
0005434551220	9878	49	14E
0005433113550	9878	50	14D
0005433234605	9878	51	14C
0005433234599	9878	52	14F
0005434725536	9878	53	14K
0005434725074	9878	54	14G
0005433766662	9878	55	15C
0005433289891	9878	56	15A
0005434725052	9878	57	15D
0005434725470	9878	58	15H
0005433181243	9878	59	15G
0005434735696	9878	60	15K
0005433234621	9878	61	16D
0005433234576	9878	62	16C
0005433181244	9878	63	16F
0005433234591	9878	64	16E
0005433234617	9878	65	16H
0005433234606	9878	66	16G
0005433181251	9878	67	17A
0005434735681	9878	68	16K
0005433181246	9878	69	17D
0005434551196	9878	70	17C
0005433234596	9878	71	17H
0005434725684	9878	72	17G
0005434725305	9878	73	17K
0005434725153	9878	74	18B
0005434551022	9878	75	18A
0005432199287	9878	76	18E
0005434550938	9878	77	18F
0005434725010	9878	78	18K
0005434550900	9878	79	18H
0005433234566	9878	80	19A
0005433234594	9878	81	19D
0005433289893	9878	82	19C
0005434551137	9878	83	19B
0005434302448	9878	84	19F
0005434724904	9878	85	19K
0005434725611	9878	86	19J
0005434551010	9878	87	20C
0005434724899	9878	88	20B
0005433234565	9878	89	20A
0005433126873	9878	90	20E
0005434551117	9878	91	20G
0005433234618	9878	92	20F
0005434725379	9878	93	20K
0005434725639	9878	94	20J
0005434725509	9878	95	20H
0005434725311	9878	96	21B
0005435142518	9878	97	21A
0005434302442	9878	98	21D
0005434725063	9878	99	21C
0005432199291	9878	100	21G
0005434302456	9878	101	21F
0005434725558	9878	102	21E
0005433234590	9878	103	21H
0005434724705	9878	104	21K
0005434735695	9878	105	22C
0005435142532	9878	106	22B
0005433234625	9878	107	22E
0005434724829	9878	108	22H
0005433289892	9878	109	22G
0005434551206	9878	110	22F
0005433181264	9878	111	22K
0005434550999	9878	112	22J
0005434725129	9878	113	23B
0005434725448	9878	114	23D
0005434725366	9878	115	23C
0005434725180	9878	116	23G
0005433234604	9878	117	23E
0005434725281	9878	118	23J
0005434724943	9878	119	23H
0005433234611	9878	120	23K
0005434302457	9878	121	24F
0005434725055	9878	122	24D
0005434551136	9878	123	25B
0005435142503	9878	124	25A
0005434551205	9878	125	24G
0005434551135	9878	126	25D
0005434551195	9878	127	25C
0005433181263	9878	128	25F
0005433234561	9878	129	25E
0005433129301	9878	130	25H
0005433234579	9878	131	25G
0005434550983	9878	132	25K
0005434725577	9878	133	25J
0005433234572	9878	134	26C
0005434724359	9878	135	26B
0005434731156	9878	136	26A
0005434725648	9878	137	26E
0005433181247	9878	138	26D
0005434551106	9878	139	26G
0005433234585	9878	140	26H
0005433766663	9878	141	27B
0005434551138	9878	142	27A
0005433234595	9878	143	26K
0005434725626	9878	144	27D
0005434550937	9878	145	27C
0005434735682	9878	146	27F
0005434550899	9878	147	27E
0005434725387	9878	148	27J
0005433129305	9878	149	27H
0005433234609	9878	150	27G
0005434724717	9878	151	28A
0005433181261	9878	152	27K
0005434725261	9878	153	28B
0005434551096	9878	154	28E
0005434725610	9878	155	28D
0005434725515	9878	156	28C
0005433129306	9878	157	28H
0005435142504	9878	158	28G
0005434731159	9878	159	28F
0005433234583	9878	160	28J
0005433181265	9878	161	29A
0005433126871	9878	162	28K
0005434725363	9878	163	29C
0005433234619	9878	164	29B
0005433234562	9878	165	29F
0005434725612	9878	166	29E
0005433234581	9878	167	29D
0005434724929	9878	168	29H
0005432199292	9878	169	29G
0005433181259	9878	170	29K
0005434550901	9878	171	29J
0005433234577	9878	172	30C
0005433181267	9878	173	30B
0005433234564	9878	174	30A
0005434724851	9878	175	30D
0005434724813	9878	176	30H
0005433181260	9878	177	30G
0005434731137	9878	178	30F
0005434725073	9878	179	30J
0005434724708	9878	180	31B
0005434724814	9878	181	30K
0005434725140	9878	182	31D
0005434725395	9878	183	31C
0005434724973	9878	184	31G
0005434725537	9878	185	31F
0005433181257	9878	186	31E
0005434725636	9878	187	31H
0005434724828	9878	188	31K
0005435142610	9878	189	31J
0005433234570	9878	190	32C
0005434724944	9878	191	32B
0005434725627	9878	192	32E
0005434725514	9878	193	32D
0005434731158	9878	194	32G
0005433766665	9878	195	32F
0005434731152	9878	196	32J
0005433181245	9878	197	32H
0005433234584	9878	198	33B
0005434724703	9878	199	32K
0005434550963	9878	200	33D
0005434724883	9878	201	33F
0005433113549	9878	202	33E
0005434725458	9878	203	33H
0005433234620	9878	204	33G
0005433234601	9878	205	34A
0005434725456	9878	206	33J
0005434724941	9878	207	34C
0005434725166	9878	208	34B
0005434551066	9878	209	34E
0005434725805	9878	210	34D
0005434725312	9878	211	34H
0005434725336	9878	212	34G
0005433126874	9878	213	34F
0005434725457	9878	214	34K
0005433129302	9878	215	35A
0005433129304	9878	216	35C
0005434550869	9878	217	35F
0005434550966	9878	218	35E
0005433234587	9878	219	35H
0005434551199	9878	220	35G
0005433234586	9878	221	36A
0005433234622	9878	222	35K
0005434731144	9878	223	36C
0005433289887	9878	224	36B
0005433234614	9878	225	36F
0005433234600	9878	226	36D
0005433234573	9878	227	36G
0005434725154	9878	228	36K
0005434725132	9878	229	36J
0005433181256	9878	230	36H
0005434725640	9878	231	37B
0005433234623	9878	232	37A
0005432199288	9878	233	37D
0005434725066	9878	234	37C
0005433234571	9878	235	37G
0005434724932	9878	236	37F
0005434725559	9878	237	37E
0005435142506	9878	238	37H
0005434725469	9878	239	38A
0005434551207	9878	240	37K
0005434550820	9878	241	37J
0005434725259	9878	242	38C
0005433126872	9878	243	38B
0005433181258	9878	244	38K
0005435142533	9878	245	38J
0005433181250	9878	246	39A
0005433181254	9878	247	39D
0005434724897	9878	248	39C
0005434551180	9878	249	39B
0005434302441	9878	250	39F
0005434725466	9878	251	39H
0005434724969	9878	252	40A
0005434725434	9878	253	39K
0005434725338	9878	254	39J
0005434725447	9878	255	40C
0005434725337	9878	256	40B
0005434725306	9878	257	40E
0005434731143	9878	258	40D
0005435142551	9878	259	40H
0005433181248	9878	260	40G
0005433181252	9878	261	40F
0005434724970	9878	262	41B
0005434725403	9878	263	41A
0005434551021	9878	264	41D
0005434724683	9878	265	41C
0005433129303	9878	266	41G
0005434735694	9878	267	41E
0005434725375	9878	268	41H
0005433234592	9878	269	42A
0005434725253	9878	270	41K
0005434725326	9878	271	42C
0005434724934	9878	272	42B
0005433234574	9878	273	42E
0005434551167	9878	274	42D
0005434551095	9878	275	42G
0005434725179	9878	276	42F
0005434550936	9878	277	42K
0005434725150	9878	278	42J
0005434551143	9878	279	42H
0005434725380	9878	280	43B
0005434725302	9878	281	43A
0005434724898	9878	282	43D
0005434725396	9878	283	43C
0005434725181	9878	284	43F
0005432199294	9878	285	43E
0005434032053	9878	286	43H
0005434725404	9878	287	43G
0005433234580	9878	288	43K
0005433289889	9878	289	44C
0005434725122	9878	290	44B
0005434725613	9878	291	44E
0005434724704	9878	292	44D
0005434725423	9878	293	44G
0005433766664	9878	294	44F
0005434724933	9878	295	44J
0005433234597	9878	296	44H
0005434725208	9878	297	45B
0005434725307	9878	298	45A
0005434550919	9878	299	44K
0005433234575	9878	300	45D
0005434725175	9878	301	45C
0005434551131	9878	302	45G
0005433234589	9878	303	45F
0005434725079	9878	304	45E
0005434551105	9878	305	45H
0005433234602	9878	306	46A
0005434550967	9878	307	45K
0005433181262	9878	308	46C
0005434550918	9878	309	46B
0005434032054	9878	310	46E
0005433234568	9878	311	46D
0005434725384	9878	312	46G
0005433181266	9878	313	46F
0005434725370	9878	314	46J
0005434724990	9878	315	46H
0005434725080	9878	316	47C
0005434725578	9878	317	47A
0005433234582	9878	318	46K
0005433234603	9878	319	47E
0005434725141	9878	320	47D
0005432199289	9878	321	47G
0005434725278	9878	322	47F
0005434725242	9878	323	47K
0005433234593	9878	324	48D
0005433234612	9878	325	48C
0005433234616	9878	326	48F
0005434725383	9878	327	48E
0005434032055	9878	328	48H
0005434724894	9878	329	49A
0005434725270	9878	330	48K
0005434725415	9878	331	49C
0005434724719	9878	332	49G
0005434725335	9878	333	49F
0005434550916	9878	334	49E
0005433234588	9878	335	49H
0005434724942	9878	336	50C
0005433234608	9878	337	50A
0005434725530	9878	338	49K
0005434725121	9878	339	50E
0005434725243	9878	340	50D
0005434724939	9878	341	51D
0005434725388	9878	342	50K
0005433234624	9878	343	50H
0005433289890	9878	344	51F
0005434551253	9878	345	51E
0005433289894	9878	346	51G
0005435213486	7749	1	1A
0005432528783	7749	2	1G
0005432528757	7749	3	1D
0005435630959	7749	4	1K
0005434067976	7749	5	2D
0005432150246	7749	6	2C
0005432528852	7749	7	2A
0005432150241	7749	8	2H
0005435725584	7749	9	2K
0005434067970	7749	10	3D
0005432528781	7749	11	3C
0005434067997	7749	12	3H
0005434068000	7749	13	3G
0005435630956	7749	14	4C
0005432528740	7749	15	4A
0005432528730	7749	16	4G
0005434068021	7749	17	4K
0005432528844	7749	18	4H
0005435213419	7749	19	5A
0005435213387	7749	20	5G
0005432069741	7749	21	5D
0005432528851	7749	22	5K
0005432528747	7749	23	5H
0005432528846	7749	24	11D
0005434068037	7749	25	11C
0005435213352	7749	26	11G
0005432528762	7749	27	11F
0005435725554	7749	28	11E
0005432528733	7749	29	11K
0005432528736	7749	30	11H
0005434068036	7749	31	12C
0005432528843	7749	32	12A
0005432528832	7749	33	12E
0005435213348	7749	34	12D
0005432528774	7749	35	12H
0005435630962	7749	36	12G
0005432528820	7749	37	12F
0005435213632	7749	38	13A
0005432528776	7749	39	12K
0005435213403	7749	40	13D
0005432528735	7749	41	13C
0005434068016	7749	42	13F
0005433656667	7749	43	13G
0005434067998	7749	44	14A
0005432528744	7749	45	13K
0005432528777	7749	46	14E
0005432528773	7749	47	14D
0005435213582	7749	48	14C
0005432528800	7749	49	14G
0005435213510	7749	50	14K
0005432528780	7749	51	14H
0005434068033	7749	52	15A
0005434067972	7749	53	15E
0005432535864	7749	54	15D
0005435213667	7749	55	15H
0005432528842	7749	56	15G
0005432528761	7749	57	15F
0005432528763	7749	58	16A
0005435213043	7749	59	15K
0005432528739	7749	60	16D
0005435213606	7749	61	16C
0005434067966	7749	62	16F
0005432533310	7749	63	16H
0005432428948	7749	64	16G
0005435213334	7749	65	17A
0005432528818	7749	66	17E
0005432528791	7749	67	17G
0005432528750	7749	68	17F
0005435213386	7749	69	17K
0005434067994	7749	70	18C
0005434068008	7749	71	18B
0005435213260	7749	72	18A
0005435213023	7749	73	18G
0005432528837	7749	74	18F
0005432069740	7749	75	18E
0005432528766	7749	76	18H
0005435213293	7749	77	19D
0005435213713	7749	78	19C
0005432528797	7749	79	19B
0005432528792	7749	80	19F
0005435213338	7749	81	19E
0005432428950	7749	82	19J
0005434068032	7749	83	19H
0005434067985	7749	84	20A
0005435213218	7749	85	20C
0005435213024	7749	86	20E
0005432528812	7749	87	20F
0005435213315	7749	88	20J
0005432528787	7749	89	20H
0005432528795	7749	90	21A
0005432528821	7749	91	20K
0005432069746	7749	92	21D
0005435725583	7749	93	21C
0005432528748	7749	94	21B
0005432150243	7749	95	21G
0005432528804	7749	96	21E
0005432528802	7749	97	21J
0005432528726	7749	98	21H
0005432528848	7749	99	22A
0005432528725	7749	100	21K
0005432528807	7749	101	22B
0005432069748	7749	102	22F
0005432535865	7749	103	22E
0005434067993	7749	104	22D
0005432069745	7749	105	22H
0005434068012	7749	106	22G
0005432528723	7749	107	22J
0005432069744	7749	108	23B
0005435213436	7749	109	23A
0005432528764	7749	110	23F
0005432528788	7749	111	23E
0005435213438	7749	112	23J
0005432528790	7749	113	23H
0005435213506	7749	114	23G
0005432528721	7749	115	23K
0005432528728	7749	116	24F
0005432528793	7749	117	24E
0005432069747	7749	118	25A
0005432528823	7749	119	24G
0005434067999	7749	120	25C
0005432528720	7749	121	25B
0005435213192	7749	122	25F
0005434067967	7749	123	25E
0005432528732	7749	124	25G
0005432528769	7749	125	25J
0005432528786	7749	126	26A
0005432533311	7749	127	26D
0005434067969	7749	128	26C
0005435212810	7749	129	26G
0005434068027	7749	130	26F
0005432528779	7749	131	26J
0005432528845	7749	132	26H
0005432069739	7749	133	27B
0005432528840	7749	134	27A
0005435213525	7749	135	26K
0005435213267	7749	136	27D
0005435725587	7749	137	27C
0005432150242	7749	138	27F
0005434068014	7749	139	27E
0005432528778	7749	140	27J
0005432528841	7749	141	27H
0005432069751	7749	142	27G
0005432528847	7749	143	28A
0005432528731	7749	144	27K
0005434067984	7749	145	28C
0005434068010	7749	146	28B
0005434068024	7749	147	28E
0005434067980	7749	148	28D
0005432528767	7749	149	28G
0005434068007	7749	150	28F
0005435213263	7749	151	28J
0005435213322	7749	152	28H
0005432528816	7749	153	29A
0005432528752	7749	154	28K
0005435213232	7749	155	29C
0005432528834	7749	156	29B
0005435213376	7749	157	29F
0005432533308	7749	158	29E
0005432528826	7749	159	29J
0005432528819	7749	160	29K
0005432528734	7749	161	30C
0005432428951	7749	162	30B
0005432528724	7749	163	30A
0005432528772	7749	164	30E
0005435213618	7749	165	30D
0005432528755	7749	166	30F
0005435725549	7749	167	30J
0005435213238	7749	168	31B
0005432528836	7749	169	31A
0005432150240	7749	170	30K
0005432528799	7749	171	31D
0005432528737	7749	172	31C
0005434068035	7749	173	31F
0005435213351	7749	174	31E
0005432528759	7749	175	32A
0005435213178	7749	176	31J
0005432528850	7749	177	32C
0005434067974	7749	178	32B
0005432528727	7749	179	32E
0005432528782	7749	180	32D
0005434067992	7749	181	32G
0005435213708	7749	182	32F
0005434067995	7749	183	32J
0005432150244	7749	184	33A
0005432528738	7749	185	33D
0005435213420	7749	186	33C
0005434068030	7749	187	33B
0005434067971	7749	188	33F
0005435213301	7749	189	33E
0005435213393	7749	190	33H
0005434067982	7749	191	33G
0005434068034	7749	192	34A
0005432528796	7749	193	33K
0005432528745	7749	194	33J
0005432528805	7749	195	34C
0005432528751	7749	196	34B
0005434067987	7749	197	34E
0005434068013	7749	198	34D
0005435213617	7749	199	34H
0005432528775	7749	200	34G
0005432528839	7749	201	34F
0005435213524	7749	202	34K
0005433656662	7749	203	34J
0005434067988	7749	204	35B
0005432528815	7749	205	35A
0005432533309	7749	206	35C
0005434067977	7749	207	35G
0005432528771	7749	208	35E
0005433656660	7749	209	35H
0005434067975	7749	210	35J
0005435213622	7749	211	36B
0005432528849	7749	212	36E
0005432528753	7749	213	36G
0005434068015	7749	214	36J
0005432528817	7749	215	37B
0005433656669	7749	216	37A
0005432528827	7749	217	37D
0005432528765	7749	218	37C
0005434068011	7749	219	37F
0005433656661	7749	220	37E
0005434068005	7749	221	37J
0005432528746	7749	222	37H
0005432528808	7749	223	37G
0005434067991	7749	224	37K
0005434068025	7749	225	38C
0005434068001	7749	226	38B
0005435213111	7749	227	38A
0005432069743	7749	228	38J
0005434068004	7749	229	38H
0005432528741	7749	230	39A
0005432528789	7749	231	38K
0005435725588	7749	232	39C
0005435725589	7749	233	39F
0005432528806	7749	234	39H
0005432528798	7749	235	39G
0005432528809	7749	236	39K
0005432528811	7749	237	40C
0005434068022	7749	238	40B
0005434068029	7749	239	40E
0005432528760	7749	240	40D
0005432535862	7749	241	40H
0005432528758	7749	242	40G
0005432528722	7749	243	40F
0005432428949	7749	244	40J
0005434067978	7749	245	41B
0005434068026	7749	246	41A
0005432528729	7749	247	40K
0005432528801	7749	248	41D
0005435213044	7749	249	41F
0005434067986	7749	250	41E
0005434067973	7749	251	41H
0005432528749	7749	252	41G
0005435213412	7749	253	41K
0005435213435	7749	254	42B
0005435213177	7749	255	42A
0005432528829	7749	256	42E
0005434068017	7749	257	42D
0005432528794	7749	258	42H
0005432069750	7749	259	42F
0005435213426	7749	260	42K
0005432528838	7749	261	42J
0005435213303	7749	262	43B
0005434067979	7749	263	43A
0005434067989	7749	264	43D
0005434068002	7749	265	43C
0005432528742	7749	266	43F
0005432069742	7749	267	43E
0005432528756	7749	268	43G
0005434068018	7749	269	44A
0005434068028	7749	270	43K
0005432069749	7749	271	43J
0005435213581	7749	272	44C
0005432528825	7749	273	44B
0005435213288	7749	274	44E
0005432528743	7749	275	44D
0005435213292	7749	276	44G
0005434068020	7749	277	44F
0005432528833	7749	278	44K
0005432528828	7749	279	44J
0005434068009	7749	280	44H
0005432528835	7749	281	45A
0005435213297	7749	282	45C
0005434068023	7749	283	45B
0005435213390	7749	284	45F
0005434068006	7749	285	45E
0005432528814	7749	286	45K
0005432528785	7749	287	46C
0005434067965	7749	288	46B
0005435213437	7749	289	46A
0005432537071	7749	290	46E
0005432528810	7749	291	46G
0005435213349	7749	292	46F
0005435213427	7749	293	46J
0005432528822	7749	294	46H
0005432528784	7749	295	47C
0005432528830	7749	296	47A
0005434067996	7749	297	46K
0005435213456	7749	298	47E
0005434068019	7749	299	47D
0005435213576	7749	300	47K
0005434068031	7749	301	47H
0005432528754	7749	302	48C
0005432528831	7749	303	48A
0005432528768	7749	304	48E
0005432528803	7749	305	48H
0005432528813	7749	306	48G
0005435213560	7749	307	48F
0005434067968	7749	308	49A
0005435630955	7749	309	48K
0005432535863	7749	310	49D
0005432150245	7749	311	49C
0005434068003	7749	312	49G
0005432528824	7749	313	49F
0005434067983	7749	314	49E
0005435213465	7749	315	49H
0005434067981	7749	316	50A
0005435213266	7749	317	50E
0005435213439	7749	318	50G
0005432069738	7749	319	50F
0005432528719	7749	320	51D
0005434067990	7749	321	51F
0005432528770	7749	322	51E
0005433656650	7749	323	51G
0005435614405	5355	1	1C
0005435614369	5355	2	1A
0005435614395	5355	3	1G
0005432363418	5355	4	1D
0005432133297	5355	5	1K
0005435490252	5355	6	1H
0005435424756	5355	7	2D
0005434573440	5355	8	2C
0005435424956	5355	9	2A
0005434344462	5355	10	2H
0005435424480	5355	11	2G
0005435614321	5355	12	3A
0005435424627	5355	13	2K
0005435614409	5355	14	3D
0005435424743	5355	15	3C
0005435424739	5355	16	3H
0005434244812	5355	17	3G
0005434244918	5355	18	4C
0005435424754	5355	19	3K
0005435614378	5355	20	4G
0005435614368	5355	21	4D
0005435614367	5355	22	5A
0005435424875	5355	23	4K
0005435042848	5355	24	4H
0005435424784	5355	25	5H
0005435614316	5355	26	5G
0005435614317	5355	27	11A
0005435424648	5355	28	5K
0005435424901	5355	29	11E
0005435614353	5355	30	11H
0005432133303	5355	31	11G
0005435319567	5355	32	12A
0005434344461	5355	33	11K
0005435424508	5355	34	12E
0005434573438	5355	35	12D
0005435614318	5355	36	12H
0005435424867	5355	37	12G
0005435614370	5355	38	12F
0005435424752	5355	39	13A
0005435424700	5355	40	12K
0005434344457	5355	41	13D
0005434244928	5355	42	13C
0005435614351	5355	43	13F
0005434573434	5355	44	13E
0005435424625	5355	45	13H
0005434573442	5355	46	13G
0005432133310	5355	47	14A
0005434344437	5355	48	13K
0005435424872	5355	49	14E
0005434573436	5355	50	14D
0005432841006	5355	51	14C
0005434244923	5355	52	14F
0005435614354	5355	53	14G
0005434244894	5355	54	15D
0005435614343	5355	55	15C
0005435614413	5355	56	15A
0005435614383	5355	57	15E
0005434244856	5355	58	15G
0005435424593	5355	59	15F
0005435614381	5355	60	16A
0005435614336	5355	61	15K
0005435491450	5355	62	15H
0005434244849	5355	63	16D
0005435424510	5355	64	16C
0005435424765	5355	65	16F
0005432841003	5355	66	16H
0005435614394	5355	67	16G
0005434244885	5355	68	17C
0005434573447	5355	69	17A
0005434244811	5355	70	16K
0005435614337	5355	71	17D
0005435424880	5355	72	17G
0005432133311	5355	73	17F
0005435614332	5355	74	18A
0005435424735	5355	75	17K
0005434344469	5355	76	17H
0005435302207	5355	77	18B
0005435424923	5355	78	18E
0005435424745	5355	79	18D
0005432133304	5355	80	18C
0005435614333	5355	81	18G
0005432133308	5355	82	18F
0005435097264	5355	83	18J
0005435424482	5355	84	18H
0005434244855	5355	85	19B
0005435319560	5355	86	19A
0005435097260	5355	87	19D
0005435097267	5355	88	19C
0005435614322	5355	89	19F
0005435614359	5355	90	19E
0005435319578	5355	91	19H
0005435614382	5355	92	19G
0005434573437	5355	93	19K
0005435614358	5355	94	20C
0005435614360	5355	95	20B
0005435614356	5355	96	20A
0005435614371	5355	97	20E
0005435491452	5355	98	20D
0005435097258	5355	99	20G
0005435614392	5355	100	20F
0005434344446	5355	101	20J
0005434245013	5355	102	20H
0005435424788	5355	103	21B
0005434344456	5355	104	21A
0005432841015	5355	105	21C
0005435424532	5355	106	21F
0005435614403	5355	107	21E
0005432133309	5355	108	21H
0005434573441	5355	109	21G
0005434344447	5355	110	21K
0005434344442	5355	111	21J
0005435614404	5355	112	22C
0005435614417	5355	113	22B
0005435614365	5355	114	22E
0005435424874	5355	115	22D
0005435424782	5355	116	22H
0005435614397	5355	117	22G
0005435614376	5355	118	22F
0005435425035	5355	119	22K
0005432047574	5355	120	22J
0005435424734	5355	121	23B
0005432047575	5355	122	23A
0005435614340	5355	123	23D
0005434245004	5355	124	23C
0005435302193	5355	125	23F
0005435424561	5355	126	23E
0005432363419	5355	127	23J
0005435614372	5355	128	23H
0005435424683	5355	129	23G
0005435424792	5355	130	24D
0005434344450	5355	131	23K
0005435097259	5355	132	24G
0005435614374	5355	133	24F
0005434344438	5355	134	24E
0005435614325	5355	135	25B
0005435614389	5355	136	25C
0005435424695	5355	137	25F
0005435424501	5355	138	25D
0005435614388	5355	139	25H
0005432363407	5355	140	25G
0005434344455	5355	141	25K
0005434573435	5355	142	26C
0005434344465	5355	143	26A
0005435614414	5355	144	26F
0005435614386	5355	145	26J
0005434344468	5355	146	26H
0005434244895	5355	147	27A
0005435424591	5355	148	26K
0005435042842	5355	149	27D
0005435614348	5355	150	27C
0005435614418	5355	151	27B
0005435424071	5355	152	27F
0005435614320	5355	153	27H
0005435424639	5355	154	27G
0005435097266	5355	155	27K
0005432133301	5355	156	28B
0005434344458	5355	157	28A
0005432047573	5355	158	28E
0005432133305	5355	159	28C
0005435614364	5355	160	28H
0005435097262	5355	161	28G
0005435302170	5355	162	28F
0005435319540	5355	163	28J
0005435424753	5355	164	29A
0005435424619	5355	165	28K
0005435490251	5355	166	29C
0005435424580	5355	167	29G
0005432363422	5355	168	29F
0005434344444	5355	169	29E
0005435614363	5355	170	29D
0005435319539	5355	171	29H
0005435614412	5355	172	30A
0005435319538	5355	173	29K
0005435424690	5355	174	30C
0005435097257	5355	175	30B
0005432363420	5355	176	30E
0005434244875	5355	177	30D
0005435424866	5355	178	30G
0005435614390	5355	179	30F
0005434573444	5355	180	30K
0005434244951	5355	181	30J
0005435614352	5355	182	30H
0005432363401	5355	183	31B
0005435614402	5355	184	31D
0005432047571	5355	185	31C
0005434573445	5355	186	31F
0005435319577	5355	187	31E
0005434344439	5355	188	31H
0005434244943	5355	189	31G
0005434244748	5355	190	32A
0005434344459	5355	191	31K
0005435614406	5355	192	31J
0005435614366	5355	193	32B
0005435424626	5355	194	32D
0005434244942	5355	195	32G
0005434244886	5355	196	32F
0005435424842	5355	197	32J
0005435424905	5355	198	32H
0005435614335	5355	199	33A
0005435614407	5355	200	32K
0005435614342	5355	201	33C
0005432363408	5355	202	33B
0005435302171	5355	203	33F
0005435614396	5355	204	33H
0005435614357	5355	205	33G
0005435424646	5355	206	33K
0005435424385	5355	207	33J
0005434244848	5355	208	34C
0005435424693	5355	209	34B
0005435424620	5355	210	34A
0005435614410	5355	211	34E
0005435424706	5355	212	34D
0005435424618	5355	213	34G
0005435424433	5355	214	34F
0005435319559	5355	215	34K
0005435614344	5355	216	34H
0005435424879	5355	217	35A
0005435424846	5355	218	35D
0005435424786	5355	219	35C
0005433719122	5355	220	35B
0005434244924	5355	221	35F
0005435614400	5355	222	35E
0005434244933	5355	223	35H
0005434245003	5355	224	35G
0005435614346	5355	225	36A
0005435491451	5355	226	35J
0005435424787	5355	227	36C
0005435614384	5355	228	36B
0005434344443	5355	229	36F
0005435097265	5355	230	36E
0005435614334	5355	231	36D
0005435614327	5355	232	36G
0005435614373	5355	233	36K
0005434244878	5355	234	36J
0005435424922	5355	235	36H
0005434244739	5355	236	37B
0005434244835	5355	237	37A
0005435424785	5355	238	37D
0005435302190	5355	239	37C
0005435424317	5355	240	37G
0005434244740	5355	241	37F
0005435424647	5355	242	37E
0005435424741	5355	243	37J
0005435614401	5355	244	37H
0005434573443	5355	245	38A
0005434344445	5355	246	38C
0005435424707	5355	247	38K
0005432363410	5355	248	38H
0005434344452	5355	249	39D
0005432133300	5355	250	39C
0005432133302	5355	251	39B
0005435425034	5355	252	39F
0005435302192	5355	253	39E
0005435424761	5355	254	39H
0005434573446	5355	255	39G
0005435302206	5355	256	39K
0005435614380	5355	257	39J
0005434244879	5355	258	40C
0005432363421	5355	259	40B
0005435424640	5355	260	40E
0005435614330	5355	261	40D
0005435319566	5355	262	40G
0005435614345	5355	263	40F
0005435319574	5355	264	40J
0005435614341	5355	265	40H
0005435490249	5355	266	41A
0005435097263	5355	267	41D
0005435614419	5355	268	41C
0005434344467	5355	269	41B
0005434344448	5355	270	41F
0005435424481	5355	271	41E
0005435424873	5355	272	41J
0005434344464	5355	273	42A
0005435614331	5355	274	41K
0005435614347	5355	275	42C
0005435424906	5355	276	42B
0005432363406	5355	277	42E
0005435614324	5355	278	42D
0005434344463	5355	279	42G
0005435424579	5355	280	42F
0005435614398	5355	281	42J
0005435614323	5355	282	42H
0005434244934	5355	283	43B
0005435614361	5355	284	42K
0005432133306	5355	285	43D
0005435614393	5355	286	43C
0005435614385	5355	287	43E
0005435424736	5355	288	43H
0005435614338	5355	289	44A
0005435614375	5355	290	43K
0005435614377	5355	291	43J
0005434344454	5355	292	44B
0005435614391	5355	293	44E
0005435302191	5355	294	44D
0005435614399	5355	295	44G
0005435424831	5355	296	44F
0005435614319	5355	297	44K
0005434344451	5355	298	44J
0005435614339	5355	299	44H
0005435424506	5355	300	45B
0005434244826	5355	301	45A
0005435614329	5355	302	45D
0005435424689	5355	303	45C
0005434244847	5355	304	45F
0005432133299	5355	305	45E
0005435424779	5355	306	45J
0005435614350	5355	307	45H
0005432047572	5355	308	46A
0005435424509	5355	309	45K
0005435424072	5355	310	46C
0005432363411	5355	311	46E
0005435424507	5355	312	46D
0005434344441	5355	313	46G
0005435614349	5355	314	46F
0005435302189	5355	315	46K
0005434344453	5355	316	46J
0005435614362	5355	317	46H
0005435424744	5355	318	47C
0005435424777	5355	319	47A
0005432133307	5355	320	47D
0005434344440	5355	321	47G
0005435614408	5355	322	47F
0005435424705	5355	323	47E
0005435614326	5355	324	47K
0005435424789	5355	325	47H
0005435614328	5355	326	48D
0005434344449	5355	327	48C
0005435424660	5355	328	48A
0005435424497	5355	329	48E
0005435614379	5355	330	48H
0005435424957	5355	331	48G
0005435097261	5355	332	48F
0005434573439	5355	333	49A
0005435614416	5355	334	48K
0005435424781	5355	335	49E
0005435424692	5355	336	49G
0005435614355	5355	337	49F
0005432133298	5355	338	49K
0005434344466	5355	339	50C
0005435614387	5355	340	50A
0005435490250	5355	341	50E
0005434344460	5355	342	50D
0005435614411	5355	343	51D
0005435424633	5355	344	50K
0005435614415	5355	345	50H
0005435424592	5355	346	51G
0005435613044	10914	1	1C
0005434245169	10914	2	1A
0005435319626	10914	3	1G
0005435613759	10914	4	1D
0005435304186	10914	5	2A
0005434344060	10914	6	1K
0005435613182	10914	7	1H
0005435613404	10914	8	2C
0005435613551	10914	9	2G
0005435425208	10914	10	2D
0005435613539	10914	11	3A
0005434245163	10914	12	2K
0005435613294	10914	13	3G
0005435555371	10914	14	3D
0005434245164	10914	15	3C
0005435425240	10914	16	3K
0005435425231	10914	17	3H
0005434343995	10914	18	4C
0005434343919	10914	19	4G
0005435613615	10914	20	4D
0005435425228	10914	21	4K
0005435613277	10914	22	4H
0005434573346	10914	23	5D
0005435042870	10914	24	5A
0005435380318	10914	25	5H
0005434343999	10914	26	5G
0005435555373	10914	27	11A
0005434245176	10914	28	5K
0005435613691	10914	29	11D
0005435425218	10914	30	11F
0005435613650	10914	31	11K
0005435612892	10914	32	11H
0005435380319	10914	33	11G
0005434245147	10914	34	12C
0005435613405	10914	35	12A
0005434343935	10914	36	12F
0005435425247	10914	37	12E
0005432166922	10914	38	12D
0005435425227	10914	39	12H
0005435425230	10914	40	12G
0005435425243	10914	41	13A
0005435425236	10914	42	12K
0005435425263	10914	43	13C
0005432166921	10914	44	13E
0005432165088	10914	45	13G
0005435613718	10914	46	14C
0005435555365	10914	47	14A
0005434344053	10914	48	13K
0005434573287	10914	49	14E
0005435613332	10914	50	14D
0005435097153	10914	51	14G
0005434344073	10914	52	14F
0005435380317	10914	53	14K
0005435425225	10914	54	14H
0005435613334	10914	55	15C
0005435613505	10914	56	15E
0005434245175	10914	57	15D
0005435319631	10914	58	15G
0005435613051	10914	59	15F
0005435613087	10914	60	15K
0005434245158	10914	61	16D
0005435425214	10914	62	16F
0005435425256	10914	63	16E
0005435425202	10914	64	16H
0005434344068	10914	65	16G
0005435613568	10914	66	17C
0005434343988	10914	67	17A
0005435613124	10914	68	17E
0005435425220	10914	69	17D
0005435425252	10914	70	17G
0005435425200	10914	71	17F
0005435425217	10914	72	18A
0005435425249	10914	73	17K
0005435425234	10914	74	17H
0005435613728	10914	75	18C
0005435613268	10914	76	18B
0005435613537	10914	77	18E
0005432165084	10914	78	18D
0005434344175	10914	79	18G
0005435305024	10914	80	18H
0005435097184	10914	81	19A
0005435097185	10914	82	18K
0005434344024	10914	83	19B
0005435425224	10914	84	19F
0005435613574	10914	85	19E
0005434344121	10914	86	19H
0005435613285	10914	87	19G
0005432841026	10914	88	20A
0005435319628	10914	89	19K
0005435613133	10914	90	19J
0005434344107	10914	91	20C
0005434344000	10914	92	20B
0005435425264	10914	93	20E
0005435613625	10914	94	20H
0005434344047	10914	95	20F
0005435425255	10914	96	20K
0005432363437	10914	97	20J
0005435613760	10914	98	21A
0005435613316	10914	99	21C
0005435613407	10914	100	21B
0005435425209	10914	101	21F
0005435425211	10914	102	21E
0005435425199	10914	103	21H
0005435613457	10914	104	22A
0005435425206	10914	105	21J
0005434344062	10914	106	22C
0005434343842	10914	107	22B
0005435613552	10914	108	22F
0005435613450	10914	109	22G
0005435613425	10914	110	22K
0005435425242	10914	111	22J
0005434344251	10914	112	22H
0005435613369	10914	113	23A
0005435555370	10914	114	23D
0005435613134	10914	115	23C
0005434344173	10914	116	23G
0005435613261	10914	117	23F
0005435304184	10914	118	23E
0005435097133	10914	119	23H
0005433719163	10914	120	24D
0005435425237	10914	121	24G
0005435613270	10914	122	24E
0005435319627	10914	123	25A
0005434245153	10914	124	25C
0005435613579	10914	125	25F
0005435613547	10914	126	25E
0005435614003	10914	127	25J
0005435613147	10914	128	25H
0005432165082	10914	129	25G
0005435425245	10914	130	25K
0005432363434	10914	131	26C
0005435613573	10914	132	26B
0005434344019	10914	133	26A
0005435425207	10914	134	26E
0005435425213	10914	135	26D
0005435425210	10914	136	26F
0005432363436	10914	137	26K
0005435425198	10914	138	26J
0005435425216	10914	139	26H
0005435425266	10914	140	27B
0005435612703	10914	141	27A
0005435305023	10914	142	27D
0005435613227	10914	143	27C
0005435305025	10914	144	27E
0005435042869	10914	145	27H
0005435612838	10914	146	27G
0005434245173	10914	147	28A
0005435613192	10914	148	27K
0005434573257	10914	149	27J
0005435613586	10914	150	28B
0005435613333	10914	151	28E
0005435042867	10914	152	28C
0005434344040	10914	153	28G
0005435613506	10914	154	28F
0005435425233	10914	155	28J
0005435097194	10914	156	28H
0005434344072	10914	157	29A
0005435380316	10914	158	28K
0005434245167	10914	159	29D
0005434343918	10914	160	29C
0005435613538	10914	161	29G
0005435425212	10914	162	29F
0005434573293	10914	163	29E
0005432166923	10914	164	29H
0005435612857	10914	165	30A
0005435425241	10914	166	29K
0005435425221	10914	167	29J
0005435425248	10914	168	30C
0005435613661	10914	169	30B
0005434245166	10914	170	30E
0005432165085	10914	171	30D
0005435491434	10914	172	30G
0005435425259	10914	173	30F
0005435042866	10914	174	30J
0005435613092	10914	175	30H
0005434344234	10914	176	31A
0005435425257	10914	177	31D
0005435613689	10914	178	31C
0005435614029	10914	179	31F
0005434245149	10914	180	31K
0005434245161	10914	181	31J
0005435425215	10914	182	32C
0005435613300	10914	183	32B
0005435612957	10914	184	32A
0005435425205	10914	185	32E
0005434343972	10914	186	32D
0005435613536	10914	187	32G
0005434245151	10914	188	32J
0005434245172	10914	189	32H
0005432165083	10914	190	33B
0005435614030	10914	191	33A
0005434656570	10914	192	32K
0005435613340	10914	193	33D
0005435319630	10914	194	33C
0005434573265	10914	195	33F
0005435612854	10914	196	33J
0005435613076	10914	197	33H
0005434344046	10914	198	33G
0005435613317	10914	199	33K
0005435425219	10914	200	34C
0005435380320	10914	201	34B
0005434245155	10914	202	34A
0005435555366	10914	203	34E
0005435612811	10914	204	34D
0005435613507	10914	205	34G
0005435613578	10914	206	34F
0005435613597	10914	207	34J
0005435097183	10914	208	35B
0005434344130	10914	209	34K
0005434344122	10914	210	35D
0005434245170	10914	211	35C
0005435613378	10914	212	35G
0005435613360	10914	213	35F
0005434344123	10914	214	35E
0005433719161	10914	215	35H
0005435613614	10914	216	36A
0005434573282	10914	217	35K
0005435613379	10914	218	35J
0005434245152	10914	219	36C
0005435380321	10914	220	36B
0005434245148	10914	221	36F
0005435613410	10914	222	36E
0005435613426	10914	223	36D
0005435613156	10914	224	36H
0005435425258	10914	225	36G
0005434573289	10914	226	36K
0005432363435	10914	227	36J
0005434573345	10914	228	37B
0005434344115	10914	229	37A
0005435425250	10914	230	37E
0005435613752	10914	231	37D
0005434344012	10914	232	37C
0005434245168	10914	233	37F
0005434344103	10914	234	37H
0005434245160	10914	235	38A
0005435425226	10914	236	37K
0005435613662	10914	237	37J
0005435319624	10914	238	38H
0005434344108	10914	239	38B
0005435425253	10914	240	38J
0005435613780	10914	241	39B
0005434343994	10914	242	39A
0005435613262	10914	243	38K
0005435613678	10914	244	39D
0005432165087	10914	245	39C
0005434656569	10914	246	39J
0005435319625	10914	247	39H
0005435613624	10914	248	39G
0005435613357	10914	249	40A
0005435613401	10914	250	39K
0005435613223	10914	251	40C
0005435304185	10914	252	40B
0005435612893	10914	253	40D
0005435425239	10914	254	40G
0005435613308	10914	255	40F
0005435425203	10914	256	40J
0005435319629	10914	257	40H
0005435613293	10914	258	40K
0005434245150	10914	259	41C
0005434344252	10914	260	41F
0005435613374	10914	261	41E
0005435425223	10914	262	41J
0005435613677	10914	263	41H
0005435613311	10914	264	41K
0005434573309	10914	265	42C
0005435613201	10914	266	42B
0005432165086	10914	267	42A
0005435613727	10914	268	42E
0005434573256	10914	269	42D
0005435425229	10914	270	42G
0005435425201	10914	271	42K
0005435613286	10914	272	42J
0005435613427	10914	273	42H
0005435613375	10914	274	43B
0005435613259	10914	275	43A
0005435613290	10914	276	43D
0005435425238	10914	277	43C
0005435425244	10914	278	43F
0005434573273	10914	279	43E
0005435613312	10914	280	43H
0005435425261	10914	281	43G
0005432165081	10914	282	43K
0005435613576	10914	283	43J
0005435380322	10914	284	44C
0005435042868	10914	285	44B
0005432841027	10914	286	44A
0005435425254	10914	287	44E
0005435613511	10914	288	44D
0005434245159	10914	289	44G
0005434573313	10914	290	44F
0005435097170	10914	291	44J
0005435425260	10914	292	44H
0005435613211	10914	293	45B
0005435425251	10914	294	45A
0005435613789	10914	295	45C
0005434343934	10914	296	45F
0005435613644	10914	297	45E
0005434344131	10914	298	45J
0005435425222	10914	299	45H
0005435613651	10914	300	45G
0005434245162	10914	301	45K
0005435613645	10914	302	46C
0005435613415	10914	303	46B
0005435425235	10914	304	46A
0005435490222	10914	305	46E
0005432841025	10914	306	46D
0005434245156	10914	307	46G
0005435613781	10914	308	46F
0005435612891	10914	309	46J
0005435613530	10914	310	47C
0005435097160	10914	311	47A
0005435613441	10914	312	46K
0005435613337	10914	313	47E
0005434573307	10914	314	47D
0005434245171	10914	315	47G
0005435613445	10914	316	47F
0005435613155	10914	317	47K
0005435425262	10914	318	47H
0005434245165	10914	319	48D
0005433719162	10914	320	48A
0005435613549	10914	321	48E
0005435613428	10914	322	48H
0005435613471	10914	323	49C
0005434344124	10914	324	49A
0005434573270	10914	325	48K
0005434245157	10914	326	49D
0005435319623	10914	327	49G
0005435425204	10914	328	49F
0005435613496	10914	329	49E
0005435613565	10914	330	49K
0005435425265	10914	331	49H
0005434344104	10914	332	50D
0005434245174	10914	333	50C
0005435613458	10914	334	50A
0005435613692	10914	335	50E
0005435613695	10914	336	50G
0005434573255	10914	337	50F
0005435613486	10914	338	51D
0005435425232	10914	339	50K
0005434245154	10914	340	50H
0005435425246	10914	341	51F
0005435613585	10914	342	51E
0005435613510	10914	343	51G
0005433507294	3257	1	1A
0005433805600	3257	2	1C
0005433805599	3257	3	1F
0005433805588	3257	4	1D
0005432459647	3257	5	2A
0005432181856	3257	6	2C
0005432459651	3257	7	2F
0005432459736	3257	8	2D
0005434143740	3257	9	3A
0005433634037	3257	10	3C
0005433805579	3257	11	3D
0005432181847	3257	12	4A
0005433805587	3257	13	3F
0005432459625	3257	14	4C
0005433805578	3257	15	4D
0005433634046	3257	16	5A
0005432459785	3257	17	4F
0005432181850	3257	18	5C
0005432459729	3257	19	5F
0005432459835	3257	20	5D
0005433634035	3257	21	6C
0005433634029	3257	22	6A
0005433507299	3257	23	6D
0005432181865	3257	24	7A
0005433634041	3257	25	6F
0005432181848	3257	26	7C
0005433634020	3257	27	7D
0005433507298	3257	28	8A
0005432459769	3257	29	7F
0005434143733	3257	30	8B
0005433805605	3257	31	8D
0005432459648	3257	32	8C
0005432459855	3257	33	8E
0005432459745	3257	34	8F
0005432459626	3257	35	9A
0005433507300	3257	36	9C
0005433805596	3257	37	9B
0005434143736	3257	38	9E
0005432181859	3257	39	9D
0005432181846	3257	40	10A
0005432459786	3257	41	9F
0005433805595	3257	42	10C
0005434143738	3257	43	10B
0005433805608	3257	44	10D
0005433507297	3257	45	10E
0005433634040	3257	46	10F
0005433507288	3257	47	11C
0005434143737	3257	48	11B
0005433507289	3257	49	11D
0005433805583	3257	50	11F
0005432181849	3257	51	11E
0005432459737	3257	52	12A
0005432459673	3257	53	12B
0005433634049	3257	54	12D
0005433805592	3257	55	12C
0005433634047	3257	56	12E
0005433634045	3257	57	12F
0005433805577	3257	58	13B
0005433805586	3257	59	13A
0005433634018	3257	60	13C
0005432459482	3257	61	13D
0005433507290	3257	62	13F
0005433507296	3257	63	13E
0005433634042	3257	64	14A
0005432459555	3257	65	14B
0005433805582	3257	66	14D
0005433805574	3257	67	14C
0005432459738	3257	68	14E
0005432459675	3257	69	15A
0005433634026	3257	70	14F
0005433634025	3257	71	15B
0005433634036	3257	72	15C
0005433805590	3257	73	15D
0005433805598	3257	74	15E
0005433805589	3257	75	16A
0005432181852	3257	76	15F
0005433805610	3257	77	16B
0005433634033	3257	78	16C
0005433634017	3257	79	16E
0005433805573	3257	80	17A
0005433507295	3257	81	16F
0005433634019	3257	82	17B
0005433634016	3257	83	17C
0005433805581	3257	84	17D
0005433507291	3257	85	17F
0005434143739	3257	86	17E
0005433805593	3257	87	18A
0005432181862	3257	88	18B
0005432459714	3257	89	18C
0005432181845	3257	90	18D
0005432459720	3257	91	18F
0005433805603	3257	92	18E
0005434143731	3257	93	19C
0005432181857	3257	94	19B
0005433507293	3257	95	19D
0005433634032	3257	96	20A
0005432459674	3257	97	19E
0005433507287	3257	98	20C
0005432459775	3257	99	20B
0005433634039	3257	100	21A
0005432459715	3257	101	21B
0005432181855	3257	102	21D
0005433634044	3257	103	21C
0005433634050	3257	104	21E
0005432459483	3257	105	21F
0005433634048	3257	106	22B
0005432459795	3257	107	22A
0005432460055	3257	108	22C
0005432181854	3257	109	22E
0005433805575	3257	110	22D
0005432459739	3257	111	22F
0005432181853	3257	112	23A
0005432459854	3257	113	23C
0005432459566	3257	114	23B
0005433634038	3257	115	23D
0005433805591	3257	116	23F
0005433805585	3257	117	23E
0005433805580	3257	118	24B
0005433634023	3257	119	24A
0005433805611	3257	120	24C
0005433805609	3257	121	24E
0005433805576	3257	122	24D
0005432459776	3257	123	24F
0005433634024	3257	124	25A
0005433634031	3257	125	25C
0005433805615	3257	126	25B
0005433805614	3257	127	25D
0005434143735	3257	128	25F
0005433805601	3257	129	25E
0005432181864	3257	130	26A
0005433507301	3257	131	26C
0005433805612	3257	132	26B
0005433805597	3257	133	26D
0005434143734	3257	134	26E
0005434143732	3257	135	26F
0005433634021	3257	136	27B
0005432181843	3257	137	27A
0005433805584	3257	138	27C
0005433805607	3257	139	27D
0005433805594	3257	140	27E
0005433634027	3257	141	27F
0005432459541	3257	142	28C
0005433805606	3257	143	28B
0005432181863	3257	144	28A
0005432181851	3257	145	28D
0005432181861	3257	146	28E
0005432459503	3257	147	28F
0005432459751	3257	148	29A
0005433634034	3257	149	29C
0005432181858	3257	150	29B
0005432181844	3257	151	29D
0005432459770	3257	152	29E
0005433507292	3257	153	30A
0005432459567	3257	154	29F
0005432181860	3257	155	30B
0005433634022	3257	156	30C
0005433805613	3257	157	30E
0005433634028	3257	158	30D
0005432459772	3257	159	30F
0005433805604	3257	160	31B
0005433634030	3257	161	31A
0005433634043	3257	162	31C
0005432459827	3257	163	31D
0005433805602	3257	164	31F
0005435885141	3256	1	1A
0005435885101	3256	2	1C
0005435885246	3256	3	1F
0005435885327	3256	4	1D
0005435885346	3256	5	4D
0005435885295	3256	6	5D
0005435885254	3256	7	6A
0005435885126	3256	8	6F
0005435885207	3256	9	7C
0005435885502	3256	10	8A
0005435885159	3256	11	7F
0005435885238	3256	12	8B
0005435885117	3256	13	8C
0005435885068	3256	14	9B
0005435885099	3256	15	9E
0005435885145	3256	16	10B
0005435885187	3256	17	10D
0005435885185	3256	18	10F
0005435885164	3256	19	11A
0005435885154	3256	20	11F
0005435885305	3256	21	12C
0005435885146	3256	22	13D
0005435885315	3256	23	14A
0005435885194	3256	24	14B
0005435885311	3256	25	15A
0005435885087	3256	26	15C
0005435884906	3256	27	15D
0005435885056	3256	28	16D
0005435885503	3256	29	16F
0005435885124	3256	30	17C
0005435885310	3256	31	18A
0005435885175	3256	32	18B
0005435885321	3256	33	18D
0005435885127	3256	34	18E
0005435885121	3256	35	19B
0005435885203	3256	36	19D
0005435885184	3256	37	19E
0005435885208	3256	38	20B
0005435885122	3256	39	21D
0005435885245	3256	40	22B
0005435885142	3256	41	22E
0005435885100	3256	42	22F
0005435885280	3256	43	23C
0005435885104	3256	44	23E
0005435885328	3256	45	24C
0005435885193	3256	46	24F
0005435885118	3256	47	25C
0005435885264	3256	48	25E
0005435885163	3256	49	26A
0005435885349	3256	50	26B
0005435885108	3256	51	27F
0005435885088	3256	52	27E
0005435885260	3256	53	28A
0005435885050	3256	54	29C
0005435885322	3256	55	30A
0005435885155	3256	56	30E
0005435885158	3256	57	31A
0005435885236	3256	58	31F
0005435885538	8282	1	1A
0005435885548	8282	2	1C
0005433507044	8282	3	1D
0005432460229	8282	4	2A
0005432460190	8282	5	1F
0005435885546	8282	6	2C
0005435885534	8282	7	2D
0005435885573	8282	8	3A
0005432460230	8282	9	3C
0005435885547	8282	10	4A
0005433507115	8282	11	4C
0005435885537	8282	12	4F
0005433507152	8282	13	5D
0005435885535	8282	14	5C
0005435885539	8282	15	6A
0005432460196	8282	16	5F
0005432460231	8282	17	6C
0005435885556	8282	18	6F
0005433507093	8282	19	6D
0005433507168	8282	20	7A
0005435885550	8282	21	7C
0005433507081	8282	22	7D
0005433507121	8282	23	8A
0005432460200	8282	24	8D
0005432460235	8282	25	8E
0005433507129	8282	26	9A
0005432460232	8282	27	9B
0005435885553	8282	28	9E
0005432042808	8282	29	9D
0005433507131	8282	30	10A
0005432460218	8282	31	9F
0005435885542	8282	32	10B
0005432460202	8282	33	10D
0005435885551	8282	34	10C
0005435885532	8282	35	10E
0005432460198	8282	36	11B
0005432460226	8282	37	11A
0005432042799	8282	38	11C
0005435885530	8282	39	11D
0005435885569	8282	40	11F
0005432460227	8282	41	12A
0005435885543	8282	42	12C
0005435885557	8282	43	12B
0005435885565	8282	44	12F
0005432460221	8282	45	13B
0005435885552	8282	46	13A
0005432460203	8282	47	13C
0005433507112	8282	48	13D
0005435885570	8282	49	13F
0005432460191	8282	50	13E
0005434312334	8282	51	14A
0005435885533	8282	52	14B
0005432460205	8282	53	14D
0005435885549	8282	54	14C
0005435885568	8282	55	15A
0005432042806	8282	56	14F
0005433507228	8282	57	15E
0005432460233	8282	58	15D
0005435885545	8282	59	16A
0005432460201	8282	60	15F
0005432460222	8282	61	16D
0005432460219	8282	62	16C
0005432460220	8282	63	16E
0005432042797	8282	64	17A
0005435885554	8282	65	16F
0005435885541	8282	66	17C
0005432460216	8282	67	17B
0005433507099	8282	68	17D
0005432042796	8282	69	17F
0005435885562	8282	70	17E
0005433507070	8282	71	18A
0005434312335	8282	72	18C
0005432460194	8282	73	18E
0005432460217	8282	74	18F
0005432460236	8282	75	19E
0005432460192	8282	76	20B
0005432460237	8282	77	20A
0005432042809	8282	78	20E
0005435885561	8282	79	20D
0005432460213	8282	80	20F
0005432460207	8282	81	21C
0005432460208	8282	82	21E
0005433507138	8282	83	21F
0005432460195	8282	84	22B
0005435885559	8282	85	22A
0005433507227	8282	86	22D
0005432460186	8282	87	22C
0005432042805	8282	88	22E
0005432460211	8282	89	22F
0005435885558	8282	90	23B
0005435885536	8282	91	23A
0005432460225	8282	92	23C
0005435885567	8282	93	23E
0005433507101	8282	94	24A
0005432042798	8282	95	23F
0005433507114	8282	96	24B
0005432460214	8282	97	24D
0005433507137	8282	98	24C
0005435885540	8282	99	24E
0005432460210	8282	100	24F
0005432460209	8282	101	25C
0005432460212	8282	102	25B
0005435885564	8282	103	25E
0005432460197	8282	104	26A
0005432460193	8282	105	25F
0005435885566	8282	106	26C
0005432460223	8282	107	26E
0005432460188	8282	108	26D
0005432042803	8282	109	26F
0005434312333	8282	110	27A
0005432460206	8282	111	27C
0005432460199	8282	112	27D
0005435885572	8282	113	27E
0005435885563	8282	114	28B
0005432042807	8282	115	28C
0005432460224	8282	116	28D
0005432042804	8282	117	29A
0005432042801	8282	118	28F
0005432460187	8282	119	28E
0005432042800	8282	120	29B
0005432460228	8282	121	29D
0005435885571	8282	122	29F
0005432042802	8282	123	29E
0005432460185	8282	124	30C
0005432460234	8282	125	30A
0005435885544	8282	126	30E
0005432460204	8282	127	30D
0005432460215	8282	128	31A
0005435885531	8282	129	30F
0005435885560	8282	130	31B
0005435885555	8282	131	31C
0005432460189	8282	132	31D
0005433507151	8282	133	31F
0005433633671	8275	1	1C
0005433633584	8275	2	1D
0005433805344	8275	3	2A
0005433633577	8275	4	2D
0005433805236	8275	5	3F
0005433805310	8275	6	4C
0005433805499	8275	7	5A
0005433633606	8275	8	6A
0005433805235	8275	9	7A
0005433805176	8275	10	7D
0005435854061	8275	11	8A
0005433805135	8275	12	8D
0005433805182	8275	13	8F
0005433633749	8275	14	9B
0005433633761	8275	15	9D
0005433633782	8275	16	9E
0005433633679	8275	17	10A
0005433805361	8275	18	10B
0005433633622	8275	19	10C
0005433805295	8275	20	10E
0005433805500	8275	21	11C
0005433633746	8275	22	12A
0005433805294	8275	23	12B
0005433633651	8275	24	12C
0005433805282	8275	25	12E
0005433633859	8275	26	12F
0005433633821	8275	27	13D
0005435854062	8275	28	13E
0005433805398	8275	29	14D
0005433805327	8275	30	14C
0005433805301	8275	31	14E
0005433805300	8275	32	15D
0005433805332	8275	33	16B
0005433805360	8275	34	16A
0005433805148	8275	35	16F
0005433633747	8275	36	17C
0005433805462	8275	37	17D
0005433805274	8275	38	17F
0005433633734	8275	39	17E
0005433633570	8275	40	18E
0005433633783	8275	41	18D
0005433805269	8275	42	18F
0005433633539	8275	43	19C
0005433633743	8275	44	20C
0005433805204	8275	45	21E
0005433805338	8275	46	21F
0005433805264	8275	47	22B
0005433633860	8275	48	22C
0005433633602	8275	49	23A
0005433633861	8275	50	23D
0005433805346	8275	51	24D
0005433633864	8275	52	24F
0005433805178	8275	53	25B
0005433805237	8275	54	26B
0005433633695	8275	55	26D
0005433805305	8275	56	26C
0005433805304	8275	57	27B
0005433633603	8275	58	27C
0005433805217	8275	59	27E
0005433805281	8275	60	27F
0005433805161	8275	61	28C
0005433633666	8275	62	28E
0005433805132	8275	63	28D
0005433805331	8275	64	28F
0005433805345	8275	65	29D
0005433805270	8275	66	29E
0005433805359	8275	67	30C
0005433633400	8275	68	30B
0005433633769	8275	69	31A
0005433805177	8275	70	31D
0005433805293	8275	71	31C
0005433633605	8275	72	31E
0005434183574	8264	1	11C
0005434183575	8264	2	18B
0005434183576	8264	3	19D
0005432383443	4562	1	1C
0005432383433	4562	2	1D
0005432383421	4562	3	2A
0005432383436	4562	4	2D
0005432728016	4562	5	2F
0005432383437	4562	6	3A
0005432728012	4562	7	3C
0005432383411	4562	8	3D
0005432728023	4562	9	3F
0005432728018	4562	10	4A
0005432383442	4562	11	4C
0005433722271	4562	12	4D
0005432383427	4562	13	5A
0005432383406	4562	14	5C
0005432383408	4562	15	5D
0005432728017	4562	16	5F
0005432728011	4562	17	6C
0005432383424	4562	18	6D
0005432383431	4562	19	6E
0005432728013	4562	20	6F
0005432728020	4562	21	7A
0005432728022	4562	22	7C
0005433454888	4562	23	7D
0005432383409	4562	24	7E
0005432383438	4562	25	7F
0005432383415	4562	26	9A
0005433453772	4562	27	9C
0005432383412	4562	28	9D
0005433454890	4562	29	9E
0005432383435	4562	30	10A
0005432383403	4562	31	10D
0005432383432	4562	32	10E
0005432383413	4562	33	10F
0005432383434	4562	34	11A
0005432383407	4562	35	11D
0005433454889	4562	36	11E
0005432383430	4562	37	11F
0005432383422	4562	38	12A
0005432728019	4562	39	12C
0005432383429	4562	40	13A
0005432383439	4562	41	13D
0005432728014	4562	42	13E
0005432383404	4562	43	14C
0005432383423	4562	44	14D
0005432383425	4562	45	14F
0005432383410	4562	46	15A
0005433454891	4562	47	15C
0005432383419	4562	48	15D
0005432383420	4562	49	15E
0005432383426	4562	50	15F
0005432383402	4562	51	16F
0005432383441	4562	52	17A
0005432728015	4562	53	17C
0005432728021	4562	54	17D
0005432383405	4562	55	17E
0005432383418	4562	56	17F
0005433722270	4562	57	18C
0005432383428	4562	58	18E
0005432383440	4562	59	19A
0005432383416	4562	60	19C
0005433194861	4562	61	19D
0005432383414	4562	62	20C
0005432383417	4562	63	20E
0005433453750	30101	1	1A
0005433194845	30101	2	1C
0005432382929	30101	3	2A
0005433194847	30101	4	2C
0005433722186	30101	5	2D
0005433722184	30101	6	3D
0005432382964	30101	7	3F
0005433722182	30101	8	4A
0005433722214	30101	9	4D
0005432727904	30101	10	4E
0005432382838	30101	11	5A
0005432382889	30101	12	5D
0005433722221	30101	13	5E
0005432383073	30101	14	5F
0005432382861	30101	15	6A
0005432382862	30101	16	6D
0005432382985	30101	17	6E
0005432382962	30101	18	6F
0005432383066	30101	19	7D
0005433722185	30101	20	7F
0005432383065	30101	21	8C
0005433722171	30101	22	8E
0005433194857	30101	23	8F
0005432382905	30101	24	9C
0005433722219	30101	25	9D
0005432382950	30101	26	10A
0005433722208	30101	27	10C
0005432727886	30101	28	10D
0005432382868	30101	29	10E
0005432382984	30101	30	11C
0005433722195	30101	31	11F
0005433194834	30101	32	12D
0005432382952	30101	33	12E
0005433722203	30101	34	12F
0005433453744	30101	35	13C
0005432382963	30101	36	13D
0005432382933	30101	37	14A
0005432382897	30101	38	14C
0005432382826	30101	39	14D
0005433451608	30101	40	14E
0005433722207	30101	41	14F
0005432383091	30101	42	15C
0005433453743	30101	43	15E
0005432383120	30101	44	15F
0005432727893	30101	45	16A
0005433722218	30101	46	16C
0005433722210	30101	47	16D
0005433722220	30101	48	16E
0005432727908	30101	49	16F
0005432382936	30101	50	17A
0005432382911	30101	51	17D
0005432382907	30101	52	17E
0005433722172	30101	53	17F
0005433194836	30101	54	18A
0005433722224	30101	55	19A
0005432727894	30101	56	19C
0005432382867	30101	57	19E
0005432382937	30101	58	19F
0005432382935	30101	59	20A
0005432727909	30101	60	20D
0005433722213	30101	61	20E
0005432925009	1735	1	1F
0005433516950	1735	2	2C
0005432294503	1735	3	2D
0005435529392	1735	4	2F
0005435529402	1735	5	3C
0005435541139	1735	6	3D
0005435529393	1735	7	3F
0005435529388	1735	8	4A
0005433516945	1735	9	4F
0005435529401	1735	10	5C
0005433516946	1735	11	5D
0005435541148	1735	12	5F
0005435529394	1735	13	6A
0005433516948	1735	14	6C
0005435529391	1735	15	6F
0005435541149	1735	16	7A
0005435529408	1735	17	7C
0005435529398	1735	18	8A
0005435529396	1735	19	8C
0005435529404	1735	20	8E
0005435541136	1735	21	8F
0005433516947	1735	22	9A
0005433516941	1735	23	9D
0005435529410	1735	24	9F
0005435529403	1735	25	10A
0005435541137	1735	26	11A
0005435541146	1735	27	11C
0005435529407	1735	28	11D
0005435541132	1735	29	12C
0005435541147	1735	30	12E
0005435541145	1735	31	12F
0005432925017	1735	32	13A
0005435541138	1735	33	13C
0005433516942	1735	34	13E
0005435529399	1735	35	13F
0005435541143	1735	36	14A
0005435541142	1735	37	14C
0005435529406	1735	38	14D
0005432925018	1735	39	14E
0005435541151	1735	40	14F
0005435541150	1735	41	15A
0005435529397	1735	42	15D
0005435541153	1735	43	15E
0005435541133	1735	44	15F
0005435541140	1735	45	16A
0005435529395	1735	46	16C
0005435541135	1735	47	16D
0005433516944	1735	48	16E
0005435541141	1735	49	16F
0005435541144	1735	50	17A
0005435529389	1735	51	17C
0005435541152	1735	52	17D
0005435541134	1735	53	17E
0005435529390	1735	54	18A
0005435529405	1735	55	18C
0005433516943	1735	56	18E
0005432925019	1735	57	19F
0005432294502	1735	58	20A
0005433516949	1735	59	20C
0005435529400	1735	60	20D
0005435529409	1735	61	20F
0005435517786	21974	1	1D
0005435540919	21974	2	1F
0005435540941	21974	3	2A
0005433516865	21974	4	2C
0005433516864	21974	5	3A
0005435517831	21974	6	4A
0005435517826	21974	7	5C
0005435517892	21974	8	6C
0005432925065	21974	9	6E
0005432925066	21974	10	7D
0005435540960	21974	11	8A
0005435517758	21974	12	8E
0005435517822	21974	13	8F
0005435540897	21974	14	10A
0005435540940	21974	15	10C
0005435540964	21974	16	10D
0005435517910	21974	17	10E
0005435517830	21974	18	11A
0005435517832	21974	19	11C
0005435541076	21974	20	11E
0005435517759	21974	21	12A
0005435540918	21974	22	12C
0005435540855	21974	23	12D
0005435540973	21974	24	12E
0005435540895	21974	25	12F
0005435517839	21974	26	13A
0005435517911	21974	27	13C
0005435517930	21974	28	13D
0005435540943	21974	29	13F
0005435517881	21974	30	14F
0005433516863	21974	31	15A
0005432925068	21974	32	15D
0005432925067	21974	33	16C
0005435517931	21974	34	16F
0005435540835	21974	35	17F
0005435517945	21974	36	18D
0005435540896	21974	37	18E
0005435517879	21974	38	19A
0005435540967	21974	39	19D
0005435517840	21974	40	19F
0005435517818	21974	41	20D
0005434458936	7363	1	1A
0005434664958	7363	2	1C
0005435252586	7363	3	1D
0005435252599	7363	4	1F
0005432839238	7363	5	2A
0005432839228	7363	6	2C
0005432073413	7363	7	2D
0005434458924	7363	8	2F
0005434458929	7363	9	3A
0005434458944	7363	10	3C
0005434664956	7363	11	3D
0005432839230	7363	12	3F
0005432839225	7363	13	4A
0005435252676	7363	14	4C
0005432841024	7363	15	4D
0005435252572	7363	16	4E
0005432839221	7363	17	4F
0005432839215	7363	18	5A
0005435252584	7363	19	5C
0005434458925	7363	20	5D
0005435252618	7363	21	5E
0005434458942	7363	22	5F
0005435252585	7363	23	6A
0005432839244	7363	24	6C
0005435252656	7363	25	6D
0005432839229	7363	26	6E
0005434458937	7363	27	6F
0005435252613	7363	28	7A
0005432839233	7363	29	7D
0005435252703	7363	30	7E
0005432841023	7363	31	8A
0005432839234	7363	32	8C
0005432839216	7363	33	8D
0005435252729	7363	34	8E
0005432839232	7363	35	8F
0005432073410	7363	36	9A
0005434458932	7363	37	9C
0005432839220	7363	38	9D
0005434458941	7363	39	9E
0005432839212	7363	40	9F
0005434458940	7363	41	10A
0005435252682	7363	42	10C
0005432839242	7363	43	10D
0005435252614	7363	44	10E
0005432839224	7363	45	10F
0005432073411	7363	46	11A
0005435252654	7363	47	11C
0005434458928	7363	48	11D
0005435252615	7363	49	11E
0005435252687	7363	50	11F
0005432839236	7363	51	12A
0005435252545	7363	52	12C
0005434458931	7363	53	12D
0005434458930	7363	54	12E
0005434458943	7363	55	12F
0005435491431	7363	56	13A
0005434458927	7363	57	13C
0005435491429	7363	58	13D
0005435252624	7363	59	13E
0005432839241	7363	60	13F
0005432073412	7363	61	14A
0005435491433	7363	62	14C
0005434458938	7363	63	14D
0005434458935	7363	64	14E
0005434458933	7363	65	14F
0005432839235	7363	66	15A
0005432839213	7363	67	15C
0005434458926	7363	68	15D
0005432839239	7363	69	15E
0005432839237	7363	70	15F
0005435252681	7363	71	16A
0005432839214	7363	72	16C
0005432839218	7363	73	16D
0005435252707	7363	74	16E
0005432839240	7363	75	16F
0005434664959	7363	76	17A
0005435252617	7363	77	17C
0005432839219	7363	78	17D
0005434458946	7363	79	17E
0005435252660	7363	80	17F
0005432839227	7363	81	18A
0005434458934	7363	82	18C
0005432839222	7363	83	18D
0005435252673	7363	84	18E
0005432839243	7363	85	18F
0005432839223	7363	86	19A
0005435252730	7363	87	19C
0005432839217	7363	88	19D
0005435252671	7363	89	19E
0005434458945	7363	90	19F
0005432839226	7363	91	20A
0005432823461	7363	92	20C
0005432839231	7363	93	20E
0005434458939	7363	94	20F
0005434458679	28898	1	1A
0005434458765	28898	2	1D
0005434458770	28898	3	1F
0005435491453	28898	4	2A
0005432838795	28898	5	2C
0005434458729	28898	6	2D
0005434458724	28898	7	2F
0005434458812	28898	8	3A
0005435252818	28898	9	3C
0005432839069	28898	10	3D
0005432839013	28898	11	3F
0005434664975	28898	12	4A
0005432839138	28898	13	4D
0005432838962	28898	14	4E
0005435252819	28898	15	4F
0005434458728	28898	16	5C
0005432838786	28898	17	5D
0005434458730	28898	18	5E
0005432841004	28898	19	5F
0005432839071	28898	20	6C
0005432839137	28898	21	6D
0005432839064	28898	22	6F
0005432838918	28898	23	7A
0005434458691	28898	24	7C
0005434458722	28898	25	7E
0005435252805	28898	26	7F
0005432839011	28898	27	8A
0005435252813	28898	28	8C
0005432839093	28898	29	8D
0005432838997	28898	30	8E
0005432838796	28898	31	8F
0005432838986	28898	32	9D
0005432001036	28898	33	9E
0005435252806	28898	34	9F
0005434458795	28898	35	10A
0005432838998	28898	36	10D
0005432839058	28898	37	10C
0005432839014	28898	38	10F
0005432823440	28898	39	11A
0005432841005	28898	40	11C
0005432838916	28898	41	11F
0005432838917	28898	42	12A
0005434458816	28898	43	12D
0005432838860	28898	44	12F
0005432839017	28898	45	13C
0005435252807	28898	46	13D
0005432838958	28898	47	13E
0005432838945	28898	48	13F
0005432838785	28898	49	14A
0005435252808	28898	50	14C
0005432838925	28898	51	14D
0005435252811	28898	52	14E
0005434458739	28898	53	14F
0005434458740	28898	54	15A
0005434664974	28898	55	15C
0005434458738	28898	56	15D
0005435252817	28898	57	15E
0005432839034	28898	58	15F
0005435252815	28898	59	16A
0005434458723	28898	60	16C
0005435252816	28898	61	16E
0005434458784	28898	62	16F
0005435252812	28898	63	17A
0005432838919	28898	64	17D
0005435491454	28898	65	17E
0005435252820	28898	66	17F
0005435252803	28898	67	18A
0005434458743	28898	68	18C
0005435252810	28898	69	18D
0005432838938	28898	70	18E
0005432839072	28898	71	18F
0005434458707	28898	72	19A
0005434458692	28898	73	19C
0005432838957	28898	74	19D
0005434458850	28898	75	19E
0005432839033	28898	76	20A
0005435252814	28898	77	19F
0005434458830	28898	78	20C
0005435252809	28898	79	20D
0005435252804	28898	80	20E
0005434458721	28898	81	20F
0005434276026	8772	1	1C
0005434276025	8772	2	2F
0005435990671	8772	3	3F
0005435990669	8772	4	7F
0005435990667	8772	5	8F
0005435990666	8772	6	9C
0005435990665	8772	7	13E
0005435990670	8772	8	16D
0005435990668	8772	9	17D
0005434275995	8772	10	17E
0005434276032	8772	11	20A
0005435990664	8772	12	21C
0005434276062	15711	1	3A
0005435990587	15711	2	5A
0005435990633	15711	3	7A
0005435990600	15711	4	7F
0005435990632	15711	5	8E
0005435990609	15711	6	9C
0005434276064	15711	7	10A
0005435990601	15711	8	11A
0005434276060	15711	9	11E
0005434276063	15711	10	12A
0005435990610	15711	11	12F
0005435990634	15711	12	16F
0005435990577	15711	13	16E
0005434276065	15711	14	17E
0005435990576	15711	15	18A
0005434276061	15711	16	18F
0005433468393	2093	1	1C
0005433468394	2093	2	1D
0005433468392	2093	3	2A
0005432909260	2093	4	2C
0005433468387	2093	5	2D
0005433468397	2093	6	3A
0005433468384	2093	7	4D
0005433468383	2093	8	5A
0005432909292	2093	9	5B
0005432909251	2093	10	5C
0005433468395	2093	11	6B
0005433468388	2093	12	6C
0005432909267	2093	13	6D
0005433468390	2093	14	7C
0005433468391	2093	15	7D
0005433468398	2093	16	19A
0005432909256	2093	17	19D
0005433468386	2093	18	20A
0005432909277	2093	19	20D
0005433468382	2093	20	21A
0005432909259	2093	21	21B
0005433468385	2093	22	21D
0005433468389	2093	23	22C
0005433468396	2093	24	23A
0005432909268	2093	25	23B
0005432909314	23849	1	1A
0005432909313	23849	2	1B
0005432909306	23849	3	1D
0005433468308	23849	4	2A
0005432909316	23849	5	2B
0005432909310	23849	6	2C
0005433468287	23849	7	2D
0005433468310	23849	8	3A
0005433468359	23849	9	3B
0005433468301	23849	10	3C
0005433468297	23849	11	3D
0005433468292	23849	12	4A
0005433468313	23849	13	4B
0005433468335	23849	14	4C
0005433468324	23849	15	4D
0005432909305	23849	16	5A
0005433468291	23849	17	5B
0005433468306	23849	18	5C
0005433468299	23849	19	5D
0005433468302	23849	20	6A
0005433468317	23849	21	6B
0005433468329	23849	22	6C
0005433468325	23849	23	6D
0005433468282	23849	24	7A
0005433468285	23849	25	7B
0005432909309	23849	26	7C
0005433468307	23849	27	7D
0005433468283	23849	28	18A
0005433468271	23849	29	18B
0005432909319	23849	30	18C
0005432909311	23849	31	18D
0005432909308	23849	32	19A
0005433468296	23849	33	19B
0005432909317	23849	34	19C
0005433468303	23849	35	19D
0005433468322	23849	36	20A
0005432909315	23849	37	20B
0005432909312	23849	38	20C
0005432909318	23849	39	20D
0005433468281	23849	40	21A
0005433468312	23849	41	21B
0005433468272	23849	42	21C
0005433468333	23849	43	21D
0005432909307	23849	44	22A
0005433468305	23849	45	22B
0005433468298	23849	46	22C
0005433468358	23849	47	22D
0005432909320	23849	48	23A
0005433468334	23849	49	23B
0005432360655	6408	1	1A
0005432360646	6408	2	1C
0005435177126	6408	3	1D
0005435177042	6408	4	2A
0005435490222	6408	5	1F
0005435177003	6408	6	2C
0005432360662	6408	7	2D
0005432360660	6408	8	2F
0005432360656	6408	9	3A
0005432062263	6408	10	3D
0005434149702	6408	11	3C
0005432336107	6408	12	3F
0005432360650	6408	13	4B
0005432336110	6408	14	4A
0005432360665	6408	15	4C
0005432360684	6408	16	4D
0005435177146	6408	17	4E
0005435176972	6408	18	5B
0005435176979	6408	19	5D
0005432360667	6408	20	5E
0005435177047	6408	21	5F
0005432360680	6408	22	6B
0005432360679	6408	23	6C
0005432336102	6408	24	6E
0005432336109	6408	25	7A
0005435177067	6408	26	6F
0005435177120	6408	27	7C
0005432336106	6408	28	7B
0005432360678	6408	29	7E
0005432062260	6408	30	7D
0005434149689	6408	31	7F
0005432360676	6408	32	8A
0005432360649	6408	33	8B
0005432360675	6408	34	8C
0005435177145	6408	35	8E
0005435177082	6408	36	8D
0005434149629	6408	37	8F
0005432336113	6408	38	9A
0005432363434	6408	39	9C
0005432360670	6408	40	9D
0005432360659	6408	41	9F
0005432360651	6408	42	9E
0005435177004	6408	43	10B
0005434149688	6408	44	10D
0005432360654	6408	45	10C
0005435177089	6408	46	10E
0005435177026	6408	47	11A
0005432360685	6408	48	11C
0005432363436	6408	49	11B
0005435176977	6408	50	11E
0005432360641	6408	51	11D
0005435176939	6408	52	12C
0005432062262	6408	53	12B
0005432360647	6408	54	12E
0005435177168	6408	55	12D
0005432336105	6408	56	13B
0005434149699	6408	57	13A
0005432336111	6408	58	13D
0005435177051	6408	59	13C
0005432360671	6408	60	13E
0005434149678	6408	61	13F
0005435176978	6408	62	14B
0005434149694	6408	63	14A
0005432336104	6408	64	14C
0005435177048	6408	65	14D
0005432360686	6408	66	14E
0005435177107	6408	67	14F
0005432360657	6408	68	15B
0005432336112	6408	69	15C
0005435177121	6408	70	15D
0005432360644	6408	71	15E
0005432360645	6408	72	16A
0005435177081	6408	73	16B
0005435177153	6408	74	16D
0005432360681	6408	75	16E
0005434149693	6408	76	17A
0005432360663	6408	77	17B
0005432336103	6408	78	17C
0005435177060	6408	79	17E
0005432062261	6408	80	17D
0005432360682	6408	81	17F
0005432360677	6408	82	18B
0005435723040	6408	83	18A
0005432360653	6408	84	18C
0005434149672	6408	85	18E
0005432363437	6408	86	18F
0005432360643	6408	87	19A
0005432360661	6408	88	19B
0005435177021	6408	89	19D
0005432360673	6408	90	19C
0005432062264	6408	91	19F
0005432336114	6408	92	19E
0005434149685	6408	93	20A
0005432363435	6408	94	20C
0005434149718	6408	95	20B
0005435177058	6408	96	20D
0005432360639	6408	97	20E
0005432360658	6408	98	20F
0005432360642	6408	99	21A
0005435177050	6408	100	21C
0005435177049	6408	101	21B
0005432360668	6408	102	21D
0005435177062	6408	103	21E
0005432360664	6408	104	21F
0005432360672	6408	105	22B
0005432360648	6408	106	22A
0005432360683	6408	107	22C
0005434149703	6408	108	22D
0005432360666	6408	109	22E
0005432360652	6408	110	23A
0005432336108	6408	111	22F
0005435177022	6408	112	23B
0005432360640	6408	113	23C
0005432360674	6408	114	23D
0005432360669	6408	115	23E
0005432336063	21031	1	1A
0005432360128	21031	2	1C
0005435490256	21031	3	2A
0005435177255	21031	4	1F
0005432360183	21031	5	2C
0005435177241	21031	6	2D
0005435177259	21031	7	2F
0005434149808	21031	8	3C
0005432360200	21031	9	3A
0005432052766	21031	10	3D
0005432360165	21031	11	3F
0005432360140	21031	12	4B
0005434149800	21031	13	4A
0005435723060	21031	14	4C
0005432360356	21031	15	4E
0005434149797	21031	16	5A
0005435490253	21031	17	5C
0005435177236	21031	18	5D
0005434149799	21031	19	5E
0005435177239	21031	20	6A
0005434149806	21031	21	6B
0005432360117	21031	22	6C
0005435177245	21031	23	6D
0005432336013	21031	24	6E
0005434149804	21031	25	6F
0005435177252	21031	26	7C
0005432360172	21031	27	7E
0005432360139	21031	28	7D
0005432360439	21031	29	7F
0005435177233	21031	30	8A
0005434149801	21031	31	8B
0005435177234	21031	32	8D
0005432336012	21031	33	8C
0005432336048	21031	34	8F
0005435177260	21031	35	9A
0005435177246	21031	36	9C
0005432360197	21031	37	9B
0005432336009	21031	38	9E
0005432360173	21031	39	9D
0005432360177	21031	40	9F
0005432360230	21031	41	10C
0005435177247	21031	42	10E
0005432360312	21031	43	11A
0005435177250	21031	44	11B
0005435177257	21031	45	11D
0005435177238	21031	46	11C
0005434149798	21031	47	11E
0005432360355	21031	48	12A
0005432360063	21031	49	12B
0005435490255	21031	50	12E
0005434149802	21031	51	12D
0005432360166	21031	52	13A
0005432359964	21031	53	12F
0005435177237	21031	54	13C
0005434149807	21031	55	13D
0005432360036	21031	56	13F
0005432360261	21031	57	13E
0005432052763	21031	58	14A
0005432360292	21031	59	14C
0005432360234	21031	60	14B
0005435177249	21031	61	14D
0005432360317	21031	62	14E
0005435177242	21031	63	15A
0005432360222	21031	64	14F
0005435177235	21031	65	15B
0005432360201	21031	66	15C
0005432360296	21031	67	15D
0005432360035	21031	68	15E
0005432360175	21031	69	16A
0005432363412	21031	70	16B
0005432360214	21031	71	16C
0005432360259	21031	72	16E
0005432360061	21031	73	16D
0005432360119	21031	74	16F
0005435177240	21031	75	17B
0005435490257	21031	76	17A
0005432360224	21031	77	17C
0005432360316	21031	78	17E
0005432360167	21031	79	17D
0005435177243	21031	80	17F
0005432360185	21031	81	18A
0005435177244	21031	82	18B
0005432363417	21031	83	18D
0005432360209	21031	84	18C
0005435177248	21031	85	18E
0005432052765	21031	86	18F
0005435723058	21031	87	19A
0005435177251	21031	88	19C
0005432052764	21031	89	19B
0005435177256	21031	90	19E
0005432360252	21031	91	19D
0005435177258	21031	92	20C
0005434149805	21031	93	20B
0005432360215	21031	94	20D
0005435723059	21031	95	20E
0005432360032	21031	96	20F
0005432336010	21031	97	21A
0005435490254	21031	98	21C
0005432360269	21031	99	21B
0005432359965	21031	100	21F
0005432360080	21031	101	21E
0005434149803	21031	102	22A
0005432360361	21031	103	22B
0005432335979	21031	104	22C
0005432360238	21031	105	22D
0005432360179	21031	106	22E
0005432360389	21031	107	22F
0005432360060	21031	108	23B
0005435177253	21031	109	23A
0005432360176	21031	110	23C
0005435177254	21031	111	23D
0005432360334	21031	112	23E
0005434448298	17704	1	1A
0005434458819	17704	2	1B
0005434458814	17704	3	1C
0005434186218	17704	4	1D
0005434448297	17704	5	2A
0005434186217	17704	6	2B
0005434458833	17704	7	3A
0005434458807	17704	8	3B
0005434458763	17704	9	3C
0005434458736	17704	10	3D
0005434458766	17704	11	4A
0005434458798	17704	12	4B
0005434186216	17704	13	4C
0005434458852	17704	14	5B
0005434458764	17704	15	5C
0005434458794	17704	16	5D
0005434461639	17704	17	6A
0005434458797	17704	18	6B
0005434458832	17704	19	6D
0005434458820	17704	20	7A
0005434458854	17704	21	7B
0005434458793	17704	22	7C
0005434458792	17704	23	7D
0005434458742	17704	24	18A
0005434448299	17704	25	18B
0005434458829	17704	26	18C
0005434458755	17704	27	19A
0005434458753	17704	28	19B
0005434458853	17704	29	19C
0005434458735	17704	30	19D
0005434458741	17704	31	20A
0005434458808	17704	32	20B
0005434458734	17704	33	20C
0005434458828	17704	34	20D
0005434458733	17704	35	21A
0005434458815	17704	36	21B
0005434458777	17704	37	21D
0005434458690	17704	38	22A
0005434458767	17704	39	22B
0005434458754	17704	40	22C
0005434458818	17704	41	22D
0005434458809	17704	42	23A
0005434458858	17704	43	23B
0005434458926	29097	1	1A
0005434463941	29097	2	1C
0005434458933	29097	3	1D
0005434458944	29097	4	2C
0005434458927	29097	5	2D
0005434462803	29097	6	3A
0005434463940	29097	7	3B
0005434458938	29097	8	3C
0005434458945	29097	9	4A
0005434458928	29097	10	4C
0005434458941	29097	11	5A
0005434458935	29097	12	5B
0005434186203	29097	13	6A
0005434448332	29097	14	6B
0005434458930	29097	15	6D
0005434458929	29097	16	7A
0005434462802	29097	17	7C
0005434458940	29097	18	7D
0005434186200	29097	19	18A
0005434458942	29097	20	18B
0005434458931	29097	21	19B
0005434458924	29097	22	19C
0005434458937	29097	23	19D
0005434458925	29097	24	20C
0005434458946	29097	25	20D
0005434458943	29097	26	21A
0005434186180	29097	27	21B
0005434458936	29097	28	21C
0005434458939	29097	29	21D
0005434458932	29097	30	22A
0005434448334	29097	31	22B
0005434448333	29097	32	22C
0005434458934	29097	33	23B
0005432604557	21424	1	1A
0005432604565	21424	2	1B
0005432604549	21424	3	1C
0005432604547	21424	4	1D
0005432604571	21424	5	2A
0005432604575	21424	6	2B
0005432604564	21424	7	2C
0005432604558	21424	8	2D
0005432604542	21424	9	3A
0005432604544	21424	10	3B
0005432604554	21424	11	3C
0005432604561	21424	12	4A
0005432604550	21424	13	3D
0005432604567	21424	14	4B
0005432604559	21424	15	4C
0005432604560	21424	16	4D
0005432604540	21424	17	5A
0005432604551	21424	18	5B
0005432604576	21424	19	5C
0005432604538	21424	20	5D
0005432604534	21424	21	6A
0005432604566	21424	22	6C
0005432604546	21424	23	6D
0005432604548	21424	24	7A
0005432604537	21424	25	7B
0005432604543	21424	26	7D
0005432604574	21424	27	18A
0005432604553	21424	28	18B
0005432604555	21424	29	18C
0005432604536	21424	30	18D
0005432604556	21424	31	19A
0005432604535	21424	32	19B
0005432604562	21424	33	19C
0005432604552	21424	34	20A
0005432604568	21424	35	20C
0005432604563	21424	36	20D
0005432604572	21424	37	21B
0005432604545	21424	38	21C
0005432604573	21424	39	21D
0005432604541	21424	40	22C
0005432604569	21424	41	22D
0005432604570	21424	42	23A
0005432604539	21424	43	23B
0005432604238	31701	1	1A
0005432604057	31701	2	1B
0005435221063	31701	3	2A
0005432604362	31701	4	2B
0005432604305	31701	5	2C
0005435221523	31701	6	3B
0005432604198	31701	7	3C
0005432604249	31701	8	3D
0005435221522	31701	9	4B
0005432604178	31701	10	4D
0005432604272	31701	11	5B
0005432604261	31701	12	5D
0005432604136	31701	13	6A
0005432604135	31701	14	6C
0005432604205	31701	15	7B
0005432604012	31701	16	7C
0005432604175	31701	17	18A
0005432604361	31701	18	18B
0005435221062	31701	19	18C
0005432604204	31701	20	18D
0005432604199	31701	21	19A
0005432604368	31701	22	19B
0005432604230	31701	23	19C
0005432604071	31701	24	20B
0005432604351	31701	25	20C
0005432604206	31701	26	20D
0005432604129	31701	27	21A
0005432604257	31701	28	21B
0005432604262	31701	29	21C
0005432604298	31701	30	21D
0005432604241	31701	31	22A
0005432604128	31701	32	22B
0005432604317	31701	33	22C
0005432604200	31701	34	22D
0005432604158	31701	35	23A
0005433293300	29601	1	1C
0005433293293	29601	2	2C
0005433293287	29601	3	3B
0005433293296	29601	4	3D
0005433293297	29601	5	5A
0005433293295	29601	6	5C
0005433293291	29601	7	6C
0005433293288	29601	8	7A
0005433293289	29601	9	7C
0005433293286	29601	10	18D
0005433293298	29601	11	19C
0005433293299	29601	12	19D
0005433293290	29601	13	22A
0005433293292	29601	14	22B
0005433293294	29601	15	22D
0005433473311	6689	1	1A
0005435257222	6689	2	1D
0005433473313	6689	3	2B
0005433473318	6689	4	2D
0005433473314	6689	5	3C
0005435257209	6689	6	3D
0005435257232	6689	7	4A
0005433473323	6689	8	4B
0005433473310	6689	9	4C
0005433473316	6689	10	5A
0005433473321	6689	11	5C
0005433473325	6689	12	5D
0005433473328	6689	13	6A
0005433473309	6689	14	6C
0005433473317	6689	15	6D
0005435257241	6689	16	7C
0005435257240	6689	17	7D
0005433473324	6689	18	18A
0005435257242	6689	19	18D
0005433473315	6689	20	19B
0005433473320	6689	21	19C
0005435257210	6689	22	19D
0005433473312	6689	23	21A
0005433473326	6689	24	21B
0005433473327	6689	25	21D
0005435257212	6689	26	22C
0005433473322	6689	27	22D
0005433473319	6689	28	23A
0005433473216	23898	1	1A
0005435257269	23898	2	1C
0005433473195	23898	3	1D
0005433473237	23898	4	2A
0005435257268	23898	5	2B
0005433473196	23898	6	2C
0005435257273	23898	7	3A
0005433473227	23898	8	3C
0005435257261	23898	9	4A
0005433473226	23898	10	4B
0005433473250	23898	11	4C
0005433473305	23898	12	4D
0005433473198	23898	13	5A
0005433473219	23898	14	5B
0005435257266	23898	15	5C
0005435257265	23898	16	5D
0005435257271	23898	17	6A
0005433473218	23898	18	6B
0005435257270	23898	19	6D
0005435257274	23898	20	6C
0005435257258	23898	21	7A
0005433473206	23898	22	7B
0005435257267	23898	23	7C
0005433473203	23898	24	7D
0005435257263	23898	25	18A
0005435257259	23898	26	18B
0005433473260	23898	27	18C
0005433473215	23898	28	18D
0005433473217	23898	29	19A
0005433473213	23898	30	19B
0005435257260	23898	31	19C
0005433473238	23898	32	19D
0005433473232	23898	33	20A
0005433473228	23898	34	20B
0005435257262	23898	35	20D
0005433473306	23898	36	21B
0005433473204	23898	37	21C
0005433473197	23898	38	21D
0005433473185	23898	39	22A
0005435257264	23898	40	22C
0005433473194	23898	41	22D
0005435257272	23898	42	23A
0005433473221	23898	43	23B
0005435904899	18836	1	3A
0005435904898	18836	2	4A
0005434606814	18836	3	6A
0005434606846	22326	1	1A
0005435904705	22326	2	1B
0005434606847	22326	3	2A
0005434604916	22326	4	3B
0005434604915	22326	5	4A
0005434606845	22326	6	6A
0005434604917	22326	7	6B
0005434602911	3842	1	1D
0005434522465	3842	2	2C
0005434522462	3842	3	2D
0005434602915	3842	4	3A
0005434522468	3842	5	3B
0005434522463	3842	6	5A
0005434602914	3842	7	5B
0005434522464	3842	8	5D
0005434522469	3842	9	6A
0005434522461	3842	10	6B
0005434522467	3842	11	7B
0005434522466	3842	12	18B
0005435904393	3842	13	18C
0005434602912	3842	14	18D
0005435904398	3842	15	19A
0005434602916	3842	16	19B
0005434522460	3842	17	19C
0005434522470	3842	18	20A
0005435904391	3842	19	20C
0005435904403	3842	20	20D
0005434602913	3842	21	22B
0005435904397	3842	22	22D
0005434522435	19046	1	1A
0005434522434	19046	2	1B
0005434522432	19046	3	1C
0005434604875	19046	4	1D
0005434604880	19046	5	2B
0005434522439	19046	6	2C
0005434522442	19046	7	2D
0005435904418	19046	8	3B
0005434604883	19046	9	3D
0005434522428	19046	10	4A
0005434602894	19046	11	4B
0005434604879	19046	12	4C
0005435904419	19046	13	5A
0005434602891	19046	14	5C
0005434604891	19046	15	5D
0005435904421	19046	16	6A
0005434522443	19046	17	6C
0005434602882	19046	18	6D
0005434604885	19046	19	7A
0005434602883	19046	20	7C
0005434602888	19046	21	7B
0005434602897	19046	22	7D
0005434522429	19046	23	18A
0005434602886	19046	24	18B
0005434604894	19046	25	18C
0005434522436	19046	26	20A
0005434522437	19046	27	19D
0005434604876	19046	28	20B
0005435904420	19046	29	20C
0005434522438	19046	30	20D
0005434522433	19046	31	21A
0005434604884	19046	32	21B
0005434602898	19046	33	21C
0005434604878	19046	34	21D
0005435904422	19046	35	22B
0005434604877	19046	36	22C
0005434604887	19046	37	23A
0005434522424	19046	38	23B
0005432747776	385	1	1A
0005432747785	385	2	1C
0005432891026	385	3	1D
0005432890973	385	4	1F
0005432747778	385	5	2A
0005432891015	385	6	2C
0005432747788	385	7	2D
0005432747774	385	8	2F
0005432747787	385	9	3A
0005432891000	385	10	3C
0005432751542	385	11	3D
0005432747791	385	12	3F
0005432890987	385	13	4A
0005432220027	385	14	4C
0005432747809	385	15	4D
0005432747798	385	16	4E
0005432747777	385	17	4F
0005432747780	385	18	5A
0005432747807	385	19	5C
0005432753318	385	20	5D
0005432891004	385	21	5E
0005432890924	385	22	5F
0005432747792	385	23	6A
0005432747781	385	24	6C
0005432890925	385	25	6D
0005432747806	385	26	6E
0005432220028	385	27	6F
0005432890907	385	28	7A
0005432747782	385	29	7C
0005432890918	385	30	7D
0005433293229	385	31	7E
0005432890943	385	32	8A
0005432891005	385	33	7F
0005432890984	385	34	8C
0005432749798	385	35	8D
0005432890962	385	36	8E
0005432749796	385	37	8F
0005432890919	385	38	9A
0005432890946	385	39	9C
0005432220029	385	40	9D
0005432220026	385	41	9E
0005432747804	385	42	9F
0005432753317	385	43	10A
0005432890974	385	44	10C
0005432890905	385	45	10D
0005432891040	385	46	10E
0005432891001	385	47	10F
0005432747800	385	48	11A
0005432890948	385	49	11C
0005432747789	385	50	11D
0005432890961	385	51	11E
0005432747790	385	52	11F
0005432747775	385	53	12A
0005432747801	385	54	12C
0005432890897	385	55	12D
0005432753320	385	56	12E
0005432747773	385	57	12F
0005432747786	385	58	13A
0005432747795	385	59	13C
0005432890938	385	60	13D
0005432747779	385	61	13E
0005432747793	385	62	13F
0005432751543	385	63	14A
0005432890939	385	64	14C
0005432220030	385	65	14D
0005432891016	385	66	14E
0005432747797	385	67	14F
0005432891007	385	68	15A
0005432890940	385	69	15C
0005432890942	385	70	15D
0005432747772	385	71	15E
0005432890947	385	72	15F
0005432890900	385	73	16A
0005432747805	385	74	16C
0005432890998	385	75	16D
0005432891027	385	76	16E
0005432751544	385	77	16F
0005432890991	385	78	17C
0005433293228	385	79	17A
0005432747784	385	80	17D
0005432749797	385	81	17E
0005432891003	385	82	17F
0005432753319	385	83	18A
0005432890996	385	84	18C
0005432747810	385	85	18D
0005432890941	385	86	18E
0005432747803	385	87	18F
0005432747794	385	88	19A
0005432890988	385	89	19C
0005432747808	385	90	19D
0005432747783	385	91	19E
0005432747796	385	92	19F
0005432890906	385	93	20A
0005432747799	385	94	20C
0005432747802	385	95	20D
0005432890899	385	96	20E
0005432751545	385	97	20F
0005432747461	12068	1	1D
0005432747553	12068	2	1F
0005432747572	12068	3	2A
0005432747262	12068	4	2C
0005432747482	12068	5	2D
0005432747528	12068	6	3A
0005432891143	12068	7	3D
0005432891144	12068	8	3F
0005432891133	12068	9	4A
0005434153539	12068	10	4C
0005432747347	12068	11	4D
0005432753287	12068	12	4E
0005432747436	12068	13	4F
0005432891132	12068	14	5A
0005432747485	12068	15	5C
0005432747563	12068	16	5D
0005432747486	12068	17	5E
0005432891146	12068	18	6A
0005432747487	12068	19	6D
0005433875391	12068	20	6F
0005432747362	12068	21	7A
0005433875392	12068	22	7C
0005432891147	12068	23	7D
0005432891145	12068	24	7E
0005432891148	12068	25	7F
0005432891139	12068	26	8A
0005432747452	12068	27	8C
0005432756841	12068	28	8D
0005432891136	12068	29	8E
0005432214817	12068	30	8F
0005432747494	12068	31	9A
0005432756832	12068	32	9C
0005432747463	12068	33	9D
0005432891138	12068	34	9E
0005432747522	12068	35	10A
0005432747464	12068	36	10D
0005432747479	12068	37	10E
0005432753290	12068	38	10F
0005432747453	12068	39	11A
0005432891131	12068	40	11C
0005432747495	12068	41	12A
0005434153540	12068	42	12D
0005435627118	12068	43	12F
0005432756838	12068	44	13A
0005432747552	12068	45	13D
0005432747424	12068	46	13F
0005432756833	12068	47	14A
0005432747496	12068	48	14C
0005434153541	12068	49	14D
0005432891142	12068	50	14E
0005432891140	12068	51	15A
0005432747394	12068	52	15D
0005432756831	12068	53	15E
0005432747620	12068	54	16A
0005432753308	12068	55	16C
0005432753286	12068	56	16D
0005432756839	12068	57	16E
0005432753293	12068	58	16F
0005432214818	12068	59	17A
0005432891137	12068	60	17C
0005432747529	12068	61	17D
0005432747425	12068	62	17F
0005432747530	12068	63	18E
0005432756813	12068	64	19C
0005432891134	12068	65	19D
0005432747476	12068	66	19E
0005432747564	12068	67	19F
0005432891141	12068	68	20A
0005432747478	12068	69	20C
0005432891149	12068	70	20D
0005432747263	12068	71	20E
0005432891135	12068	72	20F
0005433525101	18975	1	1A
0005432927980	18975	2	1D
0005433533326	18975	3	2B
0005433531313	18975	4	2C
0005433533330	18975	5	3A
0005433531311	18975	6	3C
0005433525094	18975	7	4A
0005432927953	18975	8	4D
0005433533327	18975	9	5B
0005433525100	18975	10	5C
0005432927979	18975	11	6B
0005433525097	18975	12	6C
0005432927959	18975	13	6D
0005433525096	18975	14	7C
0005433525099	18975	15	18A
0005433525095	18975	16	19A
0005433531312	18975	17	19C
0005433533329	18975	18	20A
0005433525093	18975	19	20C
0005433533328	18975	20	20D
0005432927958	18975	21	21A
0005433531314	18975	22	21B
0005432927974	18975	23	21C
0005433525098	18975	24	22B
0005432928019	32466	1	1B
0005432928021	32466	2	1D
0005433524996	32466	3	2A
0005432928018	32466	4	2D
0005433527230	32466	5	5A
0005433525019	32466	6	5C
0005433525020	32466	7	6A
0005433527229	32466	8	6D
0005433525021	32466	9	7C
0005433525022	32466	10	18A
0005432928022	32466	11	18C
0005433525001	32466	12	19A
0005433527245	32466	13	19B
0005433527251	32466	14	19D
0005432928020	32466	15	20C
0005433531286	32466	16	21A
0005433527246	32466	17	21B
0005433525002	32466	18	21C
0005433527239	32466	19	21D
0005433524968	32466	20	22A
0005433527240	32466	21	23A
0005435372949	5299	1	1A
0005435735130	5299	2	1G
0005435735138	5299	3	1D
0005434824350	5299	4	1K
0005434558332	5299	5	2D
0005434824381	5299	6	2C
0005434824299	5299	7	2A
0005434824390	5299	8	2G
0005435372961	5299	9	2K
0005435150111	5299	10	2H
0005432121415	5299	11	3H
0005434831176	5299	12	3G
0005434824401	5299	13	4A
0005434824323	5299	14	3K
0005434824306	5299	15	4D
0005434824402	5299	16	4H
0005435373138	5299	17	5D
0005435373166	5299	18	5C
0005434824366	5299	19	5G
0005432121427	5299	20	5K
0005434828711	5299	21	11D
0005435372992	5299	22	11F
0005432121419	5299	23	11E
0005434824356	5299	24	11H
0005435179691	5299	25	12A
0005435372943	5299	26	11K
0005434824385	5299	27	12E
0005434824314	5299	28	12D
0005435150114	5299	29	12H
0005434824426	5299	30	13A
0005435373096	5299	31	12K
0005434824325	5299	32	13D
0005434824335	5299	33	13F
0005435372974	5299	34	13E
0005435661923	5299	35	13H
0005434824346	5299	36	13G
0005434558331	5299	37	14A
0005435661926	5299	38	14E
0005435372975	5299	39	14D
0005434824413	5299	40	14C
0005434824347	5299	41	14G
0005434824311	5299	42	14F
0005435386561	5299	43	14K
0005434824375	5299	44	15C
0005434824359	5299	45	15A
0005434558329	5299	46	15E
0005435372999	5299	47	15D
0005435386548	5299	48	15G
0005434664973	5299	49	15F
0005434824409	5299	50	15K
0005434824362	5299	51	15H
0005434824397	5299	52	16D
0005434824319	5299	53	16C
0005434824379	5299	54	16A
0005435373176	5299	55	16F
0005434824361	5299	56	16E
0005435373148	5299	57	16H
0005434558333	5299	58	17A
0005434824393	5299	59	16K
0005432823437	5299	60	17D
0005434828712	5299	61	17F
0005435372929	5299	62	17K
0005435373313	5299	63	18B
0005435372876	5299	64	18D
0005434824406	5299	65	18G
0005434824339	5299	66	19D
0005434824343	5299	67	19C
0005434558325	5299	68	19B
0005434824348	5299	69	19F
0005435373358	5299	70	19E
0005434824321	5299	71	19G
0005432121428	5299	72	20A
0005434824367	5299	73	19K
0005435299780	5299	74	20B
0005435373314	5299	75	20E
0005434824317	5299	76	20G
0005435373026	5299	77	20F
0005434824327	5299	78	20K
0005434831177	5299	79	20J
0005435373238	5299	80	21B
0005434824322	5299	81	21A
0005435373206	5299	82	21D
0005435373035	5299	83	21F
0005435373090	5299	84	21H
0005435150115	5299	85	22A
0005435372843	5299	86	21K
0005434824352	5299	87	22C
0005435373208	5299	88	22B
0005435372916	5299	89	22F
0005435735117	5299	90	22E
0005435150106	5299	91	22D
0005434824318	5299	92	22G
0005435372851	5299	93	23B
0005434824326	5299	94	23A
0005434824341	5299	95	23D
0005434824332	5299	96	23C
0005435373177	5299	97	23G
0005435373123	5299	98	23F
0005434824357	5299	99	24D
0005434824382	5299	100	23K
0005435373347	5299	101	23J
0005435735133	5299	102	24F
0005432121425	5299	103	24E
0005434824383	5299	104	25A
0005434824304	5299	105	24G
0005434824353	5299	106	25D
0005435386550	5299	107	25C
0005435372973	5299	108	25B
0005434824360	5299	109	25F
0005434824303	5299	110	25E
0005435373361	5299	111	25H
0005435373059	5299	112	25G
0005435372867	5299	113	26A
0005432121422	5299	114	25K
0005435372941	5299	115	25J
0005434824307	5299	116	26C
0005434824399	5299	117	26F
0005435373329	5299	118	26E
0005434824369	5299	119	26D
0005434824424	5299	120	26J
0005434824403	5299	121	27B
0005435661922	5299	122	27A
0005435372950	5299	123	26K
0005434824340	5299	124	27D
0005435373195	5299	125	27H
0005434824309	5299	126	27J
0005435373296	5299	127	28C
0005434824342	5299	128	28B
0005432121418	5299	129	28A
0005435178989	5299	130	28E
0005435372996	5299	131	28D
0005432121426	5299	132	28J
0005434824345	5299	133	28H
0005435373020	5299	134	29B
0005435373219	5299	135	28K
0005435299779	5299	136	29D
0005435373192	5299	137	29C
0005435735124	5299	138	29F
0005435150117	5299	139	29K
0005434824377	5299	140	29J
0005435150113	5299	141	30C
0005434824338	5299	142	30B
0005434831175	5299	143	30A
0005434824300	5299	144	30E
0005435150108	5299	145	30D
0005434664971	5299	146	30G
0005435299778	5299	147	30F
0005434558330	5299	148	30K
0005435373125	5299	149	30H
0005434824313	5299	150	31B
0005434824312	5299	151	31C
0005435373217	5299	152	31F
0005432121417	5299	153	31E
0005434824427	5299	154	31H
0005434824405	5299	155	31K
0005434824410	5299	156	31J
0005434664972	5299	157	32B
0005434824315	5299	158	32F
0005435150119	5299	159	32J
0005434824407	5299	160	33B
0005435735122	5299	161	33A
0005434824330	5299	162	32K
0005434824380	5299	163	33F
0005434824310	5299	164	33E
0005434824414	5299	165	33J
0005435735123	5299	166	33H
0005432121414	5299	167	34C
0005435373186	5299	168	34B
0005435373137	5299	169	34A
0005434824324	5299	170	34E
0005435373097	5299	171	34D
0005434824351	5299	172	34G
0005434824384	5299	173	34F
0005434824376	5299	174	34K
0005434824374	5299	175	34H
0005434824302	5299	176	35A
0005435372942	5299	177	35C
0005434824301	5299	178	35F
0005435372755	5299	179	35E
0005435372819	5299	180	35H
0005432396268	5299	181	35G
0005432121421	5299	182	36A
0005434824336	5299	183	35K
0005434824412	5299	184	35J
0005434824368	5299	185	36B
0005434824371	5299	186	36H
0005435373091	5299	187	36G
0005432394130	5299	188	36J
0005434824398	5299	189	37C
0005435373167	5299	190	37B
0005432394128	5299	191	36K
0005434824333	5299	192	37D
0005434824372	5299	193	37G
0005434831174	5299	194	37F
0005435150107	5299	195	37J
0005434558327	5299	196	37H
0005432396267	5299	197	38A
0005435150118	5299	198	37K
0005434824417	5299	199	38J
0005434824388	5299	200	38H
0005435373044	5299	201	39A
0005432121420	5299	202	38K
0005435373277	5299	203	39D
0005434824411	5299	204	39B
0005435150109	5299	205	39F
0005434824400	5299	206	39E
0005434824354	5299	207	39H
0005434824344	5299	208	39G
0005434824331	5299	209	39K
0005432396270	5299	210	39J
0005434824329	5299	211	40C
0005435373237	5299	212	40E
0005434558326	5299	213	40D
0005435373295	5299	214	40H
0005434824404	5299	215	40F
0005434824355	5299	216	40K
0005435299774	5299	217	41B
0005435373075	5299	218	41A
0005434824421	5299	219	41D
0005435661927	5299	220	41C
0005434558328	5299	221	41E
0005435373136	5299	222	41J
0005434824386	5299	223	41H
0005434824305	5299	224	41K
0005434824396	5299	225	42C
0005434824408	5299	226	42E
0005434824365	5299	227	42D
0005432394129	5299	228	42F
0005434824423	5299	229	42H
0005434824337	5299	230	43D
0005434824425	5299	231	43E
0005432121416	5299	232	43H
0005434824363	5299	233	43G
0005434824422	5299	234	43J
0005434824316	5299	235	44C
0005434824389	5299	236	44B
0005434824419	5299	237	44E
0005435373045	5299	238	44D
0005435373362	5299	239	44G
0005434824416	5299	240	44J
0005435735127	5299	241	44H
0005435373058	5299	242	45B
0005434824392	5299	243	45A
0005435373042	5299	244	44K
0005434824358	5299	245	45D
0005435372764	5299	246	45C
0005434824387	5299	247	45F
0005434824378	5299	248	45E
0005435372960	5299	249	45H
0005434824373	5299	250	45G
0005434824415	5299	251	45K
0005435373183	5299	252	46C
0005435372995	5299	253	46A
0005432396269	5299	254	46E
0005435386551	5299	255	46G
0005434824395	5299	256	46F
0005434824334	5299	257	47E
0005432121424	5299	258	47G
0005435304151	5299	259	47F
0005435150116	5299	260	47K
0005434824418	5299	261	47H
0005432121423	5299	262	48D
0005435373359	5299	263	48C
0005434824370	5299	264	48E
0005435373057	5299	265	48G
0005434824394	5299	266	49A
0005435299754	5299	267	49D
0005435150110	5299	268	49G
0005435735129	5299	269	49E
0005435150112	5299	270	49K
0005435373198	5299	271	49H
0005432823438	5299	272	50C
0005434824308	5299	273	50E
0005434824364	5299	274	50D
0005434824328	5299	275	50H
0005434824420	5299	276	50G
0005434824320	5299	277	50F
0005435373178	5299	278	51D
0005434824391	5299	279	50K
0005435299755	5299	280	51F
0005435373218	5299	281	51E
0005434824349	5299	282	51G
0005434823599	9908	1	1A
0005434823133	9908	2	1H
0005435149972	9908	3	1G
0005434823132	9908	4	1D
0005434823360	9908	5	2A
0005434823340	9908	6	1K
0005434828690	9908	7	2C
0005435373672	9908	8	2H
0005434823420	9908	9	2D
0005435386606	9908	10	3A
0005432203106	9908	11	3C
0005434823682	9908	12	3K
0005434664953	9908	13	4C
0005434823259	9908	14	4G
0005435373688	9908	15	4D
0005435373655	9908	16	4K
0005434831148	9908	17	4H
0005435373630	9908	18	5C
0005434823116	9908	19	5A
0005435150008	9908	20	5H
0005435373679	9908	21	5G
0005434664949	9908	22	5D
0005435373667	9908	23	5K
0005434823433	9908	24	11E
0005434823733	9908	25	11C
0005434823233	9908	26	11G
0005434823354	9908	27	11H
0005435373677	9908	28	12A
0005434823342	9908	29	11K
0005432396225	9908	30	12D
0005432203107	9908	31	12G
0005435373671	9908	32	12F
0005435373685	9908	33	13A
0005435373647	9908	34	12K
0005434823214	9908	35	13C
0005434823596	9908	36	13F
0005434823653	9908	37	13E
0005434822710	9908	38	13H
0005434823400	9908	39	13G
0005434823256	9908	40	14C
0005434822709	9908	41	14A
0005434823652	9908	42	13K
0005434823260	9908	43	14D
0005434823207	9908	44	14G
0005435373651	9908	45	14F
0005435302228	9908	46	14H
0005435373641	9908	47	15C
0005434823730	9908	48	15A
0005434823027	9908	49	14K
0005435373632	9908	50	15E
0005434823179	9908	51	15D
0005435149920	9908	52	15G
0005435373638	9908	53	15F
0005434823181	9908	54	15K
0005434823428	9908	55	15H
0005435661950	9908	56	16D
0005434823870	9908	57	16A
0005435373673	9908	58	16F
0005435373642	9908	59	16E
0005435373652	9908	60	16H
0005435373687	9908	61	16G
0005434823049	9908	62	17A
0005435179399	9908	63	17E
0005435373649	9908	64	17D
0005434831149	9908	65	17H
0005435373693	9908	66	17G
0005435149921	9908	67	17F
0005434823353	9908	68	17K
0005434823888	9908	69	18B
0005435373680	9908	70	18A
0005434831150	9908	71	18E
0005435373674	9908	72	18D
0005434823349	9908	73	18F
0005435373644	9908	74	18J
0005434822909	9908	75	18H
0005434823371	9908	76	19B
0005435373648	9908	77	19A
0005435373663	9908	78	18K
0005434823134	9908	79	19C
0005435299803	9908	80	19E
0005432203104	9908	81	19G
0005434823997	9908	82	19J
0005434823591	9908	83	20C
0005434823028	9908	84	20E
0005435373665	9908	85	20F
0005432396224	9908	86	21B
0005434823998	9908	87	21A
0005434823089	9908	88	21E
0005435299804	9908	89	21H
0005434822781	9908	90	21K
0005435373659	9908	91	21J
0005434822806	9908	92	22B
0005434823252	9908	93	22D
0005434823423	9908	94	22K
0005435150018	9908	95	22J
0005435373645	9908	96	23A
0005434823210	9908	97	23E
0005435661951	9908	98	23G
0005435302226	9908	99	23J
0005434823575	9908	100	24E
0005432823462	9908	101	25B
0005435373660	9908	102	25A
0005435373670	9908	103	25C
0005434823287	9908	104	25F
0005435299805	9908	105	25E
0005435299806	9908	106	25H
0005432396231	9908	107	25G
0005434664950	9908	108	26A
0005435373690	9908	109	25K
0005434823776	9908	110	26B
0005434823620	9908	111	26E
0005434823871	9908	112	26D
0005434823212	9908	113	26H
0005434823640	9908	114	26G
0005435373678	9908	115	26F
0005434822969	9908	116	26J
0005435373692	9908	117	27B
0005434822919	9908	118	27D
0005434822943	9908	119	27C
0005434823273	9908	120	27E
0005435661948	9908	121	27H
0005434822825	9908	122	27G
0005434822966	9908	123	27K
0005435373656	9908	124	28C
0005434823115	9908	125	28B
0005435661949	9908	126	28E
0005434823015	9908	127	28D
0005435149974	9908	128	28H
0005434823475	9908	129	28G
0005434823180	9908	130	28F
0005434822944	9908	131	28J
0005434823213	9908	132	29B
0005434823203	9908	133	29A
0005434823142	9908	134	28K
0005434823359	9908	135	29C
0005434823639	9908	136	29F
0005435373629	9908	137	29E
0005434823651	9908	138	29G
0005434822901	9908	139	30A
0005434823262	9908	140	29K
0005434823384	9908	141	29J
0005432203108	9908	142	30C
0005434823434	9908	143	30B
0005432823463	9908	144	30E
0005435149964	9908	145	30D
0005432203109	9908	146	30G
0005435149979	9908	147	30F
0005434823543	9908	148	30K
0005434822650	9908	149	30H
0005434822682	9908	150	31B
0005435150015	9908	151	31A
0005435386612	9908	152	31C
0005434823225	9908	153	31F
0005434823263	9908	154	31E
0005434822663	9908	155	31H
0005434823026	9908	156	31G
0005435735165	9908	157	32A
0005435373689	9908	158	31K
0005434823104	9908	159	31J
0005434823408	9908	160	32B
0005435373664	9908	161	32E
0005435373634	9908	162	32C
0005434822763	9908	163	32G
0005434822967	9908	164	32F
0005435149973	9908	165	32K
0005432400117	9908	166	32J
0005434823061	9908	167	33A
0005434823185	9908	168	33D
0005435373662	9908	169	33F
0005435373669	9908	170	33H
0005434823401	9908	171	34A
0005434823206	9908	172	34D
0005434823729	9908	173	34C
0005435386610	9908	174	34H
0005435149943	9908	175	34K
0005434822711	9908	176	35D
0005434823544	9908	177	35C
0005435373650	9908	178	35F
0005435373631	9908	179	35E
0005434822906	9908	180	35H
0005435373639	9908	181	35G
0005435373691	9908	182	35J
0005434822807	9908	183	36C
0005435373633	9908	184	36F
0005434823247	9908	185	36E
0005435735163	9908	186	36D
0005434823013	9908	187	36G
0005435735167	9908	188	36J
0005434823291	9908	189	37A
0005432203110	9908	190	37D
0005432203105	9908	191	37E
0005435373666	9908	192	37J
0005435373637	9908	193	37H
0005434823339	9908	194	37G
0005435386609	9908	195	38A
0005434823771	9908	196	38C
0005434823215	9908	197	38B
0005434823659	9908	198	38J
0005435386607	9908	199	39B
0005434823276	9908	200	38K
0005434823700	9908	201	39F
0005434823224	9908	202	39G
0005434823598	9908	203	39J
0005434823719	9908	204	40B
0005434823739	9908	205	40D
0005434823318	9908	206	40G
0005435373675	9908	207	40H
0005435373653	9908	208	41B
0005434823683	9908	209	41A
0005434823416	9908	210	41D
0005434823264	9908	211	41C
0005434823449	9908	212	41F
0005434822990	9908	213	41H
0005435386611	9908	214	41K
0005434823641	9908	215	42C
0005432396236	9908	216	42B
0005435373643	9908	217	42E
0005435373661	9908	218	42D
0005432396248	9908	219	42G
0005435373658	9908	220	42J
0005434823205	9908	221	42H
0005434822649	9908	222	43B
0005434823051	9908	223	42K
0005435302225	9908	224	43D
0005435373657	9908	225	43E
0005434823517	9908	226	43H
0005435373683	9908	227	43G
0005434823014	9908	228	43K
0005434823775	9908	229	44E
0005434823314	9908	230	44G
0005435386608	9908	231	44F
0005434823217	9908	232	44K
0005435373635	9908	233	44J
0005435735164	9908	234	44H
0005435373682	9908	235	45B
0005434823178	9908	236	45A
0005434822900	9908	237	45D
0005434823246	9908	238	45C
0005434823204	9908	239	45F
0005435373684	9908	240	45K
0005435386605	9908	241	45J
0005434823448	9908	242	46C
0005434823508	9908	243	46B
0005434822683	9908	244	46A
0005434822736	9908	245	46G
0005432396233	9908	246	46F
0005435373668	9908	247	46K
0005435373686	9908	248	46J
0005435149965	9908	249	46H
0005434823140	9908	250	47C
0005435179699	9908	251	47A
0005435373646	9908	252	47E
0005434822737	9908	253	47D
0005434823507	9908	254	47G
0005434558263	9908	255	47F
0005434823024	9908	256	47K
0005434823366	9908	257	47H
0005434828686	9908	258	48D
0005435373654	9908	259	48A
0005434823052	9908	260	48F
0005434823035	9908	261	48E
0005434822772	9908	262	48H
0005434823272	9908	263	48G
0005434823455	9908	264	49A
0005435302227	9908	265	48K
0005435373694	9908	266	49G
0005435373636	9908	267	49E
0005434823258	9908	268	49K
0005435179698	9908	269	49H
0005435373681	9908	270	50C
0005434823114	9908	271	50E
0005435373676	9908	272	50G
0005434823025	9908	273	50F
0005434823777	9908	274	51D
0005435373640	9908	275	50K
0005434822662	9908	276	50H
0005435373628	9908	277	51E
0005435735166	9908	278	51G
0005435082832	6984	1	3A
0005435082835	6984	2	3D
0005435082834	6984	3	5A
0005435790323	6984	4	5C
0005435082840	6984	5	6B
0005435790324	6984	6	7A
0005435082839	6984	7	7D
0005435082836	6984	8	18B
0005435082837	6984	9	18C
0005435082838	6984	10	19B
0005435790325	6984	11	19D
0005435082833	6984	12	23B
0005435082751	25995	1	1A
0005435082742	25995	2	2D
0005435082763	25995	3	19C
0005435790304	25995	4	19D
0005435082762	25995	5	20C
0005435082739	25995	6	21D
0005434214417	9518	1	1C
0005434756688	9518	2	1D
0005434756685	9518	3	1F
0005434756681	9518	4	2A
0005434214294	9518	5	2C
0005434214432	9518	6	2D
0005434214304	9518	7	2F
0005434756669	9518	8	3D
0005434214181	9518	9	3F
0005434756698	9518	10	4A
0005434756680	9518	11	4C
0005434756666	9518	12	4E
0005434756682	9518	13	4F
0005434756676	9518	14	5A
0005434214274	9518	15	5C
0005434214391	9518	16	5D
0005434756705	9518	17	5E
0005434756671	9518	18	5F
0005434214322	9518	19	6A
0005434756678	9518	20	6C
0005434756707	9518	21	6D
0005434756670	9518	22	6E
0005434756711	9518	23	7A
0005434214382	9518	24	7C
0005434214400	9518	25	7D
0005434214522	9518	26	7E
0005434214390	9518	27	7F
0005434214418	9518	28	8A
0005434214341	9518	29	8C
0005434756703	9518	30	8D
0005434756704	9518	31	8E
0005434756665	9518	32	8F
0005434756679	9518	33	9A
0005434756702	9518	34	9C
0005434214302	9518	35	9D
0005434214545	9518	36	9E
0005434214307	9518	37	9F
0005434214257	9518	38	10A
0005434214163	9518	39	10C
0005434214295	9518	40	10E
0005434756691	9518	41	10F
0005434756667	9518	42	11A
0005434756674	9518	43	11C
0005434756684	9518	44	11D
0005434756686	9518	45	11E
0005434214303	9518	46	11F
0005434214389	9518	47	12A
0005434214313	9518	48	12C
0005434214399	9518	49	12D
0005434756710	9518	50	12E
0005434214273	9518	51	12F
0005434756696	9518	52	13A
0005434756700	9518	53	13C
0005434214269	9518	54	13D
0005434214293	9518	55	13E
0005434756675	9518	56	13F
0005434756699	9518	57	14A
0005434756673	9518	58	14C
0005434756697	9518	59	14D
0005434214362	9518	60	14E
0005434214336	9518	61	14F
0005434756693	9518	62	15A
0005434756668	9518	63	15C
0005434756706	9518	64	15D
0005434214340	9518	65	15E
0005434214437	9518	66	15F
0005434756692	9518	67	16A
0005434756709	9518	68	16D
0005434756690	9518	69	16E
0005434214361	9518	70	16F
0005434756708	9518	71	17A
0005434214270	9518	72	17D
0005434756683	9518	73	17E
0005434214472	9518	74	17F
0005434214301	9518	75	18A
0005434756695	9518	76	18C
0005434214356	9518	77	18D
0005434756677	9518	78	18E
0005434756694	9518	79	18F
0005434214547	9518	80	19C
0005434756689	9518	81	19D
0005434214471	9518	82	19E
0005434214548	9518	83	19F
0005434214383	9518	84	20A
0005434756687	9518	85	20C
0005434756672	9518	86	20D
0005434756701	9518	87	20E
0005434214305	9518	88	20F
0005434214770	28621	1	1A
0005434214757	28621	2	1C
0005434214745	28621	3	1D
0005434756220	28621	4	1F
0005434214783	28621	5	2A
0005434214777	28621	6	2C
0005434214754	28621	7	2D
0005434214780	28621	8	2F
0005434214760	28621	9	3A
0005434756204	28621	10	3C
0005434756226	28621	11	3D
0005434214769	28621	12	3F
0005434756281	28621	13	4A
0005434214785	28621	14	4C
0005434214779	28621	15	4D
0005434214746	28621	16	4E
0005434756176	28621	17	4F
0005434214772	28621	18	5A
0005434214788	28621	19	5C
0005434756123	28621	20	5D
0005434214759	28621	21	5E
0005434214764	28621	22	5F
0005434756310	28621	23	6A
0005434756241	28621	24	6C
0005434756194	28621	25	6F
0005434214748	28621	26	7C
0005434214786	28621	27	7D
0005434756278	28621	28	7E
0005434214765	28621	29	7F
0005434756203	28621	30	8A
0005434756137	28621	31	8C
0005434214787	28621	32	8E
0005434214751	28621	33	8F
0005434214773	28621	34	9C
0005434214776	28621	35	9D
0005434214763	28621	36	9E
0005434214790	28621	37	9F
0005434756291	28621	38	10A
0005434756081	28621	39	10C
0005434214753	28621	40	10D
0005434756234	28621	41	10E
0005434756213	28621	42	10F
0005434214766	28621	43	11A
0005434214755	28621	44	11C
0005434214778	28621	45	11D
0005434756225	28621	46	11E
0005434756212	28621	47	12A
0005434214784	28621	48	12C
0005434756175	28621	49	12D
0005434214758	28621	50	12E
0005434214781	28621	51	12F
0005434214771	28621	52	13A
0005434214749	28621	53	13C
0005434756309	28621	54	13D
0005434756080	28621	55	13E
0005434214750	28621	56	13F
0005434756214	28621	57	14A
0005434756208	28621	58	14C
0005434214792	28621	59	14D
0005434214747	28621	60	14E
0005434756189	28621	61	14F
0005434214782	28621	62	15A
0005434214767	28621	63	15C
0005434756304	28621	64	15D
0005434756166	28621	65	15E
0005434756303	28621	66	15F
0005434756198	28621	67	16A
0005434756132	28621	68	16C
0005434214791	28621	69	16E
0005434756147	28621	70	16F
0005434214761	28621	71	17A
0005434214775	28621	72	17C
0005434756277	28621	73	17D
0005434214789	28621	74	17E
0005434756165	28621	75	17F
0005434214756	28621	76	18C
0005434214768	28621	77	18D
0005434756206	28621	78	18E
0005434756224	28621	79	18F
0005434756199	28621	80	19A
0005434214774	28621	81	19C
0005434756207	28621	82	19D
0005434214762	28621	83	20A
0005434214752	28621	84	20C
0005434756192	28621	85	20E
0005434756131	28621	86	20F
0005435100144	10814	1	1A
0005434760194	10814	2	1B
0005434760181	10814	3	1C
0005435100140	10814	4	3A
0005435100142	10814	5	5D
0005434760192	10814	6	6A
0005435100143	10814	7	7D
0005435100141	10814	8	18D
0005435100114	31846	1	2A
0005434760213	31846	2	2B
0005434760211	31846	3	2D
0005435100115	31846	4	3A
0005434760214	31846	5	18B
0005434760212	31846	6	20A
0005435100119	31846	7	20B
0005435100126	31846	8	23A
0005434639482	1975	1	1A
0005434639481	1975	2	1B
0005433202314	1975	3	1C
0005432290653	1975	4	1D
0005434639490	1975	5	2A
0005434639489	1975	6	2B
0005434639486	1975	7	2D
0005433202353	1975	8	3A
0005433202333	1975	9	3B
0005434639485	1975	10	3C
0005433202380	1975	11	3D
0005434639492	1975	12	4A
0005433202362	1975	13	4B
0005433202339	1975	14	4C
0005434639484	1975	15	4D
0005433202258	1975	16	5A
0005434639477	1975	17	5B
0005434639478	1975	18	5D
0005433202352	1975	19	6A
0005434639498	1975	20	6B
0005433202367	1975	21	6C
0005433202363	1975	22	6D
0005434639496	1975	23	7B
0005433202315	1975	24	7C
0005432290652	1975	25	7D
0005433202284	1975	26	18A
0005434639497	1975	27	18B
0005433202382	1975	28	18C
0005434639480	1975	29	18D
0005434639494	1975	30	19A
0005433202397	1975	31	19B
0005433202388	1975	32	19C
0005434639487	1975	33	19D
0005434639479	1975	34	20A
0005433202381	1975	35	20B
0005434639495	1975	36	20C
0005434639491	1975	37	20D
0005433202396	1975	38	21A
0005433202305	1975	39	21B
0005433202304	1975	40	21C
0005433202387	1975	41	21D
0005434639493	1975	42	22A
0005432290651	1975	43	22B
0005434639488	1975	44	22C
0005433202364	1975	45	22D
0005433202379	1975	46	23A
0005434639483	1975	47	23B
0005434639298	23282	1	1A
0005433202436	23282	2	1C
0005433202448	23282	3	2A
0005434639167	23282	4	2B
0005433202443	23282	5	2C
0005433202441	23282	6	2D
0005433202447	23282	7	3A
0005433202446	23282	8	3C
0005434639280	23282	9	3D
0005434639067	23282	10	4A
0005434639183	23282	11	4B
0005433202437	23282	12	4C
0005434639122	23282	13	4D
0005433202444	23282	14	5A
0005433202450	23282	15	5B
0005434639265	23282	16	5D
0005433202438	23282	17	6B
0005434639101	23282	18	6C
0005434639361	23282	19	6D
0005433202442	23282	20	7A
0005434639211	23282	21	7B
0005434639281	23282	22	7C
0005433202449	23282	23	7D
0005434639305	23282	24	18A
0005433202439	23282	25	18B
0005433202435	23282	26	18D
0005434639261	23282	27	19B
0005434639206	23282	28	19C
0005434639100	23282	29	20B
0005433202445	23282	30	21A
0005434639184	23282	31	21B
0005433202440	23282	32	21C
0005434639251	23282	33	21D
0005434639282	23282	34	22A
0005434639304	23282	35	22C
0005434639123	23282	36	22D
0005434639271	23282	37	23A
0005434639256	23282	38	23B
0005433533333	6057	1	1A
0005435326606	6057	2	2A
0005434600968	6057	3	3A
0005434600978	6057	4	3C
0005434600966	6057	5	4D
0005434600975	6057	6	4F
0005433531318	6057	7	5F
0005434600986	6057	8	6A
0005434600971	6057	9	6E
0005434600970	6057	10	7A
0005434600981	6057	11	7C
0005434600987	6057	12	8A
0005434600980	6057	13	8C
0005435326702	6057	14	8D
0005434600964	6057	15	8F
0005434600977	6057	16	9A
0005432111298	6057	17	9F
0005434600967	6057	18	10A
0005435326739	6057	19	10D
0005434600985	6057	20	10F
0005434600976	6057	21	11D
0005434600963	6057	22	12A
0005432111297	6057	23	12C
0005433531317	6057	24	12E
0005435326701	6057	25	12F
0005434600988	6057	26	13C
0005435326700	6057	27	13D
0005433531315	6057	28	14A
0005433531319	6057	29	14C
0005434600983	6057	30	14D
0005435326740	6057	31	14E
0005433531316	6057	32	14F
0005434600972	6057	33	15A
0005435326732	6057	34	15D
0005433533331	6057	35	15E
0005435326677	6057	36	16A
0005434600969	6057	37	16C
0005434600965	6057	38	16E
0005434600982	6057	39	16F
0005432111299	6057	40	17C
0005434600979	6057	41	17D
0005434600974	6057	42	18A
0005435326607	6057	43	18C
0005433533332	6057	44	18D
0005435326705	6057	45	19A
0005434600984	6057	46	19E
0005434600973	6057	47	20A
0005435326685	6057	48	20D
0005435326811	6057	49	20E
0005435326723	6057	50	20F
0005435326834	18559	1	1F
0005434600660	18559	2	2D
0005434600788	18559	3	3A
0005434600795	18559	4	3C
0005434600820	18559	5	3D
0005434600759	18559	6	3F
0005433527244	18559	7	4A
0005435326833	18559	8	4C
0005435326830	18559	9	4D
0005434600673	18559	10	4F
0005434600710	18559	11	5A
0005435326837	18559	12	6C
0005435326825	18559	13	7A
0005434600756	18559	14	7D
0005433527243	18559	15	7F
0005433531281	18559	16	8A
0005434600768	18559	17	8C
0005434600757	18559	18	8D
0005435326828	18559	19	8E
0005434600687	18559	20	8F
0005433527236	18559	21	9A
0005435326835	18559	22	9D
0005434600723	18559	23	9E
0005433531302	18559	24	9F
0005435326832	18559	25	10C
0005435326827	18559	26	11A
0005435326829	18559	27	11D
0005434600659	18559	28	11E
0005433531289	18559	29	11F
0005434600822	18559	30	12C
0005434600770	18559	31	13C
0005435326824	18559	32	14A
0005434600651	18559	33	14D
0005435326836	18559	34	14E
0005433531303	18559	35	15C
0005434600745	18559	36	15E
0005434600771	18559	37	15F
0005434600686	18559	38	16A
0005434600774	18559	39	16C
0005434600661	18559	40	16D
0005434600761	18559	41	16E
0005433527235	18559	42	18C
0005433531283	18559	43	18D
0005435326823	18559	44	18E
0005434600789	18559	45	19A
0005435326826	18559	46	19C
0005433531273	18559	47	19E
0005435326831	18559	48	20E
0005434600665	18559	49	20F
0005433181048	10564	1	1A
0005433180977	10564	2	1C
0005434558312	10564	3	1D
0005433180921	10564	4	2A
0005433180983	10564	5	2C
0005434558311	10564	6	2D
0005434558319	10564	7	2F
0005434551534	10564	8	3A
0005434558314	10564	9	3C
0005434551529	10564	10	3D
0005434551537	10564	11	3F
0005434551542	10564	12	4A
0005434551545	10564	13	4C
0005434551516	10564	14	4D
0005434551527	10564	15	4E
0005434551502	10564	16	4F
0005434551517	10564	17	5A
0005434551525	10564	18	5C
0005434551520	10564	19	5D
0005434558313	10564	20	5E
0005434551536	10564	21	5F
0005434558317	10564	22	6A
0005434551544	10564	23	6C
0005434551531	10564	24	6D
0005434551523	10564	25	6E
0005434558310	10564	26	6F
0005434558321	10564	27	7A
0005434551515	10564	28	7C
0005434551506	10564	29	7E
0005434558315	10564	30	7F
0005434551511	10564	31	8A
0005434551547	10564	32	8C
0005434551543	10564	33	8D
0005434558316	10564	34	8E
0005434551519	10564	35	8F
0005433181095	10564	36	9A
0005434551533	10564	37	9C
0005433180997	10564	38	9D
0005434551535	10564	39	9E
0005434551509	10564	40	9F
0005434551539	10564	41	10A
0005434558318	10564	42	10C
0005433181100	10564	43	10D
0005434558322	10564	44	10E
0005434551504	10564	45	10F
0005434551546	10564	46	11A
0005434551497	10564	47	11C
0005434551521	10564	48	11D
0005434554077	10564	49	11E
0005434551549	10564	50	11F
0005434551500	10564	51	12A
0005434558324	10564	52	12C
0005434551524	10564	53	12D
0005434551538	10564	54	12E
0005434551528	10564	55	12F
0005434558323	10564	56	13C
0005434551494	10564	57	13D
0005434551499	10564	58	13E
0005433180984	10564	59	13F
0005434551548	10564	60	14A
0005434551505	10564	61	14C
0005433181043	10564	62	14D
0005434551541	10564	63	14E
0005434558320	10564	64	14F
0005434551507	10564	65	15A
0005434551498	10564	66	15C
0005434551513	10564	67	15E
0005434551522	10564	68	16A
0005434551501	10564	69	16D
0005434554078	10564	70	16E
0005434551496	10564	71	16F
0005434551532	10564	72	17A
0005433181046	10564	73	17C
0005434551508	10564	74	17D
0005434551512	10564	75	17E
0005433180949	10564	76	17F
0005434551540	10564	77	18A
0005434551526	10564	78	18D
0005434551510	10564	79	18E
0005433180998	10564	80	18F
0005434551495	10564	81	19A
0005434551518	10564	82	19D
0005433180948	10564	83	19E
0005434551503	10564	84	19F
0005434551514	10564	85	20A
0005433181047	10564	86	20C
0005433181022	10564	87	20D
0005434558309	10564	88	20E
0005434551530	10564	89	20F
0005433181250	27782	1	1D
0005433181262	27782	2	2F
0005433181267	27782	3	3A
0005433181260	27782	4	4D
0005433181265	27782	5	4F
0005433181251	27782	6	5C
0005433181261	27782	7	5E
0005433181252	27782	8	6C
0005433181259	27782	9	8D
0005433181263	27782	10	8F
0005433181247	27782	11	9E
0005433181264	27782	12	10C
0005433181266	27782	13	10D
0005433181248	27782	14	10E
0005433181246	27782	15	10F
0005433181245	27782	16	11A
0005433181249	27782	17	11E
0005433181256	27782	18	13A
0005433181257	27782	19	13E
0005433181255	27782	20	14C
0005433181244	27782	21	16A
0005433181253	27782	22	16C
0005433181258	27782	23	17C
0005433181254	27782	24	17D
0005433181243	27782	25	19F
0005434551126	27783	1	1D
0005434558238	27783	2	1F
0005434551184	27783	3	2A
0005434551104	27783	4	2D
0005434551144	27783	5	2F
0005434551327	27783	6	3C
0005434550868	27783	7	3D
0005434551151	27783	8	3F
0005434551127	27783	9	4A
0005434550951	27783	10	4D
0005434550980	27783	11	4E
0005434558233	27783	12	4F
0005434551098	27783	13	5A
0005434558249	27783	14	5E
0005434551192	27783	15	5F
0005434551228	27783	16	6D
0005434550946	27783	17	6C
0005434550917	27783	18	7A
0005434551006	27783	19	7C
0005434550915	27783	20	7E
0005434551174	27783	21	7F
0005434551063	27783	22	8C
0005434551326	27783	23	8D
0005434550878	27783	24	8E
0005434551189	27783	25	8F
0005434558241	27783	26	9C
0005434551097	27783	27	9D
0005434551162	27783	28	9E
0005434551311	27783	29	10A
0005434558250	27783	30	10C
0005434551001	27783	31	10E
0005434551377	27783	32	11A
0005434551281	27783	33	11D
0005434558240	27783	34	12A
0005434558260	27783	35	12D
0005434558243	27783	36	12E
0005434551202	27783	37	12F
0005434551048	27783	38	13A
0005434551190	27783	39	13D
0005434550964	27783	40	13E
0005434551007	27783	41	14C
0005434551000	27783	42	15C
0005434551075	27783	43	15E
0005434551268	27783	44	16D
0005434551059	27783	45	16E
0005434551280	27783	46	16F
0005434551058	27783	47	17A
0005434550935	27783	48	17D
0005434558237	27783	49	17E
0005434551064	27783	50	17F
0005434558247	27783	51	18A
0005434558236	27783	52	18E
0005434558232	27783	53	19C
0005434558242	27783	54	19E
0005434551152	27783	55	19F
0005434551145	27783	56	20A
0005434551191	27783	57	20C
0005434551219	27783	58	20D
0005434558246	27783	59	20E
0005434550998	27783	60	20F
0005435254471	6137	1	1A
0005435254459	6137	2	2A
0005435254460	6137	3	1B
0005435254462	6137	4	3A
0005435254476	6137	5	2B
0005433459243	6137	6	3B
0005435254472	6137	7	4A
0005433459246	6137	8	5A
0005435254461	6137	9	4B
0005433459245	6137	10	5B
0005435254477	6137	11	6B
0005433459244	6137	12	6A
0005433459214	19324	1	1B
0005433459210	19324	2	4A
0005433459215	19324	3	4B
0005435254489	19324	4	5A
0005435254488	19324	5	6B
0005435682376	6717	1	1A
0005435682404	6717	2	1C
0005435682390	6717	3	1D
0005434828688	6717	4	1F
0005435437858	6717	5	2A
0005435437897	6717	6	2C
0005435682379	6717	7	2D
0005435630984	6717	8	3A
0005435682372	6717	9	3C
0005435437896	6717	10	3D
0005435720140	6717	11	3F
0005435682370	6717	12	4A
0005435437935	6717	13	4C
0005435682389	6717	14	4D
0005435682388	6717	15	4F
0005435682396	6717	16	5A
0005435682395	6717	17	5C
0005435437903	6717	18	5D
0005435437949	6717	19	5E
0005435682397	6717	20	5F
0005435437871	6717	21	6A
0005435682367	6717	22	6D
0005435682365	6717	23	6E
0005435719569	6717	24	6F
0005435661947	6717	25	7C
0005435661946	6717	26	7D
0005435437902	6717	27	7F
0005435682392	6717	28	8A
0005435682383	6717	29	8C
0005435682368	6717	30	8D
0005435437979	6717	31	8E
0005435682378	6717	32	8F
0005435682394	6717	33	9A
0005435682369	6717	34	9C
0005432136199	6717	35	9D
0005435220313	6717	36	9E
0005435682400	6717	37	9F
0005435682374	6717	38	10A
0005435682384	6717	39	10C
0005435682407	6717	40	10D
0005435682366	6717	41	10E
0005435682382	6717	42	10F
0005432136198	6717	43	11A
0005435437895	6717	44	11C
0005432136197	6717	45	11F
0005434828697	6717	46	12A
0005435682377	6717	47	12C
0005435682402	6717	48	13A
0005432533273	6717	49	13C
0005435682403	6717	50	13E
0005435682381	6717	51	13F
0005435682380	6717	52	14A
0005432136200	6717	53	14C
0005435682393	6717	54	14F
0005435437908	6717	55	15A
0005435437950	6717	56	15C
0005435682385	6717	57	15D
0005435682362	6717	58	15E
0005432136201	6717	59	15F
0005435682399	6717	60	16A
0005435437890	6717	61	16C
0005435682405	6717	62	16D
0005435682401	6717	63	16E
0005435630983	6717	64	16F
0005435682406	6717	65	17C
0005435630982	6717	66	17D
0005434828689	6717	67	17E
0005435682398	6717	68	18A
0005434828687	6717	69	17F
0005435437938	6717	70	18C
0005435682387	6717	71	18D
0005435682375	6717	72	18E
0005435682391	6717	73	18F
0005435682364	6717	74	19C
0005435682371	6717	75	19F
0005435437932	6717	76	20A
0005435682363	6717	77	20C
0005434828685	6717	78	20D
0005435682373	6717	79	20E
0005435682386	6717	80	20F
0005435438079	24576	1	1A
0005435681898	24576	2	1C
0005435661920	24576	3	1D
0005435681940	24576	4	1F
0005435682105	24576	5	2A
0005435681909	24576	6	2C
0005435681966	24576	7	2D
0005435682050	24576	8	2F
0005435438086	24576	9	3A
0005432533310	24576	10	3C
0005435681894	24576	11	3D
0005435438094	24576	12	3F
0005435681933	24576	13	4A
0005435682079	24576	14	4C
0005435681943	24576	15	4D
0005432533311	24576	16	4E
0005435630962	24576	17	4F
0005435720821	24576	18	5A
0005435681994	24576	19	5C
0005435682010	24576	20	5D
0005435681863	24576	21	5E
0005435682051	24576	22	5F
0005435438093	24576	23	6C
0005435438074	24576	24	6D
0005435682187	24576	25	6E
0005434828714	24576	26	6F
0005435438085	24576	27	7A
0005435681989	24576	28	7C
0005435682019	24576	29	7D
0005435438080	24576	30	7E
0005434828715	24576	31	7F
0005435682038	24576	32	8A
0005432533309	24576	33	8C
0005435682142	24576	34	8D
0005435682067	24576	35	8E
0005435682144	24576	36	9A
0005435438090	24576	37	9C
0005435682178	24576	38	9D
0005435681969	24576	39	9E
0005435682049	24576	40	9F
0005435720820	24576	41	10A
0005435681899	24576	42	10D
0005435681897	24576	43	10E
0005435682011	24576	44	10F
0005435682119	24576	45	11A
0005435682179	24576	46	11C
0005435681827	24576	47	11D
0005432305764	24576	48	11E
0005435719563	24576	49	11F
0005435681906	24576	50	12A
0005435438076	24576	51	12C
0005435438077	24576	52	12E
0005435438092	24576	53	12F
0005435438083	24576	54	13A
0005435682145	24576	55	13C
0005435682126	24576	56	13D
0005435681968	24576	57	13E
0005434828713	24576	58	13F
0005435438075	24576	59	14A
0005435682020	24576	60	14C
0005435438078	24576	61	14D
0005435630956	24576	62	14F
0005435681990	24576	63	15A
0005435438095	24576	64	15C
0005435438089	24576	65	15D
0005435438084	24576	66	15E
0005435438091	24576	67	15F
0005435682235	24576	68	16A
0005432533308	24576	69	16D
0005435719565	24576	70	16E
0005435682048	24576	71	16F
0005435681868	24576	72	17A
0005435438081	24576	73	17C
0005435438087	24576	74	17D
0005435438096	24576	75	17F
0005435630959	24576	76	18A
0005435681983	24576	77	18C
0005435682080	24576	78	18D
0005435681984	24576	79	18E
0005435438082	24576	80	18F
0005435681939	24576	81	19A
0005432305763	24576	82	19D
0005435661919	24576	83	19E
0005435630955	24576	84	19F
0005435681826	24576	85	20C
0005435438097	24576	86	20D
0005435681942	24576	87	20E
0005435438088	24576	88	20F
0005435126592	11522	1	1A
0005435105999	11522	2	1C
0005435126590	11522	3	1D
0005435126576	11522	4	2F
0005435126602	11522	5	3A
0005435126597	11522	6	3C
0005435126600	11522	7	3F
0005435126569	11522	8	4A
0005435126572	11522	9	4C
0005435126594	11522	10	4D
0005435126583	11522	11	4F
0005435126599	11522	12	5E
0005435126577	11522	13	5F
0005435126581	11522	14	6E
0005435126584	11522	15	8D
0005435126570	11522	16	8E
0005435126596	11522	17	9C
0005435558072	11522	18	9D
0005435126579	11522	19	9F
0005435126589	11522	20	10A
0005435126565	11522	21	10C
0005435126580	11522	22	10E
0005435126587	11522	23	11D
0005435106001	11522	24	11E
0005435106000	11522	25	11F
0005435126595	11522	26	12A
0005435126575	11522	27	12D
0005435126588	11522	28	12F
0005435126567	11522	29	13C
0005435126582	11522	30	13D
0005435126568	11522	31	13F
0005435126574	11522	32	14C
0005435126566	11522	33	14E
0005435126564	11522	34	15A
0005435126603	11522	35	15D
0005435105998	11522	36	15F
0005435126586	11522	37	16A
0005435126598	11522	38	16C
0005435126563	11522	39	16E
0005435126591	11522	40	16F
0005435126571	11522	41	17C
0005435126578	11522	42	17D
0005435126585	11522	43	17E
0005435126601	11522	44	17F
0005435126593	11522	45	18C
0005435558085	11522	46	18D
0005435126573	11522	47	18E
0005435126604	11522	48	19E
0005435105997	11522	49	19F
0005435558073	11522	50	20E
0005435126157	31857	1	2D
0005435126440	31857	2	3C
0005435126383	31857	3	4A
0005435126171	31857	4	4D
0005435558101	31857	5	6A
0005435126127	31857	6	6E
0005435126317	31857	7	6F
0005435126289	31857	8	7A
0005435126152	31857	9	7C
0005435126401	31857	10	7D
0005435126235	31857	11	7E
0005435126153	31857	12	7F
0005435558102	31857	13	8A
0005435126219	31857	14	8D
0005435126442	31857	15	8E
0005435126357	31857	16	8F
0005435126356	31857	17	9E
0005435126300	31857	18	9F
0005435126172	31857	19	10C
0005435126239	31857	20	10D
0005435126400	31857	21	10E
0005435126355	31857	22	11D
0005435126297	31857	23	12C
0005435126208	31857	24	12F
0005435126551	31857	25	13A
0005435126315	31857	26	13C
0005435105975	31857	27	13D
0005435558103	31857	28	13E
0005435126243	31857	29	13F
0005435126288	31857	30	14D
0005435126298	31857	31	14F
0005435126382	31857	32	15C
0005435126128	31857	33	15D
0005435126417	31857	34	15F
0005435126316	31857	35	16E
0005435126257	31857	36	16F
0005435126125	31857	37	17A
0005435126299	31857	38	17D
0005435126318	31857	39	18D
0005435126162	31857	40	18F
0005435126236	31857	41	19D
0005435126158	31857	42	19E
0005435126314	31857	43	19F
0005435126284	31857	44	20A
0005435126237	31857	45	20C
0005433398361	13506	1	1A
0005435732309	13506	2	1C
0005433398362	13506	3	2F
0005433398358	13506	4	3A
0005435732296	13506	5	3D
0005433398364	13506	6	4A
0005433398365	13506	7	4C
0005433398333	13506	8	4D
0005433398353	13506	9	4E
0005433398344	13506	10	4F
0005433398369	13506	11	5A
0005433398345	13506	12	5C
0005433398342	13506	13	6C
0005433398334	13506	14	6D
0005433398351	13506	15	6E
0005433398356	13506	16	6F
0005433398355	13506	17	7C
0005433398343	13506	18	7D
0005435732310	13506	19	7E
0005435732312	13506	20	7F
0005433398347	13506	21	8C
0005435732307	13506	22	8E
0005433398327	13506	23	9D
0005433398346	13506	24	9E
0005433398331	13506	25	9F
0005433398336	13506	26	10A
0005433398341	13506	27	10C
0005433398352	13506	28	10D
0005433398372	13506	29	10E
0005435732308	13506	30	10F
0005433398324	13506	31	11A
0005433398354	13506	32	11C
0005433398328	13506	33	11D
0005433398368	13506	34	11E
0005433398323	13506	35	11F
0005433398326	13506	36	13D
0005435732295	13506	37	13E
0005433398322	13506	38	13F
0005433398359	13506	39	14F
0005435732297	13506	40	15A
0005433398338	13506	41	15C
0005433398329	13506	42	15D
0005433398366	13506	43	15F
0005433398360	13506	44	16A
0005433398371	13506	45	16C
0005433398332	13506	46	16D
0005433398349	13506	47	16E
0005433398335	13506	48	16F
0005433398363	13506	49	17F
0005435732316	13506	50	18A
0005433398348	13506	51	18C
0005433398350	13506	52	18D
0005433398325	13506	53	18E
0005433398357	13506	54	18F
0005433398330	13506	55	19E
0005433398337	13506	56	19F
0005433398339	13506	57	20A
0005433398340	13506	58	20C
0005433398370	13506	59	20E
0005433398367	13506	60	20F
0005433398089	19420	1	1C
0005433398254	19420	2	1D
0005433398115	19420	3	2A
0005433397813	19420	4	2C
0005433397688	19420	5	2F
0005433397874	19420	6	3A
0005433397844	19420	7	3D
0005433397726	19420	8	4A
0005433397812	19420	9	4C
0005433398116	19420	10	4D
0005433397969	19420	11	4E
0005433397867	19420	12	5C
0005433397979	19420	13	5D
0005433397974	19420	14	6A
0005433398094	19420	15	6C
0005433398255	19420	16	6D
0005433397948	19420	17	6E
0005433397996	19420	18	7D
0005433397968	19420	19	7E
0005433398093	19420	20	7F
0005435732392	19420	21	8A
0005433397947	19420	22	8C
0005433398014	19420	23	8D
0005433397842	19420	24	8F
0005433398033	19420	25	9A
0005432297292	19420	26	9D
0005433397958	19420	27	9E
0005435732394	19420	28	9F
0005433397785	19420	29	10A
0005433397901	19420	30	10C
0005433397959	19420	31	10D
0005432297293	19420	32	10E
0005433398012	19420	33	11C
0005433397819	19420	34	11F
0005433397940	19420	35	12A
0005432297294	19420	36	12C
0005435732390	19420	37	12D
0005433397938	19420	38	12E
0005433398071	19420	39	13C
0005435732393	19420	40	13D
0005433398020	19420	41	13E
0005433397973	19420	42	14A
0005433397900	19420	43	14C
0005433397854	19420	44	14D
0005433398023	19420	45	15C
0005433397811	19420	46	15E
0005433397939	19420	47	15F
0005433397781	19420	48	16A
0005433397962	19420	49	16D
0005433398035	19420	50	16E
0005435732391	19420	51	16F
0005433397721	19420	52	17E
0005433397936	19420	53	17F
0005433397899	19420	54	18A
0005433397873	19420	55	18C
0005433398016	19420	56	18D
0005433397749	19420	57	18E
0005433397851	19420	58	18F
0005433398017	19420	59	19C
0005433397951	19420	60	19F
0005433397980	19420	61	20A
0005433397841	19420	62	20D
0005435068912	13153	1	1A
0005435069037	13153	2	1C
0005435925373	13153	3	1D
0005435068984	13153	4	1F
0005435068818	13153	5	2A
0005435069071	13153	6	2C
0005435925367	13153	7	2D
0005435068812	13153	8	3C
0005435068636	13153	9	4A
0005435069070	13153	10	4C
0005435068905	13153	11	4D
0005435069012	13153	12	4E
0005435925374	13153	13	4F
0005435925372	13153	14	5A
0005435069008	13153	15	5D
0005435068766	13153	16	5F
0005435068844	13153	17	6C
0005435925366	13153	18	6D
0005435068796	13153	19	6E
0005435925384	13153	20	6F
0005435068892	13153	21	7C
0005435069038	13153	22	7E
0005435925386	13153	23	7F
0005435069035	13153	24	8D
0005435069097	13153	25	8E
0005435068946	13153	26	8F
0005435068981	13153	27	9C
0005435069152	13153	28	9D
0005435069009	13153	29	9E
0005435068961	13153	30	9F
0005435925383	13153	31	10A
0005435068825	13153	32	10C
0005435068883	13153	33	10E
0005435068863	13153	34	10F
0005435068797	13153	35	11A
0005435068876	13153	36	11C
0005435069054	13153	37	11D
0005435068890	13153	38	11E
0005435068904	13153	39	11F
0005435068783	13153	40	12A
0005435068837	13153	41	12C
0005435925378	13153	42	12D
0005435925365	13153	43	12E
0005435068869	13153	44	12F
0005435925381	13153	45	13A
0005435068824	13153	46	13F
0005435068983	13153	47	14A
0005435925370	13153	48	14D
0005435925369	13153	49	14C
0005435925375	13153	50	14E
0005435068635	13153	51	15E
0005435925376	13153	52	15F
0005435925379	13153	53	16A
0005435068776	13153	54	16C
0005435068862	13153	55	16D
0005435925385	13153	56	16E
0005435068990	13153	57	16F
0005435925377	13153	58	17A
0005435925371	13153	59	17C
0005435925382	13153	60	17D
0005435068928	13153	61	17E
0005435925368	13153	62	17F
0005435068877	13153	63	18A
0005435068875	13153	64	18C
0005435068767	13153	65	18E
0005435069096	13153	66	18F
0005435068871	13153	67	19A
0005435925380	13153	68	19C
0005435069026	13153	69	19D
0005435068977	13153	70	19F
0005435068962	13153	71	20A
0005435068652	13153	72	20C
0005435068956	13153	73	20D
0005435068775	13153	74	20E
0005435068845	13153	75	20F
0005435069362	15507	1	1A
0005435069347	15507	2	1C
0005435069353	15507	3	1D
0005435925244	15507	4	2A
0005435925270	15507	5	2C
0005435069325	15507	6	2F
0005435925250	15507	7	3C
0005435925249	15507	8	3D
0005435069352	15507	9	3F
0005435069346	15507	10	4A
0005435069355	15507	11	4C
0005435069373	15507	12	4D
0005435069343	15507	13	4E
0005435069330	15507	14	4F
0005435069367	15507	15	5A
0005435925247	15507	16	5D
0005435069332	15507	17	6A
0005435069349	15507	18	6C
0005435925207	15507	19	6E
0005435069375	15507	20	6F
0005435069333	15507	21	7C
0005435925269	15507	22	7E
0005435069339	15507	23	7F
0005435069329	15507	24	8A
0005435069327	15507	25	8C
0005435069360	15507	26	8E
0005435069348	15507	27	8F
0005435069345	15507	28	9A
0005435069335	15507	29	9C
0005435069341	15507	30	9D
0005435069365	15507	31	10A
0005435069370	15507	32	10C
0005435069328	15507	33	10E
0005435069376	15507	34	10D
0005435069351	15507	35	11A
0005435069342	15507	36	11C
0005435069324	15507	37	11D
0005435069350	15507	38	11F
0005435069358	15507	39	12A
0005435069371	15507	40	12C
0005435069344	15507	41	12D
0005435925221	15507	42	12E
0005435069337	15507	43	12F
0005435069338	15507	44	13A
0005435069369	15507	45	13C
0005435925256	15507	46	13D
0005435925209	15507	47	13E
0005435069374	15507	48	13F
0005435069357	15507	49	14A
0005435069363	15507	50	14C
0005435925222	15507	51	14D
0005435069372	15507	52	14E
0005435925208	15507	53	14F
0005435925239	15507	54	16A
0005435069354	15507	55	16D
0005435069334	15507	56	16E
0005435925268	15507	57	16F
0005435069356	15507	58	17A
0005435069364	15507	59	17C
0005435069368	15507	60	17E
0005435925246	15507	61	18A
0005435069366	15507	62	18D
0005435069340	15507	63	18E
0005435069331	15507	64	18F
0005435925252	15507	65	19A
0005435069359	15507	66	19C
0005435069361	15507	67	19F
0005435925245	15507	68	20A
0005435069326	15507	69	20E
0005435069336	15507	70	20F
0005433407592	29489	1	1B
0005435808210	29489	2	1C
0005435808176	29489	3	1D
0005435808167	29489	4	2A
0005435808208	29489	5	2B
0005435808153	29489	6	2C
0005435808230	29489	7	3A
0005435808140	29489	8	3B
0005433407599	29489	9	3C
0005433407596	29489	10	4A
0005433407595	29489	11	4D
0005435808211	29489	12	5B
0005435808144	29489	13	6A
0005433407600	29489	14	6B
0005435808184	29489	15	6C
0005435808181	29489	16	6D
0005435808229	29489	17	7A
0005435808261	29489	18	7B
0005435808209	29489	19	18A
0005433407598	29489	20	18B
0005435808260	29489	21	18C
0005435808191	29489	22	18D
0005435808162	29489	23	19B
0005435808186	29489	24	19D
0005435808192	29489	25	20A
0005435808166	29489	26	20B
0005435808136	29489	27	20C
0005435808183	29489	28	20D
0005435808185	29489	29	21A
0005433407593	29489	30	21B
0005433407594	29489	31	21C
0005433407597	29489	32	22D
0005435808141	29489	33	23B
0005434214797	10712	1	1A
0005434214795	10712	2	1C
0005434214801	10712	3	1D
0005434756195	10712	4	1F
0005434756231	10712	5	2A
0005434756306	10712	6	2C
0005434756305	10712	7	2D
0005434214824	10712	8	2F
0005434756289	10712	9	3A
0005434214822	10712	10	3C
0005434214819	10712	11	3D
0005434756326	10712	12	3F
0005434214820	10712	13	4A
0005434214823	10712	14	4C
0005434756215	10712	15	4D
0005434756256	10712	16	4E
0005434756320	10712	17	4F
0005434756216	10712	18	5A
0005434214832	10712	19	5C
0005434214833	10712	20	5E
0005434214814	10712	21	5F
0005434214794	10712	22	6A
0005434214827	10712	23	6C
0005434756293	10712	24	6D
0005434756349	10712	25	6E
0005434756196	10712	26	6F
0005434214838	10712	27	7A
0005434214818	10712	28	7C
0005434756240	10712	29	7D
0005434756265	10712	30	7E
0005434214808	10712	31	7F
0005434214811	10712	32	8C
0005434214839	10712	33	8D
0005434214821	10712	34	8E
0005434756335	10712	35	8F
0005434756187	10712	36	9A
0005434756332	10712	37	9C
0005434214793	10712	38	9D
0005434214807	10712	39	9E
0005434756156	10712	40	10C
0005434756247	10712	41	10D
0005434756334	10712	42	10E
0005434214825	10712	43	10F
0005434214802	10712	44	11A
0005434756313	10712	45	11C
0005434214809	10712	46	11D
0005434214815	10712	47	11E
0005434214817	10712	48	11F
0005434214836	10712	49	12A
0005434756319	10712	50	12C
0005434756283	10712	51	12D
0005434214812	10712	52	12E
0005434756188	10712	53	12F
0005434756154	10712	54	13C
0005434756257	10712	55	13D
0005434755984	10712	56	13E
0005434214830	10712	57	13F
0005434214798	10712	58	14A
0005434756333	10712	59	14C
0005434214799	10712	60	14D
0005434214834	10712	61	14F
0005434756246	10712	62	15A
0005434214806	10712	63	15C
0005434214803	10712	64	15D
0005434214831	10712	65	15E
0005434756350	10712	66	15F
0005434214816	10712	67	16A
0005434756351	10712	68	16C
0005434214828	10712	69	16D
0005434756327	10712	70	16E
0005434756155	10712	71	16F
0005434756235	10712	72	17A
0005434756090	10712	73	17C
0005434214813	10712	74	17D
0005434214800	10712	75	17E
0005434214804	10712	76	17F
0005434756201	10712	77	18A
0005434214835	10712	78	18C
0005434756321	10712	79	18D
0005434756345	10712	80	18E
0005434214810	10712	81	18F
0005434214805	10712	82	19D
0005434214826	10712	83	19E
0005434214796	10712	84	19F
0005434214829	10712	85	20A
0005434756282	10712	86	20C
0005434756331	10712	87	20D
0005434214837	10712	88	20E
0005434756625	28662	1	1A
0005434756638	28662	2	1C
0005434214462	28662	3	1D
0005434756648	28662	4	1F
0005434756652	28662	5	2A
0005434214191	28662	6	2C
0005434214265	28662	7	2D
0005434756630	28662	8	2F
0005434214461	28662	9	3A
0005434756623	28662	10	3C
0005434756653	28662	11	3D
0005434214450	28662	12	3F
0005434756655	28662	13	4A
0005434214113	28662	14	4C
0005434756642	28662	15	4D
0005434756650	28662	16	4E
0005434214256	28662	17	4F
0005434756633	28662	18	5A
0005434214180	28662	19	5C
0005434214297	28662	20	5D
0005434214323	28662	21	5E
0005434214292	28662	22	5F
0005434214151	28662	23	6A
0005434756656	28662	24	6C
0005434756624	28662	25	6D
0005434756657	28662	26	6E
0005434214155	28662	27	6F
0005434214147	28662	28	7A
0005434756640	28662	29	7C
0005434214370	28662	30	7D
0005434756645	28662	31	7E
0005434756632	28662	32	7F
0005434214458	28662	33	8A
0005434756637	28662	34	8C
0005434756649	28662	35	8D
0005434214263	28662	36	8E
0005434214435	28662	37	8F
0005434214345	28662	38	9A
0005434214359	28662	39	9C
0005434756631	28662	40	9D
0005434756651	28662	41	9E
0005434756614	28662	42	9F
0005434214244	28662	43	10A
0005434214296	28662	44	10D
0005434214169	28662	45	10E
0005434756658	28662	46	10F
0005434214429	28662	47	11A
0005434756661	28662	48	11C
0005434214451	28662	49	11D
0005434214321	28662	50	11E
0005434756628	28662	51	11F
0005434214324	28662	52	12A
0005434756643	28662	53	12C
0005434214136	28662	54	12D
0005434214408	28662	55	12E
0005434756618	28662	56	12F
0005434756613	28662	57	13A
0005434756647	28662	58	13C
0005434756619	28662	59	13D
0005434756621	28662	60	13E
0005434756659	28662	61	13F
0005434756627	28662	62	14A
0005434756646	28662	63	14C
0005434214347	28662	64	14D
0005434214135	28662	65	14E
0005434756634	28662	66	14F
0005434214371	28662	67	15A
0005434214570	28662	68	15C
0005434214452	28662	69	15D
0005434756654	28662	70	15E
0005434214168	28662	71	15F
0005434756622	28662	72	16A
0005434756662	28662	73	16C
0005434214344	28662	74	16D
0005434214283	28662	75	16E
0005434756644	28662	76	16F
0005434756617	28662	77	17A
0005434214477	28662	78	17C
0005434756615	28662	79	17E
0005434214282	28662	80	17F
0005434756616	28662	81	18A
0005434756636	28662	82	18C
0005434756660	28662	83	18D
0005434756664	28662	84	18E
0005434214434	28662	85	18F
0005434214134	28662	86	19A
0005434756641	28662	87	19D
0005434756639	28662	88	19C
0005434756620	28662	89	19F
0005434214279	28662	90	20A
0005434756663	28662	91	20C
0005434756629	28662	92	20D
0005434756635	28662	93	20E
0005434756626	28662	94	20F
0005435040140	5458	1	1A
0005435040155	5458	2	1C
0005435040178	5458	3	1D
0005434229230	5458	4	2A
0005435007176	5458	5	1F
0005435040146	5458	6	2C
0005435040171	5458	7	2D
0005435040190	5458	8	2F
0005435040151	5458	9	3C
0005435007161	5458	10	3A
0005435042867	5458	11	3D
0005435040137	5458	12	3F
0005435040153	5458	13	4A
0005434229295	5458	14	4C
0005435007163	5458	15	4B
0005435040135	5458	16	4E
0005435040139	5458	17	4D
0005435007177	5458	18	4F
0005435042866	5458	19	5A
0005434229321	5458	20	5C
0005435042868	5458	21	5B
0005435040188	5458	22	5D
0005435040133	5458	23	5E
0005435040165	5458	24	5F
0005435040159	5458	25	6C
0005435007167	5458	26	6B
0005434229291	5458	27	6D
0005435040192	5458	28	6F
0005435040169	5458	29	7A
0005435040149	5458	30	7C
0005435040193	5458	31	7D
0005435040182	5458	32	7F
0005435040145	5458	33	7E
0005435040144	5458	34	8B
0005435040181	5458	35	8C
0005434229310	5458	36	8E
0005434229309	5458	37	8F
0005432125496	5458	38	9A
0005435007166	5458	39	9D
0005435040154	5458	40	9C
0005435007169	5458	41	9E
0005435040186	5458	42	10D
0005435040175	5458	43	10E
0005435042869	5458	44	11C
0005435040162	5458	45	11B
0005435043290	5458	46	11D
0005435040158	5458	47	11E
0005435040166	5458	48	12A
0005435040142	5458	49	12B
0005435007165	5458	50	12C
0005435040136	5458	51	12E
0005435040185	5458	52	12D
0005434229325	5458	53	13A
0005435040148	5458	54	13B
0005434229288	5458	55	13C
0005435007171	5458	56	13D
0005435040150	5458	57	13E
0005432125499	5458	58	13F
0005435040157	5458	59	14A
0005435040168	5458	60	14B
0005434229300	5458	61	14D
0005434229374	5458	62	14F
0005435040187	5458	63	15B
0005435007175	5458	64	15A
0005435040179	5458	65	15C
0005432125498	5458	66	15D
0005435040174	5458	67	15F
0005435040132	5458	68	15E
0005435040141	5458	69	16B
0005435040170	5458	70	16A
0005435040147	5458	71	16D
0005435040176	5458	72	16C
0005434229387	5458	73	16E
0005435040183	5458	74	16F
0005434229202	5458	75	17B
0005434229355	5458	76	17A
0005435040173	5458	77	17C
0005432125493	5458	78	17F
0005435042870	5458	79	17E
0005435040172	5458	80	18B
0005434229324	5458	81	18A
0005435043291	5458	82	18C
0005435007172	5458	83	18D
0005432125497	5458	84	18F
0005435040161	5458	85	18E
0005435040156	5458	86	19A
0005435377902	5458	87	19B
0005435040180	5458	88	19C
0005434229201	5458	89	19D
0005435040184	5458	90	19E
0005432125495	5458	91	20A
0005435007174	5458	92	20B
0005435040138	5458	93	20C
0005435040143	5458	94	20E
0005435040134	5458	95	20D
0005432125494	5458	96	20F
0005435007162	5458	97	21B
0005435040194	5458	98	21A
0005435377903	5458	99	21D
0005435007164	5458	100	21C
0005435007173	5458	101	21E
0005435040163	5458	102	21F
0005435007170	5458	103	22B
0005434229348	5458	104	22A
0005435040177	5458	105	22C
0005435040167	5458	106	22E
0005435040152	5458	107	22D
0005435007168	5458	108	22F
0005435040189	5458	109	23A
0005435377901	5458	110	23B
0005435040191	5458	111	23C
0005435040164	5458	112	23D
0005435040160	5458	113	23F
0005435006918	12965	1	1A
0005435039350	12965	2	1C
0005434229499	12965	3	1D
0005435006960	12965	4	2A
0005435039579	12965	5	1F
0005434229517	12965	6	2C
0005435039545	12965	7	2D
0005435039561	12965	8	2F
0005435039532	12965	9	3A
0005435039906	12965	10	3D
0005435006961	12965	11	3F
0005435039383	12965	12	4B
0005434229513	12965	13	4A
0005435039775	12965	14	4C
0005435039491	12965	15	4E
0005435039803	12965	16	4D
0005435039629	12965	17	4F
0005435006975	12965	18	5A
0005435039710	12965	19	5C
0005435039428	12965	20	5B
0005435039573	12965	21	5D
0005435006917	12965	22	5E
0005435039389	12965	23	6A
0005435039767	12965	24	5F
0005435039624	12965	25	6B
0005435006895	12965	26	6C
0005434229515	12965	27	6E
0005432304422	12965	28	6D
0005435006940	12965	29	6F
0005434229507	12965	30	7B
0005435039773	12965	31	7A
0005435039801	12965	32	7C
0005435039724	12965	33	7D
0005435039625	12965	34	7E
0005435006957	12965	35	8A
0005435039732	12965	36	7F
0005435039818	12965	37	8B
0005435006990	12965	38	8C
0005435006939	12965	39	8D
0005434229520	12965	40	8F
0005435039652	12965	41	8E
0005435039861	12965	42	9A
0005434229511	12965	43	9B
0005434229519	12965	44	9C
0005432304423	12965	45	9E
0005434229509	12965	46	9D
0005435039804	12965	47	9F
0005435039517	12965	48	10B
0005435007002	12965	49	10D
0005435039270	12965	50	10C
0005434229508	12965	51	11A
0005435039769	12965	52	10E
0005434229500	12965	53	11B
0005435039580	12965	54	11D
0005435039607	12965	55	11C
0005435039384	12965	56	11E
0005432304421	12965	57	11F
0005435039787	12965	58	12B
0005435039647	12965	59	12A
0005435039650	12965	60	12C
0005435039800	12965	61	12E
0005435039765	12965	62	12D
0005435039642	12965	63	12F
0005434229518	12965	64	13A
0005435039563	12965	65	13B
0005435039492	12965	66	13D
0005435039518	12965	67	13C
0005434229514	12965	68	13E
0005435039838	12965	69	13F
0005434229512	12965	70	14A
0005435039860	12965	71	14C
0005435039562	12965	72	14B
0005434229504	12965	73	14D
0005435006984	12965	74	14E
0005435039477	12965	75	15A
0005435039651	12965	76	14F
0005435039837	12965	77	15B
0005434229502	12965	78	15C
0005435039667	12965	79	15D
0005434229503	12965	80	15E
0005435039760	12965	81	16A
0005435039456	12965	82	15F
0005435039516	12965	83	16B
0005435039450	12965	84	16C
0005435039478	12965	85	16E
0005435039777	12965	86	16D
0005435039817	12965	87	16F
0005434229510	12965	88	17A
0005435039863	12965	89	17B
0005435039774	12965	90	17D
0005435039266	12965	91	17C
0005435039678	12965	92	17F
0005435039468	12965	93	17E
0005435006995	12965	94	18A
0005435039263	12965	95	18C
0005435039489	12965	96	18B
0005435006974	12965	97	18E
0005435042846	12965	98	18D
0005435039603	12965	99	18F
0005435039786	12965	100	19A
0005434229501	12965	101	19C
0005435039725	12965	102	19B
0005435039824	12965	103	19E
0005435039416	12965	104	19D
0005435006953	12965	105	19F
0005435039655	12965	106	20A
0005435039630	12965	107	20B
0005435039668	12965	108	20D
0005435039833	12965	109	20C
0005435039785	12965	110	20E
0005434229498	12965	111	20F
0005435039604	12965	112	21A
0005435039726	12965	113	21C
0005435006956	12965	114	21B
0005435039697	12965	115	21D
0005435006888	12965	116	21E
0005434229506	12965	117	21F
0005435039731	12965	118	22B
0005435039653	12965	119	22A
0005435039519	12965	120	22C
0005435039311	12965	121	22D
0005435039271	12965	122	22F
0005435007025	12965	123	22E
0005434229516	12965	124	23A
0005435039548	12965	125	23B
0005434229505	12965	126	23C
0005435039654	12965	127	23E
0005435039496	12965	128	23D
0005435039768	12965	129	23F
0005435902663	14894	1	1C
0005434411798	14894	2	1D
0005435554149	14894	3	1F
0005435902684	14894	4	2A
0005434426763	14894	5	2C
0005434426767	14894	6	2F
0005435554166	14894	7	3D
0005435554151	14894	8	3F
0005434426750	14894	9	4A
0005434411800	14894	10	4C
0005435902668	14894	11	4E
0005434426773	14894	12	4F
0005432188624	14894	13	5A
0005434426766	14894	14	5C
0005434426753	14894	15	5D
0005435902670	14894	16	5E
0005435902575	14894	17	5F
0005435554169	14894	18	6A
0005435902643	14894	19	6C
0005434426752	14894	20	6E
0005434426774	14894	21	7A
0005435902658	14894	22	7D
0005435902549	14894	23	7E
0005435902660	14894	24	7F
0005434426777	14894	25	8A
0005435554177	14894	26	8C
0005434426760	14894	27	8E
0005434426748	14894	28	8F
0005434426761	14894	29	9E
0005434411803	14894	30	9F
0005435902683	14894	31	10A
0005434426758	14894	32	10C
0005434426756	14894	33	10D
0005435902637	14894	34	10E
0005434426754	14894	35	10F
0005435554152	14894	36	11A
0005434426775	14894	37	11C
0005435902630	14894	38	11E
0005434426759	14894	39	11F
0005434411799	14894	40	12C
0005434426770	14894	41	12D
0005434426769	14894	42	12E
0005434426755	14894	43	13A
0005435902627	14894	44	13C
0005434426771	14894	45	13D
0005435554168	14894	46	13E
0005435902576	14894	47	13F
0005435902669	14894	48	14A
0005435902685	14894	49	14C
0005435902628	14894	50	14E
0005435902578	14894	51	14F
0005434426772	14894	52	15A
0005435554172	14894	53	15C
0005435902577	14894	54	15D
0005434426762	14894	55	15F
0005434411801	14894	56	16C
0005434426768	14894	57	16D
0005432188623	14894	58	16E
0005435554165	14894	59	16F
0005434426764	14894	60	17A
0005434426776	14894	61	17C
0005432188625	14894	62	17D
0005435902657	14894	63	17E
0005435902613	14894	64	18A
0005435902681	14894	65	18D
0005434426749	14894	66	18E
0005435554171	14894	67	18F
0005434426765	14894	68	19A
0005434426757	14894	69	19C
0005435554170	14894	70	19D
0005434411802	14894	71	19E
0005434426751	14894	72	20A
0005435554150	14894	73	20C
0005435902636	14894	74	20D
0005435902635	14894	75	20F
0005435902804	20190	1	1C
0005434426572	20190	2	1D
0005434426517	20190	3	1F
0005435902807	20190	4	2A
0005434411766	20190	5	2C
0005434426526	20190	6	2D
0005432059517	20190	7	3F
0005434426438	20190	8	4A
0005435554219	20190	9	4E
0005434426499	20190	10	4F
0005435902813	20190	11	5C
0005434411773	20190	12	5E
0005434426498	20190	13	6A
0005435902808	20190	14	6E
0005435902817	20190	15	6F
0005434426500	20190	16	7A
0005435902820	20190	17	7C
0005434426516	20190	18	7D
0005434426646	20190	19	7E
0005434426551	20190	20	7F
0005434426645	20190	21	8D
0005434426652	20190	22	8F
0005435902811	20190	23	9D
0005434426515	20190	24	9F
0005434426519	20190	25	10A
0005435902806	20190	26	10C
0005434426623	20190	27	10D
0005434411772	20190	28	10E
0005434426638	20190	29	11A
0005434426642	20190	30	11D
0005434426482	20190	31	11E
0005435902815	20190	32	12A
0005434426524	20190	33	12C
0005434426525	20190	34	12E
0005434426548	20190	35	12F
0005434426489	20190	36	13A
0005435554218	20190	37	13C
0005435902809	20190	38	13D
0005434426656	20190	39	13E
0005435554221	20190	40	13F
0005434426616	20190	41	14A
0005434426583	20190	42	14E
0005434426622	20190	43	14F
0005432059516	20190	44	15A
0005435902805	20190	45	15C
0005435554220	20190	46	15E
0005434426518	20190	47	15F
0005434426428	20190	48	16A
0005434426577	20190	49	16D
0005435902810	20190	50	16E
0005434426639	20190	51	17A
0005434426481	20190	52	17D
0005435902818	20190	53	17E
0005434426644	20190	54	17F
0005434426490	20190	55	18A
0005434426538	20190	56	18C
0005435902814	20190	57	18F
0005434426567	20190	58	19C
0005434426643	20190	59	19E
0005435902812	20190	60	19F
0005435902816	20190	61	20A
0005435902819	20190	62	20C
0005434426630	20190	63	20D
0005434426488	20190	64	20E
0005434411767	20190	65	20F
0005434523768	28009	1	2A
0005432462528	28009	2	3D
0005434523752	28009	3	4E
0005434523763	28009	4	6A
0005434523772	28009	5	7F
0005434523765	28009	6	9C
0005434523764	28009	7	10C
0005434523762	28009	8	12E
0005432462527	28009	9	14D
0005432462526	28009	10	15E
0005434523749	28009	11	21A
0005434523773	28009	12	21E
0005434523766	28009	13	21F
0005432462525	28009	14	22C
0005432462524	28009	15	22B
0005434523761	28009	16	23F
0005435982567	26553	1	1C
0005435982553	26553	2	1D
0005433434449	26553	3	1F
0005433434629	26553	4	2C
0005433434573	26553	5	2D
0005433434662	26553	6	2F
0005433434572	26553	7	3A
0005435982544	26553	8	3C
0005433434619	26553	9	3D
0005433434554	26553	10	3F
0005433434450	26553	11	4A
0005435982549	26553	12	4C
0005435982562	26553	13	4D
0005435982560	26553	14	4E
0005433434630	26553	15	4F
0005435982566	26553	16	5A
0005435982555	26553	17	5C
0005435982558	26553	18	5D
0005435982552	26553	19	5E
0005435982547	26553	20	5F
0005432300296	26553	21	6C
0005433434636	26553	22	6D
0005434273072	26553	23	6E
0005433434527	26553	24	6F
0005435982534	26553	25	7A
0005435982528	26553	26	7C
0005435982569	26553	27	7D
0005433434596	26553	28	7E
0005435982542	26553	29	7F
0005435982538	26553	30	8A
0005432300294	26553	31	8C
0005433434580	26553	32	8D
0005433434470	26553	33	8E
0005433434587	26553	34	9A
0005433434471	26553	35	9C
0005433434526	26553	36	9D
0005433434620	26553	37	9E
0005435982564	26553	38	9F
0005435982568	26553	39	10A
0005435982554	26553	40	10C
0005435982530	26553	41	10D
0005432300295	26553	42	10F
0005435982565	26553	43	11C
0005433434562	26553	44	11D
0005433434483	26553	45	11F
0005435982551	26553	46	12A
0005435982548	26553	47	12C
0005433434715	26553	48	12D
0005435982536	26553	49	12E
0005435982532	26553	50	12F
0005433434621	26553	51	13A
0005435982545	26553	52	13C
0005435982561	26553	53	13D
0005435982541	26553	54	13E
0005435982557	26553	55	13F
0005433434597	26553	56	14A
0005433434563	26553	57	14C
0005433434594	26553	58	14D
0005432300291	26553	59	14E
0005433434561	26553	60	14F
0005435982543	26553	61	15C
0005435982546	26553	62	15D
0005433434599	26553	63	15E
0005435982539	26553	64	15F
0005433434575	26553	65	16A
0005435982556	26553	66	16C
0005433434595	26553	67	16D
0005435982533	26553	68	16E
0005435982527	26553	69	16F
0005435982537	26553	70	17A
0005435982531	26553	71	17D
0005434273074	26553	72	17E
0005435982563	26553	73	17F
0005435982570	26553	74	18D
0005435982550	26553	75	18E
0005433434482	26553	76	18F
0005432300293	26553	77	19C
0005433434674	26553	78	19D
0005434273073	26553	79	19E
0005435982559	26553	80	19F
0005433434574	26553	81	20A
0005435982540	26553	82	20C
0005435982529	26553	83	20D
0005432300292	26553	84	20E
0005435982535	26553	85	20F
0005435982197	26695	1	1A
0005435982126	26695	2	1C
0005435982183	26695	3	1D
0005435982075	26695	4	2A
0005435982073	26695	5	2C
0005435981919	26695	6	2D
0005432051149	26695	7	2F
0005435981971	26695	8	3A
0005434270220	26695	9	3C
0005433434850	26695	10	3D
0005435982130	26695	11	3F
0005435982196	26695	12	4C
0005435982058	26695	13	4D
0005435982286	26695	14	4E
0005434271324	26695	15	4F
0005433434849	26695	16	5A
0005434271326	26695	17	5C
0005433434845	26695	18	5D
0005433434865	26695	19	5E
0005433434847	26695	20	5F
0005435982090	26695	21	6A
0005433434844	26695	22	6C
0005435982281	26695	23	6D
0005435982225	26695	24	6E
0005433434862	26695	25	6F
0005433434863	26695	26	7C
0005435981972	26695	27	7D
0005433434846	26695	28	7E
0005433434848	26695	29	7F
0005433434868	26695	30	8A
0005434269117	26695	31	8C
0005433434852	26695	32	8D
0005432051146	26695	33	8E
0005435982053	26695	34	8F
0005435982057	26695	35	9A
0005433434864	26695	36	9C
0005433434854	26695	37	9D
0005435982269	26695	38	9E
0005435982315	26695	39	9F
0005435982052	26695	40	10A
0005435982018	26695	41	10C
0005433434866	26695	42	10D
0005435982158	26695	43	10E
0005435982125	26695	44	10F
0005435982282	26695	45	11C
0005432051147	26695	46	11D
0005435982113	26695	47	11E
0005434271325	26695	48	11F
0005435982262	26695	49	12A
0005435982204	26695	50	12C
0005433434853	26695	51	12D
0005433434855	26695	52	12E
0005435981988	26695	53	12F
0005435982084	26695	54	13A
0005435982171	26695	55	13C
0005435982314	26695	56	13D
0005435982182	26695	57	13E
0005433434851	26695	58	13F
0005435982238	26695	59	14A
0005433434842	26695	60	14C
0005435982270	26695	61	14D
0005435982237	26695	62	14E
0005434270219	26695	63	14F
0005435982271	26695	64	15A
0005433434861	26695	65	15C
0005435982205	26695	66	15E
0005435982206	26695	67	15F
0005435982101	26695	68	16A
0005435982157	26695	69	16C
0005435982229	26695	70	16D
0005433434843	26695	71	16E
0005435982181	26695	72	16F
0005435982098	26695	73	17A
0005435982214	26695	74	17C
0005433434870	26695	75	17D
0005435982076	26695	76	17E
0005433434859	26695	77	17F
0005435982161	26695	78	18A
0005435982127	26695	79	18C
0005435982059	26695	80	18D
0005433434856	26695	81	18E
0005433434867	26695	82	19A
0005433434858	26695	83	19C
0005435982285	26695	84	19D
0005435982100	26695	85	19E
0005435982093	26695	86	20A
0005432051148	26695	87	19F
0005433434869	26695	88	20C
0005433434860	26695	89	20D
0005433434857	26695	90	20E
0005434269116	26695	91	20F
0005433686628	29270	1	3B
0005433686626	29270	2	4C
0005433689899	29270	3	4D
0005433686630	29270	4	5D
0005433686625	29270	5	7D
0005433689910	29270	6	18D
0005433686608	29270	7	20A
0005433686629	29270	8	22A
0005433689909	29270	9	22C
0005433689898	29270	10	23A
0005432858052	3145	1	1A
0005432857986	3145	2	1B
0005432584194	3145	3	1C
0005432584176	3145	4	1D
0005432584192	3145	5	2B
0005432858018	3145	6	2C
0005432584177	3145	7	3B
0005432584193	3145	8	3C
0005432584179	3145	9	3D
0005432584178	3145	10	4B
0005432216289	3145	11	4C
0005432584197	3145	12	5A
0005432584198	3145	13	5C
0005432216290	3145	14	5D
0005432584199	3145	15	6A
0005432584200	3145	16	6C
0005432584180	3145	17	6D
0005432584186	3145	18	7A
0005432584183	3145	19	7B
0005432584196	3145	20	7D
0005432858055	3145	21	18A
0005432584195	3145	22	18B
0005432858050	3145	23	18C
0005432857987	3145	24	18D
0005432584188	3145	25	19A
0005432584189	3145	26	19B
0005432858053	3145	27	19C
0005432858039	3145	28	19D
0005432584181	3145	29	20B
0005432584185	3145	30	20C
0005432584190	3145	31	20D
0005432584191	3145	32	21B
0005432858041	3145	33	21D
0005432858070	3145	34	22A
0005432584187	3145	35	22B
0005432858115	3145	36	22C
0005432584184	3145	37	22D
0005432216291	3145	38	23A
0005432584182	3145	39	23B
0005432583875	31521	1	1A
0005432583962	31521	2	1D
0005432858143	31521	3	2B
0005432584079	31521	4	3B
0005432583947	31521	5	3C
0005432858139	31521	6	3D
0005432584005	31521	7	4A
0005432858142	31521	8	4B
0005432583874	31521	9	4D
0005432584023	31521	10	4C
0005432584084	31521	11	5A
0005432858137	31521	12	5B
0005432583948	31521	13	5D
0005432583979	31521	14	6A
0005432584078	31521	15	6B
0005432583946	31521	16	6C
0005432584081	31521	17	6D
0005432584085	31521	18	7A
0005432858140	31521	19	7B
0005432584051	31521	20	7C
0005432858145	31521	21	7D
0005432583961	31521	22	18A
0005432858146	31521	23	18B
0005432584015	31521	24	18C
0005432858141	31521	25	19A
0005432584034	31521	26	19C
0005432584022	31521	27	20A
0005432858144	31521	28	20B
0005432584080	31521	29	20C
0005432583881	31521	30	20D
0005432584047	31521	31	21B
0005432858135	31521	32	21C
0005432583976	31521	33	21D
0005432583975	31521	34	22A
0005432858147	31521	35	22B
0005432858136	31521	36	22C
0005432858138	31521	37	23A
0005432583999	31521	38	23B
0005434943410	907	1	1D
0005434943409	907	2	2C
0005433255078	907	3	2D
0005433255104	907	4	4C
0005433255099	907	5	4D
0005433255089	907	6	7A
0005434943411	907	7	18A
0005433255103	907	8	19A
0005434943404	907	9	19C
0005434943403	907	10	20C
0005434943407	907	11	21A
0005434943408	907	12	21B
0005434943405	907	13	21D
0005434943406	907	14	23B
0005433255151	16234	1	2B
0005434943363	16234	2	2D
0005433255154	16234	3	3D
0005434943321	16234	4	4B
0005434943322	16234	5	4D
0005434943320	16234	6	5A
0005433255153	16234	7	6B
0005433255152	16234	8	6D
0005434943302	16234	9	18A
0005434943316	16234	10	19A
0005433255150	16234	11	19B
0005434943364	16234	12	20A
0005434943377	16234	13	20D
0005434943334	16234	14	21C
0005434943378	16234	15	23B
0005435653291	21751	1	1A
0005435653278	21751	2	1D
0005433367726	21751	3	1F
0005435653283	21751	4	2A
0005435653273	21751	5	2C
0005433367857	21751	6	2F
0005433367826	21751	7	3C
0005435653284	21751	8	3D
0005435653262	21751	9	3F
0005435653269	21751	10	4A
0005433367825	21751	11	4C
0005433367819	21751	12	4E
0005435653268	21751	13	4F
0005435653290	21751	14	5A
0005433367649	21751	15	5C
0005433367704	21751	16	5D
0005433367849	21751	17	5E
0005435653263	21751	18	6A
0005435653279	21751	19	6C
0005435653288	21751	20	6E
0005433367611	21751	21	6F
0005433367571	21751	22	7A
0005433367745	21751	23	7C
0005435653281	21751	24	7D
0005433367688	21751	25	7F
0005435653287	21751	26	8A
0005433367722	21751	27	8C
0005435653264	21751	28	8D
0005433367706	21751	29	8E
0005433367744	21751	30	8F
0005433367867	21751	31	9C
0005433367628	21751	32	9D
0005433367752	21751	33	9E
0005435653289	21751	34	9F
0005433367705	21751	35	10A
0005435653270	21751	36	10C
0005433367643	21751	37	10D
0005435653266	21751	38	10E
0005435653285	21751	39	10F
0005435653294	21751	40	11A
0005433367572	21751	41	11E
0005433367850	21751	42	12A
0005433367823	21751	43	12C
0005435653271	21751	44	12D
0005435653274	21751	45	12F
0005435653277	21751	46	13A
0005435653267	21751	47	13C
0005433367607	21751	48	13F
0005433367760	21751	49	14A
0005435653280	21751	50	14D
0005433367687	21751	51	14E
0005433367832	21751	52	14F
0005435653293	21751	53	15A
0005435653272	21751	54	15C
0005433367721	21751	55	15F
0005433367796	21751	56	16C
0005435653265	21751	57	16D
0005433367822	21751	58	16E
0005435653282	21751	59	16F
0005435653275	21751	60	17A
0005433367727	21751	61	17D
0005433367821	21751	62	17E
0005433367845	21751	63	17F
0005435653286	21751	64	18D
0005433367606	21751	65	18E
0005433367854	21751	66	19C
0005433367759	21751	67	19D
0005433367907	21751	68	19E
0005435653292	21751	69	20C
0005433367700	21751	70	20D
0005433367602	21751	71	20E
0005435653276	21751	72	20F
0005433805593	9340	1	1A
0005433805586	9340	2	1B
0005433763293	9340	3	1F
0005435269700	9340	4	1G
0005435269737	9340	5	2A
0005434273071	9340	6	1H
0005433805595	9340	7	2B
0005432667465	9340	8	2H
0005433805606	9340	9	3C
0005433805613	9340	10	4A
0005433785159	9340	11	4B
0005433785169	9340	12	4C
0005433785154	9340	13	4F
0005432667466	9340	14	5A
0005432657466	9340	15	5C
0005435269736	9340	16	5G
0005434171100	9340	17	5F
0005434171092	9340	18	5H
0005433805605	9340	19	9H
0005433805609	9340	20	9G
0005433763290	9340	21	9B
0005435269712	9340	22	11A
0005433805588	9340	23	11B
0005433805591	9340	24	11E
0005433785177	9340	25	11D
0005433805597	9340	26	11F
0005433785160	9340	27	11H
0005433785172	9340	28	11G
0005433785175	9340	29	12A
0005434171028	9340	30	12B
0005433785157	9340	31	12E
0005434273069	9340	32	12G
0005433763294	9340	33	12H
0005433805590	9340	34	13B
0005433805583	9340	35	13D
0005433785168	9340	36	13F
0005434171057	9340	37	13H
0005432667468	9340	38	14A
0005435269738	9340	39	14F
0005433785183	9340	40	14E
0005433763301	9340	41	14H
0005433805601	9340	42	15D
0005434171016	9340	43	15B
0005433785186	9340	44	15E
0005433805598	9340	45	15F
0005435269710	9340	46	16A
0005433785158	9340	47	16B
0005433805582	9340	48	16E
0005433805573	9340	49	16H
0005433785171	9340	50	17B
0005433785184	9340	51	17A
0005434171099	9340	52	17D
0005433805592	9340	53	17F
0005433763299	9340	54	17E
0005433805584	9340	55	18B
0005433763300	9340	56	18A
0005434270209	9340	57	18E
0005433805600	9340	58	18G
0005434171020	9340	59	18H
0005433805589	9340	60	19D
0005433805599	9340	61	19F
0005433763291	9340	62	19E
0005433763297	9340	63	19H
0005433785185	9340	64	20A
0005434171021	9340	65	20D
0005433785174	9340	66	20B
0005433805587	9340	67	20E
0005435269735	9340	68	20F
0005435269739	9340	69	20H
0005433805580	9340	70	21A
0005434171027	9340	71	21D
0005433785176	9340	72	21B
0005434171094	9340	73	21G
0005432667467	9340	74	21H
0005433785162	9340	75	22B
0005434171024	9340	76	22F
0005434171026	9340	77	22H
0005434171019	9340	78	23E
0005435269701	9340	79	23D
0005433805614	9340	80	23F
0005433785156	9340	81	24A
0005433785179	9340	82	23H
0005433785178	9340	83	24B
0005433763288	9340	84	24D
0005433785187	9340	85	24F
0005432666402	9340	86	25E
0005433785163	9340	87	25D
0005433805615	9340	88	27A
0005432665286	9340	89	27B
0005433805612	9340	90	27H
0005433763295	9340	91	27G
0005434171015	9340	92	28A
0005435269740	9340	93	28D
0005433785181	9340	94	28B
0005433763298	9340	95	28G
0005433805585	9340	96	28F
0005433805594	9340	97	28H
0005433785155	9340	98	29A
0005433805607	9340	99	29D
0005433785180	9340	100	29B
0005433763292	9340	101	29E
0005433805577	9340	102	29G
0005433805604	9340	103	30B
0005433785167	9340	104	30G
0005433785170	9340	105	30H
0005433785153	9340	106	31B
0005434151683	9340	107	31A
0005433805611	9340	108	31F
0005433805608	9340	109	31E
0005433805610	9340	110	31H
0005434151707	9340	111	31G
0005433805576	9340	112	32B
0005435269699	9340	113	32D
0005434171025	9340	114	32F
0005432657467	9340	115	32E
0005432665287	9340	116	32H
0005433785164	9340	117	32G
0005433785166	9340	118	33A
0005433763287	9340	119	33E
0005433763296	9340	120	33F
0005435269711	9340	121	33H
0005434270203	9340	122	34A
0005432666400	9340	123	34B
0005433805603	9340	124	34F
0005435269734	9340	125	34G
0005433785165	9340	126	35A
0005434171093	9340	127	34H
0005433785173	9340	128	35B
0005433785182	9340	129	35E
0005433805596	9340	130	35F
0005435269730	9340	131	35G
0005432666401	9340	132	35H
0005433805574	9340	133	36B
0005433805579	9340	134	36A
0005433805581	9340	135	36G
0005434270195	9340	136	37D
0005433805575	9340	137	37F
0005433763289	9340	138	38A
0005433805578	9340	139	38D
0005432657468	9340	140	38F
0005433805602	9340	141	38E
0005434171022	9340	142	38H
0005433785161	9340	143	38G
0005435269725	9340	144	39E
0005435269692	9340	145	39D
0005433763169	26220	1	1B
0005433784961	26220	2	1F
0005433805274	26220	3	1C
0005433785034	26220	4	2A
0005433763212	26220	5	2B
0005433784858	26220	6	2H
0005434269115	26220	7	3B
0005433805360	26220	8	3F
0005433784842	26220	9	3H
0005433784841	26220	10	3G
0005433763117	26220	11	4F
0005435269777	26220	12	4C
0005432663016	26220	13	4G
0005433784864	26220	14	4H
0005433785042	26220	15	5C
0005434171136	26220	16	5G
0005433763140	26220	17	9B
0005433784800	26220	18	9G
0005434171142	26220	19	9H
0005433805270	26220	20	11D
0005435269783	26220	21	11B
0005434171144	26220	22	11F
0005433805264	26220	23	11G
0005433784934	26220	24	12A
0005433763137	26220	25	12B
0005433805310	26220	26	12G
0005433805346	26220	27	13A
0005434171145	26220	28	13G
0005433805361	26220	29	13F
0005433805293	26220	30	14A
0005433805235	26220	31	14B
0005434151721	26220	32	14F
0005433784940	26220	33	14E
0005433784840	26220	34	14H
0005434269114	26220	35	15A
0005433805217	26220	36	15D
0005433763195	26220	37	15G
0005433763159	26220	38	15F
0005433763180	26220	39	15H
0005433763116	26220	40	16B
0005434171143	26220	41	16E
0005434271323	26220	42	16D
0005433784812	26220	43	16F
0005433805178	26220	44	17B
0005433805282	26220	45	17E
0005433805398	26220	46	17F
0005433805269	26220	47	18A
0005433805301	26220	48	17H
0005435269782	26220	49	18B
0005435269780	26220	50	18D
0005433784960	26220	51	18F
0005433805344	26220	52	18H
0005435269781	26220	53	19B
0005432659703	26220	54	19E
0005433805304	26220	55	19H
0005433784724	26220	56	19G
0005433805359	26220	57	20A
0005434171148	26220	58	20B
0005433763131	26220	59	20F
0005433763171	26220	60	20H
0005433784839	26220	61	21A
0005434171146	26220	62	21H
0005433784853	26220	63	22B
0005433805161	26220	64	22A
0005433805237	26220	65	22D
0005433805204	26220	66	22E
0005434151722	26220	67	23A
0005433784827	26220	68	23B
0005433805281	26220	69	23G
0005433784921	26220	70	23H
0005433805177	26220	71	24B
0005433784889	26220	72	24D
0005433784922	26220	73	24F
0005433805462	26220	74	24G
0005433805332	26220	75	25D
0005433763194	26220	76	24H
0005433784811	26220	77	27A
0005434171147	26220	78	27F
0005433805182	26220	79	28A
0005433805294	26220	80	28B
0005433784852	26220	81	28E
0005433784939	26220	82	29A
0005433805345	26220	83	29D
0005434171139	26220	84	29B
0005435269784	26220	85	29G
0005434270217	26220	86	29F
0005433784894	26220	87	30D
0005433805338	26220	88	30F
0005433805135	26220	89	30E
0005433805295	26220	90	30G
0005433805148	26220	91	30H
0005433805300	26220	92	31B
0005435269779	26220	93	31D
0005434171141	26220	94	31G
0005433805176	26220	95	32A
0005433805236	26220	96	32B
0005434171138	26220	97	32D
0005433763193	26220	98	32H
0005435269778	26220	99	32G
0005433805305	26220	100	33A
0005434171137	26220	101	33D
0005434271322	26220	102	33B
0005433805331	26220	103	33E
0005433805500	26220	104	33F
0005433763211	26220	105	34F
0005435269785	26220	106	34E
0005432659704	26220	107	35B
0005433784946	26220	108	35E
0005433784878	26220	109	35F
0005434171140	26220	110	36F
0005433784725	26220	111	36H
0005433805327	26220	112	36G
0005434270218	26220	113	37A
0005433763170	26220	114	37D
0005433805499	26220	115	37B
0005433784843	26220	116	37E
0005433805132	26220	117	38B
0005433784728	26220	118	38D
0005432666374	26220	119	39F
0005435929631	4919	1	1D
0005435929633	4919	2	2B
0005435135699	4919	3	5A
0005435135701	4919	4	6C
0005435929649	4919	5	7A
0005435135698	4919	6	7C
0005435135697	4919	7	18B
0005435929632	4919	8	18A
0005435135700	4919	9	22B
0005435929660	33011	1	2A
0005435135670	33011	2	4B
0005435929661	33011	3	4D
0005435929659	33011	4	5A
0005435135674	33011	5	5D
0005435135662	33011	6	18C
0005435135669	33011	7	18D
0005435135673	33011	8	21C
0005434983317	9466	1	6C
0005434983320	9466	2	18C
0005434983318	9466	3	19D
0005434983319	9466	4	20A
0005434983321	9466	5	21B
0005434217995	27361	1	1B
0005434983293	27361	2	1C
0005434217991	27361	3	3A
0005434983270	27361	4	3B
0005434217992	27361	5	5A
0005434983265	27361	6	5C
0005434983290	27361	7	5D
0005434983294	27361	8	18B
0005434983292	27361	9	18C
0005434217994	27361	10	19A
0005434983285	27361	11	19B
0005434983286	27361	12	20B
0005434983261	27361	13	21D
0005434217993	27361	14	22D
0005433960532	24233	1	1F
0005433960730	24233	2	1H
0005433960726	24233	3	1G
0005433960624	24233	4	2A
0005433985855	24233	5	2C
0005433960607	24233	6	2F
0005433960672	24233	7	2G
0005433960524	24233	8	3A
0005433985729	24233	9	3F
0005433960461	24233	10	4B
0005433985809	24233	11	4A
0005433985716	24233	12	5C
0005433960652	24233	13	5F
0005433960544	24233	14	5H
0005433960346	24233	15	11A
0005433985814	24233	16	9H
0005433960414	24233	17	11G
0005433960347	24233	18	11H
0005433985818	24233	19	12A
0005433960634	24233	20	12D
0005433985641	24233	21	12F
0005433960597	24233	22	13B
0005433985819	24233	23	13A
0005433960696	24233	24	13D
0005433985833	24233	25	13H
0005433960704	24233	26	13G
0005433985719	24233	27	14B
0005433960690	24233	28	14D
0005433985858	24233	29	14F
0005433960626	24233	30	14E
0005433985759	24233	31	14H
0005433985635	24233	32	15E
0005433985608	24233	33	15F
0005433960677	24233	34	16B
0005433985723	24233	35	16A
0005433985622	24233	36	16E
0005433960695	24233	37	16G
0005433985628	24233	38	16F
0005433985654	24233	39	16H
0005433960499	24233	40	17B
0005433960526	24233	41	17D
0005433960681	24233	42	17E
0005433985629	24233	43	17G
0005433985695	24233	44	17F
0005433960545	24233	45	18B
0005433960543	24233	46	18A
0005433960727	24233	47	18F
0005433960714	24233	48	18E
0005433960697	24233	49	18G
0005433985810	24233	50	18H
0005433985696	24233	51	19B
0005433985871	24233	52	19E
0005433960553	24233	53	19F
0005433960689	24233	54	19H
0005433985739	24233	55	19G
0005433960354	24233	56	20A
0005433985930	24233	57	20D
0005433960646	24233	58	20G
0005433960648	24233	59	20F
0005433985731	24233	60	20H
0005433985872	24233	61	21A
0005433985928	24233	62	21D
0005433985807	24233	63	21B
0005433960585	24233	64	21E
0005433986040	24233	65	21H
0005433960529	24233	66	22D
0005433985732	24233	67	22F
0005433960547	24233	68	22E
0005433960603	24233	69	22G
0005433960453	24233	70	22H
0005433985707	24233	71	23B
0005433960452	24233	72	23E
0005433960343	24233	73	23G
0005433960390	24233	74	24F
0005433985633	24233	75	24H
0005433985828	24233	76	25E
0005433985730	24233	77	25D
0005433985870	24233	78	27A
0005433960495	24233	79	27B
0005433960525	24233	80	27H
0005433960471	24233	81	27G
0005433960722	24233	82	28A
0005433985694	24233	83	28E
0005433960653	24233	84	28F
0005433960683	24233	85	29F
0005433960669	24233	86	29H
0005433985841	24233	87	30A
0005433960599	24233	88	30B
0005433960713	24233	89	30G
0005433985811	24233	90	30F
0005433960668	24233	91	30H
0005433960533	24233	92	31B
0005433960500	24233	93	31A
0005433960584	24233	94	31F
0005433960415	24233	95	31G
0005433960738	24233	96	32E
0005433985706	24233	97	32D
0005433960633	24233	98	32F
0005433986021	24233	99	32H
0005433960418	24233	100	32G
0005433960701	24233	101	33E
0005433960304	24233	102	34B
0005433985634	24233	103	34H
0005433960692	24233	104	35F
0005433985700	24233	105	36A
0005433985655	24233	106	36F
0005433960586	24233	107	36G
0005433985773	24233	108	37B
0005433960691	24233	109	37D
0005433985701	24233	110	37F
0005433960700	24233	111	37H
0005433960419	24233	112	38D
0005433960546	24233	113	38B
0005433985607	24233	114	38E
0005433960715	24233	115	38G
0005433960723	24233	116	38F
0005433985708	24233	117	39E
0005433960731	24233	118	39D
0005433960649	24233	119	39F
0005433986176	25921	1	1A
0005433961168	25921	2	1G
0005433961188	25921	3	2B
0005433986194	25921	4	2F
0005433961183	25921	5	2C
0005433961186	25921	6	2G
0005433961165	25921	7	3B
0005433986191	25921	8	4B
0005433961177	25921	9	5F
0005433961170	25921	10	5H
0005433986192	25921	11	9G
0005433961197	25921	12	11A
0005433961187	25921	13	11F
0005433961173	25921	14	11E
0005433961206	25921	15	11H
0005433961196	25921	16	12B
0005433961180	25921	17	12G
0005433961178	25921	18	13D
0005433986190	25921	19	13B
0005433986204	25921	20	13G
0005433961207	25921	21	14A
0005433986213	25921	22	14G
0005433986182	25921	23	15F
0005433986210	25921	24	15E
0005433986203	25921	25	15H
0005433961182	25921	26	16A
0005433961204	25921	27	16G
0005433961179	25921	28	16F
0005433961203	25921	29	17A
0005433961166	25921	30	17D
0005433986207	25921	31	17F
0005433961171	25921	32	17E
0005433961199	25921	33	17G
0005433961201	25921	34	18A
0005433986215	25921	35	18F
0005433986187	25921	36	19A
0005433961202	25921	37	18H
0005433986218	25921	38	19B
0005433986186	25921	39	19G
0005433961185	25921	40	19F
0005433986211	25921	41	20A
0005433986189	25921	42	21F
0005433986201	25921	43	21H
0005433986183	25921	44	22B
0005433986193	25921	45	23F
0005433986188	25921	46	23H
0005433961194	25921	47	24B
0005433986195	25921	48	24D
0005433986206	25921	49	24F
0005433986202	25921	50	24H
0005433961172	25921	51	24G
0005433961176	25921	52	25D
0005433986181	25921	53	25F
0005433961209	25921	54	27A
0005433961189	25921	55	27B
0005433961191	25921	56	27D
0005433986177	25921	57	27F
0005433961195	25921	58	27H
0005433986178	25921	59	27G
0005433986184	25921	60	28B
0005433986179	25921	61	28G
0005433986217	25921	62	29H
0005433986198	25921	63	30B
0005433986208	25921	64	30D
0005433986185	25921	65	30E
0005433961200	25921	66	30F
0005433986209	25921	67	30H
0005433961208	25921	68	31A
0005433986205	25921	69	31D
0005433961181	25921	70	32A
0005433961175	25921	71	31H
0005433986196	25921	72	32G
0005433961198	25921	73	33D
0005433961193	25921	74	33F
0005433986197	25921	75	33G
0005433986199	25921	76	33H
0005433986180	25921	77	34E
0005433961167	25921	78	34G
0005433961205	25921	79	35B
0005433986200	25921	80	35G
0005433961210	25921	81	36A
0005433986212	25921	82	36D
0005433961169	25921	83	36F
0005433986214	25921	84	37E
0005433961211	25921	85	37H
0005433961184	25921	86	37G
0005433961192	25921	87	38E
0005433986216	25921	88	38D
0005433961174	25921	89	39D
0005433961190	25921	90	39F
0005434480478	951	1	1A
0005432269512	951	2	1B
0005434480472	951	3	1D
0005433165873	951	4	2A
0005434480493	951	5	2B
0005434480494	951	6	2C
0005434480481	951	7	2D
0005433165888	951	8	3A
0005434480480	951	9	3B
0005434480479	951	10	3C
0005433165919	951	11	3D
0005434480484	951	12	4B
0005433165868	951	13	4C
0005434480470	951	14	4D
0005433165895	951	15	5A
0005433165901	951	16	5B
0005434480477	951	17	5D
0005434480491	951	18	6A
0005433165869	951	19	6B
0005434480474	951	20	6C
0005434480473	951	21	6D
0005433165879	951	22	7B
0005433165860	951	23	7C
0005433165917	951	24	7D
0005434480490	951	25	18A
0005433165927	951	26	18C
0005432269511	951	27	18D
0005434480487	951	28	19B
0005434480488	951	29	19D
0005434480476	951	30	20A
0005434480475	951	31	20B
0005434480486	951	32	20D
0005432269513	951	33	21A
0005434480489	951	34	21B
0005434480471	951	35	21C
0005434480482	951	36	21D
0005433165925	951	37	22A
0005434480485	951	38	22B
0005434480492	951	39	22D
0005434480495	951	40	23A
0005434480483	951	41	23B
0005434480244	16571	1	1A
0005433165987	16571	2	1B
0005434480108	16571	3	1D
0005434480240	16571	4	2A
0005434480310	16571	5	2B
0005434480139	16571	6	2C
0005434480212	16571	7	2D
0005434480295	16571	8	3B
0005433165984	16571	9	3A
0005433165989	16571	10	3C
0005434480213	16571	11	3D
0005434480138	16571	12	4A
0005433165978	16571	13	4D
0005434480305	16571	14	5A
0005433165981	16571	15	5B
0005434480354	16571	16	5C
0005433165980	16571	17	5D
0005433165979	16571	18	6B
0005434480320	16571	19	6C
0005434480306	16571	20	7B
0005434480268	16571	21	7A
0005434480190	16571	22	7C
0005433165982	16571	23	7D
0005434480319	16571	24	18B
0005434480311	16571	25	18C
0005433165988	16571	26	18D
0005433165977	16571	27	19A
0005434480289	16571	28	19B
0005433165985	16571	29	19D
0005434480232	16571	30	20C
0005434480269	16571	31	21A
0005434480241	16571	32	21B
0005433165986	16571	33	21C
0005434480291	16571	34	21D
0005434480170	16571	35	22A
0005433165983	16571	36	22B
0005434480195	16571	37	22C
0005434480264	16571	38	22D
0005434480355	16571	39	23A
0005433872503	3199	1	2D
0005433872505	3199	2	5C
0005433872507	3199	3	18A
0005433872504	3199	4	19C
0005433872508	3199	5	20A
0005433872506	3199	6	23B
0005433872487	32551	1	5A
0005433872478	32551	2	5D
0005433872472	32551	3	7C
0005433872490	32551	4	23B
0005435150103	10337	1	1A
0005433289820	10337	2	1B
0005435150094	10337	3	1C
0005435142650	10337	4	1D
0005435142649	10337	5	2A
0005435142642	10337	6	2B
0005435142648	10337	7	3A
0005435150095	10337	8	3B
0005435386563	10337	9	3D
0005435386546	10337	10	4A
0005435150101	10337	11	4B
0005435150097	10337	12	4C
0005433289817	10337	13	4D
0005435142643	10337	14	5C
0005435150098	10337	15	5D
0005435386554	10337	16	6A
0005435142641	10337	17	6B
0005435150105	10337	18	6D
0005435386547	10337	19	7B
0005435150096	10337	20	7C
0005435142653	10337	21	18A
0005435142647	10337	22	18B
0005433289821	10337	23	18C
0005435142644	10337	24	18D
0005435386562	10337	25	19A
0005435386536	10337	26	19D
0005435150093	10337	27	20A
0005435386549	10337	28	20B
0005435142640	10337	29	20C
0005435142652	10337	30	21A
0005433289849	10337	31	21B
0005435142646	10337	32	21C
0005435150102	10337	33	21D
0005435150100	10337	34	22A
0005435142645	10337	35	22C
0005435142651	10337	36	22D
0005435150099	10337	37	23A
0005435150104	10337	38	23B
0005435142480	21957	1	1A
0005435149964	21957	2	1B
0005435150018	21957	3	1C
0005435149973	21957	4	1D
0005435386610	21957	5	2A
0005435386608	21957	6	2B
0005433289898	21957	7	2C
0005435142488	21957	8	2D
0005435150008	21957	9	3A
0005435149979	21957	10	3C
0005435142589	21957	11	3D
0005433289900	21957	12	4A
0005435386607	21957	13	4B
0005435149943	21957	14	4C
0005435150015	21957	15	4D
0005433289897	21957	16	5A
0005435149920	21957	17	5B
0005433289899	21957	18	5C
0005435142557	21957	19	5D
0005435142536	21957	20	6C
0005435386606	21957	21	6D
0005435386612	21957	22	7A
0005435142552	21957	23	7B
0005435149921	21957	24	7D
0005435386609	21957	25	7C
0005435149972	21957	26	18A
0005433289896	21957	27	18B
0005435142547	21957	28	18C
0005435142567	21957	29	18D
0005435142501	21957	30	19A
0005435142549	21957	31	19B
0005435149974	21957	32	19C
0005433289895	21957	33	19D
0005435142479	21957	34	20A
0005433289901	21957	35	20C
0005435386605	21957	36	20D
0005435142572	21957	37	21A
0005435142573	21957	38	21B
0005435142571	21957	39	21C
0005435142502	21957	40	21D
0005435142553	21957	41	22A
0005435386611	21957	42	22B
0005435142540	21957	43	22C
0005435149965	21957	44	23A
0005435142541	21957	45	23B
0005435529127	11208	1	1C
0005435319582	11208	2	1D
0005435502262	11208	3	1F
0005434573419	11208	4	2A
0005435545744	11208	5	2C
0005434573428	11208	6	2D
0005435502261	11208	7	3C
0005434573421	11208	8	3D
0005435529217	11208	9	3F
0005435529216	11208	10	4C
0005435319580	11208	11	4E
0005435529249	11208	12	4F
0005435529243	11208	13	5A
0005434573423	11208	14	5C
0005435502320	11208	15	5D
0005435545725	11208	16	5E
0005435502355	11208	17	5F
0005435529274	11208	18	6A
0005434573429	11208	19	6C
0005435319581	11208	20	6D
0005434573430	11208	21	6E
0005435502312	11208	22	6F
0005435545743	11208	23	7A
0005434573433	11208	24	7C
0005435502270	11208	25	7D
0005435502273	11208	26	7E
0005435502246	11208	27	7F
0005435529197	11208	28	8C
0005435529136	11208	29	8E
0005435319527	11208	30	9A
0005435545681	11208	31	9C
0005435529177	11208	32	9D
0005435529273	11208	33	9E
0005434573426	11208	34	9F
0005435529262	11208	35	10A
0005435529171	11208	36	10D
0005435502314	11208	37	10F
0005435502247	11208	38	11A
0005435529209	11208	39	11C
0005435502259	11208	40	11E
0005435529194	11208	41	11D
0005435529123	11208	42	11F
0005435529203	11208	43	12C
0005435529124	11208	44	12E
0005435545726	11208	45	12F
0005435502319	11208	46	13A
0005435529176	11208	47	13C
0005435529178	11208	48	13D
0005435529229	11208	49	14A
0005434573431	11208	50	14C
0005434573432	11208	51	14D
0005435319596	11208	52	14E
0005435502354	11208	53	14F
0005435502178	11208	54	15A
0005434573424	11208	55	15C
0005435529228	11208	56	15D
0005434573422	11208	57	15E
0005435545691	11208	58	15F
0005435319573	11208	59	16C
0005435319476	11208	60	16E
0005435545733	11208	61	17C
0005435545709	11208	62	17D
0005435319477	11208	63	17E
0005435529159	11208	64	18A
0005435529196	11208	65	18E
0005434573420	11208	66	18F
0005435502258	11208	67	19A
0005434573425	11208	68	19C
0005435545735	11208	69	19D
0005434573427	11208	70	19F
0005435529183	11208	71	20A
0005435529215	11208	72	20D
0005435529248	11208	73	20E
0005435502274	11208	74	20F
0005435502428	20955	1	1A
0005435508412	20955	2	1D
0005435508415	20955	3	1F
0005435518001	20955	4	2C
0005435502422	20955	5	2D
0005434573340	20955	6	2F
0005434573290	20955	7	3A
0005435518003	20955	8	3C
0005435502429	20955	9	3D
0005435319637	20955	10	3F
0005435518011	20955	11	4A
0005434573298	20955	12	4D
0005435517997	20955	13	4F
0005435518006	20955	14	5A
0005435319641	20955	15	5C
0005435518005	20955	16	5D
0005435502424	20955	17	5E
0005435502431	20955	18	5F
0005435319638	20955	19	6A
0005435319634	20955	20	6C
0005435502425	20955	21	6E
0005435508411	20955	22	6F
0005435502440	20955	23	7A
0005435319640	20955	24	7C
0005434573291	20955	25	7D
0005435518010	20955	26	7E
0005434573299	20955	27	8A
0005435517999	20955	28	7F
0005435502433	20955	29	8C
0005434573341	20955	30	8D
0005435319632	20955	31	8E
0005435508409	20955	32	8F
0005435502439	20955	33	9A
0005435319642	20955	34	9C
0005434573320	20955	35	9D
0005434573321	20955	36	9E
0005435508416	20955	37	10A
0005434573322	20955	38	10D
0005435319633	20955	39	10E
0005435508413	20955	40	10F
0005435518007	20955	41	11A
0005435517998	20955	42	11C
0005434573326	20955	43	11D
0005435502420	20955	44	11E
0005435518012	20955	45	11F
0005432291942	20955	46	12C
0005435502427	20955	47	12A
0005435518008	20955	48	12D
0005434573294	20955	49	12E
0005435518014	20955	50	12F
0005435502430	20955	51	13A
0005435518000	20955	52	13C
0005434573285	20955	53	13E
0005434573360	20955	54	13D
0005435518004	20955	55	13F
0005435502423	20955	56	14A
0005435502435	20955	57	14C
0005434573277	20955	58	14D
0005435319636	20955	59	14E
0005435502432	20955	60	15A
0005435508410	20955	61	15C
0005434573337	20955	62	15D
0005434573212	20955	63	15E
0005435508408	20955	64	15F
0005435508414	20955	65	16A
0005435508407	20955	66	16C
0005435502438	20955	67	16D
0005435502436	20955	68	16E
0005434573328	20955	69	17A
0005435319635	20955	70	17C
0005432291943	20955	71	17D
0005435502437	20955	72	17E
0005435518015	20955	73	18A
0005434573252	20955	74	18C
0005435502421	20955	75	18D
0005435518009	20955	76	18E
0005435518002	20955	77	18F
0005435502426	20955	78	19A
0005434573325	20955	79	19C
0005435319639	20955	80	19D
0005435502434	20955	81	19E
0005434573249	20955	82	19F
0005434573336	20955	83	20A
0005434573311	20955	84	20C
0005435518013	20955	85	20E
0005435508406	20955	86	20F
0005432693088	3068	1	1F
0005432692864	3068	2	2C
0005432692979	3068	3	3A
0005432693065	3068	4	5A
0005432693002	3068	5	5C
0005432692999	3068	6	5E
0005432692978	3068	7	5F
0005432693040	3068	8	6A
0005432693084	3068	9	6E
0005432693041	3068	10	7C
0005432692998	3068	11	8A
0005432693087	3068	12	8C
0005432693001	3068	13	9A
0005432693023	3068	14	9C
0005432692931	3068	15	10A
0005432692953	3068	16	10E
0005432693030	3068	17	10F
0005432692977	3068	18	11A
0005432692896	3068	19	11F
0005432692907	3068	20	12A
0005432692981	3068	21	14A
0005432693010	3068	22	14C
0005432692960	3068	23	14D
0005432693027	3068	24	15C
0005432693060	3068	25	15E
0005432692909	3068	26	16A
0005432692773	3068	27	16C
0005432692904	3068	28	16D
0005432693025	3068	29	17F
0005432692930	3068	30	18C
0005432692908	3068	31	18D
0005432692952	3068	32	18F
0005432693026	3068	33	19D
0005432692970	3068	34	19E
0005432692971	3068	35	19F
0005432693057	3068	36	20A
0005432706913	2888	1	1A
0005432880795	2888	2	1C
0005432706926	2888	3	1D
0005432880833	2888	4	1F
0005432880793	2888	5	2A
0005432880790	2888	6	2C
0005432706929	2888	7	2D
0005432706916	2888	8	2F
0005432706923	2888	9	3A
0005432880803	2888	10	3C
0005433123913	2888	11	3D
0005432706932	2888	12	3F
0005432706922	2888	13	4A
0005432880802	2888	14	4C
0005432706911	2888	15	4D
0005432706928	2888	16	4E
0005433123976	2888	17	4F
0005432880762	2888	18	5A
0005433123861	2888	19	5C
0005432706912	2888	20	5D
0005432706917	2888	21	5E
0005432706934	2888	22	5F
0005432706921	2888	23	6A
0005433123887	2888	24	6C
0005433123836	2888	25	6D
0005432880748	2888	26	6E
0005433123903	2888	27	6F
0005432880747	2888	28	7A
0005432880848	2888	29	7D
0005433123904	2888	30	7F
0005432706918	2888	31	8A
0005432880783	2888	32	8C
0005433123824	2888	33	8D
0005432880838	2888	34	8E
0005433123896	2888	35	8F
0005432880847	2888	36	9A
0005433123879	2888	37	9C
0005433123892	2888	38	9D
0005432706933	2888	39	9F
0005432706930	2888	40	10A
0005432217793	2888	41	10C
0005433123825	2888	42	10D
0005432880777	2888	43	10E
0005433123869	2888	44	11A
0005433123859	2888	45	11C
0005433123898	2888	46	11D
0005432706920	2888	47	11E
0005432880805	2888	48	11F
0005433194828	2888	49	12A
0005432880746	2888	50	12C
0005432706925	2888	51	12D
0005432880701	2888	52	12E
0005433123803	2888	53	12F
0005432880775	2888	54	13A
0005433123893	2888	55	13C
0005432706910	2888	56	13E
0005432880776	2888	57	14A
0005432706915	2888	58	14C
0005433123864	2888	59	14D
0005432880816	2888	60	14E
0005433123880	2888	61	14F
0005433123968	2888	62	15A
0005433123888	2888	63	15D
0005432880836	2888	64	15E
0005433123977	2888	65	15F
0005432706931	2888	66	16A
0005432706927	2888	67	16D
0005433123862	2888	68	17A
0005432706924	2888	69	17C
0005433123882	2888	70	17D
0005433123852	2888	71	18A
0005432706919	2888	72	18C
0005433123857	2888	73	18D
0005432880778	2888	74	18E
0005433123837	2888	75	18F
0005433123860	2888	76	19A
0005432880794	2888	77	19C
0005432880739	2888	78	19E
0005432880702	2888	79	20C
0005432706935	2888	80	20D
0005432706914	2888	81	20E
0005432880763	2888	82	20F
0005433124037	29992	1	1A
0005432693266	29992	2	1C
0005432706777	29992	3	1D
0005432693255	29992	4	1F
0005432880906	29992	5	2A
0005433124049	29992	6	2C
0005432693264	29992	7	2D
0005432693269	29992	8	2F
0005432693280	29992	9	3A
0005432706717	29992	10	3C
0005432706795	29992	11	3D
0005432706826	29992	12	3F
0005432880904	29992	13	4A
0005432706710	29992	14	4C
0005432706797	29992	15	4D
0005433124030	29992	16	4E
0005432880910	29992	17	4F
0005432880900	29992	18	5A
0005432693282	29992	19	5C
0005432880909	29992	20	5D
0005432706597	29992	21	5E
0005432706731	29992	22	5F
0005432706689	29992	23	6A
0005432706778	29992	24	6C
0005432693259	29992	25	6D
0005432880897	29992	26	6E
0005432693276	29992	27	6F
0005432706598	29992	28	7A
0005432880902	29992	29	7C
0005432693283	29992	30	7D
0005433124033	29992	31	7E
0005433124036	29992	32	7F
0005433124048	29992	33	8A
0005433124039	29992	34	8C
0005433124040	29992	35	8D
0005432693279	29992	36	8E
0005432693256	29992	37	8F
0005432706803	29992	38	9A
0005433124043	29992	39	9C
0005432880908	29992	40	9D
0005432693274	29992	41	9E
0005432706691	29992	42	9F
0005432706791	29992	43	10A
0005432693254	29992	44	10C
0005432693284	29992	45	10D
0005433124050	29992	46	10E
0005433124028	29992	47	10F
0005433124027	29992	48	11A
0005432706748	29992	49	11C
0005432706790	29992	50	11D
0005432880907	29992	51	11E
0005433124034	29992	52	11F
0005432693271	29992	53	12A
0005433124032	29992	54	12C
0005432693258	29992	55	12D
0005432706724	29992	56	12E
0005432693257	29992	57	12F
0005433124031	29992	58	13A
0005432693272	29992	59	13C
0005433124042	29992	60	13E
0005433124044	29992	61	13F
0005433124047	29992	62	14A
0005432706821	29992	63	14C
0005432693267	29992	64	14D
0005432693263	29992	65	14E
0005432693275	29992	66	14F
0005433124029	29992	67	15A
0005432880898	29992	68	15C
0005432693253	29992	69	15D
0005432693260	29992	70	15E
0005432693262	29992	71	15F
0005432693278	29992	72	16A
0005432693277	29992	73	16C
0005432693273	29992	74	16D
0005432880899	29992	75	16E
0005432693265	29992	76	16F
0005432693281	29992	77	17A
0005433124038	29992	78	17C
0005433124041	29992	79	17D
0005432880905	29992	80	17E
0005433124045	29992	81	17F
0005432706690	29992	82	18A
0005432706683	29992	83	18C
0005432706577	29992	84	18D
0005432706754	29992	85	18E
0005432706739	29992	86	18F
0005433194861	29992	87	19A
0005432693268	29992	88	19C
0005432880903	29992	89	19D
0005432706704	29992	90	19E
0005432693261	29992	91	19F
0005432693270	29992	92	20A
0005433124035	29992	93	20C
0005432880901	29992	94	20D
0005433124046	29992	95	20E
0005432706768	29992	96	20F
0005434979949	23675	1	1B
0005434979943	23675	2	1C
0005434979958	23675	3	1D
0005434979954	23675	4	2A
0005434979944	23675	5	2B
0005434979929	23675	6	3B
0005434979939	23675	7	3C
0005434979937	23675	8	3D
0005434979931	23675	9	4A
0005434979946	23675	10	4B
0005434979935	23675	11	4C
0005434979957	23675	12	4D
0005434988799	23675	13	5A
0005434979938	23675	14	5B
0005434988796	23675	15	5D
0005434979945	23675	16	6A
0005434988797	23675	17	6B
0005434988795	23675	18	6C
0005434979959	23675	19	6D
0005434988792	23675	20	7B
0005434979948	23675	21	7C
0005434979950	23675	22	7D
0005434979941	23675	23	18A
0005434988793	23675	24	18B
0005434979951	23675	25	18D
0005434988791	23675	26	19A
0005434979936	23675	27	19B
0005434988794	23675	28	19C
0005434979955	23675	29	19D
0005434979933	23675	30	20A
0005434979934	23675	31	20B
0005434979947	23675	32	20C
0005434979932	23675	33	20D
0005434979956	23675	34	21A
0005434979930	23675	35	21B
0005434979953	23675	36	21C
0005434988798	23675	37	21D
0005434979952	23675	38	22B
0005434979942	23675	39	22C
0005434979940	23675	40	23A
0005434979714	27530	1	1A
0005434979752	27530	2	1B
0005434979591	27530	3	1C
0005434979696	27530	4	2B
0005434979592	27530	5	2A
0005434979842	27530	6	2C
0005434979649	27530	7	2D
0005434988653	27530	8	3A
0005434979733	27530	9	3B
0005434979694	27530	10	3C
0005434988668	27530	11	3D
0005434979685	27530	12	4A
0005434979590	27530	13	4B
0005434979677	27530	14	4C
0005434979529	27530	15	4D
0005434988688	27530	16	5B
0005434988690	27530	17	5C
0005434979785	27530	18	5D
0005434979728	27530	19	6A
0005434979668	27530	20	6B
0005434988657	27530	21	6C
0005434979613	27530	22	6D
0005434988680	27530	23	7A
0005434979594	27530	24	7B
0005434979730	27530	25	7C
0005434979672	27530	26	7D
0005434988681	27530	27	18B
0005434979841	27530	28	18C
0005434988682	27530	29	18D
0005434979652	27530	30	19A
0005434979589	27530	31	19B
0005434979695	27530	32	19C
0005434979614	27530	33	19D
0005434979719	27530	34	20A
0005434979734	27530	35	20B
0005434979578	27530	36	20D
0005434979784	27530	37	21B
0005434979686	27530	38	21C
0005434979593	27530	39	21D
0005434979667	27530	40	22A
0005434979751	27530	41	22B
0005434979720	27530	42	22C
0005434979729	27530	43	22D
0005434979708	27530	44	23A
0005434988687	27530	45	23B
0005433113531	10297	1	1A
0005434302481	10297	2	1D
0005434302483	10297	3	5A
0005433111500	10297	4	7B
0005433111501	10297	5	18C
0005434302479	10297	6	18D
0005434302480	10297	7	20D
0005433111496	10297	8	21B
0005434302482	10297	9	21D
0005433111499	10297	10	22A
0005434302441	19627	1	3C
0005434302448	19627	2	3D
0005433113550	19627	3	6A
0005434302456	19627	4	7C
0005434302442	19627	5	18B
0005433113548	19627	6	19B
0005433113549	19627	7	20C
0005434302444	19627	8	21B
0005433113618	19627	9	21D
0005434302457	19627	10	22B
0005435069406	3527	1	1A
0005435069385	3527	2	1C
0005435925273	3527	3	1F
0005435069396	3527	4	2A
0005435925286	3527	5	2C
0005435069382	3527	6	2D
0005435925285	3527	7	2F
0005435069403	3527	8	3C
0005435069387	3527	9	3D
0005435069401	3527	10	3F
0005435925231	3527	11	4E
0005435069421	3527	12	4F
0005435069414	3527	13	5A
0005435069381	3527	14	5C
0005435069399	3527	15	5D
0005435069393	3527	16	5F
0005435069416	3527	17	6A
0005435069377	3527	18	6C
0005435925289	3527	19	6F
0005435069380	3527	20	7A
0005435925281	3527	21	7E
0005435069418	3527	22	8A
0005435069390	3527	23	8C
0005435069378	3527	24	8D
0005435069400	3527	25	8E
0005435069422	3527	26	8F
0005435069420	3527	27	9A
0005435069407	3527	28	9C
0005435069423	3527	29	9D
0005435069392	3527	30	10A
0005435069398	3527	31	10C
0005435069417	3527	32	10E
0005435718987	3527	33	11A
0005435069429	3527	34	11C
0005435069404	3527	35	11F
0005435069419	3527	36	12A
0005435925280	3527	37	12C
0005435069391	3527	38	12D
0005435069425	3527	39	12E
0005435069394	3527	40	13A
0005435069402	3527	41	13D
0005435069415	3527	42	14A
0005435925287	3527	43	14C
0005435069397	3527	44	14D
0005435069405	3527	45	14E
0005435069411	3527	46	15A
0005435069413	3527	47	15E
0005435069428	3527	48	15F
0005435069410	3527	49	16C
0005435069395	3527	50	16D
0005435925234	3527	51	16E
0005435925255	3527	52	16F
0005435069383	3527	53	17A
0005435069386	3527	54	17C
0005435069388	3527	55	17D
0005435925210	3527	56	17E
0005435069379	3527	57	17F
0005435069408	3527	58	18A
0005435069389	3527	59	18E
0005435069424	3527	60	18F
0005435925263	3527	61	19A
0005435925265	3527	62	19C
0005435069412	3527	63	19D
0005435069409	3527	64	19E
0005435069427	3527	65	19F
0005435069426	3527	66	20A
0005435925290	3527	67	20C
0005435925251	3527	68	20D
0005435925264	3527	69	20E
0005435069384	3527	70	20F
0005435939894	15279	1	1A
0005435068776	15279	2	1C
0005435068812	15279	3	1D
0005435068796	15279	4	2A
0005435068652	15279	5	1F
0005435068869	15279	6	2D
0005435068862	15279	7	2F
0005435068956	15279	8	3A
0005435069152	15279	9	3C
0005435068962	15279	10	3D
0005435069054	15279	11	3F
0005435925365	15279	12	4D
0005435925385	15279	13	4E
0005435069008	15279	14	4F
0005435069026	15279	15	5C
0005435068783	15279	16	5D
0005435069070	15279	17	5E
0005435069037	15279	18	5F
0005435068863	15279	19	6A
0005435068928	15279	20	6E
0005435068845	15279	21	6F
0005435939891	15279	22	7A
0005435068983	15279	23	7C
0005435068766	15279	24	7E
0005435925369	15279	25	7F
0005435068875	15279	26	8A
0005435068767	15279	27	8D
0005435925367	15279	28	8E
0005435925373	15279	29	8F
0005435069009	15279	30	9C
0005435069097	15279	31	9D
0005435068883	15279	32	9E
0005435068984	15279	33	9F
0005435925371	15279	34	10A
0005435068904	15279	35	10E
0005435069035	15279	36	10F
0005435069096	15279	37	11A
0005435068636	15279	38	11C
0005435069071	15279	39	11D
0005435068946	15279	40	11E
0005435925372	15279	41	11F
0005435069038	15279	42	12C
0005435925370	15279	43	12D
0005435925386	15279	44	12E
0005435068871	15279	45	12F
0005435925380	15279	46	13C
0005435939892	15279	47	13D
0005435068775	15279	48	13F
0005435068818	15279	49	14D
0005435925378	15279	50	14E
0005435068892	15279	51	14F
0005435068981	15279	52	15A
0005435925374	15279	53	15C
0005435068844	15279	54	15D
0005435068824	15279	55	15E
0005435068877	15279	56	15F
0005435068825	15279	57	16A
0005435925377	15279	58	16C
0005435068961	15279	59	16D
0005435925366	15279	60	16E
0005435068990	15279	61	16F
0005435939893	15279	62	17A
0005435925381	15279	63	17C
0005435068912	15279	64	17D
0005435068797	15279	65	17E
0005435925382	15279	66	17F
0005435068905	15279	67	18A
0005435068977	15279	68	18C
0005435069012	15279	69	18D
0005435068635	15279	70	18F
0005435068837	15279	71	19A
0005435925375	15279	72	19C
0005435925368	15279	73	19D
0005435068876	15279	74	19E
0005435925376	15279	75	19F
0005435925383	15279	76	20A
0005435925379	15279	77	20C
0005435925384	15279	78	20D
0005435068890	15279	79	20F
0005432658604	18140	1	1A
0005432658603	18140	2	1B
0005432660830	18140	3	3A
0005432658605	18140	4	3B
0005432660829	18140	5	4A
0005432659719	18140	6	4B
0005432658602	18140	7	5A
0005432660809	26368	1	2B
0005432667454	26368	2	3A
0005432664122	26368	3	3B
0005432660810	26368	4	4B
0005432667444	26368	5	6A
0005432667455	26368	6	5B
0005432919781	52	1	1D
0005433102000	52	2	1F
0005432901590	52	3	2D
0005433101880	52	4	2C
0005432919785	52	5	2F
0005433102066	52	6	3A
0005433101990	52	7	3C
0005432919855	52	8	3D
0005433102057	52	9	4A
0005432901591	52	10	4C
0005432919831	52	11	4F
0005432919864	52	12	5D
0005433101848	52	13	5F
0005432919816	52	14	6A
0005432919761	52	15	6F
0005433101917	52	16	7A
0005432919784	52	17	7C
0005433101994	52	18	7D
0005433101942	52	19	8A
0005433102029	52	20	8E
0005432157504	52	21	8D
0005433101849	52	22	8F
0005432919863	52	23	9F
0005432901596	52	24	9E
0005432901542	52	25	10A
0005433101947	52	26	10C
0005433102004	52	27	10B
0005433102035	52	28	10D
0005433102058	52	29	10E
0005433101966	52	30	10F
0005433102060	52	31	11A
0005432901630	52	32	11C
0005432919856	52	33	11E
0005433101912	52	34	11F
0005433102010	52	35	12B
0005432919817	52	36	12D
0005433101901	52	37	13A
0005433102097	52	38	13C
0005432157503	52	39	13D
0005433102018	52	40	14A
0005433102056	52	41	14F
0005433102090	52	42	14E
0005433101960	52	43	15B
0005433101985	52	44	15F
0005433102023	52	45	16A
0005432919844	52	46	16C
0005432901589	52	47	16F
0005433102013	52	48	17D
0005432919879	52	49	17E
0005432919880	52	50	18A
0005433101924	52	51	18B
0005433101861	52	52	18D
0005432919832	52	53	18E
0005432901580	52	54	19B
0005433102028	52	55	18F
0005433102079	52	56	19C
0005432901579	52	57	19E
0005432901620	52	58	20B
0005432901588	52	59	20F
0005433102003	52	60	20E
0005433102052	52	61	21B
0005432919862	52	62	21A
0005433101933	52	63	21C
0005433101786	52	64	21D
0005432919833	52	65	22A
0005433102089	52	66	22B
0005433101787	52	67	22C
0005433101890	52	68	23B
0005432901518	52	69	23C
0005432919801	52	70	23D
0005433101847	52	71	23F
0005433101991	52	72	23E
0005432919783	52	73	24A
0005433101965	52	74	24B
0005432919782	52	75	24D
0005432919762	52	76	25C
0005433101785	52	77	25D
0005433101788	52	78	26A
0005432901619	52	79	25F
0005432901587	52	80	26B
0005433102046	52	81	26D
0005433102059	52	82	26F
0005433101910	52	83	27A
0005432919818	52	84	27C
0005433102009	52	85	27D
0005433101871	52	86	28A
0005433101961	52	87	29A
0005433101941	52	88	29C
0005433101891	52	89	29D
0005433101948	52	90	29E
0005432901550	52	91	30A
0005433102014	52	92	30E
0005432677577	52	93	30D
0005433102124	52	94	31A
0005433101860	52	95	30F
0005433102047	52	96	31C
0005433101909	52	97	31F
0005433102048	52	98	31E
0005432262169	53	1	1C
0005432817661	53	2	1F
0005432817667	53	3	2A
0005432262203	53	4	2C
0005432262168	53	5	2F
0005432262207	53	6	3C
0005432817638	53	7	4A
0005432262178	53	8	4C
0005432817636	53	9	4F
0005432289006	53	10	4D
0005432817654	53	11	5A
0005432817648	53	12	5C
0005432262204	53	13	5F
0005432262179	53	14	5D
0005432817637	53	15	6C
0005432262172	53	16	6A
0005432262185	53	17	6D
0005432753298	53	18	7A
0005432817665	53	19	6F
0005432262175	53	20	7C
0005432262181	53	21	8D
0005432753279	53	22	8E
0005432817646	53	23	9B
0005432262195	53	24	9F
0005432262201	53	25	10B
0005432262182	53	26	11D
0005432817642	53	27	11E
0005432817655	53	28	11F
0005432262187	53	29	13A
0005432817649	53	30	12F
0005432262194	53	31	13B
0005432262173	53	32	13C
0005432817639	53	33	13F
0005432817647	53	34	13E
0005432817666	53	35	14A
0005432289008	53	36	14B
0005432817641	53	37	14E
0005432756834	53	38	14D
0005432817653	53	39	14F
0005432262183	53	40	15A
0005432262190	53	41	15B
0005432817645	53	42	16C
0005432262209	53	43	16E
0005432817652	53	44	17A
0005432817663	53	45	16F
0005432262192	53	46	17B
0005432817644	53	47	17D
0005432262171	53	48	17F
0005432262198	53	49	18A
0005432817660	53	50	18B
0005432262205	53	51	18D
0005432817640	53	52	18E
0005432262202	53	53	18F
0005432817657	53	54	19C
0005432262200	53	55	19D
0005432262180	53	56	19E
0005432262193	53	57	20B
0005432262191	53	58	21E
0005432262165	53	59	21F
0005432262164	53	60	23B
0005432262176	53	61	23A
0005432207676	53	62	23D
0005432817664	53	63	23C
0005432262188	53	64	24A
0005432262177	53	65	24B
0005432262174	53	66	24D
0005432817650	53	67	24C
0005432817659	53	68	25A
0005432262184	53	69	25F
0005432262163	53	70	25E
0005432262199	53	71	26C
0005432817651	53	72	26B
0005432262206	53	73	26A
0005432262166	53	74	26F
0005432262196	53	75	27A
0005432207674	53	76	27B
0005432817656	53	77	27F
0005432817658	53	78	28E
0005432817668	53	79	28D
0005432207675	53	80	28F
0005432289005	53	81	29A
0005432262197	53	82	29B
0005432262208	53	83	29D
0005432262167	53	84	29E
0005432262170	53	85	29F
0005432262189	53	86	30B
0005432817643	53	87	30D
0005432262186	53	88	31A
0005432289007	53	89	31D
0005432817662	53	90	31F
0005432020417	7998	1	1C
0005432919995	7998	2	1A
0005433102460	7998	3	2A
0005432919991	7998	4	1F
0005433102444	7998	5	2C
0005432020422	7998	6	2F
0005432045625	7998	7	2D
0005432020423	7998	8	3C
0005433102468	7998	9	3D
0005433102469	7998	10	4A
0005432919986	7998	11	3F
0005432392020	7998	12	5A
0005432020434	7998	13	5D
0005433102473	7998	14	6A
0005433102453	7998	15	6D
0005432751546	7998	16	6C
0005432020430	7998	17	7C
0005432392019	7998	18	8A
0005432020426	7998	19	8B
0005432020433	7998	20	8C
0005433102457	7998	21	8E
0005432020431	7998	22	8F
0005433102467	7998	23	9A
0005433102450	7998	24	9C
0005432919978	7998	25	9E
0005432020412	7998	26	9D
0005432919989	7998	27	9F
0005432919975	7998	28	10B
0005432020418	7998	29	10F
0005433102471	7998	30	11B
0005432020415	7998	31	11F
0005433102443	7998	32	12E
0005433102461	7998	33	12D
0005432919990	7998	34	12F
0005432919981	7998	35	13B
0005433102466	7998	36	13C
0005433102458	7998	37	14E
0005432919983	7998	38	14D
0005432677597	7998	39	15B
0005432751548	7998	40	15A
0005433102472	7998	41	15C
0005432677600	7998	42	15E
0005432392018	7998	43	16A
0005432919980	7998	44	15F
0005433102475	7998	45	16C
0005433102446	7998	46	16B
0005432020421	7998	47	17A
0005433102452	7998	48	17B
0005432751547	7998	49	17D
0005432020425	7998	50	17E
0005432020432	7998	51	18B
0005433102465	7998	52	18D
0005432919993	7998	53	18E
0005432919992	7998	54	18F
0005432020414	7998	55	19C
0005432919979	7998	56	19D
0005432919982	7998	57	19E
0005433102462	7998	58	20B
0005433102455	7998	59	20A
0005433102474	7998	60	20C
0005432020429	7998	61	20D
0005432020424	7998	62	20F
0005432753323	7998	63	21A
0005433102464	7998	64	21B
0005432753322	7998	65	21D
0005432919976	7998	66	22A
0005432044541	7998	67	21F
0005432020427	7998	68	22B
0005432020435	7998	69	22C
0005432044540	7998	70	22E
0005432919984	7998	71	22D
0005433102463	7998	72	23C
0005432677601	7998	73	23E
0005433102442	7998	74	24A
0005432020420	7998	75	24B
0005432020437	7998	76	24C
0005432020436	7998	77	24D
0005432919988	7998	78	24F
0005432020413	7998	79	25A
0005432045626	7998	80	25C
0005433102451	7998	81	25B
0005432919977	7998	82	25D
0005432677598	7998	83	25E
0005432677599	7998	84	26B
0005432753321	7998	85	26C
0005433102447	7998	86	26E
0005433102448	7998	87	26D
0005432020411	7998	88	27A
0005433102477	7998	89	26F
0005432044542	7998	90	27F
0005433102476	7998	91	27E
0005432020419	7998	92	28A
0005433102470	7998	93	28B
0005433102445	7998	94	28F
0005433102449	7998	95	29A
0005432919987	7998	96	29C
0005432020428	7998	97	29F
0005432045627	7998	98	29E
0005433102454	7998	99	30A
0005432020416	7998	100	30D
0005432020410	7998	101	30C
0005432919994	7998	102	30F
0005432919974	7998	103	31A
0005432919985	7998	104	31D
0005433102456	7998	105	31C
0005433102459	7998	106	31F
0005432817387	7993	1	1D
0005432901715	7993	2	2C
0005432817337	7993	3	4A
0005432817386	7993	4	4C
0005432817477	7993	5	5A
0005432817334	7993	6	5D
0005432817476	7993	7	6A
0005432901717	7993	8	6C
0005432817303	7993	9	7A
0005432901710	7993	10	6F
0005432817426	7993	11	7C
0005432901709	7993	12	7F
0005432817372	7993	13	8B
0005432901723	7993	14	8C
0005432002089	7993	15	9C
0005432817499	7993	16	9D
0005432817302	7993	17	10A
0005432817378	7993	18	9F
0005432817379	7993	19	10C
0005432817371	7993	20	11B
0005432817254	7993	21	12A
0005432817498	7993	22	12E
0005432817335	7993	23	13A
0005432817428	7993	24	13E
0005432002088	7993	25	14A
0005432817480	7993	26	14C
0005432901711	7993	27	14B
0005432817239	7993	28	14F
0005432817451	7993	29	15D
0005432817400	7993	30	15E
0005432817365	7993	31	16A
0005432817368	7993	32	16F
0005432817270	7993	33	17E
0005432901707	7993	34	18A
0005432817288	7993	35	18D
0005432901712	7993	36	18F
0005432817222	7993	37	20D
0005432817327	7993	38	20F
0005432817457	7993	39	20E
0005432901716	7993	40	21C
0005432817409	7993	41	21F
0005432817407	7993	42	21E
0005432901719	7993	43	22A
0005432901713	7993	44	22E
0005432901721	7993	45	23A
0005432901714	7993	46	23D
0005432817223	7993	47	25C
0005432901718	7993	48	26B
0005432901708	7993	49	28A
0005432817336	7993	50	29B
0005432901720	7993	51	29F
0005432901724	7993	52	30A
0005432901722	7993	53	30D
0005434175732	9677	1	1B
0005433870745	9677	2	2A
0005433870743	9677	3	2B
0005434175735	9677	4	3B
0005434175743	9677	5	4B
0005434175736	9677	6	5A
0005434175742	9677	7	5B
0005434175734	9677	8	6A
0005433870744	9677	9	6B
0005434175779	32360	1	1A
0005434175780	32360	2	4A
0005434175778	32360	3	4B
0005434175777	32360	4	6B
0005435626301	3517	1	1C
0005434878777	3517	2	1A
0005432799632	3517	3	1G
0005434426794	3517	4	1D
0005434878826	3517	5	1K
0005434878772	3517	6	1H
0005434878848	3517	7	2D
0005434426799	3517	8	2A
0005434426802	3517	9	2G
0005434878812	3517	10	3A
0005432188628	3517	11	2K
0005434878846	3517	12	3G
0005432799633	3517	13	3D
0005434938256	3517	14	3C
0005434878814	3517	15	3H
0005435126614	3517	16	4C
0005434426805	3517	17	4A
0005432799641	3517	18	3K
0005435626289	3517	19	4G
0005434878831	3517	20	4D
0005435126610	3517	21	4H
0005434878769	3517	22	5C
0005435902721	3517	23	5H
0005434878850	3517	24	11A
0005434426778	3517	25	11E
0005435902607	3517	26	11D
0005435626303	3517	27	11G
0005434938258	3517	28	11K
0005432799625	3517	29	12A
0005435913904	3517	30	12E
0005435902555	3517	31	12D
0005434878860	3517	32	12G
0005434426795	3517	33	12K
0005434938272	3517	34	12H
0005435902666	3517	35	13D
0005435902661	3517	36	13F
0005434878803	3517	37	13E
0005434938267	3517	38	13H
0005432799628	3517	39	13G
0005432611737	3517	40	14A
0005434938264	3517	41	13K
0005434878822	3517	42	14C
0005434878773	3517	43	14F
0005435902569	3517	44	14K
0005434878855	3517	45	14H
0005434938255	3517	46	15E
0005432799623	3517	47	15D
0005432799630	3517	48	15F
0005434426791	3517	49	16A
0005435626292	3517	50	15K
0005434878824	3517	51	15H
0005434938254	3517	52	16D
0005434878797	3517	53	16F
0005432613886	3517	54	16E
0005435126627	3517	55	16H
0005435913903	3517	56	16G
0005434426800	3517	57	17A
0005432799624	3517	58	16K
0005432799636	3517	59	17E
0005432799621	3517	60	17G
0005434878856	3517	61	17K
0005432799619	3517	62	17H
0005435902747	3517	63	18C
0005435126621	3517	64	18B
0005432799627	3517	65	18A
0005434878853	3517	66	18E
0005434878805	3517	67	18G
0005435126642	3517	68	18F
0005435126632	3517	69	18K
0005435126629	3517	70	19B
0005435126634	3517	71	19A
0005432799644	3517	72	19C
0005435126643	3517	73	19E
0005434878786	3517	74	19D
0005434878815	3517	75	19H
0005434426781	3517	76	20A
0005434878804	3517	77	19K
0005435626299	3517	78	20C
0005432183480	3517	79	20B
0005434426790	3517	80	20E
0005435902728	3517	81	20D
0005435126625	3517	82	20F
0005434426804	3517	83	20H
0005435126608	3517	84	21B
0005434426792	3517	85	21A
0005435626287	3517	86	20K
0005432799642	3517	87	21C
0005434878778	3517	88	21J
0005434426807	3517	89	21H
0005434878823	3517	90	21G
0005435126641	3517	91	22A
0005435902554	3517	92	21K
0005434426801	3517	93	22C
0005435913909	3517	94	22B
0005434878791	3517	95	22E
0005434878825	3517	96	22H
0005435626294	3517	97	22G
0005434878774	3517	98	22K
0005434426786	3517	99	22J
0005434878851	3517	100	23B
0005435902617	3517	101	23A
0005435126609	3517	102	23E
0005432799645	3517	103	23D
0005432183479	3517	104	23C
0005434878839	3517	105	23G
0005434878845	3517	106	23F
0005435126618	3517	107	24D
0005434938260	3517	108	23K
0005435126633	3517	109	24F
0005435126624	3517	110	24E
0005432799640	3517	111	25B
0005432799646	3517	112	25A
0005434878806	3517	113	25C
0005434426787	3517	114	25F
0005434878858	3517	115	25E
0005434878792	3517	116	25D
0005434878775	3517	117	25H
0005434878852	3517	118	25G
0005434878829	3517	119	25K
0005434878784	3517	120	25J
0005435126605	3517	121	26C
0005434878783	3517	122	26E
0005434878811	3517	123	26D
0005434878820	3517	124	26F
0005435126613	3517	125	26K
0005434878802	3517	126	26J
0005434426784	3517	127	26H
0005434878782	3517	128	27A
0005435626291	3517	129	27D
0005434878843	3517	130	27C
0005435626302	3517	131	27F
0005434878813	3517	132	27G
0005432799622	3517	133	28A
0005432799626	3517	134	27J
0005434878821	3517	135	28B
0005435626288	3517	136	28E
0005435913914	3517	137	28D
0005432799635	3517	138	28C
0005434426785	3517	139	28G
0005435902571	3517	140	28F
0005434878834	3517	141	28J
0005434878800	3517	142	29B
0005434878809	3517	143	29A
0005434878780	3517	144	29D
0005435126607	3517	145	29F
0005435626304	3517	146	29J
0005434426783	3517	147	29H
0005435126640	3517	148	29G
0005434878835	3517	149	29K
0005435126606	3517	150	30C
0005435126630	3517	151	30B
0005434878841	3517	152	30E
0005434938257	3517	153	30D
0005434878785	3517	154	30F
0005435913915	3517	155	30J
0005434878818	3517	156	31A
0005434938262	3517	157	31D
0005432188626	3517	158	31C
0005435626290	3517	159	31B
0005434426779	3517	160	31F
0005434878798	3517	161	32B
0005432188629	3517	162	32A
0005435126644	3517	163	32E
0005434426797	3517	164	32J
0005434938261	3517	165	32H
0005435126635	3517	166	33A
0005434426789	3517	167	33D
0005434938266	3517	168	33B
0005435626298	3517	169	33E
0005432799629	3517	170	33G
0005434878788	3517	171	33K
0005435126637	3517	172	34C
0005432183481	3517	173	34A
0005434426796	3517	174	34D
0005435902746	3517	175	34H
0005434878795	3517	176	34G
0005434878830	3517	177	34J
0005435126615	3517	178	35A
0005432611734	3517	179	35C
0005434878832	3517	180	35F
0005434938268	3517	181	35E
0005435126626	3517	182	35G
0005435126611	3517	183	35J
0005434878799	3517	184	36D
0005435902729	3517	185	36B
0005434426798	3517	186	36E
0005434938263	3517	187	36H
0005434878827	3517	188	36F
0005434878819	3517	189	36K
0005434878787	3517	190	36J
0005432799637	3517	191	37A
0005435902570	3517	192	37D
0005435626293	3517	193	37C
0005435626300	3517	194	37G
0005434938270	3517	195	37F
0005434878817	3517	196	37E
0005434938265	3517	197	37H
0005434878779	3517	198	37K
0005434878833	3517	199	37J
0005432799620	3517	200	38K
0005434878838	3517	201	38J
0005434878861	3517	202	39A
0005434878801	3517	203	39C
0005434426788	3517	204	39G
0005434878767	3517	205	39F
0005434878849	3517	206	39E
0005434878781	3517	207	39J
0005432799638	3517	208	40A
0005434878796	3517	209	39K
0005432799643	3517	210	40C
0005434426782	3517	211	40B
0005434878828	3517	212	40E
0005434938271	3517	213	40J
0005435126612	3517	214	41B
0005434878770	3517	215	41A
0005432613888	3517	216	41C
0005435126617	3517	217	41F
0005432799618	3517	218	41G
0005434878810	3517	219	41K
0005434878859	3517	220	41J
0005435626305	3517	221	42C
0005434426803	3517	222	42B
0005435913916	3517	223	42F
0005435626297	3517	224	42E
0005434878793	3517	225	42J
0005435126628	3517	226	43B
0005435902625	3517	227	42K
0005434878857	3517	228	43D
0005435902624	3517	229	43C
0005434878842	3517	230	43F
0005435902665	3517	231	43E
0005435126638	3517	232	43H
0005435126616	3517	233	43G
0005435126620	3517	234	43K
0005435126639	3517	235	43J
0005432611736	3517	236	44E
0005435902556	3517	237	44D
0005434878776	3517	238	44C
0005432611735	3517	239	44G
0005432799634	3517	240	44H
0005432613887	3517	241	45A
0005434878807	3517	242	44K
0005434878854	3517	243	45D
0005435626296	3517	244	45H
0005432613889	3517	245	45G
0005434426808	3517	246	45K
0005434938259	3517	247	45J
0005435126645	3517	248	46C
0005434878789	3517	249	46B
0005435126619	3517	250	46E
0005434938253	3517	251	46D
0005432613885	3517	252	46G
0005435126636	3517	253	46F
0005434426806	3517	254	46J
0005434878840	3517	255	46H
0005434878808	3517	256	47C
0005432799631	3517	257	47A
0005434878844	3517	258	46K
0005434878768	3517	259	47E
0005434878837	3517	260	47D
0005434938269	3517	261	47F
0005434878816	3517	262	47H
0005434878771	3517	263	48C
0005435126623	3517	264	48A
0005435841098	3517	265	48F
0005435626295	3517	266	48D
0005435126622	3517	267	49D
0005434878847	3517	268	49C
0005434426780	3517	269	49F
0005432188627	3517	270	49E
0005432799639	3517	271	49G
0005434426793	3517	272	50C
0005434878836	3517	273	50D
0005435126631	3517	274	50G
0005435902618	3517	275	50F
0005434878790	3517	276	51D
0005434878794	3517	277	51E
0005434938141	14590	1	1A
0005434878099	14590	2	1D
0005434878256	14590	3	2A
0005435126378	14590	4	1H
0005435126287	14590	5	2C
0005432799471	14590	6	2G
0005434878193	14590	7	2D
0005435902820	14590	8	3A
0005435126328	14590	9	2K
0005434878095	14590	10	2H
0005435902809	14590	11	3D
0005435902812	14590	12	3G
0005432607547	14590	13	4C
0005435126203	14590	14	4A
0005432799282	14590	15	3K
0005435126248	14590	16	4D
0005434877813	14590	17	4K
0005432799377	14590	18	4H
0005435126263	14590	19	5D
0005434426616	14590	20	5C
0005434938092	14590	21	5A
0005434426482	14590	22	5H
0005434878098	14590	23	5G
0005434877591	14590	24	11A
0005432799529	14590	25	5K
0005434938120	14590	26	11D
0005434878299	14590	27	11C
0005435126163	14590	28	11F
0005435902804	14590	29	11E
0005434938081	14590	30	11H
0005435126211	14590	31	11G
0005432059516	14590	32	12E
0005432799354	14590	33	12D
0005432799394	14590	34	12H
0005435902806	14590	35	12G
0005434938133	14590	36	12K
0005432611713	14590	37	13D
0005434426583	14590	38	13C
0005434938107	14590	39	13F
0005435902810	14590	40	13E
0005434877970	14590	41	13K
0005432799440	14590	42	13H
0005434426488	14590	43	13G
0005435902819	14590	44	14E
0005434877181	14590	45	14C
0005435126304	14590	46	14F
0005434426567	14590	47	14K
0005435126296	14590	48	14H
0005434877795	14590	49	15C
0005432799395	14590	50	15E
0005435126338	14590	51	15D
0005434878300	14590	52	15H
0005434878046	14590	53	15G
0005435626096	14590	54	15F
0005435126086	14590	55	16A
0005435126308	14590	56	15K
0005435126087	14590	57	16D
0005435126170	14590	58	16G
0005435126273	14590	59	16F
0005434878016	14590	60	16E
0005432799435	14590	61	16H
0005434938053	14590	62	17A
0005435126130	14590	63	16K
0005432799521	14590	64	17D
0005434877887	14590	65	17C
0005434426516	14590	66	17G
0005435626108	14590	67	17F
0005434878093	14590	68	17H
0005434878036	14590	69	18C
0005434938198	14590	70	18B
0005432607537	14590	71	18A
0005434877998	14590	72	18E
0005434426656	14590	73	18D
0005432799378	14590	74	18G
0005434878129	14590	75	18F
0005434878064	14590	76	18K
0005435126121	14590	77	18J
0005434877652	14590	78	19D
0005434877770	14590	79	19F
0005434426428	14590	80	19E
0005435126165	14590	81	19J
0005434877959	14590	82	19H
0005434426638	14590	83	19G
0005432799266	14590	84	20A
0005435126129	14590	85	19K
0005434878038	14590	86	20C
0005434878045	14590	87	20B
0005435126390	14590	88	20E
0005434426519	14590	89	20G
0005434877946	14590	90	20F
0005434426489	14590	91	20J
0005434426526	14590	92	20H
0005435126122	14590	93	21B
0005434938168	14590	94	21A
0005434937996	14590	95	20K
0005432799369	14590	96	21C
0005434877955	14590	97	21F
0005434878106	14590	98	21H
0005434877916	14590	99	22A
0005432799438	14590	100	21K
0005434426538	14590	101	22D
0005434878157	14590	102	22B
0005434878279	14590	103	22F
0005434877925	14590	104	22G
0005434426646	14590	105	22H
0005434938096	14590	106	23B
0005435126023	14590	107	23A
0005432799387	14590	108	22K
0005432799322	14590	109	23C
0005434877180	14590	110	23G
0005434877954	14590	111	23E
0005435126345	14590	112	23J
0005434877644	14590	113	23H
0005432799406	14590	114	23K
0005434426630	14590	115	24E
0005434426642	14590	116	25B
0005434938097	14590	117	25A
0005434878186	14590	118	25C
0005435126377	14590	119	25E
0005434877455	14590	120	25G
0005434877938	14590	121	25K
0005432799340	14590	122	26C
0005435902805	14590	123	26B
0005435626133	14590	124	26E
0005435902815	14590	125	26D
0005435626107	14590	126	26G
0005434426572	14590	127	26F
0005434426499	14590	128	26H
0005435902814	14590	129	26K
0005434877997	14590	130	27D
0005434938091	14590	131	27C
0005434877798	14590	132	27F
0005434878050	14590	133	27E
0005434426500	14590	134	27H
0005435902817	14590	135	28A
0005435902807	14590	136	27K
0005435126186	14590	137	28E
0005434878112	14590	138	28D
0005434877984	14590	139	28C
0005432611683	14590	140	28G
0005434878017	14590	141	28J
0005434877799	14590	142	28H
0005434426551	14590	143	29A
0005435126139	14590	144	28K
0005434878252	14590	145	29D
0005434878037	14590	146	29C
0005435126329	14590	147	29F
0005435126164	14590	148	29E
0005434878260	14590	149	29J
0005434877846	14590	150	29H
0005432607538	14590	151	29G
0005434878094	14590	152	30A
0005434937995	14590	153	29K
0005435902818	14590	154	30B
0005435126261	14590	155	30D
0005435126309	14590	156	30G
0005434938112	14590	157	30K
0005434877671	14590	158	30J
0005432799472	14590	159	31A
0005434426498	14590	160	31D
0005435902816	14590	161	31C
0005434878130	14590	162	31B
0005435126024	14590	163	31F
0005435126218	14590	164	31J
0005432607565	14590	165	31H
0005432799252	14590	166	31G
0005434877939	14590	167	32A
0005434877836	14590	168	31K
0005434878025	14590	169	32C
0005434877835	14590	170	32B
0005434877996	14590	171	32E
0005434426518	14590	172	32G
0005434877924	14590	173	32F
0005434426644	14590	174	32J
0005432799393	14590	175	32H
0005434877779	14590	176	33A
0005434877940	14590	177	33C
0005432799470	14590	178	33B
0005435902813	14590	179	33F
0005434877949	14590	180	33J
0005432799339	14590	181	34A
0005434426481	14590	182	33K
0005434878019	14590	183	34B
0005435902808	14590	184	34E
0005434877958	14590	185	34D
0005434877814	14590	186	34H
0005434426623	14590	187	34F
0005434938117	14590	188	35A
0005432799353	14590	189	34K
0005432799267	14590	190	35C
0005434878136	14590	191	35E
0005434877889	14590	192	35J
0005434938177	14590	193	35G
0005434426643	14590	194	35K
0005434878118	14590	195	36C
0005434877911	14590	196	36D
0005434878091	14590	197	36H
0005434878111	14590	198	36F
0005434426577	14590	199	37B
0005434878183	14590	200	36K
0005434877676	14590	201	37E
0005434426515	14590	202	37D
0005434877934	14590	203	37G
0005432607555	14590	204	37F
0005434877590	14590	205	38A
0005434938034	14590	206	38C
0005432607564	14590	207	38B
0005434877935	14590	208	38J
0005434426438	14590	209	38H
0005434878286	14590	210	39A
0005432799283	14590	211	39D
0005434878285	14590	212	39C
0005434938080	14590	213	39E
0005434878066	14590	214	39H
0005432799379	14590	215	40C
0005434877888	14590	216	40F
0005435126279	14590	217	40E
0005434878204	14590	218	40D
0005434878052	14590	219	40H
0005434877926	14590	220	40G
0005434877930	14590	221	40J
0005434938095	14590	222	41B
0005434938140	14590	223	40K
0005434877840	14590	224	41E
0005435626137	14590	225	41C
0005434877654	14590	226	41G
0005434877891	14590	227	41F
0005434878065	14590	228	41J
0005434878137	14590	229	41H
0005434878047	14590	230	42A
0005434878069	14590	231	41K
0005434877812	14590	232	42C
0005432799409	14590	233	42B
0005434878101	14590	234	42E
0005435125936	14590	235	42D
0005435126323	14590	236	42H
0005434877963	14590	237	42G
0005434426524	14590	238	42J
0005434877927	14590	239	42K
0005435902811	14590	240	43C
0005432799373	14590	241	43B
0005435126150	14590	242	43F
0005435126343	14590	243	43E
0005435126439	14590	244	43H
0005434878171	14590	245	43G
0005435126418	14590	246	43K
0005434938139	14590	247	44A
0005434878253	14590	248	44G
0005435626079	14590	249	44F
0005435626045	14590	250	44J
0005434878145	14590	251	44H
0005432607554	14590	252	44K
0005435126402	14590	253	45D
0005435126344	14590	254	45C
0005434878059	14590	255	45B
0005434938113	14590	256	45E
0005432799390	14590	257	45H
0005432799441	14590	258	45G
0005434938118	14590	259	45K
0005434877815	14590	260	45J
0005435126262	14590	261	46C
0005434426490	14590	262	46E
0005434877512	14590	263	46G
0005435126202	14590	264	46F
0005435126179	14590	265	46H
0005434426652	14590	266	46K
0005432607536	14590	267	47D
0005432611706	14590	268	47C
0005435126224	14590	269	47G
0005435126260	14590	270	47F
0005432799410	14590	271	47K
0005434877968	14590	272	47H
0005432799427	14590	273	48A
0005434877771	14590	274	48F
0005434426622	14590	275	48E
0005434426639	14590	276	48H
0005432059517	14590	277	49A
0005434877912	14590	278	48K
0005435126282	14590	279	49C
0005434426525	14590	280	49G
0005434426645	14590	281	49F
0005435626097	14590	282	49E
0005435126403	14590	283	49K
0005434877513	14590	284	50C
0005434877962	14590	285	50A
0005434878053	14590	286	50E
0005435126305	14590	287	50F
0005434426548	14590	288	51D
0005434938054	14590	289	50H
0005434938033	14590	290	51G
0005434426517	14590	291	51F
0005435889851	3642	1	1B
0005435889905	3642	2	1D
0005434325717	3642	3	2A
0005434312331	3642	4	2C
0005434312332	3642	5	3C
0005434325725	3642	6	3D
0005434325724	3642	7	4B
0005434325721	3642	8	5C
0005434325726	3642	9	6A
0005435889860	3642	10	6C
0005435889859	3642	11	7C
0005435889887	3642	12	18C
0005434325720	3642	13	18D
0005435889892	3642	14	19A
0005435889850	3642	15	19D
0005435889883	3642	16	20A
0005435889857	3642	17	20B
0005434325722	3642	18	21B
0005434325723	3642	19	21D
0005434325718	3642	20	22D
0005434325719	3642	21	23B
0005434325606	15606	1	1A
0005434325635	15606	2	1D
0005435889933	15606	3	2D
0005435889932	15606	4	3A
0005435889936	15606	5	3C
0005434325592	15606	6	5A
0005434325630	15606	7	5B
0005434325595	15606	8	5C
0005434325677	15606	9	6A
0005435889931	15606	10	7C
0005434325631	15606	11	18B
0005435889934	15606	12	20C
0005435889935	15606	13	22C
0005433420353	628	1	1B
0005435957790	628	2	2A
0005435957787	628	3	2B
0005435957799	628	4	3B
0005435957791	628	5	3C
0005435957793	628	6	4A
0005435957797	628	7	4B
0005435957794	628	8	4C
0005435957796	628	9	5B
0005435957786	628	10	6C
0005435957789	628	11	6D
0005435957792	628	12	7A
0005433420383	628	13	7D
0005433420372	628	14	18A
0005433420423	628	15	18B
0005435957788	628	16	18C
0005433420406	628	17	19C
0005433420354	628	18	19D
0005433420387	628	19	20C
0005435957795	628	20	20D
0005435957800	628	21	21C
0005433420388	628	22	21D
0005435957798	628	23	22C
0005433420373	628	24	22D
0005433420389	628	25	23B
0005435957642	15202	1	1B
0005435957619	15202	2	2C
0005433420458	15202	3	4C
0005433420455	15202	4	5B
0005433420452	15202	5	5C
0005433420459	15202	6	6A
0005435957643	15202	7	7B
0005435957593	15202	8	18B
0005435957587	15202	9	18C
0005433420451	15202	10	20A
0005433420450	15202	11	20C
0005433420457	15202	12	21A
0005435957666	15202	13	21C
0005433420456	15202	14	21D
0005433420453	15202	15	22C
0005435957620	15202	16	22D
0005433420454	15202	17	23B
0005435629411	8910	1	2B
0005434247136	8910	2	3A
0005434247132	8910	3	4A
0005435629410	8910	4	5A
0005435629403	16081	1	2B
0005434247164	16081	2	4B
0005435629402	16081	3	5A
0005434247163	16081	4	5B
0005434247162	16081	5	6A
0005434096734	11823	1	2B
0005434096730	11823	2	3B
0005434096735	11823	3	4A
0005434096737	11823	4	6D
0005434096731	11823	5	19B
0005434096728	11823	6	20C
0005434096733	11823	7	22A
0005435933437	4437	1	2A
0005435933440	4437	2	2B
0005435163267	4437	3	2C
0005435933455	4437	4	2D
0005435163263	4437	5	4A
0005435933452	4437	6	4C
0005435163262	4437	7	4D
0005435163261	4437	8	5B
0005435933454	4437	9	5C
0005435163257	4437	10	6A
0005435163259	4437	11	7A
0005435163258	4437	12	7C
0005435933453	4437	13	19A
0005435163265	4437	14	19C
0005435933446	4437	15	20B
0005435933439	4437	16	20D
0005435933451	4437	17	21B
0005435933450	4437	18	21D
0005435933447	4437	19	22B
0005435163266	4437	20	22C
0005435163264	4437	21	22D
0005435163260	4437	22	23A
0005435163235	29511	1	1A
0005435163234	29511	2	2A
0005435933473	29511	3	2B
0005435163221	29511	4	2C
0005435163229	29511	5	4A
0005435933475	29511	6	4B
0005435933474	29511	7	6C
0005435163217	29511	8	18B
0005435933476	29511	9	18C
0005435163205	29511	10	18D
0005435933471	29511	11	19C
0005435163206	29511	12	19D
0005435163218	29511	13	20B
0005435933477	29511	14	20C
0005435933472	29511	15	21C
0005435163233	29511	16	21D
0005435163211	29511	17	22A
0005435163230	29511	18	23A
0005433404775	2839	1	1F
0005435797566	2839	2	3C
0005435797561	2839	3	3F
0005435797564	2839	4	4C
0005433404789	2839	5	5C
0005433404771	2839	6	6E
0005435797560	2839	7	6F
0005435797558	2839	8	7E
0005433404788	2839	9	8D
0005435797563	2839	10	10C
0005435797565	2839	11	10E
0005435797562	2839	12	11E
0005435797568	2839	13	12D
0005435797556	2839	14	13F
0005433404799	2839	15	17A
0005435797567	2839	16	17D
0005435797555	2839	17	17E
0005435797559	2839	18	19D
0005435797557	2839	19	20F
0005435797460	29334	1	2A
0005435797509	29334	2	3C
0005433404856	29334	3	4E
0005433404858	29334	4	6E
0005435797415	29334	5	8D
0005435797508	29334	6	9C
0005433404855	29334	7	9F
0005433404853	29334	8	11A
0005433404860	29334	9	12D
0005435797416	29334	10	13A
0005433404859	29334	11	13C
0005435797503	29334	12	14A
0005435797502	29334	13	15C
0005435797427	29334	14	15D
0005435797481	29334	15	15E
0005433404854	29334	16	16C
0005433404857	29334	17	16E
0005435797476	29334	18	17F
0005435797461	29334	19	20C
0005435797475	29334	20	20D
0005435376348	5839	1	2A
0005434948064	5831	1	1A
0005434948070	5831	2	1B
0005434948072	5831	3	2A
0005434948073	5831	4	3A
0005434948068	5831	5	4A
0005434948067	5831	6	3B
0005434948069	5831	7	4B
0005434948066	5831	8	5A
0005434948071	5831	9	5B
0005434948065	5831	10	6A
0005434948022	16334	1	1A
0005434948020	16334	2	1B
0005435376366	16334	3	2A
0005434948026	16334	4	3A
0005435376368	16334	5	2B
0005434948021	16334	6	3B
0005434947995	16334	7	4A
0005434947968	16334	8	4B
0005435376367	16334	9	6A
0005434947969	16334	10	5B
0005433961239	6920	1	1C
0005433961251	6920	2	1D
0005433961223	6920	3	1F
0005433961234	6920	4	2A
0005433961261	6920	5	2D
0005433961259	6920	6	2F
0005433961250	6920	7	3A
0005433961229	6920	8	3C
0005433961258	6920	9	3D
0005433961219	6920	10	4A
0005433961244	6920	11	4D
0005433961238	6920	12	5A
0005433961245	6920	13	6A
0005433961232	6920	14	6C
0005433961257	6920	15	6D
0005433961242	6920	16	6E
0005433961225	6920	17	7A
0005433961235	6920	18	7E
0005433961256	6920	19	8A
0005433961249	6920	20	9D
0005433961248	6920	21	9F
0005433961220	6920	22	10E
0005433961214	6920	23	10F
0005433961236	6920	24	11D
0005433961218	6920	25	12A
0005433961215	6920	26	12D
0005433961240	6920	27	12E
0005433961221	6920	28	12F
0005433961243	6920	29	13A
0005433961237	6920	30	13C
0005433961241	6920	31	13D
0005433961222	6920	32	14C
0005433961253	6920	33	14D
0005433961213	6920	34	14E
0005433961233	6920	35	15A
0005433961230	6920	36	15D
0005433961262	6920	37	15E
0005433961231	6920	38	16A
0005433961252	6920	39	16E
0005433961247	6920	40	16F
0005433961255	6920	41	17C
0005433961216	6920	42	17D
0005433961217	6920	43	18A
0005433961254	6920	44	18C
0005433961228	6920	45	18E
0005433961212	6920	46	18F
0005433961224	6920	47	19C
0005433961260	6920	48	19D
0005433961227	6920	49	20A
0005433961226	6920	50	20C
0005433961246	6920	51	20F
0005433960447	25810	1	1D
0005433960540	25810	2	1F
0005433960445	25810	3	2D
0005433960639	25810	4	2F
0005433960587	25810	5	3A
0005433960491	25810	6	4A
0005433960567	25810	7	4C
0005433960640	25810	8	4D
0005433960446	25810	9	4E
0005433960615	25810	10	5A
0005433960515	25810	11	5D
0005433960657	25810	12	5F
0005433960614	25810	13	6A
0005433960601	25810	14	6C
0005433960577	25810	15	6D
0005433960589	25810	16	6E
0005433960444	25810	17	6F
0005433960501	25810	18	7C
0005433960606	25810	19	7D
0005433960384	25810	20	7E
0005433960578	25810	21	7F
0005433960662	25810	22	8D
0005433960463	25810	23	8E
0005433960338	25810	24	8F
0005433960598	25810	25	9A
0005433960636	25810	26	9C
0005433960613	25810	27	9D
0005433960647	25810	28	10A
0005433960486	25810	29	10C
0005433960496	25810	30	10D
0005433960602	25810	31	11A
0005433960630	25810	32	11C
0005433960497	25810	33	11E
0005433960554	25810	34	11F
0005433960539	25810	35	12C
0005433960616	25810	36	12E
0005433960403	25810	37	13A
0005433960590	25810	38	13C
0005433960608	25810	39	13D
0005433960537	25810	40	13E
0005433960485	25810	41	13F
0005433960627	25810	42	14A
0005433960656	25810	43	14C
0005433960645	25810	44	14D
0005433960654	25810	45	14E
0005433960492	25810	46	15A
0005433960385	25810	47	15C
0005433960266	25810	48	15E
0005433960643	25810	49	15F
0005433960536	25810	50	16D
0005433960573	25810	51	16E
0005433960514	25810	52	16F
0005433960420	25810	53	17A
0005433960484	25810	54	17C
0005433960566	25810	55	17D
0005433960655	25810	56	17E
0005433960637	25810	57	17F
0005433960591	25810	58	18A
0005433960389	25810	59	18E
0005433960498	25810	60	19A
0005433960576	25810	61	19C
0005433960337	25810	62	19D
0005433960617	25810	63	19F
0005433960644	25810	64	20C
0005433960638	25810	65	20D
0005433960412	25810	66	20E
0005433960572	25810	67	20F
0005435082763	24485	1	2A
0005435082739	24485	2	3A
0005435082742	24485	3	4A
0005435082762	24485	4	5A
0005435082751	24485	5	6A
0005435082827	26070	1	1A
0005435082825	26070	2	1B
0005435082823	26070	3	2A
0005435082824	26070	4	3A
0005435082829	26070	5	3B
0005435082831	26070	6	4B
0005435082828	26070	7	5B
0005435082826	26070	8	6A
0005435082830	26070	9	6B
0005435286625	5026	1	1C
0005433534500	5026	2	1F
0005434245169	5026	3	6A
0005434245171	5026	4	7A
0005434245170	5026	5	8B
0005432166923	5026	6	8C
0005435286627	5026	7	9D
0005434245156	5026	8	11E
0005434245165	5026	9	12A
0005433534488	5026	10	12D
0005434245161	5026	11	13D
0005434245152	5026	12	13F
0005434245162	5026	13	13E
0005432166922	5026	14	14D
0005434245166	5026	15	14C
0005434245150	5026	16	15E
0005435286615	5026	17	15F
0005435286617	5026	18	16B
0005435286624	5026	19	16C
0005432166921	5026	20	16F
0005434245147	5026	21	18A
0005434245159	5026	22	20B
0005434245172	5026	23	20A
0005434245154	5026	24	20F
0005434245155	5026	25	21A
0005434245149	5026	26	21E
0005434245168	5026	27	22C
0005434245151	5026	28	24B
0005434245176	5026	29	25B
0005434245167	5026	30	26B
0005433534497	5026	31	26C
0005435286614	5026	32	26F
0005434245153	5026	33	27A
0005434245173	5026	34	27F
0005434245174	5026	35	28B
0005434245160	5026	36	29A
0005434245148	5026	37	28F
0005434245164	5026	38	29C
0005434245158	5026	39	29D
0005435286613	5026	40	29E
0005434245163	5026	41	29F
0005433534492	5026	42	30D
0005434245175	5026	43	31A
0005434245157	5026	44	31C
0005433615139	5027	1	1D
0005433615135	5027	2	1C
0005433785184	5027	3	1A
0005433615113	5027	4	1F
0005433785180	5027	5	2A
0005432667467	5027	6	2D
0005433615132	5027	7	2C
0005432105864	5027	8	2F
0005433615108	5027	9	3A
0005433615129	5027	10	3D
0005432105849	5027	11	3C
0005432105869	5027	12	4A
0005433785174	5027	13	3F
0005432105875	5027	14	4C
0005433785187	5027	15	4F
0005432667466	5027	16	4D
0005433785177	5027	17	5A
0005432105883	5027	18	5D
0005433615122	5027	19	5C
0005433785182	5027	20	5F
0005433785179	5027	21	6A
0005433615131	5027	22	6C
0005432105879	5027	23	6F
0005433615110	5027	24	6D
0005433615172	5027	25	7A
0005432105838	5027	26	7D
0005433615140	5027	27	7C
0005432105874	5027	28	7F
0005433785156	5027	29	8A
0005433615124	5027	30	8B
0005433785161	5027	31	8D
0005432105881	5027	32	8C
0005433615171	5027	33	8E
0005433615152	5027	34	8F
0005433615155	5027	35	9A
0005432105853	5027	36	9C
0005432105873	5027	37	9B
0005433615133	5027	38	9D
0005432105844	5027	39	9F
0005433615137	5027	40	9E
0005433615125	5027	41	10A
0005433615114	5027	42	10C
0005432145124	5027	43	10B
0005432105880	5027	44	10D
0005432105847	5027	45	10E
0005433615181	5027	46	11A
0005432105841	5027	47	10F
0005433615162	5027	48	11B
0005432105878	5027	49	11D
0005432666400	5027	50	11C
0005433785162	5027	51	11F
0005433615150	5027	52	11E
0005432667468	5027	53	12A
0005433615136	5027	54	12B
0005433615168	5027	55	12C
0005433615121	5027	56	12E
0005433615119	5027	57	12D
0005433785160	5027	58	12F
0005433615160	5027	59	13B
0005433785168	5027	60	13A
0005433785163	5027	61	13C
0005433615180	5027	62	13D
0005433615146	5027	63	13F
0005433615151	5027	64	13E
0005433615128	5027	65	14A
0005433785178	5027	66	14B
0005432105856	5027	67	14C
0005433615169	5027	68	14E
0005432105843	5027	69	14D
0005433615144	5027	70	15A
0005433615115	5027	71	14F
0005433615120	5027	72	15C
0005432666402	5027	73	15B
0005432105870	5027	74	15D
0005433785158	5027	75	15F
0005432105846	5027	76	15E
0005433785164	5027	77	16A
0005433615111	5027	78	16C
0005433785181	5027	79	16B
0005432105868	5027	80	16E
0005433785155	5027	81	16D
0005433785183	5027	82	17A
0005433785186	5027	83	16F
0005433615170	5027	84	17B
0005433785166	5027	85	17C
0005433615173	5027	86	17D
0005432105857	5027	87	17E
0005433785165	5027	88	18A
0005433615179	5027	89	17F
0005433785171	5027	90	18B
0005433615118	5027	91	18C
0005433615112	5027	92	18D
0005433615126	5027	93	18F
0005432105863	5027	94	18E
0005432105859	5027	95	19C
0005433615116	5027	96	19B
0005433615182	5027	97	19D
0005432105858	5027	98	20A
0005432665287	5027	99	19E
0005433615134	5027	100	20B
0005432105862	5027	101	20C
0005433615127	5027	102	20E
0005432105851	5027	103	20D
0005432105837	5027	104	21B
0005432667465	5027	105	21A
0005432105861	5027	106	20F
0005433615159	5027	107	21D
0005432105885	5027	108	21C
0005432666401	5027	109	21F
0005432105845	5027	110	21E
0005433785154	5027	111	22A
0005433615166	5027	112	22B
0005433615158	5027	113	22C
0005433615130	5027	114	22E
0005433615149	5027	115	22D
0005432105877	5027	116	22F
0005433785169	5027	117	23A
0005433615163	5027	118	23B
0005433785157	5027	119	23D
0005433785153	5027	120	23C
0005433615153	5027	121	23E
0005433615148	5027	122	23F
0005433785176	5027	123	24B
0005433615109	5027	124	24A
0005432105882	5027	125	24C
0005432105839	5027	126	24D
0005433615142	5027	127	24F
0005433615138	5027	128	24E
0005433615141	5027	129	25B
0005433615165	5027	130	25A
0005432105860	5027	131	25C
0005433615123	5027	132	25D
0005432105840	5027	133	25F
0005433785185	5027	134	25E
0005433785170	5027	135	26A
0005433785173	5027	136	26B
0005432665286	5027	137	26D
0005433615156	5027	138	26C
0005432105872	5027	139	26E
0005432105854	5027	140	26F
0005432105867	5027	141	27B
0005432145123	5027	142	27A
0005432105842	5027	143	27C
0005433615161	5027	144	27D
0005433615175	5027	145	27E
0005433615164	5027	146	28A
0005433615147	5027	147	27F
0005433615177	5027	148	28C
0005433615176	5027	149	28B
0005433615145	5027	150	28D
0005433615143	5027	151	28E
0005432105866	5027	152	28F
0005433615174	5027	153	29A
0005433615154	5027	154	29C
0005432105876	5027	155	29B
0005433785159	5027	156	29E
0005432105871	5027	157	29D
0005433785172	5027	158	29F
0005433615157	5027	159	30A
0005432105850	5027	160	30B
0005432105855	5027	161	30D
0005433785167	5027	162	30C
0005433615167	5027	163	30E
0005432105884	5027	164	30F
0005433615117	5027	165	31A
0005432105848	5027	166	31C
0005432105852	5027	167	31B
0005433785175	5027	168	31E
0005433615178	5027	169	31D
0005432105865	5027	170	31F
0005432335979	5029	1	1A
0005434149807	5029	2	1F
0005434265286	5029	3	1D
0005434149806	5029	4	2D
0005434229509	5029	5	2C
0005434265291	5029	6	2F
0005434149802	5029	7	3C
0005435006953	5029	8	4A
0005434173546	5029	9	4F
0005435006957	5029	10	5A
0005434229511	5029	11	5D
0005435269673	5029	12	5F
0005434229513	5029	13	6A
0005434229520	5029	14	6C
0005432336048	5029	15	6F
0005432336012	5029	16	6D
0005434149804	5029	17	7A
0005435006939	5029	18	7C
0005434265293	5029	19	7F
0005435006960	5029	20	8A
0005434265285	5029	21	8B
0005434229517	5029	22	8D
0005435269672	5029	23	8C
0005434149805	5029	24	8F
0005433685509	5029	25	9A
0005433815371	5029	26	9C
0005434265300	5029	27	9B
0005434265299	5029	28	9D
0005433815369	5029	29	9E
0005434229498	5029	30	10B
0005435006984	5029	31	10C
0005433685511	5029	32	10E
0005434149801	5029	33	10F
0005434312310	5029	34	11C
0005432336063	5029	35	11E
0005434229499	5029	36	12A
0005435006888	5029	37	12D
0005435007025	5029	38	12C
0005434149803	5029	39	12E
0005433815361	5029	40	12F
0005435006940	5029	41	13B
0005433815368	5029	42	13C
0005435006956	5029	43	13D
0005434149800	5029	44	13E
0005434265294	5029	45	13F
0005434311213	5029	46	14B
0005434149799	5029	47	14C
0005433815372	5029	48	14E
0005435006895	5029	49	14D
0005435006975	5029	50	14F
0005434173543	5029	51	15C
0005434173545	5029	52	15D
0005435006990	5029	53	15F
0005432336010	5029	54	15E
0005434265302	5029	55	16A
0005434312309	5029	56	16B
0005434229501	5029	57	16D
0005434149797	5029	58	16C
0005434265303	5029	59	16F
0005434265295	5029	60	17B
0005434265308	5029	61	17C
0005435006961	5029	62	17E
0005434229504	5029	63	17D
0005434265288	5029	64	17F
0005434265287	5029	65	18C
0005434173544	5029	66	19B
0005435007002	5029	67	18F
0005435006918	5029	68	19C
0005434311215	5029	69	19D
0005434265307	5029	70	19E
0005433815364	5029	71	20B
0005434229510	5029	72	20C
0005434265289	5029	73	20E
0005435006974	5029	74	21C
0005434265306	5029	75	21E
0005434149798	5029	76	21F
0005434229507	5029	77	22B
0005434229515	5029	78	22E
0005434265305	5029	79	23B
0005433815370	5029	80	23D
0005434265296	5029	81	23E
0005434265297	5029	82	25A
0005434229518	5029	83	25C
0005434311214	5029	84	25B
0005434265284	5029	85	25D
0005434265290	5029	86	25F
0005434229502	5029	87	26C
0005434265301	5029	88	26F
0005435006995	5029	89	27A
0005434265309	5029	90	27B
0005434229512	5029	91	27D
0005434229516	5029	92	27C
0005432336013	5029	93	27F
0005434229514	5029	94	28B
0005434229506	5029	95	28D
0005433815373	5029	96	28F
0005434149808	5029	97	29B
0005435006917	5029	98	29A
0005434265304	5029	99	29C
0005434229500	5029	100	29E
0005434265292	5029	101	29D
0005432336009	5029	102	30A
0005433685510	5029	103	30D
0005434229519	5029	104	30C
0005434229508	5029	105	30F
0005434229505	5029	106	31B
0005434265298	5029	107	31E
0005434229503	5029	108	31F
0005433785042	8565	1	1A
0005433784800	8565	2	2C
0005433784921	8565	3	2D
0005435269780	8565	4	3D
0005433784934	8565	5	4D
0005434244983	8565	6	5D
0005433784864	8565	7	6A
0005432659703	8565	8	6C
0005433784878	8565	9	8A
0005434244935	8565	10	9A
0005433784889	8565	11	9B
0005434244948	8565	12	9D
0005433784843	8565	13	9E
0005432666374	8565	14	10D
0005434244865	8565	15	10E
0005433784812	8565	16	10F
0005435269785	8565	17	11E
0005432659704	8565	18	12A
0005434245005	8565	19	12B
0005433784842	8565	20	12C
0005434244955	8565	21	12E
0005433784724	8565	22	12D
0005433784940	8565	23	13A
0005434244984	8565	24	13C
0005433784827	8565	25	14A
0005434244981	8565	26	14B
0005433784728	8565	27	15F
0005434244953	8565	28	16D
0005435269778	8565	29	16F
0005434244893	8565	30	17C
0005435269783	8565	31	17B
0005433784811	8565	32	17E
0005434244941	8565	33	18C
0005434244916	8565	34	18B
0005435269779	8565	35	18E
0005434244930	8565	36	18D
0005433784841	8565	37	19C
0005433785034	8565	38	20B
0005434244954	8565	39	20A
0005433784960	8565	40	20E
0005434245016	8565	41	20D
0005433784725	8565	42	21A
0005434244973	8565	43	21B
0005433784961	8565	44	21D
0005433784852	8565	45	21F
0005434244945	8565	46	22A
0005434244929	8565	47	22C
0005434245017	8565	48	22F
0005433784922	8565	49	23B
0005433784853	8565	50	23A
0005433784839	8565	51	23D
0005435269777	8565	52	23C
0005434244932	8565	53	23F
0005432663016	8565	54	23E
0005433784946	8565	55	24A
0005434244952	8565	56	24E
0005435269784	8565	57	24D
0005434244861	8565	58	24F
0005434244947	8565	59	25A
0005433784939	8565	60	25F
0005434245038	8565	61	25E
0005434244962	8565	62	26F
0005435269781	8565	63	27A
0005434244985	8565	64	28A
0005433784840	8565	65	28B
0005435269782	8565	66	28D
0005434244980	8565	67	28E
0005433784858	8565	68	28F
0005434244931	8565	69	29C
0005434244946	8565	70	30B
0005434245039	8565	71	30E
0005433784894	8565	72	30D
0005434244925	8565	73	30F
0005434244972	8565	74	31A
0005434244852	8565	75	31F
0005433614495	8566	1	2D
0005433614443	8566	2	3C
0005433614389	8566	3	4C
0005433614582	8566	4	5A
0005433614287	8566	5	6A
0005433614412	8566	6	6F
0005433614425	8566	7	6D
0005433614101	8566	8	7A
0005433614382	8566	9	8A
0005433614100	8566	10	8B
0005433614383	8566	11	8D
0005433614618	8566	12	8C
0005433614433	8566	13	9D
0005433614305	8566	14	9E
0005433614462	8566	15	10B
0005433614539	8566	16	10E
0005433614415	8566	17	11B
0005433614183	8566	18	11D
0005433614326	8566	19	13D
0005433614562	8566	20	14A
0005433614641	8566	21	14D
0005433614501	8566	22	15A
0005433614603	8566	23	15B
0005433614237	8566	24	15E
0005433614496	8566	25	15F
0005433614363	8566	26	16B
0005433614019	8566	27	16E
0005433614301	8566	28	17C
0005433614288	8566	29	18A
0005433614161	8566	30	18D
0005433614307	8566	31	18E
0005433614338	8566	32	19B
0005433614619	8566	33	19D
0005433614374	8566	34	20F
0005433614642	8566	35	22B
0005433614494	8566	36	22A
0005433614275	8566	37	22D
0005433614327	8566	38	22C
0005433614333	8566	39	23D
0005433614498	8566	40	23E
0005433614515	8566	41	24F
0005433614424	8566	42	25B
0005433614497	8566	43	26C
0005433614328	8566	44	26E
0005433614652	8566	45	26D
0005433614653	8566	46	27A
0005433614397	8566	47	27D
0005433614463	8566	48	28D
0005433614225	8566	49	28C
0005433614421	8566	50	28E
0005433614289	8566	51	29B
0005433614286	8566	52	29A
0005433614375	8566	53	29C
0005433614388	8566	54	29F
0005433614381	8566	55	30B
0005433614236	8566	56	30E
0005433614387	8566	57	31B
0005433614332	8566	58	31A
0005433614224	8566	59	31D
0005432035120	8567	1	1C
0005434265119	8567	2	1A
0005433689924	8567	3	1D
0005432035124	8567	4	1F
0005432047573	8567	5	2F
0005434265051	8567	6	2D
0005432035118	8567	7	3A
0005434264972	8567	8	3C
0005434265072	8567	9	3F
0005432336107	8567	10	3D
0005434265156	8567	11	4A
0005433815415	8567	12	4D
0005433534511	8567	13	4C
0005434264992	8567	14	5A
0005432047574	8567	15	5C
0005434149693	8567	16	5F
0005435007169	8567	17	5D
0005435007165	8567	18	6A
0005435007173	8567	19	6C
0005433690937	8567	20	6D
0005432035111	8567	21	7A
0005434264973	8567	22	7C
0005432336105	8567	23	7D
0005433689923	8567	24	8A
0005434149718	8567	25	7F
0005434265111	8567	26	8B
0005433688823	8567	27	8C
0005434229324	8567	28	8E
0005434311233	8567	29	8D
0005432035114	8567	30	8F
0005435007172	8567	31	9A
0005434265152	8567	32	9C
0005432336113	8567	33	9B
0005434173524	8567	34	9D
0005434229348	8567	35	9F
0005432035122	8567	36	9E
0005434265109	8567	37	10A
0005432336114	8567	38	10C
0005434229309	8567	39	10B
0005434265073	8567	40	10D
0005434229288	8567	41	10E
0005435007177	8567	42	11A
0005434265066	8567	43	11C
0005434229295	8567	44	11D
0005434173498	8567	45	11F
0005434173493	8567	46	11E
0005434173527	8567	47	12A
0005432035115	8567	48	12C
0005434265077	8567	49	12B
0005435007164	8567	50	12E
0005432035117	8567	51	12D
0005434265075	8567	52	12F
0005432035131	8567	53	13A
0005434229202	8567	54	13C
0005434229321	8567	55	13B
0005432035112	8567	56	13E
0005432336111	8567	57	13D
0005434265139	8567	58	14A
0005434265037	8567	59	14B
0005432035130	8567	60	14C
0005432035106	8567	61	14E
0005432336104	8567	62	14D
0005434265130	8567	63	14F
0005434149689	8567	64	15B
0005434149678	8567	65	15A
0005434265067	8567	66	15C
0005433690938	8567	67	15F
0005434149672	8567	68	15E
0005432047575	8567	69	16A
0005434265052	8567	70	16B
0005432035110	8567	71	16D
0005435007162	8567	72	16C
0005434265211	8567	73	16E
0005433815419	8567	74	17A
0005434229291	8567	75	17B
0005432035127	8567	76	17C
0005434229230	8567	77	17F
0005432035126	8567	78	17E
0005434265155	8567	79	18A
0005434265094	8567	80	18B
0005434229325	8567	81	18D
0005434264977	8567	82	18C
0005434265025	8567	83	18E
0005435007161	8567	84	18F
0005432047571	8567	85	19C
0005434173513	8567	86	19B
0005432035107	8567	87	19E
0005432035108	8567	88	19D
0005434229310	8567	89	20A
0005432336106	8567	90	20B
0005434265120	8567	91	20D
0005435007175	8567	92	20C
0005435007174	8567	93	20F
0005435007171	8567	94	21A
0005433815418	8567	95	21C
0005435007176	8567	96	21B
0005432336103	8567	97	21D
0005434149688	8567	98	21E
0005432035121	8567	99	22A
0005432035113	8567	100	21F
0005432336102	8567	101	22B
0005434229355	8567	102	22C
0005432336109	8567	103	22D
0005432035116	8567	104	22F
0005434265019	8567	105	22E
0005435007170	8567	106	23A
0005433815414	8567	107	23C
0005432035119	8567	108	23B
0005434265018	8567	109	23D
0005434265137	8567	110	23E
0005434264993	8567	111	24A
0005432047572	8567	112	23F
0005434229387	8567	113	24B
0005432035123	8567	114	24C
0005434149703	8567	115	24E
0005434229201	8567	116	24D
0005432035128	8567	117	24F
0005432336112	8567	118	25A
0005432336108	8567	119	25C
0005432035105	8567	120	25B
0005434149702	8567	121	25D
0005434173494	8567	122	25E
0005433815416	8567	123	26A
0005433688821	8567	124	25F
0005434229300	8567	125	26B
0005434265093	8567	126	26D
0005434265071	8567	127	26C
0005434265076	8567	128	26E
0005432035132	8567	129	26F
0005434149629	8567	130	27A
0005435007166	8567	131	27C
0005435007168	8567	132	27B
0005432035125	8567	133	27E
0005434265114	8567	134	27D
0005435007163	8567	135	28A
0005433534512	8567	136	28C
0005434265060	8567	137	28E
0005434149694	8567	138	28F
0005432035109	8567	139	29B
0005435007167	8567	140	29C
0005434265133	8567	141	29D
0005434265110	8567	142	29E
0005433815417	8567	143	30A
0005434265026	8567	144	29F
0005434149699	8567	145	30C
0005434149685	8567	146	30B
0005433688822	8567	147	30E
0005432336110	8567	148	30F
0005432035129	8567	149	31A
0005434229374	8567	150	31C
0005434265154	8567	151	31D
0005434265023	8567	152	31F
0005434265068	8567	153	31E
0005433202451	12603	1	1A
0005434639216	12603	2	1B
0005434639266	12603	3	1C
0005434639303	12603	4	1D
0005433202457	12603	5	2A
0005434639134	12603	6	2B
0005434639296	12603	7	2C
0005433202459	12603	8	2D
0005434639192	12603	9	3A
0005434639283	12603	10	3B
0005434639252	12603	11	3C
0005434639311	12603	12	3D
0005434639274	12603	13	4A
0005434639318	12603	14	4B
0005433202458	12603	15	4C
0005434639310	12603	16	4D
0005433202461	12603	17	5A
0005433202455	12603	18	5B
0005434639321	12603	19	5C
0005434639354	12603	20	5D
0005433202463	12603	21	6A
0005434639130	12603	22	6B
0005434639317	12603	23	6C
0005434639370	12603	24	6D
0005434639309	12603	25	7A
0005434639353	12603	26	7B
0005433202452	12603	27	7C
0005434639163	12603	28	7D
0005433202460	12603	29	18A
0005433202454	12603	30	18B
0005434639156	12603	31	18C
0005434639164	12603	32	18D
0005434639358	12603	33	19A
0005433202453	12603	34	19B
0005434639357	12603	35	19C
0005434639109	12603	36	19D
0005434639253	12603	37	20A
0005433202456	12603	38	20B
0005434639135	12603	39	20C
0005434639215	12603	40	20D
0005434639254	12603	41	21A
0005433202462	12603	42	21B
0005434639263	12603	43	21C
0005434639294	12603	44	21D
0005434639249	12603	45	22A
0005434639217	12603	46	22B
0005434639306	12603	47	22C
0005434639264	12603	48	23A
0005434639275	12603	49	23B
0005434639463	23384	1	1A
0005434639467	23384	2	1D
0005433202326	23384	3	1C
0005433202294	23384	4	2A
0005434639464	23384	5	2B
0005434639451	23384	6	2C
0005433202287	23384	7	2D
0005432290649	23384	8	3A
0005432290650	23384	9	3B
0005433202328	23384	10	3C
0005434639470	23384	11	3D
0005434639465	23384	12	4A
0005434639476	23384	13	4B
0005433202289	23384	14	4C
0005433202327	23384	15	4D
0005434639475	23384	16	5C
0005434639455	23384	17	5D
0005434639456	23384	18	6A
0005433202312	23384	19	6B
0005434639459	23384	20	6C
0005432290648	23384	21	6D
0005433202310	23384	22	7B
0005434639457	23384	23	7A
0005434639466	23384	24	7C
0005433202272	23384	25	7D
0005434639468	23384	26	18A
0005434639474	23384	27	18C
0005434639452	23384	28	18D
0005434639454	23384	29	19A
0005433202292	23384	30	19C
0005434639469	23384	31	19D
0005433202271	23384	32	20A
0005433202307	23384	33	20C
0005433202337	23384	34	20D
0005434639460	23384	35	21A
0005433202291	23384	36	21B
0005434639458	23384	37	21C
0005434639461	23384	38	21D
0005434639453	23384	39	22B
0005434639473	23384	40	22A
0005434639450	23384	41	22C
0005434639472	23384	42	22D
0005434639471	23384	43	23A
0005434639462	23384	44	23B
0005432382848	21110	1	1A
0005432328523	21110	2	1C
0005432382955	21110	3	1D
0005432328713	21110	4	1F
0005432328705	21110	5	2A
0005432382991	21110	6	2C
0005432328368	21110	7	2D
0005432328636	21110	8	2F
0005432328460	21110	9	3A
0005432328678	21110	10	3C
0005432328374	21110	11	3D
0005432328520	21110	12	3F
0005432382895	21110	13	4A
0005432328488	21110	14	4C
0005432328547	21110	15	4D
0005432328704	21110	16	4E
0005432383039	21110	17	4F
0005432328578	21110	18	5A
0005432383054	21110	19	5C
0005432328603	21110	20	5D
0005432328675	21110	21	5E
0005432328581	21110	22	5F
0005432383019	21110	23	6A
0005432383040	21110	24	6C
0005432328596	21110	25	6D
0005432383033	21110	26	6E
0005432328549	21110	27	6F
0005432328661	21110	28	7A
0005432328482	21110	29	7C
0005432383083	21110	30	7D
0005432382856	21110	31	7E
0005432382932	21110	32	7F
0005432383052	21110	33	8A
0005432382942	21110	34	8C
0005432328548	21110	35	8D
0005432382904	21110	36	8E
0005432383009	21110	37	8F
0005432054324	21110	38	9A
0005432328527	21110	39	9C
0005432382896	21110	40	9D
0005432383045	21110	41	9E
0005432328613	21110	42	9F
0005432328522	21110	43	10A
0005432328666	21110	44	10C
0005432328437	21110	45	10D
0005432328590	21110	46	10F
0005432328674	21110	47	11A
0005432328677	21110	48	11C
0005432328597	21110	49	11D
0005432382965	21110	50	11E
0005432383030	21110	51	11F
0005432382951	21110	52	12A
0005432383006	21110	53	12C
0005432328628	21110	54	12D
0005432383046	21110	55	12E
0005432328461	21110	56	12F
0005432383018	21110	57	13A
0005432383051	21110	58	13C
0005432328371	21110	59	13D
0005432328434	21110	60	13E
0005432328591	21110	61	13F
0005432383063	21110	62	14A
0005432383086	21110	63	14C
0005432328614	21110	64	14D
0005432054325	21110	65	14E
0005432382992	21110	66	14F
0005432382974	21110	67	15A
0005432054323	21110	68	15C
0005432328686	21110	69	15D
0005432383007	21110	70	15E
0005432328334	21110	71	15F
0005432328602	21110	72	16A
0005432328577	21110	73	16C
0005432328594	21110	74	16D
0005432328526	21110	75	16E
0005432383055	21110	76	16F
0005432328764	21110	77	17A
0005432383053	21110	78	17C
0005432328667	21110	79	17D
0005432383044	21110	80	17E
0005432383082	21110	81	17F
0005432383078	21110	82	18A
0005432383020	21110	83	18C
0005432328622	21110	84	18D
0005432328573	21110	85	18E
0005432328685	21110	86	18F
0005432382973	21110	87	19A
0005432383000	21110	88	19C
0005432383048	21110	89	19D
0005432328413	21110	90	19E
0005432383076	21110	91	19F
0005432382980	21110	92	20A
0005432328638	21110	93	20C
0005432383008	21110	94	20D
0005432328433	21110	95	20E
0005432328694	21110	96	20F
0005432383366	31277	1	1A
0005432328939	31277	2	1C
0005432328961	31277	3	1D
0005432328936	31277	4	2A
0005432328964	31277	5	2C
0005432383359	31277	6	2D
0005432383385	31277	7	2F
0005432328970	31277	8	3A
0005432328956	31277	9	3C
0005432383361	31277	10	3F
0005432328929	31277	11	4A
0005432287218	31277	12	4C
0005432383371	31277	13	4D
0005432328945	31277	14	4E
0005432328948	31277	15	4F
0005432383382	31277	16	5A
0005432383363	31277	17	5C
0005432328952	31277	18	5D
0005432287214	31277	19	5E
0005432328942	31277	20	5F
0005432328926	31277	21	6A
0005432383393	31277	22	6D
0005432328966	31277	23	6E
0005432383374	31277	24	6F
0005432383368	31277	25	7A
0005432383373	31277	26	7C
0005432383399	31277	27	7D
0005432328931	31277	28	7E
0005432383387	31277	29	7F
0005432383396	31277	30	8A
0005432383398	31277	31	8C
0005432328930	31277	32	8D
0005432328959	31277	33	8E
0005432328927	31277	34	8F
0005432383372	31277	35	9A
0005432328949	31277	36	9C
0005432383362	31277	37	9D
0005432383383	31277	38	9E
0005432328957	31277	39	9F
0005432383364	31277	40	10A
0005432383390	31277	41	10C
0005432383380	31277	42	10D
0005432287217	31277	43	10E
0005432383384	31277	44	10F
0005432328937	31277	45	11A
0005432383360	31277	46	11C
0005432328932	31277	47	11D
0005432328940	31277	48	11E
0005432383388	31277	49	11F
0005432383370	31277	50	12A
0005432383367	31277	51	12C
0005432328955	31277	52	12D
0005432328954	31277	53	12E
0005432383369	31277	54	12F
0005432383381	31277	55	13A
0005432328950	31277	56	13C
0005432287215	31277	57	13E
0005432328965	31277	58	13F
0005432383386	31277	59	14A
0005432328953	31277	60	14C
0005432383377	31277	61	14D
0005432328951	31277	62	14E
0005432328935	31277	63	14F
0005432328944	31277	64	15A
0005432328969	31277	65	15C
0005432383389	31277	66	15D
0005432328960	31277	67	15E
0005432383400	31277	68	15F
0005432328941	31277	69	16A
0005432328933	31277	70	16C
0005432328928	31277	71	16D
0005432328934	31277	72	16E
0005432328967	31277	73	16F
0005432328968	31277	74	17A
0005432328958	31277	75	17C
0005432383401	31277	76	17D
0005432383376	31277	77	17E
0005432287216	31277	78	17F
0005432328963	31277	79	18A
0005432383365	31277	80	18C
0005432383378	31277	81	18D
0005432328943	31277	82	18E
0005432383379	31277	83	18F
0005432383397	31277	84	19A
0005432383392	31277	85	19C
0005432383394	31277	86	19D
0005432328938	31277	87	19E
0005432328947	31277	88	19F
0005432383375	31277	89	20A
0005432383395	31277	90	20C
0005432328946	31277	91	20D
0005432383391	31277	92	20E
0005432328962	31277	93	20F
0005433642423	2469	1	1C
0005433642435	2469	2	2F
0005433642438	2469	3	2D
0005433642413	2469	4	3A
0005433642437	2469	5	3C
0005433642430	2469	6	3D
0005433642445	2469	7	3F
0005432953933	2469	8	4D
0005433642417	2469	9	4E
0005433642442	2469	10	4F
0005433642424	2469	11	5C
0005433642425	2469	12	5D
0005433642421	2469	13	6E
0005432953932	2469	14	7A
0005433642432	2469	15	7F
0005432953915	2469	16	8A
0005433642426	2469	17	8D
0005432953923	2469	18	9A
0005433642433	2469	19	9C
0005433642419	2469	20	10A
0005433642443	2469	21	10E
0005433642428	2469	22	12A
0005433642429	2469	23	12C
0005433642427	2469	24	12D
0005433642422	2469	25	13D
0005432953922	2469	26	13F
0005433642418	2469	27	14A
0005432953909	2469	28	14C
0005432953924	2469	29	14E
0005433642444	2469	30	14F
0005432953926	2469	31	15C
0005433642440	2469	32	15F
0005433642416	2469	33	16E
0005433642436	2469	34	16F
0005433642414	2469	35	17D
0005432953925	2469	36	17F
0005433642431	2469	37	18A
0005433642420	2469	38	18D
0005433642441	2469	39	19A
0005433642412	2469	40	19D
0005433642434	2469	41	19E
0005433642415	2469	42	20C
0005433642439	2469	43	20F
0005432953972	27586	1	1D
0005433642311	27586	2	1F
0005433642206	27586	3	2A
0005432953977	27586	4	2C
0005433642292	27586	5	2D
0005433642282	27586	6	2F
0005433642322	27586	7	3A
0005433642298	27586	8	3C
0005432953987	27586	9	3D
0005433642261	27586	10	3F
0005432953986	27586	11	4A
0005433642304	27586	12	4D
0005432953984	27586	13	5A
0005433642198	27586	14	5C
0005433642290	27586	15	5D
0005432953989	27586	16	5E
0005433642265	27586	17	5F
0005433642301	27586	18	6A
0005433642316	27586	19	6D
0005432953983	27586	20	6C
0005432953976	27586	21	6E
0005433642267	27586	22	6F
0005432953982	27586	23	7A
0005432953992	27586	24	7C
0005432953990	27586	25	7D
0005433642305	27586	26	7E
0005433642299	27586	27	7F
0005433642315	27586	28	8C
0005433642221	27586	29	8D
0005433642224	27586	30	8E
0005432953981	27586	31	8F
0005433642293	27586	32	9A
0005433642286	27586	33	9E
0005433642259	27586	34	9F
0005433642266	27586	35	10A
0005433642171	27586	36	10C
0005433642334	27586	37	10D
0005433642210	27586	38	10F
0005433642262	27586	39	11A
0005433642269	27586	40	11C
0005433642225	27586	41	11F
0005432953978	27586	42	12C
0005433642323	27586	43	12D
0005433642276	27586	44	12E
0005432953975	27586	45	13A
0005432953970	27586	46	13C
0005432953988	27586	47	13E
0005432953979	27586	48	13F
0005433642255	27586	49	14A
0005433642300	27586	50	14C
0005433642278	27586	51	14D
0005433642172	27586	52	14E
0005433642283	27586	53	14F
0005433642366	27586	54	15A
0005433642268	27586	55	15C
0005432953969	27586	56	15D
0005433642185	27586	57	15E
0005433642333	27586	58	15F
0005433642260	27586	59	16A
0005432953993	27586	60	16C
0005432953985	27586	61	16D
0005433642274	27586	62	16E
0005432953980	27586	63	16F
0005432953974	27586	64	17A
0005432953971	27586	65	17C
0005433642272	27586	66	17D
0005433642275	27586	67	17E
0005433642309	27586	68	17F
0005432953973	27586	69	18A
0005433642318	27586	70	18C
0005433642317	27586	71	18D
0005432953991	27586	72	18E
0005433642289	27586	73	18F
0005433642365	27586	74	19A
0005433642310	27586	75	19C
0005433642280	27586	76	19E
0005433642297	27586	77	19F
0005433642294	27586	78	20C
0005433642277	27586	79	20E
0005432424698	13311	1	1A
0005432424689	13311	2	1C
0005432424709	13311	3	1D
0005432424670	13311	4	1F
0005432424685	13311	5	2A
0005432424668	13311	6	2D
0005432424695	13311	7	3C
0005432424683	13311	8	3F
0005432424703	13311	9	4A
0005432424684	13311	10	4E
0005432424699	13311	11	5C
0005432424677	13311	12	6A
0005432424692	13311	13	6D
0005432424712	13311	14	6E
0005432424679	13311	15	7C
0005432424676	13311	16	7D
0005432424714	13311	17	7E
0005432424694	13311	18	8D
0005432424678	13311	19	8E
0005432424706	13311	20	9C
0005432424680	13311	21	9E
0005432424690	13311	22	9F
0005432424707	13311	23	10D
0005432424669	13311	24	10E
0005432424675	13311	25	11A
0005432424704	13311	26	11E
0005432424691	13311	27	11F
0005432424701	13311	28	12D
0005432424682	13311	29	12E
0005432424700	13311	30	13D
0005432424708	13311	31	13E
0005432424713	13311	32	13F
0005432424674	13311	33	14F
0005432424687	13311	34	15A
0005432424710	13311	35	15C
0005432424693	13311	36	15F
0005432424681	13311	37	16C
0005432424673	13311	38	16E
0005432424705	13311	39	17A
0005432424702	13311	40	17D
0005432424696	13311	41	17F
0005432424686	13311	42	18E
0005432424671	13311	43	18F
0005432424711	13311	44	19A
0005432424672	13311	45	19E
0005432424688	13311	46	20C
0005432424697	13311	47	20F
0005432424239	30697	1	1A
0005432424125	30697	2	1F
0005432424099	30697	3	3A
0005432424300	30697	4	3F
0005432424124	30697	5	4C
0005432424241	30697	6	4D
0005432424202	30697	7	4F
0005432424319	30697	8	5A
0005432424118	30697	9	5C
0005432424286	30697	10	6C
0005432424254	30697	11	6D
0005432424200	30697	12	7A
0005432424100	30697	13	7E
0005432424098	30697	14	8A
0005432424126	30697	15	8C
0005432424045	30697	16	8D
0005432424257	30697	17	8F
0005432424242	30697	18	9A
0005432424101	30697	19	9D
0005432424292	30697	20	9E
0005432424195	30697	21	10D
0005432424259	30697	22	10E
0005432424307	30697	23	10F
0005432424302	30697	24	11A
0005432424306	30697	25	11D
0005432424256	30697	26	11F
0005432424154	30697	27	12A
0005432424117	30697	28	12D
0005432424321	30697	29	12E
0005432424278	30697	30	13C
0005432424260	30697	31	14A
0005432424301	30697	32	14C
0005432424183	30697	33	14D
0005432424295	30697	34	15A
0005432424180	30697	35	15D
0005432424193	30697	36	15E
0005432424088	30697	37	15F
0005432424323	30697	38	16A
0005432424194	30697	39	17D
0005432424187	30697	40	17E
0005432424305	30697	41	18A
0005432424267	30697	42	18C
0005432424181	30697	43	19A
0005432424322	30697	44	19F
0005432424296	30697	45	20A
0005432424299	30697	46	20D
0005432424285	30697	47	20E
0005432424314	30697	48	20F
0005432817663	9592	1	1A
0005432822249	9592	2	1C
0005432289005	9592	3	1D
0005432901481	9592	4	1F
0005432817652	9592	5	2A
0005434448336	9592	6	2C
0005432817636	9592	7	2D
0005432822252	9592	8	3A
0005432817668	9592	9	3D
0005432901570	9592	10	3F
0005432901594	9592	11	4D
0005432817659	9592	12	4E
0005434157483	9592	13	4F
0005432817658	9592	14	5A
0005432817650	9592	15	5E
0005432817655	9592	16	5F
0005434157463	9592	17	6A
0005432822251	9592	18	6C
0005434157438	9592	19	6D
0005434186199	9592	20	6E
0005432817639	9592	21	7C
0005434157439	9592	22	7D
0005432817654	9592	23	7E
0005432289008	9592	24	8A
0005432289007	9592	25	8C
0005432817664	9592	26	8D
0005434157451	9592	27	8E
0005432901545	9592	28	8F
0005432822246	9592	29	9A
0005434157469	9592	30	9C
0005432822248	9592	31	9D
0005432901592	9592	32	9E
0005432817646	9592	33	10A
0005432901573	9592	34	10D
0005434448335	9592	35	10E
0005432817645	9592	36	10F
0005432817667	9592	37	11A
0005432901555	9592	38	11D
0005432817653	9592	39	11E
0005434157462	9592	40	11F
0005434448337	9592	41	12A
0005432817642	9592	42	12C
0005432817661	9592	43	12D
0005432817644	9592	44	12E
0005432901544	9592	45	12F
0005432817649	9592	46	13A
0005432817660	9592	47	13D
0005432822247	9592	48	13E
0005434157461	9592	49	13F
0005432817643	9592	50	14A
0005434157482	9592	51	14C
0005432817638	9592	52	14E
0005432817666	9592	53	15A
0005432901514	9592	54	15C
0005432817657	9592	55	15D
0005432817640	9592	56	15E
0005432817647	9592	57	15F
0005432817641	9592	58	16A
0005432901566	9592	59	16C
0005432817651	9592	60	16D
0005432817656	9592	61	16E
0005432901593	9592	62	17A
0005432822250	9592	63	17E
0005432289006	9592	64	17F
0005432817665	9592	65	18A
0005432822253	9592	66	18E
0005434157450	9592	67	18F
0005434157474	9592	68	19A
0005432817648	9592	69	19C
0005432901515	9592	70	19D
0005432817662	9592	71	19E
0005432901571	9592	72	20A
0005432817637	9592	73	20D
0005432817334	28992	1	1C
0005432817222	28992	2	1F
0005432817372	28992	3	2A
0005432901716	28992	4	2C
0005432817499	28992	5	2F
0005432901722	28992	6	3C
0005434157530	28992	7	3D
0005432817365	28992	8	4A
0005432817378	28992	9	4C
0005434157531	28992	10	4D
0005432817480	28992	11	4E
0005432822190	28992	12	4F
0005434157526	28992	13	5A
0005434157525	28992	14	5C
0005432817379	28992	15	5D
0005432822196	28992	16	5E
0005434448296	28992	17	5F
0005432901710	28992	18	6A
0005432822186	28992	19	6D
0005432901715	28992	20	6E
0005432817302	28992	21	7C
0005432817451	28992	22	7D
0005432822171	28992	23	7F
0005432817428	28992	24	8A
0005434448312	28992	25	8D
0005432822187	28992	26	8E
0005434186214	28992	27	8F
0005432817407	28992	28	9D
0005432822188	28992	29	9E
0005432822191	28992	30	9F
0005432901723	28992	31	10A
0005432901709	28992	32	10C
0005432817303	28992	33	10D
0005434157529	28992	34	10E
0005432901708	28992	35	10F
0005432901717	28992	36	11A
0005434157528	28992	37	11C
0005432901711	28992	38	11D
0005432822189	28992	39	11E
0005434157523	28992	40	12A
0005432901718	28992	41	12D
0005432002088	28992	42	12E
0005434186215	28992	43	13A
0005432901707	28992	44	13C
0005432817336	28992	45	13D
0005432817409	28992	46	13E
0005434157527	28992	47	14A
0005432817368	28992	48	14E
0005432901713	28992	49	14F
0005432817387	28992	50	15A
0005432817239	28992	51	15C
0005432901724	28992	52	15D
0005432817476	28992	53	15E
0005432817457	28992	54	15F
0005432901721	28992	55	16A
0005432817371	28992	56	16C
0005432817386	28992	57	16D
0005432002089	28992	58	16F
0005432822168	28992	59	17A
0005432817426	28992	60	17D
0005432817337	28992	61	17E
0005432817254	28992	62	17F
0005432901720	28992	63	18A
0005432817223	28992	64	18C
0005432817288	28992	65	18D
0005432822199	28992	66	18E
0005432901714	28992	67	18F
0005432901719	28992	68	19A
0005432817400	28992	69	19C
0005432817335	28992	70	19D
0005432817327	28992	71	19E
0005432817477	28992	72	19F
0005434157524	28992	73	20A
0005432901712	28992	74	20C
0005432817498	28992	75	20D
0005432817270	28992	76	20E
0005432613887	15055	1	1A
0005432613885	15055	2	2A
0005435841098	15055	3	2B
0005432613886	15055	4	3A
0005432611736	15055	5	3B
0005432611735	15055	6	4A
0005432613889	15055	7	5A
0005432611737	15055	8	4B
0005432611734	15055	9	5B
0005432613888	15055	10	6B
0005432607537	31589	1	1A
0005432607565	31589	2	1B
0005432607536	31589	3	2A
0005432607555	31589	4	2B
0005432611713	31589	5	3A
0005432607547	31589	6	4A
0005432607564	31589	7	4B
0005432611706	31589	8	5A
0005432607554	31589	9	6A
0005432607538	31589	10	5B
0005432611683	31589	11	6B
0005432948245	11867	1	1C
0005432948124	11867	2	1A
0005433569385	11867	3	1F
0005432948342	11867	4	1D
0005432948349	11867	5	2A
0005432948351	11867	6	2D
0005433569360	11867	7	2C
0005432948413	11867	8	3A
0005432948356	11867	9	2F
0005432948221	11867	10	3D
0005432948275	11867	11	4A
0005433569421	11867	12	3F
0005433569398	11867	13	4C
0005433569419	11867	14	4D
0005432948212	11867	15	5C
0005433569410	11867	16	5A
0005433569407	11867	17	5F
0005433569401	11867	18	5D
0005433569381	11867	19	6B
0005433569366	11867	20	6C
0005433569371	11867	21	6F
0005433569413	11867	22	6E
0005432948233	11867	23	7A
0005433569427	11867	24	7C
0005432948360	11867	25	7B
0005433569370	11867	26	7D
0005432948282	11867	27	7F
0005433569391	11867	28	7E
0005433569416	11867	29	8B
0005433569422	11867	30	8A
0005432948355	11867	31	8D
0005433569384	11867	32	8C
0005432948371	11867	33	8F
0005432948363	11867	34	8E
0005433569376	11867	35	9B
0005433569373	11867	36	9A
0005433569393	11867	37	9D
0005432948436	11867	38	9C
0005433569377	11867	39	9E
0005433569382	11867	40	10A
0005432948382	11867	41	9F
0005432948357	11867	42	10C
0005433569426	11867	43	10B
0005433569406	11867	44	10E
0005432948343	11867	45	10D
0005433569378	11867	46	10F
0005433569405	11867	47	11C
0005432948344	11867	48	11B
0005433569369	11867	49	11A
0005433569402	11867	50	11D
0005432948334	11867	51	11F
0005433569363	11867	52	11E
0005433569372	11867	53	12A
0005433569390	11867	54	12D
0005432948241	11867	55	12C
0005432948385	11867	56	12E
0005432948350	11867	57	13A
0005433569400	11867	58	12F
0005432948123	11867	59	13C
0005433569364	11867	60	13B
0005433569380	11867	61	13E
0005433569386	11867	62	13D
0005432948299	11867	63	14A
0005433569387	11867	64	13F
0005433569411	11867	65	14B
0005432948316	11867	66	14D
0005433569425	11867	67	14C
0005432948213	11867	68	14F
0005433569414	11867	69	14E
0005433569392	11867	70	15B
0005433569389	11867	71	15A
0005433569415	11867	72	15C
0005432948240	11867	73	15E
0005433569417	11867	74	15D
0005433569395	11867	75	16A
0005433569397	11867	76	15F
0005433569368	11867	77	16C
0005432948330	11867	78	16B
0005433569418	11867	79	16E
0005433569408	11867	80	16D
0005433569403	11867	81	16F
0005433569412	11867	82	17C
0005433569423	11867	83	17B
0005433569420	11867	84	17A
0005432948348	11867	85	17D
0005433569367	11867	86	17E
0005433569362	11867	87	18B
0005432948157	11867	88	18A
0005433569379	11867	89	17F
0005433569383	11867	90	18C
0005432948384	11867	91	18E
0005432948353	11867	92	18D
0005433569404	11867	93	19A
0005432948249	11867	94	18F
0005433569365	11867	95	19C
0005432948443	11867	96	19B
0005432948326	11867	97	19E
0005433569374	11867	98	19D
0005433569409	11867	99	19F
0005433569388	11867	100	20A
0005433569361	11867	101	20D
0005433569396	11867	102	20C
0005433569375	11867	103	20E
0005432948301	11867	104	21B
0005432948234	11867	105	21A
0005433569394	11867	106	20F
0005433569399	11867	107	21C
0005432948125	11867	108	21E
0005433569424	11867	109	21D
0005432948274	11867	110	21F
0005432948726	25307	1	1C
0005433568908	25307	2	1A
0005432948736	25307	3	1D
0005432948740	25307	4	2A
0005432948745	25307	5	2F
0005433568852	25307	6	2C
0005432948739	25307	7	3D
0005433568813	25307	8	3C
0005433568921	25307	9	4A
0005433568767	25307	10	3F
0005433568834	25307	11	4D
0005432948758	25307	12	4C
0005433568680	25307	13	5A
0005432948746	25307	14	4F
0005433568751	25307	15	5C
0005433568904	25307	16	5F
0005433568864	25307	17	5D
0005433568905	25307	18	6B
0005433568653	25307	19	6A
0005433568835	25307	20	6C
0005432948741	25307	21	6E
0005433568822	25307	22	6D
0005432948735	25307	23	7B
0005433568846	25307	24	7A
0005433568851	25307	25	6F
0005432948737	25307	26	7C
0005433568820	25307	27	7E
0005432948727	25307	28	7D
0005432948749	25307	29	8A
0005432948753	25307	30	7F
0005432948765	25307	31	8B
0005433568844	25307	32	8E
0005433568940	25307	33	8D
0005433568790	25307	34	8C
0005432948757	25307	35	8F
0005433568933	25307	36	9A
0005433568807	25307	37	9D
0005433568819	25307	38	9B
0005433568824	25307	39	9E
0005433568900	25307	40	10A
0005432948744	25307	41	9F
0005433568768	25307	42	10C
0005432948762	25307	43	10B
0005432948732	25307	44	10E
0005433568889	25307	45	10D
0005433568899	25307	46	11A
0005432948747	25307	47	10F
0005433568770	25307	48	11B
0005433568842	25307	49	11D
0005433568832	25307	50	11C
0005433568911	25307	51	11F
0005433568939	25307	52	11E
0005432948748	25307	53	12D
0005433568906	25307	54	12C
0005432948752	25307	55	12B
0005432948728	25307	56	12F
0005432948756	25307	57	12E
0005433568515	25307	58	13A
0005433568750	25307	59	13C
0005433568764	25307	60	13B
0005433568638	25307	61	13E
0005433568865	25307	62	13D
0005432948733	25307	63	13F
0005432948763	25307	64	14B
0005432948734	25307	65	14A
0005432948764	25307	66	14D
0005433568801	25307	67	14C
0005433568896	25307	68	14F
0005433568752	25307	69	14E
0005432948730	25307	70	15B
0005433568799	25307	71	15A
0005432948738	25307	72	15D
0005433568578	25307	73	15C
0005433568763	25307	74	15E
0005433568863	25307	75	16A
0005433568514	25307	76	15F
0005433568941	25307	77	16B
0005433568831	25307	78	16E
0005432948754	25307	79	16D
0005432948759	25307	80	16C
0005432948760	25307	81	17A
0005433568903	25307	82	16F
0005433568893	25307	83	17B
0005433568853	25307	84	17D
0005433568743	25307	85	17C
0005433568765	25307	86	17F
0005433568898	25307	87	17E
0005433568907	25307	88	18A
0005433568644	25307	89	18C
0005433568814	25307	90	18B
0005432948761	25307	91	18E
0005433568843	25307	92	18D
0005433568825	25307	93	19A
0005432948742	25307	94	18F
0005433568753	25307	95	19C
0005433568845	25307	96	19B
0005432948731	25307	97	19E
0005432948743	25307	98	19F
0005432948723	25307	99	20C
0005432948750	25307	100	20B
0005433568582	25307	101	20A
0005432948751	25307	102	20F
0005432948729	25307	103	20E
0005432948725	25307	104	20D
0005433568894	25307	105	21B
0005432948755	25307	106	21A
0005433568772	25307	107	21C
0005432948724	25307	108	21E
0005433568771	25307	109	21D
0005433568930	25307	110	21F
0005434654856	5385	1	1C
0005432114221	5385	2	1D
0005434654874	5385	3	1F
0005435340198	5385	4	2A
0005434654853	5385	5	2C
0005434654866	5385	6	2F
0005435340250	5385	7	3A
0005435340207	5385	8	3C
0005435340181	5385	9	3D
0005435340233	5385	10	3F
0005434654868	5385	11	4C
0005435340189	5385	12	4D
0005434654859	5385	13	4E
0005434654860	5385	14	4F
0005435340264	5385	15	5A
0005435555371	5385	16	5C
0005435340219	5385	17	5E
0005434656569	5385	18	6A
0005435340214	5385	19	6C
0005434654877	5385	20	6D
0005434654876	5385	21	6E
0005435340195	5385	22	6F
0005434654861	5385	23	7A
0005434654862	5385	24	7C
0005434654867	5385	25	7D
0005434654865	5385	26	7E
0005435340143	5385	27	7F
0005435340252	5385	28	8A
0005435340199	5385	29	8C
0005434654863	5385	30	8E
0005434654851	5385	31	9A
0005434654849	5385	32	9C
0005434654869	5385	33	9E
0005434654872	5385	34	9F
0005432114222	5385	35	11A
0005434654864	5385	36	11C
0005432114223	5385	37	11D
0005435340220	5385	38	11E
0005434656570	5385	39	11F
0005434654855	5385	40	12A
0005435340258	5385	41	12C
0005435555365	5385	42	12D
0005435340256	5385	43	12E
0005434654870	5385	44	13C
0005434654852	5385	45	13E
0005435340262	5385	46	13F
0005435555373	5385	47	14C
0005435555370	5385	48	14D
0005434654875	5385	49	14E
0005434654850	5385	50	15A
0005434654848	5385	51	15D
0005435340133	5385	52	15E
0005435340227	5385	53	15F
0005434654873	5385	54	16A
0005432114224	5385	55	16D
0005435555366	5385	56	16F
0005434654857	5385	57	17C
0005435340216	5385	58	17E
0005434654858	5385	59	18A
0005435340251	5385	60	18D
0005434654854	5385	61	18E
0005435340266	5385	62	19A
0005435340257	5385	63	19F
0005434654871	5385	64	20E
0005435340134	5385	65	20F
0005435340353	12526	1	1D
0005434654716	12526	2	1F
0005435340362	12526	3	2C
0005434654581	12526	4	3A
0005434654554	12526	5	3C
0005434656549	12526	6	4A
0005435340360	12526	7	4C
0005435340361	12526	8	4D
0005435340350	12526	9	5C
0005435555382	12526	10	5D
0005434654622	12526	11	5E
0005435555384	12526	12	5F
0005434654717	12526	13	6A
0005434654736	12526	14	6E
0005434654591	12526	15	6F
0005435340358	12526	16	7E
0005434654563	12526	17	8A
0005435340356	12526	18	8C
0005434654608	12526	19	8D
0005434654623	12526	20	8E
0005435340349	12526	21	9D
0005435555383	12526	22	9E
0005434654598	12526	23	11D
0005434654607	12526	24	11F
0005435340355	12526	25	12E
0005435340354	12526	26	12F
0005435340359	12526	27	13A
0005434654627	12526	28	13E
0005434654702	12526	29	14E
0005434654557	12526	30	15A
0005434654743	12526	31	15D
0005434654534	12526	32	15E
0005435340352	12526	33	16D
0005435340351	12526	34	16E
0005434656548	12526	35	16F
0005435340348	12526	36	18A
0005434654550	12526	37	18C
0005434656547	12526	38	18E
0005434654564	12526	39	19A
0005435340357	12526	40	20A
0005433719158	7427	1	1A
0005433716284	7427	2	1C
0005433716279	7427	3	1F
0005433716293	7427	4	2A
0005433722256	7427	5	2C
0005433719159	7427	6	2D
0005433716268	7427	7	2F
0005433716248	7427	8	3D
0005432078139	7427	9	3F
0005433716290	7427	10	4A
0005433716288	7427	11	4C
0005433716267	7427	12	4B
0005433716277	7427	13	4F
0005433716247	7427	14	5B
0005433690935	7427	15	5A
0005433716269	7427	16	5C
0005433716255	7427	17	5D
0005433716291	7427	18	6A
0005433716276	7427	19	5F
0005433716275	7427	20	6C
0005433722263	7427	21	6E
0005433688820	7427	22	6D
0005433722254	7427	23	6F
0005435266134	7427	24	7A
0005433716251	7427	25	7B
0005435266135	7427	26	7C
0005433716253	7427	27	7D
0005433722268	7427	28	7F
0005433688819	7427	29	7E
0005432078142	7427	30	8B
0005433716285	7427	31	8F
0005433716264	7427	32	9A
0005433656690	7427	33	9B
0005433722259	7427	34	9F
0005432078140	7427	35	10B
0005433716256	7427	36	10D
0005433716262	7427	37	10C
0005433656687	7427	38	11C
0005433716260	7427	39	11E
0005433716250	7427	40	11F
0005433722267	7427	41	12A
0005432078143	7427	42	12B
0005433719157	7427	43	12C
0005433716246	7427	44	12E
0005433722258	7427	45	12D
0005433719160	7427	46	13A
0005433716274	7427	47	12F
0005435266124	7427	48	13B
0005433716272	7427	49	13C
0005433716292	7427	50	13E
0005433722265	7427	51	13D
0005433716273	7427	52	13F
0005433656688	7427	53	14A
0005433716258	7427	54	14D
0005433716280	7427	55	14C
0005433716263	7427	56	14E
0005433722269	7427	57	15A
0005433716265	7427	58	14F
0005433716244	7427	59	15B
0005433716271	7427	60	15C
0005433716286	7427	61	15F
0005433716245	7427	62	15E
0005433689922	7427	63	16B
0005433716266	7427	64	16C
0005433722264	7427	65	16D
0005433722266	7427	66	16E
0005432078141	7427	67	17D
0005433689921	7427	68	17C
0005433716252	7427	69	18A
0005433722262	7427	70	18C
0005433722260	7427	71	18B
0005433716257	7427	72	19A
0005433716282	7427	73	19B
0005433716254	7427	74	19C
0005433716287	7427	75	19E
0005433722261	7427	76	20A
0005433656689	7427	77	20B
0005433716294	7427	78	20D
0005433690936	7427	79	20C
0005433716289	7427	80	21A
0005433716243	7427	81	21B
0005432078144	7427	82	21D
0005433716270	7427	83	21C
0005433722255	7427	84	21F
0005433716281	7427	85	22A
0005435266141	7427	86	22C
0005433716283	7427	87	22D
0005433716278	7427	88	22E
0005433716261	7427	89	23A
0005433716249	7427	90	22F
0005432078145	7427	91	23C
0005433722257	7427	92	23D
0005433716259	7427	93	23E
0005433715868	29210	1	1A
0005433715851	29210	2	1C
0005433715925	29210	3	1D
0005435266168	29210	4	2A
0005433685509	29210	5	2D
0005433715786	29210	6	2F
0005433715835	29210	7	3C
0005433715793	29210	8	3A
0005432428951	29210	9	3F
0005433715780	29210	10	3D
0005433715982	29210	11	4C
0005433715790	29210	12	4B
0005433715875	29210	13	4D
0005433715987	29210	14	4E
0005435266171	29210	15	4F
0005433715709	29210	16	5A
0005433715794	29210	17	5D
0005433722197	29210	18	5F
0005433685511	29210	19	6C
0005433716024	29210	20	6D
0005435266170	29210	21	6F
0005433715797	29210	22	7A
0005433715841	29210	23	7C
0005433715879	29210	24	7E
0005433715710	29210	25	8B
0005433656660	29210	26	9A
0005433685510	29210	27	9B
0005433656669	29210	28	9D
0005433719133	29210	29	9E
0005433715781	29210	30	10B
0005433715798	29210	31	10D
0005433656662	29210	32	10C
0005433715649	29210	33	10E
0005433715659	29210	34	11A
0005433715959	29210	35	11E
0005433656667	29210	36	12A
0005433715791	29210	37	12B
0005433722168	29210	38	13B
0005433715660	29210	39	13F
0005433715836	29210	40	14C
0005433722188	29210	41	14D
0005433715700	29210	42	14F
0005435266169	29210	43	15B
0005433719132	29210	44	15A
0005433715983	29210	45	15D
0005433715921	29210	46	15F
0005433715862	29210	47	15E
0005433656661	29210	48	16B
0005433656650	29210	49	16A
0005433715772	29210	50	16C
0005433719131	29210	51	16D
0005433722189	29210	52	16E
0005435266172	29210	53	17A
0005432428949	29210	54	16F
0005433722190	29210	55	17B
0005433715648	29210	56	17C
0005432428950	29210	57	17E
0005433715775	29210	58	17F
0005433722177	29210	59	19A
0005433715727	29210	60	18F
0005433715863	29210	61	19C
0005432428948	29210	62	20A
0005433715880	29210	63	20B
0005433715984	29210	64	20D
0005433715869	29210	65	20C
0005433715647	29210	66	21C
0005433715792	29210	67	22A
0005433715872	29210	68	22C
0005433715773	29210	69	22D
0005433715782	29210	70	22E
0005433722198	29210	71	22F
0005432006779	29210	72	23B
0005434095365	8675	1	1D
0005434143736	8675	2	2D
0005434143731	8675	3	2F
0005434182172	8675	4	3A
0005434182139	8675	5	3C
0005434095358	8675	6	3D
0005434182119	8675	7	3F
0005434182136	8675	8	4C
0005434143739	8675	9	4E
0005434095361	8675	10	5A
0005434184658	8675	11	5D
0005434182170	8675	12	5E
0005434143737	8675	13	7D
0005434095363	8675	14	8A
0005434184657	8675	15	8D
0005434095364	8675	16	9A
0005434095370	8675	17	9F
0005434143738	8675	18	10A
0005434182180	8675	19	10C
0005434095360	8675	20	10E
0005434182120	8675	21	11C
0005434182184	8675	22	11E
0005434143733	8675	23	12C
0005434184667	8675	24	13A
0005434182146	8675	25	13F
0005434182179	8675	26	14C
0005434095366	8675	27	14F
0005434095369	8675	28	15C
0005434095367	8675	29	15F
0005434143732	8675	30	16A
0005434182101	8675	31	16C
0005434095357	8675	32	16D
0005434143735	8675	33	16F
0005434143734	8675	34	17D
0005434182133	8675	35	18C
0005434095359	8675	36	18D
0005434184652	8675	37	18E
0005434095368	8675	38	18F
0005434095362	8675	39	19D
0005434182100	8675	40	19F
0005434143740	8675	41	20A
0005434182178	8675	42	20F
0005434095226	11624	1	1D
0005434095210	11624	2	1F
0005434095227	11624	3	2C
0005434183590	11624	4	2D
0005434182265	11624	5	3F
0005434184676	11624	6	4E
0005434095228	11624	7	5F
0005434182264	11624	8	6C
0005434095297	11624	9	7A
0005434182256	11624	10	7D
0005434095233	11624	11	7E
0005434182263	11624	12	9C
0005434182254	11624	13	9D
0005434095256	11624	14	10A
0005434182257	11624	15	10D
0005434095211	11624	16	12C
0005434182255	11624	17	13C
0005434182259	11624	18	13D
0005434095273	11624	19	13F
0005434095212	11624	20	14C
0005434326266	11624	21	14D
0005434182258	11624	22	14E
0005434095213	11624	23	14F
0005434095248	11624	24	15C
0005434184675	11624	25	16D
0005434095243	11624	26	16E
0005434326267	11624	27	16F
0005434182262	11624	28	17C
0005434326271	11624	29	17F
0005434182253	11624	30	18C
0005434095242	11624	31	18E
0005434095247	11624	32	19A
0005434095148	11624	33	19D
0005434182260	11624	34	19E
0005434182261	11624	35	20C
0005434326270	11624	36	20F
0005433397854	1445	1	1A
0005432906523	1445	2	1C
0005433397938	1445	3	1F
0005433397968	1445	4	2A
0005433398033	1445	5	2C
0005433398035	1445	6	2D
0005435732393	1445	7	2F
0005433397899	1445	8	3A
0005433397813	1445	9	3C
0005433397974	1445	10	3D
0005433456996	1445	11	3F
0005433398115	1445	12	4A
0005433397811	1445	13	4C
0005433398116	1445	14	4E
0005433398023	1445	15	5A
0005433397851	1445	16	5C
0005433397973	1445	17	5E
0005433398020	1445	18	5F
0005433456995	1445	19	6A
0005433397996	1445	20	6D
0005433397785	1445	21	6E
0005432297294	1445	22	6F
0005433397812	1445	23	7D
0005435732391	1445	24	7F
0005432297292	1445	25	8C
0005433397979	1445	26	8D
0005433397936	1445	27	9A
0005433398089	1445	28	9D
0005433397842	1445	29	9E
0005433397962	1445	30	9F
0005433397958	1445	31	10A
0005433398071	1445	32	10C
0005433397947	1445	33	10E
0005433397721	1445	34	10F
0005433397969	1445	35	11C
0005432906535	1445	36	11D
0005433397900	1445	37	12A
0005433397844	1445	38	12C
0005433397940	1445	39	12D
0005432906538	1445	40	12E
0005433398254	1445	41	12F
0005433397951	1445	42	13C
0005432906531	1445	43	13D
0005433397841	1445	44	13F
0005433397688	1445	45	14A
0005432297293	1445	46	14D
0005433398014	1445	47	14E
0005433398012	1445	48	14F
0005433397901	1445	49	15A
0005433397939	1445	50	15C
0005433397781	1445	51	15D
0005433398093	1445	52	15E
0005433398017	1445	53	15F
0005433397726	1445	54	16A
0005433397867	1445	55	16C
0005433397874	1445	56	16F
0005433397749	1445	57	17A
0005433397980	1445	58	17C
0005435732392	1445	59	17D
0005433397948	1445	60	17E
0005433398255	1445	61	17F
0005435732394	1445	62	18A
0005433397873	1445	63	18C
0005433398016	1445	64	18D
0005433456994	1445	65	18E
0005435732390	1445	66	18F
0005433398094	1445	67	19A
0005432906522	1445	68	19D
0005432906540	1445	69	19F
0005432906539	1445	70	20C
0005433397819	1445	71	20D
0005433397959	1445	72	20F
0005433398371	19271	1	1A
0005433398325	19271	2	1C
0005433398330	19271	3	1D
0005432906550	19271	4	2A
0005433398360	19271	5	2D
0005433398347	19271	6	3A
0005433398353	19271	7	3F
0005433398324	19271	8	4A
0005433398372	19271	9	4C
0005433398344	19271	10	4D
0005433398341	19271	11	4F
0005433398339	19271	12	5F
0005433398363	19271	13	6A
0005433398334	19271	14	6C
0005433398327	19271	15	7A
0005433398357	19271	16	7C
0005433398328	19271	17	7D
0005433398335	19271	18	7E
0005433398361	19271	19	7F
0005433398346	19271	20	8A
0005433398342	19271	21	8C
0005433398326	19271	22	8D
0005435732308	19271	23	8E
0005433398338	19271	24	8F
0005433398366	19271	25	9A
0005433398340	19271	26	9C
0005435732309	19271	27	9F
0005433398322	19271	28	10A
0005435732316	19271	29	10D
0005433398348	19271	30	10F
0005433398370	19271	31	11A
0005435732310	19271	32	11D
0005433398367	19271	33	11C
0005433398358	19271	34	11E
0005433398336	19271	35	11F
0005433398345	19271	36	12A
0005435732297	19271	37	12D
0005433398343	19271	38	12E
0005433398362	19271	39	12F
0005433398351	19271	40	13D
0005435732312	19271	41	13E
0005435732307	19271	42	13F
0005433398368	19271	43	14A
0005435732296	19271	44	14C
0005433456970	19271	45	14D
0005433398352	19271	46	14E
0005433398349	19271	47	15C
0005433398355	19271	48	15D
0005433398332	19271	49	15E
0005435732295	19271	50	16A
0005433398323	19271	51	16D
0005433398364	19271	52	17A
0005433398333	19271	53	17C
0005433456958	19271	54	17E
0005433398350	19271	55	17F
0005433398331	19271	56	18A
0005433398365	19271	57	18C
0005432906549	19271	58	18E
0005433398356	19271	59	18F
0005433398329	19271	60	19D
0005433398359	19271	61	19E
0005433398354	19271	62	19F
0005433398337	19271	63	20A
0005433398369	19271	64	20E
0005432906551	19271	65	20F
0005434443682	17340	1	1A
0005434443715	17340	2	1B
0005434443664	17340	3	1C
0005434443609	17340	4	2A
0005434443685	17340	5	2D
0005434443640	17340	6	3A
0005434443686	17340	7	3C
0005434443652	17340	8	3D
0005434443662	17340	9	4A
0005434443619	17340	10	4D
0005434443642	17340	11	5C
0005434443610	17340	12	6B
0005434443643	17340	13	6D
0005434443620	17340	14	7A
0005434443613	17340	15	7B
0005434443621	17340	16	7D
0005434443736	17340	17	18A
0005434443691	17340	18	18D
0005434443653	17340	19	20C
0005434443656	17340	20	21B
0005434443646	17340	21	21C
0005434443612	17340	22	21D
0005434443661	17340	23	22B
0005434443611	17340	24	22D
0005434443618	17340	25	23A
0005434443788	20577	1	1A
0005434443800	20577	2	1D
0005434443796	20577	3	3C
0005434443787	20577	4	3D
0005434443803	20577	5	4B
0005434443789	20577	6	4A
0005434443798	20577	7	6C
0005434443801	20577	8	7A
0005434443799	20577	9	7C
0005434443795	20577	10	7D
0005434443804	20577	11	18A
0005434443792	20577	12	18C
0005434443797	20577	13	18D
0005434443794	20577	14	19A
0005434443802	20577	15	19B
0005434443791	20577	16	21C
0005434443790	20577	17	22A
0005434443793	20577	18	22B
0005435377581	7245	1	3B
0005434954631	7245	2	4B
0005434954633	7245	3	5B
0005435377579	7245	4	6A
0005434954632	7245	5	6B
0005434954596	28317	1	1A
0005434954599	28317	2	1B
0005435377594	28317	3	2A
0005434954586	28317	4	2B
0005435377593	28317	5	3A
0005434954587	28317	6	4A
0005434954597	28317	7	4B
0005434954595	28317	8	5A
0005434954608	28317	9	5B
0005434954590	28317	10	6A
0005435377595	28317	11	6B
0005434351765	4487	1	1A
0005434351766	4487	2	1C
0005434351776	4487	3	2B
0005435893640	4487	4	2D
0005434351772	4487	5	3C
0005435893621	4487	6	4A
0005434351768	4487	7	4C
0005434351767	4487	8	6B
0005435893632	4487	9	6C
0005434351770	4487	10	7B
0005434351774	4487	11	7C
0005434351775	4487	12	18A
0005434351769	4487	13	18C
0005434183573	4487	14	19C
0005434351777	4487	15	19D
0005434183580	4487	16	20C
0005434351771	4487	17	20D
0005435893622	4487	18	21A
0005434351773	4487	19	23A
0005434351676	29646	1	1A
0005434351622	29646	2	2B
0005435893676	29646	3	2D
0005434351674	29646	4	3B
0005434351631	29646	5	3C
0005434351642	29646	6	3D
0005434351664	29646	7	4B
0005435893675	29646	8	4C
0005434351606	29646	9	4D
0005435893673	29646	10	5B
0005434351646	29646	11	5D
0005434351662	29646	12	6B
0005434351719	29646	13	6C
0005434351685	29646	14	7D
0005435893677	29646	15	18A
0005434351699	29646	16	18C
0005434351669	29646	17	19A
0005435893671	29646	18	19C
0005434351687	29646	19	20B
0005434351660	29646	20	20C
0005435893674	29646	21	20D
0005434351675	29646	22	21A
0005434351658	29646	23	21B
0005434351630	29646	24	22A
0005434351661	29646	25	22B
0005435893672	29646	26	22C
0005434351641	29646	27	22D
0005433342864	1062	1	1A
0005433342606	1062	2	1C
0005435545787	1062	3	1H
0005433342818	1062	4	1G
0005433342786	1062	5	2B
0005433343138	1062	6	2F
0005433343093	1062	7	2C
0005433342982	1062	8	3B
0005433342498	1062	9	3G
0005435092133	1062	10	3H
0005433342815	1062	11	4A
0005433342950	1062	12	4C
0005435545786	1062	13	4G
0005433462760	1062	14	4F
0005433342861	1062	15	5A
0005435545789	1062	16	5B
0005433342573	1062	17	5C
0005433342427	1062	18	5G
0005433342592	1062	19	9B
0005433159302	1062	20	9A
0005433342922	1062	21	9G
0005433342793	1062	22	11A
0005433342719	1062	23	9H
0005433159314	1062	24	11B
0005433342890	1062	25	11E
0005433342789	1062	26	11D
0005433342817	1062	27	12A
0005433342954	1062	28	12D
0005433342465	1062	29	12E
0005433342408	1062	30	12G
0005433343059	1062	31	12F
0005433342875	1062	32	13B
0005433342537	1062	33	13F
0005435092136	1062	34	13E
0005433342428	1062	35	13G
0005433342307	1062	36	13H
0005433269706	1062	37	14B
0005433342556	1062	38	14A
0005435092129	1062	39	14D
0005435092138	1062	40	14F
0005433342863	1062	41	14G
0005435092139	1062	42	15A
0005433342819	1062	43	14H
0005433343157	1062	44	15B
0005433342571	1062	45	15E
0005433342505	1062	46	15D
0005433342909	1062	47	15F
0005433342842	1062	48	16D
0005433342746	1062	49	16B
0005433342649	1062	50	16F
0005433342750	1062	51	16E
0005433342607	1062	52	16H
0005433342608	1062	53	17D
0005433342417	1062	54	17B
0005433342860	1062	55	17E
0005433343015	1062	56	17F
0005433343045	1062	57	18A
0005435092135	1062	58	17H
0005433342938	1062	59	18B
0005433342598	1062	60	18E
0005433342368	1062	61	18F
0005433343181	1062	62	18H
0005433159316	1062	63	19B
0005433343025	1062	64	19A
0005433342912	1062	65	19E
0005433159303	1062	66	19H
0005433343162	1062	67	20B
0005433342555	1062	68	20E
0005433343102	1062	69	20F
0005433342813	1062	70	20G
0005433343103	1062	71	21B
0005433342788	1062	72	21E
0005433342962	1062	73	21G
0005433343021	1062	74	21F
0005433342536	1062	75	21H
0005433342862	1062	76	22A
0005433343004	1062	77	22D
0005433158129	1062	78	22E
0005433342956	1062	79	22G
0005433159315	1062	80	22F
0005433343017	1062	81	22H
0005433158130	1062	82	23B
0005433342829	1062	83	23A
0005433342816	1062	84	23E
0005434445258	1062	85	23F
0005433342516	1062	86	23H
0005433158124	1062	87	24B
0005435092137	1062	88	24H
0005435092128	1062	89	25E
0005432293222	1062	90	27A
0005433343044	1062	91	27D
0005435545788	1062	92	27G
0005433342658	1062	93	28A
0005435092134	1062	94	27H
0005433342908	1062	95	28B
0005433343022	1062	96	28H
0005435092130	1062	97	29B
0005435545785	1062	98	29A
0005433342935	1062	99	29D
0005433342585	1062	100	29E
0005433342367	1062	101	29G
0005433158125	1062	102	29H
0005433342844	1062	103	30A
0005433342646	1062	104	30D
0005433342784	1062	105	30B
0005433269687	1062	106	30F
0005433269700	1062	107	30E
0005433342689	1062	108	30G
0005432293224	1062	109	31D
0005433462759	1062	110	31B
0005433463914	1062	111	31E
0005433342569	1062	112	31H
0005435092132	1062	113	31G
0005433269688	1062	114	32A
0005435545790	1062	115	32B
0005433342974	1062	116	32D
0005433269721	1062	117	32F
0005434445259	1062	118	32H
0005433342941	1062	119	32G
0005433342623	1062	120	33A
0005433342936	1062	121	33D
0005433343295	1062	122	33B
0005433342572	1062	123	33E
0005433342670	1062	124	33F
0005433342843	1062	125	34A
0005433342854	1062	126	34D
0005433342661	1062	127	34E
0005433342409	1062	128	34H
0005435092131	1062	129	35B
0005433342913	1062	130	35E
0005433342957	1062	131	35D
0005433343066	1062	132	35F
0005433342883	1062	133	36A
0005435545791	1062	134	35H
0005433342225	1062	135	36B
0005433342605	1062	136	36D
0005433343035	1062	137	36F
0005433342574	1062	138	36H
0005433342436	1062	139	36G
0005433342973	1062	140	37A
0005433342688	1062	141	37B
0005433342437	1062	142	37D
0005433343154	1062	143	37F
0005433342454	1062	144	37H
0005433342687	1062	145	37G
0005433463913	1062	146	38B
0005433342975	1062	147	38E
0005433342655	1062	148	38F
0005433269720	1062	149	38G
0005432293223	1062	150	39D
0005433343274	1062	151	39E
0005435092009	17075	1	1B
0005433343716	17075	2	1F
0005434445241	17075	3	1H
0005435508339	17075	4	1G
0005433269749	17075	5	2B
0005433343713	17075	6	2F
0005433343623	17075	7	2G
0005433343650	17075	8	3A
0005433343660	17075	9	2H
0005433343663	17075	10	3B
0005435508315	17075	11	3C
0005433343697	17075	12	3H
0005433343690	17075	13	3G
0005433343649	17075	14	4A
0005433343670	17075	15	4C
0005435092012	17075	16	5A
0005433343645	17075	17	4H
0005433343638	17075	18	5C
0005435092070	17075	19	5F
0005433159324	17075	20	9B
0005433343700	17075	21	9G
0005433343702	17075	22	9H
0005433343707	17075	23	11B
0005433343679	17075	24	11E
0005433343676	17075	25	11D
0005433343684	17075	26	11F
0005433343641	17075	27	11H
0005433343681	17075	28	11G
0005433343651	17075	29	12B
0005433343680	17075	30	12A
0005433343629	17075	31	12D
0005433343654	17075	32	12H
0005433343696	17075	33	13D
0005433343710	17075	34	13E
0005433269750	17075	35	14E
0005433343644	17075	36	14H
0005435508324	17075	37	14G
0005433343643	17075	38	15A
0005433343687	17075	39	15B
0005433343658	17075	40	15H
0005433343632	17075	41	16A
0005433343648	17075	42	16D
0005433343698	17075	43	16B
0005433343665	17075	44	16E
0005433343671	17075	45	16G
0005433343693	17075	46	17A
0005435092033	17075	47	17D
0005433343708	17075	48	17F
0005435508337	17075	49	17H
0005433343625	17075	50	18B
0005435508344	17075	51	18E
0005433343621	17075	52	18G
0005435508348	17075	53	19A
0005433159326	17075	54	18H
0005433343709	17075	55	19D
0005435092051	17075	56	19F
0005433343657	17075	57	19E
0005433343653	17075	58	19H
0005433343705	17075	59	20E
0005435508347	17075	60	20D
0005433343677	17075	61	20F
0005435508317	17075	62	20G
0005433343627	17075	63	21A
0005433343628	17075	64	21B
0005435508345	17075	65	21F
0005434445242	17075	66	21E
0005433343711	17075	67	21G
0005435092034	17075	68	22A
0005433343634	17075	69	22E
0005433343618	17075	70	22B
0005433343636	17075	71	22F
0005433343712	17075	72	23B
0005433343655	17075	73	23E
0005433343703	17075	74	23G
0005433343667	17075	75	24B
0005433343617	17075	76	24A
0005435092043	17075	77	24F
0005433343695	17075	78	24E
0005433343631	17075	79	24G
0005433343624	17075	80	25D
0005434445229	17075	81	25E
0005433269753	17075	82	27A
0005433343692	17075	83	25F
0005433343699	17075	84	27B
0005433343706	17075	85	27F
0005435508350	17075	86	27E
0005433343664	17075	87	27G
0005433343694	17075	88	28B
0005433269751	17075	89	28A
0005433343656	17075	90	28E
0005433343683	17075	91	28D
0005433343639	17075	92	28F
0005433343672	17075	93	28H
0005435092050	17075	94	28G
0005433343637	17075	95	29D
0005433343673	17075	96	29B
0005435508316	17075	97	29F
0005433343678	17075	98	29H
0005433343669	17075	99	29G
0005433343668	17075	100	30B
0005433343619	17075	101	30D
0005435092003	17075	102	30H
0005433343642	17075	103	31D
0005433343647	17075	104	31F
0005433343661	17075	105	31E
0005433269752	17075	106	31G
0005433269748	17075	107	32A
0005433343662	17075	108	32F
0005433343622	17075	109	32G
0005435092094	17075	110	33B
0005433343675	17075	111	33A
0005433343659	17075	112	33E
0005433343646	17075	113	33F
0005433343691	17075	114	33H
0005433343704	17075	115	34A
0005433343688	17075	116	34D
0005435092066	17075	117	34B
0005433343674	17075	118	34E
0005433343630	17075	119	34G
0005433343652	17075	120	34H
0005435508340	17075	121	35D
0005435092081	17075	122	35G
0005433343635	17075	123	36D
0005433343717	17075	124	36F
0005433343682	17075	125	36E
0005433343633	17075	126	37A
0005433343620	17075	127	36H
0005433343626	17075	128	37B
0005433343715	17075	129	37E
0005433343701	17075	130	37D
0005433343685	17075	131	37F
0005433343686	17075	132	38A
0005433343714	17075	133	38B
0005433343689	17075	134	38E
0005433343640	17075	135	38D
0005433343666	17075	136	38H
0005433159325	17075	137	39D
0005433159327	17075	138	39F
0005432390204	1350	1	1C
0005432390215	1350	2	2F
0005432851908	1350	3	2D
0005432851922	1350	4	3A
0005432390192	1350	5	3D
0005432392008	1350	6	3F
0005432392016	1350	7	4C
0005432390213	1350	8	4A
0005432390199	1350	9	4F
0005432390198	1350	10	5C
0005432390196	1350	11	5A
0005432390189	1350	12	5F
0005432851883	1350	13	5D
0005432390193	1350	14	6B
0005432390208	1350	15	6C
0005432390188	1350	16	7A
0005432390190	1350	17	6F
0005432390212	1350	18	7D
0005432851899	1350	19	8A
0005432392017	1350	20	7F
0005432390191	1350	21	8B
0005432390194	1350	22	8D
0005432390187	1350	23	8F
0005432390210	1350	24	9A
0005432390211	1350	25	9C
0005432390200	1350	26	9E
0005432851884	1350	27	10B
0005432851906	1350	28	10A
0005432851907	1350	29	10C
0005432392013	1350	30	10D
0005432392011	1350	31	10F
0005432851885	1350	32	11D
0005432390184	1350	33	11C
0005432392012	1350	34	12C
0005432392007	1350	35	12E
0005432851897	1350	36	12D
0005432851923	1350	37	13C
0005432390207	1350	38	13B
0005432390203	1350	39	13F
0005432392015	1350	40	14B
0005432392014	1350	41	15B
0005432851890	1350	42	15A
0005432851924	1350	43	15E
0005432390209	1350	44	16A
0005432390183	1350	45	16B
0005432390195	1350	46	16D
0005432390185	1350	47	16F
0005432392009	1350	48	17B
0005432390216	1350	49	17F
0005432390205	1350	50	17E
0005432851946	1350	51	18A
0005432390197	1350	52	18E
0005432390186	1350	53	18F
0005432392010	1350	54	19C
0005432390217	1350	55	19B
0005432390206	1350	56	19F
0005432851909	1350	57	19E
0005432851896	1350	58	20A
0005432390214	1350	59	21A
0005432390202	1350	60	21C
0005432851905	1350	61	21D
0005432390201	1350	62	21F
0005434067318	12811	1	1A
0005434067385	12811	2	1C
0005433989756	12811	3	1D
0005434067448	12811	4	2A
0005434067445	12811	5	2C
0005434067392	12811	6	2D
0005432159884	12811	7	2F
0005434067278	12811	8	3A
0005432433713	12811	9	3D
0005434067214	12811	10	3C
0005434067228	12811	11	3F
0005432433714	12811	12	4B
0005434067408	12811	13	4A
0005434067240	12811	14	4C
0005434067424	12811	15	4F
0005434067447	12811	16	5A
0005433989749	12811	17	5C
0005434067309	12811	18	5B
0005434081754	12811	19	5D
0005434067493	12811	20	5E
0005433989757	12811	21	6A
0005434026700	12811	22	5F
0005434081854	12811	23	6C
0005432433711	12811	24	6B
0005434067390	12811	25	6E
0005434067277	12811	26	6D
0005434067229	12811	27	6F
0005433812914	12811	28	7B
0005434081894	12811	29	7C
0005434081753	12811	30	7E
0005434081893	12811	31	7D
0005434081835	12811	32	8A
0005432433710	12811	33	8B
0005434067259	12811	34	8C
0005434067255	12811	35	8E
0005434026690	12811	36	8D
0005434067317	12811	37	9B
0005434067571	12811	38	9E
0005434067423	12811	39	9D
0005434067416	12811	40	9F
0005434067232	12811	41	10B
0005434081904	12811	42	10C
0005434081731	12811	43	10E
0005434067444	12811	44	11A
0005434067395	12811	45	11C
0005434067038	12811	46	11D
0005433989754	12811	47	11F
0005434067247	12811	48	11E
0005434067176	12811	49	12A
0005434067596	12811	50	12B
0005434067334	12811	51	12C
0005434067297	12811	52	12E
0005434067094	12811	53	12F
0005434067365	12811	54	13A
0005434081914	12811	55	13C
0005434067007	12811	56	13D
0005434067037	12811	57	13E
0005432433712	12811	58	14A
0005434067155	12811	59	14C
0005434081913	12811	60	14F
0005434067195	12811	61	15B
0005434081768	12811	62	15A
0005434066762	12811	63	15C
0005434081806	12811	64	15D
0005432159887	12811	65	15E
0005434081732	12811	66	16A
0005432161165	12811	67	15F
0005432159885	12811	68	16B
0005434026695	12811	69	16C
0005432433709	12811	70	16D
0005434067594	12811	71	16E
0005434067145	12811	72	17A
0005434081810	12811	73	17B
0005434067245	12811	74	17C
0005434067177	12811	75	17D
0005434067415	12811	76	17E
0005433989753	12811	77	18A
0005434081926	12811	78	17F
0005434067085	12811	79	18B
0005434067489	12811	80	18C
0005432159883	12811	81	18F
0005434067322	12811	82	18E
0005434081755	12811	83	19A
0005434067397	12811	84	19C
0005433989748	12811	85	19E
0005434067321	12811	86	19D
0005434081771	12811	87	19F
0005433812915	12811	88	20A
0005434081901	12811	89	20B
0005434067384	12811	90	20C
0005434081861	12811	91	20E
0005434067407	12811	92	20F
0005434081798	12811	93	21A
0005434067252	12811	94	21C
0005432161166	12811	95	21B
0005434081839	12811	96	21D
0005434081859	12811	97	21E
0005434067276	12811	98	21F
0005434067484	12811	99	22B
0005434081860	12811	100	22C
0005432159886	12811	101	22E
0005434067115	12811	102	23A
0005434067104	12811	103	22F
0005434067296	12811	104	23B
0005434067431	12811	105	23C
0005434067497	12811	106	23D
0005434081892	12811	107	23F
0005434067351	12811	108	23E
0005434067899	30672	1	1A
0005434082033	30672	2	1C
0005434067953	30672	3	1D
0005434067903	30672	4	2A
0005434067927	30672	5	1F
0005434067960	30672	6	2C
0005434082014	30672	7	2D
0005432186886	30672	8	2F
0005434067958	30672	9	3D
0005434067944	30672	10	3C
0005432433682	30672	11	3F
0005434067946	30672	12	4A
0005434082016	30672	13	4C
0005434082032	30672	14	4B
0005434067961	30672	15	4E
0005434067932	30672	16	4F
0005434067963	30672	17	5A
0005434067950	30672	18	5C
0005434082030	30672	19	5B
0005434082026	30672	20	5D
0005434067921	30672	21	5E
0005434067906	30672	22	6A
0005434067931	30672	23	5F
0005432186887	30672	24	6C
0005434067894	30672	25	6B
0005434067910	30672	26	6F
0005434067945	30672	27	6E
0005434067920	30672	28	7A
0005434082031	30672	29	7B
0005434082013	30672	30	7C
0005434082018	30672	31	7E
0005434067948	30672	32	7D
0005434067942	30672	33	7F
0005434067893	30672	34	8A
0005434067904	30672	35	8B
0005434067952	30672	36	8C
0005434082025	30672	37	8E
0005434067949	30672	38	8D
0005434067936	30672	39	8F
0005434067908	30672	40	9B
0005434067954	30672	41	9D
0005434067912	30672	42	9C
0005434082017	30672	43	9F
0005434082010	30672	44	9E
0005434067900	30672	45	10B
0005434082023	30672	46	10D
0005434067913	30672	47	10C
0005434067917	30672	48	10E
0005434067902	30672	49	11A
0005434082019	30672	50	11B
0005432150238	30672	51	11C
0005434082021	30672	52	11E
0005434067933	30672	53	11D
0005433989797	30672	54	11F
0005434082008	30672	55	12A
0005434067892	30672	56	12B
0005434067919	30672	57	12C
0005434067941	30672	58	12D
0005434082009	30672	59	13A
0005434067934	30672	60	12F
0005432150233	30672	61	13B
0005434082028	30672	62	13C
0005432150237	30672	63	13E
0005432433654	30672	64	13F
0005434067940	30672	65	14B
0005434067897	30672	66	14A
0005434067918	30672	67	14C
0005432186891	30672	68	14D
0005434067915	30672	69	14F
0005432150235	30672	70	14E
0005434082027	30672	71	15A
0005434067896	30672	72	15C
0005434067938	30672	73	15B
0005434067923	30672	74	15D
0005434067909	30672	75	15F
0005434067911	30672	76	15E
0005433989796	30672	77	16A
0005434067937	30672	78	16B
0005432433685	30672	79	16C
0005432150234	30672	80	16D
0005432150236	30672	81	16F
0005432186890	30672	82	16E
0005434067924	30672	83	17A
0005434082024	30672	84	17C
0005434067930	30672	85	17D
0005434082022	30672	86	17F
0005434082029	30672	87	17E
0005434067895	30672	88	18A
0005434067907	30672	89	18B
0005433989795	30672	90	18D
0005434067939	30672	91	18E
0005434067916	30672	92	19A
0005434067957	30672	93	18F
0005434067922	30672	94	19C
0005434082011	30672	95	19B
0005434067955	30672	96	19D
0005434067935	30672	97	19E
0005434067925	30672	98	19F
0005434067959	30672	99	20A
0005434067928	30672	100	20C
0005432186888	30672	101	20B
0005434067901	30672	102	20D
0005434067898	30672	103	20F
0005434067956	30672	104	21A
0005434067905	30672	105	21B
0005432433655	30672	106	21D
0005434067926	30672	107	21C
0005434082015	30672	108	21E
0005432150239	30672	109	22A
0005434067914	30672	110	21F
0005433989794	30672	111	22B
0005432186889	30672	112	22C
0005434067962	30672	113	22D
0005432150232	30672	114	22F
0005434067947	30672	115	22E
0005434067951	30672	116	23A
0005434067943	30672	117	23B
0005434082012	30672	118	23C
0005434082020	30672	119	23D
0005434067929	30672	120	23F
0005434067964	30672	121	23E
0005435462139	5509	1	1B
0005435766610	5509	2	1F
0005435462482	5509	3	1C
0005435766571	5509	4	1G
0005435766589	5509	5	2A
0005435462404	5509	6	1H
0005434265112	5509	7	2B
0005435766570	5509	8	2F
0005435766583	5509	9	2C
0005435735159	5509	10	3A
0005435766585	5509	11	2H
0005435462345	5509	12	3B
0005435766613	5509	13	3C
0005435462317	5509	14	3G
0005435462234	5509	15	3F
0005435766582	5509	16	4A
0005435766588	5509	17	3H
0005434265089	5509	18	4B
0005435766604	5509	19	4C
0005435766614	5509	20	4G
0005435462233	5509	21	4F
0005435766612	5509	22	5A
0005435722069	5509	23	4H
0005435462260	5509	24	5C
0005435722070	5509	25	5G
0005435766577	5509	26	5F
0005435462220	5509	27	5H
0005432140498	5509	28	9A
0005435766561	5509	29	9G
0005434265116	5509	30	11A
0005435722068	5509	31	9H
0005435462423	5509	32	11B
0005435462273	5509	33	11G
0005434265006	5509	34	11F
0005435462393	5509	35	12B
0005435725628	5509	36	12A
0005435462192	5509	37	11H
0005435766600	5509	38	12E
0005435766578	5509	39	12H
0005433529300	5509	40	12G
0005435766568	5509	41	13A
0005435766569	5509	42	13E
0005434265113	5509	43	13D
0005435462254	5509	44	13G
0005434264878	5509	45	13F
0005433529303	5509	46	14A
0005434265088	5509	47	14D
0005435462337	5509	48	14H
0005435462259	5509	49	15B
0005435766574	5509	50	15E
0005434265099	5509	51	15D
0005435766598	5509	52	15G
0005435462263	5509	53	15F
0005435725627	5509	54	16B
0005435766599	5509	55	16A
0005434831136	5509	56	16E
0005435720827	5509	57	16D
0005435462368	5509	58	16G
0005435462278	5509	59	16F
0005433527289	5509	60	17A
0005434265009	5509	61	17D
0005435766572	5509	62	17E
0005435766608	5509	63	17F
0005434831131	5509	64	17H
0005435766576	5509	65	18B
0005435462512	5509	66	18F
0005432140495	5509	67	18E
0005435462185	5509	68	18G
0005435462349	5509	69	18H
0005432535797	5509	70	19B
0005435766597	5509	71	19A
0005435462303	5509	72	19D
0005434264952	5509	73	19G
0005434265127	5509	74	20A
0005432535796	5509	75	19H
0005434264879	5509	76	20B
0005435462256	5509	77	20E
0005434265015	5509	78	20G
0005435462483	5509	79	20F
0005434265035	5509	80	21A
0005432140494	5509	81	21B
0005435766606	5509	82	21E
0005434265028	5509	83	21F
0005435766596	5509	84	21H
0005434264951	5509	85	21G
0005432140493	5509	86	22A
0005435766586	5509	87	22B
0005435720828	5509	88	22F
0005435462357	5509	89	23B
0005435766579	5509	90	23A
0005434265042	5509	91	23D
0005434264976	5509	92	23G
0005432535828	5509	93	23H
0005435766607	5509	94	24B
0005435462162	5509	95	24E
0005433527291	5509	96	24D
0005432140496	5509	97	24F
0005434264998	5509	98	24H
0005435766609	5509	99	25E
0005435462372	5509	100	27A
0005433529301	5509	101	27F
0005435725626	5509	102	27G
0005435766594	5509	103	28A
0005434831130	5509	104	28B
0005435766564	5509	105	28E
0005433529302	5509	106	28D
0005435766573	5509	107	28F
0005432140497	5509	108	28H
0005434264970	5509	109	28G
0005435462257	5509	110	29A
0005432140500	5509	111	29E
0005435462348	5509	112	29D
0005435766595	5509	113	29G
0005435766591	5509	114	30A
0005435043282	5509	115	29H
0005435766575	5509	116	30F
0005434831141	5509	117	30G
0005434265016	5509	118	31A
0005435462312	5509	119	30H
0005435766592	5509	120	31B
0005435766563	5509	121	31E
0005435766581	5509	122	31H
0005432535812	5509	123	31G
0005435462377	5509	124	32A
0005435766601	5509	125	32B
0005434265126	5509	126	32E
0005435766566	5509	127	32D
0005434831129	5509	128	32G
0005435766567	5509	129	32H
0005435766584	5509	130	33A
0005435766605	5509	131	33B
0005433527292	5509	132	33E
0005435766565	5509	133	33D
0005434264975	5509	134	33F
0005435766611	5509	135	33G
0005435722071	5509	136	34A
0005435462369	5509	137	34D
0005434264877	5509	138	34F
0005434264950	5509	139	34E
0005434264989	5509	140	34G
0005435766587	5509	141	34H
0005435735162	5509	142	35A
0005435462163	5509	143	35D
0005435462193	5509	144	35B
0005435462318	5509	145	35F
0005435766593	5509	146	35E
0005435462458	5509	147	36A
0005435462243	5509	148	35H
0005435735161	5509	149	36D
0005435766580	5509	150	36F
0005435766590	5509	151	36G
0005435735160	5509	152	37A
0005433527290	5509	153	36H
0005434265087	5509	154	37B
0005435462292	5509	155	37E
0005434265041	5509	156	37D
0005435766603	5509	157	37G
0005435462235	5509	158	37H
0005435766562	5509	159	38D
0005435462384	5509	160	38B
0005434265010	5509	161	38G
0005435725625	5509	162	38F
0005432535802	5509	163	38H
0005432140499	5509	164	39E
0005435766602	5509	165	39D
0005435462394	5509	166	39F
0005434265299	13454	1	1A
0005435766199	13454	2	1B
0005435766223	13454	3	1F
0005435766163	13454	4	2A
0005434265291	13454	5	1H
0005435765825	13454	6	2B
0005435765822	13454	7	2C
0005435462676	13454	8	2H
0005435765993	13454	9	3B
0005435735126	13454	10	3F
0005435462669	13454	11	3C
0005435765952	13454	12	3G
0005435462674	13454	13	4A
0005435462672	13454	14	4B
0005435766276	13454	15	4F
0005435462671	13454	16	4H
0005435766102	13454	17	5B
0005434265284	13454	18	5F
0005435462648	13454	19	5C
0005435462666	13454	20	5G
0005435462654	13454	21	9A
0005434265301	13454	22	5H
0005432194537	13454	23	9H
0005435462661	13454	24	9B
0005435735113	13454	25	11B
0005434265285	13454	26	11D
0005435735102	13454	27	11E
0005435765708	13454	28	11H
0005435766169	13454	29	12A
0005435765994	13454	30	12B
0005435462647	13454	31	12D
0005434265289	13454	32	12G
0005435766006	13454	33	12F
0005435462662	13454	34	12H
0005434265295	13454	35	13B
0005435462667	13454	36	13A
0005432535863	13454	37	13D
0005435462649	13454	38	13E
0005435462651	13454	39	13G
0005434265305	13454	40	13F
0005435462680	13454	41	13H
0005434265309	13454	42	14B
0005435766316	13454	43	14A
0005435765969	13454	44	14D
0005435462677	13454	45	14F
0005435766289	13454	46	14E
0005435766198	13454	47	15A
0005435766036	13454	48	15E
0005432535864	13454	49	15D
0005435725587	13454	50	15H
0005435725554	13454	51	16B
0005434265287	13454	52	16A
0005434265308	13454	53	16D
0005435766027	13454	54	16E
0005435766323	13454	55	16G
0005435766140	13454	56	16F
0005435462665	13454	57	16H
0005435766175	13454	58	17B
0005434265302	13454	59	17A
0005435766056	13454	60	17D
0005434265290	13454	61	17F
0005435725588	13454	62	17E
0005435766061	13454	63	17G
0005435462668	13454	64	17H
0005435766037	13454	65	18A
0005434265296	13454	66	18B
0005435462655	13454	67	18G
0005435725589	13454	68	19A
0005435462678	13454	69	18H
0005435462682	13454	70	19D
0005435766120	13454	71	19F
0005435462675	13454	72	19E
0005435725583	13454	73	19H
0005435766176	13454	74	20A
0005435766122	13454	75	20D
0005432535862	13454	76	20B
0005434831179	13454	77	20E
0005435766134	13454	78	20G
0005435766236	13454	79	20F
0005435462663	13454	80	20H
0005435735119	13454	81	21B
0005435765821	13454	82	21A
0005434831182	13454	83	21H
0005434265292	13454	84	22D
0005434265298	13454	85	22E
0005435043291	13454	86	22F
0005434831181	13454	87	23E
0005435462683	13454	88	23D
0005435766250	13454	89	24A
0005435766060	13454	90	23H
0005432194534	13454	91	24B
0005435766062	13454	92	24D
0005435766280	13454	93	24F
0005435766282	13454	94	24G
0005435765815	13454	95	25D
0005435766063	13454	96	25F
0005435766193	13454	97	25E
0005435766192	13454	98	27A
0005434265294	13454	99	27D
0005435725549	13454	100	27B
0005434265286	13454	101	27E
0005432194536	13454	102	27F
0005435462646	13454	103	27G
0005435462673	13454	104	28A
0005435766115	13454	105	28B
0005435766275	13454	106	28G
0005435765978	13454	107	28F
0005435462657	13454	108	28H
0005434265307	13454	109	29D
0005435766185	13454	110	29B
0005432535865	13454	111	29F
0005435462652	13454	112	29E
0005435765824	13454	113	29G
0005435722050	13454	114	30D
0005435735118	13454	115	30F
0005435462645	13454	116	30E
0005435765951	13454	117	30G
0005434831180	13454	118	31A
0005435766121	13454	119	31E
0005434265293	13454	120	31D
0005435766032	13454	121	31F
0005435462679	13454	122	31G
0005434831178	13454	123	32A
0005435462664	13454	124	32B
0005435766249	13454	125	32E
0005435462659	13454	126	32D
0005435722049	13454	127	33A
0005432194535	13454	128	32H
0005435766201	13454	129	33D
0005435766291	13454	130	33B
0005435462658	13454	131	33E
0005435722048	13454	132	33G
0005434265303	13454	133	33H
0005435462681	13454	134	34A
0005435766290	13454	135	34D
0005435766170	13454	136	34F
0005435766048	13454	137	35A
0005435462660	13454	138	35D
0005435766007	13454	139	35F
0005435462670	13454	140	35G
0005435722046	13454	141	36A
0005435766244	13454	142	35H
0005435766194	13454	143	36B
0005435723040	13454	144	36E
0005434265306	13454	145	36F
0005434265288	13454	146	37A
0005435766243	13454	147	37B
0005435043290	13454	148	37D
0005435462656	13454	149	37G
0005435765977	13454	150	38A
0005435462650	13454	151	37H
0005434265297	13454	152	38E
0005434265300	13454	153	38F
0005434265304	13454	154	38H
0005435462653	13454	155	39F
0005435725584	13454	156	39E
0005434602885	18732	1	3A
0005434602892	18732	2	3B
0005434602893	18732	3	4B
0005434602899	18732	4	5B
0005434602887	18732	5	6A
0005434513592	18755	1	1B
0005434514981	18755	2	2A
0005434604876	18755	3	2B
0005434514982	18755	4	3A
0005434514980	18755	5	3B
0005434514983	18755	6	4A
0005434513594	18755	7	5A
0005434513593	18755	8	5B
0005434604891	18755	9	6A
0005434604894	18755	10	6B
0005434514958	19140	1	1B
0005434514959	19140	2	3B
0005434514960	19140	3	4B
0005434514961	19140	4	5B
0005432649360	25098	1	2A
0005432649362	25098	2	2F
0005435846275	25098	3	4C
0005432649370	25098	4	4E
0005432649405	25098	5	5F
0005435846272	25098	6	7F
0005435846276	25098	7	9C
0005432649364	25098	8	11A
0005432649388	25098	9	12A
0005432649401	25098	10	13F
0005435846270	25098	11	14C
0005432649361	25098	12	14F
0005432649377	25098	13	15F
0005435846273	25098	14	16A
0005432649367	25098	15	16E
0005435846271	25098	16	16F
0005432649378	25098	17	17C
0005435846274	25098	18	19C
0005432649387	25098	19	20D
0005432649402	25098	20	20F
0005433285154	1828	1	1A
0005433008151	1828	2	1C
0005433285197	1828	3	1D
0005433008455	1828	4	1F
0005433008659	1828	5	2A
0005433008452	1828	6	2D
0005433008630	1828	7	3A
0005433285210	1828	8	3D
0005433008432	1828	9	3F
0005433285193	1828	10	4A
0005433008441	1828	11	4C
0005433008553	1828	12	4D
0005433285194	1828	13	4E
0005433008552	1828	14	4F
0005433285269	1828	15	5A
0005433008415	1828	16	5C
0005432295895	1828	17	5D
0005433008499	1828	18	5E
0005433008392	1828	19	5F
0005433285255	1828	20	6A
0005433008640	1828	21	6C
0005433008646	1828	22	6D
0005433285254	1828	23	6F
0005433008444	1828	24	7A
0005433008578	1828	25	7C
0005433008521	1828	26	7E
0005433008635	1828	27	7F
0005433285112	1828	28	8A
0005433285205	1828	29	8C
0005433285271	1828	30	8D
0005433008150	1828	31	8E
0005433285276	1828	32	8F
0005433285306	1828	33	9A
0005433285164	1828	34	9D
0005433008332	1828	35	9E
0005433008453	1828	36	9F
0005433008528	1828	37	10A
0005433285211	1828	38	10C
0005433008498	1828	39	10D
0005433285044	1828	40	10E
0005433285282	1828	41	10F
0005433285270	1828	42	11A
0005433285160	1828	43	11C
0005433285110	1828	44	11D
0005433008641	1828	45	11E
0005433008449	1828	46	11F
0005433008587	1828	47	12A
0005433008535	1828	48	12D
0005433008391	1828	49	12E
0005433285274	1828	50	12F
0005433008799	1828	51	13A
0005433008549	1828	52	13C
0005433008800	1828	53	13D
0005433008582	1828	54	13E
0005433285281	1828	55	13F
0005433008331	1828	56	14A
0005433008433	1828	57	14C
0005433008556	1828	58	14E
0005433285163	1828	59	14F
0005433008610	1828	60	15A
0005433008348	1828	61	15C
0005432295894	1828	62	15D
0005433285273	1828	63	15E
0005433008801	1828	64	15F
0005433008554	1828	65	16A
0005433008487	1828	66	16C
0005433008434	1828	67	16D
0005433285260	1828	68	16E
0005433008454	1828	69	16F
0005433008488	1828	70	17A
0005433008473	1828	71	17C
0005433008511	1828	72	17D
0005433008456	1828	73	17F
0005433008345	1828	74	18A
0005433008232	1828	75	18C
0005433285153	1828	76	18D
0005433285307	1828	77	18E
0005433285220	1828	78	18F
0005433008520	1828	79	19A
0005433285201	1828	80	19C
0005433008645	1828	81	19D
0005432295896	1828	82	19E
0005433008318	1828	83	19F
0005433008448	1828	84	20A
0005433008650	1828	85	20C
0005433008527	1828	86	20D
0005433008638	1828	87	20E
0005433008534	1828	88	20F
0005433008850	22535	1	1A
0005433008852	22535	2	1F
0005433008844	22535	3	2A
0005433285485	22535	4	2D
0005433285466	22535	5	2F
0005433285486	22535	6	3A
0005433285470	22535	7	3C
0005433008871	22535	8	4A
0005433285463	22535	9	4C
0005433008856	22535	10	4D
0005433008883	22535	11	4E
0005433008874	22535	12	4F
0005433008851	22535	13	5A
0005433285475	22535	14	5D
0005433008864	22535	15	5E
0005433008857	22535	16	6A
0005433008877	22535	17	6D
0005433008847	22535	18	6E
0005433285487	22535	19	6F
0005433285483	22535	20	7A
0005433008884	22535	21	7D
0005433008879	22535	22	8A
0005433285477	22535	23	8C
0005433008870	22535	24	8D
0005433285461	22535	25	8E
0005433285476	22535	26	8F
0005433008848	22535	27	9A
0005433008876	22535	28	9D
0005433285472	22535	29	9E
0005433008873	22535	30	9F
0005433008853	22535	31	10A
0005433008888	22535	32	10C
0005433285473	22535	33	10D
0005433008846	22535	34	10E
0005433008881	22535	35	11A
0005433008868	22535	36	11C
0005433285471	22535	37	11E
0005433008887	22535	38	11F
0005433285481	22535	39	12A
0005433285469	22535	40	12C
0005433285460	22535	41	12D
0005433285484	22535	42	12F
0005433285480	22535	43	13A
0005433285456	22535	44	13C
0005433008863	22535	45	13D
0005433285467	22535	46	13E
0005433008845	22535	47	13F
0005433008859	22535	48	14A
0005433008880	22535	49	14D
0005433008854	22535	50	14E
0005433008866	22535	51	14F
0005433008867	22535	52	15A
0005433810517	22535	53	15C
0005433008882	22535	54	15D
0005433008872	22535	55	15E
0005433285468	22535	56	15F
0005433008886	22535	57	16A
0005433008889	22535	58	16C
0005433285457	22535	59	16D
0005433008849	22535	60	16E
0005433008885	22535	61	16F
0005433008861	22535	62	17A
0005433008865	22535	63	17C
0005433008878	22535	64	17D
0005433008858	22535	65	17E
0005433008860	22535	66	17F
0005433008875	22535	67	18A
0005433285459	22535	68	18C
0005433008869	22535	69	18D
0005433285465	22535	70	18F
0005433285458	22535	71	19C
0005433285474	22535	72	19D
0005433285482	22535	73	19E
0005433008862	22535	74	19F
0005433285462	22535	75	20A
0005433008855	22535	76	20C
0005433285479	22535	77	20D
0005433285464	22535	78	20E
0005433285478	22535	79	20F
0005432755069	12277	1	1A
0005432755061	12277	2	1C
0005432755070	12277	3	1F
0005434152795	12277	4	2A
0005432751526	12277	5	2F
0005432751504	12277	6	3C
0005432755064	12277	7	3F
0005432755065	12277	8	4A
0005432755050	12277	9	4D
0005434152801	12277	10	5A
0005432751510	12277	11	5C
0005432751505	12277	12	5E
0005434152799	12277	13	6E
0005434152800	12277	14	7A
0005432751532	12277	15	7E
0005432755053	12277	16	8D
0005432751517	12277	17	8E
0005432751506	12277	18	9A
0005432751511	12277	19	9C
0005434152797	12277	20	9E
0005434152793	12277	21	10C
0005432751503	12277	22	10D
0005434152794	12277	23	11F
0005432751509	12277	24	14A
0005432755052	12277	25	14C
0005434152802	12277	26	14F
0005432755055	12277	27	15F
0005432755044	12277	28	16C
0005434152796	12277	29	16E
0005432755049	12277	30	19C
0005434152798	12277	31	19D
0005432755043	12277	32	19E
0005432751520	12277	33	19F
0005432755072	12277	34	20F
0005432081546	5554	1	1C
0005432081549	5554	2	1A
0005433847068	5554	3	1F
0005433847054	5554	4	1D
0005433847080	5554	5	2C
0005432081547	5554	6	2D
0005434173488	5554	7	3C
0005433847061	5554	8	3A
0005432081548	5554	9	2F
0005432081550	5554	10	3D
0005433815410	5554	11	4A
0005433847069	5554	12	4D
0005434173502	5554	13	4C
0005433847055	5554	14	4F
0005433847091	5554	15	5C
0005435282537	5554	16	5A
0005435282432	5554	17	5D
0005433847072	5554	18	6B
0005435282376	5554	19	6A
0005432081552	5554	20	6D
0005435282487	5554	21	6C
0005433847046	5554	22	6E
0005433847039	5554	23	7A
0005433847082	5554	24	6F
0005433847058	5554	25	7C
0005433847078	5554	26	7B
0005433847088	5554	27	7E
0005435282536	5554	28	7D
0005433847049	5554	29	8A
0005433847066	5554	30	7F
0005433847092	5554	31	8B
0005435282385	5554	32	8F
0005433815412	5554	33	8E
0005433847038	5554	34	9B
0005433847086	5554	35	9C
0005433847063	5554	36	9E
0005433847097	5554	37	9D
0005435282455	5554	38	10A
0005433847041	5554	39	10C
0005433847073	5554	40	10B
0005433847043	5554	41	10D
0005432081551	5554	42	11A
0005433847083	5554	43	10F
0005433847053	5554	44	11E
0005435282440	5554	45	11D
0005434173514	5554	46	11C
0005433847050	5554	47	11F
0005433847084	5554	48	12A
0005433847074	5554	49	12D
0005433847079	5554	50	12C
0005433847056	5554	51	12B
0005433847064	5554	52	13A
0005433847040	5554	53	12F
0005435282443	5554	54	13B
0005433847077	5554	55	13E
0005435282398	5554	56	13D
0005433815413	5554	57	14A
0005433847057	5554	58	13F
0005433815411	5554	59	14E
0005435282479	5554	60	14C
0005433847076	5554	61	15B
0005433847065	5554	62	15A
0005433847071	5554	63	15F
0005433847060	5554	64	15E
0005433847059	5554	65	16A
0005433847089	5554	66	16C
0005435282478	5554	67	16B
0005433847096	5554	68	16F
0005433847085	5554	69	16E
0005433847047	5554	70	17B
0005433847081	5554	71	17A
0005433847094	5554	72	17D
0005433847045	5554	73	17C
0005433847062	5554	74	17E
0005435282375	5554	75	17F
0005433815409	5554	76	18D
0005433847070	5554	77	18C
0005435282384	5554	78	18E
0005433847048	5554	79	18F
0005433847042	5554	80	19C
0005433847051	5554	81	19B
0005433847090	5554	82	19D
0005433847044	5554	83	19F
0005433847095	5554	84	20C
0005434173508	5554	85	20B
0005435282488	5554	86	20A
0005433847087	5554	87	20D
0005433847052	5554	88	20F
0005433847067	5554	89	21B
0005433847075	5554	90	21A
0005434173503	5554	91	21C
0005433847093	5554	92	21E
0005435282334	5554	93	21D
0005434173500	5554	94	21F
0005435282659	13878	1	1C
0005433846057	13878	2	1A
0005433846503	13878	3	1F
0005433846655	13878	4	1D
0005433846676	13878	5	2C
0005433846581	13878	6	2A
0005433846777	13878	7	2D
0005435282646	13878	8	3C
0005433846504	13878	9	2F
0005433846492	13878	10	3F
0005435282648	13878	11	4D
0005433815361	13878	12	4C
0005435282660	13878	13	4F
0005433846739	13878	14	5C
0005433846740	13878	15	5A
0005433846450	13878	16	5F
0005435282658	13878	17	5D
0005433846809	13878	18	6B
0005433846707	13878	19	6A
0005435282663	13878	20	6F
0005433815371	13878	21	6E
0005435282671	13878	22	6D
0005435282666	13878	23	7B
0005433846501	13878	24	7A
0005433846822	13878	25	7C
0005435282665	13878	26	7E
0005433846558	13878	27	7D
0005433846490	13878	28	7F
0005435282664	13878	29	8B
0005433846494	13878	30	8A
0005433846781	13878	31	8D
0005435282668	13878	32	8C
0005433846362	13878	33	8E
0005433846577	13878	34	9B
0005433846672	13878	35	9A
0005433846764	13878	36	9C
0005435282670	13878	37	9E
0005434173545	13878	38	9D
0005433846472	13878	39	10A
0005435282667	13878	40	9F
0005435282655	13878	41	10B
0005433815372	13878	42	10D
0005435282672	13878	43	10F
0005433846502	13878	44	10E
0005433846559	13878	45	11B
0005435282650	13878	46	11F
0005433846573	13878	47	11E
0005433846056	13878	48	12A
0005433846608	13878	49	12D
0005434173544	13878	50	12C
0005433815369	13878	51	12F
0005435282656	13878	52	12E
0005433846449	13878	53	13A
0005433846623	13878	54	13C
0005433846484	13878	55	13B
0005433846778	13878	56	13E
0005433846518	13878	57	14A
0005433846532	13878	58	13F
0005433846517	13878	59	14B
0005433846776	13878	60	14E
0005435282657	13878	61	14D
0005435282669	13878	62	14F
0005435282654	13878	63	15B
0005433815370	13878	64	15A
0005434173546	13878	65	15C
0005435282649	13878	66	15E
0005433815373	13878	67	15D
0005432003720	13878	68	16C
0005435282652	13878	69	16B
0005433846625	13878	70	16D
0005433846347	13878	71	17A
0005433846561	13878	72	16F
0005433846624	13878	73	17C
0005435282661	13878	74	17B
0005433846782	13878	75	17D
0005433846569	13878	76	17F
0005433815364	13878	77	17E
0005433846750	13878	78	18A
0005435282647	13878	79	18D
0005433846575	13878	80	18C
0005433846452	13878	81	18F
0005432003721	13878	82	19A
0005434173543	13878	83	19C
0005433846562	13878	84	19B
0005433846538	13878	85	19F
0005435282645	13878	86	19E
0005435282662	13878	87	20B
0005435282653	13878	88	20D
0005433846692	13878	89	20C
0005433846671	13878	90	20F
0005433815368	13878	91	20E
0005433846810	13878	92	21A
0005433846533	13878	93	21D
0005433846607	13878	94	21C
0005433846711	13878	95	21B
0005433846650	13878	96	21E
0005435282651	13878	97	21F
0005435332321	7817	1	1A
0005434620724	7817	2	1B
0005435332290	7817	3	1D
0005434620716	7817	4	2A
0005435332287	7817	5	2B
0005435332305	7817	6	2D
0005434620718	7817	7	2C
0005435332314	7817	8	3A
0005432112530	7817	9	3B
0005435332322	7817	10	3C
0005434620720	7817	11	3D
0005435332316	7817	12	4A
0005435332301	7817	13	4B
0005434620710	7817	14	4C
0005435332283	7817	15	4D
0005435332332	7817	16	5B
0005434620715	7817	17	5C
0005434620713	7817	18	5D
0005434620726	7817	19	6A
0005434620712	7817	20	6B
0005434620711	7817	21	6C
0005434620706	7817	22	6D
0005435332323	7817	23	7A
0005434620714	7817	24	7B
0005435332330	7817	25	7C
0005434620723	7817	26	7D
0005435332313	7817	27	18A
0005434620708	7817	28	18B
0005435332306	7817	29	18C
0005435332315	7817	30	19A
0005434620721	7817	31	19B
0005435332320	7817	32	19C
0005435332294	7817	33	19D
0005435332288	7817	34	20A
0005434620717	7817	35	20B
0005435332311	7817	36	20C
0005435332293	7817	37	20D
0005432112529	7817	38	21A
0005434620707	7817	39	21B
0005434620709	7817	40	21C
0005434620725	7817	41	21D
0005434620719	7817	42	22A
0005435332285	7817	43	22C
0005435332302	7817	44	22B
0005434620722	7817	45	22D
0005435332312	7817	46	23A
0005435332317	7817	47	23B
0005434620393	32991	1	1B
0005435332397	32991	2	1D
0005435332393	32991	3	2B
0005435332402	32991	4	2C
0005434620507	32991	5	2D
0005434620508	32991	6	3A
0005435332399	32991	7	3D
0005435332401	32991	8	4B
0005435332391	32991	9	4D
0005435332398	32991	10	5A
0005434620609	32991	11	5B
0005434620619	32991	12	5D
0005435332392	32991	13	6A
0005434620488	32991	14	6B
0005434620580	32991	15	6C
0005434620570	32991	16	6D
0005434620550	32991	17	7A
0005435332396	32991	18	7D
0005434620539	32991	19	18A
0005434620451	32991	20	18B
0005434620549	32991	21	18C
0005435332400	32991	22	19A
0005435332395	32991	23	19B
0005434620461	32991	24	21A
0005434620585	32991	25	21B
0005434620591	32991	26	21C
0005434620517	32991	27	22D
0005435332394	32991	28	23B
0005435785574	4279	1	1C
0005435785561	4279	2	1D
0005435918663	4279	3	1F
0005435937345	4279	4	2A
0005434994078	4279	5	2D
0005435937358	4279	6	3A
0005434994079	4279	7	3D
0005435937344	4279	8	4A
0005435785553	4279	9	4C
0005435785566	4279	10	4D
0005435918641	4279	11	4F
0005435918660	4279	12	5A
0005435785562	4279	13	5C
0005434994077	4279	14	5D
0005435937364	4279	15	5F
0005435785558	4279	16	6A
0005435785572	4279	17	6E
0005435787366	4279	18	7C
0005435785545	4279	19	7F
0005435918649	4279	20	8C
0005435937371	4279	21	8D
0005432190653	4279	22	8F
0005435785544	4279	23	9A
0005435785543	4279	24	9C
0005432190652	4279	25	9D
0005435785548	4279	26	9E
0005435937370	4279	27	9F
0005435785577	4279	28	10D
0005435785567	4279	29	10E
0005435785575	4279	30	10F
0005435785552	4279	31	11A
0005435785554	4279	32	11C
0005435787367	4279	33	11D
0005435785549	4279	34	11E
0005434994081	4279	35	11F
0005435785557	4279	36	12A
0005435937350	4279	37	12C
0005435785563	4279	38	12D
0005435785555	4279	39	12E
0005435785550	4279	40	13A
0005435785551	4279	41	13C
0005435937372	4279	42	13E
0005435785569	4279	43	14A
0005435785571	4279	44	14F
0005435785568	4279	45	15A
0005434994080	4279	46	15C
0005435785570	4279	47	15D
0005434994082	4279	48	15E
0005435918638	4279	49	16A
0005435785576	4279	50	16C
0005435785556	4279	51	16E
0005435785560	4279	52	16F
0005435918654	4279	53	17A
0005435918628	4279	54	17D
0005435785547	4279	55	17E
0005435918655	4279	56	17F
0005435785546	4279	57	18C
0005435918659	4279	58	18E
0005435785564	4279	59	18F
0005435937385	4279	60	19C
0005435785565	4279	61	19D
0005435785559	4279	62	19F
0005435937386	4279	63	20A
0005434994084	4279	64	20C
0005435785573	4279	65	20E
0005434994083	4279	66	20F
0005435785236	27300	1	1A
0005435785241	27300	2	1C
0005434993993	27300	3	1D
0005435785191	27300	4	1F
0005434993992	27300	5	2A
0005435785029	27300	6	2C
0005435785280	27300	7	2D
0005435918682	27300	8	3C
0005435787336	27300	9	3D
0005435785141	27300	10	4A
0005434994009	27300	11	4C
0005435787351	27300	12	4D
0005435785324	27300	13	4E
0005435785200	27300	14	5C
0005435918685	27300	15	5D
0005435785265	27300	16	5E
0005434993995	27300	17	5F
0005435785231	27300	18	6A
0005434993996	27300	19	6D
0005435787353	27300	20	6F
0005435785255	27300	21	8A
0005435787341	27300	22	8C
0005435785234	27300	23	8D
0005435918683	27300	24	9C
0005434994036	27300	25	9D
0005435785180	27300	26	9F
0005435785233	27300	27	10A
0005434994012	27300	28	10C
0005435787337	27300	29	10D
0005435785229	27300	30	10E
0005434993994	27300	31	10F
0005435785256	27300	32	11A
0005435785079	27300	33	11E
0005435784991	27300	34	11F
0005435785164	27300	35	12A
0005435785198	27300	36	12C
0005435785160	27300	37	12D
0005435787352	27300	38	12E
0005435785068	27300	39	12F
0005434993986	27300	40	13C
0005435785232	27300	41	13E
0005435785030	27300	42	13F
0005434994035	27300	43	14A
0005435785197	27300	44	14C
0005434994029	27300	45	14D
0005435785072	27300	46	14E
0005435785163	27300	47	14F
0005435785174	27300	48	15A
0005435918684	27300	49	15C
0005435785154	27300	50	15D
0005435785155	27300	51	15E
0005435785186	27300	52	16C
0005435937400	27300	53	16F
0005435785139	27300	54	17D
0005435785140	27300	55	17F
0005435787327	27300	56	18A
0005435785073	27300	57	18C
0005434994034	27300	58	18D
0005434993987	27300	59	18E
0005435785080	27300	60	18F
0005435785266	27300	61	19A
0005435785069	27300	62	19C
0005435785235	27300	63	19D
0005435785165	27300	64	19F
0005432195704	27300	65	20A
0005435937401	27300	66	20C
0005432146211	19864	1	6B
0005432146210	19864	2	20A
0005432146209	19864	3	20C
0005432460132	4741	1	1C
0005432460139	4741	2	1B
0005432460157	4741	3	1F
0005432170427	4741	4	1H
0005432460136	4741	5	1G
0005432567999	4741	6	2B
0005432568020	4741	7	2F
0005434082054	4741	8	2H
0005432460180	4741	9	2G
0005432460164	4741	10	3A
0005432567998	4741	11	3B
0005432460166	4741	12	3F
0005432460175	4741	13	4A
0005432567976	4741	14	3H
0005432567970	4741	15	4F
0005432568019	4741	16	4C
0005432170430	4741	17	4H
0005432460150	4741	18	5A
0005434082048	4741	19	5C
0005432567983	4741	20	5G
0005434082042	4741	21	5H
0005432567995	4741	22	9A
0005432460142	4741	23	9H
0005432460171	4741	24	9G
0005432170425	4741	25	11A
0005432460168	4741	26	11B
0005432567985	4741	27	11D
0005432567984	4741	28	11H
0005432568024	4741	29	12A
0005432567987	4741	30	12D
0005434082041	4741	31	12B
0005432460153	4741	32	12E
0005432567967	4741	33	12G
0005433452751	4741	34	12H
0005432460134	4741	35	13E
0005432568001	4741	36	13D
0005432460184	4741	37	13F
0005435840359	4741	38	13H
0005434082058	4741	39	14B
0005432460143	4741	40	14A
0005432460178	4741	41	14D
0005432186892	4741	42	14F
0005432568006	4741	43	14E
0005432460146	4741	44	14G
0005432170428	4741	45	15A
0005432568003	4741	46	14H
0005434082039	4741	47	15B
0005432567992	4741	48	15E
0005432460182	4741	49	15D
0005432568012	4741	50	15F
0005434082052	4741	51	15H
0005432460154	4741	52	15G
0005432568015	4741	53	16D
0005432460137	4741	54	16B
0005432567971	4741	55	16E
0005432567966	4741	56	16G
0005432460149	4741	57	16F
0005434082050	4741	58	16H
0005432567978	4741	59	17A
0005434082055	4741	60	17D
0005432460140	4741	61	17F
0005433452752	4741	62	17E
0005432567979	4741	63	17G
0005432567980	4741	64	18A
0005432571342	4741	65	18B
0005432567982	4741	66	18G
0005432460148	4741	67	18F
0005434082046	4741	68	18H
0005432460152	4741	69	19B
0005432568022	4741	70	19A
0005432567991	4741	71	19E
0005432460172	4741	72	19F
0005432567988	4741	73	19G
0005432568026	4741	74	20A
0005432460167	4741	75	19H
0005434082056	4741	76	20D
0005434082035	4741	77	20B
0005432567994	4741	78	20F
0005433726117	4741	79	20H
0005432571345	4741	80	20G
0005432460155	4741	81	21D
0005432571344	4741	82	21F
0005432567972	4741	83	21E
0005432567990	4741	84	21G
0005432460135	4741	85	21H
0005432567997	4741	86	22B
0005432460133	4741	87	22D
0005432568013	4741	88	22E
0005432170424	4741	89	22F
0005432567964	4741	90	22H
0005432460169	4741	91	23A
0005432460179	4741	92	23F
0005432460170	4741	93	23E
0005432567969	4741	94	23G
0005434082040	4741	95	24A
0005432460160	4741	96	23H
0005434082044	4741	97	24F
0005432568025	4741	98	24G
0005432568010	4741	99	24H
0005432460177	4741	100	25F
0005433451632	4741	101	27B
0005432568007	4741	102	27D
0005432170429	4741	103	27F
0005434082043	4741	104	27G
0005432567974	4741	105	27H
0005432460144	4741	106	28D
0005432567986	4741	107	28F
0005434082045	4741	108	28E
0005434082057	4741	109	28H
0005432186893	4741	110	28G
0005432460145	4741	111	29A
0005432568014	4741	112	29D
0005432460159	4741	113	29F
0005432567989	4741	114	29E
0005432460174	4741	115	29H
0005432460162	4741	116	29G
0005432460163	4741	117	30D
0005434082047	4741	118	30F
0005432567977	4741	119	30E
0005434082037	4741	120	30G
0005432567965	4741	121	31A
0005432460181	4741	122	30H
0005432568009	4741	123	31B
0005432568011	4741	124	31E
0005432568002	4741	125	31D
0005432567973	4741	126	31H
0005433726118	4741	127	31G
0005432567996	4741	128	32A
0005432460161	4741	129	32E
0005434082038	4741	130	32F
0005432460156	4741	131	32H
0005433451631	4741	132	32G
0005432460183	4741	133	33A
0005432567981	4741	134	33D
0005432170426	4741	135	33H
0005432567993	4741	136	33G
0005434082053	4741	137	34A
0005432460176	4741	138	34D
0005432568016	4741	139	34E
0005432571343	4741	140	34G
0005432460173	4741	141	34F
0005432567975	4741	142	34H
0005432568005	4741	143	35A
0005432568004	4741	144	35D
0005434082049	4741	145	35F
0005434082036	4741	146	35E
0005432568023	4741	147	36A
0005432460138	4741	148	35H
0005432568021	4741	149	36D
0005432460141	4741	150	36F
0005432568008	4741	151	36G
0005432568000	4741	152	36H
0005432460158	4741	153	37E
0005432460165	4741	154	37D
0005432568018	4741	155	37F
0005432567968	4741	156	37H
0005432568017	4741	157	37G
0005432460151	4741	158	38D
0005434082051	4741	159	38B
0005432460147	4741	160	38F
0005432568027	4741	161	38H
0005434082034	4741	162	39F
0005433726082	30537	1	1C
0005432459873	30537	2	1B
0005433452734	30537	3	1F
0005432459493	30537	4	1H
0005432459688	30537	5	1G
0005432459777	30537	6	2C
0005432567487	30537	7	2B
0005432459516	30537	8	2F
0005432567531	30537	9	2G
0005432567620	30537	10	3A
0005432459611	30537	11	3C
0005433726083	30537	12	3G
0005432567434	30537	13	4A
0005432567572	30537	14	3H
0005433726078	30537	15	4B
0005432459763	30537	16	4F
0005432567344	30537	17	4C
0005432459594	30537	18	4G
0005433726092	30537	19	4H
0005434081904	30537	20	5B
0005433726077	30537	21	5A
0005432460072	30537	22	5F
0005432459919	30537	23	5C
0005432571309	30537	24	5H
0005432459874	30537	25	9B
0005432459807	30537	26	9A
0005432567245	30537	27	9G
0005432567686	30537	28	11A
0005434081861	30537	29	9H
0005432459660	30537	30	11D
0005432161165	30537	31	11B
0005432567404	30537	32	11E
0005434081913	30537	33	11F
0005432567629	30537	34	11H
0005432213627	30537	35	12A
0005432567463	30537	36	12E
0005432459750	30537	37	12G
0005432459610	30537	38	12H
0005433454872	30537	39	13B
0005432459894	30537	40	13A
0005434081860	30537	41	13D
0005432459920	30537	42	13F
0005433726089	30537	43	13E
0005432459766	30537	44	13G
0005434081754	30537	45	14A
0005434081806	30537	46	13H
0005432459547	30537	47	14B
0005432567627	30537	48	14D
0005432459867	30537	49	14F
0005433726084	30537	50	14E
0005432459548	30537	51	14G
0005432567635	30537	52	15A
0005432567707	30537	53	15B
0005432567514	30537	54	15E
0005432460121	30537	55	15D
0005432567641	30537	56	15F
0005433726064	30537	57	15H
0005432571323	30537	58	15G
0005432567298	30537	59	16A
0005432459981	30537	60	16D
0005432567642	30537	61	16E
0005432459780	30537	62	16G
0005432571322	30537	63	16F
0005434081894	30537	64	16H
0005432567405	30537	65	17A
0005433726087	30537	66	17D
0005432567658	30537	67	17E
0005432567528	30537	68	17G
0005432567489	30537	69	17F
0005432459980	30537	70	17H
0005434081839	30537	71	18B
0005432567461	30537	72	18D
0005432567346	30537	73	18F
0005432161166	30537	74	18E
0005432571329	30537	75	18G
0005434081914	30537	76	19A
0005432459754	30537	77	18H
0005432571312	30537	78	19D
0005432567306	30537	79	19B
0005432571324	30537	80	19E
0005432567698	30537	81	19H
0005432459982	30537	82	19G
0005432567165	30537	83	20A
0005434081892	30537	84	20B
0005433452736	30537	85	20E
0005434081926	30537	86	20D
0005432571315	30537	87	20F
0005432567659	30537	88	20G
0005432567241	30537	89	21A
0005432459741	30537	90	20H
0005432459685	30537	91	21D
0005432459684	30537	92	21F
0005432567697	30537	93	21E
0005432459806	30537	94	21G
0005433452733	30537	95	22A
0005432567541	30537	96	22D
0005432459492	30537	97	22B
0005432459623	30537	98	22F
0005432459762	30537	99	22E
0005432567807	30537	100	22G
0005432567626	30537	101	22H
0005432459941	30537	102	23A
0005432567530	30537	103	23D
0005432459725	30537	104	23F
0005432571314	30537	105	23E
0005434081771	30537	106	23G
0005432459689	30537	107	24A
0005432567644	30537	108	24B
0005433726075	30537	109	24E
0005432213630	30537	110	24D
0005432567630	30537	111	24F
0005432567623	30537	112	24H
0005432567353	30537	113	24G
0005432459292	30537	114	25D
0005432459546	30537	115	27B
0005434081901	30537	116	27A
0005432567654	30537	117	27F
0005434081755	30537	118	27G
0005432459612	30537	119	28A
0005434081731	30537	120	27H
0005433726081	30537	121	28B
0005432567297	30537	122	28E
0005432459897	30537	123	28D
0005432567624	30537	124	28G
0005432459888	30537	125	29B
0005432459661	30537	126	29E
0005432567708	30537	127	29F
0005432567462	30537	128	29H
0005432459617	30537	129	30A
0005433726065	30537	130	30E
0005432567437	30537	131	30D
0005432571330	30537	132	30F
0005433726085	30537	133	30G
0005432567486	30537	134	30H
0005432459837	30537	135	31B
0005434081835	30537	136	31A
0005432567403	30537	137	31E
0005432567801	30537	138	31D
0005432459727	30537	139	31F
0005432213628	30537	140	31G
0005432567402	30537	141	31H
0005432459850	30537	142	32B
0005432459726	30537	143	32A
0005434081854	30537	144	32D
0005432567643	30537	145	32F
0005433726080	30537	146	32G
0005432459805	30537	147	33A
0005432567705	30537	148	33D
0005434081810	30537	149	33E
0005434081732	30537	150	33G
0005433726090	30537	151	33F
0005433726074	30537	152	33H
0005432567471	30537	153	34A
0005432459629	30537	154	34D
0005434081768	30537	155	34F
0005434081859	30537	156	34E
0005432459598	30537	157	34G
0005432460071	30537	158	35A
0005433726091	30537	159	34H
0005432459622	30537	160	35B
0005432459597	30537	161	35D
0005434081893	30537	162	35F
0005432459851	30537	163	35E
0005432459613	30537	164	35G
0005433726073	30537	165	36A
0005432213629	30537	166	35H
0005433452737	30537	167	36B
0005432459742	30537	168	36E
0005432567704	30537	169	37A
0005432459690	30537	170	36H
0005432459735	30537	171	37B
0005432567638	30537	172	37D
0005432459804	30537	173	37F
0005434081753	30537	174	37H
0005433454871	30537	175	38A
0005432567694	30537	176	38D
0005432567583	30537	177	38B
0005432567513	30537	178	38F
0005434081798	30537	179	38E
0005432567665	30537	180	38H
0005432571313	30537	181	38G
0005433726088	30537	182	39E
0005432459721	30537	183	39D
0005435722070	13579	1	1B
0005435722071	13579	2	2B
0005435720827	13579	3	3B
0005435722068	13579	4	4A
0005435720828	13579	5	4B
0005435722069	13579	6	6B
0005435722042	21167	1	1A
0005435722040	21167	2	4A
0005435722047	21167	3	4B
0005435722041	21167	4	5B
0005432295894	22803	1	7B
0005432295896	22803	2	21D
0005432295895	22803	3	22C
0005435508309	11102	1	1C
0005433343814	11102	2	1A
0005433343784	11102	3	1D
0005433343746	11102	4	2A
0005433343721	11102	5	1F
0005433343769	11102	6	2C
0005433343724	11102	7	2D
0005433343728	11102	8	2F
0005435097255	11102	9	3A
0005433343795	11102	10	3D
0005433343767	11102	11	3C
0005433343790	11102	12	3F
0005435380287	11102	13	4A
0005433343749	11102	14	4B
0005433343766	11102	15	4C
0005435508368	11102	16	4E
0005433343729	11102	17	4D
0005435508375	11102	18	5A
0005433343802	11102	19	4F
0005433343738	11102	20	5C
0005435097251	11102	21	5B
0005433343781	11102	22	5D
0005435097254	11102	23	5F
0005435508328	11102	24	5E
0005433343754	11102	25	6B
0005433343740	11102	26	6A
0005433343780	11102	27	6C
0005433343725	11102	28	6D
0005433343778	11102	29	6E
0005433343806	11102	30	6F
0005433343756	11102	31	7B
0005433343745	11102	32	7A
0005435508287	11102	33	7C
0005433343811	11102	34	7E
0005435097256	11102	35	7D
0005433343751	11102	36	7F
0005435508327	11102	37	8B
0005433343750	11102	38	8A
0005433343819	11102	39	8D
0005433343747	11102	40	8C
0005433343762	11102	41	8E
0005433343785	11102	42	9A
0005433343775	11102	43	8F
0005433343768	11102	44	9B
0005433343757	11102	45	9D
0005433343748	11102	46	9C
0005435097249	11102	47	9E
0005433343772	11102	48	10B
0005433343777	11102	49	9F
0005433343759	11102	50	10D
0005433343799	11102	51	10C
0005435508270	11102	52	10E
0005433343739	11102	53	11A
0005435508393	11102	54	11B
0005433343718	11102	55	11C
0005433343755	11102	56	11E
0005433343719	11102	57	11D
0005433343737	11102	58	11F
0005433343764	11102	59	12A
0005433343760	11102	60	12B
0005435529973	11102	61	12D
0005433343731	11102	62	12C
0005433343741	11102	63	12E
0005435097250	11102	64	13A
0005435508360	11102	65	12F
0005435097248	11102	66	13B
0005433343722	11102	67	13D
0005433343786	11102	68	13C
0005435380286	11102	69	13E
0005433343770	11102	70	14A
0005435508312	11102	71	13F
0005433343773	11102	72	14C
0005435097253	11102	73	14B
0005433343817	11102	74	14D
0005435508367	11102	75	14F
0005433343818	11102	76	14E
0005433343776	11102	77	15A
0005433343742	11102	78	15C
0005433343720	11102	79	15B
0005433343804	11102	80	15D
0005433343789	11102	81	15E
0005433343812	11102	82	15F
0005433343753	11102	83	16B
0005433343793	11102	84	16A
0005433343810	11102	85	16C
0005433343774	11102	86	16E
0005433343761	11102	87	16D
0005433343726	11102	88	17A
0005433343743	11102	89	16F
0005433343808	11102	90	17B
0005433343813	11102	91	17C
0005433343800	11102	92	17D
0005433343797	11102	93	17E
0005433343783	11102	94	18A
0005433343732	11102	95	17F
0005433343730	11102	96	18B
0005433343733	11102	97	18C
0005433343792	11102	98	18D
0005435508305	11102	99	18F
0005433343727	11102	100	18E
0005433343796	11102	101	19B
0005433343787	11102	102	19A
0005435508286	11102	103	19C
0005433343723	11102	104	19E
0005433343788	11102	105	19D
0005433343807	11102	106	19F
0005433343736	11102	107	20A
0005433343765	11102	108	20C
0005435097252	11102	109	20B
0005433343744	11102	110	20D
0005433343782	11102	111	20E
0005433343734	11102	112	20F
0005433343779	11102	113	21B
0005433343815	11102	114	21A
0005433343798	11102	115	21C
0005433343758	11102	116	21D
0005433343791	11102	117	21E
0005433343794	11102	118	22A
0005435508392	11102	119	21F
0005433343805	11102	120	22B
0005433343771	11102	121	22C
0005433343735	11102	122	22D
0005433343816	11102	123	22F
0005435097247	11102	124	22E
0005433343803	11102	125	23A
0005433343763	11102	126	23B
0005433343801	11102	127	23D
0005433343809	11102	128	23C
0005435508325	11102	129	23E
0005433343752	11102	130	23F
0005433342454	17109	1	1A
0005433342875	17109	2	1C
0005435545790	17109	3	1D
0005433342498	17109	4	2A
0005435545785	17109	5	1F
0005433342598	17109	6	2C
0005433342367	17109	7	2D
0005435097155	17109	8	3A
0005433343035	17109	9	2F
0005433342829	17109	10	3C
0005433342890	17109	11	3D
0005433342658	17109	12	3F
0005433342789	17109	13	4A
0005435545789	17109	14	4C
0005435545787	17109	15	4B
0005433342689	17109	16	4E
0005433342860	17109	17	4D
0005433342842	17109	18	4F
0005433342661	17109	19	5A
0005433343162	17109	20	5C
0005433342982	17109	21	5B
0005433342913	17109	22	5D
0005433342585	17109	23	5F
0005433342912	17109	24	5E
0005433342844	17109	25	6A
0005435380327	17109	26	6B
0005433343022	17109	27	6C
0005433342536	17109	28	6D
0005433342793	17109	29	6E
0005433342750	17109	30	7A
0005435380325	17109	31	6F
0005433342883	17109	32	7C
0005433342962	17109	33	7B
0005435097180	17109	34	7D
0005433342784	17109	35	7F
0005433342688	17109	36	7E
0005433343102	17109	37	8B
0005433343066	17109	38	8A
0005433343093	17109	39	8D
0005435097154	17109	40	8C
0005433342670	17109	41	8E
0005433342957	17109	42	8F
0005433343295	17109	43	9A
0005433342307	17109	44	9C
0005435097152	17109	45	9B
0005433342861	17109	46	9E
0005433342408	17109	47	9D
0005433342465	17109	48	9F
0005433342922	17109	49	10B
0005435380326	17109	50	10C
0005433342427	17109	51	10D
0005433342819	17109	52	11A
0005433343015	17109	53	10E
0005432293224	17109	54	11B
0005433342817	17109	55	11C
0005433342646	17109	56	11D
0005433342788	17109	57	11F
0005433342956	17109	58	11E
0005433342556	17109	59	12A
0005433343045	17109	60	12B
0005433342862	17109	61	12D
0005435545786	17109	62	12C
0005433342975	17109	63	12E
0005433342605	17109	64	12F
0005433342225	17109	65	13A
0005433342954	17109	66	13C
0005433342786	17109	67	13B
0005433342572	17109	68	13D
0005433342816	17109	69	13E
0005432293222	17109	70	14A
0005433342813	17109	71	13F
0005433342623	17109	72	14B
0005433342854	17109	73	14C
0005433342436	17109	74	14D
0005433342655	17109	75	14E
0005433342555	17109	76	14F
0005433342573	17109	77	15B
0005433342863	17109	78	15A
0005435097158	17109	79	15C
0005433343274	17109	80	15D
0005433342908	17109	81	15F
0005433342505	17109	82	15E
0005433343157	17109	83	16A
0005435097156	17109	84	16B
0005433342571	17109	85	16C
0005433342608	17109	86	16D
0005433342437	17109	87	16F
0005433343138	17109	88	16E
0005433342974	17109	89	17A
0005433343004	17109	90	17B
0005435380323	17109	91	17C
0005433343103	17109	92	17D
0005433342936	17109	93	17F
0005433343044	17109	94	17E
0005433343059	17109	95	18A
0005433342941	17109	96	18B
0005433343181	17109	97	18D
0005433343021	17109	98	18C
0005433342537	17109	99	18F
0005433342909	17109	100	18E
0005433342746	17109	101	19B
0005432293223	17109	102	19A
0005433342516	17109	103	19C
0005433342574	17109	104	19E
0005433342864	17109	105	19D
0005433342409	17109	106	19F
0005435545788	17109	107	20A
0005433342569	17109	108	20B
0005433343025	17109	109	20C
0005433342368	17109	110	20E
0005433342428	17109	111	20D
0005433342649	17109	112	20F
0005433342815	17109	113	21B
0005433342938	17109	114	21A
0005433342606	17109	115	21C
0005433342818	17109	116	21D
0005433342687	17109	117	21F
0005433342935	17109	118	21E
0005433343017	17109	119	22A
0005433342607	17109	120	22B
0005433342592	17109	121	22C
0005435545791	17109	122	22D
0005433342843	17109	123	22E
0005433342973	17109	124	22F
0005433342950	17109	125	23B
0005433343154	17109	126	23A
0005433342719	17109	127	23C
0005435380324	17109	128	23D
0005433342417	17109	129	23F
0005433507297	9090	1	1A
0005433481214	9090	2	1D
0005433481216	9090	3	2A
0005432919808	9090	4	2C
0005433481213	9090	5	2D
0005433507295	9090	6	2F
0005433481215	9090	7	3A
0005433507294	9090	8	3F
0005432919773	9090	9	4A
0005432919813	9090	10	4C
0005432919754	9090	11	5A
0005434158981	9090	12	5C
0005433507287	9090	13	5D
0005432919869	9090	14	5F
0005433507300	9090	15	6D
0005433481211	9090	16	6F
0005433507292	9090	17	7E
0005433481212	9090	18	7D
0005432919874	9090	19	8D
0005433507299	9090	20	8E
0005432919868	9090	21	9A
0005432919772	9090	22	10A
0005432919793	9090	23	10C
0005433507290	9090	24	12A
0005432919760	9090	25	12C
0005433507298	9090	26	12D
0005432919768	9090	27	12E
0005433507301	9090	28	12F
0005432919755	9090	29	13A
0005432919858	9090	30	13D
0005433507288	9090	31	14C
0005432919770	9090	32	14E
0005432919757	9090	33	15A
0005433481217	9090	34	15C
0005432919857	9090	35	15F
0005432919799	9090	36	16C
0005434158968	9090	37	16E
0005432919763	9090	38	17C
0005433507293	9090	39	17E
0005434158982	9090	40	17F
0005433507296	9090	41	18F
0005432919800	9090	42	19A
0005433507291	9090	43	19E
0005433507289	9090	44	19F
0005434158970	9090	45	20C
0005432919776	9090	46	20E
0005432919758	9090	47	20F
0005432920010	20442	1	1A
0005433507135	20442	2	1C
0005433507128	20442	3	1D
0005433481122	20442	4	1F
0005433507159	20442	5	2A
0005433507139	20442	6	2C
0005433507088	20442	7	2D
0005432920005	20442	8	4A
0005433481139	20442	9	4D
0005432920013	20442	10	5E
0005432920001	20442	11	6A
0005433507155	20442	12	6C
0005432920014	20442	13	6D
0005433481161	20442	14	7A
0005433507142	20442	15	7C
0005432920002	20442	16	8A
0005432919999	20442	17	8E
0005433507160	20442	18	8F
0005432920016	20442	19	9C
0005433507136	20442	20	9D
0005433481145	20442	21	9E
0005433507140	20442	22	9F
0005433507175	20442	23	10D
0005433481146	20442	24	10F
0005433507162	20442	25	11A
0005433507146	20442	26	11C
0005433507043	20442	27	11E
0005433507154	20442	28	11F
0005433481160	20442	29	12C
0005432920015	20442	30	12D
0005433481138	20442	31	12E
0005433507064	20442	32	13A
0005432920000	20442	33	13C
0005432920009	20442	34	13F
0005432919998	20442	35	14D
0005432920007	20442	36	14E
0005433481176	20442	37	14F
0005432920003	20442	38	15A
0005433507141	20442	39	15D
0005433481198	20442	40	15C
0005432919997	20442	41	16A
0005433507158	20442	42	16C
0005432920006	20442	43	16E
0005432920008	20442	44	17D
0005433507147	20442	45	17E
0005432919996	20442	46	18A
0005433507145	20442	47	18D
0005432920011	20442	48	18E
0005433507165	20442	49	18F
0005433507153	20442	50	19A
0005432920012	20442	51	19D
0005432920004	20442	52	20D
0005433507095	20442	53	20E
0005435179689	10148	1	1A
0005432394125	10148	2	1B
0005432396264	10148	3	2A
0005432394126	10148	4	2B
0005432396265	10148	5	3A
0005432396262	10148	6	3B
0005432396263	10148	7	4A
0005432394124	10148	8	5A
0005435178990	10148	9	5B
0005432394127	10148	10	6A
0005432396266	10148	11	6B
0005432396231	18387	1	1A
0005432396225	18387	2	1B
0005432396224	18387	3	2A
0005435179699	18387	4	3A
0005432400117	18387	5	2B
0005432396236	18387	6	3B
0005435179399	18387	7	5A
0005435179698	18387	8	4B
0005432396233	18387	9	5B
0005432396248	18387	10	6B
0005435126329	10942	1	1A
0005435126139	10942	2	1C
0005435126279	10942	3	1D
0005435126121	10942	4	1F
0005435126087	10942	5	2A
0005434411805	10942	6	2C
0005435126309	10942	7	2D
0005435126129	10942	8	3A
0005435126261	10942	9	3F
0005435554179	10942	10	4C
0005435126328	10942	11	4D
0005434411804	10942	12	4E
0005435626108	10942	13	4F
0005435126273	10942	14	5A
0005435126164	10942	15	5C
0005435626097	10942	16	5D
0005435126260	10942	17	5E
0005435126165	10942	18	5F
0005435126378	10942	19	6C
0005435126287	10942	20	6D
0005435126023	10942	21	6E
0005435556685	10942	22	6F
0005435126179	10942	23	7A
0005435126345	10942	24	7C
0005435626096	10942	25	7D
0005435126304	10942	26	7F
0005434928316	10942	27	8A
0005435126338	10942	28	8C
0005435126263	10942	29	8F
0005435126211	10942	30	9A
0005435126439	10942	31	9C
0005434411806	10942	32	10A
0005435126150	10942	33	10D
0005435126418	10942	34	10E
0005435626045	10942	35	10F
0005435126344	10942	36	11A
0005435126402	10942	37	11C
0005434928317	10942	38	11D
0005435126163	10942	39	11E
0005435126282	10942	40	11F
0005435126377	10942	41	12A
0005435126218	10942	42	12D
0005435126262	10942	43	12F
0005435126024	10942	44	13A
0005435126390	10942	45	13F
0005435126202	10942	46	13E
0005435126086	10942	47	14A
0005435126248	10942	48	14C
0005435125936	10942	49	14D
0005435126296	10942	50	14E
0005435126224	10942	51	15A
0005435126122	10942	52	15C
0005435126305	10942	53	15E
0005435556684	10942	54	15D
0005435126186	10942	55	16A
0005435126308	10942	56	16C
0005435626107	10942	57	16F
0005435126203	10942	58	17E
0005435626079	10942	59	17F
0005434928318	10942	60	18A
0005435626133	10942	61	18C
0005435126130	10942	62	18D
0005435626137	10942	63	18F
0005435126323	10942	64	19C
0005435126170	10942	65	19D
0005435126403	10942	66	19E
0005435126343	10942	67	19F
0005435556687	10942	68	20A
0005435556686	10942	69	20C
0005435126627	14723	1	1A
0005435126621	14723	2	1C
0005435626300	14723	3	1D
0005435126609	14723	4	1F
0005435126624	14723	5	2C
0005435126636	14723	6	2D
0005435626291	14723	7	2F
0005435126605	14723	8	3A
0005435626290	14723	9	3C
0005435126637	14723	10	3D
0005435126631	14723	11	3F
0005435126618	14723	12	4A
0005435126626	14723	13	4C
0005435554213	14723	14	4D
0005435126606	14723	15	4E
0005435126633	14723	16	4F
0005435126622	14723	17	5A
0005435126615	14723	18	5D
0005435126629	14723	19	5E
0005435626297	14723	20	5F
0005435626287	14723	21	6A
0005435626288	14723	22	6C
0005435626303	14723	23	6D
0005435126644	14723	24	6F
0005435126611	14723	25	7A
0005435126620	14723	26	7C
0005435126639	14723	27	7D
0005435126616	14723	28	7E
0005435626305	14723	29	7F
0005435126612	14723	30	8D
0005435626295	14723	31	8F
0005435126623	14723	32	8E
0005435126625	14723	33	9C
0005435126613	14723	34	9D
0005435126632	14723	35	10A
0005435126628	14723	36	10C
0005434928300	14723	37	10D
0005435126640	14723	38	10E
0005435126610	14723	39	10F
0005435554216	14723	40	11A
0005434411765	14723	41	11C
0005435626301	14723	42	11D
0005435556707	14723	43	11F
0005435626302	14723	44	11E
0005435126617	14723	45	12F
0005435126638	14723	46	13A
0005435626296	14723	47	13C
0005435626292	14723	48	13D
0005435126614	14723	49	14A
0005435626293	14723	50	14C
0005435626294	14723	51	14D
0005434411747	14723	52	14E
0005435126607	14723	53	14F
0005435554214	14723	54	15C
0005434928288	14723	55	15D
0005435626304	14723	56	15E
0005435554217	14723	57	15F
0005435126645	14723	58	16D
0005435626299	14723	59	16F
0005435126635	14723	60	17C
0005435626289	14723	61	17D
0005435126608	14723	62	18A
0005435554212	14723	63	18C
0005435126642	14723	64	18E
0005435126619	14723	65	18F
0005435126641	14723	66	19A
0005435556709	14723	67	19C
0005435126630	14723	68	19D
0005435126634	14723	69	19F
0005435626298	14723	70	20A
0005435556708	14723	71	20C
0005435126643	14723	72	20E
0005435554215	14723	73	20F
0005435715565	7135	1	1A
0005432398219	7135	2	1C
0005435715570	7135	3	1D
0005435715568	7135	4	1F
0005432398220	7135	5	2A
0005435715577	7135	6	3A
0005435715575	7135	7	3C
0005435715567	7135	8	3D
0005435216572	7135	9	3F
0005435443279	7135	10	4A
0005435715572	7135	11	4D
0005435443272	7135	12	4E
0005432400151	7135	13	4F
0005435715579	7135	14	5A
0005432400152	7135	15	5F
0005435715574	7135	16	6F
0005435715581	7135	17	7C
0005432400148	7135	18	7E
0005435715564	7135	19	7F
0005435715566	7135	20	8F
0005432400149	7135	21	9A
0005432398222	7135	22	9C
0005432400150	7135	23	9D
0005435219181	7135	24	9F
0005435443291	7135	25	10C
0005435443261	7135	26	11A
0005435715578	7135	27	11C
0005435715571	7135	28	11E
0005435715573	7135	29	12D
0005435178493	7135	30	12F
0005435443271	7135	31	13F
0005435221054	7135	32	14C
0005435216573	7135	33	14D
0005432398221	7135	34	14E
0005435715580	7135	35	15E
0005435715576	7135	36	15F
0005435443262	7135	37	16A
0005435715569	7135	38	16D
0005435443280	7135	39	17A
0005432400147	7135	40	18C
0005435443285	7135	41	18E
0005435443307	7135	42	20E
0005435443303	7135	43	20F
0005435443375	27049	1	1A
0005435443366	27049	2	1C
0005432398184	27049	3	2D
0005435715397	27049	4	3A
0005435715462	27049	5	4F
0005435715412	27049	6	5A
0005435715423	27049	7	5F
0005435715331	27049	8	6C
0005435715419	27049	9	6D
0005435443374	27049	10	6F
0005432394089	27049	11	7C
0005435443367	27049	12	8A
0005435443372	27049	13	8E
0005435443368	27049	14	8F
0005435715410	27049	15	9A
0005435715449	27049	16	9F
0005435443376	27049	17	10F
0005435715401	27049	18	13C
0005432398185	27049	19	13E
0005435715411	27049	20	14A
0005435178503	27049	21	14D
0005435443373	27049	22	14C
0005435715420	27049	23	15D
0005435715435	27049	24	15E
0005435715386	27049	25	15F
0005435443370	27049	26	17D
0005435715430	27049	27	17E
0005435443371	27049	28	17F
0005435715377	27049	29	18A
0005435715445	27049	30	18E
0005435178502	27049	31	19C
0005435715424	27049	32	19E
0005435715376	27049	33	20C
0005435443369	27049	34	20E
0005433060407	2720	1	1B
0005434084960	2720	2	3A
0005434084959	2720	3	3B
0005434084958	2720	4	5B
0005433060432	28469	1	1A
0005433060429	28469	2	1B
0005433060430	28469	3	2A
0005433060431	28469	4	5A
0005433060433	28469	5	4B
0005434084916	28469	6	5B
0005434084915	28469	7	6A
0005433060428	28469	8	6B
0005435541044	11399	1	1C
0005435540963	11399	2	1D
0005435540951	11399	3	2A
0005435541009	11399	4	2C
0005435540956	11399	5	3A
0005435541010	11399	6	3C
0005435517890	11399	7	3F
0005435517851	11399	8	4A
0005435540971	11399	9	4C
0005435541045	11399	10	4F
0005435517792	11399	11	5A
0005435517912	11399	12	5E
0005435517869	11399	13	5F
0005435517918	11399	14	6A
0005435540873	11399	15	6C
0005435540950	11399	16	6D
0005435540996	11399	17	6E
0005435517844	11399	18	7A
0005435517898	11399	19	7F
0005435517921	11399	20	8E
0005435540970	11399	21	9D
0005435540907	11399	22	9E
0005435540906	11399	23	10A
0005435517893	11399	24	10F
0005435517891	11399	25	11C
0005435540957	11399	26	11D
0005435540839	11399	27	12F
0005435540838	11399	28	13A
0005435540914	11399	29	13D
0005435517957	11399	30	13E
0005435517922	11399	31	14A
0005435517904	11399	32	15F
0005435517846	11399	33	16A
0005435517913	11399	34	16D
0005435517845	11399	35	16F
0005435540936	11399	36	19A
0005435540980	11399	37	19E
0005435517829	11399	38	19F
0005435517828	11399	39	20E
0005435541061	11399	40	20F
0005435529377	22255	1	1A
0005435541113	22255	2	1D
0005435541123	22255	3	1F
0005435529378	22255	4	2A
0005435541118	22255	5	3A
0005435529367	22255	6	3C
0005435529379	22255	7	3F
0005435541129	22255	8	4D
0005435541127	22255	9	4F
0005435529369	22255	10	5E
0005435529384	22255	11	6A
0005435541130	22255	12	6E
0005435529371	22255	13	6F
0005435529373	22255	14	7A
0005435541121	22255	15	7C
0005435541122	22255	16	7E
0005435529381	22255	17	7F
0005435529368	22255	18	8A
0005435541128	22255	19	8D
0005435541125	22255	20	8E
0005435529380	22255	21	9D
0005435529385	22255	22	10A
0005435529387	22255	23	10C
0005435541131	22255	24	10D
0005435529370	22255	25	10E
0005435529382	22255	26	10F
0005432294501	22255	27	11A
0005435541114	22255	28	11E
0005435529374	22255	29	11F
0005435541119	22255	30	12A
0005435541116	22255	31	12C
0005435541112	22255	32	12D
0005435541110	22255	33	12E
0005432294500	22255	34	14C
0005435529372	22255	35	15C
0005435541126	22255	36	15E
0005435541124	22255	37	15F
0005435541120	22255	38	17C
0005435541117	22255	39	17D
0005435541111	22255	40	17E
0005435529386	22255	41	17F
0005435529376	22255	42	18D
0005435529383	22255	43	19A
0005432294499	22255	44	19D
0005435529375	22255	45	19E
0005435529366	22255	46	19F
0005435541115	22255	47	20F
0005434907614	2267	1	1A
0005434907611	2267	2	1C
0005433251383	2267	3	1F
0005433251336	2267	4	2A
0005433251388	2267	5	2C
0005433251405	2267	6	2D
0005434907601	2267	7	2F
0005434907598	2267	8	3A
0005434907634	2267	9	3C
0005434907647	2267	10	3D
0005434907613	2267	11	3F
0005433251501	2267	12	4A
0005434907632	2267	13	4C
0005433251408	2267	14	4D
0005434907653	2267	15	4E
0005434907626	2267	16	4F
0005434907650	2267	17	5A
0005433251471	2267	18	5C
0005434907604	2267	19	5D
0005434907639	2267	20	5E
0005434907617	2267	21	5F
0005434907645	2267	22	6A
0005434907643	2267	23	6C
0005433251382	2267	24	6D
0005433251575	2267	25	6F
0005433251461	2267	26	6E
0005434907608	2267	27	7A
0005434907649	2267	28	7C
0005434907640	2267	29	7D
0005434907600	2267	30	7E
0005433251504	2267	31	7F
0005434907628	2267	32	8A
0005433251567	2267	33	8C
0005434907636	2267	34	8D
0005434907624	2267	35	8E
0005433251407	2267	36	8F
0005434907644	2267	37	9A
0005433251537	2267	38	9C
0005434907627	2267	39	9D
0005434907625	2267	40	9E
0005434907633	2267	41	9F
0005433251325	2267	42	10A
0005434907607	2267	43	10C
0005434907642	2267	44	10D
0005433251502	2267	45	10E
0005433251530	2267	46	10F
0005434907612	2267	47	11A
0005433251568	2267	48	11C
0005434907648	2267	49	11D
0005433251515	2267	50	11E
0005433251421	2267	51	11F
0005434907620	2267	52	12A
0005434907652	2267	53	12C
0005433251538	2267	54	12D
0005434907609	2267	55	12E
0005433251324	2267	56	12F
0005434907621	2267	57	13A
0005434907606	2267	58	13C
0005434907638	2267	59	13D
0005434907623	2267	60	13E
0005434907603	2267	61	13F
0005433251576	2267	62	14A
0005433251387	2267	63	14C
0005434907635	2267	64	14D
0005433251386	2267	65	14E
0005433251532	2267	66	14F
0005434907646	2267	67	15A
0005434907610	2267	68	15C
0005434907622	2267	69	15D
0005434907618	2267	70	15E
0005433251472	2267	71	15F
0005433251535	2267	72	16A
0005434907619	2267	73	16C
0005433251493	2267	74	16D
0005433251319	2267	75	16E
0005434907615	2267	76	16F
0005434907629	2267	77	17A
0005433251492	2267	78	17C
0005433251410	2267	79	17D
0005434907599	2267	80	17E
0005434907651	2267	81	17F
0005434907602	2267	82	18A
0005434907605	2267	83	18C
0005434907631	2267	84	18D
0005433251549	2267	85	18E
0005434907616	2267	86	18F
0005433251282	2267	87	19A
0005433251321	2267	88	19C
0005434907641	2267	89	19D
0005433251462	2267	90	19E
0005433251516	2267	91	19F
0005434907637	2267	92	20A
0005433251486	2267	93	20C
0005434907630	2267	94	20D
0005433251330	2267	95	20E
0005433400969	2267	96	20F
0005434907101	25585	1	1A
0005433251681	25585	2	1C
0005433251667	25585	3	2A
0005434906953	25585	4	2C
0005434907100	25585	5	3A
0005434907138	25585	6	3C
0005433251659	25585	7	3D
0005434907214	25585	8	4A
0005434907015	25585	9	4C
0005433251675	25585	10	4D
0005433251683	25585	11	4E
0005434906909	25585	12	5A
0005433251679	25585	13	5C
0005434907061	25585	14	5D
0005434907136	25585	15	5E
0005433251662	25585	16	5F
0005434906924	25585	17	6A
0005434906981	25585	18	6C
0005433251666	25585	19	6D
0005434907173	25585	20	6F
0005434907067	25585	21	7A
0005433251685	25585	22	7C
0005433251661	25585	23	7D
0005433251674	25585	24	7E
0005434906854	25585	25	8A
0005434907305	25585	26	8C
0005434907068	25585	27	8E
0005433251672	25585	28	8F
0005433251680	25585	29	9C
0005434907156	25585	30	9F
0005434907139	25585	31	10A
0005434907060	25585	32	10C
0005433251676	25585	33	10E
0005434907182	25585	34	10F
0005434907140	25585	35	11A
0005434907065	25585	36	11C
0005433251656	25585	37	11D
0005434906866	25585	38	11E
0005433251678	25585	39	11F
0005433251677	25585	40	12A
0005434907084	25585	41	12C
0005434907149	25585	42	12D
0005434906908	25585	43	12F
0005434907075	25585	44	13A
0005433251684	25585	45	13C
0005433401003	25585	46	13D
0005434907066	25585	47	13E
0005433251668	25585	48	13F
0005434907102	25585	49	14A
0005434907288	25585	50	14C
0005434907233	25585	51	14E
0005433401004	25585	52	14F
0005433251660	25585	53	15C
0005433251670	25585	54	15D
0005434906999	25585	55	15E
0005434906998	25585	56	15F
0005434906963	25585	57	16A
0005433251669	25585	58	16C
0005434907154	25585	59	16D
0005434906966	25585	60	16E
0005433251673	25585	61	16F
0005433251654	25585	62	17A
0005433251682	25585	63	17C
0005433251664	25585	64	17E
0005433401002	25585	65	18A
0005433251671	25585	66	18C
0005433251655	25585	67	18D
0005433251663	25585	68	18E
0005433251657	25585	69	18F
0005434906943	25585	70	19A
0005433251665	25585	71	19C
0005434907289	25585	72	19D
0005434906980	25585	73	19E
0005433251658	25585	74	19F
0005434907143	25585	75	20A
0005434906867	25585	76	20C
0005434907239	25585	77	20E
0005432862273	2512	1	1A
0005432621122	2512	2	1B
0005432621126	2512	3	1C
0005432862296	2512	4	1D
0005432621123	2512	5	2A
0005432621130	2512	6	2B
0005432862262	2512	7	2D
0005432621119	2512	8	3A
0005432621124	2512	9	3B
0005432862276	2512	10	3C
0005432862307	2512	11	3D
0005432862303	2512	12	4B
0005432862315	2512	13	4C
0005432862299	2512	14	5B
0005432862300	2512	15	5C
0005432862316	2512	16	5D
0005432621127	2512	17	6A
0005432862272	2512	18	6D
0005432621131	2512	19	7B
0005432621132	2512	20	7D
0005432862308	2512	21	18A
0005432862306	2512	22	18B
0005432621125	2512	23	19A
0005432862263	2512	24	19B
0005432621129	2512	25	19C
0005432862255	2512	26	21C
0005432621120	2512	27	22A
0005432621128	2512	28	22B
0005432621121	2512	29	23B
0005432621036	28034	1	1D
0005432862348	28034	2	2C
0005432862351	28034	3	3A
0005432862353	28034	4	3B
0005432862352	28034	5	3C
0005432621037	28034	6	3D
0005432621054	28034	7	5B
0005432620977	28034	8	5D
0005432621002	28034	9	6A
0005432620970	28034	10	6C
0005432620942	28034	11	6D
0005432862347	28034	12	7A
0005432862346	28034	13	18B
0005432862350	28034	14	18D
0005432621022	28034	15	19C
0005432862349	28034	16	19D
0005432620992	28034	17	20B
0005432620943	28034	18	22D
0005434097484	13117	1	3B
0005434097485	13117	2	6B
0005433452752	31025	1	3A
0005433451632	31025	2	3B
0005433452751	31025	3	6A
0005433451631	31025	4	6B
0005433454871	31440	1	2A
0005433452733	31440	2	3A
0005433452734	31440	3	4A
0005433452736	31440	4	4B
0005433452737	31440	5	5B
0005433454872	31440	6	6A
0005433134127	11987	1	1D
0005433129282	11987	2	2C
0005433134116	11987	3	3B
0005434142598	11987	4	3D
0005434142600	11987	5	4A
0005433134128	11987	6	4B
0005433129267	11987	7	4C
0005433129259	11987	8	4D
0005433129263	11987	9	5B
0005434184662	11987	10	5D
0005433129241	11987	11	7A
0005434184660	11987	12	7B
0005433129257	11987	13	7C
0005433134115	11987	14	18D
0005433134122	11987	15	19A
0005433134107	11987	16	19C
0005433129242	11987	17	20D
0005433129258	11987	18	21B
0005433134114	11987	19	21C
0005434184661	11987	20	21D
0005434142601	11987	21	22A
0005434142602	11987	22	22B
0005433129283	11987	23	23B
0005433134165	29833	1	1B
0005434142630	29833	2	1C
0005434183592	29833	3	2D
0005434184677	29833	4	3B
0005434142631	29833	5	5A
0005433131735	29833	6	5C
0005434142633	29833	7	6A
0005434184678	29833	8	6B
0005434142632	29833	9	7A
0005433131736	29833	10	7C
0005433131738	29833	11	7D
0005433134164	29833	12	18A
0005433134168	29833	13	18B
0005433131734	29833	14	18C
0005434142634	29833	15	18D
0005434183591	29833	16	19B
0005433131737	29833	17	20B
0005433134166	29833	18	20D
0005433134167	29833	19	21B
0005435697477	16472	1	1A
0005435697486	16472	2	2A
0005435697487	16472	3	2B
0005435697489	16472	4	2C
0005435697482	16472	5	3A
0005435697484	16472	6	4A
0005435697495	16472	7	4B
0005435697488	16472	8	4D
0005435697499	16472	9	5A
0005435935021	16472	10	5B
0005435697494	16472	11	5D
0005435697490	16472	12	6A
0005435697475	16472	13	6B
0005435697485	16472	14	6C
0005435697491	16472	15	7A
0005435697500	16472	16	7B
0005435697501	16472	17	7C
0005435697481	16472	18	7D
0005435697498	16472	19	18A
0005435697476	16472	20	18C
0005435935033	16472	21	18D
0005435697493	16472	22	19A
0005435697492	16472	23	19C
0005435697503	16472	24	19D
0005435697502	16472	25	20A
0005435935034	16472	26	20B
0005435697474	16472	27	20C
0005435697497	16472	28	20D
0005435697479	16472	29	21B
0005435697480	16472	30	21C
0005435697483	16472	31	21D
0005435697496	16472	32	22C
0005435697478	16472	33	23A
0005435697325	24701	1	1A
0005435697150	24701	2	1B
0005435697326	24701	3	1C
0005435697215	24701	4	1D
0005435697274	24701	5	2A
0005435697384	24701	6	2B
0005435697273	24701	7	2D
0005435697380	24701	8	3A
0005435697240	24701	9	3B
0005435697324	24701	10	3C
0005435697225	24701	11	3D
0005435697263	24701	12	4B
0005435697151	24701	13	4C
0005435697379	24701	14	4D
0005435697254	24701	15	5A
0005435697152	24701	16	5B
0005435697337	24701	17	5C
0005435697287	24701	18	5D
0005435697294	24701	19	6A
0005435697382	24701	20	6B
0005435697319	24701	21	6C
0005435697246	24701	22	6D
0005435697253	24701	23	7A
0005435697331	24701	24	7B
0005435697272	24701	25	7C
0005435697342	24701	26	7D
0005435697234	24701	27	18A
0005435697269	24701	28	18B
0005435697233	24701	29	18D
0005435697202	24701	30	19B
0005435697220	24701	31	19C
0005435697293	24701	32	19D
0005435697279	24701	33	20A
0005435697291	24701	34	20B
0005435697216	24701	35	20C
0005435697270	24701	36	21A
0005435697190	24701	37	21B
0005435697359	24701	38	21C
0005435697305	24701	39	21D
0005435697219	24701	40	22A
0005435697280	24701	41	22B
0005435697341	24701	42	22D
0005435697262	24701	43	23A
0005435697203	24701	44	23B
0005433724827	18794	1	1A
0005433724829	18794	2	2B
0005433724826	18794	3	3B
0005433724830	18794	4	4B
0005433724828	18794	5	6B
0005433724807	21625	1	1B
0005432968855	21625	2	2B
0005432968856	21625	3	3A
0005432968857	21625	4	6B
0005434138638	7317	1	1A
0005434138666	7317	2	1C
0005434138671	7317	3	1D
0005434138678	7317	4	1F
0005434138639	7317	5	2A
0005434138644	7317	6	2C
0005434138705	7317	7	2D
0005434138707	7317	8	3A
0005434138704	7317	9	3C
0005434138665	7317	10	3D
0005434138657	7317	11	3F
0005434138642	7317	12	4A
0005434138640	7317	13	4C
0005434138684	7317	14	4D
0005434138674	7317	15	4E
0005434138646	7317	16	4F
0005434138710	7317	17	5C
0005434138655	7317	18	5E
0005434138694	7317	19	5F
0005434138715	7317	20	6A
0005434138712	7317	21	6C
0005434138690	7317	22	6D
0005434138667	7317	23	6E
0005434138700	7317	24	6F
0005434138696	7317	25	7A
0005434087546	7317	26	7C
0005434138633	7317	27	7D
0005434138682	7317	28	7E
0005434138702	7317	29	7F
0005434138651	7317	30	8A
0005434138692	7317	31	8C
0005434138649	7317	32	8D
0005434138685	7317	33	8E
0005434138675	7317	34	8F
0005434138634	7317	35	9A
0005434087544	7317	36	9C
0005434138711	7317	37	9D
0005434138654	7317	38	9E
0005434138688	7317	39	9F
0005434138661	7317	40	10A
0005434138659	7317	41	10C
0005434138648	7317	42	10D
0005434138683	7317	43	10E
0005434138681	7317	44	10F
0005434138695	7317	45	11A
0005434138670	7317	46	11C
0005434138706	7317	47	11D
0005434138643	7317	48	11E
0005434138687	7317	49	11F
0005434138697	7317	50	12A
0005434138635	7317	51	12C
0005434138714	7317	52	12D
0005434138650	7317	53	12E
0005434138658	7317	54	12F
0005434138703	7317	55	13A
0005434138656	7317	56	13C
0005434138679	7317	57	13D
0005434138632	7317	58	13E
0005434138693	7317	59	13F
0005434138698	7317	60	14A
0005434138641	7317	61	14C
0005434138636	7317	62	14D
0005434138691	7317	63	14E
0005434138664	7317	64	14F
0005434138680	7317	65	15A
0005434138668	7317	66	15C
0005434138699	7317	67	15F
0005434138663	7317	68	16A
0005434138686	7317	69	16D
0005434138673	7317	70	16E
0005434138653	7317	71	17A
0005434138689	7317	72	17D
0005434138677	7317	73	17E
0005434138647	7317	74	17F
0005434138637	7317	75	18A
0005434138708	7317	76	18C
0005434138669	7317	77	18D
0005434138645	7317	78	18E
0005434138709	7317	79	18F
0005434087545	7317	80	19A
0005434138652	7317	81	19D
0005434138672	7317	82	19E
0005434138662	7317	83	19F
0005434138701	7317	84	20A
0005434087543	7317	85	20C
0005434138660	7317	86	20D
0005434138713	7317	87	20E
0005434138676	7317	88	20F
0005434137812	28542	1	1C
0005434137813	28542	2	1D
0005434137917	28542	3	1F
0005434137390	28542	4	2A
0005434137730	28542	5	2C
0005434137911	28542	6	2F
0005434138265	28542	7	3A
0005434138003	28542	8	3C
0005434137748	28542	9	3D
0005434137988	28542	10	3F
0005434137709	28542	11	4A
0005434137710	28542	12	4D
0005434137756	28542	13	4E
0005434138033	28542	14	4F
0005434137816	28542	15	5A
0005434137771	28542	16	5C
0005434138040	28542	17	5D
0005434137644	28542	18	5E
0005434137984	28542	19	6A
0005434137987	28542	20	6C
0005434137683	28542	21	6D
0005434138086	28542	22	6E
0005434137685	28542	23	6F
0005434137714	28542	24	7C
0005434137684	28542	25	7D
0005434087520	28542	26	7E
0005434137933	28542	27	7F
0005434137705	28542	28	8A
0005434137779	28542	29	8C
0005434137642	28542	30	8D
0005434137846	28542	31	8F
0005434137967	28542	32	9A
0005434138019	28542	33	9C
0005434138085	28542	34	9D
0005434137883	28542	35	9E
0005434138008	28542	36	9F
0005434138093	28542	37	10A
0005434137780	28542	38	10C
0005434137881	28542	39	10D
0005434138092	28542	40	10E
0005434137706	28542	41	10F
0005434138009	28542	42	11A
0005434137716	28542	43	11C
0005434138200	28542	44	11D
0005434138097	28542	45	11E
0005434137747	28542	46	12A
0005434138124	28542	47	12C
0005434137304	28542	48	12D
0005434138191	28542	49	12E
0005434137949	28542	50	12F
0005434138101	28542	51	13A
0005434138221	28542	52	13C
0005434137682	28542	53	13D
0005434137882	28542	54	13E
0005434137704	28542	55	13F
0005434137843	28542	56	14C
0005434087505	28542	57	14D
0005434138100	28542	58	14E
0005434137742	28542	59	14F
0005434087521	28542	60	15A
0005434137715	28542	61	15C
0005434137968	28542	62	15D
0005434138134	28542	63	15E
0005434137934	28542	64	16A
0005434138012	28542	65	16C
0005434137873	28542	66	16D
0005434138199	28542	67	16F
0005434137643	28542	68	17A
0005434137990	28542	69	17C
0005434138011	28542	70	17D
0005434138010	28542	71	17E
0005434138126	28542	72	17F
0005434138021	28542	73	18A
0005434137815	28542	74	18C
0005434137912	28542	75	18D
0005434137989	28542	76	18E
0005434137680	28542	77	18F
0005434137729	28542	78	19A
0005434087496	28542	79	19C
0005434137951	28542	80	19E
0005434137985	28542	81	20A
0005434137983	28542	82	20C
0005434137814	28542	83	20D
0005434137731	28542	84	20E
0005434137717	28542	85	20F
0005435808298	1945	1	1A
0005435808299	1945	2	2A
0005435808297	1945	3	2B
0005434610254	1945	4	2C
0005435808301	1945	5	3C
0005435808302	1945	6	3D
0005435808304	1945	7	5C
0005434610252	1945	8	6C
0005435808296	1945	9	6D
0005434610253	1945	10	7B
0005435808295	1945	11	18B
0005435808303	1945	12	19A
0005433407565	1945	13	20A
0005435808300	1945	14	21A
0005434610250	1945	15	21D
0005434610251	1945	16	23A
0005434610216	23118	1	18B
0005434610220	23118	2	19C
0005434504088	16694	1	1B
0005434504038	16694	2	1C
0005434504100	16694	3	1D
0005434503947	16694	4	2B
0005434503901	16694	5	3A
0005434504126	16694	6	3D
0005434503977	16694	7	4A
0005434504254	16694	8	4C
0005434504099	16694	9	4D
0005434504024	16694	10	5A
0005434503882	16694	11	5D
0005434503902	16694	12	6A
0005434503995	16694	13	6B
0005434504003	16694	14	6C
0005434504002	16694	15	7A
0005434503946	16694	16	7C
0005434504093	16694	17	7D
0005434504022	16694	18	18D
0005434504036	16694	19	19A
0005434504019	16694	20	19B
0005434504068	16694	21	20A
0005434503819	16694	22	20B
0005434504081	16694	23	22A
0005434504046	16694	24	22B
0005434503976	16694	25	22C
0005434504037	16694	26	22D
0005434503853	16694	27	23B
0005434504360	22893	1	1B
0005434504349	22893	2	1C
0005434504344	22893	3	1D
0005434504356	22893	4	2A
0005434504351	22893	5	2B
0005434504379	22893	6	2C
0005434504367	22893	7	3A
0005434504371	22893	8	3B
0005434504361	22893	9	3C
0005434504377	22893	10	4A
0005434504374	22893	11	4C
0005434504346	22893	12	4D
0005434504342	22893	13	5A
0005434504368	22893	14	5B
0005434504362	22893	15	5C
0005434504376	22893	16	5D
0005434504358	22893	17	6A
0005434504354	22893	18	6B
0005434504375	22893	19	6D
0005434504343	22893	20	7B
0005434504359	22893	21	7C
0005434504373	22893	22	18A
0005434504347	22893	23	18B
0005434504366	22893	24	18C
0005434504365	22893	25	18D
0005434504363	22893	26	19A
0005434504348	22893	27	19B
0005434504372	22893	28	19C
0005434504382	22893	29	19D
0005434504353	22893	30	20A
0005434504380	22893	31	20B
0005434504369	22893	32	20C
0005434504370	22893	33	21B
0005434504357	22893	34	21C
0005434504381	22893	35	21D
0005434504345	22893	36	22A
0005434504364	22893	37	22B
0005434504355	22893	38	22C
0005434504352	22893	39	22D
0005434504378	22893	40	23A
0005434504350	22893	41	23B
0005433266734	2178	1	1B
0005435078432	2178	2	2B
0005435078437	2178	3	2C
0005433266710	2178	4	2D
0005433266685	2178	5	4A
0005435078430	2178	6	4B
0005433266684	2178	7	4C
0005435078434	2178	8	5C
0005433266711	2178	9	5D
0005435078435	2178	10	6B
0005435078442	2178	11	6D
0005435078436	2178	12	7A
0005433266676	2178	13	7D
0005435078438	2178	14	18A
0005433266702	2178	15	18C
0005435078443	2178	16	19B
0005435078439	2178	17	19D
0005435078445	2178	18	20A
0005435078441	2178	19	20D
0005433266660	2178	20	21B
0005435078433	2178	21	21C
0005435078431	2178	22	21D
0005433266701	2178	23	22B
0005435078440	2178	24	22D
0005435078444	2178	25	23A
0005435078285	24345	1	1A
0005435078321	24345	2	1B
0005433266776	24345	3	1C
0005433266779	24345	4	2A
0005435078309	24345	5	2B
0005435078320	24345	6	2D
0005435078282	24345	7	3A
0005435078354	24345	8	3C
0005435078316	24345	9	3D
0005433266777	24345	10	4B
0005435078291	24345	11	4D
0005435078318	24345	12	5A
0005435078262	24345	13	5C
0005433266783	24345	14	6A
0005435078263	24345	15	6D
0005433266780	24345	16	7B
0005433266785	24345	17	18B
0005433266784	24345	18	18C
0005433266782	24345	19	18D
0005435078331	24345	20	19A
0005433266778	24345	21	19B
0005435078286	24345	22	20A
0005435078317	24345	23	19D
0005435078355	24345	24	20B
0005435078279	24345	25	21B
0005435078280	24345	26	21C
0005435078274	24345	27	21D
0005435078330	24345	28	22B
0005435078361	24345	29	22C
0005435078299	24345	30	22D
0005433266781	24345	31	23B
0005434988800	6665	1	1C
0005434988807	6665	2	2B
0005434988802	6665	3	3A
0005435803280	6665	4	4A
0005434988805	6665	5	4C
0005435803282	6665	6	5D
0005434988811	6665	7	6B
0005434988809	6665	8	6D
0005435803281	6665	9	7B
0005434988804	6665	10	7C
0005434988801	6665	11	18A
0005434988810	6665	12	18C
0005434988803	6665	13	20D
0005434988808	6665	14	21B
0005434988806	6665	15	23A
0005435803279	6665	16	23B
0005434988669	23587	1	1B
0005434988691	23587	2	1C
0005434988700	23587	3	1D
0005434988663	23587	4	2B
0005434988673	23587	5	3C
0005434988699	23587	6	4A
0005434988662	23587	7	5B
0005435464520	23587	8	7C
0005434988698	23587	9	18A
0005434988689	23587	10	18C
0005434988701	23587	11	18D
0005434988676	23587	12	19A
0005435464519	23587	13	20A
0005435803267	23587	14	20C
0005434988637	23587	15	20D
0005434988670	23587	16	21C
0005434988672	23587	17	23B
0005432383425	30498	1	1A
0005432383440	30498	2	1C
0005433450104	30498	3	1F
0005432383416	30498	4	2A
0005432383426	30498	5	2C
0005432383442	30498	6	2D
0005433450099	30498	7	2F
0005433450101	30498	8	3C
0005433450115	30498	9	3D
0005433450096	30498	10	3F
0005433450114	30498	11	4A
0005432383430	30498	12	4D
0005432383443	30498	13	4E
0005432383427	30498	14	5A
0005432383419	30498	15	5C
0005433450118	30498	16	5D
0005433450107	30498	17	5E
0005432383424	30498	18	5F
0005432383423	30498	19	6A
0005432383428	30498	20	6C
0005432383409	30498	21	6D
0005433450111	30498	22	6E
0005432383433	30498	23	6F
0005433450103	30498	24	7A
0005433450116	30498	25	7C
0005433450113	30498	26	7D
0005433454890	30498	27	8A
0005433454891	30498	28	8D
0005432383406	30498	29	8F
0005433454889	30498	30	9A
0005432383422	30498	31	9C
0005432383437	30498	32	9D
0005432383438	30498	33	10A
0005433450109	30498	34	10F
0005433450098	30498	35	11C
0005432383408	30498	36	11D
0005433450097	30498	37	11E
0005432383421	30498	38	12D
0005433450100	30498	39	12E
0005432383418	30498	40	12F
0005432383407	30498	41	13C
0005432383411	30498	42	13A
0005432383432	30498	43	13D
0005432383436	30498	44	14C
0005432383439	30498	45	14E
0005433450112	30498	46	14F
0005432383431	30498	47	15A
0005432383417	30498	48	15C
0005432383412	30498	49	15D
0005432383410	30498	50	15E
0005432383415	30498	51	15F
0005432383403	30498	52	16D
0005433450117	30498	53	16E
0005433450105	30498	54	16F
0005432383404	30498	55	17A
0005432383420	30498	56	17D
0005432383402	30498	57	17E
0005433450110	30498	58	17F
0005432383414	30498	59	18A
0005433453772	30498	60	18C
0005433450102	30498	61	18D
0005433450108	30498	62	18E
0005433450106	30498	63	18F
0005432383405	30498	64	19A
0005433454888	30498	65	19D
0005432383435	30498	66	19E
0005432383413	30498	67	19F
0005432383429	30498	68	20C
0005432383441	30498	69	20E
0005432383434	30498	70	20F
0005432382982	31320	1	1A
0005432382870	31320	2	1C
0005432383025	31320	3	1F
0005433449965	31320	4	2F
0005433449913	31320	5	3C
0005432383032	31320	6	3F
0005433451615	31320	7	4A
0005432382931	31320	8	4C
0005432383085	31320	9	4D
0005432382990	31320	10	4F
0005433450001	31320	11	5A
0005433449980	31320	12	5C
0005433449910	31320	13	5E
0005433451614	31320	14	6A
0005432382886	31320	15	6C
0005432382852	31320	16	6D
0005433449969	31320	17	6E
0005432383037	31320	18	6F
0005432383023	31320	19	7D
0005432382885	31320	20	7E
0005432382975	31320	21	8A
0005432383031	31320	22	8C
0005432382916	31320	23	8E
0005432382997	31320	24	8F
0005433450005	31320	25	9A
0005432382872	31320	26	9C
0005432382976	31320	27	9E
0005433449927	31320	28	10A
0005433451613	31320	29	10C
0005432383024	31320	30	10E
0005432382851	31320	31	11A
0005432383028	31320	32	11C
0005432382810	31320	33	11D
0005432382934	31320	34	11F
0005432383060	31320	35	12A
0005433449930	31320	36	12C
0005432383080	31320	37	12E
0005432383010	31320	38	12F
0005432382887	31320	39	13A
0005432383081	31320	40	13C
0005432383056	31320	41	14A
0005432383021	31320	42	14D
0005433449929	31320	43	14E
0005433449970	31320	44	14F
0005433449926	31320	45	15A
0005433449981	31320	46	15C
0005432382960	31320	47	16A
0005433449973	31320	48	16D
0005432382981	31320	49	16E
0005433449908	31320	50	16F
0005432382869	31320	51	17C
0005433449972	31320	52	18C
0005432383029	31320	53	18E
0005432382917	31320	54	18F
0005432382892	31320	55	19C
0005432383038	31320	56	19D
0005433449909	31320	57	19E
0005433450002	31320	58	20A
0005433449880	31320	59	20F
0005433788227	20817	1	1A
0005435548456	20817	2	1D
0005433788230	20817	3	2B
0005435548457	20817	4	3A
0005435548468	20817	5	3B
0005435548461	20817	6	3C
0005433788223	20817	7	4A
0005435548465	20817	8	4B
0005433788233	20817	9	4C
0005433788221	20817	10	4D
0005433788229	20817	11	5C
0005435548470	20817	12	6B
0005435548462	20817	13	6D
0005435548450	20817	14	7A
0005433788231	20817	15	7B
0005433788222	20817	16	7C
0005433788228	20817	17	18D
0005433788225	20817	18	19A
0005433788226	20817	19	19B
0005435548455	20817	20	19C
0005435548474	20817	21	19D
0005433788224	20817	22	20A
0005435548451	20817	23	20B
0005433788220	20817	24	20C
0005433788232	20817	25	21A
0005433788234	20817	26	21C
0005433788219	20817	27	22A
0005435548466	20817	28	22B
0005435548469	20817	29	22C
0005435548458	20817	30	23A
0005435548522	26486	1	1B
0005435548517	26486	2	1C
0005435548521	26486	3	2A
0005435548516	26486	4	2B
0005435548527	26486	5	2C
0005433788187	26486	6	2D
0005433788202	26486	7	3B
0005435548515	26486	8	4A
0005433788203	26486	9	4B
0005435548525	26486	10	5B
0005435548520	26486	11	5D
0005435548519	26486	12	6A
0005433788188	26486	13	6D
0005435548526	26486	14	7B
0005435548528	26486	15	7C
0005433788166	26486	16	18A
0005435548524	26486	17	18B
0005435548523	26486	18	18C
0005433788190	26486	19	19D
0005433788186	26486	20	20D
0005435548514	26486	21	22A
0005435548518	26486	22	22B
0005433788185	26486	23	22C
0005433788201	26486	24	23B
0005433126825	10773	1	1C
0005435304140	10773	2	2B
0005435299769	10773	3	2D
0005435299758	10773	4	3A
0005433126839	10773	5	3B
0005435299765	10773	6	3C
0005435299775	10773	7	4C
0005433126840	10773	8	5A
0005435304145	10773	9	5B
0005433126826	10773	10	5D
0005435299776	10773	11	6A
0005435299760	10773	12	6C
0005435299752	10773	13	6D
0005433131691	10773	14	7A
0005433131689	10773	15	7B
0005433126817	10773	16	7C
0005435299768	10773	17	7D
0005433131670	10773	18	18A
0005435299733	10773	19	18C
0005435299763	10773	20	18D
0005435299782	10773	21	19A
0005435304139	10773	22	19B
0005433131690	10773	23	20A
0005435299751	10773	24	20D
0005435299759	10773	25	21B
0005435304141	10773	26	22B
0005433126816	10773	27	22C
0005435299764	10773	28	23A
0005435299753	10773	29	23B
0005435302230	29738	1	2B
0005435302233	29738	2	2D
0005435299811	29738	3	3D
0005433129310	29738	4	4C
0005435302234	29738	5	5A
0005435299810	29738	6	5C
0005435302229	29738	7	6A
0005433129309	29738	8	6C
0005433129307	29738	9	7A
0005433126875	29738	10	7B
0005435302232	29738	11	18A
0005435299809	29738	12	18C
0005435299808	29738	13	19A
0005435299807	29738	14	19C
0005433126877	29738	15	19D
0005433126876	29738	16	20A
0005433126878	29738	17	20B
0005433126879	29738	18	20D
0005433129308	29738	19	21A
0005435302231	29738	20	21C
0005434287432	2414	1	1A
0005434287420	2414	2	1B
0005434287429	2414	3	1D
0005433110020	2414	4	2A
0005432264491	2414	5	2B
0005434287431	2414	6	2C
0005433110029	2414	7	3A
0005434287425	2414	8	3C
0005434287422	2414	9	3D
0005433110008	2414	10	4B
0005434287421	2414	11	4C
0005434287419	2414	12	4D
0005434287430	2414	13	5A
0005434287437	2414	14	5B
0005434287423	2414	15	5C
0005433110030	2414	16	5D
0005434287424	2414	17	6A
0005434287426	2414	18	6B
0005434287434	2414	19	6C
0005433110081	2414	20	6D
0005434287435	2414	21	7A
0005434287417	2414	22	7B
0005434287418	2414	23	7C
0005434287416	2414	24	7D
0005432264490	2414	25	18A
0005434287433	2414	26	18C
0005434287428	2414	27	18D
0005433110028	2414	28	19B
0005433109999	2414	29	19D
0005432264489	2414	30	20A
0005434287415	2414	31	20C
0005434287427	2414	32	21A
0005434287438	2414	33	21C
0005433110038	2414	34	21D
0005433109998	2414	35	22A
0005434287436	2414	36	22C
0005434287439	2414	37	22D
0005434287301	26838	1	1A
0005434287255	26838	2	1B
0005434287276	26838	3	1C
0005434287195	26838	4	1D
0005433110129	26838	5	2A
0005433110134	26838	6	2B
0005434287189	26838	7	2C
0005433110125	26838	8	3A
0005433110126	26838	9	3B
0005434287256	26838	10	3D
0005434287297	26838	11	4B
0005434287257	26838	12	4C
0005433110127	26838	13	4D
0005434287331	26838	14	5A
0005434287247	26838	15	5C
0005434287263	26838	16	5D
0005434287299	26838	17	6A
0005434287222	26838	18	6B
0005433110132	26838	19	6C
0005434287289	26838	20	7B
0005434287300	26838	21	7C
0005434287221	26838	22	18A
0005433110133	26838	23	18C
0005434287302	26838	24	18D
0005433110131	26838	25	19A
0005433110124	26838	26	19C
0005434287298	26838	27	19D
0005434287248	26838	28	20A
0005434287176	26838	29	20B
0005433110123	26838	30	20C
0005434287268	26838	31	20D
0005433110128	26838	32	21A
0005433110130	26838	33	21B
0005434287260	26838	34	21C
0005434287266	26838	35	22A
0005434287188	26838	36	22B
0005433110122	26838	37	22C
0005434287290	26838	38	22D
0005434287275	26838	39	23A
0005434287209	26838	40	23B
0005434272184	25485	1	7A
0005435856232	25485	2	7D
0005435856231	25485	3	18A
0005435856229	25485	4	20C
0005435856230	25485	5	22D
0005434272203	26650	1	3B
0005434272202	26650	2	6C
0005434273087	26650	3	19A
0005434273086	26650	4	19D
0005434272201	26650	5	20B
0005435856196	26650	6	22C
0005435314820	6107	1	1B
0005434520311	6107	2	1C
0005435314821	6107	3	1D
0005434520315	6107	4	2A
0005434520308	6107	5	2B
0005435314802	6107	6	2D
0005434520330	6107	7	2C
0005434520313	6107	8	3A
0005434520325	6107	9	3C
0005434520322	6107	10	3D
0005435314811	6107	11	4A
0005434520319	6107	12	4B
0005435314818	6107	13	4C
0005434520316	6107	14	5B
0005434520328	6107	15	5C
0005434520306	6107	16	5D
0005435314812	6107	17	6C
0005434520326	6107	18	6D
0005434520324	6107	19	7A
0005434520317	6107	20	7B
0005434520309	6107	21	7C
0005434520310	6107	22	7D
0005434520318	6107	23	18A
0005435314810	6107	24	18B
0005435314837	6107	25	18C
0005434520305	6107	26	18D
0005435314836	6107	27	19A
0005435314805	6107	28	19B
0005434520323	6107	29	19C
0005435314819	6107	30	20A
0005434520327	6107	31	20B
0005434520314	6107	32	20D
0005435314828	6107	33	21A
0005434520321	6107	34	21B
0005434520329	6107	35	21C
0005434520307	6107	36	22A
0005434520312	6107	37	22B
0005434520320	6107	38	22D
0005434520304	6107	39	23A
0005435314814	6107	40	23B
0005435263597	7153	1	1A
0005433650740	7153	2	1C
0005433650748	7153	3	1D
0005435263580	7153	4	1F
0005433650695	7153	5	2A
0005435263594	7153	6	2C
0005435263511	7153	7	2D
0005435263596	7153	8	2F
0005433650736	7153	9	3A
0005435263553	7153	10	3C
0005433650739	7153	11	3D
0005433650720	7153	12	3F
0005433650750	7153	13	4A
0005435263590	7153	14	4C
0005435263606	7153	15	4D
0005435263567	7153	16	4E
0005433650749	7153	17	4F
0005433650698	7153	18	5A
0005433650726	7153	19	5C
0005433650751	7153	20	5D
0005435263582	7153	21	5E
0005433650737	7153	22	5F
0005433650719	7153	23	6A
0005433650712	7153	24	6C
0005433650716	7153	25	6D
0005435263554	7153	26	6E
0005433650738	7153	27	6F
0005433650699	7153	28	7A
0005433650692	7153	29	7C
0005433650724	7153	30	7D
0005433650702	7153	31	7E
0005433650721	7153	32	7F
0005433650723	7153	33	8A
0005433650705	7153	34	8C
0005435263603	7153	35	8D
0005433650700	7153	36	8E
0005433650746	7153	37	8F
0005433650701	7153	38	9A
0005433650713	7153	39	9C
0005433650697	7153	40	9D
0005433650735	7153	41	9E
0005435263607	7153	42	9F
0005433650728	7153	43	10A
0005435263604	7153	44	10C
0005433650743	7153	45	10E
0005433650744	7153	46	10D
0005435263608	7153	47	10F
0005435263538	7153	48	11A
0005433650691	7153	49	11C
0005435263599	7153	50	11D
0005433650725	7153	51	11E
0005435263569	7153	52	11F
0005433650731	7153	53	12A
0005433650730	7153	54	12C
0005435263593	7153	55	12D
0005433650747	7153	56	12F
0005435263584	7153	57	12E
0005435263589	7153	58	13A
0005435263578	7153	59	13C
0005433650696	7153	60	13D
0005433650690	7153	61	13E
0005435263583	7153	62	13F
0005435263579	7153	63	14A
0005433650727	7153	64	14C
0005433650709	7153	65	14E
0005435263600	7153	66	14D
0005433650729	7153	67	14F
0005435263610	7153	68	15A
0005435263588	7153	69	15C
0005433650745	7153	70	15D
0005433650741	7153	71	15E
0005435263611	7153	72	15F
0005433650694	7153	73	16A
0005433650711	7153	74	16C
0005433650732	7153	75	16D
0005433650706	7153	76	16E
0005433650693	7153	77	16F
0005433650707	7153	78	17A
0005435263595	7153	79	17C
0005433650718	7153	80	17D
0005435263577	7153	81	17E
0005435263564	7153	82	17F
0005433650704	7153	83	18A
0005433650734	7153	84	18C
0005433650722	7153	85	18D
0005435263605	7153	86	18E
0005435263598	7153	87	18F
0005433650710	7153	88	19A
0005433650708	7153	89	19C
0005433650714	7153	90	19D
0005433650717	7153	91	19E
0005433650733	7153	92	19F
0005433650715	7153	93	20A
0005435263581	7153	94	20C
0005433650703	7153	95	20D
0005433650742	7153	96	20F
0005435263666	27623	1	1A
0005435263670	27623	2	1D
0005433650666	27623	3	1F
0005433650487	27623	4	2A
0005433650477	27623	5	2F
0005433650578	27623	6	3A
0005435263653	27623	7	3F
0005435263655	27623	8	4A
0005435263676	27623	9	4D
0005433650599	27623	10	4E
0005435263665	27623	11	4F
0005433650622	27623	12	5A
0005433650558	27623	13	5C
0005435263663	27623	14	5D
0005435263664	27623	15	5E
0005433650562	27623	16	5F
0005435263657	27623	17	6A
0005433650612	27623	18	6D
0005433650474	27623	19	6E
0005433650561	27623	20	6F
0005433650559	27623	21	7A
0005433650534	27623	22	7C
0005433650672	27623	23	7E
0005435263669	27623	24	7F
0005435263678	27623	25	8A
0005435263658	27623	26	8E
0005435263660	27623	27	8F
0005433650568	27623	28	9A
0005433650555	27623	29	9D
0005435263668	27623	30	9E
0005435263659	27623	31	10C
0005433650565	27623	32	10D
0005433650473	27623	33	10F
0005433650570	27623	34	11A
0005435263656	27623	35	11D
0005433650547	27623	36	11E
0005435263672	27623	37	12A
0005433650531	27623	38	12E
0005433650533	27623	39	13A
0005435263675	27623	40	13C
0005435263674	27623	41	13E
0005433650571	27623	42	13F
0005435263661	27623	43	14A
0005435263671	27623	44	14C
0005433650634	27623	45	14D
0005433650523	27623	46	14E
0005433650591	27623	47	15C
0005435263654	27623	48	15E
0005433650553	27623	49	15F
0005433650600	27623	50	16C
0005433650564	27623	51	16D
0005435263662	27623	52	16E
0005433650620	27623	53	16F
0005433650592	27623	54	17A
0005433650605	27623	55	17C
0005433650560	27623	56	17F
0005435263677	27623	57	18E
0005433650486	27623	58	18F
0005433650613	27623	59	19A
0005433650554	27623	60	19F
0005435263652	27623	61	20A
0005433650621	27623	62	20C
0005435263667	27623	63	20D
0005435263673	27623	64	20E
0005433650532	27623	65	20F
0005433868679	4805	1	1A
0005433868672	4805	2	1B
0005433868675	4805	3	1C
0005433868673	4805	4	1D
0005433868670	4805	5	2A
0005433868695	4805	6	2C
0005433868702	4805	7	2D
0005433868693	4805	8	3B
0005433868699	4805	9	3C
0005433868678	4805	10	3D
0005433868680	4805	11	4A
0005433868691	4805	12	4B
0005433868684	4805	13	4D
0005433868696	4805	14	5A
0005433868687	4805	15	5B
0005433868671	4805	16	5C
0005433868700	4805	17	5D
0005433868707	4805	18	6B
0005433868710	4805	19	6C
0005433868676	4805	20	6D
0005433868674	4805	21	7A
0005433868706	4805	22	7B
0005433868701	4805	23	7C
0005433868708	4805	24	7D
0005433868683	4805	25	18A
0005433868689	4805	26	18B
0005433868677	4805	27	18D
0005433868686	4805	28	19A
0005433868704	4805	29	19B
0005433868688	4805	30	19C
0005435860468	4805	31	19D
0005433868690	4805	32	20A
0005433868697	4805	33	20C
0005433868709	4805	34	20D
0005433868681	4805	35	21B
0005433868694	4805	36	21C
0005433868698	4805	37	21D
0005435860480	4805	38	22A
0005433868692	4805	39	22B
0005433868682	4805	40	22C
0005433868705	4805	41	22D
0005433868703	4805	42	23A
0005433868685	4805	43	23B
0005433868410	32586	1	1A
0005433868186	32586	2	1C
0005433868305	32586	3	1D
0005433868269	32586	4	2B
0005433868317	32586	5	2C
0005433868387	32586	6	2D
0005433868127	32586	7	3B
0005433868406	32586	8	3C
0005433868428	32586	9	4D
0005433868386	32586	10	5A
0005435860509	32586	11	5B
0005433868349	32586	12	5C
0005433868318	32586	13	6A
0005433868330	32586	14	7A
0005433868262	32586	15	7B
0005433868288	32586	16	7C
0005433868289	32586	17	7D
0005433868385	32586	18	18B
0005433868361	32586	19	18C
0005435860510	32586	20	18D
0005433868140	32586	21	19A
0005435860508	32586	22	19B
0005433868295	32586	23	19C
0005433868427	32586	24	20B
0005433868356	32586	25	20C
0005433868336	32586	26	21B
0005434663498	3445	1	1A
0005434663499	3445	2	1B
0005435911413	3445	3	1C
0005434663487	3445	4	1D
0005434663497	3445	5	3B
0005434663490	3445	6	3C
0005434663501	3445	7	3D
0005434460519	3445	8	4C
0005434460520	3445	9	5A
0005434663489	3445	10	5D
0005434663486	3445	11	6A
0005434663491	3445	12	6C
0005434663496	3445	13	6D
0005434461660	3445	14	7A
0005435911438	3445	15	7D
0005434460518	3445	16	19B
0005434663495	3445	17	20A
0005434663493	3445	18	20B
0005435911412	3445	19	21B
0005434461661	3445	20	21C
0005434663494	3445	21	21D
0005434663500	3445	22	22B
0005434663492	3445	23	22D
0005435911436	3445	24	23A
0005434663488	3445	25	23B
0005435911498	12474	1	1B
0005434663343	12474	2	2A
0005435911500	12474	3	2D
0005434663446	12474	4	3B
0005434663350	12474	5	3C
0005434663447	12474	6	3D
0005435911497	12474	7	4B
0005435911502	12474	8	4C
0005434663382	12474	9	6A
0005434663398	12474	10	6C
0005434663363	12474	11	6D
0005434663395	12474	12	7D
0005435911496	12474	13	18A
0005435911501	12474	14	18B
0005434663399	12474	15	18C
0005434663362	12474	16	19D
0005435911495	12474	17	20C
0005434663385	12474	18	21C
0005434663321	12474	19	22B
0005435911499	12474	20	22C
0005434663351	12474	21	22D
0005434663344	12474	22	23A
0005433868385	14487	1	1A
0005433868386	14487	2	1C
0005433868356	14487	3	1D
0005435860509	14487	4	2B
0005433868317	14487	5	2C
0005433868295	14487	6	2D
0005433868318	14487	7	4B
0005433868428	14487	8	4C
0005433868186	14487	9	4D
0005435860510	14487	10	5B
0005433868361	14487	11	6A
0005433868289	14487	12	6B
0005433868288	14487	13	6C
0005433868140	14487	14	7B
0005433868269	14487	15	7A
0005433868427	14487	16	7C
0005433868349	14487	17	18A
0005433868127	14487	18	18B
0005433868262	14487	19	18D
0005435860508	14487	20	20B
0005433868330	14487	21	21A
0005433868305	14487	22	21C
0005433868336	14487	23	21D
0005433868406	14487	24	22A
0005433868387	14487	25	22B
0005433868410	14487	26	22C
0005433868632	32686	1	1A
0005433868653	32686	2	1B
0005433868647	32686	3	1C
0005433868656	32686	4	1D
0005433868667	32686	5	2A
0005435860471	32686	6	2B
0005433868633	32686	7	2C
0005435860477	32686	8	2D
0005433868654	32686	9	3A
0005433868669	32686	10	3B
0005433868634	32686	11	3C
0005433868643	32686	12	3D
0005433868657	32686	13	4A
0005435860476	32686	14	4B
0005433868649	32686	15	4C
0005433868638	32686	16	5A
0005433868635	32686	17	5B
0005433868655	32686	18	5C
0005435860462	32686	19	5D
0005433868636	32686	20	6A
0005433868645	32686	21	6B
0005433868637	32686	22	6C
0005433868652	32686	23	6D
0005433868659	32686	24	7A
0005435860472	32686	25	7C
0005433868648	32686	26	7D
0005433868644	32686	27	18A
0005433868641	32686	28	18B
0005433868650	32686	29	18C
0005433868642	32686	30	19A
0005433868665	32686	31	19B
0005433868662	32686	32	19C
0005433868646	32686	33	19D
0005433868651	32686	34	20A
0005433868660	32686	35	20B
0005433868664	32686	36	20C
0005435860475	32686	37	20D
0005433868658	32686	38	21A
0005433868630	32686	39	21B
0005433868666	32686	40	21C
0005433868668	32686	41	22A
0005433868663	32686	42	22B
0005433868639	32686	43	22C
0005433868661	32686	44	22D
0005433868631	32686	45	23A
0005433868640	32686	46	23B
0005432799340	12101	1	1A
0005432799393	12101	2	1B
0005432799529	12101	3	1C
0005432799521	12101	4	2A
0005432799470	12101	5	3A
0005432799267	12101	6	3C
0005432799282	12101	7	3D
0005432799354	12101	8	4A
0005432799406	12101	9	4B
0005432799322	12101	10	4D
0005432799283	12101	11	5A
0005432799377	12101	12	5B
0005432799440	12101	13	5D
0005432799472	12101	14	6A
0005432799379	12101	15	6B
0005432799390	12101	16	6D
0005432799387	12101	17	7A
0005432799266	12101	18	7B
0005432799471	12101	19	18A
0005432799378	12101	20	18B
0005432799409	12101	21	18D
0005432799438	12101	22	19A
0005432799435	12101	23	19C
0005432799427	12101	24	19D
0005432799441	12101	25	20A
0005432799373	12101	26	20B
0005432799252	12101	27	20C
0005432799353	12101	28	20D
0005432799395	12101	29	21A
0005432799369	12101	30	21B
0005432799394	12101	31	21C
0005432799339	12101	32	22D
0005432799410	12101	33	23B
0005432799594	14790	1	1A
0005432799604	14790	2	1B
0005432799612	14790	3	1D
0005432799608	14790	4	2D
0005432799606	14790	5	3B
0005432799599	14790	6	3D
0005432799595	14790	7	4B
0005432799596	14790	8	4C
0005432799598	14790	9	5C
0005432799611	14790	10	5D
0005432799591	14790	11	6A
0005432799617	14790	12	6B
0005432799590	14790	13	7A
0005432799616	14790	14	7B
0005432799592	14790	15	7C
0005432799609	14790	16	18A
0005432799603	14790	17	18B
0005432799613	14790	18	18C
0005432799597	14790	19	18D
0005432799602	14790	20	19B
0005432799593	14790	21	19C
0005432799600	14790	22	20A
0005432799607	14790	23	20B
0005432799605	14790	24	21C
0005432799614	14790	25	21D
0005432799610	14790	26	22B
0005432799601	14790	27	22C
0005432799615	14790	28	22D
0005432799589	14790	29	23B
0005434408173	7044	1	1A
0005434299703	7044	2	1C
0005434408131	7044	3	1D
0005435311035	7044	4	1F
0005434408144	7044	5	2D
0005434408181	7044	6	3A
0005435293258	7044	7	2F
0005434408142	7044	8	3D
0005434408129	7044	9	3C
0005435311022	7044	10	3F
0005434299715	7044	11	4A
0005434408176	7044	12	4C
0005434408154	7044	13	4B
0005434299716	7044	14	4D
0005434408169	7044	15	4E
0005434408145	7044	16	4F
0005434408157	7044	17	5B
0005434408126	7044	18	5A
0005434408132	7044	19	5D
0005434408161	7044	20	5C
0005434408184	7044	21	5E
0005435293255	7044	22	5F
0005434408165	7044	23	6B
0005434408140	7044	24	6A
0005434408166	7044	25	6C
0005435293259	7044	26	6D
0005432153980	7044	27	6E
0005434408159	7044	28	7A
0005435293189	7044	29	6F
0005434408188	7044	30	7C
0005432108266	7044	31	7D
0005435293250	7044	32	7E
0005435311033	7044	33	7F
0005434408130	7044	34	8B
0005434408139	7044	35	8D
0005434408172	7044	36	8F
0005434408138	7044	37	8E
0005432153982	7044	38	9A
0005435293238	7044	39	9B
0005435311036	7044	40	9C
0005434408148	7044	41	9D
0005434408153	7044	42	9F
0005434299709	7044	43	9E
0005434299711	7044	44	10B
0005434299695	7044	45	10D
0005434408163	7044	46	10C
0005434408150	7044	47	10E
0005434408136	7044	48	11A
0005435311034	7044	49	11B
0005434408171	7044	50	11D
0005434299702	7044	51	11C
0005432153984	7044	52	11E
0005434408135	7044	53	11F
0005434299704	7044	54	12A
0005434408156	7044	55	12B
0005434408152	7044	56	12D
0005434408158	7044	57	12C
0005434408182	7044	58	12E
0005434299712	7044	59	12F
0005434408168	7044	60	13B
0005434299697	7044	61	13A
0005434408179	7044	62	13C
0005434299710	7044	63	13D
0005434299708	7044	64	13E
0005434408187	7044	65	14B
0005434299696	7044	66	14A
0005434408160	7044	67	14C
0005434299713	7044	68	14D
0005432153981	7044	69	14F
0005434408186	7044	70	14E
0005435293254	7044	71	15B
0005434408127	7044	72	15C
0005434408178	7044	73	15D
0005434408141	7044	74	15E
0005432108267	7044	75	15F
0005434408170	7044	76	16B
0005434299714	7044	77	16A
0005434408177	7044	78	16C
0005435310988	7044	79	16D
0005434408180	7044	80	16E
0005434408175	7044	81	16F
0005434408133	7044	82	17B
0005435293195	7044	83	17A
0005435293167	7044	84	17C
0005435311026	7044	85	17E
0005435311013	7044	86	17D
0005434408151	7044	87	17F
0005432153983	7044	88	18A
0005434408183	7044	89	18B
0005435293188	7044	90	18D
0005434408162	7044	91	18C
0005435293197	7044	92	18F
0005434408137	7044	93	18E
0005434299700	7044	94	19A
0005434299694	7044	95	19B
0005434408134	7044	96	19C
0005434408185	7044	97	19E
0005435311029	7044	98	19F
0005434299705	7044	99	20A
0005435311045	7044	100	20C
0005435293213	7044	101	20B
0005434408128	7044	102	20D
0005435293252	7044	103	20E
0005434299698	7044	104	20F
0005435293196	7044	105	21A
0005434408155	7044	106	21C
0005434408167	7044	107	21D
0005434299699	7044	108	21F
0005432108265	7044	109	21E
0005434408174	7044	110	22B
0005434299701	7044	111	22A
0005434408149	7044	112	22C
0005434408146	7044	113	22D
0005434299707	7044	114	22F
0005434408147	7044	115	22E
0005434299717	7044	116	23A
0005434408143	7044	117	23B
0005432153979	7044	118	23C
0005435293253	7044	119	23E
0005434299706	7044	120	23D
0005434408164	7044	121	23F
0005435311125	26931	1	1A
0005434407531	26931	2	1C
0005434407662	26931	3	1D
0005434407606	26931	4	1F
0005434299487	26931	5	2C
0005435311130	26931	6	2A
0005434407548	26931	7	2D
0005434407415	26931	8	2F
0005435311120	26931	9	3C
0005434299484	26931	10	3A
0005434299459	26931	11	3D
0005434407393	26931	12	3F
0005434407705	26931	13	4B
0005434407424	26931	14	4A
0005434299604	26931	15	4D
0005434407511	26931	16	4C
0005434407482	26931	17	4E
0005434407522	26931	18	4F
0005435311119	26931	19	5B
0005435293326	26931	20	5A
0005435311116	26931	21	5C
0005434299653	26931	22	5D
0005434299485	26931	23	5E
0005434407580	26931	24	6A
0005434407547	26931	25	6C
0005434407701	26931	26	6B
0005434407425	26931	27	6D
0005434407469	26931	28	6F
0005434407716	26931	29	6E
0005435311124	26931	30	7B
0005434299546	26931	31	7A
0005434407654	26931	32	7C
0005434407532	26931	33	7E
0005434407356	26931	34	7D
0005432058402	26931	35	8B
0005435311122	26931	36	8C
0005432058403	26931	37	8D
0005434299486	26931	38	8F
0005435293334	26931	39	8E
0005435311137	26931	40	9A
0005434407578	26931	41	9B
0005434407579	26931	42	9C
0005434407732	26931	43	9F
0005435293336	26931	44	10C
0005434407338	26931	45	10B
0005434407655	26931	46	10D
0005434407607	26931	47	10E
0005435311126	26931	48	11A
0005434407306	26931	49	11B
0005434407514	26931	50	11D
0005435311118	26931	51	11C
0005434299455	26931	52	11E
0005434299548	26931	53	11F
0005434407664	26931	54	12A
0005434407733	26931	55	12B
0005434299536	26931	56	12D
0005434407574	26931	57	12C
0005434299581	26931	58	12E
0005434407614	26931	59	12F
0005435311131	26931	60	13A
0005435293327	26931	61	13C
0005435293330	26931	62	13B
0005435293331	26931	63	13D
0005434407526	26931	64	13E
0005434299469	26931	65	13F
0005434407605	26931	66	14A
0005435311123	26931	67	14C
0005435293332	26931	68	14B
0005434299489	26931	69	14D
0005434299530	26931	70	14E
0005434407615	26931	71	15A
0005435293335	26931	72	14F
0005434299547	26931	73	15B
0005434407704	26931	74	15E
0005434407737	26931	75	15D
0005435311134	26931	76	15F
0005435311132	26931	77	16C
0005434407349	26931	78	16B
0005434407617	26931	79	16E
0005434407575	26931	80	16D
0005434299540	26931	81	17A
0005435311115	26931	82	16F
0005435311133	26931	83	17B
0005434407432	26931	84	17C
0005434407600	26931	85	17E
0005434299488	26931	86	17D
0005434299503	26931	87	17F
0005434407556	26931	88	18A
0005434407339	26931	89	18B
0005434299470	26931	90	18D
0005435311136	26931	91	18C
0005434407746	26931	92	18E
0005435293329	26931	93	18F
0005434407567	26931	94	19A
0005435293328	26931	95	19B
0005435311127	26931	96	19D
0005435311129	26931	97	19C
0005434407534	26931	98	19E
0005434407468	26931	99	20A
0005435311128	26931	100	20B
0005434407405	26931	101	20C
0005434407544	26931	102	20E
0005434299580	26931	103	20D
0005434299579	26931	104	20F
0005432058404	26931	105	21B
0005434407336	26931	106	21A
0005434407406	26931	107	21C
0005434299522	26931	108	21D
0005435311121	26931	109	21E
0005435311117	26931	110	21F
0005434407731	26931	111	22B
0005434407712	26931	112	22A
0005434299521	26931	113	22C
0005434407717	26931	114	22D
0005434299539	26931	115	22F
0005435293325	26931	116	22E
0005434407419	26931	117	23B
0005434407599	26931	118	23A
0005435293333	26931	119	23C
0005434299551	26931	120	23E
0005434299573	26931	121	23D
0005435311135	26931	122	23F
0005432604598	6476	1	1A
0005432604578	6476	2	1C
0005432604610	6476	3	2A
0005432604602	6476	4	2B
0005432604595	6476	5	2C
0005432604609	6476	6	2D
0005432604584	6476	7	3A
0005432604591	6476	8	3B
0005435220490	6476	9	3C
0005432604596	6476	10	3D
0005432604579	6476	11	4A
0005432604605	6476	12	4B
0005432604588	6476	13	4C
0005432604589	6476	14	4D
0005432604611	6476	15	5A
0005432604593	6476	16	5B
0005434512140	6476	17	5C
0005432604607	6476	18	5D
0005432604603	6476	19	6A
0005434512141	6476	20	6B
0005432604590	6476	21	6C
0005432604580	6476	22	6D
0005432604604	6476	23	7A
0005432604594	6476	24	7B
0005432604582	6476	25	7C
0005432604612	6476	26	7D
0005432604583	6476	27	18A
0005432604586	6476	28	18C
0005432604613	6476	29	18D
0005434512142	6476	30	19A
0005432604585	6476	31	19B
0005432604599	6476	32	19C
0005432604614	6476	33	19D
0005434512138	6476	34	20A
0005432604601	6476	35	20B
0005432604577	6476	36	20C
0005432604597	6476	37	20D
0005432604587	6476	38	21A
0005432604608	6476	39	21B
0005432604592	6476	40	21C
0005432604600	6476	41	21D
0005434512136	6476	42	22A
0005432604606	6476	43	22B
0005435218114	6476	44	22C
0005434512139	6476	45	22D
0005434512137	6476	46	23A
0005432604581	6476	47	23B
0005432604362	21359	1	1A
0005432604199	21359	2	1C
0005432604249	21359	3	1D
0005432604158	21359	4	2A
0005432604200	21359	5	2B
0005432604230	21359	6	2C
0005432604317	21359	7	2D
0005434512124	21359	8	3A
0005434512083	21359	9	3B
0005435221523	21359	10	3C
0005434512122	21359	11	3D
0005432604205	21359	12	4A
0005432604241	21359	13	4B
0005432604305	21359	14	4C
0005432604272	21359	15	4D
0005432604135	21359	16	5A
0005432604298	21359	17	5C
0005432604198	21359	18	6A
0005432604129	21359	19	6C
0005432604261	21359	20	6D
0005432604257	21359	21	7A
0005432604262	21359	22	7B
0005432604368	21359	23	7C
0005432604206	21359	24	7D
0005432604238	21359	25	18A
0005432604128	21359	26	18B
0005434512120	21359	27	18D
0005435221062	21359	28	19A
0005432604361	21359	29	19B
0005432604204	21359	30	19D
0005432604071	21359	31	20A
0005432604175	21359	32	20D
0005432604351	21359	33	21B
0005432604012	21359	34	21C
0005434512121	21359	35	21D
0005432604136	21359	36	22A
0005434512123	21359	37	22B
0005435221063	21359	38	22C
0005432604178	21359	39	22D
0005432604057	21359	40	23A
0005435221522	21359	41	23B
0005433251672	15029	1	1A
0005433251661	15029	2	1C
0005434906966	15029	3	2A
0005434907100	15029	4	2C
0005434907136	15029	5	2D
0005433251663	15029	6	2F
0005434907138	15029	7	3C
0005434907061	15029	8	3D
0005433251671	15029	9	3F
0005434907101	15029	10	4C
0005433251680	15029	11	4E
0005434907154	15029	12	4D
0005434907015	15029	13	4F
0005434907289	15029	14	5A
0005434907182	15029	15	5D
0005434906924	15029	16	5E
0005433251654	15029	17	5F
0005433251669	15029	18	6D
0005433251660	15029	19	6E
0005433251673	15029	20	7A
0005433251674	15029	21	7C
0005433251682	15029	22	7D
0005434906854	15029	23	7E
0005434906943	15029	24	7F
0005434907066	15029	25	8A
0005433251666	15029	26	8C
0005433251683	15029	27	8F
0005433251668	15029	28	9C
0005433251658	15029	29	9D
0005434906908	15029	30	9E
0005433251681	15029	31	9F
0005433251667	15029	32	10A
0005434907060	15029	33	10D
0005434906980	15029	34	10E
0005434907239	15029	35	10F
0005433251676	15029	36	11A
0005434907214	15029	37	11C
0005434906998	15029	38	11E
0005434907065	15029	39	11F
0005433251675	15029	40	12A
0005434906867	15029	41	12C
0005433251662	15029	42	12E
0005433251659	15029	43	12F
0005434906999	15029	44	13A
0005434906981	15029	45	13C
0005434906866	15029	46	13D
0005434907075	15029	47	13F
0005433251670	15029	48	14A
0005434907156	15029	49	14D
0005434906953	15029	50	14E
0005434907143	15029	51	14F
0005433251665	15029	52	15C
0005434907149	15029	53	15D
0005434906909	15029	54	16A
0005433251656	15029	55	16C
0005434907102	15029	56	16D
0005433251657	15029	57	16E
0005434907305	15029	58	16F
0005433251679	15029	59	17A
0005434907288	15029	60	17C
0005433251678	15029	61	17D
0005433251655	15029	62	17E
0005433251664	15029	63	17F
0005434906963	15029	64	18A
0005433251677	15029	65	18D
0005433251685	15029	66	18E
0005434907233	15029	67	18F
0005434907173	15029	68	19A
0005434907084	15029	69	19C
0005434907068	15029	70	20A
0005434907139	15029	71	20C
0005433251684	15029	72	20D
0005434907067	15029	73	20E
0005434907140	15029	74	20F
0005434907552	25831	1	1A
0005434907572	25831	2	1C
0005434907559	25831	3	1D
0005433251482	25831	4	1F
0005434907534	25831	5	2A
0005434907597	25831	6	2D
0005433251327	25831	7	2C
0005434907549	25831	8	2F
0005434907596	25831	9	3A
0005434907537	25831	10	3C
0005434907554	25831	11	3D
0005434907569	25831	12	4A
0005434907550	25831	13	4D
0005433251416	25831	14	4E
0005434907575	25831	15	4F
0005434907576	25831	16	5A
0005434907579	25831	17	5C
0005434907536	25831	18	6A
0005434907563	25831	19	6C
0005434907540	25831	20	6D
0005434907580	25831	21	6F
0005433251460	25831	22	7A
0005434907594	25831	23	7C
0005434907561	25831	24	7D
0005434907568	25831	25	7E
0005434907578	25831	26	7F
0005434907544	25831	27	8A
0005434907588	25831	28	8C
0005434907591	25831	29	8D
0005433251380	25831	30	8E
0005434907543	25831	31	8F
0005434907590	25831	32	9C
0005433251409	25831	33	9A
0005434907595	25831	34	9D
0005434907577	25831	35	9E
0005433251397	25831	36	9F
0005433251518	25831	37	10C
0005434907593	25831	38	10D
0005434907584	25831	39	10F
0005434907553	25831	40	11A
0005434907542	25831	41	11C
0005434907589	25831	42	11D
0005434907535	25831	43	11E
0005433251371	25831	44	11F
0005433251452	25831	45	12A
0005433251483	25831	46	12C
0005434907570	25831	47	12D
0005434907538	25831	48	12E
0005434907562	25831	49	12F
0005433251377	25831	50	13A
0005434907545	25831	51	13C
0005434907585	25831	52	13D
0005434907548	25831	53	13E
0005434907564	25831	54	13F
0005434907539	25831	55	14C
0005434907546	25831	56	14D
0005434907592	25831	57	14E
0005434907582	25831	58	14F
0005433251339	25831	59	15A
0005434907566	25831	60	15C
0005434907555	25831	61	15D
0005433251272	25831	62	15E
0005434907587	25831	63	15F
0005434907573	25831	64	16D
0005434907560	25831	65	16E
0005434907567	25831	66	17A
0005434907583	25831	67	17C
0005434907556	25831	68	17D
0005433251341	25831	69	17E
0005433251391	25831	70	18A
0005434907581	25831	71	18C
0005434907541	25831	72	18D
0005434907571	25831	73	18E
0005433251522	25831	74	18F
0005434907586	25831	75	19A
0005434907574	25831	76	19C
0005433251379	25831	77	19D
0005434907547	25831	78	19E
0005434907558	25831	79	20C
0005434907557	25831	80	20D
0005434907565	25831	81	20E
0005434907551	25831	82	20F
0005433008926	14149	1	1A
0005433008918	14149	2	1C
0005433008929	14149	3	1D
0005433008920	14149	4	2D
0005433008901	14149	5	2F
0005433008913	14149	6	3D
0005433810518	14149	7	3F
0005433008898	14149	8	4C
0005433008923	14149	9	5D
0005433008906	14149	10	5E
0005433008912	14149	11	5F
0005433008907	14149	12	6A
0005433008916	14149	13	6C
0005433008917	14149	14	6D
0005433008937	14149	15	6E
0005433008936	14149	16	6F
0005433008924	14149	17	7D
0005433008930	14149	18	7E
0005433008899	14149	19	8A
0005433008931	14149	20	8F
0005433008914	14149	21	9A
0005433008927	14149	22	9E
0005433008905	14149	23	9F
0005433008925	14149	24	10E
0005433008922	14149	25	10F
0005433008904	14149	26	11A
0005433008910	14149	27	11C
0005433008903	14149	28	11D
0005433008919	14149	29	12A
0005433008933	14149	30	12C
0005433008932	14149	31	12D
0005433008928	14149	32	12E
0005433810519	14149	33	13D
0005433008895	14149	34	13F
0005433008902	14149	35	14A
0005433008892	14149	36	14C
0005433008909	14149	37	14D
0005433008915	14149	38	14E
0005433008890	14149	39	14F
0005433008891	14149	40	15E
0005433008921	14149	41	16C
0005433008911	14149	42	16F
0005433008897	14149	43	18F
0005433008893	14149	44	19C
0005433008896	14149	45	19D
0005433810520	14149	46	19F
0005433008908	14149	47	20A
0005433008934	14149	48	20C
0005433008935	14149	49	20D
0005433008894	14149	50	20E
0005433008900	14149	51	20F
0005433008251	22857	1	1A
0005433008489	22857	2	1C
0005433008165	22857	3	3C
0005433008267	22857	4	3D
0005433810573	22857	5	4D
0005433008417	22857	6	4F
0005433008574	22857	7	5A
0005433008400	22857	8	5F
0005433008558	22857	9	6D
0005433008450	22857	10	6E
0005433008576	22857	11	7D
0005433810574	22857	12	7E
0005433008565	22857	13	8A
0005433008522	22857	14	8C
0005433008597	22857	15	8D
0005433008285	22857	16	8E
0005433008244	22857	17	9C
0005433008268	22857	18	9D
0005433810576	22857	19	9F
0005433008652	22857	20	10D
0005433008653	22857	21	11C
0005433008425	22857	22	11F
0005433810577	22857	23	13C
0005433008462	22857	24	13D
0005433008672	22857	25	13E
0005433008363	22857	26	14D
0005433008261	22857	27	14E
0005433008262	22857	28	15C
0005433008465	22857	29	15F
0005433008252	22857	30	16A
0005433008588	22857	31	16C
0005433008476	22857	32	16D
0005433008445	22857	33	16E
0005433008598	22857	34	17A
0005433810575	22857	35	17D
0005433008514	22857	36	19A
0005433008607	22857	37	19D
0005433008166	22857	38	19E
0005433008493	22857	39	20D
0005433810572	22857	40	20E
0005433008692	22857	41	20F
0005435718909	27120	1	1A
0005435718884	27120	2	1D
0005435718903	27120	3	1F
0005435718864	27120	4	2D
0005435718910	27120	5	2F
0005435718911	27120	6	3A
0005435718838	27120	7	4C
0005435718844	27120	8	4F
0005435718850	27120	9	5A
0005435718912	27120	10	5D
0005435718833	27120	11	5E
0005435718851	27120	12	6C
0005435718916	27120	13	6D
0005435718879	27120	14	7A
0005435718917	27120	15	7D
0005435718889	27120	16	7F
0005435718876	27120	17	8E
0005435718915	27120	18	8F
0005435718892	27120	19	10C
0005435718859	27120	20	10E
0005435718897	27120	21	11A
0005435718914	27120	22	11E
0005435718896	27120	23	11F
0005435718904	27120	24	12A
0005435718900	27120	25	13D
0005435718913	27120	26	13F
0005435718832	27120	27	14D
0005435718899	27120	28	14E
0005435718918	27120	29	14F
0005435718901	27120	30	15C
0005435718866	27120	31	15D
0005435718842	27120	32	15E
0005435718890	27120	33	15F
0005435718891	27120	34	16C
0005435718860	27120	35	16F
0005435718908	27120	36	18C
0005435718845	27120	37	18D
0005435718905	27120	38	18F
0005435718893	27120	39	19A
0005435718902	27120	40	19D
0005435718887	27120	41	19F
0005435718919	27120	42	20C
0005434925732	14959	1	1A
0005434925652	14959	2	1D
0005434925540	14959	3	1F
0005434925721	14959	4	2D
0005434925678	14959	5	3F
0005434925727	14959	6	4C
0005434925625	14959	7	4D
0005434925735	14959	8	5C
0005434925707	14959	9	6C
0005434925694	14959	10	6E
0005434925676	14959	11	7E
0005434925740	14959	12	10A
0005434925677	14959	13	10C
0005434925713	14959	14	11D
0005434925741	14959	15	12A
0005434925665	14959	16	12D
0005434925728	14959	17	12F
0005434925685	14959	18	14A
0005434925704	14959	19	14E
0005434925541	14959	20	15A
0005434925729	14959	21	16A
0005434925595	14959	22	16D
0005434925693	14959	23	16F
0005434925724	14959	24	17A
0005434925667	14959	25	19A
0005434925544	14959	26	19C
0005434925580	14959	27	20A
0005434925624	14959	28	20E
0005434925969	20526	1	1D
0005434925968	20526	2	2F
0005434925981	20526	3	3F
0005434925975	20526	4	4A
0005434925982	20526	5	4F
0005434925977	20526	6	6C
0005434925974	20526	7	6D
0005434925970	20526	8	6E
0005434925985	20526	9	7C
0005434925976	20526	10	7F
0005434925988	20526	11	8D
0005434925979	20526	12	9A
0005434925983	20526	13	9F
0005434925987	20526	14	10E
0005434925965	20526	15	10F
0005434925971	20526	16	11F
0005434925966	20526	17	12C
0005434925963	20526	18	12E
0005434925972	20526	19	13F
0005434925980	20526	20	15D
0005434925986	20526	21	16C
0005434925967	20526	22	16F
0005434925964	20526	23	18C
0005434925984	20526	24	18F
0005434925973	20526	25	19C
0005434925978	20526	26	20E
0005435487966	15827	1	1B
0005435487965	15827	2	1C
0005435999206	15827	3	1D
0005435999207	15827	4	2A
0005435487968	15827	5	2C
0005435487971	15827	6	2D
0005435999210	15827	7	3A
0005435487976	15827	8	3B
0005435999179	15827	9	3C
0005435487969	15827	10	3D
0005435487978	15827	11	4A
0005435999175	15827	12	4B
0005435487975	15827	13	4D
0005435999178	15827	14	5A
0005435999174	15827	15	5B
0005435487970	15827	16	5C
0005435487981	15827	17	5D
0005435999205	15827	18	6A
0005435999187	15827	19	6B
0005435487973	15827	20	6C
0005435487980	15827	21	7A
0005435999199	15827	22	7B
0005435487967	15827	23	7C
0005435487977	15827	24	7D
0005435487979	15827	25	18A
0005435999202	15827	26	18B
0005435999192	15827	27	18C
0005435999182	15827	28	18D
0005435999188	15827	29	19B
0005435999127	15827	30	19D
0005435487974	15827	31	20A
0005435487983	15827	32	20D
0005435999204	15827	33	21A
0005435487984	15827	34	21C
0005435487972	15827	35	21D
0005435999198	15827	36	22A
0005435487982	15827	37	22C
0005435999227	15827	38	22D
0005435487964	15827	39	23A
0005435487763	19710	1	1A
0005435999344	19710	2	1B
0005435999352	19710	3	1C
0005435487803	19710	4	2A
0005435487760	19710	5	2C
0005435999356	19710	6	2D
0005435999346	19710	7	3A
0005435999348	19710	8	3B
0005435999355	19710	9	3C
0005435487752	19710	10	3D
0005435487661	19710	11	4A
0005435487664	19710	12	4D
0005435999339	19710	13	4C
0005435999340	19710	14	5A
0005435487759	19710	15	5B
0005435999335	19710	16	5C
0005435999343	19710	17	5D
0005435999338	19710	18	6A
0005435999336	19710	19	6B
0005435999351	19710	20	6D
0005435487713	19710	21	7A
0005435487726	19710	22	7B
0005435487690	19710	23	7C
0005435999349	19710	24	7D
0005435487728	19710	25	18A
0005435999350	19710	26	18B
0005435999341	19710	27	18D
0005435487837	19710	28	19A
0005435999354	19710	29	19B
0005435487780	19710	30	19C
0005435487743	19710	31	19D
0005435487678	19710	32	20A
0005435999347	19710	33	20C
0005435999337	19710	34	20D
0005435487725	19710	35	21A
0005435487705	19710	36	21C
0005435999345	19710	37	21D
0005435999353	19710	38	22B
0005435487753	19710	39	22C
0005435999342	19710	40	22D
0005435487665	19710	41	23A
0005435487838	19710	42	23B
0005432660833	5976	1	1A
0005435839639	5976	2	1F
0005432660831	5976	3	2F
0005435839623	5976	4	2D
0005432658608	5976	5	3A
0005435472813	5976	6	3C
0005435472792	5976	7	4A
0005432659720	5976	8	3F
0005435839641	5976	9	4D
0005435839631	5976	10	4C
0005435839630	5976	11	5A
0005435839634	5976	12	4F
0005435839640	5976	13	5C
0005435839625	5976	14	5F
0005435839647	5976	15	5D
0005435839643	5976	16	6B
0005435472789	5976	17	6F
0005432660834	5976	18	7C
0005435839644	5976	19	7B
0005435472797	5976	20	8A
0005432537063	5976	21	8B
0005432537049	5976	22	8C
0005435472852	5976	23	8E
0005435472791	5976	24	9B
0005435839636	5976	25	9A
0005435839635	5976	26	9D
0005435472770	5976	27	10A
0005435472809	5976	28	9F
0005432658606	5976	29	10B
0005435472713	5976	30	10E
0005432142272	5976	31	10F
0005435839632	5976	32	11B
0005435472810	5976	33	11F
0005435472716	5976	34	12B
0005432142273	5976	35	12A
0005432537052	5976	36	12D
0005432659721	5976	37	13A
0005432537050	5976	38	13B
0005435472777	5976	39	13D
0005432658607	5976	40	14A
0005435839645	5976	41	14B
0005435839646	5976	42	14D
0005435472851	5976	43	14C
0005432660832	5976	44	14F
0005432142271	5976	45	15B
0005435839648	5976	46	15A
0005435839621	5976	47	15D
0005435472796	5976	48	15C
0005435472776	5976	49	15E
0005435839624	5976	50	16A
0005435839633	5976	51	16C
0005432537047	5976	52	16B
0005432537051	5976	53	16D
0005435472801	5976	54	17A
0005435472802	5976	55	16F
0005432537048	5976	56	17B
0005435472808	5976	57	17D
0005435839642	5976	58	17C
0005432537046	5976	59	17F
0005432142270	5976	60	17E
0005435839627	5976	61	18B
0005435839628	5976	62	19A
0005435839629	5976	63	18F
0005432537064	5976	64	19C
0005435839626	5976	65	19B
0005435839622	5976	66	19E
0005435839638	5976	67	20F
0005435472800	5976	68	21A
0005432142274	5976	69	21D
0005435839637	5976	70	21F
0005435839473	18064	1	1C
0005435839293	18064	2	1D
0005435839463	18064	3	2A
0005435472907	18064	4	3F
0005435839390	18064	5	4D
0005435472902	18064	6	6E
0005432667440	18064	7	6F
0005435472910	18064	8	7C
0005435839427	18064	9	8A
0005435472909	18064	10	7F
0005435472900	18064	11	8D
0005435839429	18064	12	8C
0005435472905	18064	13	9A
0005435472906	18064	14	9F
0005435839365	18064	15	9D
0005435839411	18064	16	10A
0005432537072	18064	17	10C
0005435839521	18064	18	10B
0005435472903	18064	19	10E
0005432660806	18064	20	11B
0005432667448	18064	21	11E
0005435839428	18064	22	12C
0005432660802	18064	23	12E
0005435472908	18064	24	12D
0005435839357	18064	25	13C
0005435839376	18064	26	13B
0005435839348	18064	27	14A
0005435839467	18064	28	14E
0005435472915	18064	29	15B
0005432667449	18064	30	15E
0005432667446	18064	31	16D
0005432664125	18064	32	16C
0005435472904	18064	33	17B
0005435472914	18064	34	17D
0005435839522	18064	35	18A
0005432537073	18064	36	18D
0005435472913	18064	37	18C
0005432667445	18064	38	18E
0005435472911	18064	39	19E
0005435839292	18064	40	19D
0005435839466	18064	41	19F
0005435839366	18064	42	20B
0005435472912	18064	43	20A
0005435472901	18064	44	20C
0005435839368	18064	45	20E
0005435839419	18064	46	21C
0005435472916	18064	47	21F
0005433462733	19915	1	4H
0005433462741	19915	2	5B
0005433460417	19915	3	5C
0005433462737	19915	4	13A
0005433460416	19915	5	14B
0005433462728	19915	6	14G
0005433460422	19915	7	15H
0005433460420	19915	8	16A
0005433462732	19915	9	17E
0005433460421	19915	10	17H
0005433462731	19915	11	18A
0005433462739	19915	12	18H
0005433462738	19915	13	22B
0005433460424	19915	14	22D
0005433462740	19915	15	23G
0005433460418	19915	16	25E
0005433460423	19915	17	28F
0005433462730	19915	18	29A
0005433460425	19915	19	30G
0005433460411	19915	20	34H
0005433462729	19915	21	35H
0005433462725	19915	22	36H
0005433460415	19915	23	37E
0005433462722	19915	24	38A
0005433462736	19915	25	38B
0005433285194	23017	1	1A
0005435103973	23017	2	1D
0005433285274	23017	3	1F
0005435103975	23017	4	2C
0005433285154	23017	5	2D
0005433285281	23017	6	2F
0005433285164	23017	7	4E
0005433285220	23017	8	4F
0005435103968	23017	9	5C
0005433285276	23017	10	5F
0005433285273	23017	11	6B
0005435103976	23017	12	6D
0005435103969	23017	13	6C
0005435103974	23017	14	6F
0005433285260	23017	15	6E
0005433285205	23017	16	7E
0005433285270	23017	17	8A
0005433285211	23017	18	7F
0005433285193	23017	19	8B
0005433285254	23017	20	8D
0005435103972	23017	21	9A
0005435103977	23017	22	9D
0005433285153	23017	23	9E
0005433285160	23017	24	10B
0005435103970	23017	25	10E
0005435103971	23017	26	12A
0005433285271	23017	27	12E
0005433285044	23017	28	13B
0005435103978	23017	29	13D
0005433285201	23017	30	13C
0005433285210	23017	31	15D
0005433285255	23017	32	16A
0005433285110	23017	33	17A
0005433285306	23017	34	16F
0005433285307	23017	35	18C
0005433285112	23017	36	20C
0005433285269	23017	37	20B
0005433285282	23017	38	21D
0005433285163	23017	39	22E
0005433285197	23017	40	23B
0005435103896	32055	1	1A
0005433285507	32055	2	1F
0005435103891	32055	3	2A
0005435103904	32055	4	2C
0005435103860	32055	5	3A
0005435103888	32055	6	4B
0005435103907	32055	7	5A
0005433285504	32055	8	6D
0005433285493	32055	9	6F
0005435103901	32055	10	6E
0005433285490	32055	11	7B
0005435103893	32055	12	7D
0005433285489	32055	13	7F
0005435103886	32055	14	7E
0005433285491	32055	15	8C
0005435103885	32055	16	8B
0005433285517	32055	17	10D
0005435103863	32055	18	11A
0005433285495	32055	19	11E
0005433285516	32055	20	12E
0005435103867	32055	21	13C
0005433285506	32055	22	14A
0005435103903	32055	23	14D
0005433285512	32055	24	14F
0005433285488	32055	25	15E
0005433285515	32055	26	16A
0005433285510	32055	27	16F
0005435103899	32055	28	16E
0005433285505	32055	29	17C
0005433285496	32055	30	17F
0005433285508	32055	31	18A
0005433285511	32055	32	18C
0005433285509	32055	33	18F
0005433285514	32055	34	18E
0005433285492	32055	35	19B
0005435103902	32055	36	19E
0005433285499	32055	37	19F
0005433285513	32055	38	20C
0005433285494	32055	39	21A
0005433285501	32055	40	21B
0005435103868	32055	41	21C
0005433285497	32055	42	21E
0005435103869	32055	43	21F
0005433285503	32055	44	22D
0005433285498	32055	45	22F
0005435103861	32055	46	23B
0005433285502	32055	47	23C
0005433285500	32055	48	23D
0005432892760	19948	1	1A
0005432892773	19948	2	1F
0005432802447	19948	3	1C
0005432802474	19948	4	2C
0005433111509	19948	5	2A
0005432802455	19948	6	2D
0005432802437	19948	7	3A
0005432802466	19948	8	2F
0005432802489	19948	9	4D
0005432892766	19948	10	4C
0005433112378	19948	11	5C
0005433112379	19948	12	5D
0005432802494	19948	13	6B
0005432802497	19948	14	6A
0005433112374	19948	15	6C
0005432802481	19948	16	6E
0005433112377	19948	17	7B
0005432892769	19948	18	6F
0005433112380	19948	19	7C
0005432892765	19948	20	7E
0005432802439	19948	21	7D
0005432802443	19948	22	7F
0005433112373	19948	23	8B
0005432802450	19948	24	8A
0005433111510	19948	25	8C
0005432892775	19948	26	8F
0005432802454	19948	27	8E
0005433111506	19948	28	9B
0005432892768	19948	29	9A
0005432802459	19948	30	9D
0005432802469	19948	31	9C
0005433112382	19948	32	9F
0005432892764	19948	33	9E
0005433112375	19948	34	10C
0005432802500	19948	35	10E
0005432802441	19948	36	10D
0005432802445	19948	37	11A
0005433111518	19948	38	10F
0005432802470	19948	39	11B
0005432802440	19948	40	11D
0005432892770	19948	41	11E
0005432802436	19948	42	12A
0005433111519	19948	43	12D
0005432802467	19948	44	12B
0005433111516	19948	45	12E
0005432802438	19948	46	13A
0005433111512	19948	47	12F
0005432892772	19948	48	13C
0005432892774	19948	49	13B
0005432802471	19948	50	13E
0005433111508	19948	51	13D
0005433112383	19948	52	14B
0005433112376	19948	53	14A
0005433111505	19948	54	14D
0005433111513	19948	55	14C
0005432802465	19948	56	14E
0005432802453	19948	57	15B
0005432892762	19948	58	15A
0005432802479	19948	59	15D
0005433111517	19948	60	15C
0005433111504	19948	61	15E
0005433111511	19948	62	16A
0005432802452	19948	63	16B
0005432802480	19948	64	16D
0005432892761	19948	65	16F
0005432802487	19948	66	16E
0005432802451	19948	67	17B
0005433112381	19948	68	17D
0005433111514	19948	69	17F
0005432802473	19948	70	18B
0005433112372	19948	71	18A
0005432802446	19948	72	18C
0005432802499	19948	73	18E
0005433111515	19948	74	19A
0005432892771	19948	75	18F
0005432802442	19948	76	19C
0005432802490	19948	77	19D
0005433111507	19948	78	20A
0005432892767	19948	79	19F
0005432892763	19948	80	19E
0005433112371	19948	81	20D
0005432802472	19948	82	20C
0005432892759	19948	83	20E
0005432802468	19948	84	21D
0005433111503	19948	85	21F
0005432802488	19948	86	21E
0005432428924	30620	1	1C
0005435214041	30620	2	1A
0005434067488	30620	3	1G
0005432527604	30620	4	1D
0005435213999	30620	5	1K
0005432527255	30620	6	1H
0005435214061	30620	7	2D
0005432527855	30620	8	2A
0005432527803	30620	9	2H
0005434067550	30620	10	2G
0005432528356	30620	11	3A
0005432527802	30620	12	2K
0005432528359	30620	13	3D
0005432528187	30620	14	3C
0005432428916	30620	15	3K
0005435214000	30620	16	3H
0005435214045	30620	17	3G
0005434067498	30620	18	4A
0005434067708	30620	19	4G
0005435725638	30620	20	4D
0005432527718	30620	21	4K
0005432527673	30620	22	4H
0005432527574	30620	23	5C
0005432528293	30620	24	5H
0005435214044	30620	25	5G
0005432527786	30620	26	11A
0005432527688	30620	27	5K
0005435214032	30620	28	11E
0005434067359	30620	29	11D
0005434067709	30620	30	11C
0005435214002	30620	31	11F
0005432528132	30620	32	11G
0005435214048	30620	33	12A
0005434067461	30620	34	12F
0005432527388	30620	35	12D
0005432527398	30620	36	12G
0005432528015	30620	37	12K
0005435214005	30620	38	12H
0005432527664	30620	39	13D
0005432211558	30620	40	13C
0005432527726	30620	41	13A
0005435213996	30620	42	13F
0005434066987	30620	43	13E
0005432527488	30620	44	13K
0005434067234	30620	45	13H
0005432527326	30620	46	13G
0005432527597	30620	47	14A
0005435214037	30620	48	14E
0005432528044	30620	49	14D
0005435214025	30620	50	14C
0005432528096	30620	51	14F
0005432527470	30620	52	14K
0005432159889	30620	53	14H
0005432527672	30620	54	14G
0005435214014	30620	55	15C
0005434067191	30620	56	15E
0005432527549	30620	57	15H
0005432527518	30620	58	15G
0005435213995	30620	59	16A
0005435214038	30620	60	15K
0005432528003	30620	61	16D
0005432527681	30620	62	16C
0005432528038	30620	63	16F
0005432528021	30620	64	16E
0005434067441	30620	65	16H
0005433656694	30620	66	16G
0005434067420	30620	67	17A
0005432527901	30620	68	16K
0005432527503	30620	69	17E
0005435214023	30620	70	17D
0005432527537	30620	71	17G
0005432527680	30620	72	17F
0005435630989	30620	73	18A
0005432527378	30620	74	17K
0005432211551	30620	75	18B
0005432527079	30620	76	18D
0005434067101	30620	77	18C
0005432527733	30620	78	18F
0005432527772	30620	79	18E
0005432528004	30620	80	18K
0005432527827	30620	81	18J
0005432527894	30620	82	18H
0005434067589	30620	83	19B
0005432527852	30620	84	19D
0005432527801	30620	85	19C
0005435214015	30620	86	19F
0005432527413	30620	87	19E
0005432527969	30620	88	19J
0005435214012	30620	89	19H
0005435214047	30620	90	19G
0005435214008	30620	91	19K
0005435214027	30620	92	20C
0005432527674	30620	93	20B
0005432527753	30620	94	20A
0005434067462	30620	95	20E
0005432527399	30620	96	20D
0005432527618	30620	97	20F
0005432527244	30620	98	20K
0005434067421	30620	99	20J
0005432211553	30620	100	21B
0005432527225	30620	101	21A
0005432527686	30620	102	21D
0005434067355	30620	103	21C
0005435214053	30620	104	21E
0005432527517	30620	105	21J
0005435214033	30620	106	21G
0005435725635	30620	107	22A
0005432528167	30620	108	21K
0005434067350	30620	109	22C
0005435214051	30620	110	22F
0005432527810	30620	111	22E
0005435214026	30620	112	22D
0005435214006	30620	113	22H
0005432527679	30620	114	22J
0005432527649	30620	115	23B
0005432527866	30620	116	23A
0005432211557	30620	117	23D
0005432527592	30620	118	23F
0005432527389	30620	119	23E
0005434067473	30620	120	23H
0005432527993	30620	121	23G
0005432527256	30620	122	23K
0005435213998	30620	123	24F
0005432527647	30620	124	24E
0005435214011	30620	125	24D
0005435214028	30620	126	25B
0005435214049	30620	127	25A
0005435214030	30620	128	24G
0005432527853	30620	129	25D
0005432527277	30620	130	25C
0005432527411	30620	131	25F
0005432527641	30620	132	25H
0005432527671	30620	133	25G
0005434067585	30620	134	26A
0005432527532	30620	135	25K
0005435214039	30620	136	26C
0005432528227	30620	137	26B
0005434067354	30620	138	26E
0005435214052	30620	139	26G
0005432527683	30620	140	26J
0005434067613	30620	141	26H
0005432428933	30620	142	27B
0005435214021	30620	143	27A
0005432527734	30620	144	26K
0005432527425	30620	145	27D
0005435214003	30620	146	27C
0005432528019	30620	147	27F
0005434067213	30620	148	27E
0005432527469	30620	149	27H
0005434067563	30620	150	27G
0005432527701	30620	151	27K
0005435214043	30620	152	27J
0005434067269	30620	153	28B
0005432528152	30620	154	28A
0005432527538	30620	155	28E
0005432526976	30620	156	28C
0005432527762	30620	157	28G
0005434067333	30620	158	28F
0005435214022	30620	159	28J
0005435213994	30620	160	28H
0005432527677	30620	161	29B
0005435630990	30620	162	28K
0005432527658	30620	163	29D
0005432527562	30620	164	29C
0005432527700	30620	165	29F
0005435725637	30620	166	29E
0005432528153	30620	167	29H
0005435630988	30620	168	29K
0005434067650	30620	169	29J
0005434067330	30620	170	30C
0005432537044	30620	171	30B
0005432527876	30620	172	30A
0005432527940	30620	173	30E
0005434067433	30620	174	30D
0005434067144	30620	175	30G
0005432527619	30620	176	30F
0005435214019	30620	177	30K
0005432528358	30620	178	30J
0005432527687	30620	179	30H
0005432527650	30620	180	31B
0005435214034	30620	181	31A
0005435214050	30620	182	31C
0005435214007	30620	183	31F
0005435214035	30620	184	31E
0005432211550	30620	185	31J
0005432527167	30620	186	31H
0005432527550	30620	187	31G
0005432527747	30620	188	32A
0005435214024	30620	189	31K
0005435214058	30620	190	32E
0005432527598	30620	191	32D
0005432527941	30620	192	32G
0005432527959	30620	193	32F
0005432211552	30620	194	32K
0005432428909	30620	195	32J
0005435214055	30620	196	33B
0005434067586	30620	197	33A
0005435214040	30620	198	33D
0005434067342	30620	199	33C
0005432527724	30620	200	33F
0005432527573	30620	201	33E
0005435214060	30620	202	33J
0005434067381	30620	203	33H
0005432527659	30620	204	33G
0005434067233	30620	205	34A
0005434067608	30620	206	33K
0005432528034	30620	207	34B
0005433656696	30620	208	34E
0005434067434	30620	209	34D
0005435213993	30620	210	34C
0005432527663	30620	211	34G
0005432527899	30620	212	34F
0005432527300	30620	213	34J
0005432159888	30620	214	35D
0005432528113	30620	215	35C
0005432528020	30620	216	35F
0005432527468	30620	217	35E
0005432527426	30620	218	35H
0005432537058	30620	219	35G
0005432533282	30620	220	36A
0005434067614	30620	221	35K
0005435214009	30620	222	35J
0005432527954	30620	223	36B
0005435214031	30620	224	36D
0005432428923	30620	225	36G
0005432527385	30620	226	36F
0005434067361	30620	227	36K
0005432527600	30620	228	36J
0005433656695	30620	229	36H
0005434067391	30620	230	37B
0005432211554	30620	231	37A
0005432527900	30620	232	37D
0005432527787	30620	233	37C
0005432527178	30620	234	37G
0005432527608	30620	235	37F
0005434067490	30620	236	37E
0005435214010	30620	237	37H
0005434067257	30620	238	38A
0005432528292	30620	239	37K
0005432527719	30620	240	37J
0005432527723	30620	241	38C
0005435214042	30620	242	38H
0005435214004	30620	243	39A
0005432527980	30620	244	39C
0005434067422	30620	245	39B
0005432527640	30620	246	39E
0005432528128	30620	247	39G
0005432527939	30620	248	40A
0005434067072	30620	249	39K
0005434067538	30620	250	39J
0005432527475	30620	251	40C
0005432526977	30620	252	40B
0005435214054	30620	253	40E
0005434067440	30620	254	40D
0005432527752	30620	255	40G
0005432211555	30620	256	40F
0005432528035	30620	257	40J
0005432527646	30620	258	40H
0005432535806	30620	259	41B
0005435725636	30620	260	41A
0005434067106	30620	261	40K
0005432528154	30620	262	41D
0005435214017	30620	263	41C
0005432527476	30620	264	41F
0005432527893	30620	265	41J
0005432527665	30620	266	41H
0005435214046	30620	267	41G
0005435214056	30620	268	42A
0005432527684	30620	269	41K
0005434067126	30620	270	42D
0005434067190	30620	271	42H
0005432159890	30620	272	42G
0005432527406	30620	273	42J
0005432527817	30620	274	43B
0005432527276	30620	275	43A
0005435213997	30620	276	42K
0005432537055	30620	277	43D
0005434067525	30620	278	43C
0005434067097	30620	279	43F
0005434067465	30620	280	43E
0005432159891	30620	281	43H
0005434067380	30620	282	43G
0005434067555	30620	283	44A
0005432527474	30620	284	43K
0005432528357	30620	285	44C
0005435214001	30620	286	44E
0005435214036	30620	287	44D
0005432527624	30620	288	44H
0005432428929	30620	289	44G
0005434067251	30620	290	44K
0005432527504	30620	291	44J
0005432527301	30620	292	45B
0005435214020	30620	293	45A
0005435214059	30620	294	45C
0005432527666	30620	295	45F
0005434067329	30620	296	45E
0005432528228	30620	297	45D
0005435214057	30620	298	45H
0005432527842	30620	299	45G
0005434067328	30620	300	46A
0005434067272	30620	301	45K
0005432428915	30620	302	45J
0005434067143	30620	303	46C
0005432528039	30620	304	46E
0005432527828	30620	305	46D
0005434067096	30620	306	46F
0005435214018	30620	307	46J
0005434067357	30620	308	46H
0005435725634	30620	309	47A
0005432528102	30620	310	46K
0005432527605	30620	311	47D
0005435214013	30620	312	47C
0005432527765	30620	313	47G
0005432527678	30620	314	47F
0005432527384	30620	315	47E
0005434067459	30620	316	48A
0005434067472	30620	317	47K
0005432528258	30620	318	47H
0005432428920	30620	319	48D
0005432528257	30620	320	48C
0005432533284	30620	321	48F
0005432527303	30620	322	48E
0005434067514	30620	323	48H
0005434067492	30620	324	49A
0005434067084	30620	325	48K
0005434067510	30620	326	49E
0005434067491	30620	327	49D
0005432527758	30620	328	49C
0005432535805	30620	329	49G
0005432527662	30620	330	49F
0005432527186	30620	331	49K
0005432527797	30620	332	49H
0005434067358	30620	333	50C
0005432533283	30620	334	50E
0005432527748	30620	335	50D
0005432211556	30620	336	50H
0005435214029	30620	337	50G
0005432537056	30620	338	50F
0005434067595	30620	339	51F
0005432428934	30620	340	51E
0005435214016	30620	341	51D
0005433368144	24820	1	1A
0005433368142	24820	2	1C
0005433368149	24820	3	1F
0005435652807	24820	4	1D
0005435652797	24820	5	2A
0005433368148	24820	6	2C
0005433368166	24820	7	2D
0005435652645	24820	8	2F
0005433368146	24820	9	3A
0005433368150	24820	10	3C
0005433368169	24820	11	3F
0005433368164	24820	12	4A
0005435652814	24820	13	4C
0005435652897	24820	14	4D
0005433368161	24820	15	4E
0005433368152	24820	16	4F
0005433368167	24820	17	5A
0005435652889	24820	18	5C
0005433368155	24820	19	5D
0005433368145	24820	20	5E
0005433368160	24820	21	5F
0005435652930	24820	22	6A
0005435652821	24820	23	6C
0005435653068	24820	24	6D
0005433368176	24820	25	6E
0005435652863	24820	26	7A
0005435653045	24820	27	7C
0005433368147	24820	28	7D
0005435653046	24820	29	7E
0005433368177	24820	30	7F
0005433368141	24820	31	8A
0005433368168	24820	32	8C
0005435652646	24820	33	8D
0005435652975	24820	34	8E
0005435652782	24820	35	9A
0005435652943	24820	36	9C
0005433368173	24820	37	9F
0005433368157	24820	38	10A
0005435652924	24820	39	10C
0005435652926	24820	40	10D
0005433368151	24820	41	10E
0005435652878	24820	42	11A
0005435652967	24820	43	11D
0005435652925	24820	44	11E
0005433368154	24820	45	11F
0005433368159	24820	46	12A
0005433368174	24820	47	12C
0005435652864	24820	48	12E
0005433368140	24820	49	12F
0005435652795	24820	50	13A
0005435652896	24820	51	13C
0005435652808	24820	52	13D
0005435652932	24820	53	13E
0005435652809	24820	54	14A
0005433368163	24820	55	14F
0005433368153	24820	56	15A
0005435653059	24820	57	15C
0005435652894	24820	58	15D
0005435652796	24820	59	15E
0005433368175	24820	60	15F
0005435652895	24820	61	16A
0005435653037	24820	62	16C
0005433368165	24820	63	16E
0005433368156	24820	64	16F
0005435652868	24820	65	17C
0005435653002	24820	66	17D
0005433368170	24820	67	17E
0005433368172	24820	68	17F
0005433368158	24820	69	18A
0005433368143	24820	70	18C
0005433368162	24820	71	18E
0005435652958	24820	72	18F
0005435652867	24820	73	19A
0005435652966	24820	74	19C
0005435652788	24820	75	19F
0005435653058	24820	76	20A
0005433368171	24820	77	20C
0005435652917	24820	78	20D
0005435653040	24820	79	20E
0005435653054	24820	80	20F
0005435949797	6602	1	1A
0005435949801	6602	2	4C
0005435949794	6602	3	4D
0005435949804	6602	4	6B
0005435949796	6602	5	7B
0005435949800	6602	6	18A
0005435949793	6602	7	18D
0005435949799	6602	8	19C
0005435949798	6602	9	20D
0005435949802	6602	10	21A
0005435949792	6602	11	21B
0005435949795	6602	12	21D
0005435949803	6602	13	23B
0005434979992	2074	1	1A
0005434980019	2074	2	1B
0005434980001	2074	3	1C
0005434980013	2074	4	1D
0005434979996	2074	5	2A
0005434979994	2074	6	2B
0005434980014	2074	7	2C
0005434980017	2074	8	2D
0005434980005	2074	9	3A
0005434979998	2074	10	3C
0005434980015	2074	11	4C
0005434980008	2074	12	5A
0005434980010	2074	13	6A
0005435801717	2074	14	6B
0005435801718	2074	15	6D
0005434980000	2074	16	7A
0005434980009	2074	17	7D
0005434980018	2074	18	18A
0005434979995	2074	19	18B
0005434980020	2074	20	18C
0005434980004	2074	21	18D
0005435801716	2074	22	19A
0005434980011	2074	23	19C
0005434980006	2074	24	19D
0005435801719	2074	25	20B
0005434979997	2074	26	20D
0005434979991	2074	27	21A
0005434980002	2074	28	21B
0005434980003	2074	29	21C
0005434980016	2074	30	22A
0005434980007	2074	31	22B
0005434979993	2074	32	22C
0005434980012	2074	33	23A
0005434979999	2074	34	23B
0005434979842	23546	1	1A
0005434979591	23546	2	1B
0005434979529	23546	3	1C
0005434979592	23546	4	1D
0005434979685	23546	5	2A
0005434979695	23546	6	2B
0005434979708	23546	7	2C
0005434979719	23546	8	2D
0005434979594	23546	9	3A
0005434979728	23546	10	3B
0005434979613	23546	11	3C
0005434979652	23546	12	3D
0005434979784	23546	13	4C
0005434979667	23546	14	4D
0005434979593	23546	15	5A
0005434979696	23546	16	5C
0005434979714	23546	17	5D
0005434979729	23546	18	6A
0005434979694	23546	19	6B
0005434979677	23546	20	6D
0005434979668	23546	21	7A
0005434979785	23546	22	7C
0005435801709	23546	23	18B
0005434979649	23546	24	18C
0005434979751	23546	25	18D
0005434979752	23546	26	19A
0005434979578	23546	27	19B
0005434979686	23546	28	19D
0005434979733	23546	29	20A
0005434979589	23546	30	20C
0005434979720	23546	31	20D
0005434979734	23546	32	21A
0005435801695	23546	33	21D
0005434979672	23546	34	22A
0005434979614	23546	35	22B
0005434979730	23546	36	22C
0005434979841	23546	37	22D
0005434979590	23546	38	23A
0005434952558	2671	1	4B
0005434952559	2671	2	5A
0005434952556	2671	3	5B
0005434952557	2671	4	6A
0005433256426	2672	1	2A
0005433256422	2672	2	2B
0005433256415	2672	3	3A
0005433256421	2672	4	6A
0005434952508	28282	1	1A
0005434952538	28282	2	1B
0005433256437	28282	3	2A
0005434952521	28282	4	2B
0005434952525	28282	5	3B
0005434952536	28282	6	4A
0005433256438	28282	7	4B
0005434952526	28282	8	5A
0005434952520	28282	9	5B
0005433256439	28282	10	6B
0005434952524	28282	11	6A
0005434302855	19724	1	2A
0005433112386	19724	2	2B
0005433111523	19724	3	3A
0005433111522	19724	4	3B
0005434302856	19724	5	4A
0005433111521	19724	6	4B
0005433112387	19724	7	5A
0005434138096	11954	1	1A
0005434138258	11954	2	1D
0005434138034	11954	3	1F
0005434138245	11954	4	2A
0005434138094	11954	5	2C
0005434138349	11954	6	2D
0005434138422	11954	7	2F
0005434138113	11954	8	3A
0005434138111	11954	9	3C
0005434137827	11954	10	3D
0005434138013	11954	11	3F
0005434138095	11954	12	4A
0005434138157	11954	13	4C
0005434138028	11954	14	4D
0005434137797	11954	15	4E
0005434138072	11954	16	5A
0005434138035	11954	17	5C
0005434138262	11954	18	5D
0005434137957	11954	19	5F
0005434138212	11954	20	6C
0005434137867	11954	21	6D
0005434137936	11954	22	6E
0005434137902	11954	23	6F
0005434138454	11954	24	7A
0005434138205	11954	25	7C
0005434137825	11954	26	7E
0005434138271	11954	27	8A
0005434137712	11954	28	8C
0005434137959	11954	29	8D
0005434138216	11954	30	8E
0005434138027	11954	31	8F
0005434137977	11954	32	9A
0005434138082	11954	33	9C
0005434138369	11954	34	9D
0005434137900	11954	35	9E
0005434138052	11954	36	10A
0005434137954	11954	37	10C
0005434138247	11954	38	10D
0005434138139	11954	39	10E
0005434138179	11954	40	10F
0005434137986	11954	41	11C
0005434137645	11954	42	11D
0005434138071	11954	43	11E
0005434137965	11954	44	11F
0005434138158	11954	45	12A
0005434137958	11954	46	12C
0005434137971	11954	47	12D
0005434137963	11954	48	12E
0005434138209	11954	49	12F
0005434137899	11954	50	13D
0005434138426	11954	51	13E
0005434138305	11954	52	13F
0005434138135	11954	53	14A
0005434137890	11954	54	14C
0005434138081	11954	55	14D
0005434137868	11954	56	14E
0005434137904	11954	57	14F
0005434137708	11954	58	15C
0005434138244	11954	59	15D
0005434138107	11954	60	15E
0005434137294	11954	61	15F
0005434138053	11954	62	16A
0005434137711	11954	63	16C
0005434137901	11954	64	16D
0005434138323	11954	65	16E
0005434138408	11954	66	16F
0005434137295	11954	67	17A
0005434138348	11954	68	17C
0005434138427	11954	69	17D
0005434138324	11954	70	17E
0005434137855	11954	71	18A
0005434137976	11954	72	18C
0005434137796	11954	73	18D
0005434138122	11954	74	18E
0005434138451	11954	75	18F
0005434138065	11954	76	19A
0005434138208	11954	77	19C
0005434137962	11954	78	19D
0005434137679	11954	79	19E
0005434137822	11954	80	19F
0005434138121	11954	81	20A
0005434137997	11954	82	20D
0005434138450	11954	83	20E
0005434137903	11954	84	20F
0005434138702	28729	1	1A
0005434138700	28729	2	1C
0005434138684	28729	3	2A
0005434138671	28729	4	2F
0005434138642	28729	5	3A
0005434138695	28729	6	3C
0005434138704	28729	7	3D
0005434138668	28729	8	3F
0005434138701	28729	9	4A
0005434138682	28729	10	4C
0005434138698	28729	11	4D
0005434138640	28729	12	4E
0005434138680	28729	13	4F
0005434138648	28729	14	5A
0005434138686	28729	15	5C
0005434138633	28729	16	5D
0005434138689	28729	17	5E
0005434138662	28729	18	5F
0005434138656	28729	19	6A
0005434138707	28729	20	6C
0005434138632	28729	21	6D
0005434138713	28729	22	6E
0005434138645	28729	23	7C
0005434138692	28729	24	7D
0005434138675	28729	25	7E
0005434138676	28729	26	7F
0005434138715	28729	27	8A
0005434138683	28729	28	8C
0005434138659	28729	29	8D
0005434138653	28729	30	8E
0005434138688	28729	31	9C
0005434138644	28729	32	9D
0005434138703	28729	33	9E
0005434138706	28729	34	9F
0005434138699	28729	35	10A
0005434138655	28729	36	10C
0005434138712	28729	37	10D
0005434138664	28729	38	10E
0005434138667	28729	39	10F
0005434138636	28729	40	11A
0005434138681	28729	41	11C
0005434138643	28729	42	11D
0005434138678	28729	43	11E
0005434138663	28729	44	11F
0005434138691	28729	45	12A
0005434138637	28729	46	12C
0005434138638	28729	47	12D
0005434138651	28729	48	12E
0005434138654	28729	49	12F
0005434138641	28729	50	13A
0005434138639	28729	51	13C
0005434138709	28729	52	13D
0005434138696	28729	53	13E
0005434138673	28729	54	13F
0005434138697	28729	55	14A
0005434138661	28729	56	14C
0005434138693	28729	57	14D
0005434138670	28729	58	14E
0005434138657	28729	59	14F
0005434138635	28729	60	15A
0005434138679	28729	61	15C
0005434138666	28729	62	15D
0005434138658	28729	63	16A
0005434138694	28729	64	16C
0005434138711	28729	65	16D
0005434138705	28729	66	16E
0005434138669	28729	67	16F
0005434138714	28729	68	17A
0005434138660	28729	69	17C
0005434138690	28729	70	17D
0005434138687	28729	71	17E
0005434138649	28729	72	17F
0005434138672	28729	73	18A
0005434138652	28729	74	18C
0005434138674	28729	75	18D
0005434138710	28729	76	18E
0005434138685	28729	77	18F
0005434138646	28729	78	19C
0005434138665	28729	79	19D
0005434138650	28729	80	19E
0005434138634	28729	81	19F
0005434138647	28729	82	20D
0005434138708	28729	83	20E
0005434138677	28729	84	20F
0005433538932	6771	1	1B
0005433538937	6771	2	2D
0005433538928	6771	3	3D
0005433534514	6771	4	4B
0005433538934	6771	5	5D
0005435259773	6771	6	6A
0005435259766	6771	7	6B
0005435259743	6771	8	7A
0005433534513	6771	9	7C
0005433538933	6771	10	18A
0005433538930	6771	11	18D
0005435259737	6771	12	19D
0005433538936	6771	13	21B
0005433538935	6771	14	22A
0005433538931	6771	15	22B
0005433538929	6771	16	22D
0005435259746	6771	17	23B
0005435259790	25010	1	1A
0005433534499	25010	2	1D
0005435259789	25010	3	3A
0005435259786	25010	4	3B
0005433538891	25010	5	4B
0005433538860	25010	6	4C
0005433538849	25010	7	5B
0005433534498	25010	8	5D
0005435259787	25010	9	6A
0005435259788	25010	10	18A
0005433538892	25010	11	18B
0005433538854	25010	12	18D
0005433538851	25010	13	19D
0005433534491	25010	14	20A
0005433512014	835	1	1D
0005433512016	835	2	3B
0005433512010	835	3	4B
0005433512009	835	4	6B
0005432922521	835	5	7D
0005432922508	835	6	18A
0005432922529	835	7	18D
0005433512012	835	8	19A
0005433512008	835	9	19D
0005433512011	835	10	20A
0005433512015	835	11	21C
0005433512013	835	12	22B
0005432922507	835	13	23A
0005433511957	16143	1	2A
0005433511935	16143	2	2C
0005432922555	16143	3	3A
0005433511934	16143	4	3B
0005432922556	16143	5	3D
0005432922557	16143	6	4C
0005433511959	16143	7	5B
0005433511958	16143	8	6A
0005433511954	16143	9	19B
0005433511956	16143	10	21B
0005432922554	16143	11	22C
0005433511937	16143	12	23B
0005434950564	3676	1	1A
0005434950560	3676	2	1B
0005435697537	3676	3	1C
0005435697550	3676	4	1D
0005435697541	3676	5	2B
0005435697545	3676	6	2D
0005435697549	3676	7	3A
0005435935030	3676	8	3B
0005435697553	3676	9	4A
0005435697544	3676	10	4B
0005435697540	3676	11	4C
0005434950563	3676	12	4D
0005435697542	3676	13	5B
0005435916171	3676	14	5C
0005435697535	3676	15	6A
0005435697552	3676	16	6B
0005435697555	3676	17	6D
0005435697558	3676	18	7B
0005435697547	3676	19	7C
0005435697532	3676	20	7D
0005435697554	3676	21	18A
0005435697539	3676	22	18C
0005434950562	3676	23	18D
0005435697551	3676	24	19A
0005435697559	3676	25	19B
0005435697543	3676	26	19C
0005435935049	3676	27	19D
0005435697534	3676	28	20A
0005435697556	3676	29	20B
0005435697548	3676	30	20C
0005435697557	3676	31	21A
0005435916167	3676	32	21B
0005435697560	3676	33	21D
0005435697536	3676	34	22A
0005435697533	3676	35	22B
0005434950561	3676	36	22C
0005435697538	3676	37	22D
0005435697546	3676	38	23A
0005435916170	3676	39	23B
0005434950520	16289	1	1A
0005435697382	16289	2	1B
0005435697190	16289	3	1C
0005435697225	16289	4	1D
0005435697273	16289	5	2A
0005435697319	16289	6	2B
0005435697359	16289	7	2C
0005435697152	16289	8	2D
0005435697379	16289	9	3A
0005435697305	16289	10	3B
0005435697202	16289	11	3C
0005435697324	16289	12	3D
0005435697326	16289	13	4A
0005434950525	16289	14	4B
0005435697325	16289	15	4C
0005435697280	16289	16	4D
0005435697291	16289	17	5A
0005435697341	16289	18	5B
0005434950532	16289	19	5C
0005435697287	16289	20	5D
0005434950522	16289	21	6A
0005435697233	16289	22	6B
0005435697380	16289	23	6C
0005435697151	16289	24	6D
0005435697219	16289	25	7A
0005435697203	16289	26	7B
0005435697270	16289	27	7C
0005435697262	16289	28	7D
0005435697279	16289	29	18A
0005434950521	16289	30	18B
0005435697246	16289	31	18C
0005435697293	16289	32	18D
0005435697294	16289	33	19A
0005435697220	16289	34	19B
0005435697269	16289	35	19C
0005435697331	16289	36	19D
0005435697274	16289	37	20A
0005435697263	16289	38	20B
0005435697384	16289	39	20C
0005435697150	16289	40	20D
0005434950538	16289	41	21A
0005435697215	16289	42	21B
0005435697240	16289	43	21C
0005435697234	16289	44	21D
0005435697272	16289	45	22A
0005435697254	16289	46	22B
0005435697216	16289	47	22C
0005435697337	16289	48	22D
0005435697253	16289	49	23A
0005435697342	16289	50	23B
0005434604923	3971	1	1B
0005432607594	3971	2	2C
0005434604924	3971	3	2D
0005435904707	3971	4	3B
0005435853619	3971	5	3A
0005434606855	3971	6	3C
0005432607597	3971	7	3D
0005434606853	3971	8	4A
0005433519491	3971	9	4B
0005434604921	3971	10	4C
0005434604922	3971	11	4D
0005435853613	3971	12	5A
0005435853618	3971	13	5B
0005434606856	3971	14	5C
0005435842327	3971	15	5D
0005434606852	3971	16	6A
0005433519490	3971	17	6C
0005434606854	3971	18	7D
0005434604920	3971	19	18C
0005432609761	3971	20	19D
0005432609762	3971	21	20A
0005434606857	3971	22	20B
0005432607596	3971	23	20D
0005433519493	3971	24	21A
0005433519492	3971	25	22A
0005432607595	3971	26	22B
0005433519489	3971	27	22C
0005432609760	3971	28	23A
0005435853616	3971	29	23B
0005435853624	22038	1	1A
0005435853625	22038	2	1B
0005433519455	22038	3	1D
0005433519451	22038	4	2C
0005434606814	22038	5	4B
0005435904899	22038	6	5A
0005433519452	22038	7	5B
0005433519453	22038	8	6B
0005433519454	22038	9	6C
0005433519441	22038	10	6D
0005435904898	22038	11	7D
0005433519476	22038	12	18D
0005433519450	22038	13	22A
0005433519434	22038	14	22D
0005433519449	22038	15	23B
0005435628745	712	1	1B
0005433348999	712	2	2A
0005433348997	712	3	2B
0005435628748	712	4	3A
0005435628747	712	5	4A
0005433348998	712	6	5A
0005435628744	712	7	6A
0005435628746	712	8	6B
0005435628711	15957	1	1B
0005433349032	15957	2	2A
0005433349030	15957	3	3A
0005433349034	15957	4	3B
0005433349031	15957	5	4B
0005433349033	15957	6	5B
0005433349029	15957	7	6A
0005434445258	17206	1	1A
0005433159302	17206	2	1B
0005433158129	17206	3	2A
0005433159316	17206	4	3A
0005433159314	17206	5	3B
0005433159303	17206	6	4A
0005433158125	17206	7	4B
0005433158130	17206	8	5A
0005433159315	17206	9	6A
0005433158124	17206	10	5B
0005434445259	17206	11	6B
0005433159330	17589	1	2B
0005433159332	17589	2	3B
0005433159331	17589	3	5A
0005433159329	17589	4	6A
0005435132964	7915	1	1A
0005435132954	7915	2	3B
0005435383158	7915	3	6D
0005435132956	7915	4	7B
0005435132955	7915	5	7C
0005435132957	7915	6	18A
0005435132960	7915	7	19A
0005435383142	7915	8	20A
0005435132962	7915	9	20D
0005435132961	7915	10	21A
0005435132963	7915	11	21B
0005435132959	7915	12	21D
0005435132958	7915	13	23A
0005435383141	7915	14	23B
0005435132853	33069	1	2C
0005435132885	33069	2	3A
0005435132874	33069	3	4A
0005435132852	33069	4	4B
0005435132867	33069	5	4C
0005435132899	33069	6	6B
0005435383192	33069	7	7C
0005435383188	33069	8	7D
0005435132932	33069	9	19A
0005435383187	33069	10	19C
0005435132877	33069	11	19D
0005435383190	33069	12	20D
0005435383191	33069	13	21A
0005435132844	33069	14	21C
0005435383189	33069	15	21D
0005435132831	33069	16	22A
0005435132886	33069	17	22B
0005435390235	7487	1	1A
0005435390237	7487	2	1D
0005435390236	7487	3	2A
0005435160380	7487	4	2B
0005435160381	7487	5	2C
0005435160388	7487	6	2D
0005435160389	7487	7	3C
0005435390229	7487	8	3D
0005435160386	7487	9	4A
0005435390233	7487	10	4D
0005435160387	7487	11	5B
0005435160385	7487	12	6B
0005435160384	7487	13	7A
0005435390211	7487	14	19C
0005435160378	7487	15	20A
0005435160383	7487	16	20B
0005435390243	7487	17	20C
0005435390244	7487	18	21C
0005435160382	7487	19	21D
0005435160379	7487	20	22D
0005435390213	7487	21	23A
0005435160321	29582	1	1B
0005435160275	29582	2	1C
0005435390291	29582	3	2A
0005435160274	29582	4	2B
0005435390292	29582	5	4B
0005435390294	29582	6	5A
0005435160333	29582	7	6A
0005435160302	29582	8	6B
0005435390293	29582	9	7A
0005435160329	29582	10	19B
0005435390288	29582	11	19D
0005435390287	29582	12	20C
0005435160330	29582	13	20D
0005435160327	29582	14	21B
0005435390289	29582	15	21C
0005435160292	29582	16	22A
0005435390290	29582	17	22D
0005432394108	18485	1	1B
0005432394079	18485	2	2A
0005432394107	18485	3	2B
0005432394077	18485	4	3B
0005435178506	18485	5	3A
0005435178999	18485	6	4A
0005432398190	18485	7	4B
0005435178507	18485	8	5A
0005432394078	18485	9	5B
0005435178998	18485	10	6B
0005432398222	27149	1	1A
0005432400149	27149	2	1B
0005432398220	27149	3	2A
0005432400151	27149	4	2B
0005432400147	27149	5	3B
0005435178493	27149	6	4A
0005432400148	27149	7	4B
0005432400150	27149	8	5A
0005432398221	27149	9	6A
0005432400152	27149	10	5B
0005432398219	27149	11	6B
0005434191273	9768	1	4B
0005432661932	21846	1	1D
0005432664145	21846	2	2C
0005432663055	21846	3	3A
0005432663045	21846	4	3C
0005432663046	21846	5	5C
0005432664148	21846	6	5F
0005432661930	21846	7	5D
0005432664152	21846	8	6B
0005432661939	21846	9	6A
0005432663042	21846	10	6C
0005432664149	21846	11	7A
0005432661933	21846	12	7C
0005432661934	21846	13	7B
0005432664150	21846	14	7E
0005432664154	21846	15	7D
0005432661937	21846	16	8B
0005432664146	21846	17	8E
0005432663054	21846	18	8C
0005432663050	21846	19	9C
0005432664156	21846	20	9E
0005432663049	21846	21	10A
0005432663044	21846	22	10F
0005432664155	21846	23	11C
0005432661942	21846	24	11E
0005432661936	21846	25	12D
0005432664147	21846	26	12C
0005432663047	21846	27	12F
0005432663048	21846	28	13A
0005432661928	21846	29	14A
0005432664144	21846	30	14B
0005432663053	21846	31	15D
0005432663041	21846	32	15C
0005432661931	21846	33	15F
0005432661929	21846	34	16C
0005432661935	21846	35	17B
0005432664157	21846	36	17D
0005432661943	21846	37	17C
0005432661940	21846	38	17E
0005432663051	21846	39	18B
0005432664151	21846	40	18A
0005432664153	21846	41	19D
0005432664143	21846	42	20B
0005432663052	21846	43	20A
0005432661941	21846	44	20F
0005432661938	21846	45	21C
0005432663043	21846	46	21F
0005434504450	6553	1	1C
0005434504455	6553	2	2A
0005435103984	6553	3	3A
0005434504429	6553	4	4A
0005434504443	6553	5	4C
0005434504442	6553	6	5D
0005434504457	6553	7	5E
0005434504427	6553	8	6C
0005434504433	6553	9	6D
0005434504449	6553	10	7C
0005434504460	6553	11	7D
0005434504451	6553	12	8A
0005434504456	6553	13	8C
0005434504452	6553	14	9A
0005434504462	6553	15	9F
0005434504446	6553	16	10C
0005434504425	6553	17	10F
0005434504434	6553	18	11D
0005434504461	6553	19	12C
0005434504431	6553	20	12F
0005434504424	6553	21	13A
0005434504458	6553	22	13D
0005434504454	6553	23	13E
0005434504430	6553	24	14C
0005434504435	6553	25	14F
0005434504453	6553	26	15A
0005435103985	6553	27	15C
0005434504428	6553	28	15D
0005434504447	6553	29	16C
0005434504438	6553	30	16F
0005434504445	6553	31	17A
0005435103986	6553	32	17C
0005434504437	6553	33	17D
0005435103983	6553	34	17E
0005434504432	6553	35	18C
0005434504439	6553	36	18D
0005434504441	6553	37	18E
0005434504444	6553	38	18F
0005434504459	6553	39	19A
0005434504436	6553	40	19C
0005434504426	6553	41	19E
0005434504448	6553	42	20C
0005434504440	6553	43	20D
0005434504463	6553	44	20F
0005434504038	22660	1	1C
0005434503902	22660	2	1D
0005434504019	22660	3	1F
0005434503853	22660	4	2D
0005434504024	22660	5	3A
0005434503819	22660	6	3C
0005435103868	22660	7	3D
0005434504093	22660	8	3F
0005435103893	22660	9	4A
0005434503995	22660	10	4C
0005434503882	22660	11	4E
0005435103907	22660	12	5C
0005434504022	22660	13	5F
0005435103888	22660	14	6E
0005435103899	22660	15	6F
0005434504068	22660	16	7A
0005435103885	22660	17	8A
0005435103886	22660	18	8C
0005435103904	22660	19	9A
0005434504254	22660	20	9D
0005435103903	22660	21	9F
0005435103901	22660	22	10A
0005434503977	22660	23	10C
0005434503976	22660	24	10D
0005434503947	22660	25	10E
0005434504099	22660	26	10F
0005434504003	22660	27	11A
0005434504088	22660	28	11C
0005434504081	22660	29	11D
0005434504037	22660	30	13A
0005435103860	22660	31	13E
0005435103867	22660	32	13F
0005435103891	22660	33	14C
0005435103861	22660	34	14E
0005434504126	22660	35	15C
0005435103896	22660	36	15E
0005434504046	22660	37	15F
0005434504002	22660	38	16A
0005434504100	22660	39	16F
0005434503901	22660	40	17A
0005435103902	22660	41	17D
0005435103869	22660	42	18A
0005435103863	22660	43	19C
0005434503946	22660	44	20A
0005434504036	22660	45	20D
0005435653404	1675	1	1A
0005435653383	1675	2	1C
0005433367741	1675	3	1D
0005435653374	1675	4	1F
0005435653369	1675	5	2A
0005433367669	1675	6	2C
0005435653380	1675	7	2D
0005433367858	1675	8	2F
0005433367754	1675	9	3A
0005433367914	1675	10	3C
0005435653392	1675	11	3D
0005433367720	1675	12	3F
0005433367939	1675	13	4A
0005435653361	1675	14	4C
0005435653354	1675	15	4D
0005435653355	1675	16	4E
0005435653402	1675	17	4F
0005435653397	1675	18	5A
0005433367851	1675	19	5C
0005433367880	1675	20	5D
0005435653365	1675	21	5E
0005433368041	1675	22	5F
0005435653398	1675	23	6A
0005435653370	1675	24	6C
0005435653360	1675	25	6D
0005433367967	1675	26	6E
0005433367794	1675	27	7A
0005435653375	1675	28	7C
0005433367861	1675	29	7D
0005433367843	1675	30	7E
0005435653387	1675	31	7F
0005435653400	1675	32	8A
0005435653394	1675	33	8C
0005433367881	1675	34	8D
0005435653364	1675	35	8E
0005433367909	1675	36	8F
0005433367827	1675	37	9A
0005435653351	1675	38	9C
0005435653356	1675	39	9D
0005435653403	1675	40	9E
0005435653393	1675	41	9F
0005433368013	1675	42	10A
0005435653359	1675	43	10C
0005435653381	1675	44	10D
0005433367966	1675	45	10E
0005435653377	1675	46	10F
0005435653363	1675	47	11A
0005435653395	1675	48	11C
0005435653386	1675	49	11D
0005433367743	1675	50	11E
0005435653358	1675	51	11F
0005433367742	1675	52	12A
0005435653368	1675	53	12C
0005435653372	1675	54	12D
0005435653371	1675	55	12E
0005435653376	1675	56	12F
0005433367755	1675	57	13A
0005435653384	1675	58	13C
0005435653388	1675	59	13D
0005433367910	1675	60	13E
0005435653366	1675	61	13F
0005435653382	1675	62	14A
0005435653391	1675	63	14C
0005435653357	1675	64	14D
0005435653390	1675	65	14E
0005433367723	1675	66	14F
0005433367668	1675	67	15A
0005435653362	1675	68	15C
0005433367537	1675	69	15D
0005435653379	1675	70	15E
0005435653373	1675	71	15F
0005435653385	1675	72	16A
0005435653396	1675	73	16C
0005433367536	1675	74	16D
0005433367793	1675	75	16E
0005433367603	1675	76	16F
0005433367904	1675	77	17A
0005435653350	1675	78	17C
0005435653352	1675	79	17D
0005435653399	1675	80	17E
0005433367977	1675	81	17F
0005435653349	1675	82	18A
0005433367787	1675	83	18C
0005433367915	1675	84	18D
0005435653401	1675	85	18E
0005433367690	1675	86	18F
0005435653367	1675	87	19A
0005435653353	1675	88	19C
0005435653378	1675	89	19D
0005433367860	1675	90	19E
0005433367670	1675	91	19F
0005433367792	1675	92	20A
0005435653389	1675	93	20C
0005433367774	1675	94	20D
0005433367882	1675	95	20E
0005435652958	21687	1	1A
0005435652967	21687	2	1C
0005435652889	21687	3	1D
0005433368151	21687	4	1F
0005433368160	21687	5	2A
0005435653054	21687	6	2C
0005435652645	21687	7	2D
0005433368172	21687	8	3A
0005435652926	21687	9	3C
0005435652924	21687	10	3D
0005433368166	21687	11	3F
0005433368156	21687	12	4A
0005435652943	21687	13	4C
0005435652896	21687	14	4D
0005433368143	21687	15	4E
0005433368162	21687	16	5A
0005435652932	21687	17	5C
0005433368164	21687	18	5D
0005433368146	21687	19	5E
0005435653002	21687	20	6A
0005435652864	21687	21	6C
0005433368174	21687	22	6D
0005435652863	21687	23	6F
0005433368165	21687	24	7A
0005435653059	21687	25	7C
0005435652782	21687	26	7D
0005433368157	21687	27	7E
0005433368168	21687	28	8A
0005435652795	21687	29	8C
0005433368144	21687	30	8D
0005435652878	21687	31	8E
0005435652894	21687	32	9C
0005435652975	21687	33	9D
0005435653040	21687	34	9E
0005433368145	21687	35	9F
0005435652796	21687	36	10C
0005435652925	21687	37	10E
0005433368154	21687	38	10D
0005435652646	21687	39	10F
0005435652897	21687	40	11A
0005435652867	21687	41	11C
0005435653046	21687	42	11E
0005433368155	21687	43	11F
0005433368149	21687	44	12C
0005433368169	21687	45	12D
0005435652808	21687	46	13A
0005433368161	21687	47	13C
0005433368158	21687	48	13D
0005435652821	21687	49	13E
0005433368140	21687	50	14A
0005435653058	21687	51	14D
0005435653045	21687	52	14E
0005435653068	21687	53	15A
0005435652797	21687	54	15C
0005435652930	21687	55	15D
0005433368177	21687	56	15E
0005435652788	21687	57	15F
0005435652895	21687	58	16A
0005433368173	21687	59	16C
0005433368148	21687	60	16D
0005435652917	21687	61	16E
0005433368152	21687	62	16F
0005435652809	21687	63	17A
0005433368153	21687	64	17D
0005433368141	21687	65	17E
0005433368167	21687	66	17F
0005433368170	21687	67	18A
0005435652807	21687	68	18C
0005433368159	21687	69	18D
0005435653037	21687	70	18E
0005433368176	21687	71	19A
0005433368175	21687	72	19C
0005433368150	21687	73	19D
0005435652868	21687	74	19E
0005435652966	21687	75	19F
0005433368147	21687	76	20A
0005433368142	21687	77	20C
0005435652814	21687	78	20D
0005433368163	21687	79	20E
0005433368171	21687	80	20F
0005433986269	4166	1	1A
0005433986267	4166	2	1C
0005433986275	4166	3	1F
0005433986302	4166	4	2C
0005433986303	4166	5	2D
0005433986289	4166	6	2F
0005433986270	4166	7	3A
0005433986286	4166	8	3C
0005433986263	4166	9	3F
0005435788790	4166	10	4C
0005433986268	4166	11	4D
0005433986277	4166	12	4F
0005433986299	4166	13	5D
0005433986305	4166	14	5E
0005433986265	4166	15	5F
0005433986283	4166	16	7D
0005433986259	4166	17	7F
0005433986274	4166	18	8A
0005433986301	4166	19	8C
0005433986281	4166	20	8D
0005433986297	4166	21	8E
0005433986285	4166	22	11C
0005433986300	4166	23	11D
0005433986296	4166	24	12A
0005433986280	4166	25	12C
0005433986292	4166	26	12E
0005433986260	4166	27	13C
0005433986272	4166	28	13D
0005433986287	4166	29	13E
0005433986273	4166	30	14C
0005433986278	4166	31	14E
0005433986271	4166	32	15A
0005433986284	4166	33	15C
0005433986290	4166	34	15D
0005433986304	4166	35	15E
0005433986291	4166	36	16C
0005433986282	4166	37	16D
0005433986293	4166	38	16E
0005433986261	4166	39	16F
0005433986295	4166	40	17A
0005433986262	4166	41	17C
0005433986266	4166	42	17E
0005433986288	4166	43	18D
0005433986279	4166	44	18E
0005433986294	4166	45	19D
0005433986276	4166	46	19F
0005433986298	4166	47	20A
0005433986264	4166	48	20C
0005433985877	25666	1	1C
0005433985799	25666	2	1D
0005433986020	25666	3	1F
0005433985936	25666	4	2F
0005433985850	25666	5	3A
0005433985735	25666	6	4A
0005433985804	25666	7	4D
0005433985862	25666	8	4E
0005433985780	25666	9	4F
0005433985802	25666	10	5E
0005433985588	25666	11	5F
0005433985637	25666	12	6A
0005433985875	25666	13	6D
0005433985783	25666	14	6E
0005435788767	25666	15	7A
0005433985792	25666	16	7D
0005433985874	25666	17	7E
0005433985832	25666	18	7F
0005433985852	25666	19	8A
0005433985910	25666	20	8D
0005433985837	25666	21	8E
0005433985638	25666	22	8F
0005433985876	25666	23	9D
0005433985838	25666	24	9E
0005433985772	25666	25	10A
0005433985702	25666	26	10C
0005433985839	25666	27	10E
0005433985873	25666	28	11A
0005433985765	25666	29	11C
0005433985998	25666	30	11D
0005433985803	25666	31	11E
0005433985851	25666	32	12A
0005433985857	25666	33	12C
0005433986214	25666	34	13A
0005433985796	25666	35	13C
0005433985736	25666	36	13D
0005433985926	25666	37	13F
0005433985842	25666	38	14A
0005433985919	25666	39	14C
0005435788760	25666	40	14E
0005433985863	25666	41	14F
0005433985879	25666	42	15D
0005433985798	25666	43	15E
0005433985747	25666	44	15F
0005433985791	25666	45	16A
0005433985867	25666	46	16C
0005433985856	25666	47	16D
0005433985900	25666	48	17E
0005433985935	25666	49	17F
0005433985806	25666	50	18A
0005433985776	25666	51	18C
0005433985813	25666	52	18D
0005433985673	25666	53	18E
0005433985779	25666	54	20A
0005433985915	25666	55	20C
0005433985878	25666	56	20F
0005435719566	21293	1	20A
0005435719569	24764	1	5C
0005435720140	24764	2	21D
0005434516095	9029	1	1C
0005434190406	9029	2	2A
0005434516090	9029	3	2C
0005434190398	9029	4	3C
0005434190397	9029	5	3D
0005434190408	9029	6	4C
0005434190404	9029	7	5C
0005434516089	9029	8	6D
0005434516088	9029	9	7C
0005434190389	9029	10	18A
0005434516096	9029	11	18C
0005434516091	9029	12	18D
0005434516094	9029	13	19C
0005434190396	9029	14	20C
0005434516093	9029	15	21A
0005434516092	9029	16	22C
0005434190407	9029	17	22D
0005432869573	17862	1	1C
0005432663036	17862	2	1D
0005434151728	17862	3	2C
0005432663033	17862	4	2F
0005432664142	17862	5	3F
0005432655474	17862	6	4A
0005432655528	17862	7	4C
0005434151727	17862	8	4F
0005432655554	17862	9	5C
0005432664141	17862	10	5D
0005432655525	17862	11	5E
0005432655462	17862	12	5F
0005432665272	17862	13	6D
0005432660820	17862	14	6E
0005432655516	17862	15	6F
0005432655527	17862	16	7A
0005432664136	17862	17	7E
0005432657432	17862	18	8A
0005432655519	17862	19	8C
0005432869575	17862	20	8D
0005432664114	17862	21	9C
0005432655461	17862	22	10D
0005432657449	17862	23	10E
0005434151726	17862	24	10F
0005432663035	17862	25	11A
0005434151729	17862	26	11E
0005432658590	17862	27	12C
0005432657418	17862	28	13F
0005432869574	17862	29	14E
0005432655473	17862	30	15A
0005432657446	17862	31	15C
0005432655446	17862	32	16D
0005432869576	17862	33	16F
0005432665269	17862	34	17A
0005432657452	17862	35	17C
0005432667456	17862	36	18A
0005432869579	17862	37	18C
0005432663031	17862	38	18E
0005432655499	17862	39	18F
0005432869577	17862	40	19A
0005432869578	17862	41	19C
0005432663032	17862	42	19E
0005432663040	17862	43	20C
0005432664137	17862	44	20D
0005432655472	17862	45	20F
0005432658602	26299	1	1C
0005432655595	26299	2	1D
0005432655606	26299	3	2C
0005432658605	26299	4	2D
0005434151683	26299	5	3A
0005432658604	26299	6	3C
0005432667467	26299	7	3D
0005432665287	26299	8	4D
0005432666400	26299	9	4E
0005432655597	26299	10	5A
0005432666401	26299	11	5E
0005432869491	26299	12	5F
0005432655596	26299	13	6A
0005432869489	26299	14	6F
0005432655604	26299	15	7A
0005432869510	26299	16	7F
0005434151707	26299	17	8D
0005432657466	26299	18	8F
0005432657467	26299	19	9F
0005432655603	26299	20	10D
0005432667465	26299	21	10E
0005432665286	26299	22	11E
0005432869519	26299	23	11F
0005432655601	26299	24	12A
0005432660830	26299	25	12E
0005432666402	26299	26	13D
0005432660829	26299	27	13E
0005432869490	26299	28	14A
0005432869511	26299	29	14E
0005432667466	26299	30	15A
0005432655599	26299	31	15D
0005432658603	26299	32	15F
0005432655600	26299	33	16D
0005432655598	26299	34	17A
0005432667468	26299	35	17C
0005432657468	26299	36	18F
0005432869520	26299	37	19D
0005432655605	26299	38	19E
0005432659719	26299	39	19F
0005432869504	26299	40	20A
0005432655602	26299	41	20F
0005433438939	3117	1	1A
0005432329056	3117	2	1D
0005432287229	3117	3	1F
0005432905133	3117	4	2A
0005432329023	3117	5	2D
0005432329046	3117	6	2F
0005432329063	3117	7	3A
0005432329034	3117	8	3C
0005432329022	3117	9	3D
0005432329036	3117	10	3F
0005432329048	3117	11	4A
0005432329043	3117	12	4C
0005432329018	3117	13	4D
0005432329031	3117	14	4F
0005432329040	3117	15	5A
0005432329041	3117	16	5C
0005432329028	3117	17	5D
0005432329065	3117	18	5F
0005432329050	3117	19	6C
0005433438941	3117	20	6D
0005432329035	3117	21	6E
0005432329045	3117	22	6F
0005432287227	3117	23	7A
0005432329052	3117	24	7C
0005432329049	3117	25	7F
0005432329044	3117	26	8A
0005432329047	3117	27	8C
0005432905125	3117	28	8D
0005432329029	3117	29	8E
0005432329057	3117	30	8F
0005432329038	3117	31	9A
0005432905126	3117	32	9C
0005432329051	3117	33	9E
0005432905119	3117	34	10A
0005432329019	3117	35	10F
0005433438938	3117	36	11A
0005432329032	3117	37	11C
0005433438944	3117	38	11D
0005432329053	3117	39	11E
0005432287228	3117	40	12C
0005432329064	3117	41	13D
0005432329055	3117	42	13E
0005432329024	3117	43	13F
0005432329039	3117	44	14A
0005433438940	3117	45	14C
0005432329026	3117	46	14D
0005432329059	3117	47	15A
0005433438937	3117	48	15D
0005432329030	3117	49	15F
0005432329037	3117	50	16A
0005432329062	3117	51	17A
0005432329054	3117	52	17D
0005432329042	3117	53	18A
0005432329021	3117	54	18C
0005433438943	3117	55	18D
0005433438942	3117	56	18E
0005432329027	3117	57	18F
0005432329020	3117	58	19A
0005432329060	3117	59	19D
0005432905120	3117	60	19E
0005432329058	3117	61	19F
0005432287226	3117	62	20A
0005432329033	3117	63	20C
0005432329061	3117	64	20D
0005432329025	3117	65	20F
0005432328542	31147	1	1A
0005432328592	31147	2	1D
0005432328826	31147	3	2A
0005433438911	31147	4	2C
0005432328510	31147	5	2F
0005432328506	31147	6	3C
0005432905168	31147	7	4A
0005432905169	31147	8	4C
0005432328754	31147	9	4D
0005432328326	31147	10	4F
0005432328753	31147	11	5A
0005433438866	31147	12	5C
0005432328612	31147	13	6A
0005432905167	31147	14	6D
0005432328599	31147	15	6E
0005432328645	31147	16	6F
0005433438844	31147	17	7C
0005432328806	31147	18	8C
0005432328650	31147	19	8D
0005433438921	31147	20	8E
0005432328752	31147	21	9A
0005432328820	31147	22	9C
0005432328511	31147	23	9E
0005432328828	31147	24	9F
0005432328362	31147	25	10C
0005433438848	31147	26	10D
0005432328327	31147	27	10E
0005432905165	31147	28	10F
0005432905170	31147	29	11C
0005432328688	31147	30	11E
0005432328471	31147	31	11F
0005433438910	31147	32	12C
0005432328605	31147	33	12D
0005432328470	31147	34	12E
0005433438920	31147	35	12F
0005433438867	31147	36	13A
0005432328450	31147	37	13E
0005433438855	31147	38	13F
0005432328595	31147	39	14A
0005432328827	31147	40	14C
0005432328567	31147	41	14D
0005432328366	31147	42	14E
0005432328727	31147	43	14F
0005432328733	31147	44	15D
0005432328690	31147	45	15E
0005432328505	31147	46	15F
0005432905166	31147	47	16C
0005432328475	31147	48	16D
0005432328626	31147	49	16F
0005432328646	31147	50	17A
0005432054327	31147	51	17D
0005432328643	31147	52	17F
0005432328598	31147	53	18A
0005432054326	31147	54	18D
0005432328676	31147	55	18C
0005432328623	31147	56	18F
0005432328449	31147	57	19A
0005433438868	31147	58	19C
0005432905171	31147	59	19E
0005432328494	31147	60	20A
0005433438875	31147	61	20D
0005433438909	31147	62	20F
0005435999383	6227	1	1D
0005435297055	6227	2	1F
0005432146214	6227	3	2D
0005435297040	6227	4	3F
0005435487802	6227	5	4A
0005434309845	6227	6	4D
0005435999384	6227	7	5A
0005435487682	6227	8	5C
0005434309847	6227	9	5D
0005435999382	6227	10	5E
0005434309840	6227	11	6B
0005435487681	6227	12	7A
0005434309846	6227	13	7B
0005435487775	6227	14	7E
0005434309843	6227	15	7D
0005435487795	6227	16	7F
0005435487772	6227	17	8B
0005435487768	6227	18	8E
0005434309841	6227	19	8D
0005435999381	6227	20	9A
0005435487919	6227	21	8F
0005435487777	6227	22	9E
0005435487800	6227	23	9D
0005434309838	6227	24	9F
0005435487812	6227	25	10D
0005435487756	6227	26	11B
0005435487779	6227	27	11D
0005434309839	6227	28	11E
0005435487747	6227	29	11F
0005435487886	6227	30	12D
0005435487839	6227	31	12C
0005435487827	6227	32	12F
0005435487668	6227	33	13B
0005435487799	6227	34	13D
0005435487887	6227	35	14C
0005435487804	6227	36	14E
0005435487811	6227	37	15A
0005435487767	6227	38	15F
0005435487794	6227	39	16A
0005435487718	6227	40	16E
0005435487680	6227	41	17A
0005434309842	6227	42	17C
0005435487710	6227	43	17E
0005434309844	6227	44	17D
0005435487796	6227	45	17F
0005434309849	6227	46	18E
0005435487773	6227	47	20A
0005435487885	6227	48	20B
0005434309836	6227	49	21C
0005435487778	6227	50	22B
0005435487754	6227	51	22A
0005434309837	6227	52	22D
0005434309848	6227	53	23B
0005435487711	6227	54	23C
0005435487776	6227	55	23F
0005435487977	19574	1	1C
0005435999199	19574	2	1F
0005435487975	19574	3	2C
0005435487967	19574	4	2D
0005435487979	19574	5	3C
0005434309717	19574	6	3F
0005435297112	19574	7	4A
0005434309713	19574	8	4C
0005435999188	19574	9	4D
0005434309724	19574	10	4E
0005435999202	19574	11	4F
0005434309714	19574	12	5A
0005435999182	19574	13	5D
0005435297107	19574	14	6E
0005435999179	19574	15	7C
0005434309692	19574	16	8E
0005435999127	19574	17	8F
0005435297108	19574	18	9B
0005435487970	19574	19	10D
0005435999206	19574	20	11A
0005435487974	19574	21	12B
0005435487983	19574	22	12D
0005435487964	19574	23	12C
0005435999192	19574	24	13C
0005435297109	19574	25	13E
0005435999227	19574	26	13F
0005434309700	19574	27	14B
0005435999174	19574	28	14C
0005435999198	19574	29	14F
0005435487969	19574	30	15A
0005435487976	19574	31	15E
0005435999175	19574	32	15F
0005435487980	19574	33	16B
0005435297110	19574	34	16A
0005435487978	19574	35	16C
0005435999204	19574	36	16D
0005434309737	19574	37	17A
0005435999205	19574	38	17E
0005435297111	19574	39	17D
0005435999187	19574	40	18A
0005434309727	19574	41	19B
0005435487966	19574	42	19D
0005435487972	19574	43	19F
0005435999207	19574	44	19E
0005435487982	19574	45	20A
0005435487984	19574	46	20B
0005434309723	19574	47	20F
0005434309709	19574	48	21B
0005435487981	19574	49	21E
0005435487968	19574	50	21F
0005435487971	19574	51	22B
0005435999210	19574	52	22E
0005434309712	19574	53	23A
0005435487973	19574	54	23C
0005435999178	19574	55	23B
0005435487965	19574	56	23D
0005434566021	1570	1	1A
0005435508446	1570	2	1C
0005435508435	1570	3	1D
0005435508441	1570	4	1F
0005435518045	1570	5	2A
0005433186113	1570	6	2C
0005435502474	1570	7	2D
0005435508430	1570	8	2F
0005435518030	1570	9	3A
0005434566014	1570	10	3C
0005435508437	1570	11	3D
0005435508433	1570	12	3F
0005433186112	1570	13	4A
0005432291949	1570	14	4E
0005434566017	1570	15	4F
0005435502472	1570	16	5A
0005433186138	1570	17	5C
0005435518033	1570	18	5D
0005435502480	1570	19	5E
0005433186089	1570	20	5F
0005435518036	1570	21	6A
0005435508439	1570	22	6C
0005435518042	1570	23	6D
0005435508431	1570	24	6E
0005435502479	1570	25	6F
0005434566022	1570	26	7A
0005435518047	1570	27	7C
0005435518041	1570	28	7D
0005435518035	1570	29	7E
0005434566012	1570	30	7F
0005434566010	1570	31	8D
0005434566020	1570	32	8E
0005435518043	1570	33	8F
0005435502477	1570	34	9A
0005435518031	1570	35	9C
0005435502484	1570	36	9D
0005435518044	1570	37	9F
0005435502465	1570	38	10A
0005435502471	1570	39	10C
0005435502483	1570	40	10D
0005435508442	1570	41	10E
0005434566019	1570	42	10F
0005434566011	1570	43	11A
0005435508436	1570	44	11C
0005435508438	1570	45	11D
0005435518046	1570	46	11E
0005435518040	1570	47	11F
0005435502464	1570	48	12D
0005435502467	1570	49	12E
0005435502463	1570	50	12F
0005435518034	1570	51	13A
0005434566008	1570	52	13E
0005435508443	1570	53	13F
0005435502466	1570	54	14A
0005435508444	1570	55	14C
0005433186121	1570	56	14D
0005434566018	1570	57	14F
0005435502475	1570	58	15A
0005435502469	1570	59	15C
0005433186137	1570	60	15D
0005434566015	1570	61	15E
0005432291948	1570	62	15F
0005435502473	1570	63	16A
0005435508432	1570	64	16C
0005434566013	1570	65	16D
0005435518032	1570	66	16E
0005435502476	1570	67	16F
0005435518039	1570	68	17A
0005435518029	1570	69	17C
0005435502482	1570	70	17D
0005435502468	1570	71	17F
0005433186136	1570	72	18C
0005435502470	1570	73	18D
0005435502478	1570	74	18E
0005435518048	1570	75	18F
0005435518028	1570	76	19A
0005434566009	1570	77	19C
0005435508445	1570	78	19E
0005435518038	1570	79	19F
0005435508434	1570	80	20A
0005435502481	1570	81	20C
0005434566016	1570	82	20D
0005435508440	1570	83	20E
0005435518037	1570	84	20F
0005435529248	20852	1	1A
0005435529159	20852	2	1C
0005434565925	20852	3	2A
0005435545709	20852	4	1F
0005435502314	20852	5	2C
0005433186184	20852	6	2D
0005435529194	20852	7	2F
0005434565924	20852	8	3D
0005434565915	20852	9	3F
0005435545744	20852	10	4A
0005433186181	20852	11	4C
0005435529216	20852	12	4D
0005434565903	20852	13	4E
0005435502273	20852	14	4F
0005435502262	20852	15	5A
0005434565911	20852	16	5C
0005434565864	20852	17	5D
0005435529136	20852	18	5E
0005434565950	20852	19	6C
0005435529176	20852	20	6E
0005434565843	20852	21	6F
0005435502355	20852	22	7A
0005435502319	20852	23	7D
0005435502178	20852	24	7E
0005435545681	20852	25	7F
0005435529262	20852	26	8A
0005434565914	20852	27	8C
0005435529127	20852	28	8D
0005435529215	20852	29	8E
0005435502247	20852	30	8F
0005435529243	20852	31	9A
0005435545691	20852	32	10A
0005435529274	20852	33	9F
0005435502274	20852	34	10C
0005434565923	20852	35	10D
0005435529228	20852	36	10E
0005435545726	20852	37	10F
0005435545743	20852	38	11A
0005435529178	20852	39	11C
0005435529196	20852	40	11E
0005435502354	20852	41	11F
0005435545733	20852	42	12A
0005435545725	20852	43	12C
0005433186179	20852	44	12D
0005433186183	20852	45	12E
0005433186182	20852	46	13D
0005434565949	20852	47	13E
0005435529217	20852	48	14A
0005435502258	20852	49	14C
0005435529124	20852	50	14D
0005435529171	20852	51	14E
0005435529183	20852	52	14F
0005435502261	20852	53	15A
0005435529249	20852	54	15C
0005433186180	20852	55	15D
0005435529197	20852	56	15E
0005435502320	20852	57	16A
0005435529177	20852	58	16C
0005433186186	20852	59	16E
0005434565912	20852	60	16F
0005435502259	20852	61	17C
0005435545735	20852	62	17D
0005433186185	20852	63	17E
0005434565907	20852	64	17F
0005433186178	20852	65	18D
0005435502312	20852	66	18E
0005434565913	20852	67	18F
0005435529273	20852	68	19A
0005435529229	20852	69	19D
0005435502246	20852	70	19E
0005435529123	20852	71	19F
0005435529209	20852	72	20A
0005435529203	20852	73	20C
0005435502270	20852	74	20F
0005435931600	3907	1	1C
0005435153795	3907	2	3C
0005435153790	3907	3	6A
0005435153792	3907	4	18D
0005435153791	3907	5	19A
0005435153794	3907	6	21B
0005435153793	3907	7	21D
0005435153732	21872	1	3B
0005435931628	21872	2	3D
0005435153741	21872	3	5A
0005435153733	21872	4	7B
0005435931627	21872	5	7C
0005435153740	21872	6	21A
0005435931629	21872	7	21C
0005435931630	21872	8	23A
0005432628950	7189	1	2A
0005435225587	7189	2	2C
0005435225588	7189	3	3A
0005435225590	7189	4	3B
0005432628958	7189	5	4A
0005435225568	7189	6	4C
0005432628952	7189	7	4D
0005432628951	7189	8	5B
0005432628962	7189	9	6A
0005432628953	7189	10	6B
0005432628955	7189	11	7B
0005432628957	7189	12	18A
0005432628959	7189	13	18B
0005435225581	7189	14	18D
0005432628963	7189	15	19A
0005432628954	7189	16	19D
0005432628960	7189	17	20A
0005435225561	7189	18	21A
0005432628961	7189	19	22B
0005435225603	7189	20	22C
0005432628949	7189	21	23A
0005432628956	7189	22	23B
0005435225640	28138	1	1B
0005432628777	28138	2	1C
0005432628883	28138	3	2A
0005435225649	28138	4	2B
0005432628915	28138	5	3B
0005435225644	28138	6	3C
0005435225645	28138	7	3D
0005432628738	28138	8	4B
0005432628739	28138	9	4D
0005432628866	28138	10	6A
0005432628841	28138	11	6D
0005432628801	28138	12	7A
0005435225642	28138	13	7B
0005432628886	28138	14	7C
0005435225641	28138	15	7D
0005435225646	28138	16	18A
0005432628843	28138	17	18C
0005435225648	28138	18	18D
0005435225643	28138	19	19B
0005432628914	28138	20	20A
0005435225647	28138	21	20C
0005432628846	28138	22	21A
0005432628811	28138	23	21B
0005432628842	28138	24	21C
0005432628819	28138	25	22A
0005432628776	28138	26	22C
0005435960077	8738	1	2C
0005434267933	8738	2	4B
0005435960080	8738	3	7C
0005435960078	8738	4	18A
0005434267934	8738	5	18B
0005435960079	8738	6	19A
0005434267939	8738	7	19D
0005434267967	8738	8	21B
0005434267935	8738	9	22B
0005434267980	15220	1	1A
0005435960058	15220	2	2B
0005435960038	15220	3	4C
0005434267976	15220	4	5A
0005434267977	15220	5	18B
0005434267978	15220	6	19C
0005435960039	15220	7	19D
0005435960053	15220	8	21C
0005434267979	15220	9	22A
0005432693278	1202	1	1A
0005432677600	1202	2	1F
0005432675242	1202	3	1D
0005432693275	1202	4	4A
0005432693281	1202	5	4F
0005432693276	1202	6	5D
0005432693273	1202	7	6C
0005432677597	1202	8	6F
0005432693283	1202	9	7C
0005432693269	1202	10	7B
0005432675241	1202	11	7E
0005432693261	1202	12	8A
0005432693282	1202	13	8B
0005432675239	1202	14	8D
0005432675244	1202	15	9F
0005432675237	1202	16	9E
0005432693272	1202	17	10A
0005432675246	1202	18	10B
0005432693254	1202	19	10F
0005432693279	1202	20	11C
0005432693268	1202	21	11B
0005432675250	1202	22	11D
0005432693257	1202	23	11F
0005432693260	1202	24	11E
0005432675240	1202	25	12B
0005432693277	1202	26	12C
0005432675252	1202	27	12F
0005432675249	1202	28	12E
0005432675251	1202	29	12D
0005432873282	1202	30	13A
0005432693255	1202	31	13D
0005432693267	1202	32	14D
0005432675248	1202	33	15B
0005432693274	1202	34	15D
0005432693270	1202	35	15C
0005432693265	1202	36	15E
0005432693258	1202	37	15F
0005432677601	1202	38	16C
0005432677599	1202	39	16B
0005432675245	1202	40	16D
0005432873284	1202	41	17A
0005432675243	1202	42	16F
0005432675236	1202	43	16E
0005432677598	1202	44	17B
0005432693253	1202	45	17F
0005432873260	1202	46	17E
0005432693263	1202	47	18B
0005432693256	1202	48	18C
0005432873283	1202	49	18E
0005432693271	1202	50	18D
0005432675247	1202	51	19A
0005432693280	1202	52	19C
0005432693284	1202	53	19E
0005432693262	1202	54	20A
0005432693266	1202	55	20F
0005432675238	1202	56	20E
0005432693259	1202	57	21D
0005432693264	1202	58	21B
0005432873300	1202	59	21E
0005432873347	17481	1	1A
0005432675151	17481	2	1D
0005432693008	17481	3	2A
0005432675059	17481	4	2F
0005432693033	17481	5	3F
0005432675152	17481	6	4C
0005432693113	17481	7	4D
0005432677570	17481	8	5C
0005432873344	17481	9	5A
0005432873346	17481	10	5D
0005432873342	17481	11	6B
0005432693039	17481	12	6A
0005432677562	17481	13	6D
0005432677583	17481	14	6F
0005432693063	17481	15	6E
0005432693143	17481	16	8D
0005432675138	17481	17	8F
0005432675084	17481	18	8E
0005432675124	17481	19	9F
0005432873343	17481	20	9E
0005432677582	17481	21	9D
0005432675114	17481	22	10A
0005432675175	17481	23	10C
0005432677555	17481	24	10B
0005432692972	17481	25	10E
0005432692987	17481	26	10F
0005432693034	17481	27	11D
0005432693005	17481	28	11C
0005432677563	17481	29	11F
0005432675162	17481	30	11E
0005432873345	17481	31	12B
0005432693032	17481	32	12A
0005432693050	17481	33	12C
0005432675117	17481	34	13A
0005432677558	17481	35	13B
0005432692852	17481	36	14A
0005432693004	17481	37	14D
0005432677559	17481	38	14F
0005432675126	17481	39	15B
0005432677566	17481	40	15A
0005432677571	17481	41	15C
0005432693024	17481	42	16B
0005432675160	17481	43	16E
0005432675134	17481	44	17F
0005432675125	17481	45	18A
0005432692949	17481	46	18B
0005432675161	17481	47	18E
0005432675157	17481	48	18F
0005432693007	17481	49	19B
0005432675060	17481	50	20D
0005432693123	17481	51	20E
0005432677584	17481	52	21B
0005432873341	17481	53	21A
0005434435298	1158	1	1B
0005433156767	1158	2	2A
0005434435290	1158	3	2C
0005434435294	1158	4	3A
0005433156725	1158	5	3B
0005434435295	1158	6	3C
0005433156754	1158	7	3D
0005434435297	1158	8	4B
0005434435300	1158	9	4D
0005433156712	1158	10	5A
0005434435301	1158	11	5B
0005434435303	1158	12	6A
0005433156753	1158	13	6D
0005434435302	1158	14	7A
0005433156755	1158	15	7D
0005434435289	1158	16	18A
0005433156770	1158	17	19A
0005433156766	1158	18	19B
0005434435291	1158	19	19C
0005434435293	1158	20	20A
0005433156733	1158	21	20D
0005434435288	1158	22	21A
0005434435292	1158	23	21B
0005434435299	1158	24	21D
0005433156711	1158	25	22A
0005434435296	1158	26	22D
0005434435287	1158	27	23A
0005433156777	1158	28	23B
0005434435190	17316	1	1B
0005434435159	17316	2	1C
0005434435104	17316	3	1D
0005433156809	17316	4	2A
0005434435200	17316	5	2D
0005433156810	17316	6	3A
0005433156813	17316	7	3D
0005434435152	17316	8	4A
0005433156814	17316	9	4C
0005434435125	17316	10	5A
0005433156812	17316	11	5B
0005434435225	17316	12	6A
0005434435174	17316	13	6C
0005434435198	17316	14	7B
0005434435249	17316	15	7C
0005434435124	17316	16	7D
0005433156815	17316	17	18A
0005434435189	17316	18	18B
0005433156811	17316	19	19A
0005433156818	17316	20	19C
0005434435103	17316	21	19D
0005433156816	17316	22	20A
0005434435175	17316	23	20B
0005434435153	17316	24	20C
0005434435158	17316	25	21A
0005434435166	17316	26	21B
0005434435201	17316	27	21D
0005433156817	17316	28	22A
0005434435199	17316	29	22C
0005434435169	17316	30	23A
0005435086887	4104	1	1D
0005435928116	4104	2	2B
0005435086888	4104	3	2D
0005435928115	4104	4	5C
0005435086891	4104	5	5D
0005435928114	4104	6	6B
0005435086892	4104	7	18D
0005435928138	4104	8	19C
0005435086893	4104	9	20A
0005435086890	4104	10	20B
0005435928147	4104	11	20C
0005435086889	4104	12	21A
0005435928137	4104	13	22A
0005435086886	4104	14	23A
0005435928180	24409	1	2B
0005435928176	24409	2	3C
0005435928178	24409	3	3D
0005435086826	24409	4	4B
0005435086841	24409	5	5A
0005435928179	24409	6	5D
0005435928177	24409	7	6C
0005435086827	24409	8	7C
0005435086837	24409	9	18B
0005435086838	24409	10	19B
0005435928181	24409	11	22B
0005435086831	24409	12	22D
0005435551558	11065	1	1B
0005435551559	11065	2	2C
0005435098541	11065	3	4B
0005435098550	11065	4	4F
0005435551543	11065	5	5A
0005435098549	11065	6	5F
0005435551588	11065	7	11D
0005435098547	11065	8	11H
0005435551580	11065	9	13H
0005435098543	11065	10	14D
0005435551585	11065	11	14E
0005435551562	11065	12	14H
0005435551553	11065	13	15F
0005435551564	11065	14	16D
0005435551586	11065	15	16B
0005435551614	11065	16	16F
0005435551544	11065	17	17E
0005435551551	11065	18	18G
0005435551590	11065	19	19H
0005435551538	11065	20	20B
0005435098548	11065	21	21G
0005435551566	11065	22	22A
0005435551567	11065	23	22B
0005435551584	11065	24	22G
0005435551545	11065	25	23B
0005435551550	11065	26	24B
0005435551557	11065	27	24E
0005435551589	11065	28	27H
0005435098556	11065	29	28E
0005435551546	11065	30	28D
0005435551605	11065	31	29F
0005435551579	11065	32	31B
0005435551613	11065	33	31H
0005435551568	11065	34	32E
0005435551530	11065	35	33A
0005435551542	11065	36	33E
0005435551563	11065	37	33F
0005435551552	11065	38	34B
0005435098542	11065	39	35D
0005435551577	11065	40	36F
0005435551594	11065	41	36G
0005435551547	11065	42	38A
0005435551576	11065	43	38B
0005435551622	17014	1	1G
0005435551630	17014	2	2C
0005435098574	17014	3	3A
0005435551640	17014	4	3G
0005435551641	17014	5	5H
0005435098570	17014	6	11D
0005435551628	17014	7	12A
0005435551633	17014	8	12B
0005435551624	17014	9	14D
0005435551632	17014	10	15H
0005435551635	17014	11	16A
0005435098572	17014	12	16D
0005435551623	17014	13	17H
0005435098571	17014	14	18D
0005435551629	17014	15	19G
0005435551631	17014	16	20A
0005435098575	17014	17	22A
0005435098573	17014	18	22B
0005435551638	17014	19	28D
0005435551634	17014	20	30D
0005435551636	17014	21	30B
0005435551637	17014	22	32A
0005435551639	17014	23	35A
0005435551625	17014	24	35G
0005435551626	17014	25	37E
0005435551627	17014	26	38D
0005434964077	18257	1	1F
0005433261632	18257	2	2F
0005433261634	18257	3	3A
0005433261647	18257	4	4A
0005433261638	18257	5	4G
0005434964232	18257	6	4F
0005434964258	18257	7	5A
0005433261644	18257	8	5C
0005434964191	18257	9	5F
0005434964161	18257	10	9A
0005434964179	18257	11	9B
0005434964184	18257	12	12A
0005433261645	18257	13	12D
0005433261633	18257	14	14D
0005433261635	18257	15	14H
0005434964207	18257	16	15B
0005434964156	18257	17	15D
0005433261637	18257	18	16G
0005433261639	18257	19	16F
0005434964123	18257	20	17B
0005434964192	18257	21	18A
0005434964254	18257	22	18B
0005434964131	18257	23	18F
0005433261628	18257	24	18E
0005434964172	18257	25	19A
0005434964223	18257	26	20D
0005434964236	18257	27	21B
0005434964201	18257	28	21A
0005434964159	18257	29	21D
0005434964177	18257	30	21G
0005434964218	18257	31	22A
0005434964124	18257	32	22F
0005434964162	18257	33	23B
0005433261636	18257	34	23E
0005434964219	18257	35	23G
0005434964214	18257	36	24B
0005433261629	18257	37	24F
0005433261640	18257	38	24E
0005433261627	18257	39	25D
0005433261646	18257	40	27A
0005433261643	18257	41	27D
0005434964234	18257	42	28H
0005433261642	18257	43	29E
0005434964204	18257	44	29G
0005434964240	18257	45	29F
0005434964173	18257	46	30E
0005434964149	18257	47	31A
0005434964235	18257	48	31B
0005434964239	18257	49	32H
0005433261641	18257	50	33A
0005434964216	18257	51	33B
0005433261631	18257	52	33F
0005434964233	18257	53	34B
0005434964076	18257	54	34E
0005434964157	18257	55	35A
0005433261630	18257	56	35B
0005434964200	18257	57	36A
0005434964217	18257	58	36D
0005434964213	18257	59	37E
0005434964206	18257	60	38A
0005433194828	4867	1	1D
0005434626031	4867	2	2A
0005434626028	4867	3	4E
0005434626033	4867	4	7C
0005435907480	4867	5	8C
0005434626030	4867	6	9A
0005435907484	4867	7	9F
0005434626029	4867	8	10C
0005435907510	4867	9	12C
0005434626034	4867	10	13D
0005434626027	4867	11	13F
0005435907497	4867	12	15A
0005434626035	4867	13	16D
0005434626036	4867	14	17C
0005434626032	4867	15	18C
0005435907502	4867	16	18E
0005435907483	4867	17	19D
0005435907511	4867	18	20D
0005434625989	32921	1	1F
0005434625968	32921	2	2D
0005434625911	32921	3	4A
0005435907539	32921	4	6F
0005434625958	32921	5	7D
0005435907541	32921	6	10A
0005434625912	32921	7	11E
0005434625993	32921	8	12C
0005434625969	32921	9	14A
0005435907540	32921	10	15F
0005434625992	32921	11	17C
0005435907538	32921	12	17F
0005433194876	32921	13	19C
0005434625915	32921	14	19D
0005434625988	32921	15	20A
0005435785295	13765	1	1B
0005435785204	13765	2	1D
0005435785251	13765	3	2A
0005435937414	13765	4	2B
0005435787348	13765	5	2D
0005435785203	13765	6	3A
0005435937411	13765	7	3B
0005435785287	13765	8	3C
0005435785070	13765	9	3D
0005435785224	13765	10	4A
0005435785283	13765	11	4B
0005435785260	13765	12	4C
0005435785296	13765	13	4D
0005432195708	13765	14	5A
0005435785150	13765	15	5B
0005435785337	13765	16	5C
0005435785181	13765	17	5D
0005435785290	13765	18	6A
0005435785375	13765	19	6B
0005435937415	13765	20	7A
0005435785286	13765	21	7C
0005435937413	13765	22	7D
0005435785298	13765	23	18A
0005435785268	13765	24	18B
0005435785149	13765	25	18C
0005435785130	13765	26	18D
0005435785294	13765	27	19B
0005435785282	13765	28	19D
0005435787347	13765	29	20B
0005435785301	13765	30	20C
0005435785293	13765	31	20D
0005432195709	13765	32	21A
0005435937412	13765	33	21B
0005435937410	13765	34	21C
0005435785199	13765	35	21D
0005435785309	13765	36	22B
0005435785242	13765	37	22C
0005435785289	13765	38	22D
0005435785261	13765	39	23B
0005432190653	27443	1	1A
0005435785543	27443	2	1B
0005435937364	27443	3	1C
0005435785546	27443	4	1D
0005435785572	27443	5	2A
0005435785563	27443	6	2B
0005435785555	27443	7	2C
0005435785547	27443	8	2D
0005435785559	27443	9	3A
0005435785544	27443	10	3B
0005435937350	27443	11	3C
0005435787366	27443	12	3D
0005435785562	27443	13	4A
0005435785565	27443	14	4B
0005435785574	27443	15	4C
0005435785564	27443	16	4D
0005435785549	27443	17	5A
0005435785545	27443	18	5B
0005435785567	27443	19	5C
0005435785575	27443	20	5D
0005435785550	27443	21	6A
0005435785553	27443	22	6B
0005435785576	27443	23	6C
0005435785561	27443	24	6D
0005435937358	27443	25	7A
0005435785568	27443	26	7B
0005435937345	27443	27	7C
0005435785551	27443	28	7D
0005435785569	27443	29	18A
0005435785554	27443	30	18B
0005435785558	27443	31	18C
0005435937372	27443	32	18D
0005435785573	27443	33	19A
0005435785566	27443	34	19B
0005435937370	27443	35	19C
0005435785557	27443	36	19D
0005435937371	27443	37	20A
0005435785571	27443	38	20B
0005435937385	27443	39	20C
0005435937344	27443	40	20D
0005435785552	27443	41	21A
0005435785560	27443	42	21B
0005435785577	27443	43	21D
0005435785548	27443	44	21C
0005435787367	27443	45	22A
0005435937386	27443	46	22B
0005435785556	27443	47	22C
0005432190652	27443	48	22D
0005435785570	27443	49	23A
0005434407728	20259	1	1C
0005434407725	20259	2	1D
0005434407702	20259	3	2A
0005435311141	20259	4	2C
0005434407845	20259	5	2D
0005434408010	20259	6	2F
0005434407724	20259	7	3C
0005435311149	20259	8	3D
0005434408011	20259	9	3F
0005434408056	20259	10	4C
0005435311153	20259	11	4D
0005434407677	20259	12	4E
0005435311147	20259	13	4F
0005435311139	20259	14	5A
0005434407686	20259	15	5C
0005432058411	20259	16	5F
0005434407402	20259	17	6A
0005434407689	20259	18	6C
0005434407697	20259	19	6D
0005434407447	20259	20	6E
0005434407784	20259	21	6F
0005434407613	20259	22	7A
0005434407403	20259	23	7C
0005434407246	20259	24	7D
0005435311150	20259	25	7E
0005434407568	20259	26	7F
0005435311143	20259	27	8A
0005434407391	20259	28	8C
0005434407620	20259	29	8D
0005434407849	20259	30	8E
0005435311152	20259	31	8F
0005432058410	20259	32	9C
0005434407695	20259	33	9D
0005432058409	20259	34	9E
0005434407793	20259	35	10A
0005435311156	20259	36	10E
0005434407718	20259	37	10F
0005435311145	20259	38	11D
0005434407846	20259	39	11F
0005434407902	20259	40	12A
0005435311140	20259	41	12C
0005435311142	20259	42	12D
0005434407651	20259	43	12E
0005434407698	20259	44	13A
0005434407618	20259	45	13C
0005435311144	20259	46	13D
0005434407456	20259	47	13E
0005434407713	20259	48	13F
0005434407452	20259	49	14A
0005434407573	20259	50	14E
0005432058412	20259	51	14F
0005434407442	20259	52	15A
0005435311155	20259	53	15D
0005434407796	20259	54	15E
0005434407703	20259	55	15F
0005434407608	20259	56	16A
0005434407699	20259	57	16C
0005434407619	20259	58	16D
0005434407629	20259	59	16E
0005435311151	20259	60	16F
0005435311154	20259	61	17A
0005434407685	20259	62	17C
0005434407844	20259	63	17D
0005435311146	20259	64	17E
0005434407555	20259	65	18A
0005434407794	20259	66	18C
0005434407783	20259	67	18D
0005434407443	20259	68	18E
0005434407682	20259	69	18F
0005434407628	20259	70	19D
0005435311148	20259	71	19E
0005434407650	20259	72	19F
0005434407474	20259	73	20C
0005434407318	20259	74	20D
0005434407609	20259	75	20E
0005434408198	26982	1	1C
0005434408232	26982	2	1D
0005434408209	26982	3	1F
0005432153988	26982	4	2C
0005434408203	26982	5	2D
0005434408225	26982	6	2F
0005434408219	26982	7	3A
0005434408206	26982	8	3C
0005434408242	26982	9	3D
0005434408210	26982	10	3F
0005435311032	26982	11	4A
0005435311025	26982	12	4E
0005435310998	26982	13	5A
0005435310979	26982	14	5D
0005434408216	26982	15	5E
0005434408220	26982	16	5F
0005434408200	26982	17	6A
0005434408204	26982	18	6C
0005435310981	26982	19	6D
0005434408222	26982	20	6E
0005434408244	26982	21	6F
0005434408230	26982	22	7A
0005434408229	26982	23	7D
0005434408238	26982	24	7E
0005434408195	26982	25	7F
0005435311018	26982	26	8A
0005432153986	26982	27	8C
0005434408201	26982	28	8D
0005434408214	26982	29	8E
0005435311024	26982	30	8F
0005432153992	26982	31	9A
0005434408189	26982	32	9C
0005434408215	26982	33	9D
0005434408247	26982	34	9E
0005434408248	26982	35	9F
0005434408236	26982	36	10D
0005434408249	26982	37	10E
0005435311019	26982	38	10F
0005434408237	26982	39	11C
0005434408235	26982	40	11D
0005435311010	26982	41	11F
0005432153989	26982	42	12A
0005432153991	26982	43	12C
0005434408243	26982	44	12D
0005434408233	26982	45	12E
0005434408221	26982	46	12F
0005432153985	26982	47	13A
0005434408226	26982	48	13C
0005434408196	26982	49	13D
0005434408199	26982	50	13E
0005434408191	26982	51	14A
0005434408194	26982	52	14C
0005434408208	26982	53	14D
0005432153987	26982	54	14E
0005434408252	26982	55	14F
0005434408250	26982	56	15A
0005434408234	26982	57	15C
0005434408245	26982	58	15D
0005434408217	26982	59	15E
0005432153990	26982	60	15F
0005434408213	26982	61	16A
0005434408240	26982	62	16C
0005434408212	26982	63	16D
0005434408241	26982	64	16E
0005434408251	26982	65	16F
0005434408253	26982	66	17A
0005434408246	26982	67	17C
0005434408239	26982	68	17E
0005434408218	26982	69	17F
0005434408223	26982	70	18C
0005434408197	26982	71	18D
0005434408205	26982	72	18E
0005434408224	26982	73	18F
0005434408193	26982	74	19A
0005434408231	26982	75	19C
0005434408192	26982	76	19D
0005434408211	26982	77	19E
0005434408207	26982	78	19F
0005434408190	26982	79	20A
0005434408202	26982	80	20D
0005434408227	26982	81	20E
0005434408228	26982	82	20F
0005434311236	5720	1	2A
0005433124010	5720	2	2D
0005433123751	5720	3	3D
0005432109722	5720	4	3F
0005433123841	5720	5	4C
0005434319505	5720	6	4E
0005434319506	5720	7	5C
0005434319508	5720	8	5D
0005433123750	5720	9	5E
0005433123907	5720	10	6D
0005433123875	5720	11	6F
0005433123883	5720	12	7A
0005433123856	5720	13	7C
0005433123966	5720	14	8D
0005433123842	5720	15	8F
0005433123838	5720	16	9C
0005434319509	5720	17	9E
0005433123850	5720	18	9F
0005434311235	5720	19	10C
0005433123909	5720	20	10F
0005433123901	5720	21	11C
0005433123762	5720	22	11D
0005434319504	5720	23	11E
0005433123921	5720	24	12C
0005433123902	5720	25	12D
0005433123938	5720	26	12E
0005433123855	5720	27	12F
0005433123900	5720	28	14C
0005433124011	5720	29	14E
0005432109723	5720	30	15A
0005432109724	5720	31	15C
0005434319507	5720	32	15D
0005433123849	5720	33	16A
0005433123877	5720	34	16C
0005433123937	5720	35	16D
0005433123851	5720	36	17E
0005433123839	5720	37	17F
0005433123967	5720	38	18C
0005433123872	5720	39	18F
0005433123867	5720	40	19D
0005433123969	5720	41	20A
0005433123908	5720	42	20D
0005434311234	5720	43	20F
0005433124093	15654	1	1C
0005434319403	15654	2	1D
0005433124085	15654	3	2F
0005434311212	15654	4	3A
0005433124082	15654	5	4C
0005433124078	15654	6	4F
0005434311204	15654	7	6D
0005433124086	15654	8	7A
0005434319345	15654	9	7D
0005433124090	15654	10	7E
0005433124087	15654	11	7F
0005434319373	15654	12	8A
0005433124094	15654	13	10A
0005433124095	15654	14	10F
0005433124077	15654	15	11C
0005433124074	15654	16	11E
0005433124089	15654	17	12D
0005434319370	15654	18	13C
0005434319344	15654	19	13E
0005433124081	15654	20	13F
0005433124076	15654	21	14D
0005433124075	15654	22	15A
0005433124084	15654	23	15C
0005433124079	15654	24	16F
0005433124088	15654	25	17A
0005433124083	15654	26	17C
0005434319318	15654	27	18D
0005434311205	15654	28	18E
0005433124080	15654	29	18F
0005434319371	15654	30	19C
0005433124096	15654	31	19D
0005433124091	15654	32	20C
0005434319346	15654	33	20E
0005433124092	15654	34	20F
0005435217701	24969	1	1D
0005435220305	24969	2	3A
0005435220314	24969	3	3C
0005435220315	24969	4	4A
0005435220313	24969	5	4C
0005435221513	24969	6	6B
0005435217702	24969	7	7D
0005435220311	24969	8	19B
0005435217703	24969	9	23B
0005434189170	8961	1	1B
0005434484397	8961	2	4A
0005434189193	8961	3	4D
0005434189159	8961	4	5A
0005434189171	8961	5	6B
0005434484394	8961	6	6C
0005434189166	8961	7	7C
0005434484398	8961	8	18D
0005434484395	8961	9	19B
0005434484399	8961	10	22C
0005434484396	8961	11	23A
0005434484344	16618	1	1C
0005434484345	16618	2	2D
0005434484337	16618	3	3A
0005434189219	16618	4	3B
0005434189221	16618	5	3C
0005434189223	16618	6	4D
0005434484326	16618	7	6D
0005434189218	16618	8	18A
0005434189220	16618	9	18D
0005434484325	16618	10	19C
0005434189222	16618	11	20A
0005434189224	16618	12	20B
0005434484340	16618	13	21B
0005434484347	16618	14	21C
0005434189225	16618	15	21D
0005433124076	7681	1	1A
0005433124087	7681	2	1C
0005433124075	7681	3	3A
0005433124078	7681	4	3C
0005433722192	7681	5	3F
0005433722193	7681	6	4A
0005433124092	7681	7	4C
0005433124083	7681	8	4D
0005433124084	7681	9	5F
0005433124095	7681	10	6A
0005433124081	7681	11	7C
0005433124091	7681	12	8A
0005433124079	7681	13	10A
0005433124093	7681	14	11E
0005433124080	7681	15	12A
0005433124089	7681	16	12D
0005433722187	7681	17	13C
0005433124086	7681	18	13D
0005433124088	7681	19	15F
0005433124094	7681	20	16D
0005433124082	7681	21	16E
0005433124085	7681	22	16F
0005433124090	7681	23	17C
0005433124096	7681	24	18D
0005433124074	7681	25	20D
0005433124077	7681	26	20F
0005432721100	7683	1	1A
0005433450121	7683	2	1C
0005432721097	7683	3	1F
0005432721110	7683	4	2A
0005433450137	7683	5	2C
0005432693312	7683	6	2F
0005432693294	7683	7	3A
0005433450139	7683	8	3C
0005432721113	7683	9	3D
0005432721107	7683	10	3F
0005433450119	7683	11	4A
0005432693314	7683	12	4C
0005432693292	7683	13	4F
0005432693301	7683	14	5A
0005432693290	7683	15	5C
0005433450132	7683	16	5E
0005432071595	7683	17	5D
0005433450129	7683	18	5F
0005432721092	7683	19	6A
0005433450135	7683	20	6C
0005432693299	7683	21	6D
0005433450140	7683	22	6E
0005433450133	7683	23	6F
0005432721114	7683	24	7A
0005432721103	7683	25	7C
0005432693297	7683	26	7D
0005432721096	7683	27	7E
0005432693311	7683	28	7F
0005432721112	7683	29	8A
0005432693309	7683	30	8C
0005433450138	7683	31	8D
0005432721099	7683	32	8E
0005432693302	7683	33	8F
0005432693286	7683	34	9C
0005432693315	7683	35	9D
0005433450134	7683	36	9E
0005432721098	7683	37	9F
0005432721088	7683	38	10A
0005432721108	7683	39	10C
0005433450123	7683	40	10D
0005432071594	7683	41	10F
0005432721106	7683	42	10E
0005432693313	7683	43	11A
0005432721091	7683	44	11C
0005432693293	7683	45	11E
0005432693285	7683	46	11F
0005433450125	7683	47	12A
0005432721093	7683	48	12C
0005432693303	7683	49	12D
0005432693287	7683	50	12E
0005432721094	7683	51	12F
0005432693300	7683	52	13A
0005433450131	7683	53	13C
0005432071597	7683	54	13D
0005432693307	7683	55	13E
0005433450124	7683	56	13F
0005432693289	7683	57	14A
0005432693310	7683	58	14C
0005433450122	7683	59	14D
0005432693308	7683	60	14E
0005432721095	7683	61	15A
0005433450127	7683	62	15C
0005433450128	7683	63	15E
0005432693296	7683	64	15F
0005432693305	7683	65	16A
0005432721101	7683	66	16C
0005432693288	7683	67	16D
0005432721109	7683	68	16E
0005432693304	7683	69	16F
0005432693295	7683	70	17A
0005433450136	7683	71	17C
0005432721090	7683	72	17D
0005432721104	7683	73	17E
0005432721102	7683	74	17F
0005433450126	7683	75	18A
0005432721111	7683	76	18C
0005432721087	7683	77	18D
0005433450130	7683	78	18E
0005432721089	7683	79	19A
0005432693291	7683	80	19C
0005432721105	7683	81	19E
0005433450120	7683	82	19F
0005432693298	7683	83	20C
0005432693306	7683	84	20D
0005432721115	7683	85	20E
0005432071596	7683	86	20F
0005433449905	30299	1	1A
0005432693007	30299	2	1C
0005432693063	30299	3	1F
0005432693050	30299	4	2A
0005433449954	30299	5	3A
0005433450037	30299	6	3D
0005432693008	30299	7	4A
0005432693113	30299	8	4D
0005433449963	30299	9	5A
0005432692852	30299	10	5C
0005432693033	30299	11	5D
0005432692949	30299	12	5E
0005432692972	30299	13	6E
0005433449933	30299	14	6F
0005433449998	30299	15	8A
0005433449892	30299	16	8D
0005432693004	30299	17	8E
0005433449921	30299	18	9D
0005432692987	30299	19	10D
0005433449968	30299	20	10E
0005433450044	30299	21	10F
0005433449976	30299	22	11A
0005432693032	30299	23	12E
0005433449894	30299	24	12F
0005432693039	30299	25	13A
0005433449900	30299	26	14C
0005432693024	30299	27	14E
0005433449962	30299	28	16E
0005432693005	30299	29	16F
0005433449961	30299	30	18A
0005432693143	30299	31	18D
0005432693034	30299	32	19A
0005433449893	30299	33	19D
0005433450041	30299	34	19E
0005432693123	30299	35	20E
0005433123841	30300	1	1A
0005433123900	30300	2	1C
0005433722272	30300	3	1D
0005432720854	30300	4	1F
0005432720814	30300	5	2A
0005432720953	30300	6	2C
0005433123967	30300	7	2D
0005432720975	30300	8	2F
0005432720857	30300	9	3A
0005433123938	30300	10	3C
0005433123856	30300	11	3D
0005432720908	30300	12	3F
0005433123850	30300	13	4C
0005432720759	30300	14	4F
0005432720841	30300	15	5C
0005432720856	30300	16	5E
0005432721001	30300	17	5F
0005432720962	30300	18	6A
0005433123908	30300	19	6C
0005433123851	30300	20	6D
0005432720845	30300	21	6F
0005433123902	30300	22	7A
0005432720899	30300	23	7C
0005433123966	30300	24	7D
0005432720929	30300	25	7E
0005433123883	30300	26	7F
0005433123901	30300	27	8A
0005432720872	30300	28	8D
0005433123875	30300	29	8C
0005433722275	30300	30	8F
0005433722276	30300	31	9C
0005432720901	30300	32	9E
0005433123867	30300	33	10C
0005432720898	30300	34	10D
0005432720961	30300	35	10E
0005432720758	30300	36	10F
0005433123921	30300	37	11D
0005433123842	30300	38	11F
0005432720855	30300	39	12C
0005433123849	30300	40	12E
0005432720930	30300	41	13E
0005432720964	30300	42	14A
0005433124010	30300	43	14E
0005432720820	30300	44	14F
0005433123839	30300	45	15A
0005432720949	30300	46	15D
0005432720863	30300	47	15E
0005433123937	30300	48	15F
0005432720842	30300	49	16A
0005433722274	30300	50	16C
0005432720862	30300	51	16D
0005432720846	30300	52	16E
0005432720828	30300	53	17C
0005433123838	30300	54	17E
0005433123969	30300	55	17F
0005432720922	30300	56	18A
0005433722273	30300	57	18C
0005433123872	30300	58	18D
0005433123750	30300	59	18E
0005433123877	30300	60	19A
0005432720888	30300	61	19C
0005433123909	30300	62	19D
0005433124011	30300	63	19F
0005433123751	30300	64	20A
0005433123907	30300	65	20C
0005433123855	30300	66	20E
0005433123762	30300	67	20F
0005432927972	1385	1	1A
0005433525124	1385	2	1C
0005434586808	1385	3	1D
0005434586806	1385	4	1F
0005432927992	1385	5	2A
0005434586799	1385	6	2C
0005433724838	1385	7	2D
0005432927973	1385	8	2F
0005432271027	1385	9	3A
0005433525115	1385	10	3C
0005434586810	1385	11	3D
0005433525116	1385	12	3F
0005434586791	1385	13	4A
0005433193040	1385	14	4C
0005434586796	1385	15	4D
0005432271025	1385	16	5A
0005432968845	1385	17	5C
0005434586812	1385	18	5D
0005434513598	1385	19	6D
0005434514987	1385	20	6C
0005433525123	1385	21	6E
0005434513599	1385	22	6F
0005432271024	1385	23	7A
0005434514986	1385	24	7C
0005433525118	1385	25	7D
0005434586805	1385	26	7E
0005433193054	1385	27	7F
0005433525114	1385	28	8C
0005433193056	1385	29	8F
0005433724837	1385	30	9A
0005434586804	1385	31	9C
0005434586797	1385	32	9D
0005433193039	1385	33	9E
0005434586801	1385	34	9F
0005434586789	1385	35	10A
0005434586792	1385	36	10D
0005433724839	1385	37	11A
0005433525121	1385	38	11C
0005434586798	1385	39	11D
0005432968835	1385	40	11E
0005434586800	1385	41	12A
0005432968839	1385	42	12C
0005433724836	1385	43	12D
0005432927969	1385	44	12E
0005433193006	1385	45	12F
0005433193041	1385	46	13C
0005433525113	1385	47	13D
0005434586811	1385	48	13E
0005432927951	1385	49	13F
0005432271026	1385	50	14A
0005434586790	1385	51	14C
0005433525119	1385	52	14D
0005433525125	1385	53	15A
0005432927989	1385	54	14F
0005433525120	1385	55	15C
0005432968834	1385	56	15D
0005434586809	1385	57	15E
0005434586807	1385	58	15F
0005433724841	1385	59	16A
0005434513600	1385	60	16C
0005433525117	1385	61	16D
0005434586802	1385	62	16E
0005434586795	1385	63	17A
0005432927985	1385	64	17C
0005433193085	1385	65	17D
0005433193043	1385	66	17E
0005432927976	1385	67	17F
0005432968836	1385	68	18A
0005434586803	1385	69	18C
0005432927975	1385	70	18D
0005434586813	1385	71	18F
0005433724840	1385	72	19A
0005432927982	1385	73	19C
0005433193055	1385	74	19D
0005433193046	1385	75	19E
0005434586814	1385	76	19F
0005434586794	1385	77	20A
0005433192995	1385	78	20C
0005433193025	1385	79	20D
0005433525122	1385	80	20E
0005434586793	1385	81	20F
0005433193149	18518	1	1A
0005434586701	18518	2	1D
0005434586667	18518	3	2A
0005434586523	18518	4	3A
0005434586552	18518	5	3D
0005433193147	18518	6	3F
0005433525002	18518	7	4C
0005433193140	18518	8	4D
0005434586598	18518	9	4E
0005434586577	18518	10	4F
0005434586599	18518	11	5C
0005434514958	18518	12	5D
0005434586529	18518	13	5E
0005434586628	18518	14	5F
0005433193142	18518	15	6C
0005433524996	18518	16	6E
0005434586568	18518	17	7C
0005434586497	18518	18	7D
0005432968857	18518	19	7E
0005433193150	18518	20	7F
0005432968855	18518	21	8C
0005434514960	18518	22	8E
0005433724807	18518	23	9A
0005433193148	18518	24	9E
0005434586634	18518	25	10A
0005433525020	18518	26	10F
0005433193144	18518	27	11A
0005433193139	18518	28	11D
0005433193146	18518	29	12E
0005434586635	18518	30	12F
0005434586670	18518	31	13A
0005432968856	18518	32	13C
0005434586429	18518	33	13D
0005434586522	18518	34	13E
0005433193143	18518	35	13F
0005432928019	18518	36	14A
0005433525022	18518	37	14D
0005434586643	18518	38	14F
0005434586735	18518	39	15A
0005433524968	18518	40	15D
0005433193141	18518	41	15E
0005433193138	18518	42	15F
0005432928018	18518	43	16A
0005433525001	18518	44	16C
0005433525019	18518	45	16D
0005434586613	18518	46	16E
0005432928022	18518	47	17A
0005434586703	18518	48	17C
0005434586672	18518	49	17E
0005434514959	18518	50	17F
0005434586567	18518	51	18A
0005434586579	18518	52	18C
0005433525021	18518	53	18D
0005434586671	18518	54	18F
0005434586511	18518	55	19A
0005433193145	18518	56	19C
0005434514961	18518	57	19E
0005432928020	18518	58	19F
0005432928021	18518	59	20C
0005434586734	18518	60	20D
0005434586510	18518	61	20E
0005434344448	11478	1	1A
0005434344441	11478	2	1B
0005434344467	11478	3	1C
0005434344463	11478	4	1D
0005434344469	11478	5	2A
0005434344452	11478	6	2B
0005434344457	11478	7	2C
0005435302170	11478	8	2D
0005434344453	11478	9	3A
0005434344442	11478	10	3B
0005434344445	11478	11	3C
0005435302191	11478	12	3D
0005435302171	11478	13	4B
0005434344458	11478	14	4C
0005435302192	11478	15	4D
0005434344443	11478	16	5B
0005434344446	11478	17	5C
0005435302206	11478	18	6A
0005434344444	11478	19	6B
0005434344437	11478	20	6C
0005434344460	11478	21	6D
0005434344447	11478	22	7A
0005434344459	11478	23	7B
0005434142642	11478	24	7C
0005434344468	11478	25	7D
0005434142641	11478	26	18A
0005435302190	11478	27	18B
0005434344464	11478	28	18C
0005434344466	11478	29	18D
0005434344451	11478	30	19A
0005434344439	11478	31	19B
0005434344461	11478	32	19C
0005434344438	11478	33	19D
0005434344465	11478	34	20B
0005434344454	11478	35	20C
0005434344455	11478	36	21A
0005435302189	11478	37	21B
0005434142640	11478	38	21C
0005434344462	11478	39	21D
0005434344456	11478	40	22A
0005435302207	11478	41	22B
0005435302193	11478	42	22C
0005434344449	11478	43	22D
0005434344440	11478	44	23A
0005434344450	11478	45	23B
0005434344137	29772	1	1A
0005434344241	29772	2	1B
0005434142602	29772	3	1C
0005434344089	29772	4	1D
0005434344075	29772	5	2A
0005434344088	29772	6	2B
0005434142598	29772	7	2C
0005434142601	29772	8	3A
0005435304191	29772	9	3B
0005434344066	29772	10	3C
0005434344113	29772	11	3D
0005434344269	29772	12	4A
0005434344132	29772	13	4B
0005434344184	29772	14	4C
0005434344057	29772	15	4D
0005434344102	29772	16	5A
0005434344186	29772	17	5B
0005434344063	29772	18	5C
0005434344197	29772	19	6A
0005434142600	29772	20	6B
0005434344185	29772	21	6C
0005434344087	29772	22	6D
0005434344194	29772	23	7A
0005435304188	29772	24	7C
0005434344058	29772	25	7D
0005434343964	29772	26	18A
0005435305027	29772	27	18B
0005435304190	29772	28	18C
0005434344043	29772	29	18D
0005434344076	29772	30	19A
0005434344135	29772	31	19B
0005435304189	29772	32	19C
0005434343965	29772	33	19D
0005434344233	29772	34	20A
0005434344074	29772	35	20B
0005435304192	29772	36	20C
0005434344099	29772	37	20D
0005434344051	29772	38	21A
0005434344268	29772	39	21B
0005434344085	29772	40	21C
0005434344112	29772	41	21D
0005434343971	29772	42	22A
0005435305026	29772	43	22B
0005434344240	29772	44	22C
0005434344044	29772	45	22D
0005434344246	29772	46	23A
0005434344120	29772	47	23B
0005435824823	1296	1	1C
0005435824832	1296	2	2A
0005435824837	1296	3	1F
0005433415619	1296	4	3D
0005433415568	1296	5	3F
0005432284580	1296	6	5A
0005433415567	1296	7	5C
0005435824824	1296	8	5F
0005435824826	1296	9	5D
0005435824816	1296	10	6B
0005435824813	1296	11	6A
0005435824825	1296	12	6E
0005435824834	1296	13	7B
0005432284579	1296	14	7C
0005435824827	1296	15	8B
0005433415546	1296	16	8F
0005433415593	1296	17	8E
0005435824812	1296	18	9A
0005435824811	1296	19	9D
0005435824817	1296	20	9B
0005433415639	1296	21	10A
0005433415685	1296	22	10C
0005435824836	1296	23	10F
0005433415545	1296	24	11E
0005433415633	1296	25	11F
0005433415688	1296	26	12C
0005433415689	1296	27	12D
0005435824819	1296	28	13A
0005435824821	1296	29	13C
0005435824818	1296	30	13D
0005433415636	1296	31	13F
0005433415686	1296	32	14C
0005435824829	1296	33	14F
0005435824810	1296	34	14E
0005435824828	1296	35	16A
0005435824833	1296	36	15F
0005435824830	1296	37	16E
0005435824822	1296	38	17C
0005433415638	1296	39	17D
0005435824831	1296	40	17E
0005435824835	1296	41	17F
0005435824820	1296	42	18E
0005435824814	1296	43	18D
0005433415684	1296	44	20B
0005435824815	1296	45	20D
0005432284581	1296	46	20E
0005435824677	18013	1	1C
0005435824542	18013	2	1A
0005435824537	18013	3	1F
0005435824642	18013	4	2D
0005435824616	18013	5	2C
0005433415778	18013	6	3A
0005435824619	18013	7	3D
0005435824583	18013	8	4A
0005433415782	18013	9	4C
0005433415776	18013	10	4F
0005435824614	18013	11	6C
0005433415775	18013	12	7A
0005435824543	18013	13	6F
0005435824530	18013	14	7B
0005435824536	18013	15	7E
0005433415784	18013	16	7D
0005435824618	18013	17	8C
0005433415771	18013	18	9B
0005435824590	18013	19	9E
0005433415773	18013	20	10A
0005435824456	18013	21	10B
0005435824565	18013	22	10D
0005435824655	18013	23	10F
0005433415780	18013	24	11B
0005435824477	18013	25	11A
0005435824630	18013	26	11C
0005435824719	18013	27	11F
0005435824566	18013	28	11E
0005433415777	18013	29	12A
0005435824584	18013	30	12C
0005435824544	18013	31	12E
0005433415781	18013	32	13B
0005433415769	18013	33	13A
0005435824506	18013	34	12F
0005435824545	18013	35	13D
0005435824678	18013	36	13F
0005435824641	18013	37	16C
0005435824577	18013	38	16B
0005433415785	18013	39	16D
0005435824581	18013	40	17A
0005435824589	18013	41	16F
0005433415772	18013	42	17F
0005433415770	18013	43	17E
0005435824547	18013	44	18B
0005433415779	18013	45	18A
0005435824529	18013	46	18D
0005435824576	18013	47	18E
0005433415774	18013	48	19A
0005435824556	18013	49	18F
0005435824510	18013	50	19B
0005433415783	18013	51	19D
0005435824623	18013	52	19F
0005435824656	18013	53	20B
0005435824617	18013	54	20A
0005435824622	18013	55	20C
0005435824457	18013	56	20F
0005435824554	18013	57	21F
0005434460490	17519	1	1B
0005434460492	17519	2	2A
0005434462789	17519	3	2C
0005434460499	17519	4	2D
0005434462783	17519	5	3B
0005434460489	17519	6	3C
0005434462786	17519	7	4A
0005434460488	17519	8	6B
0005434462785	17519	9	6D
0005434460498	17519	10	7B
0005434462773	17519	11	18A
0005434460491	17519	12	18D
0005434460505	17519	13	20C
0005434462780	17519	14	21A
0005432784167	5610	1	1A
0005432784176	5610	2	1C
0005432784207	5610	3	1D
0005435476720	5610	4	1F
0005432784213	5610	5	2A
0005435242874	5610	6	2C
0005435242691	5610	7	2D
0005435242839	5610	8	2F
0005435242747	5610	9	3A
0005432784212	5610	10	3C
0005432784174	5610	11	3D
0005432784210	5610	12	3F
0005432784201	5610	13	4A
0005435242750	5610	14	4C
0005432784216	5610	15	4D
0005432784166	5610	16	4E
0005432784196	5610	17	4F
0005432144010	5610	18	5A
0005432784214	5610	19	5C
0005432784206	5610	20	5D
0005432144012	5610	21	5E
0005432784191	5610	22	5F
0005432784182	5610	23	6A
0005432784187	5610	24	6C
0005435242809	5610	25	6D
0005435242810	5610	26	6E
0005435242837	5610	27	6F
0005432784169	5610	28	7A
0005432784188	5610	29	7C
0005432784178	5610	30	7D
0005435242830	5610	31	7E
0005432784203	5610	32	7F
0005432784200	5610	33	8A
0005432784165	5610	34	8C
0005432784198	5610	35	8D
0005435242774	5610	36	8E
0005432784170	5610	37	8F
0005432784202	5610	38	9A
0005435242717	5610	39	9C
0005432784164	5610	40	9D
0005432784186	5610	41	9E
0005432784205	5610	42	9F
0005435242815	5610	43	10A
0005435242877	5610	44	10C
0005432784189	5610	45	10D
0005432784190	5610	46	10E
0005432144011	5610	47	10F
0005435242829	5610	48	11A
0005435242871	5610	49	11C
0005435242851	5610	50	11D
0005432784177	5610	51	11E
0005435242759	5610	52	11F
0005435242540	5610	53	12C
0005432784185	5610	54	12D
0005435242763	5610	55	12E
0005432784172	5610	56	12F
0005435242845	5610	57	13A
0005435242637	5610	58	13C
0005432784211	5610	59	13E
0005435242695	5610	60	13F
0005435476732	5610	61	14A
0005432784175	5610	62	14C
0005432784197	5610	63	14D
0005435476717	5610	64	14E
0005432784208	5610	65	14F
0005432784162	5610	66	15A
0005432784168	5610	67	15C
0005435242811	5610	68	15D
0005432784161	5610	69	15E
0005432784179	5610	70	15F
0005435242838	5610	71	16A
0005432784194	5610	72	16C
0005432784209	5610	73	16D
0005432784199	5610	74	16E
0005432784192	5610	75	16F
0005432784160	5610	76	17A
0005432784171	5610	77	17C
0005435242875	5610	78	17E
0005435242825	5610	79	17D
0005435242801	5610	80	17F
0005435242696	5610	81	18A
0005432784180	5610	82	18C
0005432784173	5610	83	18D
0005432784195	5610	84	18E
0005435242775	5610	85	18F
0005435242846	5610	86	19A
0005432784181	5610	87	19C
0005432784184	5610	88	19D
0005435242872	5610	89	19E
0005432784193	5610	90	19F
0005432784183	5610	91	20A
0005432784204	5610	92	20C
0005432784215	5610	93	20D
0005432784163	5610	94	20E
0005435476721	5610	95	20F
0005435476808	15378	1	1A
0005432783532	15378	2	1D
0005435476809	15378	3	1C
0005432783814	15378	4	1F
0005432783604	15378	5	2A
0005432783733	15378	6	2C
0005432783802	15378	7	2D
0005435243037	15378	8	2F
0005435243036	15378	9	3A
0005435476810	15378	10	3C
0005432783648	15378	11	3D
0005435476807	15378	12	3F
0005435243021	15378	13	4A
0005432783354	15378	14	4C
0005432783558	15378	15	4D
0005432783670	15378	16	4E
0005432783554	15378	17	4F
0005435243045	15378	18	5A
0005432783674	15378	19	5C
0005432783856	15378	20	5D
0005435243042	15378	21	5E
0005435243041	15378	22	5F
0005435243027	15378	23	6A
0005435243039	15378	24	6C
0005432783544	15378	25	6D
0005435476806	15378	26	6E
0005435243029	15378	27	6F
0005435476812	15378	28	7A
0005435243019	15378	29	7D
0005435243032	15378	30	7E
0005432783649	15378	31	7F
0005435476805	15378	32	8A
0005432783816	15378	33	8C
0005432783462	15378	34	8D
0005432783777	15378	35	8E
0005435243034	15378	36	8F
0005435243033	15378	37	9A
0005432783709	15378	38	9C
0005435243022	15378	39	9D
0005432783767	15378	40	9E
0005435243040	15378	41	9F
0005432783615	15378	42	10A
0005432783736	15378	43	10C
0005432783796	15378	44	10D
0005432783539	15378	45	10E
0005432783832	15378	46	10F
0005432783522	15378	47	11A
0005432783759	15378	48	11C
0005432783650	15378	49	11D
0005432783619	15378	50	11E
0005432783614	15378	51	11F
0005432783610	15378	52	12A
0005432783738	15378	53	12C
0005432783601	15378	54	12D
0005432783611	15378	55	12E
0005432783666	15378	56	12F
0005432783766	15378	57	13A
0005435243020	15378	58	13C
0005435476804	15378	59	13D
0005435243028	15378	60	13E
0005435243044	15378	61	13F
0005432783593	15378	62	14A
0005435476811	15378	63	14C
0005432783665	15378	64	14D
0005432783907	15378	65	14E
0005432783771	15378	66	14F
0005435243024	15378	67	15A
0005432783605	15378	68	15C
0005432783451	15378	69	15D
0005435243043	15378	70	15E
0005432783760	15378	71	15F
0005432783697	15378	72	16A
0005432783606	15378	73	16C
0005435243035	15378	74	16D
0005435243025	15378	75	16E
0005432783677	15378	76	16F
0005432783600	15378	77	17A
0005435243031	15378	78	17C
0005432783908	15378	79	17D
0005432783602	15378	80	17E
0005432783452	15378	81	17F
0005435243038	15378	82	18A
0005432783710	15378	83	18C
0005432783698	15378	84	18D
0005432783790	15378	85	18E
0005432783815	15378	86	18F
0005435476803	15378	87	19A
0005432783737	15378	88	19C
0005432783720	15378	89	19D
0005432783523	15378	90	19E
0005435243026	15378	91	20A
0005432783594	15378	92	19F
0005432783878	15378	93	20C
0005435243023	15378	94	20D
0005432783747	15378	95	20E
0005435243030	15378	96	20F
0005435850922	4378	1	1A
0005432848421	4378	2	1B
0005432848424	4378	3	1C
0005435850898	4378	4	1D
0005432848417	4378	5	2A
0005434462806	4378	6	2D
0005435850897	4378	7	3A
0005432848412	4378	8	3B
0005435850934	4378	9	3D
0005432848423	4378	10	4C
0005434463945	4378	11	4D
0005432848419	4378	12	5A
0005432848425	4378	13	5B
0005434462808	4378	14	5C
0005432848416	4378	15	6A
0005434462805	4378	16	6B
0005432848414	4378	17	6C
0005435850939	4378	18	7A
0005435850923	4378	19	7C
0005435850906	4378	20	18A
0005432848422	4378	21	18B
0005432848415	4378	22	18C
0005432848413	4378	23	19A
0005435850957	4378	24	19B
0005435850900	4378	25	20B
0005434463944	4378	26	20C
0005432848418	4378	27	21B
0005435850958	4378	28	21D
0005435850956	4378	29	22A
0005432848411	4378	30	22B
0005435850899	4378	31	22D
0005434462807	4378	32	23A
0005432848420	4378	33	23B
0005435850975	28867	1	1A
0005432848260	28867	2	1B
0005432848218	28867	3	1D
0005435850976	28867	4	2A
0005432848289	28867	5	2C
0005432848239	28867	6	3B
0005435850978	28867	7	3D
0005435850973	28867	8	4B
0005434461639	28867	9	4C
0005435850981	28867	10	5A
0005435850979	28867	11	5C
0005432848278	28867	12	5D
0005435850977	28867	13	6A
0005432848290	28867	14	6D
0005432848302	28867	15	7A
0005432848261	28867	16	7B
0005432848331	28867	17	18A
0005432848283	28867	18	18C
0005435850974	28867	19	20C
0005435850980	28867	20	20D
0005432848332	28867	21	21A
0005432848240	28867	22	21D
0005432848279	28867	23	22B
0005433497217	6327	1	2A
0005434443828	6327	2	2C
0005433497200	6327	3	2D
0005434443825	6327	4	2F
0005434926053	6327	5	3C
0005434443821	6327	6	3D
0005433497191	6327	7	3F
0005434443829	6327	8	4C
0005434926058	6327	9	4D
0005434926048	6327	10	4F
0005433497212	6327	11	5A
0005434926034	6327	12	5C
0005434443827	6327	13	5D
0005433497197	6327	14	5E
0005434443831	6327	15	5F
0005434443836	6327	16	6A
0005432075255	6327	17	6C
0005434926059	6327	18	6D
0005432075256	6327	19	6E
0005434926056	6327	20	6F
0005433497188	6327	21	7A
0005434926027	6327	22	7C
0005434443832	6327	23	7D
0005434926057	6327	24	7E
0005433497214	6327	25	7F
0005433497190	6327	26	8A
0005433497207	6327	27	8C
0005434926038	6327	28	8D
0005434926031	6327	29	8E
0005433497199	6327	30	8F
0005434926054	6327	31	9A
0005434926051	6327	32	9C
0005433497210	6327	33	9D
0005433497194	6327	34	9E
0005433497206	6327	35	9F
0005434926033	6327	36	10A
0005434926049	6327	37	10C
0005434443820	6327	38	10D
0005434443824	6327	39	10E
0005434926037	6327	40	10F
0005433497202	6327	41	11A
0005434443823	6327	42	11D
0005433497192	6327	43	11E
0005434926047	6327	44	11F
0005433497201	6327	45	12A
0005434926043	6327	46	12D
0005433497213	6327	47	12E
0005434443830	6327	48	12F
0005434443822	6327	49	13A
0005434443826	6327	50	13D
0005434443835	6327	51	13E
0005432075257	6327	52	13F
0005433497198	6327	53	14A
0005434926050	6327	54	14C
0005434926046	6327	55	14D
0005434926028	6327	56	14E
0005433497193	6327	57	14F
0005434926029	6327	58	15A
0005433497186	6327	59	15C
0005434926039	6327	60	15D
0005434926055	6327	61	15E
0005432075254	6327	62	15F
0005433497208	6327	63	16A
0005433497205	6327	64	16C
0005434926040	6327	65	16D
0005434926032	6327	66	16E
0005433497195	6327	67	16F
0005434926052	6327	68	17A
0005434926041	6327	69	17C
0005434926042	6327	70	17D
0005434926036	6327	71	17E
0005433497196	6327	72	17F
0005434926044	6327	73	18A
0005434443834	6327	74	18C
0005434926026	6327	75	18D
0005434926035	6327	76	18E
0005434926030	6327	77	18F
0005433497215	6327	78	19A
0005433497211	6327	79	19C
0005434926045	6327	80	19D
0005433497187	6327	81	19E
0005433497216	6327	82	19F
0005434443833	6327	83	20A
0005433497203	6327	84	20C
0005433497204	6327	85	20D
0005433497209	6327	86	20E
0005433497189	6327	87	20F
0005434925748	20386	1	1A
0005433497039	20386	2	1C
0005434925658	20386	3	1D
0005433496939	20386	4	2A
0005434443702	20386	5	2D
0005434443687	20386	6	2F
0005433496980	20386	7	3A
0005433497059	20386	8	3C
0005434443648	20386	9	3D
0005434925749	20386	10	3F
0005434925687	20386	11	4A
0005433496903	20386	12	4C
0005434443666	20386	13	4D
0005434925699	20386	14	4E
0005433497014	20386	15	4F
0005434925657	20386	16	5A
0005433496920	20386	17	5C
0005434925736	20386	18	5D
0005433496868	20386	19	5E
0005434925613	20386	20	6A
0005434925681	20386	21	6C
0005433497036	20386	22	6D
0005434443659	20386	23	6E
0005433496866	20386	24	6F
0005433497052	20386	25	7A
0005434925720	20386	26	7C
0005434925722	20386	27	7E
0005434925767	20386	28	7F
0005434925659	20386	29	8A
0005434925737	20386	30	8C
0005434925739	20386	31	8D
0005434925775	20386	32	8E
0005434925646	20386	33	8F
0005433496983	20386	34	9A
0005433496970	20386	35	9C
0005433496844	20386	36	9D
0005434443657	20386	37	9E
0005433497005	20386	38	9F
0005434443607	20386	39	10A
0005433496864	20386	40	10C
0005433497015	20386	41	10D
0005434925686	20386	42	10E
0005433497006	20386	43	10F
0005433496819	20386	44	11A
0005433497022	20386	45	11C
0005434443649	20386	46	11D
0005433496995	20386	47	11E
0005433496795	20386	48	11F
0005434925647	20386	49	12A
0005434925774	20386	50	12C
0005433496877	20386	51	12D
0005433497047	20386	52	12E
0005433496867	20386	53	12F
0005433496904	20386	54	13A
0005434925675	20386	55	13C
0005434925710	20386	56	13D
0005434443669	20386	57	13E
0005433496895	20386	58	13F
0005434925608	20386	59	14A
0005434925605	20386	60	14C
0005433496847	20386	61	14D
0005434925680	20386	62	14E
0005433497023	20386	63	14F
0005433496817	20386	64	15A
0005433496894	20386	65	15C
0005433496852	20386	66	15D
0005433496892	20386	67	15E
0005433497016	20386	68	15F
0005433497035	20386	69	16A
0005434925773	20386	70	16C
0005433497070	20386	71	16E
0005433497098	20386	72	16F
0005433497000	20386	73	17A
0005433496859	20386	74	17C
0005434925703	20386	75	17D
0005433496901	20386	76	17E
0005433496902	20386	77	17F
0005433496891	20386	78	18A
0005433496984	20386	79	18C
0005434443750	20386	80	18D
0005433496845	20386	81	18E
0005434443665	20386	82	18F
0005433497007	20386	83	19A
0005433497048	20386	84	19C
0005434925723	20386	85	19D
0005433496876	20386	86	19E
0005434925679	20386	87	20A
0005434443658	20386	88	20C
0005434925772	20386	89	20D
0005433497051	20386	90	20E
0005434925719	20386	91	20F
0005432783659	12181	1	1A
0005432783587	12181	2	1D
0005432783691	12181	3	1F
0005432783429	12181	4	2A
0005432783707	12181	5	2C
0005432783877	12181	6	2D
0005432783851	12181	7	2F
0005432783662	12181	8	3A
0005432783746	12181	9	3D
0005432783447	12181	10	3F
0005432783378	12181	11	4A
0005432783588	12181	12	4C
0005432783858	12181	13	4D
0005435243066	12181	14	4E
0005432783664	12181	15	4F
0005432783761	12181	16	5C
0005435243067	12181	17	5D
0005432783842	12181	18	5E
0005435243060	12181	19	5F
0005435243050	12181	20	6A
0005435243068	12181	21	6C
0005435243046	12181	22	6D
0005432783998	12181	23	6E
0005432783835	12181	24	6F
0005432783859	12181	25	7A
0005435243064	12181	26	7C
0005435243049	12181	27	7D
0005432783430	12181	28	8A
0005435243047	12181	29	8C
0005432783654	12181	30	8D
0005435243063	12181	31	8E
0005432783644	12181	32	8F
0005432783756	12181	33	9A
0005432783867	12181	34	9C
0005435243048	12181	35	9E
0005435243065	12181	36	9F
0005432783775	12181	37	10A
0005435243069	12181	38	10C
0005432783620	12181	39	10D
0005435243061	12181	40	10F
0005435243070	12181	41	11C
0005432783708	12181	42	11D
0005432783661	12181	43	11E
0005432783616	12181	44	11F
0005435243073	12181	45	12A
0005435243052	12181	46	12C
0005432783764	12181	47	12D
0005435243053	12181	48	12E
0005432783781	12181	49	12F
0005435243059	12181	50	13A
0005432783868	12181	51	13C
0005432783801	12181	52	13E
0005435243051	12181	53	13F
0005432783721	12181	54	14A
0005432783514	12181	55	14C
0005435243072	12181	56	14D
0005435243056	12181	57	14E
0005435243062	12181	58	14F
0005432783549	12181	59	15A
0005432783774	12181	60	15C
0005432783542	12181	61	15F
0005432783957	12181	62	16C
0005432783501	12181	63	16D
0005435243071	12181	64	16E
0005432783663	12181	65	17A
0005432783997	12181	66	17D
0005435243054	12181	67	17C
0005435243057	12181	68	17E
0005432783852	12181	69	17F
0005432783724	12181	70	18A
0005432783680	12181	71	18C
0005432783857	12181	72	18D
0005432783653	12181	73	18F
0005432783755	12181	74	19A
0005432783617	12181	75	19C
0005432783847	12181	76	19D
0005435243055	12181	77	19E
0005435243058	12181	78	19F
0005432783861	12181	79	20A
0005432783645	12181	80	20C
0005432783723	12181	81	20D
0005432783826	12181	82	20E
0005432783827	12181	83	20F
0005435242556	15433	1	1C
0005432784141	15433	2	1F
0005432784113	15433	3	2A
0005432784127	15433	4	2C
0005432784138	15433	5	2D
0005435242783	15433	6	2F
0005432784148	15433	7	3A
0005432784123	15433	8	3C
0005432784133	15433	9	3D
0005432784111	15433	10	3F
0005432784124	15433	11	4A
0005435242652	15433	12	4C
0005435242777	15433	13	4D
0005432784106	15433	14	4E
0005432784119	15433	15	4F
0005432784118	15433	16	5A
0005435242817	15433	17	5D
0005432784122	15433	18	5E
0005432784107	15433	19	5F
0005432784139	15433	20	6A
0005435242741	15433	21	6C
0005432784143	15433	22	6D
0005432784131	15433	23	6E
0005435242693	15433	24	6F
0005432784121	15433	25	7A
0005435242796	15433	26	7C
0005432784130	15433	27	7D
0005435242795	15433	28	7E
0005432784158	15433	29	8A
0005432784153	15433	30	8C
0005432784152	15433	31	8D
0005432784146	15433	32	8E
0005432784126	15433	33	8F
0005435242707	15433	34	9A
0005432784112	15433	35	9C
0005432784150	15433	36	9D
0005435242725	15433	37	9E
0005432784145	15433	38	9F
0005435242776	15433	39	10A
0005435242813	15433	40	10C
0005432784116	15433	41	10E
0005432784129	15433	42	10F
0005432784142	15433	43	11A
0005432784120	15433	44	11C
0005435242848	15433	45	11F
0005432784151	15433	46	12A
0005435242729	15433	47	12C
0005432784128	15433	48	12D
0005432784140	15433	49	12E
0005432784149	15433	50	12F
0005435242876	15433	51	13C
0005432784115	15433	52	13D
0005432784157	15433	53	13E
0005432784109	15433	54	13F
0005435242841	15433	55	14A
0005435242731	15433	56	14C
0005432784114	15433	57	14E
0005432784135	15433	58	15A
0005432784137	15433	59	15C
0005435242730	15433	60	15D
0005435242705	15433	61	16C
0005432784156	15433	62	16D
0005432784154	15433	63	16E
0005432784110	15433	64	16F
0005432784108	15433	65	17A
0005432784117	15433	66	17D
0005432784136	15433	67	17F
0005432784147	15433	68	18A
0005432784134	15433	69	18E
0005435242642	15433	70	18F
0005432784125	15433	71	19A
0005432784155	15433	72	19C
0005435242814	15433	73	19D
0005435242726	15433	74	19E
0005432784144	15433	75	19F
0005432784132	15433	76	20A
0005435242692	15433	77	20D
0005432784159	15433	78	20E
0005435242784	15433	79	20F
0005434878408	10096	1	1C
0005434877632	10096	2	1A
0005434878496	10096	3	1F
0005434878162	10096	4	1D
0005434877976	10096	5	2A
0005434878414	10096	6	2D
0005434878636	10096	7	2C
0005434878149	10096	8	3A
0005434877987	10096	9	2F
0005434877972	10096	10	3D
0005434877842	10096	11	3C
0005434877919	10096	12	4A
0005434878567	10096	13	3F
0005434878264	10096	14	4C
0005434878357	10096	15	4F
0005434877869	10096	16	4D
0005434877884	10096	17	5C
0005434877579	10096	18	5A
0005434878011	10096	19	5F
0005434877942	10096	20	5D
0005434878568	10096	21	6A
0005434878282	10096	22	6C
0005434877708	10096	23	6B
0005434878150	10096	24	6F
0005434878163	10096	25	6E
0005434877991	10096	26	6D
0005434878274	10096	27	7A
0005434878635	10096	28	7C
0005434877841	10096	29	7B
0005434878223	10096	30	7E
0005434878089	10096	31	7D
0005434878420	10096	32	8A
0005434758893	10096	33	7F
0005434878214	10096	34	8B
0005434877992	10096	35	8D
0005434877977	10096	36	8C
0005434878358	10096	37	8F
0005434878390	10096	38	8E
0005434878114	10096	39	9B
0005434878071	10096	40	9A
0005434878398	10096	41	9D
0005434878135	10096	42	9C
0005434910129	10096	43	9E
0005434878399	10096	44	10A
0005434878043	10096	45	9F
0005434878277	10096	46	10C
0005434910131	10096	47	10B
0005434878418	10096	48	10E
0005434878365	10096	49	10D
0005434878222	10096	50	11A
0005434758892	10096	51	10F
0005434878290	10096	52	11C
0005434878315	10096	53	11B
0005434877469	10096	54	11D
0005434878180	10096	55	11F
0005434877871	10096	56	11E
0005434877971	10096	57	12B
0005434877941	10096	58	12D
0005434878176	10096	59	12C
0005434878103	10096	60	12F
0005434878413	10096	61	13B
0005434878254	10096	62	13A
0005434878148	10096	63	13C
0005434878177	10096	64	13E
0005434877915	10096	65	13D
0005434877578	10096	66	14A
0005434878219	10096	67	13F
0005434878058	10096	68	14B
0005434878276	10096	69	14D
0005434877429	10096	70	14C
0005434878407	10096	71	14F
0005434877786	10096	72	14E
0005434878421	10096	73	15B
0005434877902	10096	74	15A
0005434878321	10096	75	15D
0005434878122	10096	76	15C
0005434878370	10096	77	15E
0005434877979	10096	78	16B
0005434878717	10096	79	16A
0005434877957	10096	80	15F
0005434878067	10096	81	16C
0005434878179	10096	82	16E
0005434910130	10096	83	16D
0005434877920	10096	84	17A
0005434878108	10096	85	16F
0005434878267	10096	86	17B
0005434877669	10096	87	17D
0005434877950	10096	88	17C
0005434877852	10096	89	17F
0005434878456	10096	90	17E
0005434878102	10096	91	18A
0005434877819	10096	92	18D
0005434878210	10096	93	18C
0005434878209	10096	94	18B
0005434877978	10096	95	18E
0005434878314	10096	96	19A
0005434878015	10096	97	18F
0005434758883	10096	98	19B
0005434878211	10096	99	19D
0005434878144	10096	100	19C
0005434758885	10096	101	19F
0005434877951	10096	102	19E
0005434878007	10096	103	20B
0005434877707	10096	104	20A
0005434878115	10096	105	20D
0005434878363	10096	106	20C
0005434877868	10096	107	20F
0005434758879	10096	108	20E
0005434878109	10096	109	21B
0005434877787	10096	110	21A
0005434877668	10096	111	21C
0005434878275	10096	112	21E
0005434878391	10096	113	21D
0005434878913	14649	1	1C
0005434878929	14649	2	1A
0005434878924	14649	3	1F
0005434878920	14649	4	1D
0005434878863	14649	5	2C
0005434878895	14649	6	2A
0005434878907	14649	7	2F
0005434878898	14649	8	2D
0005434758910	14649	9	3C
0005435913927	14649	10	4A
0005434878947	14649	11	3F
0005434878891	14649	12	3D
0005434910108	14649	13	4C
0005434878953	14649	14	4F
0005434878936	14649	15	4D
0005434878874	14649	16	5C
0005434878923	14649	17	5A
0005434878922	14649	18	5D
0005434878942	14649	19	6B
0005434878890	14649	20	6A
0005434878948	14649	21	6D
0005434878919	14649	22	6C
0005434878875	14649	23	6E
0005434878914	14649	24	7B
0005434878918	14649	25	7E
0005434878926	14649	26	7D
0005434878881	14649	27	7F
0005434878928	14649	28	8C
0005434878899	14649	29	8B
0005434878866	14649	30	8A
0005434878939	14649	31	8D
0005434878903	14649	32	8F
0005434878909	14649	33	8E
0005434878872	14649	34	9B
0005434878908	14649	35	9A
0005434878905	14649	36	9D
0005435913926	14649	37	9C
0005434878925	14649	38	9E
0005434878954	14649	39	10A
0005434878889	14649	40	9F
0005434878901	14649	41	10C
0005434878950	14649	42	10B
0005434878951	14649	43	10E
0005434878878	14649	44	10D
0005434878915	14649	45	10F
0005434878880	14649	46	11C
0005434910116	14649	47	11A
0005434878900	14649	48	11D
0005434878940	14649	49	11F
0005434878864	14649	50	11E
0005434878910	14649	51	12B
0005434878897	14649	52	12A
0005434878931	14649	53	12C
0005434878938	14649	54	12E
0005434758911	14649	55	12D
0005434878917	14649	56	13A
0005434878952	14649	57	12F
0005434878870	14649	58	13B
0005434878937	14649	59	13E
0005434878930	14649	60	13D
0005434878879	14649	61	13F
0005434878882	14649	62	14C
0005434878943	14649	63	14B
0005434878949	14649	64	14A
0005434878941	14649	65	14D
0005434878927	14649	66	14F
0005434878955	14649	67	15B
0005434878957	14649	68	15A
0005434878904	14649	69	15D
0005434878935	14649	70	15C
0005434878887	14649	71	15F
0005434878883	14649	72	15E
0005434878916	14649	73	16A
0005434878888	14649	74	16C
0005434878934	14649	75	16B
0005434878932	14649	76	16D
0005434878946	14649	77	16F
0005434878867	14649	78	16E
0005434878921	14649	79	17B
0005434878893	14649	80	17A
0005434878945	14649	81	17D
0005434878884	14649	82	17E
0005434878894	14649	83	18A
0005434878906	14649	84	17F
0005434878933	14649	85	18C
0005434878862	14649	86	18E
0005434878885	14649	87	18D
0005434878871	14649	88	19A
0005434878892	14649	89	18F
0005434878865	14649	90	19B
0005434878896	14649	91	19E
0005434878912	14649	92	19D
0005434878886	14649	93	19C
0005434878956	14649	94	19F
0005434878877	14649	95	20B
0005434878876	14649	96	20A
0005434878902	14649	97	20D
0005434878868	14649	98	20C
0005435913925	14649	99	20F
0005434878869	14649	100	21B
0005434878944	14649	101	21A
0005434878911	14649	102	21D
0005434758909	14649	103	21C
0005434878873	14649	104	21E
0005435660214	9235	1	1A
0005435660219	9235	2	1D
0005434251924	9235	3	2B
0005434251972	9235	4	2C
0005435660220	9235	5	3A
0005435660216	9235	6	3B
0005434251943	9235	7	3C
0005435660223	9235	8	4C
0005435660224	9235	9	5C
0005435660221	9235	10	6A
0005434251920	9235	11	6B
0005435660215	9235	12	6C
0005434251923	9235	13	7A
0005434251973	9235	14	7B
0005435660213	9235	15	7C
0005434251864	9235	16	7D
0005435660222	9235	17	18A
0005435660218	9235	18	18B
0005434251976	9235	19	18C
0005434251962	9235	20	19B
0005434251944	9235	21	19C
0005434251863	9235	22	19D
0005434251947	9235	23	20A
0005434251942	9235	24	20C
0005434251982	9235	25	21A
0005435660217	9235	26	21B
0005435660104	24653	1	1B
0005435660163	24653	2	2A
0005434252031	24653	3	3D
0005435660135	24653	4	4A
0005435660164	24653	5	4D
0005435660109	24653	6	5A
0005435660134	24653	7	6A
0005435660077	24653	8	7B
0005434252033	24653	9	7C
0005435660162	24653	10	7D
0005434252029	24653	11	18A
0005434252030	24653	12	18B
0005435660110	24653	13	18C
0005434252036	24653	14	18D
0005434252034	24653	15	20A
0005435660078	24653	16	19D
0005434252032	24653	17	20B
0005434252037	24653	18	20D
0005435660142	24653	19	21B
0005434252035	24653	20	21D
0005435660125	24653	21	23B
0005433680898	2765	1	1A
0005432966940	2765	2	1C
0005432966992	2765	3	1D
0005433680906	2765	4	1F
0005433680924	2765	5	2A
0005433680908	2765	6	2D
0005433680903	2765	7	2F
0005433680918	2765	8	3A
0005432966935	2765	9	3C
0005433680884	2765	10	3D
0005433684433	2765	11	4A
0005433680895	2765	12	4C
0005433680917	2765	13	4D
0005433680889	2765	14	4E
0005432222822	2765	15	4F
0005433680896	2765	16	5C
0005432967002	2765	17	5D
0005433680923	2765	18	5E
0005432966753	2765	19	5F
0005432966781	2765	20	6A
0005433680904	2765	21	6C
0005432966901	2765	22	6D
0005432966929	2765	23	6E
0005432966944	2765	24	6F
0005433680929	2765	25	7A
0005432966860	2765	26	7E
0005433680931	2765	27	7F
0005432222820	2765	28	8A
0005433684434	2765	29	8C
0005433680888	2765	30	8D
0005432966927	2765	31	8F
0005433680899	2765	32	9A
0005433680915	2765	33	9C
0005433680913	2765	34	9E
0005433680911	2765	35	9F
0005432966896	2765	36	10A
0005433680925	2765	37	10C
0005432966775	2765	38	10D
0005433680897	2765	39	10E
0005432222821	2765	40	11C
0005433680909	2765	41	11D
0005432222819	2765	42	11E
0005432966852	2765	43	11F
0005433680910	2765	44	12A
0005433680893	2765	45	12C
0005433680891	2765	46	12D
0005433680887	2765	47	12E
0005433680926	2765	48	12F
0005433680892	2765	49	13C
0005433680900	2765	50	13D
0005433680930	2765	51	14A
0005432966764	2765	52	14C
0005433680882	2765	53	14D
0005432967003	2765	54	14E
0005433680916	2765	55	14F
0005433680890	2765	56	15A
0005432966928	2765	57	15D
0005433680920	2765	58	15E
0005432222817	2765	59	15F
0005433680907	2765	60	16C
0005433680883	2765	61	16D
0005433680902	2765	62	16E
0005433680912	2765	63	17A
0005433680921	2765	64	17C
0005433680932	2765	65	17D
0005433680922	2765	66	17E
0005433680928	2765	67	17F
0005432967015	2765	68	18C
0005433680919	2765	69	18D
0005433680886	2765	70	18E
0005433680905	2765	71	18F
0005432966859	2765	72	19A
0005433680914	2765	73	19C
0005433680901	2765	74	19D
0005433680894	2765	75	19F
0005432222818	2765	76	20A
0005433680885	2765	77	20C
0005432966861	2765	78	20D
0005433680927	2765	79	20E
0005433680359	29148	1	1A
0005433680677	29148	2	1C
0005433680676	29148	3	1D
0005433680400	29148	4	1F
0005433680511	29148	5	2A
0005433680465	29148	6	2C
0005432005234	29148	7	2D
0005433680468	29148	8	2F
0005432967121	29148	9	3A
0005433680566	29148	10	3C
0005433680462	29148	11	3D
0005433680534	29148	12	4A
0005433680656	29148	13	4C
0005433680407	29148	14	4D
0005432967116	29148	15	4E
0005433680315	29148	16	5A
0005433680535	29148	17	5C
0005433680598	29148	18	5D
0005433680507	29148	19	5E
0005432005233	29148	20	5F
0005433680569	29148	21	6A
0005433680657	29148	22	6C
0005433680565	29148	23	6D
0005432967115	29148	24	6E
0005433680585	29148	25	6F
0005433680525	29148	26	7A
0005432967114	29148	27	7C
0005432967113	29148	28	7D
0005432967130	29148	29	7E
0005433680608	29148	30	7F
0005433680361	29148	31	8A
0005432967108	29148	32	8C
0005433680488	29148	33	8D
0005432967118	29148	34	8E
0005433680621	29148	35	8F
0005433680403	29148	36	9A
0005433680551	29148	37	9C
0005433680771	29148	38	9D
0005433680711	29148	39	9E
0005433680467	29148	40	9F
0005433680696	29148	41	10A
0005433680695	29148	42	10C
0005433680518	29148	43	10D
0005432967124	29148	44	10F
0005433680575	29148	45	11A
0005433680574	29148	46	11C
0005432967107	29148	47	11E
0005433680521	29148	48	11F
0005432967117	29148	49	12A
0005432967119	29148	50	12C
0005432967128	29148	51	12D
0005433680316	29148	52	12E
0005432967112	29148	53	12F
0005433680549	29148	54	13A
0005433680570	29148	55	13C
0005432967127	29148	56	13D
0005432967122	29148	57	13E
0005433680770	29148	58	13F
0005433680550	29148	59	14A
0005433680589	29148	60	14C
0005432967111	29148	61	14E
0005433680620	29148	62	14F
0005433680675	29148	63	15A
0005433680401	29148	64	15C
0005432967132	29148	65	15D
0005432967131	29148	66	15E
0005433680443	29148	67	16A
0005433680732	29148	68	16C
0005433680708	29148	69	16D
0005433680453	29148	70	16E
0005433687697	29148	71	16F
0005432967129	29148	72	17A
0005433680613	29148	73	17C
0005432967110	29148	74	17D
0005433680625	29148	75	17E
0005433680783	29148	76	18A
0005433680452	29148	77	17F
0005433680707	29148	78	18C
0005433680586	29148	79	18D
0005433680489	29148	80	18E
0005432967123	29148	81	18F
0005433680712	29148	82	19A
0005433680297	29148	83	19C
0005433680622	29148	84	19D
0005433680548	29148	85	19E
0005432005232	29148	86	19F
0005433680599	29148	87	20A
0005432967125	29148	88	20C
0005432967109	29148	89	20D
0005432967126	29148	90	20E
0005432967120	29148	91	20F
0005433615120	9329	1	1A
0005433615170	9329	2	2A
0005433634030	9329	3	2F
0005433615138	9329	4	3A
0005433615125	9329	5	3C
0005433577899	9329	6	3F
0005433577896	9329	7	3D
0005434269097	9329	8	4A
0005434163571	9329	9	4C
0005433634033	9329	10	4F
0005433615109	9329	11	4D
0005433615124	9329	12	5A
0005433634050	9329	13	5C
0005433615175	9329	14	5F
0005433615121	9329	15	5D
0005432755097	9329	16	6A
0005433615172	9329	17	6C
0005433634034	9329	18	6D
0005433634038	9329	19	7A
0005433615166	9329	20	6F
0005433615113	9329	21	7C
0005433615133	9329	22	7F
0005434152781	9329	23	8A
0005434163551	9329	24	8D
0005433577906	9329	25	8C
0005433634026	9329	26	8E
0005433634049	9329	27	8F
0005433615157	9329	28	9B
0005433634041	9329	29	9A
0005434163608	9329	30	9C
0005433577900	9329	31	9E
0005434272188	9329	32	9D
0005433615127	9329	33	9F
0005433615126	9329	34	10B
0005433615180	9329	35	10D
0005433615128	9329	36	10F
0005433577907	9329	37	11A
0005433634028	9329	38	11C
0005433615130	9329	39	11B
0005433615134	9329	40	11D
0005434272192	9329	41	11E
0005433615110	9329	42	12A
0005433615151	9329	43	12B
0005433634039	9329	44	12D
0005433615119	9329	45	12C
0005433615173	9329	46	12E
0005433577898	9329	47	12F
0005434269088	9329	48	13B
0005433577905	9329	49	13A
0005433634029	9329	50	13C
0005433615163	9329	51	13D
0005433615115	9329	52	13E
0005433615162	9329	53	13F
0005433615108	9329	54	14B
0005433615156	9329	55	14C
0005433634018	9329	56	14E
0005433634045	9329	57	14D
0005433615136	9329	58	14F
0005433634046	9329	59	15B
0005433634031	9329	60	15C
0005433615176	9329	61	15E
0005434163601	9329	62	15D
0005433634036	9329	63	16A
0005433615178	9329	64	16B
0005433634017	9329	65	16D
0005433615149	9329	66	16C
0005434163580	9329	67	16E
0005433615155	9329	68	16F
0005433615150	9329	69	17A
0005433634043	9329	70	17C
0005433615174	9329	71	17B
0005433615167	9329	72	17D
0005433615154	9329	73	17F
0005433634025	9329	74	17E
0005433615148	9329	75	18A
0005433634022	9329	76	18C
0005434153530	9329	77	18B
0005433577903	9329	78	18D
0005433615171	9329	79	18E
0005433615177	9329	80	18F
0005433615144	9329	81	19B
0005433615123	9329	82	19D
0005433634024	9329	83	19E
0005433615141	9329	84	20B
0005433615182	9329	85	20A
0005433615117	9329	86	20D
0005432756871	9329	87	20C
0005433615114	9329	88	20E
0005434269099	9329	89	20F
0005433634019	9329	90	21B
0005433634040	9329	91	21A
0005433634037	9329	92	21C
0005433615153	9329	93	21D
0005433615122	9329	94	21E
0005433577904	9329	95	22B
0005433615112	9329	96	22A
0005433634044	9329	97	22C
0005432755098	9329	98	22D
0005433634027	9329	99	22F
0005433615160	9329	100	22E
0005433615143	9329	101	23A
0005433634047	9329	102	23B
0005433615158	9329	103	23D
0005434153535	9329	104	23C
0005433634035	9329	105	23E
0005433615145	9329	106	24A
0005433615165	9329	107	23F
0005433615137	9329	108	24B
0005433615140	9329	109	24C
0005433634021	9329	110	24E
0005433615135	9329	111	24D
0005433577908	9329	112	24F
0005433615111	9329	113	25B
0005433615131	9329	114	25A
0005432756872	9329	115	25E
0005433634020	9329	116	25D
0005434269098	9329	117	26A
0005433615168	9329	118	26B
0005434272187	9329	119	26C
0005433615129	9329	120	26D
0005433615159	9329	121	27A
0005433615147	9329	122	27C
0005433615146	9329	123	27B
0005433615179	9329	124	27D
0005432755099	9329	125	27F
0005433615164	9329	126	28C
0005433615139	9329	127	28B
0005433577901	9329	128	28A
0005432756870	9329	129	28E
0005433634016	9329	130	28D
0005433615181	9329	131	29A
0005433615161	9329	132	28F
0005433634048	9329	133	29B
0005432756869	9329	134	29D
0005433577897	9329	135	29F
0005433577909	9329	136	29E
0005433615169	9329	137	30B
0005433634042	9329	138	30A
0005433634032	9329	139	30C
0005433615116	9329	140	30E
0005432145124	9329	141	30D
0005433615118	9329	142	30F
0005433615132	9329	143	31A
0005432145123	9329	144	31C
0005433577902	9329	145	31B
0005433634023	9329	146	31E
0005433615142	9329	147	31D
0005433615152	9329	148	31F
0005432755072	25261	1	1A
0005433614334	25261	2	1C
0005433614408	25261	3	1D
0005433614371	25261	4	2A
0005433614151	25261	5	1F
0005433614047	25261	6	2C
0005433614753	25261	7	2D
0005433577827	25261	8	3A
0005432755070	25261	9	2F
0005433614604	25261	10	3C
0005433614481	25261	11	3F
0005433614409	25261	12	3D
0005433614826	25261	13	4A
0005432751505	25261	14	4D
0005433614377	25261	15	4C
0005433614719	25261	16	4F
0005433614482	25261	17	5A
0005433633763	25261	18	5C
0005434163681	25261	19	5F
0005432755069	25261	20	5D
0005433614705	25261	21	6A
0005433614290	25261	22	6F
0005433614692	25261	23	6D
0005434163674	25261	24	7A
0005433614575	25261	25	7C
0005433614581	25261	26	7F
0005434152794	25261	27	7D
0005433614164	25261	28	8A
0005434163677	25261	29	8B
0005432751509	25261	30	8D
0005433633727	25261	31	8C
0005433614430	25261	32	8E
0005433614156	25261	33	8F
0005433633846	25261	34	9B
0005433633552	25261	35	9A
0005433614157	25261	36	9C
0005433614507	25261	37	9E
0005433633667	25261	38	9D
0005433614722	25261	39	9F
0005434272202	25261	40	10A
0005433614206	25261	41	10B
0005434152797	25261	42	10D
0005433614329	25261	43	10E
0005434163678	25261	44	10F
0005434152802	25261	45	11B
0005433633857	25261	46	11A
0005433614505	25261	47	11C
0005433614568	25261	48	11D
0005434163676	25261	49	11E
0005433614438	25261	50	12A
0005434152800	25261	51	11F
0005433614448	25261	52	12B
0005434152799	25261	53	12D
0005433633643	25261	54	12C
0005433633762	25261	55	12E
0005433614192	25261	56	12F
0005434152796	25261	57	13B
0005433577793	25261	58	13C
0005434152793	25261	59	13D
0005433614931	25261	60	13F
0005432751526	25261	61	14A
0005433614230	25261	62	14C
0005433633645	25261	63	14E
0005433633640	25261	64	14F
0005433633688	25261	65	15B
0005432751510	25261	66	15A
0005434152798	25261	67	15C
0005432755043	25261	68	15E
0005433614754	25261	69	15D
0005432755052	25261	70	16A
0005434163672	25261	71	15F
0005433614365	25261	72	16B
0005433614547	25261	73	16C
0005433614602	25261	74	16E
0005432751532	25261	75	16D
0005432751504	25261	76	16F
0005433633719	25261	77	17B
0005433614500	25261	78	17A
0005433614300	25261	79	17C
0005432751503	25261	80	17D
0005433614364	25261	81	17F
0005432755065	25261	82	17E
0005433614665	25261	83	18A
0005433614213	25261	84	18B
0005433614313	25261	85	18C
0005433614510	25261	86	18E
0005433614643	25261	87	18F
0005433633725	25261	88	19B
0005433633553	25261	89	19D
0005433633796	25261	90	19C
0005433633847	25261	91	19E
0005433614512	25261	92	20B
0005433614551	25261	93	20A
0005432755064	25261	94	20C
0005433633798	25261	95	20D
0005433614437	25261	96	20F
0005433633687	25261	97	20E
0005433614601	25261	98	21A
0005433614229	25261	99	21C
0005432751517	25261	100	21B
0005433614376	25261	101	21E
0005433633720	25261	102	21D
0005434163675	25261	103	22A
0005433614544	25261	104	21F
0005432751506	25261	105	22B
0005432755044	25261	106	22E
0005434163671	25261	107	22D
0005434273087	25261	108	22F
0005433633642	25261	109	23A
0005434152801	25261	110	23C
0005433633797	25261	111	23B
0005433614447	25261	112	23D
0005433614693	25261	113	23E
0005434152795	25261	114	24A
0005434163680	25261	115	23F
0005433633732	25261	116	24B
0005433614667	25261	117	24C
0005432755061	25261	118	24D
0005433614351	25261	119	24F
0005433614449	25261	120	24E
0005433633899	25261	121	25B
0005433633614	25261	122	25A
0005433633854	25261	123	25C
0005433614543	25261	124	25D
0005433633731	25261	125	25F
0005433633745	25261	126	25E
0005433614666	25261	127	26A
0005433577826	25261	128	26B
0005433633764	25261	129	26D
0005433614405	25261	130	26C
0005433614508	25261	131	26E
0005432751511	25261	132	26F
0005434163670	25261	133	27A
0005433633754	25261	134	27C
0005432755050	25261	135	27B
0005432755055	25261	136	27D
0005433614537	25261	137	27F
0005433614422	25261	138	27E
0005433633848	25261	139	28A
0005433614694	25261	140	28C
0005433614048	25261	141	28B
0005434163673	25261	142	28E
0005432755053	25261	143	28D
0005433577743	25261	144	28F
0005432751520	25261	145	29B
0005433633685	25261	146	29A
0005434163679	25261	147	29C
0005434272201	25261	148	30A
0005433614686	25261	149	29F
0005432755049	25261	150	30B
0005433633709	25261	151	30D
0005433614776	25261	152	30E
0005433633644	25261	153	30F
0005433633686	25261	154	31A
0005433614723	25261	155	31C
0005434273086	25261	156	31B
0005434272203	25261	157	31D
0005433633898	25261	158	31E
0005433614548	25261	159	31F
0005435947194	4230	1	1A
0005432571309	4230	2	2F
0005435947251	4230	3	3A
0005435854059	4230	4	2H
0005435947198	4230	5	3B
0005432184973	4230	6	9H
0005435986803	4230	7	12B
0005432571315	4230	8	13B
0005435856198	4230	9	15G
0005432184972	4230	10	16E
0005432184975	4230	11	18B
0005435947308	4230	12	18D
0005435856187	4230	13	19H
0005432571329	4230	14	22A
0005432571322	4230	15	23D
0005435986804	4230	16	23G
0005432571323	4230	17	24D
0005435947199	4230	18	24F
0005435856181	4230	19	24G
0005435986802	4230	20	25F
0005435947239	4230	21	25E
0005432184971	4230	22	27D
0005435787350	4230	23	28E
0005432571330	4230	24	29G
0005432571312	4230	25	30B
0005435947235	4230	26	31A
0005432184970	4230	27	31F
0005435986801	4230	28	34B
0005435787343	4230	29	33H
0005432571324	4230	30	35D
0005435986805	4230	31	35G
0005432184974	4230	32	35H
0005432571314	4230	33	36D
0005435947262	4230	34	36H
0005432571313	4230	35	38F
0005435947367	26581	1	2A
0005435947362	26581	2	3H
0005435947364	26581	3	5A
0005432571353	26581	4	11E
0005435856236	26581	5	12F
0005435947355	26581	6	12G
0005435947368	26581	7	14B
0005435986731	26581	8	14D
0005435947366	26581	9	15F
0005435947361	26581	10	17G
0005435947356	26581	11	18E
0005435986725	26581	12	19D
0005435856234	26581	13	20F
0005435947357	26581	14	21E
0005435947360	26581	15	23D
0005435947359	26581	16	27A
0005435947358	26581	17	27E
0005432571351	26581	18	28H
0005435986732	26581	19	29B
0005435947354	26581	20	31D
0005435856235	26581	21	31G
0005435947365	26581	22	32B
0005432571352	26581	23	35E
0005435947363	26581	24	36F
0005435787371	26581	25	37G
0005435856233	26581	26	38G
0005435986730	26581	27	39F
0005433074743	357	1	1A
0005433569496	357	2	1C
0005432948587	357	3	1F
0005433134124	357	4	1D
0005433074671	357	5	2A
0005433074678	357	6	2C
0005432948493	357	7	2D
0005433569525	357	8	2F
0005433569489	357	9	3C
0005432948407	357	10	3F
0005433569494	357	11	3D
0005433569531	357	12	4C
0005432948336	357	13	4D
0005433569503	357	14	5A
0005433569505	357	15	4F
0005433074605	357	16	5D
0005432238981	357	17	5C
0005432948468	357	18	6A
0005432948467	357	19	5F
0005432948391	357	20	6D
0005433569482	357	21	7A
0005432948513	357	22	7C
0005433074833	357	23	7F
0005433074682	357	24	7D
0005432948471	357	25	8A
0005433569477	357	26	8B
0005433569484	357	27	8D
0005433074720	357	28	8C
0005433569514	357	29	8E
0005432948711	357	30	8F
0005433569501	357	31	9A
0005433569491	357	32	9C
0005432948286	357	33	9E
0005433569498	357	34	9D
0005432948373	357	35	10A
0005433569509	357	36	9F
0005433074616	357	37	10B
0005433569517	357	38	10D
0005433569479	357	39	10C
0005433569518	357	40	10E
0005433074633	357	41	11A
0005433569493	357	42	10F
0005433569508	357	43	11B
0005432948420	357	44	11E
0005432948425	357	45	11D
0005433569510	357	46	11C
0005433129256	357	47	11F
0005433074628	357	48	12A
0005433134147	357	49	12C
0005433569515	357	50	12B
0005433569483	357	51	12D
0005433569535	357	52	12F
0005433074611	357	53	13C
0005432948511	357	54	13D
0005433569490	357	55	13E
0005433074607	357	56	13F
0005433569522	357	57	14B
0005433569516	357	58	14A
0005432948523	357	59	14D
0005433569527	357	60	14C
0005433569511	357	61	14E
0005433929858	357	62	14F
0005432948378	357	63	15B
0005433569520	357	64	15A
0005433569475	357	65	15C
0005433074666	357	66	15D
0005433569504	357	67	15E
0005433569532	357	68	16A
0005432948389	357	69	16B
0005433074619	357	70	16D
0005433569523	357	71	16C
0005433569521	357	72	16E
0005433569480	357	73	16F
0005433569486	357	74	17B
0005433569499	357	75	17A
0005433074741	357	76	17C
0005433569495	357	77	17E
0005433074677	357	78	17D
0005433569488	357	79	17F
0005433074641	357	80	18A
0005433129280	357	81	18C
0005433129266	357	82	18E
0005433074731	357	83	18D
0005433074742	357	84	18F
0005432948422	357	85	19C
0005433569526	357	86	19B
0005433569533	357	87	19D
0005433074732	357	88	19E
0005432948437	357	89	20A
0005433074719	357	90	20C
0005433074630	357	91	20E
0005432948588	357	92	20D
0005433569500	357	93	20F
0005433134125	357	94	21B
0005433569487	357	95	21C
0005433569536	357	96	21D
0005432948423	357	97	21E
0005433569513	357	98	22A
0005433569512	357	99	22D
0005433074832	357	100	22C
0005433569529	357	101	22B
0005433569497	357	102	22E
0005433074606	357	103	22F
0005433074629	357	104	23B
0005432948473	357	105	23D
0005433569481	357	106	23C
0005432948424	357	107	23F
0005432948345	357	108	24A
0005432238982	357	109	24B
0005432948306	357	110	24C
0005433074571	357	111	24E
0005433569528	357	112	24D
0005432948390	357	113	24F
0005433569474	357	114	25A
0005433074631	357	115	25C
0005433569519	357	116	25D
0005432948369	357	117	25E
0005433569537	357	118	26B
0005432948482	357	119	26D
0005433569472	357	120	26C
0005433074697	357	121	26E
0005433569530	357	122	27A
0005433569502	357	123	26F
0005432948397	357	124	27C
0005433569478	357	125	27D
0005432948512	357	126	28A
0005432238983	357	127	27F
0005433569476	357	128	28C
0005433569506	357	129	28B
0005433569507	357	130	28D
0005433569492	357	131	28E
0005432948508	357	132	28F
0005433569524	357	133	29A
0005432238980	357	134	29B
0005433074642	357	135	29D
0005433569534	357	136	29E
0005433569485	357	137	30A
0005432948415	357	138	30B
0005433569473	357	139	30C
0005432948426	357	140	30D
0005432948406	357	141	30F
0005432948461	357	142	31C
0005432948346	357	143	31E
0005432948268	357	144	31F
0005433568638	11572	1	1A
0005432948728	11572	2	1C
0005433568843	11572	3	1F
0005433568752	11572	4	1D
0005433568644	11572	5	2C
0005432948758	11572	6	2A
0005432948724	11572	7	2D
0005432948749	11572	8	3A
0005433568906	11572	9	2F
0005432948732	11572	10	3F
0005432948726	11572	11	3D
0005432948738	11572	12	4A
0005432192342	11572	13	4D
0005433568898	11572	14	4C
0005433568578	11572	15	5A
0005433074914	11572	16	4F
0005433074898	11572	17	5D
0005432948764	11572	18	5C
0005432948759	11572	19	6A
0005433568908	11572	20	5F
0005433074902	11572	21	6D
0005433568835	11572	22	6C
0005433074901	11572	23	7A
0005433074912	11572	24	6F
0005433568763	11572	25	7C
0005432948733	11572	26	7D
0005433568751	11572	27	8A
0005433568768	11572	28	7F
0005433131741	11572	29	8C
0005433568813	11572	30	8D
0005433568765	11572	31	8E
0005433074916	11572	32	9A
0005433074907	11572	33	8F
0005433568911	11572	34	9C
0005433074913	11572	35	9D
0005432948765	11572	36	9F
0005432948737	11572	37	9E
0005433568582	11572	38	10A
0005432192343	11572	39	10C
0005433134171	11572	40	10B
0005432948763	11572	41	10D
0005433568834	11572	42	10E
0005433568825	11572	43	10F
0005433074921	11572	44	11A
0005433568863	11572	45	11C
0005433568844	11572	46	11D
0005433568889	11572	47	11E
0005432192341	11572	48	12A
0005433568819	11572	49	12B
0005433568853	11572	50	12D
0005432948739	11572	51	12E
0005433568842	11572	52	12F
0005432948753	11572	53	13B
0005433568807	11572	54	13C
0005433568903	11572	55	13E
0005433568852	11572	56	13D
0005433074904	11572	57	14A
0005433568864	11572	58	13F
0005432948750	11572	59	14B
0005432948761	11572	60	14D
0005433568845	11572	61	14C
0005432948735	11572	62	14E
0005432948756	11572	63	14F
0005432948748	11572	64	15A
0005433131740	11572	65	15C
0005432948762	11572	66	15B
0005432948745	11572	67	15D
0005432948729	11572	68	15F
0005433074924	11572	69	15E
0005433568851	11572	70	16C
0005433568921	11572	71	16B
0005433568680	11572	72	16D
0005433074909	11572	73	16E
0005433568904	11572	74	16F
0005432948751	11572	75	17B
0005433074923	11572	76	17A
0005433568930	11572	77	17C
0005433568894	11572	78	17E
0005433074910	11572	79	17D
0005433568790	11572	80	18A
0005433568822	11572	81	17F
0005433568764	11572	82	18C
0005433568933	11572	83	18B
0005433568750	11572	84	18D
0005433074917	11572	85	18E
0005432948725	11572	86	18F
0005433134170	11572	87	19B
0005432948752	11572	88	19E
0005433074922	11572	89	19D
0005432948731	11572	90	19C
0005432948736	11572	91	20A
0005432948760	11572	92	20D
0005433568799	11572	93	20C
0005432948744	11572	94	20E
0005432948740	11572	95	20F
0005433074899	11572	96	21A
0005433568907	11572	97	21B
0005433134169	11572	98	21D
0005433568653	11572	99	21C
0005433074903	11572	100	21E
0005433134172	11572	101	21F
0005433568832	11572	102	22B
0005432948743	11572	103	22C
0005432948727	11572	104	22F
0005432948734	11572	105	22E
0005433568865	11572	106	23B
0005432948757	11572	107	23A
0005433568770	11572	108	23C
0005433074908	11572	109	24A
0005433568899	11572	110	24B
0005433568820	11572	111	24D
0005433074905	11572	112	24E
0005433568905	11572	113	24F
0005432948747	11572	114	25D
0005433568941	11572	115	25C
0005433568767	11572	116	25F
0005433131739	11572	117	25E
0005433074918	11572	118	26A
0005433568814	11572	119	26B
0005433568896	11572	120	26D
0005433568824	11572	121	26C
0005432948723	11572	122	26E
0005433074915	11572	123	27A
0005432948746	11572	124	27C
0005433074906	11572	125	27B
0005433131742	11572	126	27D
0005432948742	11572	127	27F
0005433568514	11572	128	27E
0005433074919	11572	129	28A
0005433074897	11572	130	28B
0005432948754	11572	131	28C
0005433074900	11572	132	28E
0005433568753	11572	133	28D
0005433568771	11572	134	29A
0005433568772	11572	135	29C
0005433568939	11572	136	29B
0005433568846	11572	137	29D
0005433074920	11572	138	29F
0005433568515	11572	139	30A
0005432948741	11572	140	30B
0005433568900	11572	141	30D
0005433568831	11572	142	30C
0005433568743	11572	143	30E
0005433568893	11572	144	30F
0005433568801	11572	145	31B
0005432948730	11572	146	31A
0005433568940	11572	147	31C
0005432948755	11572	148	31D
0005433074911	11572	149	31E
0005433817501	10013	1	1B
0005433817496	10013	2	2A
0005433817500	10013	3	3B
0005433817499	10013	4	4A
0005433817497	10013	5	5A
0005433817498	10013	6	5B
0005434732981	10013	7	6B
0005434733005	13936	1	1A
0005434733006	13936	2	2A
0005433817471	13936	3	3A
0005433817472	13936	4	3B
0005433817457	13936	5	4A
0005434733007	13936	6	5B
0005433817456	13936	7	6B
0005435982644	2322	1	1B
0005433754615	2322	2	1F
0005433754637	2322	3	1C
0005432984935	2322	4	1G
0005433766666	2322	5	2A
0005433434648	2322	6	1H
0005433434642	2322	7	2C
0005433764695	2322	8	2B
0005433754652	2322	9	2F
0005435982632	2322	10	2G
0005432985017	2322	11	2H
0005432984768	2322	12	3B
0005433764694	2322	13	3F
0005432300304	2322	14	3C
0005433754635	2322	15	3G
0005432985084	2322	16	4A
0005433434509	2322	17	3H
0005432985115	2322	18	4C
0005433754656	2322	19	4B
0005432985042	2322	20	4G
0005435982623	2322	21	4F
0005435982653	2322	22	5A
0005432655628	2322	23	4H
0005432985127	2322	24	5B
0005432655619	2322	25	5F
0005433754649	2322	26	5C
0005435982655	2322	27	5G
0005433754602	2322	28	5H
0005433434633	2322	29	9B
0005433434727	2322	30	9A
0005433766669	2322	31	9H
0005434731153	2322	32	9G
0005433754644	2322	33	11A
0005433434643	2322	34	11B
0005435982637	2322	35	11D
0005432300307	2322	36	11G
0005435982624	2322	37	11F
0005435982648	2322	38	11E
0005433754603	2322	39	11H
0005435982622	2322	40	12A
0005433434581	2322	41	12D
0005432985026	2322	42	12F
0005435982625	2322	43	12E
0005433434688	2322	44	12H
0005435982652	2322	45	12G
0005432655631	2322	46	13B
0005435982630	2322	47	13D
0005432985062	2322	48	13E
0005433754640	2322	49	13G
0005433434634	2322	50	13F
0005433754628	2322	51	13H
0005435982658	2322	52	14E
0005432655621	2322	53	14D
0005433754642	2322	54	14B
0005433754646	2322	55	14F
0005433754629	2322	56	14G
0005432226104	2322	57	15A
0005433434585	2322	58	14H
0005432985022	2322	59	15B
0005433754607	2322	60	15D
0005433434651	2322	61	15F
0005433754654	2322	62	15E
0005432985040	2322	63	15H
0005433754651	2322	64	15G
0005435982626	2322	65	16B
0005432985001	2322	66	16A
0005432655624	2322	67	16E
0005433754647	2322	68	16D
0005433754659	2322	69	16G
0005432869509	2322	70	16F
0005433754653	2322	71	17A
0005432300305	2322	72	16H
0005433434652	2322	73	17D
0005433754610	2322	74	17B
0005433754638	2322	75	17E
0005435982621	2322	76	17G
0005435982631	2322	77	17F
0005435982635	2322	78	17H
0005432985015	2322	79	18B
0005432985047	2322	80	18A
0005433754622	2322	81	18D
0005435982659	2322	82	18F
0005432985106	2322	83	18E
0005433754657	2322	84	18G
0005432985085	2322	85	19A
0005433754617	2322	86	18H
0005435982654	2322	87	19B
0005435982633	2322	88	19E
0005435982642	2322	89	19D
0005432985027	2322	90	19F
0005432985000	2322	91	19H
0005433434635	2322	92	20B
0005435982649	2322	93	20E
0005433434653	2322	94	20D
0005432226103	2322	95	20G
0005432985087	2322	96	20F
0005433754612	2322	97	20H
0005433754604	2322	98	21A
0005433434555	2322	99	21D
0005432985225	2322	100	21B
0005433434647	2322	101	21E
0005433434735	2322	102	21F
0005433754645	2322	103	21H
0005433434654	2322	104	21G
0005432655629	2322	105	22B
0005432869521	2322	106	22A
0005432985056	2322	107	22D
0005433754623	2322	108	22F
0005433754633	2322	109	22E
0005432655627	2322	110	22G
0005433754648	2322	111	22H
0005432226099	2322	112	23B
0005433754624	2322	113	23A
0005432984899	2322	114	23E
0005433434649	2322	115	23D
0005432655630	2322	116	23F
0005433754630	2322	117	23H
0005433434632	2322	118	23G
0005432984917	2322	119	24A
0005432985094	2322	120	24B
0005432869508	2322	121	24E
0005432985072	2322	122	24D
0005433754621	2322	123	24F
0005432985068	2322	124	24H
0005433754643	2322	125	24G
0005432985073	2322	126	25E
0005433754616	2322	127	25D
0005433754634	2322	128	27A
0005435982660	2322	129	25F
0005435982662	2322	130	27B
0005433434737	2322	131	27E
0005432300306	2322	132	27D
0005435982634	2322	133	27F
0005432655620	2322	134	27H
0005433754605	2322	135	27G
0005433754625	2322	136	28A
0005435982656	2322	137	28B
0005435982620	2322	138	28E
0005435982636	2322	139	28D
0005435982645	2322	140	28F
0005435982661	2322	141	29B
0005432869522	2322	142	29A
0005433754611	2322	143	28H
0005435982640	2322	144	29D
0005432985013	2322	145	29E
0005435982647	2322	146	29F
0005432226100	2322	147	29H
0005433766668	2322	148	29G
0005433754613	2322	149	30B
0005432984767	2322	150	30A
0005432655623	2322	151	30D
0005432985023	2322	152	30F
0005432655622	2322	153	30E
0005435982650	2322	154	30G
0005432984766	2322	155	30H
0005432985083	2322	156	31B
0005435982628	2322	157	31D
0005435982664	2322	158	31F
0005433434673	2322	159	31E
0005435982638	2322	160	31G
0005433754618	2322	161	32A
0005433754655	2322	162	31H
0005433434697	2322	163	32B
0005433754631	2322	164	32E
0005432226101	2322	165	32D
0005435982646	2322	166	32F
0005435982641	2322	167	32G
0005433754606	2322	168	33A
0005433754641	2322	169	32H
0005433754636	2322	170	33B
0005433434698	2322	171	33E
0005433754614	2322	172	33D
0005435982663	2322	173	33F
0005433434510	2322	174	33H
0005432869531	2322	175	34A
0005433434650	2322	176	34D
0005433754627	2322	177	34B
0005432985093	2322	178	34E
0005435982627	2322	179	34G
0005435982657	2322	180	34F
0005433754639	2322	181	34H
0005432984971	2322	182	35A
0005432985014	2322	183	35D
0005434731157	2322	184	35B
0005433434582	2322	185	35E
0005433754632	2322	186	35H
0005433754620	2322	187	35G
0005433434740	2322	188	36A
0005432226102	2322	189	36B
0005432655626	2322	190	36E
0005435982651	2322	191	36D
0005435982643	2322	192	36F
0005432226105	2322	193	36G
0005432985021	2322	194	37A
0005432985118	2322	195	36H
0005433766667	2322	196	37B
0005432300308	2322	197	37E
0005433754619	2322	198	37D
0005432300303	2322	199	37F
0005433434657	2322	200	37H
0005433754650	2322	201	37G
0005432984998	2322	202	38B
0005433754608	2322	203	38A
0005433754658	2322	204	38D
0005433754626	2322	205	38E
0005435982629	2322	206	38G
0005433754609	2322	207	38F
0005433434699	2322	208	38H
0005432869507	2322	209	39E
0005435982639	2322	210	39D
0005432655625	2322	211	39F
0005432985313	26201	1	1A
0005435982254	26201	2	1C
0005435982236	26201	3	1B
0005435982275	26201	4	1F
0005432985302	26201	5	1H
0005433434873	26201	6	1G
0005435982255	26201	7	2A
0005435982211	26201	8	2B
0005433753927	26201	9	2C
0005434731200	26201	10	2G
0005432655544	26201	11	2F
0005435982362	26201	12	3A
0005435981975	26201	13	2H
0005433754199	26201	14	3B
0005433434886	26201	15	3F
0005433434894	26201	16	3C
0005432985321	26201	17	3G
0005432655545	26201	18	3H
0005432985296	26201	19	4B
0005432985314	26201	20	4A
0005433754106	26201	21	4F
0005435982276	26201	22	4C
0005433754202	26201	23	4G
0005433754367	26201	24	4H
0005432985305	26201	25	5B
0005433434895	26201	26	5A
0005432655509	26201	27	5C
0005433754147	26201	28	5G
0005433434890	26201	29	5F
0005432985310	26201	30	5H
0005435982307	26201	31	9A
0005433753979	26201	32	9H
0005433754049	26201	33	9G
0005433434887	26201	34	9B
0005433754293	26201	35	11A
0005432051152	26201	36	11B
0005432985297	26201	37	11E
0005432985303	26201	38	11D
0005433754203	26201	39	11F
0005435982071	26201	40	11H
0005433754478	26201	41	12B
0005432655491	26201	42	12A
0005432049490	26201	43	12D
0005433754151	26201	44	12E
0005435982173	26201	45	12F
0005433434880	26201	46	12H
0005433434897	26201	47	12G
0005432051150	26201	48	13B
0005432985315	26201	49	13A
0005433434889	26201	50	13D
0005433766635	26201	51	13E
0005433754146	26201	52	13G
0005433754298	26201	53	13F
0005432985308	26201	54	14A
0005432985298	26201	55	13H
0005432655482	26201	56	14D
0005433434896	26201	57	14B
0005435982190	26201	58	14F
0005435982056	26201	59	14E
0005433434879	26201	60	14H
0005432869569	26201	61	14G
0005433754470	26201	62	15B
0005435982168	26201	63	15A
0005433754126	26201	64	15E
0005432985318	26201	65	15D
0005432985311	26201	66	15F
0005433754224	26201	67	15H
0005433754082	26201	68	15G
0005433754128	26201	69	16A
0005435982217	26201	70	16D
0005432869572	26201	71	16B
0005434731203	26201	72	16E
0005435982208	26201	73	16H
0005433754191	26201	74	16G
0005434731202	26201	75	17A
0005432655485	26201	76	17B
0005432869570	26201	77	17F
0005433754103	26201	78	17E
0005433753967	26201	79	17D
0005432869568	26201	80	17G
0005435982046	26201	81	17H
0005432985306	26201	82	18A
0005435981981	26201	83	18D
0005435982212	26201	84	18E
0005435982256	26201	85	18G
0005432655487	26201	86	18F
0005432985319	26201	87	18H
0005435982096	26201	88	19B
0005433754051	26201	89	19E
0005432985322	26201	90	19D
0005435982129	26201	91	19F
0005432985307	26201	92	19H
0005433434881	26201	93	19G
0005432985327	26201	94	20A
0005435982372	26201	95	20D
0005433434877	26201	96	20B
0005432655486	26201	97	20G
0005433434885	26201	98	20F
0005435982110	26201	99	20E
0005433754328	26201	100	20H
0005435982284	26201	101	21A
0005435982213	26201	102	21D
0005432655467	26201	103	21E
0005433754070	26201	104	21G
0005433754176	26201	105	21F
0005433754222	26201	106	21H
0005433434872	26201	107	22A
0005433753999	26201	108	22D
0005433434874	26201	109	22B
0005433754105	26201	110	22E
0005433434883	26201	111	22G
0005432985326	26201	112	23B
0005432985304	26201	113	23A
0005433754056	26201	114	23D
0005433754335	26201	115	23F
0005435982240	26201	116	23E
0005432049491	26201	117	23G
0005435982333	26201	118	24A
0005432655490	26201	119	23H
0005433754123	26201	120	24B
0005432985328	26201	121	24E
0005432655500	26201	122	24D
0005435981916	26201	123	24F
0005433754046	26201	124	24G
0005433434871	26201	125	25D
0005433764680	26201	126	24H
0005433754122	26201	127	25E
0005435982170	26201	128	27A
0005435982268	26201	129	27B
0005432985299	26201	130	27D
0005435982246	26201	131	27F
0005433434882	26201	132	27G
0005433754294	26201	133	28A
0005433754050	26201	134	27H
0005432985323	26201	135	28D
0005435982218	26201	136	28B
0005432985301	26201	137	28E
0005435982146	26201	138	28F
0005432655501	26201	139	28G
0005435982309	26201	140	29A
0005433753971	26201	141	28H
0005435982283	26201	142	29D
0005432985320	26201	143	29B
0005435982253	26201	144	29E
0005432985316	26201	145	29G
0005433766638	26201	146	29F
0005435982147	26201	147	29H
0005432655502	26201	148	30B
0005433766642	26201	149	30A
0005432655483	26201	150	30E
0005433754107	26201	151	30D
0005433434892	26201	152	30G
0005432985300	26201	153	30F
0005433754173	26201	154	31A
0005433434888	26201	155	30H
0005433754071	26201	156	31B
0005433434891	26201	157	31D
0005432051151	26201	158	31F
0005435982267	26201	159	31E
0005432655514	26201	160	31G
0005435982363	26201	161	32A
0005433434876	26201	162	31H
0005433434884	26201	163	32D
0005433434893	26201	164	32B
0005433754042	26201	165	32E
0005432985317	26201	166	32F
0005433754378	26201	167	32H
0005433754052	26201	168	32G
0005435982174	26201	169	33A
0005433754177	26201	170	33B
0005432049489	26201	171	33E
0005432985309	26201	172	33D
0005433754190	26201	173	33H
0005435981974	26201	174	33G
0005432985325	26201	175	34B
0005433766617	26201	176	34A
0005432985324	26201	177	34D
0005433754334	26201	178	34E
0005433754477	26201	179	34G
0005432655510	26201	180	34F
0005432655507	26201	181	35A
0005432655532	26201	182	34H
0005433434898	26201	183	35B
0005432985312	26201	184	35E
0005432655503	26201	185	35D
0005435982191	26201	186	35G
0005435982047	26201	187	36A
0005434731201	26201	188	35H
0005432869571	26201	189	36B
0005432655533	26201	190	36E
0005433754083	26201	191	36D
0005435982221	26201	192	37A
0005433434875	26201	193	36H
0005433434878	26201	194	37D
0005435982169	26201	195	37E
0005433754299	26201	196	37G
0005435982207	26201	197	37F
0005433754057	26201	198	38A
0005435982261	26201	199	37H
0005435982070	26201	200	38B
0005433754259	26201	201	38E
0005433754248	26201	202	38D
0005435982167	26201	203	38G
0005433754368	26201	204	38F
0005433754240	26201	205	38H
0005432655508	26201	206	39D
0005433754186	26201	207	39F
0005432049488	26201	208	39E
0005433151385	1537	1	1F
0005434374999	1537	2	1D
0005434374986	1537	3	2D
0005434374971	1537	4	2C
0005434375006	1537	5	2F
0005433151301	1537	6	3D
0005434029654	1537	7	3C
0005434374972	1537	8	3F
0005433151464	1537	9	4A
0005434374991	1537	10	4B
0005433461603	1537	11	4D
0005434374968	1537	12	4C
0005434374954	1537	13	4E
0005434375010	1537	14	4F
0005434374959	1537	15	5A
0005434374974	1537	16	5C
0005434374960	1537	17	5D
0005432267947	1537	18	5E
0005433151197	1537	19	6A
0005434374965	1537	20	5F
0005434374955	1537	21	6B
0005433151366	1537	22	6C
0005434374985	1537	23	6F
0005434374966	1537	24	7F
0005433151544	1537	25	7E
0005433151397	1537	26	8A
0005434374951	1537	27	8B
0005434374978	1537	28	8C
0005434374982	1537	29	8E
0005434375009	1537	30	8D
0005434374996	1537	31	9A
0005434375000	1537	32	8F
0005433151522	1537	33	9B
0005434374987	1537	34	9D
0005434029646	1537	35	9C
0005434375005	1537	36	9F
0005433151399	1537	37	10E
0005434374995	1537	38	10D
0005433460452	1537	39	11A
0005433151431	1537	40	11B
0005433151362	1537	41	11D
0005433931459	1537	42	11C
0005434374975	1537	43	11E
0005434374981	1537	44	11F
0005433151261	1537	45	12A
0005434374963	1537	46	12B
0005433151288	1537	47	12D
0005434374964	1537	48	12C
0005434374970	1537	49	12E
0005432267941	1537	50	13A
0005434374961	1537	51	12F
0005434375008	1537	52	13B
0005433461604	1537	53	13C
0005434374984	1537	54	13D
0005434374993	1537	55	13E
0005433931458	1537	56	14A
0005433151315	1537	57	14B
0005434374967	1537	58	14E
0005434029651	1537	59	14D
0005434374957	1537	60	14F
0005433151398	1537	61	15B
0005434375011	1537	62	15C
0005432267944	1537	63	15E
0005433151430	1537	64	16A
0005434374998	1537	65	16B
0005432267945	1537	66	16C
0005434375004	1537	67	16D
0005434375007	1537	68	16E
0005433151411	1537	69	17A
0005432267943	1537	70	16F
0005434374989	1537	71	17B
0005434374979	1537	72	17D
0005434029653	1537	73	17C
0005434374988	1537	74	17E
0005434375002	1537	75	18A
0005433151376	1537	76	17F
0005434374992	1537	77	18C
0005433151439	1537	78	18B
0005434374976	1537	79	18E
0005432267942	1537	80	18D
0005432267946	1537	81	18F
0005434374956	1537	82	19C
0005434374953	1537	83	19D
0005433460451	1537	84	19E
0005434375001	1537	85	19F
0005433151262	1537	86	20B
0005434374973	1537	87	20A
0005433151294	1537	88	20C
0005434374983	1537	89	20E
0005433151349	1537	90	20F
0005434029652	1537	91	21B
0005433151432	1537	92	21A
0005434374952	1537	93	21C
0005434374994	1537	94	21D
0005434374962	1537	95	21F
0005433151440	1537	96	21E
0005433151252	1537	97	22B
0005434374997	1537	98	22A
0005434375003	1537	99	22F
0005434374977	1537	100	22E
0005434374980	1537	101	23A
0005433151545	1537	102	23C
0005434374969	1537	103	23B
0005434374990	1537	104	23E
0005434374958	1537	105	23D
0005433151372	1537	106	23F
0005433151652	20104	1	1A
0005433151653	20104	2	1F
0005434374685	20104	3	1D
0005434374547	20104	4	2C
0005434374574	20104	5	2A
0005433151654	20104	6	2D
0005433151655	20104	7	3A
0005434029674	20104	8	2F
0005433151667	20104	9	3D
0005434374598	20104	10	3C
0005434029675	20104	11	4A
0005434374647	20104	12	4C
0005434374575	20104	13	4B
0005433151642	20104	14	4D
0005434374619	20104	15	4F
0005433931486	20104	16	5B
0005433151645	20104	17	5A
0005434374516	20104	18	5D
0005433151658	20104	19	5E
0005433931487	20104	20	6C
0005433151639	20104	21	6D
0005434374623	20104	22	6E
0005433151648	20104	23	7A
0005434374763	20104	24	6F
0005433151661	20104	25	7B
0005434374743	20104	26	7D
0005433151663	20104	27	7F
0005434374754	20104	28	7E
0005434374438	20104	29	8A
0005434374641	20104	30	8B
0005434374485	20104	31	8D
0005434374569	20104	32	8E
0005434374638	20104	33	9A
0005434374537	20104	34	9C
0005434374671	20104	35	9B
0005434374712	20104	36	9D
0005433151647	20104	37	9E
0005434374639	20104	38	9F
0005434374620	20104	39	10C
0005434374618	20104	40	10B
0005434374585	20104	41	10E
0005433151671	20104	42	11A
0005433764694	20104	43	11B
0005432056325	20104	44	11C
0005433151662	20104	45	11E
0005434374445	20104	46	11F
0005434374626	20104	47	12B
0005434374753	20104	48	12D
0005434374680	20104	49	12E
0005433151649	20104	50	13A
0005432056328	20104	51	12F
0005433151657	20104	52	13B
0005434374605	20104	53	13C
0005433151672	20104	54	13D
0005433151644	20104	55	13E
0005434374568	20104	56	14B
0005433931485	20104	57	14C
0005434374713	20104	58	14F
0005433151646	20104	59	14E
0005434374687	20104	60	15C
0005432056326	20104	61	15B
0005434374588	20104	62	15E
0005433151668	20104	63	16A
0005433764695	20104	64	16B
0005433151656	20104	65	16E
0005433151669	20104	66	16D
0005434374471	20104	67	17A
0005434374546	20104	68	17B
0005433151638	20104	69	17D
0005433151641	20104	70	17F
0005434374535	20104	71	18A
0005433151640	20104	72	18B
0005433151665	20104	73	18C
0005434374622	20104	74	18D
0005433151670	20104	75	18F
0005434374470	20104	76	19A
0005433151664	20104	77	19B
0005434374645	20104	78	19E
0005433151643	20104	79	19F
0005434374646	20104	80	20C
0005433151666	20104	81	20B
0005434374621	20104	82	20D
0005434374331	20104	83	20E
0005433931488	20104	84	21A
0005433931489	20104	85	21B
0005433151651	20104	86	21D
0005433151659	20104	87	21E
0005434374536	20104	88	22A
0005434374656	20104	89	21F
0005434374595	20104	90	22B
0005434374642	20104	91	22D
0005432056327	20104	92	22E
0005433151650	20104	93	22F
0005434374366	20104	94	23B
0005433151660	20104	95	23A
0005434374782	20104	96	23D
0005434374637	20104	97	23E
0005432424791	525	1	2A
0005432424800	525	2	1F
0005432424812	525	3	2F
0005432424801	525	4	2D
0005432424779	525	5	3D
0005432424798	525	6	4A
0005432424782	525	7	4C
0005432282915	525	8	7A
0005432424777	525	9	8F
0005432424820	525	10	9B
0005432424786	525	11	10C
0005432424810	525	12	10F
0005432424811	525	13	11C
0005432424803	525	14	12B
0005432424783	525	15	12C
0005432424793	525	16	12F
0005432424807	525	17	13B
0005432424790	525	18	13E
0005432424813	525	19	13F
0005432424795	525	20	14C
0005432424792	525	21	15B
0005432424780	525	22	15D
0005432424814	525	23	16E
0005432424789	525	24	17F
0005432424784	525	25	18A
0005432424797	525	26	18D
0005432424776	525	27	18E
0005432282918	525	28	21A
0005432424778	525	29	21D
0005432282917	525	30	21F
0005432424806	525	31	22B
0005432424802	525	32	22C
0005432424804	525	33	23C
0005432424816	525	34	24A
0005432424819	525	35	24E
0005432282916	525	36	25E
0005432424799	525	37	25D
0005432282914	525	38	25C
0005432282919	525	39	25F
0005432424787	525	40	26B
0005432424796	525	41	26C
0005432424781	525	42	27E
0005432424821	525	43	28A
0005432424785	525	44	28B
0005432424788	525	45	28F
0005432424809	525	46	29A
0005432424818	525	47	29D
0005432424805	525	48	29E
0005432424815	525	49	30A
0005432424817	525	50	29F
0005432424808	525	51	30B
0005432424794	525	52	31D
0005432302357	12834	1	3A
0005432302358	12834	2	12C
0005432302359	12834	3	18A
0005432302356	12834	4	20D
0005432424281	12842	1	1F
0005432424082	12842	2	3A
0005432424291	12842	3	3D
0005432424360	12842	4	4C
0005432424272	12842	5	5C
0005432424330	12842	6	6C
0005432424353	12842	7	7D
0005432424327	12842	8	8C
0005432424240	12842	9	8E
0005432424233	12842	10	9A
0005432424334	12842	11	10B
0005432424354	12842	12	10E
0005432424247	12842	13	11F
0005432424151	12842	14	12A
0005432424350	12842	15	12C
0005432424382	12842	16	12D
0005432424368	12842	17	12E
0005432424234	12842	18	13A
0005432424226	12842	19	14D
0005432424339	12842	20	14E
0005432423947	12842	21	15C
0005432424384	12842	22	15B
0005432424367	12842	23	16A
0005432424243	12842	24	15F
0005432424343	12842	25	17B
0005432424150	12842	26	19E
0005432424227	12842	27	20B
0005432424297	12842	28	23C
0005432424383	12842	29	24A
0005432424355	12842	30	24C
0005432424284	12842	31	24F
0005432424352	12842	32	25C
0005432424381	12842	33	25B
0005432424252	12842	34	26A
0005432424369	12842	35	25F
0005432424333	12842	36	26F
0005432424371	12842	37	27D
0005432424083	12842	38	28D
0005432424370	12842	39	29C
0005432424268	12842	40	30A
0005432424326	12842	41	31E
0005432424351	12842	42	31F
0005433057984	429	1	1A
0005434024169	429	2	1B
0005432235692	429	3	1G
0005434024225	429	4	2B
0005434024172	429	5	2C
0005432235696	429	6	2H
0005434024186	429	7	3C
0005434024226	429	8	3B
0005433057891	429	9	3F
0005434024185	429	10	3G
0005433057992	429	11	4B
0005433057979	429	12	5A
0005434024231	429	13	4H
0005432045627	429	14	5C
0005432235690	429	15	9A
0005434024217	429	16	9B
0005433057845	429	17	9G
0005434024198	429	18	11A
0005433057806	429	19	9H
0005434024177	429	20	11B
0005433057749	429	21	11H
0005434735682	429	22	11G
0005434024194	429	23	12A
0005433057921	429	24	12G
0005433058056	429	25	12F
0005434024232	429	26	12H
0005434024209	429	27	13A
0005434024233	429	28	13B
0005434024216	429	29	13F
0005432235694	429	30	13D
0005434024180	429	31	13H
0005433057881	429	32	14D
0005434024208	429	33	14E
0005434032053	429	34	14H
0005434024173	429	35	14G
0005434029671	429	36	15A
0005434032055	429	37	15E
0005434024167	429	38	15G
0005432045626	429	39	15F
0005432235693	429	40	15H
0005433057961	429	41	16D
0005434024192	429	42	16E
0005434024197	429	43	16G
0005433057892	429	44	16F
0005434735681	429	45	17A
0005433058057	429	46	17D
0005433057890	429	47	17B
0005433057980	429	48	17E
0005434029673	429	49	17G
0005433057962	429	50	17H
0005434024210	429	51	18B
0005434024218	429	52	18D
0005434024178	429	53	18E
0005434028315	429	54	18G
0005434024234	429	55	19A
0005433057908	429	56	18H
0005434024188	429	57	19B
0005434024176	429	58	19D
0005434024183	429	59	19F
0005434024171	429	60	19E
0005434024199	429	61	19H
0005434024211	429	62	19G
0005434024201	429	63	20A
0005434024207	429	64	20D
0005434024220	429	65	20B
0005433057707	429	66	20F
0005433057898	429	67	20G
0005434024181	429	68	21D
0005434024230	429	69	21F
0005433057978	429	70	21H
0005434024195	429	71	22D
0005434024203	429	72	22E
0005433057922	429	73	23D
0005434032054	429	74	23E
0005434024206	429	75	23G
0005434024223	429	76	23F
0005433057991	429	77	24B
0005434024212	429	78	24A
0005434024227	429	79	24E
0005434024190	429	80	24D
0005433057990	429	81	24G
0005434024191	429	82	25D
0005432045625	429	83	27A
0005433057844	429	84	27D
0005433057963	429	85	27B
0005433057899	429	86	27G
0005434029672	429	87	27E
0005433057968	429	88	27H
0005433058068	429	89	28A
0005434024170	429	90	28E
0005433057810	429	91	28G
0005434024205	429	92	29A
0005434024179	429	93	29D
0005434028314	429	94	29F
0005434024184	429	95	29G
0005433057989	429	96	29H
0005434024213	429	97	30B
0005434024168	429	98	30A
0005434024224	429	99	30E
0005434024189	429	100	30H
0005434735694	429	101	31B
0005434024204	429	102	31F
0005434024222	429	103	31G
0005432235695	429	104	31H
0005434032052	429	105	32D
0005434024187	429	106	32F
0005433057706	429	107	32H
0005433058013	429	108	33A
0005434735695	429	109	33B
0005434024182	429	110	33E
0005433057705	429	111	33F
0005433057882	429	112	33H
0005434735696	429	113	34A
0005433057811	429	114	34B
0005434024200	429	115	34E
0005433058069	429	116	34F
0005433058070	429	117	34G
0005434024214	429	118	35D
0005434024228	429	119	35E
0005434024229	429	120	35G
0005433057982	429	121	35H
0005434024175	429	122	36B
0005432235689	429	123	36A
0005434024202	429	124	36E
0005433057750	429	125	36D
0005433057983	429	126	36F
0005434024221	429	127	37A
0005433057893	429	128	37B
0005434024219	429	129	37E
0005433057981	429	130	37D
0005434024166	429	131	37F
0005433058012	429	132	37H
0005434024165	429	133	37G
0005433057807	429	134	38A
0005434024196	429	135	38B
0005434024193	429	136	38G
0005434024174	429	137	38H
0005432235691	429	138	39D
0005433057967	429	139	39F
0005434024215	429	140	39E
0005433058168	12678	1	1B
0005433058182	12678	2	1F
0005434023841	12678	3	1C
0005433058170	12678	4	1H
0005434735725	12678	5	2B
0005433058167	12678	6	2H
0005434023662	12678	7	2G
0005433058157	12678	8	3C
0005434023291	12678	9	3F
0005433058159	12678	10	3G
0005434023766	12678	11	4B
0005434023851	12678	12	4A
0005434023853	12678	13	4F
0005433058173	12678	14	4C
0005434023694	12678	15	4G
0005432156398	12678	16	5A
0005434023772	12678	17	5F
0005433058169	12678	18	5C
0005434023543	12678	19	5G
0005434023703	12678	20	5H
0005433058179	12678	21	9H
0005433058165	12678	22	9G
0005434023852	12678	23	11A
0005434023882	12678	24	11B
0005433929643	12678	25	11G
0005433058194	12678	26	11F
0005434023759	12678	27	12B
0005434029653	12678	28	12E
0005433058154	12678	29	12D
0005434023747	12678	30	13A
0005433058156	12678	31	13D
0005434023720	12678	32	13B
0005434023765	12678	33	13F
0005434023606	12678	34	13G
0005434023693	12678	35	13H
0005434023576	12678	36	14B
0005433058162	12678	37	14A
0005434028284	12678	38	14D
0005433058177	12678	39	14F
0005433058175	12678	40	14G
0005434023445	12678	41	15B
0005434028291	12678	42	15E
0005433929644	12678	43	15D
0005434023804	12678	44	15H
0005434735729	12678	45	16B
0005434023575	12678	46	16A
0005434023760	12678	47	16D
0005433058187	12678	48	16E
0005433058190	12678	49	16H
0005434023657	12678	50	16G
0005434735728	12678	51	17A
0005434023744	12678	52	17E
0005434023805	12678	53	17H
0005432157505	12678	54	18A
0005434023414	12678	55	18D
0005433058186	12678	56	18H
0005433058172	12678	57	19B
0005434023653	12678	58	19A
0005433684436	12678	59	19E
0005434031974	12678	60	19G
0005434028293	12678	61	20A
0005434023815	12678	62	20B
0005434023559	12678	63	20E
0005434023651	12678	64	20F
0005434023432	12678	65	21A
0005434023292	12678	66	21D
0005434023661	12678	67	22A
0005433058166	12678	68	22B
0005433058181	12678	69	22F
0005434023644	12678	70	22E
0005433058189	12678	71	22H
0005434023497	12678	72	23B
0005434023524	12678	73	23D
0005434023560	12678	74	23G
0005434023881	12678	75	24B
0005434023756	12678	76	24A
0005433058188	12678	77	24F
0005433058180	12678	78	24G
0005433058178	12678	79	25D
0005434735726	12678	80	25F
0005434029651	12678	81	27A
0005434023656	12678	82	27F
0005434023872	12678	83	28A
0005433058164	12678	84	28E
0005434023660	12678	85	28D
0005434023467	12678	86	28G
0005432157506	12678	87	28F
0005434023757	12678	88	29A
0005434023558	12678	89	29E
0005433058171	12678	90	29D
0005433684437	12678	91	29H
0005433058174	12678	92	29G
0005434023652	12678	93	30B
0005433929645	12678	94	30A
0005434023735	12678	95	30F
0005433058176	12678	96	31A
0005434023453	12678	97	30H
0005434023565	12678	98	31D
0005433058155	12678	99	31E
0005434023746	12678	100	31H
0005434735730	12678	101	32A
0005434029646	12678	102	32D
0005433684435	12678	103	32F
0005433058163	12678	104	32E
0005433058158	12678	105	32H
0005432157507	12678	106	33A
0005433058184	12678	107	33B
0005433058183	12678	108	33G
0005434023823	12678	109	33F
0005434023732	12678	110	33H
0005434023755	12678	111	34B
0005433058191	12678	112	34A
0005434023386	12678	113	34D
0005434735727	12678	114	34E
0005434023377	12678	115	35A
0005434029654	12678	116	34H
0005434023842	12678	117	35B
0005433058160	12678	118	35G
0005433058161	12678	119	35F
0005433929642	12678	120	35H
0005434028282	12678	121	36D
0005434023616	12678	122	36B
0005434023692	12678	123	36A
0005433684438	12678	124	36F
0005434028292	12678	125	36E
0005434023719	12678	126	37A
0005432156399	12678	127	36H
0005434029652	12678	128	37D
0005434023617	12678	129	37B
0005434023531	12678	130	37E
0005434023712	12678	131	37H
0005434023645	12678	132	38D
0005433058193	12678	133	38E
0005434023822	12678	134	38F
0005434023784	12678	135	38H
0005433058185	12678	136	39D
0005433058192	12678	137	39E
0005433529296	13813	1	1C
0005433527288	13813	2	3C
0005433527284	13813	3	4A
0005433527286	13813	4	5A
0005433529297	13813	5	5D
0005433529298	13813	6	6C
0005433529301	13813	7	7B
0005433527289	13813	8	7D
0005433527282	13813	9	8D
0005433527292	13813	10	8F
0005433529292	13813	11	9A
0005433529299	13813	12	11A
0005433529294	13813	13	11E
0005433529300	13813	14	12C
0005433529302	13813	15	13C
0005433527290	13813	16	15C
0005433529303	13813	17	17A
0005433529295	13813	18	18E
0005433527285	13813	19	19F
0005433529293	13813	20	20F
0005433527287	13813	21	21A
0005433527283	13813	22	21D
0005433527291	13813	23	21C
0005433533285	32447	1	2C
0005433533296	32447	2	1F
0005433529274	32447	3	3F
0005433533287	32447	4	5F
0005433533291	32447	5	5D
0005433529265	32447	6	7B
0005433533292	32447	7	8B
0005433529266	32447	8	10C
0005433533293	32447	9	10F
0005433529267	32447	10	11F
0005433529258	32447	11	12F
0005433529269	32447	12	13C
0005433533298	32447	13	13F
0005433529249	32447	14	14F
0005433533307	32447	15	15A
0005433529273	32447	16	16C
0005433533299	32447	17	17E
0005433533297	32447	18	18D
0005433533286	32447	19	18E
0005433529259	32447	20	19D
0005433533308	32447	21	20A
0005433529257	32447	22	20F
0005433529268	32447	23	21C
0005433929644	2154	1	1A
0005433923962	2154	2	1C
0005433924018	2154	3	1B
0005433036313	2154	4	1F
0005433924037	2154	5	1G
0005433036415	2154	6	2A
0005433036243	2154	7	1H
0005432231641	2154	8	2C
0005434028292	2154	9	2B
0005433923952	2154	10	2F
0005433924002	2154	11	3A
0005433923982	2154	12	2H
0005433036254	2154	13	3B
0005433924041	2154	14	3F
0005433924023	2154	15	3C
0005432044543	2154	16	3G
0005433036282	2154	17	4C
0005433875391	2154	18	4F
0005433931485	2154	19	4G
0005433923960	2154	20	5A
0005433924001	2154	21	4H
0005433036388	2154	22	5B
0005433924000	2154	23	5C
0005433036190	2154	24	5G
0005432231645	2154	25	5F
0005433036034	2154	26	5H
0005433924034	2154	27	9B
0005433923971	2154	28	9A
0005433923979	2154	29	9G
0005433929645	2154	30	11A
0005434028293	2154	31	11B
0005433923987	2154	32	11E
0005433036237	2154	33	11D
0005433924025	2154	34	11F
0005433924008	2154	35	11H
0005433924026	2154	36	11G
0005433923964	2154	37	12A
0005432044546	2154	38	12D
0005433036253	2154	39	12B
0005433036136	2154	40	12E
0005432231640	2154	41	12F
0005433923950	2154	42	13A
0005433923994	2154	43	12H
0005433924007	2154	44	12G
0005433036116	2154	45	13E
0005433931487	2154	46	13G
0005434028282	2154	47	13H
0005433923958	2154	48	14B
0005433931489	2154	49	14A
0005432044544	2154	50	14E
0005433923974	2154	51	14D
0005433923972	2154	52	14F
0005433036248	2154	53	15A
0005434028291	2154	54	14H
0005433923946	2154	55	15B
0005433036315	2154	56	15D
0005433923983	2154	57	15F
0005433923951	2154	58	15E
0005433923995	2154	59	15G
0005433929642	2154	60	16A
0005433931486	2154	61	16D
0005433923967	2154	62	16B
0005433036238	2154	63	16E
0005433036338	2154	64	16G
0005433923959	2154	65	16F
0005433036451	2154	66	16H
0005433923948	2154	67	17A
0005433923975	2154	68	17D
0005434028284	2154	69	17E
0005433924011	2154	70	17G
0005433036312	2154	71	17H
0005433036343	2154	72	18B
0005433924012	2154	73	18A
0005433923989	2154	74	18D
0005433924020	2154	75	18F
0005433036314	2154	76	18E
0005433036231	2154	77	18G
0005433923986	2154	78	19B
0005433924013	2154	79	19A
0005433923957	2154	80	19E
0005433036033	2154	81	19G
0005433036380	2154	82	20A
0005433923996	2154	83	19H
0005433924021	2154	84	20B
0005433036174	2154	85	20D
0005433923984	2154	86	20F
0005433923990	2154	87	20H
0005433924006	2154	88	20G
0005433036232	2154	89	21A
0005433036389	2154	90	21D
0005432231644	2154	91	21B
0005433036117	2154	92	21G
0005433036335	2154	93	21F
0005432231639	2154	94	21H
0005433923956	2154	95	22D
0005433036344	2154	96	22B
0005433036189	2154	97	22F
0005433923970	2154	98	22E
0005433036402	2154	99	22G
0005433923954	2154	100	22H
0005433875392	2154	101	23B
0005433036360	2154	102	23F
0005433923981	2154	103	23E
0005433924033	2154	104	23G
0005433924036	2154	105	23H
0005433036005	2154	106	24D
0005433923968	2154	107	24F
0005433924005	2154	108	24E
0005433931488	2154	109	24G
0005433923965	2154	110	25F
0005433923943	2154	111	25E
0005433923991	2154	112	27B
0005433923998	2154	113	27E
0005433923988	2154	114	27F
0005433923977	2154	115	27G
0005433036135	2154	116	28A
0005433923955	2154	117	27H
0005432231638	2154	118	28B
0005433036063	2154	119	28E
0005432231636	2154	120	28D
0005433923985	2154	121	28F
0005433036004	2154	122	28G
0005433923999	2154	123	29A
0005433924003	2154	124	28H
0005433924022	2154	125	29D
0005432231637	2154	126	29B
0005433923973	2154	127	29E
0005433036283	2154	128	29G
0005433923953	2154	129	29F
0005433924004	2154	130	30A
0005433924040	2154	131	29H
0005433923978	2154	132	30D
0005433924032	2154	133	30F
0005433036359	2154	134	30E
0005433924029	2154	135	30G
0005433923997	2154	136	30H
0005432231643	2154	137	31B
0005433923963	2154	138	31D
0005433923961	2154	139	31F
0005433036428	2154	140	31E
0005433924030	2154	141	31G
0005433923969	2154	142	32B
0005433924031	2154	143	32A
0005433036241	2154	144	32E
0005433923992	2154	145	32D
0005433929643	2154	146	32F
0005433923976	2154	147	32H
0005433036403	2154	148	32G
0005433924028	2154	149	33A
0005432231646	2154	150	33D
0005433924010	2154	151	33B
0005433924015	2154	152	33F
0005433036351	2154	153	33H
0005433036352	2154	154	33G
0005433924014	2154	155	34A
0005432044545	2154	156	34F
0005433923949	2154	157	34E
0005433924016	2154	158	34D
0005433924009	2154	159	34G
0005433924035	2154	160	34H
0005433036420	2154	161	35B
0005433924038	2154	162	35D
0005433036134	2154	163	35E
0005432231642	2154	164	35G
0005433923944	2154	165	35H
0005433036188	2154	166	36B
0005433036066	2154	167	36A
0005433036280	2154	168	36E
0005433923980	2154	169	36H
0005433036304	2154	170	36G
0005433924027	2154	171	36F
0005433036507	2154	172	37A
0005433036279	2154	173	37B
0005433036182	2154	174	37D
0005433923966	2154	175	37E
0005433036187	2154	176	37G
0005433924039	2154	177	38B
0005433924017	2154	178	38A
0005433923945	2154	179	38D
0005433924024	2154	180	38E
0005433923947	2154	181	38G
0005433036204	2154	182	38F
0005433924019	2154	183	38H
0005433923993	2154	184	39E
0005433036222	2154	185	39F
0005433036706	24110	1	1C
0005433036681	24110	2	1B
0005433036656	24110	3	1F
0005433923196	24110	4	2A
0005433923490	24110	5	2B
0005433036680	24110	6	2C
0005433923238	24110	7	2H
0005433036690	24110	8	2G
0005433922962	24110	9	3A
0005433922802	24110	10	3C
0005433036675	24110	11	3H
0005433036698	24110	12	3G
0005433036688	24110	13	3F
0005433923308	24110	14	4A
0005433036705	24110	15	4B
0005433922963	24110	16	4F
0005433923557	24110	17	4C
0005433923288	24110	18	4G
0005433923199	24110	19	4H
0005433923450	24110	20	5B
0005432206239	24110	21	5A
0005433922456	24110	22	5F
0005432207679	24110	23	5H
0005433036694	24110	24	9B
0005432207681	24110	25	9A
0005433923376	24110	26	9G
0005433036655	24110	27	9H
0005433923580	24110	28	11B
0005433923417	24110	29	11E
0005432207680	24110	30	11D
0005433923343	24110	31	11F
0005433923599	24110	32	11H
0005433923042	24110	33	11G
0005433922978	24110	34	12A
0005433923061	24110	35	12E
0005433923122	24110	36	12D
0005433923448	24110	37	12F
0005433036673	24110	38	12G
0005433036670	24110	39	13B
0005433923295	24110	40	13D
0005432206236	24110	41	13F
0005433922970	24110	42	13E
0005433036686	24110	43	14A
0005433923466	24110	44	13H
0005433923248	24110	45	13G
0005432207682	24110	46	14B
0005433923377	24110	47	14D
0005433923180	24110	48	14F
0005433036701	24110	49	14E
0005432749801	24110	50	14G
0005433036667	24110	51	15A
0005433922529	24110	52	14H
0005433923349	24110	53	15D
0005433036671	24110	54	15B
0005433922991	24110	55	15E
0005432206240	24110	56	15F
0005433036661	24110	57	15H
0005433923227	24110	58	15G
0005433922842	24110	59	16B
0005433923152	24110	60	16A
0005433923451	24110	61	16E
0005433922885	24110	62	16F
0005433923151	24110	63	16H
0005433931457	24110	64	16G
0005433922884	24110	65	17B
0005433036685	24110	66	17A
0005433923259	24110	67	17D
0005432206235	24110	68	17E
0005433036699	24110	69	17G
0005432206238	24110	70	17F
0005433923173	24110	71	17H
0005433922998	24110	72	18B
0005433036693	24110	73	18D
0005433923104	24110	74	18F
0005433923332	24110	75	18E
0005433922911	24110	76	19A
0005433922986	24110	77	19B
0005433923054	24110	78	19E
0005433036666	24110	79	19D
0005433923169	24110	80	19F
0005433923263	24110	81	19G
0005433923174	24110	82	20A
0005433923101	24110	83	19H
0005433923247	24110	84	20B
0005433036672	24110	85	20D
0005433923225	24110	86	20F
0005433923032	24110	87	20E
0005433923404	24110	88	21A
0005433923581	24110	89	21D
0005433923253	24110	90	21E
0005433036697	24110	91	21F
0005433036679	24110	92	21H
0005433923243	24110	93	22A
0005433923056	24110	94	22D
0005433036696	24110	95	22E
0005433923226	24110	96	22G
0005433923256	24110	97	22F
0005433036677	24110	98	23A
0005433923307	24110	99	22H
0005433923398	24110	100	23B
0005433923057	24110	101	23D
0005433036702	24110	102	23F
0005433923000	24110	103	23G
0005433036684	24110	104	24A
0005433923339	24110	105	23H
0005433036703	24110	106	24E
0005433923041	24110	107	24D
0005433923403	24110	108	24H
0005432749800	24110	109	24G
0005433036687	24110	110	25E
0005433923415	24110	111	25F
0005433923102	24110	112	27B
0005433923244	24110	113	27E
0005433922999	24110	114	27D
0005433922833	24110	115	27F
0005433923033	24110	116	27H
0005432206237	24110	117	27G
0005433923231	24110	118	28A
0005433922636	24110	119	28B
0005433922759	24110	120	28E
0005433923011	24110	121	28D
0005433036678	24110	122	28H
0005432207683	24110	123	28G
0005433036674	24110	124	29A
0005433036662	24110	125	29B
0005433923080	24110	126	29E
0005433036660	24110	127	29G
0005433929596	24110	128	29F
0005433923053	24110	129	30A
0005433923103	24110	130	30D
0005433036700	24110	131	30G
0005433923464	24110	132	31A
0005433923208	24110	133	30H
0005433923447	24110	134	31B
0005433036657	24110	135	31E
0005433923055	24110	136	31D
0005433036659	24110	137	31F
0005433036663	24110	138	31G
0005433923043	24110	139	31H
0005433923155	24110	140	32B
0005433922801	24110	141	32A
0005434028317	24110	142	32E
0005433923511	24110	143	32D
0005433922834	24110	144	32F
0005433036654	24110	145	32H
0005433036676	24110	146	33A
0005433036669	24110	147	33B
0005433036658	24110	148	33E
0005433036691	24110	149	33D
0005433923367	24110	150	33G
0005433036692	24110	151	33F
0005433922880	24110	152	33H
0005433036682	24110	153	34A
0005433923666	24110	154	34D
0005433922704	24110	155	34B
0005433036683	24110	156	34E
0005433036665	24110	157	34G
0005433036704	24110	158	34H
0005433923331	24110	159	35B
0005433923397	24110	160	35D
0005433923197	24110	161	35F
0005433923121	24110	162	35E
0005433923342	24110	163	35G
0005433923299	24110	164	36A
0005433923205	24110	165	36B
0005433923416	24110	166	36F
0005433036664	24110	167	36G
0005433923341	24110	168	37A
0005433036653	24110	169	36H
0005433923300	24110	170	37B
0005433036668	24110	171	37D
0005433923279	24110	172	37F
0005433036695	24110	173	37E
0005433923209	24110	174	37H
0005434028316	24110	175	37G
0005433036689	24110	176	38A
0005433923491	24110	177	38D
0005433923350	24110	178	38B
0005433923340	24110	179	38G
0005433923230	24110	180	39F
0005433234122	301	1	1D
0005434726335	301	2	1C
0005433234344	301	3	1A
0005434551620	301	4	1G
0005433181117	301	5	2A
0005434551656	301	6	1K
0005434551610	301	7	1H
0005434726312	301	8	2D
0005432277906	301	9	2C
0005435142675	301	10	2G
0005433181094	301	11	3A
0005434726345	301	12	2K
0005432277908	301	13	2H
0005433233867	301	14	3D
0005434726347	301	15	3C
0005434551643	301	16	3H
0005434726330	301	17	3G
0005434726362	301	18	4C
0005434726326	301	19	4A
0005434735720	301	20	4G
0005434726304	301	21	4D
0005434726372	301	22	4H
0005434551609	301	23	5H
0005432277912	301	24	11A
0005434726370	301	25	5K
0005434726381	301	26	11D
0005434551647	301	27	11G
0005433234227	301	28	11F
0005434726339	301	29	11E
0005434032030	301	30	11K
0005434551622	301	31	11H
0005434726311	301	32	12C
0005433233968	301	33	12A
0005434032029	301	34	12E
0005434551615	301	35	12D
0005434726301	301	36	12H
0005432277911	301	37	12G
0005433181040	301	38	12F
0005434726331	301	39	12K
0005433181138	301	40	13D
0005433234021	301	41	13C
0005433181155	301	42	13A
0005434726317	301	43	13E
0005434726405	301	44	13H
0005434726313	301	45	13G
0005434551637	301	46	14A
0005434726302	301	47	13K
0005434551640	301	48	14E
0005434302491	301	49	14D
0005434551624	301	50	14C
0005434551638	301	51	14G
0005434551625	301	52	14F
0005434726307	301	53	14K
0005433181053	301	54	14H
0005435142670	301	55	15C
0005433126823	301	56	15A
0005434726290	301	57	15D
0005434726288	301	58	15H
0005433234007	301	59	15G
0005434735722	301	60	15F
0005434726400	301	61	15K
0005433111497	301	62	16D
0005434726388	301	63	16C
0005432277907	301	64	16A
0005433181051	301	65	16G
0005434726294	301	66	16F
0005434551642	301	67	16E
0005433181111	301	68	16H
0005433181001	301	69	17C
0005433181120	301	70	16K
0005434726376	301	71	17D
0005433234192	301	72	17G
0005434551616	301	73	17F
0005434726309	301	74	17E
0005433233753	301	75	18A
0005433181007	301	76	17K
0005434302492	301	77	17H
0005434726402	301	78	18C
0005434032023	301	79	18B
0005432277904	301	80	18D
0005433234128	301	81	18H
0005433766615	301	82	18G
0005433766616	301	83	18F
0005434726394	301	84	18K
0005434726337	301	85	18J
0005433233919	301	86	19B
0005434551653	301	87	19A
0005434726369	301	88	19F
0005433181000	301	89	19E
0005434551605	301	90	19G
0005435142677	301	91	19K
0005434726287	301	92	20C
0005433181052	301	93	20B
0005434726378	301	94	20G
0005434731196	301	95	20F
0005434302490	301	96	20K
0005433234177	301	97	20H
0005434726296	301	98	21B
0005433181012	301	99	21A
0005432277905	301	100	21C
0005433181197	301	101	21F
0005433234187	301	102	21E
0005433181067	301	103	21H
0005434726289	301	104	21G
0005433131694	301	105	22A
0005435142679	301	106	21K
0005433289833	301	107	22D
0005433234135	301	108	22C
0005434551612	301	109	22B
0005434726390	301	110	22E
0005435142672	301	111	22G
0005433181118	301	112	22F
0005434551618	301	113	22J
0005433181137	301	114	22H
0005433234066	301	115	23B
0005433181154	301	116	23A
0005433233764	301	117	23D
0005434551650	301	118	23C
0005434726359	301	119	23F
0005434726396	301	120	23E
0005433181129	301	121	23H
0005433181153	301	122	23G
0005434726348	301	123	24D
0005432277909	301	124	23K
0005434302488	301	125	24F
0005434726363	301	126	24E
0005433181109	301	127	25A
0005433181068	301	128	24G
0005433234048	301	129	25D
0005434726354	301	130	25C
0005435142671	301	131	25B
0005433234311	301	132	25F
0005433234250	301	133	25E
0005433181063	301	134	25H
0005435142678	301	135	25G
0005433234251	301	136	25K
0005433234093	301	137	25J
0005433234193	301	138	26C
0005433111490	301	139	26B
0005434726329	301	140	26A
0005434726406	301	141	26E
0005434726397	301	142	26D
0005434726319	301	143	26G
0005433131709	301	144	26F
0005433234170	301	145	26J
0005434726353	301	146	26H
0005435142673	301	147	27B
0005434551648	301	148	27A
0005434726383	301	149	27D
0005434726373	301	150	27C
0005434551657	301	151	27F
0005433234126	301	152	27E
0005434726395	301	153	27J
0005433234294	301	154	27H
0005434726350	301	155	27G
0005433234234	301	156	28A
0005433289799	301	157	27K
0005435142674	301	158	28C
0005434551649	301	159	28B
0005433289834	301	160	28E
0005433131695	301	161	28D
0005433289830	301	162	28G
0005435142668	301	163	28F
0005434551619	301	164	28J
0005434551634	301	165	28H
0005435142681	301	166	29B
0005434032024	301	167	29A
0005434551630	301	168	28K
0005434726316	301	169	29D
0005433234076	301	170	29C
0005434726338	301	171	29F
0005433233969	301	172	29E
0005433233898	301	173	29H
0005434551654	301	174	29G
0005433234090	301	175	30A
0005434726365	301	176	29K
0005433289800	301	177	29J
0005433234230	301	178	30C
0005434726320	301	179	30B
0005434726333	301	180	30E
0005433233754	301	181	30D
0005434726368	301	182	30G
0005434726340	301	183	30F
0005433234433	301	184	30K
0005434551629	301	185	30J
0005433126842	301	186	31B
0005434726291	301	187	31A
0005433234224	301	188	31F
0005433181085	301	189	31H
0005434551652	301	190	31G
0005434726327	301	191	32A
0005434551608	301	192	31K
0005434726341	301	193	31J
0005433234121	301	194	32C
0005434726308	301	195	32B
0005433766631	301	196	32E
0005434726377	301	197	32D
0005434551611	301	198	32G
0005435142676	301	199	32F
0005434726299	301	200	32J
0005434726315	301	201	33A
0005434032017	301	202	32K
0005434726314	301	203	33C
0005434726324	301	204	33B
0005433233848	301	205	33F
0005433181018	301	206	33E
0005434731199	301	207	33H
0005432277899	301	208	33G
0005434726392	301	209	33K
0005433234065	301	210	33J
0005434726328	301	211	34C
0005434726323	301	212	34B
0005434551607	301	213	34A
0005434731195	301	214	34E
0005433234407	301	215	34D
0005434726303	301	216	34F
0005434726292	301	217	34K
0005433234235	301	218	34J
0005434551651	301	219	35B
0005433234075	301	220	35A
0005434726298	301	221	35E
0005434726355	301	222	35D
0005433234176	301	223	35C
0005432277910	301	224	35F
0005434726399	301	225	35H
0005434551621	301	226	35K
0005434726321	301	227	35J
0005434726366	301	228	36C
0005434726310	301	229	36A
0005433234092	301	230	36F
0005433111491	301	231	36E
0005434726398	301	232	36H
0005433766620	301	233	36G
0005434726385	301	234	36K
0005433766632	301	235	37B
0005433234091	301	236	37A
0005434735724	301	237	37E
0005433180914	301	238	37D
0005434726297	301	239	37C
0005434726336	301	240	37G
0005434735721	301	241	37F
0005434726384	301	242	37J
0005434726318	301	243	37H
0005434726389	301	244	37K
0005433181119	301	245	38C
0005433181198	301	246	38B
0005433180913	301	247	38A
0005434726300	301	248	39A
0005434726408	301	249	38K
0005434726374	301	250	39D
0005433126843	301	251	39C
0005434726361	301	252	39F
0005434726295	301	253	39E
0005434726403	301	254	39H
0005434032022	301	255	39G
0005433233967	301	256	40A
0005433234396	301	257	39K
0005434551641	301	258	39J
0005434551632	301	259	40C
0005432277903	301	260	40B
0005434551628	301	261	40E
0005433289831	301	262	40D
0005434551631	301	263	40H
0005434726367	301	264	40G
0005434551617	301	265	40F
0005434551646	301	266	40K
0005433233920	301	267	40J
0005434726305	301	268	41B
0005434726386	301	269	41A
0005433233918	301	270	41D
0005434032016	301	271	41C
0005434551614	301	272	41F
0005434726325	301	273	41E
0005433126838	301	274	41J
0005434726343	301	275	41H
0005434726371	301	276	41G
0005433181110	301	277	42A
0005434032014	301	278	41K
0005434726349	301	279	42C
0005434726344	301	280	42B
0005433181055	301	281	42E
0005433181015	301	282	42D
0005435142680	301	283	42G
0005434735723	301	284	42F
0005434726393	301	285	42J
0005433234083	301	286	42H
0005433233866	301	287	43A
0005434726293	301	288	42K
0005433181019	301	289	43D
0005434726346	301	290	43C
0005433126837	301	291	43B
0005433233897	301	292	43F
0005434726322	301	293	43E
0005433181041	301	294	43H
0005433131710	301	295	43G
0005433233917	301	296	43K
0005434726332	301	297	44C
0005433181016	301	298	44A
0005434726351	301	299	44E
0005434726306	301	300	44D
0005434726357	301	301	44H
0005434726379	301	302	44G
0005434726401	301	303	44K
0005433234408	301	304	44J
0005434551626	301	305	45A
0005433234367	301	306	45D
0005433131715	301	307	45C
0005434032018	301	308	45F
0005434726407	301	309	45E
0005432277900	301	310	45H
0005434302489	301	311	45G
0005434726375	301	312	46A
0005434726404	301	313	45K
0005433234226	301	314	45J
0005434726360	301	315	46B
0005434726409	301	316	46E
0005433289814	301	317	46D
0005433131706	301	318	46C
0005434731197	301	319	46G
0005434726358	301	320	46F
0005434731198	301	321	46J
0005432277901	301	322	46H
0005434726364	301	323	47A
0005434726382	301	324	46K
0005434551627	301	325	47E
0005433181128	301	326	47G
0005434551645	301	327	47F
0005434726352	301	328	47K
0005433181013	301	329	47H
0005434726391	301	330	48C
0005433180925	301	331	48A
0005434551606	301	332	48E
0005433233921	301	333	48D
0005434551644	301	334	48H
0005434726380	301	335	48G
0005433233776	301	336	48F
0005434726356	301	337	49A
0005433181075	301	338	48K
0005433233777	301	339	49E
0005433181086	301	340	49D
0005434551636	301	341	49C
0005435142669	301	342	49G
0005434551655	301	343	49F
0005432277902	301	344	49K
0005434726334	301	345	49H
0005433181024	301	346	50C
0005434551633	301	347	50A
0005434551635	301	348	50E
0005433766619	301	349	50D
0005434551623	301	350	50G
0005433234131	301	351	50F
0005433181062	301	352	51D
0005434551639	301	353	50K
0005434726387	301	354	50H
0005433113533	301	355	51F
0005434551613	301	356	51E
0005434726342	301	357	51G
0005434551189	9860	1	1C
0005433181269	9860	2	1A
0005435142549	9860	3	1G
0005433234643	9860	4	1D
0005433234689	9860	5	2A
0005433126878	9860	6	1K
0005433234676	9860	7	1H
0005434725245	9860	8	2D
0005433234668	9860	9	2C
0005434725725	9860	10	2H
0005434725658	9860	11	2G
0005433234679	9860	12	3A
0005433234642	9860	13	2K
0005433181268	9860	14	3D
0005433126875	9860	15	3C
0005434725503	9860	16	3K
0005434725649	9860	17	3G
0005434725251	9860	18	4C
0005434724889	9860	19	4A
0005434725791	9860	20	4G
0005434725740	9860	21	4D
0005434551377	9860	22	4H
0005435142553	9860	23	5C
0005434551001	9860	24	5H
0005433126876	9860	25	5G
0005435142488	9860	26	11A
0005434725215	9860	27	5K
0005434551059	9860	28	11D
0005434551064	9860	29	11C
0005433234660	9860	30	11G
0005434724901	9860	31	11F
0005434725228	9860	32	11H
0005434725738	9860	33	12C
0005433234682	9860	34	12A
0005433181293	9860	35	12E
0005434551058	9860	36	12D
0005435142501	9860	37	12G
0005434725552	9860	38	12F
0005434550935	9860	39	12K
0005433234678	9860	40	13F
0005434725059	9860	41	13E
0005433129310	9860	42	13D
0005434551174	9860	43	13G
0005433289897	9860	44	14A
0005434725032	9860	45	14C
0005433181288	9860	46	14G
0005434550917	9860	47	14F
0005433234685	9860	48	14E
0005434551280	9860	49	14K
0005433181277	9860	50	14H
0005433234657	9860	51	15A
0005434725605	9860	52	15E
0005434725220	9860	53	15D
0005434551126	9860	54	15H
0005434725194	9860	55	15G
0005434731153	9860	56	15F
0005434725060	9860	57	15K
0005434725048	9860	58	16D
0005434725016	9860	59	16C
0005433234638	9860	60	16A
0005434725660	9860	61	16F
0005433234637	9860	62	16E
0005434735675	9860	63	16K
0005434551281	9860	64	16H
0005434725345	9860	65	17E
0005434725314	9860	66	17D
0005434725203	9860	67	17C
0005434725737	9860	68	17F
0005433234661	9860	69	17K
0005435142572	9860	70	17H
0005434725147	9860	71	18B
0005434724911	9860	72	18A
0005433234634	9860	73	18E
0005434551191	9860	74	18D
0005433181283	9860	75	18C
0005433234654	9860	76	18G
0005433113553	9860	77	18F
0005433234687	9860	78	18J
0005434731157	9860	79	18H
0005434725726	9860	80	19A
0005432199301	9860	81	18K
0005435142571	9860	82	19D
0005433289900	9860	83	19C
0005434725201	9860	84	19F
0005434551311	9860	85	19H
0005434551063	9860	86	19G
0005434725487	9860	87	20A
0005433181284	9860	88	19K
0005434551228	9860	89	20C
0005434725501	9860	90	20B
0005433234670	9860	91	20E
0005434725489	9860	92	20D
0005434551151	9860	93	20G
0005434725845	9860	94	20F
0005433181278	9860	95	20J
0005434725145	9860	96	20H
0005433234672	9860	97	21A
0005433234641	9860	98	21D
0005434551152	9860	99	21C
0005434551192	9860	100	21F
0005433234640	9860	101	21E
0005433181280	9860	102	21J
0005434725575	9860	103	21H
0005434725562	9860	104	22A
0005433234674	9860	105	21K
0005433289901	9860	106	22B
0005433234645	9860	107	22E
0005434551007	9860	108	22D
0005434725177	9860	109	22G
0005433234649	9860	110	22F
0005433181270	9860	111	22K
0005433234651	9860	112	22H
0005433234626	9860	113	23A
0005434725813	9860	114	23D
0005434725146	9860	115	23C
0005434725563	9860	116	23G
0005434725053	9860	117	23F
0005433234650	9860	118	23E
0005433181273	9860	119	23J
0005434725164	9860	120	23K
0005434725584	9860	121	24F
0005434725459	9860	122	24E
0005433234647	9860	123	25A
0005434550964	9860	124	24G
0005433234666	9860	125	25D
0005433234631	9860	126	25C
0005434551006	9860	127	25B
0005434550868	9860	128	25F
0005433234659	9860	129	25E
0005434302429	9860	130	25G
0005433181281	9860	131	26A
0005433234675	9860	132	25K
0005433766666	9860	133	25J
0005434725077	9860	134	26D
0005434551326	9860	135	26G
0005433129308	9860	136	26F
0005433234644	9860	137	26K
0005433181290	9860	138	26J
0005434724789	9860	139	27A
0005433234652	9860	140	27D
0005434551162	9860	141	27C
0005435142540	9860	142	27B
0005434724902	9860	143	27F
0005434725654	9860	144	27E
0005435142573	9860	145	27H
0005433181271	9860	146	27G
0005434725125	9860	147	27K
0005434551144	9860	148	27J
0005433181287	9860	149	28B
0005434725138	9860	150	28A
0005434725344	9860	151	28E
0005434725296	9860	152	28D
0005433234665	9860	153	28H
0005434725126	9860	154	28G
0005435142479	9860	155	28F
0005434725299	9860	156	28K
0005434725797	9860	157	29A
0005434724729	9860	158	29D
0005434725142	9860	159	29C
0005434725751	9860	160	29B
0005434725411	9860	161	29F
0005433289899	9860	162	29E
0005434725410	9860	163	29J
0005434725319	9860	164	29H
0005433766667	9860	165	29G
0005433234636	9860	166	30C
0005433234627	9860	167	30B
0005434735672	9860	168	30E
0005434725148	9860	169	30D
0005433181286	9860	170	30G
0005434725095	9860	171	30J
0005434551145	9860	172	30H
0005434724788	9860	173	31A
0005433234664	9860	174	30K
0005434725295	9860	175	31D
0005433766668	9860	176	31C
0005434725127	9860	177	31F
0005434725313	9860	178	31E
0005434725139	9860	179	31J
0005434725096	9860	180	31H
0005433181285	9860	181	32A
0005433234681	9860	182	32C
0005434724910	9860	183	32B
0005434724972	9860	184	32E
0005432199298	9860	185	32G
0005434735693	9860	186	32F
0005434725484	9860	187	32K
0005433234677	9860	188	32J
0005434725812	9860	189	32H
0005433181294	9860	190	33D
0005433289895	9860	191	33C
0005433181282	9860	192	33G
0005433234663	9860	193	33F
0005433234671	9860	194	33J
0005434725331	9860	195	33H
0005434550915	9860	196	33K
0005432199299	9860	197	34B
0005434550980	9860	198	34A
0005434725280	9860	199	34D
0005434551104	9860	200	34G
0005434725739	9860	201	34F
0005434551097	9860	202	34J
0005433234628	9860	203	34H
0005434725685	9860	204	35B
0005433234656	9860	205	35A
0005433234684	9860	206	34K
0005434724994	9860	207	35D
0005434725906	9860	208	35C
0005434725017	9860	209	35F
0005434551098	9860	210	35E
0005434032057	9860	211	35J
0005434551327	9860	212	35G
0005433234630	9860	213	36A
0005434725534	9860	214	35K
0005434551184	9860	215	36C
0005434725619	9860	216	36B
0005434032056	9860	217	36F
0005434725233	9860	218	36E
0005433289898	9860	219	36D
0005435142502	9860	220	36H
0005433234683	9860	221	36G
0005434551202	9860	222	37B
0005435142589	9860	223	37A
0005434725428	9860	224	36K
0005433234632	9860	225	37D
0005435142480	9860	226	37C
0005432199296	9860	227	37F
0005434724658	9860	228	37E
0005434550946	9860	229	37J
0005434725902	9860	230	37H
0005433234648	9860	231	38B
0005433234629	9860	232	38J
0005433234655	9860	233	38H
0005433181289	9860	234	38K
0005433289896	9860	235	39C
0005434725870	9860	236	39F
0005433181295	9860	237	39H
0005434550998	9860	238	39G
0005434725209	9860	239	40A
0005434725460	9860	240	39K
0005433234688	9860	241	39J
0005434550951	9860	242	40B
0005433113551	9860	243	40E
0005433234653	9860	244	40D
0005434725131	9860	245	40H
0005434725325	9860	246	40G
0005435142567	9860	247	40F
0005434724993	9860	248	40J
0005434725502	9860	249	41B
0005434725202	9860	250	41A
0005434725452	9860	251	41D
0005434725393	9860	252	41C
0005434725385	9860	253	41F
0005433181291	9860	254	41E
0005433181279	9860	255	41G
0005434725594	9860	256	42A
0005433234646	9860	257	41K
0005435142541	9860	258	41J
0005435142536	9860	259	42B
0005433181272	9860	260	42E
0005433126879	9860	261	42D
0005434550878	9860	262	42G
0005434551219	9860	263	42F
0005434725346	9860	264	43B
0005432199295	9860	265	43A
0005434725618	9860	266	43C
0005433126877	9860	267	43E
0005434725072	9860	268	43D
0005434725143	9860	269	43H
0005434551000	9860	270	43K
0005434725232	9860	271	43J
0005434725178	9860	272	44B
0005434725695	9860	273	44A
0005434725003	9860	274	44E
0005433234686	9860	275	44D
0005433766669	9860	276	44G
0005434725655	9860	277	44F
0005435142547	9860	278	45B
0005434725058	9860	279	45A
0005433129309	9860	280	45C
0005433234667	9860	281	45F
0005434725483	9860	282	45E
0005434725846	9860	283	45D
0005435142557	9860	284	46A
0005433181292	9860	285	45K
0005434725392	9860	286	45J
0005433234635	9860	287	46B
0005433181276	9860	288	46E
0005434725033	9860	289	46D
0005433234662	9860	290	46C
0005434735674	9860	291	46H
0005434032060	9860	292	46J
0005433234658	9860	293	47C
0005433234633	9860	294	47A
0005433113552	9860	295	46K
0005433234680	9860	296	47D
0005434725891	9860	297	47F
0005434725390	9860	298	47E
0005433234639	9860	299	47H
0005433129307	9860	300	48E
0005433181274	9860	301	48D
0005433234669	9860	302	48H
0005433181275	9860	303	48G
0005434551127	9860	304	48F
0005434551190	9860	305	49A
0005434551048	9860	306	48K
0005434725533	9860	307	49E
0005434725165	9860	308	49C
0005435142552	9860	309	49F
0005432199297	9860	310	49H
0005434725350	9860	311	49G
0005434725246	9860	312	50C
0005434551075	9860	313	50E
0005434032059	9860	314	50D
0005433234673	9860	315	50G
0005434302428	9860	316	50F
0005434724659	9860	317	51D
0005434725504	9860	318	50K
0005432199300	9860	319	51E
0005434032058	9860	320	51G
0005434551268	9860	321	51F
0005432528944	7776	1	1A
0005434068069	7776	2	1G
0005434068090	7776	3	1D
0005432528939	7776	4	1H
0005435213314	7776	5	2D
0005434068054	7776	6	2A
0005435725595	7776	7	2H
0005432528866	7776	8	2G
0005432528909	7776	9	2K
0005432528938	7776	10	3D
0005435213643	7776	11	3C
0005432528855	7776	12	3H
0005432528979	7776	13	4A
0005432528877	7776	14	4G
0005432150248	7776	15	4D
0005434068095	7776	16	4K
0005434068046	7776	17	4H
0005434068040	7776	18	5D
0005435725596	7776	19	5C
0005435725590	7776	20	5A
0005434068085	7776	21	5H
0005432150247	7776	22	5G
0005434068089	7776	23	5K
0005432428952	7776	24	11C
0005432528959	7776	25	11G
0005432528881	7776	26	11F
0005432528941	7776	27	11E
0005435212977	7776	28	11H
0005432428953	7776	29	12C
0005432528915	7776	30	12A
0005434068103	7776	31	12F
0005434068101	7776	32	12E
0005432528965	7776	33	12D
0005433656675	7776	34	12G
0005435213596	7776	35	12K
0005432528964	7776	36	12H
0005432528930	7776	37	13D
0005435725570	7776	38	13C
0005432528890	7776	39	13A
0005432528950	7776	40	13F
0005435630977	7776	41	13E
0005435213557	7776	42	13H
0005432528872	7776	43	13G
0005432150251	7776	44	13K
0005435213104	7776	45	14E
0005434068075	7776	46	14C
0005432528986	7776	47	14G
0005432528880	7776	48	14F
0005435213646	7776	49	14K
0005434068048	7776	50	14H
0005432528926	7776	51	15C
0005432528883	7776	52	15A
0005432528894	7776	53	15D
0005432528958	7776	54	15H
0005435213684	7776	55	15G
0005435213508	7776	56	16A
0005434068086	7776	57	16C
0005435213630	7776	58	16F
0005432528898	7776	59	16H
0005434068056	7776	60	16G
0005432528901	7776	61	17A
0005435213407	7776	62	17E
0005432528936	7776	63	17D
0005432528864	7776	64	17C
0005434068073	7776	65	17G
0005432528940	7776	66	17F
0005435725566	7776	67	17K
0005435213498	7776	68	17H
0005435213635	7776	69	18B
0005432528935	7776	70	18A
0005432528924	7776	71	18E
0005432533313	7776	72	18D
0005434068108	7776	73	18G
0005432528934	7776	74	18F
0005435725574	7776	75	18K
0005434068041	7776	76	18J
0005432528956	7776	77	18H
0005434068051	7776	78	19A
0005435213358	7776	79	19D
0005432535870	7776	80	19C
0005432528884	7776	81	19B
0005435213696	7776	82	19F
0005432528857	7776	83	19E
0005435725597	7776	84	19H
0005434068083	7776	85	19G
0005432528953	7776	86	19J
0005434068076	7776	87	20B
0005432528954	7776	88	20A
0005432528922	7776	89	20E
0005432150252	7776	90	20D
0005432535871	7776	91	20G
0005432528963	7776	92	20F
0005435213091	7776	93	20K
0005432528960	7776	94	20J
0005432069758	7776	95	20H
0005432069754	7776	96	21B
0005435213513	7776	97	21A
0005432528900	7776	98	21D
0005435213491	7776	99	21C
0005432528942	7776	100	21F
0005432528987	7776	101	21E
0005434068057	7776	102	21G
0005432069759	7776	103	22A
0005435725575	7776	104	21K
0005432528875	7776	105	21J
0005435213467	7776	106	22C
0005432528917	7776	107	22E
0005434068047	7776	108	22D
0005432528951	7776	109	22G
0005434068100	7776	110	22K
0005434068065	7776	111	22J
0005432528955	7776	112	22H
0005435213430	7776	113	23B
0005434068094	7776	114	23A
0005432069755	7776	115	23C
0005432528908	7776	116	23G
0005434068061	7776	117	23E
0005435213298	7776	118	23H
0005434068093	7776	119	24D
0005435213256	7776	120	23K
0005432069756	7776	121	23J
0005434068045	7776	122	24F
0005432528906	7776	123	24E
0005434068074	7776	124	25B
0005435725576	7776	125	25A
0005434068068	7776	126	24G
0005435213201	7776	127	25D
0005432535868	7776	128	25G
0005432528949	7776	129	25K
0005432528985	7776	130	26C
0005435213539	7776	131	26B
0005432528978	7776	132	26A
0005435213533	7776	133	26E
0005432528905	7776	134	26D
0005432528899	7776	135	26G
0005433656676	7776	136	26F
0005432528980	7776	137	26K
0005432069760	7776	138	26J
0005432528911	7776	139	26H
0005432528929	7776	140	27B
0005432528867	7776	141	27D
0005435213610	7776	142	27F
0005434068043	7776	143	27E
0005432528871	7776	144	27H
0005434068039	7776	145	27K
0005435213316	7776	146	27J
0005435725593	7776	147	28C
0005432069752	7776	148	28B
0005432528919	7776	149	28A
0005432537073	7776	150	28E
0005435213532	7776	151	28D
0005432528948	7776	152	28G
0005432528932	7776	153	28F
0005434068077	7776	154	28H
0005432528969	7776	155	29A
0005432528897	7776	156	29D
0005432428954	7776	157	29C
0005432528957	7776	158	29F
0005434068063	7776	159	29E
0005432069765	7776	160	29H
0005432528983	7776	161	29K
0005432528876	7776	162	30C
0005432528927	7776	163	30B
0005432528892	7776	164	30A
0005435213540	7776	165	30D
0005432528856	7776	166	30G
0005432528914	7776	167	30F
0005432528981	7776	168	30J
0005435213392	7776	169	30H
0005434068066	7776	170	31B
0005432528885	7776	171	31A
0005435213644	7776	172	30K
0005432528863	7776	173	31D
0005432528891	7776	174	31F
0005435725567	7776	175	31E
0005432528887	7776	176	31J
0005432528896	7776	177	31H
0005435213551	7776	178	31G
0005434068104	7776	179	32A
0005434068096	7776	180	31K
0005435630966	7776	181	32B
0005435213783	7776	182	32E
0005435213362	7776	183	32D
0005432069761	7776	184	32H
0005432528918	7776	185	32G
0005432528859	7776	186	32F
0005435213782	7776	187	32J
0005432528961	7776	188	33A
0005435213535	7776	189	32K
0005434068081	7776	190	33D
0005434068091	7776	191	33C
0005432528902	7776	192	33B
0005432528886	7776	193	33F
0005434068084	7776	194	33H
0005432535866	7776	195	33K
0005432528976	7776	196	33J
0005434068105	7776	197	34C
0005434068049	7776	198	34B
0005432535869	7776	199	34A
0005432528869	7776	200	34E
0005435213634	7776	201	34H
0005432528862	7776	202	34G
0005435213468	7776	203	34F
0005435213382	7776	204	34J
0005434068050	7776	205	35A
0005435630965	7776	206	35D
0005434068052	7776	207	35C
0005432528925	7776	208	35B
0005434068059	7776	209	35G
0005434068058	7776	210	35F
0005432537072	7776	211	35E
0005435213340	7776	212	35H
0005435213685	7776	213	36A
0005432528928	7776	214	35K
0005432528967	7776	215	35J
0005434068079	7776	216	36C
0005432528943	7776	217	36B
0005432528920	7776	218	36E
0005432528912	7776	219	36D
0005434068072	7776	220	36H
0005432528937	7776	221	36G
0005432528952	7776	222	36F
0005434068042	7776	223	36J
0005432528946	7776	224	37B
0005434068053	7776	225	37D
0005432150254	7776	226	37F
0005435213631	7776	227	37E
0005435213466	7776	228	37J
0005435213885	7776	229	37H
0005432528973	7776	230	37G
0005432150249	7776	231	38A
0005435725571	7776	232	37K
0005432528868	7776	233	38C
0005432528870	7776	234	38K
0005432528893	7776	235	38J
0005434068067	7776	236	38H
0005435213478	7776	237	39B
0005435213621	7776	238	39D
0005435213507	7776	239	39C
0005434068087	7776	240	39F
0005435213395	7776	241	39E
0005432150253	7776	242	39J
0005432528962	7776	243	39H
0005435213580	7776	244	39K
0005432528904	7776	245	40B
0005432069763	7776	246	40G
0005434068107	7776	247	40F
0005432069766	7776	248	40J
0005432528916	7776	249	40H
0005432528982	7776	250	41A
0005434068082	7776	251	40K
0005432069757	7776	252	41D
0005435213544	7776	253	41B
0005432069753	7776	254	41G
0005432528933	7776	255	41F
0005434068098	7776	256	41E
0005435630948	7776	257	41J
0005432069764	7776	258	42A
0005432528971	7776	259	42C
0005434068062	7776	260	42B
0005435213443	7776	261	42E
0005432528975	7776	262	42D
0005435725585	7776	263	42G
0005435213145	7776	264	42F
0005432533312	7776	265	42J
0005432528861	7776	266	42H
0005432528882	7776	267	43B
0005434068088	7776	268	43A
0005434068106	7776	269	42K
0005435213552	7776	270	43D
0005432528970	7776	271	43E
0005432528874	7776	272	43H
0005434068078	7776	273	43G
0005432528931	7776	274	43K
0005435213326	7776	275	43J
0005432150250	7776	276	44C
0005432528889	7776	277	44B
0005432528910	7776	278	44A
0005435213069	7776	279	44E
0005435213444	7776	280	44D
0005434068055	7776	281	44G
0005432528860	7776	282	44F
0005435213448	7776	283	44J
0005435213687	7776	284	44H
0005432528984	7776	285	45A
0005432528977	7776	286	44K
0005432528865	7776	287	45D
0005434068060	7776	288	45C
0005434068099	7776	289	45B
0005432528921	7776	290	45F
0005435630967	7776	291	45E
0005434068044	7776	292	45H
0005433656670	7776	293	45G
0005432528945	7776	294	46A
0005432528974	7776	295	45J
0005435213548	7776	296	46C
0005435213408	7776	297	46B
0005432528972	7776	298	46E
0005434068038	7776	299	46D
0005432528879	7776	300	46G
0005432528878	7776	301	46F
0005432528966	7776	302	46J
0005432528858	7776	303	46H
0005432528853	7776	304	47C
0005435213697	7776	305	47A
0005434068092	7776	306	46K
0005434068070	7776	307	47E
0005432528913	7776	308	47D
0005434068102	7776	309	47F
0005432528895	7776	310	48A
0005434068080	7776	311	47K
0005434068071	7776	312	47H
0005435213490	7776	313	48C
0005432528923	7776	314	48F
0005432528873	7776	315	48E
0005435213499	7776	316	48D
0005435213375	7776	317	48H
0005432069762	7776	318	48G
0005432528888	7776	319	48K
0005432528903	7776	320	49E
0005435213595	7776	321	49C
0005435213359	7776	322	49K
0005432528907	7776	323	49H
0005435213543	7776	324	49G
0005435725598	7776	325	50C
0005432528968	7776	326	50A
0005432528854	7776	327	50F
0005432528947	7776	328	50E
0005432535867	7776	329	50D
0005434068097	7776	330	50G
0005435213706	7776	331	50K
0005434068064	7776	332	51F
0005435213492	7776	333	51E
0005434068109	7776	334	51G
0005435614421	5332	1	1C
0005435319529	5332	2	1A
0005435614434	5332	3	1D
0005435424914	5332	4	1K
0005435319542	5332	5	1H
0005432133325	5332	6	2C
0005435614458	5332	7	2A
0005435380304	5332	8	2G
0005435424737	5332	9	2D
0005435614502	5332	10	2K
0005432133320	5332	11	3G
0005435319544	5332	12	3D
0005435302186	5332	13	3C
0005435424672	5332	14	3H
0005435614466	5332	15	3K
0005434245039	5332	16	4G
0005435614440	5332	17	4D
0005435614487	5332	18	4C
0005435491454	5332	19	4K
0005435614437	5332	20	4H
0005434244931	5332	21	5D
0005432133313	5332	22	5C
0005432841005	5332	23	5A
0005435614517	5332	24	5H
0005435614479	5332	25	11A
0005432133319	5332	26	5K
0005435614427	5332	27	11D
0005435614500	5332	28	11C
0005434244952	5332	29	11G
0005434344496	5332	30	11F
0005433719133	5332	31	11K
0005435424823	5332	32	12A
0005435424828	5332	33	12E
0005435614477	5332	34	12D
0005432133323	5332	35	12G
0005435424931	5332	36	12K
0005435424562	5332	37	12H
0005435424838	5332	38	13D
0005435614463	5332	39	13C
0005435424673	5332	40	13A
0005435424915	5332	41	13F
0005435490256	5332	42	13H
0005435424963	5332	43	13G
0005434244948	5332	44	14A
0005435614478	5332	45	13K
0005435614503	5332	46	14D
0005435380274	5332	47	14C
0005435614514	5332	48	14G
0005434244954	5332	49	14K
0005435614452	5332	50	14H
0005435424829	5332	51	15C
0005435424731	5332	52	15A
0005435424678	5332	53	15E
0005435614442	5332	54	15D
0005435424807	5332	55	15F
0005435380273	5332	56	16A
0005435424642	5332	57	15K
0005435424714	5332	58	16D
0005434344475	5332	59	16C
0005435614481	5332	60	16F
0005432133317	5332	61	16E
0005435490253	5332	62	16K
0005435614483	5332	63	16H
0005435305008	5332	64	16G
0005435424827	5332	65	17A
0005435380303	5332	66	17E
0005435424748	5332	67	17D
0005434573455	5332	68	17C
0005434344495	5332	69	17G
0005435302180	5332	70	17F
0005435614432	5332	71	17K
0005435424932	5332	72	18B
0005435424755	5332	73	18A
0005434244983	5332	74	18D
0005435424826	5332	75	18C
0005435097273	5332	76	18G
0005435614454	5332	77	18F
0005435424900	5332	78	18J
0005432133324	5332	79	18H
0005432047578	5332	80	19B
0005432133326	5332	81	19C
0005435424772	5332	82	19F
0005434344483	5332	83	19E
0005435614422	5332	84	19H
0005435424916	5332	85	19G
0005435614495	5332	86	20A
0005434344488	5332	87	19K
0005434244935	5332	88	19J
0005435305009	5332	89	20C
0005435614464	5332	90	20B
0005432363412	5332	91	20E
0005435614439	5332	92	20D
0005434344487	5332	93	20H
0005435614497	5332	94	20F
0005435614526	5332	95	21B
0005435614509	5332	96	21A
0005435424729	5332	97	21D
0005434245017	5332	98	21C
0005435614527	5332	99	21F
0005435424590	5332	100	21E
0005435614446	5332	101	22A
0005434344477	5332	102	21K
0005435424609	5332	103	22C
0005435490254	5332	104	22D
0005435097279	5332	105	22G
0005435614435	5332	106	22F
0005435555384	5332	107	22K
0005434573452	5332	108	22J
0005434244947	5332	109	23B
0005435424783	5332	110	23A
0005435614426	5332	111	23D
0005435614507	5332	112	23C
0005435424698	5332	113	23E
0005434344489	5332	114	23J
0005435424653	5332	115	23H
0005435614508	5332	116	23G
0005435424793	5332	117	23K
0005435614493	5332	118	24F
0005435614445	5332	119	24E
0005435614499	5332	120	25A
0005435614428	5332	121	24G
0005435614438	5332	122	25D
0005435614453	5332	123	25B
0005435614484	5332	124	25E
0005435380292	5332	125	25H
0005435614450	5332	126	25G
0005435614529	5332	127	26C
0005432133322	5332	128	26B
0005435424851	5332	129	26A
0005435614511	5332	130	26E
0005434244932	5332	131	26G
0005434573451	5332	132	26F
0005435424602	5332	133	26J
0005435424713	5332	134	26H
0005432133316	5332	135	27D
0005434573458	5332	136	27C
0005435424808	5332	137	27F
0005435614482	5332	138	27E
0005435614431	5332	139	27J
0005435614485	5332	140	27G
0005435097277	5332	141	28A
0005435614510	5332	142	27K
0005434244941	5332	143	28C
0005435614480	5332	144	28B
0005435614473	5332	145	28E
0005434344474	5332	146	28D
0005435042846	5332	147	28G
0005432047577	5332	148	28F
0005432133318	5332	149	28J
0005435424443	5332	150	28H
0005434573454	5332	151	29B
0005435614433	5332	152	29D
0005434344481	5332	153	29C
0005435614451	5332	154	29F
0005435424670	5332	155	29E
0005434656549	5332	156	29H
0005435424564	5332	157	29G
0005434244953	5332	158	29J
0005435424876	5332	159	30C
0005434573460	5332	160	30A
0005435424890	5332	161	30E
0005435380290	5332	162	30F
0005432841004	5332	163	30J
0005435302213	5332	164	30H
0005433719132	5332	165	31A
0005434344494	5332	166	30K
0005435424496	5332	167	31D
0005435614472	5332	168	31C
0005435614519	5332	169	31F
0005434244865	5332	170	31E
0005435424675	5332	171	31H
0005435424674	5332	172	31G
0005434344498	5332	173	32A
0005435305010	5332	174	31K
0005435424601	5332	175	31J
0005435424794	5332	176	32C
0005435424584	5332	177	32B
0005434244852	5332	178	32D
0005434344471	5332	179	32G
0005434344486	5332	180	32F
0005435614521	5332	181	32K
0005435614522	5332	182	32J
0005435424563	5332	183	32H
0005435302181	5332	184	33A
0005435614476	5332	185	33D
0005434573459	5332	186	33C
0005435380272	5332	187	33B
0005432133312	5332	188	33F
0005435614424	5332	189	33E
0005435614489	5332	190	33J
0005435380285	5332	191	33G
0005434344493	5332	192	33K
0005435614491	5332	193	34C
0005434344479	5332	194	34B
0005435614475	5332	195	34A
0005435380291	5332	196	34D
0005434245038	5332	197	34H
0005435614506	5332	198	34G
0005434244925	5332	199	34F
0005435614513	5332	200	34J
0005435614420	5332	201	35B
0005435380289	5332	202	34K
0005435424810	5332	203	35D
0005435424444	5332	204	35C
0005435097269	5332	205	35F
0005435614496	5332	206	35H
0005435614460	5332	207	35G
0005435614468	5332	208	35K
0005435614447	5332	209	35J
0005434244893	5332	210	36C
0005435614505	5332	211	36B
0005434573449	5332	212	36A
0005435424824	5332	213	36E
0005434244929	5332	214	36D
0005435424771	5332	215	36F
0005434573450	5332	216	36J
0005435424608	5332	217	37B
0005435614528	5332	218	37A
0005434344480	5332	219	36K
0005435424699	5332	220	37C
0005435614467	5332	221	37G
0005435490255	5332	222	37F
0005435097276	5332	223	37E
0005434245016	5332	224	37J
0005435614425	5332	225	37H
0005434344472	5332	226	38A
0005434245005	5332	227	37K
0005435424921	5332	228	38H
0005435614469	5332	229	38C
0005435614471	5332	230	38B
0005435424822	5332	231	38J
0005435614470	5332	232	39B
0005435424715	5332	233	39A
0005435614486	5332	234	38K
0005432133321	5332	235	39C
0005434244980	5332	236	39F
0005434344470	5332	237	39E
0005435614518	5332	238	39D
0005435614455	5332	239	39J
0005435614474	5332	240	39H
0005434344492	5332	241	39G
0005435424730	5332	242	40A
0005434244981	5332	243	39K
0005435614512	5332	244	40C
0005434344476	5332	245	40B
0005435097278	5332	246	40E
0005435424825	5332	247	40D
0005434344482	5332	248	40F
0005435424738	5332	249	40J
0005435424543	5332	250	40H
0005434244946	5332	251	41B
0005435614520	5332	252	41A
0005435614494	5332	253	40K
0005434244930	5332	254	41D
0005435614449	5332	255	41C
0005432133315	5332	256	41F
0005434344490	5332	257	41E
0005435614436	5332	258	41J
0005435319585	5332	259	41H
0005435614461	5332	260	41G
0005435614465	5332	261	42A
0005434344497	5332	262	41K
0005434573461	5332	263	42C
0005432133314	5332	264	42B
0005434244985	5332	265	42E
0005435097275	5332	266	42D
0005432047576	5332	267	42G
0005434573457	5332	268	42F
0005435614462	5332	269	42K
0005434573448	5332	270	42J
0005434244972	5332	271	42H
0005432363417	5332	272	43A
0005435614443	5332	273	43C
0005435614444	5332	274	43B
0005434344491	5332	275	43F
0005435614524	5332	276	43E
0005435614441	5332	277	43D
0005435491453	5332	278	43H
0005435305011	5332	279	43G
0005434573456	5332	280	43K
0005435614504	5332	281	43J
0005435555383	5332	282	44B
0005435614457	5332	283	44A
0005434244945	5332	284	44E
0005435424816	5332	285	44D
0005434656548	5332	286	44C
0005434244955	5332	287	44J
0005434244962	5332	288	44K
0005435614459	5332	289	45B
0005435097268	5332	290	45F
0005432133327	5332	291	45H
0005435490257	5332	292	45G
0005435424815	5332	293	45K
0005433719131	5332	294	46C
0005435614430	5332	295	46B
0005435614456	5332	296	46A
0005435614498	5332	297	46E
0005435319541	5332	298	46D
0005434244973	5332	299	46F
0005434344484	5332	300	46H
0005434573453	5332	301	47C
0005435097272	5332	302	47A
0005435424887	5332	303	46K
0005434244984	5332	304	47G
0005435614490	5332	305	47F
0005435424994	5332	306	47E
0005435614448	5332	307	47K
0005434344478	5332	308	47H
0005435614429	5332	309	48A
0005435302185	5332	310	48D
0005435097271	5332	311	48G
0005435425013	5332	312	48F
0005435614501	5332	313	49C
0005434344485	5332	314	49A
0005435614488	5332	315	48K
0005435097270	5332	316	49D
0005434344473	5332	317	49E
0005434244916	5332	318	49K
0005435614492	5332	319	49H
0005435614525	5332	320	49G
0005435614423	5332	321	50D
0005434656547	5332	322	50A
0005435614516	5332	323	50E
0005435555382	5332	324	50H
0005435614515	5332	325	50G
0005435097274	5332	326	50F
0005435424583	5332	327	51D
0005435614523	5332	328	50K
0005434244861	5332	329	51E
0005435424837	5332	330	51G
0005434245177	10915	1	42F
0005434344163	10915	2	1D
0005435613398	10915	3	1C
0005435425304	10915	4	1G
0005435425297	10915	5	1K
0005435613029	10915	6	1H
0005435425315	10915	7	2C
0005434344146	10915	8	2G
0005434344001	10915	9	2D
0005435613523	10915	10	2K
0005435613266	10915	11	3D
0005435425329	10915	12	3C
0005435425284	10915	13	3K
0005435425292	10915	14	3G
0005435380323	10915	15	4C
0005434573360	10915	16	4A
0005435613422	10915	17	4K
0005434344007	10915	18	4H
0005435425336	10915	19	5A
0005435425269	10915	20	5G
0005435425271	10915	21	5D
0005435613177	10915	22	11A
0005434344090	10915	23	5K
0005433719164	10915	24	11D
0005435613648	10915	25	11C
0005435425299	10915	26	11E
0005434245197	10915	27	11K
0005435613497	10915	28	11H
0005435613463	10915	29	11G
0005435613214	10915	30	12A
0005435613476	10915	31	12E
0005435613322	10915	32	12D
0005434573341	10915	33	12H
0005435613069	10915	34	12G
0005432363440	10915	35	12F
0005435304187	10915	36	13A
0005435613068	10915	37	12K
0005435613421	10915	38	13D
0005434344035	10915	39	13C
0005435613684	10915	40	13F
0005434245200	10915	41	13E
0005435319639	10915	42	13H
0005435425268	10915	43	13G
0005435425331	10915	44	14A
0005434344008	10915	45	14E
0005435613464	10915	46	14D
0005435425314	10915	47	14C
0005434344114	10915	48	14G
0005435097155	10915	49	14K
0005435555367	10915	50	14H
0005435613075	10915	51	15C
0005435097154	10915	52	15A
0005435613680	10915	53	15E
0005434344168	10915	54	15G
0005435319640	10915	55	15F
0005435425275	10915	56	16A
0005435425278	10915	57	15K
0005435613059	10915	58	16D
0005435613103	10915	59	16F
0005434573340	10915	60	16E
0005435425318	10915	61	16K
0005434344065	10915	62	16H
0005432363439	10915	63	16G
0005435613297	10915	64	17A
0005435613477	10915	65	17E
0005434245193	10915	66	17D
0005435425326	10915	67	17C
0005435425296	10915	68	17G
0005435613451	10915	69	17F
0005435613440	10915	70	17K
0005435613196	10915	71	17H
0005435319637	10915	72	18C
0005434344034	10915	73	18B
0005435555362	10915	74	18A
0005435613442	10915	75	18E
0005435613235	10915	76	18D
0005435613475	10915	77	18F
0005434573299	10915	78	18J
0005435490201	10915	79	18H
0005435613646	10915	80	19A
0005435380324	10915	81	19D
0005433719167	10915	82	19C
0005434245198	10915	83	19B
0005435613543	10915	84	19F
0005433719166	10915	85	19E
0005434573277	10915	86	19H
0005435319641	10915	87	19G
0005435613679	10915	88	19J
0005432165096	10915	89	20C
0005434344144	10915	90	20B
0005435613634	10915	91	20A
0005432363441	10915	92	20G
0005435425327	10915	93	20F
0005435319634	10915	94	20J
0005434344181	10915	95	20H
0005435425312	10915	96	21A
0005434344036	10915	97	21E
0005435380326	10915	98	21D
0005435613642	10915	99	21C
0005435613438	10915	100	21B
0005435425295	10915	101	21G
0005434344069	10915	102	21F
0005435613097	10915	103	21J
0005435613488	10915	104	21H
0005435613151	10915	105	21K
0005435425321	10915	106	22C
0005435613205	10915	107	22B
0005435425302	10915	108	22F
0005434245180	10915	109	22D
0005434343928	10915	110	22H
0005435425309	10915	111	22G
0005435613566	10915	112	22J
0005435425300	10915	113	23B
0005435425328	10915	114	23A
0005434245187	10915	115	23E
0005434344203	10915	116	23D
0005435613420	10915	117	23H
0005434573249	10915	118	23G
0005435425283	10915	119	24D
0005434245207	10915	120	23K
0005435425325	10915	121	23J
0005434245179	10915	122	24F
0005434245199	10915	123	25B
0005434245191	10915	124	25A
0005435319638	10915	125	24G
0005434344029	10915	126	25C
0005435613636	10915	127	25F
0005435425274	10915	128	25E
0005435425285	10915	129	25D
0005434245201	10915	130	25H
0005434573290	10915	131	25K
0005435613512	10915	132	25J
0005434344119	10915	133	26C
0005435425335	10915	134	26B
0005435425323	10915	135	26D
0005435613049	10915	136	26H
0005435613647	10915	137	26F
0005434343977	10915	138	26K
0005435042871	10915	139	26J
0005435613437	10915	140	27B
0005435425311	10915	141	27A
0005435613593	10915	142	27F
0005435425273	10915	143	27E
0005432165093	10915	144	27G
0005435425322	10915	145	27K
0005435613681	10915	146	27J
0005435613478	10915	147	28B
0005435613643	10915	148	28A
0005434344161	10915	149	28D
0005432165089	10915	150	28C
0005434344143	10915	151	28G
0005435319632	10915	152	28F
0005434344176	10915	153	28E
0005435613542	10915	154	28J
0005435425279	10915	155	29B
0005435613557	10915	156	29A
0005435613513	10915	157	29D
0005435425303	10915	158	29G
0005434344215	10915	159	29F
0005435612959	10915	160	29E
0005435613462	10915	161	29J
0005435425291	10915	162	29H
0005435425313	10915	163	30A
0005434245178	10915	164	29K
0005434573252	10915	165	30C
0005435613596	10915	166	30B
0005435425308	10915	167	30E
0005435613412	10915	168	30D
0005435613685	10915	169	30K
0005435613074	10915	170	30J
0005432841028	10915	171	30H
0005435425334	10915	172	31D
0005435425330	10915	173	31C
0005435613416	10915	174	31B
0005435613413	10915	175	31F
0005435613299	10915	176	31E
0005434573328	10915	177	31J
0005435097180	10915	178	31H
0005435425317	10915	179	31G
0005434245203	10915	180	32A
0005435613500	10915	181	31K
0005435613382	10915	182	32C
0005435425282	10915	183	32E
0005434344079	10915	184	32D
0005435425267	10915	185	32G
0005435613236	10915	186	32J
0005434573291	10915	187	32H
0005435425319	10915	188	33B
0005432165091	10915	189	33A
0005435613419	10915	190	32K
0005435380327	10915	191	33D
0005432165094	10915	192	33F
0005435425288	10915	193	33E
0005435425316	10915	194	33H
0005435613383	10915	195	33G
0005435612679	10915	196	34A
0005434573285	10915	197	33K
0005435425333	10915	198	33J
0005434344020	10915	199	34C
0005435613522	10915	200	34B
0005435425307	10915	201	34E
0005432841030	10915	202	34D
0005434344056	10915	203	34F
0005435613558	10915	204	34J
0005435613508	10915	205	34H
0005435613305	10915	206	35B
0005434344091	10915	207	35A
0005435613234	10915	208	34K
0005434245185	10915	209	35C
0005435613043	10915	210	35F
0005435613630	10915	211	35E
0005432841029	10915	212	35J
0005435491438	10915	213	35H
0005434344055	10915	214	35G
0005435613399	10915	215	36C
0005435613682	10915	216	36B
0005435613453	10915	217	36E
0005434344092	10915	218	36D
0005435613417	10915	219	36G
0005434245202	10915	220	36F
0005434573212	10915	221	36K
0005434245186	10915	222	36J
0005435490216	10915	223	36H
0005435097158	10915	224	37B
0005435613396	10915	225	37A
0005435613499	10915	226	37D
0005435613132	10915	227	37C
0005435425301	10915	228	37G
0005435613077	10915	229	37E
0005434245205	10915	230	37J
0005435612961	10915	231	38A
0005435425332	10915	232	37K
0005435613531	10915	233	38C
0005435319636	10915	234	38B
0005435613702	10915	235	38K
0005434573311	10915	236	38J
0005434344064	10915	237	38H
0005435613060	10915	238	39A
0005435425337	10915	239	39D
0005435613381	10915	240	39C
0005434245183	10915	241	39B
0005435319633	10915	242	39F
0005435613298	10915	243	39E
0005435425293	10915	244	39J
0005434573322	10915	245	39G
0005435613541	10915	246	40A
0005435425298	10915	247	39K
0005435613701	10915	248	40C
0005435613540	10915	249	40B
0005435425310	10915	250	40E
0005434573320	10915	251	40G
0005435612964	10915	252	40F
0005435425272	10915	253	40K
0005434245181	10915	254	40J
0005435613185	10915	255	41B
0005434344160	10915	256	41C
0005434245182	10915	257	41G
0005435425276	10915	258	41F
0005435425324	10915	259	41E
0005435425305	10915	260	41J
0005434245204	10915	261	41H
0005434573298	10915	262	42A
0005435613443	10915	263	41K
0005435097156	10915	264	42C
0005434245192	10915	265	42B
0005435613104	10915	266	42E
0005435613265	10915	267	42K
0005434573336	10915	268	42J
0005435613281	10915	269	43D
0005435490229	10915	270	43C
0005432165092	10915	271	43F
0005434344134	10915	272	43E
0005434245194	10915	273	43H
0005434343969	10915	274	43G
0005435425294	10915	275	43K
0005432166926	10915	276	44C
0005434344167	10915	277	44A
0005432166925	10915	278	44E
0005434245189	10915	279	44D
0005434573294	10915	280	44G
0005434573337	10915	281	44J
0005435380325	10915	282	44H
0005435319642	10915	283	45A
0005435425270	10915	284	44K
0005435425281	10915	285	45D
0005434344147	10915	286	45C
0005432165090	10915	287	45B
0005435613501	10915	288	45F
0005435613637	10915	289	45E
0005432165095	10915	290	45J
0005434573326	10915	291	45H
0005434344086	10915	292	45G
0005435613197	10915	293	45K
0005434245196	10915	294	46B
0005435319635	10915	295	46A
0005434344141	10915	296	46E
0005434245188	10915	297	46D
0005434344148	10915	298	46C
0005435491437	10915	299	46G
0005435613023	10915	300	46F
0005435613380	10915	301	46H
0005435097152	10915	302	47A
0005434573325	10915	303	47D
0005432363438	10915	304	47C
0005434573321	10915	305	47G
0005435613454	10915	306	47F
0005435613629	10915	307	47K
0005435425286	10915	308	47H
0005434656571	10915	309	48D
0005435425277	10915	310	48C
0005434344109	10915	311	48F
0005435613635	10915	312	48E
0005435491435	10915	313	48H
0005434344084	10915	314	48G
0005433719165	10915	315	49A
0005434245184	10915	316	48K
0005434245190	10915	317	49D
0005435612987	10915	318	49C
0005434245206	10915	319	49F
0005435613509	10915	320	49E
0005434344216	10915	321	49H
0005435425306	10915	322	49K
0005432166924	10915	323	50F
0005434245195	10915	324	50E
0005435613489	10915	325	50D
0005435425287	10915	326	50H
0005435425320	10915	327	50G
0005435425289	10915	328	51F
0005435613145	10915	329	51E
0005435425290	10915	330	51D
0005435425280	10915	331	51G
0005432459742	3251	1	1C
0005432459611	3251	2	1D
0005432181879	3251	3	2A
0005432181881	3251	4	1F
0005433805628	3251	5	2D
0005433507304	3251	6	2C
0005432459805	3251	7	3A
0005433634067	3251	8	2F
0005433634069	3251	9	3C
0005433634058	3251	10	3F
0005433805623	3251	11	3D
0005432459777	3251	12	4A
0005433634053	3251	13	4C
0005432181868	3251	14	4F
0005433634051	3251	15	4D
0005432181883	3251	16	5A
0005433634055	3251	17	5C
0005433805634	3251	18	5F
0005433634060	3251	19	5D
0005433507305	3251	20	6C
0005432459623	3251	21	6A
0005432181884	3251	22	6F
0005433634075	3251	23	6D
0005432459613	3251	24	7A
0005432181870	3251	25	7C
0005433507318	3251	26	7D
0005433805617	3251	27	8A
0005432459920	3251	28	7F
0005433805638	3251	29	8C
0005433507317	3251	30	8B
0005432181873	3251	31	8E
0005432459546	3251	32	8D
0005432459727	3251	33	8F
0005432459894	3251	34	9B
0005432181875	3251	35	9A
0005433507310	3251	36	9C
0005432181876	3251	37	9E
0005432459754	3251	38	9D
0005432181888	3251	39	9F
0005432459661	3251	40	10A
0005433634076	3251	41	10B
0005432459941	3251	42	10D
0005433634059	3251	43	10C
0005432459780	3251	44	10E
0005433507312	3251	45	10F
0005433507316	3251	46	11B
0005433805635	3251	47	11A
0005433805619	3251	48	11C
0005433634085	3251	49	11D
0005432459867	3251	50	11E
0005432459516	3251	51	12A
0005433507319	3251	52	11F
0005432459919	3251	53	12B
0005433507306	3251	54	12C
0005432181874	3251	55	12E
0005433805633	3251	56	12D
0005432181878	3251	57	12F
0005433805640	3251	58	13B
0005432181869	3251	59	13A
0005432460121	3251	60	13C
0005432459688	3251	61	13D
0005433507320	3251	62	13E
0005432459684	3251	63	14A
0005432459897	3251	64	13F
0005432181885	3251	65	14B
0005432181886	3251	66	14D
0005432181880	3251	67	14C
0005433634072	3251	68	14E
0005433634081	3251	69	14F
0005433634083	3251	70	15A
0005433805616	3251	71	1A
0005432459493	3251	72	15C
0005433507308	3251	73	15B
0005433805629	3251	74	15D
0005432459292	3251	75	15E
0005432459725	3251	76	16A
0005433805637	3251	77	16C
0005433634064	3251	78	16B
0005433805642	3251	79	16E
0005433507303	3251	80	16D
0005432459735	3251	81	16F
0005433507313	3251	82	17A
0005432459612	3251	83	17C
0005433805622	3251	84	17B
0005432181889	3251	85	17D
0005432459617	3251	86	17E
0005433634063	3251	87	18A
0005433634068	3251	88	17F
0005432459980	3251	89	18B
0005433805618	3251	90	18D
0005432459851	3251	91	18C
0005432459547	3251	92	18E
0005433634084	3251	93	18F
0005433634062	3251	94	19B
0005433507321	3251	95	19D
0005433634052	3251	96	19C
0005432459837	3251	97	20A
0005432459762	3251	98	19E
0005433634080	3251	99	20C
0005432459873	3251	100	20B
0005432459807	3251	101	20D
0005433507309	3251	102	20F
0005433634077	3251	103	20E
0005433805621	3251	104	21B
0005432181871	3251	105	21A
0005432460071	3251	106	21C
0005433634066	3251	107	21D
0005432459622	3251	108	21F
0005432459610	3251	109	21E
0005432459750	3251	110	22A
0005433634082	3251	111	22B
0005433507314	3251	112	22D
0005432459721	3251	113	22F
0005432459594	3251	114	22E
0005433634057	3251	115	23A
0005432459763	3251	116	23C
0005432459598	3251	117	23B
0005433805632	3251	118	23D
0005432459548	3251	119	23F
0005432459981	3251	120	23E
0005432460072	3251	121	24A
0005432459806	3251	122	24B
0005433805630	3251	123	24C
0005432459689	3251	124	24D
0005433634074	3251	125	24F
0005432459660	3251	126	24E
0005433805636	3251	127	25B
0005433805639	3251	128	25A
0005433805624	3251	129	25D
0005432459766	3251	130	25C
0005433805620	3251	131	25F
0005432459690	3251	132	25E
0005433634071	3251	133	26B
0005433507311	3251	134	26A
0005433805641	3251	135	26C
0005433805643	3251	136	26E
0005433634061	3251	137	26D
0005433634054	3251	138	26F
0005433805626	3251	139	27A
0005433634079	3251	140	27C
0005432181882	3251	141	27B
0005432459629	3251	142	27D
0005432181887	3251	143	27F
0005433634078	3251	144	27E
0005432459874	3251	145	28A
0005433507315	3251	146	28C
0005432459804	3251	147	28B
0005432459492	3251	148	28D
0005433805625	3251	149	29A
0005433634073	3251	150	28F
0005432459726	3251	151	28E
0005433805627	3251	152	29C
0005433634070	3251	153	29B
0005432181877	3251	154	29E
0005432459888	3251	155	29D
0005433634056	3251	156	29F
0005432181866	3251	157	30A
0005433805631	3251	158	30B
0005432459850	3251	159	30C
0005433634065	3251	160	30E
0005432181872	3251	161	30D
0005432459597	3251	162	30F
0005432459741	3251	163	31A
0005433507307	3251	164	31C
0005432181867	3251	165	31B
0005432459982	3251	166	31D
0005432459685	3251	167	31E
0005433507302	3251	168	31F
0005435885446	3250	1	1C
0005435885036	3250	2	2D
0005435885218	3250	3	3C
0005435885151	3250	4	5D
0005435885265	3250	5	6A
0005435885262	3250	6	5F
0005435885025	3250	7	6F
0005435885240	3250	8	7F
0005435885166	3250	9	8B
0005435885294	3250	10	8C
0005435885150	3250	11	8F
0005435885452	3250	12	9B
0005435885241	3250	13	9C
0005435885026	3250	14	9D
0005435885217	3250	15	10B
0005435885221	3250	16	10F
0005435885131	3250	17	11B
0005435885263	3250	18	11D
0005435884928	3250	19	11E
0005435885162	3250	20	12D
0005435885275	3250	21	13C
0005435885120	3250	22	13D
0005435885427	3250	23	13E
0005435885149	3250	24	13F
0005435885268	3250	25	14B
0005435885332	3250	26	14F
0005435885114	3250	27	15E
0005435885357	3250	28	15F
0005435885063	3250	29	17B
0005435885267	3250	30	18E
0005435885255	3250	31	19D
0005435885281	3250	32	20A
0005435885197	3250	33	20C
0005435885066	3250	34	20F
0005435885216	3250	35	21C
0005435885074	3250	36	21D
0005435885266	3250	37	22B
0005435885202	3250	38	23A
0005435885198	3250	39	23C
0005435885091	3250	40	23B
0005435885107	3250	41	25B
0005435885051	3250	42	25F
0005435885220	3250	43	26E
0005435885242	3250	44	27B
0005435885065	3250	45	27D
0005435885219	3250	46	27E
0005435885171	3250	47	28C
0005435885426	3250	48	29A
0005435885451	3250	49	29C
0005435885092	3250	50	30B
0005435885119	3250	51	30D
0005435885292	3250	52	30F
0005435885064	3250	53	31A
0005435885293	3250	54	31D
0005432460258	8231	1	1A
0005433507088	8231	2	1C
0005432460264	8231	3	1F
0005435885588	8231	4	1D
0005432042817	8231	5	2A
0005432460242	8231	6	2D
0005432042820	8231	7	2C
0005432460248	8231	8	2F
0005432460271	8231	9	3F
0005432460284	8231	10	3D
0005432460291	8231	11	4A
0005432460263	8231	12	4C
0005435885587	8231	13	4F
0005435885611	8231	14	4D
0005435885598	8231	15	5C
0005435885583	8231	16	5F
0005432460254	8231	17	6A
0005432460270	8231	18	6D
0005432042819	8231	19	7A
0005435885584	8231	20	7C
0005433507154	8231	21	7F
0005432042816	8231	22	8A
0005432460278	8231	23	8B
0005432460279	8231	24	8D
0005432042814	8231	25	8E
0005435885574	8231	26	8F
0005432460283	8231	27	9F
0005435885593	8231	28	9E
0005432460245	8231	29	10A
0005433507145	8231	30	10C
0005432460265	8231	31	10D
0005433507142	8231	32	10E
0005435885613	8231	33	11A
0005432460256	8231	34	10F
0005434312336	8231	35	11C
0005435885614	8231	36	11B
0005432460288	8231	37	11F
0005433507175	8231	38	11E
0005435885602	8231	39	12A
0005432460249	8231	40	12C
0005435885606	8231	41	12B
0005435885579	8231	42	12D
0005435885591	8231	43	12E
0005432460268	8231	44	12F
0005435885607	8231	45	13A
0005432460250	8231	46	13C
0005435885590	8231	47	13B
0005432460251	8231	48	13D
0005432460253	8231	49	13F
0005433507128	8231	50	13E
0005432460276	8231	51	14B
0005435885608	8231	52	14C
0005432042818	8231	53	14E
0005435885594	8231	54	14F
0005432460274	8231	55	15C
0005433507140	8231	56	15B
0005435885612	8231	57	15D
0005435885586	8231	58	15F
0005435885604	8231	59	15E
0005432460285	8231	60	16A
0005432460286	8231	61	16B
0005433507155	8231	62	16D
0005435885616	8231	63	16E
0005435885601	8231	64	16F
0005432460259	8231	65	17B
0005433507095	8231	66	17C
0005432042821	8231	67	17D
0005432042823	8231	68	17F
0005435885599	8231	69	17E
0005435885589	8231	70	18A
0005435885580	8231	71	18C
0005435885582	8231	72	18B
0005435885595	8231	73	18D
0005433507043	8231	74	18E
0005432460238	8231	75	18F
0005432460269	8231	76	19C
0005435885621	8231	77	19B
0005435885585	8231	78	19D
0005432460262	8231	79	19E
0005432460273	8231	80	20C
0005432042812	8231	81	20B
0005435885575	8231	82	20F
0005433507146	8231	83	21A
0005435885597	8231	84	21C
0005435885603	8231	85	21B
0005432460266	8231	86	21F
0005433507160	8231	87	21E
0005432460289	8231	88	22A
0005432460252	8231	89	22B
0005435885600	8231	90	22C
0005433507136	8231	91	22E
0005432460239	8231	92	22D
0005432042810	8231	93	23C
0005433507141	8231	94	23E
0005432460246	8231	95	24A
0005432460244	8231	96	23F
0005435885610	8231	97	24B
0005435885581	8231	98	24D
0005435885618	8231	99	24C
0005432460275	8231	100	24E
0005432460260	8231	101	24F
0005433507139	8231	102	25A
0005435885617	8231	103	25C
0005432460240	8231	104	25B
0005433507147	8231	105	25D
0005433507064	8231	106	25E
0005435885605	8231	107	26A
0005432042815	8231	108	26B
0005435885609	8231	109	26D
0005432460280	8231	110	26C
0005433507159	8231	111	26E
0005432460277	8231	112	27B
0005432042813	8231	113	27A
0005432460243	8231	114	27D
0005434312337	8231	115	27C
0005432460247	8231	116	27F
0005435885577	8231	117	27E
0005435885619	8231	118	28A
0005435885576	8231	119	28B
0005432460241	8231	120	28D
0005433507158	8231	121	28C
0005435885578	8231	122	28E
0005432460261	8231	123	28F
0005432042811	8231	124	29B
0005435885592	8231	125	29A
0005432460290	8231	126	29C
0005435885596	8231	127	29D
0005432460287	8231	128	29E
0005432460281	8231	129	30A
0005433507162	8231	130	29F
0005432042822	8231	131	30B
0005435885615	8231	132	30C
0005432460255	8231	133	30E
0005433507165	8231	134	30D
0005432460257	8231	135	31A
0005432460282	8231	136	30F
0005432460267	8231	137	31B
0005433507135	8231	138	31C
0005433507153	8231	139	31D
0005435885620	8231	140	31E
0005432460272	8231	141	31F
0005433805356	8241	1	1A
0005433805329	8241	2	2A
0005433805253	8241	3	1F
0005433633686	8241	4	2C
0005433633764	8241	5	3A
0005433633725	8241	6	2F
0005433633731	8241	7	4C
0005433633847	8241	8	4F
0005433805402	8241	9	5C
0005433633687	8241	10	5F
0005433805272	8241	11	5D
0005433633763	8241	12	6A
0005434143722	8241	13	6C
0005433805307	8241	14	6F
0005433633688	8241	15	8C
0005433633727	8241	16	8B
0005433633732	8241	17	8E
0005433633854	8241	18	8F
0005433805273	8241	19	9C
0005433633745	8241	20	9D
0005433633644	8241	21	9E
0005433805378	8241	22	10B
0005433805432	8241	23	10D
0005433805371	8241	24	10E
0005433805429	8241	25	11A
0005433633762	8241	26	11C
0005433633642	8241	27	11F
0005433805400	8241	28	12D
0005433805370	8241	29	13A
0005433805276	8241	30	13D
0005433633798	8241	31	13F
0005433805433	8241	32	13E
0005433805323	8241	33	14B
0005433805261	8241	34	14D
0005433805427	8241	35	14E
0005433633645	8241	36	15A
0005433633643	8241	37	14F
0005433805302	8241	38	15C
0005433805297	8241	39	16A
0005433805328	8241	40	16C
0005433633857	8241	41	16B
0005433805343	8241	42	17F
0005433633797	8241	43	17E
0005433805362	8241	44	18D
0005433805318	8241	45	18F
0005433805303	8241	46	21B
0005433805401	8241	47	21D
0005433633846	8241	48	21C
0005433633796	8241	49	21E
0005433633685	8241	50	22B
0005433805368	8241	51	22C
0005433633719	8241	52	22E
0005433805390	8241	53	22D
0005433805342	8241	54	22F
0005433633899	8241	55	23C
0005433633640	8241	56	23E
0005433805383	8241	57	24C
0005433633552	8241	58	25A
0005433633898	8241	59	25E
0005433633754	8241	60	25D
0005433805399	8241	61	26B
0005433805384	8241	62	26C
0005433805347	8241	63	26E
0005433805256	8241	64	26F
0005433633709	8241	65	27B
0005433805428	8241	66	27A
0005433633553	8241	67	27C
0005433633667	8241	68	27E
0005433805306	8241	69	28A
0005433633848	8241	70	28C
0005433805262	8241	71	30E
0005433633614	8241	72	31B
0005433633720	8241	73	31E
0005434183583	8242	1	9E
0005434183582	8242	2	31A
0005432383463	4605	1	1A
0005432728035	4605	2	1C
0005432383469	4605	3	1D
0005432728030	4605	4	1F
0005433722274	4605	5	2A
0005432383453	4605	6	2C
0005432383448	4605	7	2F
0005433194864	4605	8	3A
0005432383446	4605	9	3C
0005433194870	4605	10	3D
0005432383447	4605	11	3F
0005432728029	4605	12	4A
0005433194866	4605	13	4D
0005433194867	4605	14	4E
0005433194863	4605	15	4F
0005432383483	4605	16	5A
0005433194869	4605	17	5C
0005433453774	4605	18	5D
0005432728032	4605	19	5E
0005432383456	4605	20	5F
0005432383457	4605	21	6A
0005432383452	4605	22	6C
0005432383449	4605	23	6F
0005432383467	4605	24	7A
0005433194875	4605	25	7D
0005433194874	4605	26	7F
0005432383445	4605	27	8A
0005432383486	4605	28	8C
0005432383458	4605	29	8D
0005433194868	4605	30	8E
0005432383473	4605	31	9A
0005432383482	4605	32	9D
0005433722276	4605	33	9E
0005432383478	4605	34	9F
0005433194872	4605	35	10C
0005432383468	4605	36	10D
0005433453773	4605	37	10E
0005432728028	4605	38	11A
0005432383460	4605	39	11C
0005433722275	4605	40	11D
0005432728024	4605	41	11E
0005432383476	4605	42	11F
0005432383479	4605	43	12A
0005432383464	4605	44	12C
0005432383444	4605	45	12D
0005432728026	4605	46	12E
0005432383450	4605	47	12F
0005432383477	4605	48	13A
0005432383481	4605	49	13C
0005433722273	4605	50	13D
0005432383466	4605	51	13F
0005432728031	4605	52	14A
0005432383474	4605	53	14C
0005432383485	4605	54	14D
0005433194873	4605	55	14F
0005432383459	4605	56	15A
0005432383472	4605	57	15C
0005432728034	4605	58	15D
0005432383484	4605	59	15E
0005432728025	4605	60	15F
0005432383480	4605	61	16C
0005432383487	4605	62	16E
0005432383465	4605	63	16F
0005432383451	4605	64	17A
0005433194862	4605	65	17C
0005432728033	4605	66	17E
0005432383471	4605	67	17F
0005432728036	4605	68	18A
0005432383475	4605	69	18C
0005432383470	4605	70	18D
0005432383461	4605	71	18E
0005433194865	4605	72	18F
0005432383462	4605	73	19A
0005432383455	4605	74	19D
0005432728027	4605	75	19E
0005432383454	4605	76	20A
0005433194871	4605	77	20C
0005433722272	4605	78	20D
0005433451614	30115	1	1A
0005433722188	30115	2	1F
0005433722189	30115	3	2C
0005432383029	30115	4	2D
0005432382916	30115	5	2F
0005432727958	30115	6	3A
0005433722168	30115	7	3C
0005432382960	30115	8	3F
0005432382872	30115	9	4A
0005432382887	30115	10	4D
0005432727931	30115	11	4E
0005432382931	30115	12	4F
0005432383032	30115	13	5A
0005432383037	30115	14	5F
0005433451613	30115	15	6A
0005432383080	30115	16	6D
0005432382934	30115	17	6E
0005432727890	30115	18	6F
0005432382982	30115	19	7A
0005432727897	30115	20	7D
0005433451615	30115	21	7F
0005432382892	30115	22	8A
0005432382997	30115	23	9C
0005432382851	30115	24	9D
0005432382885	30115	25	9E
0005432383038	30115	26	9F
0005432382810	30115	27	10A
0005432727907	30115	28	10C
0005432382852	30115	29	10D
0005432727944	30115	30	10E
0005432727915	30115	31	10F
0005432383023	30115	32	11C
0005432383010	30115	33	11F
0005432383085	30115	34	12A
0005432382976	30115	35	12C
0005432727898	30115	36	12D
0005432382990	30115	37	12E
0005432382917	30115	38	12F
0005432383025	30115	39	13C
0005432727912	30115	40	13D
0005432383028	30115	41	13F
0005432727902	30115	42	14D
0005433722197	30115	43	14F
0005432383060	30115	44	15A
0005432727932	30115	45	15D
0005432727927	30115	46	15F
0005433722177	30115	47	16A
0005433722190	30115	48	16D
0005433722198	30115	49	16E
0005432382981	30115	50	16F
0005432383056	30115	51	17C
0005432382975	30115	52	17D
0005432383031	30115	53	17F
0005433194828	30115	54	18C
0005432382886	30115	55	18E
0005432382869	30115	56	18F
0005432727911	30115	57	19A
0005432382870	30115	58	19C
0005432383024	30115	59	20A
0005432727901	30115	60	20C
0005432383081	30115	61	20E
0005432383021	30115	62	20F
0005433516956	1728	1	1C
0005433516959	1728	2	1D
0005435529418	1728	3	1F
0005435529429	1728	4	2A
0005435541164	1728	5	2C
0005435529420	1728	6	3C
0005435541163	1728	7	3D
0005435541157	1728	8	4A
0005432925035	1728	9	4C
0005435529414	1728	10	4D
0005435541171	1728	11	4E
0005433516955	1728	12	4F
0005435529430	1728	13	5A
0005433516953	1728	14	5C
0005435529415	1728	15	5D
0005435529425	1728	16	5F
0005433516951	1728	17	6A
0005435541160	1728	18	6C
0005435541159	1728	19	6E
0005435529413	1728	20	6F
0005435541156	1728	21	7A
0005433516954	1728	22	7C
0005435529428	1728	23	7D
0005435541155	1728	24	7E
0005435529427	1728	25	8A
0005435541154	1728	26	8D
0005435541169	1728	27	8F
0005435529417	1728	28	9A
0005432925011	1728	29	9E
0005432294506	1728	30	10A
0005435529431	1728	31	10C
0005435529424	1728	32	10E
0005435541170	1728	33	10F
0005435541174	1728	34	12C
0005435529419	1728	35	12D
0005433516957	1728	36	12F
0005435541175	1728	37	13A
0005432925040	1728	38	13C
0005432925028	1728	39	13F
0005435529422	1728	40	14A
0005435529426	1728	41	14D
0005435529412	1728	42	14E
0005435529421	1728	43	14F
0005435541166	1728	44	15D
0005435529411	1728	45	15E
0005435541168	1728	46	15F
0005435541161	1728	47	16A
0005433516958	1728	48	16C
0005435541172	1728	49	16E
0005432925027	1728	50	17A
0005432294504	1728	51	17C
0005433516952	1728	52	17D
0005435529423	1728	53	18C
0005435529416	1728	54	18D
0005435541167	1728	55	18E
0005432925041	1728	56	18F
0005432294505	1728	57	19A
0005435541173	1728	58	19C
0005435541158	1728	59	19D
0005435541162	1728	60	19F
0005432925010	1728	61	20A
0005435541165	1728	62	20F
0005435541061	22017	1	1C
0005432925071	22017	2	1D
0005435517922	22017	3	1F
0005433516892	22017	4	2D
0005435517828	22017	5	2F
0005433516870	22017	6	3A
0005435517893	22017	7	3C
0005433516908	22017	8	4D
0005435517869	22017	9	4E
0005433516869	22017	10	4F
0005435517846	22017	11	5C
0005435540914	22017	12	5E
0005433516862	22017	13	6C
0005435540873	22017	14	6D
0005435540996	22017	15	6E
0005435541010	22017	16	7A
0005435517792	22017	17	7E
0005435540980	22017	18	8A
0005435517890	22017	19	8D
0005435517918	22017	20	8E
0005433516851	22017	21	9A
0005435517912	22017	22	9C
0005435517851	22017	23	9E
0005435540951	22017	24	9F
0005435517844	22017	25	10A
0005435540936	22017	26	10C
0005435540971	22017	27	10D
0005435517904	22017	28	10F
0005435517845	22017	29	11A
0005432925072	22017	30	11C
0005435541045	22017	31	11F
0005435517957	22017	32	12C
0005433516878	22017	33	12D
0005432925070	22017	34	13A
0005435517913	22017	35	13C
0005435541009	22017	36	13E
0005435517891	22017	37	14D
0005435540838	22017	38	14E
0005432925073	22017	39	14F
0005435540839	22017	40	15D
0005435517921	22017	41	15F
0005435540970	22017	42	16A
0005433516891	22017	43	16D
0005435540957	22017	44	17C
0005432925069	22017	45	17E
0005435540907	22017	46	18A
0005433516852	22017	47	18D
0005435517829	22017	48	18E
0005433516827	22017	49	18F
0005433516879	22017	50	19A
0005435540950	22017	51	19D
0005435517898	22017	52	19E
0005435540906	22017	53	20A
0005435540963	22017	54	20C
0005435541044	22017	55	20D
0005435540956	22017	56	20F
0005432073416	7366	1	1A
0005432839254	7366	2	1C
0005432839248	7366	3	2F
0005432839268	7366	4	3A
0005432839250	7366	5	3D
0005432073415	7366	6	3F
0005434458951	7366	7	4A
0005432073414	7366	8	4C
0005432823463	7366	9	4D
0005432839252	7366	10	4E
0005432839271	7366	11	5A
0005432839272	7366	12	5C
0005435252693	7366	13	5D
0005434458957	7366	14	5E
0005432839253	7366	15	5F
0005434458959	7366	16	6A
0005434458952	7366	17	6C
0005435252611	7366	18	6D
0005435252711	7366	19	6E
0005434458958	7366	20	7A
0005434458963	7366	21	7C
0005435252710	7366	22	7D
0005432839255	7366	23	7E
0005434458961	7366	24	7F
0005432839256	7366	25	8C
0005434458955	7366	26	8D
0005435491434	7366	27	8E
0005435252662	7366	28	8F
0005432841025	7366	29	9A
0005432839270	7366	30	9C
0005432839245	7366	31	9D
0005432839257	7366	32	9F
0005432839265	7366	33	10A
0005434458964	7366	34	10C
0005432839275	7366	35	10D
0005435252653	7366	36	10E
0005435252621	7366	37	10F
0005434458949	7366	38	11A
0005434458962	7366	39	11C
0005435252661	7366	40	11D
0005432839269	7366	41	11E
0005435252694	7366	42	11F
0005432839262	7366	43	12A
0005432841026	7366	44	12D
0005435252674	7366	45	12E
0005434664953	7366	46	12F
0005435252751	7366	47	13A
0005432823462	7366	48	13D
0005432073417	7366	49	13E
0005432841027	7366	50	13F
0005432839264	7366	51	14C
0005432839266	7366	52	14D
0005432839258	7366	53	14E
0005434458960	7366	54	15A
0005434664949	7366	55	15C
0005434458953	7366	56	15D
0005434458965	7366	57	15E
0005435252740	7366	58	15F
0005432839274	7366	59	16A
0005434458950	7366	60	16C
0005432839261	7366	61	16D
0005432839273	7366	62	16E
0005432839259	7366	63	16F
0005435252670	7366	64	17A
0005432839251	7366	65	17C
0005434458954	7366	66	17D
0005432839247	7366	67	17E
0005432839267	7366	68	17F
0005435252741	7366	69	18A
0005432839260	7366	70	18E
0005432839263	7366	71	18F
0005434458948	7366	72	19C
0005432839246	7366	73	19D
0005434664950	7366	74	19F
0005432839249	7366	75	20A
0005435252663	7366	76	20C
0005434458947	7366	77	20D
0005435252717	7366	78	20E
0005434458956	7366	79	20F
0005432823445	28921	1	1A
0005432839047	28921	2	1C
0005432001038	28921	3	1D
0005434664977	28921	4	1F
0005434458852	28921	5	2A
0005432839059	28921	6	2C
0005432841009	28921	7	2D
0005432839009	28921	8	2F
0005432841008	28921	9	3A
0005434458818	28921	10	3C
0005434458858	28921	11	3D
0005434458793	28921	12	3F
0005434458798	28921	13	4A
0005434458690	28921	14	4C
0005434458753	28921	15	4D
0005434458807	28921	16	4E
0005434458734	28921	17	4F
0005432839073	28921	18	5A
0005434458832	28921	19	5C
0005435252830	28921	20	5D
0005434458767	28921	21	5E
0005435252832	28921	22	5F
0005434664978	28921	23	6A
0005435252835	28921	24	6C
0005434458833	28921	25	6D
0005435252821	28921	26	6E
0005434458809	28921	27	6F
0005432839154	28921	28	7A
0005434458733	28921	29	7C
0005434458853	28921	30	7D
0005432839057	28921	31	7F
0005432838862	28921	32	7E
0005432839096	28921	33	8A
0005435252825	28921	34	8C
0005434458763	28921	35	8D
0005432839004	28921	36	8E
0005434458814	28921	37	8F
0005434458736	28921	38	9A
0005434458797	28921	39	9C
0005432823447	28921	40	9D
0005435252826	28921	41	9E
0005434458754	28921	42	9F
0005432841007	28921	43	10A
0005434458819	28921	44	10C
0005432839039	28921	45	10D
0005432839005	28921	46	10E
0005432839077	28921	47	10F
0005432841010	28921	48	11A
0005432838996	28921	49	11C
0005432839040	28921	50	11D
0005432838969	28921	51	11E
0005432838995	28921	52	11F
0005432839098	28921	53	12A
0005434458854	28921	54	12C
0005434458808	28921	55	12D
0005432839048	28921	56	12E
0005432839076	28921	57	12F
0005434458741	28921	58	13A
0005434458755	28921	59	13C
0005432838987	28921	60	13D
0005432839155	28921	61	13E
0005432823446	28921	62	13F
0005434458829	28921	63	14A
0005432839082	28921	64	14C
0005435252827	28921	65	14D
0005435252834	28921	66	14E
0005435252822	28921	67	14F
0005435252823	28921	68	15A
0005434664976	28921	69	15C
0005432839019	28921	70	15D
0005432839097	28921	71	15E
0005434458828	28921	72	15F
0005434458764	28921	73	16A
0005432839036	28921	74	16C
0005432839029	28921	75	16D
0005432838944	28921	76	16E
0005435252824	28921	77	16F
0005434458794	28921	78	17A
0005434458815	28921	79	17C
0005435252836	28921	80	17D
0005432839055	28921	81	17E
0005435252833	28921	82	17F
0005435252829	28921	83	18A
0005434458820	28921	84	18C
0005432838943	28921	85	18D
0005432838976	28921	86	18E
0005432001037	28921	87	18F
0005434458777	28921	88	19A
0005434458735	28921	89	19C
0005434458742	28921	90	19D
0005435252828	28921	91	19E
0005434458766	28921	92	19F
0005432839056	28921	93	20A
0005435252831	28921	94	20D
0005434458792	28921	95	20C
0005432823450	28921	96	20E
0005432839081	28921	97	20F
0005434276017	8812	1	5F
0005435990672	8812	2	6B
0005435990673	8812	3	6D
0005435990675	8812	4	6F
0005435990679	8812	5	7E
0005435990676	8812	6	8C
0005435990677	8812	7	13C
0005435990674	8812	8	16D
0005435990678	8812	9	18D
0005434276033	8812	10	20B
0005434276069	15721	1	2C
0005434276068	15721	2	3F
0005435990614	15721	3	6A
0005435990620	15721	4	9C
0005434276066	15721	5	10B
0005435990621	15721	6	10D
0005435990597	15721	7	13C
0005435990624	15721	8	14A
0005434276071	15721	9	14D
0005434276067	15721	10	18A
0005434276070	15721	11	19A
0005432427155	20624	1	5B
0005433476886	20624	2	5C
0005433476894	20624	3	6B
0005433476885	20624	4	6D
0005432427157	20624	5	7C
0005433476884	20624	6	22A
0005432427158	20624	7	22C
0005432427156	20624	8	22D
0005433476895	20624	9	23B
0005434149742	6359	1	1A
0005432360698	6359	2	1C
0005435177099	6359	3	1D
0005432360715	6359	4	2C
0005432360724	6359	5	2A
0005432360729	6359	6	2D
0005432360713	6359	7	3A
0005435490201	6359	8	3C
0005435177040	6359	9	3D
0005435177073	6359	10	3F
0005435490229	6359	11	4B
0005435176932	6359	12	4A
0005432360717	6359	13	4C
0005434149739	6359	14	4E
0005435177114	6359	15	4F
0005432360710	6359	16	5A
0005432360732	6359	17	5C
0005432363441	6359	18	5B
0005432336116	6359	19	5D
0005434149741	6359	20	5E
0005432360701	6359	21	5F
0005432336118	6359	22	6A
0005432360707	6359	23	6C
0005435490216	6359	24	6B
0005432363440	6359	25	6D
0005432360733	6359	26	6F
0005432360692	6359	27	6E
0005435177072	6359	28	7A
0005435177039	6359	29	7B
0005432336119	6359	30	7C
0005432336123	6359	31	7D
0005432336124	6359	32	7F
0005432360706	6359	33	7E
0005435177088	6359	34	8A
0005435177094	6359	35	8B
0005432360702	6359	36	8C
0005435177134	6359	37	8E
0005435723049	6359	38	8D
0005435723039	6359	39	9A
0005432360723	6359	40	8F
0005435176983	6359	41	9C
0005435177119	6359	42	9E
0005432360735	6359	43	9D
0005434149729	6359	44	10B
0005435177118	6359	45	10C
0005432360687	6359	46	10D
0005432360736	6359	47	10E
0005432336117	6359	48	11C
0005432360712	6359	49	11B
0005435176910	6359	50	11D
0005435177155	6359	51	11F
0005432360709	6359	52	11E
0005432360711	6359	53	12A
0005435177175	6359	54	12C
0005432360719	6359	55	12B
0005435177086	6359	56	12E
0005434149697	6359	57	12D
0005432360691	6359	58	13A
0005432062267	6359	59	12F
0005435177029	6359	60	13C
0005432360688	6359	61	13B
0005432360728	6359	62	13D
0005432336120	6359	63	13E
0005432336122	6359	64	14A
0005435723051	6359	65	13F
0005435177084	6359	66	14B
0005432360697	6359	67	14C
0005434149728	6359	68	14F
0005432336125	6359	69	14E
0005434149700	6359	70	15B
0005432360704	6359	71	15A
0005432360731	6359	72	15C
0005435723052	6359	73	15D
0005432360730	6359	74	16A
0005435177116	6359	75	15F
0005434149674	6359	76	16B
0005432360695	6359	77	16C
0005432360726	6359	78	16D
0005432336115	6359	79	16F
0005432363439	6359	80	16E
0005434149715	6359	81	17A
0005432062266	6359	82	17B
0005432360689	6359	83	17C
0005435177098	6359	84	17E
0005435177041	6359	85	17D
0005432336121	6359	86	17F
0005432360716	6359	87	18A
0005435177111	6359	88	18B
0005432360705	6359	89	18C
0005432360727	6359	90	18D
0005435177085	6359	91	18F
0005432062268	6359	92	18E
0005432360722	6359	93	19A
0005435177176	6359	94	19B
0005432360703	6359	95	19D
0005432360714	6359	96	19C
0005434149746	6359	97	19E
0005432062265	6359	98	20A
0005432360699	6359	99	20C
0005432363438	6359	100	20B
0005432360690	6359	101	20E
0005432360708	6359	102	20D
0005435177139	6359	103	20F
0005435177205	6359	104	21A
0005435176982	6359	105	21C
0005435176933	6359	106	21B
0005432360693	6359	107	21D
0005432360734	6359	108	21E
0005432360720	6359	109	22A
0005432360718	6359	110	21F
0005432360694	6359	111	22C
0005432360696	6359	112	22B
0005432062269	6359	113	22D
0005432360725	6359	114	22F
0005435177115	6359	115	22E
0005435177140	6359	116	23A
0005434149644	6359	117	23B
0005432360700	6359	118	23C
0005434149747	6359	119	23D
0005432360721	6359	120	23F
0005432336126	6359	121	23E
0005434149818	21025	1	1C
0005432360517	21025	2	1D
0005432360135	21025	3	2C
0005435177272	21025	4	2A
0005435177269	21025	5	2F
0005434149812	21025	6	2D
0005432336021	21025	7	3C
0005432360191	21025	8	3A
0005435490259	21025	9	3F
0005432360326	21025	10	3D
0005432336050	21025	11	4B
0005432360265	21025	12	4A
0005432360120	21025	13	4E
0005432335965	21025	14	4D
0005432360253	21025	15	5B
0005432360466	21025	16	5C
0005432360308	21025	17	5E
0005432052767	21025	18	5F
0005432360353	21025	19	6A
0005435177282	21025	20	6C
0005432360231	21025	21	6B
0005432360205	21025	22	6E
0005435177271	21025	23	6D
0005432336018	21025	24	7A
0005435177285	21025	25	6F
0005435177286	21025	26	7B
0005432360325	21025	27	7C
0005432336049	21025	28	7D
0005432360321	21025	29	7F
0005434149811	21025	30	8B
0005432360207	21025	31	8D
0005435177284	21025	32	8C
0005435177281	21025	33	8E
0005432360365	21025	34	9A
0005435177265	21025	35	8F
0005435177279	21025	36	9B
0005435177275	21025	37	9C
0005434149809	21025	38	9E
0005432336011	21025	39	9D
0005432335993	21025	40	9F
0005432360297	21025	41	10C
0005432360068	21025	42	10B
0005434149814	21025	43	10D
0005432360208	21025	44	11A
0005432335995	21025	45	11B
0005435177276	21025	46	11C
0005435177288	21025	47	11E
0005435177267	21025	48	11D
0005434149819	21025	49	11F
0005432360168	21025	50	12A
0005435177266	21025	51	12D
0005432360518	21025	52	12C
0005432360415	21025	53	12E
0005434149815	21025	54	12F
0005432360064	21025	55	13A
0005434149816	21025	56	13C
0005432360414	21025	57	13B
0005432360164	21025	58	13D
0005432052768	21025	59	13E
0005432360264	21025	60	13F
0005432360560	21025	61	14A
0005432360324	21025	62	14C
0005432360266	21025	63	14D
0005435177270	21025	64	14E
0005432336016	21025	65	14F
0005432360258	21025	66	15B
0005432360337	21025	67	15A
0005432335991	21025	68	15C
0005432363409	21025	69	15D
0005435177287	21025	70	15F
0005435177273	21025	71	16A
0005435177262	21025	72	16B
0005432360221	21025	73	16D
0005434149820	21025	74	16C
0005432363415	21025	75	16E
0005435177274	21025	76	16F
0005434149821	21025	77	17B
0005435177283	21025	78	17C
0005434149813	21025	79	17D
0005432360298	21025	80	17F
0005435177278	21025	81	18C
0005432052769	21025	82	18F
0005435177261	21025	83	18E
0005432360309	21025	84	19A
0005432360338	21025	85	19B
0005432360206	21025	86	19D
0005432360067	21025	87	19C
0005432336017	21025	88	19E
0005435490258	21025	89	19F
0005434149817	21025	90	20A
0005435177263	21025	91	20B
0005432360257	21025	92	20D
0005432360146	21025	93	20C
0005432360376	21025	94	20E
0005435177277	21025	95	20F
0005435723061	21025	96	21A
0005435177268	21025	97	21C
0005435177280	21025	98	21B
0005432363398	21025	99	21D
0005432360162	21025	100	21E
0005432360134	21025	101	21F
0005434149810	21025	102	22A
0005432360268	21025	103	22B
0005432360163	21025	104	22D
0005432336006	21025	105	22F
0005435177264	21025	106	23B
0005432363399	21025	107	23C
0005432360233	21025	108	23E
0005432335992	21025	109	23D
0005432360267	21025	110	23F
0005434448311	17728	1	1B
0005434448307	17728	2	1C
0005434186219	17728	3	1D
0005434458779	17728	4	2B
0005434458681	17728	5	2C
0005434458873	17728	6	2D
0005434458837	17728	7	3A
0005434458757	17728	8	3B
0005434458804	17728	9	3C
0005434463918	17728	10	4B
0005434458836	17728	11	4D
0005434448316	17728	12	5A
0005434458605	17728	13	5B
0005434461643	17728	14	5D
0005434458682	17728	15	6A
0005434458780	17728	16	6C
0005434461642	17728	17	6D
0005434458756	17728	18	7A
0005434458831	17728	19	7B
0005434463928	17728	20	7C
0005434458786	17728	21	18A
0005434461638	17728	22	18C
0005434448315	17728	23	18D
0005434458785	17728	24	19A
0005434458867	17728	25	19B
0005434461644	17728	26	19C
0005434186221	17728	27	19D
0005434458759	17728	28	20A
0005434463919	17728	29	20B
0005434186220	17728	30	21A
0005434448308	17728	31	21C
0005434448310	17728	32	22A
0005434463927	17728	33	22B
0005434458604	17728	34	22C
0005434461648	17728	35	22D
0005434461649	17728	36	23B
0005434463942	29129	1	1B
0005434463943	29129	2	1C
0005434458956	29129	3	2B
0005434458960	29129	4	2C
0005434458961	29129	5	2D
0005434458947	29129	6	3B
0005434458952	29129	7	3C
0005434458953	29129	8	4A
0005434458962	29129	9	4B
0005434458958	29129	10	4D
0005434458954	29129	11	5A
0005434458959	29129	12	6A
0005434458964	29129	13	6B
0005434458951	29129	14	6D
0005434458965	29129	15	7C
0005434186199	29129	16	18A
0005434458955	29129	17	18B
0005434458957	29129	18	18C
0005434458950	29129	19	18D
0005434448336	29129	20	19B
0005434448335	29129	21	19D
0005434458963	29129	22	20B
0005434448337	29129	23	21A
0005434462804	29129	24	21D
0005434458948	29129	25	22A
0005434458949	29129	26	23A
0005432604604	21414	1	1A
0005432604588	21414	2	1B
0005432604599	21414	3	1C
0005432604584	21414	4	2A
0005432604589	21414	5	2B
0005432604613	21414	6	2C
0005432604610	21414	7	2D
0005432604586	21414	8	3A
0005432604587	21414	9	3B
0005432604612	21414	10	3C
0005432604579	21414	11	3D
0005432604590	21414	12	4A
0005435220490	21414	13	4B
0005432604606	21414	14	5A
0005432604581	21414	15	5B
0005432604605	21414	16	5D
0005432604596	21414	17	6A
0005432604614	21414	18	6B
0005432604602	21414	19	7B
0005432604607	21414	20	7C
0005432604585	21414	21	7D
0005432604591	21414	22	18B
0005432604592	21414	23	18C
0005432604578	21414	24	18D
0005432604598	21414	25	19A
0005432604594	21414	26	19B
0005432604603	21414	27	19C
0005432604582	21414	28	19D
0005432604583	21414	29	20B
0005432604601	21414	30	20C
0005432604608	21414	31	20D
0005432604595	21414	32	21A
0005435218114	21414	33	21B
0005432604580	21414	34	21C
0005432604597	21414	35	21D
0005432604609	21414	36	22A
0005432604611	21414	37	22B
0005432604577	21414	38	22C
0005432604593	21414	39	22D
0005432604600	21414	40	23A
0005432604331	31697	1	1A
0005432604330	31697	2	1B
0005432604314	31697	3	1C
0005432604218	31697	4	1D
0005432604252	31697	5	2A
0005432604235	31697	6	2B
0005432604169	31697	7	2C
0005432604100	31697	8	2D
0005432604288	31697	9	3A
0005432604363	31697	10	3B
0005432604378	31697	11	3C
0005432604263	31697	12	3D
0005432604391	31697	13	4A
0005432604411	31697	14	4B
0005432604276	31697	15	4C
0005432604339	31697	16	4D
0005432604160	31697	17	5A
0005432604476	31697	18	5B
0005432604106	31697	19	5C
0005432604264	31697	20	5D
0005432604247	31697	21	6A
0005432604290	31697	22	6B
0005432604364	31697	23	6C
0005432604248	31697	24	6D
0005432604350	31697	25	7A
0005432603985	31697	26	7B
0005432604214	31697	27	7C
0005432604289	31697	28	7D
0005432604269	31697	29	18A
0005432604286	31697	30	18B
0005432604232	31697	31	18C
0005432604234	31697	32	18D
0005432604233	31697	33	19A
0005432604099	31697	34	19B
0005432604477	31697	35	19C
0005432604377	31697	36	19D
0005432604159	31697	37	20A
0005432604284	31697	38	20B
0005432604195	31697	39	20C
0005432604253	31697	40	20D
0005432604005	31697	41	21A
0005432604236	31697	42	21B
0005432604151	31697	43	21C
0005432604231	31697	44	21D
0005432604152	31697	45	22A
0005432604101	31697	46	22B
0005432604285	31697	47	22C
0005432604177	31697	48	22D
0005432604275	31697	49	23A
0005432603968	31697	50	23B
0005433293214	12300	1	1A
0005433293239	12300	2	2B
0005433293241	12300	3	3B
0005435154600	12300	4	5B
0005433293229	12300	5	6A
0005433293232	12300	6	6C
0005433293219	12300	7	6D
0005433293228	12300	8	7D
0005433293215	12300	9	18B
0005433293234	12300	10	19B
0005433293216	12300	11	20B
0005433293233	12300	12	20C
0005433293240	12300	13	21A
0005433293230	12300	14	21D
0005433293235	12300	15	22A
0005435154601	12300	16	22B
0005434606811	18911	1	5B
0005434606810	18911	2	6B
0005434606851	22349	1	1A
0005434604919	22349	2	1B
0005434606849	22349	3	2A
0005434606848	22349	4	3A
0005434606850	22349	5	4A
0005434604918	22349	6	5B
0005432747842	381	1	1A
0005432747811	381	2	1C
0005432747824	381	3	1D
0005432747837	381	4	1F
0005432751547	381	5	2A
0005432747814	381	6	2C
0005433293224	381	7	2D
0005433875375	381	8	2F
0005435154604	381	9	3A
0005432891011	381	10	3C
0005432753321	381	11	4A
0005432890986	381	12	4D
0005433875374	381	13	4E
0005432891028	381	14	4F
0005432891006	381	15	5C
0005432747841	381	16	5D
0005432891008	381	17	5E
0005432747813	381	18	6C
0005432891024	381	19	6D
0005432747829	381	20	6E
0005432747843	381	21	6F
0005432747815	381	22	7A
0005432220033	381	23	7C
0005432747826	381	24	7D
0005432747849	381	25	7E
0005432220031	381	26	8A
0005432747833	381	27	8C
0005432747832	381	28	8D
0005432753323	381	29	8E
0005432747848	381	30	8F
0005432890985	381	31	9A
0005432753322	381	32	9C
0005432747819	381	33	9D
0005432749799	381	34	9E
0005432747817	381	35	9F
0005432220034	381	36	10A
0005432747850	381	37	10C
0005432747830	381	38	10D
0005432747834	381	39	10E
0005432891002	381	40	10F
0005433293212	381	41	11A
0005432747823	381	42	11E
0005432747846	381	43	11D
0005432747827	381	44	11F
0005432747828	381	45	12A
0005432747839	381	46	12E
0005432890978	381	47	12F
0005433875376	381	48	13A
0005432747840	381	49	13C
0005432891013	381	50	13D
0005432751546	381	51	13E
0005432747844	381	52	13F
0005435154605	381	53	14C
0005432747818	381	54	14D
0005432891056	381	55	14E
0005432747821	381	56	14F
0005432747847	381	57	15C
0005432747822	381	58	15E
0005432891025	381	59	15F
0005432747816	381	60	16A
0005432747831	381	61	16D
0005435154603	381	62	16F
0005432747825	381	63	17A
0005432747845	381	64	17C
0005432747812	381	65	18A
0005435154602	381	66	18C
0005432747820	381	67	19A
0005433293251	381	68	19C
0005432747836	381	69	19D
0005432890979	381	70	19E
0005432747838	381	71	19F
0005432220032	381	72	20C
0005432751548	381	73	20D
0005432747835	381	74	20E
0005433293299	12077	1	1A
0005432747715	12077	2	1C
0005432747516	12077	3	1D
0005433293294	12077	4	1F
0005432747645	12077	5	2A
0005432747427	12077	6	2D
0005432747633	12077	7	2F
0005433293288	12077	8	3A
0005432747628	12077	9	3C
0005432747360	12077	10	3D
0005432747627	12077	11	3F
0005433293296	12077	12	4A
0005432891160	12077	13	4C
0005433293292	12077	14	4E
0005432753292	12077	15	4F
0005432891169	12077	16	5A
0005432747254	12077	17	5C
0005432747596	12077	18	5D
0005432747569	12077	19	5E
0005432747484	12077	20	5F
0005432891163	12077	21	6A
0005432747646	12077	22	6C
0005432891165	12077	23	6D
0005432747443	12077	24	6F
0005432747558	12077	25	7A
0005432756825	12077	26	7C
0005432214820	12077	27	7D
0005432749779	12077	28	7E
0005432747716	12077	29	7F
0005432747570	12077	30	8A
0005433293298	12077	31	8C
0005432747571	12077	32	8D
0005432891166	12077	33	8E
0005433293300	12077	34	8F
0005432747605	12077	35	9A
0005432756821	12077	36	9C
0005432747649	12077	37	9D
0005432891151	12077	38	9E
0005432747468	12077	39	9F
0005432891156	12077	40	10A
0005432747644	12077	41	10C
0005432891153	12077	42	10D
0005432891152	12077	43	10E
0005432747654	12077	44	10F
0005432749786	12077	45	11A
0005432747490	12077	46	11C
0005432747477	12077	47	11D
0005432747709	12077	48	11E
0005432747542	12077	49	11F
0005432747647	12077	50	12A
0005432891164	12077	51	12C
0005432747617	12077	52	12D
0005432747632	12077	53	12E
0005432214819	12077	54	12F
0005433293286	12077	55	13A
0005432891155	12077	56	13C
0005432749785	12077	57	13D
0005432747451	12077	58	13E
0005432747643	12077	59	13F
0005432891159	12077	60	14A
0005432747426	12077	61	14C
0005432749780	12077	62	14D
0005432891167	12077	63	14E
0005432747598	12077	64	14F
0005433293297	12077	65	15A
0005432747473	12077	66	15C
0005432747629	12077	67	15D
0005432747491	12077	68	15E
0005432891162	12077	69	15F
0005432891158	12077	70	16A
0005432891157	12077	71	16C
0005432891161	12077	72	16D
0005432747361	12077	73	16E
0005432747430	12077	74	16F
0005433293290	12077	75	17A
0005432891154	12077	76	17C
0005432747502	12077	77	17D
0005432747503	12077	78	17E
0005432747459	12077	79	17F
0005432891168	12077	80	18A
0005433293293	12077	81	18C
0005433293287	12077	82	18D
0005432747458	12077	83	18F
0005432753297	12077	84	19A
0005432891150	12077	85	19C
0005432753291	12077	86	19D
0005432747655	12077	87	19E
0005433293291	12077	88	19F
0005432747543	12077	89	20A
0005433293295	12077	90	20C
0005433293289	12077	91	20D
0005432747565	12077	92	20E
0005433533332	18986	1	1A
0005433525104	18986	2	1D
0005432927997	18986	3	2A
0005433525102	18986	4	2C
0005432927961	18986	5	2D
0005433525111	18986	6	3A
0005433525112	18986	7	3C
0005433531319	18986	8	4A
0005433533333	18986	9	4B
0005433525108	18986	10	4C
0005432927998	18986	11	5A
0005433531317	18986	12	4D
0005433525109	18986	13	5B
0005433531315	18986	14	5C
0005432927977	18986	15	5D
0005433525106	18986	16	7A
0005433525110	18986	17	7C
0005433531316	18986	18	18A
0005433533331	18986	19	18B
0005433525107	18986	20	19C
0005433525105	18986	21	20B
0005432927963	18986	22	20C
0005433531318	18986	23	20D
0005432927962	18986	24	21C
0005433525103	18986	25	22B
0005432927960	18986	26	23A
0005432928026	32464	1	1B
0005432928027	32464	2	1C
0005433527252	32464	3	1D
0005432928028	32464	4	3B
0005433525043	32464	5	3C
0005432928025	32464	6	4A
0005433531278	32464	7	5A
0005433527253	32464	8	5C
0005432928024	32464	9	7C
0005433531282	32464	10	19A
0005433531291	32464	11	21D
0005432928023	32464	12	22A
0005433525008	32464	13	22B
0005433524945	32464	14	22C
0005435373130	5290	1	1A
0005435661919	5290	2	1G
0005434824551	5290	3	1K
0005434824460	5290	4	2C
0005435373240	5290	5	2A
0005434824540	5290	6	2H
0005435373288	5290	7	3A
0005434824537	5290	8	2K
0005434824452	5290	9	3D
0005432121436	5290	10	3C
0005434824445	5290	11	3H
0005435373463	5290	12	3G
0005434824461	5290	13	4C
0005435372837	5290	14	4A
0005434824548	5290	15	3K
0005434824454	5290	16	4H
0005434831178	5290	17	4G
0005435373145	5290	18	4D
0005434824458	5290	19	5C
0005434824539	5290	20	5A
0005432121429	5290	21	5H
0005434824484	5290	22	5G
0005434824503	5290	23	5D
0005434824513	5290	24	11D
0005435373232	5290	25	11E
0005434824433	5290	26	11K
0005434828715	5290	27	12C
0005435373315	5290	28	12A
0005435373061	5290	29	12E
0005435373233	5290	30	12D
0005432121430	5290	31	12H
0005434824545	5290	32	12G
0005434824518	5290	33	13A
0005435373095	5290	34	13D
0005435386565	5290	35	13H
0005435373129	5290	36	13G
0005434824520	5290	37	13K
0005434824509	5290	38	14E
0005434824453	5290	39	14D
0005434824488	5290	40	14C
0005435373261	5290	41	14G
0005434824456	5290	42	14F
0005434824481	5290	43	14H
0005432396274	5290	44	15D
0005434824441	5290	45	15C
0005435373080	5290	46	15A
0005434824480	5290	47	15E
0005434824489	5290	48	15G
0005432396271	5290	49	15F
0005435150129	5290	50	15K
0005435373180	5290	51	16D
0005435373199	5290	52	16C
0005434824526	5290	53	16A
0005434824442	5290	54	16F
0005435735119	5290	55	16E
0005434824429	5290	56	16H
0005434824435	5290	57	16G
0005434824517	5290	58	17A
0005434824487	5290	59	16K
0005435372886	5290	60	17E
0005432394136	5290	61	17C
0005434824443	5290	62	17G
0005434824437	5290	63	17F
0005432394133	5290	64	17H
0005435373339	5290	65	18B
0005434824493	5290	66	18E
0005435373342	5290	67	18C
0005435386558	5290	68	18G
0005435304185	5290	69	18F
0005434824504	5290	70	18K
0005435373133	5290	71	18J
0005434824464	5290	72	18H
0005435373406	5290	73	19A
0005435150126	5290	74	19D
0005434824495	5290	75	19C
0005435373523	5290	76	19E
0005435150131	5290	77	19H
0005434824538	5290	78	19G
0005434824486	5290	79	19J
0005434824505	5290	80	20C
0005435373149	5290	81	20B
0005435735113	5290	82	20A
0005434824439	5290	83	20D
0005434824469	5290	84	20G
0005434824470	5290	85	21B
0005434824436	5290	86	21D
0005434824512	5290	87	21C
0005434824500	5290	88	21E
0005434824438	5290	89	21J
0005435373464	5290	90	21H
0005434824490	5290	91	22B
0005435373291	5290	92	22A
0005432121438	5290	93	22E
0005434824544	5290	94	22D
0005432396272	5290	95	22H
0005434824514	5290	96	22G
0005434824546	5290	97	22F
0005434824491	5290	98	23C
0005434831182	5290	99	23F
0005435150121	5290	100	23J
0005434824552	5290	101	23H
0005435372967	5290	102	23G
0005434824496	5290	103	24D
0005435372909	5290	104	23K
0005434824447	5290	105	24E
0005434824477	5290	106	25A
0005434824475	5290	107	25D
0005435386559	5290	108	25C
0005434824530	5290	109	25B
0005434831181	5290	110	25E
0005434824459	5290	111	25H
0005434824473	5290	112	26A
0005434828713	5290	113	26E
0005432121442	5290	114	26D
0005434824455	5290	115	26F
0005434824451	5290	116	26J
0005434824468	5290	117	26K
0005432121431	5290	118	27F
0005434824492	5290	119	27E
0005435373265	5290	120	27H
0005435373051	5290	121	27G
0005432121435	5290	122	27K
0005435661920	5290	123	27J
0005435150123	5290	124	28B
0005434824444	5290	125	28D
0005432394132	5290	126	28G
0005435150132	5290	127	28H
0005435150122	5290	128	29B
0005434824478	5290	129	29A
0005432121433	5290	130	28K
0005435373507	5290	131	29D
0005434824494	5290	132	29F
0005434824450	5290	133	29E
0005434824516	5290	134	29G
0005434824498	5290	135	29J
0005435735126	5290	136	30E
0005435373069	5290	137	30D
0005434824474	5290	138	30C
0005434824483	5290	139	30F
0005434824479	5290	140	30J
0005435373006	5290	141	30H
0005435373216	5290	142	31B
0005434824524	5290	143	31F
0005434824543	5290	144	31E
0005434824535	5290	145	31H
0005434824446	5290	146	32A
0005435373506	5290	147	31K
0005435372938	5290	148	31J
0005434824430	5290	149	32B
0005435373235	5290	150	32E
0005435150120	5290	151	32D
0005435304157	5290	152	32C
0005435373598	5290	153	32H
0005434824463	5290	154	32G
0005435150124	5290	155	32F
0005435373202	5290	156	33A
0005435150130	5290	157	33D
0005434824547	5290	158	33C
0005434824467	5290	159	33B
0005434824525	5290	160	33F
0005434824510	5290	161	33H
0005435373081	5290	162	33G
0005434664975	5290	163	34C
0005434824522	5290	164	34B
0005435373128	5290	165	34E
0005434824542	5290	166	34G
0005434824515	5290	167	34F
0005435373356	5290	168	34K
0005434824431	5290	169	35B
0005434824557	5290	170	35A
0005435299786	5290	171	35F
0005435150133	5290	172	35E
0005435373264	5290	173	35J
0005432121432	5290	174	35G
0005434824511	5290	175	36C
0005434824499	5290	176	36B
0005434664974	5290	177	36E
0005434824549	5290	178	36D
0005435373112	5290	179	36G
0005435150125	5290	180	36J
0005435372896	5290	181	37A
0005434824462	5290	182	37C
0005435373260	5290	183	37F
0005434824550	5290	184	37J
0005435150127	5290	185	37H
0005434824534	5290	186	37K
0005434831180	5290	187	38B
0005435373041	5290	188	38A
0005434824501	5290	189	38K
0005434824533	5290	190	38H
0005435735118	5290	191	39B
0005435304148	5290	192	39D
0005432121434	5290	193	39G
0005435373407	5290	194	39J
0005432394135	5290	195	39H
0005435373052	5290	196	40A
0005434824482	5290	197	40D
0005434824528	5290	198	40C
0005434824556	5290	199	40B
0005435373028	5290	200	40F
0005434824541	5290	201	40K
0005435150128	5290	202	40J
0005434824508	5290	203	41D
0005434828714	5290	204	41C
0005434824536	5290	205	41F
0005435735102	5290	206	41E
0005434824471	5290	207	41H
0005435373127	5290	208	41G
0005434824527	5290	209	41K
0005435150134	5290	210	42B
0005434831179	5290	211	42E
0005432823440	5290	212	42D
0005434824531	5290	213	42G
0005434824529	5290	214	42F
0005432121440	5290	215	42J
0005434824506	5290	216	43A
0005435386557	5290	217	42K
0005434824457	5290	218	43C
0005435299787	5290	219	43F
0005435373207	5290	220	43E
0005434824448	5290	221	43D
0005434824555	5290	222	43J
0005434824432	5290	223	44B
0005434824553	5290	224	44A
0005435373290	5290	225	44H
0005435373027	5290	226	44F
0005434824465	5290	227	44K
0005435373056	5290	228	45D
0005432394134	5290	229	45C
0005435373107	5290	230	45F
0005432121439	5290	231	45E
0005432396273	5290	232	45H
0005432121441	5290	233	45G
0005434824466	5290	234	46A
0005434824497	5290	235	45K
0005435373179	5290	236	45J
0005434824440	5290	237	46C
0005432394131	5290	238	46D
0005435372968	5290	239	46G
0005434824449	5290	240	46J
0005434824476	5290	241	46H
0005434824532	5290	242	47A
0005435372887	5290	243	47D
0005435386569	5290	244	47C
0005435373126	5290	245	47G
0005434824523	5290	246	47F
0005435386568	5290	247	47E
0005434824428	5290	248	47K
0005432121437	5290	249	47H
0005435386567	5290	250	48C
0005435372927	5290	251	48A
0005434824507	5290	252	48F
0005435373258	5290	253	48H
0005434824554	5290	254	48G
0005434824434	5290	255	48K
0005434824502	5290	256	49E
0005434824521	5290	257	49C
0005435372833	5290	258	49G
0005434824472	5290	259	49F
0005435373065	5290	260	50E
0005434824485	5290	261	50G
0005435373150	5290	262	50F
0005434824519	5290	263	50K
0005434823490	9882	1	1D
0005435149941	9882	2	1C
0005434823770	9882	3	1A
0005435373713	9882	4	1G
0005434823438	9882	5	1K
0005434823172	9882	6	2C
0005434822823	9882	7	2A
0005434823411	9882	8	2D
0005434558237	9882	9	3C
0005435373716	9882	10	3A
0005434828694	9882	11	2K
0005435373757	9882	12	3D
0005435373727	9882	13	3K
0005435373720	9882	14	3G
0005435373730	9882	15	4C
0005434823605	9882	16	4A
0005435373695	9882	17	4G
0005432400120	9882	18	5A
0005434558247	9882	19	4K
0005434822891	9882	20	5D
0005434823378	9882	21	5H
0005435373751	9882	22	5G
0005434823176	9882	23	11A
0005435150003	9882	24	11C
0005434823302	9882	25	11F
0005435373759	9882	26	11E
0005435373741	9882	27	11K
0005432396239	9882	28	11H
0005435386614	9882	29	12C
0005435373749	9882	30	12E
0005435373728	9882	31	12D
0005434823480	9882	32	13A
0005435149994	9882	33	12K
0005435373745	9882	34	12H
0005434823769	9882	35	13D
0005435386619	9882	36	13K
0005434558233	9882	37	13H
0005432400110	9882	38	14A
0005435373696	9882	39	14D
0005435373715	9882	40	14G
0005435386620	9882	41	14E
0005435149984	9882	42	14K
0005435373711	9882	43	14H
0005432203118	9882	44	15A
0005434823821	9882	45	15E
0005434823053	9882	46	15D
0005435373705	9882	47	15H
0005434823175	9882	48	16F
0005434823430	9882	49	16K
0005435373697	9882	50	16H
0005435302229	9882	51	17A
0005435149986	9882	52	17D
0005434823764	9882	53	17C
0005434823538	9882	54	17G
0005435373743	9882	55	17E
0005435302234	9882	56	17H
0005435373750	9882	57	18C
0005432203115	9882	58	18B
0005432823465	9882	59	18A
0005435386615	9882	60	18E
0005434824040	9882	61	18G
0005434823440	9882	62	18F
0005434823601	9882	63	18J
0005434823147	9882	64	18H
0005434823728	9882	65	19D
0005435299808	9882	66	19C
0005434823294	9882	67	19F
0005434823704	9882	68	19E
0005434823680	9882	69	19J
0005435373735	9882	70	19K
0005434823043	9882	71	20C
0005435179401	9882	72	20A
0005435150012	9882	73	20E
0005435373726	9882	74	20D
0005434823978	9882	75	20H
0005434822824	9882	76	20G
0005434823504	9882	77	20F
0005434831153	9882	78	21B
0005434824041	9882	79	21A
0005434823323	9882	80	20K
0005434823173	9882	81	21D
0005435149995	9882	82	21C
0005434823576	9882	83	21E
0005435373701	9882	84	21H
0005434823745	9882	85	21G
0005434823609	9882	86	22A
0005435373733	9882	87	22C
0005434558240	9882	88	22B
0005435149997	9882	89	22E
0005434823697	9882	90	22H
0005434823300	9882	91	22F
0005435302230	9882	92	22J
0005434558260	9882	93	23B
0005435302231	9882	94	23A
0005435373712	9882	95	23D
0005434823365	9882	96	23C
0005435373734	9882	97	23G
0005434823424	9882	98	23F
0005434822777	9882	99	23H
0005434828691	9882	100	23K
0005435661953	9882	101	24G
0005435373704	9882	102	24E
0005435373755	9882	103	25B
0005435149940	9882	104	25A
0005435373732	9882	105	25F
0005432396243	9882	106	25E
0005434823848	9882	107	25G
0005435373725	9882	108	26C
0005435386618	9882	109	26A
0005434823506	9882	110	26E
0005435373754	9882	111	26D
0005434823505	9882	112	26F
0005434823638	9882	113	26J
0005434823762	9882	114	26H
0005434823226	9882	115	27B
0005435373699	9882	116	27A
0005434823412	9882	117	27F
0005435735169	9882	118	27J
0005434823952	9882	119	27G
0005434823496	9882	120	27K
0005432400118	9882	121	28B
0005435150053	9882	122	28E
0005434822892	9882	123	28C
0005435373760	9882	124	28F
0005434558250	9882	125	28H
0005435373761	9882	126	29A
0005435373747	9882	127	28K
0005435373739	9882	128	29D
0005435373752	9882	129	29F
0005435373703	9882	130	29E
0005435373714	9882	131	29H
0005434823393	9882	132	29G
0005434823060	9882	133	29J
0005434823391	9882	134	30B
0005434823631	9882	135	30A
0005435150050	9882	136	30D
0005434828693	9882	137	30C
0005434823681	9882	138	30G
0005434823431	9882	139	30F
0005435373702	9882	140	30J
0005434823437	9882	141	30H
0005434822902	9882	142	31A
0005435373744	9882	143	30K
0005435373762	9882	144	31D
0005435661952	9882	145	31C
0005434664954	9882	146	31B
0005435299809	9882	147	31F
0005434558236	9882	148	31H
0005435302232	9882	149	31G
0005435373719	9882	150	32A
0005435386616	9882	151	31K
0005434823705	9882	152	32C
0005434823781	9882	153	32E
0005435373700	9882	154	32D
0005434822811	9882	155	32H
0005435373722	9882	156	32G
0005434831154	9882	157	32F
0005434823385	9882	158	32J
0005434823044	9882	159	33B
0005434823392	9882	160	33D
0005435735172	9882	161	33C
0005435150002	9882	162	33F
0005434823628	9882	163	33J
0005435150051	9882	164	33H
0005434823612	9882	165	34A
0005435373717	9882	166	34C
0005435373724	9882	167	34B
0005435735170	9882	168	34E
0005434823573	9882	169	34D
0005434823635	9882	170	34H
0005435373729	9882	171	34K
0005434823858	9882	172	34J
0005434823388	9882	173	35B
0005434823189	9882	174	35C
0005434831152	9882	175	35E
0005434823799	9882	176	35G
0005434558246	9882	177	35K
0005434558249	9882	178	36C
0005434823047	9882	179	36B
0005434823066	9882	180	36F
0005434822968	9882	181	36D
0005434823510	9882	182	36G
0005435735171	9882	183	36K
0005432203113	9882	184	37B
0005432203111	9882	185	37D
0005434831159	9882	186	37C
0005434828692	9882	187	37G
0005434823001	9882	188	38A
0005435373709	9882	189	37K
0005434823303	9882	190	37J
0005434823293	9882	191	38C
0005435373706	9882	192	38H
0005434823265	9882	193	39A
0005435373723	9882	194	39D
0005435373721	9882	195	39C
0005435179400	9882	196	39B
0005432203119	9882	197	39E
0005435373738	9882	198	39K
0005434823156	9882	199	39J
0005432203114	9882	200	40C
0005435373710	9882	201	40B
0005432203116	9882	202	40A
0005434664957	9882	203	40E
0005434822907	9882	204	40G
0005434823627	9882	205	40K
0005434823389	9882	206	40J
0005432203112	9882	207	40H
0005435373707	9882	208	41A
0005434823425	9882	209	41B
0005434823604	9882	210	41F
0005435373740	9882	211	41E
0005434823439	9882	212	41H
0005434823602	9882	213	41G
0005434823465	9882	214	42A
0005434823610	9882	215	41J
0005435373758	9882	216	42C
0005435150010	9882	217	42E
0005434823577	9882	218	42D
0005434822908	9882	219	42F
0005434823489	9882	220	42J
0005434823780	9882	221	42H
0005434823761	9882	222	43B
0005434558232	9882	223	43A
0005435373748	9882	224	43D
0005435373737	9882	225	43C
0005432400114	9882	226	43E
0005435373746	9882	227	43H
0005435386617	9882	228	43K
0005435373708	9882	229	43J
0005432400121	9882	230	44B
0005434823853	9882	231	44D
0005434558238	9882	232	44C
0005434558241	9882	233	44H
0005435386613	9882	234	44F
0005435373736	9882	235	44K
0005435373753	9882	236	44J
0005434823160	9882	237	45B
0005435299810	9882	238	45A
0005434823304	9882	239	45D
0005434823814	9882	240	45C
0005434558243	9882	241	45E
0005434823894	9882	242	45H
0005434823637	9882	243	45G
0005434823466	9882	244	45J
0005434823820	9882	245	46C
0005434823046	9882	246	46A
0005435302233	9882	247	46E
0005434823188	9882	248	46G
0005434823813	9882	249	46F
0005434824139	9882	250	47C
0005434823048	9882	251	47A
0005435735168	9882	252	46K
0005435150009	9882	253	47E
0005434831158	9882	254	47D
0005435373731	9882	255	47G
0005434823216	9882	256	48C
0005434823290	9882	257	48F
0005432823464	9882	258	48D
0005435299807	9882	259	48H
0005434823849	9882	260	49A
0005435373742	9882	261	49G
0005434558242	9882	262	49E
0005435373718	9882	263	49K
0005432203117	9882	264	49H
0005435373756	9882	265	50C
0005435299811	9882	266	50A
0005434823497	9882	267	50E
0005434823227	9882	268	50D
0005434828695	9882	269	50G
0005435373698	9882	270	50K
0005434823509	9882	271	51F
0005432823466	9882	272	51D
0005435082846	7025	1	1C
0005435790327	7025	2	2C
0005435082842	7025	3	3D
0005435082849	7025	4	4A
0005435082845	7025	5	4B
0005435082841	7025	6	5A
0005435790326	7025	7	5C
0005435082843	7025	8	6A
0005435082850	7025	9	6C
0005435790328	7025	10	7C
0005435082848	7025	11	18A
0005435082844	7025	12	18C
0005435082847	7025	13	20D
0005435082780	26023	1	19A
0005435082770	26023	2	20A
0005434756722	9561	1	1C
0005434756726	9561	2	1D
0005434756729	9561	3	1F
0005434756745	9561	4	2A
0005434756717	9561	5	2D
0005434214428	9561	6	2F
0005434214444	9561	7	3A
0005434756734	9561	8	3C
0005434756744	9561	9	3D
0005434214481	9561	10	3F
0005434214416	9561	11	4A
0005434214342	9561	12	4C
0005434756715	9561	13	4D
0005434214530	9561	14	4E
0005434756713	9561	15	4F
0005434214500	9561	16	5A
0005434214384	9561	17	5C
0005434214578	9561	18	5D
0005434756733	9561	19	5F
0005434214482	9561	20	6A
0005434214531	9561	21	6C
0005434214393	9561	22	6D
0005434214357	9561	23	6E
0005434214339	9561	24	6F
0005434756741	9561	25	7A
0005434214483	9561	26	7D
0005434756731	9561	27	7E
0005434214315	9561	28	7F
0005434756740	9561	29	8A
0005434214348	9561	30	8C
0005434214460	9561	31	8D
0005434756730	9561	32	8E
0005434214590	9561	33	8F
0005434214405	9561	34	9A
0005434214365	9561	35	9C
0005434756714	9561	36	9D
0005434756743	9561	37	9E
0005434214328	9561	38	10A
0005434756721	9561	39	10C
0005434756727	9561	40	10D
0005434756732	9561	41	10E
0005434756716	9561	42	10F
0005434756742	9561	43	11A
0005434214364	9561	44	11C
0005434756735	9561	45	11D
0005434214441	9561	46	11E
0005434214410	9561	47	12A
0005434214334	9561	48	12C
0005434756739	9561	49	12D
0005434756746	9561	50	12E
0005434214579	9561	51	12F
0005434214459	9561	52	13A
0005434756724	9561	53	13C
0005434756728	9561	54	13E
0005434756720	9561	55	13F
0005434214503	9561	56	14C
0005434214396	9561	57	14A
0005434214496	9561	58	14D
0005434214402	9561	59	14E
0005434214407	9561	60	15A
0005434214406	9561	61	15C
0005434214469	9561	62	15D
0005434756712	9561	63	15E
0005434214343	9561	64	15F
0005434214392	9561	65	16A
0005434756738	9561	66	16C
0005434756725	9561	67	16D
0005434214316	9561	68	16E
0005434756723	9561	69	17A
0005434214394	9561	70	16F
0005434214415	9561	71	17D
0005434214422	9561	72	17E
0005434214248	9561	73	17F
0005434214385	9561	74	18C
0005434214311	9561	75	18D
0005434214495	9561	76	18E
0005434214395	9561	77	18F
0005434756719	9561	78	19A
0005434756736	9561	79	19C
0005434214386	9561	80	19E
0005434756737	9561	81	19F
0005434214475	9561	82	20C
0005434756718	9561	83	20E
0005434214401	9561	84	20F
0005434756188	28596	1	1A
0005434214820	28596	2	1C
0005434756257	28596	3	1D
0005434214812	28596	4	1F
0005434214798	28596	5	2A
0005434756293	28596	6	2C
0005434214794	28596	7	2D
0005434214827	28596	8	2F
0005434756240	28596	9	3A
0005434756305	28596	10	3C
0005434756155	28596	11	3D
0005434756332	28596	12	4A
0005434756326	28596	13	4C
0005434214795	28596	14	4E
0005434756154	28596	15	4F
0005434214833	28596	16	5A
0005434756349	28596	17	5D
0005434214800	28596	18	5E
0005434214830	28596	19	5F
0005434214832	28596	20	6C
0005434756351	28596	21	6D
0005434756187	28596	22	6E
0005434214828	28596	23	6F
0005434214793	28596	24	7A
0005434756350	28596	25	7C
0005434756246	28596	26	7D
0005434756283	28596	27	7E
0005434214811	28596	28	7F
0005434214807	28596	29	8C
0005434756289	28596	30	8D
0005434756333	28596	31	8E
0005434214803	28596	32	8F
0005434756327	28596	33	9A
0005434214825	28596	34	9C
0005434756313	28596	35	9D
0005434214801	28596	36	9E
0005434214806	28596	37	9F
0005434214816	28596	38	10A
0005434756256	28596	39	10C
0005434214838	28596	40	10D
0005434214797	28596	41	10E
0005434214829	28596	42	10F
0005434756335	28596	43	11A
0005434214831	28596	44	11C
0005434214796	28596	45	11E
0005434214836	28596	46	11F
0005434214839	28596	47	12A
0005434214815	28596	48	12C
0005434756201	28596	49	12D
0005434756265	28596	50	12E
0005434756334	28596	51	12F
0005434214823	28596	52	13A
0005434756215	28596	53	13C
0005434756282	28596	54	13D
0005434756321	28596	55	13E
0005434214821	28596	56	13F
0005434756090	28596	57	14A
0005434755984	28596	58	14C
0005434756247	28596	59	14D
0005434756331	28596	60	14E
0005434756231	28596	61	14F
0005434756156	28596	62	15A
0005434214814	28596	63	15C
0005434214824	28596	64	15D
0005434756320	28596	65	15E
0005434214808	28596	66	15F
0005434756216	28596	67	16A
0005434756195	28596	68	16D
0005434756345	28596	69	16E
0005434214809	28596	70	16F
0005434756319	28596	71	17A
0005434214810	28596	72	17C
0005434756196	28596	73	17D
0005434214799	28596	74	17F
0005434756235	28596	75	17E
0005434214805	28596	76	18A
0005434214826	28596	77	18C
0005434214802	28596	78	18E
0005434214837	28596	79	18F
0005434214835	28596	80	19C
0005434214817	28596	81	19D
0005434214818	28596	82	19E
0005434214834	28596	83	19F
0005434214819	28596	84	20A
0005434214822	28596	85	20C
0005434756306	28596	86	20D
0005434214804	28596	87	20E
0005434214813	28596	88	20F
0005435100145	10815	1	1B
0005434760179	10815	2	2C
0005434760199	10815	3	7B
0005434760177	10815	4	19B
0005434760178	10815	5	19C
0005434760198	10815	6	19D
0005435100110	31831	1	1A
0005434760215	31831	2	1D
0005434760216	31831	3	5C
0005435100127	31831	4	6C
0005435100122	31831	5	18C
0005434639499	2013	1	1A
0005434639519	2013	2	1C
0005433202348	2013	3	1D
0005433202254	2013	4	2A
0005433202365	2013	5	2C
0005433202306	2013	6	3A
0005434639510	2013	7	3B
0005433202313	2013	8	3C
0005434639507	2013	9	3D
0005433202341	2013	10	4B
0005433202256	2013	11	4A
0005432290654	2013	12	4C
0005434639516	2013	13	4D
0005433202344	2013	14	5A
0005433202335	2013	15	5B
0005434639520	2013	16	5C
0005433202340	2013	17	5D
0005433202321	2013	18	6A
0005433202255	2013	19	6B
0005434639502	2013	20	6C
0005434639521	2013	21	6D
0005433202345	2013	22	7A
0005434639508	2013	23	7B
0005434639500	2013	24	7C
0005434639505	2013	25	18A
0005434639503	2013	26	18B
0005434639506	2013	27	18C
0005433202347	2013	28	18D
0005433202320	2013	29	19A
0005432290657	2013	30	19B
0005434639517	2013	31	19C
0005434639501	2013	32	19D
0005434639509	2013	33	20A
0005434639513	2013	34	20B
0005433202274	2013	35	20C
0005433202336	2013	36	20D
0005434639512	2013	37	21A
0005434639511	2013	38	21C
0005434639504	2013	39	21D
0005434639518	2013	40	22A
0005434639514	2013	41	22B
0005432290656	2013	42	22C
0005432290655	2013	43	22D
0005434639515	2013	44	23A
0005435948333	2013	45	23B
0005434639317	23273	1	1A
0005433202461	23273	2	1B
0005434639215	23273	3	1C
0005434639318	23273	4	1D
0005434639266	23273	5	2A
0005433202455	23273	6	2B
0005434639296	23273	7	2C
0005434639357	23273	8	2D
0005434639274	23273	9	3B
0005434639217	23273	10	3A
0005434639216	23273	11	3C
0005434639294	23273	12	4A
0005433202462	23273	13	4B
0005434639309	23273	14	4C
0005434639358	23273	15	4D
0005434639252	23273	16	5A
0005434639163	23273	17	5B
0005433202454	23273	18	5C
0005434639353	23273	19	5D
0005433202451	23273	20	6A
0005433202459	23273	21	6B
0005433202456	23273	22	6C
0005434639370	23273	23	6D
0005434639135	23273	24	7A
0005434639253	23273	25	7B
0005434639303	23273	26	7C
0005434639275	23273	27	7D
0005434639264	23273	28	18A
0005433202458	23273	29	18B
0005434639134	23273	30	18C
0005434639130	23273	31	18D
0005434639310	23273	32	19A
0005433202457	23273	33	19B
0005433202463	23273	34	19C
0005434639263	23273	35	19D
0005434639354	23273	36	20A
0005434639254	23273	37	20B
0005434639192	23273	38	20C
0005434639321	23273	39	20D
0005434639156	23273	40	21A
0005434639249	23273	41	21B
0005433202460	23273	42	21C
0005434639311	23273	43	21D
0005433202452	23273	44	22A
0005434639283	23273	45	22B
0005434639109	23273	46	22C
0005434639164	23273	47	22D
0005434639306	23273	48	23A
0005433202453	23273	49	23B
0005434601001	6046	1	1A
0005433533335	6046	2	2A
0005435326669	6046	3	2C
0005434601004	6046	4	2F
0005433533337	6046	5	3D
0005435326753	6046	6	3F
0005434600994	6046	7	4C
0005433531320	6046	8	4F
0005434600999	6046	9	5A
0005434601009	6046	10	5C
0005434601014	6046	11	5D
0005434600992	6046	12	5E
0005434600998	6046	13	6A
0005435326750	6046	14	6C
0005435326691	6046	15	6D
0005434600989	6046	16	6E
0005432111301	6046	17	6F
0005434601007	6046	18	7A
0005435326736	6046	19	7C
0005433533334	6046	20	7E
0005433531323	6046	21	7F
0005435326754	6046	22	8A
0005434601008	6046	23	8D
0005435326770	6046	24	8E
0005434600996	6046	25	9C
0005435326734	6046	26	10A
0005433531321	6046	27	10D
0005434600991	6046	28	10E
0005435326792	6046	29	10F
0005435326671	6046	30	11C
0005433533336	6046	31	12E
0005434601003	6046	32	13A
0005434600993	6046	33	13C
0005434601011	6046	34	13E
0005434601002	6046	35	13F
0005433531322	6046	36	14A
0005434600995	6046	37	14D
0005434601006	6046	38	15A
0005434600990	6046	39	15C
0005434601015	6046	40	15F
0005434601013	6046	41	16D
0005432111302	6046	42	16E
0005435326686	6046	43	17D
0005435326670	6046	44	17C
0005434601000	6046	45	17E
0005434600997	6046	46	18A
0005435326741	6046	47	18D
0005435326742	6046	48	19A
0005434601010	6046	49	19C
0005434601005	6046	50	19D
0005432111300	6046	51	19F
0005435326737	6046	52	20C
0005434601012	6046	53	20D
0005434600849	18560	1	1C
0005434600667	18560	2	1F
0005434600814	18560	3	2A
0005435326848	18560	4	2C
0005434600794	18560	5	3A
0005434600751	18560	6	4A
0005434600792	18560	7	4E
0005435326850	18560	8	5A
0005434600752	18560	9	5C
0005435326844	18560	10	5F
0005434600626	18560	11	6A
0005434600813	18560	12	6D
0005433527245	18560	13	6E
0005435326843	18560	14	6F
0005433527230	18560	15	7D
0005434600769	18560	16	7F
0005434600682	18560	17	8A
0005433527239	18560	18	8E
0005434600852	18560	19	8F
0005434600889	18560	20	9A
0005435326845	18560	21	9C
0005434600728	18560	22	10A
0005435326839	18560	23	10F
0005434600908	18560	24	11A
0005434600740	18560	25	11C
0005434600793	18560	26	11D
0005433527229	18560	27	11F
0005435326847	18560	28	12D
0005434600888	18560	29	13A
0005434600749	18560	30	13C
0005435326841	18560	31	13E
0005434600909	18560	32	13F
0005434600729	18560	33	14D
0005434600760	18560	34	14E
0005435326842	18560	35	14F
0005434600693	18560	36	15C
0005433531286	18560	37	15E
0005433527240	18560	38	16C
0005434600739	18560	39	16D
0005435326838	18560	40	16F
0005433527251	18560	41	17C
0005433527246	18560	42	17E
0005435326849	18560	43	17F
0005434600733	18560	44	18E
0005435326846	18560	45	18F
0005434600727	18560	46	19A
0005435326851	18560	47	19C
0005434600750	18560	48	19D
0005435326852	18560	49	19F
0005434600694	18560	50	20A
0005435326840	18560	51	20C
0005434600622	18560	52	20D
0005434600621	18560	53	20E
0005434551552	10667	1	1A
0005433181029	10667	2	1C
0005433181014	10667	3	1F
0005434551580	10667	4	2A
0005433181002	10667	5	2C
0005434551585	10667	6	2D
0005434551574	10667	7	2F
0005434558325	10667	8	3C
0005434551575	10667	9	3D
0005433181025	10667	10	3F
0005434551602	10667	11	4A
0005434558328	10667	12	4C
0005434551603	10667	13	4D
0005434551599	10667	14	4E
0005434551563	10667	15	4F
0005434551595	10667	16	5A
0005434551581	10667	17	5C
0005433181061	10667	18	5D
0005433180965	10667	19	5E
0005434551590	10667	20	5F
0005433180946	10667	21	6A
0005434551570	10667	22	6C
0005434551555	10667	23	6D
0005434558327	10667	24	6E
0005434551578	10667	25	6F
0005434551550	10667	26	7C
0005434558326	10667	27	7D
0005434551566	10667	28	7E
0005433181073	10667	29	7F
0005433181031	10667	30	8A
0005433181057	10667	31	8C
0005433181058	10667	32	8D
0005434551573	10667	33	8E
0005434551604	10667	34	8F
0005434551572	10667	35	9A
0005434551583	10667	36	9C
0005434551551	10667	37	9D
0005434551597	10667	38	9E
0005434558330	10667	39	9F
0005433181030	10667	40	10A
0005433181028	10667	41	10C
0005434551561	10667	42	10D
0005434551562	10667	43	10E
0005433181027	10667	44	10F
0005433180994	10667	45	11A
0005433180960	10667	46	11C
0005434551579	10667	47	11D
0005434551567	10667	48	11E
0005433181006	10667	49	11F
0005434551557	10667	50	12A
0005433181026	10667	51	12C
0005434551564	10667	52	12D
0005434551560	10667	53	12E
0005434551559	10667	54	12F
0005434551587	10667	55	13A
0005434558331	10667	56	13C
0005434551568	10667	57	13D
0005433181034	10667	58	13E
0005434551582	10667	59	13F
0005434558333	10667	60	14A
0005434551598	10667	61	14C
0005433181060	10667	62	14D
0005434551600	10667	63	14E
0005434558329	10667	64	14F
0005433181035	10667	65	15A
0005434551588	10667	66	15C
0005434551591	10667	67	15D
0005434554079	10667	68	15E
0005434551589	10667	69	15F
0005434551593	10667	70	16A
0005434551554	10667	71	16C
0005433180945	10667	72	16E
0005434551569	10667	73	16F
0005433181124	10667	74	17A
0005434551586	10667	75	17C
0005434551577	10667	76	17D
0005434551594	10667	77	17E
0005434551556	10667	78	17F
0005433181033	10667	79	18A
0005434551558	10667	80	18C
0005434551576	10667	81	18D
0005434551565	10667	82	18E
0005433181021	10667	83	18F
0005434551601	10667	84	19A
0005433181074	10667	85	19C
0005434558332	10667	86	19D
0005434551584	10667	87	19F
0005434551571	10667	88	20A
0005433181003	10667	89	20C
0005434551553	10667	90	20D
0005434551596	10667	91	20E
0005434551592	10667	92	20F
0005433181280	27754	1	1C
0005433181277	27754	2	1F
0005433181295	27754	3	2D
0005433181274	27754	4	3C
0005433181285	27754	5	5C
0005433181282	27754	6	5E
0005433181269	27754	7	6A
0005433181272	27754	8	7A
0005433181287	27754	9	7E
0005433181288	27754	10	8E
0005433181289	27754	11	9A
0005433181284	27754	12	9E
0005433181290	27754	13	9F
0005433181268	27754	14	10A
0005433181275	27754	15	10D
0005433181276	27754	16	12A
0005433181279	27754	17	12D
0005433181283	27754	18	13A
0005433181273	27754	19	14E
0005433181278	27754	20	14F
0005433181291	27754	21	15C
0005433181294	27754	22	15F
0005433181293	27754	23	16D
0005433181270	27754	24	16F
0005433181292	27754	25	17A
0005433181286	27754	26	17C
0005433181271	27754	27	18E
0005433181281	27754	28	20E
0005434554067	27753	1	1A
0005434558255	27753	2	1C
0005434551188	27753	3	1F
0005434551429	27753	4	2C
0005434550948	27753	5	2D
0005434551335	27753	6	2F
0005434558254	27753	7	3A
0005434551110	27753	8	3F
0005434551288	27753	9	4A
0005434551029	27753	10	4D
0005434551055	27753	11	4E
0005434551242	27753	12	4F
0005434551056	27753	13	5D
0005434551169	27753	14	5E
0005434551069	27753	15	5F
0005434551316	27753	16	6C
0005434550902	27753	17	6D
0005434551121	27753	18	6E
0005434551111	27753	19	6F
0005434554061	27753	20	7C
0005434550890	27753	21	7D
0005434551264	27753	22	8C
0005434551261	27753	23	8E
0005434551120	27753	24	8F
0005434554062	27753	25	9D
0005434551473	27753	26	9E
0005434551065	27753	27	9F
0005434551024	27753	28	10A
0005434551185	27753	29	10D
0005434551241	27753	30	10E
0005434554070	27753	31	11A
0005434558265	27753	32	11C
0005434551300	27753	33	11D
0005434551292	27753	34	11E
0005434558239	27753	35	12A
0005434551186	27753	36	12C
0005434551057	27753	37	12D
0005434551243	27753	38	12E
0005434550949	27753	39	12F
0005434551393	27753	40	13A
0005434551317	27753	41	13C
0005434551008	27753	42	13D
0005434551028	27753	43	13E
0005434551046	27753	44	13F
0005434551334	27753	45	14C
0005434551047	27753	46	14D
0005434551017	27753	47	14E
0005434550905	27753	48	14F
0005434551293	27753	49	15A
0005434551266	27753	50	15C
0005434550867	27753	51	15D
0005434558244	27753	52	15F
0005434551101	27753	53	16A
0005434558266	27753	54	16C
0005434551031	27753	55	16E
0005434558229	27753	56	16F
0005434551231	27753	57	17A
0005434551030	27753	58	17D
0005434551168	27753	59	17E
0005434551187	27753	60	17F
0005434551265	27753	61	18A
0005434550969	27753	62	18C
0005434554065	27753	63	18D
0005434550737	27753	64	18E
0005434551119	27753	65	18F
0005434551336	27753	66	20C
0005434550970	27753	67	20E
0005434558267	27753	68	20F
0005433459250	6159	1	1A
0005433459248	6159	2	2A
0005433459251	6159	3	2B
0005433459247	6159	4	3A
0005435254466	6159	5	3B
0005435254467	6159	6	5A
0005435254468	6159	7	5B
0005433459249	6159	8	6A
0005435254490	19326	1	2B
0005433459209	19326	2	4B
0005433459225	19326	3	5A
0005433459218	19326	4	5B
0005435254491	19326	5	6A
0005435254492	19326	6	6B
0005435437934	6741	1	1A
0005435682441	6741	2	1C
0005435682438	6741	3	1D
0005435437993	6741	4	1F
0005432136206	6741	5	2A
0005435438028	6741	6	2C
0005432136204	6741	7	2D
0005435217700	6741	8	2F
0005435661951	6741	9	3A
0005435437957	6741	10	3C
0005435682413	6741	11	3D
0005435682450	6741	12	3F
0005435682451	6741	13	4A
0005435682420	6741	14	4C
0005432533286	6741	15	4D
0005435437724	6741	16	4E
0005435682437	6741	17	4F
0005435437919	6741	18	5A
0005435437886	6741	19	5C
0005435437944	6741	20	5D
0005435682423	6741	21	5E
0005435437725	6741	22	5F
0005435437956	6741	23	6A
0005435220307	6741	24	6C
0005435682418	6741	25	6D
0005435661949	6741	26	6E
0005435682415	6741	27	6F
0005435682447	6741	28	7A
0005435682432	6741	29	7C
0005435682445	6741	30	7D
0005435661948	6741	31	7E
0005435217704	6741	32	7F
0005435682425	6741	33	8A
0005435682426	6741	34	8C
0005435437958	6741	35	8D
0005435682408	6741	36	8E
0005435437943	6741	37	8F
0005432533285	6741	38	9A
0005435437945	6741	39	9C
0005435630986	6741	40	9D
0005435682444	6741	41	9E
0005432533281	6741	42	9F
0005435437994	6741	43	10A
0005435682412	6741	44	10C
0005432533280	6741	45	10D
0005435682421	6741	46	10E
0005432533290	6741	47	10F
0005435682452	6741	48	11A
0005435682434	6741	49	11C
0005435682422	6741	50	11D
0005435682419	6741	51	11E
0005435682449	6741	52	11F
0005435682417	6741	53	12A
0005435437959	6741	54	12D
0005435682435	6741	55	12E
0005435682414	6741	56	12F
0005434828686	6741	57	13A
0005435682409	6741	58	13C
0005435682416	6741	59	13D
0005435682424	6741	60	13E
0005432533289	6741	61	13F
0005435682427	6741	62	14A
0005435682439	6741	63	14C
0005435437933	6741	64	14D
0005435682440	6741	65	14E
0005435437904	6741	66	14F
0005435630985	6741	67	15A
0005432533275	6741	68	15C
0005435437983	6741	69	15D
0005435682428	6741	70	15E
0005435437853	6741	71	15F
0005432136202	6741	72	16A
0005435682410	6741	73	16C
0005435682429	6741	74	16D
0005432136205	6741	75	16E
0005435682431	6741	76	16F
0005434828690	6741	77	17A
0005435682446	6741	78	17C
0005435682411	6741	79	17D
0005435682433	6741	80	17E
0005435630987	6741	81	17F
0005435682436	6741	82	18A
0005435217706	6741	83	18C
0005432136203	6741	84	18D
0005435217707	6741	85	18E
0005435661950	6741	86	18F
0005435221511	6741	87	19C
0005435437917	6741	88	19D
0005435682453	6741	89	19E
0005435682443	6741	90	19F
0005435437918	6741	91	20C
0005435682442	6741	92	20D
0005435682448	6741	93	20E
0005435682430	6741	94	20F
0005435682166	24567	1	1A
0005435682058	24567	2	1C
0005435220492	24567	3	1D
0005435661924	24567	4	2F
0005435682012	24567	5	3A
0005434828720	24567	6	3C
0005435681835	24567	7	3D
0005435438113	24567	8	3F
0005435438104	24567	9	4A
0005435438106	24567	10	4C
0005435630977	24567	11	4D
0005435438099	24567	12	4E
0005435682078	24567	13	4F
0005435681986	24567	14	5A
0005435630948	24567	15	5C
0005435682074	24567	16	5D
0005435438117	24567	17	5E
0005435682022	24567	18	5F
0005435438098	24567	19	6A
0005435219213	24567	20	6C
0005435438118	24567	21	6D
0005435682133	24567	22	6E
0005435438105	24567	23	6F
0005432533313	24567	24	7A
0005435681917	24567	25	7C
0005435220332	24567	26	7D
0005435682148	24567	27	7E
0005435681988	24567	28	7F
0005435438116	24567	29	8A
0005435681975	24567	30	8C
0005435682167	24567	31	8D
0005435682176	24567	32	8E
0005435682030	24567	33	8F
0005435220334	24567	34	9A
0005435438112	24567	35	9C
0005435682006	24567	36	9D
0005435438100	24567	37	9E
0005435681871	24567	38	9F
0005435220333	24567	39	10A
0005435681987	24567	40	10C
0005435220331	24567	41	10E
0005435438101	24567	42	10F
0005435630966	24567	43	11A
0005435438120	24567	44	11D
0005435682003	24567	45	11E
0005435682013	24567	46	11F
0005435682131	24567	47	12A
0005435682136	24567	48	12C
0005435438119	24567	49	12D
0005435438108	24567	50	12E
0005435681998	24567	51	12F
0005434828717	24567	52	13A
0005435438102	24567	53	13C
0005435682021	24567	54	13D
0005432305766	24567	55	13E
0005435219212	24567	56	13F
0005435630967	24567	57	14A
0005435630965	24567	58	14C
0005435681974	24567	59	14D
0005435438114	24567	60	14E
0005435682157	24567	61	14F
0005435682132	24567	62	15A
0005432305765	24567	63	15C
0005435219214	24567	64	15D
0005432533312	24567	65	15E
0005435438115	24567	66	15F
0005435682113	24567	67	16A
0005435682001	24567	68	16C
0005435438111	24567	69	16D
0005434828719	24567	70	16E
0005435682177	24567	71	16F
0005435682108	24567	72	17A
0005434828716	24567	73	17C
0005434828718	24567	74	17D
0005435438110	24567	75	17E
0005432305767	24567	76	17F
0005435681963	24567	77	18A
0005435681959	24567	78	18D
0005435682073	24567	79	18F
0005435219215	24567	80	19A
0005435438107	24567	81	19F
0005435438103	24567	82	20A
0005435682141	24567	83	20C
0005435682077	24567	84	20D
0005435438109	24567	85	20E
0005435682130	24567	86	20F
0005435126620	11556	1	1C
0005435126613	11556	2	1D
0005435126614	11556	3	1F
0005435126618	11556	4	2A
0005435126627	11556	5	2C
0005435558084	11556	6	2F
0005435126634	11556	7	4A
0005435558086	11556	8	4C
0005435558075	11556	9	4E
0005435126636	11556	10	4F
0005435126626	11556	11	5A
0005435126625	11556	12	5C
0005435558074	11556	13	5F
0005435126639	11556	14	6C
0005435126629	11556	15	6D
0005435126616	11556	16	6F
0005435126608	11556	17	7C
0005435126606	11556	18	7D
0005435126638	11556	19	7F
0005435106003	11556	20	8A
0005435126631	11556	21	8C
0005435126632	11556	22	8F
0005435126630	11556	23	9A
0005435126642	11556	24	9C
0005435126637	11556	25	9D
0005435126633	11556	26	10C
0005435126612	11556	27	11A
0005435126615	11556	28	12A
0005435126607	11556	29	12D
0005435126617	11556	30	12E
0005435126605	11556	31	13E
0005435126644	11556	32	14C
0005435558082	11556	33	14D
0005435126640	11556	34	15A
0005435126621	11556	35	15C
0005435126643	11556	36	15D
0005435558081	11556	37	15E
0005435126619	11556	38	16C
0005435126609	11556	39	16D
0005435126623	11556	40	16F
0005435126628	11556	41	17D
0005435126635	11556	42	17F
0005435126624	11556	43	18A
0005435126641	11556	44	18E
0005435126645	11556	45	18F
0005435126622	11556	46	19A
0005435558089	11556	47	19D
0005435126611	11556	48	19E
0005435106002	11556	49	20C
0005435126610	11556	50	20D
0005435126240	31865	1	1A
0005435126290	31865	2	1D
0005435126267	31865	3	2A
0005435126244	31865	4	2D
0005435126313	31865	5	2F
0005435126437	31865	6	3A
0005435098551	31865	7	3D
0005435098539	31865	8	3F
0005435126278	31865	9	4C
0005435126431	31865	10	5A
0005435098560	31865	11	5C
0005435126255	31865	12	5D
0005435126241	31865	13	5E
0005435126189	31865	14	5F
0005435126232	31865	15	6A
0005435098559	31865	16	6C
0005435126188	31865	17	6D
0005435126393	31865	18	6E
0005435126266	31865	19	6F
0005435126294	31865	20	7A
0005435126360	31865	21	7C
0005435126242	31865	22	7E
0005435098552	31865	23	7F
0005435126231	31865	24	8C
0005435126250	31865	25	8D
0005435126254	31865	26	8E
0005435126415	31865	27	8F
0005435126249	31865	28	9C
0005435126379	31865	29	9D
0005435098553	31865	30	9E
0005435126517	31865	31	9F
0005435558105	31865	32	10A
0005435126307	31865	33	10C
0005435126247	31865	34	10D
0005435558106	31865	35	11C
0005435098554	31865	36	11D
0005435126339	31865	37	12A
0005435126097	31865	38	12D
0005435126330	31865	39	12E
0005435126369	31865	40	12F
0005435126469	31865	41	13A
0005435126168	31865	42	13C
0005435126327	31865	43	13D
0005435126312	31865	44	13F
0005435105976	31865	45	14A
0005435126293	31865	46	14C
0005435126277	31865	47	14D
0005435098538	31865	48	14E
0005435126341	31865	49	14F
0005435126212	31865	50	15A
0005435126292	31865	51	15C
0005435558104	31865	52	15D
0005435126096	31865	53	15E
0005435126414	31865	54	16A
0005435126151	31865	55	16E
0005435126434	31865	56	16F
0005435126370	31865	57	17A
0005435105982	31865	58	17C
0005435105983	31865	59	17E
0005435126245	31865	60	18A
0005435126420	31865	61	18C
0005435098558	31865	62	18F
0005435126215	31865	63	19A
0005435126265	31865	64	19C
0005435126223	31865	65	19F
0005435126213	31865	66	20A
0005435098555	31865	67	20C
0005435126246	31865	68	20D
0005435126214	31865	69	20F
0005433398412	13524	1	1F
0005433398380	13524	2	2A
0005433398386	13524	3	2C
0005435732323	13524	4	3A
0005433398393	13524	5	3C
0005433398398	13524	6	3D
0005433398381	13524	7	4D
0005433398404	13524	8	4E
0005433398395	13524	9	5A
0005433398406	13524	10	5D
0005433398418	13524	11	6A
0005433398402	13524	12	6F
0005433398387	13524	13	7A
0005433398409	13524	14	7C
0005433398390	13524	15	8A
0005435732324	13524	16	8D
0005435732303	13524	17	9D
0005433398416	13524	18	10A
0005433398419	13524	19	10C
0005433398414	13524	20	10D
0005435732362	13524	21	10F
0005433398391	13524	22	11A
0005433398399	13524	23	11C
0005433398408	13524	24	11E
0005433398376	13524	25	12A
0005435732361	13524	26	12C
0005433398374	13524	27	12F
0005433398401	13524	28	13A
0005433398382	13524	29	13C
0005433398389	13524	30	13D
0005433398420	13524	31	13E
0005433398411	13524	32	14E
0005433398417	13524	33	14F
0005435732290	13524	34	15A
0005433398415	13524	35	15D
0005433398379	13524	36	15F
0005433398410	13524	37	16A
0005433398397	13524	38	16D
0005433398377	13524	39	16E
0005433398383	13524	40	16F
0005433398385	13524	41	17A
0005433398400	13524	42	17C
0005433398392	13524	43	17D
0005433398378	13524	44	17E
0005435732304	13524	45	17F
0005433398394	13524	46	18D
0005433398384	13524	47	18E
0005433398375	13524	48	19A
0005433398373	13524	49	19C
0005433398388	13524	50	19D
0005433398407	13524	51	19E
0005433398396	13524	52	20A
0005433398405	13524	53	20C
0005433398403	13524	54	20D
0005435732359	13524	55	20E
0005433398413	13524	56	20F
0005433397809	19395	1	1D
0005435732409	19395	2	1F
0005435732405	19395	3	2C
0005433397989	19395	4	2D
0005435732413	19395	5	3A
0005435732402	19395	6	3C
0005435732400	19395	7	3D
0005435732408	19395	8	4A
0005433397836	19395	9	4C
0005435732415	19395	10	4D
0005433398044	19395	11	4E
0005433397886	19395	12	5E
0005433397855	19395	13	6A
0005435732395	19395	14	6F
0005433397987	19395	15	7C
0005435732411	19395	16	7D
0005432297295	19395	17	7E
0005433398029	19395	18	8C
0005435732407	19395	19	8D
0005433397990	19395	20	8E
0005435732419	19395	21	8F
0005433398024	19395	22	9C
0005435732412	19395	23	9D
0005435732397	19395	24	9E
0005433397887	19395	25	9F
0005432297298	19395	26	10C
0005432297297	19395	27	10D
0005433397856	19395	28	10E
0005435732417	19395	29	10F
0005435732404	19395	30	11A
0005435732401	19395	31	11F
0005435732416	19395	32	12C
0005433398028	19395	33	12D
0005435732418	19395	34	12F
0005435732414	19395	35	13C
0005433397917	19395	36	13D
0005433397933	19395	37	14A
0005433397831	19395	38	14C
0005433397930	19395	39	14E
0005433398034	19395	40	15A
0005435732396	19395	41	15C
0005435732410	19395	42	15D
0005433397891	19395	43	15E
0005435732398	19395	44	16E
0005433397946	19395	45	17C
0005433397908	19395	46	17E
0005433397952	19395	47	18C
0005435732399	19395	48	18D
0005435732406	19395	49	18F
0005432297296	19395	50	19D
0005435732403	19395	51	20D
0005433398144	19395	52	20C
0005433398037	19395	53	20F
0005435068838	13166	1	2A
0005435068795	13166	2	2C
0005435069057	13166	3	2D
0005435069105	13166	4	3A
0005435068822	13166	5	3D
0005435068647	13166	6	3F
0005435068748	13166	7	4C
0005435068888	13166	8	4D
0005435068971	13166	9	4E
0005435068897	13166	10	4F
0005435068967	13166	11	5D
0005435068829	13166	12	5E
0005435069028	13166	13	5F
0005435068991	13166	14	6C
0005435069041	13166	15	6D
0005435069016	13166	16	6E
0005435068868	13166	17	6F
0005435069106	13166	18	7C
0005435068853	13166	19	7D
0005435068852	13166	20	7F
0005435069042	13166	21	8A
0005435069055	13166	22	8C
0005435068988	13166	23	8D
0005435068765	13166	24	9A
0005435068828	13166	25	9C
0005435068709	13166	26	10A
0005435069017	13166	27	10E
0005435068894	13166	28	10F
0005435069018	13166	29	11A
0005435069186	13166	30	11C
0005435068889	13166	31	11D
0005435069001	13166	32	11F
0005435068898	13166	33	12A
0005435068992	13166	34	12D
0005435068746	13166	35	12E
0005435068851	13166	36	13C
0005435068942	13166	37	13D
0005435068911	13166	38	14D
0005435069015	13166	39	15C
0005435068895	13166	40	15F
0005435068874	13166	41	16A
0005435068747	13166	42	16C
0005435068919	13166	43	16D
0005435068864	13166	44	16F
0005435068982	13166	45	17C
0005435068922	13166	46	18C
0005435068987	13166	47	18E
0005435068906	13166	48	19A
0005435068754	13166	49	19C
0005435068899	13166	50	19F
0005435068966	13166	51	20A
0005435068900	13166	52	20C
0005435069003	13166	53	20D
0005435068708	13166	54	20F
0005435069396	15509	1	1A
0005435925234	15509	2	2A
0005435925273	15509	3	2C
0005435069399	15509	4	2D
0005435925263	15509	5	2F
0005435069410	15509	6	3A
0005435069404	15509	7	3C
0005435925286	15509	8	3F
0005435069385	15509	9	4A
0005435069414	15509	10	4E
0005435925289	15509	11	5C
0005435069429	15509	12	5E
0005435069397	15509	13	5F
0005435069378	15509	14	6A
0005435069415	15509	15	6C
0005435069418	15509	16	6D
0005435069424	15509	17	6E
0005435069392	15509	18	7C
0005435069417	15509	19	7D
0005435069411	15509	20	7E
0005435069401	15509	21	8A
0005435069391	15509	22	8D
0005435069400	15509	23	8E
0005435069420	15509	24	9A
0005435069382	15509	25	9D
0005435069393	15509	26	9E
0005435069419	15509	27	9F
0005435069428	15509	28	10A
0005435069413	15509	29	10D
0005435069407	15509	30	10F
0005435069394	15509	31	11A
0005435069412	15509	32	11C
0005435069423	15509	33	11E
0005435069405	15509	34	12A
0005435069425	15509	35	12C
0005435925264	15509	36	12D
0005435069406	15509	37	12E
0005435925251	15509	38	12F
0005435069377	15509	39	13C
0005435069384	15509	40	13D
0005435069409	15509	41	13E
0005435925285	15509	42	14A
0005435069427	15509	43	14C
0005435925290	15509	44	14D
0005435069408	15509	45	14E
0005435069383	15509	46	15A
0005435925280	15509	47	15C
0005435069380	15509	48	15E
0005435925281	15509	49	15F
0005435069381	15509	50	16C
0005435069422	15509	51	16D
0005435069388	15509	52	16E
0005435069379	15509	53	17A
0005435069398	15509	54	17C
0005435925265	15509	55	17D
0005435925231	15509	56	17E
0005435069402	15509	57	17F
0005435069389	15509	58	18D
0005435069386	15509	59	18E
0005435069395	15509	60	18F
0005435069387	15509	61	19A
0005435925210	15509	62	19C
0005435069421	15509	63	19E
0005435069390	15509	64	19F
0005435069416	15509	65	20A
0005435925255	15509	66	20C
0005435069426	15509	67	20D
0005435069403	15509	68	20E
0005435925287	15509	69	20F
0005433407561	23187	1	1C
0005433407518	23187	2	2A
0005435808297	23187	3	2B
0005433407541	23187	4	3A
0005435808294	23187	5	3D
0005435808289	23187	6	4A
0005433407542	23187	7	4B
0005435808299	23187	8	5A
0005435808301	23187	9	5C
0005435808296	23187	10	5D
0005433407562	23187	11	6A
0005435808295	23187	12	6C
0005435808300	23187	13	6D
0005435808292	23187	14	7A
0005435808286	23187	15	7B
0005433407538	23187	16	7C
0005435808290	23187	17	7D
0005435808303	23187	18	18C
0005433407531	23187	19	18D
0005433407544	23187	20	19A
0005435808298	23187	21	19B
0005435808287	23187	22	19C
0005433407565	23187	23	19D
0005435808291	23187	24	20A
0005435808288	23187	25	20C
0005435808284	23187	26	20D
0005435808285	23187	27	21A
0005435808293	23187	28	21B
0005435808304	23187	29	22B
0005433407563	23187	30	22C
0005433407530	23187	31	22D
0005433407543	23187	32	23A
0005435808302	23187	33	23B
0005434756397	10722	1	1A
0005434756296	10722	2	1C
0005434756302	10722	3	1D
0005434756280	10722	4	1F
0005434214860	10722	5	2A
0005434214857	10722	6	2C
0005434756325	10722	7	2D
0005434214885	10722	8	2F
0005434756299	10722	9	3A
0005434756324	10722	10	3C
0005434214868	10722	11	3D
0005434756315	10722	12	3F
0005434756279	10722	13	4C
0005434214852	10722	14	4E
0005434756249	10722	15	4D
0005434756259	10722	16	5A
0005434756160	10722	17	5C
0005434214862	10722	18	5E
0005434756248	10722	19	5F
0005434756295	10722	20	6A
0005434214855	10722	21	6C
0005434214859	10722	22	6D
0005434756365	10722	23	6E
0005434214867	10722	24	6F
0005434214880	10722	25	7C
0005434214844	10722	26	7D
0005434214871	10722	27	7E
0005434756260	10722	28	7F
0005434214842	10722	29	8A
0005434214848	10722	30	8C
0005434756347	10722	31	8D
0005434214874	10722	32	8E
0005434214858	10722	33	9A
0005434214886	10722	34	9C
0005434756391	10722	35	9D
0005434214887	10722	36	9E
0005434214865	10722	37	9F
0005434214850	10722	38	10A
0005434756236	10722	39	10D
0005434214845	10722	40	10E
0005434214882	10722	41	10F
0005434756223	10722	42	11C
0005434214846	10722	43	11D
0005434214869	10722	44	11F
0005434214884	10722	45	12A
0005434214870	10722	46	12D
0005434756395	10722	47	12E
0005434214863	10722	48	12F
0005434756314	10722	49	13C
0005434756266	10722	50	13D
0005434214877	10722	51	13E
0005434214878	10722	52	13F
0005434214849	10722	53	14A
0005434756288	10722	54	14C
0005434214851	10722	55	14D
0005434756219	10722	56	14F
0005434214861	10722	57	15A
0005434756271	10722	58	15C
0005434214872	10722	59	15D
0005434214864	10722	60	15E
0005434756209	10722	61	15F
0005434214879	10722	62	16A
0005434756218	10722	63	16C
0005434756328	10722	64	16D
0005434214875	10722	65	16E
0005434756221	10722	66	16F
0005434214840	10722	67	17A
0005434756341	10722	68	17D
0005434214854	10722	69	17E
0005434756394	10722	70	17F
0005434214853	10722	71	18A
0005434756287	10722	72	18C
0005434214847	10722	73	18D
0005434756222	10722	74	18E
0005434214873	10722	75	18F
0005434214883	10722	76	19A
0005434214843	10722	77	19C
0005434214866	10722	78	19E
0005434214841	10722	79	19F
0005434214856	10722	80	20A
0005434756342	10722	81	20C
0005434756364	10722	82	20D
0005434214876	10722	83	20E
0005434214881	10722	84	20F
0005434214336	28673	1	1A
0005434214303	28673	2	1C
0005434756695	28673	3	1F
0005434756700	28673	4	2A
0005434756688	28673	5	2C
0005434756682	28673	6	2D
0005434214400	28673	7	2F
0005434214269	28673	8	3A
0005434214472	28673	9	3C
0005434756672	28673	10	3D
0005434756668	28673	11	3F
0005434756685	28673	12	4A
0005434756683	28673	13	4C
0005434756708	28673	14	4D
0005434214545	28673	15	4E
0005434214547	28673	16	4F
0005434756693	28673	17	5A
0005434756673	28673	18	5C
0005434214437	28673	19	5D
0005434214361	28673	20	5E
0005434214274	28673	21	5F
0005434214418	28673	22	6A
0005434756702	28673	23	6C
0005434756709	28673	24	6D
0005434214341	28673	25	6E
0005434756699	28673	26	6F
0005434214294	28673	27	7A
0005434756697	28673	28	7C
0005434756704	28673	29	7E
0005434214522	28673	30	7F
0005434214417	28673	31	8A
0005434756670	28673	32	8D
0005434756696	28673	33	8E
0005434214313	28673	34	8F
0005434214304	28673	35	9C
0005434756679	28673	36	9D
0005434756703	28673	37	9E
0005434756665	28673	38	9F
0005434756706	28673	39	10C
0005434214548	28673	40	10D
0005434756681	28673	41	10E
0005434214356	28673	42	10F
0005434756689	28673	43	11A
0005434214293	28673	44	11C
0005434214382	28673	45	11D
0005434756667	28673	46	11F
0005434214163	28673	47	12A
0005434756674	28673	48	12C
0005434756707	28673	49	12E
0005434214362	28673	50	12F
0005434214270	28673	51	13A
0005434756701	28673	52	13C
0005434756692	28673	53	13D
0005434756687	28673	54	13E
0005434756677	28673	55	13F
0005434756705	28673	56	14A
0005434214340	28673	57	14C
0005434214257	28673	58	14D
0005434756684	28673	59	14E
0005434756710	28673	60	14F
0005434756711	28673	61	15A
0005434214295	28673	62	15C
0005434214389	28673	63	15D
0005434214391	28673	64	15E
0005434756686	28673	65	15F
0005434756676	28673	66	16A
0005434756691	28673	67	16C
0005434214432	28673	68	16D
0005434214305	28673	69	16E
0005434756666	28673	70	16F
0005434214301	28673	71	17A
0005434214390	28673	72	17C
0005434214471	28673	73	17D
0005434756694	28673	74	17E
0005434756698	28673	75	17F
0005434756671	28673	76	18A
0005434756680	28673	77	18C
0005434756678	28673	78	18D
0005434214322	28673	79	18E
0005434214273	28673	80	19A
0005434756675	28673	81	19C
0005434214302	28673	82	19D
0005434214181	28673	83	19E
0005434756669	28673	84	19F
0005434214399	28673	85	20A
0005434214383	28673	86	20D
0005434756690	28673	87	20E
0005434214307	28673	88	20F
0005434229271	5453	1	1C
0005435007195	5453	2	1D
0005432125502	5453	3	1F
0005434229392	5453	4	2A
0005432125506	5453	5	2D
0005435040212	5453	6	2C
0005435007185	5453	7	2F
0005432125507	5453	8	3C
0005435040208	5453	9	3A
0005435040237	5453	10	3D
0005435040245	5453	11	3F
0005435040227	5453	12	4C
0005432125504	5453	13	4B
0005435040215	5453	14	4D
0005434229357	5453	15	4E
0005434229400	5453	16	5A
0005435040238	5453	17	4F
0005435007180	5453	18	5D
0005435040229	5453	19	5C
0005434229353	5453	20	5E
0005434229217	5453	21	6A
0005434229299	5453	22	5F
0005435040230	5453	23	6B
0005434229275	5453	24	6C
0005435040195	5453	25	6D
0005434229328	5453	26	6F
0005434229372	5453	27	6E
0005435007178	5453	28	7A
0005435040244	5453	29	7B
0005435040234	5453	30	7C
0005434229267	5453	31	7D
0005435040231	5453	32	7F
0005434229430	5453	33	7E
0005435007183	5453	34	8A
0005435040251	5453	35	8B
0005435040225	5453	36	8E
0005435040198	5453	37	8D
0005434229329	5453	38	8F
0005432125500	5453	39	9B
0005435040210	5453	40	9A
0005432125503	5453	41	9D
0005435040233	5453	42	9C
0005435040247	5453	43	9F
0005434229313	5453	44	9E
0005434229337	5453	45	10C
0005435007184	5453	46	10B
0005435040202	5453	47	10D
0005432125501	5453	48	10E
0005435007198	5453	49	11B
0005435040236	5453	50	11C
0005435040252	5453	51	11E
0005434229358	5453	52	11D
0005435040199	5453	53	11F
0005435007186	5453	54	12A
0005434229351	5453	55	12B
0005435007182	5453	56	12E
0005434229352	5453	57	12D
0005435007189	5453	58	12F
0005434229338	5453	59	13A
0005435040209	5453	60	13C
0005435040221	5453	61	13E
0005435040220	5453	62	13D
0005435040235	5453	63	13F
0005435040205	5453	64	14A
0005435007200	5453	65	14D
0005435007181	5453	66	14C
0005435040253	5453	67	14F
0005435040243	5453	68	15B
0005435040250	5453	69	15A
0005434229334	5453	70	15C
0005434229398	5453	71	15D
0005432125505	5453	72	15E
0005435042871	5453	73	16A
0005435040242	5453	74	15F
0005435040197	5453	75	16B
0005435007196	5453	76	16C
0005435040241	5453	77	16D
0005434229399	5453	78	16E
0005435007199	5453	79	17A
0005435040218	5453	80	16F
0005435007194	5453	81	17B
0005434229314	5453	82	17C
0005435007193	5453	83	17D
0005435040222	5453	84	17F
0005435040203	5453	85	17E
0005435040224	5453	86	18A
0005434229270	5453	87	18B
0005435007197	5453	88	18C
0005435040213	5453	89	18E
0005435007190	5453	90	18D
0005435040217	5453	91	19A
0005434229315	5453	92	18F
0005435040223	5453	93	19B
0005434229266	5453	94	19D
0005435040240	5453	95	19C
0005435040246	5453	96	19E
0005434229365	5453	97	19F
0005435040216	5453	98	20B
0005435040248	5453	99	20A
0005435040232	5453	100	20D
0005435040249	5453	101	20C
0005435040204	5453	102	20E
0005435040226	5453	103	20F
0005435040196	5453	104	21B
0005435040219	5453	105	21A
0005435007179	5453	106	21C
0005434229306	5453	107	21D
0005435040201	5453	108	21F
0005435040206	5453	109	21E
0005435040211	5453	110	22A
0005435007191	5453	111	22C
0005435007192	5453	112	22E
0005435040207	5453	113	22D
0005435007201	5453	114	22F
0005435007187	5453	115	23B
0005435040214	5453	116	23A
0005435040239	5453	117	23D
0005435040228	5453	118	23C
0005435040200	5453	119	23E
0005435007188	5453	120	23F
0005435006932	13001	1	1A
0005435039717	13001	2	1D
0005435039708	13001	3	1C
0005435039690	13001	4	1F
0005435039631	13001	5	2A
0005434229537	13001	6	2D
0005435039226	13001	7	2C
0005435006973	13001	8	2F
0005435039348	13001	9	3A
0005435039616	13001	10	3C
0005435039734	13001	11	3F
0005434229542	13001	12	3D
0005435007004	13001	13	4A
0005435006848	13001	14	4C
0005435039805	13001	15	4B
0005435039720	13001	16	4D
0005434229527	13001	17	4E
0005435039612	13001	18	4F
0005435039751	13001	19	5B
0005435006915	13001	20	5A
0005435039578	13001	21	5C
0005435039635	13001	22	5D
0005435006931	13001	23	5E
0005435039766	13001	24	5F
0005435039412	13001	25	6B
0005434229534	13001	26	6A
0005434229526	13001	27	6C
0005434229524	13001	28	6D
0005435007009	13001	29	6E
0005435039719	13001	30	6F
0005435039687	13001	31	7B
0005435039558	13001	32	7A
0005435007011	13001	33	7C
0005435006881	13001	34	7E
0005434229541	13001	35	7D
0005435039686	13001	36	8A
0005435007019	13001	37	7F
0005435039707	13001	38	8B
0005434229535	13001	39	8D
0005435039735	13001	40	8C
0005434229521	13001	41	8E
0005435039363	13001	42	8F
0005435039365	13001	43	9A
0005435039329	13001	44	9B
0005435039752	13001	45	9D
0005434229539	13001	46	9C
0005435039521	13001	47	9F
0005435039841	13001	48	9E
0005435039700	13001	49	10B
0005435039525	13001	50	10D
0005435039443	13001	51	10C
0005435006928	13001	52	10E
0005435039550	13001	53	11A
0005435007022	13001	54	11B
0005435039669	13001	55	11C
0005435006882	13001	56	11D
0005435039619	13001	57	11F
0005435039360	13001	58	11E
0005435007020	13001	59	12A
0005435039842	13001	60	12B
0005435039227	13001	61	12D
0005434229528	13001	62	12C
0005432304425	13001	63	12E
0005435039835	13001	64	13A
0005435007010	13001	65	12F
0005435039567	13001	66	13C
0005434229532	13001	67	13B
0005435039679	13001	68	13D
0005435039602	13001	69	13E
0005435039737	13001	70	13F
0005435039859	13001	71	14B
0005434229536	13001	72	14A
0005435039663	13001	73	14C
0005435039854	13001	74	14D
0005434229525	13001	75	14E
0005435039718	13001	76	15A
0005432304427	13001	77	14F
0005435039533	13001	78	15B
0005435039793	13001	79	15C
0005435039639	13001	80	15D
0005435039676	13001	81	15F
0005434229523	13001	82	15E
0005435039617	13001	83	16B
0005435006962	13001	84	16A
0005434229544	13001	85	16C
0005435039633	13001	86	16D
0005435039422	13001	87	16F
0005434229533	13001	88	16E
0005435039618	13001	89	17B
0005434229530	13001	90	17A
0005435039794	13001	91	17D
0005434229531	13001	92	17C
0005435006927	13001	93	17F
0005435039476	13001	94	17E
0005434229543	13001	95	18A
0005435039586	13001	96	18B
0005435039640	13001	97	18D
0005435039641	13001	98	18C
0005434229522	13001	99	18E
0005435039753	13001	100	19A
0005435039645	13001	101	18F
0005435039685	13001	102	19C
0005435039328	13001	103	19B
0005435039797	13001	104	19D
0005435039357	13001	105	19F
0005435039865	13001	106	19E
0005435039502	13001	107	20B
0005435039364	13001	108	20A
0005435006944	13001	109	20C
0005435039209	13001	110	20D
0005435006954	13001	111	21A
0005435039733	13001	112	20F
0005435039566	13001	113	21C
0005435039500	13001	114	21B
0005435007084	13001	115	21D
0005435006914	13001	116	21F
0005435007075	13001	117	21E
0005434229540	13001	118	22B
0005432304424	13001	119	22A
0005432304426	13001	120	22C
0005435039210	13001	121	22D
0005435007066	13001	122	22E
0005435039522	13001	123	23A
0005435007067	13001	124	22F
0005434229529	13001	125	23B
0005435007036	13001	126	23C
0005435007076	13001	127	23D
0005435039442	13001	128	23F
0005434229538	13001	129	23E
0005435902729	14902	1	1A
0005434426800	14902	2	1D
0005435902554	14902	3	1F
0005435902728	14902	4	2A
0005434426783	14902	5	2C
0005434426808	14902	6	2D
0005435902747	14902	7	3D
0005432188628	14902	8	3F
0005435902721	14902	9	4C
0005434426792	14902	10	4D
0005434426788	14902	11	4F
0005435902618	14902	12	5A
0005432188629	14902	13	5C
0005435902624	14902	14	5E
0005434426796	14902	15	6A
0005434426806	14902	16	7A
0005434426780	14902	17	6F
0005434411806	14902	18	7C
0005434426804	14902	19	8A
0005435554179	14902	20	8C
0005434426785	14902	21	8D
0005435902661	14902	22	8E
0005434426807	14902	23	8F
0005435902570	14902	24	9A
0005435902746	14902	25	9D
0005435902607	14902	26	9F
0005434426778	14902	27	10A
0005434426797	14902	28	10C
0005435902625	14902	29	10E
0005434426793	14902	30	10F
0005434426803	14902	31	11A
0005435902571	14902	32	11C
0005435902666	14902	33	11D
0005435902555	14902	34	11E
0005434411805	14902	35	11F
0005435902617	14902	36	12D
0005434426781	14902	37	12F
0005434426790	14902	38	13A
0005434426784	14902	39	13E
0005434426801	14902	40	13F
0005434426786	14902	41	14A
0005434426805	14902	42	14C
0005434426798	14902	43	14D
0005432188626	14902	44	14F
0005434411804	14902	45	15D
0005434426794	14902	46	16C
0005434426791	14902	47	16D
0005435902665	14902	48	16E
0005435902569	14902	49	17C
0005435902556	14902	50	17E
0005432188627	14902	51	18D
0005434426782	14902	52	18E
0005434426802	14902	53	18F
0005434426795	14902	54	19F
0005434426799	14902	55	20A
0005434426787	14902	56	20D
0005434426789	14902	57	20E
0005434426779	14902	58	20F
0005434426550	20199	1	1A
0005434411761	20199	2	1C
0005434426472	20199	3	1D
0005434426553	20199	4	1F
0005434426593	20199	5	2A
0005434426532	20199	6	2F
0005434426594	20199	7	3C
0005435902840	20199	8	3D
0005435902829	20199	9	3F
0005435902832	20199	10	4A
0005435902831	20199	11	4C
0005435554222	20199	12	5C
0005435902833	20199	13	5E
0005434426480	20199	14	5F
0005434426541	20199	15	6A
0005435902828	20199	16	6D
0005435902834	20199	17	6F
0005434426672	20199	18	7C
0005435554224	20199	19	7D
0005434426564	20199	20	7E
0005435554226	20199	21	8A
0005434426592	20199	22	8E
0005434426609	20199	23	9C
0005434426617	20199	24	9E
0005435554223	20199	25	9F
0005435902835	20199	26	10A
0005434426479	20199	27	10C
0005434411787	20199	28	10F
0005434426573	20199	29	11A
0005434426533	20199	30	11D
0005432059519	20199	31	12C
0005435902822	20199	32	12D
0005434426565	20199	33	12F
0005435902824	20199	34	13A
0005434426495	20199	35	13F
0005435902837	20199	36	14C
0005434426552	20199	37	14D
0005434426531	20199	38	14E
0005435902826	20199	39	14F
0005434426512	20199	40	15A
0005434411760	20199	41	15C
0005434426725	20199	42	15D
0005435902823	20199	43	15E
0005435554225	20199	44	15F
0005435902839	20199	45	16A
0005434426614	20199	46	16C
0005435902821	20199	47	16D
0005435902825	20199	48	16E
0005434426635	20199	49	16F
0005435902830	20199	50	17D
0005435902836	20199	51	17E
0005434426613	20199	52	18A
0005434426708	20199	53	18C
0005435902827	20199	54	18F
0005432059518	20199	55	19A
0005435902838	20199	56	19C
0005434426563	20199	57	19D
0005434426520	20199	58	20A
0005434426460	20199	59	20C
0005434426608	20199	60	20D
0005434426634	20199	61	20F
0005432462511	30892	1	3C
0005434559097	30892	2	4C
0005432462513	30892	3	4F
0005432462508	30892	4	5A
0005434523789	30892	5	6E
0005434523787	30892	6	7B
0005434559098	30892	7	8A
0005434523790	30892	8	8B
0005434523784	30892	9	9C
0005432462502	30892	10	9B
0005434559096	30892	11	11B
0005434523783	30892	12	12B
0005434523786	30892	13	13D
0005432462517	30892	14	13F
0005432462509	30892	15	14A
0005432462501	30892	16	15C
0005434523791	30892	17	16D
0005434523788	30892	18	17B
0005434559099	30892	19	17E
0005432462500	30892	20	18D
0005434523785	30892	21	18F
0005434523792	30892	22	21A
0005432462503	30892	23	22D
0005432462518	30892	24	23A
0005432462504	30892	25	23E
0005433434474	26513	1	1A
0005432300300	26513	2	1C
0005435982612	26513	3	1D
0005435982602	26513	4	1F
0005435982615	26513	5	2A
0005435982596	26513	6	2C
0005435982581	26513	7	2D
0005435982617	26513	8	2F
0005435982613	26513	9	3A
0005435982607	26513	10	3D
0005435982600	26513	11	3F
0005433434666	26513	12	4A
0005433434669	26513	13	4C
0005435982594	26513	14	4D
0005435982592	26513	15	4E
0005435982595	26513	16	4F
0005435982589	26513	17	5A
0005435982611	26513	18	5C
0005433434719	26513	19	5D
0005433434665	26513	20	5E
0005435982593	26513	21	5F
0005435982572	26513	22	6A
0005433434608	26513	23	6C
0005435982585	26513	24	6D
0005435982587	26513	25	6E
0005432300298	26513	26	7C
0005433434686	26513	27	7E
0005433434703	26513	28	8A
0005435982575	26513	29	8C
0005435982603	26513	30	8D
0005433434615	26513	31	8E
0005432300297	26513	32	8F
0005435982582	26513	33	9A
0005432300301	26513	34	9C
0005435982619	26513	35	9D
0005433434645	26513	36	9F
0005435982580	26513	37	10A
0005435982588	26513	38	10C
0005435982579	26513	39	10D
0005435982573	26513	40	10E
0005432300299	26513	41	10F
0005432300302	26513	42	11A
0005435982571	26513	43	11E
0005435982610	26513	44	11F
0005434270195	26513	45	12A
0005433434600	26513	46	12C
0005433434520	26513	47	12D
0005435982609	26513	48	12F
0005433434560	26513	49	12E
0005433434617	26513	50	13A
0005433434718	26513	51	13C
0005435982583	26513	52	13D
0005435982614	26513	53	13E
0005434270203	26513	54	13F
0005433434601	26513	55	14A
0005435982618	26513	56	14D
0005434270209	26513	57	14F
0005435982591	26513	58	15A
0005433434542	26513	59	15C
0005435982584	26513	60	15D
0005435982604	26513	61	15E
0005434273071	26513	62	15F
0005435982605	26513	63	16A
0005435982590	26513	64	16C
0005433434496	26513	65	16D
0005433434577	26513	66	16E
0005435982599	26513	67	16F
0005434273069	26513	68	17A
0005433434475	26513	69	17C
0005433434525	26513	70	17D
0005435982616	26513	71	17E
0005435982576	26513	72	17F
0005435982608	26513	73	18A
0005435982578	26513	74	18C
0005435982574	26513	75	18E
0005433434578	26513	76	19A
0005433434495	26513	77	19C
0005435982577	26513	78	19E
0005435982601	26513	79	19F
0005435982586	26513	80	20A
0005435982597	26513	81	20C
0005433434476	26513	82	20D
0005435982598	26513	83	20E
0005435982606	26513	84	20F
0005435982191	26713	1	1A
0005435982246	26713	2	1C
0005435982309	26713	3	1D
0005433434874	26713	4	1F
0005433434897	26713	5	2A
0005435982129	26713	6	2C
0005435982212	26713	7	2D
0005433434894	26713	8	2F
0005435982267	26713	9	3A
0005433434878	26713	10	3D
0005434269119	26713	11	3F
0005435981916	26713	12	4A
0005435982253	26713	13	4C
0005433434892	26713	14	4D
0005434271327	26713	15	4E
0005433434880	26713	16	4F
0005435982256	26713	17	5A
0005433434884	26713	18	5C
0005433434898	26713	19	5D
0005435982213	26713	20	5E
0005433434883	26713	21	5F
0005433434891	26713	22	6A
0005433434888	26713	23	6C
0005435982240	26713	24	6D
0005435982217	26713	25	6F
0005435982221	26713	26	7A
0005433434876	26713	27	7C
0005434269118	26713	28	7D
0005435982372	26713	29	7E
0005435982275	26713	30	7F
0005435981975	26713	31	8A
0005433434885	26713	32	8C
0005435982333	26713	33	8D
0005435982146	26713	34	8E
0005435982363	26713	35	8F
0005435982071	26713	36	9A
0005434271328	26713	37	9C
0005435982047	26713	38	9D
0005433434873	26713	39	10A
0005435982254	26713	40	10C
0005435982147	26713	41	10D
0005433434886	26713	42	10E
0005435982362	26713	43	10F
0005432051150	26713	44	11A
0005433434875	26713	45	11C
0005435982283	26713	46	11D
0005435982218	26713	47	11E
0005433434889	26713	48	11F
0005433434877	26713	49	12A
0005434270221	26713	50	12D
0005435982110	26713	51	12E
0005435982307	26713	52	12F
0005435982261	26713	53	13A
0005435982046	26713	54	13C
0005432051152	26713	55	13D
0005433434882	26713	56	13E
0005435982268	26713	57	13F
0005435982211	26713	58	14A
0005435982170	26713	59	14C
0005435982276	26713	60	14D
0005435982284	26713	61	14E
0005435982190	26713	62	15A
0005434270222	26713	63	15C
0005435982208	26713	64	15D
0005433434890	26713	65	15E
0005433434887	26713	66	15F
0005435982173	26713	67	16A
0005435982168	26713	68	16C
0005435981981	26713	69	16D
0005433434896	26713	70	16E
0005433434881	26713	71	17A
0005433434879	26713	72	17C
0005435981974	26713	73	17D
0005434269120	26713	74	17E
0005435982207	26713	75	17F
0005433434893	26713	76	18A
0005435982174	26713	77	18C
0005433434871	26713	78	18D
0005433434872	26713	79	18E
0005435982096	26713	80	19A
0005435982070	26713	81	19C
0005435982255	26713	82	19D
0005435982169	26713	83	19E
0005435982236	26713	84	19F
0005433434895	26713	85	20C
0005435982056	26713	86	20D
0005435982167	26713	87	20E
0005432051151	26713	88	20F
0005432858096	3149	1	1A
0005432584221	3149	2	1B
0005432584222	3149	3	1D
0005432584205	3149	4	2A
0005432584227	3149	5	2B
0005432858062	3149	6	2C
0005432584214	3149	7	2D
0005432584211	3149	8	3A
0005432584219	3149	9	3C
0005432858104	3149	10	3D
0005432216293	3149	11	4A
0005432858056	3149	12	4B
0005432858064	3149	13	4C
0005432584204	3149	14	5A
0005432858097	3149	15	5D
0005432584208	3149	16	6A
0005432216292	3149	17	6B
0005432584226	3149	18	6C
0005432858024	3149	19	7A
0005432858093	3149	20	7B
0005432584201	3149	21	7C
0005432858054	3149	22	7D
0005432584207	3149	23	18A
0005432584213	3149	24	18B
0005432584218	3149	25	18C
0005432584225	3149	26	18D
0005432584224	3149	27	19B
0005432584220	3149	28	19C
0005432584223	3149	29	19D
0005432584212	3149	30	20A
0005432584203	3149	31	20B
0005432858007	3149	32	20C
0005432584210	3149	33	21A
0005432858035	3149	34	21B
0005432584217	3149	35	21C
0005432584202	3149	36	21D
0005432584209	3149	37	22A
0005432584215	3149	38	22B
0005432584216	3149	39	22C
0005432858105	3149	40	23A
0005432584206	3149	41	23B
0005432858149	31466	1	1A
0005432584004	31466	2	1B
0005432584060	31466	3	1C
0005432583996	31466	4	1D
0005432584038	31466	5	2A
0005432584003	31466	6	2B
0005432858151	31466	7	2C
0005432583897	31466	8	2D
0005432584095	31466	9	3A
0005432584002	31466	10	3B
0005432584017	31466	11	3D
0005432858156	31466	12	4A
0005432858150	31466	13	4B
0005432858159	31466	14	4C
0005432584016	31466	15	4D
0005432584050	31466	16	5A
0005432858153	31466	17	5C
0005432584012	31466	18	5D
0005432584039	31466	19	6A
0005432583998	31466	20	6B
0005432584059	31466	21	6C
0005432584029	31466	22	7B
0005432858157	31466	23	7C
0005432584030	31466	24	7D
0005432858158	31466	25	18A
0005432858155	31466	26	18B
0005432583950	31466	27	18C
0005432858154	31466	28	18D
0005432583949	31466	29	19A
0005432858148	31466	30	19D
0005432584094	31466	31	20A
0005432584061	31466	32	20B
0005432584001	31466	33	20D
0005432583995	31466	34	21A
0005432584171	31466	35	21D
0005432858152	31466	36	22B
0005432583945	31466	37	22A
0005432584018	31466	38	22C
0005432583937	31466	39	22D
0005432584011	31466	40	23A
0005432584025	31466	41	23B
0005434943414	855	1	2B
0005434943413	855	2	3A
0005434943416	855	3	3C
0005434943417	855	4	5A
0005433255115	855	5	6B
0005434943419	855	6	7D
0005434943412	855	7	18D
0005434943421	855	8	19B
0005434943418	855	9	19D
0005433255114	855	10	20A
0005434943415	855	11	20B
0005434943420	855	12	20C
0005434943360	16223	1	1B
0005434943372	16223	2	2B
0005434943371	16223	3	4A
0005434943353	16223	4	4D
0005433255160	16223	5	5D
0005434943359	16223	6	6A
0005433255158	16223	7	6C
0005433255159	16223	8	6D
0005433255156	16223	9	7B
0005434943350	16223	10	18C
0005433255157	16223	11	19A
0005433255162	16223	12	19B
0005434943331	16223	13	19D
0005434943345	16223	14	20A
0005434943349	16223	15	20B
0005434943346	16223	16	21A
0005434943312	16223	17	22A
0005433255155	16223	18	22B
0005434943340	16223	19	22C
0005433255161	16223	20	22D
0005433654750	27618	1	1F
0005433654713	27618	2	2A
0005435858589	27618	3	3A
0005433654737	27618	4	5A
0005433654715	27618	5	4D
0005433654716	27618	6	5D
0005435858580	27618	7	6C
0005435858590	27618	8	6E
0005435858584	27618	9	6D
0005433654759	27618	10	7B
0005435858592	27618	11	7A
0005433654711	27618	12	7C
0005433654753	27618	13	7F
0005433654749	27618	14	8B
0005433654714	27618	15	8D
0005433654767	27618	16	8E
0005435858594	27618	17	10A
0005435858587	27618	18	11A
0005433654740	27618	19	10F
0005433654780	27618	20	11B
0005433654771	27618	21	11D
0005433654741	27618	22	12B
0005433654738	27618	23	12A
0005435858579	27618	24	12D
0005433654758	27618	25	13B
0005435858582	27618	26	13E
0005433654756	27618	27	14D
0005433654742	27618	28	15B
0005433654751	27618	29	15C
0005433654712	27618	30	15E
0005435858585	27618	31	15F
0005433654743	27618	32	16D
0005435858586	27618	33	16F
0005433654773	27618	34	17B
0005433654752	27618	35	17F
0005433654776	27618	36	18C
0005433654754	27618	37	18B
0005433654739	27618	38	18E
0005435858591	27618	39	19A
0005433654745	27618	40	19E
0005435858581	27618	41	19F
0005435858593	27618	42	20B
0005433654762	27618	43	20A
0005435858583	27618	44	20D
0005433654757	27618	45	21B
0005435858588	27618	46	21E
0005435653345	21735	1	1A
0005435653307	21735	2	1C
0005435653344	21735	3	1D
0005433367698	21735	4	1F
0005433367810	21735	5	2A
0005433367924	21735	6	2C
0005433367617	21735	7	2D
0005435653348	21735	8	2F
0005435653336	21735	9	3A
0005435653331	21735	10	3C
0005433367767	21735	11	3D
0005435653342	21735	12	3F
0005435653304	21735	13	4C
0005435653334	21735	14	4D
0005433367788	21735	15	4E
0005435653303	21735	16	4F
0005433367846	21735	17	5A
0005433367887	21735	18	5C
0005435653338	21735	19	5D
0005435653306	21735	20	6A
0005435653296	21735	21	6C
0005435653346	21735	22	6E
0005435653347	21735	23	7A
0005435653327	21735	24	7D
0005435653299	21735	25	7E
0005433367738	21735	26	7F
0005435653324	21735	27	8A
0005433367756	21735	28	8C
0005435653329	21735	29	8D
0005435653332	21735	30	8E
0005435653339	21735	31	8F
0005435653325	21735	32	9A
0005433367735	21735	33	9C
0005433367763	21735	34	9D
0005435653310	21735	35	9E
0005435653317	21735	36	9F
0005435653343	21735	37	10A
0005435653323	21735	38	10C
0005435653297	21735	39	10F
0005433367768	21735	40	11C
0005435653311	21735	41	11D
0005435653326	21735	42	11F
0005435653340	21735	43	12A
0005435653301	21735	44	12C
0005435653305	21735	45	12D
0005435653300	21735	46	12E
0005433367685	21735	47	12F
0005435653298	21735	48	13A
0005435653322	21735	49	13D
0005433367802	21735	50	13F
0005435653313	21735	51	14A
0005435653312	21735	52	14C
0005435653333	21735	53	14E
0005435653309	21735	54	14F
0005433367773	21735	55	15A
0005433367809	21735	56	15E
0005435653337	21735	57	16A
0005433367934	21735	58	16D
0005435653341	21735	59	16E
0005435653295	21735	60	16F
0005435653315	21735	61	17A
0005433367684	21735	62	17C
0005435653321	21735	63	17D
0005433367762	21735	64	17F
0005435653318	21735	65	18C
0005435653316	21735	66	18D
0005433367847	21735	67	18E
0005435653328	21735	68	18F
0005435653320	21735	69	19A
0005435653330	21735	70	19C
0005435653335	21735	71	19D
0005435653319	21735	72	19E
0005435653314	21735	73	19F
0005435653302	21735	74	20A
0005433367902	21735	75	20C
0005435653308	21735	76	20D
0005433367618	21735	77	20E
0005433367886	21735	78	20F
0005433785220	9362	1	1A
0005433763312	9362	2	1F
0005433785195	9362	3	1C
0005434273070	9362	4	1G
0005433785218	9362	5	1H
0005434151708	9362	6	2B
0005433785202	9362	7	2F
0005434171049	9362	8	2C
0005433785222	9362	9	2G
0005433763305	9362	10	3A
0005434151687	9362	11	2H
0005432657472	9362	12	3G
0005433763303	9362	13	3H
0005434270212	9362	14	4C
0005433805621	9362	15	4F
0005433785197	9362	16	5A
0005433785212	9362	17	5F
0005433785215	9362	18	9A
0005432665290	9362	19	5G
0005434171044	9362	20	9H
0005433763313	9362	21	11D
0005433805622	9362	22	11B
0005433785192	9362	23	11E
0005434170990	9362	24	11H
0005434170977	9362	25	12A
0005433805620	9362	26	12D
0005433805626	9362	27	12B
0005433785198	9362	28	12E
0005433805623	9362	29	12G
0005433785201	9362	30	12F
0005432657470	9362	31	13A
0005434170978	9362	32	13B
0005433785190	9362	33	13E
0005433805633	9362	34	13G
0005433805616	9362	35	13F
0005433785199	9362	36	13H
0005433805625	9362	37	14B
0005434171004	9362	38	14E
0005434171048	9362	39	14G
0005434171034	9362	40	14H
0005433785211	9362	41	15B
0005433785216	9362	42	15F
0005433785209	9362	43	15E
0005433785213	9362	44	16A
0005434171018	9362	45	16D
0005434171071	9362	46	16E
0005433763308	9362	47	17B
0005433763306	9362	48	17D
0005433763302	9362	49	18A
0005434171055	9362	50	17H
0005433785188	9362	51	18D
0005433805641	9362	52	18G
0005433805635	9362	53	18H
0005433763309	9362	54	19A
0005433785196	9362	55	19E
0005433785204	9362	56	19D
0005433805631	9362	57	19F
0005432657471	9362	58	20D
0005433805636	9362	59	20F
0005432667469	9362	60	21B
0005432666404	9362	61	21A
0005433805629	9362	62	21D
0005434171035	9362	63	21H
0005433763311	9362	64	22B
0005433785205	9362	65	22D
0005433763310	9362	66	22G
0005433785207	9362	67	22F
0005433805638	9362	68	23E
0005434171017	9362	69	23D
0005432657469	9362	70	23G
0005433805618	9362	71	23H
0005433805617	9362	72	24D
0005433763307	9362	73	24A
0005434171088	9362	74	24E
0005433805619	9362	75	24F
0005434171097	9362	76	24H
0005433785206	9362	77	24G
0005433785214	9362	78	27D
0005433805643	9362	79	27F
0005433805628	9362	80	27E
0005432667470	9362	81	27H
0005434170976	9362	82	28E
0005434171009	9362	83	28D
0005433785217	9362	84	28F
0005432665288	9362	85	28H
0005434151686	9362	86	29B
0005433785221	9362	87	29E
0005433785208	9362	88	29D
0005434270208	9362	89	29F
0005434171003	9362	90	29H
0005433805642	9362	91	29G
0005433785210	9362	92	30A
0005432666403	9362	93	30E
0005433805632	9362	94	30G
0005433785203	9362	95	30H
0005433785219	9362	96	31B
0005433805637	9362	97	31D
0005433763316	9362	98	31F
0005435269672	9362	99	31H
0005433805640	9362	100	32B
0005434171072	9362	101	32F
0005434171089	9362	102	32E
0005434171073	9362	103	32H
0005433763304	9362	104	32G
0005433805624	9362	105	33E
0005434171014	9362	106	33F
0005433805634	9362	107	33H
0005433763314	9362	108	34A
0005433805630	9362	109	35A
0005433785194	9362	110	35D
0005432665289	9362	111	35E
0005435269673	9362	112	35F
0005433785200	9362	113	35H
0005433785193	9362	114	36B
0005434151688	9362	115	36H
0005433805639	9362	116	37B
0005433785189	9362	117	37F
0005433805627	9362	118	38A
0005433763315	9362	119	37H
0005433785191	9362	120	38D
0005434170989	9362	121	38G
0005434171153	26267	1	1A
0005433784830	26267	2	1B
0005434171161	26267	3	2A
0005433784875	26267	4	2F
0005433784813	26267	5	3B
0005433784747	26267	6	3F
0005434171152	26267	7	3G
0005433805307	26267	8	4A
0005433785027	26267	9	3H
0005435269791	26267	10	4B
0005433784795	26267	11	4C
0005433763167	26267	12	4H
0005434271326	26267	13	5B
0005433805429	26267	14	9A
0005433785003	26267	15	5H
0005433805378	26267	16	9G
0005435269793	26267	17	9H
0005434270220	26267	18	11B
0005434269116	26267	19	11E
0005433784880	26267	20	11D
0005435269787	26267	21	11F
0005434171163	26267	22	11G
0005433785026	26267	23	12A
0005433805368	26267	24	12D
0005435269794	26267	25	12E
0005433784917	26267	26	12F
0005433805342	26267	27	12G
0005433784797	26267	28	13A
0005434171154	26267	29	13D
0005433805329	26267	30	13E
0005434270219	26267	31	13F
0005433784845	26267	32	14A
0005433805356	26267	33	13G
0005434151725	26267	34	14E
0005433784970	26267	35	14D
0005433805370	26267	36	14G
0005433805432	26267	37	15A
0005433784796	26267	38	15E
0005433784905	26267	39	15D
0005433805427	26267	40	15F
0005433805371	26267	41	15H
0005433784911	26267	42	16E
0005435269790	26267	43	16D
0005433763218	26267	44	16H
0005435269788	26267	45	16G
0005433805272	26267	46	17B
0005434171156	26267	47	17A
0005433784935	26267	48	17G
0005435269786	26267	49	17H
0005433763183	26267	50	18A
0005433805402	26267	51	18E
0005434171162	26267	52	18D
0005434271325	26267	53	18F
0005433805262	26267	54	18G
0005433805433	26267	55	19A
0005433763166	26267	56	19B
0005435269792	26267	57	19E
0005434269117	26267	58	19G
0005433785002	26267	59	20D
0005433805343	26267	60	20B
0005434171149	26267	61	21D
0005433763219	26267	62	21B
0005433784900	26267	63	21E
0005433805256	26267	64	21H
0005433784746	26267	65	22A
0005433805306	26267	66	22D
0005433805347	26267	67	22B
0005434171157	26267	68	22E
0005433805328	26267	69	22G
0005433805384	26267	70	22F
0005433784937	26267	71	23A
0005433805399	26267	72	23D
0005433805323	26267	73	23F
0005433763184	26267	74	23E
0005433784806	26267	75	23G
0005433784879	26267	76	23H
0005433784862	26267	77	24E
0005433805261	26267	78	24D
0005434171150	26267	79	24F
0005433784955	26267	80	24H
0005432657450	26267	81	25E
0005432659706	26267	82	27B
0005433784916	26267	83	27E
0005432659705	26267	84	27G
0005433805390	26267	85	28A
0005433784920	26267	86	28B
0005433805253	26267	87	28D
0005433805383	26267	88	28F
0005433763237	26267	89	29A
0005433784928	26267	90	28H
0005433805302	26267	91	29B
0005434271324	26267	92	29E
0005433784888	26267	93	30A
0005433805297	26267	94	30F
0005433805401	26267	95	30H
0005433805362	26267	96	30G
0005433784977	26267	97	31F
0005434151724	26267	98	31H
0005433805273	26267	99	32B
0005433763168	26267	100	32D
0005433784927	26267	101	32F
0005433805318	26267	102	32E
0005433784936	26267	103	32H
0005434171160	26267	104	33A
0005433763165	26267	105	33B
0005432659695	26267	106	33E
0005433763139	26267	107	33F
0005433805303	26267	108	33H
0005434171151	26267	109	34D
0005434151723	26267	110	34E
0005433784844	26267	111	34G
0005433784781	26267	112	35B
0005435269789	26267	113	35D
0005433805276	26267	114	35F
0005435269795	26267	115	35E
0005434171158	26267	116	35G
0005432657448	26267	117	36A
0005433763238	26267	118	36B
0005434171159	26267	119	36D
0005433805428	26267	120	36F
0005433784944	26267	121	37E
0005433784782	26267	122	37D
0005432666380	26267	123	37F
0005432659696	26267	124	37G
0005433784846	26267	125	38A
0005433805400	26267	126	38B
0005433784973	26267	127	38E
0005434171155	26267	128	38F
0005433784720	26267	129	38H
0005435135703	4936	1	1D
0005435135706	4936	2	2B
0005435135702	4936	3	2C
0005435929644	4936	4	2D
0005435135705	4936	5	3D
0005435135704	4936	6	19C
0005435929641	4936	7	21C
0005435929663	33048	1	1B
0005435929662	33048	2	3A
0005435135653	33048	3	3B
0005435135656	33048	4	3C
0005435135654	33048	5	18C
0005435929664	33048	6	19A
0005434217938	9508	1	2C
0005434217956	9508	2	3A
0005434983326	9508	3	3C
0005434983323	9508	4	6D
0005434217957	9508	5	7B
0005434217955	9508	6	18B
0005434983325	9508	7	19A
0005434983324	9508	8	20A
0005434217954	9508	9	21A
0005434217948	9508	10	21B
0005434217949	9508	11	21C
0005434983322	9508	12	22A
0005434983327	9508	13	22B
0005434217939	9508	14	22D
0005434217958	9508	15	23B
0005434217996	27365	1	2B
0005434217997	27365	2	4B
0005434983284	27365	3	4C
0005434217998	27365	4	6B
0005434983291	27365	5	19A
0005434983287	27365	6	21C
0005433960678	24286	1	1B
0005433960410	24286	2	1C
0005433960519	24286	3	1F
0005433985772	24286	4	1G
0005433985791	24286	5	2A
0005433985852	24286	6	1H
0005433985735	24286	7	2C
0005433985926	24286	8	2B
0005433960628	24286	9	2F
0005433985813	24286	10	3A
0005433985863	24286	11	2H
0005433960786	24286	12	3C
0005433985637	24286	13	3B
0005433960774	24286	14	3F
0005433960595	24286	15	4C
0005433960621	24286	16	9A
0005433960725	24286	17	9B
0005433985839	24286	18	9G
0005433985747	24286	19	9H
0005433985874	24286	20	11E
0005433985879	24286	21	11D
0005433960663	24286	22	11G
0005433985857	24286	23	12A
0005433985806	24286	24	12E
0005433960488	24286	25	12G
0005433960709	24286	26	13B
0005433985783	24286	27	13E
0005433960604	24286	28	13F
0005433960474	24286	29	14D
0005433960473	24286	30	14E
0005433985900	24286	31	14H
0005433985798	24286	32	15G
0005433960596	24286	33	16D
0005433960779	24286	34	17B
0005433960560	24286	35	17F
0005433960789	24286	36	18B
0005433960564	24286	37	18A
0005433960561	24286	38	19B
0005433985850	24286	39	19D
0005433960680	24286	40	19F
0005433960659	24286	41	20A
0005433960708	24286	42	20B
0005433985802	24286	43	20E
0005433985838	24286	44	20D
0005433985638	24286	45	20F
0005433985765	24286	46	21A
0005433960744	24286	47	21E
0005433960679	24286	48	21D
0005433985935	24286	49	21F
0005433960660	24286	50	22D
0005433960780	24286	51	22B
0005433985832	24286	52	22E
0005433960743	24286	53	22G
0005433985799	24286	54	23A
0005433960569	24286	55	23G
0005433960623	24286	56	23F
0005433985780	24286	57	24A
0005433985998	24286	58	24B
0005433960635	24286	59	24D
0005433985910	24286	60	24F
0005433985776	24286	61	24G
0005433985875	24286	62	25F
0005433985779	24286	63	27B
0005433960758	24286	64	27F
0005433960675	24286	65	27E
0005433960706	24286	66	28B
0005433960676	24286	67	28E
0005433960570	24286	68	28H
0005433960707	24286	69	29A
0005433985736	24286	70	29B
0005433960661	24286	71	29E
0005433985673	24286	72	29H
0005433985936	24286	73	29G
0005433960641	24286	74	30F
0005433985837	24286	75	30G
0005433960773	24286	76	31B
0005433986020	24286	77	31A
0005433985876	24286	78	31E
0005433985862	24286	79	31F
0005433960629	24286	80	31G
0005433985792	24286	81	31H
0005433985915	24286	82	32E
0005433960622	24286	83	32D
0005433960658	24286	84	32H
0005433960562	24286	85	32G
0005433985851	24286	86	33A
0005433985867	24286	87	33E
0005433986214	24286	88	34B
0005433960620	24286	89	34G
0005433985919	24286	90	34H
0005433985796	24286	91	35B
0005433960790	24286	92	35D
0005433985804	24286	93	35E
0005433960502	24286	94	36A
0005433985588	24286	95	35H
0005433985842	24286	96	36B
0005433985803	24286	97	37A
0005433960619	24286	98	37B
0005433960618	24286	99	37D
0005433985877	24286	100	37G
0005433985856	24286	101	37H
0005433960785	24286	102	38E
0005433960762	24286	103	38D
0005433985878	24286	104	38F
0005433985702	24286	105	38H
0005433985873	24286	106	38G
0005433961217	25941	1	1A
0005433986226	25941	2	1F
0005433961236	25941	3	1G
0005433986234	25941	4	2A
0005433986244	25941	5	2C
0005433986241	25941	6	3A
0005433986245	25941	7	3C
0005433961251	25941	8	3H
0005433986253	25941	9	4A
0005433986237	25941	10	4F
0005433986231	25941	11	4C
0005433986221	25941	12	4H
0005433961232	25941	13	5B
0005433961215	25941	14	5F
0005433961238	25941	15	5G
0005433961218	25941	16	9H
0005433961260	25941	17	11G
0005433986249	25941	18	12F
0005433986240	25941	19	12H
0005433961262	25941	20	12G
0005433961245	25941	21	13A
0005433961213	25941	22	13D
0005433961250	25941	23	13G
0005433961252	25941	24	13H
0005433961216	25941	25	14D
0005433961229	25941	26	14E
0005433961220	25941	27	14G
0005433961249	25941	28	14H
0005433986243	25941	29	15E
0005433986223	25941	30	16D
0005433986224	25941	31	16B
0005433986230	25941	32	17B
0005433961244	25941	33	17A
0005433961256	25941	34	17G
0005433961248	25941	35	18A
0005433986239	25941	36	18D
0005433986256	25941	37	18F
0005433986235	25941	38	18E
0005433961235	25941	39	18G
0005433961221	25941	40	19A
0005433986219	25941	41	19G
0005433961261	25941	42	20D
0005433961231	25941	43	20G
0005433961257	25941	44	22A
0005433986236	25941	45	22B
0005433986250	25941	46	22D
0005433961225	25941	47	23D
0005433961214	25941	48	23E
0005433961240	25941	49	23G
0005433961254	25941	50	24A
0005433986247	25941	51	23H
0005433986257	25941	52	24D
0005433986233	25941	53	24E
0005433986258	25941	54	24G
0005433961242	25941	55	25F
0005433961239	25941	56	27H
0005433961226	25941	57	27G
0005433961234	25941	58	28A
0005433986254	25941	59	28B
0005433961243	25941	60	28D
0005433961228	25941	61	28F
0005433961230	25941	62	28G
0005433961258	25941	63	29B
0005433961212	25941	64	29F
0005433986227	25941	65	29H
0005433961222	25941	66	30B
0005433986228	25941	67	30E
0005433986229	25941	68	30D
0005433986242	25941	69	30F
0005433986222	25941	70	31B
0005433986220	25941	71	31E
0005433961259	25941	72	31F
0005433986251	25941	73	32B
0005433961247	25941	74	32D
0005433961237	25941	75	32H
0005433986252	25941	76	33F
0005433986255	25941	77	33H
0005433986232	25941	78	34B
0005433961253	25941	79	34E
0005433986246	25941	80	34F
0005433961227	25941	81	35B
0005433961219	25941	82	35E
0005433986248	25941	83	36E
0005433961224	25941	84	36D
0005433986225	25941	85	36F
0005433961233	25941	86	36G
0005433961223	25941	87	36H
0005433961255	25941	88	37E
0005433986238	25941	89	38D
0005433961246	25941	90	38E
0005433961241	25941	91	39E
0005434480515	939	1	1A
0005433165926	939	2	1B
0005434480511	939	3	1C
0005434480512	939	4	1D
0005433165884	939	5	2A
0005433165880	939	6	2C
0005434480507	939	7	2D
0005432269515	939	8	3A
0005433165876	939	9	3B
0005433165847	939	10	3C
0005433165848	939	11	3D
0005432269516	939	12	4A
0005434480517	939	13	4B
0005434480521	939	14	4C
0005434480509	939	15	4D
0005434480519	939	16	5B
0005434480505	939	17	5C
0005433165910	939	18	5D
0005434480510	939	19	6A
0005434480502	939	20	6B
0005434480516	939	21	6C
0005433165899	939	22	6D
0005433165900	939	23	7A
0005432269514	939	24	7D
0005434480498	939	25	18B
0005434480503	939	26	18C
0005433165909	939	27	18D
0005434480508	939	28	19A
0005434480501	939	29	19C
0005433165844	939	30	19D
0005434480504	939	31	20A
0005433165881	939	32	20B
0005434480496	939	33	20C
0005434480497	939	34	20D
0005434480522	939	35	21A
0005434480506	939	36	21B
0005434480499	939	37	21C
0005434480518	939	38	21D
0005434480520	939	39	22A
0005434480513	939	40	22C
0005434480514	939	41	22D
0005433165921	939	42	23A
0005434480500	939	43	23B
0005433165991	16583	1	1A
0005434480401	16583	2	1B
0005434480286	16583	3	1C
0005434480304	16583	4	1D
0005433165992	16583	5	2B
0005433165993	16583	6	2C
0005433165999	16583	7	3A
0005433166002	16583	8	3B
0005433166000	16583	9	3C
0005434480294	16583	10	3D
0005434480350	16583	11	4A
0005433166001	16583	12	4B
0005434480402	16583	13	4C
0005434480215	16583	14	4D
0005434480334	16583	15	5A
0005434480209	16583	16	5B
0005434480277	16583	17	6A
0005433165990	16583	18	6B
0005433165997	16583	19	6C
0005434480166	16583	20	6D
0005433165994	16583	21	7A
0005433165996	16583	22	7B
0005434480303	16583	23	7C
0005434480335	16583	24	7D
0005434480367	16583	25	18A
0005434480287	16583	26	18B
0005434480316	16583	27	18C
0005434480349	16583	28	18D
0005434480214	16583	29	19B
0005434480191	16583	30	19D
0005434480293	16583	31	20A
0005434480254	16583	32	20B
0005434480227	16583	33	20C
0005434480357	16583	34	20D
0005434480208	16583	35	21A
0005433165998	16583	36	21B
0005434480366	16583	37	21C
0005433165995	16583	38	22A
0005434480165	16583	39	22B
0005434480391	16583	40	22D
0005434480317	16583	41	23A
0005434480368	16583	42	23B
0005435150119	10368	1	1A
0005435150113	10368	2	1B
0005435150106	10368	3	1D
0005435150111	10368	4	2A
0005435142657	10368	5	2C
0005433289805	10368	6	2D
0005435142659	10368	7	3A
0005435150117	10368	8	3B
0005435142655	10368	9	3C
0005435150112	10368	10	3D
0005435142660	10368	11	4A
0005433289826	10368	12	4B
0005433289806	10368	13	4C
0005435386550	10368	14	4D
0005435386548	10368	15	5C
0005435386551	10368	16	6A
0005435150108	10368	17	6B
0005435142666	10368	18	6C
0005435142654	10368	19	6D
0005435142662	10368	20	7A
0005433289823	10368	21	7B
0005433289829	10368	22	7C
0005435142665	10368	23	18A
0005435142664	10368	24	18B
0005433289828	10368	25	18C
0005435150109	10368	26	18D
0005435386561	10368	27	19A
0005433289824	10368	28	19B
0005433289825	10368	29	19C
0005435150110	10368	30	19D
0005435150114	10368	31	20A
0005435150107	10368	32	20B
0005435142658	10368	33	20C
0005433289807	10368	34	20D
0005435150115	10368	35	21B
0005435142663	10368	36	21C
0005435142661	10368	37	21D
0005435150116	10368	38	22A
0005435150118	10368	39	22B
0005435142667	10368	40	22C
0005435142656	10368	41	22D
0005433289804	10368	42	23A
0005433289904	21919	1	1A
0005435142585	21919	2	1C
0005435142561	21919	3	1D
0005435149995	21919	4	2A
0005433289903	21919	5	2B
0005435142582	21919	6	2C
0005433289905	21919	7	2D
0005435150003	21919	8	3A
0005435386617	21919	9	3B
0005435386619	21919	10	3D
0005435142515	21919	11	4A
0005433289910	21919	12	4B
0005435142584	21919	13	4C
0005435150051	21919	14	4D
0005435142516	21919	15	5A
0005435150050	21919	16	5B
0005435386615	21919	17	5C
0005435142534	21919	18	5D
0005435150002	21919	19	6A
0005433289907	21919	20	6B
0005433289908	21919	21	6C
0005435386614	21919	22	6D
0005435386613	21919	23	7A
0005433289902	21919	24	7B
0005435386620	21919	25	18A
0005435150012	21919	26	18B
0005435386616	21919	27	18C
0005433289909	21919	28	18D
0005435142517	21919	29	19A
0005435149984	21919	30	19B
0005435142562	21919	31	19D
0005435386618	21919	32	20A
0005435142535	21919	33	20B
0005435142558	21919	34	20C
0005435149941	21919	35	20D
0005435150010	21919	36	21B
0005435149986	21919	37	21C
0005435149994	21919	38	21D
0005435150053	21919	39	22A
0005433289906	21919	40	22B
0005435149997	21919	41	22D
0005435149940	21919	42	23A
0005435150009	21919	43	23B
0005435545697	11201	1	1A
0005435529173	11201	2	1C
0005435319577	11201	3	1D
0005435319560	11201	4	1F
0005435502360	11201	5	2A
0005435529182	11201	6	2C
0005434573444	11201	7	2D
0005434573441	11201	8	2F
0005434573435	11201	9	3C
0005435319578	11201	10	3D
0005435502294	11201	11	3F
0005434573439	11201	12	4C
0005435502311	11201	13	4D
0005434573434	11201	14	4E
0005435529164	11201	15	5A
0005435502315	11201	16	5C
0005435545719	11201	17	5E
0005435529193	11201	18	5F
0005434573445	11201	19	6C
0005435502226	11201	20	6D
0005434573443	11201	21	6E
0005434573438	11201	22	6F
0005434573440	11201	23	7A
0005435319540	11201	24	7C
0005435529189	11201	25	7D
0005435545677	11201	26	7F
0005435502263	11201	27	8A
0005434573437	11201	28	8C
0005435319574	11201	29	8D
0005434573447	11201	30	9A
0005435502228	11201	31	9D
0005435529147	11201	32	9E
0005435502237	11201	33	9F
0005435529154	11201	34	10C
0005434573436	11201	35	10D
0005435529257	11201	36	10E
0005435319559	11201	37	10F
0005435319539	11201	38	11C
0005435545699	11201	39	11E
0005435529231	11201	40	11F
0005435529204	11201	41	12A
0005435502292	11201	42	13C
0005435545704	11201	43	13A
0005435529221	11201	44	13E
0005435502368	11201	45	14A
0005435529186	11201	46	14C
0005435529192	11201	47	14E
0005435502219	11201	48	14F
0005435502293	11201	49	15C
0005435529169	11201	50	15D
0005435502281	11201	51	15F
0005435319566	11201	52	16A
0005435502238	11201	53	16C
0005435529270	11201	54	16D
0005435529246	11201	55	16E
0005435502227	11201	56	17A
0005435545721	11201	57	17C
0005435529220	11201	58	17E
0005435319538	11201	59	17F
0005435319567	11201	60	18C
0005435529172	11201	61	18D
0005435502362	11201	62	18F
0005435502264	11201	63	19A
0005434573446	11201	64	19D
0005434573442	11201	65	19E
0005435502339	11201	66	19F
0005435545720	11201	67	20A
0005435545698	11201	68	20D
0005435502367	11201	69	20E
0005435502257	11201	70	20F
0005435502443	20954	1	1A
0005434573306	20954	2	1C
0005432291947	20954	3	1F
0005435502446	20954	4	2A
0005435502455	20954	5	2C
0005435502453	20954	6	2D
0005435502450	20954	7	3A
0005434573300	20954	8	3D
0005434573327	20954	9	3F
0005435518016	20954	10	4A
0005434573259	20954	11	4C
0005435319646	20954	12	4D
0005432291945	20954	13	4E
0005435502456	20954	14	4F
0005435502448	20954	15	5C
0005435508422	20954	16	5D
0005435319645	20954	17	5F
0005435502441	20954	18	6A
0005435508419	20954	19	6E
0005435502445	20954	20	7A
0005435518024	20954	21	7C
0005435502451	20954	22	7D
0005432291944	20954	23	7E
0005435518022	20954	24	7F
0005435319647	20954	25	8D
0005435502452	20954	26	8F
0005435319643	20954	27	9A
0005435502454	20954	28	9C
0005435319648	20954	29	9D
0005435508423	20954	30	9F
0005435518020	20954	31	10C
0005434573304	20954	32	10E
0005435508421	20954	33	10F
0005435518019	20954	34	11C
0005435518026	20954	35	11D
0005435502447	20954	36	11E
0005435518021	20954	37	12A
0005435502459	20954	38	12C
0005434573301	20954	39	12D
0005434573344	20954	40	12F
0005435319644	20954	41	13A
0005435508428	20954	42	13C
0005435508427	20954	43	13E
0005435502458	20954	44	13F
0005435508420	20954	45	14A
0005434573319	20954	46	14C
0005435502457	20954	47	14D
0005434573244	20954	48	14F
0005435508425	20954	49	15A
0005432291946	20954	50	15C
0005434573305	20954	51	15D
0005435508418	20954	52	15F
0005435502462	20954	53	16C
0005434573243	20954	54	16F
0005435518025	20954	55	17C
0005435518027	20954	56	17D
0005435508424	20954	57	17E
0005435319649	20954	58	17F
0005435502442	20954	59	18A
0005435518023	20954	60	18E
0005434573260	20954	61	18F
0005435508417	20954	62	19A
0005435502444	20954	63	19C
0005435508429	20954	64	19D
0005435502449	20954	65	19E
0005434573245	20954	66	19F
0005435518017	20954	67	20A
0005435508426	20954	68	20C
0005435518018	20954	69	20D
0005435502461	20954	70	20E
0005435502460	20954	71	20F
0005433683353	24316	1	1C
0005433683356	24316	2	2A
0005433927422	24316	3	2B
0005433683355	24316	4	4A
0005433683358	24316	5	4C
0005433927426	24316	6	5B
0005433683352	24316	7	5D
0005433927438	24316	8	6B
0005433927442	24316	9	6C
0005433683357	24316	10	7A
0005433927439	24316	11	7B
0005433927431	24316	12	7D
0005433683354	24316	13	18D
0005433927440	24316	14	20B
0005433927443	24316	15	21D
0005433927441	24316	16	22A
0005433683326	29288	1	1A
0005433683334	29288	2	1B
0005433927459	29288	3	1C
0005433927458	29288	4	2C
0005433683338	29288	5	3A
0005433683340	29288	6	3C
0005433683314	29288	7	4A
0005433683320	29288	8	4C
0005433927454	29288	9	4D
0005433683324	29288	10	5A
0005433683321	29288	11	5C
0005433683325	29288	12	5D
0005433927455	29288	13	7D
0005433683336	29288	14	18A
0005433683328	29288	15	18B
0005433927456	29288	16	19D
0005433927461	29288	17	20B
0005433683337	29288	18	21B
0005433683339	29288	19	21C
0005433927457	29288	20	22A
0005433927460	29288	21	23A
0005433683322	29288	22	23B
0005432693004	3035	1	1F
0005432693007	3035	2	2D
0005432693113	3035	3	4F
0005432692949	3035	4	6A
0005432693050	3035	5	6D
0005432692972	3035	6	6E
0005432692852	3035	7	10A
0005432693024	3035	8	11E
0005432693039	3035	9	12D
0005432693005	3035	10	13C
0005432693143	3035	11	13E
0005432692987	3035	12	14F
0005432693123	3035	13	16D
0005432693063	3035	14	16E
0005432693008	3035	15	17E
0005432693032	3035	16	18D
0005432693034	3035	17	19E
0005432693033	3035	18	20A
0005432706940	3032	1	1A
0005432706959	3032	2	1C
0005433123762	3032	3	1D
0005432706950	3032	4	1F
0005432706937	3032	5	2A
0005433123838	3032	6	2C
0005433123751	3032	7	2F
0005433123849	3032	8	3D
0005432706957	3032	9	3F
0005433123867	3032	10	4A
0005432880787	3032	11	4C
0005432880791	3032	12	4E
0005433123856	3032	13	4F
0005432880875	3032	14	5A
0005433123967	3032	15	5C
0005432880832	3032	16	5D
0005433123851	3032	17	6A
0005432880761	3032	18	6D
0005433123872	3032	19	6E
0005433194851	3032	20	6F
0005433123750	3032	21	7A
0005432706951	3032	22	7C
0005433123855	3032	23	7D
0005433123900	3032	24	7E
0005433124011	3032	25	7F
0005432706943	3032	26	8A
0005433124010	3032	27	8C
0005433123908	3032	28	8D
0005433123969	3032	29	8E
0005433123839	3032	30	8F
0005432706955	3032	31	9D
0005432217795	3032	32	9E
0005432217794	3032	33	9F
0005432706960	3032	34	10A
0005433123841	3032	35	10D
0005433123875	3032	36	10E
0005433123902	3032	37	10F
0005432880779	3032	38	11A
0005433123907	3032	39	11C
0005432706956	3032	40	11E
0005433123883	3032	41	11F
0005433123842	3032	42	12A
0005432880807	3032	43	12C
0005433123966	3032	44	12D
0005433123909	3032	45	12E
0005432706945	3032	46	12F
0005432706936	3032	47	13A
0005432706947	3032	48	13C
0005432880738	3032	49	13D
0005433123937	3032	50	13F
0005432706942	3032	51	14A
0005432706944	3032	52	14D
0005432706958	3032	53	14E
0005432880782	3032	54	14F
0005432880753	3032	55	15C
0005432880781	3032	56	15E
0005433123938	3032	57	15F
0005433123901	3032	58	16A
0005432706953	3032	59	16C
0005432706941	3032	60	16D
0005433123850	3032	61	16E
0005432706952	3032	62	16F
0005432706961	3032	63	17C
0005432706948	3032	64	17D
0005432706938	3032	65	17F
0005432706946	3032	66	18A
0005432880754	3032	67	18C
0005432880755	3032	68	18D
0005432706949	3032	69	18E
0005433123921	3032	70	18F
0005432706962	3032	71	19A
0005432880780	3032	72	19D
0005432217796	3032	73	19E
0005433123877	3032	74	20A
0005432706954	3032	75	20C
0005432706939	3032	76	20F
0005432693307	29921	1	1A
0005432880923	29921	2	1C
0005432880919	29921	3	1D
0005432693292	29921	4	1F
0005433124062	29921	5	2A
0005432693298	29921	6	2C
0005433194874	29921	7	2D
0005433124052	29921	8	2F
0005433124066	29921	9	3A
0005432706675	29921	10	3C
0005432693302	29921	11	3D
0005432706802	29921	12	3F
0005433124054	29921	13	4A
0005432706763	29921	14	4C
0005432706755	29921	15	4D
0005433124060	29921	16	4E
0005432693314	29921	17	4F
0005433194872	29921	18	5A
0005432693296	29921	19	5C
0005433124069	29921	20	5D
0005432693293	29921	21	5E
0005433124073	29921	22	5F
0005433124067	29921	23	6A
0005432706732	29921	24	6C
0005432706740	29921	25	6D
0005433194867	29921	26	6E
0005432880918	29921	27	6F
0005433194869	29921	28	7A
0005433124070	29921	29	7C
0005432693295	29921	30	7D
0005433124061	29921	31	7E
0005433194866	29921	32	7F
0005432880920	29921	33	8A
0005432693309	29921	34	8C
0005433124065	29921	35	8D
0005432693287	29921	36	8E
0005432880915	29921	37	8F
0005432693306	29921	38	9A
0005432693291	29921	39	9C
0005432706697	29921	40	9D
0005432693294	29921	41	9E
0005433194875	29921	42	9F
0005432693289	29921	43	10A
0005432706728	29921	44	10C
0005433194863	29921	45	10D
0005432693312	29921	46	10E
0005433194870	29921	47	10F
0005432880921	29921	48	11A
0005432880911	29921	49	11C
0005432706708	29921	50	11D
0005433124059	29921	51	11E
0005433124056	29921	52	12A
0005433124058	29921	53	12C
0005432693305	29921	54	12D
0005432693297	29921	55	12E
0005433124064	29921	56	12F
0005432880922	29921	57	13A
0005433124063	29921	58	13C
0005432693308	29921	59	13D
0005433124072	29921	60	13E
0005432693310	29921	61	13F
0005432693299	29921	62	14A
0005432693290	29921	63	14C
0005432880925	29921	64	14D
0005432706883	29921	65	14E
0005433194868	29921	66	14F
0005432693301	29921	67	15A
0005432880912	29921	68	15C
0005432693288	29921	69	15D
0005433194873	29921	70	15E
0005432693313	29921	71	15F
0005433124055	29921	72	16A
0005433124051	29921	73	16C
0005432880916	29921	74	16D
0005432706733	29921	75	16E
0005433194862	29921	76	16F
0005432693286	29921	77	17A
0005433124053	29921	78	17C
0005432706709	29921	79	17D
0005433124068	29921	80	17E
0005432693304	29921	81	17F
0005432693311	29921	82	18A
0005432706816	29921	83	18C
0005432693300	29921	84	18D
0005433194871	29921	85	18E
0005432880914	29921	86	18F
0005432880913	29921	87	19A
0005432880917	29921	88	19C
0005432880924	29921	89	19D
0005433124071	29921	90	19E
0005432693315	29921	91	19F
0005433194864	29921	92	20A
0005433124057	29921	93	20C
0005432693303	29921	94	20D
0005433194865	29921	95	20E
0005432693285	29921	96	20F
0005434979966	23670	1	1B
0005434988800	23670	2	1C
0005434979970	23670	3	1D
0005434979969	23670	4	2B
0005434988804	23670	5	2A
0005434979988	23670	6	2D
0005434979983	23670	7	3A
0005434979985	23670	8	3B
0005434979982	23670	9	3C
0005434979973	23670	10	3D
0005434979976	23670	11	4A
0005434988807	23670	12	4B
0005434979980	23670	13	4C
0005434979974	23670	14	4D
0005434988805	23670	15	5A
0005434988803	23670	16	5C
0005434979961	23670	17	5D
0005434979972	23670	18	6A
0005434988810	23670	19	6B
0005434979984	23670	20	6C
0005434988811	23670	21	6D
0005434979990	23670	22	7A
0005434979979	23670	23	7B
0005434979962	23670	24	7C
0005434979971	23670	25	7D
0005434988801	23670	26	18A
0005434988806	23670	27	18B
0005434988808	23670	28	18C
0005434979989	23670	29	19A
0005434988802	23670	30	19B
0005434979964	23670	31	19C
0005434988809	23670	32	20B
0005434979975	23670	33	20C
0005434979981	23670	34	20D
0005434979987	23670	35	21A
0005434979965	23670	36	21B
0005434979960	23670	37	21C
0005434979963	23670	38	21D
0005434979986	23670	39	22A
0005434979968	23670	40	22B
0005434979978	23670	41	22C
0005434979977	23670	42	22D
0005434979967	23670	43	23A
0005434979744	27537	1	1B
0005434988686	27537	2	1C
0005434979803	27537	3	1D
0005434988708	27537	4	2A
0005434979746	27537	5	2B
0005434988704	27537	6	2C
0005434979722	27537	7	2D
0005434979701	27537	8	3A
0005434979671	27537	9	3B
0005434988709	27537	10	3C
0005434979794	27537	11	3D
0005434979805	27537	12	4A
0005434979679	27537	13	4B
0005434979611	27537	14	4C
0005434988667	27537	15	4D
0005434979707	27537	16	5B
0005434979825	27537	17	5A
0005434979732	27537	18	5C
0005434979626	27537	19	5D
0005434979793	27537	20	6A
0005434988671	27537	21	6B
0005434988703	27537	22	6D
0005434979670	27537	23	7A
0005434979660	27537	24	7B
0005434979824	27537	25	7C
0005434979716	27537	26	7D
0005434979745	27537	27	18A
0005434979658	27537	28	18B
0005434988674	27537	29	18C
0005434979662	27537	30	18D
0005434988696	27537	31	19A
0005434988697	27537	32	19B
0005434979802	27537	33	19C
0005434979727	27537	34	19D
0005434988675	27537	35	20A
0005434979661	27537	36	20B
0005434988679	27537	37	20C
0005434979678	27537	38	20D
0005434988678	27537	39	21A
0005434979764	27537	40	21B
0005434979706	27537	41	21C
0005434979610	27537	42	22A
0005434979741	27537	43	22B
0005434979765	27537	44	22C
0005434979625	27537	45	23A
0005434979669	27537	46	23B
0005434302486	10254	1	1C
0005434302487	10254	2	3D
0005434302484	10254	3	7D
0005434302485	10254	4	18A
0005433111502	10254	5	19B
0005433113539	10254	6	22B
0005433113551	19636	1	2B
0005434302429	19636	2	4C
0005434302428	19636	3	6B
0005433113553	19636	4	7C
0005433113552	19636	5	19B
0005435069478	3571	1	1A
0005435069456	3571	2	1C
0005435069439	3571	3	1D
0005435069459	3571	4	1F
0005435069452	3571	5	2A
0005435069472	3571	6	2C
0005435069432	3571	7	2D
0005435925259	3571	8	2F
0005435069463	3571	9	3A
0005435069462	3571	10	3C
0005435925248	3571	11	3F
0005435069464	3571	12	4A
0005435925258	3571	13	4E
0005435069448	3571	14	4F
0005435069437	3571	15	5D
0005435925212	3571	16	5E
0005435069451	3571	17	5F
0005435069471	3571	18	6A
0005435069449	3571	19	6C
0005435718989	3571	20	6D
0005435069458	3571	21	6F
0005435069445	3571	22	7A
0005435069476	3571	23	7C
0005435069431	3571	24	7D
0005435925254	3571	25	7F
0005435925193	3571	26	8A
0005435069466	3571	27	8D
0005435069438	3571	28	8E
0005435069461	3571	29	8F
0005435069479	3571	30	9A
0005435925262	3571	31	9D
0005435069477	3571	32	9E
0005435925233	3571	33	9F
0005435069468	3571	34	10C
0005435069470	3571	35	10D
0005435069481	3571	36	10E
0005435925271	3571	37	10F
0005435925179	3571	38	11A
0005435925223	3571	39	11C
0005435069469	3571	40	11D
0005435069465	3571	41	11E
0005435069454	3571	42	11F
0005435069435	3571	43	12A
0005435069473	3571	44	12C
0005435069442	3571	45	12E
0005435069475	3571	46	12F
0005435069433	3571	47	13C
0005435069457	3571	48	13D
0005435069434	3571	49	13E
0005435069446	3571	50	13F
0005435718991	3571	51	14C
0005435069450	3571	52	14D
0005435069467	3571	53	14E
0005435069436	3571	54	14F
0005435069453	3571	55	15A
0005435718988	3571	56	15C
0005435069474	3571	57	15F
0005435069480	3571	58	16A
0005435069460	3571	59	16C
0005435925243	3571	60	16E
0005435069455	3571	61	16F
0005435925242	3571	62	17A
0005435069443	3571	63	17C
0005435925261	3571	64	17D
0005435069444	3571	65	17E
0005435925224	3571	66	17F
0005435069441	3571	67	18A
0005435069482	3571	68	18F
0005435925227	3571	69	19A
0005435069430	3571	70	19C
0005435069440	3571	71	19D
0005435925228	3571	72	19F
0005435718990	3571	73	20A
0005435925232	3571	74	20C
0005435925192	3571	75	20E
0005435069447	3571	76	20F
0005435068966	15313	1	1A
0005435718845	15313	2	1C
0005435718864	15313	3	1D
0005435718905	15313	4	1F
0005435069105	15313	5	2A
0005435069186	15313	6	2C
0005435718908	15313	7	2D
0005435718917	15313	8	2F
0005435068868	15313	9	3A
0005435068897	15313	10	3C
0005435718914	15313	11	3D
0005435718887	15313	12	3F
0005435068748	15313	13	4A
0005435718859	15313	14	4C
0005435068991	15313	15	4D
0005435068971	15313	16	4E
0005435718915	15313	17	4F
0005435068988	15313	18	5A
0005435069018	15313	19	5C
0005435068708	15313	20	5D
0005435068906	15313	21	5E
0005435718833	15313	22	5F
0005435069041	15313	23	6A
0005435069015	15313	24	6C
0005435068828	15313	25	6D
0005435718891	15313	26	6E
0005435718893	15313	27	6F
0005435718903	15313	28	7A
0005435068889	15313	29	7C
0005435068895	15313	30	7D
0005435718918	15313	31	7E
0005435068899	15313	32	7F
0005435069042	15313	33	8A
0005435718866	15313	34	8C
0005435718842	15313	35	8D
0005435069057	15313	36	8E
0005435068765	15313	37	8F
0005435068874	15313	38	9A
0005435068851	15313	39	9C
0005435718832	15313	40	9D
0005435068746	15313	41	9E
0005435068894	15313	42	9F
0005435068911	15313	43	10A
0005435718911	15313	44	10C
0005435068922	15313	45	10D
0005435718892	15313	46	10E
0005435718904	15313	47	10F
0005435068709	15313	48	11A
0005435068942	15313	49	11C
0005435068795	15313	50	11D
0005435068982	15313	51	11E
0005435718851	15313	52	11F
0005435718850	15313	53	12A
0005435068900	15313	54	12C
0005435068829	15313	55	12D
0005435069106	15313	56	12E
0005435068919	15313	57	12F
0005435068852	15313	58	13A
0005435068647	15313	59	13C
0005435068992	15313	60	13D
0005435718890	15313	61	13E
0005435068898	15313	62	13F
0005435718879	15313	63	14A
0005435068987	15313	64	14C
0005435069017	15313	65	14D
0005435718901	15313	66	14E
0005435718876	15313	67	14F
0005435069001	15313	68	15A
0005435068967	15313	69	15C
0005435718896	15313	70	15D
0005435718900	15313	71	15E
0005435068754	15313	72	15F
0005435069003	15313	73	16A
0005435068747	15313	74	16C
0005435718909	15313	75	16D
0005435718889	15313	76	16E
0005435718913	15313	77	16F
0005435718902	15313	78	17A
0005435069028	15313	79	17C
0005435718916	15313	80	17D
0005435069055	15313	81	17E
0005435068888	15313	82	17F
0005435718899	15313	83	18A
0005435068864	15313	84	18D
0005435718844	15313	85	18E
0005435718884	15313	86	18F
0005435069016	15313	87	19A
0005435718860	15313	88	19C
0005435718897	15313	89	19D
0005435068853	15313	90	19E
0005435068838	15313	91	19F
0005435718838	15313	92	20A
0005435718919	15313	93	20C
0005435718910	15313	94	20D
0005435068822	15313	95	20E
0005435718912	15313	96	20F
0005432659720	18217	1	1A
0005432659721	18217	2	2A
0005432660831	18217	3	2B
0005432660833	18217	4	3A
0005432658607	18217	5	4A
0005432658606	18217	6	4B
0005432660834	18217	7	5A
0005432660832	18217	8	6A
0005432658608	18217	9	6B
0005432660817	26375	1	1B
0005432667450	26375	2	3A
0005432660818	26375	3	3B
0005432660813	26375	4	4A
0005432667452	26375	5	5A
0005432660814	26375	6	5B
0005432667451	26375	7	6B
0005432919838	74	1	1A
0005432901576	74	2	1C
0005432677584	74	3	1D
0005432901534	74	4	2A
0005432901517	74	5	2D
0005433102116	74	6	2F
0005432901560	74	7	3C
0005432919906	74	8	3F
0005432391987	74	9	3D
0005433101868	74	10	4C
0005432919841	74	11	4F
0005432901625	74	12	5C
0005433102112	74	13	5A
0005432919795	74	14	5D
0005432901623	74	15	5F
0005433102037	74	16	6C
0005433101930	74	17	6A
0005432677582	74	18	6D
0005433101928	74	19	7A
0005432391989	74	20	7D
0005433102080	74	21	7C
0005433101936	74	22	7F
0005433102093	74	23	8A
0005433102081	74	24	8B
0005432901627	74	25	8E
0005433102042	74	26	8D
0005433102115	74	27	8F
0005432901581	74	28	9B
0005433102015	74	29	9E
0005432901516	74	30	9D
0005432919870	74	31	10A
0005433102050	74	32	10C
0005432919845	74	33	10B
0005432677559	74	34	10D
0005433102051	74	35	10E
0005432901585	74	36	11A
0005433102038	74	37	11B
0005433102088	74	38	11D
0005432919907	74	39	11F
0005433102034	74	40	11E
0005432677566	74	41	12C
0005432901572	74	42	12D
0005432901521	74	43	12E
0005432677563	74	44	12F
0005433102031	74	45	13B
0005433102075	74	46	13A
0005433102049	74	47	13C
0005432677583	74	48	13D
0005433101937	74	49	13F
0005433102118	74	50	13E
0005433102022	74	51	14A
0005432919846	74	52	14C
0005433102030	74	53	14B
0005433102103	74	54	14E
0005432901665	74	55	14F
0005432919951	74	56	15B
0005433102106	74	57	15A
0005432901632	74	58	15F
0005433102077	74	59	16A
0005433102033	74	60	16B
0005432157507	74	61	16D
0005432919837	74	62	16F
0005433101967	74	63	17B
0005432901552	74	64	17A
0005433101980	74	65	17E
0005432919888	74	66	17D
0005433101970	74	67	17F
0005433101975	74	68	18A
0005433102020	74	69	18B
0005432677555	74	70	18D
0005433101981	74	71	18F
0005433102036	74	72	19D
0005432901626	74	73	20A
0005433102043	74	74	20C
0005433101969	74	75	20F
0005432677558	74	76	20E
0005432901613	74	77	21A
0005433102025	74	78	21C
0005432677570	74	79	21B
0005432901614	74	80	21D
0005432901672	74	81	21F
0005433102065	74	82	21E
0005433101993	74	83	22A
0005432919839	74	84	22C
0005433102078	74	85	22D
0005432157506	74	86	22E
0005433101842	74	87	23A
0005432901549	74	88	23C
0005433102039	74	89	23F
0005432901649	74	90	24A
0005432677562	74	91	24B
0005433102016	74	92	24D
0005432901631	74	93	24C
0005432919747	74	94	24E
0005432919825	74	95	24F
0005432919746	74	96	25C
0005433102024	74	97	25B
0005433101915	74	98	25F
0005433102109	74	99	25E
0005433102069	74	100	26C
0005432901612	74	101	26D
0005433102094	74	102	26F
0005433101968	74	103	27C
0005433101976	74	104	27B
0005432901561	74	105	27E
0005432901503	74	106	27D
0005433102040	74	107	27F
0005433102072	74	108	28A
0005433102032	74	109	28C
0005433101870	74	110	28B
0005432157505	74	111	28E
0005432919872	74	112	28F
0005433102071	74	113	29B
0005433102021	74	114	29E
0005433102041	74	115	29D
0005433102087	74	116	29F
0005433101979	74	117	30A
0005432901548	74	118	30B
0005432901715	74	119	30C
0005433101851	74	120	30E
0005432677571	74	121	30D
0005433101929	74	122	30F
0005433102017	74	123	31A
0005433101806	74	124	31C
0005432901714	74	125	31E
0005432901565	74	126	31D
0005432817693	75	1	2A
0005432262252	75	2	2D
0005432817685	75	3	3A
0005433687690	75	4	2F
0005432262237	75	5	5C
0005432262217	75	6	6A
0005432262228	75	7	6C
0005432817691	75	8	6F
0005432817695	75	9	6D
0005432817682	75	10	7A
0005432262225	75	11	7C
0005432753287	75	12	7F
0005432262213	75	13	7D
0005432817689	75	14	8B
0005432753293	75	15	8E
0005432756831	75	16	8D
0005432262232	75	17	9A
0005432817697	75	18	8F
0005432262220	75	19	9D
0005432262221	75	20	9E
0005432262227	75	21	10B
0005432262251	75	22	10C
0005432817680	75	23	10E
0005432262229	75	24	11B
0005432817687	75	25	11A
0005432817674	75	26	11D
0005432817672	75	27	11F
0005432753290	75	28	12C
0005432753308	75	29	12D
0005432262253	75	30	12E
0005432817692	75	31	13B
0005432262222	75	32	13D
0005432262243	75	33	13F
0005432262211	75	34	14E
0005432262244	75	35	14D
0005432817696	75	36	14F
0005432262236	75	37	15B
0005432817675	75	38	15A
0005432753286	75	39	15D
0005432262215	75	40	15E
0005432756832	75	41	16A
0005432289010	75	42	15F
0005432262249	75	43	16C
0005432262250	75	44	16B
0005432817688	75	45	17A
0005432262210	75	46	17B
0005432756833	75	47	17D
0005432262241	75	48	18B
0005433687691	75	49	18D
0005432817678	75	50	18E
0005432817669	75	51	18F
0005432262240	75	52	19D
0005432262246	75	53	19E
0005434153541	75	54	20B
0005432262239	75	55	20A
0005432262234	75	56	20C
0005432262224	75	57	20D
0005432756813	75	58	20F
0005432207678	75	59	21A
0005432817684	75	60	21B
0005432817690	75	61	21C
0005432262256	75	62	21E
0005432817671	75	63	23A
0005432262231	75	64	23B
0005432262235	75	65	23D
0005432817670	75	66	23C
0005432817677	75	67	23E
0005432262245	75	68	24B
0005432817683	75	69	24A
0005432262214	75	70	24D
0005432262218	75	71	24C
0005432262226	75	72	25C
0005432262223	75	73	25B
0005432207677	75	74	25D
0005432289009	75	75	25E
0005432262219	75	76	25F
0005432817679	75	77	27C
0005432817694	75	78	27B
0005432262248	75	79	27E
0005432262216	75	80	28A
0005432262242	75	81	28D
0005434153539	75	82	28C
0005432262212	75	83	28E
0005432262238	75	84	29A
0005432817686	75	85	28F
0005432262255	75	86	29C
0005432262233	75	87	29E
0005432262254	75	88	30A
0005432262230	75	89	29F
0005432817676	75	90	30B
0005432817681	75	91	30C
0005432756838	75	92	31A
0005432817673	75	93	30F
0005434153540	75	94	31B
0005432756841	75	95	31C
0005432756839	75	96	31D
0005432262247	75	97	31E
0005433102491	7926	1	1A
0005433102490	7926	2	1C
0005432753326	7926	3	2A
0005433102500	7926	4	2D
0005432920010	7926	5	2F
0005433102524	7926	6	3A
0005433102516	7926	7	3C
0005432020438	7926	8	3F
0005432392021	7926	9	4C
0005433102501	7926	10	4F
0005432920001	7926	11	4D
0005432020445	7926	12	5D
0005432920015	7926	13	6A
0005432751551	7926	14	6F
0005433102488	7926	15	6D
0005432753325	7926	16	7A
0005433102504	7926	17	7F
0005433102507	7926	18	8B
0005432020441	7926	19	8C
0005432020459	7926	20	8D
0005432920008	7926	21	9B
0005432020463	7926	22	9A
0005432920009	7926	23	9C
0005432020447	7926	24	9E
0005432677602	7926	25	10A
0005433102486	7926	26	10B
0005433102478	7926	27	10D
0005433102511	7926	28	10E
0005432020453	7926	29	11B
0005433102527	7926	30	11C
0005432751552	7926	31	11D
0005433102499	7926	32	11E
0005433102513	7926	33	12A
0005432020462	7926	34	12C
0005432677603	7926	35	12D
0005432020449	7926	36	12F
0005433102495	7926	37	12E
0005433102521	7926	38	13A
0005432020458	7926	39	13D
0005432920005	7926	40	13E
0005432919999	7926	41	13F
0005432020464	7926	42	14B
0005433102517	7926	43	14C
0005433102484	7926	44	14F
0005432044545	7926	45	15B
0005433102510	7926	46	15A
0005433102520	7926	47	15C
0005433102526	7926	48	15D
0005432045628	7926	49	16B
0005432020456	7926	50	16D
0005433102485	7926	51	16C
0005432020448	7926	52	16E
0005433102482	7926	53	16F
0005432020455	7926	54	17A
0005432020452	7926	55	17B
0005433102505	7926	56	17E
0005433102509	7926	57	17D
0005433102489	7926	58	17F
0005433102523	7926	59	18C
0005432753324	7926	60	18B
0005432919997	7926	61	18E
0005432020457	7926	62	18D
0005432920013	7926	63	18F
0005433102514	7926	64	19C
0005432920007	7926	65	19B
0005432751549	7926	66	19E
0005432751550	7926	67	19D
0005433102525	7926	68	20C
0005432020451	7926	69	20B
0005432919996	7926	70	20E
0005432392022	7926	71	21B
0005432920014	7926	72	20F
0005433102480	7926	73	21C
0005432920000	7926	74	21D
0005432020461	7926	75	22A
0005432020442	7926	76	21F
0005433102479	7926	77	22B
0005433102494	7926	78	22E
0005433102496	7926	79	22D
0005433102502	7926	80	23B
0005432020446	7926	81	23A
0005433102512	7926	82	23C
0005433102498	7926	83	23E
0005433102506	7926	84	24A
0005433102515	7926	85	23F
0005433102522	7926	86	24C
0005432919998	7926	87	24D
0005433102492	7926	88	25B
0005432020444	7926	89	25D
0005432045629	7926	90	25E
0005432920002	7926	91	26B
0005432920012	7926	92	26A
0005432020454	7926	93	26D
0005432677604	7926	94	26C
0005433102503	7926	95	26E
0005432020439	7926	96	27A
0005433102508	7926	97	27C
0005433102487	7926	98	27D
0005433102481	7926	99	28A
0005433102497	7926	100	28E
0005433102483	7926	101	28F
0005433102519	7926	102	29A
0005432020443	7926	103	29C
0005432044544	7926	104	29B
0005432920016	7926	105	29D
0005432044543	7926	106	29F
0005433102518	7926	107	29E
0005432020450	7926	108	30B
0005432044546	7926	109	30A
0005432920004	7926	110	30C
0005432020460	7926	111	31A
0005432020440	7926	112	30F
0005432920003	7926	113	31C
0005432920006	7926	114	31B
0005433102493	7926	115	31D
0005432920011	7926	116	31F
0005432817441	7925	1	1C
0005432817414	7925	2	2A
0005432817484	7925	3	4D
0005432817453	7925	4	4F
0005432817486	7925	5	5C
0005432817328	7925	6	6A
0005432901742	7925	7	6D
0005432817471	7925	8	7C
0005432817479	7925	9	7D
0005432817468	7925	10	8A
0005432817358	7925	11	8E
0005432817470	7925	12	9A
0005432817549	7925	13	8F
0005432901726	7925	14	9C
0005432817398	7925	15	9F
0005432817463	7925	16	10B
0005432817436	7925	17	10C
0005432817392	7925	18	10D
0005432817404	7925	19	10F
0005432817391	7925	20	11B
0005432817390	7925	21	11D
0005432002091	7925	22	11F
0005432817481	7925	23	12E
0005432002090	7925	24	13B
0005432817469	7925	25	13C
0005432901739	7925	26	13F
0005432817393	7925	27	14E
0005432817502	7925	28	14D
0005432817455	7925	29	15E
0005432817405	7925	30	16B
0005432901740	7925	31	17B
0005432817443	7925	32	17C
0005432901741	7925	33	17D
0005432901731	7925	34	17E
0005432901728	7925	35	18B
0005432817548	7925	36	18D
0005432817488	7925	37	18F
0005432901736	7925	38	19C
0005432817421	7925	39	19B
0005432817435	7925	40	19E
0005432817509	7925	41	20C
0005432817352	7925	42	21C
0005432901727	7925	43	21D
0005432817450	7925	44	21E
0005432817331	7925	45	22A
0005432817415	7925	46	22B
0005432901738	7925	47	22D
0005432817416	7925	48	22F
0005432817367	7925	49	22E
0005432817458	7925	50	23B
0005432817399	7925	51	23A
0005432901725	7925	52	23E
0005432817389	7925	53	24B
0005432817487	7925	54	24E
0005432817513	7925	55	24D
0005432817485	7925	56	25E
0005432901734	7925	57	26B
0005432901732	7925	58	26E
0005432901735	7925	59	26F
0005432901733	7925	60	28A
0005432817370	7925	61	27F
0005432817442	7925	62	28E
0005432817427	7925	63	29A
0005432817482	7925	64	29F
0005432901729	7925	65	30D
0005432901737	7925	66	30E
0005432901730	7925	67	31A
0005432817364	7925	68	31C
0005434175750	9664	1	1B
0005434175727	9664	2	2B
0005434175728	9664	3	3B
0005434175751	9664	4	4B
0005433870746	9664	5	5A
0005434175760	9664	6	6A
0005433870747	9664	7	6B
0005434175783	32349	1	1B
0005434175784	32349	2	3A
0005434175782	32349	3	4A
0005434175781	32349	4	6B
0005434426837	3463	1	1C
0005435902667	3463	2	1G
0005434426812	3463	3	1D
0005432188630	3463	4	2A
0005434878924	3463	5	1K
0005432799664	3463	6	2D
0005435126686	3463	7	2C
0005434878892	3463	8	2H
0005434878864	3463	9	2G
0005434878922	3463	10	3A
0005434426825	3463	11	2K
0005434878874	3463	12	3C
0005434878886	3463	13	3K
0005434878887	3463	14	4C
0005434878957	3463	15	4A
0005435126661	3463	16	4G
0005434426835	3463	17	4D
0005435902770	3463	18	4K
0005434878948	3463	19	5D
0005434878866	3463	20	5A
0005432799673	3463	21	5H
0005434426819	3463	22	5G
0005432799647	3463	23	11A
0005435126668	3463	24	5K
0005435902693	3463	25	11D
0005434878953	3463	26	11F
0005435902631	3463	27	11H
0005435626314	3463	28	11G
0005434878930	3463	29	12C
0005435126651	3463	30	12A
0005434878868	3463	31	12F
0005435126646	3463	32	12E
0005432799672	3463	33	12D
0005434878883	3463	34	13A
0005434878879	3463	35	13D
0005434878919	3463	36	13C
0005434878911	3463	37	13F
0005432183483	3463	38	13E
0005434938274	3463	39	13G
0005434878944	3463	40	13K
0005432799670	3463	41	14E
0005435126665	3463	42	14D
0005434878915	3463	43	14G
0005434938276	3463	44	14K
0005432613891	3463	45	14H
0005432799649	3463	46	15E
0005434426821	3463	47	16A
0005432611741	3463	48	15K
0005434878898	3463	49	16D
0005435126650	3463	50	16C
0005435126657	3463	51	16F
0005434878949	3463	52	16E
0005434878945	3463	53	16H
0005435902691	3463	54	16G
0005434426830	3463	55	17E
0005434426813	3463	56	17D
0005434878894	3463	57	17C
0005432183482	3463	58	17G
0005435126685	3463	59	17F
0005435126663	3463	60	17K
0005435126649	3463	61	17H
0005434938280	3463	62	18A
0005435902646	3463	63	18G
0005432613892	3463	64	18J
0005432613890	3463	65	18H
0005435126687	3463	66	19B
0005434878946	3463	67	19A
0005435902705	3463	68	18K
0005435126662	3463	69	19D
0005435902650	3463	70	19C
0005434878863	3463	71	19F
0005432799668	3463	72	19E
0005434426828	3463	73	20A
0005432799652	3463	74	19K
0005434878878	3463	75	19J
0005432611739	3463	76	20B
0005434938283	3463	77	20E
0005435126682	3463	78	20D
0005435902706	3463	79	20F
0005434426810	3463	80	20J
0005434878921	3463	81	20H
0005434878906	3463	82	21A
0005435902675	3463	83	21D
0005435126659	3463	84	21C
0005434878865	3463	85	21B
0005435626309	3463	86	21G
0005434878884	3463	87	21F
0005434426832	3463	88	21E
0005435626315	3463	89	21J
0005434426814	3463	90	21H
0005434878936	3463	91	22A
0005434426811	3463	92	21K
0005434878914	3463	93	22E
0005434878950	3463	94	22H
0005435913926	3463	95	22G
0005434938290	3463	96	22F
0005434878913	3463	97	22K
0005434878917	3463	98	23A
0005432799657	3463	99	23D
0005434938279	3463	100	23C
0005435126676	3463	101	23J
0005434878881	3463	102	23H
0005435126674	3463	103	23G
0005432799659	3463	104	24D
0005434938277	3463	105	23K
0005434878923	3463	106	24F
0005434878925	3463	107	24E
0005434878947	3463	108	25A
0005434878889	3463	109	24G
0005435126680	3463	110	25C
0005434878929	3463	111	25F
0005434878901	3463	112	25E
0005434878916	3463	113	25G
0005435902621	3463	114	25J
0005435126670	3463	115	26B
0005434878928	3463	116	26E
0005432799669	3463	117	26D
0005434878910	3463	118	26C
0005432611740	3463	119	26G
0005434878940	3463	120	26F
0005434426815	3463	121	26K
0005434878903	3463	122	27A
0005432799650	3463	123	27C
0005434878871	3463	124	27E
0005434878897	3463	125	27D
0005434878939	3463	126	27H
0005435913925	3463	127	27G
0005434426822	3463	128	28C
0005434878876	3463	129	28A
0005435126656	3463	130	28J
0005435126652	3463	131	29A
0005434426836	3463	132	28K
0005434938292	3463	133	29H
0005434878935	3463	134	30A
0005434938273	3463	135	30E
0005435126666	3463	136	30D
0005435626308	3463	137	30F
0005432799662	3463	138	30J
0005434878938	3463	139	30H
0005434878908	3463	140	31B
0005435126658	3463	141	31A
0005435626310	3463	142	31D
0005434426823	3463	143	31C
0005435126655	3463	144	31F
0005434878900	3463	145	31E
0005434878934	3463	146	31J
0005435902662	3463	147	31H
0005435126648	3463	148	32A
0005435902724	3463	149	32E
0005432799653	3463	150	32D
0005435126654	3463	151	32G
0005432799667	3463	152	32F
0005434878954	3463	153	32K
0005434878912	3463	154	33B
0005435626311	3463	155	33D
0005434878941	3463	156	33J
0005434878931	3463	157	33K
0005434938287	3463	158	34B
0005434426816	3463	159	34A
0005434878942	3463	160	34E
0005434878869	3463	161	34D
0005435126683	3463	162	34C
0005435126669	3463	163	34K
0005435902676	3463	164	34H
0005435902698	3463	165	35B
0005434938286	3463	166	35A
0005434878932	3463	167	35D
0005434878920	3463	168	35C
0005434878904	3463	169	35F
0005435126677	3463	170	35E
0005435902664	3463	171	35H
0005434878951	3463	172	36A
0005434878907	3463	173	35J
0005435902644	3463	174	36D
0005434878905	3463	175	36C
0005434938289	3463	176	36E
0005434878891	3463	177	36H
0005434938288	3463	178	36G
0005435126675	3463	179	36J
0005434426834	3463	180	37B
0005434878888	3463	181	37A
0005435626307	3463	182	37E
0005434938281	3463	183	37H
0005434938291	3463	184	37G
0005434938284	3463	185	37K
0005435126660	3463	186	38B
0005434878933	3463	187	38H
0005434878867	3463	188	39B
0005434878909	3463	189	38K
0005435126678	3463	190	39C
0005435126679	3463	191	39F
0005434878895	3463	192	39E
0005435902674	3463	193	39D
0005432613893	3463	194	39H
0005434878870	3463	195	39K
0005434426833	3463	196	40C
0005432799675	3463	197	40B
0005432188631	3463	198	40D
0005435902739	3463	199	40F
0005434426829	3463	200	40J
0005434426831	3463	201	40H
0005434878952	3463	202	41A
0005435126653	3463	203	41D
0005432799656	3463	204	41C
0005434878926	3463	205	41F
0005434878956	3463	206	41E
0005435902725	3463	207	41H
0005435841822	3463	208	41K
0005432611738	3463	209	41J
0005435126681	3463	210	42B
0005434426820	3463	211	42A
0005434878873	3463	212	42E
0005435126684	3463	213	42D
0005432799651	3463	214	42F
0005432799654	3463	215	42J
0005434878890	3463	216	43A
0005434426818	3463	217	43D
0005435626306	3463	218	43C
0005432799660	3463	219	43E
0005435626312	3463	220	43H
0005434878896	3463	221	43K
0005432188632	3463	222	43J
0005434426826	3463	223	44B
0005434878918	3463	224	44A
0005432799661	3463	225	44E
0005434878902	3463	226	44D
0005434878880	3463	227	44H
0005434878893	3463	228	44F
0005434426827	3463	229	44J
0005434878862	3463	230	44K
0005434878927	3463	231	45C
0005435126673	3463	232	45B
0005432799665	3463	233	45F
0005432799674	3463	234	45D
0005432799671	3463	235	45H
0005434878937	3463	236	46A
0005432799655	3463	237	46B
0005432799648	3463	238	46D
0005435126671	3463	239	46G
0005434938275	3463	240	46F
0005435126667	3463	241	46H
0005435626313	3463	242	47C
0005435126664	3463	243	47A
0005434878955	3463	244	47D
0005434426824	3463	245	47G
0005434878875	3463	246	47F
0005432799663	3463	247	47E
0005434938282	3463	248	47K
0005435126672	3463	249	48C
0005434938285	3463	250	48D
0005434878882	3463	251	48H
0005432799658	3463	252	48G
0005435913927	3463	253	49A
0005434426809	3463	254	49D
0005434878899	3463	255	49G
0005434878885	3463	256	49K
0005434878877	3463	257	50A
0005434426817	3463	258	50E
0005435902699	3463	259	50D
0005435126647	3463	260	50H
0005434878943	3463	261	50G
0005434938278	3463	262	50F
0005434878872	3463	263	50K
0005432799666	3463	264	51E
0005435902645	3463	265	51G
0005434938172	14552	1	1C
0005434878122	14552	2	1A
0005435626095	14552	3	1G
0005434878636	14552	4	1D
0005432799363	14552	5	2A
0005434426552	14552	6	1K
0005434426592	14552	7	1H
0005432799510	14552	8	2C
0005434878274	14552	9	2G
0005434878015	14552	10	3A
0005435626074	14552	11	3C
0005435902834	14552	12	3H
0005434878115	14552	13	4C
0005434878144	14552	14	4A
0005435902830	14552	15	4G
0005432611703	14552	16	4D
0005434878149	14552	17	5A
0005432799380	14552	18	5H
0005435626101	14552	19	5G
0005434426563	14552	20	5K
0005434878717	14552	21	11D
0005435126315	14552	22	11C
0005435902840	14552	23	11F
0005434878135	14552	24	11K
0005434877841	14552	25	11G
0005434938076	14552	26	12C
0005434877972	14552	27	12G
0005432799381	14552	28	13D
0005435902831	14552	29	13C
0005434878413	14552	30	13F
0005434938065	14552	31	13E
0005434877819	14552	32	13H
0005434878418	14552	33	13G
0005435626109	14552	34	14C
0005434878282	14552	35	13K
0005434878420	14552	36	14G
0005435126288	14552	37	14F
0005434878011	14552	38	14K
0005434878421	14552	39	14H
0005434426512	14552	40	15C
0005432799442	14552	41	15A
0005434878176	14552	42	15D
0005434878043	14552	43	15G
0005434878089	14552	44	15K
0005434937981	14552	45	16D
0005432799443	14552	46	16G
0005435126317	14552	47	16K
0005435126289	14552	48	17C
0005435902823	14552	49	17A
0005434426564	14552	50	17E
0005435841826	14552	51	17D
0005434426593	14552	52	17G
0005434878067	14552	53	17F
0005434878214	14552	54	17H
0005434877991	14552	55	18B
0005434426613	14552	56	18C
0005434938161	14552	57	18F
0005435126243	14552	58	18J
0005434878102	14552	59	18H
0005434877868	14552	60	19B
0005434938029	14552	61	19C
0005435126551	14552	62	19F
0005434426708	14552	63	19E
0005434426480	14552	64	19H
0005432059518	14552	65	19G
0005434426573	14552	66	20A
0005434877919	14552	67	19K
0005434426608	14552	68	19J
0005435126171	14552	69	20C
0005434938138	14552	70	20B
0005434938123	14552	71	20G
0005435126316	14552	72	20J
0005432799456	14552	73	20H
0005434877976	14552	74	21A
0005435126284	14552	75	20K
0005434426520	14552	76	21F
0005434938143	14552	77	21H
0005434426635	14552	78	21G
0005434877987	14552	79	22A
0005435126172	14552	80	21K
0005435626098	14552	81	22B
0005434877979	14552	82	22E
0005432611705	14552	83	22D
0005434877786	14552	84	22G
0005435126298	14552	85	22F
0005435126400	14552	86	22K
0005432799428	14552	87	22H
0005432799473	14552	88	23B
0005434878315	14552	89	23A
0005432799495	14552	90	23D
0005435626123	14552	91	23C
0005434938144	14552	92	23G
0005434938036	14552	93	23F
0005434877852	14552	94	23E
0005432611725	14552	95	23H
0005434877884	14552	96	24D
0005435126440	14552	97	23K
0005434877977	14552	98	23J
0005434938132	14552	99	24E
0005434426472	14552	100	25B
0005434878179	14552	101	25A
0005434877668	14552	102	24G
0005435126257	14552	103	25D
0005432611704	14552	104	25C
0005435126297	14552	105	25F
0005434938028	14552	106	25E
0005432611700	14552	107	25G
0005434938114	14552	108	25K
0005435126162	14552	109	26C
0005434877950	14552	110	26A
0005434878222	14552	111	26E
0005434426565	14552	112	26D
0005435126383	14552	113	26G
0005434426725	14552	114	26F
0005432799436	14552	115	26J
0005435126355	14552	116	27A
0005434938108	14552	117	26K
0005434878276	14552	118	27D
0005434877992	14552	119	27C
0005435902838	14552	120	27B
0005434877871	14552	121	27F
0005434938173	14552	122	27E
0005432607543	14552	123	27G
0005434877941	14552	124	28A
0005432799465	14552	125	27K
0005435126235	14552	126	27J
0005434878219	14552	127	28B
0005432799362	14552	128	28E
0005435126208	14552	129	28D
0005434878496	14552	130	28C
0005434878357	14552	131	28K
0005434878407	14552	132	28H
0005434878007	14552	133	29B
0005434426531	14552	134	29C
0005435902829	14552	135	29D
0005434878148	14552	136	29G
0005435126401	14552	137	29J
0005434878365	14552	138	30C
0005435626091	14552	139	30B
0005435126357	14552	140	30A
0005434878398	14552	141	30E
0005434426634	14552	142	30G
0005435126318	14552	143	30F
0005432799323	14552	144	30K
0005434878321	14552	145	30J
0005434877579	14552	146	31B
0005434878568	14552	147	31A
0005435126299	14552	148	31D
0005434878210	14552	149	31C
0005434878109	14552	150	31F
0005434878211	14552	151	31G
0005434878358	14552	152	31J
0005435902821	14552	153	32C
0005434878180	14552	154	32B
0005435126239	14552	155	32A
0005432059519	14552	156	32E
0005432799433	14552	157	32D
0005434878414	14552	158	32G
0005434426672	14552	159	32F
0005435126300	14552	160	32K
0005434938124	14552	161	32H
0005434877951	14552	162	33B
0005434877578	14552	163	33D
0005434878223	14552	164	33C
0005434426609	14552	165	33F
0005435126128	14552	166	33J
0005434938136	14552	167	33G
0005434878277	14552	168	33K
0005435626075	14552	169	34C
0005434878209	14552	170	34A
0005434878314	14552	171	34G
0005434938066	14552	172	34F
0005435902839	14552	173	34J
0005434878071	14552	174	35A
0005434878177	14552	175	35G
0005434878370	14552	176	35F
0005435126152	14552	177	35E
0005434878390	14552	178	35H
0005434426495	14552	179	36F
0005434878103	14552	180	36H
0005434878408	14552	181	36J
0005435626114	14552	182	37B
0005434878163	14552	183	37A
0005435626094	14552	184	37E
0005434878275	14552	185	37C
0005435626099	14552	186	37G
0005435902833	14552	187	37F
0005434426550	14552	188	37H
0005434878162	14552	189	38B
0005434877971	14552	190	38K
0005434426533	14552	191	38J
0005434877842	14552	192	39F
0005434878399	14552	193	39E
0005432799501	14552	194	39H
0005435626100	14552	195	39G
0005435902822	14552	196	40A
0005434938135	14552	197	39K
0005434878363	14552	198	40C
0005435626049	14552	199	40B
0005435126125	14552	200	40E
0005435126127	14552	201	40D
0005434877915	14552	202	40G
0005434426594	14552	203	40H
0005432799401	14552	204	41B
0005434877869	14552	205	41A
0005435126382	14552	206	40K
0005434938137	14552	207	41D
0005435902826	14552	208	41C
0005435126157	14552	209	41G
0005434426460	14552	210	42A
0005434878058	14552	211	41K
0005435902824	14552	212	42C
0005434878108	14552	213	42E
0005435126314	14552	214	42F
0005434877902	14552	215	42J
0005434878391	14552	216	43A
0005434877632	14552	217	42K
0005432611699	14552	218	43D
0005435126237	14552	219	43C
0005434878290	14552	220	43B
0005434878114	14552	221	43F
0005434877707	14552	222	43H
0005435126442	14552	223	43G
0005434877708	14552	224	43K
0005435902825	14552	225	43J
0005432611712	14552	226	44C
0005432799452	14552	227	44B
0005435902832	14552	228	44A
0005434426479	14552	229	44E
0005432799420	14552	230	44D
0005435902837	14552	231	44F
0005434878456	14552	232	44J
0005435626092	14552	233	44H
0005435902836	14552	234	45A
0005434938115	14552	235	45C
0005434878254	14552	236	45B
0005434877469	14552	237	45F
0005435626080	14552	238	45D
0005435126158	14552	239	45H
0005434878567	14552	240	45G
0005432611724	14552	241	45K
0005434426617	14552	242	46C
0005435126219	14552	243	46B
0005435902828	14552	244	46A
0005434878264	14552	245	46D
0005434877978	14552	246	46H
0005434877920	14552	247	46G
0005435626070	14552	248	46F
0005434426553	14552	249	46J
0005435626106	14552	250	47C
0005434878635	14552	251	47A
0005434426532	14552	252	46K
0005432799432	14552	253	47E
0005435126236	14552	254	47D
0005434877669	14552	255	47F
0005432799419	14552	256	48A
0005435126356	14552	257	47H
0005434877429	14552	258	48D
0005435902835	14552	259	48C
0005432799338	14552	260	48F
0005432799496	14552	261	48E
0005435126417	14552	262	48H
0005435902827	14552	263	48G
0005434938075	14552	264	49C
0005434426614	14552	265	49A
0005434877957	14552	266	48K
0005434938145	14552	267	49E
0005434426541	14552	268	49G
0005434877942	14552	269	50C
0005432607540	14552	270	50A
0005435126153	14552	271	50D
0005432799457	14552	272	50H
0005435626055	14552	273	50G
0005434878150	14552	274	50F
0005434938030	14552	275	51D
0005435626056	14552	276	50K
0005434878267	14552	277	51E
0005434877787	14552	278	51G
0005435889885	3627	1	1A
0005435889891	3627	2	1B
0005435889884	3627	3	1C
0005434325733	3627	4	2D
0005435889882	3627	5	3D
0005435889890	3627	6	4A
0005434325730	3627	7	4C
0005435889898	3627	8	4D
0005434325728	3627	9	6A
0005434325734	3627	10	6D
0005434325727	3627	11	7B
0005434312335	3627	12	7C
0005434325737	3627	13	18A
0005435889897	3627	14	18D
0005434325735	3627	15	19A
0005434312334	3627	16	19B
0005435889858	3627	17	19C
0005434325729	3627	18	19D
0005434312333	3627	19	20B
0005434325731	3627	20	20C
0005434325738	3627	21	21B
0005434325736	3627	22	21C
0005435889873	3627	23	22A
0005434325732	3627	24	22D
0005435889904	3627	25	23B
0005434325663	15598	1	1B
0005434325623	15598	2	2C
0005434325659	15598	3	3A
0005435889940	15598	4	3B
0005434325609	15598	5	3C
0005435889939	15598	6	4D
0005434325652	15598	7	5A
0005434325671	15598	8	5B
0005434325651	15598	9	5C
0005435889937	15598	10	5D
0005434325664	15598	11	6A
0005434325627	15598	12	6B
0005435889941	15598	13	6D
0005435889938	15598	14	7A
0005434325640	15598	15	7C
0005434325650	15598	16	18B
0005434325666	15598	17	18C
0005435889942	15598	18	19A
0005434325626	15598	19	19C
0005434325639	15598	20	20B
0005434325642	15598	21	20C
0005434325670	15598	22	21A
0005434325665	15598	23	21B
0005434325658	15598	24	21C
0005434325647	15598	25	21D
0005434325621	15598	26	22B
0005434325641	15598	27	22C
0005434325656	15598	28	22D
0005434325657	15598	29	23B
0005435957806	667	1	1A
0005435957805	667	2	1C
0005435957802	667	3	2A
0005435957804	667	4	2C
0005435957803	667	5	4A
0005435957811	667	6	4B
0005435957812	667	7	5A
0005433420369	667	8	5D
0005433420365	667	9	6A
0005433420401	667	10	18A
0005435957810	667	11	18B
0005433420355	667	12	18C
0005435957809	667	13	19A
0005435957808	667	14	19D
0005433420386	667	15	20A
0005435957814	667	16	21A
0005433420403	667	17	21C
0005435957816	667	18	22A
0005435957801	667	19	22B
0005435957813	667	20	22C
0005433420370	667	21	22D
0005435957815	667	22	23A
0005435957807	667	23	23B
0005435957674	15172	1	1B
0005435957645	15172	2	1C
0005433420464	15172	3	1D
0005433420462	15172	4	2A
0005433420468	15172	5	2B
0005433420463	15172	6	2C
0005435957739	15172	7	3A
0005435957684	15172	8	3D
0005435957672	15172	9	4B
0005435957705	15172	10	4C
0005435957647	15172	11	4D
0005435957613	15172	12	5A
0005435957671	15172	13	5B
0005433420466	15172	14	6A
0005435957668	15172	15	6B
0005435957693	15172	16	6C
0005435957676	15172	17	6D
0005435957675	15172	18	7A
0005433420461	15172	19	7B
0005435957704	15172	20	7C
0005435957695	15172	21	7D
0005435957698	15172	22	18A
0005433420467	15172	23	19A
0005435957692	15172	24	19B
0005435957646	15172	25	19C
0005435957696	15172	26	19D
0005435957670	15172	27	20A
0005435957667	15172	28	21A
0005435957607	15172	29	21C
0005433420465	15172	30	21D
0005433420460	15172	31	22A
0005435957694	15172	32	22B
0005435957669	15172	33	23A
0005435218122	31786	1	1A
0005435217725	31786	2	2C
0005435216600	31786	3	3A
0005435216603	31786	4	3B
0005435217726	31786	5	4A
0005435216606	31786	6	4C
0005435216601	31786	7	6A
0005435217727	31786	8	6C
0005435216604	31786	9	18A
0005435216602	31786	10	18D
0005435217729	31786	11	19C
0005435217728	31786	12	19D
0005435216605	31786	13	20D
0005435217730	31786	14	21D
0005435217724	31786	15	22C
0005435218121	31786	16	22D
0005434995311	6702	1	1C
0005434995317	6702	2	3A
0005434995319	6702	3	4B
0005434995320	6702	4	6A
0005434995313	6702	5	6C
0005434995312	6702	6	6F
0005434995315	6702	7	7C
0005434995314	6702	8	8B
0005434995325	6702	9	13F
0005434995318	6702	10	14C
0005434995322	6702	11	14E
0005434995324	6702	12	16D
0005434995310	6702	13	16F
0005434995321	6702	14	18B
0005434995316	6702	15	19E
0005434995323	6702	16	20D
0005434247143	8888	1	2A
0005435629412	8888	2	3B
0005434247156	8888	3	6A
0005434247165	16066	1	3B
0005434247166	16066	2	4B
0005434247167	16066	3	6A
0005434467779	4009	1	3A
0005434467781	4009	2	4B
0005434467777	4009	3	5C
0005434467778	4009	4	6B
0005434467776	4009	5	7A
0005434467780	4009	6	18D
0005434467775	4009	7	22A
0005434467745	23212	1	1A
0005434467758	23212	2	20A
0005434467744	23212	3	20D
0005434467762	23212	4	22B
0005434467754	23212	5	22C
0005434096756	20164	1	1B
0005434096750	20164	2	2A
0005434096755	20164	3	5B
0005434096754	20164	4	6B
0005434096753	20164	5	7C
0005434096752	20164	6	18A
0005434096751	20164	7	18C
0005434096757	20164	8	18D
0005432646052	6838	1	1D
0005432646058	6838	2	2D
0005432646053	6838	3	2F
0005432646091	6838	4	3A
0005435229411	6838	5	3D
0005432646066	6838	6	3F
0005432646086	6838	7	4C
0005432646063	6838	8	4F
0005432646057	6838	9	5A
0005432646056	6838	10	5D
0005432646065	6838	11	5C
0005435229405	6838	12	6C
0005435229413	6838	13	6E
0005435229392	6838	14	6F
0005432646071	6838	15	7A
0005432646059	6838	16	7C
0005435229412	6838	17	7D
0005432646075	6838	18	7E
0005435229356	6838	19	7F
0005432646062	6838	20	8D
0005432646087	6838	21	8E
0005432646083	6838	22	9D
0005432646064	6838	23	9E
0005432646081	6838	24	9F
0005432646077	6838	25	10C
0005432646073	6838	26	10D
0005432646089	6838	27	10F
0005435229386	6838	28	11C
0005432646069	6838	29	11D
0005432646074	6838	30	11E
0005432646070	6838	31	11F
0005435229359	6838	32	12A
0005432646076	6838	33	12D
0005435229430	6838	34	12E
0005435229414	6838	35	13A
0005432646084	6838	36	13C
0005432646061	6838	37	13E
0005435229432	6838	38	14A
0005432646060	6838	39	14C
0005435229406	6838	40	14D
0005435229404	6838	41	15C
0005432646054	6838	42	15E
0005432646072	6838	43	15F
0005432646085	6838	44	16A
0005432646090	6838	45	16F
0005435229390	6838	46	17C
0005432646078	6838	47	17E
0005432646068	6838	48	18A
0005432646079	6838	49	18E
0005432646088	6838	50	19A
0005432646082	6838	51	19D
0005432646055	6838	52	19E
0005435229391	6838	53	20A
0005432646080	6838	54	20C
0005432646067	6838	55	20D
0005435229460	25104	1	1A
0005432645922	25104	2	1C
0005432645930	25104	3	1D
0005435229483	25104	4	1F
0005435229474	25104	5	2A
0005435229471	25104	6	2D
0005432645917	25104	7	2F
0005435229478	25104	8	3A
0005432645959	25104	9	3C
0005435229469	25104	10	3D
0005435229458	25104	11	3F
0005435229482	25104	12	4A
0005432645911	25104	13	4C
0005432645925	25104	14	5A
0005432645927	25104	15	5C
0005435229457	25104	16	5E
0005432645891	25104	17	5F
0005432645968	25104	18	6A
0005432645964	25104	19	6C
0005432645948	25104	20	6D
0005432645949	25104	21	6E
0005432645979	25104	22	6F
0005432645957	25104	23	7E
0005435229459	25104	24	7F
0005432645937	25104	25	8C
0005432645985	25104	26	8D
0005432645907	25104	27	8E
0005435229466	25104	28	8F
0005435229470	25104	29	9A
0005435229479	25104	30	9D
0005432645914	25104	31	9E
0005432645916	25104	32	9F
0005435229463	25104	33	10A
0005432645938	25104	34	10D
0005432645926	25104	35	10E
0005432645892	25104	36	10F
0005432645923	25104	37	11A
0005432645982	25104	38	11C
0005435229484	25104	39	11D
0005435229473	25104	40	11E
0005435229468	25104	41	12A
0005432645919	25104	42	12E
0005432645893	25104	43	12F
0005435229465	25104	44	13A
0005435229481	25104	45	13C
0005435229475	25104	46	13E
0005432645889	25104	47	13F
0005432645913	25104	48	14A
0005435229485	25104	49	14D
0005435229486	25104	50	14F
0005435229477	25104	51	15A
0005435229472	25104	52	15C
0005432645924	25104	53	15D
0005435229476	25104	54	15E
0005432645939	25104	55	15F
0005432645918	25104	56	16A
0005432645908	25104	57	16C
0005432645936	25104	58	16D
0005435229467	25104	59	16E
0005432645942	25104	60	17A
0005432645929	25104	61	17C
0005432645886	25104	62	17D
0005432645873	25104	63	17E
0005432645955	25104	64	17F
0005435229461	25104	65	18A
0005435229464	25104	66	18C
0005435229480	25104	67	18D
0005432645954	25104	68	18E
0005432645941	25104	69	18F
0005432645928	25104	70	19A
0005432645934	25104	71	19C
0005432645920	25104	72	19D
0005435229462	25104	73	20A
0005432645940	25104	74	20C
0005432645944	25104	75	20D
0005432645956	25104	76	20E
0005432645906	25104	77	20F
0005435797582	2866	1	1A
0005435797572	2866	2	3A
0005435797578	2866	3	3C
0005435797574	2866	4	4D
0005435797573	2866	5	4E
0005433404777	2866	6	5D
0005433404760	2866	7	6D
0005435797575	2866	8	7C
0005435797581	2866	9	7E
0005435797576	2866	10	8A
0005433404786	2866	11	11D
0005435797583	2866	12	11E
0005435797580	2866	13	14F
0005435797571	2866	14	15A
0005433404761	2866	15	16C
0005435797569	2866	16	17A
0005435797579	2866	17	17E
0005435797577	2866	18	18A
0005435797570	2866	19	18F
0005433404806	2866	20	20A
0005433404787	2866	21	20F
0005435797497	29342	1	1D
0005435797401	29342	2	2D
0005435797467	29342	3	4A
0005433404864	29342	4	4C
0005435797529	29342	5	5D
0005435797469	29342	6	5E
0005435797400	29342	7	7E
0005433404862	29342	8	8F
0005433404866	29342	9	9E
0005433404861	29342	10	10E
0005433404865	29342	11	11A
0005435797528	29342	12	11F
0005435797451	29342	13	13C
0005435797498	29342	14	14D
0005435797480	29342	15	15C
0005433404863	29342	16	17C
0005435797445	29342	17	17D
0005435797470	29342	18	19A
0005435797450	29342	19	20D
0005435376357	5804	1	1B
0005435376351	5804	2	2B
0005435376352	5804	3	3A
0005435376346	5804	4	3B
0005435376347	5804	5	4B
0005434948082	5749	1	1B
0005434948080	5749	2	2A
0005434948076	5749	3	3A
0005434948077	5749	4	3B
0005434948081	5749	5	4A
0005434948083	5749	6	4B
0005434948074	5749	7	5A
0005434948075	5749	8	5B
0005434948078	5749	9	6A
0005434948079	5749	10	6B
0005434948005	16330	1	1A
0005434948031	16330	2	2A
0005434947992	16330	3	3A
0005434948008	16330	4	2B
0005434948034	16330	5	3B
0005434948010	16330	6	4A
0005434948030	16330	7	4B
0005434948032	16330	8	5A
0005434948009	16330	9	5B
0005434948007	16330	10	6B
0005434948033	16330	11	6A
0005433961279	6913	1	1C
0005433961314	6913	2	1F
0005433961287	6913	3	2A
0005433961290	6913	4	2D
0005433961317	6913	5	2F
0005433961285	6913	6	3A
0005433961307	6913	7	4C
0005433961298	6913	8	4D
0005433961326	6913	9	4E
0005433961294	6913	10	4F
0005433961302	6913	11	5A
0005433961316	6913	12	5C
0005433961282	6913	13	5D
0005433961325	6913	14	5F
0005433961322	6913	15	6A
0005433961269	6913	16	6C
0005433961295	6913	17	6F
0005433961311	6913	18	7C
0005433961286	6913	19	7D
0005433961319	6913	20	7E
0005433961306	6913	21	7F
0005433961283	6913	22	8A
0005433961310	6913	23	8C
0005433961320	6913	24	8D
0005433961305	6913	25	8E
0005433961289	6913	26	8F
0005433961308	6913	27	9A
0005433961309	6913	28	9C
0005433961318	6913	29	9E
0005433961270	6913	30	10A
0005433961296	6913	31	10C
0005433961264	6913	32	10D
0005433961280	6913	33	10E
0005433961292	6913	34	10F
0005433961277	6913	35	11A
0005433961272	6913	36	11C
0005433961297	6913	37	11D
0005433961303	6913	38	11E
0005433961313	6913	39	11F
0005433961293	6913	40	12D
0005433961300	6913	41	12E
0005433961312	6913	42	13A
0005433961273	6913	43	13C
0005433961328	6913	44	13D
0005433961288	6913	45	13F
0005433961263	6913	46	14A
0005433961323	6913	47	14C
0005433961315	6913	48	14D
0005433961276	6913	49	14E
0005433961266	6913	50	14F
0005433961299	6913	51	15C
0005433961271	6913	52	15E
0005433961267	6913	53	16F
0005433961274	6913	54	17A
0005433961291	6913	55	17C
0005433961324	6913	56	17D
0005433961265	6913	57	17E
0005433961327	6913	58	18A
0005433961284	6913	59	18C
0005433961278	6913	60	18F
0005433961275	6913	61	19A
0005433961304	6913	62	19C
0005433961301	6913	63	19D
0005433961281	6913	64	20D
0005433961321	6913	65	20E
0005433961268	6913	66	20F
0005433960452	25770	1	1A
0005433960343	25770	2	1C
0005433960346	25770	3	1D
0005433960607	25770	4	2C
0005433960584	25770	5	2F
0005433960390	25770	6	3C
0005433960526	25770	7	4A
0005433960727	25770	8	4C
0005433960626	25770	9	4D
0005433960603	25770	10	4E
0005433960544	25770	11	4F
0005433960704	25770	12	5A
0005433960461	25770	13	5D
0005433960714	25770	14	5E
0005433960525	25770	15	6A
0005433960545	25770	16	6C
0005433960304	25770	17	6E
0005433960692	25770	18	6F
0005433960624	25770	19	7A
0005433960677	25770	20	7C
0005433960648	25770	21	7F
0005433960681	25770	22	8A
0005433960730	25770	23	8C
0005433960701	25770	24	8F
0005433960500	25770	25	9A
0005433960731	25770	26	9F
0005433960597	25770	27	10A
0005433960715	25770	28	10D
0005433960354	25770	29	10E
0005433960586	25770	30	11A
0005433960547	25770	31	11C
0005433960532	25770	32	11D
0005433960683	25770	33	11E
0005433960419	25770	34	11F
0005433960499	25770	35	12A
0005433960726	25770	36	12E
0005433960347	25770	37	13A
0005433960599	25770	38	13C
0005433960690	25770	39	13D
0005433960722	25770	40	13E
0005433960672	25770	41	13F
0005433960700	25770	42	14A
0005433960633	25770	43	14D
0005433960691	25770	44	14E
0005433960689	25770	45	14F
0005433960669	25770	46	15A
0005433960696	25770	47	15C
0005433960697	25770	48	15D
0005433960529	25770	49	15E
0005433960634	25770	50	15F
0005433960653	25770	51	16A
0005433960652	25770	52	16C
0005433960713	25770	53	16D
0005433960533	25770	54	16E
0005433960585	25770	55	16F
0005433960546	25770	56	17A
0005433960553	25770	57	17C
0005433960668	25770	58	17D
0005433960695	25770	59	17E
0005433960418	25770	60	17F
0005433960524	25770	61	18A
0005433960414	25770	62	18C
0005433960738	25770	63	18D
0005433960495	25770	64	18F
0005433960453	25770	65	19C
0005433960723	25770	66	19D
0005433960415	25770	67	19E
0005433960649	25770	68	20A
0005433960471	25770	69	20C
0005433960646	25770	70	20D
0005433960543	25770	71	20F
0005435082770	24506	1	2B
0005435082780	24506	2	5B
0005435082840	26110	1	1A
0005435082835	26110	2	1B
0005435082838	26110	3	2A
0005435082834	26110	4	3A
0005435082839	26110	5	3B
0005435082833	26110	6	4B
0005435082837	26110	7	5A
0005435082836	26110	8	5B
0005435082832	26110	9	6B
0005432166925	5087	1	2D
0005434245204	5087	2	3C
0005434245180	5087	3	4A
0005434245196	5087	4	4F
0005434245195	5087	5	6D
0005434245201	5087	6	7C
0005434245189	5087	7	7D
0005434245207	5087	8	8C
0005434245203	5087	9	11A
0005434245205	5087	10	11F
0005434245198	5087	11	11E
0005434245191	5087	12	12D
0005434245194	5087	13	13D
0005432166924	5087	14	13F
0005432166926	5087	15	14A
0005433534499	5087	16	14E
0005434245182	5087	17	16B
0005434245200	5087	18	16E
0005435286616	5087	19	16F
0005434245181	5087	20	17C
0005434245177	5087	21	19B
0005434245186	5087	22	20A
0005434245190	5087	23	20C
0005434245187	5087	24	21B
0005435286612	5087	25	22A
0005433534491	5087	26	22D
0005434245183	5087	27	23A
0005434245197	5087	28	23B
0005434245178	5087	29	23F
0005434245193	5087	30	24B
0005434245206	5087	31	24D
0005434245179	5087	32	27B
0005434245199	5087	33	28B
0005433534498	5087	34	28A
0005434245192	5087	35	28E
0005434245188	5087	36	28D
0005434245184	5087	37	29E
0005434245185	5087	38	30E
0005434245202	5087	39	31D
0005432105900	5088	1	1C
0005433615220	5088	2	1A
0005432105929	5088	3	1D
0005433615254	5088	4	2A
0005433615215	5088	5	1F
0005433785210	5088	6	2D
0005433785193	5088	7	2C
0005432105911	5088	8	2F
0005433615217	5088	9	3A
0005433615256	5088	10	3C
0005433615250	5088	11	3D
0005433615212	5088	12	4A
0005433785200	5088	13	3F
0005432105893	5088	14	4D
0005432105898	5088	15	4C
0005433785191	5088	16	4F
0005433615198	5088	17	5A
0005433615227	5088	18	5C
0005432105912	5088	19	5F
0005433615224	5088	20	5D
0005432145126	5088	21	6A
0005432666404	5088	22	6D
0005433615194	5088	23	6C
0005433615186	5088	24	7A
0005433615248	5088	25	6F
0005433615196	5088	26	7C
0005433615246	5088	27	7F
0005433615185	5088	28	7D
0005433615213	5088	29	8A
0005433615219	5088	30	8B
0005433785201	5088	31	8D
0005432105916	5088	32	8C
0005432667469	5088	33	8E
0005432105910	5088	34	9A
0005433615189	5088	35	8F
0005433615231	5088	36	9C
0005433615244	5088	37	9B
0005433615193	5088	38	9D
0005432105917	5088	39	9F
0005433615188	5088	40	9E
0005432105887	5088	41	10A
0005432105914	5088	42	10B
0005432105928	5088	43	10D
0005432105915	5088	44	10C
0005433615208	5088	45	10E
0005433615202	5088	46	11A
0005433785207	5088	47	10F
0005433615206	5088	48	11C
0005433785196	5088	49	11B
0005432105888	5088	50	11D
0005433615245	5088	51	11F
0005432105897	5088	52	11E
0005433785220	5088	53	12A
0005433615184	5088	54	12B
0005433615243	5088	55	12C
0005433785203	5088	56	12E
0005432105923	5088	57	12D
0005433615232	5088	58	12F
0005433615209	5088	59	13A
0005432105894	5088	60	13C
0005432145125	5088	61	13B
0005433785192	5088	62	13D
0005432105926	5088	63	13E
0005432105903	5088	64	14A
0005433785205	5088	65	13F
0005432105920	5088	66	14C
0005433785218	5088	67	14B
0005433615257	5088	68	14D
0005433615236	5088	69	14E
0005432105906	5088	70	14F
0005432105896	5088	71	15B
0005432105922	5088	72	15A
0005432105891	5088	73	15C
0005432105901	5088	74	15D
0005433785194	5088	75	15E
0005433785222	5088	76	16A
0005433615240	5088	77	15F
0005433615195	5088	78	16C
0005433615203	5088	79	16B
0005433615183	5088	80	16D
0005433615235	5088	81	16E
0005432105930	5088	82	16F
0005433785219	5088	83	17B
0005432105932	5088	84	17A
0005432665289	5088	85	17C
0005432105934	5088	86	17D
0005432105918	5088	87	17E
0005432105907	5088	88	18A
0005433615211	5088	89	17F
0005432105886	5088	90	18B
0005433615214	5088	91	18D
0005433615201	5088	92	18C
0005433615210	5088	93	18E
0005433615233	5088	94	19B
0005432105895	5088	95	18F
0005432105933	5088	96	19D
0005433785199	5088	97	19C
0005432105919	5088	98	20A
0005433785221	5088	99	19E
0005433785215	5088	100	20B
0005432105909	5088	101	20C
0005433615191	5088	102	20D
0005432105927	5088	103	20E
0005432105924	5088	104	21B
0005433785206	5088	105	21A
0005432105925	5088	106	20F
0005433615205	5088	107	21C
0005433615234	5088	108	21D
0005433615199	5088	109	21E
0005433615218	5088	110	21F
0005433785209	5088	111	22B
0005433615259	5088	112	22A
0005433615252	5088	113	22C
0005433615225	5088	114	22E
0005433615226	5088	115	22D
0005432105921	5088	116	22F
0005433785216	5088	117	23A
0005433615197	5088	118	23C
0005432105931	5088	119	23B
0005433785189	5088	120	23D
0005432105908	5088	121	23F
0005433785214	5088	122	23E
0005432105902	5088	123	24B
0005432105892	5088	124	24A
0005433615190	5088	125	24D
0005432105890	5088	126	24C
0005433615249	5088	127	24E
0005433615222	5088	128	24F
0005432666403	5088	129	25A
0005432105913	5088	130	25C
0005433615200	5088	131	25B
0005433785204	5088	132	25D
0005433615241	5088	133	25E
0005433785198	5088	134	26A
0005433615247	5088	135	25F
0005433615216	5088	136	26B
0005433615204	5088	137	26D
0005433615221	5088	138	26C
0005432665288	5088	139	26E
0005433785202	5088	140	26F
0005433615230	5088	141	27B
0005433615239	5088	142	27A
0005432667470	5088	143	27C
0005433785217	5088	144	27D
0005433615255	5088	145	27E
0005433785197	5088	146	27F
0005432665290	5088	147	28B
0005432105904	5088	148	28A
0005433615187	5088	149	28C
0005433785213	5088	150	28E
0005433615229	5088	151	28D
0005433785212	5088	152	29A
0005432105899	5088	153	28F
0005432105889	5088	154	29B
0005433785211	5088	155	29C
0005433615242	5088	156	29D
0005433615258	5088	157	29F
0005433615237	5088	158	29E
0005433615253	5088	159	30A
0005433615251	5088	160	30C
0005433785195	5088	161	30B
0005432105905	5088	162	30D
0005433615223	5088	163	30E
0005433785188	5088	164	30F
0005433615192	5088	165	31B
0005433785190	5088	166	31A
0005433615207	5088	167	31C
0005433615238	5088	168	31D
0005433785208	5088	169	31F
0005433615228	5088	170	31E
0005434265327	5090	1	1A
0005434149812	5090	2	1D
0005435269728	5090	3	1F
0005434229527	5090	4	2C
0005434149816	5090	5	2D
0005432335992	5090	6	2F
0005434265323	5090	7	3D
0005434229534	5090	8	3C
0005435007022	5090	9	4C
0005434149820	5090	10	4D
0005434229540	5090	11	5A
0005435007075	5090	12	5D
0005435007084	5090	13	6A
0005435007036	5090	14	6C
0005434229530	5090	15	6F
0005432336018	5090	16	7A
0005434265325	5090	17	7C
0005434311204	5090	18	7F
0005434265322	5090	19	7D
0005435007020	5090	20	8A
0005434265330	5090	21	8D
0005434265316	5090	22	8C
0005434149817	5090	23	9A
0005434265314	5090	24	8F
0005434265317	5090	25	9C
0005434265329	5090	26	9B
0005434173550	5090	27	9D
0005434265332	5090	28	9F
0005435269743	5090	29	9E
0005434265312	5090	30	10A
0005432336021	5090	31	10C
0005435006932	5090	32	10B
0005434265331	5090	33	10D
0005434265326	5090	34	10F
0005432336006	5090	35	11B
0005434229535	5090	36	11E
0005435006881	5090	37	11D
0005434229543	5090	38	12A
0005434265310	5090	39	12D
0005435007076	5090	40	12C
0005434265313	5090	41	13A
0005435006927	5090	42	13C
0005434229542	5090	43	13D
0005433685513	5090	44	13E
0005434229526	5090	45	14C
0005434311212	5090	46	14D
0005435007011	5090	47	14F
0005435007067	5090	48	14E
0005435006973	5090	49	15B
0005434229521	5090	50	15A
0005432335965	5090	51	15C
0005432336016	5090	52	15D
0005434265333	5090	53	15E
0005434229532	5090	54	16E
0005435269729	5090	55	16D
0005433685512	5090	56	16F
0005434265321	5090	57	17B
0005435007009	5090	58	17A
0005435006962	5090	59	17E
0005435006928	5090	60	18A
0005434311205	5090	61	18B
0005434265311	5090	62	18D
0005433685514	5090	63	18C
0005434229544	5090	64	18E
0005434229528	5090	65	18F
0005435007066	5090	66	19C
0005434229537	5090	67	19D
0005435006914	5090	68	19E
0005434229524	5090	69	20A
0005434265319	5090	70	20B
0005434229523	5090	71	20E
0005434149815	5090	72	20D
0005435006915	5090	73	20F
0005435007004	5090	74	21C
0005433815381	5090	75	21B
0005435006944	5090	76	21E
0005435007019	5090	77	21D
0005432336049	5090	78	22B
0005434173547	5090	79	22D
0005434229525	5090	80	22E
0005434265334	5090	81	22F
0005434229541	5090	82	23B
0005433685516	5090	83	23A
0005434265324	5090	84	23C
0005435269733	5090	85	23E
0005434265328	5090	86	23F
0005435007010	5090	87	24B
0005435006848	5090	88	24E
0005434149811	5090	89	24D
0005432335993	5090	90	24F
0005434149819	5090	91	25B
0005434173548	5090	92	25C
0005432336050	5090	93	25D
0005434229536	5090	94	25E
0005432335995	5090	95	26A
0005434229538	5090	96	25F
0005434229529	5090	97	26E
0005434229533	5090	98	26F
0005435006882	5090	99	27B
0005434229539	5090	100	27A
0005434149821	5090	101	27C
0005435006931	5090	102	27D
0005435006954	5090	103	27F
0005432335991	5090	104	28A
0005434229522	5090	105	28E
0005433815382	5090	106	28D
0005434265335	5090	107	28F
0005434265336	5090	108	29B
0005434229531	5090	109	29A
0005434173551	5090	110	29C
0005434149809	5090	111	29E
0005434265320	5090	112	30A
0005434265315	5090	113	29F
0005432336017	5090	114	30B
0005434265318	5090	115	30D
0005432336011	5090	116	30C
0005434149814	5090	117	30E
0005434149818	5090	118	30F
0005434149810	5090	119	31A
0005433685515	5090	120	31C
0005434149813	5090	121	31D
0005434173549	5090	122	31F
0005433785027	8580	1	1A
0005433784782	8580	2	3D
0005435269791	8580	3	3C
0005434244880	8580	4	3F
0005435269788	8580	5	4A
0005433784781	8580	6	4C
0005434244958	8580	7	4F
0005433784862	8580	8	4D
0005433784875	8580	9	5A
0005434244998	8580	10	5D
0005434244842	8580	11	6A
0005433784879	8580	12	5F
0005433784830	8580	13	6C
0005433784973	8580	14	6F
0005434244956	8580	15	6D
0005434244982	8580	16	7A
0005433784928	8580	17	8A
0005435269794	8580	18	8C
0005434244832	8580	19	8E
0005432659695	8580	20	8F
0005434244858	8580	21	9B
0005434244971	8580	22	10B
0005434244818	8580	23	10D
0005432659696	8580	24	11A
0005433784795	8580	25	11B
0005434244957	8580	26	11D
0005433784806	8580	27	11F
0005433784911	8580	28	12A
0005435269786	8580	29	12B
0005435269795	8580	30	12E
0005433784937	8580	31	12F
0005434244911	8580	32	13A
0005433784905	8580	33	13F
0005434244889	8580	34	13E
0005432659706	8580	35	14A
0005435269790	8580	36	15F
0005434244970	8580	37	15E
0005435269793	8580	38	16A
0005433785026	8580	39	16D
0005433784944	8580	40	16C
0005434244912	8580	41	16F
0005434244864	8580	42	17C
0005434244877	8580	43	17D
0005434244859	8580	44	17F
0005432666380	8580	45	18B
0005435269792	8580	46	18D
0005433785002	8580	47	18C
0005433784917	8580	48	18E
0005433784927	8580	49	19B
0005434244887	8580	50	19D
0005433784846	8580	51	20B
0005433785003	8580	52	21C
0005432659705	8580	53	21B
0005434244921	8580	54	21E
0005433784936	8580	55	22A
0005433784720	8580	56	22B
0005433784888	8580	57	22F
0005433784845	8580	58	22E
0005433784880	8580	59	23A
0005433784796	8580	60	23D
0005434244959	8580	61	24C
0005434244831	8580	62	24F
0005433784797	8580	63	24E
0005433784977	8580	64	25A
0005433784970	8580	65	25E
0005433784747	8580	66	26B
0005435269787	8580	67	26D
0005434244920	8580	68	26C
0005434244997	8580	69	27B
0005434244914	8580	70	27C
0005433784844	8580	71	27E
0005434244850	8580	72	27F
0005435269789	8580	73	28B
0005433784920	8580	74	28C
0005433784955	8580	75	29B
0005434244888	8580	76	29A
0005433784900	8580	77	29C
0005433784935	8580	78	29E
0005433784813	8580	79	30C
0005433784916	8580	80	30F
0005433784746	8580	81	31A
0005433614351	8581	1	1A
0005433614206	8581	2	1C
0005433614543	8581	3	2D
0005433614438	8581	4	3C
0005433614601	8581	5	3F
0005433614547	8581	6	4C
0005433614500	8581	7	6A
0005433614047	8581	8	6D
0005433614447	8581	9	7A
0005433614048	8581	10	6F
0005433614300	8581	11	8A
0005433614157	8581	12	8C
0005433614604	8581	13	8E
0005433614290	8581	14	8F
0005433614430	8581	15	9B
0005433614826	8581	16	9D
0005433614230	8581	17	9E
0005433614422	8581	18	10A
0005433614507	8581	19	11B
0005433614722	8581	20	11A
0005433614753	8581	21	11D
0005433614551	8581	22	11C
0005433614481	8581	23	12B
0005433614693	8581	24	12D
0005433614694	8581	25	12E
0005433614508	8581	26	13A
0005433614643	8581	27	13D
0005433614229	8581	28	13E
0005433614602	8581	29	14C
0005433614376	8581	30	14D
0005433614329	8581	31	15D
0005433614449	8581	32	16C
0005433614364	8581	33	17A
0005433614505	8581	34	16F
0005433614448	8581	35	17C
0005433614776	8581	36	18A
0005433614377	8581	37	19D
0005433614544	8581	38	19C
0005433614512	8581	39	20A
0005433614666	8581	40	21B
0005433614405	8581	41	21D
0005433614665	8581	42	21F
0005433614667	8581	43	22A
0005433614482	8581	44	23B
0005433614581	8581	45	23C
0005433614510	8581	46	23E
0005433614754	8581	47	24B
0005433614409	8581	48	24E
0005433614164	8581	49	25A
0005433614192	8581	50	25B
0005433614365	8581	51	25D
0005433614692	8581	52	25E
0005433614156	8581	53	26A
0005433614371	8581	54	25F
0005433614723	8581	55	26E
0005433614213	8581	56	27A
0005433614151	8581	57	27C
0005433614719	8581	58	27F
0005433614408	8581	59	28D
0005433614313	8581	60	29A
0005433614437	8581	61	29C
0005433614686	8581	62	29B
0005433614537	8581	63	29D
0005433614575	8581	64	29E
0005433614931	8581	65	30A
0005433614334	8581	66	30D
0005433614568	8581	67	30F
0005433614705	8581	68	31A
0005433614548	8581	69	31F
0005435007182	8582	1	1A
0005432035151	8582	2	1C
0005433688826	8582	3	1F
0005434229267	8582	4	2A
0005434149747	8582	5	2C
0005432035150	8582	6	2D
0005434229399	8582	7	3A
0005432035144	8582	8	3D
0005432336121	8582	9	3C
0005434149715	8582	10	3F
0005433534513	8582	11	4A
0005435007187	8582	12	4C
0005433689927	8582	13	4D
0005434229400	8582	14	5A
0005435007199	8582	15	4F
0005435007186	8582	16	5C
0005434229357	8582	17	5D
0005435007194	8582	18	6A
0005434229358	8582	19	5F
0005433688824	8582	20	6C
0005432336122	8582	21	6D
0005434265173	8582	22	7A
0005434149644	8582	23	6F
0005432035156	8582	24	7D
0005434265172	8582	25	7C
0005432336118	8582	26	7F
0005434265101	8582	27	8B
0005434311235	8582	28	8A
0005434229329	8582	29	8C
0005433815422	8582	30	8E
0005432336115	8582	31	8D
0005434265231	8582	32	8F
0005432035133	8582	33	9B
0005432336117	8582	34	9A
0005434229351	8582	35	9D
0005434173522	8582	36	9C
0005432336119	8582	37	9E
0005435007198	8582	38	10A
0005435007183	8582	39	9F
0005435007201	8582	40	10B
0005435007195	8582	41	10D
0005433689925	8582	42	10C
0005434173512	8582	43	10E
0005433689926	8582	44	10F
0005434265162	8582	45	11B
0005434229313	8582	46	11A
0005432035159	8582	47	11D
0005434149674	8582	48	11E
0005435007181	8582	49	12A
0005432336123	8582	50	11F
0005434149700	8582	51	12B
0005435007197	8582	52	12C
0005434229315	8582	53	12D
0005432035158	8582	54	12F
0005434149739	8582	55	13A
0005432035138	8582	56	13C
0005434229306	8582	57	13B
0005434149741	8582	58	13D
0005432035155	8582	59	13E
0005432035143	8582	60	14A
0005432035148	8582	61	13F
0005434265143	8582	62	14D
0005434173499	8582	63	14C
0005432035153	8582	64	14E
0005432035142	8582	65	15A
0005433815421	8582	66	14F
0005432035145	8582	67	15B
0005435007185	8582	68	15D
0005435286661	8582	69	15F
0005432035136	8582	70	16A
0005434311236	8582	71	16C
0005434229271	8582	72	16B
0005434229372	8582	73	16D
0005433534514	8582	74	16E
0005434229275	8582	75	17A
0005432035141	8582	76	16F
0005434229314	8582	77	17C
0005435007188	8582	78	17B
0005435007192	8582	79	17D
0005434229266	8582	80	17F
0005434265098	8582	81	17E
0005432035140	8582	82	18A
0005434265230	8582	83	18B
0005434265030	8582	84	18C
0005434229217	8582	85	18E
0005435007200	8582	86	18D
0005434173486	8582	87	18F
0005432047578	8582	88	19C
0005433815420	8582	89	19B
0005435007178	8582	90	19D
0005434229352	8582	91	19E
0005432035160	8582	92	20B
0005432035134	8582	93	20A
0005434229334	8582	94	20C
0005434265097	8582	95	20F
0005435007193	8582	96	20E
0005432035137	8582	97	21A
0005434173523	8582	98	21C
0005435286660	8582	99	21B
0005434173487	8582	100	21D
0005435007191	8582	101	21F
0005433688825	8582	102	21E
0005432035149	8582	103	22A
0005434265157	8582	104	22B
0005433690940	8582	105	22C
0005432035135	8582	106	22E
0005432035139	8582	107	22D
0005432336116	8582	108	22F
0005434265134	8582	109	23B
0005434229353	8582	110	23A
0005432035146	8582	111	23C
0005432035154	8582	112	23D
0005434229299	8582	113	23F
0005435007196	8582	114	24A
0005434265100	8582	115	24B
0005434229365	8582	116	24C
0005432035157	8582	117	24E
0005434229337	8582	118	24F
0005434173496	8582	119	25A
0005434229398	8582	120	25B
0005434149742	8582	121	25D
0005434229392	8582	122	25C
0005435007179	8582	123	25E
0005434149728	8582	124	25F
0005435007190	8582	125	26B
0005434173517	8582	126	26A
0005433690939	8582	127	26D
0005434265140	8582	128	26C
0005433815424	8582	129	26E
0005434229338	8582	130	26F
0005432035152	8582	131	27B
0005432035147	8582	132	27C
0005434149697	8582	133	27D
0005432336120	8582	134	27F
0005434265096	8582	135	28A
0005435007180	8582	136	28B
0005434265070	8582	137	28D
0005434149729	8582	138	28C
0005432336126	8582	139	28E
0005434265176	8582	140	29A
0005432047577	8582	141	28F
0005434264968	8582	142	29B
0005434265147	8582	143	29C
0005432047576	8582	144	29D
0005434229328	8582	145	29E
0005434173497	8582	146	30A
0005435007184	8582	147	29F
0005434149746	8582	148	30B
0005434311234	8582	149	30C
0005434229430	8582	150	30E
0005432336124	8582	151	30F
0005432336125	8582	152	31A
0005435007189	8582	153	31C
0005434229270	8582	154	31B
0005434265146	8582	155	31D
0005433815423	8582	156	31E
0005434265232	8582	157	31F
0005433202467	12591	1	1B
0005434639288	12591	2	1C
0005434639131	12591	3	1D
0005434639218	12591	4	2B
0005433202469	12591	5	2D
0005433202474	12591	6	3A
0005433202471	12591	7	3B
0005433202464	12591	8	3C
0005434639308	12591	9	3D
0005434639158	12591	10	4A
0005434639307	12591	11	4C
0005433202465	12591	12	5A
0005434639248	12591	13	5B
0005433202466	12591	14	5D
0005433202472	12591	15	6B
0005433202477	12591	16	7A
0005434639232	12591	17	7C
0005433202470	12591	18	7D
0005434639289	12591	19	18D
0005434639236	12591	20	19B
0005434639246	12591	21	19C
0005434639247	12591	22	20B
0005433202468	12591	23	20C
0005434639159	12591	24	21A
0005433202478	12591	25	21B
0005434639166	12591	26	21C
0005433202473	12591	27	21D
0005433202476	12591	28	22A
0005434639132	12591	29	22B
0005434639258	12591	30	22C
0005433202475	12591	31	22D
0005434639157	12591	32	23B
0005434639495	23399	1	1A
0005433202305	23399	2	1B
0005434639481	23399	3	1C
0005433202353	23399	4	1D
0005434639487	23399	5	2A
0005433202304	23399	6	2B
0005434639493	23399	7	2C
0005433202380	23399	8	2D
0005434639497	23399	9	3A
0005432290653	23399	10	3B
0005433202388	23399	11	3D
0005433202381	23399	12	4B
0005433202363	23399	13	4C
0005433202367	23399	14	4D
0005433202396	23399	15	5A
0005434639483	23399	16	5B
0005434639496	23399	17	5C
0005433202333	23399	18	5D
0005433202314	23399	19	6A
0005432290651	23399	20	6B
0005434639479	23399	21	6C
0005433202284	23399	22	6D
0005434639478	23399	23	7A
0005434639477	23399	24	7B
0005432290652	23399	25	7C
0005433202258	23399	26	7D
0005434639482	23399	27	18A
0005434639486	23399	28	18B
0005433202362	23399	29	18D
0005434639498	23399	30	19A
0005433202339	23399	31	19B
0005433202364	23399	32	19C
0005434639494	23399	33	19D
0005434639491	23399	34	20A
0005434639485	23399	35	20B
0005434639490	23399	36	20C
0005433202397	23399	37	20D
0005433202387	23399	38	21A
0005433202382	23399	39	21B
0005434639492	23399	40	21C
0005434639488	23399	41	22A
0005433202352	23399	42	21D
0005434639480	23399	43	22B
0005433202315	23399	44	22C
0005434639489	23399	45	22D
0005434639484	23399	46	23A
0005433202379	23399	47	23B
0005432328471	21106	1	1A
0005432383069	21106	2	1C
0005432383224	21106	3	1D
0005432383103	21106	4	1F
0005432328327	21106	5	2A
0005432383213	21106	6	2C
0005432383070	21106	7	2D
0005432054327	21106	8	3A
0005432383071	21106	9	3C
0005432328505	21106	10	3D
0005432328646	21106	11	3F
0005432328470	21106	12	4C
0005432328475	21106	13	4D
0005432383128	21106	14	4E
0005432328506	21106	15	4F
0005432328494	21106	16	5A
0005432328623	21106	17	5C
0005432328826	21106	18	5D
0005432383125	21106	19	5E
0005432383102	21106	20	5F
0005432383194	21106	21	6C
0005432328806	21106	22	6D
0005432383003	21106	23	6E
0005432383180	21106	24	6F
0005432054326	21106	25	7A
0005432328733	21106	26	7E
0005432383245	21106	27	7F
0005432383059	21106	28	8A
0005432383223	21106	29	8C
0005432383034	21106	30	8D
0005432328688	21106	31	8E
0005432328592	21106	32	8F
0005432383062	21106	33	9C
0005432328754	21106	34	9A
0005432328567	21106	35	9D
0005432328752	21106	36	9E
0005432383127	21106	37	9F
0005432383104	21106	38	10A
0005432328510	21106	39	10C
0005432328690	21106	40	10D
0005432328727	21106	41	10E
0005432328820	21106	42	10F
0005432328599	21106	43	11A
0005432383186	21106	44	11C
0005432328366	21106	45	11D
0005432382928	21106	46	11E
0005432382944	21106	47	11F
0005432328605	21106	48	12A
0005432328362	21106	49	12D
0005432328827	21106	50	12E
0005432382979	21106	51	13A
0005432383105	21106	52	13C
0005432328753	21106	53	13D
0005432328595	21106	54	13E
0005432383089	21106	55	13F
0005432328598	21106	56	14A
0005432383012	21106	57	14C
0005432328643	21106	58	14D
0005432383199	21106	59	14E
0005432328626	21106	60	14F
0005432328828	21106	61	15A
0005432383077	21106	62	15C
0005432383058	21106	63	15D
0005432383110	21106	64	15E
0005432383050	21106	65	15F
0005432328645	21106	66	16C
0005432328612	21106	67	16D
0005432383159	21106	68	16F
0005432328511	21106	69	17A
0005432383057	21106	70	17E
0005432383185	21106	71	18A
0005432383130	21106	72	18C
0005432383126	21106	73	18D
0005432328542	21106	74	18E
0005432383061	21106	75	18F
0005432328449	21106	76	19C
0005432328450	21106	77	19D
0005432383222	21106	78	19F
0005432383111	21106	79	20A
0005432328650	21106	80	20D
0005432328326	21106	81	20E
0005432328676	21106	82	20F
0005432329006	31228	1	1A
0005432328976	31228	2	1C
0005432383427	31228	3	1D
0005432328999	31228	4	1F
0005432383417	31228	5	2A
0005432287224	31228	6	2C
0005432383428	31228	7	2D
0005432383434	31228	8	2F
0005432287225	31228	9	3C
0005432329017	31228	10	3D
0005432287220	31228	11	3F
0005432329010	31228	12	4A
0005432383410	31228	13	4C
0005432328995	31228	14	4D
0005432287222	31228	15	4E
0005432383418	31228	16	4F
0005432329008	31228	17	5A
0005432328994	31228	18	5C
0005432328979	31228	19	5D
0005432329009	31228	20	5E
0005432383422	31228	21	5F
0005432383402	31228	22	6A
0005432328982	31228	23	6C
0005432383414	31228	24	6D
0005432328978	31228	25	6E
0005432328991	31228	26	6F
0005432329016	31228	27	7A
0005432383424	31228	28	7C
0005432383435	31228	29	7D
0005432287219	31228	30	7E
0005432329003	31228	31	7F
0005432383406	31228	32	8A
0005432383419	31228	33	8C
0005432329004	31228	34	8D
0005432329000	31228	35	8E
0005432383412	31228	36	8F
0005432329013	31228	37	9C
0005432328972	31228	38	9A
0005432328996	31228	39	9D
0005432383437	31228	40	9E
0005432328973	31228	41	9F
0005432329012	31228	42	10A
0005432328992	31228	43	10C
0005432328986	31228	44	10D
0005432383425	31228	45	10E
0005432383441	31228	46	10F
0005432383439	31228	47	11A
0005432328971	31228	48	11C
0005432383433	31228	49	11D
0005432383440	31228	50	11E
0005432328993	31228	51	11F
0005432328997	31228	52	12A
0005432287221	31228	53	12C
0005432383436	31228	54	12D
0005432383416	31228	55	12E
0005432328984	31228	56	12F
0005432329001	31228	57	13A
0005432328988	31228	58	13C
0005432328985	31228	59	13D
0005432328975	31228	60	13E
0005432383431	31228	61	13F
0005432328981	31228	62	14A
0005432383438	31228	63	14C
0005432328974	31228	64	14D
0005432383421	31228	65	14E
0005432383413	31228	66	14F
0005432287223	31228	67	15A
0005432329007	31228	68	15C
0005432328987	31228	69	15D
0005432383409	31228	70	15E
0005432383408	31228	71	15F
0005432383426	31228	72	16A
0005432383404	31228	73	16C
0005432383430	31228	74	16D
0005432328998	31228	75	16E
0005432329014	31228	76	16F
0005432383407	31228	77	17A
0005432383411	31228	78	17C
0005432328977	31228	79	17D
0005432328989	31228	80	17E
0005432383403	31228	81	17F
0005432383432	31228	82	18A
0005432328983	31228	83	18C
0005432383429	31228	84	18D
0005432329011	31228	85	18E
0005432329015	31228	86	18F
0005432328980	31228	87	19A
0005432383423	31228	88	19C
0005432383415	31228	89	19D
0005432329005	31228	90	19E
0005432328990	31228	91	19F
0005432383442	31228	92	20A
0005432383420	31228	93	20C
0005432383405	31228	94	20D
0005432329002	31228	95	20E
0005432383443	31228	96	20F
0005432424771	13358	1	1A
0005432424743	13358	2	1C
0005432424751	13358	3	1D
0005432424766	13358	4	2A
0005432424732	13358	5	2D
0005432424750	13358	6	2F
0005432424720	13358	7	3A
0005432424759	13358	8	3D
0005432424725	13358	9	3F
0005432424772	13358	10	4C
0005432424722	13358	11	4D
0005432424769	13358	12	4E
0005432424757	13358	13	4F
0005432424738	13358	14	5A
0005432424767	13358	15	5C
0005432424770	13358	16	5F
0005432424742	13358	17	6A
0005432424768	13358	18	6F
0005432424718	13358	19	7A
0005432424749	13358	20	7E
0005432424740	13358	21	7F
0005432424731	13358	22	8A
0005432424760	13358	23	8C
0005432424726	13358	24	8E
0005432424753	13358	25	9A
0005432424746	13358	26	9C
0005432424734	13358	27	9E
0005432424752	13358	28	9F
0005432424763	13358	29	10C
0005432424739	13358	30	10D
0005432424745	13358	31	10E
0005432424748	13358	32	11C
0005432424765	13358	33	11D
0005432424716	13358	34	12F
0005432424775	13358	35	13A
0005432424774	13358	36	13C
0005432424755	13358	37	13D
0005432424758	13358	38	13E
0005432424764	13358	39	13F
0005432424747	13358	40	14A
0005432424741	13358	41	14C
0005432424754	13358	42	14E
0005432424744	13358	43	14F
0005432424728	13358	44	15A
0005432424721	13358	45	15E
0005432424719	13358	46	16C
0005432424724	13358	47	16D
0005432424762	13358	48	17A
0005432424756	13358	49	17D
0005432424723	13358	50	17F
0005432424773	13358	51	18A
0005432424717	13358	52	18C
0005432424737	13358	53	18D
0005432424727	13358	54	18E
0005432424715	13358	55	19A
0005432424730	13358	56	19D
0005432424735	13358	57	19F
0005432424729	13358	58	20A
0005432424733	13358	59	20D
0005432424736	13358	60	20E
0005432424761	13358	61	20F
0005432424330	30732	1	1C
0005432424272	30732	2	1D
0005432424350	30732	3	1F
0005432424354	30732	4	2C
0005432424240	30732	5	3F
0005432424268	30732	6	4A
0005432424291	30732	7	4C
0005432424382	30732	8	5C
0005432424352	30732	9	6C
0005432424247	30732	10	6D
0005432424151	30732	11	6F
0005432424343	30732	12	7A
0005432424297	30732	13	7F
0005432424360	30732	14	8D
0005432424351	30732	15	9E
0005432424334	30732	16	9F
0005432424243	30732	17	10A
0005432424370	30732	18	10E
0005432424227	30732	19	10F
0005432424284	30732	20	11A
0005432424150	30732	21	11C
0005432424281	30732	22	13A
0005432424383	30732	23	13D
0005432423947	30732	24	13E
0005432424384	30732	25	13F
0005432424355	30732	26	14D
0005432424367	30732	27	14E
0005432424082	30732	28	14F
0005432424083	30732	29	15A
0005432424368	30732	30	15D
0005432424369	30732	31	15E
0005432424353	30732	32	15F
0005432424371	30732	33	16A
0005432424226	30732	34	16C
0005432424326	30732	35	16D
0005432424233	30732	36	17A
0005432424234	30732	37	17E
0005432424333	30732	38	17F
0005432424339	30732	39	18E
0005432424252	30732	40	19A
0005432424327	30732	41	20C
0005432424381	30732	42	20D
0005434186184	9577	1	1A
0005432817670	9577	2	1C
0005432817696	9577	3	1D
0005434448342	9577	4	1F
0005432817675	9577	5	2A
0005434448339	9577	6	2D
0005432822262	9577	7	3A
0005432817671	9577	8	3C
0005434448338	9577	9	3D
0005434157487	9577	10	3F
0005432817679	9577	11	4A
0005434157480	9577	12	4D
0005432901550	9577	13	4E
0005432817680	9577	14	4F
0005432822261	9577	15	5A
0005434157478	9577	16	5C
0005432817678	9577	17	5D
0005432901588	9577	18	5F
0005432289010	9577	19	6C
0005434157466	9577	20	6F
0005432817681	9577	21	7C
0005432901590	9577	22	7E
0005432817691	9577	23	7F
0005432822260	9577	24	8A
0005432817676	9577	25	8C
0005432817688	9577	26	8F
0005432901619	9577	27	9A
0005432817673	9577	28	9C
0005432901620	9577	29	9D
0005432822259	9577	30	9F
0005432901589	9577	31	10A
0005432822255	9577	32	10C
0005432817672	9577	33	10D
0005432817689	9577	34	10E
0005432822263	9577	35	10F
0005432817683	9577	36	11A
0005434448341	9577	37	12A
0005432822254	9577	38	12C
0005432817686	9577	39	12E
0005432817674	9577	40	12F
0005434157467	9577	41	13A
0005432901542	9577	42	13C
0005432901596	9577	43	13D
0005432817697	9577	44	13E
0005432822257	9577	45	13F
0005432901518	9577	46	14A
0005434186190	9577	47	14C
0005432901580	9577	48	14E
0005432817687	9577	49	14F
0005432901587	9577	50	15A
0005432817693	9577	51	15D
0005432817692	9577	52	15E
0005434186189	9577	53	15F
0005432817669	9577	54	16A
0005432817684	9577	55	16C
0005434186183	9577	56	16D
0005432817682	9577	57	16F
0005434186191	9577	58	17A
0005432817685	9577	59	17C
0005432822256	9577	60	17E
0005432901579	9577	61	17F
0005432822258	9577	62	18A
0005434157468	9577	63	18D
0005432901591	9577	64	18E
0005432817677	9577	65	18F
0005432817695	9577	66	19A
0005434157465	9577	67	19D
0005432901630	9577	68	19E
0005434157432	9577	69	19F
0005432289009	9577	70	20A
0005434157488	9577	71	20C
0005432817694	9577	72	20D
0005432817690	9577	73	20E
0005434448340	9577	74	20F
0005434157538	28958	1	1A
0005432817392	28958	2	1D
0005432901741	28958	3	1F
0005432901739	28958	4	2A
0005432822213	28958	5	2C
0005432817399	28958	6	2D
0005432817328	28958	7	2F
0005432822214	28958	8	3A
0005432817367	28958	9	3C
0005434157535	28958	10	3D
0005432817470	28958	11	4C
0005432822202	28958	12	4D
0005432817455	28958	13	4E
0005432817458	28958	14	4F
0005432817389	28958	15	5A
0005432817398	28958	16	5C
0005434157533	28958	17	5D
0005432901727	28958	18	5E
0005432817513	28958	19	5F
0005432817488	28958	20	6A
0005434157534	28958	21	6C
0005434186216	28958	22	6D
0005432817414	28958	23	6E
0005432901729	28958	24	6F
0005434186218	28958	25	7A
0005432002091	28958	26	7C
0005432901734	28958	27	7D
0005432901740	28958	28	7E
0005432817463	28958	29	7F
0005432901725	28958	30	8C
0005432817405	28958	31	8D
0005432901737	28958	32	8E
0005432901728	28958	33	8F
0005432822173	28958	34	9A
0005434157537	28958	35	9C
0005432817427	28958	36	9D
0005432817442	28958	37	9E
0005432817441	28958	38	9F
0005432817393	28958	39	10A
0005434448298	28958	40	10C
0005432901731	28958	41	10D
0005434157536	28958	42	10E
0005432817370	28958	43	10F
0005432817468	28958	44	11A
0005432901742	28958	45	11C
0005432901730	28958	46	11D
0005432817352	28958	47	11E
0005432901736	28958	48	11F
0005432822161	28958	49	12C
0005432901732	28958	50	12D
0005432817443	28958	51	12E
0005432817364	28958	52	12F
0005432822203	28958	53	13A
0005432901738	28958	54	13C
0005432901726	28958	55	13D
0005432817485	28958	56	13E
0005432822160	28958	57	13F
0005432817486	28958	58	14A
0005432817331	28958	59	14C
0005434448299	28958	60	14D
0005432817436	28958	61	14E
0005432817415	28958	62	14F
0005432817487	28958	63	15A
0005432822219	28958	64	15C
0005432817358	28958	65	15D
0005434186217	28958	66	15E
0005432817548	28958	67	15F
0005432817502	28958	68	16A
0005432817390	28958	69	16D
0005434448297	28958	70	16E
0005432817471	28958	71	16F
0005432817482	28958	72	17A
0005432002090	28958	73	17C
0005432817469	28958	74	17D
0005432817484	28958	75	17F
0005434157532	28958	76	18A
0005432817421	28958	77	18C
0005432901735	28958	78	18D
0005432817391	28958	79	18E
0005432817479	28958	80	18F
0005432817549	28958	81	19A
0005432817481	28958	82	19C
0005432817416	28958	83	19D
0005432817453	28958	84	19E
0005432817450	28958	85	19F
0005432901733	28958	86	20A
0005432817509	28958	87	20D
0005432817404	28958	88	20E
0005432817435	28958	89	20F
0005432611740	15147	1	1A
0005432613892	15147	2	1B
0005432613893	15147	3	2A
0005432613891	15147	4	3A
0005432611738	15147	5	2B
0005435841822	15147	6	4A
0005432613890	15147	7	4B
0005432611739	15147	8	5B
0005432611741	15147	9	6B
0005432611699	31601	1	1A
0005432611700	31601	2	1B
0005432611712	31601	3	2A
0005432611724	31601	4	2B
0005432607540	31601	5	3A
0005435841826	31601	6	3B
0005432611705	31601	7	4A
0005432611703	31601	8	4B
0005432607543	31601	9	5B
0005432611725	31601	10	6A
0005432611704	31601	11	6B
0005433569449	11891	1	1C
0005432948331	11891	2	1A
0005433569446	11891	3	1D
0005432948487	11891	4	2C
0005432948324	11891	5	2A
0005432948399	11891	6	1F
0005433569459	11891	7	2D
0005432948439	11891	8	3A
0005433569457	11891	9	2F
0005433569469	11891	10	3D
0005432948377	11891	11	3F
0005432948252	11891	12	4D
0005432948189	11891	13	4C
0005433569468	11891	14	4A
0005433569465	11891	15	4F
0005432948486	11891	16	5A
0005433569442	11891	17	5F
0005433569448	11891	18	5D
0005433569456	11891	19	6B
0005433569434	11891	20	6A
0005432948201	11891	21	6D
0005433569441	11891	22	6C
0005432948257	11891	23	6F
0005433569445	11891	24	6E
0005433569447	11891	25	7A
0005432948488	11891	26	7C
0005433569467	11891	27	7B
0005432948421	11891	28	7E
0005432948460	11891	29	7D
0005433569444	11891	30	7F
0005432948361	11891	31	8B
0005432948517	11891	32	8D
0005433569436	11891	33	8F
0005432948199	11891	34	9A
0005433569439	11891	35	9D
0005432948295	11891	36	9C
0005433569440	11891	37	9B
0005433569433	11891	38	9E
0005432948239	11891	39	10A
0005433569461	11891	40	9F
0005433569450	11891	41	10B
0005433569454	11891	42	10E
0005432948433	11891	43	10D
0005433569437	11891	44	10F
0005432948325	11891	45	11C
0005432948398	11891	46	11B
0005432948403	11891	47	11D
0005433569432	11891	48	11F
0005432948438	11891	49	12B
0005433569460	11891	50	12A
0005432948276	11891	51	12D
0005433569435	11891	52	12C
0005432948200	11891	53	12E
0005432948386	11891	54	13D
0005432948303	11891	55	13C
0005432948305	11891	56	13B
0005432948354	11891	57	13E
0005432948320	11891	58	14A
0005432948387	11891	59	13F
0005432948307	11891	60	14B
0005432948388	11891	61	14E
0005432948319	11891	62	15B
0005433569452	11891	63	15A
0005432948404	11891	64	15C
0005432948328	11891	65	15E
0005433569428	11891	66	15D
0005433569463	11891	67	16B
0005433569443	11891	68	16A
0005433569455	11891	69	15F
0005432948440	11891	70	16C
0005432948215	11891	71	16E
0005433569431	11891	72	16D
0005432948287	11891	73	16F
0005432948380	11891	74	17B
0005432948304	11891	75	17D
0005433569458	11891	76	17F
0005432948278	11891	77	17E
0005432948327	11891	78	18A
0005433569470	11891	79	18C
0005432948302	11891	80	18B
0005432948214	11891	81	18D
0005432948323	11891	82	19A
0005432948332	11891	83	18F
0005433569438	11891	84	19C
0005432948469	11891	85	19B
0005433569471	11891	86	19D
0005432948258	11891	87	20A
0005433569429	11891	88	19F
0005433569453	11891	89	19E
0005433569451	11891	90	20B
0005432948362	11891	91	20C
0005433569464	11891	92	20F
0005433569466	11891	93	20E
0005432948333	11891	94	20D
0005432948479	11891	95	21B
0005432948277	11891	96	21A
0005433569430	11891	97	21F
0005432948251	11891	98	21E
0005433569462	11891	99	21D
0005433569082	25316	1	1A
0005433569199	25316	2	1F
0005433568912	25316	3	1C
0005433568902	25316	4	2A
0005432948789	25316	5	2F
0005433569200	25316	6	2C
0005433568973	25316	7	3A
0005433569000	25316	8	3D
0005432948775	25316	9	3C
0005432948782	25316	10	4A
0005432948778	25316	11	3F
0005433568858	25316	12	4C
0005432948785	25316	13	4F
0005433568966	25316	14	4D
0005433568859	25316	15	5C
0005433568969	25316	16	5F
0005433568980	25316	17	6A
0005432948804	25316	18	6C
0005433568956	25316	19	6B
0005432948766	25316	20	6E
0005433568970	25316	21	6D
0005432948788	25316	22	7A
0005432948767	25316	23	7C
0005433568901	25316	24	7E
0005433568709	25316	25	7D
0005432948787	25316	26	7F
0005433568925	25316	27	8B
0005433569094	25316	28	8C
0005433569016	25316	29	8F
0005433568885	25316	30	8E
0005433568892	25316	31	9B
0005432948799	25316	32	9A
0005433568810	25316	33	9C
0005433569017	25316	34	9E
0005433569114	25316	35	9D
0005433569041	25316	36	10A
0005432948773	25316	37	9F
0005433569155	25316	38	10B
0005433569009	25316	39	10E
0005433569113	25316	40	11A
0005433569092	25316	41	10F
0005433568884	25316	42	11B
0005432948790	25316	43	11D
0005433569081	25316	44	11C
0005433568641	25316	45	11F
0005432948793	25316	46	11E
0005433569093	25316	47	12A
0005432948779	25316	48	12D
0005433568949	25316	49	12C
0005433568708	25316	50	12B
0005432948798	25316	51	12F
0005433569106	25316	52	12E
0005433568812	25316	53	13A
0005433568948	25316	54	13C
0005432948768	25316	55	13B
0005433569010	25316	56	13E
0005432948770	25316	57	13D
0005432948791	25316	58	14A
0005432948783	25316	59	13F
0005433569056	25316	60	14B
0005433569067	25316	61	14D
0005432948772	25316	62	14C
0005433569112	25316	63	14F
0005433568698	25316	64	14E
0005433568877	25316	65	15B
0005433568841	25316	66	15A
0005433569105	25316	67	15D
0005433568854	25316	68	15C
0005432948774	25316	69	15F
0005432948802	25316	70	15E
0005433568934	25316	71	16A
0005433568878	25316	72	16C
0005432948784	25316	73	16E
0005433568868	25316	74	16D
0005432948795	25316	75	16F
0005433568879	25316	76	17B
0005432948777	25316	77	17A
0005432948800	25316	78	17C
0005432948801	25316	79	17F
0005433569055	25316	80	17E
0005432948803	25316	81	18B
0005433569024	25316	82	18A
0005433569335	25316	83	18D
0005433568891	25316	84	18C
0005432948796	25316	85	18E
0005433568738	25316	86	19A
0005432948781	25316	87	18F
0005432948805	25316	88	19C
0005432948786	25316	89	19B
0005432948794	25316	90	19D
0005433569001	25316	91	19F
0005433568957	25316	92	19E
0005433568979	25316	93	20B
0005432948769	25316	94	20A
0005433569042	25316	95	20C
0005432948771	25316	96	20F
0005432948792	25316	97	20E
0005432948776	25316	98	21B
0005432948797	25316	99	21A
0005433568890	25316	100	21D
0005433568847	25316	101	21C
0005432948780	25316	102	21E
0005433568480	25316	103	21F
0005433812911	30831	1	1D
0005433808402	30831	2	2D
0005434026700	30831	3	2C
0005433808398	30831	4	3D
0005432430853	30831	5	4D
0005433812912	30831	6	5C
0005432430856	30831	7	6D
0005433812915	30831	8	7A
0005433808401	30831	9	7F
0005433808400	30831	10	8B
0005432430848	30831	11	9B
0005433812914	30831	12	10A
0005432430844	30831	13	10D
0005432430852	30831	14	10F
0005434026691	30831	15	11B
0005433808403	30831	16	11C
0005432430845	30831	17	11E
0005432430831	30831	18	12D
0005433808396	30831	19	13A
0005432430841	30831	20	13E
0005434026697	30831	21	14A
0005433812910	30831	22	14B
0005433808399	30831	23	14C
0005432430870	30831	24	15E
0005434026695	30831	25	16B
0005434026690	30831	26	17A
0005434026694	30831	27	17E
0005432430857	30831	28	18B
0005433808393	30831	29	17F
0005434026692	30831	30	18D
0005433808397	30831	31	19A
0005433812913	30831	32	19C
0005433808394	30831	33	19E
0005434026693	30831	34	19D
0005433808404	30831	35	21C
0005433808395	30831	36	21B
0005434654891	5409	1	1A
0005434654903	5409	2	1D
0005435555362	5409	3	1F
0005434654885	5409	4	2A
0005432114225	5409	5	2D
0005435340230	5409	6	2F
0005435340182	5409	7	3C
0005434654887	5409	8	3F
0005435340228	5409	9	4F
0005434654905	5409	10	5A
0005434654889	5409	11	5C
0005434654892	5409	12	5D
0005434654880	5409	13	5E
0005434654900	5409	14	5F
0005434654899	5409	15	6A
0005435340240	5409	16	6C
0005435555367	5409	17	7A
0005434654881	5409	18	8A
0005435340263	5409	19	8F
0005434654878	5409	20	9A
0005432114227	5409	21	9E
0005434654883	5409	22	9F
0005435340249	5409	23	10A
0005435340188	5409	24	10D
0005434654898	5409	25	10F
0005434654884	5409	26	11A
0005434654890	5409	27	11C
0005435340290	5409	28	12C
0005434654897	5409	29	12D
0005434654882	5409	30	12F
0005434654893	5409	31	13C
0005435340206	5409	32	13E
0005434654879	5409	33	13F
0005434654901	5409	34	14A
0005435340225	5409	35	15A
0005434654888	5409	36	15C
0005432114226	5409	37	15E
0005435340241	5409	38	16C
0005434654904	5409	39	16D
0005435340289	5409	40	17A
0005434654895	5409	41	17C
0005434654906	5409	42	18A
0005434654896	5409	43	18C
0005435340248	5409	44	19C
0005434654894	5409	45	19F
0005434654902	5409	46	20A
0005434654886	5409	47	20D
0005435340229	5409	48	20E
0005434656571	5409	49	20F
0005435340364	12544	1	1A
0005435340366	12544	2	1D
0005434654709	12544	3	2F
0005435340372	12544	4	3C
0005434654651	12544	5	3F
0005434654535	12544	6	4C
0005435340375	12544	7	5F
0005435340373	12544	8	6C
0005434656559	12544	9	6D
0005434654644	12544	10	7A
0005435555385	12544	11	7C
0005435340368	12544	12	7D
0005434654652	12544	13	7E
0005435340376	12544	14	7F
0005435555386	12544	15	8A
0005434654711	12544	16	8C
0005434654657	12544	17	8D
0005435340367	12544	18	9A
0005434654633	12544	19	9D
0005434654712	12544	20	10A
0005434654586	12544	21	10E
0005435340378	12544	22	10F
0005434656551	12544	23	11A
0005434654596	12544	24	11C
0005435340365	12544	25	11E
0005434654504	12544	26	12D
0005434656550	12544	27	13A
0005434654698	12544	28	13C
0005435340371	12544	29	13D
0005434654653	12544	30	13F
0005435340363	12544	31	14C
0005435340377	12544	32	14E
0005434654597	12544	33	15D
0005434654570	12544	34	15E
0005434654658	12544	35	16D
0005434654536	12544	36	16E
0005435340374	12544	37	16F
0005434654585	12544	38	17A
0005434654641	12544	39	17D
0005435340369	12544	40	17E
0005435555387	12544	41	18A
0005434654503	12544	42	18C
0005434654631	12544	43	18E
0005434654571	12544	44	19A
0005434654720	12544	45	19C
0005434654632	12544	46	19D
0005435340370	12544	47	19F
0005434654675	12544	48	20D
0005434654665	12544	49	20F
0005432078147	7435	1	1A
0005433689923	7435	2	1D
0005433716300	7435	3	1F
0005432428913	7435	4	2D
0005433716325	7435	5	3D
0005433716328	7435	6	3C
0005432428892	7435	7	3F
0005433716344	7435	8	4C
0005433716303	7435	9	4B
0005433690937	7435	10	4F
0005433716302	7435	11	5B
0005433716333	7435	12	5C
0005432078146	7435	13	5D
0005433716332	7435	14	5E
0005433716311	7435	15	6A
0005433716334	7435	16	5F
0005433716298	7435	17	6B
0005433716312	7435	18	6C
0005433716323	7435	19	6E
0005433716304	7435	20	7A
0005433688823	7435	21	6F
0005433716310	7435	22	7C
0005432428893	7435	23	7E
0005433716305	7435	24	8A
0005433716340	7435	25	8C
0005433719163	7435	26	8D
0005433716299	7435	27	8F
0005433690938	7435	28	8E
0005433656692	7435	29	9A
0005433716338	7435	30	9B
0005433716313	7435	31	10B
0005433716320	7435	32	11A
0005433716330	7435	33	11C
0005433716321	7435	34	11D
0005432078149	7435	35	11F
0005433689924	7435	36	12B
0005433716329	7435	37	12A
0005433719161	7435	38	12C
0005433716314	7435	39	12E
0005433716295	7435	40	12F
0005432078148	7435	41	13B
0005433688821	7435	42	13A
0005433716307	7435	43	13C
0005435266137	7435	44	13E
0005432078150	7435	45	14B
0005433716306	7435	46	14A
0005433716336	7435	47	14D
0005433719162	7435	48	15C
0005433688822	7435	49	15B
0005433716339	7435	50	15D
0005433716337	7435	51	15F
0005433716315	7435	52	15E
0005433716327	7435	53	16B
0005433716301	7435	54	16C
0005433722271	7435	55	16D
0005433656691	7435	56	17A
0005433716341	7435	57	17F
0005433716297	7435	58	18D
0005433716331	7435	59	18C
0005433716317	7435	60	18E
0005433716322	7435	61	19F
0005433716319	7435	62	20B
0005433716326	7435	63	20F
0005433716324	7435	64	21A
0005433716335	7435	65	21D
0005433716316	7435	66	21E
0005433656693	7435	67	21F
0005433716308	7435	68	22A
0005433716318	7435	69	22C
0005433716342	7435	70	22B
0005433722270	7435	71	22D
0005433716343	7435	72	22E
0005435266138	7435	73	23A
0005433716296	7435	74	23B
0005433716309	7435	75	23D
0005433715663	29249	1	1C
0005433715891	29249	2	1D
0005433715919	29249	3	2F
0005433715870	29249	4	3A
0005433715913	29249	5	3D
0005433715813	29249	6	4A
0005435266178	29249	7	4D
0005433715817	29249	8	4F
0005433715905	29249	9	5A
0005432006782	29249	10	5B
0005433715860	29249	11	6B
0005435266176	29249	12	6D
0005433722192	29249	13	7A
0005433715707	29249	14	6F
0005433715837	29249	15	7B
0005433715866	29249	16	7C
0005433715937	29249	17	7D
0005432428954	29249	18	7F
0005433715906	29249	19	7E
0005435266177	29249	20	8A
0005433715930	29249	21	8B
0005433715662	29249	22	8C
0005433715914	29249	23	8D
0005433685515	29249	24	9C
0005433719145	29249	25	9B
0005433715755	29249	26	9D
0005432428953	29249	27	9F
0005432006780	29249	28	10C
0005433719129	29249	29	10B
0005433715873	29249	30	10D
0005433716081	29249	31	11A
0005433715753	29249	32	10E
0005433715754	29249	33	11B
0005433716084	29249	34	11D
0005435266173	29249	35	11E
0005433716082	29249	36	12A
0005433715823	29249	37	12D
0005433715979	29249	38	12C
0005433715907	29249	39	12E
0005433715876	29249	40	13A
0005433715969	29249	41	13B
0005433715892	29249	42	13D
0005433715897	29249	43	14A
0005433685516	29249	44	13F
0005433715706	29249	45	14B
0005433715965	29249	46	14E
0005433716026	29249	47	15A
0005433715883	29249	48	14F
0005433685514	29249	49	15B
0005432006781	29249	50	15D
0005435266175	29249	51	15F
0005433715920	29249	52	15E
0005432428952	29249	53	16D
0005433715671	29249	54	16F
0005433656675	29249	55	17A
0005433716025	29249	56	17B
0005433722187	29249	57	17C
0005433715948	29249	58	18A
0005435266174	29249	59	18B
0005433715960	29249	60	18C
0005433715981	29249	61	18E
0005433656670	29249	62	18D
0005433656676	29249	63	18F
0005433715850	29249	64	19A
0005433715951	29249	65	19E
0005433715756	29249	66	19D
0005433715886	29249	67	20A
0005433715964	29249	68	21D
0005433716085	29249	69	21C
0005435266179	29249	70	21E
0005433722193	29249	71	22A
0005433685513	29249	72	22C
0005433715664	29249	73	22D
0005433715980	29249	74	23A
0005433715929	29249	75	23B
0005433715867	29249	76	23C
0005433685512	29249	77	23D
0005433715896	29249	78	23F
0005433715838	29249	79	23E
0005434182145	8665	1	1A
0005434095371	8665	2	2C
0005434095372	8665	3	2F
0005434182207	8665	4	4F
0005434095385	8665	5	5A
0005434095384	8665	6	5F
0005434095374	8665	7	6C
0005434095376	8665	8	6D
0005434184668	8665	9	7C
0005434182220	8665	10	7D
0005434095381	8665	11	7E
0005434095378	8665	12	7F
0005434095379	8665	13	8C
0005434095380	8665	14	8D
0005434095382	8665	15	8F
0005434095377	8665	16	9D
0005434182162	8665	17	9E
0005434182129	8665	18	9F
0005434182215	8665	19	10C
0005434182182	8665	20	10F
0005434182200	8665	21	11A
0005434182128	8665	22	12C
0005434095375	8665	23	13C
0005434182122	8665	24	15C
0005434182166	8665	25	15D
0005434095383	8665	26	16A
0005434182163	8665	27	16C
0005434095386	8665	28	17A
0005434184659	8665	29	17E
0005434095373	8665	30	18A
0005434182221	8665	31	19C
0005434182214	8665	32	19F
0005434182190	8665	33	20D
0005434182183	8665	34	20E
0005434095262	11634	1	1C
0005434182266	11634	2	3A
0005434095252	11634	3	4A
0005434095234	11634	4	4D
0005434095308	11634	5	5F
0005434095241	11634	6	6A
0005434095299	11634	7	6D
0005434183591	11634	8	6E
0005434095200	11634	9	8A
0005434095253	11634	10	8C
0005434183592	11634	11	8E
0005434182274	11634	12	8F
0005434182267	11634	13	9D
0005434095231	11634	14	9E
0005434182270	11634	15	11A
0005434182271	11634	16	12A
0005434182278	11634	17	12C
0005434095235	11634	18	12D
0005434095298	11634	19	12E
0005434182268	11634	20	12F
0005434095229	11634	21	13C
0005434095260	11634	22	13E
0005434182269	11634	23	14D
0005434095216	11634	24	14E
0005434182273	11634	25	15A
0005434095309	11634	26	15D
0005434095295	11634	27	15E
0005434095230	11634	28	15F
0005434182277	11634	29	16C
0005434095274	11634	30	16D
0005434095264	11634	31	17C
0005434095215	11634	32	17D
0005434143722	11634	33	17F
0005434182275	11634	34	18A
0005434184678	11634	35	19A
0005434182276	11634	36	19C
0005434095240	11634	37	19F
0005434184677	11634	38	20A
0005434182272	11634	39	20F
0005435732395	1414	1	1A
0005433397887	1414	2	1D
0005433397836	1414	3	1F
0005432297297	1414	4	2A
0005435732408	1414	5	2D
0005435732410	1414	6	2F
0005432297298	1414	7	3A
0005435732412	1414	8	3C
0005435732418	1414	9	3D
0005435732419	1414	10	4A
0005433456997	1414	11	4C
0005435732407	1414	12	4F
0005435732415	1414	13	5A
0005433397933	1414	14	5F
0005435732399	1414	15	6F
0005433397855	1414	16	7A
0005435732414	1414	17	7C
0005433397809	1414	18	7D
0005432297295	1414	19	7E
0005433397886	1414	20	8A
0005433397831	1414	21	8C
0005435732403	1414	22	8D
0005433397908	1414	23	8F
0005435732416	1414	24	9A
0005433397989	1414	25	9E
0005435732413	1414	26	9F
0005433398037	1414	27	10D
0005435732405	1414	28	11A
0005435732396	1414	29	11D
0005433398024	1414	30	11F
0005433397917	1414	31	12A
0005432297296	1414	32	12D
0005433397987	1414	33	12E
0005435732400	1414	34	12F
0005433398144	1414	35	13A
0005433397930	1414	36	13C
0005433397856	1414	37	13E
0005435732404	1414	38	14A
0005435732417	1414	39	14E
0005433456999	1414	40	14F
0005433397952	1414	41	15C
0005433397946	1414	42	15D
0005433456998	1414	43	16A
0005435732411	1414	44	15F
0005433397990	1414	45	16E
0005433398034	1414	46	17D
0005435732409	1414	47	17E
0005433398028	1414	48	17F
0005433398029	1414	49	18A
0005433398044	1414	50	18C
0005433397891	1414	51	18E
0005432906526	1414	52	18F
0005435732397	1414	53	19A
0005435732401	1414	54	19F
0005432906527	1414	55	20A
0005435732406	1414	56	20D
0005435732398	1414	57	20E
0005435732402	1414	58	20F
0005433398404	19261	1	1A
0005433398402	19261	2	1C
0005433456960	19261	3	1D
0005433398413	19261	4	1F
0005433398403	19261	5	2A
0005433398412	19261	6	2C
0005433398378	19261	7	2F
0005433398390	19261	8	3A
0005433398376	19261	9	3C
0005433456952	19261	10	3F
0005433398384	19261	11	4A
0005432906553	19261	12	4C
0005433398397	19261	13	4D
0005433398406	19261	14	5A
0005433456964	19261	15	5D
0005433398375	19261	16	5E
0005433398415	19261	17	5F
0005433398385	19261	18	6A
0005433398399	19261	19	6E
0005433398410	19261	20	7A
0005435732290	19261	21	7D
0005433398416	19261	22	7E
0005432906554	19261	23	7F
0005433398379	19261	24	8C
0005433398420	19261	25	8D
0005433398388	19261	26	8F
0005433456965	19261	27	9A
0005433398389	19261	28	9C
0005433398377	19261	29	9D
0005433398414	19261	30	9E
0005433456961	19261	31	9F
0005433456962	19261	32	10A
0005432906552	19261	33	10D
0005433398418	19261	34	10F
0005433456968	19261	35	11C
0005435732324	19261	36	11D
0005435732362	19261	37	11E
0005433398408	19261	38	12C
0005433398395	19261	39	12D
0005435732361	19261	40	12E
0005435732304	19261	41	13C
0005433398391	19261	42	13D
0005433398380	19261	43	13F
0005433398417	19261	44	14A
0005433398396	19261	45	14C
0005433398398	19261	46	14D
0005435732359	19261	47	14E
0005433456963	19261	48	14F
0005433398419	19261	49	15A
0005433398407	19261	50	15D
0005433398393	19261	51	15E
0005433398405	19261	52	16C
0005433398409	19261	53	16E
0005433398373	19261	54	16F
0005433398383	19261	55	17A
0005433398386	19261	56	17C
0005433398382	19261	57	17D
0005433456937	19261	58	17E
0005435732323	19261	59	17F
0005435732303	19261	60	18C
0005433398374	19261	61	18D
0005433398401	19261	62	18F
0005433398392	19261	63	19A
0005433398394	19261	64	19C
0005433398381	19261	65	19D
0005433456967	19261	66	19E
0005433398400	19261	67	19F
0005433456966	19261	68	20A
0005433398387	19261	69	20D
0005433398411	19261	70	20E
0005434443648	17348	1	2C
0005434443669	17348	2	5B
0005434443657	17348	3	18C
0005434443649	17348	4	19A
0005434443750	17348	5	19C
0005434443607	17348	6	19D
0005434443658	17348	7	20C
0005434443665	17348	8	21A
0005434443702	17348	9	21B
0005434443687	17348	10	21C
0005434443666	17348	11	22D
0005434443659	17348	12	23A
0005434443819	20593	1	1D
0005434443816	20593	2	2B
0005434443807	20593	3	2D
0005434443817	20593	4	3A
0005434443805	20593	5	4C
0005434443808	20593	6	4D
0005434443811	20593	7	5D
0005434443810	20593	8	6B
0005434443813	20593	9	6D
0005434443815	20593	10	7A
0005434443818	20593	11	7D
0005434443812	20593	12	19B
0005434443814	20593	13	20A
0005434443806	20593	14	20B
0005434443809	20593	15	21C
0005435377583	7253	1	1B
0005434954634	7253	2	2B
0005434954635	7253	3	3B
0005434954637	7253	4	5A
0005434954636	7253	5	6B
0005435377582	7253	6	6A
0005435377596	28314	1	1A
0005435377597	28314	2	3B
0005435893626	4492	1	1B
0005434351787	4492	2	2A
0005435893637	4492	3	2B
0005434351784	4492	4	2D
0005435893635	4492	5	2C
0005435893661	4492	6	3B
0005434351782	4492	7	3C
0005435893625	4492	8	4A
0005435893648	4492	9	4C
0005434183574	4492	10	4D
0005434351788	4492	11	5B
0005435893617	4492	12	5D
0005434183576	4492	13	6A
0005434351778	4492	14	6C
0005434351790	4492	15	6D
0005434183575	4492	16	7A
0005434351786	4492	17	7B
0005435893634	4492	18	7C
0005434351781	4492	19	18A
0005434351785	4492	20	18C
0005434351783	4492	21	18D
0005434351791	4492	22	19A
0005434351779	4492	23	20A
0005435893638	4492	24	20C
0005434351789	4492	25	21B
0005434351780	4492	26	21D
0005435893633	4492	27	22C
0005435893652	4492	28	22D
0005435893616	4492	29	23A
0005435893653	4492	30	23B
0005435893680	29671	1	1D
0005434351734	29671	2	2A
0005434351668	29671	3	2C
0005434351732	29671	4	3C
0005435893682	29671	5	3D
0005434351690	29671	6	4A
0005434351682	29671	7	4B
0005435893683	29671	8	5A
0005435893679	29671	9	5C
0005434351733	29671	10	6B
0005435893684	29671	11	6D
0005434351689	29671	12	7D
0005435893681	29671	13	19A
0005435893685	29671	14	19B
0005434351688	29671	15	20C
0005435893678	29671	16	21A
0005434351681	29671	17	22B
0005432293225	1063	1	1A
0005433343079	1063	2	1F
0005433158119	1063	3	2A
0005433343246	1063	4	1H
0005433342778	1063	5	2C
0005433342821	1063	6	2B
0005433342404	1063	7	2H
0005433343054	1063	8	2G
0005433342937	1063	9	3A
0005433342743	1063	10	3B
0005433343000	1063	11	3F
0005433342633	1063	12	3C
0005433342782	1063	13	3G
0005433342603	1063	14	3H
0005435092146	1063	15	4A
0005433342715	1063	16	4C
0005433343206	1063	17	4G
0005433463916	1063	18	4F
0005433342920	1063	19	4H
0005433159312	1063	20	5C
0005433159313	1063	21	5G
0005433342720	1063	22	5F
0005432293226	1063	23	5H
0005433343085	1063	24	9A
0005433342163	1063	25	9G
0005433342388	1063	26	11A
0005433342756	1063	27	9H
0005433343226	1063	28	11B
0005433342632	1063	29	11D
0005433342876	1063	30	11F
0005433343257	1063	31	11G
0005433342529	1063	32	12A
0005433342856	1063	33	11H
0005433342985	1063	34	12E
0005433343098	1063	35	12G
0005433342833	1063	36	12F
0005433342641	1063	37	12H
0005433343058	1063	38	13A
0005433342716	1063	39	13D
0005433159309	1063	40	13E
0005433342528	1063	41	14A
0005433343071	1063	42	13H
0005433343207	1063	43	14B
0005433342835	1063	44	14D
0005433342927	1063	45	14E
0005434445260	1063	46	14G
0005433343057	1063	47	15A
0005435092143	1063	48	14H
0005433343191	1063	49	15D
0005433342224	1063	50	15E
0005433342777	1063	51	15G
0005433342696	1063	52	16A
0005433342162	1063	53	15H
0005433342677	1063	54	16D
0005433343258	1063	55	16F
0005433343096	1063	56	16H
0005433343308	1063	57	16G
0005433342799	1063	58	17A
0005433342970	1063	59	17D
0005433343063	1063	60	17B
0005433342706	1063	61	17F
0005433343309	1063	62	17H
0005433269704	1063	63	17G
0005433342673	1063	64	18B
0005433462762	1063	65	18A
0005435092147	1063	66	18G
0005433342668	1063	67	18F
0005433342721	1063	68	19A
0005433343074	1063	69	18H
0005435092144	1063	70	19B
0005433342766	1063	71	19E
0005433342807	1063	72	19D
0005433342767	1063	73	19F
0005433343140	1063	74	19G
0005433342164	1063	75	20E
0005433343078	1063	76	20H
0005433342583	1063	77	20G
0005433342986	1063	78	21B
0005433342682	1063	79	21A
0005433342831	1063	80	21H
0005433342602	1063	81	22B
0005433343038	1063	82	22E
0005435092140	1063	83	22H
0005432293227	1063	84	23D
0005433343303	1063	85	23F
0005433342755	1063	86	23E
0005433343183	1063	87	23G
0005433342983	1063	88	23H
0005433342678	1063	89	24B
0005433342959	1063	90	24A
0005433269696	1063	91	24E
0005433343256	1063	92	24G
0005433342877	1063	93	25D
0005433342771	1063	94	24H
0005433343141	1063	95	25E
0005433342946	1063	96	27A
0005433463915	1063	97	25F
0005433342995	1063	98	27B
0005433343097	1063	99	27E
0005433343208	1063	100	27D
0005433342559	1063	101	27F
0005433343299	1063	102	27G
0005433342217	1063	103	28A
0005433159308	1063	104	27H
0005433342872	1063	105	28B
0005433342680	1063	106	28E
0005433342841	1063	107	28D
0005433159306	1063	108	28H
0005433342918	1063	109	28G
0005433343030	1063	110	29B
0005433269698	1063	111	29A
0005433343072	1063	112	29D
0005433343075	1063	113	29F
0005433342577	1063	114	29H
0005433343061	1063	115	29G
0005433342700	1063	116	30B
0005433342919	1063	117	30A
0005433342727	1063	118	30D
0005433343298	1063	119	30F
0005435092145	1063	120	30H
0005433343158	1063	121	31D
0005433269705	1063	122	31F
0005433343099	1063	123	31G
0005433343064	1063	124	32A
0005433342783	1063	125	31H
0005433342768	1063	126	32E
0005433343115	1063	127	32D
0005433343190	1063	128	33B
0005433342969	1063	129	33A
0005433343247	1063	130	32H
0005433342960	1063	131	33D
0005433269699	1063	132	33G
0005433342683	1063	133	33F
0005433342761	1063	134	33H
0005433343062	1063	135	34A
0005433342634	1063	136	34F
0005433343128	1063	137	34E
0005433342895	1063	138	34H
0005435092141	1063	139	35B
0005433342757	1063	140	35A
0005435092142	1063	141	35E
0005433342371	1063	142	36D
0005433343286	1063	143	36B
0005433269695	1063	144	36F
0005433342812	1063	145	36G
0005433343116	1063	146	37D
0005433342984	1063	147	37F
0005435092148	1063	148	37H
0005433342896	1063	149	37G
0005433343152	1063	150	38F
0005433343124	1063	151	38E
0005433342772	1063	152	38D
0005433342820	1063	153	38G
0005433342834	1063	154	38H
0005433342744	1063	155	39E
0005433462761	1063	156	39D
0005433343772	17027	1	1A
0005435092117	17027	2	1C
0005433343786	17027	3	1B
0005433159328	17027	4	1F
0005433343737	17027	5	2A
0005433343791	17027	6	1H
0005433343771	17027	7	2B
0005433343757	17027	8	2F
0005435508328	17027	9	2C
0005435092061	17027	10	2G
0005433343730	17027	11	3A
0005435092088	17027	12	3C
0005433343817	17027	13	3B
0005433269755	17027	14	3G
0005433343801	17027	15	3F
0005433343732	17027	16	4A
0005435092030	17027	17	3H
0005435508325	17027	18	4B
0005433343766	17027	19	4F
0005433269757	17027	20	4C
0005433343731	17027	21	4G
0005433343741	17027	22	5B
0005433343727	17027	23	5A
0005435508286	17027	24	5F
0005435508360	17027	25	5C
0005433462741	17027	26	5G
0005433343734	17027	27	5H
0005433343728	17027	28	9B
0005433343798	17027	29	9A
0005435092075	17027	30	9G
0005433343781	17027	31	9H
0005433269754	17027	32	11B
0005433343725	17027	33	11E
0005433462738	17027	34	11D
0005433343760	17027	35	11H
0005433343795	17027	36	12B
0005433343799	17027	37	12A
0005434445232	17027	38	12D
0005433343811	17027	39	12F
0005433343752	17027	40	12G
0005433460421	17027	41	13B
0005435092074	17027	42	13A
0005435508392	17027	43	13D
0005433462731	17027	44	13E
0005433343726	17027	45	13G
0005433343753	17027	46	14B
0005433460416	17027	47	14E
0005433343807	17027	48	14D
0005433343719	17027	49	14F
0005433343750	17027	50	14G
0005433343733	17027	51	14H
0005433343746	17027	52	15D
0005433462729	17027	53	15B
0005435508287	17027	54	15E
0005433343765	17027	55	15F
0005433343774	17027	56	15H
0005434445231	17027	57	16A
0005435092057	17027	58	16D
0005435508393	17027	59	16F
0005433343806	17027	60	16E
0005433343755	17027	61	16G
0005433343773	17027	62	17A
0005433343740	17027	63	17D
0005433269758	17027	64	17B
0005435092079	17027	65	17E
0005433343769	17027	66	17F
0005435508367	17027	67	17H
0005433343722	17027	68	18D
0005433462739	17027	69	18B
0005433462728	17027	70	18E
0005433343749	17027	71	19B
0005433460424	17027	72	19A
0005433343819	17027	73	19F
0005433343721	17027	74	19E
0005433343735	17027	75	20A
0005433460423	17027	76	20D
0005433343804	17027	77	20B
0005433343818	17027	78	20E
0005433460411	17027	79	20G
0005433343747	17027	80	20F
0005433462733	17027	81	21A
0005433343784	17027	82	20H
0005433343723	17027	83	21D
0005433343761	17027	84	21B
0005435092058	17027	85	21E
0005433462730	17027	86	21F
0005433343767	17027	87	22B
0005433343810	17027	88	22A
0005433343815	17027	89	22H
0005433343724	17027	90	23B
0005433343763	17027	91	23A
0005435529973	17027	92	23E
0005433343803	17027	93	23G
0005433343796	17027	94	23F
0005435092087	17027	95	23H
0005433343775	17027	96	24B
0005435508368	17027	97	24D
0005433460415	17027	98	24F
0005433343797	17027	99	24G
0005433269756	17027	100	25D
0005433343754	17027	101	25E
0005433460420	17027	102	27D
0005433343808	17027	103	27E
0005433462725	17027	104	27H
0005433343736	17027	105	28A
0005433343812	17027	106	28B
0005433343718	17027	107	28E
0005435092015	17027	108	28D
0005433343743	17027	109	28F
0005435508309	17027	110	28G
0005435092078	17027	111	29A
0005433343738	17027	112	28H
0005433343742	17027	113	29D
0005435508375	17027	114	29B
0005433462722	17027	115	29E
0005433460417	17027	116	29G
0005433343788	17027	117	29F
0005433343779	17027	118	29H
0005435092046	17027	119	30B
0005433343768	17027	120	30A
0005433343770	17027	121	30E
0005433343783	17027	122	30D
0005433343776	17027	123	30G
0005433343780	17027	124	30F
0005433343789	17027	125	31A
0005433343777	17027	126	31B
0005433343800	17027	127	31D
0005433460425	17027	128	31F
0005433462736	17027	129	31G
0005433343792	17027	130	32A
0005433343739	17027	131	32B
0005433343756	17027	132	32E
0005433343745	17027	133	32F
0005435092080	17027	134	32H
0005433343748	17027	135	33A
0005433343793	17027	136	33D
0005433343744	17027	137	33B
0005433343729	17027	138	33G
0005433343764	17027	139	33F
0005433343751	17027	140	33E
0005433343814	17027	141	34A
0005433462740	17027	142	34D
0005435092056	17027	143	34B
0005435508312	17027	144	34F
0005435508305	17027	145	34E
0005433343759	17027	146	34G
0005433343813	17027	147	34H
0005433343782	17027	148	35F
0005433462737	17027	149	36A
0005433460422	17027	150	35H
0005435508270	17027	151	36B
0005435508327	17027	152	36D
0005433343809	17027	153	36E
0005433343785	17027	154	37A
0005433343816	17027	155	36H
0005433343802	17027	156	37E
0005433343790	17027	157	37F
0005433462732	17027	158	37H
0005433343762	17027	159	37G
0005433460418	17027	160	38A
0005433343778	17027	161	38E
0005433343805	17027	162	38D
0005433343720	17027	163	38G
0005433343758	17027	164	38F
0005433343787	17027	165	38H
0005433343794	17027	166	39E
0005432390072	18276	1	1A
0005432390097	18276	2	1D
0005432390070	18276	3	2C
0005432851952	18276	4	1F
0005432390130	18276	5	2D
0005432390099	18276	6	3A
0005432390068	18276	7	3D
0005432390122	18276	8	3C
0005432390096	18276	9	4A
0005432390094	18276	10	3F
0005432851958	18276	11	4C
0005432390090	18276	12	5A
0005432390082	18276	13	5F
0005432390023	18276	14	6B
0005432390112	18276	15	6E
0005432390134	18276	16	6D
0005432851967	18276	17	7E
0005432390081	18276	18	7D
0005432851955	18276	19	8A
0005432851964	18276	20	7F
0005432851954	18276	21	8F
0005432390128	18276	22	8E
0005432390086	18276	23	9B
0005432390071	18276	24	9A
0005432851957	18276	25	9D
0005432390106	18276	26	9C
0005432390061	18276	27	9E
0005432390091	18276	28	9F
0005432390113	18276	29	10C
0005432851950	18276	30	10B
0005432851968	18276	31	10E
0005432851962	18276	32	10F
0005432390084	18276	33	11B
0005432851961	18276	34	11A
0005432390063	18276	35	11D
0005432851959	18276	36	12D
0005432390098	18276	37	12C
0005432851960	18276	38	12B
0005432390110	18276	39	12F
0005432851965	18276	40	13C
0005432390028	18276	41	13E
0005432390120	18276	42	14A
0005432390143	18276	43	14C
0005432390105	18276	44	14D
0005432390085	18276	45	14F
0005432390121	18276	46	14E
0005432390171	18276	47	15B
0005432851953	18276	48	15A
0005432391987	18276	49	15E
0005432390052	18276	50	16D
0005432390100	18276	51	18A
0005432390089	18276	52	18D
0005432390111	18276	53	18B
0005432851956	18276	54	18F
0005432390087	18276	55	19B
0005432390062	18276	56	19D
0005432851966	18276	57	19C
0005432851951	18276	58	20A
0005432390144	18276	59	19F
0005432851963	18276	60	20B
0005432390095	18276	61	20D
0005432390022	18276	62	20C
0005432390069	18276	63	20F
0005432390060	18276	64	20E
0005432390066	18276	65	21C
0005432390079	18276	66	21B
0005432390078	18276	67	21D
0005432391989	18276	68	21F
0005434067144	12794	1	1A
0005434067510	12794	2	1C
0005434081763	12794	3	1F
0005434081773	12794	4	1D
0005432433718	12794	5	2C
0005434067350	12794	6	2A
0005434067709	12794	7	2D
0005434067355	12794	8	3A
0005434067595	12794	9	2F
0005432159890	12794	10	3C
0005434067472	12794	11	3D
0005434067342	12794	12	3F
0005434067391	12794	13	4B
0005433989776	12794	14	4A
0005434067589	12794	15	4C
0005434026687	12794	16	4D
0005434081849	12794	17	4E
0005432433719	12794	18	4F
0005434081857	12794	19	5A
0005434067563	12794	20	5C
0005433812918	12794	21	5B
0005434067422	12794	22	5D
0005434067096	12794	23	5E
0005432161168	12794	24	6A
0005434067421	12794	25	5F
0005434067084	12794	26	6B
0005434081765	12794	27	6C
0005432433715	12794	28	6D
0005434067191	12794	29	6F
0005434081762	12794	30	6E
0005434067490	12794	31	7B
0005432159889	12794	32	7A
0005434067525	12794	33	7C
0005434081761	12794	34	7E
0005434067488	12794	35	7D
0005434067330	12794	36	7F
0005434081751	12794	37	8A
0005434067143	12794	38	8B
0005434081787	12794	39	8D
0005434067538	12794	40	8C
0005434081750	12794	41	8F
0005434067354	12794	42	8E
0005434081916	12794	43	9C
0005434067101	12794	44	9B
0005434067492	12794	45	9E
0005434081831	12794	46	9D
0005434067550	12794	47	9F
0005432161167	12794	48	10B
0005434067333	12794	49	10D
0005432159888	12794	50	10C
0005434067708	12794	51	10E
0005434067585	12794	52	11A
0005434067380	12794	53	11B
0005434081795	12794	54	11C
0005434067272	12794	55	11E
0005434081858	12794	56	11D
0005433989740	12794	57	11F
0005434067461	12794	58	12A
0005434067441	12794	59	12C
0005434067473	12794	60	12B
0005434081760	12794	61	12D
0005434081871	12794	62	12E
0005434081895	12794	63	12F
0005434067251	12794	64	13A
0005434067234	12794	65	13C
0005434067433	12794	66	13B
0005432433716	12794	67	13D
0005433812916	12794	68	13E
0005434067329	12794	69	14A
0005434067514	12794	70	13F
0005434067190	12794	71	14B
0005434067440	12794	72	14C
0005434067459	12794	73	14E
0005434081896	12794	74	14D
0005434081886	12794	75	15A
0005432159891	12794	76	14F
0005434081819	12794	77	15C
0005434067462	12794	78	15B
0005434026688	12794	79	15D
0005434067361	12794	80	15E
0005434081759	12794	81	16A
0005434081851	12794	82	15F
0005434067586	12794	83	16B
0005434066987	12794	84	16C
0005434067555	12794	85	16D
0005434081848	12794	86	16E
0005433989759	12794	87	16F
0005433989752	12794	88	17B
0005434026689	12794	89	17C
0005434067498	12794	90	17D
0005433989746	12794	91	17F
0005434067614	12794	92	17E
0005434067106	12794	93	18A
0005434081850	12794	94	18B
0005432433717	12794	95	18D
0005434081799	12794	96	18C
0005434067328	12794	97	18E
0005434081902	12794	98	19A
0005434067269	12794	99	18F
0005434067491	12794	100	19B
0005434067213	12794	101	19D
0005434026698	12794	102	19C
0005434067097	12794	103	19E
0005434067257	12794	104	19F
0005433989775	12794	105	20A
0005434081868	12794	106	20B
0005434081766	12794	107	20D
0005433812917	12794	108	20C
0005434067420	12794	109	20E
0005434067357	12794	110	20F
0005434081922	12794	111	21A
0005434081708	12794	112	21C
0005434081772	12794	113	21B
0005434067359	12794	114	21D
0005434067465	12794	115	21E
0005434081870	12794	116	21F
0005434026699	12794	117	22B
0005434067126	12794	118	22A
0005434067650	12794	119	22C
0005434081912	12794	120	22D
0005434067072	12794	121	22F
0005434067608	12794	122	22E
0005434067613	12794	123	23A
0005434067233	12794	124	23B
0005434067381	12794	125	23C
0005434067434	12794	126	23D
0005434067358	12794	127	23F
0005433989760	12794	128	23E
0005434082042	30670	1	1A
0005434082054	30670	2	1C
0005434068030	30670	3	1D
0005434082041	30670	4	2C
0005434067977	30670	5	2A
0005434082039	30670	6	2D
0005434068007	30670	7	2F
0005434068034	30670	8	3A
0005434068015	30670	9	3D
0005434067997	30670	10	3F
0005434067975	30670	11	4B
0005432433671	30670	12	4A
0005434068032	30670	13	4D
0005434068021	30670	14	4C
0005434067991	30670	15	4E
0005432186892	30670	16	5A
0005434067995	30670	17	5C
0005434067992	30670	18	5B
0005434068003	30670	19	5D
0005434068011	30670	20	5F
0005434068014	30670	21	5E
0005434068005	30670	22	6A
0005434082049	30670	23	6B
0005434068001	30670	24	6C
0005434067972	30670	25	6D
0005434067980	30670	26	6F
0005434067986	30670	27	6E
0005434067989	30670	28	7A
0005434068025	30670	29	7C
0005434067984	30670	30	7B
0005432433646	30670	31	7D
0005434082048	30670	32	7E
0005434082043	30670	33	8A
0005434082051	30670	34	7F
0005433989801	30670	35	8B
0005432150244	30670	36	8C
0005432433656	30670	37	8D
0005434068026	30670	38	8E
0005434067981	30670	39	9A
0005434082040	30670	40	8F
0005434067982	30670	41	9B
0005432433714	30670	42	9D
0005434068017	30670	43	9C
0005434068029	30670	44	9F
0005434068000	30670	45	9E
0005434067987	30670	46	10B
0005434068010	30670	47	10D
0005433989798	30670	48	10C
0005434068004	30670	49	10E
0005434067973	30670	50	11A
0005434068013	30670	51	11B
0005434067971	30670	52	11C
0005434068009	30670	53	11E
0005434082055	30670	54	11D
0005434068008	30670	55	11F
0005434067974	30670	56	12A
0005434082037	30670	57	12C
0005434082047	30670	58	12B
0005434067983	30670	59	12D
0005434082056	30670	60	12E
0005434068022	30670	61	13A
0005434067998	30670	62	12F
0005434082035	30670	63	13B
0005434082045	30670	64	13C
0005434067990	30670	65	13D
0005434068018	30670	66	14A
0005432150245	30670	67	13F
0005433989800	30670	68	14B
0005434067988	30670	69	14C
0005434067978	30670	70	14F
0005434068035	30670	71	14E
0005434068006	30670	72	15B
0005434082038	30670	73	15A
0005432150241	30670	74	15D
0005432433647	30670	75	15C
0005433989802	30670	76	15F
0005434082053	30670	77	15E
0005434068027	30670	78	16A
0005434068037	30670	79	16B
0005434067965	30670	80	16C
0005434067968	30670	81	16E
0005434067993	30670	82	16D
0005433989799	30670	83	17B
0005434068028	30670	84	17C
0005434082050	30670	85	17D
0005432150242	30670	86	17F
0005434067985	30670	87	17E
0005434067999	30670	88	18C
0005432150243	30670	89	18B
0005432433663	30670	90	18A
0005434082034	30670	91	18E
0005432150240	30670	92	18D
0005434068020	30670	93	19A
0005434067979	30670	94	18F
0005434082044	30670	95	19B
0005434068024	30670	96	19D
0005434068002	30670	97	19C
0005434068036	30670	98	19F
0005434067996	30670	99	19E
0005434067970	30670	100	20A
0005434068019	30670	101	20C
0005434082052	30670	102	20E
0005434067994	30670	103	20D
0005434067966	30670	104	20F
0005432150246	30670	105	21B
0005434082057	30670	106	21A
0005434082046	30670	107	21C
0005432186893	30670	108	21D
0005434068012	30670	109	21E
0005434067976	30670	110	21F
0005434082058	30670	111	22B
0005434082036	30670	112	22A
0005434068023	30670	113	22C
0005434068031	30670	114	22D
0005434068033	30670	115	22E
0005434068016	30670	116	23B
0005432433662	30670	117	23C
0005434067967	30670	118	23D
0005434067969	30670	119	23E
0005433685536	9049	1	1A
0005433686655	9049	2	1B
0005433685540	9049	3	1C
0005433686648	9049	4	2A
0005433687723	9049	5	2B
0005433686651	9049	6	2C
0005433685543	9049	7	2D
0005433687725	9049	8	3B
0005433685538	9049	9	3C
0005433686657	9049	10	3D
0005433686647	9049	11	4A
0005433686654	9049	12	4C
0005433685542	9049	13	5C
0005433685537	9049	14	5D
0005433685539	9049	15	6A
0005433686652	9049	16	6B
0005433686650	9049	17	6C
0005433686656	9049	18	7C
0005433687720	9049	19	7D
0005433687719	9049	20	18B
0005433687727	9049	21	18C
0005433685541	9049	22	18D
0005433686649	9049	23	19A
0005433687726	9049	24	19B
0005433687724	9049	25	19D
0005433686653	9049	26	21A
0005433687721	9049	27	21C
0005433687722	9049	28	23A
0005434265111	5544	1	1B
0005433527293	5544	2	1A
0005434265068	5544	3	1F
0005435766619	5544	4	1H
0005434265211	5544	5	1G
0005435766617	5544	6	2B
0005435462426	5544	7	2F
0005435462324	5544	8	2C
0005433529306	5544	9	2G
0005433527296	5544	10	3C
0005435462434	5544	11	3B
0005435766636	5544	12	3F
0005432535822	5544	13	3G
0005435766658	5544	14	3H
0005434265066	5544	15	4B
0005435462274	5544	16	4A
0005435766632	5544	17	4F
0005434831148	5544	18	4C
0005434265077	5544	19	4H
0005435766623	5544	20	5B
0005435462387	5544	21	5A
0005434264977	5544	22	5C
0005434265051	5544	23	5F
0005435462413	5544	24	9A
0005435462325	5544	25	5G
0005433527294	5544	26	9B
0005435462491	5544	27	9G
0005435720831	5544	28	11B
0005432140504	5544	29	11E
0005434265067	5544	30	11D
0005434264973	5544	31	11F
0005432140502	5544	32	12A
0005435766648	5544	33	11H
0005435462492	5544	34	12B
0005435766647	5544	35	12D
0005435725630	5544	36	12F
0005435766674	5544	37	12H
0005434264992	5544	38	12G
0005435766660	5544	39	13A
0005434265026	5544	40	13B
0005435766676	5544	41	13E
0005435735167	5544	42	13F
0005434265109	5544	43	13H
0005435462360	5544	44	14B
0005434265023	5544	45	14D
0005435725631	5544	46	14F
0005432535817	5544	47	14E
0005435766637	5544	48	14G
0005435766668	5544	49	15A
0005434265155	5544	50	14H
0005435462284	5544	51	15B
0005435462490	5544	52	15E
0005435735164	5544	53	15D
0005435462298	5544	54	15F
0005434265073	5544	55	15H
0005435720829	5544	56	15G
0005435766671	5544	57	16A
0005435462499	5544	58	16D
0005434265037	5544	59	16B
0005434265018	5544	60	16E
0005435462275	5544	61	16F
0005435766657	5544	62	16H
0005435720830	5544	63	16G
0005435723058	5544	64	17A
0005435766631	5544	65	17D
0005435766655	5544	66	17B
0005434265110	5544	67	17F
0005435766675	5544	68	17E
0005435462297	5544	69	17G
0005432140505	5544	70	17H
0005435766650	5544	71	18B
0005435766625	5544	72	18A
0005435462489	5544	73	18D
0005434265152	5544	74	18E
0005435766644	5544	75	18G
0005435766624	5544	76	18H
0005435766641	5544	77	19B
0005434265071	5544	78	19A
0005434265156	5544	79	19E
0005432535823	5544	80	19F
0005434265060	5544	81	19H
0005435766661	5544	82	19G
0005435766639	5544	83	20A
0005435766628	5544	84	20B
0005435766633	5544	85	20E
0005435462361	5544	86	20D
0005435462336	5544	87	20H
0005433527297	5544	88	20G
0005434264993	5544	89	21B
0005435766616	5544	90	21A
0005435462165	5544	91	21D
0005434831150	5544	92	21G
0005435723059	5544	93	21F
0005435462375	5544	94	22A
0005434265120	5544	95	22B
0005435766654	5544	96	22E
0005435766645	5544	97	22F
0005432535826	5544	98	23A
0005435462445	5544	99	22H
0005435766643	5544	100	23D
0005435462183	5544	101	23E
0005434265025	5544	102	23H
0005435766663	5544	103	23F
0005433529304	5544	104	24A
0005435725632	5544	105	24B
0005434265052	5544	106	24D
0005435766649	5544	107	24F
0005435766651	5544	108	24E
0005434265119	5544	109	24H
0005434265072	5544	110	24G
0005435462438	5544	111	25D
0005435766627	5544	112	25E
0005435462376	5544	113	27A
0005435735165	5544	114	27B
0005434265019	5544	115	27D
0005435766640	5544	116	27F
0005435766615	5544	117	27H
0005435766670	5544	118	28A
0005435766667	5544	119	28B
0005433529307	5544	120	28D
0005435735166	5544	121	28H
0005435766638	5544	122	28G
0005435766618	5544	123	29A
0005432140506	5544	124	29B
0005432535825	5544	125	29E
0005432140503	5544	126	29G
0005435766622	5544	127	29F
0005435766653	5544	128	29H
0005435766646	5544	129	30B
0005434265094	5544	130	30A
0005434265130	5544	131	30D
0005434264972	5544	132	30F
0005435766634	5544	133	30E
0005435462350	5544	134	30H
0005435766652	5544	135	30G
0005432140501	5544	136	31A
0005434265114	5544	137	31E
0005435462433	5544	138	31D
0005433529305	5544	139	31F
0005435766656	5544	140	31H
0005435766621	5544	141	31G
0005435766664	5544	142	32B
0005432535818	5544	143	32E
0005435462245	5544	144	32D
0005435766662	5544	145	32F
0005434265139	5544	146	32G
0005434831149	5544	147	33A
0005435462246	5544	148	32H
0005435462382	5544	149	33E
0005435766666	5544	150	33D
0005435766673	5544	151	33H
0005435766626	5544	152	34A
0005435725633	5544	153	34D
0005435766620	5544	154	34B
0005432535809	5544	155	34E
0005432535821	5544	156	34G
0005435766665	5544	157	34F
0005434265075	5544	158	34H
0005435723060	5544	159	35B
0005435766659	5544	160	35A
0005434265133	5544	161	35E
0005435766630	5544	162	35D
0005435766672	5544	163	35F
0005432140507	5544	164	35G
0005435462405	5544	165	36A
0005434265137	5544	166	35H
0005435766642	5544	167	36B
0005435735163	5544	168	36E
0005434265076	5544	169	36D
0005435766635	5544	170	36F
0005434265154	5544	171	36H
0005435766629	5544	172	37A
0005432140508	5544	173	37D
0005435722072	5544	174	37B
0005434265093	5544	175	37F
0005435462435	5544	176	37H
0005433527295	5544	177	38A
0005432535820	5544	178	38E
0005435725629	5544	179	38D
0005435766669	5544	180	38G
0005435462515	5544	181	38F
0005435462406	5544	182	39D
0005435765956	13466	1	1B
0005435462695	13466	2	1F
0005435766118	13466	3	1C
0005435766380	13466	4	1H
0005435765925	13466	5	1G
0005434265330	13466	6	2A
0005435725596	13466	7	2B
0005434265336	13466	8	2C
0005435766153	13466	9	2H
0005435462720	13466	10	3B
0005434265332	13466	11	3F
0005435462689	13466	12	3C
0005432535868	13466	13	3G
0005435766258	13466	14	4A
0005435765851	13466	15	3H
0005432535869	13466	16	4C
0005435462707	13466	17	4G
0005435462686	13466	18	4F
0005435462693	13466	19	5B
0005435765945	13466	20	5A
0005435725571	13466	21	5C
0005435462687	13466	22	5G
0005434265333	13466	23	5F
0005435462706	13466	24	5H
0005435725597	13466	25	9B
0005435462708	13466	26	9H
0005434265313	13466	27	9G
0005435462717	13466	28	11B
0005432194539	13466	29	11D
0005435725567	13466	30	11F
0005435462705	13466	31	11G
0005435725593	13466	32	12A
0005434265321	13466	33	12D
0005435766137	13466	34	12E
0005432535871	13466	35	12G
0005435462704	13466	36	12F
0005435462716	13466	37	12H
0005435462714	13466	38	13A
0005435462721	13466	39	13D
0005435766042	13466	40	13B
0005435766202	13466	41	13E
0005434265323	13466	42	13G
0005435735132	13466	43	13F
0005435735111	13466	44	13H
0005435766307	13466	45	14A
0005435462696	13466	46	14E
0005432194538	13466	47	14G
0005435723052	13466	48	14H
0005435766228	13466	49	15B
0005435722042	13466	50	15E
0005435462698	13466	51	15D
0005434265335	13466	52	15G
0005434265310	13466	53	16B
0005434265315	13466	54	16A
0005432194542	13466	55	16D
0005435766331	13466	56	16E
0005435766040	13466	57	16F
0005435725576	13466	58	16H
0005435735110	13466	59	16G
0005435462690	13466	60	17A
0005435766022	13466	61	17E
0005435766314	13466	62	17G
0005435462694	13466	63	18B
0005434265322	13466	64	18E
0005435462710	13466	65	18F
0005435766082	13466	66	19A
0005434831186	13466	67	18H
0005432535867	13466	68	19B
0005434831185	13466	69	19E
0005435725595	13466	70	19D
0005432194541	13466	71	19F
0005435766165	13466	72	19G
0005434265312	13466	73	20B
0005435462700	13466	74	20D
0005435723039	13466	75	20H
0005435766310	13466	76	20G
0005434265334	13466	77	21A
0005435725598	13466	78	21E
0005435725570	13466	79	21H
0005435462688	13466	80	21G
0005435462684	13466	81	22B
0005435725585	13466	82	22A
0005435766179	13466	83	22D
0005435462701	13466	84	22E
0005435765955	13466	85	22G
0005435766104	13466	86	22F
0005432535870	13466	87	22H
0005435766251	13466	88	23B
0005435725566	13466	89	23A
0005435766041	13466	90	23F
0005435462702	13466	91	23E
0005434831183	13466	92	23H
0005435766103	13466	93	24F
0005435723051	13466	94	24H
0005435765850	13466	95	25D
0005434265331	13466	96	25E
0005435735112	13466	97	27A
0005435725590	13466	98	25F
0005435723049	13466	99	27B
0005435766308	13466	100	27H
0005435462715	13466	101	28D
0005435462718	13466	102	28B
0005432535866	13466	103	28G
0005435766126	13466	104	29B
0005435766313	13466	105	29A
0005435766053	13466	106	29E
0005435765744	13466	107	29F
0005435462685	13466	108	29H
0005434831187	13466	109	29G
0005435766196	13466	110	30D
0005434265329	13466	111	30F
0005435462709	13466	112	30E
0005435766057	13466	113	30G
0005435735135	13466	114	30H
0005435462712	13466	115	31A
0005435766081	13466	116	31D
0005435766221	13466	117	31F
0005434265324	13466	118	31H
0005434265314	13466	119	31G
0005435766125	13466	120	32A
0005434265319	13466	121	32B
0005435462699	13466	122	32E
0005435462722	13466	123	32D
0005435725574	13466	124	32G
0005435766208	13466	125	32H
0005435766178	13466	126	33A
0005435725575	13466	127	33B
0005435722041	13466	128	33E
0005435766008	13466	129	33D
0005435735131	13466	130	33F
0005435765983	13466	131	33H
0005435462691	13466	132	34B
0005435462703	13466	133	34F
0005435766045	13466	134	34E
0005435765954	13466	135	34G
0005435766034	13466	136	34H
0005435766033	13466	137	35B
0005435462711	13466	138	35D
0005435462692	13466	139	35F
0005434265320	13466	140	35E
0005434265325	13466	141	36B
0005434265316	13466	142	36D
0005435722047	13466	143	36F
0005434265317	13466	144	36H
0005434265311	13466	145	36G
0005434265328	13466	146	37A
0005435766254	13466	147	37B
0005434265327	13466	148	37E
0005432194540	13466	149	37F
0005435462697	13466	150	37H
0005434831184	13466	151	37G
0005434265326	13466	152	38E
0005435462713	13466	153	38F
0005435722040	13466	154	38H
0005434265318	13466	155	39E
0005435462719	13466	156	39D
0005435766177	13466	157	39F
0005434602890	18696	1	4B
0005434604895	18699	1	1A
0005434513597	18699	2	1B
0005434604889	18699	3	2A
0005434604886	18699	4	2B
0005434514984	18699	5	3A
0005434604896	18699	6	4A
0005434513595	18699	7	3B
0005434604898	18699	8	4B
0005434514985	18699	9	5A
0005434513596	18699	10	6A
0005434602912	19212	1	1A
0005434602916	19212	2	3B
0005434602914	19212	3	4A
0005434602915	19212	4	4B
0005434602913	19212	5	5A
0005434602911	19212	6	5B
0005433008674	1848	1	1A
0005433008786	1848	2	1C
0005433008634	1848	3	1D
0005433008673	1848	4	1F
0005433285256	1848	5	2A
0005433008701	1848	6	2D
0005433810578	1848	7	2F
0005433008570	1848	8	3A
0005433008572	1848	9	3C
0005433008660	1848	10	3F
0005433285253	1848	11	4A
0005433008675	1848	12	4C
0005433285268	1848	13	4D
0005433285393	1848	14	4E
0005433008557	1848	15	4F
0005433008593	1848	16	5A
0005433285204	1848	17	5C
0005433008546	1848	18	5D
0005433285298	1848	19	5E
0005433285248	1848	20	5F
0005433008524	1848	21	6A
0005433285313	1848	22	6C
0005433008409	1848	23	6D
0005433008551	1848	24	6E
0005433285259	1848	25	6F
0005433285208	1848	26	7A
0005433008622	1848	27	7D
0005433285235	1848	28	7C
0005433008537	1848	29	7E
0005433810579	1848	30	7F
0005433008702	1848	31	8A
0005433285257	1848	32	8C
0005433008540	1848	33	8D
0005433008451	1848	34	8E
0005433285265	1848	35	8F
0005433008410	1848	36	9A
0005433008430	1848	37	9C
0005433285215	1848	38	9D
0005433285140	1848	39	10C
0005433008483	1848	40	10F
0005432295899	1848	41	11A
0005433285364	1848	42	11C
0005433008387	1848	43	11D
0005433008428	1848	44	11E
0005433285249	1848	45	11F
0005433008567	1848	46	12C
0005433285114	1848	47	12D
0005433008407	1848	48	12E
0005433008516	1848	49	13C
0005433008406	1848	50	13A
0005433008629	1848	51	13D
0005433285343	1848	52	13E
0005433285289	1848	53	13F
0005433285245	1848	54	14A
0005433008531	1848	55	14C
0005432295898	1848	56	14D
0005433285159	1848	57	14E
0005433008529	1848	58	14F
0005433008328	1848	59	15A
0005433008620	1848	60	15D
0005433008621	1848	61	15E
0005433008497	1848	62	15F
0005433008566	1848	63	16A
0005432295897	1848	64	16C
0005433008431	1848	65	16D
0005433008596	1848	66	16E
0005433008617	1848	67	16F
0005433285141	1848	68	17D
0005433008611	1848	69	17E
0005433008539	1848	70	17F
0005433285264	1848	71	18A
0005433285363	1848	72	18C
0005433285102	1848	73	18D
0005433008785	1848	74	18E
0005433285418	1848	75	18F
0005433008388	1848	76	19A
0005433008573	1848	77	19C
0005433285326	1848	78	19D
0005433285098	1848	79	19E
0005433008427	1848	80	19F
0005433285250	1848	81	20A
0005433008484	1848	82	20C
0005433008602	1848	83	20D
0005433008485	1848	84	20E
0005433008594	1848	85	20F
0005433285504	22543	1	1A
0005433008904	22543	2	1C
0005433810520	22543	3	1D
0005433008916	22543	4	1F
0005433285514	22543	5	2A
0005433285497	22543	6	2C
0005433008928	22543	7	2F
0005433008907	22543	8	3A
0005433008933	22543	9	3C
0005433008927	22543	10	3D
0005433008926	22543	11	4A
0005433008896	22543	12	4C
0005433008899	22543	13	4D
0005433008920	22543	14	4E
0005433285496	22543	15	4F
0005433008910	22543	16	5A
0005433008914	22543	17	5C
0005433285506	22543	18	5D
0005433008906	22543	19	5E
0005433285490	22543	20	5F
0005433008908	22543	21	6A
0005433285512	22543	22	6C
0005433285491	22543	23	6D
0005433008937	22543	24	6E
0005433285507	22543	25	6F
0005433810519	22543	26	7A
0005433008917	22543	27	7C
0005433285510	22543	28	7D
0005433008915	22543	29	7E
0005433008892	22543	30	7F
0005433008930	22543	31	8A
0005433285488	22543	32	8C
0005433008901	22543	33	8D
0005433285500	22543	34	8E
0005433285515	22543	35	8F
0005433008923	22543	36	9A
0005433008898	22543	37	9C
0005433285495	22543	38	9D
0005433285494	22543	39	9E
0005433008934	22543	40	10A
0005433285505	22543	41	10D
0005433008911	22543	42	10F
0005433008919	22543	43	11A
0005433008929	22543	44	11C
0005433008913	22543	45	11D
0005433008932	22543	46	11F
0005433810518	22543	47	12A
0005433008900	22543	48	12D
0005433008895	22543	49	12E
0005433008925	22543	50	12F
0005433008931	22543	51	13A
0005433285493	22543	52	13C
0005433008921	22543	53	13F
0005433008903	22543	54	14C
0005433285511	22543	55	14E
0005433008935	22543	56	14F
0005433285509	22543	57	15C
0005433285501	22543	58	15D
0005433008936	22543	59	15F
0005433008891	22543	60	16A
0005433285508	22543	61	16C
0005433285516	22543	62	16D
0005433285492	22543	63	16E
0005433285503	22543	64	16F
0005433285513	22543	65	17A
0005433285517	22543	66	17E
0005433008922	22543	67	17F
0005433008893	22543	68	18A
0005433008909	22543	69	18D
0005433008890	22543	70	18E
0005433008918	22543	71	18F
0005433008924	22543	72	19A
0005433285499	22543	73	19C
0005433285489	22543	74	19D
0005433285498	22543	75	19E
0005433008902	22543	76	19F
0005433008897	22543	77	20A
0005433008894	22543	78	20C
0005433008912	22543	79	20D
0005433008905	22543	80	20E
0005433285502	22543	81	20F
0005432755092	25329	1	1A
0005432755088	25329	2	2D
0005432755093	25329	3	2F
0005432756868	25329	4	4C
0005432756864	25329	5	4E
0005432755090	25329	6	5A
0005432755089	25329	7	5C
0005432755094	25329	8	5D
0005434152772	25329	9	7D
0005432756862	25329	10	9E
0005432756866	25329	11	10A
0005432755091	25329	12	10D
0005432756865	25329	13	11D
0005434153524	25329	14	13A
0005432755095	25329	15	14E
0005432756867	25329	16	16A
0005434152773	25329	17	16E
0005434152775	25329	18	17F
0005434153527	25329	19	18E
0005432756863	25329	20	19A
0005432755096	25329	21	19C
0005432755087	25329	22	19D
0005432756861	25329	23	19F
0005433847113	5581	1	1C
0005433847115	5581	2	1A
0005432081554	5581	3	1F
0005433847136	5581	4	1D
0005433847104	5581	5	2D
0005433847148	5581	6	2C
0005432081553	5581	7	3A
0005433847117	5581	8	3D
0005433847110	5581	9	3C
0005433847106	5581	10	4A
0005433847135	5581	11	3F
0005433847128	5581	12	4D
0005433847139	5581	13	4C
0005433847107	5581	14	5C
0005433847098	5581	15	5A
0005433815415	5581	16	5F
0005433847143	5581	17	5D
0005435282373	5581	18	6B
0005433847133	5581	19	6A
0005435282461	5581	20	6D
0005433847116	5581	21	6E
0005434173527	5581	22	6F
0005435282501	5581	23	7C
0005434173513	5581	24	7B
0005433847112	5581	25	7E
0005434173524	5581	26	7D
0005433847152	5581	27	8A
0005433847102	5581	28	7F
0005433847119	5581	29	8D
0005435282484	5581	30	8C
0005433847101	5581	31	8F
0005433847125	5581	32	8E
0005433847114	5581	33	9B
0005433847124	5581	34	9A
0005435282436	5581	35	9C
0005435282486	5581	36	9E
0005435282415	5581	37	9D
0005432081555	5581	38	10A
0005433847111	5581	39	10C
0005433847155	5581	40	10B
0005433815418	5581	41	10D
0005433847130	5581	42	10F
0005433847109	5581	43	11B
0005434173494	5581	44	11A
0005435282439	5581	45	11D
0005433847138	5581	46	11C
0005433847105	5581	47	11E
0005433847140	5581	48	12B
0005433847134	5581	49	12A
0005435282438	5581	50	12C
0005432081557	5581	51	12D
0005433847103	5581	52	13A
0005435282406	5581	53	12F
0005435282458	5581	54	13C
0005435282502	5581	55	13B
0005433847100	5581	56	13E
0005433847131	5581	57	13D
0005435282399	5581	58	14A
0005435282485	5581	59	14C
0005433847149	5581	60	14B
0005433847129	5581	61	14D
0005433847132	5581	62	14F
0005435282416	5581	63	14E
0005435282491	5581	64	15B
0005434173498	5581	65	15A
0005435282462	5581	66	15D
0005433847121	5581	67	15C
0005433847151	5581	68	15E
0005433847142	5581	69	15F
0005433847154	5581	70	16C
0005432081556	5581	71	16E
0005435282513	5581	72	16F
0005433847146	5581	73	17A
0005433847127	5581	74	17D
0005433847118	5581	75	17F
0005433815417	5581	76	17E
0005434173493	5581	77	18B
0005433847122	5581	78	18A
0005433847108	5581	79	18C
0005433847153	5581	80	18F
0005433847126	5581	81	18E
0005433847147	5581	82	18D
0005433815414	5581	83	19B
0005433847120	5581	84	19A
0005433847145	5581	85	19E
0005433847150	5581	86	19D
0005432081558	5581	87	19C
0005433815416	5581	88	19F
0005433847141	5581	89	20C
0005433847123	5581	90	20B
0005433847099	5581	91	20A
0005432081559	5581	92	20D
0005433847144	5581	93	20F
0005433815419	5581	94	20E
0005435282463	5581	95	21B
0005433847137	5581	96	21A
0005433847156	5581	97	21E
0005434173551	13869	1	1C
0005433846560	13869	2	1A
0005435282686	13869	3	1F
0005433846445	13869	4	1D
0005433846677	13869	5	2A
0005433846780	13869	6	2D
0005435282674	13869	7	3A
0005433846649	13869	8	2F
0005433846611	13869	9	3D
0005434173550	13869	10	3C
0005435282680	13869	11	3F
0005433846834	13869	12	4C
0005435282700	13869	13	4A
0005433846461	13869	14	5A
0005433846515	13869	15	4F
0005435282702	13869	16	4D
0005435282689	13869	17	5F
0005432003722	13869	18	5D
0005433846846	13869	19	6B
0005433846630	13869	20	6A
0005435282675	13869	21	6C
0005433846485	13869	22	6E
0005433846773	13869	23	7A
0005435282699	13869	24	6F
0005435282696	13869	25	7C
0005433846593	13869	26	7B
0005433846658	13869	27	7D
0005433846568	13869	28	8A
0005433846557	13869	29	7F
0005433846556	13869	30	7E
0005433846760	13869	31	8B
0005433846601	13869	32	8D
0005433846790	13869	33	8C
0005435282681	13869	34	8F
0005433846585	13869	35	8E
0005433846401	13869	36	9B
0005433846414	13869	37	9A
0005433846691	13869	38	9D
0005435282691	13869	39	9C
0005433846602	13869	40	9E
0005432003725	13869	41	10A
0005435282684	13869	42	9F
0005433846584	13869	43	10C
0005433846779	13869	44	10E
0005435282677	13869	45	10D
0005433846343	13869	46	11A
0005434173549	13869	47	10F
0005435282701	13869	48	11B
0005435282690	13869	49	11D
0005434173547	13869	50	11F
0005433846402	13869	51	11E
0005433846627	13869	52	12C
0005433846701	13869	53	12B
0005433846462	13869	54	12F
0005435282673	13869	55	12E
0005433846609	13869	56	13A
0005435282678	13869	57	13C
0005433815381	13869	58	13B
0005433815382	13869	59	13E
0005435282698	13869	60	13D
0005433846628	13869	61	14A
0005433846555	13869	62	13F
0005435282688	13869	63	14D
0005433846909	13869	64	14C
0005433846487	13869	65	15B
0005433846574	13869	66	15A
0005433846745	13869	67	15C
0005435282685	13869	68	15F
0005433846583	13869	69	15E
0005433846794	13869	70	15D
0005433846539	13869	71	16A
0005432003724	13869	72	16C
0005435282694	13869	73	16B
0005435282693	13869	74	16D
0005435282676	13869	75	17A
0005433846344	13869	76	16E
0005433846626	13869	77	17B
0005435282687	13869	78	17D
0005433846759	13869	79	17C
0005433846579	13869	80	17F
0005433846413	13869	81	17E
0005433846789	13869	82	18B
0005435282692	13869	83	18A
0005432003723	13869	84	18C
0005433846441	13869	85	18E
0005433846578	13869	86	19A
0005435282682	13869	87	18F
0005435282697	13869	88	19B
0005433846422	13869	89	19E
0005433846526	13869	90	19D
0005433846580	13869	91	19C
0005435282683	13869	92	19F
0005433846440	13869	93	20B
0005435282695	13869	94	20C
0005433846400	13869	95	20F
0005433846716	13869	96	20E
0005435282679	13869	97	20D
0005433846463	13869	98	21C
0005433846704	13869	99	21B
0005434173548	13869	100	21E
0005433846540	13869	101	21F
0005434620744	7823	1	1C
0005434620746	7823	2	2B
0005434620742	7823	3	2D
0005435332272	7823	4	3A
0005432112531	7823	5	4A
0005434620743	7823	6	4C
0005434620737	7823	7	5A
0005434620739	7823	8	5C
0005434620730	7823	9	5D
0005434620734	7823	10	6B
0005435332282	7823	11	6C
0005434620747	7823	12	6D
0005434620729	7823	13	7A
0005435332355	7823	14	7C
0005434620728	7823	15	18A
0005434620736	7823	16	18C
0005434620738	7823	17	18D
0005435332345	7823	18	19A
0005434620741	7823	19	19B
0005435332331	7823	20	19D
0005435332281	7823	21	20A
0005434620731	7823	22	20B
0005435332273	7823	23	20C
0005434620727	7823	24	20D
0005434620732	7823	25	21A
0005435332325	7823	26	21B
0005434620740	7823	27	21D
0005432112532	7823	28	22B
0005434620733	7823	29	22C
0005434620735	7823	30	22D
0005434620745	7823	31	23A
0005435332324	7823	32	23B
0005434620582	32950	1	1A
0005434620606	32950	2	1C
0005434620587	32950	3	2C
0005435332407	32950	4	2D
0005435332403	32950	5	3A
0005435332409	32950	6	3C
0005434620547	32950	7	4A
0005434620607	32950	8	4B
0005435332411	32950	9	4C
0005434620657	32950	10	4D
0005434620608	32950	11	5A
0005434620553	32950	12	5B
0005434620434	32950	13	5C
0005434620556	32950	14	6B
0005434620551	32950	15	6C
0005434620595	32950	16	7B
0005434620552	32950	17	7C
0005435332405	32950	18	7D
0005434620605	32950	19	18A
0005434620536	32950	20	18B
0005434620588	32950	21	18C
0005435332404	32950	22	18D
0005434620577	32950	23	19B
0005435332406	32950	24	19C
0005434620537	32950	25	19D
0005435332408	32950	26	20A
0005435332410	32950	27	20B
0005434620555	32950	28	20C
0005434620494	32950	29	20D
0005434620545	32950	30	21A
0005434620583	32950	31	21B
0005434620493	32950	32	21D
0005434620658	32950	33	22B
0005434620578	32950	34	22C
0005434620581	32950	35	23A
0005435785605	4316	1	1A
0005435937369	4316	2	1C
0005435785594	4316	3	1D
0005435785595	4316	4	2A
0005434994090	4316	5	2C
0005434994091	4316	6	2D
0005434994086	4316	7	2F
0005435785580	4316	8	3A
0005435937377	4316	9	3D
0005435785613	4316	10	3F
0005435937373	4316	11	4D
0005435787368	4316	12	4E
0005435785610	4316	13	4F
0005434994088	4316	14	5C
0005432190656	4316	15	5F
0005435785607	4316	16	6C
0005435785604	4316	17	6D
0005435918645	4316	18	6E
0005434994095	4316	19	7A
0005432190657	4316	20	7C
0005432190655	4316	21	7E
0005435785589	4316	22	8A
0005432190654	4316	23	8D
0005435785593	4316	24	8E
0005435787370	4316	25	9A
0005434994089	4316	26	9C
0005435918644	4316	27	9D
0005435785609	4316	28	9E
0005435785579	4316	29	10A
0005435785585	4316	30	10D
0005434994085	4316	31	10E
0005435785591	4316	32	11A
0005435785606	4316	33	11C
0005435785600	4316	34	11D
0005435787369	4316	35	11F
0005435785597	4316	36	12A
0005435785587	4316	37	12C
0005435785586	4316	38	12E
0005434994087	4316	39	12F
0005435785598	4316	40	13C
0005435785578	4316	41	13E
0005435937367	4316	42	13F
0005435918635	4316	43	14A
0005435785602	4316	44	14C
0005435785603	4316	45	14E
0005435785596	4316	46	15C
0005435785612	4316	47	16A
0005434994093	4316	48	16C
0005434994094	4316	49	16D
0005435918657	4316	50	16E
0005435785583	4316	51	17A
0005435918656	4316	52	17D
0005435785611	4316	53	17E
0005435785581	4316	54	17F
0005435785590	4316	55	18A
0005435785599	4316	56	18C
0005435785584	4316	57	18F
0005434994092	4316	58	19A
0005435785592	4316	59	19C
0005435785608	4316	60	19D
0005435785582	4316	61	19E
0005435785588	4316	62	19F
0005435785601	4316	63	20E
0005435937376	4316	64	20F
0005435785271	27285	1	1A
0005435918690	27285	2	1C
0005435785206	27285	3	1F
0005435785192	27285	4	2C
0005435937404	27285	5	2D
0005434993976	27285	6	2F
0005435785311	27285	7	3A
0005435918686	27285	8	3F
0005435785257	27285	9	4A
0005435785351	27285	10	4D
0005435785175	27285	11	5A
0005434993982	27285	12	5C
0005435918687	27285	13	5F
0005435918688	27285	14	6C
0005435785262	27285	15	6E
0005435937405	27285	16	7C
0005435937407	27285	17	7D
0005435785291	27285	18	7F
0005435785306	27285	19	8D
0005435785190	27285	20	8E
0005435937403	27285	21	9A
0005435937409	27285	22	9E
0005435918689	27285	23	9F
0005432195706	27285	24	10E
0005435785352	27285	25	10F
0005435785184	27285	26	11A
0005435785358	27285	27	12A
0005435785178	27285	28	12E
0005434993975	27285	29	12F
0005435937402	27285	30	13C
0005432195705	27285	31	13F
0005435785147	27285	32	14A
0005435785357	27285	33	14D
0005435937406	27285	34	14E
0005435785258	27285	35	14F
0005435785159	27285	36	15A
0005435787350	27285	37	15C
0005434993977	27285	38	15D
0005435785307	27285	39	15E
0005435937408	27285	40	16A
0005435785292	27285	41	16C
0005435787343	27285	42	16D
0005435785272	27285	43	16E
0005435785237	27285	44	17A
0005434993965	27285	45	17D
0005435785205	27285	46	17E
0005435785305	27285	47	18C
0005435785209	27285	48	18D
0005435785185	27285	49	18F
0005432195707	27285	50	19A
0005434993981	27285	51	19D
0005435785395	27285	52	20A
0005435785189	27285	53	20D
0005432146213	19891	1	20B
0005432146212	19891	2	21B
0005432568064	4715	1	1A
0005432568086	4715	2	1C
0005432460233	4715	3	1G
0005432568074	4715	4	2A
0005434082072	4715	5	2C
0005432460205	4715	6	2G
0005434082089	4715	7	3A
0005432460237	4715	8	2H
0005433726121	4715	9	3B
0005432568069	4715	10	3C
0005432568083	4715	11	4A
0005432568054	4715	12	3H
0005433451633	4715	13	4B
0005432460190	4715	14	4F
0005432170437	4715	15	4C
0005434082071	4715	16	4G
0005432460186	4715	17	5A
0005432460189	4715	18	4H
0005432460192	4715	19	5B
0005432460188	4715	20	5G
0005432568080	4715	21	9B
0005432568038	4715	22	9A
0005432460220	4715	23	9G
0005432568060	4715	24	11A
0005432568059	4715	25	9H
0005434082068	4715	26	11B
0005432460235	4715	27	11E
0005434559101	4715	28	11D
0005434082081	4715	29	11F
0005432460236	4715	30	11H
0005432568044	4715	31	11G
0005434082078	4715	32	12A
0005432568076	4715	33	12D
0005432460219	4715	34	12E
0005432568031	4715	35	12G
0005432568028	4715	36	12H
0005432568046	4715	37	13A
0005432568029	4715	38	13D
0005432170433	4715	39	13B
0005432186894	4715	40	13E
0005432460217	4715	41	13F
0005432568051	4715	42	13H
0005432460206	4715	43	13G
0005434082066	4715	44	14B
0005434082087	4715	45	14A
0005434082083	4715	46	14D
0005432568041	4715	47	14E
0005434082059	4715	48	14G
0005434082067	4715	49	15A
0005434082084	4715	50	14H
0005432571349	4715	51	15D
0005432571350	4715	52	15B
0005432460218	4715	53	15G
0005432568035	4715	54	15F
0005432568058	4715	55	15H
0005432568089	4715	56	16A
0005432460225	4715	57	16D
0005432460187	4715	58	16B
0005432568053	4715	59	16E
0005432568087	4715	60	16F
0005432460230	4715	61	17A
0005432460209	4715	62	16G
0005432571346	4715	63	17D
0005432460207	4715	64	17B
0005433451634	4715	65	17E
0005432460228	4715	66	17G
0005432460234	4715	67	17F
0005432460193	4715	68	18A
0005432568085	4715	69	18E
0005432460212	4715	70	18D
0005432568061	4715	71	18B
0005432568042	4715	72	18G
0005432460201	4715	73	18F
0005432460227	4715	74	18H
0005432568072	4715	75	19D
0005432568088	4715	76	19F
0005432568052	4715	77	19G
0005432571348	4715	78	20A
0005432460197	4715	79	19H
0005432568030	4715	80	20B
0005432568032	4715	81	20E
0005433726119	4715	82	20G
0005434082088	4715	83	20F
0005432568081	4715	84	21A
0005432460226	4715	85	21D
0005434082073	4715	86	21E
0005432460231	4715	87	21F
0005432568066	4715	88	21H
0005432568062	4715	89	22A
0005432568043	4715	90	22D
0005434082074	4715	91	22B
0005432568048	4715	92	22F
0005432460191	4715	93	22E
0005432460213	4715	94	22G
0005432460232	4715	95	22H
0005432568039	4715	96	23B
0005432568078	4715	97	23E
0005432568055	4715	98	23D
0005432460203	4715	99	23F
0005432568068	4715	100	23G
0005434082080	4715	101	23H
0005432460223	4715	102	24A
0005432460196	4715	103	24E
0005434082060	4715	104	24D
0005432568040	4715	105	24G
0005434082062	4715	106	25D
0005434082070	4715	107	27A
0005434559100	4715	108	25F
0005434082069	4715	109	27B
0005432170435	4715	110	27F
0005434082085	4715	111	27G
0005432568047	4715	112	28A
0005432568037	4715	113	28B
0005432460229	4715	114	28E
0005432460202	4715	115	28D
0005432568036	4715	116	28F
0005432460215	4715	117	28G
0005432568034	4715	118	29A
0005432568084	4715	119	28H
0005432460195	4715	120	29B
0005432170434	4715	121	29G
0005432568049	4715	122	29F
0005434082061	4715	123	29H
0005432568077	4715	124	30E
0005432460221	4715	125	30D
0005432568079	4715	126	30B
0005432568082	4715	127	30G
0005432170431	4715	128	30H
0005432170436	4715	129	31B
0005434082082	4715	130	31A
0005432568070	4715	131	31E
0005432460216	4715	132	31F
0005432568056	4715	133	31G
0005433452753	4715	134	31H
0005434082065	4715	135	32B
0005432460204	4715	136	32E
0005434082064	4715	137	32F
0005432460214	4715	138	32H
0005432460199	4715	139	32G
0005432186895	4715	140	33A
0005434082086	4715	141	33D
0005434082079	4715	142	33B
0005432460200	4715	143	33E
0005432571347	4715	144	33F
0005432568071	4715	145	33H
0005432568033	4715	146	34A
0005432568067	4715	147	34B
0005432460224	4715	148	34E
0005432568057	4715	149	34G
0005433726120	4715	150	34H
0005432460194	4715	151	35E
0005434082077	4715	152	35G
0005432568065	4715	153	36A
0005433451635	4715	154	35H
0005432568063	4715	155	36B
0005432568073	4715	156	36D
0005433452754	4715	157	36F
0005434082063	4715	158	36G
0005432170432	4715	159	37D
0005432186896	4715	160	37B
0005432568050	4715	161	37F
0005432568045	4715	162	37H
0005432460211	4715	163	38A
0005432460198	4715	164	38D
0005432460185	4715	165	38B
0005432460210	4715	166	38G
0005432568075	4715	167	38F
0005434082075	4715	168	38H
0005434082076	4715	169	39D
0005432460222	4715	170	39F
0005432460208	4715	171	39E
0005432567430	30568	1	1A
0005432567734	30568	2	1C
0005432459917	30568	3	1F
0005432459905	30568	4	2A
0005432567465	30568	5	1H
0005434081857	30568	6	2B
0005432459614	30568	7	2F
0005434081831	30568	8	2C
0005432459852	30568	9	2G
0005432567691	30568	10	3A
0005432567293	30568	11	2H
0005434081895	30568	12	3C
0005434081849	30568	13	3B
0005432567496	30568	14	3G
0005432567631	30568	15	3H
0005432567712	30568	16	4B
0005432567622	30568	17	4F
0005432567619	30568	18	4C
0005432459886	30568	19	4G
0005432459853	30568	20	5B
0005432567632	30568	21	5C
0005432459656	30568	22	5G
0005432567327	30568	23	5F
0005432459709	30568	24	5H
0005432459863	30568	25	9B
0005434081799	30568	26	9H
0005432567657	30568	27	9G
0005432567518	30568	28	11B
0005432567495	30568	29	11D
0005432567613	30568	30	11G
0005434081773	30568	31	11H
0005432213631	30568	32	12D
0005432567517	30568	33	12B
0005434081765	30568	34	12E
0005434081762	30568	35	12G
0005434081763	30568	36	12H
0005432567602	30568	37	13D
0005434081858	30568	38	13E
0005432567497	30568	39	13F
0005434081708	30568	40	14A
0005432213633	30568	41	13H
0005433454870	30568	42	14B
0005432567633	30568	43	14D
0005432459615	30568	44	14G
0005434081795	30568	45	15A
0005432567546	30568	46	15E
0005432567452	30568	47	15D
0005432459641	30568	48	15F
0005434081916	30568	49	16A
0005434081760	30568	50	16D
0005432459816	30568	51	16B
0005432567779	30568	52	16E
0005432567429	30568	53	16F
0005432459808	30568	54	16H
0005434081886	30568	55	16G
0005432567670	30568	56	17A
0005432567216	30568	57	17E
0005432567393	30568	58	17F
0005432161168	30568	59	17H
0005432567692	30568	60	18B
0005434081819	30568	61	18A
0005432459910	30568	62	18F
0005432459765	30568	63	18H
0005432459856	30568	64	18G
0005434081750	30568	65	19A
0005432459962	30568	66	19D
0005432567671	30568	67	19F
0005432567321	30568	68	19H
0005432459628	30568	69	20E
0005432567725	30568	70	20D
0005432567778	30568	71	20H
0005434081850	30568	72	20G
0005434081868	30568	73	21A
0005432459782	30568	74	21B
0005432567553	30568	75	21E
0005434081759	30568	76	21D
0005434081870	30568	77	21F
0005432567685	30568	78	22A
0005434081787	30568	79	21H
0005432459885	30568	80	22B
0005432567614	30568	81	22E
0005432567684	30568	82	22G
0005432567690	30568	83	22F
0005432567406	30568	84	22H
0005434081871	30568	85	23A
0005432460007	30568	86	23D
0005432459774	30568	87	23F
0005434081922	30568	88	24A
0005432459733	30568	89	24E
0005434081761	30568	90	24F
0005432459764	30568	91	24G
0005432567733	30568	92	25F
0005434081772	30568	93	25D
0005432460008	30568	94	27E
0005432567547	30568	95	27D
0005432567557	30568	96	28A
0005432213632	30568	97	28B
0005432567693	30568	98	28D
0005434081766	30568	99	28F
0005432459705	30568	100	28E
0005432161167	30568	101	29B
0005432459708	30568	102	29E
0005432567724	30568	103	29F
0005432459833	30568	104	29H
0005434081851	30568	105	29G
0005432567326	30568	106	30A
0005432567215	30568	107	30D
0005434081896	30568	108	30E
0005432567748	30568	109	30G
0005432567396	30568	110	31A
0005432459732	30568	111	31F
0005432567453	30568	112	31E
0005434081751	30568	113	31G
0005432459911	30568	114	32B
0005432459951	30568	115	32A
0005432567590	30568	116	32E
0005432459961	30568	117	32F
0005432459639	30568	118	32H
0005432567458	30568	119	33A
0005434081912	30568	120	33E
0005432567655	30568	121	33D
0005432567347	30568	122	33F
0005432460004	30568	123	33H
0005432459963	30568	124	33G
0005432567732	30568	125	34A
0005432567618	30568	126	34D
0005432460005	30568	127	34F
0005432459652	30568	128	34E
0005432459734	30568	129	34G
0005432459781	30568	130	34H
0005432459826	30568	131	35A
0005433452735	30568	132	35D
0005432459640	30568	133	35F
0005432567706	30568	134	35G
0005434081902	30568	135	36B
0005432567421	30568	136	36F
0005432567556	30568	137	36H
0005433454876	30568	138	37A
0005432459906	30568	139	37D
0005432459653	30568	140	37F
0005432567683	30568	141	37E
0005432567689	30568	142	37H
0005432459834	30568	143	37G
0005432567656	30568	144	38B
0005432567467	30568	145	38G
0005434081848	30568	146	38F
0005432567320	30568	147	39E
0005432460006	30568	148	39D
0005432571316	30568	149	39F
0005435720829	13637	1	4A
0005435720830	13637	2	4B
0005435720831	13637	3	5B
0005435722072	13637	4	5A
0005435722054	21154	1	2B
0005435722051	21154	2	6A
0005432295898	22812	1	4B
0005432295897	22812	2	5C
0005432295899	22812	3	6A
0005435508335	11119	1	1A
0005433343864	11119	2	1C
0005433343852	11119	3	1F
0005433343905	11119	4	1D
0005433343916	11119	5	2A
0005433343881	11119	6	2D
0005435508297	11119	7	2C
0005435097258	11119	8	2F
0005433343833	11119	9	3C
0005435508299	11119	10	3A
0005435508364	11119	11	3D
0005433343908	11119	12	3F
0005433343876	11119	13	4A
0005433343898	11119	14	4C
0005433343896	11119	15	4B
0005435508333	11119	16	4E
0005433343865	11119	17	4D
0005433343849	11119	18	5A
0005435508332	11119	19	4F
0005433343891	11119	20	5B
0005433343878	11119	21	5D
0005433343918	11119	22	5C
0005433343901	11119	23	5E
0005433343907	11119	24	5F
0005433343835	11119	25	6A
0005433343825	11119	26	6C
0005433343821	11119	27	6B
0005433343861	11119	28	6D
0005433343870	11119	29	6E
0005435097267	11119	30	6F
0005433343886	11119	31	7B
0005433343868	11119	32	7A
0005433343841	11119	33	7C
0005435097266	11119	34	7E
0005433343853	11119	35	7D
0005433343885	11119	36	7F
0005433343919	11119	37	8A
0005433343862	11119	38	8B
0005433343824	11119	39	8C
0005433343854	11119	40	8E
0005435508298	11119	41	8D
0005433343887	11119	42	9A
0005433343823	11119	43	8F
0005433343855	11119	44	9B
0005433343880	11119	45	9D
0005433343917	11119	46	9C
0005433343888	11119	47	9E
0005433343894	11119	48	9F
0005433343869	11119	49	10C
0005433343906	11119	50	10B
0005433343902	11119	51	10D
0005433343840	11119	52	11A
0005433343897	11119	53	10E
0005433343920	11119	54	11B
0005433343913	11119	55	11C
0005433343882	11119	56	11E
0005433343845	11119	57	11D
0005433343889	11119	58	11F
0005433343858	11119	59	12A
0005435097261	11119	60	12B
0005433343893	11119	61	12D
0005433343866	11119	62	12C
0005433343900	11119	63	12E
0005433343910	11119	64	12F
0005435097257	11119	65	13B
0005433343912	11119	66	13A
0005435508314	11119	67	13C
0005433343834	11119	68	13D
0005433343827	11119	69	13E
0005433343911	11119	70	13F
0005433343860	11119	71	14A
0005433343904	11119	72	14C
0005433343863	11119	73	14B
0005433343847	11119	74	14D
0005435097260	11119	75	14E
0005433343871	11119	76	15A
0005433343877	11119	77	14F
0005433343890	11119	78	15B
0005433343822	11119	79	15C
0005433343838	11119	80	15D
0005433343837	11119	81	15E
0005433343831	11119	82	15F
0005433343857	11119	83	16B
0005433343846	11119	84	16A
0005433343842	11119	85	16C
0005433343892	11119	86	16E
0005433343899	11119	87	16D
0005433343873	11119	88	16F
0005433343844	11119	89	17A
0005435508356	11119	90	17B
0005433343836	11119	91	17C
0005435508334	11119	92	17E
0005433343879	11119	93	17D
0005433343850	11119	94	17F
0005433343903	11119	95	18A
0005433343915	11119	96	18B
0005433343914	11119	97	18D
0005433343867	11119	98	18C
0005433343859	11119	99	18E
0005435508313	11119	100	19A
0005433343884	11119	101	18F
0005433343851	11119	102	19C
0005435097264	11119	103	19B
0005433343828	11119	104	19E
0005433343826	11119	105	19D
0005435097265	11119	106	19F
0005435508359	11119	107	20B
0005435508351	11119	108	20A
0005435508300	11119	109	20C
0005433343874	11119	110	20E
0005433343843	11119	111	20D
0005433343921	11119	112	20F
0005433343829	11119	113	21A
0005433343820	11119	114	21C
0005433343883	11119	115	21B
0005433343909	11119	116	21D
0005433343830	11119	117	21F
0005435097262	11119	118	21E
0005433343848	11119	119	22A
0005435097259	11119	120	22C
0005433343895	11119	121	22B
0005433343856	11119	122	22E
0005433343832	11119	123	22D
0005433343875	11119	124	22F
0005433343872	11119	125	23A
0005433343839	11119	126	23B
0005435508301	11119	127	23C
0005435508355	11119	128	23E
0005435097263	11119	129	23D
0005435508357	11119	130	23F
0005433343116	17113	1	1A
0005433342162	17113	2	1C
0005433342721	17113	3	1D
0005433342969	17113	4	2A
0005433342821	17113	5	1F
0005433342768	17113	6	2D
0005433343226	17113	7	2C
0005433342371	17113	8	3A
0005433342163	17113	9	2F
0005433343256	17113	10	3C
0005433342715	17113	11	3D
0005433342678	17113	12	3F
0005433342388	17113	13	4A
0005432293227	17113	14	4C
0005433342756	17113	15	4B
0005433343072	17113	16	4D
0005433342771	17113	17	4E
0005433343098	17113	18	4F
0005433342700	17113	19	5B
0005433343038	17113	20	5A
0005433342841	17113	21	5C
0005433342683	17113	22	5D
0005433342761	17113	23	5E
0005433342583	17113	24	5F
0005433343128	17113	25	6B
0005433342783	17113	26	6A
0005433342918	17113	27	6C
0005433343078	17113	28	6D
0005433343140	17113	29	6E
0005433343191	17113	30	6F
0005433343207	17113	31	7B
0005433342528	17113	32	7A
0005433343030	17113	33	7C
0005433343054	17113	34	7D
0005433342985	17113	35	7F
0005433342984	17113	36	7E
0005433342755	17113	37	8B
0005433342641	17113	38	8A
0005433342677	17113	39	8D
0005433343286	17113	40	8C
0005433342959	17113	41	8F
0005433342164	17113	42	8E
0005433342807	17113	43	9A
0005433342682	17113	44	9B
0005433342856	17113	45	9C
0005433342995	17113	46	9E
0005433343158	17113	47	9D
0005433343309	17113	48	9F
0005433343303	17113	49	10B
0005433343075	17113	50	10D
0005433342529	17113	51	10C
0005433343208	17113	52	10E
0005433342680	17113	53	11A
0005433343308	17113	54	11B
0005432293226	17113	55	11D
0005433342777	17113	56	11C
0005433342896	17113	57	11E
0005433342632	17113	58	11F
0005433342706	17113	59	12B
0005433342920	17113	60	12A
0005433343096	17113	61	12C
0005433342767	17113	62	12D
0005433343099	17113	63	12E
0005433343183	17113	64	12F
0005433343152	17113	65	13A
0005433342812	17113	66	13B
0005433342757	17113	67	13D
0005433343258	17113	68	13C
0005433343097	17113	69	13E
0005433342404	17113	70	13F
0005433342743	17113	71	14A
0005433342927	17113	72	14C
0005433343079	17113	73	14B
0005433342634	17113	74	14D
0005433343247	17113	75	14E
0005433343085	17113	76	14F
0005433343190	17113	77	15A
0005433342668	17113	78	15C
0005433343124	17113	79	15B
0005433343257	17113	80	15D
0005433343141	17113	81	15F
0005433342877	17113	82	15E
0005433342602	17113	83	16A
0005432293225	17113	84	16B
0005433343063	17113	85	16C
0005433342872	17113	86	16D
0005433342720	17113	87	16F
0005433342633	17113	88	16E
0005433342986	17113	89	17A
0005433343062	17113	90	17B
0005433342696	17113	91	17D
0005433342673	17113	92	17C
0005433342217	17113	93	17F
0005433342778	17113	94	17E
0005433343115	17113	95	18B
0005433342772	17113	96	18A
0005433342895	17113	97	18C
0005433342782	17113	98	18E
0005433343061	17113	99	18D
0005433342727	17113	100	18F
0005433343064	17113	101	19B
0005433343298	17113	102	19A
0005433342937	17113	103	19D
0005433343206	17113	104	19C
0005433343299	17113	105	19E
0005433342876	17113	106	19F
0005433343071	17113	107	20B
0005433343000	17113	108	20A
0005433342834	17113	109	20C
0005433342716	17113	110	20D
0005433342970	17113	111	20E
0005433342983	17113	112	20F
0005433343057	17113	113	21A
0005433342946	17113	114	21B
0005433342820	17113	115	21D
0005433342744	17113	116	21C
0005433342799	17113	117	21E
0005433342919	17113	118	22A
0005433342577	17113	119	21F
0005433343058	17113	120	22B
0005433342603	17113	121	22C
0005433342835	17113	122	22D
0005433342559	17113	123	22F
0005433342960	17113	124	22E
0005433342831	17113	125	23A
0005433343246	17113	126	23B
0005433342224	17113	127	23D
0005433343074	17113	128	23C
0005433342833	17113	129	23F
0005433342766	17113	130	23E
0005432919880	9076	1	1A
0005433507314	9076	2	1D
0005433507313	9076	3	1F
0005432919864	9076	4	2C
0005433507311	9076	5	2F
0005432919784	9076	6	3A
0005433507317	9076	7	3F
0005432919785	9076	8	4A
0005433481218	9076	9	5C
0005432919844	9076	10	5D
0005432919761	9076	11	5F
0005433481223	9076	12	6C
0005433507319	9076	13	6D
0005432919832	9076	14	6E
0005433507303	9076	15	7C
0005433481220	9076	16	7D
0005433507321	9076	17	8C
0005432919831	9076	18	8D
0005433507302	9076	19	8E
0005433507310	9076	20	10C
0005432919818	9076	21	10D
0005432919862	9076	22	11C
0005433507312	9076	23	11D
0005432919856	9076	24	11E
0005433481219	9076	25	11F
0005433481225	9076	26	12A
0005432919801	9076	27	12F
0005433507304	9076	28	13A
0005433507316	9076	29	13C
0005432919781	9076	30	14A
0005433481222	9076	31	14C
0005433481224	9076	32	14D
0005432919782	9076	33	15A
0005432919783	9076	34	15D
0005432919762	9076	35	15F
0005432919816	9076	36	16A
0005433507318	9076	37	16C
0005432919855	9076	38	16D
0005432919817	9076	39	16E
0005432919863	9076	40	16F
0005433507309	9076	41	17A
0005433507305	9076	42	17C
0005433507315	9076	43	17F
0005433507308	9076	44	18C
0005433507306	9076	45	18E
0005432919833	9076	46	19A
0005432919879	9076	47	19C
0005433481221	9076	48	19D
0005433507320	9076	49	19F
0005433507307	9076	50	20C
0005434158992	20488	1	1A
0005433481180	20488	2	1C
0005432920033	20488	3	1D
0005432920027	20488	4	1F
0005432920020	20488	5	2C
0005432920028	20488	6	2F
0005432920017	20488	7	3D
0005433481182	20488	8	4E
0005433481181	20488	9	4F
0005433481189	20488	10	5A
0005433481164	20488	11	5C
0005434158993	20488	12	5F
0005433507050	20488	13	6D
0005432920035	20488	14	6F
0005433481184	20488	15	8A
0005432920034	20488	16	8C
0005432920032	20488	17	8D
0005432920021	20488	18	9A
0005433507184	20488	19	9C
0005433507181	20488	20	10C
0005433507188	20488	21	10F
0005432920019	20488	22	11C
0005433507164	20488	23	11D
0005432920037	20488	24	11E
0005433481155	20488	25	12A
0005433481183	20488	26	12F
0005433507207	20488	27	13C
0005433481173	20488	28	13D
0005434158990	20488	29	13E
0005433481156	20488	30	14D
0005433507163	20488	31	14F
0005432920026	20488	32	15A
0005432920036	20488	33	15C
0005433507185	20488	34	15D
0005432920024	20488	35	15F
0005432920025	20488	36	16A
0005433507223	20488	37	16D
0005432920022	20488	38	16E
0005432920029	20488	39	16F
0005434158991	20488	40	17A
0005432920031	20488	41	17C
0005433507176	20488	42	17D
0005433481147	20488	43	17F
0005432920018	20488	44	19A
0005432920023	20488	45	19C
0005433481179	20488	46	19D
0005432920030	20488	47	19E
0005433507074	20488	48	20A
0005435179691	10161	1	1A
0005432396269	10161	2	2B
0005432394129	10161	3	3A
0005432396270	10161	4	4A
0005432396267	10161	5	4B
0005432396268	10161	6	5A
0005432394128	10161	7	5B
0005432394130	10161	8	6A
0005435178989	10161	9	6B
0005432400118	18368	1	1A
0005432400120	18368	2	2B
0005432396243	18368	3	3A
0005435179401	18368	4	3B
0005432400121	18368	5	4B
0005432396239	18368	6	5A
0005435179400	18368	7	5B
0005432400110	18368	8	6A
0005432400114	18368	9	6B
0005435626100	10983	1	1A
0005435126127	10983	2	1C
0005435126382	10983	3	1D
0005435626092	10983	4	1F
0005435626094	10983	5	2A
0005435126128	10983	6	2C
0005435126355	10983	7	2F
0005435126551	10983	8	3A
0005434928319	10983	9	3C
0005434411808	10983	10	3D
0005435626098	10983	11	3F
0005435126383	10983	12	4A
0005434411807	10983	13	4C
0005435554173	10983	14	4E
0005435626095	10983	15	4F
0005435126171	10983	16	5A
0005435626101	10983	17	5C
0005435126401	10983	18	5D
0005435126284	10983	19	5E
0005435126158	10983	20	5F
0005435126239	10983	21	6A
0005435126236	10983	22	6C
0005435554162	10983	23	6D
0005435626106	10983	24	6E
0005435126299	10983	25	6F
0005435126315	10983	26	7C
0005435626049	10983	27	7D
0005434928321	10983	28	7F
0005435126208	10983	29	8C
0005435126317	10983	30	8D
0005435126257	10983	31	8E
0005435126440	10983	32	9A
0005435126442	10983	33	9C
0005435626074	10983	34	9D
0005435626099	10983	35	9E
0005435126153	10983	36	9F
0005435626109	10983	37	10A
0005435126316	10983	38	10D
0005435126219	10983	39	10E
0005435626056	10983	40	10F
0005435126289	10983	41	11C
0005434411809	10983	42	11D
0005435626070	10983	43	11F
0005435556681	10983	44	12A
0005434411810	10983	45	12D
0005434411811	10983	46	12E
0005435626114	10983	47	12F
0005435126298	10983	48	13A
0005435554178	10983	49	13D
0005435126237	10983	50	13E
0005435126235	10983	51	13F
0005435554161	10983	52	14A
0005434928320	10983	53	14C
0005435556698	10983	54	14E
0005435626080	10983	55	14F
0005435554163	10983	56	15A
0005435556680	10983	57	15C
0005435126400	10983	58	15D
0005435126162	10983	59	15E
0005435126243	10983	60	16A
0005435126357	10983	61	16C
0005435626075	10983	62	16D
0005435126297	10983	63	16E
0005435126157	10983	64	16F
0005435126356	10983	65	17A
0005435126318	10983	66	17F
0005435626123	10983	67	18D
0005435126152	10983	68	18E
0005435626055	10983	69	18F
0005435126288	10983	70	19A
0005435126314	10983	71	19C
0005435126417	10983	72	19D
0005435626091	10983	73	19E
0005435126125	10983	74	19F
0005435126172	10983	75	20C
0005435126300	10983	76	20D
0005435126679	14701	1	1A
0005435126685	14701	2	1C
0005435126668	14701	3	1D
0005435554219	14701	4	1F
0005435626312	14701	5	2A
0005435626309	14701	6	3A
0005435126661	14701	7	3C
0005435126657	14701	8	3D
0005435126656	14701	9	3F
0005434411773	14701	10	4A
0005435126667	14701	11	4C
0005435126669	14701	12	4E
0005435626311	14701	13	5A
0005435626306	14701	14	5C
0005435126676	14701	15	5D
0005435554220	14701	16	5F
0005435126646	14701	17	6A
0005435126670	14701	18	6C
0005435126666	14701	19	6D
0005435126648	14701	20	6E
0005435126652	14701	21	7D
0005435626315	14701	22	7E
0005435126659	14701	23	7F
0005435126686	14701	24	8A
0005435126678	14701	25	8C
0005435556710	14701	26	8D
0005435126649	14701	27	8E
0005435126687	14701	28	8F
0005435126662	14701	29	9C
0005434411772	14701	30	9D
0005435626310	14701	31	9F
0005435626313	14701	32	10C
0005435126674	14701	33	10F
0005435126654	14701	34	11A
0005435126671	14701	35	11D
0005435126681	14701	36	11F
0005434411767	14701	37	12C
0005435126673	14701	38	12E
0005435126665	14701	39	12F
0005435626307	14701	40	13C
0005435126658	14701	41	13D
0005435126680	14701	42	13F
0005435126677	14701	43	14A
0005435126675	14701	44	14C
0005435626314	14701	45	14D
0005435126672	14701	46	15C
0005434411766	14701	47	15D
0005435126651	14701	48	15F
0005435126647	14701	49	16A
0005435126683	14701	50	16D
0005435554221	14701	51	16E
0005435126660	14701	52	16F
0005435126650	14701	53	17C
0005435126684	14701	54	17E
0005435556711	14701	55	17F
0005435126664	14701	56	18A
0005435126655	14701	57	18C
0005435126653	14701	58	18D
0005435554218	14701	59	18F
0005435126682	14701	60	19C
0005435126663	14701	61	20A
0005435626308	14701	62	20D
0005435715594	7109	1	1D
0005435715598	7109	2	2C
0005435443329	7109	3	2D
0005435219193	7109	4	2F
0005432400153	7109	5	3C
0005435443295	7109	6	3F
0005435443290	7109	7	4C
0005435715589	7109	8	4E
0005432398223	7109	9	4F
0005432400154	7109	10	5D
0005435443306	7109	11	6A
0005435715587	7109	12	6C
0005435179394	7109	13	6D
0005432398226	7109	14	7C
0005435179393	7109	15	7D
0005435179392	7109	16	8E
0005435715591	7109	17	9E
0005435715586	7109	18	10A
0005435715585	7109	19	10E
0005435219204	7109	20	11A
0005435715584	7109	21	11F
0005435443313	7109	22	12A
0005432398225	7109	23	12D
0005435443312	7109	24	13A
0005435715582	7109	25	13D
0005432398224	7109	26	13F
0005435715593	7109	27	14C
0005435715599	7109	28	15A
0005435715597	7109	29	15E
0005435715596	7109	30	15F
0005435715590	7109	31	16A
0005435715588	7109	32	16C
0005435216579	7109	33	16D
0005435715592	7109	34	16E
0005435715583	7109	35	17D
0005435216578	7109	36	17E
0005435443281	7109	37	18A
0005435443311	7109	38	18F
0005435715600	7109	39	19D
0005435715595	7109	40	19E
0005435219201	7109	41	20A
0005432400155	7109	42	20C
0005435221052	7109	43	20E
0005435715473	27085	1	1C
0005435443378	27085	2	4C
0005435715438	27085	3	4D
0005432398187	27085	4	5C
0005435715469	27085	5	5D
0005435715378	27085	6	5E
0005435443379	27085	7	6A
0005435715480	27085	8	6D
0005432398186	27085	9	7A
0005432398193	27085	10	7E
0005435715425	27085	11	7F
0005432398192	27085	12	8C
0005435715471	27085	13	8E
0005432394083	27085	14	8F
0005432394088	27085	15	9F
0005435715500	27085	16	11A
0005432398180	27085	17	11F
0005435715468	27085	18	12C
0005435443380	27085	19	12D
0005435715474	27085	20	12F
0005435715479	27085	21	13A
0005435715454	27085	22	13C
0005435715400	27085	23	14A
0005435178504	27085	24	14C
0005435443382	27085	25	14E
0005435443377	27085	26	16A
0005435443384	27085	27	16E
0005435178505	27085	28	17D
0005435715455	27085	29	17F
0005432398195	27085	30	18A
0005435715440	27085	31	18F
0005435715486	27085	32	19C
0005435715439	27085	33	19D
0005435443385	27085	34	19E
0005435443381	27085	35	20A
0005435443383	27085	36	20D
0005432394101	27085	37	20F
0005434084964	2731	1	1A
0005434084962	2731	2	2A
0005434084963	2731	3	1B
0005433060413	2731	4	2B
0005434084961	2731	5	3B
0005433060415	2731	6	4A
0005433060412	2731	7	5A
0005434084965	2731	8	5B
0005434084966	2731	9	6A
0005433060404	2731	10	6B
0005434084940	28511	1	2B
0005432632759	25191	1	1A
0005432632778	25191	2	1B
0005435844288	25191	3	1C
0005432632755	25191	4	1D
0005432632768	25191	5	2A
0005435844285	25191	6	2B
0005432632769	25191	7	2C
0005435844298	25191	8	2D
0005435844296	25191	9	3A
0005432632781	25191	10	3B
0005432632763	25191	11	3C
0005435844299	25191	12	3D
0005432632774	25191	13	4A
0005435844308	25191	14	4B
0005432632761	25191	15	4C
0005435844300	25191	16	4D
0005435844297	25191	17	5B
0005432632762	25191	18	5C
0005432632757	25191	19	5D
0005432632758	25191	20	6A
0005432632779	25191	21	6B
0005432632775	25191	22	6C
0005432632772	25191	23	6D
0005435844289	25191	24	7B
0005435844312	25191	25	7C
0005432632760	25191	26	7D
0005432632771	25191	27	18A
0005435844291	25191	28	18B
0005432632773	25191	29	18C
0005435844301	25191	30	18D
0005432632776	25191	31	19A
0005432632780	25191	32	19B
0005435844303	25191	33	19C
0005432632782	25191	34	19D
0005432632767	25191	35	20A
0005435844309	25191	36	20B
0005432632765	25191	37	20C
0005435844306	25191	38	20D
0005432632766	25191	39	21A
0005435844302	25191	40	21B
0005432632770	25191	41	21C
0005435844311	25191	42	21D
0005432632756	25191	43	22A
0005432632777	25191	44	22C
0005435844307	25191	45	22D
0005432632764	25191	46	23A
0005435844295	25191	47	23B
0005432632709	28166	1	1A
0005432632706	28166	2	1B
0005435844349	28166	3	1C
0005432632730	28166	4	1D
0005432632691	28166	5	2A
0005432632684	28166	6	2B
0005435844338	28166	7	2C
0005432632701	28166	8	2D
0005435844342	28166	9	3A
0005435844347	28166	10	3B
0005432632729	28166	11	3C
0005432632692	28166	12	3D
0005432632657	28166	13	4A
0005432632722	28166	14	4B
0005432632693	28166	15	4D
0005432632728	28166	16	4C
0005432632711	28166	17	5A
0005432632664	28166	18	5B
0005432632719	28166	19	5C
0005435844340	28166	20	5D
0005432632723	28166	21	6A
0005432632688	28166	22	6B
0005432632734	28166	23	6C
0005432632708	28166	24	6D
0005432632725	28166	25	7A
0005432632678	28166	26	7B
0005435844339	28166	27	7C
0005435844343	28166	28	7D
0005435844344	28166	29	18A
0005432632710	28166	30	18B
0005432632700	28166	31	18C
0005435844348	28166	32	19A
0005435844341	28166	33	19B
0005432632689	28166	34	19C
0005435844346	28166	35	19D
0005432632687	28166	36	20A
0005432632704	28166	37	20B
0005435844345	28166	38	20C
0005432632690	28166	39	20D
0005432632718	28166	40	21A
0005432632702	28166	41	21B
0005432632703	28166	42	21C
0005432632712	28166	43	21D
0005432632732	28166	44	22A
0005432632697	28166	45	22B
0005432632679	28166	46	22C
0005432632705	28166	47	22D
0005432632677	28166	48	23A
0005432632707	28166	49	23B
0005435517880	11402	1	1F
0005435540977	11402	2	2A
0005435540858	11402	3	2C
0005435517864	11402	4	2D
0005435517825	11402	5	3A
0005435517863	11402	6	3C
0005435540976	11402	7	4D
0005435540988	11402	8	4E
0005435541041	11402	9	4F
0005435540985	11402	10	5A
0005435517871	11402	11	5C
0005435541004	11402	12	5E
0005435517968	11402	13	6A
0005435541014	11402	14	9C
0005435540962	11402	15	9E
0005435541059	11402	16	9F
0005435540961	11402	17	10E
0005435541006	11402	18	11C
0005435517817	11402	19	11D
0005435517896	11402	20	12D
0005435540831	11402	21	12E
0005435517969	11402	22	14D
0005435540984	11402	23	14E
0005435540958	11402	24	14F
0005435540942	11402	25	15C
0005435517849	11402	26	15D
0005435517837	11402	27	15E
0005435541023	11402	28	15F
0005435540959	11402	29	16D
0005435540859	11402	30	17A
0005435541015	11402	31	17D
0005435517901	11402	32	17F
0005435517897	11402	33	19A
0005435540990	11402	34	19D
0005435540989	11402	35	19E
0005435517894	11402	36	20A
0005435517895	11402	37	20C
0005435540981	11402	38	20E
0005432294503	22254	1	1A
0005435541136	22254	2	1C
0005435529402	22254	3	1F
0005435541152	22254	4	2D
0005435529398	22254	5	3A
0005435529391	22254	6	3C
0005435541138	22254	7	4C
0005435541143	22254	8	4D
0005435541140	22254	9	5C
0005435529406	22254	10	5D
0005435529399	22254	11	5F
0005435529388	22254	12	6C
0005435541135	22254	13	7A
0005435541153	22254	14	7D
0005435541151	22254	15	8A
0005435529397	22254	16	8D
0005435529408	22254	17	9A
0005435541148	22254	18	9C
0005435529401	22254	19	9F
0005435541139	22254	20	10A
0005435529394	22254	21	10D
0005435529389	22254	22	10E
0005435541145	22254	23	10F
0005435529392	22254	24	11C
0005435529403	22254	25	12A
0005435529396	22254	26	12C
0005435541134	22254	27	12D
0005435541133	22254	28	12E
0005435541132	22254	29	13A
0005432294502	22254	30	13D
0005435529400	22254	31	13E
0005435541147	22254	32	14C
0005435541141	22254	33	14D
0005435529393	22254	34	14E
0005435529405	22254	35	14F
0005435529407	22254	36	15D
0005435529404	22254	37	15F
0005435529409	22254	38	16E
0005435541149	22254	39	17A
0005435541150	22254	40	17E
0005435541137	22254	41	18A
0005435541142	22254	42	18D
0005435541146	22254	43	19D
0005435529390	22254	44	19E
0005435541144	22254	45	19F
0005435529395	22254	46	20D
0005435529410	22254	47	20F
0005434907677	2281	1	1A
0005434907689	2281	2	1C
0005434907696	2281	3	1D
0005433400986	2281	4	1F
0005433251450	2281	5	2A
0005433251442	2281	6	2C
0005434907673	2281	7	2D
0005433251526	2281	8	2F
0005434907659	2281	9	3A
0005434907690	2281	10	3C
0005433251441	2281	11	3D
0005434907695	2281	12	3F
0005434907691	2281	13	4A
0005434907661	2281	14	4C
0005434907694	2281	15	4D
0005433251525	2281	16	4E
0005433251459	2281	17	4F
0005434907706	2281	18	5A
0005433251448	2281	19	5C
0005434907668	2281	20	5D
0005433251464	2281	21	5E
0005433400985	2281	22	5F
0005433251572	2281	23	6A
0005433251540	2281	24	6D
0005433251412	2281	25	6E
0005433251352	2281	26	6F
0005433251445	2281	27	7A
0005434907662	2281	28	7C
0005434907692	2281	29	7D
0005433251413	2281	30	7E
0005434907670	2281	31	7F
0005433251527	2281	32	8A
0005434907702	2281	33	8C
0005433251467	2281	34	8D
0005434907688	2281	35	8E
0005433251343	2281	36	8F
0005433251247	2281	37	9A
0005434907672	2281	38	9C
0005434907699	2281	39	9D
0005433251465	2281	40	9E
0005433251495	2281	41	9F
0005434907683	2281	42	10A
0005434907693	2281	43	10C
0005434907680	2281	44	10D
0005434907681	2281	45	10E
0005434907665	2281	46	11A
0005434907701	2281	47	11D
0005434907686	2281	48	11C
0005433251443	2281	49	11E
0005434907674	2281	50	11F
0005434907682	2281	51	12C
0005434907675	2281	52	12D
0005433251381	2281	53	12E
0005433251487	2281	54	12F
0005434907687	2281	55	13A
0005434907654	2281	56	13D
0005433251485	2281	57	13E
0005434907660	2281	58	13F
0005433251524	2281	59	14A
0005434907685	2281	60	14C
0005434907657	2281	61	14D
0005434907664	2281	62	14E
0005434907658	2281	63	14F
0005434907700	2281	64	15A
0005434907698	2281	65	15C
0005433251320	2281	66	15D
0005433251506	2281	67	15E
0005433251470	2281	68	16A
0005433251458	2281	69	16C
0005433251469	2281	70	16D
0005433251494	2281	71	16E
0005434907666	2281	72	16F
0005434907669	2281	73	17A
0005434907697	2281	74	17C
0005434907667	2281	75	17D
0005434907676	2281	76	17E
0005434907705	2281	77	17F
0005434907656	2281	78	18A
0005434907663	2281	79	18C
0005433251395	2281	80	18D
0005434907679	2281	81	18E
0005434907684	2281	82	18F
0005434907704	2281	83	19C
0005434907703	2281	84	19D
0005434907678	2281	85	19E
0005433251463	2281	86	19F
0005433251468	2281	87	20A
0005434907655	2281	88	20C
0005434907671	2281	89	20E
0005433251589	2281	90	20F
0005433251709	25604	1	1A
0005433251710	25604	2	1C
0005433251698	25604	3	1D
0005434907059	25604	4	1F
0005433251689	25604	5	2A
0005434907193	25604	6	2D
0005434907189	25604	7	2F
0005433251687	25604	8	3C
0005434907111	25604	9	3D
0005433251715	25604	10	3F
0005434906951	25604	11	4A
0005434907162	25604	12	4C
0005434907262	25604	13	4D
0005434906874	25604	14	4E
0005434907247	25604	15	4F
0005434907254	25604	16	5A
0005433251717	25604	17	5C
0005433251708	25604	18	5E
0005433251703	25604	19	5F
0005433251699	25604	20	6A
0005433251691	25604	21	6D
0005433251712	25604	22	6E
0005433251688	25604	23	6F
0005433251692	25604	24	7A
0005433251707	25604	25	7C
0005433251704	25604	26	7D
0005433251694	25604	27	7E
0005434907200	25604	28	7F
0005433401006	25604	29	8A
0005433251711	25604	30	8D
0005433251705	25604	31	8E
0005434906992	25604	32	8F
0005433401007	25604	33	9A
0005434907184	25604	34	9C
0005434907126	25604	35	9D
0005434906945	25604	36	9E
0005433401005	25604	37	9F
0005434907196	25604	38	10A
0005434907218	25604	39	10C
0005434907190	25604	40	10D
0005434907326	25604	41	10E
0005433251716	25604	42	10F
0005434907452	25604	43	11A
0005433251695	25604	44	11C
0005434907137	25604	45	11D
0005434907161	25604	46	11E
0005434907185	25604	47	11F
0005434906991	25604	48	12C
0005434907352	25604	49	12E
0005433251701	25604	50	12F
0005433251686	25604	51	13A
0005434907187	25604	52	13C
0005434907122	25604	53	13D
0005434907155	25604	54	13F
0005434907186	25604	55	14A
0005434907365	25604	56	14C
0005434907147	25604	57	14D
0005434907144	25604	58	14E
0005434907219	25604	59	14F
0005433251700	25604	60	15A
0005433251696	25604	61	15C
0005433251702	25604	62	15D
0005434907127	25604	63	15E
0005434906952	25604	64	15F
0005433251706	25604	65	16A
0005434907188	25604	66	16C
0005434907325	25604	67	16D
0005434907207	25604	68	16E
0005433251713	25604	69	17A
0005433251697	25604	70	17C
0005434907062	25604	71	17D
0005433251714	25604	72	17E
0005434907295	25604	73	17F
0005434907131	25604	74	18A
0005434907354	25604	75	18C
0005434907453	25604	76	18D
0005433251690	25604	77	18F
0005434907353	25604	78	19A
0005434907215	25604	79	19C
0005434907158	25604	80	19D
0005433251693	25604	81	19E
0005434907273	25604	82	19F
0005434907208	25604	83	20A
0005434906956	25604	84	20C
0005434907246	25604	85	20D
0005434907157	25604	86	20E
0005434907172	25604	87	20F
0005432862269	2515	1	1B
0005432862268	2515	2	2A
0005432862281	2515	3	2B
0005432621136	2515	4	2D
0005432621141	2515	5	3A
0005432621147	2515	6	3B
0005432621146	2515	7	3C
0005432862277	2515	8	5B
0005432621145	2515	9	5D
0005432862305	2515	10	6A
0005432621135	2515	11	7B
0005432621133	2515	12	18C
0005432621137	2515	13	19A
0005432621138	2515	14	19B
0005432621134	2515	15	19D
0005432621144	2515	16	20B
0005432862283	2515	17	20D
0005432862284	2515	18	21B
0005432621143	2515	19	21C
0005432621140	2515	20	21D
0005432862285	2515	21	22A
0005432621142	2515	22	22B
0005432621139	2515	23	22C
0005432862282	2515	24	23B
0005432621027	28063	1	1A
0005432862362	28063	2	3A
0005432862357	28063	3	3C
0005432862355	28063	4	4C
0005432620995	28063	5	4D
0005432621017	28063	6	5A
0005432621007	28063	7	5B
0005432621028	28063	8	5C
0005432620994	28063	9	5D
0005432862354	28063	10	6B
0005432621045	28063	11	7A
0005432621008	28063	12	7C
0005432621016	28063	13	7B
0005432621026	28063	14	7D
0005432621023	28063	15	18A
0005432862359	28063	16	18B
0005432621050	28063	17	18C
0005432862360	28063	18	19B
0005432862361	28063	19	19D
0005432862356	28063	20	20B
0005432620979	28063	21	20D
0005432620997	28063	22	21A
0005432862358	28063	23	21B
0005432621020	28063	24	21D
0005432620996	28063	25	22C
0005432621018	28063	26	22D
0005432621019	28063	27	23B
0005434097476	11763	1	1B
0005434097469	11763	2	6B
0005434097486	13033	1	2B
0005433452754	31063	1	2A
0005433452753	31063	2	3A
0005433451635	31063	3	5B
0005433451633	31063	4	6A
0005433451634	31063	5	6B
0005433454876	31437	1	1A
0005433452735	31437	2	5A
0005433454870	31437	3	6B
0005434142594	12032	1	1C
0005434184657	12032	2	1B
0005434184658	12032	3	2D
0005433129280	12032	4	4A
0005434184667	12032	5	4B
0005433134147	12032	6	18A
0005433129266	12032	7	18C
0005433134125	12032	8	19B
0005433134124	12032	9	20D
0005433129256	12032	10	22C
0005434184652	12032	11	22D
0005434183595	29828	1	1B
0005433134169	29828	2	1D
0005433131742	29828	3	2A
0005434142636	29828	4	2C
0005433134172	29828	5	2D
0005434142635	29828	6	3A
0005434142638	29828	7	3D
0005433131741	29828	8	4B
0005434184681	29828	9	5B
0005434142637	29828	10	6A
0005434142639	29828	11	19A
0005434326268	29828	12	19C
0005433131739	29828	13	19D
0005433134170	29828	14	20A
0005434184679	29828	15	20D
0005433134171	29828	16	21B
0005434183593	29828	17	22A
0005434184680	29828	18	22D
0005434183594	29828	19	22C
0005434326269	29828	20	23A
0005433131740	29828	21	23B
0005435697511	16483	1	1A
0005435697508	16483	2	1C
0005435697525	16483	3	1D
0005435697518	16483	4	2B
0005435697506	16483	5	3A
0005435697521	16483	6	3B
0005435697531	16483	7	3C
0005435697510	16483	8	4A
0005435697513	16483	9	4B
0005435935054	16483	10	4C
0005435697515	16483	11	4D
0005435697519	16483	12	5B
0005435697529	16483	13	6B
0005435697514	16483	14	6D
0005435935042	16483	15	7A
0005435697523	16483	16	7B
0005435697517	16483	17	7D
0005435697520	16483	18	18A
0005435697526	16483	19	18B
0005435697504	16483	20	18D
0005435697530	16483	21	19A
0005435935047	16483	22	19B
0005435697527	16483	23	19D
0005435697516	16483	24	20A
0005435697512	16483	25	20B
0005435697524	16483	26	20D
0005435697522	16483	27	21B
0005435697507	16483	28	21D
0005435697505	16483	29	22A
0005435697509	16483	30	22B
0005435697528	16483	31	23B
0005435697258	24723	1	1A
0005435697358	24723	2	1B
0005435697289	24723	3	1C
0005435697259	24723	4	1D
0005435697332	24723	5	2A
0005435697250	24723	6	2B
0005435697290	24723	7	2C
0005435697340	24723	8	2D
0005435697249	24723	9	3A
0005435697288	24723	10	3B
0005435935066	24723	11	3C
0005435697297	24723	12	3D
0005435697314	24723	13	4A
0005435697321	24723	14	5D
0005435697312	24723	15	6C
0005435697369	24723	16	7B
0005435697409	24723	17	7C
0005435697296	24723	18	18B
0005435697322	24723	19	18C
0005435697355	24723	20	18D
0005435935065	24723	21	19B
0005435697241	24723	22	19C
0005435697354	24723	23	19D
0005435935068	24723	24	20A
0005435697295	24723	25	20C
0005435697347	24723	26	20D
0005435697316	24723	27	21A
0005435697226	24723	28	21B
0005435697217	24723	29	21D
0005435697248	24723	30	22A
0005435697300	24723	31	22C
0005435697311	24723	32	22D
0005435935067	24723	33	23A
0005433724833	18776	1	1B
0005433724835	18776	2	2B
0005433724832	18776	3	4A
0005433724831	18776	4	4B
0005433724834	18776	5	5A
0005432968837	18776	6	6A
0005433724799	21610	1	1A
0005432968859	21610	2	1B
0005433724824	21610	3	2A
0005433724796	21610	4	3A
0005433724788	21610	5	3B
0005433724797	21610	6	4A
0005433724811	21610	7	4B
0005433724798	21610	8	5A
0005433724810	21610	9	5B
0005433724825	21610	10	6A
0005432968858	21610	11	6B
0005434138786	7302	1	1A
0005434138784	7302	2	1C
0005434138755	7302	3	1D
0005434138768	7302	4	1F
0005434138763	7302	5	2A
0005434138753	7302	6	2C
0005434138792	7302	7	2D
0005434138734	7302	8	2F
0005434138756	7302	9	3A
0005434138732	7302	10	3C
0005434138773	7302	11	3D
0005434138805	7302	12	3F
0005434138748	7302	13	4A
0005434138775	7302	14	4C
0005434138766	7302	15	4D
0005434138776	7302	16	4E
0005434138721	7302	17	5A
0005434138789	7302	18	4F
0005434138800	7302	19	5C
0005434138790	7302	20	5E
0005434138728	7302	21	5F
0005434138799	7302	22	6A
0005434087548	7302	23	6C
0005434138739	7302	24	6D
0005434138761	7302	25	6E
0005434138730	7302	26	6F
0005434138778	7302	27	7A
0005434138779	7302	28	7C
0005434138791	7302	29	7D
0005434138787	7302	30	7E
0005434138797	7302	31	7F
0005434138744	7302	32	8A
0005434138741	7302	33	8C
0005434138723	7302	34	8D
0005434138788	7302	35	8E
0005434138758	7302	36	8F
0005434138757	7302	37	9A
0005434138733	7302	38	9C
0005434087551	7302	39	9D
0005434138747	7302	40	9E
0005434138742	7302	41	9F
0005434138781	7302	42	10A
0005434138736	7302	43	10C
0005434138735	7302	44	10D
0005434138774	7302	45	10E
0005434138719	7302	46	10F
0005434138731	7302	47	11A
0005434138740	7302	48	11C
0005434138803	7302	49	11D
0005434138724	7302	50	11E
0005434138760	7302	51	11F
0005434138722	7302	52	12A
0005434138777	7302	53	12C
0005434138751	7302	54	12D
0005434138750	7302	55	12E
0005434138795	7302	56	12F
0005434138806	7302	57	13A
0005434138798	7302	58	13C
0005434138716	7302	59	13D
0005434138801	7302	60	13E
0005434138769	7302	61	13F
0005434138794	7302	62	14A
0005434138737	7302	63	14C
0005434138765	7302	64	14D
0005434087550	7302	65	14E
0005434138802	7302	66	14F
0005434138793	7302	67	15A
0005434138759	7302	68	15C
0005434087547	7302	69	15D
0005434138752	7302	70	15E
0005434087549	7302	71	15F
0005434138780	7302	72	16A
0005434138796	7302	73	16C
0005434138749	7302	74	16D
0005434138754	7302	75	16E
0005434138785	7302	76	16F
0005434138804	7302	77	17A
0005434138767	7302	78	17D
0005434138718	7302	79	17C
0005434138743	7302	80	17E
0005434138746	7302	81	17F
0005434138764	7302	82	18A
0005434138720	7302	83	18C
0005434138726	7302	84	18D
0005434138717	7302	85	18E
0005434138738	7302	86	18F
0005434138772	7302	87	19A
0005434138771	7302	88	19C
0005434138725	7302	89	19D
0005434138745	7302	90	19E
0005434138770	7302	91	19F
0005434138783	7302	92	20A
0005434138762	7302	93	20C
0005434138727	7302	94	20D
0005434138729	7302	95	20E
0005434138782	7302	96	20F
0005434137956	28549	1	1A
0005434138217	28549	2	1C
0005434138241	28549	3	1D
0005434137746	28549	4	1F
0005434137982	28549	5	2A
0005434137701	28549	6	2C
0005434137937	28549	7	2D
0005434138170	28549	8	3A
0005434087528	28549	9	3C
0005434138051	28549	10	3D
0005434138147	28549	11	3F
0005434137980	28549	12	4A
0005434138171	28549	13	4C
0005434137828	28549	14	4D
0005434137749	28549	15	4E
0005434138129	28549	16	4F
0005434137820	28549	17	5A
0005434087498	28549	18	5C
0005434137775	28549	19	5D
0005434138004	28549	20	5E
0005434137806	28549	21	5F
0005434138146	28549	22	6A
0005434137666	28549	23	6C
0005434137938	28549	24	6D
0005434137810	28549	25	6E
0005434137593	28549	26	6F
0005434137950	28549	27	7A
0005434137897	28549	28	7C
0005434138178	28549	29	7D
0005434137790	28549	30	7E
0005434138115	28549	31	7F
0005434138175	28549	32	8A
0005434138174	28549	33	8C
0005434138067	28549	34	8D
0005434137884	28549	35	8E
0005434137907	28549	36	8F
0005434138057	28549	37	9A
0005434138246	28549	38	9C
0005434137826	28549	39	9D
0005434137772	28549	40	9E
0005434137861	28549	41	9F
0005434137838	28549	42	10A
0005434138260	28549	43	10C
0005434137604	28549	44	10D
0005434138329	28549	45	10E
0005434137927	28549	46	10F
0005434137864	28549	47	11A
0005434137728	28549	48	11C
0005434138005	28549	49	11D
0005434137821	28549	50	11E
0005434137844	28549	51	12A
0005434137945	28549	52	12C
0005434137928	28549	53	12D
0005434137979	28549	54	12E
0005434138022	28549	55	12F
0005434087514	28549	56	13A
0005434137991	28549	57	13C
0005434137973	28549	58	13D
0005434087513	28549	59	13E
0005434137914	28549	60	13F
0005434138327	28549	61	14A
0005434137750	28549	62	14C
0005434138120	28549	63	14D
0005434137913	28549	64	14E
0005434137700	28549	65	14F
0005434137955	28549	66	15A
0005434137574	28549	67	15C
0005434137832	28549	68	15D
0005434138058	28549	69	15E
0005434137774	28549	70	15F
0005434137946	28549	71	16A
0005434137811	28549	72	16C
0005434087499	28549	73	16D
0005434137770	28549	74	16F
0005434137819	28549	75	17A
0005434138038	28549	76	17C
0005434138177	28549	77	17D
0005434137943	28549	78	17E
0005434137833	28549	79	17F
0005434137942	28549	80	18A
0005434138066	28549	81	18C
0005434137793	28549	82	18D
0005434137887	28549	83	18E
0005434138070	28549	84	18F
0005434138123	28549	85	19A
0005434138024	28549	86	19C
0005434137765	28549	87	19D
0005434137888	28549	88	19E
0005434137908	28549	89	19F
0005434137909	28549	90	20A
0005434137702	28549	91	20C
0005434137935	28549	92	20D
0005435808309	1937	1	1A
0005435808311	1937	2	1B
0005433407546	1937	3	2A
0005433407554	1937	4	2C
0005433407540	1937	5	3C
0005435808310	1937	6	4B
0005433407551	1937	7	5A
0005433407545	1937	8	6C
0005435808314	1937	9	7B
0005434610256	1937	10	7C
0005435808308	1937	11	7D
0005435808305	1937	12	18A
0005435808312	1937	13	19A
0005434610255	1937	14	19D
0005435808306	1937	15	20C
0005435808313	1937	16	20D
0005433407539	1937	17	21B
0005435808307	1937	18	21C
0005435808315	1937	19	22C
0005433407552	1937	20	22D
0005435808211	23100	1	1A
0005435808144	23100	2	1D
0005433407600	23100	3	2A
0005434610227	23100	4	2B
0005433407595	23100	5	2C
0005434610218	23100	6	3A
0005435808176	23100	7	3B
0005435808186	23100	8	3C
0005434610232	23100	9	3D
0005435808191	23100	10	4A
0005435808162	23100	11	4B
0005435808141	23100	12	4C
0005435808210	23100	13	4D
0005435808209	23100	14	5A
0005433407594	23100	15	5B
0005435808184	23100	16	5D
0005435808153	23100	17	6A
0005434610211	23100	18	6B
0005435808136	23100	19	6D
0005435808230	23100	20	7B
0005435808140	23100	21	7C
0005435808183	23100	22	18A
0005434610230	23100	23	18B
0005435808261	23100	24	18D
0005435808192	23100	25	19A
0005435808208	23100	26	19B
0005434610226	23100	27	19C
0005433407593	23100	28	20A
0005433407596	23100	29	20B
0005433407597	23100	30	20C
0005433407598	23100	31	20D
0005433407592	23100	32	21A
0005435808166	23100	33	21B
0005434610229	23100	34	21C
0005435808167	23100	35	22A
0005435808185	23100	36	22B
0005435808229	23100	37	22C
0005435808181	23100	38	22D
0005435808260	23100	39	23A
0005433407599	23100	40	23B
0005434504147	16689	1	1B
0005434504135	16689	2	2A
0005434503960	16689	3	2B
0005434504139	16689	4	2C
0005434504097	16689	5	3A
0005434503959	16689	6	3B
0005434503870	16689	7	3C
0005434504076	16689	8	3D
0005434504001	16689	9	4A
0005434503978	16689	10	5B
0005434504074	16689	11	5C
0005434503910	16689	12	5D
0005434503974	16689	13	6B
0005434504140	16689	14	7A
0005434504110	16689	15	7D
0005434504016	16689	16	18A
0005434503871	16689	17	18B
0005434504004	16689	18	18D
0005434504156	16689	19	18C
0005434504066	16689	20	19A
0005434504134	16689	21	19B
0005434504149	16689	22	20A
0005434504163	16689	23	19D
0005434504119	16689	24	20B
0005434504109	16689	25	20C
0005434504008	16689	26	20D
0005434503911	16689	27	21B
0005434503975	16689	28	21A
0005434503979	16689	29	21C
0005434504188	16689	30	21D
0005434504061	16689	31	22B
0005434504148	16689	32	22D
0005434504065	16689	33	23A
0005434504416	22924	1	1A
0005434504404	22924	2	1B
0005434504389	22924	3	1C
0005434504414	22924	4	1D
0005434504402	22924	5	2A
0005434504422	22924	6	2B
0005434504398	22924	7	2C
0005434504391	22924	8	2D
0005434504395	22924	9	3A
0005434504392	22924	10	3B
0005434504390	22924	11	3C
0005434504408	22924	12	4A
0005434504385	22924	13	4B
0005434504406	22924	14	5B
0005434504400	22924	15	5C
0005434504420	22924	16	5D
0005434504393	22924	17	6A
0005434504419	22924	18	6B
0005434504413	22924	19	6C
0005434504403	22924	20	6D
0005434504421	22924	21	7A
0005434504388	22924	22	7B
0005434504409	22924	23	7C
0005434504418	22924	24	7D
0005434504412	22924	25	18A
0005434504399	22924	26	18B
0005434504411	22924	27	18C
0005434504397	22924	28	18D
0005434504396	22924	29	19A
0005434504417	22924	30	19D
0005434504410	22924	31	20A
0005434504394	22924	32	20B
0005434504415	22924	33	20D
0005434504383	22924	34	21A
0005434504407	22924	35	21C
0005434504386	22924	36	21D
0005434504423	22924	37	22A
0005434504384	22924	38	22B
0005434504405	22924	39	22C
0005434504387	22924	40	22D
0005434504401	22924	41	23B
0005433266693	2204	1	1A
0005435078453	2204	2	1C
0005433266698	2204	3	2B
0005433266725	2204	4	3A
0005433266700	2204	5	3B
0005435078446	2204	6	4C
0005433266694	2204	7	4D
0005435078457	2204	8	5C
0005435078461	2204	9	6A
0005435078451	2204	10	6B
0005435078454	2204	11	7C
0005435078452	2204	12	7D
0005435078459	2204	13	18A
0005435078447	2204	14	18B
0005435078450	2204	15	18D
0005433266661	2204	16	19B
0005435078460	2204	17	19C
0005435078456	2204	18	20A
0005433266762	2204	19	20D
0005435078458	2204	20	21C
0005433266699	2204	21	22A
0005433266726	2204	22	22B
0005435078448	2204	23	22C
0005435078449	2204	24	23A
0005435078455	2204	25	23B
0005435078264	24370	1	1A
0005435078340	24370	2	2B
0005433266789	24370	3	3A
0005433266788	24370	4	3C
0005435078364	24370	5	3D
0005433266792	24370	6	4A
0005435078339	24370	7	4D
0005433266786	24370	8	5A
0005433266787	24370	9	5B
0005435078265	24370	10	5C
0005433266791	24370	11	5D
0005435078336	24370	12	6D
0005435078284	24370	13	7A
0005435078272	24370	14	7B
0005435078350	24370	15	18B
0005435078314	24370	16	18A
0005435078312	24370	17	18C
0005435078311	24370	18	18D
0005433266790	24370	19	19A
0005435078352	24370	20	20D
0005435078324	24370	21	21C
0005435078281	24370	22	21D
0005435078365	24370	23	22A
0005433266793	24370	24	22C
0005433266794	24370	25	22D
0005434988817	6623	1	1B
0005435803284	6623	2	1D
0005434988820	6623	3	2D
0005434988816	6623	4	3A
0005434988815	6623	5	5C
0005434988812	6623	6	6A
0005435464499	6623	7	7C
0005435464507	6623	8	18A
0005434988819	6623	9	18C
0005435803283	6623	10	19B
0005434988814	6623	11	19D
0005435464508	6623	12	20A
0005435464500	6623	13	20B
0005434988818	6623	14	20D
0005435464506	6623	15	21B
0005434988813	6623	16	22A
0005435803285	6623	17	23B
0005434988653	23591	1	1B
0005435803250	23591	2	1C
0005435803238	23591	3	1D
0005434988687	23591	4	2B
0005434988668	23591	5	2C
0005434988688	23591	6	3B
0005435803268	23591	7	4A
0005435803266	23591	8	4C
0005434988657	23591	9	6A
0005435803260	23591	10	6C
0005434988690	23591	11	7C
0005435803253	23591	12	7D
0005434988681	23591	13	18A
0005435803251	23591	14	18B
0005435464523	23591	15	19D
0005435803239	23591	16	20A
0005435464522	23591	17	20B
0005434988682	23591	18	21C
0005435803265	23591	19	22B
0005434988680	23591	20	22D
0005435464521	23591	21	23B
0005433450125	30479	1	1D
0005433450120	30479	2	1F
0005432383472	30479	3	2A
0005432383470	30479	4	2F
0005432383484	30479	5	3A
0005433450121	30479	6	3C
0005432383464	30479	7	3D
0005433450136	30479	8	4C
0005432383456	30479	9	4E
0005432383473	30479	10	5A
0005432383457	30479	11	5C
0005432383453	30479	12	5E
0005432383460	30479	13	5F
0005433450123	30479	14	6A
0005433453774	30479	15	6C
0005433450127	30479	16	6D
0005432383448	30479	17	6E
0005432383486	30479	18	6F
0005432383479	30479	19	7D
0005433450128	30479	20	8A
0005432383482	30479	21	8C
0005433450130	30479	22	8D
0005433450133	30479	23	8E
0005433450135	30479	24	8F
0005433450132	30479	25	9A
0005433450137	30479	26	9D
0005432383465	30479	27	9E
0005433450140	30479	28	10A
0005432383459	30479	29	10C
0005432383447	30479	30	10D
0005432383445	30479	31	10E
0005432383468	30479	32	11A
0005433450139	30479	33	11C
0005432383462	30479	34	11D
0005433450122	30479	35	11F
0005432383466	30479	36	12C
0005432383454	30479	37	12D
0005432383485	30479	38	12E
0005432383481	30479	39	13A
0005433450129	30479	40	13C
0005432383476	30479	41	13D
0005433450131	30479	42	13E
0005432383478	30479	43	13F
0005432383487	30479	44	14C
0005432383461	30479	45	14D
0005432383455	30479	46	14E
0005433450119	30479	47	15A
0005433450134	30479	48	15C
0005432383463	30479	49	15D
0005432383480	30479	50	15E
0005433450124	30479	51	16A
0005433450138	30479	52	16C
0005432383452	30479	53	16D
0005432383458	30479	54	16F
0005432383449	30479	55	17A
0005432383451	30479	56	17C
0005432383444	30479	57	17D
0005432383483	30479	58	17E
0005432383450	30479	59	17F
0005432383471	30479	60	18D
0005432383474	30479	61	18E
0005432383446	30479	62	19A
0005432383469	30479	63	19D
0005432383467	30479	64	19E
0005433453773	30479	65	19F
0005432383477	30479	66	20A
0005432383475	30479	67	20C
0005433450126	30479	68	20D
0005432382904	31292	1	1A
0005432382980	31292	2	1C
0005433449963	31292	3	1D
0005432383086	31292	4	1F
0005432383051	31292	5	2A
0005432383033	31292	6	2D
0005433449998	31292	7	3A
0005432383044	31292	8	3C
0005433449892	31292	9	3D
0005432382992	31292	10	3F
0005433451620	31292	11	5A
0005432383083	31292	12	5C
0005433449954	31292	13	5D
0005433449900	31292	14	6E
0005433449933	31292	15	6F
0005432383019	31292	16	7E
0005433449905	31292	17	7F
0005432383008	31292	18	8D
0005433449962	31292	19	8E
0005432382848	31292	20	8F
0005432383052	31292	21	9A
0005432382942	31292	22	9E
0005433449893	31292	23	9F
0005432383007	31292	24	10C
0005433449968	31292	25	10D
0005432382973	31292	26	10E
0005433450037	31292	27	10F
0005432383009	31292	28	11E
0005432382856	31292	29	12C
0005432383045	31292	30	12E
0005433449961	31292	31	12F
0005432382951	31292	32	13A
0005433449921	31292	33	13C
0005433451617	31292	34	13D
0005432383076	31292	35	13E
0005433451619	31292	36	13F
0005433450044	31292	37	14C
0005432382932	31292	38	14D
0005432383053	31292	39	14E
0005433449976	31292	40	15A
0005432382974	31292	41	15C
0005432382991	31292	42	15D
0005432383018	31292	43	15E
0005432383082	31292	44	15F
0005432382965	31292	45	16A
0005432383030	31292	46	16D
0005432383063	31292	47	16F
0005433449894	31292	48	17A
0005432383000	31292	49	17D
0005432383046	31292	50	17E
0005432383048	31292	51	17F
0005432383006	31292	52	18A
0005433450041	31292	53	18C
0005432383040	31292	54	18D
0005432383078	31292	55	18E
0005432382955	31292	56	18F
0005432383055	31292	57	19D
0005432383039	31292	58	19E
0005432383054	31292	59	19F
0005433453758	31292	60	20A
0005432383020	31292	61	20C
0005432382895	31292	62	20E
0005432382896	31292	63	20F
0005435299780	10790	1	1A
0005433131700	10790	2	1D
0005433126827	10790	3	2C
0005433131699	10790	4	2D
0005433126831	10790	5	3A
0005435299755	10790	6	3D
0005433131686	10790	7	4B
0005433131684	10790	8	4D
0005433131698	10790	9	5A
0005435299778	10790	10	5D
0005433131688	10790	11	6C
0005433126836	10790	12	6D
0005433126828	10790	13	7B
0005435299774	10790	14	7D
0005435299754	10790	15	18B
0005433131685	10790	16	20D
0005433126835	10790	17	21A
0005435299779	10790	18	21B
0005433126846	10790	19	21C
0005433126847	10790	20	21D
0005435304151	10790	21	22C
0005433131687	10790	22	23A
0005433126883	29731	1	1D
0005435302237	29731	2	2A
0005435299813	29731	3	2B
0005435302235	29731	4	2D
0005433129315	29731	5	3A
0005433129312	29731	6	3B
0005435299812	29731	7	3D
0005433129311	29731	8	4B
0005433126884	29731	9	5D
0005435302238	29731	10	6B
0005435299814	29731	11	7C
0005433129313	29731	12	18B
0005433126882	29731	13	18C
0005433126881	29731	14	19A
0005435302236	29731	15	19B
0005435299815	29731	16	20B
0005433126880	29731	17	20C
0005435299816	29731	18	21C
0005433129314	29731	19	21D
0005433110074	2405	1	1A
0005434287450	2405	2	1B
0005433110007	2405	3	1C
0005434287440	2405	4	1D
0005434287448	2405	5	2A
0005434287452	2405	6	2B
0005434287459	2405	7	2C
0005434287461	2405	8	2D
0005434287444	2405	9	3A
0005434287451	2405	10	3C
0005433110048	2405	11	4A
0005434287454	2405	12	4C
0005433110018	2405	13	4D
0005434287449	2405	14	5B
0005433110049	2405	15	5D
0005432264493	2405	16	6A
0005434287443	2405	17	6C
0005433110073	2405	18	6D
0005434287453	2405	19	7B
0005434287455	2405	20	7D
0005434287447	2405	21	18A
0005434287457	2405	22	18C
0005434287441	2405	23	19A
0005432264494	2405	24	19D
0005433110051	2405	25	20B
0005434287456	2405	26	20C
0005434287442	2405	27	20D
0005434287445	2405	28	21A
0005434287460	2405	29	21B
0005434287446	2405	30	21C
0005433110054	2405	31	22A
0005433110055	2405	32	22C
0005432264492	2405	33	22D
0005433110017	2405	34	23A
0005434287458	2405	35	23B
0005433110139	26859	1	1A
0005433110143	26859	2	1B
0005434287259	26859	3	1D
0005433110146	26859	4	2A
0005434287227	26859	5	2B
0005434287228	26859	6	2C
0005434287208	26859	7	2D
0005434287258	26859	8	3A
0005433110145	26859	9	3C
0005434287245	26859	10	3D
0005433110144	26859	11	4A
0005433110136	26859	12	4B
0005433110142	26859	13	4C
0005434287280	26859	14	4D
0005434287193	26859	15	5B
0005434287127	26859	16	5C
0005434287233	26859	17	6A
0005434287250	26859	18	6B
0005434287254	26859	19	6C
0005434287281	26859	20	7C
0005434287237	26859	21	18A
0005434287232	26859	22	18C
0005433110141	26859	23	19B
0005433110140	26859	24	19C
0005433110137	26859	25	20A
0005434287231	26859	26	20B
0005434287251	26859	27	20C
0005434287202	26859	28	20D
0005434287265	26859	29	21A
0005433110138	26859	30	21B
0005434287215	26859	31	21D
0005433110135	26859	32	22A
0005434287190	26859	33	22B
0005434287126	26859	34	22D
0005434287264	26859	35	23A
0005434287226	26859	36	23B
0005434269092	25458	1	1C
0005435856235	25458	2	2B
0005434272183	25458	3	18B
0005434269101	25458	4	18C
0005435856234	25458	5	20B
0005435856233	25458	6	22C
0005435856236	25458	7	23B
0005434273089	26643	1	2A
0005435856189	26643	2	3B
0005435854056	26643	3	4C
0005435856200	26643	4	6D
0005435856188	26643	5	7A
0005434273090	26643	6	18B
0005435856184	26643	7	19C
0005435854055	26643	8	19D
0005434273088	26643	9	20B
0005434272204	26643	10	21A
0005435854058	26643	11	21D
0005435856201	26643	12	22B
0005435854057	26643	13	22C
0005435856183	26643	14	22D
0005435856199	26643	15	23B
0005433868731	4767	1	1A
0005433868715	4767	2	1B
0005433868724	4767	3	1C
0005433868748	4767	4	1D
0005433868740	4767	5	2A
0005433868718	4767	6	2B
0005433868747	4767	7	2C
0005433868736	4767	8	2D
0005433868730	4767	9	3A
0005433868745	4767	10	3B
0005433868727	4767	11	3C
0005433868711	4767	12	3D
0005433868751	4767	13	4A
0005433868741	4767	14	4B
0005433868733	4767	15	4C
0005433868737	4767	16	4D
0005435860473	4767	17	5A
0005435860478	4767	18	5B
0005433868725	4767	19	5C
0005433868722	4767	20	6A
0005433868734	4767	21	6B
0005433868713	4767	22	6C
0005433868746	4767	23	7B
0005433868712	4767	24	7A
0005433868743	4767	25	7D
0005433868721	4767	26	18A
0005435860474	4767	27	18C
0005435860479	4767	28	18D
0005433868728	4767	29	19A
0005433868739	4767	30	19B
0005433868729	4767	31	19C
0005433868726	4767	32	19D
0005433868723	4767	33	20A
0005433868744	4767	34	20B
0005433868750	4767	35	20C
0005433868714	4767	36	20D
0005433868717	4767	37	21A
0005433868752	4767	38	21B
0005433868742	4767	39	21C
0005433868719	4767	40	21D
0005433868716	4767	41	22A
0005433868735	4767	42	22B
0005433868720	4767	43	22C
0005433868732	4767	44	22D
0005433868738	4767	45	23A
0005433868749	4767	46	23B
0005433868238	32598	1	1A
0005433868449	32598	2	1B
0005433868507	32598	3	1C
0005433868191	32598	4	1D
0005433868307	32598	5	2A
0005433868332	32598	6	2C
0005433868374	32598	7	2B
0005433868313	32598	8	2D
0005433868240	32598	9	3A
0005433868409	32598	10	3B
0005433868340	32598	11	3C
0005433868426	32598	12	3D
0005433868459	32598	13	4A
0005433868433	32598	14	4B
0005433868377	32598	15	4C
0005433868237	32598	16	4D
0005433868506	32598	17	5A
0005433868424	32598	18	5B
0005433868301	32598	19	5C
0005433868273	32598	20	5D
0005433868378	32598	21	6A
0005433868458	32598	22	6B
0005433868239	32598	23	6C
0005433868384	32598	24	6D
0005433868303	32598	25	7A
0005433868425	32598	26	7B
0005433868183	32598	27	7C
0005433868311	32598	28	7D
0005433868375	32598	29	18B
0005433868277	32598	30	18A
0005433868508	32598	31	18C
0005433868244	32598	32	18D
0005433868373	32598	33	19A
0005433868297	32598	34	19B
0005433868394	32598	35	19C
0005433868294	32598	36	19D
0005433868383	32598	37	20A
0005433868455	32598	38	20B
0005433868438	32598	39	20C
0005433868418	32598	40	20D
0005433868423	32598	41	21A
0005433868274	32598	42	21B
0005433868522	32598	43	21D
0005433868312	32598	44	22A
0005433868302	32598	45	22B
0005433868193	32598	46	22C
0005433868182	32598	47	22D
0005433868304	32598	48	23A
0005433868293	32598	49	23B
0005434663503	3438	1	1C
0005434663509	3438	2	2A
0005434460521	3438	3	2B
0005435911460	3438	4	3A
0005434663507	3438	5	3C
0005435911452	3438	6	3D
0005434663504	3438	7	5B
0005434663508	3438	8	5C
0005434461662	3438	9	6D
0005434663512	3438	10	7A
0005435911426	3438	11	7C
0005435911451	3438	12	18A
0005434663505	3438	13	18C
0005434663502	3438	14	18D
0005434663511	3438	15	19A
0005435911453	3438	16	20A
0005435911479	3438	17	20D
0005434663510	3438	18	21A
0005435911439	3438	19	21B
0005434663506	3438	20	21D
0005434460522	3438	21	22A
0005434663513	3438	22	22C
0005434461663	3438	23	23A
0005434663370	12459	1	1B
0005434663369	12459	2	1C
0005434663384	12459	3	1D
0005434663353	12459	4	2C
0005434663422	12459	5	2D
0005434663419	12459	6	3A
0005434663400	12459	7	3B
0005434663401	12459	8	4B
0005434663371	12459	9	4C
0005435911503	12459	10	5A
0005435911506	12459	11	5B
0005434663391	12459	12	5D
0005434663392	12459	13	6A
0005434663421	12459	14	6C
0005435911504	12459	15	6D
0005434663397	12459	16	7A
0005434663355	12459	17	7C
0005435911510	12459	18	7D
0005435911509	12459	19	18C
0005434663408	12459	20	18D
0005434663427	12459	21	19C
0005434663354	12459	22	19D
0005434663386	12459	23	20C
0005434663423	12459	24	20D
0005435911508	12459	25	21C
0005434663412	12459	26	21D
0005435911505	12459	27	22B
0005435911507	12459	28	22C
0005434663428	12459	29	22D
0005433868240	14483	1	1A
0005433868239	14483	2	1B
0005433868426	14483	3	1C
0005433868303	14483	4	1D
0005433868191	14483	5	2A
0005433868507	14483	6	2C
0005433868424	14483	7	2B
0005433868332	14483	8	2D
0005433868374	14483	9	3A
0005433868373	14483	10	3B
0005433868425	14483	11	3C
0005433868455	14483	12	3D
0005433868274	14483	13	4A
0005433868304	14483	14	4B
0005433868193	14483	15	4C
0005433868394	14483	16	4D
0005433868340	14483	17	5A
0005433868459	14483	18	5B
0005433868438	14483	19	5C
0005433868377	14483	20	5D
0005433868458	14483	21	6A
0005433868449	14483	22	6B
0005433868237	14483	23	6C
0005433868244	14483	24	6D
0005433868312	14483	25	7A
0005433868183	14483	26	7B
0005433868383	14483	27	7C
0005433868297	14483	28	7D
0005433868506	14483	29	18A
0005433868384	14483	30	18B
0005433868375	14483	31	18C
0005433868294	14483	32	18D
0005433868508	14483	33	19A
0005433868273	14483	34	19C
0005433868302	14483	35	19B
0005433868182	14483	36	19D
0005433868311	14483	37	20A
0005433868293	14483	38	20B
0005433868522	14483	39	20C
0005433868238	14483	40	20D
0005433868313	14483	41	21B
0005433868277	14483	42	21C
0005433868409	14483	43	21D
0005433868301	14483	44	22A
0005433868433	14483	45	22B
0005433868307	14483	46	22C
0005433868378	14483	47	22D
0005433868423	14483	48	23A
0005433868418	14483	49	23B
0005433868672	32660	1	1A
0005433868701	32660	2	1B
0005433868703	32660	3	1C
0005433868683	32660	4	1D
0005433868673	32660	5	2A
0005433868704	32660	6	2B
0005433868706	32660	7	2C
0005433868699	32660	8	2D
0005433868709	32660	9	3A
0005433868671	32660	10	3B
0005433868681	32660	11	3C
0005433868698	32660	12	3D
0005433868678	32660	13	4B
0005433868688	32660	14	4A
0005433868682	32660	15	4C
0005433868705	32660	16	4D
0005433868670	32660	17	5A
0005433868689	32660	18	5B
0005433868680	32660	19	5C
0005433868690	32660	20	6A
0005433868674	32660	21	6C
0005433868675	32660	22	6B
0005433868684	32660	23	6D
0005433868677	32660	24	7C
0005433868710	32660	25	7D
0005433868687	32660	26	18B
0005433868694	32660	27	18C
0005435860468	32660	28	18D
0005433868695	32660	29	19A
0005433868686	32660	30	19B
0005433868685	32660	31	19C
0005433868697	32660	32	19D
0005433868676	32660	33	20A
0005433868696	32660	34	20D
0005433868702	32660	35	21A
0005433868700	32660	36	21B
0005435860480	32660	37	21C
0005433868692	32660	38	21D
0005433868693	32660	39	22A
0005433868691	32660	40	22B
0005433868708	32660	41	22C
0005433868679	32660	42	22D
0005433868707	32660	43	23B
0005432799380	12100	1	1D
0005432799419	12100	2	2A
0005432799452	12100	3	2B
0005432799428	12100	4	2C
0005432799401	12100	5	3B
0005432799457	12100	6	3D
0005432799338	12100	7	4A
0005432799432	12100	8	4B
0005432799436	12100	9	4D
0005432799323	12100	10	5B
0005432799363	12100	11	5C
0005432799433	12100	12	6D
0005432799456	12100	13	18B
0005432799496	12100	14	19A
0005432799442	12100	15	18D
0005432799473	12100	16	19D
0005432799465	12100	17	20B
0005432799420	12100	18	20D
0005432799362	12100	19	21B
0005432799381	12100	20	21C
0005432799443	12100	21	22B
0005432799501	12100	22	22D
0005432799510	12100	23	23A
0005432799495	12100	24	23B
0005432799637	14836	1	1A
0005432799619	14836	2	1B
0005432799627	14836	3	1C
0005432799630	14836	4	1D
0005432799633	14836	5	2A
0005432799641	14836	6	2B
0005432799635	14836	7	2C
0005432799618	14836	8	2D
0005432799634	14836	9	3A
0005432799632	14836	10	4A
0005432799642	14836	11	4D
0005432799631	14836	12	4C
0005432799645	14836	13	5A
0005432799620	14836	14	5C
0005432799625	14836	15	5D
0005432799629	14836	16	6C
0005432799621	14836	17	7A
0005432799644	14836	18	7B
0005432799640	14836	19	7C
0005432799638	14836	20	18C
0005432799639	14836	21	19A
0005432799622	14836	22	19B
0005432799636	14836	23	19D
0005432799626	14836	24	20B
0005432799646	14836	25	20C
0005432799628	14836	26	21C
0005432799643	14836	27	22B
0005432799624	14836	28	22C
0005432799623	14836	29	22D
0005434408211	7055	1	1C
0005434299726	7055	2	1D
0005434299720	7055	3	1F
0005434299735	7055	4	2C
0005435293225	7055	5	2A
0005435311024	7055	6	2D
0005434299731	7055	7	2F
0005435293239	7055	8	3C
0005435293224	7055	9	3A
0005432153992	7055	10	3D
0005434408244	7055	11	3F
0005434408242	7055	12	4B
0005434408225	7055	13	4D
0005434299727	7055	14	4C
0005434408199	7055	15	4E
0005434408253	7055	16	5A
0005434299741	7055	17	4F
0005434408224	7055	18	5B
0005432153988	7055	19	5C
0005434408216	7055	20	5D
0005432153987	7055	21	5E
0005434299732	7055	22	5F
0005434299733	7055	23	6B
0005432108269	7055	24	6A
0005434408215	7055	25	6C
0005435293208	7055	26	6D
0005434408204	7055	27	6F
0005434299737	7055	28	6E
0005432108268	7055	29	7B
0005432153991	7055	30	7A
0005434408194	7055	31	7C
0005434408200	7055	32	7E
0005434408198	7055	33	7D
0005434408220	7055	34	7F
0005434299730	7055	35	8A
0005435293227	7055	36	8C
0005434408191	7055	37	8E
0005434408245	7055	38	8D
0005435293230	7055	39	8F
0005434408202	7055	40	9A
0005434408240	7055	41	9B
0005435293244	7055	42	9D
0005434408219	7055	43	9C
0005434408201	7055	44	9E
0005434408243	7055	45	9F
0005434299718	7055	46	10B
0005432153989	7055	47	10C
0005435310981	7055	48	10E
0005434408221	7055	49	10D
0005435310979	7055	50	11A
0005434408232	7055	51	11C
0005434408231	7055	52	11B
0005435311010	7055	53	11D
0005435293243	7055	54	11F
0005435293268	7055	55	11E
0005434408208	7055	56	12A
0005434299722	7055	57	12C
0005434408228	7055	58	12B
0005434299728	7055	59	12D
0005434299724	7055	60	12E
0005432153985	7055	61	13A
0005435293226	7055	62	12F
0005434408236	7055	63	13B
0005434408234	7055	64	13C
0005434408222	7055	65	13D
0005434408226	7055	66	13E
0005434408230	7055	67	13F
0005435293245	7055	68	14B
0005432153990	7055	69	14A
0005434408217	7055	70	14C
0005434408209	7055	71	14D
0005434408197	7055	72	14E
0005434408223	7055	73	14F
0005434408205	7055	74	15A
0005435311032	7055	75	15C
0005434408189	7055	76	15B
0005435293248	7055	77	15D
0005434408212	7055	78	15F
0005435293231	7055	79	15E
0005434408207	7055	80	16B
0005434408233	7055	81	16A
0005434408192	7055	82	16C
0005434408248	7055	83	16D
0005435311019	7055	84	16F
0005435311018	7055	85	16E
0005434408214	7055	86	17A
0005434408210	7055	87	17B
0005434408213	7055	88	17C
0005434408247	7055	89	17D
0005432153986	7055	90	17F
0005434408218	7055	91	17E
0005435293308	7055	92	18A
0005434299723	7055	93	18B
0005434299725	7055	94	18C
0005434408241	7055	95	18E
0005435310998	7055	96	18D
0005434408227	7055	97	18F
0005434408206	7055	98	19A
0005434408252	7055	99	19C
0005434299736	7055	100	19B
0005434299740	7055	101	19D
0005434408238	7055	102	19E
0005434408237	7055	103	19F
0005434299719	7055	104	20A
0005435293194	7055	105	20B
0005434408196	7055	106	20C
0005434408239	7055	107	20E
0005434408195	7055	108	20D
0005434408246	7055	109	21A
0005434408190	7055	110	20F
0005434408249	7055	111	21B
0005435293217	7055	112	21C
0005434408203	7055	113	21D
0005435293198	7055	114	21E
0005434408250	7055	115	22A
0005434408251	7055	116	21F
0005434299734	7055	117	22B
0005434408235	7055	118	22C
0005434299721	7055	119	22D
0005435293216	7055	120	23A
0005434299739	7055	121	22F
0005434299738	7055	122	23B
0005434299729	7055	123	23D
0005434408193	7055	124	23C
0005435311025	7055	125	23F
0005434408229	7055	126	23E
0005434299543	26887	1	1A
0005434407828	26887	2	1C
0005435293343	26887	3	1D
0005434407284	26887	4	2A
0005434299596	26887	5	1F
0005434407790	26887	6	2C
0005435293344	26887	7	2D
0005434407466	26887	8	2F
0005434299472	26887	9	3A
0005434407921	26887	10	3C
0005434299529	26887	11	3F
0005434407594	26887	12	3D
0005434407763	26887	13	4A
0005434407327	26887	14	4C
0005435293346	26887	15	4B
0005434299498	26887	16	4E
0005434407414	26887	17	4D
0005434299520	26887	18	5A
0005434407789	26887	19	4F
0005434407690	26887	20	5C
0005435311138	26887	21	5B
0005434299637	26887	22	5D
0005434299519	26887	23	5E
0005434407431	26887	24	6A
0005434407565	26887	25	5F
0005434299528	26887	26	6C
0005434407505	26887	27	6B
0005434299525	26887	28	6D
0005434407366	26887	29	6E
0005434407524	26887	30	7A
0005434299595	26887	31	6F
0005434407639	26887	32	7C
0005434407475	26887	33	7B
0005434407367	26887	34	7E
0005435293340	26887	35	7D
0005434299556	26887	36	7F
0005434407665	26887	37	8A
0005434407282	26887	38	8B
0005434407674	26887	39	8C
0005434299509	26887	40	8E
0005434407985	26887	41	8D
0005434407612	26887	42	8F
0005434299585	26887	43	9A
0005434407768	26887	44	9B
0005434407399	26887	45	9C
0005434407434	26887	46	9E
0005434407691	26887	47	9D
0005434407398	26887	48	9F
0005432058407	26887	49	10C
0005434299510	26887	50	10D
0005434407666	26887	51	11A
0005434407429	26887	52	10E
0005432058408	26887	53	11B
0005434299526	26887	54	11C
0005434407750	26887	55	11E
0005434407283	26887	56	11D
0005435293341	26887	57	11F
0005434407711	26887	58	12A
0005434407507	26887	59	12B
0005434407764	26887	60	12D
0005434407520	26887	61	12C
0005434407901	26887	62	12E
0005434407843	26887	63	12F
0005434407166	26887	64	13B
0005432058405	26887	65	13A
0005434407669	26887	66	13D
0005434407735	26887	67	13C
0005434407435	26887	68	13E
0005435293345	26887	69	14A
0005434299555	26887	70	13F
0005434407572	26887	71	14C
0005434407490	26887	72	14B
0005434407535	26887	73	14E
0005434407653	26887	74	15A
0005432058406	26887	75	14F
0005434407734	26887	76	15B
0005434299559	26887	77	15C
0005434407326	26887	78	15E
0005434299516	26887	79	15D
0005434407446	26887	80	16A
0005434407387	26887	81	15F
0005434299622	26887	82	16B
0005434407723	26887	83	16C
0005434407430	26887	84	16E
0005434407581	26887	85	16D
0005434407710	26887	86	16F
0005434407645	26887	87	17B
0005435293337	26887	88	17A
0005435293338	26887	89	17C
0005435293348	26887	90	17E
0005434407536	26887	91	17D
0005435293347	26887	92	18A
0005434407837	26887	93	17F
0005434407755	26887	94	18B
0005434407221	26887	95	18C
0005434299597	26887	96	18E
0005435293339	26887	97	18D
0005434299511	26887	98	18F
0005434407696	26887	99	19A
0005434407559	26887	100	19B
0005434407625	26887	101	19D
0005434299499	26887	102	19C
0005434407836	26887	103	19E
0005434407788	26887	104	19F
0005434299662	26887	105	20B
0005434407523	26887	106	20A
0005434407812	26887	107	20D
0005434407386	26887	108	20E
0005434407325	26887	109	20F
0005434407285	26887	110	21B
0005434407465	26887	111	21A
0005434408036	26887	112	21C
0005434299508	26887	113	21D
0005434407795	26887	114	21F
0005434407506	26887	115	21E
0005434299527	26887	116	22B
0005434407329	26887	117	22A
0005434407842	26887	118	22C
0005434299464	26887	119	22E
0005434407730	26887	120	22D
0005434407576	26887	121	22F
0005434407464	26887	122	23A
0005435293342	26887	123	23B
0005434407760	26887	124	23C
0005434407660	26887	125	23D
0005434299515	26887	126	23E
0005434407692	26887	127	23F
0005434512147	6464	1	1A
0005432604650	6464	2	1B
0005432604631	6464	3	1C
0005432604642	6464	4	1D
0005432604644	6464	5	2A
0005434512148	6464	6	2B
0005432604632	6464	7	2C
0005432604653	6464	8	2D
0005432604638	6464	9	3B
0005432604624	6464	10	3A
0005432604641	6464	11	3C
0005432604633	6464	12	3D
0005434512145	6464	13	4A
0005434512144	6464	14	4B
0005432604616	6464	15	4C
0005432604626	6464	16	4D
0005434512146	6464	17	5B
0005432604628	6464	18	5C
0005432604620	6464	19	5D
0005432604646	6464	20	6A
0005432604647	6464	21	6B
0005432604636	6464	22	6C
0005432604621	6464	23	6D
0005432604643	6464	24	7A
0005432604655	6464	25	7C
0005432604635	6464	26	7B
0005432604615	6464	27	7D
0005432604654	6464	28	18A
0005432604625	6464	29	18B
0005432604623	6464	30	18C
0005432604648	6464	31	18D
0005432604622	6464	32	19A
0005432604618	6464	33	19B
0005432604619	6464	34	19C
0005432604634	6464	35	19D
0005432604630	6464	36	20A
0005432604645	6464	37	20B
0005432604639	6464	38	20C
0005432604629	6464	39	20D
0005432604649	6464	40	21A
0005432604651	6464	41	21B
0005432604640	6464	42	21C
0005432604627	6464	43	21D
0005432604637	6464	44	22A
0005432604617	6464	45	22B
0005434512149	6464	46	22C
0005432604652	6464	47	22D
0005434512143	6464	48	23A
0005435218112	6464	49	23B
0005432603985	21381	1	1A
0005432604236	21381	2	1B
0005432604285	21381	3	1C
0005432604263	21381	4	1D
0005432604159	21381	5	2A
0005432604477	21381	6	2C
0005432604290	21381	7	2B
0005432604101	21381	8	2D
0005432604364	21381	9	3A
0005432604151	21381	10	3B
0005432604330	21381	11	3C
0005432604252	21381	12	3D
0005432604177	21381	13	4A
0005432604377	21381	14	4B
0005432604276	21381	15	4C
0005432604218	21381	16	4D
0005432604169	21381	17	5A
0005432604005	21381	18	5B
0005432604253	21381	19	5C
0005432604411	21381	20	5D
0005432604289	21381	21	6A
0005432604269	21381	22	6B
0005432604248	21381	23	6C
0005432604331	21381	24	6D
0005432604286	21381	25	7A
0005432604195	21381	26	7B
0005432604232	21381	27	7C
0005432604247	21381	28	7D
0005432604288	21381	29	18A
0005432604476	21381	30	18B
0005432604231	21381	31	18C
0005432604339	21381	32	18D
0005432604099	21381	33	19A
0005432604100	21381	34	19B
0005432604106	21381	35	19C
0005432604234	21381	36	19D
0005432603968	21381	37	20A
0005432604235	21381	38	20B
0005432604378	21381	39	20C
0005432604160	21381	40	20D
0005432604152	21381	41	21A
0005432604314	21381	42	21B
0005432604391	21381	43	21C
0005432604214	21381	44	21D
0005432604264	21381	45	22A
0005432604363	21381	46	22B
0005432604233	21381	47	22C
0005432604350	21381	48	22D
0005432604275	21381	49	23A
0005432604284	21381	50	23B
0005434907162	14986	1	1C
0005434907207	14986	2	1F
0005433251704	14986	3	2C
0005434907059	14986	4	2D
0005434907111	14986	5	2F
0005434907246	14986	6	3A
0005434907326	14986	7	3C
0005433251692	14986	8	3D
0005433251710	14986	9	3F
0005433251716	14986	10	4A
0005434907215	14986	11	4C
0005433251712	14986	12	4D
0005433251688	14986	13	4E
0005434907452	14986	14	4F
0005434907218	14986	15	5A
0005434907188	14986	16	5C
0005433251715	14986	17	5D
0005434907325	14986	18	5E
0005434907189	14986	19	5F
0005433251705	14986	20	6A
0005434907062	14986	21	6C
0005434907172	14986	22	6D
0005433251703	14986	23	6F
0005434907186	14986	24	7A
0005433251695	14986	25	7C
0005434907208	14986	26	7D
0005434906951	14986	27	7F
0005434907262	14986	28	8A
0005433251707	14986	29	8C
0005434907273	14986	30	8D
0005434907161	14986	31	8F
0005434907131	14986	32	9A
0005434907158	14986	33	9C
0005434907352	14986	34	9D
0005434907219	14986	35	9E
0005433251699	14986	36	9F
0005433251709	14986	37	10A
0005433251691	14986	38	10C
0005433251690	14986	39	10D
0005434906874	14986	40	10E
0005434907353	14986	41	10F
0005434907122	14986	42	11A
0005433251693	14986	43	11C
0005434907247	14986	44	11D
0005434906991	14986	45	11E
0005434907187	14986	46	11F
0005434907193	14986	47	12A
0005433251701	14986	48	12C
0005433251689	14986	49	12D
0005434907185	14986	50	12E
0005434907155	14986	51	12F
0005434907196	14986	52	13A
0005433251696	14986	53	13C
0005434907354	14986	54	13D
0005433251687	14986	55	13E
0005433251714	14986	56	13F
0005433251711	14986	57	14A
0005434907453	14986	58	14C
0005433251700	14986	59	14D
0005434907190	14986	60	14E
0005433251698	14986	61	14F
0005434907184	14986	62	15A
0005434907365	14986	63	15C
0005434906945	14986	64	15D
0005433251694	14986	65	15E
0005434906952	14986	66	15F
0005434907127	14986	67	16C
0005433251702	14986	68	16D
0005434907157	14986	69	16E
0005434907144	14986	70	16F
0005433251717	14986	71	17C
0005434907200	14986	72	17D
0005434906956	14986	73	18A
0005433251706	14986	74	18C
0005433251686	14986	75	18E
0005434907147	14986	76	18F
0005434907295	14986	77	19A
0005433251708	14986	78	19C
0005434907126	14986	79	19D
0005434906992	14986	80	19F
0005433251713	14986	81	20A
0005434907137	14986	82	20C
0005434907254	14986	83	20D
0005433251697	14986	84	20F
0005433251324	25817	1	1A
0005433251408	25817	2	1C
0005434907634	25817	3	1D
0005434907598	25817	4	1F
0005434907612	25817	5	2A
0005434907639	25817	6	2D
0005433251388	25817	7	2C
0005434907606	25817	8	2F
0005434907622	25817	9	3A
0005433251325	25817	10	3C
0005433251530	25817	11	3D
0005433251321	25817	12	4A
0005433251382	25817	13	4C
0005434907620	25817	14	4D
0005434907646	25817	15	4E
0005433251472	25817	16	4F
0005434907643	25817	17	5A
0005433251493	25817	18	5C
0005433251535	25817	19	5D
0005434907632	25817	20	5E
0005434907618	25817	21	5F
0005433251537	25817	22	6A
0005434907647	25817	23	6C
0005434907625	25817	24	6D
0005434907602	25817	25	6E
0005434907621	25817	26	6F
0005433251504	25817	27	7A
0005434907637	25817	28	7C
0005434907649	25817	29	7D
0005433251471	25817	30	7E
0005434907610	25817	31	7F
0005433251405	25817	32	8A
0005434907636	25817	33	8C
0005433251407	25817	34	8D
0005433251410	25817	35	8E
0005434907633	25817	36	8F
0005433251492	25817	37	9A
0005433251383	25817	38	9C
0005433251421	25817	39	9D
0005434907623	25817	40	9E
0005433251330	25817	41	9F
0005434907638	25817	42	10A
0005434907615	25817	43	10C
0005434907645	25817	44	10D
0005433251575	25817	45	10F
0005434907605	25817	46	11A
0005433251282	25817	47	11C
0005433251461	25817	48	11D
0005434907626	25817	49	11E
0005433251567	25817	50	11F
0005434907652	25817	51	12A
0005434907619	25817	52	12C
0005434907642	25817	53	12D
0005434907635	25817	54	12E
0005434907650	25817	55	12F
0005434907601	25817	56	13A
0005433251502	25817	57	13C
0005434907611	25817	58	13D
0005433251568	25817	59	13E
0005433251576	25817	60	14A
0005433251549	25817	61	13F
0005433251516	25817	62	14C
0005434907599	25817	63	14D
0005434907640	25817	64	14E
0005434907630	25817	65	14F
0005434907617	25817	66	15A
0005434907629	25817	67	15C
0005434907616	25817	68	15D
0005434907631	25817	69	15E
0005433251515	25817	70	15F
0005434907653	25817	71	16A
0005434907603	25817	72	16C
0005433251532	25817	73	16D
0005434907600	25817	74	16E
0005434907644	25817	75	16F
0005434907608	25817	76	17A
0005433251538	25817	77	17C
0005434907609	25817	78	17D
0005433251486	25817	79	17E
0005433251462	25817	80	17F
0005433251336	25817	81	18A
0005434907648	25817	82	18C
0005434907614	25817	83	18D
0005434907641	25817	84	18E
0005434907624	25817	85	18F
0005434907651	25817	86	19A
0005434907604	25817	87	19C
0005434907627	25817	88	19D
0005434907607	25817	89	19E
0005433251501	25817	90	19F
0005433251387	25817	91	20A
0005434907613	25817	92	20C
0005433251386	25817	93	20D
0005434907628	25817	94	20E
0005433251319	25817	95	20F
0005432609755	22477	1	1A
0005432609753	22477	2	1C
0005435841474	22477	3	1D
0005432607587	22477	4	2B
0005432609754	22477	5	2C
0005432609756	22477	6	3B
0005435842326	22477	7	3C
0005432609751	22477	8	4B
0005432607584	22477	9	5B
0005435841472	22477	10	5C
0005432607585	22477	11	5D
0005432607589	22477	12	6B
0005432609747	22477	13	7A
0005435842325	22477	14	7B
0005432607586	22477	15	7C
0005432607591	22477	16	18A
0005435842324	22477	17	18B
0005432609759	22477	18	18D
0005432609757	22477	19	19A
0005432607588	22477	20	19C
0005432609752	22477	21	19B
0005432607592	22477	22	20B
0005432607590	22477	23	21A
0005432607583	22477	24	21B
0005432609758	22477	25	21C
0005432609750	22477	26	21D
0005432609748	22477	27	22A
0005432609749	22477	28	22B
0005435841473	22477	29	22C
0005432607593	22477	30	23A
0005432613875	31729	1	1B
0005432609712	31729	2	1C
0005432609705	31729	3	2C
0005432613852	31729	4	3A
0005435841100	31729	5	3B
0005432613836	31729	6	3D
0005432609713	31729	7	4A
0005432609721	31729	8	4C
0005432613835	31729	9	4D
0005435841101	31729	10	5A
0005435841099	31729	11	5C
0005432609720	31729	12	5D
0005432613841	31729	13	6A
0005432613847	31729	14	7C
0005432613854	31729	15	18B
0005432613842	31729	16	18C
0005432609711	31729	17	18D
0005432613849	31729	18	19A
0005432609717	31729	19	19C
0005432613843	31729	20	19D
0005432609728	31729	21	20A
0005432609716	31729	22	20B
0005432609710	31729	23	20C
0005432613851	31729	24	21A
0005432613856	31729	25	21B
0005432609726	31729	26	21C
0005432613857	31729	27	21D
0005432609708	31729	28	22A
0005432609715	31729	29	22B
0005432613850	31729	30	22D
0005432609727	31729	31	23B
0005433008960	14182	1	1A
0005433008969	14182	2	1C
0005433008957	14182	3	1D
0005433008975	14182	4	1F
0005433008951	14182	5	3A
0005433008968	14182	6	3C
0005433008981	14182	7	3D
0005433008938	14182	8	4A
0005433008947	14182	9	4C
0005433008943	14182	10	5A
0005433008958	14182	11	6A
0005433008959	14182	12	6D
0005433008942	14182	13	7A
0005433810527	14182	14	7C
0005433008967	14182	15	7E
0005433008948	14182	16	7F
0005433008966	14182	17	8A
0005433008963	14182	18	8D
0005433008974	14182	19	8E
0005433008945	14182	20	9C
0005433810528	14182	21	9D
0005433008977	14182	22	10A
0005433008955	14182	23	10D
0005433008941	14182	24	11A
0005433008962	14182	25	11F
0005433008954	14182	26	12A
0005433008973	14182	27	12D
0005433008953	14182	28	12E
0005433008964	14182	29	12F
0005433008950	14182	30	13A
0005433008965	14182	31	13F
0005433008978	14182	32	14A
0005433008952	14182	33	14E
0005433810523	14182	34	15A
0005433008972	14182	35	15C
0005433008961	14182	36	15D
0005433008980	14182	37	15E
0005433008976	14182	38	15F
0005433008946	14182	39	16D
0005433008970	14182	40	16E
0005433008971	14182	41	17E
0005433810522	14182	42	17F
0005433008939	14182	43	18C
0005433008949	14182	44	18F
0005433008944	14182	45	19C
0005433008940	14182	46	19E
0005433008956	14182	47	19F
0005433008979	14182	48	20A
0005433008528	22847	1	1A
0005433008441	22847	2	1D
0005433008318	22847	3	2A
0005433008640	22847	4	2D
0005433008150	22847	5	3A
0005433008345	22847	6	3C
0005433008650	22847	7	4A
0005433008432	22847	8	4D
0005433008487	22847	9	4E
0005433008499	22847	10	5A
0005433008434	22847	11	5E
0005433008552	22847	12	5F
0005433008232	22847	13	6D
0005433008553	22847	14	6E
0005433008331	22847	15	6F
0005433008578	22847	16	7A
0005433008645	22847	17	7C
0005433008635	22847	18	7D
0005433008521	22847	19	7E
0005433008511	22847	20	8A
0005433008556	22847	21	8E
0005433008392	22847	22	9A
0005433008801	22847	23	9C
0005433008498	22847	24	9E
0005433008391	22847	25	9F
0005433008610	22847	26	10D
0005433008452	22847	27	11A
0005433008799	22847	28	11E
0005433008535	22847	29	11F
0005433008455	22847	30	12C
0005433008415	22847	31	12E
0005433008433	22847	32	12F
0005433008444	22847	33	13A
0005433008448	22847	34	13C
0005433008582	22847	35	13D
0005433008800	22847	36	13E
0005433008554	22847	37	14C
0005433008520	22847	38	14E
0005433008549	22847	39	14F
0005433008630	22847	40	15D
0005433008659	22847	41	15E
0005433008151	22847	42	16E
0005433008527	22847	43	17C
0005433008454	22847	44	17D
0005433008449	22847	45	17F
0005433008348	22847	46	18C
0005433008473	22847	47	18D
0005433008587	22847	48	19A
0005433008488	22847	49	19D
0005433008646	22847	50	19E
0005433008641	22847	51	19F
0005433008534	22847	52	20A
0005433008638	22847	53	20C
0005433008453	22847	54	20D
0005433008456	22847	55	20E
0005433008332	22847	56	20F
0005434925605	14935	1	3C
0005434925773	14935	2	4E
0005434925687	14935	3	5C
0005434925737	14935	4	6A
0005434925703	14935	5	6F
0005434925719	14935	6	7C
0005434925647	14935	7	7D
0005434925749	14935	8	8A
0005434925657	14935	9	8F
0005434925613	14935	10	9C
0005434925646	14935	11	9F
0005434925775	14935	12	10C
0005434925659	14935	13	10D
0005434925681	14935	14	11E
0005434925723	14935	15	12E
0005434925686	14935	16	13A
0005434925679	14935	17	13F
0005434925722	14935	18	14A
0005434925767	14935	19	14C
0005434925658	14935	20	14F
0005434925736	14935	21	15E
0005434925748	14935	22	16A
0005434925699	14935	23	16D
0005434925675	14935	24	16F
0005434925772	14935	25	17C
0005434925774	14935	26	17D
0005434925739	14935	27	17E
0005434925720	14935	28	19C
0005434925608	14935	29	19F
0005434925710	14935	30	20D
0005434925680	14935	31	20F
0005434926000	20531	1	1A
0005434926002	20531	2	1D
0005434926023	20531	3	2C
0005434926001	20531	4	3C
0005434926021	20531	5	4C
0005434925994	20531	6	4D
0005434925990	20531	7	4F
0005434926018	20531	8	5D
0005434925991	20531	9	5E
0005434926022	20531	10	5F
0005434925995	20531	11	6A
0005434925996	20531	12	7F
0005434926007	20531	13	8A
0005434926004	20531	14	8F
0005434925992	20531	15	9A
0005434926016	20531	16	9C
0005434925989	20531	17	9D
0005434926025	20531	18	9E
0005434926015	20531	19	10E
0005434925998	20531	20	12C
0005434925999	20531	21	12E
0005434926009	20531	22	12F
0005434926006	20531	23	13C
0005434926024	20531	24	13D
0005434926005	20531	25	13E
0005434926011	20531	26	14C
0005434926017	20531	27	14D
0005434926012	20531	28	15C
0005434925993	20531	29	16A
0005434926014	20531	30	16F
0005434926020	20531	31	17A
0005434926013	20531	32	17C
0005434926003	20531	33	17D
0005434926008	20531	34	17E
0005434925997	20531	35	17F
0005434926010	20531	36	20D
0005434926019	20531	37	20F
0005435487997	15844	1	1B
0005435488003	15844	2	1C
0005435487985	15844	3	1D
0005435487998	15844	4	2A
0005435487990	15844	5	2C
0005435999238	15844	6	3A
0005435487991	15844	7	3C
0005435487989	15844	8	3D
0005435999242	15844	9	4A
0005435487988	15844	10	4B
0005435999237	15844	11	4C
0005435488001	15844	12	5C
0005435999248	15844	13	5D
0005435999233	15844	14	7A
0005435487992	15844	15	7B
0005435999222	15844	16	7D
0005435487999	15844	17	18A
0005435488002	15844	18	18B
0005435488000	15844	19	18C
0005435487996	15844	20	18D
0005435999149	15844	21	19A
0005435999203	15844	22	19B
0005435488004	15844	23	19C
0005435488005	15844	24	19D
0005435487987	15844	25	20A
0005435487986	15844	26	20B
0005435487993	15844	27	20D
0005435487995	15844	28	21B
0005435999234	15844	29	22A
0005435487994	15844	30	22B
0005435999221	15844	31	22D
0005435999224	15844	32	23A
0005435488006	15844	33	23B
0005435487807	19708	1	1A
0005435999377	19708	2	1B
0005435487701	19708	3	1C
0005435999365	19708	4	1D
0005435487696	19708	5	2A
0005435999369	19708	6	2B
0005435999371	19708	7	2C
0005435487820	19708	8	2D
0005435487770	19708	9	3A
0005435487689	19708	10	3B
0005435999363	19708	11	3C
0005435999361	19708	12	3D
0005435999359	19708	13	4A
0005435999379	19708	14	4C
0005435487787	19708	15	5A
0005435999366	19708	16	5C
0005435999373	19708	17	5D
0005435487821	19708	18	6B
0005435999357	19708	19	6C
0005435999372	19708	20	6D
0005435999370	19708	21	7A
0005435487749	19708	22	7C
0005435999360	19708	23	7D
0005435999362	19708	24	18A
0005435999380	19708	25	18B
0005435999358	19708	26	18C
0005435487788	19708	27	18D
0005435999378	19708	28	19C
0005435999364	19708	29	19D
0005435487742	19708	30	20A
0005435487755	19708	31	20B
0005435487818	19708	32	20C
0005435999368	19708	33	20D
0005435487676	19708	34	21A
0005435487746	19708	35	21B
0005435487727	19708	36	21C
0005435487806	19708	37	21D
0005435999367	19708	38	22A
0005435999375	19708	39	22B
0005435487741	19708	40	22C
0005435999376	19708	41	23A
0005435999374	19708	42	23B
0005432142276	5980	1	1D
0005435472762	5980	2	2F
0005435472763	5980	3	2D
0005435472818	5980	4	4A
0005435839651	5980	5	3F
0005435839649	5980	6	4F
0005435472711	5980	7	5A
0005435839667	5980	8	5D
0005435839657	5980	9	6D
0005435472814	5980	10	6F
0005435472816	5980	11	7C
0005435839666	5980	12	7B
0005435472788	5980	13	7D
0005435839664	5980	14	8A
0005435839650	5980	15	7F
0005435839658	5980	16	8C
0005432660836	5980	17	8E
0005435839654	5980	18	9B
0005435472778	5980	19	9D
0005435839675	5980	20	9C
0005435839670	5980	21	10A
0005435839662	5980	22	10C
0005435472821	5980	23	10D
0005435839656	5980	24	11A
0005432660835	5980	25	12A
0005435839652	5980	26	12E
0005435472783	5980	27	13A
0005432142275	5980	28	13B
0005435839671	5980	29	13E
0005432659724	5980	30	13F
0005435472710	5980	31	15B
0005435839661	5980	32	15A
0005435839663	5980	33	15C
0005435839668	5980	34	15D
0005435839673	5980	35	15F
0005435472764	5980	36	16F
0005435472742	5980	37	17B
0005435472784	5980	38	17A
0005435472817	5980	39	17C
0005435839669	5980	40	18A
0005435839659	5980	41	18B
0005435472805	5980	42	19A
0005435839655	5980	43	18F
0005435839672	5980	44	19C
0005435839676	5980	45	19F
0005432659723	5980	46	19E
0005435839674	5980	47	20B
0005435839665	5980	48	20D
0005432659722	5980	49	20F
0005435839660	5980	50	21B
0005435472824	5980	51	21D
0005435472745	5980	52	21E
0005435839653	5980	53	21F
0005432537074	18039	1	1C
0005432667454	18039	2	1A
0005435472932	18039	3	2C
0005432667444	18039	4	2A
0005435839349	18039	5	3A
0005435472917	18039	6	4C
0005432664122	18039	7	4D
0005435839417	18039	8	5C
0005435839330	18039	9	5D
0005435839458	18039	10	6D
0005435839475	18039	11	6E
0005435472925	18039	12	7F
0005435839359	18039	13	8B
0005435839360	18039	14	8A
0005435472926	18039	15	9C
0005435472922	18039	16	9F
0005432660810	18039	17	9D
0005435472930	18039	18	10F
0005435839383	18039	19	11C
0005435472927	18039	20	11E
0005435839409	18039	21	12B
0005435839447	18039	22	12C
0005435472933	18039	23	12F
0005435839282	18039	24	14C
0005435472919	18039	25	14B
0005435472921	18039	26	14E
0005435472928	18039	27	15C
0005435839517	18039	28	15E
0005432537075	18039	29	16A
0005435472918	18039	30	15F
0005435839465	18039	31	16E
0005435472929	18039	32	16F
0005432667455	18039	33	17A
0005435839410	18039	34	17C
0005435839472	18039	35	18B
0005435839416	18039	36	18A
0005435472924	18039	37	18E
0005435839350	18039	38	18D
0005435839503	18039	39	20B
0005435472931	18039	40	20A
0005435839358	18039	41	21C
0005432660809	18039	42	21B
0005435472920	18039	43	21D
0005435472923	18039	44	21F
0005433285289	23032	1	1A
0005435103979	23032	2	1F
0005433285140	23032	3	2D
0005433285264	23032	4	2F
0005433285159	23032	5	5B
0005433285249	23032	6	6E
0005433285259	23032	7	7A
0005433285250	23032	8	7B
0005433285215	23032	9	7E
0005433285364	23032	10	8A
0005433285326	23032	11	8C
0005433285298	23032	12	9C
0005435103981	23032	13	10B
0005433285098	23032	14	10C
0005433285248	23032	15	11E
0005433285102	23032	16	13A
0005435103982	23032	17	13F
0005433285268	23032	18	14A
0005433285257	23032	19	14F
0005433285313	23032	20	15C
0005435103980	23032	21	15F
0005433285208	23032	22	16A
0005433285256	23032	23	16B
0005433285204	23032	24	16F
0005433285253	23032	25	17A
0005433285343	23032	26	18B
0005433285141	23032	27	18F
0005433285265	23032	28	19B
0005433285418	23032	29	20E
0005433285393	23032	30	20F
0005433285114	23032	31	21A
0005433285235	23032	32	21C
0005433285245	23032	33	22E
0005433285363	23032	34	23B
0005433285548	32091	1	1D
0005433285541	32091	2	2A
0005433285546	32091	3	2D
0005433285519	32091	4	3C
0005433285538	32091	5	3F
0005433285525	32091	6	4C
0005435103880	32091	7	5D
0005433285529	32091	8	6D
0005433285527	32091	9	6E
0005433285520	32091	10	7C
0005433285539	32091	11	7E
0005435103881	32091	12	7F
0005433285521	32091	13	8E
0005433285536	32091	14	9A
0005433285531	32091	15	9D
0005433285540	32091	16	10D
0005433285535	32091	17	11B
0005433285532	32091	18	13B
0005433285528	32091	19	13F
0005433285545	32091	20	14F
0005433285549	32091	21	15E
0005433285526	32091	22	16E
0005433285530	32091	23	17A
0005433285543	32091	24	17E
0005433285544	32091	25	18B
0005433285537	32091	26	18C
0005433285533	32091	27	18F
0005433285524	32091	28	19B
0005433285542	32091	29	20C
0005433285518	32091	30	21B
0005433285522	32091	31	21A
0005433285534	32091	32	21D
0005433285550	32091	33	21F
0005433285547	32091	34	22B
0005433285523	32091	35	23D
0005435852596	23861	1	1A
0005433475699	23861	2	3B
0005435852597	23861	3	4A
0005433475698	23861	4	5D
0005435852598	23861	5	6B
0005433475701	23861	6	18B
0005433475711	23861	7	18D
0005433475692	23861	8	19A
0005435852595	23861	9	20B
0005435852599	23861	10	20D
0005435852594	23861	11	22D
0005433475700	23861	12	23A
0005432528093	30626	1	1C
0005432528317	30626	2	1A
0005435214078	30626	3	1H
0005434067562	30626	4	1G
0005434067515	30626	5	1D
0005434067659	30626	6	2C
0005432527268	30626	7	2A
0005432527725	30626	8	2H
0005434067542	30626	9	2G
0005435214130	30626	10	2D
0005435214119	30626	11	3C
0005432527945	30626	12	3A
0005434067262	30626	13	3D
0005435214126	30626	14	3K
0005434067636	30626	15	3H
0005435214088	30626	16	3G
0005434067382	30626	17	4C
0005432527275	30626	18	4A
0005435214079	30626	19	4G
0005432528138	30626	20	4D
0005435214092	30626	21	4K
0005432527274	30626	22	4H
0005432528164	30626	23	5C
0005433656699	30626	24	5A
0005432528499	30626	25	5G
0005432527872	30626	26	11A
0005435214086	30626	27	5K
0005432528222	30626	28	11E
0005432528101	30626	29	11D
0005432528165	30626	30	11C
0005434067633	30626	31	11F
0005434067052	30626	32	11H
0005432528156	30626	33	11G
0005432528408	30626	34	12C
0005432528026	30626	35	11K
0005435214063	30626	36	12E
0005432528053	30626	37	12D
0005435214115	30626	38	12G
0005434067627	30626	39	12F
0005434067813	30626	40	12K
0005435214093	30626	41	13C
0005434067597	30626	42	13A
0005434067449	30626	43	13F
0005435214118	30626	44	13E
0005432527607	30626	45	13H
0005432535836	30626	46	13G
0005434067655	30626	47	14A
0005435214094	30626	48	13K
0005432527920	30626	49	14E
0005434067677	30626	50	14D
0005432528441	30626	51	14C
0005434067598	30626	52	14F
0005432527690	30626	53	14K
0005433656698	30626	54	14H
0005435214075	30626	55	14G
0005432527921	30626	56	15C
0005435214127	30626	57	15E
0005432527790	30626	58	15D
0005432211560	30626	59	15H
0005435214077	30626	60	15F
0005432528604	30626	61	16A
0005434067432	30626	62	15K
0005432527702	30626	63	16D
0005432528017	30626	64	16C
0005434067312	30626	65	16G
0005435214071	30626	66	16H
0005432528501	30626	67	17A
0005434067508	30626	68	16K
0005432528467	30626	69	17E
0005435214070	30626	70	17D
0005434067463	30626	71	17C
0005432535837	30626	72	17G
0005435214102	30626	73	17F
0005432527883	30626	74	17K
0005434067292	30626	75	17H
0005435214068	30626	76	18C
0005435214113	30626	77	18B
0005432528247	30626	78	18A
0005435214120	30626	79	18E
0005432528139	30626	80	18D
0005432159892	30626	81	18H
0005434067502	30626	82	18G
0005432528260	30626	83	18F
0005435214129	30626	84	18K
0005434067171	30626	85	18J
0005432527930	30626	86	19B
0005432528088	30626	87	19A
0005434067624	30626	88	19C
0005434067814	30626	89	19F
0005432527923	30626	90	19E
0005435630992	30626	91	19D
0005435214076	30626	92	19J
0005434067486	30626	93	19G
0005432528074	30626	94	20A
0005435214122	30626	95	19K
0005432527805	30626	96	20C
0005432527580	30626	97	20E
0005435214073	30626	98	20D
0005432211559	30626	99	20G
0005432527703	30626	100	20K
0005432527535	30626	101	20J
0005432528178	30626	102	21A
0005432528061	30626	103	21C
0005432211562	30626	104	21B
0005435214100	30626	105	21F
0005432527818	30626	106	21J
0005432528068	30626	107	21H
0005432159893	30626	108	21G
0005432211563	30626	109	22A
0005435214109	30626	110	21K
0005435214111	30626	111	22C
0005433656697	30626	112	22B
0005435214097	30626	113	22F
0005432528094	30626	114	22D
0005435214114	30626	115	22G
0005434067311	30626	116	22K
0005432527951	30626	117	22J
0005434067728	30626	118	23B
0005432527267	30626	119	23A
0005432528155	30626	120	23D
0005432528045	30626	121	23C
0005432528166	30626	122	23J
0005432159894	30626	123	23H
0005432527985	30626	124	24D
0005432528041	30626	125	23K
0005435214087	30626	126	24F
0005432528062	30626	127	24E
0005434067279	30626	128	25A
0005432528048	30626	129	24G
0005432528223	30626	130	25B
0005432528602	30626	131	25F
0005432528242	30626	132	25E
0005432528012	30626	133	25D
0005435214124	30626	134	25H
0005434067504	30626	135	25G
0005432527897	30626	136	26A
0005435214067	30626	137	25K
0005432528046	30626	138	25J
0005435725643	30626	139	26B
0005432527938	30626	140	26E
0005432528108	30626	141	26D
0005434067505	30626	142	26G
0005435214085	30626	143	26F
0005432535830	30626	144	26K
0005432527627	30626	145	26J
0005434067559	30626	146	27A
0005432159896	30626	147	27C
0005432527935	30626	148	27B
0005435214106	30626	149	27E
0005432527545	30626	150	27D
0005434067451	30626	151	27H
0005432527446	30626	152	27K
0005435214101	30626	153	27J
0005432527743	30626	154	28B
0005435214095	30626	155	28A
0005432527581	30626	156	28E
0005435214099	30626	157	28D
0005432528250	30626	158	28C
0005434067383	30626	159	28G
0005435214116	30626	160	28F
0005434067547	30626	161	28J
0005434067729	30626	162	28H
0005432535850	30626	163	28K
0005434067282	30626	164	29D
0005434067733	30626	165	29C
0005435214123	30626	166	29B
0005434067687	30626	167	29F
0005434067675	30626	168	29E
0005434067577	30626	169	29J
0005435214125	30626	170	29H
0005435214090	30626	171	29G
0005435725641	30626	172	30A
0005435214117	30626	173	29K
0005435214064	30626	174	30C
0005434067300	30626	175	30B
0005434067649	30626	176	30E
0005432527816	30626	177	30D
0005434067352	30626	178	30H
0005432528367	30626	179	30G
0005435725642	30626	180	30F
0005434067467	30626	181	30J
0005432528233	30626	182	31D
0005434067622	30626	183	31C
0005434067686	30626	184	31B
0005434067399	30626	185	31F
0005435725639	30626	186	31H
0005434067291	30626	187	31J
0005432527519	30626	188	32C
0005432527791	30626	189	32B
0005432528444	30626	190	32A
0005434067364	30626	191	32E
0005432528438	30626	192	32D
0005434067336	30626	193	32H
0005432528023	30626	194	32G
0005435214096	30626	195	32F
0005432528043	30626	196	33B
0005432527882	30626	197	33A
0005434067503	30626	198	32K
0005432528161	30626	199	33C
0005434067172	30626	200	33F
0005435214084	30626	201	33E
0005432528286	30626	202	33H
0005435214103	30626	203	33G
0005432527744	30626	204	33K
0005435214108	30626	205	34B
0005434067734	30626	206	34E
0005432527717	30626	207	34D
0005434067122	30626	208	34H
0005432527606	30626	209	34G
0005432528058	30626	210	34F
0005432527588	30626	211	34J
0005434067628	30626	212	35E
0005434067051	30626	213	35D
0005435214082	30626	214	35C
0005432528295	30626	215	35F
0005432527614	30626	216	35J
0005435214121	30626	217	35H
0005434067430	30626	218	35G
0005432535792	30626	219	36A
0005432428930	30626	220	35K
0005434067521	30626	221	36C
0005435214065	30626	222	36B
0005432527785	30626	223	36E
0005432527890	30626	224	36D
0005432527929	30626	225	36H
0005432211566	30626	226	36G
0005434067561	30626	227	36F
0005432527804	30626	228	36K
0005434067507	30626	229	36J
0005435214128	30626	230	37B
0005432211565	30626	231	37D
0005432528436	30626	232	37C
0005435214112	30626	233	37F
0005432527884	30626	234	37E
0005432528142	30626	235	37J
0005432527814	30626	236	37G
0005434067660	30626	237	38A
0005434067676	30626	238	37K
0005434067674	30626	239	38C
0005432527928	30626	240	38B
0005432537061	30626	241	38K
0005435214062	30626	242	38J
0005435725640	30626	243	38H
0005432528040	30626	244	39B
0005432528092	30626	245	39A
0005434067283	30626	246	39D
0005434067632	30626	247	39G
0005434067541	30626	248	39F
0005434067319	30626	249	39E
0005432528106	30626	250	39H
0005434067280	30626	251	40A
0005432528100	30626	252	39K
0005432528318	30626	253	39J
0005432527950	30626	254	40B
0005432527757	30626	255	40E
0005435214110	30626	256	40D
0005432527986	30626	257	40G
0005432528466	30626	258	40F
0005434067799	30626	259	40J
0005434067466	30626	260	41B
0005432528248	30626	261	41A
0005432528493	30626	262	40K
0005434067792	30626	263	41D
0005435214083	30626	264	41C
0005435214105	30626	265	41G
0005435214098	30626	266	41H
0005435214107	30626	267	41K
0005435214080	30626	268	41J
0005434067345	30626	269	42E
0005432211561	30626	270	42D
0005432535829	30626	271	42G
0005434067703	30626	272	42K
0005434067735	30626	273	42J
0005435214069	30626	274	42H
0005432528042	30626	275	43A
0005435214081	30626	276	43C
0005434067183	30626	277	43B
0005435214091	30626	278	43F
0005434067479	30626	279	43E
0005433656700	30626	280	43J
0005435630991	30626	281	43H
0005432527589	30626	282	44A
0005432527830	30626	283	43K
0005432527960	30626	284	44E
0005434067344	30626	285	44D
0005432527873	30626	286	44C
0005432527854	30626	287	44G
0005432528603	30626	288	44J
0005434067339	30626	289	44H
0005432211564	30626	290	45A
0005432528409	30626	291	45D
0005434067663	30626	292	45B
0005435214072	30626	293	45F
0005432528221	30626	294	45H
0005432527891	30626	295	45K
0005435214074	30626	296	46B
0005432527961	30626	297	46A
0005432528217	30626	298	46E
0005432527755	30626	299	46D
0005432528437	30626	300	46C
0005432527952	30626	301	46G
0005432528028	30626	302	46F
0005434067274	30626	303	46K
0005434067600	30626	304	46J
0005432527756	30626	305	46H
0005432527525	30626	306	47E
0005434067524	30626	307	47D
0005432527780	30626	308	47C
0005434067050	30626	309	47G
0005435630993	30626	310	47F
0005434067246	30626	311	47H
0005432159895	30626	312	48C
0005435214104	30626	313	48A
0005434067454	30626	314	48E
0005432528500	30626	315	48D
0005432527984	30626	316	48H
0005432528033	30626	317	48G
0005434067192	30626	318	48F
0005434067477	30626	319	48K
0005432527617	30626	320	49E
0005432528277	30626	321	49D
0005432528073	30626	322	49F
0005432528160	30626	323	49K
0005435214066	30626	324	49H
0005432528107	30626	325	50C
0005432528191	30626	326	50E
0005432528243	30626	327	50D
0005432528261	30626	328	50G
0005434067478	30626	329	50F
0005434067366	30626	330	51D
0005434067509	30626	331	50K
0005434067450	30626	332	50H
0005434067727	30626	333	51F
0005432528614	30626	334	51E
0005435214089	30626	335	51G
0005433368209	24843	1	1C
0005433368203	24843	2	1D
0005435653017	24843	3	1F
0005433368208	24843	4	2A
0005435653047	24843	5	2D
0005435652851	24843	6	2F
0005433368178	24843	7	3A
0005435653033	24843	8	3C
0005433368182	24843	9	3F
0005435652743	24843	10	4A
0005433368187	24843	11	4C
0005433368204	24843	12	4D
0005433368188	24843	13	4E
0005435652850	24843	14	4F
0005433368181	24843	15	5A
0005433368206	24843	16	5C
0005435652945	24843	17	5D
0005433368186	24843	18	5F
0005433368200	24843	19	6C
0005435652881	24843	20	6D
0005435653013	24843	21	6E
0005435652880	24843	22	6F
0005433368214	24843	23	7A
0005435652974	24843	24	7C
0005433368192	24843	25	7D
0005435652944	24843	26	7E
0005433368189	24843	27	8A
0005435652961	24843	28	8C
0005435652939	24843	29	8D
0005433368215	24843	30	8E
0005435652933	24843	31	8F
0005435652985	24843	32	9A
0005433368184	24843	33	9C
0005435653009	24843	34	9D
0005433368202	24843	35	9F
0005435652940	24843	36	10A
0005435652919	24843	37	10C
0005433368207	24843	38	10D
0005435653025	24843	39	10E
0005433368211	24843	40	10F
0005433368191	24843	41	11A
0005433368196	24843	42	11C
0005433368197	24843	43	11D
0005435653012	24843	44	11E
0005433368198	24843	45	11F
0005435653036	24843	46	12A
0005435652920	24843	47	12C
0005433368180	24843	48	12D
0005435652849	24843	49	12F
0005435652948	24843	50	13A
0005433368201	24843	51	13C
0005435652906	24843	52	13D
0005433368190	24843	53	13F
0005433368183	24843	54	14A
0005435653032	24843	55	14C
0005433368216	24843	56	14D
0005435653027	24843	57	14F
0005433368194	24843	58	15A
0005435652908	24843	59	15C
0005435652787	24843	60	15D
0005435652907	24843	61	15E
0005433368212	24843	62	15F
0005435653028	24843	63	16A
0005435653026	24843	64	16D
0005435652972	24843	65	16E
0005433368205	24843	66	16F
0005433368199	24843	67	17A
0005433368185	24843	68	17D
0005435652837	24843	69	17E
0005435652905	24843	70	17F
0005433368195	24843	71	18A
0005433368213	24843	72	18C
0005435652986	24843	73	18E
0005433368179	24843	74	18F
0005435653003	24843	75	19C
0005435652904	24843	76	19F
0005435652938	24843	77	20A
0005433368193	24843	78	20C
0005435652742	24843	79	20D
0005433368210	24843	80	20F
0005435949776	23318	1	1B
0005435949775	23318	2	20A
0005435949777	23318	3	22D
0005435949766	23318	4	23B
0005434980032	2026	1	1A
0005434980043	2026	2	1B
0005435801720	2026	3	1D
0005434980025	2026	4	2A
0005434980051	2026	5	2B
0005434980050	2026	6	2C
0005434980029	2026	7	2D
0005434980037	2026	8	3A
0005434980041	2026	9	4A
0005434980031	2026	10	4B
0005434980030	2026	11	4C
0005434980034	2026	12	4D
0005434980033	2026	13	5B
0005434980022	2026	14	5C
0005434980047	2026	15	5D
0005434980036	2026	16	6D
0005434980044	2026	17	7A
0005434980045	2026	18	7C
0005434980040	2026	19	7D
0005434980046	2026	20	18D
0005434980049	2026	21	19A
0005434980042	2026	22	19C
0005434980028	2026	23	19D
0005434980048	2026	24	20A
0005434980035	2026	25	20B
0005434980039	2026	26	20C
0005434980024	2026	27	21C
0005434980027	2026	28	21B
0005434980021	2026	29	21D
0005435801722	2026	30	22A
0005434980023	2026	31	22B
0005435801721	2026	32	22C
0005434980038	2026	33	22D
0005434980026	2026	34	23A
0005434979671	23564	1	1A
0005434979825	23564	2	1B
0005434979793	23564	3	1C
0005434979741	23564	4	1D
0005434979722	23564	5	2B
0005434979626	23564	6	2C
0005434979658	23564	7	2D
0005434979669	23564	8	3B
0005434979716	23564	9	3A
0005435801700	23564	10	3D
0005434979661	23564	11	4B
0005435801689	23564	12	4C
0005434979662	23564	13	4D
0005434979611	23564	14	5B
0005434979764	23564	15	5C
0005434979679	23564	16	5D
0005434979678	23564	17	6A
0005434979610	23564	18	6B
0005434979802	23564	19	6D
0005434979706	23564	20	7B
0005434979625	23564	21	7C
0005434979746	23564	22	7D
0005434979805	23564	23	18B
0005434979803	23564	24	19B
0005434979670	23564	25	19C
0005434979727	23564	26	20A
0005434979765	23564	27	20B
0005434979732	23564	28	20C
0005434979707	23564	29	21A
0005434979744	23564	30	21B
0005434979794	23564	31	21C
0005434979660	23564	32	21D
0005434979745	23564	33	22B
0005434979701	23564	34	22D
0005434979824	23564	35	23A
0005434952562	2572	1	1A
0005434952563	2572	2	1B
0005434952560	2572	3	2A
0005434952561	2572	4	4B
0005433256420	2573	1	3A
0005433256416	2573	2	4A
0005434952527	28221	1	1A
0005434952539	28221	2	2A
0005433256441	28221	3	3A
0005434952534	28221	4	2B
0005434952535	28221	5	4A
0005434952532	28221	6	4B
0005433256440	28221	7	5B
0005433111525	19741	1	1B
0005434302869	19741	2	2B
0005434302857	19741	3	3A
0005434302858	19741	4	4B
0005434302854	19741	5	5A
0005433111524	19741	6	6A
0005434138264	11939	1	1A
0005434138185	11939	2	1C
0005434138016	11939	3	1D
0005434137869	11939	4	1F
0005434138261	11939	5	2A
0005434138249	11939	6	2C
0005434137972	11939	7	2D
0005434137803	11939	8	2F
0005434137947	11939	9	3A
0005434138076	11939	10	3D
0005434138087	11939	11	3F
0005434138018	11939	12	4A
0005434137948	11939	13	4C
0005434137925	11939	14	4D
0005434137781	11939	15	4F
0005434138109	11939	16	5A
0005434138098	11939	17	5D
0005434138239	11939	18	5E
0005434138088	11939	19	5F
0005434137923	11939	20	6A
0005434138150	11939	21	6D
0005434138230	11939	22	6E
0005434138032	11939	23	6F
0005434138118	11939	24	7A
0005434138201	11939	25	7D
0005434138141	11939	26	7E
0005434137999	11939	27	7F
0005434137834	11939	28	8A
0005434137910	11939	29	8D
0005434138251	11939	30	8E
0005434137920	11939	31	8F
0005434138152	11939	32	9C
0005434137922	11939	33	9D
0005434137783	11939	34	9E
0005434138075	11939	35	10A
0005434137964	11939	36	10C
0005434138202	11939	37	10D
0005434138233	11939	38	10E
0005434138110	11939	39	10F
0005434138140	11939	40	11A
0005434137930	11939	41	11D
0005434138000	11939	42	11E
0005434137916	11939	43	11F
0005434138151	11939	44	12A
0005434138169	11939	45	12C
0005434137919	11939	46	12E
0005434138180	11939	47	12F
0005434138181	11939	48	13A
0005434138060	11939	49	13C
0005434138133	11939	50	13D
0005434137851	11939	51	13E
0005434138238	11939	52	13F
0005434138079	11939	53	14A
0005434138073	11939	54	14C
0005434137924	11939	55	14D
0005434137896	11939	56	14F
0005434138231	11939	57	14E
0005434138184	11939	58	15A
0005434138116	11939	59	15C
0005434137918	11939	60	15D
0005434137804	11939	61	15E
0005434137891	11939	62	16A
0005434137921	11939	63	16C
0005434137992	11939	64	16D
0005434138063	11939	65	16E
0005434137835	11939	66	16F
0005434138142	11939	67	17A
0005434137915	11939	68	17C
0005434138232	11939	69	17E
0005434138023	11939	70	17F
0005434138234	11939	71	18A
0005434138017	11939	72	18C
0005434138002	11939	73	18D
0005434138078	11939	74	18E
0005434138108	11939	75	18F
0005434137892	11939	76	19A
0005434138193	11939	77	19C
0005434137805	11939	78	19E
0005434138039	11939	79	19F
0005434137782	11939	80	20A
0005434138007	11939	81	20C
0005434138062	11939	82	20D
0005434137795	11939	83	20E
0005434138099	11939	84	20F
0005434138745	28728	1	1A
0005434138798	28728	2	1C
0005434138751	28728	3	1D
0005434138727	28728	4	1F
0005434138766	28728	5	2A
0005434138804	28728	6	2C
0005434138716	28728	7	2D
0005434138797	28728	8	2F
0005434138719	28728	9	3A
0005434138750	28728	10	3C
0005434138764	28728	11	3D
0005434138735	28728	12	3F
0005434138758	28728	13	4A
0005434138763	28728	14	4C
0005434138733	28728	15	4D
0005434138801	28728	16	4E
0005434138793	28728	17	4F
0005434138731	28728	18	5A
0005434138779	28728	19	5C
0005434138775	28728	20	5D
0005434138723	28728	21	5E
0005434138790	28728	22	5F
0005434138746	28728	23	6C
0005434138760	28728	24	6D
0005434138757	28728	25	6E
0005434138744	28728	26	6F
0005434138739	28728	27	7A
0005434138718	28728	28	7C
0005434138753	28728	29	7E
0005434138792	28728	30	7F
0005434138777	28728	31	8C
0005434138762	28728	32	8D
0005434138776	28728	33	8E
0005434138717	28728	34	8F
0005434138788	28728	35	9A
0005434138786	28728	36	9C
0005434138724	28728	37	9D
0005434138752	28728	38	9E
0005434138767	28728	39	10A
0005434138749	28728	40	10C
0005434138774	28728	41	10D
0005434138743	28728	42	10E
0005434138780	28728	43	10F
0005434138802	28728	44	11A
0005434138803	28728	45	11C
0005434138805	28728	46	11D
0005434138796	28728	47	11E
0005434138782	28728	48	11F
0005434138794	28728	49	12A
0005434138730	28728	50	12C
0005434138795	28728	51	12D
0005434138728	28728	52	12E
0005434138769	28728	53	12F
0005434138755	28728	54	13A
0005434138799	28728	55	13C
0005434138738	28728	56	13D
0005434138720	28728	57	13E
0005434138806	28728	58	13F
0005434138785	28728	59	14A
0005434138772	28728	60	14C
0005434138722	28728	61	14D
0005434138747	28728	62	14E
0005434138800	28728	63	14F
0005434138783	28728	64	15A
0005434138736	28728	65	15C
0005434138741	28728	66	15D
0005434138726	28728	67	15E
0005434138789	28728	68	16A
0005434138759	28728	69	16C
0005434138784	28728	70	16D
0005434138725	28728	71	16E
0005434138765	28728	72	16F
0005434138778	28728	73	17A
0005434138737	28728	74	17C
0005434138791	28728	75	17D
0005434138740	28728	76	17E
0005434138773	28728	77	17F
0005434138770	28728	78	18A
0005434138734	28728	79	18C
0005434138761	28728	80	18D
0005434138748	28728	81	18E
0005434138771	28728	82	18F
0005434138721	28728	83	19A
0005434138756	28728	84	19C
0005434138742	28728	85	19D
0005434138768	28728	86	19E
0005434138732	28728	87	19F
0005434138754	28728	88	20A
0005434138787	28728	89	20D
0005434138729	28728	90	20E
0005434138781	28728	91	20F
0005434466503	6577	1	2B
0005434466502	6577	2	2C
0005434466504	6577	3	3A
0005435312809	6577	4	4B
0005435312804	6577	5	4D
0005434466498	6577	6	5C
0005434466499	6577	7	5D
0005434466494	6577	8	6B
0005434466495	6577	9	7B
0005435312811	6577	10	7D
0005435312800	6577	11	18D
0005434466497	6577	12	19B
0005434466500	6577	13	19C
0005435312808	6577	14	19D
0005434466501	6577	15	20D
0005434466496	6577	16	21B
0005435312807	6577	17	22A
0005435312810	6577	18	22D
0005434516077	19100	1	1A
0005434513581	19100	2	1C
0005434516076	19100	3	1D
0005434513562	19100	4	2C
0005434190417	19100	5	2D
0005434513570	19100	6	3A
0005434516073	19100	7	3B
0005434513583	19100	8	3C
0005434513589	19100	9	3D
0005434513572	19100	10	4B
0005434513577	19100	11	4D
0005434190416	19100	12	5A
0005434513567	19100	13	5B
0005434513561	19100	14	5D
0005434513568	19100	15	6D
0005434190422	19100	16	7A
0005434513582	19100	17	7B
0005434190421	19100	18	7C
0005434190419	19100	19	18A
0005434513578	19100	20	18B
0005434516074	19100	21	18C
0005434516072	19100	22	18D
0005434190420	19100	23	19B
0005434513590	19100	24	20C
0005434513569	19100	25	20D
0005434513564	19100	26	21A
0005434513563	19100	27	21B
0005434513576	19100	28	21C
0005434190423	19100	29	21D
0005434190415	19100	30	22A
0005434513591	19100	31	22B
0005434513571	19100	32	22C
0005434513580	19100	33	23A
0005434190418	19100	34	23B
0005433534516	6777	1	2A
0005433538942	6777	2	2C
0005435259730	6777	3	3A
0005433538943	6777	4	3B
0005435259762	6777	5	3D
0005433538944	6777	6	4C
0005433538939	6777	7	4D
0005433538941	6777	8	5A
0005433538945	6777	9	6D
0005433538938	6777	10	7A
0005435259729	6777	11	18A
0005433534517	6777	12	18D
0005433538946	6777	13	19D
0005433534515	6777	14	21A
0005433538940	6777	15	21D
0005435259763	6777	16	23B
0005435259794	25014	1	4A
0005433538863	25014	2	4C
0005433538916	25014	3	6B
0005433538872	25014	4	6C
0005433538869	25014	5	18D
0005435259792	25014	6	19B
0005433538870	25014	7	20A
0005435259791	25014	8	20C
0005433534502	25014	9	21B
0005435259793	25014	10	21C
0005433538852	25014	11	22A
0005433512018	843	1	2C
0005433512022	843	2	4C
0005433512019	843	3	4D
0005432922527	843	4	5B
0005433512021	843	5	6B
0005433512020	843	6	6D
0005432922533	843	7	7B
0005432922528	843	8	7A
0005433512017	843	9	7D
0005433512025	843	10	19C
0005433512023	843	11	20A
0005433512024	843	12	20D
0005433512026	843	13	21B
0005432922525	843	14	22A
0005432922524	843	15	23A
0005433511963	16137	1	1C
0005433511929	16137	2	1D
0005433511961	16137	3	3C
0005433511978	16137	4	4B
0005433511933	16137	5	6C
0005433511972	16137	6	6D
0005432922558	16137	7	7B
0005432922560	16137	8	7D
0005433511962	16137	9	20A
0005433511928	16137	10	20C
0005432922559	16137	11	21C
0005433511953	16137	12	21D
0005433511932	16137	13	22A
0005434950567	3672	1	1B
0005435697585	3672	2	1C
0005434950569	3672	3	2B
0005435935050	3672	4	2D
0005435697571	3672	5	2C
0005435697572	3672	6	3A
0005435697582	3672	7	3B
0005435697586	3672	8	3C
0005435697577	3672	9	3D
0005435697563	3672	10	4A
0005435935051	3672	11	4B
0005435935039	3672	12	4C
0005435697581	3672	13	4D
0005435697564	3672	14	5A
0005435697570	3672	15	5B
0005435697575	3672	16	5C
0005435697584	3672	17	6A
0005435697561	3672	18	6B
0005435697576	3672	19	6C
0005435935041	3672	20	7A
0005434950565	3672	21	7B
0005434950566	3672	22	7C
0005435697578	3672	23	7D
0005435697569	3672	24	18A
0005435697565	3672	25	18B
0005435697567	3672	26	18C
0005434950568	3672	27	18D
0005435697568	3672	28	19B
0005435697566	3672	29	19C
0005435697583	3672	30	19D
0005435935038	3672	31	20A
0005435697580	3672	32	20B
0005435697579	3672	33	20C
0005435697562	3672	34	21B
0005435697587	3672	35	21C
0005435935040	3672	36	22A
0005435697588	3672	37	22B
0005435697573	3672	38	22C
0005435697574	3672	39	22D
0005435697332	16306	1	1A
0005434950547	16306	2	1B
0005434950519	16306	3	1C
0005435697312	16306	4	1D
0005435697409	16306	5	2A
0005435697316	16306	6	2B
0005435697288	16306	7	2C
0005435697249	16306	8	2D
0005435697354	16306	9	3A
0005435697248	16306	10	3B
0005435935066	16306	11	3C
0005435935068	16306	12	3D
0005435697340	16306	13	4A
0005435916191	16306	14	4B
0005435697259	16306	15	4D
0005435697295	16306	16	5C
0005435697369	16306	17	5D
0005435697217	16306	18	6A
0005435935065	16306	19	7A
0005435697258	16306	20	7B
0005435935067	16306	21	7D
0005435697296	16306	22	18A
0005435697297	16306	23	18B
0005435697300	16306	24	18C
0005435697321	16306	25	18D
0005435697311	16306	26	19A
0005435697250	16306	27	19B
0005435697347	16306	28	19C
0005435697355	16306	29	19D
0005435697226	16306	30	20A
0005435697290	16306	31	20C
0005435916190	16306	32	20D
0005435697358	16306	33	21A
0005435697241	16306	34	21B
0005435697322	16306	35	21C
0005435916189	16306	36	21D
0005435697314	16306	37	22B
0005435697289	16306	38	22C
0005434950540	16306	39	22D
0005434606861	3939	1	1C
0005432607599	3939	2	1D
0005435853612	3939	3	2A
0005433519494	3939	4	3B
0005435853615	3939	5	3C
0005432607602	3939	6	3D
0005432609765	3939	7	4B
0005434606862	3939	8	4C
0005432607600	3939	9	5B
0005434606859	3939	10	5D
0005435853608	3939	11	6A
0005432609766	3939	12	6B
0005434606858	3939	13	7A
0005434604925	3939	14	7B
0005435853607	3939	15	7D
0005433519496	3939	16	18A
0005432607598	3939	17	18B
0005432609763	3939	18	18C
0005434604926	3939	19	19A
0005432609764	3939	20	19C
0005432607601	3939	21	19D
0005433519497	3939	22	20C
0005434604927	3939	23	21D
0005433519495	3939	24	22A
0005432609767	3939	25	22D
0005434606860	3939	26	23B
0005433519469	22069	1	1B
0005432609715	22069	2	1C
0005432613835	22069	3	1D
0005433519480	22069	4	2A
0005432609727	22069	5	2B
0005432613857	22069	6	2C
0005432609711	22069	7	2D
0005432613841	22069	8	3A
0005432613850	22069	9	3B
0005433519479	22069	10	3C
0005433519467	22069	11	3D
0005432613843	22069	12	4A
0005433519470	22069	13	4B
0005433519473	22069	14	4C
0005433519461	22069	15	5A
0005432613875	22069	16	5B
0005435841101	22069	17	5C
0005432613847	22069	18	5D
0005432609708	22069	19	6B
0005432613836	22069	20	6C
0005432609712	22069	21	6D
0005434606810	22069	22	7C
0005432609726	22069	23	7D
0005435841100	22069	24	18B
0005432609713	22069	25	18C
0005432609705	22069	26	18D
0005432609720	22069	27	19A
0005433519478	22069	28	19B
0005432613856	22069	29	19C
0005432613849	22069	30	19D
0005432609728	22069	31	20B
0005433519462	22069	32	20C
0005432613842	22069	33	20D
0005432609710	22069	34	21A
0005432613851	22069	35	21B
0005432609717	22069	36	21C
0005434606811	22069	37	21D
0005432609716	22069	38	22A
0005432613852	22069	39	22B
0005435841099	22069	40	22C
0005432613854	22069	41	22D
0005433519460	22069	42	23A
0005432609721	22069	43	23B
0005435628752	672	1	1A
0005435628753	672	2	2A
0005433349016	672	3	1B
0005433348996	672	4	2B
0005435628751	672	5	3A
0005433348990	672	6	3B
0005433348984	672	7	4A
0005435628750	672	8	4B
0005435628749	672	9	5A
0005433348982	672	10	5B
0005433348994	672	11	6A
0005433348983	672	12	6B
0005433349036	15923	1	1A
0005435628718	15923	2	1B
0005433349037	15923	3	2B
0005433349041	15923	4	2A
0005433349038	15923	5	3A
0005433349039	15923	6	3B
0005433349035	15923	7	4A
0005433349040	15923	8	4B
0005435628721	15923	9	6A
0005434445260	17208	1	1A
0005433159313	17208	2	3A
0005433159308	17208	3	3B
0005433159312	17208	4	4B
0005433159309	17208	5	5A
0005433158119	17208	6	5B
0005433159306	17208	7	6B
0005434445228	17671	1	1B
0005434445243	17671	2	2B
0005435132974	7912	1	3C
0005435132971	7912	2	5D
0005435132973	7912	3	6A
0005435383128	7912	4	6C
0005435132966	7912	5	6D
0005435132969	7912	6	7D
0005435132965	7912	7	18C
0005435383135	7912	8	18D
0005435132970	7912	9	19C
0005435132967	7912	10	20A
0005435132972	7912	11	21A
0005435132975	7912	12	21B
0005435132968	7912	13	21C
0005435383150	7912	14	23A
0005435132887	33113	1	1D
0005435132858	33113	2	2A
0005435132940	33113	3	2C
0005435383195	33113	4	2D
0005435132882	33113	5	3B
0005435132876	33113	6	4A
0005435383194	33113	7	4B
0005435132891	33113	8	4D
0005435383196	33113	9	5B
0005435132931	33113	10	6A
0005435132894	33113	11	6C
0005435132941	33113	12	7A
0005435132875	33113	13	7B
0005435132893	33113	14	18A
0005435383193	33113	15	18B
0005435132888	33113	16	19A
0005435132908	33113	17	19D
0005435132930	33113	18	20B
0005435383198	33113	19	21A
0005435383197	33113	20	21D
0005435132892	33113	21	23A
0005435811119	4407	1	1F
0005435938872	4407	2	2F
0005435811112	4407	3	2C
0005435938879	4407	4	3C
0005435938881	4407	5	3D
0005435811107	4407	6	6B
0005435811109	4407	7	6C
0005435811106	4407	8	7A
0005435811111	4407	9	7D
0005435811116	4407	10	7F
0005435938883	4407	11	8F
0005435811114	4407	12	9C
0005435811108	4407	13	9B
0005435938880	4407	14	9D
0005435938893	4407	15	10C
0005435811117	4407	16	10D
0005435938894	4407	17	11C
0005435811118	4407	18	11E
0005435938892	4407	19	12E
0005435811110	4407	20	13C
0005435811120	4407	21	18D
0005435811113	4407	22	19D
0005435938884	4407	23	20C
0005435811115	4407	24	21C
0005435811058	29442	1	1F
0005435811044	29442	2	2F
0005435938904	29442	3	3A
0005435938907	29442	4	5D
0005435938908	29442	5	6A
0005435811046	29442	6	7E
0005435938909	29442	7	10B
0005435938910	29442	8	11B
0005435811069	29442	9	11D
0005435811045	29442	10	14A
0005435811051	29442	11	14E
0005435811061	29442	12	15F
0005435811041	29442	13	16B
0005435811059	29442	14	17F
0005435811068	29442	15	18C
0005435811066	29442	16	18F
0005435811032	29442	17	18E
0005435811081	29442	18	19A
0005435938906	29442	19	19B
0005435811080	29442	20	21F
0005435938905	29442	21	21D
0005435390259	7484	1	1B
0005435160394	7484	2	3D
0005435390270	7484	3	4A
0005435160396	7484	4	4B
0005435160399	7484	5	5A
0005435390269	7484	6	5B
0005435390217	7484	7	5D
0005435160392	7484	8	6A
0005435160390	7484	9	6B
0005435160393	7484	10	6C
0005435160398	7484	11	18A
0005435160401	7484	12	19A
0005435160395	7484	13	19D
0005435160391	7484	14	21A
0005435390225	7484	15	21B
0005435390216	7484	16	21C
0005435160397	7484	17	22A
0005435160400	7484	18	22B
0005435390255	7484	19	22D
0005435390240	7484	20	23A
0005435390232	7484	21	23B
0005435160296	29556	1	1A
0005435160331	29556	2	1B
0005435160348	29556	3	1C
0005435160299	29556	4	1D
0005435160287	29556	5	3A
0005435160349	29556	6	4A
0005435390296	29556	7	4B
0005435390298	29556	8	4C
0005435160265	29556	9	4D
0005435390300	29556	10	5A
0005435160328	29556	11	5B
0005435390297	29556	12	6B
0005435160286	29556	13	7A
0005435390301	29556	14	7C
0005435160295	29556	15	7D
0005435390295	29556	16	18B
0005435160293	29556	17	19C
0005435390299	29556	18	20A
0005435160351	29556	19	20B
0005435160288	29556	20	21C
0005435160294	29556	21	22A
0005435160283	29556	22	23A
0005435160332	29556	23	23B
0005432398196	18452	1	1A
0005432394099	18452	2	1B
0005432394106	18452	3	2A
0005432398197	18452	4	2B
0005432394097	18452	5	3A
0005432394113	18452	6	4A
0005432394098	18452	7	5A
0005432398191	18452	8	4B
0005432394109	18452	9	5B
0005432394105	18452	10	6A
0005432398198	18452	11	6B
0005432398224	27148	1	1A
0005432398223	27148	2	1B
0005435179393	27148	3	2A
0005432400153	27148	4	2B
0005432400154	27148	5	3B
0005435179394	27148	6	4A
0005435179392	27148	7	5A
0005432398226	27148	8	5B
0005432398225	27148	9	6A
0005432400155	27148	10	6B
0005432639243	2246	1	1A
0005432639227	2246	2	1C
0005432639225	2246	3	1F
0005432866025	2246	4	2A
0005432866013	2246	5	2D
0005432639238	2246	6	2F
0005432639237	2246	7	3C
0005432866026	2246	8	4A
0005432866020	2246	9	4F
0005432866007	2246	10	5F
0005432639233	2246	11	6E
0005432639222	2246	12	7C
0005432639234	2246	13	7D
0005432865992	2246	14	8A
0005432639235	2246	15	8F
0005432639244	2246	16	9A
0005432865998	2246	17	9E
0005432639221	2246	18	10A
0005432639242	2246	19	10C
0005432866021	2246	20	10E
0005432639241	2246	21	11C
0005432639239	2246	22	11E
0005432639232	2246	23	12E
0005432866008	2246	24	13C
0005432866019	2246	25	13F
0005432865983	2246	26	14A
0005432639228	2246	27	14E
0005432639236	2246	28	16C
0005432639226	2246	29	16D
0005432639231	2246	30	16F
0005432639230	2246	31	17A
0005432865984	2246	32	17C
0005432639223	2246	33	17F
0005432639220	2246	34	18C
0005432865985	2246	35	19D
0005432865991	2246	36	19E
0005432639224	2246	37	19F
0005432639229	2246	38	20C
0005432639240	2246	39	20D
0005434191283	9814	1	2B
0005434191284	9814	2	3A
0005434191282	9814	3	3B
0005434504473	6558	1	1C
0005434504481	6558	2	2D
0005434504470	6558	3	2F
0005435103991	6558	4	3A
0005435103988	6558	5	3C
0005434504494	6558	6	4C
0005434504477	6558	7	4E
0005434504499	6558	8	4F
0005434504471	6558	9	5A
0005434504476	6558	10	5C
0005434504501	6558	11	5E
0005434504503	6558	12	6C
0005434504480	6558	13	6E
0005434504467	6558	14	6F
0005435103990	6558	15	7D
0005434504495	6558	16	8C
0005434504484	6558	17	8F
0005434504497	6558	18	9A
0005434504490	6558	19	9D
0005435103993	6558	20	10A
0005434504485	6558	21	10C
0005434504464	6558	22	10D
0005434504504	6558	23	10E
0005434504486	6558	24	10F
0005434504502	6558	25	11D
0005434504498	6558	26	12D
0005434504466	6558	27	12F
0005434504489	6558	28	13C
0005435103989	6558	29	13D
0005434504491	6558	30	14A
0005434504474	6558	31	14C
0005434504465	6558	32	15A
0005434504496	6558	33	15C
0005434504488	6558	34	15F
0005435103987	6558	35	16A
0005434504469	6558	36	16C
0005434504487	6558	37	16D
0005434504479	6558	38	16E
0005435103992	6558	39	16F
0005434504492	6558	40	17D
0005434504482	6558	41	17E
0005434504483	6558	42	18C
0005434504468	6558	43	18E
0005434504472	6558	44	19A
0005434504500	6558	45	19C
0005434504478	6558	46	19D
0005434504475	6558	47	19E
0005434504493	6558	48	20C
0005434503911	22672	1	2D
0005434504110	22672	2	2F
0005434504188	22672	3	3A
0005434504148	22672	4	3D
0005434503910	22672	5	5A
0005434504135	22672	6	5D
0005434504109	22672	7	5F
0005434503979	22672	8	6C
0005434503870	22672	9	6D
0005434504147	22672	10	6F
0005434504156	22672	11	7C
0005434504074	22672	12	7E
0005434504140	22672	13	8A
0005434504001	22672	14	8E
0005434504016	22672	15	8F
0005434504004	22672	16	10C
0005434503978	22672	17	11A
0005434503974	22672	18	11E
0005434504076	22672	19	12D
0005434503871	22672	20	12E
0005434504139	22672	21	13A
0005434504119	22672	22	13C
0005434504061	22672	23	13D
0005434504149	22672	24	13E
0005434504008	22672	25	14C
0005434503960	22672	26	14E
0005434504134	22672	27	15A
0005435103881	22672	28	15E
0005434503975	22672	29	16A
0005434504163	22672	30	16F
0005435103880	22672	31	17A
0005434503959	22672	32	19C
0005434504065	22672	33	19E
0005434504066	22672	34	20D
0005434504097	22672	35	20E
0005435653441	1688	1	1A
0005433367799	1688	2	1C
0005435653430	1688	3	1D
0005435653453	1688	4	2A
0005433367903	1688	5	2C
0005435653413	1688	6	2D
0005435653412	1688	7	2F
0005435653451	1688	8	3A
0005435653434	1688	9	3C
0005435653416	1688	10	3F
0005433367815	1688	11	4A
0005435653456	1688	12	4C
0005435653433	1688	13	4D
0005435653418	1688	14	4E
0005435653455	1688	15	5A
0005433367740	1688	16	5C
0005435653438	1688	17	5D
0005435653428	1688	18	5E
0005433367885	1688	19	5F
0005433367560	1688	20	6A
0005433367824	1688	21	6C
0005435653454	1688	22	6D
0005435653406	1688	23	6E
0005435653452	1688	24	6F
0005433367918	1688	25	7A
0005435653431	1688	26	7E
0005435653405	1688	27	7F
0005435653439	1688	28	8A
0005433367863	1688	29	8C
0005435653440	1688	30	8E
0005433367710	1688	31	8F
0005433367946	1688	32	9A
0005435653442	1688	33	9C
0005435653435	1688	34	9D
0005435653447	1688	35	9E
0005435653408	1688	36	9F
0005435653449	1688	37	10C
0005435653423	1688	38	10D
0005433368022	1688	39	10E
0005435653411	1688	40	10F
0005435653424	1688	41	11A
0005433367739	1688	42	11C
0005435653444	1688	43	11D
0005435653425	1688	44	11E
0005435653409	1688	45	11F
0005433367932	1688	46	12A
0005435653445	1688	47	12C
0005433367844	1688	48	12D
0005435653437	1688	49	12E
0005435653450	1688	50	12F
0005433367714	1688	51	13A
0005433367839	1688	52	13C
0005433368015	1688	53	13D
0005435653422	1688	54	13E
0005435653427	1688	55	13F
0005435653407	1688	56	14A
0005435653436	1688	57	14C
0005433367816	1688	58	14D
0005433367933	1688	59	14E
0005435653417	1688	60	14F
0005435653410	1688	61	15A
0005433367955	1688	62	15C
0005435653429	1688	63	15D
0005435653432	1688	64	15E
0005433367954	1688	65	15F
0005435653446	1688	66	16A
0005433367664	1688	67	16C
0005433367786	1688	68	16D
0005433367878	1688	69	16E
0005433367814	1688	70	16F
0005435653421	1688	71	17A
0005433367835	1688	72	17C
0005433367834	1688	73	17D
0005435653448	1688	74	17E
0005433367864	1688	75	17F
0005433367797	1688	76	18A
0005433367801	1688	77	18C
0005433367820	1688	78	18D
0005433367708	1688	79	18E
0005435653419	1688	80	18F
0005435653426	1688	81	19A
0005433367876	1688	82	19C
0005435653415	1688	83	19D
0005435653414	1688	84	19F
0005435653420	1688	85	20A
0005433367941	1688	86	20C
0005433367879	1688	87	20D
0005435653443	1688	88	20F
0005435652920	21695	1	1A
0005435652907	21695	2	1C
0005433368213	21695	3	1D
0005433368208	21695	4	1F
0005435652850	21695	5	2C
0005433368205	21695	6	2D
0005435652849	21695	7	2F
0005433368196	21695	8	3A
0005433368210	21695	9	3C
0005435652851	21695	10	3D
0005433368215	21695	11	3F
0005435653026	21695	12	4A
0005433368203	21695	13	4D
0005433368182	21695	14	4E
0005435652919	21695	15	4F
0005433368212	21695	16	5A
0005435652933	21695	17	5C
0005433368216	21695	18	5D
0005433368191	21695	19	5F
0005435653036	21695	20	6A
0005433368181	21695	21	6C
0005433368209	21695	22	6D
0005433368214	21695	23	6F
0005435652742	21695	24	7A
0005433368200	21695	25	7C
0005433368189	21695	26	7D
0005433368195	21695	27	7E
0005433368179	21695	28	7F
0005435652948	21695	29	8C
0005433368180	21695	30	8D
0005433368202	21695	31	8E
0005435653032	21695	32	9C
0005435652743	21695	33	9D
0005433368201	21695	34	9F
0005435653027	21695	35	10A
0005433368186	21695	36	10C
0005435652961	21695	37	10E
0005435652904	21695	38	10F
0005435652938	21695	39	11A
0005435652945	21695	40	11C
0005433368178	21695	41	11E
0005433368183	21695	42	11F
0005435653017	21695	43	12A
0005433368207	21695	44	12C
0005433368197	21695	45	12D
0005435652881	21695	46	12E
0005433368193	21695	47	12F
0005433368188	21695	48	13A
0005433368199	21695	49	13D
0005435653028	21695	50	13E
0005433368198	21695	51	13F
0005435652944	21695	52	14A
0005435652986	21695	53	14C
0005435653013	21695	54	14D
0005435652974	21695	55	14E
0005435653009	21695	56	14F
0005435652906	21695	57	15A
0005433368190	21695	58	15C
0005435653003	21695	59	15D
0005435652985	21695	60	15E
0005435653033	21695	61	15F
0005433368184	21695	62	16A
0005435652880	21695	63	16C
0005435652939	21695	64	16D
0005435652787	21695	65	16E
0005433368206	21695	66	16F
0005433368187	21695	67	17D
0005433368211	21695	68	18A
0005433368204	21695	69	18C
0005435652905	21695	70	18E
0005433368185	21695	71	18F
0005435652972	21695	72	19A
0005433368194	21695	73	19C
0005435652837	21695	74	19D
0005435652908	21695	75	19E
0005435653047	21695	76	19F
0005435652940	21695	77	20A
0005433368192	21695	78	20C
0005435653025	21695	79	20E
0005435653012	21695	80	20F
0005434466447	23231	1	1A
0005434466432	23231	2	1D
0005435312826	23231	3	2A
0005434466461	23231	4	3A
0005435312827	23231	5	5C
0005435312823	23231	6	7B
0005435312824	23231	7	18C
0005435312825	23231	8	21C
0005434466431	23231	9	22A
0005434466445	23231	10	22D
0005433986324	4174	1	1C
0005433986352	4174	2	2A
0005433986348	4174	3	2C
0005433986337	4174	4	3A
0005433986330	4174	5	3C
0005433986341	4174	6	3D
0005433986318	4174	7	3F
0005433986310	4174	8	4A
0005433986323	4174	9	4C
0005433986322	4174	10	5C
0005433986327	4174	11	5D
0005433986336	4174	12	5E
0005435788791	4174	13	6D
0005433986331	4174	14	6E
0005433986319	4174	15	6F
0005433986308	4174	16	7A
0005433986349	4174	17	7C
0005433986311	4174	18	7D
0005433986354	4174	19	7E
0005433986321	4174	20	7F
0005435788792	4174	21	8C
0005433986306	4174	22	8F
0005433986345	4174	23	9A
0005433986332	4174	24	9C
0005433986333	4174	25	9E
0005433986351	4174	26	9F
0005433986340	4174	27	10C
0005433986339	4174	28	10D
0005433986309	4174	29	10E
0005433986320	4174	30	11A
0005433986328	4174	31	11C
0005433986315	4174	32	11E
0005433986344	4174	33	11F
0005433986353	4174	34	12F
0005433986329	4174	35	13D
0005433986350	4174	36	14E
0005433986313	4174	37	15C
0005433986307	4174	38	15E
0005433986335	4174	39	15F
0005433986355	4174	40	16C
0005433986343	4174	41	16F
0005433986326	4174	42	17C
0005433986314	4174	43	17D
0005433986316	4174	44	17F
0005433986325	4174	45	18A
0005433986334	4174	46	18E
0005435788793	4174	47	19A
0005433986317	4174	48	19C
0005433986346	4174	49	19D
0005433986312	4174	50	20A
0005433986342	4174	51	20C
0005433986338	4174	52	20D
0005433986347	4174	53	20F
0005433985825	25653	1	1A
0005433985829	25653	2	1C
0005433985883	25653	3	1D
0005433985761	25653	4	1F
0005433985830	25653	5	2D
0005433985824	25653	6	3A
0005433985743	25653	7	3F
0005433985781	25653	8	4A
0005433985884	25653	9	4C
0005433985896	25653	10	4D
0005433985934	25653	11	4E
0005433985853	25653	12	4F
0005433985784	25653	13	5A
0005433985953	25653	14	5C
0005433986110	25653	15	5D
0005433986091	25653	16	5F
0005433985970	25653	17	6A
0005433985937	25653	18	6F
0005433985800	25653	19	7C
0005433985907	25653	20	7F
0005433985808	25653	21	8C
0005433985854	25653	22	8D
0005433986010	25653	23	8E
0005433985952	25653	24	8F
0005433985895	25653	25	9A
0005433985917	25653	26	9E
0005433985994	25653	27	9F
0005433986011	25653	28	10D
0005433985762	25653	29	10E
0005433985941	25653	30	11A
0005433985827	25653	31	11E
0005433985836	25653	32	12A
0005433985905	25653	33	12E
0005433986066	25653	34	12F
0005433985793	25653	35	13C
0005433985886	25653	36	14C
0005433985760	25653	37	14E
0005433985938	25653	38	15A
0005433986041	25653	39	15E
0005433985805	25653	40	16A
0005433985897	25653	41	16D
0005433986019	25653	42	16E
0005433985846	25653	43	17A
0005433985906	25653	44	17F
0005433985733	25653	45	18A
0005433985940	25653	46	18C
0005433985744	25653	47	18D
0005433985885	25653	48	18E
0005433985745	25653	49	18F
0005433985826	25653	50	19F
0005433985748	25653	51	20A
0005433986053	25653	52	20D
0005433985782	25653	53	20F
0005433461574	19923	1	1G
0005433461555	19923	2	1H
0005433461591	19923	3	2F
0005433461579	19923	4	2H
0005433463887	19923	5	3C
0005433463886	19923	6	4F
0005433461584	19923	7	5C
0005433463884	19923	8	5H
0005433461565	19923	9	9B
0005433463867	19923	10	11B
0005433461575	19923	11	11D
0005433463892	19923	12	11H
0005433463879	19923	13	12D
0005433463872	19923	14	13G
0005433463891	19923	15	14E
0005433463893	19923	16	15A
0005433463881	19923	17	15D
0005433463888	19923	18	16G
0005433461568	19923	19	17F
0005433463882	19923	20	17H
0005433463894	19923	21	18B
0005433461567	19923	22	18G
0005433461572	19923	23	18F
0005433461569	19923	24	20B
0005433461571	19923	25	20F
0005433461592	19923	26	21A
0005433461573	19923	27	21B
0005433463883	19923	28	21D
0005433461576	19923	29	23B
0005433461577	19923	30	24D
0005433463885	19923	31	29E
0005433461583	19923	32	30E
0005433463890	19923	33	30G
0005433461566	19923	34	31H
0005433461570	19923	35	33B
0005433463889	19923	36	34A
0005433463880	19923	37	35G
0005433461578	19923	38	36G
0005434509202	1632	1	1A
0005434509215	1632	2	1B
0005434509208	1632	3	1D
0005434509203	1632	4	2A
0005434509207	1632	5	3A
0005434509212	1632	6	3B
0005433168392	1632	7	4A
0005434509198	1632	8	4C
0005434509201	1632	9	4D
0005434509195	1632	10	5B
0005434509216	1632	11	5C
0005434509204	1632	12	5D
0005434509196	1632	13	6A
0005434509213	1632	14	6B
0005434509217	1632	15	6C
0005434509197	1632	16	7A
0005433168365	1632	17	7B
0005434509210	1632	18	18A
0005434509214	1632	19	18D
0005434509199	1632	20	19C
0005434509211	1632	21	20B
0005434509194	1632	22	20C
0005434509205	1632	23	20D
0005433168366	1632	24	21B
0005434509206	1632	25	21C
0005434509209	1632	26	22B
0005434509200	1632	27	22C
0005432666384	17838	1	1A
0005432664132	17838	2	1D
0005432869588	17838	3	2C
0005432657435	17838	4	2F
0005432869586	17838	5	3A
0005432663034	17838	6	4A
0005432664134	17838	7	4E
0005432660822	17838	8	4F
0005432655471	17838	9	5A
0005432664133	17838	10	5E
0005432869584	17838	11	5F
0005432657447	17838	12	6E
0005432659702	17838	13	7A
0005432658588	17838	14	8E
0005432869587	17838	15	8F
0005432664138	17838	16	9A
0005432661919	17838	17	9D
0005432660821	17838	18	9F
0005432655466	17838	19	10A
0005432659699	17838	20	10C
0005432655451	17838	21	11C
0005434151730	17838	22	12A
0005432869580	17838	23	12C
0005432869582	17838	24	12D
0005432658582	17838	25	13A
0005432666386	17838	26	13E
0005432660811	17838	27	14C
0005432655465	17838	28	15A
0005432661918	17838	29	15C
0005432655494	17838	30	15D
0005432655547	17838	31	16D
0005432658584	17838	32	17C
0005434151731	17838	33	17D
0005432658583	17838	34	18C
0005432869585	17838	35	18D
0005432655565	17838	36	18E
0005432666383	17838	37	18F
0005432869583	17838	38	19D
0005432869581	17838	39	19E
0005432663039	17838	40	20D
0005432664156	26294	1	1A
0005434151687	26294	2	1C
0005434151688	26294	3	1D
0005432655609	26294	4	1F
0005432665289	26294	5	2A
0005432664146	26294	6	2F
0005432657472	26294	7	3A
0005432664143	26294	8	3C
0005432657469	26294	9	3D
0005432869516	26294	10	3F
0005434151708	26294	11	4A
0005432661929	26294	12	4C
0005432661934	26294	13	4E
0005432660832	26294	14	4F
0005432655607	26294	15	5A
0005432655610	26294	16	5C
0005432658608	26294	17	5D
0005432660834	26294	18	5F
0005432663044	26294	19	6A
0005432661932	26294	20	6C
0005432659721	26294	21	6D
0005432664152	26294	22	6E
0005432664148	26294	23	6F
0005432665290	26294	24	7A
0005432664144	26294	25	7C
0005432869505	26294	26	7D
0005434151686	26294	27	7E
0005432655618	26294	28	7F
0005432655613	26294	29	8A
0005432663053	26294	30	8D
0005432665288	26294	31	8C
0005432661943	26294	32	8E
0005432661935	26294	33	9A
0005432664149	26294	34	9C
0005432661940	26294	35	9D
0005432869506	26294	36	9F
0005432664145	26294	37	10A
0005432663047	26294	38	10C
0005432663048	26294	39	10E
0005432655614	26294	40	10F
0005432663055	26294	41	11A
0005432655608	26294	42	11C
0005432659720	26294	43	11D
0005432664150	26294	44	11E
0005432666404	26294	45	11F
0005432661930	26294	46	12A
0005432664154	26294	47	12C
0005432661933	26294	48	12E
0005432663052	26294	49	12F
0005432664147	26294	50	13A
0005432658606	26294	51	13C
0005432661938	26294	52	13D
0005432655617	26294	53	13E
0005432663050	26294	54	13F
0005432664155	26294	55	14A
0005432663046	26294	56	14C
0005432658607	26294	57	14D
0005432664157	26294	58	14E
0005432661941	26294	59	14F
0005432663041	26294	60	15C
0005432657470	26294	61	15D
0005432661931	26294	62	15E
0005432666403	26294	63	15F
0005432663042	26294	64	16A
0005432655611	26294	65	16C
0005432655616	26294	66	16D
0005432663045	26294	67	16E
0005432663043	26294	68	16F
0005432664153	26294	69	17A
0005432655615	26294	70	17C
0005432661928	26294	71	17D
0005432660833	26294	72	17E
0005432661937	26294	73	17F
0005432664151	26294	74	18A
0005432661942	26294	75	18D
0005432661939	26294	76	18E
0005432663054	26294	77	18F
0005432667470	26294	78	19A
0005432655612	26294	79	19C
0005432657471	26294	80	19E
0005432663049	26294	81	20A
0005432663051	26294	82	20C
0005432667469	26294	83	20D
0005432661936	26294	84	20E
0005432660831	26294	85	20F
0005432866067	25053	1	1A
0005432639142	25053	2	1C
0005432639112	25053	3	1D
0005432866060	25053	4	1F
0005432866076	25053	5	2A
0005432866069	25053	6	2C
0005432639096	25053	7	2D
0005432866065	25053	8	3A
0005432639130	25053	9	3D
0005432639081	25053	10	4C
0005432866080	25053	11	4D
0005432866070	25053	12	4E
0005432866072	25053	13	4F
0005432639182	25053	14	5A
0005432639105	25053	15	5C
0005432639125	25053	16	5D
0005432866064	25053	17	5E
0005432639131	25053	18	5F
0005432639148	25053	19	6A
0005432639128	25053	20	6C
0005432639129	25053	21	6D
0005432639058	25053	22	6E
0005432639155	25053	23	6F
0005432639089	25053	24	7D
0005432639095	25053	25	7E
0005432866059	25053	26	7F
0005432639107	25053	27	8A
0005432639021	25053	28	8D
0005432866071	25053	29	9A
0005432866079	25053	30	9C
0005432866063	25053	31	9D
0005432639110	25053	32	9E
0005432866062	25053	33	10A
0005432639109	25053	34	10D
0005432639117	25053	35	10F
0005432639154	25053	36	11A
0005432639085	25053	37	11C
0005432639181	25053	38	11D
0005432639062	25053	39	11F
0005432639059	25053	40	12A
0005432639094	25053	41	12C
0005432866074	25053	42	12D
0005432866075	25053	43	12E
0005432866068	25053	44	13A
0005432639108	25053	45	13C
0005432866078	25053	46	13D
0005432639072	25053	47	13F
0005432639101	25053	48	14C
0005432866073	25053	49	15A
0005432639099	25053	50	15C
0005432639156	25053	51	15D
0005432639143	25053	52	15E
0005432866058	25053	53	16A
0005432639123	25053	54	16C
0005432639098	25053	55	16D
0005432639092	25053	56	17A
0005432866061	25053	57	17D
0005432639075	25053	58	17F
0005432639078	25053	59	18C
0005432866077	25053	60	18E
0005432639111	25053	61	18F
0005432639144	25053	62	19C
0005432639114	25053	63	19D
0005432866066	25053	64	19E
0005432639145	25053	65	20A
0005432639113	25053	66	20F
0005432329087	3109	1	1C
0005432329068	3109	2	2C
0005432329090	3109	3	2D
0005432287232	3109	4	2F
0005432329091	3109	5	3C
0005432287231	3109	6	4A
0005432329089	3109	7	5A
0005432329070	3109	8	5C
0005432329084	3109	9	5D
0005432287230	3109	10	5F
0005432329079	3109	11	6A
0005432329083	3109	12	6C
0005432329069	3109	13	6D
0005432329099	3109	14	6E
0005432329100	3109	15	7A
0005432329076	3109	16	7C
0005432329107	3109	17	7E
0005432329109	3109	18	7F
0005432287233	3109	19	8D
0005432329102	3109	20	8E
0005432329104	3109	21	8F
0005432329088	3109	22	9A
0005432329110	3109	23	9C
0005432329103	3109	24	9D
0005432329066	3109	25	9E
0005432329072	3109	26	9F
0005432329078	3109	27	10A
0005432329111	3109	28	10C
0005432329094	3109	29	10D
0005432905121	3109	30	11C
0005432329085	3109	31	11D
0005432329074	3109	32	12A
0005432329081	3109	33	12E
0005432329082	3109	34	12F
0005432329086	3109	35	13E
0005432329075	3109	36	14C
0005432287234	3109	37	14D
0005432329073	3109	38	14F
0005432329095	3109	39	15C
0005432329097	3109	40	15D
0005432329067	3109	41	15F
0005432329098	3109	42	16C
0005432329096	3109	43	17C
0005432329105	3109	44	17E
0005432329108	3109	45	17F
0005432329080	3109	46	18E
0005432329093	3109	47	18F
0005432329106	3109	48	19A
0005432329077	3109	49	19C
0005432329071	3109	50	19D
0005432329092	3109	51	19F
0005432905130	3109	52	20E
0005432329101	3109	53	20F
0005432328579	31104	1	1C
0005432328618	31104	2	1D
0005432328682	31104	3	1F
0005432328673	31104	4	2A
0005432328601	31104	5	2C
0005432328718	31104	6	2D
0005432328803	31104	7	3C
0005432328710	31104	8	3F
0005432328789	31104	9	4C
0005432328681	31104	10	4D
0005432328589	31104	11	4E
0005432328585	31104	12	4F
0005432328729	31104	13	5A
0005433438839	31104	14	5D
0005432328513	31104	15	5F
0005432328720	31104	16	6A
0005432328790	31104	17	6C
0005432905174	31104	18	6D
0005432328642	31104	19	6E
0005432328708	31104	20	7A
0005432328825	31104	21	7C
0005432328616	31104	22	7E
0005432328489	31104	23	7F
0005432328644	31104	24	8C
0005432054329	31104	25	8D
0005432328584	31104	26	8E
0005432328600	31104	27	9A
0005432328641	31104	28	9C
0005432328653	31104	29	9D
0005432328717	31104	30	9E
0005432328456	31104	31	10A
0005432328518	31104	32	10C
0005432328455	31104	33	10D
0005432328672	31104	34	10E
0005432328774	31104	35	11C
0005432328723	31104	36	11E
0005432905175	31104	37	12C
0005432328855	31104	38	12D
0005432054328	31104	39	12E
0005432328765	31104	40	13C
0005432328572	31104	41	13F
0005432905172	31104	42	13E
0005432328665	31104	43	14A
0005432905176	31104	44	14D
0005432328801	31104	45	14E
0005432328654	31104	46	15D
0005432328619	31104	47	15E
0005432328580	31104	48	15F
0005432328711	31104	49	16A
0005432328588	31104	50	16D
0005432328800	31104	51	16E
0005433438861	31104	52	16F
0005432328719	31104	53	17A
0005432328802	31104	54	17C
0005432328693	31104	55	17E
0005432328716	31104	56	17F
0005432905173	31104	57	18A
0005433438838	31104	58	18C
0005432328512	31104	59	18D
0005432328807	31104	60	18E
0005432328905	31104	61	19A
0005432328707	31104	62	19C
0005432328728	31104	63	19E
0005432328700	31104	64	20C
0005432328617	31104	65	20D
0005432328680	31104	66	20F
0005435487748	6177	1	1D
0005435487781	6177	2	2A
0005435999388	6177	3	2D
0005435999385	6177	4	2C
0005434309861	6177	5	3C
0005434309853	6177	6	3A
0005432146217	6177	7	3F
0005435297051	6177	8	4C
0005435999396	6177	9	4D
0005435297027	6177	10	4E
0005435487790	6177	11	5A
0005435487825	6177	12	4F
0005435487782	6177	13	5C
0005435487706	6177	14	5F
0005435487766	6177	15	6B
0005435999397	6177	16	6D
0005432146216	6177	17	6E
0005435999402	6177	18	7A
0005434309857	6177	19	7C
0005434309854	6177	20	7E
0005435999399	6177	21	7F
0005435297081	6177	22	8B
0005435999394	6177	23	8E
0005434309863	6177	24	8F
0005435297065	6177	25	9A
0005435487824	6177	26	9B
0005435487888	6177	27	9C
0005435487852	6177	28	9D
0005435999395	6177	29	9F
0005435999389	6177	30	10C
0005435297048	6177	31	11A
0005435487847	6177	32	11D
0005434309860	6177	33	11C
0005435999387	6177	34	11E
0005435999393	6177	35	12B
0005435487786	6177	36	12E
0005435487849	6177	37	12F
0005435297043	6177	38	13C
0005435999390	6177	39	13F
0005435487789	6177	40	14C
0005434309858	6177	41	14D
0005434309855	6177	42	14E
0005434309856	6177	43	14F
0005435999398	6177	44	15C
0005435999403	6177	45	15B
0005435999401	6177	46	15D
0005435297064	6177	47	15E
0005435297082	6177	48	16B
0005435487764	6177	49	16A
0005435487893	6177	50	16C
0005435487826	6177	51	16D
0005432146215	6177	52	17C
0005435487765	6177	53	17F
0005435999386	6177	54	17E
0005434309862	6177	55	18B
0005435487850	6177	56	18D
0005435487783	6177	57	18F
0005435487873	6177	58	19A
0005435487750	6177	59	19B
0005435487892	6177	60	19D
0005435999400	6177	61	19F
0005434309852	6177	62	19E
0005434309859	6177	63	20B
0005435297068	6177	64	20C
0005435297028	6177	65	21A
0005435999404	6177	66	21C
0005435487851	6177	67	21F
0005435999392	6177	68	22B
0005434309851	6177	69	22C
0005435999391	6177	70	23B
0005434309850	6177	71	23E
0005435487864	6177	72	23D
0005435999238	19531	1	1C
0005435297113	19531	2	1D
0005434309733	19531	3	2A
0005435487997	19531	4	2D
0005435297119	19531	5	2F
0005435297114	19531	6	4A
0005435487988	19531	7	3F
0005435487995	19531	8	5C
0005435488005	19531	9	5D
0005434309749	19531	10	6A
0005434309729	19531	11	5F
0005435487993	19531	12	6E
0005434309763	19531	13	7A
0005434309697	19531	14	8A
0005434309797	19531	15	8E
0005435487999	19531	16	8F
0005435999222	19531	17	9C
0005435487991	19531	18	9B
0005435487996	19531	19	9F
0005434309796	19531	20	10B
0005435487994	19531	21	10D
0005435999234	19531	22	11A
0005435487987	19531	23	11C
0005435488002	19531	24	12A
0005435297115	19531	25	11F
0005435488003	19531	26	12D
0005435487986	19531	27	13A
0005434309770	19531	28	13C
0005435999224	19531	29	13F
0005435999221	19531	30	14D
0005435297117	19531	31	14E
0005434309719	19531	32	14F
0005435999248	19531	33	15B
0005435488006	19531	34	15D
0005435488001	19531	35	16D
0005435488000	19531	36	17A
0005435999203	19531	37	17C
0005435999233	19531	38	17D
0005435487990	19531	39	18A
0005435487992	19531	40	18C
0005435999149	19531	41	19A
0005435297120	19531	42	19C
0005435487989	19531	43	19F
0005435488004	19531	44	20D
0005434309699	19531	45	20F
0005435487998	19531	46	21D
0005435999242	19531	47	21F
0005435999237	19531	48	22D
0005434309756	19531	49	22F
0005435297118	19531	50	22E
0005434309698	19531	51	23B
0005435297116	19531	52	23D
0005435487985	19531	53	23F
0005434446517	17551	1	1B
0005433158148	17551	2	2D
0005433158151	17551	3	4B
0005433158147	17551	4	4D
0005433158149	17551	5	7D
0005434446521	17551	6	18A
0005433158150	17551	7	20D
0005434446514	17551	8	22B
0005434446522	17551	9	22C
0005435518049	1595	1	1C
0005435518062	1595	2	1D
0005435502485	1595	3	1F
0005435502494	1595	4	2C
0005434566032	1595	5	2D
0005435502503	1595	6	2F
0005434566024	1595	7	3A
0005435508447	1595	8	3C
0005434566025	1595	9	3D
0005435518070	1595	10	3F
0005434566028	1595	11	4A
0005435502493	1595	12	4C
0005435508453	1595	13	4D
0005435518072	1595	14	4E
0005435502487	1595	15	4F
0005435502496	1595	16	5A
0005435502505	1595	17	5C
0005435508449	1595	18	5D
0005435508454	1595	19	5E
0005435502486	1595	20	5F
0005435518068	1595	21	6A
0005435508459	1595	22	6D
0005433186073	1595	23	6C
0005435502495	1595	24	6E
0005435518066	1595	25	6F
0005433186124	1595	26	7A
0005435502498	1595	27	7C
0005435518067	1595	28	7D
0005434566031	1595	29	7E
0005435518058	1595	30	8A
0005434566036	1595	31	8C
0005435518052	1595	32	8D
0005434566033	1595	33	8E
0005434566034	1595	34	8F
0005435518053	1595	35	9A
0005435518050	1595	36	9C
0005435508448	1595	37	9D
0005435502506	1595	38	9E
0005435518069	1595	39	9F
0005434566029	1595	40	10C
0005435508451	1595	41	10D
0005435502497	1595	42	10E
0005435518059	1595	43	10F
0005435502490	1595	44	11A
0005435502492	1595	45	11C
0005435518051	1595	46	11D
0005435518071	1595	47	11E
0005435508452	1595	48	11F
0005435518064	1595	49	12A
0005434566026	1595	50	12D
0005432291951	1595	51	12E
0005435518057	1595	52	12F
0005435508455	1595	53	13C
0005435502501	1595	54	13E
0005435508462	1595	55	13F
0005435518055	1595	56	14A
0005433186091	1595	57	14C
0005435518061	1595	58	15A
0005435508460	1595	59	15D
0005434566023	1595	60	15E
0005435502499	1595	61	15F
0005435518054	1595	62	16A
0005435508461	1595	63	16C
0005435508457	1595	64	16D
0005435502488	1595	65	16E
0005435502502	1595	66	17C
0005435502504	1595	67	17D
0005435508450	1595	68	17E
0005434566027	1595	69	18A
0005435518065	1595	70	18C
0005435502489	1595	71	18D
0005435502507	1595	72	18E
0005432291950	1595	73	18F
0005435502500	1595	74	19A
0005434566030	1595	75	19D
0005435518063	1595	76	19E
0005435502491	1595	77	19F
0005435508458	1595	78	20A
0005435508456	1595	79	20C
0005435518056	1595	80	20D
0005434566035	1595	81	20E
0005435518060	1595	82	20F
0005435545697	20888	1	1A
0005435502281	20888	2	1C
0005435502264	20888	3	1D
0005435529182	20888	4	1F
0005435502292	20888	5	2A
0005435545677	20888	6	2D
0005435502257	20888	7	2F
0005433186192	20888	8	3C
0005435502311	20888	9	4A
0005434565951	20888	10	4C
0005434565857	20888	11	4D
0005435502263	20888	12	4E
0005435502339	20888	13	5A
0005434565894	20888	14	5C
0005435529221	20888	15	5E
0005433186189	20888	16	5F
0005435529192	20888	17	6A
0005435502368	20888	18	6D
0005435529270	20888	19	6E
0005435502362	20888	20	7A
0005435529246	20888	21	7C
0005435529189	20888	22	7E
0005433186195	20888	23	8C
0005434565851	20888	24	8D
0005434565850	20888	25	8E
0005434565938	20888	26	8F
0005435529173	20888	27	9A
0005434565871	20888	28	9D
0005435529169	20888	29	9F
0005435529154	20888	30	10A
0005435545719	20888	31	10C
0005435545721	20888	32	10D
0005435502227	20888	33	11A
0005434565876	20888	34	11C
0005435529257	20888	35	11D
0005435545720	20888	36	11F
0005434565887	20888	37	12D
0005433186188	20888	38	12E
0005434565860	20888	39	13A
0005433186193	20888	40	13C
0005434565933	20888	41	13D
0005435502238	20888	42	13E
0005435502293	20888	43	13F
0005434565952	20888	44	14A
0005435502219	20888	45	14C
0005434565976	20888	46	14D
0005433186187	20888	47	14E
0005435545704	20888	48	14F
0005434565867	20888	49	15A
0005435529172	20888	50	15C
0005435502315	20888	51	15F
0005435502226	20888	52	16C
0005435502360	20888	53	16D
0005435502367	20888	54	16E
0005435529147	20888	55	16F
0005433186194	20888	56	17A
0005435545699	20888	57	17C
0005435529220	20888	58	18A
0005435502294	20888	59	18C
0005433186190	20888	60	18D
0005435529164	20888	61	18E
0005435529204	20888	62	19A
0005433186191	20888	63	19C
0005435502228	20888	64	19D
0005435529193	20888	65	19E
0005435529186	20888	66	19F
0005435502237	20888	67	20A
0005435545698	20888	68	20C
0005434565977	20888	69	20D
0005435529231	20888	70	20E
0005435153800	3895	1	2B
0005435153796	3895	2	2C
0005435153798	3895	3	3B
0005435153801	3895	4	3C
0005435153797	3895	5	4B
0005435931592	3895	6	5C
0005435153799	3895	7	21C
0005435153746	21873	1	1D
0005435153729	21873	2	3C
0005435153742	21873	3	3D
0005435153765	21873	4	4A
0005435931631	21873	5	5A
0005435153730	21873	6	5B
0005435931632	21873	7	5D
0005435153747	21873	8	6D
0005435153749	21873	9	7C
0005435931634	21873	10	18C
0005435931633	21873	11	22B
0005432628976	7184	1	1B
0005435225595	7184	2	2B
0005432628973	7184	3	3B
0005435225553	7184	4	4A
0005432628974	7184	5	4C
0005435225577	7184	6	4D
0005432628977	7184	7	5B
0005432628970	7184	8	6A
0005432628972	7184	9	6B
0005432628965	7184	10	6C
0005435225579	7184	11	7B
0005432628969	7184	12	7A
0005432628978	7184	13	7C
0005432628968	7184	14	7D
0005432628967	7184	15	19A
0005435225593	7184	16	19B
0005432628966	7184	17	19C
0005435225592	7184	18	20A
0005432628964	7184	19	20C
0005432628971	7184	20	21A
0005435225591	7184	21	21B
0005432628975	7184	22	21D
0005435225600	7184	23	22A
0005435225594	7184	24	22D
0005432628874	28091	1	2C
0005435225655	28091	2	2D
0005432628903	28091	3	4D
0005432628831	28091	4	6B
0005432628885	28091	5	7B
0005435225651	28091	6	18A
0005435225650	28091	7	18B
0005435225653	28091	8	18C
0005432628884	28091	9	18D
0005435225654	28091	10	19B
0005432628919	28091	11	19D
0005432628864	28091	12	20A
0005432628920	28091	13	20B
0005432628858	28091	14	21A
0005432628852	28091	15	21D
0005435225652	28091	16	22A
0005432628832	28091	17	22B
0005432628902	28091	18	22C
0005435225656	28091	19	23B
0005434267943	8752	1	1B
0005434267932	8752	2	1C
0005434267956	8752	3	1D
0005435960082	8752	4	2C
0005434267941	8752	5	4A
0005435960081	8752	6	4C
0005434267955	8752	7	5C
0005435960084	8752	8	7B
0005434267942	8752	9	18B
0005435960085	8752	10	20C
0005435960083	8752	11	20D
0005435960045	15237	1	1B
0005434267981	15237	2	4A
0005434267984	15237	3	6C
0005434267982	15237	4	7A
0005435960048	15237	5	19B
0005435960044	15237	6	19D
0005435960046	15237	7	20D
0005434267983	15237	8	22B
0005432675254	1186	1	1C
0005432675265	1186	2	1A
0005432873287	1186	3	1F
0005432693298	1186	4	2D
0005432693313	1186	5	3A
0005432675267	1186	6	3D
0005432693305	1186	7	3C
0005432873276	1186	8	3F
0005432693287	1186	9	4C
0005432675255	1186	10	5A
0005432873290	1186	11	5C
0005432677604	1186	12	5F
0005432693289	1186	13	6C
0005432873289	1186	14	6E
0005432675257	1186	15	6D
0005432693291	1186	16	7B
0005432693302	1186	17	7F
0005432675264	1186	18	8A
0005432675262	1186	19	9A
0005432693293	1186	20	9C
0005432693310	1186	21	10A
0005432693286	1186	22	10B
0005432873297	1186	23	11D
0005432693290	1186	24	11F
0005432675259	1186	25	11E
0005432675260	1186	26	12A
0005432693315	1186	27	12C
0005432693294	1186	28	12E
0005432675266	1186	29	12D
0005432675258	1186	30	13A
0005432693297	1186	31	13C
0005432677603	1186	32	13B
0005432873275	1186	33	13E
0005432693285	1186	34	13F
0005432693307	1186	35	14D
0005432675263	1186	36	15B
0005432693312	1186	37	15A
0005432693300	1186	38	15C
0005432693308	1186	39	15E
0005432693309	1186	40	16A
0005432693301	1186	41	16C
0005432693314	1186	42	16E
0005432693296	1186	43	17D
0005432675253	1186	44	17C
0005432693288	1186	45	18B
0005432693311	1186	46	17F
0005432675256	1186	47	18C
0005432693306	1186	48	18E
0005432693292	1186	49	19A
0005432675261	1186	50	18F
0005432677602	1186	51	19C
0005432693303	1186	52	19D
0005432693304	1186	53	20A
0005432693299	1186	54	20C
0005432693295	1186	55	21B
0005432873296	1186	56	21D
0005432675192	17505	1	1F
0005432692948	17505	2	2C
0005432693049	17505	3	2A
0005432692914	17505	4	2D
0005432677564	17505	5	3F
0005432677586	17505	6	4D
0005432677557	17505	7	5D
0005432873352	17505	8	6D
0005432677578	17505	9	6B
0005432693069	17505	10	6E
0005432873349	17505	11	6F
0005432692828	17505	12	7E
0005432675173	17505	13	7D
0005432693019	17505	14	8B
0005432693009	17505	15	8D
0005432693058	17505	16	8F
0005432675174	17505	17	8E
0005432677556	17505	18	9B
0005432693067	17505	19	9A
0005432693117	17505	20	9C
0005432675128	17505	21	10A
0005432692915	17505	22	9F
0005432692882	17505	23	10B
0005432873354	17505	24	10F
0005432675145	17505	25	10E
0005432675118	17505	26	11A
0005432692947	17505	27	11C
0005432693031	17505	28	11F
0005432873348	17505	29	12B
0005432675082	17505	30	13B
0005432693018	17505	31	13D
0005432692919	17505	32	14C
0005432692975	17505	33	14B
0005432693118	17505	34	14E
0005432873351	17505	35	15D
0005432693082	17505	36	15E
0005432692890	17505	37	16B
0005432693093	17505	38	16D
0005432693083	17505	39	17A
0005432677565	17505	40	17C
0005432873353	17505	41	18A
0005432873350	17505	42	18C
0005432677587	17505	43	18E
0005432693068	17505	44	18D
0005432692881	17505	45	18F
0005432677549	17505	46	19B
0005432675146	17505	47	19F
0005433156784	1150	1	1B
0005434435310	1150	2	1C
0005433156783	1150	3	1D
0005434435316	1150	4	2B
0005433156739	1150	5	2D
0005434435317	1150	6	3A
0005433156688	1150	7	3B
0005434435312	1150	8	3D
0005434435307	1150	9	4C
0005434435311	1150	10	4D
0005434435306	1150	11	5A
0005433156740	1150	12	5B
0005434435320	1150	13	5C
0005434435315	1150	14	6B
0005434435309	1150	15	6D
0005434435305	1150	16	7A
0005434435318	1150	17	18B
0005434435304	1150	18	19B
0005433156794	1150	19	19D
0005434435313	1150	20	20B
0005433156760	1150	21	20C
0005434435319	1150	22	20D
0005433156689	1150	23	22D
0005434435314	1150	24	23A
0005434435308	1150	25	23B
0005433156825	17321	1	1A
0005434435184	17321	2	1C
0005433156820	17321	3	2A
0005434435179	17321	4	2C
0005434435155	17321	5	2D
0005434435128	17321	6	3B
0005434435187	17321	7	3D
0005434435251	17321	8	4A
0005434435188	17321	9	4B
0005434435102	17321	10	4C
0005434435214	17321	11	4D
0005434435186	17321	12	5A
0005433156822	17321	13	5C
0005434435120	17321	14	6A
0005434435183	17321	15	6B
0005434435213	17321	16	6C
0005433156819	17321	17	7B
0005434435216	17321	18	7D
0005434435087	17321	19	18A
0005433156826	17321	20	18C
0005434435142	17321	21	18D
0005434435127	17321	22	19B
0005433156824	17321	23	19D
0005434435217	17321	24	20A
0005434435119	17321	25	20C
0005434435141	17321	26	20D
0005434435084	17321	27	21A
0005434435126	17321	28	21C
0005433156823	17321	29	22B
0005433156821	17321	30	22D
0005434435118	17321	31	23B
0005435086897	4105	1	1B
0005435086898	4105	2	3B
0005435086900	4105	3	5D
0005435086894	4105	4	6B
0005435086902	4105	5	7A
0005435086899	4105	6	19A
0005435086896	4105	7	21A
0005435928140	4105	8	21B
0005435086901	4105	9	21C
0005435086895	4105	10	22A
0005435928126	4105	11	23B
0005435928183	24424	1	1C
0005435086828	24424	2	3A
0005435086815	24424	3	3B
0005435086829	24424	4	4A
0005435086811	24424	5	5A
0005435086846	24424	6	5B
0005435086819	24424	7	7B
0005435928185	24424	8	19A
0005435928182	24424	9	22A
0005435928184	24424	10	22D
0005435706510	2458	1	1A
0005435706522	2458	2	1C
0005435706499	2458	3	1D
0005433373563	2458	4	2A
0005433373531	2458	5	3D
0005435706505	2458	6	4A
0005433373536	2458	7	4C
0005435706528	2458	8	4E
0005435706500	2458	9	5C
0005433373555	2458	10	6A
0005435706507	2458	11	6C
0005435706524	2458	12	6D
0005435706517	2458	13	6E
0005435706526	2458	14	6F
0005433373537	2458	15	7C
0005435706503	2458	16	7D
0005435706508	2458	17	7E
0005435706523	2458	18	7F
0005435706513	2458	19	8A
0005435706511	2458	20	8C
0005435706506	2458	21	8F
0005435706518	2458	22	9E
0005435706525	2458	23	9F
0005435706504	2458	24	10A
0005435706532	2458	25	10C
0005435706512	2458	26	10D
0005433373506	2458	27	10E
0005435706515	2458	28	10F
0005435706509	2458	29	11D
0005435706519	2458	30	12D
0005433373551	2458	31	12E
0005435706527	2458	32	13A
0005435706531	2458	33	14A
0005435706530	2458	34	14E
0005435706501	2458	35	15A
0005435706514	2458	36	15E
0005433373517	2458	37	16A
0005435706502	2458	38	16C
0005435706516	2458	39	16D
0005433373480	2458	40	16F
0005433373510	2458	41	17C
0005433373505	2458	42	17E
0005435706521	2458	43	17F
0005433373540	2458	44	18A
0005433373524	2458	45	18C
0005433373546	2458	46	19D
0005433373470	2458	47	19E
0005435706529	2458	48	19F
0005435706520	2458	49	20D
0005433373529	2458	50	20E
0005433373562	2458	51	20F
0005435706329	27032	1	1A
0005435706444	27032	2	1C
0005433373611	27032	3	1D
0005435706316	27032	4	1F
0005435706386	27032	5	2A
0005435706373	27032	6	2D
0005435706389	27032	7	2F
0005435706410	27032	8	3C
0005435706314	27032	9	3F
0005435706372	27032	10	4A
0005435706412	27032	11	4C
0005435706390	27032	12	4D
0005435706446	27032	13	5A
0005433373616	27032	14	5D
0005435706313	27032	15	6A
0005435706332	27032	16	6C
0005435706338	27032	17	7A
0005435706345	27032	18	7C
0005433373613	27032	19	7D
0005435706371	27032	20	7E
0005433373617	27032	21	7F
0005435706357	27032	22	8A
0005433373602	27032	23	8C
0005433373610	27032	24	8E
0005435706355	27032	25	8F
0005433373607	27032	26	9F
0005435706361	27032	27	10A
0005433373604	27032	28	10C
0005435706328	27032	29	10D
0005433373599	27032	30	11A
0005435706376	27032	31	11D
0005433373600	27032	32	11F
0005435706344	27032	33	12A
0005435706398	27032	34	12C
0005433373606	27032	35	12D
0005435706445	27032	36	12F
0005435706365	27032	37	13F
0005435706364	27032	38	14A
0005435706309	27032	39	14C
0005435706319	27032	40	14D
0005435706337	27032	41	14E
0005435706413	27032	42	15C
0005433373609	27032	43	15D
0005433373601	27032	44	15E
0005433373603	27032	45	16D
0005435706318	27032	46	16F
0005433373615	27032	47	17A
0005435706322	27032	48	17C
0005433373605	27032	49	17D
0005435706331	27032	50	17F
0005433373612	27032	51	18C
0005435706360	27032	52	18E
0005435706317	27032	53	19D
0005435706375	27032	54	19E
0005433373614	27032	55	20A
0005433373608	27032	56	20C
0005435706346	27032	57	20D
0005435706387	27032	58	20F
0005434964391	1324	1	1C
0005433261564	1324	2	1B
0005433261511	1324	3	1F
0005434964397	1324	4	3C
0005434964371	1324	5	3B
0005434964401	1324	6	4A
0005433261537	1324	7	3H
0005434964359	1324	8	4B
0005433261573	1324	9	4F
0005432279290	1324	10	5A
0005433261549	1324	11	4H
0005433261542	1324	12	5C
0005433261572	1324	13	5H
0005434964364	1324	14	9B
0005433261568	1324	15	9H
0005433261550	1324	16	11D
0005434964381	1324	17	11F
0005434964394	1324	18	11H
0005433261558	1324	19	12A
0005434964370	1324	20	12E
0005433261540	1324	21	12D
0005434964384	1324	22	12G
0005434964382	1324	23	13D
0005434964376	1324	24	13B
0005433261510	1324	25	13E
0005432279287	1324	26	13G
0005434964392	1324	27	13F
0005434964389	1324	28	13H
0005434964357	1324	29	14A
0005432279286	1324	30	14G
0005432279285	1324	31	15B
0005433261575	1324	32	15D
0005433261536	1324	33	15F
0005433261544	1324	34	15H
0005434964346	1324	35	16B
0005434964366	1324	36	16F
0005434964379	1324	37	16H
0005434964353	1324	38	17B
0005433261545	1324	39	17G
0005433261539	1324	40	17H
0005434964385	1324	41	18B
0005434964355	1324	42	19A
0005433261552	1324	43	18H
0005434964399	1324	44	19B
0005434964369	1324	45	19F
0005434964386	1324	46	19H
0005433261555	1324	47	19G
0005434964363	1324	48	20A
0005433261584	1324	49	20E
0005434964390	1324	50	20D
0005433261567	1324	51	20G
0005434964349	1324	52	20H
0005433261571	1324	53	21B
0005433261541	1324	54	22B
0005434964374	1324	55	22A
0005434964351	1324	56	22E
0005434964387	1324	57	22H
0005433261509	1324	58	23A
0005433261548	1324	59	23D
0005434964383	1324	60	23F
0005434964373	1324	61	23E
0005434964360	1324	62	23H
0005434964395	1324	63	23G
0005434964358	1324	64	24D
0005434964393	1324	65	24F
0005434964354	1324	66	24G
0005434964347	1324	67	25F
0005434964368	1324	68	27A
0005433261551	1324	69	27F
0005434964388	1324	70	27G
0005434964378	1324	71	27H
0005434964344	1324	72	28D
0005434964362	1324	73	29A
0005433261524	1324	74	29B
0005434964375	1324	75	29F
0005433261543	1324	76	30E
0005434964367	1324	77	30G
0005434964400	1324	78	30F
0005434964365	1324	79	32B
0005434964361	1324	80	32E
0005433261553	1324	81	32F
0005434964356	1324	82	33A
0005434964377	1324	83	33B
0005433261512	1324	84	33D
0005434964398	1324	85	33F
0005434964396	1324	86	34G
0005433261574	1324	87	35D
0005434964345	1324	88	35F
0005434964350	1324	89	35G
0005433261513	1324	90	36B
0005434964348	1324	91	36H
0005432279288	1324	92	37D
0005434964380	1324	93	37H
0005434964372	1324	94	38E
0005433261563	1324	95	38H
0005434964352	1324	96	38G
0005432279289	1324	97	39D
0005434626039	4860	1	1F
0005433194851	4860	2	5C
0005435907496	4860	3	7A
0005434626045	4860	4	7D
0005434626042	4860	5	8F
0005435907512	4860	6	9E
0005435907517	4860	7	10E
0005434626040	4860	8	11A
0005434626043	4860	9	13A
0005434626038	4860	10	13E
0005434626041	4860	11	18A
0005434626044	4860	12	18C
0005434626037	4860	13	20C
0005434625980	32911	1	1C
0005434625990	32911	2	1D
0005434625995	32911	3	2C
0005433194887	32911	4	4C
0005434625996	32911	5	4D
0005435907543	32911	6	4F
0005435907546	32911	7	5E
0005434625909	32911	8	7A
0005433194880	32911	9	7C
0005433194883	32911	10	8A
0005433194884	32911	11	8C
0005433194879	32911	12	10C
0005435907542	32911	13	10D
0005433194885	32911	14	10E
0005435907544	32911	15	10F
0005434625939	32911	16	13A
0005433194878	32911	17	13E
0005433194881	32911	18	14A
0005433194877	32911	19	14C
0005435907547	32911	20	15A
0005435907545	32911	21	16C
0005433194882	32911	22	19A
0005434625941	32911	23	19F
0005433194886	32911	24	20D
0005435787344	13807	1	1B
0005435785267	13807	2	1A
0005435785227	13807	3	1C
0005435785085	13807	4	1D
0005432195711	13807	5	2A
0005435785187	13807	6	2B
0005435787345	13807	7	2C
0005435785179	13807	8	2D
0005435785297	13807	9	3A
0005435785166	13807	10	3B
0005435937417	13807	11	3C
0005435785264	13807	12	3D
0005435785225	13807	13	4A
0005435787358	13807	14	4B
0005435785285	13807	15	4C
0005435785196	13807	16	4D
0005435785177	13807	17	5A
0005435785228	13807	18	5B
0005435785218	13807	19	5C
0005435785462	13807	20	5D
0005435785359	13807	21	6A
0005435785183	13807	22	6B
0005435785276	13807	23	6C
0005435785383	13807	24	6D
0005435785329	13807	25	7A
0005435785340	13807	26	7B
0005435787357	13807	27	7C
0005435785374	13807	28	7D
0005435937416	13807	29	18A
0005435785384	13807	30	18C
0005435785223	13807	31	18D
0005435785328	13807	32	19A
0005435785483	13807	33	19B
0005435785331	13807	34	19C
0005435785208	13807	35	19D
0005435785119	13807	36	20A
0005435785226	13807	37	20B
0005435785330	13807	38	20C
0005435787359	13807	39	20D
0005435785412	13807	40	21A
0005435787349	13807	41	21B
0005435785161	13807	42	21C
0005435785219	13807	43	21D
0005435785243	13807	44	22A
0005432195710	13807	45	22B
0005435785339	13807	46	22C
0005435785118	13807	47	23A
0005435785240	13807	48	23B
0005432190656	27404	1	1A
0005435785591	27404	2	1B
0005435785582	27404	3	1C
0005435937377	27404	4	1D
0005435785603	27404	5	2A
0005435937373	27404	6	2B
0005435785585	27404	7	2C
0005435785580	27404	8	2D
0005435785587	27404	9	3A
0005435785589	27404	10	3B
0005435785590	27404	11	3C
0005432190657	27404	12	3D
0005435785602	27404	13	4A
0005435785588	27404	14	4B
0005435937369	27404	15	4C
0005435787369	27404	16	4D
0005435785606	27404	17	5A
0005435787370	27404	18	5B
0005435785594	27404	19	5C
0005435785578	27404	20	5D
0005435785608	27404	21	6A
0005435785592	27404	22	6B
0005435785601	27404	23	6C
0005435785604	27404	24	6D
0005435785599	27404	25	7A
0005435785583	27404	26	7B
0005435785584	27404	27	7C
0005435785579	27404	28	7D
0005435785600	27404	29	18A
0005435785598	27404	30	18B
0005432190654	27404	31	18C
0005435785609	27404	32	18D
0005435785612	27404	33	19A
0005435785596	27404	34	19B
0005435785597	27404	35	19C
0005435785586	27404	36	20A
0005435785611	27404	37	20C
0005435937367	27404	38	20D
0005435785581	27404	39	21A
0005432190655	27404	40	21B
0005435787368	27404	41	21C
0005435785593	27404	42	21D
0005435785610	27404	43	22A
0005435785605	27404	44	22B
0005435785607	27404	45	22C
0005435937376	27404	46	22D
0005435785595	27404	47	23A
0005435785613	27404	48	23B
0005434407486	20249	1	1A
0005434407426	20249	2	1D
0005434407539	20249	3	2D
0005432058413	20249	4	2F
0005432058417	20249	5	3C
0005432058414	20249	6	3D
0005434407969	20249	7	3F
0005435311157	20249	8	4C
0005434407754	20249	9	4A
0005434407927	20249	10	4D
0005434407873	20249	11	4E
0005434407857	20249	12	4F
0005434408023	20249	13	5D
0005434407780	20249	14	5E
0005434407557	20249	15	5F
0005434407644	20249	16	6A
0005435311161	20249	17	6C
0005435311162	20249	18	6D
0005434407951	20249	19	6E
0005434407577	20249	20	6F
0005434407738	20249	21	7C
0005434407540	20249	22	7D
0005434407858	20249	23	7E
0005434407856	20249	24	8A
0005434407878	20249	25	8C
0005434407748	20249	26	8D
0005434407753	20249	27	8E
0005434407549	20249	28	9C
0005434407758	20249	29	9D
0005434407762	20249	30	9F
0005434407771	20249	31	10A
0005434407494	20249	32	10C
0005434407957	20249	33	10D
0005434407601	20249	34	10F
0005435311160	20249	35	11C
0005434407896	20249	36	11D
0005434407584	20249	37	11E
0005435311159	20249	38	11F
0005434407772	20249	39	12C
0005434407675	20249	40	12F
0005432058415	20249	41	13A
0005434407678	20249	42	13C
0005434407855	20249	43	13D
0005434407928	20249	44	13E
0005434408024	20249	45	13F
0005434407874	20249	46	14C
0005434407939	20249	47	14D
0005434407879	20249	48	14E
0005434407898	20249	49	14F
0005434407714	20249	50	15A
0005434407741	20249	51	15D
0005432058416	20249	52	15F
0005434407495	20249	53	16A
0005434407583	20249	54	16C
0005434407838	20249	55	16D
0005435311158	20249	56	16E
0005434407630	20249	57	17A
0005434407631	20249	58	17C
0005434407859	20249	59	17D
0005434407715	20249	60	17E
0005434407679	20249	61	18A
0005434407791	20249	62	18E
0005434407815	20249	63	19A
0005434407773	20249	64	19D
0005434408025	20249	65	19E
0005434407781	20249	66	19F
0005434407792	20249	67	20A
0005434407740	20249	68	20C
0005434407564	20249	69	20E
0005434407561	20249	70	20F
0005435311064	27002	1	1A
0005434408254	27002	2	1C
0005434408259	27002	3	1D
0005434408301	27002	4	1F
0005434408284	27002	5	2A
0005432153995	27002	6	2C
0005434408294	27002	7	2D
0005432153998	27002	8	2F
0005434408283	27002	9	3C
0005434408268	27002	10	3D
0005434408302	27002	11	3F
0005434408313	27002	12	4A
0005434408281	27002	13	4C
0005434408307	27002	14	4E
0005435311051	27002	15	4F
0005432153994	27002	16	5A
0005435311050	27002	17	5C
0005434408265	27002	18	5D
0005434408267	27002	19	5F
0005434408287	27002	20	6A
0005434408272	27002	21	6C
0005434408310	27002	22	6D
0005434408270	27002	23	6E
0005434408258	27002	24	6F
0005434408289	27002	25	7A
0005434408262	27002	26	7C
0005434408304	27002	27	7D
0005434408255	27002	28	7E
0005434408308	27002	29	7F
0005434408293	27002	30	8A
0005434408295	27002	31	8C
0005434408264	27002	32	8D
0005434408263	27002	33	8E
0005434408306	27002	34	8F
0005434408290	27002	35	9A
0005434408286	27002	36	9D
0005434408292	27002	37	9E
0005435311049	27002	38	9F
0005435311061	27002	39	10A
0005432153993	27002	40	10C
0005434408312	27002	41	10D
0005434408316	27002	42	10E
0005434408276	27002	43	10F
0005434408277	27002	44	11A
0005434408275	27002	45	11C
0005432153996	27002	46	11D
0005434408274	27002	47	11F
0005434408260	27002	48	12A
0005434408314	27002	49	12C
0005435311046	27002	50	12E
0005434408303	27002	51	13A
0005435311039	27002	52	13C
0005434408317	27002	53	13D
0005434408256	27002	54	13E
0005432153997	27002	55	13F
0005434408311	27002	56	14A
0005432153999	27002	57	14C
0005434408296	27002	58	14D
0005434408261	27002	59	14E
0005434408273	27002	60	14F
0005434408297	27002	61	15C
0005435311015	27002	62	15D
0005434408300	27002	63	15E
0005434408305	27002	64	16C
0005434408278	27002	65	16F
0005434408309	27002	66	17C
0005434408257	27002	67	17D
0005434408269	27002	68	17E
0005435311047	27002	69	17F
0005434408315	27002	70	18A
0005434408285	27002	71	18C
0005434408279	27002	72	18D
0005434408266	27002	73	18F
0005435311055	27002	74	19A
0005434408299	27002	75	19C
0005434408291	27002	76	19D
0005434408280	27002	77	19E
0005434408271	27002	78	19F
0005435311040	27002	79	20A
0005435311014	27002	80	20C
0005434408298	27002	81	20D
0005434408282	27002	82	20E
0005434408288	27002	83	20F
0005432109726	5723	1	1C
0005433123942	5723	2	2A
0005434319520	5723	3	2C
0005434319513	5723	4	2F
0005433123914	5723	5	3A
0005434319526	5723	6	3D
0005434319511	5723	7	3F
0005433123854	5723	8	4E
0005434319524	5723	9	5D
0005434319518	5723	10	5E
0005433123866	5723	11	6A
0005434319522	5723	12	6C
0005434319512	5723	13	7F
0005433123944	5723	14	8C
0005432109725	5723	15	8F
0005434319519	5723	16	9A
0005433123965	5723	17	9E
0005434319516	5723	18	10F
0005433123912	5723	19	11F
0005432109727	5723	20	12C
0005433123915	5723	21	12D
0005434319527	5723	22	12E
0005433123948	5723	23	12F
0005434319525	5723	24	13A
0005434319517	5723	25	13E
0005433123943	5723	26	13F
0005434319510	5723	27	14D
0005434319515	5723	28	16A
0005433123947	5723	29	16C
0005433123884	5723	30	17A
0005433123923	5723	31	17C
0005434319514	5723	32	17F
0005434319521	5723	33	18A
0005433123927	5723	34	18F
0005434319528	5723	35	19A
0005433123848	5723	36	19C
0005434319523	5723	37	19D
0005433123885	5723	38	19F
0005433123911	5723	39	20A
0005434311237	5723	40	20C
0005434319349	15656	1	1A
0005433124100	15656	2	2A
0005433124102	15656	3	2C
0005434311211	15656	4	2D
0005433124113	15656	5	3A
0005433124106	15656	6	4A
0005433124103	15656	7	4C
0005434319342	15656	8	4D
0005433124101	15656	9	5A
0005434319303	15656	10	5C
0005433124109	15656	11	5D
0005434312300	15656	12	5F
0005433124098	15656	13	6E
0005433124105	15656	14	6F
0005433124117	15656	15	7A
0005433124119	15656	16	7C
0005433124118	15656	17	8C
0005434311210	15656	18	8D
0005434319276	15656	19	10A
0005434319302	15656	20	10E
0005433124108	15656	21	11C
0005434319350	15656	22	11F
0005433124111	15656	23	12A
0005433124110	15656	24	12C
0005434311225	15656	25	12E
0005433124116	15656	26	12F
0005433124099	15656	27	13A
0005434311221	15656	28	13E
0005433124115	15656	29	14D
0005434319293	15656	30	15E
0005433124107	15656	31	15F
0005434312301	15656	32	16C
0005433124112	15656	33	16E
0005434319294	15656	34	16F
0005434319304	15656	35	17A
0005434312317	15656	36	17E
0005433124097	15656	37	18C
0005433124114	15656	38	18F
0005433124104	15656	39	19C
0005434311224	15656	40	19F
0005434312302	15656	41	20F
0005435219218	31745	1	3B
0005435220338	31745	2	3D
0005435220335	31745	3	5B
0005435219216	31745	4	6D
0005435220339	31745	5	18D
0005435220336	31745	6	19A
0005435219219	31745	7	20A
0005435220337	31745	8	20D
0005435219217	31745	9	21A
0005435219220	31745	10	23B
0005434189161	8992	1	1C
0005434189160	8992	2	2D
0005434484403	8992	3	3C
0005434484400	8992	4	5A
0005434484404	8992	5	5B
0005434484405	8992	6	6B
0005434189163	8992	7	6D
0005434484402	8992	8	7B
0005434189164	8992	9	7C
0005434189149	8992	10	19D
0005434484401	8992	11	20A
0005434484309	16658	1	1C
0005434484324	16658	2	2A
0005434189227	16658	3	3D
0005434484336	16658	4	4C
0005434484316	16658	5	6A
0005434484370	16658	6	6D
0005434484359	16658	7	7A
0005434189229	16658	8	18C
0005434189228	16658	9	19B
0005434484310	16658	10	19D
0005434484315	16658	11	20D
0005434484348	16658	12	21D
0005434189226	16658	13	23B
0005433124112	7535	1	1D
0005433124101	7535	2	2A
0005433124105	7535	3	3F
0005433124099	7535	4	4D
0005433124118	7535	5	4E
0005433722194	7535	6	4F
0005433124100	7535	7	5D
0005433124113	7535	8	6A
0005433722216	7535	9	6D
0005433124114	7535	10	6F
0005433124103	7535	11	7A
0005433124119	7535	12	7C
0005433124115	7535	13	7D
0005433124106	7535	14	7F
0005433124111	7535	15	9D
0005433722202	7535	16	9E
0005433722201	7535	17	10C
0005433124117	7535	18	11A
0005433124098	7535	19	11C
0005433722211	7535	20	12A
0005433124116	7535	21	12D
0005433124102	7535	22	12F
0005433124108	7535	23	13C
0005433722215	7535	24	13E
0005433722212	7535	25	13F
0005433124097	7535	26	14D
0005433124104	7535	27	15E
0005433124107	7535	28	18A
0005433124110	7535	29	18F
0005433124109	7535	30	20E
0005432693327	7716	1	1A
0005432693342	7716	2	1C
0005432721123	7716	3	2A
0005432071598	7716	4	2C
0005432721119	7716	5	2D
0005432693317	7716	6	2F
0005432721140	7716	7	3A
0005432693319	7716	8	3C
0005432721138	7716	9	3D
0005432693320	7716	10	3F
0005432693323	7716	11	4A
0005432693331	7716	12	4C
0005433450155	7716	13	4D
0005433450151	7716	14	5A
0005433450160	7716	15	5C
0005432693347	7716	16	5D
0005433450158	7716	17	5E
0005433450143	7716	18	5F
0005432721136	7716	19	6C
0005432693333	7716	20	6D
0005432721129	7716	21	6E
0005432721141	7716	22	6F
0005432721139	7716	23	7A
0005432693321	7716	24	7C
0005432721128	7716	25	7E
0005432721142	7716	26	7F
0005432721137	7716	27	8A
0005432693345	7716	28	8C
0005432721132	7716	29	8D
0005432693340	7716	30	8E
0005433450147	7716	31	8F
0005433450156	7716	32	9A
0005432721121	7716	33	9C
0005432693337	7716	34	9E
0005432071600	7716	35	9F
0005433450142	7716	36	10C
0005432721130	7716	37	10D
0005432693316	7716	38	10E
0005432693332	7716	39	10F
0005432693322	7716	40	11A
0005432721120	7716	41	11C
0005432721133	7716	42	11D
0005432693325	7716	43	11E
0005433450148	7716	44	11F
0005432693344	7716	45	12A
0005432693335	7716	46	12C
0005433450157	7716	47	12D
0005432721124	7716	48	12E
0005432693343	7716	49	12F
0005432721134	7716	50	13A
0005432693326	7716	51	13C
0005432693339	7716	52	13D
0005433450146	7716	53	13E
0005432693346	7716	54	13F
0005432693328	7716	55	14A
0005432693324	7716	56	14C
0005432693329	7716	57	14D
0005432693336	7716	58	14E
0005432721116	7716	59	14F
0005433450162	7716	60	15A
0005432721135	7716	61	15C
0005433450153	7716	62	15D
0005432693334	7716	63	15E
0005433450149	7716	64	16A
0005433450161	7716	65	15F
0005432071599	7716	66	16C
0005433450141	7716	67	16D
0005433450154	7716	68	16E
0005432721127	7716	69	17A
0005432693318	7716	70	17D
0005432693330	7716	71	17E
0005433450152	7716	72	17F
0005433450145	7716	73	18A
0005433450159	7716	74	18C
0005432721117	7716	75	18D
0005432721131	7716	76	18F
0005432721118	7716	77	19A
0005432721125	7716	78	19C
0005432693341	7716	79	19D
0005433450150	7716	80	19E
0005432693338	7716	81	20A
0005433450144	7716	82	20D
0005432721126	7716	83	20E
0005432721122	7716	84	20F
0005432693083	30311	1	1A
0005432692919	30311	2	1D
0005433449931	30311	3	1F
0005432693069	30311	4	2A
0005432693009	30311	5	3A
0005432693049	30311	6	3D
0005432692948	30311	7	3F
0005433449993	30311	8	4C
0005433450012	30311	9	5D
0005432693093	30311	10	5E
0005432692828	30311	11	5F
0005432692975	30311	12	6E
0005432693019	30311	13	7A
0005432692915	30311	14	7C
0005432693118	30311	15	7E
0005432693018	30311	16	8A
0005432692882	30311	17	9C
0005433449820	30311	18	9F
0005432692914	30311	19	10E
0005433449898	30311	20	11D
0005432693082	30311	21	12A
0005433449992	30311	22	12C
0005432693068	30311	23	12F
0005433449819	30311	24	13A
0005433449940	30311	25	13F
0005433449974	30311	26	15A
0005432693067	30311	27	15C
0005432692947	30311	28	15D
0005432692890	30311	29	15E
0005432692881	30311	30	16A
0005432693031	30311	31	17D
0005432693058	30311	32	17F
0005432693117	30311	33	19A
0005433449956	30311	34	19C
0005433449939	30311	35	20A
0005433449899	30311	36	20F
0005432720879	30312	1	1C
0005433123911	30312	2	1F
0005432720927	30312	3	2C
0005433123915	30312	4	2F
0005433123923	30312	5	4C
0005432720897	30312	6	4F
0005432721021	30312	7	6A
0005432720871	30312	8	6C
0005433722279	30312	9	6D
0005433123914	30312	10	6E
0005433722280	30312	11	6F
0005433123947	30312	12	7C
0005433123965	30312	13	8A
0005432720939	30312	14	9A
0005432720894	30312	15	9C
0005433123948	30312	16	9D
0005433123912	30312	17	9E
0005433123854	30312	18	9F
0005432720947	30312	19	10C
0005432721009	30312	20	10E
0005433722278	30312	21	11A
0005432720876	30312	22	11F
0005433123944	30312	23	12C
0005432721085	30312	24	12E
0005432720923	30312	25	12F
0005432720926	30312	26	13A
0005432720972	30312	27	13D
0005433123884	30312	28	13F
0005433123942	30312	29	14D
0005432720896	30312	30	15C
0005432720880	30312	31	15E
0005433123927	30312	32	16C
0005432720838	30312	33	16E
0005432720900	30312	34	16F
0005432720840	30312	35	17A
0005433123848	30312	36	17C
0005432720928	30312	37	17D
0005432720924	30312	38	18D
0005433722277	30312	39	18E
0005433123943	30312	40	19A
0005433722281	30312	41	19C
0005433123885	30312	42	19E
0005432720799	30312	43	19F
0005433123866	30312	44	20A
0005432720839	30312	45	20E
0005432720873	30312	46	20F
0005434586838	1388	1	1A
0005432271028	1388	2	1C
0005433193008	1388	3	1F
0005433525126	1388	4	2C
0005432271029	1388	5	2D
0005433193031	1388	6	2F
0005434586834	1388	7	3A
0005434586827	1388	8	3D
0005433193077	1388	9	3F
0005434586840	1388	10	4A
0005434586839	1388	11	4C
0005433193064	1388	12	4D
0005434586832	1388	13	4E
0005434586837	1388	14	4F
0005432968833	1388	15	5A
0005433193061	1388	16	5C
0005434586816	1388	17	5D
0005434586822	1388	18	5E
0005433525133	1388	19	5F
0005433525127	1388	20	6A
0005433525131	1388	21	6C
0005432927983	1388	22	6D
0005434586817	1388	23	6E
0005434586826	1388	24	7A
0005434586829	1388	25	7C
0005433724844	1388	26	7E
0005433193073	1388	27	7F
0005433193069	1388	28	8A
0005433193071	1388	29	8D
0005434586820	1388	30	8E
0005434514988	1388	31	8F
0005434586836	1388	32	9D
0005434586830	1388	33	9F
0005433193062	1388	34	10A
0005432271030	1388	35	10C
0005434586815	1388	36	10D
0005433193063	1388	37	10E
0005434586824	1388	38	10F
0005433525130	1388	39	11A
0005433724845	1388	40	11C
0005434586835	1388	41	11D
0005433724842	1388	42	11E
0005433525134	1388	43	12A
0005434586818	1388	44	12D
0005434586821	1388	45	12E
0005432968842	1388	46	12F
0005433525129	1388	47	13C
0005432927968	1388	48	13D
0005434586841	1388	49	13E
0005432927978	1388	50	14A
0005433193095	1388	51	14C
0005434514990	1388	52	14D
0005434586833	1388	53	14E
0005433193003	1388	54	14F
0005434514989	1388	55	15A
0005434513602	1388	56	15C
0005432927965	1388	57	15E
0005433193037	1388	58	15F
0005433193072	1388	59	16A
0005432968832	1388	60	16C
0005433193038	1388	61	16D
0005433193109	1388	62	16F
0005433525128	1388	63	17C
0005433193007	1388	64	17D
0005433724843	1388	65	17E
0005434513601	1388	66	17F
0005434586831	1388	67	18A
0005434586828	1388	68	18D
0005433525135	1388	69	18F
0005433525132	1388	70	18E
0005434586825	1388	71	19A
0005433193023	1388	72	19D
0005432927964	1388	73	19F
0005434586819	1388	74	20A
0005434586823	1388	75	20C
0005432968844	1388	76	20F
0005434586583	18532	1	1A
0005433193157	18532	2	1C
0005434586571	18532	3	1D
0005433193156	18532	4	2A
0005434586649	18532	5	2C
0005434586651	18532	6	2D
0005434586582	18532	7	2F
0005434586632	18532	8	3A
0005434586620	18532	9	3C
0005434586692	18532	10	3D
0005433193155	18532	11	3F
0005432928025	18532	12	4D
0005432928023	18532	13	4E
0005433724796	18532	14	4F
0005434586618	18532	15	5A
0005433724810	18532	16	5C
0005434586604	18532	17	6A
0005434586502	18532	18	6D
0005434586637	18532	19	6E
0005434586626	18532	20	6F
0005433724797	18532	21	7C
0005434586572	18532	22	7F
0005434586619	18532	23	8A
0005433724811	18532	24	8C
0005432928028	18532	25	8E
0005432928026	18532	26	8F
0005433193163	18532	27	9C
0005434586682	18532	28	9D
0005432968858	18532	29	9E
0005434586655	18532	30	9F
0005434586581	18532	31	10C
0005433724798	18532	32	10D
0005434586680	18532	33	10E
0005433193152	18532	34	10F
0005433724824	18532	35	11C
0005433193159	18532	36	11D
0005434586600	18532	37	11F
0005433724788	18532	38	12A
0005433193151	18532	39	12C
0005432928024	18532	40	12E
0005433193158	18532	41	12F
0005434586555	18532	42	13A
0005433525008	18532	43	13E
0005434586603	18532	44	13F
0005432968859	18532	45	14A
0005433724825	18532	46	14D
0005434586644	18532	47	14F
0005433524945	18532	48	15A
0005434586650	18532	49	15E
0005433193161	18532	50	15F
0005434586573	18532	51	16A
0005433525043	18532	52	16D
0005433193154	18532	53	16E
0005433724799	18532	54	17A
0005434586638	18532	55	17C
0005432928027	18532	56	17D
0005433193162	18532	57	17E
0005434586593	18532	58	18A
0005434586679	18532	59	18C
0005434586625	18532	60	18F
0005433193160	18532	61	19A
0005434586501	18532	62	19C
0005434586452	18532	63	19D
0005434586591	18532	64	19E
0005434586514	18532	65	20A
0005434586627	18532	66	19F
0005433193153	18532	67	20C
0005434344491	11477	1	1A
0005434142643	11477	2	1B
0005434344474	11477	3	1C
0005434344484	11477	4	1D
0005435305011	11477	5	2A
0005434344483	11477	6	2C
0005434344492	11477	7	2D
0005435305009	11477	8	3B
0005434344470	11477	9	3C
0005434344480	11477	10	4A
0005434344493	11477	11	4B
0005435302213	11477	12	4C
0005434344472	11477	13	4D
0005434344477	11477	14	5A
0005434344473	11477	15	5B
0005434344496	11477	16	5C
0005435302186	11477	17	5D
0005434344495	11477	18	6A
0005434344485	11477	19	6B
0005434344489	11477	20	6C
0005434344498	11477	21	6D
0005435305008	11477	22	7A
0005435302180	11477	23	7B
0005435302185	11477	24	7D
0005434142645	11477	25	18A
0005434142644	11477	26	18B
0005435305010	11477	27	18D
0005434344471	11477	28	19B
0005434344478	11477	29	19C
0005434344481	11477	30	20A
0005434344475	11477	31	20B
0005434344494	11477	32	20C
0005434344486	11477	33	20D
0005434344490	11477	34	21B
0005434344476	11477	35	21C
0005434344487	11477	36	21D
0005434344488	11477	37	22B
0005435302181	11477	38	22C
0005434344479	11477	39	22D
0005434344482	11477	40	23A
0005434344497	11477	41	23B
0005434343998	29800	1	1A
0005435304196	29800	2	1B
0005435304197	29800	3	1C
0005434344308	29800	4	1D
0005434344139	29800	5	2A
0005434344140	29800	6	2B
0005434344204	29800	7	2C
0005434142594	29800	8	2D
0005434344126	29800	9	3A
0005434344171	29800	10	3B
0005434344195	29800	11	3C
0005434344083	29800	12	3D
0005435304193	29800	13	4A
0005434344230	29800	14	4B
0005434344164	29800	15	4C
0005434344128	29800	16	4D
0005434344232	29800	17	5B
0005435305029	29800	18	5C
0005434344231	29800	19	5D
0005434344229	29800	20	6B
0005434344206	29800	21	6C
0005434344266	29800	22	6D
0005434344200	29800	23	7A
0005434344172	29800	24	7B
0005435304194	29800	25	7C
0005434344201	29800	26	18A
0005434344033	29800	27	18B
0005434344191	29800	28	18C
0005434343920	29800	29	18D
0005434344145	29800	30	19A
0005434344082	29800	31	19B
0005434344192	29800	32	19C
0005434344105	29800	33	19D
0005434344129	29800	34	20A
0005435305028	29800	35	20B
0005434344032	29800	36	20C
0005435305030	29800	37	20D
0005434344289	29800	38	21A
0005434344177	29800	39	21B
0005434344202	29800	40	21C
0005435304195	29800	41	21D
0005434344149	29800	42	22A
0005434344207	29800	43	22B
0005434344106	29800	44	23A
0005435305031	29800	45	23B
0005435824857	1301	1	1D
0005435824843	1301	2	2C
0005433415661	1301	3	2A
0005433415715	1301	4	2D
0005435824853	1301	5	3A
0005433415655	1301	6	4A
0005433415609	1301	7	3F
0005435824842	1301	8	5C
0005435824849	1301	9	6D
0005435824860	1301	10	6E
0005433415646	1301	11	7B
0005435824861	1301	12	7A
0005433415629	1301	13	8A
0005435824852	1301	14	8C
0005433415654	1301	15	8D
0005433415694	1301	16	9B
0005435824851	1301	17	9D
0005435824839	1301	18	9F
0005435824848	1301	19	11A
0005433415693	1301	20	11E
0005435824846	1301	21	12B
0005433415699	1301	22	13A
0005432284582	1301	23	12F
0005435824855	1301	24	13B
0005433415644	1301	25	13E
0005435824844	1301	26	14A
0005435824841	1301	27	14C
0005433415713	1301	28	14B
0005435824850	1301	29	14D
0005433415634	1301	30	15B
0005435824864	1301	31	15C
0005435824845	1301	32	15D
0005432284583	1301	33	16E
0005433415687	1301	34	16D
0005435824838	1301	35	16F
0005435824847	1301	36	17D
0005435824840	1301	37	17C
0005435824854	1301	38	18B
0005433415628	1301	39	18E
0005433415667	1301	40	19B
0005435824858	1301	41	19E
0005435824862	1301	42	19C
0005435824856	1301	43	20D
0005435824863	1301	44	20C
0005433415714	1301	45	21B
0005435824859	1301	46	21C
0005432284584	1301	47	21E
0005433415660	1301	48	21F
0005433415795	17971	1	1A
0005435824606	17971	2	1F
0005433415796	17971	3	3C
0005435824683	17971	4	4C
0005435824651	17971	5	4F
0005433415800	17971	6	6C
0005435824541	17971	7	6E
0005435824628	17971	8	6D
0005433415792	17971	9	7C
0005433415787	17971	10	7F
0005435824626	17971	11	8B
0005433415788	17971	12	8C
0005435824518	17971	13	8F
0005433415799	17971	14	8E
0005433415786	17971	15	9C
0005433415794	17971	16	9F
0005435824690	17971	17	9D
0005433415793	17971	18	10A
0005435824575	17971	19	11F
0005435824592	17971	20	13A
0005433415797	17971	21	13D
0005435824752	17971	22	13C
0005435824696	17971	23	13E
0005433415789	17971	24	14B
0005435824560	17971	25	14E
0005433415790	17971	26	15F
0005435824629	17971	27	16E
0005433415791	17971	28	17E
0005433415801	17971	29	18A
0005433415798	17971	30	18D
0005435824750	17971	31	18E
0005435824591	17971	32	20A
0005435824574	17971	33	21C
0005432784253	5663	1	1A
0005435242833	5663	2	1C
0005432784239	5663	3	1D
0005435242778	5663	4	1F
0005432784249	5663	5	2A
0005432784224	5663	6	2C
0005435476737	5663	7	2D
0005432784231	5663	8	2F
0005432784247	5663	9	3A
0005432784270	5663	10	3C
0005432784255	5663	11	3D
0005435242900	5663	12	3F
0005432784223	5663	13	4A
0005432784236	5663	14	4C
0005432784246	5663	15	4D
0005432784222	5663	16	4E
0005435242842	5663	17	4F
0005432784234	5663	18	5A
0005435242893	5663	19	5C
0005432784229	5663	20	5D
0005435242791	5663	21	5E
0005432784250	5663	22	5F
0005432784262	5663	23	6A
0005432784233	5663	24	6C
0005432784237	5663	25	6D
0005435242834	5663	26	6E
0005432784238	5663	27	6F
0005432784265	5663	28	7A
0005435242773	5663	29	7C
0005435242895	5663	30	7D
0005432784268	5663	31	7E
0005432784248	5663	32	7F
0005432784266	5663	33	8A
0005432784235	5663	34	8C
0005435242820	5663	35	8D
0005435242782	5663	36	8E
0005432784252	5663	37	8F
0005435242931	5663	38	9A
0005432784259	5663	39	9C
0005435242822	5663	40	9D
0005435242779	5663	41	9E
0005435242824	5663	42	9F
0005435242836	5663	43	10A
0005432784230	5663	44	10C
0005432784267	5663	45	10D
0005432784244	5663	46	10E
0005435242843	5663	47	10F
0005432784256	5663	48	11A
0005432144014	5663	49	11C
0005432784269	5663	50	11D
0005435242756	5663	51	11E
0005432784254	5663	52	11F
0005432784264	5663	53	12A
0005435242792	5663	54	12C
0005435242959	5663	55	12D
0005435242789	5663	56	12E
0005432784228	5663	57	12F
0005435242899	5663	58	13A
0005435242977	5663	59	13C
0005432784226	5663	60	13D
0005432784221	5663	61	13E
0005432784258	5663	62	13F
0005432144016	5663	63	14A
0005432784240	5663	64	14C
0005432784260	5663	65	14D
0005432144013	5663	66	14E
0005432784243	5663	67	14F
0005432784251	5663	68	15A
0005432784227	5663	69	15C
0005435242835	5663	70	15D
0005435242781	5663	71	15E
0005435242790	5663	72	15F
0005432144015	5663	73	16A
0005435476728	5663	74	16C
0005432784241	5663	75	16D
0005432784218	5663	76	16E
0005435242932	5663	77	16F
0005432784232	5663	78	17A
0005435242844	5663	79	17C
0005435242772	5663	80	17D
0005432784217	5663	81	17F
0005432784263	5663	82	18A
0005435242978	5663	83	18C
0005432784220	5663	84	18E
0005435476729	5663	85	18F
0005432784219	5663	86	19A
0005432784257	5663	87	19C
0005435242823	5663	88	19D
0005435242766	5663	89	19E
0005432784242	5663	90	19F
0005432784245	5663	91	20A
0005435242765	5663	92	20D
0005432784225	5663	93	20E
0005432784261	5663	94	20F
0005432783721	15376	1	1A
0005435243049	15376	2	1C
0005432783775	15376	3	1D
0005435476821	15376	4	1F
0005432783542	15376	5	2A
0005435243061	15376	6	2C
0005435476819	15376	7	2D
0005432783764	15376	8	2F
0005435243050	15376	9	3A
0005435476813	15376	10	3C
0005432783868	15376	11	3D
0005432783587	15376	12	3F
0005432783998	15376	13	4C
0005432783708	15376	14	4D
0005432783781	15376	15	4E
0005435476814	15376	16	4F
0005435243056	15376	17	5A
0005435243067	15376	18	5C
0005432783501	15376	19	5D
0005435243072	15376	20	5E
0005432783620	15376	21	5F
0005432783549	15376	22	6A
0005432783826	15376	23	6C
0005432783859	15376	24	6D
0005432783514	15376	25	6E
0005432783664	15376	26	6F
0005435243051	15376	27	7A
0005435243062	15376	28	7C
0005435243057	15376	29	7D
0005435243066	15376	30	7E
0005432783430	15376	31	7F
0005432783801	15376	32	8A
0005435243055	15376	33	8C
0005432783659	15376	34	8D
0005432783755	15376	35	8E
0005432783644	15376	36	8F
0005435243073	15376	37	9A
0005435243065	15376	38	9C
0005432783761	15376	39	9D
0005435243046	15376	40	9E
0005432783662	15376	41	9F
0005432783852	15376	42	10A
0005432783997	15376	43	10C
0005432783858	15376	44	10D
0005432783680	15376	45	10E
0005432783447	15376	46	10F
0005432783691	15376	47	11A
0005432783957	15376	48	11C
0005435476818	15376	49	11D
0005435243071	15376	50	11F
0005435243059	15376	51	12A
0005435243068	15376	52	12C
0005435243058	15376	53	12D
0005432783835	15376	54	12E
0005432783724	15376	55	12F
0005432783857	15376	56	13A
0005435243069	15376	57	13C
0005432783756	15376	58	13D
0005432783847	15376	59	13E
0005435476816	15376	60	13F
0005432783851	15376	61	14C
0005432783723	15376	62	14D
0005435243047	15376	63	14E
0005435243054	15376	64	14F
0005432783617	15376	65	15A
0005435476820	15376	66	15C
0005432783654	15376	67	15D
0005432783867	15376	68	15E
0005435243070	15376	69	15F
0005435243064	15376	70	16A
0005435243063	15376	71	16D
0005435243053	15376	72	16C
0005432783653	15376	73	16E
0005435243052	15376	74	16F
0005432783429	15376	75	17A
0005435476815	15376	76	17C
0005432783746	15376	77	17D
0005432783774	15376	78	17E
0005432783588	15376	79	17F
0005432783645	15376	80	18A
0005432783616	15376	81	18C
0005432783861	15376	82	18D
0005435243048	15376	83	18E
0005435243060	15376	84	18F
0005435476817	15376	85	19A
0005432783827	15376	86	19C
0005432783707	15376	87	19D
0005432783663	15376	88	19E
0005432783378	15376	89	19F
0005432783877	15376	90	20A
0005432783661	15376	91	20D
0005432783842	15376	92	20F
0005432848433	4375	1	1C
0005432848427	4375	2	2B
0005432848426	4375	3	2C
0005432848439	4375	4	3A
0005432848434	4375	5	3B
0005435850907	4375	6	4A
0005432848441	4375	7	4B
0005432848437	4375	8	4C
0005432848431	4375	9	5A
0005432848435	4375	10	6B
0005435850908	4375	11	6D
0005432848438	4375	12	18A
0005434463946	4375	13	18C
0005432848436	4375	14	19A
0005434463948	4375	15	19D
0005432848432	4375	16	20A
0005435850920	4375	17	20B
0005432848428	4375	18	20C
0005432848430	4375	19	21C
0005432848429	4375	20	21D
0005432848440	4375	21	22B
0005434463947	4375	22	23B
0005432848237	28887	1	1A
0005434463919	28887	2	1C
0005432848294	28887	3	1D
0005434463928	28887	4	2A
0005435850990	28887	5	2B
0005432848276	28887	6	2C
0005434461638	28887	7	2D
0005435850988	28887	8	3B
0005434461649	28887	9	3C
0005432848300	28887	10	3D
0005435850984	28887	11	4A
0005432848296	28887	12	4B
0005432848385	28887	13	4C
0005434461642	28887	14	4D
0005432848325	28887	15	5A
0005432848307	28887	16	5B
0005432848334	28887	17	5C
0005435850989	28887	18	5D
0005434461648	28887	19	6A
0005432848336	28887	20	6B
0005434461643	28887	21	6C
0005435850987	28887	22	7A
0005434463918	28887	23	7B
0005432848323	28887	24	7C
0005432848345	28887	25	7D
0005435850986	28887	26	18A
0005432848249	28887	27	18C
0005432848250	28887	28	18D
0005434461644	28887	29	19A
0005432848346	28887	30	19C
0005434463927	28887	31	20A
0005432848248	28887	32	20B
0005432848309	28887	33	20D
0005432848306	28887	34	21A
0005432848293	28887	35	21B
0005435850985	28887	36	21C
0005432848270	28887	37	21D
0005432848335	28887	38	22A
0005435850983	28887	39	22B
0005435850982	28887	40	22C
0005432848269	28887	41	23A
0005432848295	28887	42	23B
0005432075261	6347	1	1A
0005433497247	6347	2	1C
0005434443839	6347	3	1D
0005434926081	6347	4	1F
0005434443847	6347	5	2A
0005433497236	6347	6	2C
0005434443844	6347	7	2D
0005434926089	6347	8	2F
0005434443852	6347	9	3A
0005433497222	6347	10	3D
0005434443838	6347	11	3F
0005434926064	6347	12	4A
0005434926075	6347	13	4C
0005434926067	6347	14	4D
0005432075260	6347	15	4F
0005433497240	6347	16	5A
0005434926084	6347	17	5C
0005432075259	6347	18	5D
0005433497234	6347	19	5E
0005434443837	6347	20	6A
0005434443846	6347	21	6C
0005433497218	6347	22	6E
0005433497225	6347	23	6F
0005433497228	6347	24	7A
0005434926087	6347	25	7C
0005433497232	6347	26	7D
0005434926090	6347	27	7E
0005434926093	6347	28	7F
0005434926070	6347	29	8A
0005433497246	6347	30	8C
0005434926062	6347	31	8D
0005434926073	6347	32	8E
0005434926095	6347	33	8F
0005434926065	6347	34	9A
0005434926069	6347	35	9C
0005432075258	6347	36	9D
0005434926071	6347	37	9E
0005434926079	6347	38	9F
0005434926078	6347	39	10A
0005433497239	6347	40	10C
0005434926061	6347	41	10D
0005433497249	6347	42	10E
0005434926068	6347	43	10F
0005433497227	6347	44	11A
0005434926063	6347	45	11C
0005434926097	6347	46	11D
0005433497233	6347	47	11F
0005434443848	6347	48	12A
0005434443842	6347	49	12C
0005434443843	6347	50	12D
0005433497241	6347	51	12E
0005433497226	6347	52	12F
0005433497235	6347	53	13A
0005434926086	6347	54	13C
0005434443840	6347	55	13D
0005433497237	6347	56	13E
0005434926077	6347	57	13F
0005434926066	6347	58	14A
0005434926076	6347	59	14C
0005434926074	6347	60	14D
0005434926080	6347	61	14E
0005434926088	6347	62	14F
0005433497220	6347	63	15A
0005433497242	6347	64	15C
0005434443849	6347	65	15D
0005434926092	6347	66	15E
0005433497231	6347	67	15F
0005433497248	6347	68	16A
0005433497221	6347	69	16C
0005434443850	6347	70	16D
0005433497219	6347	71	16E
0005434443841	6347	72	17C
0005434926091	6347	73	17A
0005434443845	6347	74	17D
0005434443853	6347	75	17E
0005433497224	6347	76	17F
0005433497243	6347	77	18A
0005434926096	6347	78	18C
0005434926082	6347	79	18D
0005433497230	6347	80	18E
0005434926060	6347	81	18F
0005434926094	6347	82	19A
0005434926083	6347	83	19C
0005434926085	6347	84	19D
0005434926072	6347	85	19E
0005433497223	6347	86	19F
0005433497245	6347	87	20A
0005433497229	6347	88	20C
0005433497238	6347	89	20D
0005433497244	6347	90	20E
0005434443851	6347	91	20F
0005433496865	20390	1	1A
0005433497132	20390	2	1C
0005433496958	20390	3	1D
0005433497113	20390	4	1F
0005434925609	20390	5	2A
0005433496855	20390	6	2C
0005434925715	20390	7	2D
0005434925708	20390	8	2F
0005433496933	20390	9	3A
0005434443704	20390	10	3C
0005434925688	20390	11	3D
0005433497145	20390	12	3F
0005434443738	20390	13	4A
0005433497045	20390	14	4C
0005434925695	20390	15	4D
0005433496907	20390	16	4E
0005434443672	20390	17	4F
0005433496971	20390	18	5A
0005434925669	20390	19	5C
0005433496906	20390	20	5D
0005434443688	20390	21	5E
0005434443770	20390	22	5F
0005434443680	20390	23	6A
0005434443737	20390	24	6C
0005434925668	20390	25	6D
0005434443739	20390	26	6E
0005433496839	20390	27	6F
0005434925698	20390	28	7A
0005433497054	20390	29	7C
0005433497038	20390	30	7D
0005433496820	20390	31	7E
0005434925690	20390	32	7F
0005433496926	20390	33	8A
0005433497060	20390	34	8C
0005433496934	20390	35	8D
0005434443670	20390	36	8E
0005433497109	20390	37	8F
0005434925714	20390	38	9A
0005433496975	20390	39	9C
0005433496840	20390	40	9D
0005433497072	20390	41	9F
0005433496908	20390	42	9E
0005434443759	20390	43	10A
0005434925709	20390	44	10E
0005434925610	20390	45	10F
0005433497019	20390	46	11A
0005434443695	20390	47	11C
0005434925711	20390	48	11D
0005433497037	20390	49	11E
0005433497013	20390	50	11F
0005433496957	20390	51	12A
0005433496994	20390	52	12C
0005433497012	20390	53	12D
0005433497029	20390	54	12E
0005433497110	20390	55	12F
0005434443638	20390	56	13C
0005434443673	20390	57	13D
0005434925697	20390	58	13F
0005433496972	20390	59	14A
0005434443705	20390	60	14C
0005433497111	20390	61	14D
0005434925607	20390	62	14E
0005433497131	20390	63	14F
0005433497017	20390	64	15A
0005433496932	20390	65	15C
0005434925696	20390	66	15D
0005433496841	20390	67	15E
0005434443696	20390	68	15F
0005433496931	20390	69	16A
0005434443697	20390	70	16C
0005433497071	20390	71	16D
0005433497024	20390	72	16E
0005434443703	20390	73	16F
0005434443681	20390	74	17A
0005434443724	20390	75	17C
0005433496910	20390	76	17D
0005433496953	20390	77	17E
0005433496935	20390	78	17F
0005433496869	20390	79	18A
0005433496927	20390	80	18C
0005433496856	20390	81	18D
0005434925689	20390	82	18F
0005433497027	20390	83	18E
0005434443713	20390	84	19C
0005433496991	20390	85	19D
0005434443717	20390	86	19E
0005434443714	20390	87	19F
0005434443698	20390	88	20A
0005433496821	20390	89	20C
0005434443723	20390	90	20D
0005433497028	20390	91	20E
0005433496973	20390	92	20F
0005435243090	12208	1	1A
0005432783765	12208	2	1C
0005432783598	12208	3	1D
0005432783769	12208	4	2A
0005432783811	12208	5	2C
0005432783751	12208	6	2D
0005432783806	12208	7	2F
0005432783712	12208	8	3C
0005435243095	12208	9	3D
0005432783799	12208	10	3F
0005432783812	12208	11	4C
0005432783843	12208	12	4E
0005435243091	12208	13	4F
0005432783564	12208	14	5C
0005432783689	12208	15	5D
0005435243097	12208	16	5F
0005432783563	12208	17	6A
0005432783883	12208	18	6C
0005432783939	12208	19	6D
0005435243084	12208	20	6E
0005432783631	12208	21	6F
0005435243074	12208	22	7A
0005432783743	12208	23	7C
0005432783891	12208	24	7D
0005432783819	12208	25	7E
0005432783688	12208	26	7F
0005432783785	12208	27	8A
0005432783750	12208	28	8C
0005435243093	12208	29	8D
0005435243075	12208	30	8E
0005435243079	12208	31	8F
0005435243082	12208	32	9A
0005435243080	12208	33	9C
0005435243100	12208	34	9D
0005432784041	12208	35	9E
0005432783647	12208	36	10A
0005432784012	12208	37	10C
0005432783807	12208	38	10E
0005435243101	12208	39	10F
0005432784042	12208	40	11A
0005432783599	12208	41	11C
0005432783744	12208	42	11D
0005435243081	12208	43	11E
0005432783938	12208	44	11F
0005432783879	12208	45	12A
0005432783876	12208	46	12C
0005432783892	12208	47	12D
0005432783603	12208	48	12E
0005435243077	12208	49	13A
0005432783916	12208	50	13C
0005435243094	12208	51	13E
0005435243096	12208	52	13F
0005432784011	12208	53	14A
0005432784051	12208	54	14C
0005432783745	12208	55	14E
0005435243092	12208	56	14F
0005435243078	12208	57	15A
0005432783881	12208	58	15C
0005435243102	12208	59	15D
0005435243088	12208	60	15E
0005432784050	12208	61	15F
0005435243085	12208	62	16A
0005432783820	12208	63	16C
0005432783882	12208	64	16D
0005435243098	12208	65	16E
0005432783699	12208	66	16F
0005435243099	12208	67	17A
0005432783597	12208	68	17C
0005432783768	12208	69	17D
0005435243083	12208	70	17E
0005432783734	12208	71	18A
0005432783875	12208	72	18D
0005432783684	12208	73	18E
0005435243076	12208	74	18F
0005435243087	12208	75	19A
0005435243086	12208	76	19D
0005432783921	12208	77	19E
0005432783872	12208	78	19F
0005432783788	12208	79	20A
0005435243089	12208	80	20C
0005432783711	12208	81	20D
0005432783729	12208	82	20E
0005432783800	12208	83	20F
0005435242830	15435	1	1A
0005432784195	15435	2	1C
0005435242695	15435	3	1D
0005435242540	15435	4	1F
0005432784182	15435	5	2A
0005435242839	15435	6	2C
0005435242845	15435	7	2D
0005432784206	15435	8	2F
0005432784194	15435	9	3A
0005435242877	15435	10	3C
0005432784207	15435	11	3D
0005432784209	15435	12	4A
0005435242696	15435	13	3F
0005432784172	15435	14	4C
0005432784188	15435	15	4D
0005432784185	15435	16	4E
0005432784165	15435	17	4F
0005435242874	15435	18	5A
0005432784202	15435	19	5C
0005435242811	15435	20	5D
0005435242815	15435	21	5E
0005432784204	15435	22	6A
0005432784170	15435	23	6C
0005432784169	15435	24	6E
0005435242759	15435	25	6F
0005432784175	15435	26	7A
0005435242809	15435	27	7C
0005432784177	15435	28	7D
0005435242747	15435	29	7E
0005432784166	15435	30	7F
0005432784171	15435	31	8A
0005432784193	15435	32	8C
0005432784164	15435	33	8D
0005432784180	15435	34	8E
0005432784192	15435	35	9A
0005435242871	15435	36	9C
0005432784178	15435	37	9E
0005432784198	15435	38	10A
0005435242775	15435	39	10C
0005432784163	15435	40	10D
0005432784215	15435	41	10E
0005432784187	15435	42	10F
0005432784184	15435	43	11A
0005432784167	15435	44	11C
0005432784168	15435	45	11E
0005432784190	15435	46	11F
0005432784191	15435	47	12A
0005435242750	15435	48	12C
0005435242829	15435	49	12D
0005432784189	15435	50	12E
0005432784216	15435	51	12F
0005432784214	15435	52	13A
0005432784160	15435	53	13C
0005435242763	15435	54	13D
0005432784179	15435	55	13E
0005435242801	15435	56	13F
0005432784174	15435	57	14A
0005432784196	15435	58	14C
0005432784197	15435	59	14D
0005432784205	15435	60	14E
0005435242691	15435	61	14F
0005435242875	15435	62	15A
0005432784200	15435	63	15C
0005432784161	15435	64	15D
0005432784181	15435	65	15E
0005432784176	15435	66	15F
0005435242846	15435	67	16A
0005435242837	15435	68	16C
0005432784208	15435	69	16D
0005432784199	15435	70	16E
0005435242717	15435	71	16F
0005432784212	15435	72	17A
0005432784213	15435	73	17C
0005435242810	15435	74	17D
0005432784210	15435	75	17E
0005432784162	15435	76	17F
0005432784186	15435	77	18A
0005432784173	15435	78	18C
0005435242838	15435	79	18E
0005435242774	15435	80	18F
0005435242851	15435	81	19A
0005435242825	15435	82	19C
0005435242637	15435	83	19D
0005432784201	15435	84	19F
0005432784211	15435	85	20A
0005432784183	15435	86	20D
0005435242872	15435	87	20E
0005432784203	15435	88	20F
0005434878343	10063	1	1C
0005434877807	10063	2	1A
0005434878416	10063	3	1F
0005434878473	10063	4	1D
0005434878291	10063	5	2A
0005434878278	10063	6	2D
0005434878147	10063	7	2C
0005434878188	10063	8	3C
0005434878100	10063	9	3A
0005434878350	10063	10	2F
0005434877752	10063	11	3D
0005434878074	10063	12	4D
0005434878054	10063	13	5C
0005434878472	10063	14	5A
0005435913961	10063	15	5F
0005434878351	10063	16	6A
0005434878092	10063	17	6C
0005434878032	10063	18	6F
0005434877818	10063	19	7A
0005435913955	10063	20	7B
0005434878201	10063	21	7E
0005434878304	10063	22	7D
0005434878240	10063	23	8A
0005434878008	10063	24	7F
0005434878346	10063	25	8C
0005434878661	10063	26	8B
0005434878486	10063	27	8E
0005434878218	10063	28	9B
0005434878301	10063	29	9A
0005434878012	10063	30	9C
0005434878079	10063	31	9E
0005435913958	10063	32	9D
0005434878261	10063	33	10A
0005434877952	10063	34	10C
0005434878650	10063	35	10B
0005435913960	10063	36	10E
0005434878270	10063	37	10D
0005434878469	10063	38	10F
0005434877898	10063	39	11B
0005434878207	10063	40	11A
0005434878200	10063	41	11D
0005434877699	10063	42	11F
0005434910132	10063	43	11E
0005434878080	10063	44	12B
0005434878216	10063	45	12A
0005434878492	10063	46	12C
0005435913957	10063	47	12E
0005434878402	10063	48	12F
0005434878620	10063	49	13E
0005434758886	10063	50	13D
0005434910134	10063	51	13F
0005434878647	10063	52	14B
0005434878380	10063	53	14A
0005434878073	10063	54	14D
0005434878031	10063	55	14C
0005434878123	10063	56	14F
0005434758873	10063	57	14E
0005434878452	10063	58	15A
0005434878379	10063	59	15C
0005434878410	10063	60	15B
0005434877753	10063	61	15F
0005434877866	10063	62	15E
0005434878371	10063	63	15D
0005434878269	10063	64	16A
0005434878212	10063	65	16C
0005434910133	10063	66	16B
0005434878245	10063	67	16D
0005434877995	10063	68	16F
0005434878217	10063	69	17C
0005434878352	10063	70	17B
0005434877806	10063	71	17E
0005434877817	10063	72	18B
0005434878293	10063	73	17F
0005434877880	10063	74	18D
0005434878331	10063	75	18C
0005434878471	10063	76	19A
0005434877901	10063	77	18F
0005435913956	10063	78	19C
0005434878284	10063	79	19B
0005434878168	10063	80	19D
0005434878187	10063	81	19F
0005434878262	10063	82	19E
0005434878164	10063	83	20B
0005434878646	10063	84	20A
0005434878110	10063	85	20C
0005434878224	10063	86	20F
0005435913959	10063	87	20D
0005434878128	10063	88	21A
0005434910135	10063	89	21C
0005434878049	10063	90	21D
0005434878048	10063	91	21F
0005434879017	14595	1	1C
0005434879054	14595	2	1A
0005434878994	14595	3	1D
0005434879016	14595	4	2C
0005434879038	14595	5	2A
0005434879031	14595	6	1F
0005434879048	14595	7	2D
0005434879043	14595	8	3A
0005434878993	14595	9	3D
0005434879047	14595	10	3C
0005434878997	14595	11	3F
0005434879007	14595	12	4C
0005435913922	14595	13	4A
0005434878989	14595	14	4F
0005435913923	14595	15	4D
0005434879010	14595	16	5C
0005434879053	14595	17	5F
0005434879024	14595	18	5D
0005434879050	14595	19	6B
0005434879001	14595	20	6A
0005434878977	14595	21	6D
0005434878958	14595	22	6C
0005434878968	14595	23	6E
0005434879006	14595	24	7A
0005434878966	14595	25	6F
0005434878990	14595	26	7C
0005434878981	14595	27	7B
0005434878965	14595	28	7E
0005434879000	14595	29	7D
0005434910110	14595	30	8A
0005434879026	14595	31	8C
0005435913929	14595	32	8D
0005434879021	14595	33	8F
0005434879049	14595	34	8E
0005434879051	14595	35	9B
0005434878970	14595	36	9A
0005434910111	14595	37	9D
0005434879005	14595	38	9C
0005434879041	14595	39	9E
0005434910097	14595	40	10A
0005434878972	14595	41	9F
0005434879013	14595	42	10C
0005434879034	14595	43	10B
0005434879019	14595	44	10E
0005434878996	14595	45	10D
0005434878984	14595	46	11A
0005434878991	14595	47	10F
0005434879046	14595	48	11C
0005434879025	14595	49	11B
0005434878979	14595	50	11D
0005434879040	14595	51	11F
0005434878988	14595	52	11E
0005435913924	14595	53	12B
0005434879023	14595	54	12A
0005434879042	14595	55	12D
0005434879044	14595	56	12C
0005434879029	14595	57	12F
0005434878998	14595	58	12E
0005434879011	14595	59	13A
0005434879015	14595	60	13B
0005434878983	14595	61	13D
0005434878967	14595	62	14A
0005434879039	14595	63	13F
0005434879020	14595	64	13E
0005434878959	14595	65	14C
0005434879003	14595	66	14B
0005434910098	14595	67	14D
0005434879002	14595	68	15A
0005434878969	14595	69	14F
0005434879008	14595	70	14E
0005434879033	14595	71	15D
0005434878963	14595	72	15C
0005434878962	14595	73	15B
0005434910109	14595	74	16A
0005434879027	14595	75	15F
0005434878985	14595	76	16C
0005434878961	14595	77	16B
0005434879018	14595	78	16D
0005434879052	14595	79	16F
0005434878971	14595	80	16E
0005434879035	14595	81	17B
0005434879037	14595	82	17A
0005434878974	14595	83	17D
0005434878999	14595	84	17C
0005434879012	14595	85	17F
0005434878960	14595	86	17E
0005434878982	14595	87	18B
0005434878973	14595	88	18A
0005434879009	14595	89	18D
0005434878976	14595	90	18C
0005434879030	14595	91	18F
0005434878978	14595	92	18E
0005434879028	14595	93	19A
0005434878980	14595	94	19C
0005434879014	14595	95	19B
0005434879036	14595	96	19E
0005434878986	14595	97	19D
0005434758913	14595	98	20A
0005434878964	14595	99	19F
0005434878995	14595	100	20B
0005434879045	14595	101	20D
0005434758912	14595	102	20C
0005434879004	14595	103	20F
0005434879032	14595	104	20E
0005434879022	14595	105	21A
0005434878987	14595	106	21D
0005434878992	14595	107	21B
0005434878975	14595	108	21F
0005435660225	9231	1	2A
0005435660231	9231	2	3A
0005435660235	9231	3	4A
0005434251975	9231	4	4B
0005434251983	9231	5	5B
0005434251934	9231	6	6B
0005435660234	9231	7	6C
0005434251877	9231	8	6D
0005434251926	9231	9	7B
0005435660229	9231	10	7C
0005435660233	9231	11	18A
0005435660228	9231	12	18C
0005434251974	9231	13	19A
0005434251984	9231	14	19C
0005435660226	9231	15	19D
0005435660232	9231	16	20D
0005435660230	9231	17	21A
0005434251985	9231	18	22B
0005435660227	9231	19	22C
0005435660132	24660	1	1B
0005435660107	24660	2	1C
0005435660131	24660	3	1D
0005435660115	24660	4	2A
0005434252038	24660	5	2B
0005435660171	24660	6	2D
0005435660156	24660	7	3B
0005435660112	24660	8	3C
0005435660147	24660	9	3D
0005435660129	24660	10	4B
0005435660170	24660	11	4C
0005434252044	24660	12	5C
0005434252046	24660	13	5D
0005435660106	24660	14	6A
0005435660111	24660	15	6B
0005435660119	24660	16	6C
0005434252045	24660	17	7A
0005435660139	24660	18	7D
0005434252042	24660	19	18A
0005435660113	24660	20	18B
0005434252041	24660	21	19C
0005434252047	24660	22	19D
0005435660177	24660	23	20A
0005434252040	24660	24	20C
0005434252043	24660	25	20D
0005434252039	24660	26	21D
0005435660114	24660	27	22A
0005435660118	24660	28	22D
0005435660120	24660	29	23A
0005433684438	2784	1	1A
0005432222826	2784	2	1C
0005433680963	2784	3	1D
0005433680943	2784	4	1F
0005432966931	2784	5	2C
0005433680933	2784	6	2D
0005433680941	2784	7	2F
0005432966988	2784	8	3A
0005432966760	2784	9	3C
0005433680936	2784	10	3D
0005433680962	2784	11	3F
0005433680977	2784	12	4A
0005432966870	2784	13	4C
0005433680969	2784	14	4D
0005433680964	2784	15	4E
0005432966966	2784	16	4F
0005433680955	2784	17	5C
0005433680939	2784	18	5D
0005432966921	2784	19	5E
0005433680952	2784	20	5F
0005432966825	2784	21	6A
0005433680956	2784	22	6C
0005432966854	2784	23	6D
0005433680944	2784	24	6E
0005433684435	2784	25	6F
0005433680965	2784	26	7C
0005432966908	2784	27	7D
0005432966855	2784	28	7E
0005432966887	2784	29	7F
0005433680934	2784	30	8A
0005433680948	2784	31	8C
0005432966968	2784	32	8D
0005432966805	2784	33	8E
0005433680951	2784	34	9A
0005432966889	2784	35	9C
0005433680950	2784	36	9D
0005432966984	2784	37	9E
0005432966824	2784	38	9F
0005432966965	2784	39	10A
0005433680960	2784	40	10C
0005433680972	2784	41	10D
0005433680971	2784	42	10E
0005433680974	2784	43	10F
0005433680970	2784	44	11A
0005432966826	2784	45	11C
0005433680953	2784	46	11D
0005433680949	2784	47	11E
0005432222824	2784	48	11F
0005433680967	2784	49	12A
0005433680959	2784	50	12C
0005433680942	2784	51	12D
0005433680975	2784	52	12E
0005433684437	2784	53	12F
0005433680947	2784	54	13A
0005432966872	2784	55	13C
0005433680968	2784	56	13D
0005432966941	2784	57	13E
0005432966759	2784	58	13F
0005433684436	2784	59	14A
0005433680940	2784	60	14C
0005432966989	2784	61	14D
0005432222827	2784	62	14E
0005433680961	2784	63	14F
0005432966983	2784	64	15A
0005433680938	2784	65	15C
0005433680946	2784	66	15D
0005433680935	2784	67	15E
0005433680945	2784	68	15F
0005432966869	2784	69	16A
0005433680958	2784	70	16D
0005432966996	2784	71	16E
0005433680937	2784	72	16F
0005433680957	2784	73	17A
0005432966993	2784	74	17C
0005432966873	2784	75	17D
0005432967079	2784	76	17E
0005433680973	2784	77	18A
0005432966888	2784	78	18C
0005432222825	2784	79	18E
0005432966942	2784	80	18F
0005433680966	2784	81	19A
0005433680979	2784	82	19D
0005432966985	2784	83	19E
0005433680978	2784	84	19F
0005433680954	2784	85	20A
0005432222823	2784	86	20C
0005433680976	2784	87	20D
0005432966868	2784	88	20F
0005433680590	29177	1	1A
0005432967138	29177	2	1C
0005432005238	29177	3	1D
0005433680336	29177	4	1F
0005433684423	29177	5	2A
0005433680557	29177	6	2C
0005433680479	29177	7	2D
0005433680480	29177	8	2F
0005432967156	29177	9	3C
0005433680539	29177	10	3D
0005432967153	29177	11	3F
0005433680680	29177	12	4A
0005433684419	29177	13	4D
0005433680670	29177	14	4F
0005433680345	29177	15	4E
0005433680605	29177	16	5A
0005433680396	29177	17	5D
0005433684415	29177	18	5E
0005433680699	29177	19	5F
0005432967140	29177	20	6A
0005433680650	29177	21	6C
0005432967142	29177	22	6D
0005432967154	29177	23	6E
0005433680576	29177	24	6F
0005433680600	29177	25	7A
0005433680483	29177	26	7C
0005433680591	29177	27	7D
0005433680700	29177	28	7E
0005433680411	29177	29	8A
0005433680571	29177	30	8C
0005433680601	29177	31	8D
0005433680531	29177	32	8E
0005433680607	29177	33	8F
0005432005236	29177	34	9A
0005432967148	29177	35	9C
0005432967133	29177	36	9D
0005432967149	29177	37	9F
0005433680606	29177	38	10A
0005433684431	29177	39	10C
0005433680603	29177	40	10D
0005432967151	29177	41	10F
0005433680773	29177	42	11A
0005433680577	29177	43	11C
0005433680369	29177	44	11D
0005432967155	29177	45	11F
0005432967146	29177	46	12C
0005433680370	29177	47	12D
0005433680334	29177	48	12E
0005433680335	29177	49	12F
0005433680692	29177	50	13A
0005432967152	29177	51	13C
0005433680555	29177	52	13D
0005432005237	29177	53	13E
0005433680484	29177	54	13F
0005433680594	29177	55	14A
0005433680596	29177	56	14C
0005433680654	29177	57	14D
0005433680592	29177	58	14E
0005432967143	29177	59	14F
0005432005235	29177	60	15A
0005433684420	29177	61	15C
0005433680595	29177	62	15D
0005433680694	29177	63	15E
0005432967137	29177	64	15F
0005433680395	29177	65	16C
0005433680738	29177	66	16D
0005433680739	29177	67	16E
0005432967157	29177	68	16F
0005433680693	29177	69	17A
0005433680556	29177	70	17C
0005432967139	29177	71	17D
0005433680587	29177	72	17E
0005433680454	29177	73	17F
0005432967144	29177	74	18A
0005432967150	29177	75	18C
0005433680671	29177	76	18D
0005432967147	29177	77	18E
0005433680597	29177	78	18F
0005432967135	29177	79	19E
0005433680602	29177	80	19F
0005432967145	29177	81	20A
0005433680353	29177	82	20C
0005432967141	29177	83	20D
0005432967136	29177	84	20E
0005432967134	29177	85	20F
0005433615208	9298	1	1D
0005433615225	9298	2	1C
0005433615224	9298	3	1A
0005434153528	9298	4	1F
0005433577922	9298	5	2A
0005432756876	9298	6	2C
0005433615249	9298	7	2F
0005433615217	9298	8	2D
0005434163600	9298	9	3A
0005433615218	9298	10	3D
0005433634055	9298	11	3C
0005433615220	9298	12	3F
0005433615211	9298	13	4C
0005433577916	9298	14	4F
0005433615196	9298	15	4D
0005433615200	9298	16	5A
0005433615254	9298	17	5D
0005433634057	9298	18	5C
0005433615214	9298	19	5F
0005432755103	9298	20	6A
0005433615221	9298	21	6C
0005433615236	9298	22	6D
0005433615197	9298	23	7A
0005433634069	9298	24	7D
0005432145126	9298	25	7C
0005433615216	9298	26	7F
0005434272191	9298	27	8A
0005434163634	9298	28	8C
0005433615192	9298	29	8B
0005434163607	9298	30	8D
0005433634063	9298	31	8E
0005433615185	9298	32	8F
0005433634059	9298	33	9A
0005433615202	9298	34	9D
0005433615252	9298	35	9C
0005433615189	9298	36	9B
0005432755104	9298	37	9F
0005433615195	9298	38	9E
0005433634074	9298	39	10A
0005433615190	9298	40	10C
0005433634052	9298	41	10B
0005433634078	9298	42	10E
0005434163635	9298	43	10D
0005433634077	9298	44	10F
0005434269100	9298	45	11A
0005433615206	9298	46	11C
0005433615238	9298	47	11B
0005433634054	9298	48	11D
0005433615187	9298	49	12A
0005433615184	9298	50	11F
0005433615223	9298	51	12B
0005434163624	9298	52	12D
0005433615213	9298	53	12C
0005433615209	9298	54	12E
0005433615194	9298	55	12F
0005433577921	9298	56	13B
0005433615233	9298	57	13C
0005432145125	9298	58	13E
0005434272190	9298	59	13F
0005433577917	9298	60	14A
0005433615207	9298	61	14B
0005433615242	9298	62	14D
0005433577914	9298	63	14C
0005434163606	9298	64	14E
0005433615234	9298	65	14F
0005433577913	9298	66	15B
0005433615235	9298	67	15A
0005433615215	9298	68	15C
0005433615188	9298	69	15D
0005433615248	9298	70	15E
0005434269095	9298	71	16A
0005433615183	9298	72	15F
0005433634082	9298	73	16E
0005433615232	9298	74	16F
0005433615243	9298	75	17A
0005433577919	9298	76	17C
0005433615241	9298	77	17B
0005433634083	9298	78	17E
0005434163616	9298	79	17D
0005433615230	9298	80	18A
0005432755101	9298	81	17F
0005432756874	9298	82	18B
0005433634056	9298	83	18D
0005433615212	9298	84	18C
0005433634080	9298	85	18E
0005433615258	9298	86	18F
0005434163632	9298	87	19D
0005433615245	9298	88	19E
0005433634073	9298	89	20B
0005433577918	9298	90	20A
0005434163593	9298	91	20C
0005433615191	9298	92	20E
0005433577915	9298	93	20D
0005433634076	9298	94	20F
0005433615205	9298	95	21A
0005434269094	9298	96	21C
0005433615244	9298	97	21B
0005433615198	9298	98	21E
0005433634068	9298	99	21D
0005433615193	9298	100	22A
0005433634053	9298	101	21F
0005433615227	9298	102	22B
0005433634066	9298	103	22C
0005433615201	9298	104	22D
0005433615239	9298	105	22F
0005433634071	9298	106	22E
0005433634058	9298	107	23A
0005433615259	9298	108	23C
0005433615251	9298	109	23B
0005433615231	9298	110	23D
0005433615203	9298	111	23F
0005433615240	9298	112	24B
0005433634072	9298	113	24A
0005433634075	9298	114	24C
0005432756873	9298	115	24E
0005433615210	9298	116	24D
0005433634085	9298	117	24F
0005434163596	9298	118	25B
0005433615199	9298	119	25A
0005433634061	9298	120	25C
0005433634060	9298	121	25D
0005434163595	9298	122	25E
0005433634064	9298	123	26A
0005433615219	9298	124	25F
0005433634065	9298	125	26B
0005434163633	9298	126	26D
0005433615250	9298	127	26C
0005433634079	9298	128	26E
0005433615204	9298	129	26F
0005433615226	9298	130	27B
0005433615255	9298	131	27A
0005432755102	9298	132	27C
0005433634067	9298	133	27D
0005433615257	9298	134	27F
0005434272189	9298	135	27E
0005432756875	9298	136	28B
0005434163599	9298	137	28A
0005433615247	9298	138	28C
0005433634051	9298	139	28E
0005433615237	9298	140	28D
0005433615186	9298	141	28F
0005433577912	9298	142	29B
0005433615256	9298	143	29C
0005433634084	9298	144	29D
0005433577911	9298	145	29E
0005433615253	9298	146	30A
0005433634062	9298	147	30B
0005433615228	9298	148	30D
0005433615222	9298	149	30C
0005433577910	9298	150	30E
0005433634070	9298	151	30F
0005432755100	9298	152	31B
0005433615229	9298	153	31C
0005433615246	9298	154	31E
0005433634081	9298	155	31D
0005433577920	9298	156	31F
0005433614712	25244	1	1C
0005433614801	25244	2	1D
0005433615071	25244	3	2A
0005433615070	25244	4	1F
0005433614480	25244	5	2C
0005433633765	25244	6	2D
0005433614487	25244	7	3A
0005434163684	25244	8	2F
0005433633778	25244	9	3C
0005433614711	25244	10	3D
0005434272204	25244	11	4A
0005433614630	25244	12	3F
0005433577816	25244	13	4C
0005433614808	25244	14	5A
0005433614474	25244	15	4F
0005433614628	25244	16	5F
0005433633742	25244	17	5D
0005433614217	25244	18	6A
0005433633738	25244	19	6F
0005434273088	25244	20	6D
0005434163688	25244	21	7C
0005433614479	25244	22	7F
0005433633876	25244	23	7D
0005433633705	25244	24	8A
0005433614216	25244	25	8C
0005433614593	25244	26	8B
0005433614477	25244	27	8E
0005433633771	25244	28	8D
0005433614572	25244	29	9A
0005433614567	25244	30	9B
0005433614559	25244	31	9E
0005433633934	25244	32	9D
0005433614696	25244	33	9F
0005434163686	25244	34	10A
0005433614626	25244	35	10B
0005433633611	25244	36	10D
0005433614380	25244	37	10C
0005433614385	25244	38	10E
0005433577825	25244	39	10F
0005434163689	25244	40	11B
0005433614683	25244	41	11A
0005433614296	25244	42	11C
0005433633794	25244	43	11D
0005434163690	25244	44	11E
0005433614577	25244	45	12A
0005433633800	25244	46	11F
0005433614027	25244	47	12B
0005433633817	25244	48	12C
0005433614335	25244	49	12E
0005433614502	25244	50	12D
0005433614549	25244	51	12F
0005433577809	25244	52	13A
0005433633815	25244	53	13C
0005433614647	25244	54	13B
0005433633802	25244	55	13D
0005433633875	25244	56	13F
0005433614295	25244	57	13E
0005433614560	25244	58	14A
0005433614427	25244	59	14B
0005433614762	25244	60	14D
0005434163687	25244	61	14C
0005434163692	25244	62	14E
0005433614663	25244	63	14F
0005433614733	25244	64	15B
0005434163682	25244	65	15A
0005433614578	25244	66	15C
0005433633793	25244	67	15D
0005433614631	25244	68	15F
0005433614379	25244	69	15E
0005433614597	25244	70	16A
0005433577810	25244	71	16C
0005433633933	25244	72	16B
0005433633801	25244	73	16F
0005433614761	25244	74	16E
0005434163685	25244	75	16D
0005433614610	25244	76	17A
0005433633706	25244	77	17B
0005433633822	25244	78	17D
0005433633926	25244	79	17C
0005433614471	25244	80	17E
0005433633715	25244	81	18A
0005433633760	25244	82	17F
0005433614532	25244	83	18C
0005433614636	25244	84	18B
0005433614541	25244	85	18D
0005433633768	25244	86	19B
0005433614746	25244	87	18F
0005433633615	25244	88	19D
0005433614475	25244	89	19C
0005433614594	25244	90	19E
0005433614740	25244	91	20B
0005433614454	25244	92	20A
0005433614529	25244	93	20C
0005433614484	25244	94	20E
0005433614576	25244	95	20D
0005433614569	25244	96	20F
0005433614528	25244	97	21B
0005433614646	25244	98	21A
0005433633902	25244	99	21D
0005433614538	25244	100	21E
0005433614600	25244	101	21F
0005433614069	25244	102	22B
0005433614384	25244	103	22A
0005433633787	25244	104	22C
0005433614634	25244	105	22D
0005433614700	25244	106	22F
0005433614565	25244	107	22E
0005433614558	25244	108	23A
0005433614697	25244	109	23B
0005433577811	25244	110	23D
0005433614257	25244	111	23C
0005433577792	25244	112	23E
0005433614745	25244	113	23F
0005433614802	25244	114	24B
0005434273089	25244	115	24A
0005433577760	25244	116	24C
0005433614473	25244	117	24D
0005433614523	25244	118	24F
0005433633767	25244	119	25A
0005433633788	25244	120	25C
0005433614664	25244	121	25B
0005433614509	25244	122	25E
0005433633849	25244	123	26A
0005433633670	25244	124	25F
0005433614356	25244	125	26B
0005433614635	25244	126	26C
0005434273090	25244	127	26E
0005433633855	25244	128	26D
0005433614592	25244	129	26F
0005433614476	25244	130	27B
0005433577836	25244	131	27A
0005433633714	25244	132	27C
0005433633717	25244	133	27E
0005433633816	25244	134	27D
0005433614483	25244	135	27F
0005433633823	25244	136	28A
0005433633739	25244	137	28B
0005433614258	25244	138	28D
0005433577753	25244	139	28C
0005433633803	25244	140	28E
0005433614807	25244	141	29B
0005433614472	25244	142	29A
0005433614566	25244	143	29C
0005433633634	25244	144	29F
0005433614611	25244	145	29E
0005433633691	25244	146	30B
0005433614598	25244	147	30A
0005434163683	25244	148	30C
0005434163691	25244	149	30E
0005433614378	25244	150	31B
0005433614870	25244	151	31A
0005433614503	25244	152	31C
0005433633690	25244	153	31E
0005435947254	4247	1	2B
0005435947297	4247	2	3C
0005435854060	4247	3	4H
0005435947244	4247	4	5A
0005435947218	4247	5	9G
0005435986822	4247	6	11A
0005435947190	4247	7	11G
0005435986809	4247	8	11H
0005435947269	4247	9	12H
0005435947182	4247	10	12G
0005435856207	4247	11	13D
0005435986820	4247	12	13G
0005435856185	4247	13	13F
0005432571316	4247	14	15F
0005435947156	4247	15	16E
0005435787347	4247	16	17B
0005435986808	4247	17	18F
0005435986821	4247	18	18H
0005435947225	4247	19	19F
0005435986818	4247	20	20E
0005435986811	4247	21	20G
0005435947299	4247	22	21A
0005435947219	4247	23	20H
0005435787348	4247	24	21E
0005435986819	4247	25	22F
0005435986814	4247	26	23A
0005435947286	4247	27	27H
0005435947268	4247	28	29A
0005435986807	4247	29	29B
0005435856206	4247	30	30G
0005435856221	4247	31	31G
0005435986810	4247	32	32D
0005435986816	4247	33	32F
0005435947228	4247	34	33E
0005435986815	4247	35	33G
0005435986806	4247	36	34D
0005435986813	4247	37	34G
0005435986817	4247	38	35F
0005435986812	4247	39	36E
0005435856241	26567	1	1G
0005435947378	26567	2	5F
0005432571356	26567	3	12E
0005435787374	26567	4	13G
0005435986737	26567	5	15D
0005435947370	26567	6	15G
0005435856237	26567	7	16D
0005435787372	26567	8	16B
0005435986768	26567	9	17B
0005435986767	26567	10	17A
0005435856239	26567	11	18D
0005435986733	26567	12	18E
0005435947383	26567	13	18F
0005435986762	26567	14	21B
0005432571357	26567	15	21E
0005435947381	26567	16	21H
0005435947377	26567	17	22F
0005435947372	26567	18	23D
0005435986734	26567	19	23G
0005435947373	26567	20	23F
0005435947374	26567	21	23H
0005435986763	26567	22	24A
0005435986738	26567	23	24F
0005435947379	26567	24	25E
0005435856238	26567	25	27D
0005435986752	26567	26	28B
0005432571355	26567	27	29H
0005435947380	26567	28	30A
0005435986741	26567	29	30H
0005435947384	26567	30	31B
0005435986756	26567	31	31E
0005435947371	26567	32	32B
0005435986740	26567	33	33B
0005435947376	26567	34	33F
0005435947382	26567	35	34E
0005435787373	26567	36	34G
0005435986724	26567	37	35D
0005435947375	26567	38	36D
0005435856240	26567	39	38A
0005432571354	26567	40	38G
0005435947369	26567	41	39D
0005432948337	362	1	1A
0005433134135	362	2	1C
0005433569578	362	3	1F
0005432238989	362	4	2C
0005433569572	362	5	2A
0005432948402	362	6	2F
0005433569553	362	7	2D
0005433569549	362	8	3A
0005432948472	362	9	3C
0005432948412	362	10	3F
0005432948411	362	11	4A
0005433074640	362	12	4D
0005433569548	362	13	4C
0005432948448	362	14	5A
0005432948284	362	15	5C
0005433129273	362	16	6A
0005432948283	362	17	6C
0005432948154	362	18	6F
0005432948338	362	19	6D
0005433074680	362	20	7C
0005433569552	362	21	7D
0005433569559	362	22	8A
0005433569567	362	23	7F
0005432948401	362	24	8B
0005433569577	362	25	8D
0005433074567	362	26	8C
0005433074686	362	27	9B
0005433074721	362	28	9A
0005433569556	362	29	9C
0005433569546	362	30	9E
0005433569539	362	31	9D
0005433074739	362	32	10A
0005432948155	362	33	10B
0005432948441	362	34	10C
0005433569545	362	35	10F
0005432238988	362	36	10E
0005433569583	362	37	11B
0005433074683	362	38	11C
0005433569555	362	39	11D
0005433569571	362	40	12A
0005433569541	362	41	11F
0005432948495	362	42	12B
0005433569579	362	43	12C
0005433074529	362	44	12E
0005432948427	362	45	12F
0005433074699	362	46	13C
0005432948379	362	47	13B
0005433569582	362	48	13D
0005432948209	362	49	13F
0005432948417	362	50	14B
0005433569543	362	51	14D
0005433074656	362	52	14C
0005432948547	362	53	14E
0005433569560	362	54	14F
0005432948367	362	55	15A
0005433569564	362	56	15B
0005433569551	362	57	15D
0005432948414	362	58	15F
0005433134132	362	59	15E
0005433569574	362	60	16A
0005433129277	362	61	16C
0005433074705	362	62	16D
0005432948359	362	63	16E
0005433074681	362	64	16F
0005433074700	362	65	17C
0005432948548	362	66	17B
0005433569569	362	67	17D
0005432948294	362	68	17F
0005432948534	362	69	18A
0005433134136	362	70	18B
0005433074769	362	71	18E
0005432948652	362	72	18D
0005433569557	362	73	19B
0005433569547	362	74	18F
0005433569558	362	75	19D
0005432948515	362	76	19C
0005432948311	362	77	20A
0005433074715	362	78	20C
0005433074740	362	79	20E
0005432948197	362	80	20D
0005433074588	362	81	20F
0005433074704	362	82	21C
0005432948260	362	83	21B
0005433569576	362	84	21D
0005433074716	362	85	21E
0005432948310	362	86	21F
0005432948374	362	87	22B
0005433569565	362	88	22A
0005432948358	362	89	22D
0005433569542	362	90	22C
0005433569581	362	91	22E
0005433569563	362	92	23B
0005433074717	362	93	23C
0005433569575	362	94	23D
0005432948429	362	95	24A
0005433569580	362	96	23F
0005433074583	362	97	24B
0005433134137	362	98	24C
0005433569544	362	99	24D
0005433569561	362	100	24F
0005432948498	362	101	24E
0005432948368	362	102	25A
0005433569562	362	103	25C
0005432948434	362	104	25D
0005432948456	362	105	25E
0005432238987	362	106	26B
0005432238984	362	107	26A
0005433569573	362	108	26C
0005433074808	362	109	26D
0005433569554	362	110	26F
0005432238985	362	111	27B
0005432948527	362	112	27D
0005433074664	362	113	27C
0005432948208	362	114	27F
0005433074679	362	115	28A
0005432948293	362	116	28B
0005432238990	362	117	28D
0005433569538	362	118	28C
0005432948259	362	119	28E
0005433569540	362	120	29B
0005432948533	362	121	29D
0005433569566	362	122	29C
0005432948459	362	123	29E
0005432948499	362	124	30A
0005433074672	362	125	29F
0005433569570	362	126	30B
0005432948428	362	127	30E
0005433569568	362	128	30D
0005432948375	362	129	30F
0005433569550	362	130	31A
0005432948455	362	131	31C
0005432238986	362	132	31B
0005432948657	362	133	31E
0005432948792	11576	1	1A
0005433074931	11576	2	1C
0005432948774	11576	3	2A
0005433131744	11576	4	1F
0005433568891	11576	5	2D
0005432948788	11576	6	2C
0005432948779	11576	7	3A
0005433568980	11576	8	2F
0005433569016	11576	9	3D
0005433074949	11576	10	4A
0005433569112	11576	11	3F
0005433569200	11576	12	4D
0005433074951	11576	13	4C
0005433568847	11576	14	4F
0005433134177	11576	15	5C
0005433568969	11576	16	5A
0005433131746	11576	17	5F
0005432192346	11576	18	5D
0005433568877	11576	19	6A
0005432948790	11576	20	6C
0005432948768	11576	21	6F
0005433568956	11576	22	6D
0005432948767	11576	23	7C
0005432948776	11576	24	7A
0005433568709	11576	25	7D
0005433568912	11576	26	8A
0005433568885	11576	27	8C
0005433569113	11576	28	8B
0005433569009	11576	29	8E
0005432948780	11576	30	8F
0005433131745	11576	31	9A
0005433074936	11576	32	9C
0005433568738	11576	33	9F
0005433569092	11576	34	9E
0005433569056	11576	35	10A
0005432948778	11576	36	10C
0005432948777	11576	37	10B
0005433074927	11576	38	10D
0005432948781	11576	39	10E
0005433569000	11576	40	10F
0005433074947	11576	41	11A
0005433569024	11576	42	11B
0005433568979	11576	43	11D
0005433074939	11576	44	11E
0005433569010	11576	45	12A
0005433568901	11576	46	11F
0005433074952	11576	47	12C
0005433569041	11576	48	12F
0005432948771	11576	49	12E
0005433568949	11576	50	13A
0005433074926	11576	51	13C
0005433131748	11576	52	13B
0005433569017	11576	53	13D
0005432948804	11576	54	13F
0005433568868	11576	55	13E
0005433074934	11576	56	14A
0005432948787	11576	57	14B
0005433131747	11576	58	14C
0005433569155	11576	59	14E
0005433074929	11576	60	14D
0005433568854	11576	61	15A
0005433074943	11576	62	14F
0005432948766	11576	63	15B
0005433569082	11576	64	15C
0005432948794	11576	65	15D
0005433569105	11576	66	15F
0005433568480	11576	67	15E
0005433131743	11576	68	16A
0005433568957	11576	69	16C
0005433569042	11576	70	16B
0005433568810	11576	71	16E
0005433569067	11576	72	16F
0005432948775	11576	73	17B
0005433074933	11576	74	17A
0005432948783	11576	75	17C
0005433074940	11576	76	17D
0005433569114	11576	77	17E
0005432948796	11576	78	18A
0005432948797	11576	79	17F
0005433074950	11576	80	18B
0005433568884	11576	81	18C
0005432948773	11576	82	18E
0005432948784	11576	83	18D
0005433074928	11576	84	18F
0005432948798	11576	85	19E
0005433568858	11576	86	19D
0005432948786	11576	87	19C
0005433569055	11576	88	20C
0005432948803	11576	89	20B
0005433569094	11576	90	20F
0005433134176	11576	91	20E
0005433568966	11576	92	21A
0005432948770	11576	93	21B
0005433568698	11576	94	21D
0005433074948	11576	95	21C
0005433568892	11576	96	21F
0005433074953	11576	97	21E
0005433134173	11576	98	22B
0005433568948	11576	99	22A
0005433568879	11576	100	22C
0005433074942	11576	101	22E
0005433569106	11576	102	22D
0005432948802	11576	103	23B
0005433568925	11576	104	23C
0005433134175	11576	105	23E
0005433568641	11576	106	23F
0005433074938	11576	107	24B
0005433568890	11576	108	24C
0005433568973	11576	109	24E
0005433569335	11576	110	24D
0005432948795	11576	111	25A
0005433568841	11576	112	25C
0005433074925	11576	113	25B
0005433568970	11576	114	25D
0005433568859	11576	115	25E
0005433074945	11576	116	25F
0005433074941	11576	117	26B
0005432948799	11576	118	26A
0005432948793	11576	119	26C
0005432948782	11576	120	26E
0005432948785	11576	121	27B
0005433569001	11576	122	27C
0005433074930	11576	123	27D
0005433569199	11576	124	27E
0005432948800	11576	125	28A
0005433568708	11576	126	27F
0005432948769	11576	127	28B
0005432948791	11576	128	28C
0005432192344	11576	129	28E
0005433569093	11576	130	28D
0005433074944	11576	131	28F
0005433568812	11576	132	29B
0005433568934	11576	133	29D
0005433074937	11576	134	29E
0005433134174	11576	135	30A
0005433568902	11576	136	29F
0005433074935	11576	137	30B
0005432948772	11576	138	30C
0005432192345	11576	139	30E
0005433568878	11576	140	30D
0005433074946	11576	141	30F
0005432948801	11576	142	31A
0005432948789	11576	143	31C
0005433569081	11576	144	31B
0005432948805	11576	145	31D
0005433074932	11576	146	31E
0005433817503	10045	1	2B
0005433817502	10045	2	4B
0005434732988	10045	3	4A
0005434732989	10045	4	6A
0005434732983	10045	5	6B
0005434733009	13944	1	1A
0005434733011	13944	2	1B
0005433817470	13944	3	2B
0005434733010	13944	4	5A
0005434733008	13944	5	6A
0005433754717	2356	1	1A
0005433754714	2356	2	1B
0005435982677	2356	3	1F
0005435982665	2356	4	1C
0005435982695	2356	5	1H
0005433434694	2356	6	1G
0005435982688	2356	7	2A
0005432300312	2356	8	2C
0005433754686	2356	9	2B
0005432985223	2356	10	2F
0005435982674	2356	11	2H
0005433434770	2356	12	2G
0005433434695	2356	13	3A
0005433766673	2356	14	3C
0005432984938	2356	15	3G
0005433754702	2356	16	4A
0005433754708	2356	17	3H
0005432655638	2356	18	4B
0005433434675	2356	19	4F
0005435982700	2356	20	4C
0005433434705	2356	21	4G
0005432226108	2356	22	5A
0005435982671	2356	23	4H
0005435982685	2356	24	5C
0005432985052	2356	25	5G
0005435982713	2356	26	5F
0005434731167	2356	27	5H
0005433754707	2356	28	9B
0005432985222	2356	29	9A
0005433754669	2356	30	9G
0005435982699	2356	31	11A
0005435982678	2356	32	9H
0005433754677	2356	33	11B
0005433766670	2356	34	11E
0005432869502	2356	35	11F
0005432655632	2356	36	11H
0005435982710	2356	37	11G
0005435982703	2356	38	12A
0005433754684	2356	39	12D
0005433754695	2356	40	12B
0005435982681	2356	41	12E
0005435982684	2356	42	12F
0005432985034	2356	43	12H
0005432869514	2356	44	12G
0005435982698	2356	45	13A
0005433754713	2356	46	13D
0005433754706	2356	47	13B
0005432984974	2356	48	13F
0005433754711	2356	49	13G
0005432869524	2356	50	13H
0005432869515	2356	51	14B
0005433754680	2356	52	14F
0005433434668	2356	53	14E
0005433754683	2356	54	14G
0005433434692	2356	55	15A
0005432655637	2356	56	14H
0005433434704	2356	57	15B
0005432985018	2356	58	15E
0005432300314	2356	59	15D
0005435982682	2356	60	15F
0005433434584	2356	61	15H
0005433434693	2356	62	15G
0005435982668	2356	63	16A
0005432655641	2356	64	16B
0005433754676	2356	65	16E
0005432226111	2356	66	16G
0005435982694	2356	67	16F
0005433434605	2356	68	16H
0005433434612	2356	69	17D
0005432984985	2356	70	17B
0005432226107	2356	71	17F
0005435982705	2356	72	17E
0005432869487	2356	73	17G
0005434731160	2356	74	17H
0005432655635	2356	75	18B
0005433434604	2356	76	18A
0005435982712	2356	77	18D
0005433434748	2356	78	18F
0005432655640	2356	79	18E
0005432985048	2356	80	18H
0005433434543	2356	81	19B
0005433754694	2356	82	19A
0005432985067	2356	83	19E
0005432226106	2356	84	19D
0005433754682	2356	85	19F
0005432985051	2356	86	19H
0005435982687	2356	87	19G
0005435982693	2356	88	20A
0005433754696	2356	89	20D
0005435982706	2356	90	20B
0005432300313	2356	91	20E
0005433754700	2356	92	20F
0005433434679	2356	93	20H
0005433754681	2356	94	20G
0005432226110	2356	95	21D
0005433754665	2356	96	21B
0005433754674	2356	97	21F
0005435982692	2356	98	21H
0005435982691	2356	99	21G
0005433754716	2356	100	22A
0005433754704	2356	101	22D
0005435982689	2356	102	22B
0005432655633	2356	103	22F
0005435982670	2356	104	22E
0005432655636	2356	105	22G
0005433754671	2356	106	23A
0005433754698	2356	107	22H
0005433754667	2356	108	23D
0005435982715	2356	109	23B
0005433754663	2356	110	23F
0005435982686	2356	111	23E
0005433754689	2356	112	23G
0005433754705	2356	113	24A
0005433434710	2356	114	23H
0005432985019	2356	115	24B
0005433764696	2356	116	24D
0005434731171	2356	117	24F
0005433754675	2356	118	24E
0005432869501	2356	119	24G
0005433754662	2356	120	25D
0005435982675	2356	121	24H
0005433754664	2356	122	25E
0005433434707	2356	123	25F
0005435982669	2356	124	27A
0005433434701	2356	125	27E
0005433754660	2356	126	27D
0005433434761	2356	127	27F
0005432655639	2356	128	27G
0005435982714	2356	129	28A
0005433434687	2356	130	27H
0005433754712	2356	131	28B
0005432984939	2356	132	28E
0005433434711	2356	133	28D
0005432985112	2356	134	28G
0005435982707	2356	135	28F
0005435982701	2356	136	28H
0005432869523	2356	137	29A
0005432985114	2356	138	29D
0005433754709	2356	139	29B
0005432226109	2356	140	29G
0005432655634	2356	141	29F
0005432985161	2356	142	29H
0005433754685	2356	143	30B
0005432300309	2356	144	30A
0005433754678	2356	145	30D
0005433754703	2356	146	30F
0005432984984	2356	147	30E
0005433754690	2356	148	30G
0005433764698	2356	149	30H
0005435982704	2356	150	31B
0005433434678	2356	151	31D
0005433434613	2356	152	31F
0005435982711	2356	153	31E
0005433434670	2356	154	31H
0005433754691	2356	155	31G
0005433754699	2356	156	32D
0005433434708	2356	157	32B
0005433754697	2356	158	32A
0005433754701	2356	159	32F
0005432655642	2356	160	32E
0005435982666	2356	161	32G
0005433764697	2356	162	33A
0005435982716	2356	163	33D
0005435982708	2356	164	33B
0005433766672	2356	165	33E
0005433754661	2356	166	33F
0005435982679	2356	167	33H
0005432869530	2356	168	34B
0005435982680	2356	169	34A
0005435982673	2356	170	34D
0005433754687	2356	171	34E
0005434731172	2356	172	34G
0005433754666	2356	173	34F
0005433754672	2356	174	34H
0005432300310	2356	175	35B
0005435982702	2356	176	35D
0005432655643	2356	177	35F
0005435982667	2356	178	35E
0005435982709	2356	179	35G
0005435982697	2356	180	35H
0005432300315	2356	181	36B
0005433754693	2356	182	36A
0005433766671	2356	183	36E
0005435982696	2356	184	36D
0005433754679	2356	185	36F
0005435982672	2356	186	36H
0005432869494	2356	187	36G
0005433754715	2356	188	37A
0005432985113	2356	189	37B
0005435982676	2356	190	37E
0005435982690	2356	191	37F
0005435982683	2356	192	37H
0005433754692	2356	193	37G
0005432300311	2356	194	38A
0005433754670	2356	195	38D
0005433754668	2356	196	38B
0005433754710	2356	197	38E
0005433754688	2356	198	38H
0005433754673	2356	199	38G
0005434731168	2356	200	39E
0005432985069	2356	201	39D
0005433434724	2356	202	39F
0005433434907	26184	1	1A
0005433754026	26184	2	1C
0005433754264	26184	3	1B
0005432985337	26184	4	1H
0005433754354	26184	5	1G
0005433754330	26184	6	2A
0005432655461	26184	7	2B
0005433754136	26184	8	2F
0005433754302	26184	9	2C
0005435982118	26184	10	2H
0005435982258	26184	11	2G
0005433434920	26184	12	3A
0005435982325	26184	13	3B
0005435982365	26184	14	3G
0005432655525	26184	15	3H
0005435982175	26184	16	4C
0005432985353	26184	17	4B
0005433754104	26184	18	4A
0005432049492	26184	19	4F
0005433766628	26184	20	4G
0005432985343	26184	21	5A
0005433754273	26184	22	4H
0005432051155	26184	23	5B
0005433754250	26184	24	5F
0005433434921	26184	25	5C
0005433754158	26184	26	5G
0005433754266	26184	27	5H
0005433754114	26184	28	9B
0005433754195	26184	29	9G
0005434731206	26184	30	9H
0005433434916	26184	31	11B
0005433766645	26184	32	11A
0005433753990	26184	33	11E
0005432985360	26184	34	11D
0005433754132	26184	35	11G
0005432655516	26184	36	11F
0005435982368	26184	37	12A
0005435982245	26184	38	11H
0005435982328	26184	39	12B
0005432869578	26184	40	12E
0005432985355	26184	41	12D
0005435982288	26184	42	12G
0005433754183	26184	43	12F
0005433754024	26184	44	12H
0005432985332	26184	45	13A
0005433434900	26184	46	13D
0005435982409	26184	47	13F
0005435982369	26184	48	13E
0005433434914	26184	49	13G
0005433434908	26184	50	13H
0005432869573	26184	51	14A
0005433754127	26184	52	14E
0005435982107	26184	53	14D
0005435982441	26184	54	14B
0005433434909	26184	55	14F
0005432985333	26184	56	14G
0005433754253	26184	57	15A
0005433754159	26184	58	14H
0005435982289	26184	59	15B
0005433754255	26184	60	15E
0005432869574	26184	61	15D
0005435981987	26184	62	15F
0005432985336	26184	63	15G
0005432655462	26184	64	16B
0005433753938	26184	65	16A
0005433766646	26184	66	15H
0005433434905	26184	67	16D
0005433754112	26184	68	16F
0005432985334	26184	69	16E
0005433434902	26184	70	16H
0005433754219	26184	71	17A
0005435982335	26184	72	17D
0005434731205	26184	73	17B
0005432655474	26184	74	17E
0005435982310	26184	75	17G
0005435982297	26184	76	17F
0005433754223	26184	77	18A
0005433434913	26184	78	18B
0005432985362	26184	79	18D
0005433754085	26184	80	18E
0005433434899	26184	81	18G
0005433766630	26184	82	18F
0005432869579	26184	83	18H
0005433754164	26184	84	19D
0005435982476	26184	85	19B
0005432049493	26184	86	19E
0005433754265	26184	87	19F
0005435982123	26184	88	19H
0005432655473	26184	89	20A
0005435982414	26184	90	20B
0005432985357	26184	91	20E
0005432985339	26184	92	20D
0005432869576	26184	93	20F
0005432985345	26184	94	20H
0005433434904	26184	95	21D
0005432985344	26184	96	21B
0005435982228	26184	97	21E
0005432985340	26184	98	21G
0005433434923	26184	99	21F
0005435982049	26184	100	21H
0005433434911	26184	101	22B
0005432655519	26184	102	22A
0005432985348	26184	103	22D
0005433754220	26184	104	22E
0005432985330	26184	105	22G
0005433754111	26184	106	22H
0005435982124	26184	107	23B
0005433434910	26184	108	23A
0005433754228	26184	109	23E
0005435982260	26184	110	23D
0005433754276	26184	111	23F
0005433434926	26184	112	23H
0005433754080	26184	113	23G
0005435982400	26184	114	24B
0005432985359	26184	115	24A
0005433754110	26184	116	24D
0005433754340	26184	117	24F
0005432985329	26184	118	24H
0005432985346	26184	119	24G
0005433754263	26184	120	25D
0005433754041	26184	121	25E
0005432985358	26184	122	27A
0005433754184	26184	123	25F
0005433754322	26184	124	27B
0005433753993	26184	125	27E
0005435982339	26184	126	27D
0005435982159	26184	127	27F
0005435982327	26184	128	27H
0005433754084	26184	129	27G
0005435982413	26184	130	28A
0005433434915	26184	131	28D
0005433434906	26184	132	28B
0005433754113	26184	133	28E
0005433754181	26184	134	28F
0005432051154	26184	135	28H
0005435982259	26184	136	28G
0005432985351	26184	137	29A
0005432985338	26184	138	29B
0005432985356	26184	139	29D
0005432655446	26184	140	29G
0005433754331	26184	141	29F
0005433434912	26184	142	29H
0005432655528	26184	143	30A
0005433754157	26184	144	30D
0005433754251	26184	145	30B
0005433754323	26184	146	30F
0005433434917	26184	147	30E
0005435982295	26184	148	30G
0005433434919	26184	149	31A
0005432655527	26184	150	30H
0005433434922	26184	151	31B
0005432985347	26184	152	31F
0005432051153	26184	153	31E
0005433754221	26184	154	32A
0005433754152	26184	155	31H
0005432049494	26184	156	32B
0005433754156	26184	157	32D
0005432049496	26184	158	32E
0005432985350	26184	159	32H
0005435982257	26184	160	32G
0005433434924	26184	161	33A
0005433434927	26184	162	33B
0005433754044	26184	163	33E
0005432655499	26184	164	33D
0005433434928	26184	165	33F
0005432869575	26184	166	33H
0005433754267	26184	167	33G
0005432985341	26184	168	34A
0005433754366	26184	169	34D
0005432985335	26184	170	34B
0005435982235	26184	171	34F
0005433753937	26184	172	34E
0005433754153	26184	173	34G
0005433754347	26184	174	35A
0005433434925	26184	175	34H
0005433754025	26184	176	35B
0005433754109	26184	177	35D
0005432985352	26184	178	35E
0005435982280	26184	179	35H
0005435982034	26184	180	35G
0005432985354	26184	181	36B
0005432985349	26184	182	36A
0005433434918	26184	183	36D
0005434731204	26184	184	36F
0005433754341	26184	185	36E
0005433754216	26184	186	36H
0005435982477	26184	187	36G
0005433434901	26184	188	37A
0005432985361	26184	189	37B
0005432985331	26184	190	37E
0005433434903	26184	191	37D
0005434731207	26184	192	37F
0005435982234	26184	193	37H
0005432869577	26184	194	37G
0005433754361	26184	195	38B
0005432049495	26184	196	38E
0005433754285	26184	197	38D
0005432985342	26184	198	38G
0005433754257	26184	199	38F
0005433754333	26184	200	38H
0005432655554	26184	201	39E
0005433754256	26184	202	39D
0005432655472	26184	203	39F
0005433151494	1515	1	1C
0005434375059	1515	2	1F
0005434375053	1515	3	2D
0005434375057	1515	4	2F
0005432267954	1515	5	3C
0005434375025	1515	6	3D
0005433151446	1515	7	3F
0005433151377	1515	8	4B
0005434375041	1515	9	4A
0005434375061	1515	10	4D
0005433151310	1515	11	5A
0005434375045	1515	12	5B
0005433151364	1515	13	5C
0005434375032	1515	14	5E
0005433151531	1515	15	6C
0005434375042	1515	16	6D
0005434375015	1515	17	6E
0005434375016	1515	18	7A
0005433151480	1515	19	7C
0005433151481	1515	20	7B
0005434375035	1515	21	7F
0005434375017	1515	22	7E
0005434375038	1515	23	8B
0005434375040	1515	24	8A
0005434375058	1515	25	8D
0005434375039	1515	26	8E
0005433151510	1515	27	9A
0005433151489	1515	28	8F
0005434375037	1515	29	9D
0005434029650	1515	30	9C
0005433151365	1515	31	9E
0005432267953	1515	32	9F
0005433151435	1515	33	10B
0005433151342	1515	34	10C
0005434375021	1515	35	10E
0005434375019	1515	36	10D
0005434375060	1515	37	11B
0005432267950	1515	38	11D
0005433461605	1515	39	11F
0005434375034	1515	40	12A
0005434375049	1515	41	12B
0005434375013	1515	42	12D
0005433461606	1515	43	13D
0005434375047	1515	44	13C
0005432267952	1515	45	13F
0005432267949	1515	46	14C
0005434375050	1515	47	14E
0005434375028	1515	48	14F
0005434375062	1515	49	15B
0005434375056	1515	50	15A
0005434375033	1515	51	15C
0005434375020	1515	52	15D
0005434375022	1515	53	15E
0005434375027	1515	54	16A
0005433460454	1515	55	16B
0005433764680	1515	56	16D
0005433151488	1515	57	16E
0005433151530	1515	58	16F
0005434375029	1515	59	17C
0005434375031	1515	60	17D
0005434375048	1515	61	17E
0005434375030	1515	62	18A
0005434375023	1515	63	17F
0005433151560	1515	64	18B
0005432267951	1515	65	18F
0005434375024	1515	66	19B
0005433151495	1515	67	19A
0005434375018	1515	68	19C
0005434375014	1515	69	19D
0005433151363	1515	70	20B
0005434375043	1515	71	20A
0005432267948	1515	72	20C
0005433151519	1515	73	20F
0005434375054	1515	74	21B
0005434375036	1515	75	21A
0005433460453	1515	76	21C
0005433931457	1515	77	21D
0005434375052	1515	78	21E
0005433151445	1515	79	21F
0005434375026	1515	80	22A
0005434375055	1515	81	22C
0005434375044	1515	82	22B
0005433151458	1515	83	22D
0005434375012	1515	84	22F
0005433151148	1515	85	23B
0005434375046	1515	86	23C
0005434375051	1515	87	23D
0005433151701	20128	1	1D
0005434374705	20128	2	1C
0005434374719	20128	3	2A
0005433151692	20128	4	2D
0005433151694	20128	5	2C
0005434376223	20128	6	3D
0005433151679	20128	7	3C
0005433764698	20128	8	4A
0005434374652	20128	9	4C
0005434374636	20128	10	4E
0005433151675	20128	11	4F
0005434374624	20128	12	5C
0005433151697	20128	13	5E
0005433764697	20128	14	5F
0005434374573	20128	15	6C
0005434374675	20128	16	6D
0005433151682	20128	17	6F
0005433151681	20128	18	7A
0005432056330	20128	19	7B
0005433151699	20128	20	7E
0005434029678	20128	21	7F
0005433931492	20128	22	8B
0005433151706	20128	23	8A
0005433151705	20128	24	8D
0005434374776	20128	25	8E
0005433151674	20128	26	8F
0005433151680	20128	27	9A
0005434374612	20128	28	9D
0005434374629	20128	29	9F
0005433151688	20128	30	10B
0005434374616	20128	31	10E
0005433931491	20128	32	11A
0005433151677	20128	33	11C
0005434374493	20128	34	11B
0005433151695	20128	35	11F
0005433151683	20128	36	12A
0005433931490	20128	37	12E
0005433151690	20128	38	13A
0005434029677	20128	39	13D
0005433151696	20128	40	13F
0005434374492	20128	41	14D
0005434374828	20128	42	14E
0005433151700	20128	43	14F
0005433151691	20128	44	15B
0005434374504	20128	45	15A
0005433151702	20128	46	15D
0005433151678	20128	47	15E
0005434374491	20128	48	15F
0005434374651	20128	49	16E
0005433151687	20128	50	17A
0005434374594	20128	51	17B
0005434374856	20128	52	17D
0005434374744	20128	53	17C
0005434374653	20128	54	17F
0005433151707	20128	55	17E
0005434374640	20128	56	18A
0005432056331	20128	57	18B
0005433151704	20128	58	18C
0005434374748	20128	59	18D
0005433151703	20128	60	18F
0005432056329	20128	61	18E
0005434374857	20128	62	19A
0005434374483	20128	63	19B
0005434374482	20128	64	19C
0005433151685	20128	65	19E
0005434374549	20128	66	20A
0005434374752	20128	67	19F
0005433764696	20128	68	20E
0005433151693	20128	69	20F
0005434374633	20128	70	21C
0005433151689	20128	71	21E
0005433151673	20128	72	22B
0005434374611	20128	73	22C
0005434376224	20128	74	22D
0005433151676	20128	75	22E
0005433151684	20128	76	23A
0005433151686	20128	77	23B
0005433151698	20128	78	23D
0005434029676	20128	79	23F
0005432424839	566	1	2D
0005432282923	566	2	3D
0005432424826	566	3	4C
0005432424842	566	4	4F
0005432424828	566	5	5F
0005432424860	566	6	8F
0005432424863	566	7	9D
0005432282922	566	8	9F
0005432282925	566	9	10F
0005432424843	566	10	11A
0005432424829	566	11	11C
0005432424845	566	12	11E
0005432424859	566	13	11F
0005432424861	566	14	12D
0005432424857	566	15	13A
0005432424841	566	16	13D
0005432424836	566	17	13E
0005432424854	566	18	15A
0005432424837	566	19	15D
0005432424844	566	20	15F
0005432424822	566	21	16D
0005432424858	566	22	17B
0005432424862	566	23	17C
0005432424856	566	24	17F
0005432424855	566	25	20A
0005432282920	566	26	21B
0005432424823	566	27	21C
0005432424847	566	28	21E
0005432424824	566	29	22A
0005432424853	566	30	22C
0005432424830	566	31	23D
0005432424850	566	32	23F
0005432424851	566	33	25A
0005432424825	566	34	26B
0005432424846	566	35	26D
0005432424838	566	36	26F
0005432424852	566	37	27C
0005432282924	566	38	27B
0005432424834	566	39	27D
0005432424835	566	40	27E
0005432424849	566	41	27F
0005432424831	566	42	28B
0005432424833	566	43	29C
0005432424832	566	44	29E
0005432424848	566	45	29F
0005432424840	566	46	30B
0005432282921	566	47	30F
0005432424827	566	48	31F
0005433158148	12924	1	1A
0005434446517	12924	2	2A
0005432302365	12924	3	5D
0005434446521	12924	4	6A
0005432302361	12924	5	7A
0005434446514	12924	6	10C
0005433158151	12924	7	11E
0005433158150	12924	8	14C
0005433158147	12924	9	16C
0005434446522	12924	10	24A
0005432302364	12924	11	26B
0005432302363	12924	12	26E
0005432302362	12924	13	29D
0005433158149	12924	14	29F
0005432302360	12924	15	31D
0005432424365	12920	1	2A
0005432424389	12920	2	2D
0005432424303	12920	3	5D
0005432424394	12920	4	6A
0005432424410	12920	5	7F
0005432424403	12920	6	8A
0005432424399	12920	7	9A
0005432424329	12920	8	9B
0005432424263	12920	9	9D
0005432424341	12920	10	11F
0005432424357	12920	11	11E
0005432424358	12920	12	12E
0005432424408	12920	13	13A
0005432424388	12920	14	14E
0005432424375	12920	15	15B
0005432424310	12920	16	15A
0005432424346	12920	17	17B
0005432424189	12920	18	17C
0005432424262	12920	19	17F
0005432424337	12920	20	18B
0005432424196	12920	21	19C
0005432424364	12920	22	19B
0005432424336	12920	23	20B
0005432424342	12920	24	20E
0005432424404	12920	25	20D
0005432424373	12920	26	22B
0005432424347	12920	27	22D
0005432424356	12920	28	22C
0005432424348	12920	29	23B
0005432424304	12920	30	24B
0005432424385	12920	31	24D
0005432424258	12920	32	25F
0005432424411	12920	33	25E
0005432424372	12920	34	26E
0005432424409	12920	35	26D
0005432424324	12920	36	27D
0005432424340	12920	37	28B
0005432424395	12920	38	28C
0005432424325	12920	39	28E
0005432424374	12920	40	29C
0005432424163	12920	41	30B
0005432424298	12920	42	31A
0005432424345	12920	43	31D
0005433929596	453	1	1A
0005433057997	453	2	1B
0005432235700	453	3	1G
0005434028317	453	4	2A
0005434024293	453	5	1H
0005434024297	453	6	2C
0005434024287	453	7	2H
0005433057947	453	8	2F
0005433057901	453	9	3A
0005434735672	453	10	3B
0005434024299	453	11	3C
0005433057902	453	12	3H
0005434024246	453	13	3F
0005434024264	453	14	4F
0005433057913	453	15	4C
0005433058023	453	16	4H
0005434024283	453	17	5C
0005433058002	453	18	5H
0005434024294	453	19	9G
0005433057932	453	20	11A
0005434024235	453	21	9H
0005434024253	453	22	11B
0005434024257	453	23	11E
0005434024288	453	24	11F
0005434024242	453	25	11H
0005433057722	453	26	11G
0005433057765	453	27	12B
0005433057896	453	28	12E
0005434024284	453	29	12F
0005433057692	453	30	12G
0005434024261	453	31	13B
0005434024262	453	32	13A
0005434024270	453	33	13G
0005433057754	453	34	13H
0005433057848	453	35	14F
0005433057954	453	36	15B
0005433057900	453	37	15E
0005434024254	453	38	15H
0005432235697	453	39	16A
0005434024255	453	40	16E
0005434024300	453	41	16G
0005434024267	453	42	16H
0005434024263	453	43	17A
0005433057846	453	44	17G
0005433058000	453	45	18B
0005432235699	453	46	18D
0005434024259	453	47	18F
0005433057820	453	48	18E
0005434024245	453	49	19B
0005433057876	453	50	19A
0005433057911	453	51	19D
0005434024277	453	52	19F
0005433057868	453	53	19G
0005433057920	453	54	20A
0005433057895	453	55	19H
0005432235702	453	56	20B
0005434024278	453	57	20E
0005433057821	453	58	20F
0005433057973	453	59	21A
0005434024268	453	60	21D
0005433057918	453	61	21E
0005434024248	453	62	21F
0005434024260	453	63	21H
0005434024252	453	64	22B
0005434024256	453	65	22A
0005434032060	453	66	22D
0005434024247	453	67	22F
0005434024266	453	68	22E
0005433057930	453	69	22G
0005434735675	453	70	23A
0005434024236	453	71	22H
0005434024289	453	72	23D
0005434024286	453	73	23F
0005434024250	453	74	23H
0005434024292	453	75	24B
0005434024296	453	76	24A
0005434032056	453	77	24D
0005433058025	453	78	24F
0005434735693	453	79	24E
0005433057878	453	80	24G
0005434032058	453	81	24H
0005432045629	453	82	25E
0005434024240	453	83	25D
0005434024239	453	84	25F
0005432045628	453	85	27B
0005434735674	453	86	27E
0005433058129	453	87	27D
0005433057912	453	88	27F
0005433057814	453	89	27H
0005434024282	453	90	28A
0005433058026	453	91	28D
0005434024301	453	92	28B
0005434032059	453	93	28E
0005433057919	453	94	28F
0005433057859	453	95	28G
0005433057877	453	96	28H
0005434024280	453	97	29D
0005434028316	453	98	29B
0005434024243	453	99	29E
0005434024281	453	100	29F
0005434024295	453	101	29G
0005434024273	453	102	30A
0005434024291	453	103	30B
0005434024279	453	104	30E
0005434024251	453	105	31A
0005433058001	453	106	31B
0005433058024	453	107	31E
0005432235698	453	108	31H
0005434024298	453	109	31G
0005433058011	453	110	32A
0005434024258	453	111	32D
0005433057858	453	112	32F
0005434024244	453	113	32H
0005434024241	453	114	32G
0005433057996	453	115	33A
0005434024274	453	116	33D
0005434029674	453	117	33E
0005434024303	453	118	33F
0005433057969	453	119	33H
0005434024237	453	120	34D
0005434024238	453	121	34B
0005433057889	453	122	34F
0005434024275	453	123	34E
0005434024249	453	124	34G
0005434024265	453	125	34H
0005433058052	453	126	35B
0005432235703	453	127	35A
0005434024269	453	128	35G
0005433057964	453	129	36A
0005434024302	453	130	35H
0005432235701	453	131	36B
0005433057940	453	132	36F
0005434029675	453	133	36G
0005434024272	453	134	37A
0005434024271	453	135	36H
0005433057966	453	136	37D
0005433058059	453	137	37B
0005433057910	453	138	38A
0005433057817	453	139	38B
0005434024285	453	140	38D
0005434032057	453	141	38G
0005434024276	453	142	39D
0005433057831	453	143	39F
0005434024290	453	144	39E
0005433058203	12684	1	1F
0005434024086	12684	2	1C
0005434023640	12684	3	1G
0005434023702	12684	4	2A
0005434023533	12684	5	1H
0005434024065	12684	6	2B
0005434023876	12684	7	2C
0005432157508	12684	8	2G
0005432156404	12684	9	3G
0005433058196	12684	10	4A
0005434023506	12684	11	4B
0005434023359	12684	12	4F
0005433058220	12684	13	4C
0005433058197	12684	14	4G
0005434023687	12684	15	5C
0005434023631	12684	16	5G
0005434023742	12684	17	9A
0005433058206	12684	18	9G
0005433058217	12684	19	11A
0005434023630	12684	20	11D
0005434023786	12684	21	11B
0005434024088	12684	22	11E
0005434032025	12684	23	11F
0005432156403	12684	24	11G
0005433058224	12684	25	12A
0005434735733	12684	26	12D
0005434023904	12684	27	12E
0005434023627	12684	28	12F
0005434023360	12684	29	13A
0005434023785	12684	30	13F
0005434032026	12684	31	13G
0005433058228	12684	32	14B
0005434023752	12684	33	14E
0005433058209	12684	34	14G
0005432156401	12684	35	15A
0005434023877	12684	36	15E
0005434023974	12684	37	16E
0005434023832	12684	38	17A
0005434023754	12684	39	17B
0005432156400	12684	40	17G
0005434023444	12684	41	17H
0005434023632	12684	42	18A
0005433058214	12684	43	18F
0005434023889	12684	44	18E
0005434023814	12684	45	19A
0005434023903	12684	46	19D
0005434735735	12684	47	19E
0005434023722	12684	48	19F
0005434023626	12684	49	20A
0005434023625	12684	50	19H
0005433058235	12684	51	20D
0005434023866	12684	52	20G
0005433058232	12684	53	20F
0005434023809	12684	54	20E
0005433058213	12684	55	20H
0005433058226	12684	56	21B
0005433058230	12684	57	21D
0005433058198	12684	58	22A
0005434023557	12684	59	22G
0005434032027	12684	60	23A
0005434735731	12684	61	22H
0005434024087	12684	62	23G
0005433058207	12684	63	24A
0005434023663	12684	64	23H
0005434023951	12684	65	24B
0005433058205	12684	66	24E
0005434023566	12684	67	24D
0005433058210	12684	68	24F
0005434024066	12684	69	25D
0005434735734	12684	70	25E
0005433058221	12684	71	25F
0005433929646	12684	72	27B
0005432156402	12684	73	27A
0005433058211	12684	74	27E
0005434023561	12684	75	27D
0005434023893	12684	76	28A
0005434023796	12684	77	27H
0005433058233	12684	78	28D
0005433058201	12684	79	28B
0005433058212	12684	80	28F
0005433058219	12684	81	28G
0005434023649	12684	82	29A
0005434023888	12684	83	28H
0005433058234	12684	84	29B
0005433058218	12684	85	29F
0005433058216	12684	86	29H
0005434023507	12684	87	30A
0005434023570	12684	88	30D
0005434023603	12684	89	30B
0005433058215	12684	90	30E
0005433058227	12684	91	31A
0005434024085	12684	92	31B
0005433058208	12684	93	31F
0005433058202	12684	94	31E
0005434023532	12684	95	31G
0005434023684	12684	96	32B
0005434023404	12684	97	32E
0005433058200	12684	98	32F
0005433058199	12684	99	32H
0005433058225	12684	100	32G
0005433058231	12684	101	33A
0005433058222	12684	102	33B
0005434735732	12684	103	33G
0005434023641	12684	104	33F
0005434023511	12684	105	33H
0005434023676	12684	106	34A
0005434023646	12684	107	34D
0005434029650	12684	108	34H
0005434023952	12684	109	35A
0005434023787	12684	110	35G
0005434023908	12684	111	36A
0005433058195	12684	112	35H
0005433058204	12684	113	36E
0005434023682	12684	114	36D
0005433929648	12684	115	36G
0005434023658	12684	116	37A
0005433929647	12684	117	36H
0005433058223	12684	118	37D
0005434023894	12684	119	37F
0005434023773	12684	120	37E
0005434023774	12684	121	37H
0005434023609	12684	122	37G
0005434023739	12684	123	38A
0005433058229	12684	124	38G
0005434023778	12684	125	39E
0005433036286	2139	1	1A
0005433036346	2139	2	1F
0005433924130	2139	3	1C
0005433924108	2139	4	1H
0005433924045	2139	5	1G
0005433036218	2139	6	2A
0005433924105	2139	7	2C
0005433924049	2139	8	2B
0005433036424	2139	9	2F
0005433036179	2139	10	2G
0005433924092	2139	11	3A
0005432749780	2139	12	2H
0005433929648	2139	13	3B
0005433924110	2139	14	3F
0005433924060	2139	15	3C
0005433924058	2139	16	3G
0005433036292	2139	17	4A
0005433924106	2139	18	3H
0005433924086	2139	19	4B
0005433924104	2139	20	4F
0005432749785	2139	21	4C
0005433924069	2139	22	4G
0005433924136	2139	23	4H
0005433924053	2139	24	5B
0005433036449	2139	25	5C
0005433924076	2139	26	5G
0005433924079	2139	27	5F
0005433924057	2139	28	5H
0005433924122	2139	29	9B
0005433036095	2139	30	9A
0005433036345	2139	31	9H
0005432231653	2139	32	11D
0005433924044	2139	33	11B
0005433036331	2139	34	11A
0005432231648	2139	35	11F
0005433924128	2139	36	11E
0005433924068	2139	37	11H
0005433924063	2139	38	12A
0005433036275	2139	39	12B
0005433924046	2139	40	12E
0005433924052	2139	41	12F
0005433924132	2139	42	12H
0005433036115	2139	43	13B
0005433924134	2139	44	13A
0005433924113	2139	45	13D
0005433924115	2139	46	13F
0005433924120	2139	47	13E
0005433924083	2139	48	13G
0005433036322	2139	49	13H
0005433036024	2139	50	14B
0005433036154	2139	51	14E
0005433924093	2139	52	14D
0005433924061	2139	53	14G
0005433036417	2139	54	14H
0005433931491	2139	55	15D
0005433924118	2139	56	15E
0005433036421	2139	57	15F
0005433036422	2139	58	15H
0005433924073	2139	59	16E
0005433931492	2139	60	16D
0005433924087	2139	61	16F
0005433036308	2139	62	17A
0005433924126	2139	63	17D
0005433924138	2139	64	17F
0005433924054	2139	65	17E
0005433924133	2139	66	17G
0005432231656	2139	67	18A
0005433924123	2139	68	18B
0005433924121	2139	69	18D
0005432231650	2139	70	18F
0005433924102	2139	71	18E
0005433924067	2139	72	18H
0005433924048	2139	73	19A
0005433036208	2139	74	19B
0005433924082	2139	75	19D
0005433931490	2139	76	19F
0005432749779	2139	77	19H
0005433036261	2139	78	19G
0005433036246	2139	79	20D
0005433036220	2139	80	20B
0005433924077	2139	81	20E
0005433036155	2139	82	20H
0005433036339	2139	83	20G
0005433924064	2139	84	21D
0005433924065	2139	85	21B
0005433036306	2139	86	21E
0005433036321	2139	87	21G
0005433924135	2139	88	21F
0005433924078	2139	89	21H
0005433924055	2139	90	22A
0005433929647	2139	91	22D
0005433036358	2139	92	22B
0005433924047	2139	93	22G
0005433924075	2139	94	22F
0005433924085	2139	95	22H
0005433924131	2139	96	23A
0005433924088	2139	97	23D
0005433924080	2139	98	23F
0005433036324	2139	99	23E
0005433924074	2139	100	23G
0005433929646	2139	101	23H
0005433924070	2139	102	24B
0005432231652	2139	103	24E
0005433036310	2139	104	24G
0005432044548	2139	105	24H
0005433924071	2139	106	25F
0005433924107	2139	107	27A
0005433036193	2139	108	27B
0005432231655	2139	109	27E
0005433924051	2139	110	27F
0005432231651	2139	111	27G
0005433036460	2139	112	28A
0005433036194	2139	113	28B
0005433036114	2139	114	28D
0005433035943	2139	115	28G
0005433036330	2139	116	28F
0005432749786	2139	117	28E
0005433924097	2139	118	28H
0005433924094	2139	119	29A
0005433924127	2139	120	29B
0005433924129	2139	121	29E
0005433036274	2139	122	29F
0005432231649	2139	123	29H
0005433924059	2139	124	29G
0005433924139	2139	125	30B
0005432044549	2139	126	30A
0005433924103	2139	127	30D
0005433924140	2139	128	30G
0005433924116	2139	129	30F
0005433924124	2139	130	30H
0005433036373	2139	131	31B
0005433924043	2139	132	31D
0005433924119	2139	133	31G
0005433924072	2139	134	32A
0005433924137	2139	135	31H
0005433036293	2139	136	32B
0005433036305	2139	137	32D
0005433924117	2139	138	32G
0005433924111	2139	139	33A
0005433924095	2139	140	33B
0005433036064	2139	141	33E
0005432231647	2139	142	33F
0005432231654	2139	143	33H
0005433036252	2139	144	33G
0005433924096	2139	145	34D
0005433924042	2139	146	34B
0005433924114	2139	147	34E
0005433924112	2139	148	34G
0005433924099	2139	149	35A
0005433924056	2139	150	34H
0005433036317	2139	151	35B
0005433924100	2139	152	35D
0005433036219	2139	153	35F
0005433924084	2139	154	35G
0005433924050	2139	155	35H
0005433924066	2139	156	36B
0005433924101	2139	157	36A
0005433036166	2139	158	36E
0005433036177	2139	159	36D
0005433036316	2139	160	36G
0005433924081	2139	161	37A
0005433036384	2139	162	36H
0005432044547	2139	163	37B
0005433924125	2139	164	37D
0005433036153	2139	165	37F
0005433924091	2139	166	37H
0005433924109	2139	167	37G
0005433924062	2139	168	38A
0005433036357	2139	169	38B
0005433924089	2139	170	38E
0005433924098	2139	171	38D
0005433924090	2139	172	38G
0005433036309	2139	173	39E
0005433036180	2139	174	39D
0005433922851	24121	1	1A
0005433875372	24121	2	1B
0005433923543	24121	3	1F
0005433923735	24121	4	1C
0005433923284	24121	5	1H
0005432206246	24121	6	1G
0005432207685	24121	7	2A
0005433923405	24121	8	2B
0005433923375	24121	9	2F
0005433929857	24121	10	2C
0005433923427	24121	11	2G
0005433036724	24121	12	3A
0005433923163	24121	13	2H
0005433931470	24121	14	3B
0005433922969	24121	15	3C
0005433036714	24121	16	3H
0005433036708	24121	17	3F
0005433036726	24121	18	4B
0005433923734	24121	19	4A
0005433923428	24121	20	4F
0005433923282	24121	21	4C
0005433036710	24121	22	4G
0005433931466	24121	23	5A
0005433923346	24121	24	4H
0005433036728	24121	25	5C
0005433036722	24121	26	5B
0005433922992	24121	27	5F
0005433923290	24121	28	5H
0005433036727	24121	29	9B
0005433036746	24121	30	9A
0005433923021	24121	31	9G
0005433922839	24121	32	11D
0005433923312	24121	33	11B
0005433923323	24121	34	11F
0005433036751	24121	35	11E
0005433036718	24121	36	11H
0005433923478	24121	37	11G
0005433036754	24121	38	12D
0005433923316	24121	39	12B
0005433036755	24121	40	12E
0005433036723	24121	41	12F
0005433036748	24121	42	12H
0005433923315	24121	43	13D
0005433036758	24121	44	13E
0005433922923	24121	45	13G
0005433036720	24121	46	13F
0005433929627	24121	47	14B
0005432749803	24121	48	14D
0005433929628	24121	49	14E
0005433036735	24121	50	14G
0005433036759	24121	51	15A
0005433922994	24121	52	14H
0005433923408	24121	53	15B
0005433923399	24121	54	15E
0005433923120	24121	55	15D
0005433036711	24121	56	15H
0005433923018	24121	57	15G
0005433923203	24121	58	16B
0005433923407	24121	59	16A
0005432206241	24121	60	16D
0005433922968	24121	61	16G
0005433923202	24121	62	16H
0005433036730	24121	63	17A
0005433036745	24121	64	17D
0005433922922	24121	65	17B
0005433923214	24121	66	17E
0005433036713	24121	67	17F
0005433923321	24121	68	18A
0005433923495	24121	69	17H
0005432749802	24121	70	18D
0005433923210	24121	71	18E
0005433875377	24121	72	18G
0005433923119	24121	73	18F
0005433923020	24121	74	18H
0005433922852	24121	75	19B
0005433923352	24121	76	19E
0005434028319	24121	77	19D
0005433036712	24121	78	19F
0005433036709	24121	79	19H
0005433875373	24121	80	20A
0005433923019	24121	81	20B
0005433036732	24121	82	20E
0005433036736	24121	83	20D
0005433036731	24121	84	20G
0005433923384	24121	85	20F
0005433923388	24121	86	21A
0005433036738	24121	87	20H
0005432207684	24121	88	21B
0005433923297	24121	89	21E
0005433036737	24121	90	21D
0005433923028	24121	91	21G
0005433923162	24121	92	21H
0005433036750	24121	93	22B
0005433923395	24121	94	22F
0005433923023	24121	95	22E
0005433922881	24121	96	22G
0005433931465	24121	97	23B
0005433036729	24121	98	23D
0005433922927	24121	99	23F
0005433923289	24121	100	23E
0005433036716	24121	101	23G
0005432206245	24121	102	24A
0005433036715	24121	103	24B
0005433036760	24121	104	24E
0005432749804	24121	105	24D
0005433923426	24121	106	24F
0005433923213	24121	107	24H
0005434028320	24121	108	25D
0005433036747	24121	109	25E
0005433923117	24121	110	27A
0005433923158	24121	111	25F
0005433923025	24121	112	27B
0005433922965	24121	113	27E
0005432206243	24121	114	27G
0005433931471	24121	115	28A
0005433922826	24121	116	27H
0005433923536	24121	117	28B
0005433036719	24121	118	28D
0005433922827	24121	119	28F
0005433036744	24121	120	28G
0005433923351	24121	121	29A
0005433922781	24121	122	28H
0005433923345	24121	123	29B
0005432206242	24121	124	29D
0005433923317	24121	125	29F
0005433923533	24121	126	29H
0005433922791	24121	127	29G
0005433036756	24121	128	30B
0005433923696	24121	129	30D
0005433036743	24121	130	30E
0005433929601	24121	131	30G
0005433923168	24121	132	30F
0005433923374	24121	133	31A
0005433923383	24121	134	30H
0005433931463	24121	135	31B
0005433923368	24121	136	31F
0005433923251	24121	137	31E
0005433036734	24121	138	31H
0005433036757	24121	139	32A
0005433036707	24121	140	32B
0005433923432	24121	141	32E
0005433923150	24121	142	32D
0005433922792	24121	143	32H
0005433923258	24121	144	32G
0005433923149	24121	145	33A
0005433036733	24121	146	33B
0005433923164	24121	147	33E
0005433036741	24121	148	33D
0005433923394	24121	149	33F
0005433923262	24121	150	33H
0005433923479	24121	151	34A
0005433036749	24121	152	34F
0005433923446	24121	153	34G
0005434028318	24121	154	34H
0005433923292	24121	155	35A
0005433923246	24121	156	35D
0005433923439	24121	157	35B
0005433923069	24121	158	35F
0005433923144	24121	159	35H
0005433036725	24121	160	36B
0005433923400	24121	161	36A
0005433922780	24121	162	36D
0005433036753	24121	163	36F
0005433923545	24121	164	36E
0005433036717	24121	165	36H
0005433923024	24121	166	36G
0005433036740	24121	167	37B
0005433923027	24121	168	37E
0005433036721	24121	169	37D
0005433036739	24121	170	37F
0005432206244	24121	171	37H
0005433923505	24121	172	37G
0005433036742	24121	173	38D
0005433923052	24121	174	38E
0005433036752	24121	175	38G
0005433923532	24121	176	39D
0005433929626	24121	177	39F
0005434028321	24121	178	39E
0005434726424	271	1	1D
0005433234265	271	2	1C
0005434726450	271	3	1A
0005434726440	271	4	1G
0005433234438	271	5	1K
0005433234047	271	6	1H
0005434726426	271	7	2D
0005433234308	271	8	2C
0005435142689	271	9	2A
0005434726425	271	10	2G
0005434726467	271	11	3C
0005433233984	271	12	3A
0005434731201	271	13	2K
0005434551690	271	14	2H
0005434726468	271	15	3G
0005433234538	271	16	3D
0005434551678	271	17	4C
0005433234267	271	18	4A
0005434551666	271	19	3K
0005434726485	271	20	4G
0005434726452	271	21	4H
0005434726476	271	22	5D
0005434551697	271	23	5C
0005434302495	271	24	5H
0005434726446	271	25	5G
0005434726512	271	26	11A
0005434735728	271	27	5K
0005434726529	271	28	11D
0005432277913	271	29	11C
0005433234169	271	30	11F
0005434551684	271	31	11E
0005434726510	271	32	11H
0005434726479	271	33	11G
0005434551677	271	34	12C
0005433181054	271	35	12A
0005433181181	271	36	12D
0005433234316	271	37	12K
0005432277914	271	38	13C
0005433111489	271	39	13A
0005434726414	271	40	13F
0005433234081	271	41	13E
0005434551711	271	42	13D
0005434551676	271	43	13G
0005434726488	271	44	14A
0005433234219	271	45	13K
0005434551708	271	46	14D
0005434726527	271	47	14C
0005434302497	271	48	14G
0005433181056	271	49	14F
0005433131712	271	50	14E
0005434302498	271	51	15C
0005433181102	271	52	15A
0005433234212	271	53	15E
0005434726436	271	54	15D
0005434551704	271	55	15F
0005434551681	271	56	15K
0005434726434	271	57	16C
0005434726500	271	58	16A
0005434726517	271	59	16E
0005433233975	271	60	16H
0005434735727	271	61	16G
0005433234420	271	62	17C
0005434726473	271	63	17A
0005434726451	271	64	16K
0005433234082	271	65	17E
0005434726435	271	66	17D
0005433233977	271	67	17G
0005434726486	271	68	17F
0005434726439	271	69	18A
0005434726457	271	70	17K
0005434551709	271	71	17H
0005434726532	271	72	18B
0005433234184	271	73	18D
0005434726460	271	74	18G
0005434726432	271	75	18F
0005434726506	271	76	18K
0005434726438	271	77	18J
0005434726521	271	78	18H
0005434551660	271	79	19B
0005434726418	271	80	19A
0005433181103	271	81	19D
0005433181032	271	82	19C
0005435142694	271	83	19F
0005434551694	271	84	19E
0005434551673	271	85	19H
0005432277923	271	86	19G
0005434726480	271	87	20A
0005434726475	271	88	19K
0005435142691	271	89	19J
0005432277921	271	90	20B
0005433113530	271	91	20E
0005434726490	271	92	20D
0005434735729	271	93	20G
0005434551700	271	94	20F
0005434735730	271	95	20J
0005434726493	271	96	20H
0005434726495	271	97	21B
0005434726419	271	98	21A
0005434726433	271	99	21C
0005434726472	271	100	21G
0005435142683	271	101	21F
0005434551710	271	102	21E
0005434551658	271	103	21H
0005434726483	271	104	22A
0005433126834	271	105	21K
0005433233989	271	106	21J
0005434726441	271	107	22C
0005433234107	271	108	22B
0005434731202	271	109	22F
0005433234203	271	110	22G
0005434726470	271	111	22J
0005435142690	271	112	22H
0005434726477	271	113	23B
0005433126814	271	114	23A
0005435142688	271	115	23C
0005433234009	271	116	23G
0005434735725	271	117	23F
0005434551670	271	118	23H
0005434551701	271	119	24D
0005434726427	271	120	23K
0005433126832	271	121	23J
0005434551695	271	122	24F
0005434551665	271	123	24E
0005434726513	271	124	25B
0005434302496	271	125	25A
0005434731200	271	126	25C
0005434726530	271	127	25E
0005433181091	271	128	25H
0005434726411	271	129	25G
0005434731203	271	130	25K
0005433181009	271	131	25J
0005434726413	271	132	26B
0005434726449	271	133	26E
0005433234183	271	134	26D
0005434551699	271	135	26G
0005434551693	271	136	26F
0005434726423	271	137	26J
0005433181189	271	138	26H
0005434551712	271	139	27B
0005434726522	271	140	27A
0005433181083	271	141	27C
0005435142684	271	142	27F
0005433113529	271	143	27E
0005434726528	271	144	27H
0005434726443	271	145	27G
0005435142685	271	146	27K
0005433234125	271	147	28C
0005434726459	271	148	28B
0005434726421	271	149	28A
0005433234421	271	150	28E
0005432277922	271	151	28D
0005434735726	271	152	28G
0005434726511	271	153	28F
0005434726471	271	154	28J
0005432277915	271	155	28H
0005434551686	271	156	29B
0005434726428	271	157	29A
0005433181152	271	158	29D
0005434726507	271	159	29C
0005432277925	271	160	29F
0005433181008	271	161	29H
0005434551685	271	162	29G
0005434726516	271	163	29K
0005433234167	271	164	29J
0005433234207	271	165	30B
0005433181179	271	166	30A
0005433234391	271	167	30E
0005434726515	271	168	30D
0005432277920	271	169	30G
0005433234218	271	170	30F
0005434551672	271	171	30K
0005433234330	271	172	30J
0005433234058	271	173	31A
0005434726525	271	174	31D
0005433766642	271	175	31C
0005433234196	271	176	31B
0005433126833	271	177	31E
0005435142687	271	178	31H
0005434726526	271	179	31G
0005433234318	271	180	32A
0005434726417	271	181	31K
0005433181163	271	182	31J
0005434551689	271	183	32C
0005434726456	271	184	32D
0005434726442	271	185	32G
0005434726481	271	186	32F
0005434726410	271	187	32K
0005433233974	271	188	32J
0005433181140	271	189	32H
0005433766617	271	190	33B
0005433234361	271	191	33A
0005434726484	271	192	33C
0005432277917	271	193	33F
0005432277919	271	194	33E
0005433233988	271	195	33H
0005434726503	271	196	33G
0005434551667	271	197	33K
0005434551687	271	198	34B
0005433234245	271	199	34A
0005432277916	271	200	34E
0005433234204	271	201	34D
0005434726444	271	202	34G
0005433180992	271	203	34F
0005433234178	271	204	34K
0005434551674	271	205	34H
0005434726458	271	206	35A
0005433234317	271	207	35D
0005434726514	271	208	35C
0005434302494	271	209	35F
0005434551706	271	210	35E
0005434726509	271	211	35J
0005434726524	271	212	35H
0005433234331	271	213	35G
0005433181141	271	214	36A
0005433766638	271	215	35K
0005435142695	271	216	36B
0005434726518	271	217	36E
0005434551662	271	218	36D
0005434726491	271	219	36G
0005434551688	271	220	36F
0005435142692	271	221	36K
0005434726494	271	222	36J
0005433234315	271	223	36H
0005433234329	271	224	37C
0005434726466	271	225	37B
0005433234246	271	226	37A
0005433766635	271	227	37D
0005434726422	271	228	37F
0005434551696	271	229	37J
0005433234409	271	230	37H
0005433234213	271	231	37G
0005433126820	271	232	38A
0005434726489	271	233	37K
0005435142693	271	234	38C
0005433289841	271	235	38B
0005434726453	271	236	38K
0005434551682	271	237	38J
0005433131713	271	238	38H
0005433289838	271	239	39B
0005434726531	271	240	39A
0005432277924	271	241	39D
0005434726478	271	242	39C
0005434726412	271	243	39F
0005434726464	271	244	39E
0005434726416	271	245	39H
0005434726437	271	246	39J
0005434726520	271	247	40B
0005433113534	271	248	40A
0005434726523	271	249	40E
0005434551692	271	250	40D
0005434726415	271	251	40G
0005433234322	271	252	40H
0005433180993	271	253	41A
0005434551679	271	254	40K
0005434551680	271	255	41D
0005433234217	271	256	41C
0005434726463	271	257	41F
0005434551668	271	258	41E
0005433234298	271	259	41H
0005434726448	271	260	41G
0005434726455	271	261	41K
0005433234197	271	262	41J
0005434726508	271	263	42C
0005434726454	271	264	42B
0005434726519	271	265	42A
0005434551707	271	266	42D
0005433233878	271	267	42F
0005433234299	271	268	42J
0005434551675	271	269	42H
0005434302493	271	270	43B
0005433181090	271	271	43A
0005433234055	271	272	43D
0005434726502	271	273	43F
0005434551671	271	274	43E
0005433234008	271	275	43H
0005433181010	271	276	43G
0005434726474	271	277	43J
0005434726462	271	278	44C
0005433234080	271	279	44B
0005434551663	271	280	44E
0005434726430	271	281	44D
0005434551702	271	282	44F
0005434551683	271	283	44K
0005433234067	271	284	44J
0005434726445	271	285	44H
0005434551664	271	286	45B
0005434726431	271	287	45D
0005433234323	271	288	45F
0005434726496	271	289	45E
0005434726498	271	290	45H
0005434726492	271	291	46A
0005434726469	271	292	46B
0005433126821	271	293	46E
0005434551669	271	294	46D
0005435142682	271	295	46G
0005434726420	271	296	46F
0005433234096	271	297	46K
0005434551691	271	298	46J
0005434726504	271	299	46H
0005434726501	271	300	47C
0005433234166	271	301	47A
0005433234220	271	302	47E
0005434551703	271	303	47G
0005433234273	271	304	47K
0005432277918	271	305	47H
0005434551705	271	306	48A
0005434726447	271	307	48F
0005433181162	271	308	48E
0005434726497	271	309	48H
0005434726487	271	310	48G
0005434551698	271	311	49A
0005434726499	271	312	48K
0005434726461	271	313	49C
0005433181180	271	314	49G
0005434726429	271	315	49F
0005433234244	271	316	49E
0005435142686	271	317	49K
0005433181113	271	318	49H
0005433126815	271	319	50C
0005433234211	271	320	50E
0005434551661	271	321	50D
0005434726505	271	322	50G
0005434031974	271	323	51D
0005434726465	271	324	50H
0005434551659	271	325	51E
0005434726482	271	326	51G
0005433181302	9818	1	1C
0005434725478	9818	2	1A
0005433234746	9818	3	1G
0005434725641	9818	4	1D
0005433129315	9818	5	1H
0005433289903	9818	6	2C
0005434725371	9818	7	2H
0005434725008	9818	8	3A
0005434551110	9818	9	2K
0005433234753	9818	10	3D
0005433126884	9818	11	3C
0005433234738	9818	12	3G
0005434725144	9818	13	4C
0005434724860	9818	14	4A
0005433181303	9818	15	3K
0005433234705	9818	16	4G
0005434725722	9818	17	4D
0005434725727	9818	18	4K
0005433181298	9818	19	4H
0005434550949	9818	20	5D
0005434726030	9818	21	5A
0005434551293	9818	22	5H
0005434551029	9818	23	5G
0005433126881	9818	24	11A
0005433181309	9818	25	5K
0005434551111	9818	26	11D
0005434725451	9818	27	11C
0005434551024	9818	28	11F
0005434725212	9818	29	11E
0005434725092	9818	30	11H
0005434735661	9818	31	11G
0005434724961	9818	32	12C
0005434725046	9818	33	12A
0005434550948	9818	34	12E
0005434725343	9818	35	12D
0005433234752	9818	36	12G
0005433234720	9818	37	13A
0005434551288	9818	38	12K
0005434725111	9818	39	12H
0005433234692	9818	40	13D
0005434550902	9818	41	13C
0005434725275	9818	42	13F
0005434724900	9818	43	13E
0005433234723	9818	44	13K
0005433234715	9818	45	13H
0005433234696	9818	46	14E
0005434550737	9818	47	14D
0005432199308	9818	48	14C
0005434032063	9818	49	14F
0005434725642	9818	50	14K
0005434725449	9818	51	14H
0005434725239	9818	52	15C
0005433181312	9818	53	15A
0005434725062	9818	54	15E
0005434724861	9818	55	15D
0005433181305	9818	56	15H
0005434551168	9818	57	15G
0005434551057	9818	58	15F
0005433129312	9818	59	16A
0005435142585	9818	60	15K
0005434725462	9818	61	16D
0005434725521	9818	62	16C
0005434551242	9818	63	16F
0005433766673	9818	64	16E
0005435142562	9818	65	16H
0005432199305	9818	66	16G
0005433181314	9818	67	17C
0005433234730	9818	68	16K
0005434725297	9818	69	17E
0005434725294	9818	70	17D
0005434725671	9818	71	17G
0005434725491	9818	72	18A
0005433234749	9818	73	17K
0005433234690	9818	74	18D
0005434551473	9818	75	18G
0005435142582	9818	76	18F
0005433234722	9818	77	18J
0005434725699	9818	78	18H
0005434725214	9818	79	19B
0005434725736	9818	80	19A
0005434302440	9818	81	19C
0005433129314	9818	82	19F
0005435142584	9818	83	19E
0005434551055	9818	84	19H
0005434725450	9818	85	20A
0005433289907	9818	86	19K
0005434725696	9818	87	19J
0005434725267	9818	88	20C
0005434550890	9818	89	20B
0005434725508	9818	90	20E
0005433234701	9818	91	20D
0005434725009	9818	92	20H
0005433181313	9818	93	20G
0005434551056	9818	94	20F
0005434551300	9818	95	20J
0005434725149	9818	96	21A
0005433181296	9818	97	20K
0005433234727	9818	98	21D
0005434551186	9818	99	21C
0005434725723	9818	100	21G
0005434032061	9818	101	21F
0005434725254	9818	102	21E
0005433289904	9818	103	21J
0005434725433	9818	104	21H
0005433181318	9818	105	22A
0005434735670	9818	106	22C
0005434551243	9818	107	22B
0005434725490	9818	108	22E
0005433234736	9818	109	22D
0005434725506	9818	110	22H
0005434725374	9818	111	22G
0005433234694	9818	112	22F
0005434725793	9818	113	22J
0005433181304	9818	114	23B
0005433181315	9818	115	23A
0005434725674	9818	116	22K
0005434551120	9818	117	23D
0005433234729	9818	118	23G
0005435142517	9818	119	23F
0005434725735	9818	120	23J
0005434725193	9818	121	23H
0005434724928	9818	122	24D
0005434725768	9818	123	23K
0005434725694	9818	124	24F
0005434551335	9818	125	24E
0005434551187	9818	126	24G
0005434725887	9818	127	25C
0005433181297	9818	128	25B
0005434724974	9818	129	25F
0005434725794	9818	130	25D
0005433234702	9818	131	25H
0005434725673	9818	132	25G
0005433234735	9818	133	26A
0005434551317	9818	134	25K
0005433234731	9818	135	25J
0005433126882	9818	136	26B
0005433234706	9818	137	26E
0005433113554	9818	138	26D
0005434725541	9818	139	26C
0005433126883	9818	140	26G
0005434725767	9818	141	26F
0005433181307	9818	142	26J
0005432199306	9818	143	26H
0005434725571	9818	144	26K
0005433766671	9818	145	27C
0005434725430	9818	146	27E
0005433234710	9818	147	27H
0005433234718	9818	148	27G
0005434725453	9818	149	27K
0005434725414	9818	150	27J
0005434551030	9818	151	28B
0005434725061	9818	152	28E
0005433766670	9818	153	28D
0005435142534	9818	154	28G
0005435142535	9818	155	28F
0005433234709	9818	156	28K
0005434731171	9818	157	28J
0005434725807	9818	158	28H
0005434551261	9818	159	29B
0005434725652	9818	160	29A
0005433289910	9818	161	29D
0005433234742	9818	162	29C
0005434551069	9818	163	29F
0005434550969	9818	164	29E
0005434032062	9818	165	29J
0005434725250	9818	166	29H
0005434725604	9818	167	29G
0005433234700	9818	168	29K
0005434550970	9818	169	30C
0005434725535	9818	170	30B
0005434725317	9818	171	30A
0005434551008	9818	172	30E
0005434725110	9818	173	30D
0005434725329	9818	174	30F
0005434551231	9818	175	30K
0005433289906	9818	176	30J
0005434735680	9818	177	31B
0005434725520	9818	178	31E
0005434725798	9818	179	31G
0005434551264	9818	180	32A
0005433234724	9818	181	32C
0005434725454	9818	182	32B
0005433234737	9818	183	32E
0005434725176	9818	184	32D
0005434551185	9818	185	32G
0005434724935	9818	186	32F
0005433234704	9818	187	32K
0005434724765	9818	188	32J
0005434551169	9818	189	32H
0005433181300	9818	190	33A
0005434551265	9818	191	33D
0005433181308	9818	192	33C
0005434032064	9818	193	33B
0005433766672	9818	194	33F
0005434551393	9818	195	33E
0005434731168	9818	196	33H
0005434731167	9818	197	33G
0005433234743	9818	198	34A
0005434725507	9818	199	33K
0005433234740	9818	200	33J
0005435142558	9818	201	34C
0005434725315	9818	202	34E
0005434735662	9818	203	34D
0005433234712	9818	204	34G
0005434551065	9818	205	34F
0005434725301	9818	206	34J
0005433234750	9818	207	35A
0005435142515	9818	208	35D
0005434302439	9818	209	35C
0005434551046	9818	210	35B
0005433234716	9818	211	35G
0005434725213	9818	212	35F
0005434725064	9818	213	36A
0005434725523	9818	214	35K
0005434725224	9818	215	35J
0005434725262	9818	216	36C
0005432199303	9818	217	36D
0005433181301	9818	218	36G
0005434725581	9818	219	36F
0005433234713	9818	220	36K
0005433234703	9818	221	37A
0005433181317	9818	222	37C
0005433234697	9818	223	37G
0005434725192	9818	224	37F
0005434725435	9818	225	37E
0005433234695	9818	226	37J
0005434551031	9818	227	37H
0005434550905	9818	228	38A
0005434725461	9818	229	37K
0005433181310	9818	230	38B
0005434725888	9818	231	38J
0005433234734	9818	232	38H
0005433234725	9818	233	39A
0005433234739	9818	234	38K
0005434725593	9818	235	39C
0005434551266	9818	236	39F
0005434725542	9818	237	39E
0005434725719	9818	238	39H
0005434551101	9818	239	39G
0005434725391	9818	240	40A
0005433234748	9818	241	39K
0005434551121	9818	242	39J
0005433234691	9818	243	40B
0005434725065	9818	244	40E
0005432199304	9818	245	40D
0005432199302	9818	246	40H
0005434725247	9818	247	40G
0005434724983	9818	248	40J
0005433181306	9818	249	41A
0005434725573	9818	250	40K
0005433234721	9818	251	41D
0005434725373	9818	252	41C
0005434551047	9818	253	41B
0005433234733	9818	254	41G
0005434725653	9818	255	41F
0005433126880	9818	256	41E
0005434551336	9818	257	41H
0005434725480	9818	258	42A
0005433289908	9818	259	41K
0005433234711	9818	260	41J
0005434032065	9818	261	42C
0005434550867	9818	262	42B
0005433234707	9818	263	42E
0005434551188	9818	264	42G
0005434725108	9818	265	42F
0005434725274	9818	266	42J
0005434725091	9818	267	43B
0005434725118	9818	268	42K
0005434725266	9818	269	43C
0005433129311	9818	270	43F
0005434551334	9818	271	43E
0005434725135	9818	272	43H
0005433234732	9818	273	43G
0005434725330	9818	274	44A
0005433129313	9818	275	43J
0005433234754	9818	276	44C
0005434725225	9818	277	44B
0005433234747	9818	278	44E
0005433181316	9818	279	44D
0005434551429	9818	280	44G
0005433234728	9818	281	44F
0005433289905	9818	282	44J
0005434725892	9818	283	44H
0005434731172	9818	284	45B
0005434725637	9818	285	45A
0005434725638	9818	286	44K
0005434551119	9818	287	45F
0005433234693	9818	288	45E
0005435142561	9818	289	45G
0005433234741	9818	290	45K
0005433234719	9818	291	45J
0005433234751	9818	292	46B
0005434725123	9818	293	46A
0005434551017	9818	294	46E
0005434724962	9818	295	46D
0005434725485	9818	296	46G
0005433234745	9818	297	46F
0005433234698	9818	298	46J
0005434725479	9818	299	46H
0005433181311	9818	300	47C
0005435142516	9818	301	46K
0005433289902	9818	302	47E
0005433234726	9818	303	47D
0005434735669	9818	304	47G
0005433181319	9818	305	47H
0005434725724	9818	306	48E
0005434725300	9818	307	48D
0005433234708	9818	308	48H
0005434725334	9818	309	48G
0005434731160	9818	310	48F
0005433289909	9818	311	49A
0005434725586	9818	312	48K
0005434725431	9818	313	49E
0005434551292	9818	314	49D
0005433234744	9818	315	49C
0005433234717	9818	316	49F
0005434551241	9818	317	49K
0005434551028	9818	318	49H
0005434551316	9818	319	49G
0005434725316	9818	320	50C
0005433234699	9818	321	50A
0005432199307	9818	322	50E
0005434725598	9818	323	50G
0005434724925	9818	324	50F
0005434725432	9818	325	50K
0005433181299	9818	326	51F
0005433234714	9818	327	51E
0005434724892	9818	328	51G
0005432529108	7748	1	1D
0005432529072	7748	2	1C
0005432533315	7748	3	1A
0005435213363	7748	4	2A
0005435213739	7748	5	1K
0005435213276	7748	6	1H
0005432529103	7748	7	2D
0005435213651	7748	8	2C
0005432069775	7748	9	2G
0005432529051	7748	10	3A
0005435213870	7748	11	2K
0005432529106	7748	12	3D
0005434068153	7748	13	3C
0005435213657	7748	14	3K
0005432529005	7748	15	3H
0005434068165	7748	16	3G
0005434068131	7748	17	4C
0005434068167	7748	18	4A
0005432529067	7748	19	4G
0005432529104	7748	20	4D
0005432528994	7748	21	4K
0005434068117	7748	22	5D
0005434068160	7748	23	5C
0005434068112	7748	24	5H
0005432528999	7748	25	5G
0005432529118	7748	26	11A
0005434068155	7748	27	5K
0005432529063	7748	28	11D
0005432529032	7748	29	11C
0005432069779	7748	30	11G
0005434068140	7748	31	11E
0005432529041	7748	32	11K
0005434068137	7748	33	11H
0005432069772	7748	34	12C
0005432529029	7748	35	12A
0005432069781	7748	36	12E
0005432529115	7748	37	12D
0005432529052	7748	38	12G
0005434068182	7748	39	12F
0005432529037	7748	40	12K
0005432150261	7748	41	13C
0005432529112	7748	42	13A
0005435213489	7748	43	13F
0005435213388	7748	44	13D
0005435213447	7748	45	13H
0005435213649	7748	46	14A
0005434068169	7748	47	14E
0005432069774	7748	48	14D
0005432529074	7748	49	14C
0005434068130	7748	50	14G
0005435213339	7748	51	14F
0005432529070	7748	52	14K
0005432529113	7748	53	14H
0005432428955	7748	54	15C
0005432533316	7748	55	15A
0005435213476	7748	56	15E
0005432529028	7748	57	15K
0005432533314	7748	58	16D
0005435213572	7748	59	16C
0005432529100	7748	60	16A
0005432069776	7748	61	16F
0005432529062	7748	62	16E
0005434068173	7748	63	16H
0005435725579	7748	64	16G
0005432529061	7748	65	17C
0005435213477	7748	66	17A
0005434068157	7748	67	16K
0005432529095	7748	68	17E
0005432150255	7748	69	17D
0005432069771	7748	70	17G
0005435213335	7748	71	17F
0005435725581	7748	72	18A
0005432529059	7748	73	17K
0005432529057	7748	74	17H
0005434068150	7748	75	18B
0005432069777	7748	76	18E
0005435213558	7748	77	18C
0005432529043	7748	78	18G
0005435213672	7748	79	18F
0005435213647	7748	80	18K
0005435213286	7748	81	18J
0005432428957	7748	82	18H
0005432529034	7748	83	19B
0005435213480	7748	84	19A
0005434068149	7748	85	19C
0005434068146	7748	86	19F
0005434068143	7748	87	19E
0005432529099	7748	88	19K
0005432529003	7748	89	19J
0005432529033	7748	90	20C
0005432529015	7748	91	20B
0005432529024	7748	92	20E
0005432069778	7748	93	20G
0005434068180	7748	94	20F
0005434068128	7748	95	20J
0005435725569	7748	96	20H
0005434068177	7748	97	21B
0005435213856	7748	98	20K
0005432529086	7748	99	21D
0005434068158	7748	100	21C
0005432529111	7748	101	21G
0005432535872	7748	102	21F
0005432529045	7748	103	21H
0005435213542	7748	104	21K
0005434068148	7748	105	21J
0005434068136	7748	106	22C
0005432529035	7748	107	22B
0005432535874	7748	108	22E
0005435213445	7748	109	22D
0005432529069	7748	110	22F
0005435213418	7748	111	22K
0005434068175	7748	112	22J
0005432529004	7748	113	22H
0005435213612	7748	114	23C
0005432150262	7748	115	23B
0005432529109	7748	116	23A
0005432529027	7748	117	23D
0005432529083	7748	118	23G
0005432150257	7748	119	23F
0005434068126	7748	120	23E
0005432069773	7748	121	23H
0005432529119	7748	122	23K
0005435213636	7748	123	24F
0005432529008	7748	124	24E
0005435213602	7748	125	25B
0005432528990	7748	126	25A
0005434068133	7748	127	25D
0005434068174	7748	128	25C
0005432529105	7748	129	25E
0005435213397	7748	130	25G
0005434068176	7748	131	25K
0005432529036	7748	132	26B
0005435725580	7748	133	26A
0005432535875	7748	134	26D
0005434068111	7748	135	26C
0005435213570	7748	136	26G
0005432537074	7748	137	26F
0005434068138	7748	138	26K
0005435630961	7748	139	26H
0005435213417	7748	140	27A
0005432529040	7748	141	27B
0005432529096	7748	142	27F
0005432529022	7748	143	27D
0005432529011	7748	144	27H
0005432529101	7748	145	27G
0005432529006	7748	146	28A
0005434068116	7748	147	27J
0005435630960	7748	148	28B
0005435213511	7748	149	28E
0005432529010	7748	150	28D
0005434068124	7748	151	28H
0005432528995	7748	152	28G
0005434068127	7748	153	28F
0005432529023	7748	154	28J
0005434068170	7748	155	28K
0005432535873	7748	156	29D
0005432529060	7748	157	29C
0005435213868	7748	158	29B
0005434068179	7748	159	29F
0005432529087	7748	160	29E
0005432069767	7748	161	29K
0005432069782	7748	162	29J
0005432529050	7748	163	30E
0005432069768	7748	164	30D
0005432529044	7748	165	30C
0005434068134	7748	166	30G
0005432529121	7748	167	30J
0005434068123	7748	168	30H
0005432529110	7748	169	31B
0005435213463	7748	170	31C
0005435213493	7748	171	31F
0005432529094	7748	172	31E
0005432537075	7748	173	31J
0005432529079	7748	174	31H
0005432529047	7748	175	31K
0005435213573	7748	176	32C
0005432529056	7748	177	32B
0005432529117	7748	178	32E
0005432529085	7748	179	32D
0005435213429	7748	180	32F
0005432528998	7748	181	32J
0005432529107	7748	182	32H
0005435213488	7748	183	33B
0005432529102	7748	184	32K
0005435213336	7748	185	33D
0005435213318	7748	186	33F
0005434068161	7748	187	33E
0005435213341	7748	188	33J
0005432529025	7748	189	33H
0005435213487	7748	190	33G
0005434068120	7748	191	34A
0005432529089	7748	192	33K
0005434068110	7748	193	34B
0005432529091	7748	194	34E
0005433656671	7748	195	34D
0005435725586	7748	196	34C
0005434068154	7748	197	34H
0005435213117	7748	198	34G
0005432529001	7748	199	34F
0005435213446	7748	200	35B
0005434068118	7748	201	35A
0005432529007	7748	202	34K
0005432529098	7748	203	35D
0005435213398	7748	204	35C
0005432528989	7748	205	35E
0005432529046	7748	206	35H
0005435213583	7748	207	35G
0005435213857	7748	208	36E
0005435213449	7748	209	36D
0005435213585	7748	210	36H
0005434068139	7748	211	36G
0005432428956	7748	212	36F
0005432529081	7748	213	36K
0005432529039	7748	214	36J
0005434068141	7748	215	37B
0005432529068	7748	216	37C
0005432529073	7748	217	37F
0005434068142	7748	218	37E
0005434068144	7748	219	37J
0005434068125	7748	220	38A
0005432529030	7748	221	37K
0005435213534	7748	222	38H
0005432529092	7748	223	38C
0005432529031	7748	224	38B
0005432529049	7748	225	38K
0005432529054	7748	226	38J
0005432529038	7748	227	39B
0005432528991	7748	228	39A
0005432069769	7748	229	39C
0005432529058	7748	230	39E
0005434068163	7748	231	39G
0005432529090	7748	232	39K
0005432529014	7748	233	39J
0005435213620	7748	234	40C
0005434068152	7748	235	40B
0005432529055	7748	236	40F
0005435213571	7748	237	40E
0005432150263	7748	238	40D
0005435213497	7748	239	40K
0005432150256	7748	240	40J
0005432529114	7748	241	40H
0005432529021	7748	242	41B
0005435213374	7748	243	41A
0005434068159	7748	244	41C
0005432150259	7748	245	41F
0005434068129	7748	246	41E
0005432529000	7748	247	41J
0005434068122	7748	248	41H
0005434068121	7748	249	41G
0005432529120	7748	250	42A
0005432150260	7748	251	41K
0005432528997	7748	252	42C
0005434068151	7748	253	42B
0005432529076	7748	254	42D
0005432529020	7748	255	42G
0005432529071	7748	256	42J
0005432528992	7748	257	42H
0005432529016	7748	258	43B
0005432528988	7748	259	43A
0005434068172	7748	260	42K
0005434068132	7748	261	43D
0005432529088	7748	262	43C
0005434068113	7748	263	43F
0005434068115	7748	264	43H
0005435213496	7748	265	43G
0005432529116	7748	266	44A
0005435213411	7748	267	43K
0005435213586	7748	268	43J
0005434068168	7748	269	44B
0005432529065	7748	270	44D
0005432529082	7748	271	44C
0005434068147	7748	272	44G
0005432529042	7748	273	44F
0005432529048	7748	274	44J
0005432528996	7748	275	45B
0005432529075	7748	276	45A
0005434068114	7748	277	45C
0005432529078	7748	278	45F
0005432529002	7748	279	45E
0005434068119	7748	280	45H
0005432529093	7748	281	45G
0005432428958	7748	282	45K
0005435213559	7748	283	45J
0005435213648	7748	284	46C
0005434068178	7748	285	46A
0005434068166	7748	286	46E
0005435212955	7748	287	46D
0005435213584	7748	288	46G
0005432069770	7748	289	46F
0005435213541	7748	290	46H
0005432529017	7748	291	47A
0005432529026	7748	292	47E
0005434068162	7748	293	47D
0005432529084	7748	294	47G
0005435213464	7748	295	47F
0005432529019	7748	296	47K
0005432529018	7748	297	48D
0005435213234	7748	298	48A
0005432529053	7748	299	48F
0005435213656	7748	300	48E
0005432529080	7748	301	48H
0005432529077	7748	302	48G
0005434068145	7748	303	49A
0005435213869	7748	304	48K
0005434068171	7748	305	49E
0005432529009	7748	306	49D
0005432529013	7748	307	49C
0005434068156	7748	308	49G
0005432069780	7748	309	49F
0005432150258	7748	310	49K
0005432529066	7748	311	50C
0005432529097	7748	312	50A
0005434068135	7748	313	50E
0005432529012	7748	314	50D
0005432528993	7748	315	50H
0005435213682	7748	316	50G
0005435213428	7748	317	50F
0005434068164	7748	318	51D
0005432529064	7748	319	51F
0005435213615	7748	320	51E
0005434068181	7748	321	51G
0005434344520	5321	1	1C
0005435614581	5321	2	1A
0005435425076	5321	3	1G
0005434244888	5321	4	1D
0005432841010	5321	5	2A
0005434344522	5321	6	1K
0005435424845	5321	7	2C
0005435614606	5321	8	2D
0005435614590	5321	9	2K
0005432133341	5321	10	3K
0005435614559	5321	11	3H
0005435424964	5321	12	3G
0005435614532	5321	13	4C
0005432363409	5321	14	4A
0005435302220	5321	15	4G
0005434344501	5321	16	5D
0005435424962	5321	17	5A
0005435424853	5321	18	5H
0005435424877	5321	19	5G
0005435614616	5321	20	11A
0005434656559	5321	21	5K
0005435614571	5321	22	11D
0005434573476	5321	23	11C
0005432133331	5321	24	11F
0005435425021	5321	25	11E
0005432133339	5321	26	11K
0005434344518	5321	27	11H
0005435614588	5321	28	11G
0005435319620	5321	29	12C
0005435614531	5321	30	12A
0005435614570	5321	31	12E
0005434344528	5321	32	12D
0005432841008	5321	33	12G
0005434244911	5321	34	12F
0005435614533	5321	35	12K
0005435319619	5321	36	12H
0005434573469	5321	37	13D
0005434244957	5321	38	13C
0005434573470	5321	39	13A
0005435614535	5321	40	13H
0005435424926	5321	41	13G
0005435380298	5321	42	14A
0005434244921	5321	43	13K
0005435424860	5321	44	14D
0005435424680	5321	45	14C
0005435614622	5321	46	14F
0005435614560	5321	47	14K
0005434344513	5321	48	14H
0005435097285	5321	49	14G
0005435424835	5321	50	15C
0005435614596	5321	51	15A
0005435424694	5321	52	15H
0005434573474	5321	53	15G
0005435302214	5321	54	15F
0005434244850	5321	55	15K
0005435614575	5321	56	16C
0005435614541	5321	57	16F
0005435614595	5321	58	16E
0005435424830	5321	59	16K
0005434344526	5321	60	16H
0005434573473	5321	61	17A
0005434244880	5321	62	17E
0005435424966	5321	63	17D
0005435614573	5321	64	17G
0005435614542	5321	65	17F
0005434344516	5321	66	17K
0005435424891	5321	67	17H
0005435614547	5321	68	18B
0005432133336	5321	69	18A
0005435424844	5321	70	18E
0005432047581	5321	71	18D
0005432047583	5321	72	18G
0005434244877	5321	73	18F
0005434573467	5321	74	18H
0005435614566	5321	75	19B
0005432133334	5321	76	19C
0005432047582	5321	77	19E
0005435424611	5321	78	19D
0005435614613	5321	79	19H
0005434344514	5321	80	19G
0005435424958	5321	81	20A
0005433719145	5321	82	19K
0005434244912	5321	83	19J
0005434244887	5321	84	20B
0005435614580	5321	85	20E
0005435097282	5321	86	20D
0005435319587	5321	87	20H
0005435614565	5321	88	20G
0005434244831	5321	89	20F
0005434344524	5321	90	20J
0005435614552	5321	91	21B
0005435319617	5321	92	20K
0005435490259	5321	93	21C
0005435425042	5321	94	21F
0005435424641	5321	95	21E
0005435614608	5321	96	21H
0005435097281	5321	97	21G
0005434344508	5321	98	21K
0005435614554	5321	99	21J
0005432133332	5321	100	22B
0005434573468	5321	101	22E
0005435424925	5321	102	22D
0005435425010	5321	103	22G
0005434344519	5321	104	22F
0005435614603	5321	105	22K
0005435424892	5321	106	22J
0005435425075	5321	107	22H
0005434244998	5321	108	23B
0005434344507	5321	109	23A
0005435614539	5321	110	23D
0005435424911	5321	111	23C
0005434656550	5321	112	23F
0005435302173	5321	113	23H
0005435614589	5321	114	23G
0005432133329	5321	115	24D
0005432133330	5321	116	23J
0005435555387	5321	117	24F
0005434656551	5321	118	24E
0005434344515	5321	119	24G
0005435424960	5321	120	25D
0005435614562	5321	121	25C
0005435380305	5321	122	25B
0005435425046	5321	123	25F
0005435614567	5321	124	25E
0005435097289	5321	125	25H
0005435614540	5321	126	25G
0005435425036	5321	127	26A
0005435424795	5321	128	25K
0005435614601	5321	129	25J
0005434573462	5321	130	26C
0005435614563	5321	131	26E
0005435614537	5321	132	26G
0005435614605	5321	133	26F
0005435614548	5321	134	26K
0005435614550	5321	135	26H
0005435614568	5321	136	27B
0005435425101	5321	137	27D
0005435424908	5321	138	27F
0005435614556	5321	139	27E
0005435302196	5321	140	27J
0005435424587	5321	141	27H
0005434344510	5321	142	27G
0005435424981	5321	143	27K
0005435614593	5321	144	28B
0005435097283	5321	145	28E
0005435614577	5321	146	28D
0005435614583	5321	147	28C
0005435614549	5321	148	28G
0005435614572	5321	149	28F
0005434344503	5321	150	28J
0005435614614	5321	151	29B
0005435302210	5321	152	29A
0005435614551	5321	153	29D
0005434344529	5321	154	29F
0005435614620	5321	155	29E
0005435424913	5321	156	29H
0005434244959	5321	157	29G
0005432133342	5321	158	30A
0005432363399	5321	159	29K
0005434573471	5321	160	29J
0005434573466	5321	161	30C
0005434344512	5321	162	30B
0005432047580	5321	163	30G
0005432363415	5321	164	30F
0005435424912	5321	165	30E
0005435305013	5321	166	30J
0005432133335	5321	167	30H
0005435302215	5321	168	31A
0005434244864	5321	169	31D
0005435424909	5321	170	31C
0005435614604	5321	171	31B
0005434344521	5321	172	31F
0005435424841	5321	173	31G
0005434244970	5321	174	32A
0005435614569	5321	175	31K
0005435555386	5321	176	31J
0005435424959	5321	177	32C
0005435319588	5321	178	32B
0005435425069	5321	179	32G
0005432363398	5321	180	32F
0005435302195	5321	181	32J
0005434244842	5321	182	32H
0005435614597	5321	183	33A
0005435614624	5321	184	32K
0005435614599	5321	185	33C
0005435614576	5321	186	33G
0005432133338	5321	187	33F
0005434344506	5321	188	33E
0005435614607	5321	189	33H
0005435302194	5321	190	33K
0005435424696	5321	191	34C
0005435614592	5321	192	34B
0005435097287	5321	193	34E
0005434344509	5321	194	34D
0005434344527	5321	195	34H
0005435614617	5321	196	34G
0005435319575	5321	197	34F
0005435097280	5321	198	34J
0005434244958	5321	199	34K
0005435425022	5321	200	35D
0005434573475	5321	201	35C
0005435424766	5321	202	35E
0005435425248	5321	203	35H
0005435424836	5321	204	36A
0005432047579	5321	205	35K
0005435614598	5321	206	36C
0005435425016	5321	207	36E
0005435614623	5321	208	36D
0005435614574	5321	209	36G
0005435424840	5321	210	36F
0005435614585	5321	211	36K
0005435425017	5321	212	36J
0005435424733	5321	213	37B
0005435319616	5321	214	37A
0005434244982	5321	215	37D
0005435490258	5321	216	37C
0005435614564	5321	217	37F
0005435614600	5321	218	37H
0005435424749	5321	219	37K
0005435425172	5321	220	37J
0005435424843	5321	221	38H
0005434244858	5321	222	38C
0005435614618	5321	223	38B
0005435424852	5321	224	38A
0005435614610	5321	225	38J
0005435614555	5321	226	38K
0005434573465	5321	227	39C
0005435319569	5321	228	39B
0005435319556	5321	229	39F
0005435614621	5321	230	39E
0005435614530	5321	231	39J
0005435614612	5321	232	39H
0005435614538	5321	233	39G
0005435424650	5321	234	40C
0005435380283	5321	235	40E
0005435319583	5321	236	40D
0005435424630	5321	237	40G
0005435614543	5321	238	40J
0005434244859	5321	239	40H
0005435425070	5321	240	41B
0005434244956	5321	241	41A
0005435424967	5321	242	41D
0005432841007	5321	243	41C
0005435319563	5321	244	41F
0005435614584	5321	245	41H
0005435380284	5321	246	41G
0005435614536	5321	247	42A
0005434344531	5321	248	41K
0005434244920	5321	249	42B
0005435614582	5321	250	42E
0005434244818	5321	251	42H
0005435097284	5321	252	42G
0005434344504	5321	253	42K
0005435614611	5321	254	42J
0005435424319	5321	255	43A
0005435425011	5321	256	43C
0005435425087	5321	257	43E
0005434344525	5321	258	43D
0005435425249	5321	259	43H
0005434573463	5321	260	43G
0005435614586	5321	261	44A
0005434344530	5321	262	43K
0005435424878	5321	263	43J
0005435424769	5321	264	44B
0005435424318	5321	265	44E
0005435614619	5321	266	44D
0005434573464	5321	267	44H
0005434244889	5321	268	44G
0005435424802	5321	269	44F
0005435614587	5321	270	44K
0005435425002	5321	271	44J
0005434244914	5321	272	45B
0005435614602	5321	273	45A
0005434344532	5321	274	45D
0005435097286	5321	275	45C
0005432133333	5321	276	45F
0005435614561	5321	277	45E
0005435424910	5321	278	45H
0005433719129	5321	279	45G
0005435380306	5321	280	45K
0005434244832	5321	281	46C
0005434344502	5321	282	46A
0005435614615	5321	283	46D
0005435614557	5321	284	46G
0005435614558	5321	285	46F
0005434344523	5321	286	46J
0005432133337	5321	287	46H
0005435614609	5321	288	47A
0005435319570	5321	289	46K
0005435614534	5321	290	47E
0005434344505	5321	291	47D
0005435614594	5321	292	47F
0005435097288	5321	293	47K
0005432133340	5321	294	47H
0005435424684	5321	295	48D
0005435614578	5321	296	48A
0005434244971	5321	297	48G
0005434573472	5321	298	49C
0005435425019	5321	299	49A
0005434344500	5321	300	48K
0005435555385	5321	301	49D
0005435614591	5321	302	49E
0005435614579	5321	303	49H
0005434244997	5321	304	49G
0005432133328	5321	305	50C
0005435614553	5321	306	50A
0005434344511	5321	307	50D
0005435424989	5321	308	50G
0005434344517	5321	309	50F
0005435614546	5321	310	50K
0005435319584	5321	311	50H
0005434344499	5321	312	51F
0005435614545	5321	313	51E
0005432841009	5321	314	51D
0005435614544	5321	315	51G
0005435425365	10896	1	1C
0005435613669	10896	2	1A
0005435425405	10896	3	1H
0005434344120	10896	4	1G
0005435613763	10896	5	1D
0005434245234	10896	6	1K
0005435555378	10896	7	2C
0005435425391	10896	8	2A
0005434245224	10896	9	2G
0005435613725	10896	10	2D
0005434573260	10896	11	3A
0005434344087	10896	12	2K
0005432166927	10896	13	3G
0005435614137	10896	14	3C
0005435613868	10896	15	3H
0005432166929	10896	16	4C
0005434344057	10896	17	4A
0005435613658	10896	18	3K
0005434656572	10896	19	4G
0005434245236	10896	20	4D
0005435305027	10896	21	4K
0005435613611	10896	22	4H
0005435613700	10896	23	5A
0005435042872	10896	24	5H
0005434344269	10896	25	11A
0005432165101	10896	26	5K
0005435613554	10896	27	11D
0005434344135	10896	28	11C
0005435425360	10896	29	11E
0005434656574	10896	30	11H
0005432165099	10896	31	11G
0005435614136	10896	32	12C
0005435613638	10896	33	12A
0005435425389	10896	34	11K
0005434245228	10896	35	12E
0005434344184	10896	36	12D
0005435425369	10896	37	12G
0005435425403	10896	38	12F
0005434344085	10896	39	13A
0005435613465	10896	40	12H
0005434573245	10896	41	13D
0005435425363	10896	42	13C
0005435613502	10896	43	13E
0005435613785	10896	44	13H
0005435613460	10896	45	14A
0005435425353	10896	46	13K
0005432165098	10896	47	14D
0005435613992	10896	48	14C
0005434344268	10896	49	14E
0005435425384	10896	50	14K
0005435425367	10896	51	14H
0005435613481	10896	52	14G
0005434344102	10896	53	15D
0005435425351	10896	54	15C
0005434344043	10896	55	15A
0005434343965	10896	56	15F
0005435425346	10896	57	15E
0005435613467	10896	58	15H
0005434245208	10896	59	15G
0005435613814	10896	60	16A
0005434344246	10896	61	16D
0005435613745	10896	62	16F
0005435613704	10896	63	16E
0005435613756	10896	64	16G
0005434245232	10896	65	17C
0005434573243	10896	66	17A
0005434344186	10896	67	17E
0005434245219	10896	68	17G
0005433719171	10896	69	18A
0005434344233	10896	70	17K
0005435613229	10896	71	18B
0005435425355	10896	72	18D
0005435425371	10896	73	18G
0005434344197	10896	74	18J
0005435613606	10896	75	19A
0005435613350	10896	76	19D
0005435613449	10896	77	19C
0005432165106	10896	78	19B
0005435613693	10896	79	19F
0005435304188	10896	80	19J
0005435425387	10896	81	19H
0005435613726	10896	82	19G
0005435425378	10896	83	20A
0005434344066	10896	84	20C
0005435613776	10896	85	20B
0005435613395	10896	86	20E
0005434344137	10896	87	20D
0005434245229	10896	88	20G
0005434344089	10896	89	20F
0005434245211	10896	90	20J
0005435613714	10896	91	20H
0005435613248	10896	92	21B
0005435042873	10896	93	21A
0005435613535	10896	94	20K
0005435425357	10896	95	21D
0005434245233	10896	96	21C
0005434245235	10896	97	21F
0005435613775	10896	98	21J
0005432165102	10896	99	21H
0005435613954	10896	100	22A
0005434344058	10896	101	21K
0005435613344	10896	102	22C
0005434573259	10896	103	22B
0005435613469	10896	104	22F
0005432165104	10896	105	22E
0005435319645	10896	106	22D
0005435490219	10896	107	22H
0005435425380	10896	108	22G
0005432166928	10896	109	22K
0005432165103	10896	110	22J
0005434245212	10896	111	23B
0005435613603	10896	112	23A
0005435491441	10896	113	23D
0005435613397	10896	114	23F
0005435425394	10896	115	23E
0005435425338	10896	116	23J
0005434344074	10896	117	23H
0005435613447	10896	118	23G
0005435425343	10896	119	24D
0005432363444	10896	120	23K
0005435425341	10896	121	24F
0005434573301	10896	122	24E
0005435613671	10896	123	25A
0005433719170	10896	124	24G
0005434245216	10896	125	25D
0005434245222	10896	126	25C
0005435613755	10896	127	25F
0005434245225	10896	128	25E
0005435425344	10896	129	25H
0005435304189	10896	130	26A
0005435425348	10896	131	25K
0005435613813	10896	132	25J
0005435425376	10896	133	26B
0005435425340	10896	134	26E
0005435613470	10896	135	26D
0005434573344	10896	136	26G
0005435319648	10896	137	26F
0005435490218	10896	138	26J
0005435425374	10896	139	27A
0005435613391	10896	140	27D
0005434343964	10896	141	27C
0005435425382	10896	142	27B
0005435304192	10896	143	27E
0005435613627	10896	144	27H
0005434245237	10896	145	27F
0005434245217	10896	146	27K
0005435555377	10896	147	27J
0005434573300	10896	148	28B
0005435613529	10896	149	28A
0005432363442	10896	150	28E
0005435613455	10896	151	28D
0005435613631	10896	152	28G
0005434245230	10896	153	28F
0005435613751	10896	154	28J
0005435425358	10896	155	28H
0005435613157	10896	156	29B
0005435425354	10896	157	29A
0005435319643	10896	158	29D
0005435491440	10896	159	29C
0005435319644	10896	160	29F
0005434656573	10896	161	29E
0005435613448	10896	162	29J
0005435425397	10896	163	29H
0005435613774	10896	164	29G
0005435425393	10896	165	29K
0005435614109	10896	166	30B
0005435613336	10896	167	30E
0005435613521	10896	168	30D
0005435613553	10896	169	30C
0005435042874	10896	170	30G
0005435613936	10896	171	30F
0005435613937	10896	172	30J
0005435425364	10896	173	30H
0005435425404	10896	174	31B
0005434245223	10896	175	31D
0005435490215	10896	176	31C
0005435612940	10896	177	31F
0005434343971	10896	178	31E
0005434573244	10896	179	31J
0005434344112	10896	180	31G
0005435555369	10896	181	32A
0005435613484	10896	182	32E
0005435425347	10896	183	32D
0005435613871	10896	184	32G
0005435425390	10896	185	32F
0005435613491	10896	186	32K
0005435613591	10896	187	32J
0005434344044	10896	188	33A
0005435425342	10896	189	33D
0005434573306	10896	190	33B
0005435425366	10896	191	33E
0005435613626	10896	192	33J
0005435613824	10896	193	33H
0005435425383	10896	194	34B
0005435613555	10896	195	34A
0005435613703	10896	196	34E
0005434573327	10896	197	34D
0005435613713	10896	198	34C
0005435613527	10896	199	34G
0005434245214	10896	200	34H
0005435613598	10896	201	35B
0005432841031	10896	202	35C
0005435613158	10896	203	35F
0005435613717	10896	204	35E
0005434344063	10896	205	35H
0005434344099	10896	206	35K
0005434344132	10896	207	36D
0005435613435	10896	208	36C
0005435490214	10896	209	36B
0005435613764	10896	210	36F
0005434344194	10896	211	36K
0005435613349	10896	212	36J
0005434344113	10896	213	36H
0005435613825	10896	214	37B
0005434245218	10896	215	37A
0005434344076	10896	216	37C
0005435613815	10896	217	37F
0005435425372	10896	218	37E
0005435425350	10896	219	37H
0005435613434	10896	220	37K
0005435613384	10896	221	37J
0005435613386	10896	222	38C
0005434573305	10896	223	38B
0005434245210	10896	224	38K
0005435613590	10896	225	38J
0005435425368	10896	226	38H
0005435613742	10896	227	39B
0005435613853	10896	228	39A
0005435613832	10896	229	39D
0005435613580	10896	230	39C
0005435613582	10896	231	39F
0005434344241	10896	232	39E
0005435613816	10896	233	39H
0005435613869	10896	234	39G
0005435613933	10896	235	40A
0005435425345	10896	236	39K
0005435425361	10896	237	39J
0005435425370	10896	238	40C
0005435613605	10896	239	40B
0005435613823	10896	240	40E
0005435425385	10896	241	40D
0005434344075	10896	242	40F
0005435613153	10896	243	40K
0005435319646	10896	244	41B
0005435319647	10896	245	41A
0005435319649	10896	246	41D
0005434344185	10896	247	41C
0005435425395	10896	248	41H
0005435613495	10896	249	41G
0005435613757	10896	250	41K
0005435425377	10896	251	42C
0005435425398	10896	252	42B
0005435425386	10896	253	42E
0005435491442	10896	254	42D
0005435425352	10896	255	42F
0005435613938	10896	256	42K
0005435425339	10896	257	42J
0005434245221	10896	258	42H
0005435305026	10896	259	43A
0005435613672	10896	260	43D
0005434344240	10896	261	43C
0005435555368	10896	262	43B
0005435425407	10896	263	43F
0005435425379	10896	264	43H
0005435613385	10896	265	43G
0005435614113	10896	266	43K
0005434245213	10896	267	43J
0005435613400	10896	268	44C
0005434245227	10896	269	44B
0005433719168	10896	270	44E
0005434344051	10896	271	44D
0005435425356	10896	272	44G
0005435304191	10896	273	44J
0005435425381	10896	274	44H
0005435425359	10896	275	45A
0005435425388	10896	276	44K
0005435613492	10896	277	45D
0005435613922	10896	278	45C
0005435425399	10896	279	45B
0005435425375	10896	280	45F
0005435425400	10896	281	45H
0005435613528	10896	282	45G
0005435613168	10896	283	45K
0005434344088	10896	284	46C
0005435425349	10896	285	46B
0005435425392	10896	286	46E
0005435304190	10896	287	46H
0005435614112	10896	288	46G
0005435614042	10896	289	46F
0005435425401	10896	290	46K
0005435613490	10896	291	46J
0005435613581	10896	292	47A
0005435613466	10896	293	47E
0005434245220	10896	294	47D
0005432165097	10896	295	47C
0005435425406	10896	296	47G
0005432165105	10896	297	47F
0005434573319	10896	298	47K
0005435613468	10896	299	48C
0005433719169	10896	300	48A
0005434245215	10896	301	48F
0005435613921	10896	302	48E
0005435613673	10896	303	48D
0005435613694	10896	304	48H
0005434573304	10896	305	48G
0005435613179	10896	306	49A
0005434245226	10896	307	48K
0005434245209	10896	308	49D
0005435425396	10896	309	49C
0005435613228	10896	310	49G
0005432165100	10896	311	49F
0005435425362	10896	312	49E
0005435613950	10896	313	49K
0005435425373	10896	314	49H
0005435613414	10896	315	50C
0005432363443	10896	316	50E
0005435425402	10896	317	50D
0005435613518	10896	318	50F
0005435613483	10896	319	51D
0005435612939	10896	320	50H
0005435613670	10896	321	51F
0005434245231	10896	322	51E
0005433805656	3237	1	1C
0005433805653	3237	2	1A
0005432459781	3237	3	1D
0005433634087	3237	4	2A
0005432181900	3237	5	1F
0005432459653	3237	6	2C
0005432459852	3237	7	2F
0005432181905	3237	8	2D
0005433507333	3237	9	3A
0005433507326	3237	10	3D
0005433507335	3237	11	3C
0005432459834	3237	12	3F
0005432460008	3237	13	4A
0005432459853	3237	14	4C
0005432459962	3237	15	4F
0005432459911	3237	16	4D
0005433634098	3237	17	5A
0005433805672	3237	18	5D
0005432459709	3237	19	5F
0005432181910	3237	20	6A
0005433805661	3237	21	6C
0005432459774	3237	22	7A
0005433805650	3237	23	6F
0005433634106	3237	24	7D
0005433805658	3237	25	7C
0005432459640	3237	26	8A
0005432459816	3237	27	7F
0005432181901	3237	28	8C
0005432181904	3237	29	8B
0005433805651	3237	30	8E
0005432181909	3237	31	8F
0005433507329	3237	32	9B
0005433634119	3237	33	9A
0005433805654	3237	34	9C
0005432459732	3237	35	9D
0005433805657	3237	36	9F
0005433805673	3237	37	9E
0005433805678	3237	38	10A
0005433634118	3237	39	10B
0005433805644	3237	40	10D
0005432459863	3237	41	10C
0005433805683	3237	42	10E
0005433805674	3237	43	10F
0005432459708	3237	44	11B
0005432181897	3237	45	11A
0005433805676	3237	46	11C
0005433634103	3237	47	11D
0005432459963	3237	48	11E
0005433634090	3237	49	12A
0005433634097	3237	50	11F
0005432459808	3237	51	12C
0005434143741	3237	52	12B
0005432459615	3237	53	12D
0005432181892	3237	54	12E
0005433805659	3237	55	13A
0005433805666	3237	56	12F
0005432459961	3237	57	13C
0005432181894	3237	58	13B
0005433634104	3237	59	13D
0005433634113	3237	60	13F
0005433507331	3237	61	13E
0005433507325	3237	62	14A
0005432181890	3237	63	14B
0005433805646	3237	64	14D
0005433507337	3237	65	14E
0005433805645	3237	66	14F
0005433634092	3237	67	15B
0005433634116	3237	68	15A
0005433634111	3237	69	15C
0005432459705	3237	70	15D
0005432459614	3237	71	15E
0005432181903	3237	72	16B
0005433805679	3237	73	16A
0005433805671	3237	74	15F
0005433634105	3237	75	16C
0005433634109	3237	76	16D
0005432181908	3237	77	16E
0005432181899	3237	78	16F
0005433805670	3237	79	17A
0005432459641	3237	80	17C
0005432459886	3237	81	17B
0005432181895	3237	82	17D
0005433805668	3237	83	17E
0005432181896	3237	84	18A
0005433507332	3237	85	17F
0005432460005	3237	86	18C
0005433634100	3237	87	18B
0005433507334	3237	88	18D
0005432459764	3237	89	18E
0005433507336	3237	90	18F
0005432181907	3237	91	19C
0005432181902	3237	92	19B
0005433805681	3237	93	19D
0005433634095	3237	94	19E
0005433634088	3237	95	20A
0005433507323	3237	96	20C
0005433634094	3237	97	20B
0005432181891	3237	98	20D
0005432181911	3237	99	20F
0005433634089	3237	100	20E
0005433634101	3237	101	21A
0005433634107	3237	102	21B
0005432181893	3237	103	21D
0005432181912	3237	104	21C
0005432459856	3237	105	21F
0005433805663	3237	106	21E
0005433634114	3237	107	22B
0005433634112	3237	108	22A
0005433805684	3237	109	22C
0005432181906	3237	110	22D
0005432460004	3237	111	22F
0005433634110	3237	112	22E
0005433507339	3237	113	23A
0005432459733	3237	114	23C
0005432459628	3237	115	23B
0005433507328	3237	116	23D
0005433507327	3237	117	23E
0005433805662	3237	118	24A
0005433507340	3237	119	23F
0005433805680	3237	120	24B
0005433507324	3237	121	24D
0005433634102	3237	122	24C
0005432459639	3237	123	24E
0005433634091	3237	124	24F
0005432459765	3237	125	25B
0005433805652	3237	126	25A
0005433634115	3237	127	25C
0005433805665	3237	128	25D
0005433507330	3237	129	25E
0005432459782	3237	130	26A
0005433805675	3237	131	25F
0005434143743	3237	132	26B
0005432459951	3237	133	26D
0005432459906	3237	134	26E
0005432459652	3237	135	26F
0005433634099	3237	136	27A
0005433507322	3237	137	27C
0005432181898	3237	138	27B
0005433805649	3237	139	27E
0005433634093	3237	140	27D
0005432459734	3237	141	27F
0005432459905	3237	142	28A
0005432459656	3237	143	28B
0005433805664	3237	144	28C
0005433507338	3237	145	28E
0005433805655	3237	146	28D
0005433634086	3237	147	28F
0005433805648	3237	148	29A
0005432460007	3237	149	29C
0005432459910	3237	150	29B
0005432459917	3237	151	29D
0005432459833	3237	152	29E
0005433805667	3237	153	30A
0005433805647	3237	154	29F
0005433634108	3237	155	30B
0005434143742	3237	156	30D
0005432459885	3237	157	30C
0005432460006	3237	158	30E
0005433805669	3237	159	30F
0005433805660	3237	160	31B
0005432459826	3237	161	31A
0005433805682	3237	162	31C
0005433634096	3237	163	31E
0005433634117	3237	164	31D
0005433805677	3237	165	31F
0005435885247	3236	1	1A
0005435885494	3236	2	1F
0005435885189	3236	3	3D
0005435885204	3236	4	4A
0005435885206	3236	5	5D
0005435885261	3236	6	6A
0005435885085	3236	7	7C
0005435885103	3236	8	8B
0005435885231	3236	9	8F
0005435885291	3236	10	9E
0005435885408	3236	11	10E
0005435885354	3236	12	10F
0005435885284	3236	13	11A
0005435885378	3236	14	11E
0005435885303	3236	15	12D
0005435885413	3236	16	13B
0005435885188	3236	17	13D
0005435885383	3236	18	13F
0005435885290	3236	19	14D
0005435885397	3236	20	15A
0005435885341	3236	21	15F
0005435885214	3236	22	16F
0005435885052	3236	23	18A
0005435885152	3236	24	18B
0005435885205	3236	25	18D
0005435885285	3236	26	20B
0005435885165	3236	27	20D
0005435885384	3236	28	20E
0005435885125	3236	29	21A
0005435885251	3236	30	21B
0005435885276	3236	31	21D
0005435885252	3236	32	21E
0005435885419	3236	33	22C
0005435885402	3236	34	22F
0005435885396	3236	35	23B
0005435885195	3236	36	23E
0005435885337	3236	37	24C
0005435885385	3236	38	24D
0005435885353	3236	39	24F
0005435885334	3236	40	25A
0005435885234	3236	41	25C
0005435885132	3236	42	25E
0005435885495	3236	43	26B
0005435885233	3236	44	26D
0005435885318	3236	45	27B
0005435884975	3236	46	27D
0005435885306	3236	47	27E
0005435885324	3236	48	28B
0005435885424	3236	49	28F
0005435885361	3236	50	29B
0005435885519	3236	51	29D
0005435885156	3236	52	29F
0005435885663	8263	1	1A
0005432460296	8263	2	1C
0005435885629	8263	3	1D
0005432042837	8263	4	2A
0005435885627	8263	5	1F
0005432460319	8263	6	2D
0005432460292	8263	7	3A
0005435885674	8263	8	2F
0005432460326	8263	9	3C
0005433507164	8263	10	3D
0005435885667	8263	11	4A
0005433507207	8263	12	3F
0005432042830	8263	13	4C
0005433507163	8263	14	4F
0005435885639	8263	15	4D
0005435885637	8263	16	5A
0005432042829	8263	17	5D
0005433507184	8263	18	5C
0005435885665	8263	19	6A
0005432460310	8263	20	5F
0005432460298	8263	21	6D
0005435885658	8263	22	7A
0005435885662	8263	23	6F
0005435885670	8263	24	7C
0005435885631	8263	25	7F
0005435885672	8263	26	8A
0005435885682	8263	27	8B
0005432460341	8263	28	8D
0005432460314	8263	29	8C
0005432460339	8263	30	8E
0005435885676	8263	31	8F
0005432460302	8263	32	9B
0005432460329	8263	33	9A
0005432460334	8263	34	9C
0005435885653	8263	35	9D
0005435885680	8263	36	9F
0005435885626	8263	37	10A
0005432460344	8263	38	10B
0005432042831	8263	39	10D
0005432460332	8263	40	10C
0005432460345	8263	41	10E
0005435885632	8263	42	10F
0005432460323	8263	43	11C
0005432460309	8263	44	11B
0005432042835	8263	45	11E
0005432460328	8263	46	11D
0005435885681	8263	47	11F
0005432460340	8263	48	12A
0005435885678	8263	49	12C
0005435885673	8263	50	12B
0005433507050	8263	51	12D
0005432460299	8263	52	12F
0005435885641	8263	53	12E
0005432460316	8263	54	13C
0005435885666	8263	55	13B
0005432042827	8263	56	13F
0005432460308	8263	57	13E
0005432460331	8263	58	14A
0005435885668	8263	59	14C
0005432042836	8263	60	14B
0005434312338	8263	61	14D
0005435885643	8263	62	14E
0005435885655	8263	63	14F
0005433507188	8263	64	15C
0005432460311	8263	65	15B
0005435885679	8263	66	15D
0005432460305	8263	67	15F
0005432042828	8263	68	16A
0005432460327	8263	69	16C
0005432460306	8263	70	16B
0005435885630	8263	71	16D
0005432460304	8263	72	16E
0005432460317	8263	73	17A
0005435885661	8263	74	16F
0005432042833	8263	75	17B
0005432460297	8263	76	17C
0005435885685	8263	77	17D
0005435885649	8263	78	17F
0005432460312	8263	79	17E
0005433507223	8263	80	18A
0005432460313	8263	81	18B
0005435885633	8263	82	18E
0005432460294	8263	83	18D
0005435885624	8263	84	19C
0005435885671	8263	85	19B
0005432460337	8263	86	19D
0005432460320	8263	87	19E
0005432460335	8263	88	20B
0005435885669	8263	89	20C
0005435885625	8263	90	20E
0005435885642	8263	91	20D
0005435885628	8263	92	20F
0005432042832	8263	93	21A
0005435885656	8263	94	21D
0005432460315	8263	95	21C
0005435885650	8263	96	21E
0005432460324	8263	97	21F
0005434312339	8263	98	22B
0005432460321	8263	99	22A
0005432460336	8263	100	22C
0005435885677	8263	101	22D
0005435885636	8263	102	22F
0005435885647	8263	103	22E
0005435885638	8263	104	23B
0005432460343	8263	105	23A
0005433507181	8263	106	23D
0005435885654	8263	107	23F
0005432460307	8263	108	23E
0005435885652	8263	109	24A
0005435885622	8263	110	24E
0005435885659	8263	111	24D
0005435885644	8263	112	24F
0005432042824	8263	113	25A
0005435885635	8263	114	25C
0005432460338	8263	115	25B
0005433507176	8263	116	25E
0005432460322	8263	117	25D
0005432042826	8263	118	25F
0005432460318	8263	119	26B
0005435885645	8263	120	26D
0005432460293	8263	121	26C
0005435885634	8263	122	26F
0005435885684	8263	123	27A
0005432460300	8263	124	27C
0005435885646	8263	125	27D
0005435885623	8263	126	27E
0005435885664	8263	127	28A
0005435885657	8263	128	28B
0005433507185	8263	129	28D
0005432460342	8263	130	28E
0005435885648	8263	131	29A
0005432460333	8263	132	29C
0005435885675	8263	133	29B
0005432460295	8263	134	29D
0005435885683	8263	135	29F
0005432042825	8263	136	30B
0005432460303	8263	137	30A
0005435885640	8263	138	30C
0005432460330	8263	139	30E
0005432460325	8263	140	30D
0005432042834	8263	141	30F
0005432460301	8263	142	31B
0005434326274	8263	143	31A
0005433507074	8263	144	31C
0005435885651	8263	145	31D
0005435885660	8263	146	31F
0005433805513	8250	1	1A
0005433633714	8250	2	1D
0005433633670	8250	3	2C
0005433633634	8250	4	2F
0005433633875	8250	5	3C
0005433633611	8250	6	3F
0005433633690	8250	7	4A
0005433805186	8250	8	5D
0005433633822	8250	9	5C
0005433633855	8250	10	6C
0005433633739	8250	11	7D
0005433805308	8250	12	8E
0005433805425	8250	13	8F
0005433633771	8250	14	9E
0005433805313	8250	15	9D
0005433633715	8250	16	10B
0005433633801	8250	17	10D
0005433633817	8250	18	10F
0005433805437	8250	19	11B
0005433633794	8250	20	11A
0005433633803	8250	21	11C
0005433805535	8250	22	11E
0005433633849	8250	23	11F
0005433633933	8250	24	12B
0005433805335	8250	25	12F
0005433805296	8250	26	13C
0005433805406	8250	27	13B
0005433805312	8250	28	14A
0005434143728	8250	29	13F
0005433633765	8250	30	14C
0005433633787	8250	31	14B
0005433633902	8250	32	14E
0005433805496	8250	33	14F
0005433805185	8250	34	15C
0005433805458	8250	35	16A
0005433633767	8250	36	16D
0005433633800	8250	37	16E
0005433633706	8250	38	17C
0005433633615	8250	39	17D
0005433633815	8250	40	18F
0005433805352	8250	41	19C
0005433633691	8250	42	19E
0005433633788	8250	43	20D
0005433633926	8250	44	20F
0005433633738	8250	45	21B
0005433805375	8250	46	21F
0005433633717	8250	47	22A
0005433805351	8250	48	22E
0005433633876	8250	49	22D
0005434271310	8250	50	22F
0005433633823	8250	51	23D
0005434271317	8250	52	23F
0005433633742	8250	53	24A
0005433633793	8250	54	24B
0005433633705	8250	55	24D
0005433805392	8250	56	24F
0005433805309	8250	57	25D
0005433633934	8250	58	25E
0005433805290	8250	59	26B
0005433805212	8250	60	26D
0005433633802	8250	61	26E
0005433805277	8250	62	26F
0005433805259	8250	63	27F
0005433633768	8250	64	28A
0005433805407	8250	65	28E
0005433805502	8250	66	28F
0005433633760	8250	67	29D
0005433805367	8250	68	29F
0005433805464	8250	69	30A
0005433805336	8250	70	30C
0005433633778	8250	71	30D
0005433633816	8250	72	30F
0005433805393	8250	73	31E
0005433805512	8250	74	31F
0005434183577	8321	1	10B
0005434183571	8321	2	24A
0005434183586	8321	3	24C
0005432383508	4516	1	1C
0005433454892	4516	2	1D
0005432383521	4516	3	1F
0005432383513	4516	4	2C
0005432383528	4516	5	2D
0005433454893	4516	6	2F
0005433722278	4516	7	3A
0005432728041	4516	8	3F
0005433722281	4516	9	4A
0005432383526	4516	10	4C
0005433454894	4516	11	4D
0005432383516	4516	12	4E
0005432383504	4516	13	4F
0005433453776	4516	14	5C
0005432383530	4516	15	5F
0005432383527	4516	16	6A
0005432383490	4516	17	6D
0005432383489	4516	18	6E
0005432383519	4516	19	7A
0005432383501	4516	20	7D
0005432728046	4516	21	7E
0005432383499	4516	22	7F
0005432383518	4516	23	8A
0005432383494	4516	24	8C
0005432383520	4516	25	8D
0005432728038	4516	26	8E
0005432728044	4516	27	8F
0005433722279	4516	28	9C
0005432383500	4516	29	9D
0005432728039	4516	30	9F
0005433194876	4516	31	10A
0005432383491	4516	32	10C
0005432728048	4516	33	10D
0005432383523	4516	34	10E
0005432383506	4516	35	10F
0005433722277	4516	36	11C
0005432383514	4516	37	11E
0005432383502	4516	38	11F
0005432383531	4516	39	12C
0005432383524	4516	40	12D
0005432728045	4516	41	12E
0005432383515	4516	42	13A
0005432383492	4516	43	13C
0005432383525	4516	44	13D
0005432383488	4516	45	13F
0005432728042	4516	46	14A
0005433453775	4516	47	14C
0005432383522	4516	48	14E
0005432383517	4516	49	14F
0005432383510	4516	50	15A
0005433722280	4516	51	15C
0005432383496	4516	52	15D
0005432383497	4516	53	15F
0005432383529	4516	54	16E
0005432383505	4516	55	16F
0005432383507	4516	56	17C
0005432383509	4516	57	17E
0005432383532	4516	58	17F
0005432728043	4516	59	18D
0005432728040	4516	60	18E
0005432383512	4516	61	18F
0005432383498	4516	62	19A
0005432383503	4516	63	19C
0005432383511	4516	64	19D
0005432728047	4516	65	19E
0005432383495	4516	66	19F
0005432728037	4516	67	20A
0005432383493	4516	68	20D
0005432727956	30129	1	1A
0005432727895	30129	2	1C
0005433451617	30129	3	1D
0005432383048	30129	4	1F
0005432382895	30129	5	2D
0005432383076	30129	6	2F
0005432382942	30129	7	3A
0005433722187	30129	8	3D
0005432383086	30129	9	4D
0005432383051	30129	10	5A
0005432383078	30129	11	5C
0005432383054	30129	12	5D
0005433722192	30129	13	5E
0005432382980	30129	14	6A
0005432727992	30129	15	5F
0005433453758	30129	16	6C
0005433451619	30129	17	6E
0005432383006	30129	18	6F
0005432727934	30129	19	7A
0005432383083	30129	20	7C
0005432383009	30129	21	7D
0005432382848	30129	22	7F
0005432382991	30129	23	8E
0005432727922	30129	24	8F
0005432383007	30129	25	9A
0005432382904	30129	26	9C
0005432382992	30129	27	9E
0005432383052	30129	28	9F
0005432382965	30129	29	10A
0005432727880	30129	30	10D
0005432383008	30129	31	10E
0005432383033	30129	32	10F
0005432727879	30129	33	11A
0005432383053	30129	34	11C
0005432382955	30129	35	11E
0005432727869	30129	36	11F
0005432383045	30129	37	12C
0005432383000	30129	38	12D
0005432727971	30129	39	12E
0005433722193	30129	40	13A
0005432383039	30129	41	13C
0005432383063	30129	42	13D
0005432382951	30129	43	13F
0005432383082	30129	44	14A
0005432382896	30129	45	14D
0005433194851	30129	46	14E
0005432383044	30129	47	14F
0005432383019	30129	48	15A
0005432383030	30129	49	15E
0005432383040	30129	50	15F
0005433451620	30129	51	16C
0005432383055	30129	52	16E
0005432382932	30129	53	17C
0005432383046	30129	54	17D
0005432383018	30129	55	17F
0005432727930	30129	56	18D
0005432382974	30129	57	18E
0005432382856	30129	58	19D
0005432727903	30129	59	19E
0005432383020	30129	60	20D
0005432382973	30129	61	20E
0005435529433	1720	1	1A
0005432294507	1720	2	1D
0005435541198	1720	3	1F
0005435529450	1720	4	2A
0005432294508	1720	5	2D
0005435541176	1720	6	2F
0005435541191	1720	7	3A
0005433516966	1720	8	3F
0005435529438	1720	9	4A
0005435529434	1720	10	4D
0005435529448	1720	11	5C
0005435529432	1720	12	5D
0005435541177	1720	13	6A
0005435541183	1720	14	6C
0005435541185	1720	15	6D
0005435529453	1720	16	6E
0005435541197	1720	17	6F
0005435541193	1720	18	7A
0005435541192	1720	19	7C
0005435529445	1720	20	7D
0005435529442	1720	21	7E
0005435529452	1720	22	8C
0005432925044	1720	23	8D
0005433516963	1720	24	8E
0005433516960	1720	25	8F
0005435529441	1720	26	9A
0005432925033	1720	27	9C
0005435529436	1720	28	9D
0005435541180	1720	29	9E
0005433516969	1720	30	11A
0005435529449	1720	31	11C
0005435541179	1720	32	11D
0005435541181	1720	33	11E
0005435541187	1720	34	11F
0005432925034	1720	35	12A
0005435541178	1720	36	12D
0005433516964	1720	37	12E
0005433516962	1720	38	13A
0005435541190	1720	39	13D
0005435529446	1720	40	13E
0005433516968	1720	41	13F
0005435529454	1720	42	14A
0005435541196	1720	43	14D
0005433516967	1720	44	14F
0005435529435	1720	45	15A
0005435529440	1720	46	15C
0005435541189	1720	47	15E
0005435529451	1720	48	15F
0005433516961	1720	49	16A
0005435529437	1720	50	16C
0005435529439	1720	51	16E
0005435541184	1720	52	17E
0005433516965	1720	53	17F
0005435529443	1720	54	18A
0005435541195	1720	55	18C
0005435541186	1720	56	18D
0005435541188	1720	57	18F
0005435541194	1720	58	19A
0005435529455	1720	59	19C
0005435529447	1720	60	19D
0005435541182	1720	61	19E
0005435529444	1720	62	20C
0005435540961	21977	1	2D
0005433516876	21977	2	3F
0005435517968	21977	3	4E
0005432925078	21977	4	4F
0005435517837	21977	5	5A
0005435517895	21977	6	5C
0005435541006	21977	7	5D
0005435517817	21977	8	6A
0005433516894	21977	9	6C
0005435540958	21977	10	6D
0005435541004	21977	11	6E
0005435541059	21977	12	6F
0005435517825	21977	13	7A
0005435540981	21977	14	7C
0005435540859	21977	15	8A
0005435517871	21977	16	8C
0005435540988	21977	17	8D
0005432925075	21977	18	8E
0005433516889	21977	19	8F
0005433516914	21977	20	9A
0005435517896	21977	21	9C
0005435517894	21977	22	9D
0005435540831	21977	23	9E
0005435541023	21977	24	9F
0005432925074	21977	25	10D
0005432925077	21977	26	10E
0005435540984	21977	27	10F
0005435540962	21977	28	11C
0005435517969	21977	29	11D
0005435517864	21977	30	11F
0005433516875	21977	31	12C
0005435517897	21977	32	12E
0005435540977	21977	33	13A
0005433516877	21977	34	13D
0005435517863	21977	35	13E
0005435517880	21977	36	14A
0005433516858	21977	37	14C
0005433516881	21977	38	14D
0005433516888	21977	39	14F
0005435540858	21977	40	16C
0005435517901	21977	41	16E
0005435540976	21977	42	16F
0005432925079	21977	43	17A
0005435540942	21977	44	17C
0005435517849	21977	45	17E
0005435540990	21977	46	17F
0005435541014	21977	47	18C
0005432925076	21977	48	18E
0005435541041	21977	49	19A
0005435540985	21977	50	19D
0005435540989	21977	51	19E
0005433516880	21977	52	19F
0005435541015	21977	53	20A
0005435540959	21977	54	20E
0005435491438	7392	1	1A
0005432839305	7392	2	1C
0005434458976	7392	3	1D
0005434458983	7392	4	1F
0005432839285	7392	5	2A
0005435252647	7392	6	2C
0005434458977	7392	7	2F
0005432839283	7392	8	3A
0005432841030	7392	9	3D
0005435252672	7392	10	3F
0005432839292	7392	11	4A
0005434458972	7392	12	4C
0005435252763	7392	13	4D
0005432839281	7392	14	4E
0005435491437	7392	15	4F
0005432841029	7392	16	5C
0005435252588	7392	17	5D
0005432823464	7392	18	5E
0005432839286	7392	19	5F
0005432839291	7392	20	6C
0005434458982	7392	21	6D
0005432823466	7392	22	6E
0005432839280	7392	23	6F
0005435252649	7392	24	7A
0005432823465	7392	25	7C
0005432839284	7392	26	7D
0005434458967	7392	27	7E
0005434664954	7392	28	7F
0005432841028	7392	29	8A
0005432839276	7392	30	8D
0005434458986	7392	31	8E
0005435491435	7392	32	8F
0005434664957	7392	33	9A
0005434458978	7392	34	9C
0005432839306	7392	35	9D
0005434458979	7392	36	9E
0005434458966	7392	37	9F
0005434458981	7392	38	10C
0005435252786	7392	39	10D
0005432839296	7392	40	10E
0005434458973	7392	41	11A
0005432839304	7392	42	11C
0005434458985	7392	43	11D
0005432839298	7392	44	11E
0005432073418	7392	45	11F
0005432839294	7392	46	12A
0005432839299	7392	47	12C
0005432839278	7392	48	12D
0005432839279	7392	49	12E
0005432839302	7392	50	12F
0005435252631	7392	51	13A
0005434458968	7392	52	13C
0005432839300	7392	53	13D
0005432839288	7392	54	13E
0005432839303	7392	55	13F
0005434458970	7392	56	14A
0005435252722	7392	57	14D
0005432839290	7392	58	14E
0005432839293	7392	59	14F
0005435252630	7392	60	15A
0005434458980	7392	61	15C
0005434458984	7392	62	15E
0005435252719	7392	63	15F
0005432839287	7392	64	16A
0005435252738	7392	65	16C
0005432073420	7392	66	16D
0005435252721	7392	67	16F
0005434458971	7392	68	17D
0005432073419	7392	69	17E
0005432839282	7392	70	17F
0005434458975	7392	71	18C
0005434458974	7392	72	18E
0005435252648	7392	73	18F
0005432839307	7392	74	19A
0005434458969	7392	75	19C
0005435252720	7392	76	19D
0005432839277	7392	77	19E
0005435252589	7392	78	19F
0005432839301	7392	79	20C
0005432839297	7392	80	20D
0005432839289	7392	81	20E
0005432839295	7392	82	20F
0005432839158	28941	1	1A
0005432839092	28941	2	1C
0005432838926	28941	3	1D
0005432823442	28941	4	1F
0005432838956	28941	5	2A
0005432839108	28941	6	2C
0005432839094	28941	7	2D
0005432823452	28941	8	2F
0005432839132	28941	9	3A
0005435491458	28941	10	3C
0005434458682	28941	11	3D
0005432823444	28941	12	3F
0005435252840	28941	13	4A
0005435252852	28941	14	4C
0005434458756	28941	15	4E
0005432839109	28941	16	4F
0005432838982	28941	17	5A
0005432839146	28941	18	5C
0005434458836	28941	19	5D
0005434458604	28941	20	5E
0005432839080	28941	21	5F
0005434458779	28941	22	6A
0005435252851	28941	23	6C
0005435252838	28941	24	6D
0005432823449	28941	25	6E
0005432839104	28941	26	6F
0005435252841	28941	27	7A
0005434458605	28941	28	7C
0005432838965	28941	29	7D
0005432838928	28941	30	7E
0005434458780	28941	31	7F
0005435252837	28941	32	8A
0005434664981	28941	33	8C
0005432001039	28941	34	8D
0005432841013	28941	35	8E
0005432839149	28941	36	8F
0005432839147	28941	37	9A
0005432839148	28941	38	9C
0005434458831	28941	39	9D
0005435252847	28941	40	9E
0005432838927	28941	41	10A
0005435491455	28941	42	10E
0005435252854	28941	43	10F
0005432839038	28941	44	11A
0005435252849	28941	45	11C
0005434458867	28941	46	11D
0005432839159	28941	47	11F
0005434458757	28941	48	12A
0005432823443	28941	49	12C
0005432839049	28941	50	12D
0005435252845	28941	51	12E
0005432001040	28941	52	12F
0005432838955	28941	53	13A
0005435252844	28941	54	13D
0005432839067	28941	55	13E
0005432839102	28941	56	13F
0005434664980	28941	57	14A
0005435252855	28941	58	14C
0005432839110	28941	59	14D
0005432839130	28941	60	14E
0005432838929	28941	61	14F
0005432839107	28941	62	15A
0005435491457	28941	63	15C
0005434458873	28941	64	15D
0005435252853	28941	65	15E
0005432839095	28941	66	15F
0005435252839	28941	67	16A
0005434458785	28941	68	16C
0005432839103	28941	69	16D
0005435491456	28941	70	16E
0005434458759	28941	71	16F
0005435252843	28941	72	17A
0005432839068	28941	73	17C
0005432839070	28941	74	17D
0005434458681	28941	75	17F
0005435252850	28941	76	18A
0005434458837	28941	77	18C
0005435252846	28941	78	18D
0005432838966	28941	79	18E
0005434664979	28941	80	18F
0005435252848	28941	81	19A
0005432838981	28941	82	19C
0005432839003	28941	83	19D
0005435252842	28941	84	19E
0005434458786	28941	85	19F
0005432823451	28941	86	20A
0005434458804	28941	87	20C
0005432838963	28941	88	20D
0005432839131	28941	89	20E
0005432839045	28941	90	20F
0005434276036	8782	1	2D
0005434276031	8782	2	6C
0005434276035	8782	3	6F
0005435990683	8782	4	9A
0005435990684	8782	5	10B
0005435990681	8782	6	11A
0005435990685	8782	7	11F
0005435990682	8782	8	16D
0005435990680	8782	9	20B
0005434276076	15720	1	5D
0005434276072	15720	2	6A
0005434276073	15720	3	6D
0005435990618	15720	4	7D
0005435990623	15720	5	9A
0005435990626	15720	6	9F
0005434276074	15720	7	11F
0005434276077	15720	8	15A
0005434276075	15720	9	16D
0005435990622	15720	10	18D
0005435990599	15720	11	19A
0005435990613	15720	12	21B
0005432427141	30847	1	5B
0005433476907	30847	2	7B
0005433476912	30847	3	7C
0005433476909	30847	4	19B
0005433476910	30847	5	19D
0005433476908	30847	6	21A
0005433476911	30847	7	21D
0005432909323	23850	1	1A
0005432909325	23850	2	1C
0005433468352	23850	3	1D
0005433468289	23850	4	2A
0005432909330	23850	5	2B
0005432909324	23850	6	2C
0005432909322	23850	7	3B
0005433468346	23850	8	3C
0005433468328	23850	9	4D
0005433468332	23850	10	5B
0005432909321	23850	11	5C
0005432909329	23850	12	5D
0005433468319	23850	13	6A
0005432909328	23850	14	6B
0005432909326	23850	15	6C
0005433468316	23850	16	6D
0005433468330	23850	17	7A
0005433468304	23850	18	7B
0005433468321	23850	19	7C
0005433468357	23850	20	7D
0005433468327	23850	21	18B
0005433468323	23850	22	18D
0005433468320	23850	23	19C
0005433468337	23850	24	19D
0005433468355	23850	25	20D
0005432909327	23850	26	21A
0005433468351	23850	27	21C
0005433468347	23850	28	21D
0005433468326	23850	29	22A
0005433468318	23850	30	22B
0005433468356	23850	31	22C
0005432909331	23850	32	23B
0005432336133	6379	1	1A
0005432360759	6379	2	1C
0005432360774	6379	3	1D
0005434149648	6379	4	2A
0005432360744	6379	5	1F
0005432360773	6379	6	2C
0005435490215	6379	7	2D
0005434149649	6379	8	2F
0005435723034	6379	9	3C
0005432363442	6379	10	3A
0005434149748	6379	11	3D
0005432360765	6379	12	4A
0005432336131	6379	13	3F
0005432360783	6379	14	4B
0005432360737	6379	15	4C
0005432360755	6379	16	4E
0005435723046	6379	17	4D
0005434149717	6379	18	4F
0005432360776	6379	19	5B
0005435490219	6379	20	5A
0005432360746	6379	21	5C
0005432360761	6379	22	5F
0005434149692	6379	23	6C
0005432360764	6379	24	6B
0005432062274	6379	25	6D
0005432336127	6379	26	6E
0005435177150	6379	27	7A
0005432360780	6379	28	6F
0005435177038	6379	29	7B
0005432062271	6379	30	7D
0005435176968	6379	31	7E
0005432360741	6379	32	8A
0005432336137	6379	33	7F
0005432360756	6379	34	8B
0005432360782	6379	35	8C
0005435177151	6379	36	8E
0005432360763	6379	37	8D
0005432360766	6379	38	9A
0005432336134	6379	39	8F
0005434149707	6379	40	9B
0005435490214	6379	41	9D
0005432360775	6379	42	9C
0005432062273	6379	43	9E
0005432360738	6379	44	9F
0005435177141	6379	45	10B
0005435177177	6379	46	10C
0005432360758	6379	47	10E
0005435177053	6379	48	10D
0005432336138	6379	49	11A
0005435177130	6379	50	11B
0005434149708	6379	51	11D
0005434149727	6379	52	11C
0005435177124	6379	53	11E
0005432336132	6379	54	11F
0005432336136	6379	55	12B
0005432336130	6379	56	12A
0005435177044	6379	57	12E
0005432360762	6379	58	12F
0005432360768	6379	59	13A
0005432360752	6379	60	13C
0005432360742	6379	61	13B
0005432360760	6379	62	13D
0005435177037	6379	63	13F
0005434149679	6379	64	14B
0005432360769	6379	65	14A
0005435723033	6379	66	14D
0005432360771	6379	67	14C
0005432062270	6379	68	15A
0005435177070	6379	69	14F
0005434149745	6379	70	15B
0005435177071	6379	71	15C
0005432360757	6379	72	15D
0005432360778	6379	73	15E
0005435177090	6379	74	16A
0005432062276	6379	75	15F
0005432360740	6379	76	16B
0005435490218	6379	77	16C
0005432336135	6379	78	16E
0005435176967	6379	79	16D
0005432360767	6379	80	16F
0005432062272	6379	81	17A
0005432360743	6379	82	17B
0005435177011	6379	83	17C
0005432360784	6379	84	17E
0005435177102	6379	85	17D
0005432360745	6379	86	17F
0005432360749	6379	87	18A
0005432360750	6379	88	18B
0005435177076	6379	89	18C
0005432363443	6379	90	18E
0005435177161	6379	91	18F
0005432360753	6379	92	19A
0005432336129	6379	93	19D
0005432363444	6379	94	19C
0005432360779	6379	95	19E
0005435177129	6379	96	19F
0005435177192	6379	97	20B
0005435177083	6379	98	20A
0005432360781	6379	99	20D
0005434149680	6379	100	20C
0005435177167	6379	101	20E
0005432360739	6379	102	21A
0005435177149	6379	103	20F
0005432360751	6379	104	21C
0005432062275	6379	105	21D
0005435177055	6379	106	21F
0005434149706	6379	107	21E
0005435177069	6379	108	22A
0005435177052	6379	109	22B
0005432360754	6379	110	22C
0005432360770	6379	111	22E
0005432360772	6379	112	22F
0005432360748	6379	113	23A
0005432360777	6379	114	23C
0005435177054	6379	115	23D
0005432336128	6379	116	23E
0005432360747	6379	117	23F
0005435177316	21037	1	1A
0005432360314	21037	2	1F
0005435490260	21037	3	1D
0005432335938	21037	4	2A
0005432360479	21037	5	2C
0005435723063	21037	6	2D
0005434149832	21037	7	2F
0005432360395	21037	8	3A
0005432360480	21037	9	3D
0005432360131	21037	10	3C
0005432360093	21037	11	3F
0005432360274	21037	12	4A
0005432360178	21037	13	4C
0005432336027	21037	14	4D
0005432360433	21037	15	4F
0005435177299	21037	16	5A
0005432360485	21037	17	5C
0005432360094	21037	18	5D
0005435177311	21037	19	5E
0005435177315	21037	20	6B
0005432336007	21037	21	6A
0005435177295	21037	22	6C
0005432360313	21037	23	6D
0005432360251	21037	24	6F
0005432360463	21037	25	7B
0005432360385	21037	26	7C
0005434149827	21037	27	7E
0005432360169	21037	28	7D
0005435177303	21037	29	8A
0005432360255	21037	30	7F
0005434149828	21037	31	8B
0005435490261	21037	32	8D
0005432360378	21037	33	8F
0005432360564	21037	34	8E
0005432360319	21037	35	9A
0005432363414	21037	36	9C
0005435177305	21037	37	9B
0005432336038	21037	38	9E
0005432336035	21037	39	9F
0005435177294	21037	40	10B
0005432363413	21037	41	10C
0005432360535	21037	42	10E
0005432336024	21037	43	11A
0005432360294	21037	44	11B
0005435177289	21037	45	11C
0005435723062	21037	46	11D
0005432360366	21037	47	11F
0005432360503	21037	48	11E
0005434149825	21037	49	12B
0005432360327	21037	50	12D
0005435177301	21037	51	12C
0005435177293	21037	52	12E
0005432360392	21037	53	12F
0005432336022	21037	54	13C
0005432336037	21037	55	13B
0005432335939	21037	56	13D
0005432360299	21037	57	13F
0005434149826	21037	58	14A
0005435177292	21037	59	14C
0005432336023	21037	60	14B
0005432360275	21037	61	14E
0005435177297	21037	62	15A
0005435177298	21037	63	14F
0005435177317	21037	64	15B
0005434149831	21037	65	15C
0005432360394	21037	66	15D
0005435177291	21037	67	15E
0005434149822	21037	68	16C
0005435177296	21037	69	16D
0005432360506	21037	70	16F
0005432360379	21037	71	16E
0005435177300	21037	72	17A
0005434149823	21037	73	17B
0005432360515	21037	74	17C
0005434149824	21037	75	17D
0005432336062	21037	76	17F
0005435177309	21037	77	17E
0005432336008	21037	78	18A
0005434149830	21037	79	18C
0005435177312	21037	80	18D
0005432052771	21037	81	18E
0005435177318	21037	82	18F
0005435177290	21037	83	19A
0005435723065	21037	84	19B
0005435490263	21037	85	19C
0005432360085	21037	86	19F
0005435177307	21037	87	20C
0005432336028	21037	88	20B
0005432360393	21037	89	20D
0005432360320	21037	90	20E
0005435177314	21037	91	21A
0005435177308	21037	92	20F
0005434149829	21037	93	21D
0005435177302	21037	94	21C
0005432360256	21037	95	21E
0005432052772	21037	96	21F
0005432052770	21037	97	22A
0005432360514	21037	98	22C
0005435177310	21037	99	22B
0005435177306	21037	100	22D
0005435490262	21037	101	22F
0005435723064	21037	102	22E
0005432360360	21037	103	23A
0005435177313	21037	104	23B
0005435177304	21037	105	23E
0005432335999	21037	106	23F
0005434463920	17692	1	1B
0005434458826	17692	2	2B
0005434458799	17692	3	3A
0005434458800	17692	4	3B
0005434458787	17692	5	3C
0005434458822	17692	6	3D
0005434458748	17692	7	4A
0005434458801	17692	8	4B
0005434458835	17692	9	4C
0005434458845	17692	10	4D
0005434448320	17692	11	5B
0005434458825	17692	12	5D
0005434461650	17692	13	6C
0005434458746	17692	14	6D
0005434458962	17692	15	7B
0005434458768	17692	16	7C
0005434458751	17692	17	7D
0005434458821	17692	18	18A
0005434186223	17692	19	18B
0005434458834	17692	20	18C
0005434458817	17692	21	18D
0005434458803	17692	22	19B
0005434458860	17692	23	19C
0005434186224	17692	24	20C
0005434458750	17692	25	21B
0005434458872	17692	26	21C
0005434186222	17692	27	22B
0005434458963	17692	28	22C
0005434458859	17692	29	22D
0005434458747	17692	30	23B
0005434186189	29103	1	1B
0005434458969	29103	2	1C
0005434462805	29103	3	1D
0005434458966	29103	4	2A
0005434458978	29103	5	2B
0005434186184	29103	6	2C
0005434458967	29103	7	3B
0005434458972	29103	8	3D
0005434462808	29103	9	4A
0005434458981	29103	10	4B
0005434458976	29103	11	4C
0005434458974	29103	12	5C
0005434458982	29103	13	5D
0005434448340	29103	14	6A
0005434458975	29103	15	6B
0005434463944	29103	16	6D
0005434448342	29103	17	7A
0005434458980	29103	18	7B
0005434458977	29103	19	7C
0005434458979	29103	20	7D
0005434462806	29103	21	18A
0005434186190	29103	22	18C
0005434463945	29103	23	18D
0005434458970	29103	24	19A
0005434458985	29103	25	19C
0005434458968	29103	26	19D
0005434448339	29103	27	20A
0005434458984	29103	28	20B
0005434458971	29103	29	20C
0005434186191	29103	30	20D
0005434186183	29103	31	21B
0005434462807	29103	32	21C
0005434448338	29103	33	21D
0005434448341	29103	34	22A
0005434458973	29103	35	22B
0005434458986	29103	36	22C
0005434458983	29103	37	23A
0005432658581	21834	1	1C
0005432665259	21834	2	2A
0005432665253	21834	3	2F
0005432665251	21834	4	4D
0005432665247	21834	5	4F
0005432658580	21834	6	5C
0005432661904	21834	7	5F
0005432658569	21834	8	5D
0005432665257	21834	9	6D
0005432661910	21834	10	6F
0005432665265	21834	11	6E
0005432665254	21834	12	7A
0005432661901	21834	13	8A
0005432658573	21834	14	7F
0005432665252	21834	15	9D
0005432661912	21834	16	10E
0005432658558	21834	17	11A
0005432661903	21834	18	10F
0005432658576	21834	19	11B
0005432665260	21834	20	11F
0005432658557	21834	21	12D
0005432661902	21834	22	13A
0005432661906	21834	23	12F
0005432658574	21834	24	13E
0005432661909	21834	25	13F
0005432665248	21834	26	14B
0005432658564	21834	27	14D
0005432658571	21834	28	15E
0005432658577	21834	29	16A
0005432658575	21834	30	15F
0005432661905	21834	31	16B
0005432665256	21834	32	17A
0005432658568	21834	33	16F
0005432665258	21834	34	16E
0005432661899	21834	35	17D
0005432665267	21834	36	17F
0005432658562	21834	37	18F
0005432658560	21834	38	19C
0005432658570	21834	39	19B
0005432661898	21834	40	19D
0005432665266	21834	41	19E
0005432661907	21834	42	20B
0005432658563	21834	43	20D
0005432665246	21834	44	20E
0005432665255	21834	45	21A
0005432661908	21834	46	21C
0005432658559	21834	47	21D
0005432604644	21452	1	1A
0005432604635	21452	2	1C
0005432604632	21452	3	1D
0005432604648	21452	4	2A
0005432604628	21452	5	2B
0005432604617	21452	6	2C
0005432604637	21452	7	2D
0005432604622	21452	8	3A
0005432604650	21452	9	3B
0005432604655	21452	10	3C
0005432604626	21452	11	3D
0005432604624	21452	12	4A
0005432604618	21452	13	4B
0005432604640	21452	14	4C
0005432604619	21452	15	4D
0005432604638	21452	16	5A
0005432604620	21452	17	5B
0005432604621	21452	18	5C
0005432604630	21452	19	6A
0005432604651	21452	20	6B
0005432604646	21452	21	6C
0005432604616	21452	22	6D
0005432604641	21452	23	7A
0005432604654	21452	24	7B
0005432604627	21452	25	7C
0005432604642	21452	26	7D
0005432604633	21452	27	18B
0005432604636	21452	28	18C
0005432604652	21452	29	18D
0005432604634	21452	30	19A
0005432604625	21452	31	19B
0005432604631	21452	32	19C
0005432604629	21452	33	20B
0005432604615	21452	34	20C
0005432604639	21452	35	21B
0005432604623	21452	36	21C
0005432604645	21452	37	21D
0005432604647	21452	38	22A
0005435218112	21452	39	22C
0005432604649	21452	40	22D
0005432604643	21452	41	23A
0005432604653	21452	42	23B
0005432604299	31675	1	1A
0005432604172	31675	2	1D
0005432604291	31675	3	2A
0005432604386	31675	4	2B
0005432604010	31675	5	2C
0005432604324	31675	6	2D
0005432604274	31675	7	3B
0005432604077	31675	8	3A
0005432604222	31675	9	3D
0005432604051	31675	10	4A
0005432604148	31675	11	4B
0005432604273	31675	12	4C
0005432604149	31675	13	4D
0005432604534	31675	14	5A
0005432604446	31675	15	5B
0005432604410	31675	16	5C
0005432604287	31675	17	5D
0005432604281	31675	18	6B
0005432604191	31675	19	6C
0005432604190	31675	20	6D
0005432604309	31675	21	7A
0005432604161	31675	22	7B
0005432604271	31675	23	7C
0005432604384	31675	24	7D
0005432604211	31675	25	18B
0005432604310	31675	26	18C
0005432604170	31675	27	18D
0005432604413	31675	28	19A
0005432604162	31675	29	19B
0005432604171	31675	30	19C
0005432604297	31675	31	19D
0005432604213	31675	32	20A
0005432604192	31675	33	20B
0005432604221	31675	34	20C
0005432604157	31675	35	20D
0005432604346	31675	36	21A
0005432604323	31675	37	21B
0005432604225	31675	38	21D
0005432604052	31675	39	22A
0005432604385	31675	40	22B
0005432604296	31675	41	22C
0005432604412	31675	42	22D
0005432604292	31675	43	23A
0005432604229	31675	44	23B
0005433293305	29594	1	1B
0005433293303	29594	2	2B
0005435154594	29594	3	2C
0005433293301	29594	4	3C
0005433293306	29594	5	3D
0005433293304	29594	6	4B
0005433293309	29594	7	4D
0005433293310	29594	8	5A
0005433293312	29594	9	5C
0005435154595	29594	10	5D
0005433293302	29594	11	6B
0005433293308	29594	12	6D
0005433293307	29594	13	7C
0005435154591	29594	14	18B
0005435154593	29594	15	20C
0005433293313	29594	16	20D
0005435154592	29594	17	22B
0005433293311	29594	18	22D
0005433473345	6676	1	1A
0005433473337	6676	2	1D
0005435257231	6676	3	2B
0005433473334	6676	4	2C
0005435257224	6676	5	2D
0005433473339	6676	6	3A
0005435257243	6676	7	3B
0005435257223	6676	8	3C
0005433473342	6676	9	3D
0005435257227	6676	10	4A
0005435257239	6676	11	4D
0005433473340	6676	12	5C
0005435257236	6676	13	5D
0005435257228	6676	14	6D
0005435257244	6676	15	7B
0005433473336	6676	16	7C
0005435257238	6676	17	7D
0005433473333	6676	18	19A
0005433473330	6676	19	19B
0005433473329	6676	20	19D
0005433473344	6676	21	20B
0005433473341	6676	22	20C
0005433473331	6676	23	20D
0005433473335	6676	24	21A
0005433473338	6676	25	21B
0005435257229	6676	26	21C
0005435257230	6676	27	21D
0005433473332	6676	28	22B
0005433473343	6676	29	22C
0005435257237	6676	30	22D
0005433473346	6676	31	23B
0005435257279	23896	1	1A
0005435257284	23896	2	1C
0005433473265	23896	3	1D
0005433473256	23896	4	2B
0005433473251	23896	5	2D
0005433473253	23896	6	3C
0005433473214	23896	7	3D
0005435257278	23896	8	4A
0005435257276	23896	9	4B
0005433473266	23896	10	4C
0005433473246	23896	11	5B
0005435257277	23896	12	5C
0005433473249	23896	13	6B
0005433473267	23896	14	6C
0005435257283	23896	15	7A
0005433473252	23896	16	7D
0005433473271	23896	17	18A
0005433473255	23896	18	19A
0005433473248	23896	19	19B
0005435257281	23896	20	19D
0005435257282	23896	21	21B
0005433473236	23896	22	21C
0005435257285	23896	23	21D
0005435257275	23896	24	22A
0005435257280	23896	25	22B
0005433473247	23896	26	23A
0005434606829	18937	1	1B
0005434606821	18937	2	2B
0005434606822	18937	3	6A
0005434606857	22370	1	1A
0005434604924	22370	2	1B
0005434604920	22370	3	2A
0005434604923	22370	4	2B
0005435904707	22370	5	3A
0005434606852	22370	6	3B
0005434606854	22370	7	4A
0005434604922	22370	8	4B
0005434606853	22370	9	5A
0005434606855	22370	10	5B
0005434606856	22370	11	6A
0005434604921	22370	12	6B
0005434522476	3852	1	2A
0005435904401	3852	2	2C
0005434522471	3852	3	2D
0005434522478	3852	4	3A
0005435904406	3852	5	3B
0005434522477	3852	6	4B
0005434522475	3852	7	4C
0005434522474	3852	8	4D
0005434602917	3852	9	5C
0005434522473	3852	10	6A
0005434602919	3852	11	6B
0005434522472	3852	12	6D
0005434602920	3852	13	7D
0005434602921	3852	14	19B
0005435904400	3852	15	19C
0005434602922	3852	16	20B
0005435904405	3852	17	22C
0005435904402	3852	18	22D
0005435904399	3852	19	23A
0005434602918	3852	20	23B
0005434604898	19050	1	3A
0005434602890	19050	2	4B
0005434604890	19050	3	4C
0005435904427	19050	4	4D
0005434522451	19050	5	5B
0005434604900	19050	6	5D
0005434604886	19050	7	6A
0005434602885	19050	8	6C
0005435904424	19050	9	7A
0005435904426	19050	10	7B
0005434604896	19050	11	18C
0005435904423	19050	12	18D
0005435904425	19050	13	19B
0005434602899	19050	14	19C
0005434604895	19050	15	19D
0005434604903	19050	16	20B
0005434602893	19050	17	20D
0005434522431	19050	18	21C
0005434604889	19050	19	22A
0005434602892	19050	20	22D
0005434602887	19050	21	23A
0005435904708	19050	22	23B
0005432747865	377	1	1A
0005432891009	377	2	1C
0005432747854	377	3	1F
0005432747853	377	4	2A
0005433293258	377	5	2C
0005433293277	377	6	2D
0005432747873	377	7	2F
0005432747878	377	8	3A
0005432747885	377	9	3C
0005432747868	377	10	3D
0005432890955	377	11	3F
0005432220035	377	12	4A
0005432891057	377	13	4E
0005432749801	377	14	4F
0005432751552	377	15	5A
0005432890972	377	16	5C
0005432747857	377	17	5D
0005432747860	377	18	5E
0005432747861	377	19	5F
0005432747862	377	20	6A
0005433293231	377	21	6C
0005432890982	377	22	6D
0005432747864	377	23	6E
0005432749800	377	24	6F
0005432890980	377	25	7A
0005432890954	377	26	7C
0005432220036	377	27	7D
0005432747869	377	28	7E
0005432747880	377	29	7F
0005432751549	377	30	8A
0005432747863	377	31	8C
0005432753325	377	32	8D
0005432747875	377	33	8E
0005432747883	377	34	8F
0005432890999	377	35	9A
0005432890994	377	36	9C
0005432890976	377	37	9E
0005432747888	377	38	9F
0005432747851	377	39	10D
0005432747858	377	40	10E
0005435154609	377	41	10F
0005432747859	377	42	11A
0005432890981	377	43	11C
0005432747879	377	44	11D
0005432890957	377	45	11E
0005432220037	377	46	12A
0005432747889	377	47	12C
0005432747871	377	48	12D
0005432747886	377	49	12E
0005433293263	377	50	12F
0005432891018	377	51	13A
0005432747874	377	52	13C
0005432747855	377	53	13E
0005433293276	377	54	13F
0005432220039	377	55	14C
0005432890977	377	56	14D
0005432747870	377	57	14F
0005432747882	377	58	15A
0005432890995	377	59	15C
0005432890964	377	60	15D
0005432747881	377	61	15E
0005432751551	377	62	15F
0005435154607	377	63	16A
0005432747884	377	64	16C
0005432747866	377	65	16D
0005432747852	377	66	16E
0005432751550	377	67	16F
0005432747887	377	68	17A
0005433293262	377	69	17C
0005432747856	377	70	17D
0005435154606	377	71	17E
0005432890956	377	72	17F
0005432220040	377	73	18A
0005432747877	377	74	18D
0005433293225	377	75	18E
0005432747872	377	76	18F
0005432753326	377	77	19A
0005432747876	377	78	19C
0005432891020	377	79	19D
0005432891019	377	80	19E
0005432747867	377	81	19F
0005432220038	377	82	20A
0005435154608	377	83	20C
0005432753324	377	84	20E
0005432890903	377	85	20F
0005432749788	12086	1	1A
0005432747650	12086	2	1C
0005432747345	12086	3	1D
0005432891173	12086	4	1F
0005432756830	12086	5	2A
0005432747610	12086	6	2C
0005432747359	12086	7	2F
0005432891184	12086	8	3A
0005432747676	12086	9	3C
0005432747576	12086	10	3D
0005432747685	12086	11	3F
0005432891189	12086	12	4A
0005432891176	12086	13	4D
0005432747358	12086	14	4F
0005432891170	12086	15	4E
0005432749784	12086	16	5A
0005432756840	12086	17	5C
0005432891187	12086	18	5D
0005432747567	12086	19	5E
0005432891179	12086	20	5F
0005432747341	12086	21	6A
0005432747686	12086	22	6C
0005432214821	12086	23	6F
0005432747439	12086	24	7D
0005432747455	12086	25	7E
0005432756849	12086	26	7F
0005432747663	12086	27	8A
0005432747554	12086	28	8C
0005432891181	12086	29	8E
0005432747575	12086	30	8F
0005432891171	12086	31	9A
0005432747615	12086	32	9C
0005432747606	12086	33	9D
0005432747583	12086	34	9E
0005432747619	12086	35	10A
0005432891185	12086	36	10C
0005432747599	12086	37	10E
0005432747607	12086	38	10F
0005432747560	12086	39	11A
0005432747555	12086	40	11C
0005432747582	12086	41	11E
0005432753305	12086	42	11F
0005432891180	12086	43	12C
0005432747651	12086	44	12D
0005432747521	12086	45	12E
0005432747566	12086	46	12F
0005432891186	12086	47	13C
0005432891188	12086	48	13D
0005432891183	12086	49	13F
0005432747556	12086	50	14C
0005432749777	12086	51	14E
0005432891178	12086	52	14F
0005432756850	12086	53	15A
0005432891172	12086	54	15C
0005432747581	12086	55	15E
0005432747549	12086	56	15F
0005432747525	12086	57	16C
0005432747640	12086	58	16D
0005432891182	12086	59	16E
0005432747559	12086	60	17A
0005432749776	12086	61	17C
0005432747505	12086	62	17D
0005432891175	12086	63	17E
0005432747557	12086	64	18A
0005432749771	12086	65	18C
0005434153542	12086	66	18E
0005432749781	12086	67	18F
0005432747541	12086	68	19A
0005432891174	12086	69	19C
0005432214822	12086	70	19D
0005434153543	12086	71	19F
0005432749775	12086	72	20D
0005432891177	12086	73	20E
0005432747641	12086	74	20F
0005433525122	18997	1	1B
0005432927969	18997	2	2D
0005433525116	18997	3	3B
0005433525124	18997	4	3C
0005433533334	18997	5	3D
0005432927976	18997	6	4B
0005432927982	18997	7	4C
0005433533335	18997	8	5A
0005433525114	18997	9	5B
0005433525123	18997	10	5C
0005432927973	18997	11	6A
0005433525120	18997	12	6B
0005433531320	18997	13	6C
0005432927951	18997	14	6D
0005433531321	18997	15	7B
0005432927985	18997	16	7C
0005433533337	18997	17	7D
0005433531322	18997	18	18A
0005433525119	18997	19	18B
0005433525113	18997	20	18D
0005433525117	18997	21	19A
0005433525125	18997	22	19C
0005433525121	18997	23	20A
0005432927992	18997	24	20B
0005433525118	18997	25	20D
0005433525115	18997	26	21A
0005432927972	18997	27	21C
0005433531323	18997	28	21D
0005432927989	18997	29	22C
0005433533336	18997	30	23A
0005432927975	18997	31	23B
0005432928033	32476	1	1A
0005433525056	32476	2	1C
0005433525047	32476	3	2B
0005432928032	32476	4	2C
0005433525061	32476	5	3D
0005433531314	32476	6	4B
0005433525038	32476	7	4C
0005433525005	32476	8	4D
0005433525006	32476	9	5A
0005432928031	32476	10	5B
0005432928030	32476	11	5C
0005433525003	32476	12	5D
0005433525048	32476	13	7B
0005433525029	32476	14	18B
0005433525026	32476	15	18D
0005433525027	32476	16	19A
0005433525025	32476	17	19B
0005433525037	32476	18	19D
0005432928029	32476	19	20A
0005433525041	32476	20	20C
0005433525030	32476	21	21D
0005433525034	32476	22	22B
0005433525028	32476	23	22C
0005433527241	32476	24	22D
0005433525004	32476	25	23A
0005433525036	32476	26	23B
0005435372952	5284	1	1A
0005435178994	5284	2	1H
0005434558337	5284	3	1D
0005434824586	5284	4	2A
0005435304154	5284	5	1K
0005434824669	5284	6	2C
0005434824678	5284	7	2H
0005434824574	5284	8	2G
0005435150145	5284	9	2K
0005434824626	5284	10	3K
0005434558344	5284	11	3H
0005435373234	5284	12	3G
0005434824640	5284	13	4C
0005434824581	5284	14	4A
0005432396276	5284	15	4G
0005435373029	5284	16	4K
0005434824635	5284	17	5D
0005434824649	5284	18	5C
0005435150137	5284	19	5A
0005434824561	5284	20	5G
0005435373357	5284	21	11A
0005434824598	5284	22	5K
0005434824615	5284	23	11C
0005435735135	5284	24	11E
0005434824655	5284	25	11H
0005432121448	5284	26	12A
0005435304153	5284	27	12E
0005435373411	5284	28	12G
0005435150136	5284	29	12F
0005434824684	5284	30	13A
0005434824605	5284	31	12K
0005435386577	5284	32	13D
0005434558341	5284	33	13C
0005434824662	5284	34	13F
0005434824654	5284	35	13E
0005435373408	5284	36	13G
0005434824580	5284	37	14A
0005434824570	5284	38	14D
0005435373319	5284	39	14C
0005434824562	5284	40	14G
0005434824632	5284	41	14F
0005434824596	5284	42	14E
0005435373477	5284	43	14K
0005434824628	5284	44	14H
0005435372700	5284	45	15C
0005434824602	5284	46	15A
0005435373404	5284	47	15F
0005434664978	5284	48	15E
0005435373196	5284	49	15D
0005434824676	5284	50	15H
0005434824577	5284	51	15G
0005434824671	5284	52	16A
0005435386571	5284	53	16D
0005435373396	5284	54	16F
0005435373124	5284	55	16E
0005434824623	5284	56	16H
0005432121450	5284	57	16G
0005435386583	5284	58	17C
0005434824588	5284	59	17A
0005434824590	5284	60	16K
0005434824568	5284	61	17E
0005435373004	5284	62	17D
0005434824601	5284	63	17G
0005435373131	5284	64	17F
0005434824643	5284	65	17K
0005434664977	5284	66	18C
0005435735131	5284	67	18B
0005435373100	5284	68	18A
0005435178995	5284	69	18D
0005435735112	5284	70	18G
0005434824683	5284	71	18H
0005434831186	5284	72	19B
0005435373114	5284	73	19A
0005435150139	5284	74	18K
0005434824621	5284	75	19C
0005434828719	5284	76	19F
0005434824631	5284	77	19E
0005434824641	5284	78	19D
0005435373410	5284	79	19G
0005435373397	5284	80	19K
0005434824651	5284	81	20C
0005434824634	5284	82	20B
0005435373255	5284	83	20A
0005435373272	5284	84	20G
0005434828716	5284	85	20F
0005434558340	5284	86	20K
0005434824567	5284	87	20J
0005434824647	5284	88	20H
0005434824618	5284	89	21B
0005434824630	5284	90	21E
0005435373270	5284	91	21F
0005435373212	5284	92	21J
0005434824681	5284	93	21H
0005434824589	5284	94	22A
0005434824582	5284	95	21K
0005435373120	5284	96	22B
0005432121452	5284	97	22D
0005434824666	5284	98	22H
0005434824583	5284	99	22G
0005435735110	5284	100	22F
0005435373387	5284	101	22J
0005434558339	5284	102	23B
0005434824608	5284	103	22K
0005434824650	5284	104	23D
0005434824559	5284	105	23C
0005435150141	5284	106	23G
0005434824656	5284	107	23F
0005432121444	5284	108	23J
0005434824563	5284	109	24D
0005434824675	5284	110	23K
0005435373086	5284	111	24F
0005435150147	5284	112	24E
0005435150143	5284	113	25D
0005435373388	5284	114	25C
0005435150148	5284	115	25B
0005434824594	5284	116	25F
0005434824565	5284	117	25H
0005435373093	5284	118	25G
0005434824652	5284	119	26A
0005434824667	5284	120	26C
0005435373184	5284	121	26B
0005434824622	5284	122	26E
0005434824663	5284	123	26D
0005435373348	5284	124	26H
0005432121445	5284	125	26G
0005435386572	5284	126	26F
0005434824680	5284	127	26K
0005435373484	5284	128	26J
0005435373215	5284	129	27A
0005434824578	5284	130	27E
0005432121453	5284	131	27H
0005434824573	5284	132	27G
0005434824648	5284	133	28A
0005435661924	5284	134	27K
0005434824610	5284	135	27J
0005435373054	5284	136	28B
0005432823446	5284	137	28E
0005435372958	5284	138	28D
0005435735111	5284	139	28C
0005434824637	5284	140	28K
0005432394137	5284	141	28J
0005435373423	5284	142	28H
0005434824609	5284	143	29A
0005434824672	5284	144	29C
0005434824558	5284	145	29G
0005435373311	5284	146	29F
0005434558343	5284	147	29D
0005434824633	5284	148	29H
0005435373320	5284	149	30A
0005434824686	5284	150	29K
0005434824646	5284	151	30E
0005432823447	5284	152	30D
0005434824569	5284	153	30G
0005435372901	5284	154	30F
0005435373102	5284	155	30K
0005434831183	5284	156	31B
0005434824627	5284	157	31C
0005435373269	5284	158	31E
0005432396275	5284	159	31D
0005432121451	5284	160	31H
0005434824616	5284	161	31G
0005434824645	5284	162	32A
0005435373205	5284	163	31J
0005434824664	5284	164	32B
0005434824591	5284	165	32E
0005434558342	5284	166	32D
0005435179693	5284	167	32C
0005432396277	5284	168	32G
0005435735132	5284	169	32F
0005434824660	5284	170	32H
0005435373309	5284	171	33A
0005434824642	5284	172	32K
0005435150142	5284	173	33D
0005434824679	5284	174	33C
0005434824636	5284	175	33F
0005434824607	5284	176	33E
0005434824682	5284	177	33H
0005434824592	5284	178	33K
0005434824560	5284	179	33J
0005434824659	5284	180	34A
0005434824639	5284	181	34E
0005432121443	5284	182	34D
0005434824603	5284	183	34C
0005432121455	5284	184	34G
0005435373094	5284	185	34F
0005435150138	5284	186	34J
0005435373409	5284	187	34H
0005434824597	5284	188	35A
0005434824665	5284	189	35D
0005435373308	5284	190	35C
0005432394138	5284	191	35G
0005435304167	5284	192	35E
0005434824584	5284	193	35H
0005435304149	5284	194	36A
0005432121456	5284	195	35K
0005435373190	5284	196	36C
0005435373163	5284	197	36B
0005435386576	5284	198	36G
0005434824658	5284	199	36F
0005434824587	5284	200	36K
0005434824677	5284	201	36H
0005434824674	5284	202	37B
0005434824604	5284	203	37D
0005435373395	5284	204	37C
0005434824595	5284	205	37F
0005434824564	5284	206	37E
0005435373213	5284	207	37J
0005434824620	5284	208	37H
0005434828717	5284	209	37G
0005434824585	5284	210	37K
0005435373278	5284	211	38C
0005435373427	5284	212	38A
0005434824614	5284	213	38J
0005435386570	5284	214	39A
0005435373030	5284	215	38K
0005434824612	5284	216	39C
0005434831184	5284	217	39F
0005434824576	5284	218	39E
0005435373092	5284	219	39H
0005435373416	5284	220	40B
0005435373398	5284	221	40A
0005435373307	5284	222	40E
0005435372900	5284	223	40D
0005435150146	5284	224	40F
0005434558334	5284	225	40J
0005434558336	5284	226	41A
0005435373191	5284	227	40K
0005435373489	5284	228	41C
0005434824668	5284	229	41F
0005432121449	5284	230	41H
0005435373316	5284	231	41G
0005432121446	5284	232	42E
0005435373189	5284	233	42D
0005434824617	5284	234	42G
0005432121454	5284	235	42K
0005435373172	5284	236	42J
0005434824611	5284	237	42H
0005435373405	5284	238	43D
0005434824572	5284	239	43C
0005435179692	5284	240	43E
0005435373085	5284	241	43G
0005432823445	5284	242	43K
0005434824624	5284	243	44B
0005434824670	5284	244	44E
0005435373289	5284	245	44D
0005435150140	5284	246	44H
0005435373363	5284	247	44F
0005434824575	5284	248	44J
0005434828720	5284	249	45B
0005432121447	5284	250	45A
0005434664976	5284	251	45C
0005435373113	5284	252	45F
0005434824619	5284	253	45E
0005435373364	5284	254	45D
0005435373132	5284	255	45H
0005435299792	5284	256	45K
0005432823450	5284	257	46B
0005434824644	5284	258	46A
0005435373244	5284	259	46E
0005434828718	5284	260	46H
0005435150135	5284	261	46G
0005435150144	5284	262	46F
0005434824657	5284	263	47C
0005434558338	5284	264	47A
0005434824566	5284	265	46K
0005434824638	5284	266	47E
0005435373271	5284	267	47D
0005434824685	5284	268	47G
0005434831187	5284	269	47F
0005435373220	5284	270	48A
0005435373302	5284	271	47K
0005434824653	5284	272	47H
0005434824579	5284	273	48C
0005434558335	5284	274	48E
0005434824613	5284	275	48D
0005434824606	5284	276	48H
0005434824629	5284	277	48G
0005434831185	5284	278	49A
0005434824593	5284	279	48K
0005434824600	5284	280	49C
0005434824673	5284	281	49G
0005434824661	5284	282	49F
0005435304152	5284	283	49K
0005435373101	5284	284	49H
0005434824571	5284	285	50A
0005435373382	5284	286	50E
0005435373005	5284	287	50D
0005434558345	5284	288	50H
0005434824599	5284	289	50G
0005435372984	5284	290	50F
0005434824625	5284	291	50K
0005435373214	5284	292	51F
0005435386560	5284	293	51E
0005435373298	5284	294	51G
0005435373804	9909	1	1C
0005432203120	9909	2	1A
0005435373771	9909	3	1G
0005435373779	9909	4	1D
0005434664952	9909	5	2A
0005434823085	9909	6	1H
0005435373819	9909	7	2C
0005435373808	9909	8	2H
0005434823571	9909	9	2D
0005435373768	9909	10	3A
0005434823301	9909	11	3G
0005434824059	9909	12	3D
0005435735173	9909	13	3C
0005434824029	9909	14	4C
0005435302235	9909	15	4A
0005435373787	9909	16	4G
0005434823105	9909	17	4D
0005435373803	9909	18	4K
0005434823597	9909	19	4H
0005434823841	9909	20	5C
0005432396244	9909	21	5A
0005434823125	9909	22	5H
0005434823758	9909	23	5G
0005434823443	9909	24	5D
0005435386624	9909	25	5K
0005434823472	9909	26	11C
0005434823850	9909	27	11G
0005434823328	9909	28	11F
0005435373796	9909	29	11E
0005435373801	9909	30	11H
0005434823398	9909	31	12A
0005434823644	9909	32	12E
0005435735174	9909	33	12G
0005434823031	9909	34	12F
0005434558254	9909	35	13A
0005435373805	9909	36	12K
0005434558265	9909	37	13D
0005434823444	9909	38	13H
0005434823908	9909	39	13G
0005434823930	9909	40	13K
0005434823791	9909	41	14D
0005434823345	9909	42	14C
0005434823170	9909	43	14G
0005435373788	9909	44	14F
0005434558255	9909	45	14K
0005434823228	9909	46	14H
0005434823893	9909	47	15C
0005434823525	9909	48	15E
0005435735177	9909	49	15G
0005434823409	9909	50	15K
0005434823057	9909	51	15H
0005435373802	9909	52	16C
0005435373813	9909	53	16E
0005434823432	9909	54	16K
0005434558267	9909	55	16G
0005435150024	9909	56	17C
0005435373800	9909	57	17A
0005435386621	9909	58	17E
0005432400125	9909	59	17D
0005435373829	9909	60	17F
0005434558244	9909	61	18A
0005434823320	9909	62	17K
0005434823199	9909	63	18B
0005432400116	9909	64	18D
0005435373793	9909	65	18C
0005434823447	9909	66	18F
0005434823886	9909	67	18K
0005434823917	9909	68	18J
0005434823843	9909	69	18H
0005434823012	9909	70	19B
0005434824079	9909	71	19A
0005432203123	9909	72	19C
0005434823197	9909	73	19E
0005435661955	9909	74	19H
0005435386629	9909	75	19G
0005434823194	9909	76	20C
0005434823462	9909	77	20B
0005434823549	9909	78	20A
0005435373820	9909	79	20E
0005434823473	9909	80	20D
0005435373823	9909	81	20G
0005434823316	9909	82	20F
0005435373794	9909	83	20K
0005434823675	9909	84	21D
0005435661957	9909	85	21C
0005434823317	9909	86	21F
0005435299812	9909	87	21E
0005434823478	9909	88	21H
0005434823399	9909	89	21G
0005434823749	9909	90	22A
0005434823343	9909	91	21K
0005434823056	9909	92	22C
0005435373776	9909	93	22B
0005434823196	9909	94	22E
0005434823011	9909	95	22K
0005435373825	9909	96	22J
0005434823086	9909	97	23A
0005434823678	9909	98	23C
0005435373786	9909	99	23F
0005434558239	9909	100	23E
0005434823660	9909	101	23J
0005435302238	9909	102	23G
0005434823840	9909	103	23K
0005435149996	9909	104	24G
0005435373773	9909	105	24E
0005434823859	9909	106	25A
0005435373797	9909	107	25D
0005434823649	9909	108	25B
0005434823526	9909	109	25F
0005435373775	9909	110	25E
0005435150047	9909	111	25G
0005435661958	9909	112	25K
0005435302236	9909	113	25J
0005435373799	9909	114	26C
0005435373817	9909	115	26B
0005434823344	9909	116	26A
0005435373763	9909	117	26D
0005434831155	9909	118	26G
0005434831151	9909	119	26K
0005435373790	9909	120	26J
0005434823648	9909	121	26H
0005434823587	9909	122	27B
0005434823766	9909	123	27A
0005434831146	9909	124	27C
0005434823825	9909	125	27E
0005435373777	9909	126	27J
0005435373789	9909	127	27H
0005435386628	9909	128	27G
0005434823315	9909	129	27K
0005434823356	9909	130	28C
0005434823879	9909	131	28B
0005434823992	9909	132	28E
0005432396228	9909	133	28F
0005435373809	9909	134	28J
0005435373764	9909	135	29B
0005435373785	9909	136	29C
0005435150017	9909	137	29F
0005434831147	9909	138	29E
0005434823668	9909	139	29H
0005434823211	9909	140	29G
0005432400113	9909	141	29K
0005435373798	9909	142	29J
0005434823117	9909	143	30C
0005435373821	9909	144	30A
0005435735176	9909	145	30D
0005435373818	9909	146	30J
0005435149987	9909	147	30H
0005435299815	9909	148	31B
0005432396256	9909	149	31A
0005434823461	9909	150	30K
0005432400128	9909	151	31D
0005435373827	9909	152	31C
0005434823321	9909	153	31E
0005434823563	9909	154	31J
0005434823479	9909	155	31H
0005434823582	9909	156	31G
0005434831145	9909	157	32A
0005435386622	9909	158	32E
0005434823352	9909	159	32D
0005435373811	9909	160	32G
0005435386625	9909	161	32F
0005434823355	9909	162	32K
0005434823738	9909	163	32H
0005434823555	9909	164	33A
0005432400119	9909	165	33C
0005435373816	9909	166	33B
0005435373769	9909	167	33F
0005434823357	9909	168	33E
0005435373792	9909	169	33H
0005434823890	9909	170	33G
0005434823837	9909	171	33J
0005435150016	9909	172	34A
0005434823661	9909	173	34D
0005435373781	9909	174	34G
0005434823477	9909	175	34J
0005435373810	9909	176	35B
0005434823581	9909	177	35A
0005432823467	9909	178	35E
0005434823943	9909	179	35G
0005434558266	9909	180	36A
0005434823470	9909	181	36C
0005434823016	9909	182	36B
0005434823257	9909	183	36H
0005434558229	9909	184	36K
0005435373815	9909	185	36J
0005435373784	9909	186	37A
0005434822749	9909	187	37D
0005435373770	9909	188	37F
0005434823002	9909	189	37J
0005434823561	9909	190	37H
0005432203124	9909	191	37G
0005434823564	9909	192	38A
0005434823488	9909	193	37K
0005432203125	9909	194	38C
0005435373765	9909	195	38B
0005434824158	9909	196	38J
0005434824159	9909	197	38H
0005434828696	9909	198	39B
0005435373822	9909	199	39A
0005434823643	9909	200	38K
0005434823459	9909	201	39D
0005434823131	9909	202	39C
0005434823669	9909	203	39F
0005435386623	9909	204	39E
0005435373772	9909	205	39J
0005434823765	9909	206	39H
0005434823471	9909	207	40A
0005434823907	9909	208	40C
0005435373795	9909	209	40E
0005435735178	9909	210	40G
0005435373783	9909	211	40J
0005435373767	9909	212	40H
0005434823463	9909	213	41B
0005434823374	9909	214	41A
0005434823708	9909	215	41D
0005434823562	9909	216	41C
0005434823403	9909	217	41F
0005435299813	9909	218	41E
0005434823767	9909	219	41H
0005434823611	9909	220	42C
0005432400124	9909	221	42B
0005435373828	9909	222	42E
0005432400130	9909	223	42G
0005434824172	9909	224	42F
0005434823327	9909	225	43A
0005435373778	9909	226	43D
0005435150019	9909	227	43B
0005435299816	9909	228	43E
0005432400129	9909	229	43G
0005434823503	9909	230	44A
0005434823351	9909	231	43K
0005435373782	9909	232	43J
0005435373791	9909	233	44C
0005434823150	9909	234	44D
0005435373780	9909	235	44G
0005434824032	9909	236	44J
0005434823363	9909	237	44H
0005434822999	9909	238	45B
0005434823054	9909	239	45A
0005434823319	9909	240	45C
0005434823030	9909	241	45H
0005434823785	9909	242	46C
0005434823402	9909	243	46B
0005435373807	9909	244	46A
0005434823860	9909	245	46E
0005434823322	9909	246	46D
0005435373766	9909	247	46G
0005435661954	9909	248	46F
0005435302237	9909	249	46K
0005434823617	9909	250	46J
0005434823201	9909	251	46H
0005432203126	9909	252	47A
0005434823931	9909	253	47D
0005434823891	9909	254	47G
0005434823418	9909	255	47E
0005435373826	9909	256	48A
0005435386627	9909	257	47K
0005434823500	9909	258	48D
0005435373774	9909	259	48C
0005435373806	9909	260	48E
0005435735175	9909	261	48H
0005434823586	9909	262	48F
0005434823662	9909	263	49A
0005432203122	9909	264	48K
0005434823529	9909	265	49D
0005435661956	9909	266	49C
0005435373824	9909	267	49F
0005434828700	9909	268	49K
0005435299814	9909	269	49H
0005434823390	9909	270	50C
0005435373812	9909	271	50A
0005432203121	9909	272	50G
0005435373814	9909	273	50K
0005434823679	9909	274	50H
0005434823658	9909	275	51F
0005435386626	9909	276	51E
0005435790329	6993	1	2D
0005435082852	6993	2	3B
0005435082854	6993	3	4A
0005435082853	6993	4	4C
0005435082855	6993	5	5D
0005435790330	6993	6	18C
0005435082851	6993	7	19D
0005435790331	6993	8	20D
0005435082856	6993	9	22C
0005435082741	26001	1	1B
0005435082766	26001	2	2C
0005435082764	26001	3	5A
0005435082746	26001	4	5D
0005435082767	26001	5	6A
0005435082745	26001	6	6C
0005435082743	26001	7	18C
0005435082776	26001	8	19A
0005435790303	26001	9	20B
0005435790315	26001	10	22A
0005434214633	9568	1	1A
0005434214473	9568	2	1C
0005434756782	9568	3	1D
0005434214599	9568	4	1F
0005434756766	9568	5	2A
0005434214423	9568	6	2C
0005434756779	9568	7	2D
0005434756764	9568	8	2F
0005434214479	9568	9	3A
0005434214354	9568	10	3C
0005434214214	9568	11	3D
0005434214398	9568	12	3F
0005434214536	9568	13	4A
0005434214480	9568	14	4C
0005434756778	9568	15	4D
0005434756763	9568	16	4E
0005434214326	9568	17	4F
0005434214327	9568	18	5C
0005434756762	9568	19	5D
0005434214353	9568	20	5E
0005434756781	9568	21	5F
0005434756759	9568	22	6A
0005434214443	9568	23	6C
0005434756756	9568	24	6D
0005434214627	9568	25	6E
0005434214376	9568	26	6F
0005434756757	9568	27	7A
0005434756783	9568	28	7C
0005434214433	9568	29	7D
0005434214352	9568	30	7E
0005434756765	9568	31	7F
0005434756786	9568	32	8A
0005434756780	9568	33	8C
0005434214634	9568	34	8D
0005434214598	9568	35	8E
0005434214397	9568	36	8F
0005434756771	9568	37	9A
0005434214517	9568	38	9C
0005434756784	9568	39	9D
0005434756748	9568	40	9E
0005434214556	9568	41	9F
0005434214379	9568	42	10A
0005434756753	9568	43	10C
0005434756769	9568	44	10D
0005434214594	9568	45	10E
0005434756760	9568	46	11A
0005434756761	9568	47	10F
0005434756755	9568	48	11C
0005434214555	9568	49	11D
0005434756758	9568	50	11E
0005434214333	9568	51	12A
0005434214442	9568	52	12C
0005434756750	9568	53	12D
0005434214332	9568	54	12E
0005434756772	9568	55	12F
0005434214612	9568	56	13A
0005434214533	9568	57	13C
0005434756747	9568	58	13D
0005434214474	9568	59	13E
0005434756752	9568	60	13F
0005434214489	9568	61	14A
0005434756775	9568	62	14C
0005434756767	9568	63	14D
0005434214476	9568	64	14E
0005434756774	9568	65	14F
0005434756785	9568	66	15A
0005434214470	9568	67	15C
0005434756773	9568	68	15D
0005434214377	9568	69	15E
0005434214561	9568	70	15F
0005434214515	9568	71	16A
0005434214298	9568	72	16C
0005434756749	9568	73	16D
0005434756777	9568	74	16E
0005434214478	9568	75	16F
0005434756754	9568	76	17A
0005434756776	9568	77	17C
0005434214537	9568	78	17D
0005434214539	9568	79	17E
0005434214426	9568	80	17F
0005434214554	9568	81	18A
0005434214227	9568	82	18C
0005434214445	9568	83	18D
0005434214607	9568	84	18E
0005434756768	9568	85	18F
0005434214366	9568	86	19A
0005434214680	9568	87	19C
0005434214421	9568	88	19D
0005434214320	9568	89	19E
0005434756770	9568	90	19F
0005434214512	9568	91	20A
0005434214355	9568	92	20C
0005434214558	9568	93	20D
0005434214420	9568	94	20E
0005434756751	9568	95	20F
0005434214848	28645	1	1A
0005434214863	28645	2	1C
0005434214841	28645	3	1D
0005434214868	28645	4	2A
0005434756328	28645	5	2C
0005434214864	28645	6	3A
0005434756342	28645	7	3C
0005434214849	28645	8	3D
0005434214881	28645	9	3F
0005434756279	28645	10	4A
0005434214879	28645	11	4C
0005434756223	28645	12	4D
0005434214857	28645	13	4E
0005434756260	28645	14	4F
0005434214886	28645	15	5A
0005434214856	28645	16	5C
0005434214847	28645	17	5D
0005434214876	28645	18	5E
0005434756347	28645	19	5F
0005434214854	28645	20	6A
0005434756236	28645	21	6C
0005434756249	28645	22	6D
0005434756365	28645	23	6E
0005434214873	28645	24	7A
0005434756218	28645	25	7C
0005434756287	28645	26	7D
0005434756266	28645	27	7E
0005434214844	28645	28	7F
0005434756222	28645	29	8A
0005434214853	28645	30	8C
0005434756324	28645	31	8D
0005434756259	28645	32	8E
0005434214862	28645	33	8F
0005434214850	28645	34	9A
0005434214855	28645	35	9C
0005434214885	28645	36	9D
0005434756271	28645	37	9E
0005434756280	28645	38	9F
0005434756302	28645	39	10A
0005434214846	28645	40	10C
0005434756248	28645	41	10E
0005434214840	28645	42	10F
0005434756391	28645	43	11A
0005434214887	28645	44	11C
0005434214858	28645	45	11E
0005434214851	28645	46	11F
0005434756341	28645	47	12C
0005434756160	28645	48	12D
0005434756394	28645	49	12E
0005434756315	28645	50	12F
0005434756288	28645	51	13A
0005434214861	28645	52	13C
0005434756325	28645	53	13D
0005434214860	28645	54	13E
0005434756219	28645	55	13F
0005434214882	28645	56	14A
0005434214843	28645	57	14C
0005434214884	28645	58	14E
0005434214859	28645	59	14F
0005434214875	28645	60	15A
0005434214872	28645	61	15C
0005434214865	28645	62	15D
0005434756299	28645	63	15E
0005434756395	28645	64	15F
0005434756209	28645	65	16A
0005434214880	28645	66	16D
0005434214883	28645	67	16E
0005434214870	28645	68	16F
0005434214842	28645	69	17C
0005434756221	28645	70	17D
0005434756295	28645	71	17E
0005434214874	28645	72	17F
0005434756314	28645	73	18A
0005434214852	28645	74	18C
0005434214867	28645	75	18E
0005434214869	28645	76	18F
0005434214871	28645	77	19A
0005434756397	28645	78	19D
0005434214866	28645	79	19E
0005434214878	28645	80	19F
0005434214845	28645	81	20A
0005434756296	28645	82	20D
0005434756364	28645	83	20E
0005434214877	28645	84	20F
0005435100148	10850	1	3B
0005434760187	10850	2	4C
0005435100147	10850	3	6C
0005435100146	10850	4	6D
0005434760186	10850	5	18C
0005434760185	10850	6	19C
0005434760217	31842	1	18A
0005434760218	31842	2	21A
0005433202330	1990	1	1A
0005434639526	1990	2	1B
0005434639534	1990	3	1C
0005433202322	1990	4	1D
0005434639537	1990	5	2A
0005434639547	1990	6	2B
0005434639532	1990	7	2C
0005434639535	1990	8	2D
0005433202343	1990	9	3B
0005434639539	1990	10	3C
0005434639544	1990	11	3D
0005434639522	1990	12	4A
0005434639542	1990	13	4B
0005434639538	1990	14	4C
0005434639546	1990	15	5A
0005433202319	1990	16	5B
0005434639524	1990	17	5C
0005434639531	1990	18	5D
0005433202383	1990	19	6B
0005433202346	1990	20	6C
0005435948335	1990	21	6D
0005434639541	1990	22	7A
0005434639525	1990	23	7C
0005435948334	1990	24	7D
0005432290658	1990	25	18A
0005433202435	1990	26	18B
0005434639523	1990	27	18C
0005434639543	1990	28	18D
0005433202331	1990	29	19A
0005434639533	1990	30	19B
0005434639545	1990	31	19C
0005434639536	1990	32	19D
0005434639548	1990	33	20A
0005432290659	1990	34	20B
0005435948336	1990	35	20C
0005433202334	1990	36	20D
0005433202329	1990	37	21A
0005434639528	1990	38	21B
0005434639540	1990	39	21D
0005433202436	1990	40	21C
0005433202318	1990	41	22A
0005434639529	1990	42	22B
0005432290660	1990	43	22C
0005434639530	1990	44	22D
0005433202338	1990	45	23A
0005434639527	1990	46	23B
0005433202478	23261	1	1B
0005433202471	23261	2	1C
0005433202468	23261	3	2A
0005434639308	23261	4	2B
0005434639248	23261	5	2C
0005434639159	23261	6	3A
0005434639289	23261	7	3B
0005434639131	23261	8	3C
0005433202467	23261	9	3D
0005433202476	23261	10	4A
0005433202464	23261	11	4B
0005434639157	23261	12	4D
0005433202474	23261	13	5A
0005433202466	23261	14	5C
0005434639218	23261	15	6B
0005433202477	23261	16	6D
0005433202470	23261	17	7A
0005433202472	23261	18	7B
0005434639246	23261	19	7C
0005433202469	23261	20	18A
0005434639247	23261	21	18B
0005433202465	23261	22	18D
0005433202475	23261	23	19B
0005434639236	23261	24	19D
0005434639307	23261	25	20D
0005434639166	23261	26	21B
0005434639288	23261	27	21D
0005433202473	23261	28	22B
0005434639258	23261	29	22C
0005434639232	23261	30	22D
0005434639132	23261	31	23A
0005434639158	23261	32	23B
0005435326722	6044	1	1A
0005434601017	6044	2	2A
0005433531324	6044	3	2C
0005434601028	6044	4	2F
0005434601018	6044	5	3C
0005434601037	6044	6	3D
0005433533338	6044	7	4D
0005434601043	6044	8	4E
0005434601023	6044	9	5A
0005434601016	6044	10	5D
0005432111304	6044	11	5E
0005435326773	6044	12	5F
0005434601041	6044	13	6A
0005434601021	6044	14	6D
0005432111303	6044	15	7C
0005434601020	6044	16	7E
0005434601029	6044	17	8D
0005435326748	6044	18	8F
0005435326720	6044	19	9C
0005434601038	6044	20	9D
0005434601026	6044	21	10C
0005434601025	6044	22	11A
0005435326721	6044	23	11D
0005434601035	6044	24	11F
0005434601024	6044	25	12A
0005433533340	6044	26	12E
0005435326761	6044	27	13A
0005434601042	6044	28	13C
0005434601034	6044	29	13E
0005435326774	6044	30	13F
0005433533339	6044	31	14A
0005434601019	6044	32	14E
0005434601031	6044	33	15A
0005433531325	6044	34	15D
0005434601039	6044	35	16A
0005435326749	6044	36	16C
0005435326698	6044	37	17A
0005434601027	6044	38	17E
0005434601040	6044	39	18A
0005432111305	6044	40	18D
0005434601036	6044	41	19A
0005434601022	6044	42	19C
0005434601032	6044	43	19E
0005435326699	6044	44	20D
0005434601030	6044	45	20C
0005434601033	6044	46	20E
0005435326730	6044	47	20F
0005435326864	18578	1	1A
0005435326855	18578	2	1C
0005434600845	18578	3	1F
0005435326859	18578	4	2A
0005435326861	18578	5	2D
0005434600808	18578	6	2F
0005434600876	18578	7	3C
0005435326858	18578	8	3F
0005435326854	18578	9	4E
0005434600886	18578	10	4F
0005434600787	18578	11	5C
0005434600785	18578	12	5E
0005435326853	18578	13	5F
0005434600638	18578	14	6C
0005434600958	18578	15	7A
0005434600670	18578	16	7C
0005434600627	18578	17	7F
0005433531282	18578	18	8D
0005434600887	18578	19	8F
0005434600807	18578	20	9A
0005435326856	18578	21	9C
0005434600821	18578	22	9D
0005434600848	18578	23	9E
0005434600781	18578	24	9F
0005433531278	18578	25	10E
0005434600844	18578	26	10F
0005434600796	18578	27	11A
0005434600764	18578	28	11C
0005434600741	18578	29	12E
0005434600797	18578	30	12F
0005434600854	18578	31	13D
0005433527253	18578	32	13E
0005434600885	18578	33	14A
0005435326857	18578	34	15A
0005434600855	18578	35	15E
0005433527252	18578	36	16D
0005434600784	18578	37	16F
0005435326865	18578	38	17E
0005434600776	18578	39	17F
0005433531291	18578	40	18A
0005435326863	18578	41	18C
0005435326862	18578	42	18E
0005434600850	18578	43	19A
0005434600671	18578	44	19C
0005435326860	18578	45	19F
0005434551611	10607	1	1A
0005433180913	10607	2	1C
0005434551638	10607	3	1D
0005433181063	10607	4	1F
0005433181155	10607	5	2A
0005434551656	10607	6	2C
0005434551626	10607	7	2D
0005434551644	10607	8	2F
0005434551606	10607	9	3A
0005434551634	10607	10	3D
0005434551652	10607	11	3F
0005434551653	10607	12	4A
0005433181062	10607	13	4C
0005433181086	10607	14	4D
0005433181053	10607	15	4E
0005433181110	10607	16	4F
0005434551643	10607	17	5A
0005433181040	10607	18	5C
0005433181001	10607	19	5D
0005433181153	10607	20	5E
0005433181068	10607	21	5F
0005434551645	10607	22	6A
0005434551640	10607	23	6C
0005434551629	10607	24	6D
0005433181019	10607	25	6E
0005434551630	10607	26	6F
0005434551650	10607	27	7A
0005433181075	10607	28	7C
0005434551639	10607	29	7D
0005433181015	10607	30	7E
0005434551654	10607	31	7F
0005433181137	10607	32	8A
0005433181012	10607	33	8C
0005433181013	10607	34	8D
0005434551623	10607	35	8E
0005434551607	10607	36	8F
0005434551622	10607	37	9A
0005433181109	10607	38	9C
0005434551624	10607	39	9D
0005434551657	10607	40	9E
0005433181007	10607	41	9F
0005434551618	10607	42	10A
0005433181118	10607	43	10C
0005434551633	10607	44	10D
0005434551625	10607	45	10E
0005433181085	10607	46	10F
0005434551612	10607	47	11A
0005434551641	10607	48	11C
0005433181128	10607	49	11D
0005434551646	10607	50	11E
0005433181154	10607	51	11F
0005433181000	10607	52	12A
0005433181055	10607	53	12C
0005433180914	10607	54	12D
0005434551617	10607	55	12E
0005434551627	10607	56	12F
0005433181119	10607	57	13C
0005434551609	10607	58	13A
0005433181016	10607	59	13D
0005434551616	10607	60	13E
0005433181129	10607	61	13F
0005434551655	10607	62	14A
0005434551628	10607	63	14C
0005434551631	10607	64	14D
0005434551614	10607	65	14E
0005434551608	10607	66	14F
0005433181052	10607	67	15A
0005433181067	10607	68	15C
0005434551615	10607	69	15D
0005434551605	10607	70	15E
0005433181024	10607	71	15F
0005433181120	10607	72	16A
0005434551636	10607	73	16D
0005433181117	10607	74	16C
0005434551635	10607	75	16E
0005434551637	10607	76	16F
0005434551651	10607	77	17A
0005433181138	10607	78	17C
0005433180925	10607	79	17D
0005434551620	10607	80	17E
0005434551610	10607	81	17F
0005433181018	10607	82	18A
0005434551649	10607	83	18C
0005434551642	10607	84	18D
0005434551632	10607	85	18E
0005433181041	10607	86	18F
0005433181111	10607	87	19A
0005434551647	10607	88	19C
0005434551613	10607	89	19D
0005434551619	10607	90	19E
0005434551621	10607	91	19F
0005433181198	10607	92	20A
0005433181197	10607	93	20C
0005433181051	10607	94	20D
0005434551648	10607	95	20E
0005433181094	10607	96	20F
0005433181308	27686	1	1D
0005433181316	27686	2	3A
0005433181313	27686	3	3C
0005433181299	27686	4	3F
0005433181302	27686	5	4A
0005433181311	27686	6	4E
0005433181306	27686	7	5A
0005433181318	27686	8	6C
0005433181300	27686	9	7F
0005433181307	27686	10	8E
0005433181309	27686	11	10F
0005433181317	27686	12	11E
0005433181305	27686	13	12E
0005433181310	27686	14	13E
0005433181319	27686	15	15A
0005433181298	27686	16	15E
0005433181303	27686	17	16A
0005433181301	27686	18	17A
0005433181297	27686	19	17D
0005433181315	27686	20	17F
0005433181314	27686	21	18A
0005433181312	27686	22	18F
0005433181304	27686	23	19C
0005433181296	27686	24	20D
0005434551355	27685	1	1A
0005434551133	27685	2	1C
0005434551258	27685	3	2C
0005434558269	27685	4	2D
0005434551124	27685	5	3C
0005434551235	27685	6	3D
0005434551128	27685	7	3F
0005434558248	27685	8	4A
0005434551287	27685	9	4C
0005434551247	27685	10	4D
0005434551342	27685	11	5A
0005434551431	27685	12	5D
0005434551323	27685	13	5E
0005434558268	27685	14	5F
0005434558252	27685	15	6A
0005434551234	27685	16	6C
0005434551348	27685	17	6F
0005434558251	27685	18	7C
0005434558253	27685	19	7E
0005434558273	27685	20	7F
0005434551310	27685	21	8A
0005434551294	27685	22	8C
0005434551103	27685	23	8D
0005434551213	27685	24	8E
0005434551232	27685	25	8F
0005434551209	27685	26	9A
0005434558272	27685	27	9D
0005434551003	27685	28	9E
0005434551129	27685	29	9F
0005434551221	27685	30	10D
0005434551014	27685	31	11A
0005434551296	27685	32	11C
0005434551297	27685	33	11D
0005434551130	27685	34	12A
0005434558271	27685	35	12E
0005434551027	27685	36	12F
0005434551372	27685	37	13A
0005434558262	27685	38	13C
0005434551165	27685	39	13E
0005434551255	27685	40	13F
0005434551223	27685	41	14A
0005434550881	27685	42	14E
0005434554058	27685	43	15A
0005434558261	27685	44	15C
0005434551210	27685	45	15F
0005434551125	27685	46	16A
0005434551172	27685	47	16C
0005434551171	27685	48	16F
0005434558270	27685	49	17C
0005434551236	27685	50	17D
0005434551204	27685	51	17E
0005434551222	27685	52	17F
0005434551373	27685	53	18A
0005434551286	27685	54	18C
0005434554069	27685	55	18D
0005434551170	27685	56	18E
0005434551257	27685	57	19E
0005434551256	27685	58	19F
0005434551134	27685	59	20A
0005434551354	27685	60	20C
0005433459252	6160	1	1A
0005433459253	6160	2	2B
0005433459254	6160	3	3A
0005433459255	6160	4	4A
0005433459256	6160	5	5B
0005435254493	19299	1	1A
0005435254496	19299	2	1B
0005435254495	19299	3	2A
0005435254494	19299	4	2B
0005433459228	19299	5	3A
0005433459226	19299	6	4A
0005433459227	19299	7	4B
0005435682454	6738	1	1A
0005435682475	6738	2	1C
0005435682480	6738	3	1D
0005435682484	6738	4	1F
0005435437909	6738	5	2A
0005432136209	6738	6	2C
0005435682477	6738	7	2D
0005435437955	6738	8	2F
0005435682455	6738	9	3A
0005435437913	6738	10	3C
0005434828695	6738	11	3F
0005435682459	6738	12	4A
0005434828693	6738	13	4C
0005435682465	6738	14	4D
0005435438016	6738	15	4E
0005435217710	6738	16	4F
0005435437920	6738	17	5A
0005435682469	6738	18	5C
0005432136207	6738	19	5E
0005435630989	6738	20	5F
0005432136210	6738	21	6A
0005435630988	6738	22	6C
0005435217711	6738	23	6E
0005435682472	6738	24	6F
0005434828692	6738	25	7A
0005435437985	6738	26	7C
0005432533282	6738	27	7F
0005435220316	6738	28	8A
0005432533284	6738	29	8C
0005435682474	6738	30	8D
0005435682479	6738	31	9A
0005435437914	6738	32	9C
0005435437901	6738	33	9D
0005435682458	6738	34	9E
0005435437964	6738	35	9F
0005435682476	6738	36	10A
0005435437940	6738	37	10C
0005435437921	6738	38	10D
0005435682473	6738	39	10E
0005435437990	6738	40	10F
0005435682467	6738	41	11A
0005435437963	6738	42	11C
0005432136208	6738	43	11D
0005435661952	6738	44	11E
0005435437916	6738	45	11F
0005432136211	6738	46	12A
0005432533283	6738	47	12C
0005435682471	6738	48	12E
0005435661953	6738	49	12F
0005435437948	6738	50	13A
0005435437971	6738	51	13C
0005435682483	6738	52	13D
0005435682482	6738	53	13E
0005435437989	6738	54	13F
0005435630990	6738	55	14A
0005435682460	6738	56	14C
0005435437954	6738	57	14D
0005435682457	6738	58	14E
0005435217709	6738	59	14F
0005435682478	6738	60	15C
0005435217708	6738	61	15D
0005434828694	6738	62	15E
0005435438021	6738	63	15F
0005435682464	6738	64	16A
0005435682461	6738	65	16C
0005435438020	6738	66	16D
0005435437996	6738	67	16E
0005435437982	6738	68	16F
0005435682481	6738	69	17A
0005432136212	6738	70	17D
0005435221516	6738	71	17E
0005435682462	6738	72	18A
0005435437988	6738	73	18C
0005435682468	6738	74	18E
0005435682456	6738	75	18F
0005435682463	6738	76	19A
0005435220317	6738	77	19C
0005435437981	6738	78	19E
0005435437960	6738	79	19F
0005435682470	6738	80	20A
0005434828691	6738	81	20C
0005435682466	6738	82	20D
0005435437962	6738	83	20F
0005435438141	24616	1	1A
0005435682135	24616	2	1C
0005435438126	24616	3	1D
0005435682087	24616	4	1F
0005435681854	24616	5	2A
0005435438128	24616	6	2C
0005435438124	24616	7	2D
0005435681855	24616	8	2F
0005435438136	24616	9	3A
0005435682129	24616	10	3D
0005435682238	24616	11	3F
0005435681922	24616	12	4A
0005432305768	24616	13	4C
0005435682102	24616	14	4D
0005435681967	24616	15	4E
0005435438121	24616	16	4F
0005435438138	24616	17	5A
0005435661935	24616	18	5C
0005435682057	24616	19	5E
0005435682069	24616	20	5F
0005435682242	24616	21	6A
0005435682198	24616	22	6C
0005435682228	24616	23	6D
0005435438140	24616	24	6E
0005435661925	24616	25	7D
0005435682221	24616	26	7E
0005435682220	24616	27	7F
0005435682070	24616	28	8C
0005435681856	24616	29	8D
0005435681961	24616	30	8F
0005435682151	24616	31	9A
0005435682196	24616	32	9C
0005432533315	24616	33	9D
0005435682128	24616	34	9E
0005435719566	24616	35	9F
0005435661918	24616	36	10A
0005435438142	24616	37	10C
0005435438133	24616	38	10E
0005435682042	24616	39	10F
0005435682134	24616	40	11A
0005435682259	24616	41	11C
0005435438129	24616	42	11D
0005435661928	24616	43	11E
0005435438137	24616	44	11F
0005435438125	24616	45	12A
0005435682041	24616	46	12C
0005435681861	24616	47	12D
0005432533316	24616	48	12E
0005435438139	24616	49	12F
0005435682237	24616	50	13A
0005435682028	24616	51	13C
0005435682122	24616	52	13D
0005435438131	24616	53	13E
0005435438123	24616	54	13F
0005435682091	24616	55	14A
0005435682100	24616	56	14C
0005432305769	24616	57	14D
0005435682068	24616	58	14E
0005435682088	24616	59	14F
0005435682121	24616	60	15A
0005435438134	24616	61	15C
0005435682224	24616	62	15D
0005435630961	24616	63	15E
0005435682244	24616	64	15F
0005435682120	24616	65	16A
0005434828721	24616	66	16C
0005435438130	24616	67	16D
0005435681859	24616	68	16E
0005435630960	24616	69	17A
0005435438132	24616	70	16F
0005435682169	24616	71	17C
0005435682164	24616	72	17D
0005435682140	24616	73	17E
0005432533314	24616	74	17F
0005435681883	24616	75	18C
0005435438127	24616	76	18D
0005435682116	24616	77	18F
0005435682090	24616	78	19C
0005435681905	24616	79	19D
0005435682103	24616	80	19E
0005435682056	24616	81	19F
0005435682138	24616	82	20A
0005435681882	24616	83	20C
0005435438135	24616	84	20D
0005435682170	24616	85	20E
0005435438122	24616	86	20F
0005435126679	11547	1	1A
0005435126684	11547	2	1D
0005435126648	11547	3	2A
0005435126660	11547	4	2C
0005435126653	11547	5	2F
0005435126670	11547	6	3D
0005435126666	11547	7	3F
0005435126650	11547	8	4D
0005435126669	11547	9	4F
0005435126647	11547	10	5A
0005435558083	11547	11	6A
0005435126654	11547	12	6C
0005435126681	11547	13	7C
0005435126661	11547	14	7D
0005435126662	11547	15	7E
0005435098571	11547	16	7F
0005435098574	11547	17	8A
0005435098572	11547	18	8C
0005435126683	11547	19	8D
0005435126682	11547	20	8E
0005435126676	11547	21	8F
0005435126663	11547	22	9A
0005435126646	11547	23	9C
0005435126671	11547	24	10A
0005435126672	11547	25	10C
0005435126664	11547	26	10F
0005435126674	11547	27	11E
0005435126651	11547	28	12A
0005435126649	11547	29	12D
0005435126655	11547	30	12E
0005435106006	11547	31	13A
0005435126678	11547	32	13C
0005435126686	11547	33	13E
0005435126667	11547	34	14D
0005435126665	11547	35	14E
0005435126652	11547	36	15A
0005435126657	11547	37	15C
0005435126673	11547	38	15D
0005435126675	11547	39	16A
0005435126677	11547	40	16F
0005435098570	11547	41	17C
0005435126668	11547	42	17E
0005435098573	11547	43	18A
0005435126659	11547	44	18E
0005435126687	11547	45	19A
0005435106004	11547	46	19D
0005435126656	11547	47	19E
0005435126680	11547	48	19F
0005435126658	11547	49	20A
0005435098575	11547	50	20C
0005435126685	11547	51	20D
0005435106005	11547	52	20E
0005435126562	31853	1	1C
0005435126395	31853	2	1D
0005435126421	31853	3	2A
0005435126384	31853	4	2F
0005435126519	31853	5	3A
0005435126520	31853	6	3C
0005435126391	31853	7	3F
0005435126256	31853	8	4A
0005435126275	31853	9	4C
0005435126353	31853	10	4D
0005435126361	31853	11	4E
0005435126306	31853	12	5A
0005435126561	31853	13	5E
0005435105973	31853	14	5F
0005435126468	31853	15	6A
0005435126334	31853	16	6E
0005435126419	31853	17	7A
0005435126286	31853	18	7D
0005435126251	31853	19	8A
0005435126452	31853	20	8C
0005435126366	31853	21	8D
0005435126555	31853	22	8E
0005435126385	31853	23	9D
0005435126326	31853	24	9E
0005435126372	31853	25	9F
0005435126346	31853	26	10A
0005435126276	31853	27	10D
0005435126453	31853	28	11A
0005435126531	31853	29	11C
0005435105974	31853	30	11D
0005435126258	31853	31	11E
0005435126416	31853	32	12A
0005435126325	31853	33	12C
0005435126274	31853	34	12D
0005435105972	31853	35	12F
0005435558107	31853	36	13A
0005435126324	31853	37	13D
0005435126347	31853	38	14A
0005435126259	31853	39	14D
0005435126321	31853	40	14E
0005435126438	31853	41	14F
0005435126075	31853	42	15C
0005435126396	31853	43	15D
0005435126492	31853	44	15F
0005435126554	31853	45	16A
0005435126210	31853	46	16C
0005435126532	31853	47	16D
0005435126407	31853	48	16E
0005435126397	31853	49	17D
0005435126371	31853	50	17E
0005435558108	31853	51	17F
0005435126333	31853	52	18A
0005435126365	31853	53	19A
0005435126467	31853	54	19C
0005435126340	31853	55	19E
0005435558110	31853	56	20A
0005435126422	31853	57	20D
0005435558109	31853	58	20F
0005433398427	13510	1	1C
0005433398421	13510	2	2A
0005433398443	13510	3	2C
0005433398467	13510	4	2D
0005433398455	13510	5	2F
0005433398460	13510	6	3A
0005433398444	13510	7	3C
0005433398469	13510	8	4D
0005433398447	13510	9	4E
0005433398439	13510	10	5A
0005433398454	13510	11	5D
0005433398452	13510	12	5E
0005433398450	13510	13	5F
0005433398435	13510	14	6A
0005435732352	13510	15	6C
0005433398456	13510	16	6E
0005433398457	13510	17	6F
0005435732327	13510	18	7C
0005433398437	13510	19	7E
0005433398422	13510	20	7F
0005433398423	13510	21	8C
0005433398438	13510	22	8F
0005433398459	13510	23	9A
0005433398430	13510	24	9C
0005435732363	13510	25	9E
0005433398441	13510	26	9F
0005433398434	13510	27	10C
0005433398462	13510	28	10E
0005433398431	13510	29	10F
0005435732318	13510	30	11D
0005435732285	13510	31	11E
0005433398445	13510	32	11F
0005433398464	13510	33	12C
0005433398429	13510	34	12F
0005433398461	13510	35	13A
0005433398432	13510	36	13D
0005433398451	13510	37	13E
0005433398428	13510	38	13F
0005435732321	13510	39	14C
0005433398466	13510	40	14D
0005433398433	13510	41	14E
0005433398425	13510	42	14F
0005433398442	13510	43	15A
0005433398465	13510	44	15C
0005435732319	13510	45	15E
0005433398448	13510	46	16A
0005433398446	13510	47	16D
0005435732345	13510	48	16E
0005433398453	13510	49	16F
0005433398458	13510	50	17A
0005433398440	13510	51	17E
0005433398470	13510	52	18A
0005433398424	13510	53	18D
0005433398463	13510	54	18E
0005435732328	13510	55	19A
0005433398436	13510	56	19C
0005433398468	13510	57	19E
0005433398426	13510	58	20C
0005435732322	13510	59	20E
0005433398449	13510	60	20F
0005433397847	19372	1	1A
0005433397784	19372	2	1C
0005433398096	19372	3	2D
0005433398041	19372	4	2F
0005433398009	19372	5	3A
0005435732428	19372	6	3C
0005433398002	19372	7	3D
0005433397942	19372	8	3F
0005433397995	19372	9	4A
0005433398086	19372	10	4C
0005433398155	19372	11	4E
0005433397957	19372	12	4F
0005433397876	19372	13	5A
0005433398253	19372	14	5C
0005435732427	19372	15	5D
0005435732438	19372	16	5E
0005433397956	19372	17	6C
0005433398075	19372	18	6D
0005433398090	19372	19	6E
0005433398042	19372	20	7A
0005435732437	19372	21	7E
0005435732422	19372	22	7F
0005433398251	19372	23	8A
0005433397827	19372	24	8C
0005435732440	19372	25	8D
0005435732436	19372	26	8F
0005433398003	19372	27	9A
0005435732430	19372	28	9C
0005433397880	19372	29	9E
0005433398055	19372	30	9F
0005433398122	19372	31	10D
0005433398008	19372	32	10E
0005435732431	19372	33	11C
0005435732420	19372	34	11D
0005433398065	19372	35	11F
0005433398091	19372	36	12A
0005433398234	19372	37	12D
0005433397965	19372	38	12F
0005435732423	19372	39	13C
0005433397941	19372	40	13E
0005433398006	19372	41	13F
0005435732425	19372	42	14C
0005433397859	19372	43	14D
0005435732421	19372	44	14E
0005433398142	19372	45	14F
0005433398252	19372	46	15A
0005435732429	19372	47	15D
0005435732433	19372	48	15E
0005433398007	19372	49	15F
0005435732435	19372	50	16A
0005435732424	19372	51	16C
0005433398233	19372	52	16D
0005433398235	19372	53	16E
0005433397902	19372	54	17A
0005435732426	19372	55	17C
0005433398076	19372	56	17D
0005435732439	19372	57	17E
0005433398054	19372	58	18C
0005433398021	19372	59	18D
0005433397882	19372	60	18E
0005433398123	19372	61	18F
0005433398056	19372	62	19A
0005433398143	19372	63	19C
0005433398092	19372	64	19D
0005435732432	19372	65	19E
0005433397966	19372	66	20A
0005435732434	19372	67	20D
0005432297299	19372	68	20E
0005435068920	13139	1	1A
0005435068973	13139	2	1C
0005435925404	13139	3	1D
0005435925390	13139	4	1F
0005435068849	13139	5	2A
0005435069006	13139	6	3C
0005435068887	13139	7	3D
0005435925399	13139	8	3F
0005435068820	13139	9	4C
0005435068903	13139	10	4D
0005435925394	13139	11	4E
0005435068850	13139	12	4F
0005435069101	13139	13	5A
0005435068960	13139	14	5C
0005435068909	13139	15	5D
0005435068940	13139	16	5E
0005435069103	13139	17	6A
0005435068995	13139	18	6D
0005435069232	13139	19	6E
0005435068821	13139	20	7A
0005435068959	13139	21	7C
0005435925403	13139	22	7D
0005435069104	13139	23	7F
0005435069010	13139	24	8A
0005435068972	13139	25	8C
0005435069169	13139	26	8F
0005435069191	13139	27	9A
0005435069005	13139	28	9C
0005435925393	13139	29	9E
0005435925392	13139	30	10A
0005435068965	13139	31	10D
0005435068908	13139	32	10F
0005435925405	13139	33	11A
0005435068945	13139	34	11C
0005435068819	13139	35	11D
0005435068979	13139	36	11F
0005435068994	13139	37	12A
0005435925396	13139	38	12C
0005435069107	13139	39	12D
0005435925406	13139	40	12F
0005435068996	13139	41	13A
0005435925400	13139	42	13C
0005435068907	13139	43	13D
0005435925408	13139	44	13E
0005435925395	13139	45	13F
0005435069139	13139	46	14A
0005435925409	13139	47	14C
0005435925397	13139	48	14D
0005435925410	13139	49	14E
0005435068873	13139	50	14F
0005435068882	13139	51	15A
0005435068872	13139	52	15C
0005435925398	13139	53	15D
0005435925401	13139	54	15E
0005435925387	13139	55	15F
0005435925389	13139	56	16A
0005435069029	13139	57	16C
0005435068886	13139	58	16D
0005435069100	13139	59	16E
0005435069130	13139	60	16F
0005435068978	13139	61	17A
0005435925391	13139	62	17C
0005435068902	13139	63	17F
0005435925402	13139	64	18A
0005435069157	13139	65	18C
0005435069156	13139	66	18D
0005435068910	13139	67	18E
0005435068944	13139	68	18F
0005435925388	13139	69	19C
0005435925411	13139	70	19D
0005435069011	13139	71	19E
0005435069253	13139	72	19F
0005435069231	13139	73	20C
0005435925407	13139	74	20D
0005435069482	15464	1	1A
0005435925258	15464	2	1D
0005435069441	15464	3	1F
0005435069481	15464	4	2C
0005435069442	15464	5	2D
0005435925259	15464	6	2F
0005435069472	15464	7	4A
0005435069467	15464	8	4C
0005435069479	15464	9	4D
0005435069457	15464	10	4E
0005435069459	15464	11	4F
0005435069470	15464	12	5A
0005435069461	15464	13	5C
0005435069463	15464	14	5D
0005435069462	15464	15	5F
0005435069432	15464	16	6A
0005435069452	15464	17	6D
0005435069474	15464	18	6E
0005435069434	15464	19	7A
0005435069445	15464	20	7C
0005435925242	15464	21	7E
0005435069476	15464	22	7F
0005435069439	15464	23	8A
0005435925227	15464	24	8D
0005435069430	15464	25	8E
0005435069454	15464	26	8F
0005435925248	15464	27	9A
0005435069465	15464	28	9C
0005435069450	15464	29	9D
0005435925212	15464	30	9E
0005435069451	15464	31	9F
0005435069468	15464	32	10A
0005435925228	15464	33	10C
0005435069473	15464	34	10D
0005435069458	15464	35	10E
0005435069477	15464	36	10F
0005435925223	15464	37	11A
0005435069466	15464	38	11D
0005435069480	15464	39	11E
0005435069437	15464	40	12A
0005435069478	15464	41	12C
0005435925261	15464	42	12F
0005435069446	15464	43	13A
0005435925233	15464	44	13C
0005435069460	15464	45	13D
0005435925254	15464	46	13E
0005435925232	15464	47	14A
0005435069453	15464	48	14D
0005435925262	15464	49	14F
0005435069444	15464	50	15A
0005435069438	15464	51	15C
0005435925224	15464	52	15D
0005435069464	15464	53	15E
0005435069448	15464	54	15F
0005435069455	15464	55	16A
0005435069436	15464	56	16C
0005435069449	15464	57	16F
0005435069456	15464	58	17C
0005435069471	15464	59	17D
0005435925179	15464	60	17F
0005435069469	15464	61	18C
0005435069435	15464	62	18D
0005435925271	15464	63	18E
0005435069431	15464	64	18F
0005435069475	15464	65	19A
0005435069443	15464	66	19D
0005435925193	15464	67	19E
0005435925243	15464	68	19F
0005435069447	15464	69	20C
0005435069440	15464	70	20D
0005435069433	15464	71	20E
0005435925192	15464	72	20F
0005435808224	29479	1	1A
0005435808194	29479	2	1B
0005435808213	29479	3	1C
0005433407603	29479	4	2B
0005433407606	29479	5	2C
0005435808201	29479	6	2D
0005435808221	29479	7	3A
0005435808159	29479	8	3B
0005435808178	29479	9	4A
0005435808225	29479	10	4B
0005433407608	29479	11	4C
0005435808193	29479	12	4D
0005435808214	29479	13	5B
0005435808234	29479	14	5C
0005435808223	29479	15	5D
0005435808212	29479	16	6A
0005433407610	29479	17	6B
0005433407609	29479	18	6C
0005433407605	29479	19	7B
0005435808189	29479	20	7C
0005435808198	29479	21	18A
0005435808197	29479	22	7D
0005435808173	29479	23	18B
0005435808182	29479	24	18C
0005433407611	29479	25	18D
0005435808190	29479	26	19A
0005435808222	29479	27	19B
0005435808218	29479	28	19C
0005435808199	29479	29	19D
0005435808195	29479	30	20C
0005435808233	29479	31	21A
0005433407604	29479	32	21B
0005433407607	29479	33	21C
0005433407602	29479	34	21D
0005433407601	29479	35	22B
0005435808188	29479	36	22C
0005435808165	29479	37	23A
0005435808196	29479	38	23B
0005434756233	10690	1	1A
0005434756312	10690	2	1C
0005434756420	10690	3	1D
0005434756402	10690	4	1F
0005434756378	10690	5	2A
0005434756355	10690	6	2C
0005434214925	10690	7	2D
0005434756261	10690	8	2F
0005434214907	10690	9	3A
0005434756358	10690	10	3C
0005434214921	10690	11	3D
0005434214896	10690	12	3F
0005434214930	10690	13	4A
0005434214894	10690	14	4C
0005434214931	10690	15	4D
0005434756356	10690	16	4E
0005434214923	10690	17	4F
0005434756387	10690	18	5A
0005434214891	10690	19	5C
0005434214900	10690	20	5D
0005434214914	10690	21	5E
0005434756140	10690	22	5F
0005434756381	10690	23	6A
0005434756421	10690	24	6C
0005434214903	10690	25	6D
0005434756255	10690	26	6E
0005434756434	10690	27	6F
0005434214892	10690	28	7A
0005434214916	10690	29	7C
0005434756407	10690	30	7D
0005434214935	10690	31	7E
0005434214913	10690	32	7F
0005434214933	10690	33	8A
0005434214899	10690	34	8C
0005434756232	10690	35	8D
0005434214922	10690	36	8E
0005434214912	10690	37	8F
0005434756360	10690	38	9A
0005434756339	10690	39	9C
0005434756254	10690	40	9D
0005434214911	10690	41	9E
0005434756385	10690	42	9F
0005434214924	10690	43	10A
0005434756338	10690	44	10C
0005434756308	10690	45	10D
0005434756318	10690	46	10E
0005434756340	10690	47	10F
0005434214920	10690	48	11A
0005434756311	10690	49	11C
0005434214909	10690	50	11D
0005434214932	10690	51	11E
0005434756374	10690	52	11F
0005434214936	10690	53	12A
0005434756392	10690	54	12D
0005434214901	10690	55	12E
0005434756307	10690	56	12F
0005434214890	10690	57	13A
0005434756379	10690	58	13C
0005434214904	10690	59	13D
0005434756375	10690	60	13E
0005434756401	10690	61	13F
0005434756382	10690	62	14A
0005434214934	10690	63	14C
0005434756301	10690	64	14D
0005434756316	10690	65	14E
0005434214910	10690	66	14F
0005434214928	10690	67	15A
0005434214897	10690	68	15C
0005434214929	10690	69	15D
0005434756357	10690	70	15E
0005434756383	10690	71	15F
0005434214919	10690	72	16A
0005434756386	10690	73	16C
0005434214902	10690	74	16D
0005434756139	10690	75	16E
0005434214905	10690	76	16F
0005434214908	10690	77	17A
0005434214895	10690	78	17C
0005434214927	10690	79	17D
0005434756423	10690	80	17E
0005434214893	10690	81	17F
0005434756300	10690	82	18A
0005434756286	10690	83	18C
0005434756363	10690	84	18D
0005434756317	10690	85	18E
0005434214906	10690	86	18F
0005434214917	10690	87	19A
0005434214937	10690	88	19C
0005434756141	10690	89	19D
0005434214898	10690	90	19E
0005434214889	10690	91	19F
0005434214888	10690	92	20A
0005434756330	10690	93	20C
0005434214926	10690	94	20D
0005434214918	10690	95	20E
0005434214915	10690	96	20F
0005434756719	28686	1	1A
0005434214460	28686	2	1C
0005434214328	28686	3	1D
0005434214481	28686	4	2A
0005434214482	28686	5	2D
0005434214495	28686	6	3A
0005434214475	28686	7	3D
0005434214503	28686	8	3C
0005434756724	28686	9	3F
0005434756737	28686	10	4A
0005434756730	28686	11	4D
0005434214496	28686	12	4E
0005434756714	28686	13	4F
0005434214342	28686	14	5C
0005434214531	28686	15	5D
0005434214444	28686	16	5E
0005434756738	28686	17	5F
0005434214392	28686	18	6A
0005434214416	28686	19	6C
0005434756745	28686	20	6D
0005434214483	28686	21	6E
0005434214386	28686	22	6F
0005434756734	28686	23	7A
0005434756728	28686	24	7C
0005434214459	28686	25	7D
0005434214365	28686	26	7E
0005434214396	28686	27	7F
0005434214364	28686	28	8A
0005434756726	28686	29	8C
0005434214402	28686	30	8D
0005434756741	28686	31	8F
0005434756716	28686	32	9A
0005434756739	28686	33	9C
0005434756742	28686	34	9D
0005434756722	28686	35	9E
0005434214334	28686	36	9F
0005434214407	28686	37	10A
0005434214393	28686	38	10C
0005434756727	28686	39	10D
0005434756723	28686	40	10E
0005434214395	28686	41	10F
0005434214530	28686	42	11C
0005434214406	28686	43	11D
0005434214422	28686	44	11E
0005434214405	28686	45	11F
0005434756740	28686	46	12A
0005434756715	28686	47	12C
0005434214441	28686	48	12D
0005434214578	28686	49	12E
0005434214384	28686	50	13A
0005434214500	28686	51	13C
0005434214316	28686	52	13D
0005434214579	28686	53	13E
0005434214357	28686	54	13F
0005434756732	28686	55	14A
0005434756731	28686	56	14D
0005434214394	28686	57	14E
0005434756729	28686	58	14F
0005434214315	28686	59	15A
0005434756717	28686	60	15C
0005434214343	28686	61	15D
0005434756733	28686	62	15E
0005434756720	28686	63	16A
0005434214311	28686	64	16C
0005434214339	28686	65	16D
0005434756712	28686	66	16E
0005434756721	28686	67	16F
0005434756735	28686	68	17A
0005434214469	28686	69	17C
0005434756746	28686	70	17D
0005434214428	28686	71	17E
0005434214410	28686	72	17F
0005434756725	28686	73	18A
0005434214415	28686	74	18C
0005434756744	28686	75	18D
0005434214248	28686	76	18E
0005434756743	28686	77	18F
0005434756713	28686	78	19A
0005434214590	28686	79	19C
0005434756718	28686	80	19D
0005434756736	28686	81	19E
0005434214401	28686	82	20A
0005434214385	28686	83	20C
0005434214348	28686	84	20E
0005435040255	5449	1	1C
0005435040285	5449	2	1A
0005435040314	5449	3	1D
0005435040257	5449	4	2A
0005435007220	5449	5	1F
0005435007210	5449	6	2C
0005435040260	5449	7	2D
0005435040303	5449	8	3A
0005435040288	5449	9	2F
0005435040273	5449	10	3D
0005435040304	5449	11	3C
0005435042874	5449	12	3F
0005434229336	5449	13	4A
0005435040293	5449	14	4C
0005435040279	5449	15	4B
0005435040294	5449	16	4D
0005435040290	5449	17	4E
0005435040256	5449	18	4F
0005435040291	5449	19	5B
0005434229367	5449	20	5A
0005435040292	5449	21	5C
0005435040259	5449	22	5D
0005435040280	5449	23	5E
0005434229483	5449	24	6A
0005434229408	5449	25	5F
0005435007214	5449	26	6C
0005435007218	5449	27	6B
0005435007211	5449	28	6D
0005435040277	5449	29	6E
0005435040263	5449	30	7A
0005435007216	5449	31	6F
0005435040270	5449	32	7B
0005434229375	5449	33	7D
0005435040296	5449	34	7C
0005434229484	5449	35	7F
0005435040300	5449	36	7E
0005435040265	5449	37	8A
0005435007202	5449	38	8B
0005434229432	5449	39	8D
0005435040313	5449	40	8C
0005434229373	5449	41	8E
0005434229354	5449	42	9A
0005435040267	5449	43	8F
0005435040289	5449	44	9C
0005434229345	5449	45	9B
0005435040312	5449	46	9D
0005435040287	5449	47	9E
0005435040282	5449	48	10B
0005435040310	5449	49	10C
0005432125510	5449	50	10E
0005435007205	5449	51	10D
0005434229318	5449	52	11A
0005435007226	5449	53	11B
0005434229349	5449	54	11C
0005434229427	5449	55	11E
0005432125512	5449	56	11D
0005435007207	5449	57	11F
0005435040301	5449	58	12A
0005432125509	5449	59	12C
0005434229369	5449	60	12B
0005435040297	5449	61	12D
0005435040298	5449	62	12F
0005435040315	5449	63	13A
0005435007224	5449	64	13C
0005435040278	5449	65	13B
0005435040262	5449	66	13E
0005435040307	5449	67	13D
0005434229366	5449	68	13F
0005435040305	5449	69	14A
0005435040309	5449	70	14C
0005435040316	5449	71	14B
0005432125513	5449	72	14D
0005435007219	5449	73	14E
0005435007215	5449	74	15A
0005435042873	5449	75	14F
0005434229429	5449	76	15B
0005435040283	5449	77	15C
0005434229391	5449	78	15D
0005432125511	5449	79	15F
0005434229335	5449	80	15E
0005435040284	5449	81	16A
0005435040299	5449	82	16B
0005435040276	5449	83	16C
0005434229350	5449	84	16D
0005435040272	5449	85	16E
0005435040266	5449	86	17A
0005435007217	5449	87	16F
0005432125508	5449	88	17B
0005435040311	5449	89	17C
0005435007204	5449	90	17D
0005435040281	5449	91	17F
0005434229428	5449	92	17E
0005435040264	5449	93	18A
0005435040302	5449	94	18B
0005435040306	5449	95	18C
0005435040308	5449	96	18E
0005432125514	5449	97	18D
0005435040295	5449	98	18F
0005435040269	5449	99	19A
0005434229482	5449	100	19B
0005434229368	5449	101	19D
0005435040268	5449	102	19E
0005435007212	5449	103	19F
0005435040261	5449	104	20A
0005434229377	5449	105	20C
0005435007213	5449	106	20B
0005434229431	5449	107	20D
0005434229346	5449	108	20E
0005435040254	5449	109	21A
0005435007221	5449	110	21B
0005435007203	5449	111	21C
0005435040286	5449	112	21D
0005435040275	5449	113	21F
0005435040317	5449	114	22B
0005435007208	5449	115	22A
0005435007223	5449	116	22C
0005435040271	5449	117	22D
0005435007206	5449	118	22F
0005435040258	5449	119	22E
0005435042872	5449	120	23A
0005434229312	5449	121	23B
0005435007209	5449	122	23D
0005435007222	5449	123	23C
0005435040274	5449	124	23E
0005435007225	5449	125	23F
0005435006985	12982	1	1A
0005435006952	12982	2	1C
0005435039632	12982	3	1D
0005434229550	12982	4	2A
0005434229566	12982	5	1F
0005435006920	12982	6	2D
0005432304431	12982	7	2C
0005435007008	12982	8	2F
0005435006979	12982	9	3C
0005435039376	12982	10	3A
0005435007043	12982	11	3D
0005434229546	12982	12	3F
0005434229548	12982	13	4A
0005435040017	12982	14	4B
0005434229547	12982	15	4D
0005435039840	12982	16	4E
0005435007100	12982	17	5A
0005435007035	12982	18	5B
0005435039771	12982	19	5C
0005435039980	12982	20	5D
0005434229562	12982	21	5E
0005435039935	12982	22	5F
0005435039692	12982	23	6B
0005434229545	12982	24	6C
0005435039739	12982	25	6D
0005435039626	12982	26	6E
0005432304428	12982	27	7A
0005432304429	12982	28	7B
0005435039610	12982	29	7D
0005435006873	12982	30	7F
0005435039601	12982	31	8B
0005435007042	12982	32	8F
0005435039680	12982	33	8E
0005435039853	12982	34	9A
0005435042852	12982	35	9B
0005435006991	12982	36	9C
0005435039742	12982	37	9E
0005435039779	12982	38	9D
0005435007059	12982	39	9F
0005435006988	12982	40	10B
0005434229557	12982	41	10D
0005435039743	12982	42	10C
0005435039919	12982	43	10E
0005435039646	12982	44	11A
0005435006884	12982	45	11D
0005435039721	12982	46	11C
0005435039600	12982	47	11E
0005434229551	12982	48	11F
0005435007033	12982	49	12A
0005435039852	12982	50	12D
0005435039353	12982	51	12E
0005435039898	12982	52	12F
0005434229553	12982	53	13D
0005435007090	12982	54	13C
0005435039959	12982	55	13E
0005435006919	12982	56	13F
0005432304430	12982	57	14B
0005435039705	12982	58	14C
0005435006980	12982	59	14D
0005435039691	12982	60	14F
0005434229554	12982	61	14E
0005434229552	12982	62	15A
0005434229560	12982	63	15C
0005435006900	12982	64	15D
0005435039799	12982	65	15E
0005434229558	12982	66	15F
0005435039459	12982	67	16B
0005435039741	12982	68	16A
0005435039352	12982	69	16C
0005435039901	12982	70	16E
0005435007055	12982	71	16D
0005435039683	12982	72	16F
0005435039701	12982	73	17B
0005435039839	12982	74	17A
0005435007021	12982	75	17C
0005434229556	12982	76	17D
0005435006872	12982	77	17F
0005435039506	12982	78	17E
0005435039816	12982	79	18A
0005435039772	12982	80	18B
0005435006992	12982	81	18E
0005435039834	12982	82	18D
0005435042853	12982	83	18F
0005435039920	12982	84	19B
0005435039557	12982	85	19D
0005435039627	12982	86	19C
0005435039831	12982	87	19E
0005434229565	12982	88	19F
0005435039744	12982	89	20A
0005435040016	12982	90	20B
0005435039740	12982	91	20C
0005435039778	12982	92	20E
0005435006899	12982	93	20D
0005435007034	12982	94	20F
0005435039702	12982	95	21A
0005435039738	12982	96	21C
0005435043284	12982	97	21B
0005435039970	12982	98	21D
0005434229561	12982	99	21E
0005434229564	12982	100	21F
0005435039628	12982	101	22B
0005435007077	12982	102	22A
0005435007078	12982	103	22C
0005434229555	12982	104	22D
0005434229563	12982	105	22F
0005435039948	12982	106	23A
0005434229549	12982	107	23B
0005435006989	12982	108	23D
0005435039722	12982	109	23C
0005434229559	12982	110	23E
0005435902725	14877	1	1A
0005434411810	14877	2	1C
0005435902724	14877	3	1F
0005435902705	14877	4	2C
0005434426822	14877	5	2D
0005434426824	14877	6	3A
0005435902667	14877	7	3C
0005434426809	14877	8	3D
0005434426825	14877	9	4D
0005434426813	14877	10	4F
0005435902664	14877	11	5A
0005434426835	14877	12	5D
0005435902698	14877	13	5E
0005434426819	14877	14	6A
0005434411811	14877	15	6C
0005434426827	14877	16	6E
0005434426815	14877	17	6F
0005434426814	14877	18	7A
0005434426812	14877	19	7D
0005434411808	14877	20	8D
0005435902631	14877	21	8E
0005434426818	14877	22	8F
0005434426811	14877	23	9C
0005435902674	14877	24	9D
0005434426820	14877	25	10A
0005434426810	14877	26	10D
0005435554162	14877	27	10E
0005432188630	14877	28	10F
0005434426823	14877	29	11A
0005432188631	14877	30	11C
0005434426831	14877	31	11D
0005434426817	14877	32	11E
0005434426832	14877	33	11F
0005435902691	14877	34	12A
0005435554161	14877	35	12D
0005432188632	14877	36	12E
0005434426828	14877	37	13D
0005435902646	14877	38	14A
0005435902645	14877	39	14C
0005435902644	14877	40	14D
0005435554173	14877	41	14E
0005434426837	14877	42	14F
0005435902676	14877	43	15A
0005435902770	14877	44	15C
0005434426829	14877	45	15D
0005434426816	14877	46	16D
0005434411809	14877	47	16E
0005434411807	14877	48	16F
0005434426826	14877	49	17A
0005435902739	14877	50	17C
0005435902675	14877	51	17D
0005435554163	14877	52	17E
0005434426834	14877	53	17F
0005434426836	14877	54	18C
0005434426830	14877	55	18D
0005435902693	14877	56	18E
0005434426833	14877	57	18F
0005435902662	14877	58	19A
0005435902621	14877	59	19C
0005435902699	14877	60	19E
0005434426821	14877	61	19F
0005435554178	14877	62	20D
0005435902706	14877	63	20E
0005435902650	14877	64	20F
0005435902842	20200	1	1A
0005434426579	20200	2	1D
0005434426453	20200	3	2C
0005435902854	20200	4	2D
0005435902853	20200	5	3A
0005434426688	20200	6	3D
0005432059520	20200	7	4C
0005435902855	20200	8	5C
0005434426601	20200	9	6E
0005435554229	20200	10	6F
0005435902857	20200	11	7C
0005434426452	20200	12	7D
0005434411784	20200	13	8A
0005434426536	20200	14	8C
0005435902845	20200	15	8E
0005434426600	20200	16	8F
0005434426687	20200	17	9A
0005435902847	20200	18	9D
0005434411788	20200	19	9E
0005434426534	20200	20	9F
0005435902851	20200	21	10C
0005435902850	20200	22	10D
0005435902844	20200	23	10E
0005432059521	20200	24	10F
0005434426712	20200	25	11A
0005435554227	20200	26	11C
0005435902843	20200	27	11D
0005435554230	20200	28	12C
0005435902852	20200	29	12D
0005434426666	20200	30	12E
0005434426471	20200	31	13D
0005434426476	20200	32	13E
0005434426602	20200	33	14C
0005434426509	20200	34	14D
0005434426721	20200	35	14E
0005434426612	20200	36	14F
0005434426454	20200	37	15C
0005435554228	20200	38	15D
0005435902856	20200	39	15E
0005434426580	20200	40	16D
0005434426707	20200	41	17A
0005434426537	20200	42	17D
0005434426562	20200	43	17F
0005435902846	20200	44	18C
0005435902849	20200	45	18F
0005434426408	20200	46	19C
0005434411777	20200	47	19D
0005435902848	20200	48	19E
0005434426760	20200	49	19F
0005434426451	20200	50	20C
0005435902841	20200	51	20D
0005434426535	20200	52	20F
0005435982638	26504	1	1C
0005435982646	26504	2	1D
0005435982648	26504	3	1F
0005435982631	26504	4	2C
0005435982625	26504	5	2D
0005435982641	26504	6	2F
0005432300307	26504	7	3A
0005435982628	26504	8	3C
0005435982627	26504	9	3D
0005433434673	26504	10	3F
0005435982642	26504	11	4A
0005433434653	26504	12	4C
0005435982640	26504	13	4E
0005435982623	26504	14	5A
0005435982647	26504	15	5C
0005433434649	26504	16	5D
0005433434634	26504	17	5E
0005435982653	26504	18	5F
0005433434727	26504	19	6A
0005433434581	26504	20	6C
0005435982660	26504	21	6E
0005433434688	26504	22	6F
0005433434737	26504	23	7A
0005435982624	26504	24	7D
0005432300306	26504	25	7E
0005433434633	26504	26	7F
0005435982633	26504	27	8C
0005433434642	26504	28	8E
0005435982663	26504	29	8F
0005435982630	26504	30	9A
0005435982661	26504	31	9C
0005434270212	26504	32	9D
0005435982639	26504	33	9E
0005435982634	26504	34	9F
0005435982620	26504	35	10A
0005435982622	26504	36	10C
0005435982621	26504	37	10D
0005434273070	26504	38	10E
0005435982664	26504	39	10F
0005433434650	26504	40	11A
0005435982651	26504	41	11C
0005432300308	26504	42	11E
0005435982632	26504	43	11F
0005433434652	26504	44	12A
0005433434635	26504	45	12C
0005433434509	26504	46	12D
0005433434582	26504	47	12E
0005433434632	26504	48	12F
0005435982655	26504	49	13A
0005435982659	26504	50	13C
0005435982636	26504	51	13D
0005433434555	26504	52	13E
0005435982662	26504	53	13F
0005435982652	26504	54	14C
0005435982644	26504	55	14D
0005433434647	26504	56	14E
0005435982637	26504	57	14F
0005433434699	26504	58	15A
0005435982629	26504	59	15C
0005433434643	26504	60	15D
0005433434698	26504	61	15E
0005435982658	26504	62	15F
0005433434585	26504	63	16A
0005432300305	26504	64	16C
0005433434651	26504	65	16D
0005435982643	26504	66	16E
0005433434657	26504	67	16F
0005435982656	26504	68	17A
0005433434510	26504	69	17D
0005433434697	26504	70	17F
0005435982635	26504	71	17E
0005433434740	26504	72	18A
0005435982645	26504	73	18C
0005434270208	26504	74	18D
0005433434735	26504	75	18E
0005435982649	26504	76	18F
0005433434654	26504	77	19A
0005435982626	26504	78	19C
0005435982654	26504	79	19F
0005432300303	26504	80	20A
0005435982650	26504	81	20C
0005435982657	26504	82	20D
0005432300304	26504	83	20E
0005433434648	26504	84	20F
0005435982328	26738	1	1A
0005435982288	26738	2	1C
0005435982049	26738	3	1D
0005433434922	26738	4	1F
0005435982327	26738	5	2A
0005435982325	26738	6	2C
0005435981987	26738	7	3C
0005433434911	26738	8	3D
0005433434916	26738	9	3F
0005435982280	26738	10	4C
0005434271330	26738	11	4D
0005435982477	26738	12	4E
0005433434928	26738	13	5A
0005435982409	26738	14	5C
0005435982175	26738	15	5D
0005435982295	26738	16	5E
0005435982260	26738	17	5F
0005435982118	26738	18	6A
0005433434904	26738	19	6C
0005435982414	26738	20	6E
0005433434921	26738	21	7A
0005433434919	26738	22	7C
0005435982441	26738	23	7E
0005433434912	26738	24	7F
0005433434926	26738	25	8A
0005433434901	26738	26	8C
0005435982228	26738	27	8D
0005433434902	26738	28	8E
0005433434910	26738	29	8F
0005435982123	26738	30	9A
0005434271329	26738	31	9C
0005435982413	26738	32	9E
0005435982234	26738	33	9F
0005435982476	26738	34	10A
0005433434923	26738	35	10C
0005433434908	26738	36	10D
0005433434915	26738	37	10E
0005433434906	26738	38	10F
0005432051153	26738	39	11A
0005435982159	26738	40	11C
0005435982107	26738	41	11D
0005433434909	26738	42	11F
0005433434903	26738	43	12A
0005435982339	26738	44	12C
0005433434918	26738	45	12D
0005434269121	26738	46	12F
0005433434925	26738	47	13A
0005432051155	26738	48	13C
0005433434924	26738	49	13D
0005435982257	26738	50	13E
0005435982297	26738	51	13F
0005433434917	26738	52	14A
0005435982259	26738	53	14C
0005435982235	26738	54	14D
0005435982365	26738	55	14E
0005435982034	26738	56	14F
0005433434899	26738	57	15A
0005434270224	26738	58	15F
0005435982245	26738	59	16A
0005435982289	26738	60	16C
0005433434905	26738	61	16D
0005433434914	26738	62	16E
0005433434907	26738	63	16F
0005435982258	26738	64	17A
0005435982368	26738	65	17C
0005433434920	26738	66	17D
0005435982400	26738	67	18C
0005435982369	26738	68	18D
0005435982335	26738	69	18E
0005433434913	26738	70	19A
0005432051154	26738	71	19D
0005433434900	26738	72	20A
0005435982310	26738	73	20C
0005435982124	26738	74	20D
0005433434927	26738	75	20E
0005434270223	26738	76	20F
0005432584229	3136	1	1B
0005432584249	3136	2	1C
0005432584236	3136	3	1D
0005432584238	3136	4	2A
0005432858081	3136	5	2B
0005432584250	3136	6	2C
0005432858073	3136	7	3A
0005432584244	3136	8	3D
0005432858078	3136	9	4A
0005432858114	3136	10	4B
0005432584251	3136	11	4C
0005432584237	3136	12	5B
0005432584246	3136	13	5C
0005432858080	3136	14	6A
0005432858038	3136	15	6B
0005432584242	3136	16	6C
0005432584245	3136	17	6D
0005432584252	3136	18	7A
0005432584241	3136	19	7C
0005432584248	3136	20	7D
0005432216294	3136	21	18A
0005432216296	3136	22	18C
0005432584232	3136	23	18D
0005432584234	3136	24	19A
0005432216295	3136	25	19B
0005432858061	3136	26	19C
0005432584230	3136	27	19D
0005432858113	3136	28	20A
0005432584247	3136	29	20B
0005432858092	3136	30	20C
0005432584228	3136	31	20D
0005432584235	3136	32	21A
0005432584243	3136	33	21B
0005432858077	3136	34	21C
0005432858085	3136	35	21D
0005432584240	3136	36	22A
0005432584239	3136	37	22B
0005432584233	3136	38	22C
0005432584231	3136	39	23A
0005432858051	3136	40	23B
0005432584036	31519	1	1A
0005432584070	31519	2	1B
0005432584044	31519	3	1C
0005432584196	31519	4	2A
0005432584045	31519	5	2B
0005432858163	31519	6	2C
0005432858167	31519	7	2D
0005432584064	31519	8	3A
0005432858172	31519	9	3C
0005432583989	31519	10	3D
0005432584052	31519	11	4A
0005432858165	31519	12	4B
0005432858168	31519	13	4C
0005432584053	31519	14	5A
0005432858164	31519	15	5B
0005432584065	31519	16	5C
0005432858170	31519	17	6A
0005432584026	31519	18	6B
0005432584035	31519	19	6C
0005432584032	31519	20	6D
0005432584147	31519	21	7A
0005432584116	31519	22	7B
0005432584063	31519	23	7C
0005432584048	31519	24	7D
0005432858171	31519	25	18A
0005432584115	31519	26	18D
0005432584033	31519	27	19A
0005432858160	31519	28	19B
0005432858162	31519	29	19C
0005432583994	31519	30	19D
0005432584138	31519	31	20A
0005432858169	31519	32	20C
0005432584068	31519	33	20D
0005432584100	31519	34	21A
0005432584071	31519	35	21B
0005432858161	31519	36	21C
0005432858166	31519	37	21D
0005432584037	31519	38	22B
0005432584020	31519	39	22C
0005432584197	31519	40	23A
0005432584101	31519	41	23B
0005433255146	886	1	2B
0005434943429	886	2	2C
0005433255125	886	3	3B
0005433255128	886	4	4A
0005433255112	886	5	4D
0005434943422	886	6	6B
0005434943426	886	7	6C
0005434943423	886	8	7C
0005434943430	886	9	18A
0005433255113	886	10	18B
0005433255106	886	11	19B
0005433255129	886	12	20B
0005433255127	886	13	20C
0005434943425	886	14	21A
0005434943424	886	15	21C
0005434943427	886	16	21D
0005434943428	886	17	22D
0005434943382	16242	1	3B
0005433255164	16242	2	6C
0005433255165	16242	3	7B
0005433255163	16242	4	21C
0005434943361	16242	5	23B
0005433654834	4323	1	2D
0005435858540	4323	2	3A
0005435858519	4323	3	3C
0005433654837	4323	4	4A
0005433654826	4323	5	5A
0005435858560	4323	6	6D
0005433654818	4323	7	7D
0005433654827	4323	8	8A
0005433654829	4323	9	8B
0005433654828	4323	10	8D
0005433654815	4323	11	9B
0005433654821	4323	12	9C
0005433654838	4323	13	9E
0005433654820	4323	14	10A
0005435858518	4323	15	10F
0005433654819	4323	16	11B
0005435858561	4323	17	12B
0005433654816	4323	18	12A
0005433654823	4323	19	12C
0005435858520	4323	20	12E
0005435858556	4323	21	14A
0005435858547	4323	22	14C
0005433654840	4323	23	14E
0005433654817	4323	24	15C
0005433654830	4323	25	15F
0005433654842	4323	26	15E
0005433654833	4323	27	16B
0005433654843	4323	28	16F
0005433654836	4323	29	17D
0005435858533	4323	30	17C
0005433654835	4323	31	17E
0005435858537	4323	32	18E
0005433654822	4323	33	19A
0005433654841	4323	34	18F
0005433654814	4323	35	19D
0005433654825	4323	36	20B
0005433654831	4323	37	20C
0005433654832	4323	38	21B
0005433654824	4323	39	20F
0005433654839	4323	40	21E
0005433811629	14406	1	5B
0005433811626	14406	2	6A
0005433811627	14406	3	6B
0005433367537	21724	1	1A
0005433367904	21724	2	1C
0005435653376	21724	3	1D
0005433367909	21724	4	1F
0005435653395	21724	5	2A
0005435653379	21724	6	2C
0005433367881	21724	7	2D
0005435653366	21724	8	2F
0005435653393	21724	9	3A
0005435653375	21724	10	3C
0005435653404	21724	11	3D
0005433367915	21724	12	3F
0005435653397	21724	13	4A
0005435653377	21724	14	4C
0005435653361	21724	15	4D
0005435653380	21724	16	4E
0005435653402	21724	17	4F
0005435653382	21724	18	5A
0005433367603	21724	19	5C
0005435653358	21724	20	5D
0005433367536	21724	21	5E
0005433367977	21724	22	5F
0005435653369	21724	23	6A
0005433367858	21724	24	6C
0005435653365	21724	25	6D
0005433367851	21724	26	6E
0005433367774	21724	27	6F
0005435653349	21724	28	7A
0005435653360	21724	29	7C
0005435653396	21724	30	7D
0005435653391	21724	31	7E
0005435653350	21724	32	7F
0005435653364	21724	33	8A
0005433368013	21724	34	8C
0005435653394	21724	35	8D
0005433368041	21724	36	8E
0005435653362	21724	37	8F
0005435653363	21724	38	9C
0005433367690	21724	39	9D
0005433367939	21724	40	9E
0005433367743	21724	41	9F
0005435653357	21724	42	10A
0005433367787	21724	43	10C
0005433367966	21724	44	10D
0005435653386	21724	45	10E
0005433367755	21724	46	10F
0005433367723	21724	47	11A
0005435653356	21724	48	11C
0005433367967	21724	49	11D
0005433367754	21724	50	11E
0005435653374	21724	51	11F
0005435653371	21724	52	12A
0005435653373	21724	53	12D
0005433367792	21724	54	12E
0005435653383	21724	55	12F
0005433367914	21724	56	13A
0005435653370	21724	57	13C
0005433367860	21724	58	13D
0005433367669	21724	59	13E
0005435653384	21724	60	13F
0005433367742	21724	61	14A
0005433367882	21724	62	14C
0005435653353	21724	63	14D
0005433367670	21724	64	14E
0005435653372	21724	65	14F
0005435653387	21724	66	15A
0005433367793	21724	67	15C
0005435653401	21724	68	15D
0005433367861	21724	69	15E
0005433367880	21724	70	15F
0005435653368	21724	71	16A
0005435653399	21724	72	16C
0005433367741	21724	73	16D
0005435653352	21724	74	16E
0005433367794	21724	75	16F
0005433367720	21724	76	17A
0005435653381	21724	77	17C
0005435653398	21724	78	17D
0005435653388	21724	79	17E
0005435653351	21724	80	17F
0005435653400	21724	81	18A
0005435653354	21724	82	18C
0005433367910	21724	83	18D
0005435653359	21724	84	18E
0005435653403	21724	85	18F
0005435653355	21724	86	19A
0005435653385	21724	87	19C
0005433367827	21724	88	19D
0005435653367	21724	89	19E
0005435653390	21724	90	19F
0005435653378	21724	91	20A
0005433367668	21724	92	20C
0005435653389	21724	93	20D
0005435653392	21724	94	20E
0005433367843	21724	95	20F
0005433785254	9334	1	1A
0005433763323	9334	2	1B
0005433805645	9334	3	1F
0005433785258	9334	4	2A
0005433805661	9334	5	2C
0005433785230	9334	6	2B
0005433785250	9334	7	2F
0005433763318	9334	8	2H
0005433785239	9334	9	2G
0005433785251	9334	10	3F
0005433785259	9334	11	3C
0005433805676	9334	12	3G
0005434151706	9334	13	3H
0005433785225	9334	14	4C
0005433785257	9334	15	4F
0005433805662	9334	16	4H
0005433805646	9334	17	5B
0005433785236	9334	18	5C
0005435269733	9334	19	5F
0005434151700	9334	20	11D
0005433805666	9334	21	11E
0005433785226	9334	22	11H
0005433805654	9334	23	12A
0005433785256	9334	24	12E
0005433805667	9334	25	12G
0005434151702	9334	26	12H
0005433805682	9334	27	13F
0005434171050	9334	28	14D
0005435269729	9334	29	14F
0005433785234	9334	30	14G
0005433785246	9334	31	14H
0005433805659	9334	32	15B
0005433805648	9334	33	15A
0005433785245	9334	34	15F
0005432657474	9334	35	15H
0005434273076	9334	36	15G
0005433805680	9334	37	16B
0005433785232	9334	38	16G
0005433805670	9334	39	16F
0005432665292	9334	40	16H
0005432667471	9334	41	17A
0005434151705	9334	42	17D
0005433785229	9334	43	17B
0005433805674	9334	44	17F
0005433805644	9334	45	17E
0005433785235	9334	46	17G
0005433805653	9334	47	18A
0005434171103	9334	48	18D
0005434170984	9334	49	18E
0005433805658	9334	50	18G
0005433785240	9334	51	18H
0005433805649	9334	52	19D
0005434273077	9334	53	19F
0005433805672	9334	54	19H
0005433785247	9334	55	20B
0005432666407	9334	56	20E
0005434151701	9334	57	20H
0005433785252	9334	58	21A
0005433763326	9334	59	21D
0005434151703	9334	60	21E
0005432666405	9334	61	21G
0005432665291	9334	62	21H
0005434151697	9334	63	22D
0005434171010	9334	64	22B
0005433763325	9334	65	22E
0005433805664	9334	66	22G
0005433785249	9334	67	22F
0005433805657	9334	68	22H
0005433763322	9334	69	23B
0005433805675	9334	70	23E
0005433785231	9334	71	23H
0005433763329	9334	72	24A
0005433785243	9334	73	24D
0005434151696	9334	74	24F
0005434171116	9334	75	24G
0005433785224	9334	76	25D
0005433785227	9334	77	25E
0005433785248	9334	78	27F
0005433805652	9334	79	27E
0005434270207	9334	80	27G
0005433785223	9334	81	27H
0005434273075	9334	82	28B
0005433805668	9334	83	28E
0005433805679	9334	84	28D
0005433785233	9334	85	28F
0005433805681	9334	86	29B
0005433805663	9334	87	29A
0005433805673	9334	88	28H
0005435269728	9334	89	29F
0005432657473	9334	90	29H
0005433785228	9334	91	29G
0005432666406	9334	92	30A
0005433763320	9334	93	30E
0005433805655	9334	94	30H
0005433763317	9334	95	31D
0005433805656	9334	96	31F
0005433805669	9334	97	31H
0005434273080	9334	98	32A
0005434171163	9334	99	32D
0005434151704	9334	100	32F
0005433785244	9334	101	32H
0005433763319	9334	102	32G
0005433785237	9334	103	33D
0005434151695	9334	104	33E
0005433763331	9334	105	33F
0005432657475	9334	106	33H
0005433805683	9334	107	34B
0005433805677	9334	108	34E
0005433785253	9334	109	34F
0005433805671	9334	110	34H
0005432667472	9334	111	35D
0005433805650	9334	112	35E
0005433805651	9334	113	35G
0005433805665	9334	114	35F
0005434270206	9334	115	36A
0005435269743	9334	116	35H
0005433785241	9334	117	36B
0005433785242	9334	118	36E
0005433763321	9334	119	36G
0005433763327	9334	120	37A
0005433763330	9334	121	36H
0005433805684	9334	122	37D
0005433805660	9334	123	37F
0005433805647	9334	124	37H
0005433785255	9334	125	37G
0005433763324	9334	126	38D
0005433805678	9334	127	38E
0005433763328	9334	128	39D
0005433785238	9334	129	39F
0005435269800	26244	1	1A
0005434171178	26244	2	1H
0005434171167	26244	3	2B
0005433784948	26244	4	2F
0005433763233	26244	5	2C
0005433805464	26244	6	3G
0005432663033	26244	7	4C
0005434270221	26244	8	4F
0005433784967	26244	9	4H
0005433805367	26244	10	5B
0005433805296	26244	11	5F
0005433784712	26244	12	5H
0005432657449	26244	13	9B
0005433763205	26244	14	9G
0005434171171	26244	15	11E
0005434269120	26244	16	11D
0005433805185	26244	17	11F
0005433805308	26244	18	11G
0005433784966	26244	19	12A
0005433785031	26244	20	12D
0005435269797	26244	21	12F
0005433785041	26244	22	13A
0005433805259	26244	23	13D
0005434171170	26244	24	13B
0005433763150	26244	25	13F
0005433805425	26244	26	13E
0005433805496	26244	27	13G
0005433784863	26244	28	14B
0005433805513	26244	29	14A
0005433805212	26244	30	14F
0005433784871	26244	31	14E
0005433805375	26244	32	14H
0005434151728	26244	33	15E
0005434171176	26244	34	15F
0005435269798	26244	35	16E
0005434151726	26244	36	17A
0005433763186	26244	37	17D
0005434151727	26244	38	17B
0005432657452	26244	39	17E
0005433805336	26244	40	17G
0005433784897	26244	41	17F
0005432657418	26244	42	18B
0005433763214	26244	43	18A
0005433785062	26244	44	18G
0005433805393	26244	45	19B
0005433763161	26244	46	19D
0005435269799	26244	47	19F
0005432663032	26244	48	20A
0005433805312	26244	49	19H
0005433805458	26244	50	20D
0005434271327	26244	51	20B
0005433805313	26244	52	20H
0005433784854	26244	53	20G
0005433805352	26244	54	21D
0005433805535	26244	55	21E
0005433805437	26244	56	21G
0005433763232	26244	57	22D
0005433805335	26244	58	22F
0005433763202	26244	59	22E
0005433805186	26244	60	22G
0005434171172	26244	61	22H
0005434269119	26244	62	23B
0005433763135	26244	63	24A
0005434171173	26244	64	23H
0005433785055	26244	65	24E
0005433785014	26244	66	24G
0005433763213	26244	67	25D
0005434151729	26244	68	24H
0005433784938	26244	69	25F
0005432663035	26244	70	27B
0005434171177	26244	71	27E
0005433784887	26244	72	27D
0005435269796	26244	73	27G
0005433805392	26244	74	28A
0005433785032	26244	75	27H
0005435269801	26244	76	28D
0005433763164	26244	77	28F
0005434270222	26244	78	28H
0005433785001	26244	79	29B
0005433784870	26244	80	29E
0005432657446	26244	81	29D
0005433784898	26244	82	29F
0005432663031	26244	83	30B
0005434171166	26244	84	30D
0005434171175	26244	85	30F
0005433805309	26244	86	30G
0005433763231	26244	87	30H
0005434171168	26244	88	31B
0005434171165	26244	89	31E
0005433784740	26244	90	31F
0005433805351	26244	91	31H
0005433785065	26244	92	32D
0005433805407	26244	93	32H
0005433784909	26244	94	32G
0005433785066	26244	95	33G
0005433805512	26244	96	34A
0005433784945	26244	97	34D
0005433784910	26244	98	34E
0005433785074	26244	99	34G
0005433805406	26244	100	35F
0005433805290	26244	101	35E
0005434269118	26244	102	36A
0005432663036	26244	103	37A
0005433785069	26244	104	36H
0005432657432	26244	105	37D
0005433763172	26244	106	37B
0005433784971	26244	107	37E
0005433784933	26244	108	37F
0005434171174	26244	109	37H
0005433784930	26244	110	38A
0005434171169	26244	111	38D
0005434271328	26244	112	38B
0005433785061	26244	113	38E
0005433805502	26244	114	38F
0005434171164	26244	115	38H
0005433805277	26244	116	38G
0005432663040	26244	117	39E
0005435135710	4892	1	3A
0005435929646	4892	2	3B
0005435135711	4892	3	4B
0005435135707	4892	4	5C
0005435135709	4892	5	18B
0005435135708	4892	6	22B
0005435929666	33056	1	2A
0005435135668	33056	2	2D
0005435135684	33056	3	5C
0005435929665	33056	4	22B
0005434217981	9477	1	4B
0005434217972	9477	2	5D
0005434217980	9477	3	6A
0005434983328	9477	4	6B
0005434983332	9477	5	7B
0005434983329	9477	6	18A
0005434983330	9477	7	21A
0005434983331	9477	8	21D
0005434218001	27334	1	3A
0005434983296	27334	2	4A
0005434217999	27334	3	4B
0005434983288	27334	4	19B
0005434218002	27334	5	20A
0005434218003	27334	6	20C
0005434218000	27334	7	21B
0005434983313	27334	8	21C
0005434983297	27334	9	22D
0005433960747	24245	1	1F
0005433960841	24245	2	1H
0005433985744	24245	3	2H
0005433985745	24245	4	3A
0005433985827	24245	5	3C
0005433985885	24245	6	3B
0005433960612	24245	7	3G
0005433960782	24245	8	3F
0005433960685	24245	9	3H
0005433986019	24245	10	4A
0005433960703	24245	11	4C
0005433960813	24245	12	5B
0005433960745	24245	13	5A
0005433985761	24245	14	11D
0005433985829	24245	15	11B
0005433985824	24245	16	11E
0005433960844	24245	17	11F
0005433960839	24245	18	12A
0005433960664	24245	19	12D
0005433960834	24245	20	12H
0005433985836	24245	21	12G
0005433985897	24245	22	13B
0005433985970	24245	23	13E
0005433986041	24245	24	13F
0005433985937	24245	25	13H
0005433960667	24245	26	14A
0005433960503	24245	27	14E
0005433960686	24245	28	15D
0005433960487	24245	29	15F
0005433985782	24245	30	16A
0005433960650	24245	31	16E
0005433985907	24245	32	16G
0005433985808	24245	33	16F
0005433960651	24245	34	16H
0005433960673	24245	35	17A
0005433985896	24245	36	18D
0005433985748	24245	37	18G
0005433986011	24245	38	18F
0005433985784	24245	39	19B
0005433985941	24245	40	19E
0005433960753	24245	41	19H
0005433985762	24245	42	20A
0005433985886	24245	43	20D
0005433985934	24245	44	20E
0005433960754	24245	45	20H
0005433960684	24245	46	21A
0005433986110	24245	47	21D
0005433985830	24245	48	22B
0005433960702	24245	49	22A
0005433986066	24245	50	22E
0005433986010	24245	51	22G
0005433960828	24245	52	22H
0005433985906	24245	53	23A
0005433985952	24245	54	23F
0005433960516	24245	55	24A
0005433960711	24245	56	24D
0005433985940	24245	57	24F
0005433985846	24245	58	24G
0005433960797	24245	59	25D
0005433960763	24245	60	27F
0005433986091	24245	61	27G
0005433960610	24245	62	28B
0005433986053	24245	63	28F
0005433960798	24245	64	29B
0005433985826	24245	65	29E
0005433960784	24245	66	29G
0005433985953	24245	67	29F
0005433960765	24245	68	30A
0005433960766	24245	69	29H
0005433985994	24245	70	30F
0005433985793	24245	71	30E
0005433960845	24245	72	30G
0005433960581	24245	73	31B
0005433960850	24245	74	32B
0005433960611	24245	75	32D
0005433985760	24245	76	32H
0005433960409	24245	77	32G
0005433960829	24245	78	33F
0005433985854	24245	79	33H
0005433985800	24245	80	34B
0005433985781	24245	81	34A
0005433985905	24245	82	34D
0005433960666	24245	83	34H
0005433985853	24245	84	35A
0005433985825	24245	85	36A
0005433985883	24245	86	35H
0005433960504	24245	87	37A
0005433985805	24245	88	37B
0005433985938	24245	89	37E
0005433960665	24245	90	37D
0005433985743	24245	91	37F
0005433960808	24245	92	38B
0005433960764	24245	93	37H
0005433985733	24245	94	38E
0005433985917	24245	95	38D
0005433985884	24245	96	38F
0005433960593	24245	97	38H
0005433960594	24245	98	38G
0005433985895	24245	99	39F
0005433961267	25953	1	1B
0005433961310	25953	2	1G
0005433986285	25953	3	1H
0005433961278	25953	4	2G
0005433986290	25953	5	3A
0005433986272	25953	6	3B
0005433961288	25953	7	3F
0005433986289	25953	8	3C
0005433961295	25953	9	4A
0005433961319	25953	10	4B
0005433986282	25953	11	4C
0005433986277	25953	12	5A
0005433986280	25953	13	4H
0005433986299	25953	14	5H
0005433961284	25953	15	11A
0005433961306	25953	16	9H
0005433961290	25953	17	11D
0005433986275	25953	18	11B
0005433961321	25953	19	11E
0005433986300	25953	20	11F
0005433961299	25953	21	11H
0005433961313	25953	22	11G
0005433986281	25953	23	12B
0005433986263	25953	24	12D
0005433961289	25953	25	12F
0005433986293	25953	26	12H
0005433961303	25953	27	13A
0005433986270	25953	28	13B
0005433961328	25953	29	13E
0005433961308	25953	30	13H
0005433961263	25953	31	14D
0005433986266	25953	32	14F
0005433986305	25953	33	15A
0005433986291	25953	34	15H
0005433961322	25953	35	16B
0005433961287	25953	36	16D
0005433961305	25953	37	16G
0005433961293	25953	38	16F
0005433986269	25953	39	16H
0005433961274	25953	40	17B
0005433961281	25953	41	17F
0005433961276	25953	42	17G
0005433961268	25953	43	17H
0005433986296	25953	44	18B
0005433986264	25953	45	18A
0005433986274	25953	46	18D
0005433961309	25953	47	18F
0005433961311	25953	48	18E
0005433986267	25953	49	18H
0005433986297	25953	50	18G
0005433986295	25953	51	19G
0005433986303	25953	52	19F
0005433961312	25953	53	20A
0005433986276	25953	54	20B
0005433961280	25953	55	20E
0005433961271	25953	56	20D
0005433986286	25953	57	21B
0005433986265	25953	58	21H
0005433961325	25953	59	21G
0005433961301	25953	60	22D
0005433961316	25953	61	22E
0005433961318	25953	62	22G
0005433961277	25953	63	22F
0005433961314	25953	64	23B
0005433986271	25953	65	23D
0005433961264	25953	66	23F
0005433961298	25953	67	23E
0005433961294	25953	68	24A
0005433961265	25953	69	24B
0005433961302	25953	70	24D
0005433961292	25953	71	24F
0005433986288	25953	72	24H
0005433961320	25953	73	24G
0005433961324	25953	74	25D
0005433961296	25953	75	25F
0005433986301	25953	76	25E
0005433961269	25953	77	27A
0005433961304	25953	78	27F
0005433986273	25953	79	28D
0005433986284	25953	80	28F
0005433986278	25953	81	28E
0005433961323	25953	82	28H
0005433986302	25953	83	29D
0005433961275	25953	84	29E
0005433961297	25953	85	30E
0005433961279	25953	86	30G
0005433986304	25953	87	30H
0005433961285	25953	88	31D
0005433986283	25953	89	31G
0005433986287	25953	90	32B
0005433986262	25953	91	32D
0005433986259	25953	92	32F
0005433986261	25953	93	33A
0005433986279	25953	94	32H
0005433961273	25953	95	33B
0005433986260	25953	96	33E
0005433961266	25953	97	33H
0005433961315	25953	98	34E
0005433986298	25953	99	34G
0005433986294	25953	100	34F
0005433961307	25953	101	34H
0005433986268	25953	102	35G
0005433961282	25953	103	36B
0005433961317	25953	104	36D
0005433961291	25953	105	37A
0005433961270	25953	106	36H
0005433961283	25953	107	37D
0005433961327	25953	108	37B
0005433986292	25953	109	37E
0005433961326	25953	110	37H
0005433961272	25953	111	38A
0005433961286	25953	112	38F
0005433961300	25953	113	38H
0005434480526	957	1	1B
0005434480525	957	2	1D
0005433165871	957	3	2A
0005434480545	957	4	2B
0005434480535	957	5	2C
0005433165870	957	6	2D
0005434480546	957	7	3B
0005433165939	957	8	3C
0005434480534	957	9	4A
0005432269519	957	10	4B
0005434480528	957	11	4D
0005433165930	957	12	5A
0005434480544	957	13	5B
0005434480541	957	14	5C
0005434480529	957	15	5D
0005433165878	957	16	6A
0005434480547	957	17	6D
0005434480532	957	18	7A
0005432269517	957	19	7D
0005433165938	957	20	18A
0005434480536	957	21	18B
0005433165904	957	22	18C
0005432269518	957	23	18D
0005434480537	957	24	19A
0005434480543	957	25	19B
0005434480539	957	26	19C
0005434480542	957	27	20A
0005434480530	957	28	20B
0005434480533	957	29	20C
0005434480540	957	30	20D
0005434480523	957	31	21A
0005434480524	957	32	21B
0005434480531	957	33	21C
0005433165918	957	34	22B
0005434480538	957	35	22C
0005433165905	957	36	22D
0005434480527	957	37	23A
0005434480397	16572	1	1A
0005434480312	16572	2	1C
0005433166007	16572	3	1D
0005433166004	16572	4	2B
0005433166012	16572	5	2C
0005434480406	16572	6	2D
0005434480313	16572	7	3A
0005434480340	16572	8	3B
0005433166008	16572	9	3C
0005434480384	16572	10	3D
0005434480364	16572	11	4A
0005434480399	16572	12	4B
0005434480330	16572	13	4D
0005433166009	16572	14	5C
0005433166010	16572	15	5D
0005434480237	16572	16	6A
0005434480292	16572	17	6B
0005434480329	16572	18	7B
0005433166015	16572	19	7C
0005434480271	16572	20	7D
0005433166006	16572	21	18A
0005434480229	16572	22	18B
0005434480228	16572	23	18D
0005433166005	16572	24	19B
0005434480140	16572	25	19D
0005434480238	16572	26	20A
0005433166011	16572	27	20B
0005434480333	16572	28	20C
0005434480405	16572	29	20D
0005433166017	16572	30	21A
0005433166014	16572	31	21B
0005433166013	16572	32	21C
0005434480383	16572	33	21D
0005433166003	16572	34	22A
0005434480363	16572	35	22B
0005434480260	16572	36	22D
0005433166016	16572	37	23A
0005434480390	16572	38	23B
0005433872513	3210	1	1C
0005433872511	3210	2	4B
0005433872512	3210	3	5C
0005433872509	3210	4	6B
0005433872514	3210	5	7B
0005433872510	3210	6	20D
0005433872515	3210	7	21B
0005433872479	32538	1	1B
0005433872482	32538	2	5B
0005433872474	32538	3	19B
0005433872483	32538	4	21B
0005433872486	32538	5	23A
0005433289831	10372	1	1A
0005435386558	10372	2	1B
0005433289800	10372	3	1C
0005435142674	10372	4	1D
0005435142670	10372	5	2B
0005435386567	10372	6	2C
0005435150123	10372	7	2D
0005435386565	10372	8	3A
0005435150120	10372	9	3B
0005433289830	10372	10	3C
0005435142676	10372	11	3D
0005435142677	10372	12	4B
0005435142671	10372	13	4C
0005435142669	10372	14	4D
0005433289814	10372	15	5A
0005435150127	10372	16	5B
0005435386557	10372	17	5D
0005435150130	10372	18	6A
0005435150126	10372	19	6B
0005435142681	10372	20	6C
0005433289834	10372	21	6D
0005435150133	10372	22	7A
0005433289833	10372	23	7B
0005435142668	10372	24	7C
0005435386569	10372	25	7D
0005435150121	10372	26	18A
0005435386568	10372	27	18B
0005435142679	10372	28	18C
0005435142680	10372	29	18D
0005435142678	10372	30	19D
0005435142673	10372	31	20B
0005435150134	10372	32	20C
0005435150132	10372	33	20D
0005433289799	10372	34	21A
0005435142672	10372	35	21B
0005435150128	10372	36	21C
0005435150124	10372	37	21D
0005435150125	10372	38	22A
0005435386559	10372	39	22B
0005435150122	10372	40	22C
0005435150131	10372	41	22D
0005435150129	10372	42	23A
0005435142675	10372	43	23B
0005435150017	21940	1	1C
0005435142545	21940	2	1D
0005435142592	21940	3	2A
0005435150024	21940	4	2B
0005435149996	21940	5	2C
0005433289916	21940	6	2D
0005435386628	21940	7	3A
0005435142554	21940	8	3B
0005433289911	21940	9	3D
0005435149987	21940	10	4A
0005435142510	21940	11	4B
0005435150019	21940	12	4C
0005435142604	21940	13	4D
0005435142581	21940	14	5A
0005435386622	21940	15	5B
0005435142579	21940	16	5C
0005435386624	21940	17	6A
0005435386626	21940	18	6B
0005435142612	21940	19	6C
0005433289913	21940	20	7A
0005433289915	21940	21	18B
0005435386629	21940	22	18C
0005435386621	21940	23	18D
0005435142593	21940	24	19B
0005435386623	21940	25	19C
0005433289914	21940	26	19D
0005435142509	21940	27	20A
0005435142591	21940	28	20B
0005435386625	21940	29	20D
0005435142605	21940	30	21A
0005435150047	21940	31	21B
0005435142609	21940	32	21C
0005435386627	21940	33	22A
0005433289912	21940	34	22B
0005435142546	21940	35	22C
0005435150016	21940	36	22D
0005435142514	21940	37	23A
0005435502285	11229	1	1D
0005435319541	11229	2	1F
0005434573459	11229	3	2C
0005435502283	11229	4	2D
0005435502252	11229	5	2F
0005435529235	11229	6	3A
0005435502211	11229	7	3C
0005435319542	11229	8	3D
0005434573449	11229	9	3F
0005435529234	11229	10	4D
0005434573451	11229	11	4E
0005434573448	11229	12	5A
0005434573453	11229	13	5C
0005435502295	11229	14	5D
0005435502412	11229	15	5E
0005434573450	11229	16	5F
0005434573457	11229	17	6C
0005435545717	11229	18	6F
0005435545751	11229	19	7A
0005435529255	11229	20	7C
0005435545745	11229	21	7D
0005435545732	11229	22	7F
0005435502393	11229	23	8C
0005435545731	11229	24	8D
0005434573461	11229	25	8F
0005435529170	11229	26	9A
0005435529218	11229	27	9C
0005435529254	11229	28	9D
0005435502322	11229	29	10A
0005435529263	11229	30	10C
0005435545740	11229	31	10D
0005435529151	11229	32	10E
0005435319585	11229	33	10F
0005435502413	11229	34	11A
0005435529351	11229	35	11D
0005435502265	11229	36	11F
0005435502290	11229	37	11E
0005435502249	11229	38	12C
0005435529322	11229	39	12D
0005435319544	11229	40	12E
0005434573455	11229	41	12F
0005434573456	11229	42	13A
0005435529145	11229	43	13C
0005435502369	11229	44	13D
0005435502328	11229	45	13E
0005435502356	11229	46	13F
0005435529304	11229	47	14C
0005435502353	11229	48	14D
0005434573458	11229	49	14E
0005435502284	11229	50	14F
0005435529244	11229	51	15C
0005435502411	11229	52	15E
0005435319529	11229	53	15F
0005435502352	11229	54	16C
0005435529219	11229	55	16D
0005435529236	11229	56	16E
0005435545727	11229	57	16F
0005435545746	11229	58	17A
0005435502394	11229	59	17C
0005435529157	11229	60	17D
0005435502286	11229	61	17E
0005434573452	11229	62	17F
0005435545723	11229	63	18A
0005435502364	11229	64	18F
0005435529237	11229	65	19C
0005435529264	11229	66	19D
0005434573460	11229	67	19F
0005434573454	11229	68	20A
0005435529303	11229	69	20D
0005435502251	11229	70	20E
0005435529265	11229	71	20F
0005435502464	20935	1	1A
0005434573330	20935	2	1F
0005435518032	20935	3	2A
0005435518041	20935	4	2C
0005434573365	20935	5	2D
0005435518044	20935	6	2F
0005435518040	20935	7	3A
0005435518047	20935	8	3C
0005435508446	20935	9	3F
0005435502470	20935	10	4A
0005435518046	20935	11	4C
0005435518037	20935	12	4D
0005435502463	20935	13	4F
0005435502476	20935	14	5A
0005435502472	20935	15	5C
0005435502477	20935	16	5D
0005435508443	20935	17	5E
0005435319654	20935	18	5F
0005434573348	20935	19	6A
0005435518043	20935	20	6C
0005435319653	20935	21	6D
0005435319658	20935	22	6E
0005434573366	20935	23	7A
0005434573331	20935	24	7C
0005435508445	20935	25	7D
0005435508442	20935	26	7E
0005435508439	20935	27	7F
0005435502468	20935	28	8A
0005435502466	20935	29	8C
0005435508436	20935	30	8D
0005435508435	20935	31	8E
0005435518048	20935	32	8F
0005435518035	20935	33	9A
0005435502484	20935	34	9C
0005435508433	20935	35	9D
0005435508432	20935	36	9E
0005435319659	20935	37	9F
0005435508430	20935	38	10A
0005435502469	20935	39	10C
0005435508431	20935	40	10E
0005435502473	20935	41	11A
0005435319655	20935	42	11C
0005435502471	20935	43	11D
0005435518030	20935	44	11E
0005435502480	20935	45	11F
0005435319657	20935	46	12A
0005435518031	20935	47	12C
0005435502475	20935	48	12F
0005434573342	20935	49	13A
0005435518028	20935	50	13C
0005435502479	20935	51	13E
0005435508440	20935	52	13F
0005435508444	20935	53	14A
0005435319650	20935	54	14C
0005435502482	20935	55	14E
0005435319651	20935	56	14F
0005435502483	20935	57	15A
0005435518029	20935	58	15D
0005435319652	20935	59	15E
0005434573389	20935	60	15F
0005435508438	20935	61	16A
0005435518036	20935	62	16D
0005435319656	20935	63	16E
0005435508437	20935	64	16F
0005432291949	20935	65	17D
0005435502474	20935	66	17F
0005432291948	20935	67	18A
0005435502467	20935	68	18C
0005435508434	20935	69	18D
0005435502481	20935	70	18E
0005435518038	20935	71	18F
0005435502478	20935	72	19A
0005435502465	20935	73	19C
0005435518039	20935	74	19D
0005435508441	20935	75	19E
0005435518033	20935	76	20A
0005435518045	20935	77	20C
0005434573210	20935	78	20D
0005435518042	20935	79	20E
0005435518034	20935	80	20F
0005432692975	2886	1	2A
0005432693019	2886	2	2D
0005432693083	2886	3	3D
0005432692915	2886	4	4C
0005432693067	2886	5	5D
0005432693009	2886	6	5E
0005432693082	2886	7	5F
0005432692882	2886	8	6A
0005432692947	2886	9	7F
0005432692919	2886	10	8D
0005432693058	2886	11	8E
0005432692948	2886	12	9D
0005432692914	2886	13	9F
0005432693117	2886	14	10C
0005432693069	2886	15	12A
0005432693068	2886	16	12E
0005432692881	2886	17	13A
0005432692828	2886	18	14A
0005432693049	2886	19	15A
0005432693093	2886	20	17E
0005432693018	2886	21	17F
0005432692890	2886	22	18E
0005432693031	2886	23	19E
0005432693118	2886	24	20A
0005432706976	2934	1	1A
0005433123914	2934	2	1D
0005433123948	2934	3	1F
0005432706967	2934	4	2C
0005432706980	2934	5	2D
0005432706988	2934	6	2F
0005433123944	2934	7	3A
0005433123915	2934	8	3C
0005432706965	2934	9	4A
0005433123885	2934	10	4D
0005432880811	2934	11	5C
0005432880831	2934	12	5E
0005433123884	2934	13	6A
0005432217797	2934	14	6E
0005433123854	2934	15	6F
0005432706974	2934	16	7A
0005433123943	2934	17	7C
0005432880817	2934	18	7D
0005432706986	2934	19	7E
0005432880812	2934	20	7F
0005433123965	2934	21	8A
0005432706981	2934	22	8E
0005432880862	2934	23	8F
0005432706977	2934	24	9A
0005432880863	2934	25	9D
0005433123927	2934	26	10A
0005432217798	2934	27	10C
0005432880806	2934	28	10D
0005432880799	2934	29	10E
0005432706968	2934	30	10F
0005432880861	2934	31	11C
0005432880752	2934	32	11E
0005432706985	2934	33	11F
0005432706969	2934	34	12C
0005432706973	2934	35	12D
0005432706983	2934	36	12E
0005433123912	2934	37	12F
0005432706984	2934	38	13C
0005432880810	2934	39	13D
0005432706964	2934	40	13E
0005432706987	2934	41	13F
0005432880808	2934	42	14A
0005433123911	2934	43	14C
0005433194852	2934	44	14D
0005432706970	2934	45	14F
0005432706978	2934	46	15A
0005432706979	2934	47	15E
0005432706982	2934	48	15F
0005433123866	2934	49	16A
0005433123947	2934	50	16D
0005433123923	2934	51	16E
0005432880796	2934	52	16F
0005432880823	2934	53	17A
0005432706971	2934	54	17C
0005432706966	2934	55	17E
0005433123942	2934	56	17F
0005433123848	2934	57	18A
0005432880751	2934	58	19A
0005432217799	2934	59	19D
0005432706963	2934	60	19F
0005432706972	2934	61	20A
0005432706975	2934	62	20C
0005432880809	2934	63	20D
0005432880820	2934	64	20F
0005432693327	30073	1	1A
0005433124095	30073	2	1C
0005432880939	30073	3	1D
0005432706866	30073	4	1F
0005432693340	30073	5	2A
0005432880937	30073	6	2C
0005432706685	30073	7	2D
0005432706859	30073	8	2F
0005433124091	30073	9	3A
0005432706789	30073	10	3C
0005432706762	30073	11	3D
0005433124090	30073	12	3F
0005432706793	30073	13	4A
0005432693332	30073	14	4C
0005432880935	30073	15	4D
0005432693319	30073	16	4E
0005432880929	30073	17	4F
0005432693346	30073	18	5A
0005433124082	30073	19	5C
0005432693343	30073	20	5D
0005433124084	30073	21	5E
0005433124092	30073	22	5F
0005432706781	30073	23	6A
0005432693324	30073	24	6C
0005433124078	30073	25	6D
0005432693320	30073	26	6E
0005433124088	30073	27	6F
0005432693331	30073	28	7A
0005433124085	30073	29	7C
0005432706660	30073	30	7D
0005432880940	30073	31	7E
0005432693347	30073	32	7F
0005433124086	30073	33	8A
0005432693337	30073	34	8C
0005432693326	30073	35	8D
0005432693335	30073	36	8E
0005432706831	30073	37	8F
0005432880927	30073	38	9A
0005432706659	30073	39	9C
0005432706686	30073	40	9D
0005433124089	30073	41	9E
0005433124093	30073	42	9F
0005432706852	30073	43	10A
0005432693336	30073	44	10C
0005432693334	30073	45	10D
0005432706643	30073	46	10E
0005432706867	30073	47	10F
0005433124076	30073	48	11A
0005432693342	30073	49	11C
0005432880934	30073	50	11D
0005432693322	30073	51	11E
0005432693341	30073	52	11F
0005432880930	30073	53	12A
0005432706771	30073	54	12C
0005432693316	30073	55	12D
0005432880933	30073	56	12E
0005432880931	30073	57	12F
0005432880941	30073	58	13A
0005433124074	30073	59	13C
0005432693318	30073	60	13D
0005433124083	30073	61	13E
0005433124077	30073	62	13F
0005432706796	30073	63	14A
0005432880938	30073	64	14C
0005432706767	30073	65	14D
0005432706758	30073	66	14E
0005433124081	30073	67	14F
0005432880932	30073	68	15A
0005432706851	30073	69	15C
0005432693344	30073	70	15D
0005432693329	30073	71	15E
0005432693339	30073	72	15F
0005432693321	30073	73	16A
0005432693325	30073	74	16C
0005433124075	30073	75	16D
0005432706649	30073	76	16E
0005432706706	30073	77	16F
0005432706835	30073	78	17A
0005432706746	30073	79	17C
0005433194876	30073	80	17D
0005432693330	30073	81	17E
0005432693345	30073	82	17F
0005432693317	30073	83	18A
0005433124087	30073	84	18C
0005432880926	30073	85	18D
0005432693333	30073	86	18E
0005432880936	30073	87	18F
0005432706770	30073	88	19A
0005433124079	30073	89	19C
0005433124096	30073	90	19D
0005432693323	30073	91	19E
0005432693328	30073	92	19F
0005432693338	30073	93	20A
0005433124080	30073	94	20C
0005432706707	30073	95	20D
0005433124094	30073	96	20E
0005432880928	30073	97	20F
0005434980001	23700	1	1C
0005434980004	23700	2	1D
0005434980002	23700	3	2A
0005434988816	23700	4	2B
0005434980019	23700	5	2C
0005434980012	23700	6	3A
0005434980014	23700	7	3B
0005434988820	23700	8	3C
0005434979994	23700	9	3D
0005434980016	23700	10	4B
0005434980009	23700	11	4C
0005434988813	23700	12	5A
0005434980005	23700	13	5B
0005434980017	23700	14	5C
0005434980015	23700	15	5D
0005434979993	23700	16	6A
0005434988817	23700	17	6B
0005434988814	23700	18	6C
0005434980003	23700	19	7B
0005434979995	23700	20	7A
0005434980010	23700	21	7C
0005434980008	23700	22	7D
0005434979999	23700	23	18A
0005434979998	23700	24	18C
0005434980018	23700	25	19A
0005434979997	23700	26	19B
0005434980006	23700	27	19C
0005434988819	23700	28	20A
0005434988818	23700	29	20B
0005434988812	23700	30	20C
0005434980013	23700	31	20D
0005434979992	23700	32	21A
0005434988815	23700	33	21B
0005434979996	23700	34	21C
0005434980020	23700	35	22A
0005434980011	23700	36	22B
0005434980000	23700	37	22D
0005434980007	23700	38	23A
0005434979991	23700	39	23B
0005434979680	27561	1	1A
0005434979681	27561	2	1B
0005434979725	27561	3	1D
0005434979704	27561	4	2A
0005434979735	27561	5	2B
0005434979769	27561	6	2C
0005434979715	27561	7	2D
0005434979814	27561	8	3A
0005434988693	27561	9	3D
0005434979682	27561	10	4A
0005434979642	27561	11	4B
0005434979878	27561	12	4C
0005434979703	27561	13	4D
0005434988695	27561	14	5A
0005434988685	27561	15	5B
0005434979796	27561	16	5C
0005434979705	27561	17	5D
0005434979723	27561	18	6A
0005434979879	27561	19	6B
0005434979821	27561	20	6C
0005434988683	27561	21	7A
0005434979650	27561	22	7B
0005434988702	27561	23	18A
0005434988694	27561	24	18C
0005434979683	27561	25	18D
0005434988684	27561	26	19A
0005434988707	27561	27	19B
0005434979801	27561	28	19C
0005434979792	27561	29	19D
0005434979795	27561	30	20A
0005434979724	27561	31	20B
0005434979770	27561	32	20D
0005434979651	27561	33	21A
0005434979655	27561	34	21B
0005434979737	27561	35	21C
0005434979690	27561	36	21D
0005434988692	27561	37	22A
0005434979691	27561	38	22C
0005434979747	27561	39	22D
0005434979624	27561	40	23B
0005434302488	10255	1	1A
0005433111497	10255	2	1D
0005433113533	10255	3	4C
0005434302491	10255	4	5C
0005434302489	10255	5	5D
0005434302490	10255	6	6D
0005433111491	10255	7	19B
0005434302492	10255	8	23A
0005433111490	10255	9	23B
0005433113554	19591	1	3C
0005434302439	19591	2	4B
0005434302440	19591	3	21D
0005435069491	3570	1	1A
0005435069523	3570	2	1C
0005435069485	3570	3	1D
0005435069492	3570	4	1F
0005435069483	3570	5	2C
0005435069487	3570	6	2D
0005435069535	3570	7	3A
0005435069518	3570	8	4C
0005435069527	3570	9	4E
0005435069510	3570	10	4F
0005435069494	3570	11	5A
0005435925266	3570	12	5C
0005435069497	3570	13	5D
0005435925267	3570	14	5E
0005435925275	3570	15	6D
0005435069526	3570	16	6E
0005435069515	3570	17	6F
0005435718994	3570	18	7C
0005435069502	3570	19	7D
0005435069505	3570	20	7F
0005435069519	3570	21	8A
0005435925332	3570	22	8C
0005435925292	3570	23	8D
0005435069511	3570	24	8F
0005435069525	3570	25	9A
0005435069530	3570	26	9C
0005435069489	3570	27	9D
0005435069493	3570	28	9F
0005435069509	3570	29	10C
0005435069516	3570	30	10D
0005435069501	3570	31	10E
0005435069488	3570	32	10F
0005435069529	3570	33	11A
0005435925274	3570	34	11C
0005435069533	3570	35	11D
0005435939876	3570	36	11E
0005435718992	3570	37	11F
0005435925309	3570	38	12A
0005435925276	3570	39	12C
0005435069531	3570	40	12F
0005435069503	3570	41	13A
0005435069517	3570	42	13C
0005435069496	3570	43	13E
0005435069506	3570	44	13F
0005435069508	3570	45	14C
0005435925303	3570	46	14D
0005435925257	3570	47	14E
0005435069513	3570	48	15C
0005435069532	3570	49	15D
0005435069534	3570	50	15E
0005435069524	3570	51	15F
0005435925308	3570	52	16A
0005435925291	3570	53	16C
0005435069521	3570	54	16D
0005435069498	3570	55	16E
0005435069486	3570	56	16F
0005435069520	3570	57	17A
0005435069500	3570	58	17D
0005435069504	3570	59	17F
0005435069514	3570	60	18A
0005435925333	3570	61	18C
0005435069512	3570	62	18D
0005435069484	3570	63	18E
0005435069499	3570	64	19A
0005435069522	3570	65	19C
0005435069490	3570	66	19D
0005435069495	3570	67	19F
0005435069528	3570	68	20A
0005435925226	3570	69	20C
0005435718993	3570	70	20E
0005435069507	3570	71	20F
0005435068903	15295	1	1A
0005435068909	15295	2	1C
0005435068873	15295	3	1D
0005435925391	15295	4	1F
0005435925392	15295	5	2C
0005435068821	15295	6	2D
0005435925404	15295	7	3A
0005435069253	15295	8	3D
0005435068886	15295	9	4A
0005435068820	15295	10	4C
0005435068994	15295	11	4D
0005435069011	15295	12	4E
0005435068944	15295	13	5C
0005435069156	15295	14	5D
0005435925403	15295	15	6A
0005435068849	15295	16	6C
0005435925402	15295	17	6D
0005435069231	15295	18	6E
0005435068910	15295	19	6F
0005435925388	15295	20	7A
0005435069139	15295	21	7D
0005435925393	15295	22	7E
0005435069104	15295	23	7F
0005435069101	15295	24	8A
0005435068850	15295	25	8C
0005435068940	15295	26	8D
0005435925407	15295	27	8F
0005435068960	15295	28	9A
0005435925399	15295	29	9C
0005435069191	15295	30	9D
0005435925397	15295	31	9E
0005435925411	15295	32	9F
0005435068907	15295	33	10A
0005435068959	15295	34	10C
0005435069107	15295	35	10D
0005435069006	15295	36	10E
0005435069010	15295	37	10F
0005435068887	15295	38	11C
0005435925387	15295	39	11D
0005435068996	15295	40	11E
0005435068902	15295	41	11F
0005435068945	15295	42	12A
0005435069130	15295	43	12D
0005435068979	15295	44	12F
0005435068978	15295	45	13C
0005435069169	15295	46	13D
0005435068819	15295	47	13E
0005435068972	15295	48	13F
0005435069005	15295	49	14A
0005435925406	15295	50	14C
0005435925395	15295	51	14D
0005435925394	15295	52	14F
0005435925410	15295	53	15C
0005435925390	15295	54	15D
0005435925405	15295	55	15E
0005435068920	15295	56	16A
0005435925409	15295	57	15F
0005435068908	15295	58	16E
0005435069029	15295	59	16F
0005435925398	15295	60	17A
0005435069103	15295	61	17D
0005435925389	15295	62	17E
0005435069232	15295	63	17F
0005435925396	15295	64	18A
0005435068995	15295	65	18C
0005435925400	15295	66	18D
0005435068973	15295	67	19A
0005435069100	15295	68	19C
0005435068882	15295	69	19D
0005435925401	15295	70	19E
0005435068965	15295	71	19F
0005435925408	15295	72	20A
0005435069157	15295	73	20C
0005435068872	15295	74	20E
0005432660836	18128	1	1A
0005432659724	18128	2	2A
0005432659722	18128	3	3A
0005432659723	18128	4	5A
0005432660835	18128	5	6B
0005432664137	26374	1	1A
0005432664142	26374	2	2A
0005432667456	26374	3	2B
0005432664141	26374	4	4A
0005432664114	26374	5	5A
0005432664136	26374	6	6A
0005432660820	26374	7	6B
0005433102202	85	1	1A
0005432919866	85	2	1C
0005432919802	85	3	1D
0005432919931	85	4	2A
0005432919766	85	5	2D
0005432919834	85	6	2F
0005432919752	85	7	3C
0005432919892	85	8	3D
0005432919927	85	9	4A
0005432901475	85	10	3F
0005432919753	85	11	4C
0005433102164	85	12	4F
0005432901634	85	13	4D
0005432901692	85	14	5A
0005433102120	85	15	5D
0005433101998	85	16	6A
0005433102063	85	17	5F
0005432677557	85	18	6C
0005432919928	85	19	6F
0005433102132	85	20	7C
0005433102125	85	21	7F
0005433101972	85	22	8A
0005432919853	85	23	8D
0005433102135	85	24	8E
0005432901556	85	25	8F
0005433102194	85	26	9A
0005432919843	85	27	9C
0005433102095	85	28	9D
0005433102154	85	29	10A
0005433102068	85	30	10B
0005432677556	85	31	10C
0005433102104	85	32	10F
0005433102091	85	33	11B
0005432901661	85	34	11C
0005433102127	85	35	11E
0005433102221	85	36	11F
0005432677587	85	37	12C
0005433102155	85	38	12B
0005433102196	85	39	12E
0005433102134	85	40	12D
0005432901618	85	41	13B
0005433101943	85	42	13A
0005432901707	85	43	13C
0005432919865	85	44	13D
0005433102137	85	45	14A
0005433102055	85	46	14B
0005433102206	85	47	14C
0005432677565	85	48	14E
0005433102193	85	49	15A
0005433102233	85	50	16B
0005433102122	85	51	16C
0005432901557	85	52	16E
0005432901491	85	53	17A
0005433102195	85	54	17C
0005433101920	85	55	17E
0005432901691	85	56	17D
0005432919914	85	57	18B
0005433101949	85	58	18D
0005432919848	85	59	18E
0005432901617	85	60	19D
0005433102064	85	61	19E
0005433102179	85	62	20C
0005432677586	85	63	20B
0005433102238	85	64	20D
0005432677549	85	65	20F
0005432901490	85	66	20E
0005432157508	85	67	21C
0005432677564	85	68	21E
0005432919881	85	69	22B
0005433102231	85	70	22C
0005433102176	85	71	22F
0005432919867	85	72	22E
0005433102165	85	73	23B
0005433101950	85	74	23A
0005432901662	85	75	23C
0005432919850	85	76	23D
0005433102220	85	77	23E
0005433102136	85	78	24B
0005433101999	85	79	24A
0005432919847	85	80	24D
0005433102121	85	81	24C
0005433101996	85	82	24F
0005433101986	85	83	25B
0005433102146	85	84	25A
0005432677578	85	85	25C
0005432919882	85	86	25E
0005433102191	85	87	26A
0005432901685	85	88	25F
0005432901476	85	89	26E
0005432919849	85	90	27B
0005433102083	85	91	27C
0005432901658	85	92	27F
0005432901633	85	93	28A
0005432919830	85	94	28C
0005432919822	85	95	28F
0005433102105	85	96	29C
0005433102084	85	97	29B
0005433102119	85	98	29F
0005432901607	85	99	30C
0005432919891	85	100	31A
0005432901604	85	101	31C
0005433102019	85	102	31B
0005433102096	85	103	31E
0005432817714	86	1	1A
0005432817727	86	2	1D
0005432817726	86	3	2A
0005432817701	86	4	2F
0005432817721	86	5	4A
0005432262268	86	6	4C
0005432817707	86	7	5A
0005432262258	86	8	5C
0005432817698	86	9	5F
0005432262262	86	10	6A
0005432817706	86	11	7A
0005432262261	86	12	6F
0005432262267	86	13	8A
0005432262259	86	14	8B
0005432262271	86	15	8E
0005432262263	86	16	8D
0005432262297	86	17	9C
0005432262281	86	18	9D
0005432817704	86	19	9F
0005432262280	86	20	9E
0005432756825	86	21	10A
0005432262288	86	22	10E
0005432817710	86	23	10D
0005432262302	86	24	10F
0005432262299	86	25	11B
0005432207683	86	26	11E
0005432817711	86	27	11D
0005432207679	86	28	11F
0005432817700	86	29	12B
0005433687697	86	30	12C
0005432817708	86	31	13A
0005432817715	86	32	13E
0005432262273	86	33	13D
0005432262275	86	34	13C
0005432262293	86	35	14B
0005432817720	86	36	14E
0005432817705	86	37	15B
0005432817713	86	38	15E
0005432262300	86	39	15F
0005432262278	86	40	16B
0005432262284	86	41	16D
0005432262296	86	42	16E
0005432262289	86	43	17A
0005432262264	86	44	16F
0005432262294	86	45	17B
0005432817716	86	46	17C
0005432262266	86	47	17F
0005432289012	86	48	17E
0005432262277	86	49	18A
0005432262260	86	50	18D
0005432817699	86	51	18E
0005432753291	86	52	18F
0005432262265	86	53	19C
0005432817718	86	54	19B
0005432753292	86	55	19E
0005432817709	86	56	20A
0005432262301	86	57	20C
0005432817719	86	58	20D
0005432262276	86	59	20F
0005432817703	86	60	20E
0005432289014	86	61	21B
0005432262282	86	62	21A
0005432207680	86	63	21D
0005432207682	86	64	21E
0005432262269	86	65	22B
0005432753297	86	66	22D
0005432817723	86	67	22E
0005432262257	86	68	23D
0005432262298	86	69	23F
0005432207681	86	70	24F
0005432262272	86	71	25A
0005432262270	86	72	25B
0005432817725	86	73	25E
0005432262285	86	74	25D
0005432262286	86	75	26B
0005432289011	86	76	26E
0005432262279	86	77	26D
0005432817717	86	78	26F
0005432756821	86	79	27C
0005432817724	86	80	27F
0005432262283	86	81	28E
0005432262287	86	82	29A
0005432289013	86	83	29B
0005432817702	86	84	29D
0005432262295	86	85	30A
0005432262290	86	86	29F
0005432817712	86	87	30B
0005432262274	86	88	30D
0005432262291	86	89	30F
0005432262292	86	90	31A
0005432817722	86	91	31E
0005432045630	7941	1	1A
0005433102553	7941	2	1C
0005432020491	7941	3	1D
0005432920019	7941	4	2A
0005432044548	7941	5	2F
0005433102535	7941	6	2D
0005432020481	7941	7	3A
0005432920017	7941	8	3D
0005432920032	7941	9	4A
0005432920037	7941	10	4C
0005433102587	7941	11	4F
0005433102591	7941	12	4D
0005433102545	7941	13	5A
0005433102536	7941	14	5C
0005433102571	7941	15	5F
0005433102586	7941	16	5D
0005433102568	7941	17	6C
0005433102579	7941	18	6D
0005433102549	7941	19	7A
0005433102566	7941	20	6F
0005432677605	7941	21	7C
0005432020488	7941	22	7F
0005433102561	7941	23	7D
0005432020482	7941	24	8A
0005433102578	7941	25	8C
0005432392023	7941	26	8E
0005433102575	7941	27	8F
0005433102590	7941	28	9C
0005433102547	7941	29	9D
0005433102530	7941	30	9F
0005432920036	7941	31	10A
0005432920025	7941	32	10B
0005432753328	7941	33	10D
0005433102557	7941	34	10E
0005432753329	7941	35	10F
0005433102551	7941	36	11A
0005432751554	7941	37	11C
0005432020470	7941	38	11B
0005433102574	7941	39	11D
0005433102556	7941	40	11F
0005432020475	7941	41	12A
0005433102537	7941	42	12B
0005433102572	7941	43	12D
0005432044549	7941	44	12E
0005433102554	7941	45	12F
0005433102582	7941	46	13A
0005433102555	7941	47	13C
0005432020472	7941	48	13B
0005433102576	7941	49	13F
0005432020483	7941	50	14B
0005433102581	7941	51	14D
0005433102560	7941	52	14C
0005433102528	7941	53	14F
0005433102564	7941	54	15C
0005433102570	7941	55	16D
0005432920031	7941	56	16C
0005433102580	7941	57	16F
0005432753327	7941	58	16E
0005432920029	7941	59	17B
0005433102548	7941	60	17A
0005433102583	7941	61	17D
0005432020469	7941	62	17F
0005432677607	7941	63	18A
0005433102540	7941	64	18B
0005432020485	7941	65	18D
0005432020477	7941	66	18C
0005432392025	7941	67	18E
0005432920024	7941	68	19B
0005432920023	7941	69	19C
0005432920035	7941	70	19D
0005432020478	7941	71	19E
0005433102538	7941	72	20B
0005433102565	7941	73	20A
0005432920027	7941	74	20C
0005432020476	7941	75	20D
0005433102563	7941	76	20F
0005433102573	7941	77	20E
0005432020473	7941	78	21A
0005432920034	7941	79	21B
0005432044547	7941	80	21D
0005432020480	7941	81	21C
0005433102588	7941	82	22A
0005432020486	7941	83	22B
0005432020489	7941	84	22C
0005433102539	7941	85	22D
0005432677608	7941	86	22F
0005432020465	7941	87	22E
0005432753331	7941	88	23A
0005432677606	7941	89	23B
0005432392024	7941	90	23C
0005433102562	7941	91	23E
0005433102546	7941	92	23F
0005432920030	7941	93	24A
0005433102592	7941	94	24C
0005432920018	7941	95	24F
0005432920033	7941	96	24E
0005432020466	7941	97	25C
0005432920028	7941	98	25B
0005433102577	7941	99	25D
0005433102589	7941	100	25F
0005433102531	7941	101	25E
0005432020468	7941	102	26B
0005433102542	7941	103	26C
0005432751555	7941	104	26E
0005433102543	7941	105	27A
0005433102532	7941	106	26F
0005433102544	7941	107	27C
0005432920021	7941	108	27B
0005433102567	7941	109	27D
0005433102559	7941	110	27F
0005433102569	7941	111	27E
0005432753330	7941	112	28A
0005432751553	7941	113	28B
0005432020490	7941	114	28D
0005433102558	7941	115	28C
0005432020474	7941	116	28E
0005432920026	7941	117	28F
0005433102585	7941	118	29B
0005432020471	7941	119	29C
0005433102584	7941	120	29E
0005432020487	7941	121	29D
0005433102534	7941	122	29F
0005432920020	7941	123	30A
0005433102550	7941	124	30B
0005432020484	7941	125	30C
0005432020492	7941	126	30E
0005433102541	7941	127	30D
0005433102529	7941	128	30F
0005433102552	7941	129	31B
0005432920022	7941	130	31C
0005433102533	7941	131	31E
0005432020479	7941	132	31D
0005432020467	7941	133	31F
0005432901747	7943	1	1A
0005432002093	7943	2	1F
0005434513569	7943	3	1D
0005434513582	7943	4	2A
0005432817662	7943	5	2D
0005432817375	7943	6	3A
0005432817307	7943	7	3C
0005434513561	7943	8	3D
0005432817425	7943	9	3F
0005432901744	7943	10	4C
0005432817524	7943	11	4F
0005432817461	7943	12	5F
0005434513562	7943	13	5D
0005432817544	7943	14	6D
0005432817510	7943	15	6A
0005432817369	7943	16	7D
0005432901748	7943	17	7C
0005434513572	7943	18	7F
0005432901751	7943	19	8A
0005432901743	7943	20	8B
0005432901745	7943	21	8E
0005432901755	7943	22	8F
0005432901753	7943	23	9B
0005432817384	7943	24	9A
0005432901758	7943	25	9C
0005432817478	7943	26	10B
0005432901746	7943	27	10C
0005432901750	7943	28	10E
0005432817343	7943	29	11C
0005432901759	7943	30	11B
0005434513570	7943	31	11E
0005434513580	7943	32	12A
0005432817496	7943	33	13B
0005434513563	7943	34	13C
0005432817382	7943	35	13D
0005432817394	7943	36	14A
0005434513589	7943	37	14C
0005432817292	7943	38	14E
0005432817454	7943	39	15F
0005432817448	7943	40	16B
0005432817511	7943	41	16E
0005432002092	7943	42	17C
0005432817366	7943	43	17B
0005434513576	7943	44	18A
0005432817360	7943	45	18D
0005434513581	7943	46	18C
0005432817431	7943	47	19D
0005432817374	7943	48	19E
0005432817538	7943	49	20A
0005432817406	7943	50	20C
0005434513583	7943	51	20D
0005434513590	7943	52	21D
0005434513567	7943	53	22A
0005432817449	7943	54	21F
0005432817534	7943	55	22B
0005432817306	7943	56	22E
0005432817342	7943	57	23D
0005434513564	7943	58	23E
0005432901752	7943	59	24E
0005434513577	7943	60	25A
0005434513571	7943	61	25E
0005432901754	7943	62	26B
0005432901756	7943	63	26D
0005432901757	7943	64	27D
0005432817663	7943	65	28A
0005432901749	7943	66	28C
0005432817385	7943	67	28D
0005432817501	7943	68	29A
0005434513578	7943	69	29C
0005432817545	7943	70	30C
0005432901760	7943	71	30E
0005434513591	7943	72	30F
0005432817376	7943	73	31A
0005434513568	7943	74	31E
0005433870749	9653	1	2A
0005434175759	9653	2	4A
0005433870748	9653	3	4B
0005434175768	9653	4	5B
0005434175753	9653	5	6A
0005434175767	9653	6	6B
0005433870729	32375	1	1A
0005434175789	32375	2	2A
0005434175788	32375	3	3B
0005434175786	32375	4	3A
0005434175785	32375	5	4A
0005433870730	32375	6	5A
0005433870725	32375	7	6A
0005434175787	32375	8	6B
0005434426841	3474	1	1D
0005434878964	3474	2	1C
0005435626319	3474	3	1A
0005434879031	3474	4	2A
0005434878991	3474	5	1K
0005435913923	3474	6	1H
0005435902659	3474	7	2D
0005435626323	3474	8	2C
0005434938295	3474	9	2H
0005432799690	3474	10	3A
0005434878977	3474	11	2K
0005435126724	3474	12	3D
0005434938312	3474	13	3K
0005434879016	3474	14	4C
0005435902592	3474	15	4A
0005435626320	3474	16	4G
0005432799680	3474	17	5A
0005435902690	3474	18	4H
0005435626318	3474	19	5D
0005434938297	3474	20	5C
0005435902593	3474	21	5H
0005435626329	3474	22	5K
0005435626326	3474	23	11E
0005434879021	3474	24	11D
0005435626317	3474	25	11G
0005435126705	3474	26	11F
0005435126718	3474	27	11K
0005432188635	3474	28	11H
0005434879011	3474	29	12C
0005435126690	3474	30	12E
0005434879043	3474	31	12D
0005435126709	3474	32	12K
0005435126710	3474	33	12H
0005434879044	3474	34	13D
0005434879002	3474	35	13C
0005435902647	3474	36	13A
0005435626336	3474	37	13G
0005432611743	3474	38	14A
0005434879023	3474	39	13K
0005435126699	3474	40	14D
0005434938299	3474	41	14G
0005434879005	3474	42	14E
0005432799679	3474	43	15C
0005435126720	3474	44	15A
0005434878979	3474	45	15D
0005434879006	3474	46	15G
0005432799699	3474	47	15F
0005435126707	3474	48	15H
0005435902716	3474	49	16C
0005435126729	3474	50	16E
0005434426857	3474	51	16G
0005434878990	3474	52	17C
0005435902688	3474	53	17A
0005434878992	3474	54	16K
0005435126711	3474	55	17G
0005434426860	3474	56	17F
0005434879019	3474	57	17E
0005435626322	3474	58	17K
0005434879042	3474	59	17H
0005434426861	3474	60	18E
0005432799696	3474	61	18C
0005434879038	3474	62	18G
0005434879029	3474	63	18F
0005435126715	3474	64	18K
0005434426863	3474	65	18J
0005432611748	3474	66	19B
0005434879015	3474	67	19A
0005432799697	3474	68	19D
0005434878980	3474	69	19C
0005435126706	3474	70	19F
0005432799702	3474	71	19J
0005435126698	3474	72	19G
0005434879007	3474	73	20A
0005432611745	3474	74	19K
0005432799676	3474	75	20C
0005435126700	3474	76	20B
0005434426869	3474	77	20D
0005434938308	3474	78	20F
0005434426842	3474	79	20K
0005432799685	3474	80	21A
0005435126689	3474	81	21C
0005434879051	3474	82	21B
0005434879024	3474	83	21F
0005435126692	3474	84	21E
0005435126731	3474	85	21J
0005434878997	3474	86	21H
0005432183484	3474	87	21G
0005434878998	3474	88	22A
0005432799692	3474	89	21K
0005434426851	3474	90	22D
0005432611744	3474	91	22C
0005434878966	3474	92	22B
0005434879022	3474	93	22E
0005435913924	3474	94	22H
0005434426838	3474	95	22G
0005432799694	3474	96	22K
0005435126702	3474	97	23B
0005434879045	3474	98	23D
0005434879041	3474	99	23C
0005434938307	3474	100	23F
0005434879014	3474	101	23E
0005434879032	3474	102	23J
0005434878988	3474	103	24D
0005432611742	3474	104	23K
0005435626325	3474	105	24G
0005434879036	3474	106	24F
0005435626316	3474	107	24E
0005434938302	3474	108	25B
0005432799704	3474	109	25A
0005434938303	3474	110	25C
0005434938306	3474	111	25F
0005435902731	3474	112	25E
0005432799678	3474	113	25G
0005434878962	3474	114	25K
0005432613895	3474	115	26C
0005432799703	3474	116	26B
0005435626338	3474	117	26G
0005434426867	3474	118	26F
0005434938304	3474	119	26K
0005434879047	3474	120	26H
0005435626339	3474	121	27A
0005435626328	3474	122	27D
0005432799701	3474	123	27C
0005434878969	3474	124	27F
0005434878981	3474	125	27H
0005435126695	3474	126	27K
0005435126696	3474	127	27J
0005434938298	3474	128	28C
0005435126723	3474	129	28B
0005435902714	3474	130	28E
0005434426856	3474	131	28G
0005434878986	3474	132	28F
0005432188634	3474	133	28H
0005434938311	3474	134	29A
0005435913929	3474	135	29D
0005434426850	3474	136	29F
0005432799700	3474	137	30A
0005434878985	3474	138	29K
0005432188636	3474	139	30B
0005434879001	3474	140	30E
0005435626333	3474	141	30D
0005434426839	3474	142	30G
0005434878972	3474	143	30J
0005435126697	3474	144	31A
0005434426864	3474	145	31F
0005432611747	3474	146	31H
0005434879028	3474	147	31G
0005434879039	3474	148	32A
0005434879049	3474	149	32C
0005434938300	3474	150	32B
0005434878976	3474	151	32D
0005434426865	3474	152	32G
0005432799688	3474	153	32F
0005434879030	3474	154	32J
0005434938309	3474	155	33B
0005434879052	3474	156	33A
0005435126725	3474	157	32K
0005434878971	3474	158	33D
0005435126728	3474	159	33C
0005435902781	3474	160	33G
0005434879048	3474	161	33E
0005434879018	3474	162	34A
0005434426866	3474	163	33K
0005434878989	3474	164	33J
0005434426846	3474	165	34B
0005434938301	3474	166	34E
0005432799687	3474	167	34D
0005434878994	3474	168	34G
0005435126713	3474	169	34J
0005434879009	3474	170	34H
0005434426844	3474	171	35D
0005434879050	3474	172	35C
0005432611746	3474	173	35F
0005435902696	3474	174	35E
0005435126716	3474	175	35J
0005434426852	3474	176	35H
0005434426862	3474	177	35G
0005434878970	3474	178	36A
0005434878973	3474	179	36C
0005434879053	3474	180	36B
0005432613897	3474	181	36D
0005435126730	3474	182	36H
0005434878958	3474	183	36G
0005434878961	3474	184	36F
0005434938293	3474	185	36K
0005432799695	3474	186	36J
0005435626331	3474	187	37B
0005434426858	3474	188	37A
0005434879027	3474	189	37C
0005434878959	3474	190	37F
0005435126708	3474	191	37E
0005434426849	3474	192	37H
0005434878987	3474	193	37G
0005435913922	3474	194	38A
0005434879040	3474	195	37J
0005435626327	3474	196	38C
0005435902730	3474	197	38B
0005435126714	3474	198	38J
0005434879003	3474	199	38H
0005432183485	3474	200	39B
0005434879054	3474	201	39A
0005434879012	3474	202	38K
0005432799689	3474	203	39D
0005434878960	3474	204	39C
0005434426854	3474	205	39E
0005434878967	3474	206	39H
0005432799691	3474	207	39G
0005434879025	3474	208	39K
0005435126727	3474	209	40C
0005435126719	3474	210	40B
0005435126717	3474	211	40E
0005434426855	3474	212	40D
0005434426853	3474	213	40H
0005434879034	3474	214	40G
0005434426847	3474	215	40F
0005435126704	3474	216	41B
0005434879017	3474	217	40K
0005434938313	3474	218	41D
0005435626330	3474	219	41C
0005432799693	3474	220	41F
0005434426848	3474	221	41E
0005435626321	3474	222	41J
0005432799705	3474	223	41H
0005435626324	3474	224	41G
0005432799698	3474	225	41K
0005435626337	3474	226	42C
0005432799706	3474	227	42B
0005434426840	3474	228	42D
0005434878993	3474	229	42G
0005435902738	3474	230	42J
0005435902733	3474	231	42H
0005434879013	3474	232	43A
0005434426843	3474	233	42K
0005434426845	3474	234	43C
0005435126722	3474	235	43F
0005434938310	3474	236	43E
0005434878982	3474	237	43D
0005434879004	3474	238	43G
0005432799684	3474	239	43K
0005434879000	3474	240	43J
0005434426859	3474	241	44B
0005435126688	3474	242	44A
0005435126703	3474	243	44E
0005434938305	3474	244	44C
0005432799683	3474	245	44F
0005434878995	3474	246	44J
0005432188633	3474	247	44H
0005434878965	3474	248	45A
0005432799686	3474	249	45D
0005432799677	3474	250	45C
0005434879035	3474	251	45G
0005434878999	3474	252	45F
0005434879033	3474	253	45E
0005435126701	3474	254	45H
0005434879046	3474	255	45K
0005434426868	3474	256	45J
0005434938296	3474	257	46B
0005434878975	3474	258	46A
0005435126721	3474	259	46E
0005434878983	3474	260	46C
0005434879037	3474	261	46G
0005434879008	3474	262	46F
0005434878978	3474	263	46H
0005432799681	3474	264	47C
0005434878984	3474	265	46K
0005432799682	3474	266	47F
0005435126691	3474	267	47K
0005434878963	3474	268	47H
0005434879010	3474	269	48A
0005434879020	3474	270	48F
0005435126693	3474	271	48E
0005435126726	3474	272	48D
0005434878974	3474	273	48H
0005434878968	3474	274	48G
0005434938294	3474	275	49C
0005435626332	3474	276	49F
0005435626335	3474	277	49E
0005434879026	3474	278	50C
0005432613896	3474	279	50A
0005435126694	3474	280	50E
0005434878996	3474	281	50D
0005435626334	3474	282	50H
0005435902707	3474	283	50G
0005435902715	3474	284	50F
0005432613894	3474	285	51D
0005435126712	3474	286	50K
0005434426537	14537	1	1A
0005435126312	14537	2	1G
0005435902848	14537	3	2A
0005435842331	14537	4	1K
0005435126434	14537	5	2D
0005434878048	14537	6	2C
0005435126293	14537	7	3A
0005434878201	14537	8	2K
0005434938216	14537	9	3G
0005432611722	14537	10	3D
0005434877901	14537	11	3C
0005435126330	14537	12	4A
0005435126360	14537	13	3K
0005434938209	14537	14	4G
0005432799475	14537	15	4D
0005434878352	14537	16	5A
0005435126231	14537	17	5C
0005435126151	14537	18	11A
0005434426535	14537	19	5K
0005434938212	14537	20	11D
0005435126247	14537	21	11C
0005435126277	14537	22	11E
0005434426562	14537	23	11K
0005435126370	14537	24	12C
0005435126431	14537	25	12A
0005435902850	14537	26	12E
0005435126292	14537	27	12G
0005434426453	14537	28	13A
0005435126246	14537	29	12K
0005434938162	14537	30	12H
0005434878123	14537	31	13D
0005435126223	14537	32	13F
0005434878012	14537	33	13E
0005434878284	14537	34	13K
0005434877753	14537	35	13H
0005434878346	14537	36	14A
0005435126414	14537	37	14D
0005435902842	14537	38	14C
0005432799386	14537	39	14G
0005435126254	14537	40	14F
0005434426612	14537	41	14K
0005435626120	14537	42	15C
0005435126241	14537	43	15A
0005434878212	14537	44	15E
0005435913955	14537	45	15D
0005434938126	14537	46	15H
0005435914701	14537	47	15G
0005434878168	14537	48	15F
0005434878343	14537	49	16A
0005432799358	14537	50	15K
0005435626141	14537	51	16C
0005432799463	14537	52	16E
0005435913958	14537	53	16H
0005432799460	14537	54	17A
0005435626071	14537	55	17E
0005434877699	14537	56	17G
0005435902855	14537	57	17K
0005435126249	14537	58	17H
0005435126369	14537	59	18C
0005434938079	14537	60	18A
0005434878188	14537	61	18E
0005434878187	14537	62	18D
0005434878472	14537	63	18G
0005434878032	14537	64	18F
0005434426451	14537	65	19A
0005435126307	14537	66	19C
0005434878620	14537	67	19B
0005435841828	14537	68	19F
0005434426452	14537	69	19E
0005434878110	14537	70	19H
0005434877818	14537	71	19G
0005435126420	14537	72	20A
0005434878164	14537	73	19K
0005435126189	14537	74	20B
0005435126265	14537	75	20E
0005434938131	14537	76	20H
0005434938150	14537	77	20G
0005434426579	14537	78	20F
0005434426601	14537	79	21B
0005434878469	14537	80	21E
0005435902854	14537	81	21J
0005434878092	14537	82	21H
0005435626142	14537	83	21G
0005434877807	14537	84	22C
0005434878031	14537	85	22B
0005435126415	14537	86	22E
0005434878207	14537	87	22G
0005434878100	14537	88	22F
0005434877880	14537	89	22K
0005435126255	14537	90	22J
0005434878224	14537	91	23C
0005434877806	14537	92	23A
0005434877952	14537	93	23G
0005435626077	14537	94	23J
0005434878492	14537	95	24F
0005434938149	14537	96	25B
0005434877817	14537	97	25A
0005435126097	14537	98	25D
0005434878371	14537	99	25F
0005434878416	14537	100	25E
0005435126212	14537	101	25H
0005434938125	14537	102	25K
0005434426688	14537	103	25J
0005435126215	14537	104	26E
0005435626140	14537	105	26D
0005434878293	14537	106	26G
0005434878452	14537	107	26F
0005432799461	14537	108	26H
0005435626138	14537	109	27B
0005432799468	14537	110	27A
0005432799464	14537	111	27D
0005434426602	14537	112	27F
0005434877752	14537	113	27K
0005432799552	14537	114	28C
0005435626139	14537	115	28B
0005435126096	14537	116	28A
0005434877898	14537	117	28E
0005435126214	14537	118	28D
0005435902851	14537	119	28G
0005434938154	14537	120	29B
0005434878278	14537	121	29A
0005435126313	14537	122	28K
0005434878262	14537	123	29D
0005435126245	14537	124	29E
0005435626134	14537	125	29H
0005435902841	14537	126	29G
0005434878350	14537	127	29J
0005432799578	14537	128	30C
0005434426712	14537	129	30B
0005434878261	14537	130	30E
0005435126278	14537	131	30G
0005434426454	14537	132	30K
0005435126232	14537	133	30J
0005435126168	14537	134	30H
0005434877995	14537	135	31D
0005432799503	14537	136	31C
0005435626119	14537	137	31B
0005434878291	14537	138	31G
0005434878331	14537	139	31E
0005434426666	14537	140	31H
0005434878380	14537	141	31K
0005435626135	14537	142	32B
0005434426721	14537	143	32A
0005434878073	14537	144	32H
0005434938188	14537	145	32F
0005434426687	14537	146	33A
0005434426760	14537	147	33C
0005435626122	14537	148	33F
0005434878008	14537	149	33E
0005432799398	14537	150	33J
0005435626121	14537	151	33H
0005432059520	14537	152	33G
0005435626132	14537	153	33K
0005434938151	14537	154	34B
0005432799372	14537	155	34A
0005434878049	14537	156	34G
0005434878079	14537	157	34J
0005434938174	14537	158	34K
0005434938248	14537	159	35C
0005434878301	14537	160	35F
0005432611719	14537	161	35E
0005434878074	14537	162	35G
0005434878661	14537	163	36A
0005432799516	14537	164	35K
0005434878410	14537	165	35J
0005434878647	14537	166	36C
0005435902846	14537	167	36B
0005432799449	14537	168	36E
0005434878128	14537	169	36D
0005434426580	14537	170	37B
0005435126266	14537	171	37A
0005432059521	14537	172	37D
0005432799497	14537	173	37C
0005434938110	14537	174	37F
0005435126379	14537	175	37E
0005434426536	14537	176	37K
0005432799453	14537	177	37J
0005434878269	14537	178	38C
0005434878473	14537	179	38B
0005434878646	14537	180	38A
0005434938153	14537	181	38H
0005435841827	14537	182	39B
0005432799577	14537	183	39A
0005434878486	14537	184	39D
0005434878270	14537	185	39E
0005434938130	14537	186	39J
0005432799502	14537	187	40F
0005434878471	14537	188	40E
0005435913956	14537	189	40D
0005435913960	14537	190	40G
0005434938158	14537	191	40J
0005434426534	14537	192	40H
0005434426509	14537	193	41D
0005434426707	14537	194	41C
0005435626157	14537	195	41E
0005434426408	14537	196	41G
0005434426600	14537	197	42A
0005435126393	14537	198	41K
0005435126294	14537	199	42C
0005434938163	14537	200	42B
0005435902849	14537	201	42H
0005435902853	14537	202	42G
0005435126341	14537	203	42F
0005435126437	14537	204	43A
0005432799492	14537	205	43D
0005432799402	14537	206	43C
0005435126213	14537	207	43F
0005434878351	14537	208	43E
0005434878379	14537	209	43J
0005435902844	14537	210	43H
0005435902843	14537	211	44A
0005432799418	14537	212	44C
0005432799500	14537	213	44B
0005435126250	14537	214	44E
0005432607562	14537	215	44D
0005435126469	14537	216	44F
0005435626158	14537	217	44J
0005435126327	14537	218	45B
0005435626078	14537	219	45A
0005435126267	14537	220	44K
0005434878218	14537	221	45C
0005434878217	14537	222	45F
0005435913959	14537	223	45E
0005434878245	14537	224	45H
0005434878240	14537	225	45J
0005435126242	14537	226	46E
0005435902856	14537	227	46D
0005434878304	14537	228	46G
0005435126240	14537	229	46F
0005434878080	14537	230	46J
0005434878650	14537	231	46H
0005432799397	14537	232	47A
0005435126244	14537	233	46K
0005434878200	14537	234	47D
0005435126188	14537	235	47F
0005432611720	14537	236	47K
0005435126339	14537	237	47H
0005434426476	14537	238	48C
0005435626131	14537	239	48E
0005432799371	14537	240	48D
0005432607580	14537	241	48H
0005434878054	14537	242	48G
0005435902845	14537	243	49C
0005435126290	14537	244	49A
0005435913957	14537	245	48K
0005434878147	14537	246	49K
0005434878402	14537	247	49H
0005435902852	14537	248	50C
0005434877866	14537	249	50F
0005435913961	14537	250	50E
0005432799522	14537	251	50D
0005435626076	14537	252	50G
0005435126517	14537	253	51D
0005434878216	14537	254	50K
0005434426471	14537	255	51F
0005435902847	14537	256	51E
0005435902857	14537	257	51G
0005434325743	3639	1	1C
0005434325744	3639	2	2A
0005435889925	3639	3	2C
0005435889926	3639	4	2D
0005434325746	3639	5	3A
0005435889896	3639	6	4A
0005434325740	3639	7	5C
0005434325747	3639	8	7B
0005434325742	3639	9	7C
0005434312337	3639	10	7D
0005434325745	3639	11	18A
0005434325750	3639	12	18D
0005434325752	3639	13	19B
0005434325741	3639	14	19D
0005434325751	3639	15	20A
0005434325748	3639	16	20B
0005434312336	3639	17	20C
0005434325749	3639	18	21C
0005435889894	3639	19	22A
0005434325739	3639	20	22D
0005435889946	15617	1	2A
0005435889949	15617	2	2C
0005434325638	15617	3	2D
0005434325695	15617	4	3A
0005434325636	15617	5	3C
0005434325694	15617	6	4A
0005434325599	15617	7	5C
0005434325637	15617	8	6D
0005435889945	15617	9	7D
0005434325687	15617	10	18B
0005434325667	15617	11	18C
0005435889948	15617	12	20B
0005435889943	15617	13	20D
0005434325661	15617	14	21A
0005435889944	15617	15	21C
0005435889947	15617	16	22D
0005435957818	619	1	1A
0005433420390	619	2	1B
0005435957819	619	3	1C
0005433420395	619	4	2B
0005435957824	619	5	3B
0005435957823	619	6	3D
0005435957831	619	7	4A
0005435957822	619	8	4B
0005433420415	619	9	4C
0005433420402	619	10	4D
0005433420394	619	11	5B
0005433420393	619	12	5A
0005435957828	619	13	5C
0005435957827	619	14	5D
0005433420416	619	15	7A
0005435957821	619	16	7D
0005435957820	619	17	18B
0005435957829	619	18	18C
0005435957825	619	19	19C
0005435957830	619	20	21A
0005435957817	619	21	21C
0005433420392	619	22	21D
0005433420385	619	23	22B
0005435957826	619	24	22C
0005433420396	619	25	23A
0005433420391	619	26	23B
0005433420472	15153	1	1A
0005435957633	15153	2	1B
0005435957719	15153	3	1C
0005435957688	15153	4	1D
0005433420477	15153	5	2B
0005435957678	15153	6	2D
0005435957750	15153	7	3B
0005435957708	15153	8	4C
0005433420473	15153	9	5A
0005435957679	15153	10	5B
0005435957709	15153	11	5C
0005433420469	15153	12	6A
0005435957713	15153	13	6B
0005435957651	15153	14	6D
0005435957632	15153	15	7A
0005435957707	15153	16	7C
0005433420471	15153	17	18C
0005435957680	15153	18	19B
0005433420476	15153	19	19D
0005433420470	15153	20	20A
0005435957710	15153	21	21A
0005433420475	15153	22	21B
0005435957677	15153	23	21D
0005435957673	15153	24	22B
0005435957718	15153	25	22C
0005433420474	15153	26	22D
0005435219193	27271	1	1A
0005435219202	27271	2	1D
0005435216579	27271	3	2B
0005435221051	27271	4	3B
0005435221052	27271	5	3C
0005435219204	27271	6	4A
0005435219201	27271	7	5C
0005435221050	27271	8	5D
0005435219181	27271	9	6B
0005435219203	27271	10	18A
0005435216573	27271	11	18B
0005435219187	27271	12	20A
0005435221054	27271	13	20C
0005435219196	27271	14	21A
0005435216578	27271	15	22B
0005435216572	27271	16	23A
0005435629414	8872	1	1B
0005434247150	8872	2	3A
0005434247149	8872	3	4B
0005435629413	8872	4	5A
0005434247148	8872	5	6B
0005434247170	16054	1	3B
0005434247168	16054	2	5B
0005434247169	16054	3	6A
0005434247171	16054	4	6B
0005435933459	4435	1	1C
0005435163271	4435	2	2C
0005435933457	4435	3	3A
0005435163277	4435	4	3B
0005435163273	4435	5	3C
0005435163272	4435	6	3D
0005435163270	4435	7	4C
0005435163268	4435	8	4D
0005435933448	4435	9	5C
0005435933470	4435	10	6D
0005435933463	4435	11	18D
0005435933458	4435	12	19C
0005435163269	4435	13	19D
0005435163274	4435	14	20C
0005435163275	4435	15	22B
0005435163278	4435	16	22D
0005435163276	4435	17	23A
0005435933456	4435	18	23B
0005435797595	2840	1	1F
0005433404821	2840	2	2A
0005433404832	2840	3	3A
0005435797584	2840	4	4A
0005433404800	2840	5	5E
0005435797591	2840	6	6A
0005433404814	2840	7	7D
0005433404826	2840	8	8F
0005435797586	2840	9	9E
0005433404813	2840	10	10A
0005435797593	2840	11	10F
0005433404801	2840	12	11A
0005433404822	2840	13	11C
0005435797587	2840	14	12C
0005435797585	2840	15	13A
0005435797589	2840	16	14E
0005435797596	2840	17	15A
0005435797594	2840	18	15C
0005433404764	2840	19	15D
0005435797597	2840	20	16F
0005433404763	2840	21	17C
0005433404795	2840	22	17D
0005435797588	2840	23	18A
0005435797590	2840	24	18E
0005435797592	2840	25	19A
0005435797468	29348	1	2D
0005435797465	29348	2	4C
0005433404869	29348	3	5C
0005435797533	29348	4	5F
0005435797496	29348	5	6D
0005435797464	29348	6	7A
0005435797532	29348	7	7F
0005435797534	29348	8	8E
0005433404872	29348	9	10A
0005433404868	29348	10	11E
0005435797457	29348	11	12A
0005435797489	29348	12	13E
0005435797466	29348	13	14C
0005433404873	29348	14	14F
0005435797531	29348	15	16F
0005435797488	29348	16	17A
0005433404871	29348	17	17C
0005435797493	29348	18	18A
0005433404867	29348	19	18C
0005433404874	29348	20	18F
0005433404870	29348	21	20A
0005434948087	5817	1	1B
0005434948090	5817	2	2A
0005434948084	5817	3	3A
0005434948086	5817	4	4A
0005434948085	5817	5	3B
0005434948093	5817	6	4B
0005434948088	5817	7	5A
0005434948091	5817	8	5B
0005434948092	5817	9	6A
0005434948089	5817	10	6B
0005434948024	16324	1	1A
0005434948019	16324	2	1B
0005434948044	16324	3	3A
0005434948049	16324	4	2B
0005434948025	16324	5	3B
0005434948002	16324	6	4A
0005434947971	16324	7	4B
0005434948036	16324	8	5A
0005434948006	16324	9	5B
0005434948043	16324	10	6A
0005434948037	16324	11	6B
0005433961382	6885	1	2A
0005433961361	6885	2	2F
0005433961355	6885	3	3A
0005433961360	6885	4	3D
0005433961333	6885	5	3F
0005433961356	6885	6	4A
0005433961335	6885	7	5C
0005433961380	6885	8	5D
0005433961364	6885	9	5F
0005433961352	6885	10	6A
0005433961337	6885	11	6E
0005433961353	6885	12	6F
0005433961373	6885	13	8A
0005433961366	6885	14	8C
0005433961346	6885	15	8E
0005433961357	6885	16	8F
0005433961363	6885	17	9A
0005433961371	6885	18	9C
0005433961368	6885	19	9D
0005433961367	6885	20	10A
0005433961378	6885	21	10C
0005433961384	6885	22	10D
0005433961347	6885	23	10E
0005433961348	6885	24	10F
0005433961345	6885	25	11A
0005433961354	6885	26	11C
0005433961341	6885	27	11D
0005433961383	6885	28	11F
0005433961359	6885	29	12C
0005433961358	6885	30	12E
0005433961330	6885	31	12F
0005433961350	6885	32	13F
0005433961372	6885	33	14A
0005433961379	6885	34	14C
0005433961336	6885	35	14D
0005433961377	6885	36	14E
0005433961329	6885	37	14F
0005433961370	6885	38	15A
0005433961351	6885	39	15C
0005433961334	6885	40	15E
0005433961344	6885	41	15F
0005433961340	6885	42	16A
0005433961369	6885	43	16D
0005433961338	6885	44	16E
0005433961376	6885	45	16F
0005433961374	6885	46	17D
0005433961331	6885	47	18E
0005433961362	6885	48	18F
0005433961342	6885	49	19A
0005433961332	6885	50	19C
0005433961375	6885	51	19D
0005433961349	6885	52	19F
0005433961381	6885	53	20C
0005433961339	6885	54	20D
0005433961343	6885	55	20E
0005433961365	6885	56	20F
0005433960758	25695	1	1C
0005433960628	25695	2	1D
0005433960570	25695	3	1F
0005433960629	25695	4	2C
0005433960560	25695	5	3C
0005433960604	25695	6	3D
0005433960661	25695	7	3F
0005433960502	25695	8	4A
0005433960779	25695	9	4C
0005433960725	25695	10	4E
0005433960743	25695	11	5C
0005433960679	25695	12	5E
0005433960623	25695	13	6D
0005433960744	25695	14	6E
0005433960473	25695	15	7F
0005433960618	25695	16	8A
0005433960660	25695	17	8C
0005433960790	25695	18	8E
0005433960596	25695	19	9A
0005433960663	25695	20	9C
0005433960780	25695	21	9D
0005433960641	25695	22	9E
0005433960773	25695	23	9F
0005433960706	25695	24	10D
0005433960410	25695	25	10E
0005433960474	25695	26	11F
0005433960595	25695	27	12C
0005433960774	25695	28	12E
0005433960658	25695	29	12F
0005433960707	25695	30	13A
0005433960678	25695	31	13E
0005433960561	25695	32	13F
0005433960762	25695	33	14A
0005433960675	25695	34	14E
0005433960619	25695	35	15C
0005433960488	25695	36	15D
0005433960785	25695	37	15F
0005433960519	25695	38	16C
0005433960635	25695	39	16D
0005433960676	25695	40	16E
0005433960709	25695	41	16F
0005433960680	25695	42	17A
0005433960789	25695	43	17C
0005433960708	25695	44	17E
0005433960622	25695	45	18C
0005433960564	25695	46	18D
0005433960620	25695	47	18E
0005433960621	25695	48	18F
0005433960569	25695	49	19D
0005433960659	25695	50	19E
0005433960562	25695	51	20A
0005433960786	25695	52	20F
0005435082743	24531	1	1A
0005435082766	24531	2	1B
0005435082776	24531	3	2A
0005435082746	24531	4	3B
0005435082741	24531	5	4B
0005435082767	24531	6	5A
0005435082745	24531	7	6A
0005435082764	24531	8	6B
0005435082850	26055	1	1A
0005435082847	26055	2	1B
0005435082849	26055	3	2A
0005435082846	26055	4	2B
0005435082845	26055	5	3A
0005435082842	26055	6	3B
0005435082848	26055	7	4A
0005435082844	26055	8	5B
0005435082841	26055	9	6A
0005435082843	26055	10	6B
0005434245235	5159	1	1A
0005434245209	5159	2	4C
0005434245212	5159	3	6F
0005434245208	5159	4	7A
0005434245222	5159	5	8B
0005434245231	5159	6	8E
0005434245221	5159	7	8D
0005434245232	5159	8	8F
0005434245213	5159	9	9E
0005434245237	5159	10	10F
0005434245233	5159	11	11A
0005432166929	5159	12	11F
0005435286626	5159	13	12C
0005432166928	5159	14	12D
0005434245216	5159	15	13E
0005434245218	5159	16	15A
0005434245236	5159	17	15B
0005435286631	5159	18	16B
0005434245217	5159	19	17D
0005434245229	5159	20	17E
0005434245230	5159	21	18D
0005434245214	5159	22	19C
0005434245219	5159	23	20E
0005434245234	5159	24	22F
0005435286619	5159	25	23E
0005434245224	5159	26	24C
0005434245228	5159	27	25B
0005434245223	5159	28	25A
0005433534502	5159	29	25C
0005434245210	5159	30	26E
0005434245226	5159	31	27D
0005434245227	5159	32	27E
0005435286607	5159	33	28C
0005434245220	5159	34	28E
0005432166927	5159	35	29A
0005435286608	5159	36	28F
0005435286618	5159	37	29E
0005434245225	5159	38	30D
0005434245215	5159	39	30F
0005434245211	5159	40	31E
0005433615317	5160	1	1A
0005433615332	5160	2	1C
0005432665291	5160	3	1F
0005433785229	5160	4	1D
0005433615265	5160	5	2A
0005432105962	5160	6	2D
0005433785245	5160	7	2C
0005433785242	5160	8	3A
0005433615291	5160	9	2F
0005433615276	5160	10	3C
0005433615268	5160	11	3D
0005432105936	5160	12	4A
0005433615293	5160	13	3F
0005432105954	5160	14	4C
0005433615273	5160	15	4F
0005433615326	5160	16	4D
0005433785227	5160	17	5A
0005432105972	5160	18	5C
0005432105952	5160	19	5D
0005432105953	5160	20	6A
0005433615302	5160	21	5F
0005432105946	5160	22	6C
0005433615266	5160	23	6F
0005433615296	5160	24	6D
0005433785256	5160	25	7A
0005433785253	5160	26	7C
0005433615282	5160	27	7D
0005433615304	5160	28	8A
0005432666407	5160	29	7F
0005433615316	5160	30	8C
0005433785246	5160	31	8B
0005433615275	5160	32	8D
0005433615277	5160	33	8E
0005432667472	5160	34	9A
0005433615289	5160	35	8F
0005433615267	5160	36	9B
0005433615313	5160	37	9C
0005433615307	5160	38	9E
0005432105965	5160	39	9D
0005433785248	5160	40	9F
0005432105947	5160	41	10A
0005433785230	5160	42	10B
0005432105981	5160	43	10C
0005433615324	5160	44	10E
0005432105958	5160	45	10D
0005433615285	5160	46	10F
0005432105955	5160	47	11B
0005432105980	5160	48	11A
0005432105957	5160	49	11C
0005432145128	5160	50	11D
0005433615272	5160	51	11F
0005433615303	5160	52	11E
0005432145129	5160	53	12A
0005432105961	5160	54	12B
0005432105978	5160	55	12D
0005433615261	5160	56	12C
0005433615297	5160	57	12E
0005433615263	5160	58	12F
0005432105963	5160	59	13A
0005432105949	5160	60	13B
0005433615301	5160	61	13D
0005433615262	5160	62	13C
0005433785241	5160	63	13F
0005432105976	5160	64	13E
0005432105967	5160	65	14A
0005433615287	5160	66	14B
0005433785226	5160	67	14D
0005432105974	5160	68	14C
0005433615299	5160	69	14E
0005433615323	5160	70	14F
0005433785249	5160	71	15B
0005432105984	5160	72	15A
0005433615278	5160	73	15C
0005432666405	5160	74	15D
0005433615321	5160	75	15F
0005433615286	5160	76	15E
0005433615288	5160	77	16A
0005433615322	5160	78	16B
0005432105945	5160	79	16C
0005433785247	5160	80	16E
0005433785231	5160	81	16D
0005433615294	5160	82	17A
0005433615306	5160	83	16F
0005433615315	5160	84	17C
0005432667471	5160	85	17B
0005432105937	5160	86	17D
0005433785223	5160	87	17E
0005432105950	5160	88	18A
0005432105938	5160	89	17F
0005432105935	5160	90	18B
0005433615284	5160	91	18D
0005433785228	5160	92	18C
0005432105970	5160	93	18E
0005432105964	5160	94	18F
0005433615269	5160	95	19B
0005433615310	5160	96	19D
0005433615260	5160	97	19C
0005433615300	5160	98	19E
0005432665292	5160	99	20A
0005433785243	5160	100	20C
0005432105983	5160	101	20B
0005433615279	5160	102	20D
0005433785254	5160	103	20F
0005433615328	5160	104	20E
0005432145127	5160	105	21A
0005432105977	5160	106	21C
0005433785233	5160	107	21B
0005433785238	5160	108	21D
0005433785234	5160	109	21E
0005433615329	5160	110	22A
0005433615320	5160	111	21F
0005433615283	5160	112	22B
0005433785259	5160	113	22D
0005433615298	5160	114	22C
0005433785239	5160	115	22F
0005432105941	5160	116	22E
0005432105943	5160	117	23B
0005433785225	5160	118	23A
0005432105973	5160	119	23C
0005433615264	5160	120	23D
0005433615281	5160	121	23F
0005433785258	5160	122	23E
0005433615274	5160	123	24B
0005432105939	5160	124	24A
0005433615309	5160	125	24D
0005433785255	5160	126	24C
0005433615308	5160	127	24E
0005432105951	5160	128	24F
0005432105966	5160	129	25A
0005433615292	5160	130	25C
0005433615331	5160	131	25B
0005433615311	5160	132	25D
0005433615330	5160	133	25E
0005433615312	5160	134	25F
0005433785236	5160	135	26B
0005432105969	5160	136	26A
0005432105942	5160	137	26C
0005432105979	5160	138	26D
0005433615280	5160	139	26F
0005432666406	5160	140	26E
0005433615305	5160	141	27A
0005433785244	5160	142	27C
0005433785224	5160	143	27B
0005433615318	5160	144	27D
0005433615271	5160	145	27E
0005432105975	5160	146	27F
0005432105960	5160	147	28C
0005433785235	5160	148	28B
0005433785251	5160	149	28A
0005432105968	5160	150	28D
0005432105982	5160	151	28F
0005432105971	5160	152	28E
0005433785240	5160	153	29B
0005433615319	5160	154	29A
0005433615270	5160	155	29C
0005433615314	5160	156	29D
0005432105959	5160	157	29E
0005433785252	5160	158	30A
0005433785250	5160	159	29F
0005432105956	5160	160	30B
0005432105944	5160	161	30D
0005433615295	5160	162	30C
0005433615290	5160	163	30E
0005432105948	5160	164	30F
0005433615325	5160	165	31B
0005433785257	5160	166	31A
0005432105940	5160	167	31C
0005433615327	5160	168	31D
0005433785232	5160	169	31F
0005433785237	5160	170	31E
0005434229550	5162	1	1C
0005434229547	5162	2	1A
0005435007042	5162	3	2A
0005434312302	5162	4	1F
0005432335999	5162	5	2D
0005435007100	5162	6	2C
0005434149829	5162	7	2F
0005434265339	5162	8	3A
0005434265360	5162	9	3C
0005434229563	5162	10	3F
0005434229566	5162	11	3D
0005432336007	5162	12	4C
0005434229564	5162	13	4F
0005434229562	5162	14	5D
0005434229545	5162	15	5C
0005434265355	5162	16	6A
0005434311224	5162	17	5F
0005433815379	5162	18	6D
0005433815383	5162	19	6C
0005434312300	5162	20	7A
0005434265346	5162	21	8A
0005435006920	5162	22	8B
0005434229558	5162	23	8C
0005434149825	5162	24	8E
0005434265351	5162	25	8F
0005432336037	5162	26	9A
0005435006989	5162	27	9D
0005434265342	5162	28	9B
0005432336008	5162	29	9F
0005432336028	5162	30	9E
0005434265354	5162	31	10A
0005434229549	5162	32	10B
0005434265348	5162	33	10D
0005432336022	5162	34	10F
0005434265344	5162	35	11C
0005435007055	5162	36	11B
0005434265347	5162	37	11D
0005435006873	5162	38	11E
0005433685531	5162	39	12A
0005434265362	5162	40	11F
0005435007059	5162	41	12B
0005435007008	5162	42	12C
0005434265343	5162	43	12E
0005434265350	5162	44	12D
0005434229565	5162	45	12F
0005432336027	5162	46	13B
0005435007035	5162	47	13C
0005433688802	5162	48	13D
0005435006979	5162	49	13E
0005434229553	5162	50	14A
0005432336035	5162	51	13F
0005435006985	5162	52	14C
0005435006992	5162	53	14B
0005434312301	5162	54	14E
0005434311211	5162	55	14F
0005434149831	5162	56	15B
0005434229560	5162	57	15C
0005434229561	5162	58	15D
0005434265356	5162	59	15F
0005434229559	5162	60	16C
0005434312317	5162	61	16E
0005435006899	5162	62	17A
0005432336023	5162	63	16F
0005432335939	5162	64	17C
0005435007034	5162	65	17B
0005433688803	5162	66	17D
0005435006988	5162	67	17F
0005435006991	5162	68	18A
0005434229546	5162	69	18C
0005434149822	5162	70	18D
0005434265352	5162	71	18F
0005434311210	5162	72	19C
0005433688798	5162	73	19B
0005434265361	5162	74	19D
0005435007090	5162	75	20A
0005435007033	5162	76	19E
0005434173553	5162	77	20C
0005435006952	5162	78	20B
0005434149826	5162	79	20D
0005432336062	5162	80	20F
0005435006900	5162	81	21A
0005434265337	5162	82	21C
0005434265340	5162	83	21B
0005434229557	5162	84	21E
0005432335938	5162	85	22A
0005435006980	5162	86	21F
0005434265338	5162	87	22B
0005434149824	5162	88	22D
0005433815367	5162	89	23B
0005434229548	5162	90	23D
0005434311221	5162	91	23F
0005434265359	5162	92	24A
0005432336024	5162	93	24D
0005435006919	5162	94	24C
0005434265341	5162	95	24E
0005434149827	5162	96	24F
0005434149823	5162	97	25A
0005434265363	5162	98	25B
0005434149830	5162	99	25F
0005434265357	5162	100	26A
0005434229556	5162	101	26B
0005434229551	5162	102	26C
0005434229555	5162	103	27B
0005434311225	5162	104	27A
0005434173552	5162	105	27C
0005434173554	5162	106	27D
0005435006872	5162	107	28B
0005435007021	5162	108	28D
0005434149832	5162	109	28C
0005434149828	5162	110	28E
0005434265345	5162	111	28F
0005433815374	5162	112	29A
0005434229552	5162	113	29B
0005435006884	5162	114	29D
0005434265353	5162	115	29C
0005432336038	5162	116	29E
0005434229554	5162	117	30A
0005435007078	5162	118	29F
0005433688805	5162	119	30B
0005435007043	5162	120	30D
0005435007077	5162	121	30E
0005434265358	5162	122	30F
0005434265349	5162	123	31B
0005433685529	5162	124	31D
0005433685530	5162	125	31F
0005433815378	5162	126	31E
0005434244907	8605	1	1A
0005434244936	8605	2	1D
0005434245024	8605	3	2C
0005434244996	8605	4	2A
0005433785069	8605	5	2D
0005434245047	8605	6	2F
0005434244949	8605	7	3C
0005434244908	8605	8	3D
0005435269799	8605	9	4D
0005434244881	8605	10	4C
0005433784967	8605	11	5C
0005434245040	8605	12	6C
0005434244994	8605	13	6F
0005435269796	8605	14	7A
0005433785065	8605	15	7D
0005434245053	8605	16	8B
0005434245109	8605	17	8E
0005433785001	8605	18	9A
0005433784863	8605	19	9F
0005432663036	8605	20	9E
0005432663032	8605	21	10C
0005434245097	8605	22	10E
0005433784898	8605	23	11D
0005433784933	8605	24	11F
0005434245014	8605	25	11E
0005434245019	8605	26	12A
0005434244967	8605	27	12E
0005434244990	8605	28	13B
0005434245046	8605	29	13A
0005433784971	8605	30	13C
0005434244989	8605	31	13D
0005435269797	8605	32	14D
0005433784948	8605	33	15B
0005433784871	8605	34	15A
0005434245110	8605	35	15C
0005434244919	8605	36	15F
0005432663033	8605	37	16D
0005433784854	8605	38	16C
0005433784870	8605	39	16E
0005433785032	8605	40	16F
0005435269801	8605	41	17B
0005434244986	8605	42	17F
0005433785061	8605	43	18D
0005433784712	8605	44	18E
0005432663035	8605	45	18F
0005433784887	8605	46	19C
0005433784966	8605	47	20A
0005433785014	8605	48	19E
0005433785041	8605	49	20D
0005434245082	8605	50	21D
0005432663031	8605	51	22C
0005434245122	8605	52	22D
0005435269798	8605	53	22E
0005434244950	8605	54	23A
0005433785031	8605	55	23C
0005434244890	8605	56	23B
0005433784897	8605	57	24A
0005434244917	8605	58	24B
0005434245027	8605	59	24C
0005434245035	8605	60	25C
0005434244909	8605	61	25E
0005434244937	8605	62	26B
0005433784938	8605	63	26F
0005433784909	8605	64	27B
0005434245018	8605	65	27D
0005432663040	8605	66	27E
0005433785055	8605	67	28A
0005434245043	8605	68	27F
0005435269800	8605	69	28C
0005433784930	8605	70	28E
0005434245025	8605	71	28F
0005433785074	8605	72	29A
0005433785066	8605	73	29B
0005433785062	8605	74	29D
0005434245033	8605	75	29C
0005433784945	8605	76	30B
0005434244993	8605	77	30D
0005433784910	8605	78	30F
0005433784740	8605	79	31A
0005433614296	8606	1	1A
0005433614569	8606	2	2A
0005433614746	8606	3	2C
0005433614597	8606	4	2F
0005433614356	8606	5	3C
0005433614295	8606	6	3D
0005433614577	8606	7	4A
0005433614473	8606	8	3F
0005433614593	8606	9	5D
0005433614628	8606	10	5F
0005433614594	8606	11	6D
0005433614523	8606	12	7A
0005433614509	8606	13	7D
0005433614549	8606	14	8A
0005433614480	8606	15	7F
0005433614257	8606	16	8B
0005433614807	8606	17	8D
0005433614712	8606	18	8E
0005433614870	8606	19	9A
0005433614560	8606	20	9D
0005433614631	8606	21	10F
0005433614733	8606	22	11A
0005433614802	8606	23	11E
0005433614740	8606	24	11D
0005433614647	8606	25	12E
0005433614598	8606	26	12D
0005433614483	8606	27	12F
0005433614454	8606	28	13A
0005433614576	8606	29	13D
0005433614384	8606	30	13E
0005433614529	8606	31	14A
0005433614474	8606	32	14B
0005433614578	8606	33	14C
0005433614378	8606	34	14F
0005433614567	8606	35	15B
0005433614379	8606	36	15C
0005433614475	8606	37	15D
0005433614566	8606	38	15F
0005433614697	8606	39	16D
0005433614541	8606	40	16C
0005433614487	8606	41	16E
0005433614471	8606	42	17A
0005433614634	8606	43	17B
0005433614572	8606	44	17D
0005433614427	8606	45	17F
0005433614216	8606	46	17E
0005433614700	8606	47	18D
0005433614635	8606	48	19B
0005433614502	8606	49	19D
0005433614538	8606	50	19C
0005433614217	8606	51	20A
0005433614711	8606	52	19E
0005433614565	8606	53	20B
0005433614683	8606	54	20D
0005433614477	8606	55	21C
0005433614592	8606	56	21B
0005433614484	8606	57	21D
0005433614479	8606	58	21E
0005433614801	8606	59	22A
0005433614761	8606	60	22D
0005433614027	8606	61	22E
0005433614600	8606	62	22F
0005433614528	8606	63	23A
0005433614808	8606	64	23C
0005433614664	8606	65	23B
0005433614558	8606	66	23D
0005433614503	8606	67	24A
0005433614745	8606	68	24D
0005433614380	8606	69	24F
0005433614559	8606	70	25B
0005433614630	8606	71	25A
0005433614696	8606	72	25D
0005433615071	8606	73	25C
0005433614476	8606	74	25E
0005433614663	8606	75	26A
0005433614472	8606	76	26D
0005433614385	8606	77	26C
0005433614532	8606	78	26E
0005433614636	8606	79	27D
0005433614762	8606	80	27E
0005433614610	8606	81	28A
0005433615070	8606	82	28B
0005433614611	8606	83	28D
0005433614258	8606	84	29A
0005433614335	8606	85	29E
0005433614626	8606	86	30A
0005433614069	8606	87	30B
0005433614646	8606	88	30C
0005434149727	8607	1	1D
0005434265255	8607	2	1C
0005433690942	8607	3	1A
0005432035189	8607	4	1F
0005433815427	8607	5	2A
0005435007225	8607	6	2D
0005434229375	8607	7	2C
0005432336136	8607	8	2F
0005433689928	8607	9	3A
0005434149649	8607	10	3C
0005434265206	8607	11	3F
0005432047583	8607	12	3D
0005434173516	8607	13	4A
0005432035181	8607	14	4C
0005434229354	8607	15	4D
0005434229408	8607	16	5A
0005434265151	8607	17	4F
0005433534516	8607	18	5C
0005435286662	8607	19	5F
0005434149748	8607	20	5D
0005435007212	8607	21	6A
0005435007222	8607	22	6D
0005432035172	8607	23	6C
0005435007202	8607	24	7A
0005434229427	8607	25	7C
0005435007216	8607	26	7D
0005435007214	8607	27	8A
0005432035167	8607	28	8B
0005435007223	8607	29	8C
0005432035173	8607	30	8E
0005434311237	8607	31	8F
0005434229369	8607	32	9A
0005432336131	8607	33	9B
0005432047580	8607	34	9D
0005434229482	8607	35	9E
0005434149648	8607	36	10A
0005435286663	8607	37	10B
0005432035182	8607	38	10D
0005434229368	8607	39	10E
0005435007219	8607	40	10F
0005434265106	8607	41	11A
0005432336127	8607	42	11C
0005434265191	8607	43	11B
0005434265267	8607	44	11E
0005434229345	8607	45	11D
0005432035168	8607	46	12A
0005435007224	8607	47	11F
0005433690941	8607	48	12B
0005432336134	8607	49	12D
0005434229367	8607	50	12E
0005432035171	8607	51	12F
0005435007221	8607	52	13A
0005432035183	8607	53	13C
0005432035185	8607	54	13B
0005434229318	8607	55	13D
0005435007205	8607	56	13F
0005432336130	8607	57	13E
0005435007204	8607	58	14A
0005435007220	8607	59	14B
0005434265122	8607	60	14D
0005432047579	8607	61	14C
0005432035180	8607	62	14E
0005435007207	8607	63	14F
0005434149680	8607	64	15B
0005432035164	8607	65	15A
0005435286665	8607	66	15C
0005434265210	8607	67	15D
0005434229377	8607	68	15E
0005432035170	8607	69	16A
0005434265045	8607	70	15F
0005432336132	8607	71	16C
0005434265178	8607	72	16B
0005434229312	8607	73	16D
0005432035163	8607	74	16E
0005435286666	8607	75	17A
0005435007203	8607	76	16F
0005434265121	8607	77	17C
0005434229391	8607	78	17E
0005432035187	8607	79	17D
0005435007217	8607	80	17F
0005432035169	8607	81	18A
0005434265195	8607	82	18B
0005434264988	8607	83	18C
0005432035175	8607	84	18E
0005435007211	8607	85	18D
0005432336129	8607	86	19B
0005435007209	8607	87	18F
0005433815426	8607	88	19C
0005434229429	8607	89	19D
0005435007208	8607	90	20A
0005433815425	8607	91	19E
0005435286664	8607	92	20C
0005432035177	8607	93	20B
0005434229431	8607	94	20E
0005434173515	8607	95	20D
0005435007206	8607	96	20F
0005432047582	8607	97	21C
0005434229346	8607	98	21B
0005432035162	8607	99	21D
0005434173526	8607	100	21E
0005434265199	8607	101	21F
0005434265132	8607	102	22B
0005432336135	8607	103	22E
0005434265085	8607	104	22D
0005432336138	8607	105	22F
0005433815428	8607	106	23B
0005434265074	8607	107	23D
0005435007215	8607	108	23E
0005432035186	8607	109	24A
0005435007218	8607	110	23F
0005434265177	8607	111	24B
0005434229336	8607	112	24C
0005435007210	8607	113	24E
0005434149717	8607	114	24D
0005434229366	8607	115	24F
0005432035179	8607	116	25A
0005433688827	8607	117	25B
0005435007213	8607	118	25D
0005432035184	8607	119	25C
0005432035165	8607	120	25E
0005432336133	8607	121	26A
0005434265055	8607	122	25F
0005434149706	8607	123	26B
0005432336128	8607	124	26C
0005432035178	8607	125	26D
0005434229483	8607	126	26F
0005432035188	8607	127	27A
0005434229335	8607	128	27C
0005434229432	8607	129	27B
0005432035174	8607	130	27D
0005434229350	8607	131	27E
0005432035166	8607	132	28A
0005434229428	8607	133	27F
0005434173521	8607	134	28D
0005432035161	8607	135	28C
0005434264987	8607	136	28E
0005433534517	8607	137	28F
0005434265202	8607	138	29B
0005434149745	8607	139	29A
0005434149679	8607	140	29C
0005435007226	8607	141	29D
0005434229484	8607	142	29F
0005433534515	8607	143	30B
0005434229349	8607	144	30C
0005432035176	8607	145	30E
0005434149708	8607	146	30D
0005432336137	8607	147	31A
0005434265031	8607	148	30F
0005434229373	8607	149	31B
0005432047581	8607	150	31D
0005434149692	8607	151	31C
0005434149707	8607	152	31F
0005434265138	8607	153	31E
0005434639299	12622	1	1A
0005433202491	12622	2	1B
0005434639379	12622	3	1D
0005433202485	12622	4	2A
0005434639319	12622	5	2B
0005434639381	12622	6	2C
0005434639238	12622	7	2D
0005434639391	12622	8	3A
0005434639300	12622	9	3B
0005434639338	12622	10	3C
0005434639336	12622	11	3D
0005433202492	12622	12	4A
0005434639386	12622	13	4B
0005433202490	12622	14	4C
0005433202482	12622	15	4D
0005433202487	12622	16	5B
0005433202479	12622	17	5C
0005433202484	12622	18	6A
0005434639417	12622	19	6B
0005433202481	12622	20	6D
0005434639389	12622	21	7B
0005433202493	12622	22	7C
0005434639380	12622	23	7D
0005434639219	12622	24	18A
0005433202489	12622	25	18B
0005433202480	12622	26	18D
0005434639337	12622	27	19A
0005433202488	12622	28	19B
0005434639290	12622	29	19C
0005434639314	12622	30	20A
0005433202483	12622	31	20B
0005434639394	12622	32	20C
0005434639342	12622	33	21A
0005434639390	12622	34	21B
0005434639324	12622	35	21C
0005434639255	12622	36	22A
0005433202486	12622	37	22C
0005434639387	12622	38	23A
0005434639291	12622	39	23B
0005434639502	23352	1	1A
0005434639506	23352	2	1C
0005433202321	23352	3	1D
0005434639515	23352	4	2A
0005434639504	23352	5	2B
0005434639521	23352	6	2C
0005433202365	23352	7	2D
0005434639500	23352	8	3A
0005434639510	23352	9	3C
0005432290657	23352	10	3D
0005434639520	23352	11	4A
0005433202274	23352	12	4C
0005432290656	23352	13	4D
0005434639517	23352	14	5A
0005433202313	23352	15	5B
0005434639503	23352	16	5C
0005434639514	23352	17	5D
0005434639508	23352	18	6A
0005433202347	23352	19	6B
0005433202320	23352	20	6C
0005433202336	23352	21	6D
0005434639505	23352	22	7A
0005434639499	23352	23	7B
0005434639511	23352	24	7C
0005432290655	23352	25	7D
0005433202254	23352	26	18A
0005433202255	23352	27	18B
0005434639501	23352	28	18C
0005433202345	23352	29	18D
0005434639519	23352	30	19B
0005433202341	23352	31	19C
0005434639516	23352	32	19D
0005433202256	23352	33	20A
0005433202306	23352	34	20B
0005434639509	23352	35	20D
0005432290654	23352	36	21A
0005434639513	23352	37	21B
0005433202335	23352	38	21C
0005434639507	23352	39	21D
0005433202344	23352	40	22A
0005434639512	23352	41	22B
0005433202340	23352	42	22D
0005433202348	23352	43	23A
0005434639518	23352	44	23B
0005432383146	21071	1	1A
0005432328716	21071	2	1C
0005432383162	21071	3	1D
0005432383098	21071	4	1F
0005432328765	21071	5	2A
0005432383135	21071	6	2C
0005432328711	21071	7	2D
0005432054328	21071	8	2F
0005432328789	21071	9	3A
0005432328723	21071	10	3C
0005432383015	21071	11	3D
0005432382986	21071	12	3F
0005432328774	21071	13	4A
0005432383092	21071	14	4C
0005432383014	21071	15	4D
0005432328790	21071	16	4E
0005432383049	21071	17	4F
0005432383179	21071	18	5A
0005432383097	21071	19	5C
0005432328455	21071	20	5D
0005432328580	21071	21	5E
0005432328653	21071	22	5F
0005432328588	21071	23	6A
0005432328654	21071	24	6C
0005432328644	21071	25	6D
0005432328572	21071	26	6E
0005432328618	21071	27	6F
0005432328642	21071	28	7A
0005432328601	21071	29	7C
0005432383137	21071	30	7D
0005432328672	21071	31	7E
0005432328905	21071	32	7F
0005432383169	21071	33	8A
0005432383143	21071	34	8C
0005432328513	21071	35	8D
0005432328708	21071	36	8E
0005432382970	21071	37	8F
0005432328807	21071	38	9A
0005432328584	21071	39	9C
0005432383094	21071	40	9D
0005432383142	21071	41	9E
0005432383004	21071	42	9F
0005432328589	21071	43	10A
0005432383022	21071	44	10C
0005432328616	21071	45	10D
0005432383173	21071	46	10E
0005432382998	21071	47	10F
0005432383138	21071	48	11A
0005432328717	21071	49	11C
0005432383112	21071	50	11D
0005432383005	21071	51	11E
0005432383068	21071	52	11F
0005432382994	21071	53	12A
0005432328729	21071	54	12C
0005432328720	21071	55	12D
0005432328801	21071	56	12E
0005432383101	21071	57	12F
0005432328802	21071	58	13A
0005432382987	21071	59	13C
0005432328680	21071	60	13D
0005432328641	21071	61	13E
0005432328489	21071	62	13F
0005432328456	21071	63	14A
0005432328682	21071	64	14C
0005432328518	21071	65	14D
0005432383093	21071	66	14E
0005432328579	21071	67	14F
0005432328825	21071	68	15A
0005432328673	21071	69	15C
0005432328728	21071	70	15D
0005432383131	21071	71	15E
0005432383017	21071	72	15F
0005432382993	21071	73	16A
0005432328619	21071	74	16C
0005432383187	21071	75	16D
0005432054329	21071	76	16E
0005432328681	21071	77	16F
0005432383141	21071	78	17A
0005432328665	21071	79	17C
0005432328512	21071	80	17D
0005432328693	21071	81	17E
0005432328719	21071	82	17F
0005432328617	21071	83	18A
0005432328700	21071	84	18C
0005432328585	21071	85	18D
0005432383013	21071	86	18E
0005432328803	21071	87	18F
0005432383188	21071	88	19A
0005432383167	21071	89	19C
0005432328800	21071	90	19D
0005432328707	21071	91	19E
0005432328718	21071	92	19F
0005432328600	21071	93	20A
0005432328855	21071	94	20C
0005432383067	21071	95	20D
0005432328710	21071	96	20E
0005432383174	21071	97	20F
0005432383457	31261	1	1A
0005432383478	31261	2	1C
0005432287228	31261	3	1D
0005432383469	31261	4	1F
0005432329040	31261	5	2A
0005432329062	31261	6	2C
0005432329041	31261	7	2D
0005432383471	31261	8	2F
0005432329053	31261	9	3A
0005432383467	31261	10	3D
0005432383486	31261	11	3C
0005432383472	31261	12	3F
0005432329058	31261	13	4A
0005432329023	31261	14	4C
0005432383474	31261	15	4D
0005432383487	31261	16	4E
0005432383476	31261	17	4F
0005432329034	31261	18	5A
0005432383453	31261	19	5C
0005432329043	31261	20	5D
0005432329042	31261	21	5E
0005432383444	31261	22	5F
0005432329061	31261	23	6A
0005432329045	31261	24	6C
0005432329052	31261	25	6D
0005432329036	31261	26	6E
0005432329027	31261	27	6F
0005432383454	31261	28	7A
0005432383460	31261	29	7C
0005432329054	31261	30	7D
0005432383461	31261	31	7E
0005432329064	31261	32	7F
0005432287226	31261	33	8A
0005432383464	31261	34	8C
0005432383485	31261	35	8D
0005432329032	31261	36	8E
0005432383475	31261	37	8F
0005432383463	31261	38	9A
0005432383477	31261	39	9C
0005432383466	31261	40	9D
0005432383484	31261	41	9E
0005432329063	31261	42	9F
0005432329029	31261	43	10C
0005432383448	31261	44	10D
0005432329055	31261	45	10E
0005432383482	31261	46	10F
0005432383452	31261	47	11A
0005432329033	31261	48	11C
0005432329019	31261	49	11D
0005432329035	31261	50	11E
0005432383481	31261	51	11F
0005432383449	31261	52	12A
0005432329020	31261	53	12C
0005432329038	31261	54	12D
0005432329021	31261	55	12E
0005432383473	31261	56	12F
0005432329060	31261	57	13A
0005432383459	31261	58	13C
0005432383480	31261	59	13D
0005432383446	31261	60	13E
0005432329049	31261	61	13F
0005432383462	31261	62	14A
0005432329018	31261	63	14C
0005432329030	31261	64	14D
0005432329047	31261	65	14E
0005432329056	31261	66	14F
0005432383451	31261	67	15A
0005432329031	31261	68	15C
0005432383479	31261	69	15D
0005432329028	31261	70	15E
0005432329065	31261	71	15F
0005432329050	31261	72	16A
0005432383456	31261	73	16C
0005432383447	31261	74	16E
0005432329026	31261	75	16D
0005432383455	31261	76	16F
0005432329051	31261	77	17A
0005432329046	31261	78	17C
0005432329048	31261	79	17D
0005432329022	31261	80	17E
0005432383445	31261	81	17F
0005432383483	31261	82	18A
0005432329057	31261	83	18C
0005432287229	31261	84	18D
0005432383450	31261	85	18E
0005432329025	31261	86	18F
0005432383458	31261	87	19A
0005432329044	31261	88	19C
0005432329059	31261	89	19D
0005432329037	31261	90	19E
0005432329024	31261	91	19F
0005432287227	31261	92	20A
0005432383468	31261	93	20C
0005432383465	31261	94	20D
0005432329039	31261	95	20E
0005432383470	31261	96	20F
0005433642452	2468	1	1A
0005432953935	2468	2	1C
0005433642471	2468	3	2A
0005433642458	2468	4	2F
0005432953912	2468	5	3F
0005432953930	2468	6	4C
0005432953947	2468	7	4D
0005432953889	2468	8	4E
0005432953894	2468	9	5D
0005433642459	2468	10	5E
0005433642446	2468	11	6A
0005432953944	2468	12	6F
0005433642447	2468	13	7C
0005432953964	2468	14	7A
0005433642457	2468	15	7E
0005433642469	2468	16	8C
0005433642461	2468	17	8F
0005433642451	2468	18	9A
0005433642468	2468	19	9E
0005433642460	2468	20	9F
0005432953918	2468	21	10A
0005433642466	2468	22	10C
0005433642462	2468	23	11A
0005432953914	2468	24	11C
0005433642464	2468	25	11E
0005432953929	2468	26	12C
0005433642455	2468	27	12D
0005433642454	2468	28	13C
0005433642456	2468	29	13F
0005432953906	2468	30	14A
0005433642448	2468	31	14D
0005433642467	2468	32	14E
0005433642449	2468	33	14F
0005433642472	2468	34	15A
0005432953893	2468	35	15C
0005432953959	2468	36	15D
0005433642470	2468	37	16F
0005432953913	2468	38	17C
0005432953905	2468	39	17E
0005432953963	2468	40	17F
0005433642463	2468	41	18C
0005433642453	2468	42	18D
0005432953936	2468	43	18F
0005433642450	2468	44	19C
0005433642473	2468	45	19D
0005432953919	2468	46	19E
0005433642465	2468	47	20D
0005432954000	27599	1	1A
0005433642201	27599	2	1D
0005432953994	27599	3	1F
0005432954008	27599	4	2A
0005433642353	27599	5	2D
0005432954001	27599	6	3D
0005433642227	27599	7	3F
0005432953995	27599	8	4A
0005433642345	27599	9	4C
0005433642296	27599	10	4D
0005433642295	27599	11	4E
0005433642361	27599	12	4F
0005433642346	27599	13	5C
0005433642202	27599	14	5D
0005433642270	27599	15	5F
0005432954006	27599	16	6C
0005432953998	27599	17	6F
0005432954009	27599	18	7A
0005432954011	27599	19	8D
0005433642273	27599	20	9A
0005432954005	27599	21	9D
0005433642287	27599	22	10C
0005433642319	27599	23	10D
0005432953999	27599	24	10E
0005433642228	27599	25	11A
0005433642303	27599	26	11F
0005433642306	27599	27	12C
0005433642364	27599	28	12F
0005433642359	27599	29	13C
0005433642344	27599	30	13D
0005433642352	27599	31	13F
0005433642354	27599	32	14A
0005433642226	27599	33	14D
0005433642331	27599	34	15D
0005433642363	27599	35	16C
0005433642263	27599	36	16E
0005432953996	27599	37	16F
0005433642339	27599	38	17A
0005433642249	27599	39	17D
0005432954003	27599	40	17C
0005432953997	27599	41	17E
0005433642281	27599	42	18C
0005432954002	27599	43	18E
0005433642321	27599	44	18F
0005432954004	27599	45	19E
0005433642360	27599	46	19F
0005432954007	27599	47	20A
0005433642347	27599	48	20D
0005432954010	27599	49	20E
0005432424803	13377	1	1A
0005432424795	13377	2	1C
0005432424799	13377	3	1D
0005432424787	13377	4	2C
0005432424797	13377	5	2F
0005432424806	13377	6	3D
0005432424785	13377	7	3F
0005432424786	13377	8	4A
0005432424815	13377	9	4D
0005432424817	13377	10	4E
0005432424819	13377	11	4F
0005432424777	13377	12	5A
0005432424816	13377	13	5C
0005432424800	13377	14	5E
0005432424791	13377	15	5F
0005432424812	13377	16	6C
0005432424810	13377	17	6D
0005432424784	13377	18	7C
0005432424790	13377	19	7D
0005432424814	13377	20	8C
0005432424818	13377	21	8E
0005432424783	13377	22	9C
0005432424808	13377	23	9F
0005432424802	13377	24	10A
0005432424789	13377	25	10F
0005432424796	13377	26	11D
0005432424779	13377	27	11E
0005432424778	13377	28	11F
0005432424811	13377	29	12C
0005432424782	13377	30	12D
0005432424804	13377	31	12F
0005432424780	13377	32	13F
0005432424794	13377	33	14A
0005432424788	13377	34	14D
0005432424801	13377	35	14F
0005432424821	13377	36	15C
0005432424793	13377	37	16C
0005432424792	13377	38	16D
0005432424820	13377	39	17A
0005432424798	13377	40	17E
0005432424807	13377	41	17F
0005432424809	13377	42	18A
0005432424805	13377	43	18C
0005432424813	13377	44	18E
0005432424781	13377	45	19A
0005432424776	13377	46	20F
0005432424324	30708	1	1A
0005432424385	30708	2	1F
0005432424357	30708	3	2A
0005432424348	30708	4	2C
0005432424388	30708	5	2F
0005432424408	30708	6	3A
0005432424189	30708	7	4D
0005432424358	30708	8	4F
0005432424329	30708	9	5A
0005432424341	30708	10	5C
0005432424411	30708	11	5F
0005432424409	30708	12	6A
0005432424403	30708	13	6E
0005432424325	30708	14	6F
0005432424258	30708	15	7A
0005432424399	30708	16	7C
0005432424374	30708	17	7F
0005432424346	30708	18	8C
0005432424263	30708	19	8E
0005432424303	30708	20	9D
0005432424394	30708	21	9F
0005432424262	30708	22	10D
0005432424163	30708	23	10E
0005432424365	30708	24	10F
0005432424304	30708	25	12A
0005432424356	30708	26	13A
0005432424404	30708	27	13D
0005432424196	30708	28	13E
0005432424345	30708	29	14D
0005432424364	30708	30	14F
0005432424389	30708	31	15C
0005432424375	30708	32	15D
0005432424336	30708	33	16C
0005432424337	30708	34	17C
0005432424410	30708	35	17D
0005432424342	30708	36	17E
0005432424372	30708	37	17F
0005432424340	30708	38	18E
0005432424310	30708	39	19A
0005432424347	30708	40	19F
0005432424298	30708	41	20C
0005432424395	30708	42	20D
0005432424373	30708	43	20F
0005434157481	9598	1	1A
0005432817714	9598	2	1C
0005432817720	9598	3	1D
0005432817717	9598	4	1F
0005432817700	9598	5	2A
0005432822269	9598	6	2C
0005434448345	9598	7	2D
0005432817701	9598	8	2F
0005432817715	9598	9	3A
0005432817722	9598	10	3C
0005432901521	9598	11	3D
0005434157494	9598	12	3F
0005432901552	9598	13	4A
0005432901565	9598	14	4C
0005432822264	9598	15	4D
0005432901625	9598	16	4F
0005432817708	9598	17	5A
0005434157484	9598	18	5C
0005434157497	9598	19	5E
0005432817713	9598	20	5F
0005432289013	9598	21	6A
0005432817698	9598	22	6C
0005432901516	9598	23	6D
0005432817709	9598	24	6E
0005434186204	9598	25	6F
0005434186187	9598	26	7A
0005432817719	9598	27	7C
0005432901623	9598	28	7D
0005432901576	9598	29	7E
0005432817711	9598	30	7F
0005434186185	9598	31	8A
0005432901560	9598	32	8C
0005432817702	9598	33	8D
0005432901549	9598	34	8E
0005432817718	9598	35	8F
0005434186192	9598	36	9A
0005432901548	9598	37	9C
0005432901672	9598	38	9D
0005432822265	9598	39	9E
0005432817723	9598	40	9F
0005432901503	9598	41	10A
0005434157441	9598	42	10C
0005432901649	9598	43	10D
0005432901631	9598	44	10E
0005432817725	9598	45	11C
0005432817704	9598	46	11D
0005432901534	9598	47	11E
0005434186186	9598	48	11F
0005432901517	9598	49	12A
0005432901614	9598	50	12C
0005432901626	9598	51	12D
0005434186188	9598	52	12E
0005432817710	9598	53	12F
0005432817707	9598	54	13A
0005432817712	9598	55	13C
0005432822266	9598	56	13D
0005432817726	9598	57	13E
0005434448344	9598	58	13F
0005432817705	9598	59	14A
0005432901613	9598	60	14D
0005432817703	9598	61	14E
0005432901627	9598	62	14F
0005432817724	9598	63	15A
0005432901572	9598	64	15C
0005432817706	9598	65	15D
0005432901585	9598	66	15E
0005432901632	9598	67	15F
0005432289012	9598	68	16A
0005434448343	9598	69	16C
0005432901665	9598	70	16D
0005434157442	9598	71	16E
0005434157498	9598	72	16F
0005432817727	9598	73	17A
0005434157440	9598	74	17C
0005432817721	9598	75	17D
0005432289011	9598	76	17E
0005432817716	9598	77	17F
0005432901612	9598	78	18A
0005432901561	9598	79	18D
0005432822267	9598	80	18F
0005432817699	9598	81	19C
0005432289014	9598	82	19E
0005432822268	9598	83	20A
0005432901581	9598	84	20C
0005432901714	9598	85	20D
0005434186205	9598	86	20E
0005432901715	9598	87	20F
0005434157539	28961	1	1A
0005432817376	28961	2	1C
0005432822159	28961	3	1D
0005434157540	28961	4	1F
0005432817394	28961	5	2A
0005432817510	28961	6	2D
0005434157541	28961	7	2F
0005432901753	28961	8	3A
0005434448308	28961	9	3D
0005432901750	28961	10	3F
0005432822205	28961	11	4A
0005432817544	28961	12	4C
0005432822169	28961	13	4D
0005434186220	28961	14	4E
0005432817461	28961	15	4F
0005432901754	28961	16	5C
0005432817374	28961	17	5D
0005432817406	28961	18	5E
0005434157546	28961	19	5F
0005432901748	28961	20	6A
0005432901747	28961	21	6C
0005432901760	28961	22	6D
0005434157547	28961	23	6F
0005432901743	28961	24	7A
0005432822197	28961	25	7D
0005432817545	28961	26	7E
0005432817382	28961	27	8A
0005432817385	28961	28	8C
0005432901752	28961	29	8D
0005432817511	28961	30	8E
0005432817384	28961	31	8F
0005432817538	28961	32	9C
0005432817662	28961	33	9D
0005432002092	28961	34	9F
0005432817431	28961	35	10C
0005432817448	28961	36	10D
0005432817360	28961	37	10E
0005434448311	28961	38	10F
0005432817454	28961	39	11A
0005434448315	28961	40	11C
0005432817343	28961	41	11D
0005434157544	28961	42	11E
0005432901744	28961	43	11F
0005434186221	28961	44	12A
0005432901759	28961	45	12C
0005434186219	28961	46	12D
0005432901758	28961	47	12E
0005432817342	28961	48	12F
0005434448310	28961	49	13A
0005432817663	28961	50	13C
0005432817524	28961	51	13D
0005432817369	28961	52	13F
0005432822200	28961	53	14C
0005432901751	28961	54	14F
0005432822201	28961	55	15A
0005432901746	28961	56	15C
0005434157542	28961	57	15D
0005432822204	28961	58	15E
0005432817501	28961	59	16A
0005432901755	28961	60	16C
0005434157545	28961	61	16D
0005432817534	28961	62	16F
0005432901745	28961	63	17A
0005434157543	28961	64	17C
0005432817425	28961	65	17D
0005434448307	28961	66	17E
0005432901757	28961	67	17F
0005432817375	28961	68	18A
0005432817366	28961	69	18C
0005432817478	28961	70	18D
0005434448316	28961	71	18E
0005432817292	28961	72	18F
0005432817306	28961	73	19A
0005432817307	28961	74	19C
0005432901756	28961	75	19E
0005432817449	28961	76	19F
0005432002093	28961	77	20A
0005432901749	28961	78	20C
0005432822181	28961	79	20D
0005432817496	28961	80	20F
0005432611745	15074	1	1A
0005432613894	15074	2	1B
0005432613897	15074	3	2A
0005432613896	15074	4	3A
0005432611748	15074	5	3B
0005432611742	15074	6	4A
0005432611744	15074	7	4B
0005432611743	15074	8	5A
0005432611747	15074	9	5B
0005432611746	15074	10	6A
0005432613895	15074	11	6B
0005432611720	31588	1	2A
0005432607580	31588	2	1B
0005432611719	31588	3	2B
0005435841828	31588	4	3A
0005432607562	31588	5	3B
0005435841827	31588	6	4B
0005435842331	31588	7	5B
0005432611722	31588	8	6B
0005432948512	11886	1	1C
0005432948422	11886	2	1D
0005433569509	11886	3	1F
0005432948513	11886	4	2D
0005433569516	11886	5	2C
0005432948587	11886	6	3A
0005432948415	11886	7	3D
0005433569502	11886	8	4A
0005433569488	11886	9	3F
0005433569505	11886	10	4D
0005433569537	11886	11	4C
0005432948473	11886	12	4F
0005432948346	11886	13	5C
0005432948423	11886	14	5F
0005432948378	11886	15	5D
0005433569528	11886	16	6A
0005433569499	11886	17	6C
0005432948424	11886	18	6B
0005433569497	11886	19	6E
0005433569513	11886	20	6D
0005433569507	11886	21	7A
0005433569517	11886	22	7C
0005433569480	11886	23	7B
0005432948345	11886	24	7D
0005433569475	11886	25	8A
0005432948390	11886	26	7F
0005433569529	11886	27	7E
0005433569518	11886	28	8C
0005432948588	11886	29	8B
0005432948286	11886	30	8D
0005433569500	11886	31	8F
0005433569514	11886	32	8E
0005433569501	11886	33	9B
0005433569523	11886	34	9A
0005433569487	11886	35	9D
0005432948391	11886	36	9C
0005433569483	11886	37	9E
0005433569484	11886	38	10A
0005433569522	11886	39	9F
0005433569535	11886	40	10B
0005433569472	11886	41	10E
0005432948482	11886	42	10D
0005433569525	11886	43	10F
0005432948511	11886	44	11B
0005433569510	11886	45	11A
0005433569536	11886	46	11D
0005432948711	11886	47	11C
0005433569489	11886	48	11F
0005432948471	11886	49	11E
0005433569498	11886	50	12A
0005433569482	11886	51	12C
0005432948407	11886	52	12B
0005433569531	11886	53	12F
0005433569486	11886	54	12E
0005432948406	11886	55	12D
0005433569493	11886	56	13B
0005433569533	11886	57	13A
0005433569478	11886	58	13C
0005433569519	11886	59	13E
0005432948467	11886	60	13F
0005433569481	11886	61	14C
0005432948493	11886	62	14B
0005433569494	11886	63	14D
0005433569492	11886	64	14F
0005432948306	11886	65	14E
0005433569530	11886	66	15B
0005433569515	11886	67	15A
0005433569520	11886	68	15C
0005433569485	11886	69	15E
0005432948389	11886	70	15D
0005432948397	11886	71	16A
0005432948508	11886	72	15F
0005433569495	11886	73	16B
0005432948461	11886	74	16E
0005433569524	11886	75	16D
0005432948420	11886	76	17A
0005433569474	11886	77	16F
0005433569491	11886	78	17B
0005432948268	11886	79	17D
0005432948468	11886	80	17C
0005432948426	11886	81	17F
0005432948437	11886	82	17E
0005433569476	11886	83	18B
0005432948373	11886	84	18D
0005433569496	11886	85	18C
0005433569526	11886	86	19A
0005433569511	11886	87	18F
0005432948369	11886	88	19C
0005433569503	11886	89	19B
0005433569532	11886	90	19D
0005433569521	11886	91	20A
0005432948425	11886	92	19F
0005433569473	11886	93	19E
0005433569506	11886	94	20B
0005433569527	11886	95	20C
0005433569508	11886	96	20F
0005433569534	11886	97	20E
0005432948523	11886	98	20D
0005433569479	11886	99	21B
0005433569490	11886	100	21A
0005432948336	11886	101	21C
0005433569477	11886	102	21E
0005433569504	11886	103	21D
0005433569512	11886	104	21F
0005433568787	25299	1	1A
0005432948814	25299	2	1D
0005433568999	25299	3	1C
0005433569036	25299	4	2C
0005433568848	25299	5	2A
0005433568628	25299	6	2D
0005432948833	25299	7	3A
0005433569015	25299	8	3D
0005433569037	25299	9	3C
0005432948845	25299	10	3F
0005433568917	25299	11	4D
0005433568915	25299	12	4C
0005432948826	25299	13	5A
0005433569033	25299	14	5F
0005433569111	25299	15	5D
0005433568982	25299	16	6B
0005433568745	25299	17	6A
0005433569118	25299	18	6D
0005432948813	25299	19	6C
0005432948821	25299	20	6E
0005432948811	25299	21	7A
0005432948823	25299	22	6F
0005433568811	25299	23	7C
0005432948806	25299	24	7B
0005433568629	25299	25	7E
0005433568788	25299	26	7F
0005433568951	25299	27	8B
0005433569172	25299	28	8A
0005432948831	25299	29	8E
0005433568918	25299	30	8D
0005432948844	25299	31	8C
0005433569166	25299	32	8F
0005433569097	25299	33	9B
0005433569068	25299	34	9A
0005432948838	25299	35	9D
0005433568732	25299	36	9E
0005432948830	25299	37	9F
0005432948809	25299	38	10C
0005433569117	25299	39	10B
0005432948843	25299	40	10E
0005433568971	25299	41	10D
0005432948837	25299	42	11A
0005433568965	25299	43	10F
0005432948827	25299	44	11B
0005432948817	25299	45	11D
0005433569043	25299	46	11F
0005432948825	25299	47	11E
0005432948832	25299	48	12B
0005433568991	25299	49	12A
0005432948808	25299	50	12C
0005433568886	25299	51	12E
0005432948824	25299	52	13A
0005433568897	25299	53	12F
0005433568636	25299	54	13C
0005432948828	25299	55	13B
0005432948847	25299	56	13E
0005433569119	25299	57	13D
0005432948812	25299	58	14A
0005433569051	25299	59	13F
0005432948840	25299	60	14C
0005433569153	25299	61	14F
0005433568992	25299	62	14E
0005433568952	25299	63	15B
0005433569002	25299	64	15D
0005433568953	25299	65	15C
0005433568646	25299	66	15F
0005432948835	25299	67	15E
0005433568993	25299	68	16B
0005432948816	25299	69	16E
0005432948846	25299	70	16D
0005432948807	25299	71	17A
0005433568630	25299	72	16F
0005432948842	25299	73	17B
0005432948836	25299	74	17D
0005433568926	25299	75	17C
0005433569180	25299	76	17F
0005432948834	25299	77	17E
0005432948829	25299	78	18A
0005432948818	25299	79	18C
0005433569030	25299	80	18B
0005432948841	25299	81	18E
0005432948822	25299	82	18D
0005432948839	25299	83	19A
0005432948819	25299	84	18F
0005433568855	25299	85	19B
0005433568959	25299	86	19C
0005433568697	25299	87	19F
0005433569079	25299	88	19E
0005433569014	25299	89	20B
0005432948820	25299	90	20A
0005433569019	25299	91	20C
0005432948810	25299	92	20F
0005433568808	25299	93	20E
0005433569104	25299	94	21B
0005432948815	25299	95	21A
0005433568964	25299	96	21C
0005433568968	25299	97	21E
0005433568796	25299	98	21F
0005432430886	14465	1	1D
0005434026718	14465	2	2A
0005432430892	14465	3	1F
0005432430897	14465	4	2C
0005432430889	14465	5	3C
0005433808353	14465	6	4A
0005432430887	14465	7	4F
0005433812886	14465	8	4D
0005434026717	14465	9	5C
0005434026716	14465	10	5A
0005433808358	14465	11	6A
0005433808341	14465	12	6D
0005432430896	14465	13	6C
0005432430883	14465	14	7C
0005433812881	14465	15	7E
0005433808369	14465	16	7F
0005433808356	14465	17	8C
0005432430893	14465	18	8B
0005433808339	14465	19	8A
0005432430895	14465	20	8F
0005434026723	14465	21	8E
0005433812883	14465	22	9A
0005433808340	14465	23	9C
0005433812882	14465	24	9D
0005434026720	14465	25	10A
0005433808367	14465	26	10D
0005434026715	14465	27	10F
0005433812887	14465	28	11E
0005433808364	14465	29	11D
0005433808350	14465	30	12B
0005434026721	14465	31	12D
0005433812879	14465	32	13B
0005432430894	14465	33	13E
0005433812893	14465	34	14B
0005433808372	14465	35	14E
0005434026719	14465	36	15A
0005434026722	14465	37	17D
0005433808354	14465	38	17C
0005432430884	14465	39	17E
0005433808371	14465	40	18B
0005432430891	14465	41	18D
0005432430890	14465	42	18F
0005433812880	14465	43	19B
0005432430885	14465	44	19E
0005433812878	14465	45	20E
0005433808391	14465	46	20F
0005432430888	14465	47	21F
0005434654907	5383	1	1C
0005435555368	5383	2	1D
0005435340329	5383	3	2A
0005435340232	5383	4	2C
0005434654926	5383	5	2F
0005434654918	5383	6	3C
0005434654928	5383	7	3D
0005434654910	5383	8	4D
0005435340255	5383	9	4F
0005434654934	5383	10	5A
0005435340231	5383	11	5C
0005432114229	5383	12	5D
0005434654936	5383	13	5F
0005435555378	5383	14	6A
0005435340332	5383	15	6C
0005435340275	5383	16	7A
0005435555369	5383	17	7C
0005434656572	5383	18	7D
0005434654915	5383	19	7E
0005434654925	5383	20	7F
0005434654916	5383	21	8A
0005434654930	5383	22	8C
0005434654932	5383	23	8E
0005434654913	5383	24	9C
0005435340278	5383	25	9E
0005432114228	5383	26	9F
0005434654920	5383	27	10A
0005434654927	5383	28	10C
0005434654924	5383	29	10D
0005434656574	5383	30	10F
0005435555377	5383	31	12A
0005434654914	5383	32	12C
0005435340330	5383	33	12D
0005432114230	5383	34	13A
0005434654908	5383	35	13C
0005435340298	5383	36	13F
0005434654917	5383	37	14C
0005434654912	5383	38	14D
0005434656573	5383	39	15E
0005435340331	5383	40	15F
0005434654922	5383	41	16A
0005434654911	5383	42	16E
0005434654919	5383	43	17C
0005434654931	5383	44	17D
0005434654909	5383	45	18E
0005434654921	5383	46	19A
0005434654929	5383	47	19E
0005434654935	5383	48	19F
0005434654923	5383	49	20A
0005434654933	5383	50	20C
0005434654695	12524	1	1C
0005435340380	12524	2	1D
0005434654781	12524	3	2A
0005435340393	12524	4	2D
0005435340391	12524	5	3A
0005435340381	12524	6	3C
0005435340382	12524	7	3D
0005434654737	12524	8	3F
0005434654630	12524	9	4C
0005435340385	12524	10	4E
0005435340384	12524	11	5C
0005434656552	12524	12	5E
0005434654688	12524	13	5F
0005434654668	12524	14	6A
0005435340394	12524	15	6D
0005434654787	12524	16	6F
0005435340389	12524	17	7C
0005435340387	12524	18	7D
0005434654611	12524	19	7F
0005434656553	12524	20	8A
0005435340383	12524	21	8E
0005434654615	12524	22	9D
0005434654614	12524	23	9E
0005435340390	12524	24	10D
0005434654714	12524	25	10E
0005434654687	12524	26	11D
0005434654710	12524	27	12A
0005435340386	12524	28	12C
0005434654677	12524	29	12F
0005434654768	12524	30	13A
0005434654629	12524	31	13D
0005434654505	12524	32	13E
0005434656554	12524	33	13F
0005434654580	12524	34	14C
0005435340379	12524	35	14E
0005435555388	12524	36	15C
0005434654696	12524	37	15E
0005434656555	12524	38	15F
0005434654738	12524	39	16C
0005435340392	12524	40	16D
0005434654795	12524	41	16E
0005434654786	12524	42	16F
0005434654782	12524	43	17C
0005434654678	12524	44	17E
0005434654778	12524	45	17F
0005434656557	12524	46	18A
0005435340388	12524	47	18C
0005434654783	12524	48	18D
0005434654771	12524	49	19D
0005434654800	12524	50	19E
0005434654676	12524	51	20E
0005433716365	7425	1	1A
0005433716352	7425	2	1D
0005432428934	7425	3	2F
0005432428929	7425	4	3C
0005433716353	7425	5	3A
0005433716367	7425	6	3F
0005432428909	7425	7	4C
0005433716363	7425	8	4D
0005433716390	7425	9	4F
0005433716385	7425	10	5B
0005433716372	7425	11	5A
0005433716361	7425	12	5D
0005433716373	7425	13	5E
0005433716386	7425	14	5F
0005433716396	7425	15	6B
0005433716378	7425	16	6E
0005433716346	7425	17	6D
0005433656694	7425	18	7A
0005433716349	7425	19	6F
0005433716359	7425	20	7B
0005432078156	7425	21	7C
0005433716388	7425	22	7D
0005433716355	7425	23	7F
0005433656696	7425	24	7E
0005433656695	7425	25	8A
0005433688825	7425	26	8B
0005433716392	7425	27	8C
0005433689925	7425	28	8D
0005433722275	7425	29	8F
0005433716360	7425	30	8E
0005433716358	7425	31	9B
0005433716381	7425	32	9C
0005433716347	7425	33	9E
0005433716345	7425	34	9D
0005433689926	7425	35	10B
0005435266139	7425	36	11A
0005432078155	7425	37	11C
0005432428916	7425	38	11B
0005433719166	7425	39	11D
0005433716371	7425	40	11E
0005433716394	7425	41	11F
0005432078153	7425	42	12A
0005433716395	7425	43	12D
0005433722274	7425	44	12E
0005433722272	7425	45	13B
0005433716384	7425	46	13A
0005433690939	7425	47	13C
0005433716369	7425	48	13D
0005433716391	7425	49	13E
0005433719165	7425	50	14C
0005435266140	7425	51	14D
0005433716380	7425	52	15A
0005433716383	7425	53	14F
0005433688826	7425	54	15D
0005433716375	7425	55	15E
0005432078151	7425	56	15F
0005433716387	7425	57	16B
0005433716364	7425	58	16C
0005433719164	7425	59	16F
0005433716356	7425	60	17A
0005433716351	7425	61	17B
0005433716376	7425	62	17C
0005432428924	7425	63	17D
0005433716366	7425	64	17F
0005433716377	7425	65	17E
0005433716370	7425	66	18A
0005433716354	7425	67	18B
0005433719167	7425	68	18C
0005433716382	7425	69	18D
0005433688824	7425	70	19B
0005432078154	7425	71	19A
0005432428915	7425	72	19D
0005432428933	7425	73	19E
0005432428923	7425	74	19F
0005433690940	7425	75	20A
0005433716348	7425	76	20B
0005433716393	7425	77	20E
0005433716368	7425	78	20F
0005432428920	7425	79	21B
0005433716379	7425	80	21A
0005432078152	7425	81	21C
0005433716350	7425	82	22A
0005433716357	7425	83	21F
0005433689927	7425	84	22C
0005433722276	7425	85	22D
0005433722273	7425	86	22F
0005433716362	7425	87	23B
0005433716374	7425	88	23D
0005433716389	7425	89	23E
0005433715950	29233	1	1C
0005433722201	29233	2	1F
0005433716015	29233	3	2A
0005435266183	29233	4	2D
0005433685530	29233	5	3C
0005433716134	29233	6	3F
0005432428955	29233	7	4A
0005433656671	29233	8	5B
0005433715839	29233	9	5D
0005432006784	29233	10	6A
0005433715881	29233	11	5F
0005433715922	29233	12	6D
0005433715975	29233	13	7A
0005433719144	29233	14	7D
0005433715894	29233	15	7E
0005433688798	29233	16	8A
0005432006783	29233	17	7F
0005433716019	29233	18	8B
0005432428956	29233	19	8D
0005433719118	29233	20	8E
0005433688805	29233	21	9A
0005433715853	29233	22	9C
0005433722211	29233	23	9E
0005433715888	29233	24	9D
0005433715779	29233	25	10B
0005435266184	29233	26	10D
0005433688802	29233	27	10C
0005433715953	29233	28	10E
0005433715887	29233	29	11B
0005433715831	29233	30	11F
0005433722194	29233	31	12C
0005433722212	29233	32	12B
0005435266180	29233	33	12D
0005433715916	29233	34	12E
0005433715942	29233	35	12F
0005433716072	29233	36	13B
0005433716031	29233	37	13C
0005433715807	29233	38	13E
0005433716135	29233	39	14B
0005433715952	29233	40	14D
0005433716076	29233	41	14C
0005433715895	29233	42	14F
0005433716063	29233	43	15B
0005433688803	29233	44	15C
0005433715924	29233	45	15E
0005433722215	29233	46	15D
0005433715945	29233	47	16C
0005433716064	29233	48	16E
0005433685531	29233	49	17B
0005432006785	29233	50	17C
0005433715954	29233	51	17E
0005433715803	29233	52	18A
0005433716077	29233	53	17F
0005435266181	29233	54	18B
0005432428957	29233	55	18E
0005435266182	29233	56	18D
0005433715804	29233	57	19D
0005433685529	29233	58	19C
0005433715918	29233	59	19E
0005433715938	29233	60	20B
0005433715889	29233	61	20C
0005433716075	29233	62	20E
0005433715923	29233	63	20D
0005433722202	29233	64	21B
0005433716095	29233	65	21D
0005433722216	29233	66	21C
0005433719128	29233	67	21E
0005433715840	29233	68	21F
0005432428958	29233	69	22A
0005433716054	29233	70	22C
0005433716071	29233	71	22E
0005433715703	29233	72	22F
0005433715917	29233	73	23A
0005433715802	29233	74	23D
0005433715785	29233	75	23E
0005434143741	8691	1	1C
0005434143743	8691	2	1D
0005434095398	8691	3	2A
0005434095390	8691	4	3F
0005434182194	8691	5	4D
0005434095387	8691	6	5E
0005434095395	8691	7	6C
0005434182223	8691	8	6F
0005434143742	8691	9	9D
0005434095388	8691	10	9E
0005434182159	8691	11	9F
0005434182127	8691	12	10E
0005434184669	8691	13	10F
0005434182176	8691	14	11A
0005434182224	8691	15	11D
0005434182175	8691	16	12E
0005434095397	8691	17	13D
0005434095391	8691	18	14E
0005434095394	8691	19	15F
0005434182189	8691	20	17A
0005434095392	8691	21	17F
0005434182229	8691	22	18A
0005434095393	8691	23	18C
0005434095396	8691	24	18E
0005434184670	8691	25	19C
0005434095389	8691	26	20D
0005434184679	11679	1	3C
0005434095269	11679	2	4A
0005434095288	11679	3	5A
0005434095250	11679	4	5C
0005434182290	11679	5	5F
0005434095280	11679	6	6D
0005434182279	11679	7	6E
0005434182281	11679	8	6F
0005434143728	11679	9	7A
0005434095190	11679	10	7D
0005434095286	11679	11	7E
0005434182283	11679	12	7F
0005434183594	11679	13	8A
0005434183595	11679	14	8F
0005434182291	11679	15	9A
0005434182284	11679	16	11A
0005434182286	11679	17	12C
0005434326269	11679	18	14A
0005434183593	11679	19	14F
0005434095251	11679	20	15A
0005434182288	11679	21	15F
0005434182282	11679	22	16A
0005434182280	11679	23	16D
0005434182287	11679	24	16F
0005434182285	11679	25	17D
0005434326268	11679	26	18C
0005434095151	11679	27	18D
0005434095270	11679	28	19D
0005434095287	11679	29	19F
0005434182289	11679	30	20A
0005434184680	11679	31	20D
0005434184681	11679	32	20E
0005433398007	1441	1	1C
0005433398002	1441	2	1D
0005433397941	1441	3	1F
0005433398086	1441	4	2A
0005435732438	1441	5	2C
0005435732430	1441	6	2D
0005432297299	1441	7	3A
0005433398233	1441	8	3D
0005433397882	1441	9	3F
0005433398076	1441	10	4A
0005435732420	1441	11	4C
0005433457003	1441	12	4D
0005433398251	1441	13	4E
0005433398003	1441	14	4F
0005433398054	1441	15	5C
0005433397880	1441	16	5D
0005435732424	1441	17	5E
0005435732428	1441	18	5F
0005435732429	1441	19	6A
0005433398056	1441	20	6D
0005435732423	1441	21	7A
0005433398143	1441	22	7E
0005433398235	1441	23	8A
0005435732432	1441	24	8C
0005435732440	1441	25	8D
0005433398091	1441	26	8F
0005433398253	1441	27	9C
0005433398021	1441	28	9D
0005433397957	1441	29	9E
0005433398142	1441	30	9F
0005432906537	1441	31	10A
0005433397966	1441	32	10E
0005433397827	1441	33	10F
0005433398041	1441	34	11A
0005435732421	1441	35	11C
0005435732427	1441	36	11D
0005435732437	1441	37	11E
0005433457000	1441	38	11F
0005433398122	1441	39	12A
0005433397847	1441	40	12C
0005435732425	1441	41	12D
0005433457002	1441	42	12E
0005435732434	1441	43	12F
0005433398252	1441	44	13A
0005433398075	1441	45	13C
0005433457001	1441	46	13D
0005433397995	1441	47	13E
0005433397956	1441	48	13F
0005433397784	1441	49	14A
0005433397876	1441	50	14F
0005433398006	1441	51	15C
0005433397965	1441	52	15D
0005433398065	1441	53	15E
0005435732435	1441	54	15F
0005433398234	1441	55	16C
0005433397902	1441	56	16D
0005433398096	1441	57	16E
0005433398092	1441	58	16F
0005433398009	1441	59	17A
0005433397859	1441	60	17C
0005433398155	1441	61	17D
0005435732431	1441	62	17F
0005433397942	1441	63	18C
0005433398055	1441	64	18D
0005433398042	1441	65	18F
0005433398123	1441	66	19A
0005435732426	1441	67	19D
0005435732433	1441	68	19E
0005435732439	1441	69	19F
0005433398090	1441	70	20A
0005433398008	1441	71	20C
0005435732436	1441	72	20D
0005435732422	1441	73	20E
0005435732321	19263	1	1C
0005433398455	19263	2	1D
0005433398458	19263	3	2A
0005433398438	19263	4	2C
0005433398442	19263	5	2D
0005433398464	19263	6	2F
0005435732319	19263	7	3A
0005432906555	19263	8	3C
0005435732318	19263	9	3F
0005433398466	19263	10	4A
0005433398469	19263	11	4E
0005433398462	19263	12	5C
0005433398456	19263	13	5E
0005433398435	19263	14	6A
0005433398429	19263	15	6C
0005433398436	19263	16	6D
0005433398450	19263	17	6E
0005433398445	19263	18	6F
0005433398441	19263	19	7C
0005435732352	19263	20	7D
0005433398430	19263	21	7E
0005433398431	19263	22	7F
0005433398434	19263	23	8A
0005433398452	19263	24	8E
0005433398461	19263	25	8F
0005433456971	19263	26	9C
0005433398459	19263	27	9D
0005435732345	19263	28	9F
0005433456972	19263	29	10A
0005433398454	19263	30	10C
0005435732363	19263	31	10D
0005433398424	19263	32	10E
0005433456946	19263	33	10F
0005433398426	19263	34	11A
0005435732322	19263	35	11C
0005433398425	19263	36	11D
0005433398447	19263	37	11F
0005433398448	19263	38	12C
0005435732285	19263	39	12E
0005433398451	19263	40	13A
0005433398468	19263	41	13E
0005433398457	19263	42	13F
0005433456979	19263	43	14A
0005433398427	19263	44	14C
0005433398463	19263	45	14E
0005435732327	19263	46	14F
0005433398428	19263	47	15A
0005433456973	19263	48	15C
0005433398443	19263	49	15D
0005433398423	19263	50	15F
0005433398449	19263	51	16D
0005433398439	19263	52	16E
0005433398444	19263	53	17A
0005433398453	19263	54	17C
0005433398470	19263	55	17D
0005433398421	19263	56	17E
0005433456980	19263	57	17F
0005432906556	19263	58	18A
0005433398432	19263	59	18C
0005433398422	19263	60	18D
0005433398467	19263	61	18F
0005433398460	19263	62	19A
0005433398433	19263	63	19E
0005435732328	19263	64	20A
0005433398440	19263	65	20C
0005433398446	19263	66	20D
0005433398465	19263	67	20E
0005433398437	19263	68	20F
0005434443738	17355	1	1A
0005434443724	17355	2	1B
0005434443723	17355	3	2C
0005434443696	17355	4	3A
0005434443704	17355	5	3B
0005434443759	17355	6	3D
0005434443688	17355	7	4C
0005434443714	17355	8	5A
0005434443737	17355	9	4D
0005434443717	17355	10	5B
0005434443703	17355	11	5C
0005434443705	17355	12	5D
0005434443681	17355	13	6B
0005434443698	17355	14	6C
0005434443672	17355	15	7A
0005434443638	17355	16	7B
0005434443697	17355	17	7C
0005434443739	17355	18	7D
0005434443670	17355	19	18A
0005434443680	17355	20	19A
0005434443713	17355	21	19D
0005434443673	17355	22	20D
0005434443770	17355	23	21B
0005434443695	17355	24	22D
0005434443821	20605	1	1A
0005434443835	20605	2	2C
0005434443827	20605	3	3A
0005434443828	20605	4	3B
0005434443825	20605	5	3C
0005434443820	20605	6	4B
0005434443829	20605	7	5A
0005434443824	20605	8	5C
0005434443834	20605	9	5D
0005434443826	20605	10	6B
0005434443830	20605	11	6C
0005434443822	20605	12	7B
0005434443832	20605	13	7C
0005434443823	20605	14	20C
0005434443836	20605	15	21C
0005434443833	20605	16	21D
0005434443831	20605	17	22D
0005435377578	7240	1	1A
0005434954641	7240	2	1B
0005434954642	7240	3	2B
0005434954640	7240	4	3A
0005434954638	7240	5	4A
0005434954639	7240	6	4B
0005434954643	7240	7	5A
0005435377573	7240	8	6B
0005435377600	28324	1	1B
0005434954609	28324	2	2A
0005434954613	28324	3	2B
0005434954591	28324	4	3A
0005434954612	28324	5	4A
0005435377598	28324	6	5A
0005435377599	28324	7	5B
0005434954615	28324	8	6A
0005434954614	28324	9	6B
0005434351796	4498	1	1A
0005435893674	4498	2	1B
0005434351800	4498	3	1C
0005435893612	4498	4	2A
0005434326274	4498	5	2B
0005435893658	4498	6	2C
0005434351793	4498	7	3B
0005435893611	4498	8	3C
0005434351792	4498	9	4A
0005434351795	4498	10	4B
0005435893659	4498	11	5A
0005434351802	4498	12	5C
0005434351794	4498	13	6B
0005434351799	4498	14	6C
0005434183582	4498	15	6D
0005435893642	4498	16	7D
0005434351797	4498	17	18C
0005434351798	4498	18	18D
0005435893627	4498	19	20A
0005434351803	4498	20	20B
0005434351804	4498	21	21A
0005434351801	4498	22	22A
0005434183583	4498	23	22C
0005435893691	29651	1	1B
0005434351729	29651	2	1D
0005435893687	29651	3	2A
0005434351707	29651	4	3D
0005434351737	29651	5	4A
0005435893689	29651	6	4C
0005434351708	29651	7	6A
0005434351670	29651	8	7A
0005434351692	29651	9	7D
0005434351665	29651	10	18C
0005434351715	29651	11	18D
0005434351694	29651	12	19A
0005434351714	29651	13	19B
0005434351728	29651	14	19C
0005435893686	29651	15	20B
0005434351693	29651	16	20C
0005435893690	29651	17	21C
0005435893688	29651	18	22C
0005434351647	29651	19	23A
0005433343159	1097	1	1A
0005433342891	1097	2	1B
0005433343359	1097	3	1F
0005433343142	1097	4	2A
0005433342676	1097	5	1H
0005433269738	1097	6	2F
0005433342966	1097	7	2G
0005433269722	1097	8	3B
0005433343143	1097	9	3F
0005433343051	1097	10	3G
0005433343117	1097	11	3H
0005433269719	1097	12	4B
0005433463917	1097	13	4C
0005433342642	1097	14	5A
0005433343100	1097	15	5F
0005433342600	1097	16	5C
0005432293228	1097	17	5G
0005433342965	1097	18	9A
0005433343285	1097	19	5H
0005433342468	1097	20	9B
0005433462763	1097	21	9G
0005433269711	1097	22	9H
0005434446535	1097	23	11B
0005435545795	1097	24	11E
0005433343473	1097	25	11D
0005433342921	1097	26	11F
0005433158137	1097	27	12A
0005433343149	1097	28	12E
0005433343150	1097	29	12G
0005433343094	1097	30	12F
0005433342590	1097	31	12H
0005433343444	1097	32	13A
0005433342914	1097	33	13D
0005433342467	1097	34	13G
0005435092154	1097	35	13F
0005433343284	1097	36	14G
0005433342449	1097	37	15D
0005433269707	1097	38	15E
0005433342892	1097	39	15F
0005433342517	1097	40	15H
0005435092152	1097	41	15G
0005433343101	1097	42	16B
0005435545793	1097	43	16F
0005435545794	1097	44	16H
0005433343112	1097	45	16G
0005433343092	1097	46	17D
0005433343031	1097	47	17E
0005433343151	1097	48	17G
0005433343472	1097	49	18A
0005435092150	1097	50	17H
0005433269710	1097	51	18B
0005433343007	1097	52	18D
0005435092158	1097	53	18E
0005433463918	1097	54	18H
0005433343113	1097	55	19D
0005433343136	1097	56	19B
0005435092156	1097	57	19E
0005433343010	1097	58	20B
0005433343352	1097	59	20D
0005433342953	1097	60	20F
0005433343287	1097	61	20E
0005433342832	1097	62	20H
0005433342837	1097	63	21B
0005432293229	1097	64	21D
0005435092155	1097	65	21F
0005433342967	1097	66	21E
0005433343311	1097	67	21G
0005433343081	1097	68	22D
0005433342762	1097	69	22F
0005433343087	1097	70	22G
0005434445261	1097	71	23B
0005433343080	1097	72	23A
0005433343069	1097	73	23D
0005433343148	1097	74	23F
0005433342770	1097	75	23E
0005434446534	1097	76	24B
0005435092157	1097	77	24A
0005433462764	1097	78	24E
0005433343263	1097	79	24G
0005433343259	1097	80	25D
0005433343139	1097	81	25E
0005433342886	1097	82	27A
0005433342708	1097	83	25F
0005433343213	1097	84	27B
0005433343086	1097	85	27G
0005433342942	1097	86	27H
0005433343027	1097	87	28E
0005433343147	1097	88	28F
0005433269724	1097	89	28H
0005435092149	1097	90	29A
0005433342763	1097	91	29E
0005435092153	1097	92	29D
0005433342868	1097	93	29F
0005433342865	1097	94	29H
0005433343089	1097	95	29G
0005433342730	1097	96	30E
0005433343028	1097	97	30F
0005435545796	1097	98	30G
0005433342751	1097	99	31A
0005433342923	1097	100	30H
0005433343008	1097	101	31B
0005433343130	1097	102	31E
0005433343029	1097	103	31F
0005433343090	1097	104	31G
0005433343005	1097	105	32A
0005433342595	1097	106	31H
0005433342846	1097	107	32B
0005433342910	1097	108	32F
0005433343033	1097	109	32E
0005433269718	1097	110	32H
0005433342739	1097	111	32G
0005433342754	1097	112	33A
0005433269723	1097	113	33D
0005433343155	1097	114	33E
0005433342971	1097	115	33G
0005433342847	1097	116	33F
0005434446533	1097	117	33H
0005433269703	1097	118	34A
0005435545792	1097	119	34D
0005433343325	1097	120	34B
0005435092159	1097	121	34F
0005433269712	1097	122	34E
0005433343032	1097	123	35A
0005433342764	1097	124	34H
0005433269709	1097	125	35B
0005433343312	1097	126	35D
0005433343088	1097	127	35E
0005433342836	1097	128	35G
0005433343161	1097	129	36B
0005435092151	1097	130	36A
0005433343067	1097	131	36H
0005433342731	1097	132	37A
0005433269717	1097	133	37B
0005433269708	1097	134	37G
0005433343353	1097	135	37F
0005434446536	1097	136	37H
0005433342878	1097	137	38A
0005433342972	1097	138	38D
0005433343251	1097	139	38B
0005433342738	1097	140	38E
0005433343252	1097	141	38G
0005433158136	1097	142	38H
0005433343011	1097	143	39D
0005433342773	1097	144	39F
0005433343840	17060	1	1B
0005433159329	17060	2	1F
0005433343846	17060	3	1C
0005433343867	17060	4	1H
0005433343837	17060	5	2C
0005433343847	17060	6	2F
0005433343903	17060	7	3F
0005433343851	17060	8	3H
0005435508314	17060	9	4A
0005433343828	17060	10	4B
0005433343832	17060	11	4C
0005433343918	17060	12	4G
0005433343849	17060	13	4H
0005435508356	17060	14	5B
0005433343857	17060	15	5A
0005433343854	17060	16	5G
0005433343919	17060	17	5F
0005433343878	17060	18	9A
0005435508300	17060	19	5H
0005433159331	17060	20	9H
0005435508301	17060	21	11B
0005433343889	17060	22	11H
0005433343891	17060	23	11G
0005433343888	17060	24	12A
0005433343912	17060	25	12E
0005435092069	17060	26	12D
0005433343861	17060	27	12G
0005433343911	17060	28	12F
0005433343833	17060	29	13A
0005433343874	17060	30	13D
0005433343862	17060	31	13F
0005433343827	17060	32	13G
0005433343863	17060	33	14A
0005433343872	17060	34	14F
0005433343873	17060	35	14E
0005435508333	17060	36	15A
0005433343823	17060	37	15E
0005435508299	17060	38	15F
0005433343822	17060	39	15G
0005433343826	17060	40	16B
0005433343860	17060	41	16A
0005433343890	17060	42	16F
0005433343883	17060	43	17B
0005433343908	17060	44	17A
0005433343879	17060	45	17F
0005433343853	17060	46	17H
0005433343834	17060	47	18A
0005433343831	17060	48	18D
0005433343821	17060	49	18F
0005435508355	17060	50	18E
0005433343869	17060	51	18G
0005433343870	17060	52	19B
0005433269762	17060	53	19A
0005433343887	17060	54	19E
0005433269759	17060	55	19G
0005433343894	17060	56	20A
0005433343905	17060	57	19H
0005433343909	17060	58	20B
0005433343852	17060	59	20E
0005433343820	17060	60	20F
0005433343907	17060	61	20G
0005433343842	17060	62	21A
0005433343871	17060	63	21B
0005433343882	17060	64	21G
0005433343864	17060	65	21H
0005433343824	17060	66	22B
0005433343895	17060	67	22E
0005433343900	17060	68	22G
0005433269760	17060	69	22F
0005433343915	17060	70	22H
0005433343843	17060	71	23B
0005433343913	17060	72	23F
0005433343844	17060	73	23G
0005433343836	17060	74	24A
0005433343858	17060	75	24B
0005433343914	17060	76	24E
0005435508357	17060	77	24F
0005435508297	17060	78	24G
0005433343865	17060	79	25D
0005435092082	17060	80	24H
0005433343848	17060	81	25E
0005433343893	17060	82	27B
0005433343841	17060	83	27D
0005433343897	17060	84	27E
0005433343899	17060	85	27H
0005433343910	17060	86	27G
0005433269761	17060	87	28D
0005433343920	17060	88	28F
0005435508334	17060	89	28E
0005433343825	17060	90	28G
0005433343898	17060	91	29A
0005433343877	17060	92	28H
0005435508335	17060	93	29B
0005435092073	17060	94	29E
0005433343917	17060	95	29D
0005435092052	17060	96	29F
0005433269764	17060	97	29H
0005433343855	17060	98	30B
0005433343881	17060	99	30G
0005433343921	17060	100	30F
0005433343875	17060	101	30H
0005433343835	17060	102	31D
0005433343906	17060	103	31F
0005435508298	17060	104	31H
0005433343845	17060	105	31G
0005433269763	17060	106	32A
0005435092084	17060	107	32B
0005435508313	17060	108	32D
0005433343859	17060	109	32H
0005433343880	17060	110	33B
0005435092083	17060	111	33E
0005433343884	17060	112	33F
0005435508364	17060	113	33H
0005433159330	17060	114	34F
0005433343856	17060	115	34E
0005435092068	17060	116	34G
0005433343885	17060	117	35D
0005435508359	17060	118	35B
0005433343902	17060	119	35F
0005435508351	17060	120	35E
0005433343886	17060	121	35H
0005433343868	17060	122	36E
0005433343839	17060	123	36D
0005433343876	17060	124	36F
0005433269765	17060	125	36H
0005433343896	17060	126	36G
0005435508332	17060	127	37B
0005433343904	17060	128	37A
0005433343901	17060	129	37F
0005433343850	17060	130	37H
0005433343892	17060	131	37G
0005433343866	17060	132	38A
0005433159332	17060	133	38D
0005433343838	17060	134	38B
0005433343830	17060	135	38F
0005433343916	17060	136	38H
0005433343829	17060	137	39F
0005434067663	12802	1	1A
0005434067507	12802	2	1C
0005434081842	12802	3	1D
0005434067364	12802	4	1F
0005434067171	12802	5	2C
0005434067300	12802	6	2A
0005434067799	12802	7	2D
0005433989758	12802	8	2F
0005434067814	12802	9	3C
0005432159894	12802	10	3A
0005434067282	12802	11	3D
0005434067508	12802	12	3F
0005434067502	12802	13	4B
0005434067505	12802	14	4A
0005434067319	12802	15	4C
0005434067733	12802	16	4D
0005434067655	12802	17	4E
0005434067597	12802	18	4F
0005434067521	12802	19	5B
0005434067477	12802	20	5A
0005434067524	12802	21	5C
0005434067052	12802	22	5D
0005432433722	12802	23	5E
0005434067366	12802	24	6A
0005434067183	12802	25	5F
0005434067727	12802	26	6C
0005433989770	12802	27	6D
0005432161169	12802	28	6E
0005433812920	12802	29	7A
0005434067792	12802	30	6F
0005434067467	12802	31	7B
0005434067122	12802	32	7C
0005433989761	12802	33	7D
0005432433723	12802	34	7F
0005433989765	12802	35	7E
0005434067674	12802	36	8A
0005434081791	12802	37	8B
0005434067598	12802	38	8C
0005432159892	12802	39	8D
0005434067454	12802	40	8F
0005434067486	12802	41	8E
0005434067686	12802	42	9A
0005434067813	12802	43	9B
0005434067283	12802	44	9D
0005434067633	12802	45	9C
0005434067729	12802	46	9F
0005434067632	12802	47	9E
0005434067504	12802	48	10B
0005434067312	12802	49	10C
0005434067627	12802	50	10E
0005434067463	12802	51	10D
0005434067515	12802	52	11A
0005434067279	12802	53	11C
0005434067561	12802	54	11B
0005434067399	12802	55	11D
0005432159893	12802	56	11F
0005434067432	12802	57	11E
0005434067547	12802	58	12B
0005434067479	12802	59	12A
0005434081752	12802	60	12C
0005434067541	12802	61	12D
0005434067466	12802	62	12E
0005434067676	12802	63	12F
0005434067352	12802	64	13A
0005434067577	12802	65	13B
0005434067675	12802	66	13C
0005434067382	12802	67	13E
0005434067050	12802	68	13D
0005432159896	12802	69	13F
0005434081820	12802	70	14A
0005433989769	12802	71	14C
0005434067478	12802	72	14B
0005432433720	12802	73	14D
0005434067383	12802	74	14F
0005434067600	12802	75	14E
0005434067622	12802	76	15A
0005434067509	12802	77	15C
0005434067659	12802	78	15B
0005434067192	12802	79	15D
0005433989764	12802	80	15E
0005434067291	12802	81	16A
0005434067542	12802	82	15F
0005434067735	12802	83	16B
0005434067345	12802	84	16C
0005432433721	12802	85	16D
0005434067262	12802	86	16F
0005434067449	12802	87	16E
0005434081764	12802	88	17A
0005432161170	12802	89	17B
0005434067172	12802	90	17C
0005434067339	12802	91	17D
0005434067660	12802	92	17F
0005434067628	12802	93	17E
0005434067280	12802	94	18A
0005434067649	12802	95	18B
0005432433724	12802	96	18C
0005434067430	12802	97	18E
0005434067451	12802	98	18D
0005434067336	12802	99	18F
0005434067677	12802	100	19A
0005434067246	12802	101	19B
0005433812919	12802	102	19D
0005434067292	12802	103	19C
0005434067624	12802	104	19F
0005434081821	12802	105	19E
0005434067562	12802	106	20A
0005434067051	12802	107	20B
0005434067311	12802	108	20C
0005434067703	12802	109	20E
0005434067344	12802	110	20D
0005432433725	12802	111	21A
0005434081840	12802	112	20F
0005434067687	12802	113	21B
0005434067274	12802	114	21D
0005433989771	12802	115	21C
0005434067728	12802	116	21E
0005434081843	12802	117	22A
0005432159895	12802	118	21F
0005434081837	12802	119	22B
0005434067503	12802	120	22C
0005434081834	12802	121	22D
0005434067636	12802	122	22E
0005434081845	12802	123	22F
0005434081867	12802	124	23B
0005434067559	12802	125	23C
0005434067734	12802	126	23D
0005432161171	12802	127	23E
0005434067450	12802	128	23F
0005434082072	30663	1	1A
0005434068086	30663	2	1C
0005434068083	30663	3	1D
0005434082078	30663	4	2A
0005434068082	30663	5	1F
0005434068073	30663	6	2C
0005434068098	30663	7	2D
0005434068047	30663	8	2F
0005434068038	30663	9	3C
0005434068109	30663	10	3A
0005434068093	30663	11	3D
0005432433694	30663	12	3F
0005432433674	30663	13	4A
0005434068048	30663	14	4B
0005433989807	30663	15	4D
0005434068087	30663	16	4C
0005434082079	30663	17	4E
0005434068074	30663	18	4F
0005434068102	30663	19	5B
0005434068045	30663	20	5A
0005432433691	30663	21	5C
0005434068064	30663	22	5D
0005432186895	30663	23	5E
0005434068078	30663	24	5F
0005432186896	30663	25	6A
0005434068095	30663	26	6C
0005434068061	30663	27	6B
0005434068050	30663	28	6D
0005434068070	30663	29	6E
0005434082064	30663	30	6F
0005432433673	30663	31	7B
0005434082082	30663	32	7A
0005434068099	30663	33	7C
0005434068043	30663	34	7D
0005434068090	30663	35	7F
0005434068103	30663	36	7E
0005434082081	30663	37	8A
0005433989805	30663	38	8B
0005434068069	30663	39	8C
0005434068052	30663	40	8D
0005434082060	30663	41	8F
0005434082065	30663	42	8E
0005434068071	30663	43	9A
0005434082085	30663	44	9B
0005434068079	30663	45	9D
0005434068089	30663	46	9C
0005434068042	30663	47	9E
0005432433683	30663	48	9F
0005434068065	30663	49	10B
0005434068100	30663	50	10C
0005432433692	30663	51	10E
0005434068105	30663	52	10D
0005434068104	30663	53	11A
0005434082069	30663	54	11B
0005434068077	30663	55	11C
0005434082080	30663	56	11E
0005434068080	30663	57	11F
0005434068108	30663	58	12B
0005434068060	30663	59	12A
0005434082066	30663	60	12D
0005432150247	30663	61	12C
0005434068067	30663	62	12E
0005432150252	30663	63	12F
0005434068068	30663	64	13B
0005434068094	30663	65	13A
0005432186894	30663	66	13C
0005434068054	30663	67	13D
0005434082062	30663	68	13E
0005434082068	30663	69	13F
0005434082070	30663	70	14B
0005434068101	30663	71	14A
0005434068076	30663	72	14C
0005433989804	30663	73	14D
0005434082077	30663	74	14F
0005434068096	30663	75	15A
0005434068097	30663	76	15C
0005434082071	30663	77	15B
0005434068039	30663	78	15D
0005434068041	30663	79	15E
0005434068057	30663	80	15F
0005434068055	30663	81	16B
0005434082061	30663	82	16A
0005434068046	30663	83	16C
0005434082073	30663	84	16E
0005434068085	30663	85	16D
0005434068051	30663	86	17A
0005434082059	30663	87	16F
0005434082075	30663	88	17B
0005434068059	30663	89	17C
0005434082084	30663	90	17D
0005434068088	30663	91	17F
0005434068084	30663	92	17E
0005433989806	30663	93	18A
0005434082067	30663	94	18B
0005432433672	30663	95	18C
0005434068106	30663	96	18D
0005434068066	30663	97	18E
0005434068081	30663	98	19A
0005434068062	30663	99	19C
0005434068063	30663	100	19B
0005434082087	30663	101	19D
0005433989803	30663	102	19E
0005434068107	30663	103	19F
0005434068053	30663	104	20A
0005434082083	30663	105	20C
0005432150248	30663	106	20B
0005432150249	30663	107	20E
0005432150254	30663	108	20D
0005434082089	30663	109	20F
0005434082088	30663	110	21A
0005432150253	30663	111	21C
0005434082063	30663	112	21B
0005434068044	30663	113	21D
0005434068092	30663	114	21E
0005434082076	30663	115	22A
0005434082074	30663	116	22B
0005434068091	30663	117	22C
0005434068075	30663	118	22D
0005434068058	30663	119	22F
0005432150250	30663	120	22E
0005434068049	30663	121	23B
0005434068040	30663	122	23A
0005434068072	30663	123	23C
0005434068056	30663	124	23D
0005434082086	30663	125	23F
0005432150251	30663	126	23E
0005433689899	19351	1	1B
0005433686608	19351	2	2A
0005433689909	19351	3	3A
0005433689910	19351	4	3D
0005433686629	19351	5	4D
0005433686626	19351	6	5C
0005433686625	19351	7	6D
0005433689898	19351	8	7B
0005433686630	19351	9	18D
0005433686628	19351	10	21D
0005432140516	5528	1	1B
0005434265172	5528	2	1C
0005435735172	5528	3	1H
0005434265100	5528	4	1G
0005435766712	5528	5	2C
0005435766701	5528	6	2B
0005435462334	5528	7	2F
0005435766745	5528	8	2G
0005435766686	5528	9	3A
0005435462365	5528	10	2H
0005435462378	5528	11	3B
0005435462358	5528	12	3G
0005435462420	5528	13	3F
0005435766698	5528	14	4A
0005432140517	5528	15	3H
0005435725635	5528	16	4B
0005435766751	5528	17	4G
0005435735171	5528	18	4F
0005434265134	5528	19	5A
0005435766740	5528	20	4H
0005435462338	5528	21	5B
0005435766749	5528	22	5G
0005435766694	5528	23	5F
0005435766679	5528	24	5H
0005434831159	5528	25	9B
0005435766724	5528	26	9G
0005435462459	5528	27	9H
0005435462403	5528	28	11B
0005435462359	5528	29	11E
0005435766747	5528	30	11D
0005435766731	5528	31	11G
0005435766710	5528	32	12E
0005435766682	5528	33	12F
0005435462419	5528	34	12G
0005435766690	5528	35	13A
0005435722074	5528	36	13D
0005435766722	5528	37	13E
0005433527298	5528	38	13H
0005434265230	5528	39	14A
0005435766742	5528	40	14F
0005434831154	5528	41	14E
0005435725636	5528	42	14G
0005435766727	5528	43	15A
0005435462443	5528	44	14H
0005435766700	5528	45	15B
0005435462450	5528	46	15E
0005435462390	5528	47	15D
0005434831153	5528	48	15F
0005434265096	5528	49	15G
0005435766732	5528	50	16A
0005434265030	5528	51	16D
0005435462479	5528	52	16G
0005435766735	5528	53	16F
0005434265143	5528	54	17A
0005435766705	5528	55	17D
0005435766693	5528	56	17B
0005435462248	5528	57	17F
0005435766750	5528	58	17E
0005435766729	5528	59	18A
0005435462478	5528	60	18B
0005435766704	5528	61	18D
0005435462511	5528	62	18F
0005435766677	5528	63	18E
0005434265070	5528	64	18G
0005435766730	5528	65	19A
0005432140509	5528	66	18H
0005435722075	5528	67	19B
0005435462533	5528	68	19D
0005435766707	5528	69	19F
0005435766723	5528	70	19E
0005435766718	5528	71	20A
0005435766738	5528	72	19H
0005432140515	5528	73	20B
0005435462389	5528	74	20E
0005434265162	5528	75	20D
0005435766721	5528	76	21B
0005435462440	5528	77	20H
0005435735170	5528	78	21D
0005435766728	5528	79	21E
0005433527299	5528	80	21G
0005435766695	5528	81	21F
0005435766689	5528	82	22A
0005435462354	5528	83	22D
0005435735168	5528	84	22B
0005434265232	5528	85	22G
0005435766737	5528	86	22F
0005432535805	5528	87	22H
0005432140514	5528	88	23B
0005435766744	5528	89	23A
0005435766684	5528	90	23E
0005435462414	5528	91	23D
0005435766713	5528	92	23F
0005435766743	5528	93	23H
0005435766746	5528	94	23G
0005435766748	5528	95	24B
0005434265098	5528	96	24E
0005435462353	5528	97	24F
0005435725634	5528	98	24G
0005435766752	5528	99	25D
0005435766687	5528	100	24H
0005435725638	5528	101	25F
0005435766736	5528	102	27A
0005435766726	5528	103	27B
0005435766703	5528	104	27D
0005435462462	5528	105	27F
0005435766692	5528	106	27E
0005435766719	5528	107	27G
0005435462461	5528	108	28A
0005435766734	5528	109	27H
0005434264968	5528	110	28D
0005435766696	5528	111	28B
0005435766706	5528	112	28E
0005434265101	5528	113	28H
0005435462510	5528	114	28G
0005435462396	5528	115	29D
0005435766725	5528	116	29E
0005435766678	5528	117	30A
0005434831158	5528	118	29H
0005435766715	5528	119	29G
0005435766733	5528	120	30D
0005435766711	5528	121	30H
0005435766702	5528	122	30G
0005434265173	5528	123	31A
0005435462493	5528	124	31B
0005433529310	5528	125	31D
0005435462418	5528	126	31F
0005435766681	5528	127	31E
0005435462439	5528	128	31H
0005434265157	5528	129	31G
0005435462449	5528	130	32A
0005435766720	5528	131	32D
0005435766680	5528	132	32B
0005434265147	5528	133	32E
0005435766697	5528	134	32G
0005434265176	5528	135	33A
0005435462249	5528	136	32H
0005433529309	5528	137	33B
0005435722073	5528	138	33F
0005434831152	5528	139	33H
0005434265146	5528	140	34D
0005435723061	5528	141	34G
0005432535806	5528	142	34F
0005435766699	5528	143	34H
0005435766716	5528	144	35B
0005432140512	5528	145	35A
0005434265231	5528	146	35D
0005435766714	5528	147	35E
0005435766708	5528	148	35G
0005435766688	5528	149	36A
0005434265097	5528	150	35H
0005432140513	5528	151	36D
0005432140511	5528	152	36E
0005435766709	5528	153	36H
0005435766717	5528	154	36G
0005434265140	5528	155	37A
0005435725637	5528	156	37B
0005435766739	5528	157	37E
0005435766685	5528	158	37G
0005433529311	5528	159	38B
0005435766741	5528	160	38A
0005433529308	5528	161	38D
0005435735169	5528	162	38F
0005435766691	5528	163	38E
0005432140510	5528	164	38H
0005435766683	5528	165	39F
0005435462761	13487	1	1A
0005434265349	13487	2	1B
0005432194546	13487	3	1F
0005434265338	13487	4	1C
0005435766189	13487	5	1H
0005435725580	13487	6	2A
0005435462759	13487	7	2B
0005434831189	13487	8	2F
0005435766052	13487	9	2G
0005435766114	13487	10	2H
0005432535873	13487	11	3B
0005435766070	13487	12	3H
0005435462750	13487	13	4A
0005435766138	13487	14	4F
0005435766020	13487	15	4C
0005435766191	13487	16	4G
0005434265351	13487	17	5A
0005434265355	13487	18	4H
0005434265342	13487	19	5F
0005435462756	13487	20	5C
0005435766067	13487	21	5H
0005433533296	13487	22	9A
0005433529274	13487	23	9H
0005432194543	13487	24	11B
0005435766068	13487	25	11E
0005433533297	13487	26	11D
0005433533285	13487	27	11G
0005435722054	13487	28	11F
0005435766054	13487	29	12B
0005434831191	13487	30	12G
0005433533286	13487	31	12F
0005435766013	13487	32	12H
0005434265360	13487	33	13A
0005432194545	13487	34	13D
0005435462736	13487	35	13B
0005434265347	13487	36	13F
0005435462757	13487	37	13E
0005435766218	13487	38	13G
0005435462735	13487	39	14A
0005434265358	13487	40	14D
0005434265352	13487	41	14E
0005435462728	13487	42	14G
0005434831190	13487	43	14F
0005435766028	13487	44	14H
0005435765840	13487	45	15B
0005435765979	13487	46	15A
0005434831192	13487	47	15D
0005434265363	13487	48	15G
0005432535875	13487	49	16B
0005435462726	13487	50	16A
0005435765933	13487	51	15H
0005435462751	13487	52	16E
0005435462740	13487	53	16G
0005435765778	13487	54	16F
0005435766174	13487	55	16H
0005435462747	13487	56	17A
0005433533292	13487	57	17D
0005434265344	13487	58	17B
0005434831188	13487	59	17F
0005435765937	13487	60	17E
0005434265353	13487	61	17G
0005435766017	13487	62	17H
0005434265362	13487	63	18A
0005435765849	13487	64	18E
0005435766217	13487	65	18G
0005435766124	13487	66	18H
0005432535872	13487	67	19B
0005434265343	13487	68	19E
0005435462737	13487	69	19D
0005434265346	13487	70	19F
0005433529265	13487	71	19H
0005435723033	13487	72	20A
0005435766188	13487	73	20D
0005435462760	13487	74	20F
0005434265356	13487	75	20G
0005435462731	13487	76	21A
0005434265348	13487	77	21D
0005435462733	13487	78	21E
0005433533308	13487	79	21F
0005435765726	13487	80	21H
0005434265340	13487	81	21G
0005433529258	13487	82	22D
0005435766098	13487	83	22B
0005435462730	13487	84	22F
0005435766190	13487	85	23A
0005433533291	13487	86	22H
0005435766019	13487	87	23F
0005435617173	13487	88	23E
0005435462741	13487	89	23G
0005435462754	13487	90	23H
0005435462738	13487	91	24B
0005433529257	13487	92	24D
0005435766066	13487	93	24G
0005433533287	13487	94	25D
0005435462724	13487	95	24H
0005435766113	13487	96	25E
0005433529249	13487	97	27A
0005432194544	13487	98	27B
0005435462723	13487	99	27E
0005435462752	13487	100	27F
0005434265339	13487	101	27H
0005435725581	13487	102	27G
0005435766069	13487	103	28A
0005435765998	13487	104	28B
0005435765898	13487	105	28E
0005434265354	13487	106	28F
0005434265345	13487	107	28H
0005435462744	13487	108	29B
0005433529259	13487	109	29A
0005433529268	13487	110	29D
0005435766219	13487	111	29H
0005435765943	13487	112	30B
0005434265337	13487	113	30A
0005435723034	13487	114	30E
0005434265357	13487	115	30F
0005435765841	13487	116	31B
0005435462755	13487	117	31A
0005435462739	13487	118	31E
0005435462743	13487	119	31D
0005433529266	13487	120	31F
0005435462727	13487	121	32A
0005435462753	13487	122	31H
0005434265361	13487	123	32B
0005435462734	13487	124	32E
0005435766182	13487	125	32F
0005433529273	13487	126	32H
0005432535874	13487	127	33A
0005435462725	13487	128	33B
0005435766000	13487	129	33G
0005435766065	13487	130	33H
0005434265341	13487	131	34B
0005435462732	13487	132	34A
0005435462758	13487	133	34E
0005433533298	13487	134	34G
0005433529267	13487	135	35A
0005435766055	13487	136	34H
0005435725569	13487	137	35B
0005435462729	13487	138	35E
0005435462746	13487	139	35H
0005433533293	13487	140	35G
0005435722051	13487	141	36B
0005435462748	13487	142	36D
0005435766018	13487	143	36E
0005434265359	13487	144	36G
0005435765853	13487	145	36H
0005435462749	13487	146	37B
0005433533299	13487	147	37E
0005435765999	13487	148	37D
0005435765944	13487	149	37F
0005435725579	13487	150	37H
0005433529269	13487	151	37G
0005435766021	13487	152	38B
0005435725586	13487	153	38A
0005434265350	13487	154	38D
0005435462742	13487	155	38E
0005435766123	13487	156	38F
0005435766080	13487	157	38H
0005433533307	13487	158	39E
0005435723046	13487	159	39D
0005435462745	13487	160	39F
0005434602889	18728	1	3B
0005434513599	18721	1	1A
0005434513598	18721	2	2B
0005434604890	18721	3	3A
0005434604900	18721	4	3B
0005435904708	18721	5	4A
0005434514986	18721	6	4B
0005434514987	18721	7	5B
0005434513600	18721	8	6A
0005434604903	18721	9	6B
0005434514969	19134	1	1A
0005434514965	19134	2	2A
0005434514970	19134	3	2B
0005434514962	19134	4	4A
0005432632783	4127	1	1A
0005435844310	4127	2	1D
0005435846263	4127	3	1F
0005435844318	4127	4	2A
0005435846234	4127	5	2C
0005432649443	4127	6	2D
0005435846264	4127	7	2F
0005432632788	4127	8	3A
0005432632797	4127	9	3C
0005435846243	4127	10	3D
0005432649444	4127	11	3F
0005435846247	4127	12	4A
0005432632796	4127	13	4C
0005435846255	4127	14	4D
0005435844305	4127	15	4E
0005435846218	4127	16	4F
0005435846241	4127	17	5E
0005435846242	4127	18	5F
0005432632804	4127	19	6C
0005432632791	4127	20	6D
0005432649438	4127	21	7A
0005432632803	4127	22	7C
0005432649449	4127	23	7E
0005432649448	4127	24	7F
0005435844294	4127	25	8A
0005432632801	4127	26	8D
0005435846246	4127	27	8E
0005432632793	4127	28	8F
0005432632789	4127	29	9A
0005432649456	4127	30	9C
0005432632792	4127	31	9D
0005432649455	4127	32	9E
0005432649442	4127	33	9F
0005432632786	4127	34	10C
0005435846259	4127	35	10F
0005432632795	4127	36	11C
0005435846260	4127	37	11E
0005432649446	4127	38	11F
0005432649447	4127	39	12D
0005435846222	4127	40	12F
0005432632794	4127	41	13A
0005432649440	4127	42	13C
0005432632790	4127	43	13D
0005432649454	4127	44	13F
0005435844293	4127	45	14A
0005432649441	4127	46	14C
0005432632785	4127	47	14D
0005435844292	4127	48	14E
0005432632784	4127	49	14F
0005432632787	4127	50	15C
0005435844317	4127	51	15D
0005432632798	4127	52	16D
0005432649450	4127	53	16F
0005432632799	4127	54	17A
0005435846240	4127	55	17D
0005432649452	4127	56	17F
0005432632802	4127	57	18A
0005432649453	4127	58	18C
0005432649451	4127	59	18E
0005432649445	4127	60	18F
0005435844316	4127	61	19A
0005432649439	4127	62	19C
0005432632800	4127	63	19F
0005435846244	4127	64	20C
0005433285406	1842	1	1A
0005433285126	1842	2	1C
0005433285391	1842	3	1D
0005433008541	1842	4	1F
0005433008655	1842	5	2A
0005433285207	1842	6	2C
0005433285317	1842	7	2D
0005433008656	1842	8	2F
0005433285286	1842	9	3A
0005433285293	1842	10	3C
0005433285246	1842	11	3D
0005433285328	1842	12	3F
0005433008658	1842	13	4A
0005433008735	1842	14	4C
0005433008775	1842	15	4D
0005432295901	1842	16	4E
0005433008396	1842	17	4F
0005433285174	1842	18	5A
0005433008595	1842	19	5C
0005433008774	1842	20	5D
0005433008442	1842	21	5E
0005433008616	1842	22	5F
0005433285206	1842	23	6A
0005433008560	1842	24	6C
0005432295900	1842	25	6D
0005433008530	1842	26	6E
0005433285124	1842	27	6F
0005433008615	1842	28	7A
0005433008657	1842	29	7C
0005433285218	1842	30	7D
0005433008750	1842	31	7E
0005433285351	1842	32	7F
0005433008379	1842	33	8A
0005433285347	1842	34	8C
0005433285312	1842	35	8D
0005433008882	1842	36	8E
0005433008883	1842	37	8F
0005433008626	1842	38	9A
0005433008666	1842	39	9C
0005433008316	1842	40	9D
0005433008676	1842	41	9E
0005433008559	1842	42	9F
0005433285407	1842	43	10A
0005433285341	1842	44	10C
0005433008474	1842	45	10D
0005433285242	1842	46	10E
0005433008481	1842	47	10F
0005433008734	1842	48	11A
0005433008495	1842	49	11C
0005433285346	1842	50	11D
0005433285291	1842	51	11E
0005433285390	1842	52	11F
0005433008545	1842	53	12A
0005433285294	1842	54	12C
0005433008745	1842	55	12D
0005433008544	1842	56	12E
0005433285234	1842	57	12F
0005433008683	1842	58	13A
0005433008682	1842	59	13C
0005433008589	1842	60	13D
0005433285321	1842	61	13E
0005433285348	1842	62	13F
0005433008508	1842	63	14A
0005433285352	1842	64	14C
0005433285315	1842	65	14D
0005433285240	1842	66	14E
0005433008482	1842	67	14F
0005433285292	1842	68	15A
0005433008555	1842	69	15C
0005433285327	1842	70	15D
0005433285123	1842	71	15E
0005433008685	1842	72	15F
0005433285331	1842	73	16A
0005433285125	1842	74	16C
0005433008776	1842	75	16D
0005433285376	1842	76	16E
0005433008496	1842	77	16F
0005433285345	1842	78	17A
0005433008501	1842	79	17C
0005433008727	1842	80	17D
0005433285214	1842	81	17E
0005433008713	1842	82	17F
0005433008550	1842	83	18A
0005433285247	1842	84	18C
0005433285217	1842	85	18D
0005433008538	1842	86	18E
0005433008746	1842	87	18F
0005433008502	1842	88	19A
0005433285349	1842	89	19C
0005433008536	1842	90	19D
0005432295902	1842	91	19E
0005433285222	1842	92	19F
0005433008623	1842	93	20A
0005433285324	1842	94	20C
0005433285316	1842	95	20D
0005433008580	1842	96	20E
0005433008575	1842	97	20F
0005433008958	22553	1	1C
0005433285548	22553	2	1D
0005433008956	22553	3	1F
0005433285525	22553	4	2A
0005433008979	22553	5	2C
0005433008972	22553	6	2D
0005433285543	22553	7	2F
0005433008944	22553	8	3A
0005433285530	22553	9	3C
0005433008975	22553	10	3D
0005433008965	22553	11	3F
0005433285527	22553	12	4A
0005433285542	22553	13	4C
0005433008949	22553	14	4D
0005433008968	22553	15	4E
0005433008953	22553	16	5A
0005433810528	22553	17	5C
0005433285528	22553	18	5D
0005433285545	22553	19	5E
0005433285540	22553	20	5F
0005433285541	22553	21	6A
0005433285546	22553	22	6C
0005433008980	22553	23	6D
0005433008971	22553	24	6E
0005433285538	22553	25	6F
0005433285535	22553	26	7A
0005433008976	22553	27	7C
0005433008967	22553	28	7D
0005433008945	22553	29	7E
0005433285519	22553	30	8A
0005433008970	22553	31	8C
0005433810523	22553	32	8D
0005433008962	22553	33	8E
0005433285549	22553	34	8F
0005433285521	22553	35	9A
0005433008950	22553	36	9C
0005433008981	22553	37	9D
0005433008964	22553	38	9E
0005433008939	22553	39	10A
0005433285544	22553	40	10D
0005433008938	22553	41	10E
0005433285539	22553	42	10F
0005433285532	22553	43	11C
0005433285536	22553	44	11D
0005433008969	22553	45	11F
0005433285537	22553	46	12C
0005433008946	22553	47	12D
0005433008955	22553	48	12E
0005433008942	22553	49	12F
0005433008973	22553	50	13A
0005433285518	22553	51	13C
0005433008941	22553	52	13D
0005433285523	22553	53	13F
0005433008947	22553	54	14A
0005433008951	22553	55	14C
0005433008960	22553	56	14E
0005433008943	22553	57	15A
0005433008952	22553	58	15C
0005433008966	22553	59	15D
0005433008940	22553	60	15E
0005433810527	22553	61	15F
0005433008954	22553	62	16A
0005433285526	22553	63	16D
0005433285550	22553	64	16F
0005433285533	22553	65	17C
0005433285534	22553	66	17D
0005433008961	22553	67	17E
0005433285524	22553	68	17F
0005433008963	22553	69	18A
0005433008977	22553	70	18C
0005433008959	22553	71	18D
0005433285547	22553	72	18E
0005433008948	22553	73	18F
0005433008957	22553	74	19A
0005433810522	22553	75	19C
0005433285522	22553	76	19D
0005433285529	22553	77	19E
0005433008974	22553	78	19F
0005433285520	22553	79	20C
0005433008978	22553	80	20E
0005433285531	22553	81	20F
0005433815424	5551	1	1C
0005434173487	5551	2	1A
0005433847203	5551	3	2C
0005433847186	5551	4	2A
0005435282542	5551	5	1F
0005433847202	5551	6	2D
0005435282468	5551	7	2F
0005433847170	5551	8	3D
0005433847201	5551	9	3C
0005435282526	5551	10	4C
0005433847191	5551	11	4A
0005433847215	5551	12	4F
0005433847211	5551	13	4D
0005433847182	5551	14	5C
0005433847204	5551	15	5F
0005435282541	5551	16	5D
0005433847189	5551	17	6B
0005433847167	5551	18	6A
0005433847193	5551	19	6D
0005433847192	5551	20	6C
0005435282550	5551	21	6E
0005433847160	5551	22	7A
0005433847195	5551	23	6F
0005433847205	5551	24	7C
0005433847199	5551	25	7B
0005433847158	5551	26	7E
0005433847166	5551	27	7D
0005433847162	5551	28	8A
0005432081564	5551	29	7F
0005433847206	5551	30	8C
0005432081561	5551	31	8B
0005434173497	5551	32	8D
0005435282563	5551	33	8F
0005433847198	5551	34	8E
0005432081563	5551	35	9B
0005432081566	5551	36	9A
0005435282558	5551	37	9D
0005433847165	5551	38	9C
0005433847208	5551	39	9F
0005435282459	5551	40	9E
0005435282405	5551	41	10A
0005433847163	5551	42	10C
0005433847180	5551	43	10E
0005433847174	5551	44	10D
0005433847187	5551	45	10F
0005435282559	5551	46	11C
0005435282460	5551	47	11B
0005435282450	5551	48	11A
0005433847200	5551	49	11D
0005433847188	5551	50	11F
0005433847209	5551	51	11E
0005434173512	5551	52	12A
0005435282350	5551	53	12D
0005433847197	5551	54	12C
0005434173499	5551	55	12F
0005433847171	5551	56	12E
0005433847175	5551	57	13A
0005434173486	5551	58	13C
0005433847217	5551	59	13B
0005433847168	5551	60	13E
0005433847207	5551	61	13D
0005433847216	5551	62	14A
0005435282557	5551	63	13F
0005432081562	5551	64	14B
0005433847181	5551	65	14E
0005433815421	5551	66	14D
0005433815422	5551	67	14C
0005432081565	5551	68	14F
0005433847177	5551	69	15B
0005433847178	5551	70	15A
0005435282496	5551	71	15D
0005433847179	5551	72	15C
0005435282533	5551	73	15E
0005433847212	5551	74	16A
0005433847214	5551	75	15F
0005433847185	5551	76	16C
0005433847194	5551	77	16B
0005433847169	5551	78	16E
0005435282466	5551	79	16D
0005435282471	5551	80	17A
0005435282470	5551	81	17B
0005433847157	5551	82	17D
0005433847183	5551	83	17C
0005433847173	5551	84	17F
0005433847161	5551	85	17E
0005435282551	5551	86	18B
0005434173517	5551	87	18A
0005433847184	5551	88	18C
0005434173496	5551	89	18E
0005433847213	5551	90	18D
0005435282404	5551	91	19A
0005433815423	5551	92	18F
0005433847159	5551	93	19C
0005433847210	5551	94	19B
0005433847164	5551	95	19E
0005433847196	5551	96	20A
0005433847190	5551	97	19F
0005432081560	5551	98	20B
0005433847172	5551	99	20D
0005435282497	5551	100	20C
0005433847176	5551	101	20F
0005435282532	5551	102	20E
0005435282467	5551	103	21A
0005434173522	5551	104	21C
0005435282607	5551	105	21B
0005435282560	5551	106	21F
0005433815420	5551	107	21E
0005434173523	5551	108	21D
0005433846457	13876	1	1C
0005433846766	13876	2	1D
0005435282725	13876	3	1F
0005435282712	13876	4	2D
0005433846732	13876	5	3C
0005433846675	13876	6	2F
0005433846615	13876	7	3D
0005433846949	13876	8	3F
0005435282716	13876	9	4D
0005435282724	13876	10	5A
0005433846528	13876	11	4F
0005433846640	13876	12	5F
0005433846920	13876	13	5D
0005435282730	13876	14	6B
0005433846682	13876	15	6A
0005434173552	13876	16	6D
0005433846674	13876	17	6C
0005433846699	13876	18	6E
0005433846999	13876	19	7B
0005435282720	13876	20	7A
0005433846756	13876	21	6F
0005433815367	13876	22	7C
0005433846652	13876	23	7D
0005435282722	13876	24	7F
0005433846603	13876	25	8B
0005432003727	13876	26	8C
0005435282711	13876	27	8F
0005433846843	13876	28	9B
0005432003726	13876	29	9A
0005433846620	13876	30	9C
0005435282729	13876	31	9E
0005433846735	13876	32	9D
0005433846664	13876	33	10A
0005433846629	13876	34	9F
0005433846811	13876	35	10C
0005433846702	13876	36	10B
0005435282717	13876	37	10D
0005433846876	13876	38	10F
0005435282704	13876	39	10E
0005435282721	13876	40	11B
0005433846812	13876	41	11A
0005433846942	13876	42	11D
0005433846697	13876	43	11C
0005433846493	13876	44	11F
0005434173553	13876	45	11E
0005433846875	13876	46	12B
0005433846673	13876	47	12A
0005433815374	13876	48	12C
0005435282707	13876	49	12E
0005433846968	13876	50	12D
0005433846998	13876	51	12F
0005435282719	13876	52	13C
0005433846606	13876	53	13D
0005433815383	13876	54	14A
0005433846706	13876	55	13F
0005433846802	13876	56	14C
0005435282718	13876	57	14B
0005433846637	13876	58	14F
0005435282731	13876	59	15C
0005435282714	13876	60	15B
0005433846874	13876	61	15E
0005433846659	13876	62	15D
0005433846730	13876	63	16A
0005433846522	13876	64	16C
0005433846696	13876	65	16F
0005433846660	13876	66	16E
0005434173554	13876	67	17B
0005435282708	13876	68	17A
0005433846722	13876	69	17D
0005433846705	13876	70	17E
0005435282727	13876	71	18A
0005433846592	13876	72	18D
0005433846700	13876	73	18B
0005435282723	13876	74	18E
0005433846527	13876	75	19A
0005433846596	13876	76	18F
0005435282713	13876	77	19C
0005435282706	13876	78	19B
0005435282710	13876	79	19E
0005435282715	13876	80	19D
0005433846639	13876	81	19F
0005433846458	13876	82	20B
0005433846688	13876	83	20A
0005435282726	13876	84	20C
0005435282703	13876	85	20F
0005435282728	13876	86	20E
0005435282705	13876	87	20D
0005433815378	13876	88	21B
0005433846943	13876	89	21A
0005433815379	13876	90	21C
0005433846523	13876	91	21E
0005435282709	13876	92	21F
0005434620761	7834	1	1A
0005434620752	7834	2	1B
0005434620751	7834	3	1C
0005435332329	7834	4	1D
0005435332361	7834	5	2A
0005435332381	7834	6	2B
0005435332347	7834	7	2C
0005434620755	7834	8	2D
0005434620748	7834	9	3A
0005435332340	7834	10	3B
0005435332351	7834	11	3C
0005434620763	7834	12	3D
0005434620758	7834	13	4A
0005434620762	7834	14	4C
0005434620756	7834	15	4D
0005434620765	7834	16	5A
0005432112533	7834	17	5C
0005434620750	7834	18	5D
0005435332336	7834	19	6A
0005435332328	7834	20	6D
0005434620754	7834	21	7A
0005434620760	7834	22	7C
0005434620768	7834	23	7D
0005435332382	7834	24	18A
0005434620766	7834	25	18B
0005434620767	7834	26	18C
0005434620757	7834	27	18D
0005434620753	7834	28	19A
0005435332341	7834	29	19B
0005435332335	7834	30	19C
0005435332360	7834	31	19D
0005435332354	7834	32	20A
0005434620764	7834	33	20B
0005432112534	7834	34	20D
0005434620749	7834	35	21B
0005435332309	7834	36	21C
0005435332310	7834	37	22A
0005434620759	7834	38	22D
0005435332364	7834	39	23A
0005435332363	7834	40	23B
0005435332418	32942	1	1A
0005434620594	32942	2	1B
0005435332419	32942	3	1D
0005435332420	32942	4	2A
0005434620568	32942	5	2B
0005435332421	32942	6	3A
0005434620567	32942	7	3B
0005435332416	32942	8	3C
0005434620681	32942	9	3D
0005434620622	32942	10	4B
0005435332417	32942	11	4C
0005435332415	32942	12	5A
0005434620612	32942	13	5B
0005434620597	32942	14	5C
0005434620525	32942	15	5D
0005435332412	32942	16	6D
0005434620627	32942	17	6C
0005434620682	32942	18	7A
0005434620611	32942	19	7B
0005434620534	32942	20	7D
0005435332414	32942	21	18A
0005434620572	32942	22	18D
0005435332423	32942	23	19A
0005434620623	32942	24	19B
0005434620565	32942	25	19D
0005434620598	32942	26	20A
0005434620558	32942	27	20B
0005434620533	32942	28	20C
0005434620532	32942	29	20D
0005435332422	32942	30	21A
0005435332413	32942	31	21C
0005434620596	32942	32	21D
0005434620524	32942	33	22B
0005434620535	32942	34	22C
0005434620593	32942	35	22D
0005434620646	32942	36	23A
0005435785617	4289	1	1A
0005435785646	4289	2	1F
0005435785618	4289	3	2F
0005435785631	4289	4	3A
0005435785622	4289	5	3D
0005434994100	4289	6	4D
0005435937388	4289	7	5A
0005435785634	4289	8	5C
0005435785648	4289	9	5D
0005435785628	4289	10	5F
0005432190658	4289	11	6A
0005435785632	4289	12	6C
0005435937387	4289	13	6D
0005435785638	4289	14	6E
0005435785616	4289	15	6F
0005435785630	4289	16	7C
0005435785627	4289	17	7D
0005435785620	4289	18	7E
0005435785623	4289	19	7F
0005435785625	4289	20	8D
0005435785633	4289	21	8E
0005435785642	4289	22	9C
0005435785615	4289	23	9D
0005434994096	4289	24	9F
0005435937379	4289	25	10A
0005434994104	4289	26	10C
0005435937378	4289	27	10F
0005435785626	4289	28	11C
0005434994098	4289	29	11E
0005435785645	4289	30	12C
0005434994102	4289	31	12D
0005434994103	4289	32	12E
0005435785644	4289	33	12F
0005435785641	4289	34	13C
0005435785629	4289	35	13E
0005435785635	4289	36	13F
0005432190660	4289	37	14C
0005434994097	4289	38	14D
0005435785636	4289	39	14F
0005435785621	4289	40	15D
0005432190661	4289	41	15F
0005435785647	4289	42	16A
0005435918679	4289	43	16C
0005435785637	4289	44	16D
0005435785619	4289	45	16F
0005434994101	4289	46	17C
0005435785614	4289	47	17F
0005432190659	4289	48	18D
0005435785624	4289	49	18E
0005435937368	4289	50	18F
0005435785639	4289	51	19A
0005435785643	4289	52	19C
0005435937375	4289	53	19E
0005435785640	4289	54	20A
0005434994099	4289	55	20E
0005435787371	4289	56	20F
0005434993968	27332	1	1A
0005435785130	27332	2	1C
0005435785296	27332	3	2A
0005435785251	27332	4	2C
0005435785287	27332	5	3A
0005435918693	27332	6	4C
0005435785309	27332	7	4D
0005434994004	27332	8	4E
0005434994043	27332	9	4F
0005435785294	27332	10	5A
0005435785289	27332	11	5F
0005435785283	27332	12	6A
0005435785282	27332	13	6C
0005435787347	27332	14	6E
0005435785203	27332	15	7C
0005434993999	27332	16	7D
0005435918695	27332	17	7E
0005435785301	27332	18	8D
0005435785290	27332	19	8F
0005434994027	27332	20	9A
0005434994019	27332	21	9C
0005434994023	27332	22	9D
0005435785260	27332	23	9E
0005435785181	27332	24	10A
0005435785150	27332	25	10C
0005435937411	27332	26	10E
0005435918692	27332	27	10F
0005435785204	27332	28	11D
0005434994028	27332	29	11F
0005434994005	27332	30	12A
0005435785070	27332	31	12F
0005435918694	27332	32	13C
0005435785375	27332	33	14A
0005435937413	27332	34	14C
0005435785295	27332	35	14D
0005435785199	27332	36	14E
0005435785268	27332	37	15C
0005434993998	27332	38	15D
0005435937415	27332	39	15E
0005435785286	27332	40	16C
0005432195708	27332	41	16E
0005435937412	27332	42	16F
0005435937414	27332	43	17A
0005435785149	27332	44	17E
0005435787348	27332	45	17F
0005435785242	27332	46	18D
0005435785298	27332	47	18E
0005435785293	27332	48	18F
0005432195709	27332	49	19A
0005435785224	27332	50	19E
0005435937410	27332	51	19F
0005435785261	27332	52	20A
0005435785337	27332	53	20C
0005435918691	27332	54	20F
0005432146214	19896	1	3A
0005432568098	4696	1	1A
0005434082108	4696	2	1B
0005432571351	4696	3	1F
0005432460244	4696	4	1C
0005432186898	4696	5	1G
0005432460247	4696	6	1H
0005432568099	4696	7	2F
0005432170438	4696	8	2C
0005432170439	4696	9	2G
0005432170440	4696	10	2H
0005432460288	4696	11	3B
0005432571352	4696	12	3A
0005432568107	4696	13	3F
0005432460276	4696	14	3G
0005432460272	4696	15	4A
0005432460238	4696	16	3H
0005432568140	4696	17	4C
0005432460284	4696	18	4G
0005432568142	4696	19	4H
0005432460289	4696	20	5A
0005432568127	4696	21	5F
0005432460278	4696	22	5C
0005432170443	4696	23	5B
0005432568094	4696	24	5H
0005432460281	4696	25	9A
0005434082098	4696	26	9G
0005432460291	4696	27	11A
0005432460287	4696	28	9H
0005434082104	4696	29	11D
0005432186897	4696	30	11F
0005433452756	4696	31	11G
0005432460255	4696	32	12B
0005432460266	4696	33	12E
0005433451636	4696	34	12F
0005432568103	4696	35	13A
0005432568101	4696	36	12H
0005432568104	4696	37	12G
0005433452755	4696	38	13B
0005432568130	4696	39	13D
0005432460275	4696	40	13F
0005434559103	4696	41	13E
0005432460283	4696	42	13H
0005432568112	4696	43	13G
0005432568092	4696	44	14B
0005432460268	4696	45	14A
0005432568091	4696	46	14D
0005432460261	4696	47	14F
0005432568137	4696	48	14E
0005434082103	4696	49	14H
0005432170442	4696	50	15A
0005432568118	4696	51	15E
0005432568125	4696	52	15D
0005432568138	4696	53	15F
0005432568139	4696	54	15H
0005432568113	4696	55	15G
0005432460260	4696	56	16D
0005432460282	4696	57	16B
0005432568144	4696	58	16E
0005432460263	4696	59	17A
0005432568145	4696	60	16G
0005432568102	4696	61	17D
0005434082100	4696	62	17F
0005433726124	4696	63	17E
0005432568096	4696	64	17G
0005434082106	4696	65	17H
0005432568141	4696	66	18B
0005434082093	4696	67	18F
0005432568122	4696	68	18E
0005432568143	4696	69	18G
0005432568110	4696	70	19B
0005432568136	4696	71	19A
0005432568148	4696	72	19E
0005432460285	4696	73	19D
0005432460252	4696	74	19F
0005432460239	4696	75	19G
0005434082094	4696	76	20A
0005432460243	4696	77	20B
0005432568149	4696	78	20D
0005432568105	4696	79	20H
0005432568134	4696	80	21A
0005432186901	4696	81	21E
0005432460251	4696	82	21G
0005432568124	4696	83	21F
0005432460250	4696	84	21H
0005432568151	4696	85	22A
0005432170444	4696	86	22F
0005433726122	4696	87	22H
0005432568120	4696	88	23B
0005432568115	4696	89	23A
0005432568093	4696	90	23D
0005434082105	4696	91	23F
0005432460280	4696	92	23G
0005432460270	4696	93	23H
0005432460242	4696	94	24A
0005434082096	4696	95	24D
0005433726123	4696	96	24F
0005432460248	4696	97	25D
0005432568109	4696	98	27A
0005432568121	4696	99	27B
0005434082107	4696	100	27E
0005432460274	4696	101	27D
0005432460290	4696	102	27H
0005432568146	4696	103	27G
0005432568097	4696	104	28A
0005432568117	4696	105	28E
0005432460257	4696	106	29B
0005432568123	4696	107	29A
0005432460279	4696	108	28H
0005432460241	4696	109	29D
0005432460246	4696	110	29E
0005432568116	4696	111	29F
0005432568114	4696	112	29H
0005432460259	4696	113	29G
0005432568132	4696	114	30B
0005432460258	4696	115	30D
0005432460245	4696	116	30F
0005432568100	4696	117	30E
0005432568111	4696	118	30H
0005432460265	4696	119	30G
0005434082101	4696	120	31B
0005432568133	4696	121	31A
0005432460269	4696	122	31E
0005432460273	4696	123	31D
0005434082092	4696	124	31G
0005432170441	4696	125	32A
0005432460277	4696	126	31H
0005432460286	4696	127	32B
0005432568135	4696	128	32H
0005432460249	4696	129	32G
0005432571353	4696	130	33A
0005432186899	4696	131	33B
0005434082099	4696	132	33E
0005432568119	4696	133	33G
0005432170445	4696	134	33F
0005432460264	4696	135	33H
0005432568095	4696	136	34B
0005432460271	4696	137	34A
0005432568106	4696	138	34D
0005432460254	4696	139	34E
0005434082091	4696	140	34H
0005432460253	4696	141	35B
0005432568108	4696	142	35D
0005433452757	4696	143	35F
0005432568090	4696	144	35E
0005432568147	4696	145	35H
0005432568126	4696	146	36B
0005432186900	4696	147	36A
0005432568129	4696	148	36E
0005432460267	4696	149	36H
0005432460240	4696	150	37D
0005434082102	4696	151	37B
0005432568131	4696	152	37E
0005432568150	4696	153	37G
0005434082097	4696	154	37F
0005432460262	4696	155	38A
0005432460256	4696	156	38D
0005432568128	4696	157	38H
0005434559104	4696	158	38G
0005434082095	4696	159	39E
0005434082090	4696	160	39D
0005434559102	4696	161	39F
0005432459949	30565	1	1A
0005432459822	30565	2	1B
0005432459649	30565	3	1F
0005432571331	30565	4	2C
0005432567668	30565	5	2F
0005432567669	30565	6	3A
0005432567651	30565	7	3F
0005432567349	30565	8	3C
0005434081791	30565	9	3H
0005432459987	30565	10	4B
0005432459797	30565	11	4F
0005432567856	30565	12	4G
0005432571310	30565	13	4H
0005434081840	30565	14	5G
0005432567892	30565	15	5F
0005432567493	30565	16	5H
0005432161170	30565	17	9B
0005432567790	30565	18	9G
0005432567702	30565	19	11A
0005432567387	30565	20	9H
0005432567662	30565	21	11B
0005432567866	30565	22	11D
0005432567891	30565	23	11H
0005432459798	30565	24	12A
0005432571332	30565	25	12D
0005432567771	30565	26	12B
0005432459999	30565	27	12E
0005432567637	30565	28	12F
0005434081821	30565	29	13B
0005432567527	30565	30	13D
0005432567598	30565	31	13E
0005432459758	30565	32	13H
0005434081842	30565	33	14E
0005432459789	30565	34	14H
0005432567737	30565	35	14G
0005432459823	30565	36	15A
0005432567491	30565	37	15B
0005432571311	30565	38	15E
0005432567717	30565	39	15D
0005432460037	30565	40	15G
0005432459993	30565	41	15F
0005434081764	30565	42	15H
0005432567770	30565	43	16A
0005433454878	30565	44	16B
0005432460011	30565	45	16D
0005432459877	30565	46	16G
0005432567617	30565	47	16F
0005434081845	30565	48	17A
0005432567628	30565	49	17E
0005432460010	30565	50	17G
0005432213636	30565	51	18A
0005432459849	30565	52	18D
0005432567277	30565	53	18E
0005432460087	30565	54	19A
0005432161169	30565	55	18H
0005432567854	30565	56	19B
0005432460164	30565	57	19E
0005432459948	30565	58	19G
0005434081867	30565	59	19H
0005432213637	30565	60	20D
0005432459887	30565	61	20B
0005432459817	30565	62	20E
0005432459756	30565	63	20F
0005432459700	30565	64	20G
0005432459749	30565	65	21A
0005432567621	30565	66	21F
0005432459796	30565	67	21E
0005432567713	30565	68	21D
0005432459893	30565	69	22B
0005432567750	30565	70	22A
0005432459704	30565	71	22D
0005432459892	30565	72	22E
0005432459767	30565	73	22H
0005432567374	30565	74	22G
0005434081820	30565	75	23D
0005432459768	30565	76	23F
0005432213635	30565	77	23E
0005432460009	30565	78	23G
0005432567711	30565	79	24A
0005432567818	30565	80	24B
0005432567592	30565	81	24E
0005432213634	30565	82	25D
0005432459912	30565	83	24H
0005432567552	30565	84	27A
0005432459876	30565	85	27B
0005432571328	30565	86	27E
0005432567526	30565	87	27F
0005432459879	30565	88	27G
0005432459903	30565	89	28B
0005432460000	30565	90	28D
0005432161171	30565	91	28E
0005432567703	30565	92	28G
0005432459904	30565	93	29A
0005432567939	30565	94	29F
0005432459950	30565	95	29E
0005432459880	30565	96	29D
0005432567436	30565	97	29H
0005432567845	30565	98	29G
0005434081834	30565	99	30B
0005432567871	30565	100	30A
0005432567348	30565	101	30D
0005432459747	30565	102	30F
0005432459773	30565	103	30E
0005432567791	30565	104	30H
0005432459847	30565	105	31B
0005432567701	30565	106	31F
0005432459968	30565	107	31H
0005432567720	30565	108	31G
0005432567736	30565	109	32A
0005432459819	30565	110	32F
0005432459913	30565	111	32H
0005432567538	30565	112	32G
0005434081837	30565	113	33A
0005432567896	30565	114	33B
0005432567718	30565	115	33E
0005432567774	30565	116	33D
0005432567539	30565	117	33H
0005432459918	30565	118	34B
0005432459719	30565	119	34E
0005432567443	30565	120	34F
0005432567373	30565	121	34H
0005432459881	30565	122	35A
0005432459848	30565	123	35D
0005432567819	30565	124	35E
0005432459650	30565	125	35G
0005432567276	30565	126	35F
0005434081843	30565	127	35H
0005432567895	30565	128	36B
0005432567492	30565	129	36A
0005432460038	30565	130	36E
0005432567777	30565	131	37B
0005434081752	30565	132	37E
0005432460028	30565	133	37F
0005432459818	30565	134	37H
0005432567388	30565	135	38D
0005432459829	30565	136	38B
0005432459746	30565	137	38G
0005432459846	30565	138	38F
0005433454877	30565	139	38H
0005432567663	30565	140	39D
0005432459682	30565	141	39E
0005435722073	13646	1	3A
0005435722074	13646	2	4A
0005435722075	13646	3	5A
0005435720130	21204	1	2B
0005432295901	22784	1	1A
0005432295900	22784	2	19D
0005432295902	22784	3	22B
0005433343987	11122	1	1A
0005433343940	11122	2	1C
0005433344022	11122	3	1F
0005433343998	11122	4	1D
0005433343996	11122	5	2A
0005433343926	11122	6	2C
0005433344004	11122	7	2D
0005433343973	11122	8	2F
0005435097275	11122	9	3A
0005433343935	11122	10	3C
0005433343969	11122	11	3F
0005433344017	11122	12	3D
0005433343977	11122	13	4A
0005433343993	11122	14	4B
0005433343986	11122	15	4D
0005433343950	11122	16	4C
0005433343957	11122	17	4E
0005433344014	11122	18	5A
0005433343984	11122	19	5C
0005435380274	11122	20	5B
0005433343951	11122	21	5D
0005435097269	11122	22	5F
0005435097279	11122	23	5E
0005435380292	11122	24	6A
0005433343981	11122	25	6B
0005433343943	11122	26	6C
0005433343974	11122	27	6D
0005433343922	11122	28	6E
0005433343954	11122	29	7A
0005435508304	11122	30	6F
0005433344010	11122	31	7B
0005433343975	11122	32	7C
0005433343923	11122	33	7D
0005435380291	11122	34	7F
0005435097274	11122	35	7E
0005433343937	11122	36	8A
0005435380285	11122	37	8B
0005433344019	11122	38	8C
0005433343965	11122	39	8D
0005433343963	11122	40	8E
0005433343991	11122	41	9A
0005435508318	11122	42	8F
0005435380290	11122	43	9B
0005433343947	11122	44	9D
0005435097268	11122	45	9C
0005435380303	11122	46	9E
0005433344009	11122	47	9F
0005433344015	11122	48	10C
0005433343946	11122	49	10B
0005433344021	11122	50	10D
0005433343953	11122	51	10E
0005433343967	11122	52	11A
0005433343992	11122	53	11B
0005433343958	11122	54	11D
0005433344013	11122	55	11C
0005433343933	11122	56	11F
0005433343999	11122	57	11E
0005433343959	11122	58	12A
0005435380304	11122	59	12B
0005433343997	11122	60	12D
0005433343942	11122	61	12C
0005435097273	11122	62	12E
0005433343941	11122	63	12F
0005433343964	11122	64	13B
0005433343972	11122	65	13A
0005433344012	11122	66	13C
0005435097272	11122	67	13E
0005433343928	11122	68	13D
0005433343978	11122	69	13F
0005433343956	11122	70	14A
0005433343939	11122	71	14B
0005435380272	11122	72	14D
0005433344008	11122	73	14C
0005435508302	11122	74	14E
0005433343985	11122	75	14F
0005433344016	11122	76	15B
0005433343966	11122	77	15A
0005433343945	11122	78	15C
0005433343924	11122	79	15E
0005433344018	11122	80	15D
0005433343994	11122	81	15F
0005433343988	11122	82	16B
0005435380273	11122	83	16A
0005433343927	11122	84	16D
0005433343938	11122	85	16C
0005433343948	11122	86	16E
0005433343931	11122	87	16F
0005433344000	11122	88	17B
0005433343989	11122	89	17A
0005433343971	11122	90	17C
0005433343932	11122	91	17E
0005435097277	11122	92	17D
0005433343979	11122	93	17F
0005433344003	11122	94	18A
0005433343936	11122	95	18B
0005435097271	11122	96	18D
0005433343980	11122	97	18C
0005433344007	11122	98	18E
0005433343968	11122	99	18F
0005433343960	11122	100	19B
0005433343934	11122	101	19A
0005435508306	11122	102	19C
0005433343952	11122	103	19E
0005433343944	11122	104	19D
0005433344005	11122	105	19F
0005433344011	11122	106	20A
0005433343930	11122	107	20C
0005433343961	11122	108	20B
0005433343949	11122	109	20D
0005435097278	11122	110	20E
0005433344023	11122	111	20F
0005433344006	11122	112	21B
0005433343925	11122	113	21A
0005433344020	11122	114	21C
0005433343990	11122	115	21D
0005433343955	11122	116	21E
0005433344002	11122	117	21F
0005433343995	11122	118	22B
0005435097270	11122	119	22A
0005433343929	11122	120	22C
0005433343962	11122	121	22D
0005435097276	11122	122	22F
0005433343976	11122	123	22E
0005433343970	11122	124	23B
0005435380289	11122	125	23A
0005433344001	11122	126	23C
0005433343983	11122	127	23D
0005435508303	11122	128	23F
0005433343982	11122	129	23E
0005432293228	17129	1	1C
0005433342754	17129	2	1A
0005433342751	17129	3	1F
0005433342836	17129	4	1D
0005433343259	17129	5	2A
0005433342966	17129	6	2D
0005435097238	17129	7	2C
0005435097207	17129	8	2F
0005433343031	17129	9	3C
0005433343007	17129	10	3A
0005433342739	17129	11	3D
0005433342847	17129	12	3F
0005433343148	17129	13	4B
0005433342910	17129	14	4A
0005433343325	17129	15	4D
0005433343353	17129	16	4C
0005433342886	17129	17	4E
0005433342764	17129	18	4F
0005433342891	17129	19	5A
0005433343159	17129	20	5C
0005435380330	17129	21	5B
0005433342600	17129	22	5D
0005435545796	17129	23	5F
0005433343252	17129	24	5E
0005433343088	17129	25	6B
0005433343150	17129	26	6A
0005433343473	17129	27	6C
0005433342590	17129	28	6D
0005433343010	17129	29	6E
0005433343086	17129	30	6F
0005435097178	17129	31	7B
0005433342921	17129	32	7A
0005433342923	17129	33	7C
0005435097181	17129	34	7E
0005433342517	17129	35	7D
0005435545792	17129	36	8A
0005433343028	17129	37	7F
0005433342449	17129	38	8B
0005433343067	17129	39	8D
0005435380331	17129	40	8C
0005433342708	17129	41	8F
0005433343251	17129	42	8E
0005433343285	17129	43	9A
0005433343033	17129	44	9C
0005433342676	17129	45	9B
0005433343130	17129	46	9D
0005433343352	17129	47	9E
0005433342832	17129	48	9F
0005433342595	17129	49	10C
0005433342892	17129	50	10B
0005433343112	17129	51	10D
0005433343359	17129	52	11A
0005433342770	17129	53	10E
0005435097206	17129	54	11B
0005433343472	17129	55	11C
0005433342773	17129	56	11E
0005433343080	17129	57	11D
0005433342738	17129	58	11F
0005433342942	17129	59	12B
0005433342953	17129	60	12A
0005435097167	17129	61	12D
0005433342967	17129	62	12C
0005433343284	17129	63	12E
0005432293229	17129	64	12F
0005435097193	17129	65	13B
0005433342468	17129	66	13A
0005435545795	17129	67	13C
0005433343113	17129	68	13D
0005433343011	17129	69	13E
0005435097175	17129	70	13F
0005433343090	17129	71	14B
0005433343008	17129	72	14A
0005433343100	17129	73	14C
0005433343142	17129	74	14D
0005433343094	17129	75	14F
0005435545793	17129	76	14E
0005433342467	17129	77	15A
0005433343287	17129	78	15B
0005433343213	17129	79	15D
0005433343005	17129	80	15C
0005433343263	17129	81	15E
0005433343444	17129	82	16A
0005435097169	17129	83	15F
0005433343143	17129	84	16B
0005433342868	17129	85	16C
0005433342763	17129	86	16D
0005435097174	17129	87	16F
0005433343147	17129	88	16E
0005433343087	17129	89	17A
0005433343029	17129	90	17B
0005433342837	17129	91	17C
0005435097168	17129	92	17D
0005433343139	17129	93	17F
0005433343149	17129	94	17E
0005435097182	17129	95	18A
0005433343069	17129	96	18C
0005433342914	17129	97	18B
0005433343081	17129	98	18D
0005433342642	17129	99	18F
0005433343051	17129	100	18E
0005433342972	17129	101	19B
0005435097254	17129	102	19A
0005433343151	17129	103	19C
0005435380328	17129	104	19D
0005433343161	17129	105	19E
0005433342730	17129	106	19F
0005433343092	17129	107	20A
0005433342731	17129	108	20B
0005433343089	17129	109	20D
0005433343032	17129	110	20C
0005435097221	17129	111	20E
0005433342762	17129	112	20F
0005433343027	17129	113	21B
0005435380333	17129	114	21A
0005433343101	17129	115	21C
0005435097192	17129	116	21D
0005433342965	17129	117	21F
0005433343312	17129	118	21E
0005433343136	17129	119	22A
0005435380332	17129	120	22C
0005433342846	17129	121	22B
0005433343155	17129	122	22E
0005433342865	17129	123	22D
0005435545794	17129	124	23A
0005433342878	17129	125	22F
0005435097222	17129	126	23B
0005433342971	17129	127	23C
0005433343311	17129	128	23D
0005435380329	17129	129	23F
0005433343117	17129	130	23E
0005433507340	9078	1	1C
0005433507323	9078	2	1D
0005433507327	9078	3	1F
0005433481233	9078	4	3A
0005432919795	9078	5	4A
0005433507338	9078	6	6C
0005434158977	9078	7	6D
0005434158966	9078	8	7A
0005433507329	9078	9	7C
0005433481232	9078	10	7E
0005433507334	9078	11	8D
0005433507324	9078	12	8F
0005433507332	9078	13	9C
0005433481228	9078	14	9E
0005432919907	9078	15	9F
0005432919839	9078	16	10A
0005433507337	9078	17	10C
0005432919870	9078	18	10E
0005433507339	9078	19	10F
0005433481227	9078	20	11A
0005433481226	9078	21	11D
0005432919841	9078	22	11E
0005433507322	9078	23	12F
0005432919888	9078	24	13C
0005432919747	9078	25	13D
0005433481229	9078	26	13F
0005433507326	9078	27	14D
0005432919746	9078	28	14C
0005433507333	9078	29	15A
0005432919872	9078	30	15D
0005433507331	9078	31	15E
0005433507330	9078	32	15F
0005432919951	9078	33	16C
0005433507335	9078	34	16D
0005432919845	9078	35	16E
0005434158976	9078	36	17A
0005433507328	9078	37	17E
0005433507336	9078	38	18A
0005433481231	9078	39	18E
0005432919846	9078	40	18F
0005432919906	9078	41	19A
0005432919838	9078	42	19C
0005432919825	9078	43	19E
0005433481230	9078	44	20C
0005432919837	9078	45	20D
0005433507325	9078	46	20E
0005432920053	20463	1	1D
0005434158995	20463	2	2A
0005432920057	20463	3	2D
0005432920047	20463	4	3C
0005433507186	20463	5	3D
0005432920039	20463	6	4D
0005432920054	20463	7	4F
0005433507166	20463	8	5C
0005432920045	20463	9	7D
0005432920049	20463	10	8A
0005433507216	20463	11	8F
0005433481200	20463	12	9A
0005433507149	20463	13	9E
0005433481178	20463	14	10A
0005432920038	20463	15	10C
0005433481199	20463	16	10D
0005432920052	20463	17	10F
0005433507174	20463	18	11C
0005432920044	20463	19	11D
0005433481175	20463	20	11F
0005432920058	20463	21	12C
0005432920043	20463	22	13A
0005433507182	20463	23	12F
0005433481165	20463	24	13C
0005432920042	20463	25	13D
0005434158997	20463	26	13E
0005433481135	20463	27	14C
0005434158994	20463	28	14F
0005432920056	20463	29	15C
0005433481174	20463	30	15D
0005433481157	20463	31	15E
0005432920050	20463	32	16A
0005432920046	20463	33	16C
0005432920048	20463	34	16D
0005433507212	20463	35	16E
0005432920051	20463	36	16F
0005432920041	20463	37	17E
0005433507133	20463	38	17F
0005433507203	20463	39	18A
0005434158996	20463	40	18C
0005433481177	20463	41	18D
0005433481136	20463	42	19C
0005432920040	20463	43	19D
0005432920055	20463	44	20C
0005433507183	20463	45	20E
0005433507215	20463	46	20F
0005432394135	10231	1	1A
0005432394136	10231	2	1B
0005432394134	10231	3	2A
0005432396274	10231	4	2B
0005432396272	10231	5	3A
0005432394131	10231	6	4B
0005432394133	10231	7	5A
0005432394132	10231	8	5B
0005432396273	10231	9	6A
0005432396271	10231	10	6B
0005432400119	18348	1	1A
0005432400128	18348	2	1B
0005432396256	18348	3	2A
0005432396228	18348	4	2B
0005432400130	18348	5	3A
0005432400124	18348	6	4A
0005432400129	18348	7	3B
0005432400113	18348	8	5A
0005432396244	18348	9	5B
0005432400125	18348	10	6A
0005432400116	18348	11	6B
0005435126241	11015	1	1C
0005435626158	11015	2	1D
0005435126393	11015	3	1F
0005435626071	11015	4	2A
0005435126246	11015	5	2C
0005435126370	11015	6	2D
0005435626122	11015	7	3A
0005435556692	11015	8	2F
0005435126213	11015	9	3C
0005434928322	11015	10	3F
0005435126250	11015	11	4A
0005434411814	11015	12	4C
0005435126278	11015	13	4D
0005435126369	11015	14	4E
0005435126232	11015	15	5A
0005435126339	11015	16	5C
0005435126266	11015	17	5D
0005435126245	11015	18	5E
0005434411812	11015	19	5F
0005435554189	11015	20	6A
0005435626157	11015	21	6D
0005435126214	11015	22	6E
0005435126469	11015	23	6F
0005435126267	11015	24	7A
0005435126330	11015	25	7C
0005435554196	11015	26	7D
0005435126231	11015	27	7E
0005435126414	11015	28	7F
0005435626132	11015	29	8A
0005435126168	11015	30	8D
0005435126294	11015	31	9A
0005435554198	11015	32	9C
0005435626140	11015	33	9D
0005435626131	11015	34	9E
0005435126242	11015	35	9F
0005435626077	11015	36	10A
0005435626120	11015	37	10D
0005435126415	11015	38	10E
0005435554197	11015	39	10F
0005435126437	11015	40	11C
0005435126212	11015	41	11D
0005435126265	11015	42	11E
0005435126247	11015	43	11F
0005435126277	11015	44	12A
0005435126188	11015	45	12C
0005435126096	11015	46	12D
0005435626138	11015	47	12F
0005434928324	11015	48	13A
0005434411813	11015	49	13C
0005435126327	11015	50	13D
0005434411817	11015	51	13E
0005435126307	11015	52	13F
0005435626134	11015	53	14A
0005435126244	11015	54	14C
0005435126223	11015	55	14D
0005434411816	11015	56	14E
0005435626119	11015	57	14F
0005435626076	11015	58	15A
0005435626142	11015	59	15C
0005435126240	11015	60	15D
0005434411815	11015	61	15E
0005435126312	11015	62	15F
0005435126255	11015	63	16A
0005435126313	11015	64	16C
0005435126434	11015	65	16D
0005435626135	11015	66	16E
0005435126290	11015	67	16F
0005435126517	11015	68	17A
0005435126379	11015	69	17C
0005435626141	11015	70	17D
0005435126189	11015	71	17E
0005435126431	11015	72	17F
0005435126215	11015	73	18A
0005435126097	11015	74	18C
0005435126151	11015	75	18E
0005435626139	11015	76	18F
0005435126420	11015	77	19A
0005435126341	11015	78	19C
0005435126254	11015	79	19D
0005434928323	11015	80	19E
0005435626078	11015	81	19F
0005435126249	11015	82	20A
0005435126360	11015	83	20C
0005435126293	11015	84	20D
0005435126292	11015	85	20E
0005435626121	11015	86	20F
0005435556712	14668	1	1C
0005434928285	14668	2	1D
0005435626328	14668	3	1F
0005435126720	14668	4	2A
0005435126722	14668	5	2C
0005435126701	14668	6	2D
0005435626317	14668	7	2F
0005435626337	14668	8	3A
0005435126693	14668	9	3C
0005435626322	14668	10	3D
0005435626327	14668	11	4A
0005435626318	14668	12	4C
0005435626320	14668	13	4D
0005435626329	14668	14	4E
0005435626334	14668	15	4F
0005435626333	14668	16	5A
0005435126707	14668	17	5D
0005434411760	14668	18	5C
0005435554226	14668	19	5E
0005435126688	14668	20	5F
0005435126726	14668	21	6C
0005435126702	14668	22	6D
0005435126725	14668	23	6E
0005434928313	14668	24	6F
0005435626339	14668	25	7A
0005435126717	14668	26	7C
0005435626332	14668	27	7D
0005435126713	14668	28	7E
0005435626316	14668	29	7F
0005435554223	14668	30	8A
0005435126705	14668	31	8C
0005435126698	14668	32	8D
0005435126714	14668	33	8E
0005435554224	14668	34	8F
0005435626321	14668	35	9A
0005435126704	14668	36	9C
0005434411787	14668	37	9D
0005435626338	14668	38	9E
0005435126712	14668	39	9F
0005435126731	14668	40	10A
0005435626325	14668	41	10C
0005435126724	14668	42	10D
0005435126697	14668	43	10E
0005435126710	14668	44	11A
0005435626324	14668	45	11C
0005435626326	14668	46	11D
0005435556713	14668	47	11E
0005435126729	14668	48	11F
0005435626330	14668	49	12C
0005435126699	14668	50	12A
0005435126696	14668	51	12D
0005435556714	14668	52	12E
0005435554225	14668	53	13C
0005435626323	14668	54	13D
0005435126711	14668	55	13F
0005435126721	14668	56	14A
0005435126709	14668	57	14C
0005435126715	14668	58	14D
0005435126723	14668	59	14E
0005435126706	14668	60	15A
0005435126718	14668	61	15C
0005435126728	14668	62	15E
0005435126703	14668	63	15F
0005435126689	14668	64	16C
0005435626331	14668	65	17A
0005435126727	14668	66	17C
0005435126708	14668	67	17E
0005434928306	14668	68	17F
0005435126694	14668	69	18A
0005435126691	14668	70	18C
0005435626335	14668	71	18D
0005435126692	14668	72	18E
0005435126719	14668	73	18F
0005435626319	14668	74	19A
0005434411761	14668	75	19C
0005435126716	14668	76	19E
0005435126730	14668	77	19F
0005435126690	14668	78	20A
0005435126695	14668	79	20C
0005435554222	14668	80	20D
0005435126700	14668	81	20E
0005435626336	14668	82	20F
0005432400158	7099	1	1D
0005435178495	7099	2	4A
0005435715610	7099	3	4C
0005435715615	7099	4	5C
0005432398230	7099	5	5D
0005435443284	7099	6	5E
0005435715602	7099	7	6F
0005435715612	7099	8	7F
0005435715608	7099	9	8A
0005435219203	7099	10	9C
0005435443351	7099	11	9D
0005435443287	7099	12	10D
0005435715605	7099	13	10E
0005435715607	7099	14	10F
0005432400157	7099	15	11A
0005435715611	7099	16	11C
0005435443269	7099	17	11E
0005435219187	7099	18	12E
0005435715616	7099	19	13A
0005435715604	7099	20	13C
0005435715603	7099	21	13E
0005435443276	7099	22	14A
0005435715601	7099	23	14D
0005435715609	7099	24	14F
0005432398228	7099	25	15A
0005435178494	7099	26	15C
0005432398229	7099	27	15D
0005435715613	7099	28	16A
0005435715614	7099	29	16D
0005435219202	7099	30	16E
0005435443324	7099	31	16F
0005435178501	7099	32	17D
0005432400156	7099	33	18C
0005435715606	7099	34	18D
0005435443314	7099	35	19E
0005432398227	7099	36	20A
0005435217728	27066	1	1A
0005435216606	27066	2	2D
0005435216603	27066	3	2F
0005435178507	27066	4	3D
0005435217725	27066	5	3F
0005432398190	27066	6	4A
0005435715458	27066	7	5C
0005435443394	27066	8	5E
0005435178999	27066	9	6A
0005432394107	27066	10	6C
0005435216602	27066	11	6F
0005435715429	27066	12	7A
0005435178506	27066	13	7C
0005435216605	27066	14	7D
0005435443391	27066	15	8C
0005435216601	27066	16	8E
0005435715453	27066	17	9A
0005435216604	27066	18	9C
0005432394077	27066	19	9D
0005435178998	27066	20	10C
0005435443387	27066	21	10A
0005435715472	27066	22	10D
0005435218122	27066	23	10E
0005432394108	27066	24	12A
0005432394079	27066	25	12D
0005432394078	27066	26	12E
0005435715494	27066	27	12F
0005435443392	27066	28	13E
0005435443388	27066	29	14C
0005435443386	27066	30	14D
0005435443390	27066	31	14E
0005435217727	27066	32	14F
0005435715427	27066	33	15A
0005435715399	27066	34	15C
0005435216600	27066	35	15D
0005435715426	27066	36	16A
0005435443393	27066	37	16C
0005435443395	27066	38	16F
0005435217730	27066	39	17A
0005435218121	27066	40	17F
0005435443389	27066	41	18C
0005435217724	27066	42	18E
0005435715484	27066	43	19D
0005435217726	27066	44	19E
0005435217729	27066	45	19F
0005435715354	27066	46	20C
0005435715483	27066	47	20E
0005434084970	2757	1	1A
0005433060408	2757	2	2A
0005434084968	2757	3	1B
0005433060416	2757	4	2B
0005434084967	2757	5	4A
0005434084969	2757	6	5A
0005433060417	2757	7	6A
0005434084918	28517	1	1A
0005433060436	28517	2	1B
0005434084941	28517	3	2A
0005434084921	28517	4	2B
0005433060434	28517	5	3B
0005434084920	28517	6	4B
0005434084905	28517	7	5B
0005434084942	28517	8	6A
0005433060435	28517	9	6B
0005433788246	11174	1	1A
0005433788240	11174	2	1B
0005433788236	11174	3	1D
0005435548471	11174	4	2B
0005435548478	11174	5	2C
0005435548492	11174	6	2D
0005433788247	11174	7	3B
0005433788237	11174	8	4B
0005435548472	11174	9	4D
0005435548490	11174	10	5B
0005435548488	11174	11	5C
0005433788241	11174	12	5D
0005435548475	11174	13	6C
0005435548484	11174	14	6D
0005433788245	11174	15	7A
0005433788244	11174	16	7B
0005433788239	11174	17	7D
0005435548459	11174	18	18A
0005433788243	11174	19	18D
0005435548477	11174	20	19B
0005433788248	11174	21	19D
0005433788238	11174	22	21A
0005435548463	11174	23	21C
0005435548493	11174	24	21D
0005435548489	11174	25	22A
0005433788235	11174	26	22B
0005435548473	11174	27	22C
0005435548476	11174	28	22D
0005435548485	11174	29	23A
0005433788242	11174	30	23B
0005433788192	20675	1	1A
0005435548523	20675	2	1B
0005433788191	20675	3	1C
0005433788200	20675	4	1D
0005435548525	20675	5	2A
0005433788196	20675	6	2B
0005435548526	20675	7	2C
0005435548528	20675	8	3A
0005435548532	20675	9	3B
0005433788193	20675	10	3C
0005435548514	20675	11	3D
0005433788186	20675	12	4A
0005435548515	20675	13	4B
0005435548534	20675	14	4C
0005435548531	20675	15	4D
0005435548524	20675	16	5D
0005435548516	20675	17	6A
0005435548518	20675	18	6B
0005433788190	20675	19	6C
0005435548527	20675	20	6D
0005433788188	20675	21	7A
0005435548520	20675	22	7B
0005435548536	20675	23	7C
0005433788202	20675	24	18B
0005433788185	20675	25	18C
0005435548535	20675	26	19A
0005435548529	20675	27	19B
0005433788166	20675	28	19D
0005433788187	20675	29	20A
0005433788203	20675	30	20C
0005435548522	20675	31	20D
0005435548530	20675	32	21A
0005435548519	20675	33	21B
0005435548537	20675	34	21C
0005435548517	20675	35	22B
0005435548533	20675	36	22C
0005435548521	20675	37	22D
0005433788201	20675	38	23B
0005435517902	11411	1	1F
0005435540867	11411	2	2A
0005435541011	11411	3	3C
0005435517905	11411	4	3D
0005435517937	11411	5	3F
0005435541020	11411	6	4A
0005435540968	11411	7	4C
0005435541005	11411	8	4F
0005435541036	11411	9	5C
0005435517791	11411	10	6A
0005435517876	11411	11	6C
0005435540912	11411	12	6F
0005435540926	11411	13	7A
0005435541077	11411	14	7D
0005435541003	11411	15	7E
0005435517790	11411	16	8A
0005435541021	11411	17	9C
0005435541042	11411	18	9D
0005435540979	11411	19	9F
0005435517888	11411	20	10A
0005435517958	11411	21	10E
0005435517885	11411	22	11D
0005435517883	11411	23	11E
0005435541072	11411	24	12A
0005435517884	11411	25	12E
0005435517948	11411	26	12F
0005435517950	11411	27	13A
0005435517926	11411	28	13C
0005435517887	11411	29	13D
0005435517942	11411	30	14C
0005435517927	11411	31	14D
0005435540911	11411	32	14F
0005435517886	11411	33	15A
0005435540994	11411	34	15C
0005435540924	11411	35	15F
0005435541035	11411	36	16A
0005435517872	11411	37	16D
0005435517949	11411	38	17E
0005435540995	11411	39	17F
0005435517855	11411	40	18A
0005435517868	11411	41	18D
0005435540927	11411	42	18E
0005435541102	11411	43	18F
0005435540913	11411	44	19A
0005435541135	11411	45	20A
0005435540925	11411	46	20D
0005435541022	11411	47	20E
0005435529419	22270	1	1A
0005435529421	22270	2	1D
0005432294506	22270	3	2D
0005435529414	22270	4	3F
0005435541154	22270	5	4A
0005435541172	22270	6	4C
0005435541156	22270	7	4E
0005435529415	22270	8	4F
0005435529417	22270	9	5C
0005435529429	22270	10	5D
0005435541165	22270	11	5F
0005435541171	22270	12	6A
0005435541166	22270	13	6C
0005435541173	22270	14	6D
0005432294505	22270	15	7E
0005435529428	22270	16	8A
0005435529413	22270	17	8E
0005435529431	22270	18	8F
0005432294504	22270	19	9E
0005435541167	22270	20	10A
0005435541164	22270	21	10D
0005435529426	22270	22	10E
0005435541157	22270	23	12A
0005435529425	22270	24	12C
0005435541158	22270	25	13E
0005435541160	22270	26	14C
0005435529423	22270	27	14D
0005435529430	22270	28	14E
0005435541175	22270	29	15A
0005435529416	22270	30	15D
0005435541168	22270	31	15E
0005435529424	22270	32	15F
0005435541169	22270	33	16A
0005435541155	22270	34	16C
0005435529411	22270	35	16E
0005435541162	22270	36	16F
0005435529412	22270	37	17A
0005435529427	22270	38	17E
0005435529418	22270	39	18A
0005435541174	22270	40	18D
0005435529420	22270	41	18E
0005435541170	22270	42	18F
0005435541163	22270	43	19A
0005435529422	22270	44	19F
0005435541159	22270	45	20E
0005435541161	22270	46	20F
0005433251562	2303	1	1A
0005433251511	2303	2	1C
0005434907715	2303	3	1D
0005433251480	2303	4	1F
0005434907742	2303	5	2A
0005433251512	2303	6	2C
0005434907707	2303	7	2D
0005433251599	2303	8	2F
0005433400975	2303	9	3A
0005433251496	2303	10	3C
0005433251367	2303	11	3D
0005434907716	2303	12	3F
0005433251593	2303	13	4A
0005433251433	2303	14	4C
0005434907713	2303	15	4D
0005434907735	2303	16	4E
0005434907724	2303	17	4F
0005433400974	2303	18	5A
0005433251389	2303	19	5C
0005434907726	2303	20	5D
0005434907736	2303	21	5E
0005433251418	2303	22	5F
0005434907712	2303	23	6C
0005433251435	2303	24	6D
0005434907718	2303	25	6E
0005433251611	2303	26	6F
0005434907725	2303	27	7A
0005434907720	2303	28	7C
0005433251481	2303	29	7D
0005433251434	2303	30	7E
0005433251553	2303	31	7F
0005433400982	2303	32	8A
0005434907730	2303	33	8C
0005433251338	2303	34	8D
0005433251592	2303	35	8E
0005433251455	2303	36	8F
0005434907708	2303	37	9A
0005434907727	2303	38	9C
0005434907741	2303	39	9D
0005433251456	2303	40	9E
0005433400987	2303	41	9F
0005434907728	2303	42	10A
0005434907744	2303	43	10C
0005434907740	2303	44	10E
0005434907719	2303	45	10F
0005434907723	2303	46	11A
0005433251447	2303	47	11C
0005433400988	2303	48	11E
0005433251510	2303	49	11F
0005433251600	2303	50	12A
0005434907738	2303	51	12C
0005433251488	2303	52	12D
0005433251392	2303	53	12E
0005433251505	2303	54	12F
0005433251548	2303	55	13A
0005433251544	2303	56	13C
0005434907734	2303	57	13D
0005433251514	2303	58	13E
0005433251454	2303	59	13F
0005433400973	2303	60	14C
0005433251428	2303	61	14D
0005433251489	2303	62	14E
0005433251466	2303	63	14F
0005434907743	2303	64	15A
0005433400992	2303	65	15C
0005434907739	2303	66	15D
0005433251594	2303	67	15E
0005433251347	2303	68	15F
0005433251561	2303	69	16A
0005434907733	2303	70	16C
0005433251498	2303	71	16D
0005434907722	2303	72	16E
0005434907714	2303	73	16F
0005434907709	2303	74	17C
0005433251390	2303	75	17D
0005434907711	2303	76	17E
0005434907745	2303	77	17F
0005433251453	2303	78	18A
0005434907737	2303	79	18C
0005434907729	2303	80	18D
0005434907721	2303	81	18E
0005433251420	2303	82	18F
0005433251346	2303	83	19A
0005433251534	2303	84	19C
0005433251414	2303	85	19D
0005434907717	2303	86	19E
0005434907732	2303	87	19F
0005434907731	2303	88	20A
0005433400993	2303	89	20C
0005434907710	2303	90	20D
0005433251491	2303	91	20E
0005434907203	25629	1	1A
0005434907315	25629	2	1C
0005434907115	25629	3	1D
0005434907033	25629	4	1F
0005433251734	25629	5	2A
0005434907223	25629	6	2C
0005434907036	25629	7	2D
0005434906950	25629	8	2F
0005434907135	25629	9	3A
0005434907237	25629	10	3C
0005433251743	25629	11	3D
0005434907123	25629	12	3F
0005434907057	25629	13	4A
0005433251729	25629	14	4C
0005434907092	25629	15	4D
0005434906929	25629	16	4E
0005434907206	25629	17	4F
0005434907034	25629	18	5C
0005433251727	25629	19	5D
0005434907220	25629	20	5E
0005434907063	25629	21	5F
0005434907150	25629	22	6A
0005434907229	25629	23	6C
0005434907113	25629	24	6D
0005434907195	25629	25	6E
0005433251732	25629	26	6F
0005434907103	25629	27	7A
0005433251741	25629	28	7C
0005434907083	25629	29	7D
0005433251731	25629	30	7E
0005434907168	25629	31	7F
0005434907171	25629	32	8A
0005434907035	25629	33	8D
0005433251736	25629	34	8C
0005434906995	25629	35	8E
0005433251718	25629	36	8F
0005433251744	25629	37	9C
0005433251747	25629	38	9D
0005433401009	25629	39	9E
0005433251721	25629	40	10A
0005434907121	25629	41	10E
0005434907164	25629	42	10F
0005433251726	25629	43	11C
0005434907179	25629	44	11D
0005433251742	25629	45	11E
0005434907238	25629	46	12A
0005434907082	25629	47	12C
0005433251725	25629	48	12D
0005433251738	25629	49	12E
0005434907099	25629	50	12F
0005433251737	25629	51	13A
0005433251723	25629	52	13C
0005433251735	25629	53	13D
0005433251748	25629	54	13E
0005434907151	25629	55	13F
0005434907231	25629	56	14A
0005434907278	25629	57	14C
0005433251739	25629	58	14D
0005433251720	25629	59	14E
0005434907221	25629	60	14F
0005434907064	25629	61	15A
0005434907283	25629	62	15C
0005434907240	25629	63	15D
0005433251724	25629	64	15E
0005434907125	25629	65	15F
0005434906949	25629	66	16C
0005433251722	25629	67	16D
0005433401008	25629	68	16E
0005434907212	25629	69	16F
0005434907183	25629	70	17A
0005433251746	25629	71	17C
0005433251719	25629	72	17D
0005433251728	25629	73	17E
0005434907236	25629	74	17F
0005433251730	25629	75	18A
0005433251745	25629	76	18E
0005434907058	25629	77	18F
0005434907194	25629	78	19A
0005434907133	25629	79	19C
0005433251740	25629	80	19D
0005434907124	25629	81	19E
0005434907163	25629	82	19F
0005434907114	25629	83	20A
0005434907204	25629	84	20C
0005434907112	25629	85	20D
0005433251733	25629	86	20E
0005434907232	25629	87	20F
0005432621150	2548	1	1C
0005432862312	2548	2	2B
0005432621152	2548	3	3C
0005432621160	2548	4	4A
0005432621149	2548	5	4C
0005432862290	2548	6	4D
0005432862324	2548	7	5C
0005432621156	2548	8	6B
0005432621159	2548	9	6C
0005432862325	2548	10	6D
0005432862286	2548	11	7B
0005432621158	2548	12	7C
0005432621155	2548	13	7D
0005432862293	2548	14	18A
0005432621148	2548	15	18B
0005432621153	2548	16	18C
0005432862346	2548	17	19A
0005432862294	2548	18	19D
0005432621161	2548	19	20A
0005432621151	2548	20	20B
0005432862287	2548	21	20C
0005432621157	2548	22	21A
0005432621154	2548	23	22D
0005432621065	28069	1	1A
0005432621047	28069	2	1B
0005432621046	28069	3	1C
0005432621015	28069	4	1D
0005432862365	28069	5	2A
0005432862363	28069	6	2D
0005432621048	28069	7	3C
0005432621058	28069	8	3D
0005432862366	28069	9	4B
0005432621066	28069	10	5A
0005432620974	28069	11	5C
0005432621049	28069	12	5D
0005432621041	28069	13	6A
0005432621024	28069	14	6B
0005432621059	28069	15	6C
0005432621001	28069	16	6D
0005432862367	28069	17	7A
0005432621021	28069	18	7B
0005432621074	28069	19	7C
0005432862369	28069	20	18B
0005432621000	28069	21	19A
0005432862368	28069	22	19C
0005432621044	28069	23	19D
0005432621064	28069	24	20B
0005432621042	28069	25	21B
0005432862364	28069	26	21C
0005432620998	28069	27	21D
0005432621043	28069	28	22A
0005432621025	28069	29	22C
0005432621072	28069	30	22D
0005432620999	28069	31	23B
0005434097470	11799	1	2B
0005434097471	11799	2	6A
0005434097487	13027	1	4B
0005433452757	31020	1	1B
0005433452756	31020	2	2B
0005433452755	31020	3	4A
0005433451636	31020	4	5A
0005433454878	31364	1	2A
0005433454877	31364	2	2B
0005433129273	11978	1	1A
0005434142599	11978	2	1C
0005433134136	11978	3	3D
0005434184668	11978	4	4B
0005434184659	11978	5	4C
0005433134137	11978	6	6A
0005433134135	11978	7	7B
0005434142612	11978	8	20D
0005434142595	11978	9	21B
0005433134132	11978	10	21D
0005433129277	11978	11	22D
0005433134176	29824	1	1A
0005434142641	29824	2	1C
0005433134177	29824	3	1D
0005434183597	29824	4	3A
0005433134173	29824	5	3B
0005433131746	29824	6	3D
0005434183596	29824	7	4A
0005433134174	29824	8	4D
0005434142642	29824	9	5C
0005433134175	29824	10	18B
0005433131744	29824	11	19C
0005433131748	29824	12	20A
0005434184682	29824	13	20B
0005433131743	29824	14	20C
0005433131747	29824	15	21B
0005434142640	29824	16	22C
0005433131745	29824	17	23A
0005435697537	16482	1	1A
0005435697560	16482	2	1B
0005435697558	16482	3	1C
0005435697559	16482	4	1D
0005435697551	16482	5	2A
0005435697540	16482	6	2B
0005435697539	16482	7	2D
0005435697553	16482	8	4A
0005435697543	16482	9	5A
0005435697536	16482	10	5B
0005435697556	16482	11	5D
0005435697534	16482	12	6A
0005435697557	16482	13	6B
0005435697541	16482	14	6C
0005435697535	16482	15	6D
0005435697544	16482	16	7A
0005435697545	16482	17	7C
0005435697554	16482	18	7D
0005435697532	16482	19	18B
0005435697542	16482	20	18C
0005435697552	16482	21	18D
0005435697533	16482	22	19A
0005435697549	16482	23	19B
0005435697547	16482	24	19D
0005435935049	16482	25	20D
0005435697548	16482	26	21B
0005435935030	16482	27	22B
0005435697546	16482	28	22C
0005435697538	16482	29	22D
0005435697555	16482	30	23A
0005435697550	16482	31	23B
0005435697394	24728	1	1A
0005435697443	24728	2	1B
0005435697404	24728	3	1C
0005435697329	24728	4	1D
0005435697349	24728	5	2A
0005435935070	24728	6	2B
0005435697390	24728	7	2C
0005435697362	24728	8	2D
0005435935071	24728	9	3A
0005435935072	24728	10	3B
0005435697363	24728	11	3C
0005435697501	24728	12	3D
0005435697398	24728	13	4A
0005435697257	24728	14	4B
0005435697330	24728	15	5A
0005435697360	24728	16	4D
0005435697361	24728	17	5B
0005435697213	24728	18	6B
0005435697229	24728	19	6C
0005435697442	24728	20	6D
0005435697334	24728	21	7A
0005435697393	24728	22	7C
0005435697500	24728	23	18A
0005435697417	24728	24	18B
0005435697392	24728	25	18C
0005435697323	24728	26	18D
0005435697378	24728	27	19B
0005435697372	24728	28	19C
0005435697383	24728	29	20A
0005435697416	24728	30	20C
0005435697327	24728	31	21D
0005435935069	24728	32	22A
0005435697328	24728	33	22C
0005432968839	18801	1	1A
0005433724839	18801	2	2A
0005432968836	18801	3	1B
0005433724840	18801	4	2B
0005433724837	18801	5	3A
0005432968835	18801	6	3B
0005433724836	18801	7	4A
0005433724838	18801	8	4B
0005432968845	18801	9	5A
0005432968834	18801	10	6A
0005433724841	18801	11	6B
0005432968862	21611	1	1A
0005433724783	21611	2	1B
0005433724785	21611	3	2A
0005432968863	21611	4	2B
0005433724784	21611	5	3B
0005432968861	21611	6	4B
0005432968860	21611	7	4A
0005433724808	21611	8	5B
0005433724802	21611	9	5A
0005433724782	21611	10	6A
0005433724809	21611	11	6B
0005434138825	7337	1	1A
0005434138837	7337	2	1C
0005434138883	7337	3	1D
0005434138823	7337	4	1F
0005434138833	7337	5	2A
0005434138868	7337	6	2C
0005434138874	7337	7	2D
0005434138877	7337	8	3A
0005434138860	7337	9	3C
0005434138831	7337	10	3D
0005434138853	7337	11	3F
0005434138892	7337	12	4A
0005434138838	7337	13	4D
0005434138864	7337	14	4E
0005434138887	7337	15	4F
0005434138850	7337	16	5A
0005434138880	7337	17	5C
0005434138888	7337	18	5D
0005434138824	7337	19	5E
0005434138812	7337	20	5F
0005434138822	7337	21	6A
0005434138862	7337	22	6C
0005434138848	7337	23	6D
0005434138870	7337	24	6E
0005434138819	7337	25	6F
0005434138830	7337	26	7A
0005434138811	7337	27	7C
0005434087552	7337	28	7D
0005434138810	7337	29	7F
0005434138826	7337	30	8A
0005434138867	7337	31	8C
0005434138893	7337	32	8D
0005434138852	7337	33	8E
0005434138820	7337	34	8F
0005434087553	7337	35	9A
0005434138885	7337	36	9C
0005434087556	7337	37	9D
0005434138849	7337	38	9E
0005434138866	7337	39	9F
0005434138845	7337	40	10A
0005434138839	7337	41	10C
0005434138829	7337	42	10D
0005434138832	7337	43	10E
0005434138846	7337	44	10F
0005434138872	7337	45	11A
0005434138854	7337	46	11C
0005434138889	7337	47	11D
0005434138891	7337	48	11E
0005434138882	7337	49	11F
0005434138843	7337	50	12A
0005434087555	7337	51	12C
0005434138835	7337	52	12D
0005434138827	7337	53	12E
0005434138816	7337	54	12F
0005434138807	7337	55	13A
0005434138875	7337	56	13D
0005434138871	7337	57	13E
0005434138856	7337	58	13F
0005434138855	7337	59	14A
0005434138809	7337	60	14C
0005434138884	7337	61	14D
0005434138878	7337	62	14E
0005434138828	7337	63	14F
0005434138842	7337	64	15A
0005434138857	7337	65	15C
0005434138858	7337	66	15D
0005434138813	7337	67	15E
0005434138844	7337	68	15F
0005434138834	7337	69	16A
0005434138881	7337	70	16D
0005434138840	7337	71	16E
0005434138818	7337	72	16F
0005434138876	7337	73	17A
0005434138847	7337	74	17C
0005434138861	7337	75	17D
0005434138841	7337	76	17E
0005434087554	7337	77	17F
0005434138851	7337	78	18A
0005434138869	7337	79	18C
0005434138859	7337	80	18D
0005434138865	7337	81	18E
0005434138873	7337	82	18F
0005434138836	7337	83	19A
0005434138886	7337	84	19C
0005434138863	7337	85	19D
0005434138821	7337	86	19E
0005434138815	7337	87	19F
0005434138879	7337	88	20A
0005434138890	7337	89	20C
0005434138814	7337	90	20D
0005434138808	7337	91	20E
0005434138817	7337	92	20F
0005434138427	28554	1	1C
0005434138065	28554	2	1D
0005434138212	28554	3	1F
0005434137712	28554	4	2A
0005434138205	28554	5	2C
0005434138081	28554	6	2D
0005434138426	28554	7	2F
0005434137796	28554	8	3A
0005434137903	28554	9	3C
0005434138305	28554	10	3D
0005434137962	28554	11	3F
0005434138258	28554	12	4A
0005434137971	28554	13	4C
0005434138216	28554	14	4D
0005434138111	28554	15	4E
0005434138113	28554	16	4F
0005434138208	28554	17	5A
0005434138035	28554	18	5C
0005434138071	28554	19	5D
0005434137867	28554	20	5F
0005434087506	28554	21	6A
0005434137963	28554	22	6C
0005434137954	28554	23	6D
0005434138408	28554	24	6E
0005434137899	28554	25	6F
0005434138450	28554	26	7A
0005434137679	28554	27	7C
0005434138454	28554	28	7D
0005434137902	28554	29	7E
0005434137986	28554	30	7F
0005434138179	28554	31	8A
0005434137855	28554	32	8C
0005434137901	28554	33	8D
0005434138324	28554	34	8E
0005434137976	28554	35	8F
0005434138135	28554	36	9A
0005434138122	28554	37	9C
0005434137295	28554	38	9D
0005434137708	28554	39	9E
0005434138139	28554	40	9F
0005434137900	28554	41	10A
0005434138082	28554	42	10C
0005434138451	28554	43	10D
0005434137904	28554	44	10E
0005434138262	28554	45	10F
0005434137936	28554	46	11A
0005434138095	28554	47	11C
0005434138107	28554	48	11D
0005434138323	28554	49	11E
0005434138034	28554	50	11F
0005434138271	28554	51	12A
0005434137957	28554	52	12C
0005434087522	28554	53	12D
0005434138052	28554	54	12E
0005434137890	28554	55	13A
0005434138157	28554	56	13C
0005434138158	28554	57	13D
0005434138053	28554	58	13E
0005434138245	28554	59	14A
0005434137959	28554	60	14C
0005434137822	28554	61	14E
0005434137797	28554	62	14F
0005434137825	28554	63	15A
0005434137958	28554	64	15C
0005434137711	28554	65	15E
0005434137294	28554	66	16A
0005434087535	28554	67	16C
0005434138244	28554	68	16D
0005434138121	28554	69	16E
0005434138013	28554	70	17A
0005434138028	28554	71	17C
0005434137645	28554	72	17D
0005434138348	28554	73	17E
0005434137977	28554	74	17F
0005434138072	28554	75	18A
0005434138096	28554	76	18C
0005434137997	28554	77	18D
0005434138209	28554	78	18E
0005434138094	28554	79	18F
0005434137965	28554	80	19A
0005434137827	28554	81	19C
0005434087519	28554	82	19D
0005434137868	28554	83	19F
0005434138369	28554	84	20A
0005434138422	28554	85	20C
0005434138349	28554	86	20D
0005434138247	28554	87	20E
0005434138027	28554	88	20F
0005435808320	1899	1	1C
0005435808327	1899	2	1D
0005435808326	1899	3	2A
0005435808319	1899	4	2C
0005435808321	1899	5	2D
0005434610258	1899	6	3A
0005433407535	1899	7	3C
0005434610260	1899	8	4B
0005434610257	1899	9	6B
0005435808316	1899	10	6C
0005435808324	1899	11	18B
0005435808318	1899	12	19B
0005435808323	1899	13	19C
0005435808325	1899	14	20A
0005434610261	1899	15	20C
0005434610259	1899	16	21A
0005435808322	1899	17	21D
0005433407536	1899	18	22A
0005435808317	1899	19	22D
0005434610213	23120	1	3C
0005434504234	16706	1	1A
0005434504080	16706	2	1B
0005434504102	16706	3	1C
0005434504141	16706	4	2A
0005434504187	16706	5	2C
0005434504035	16706	6	2D
0005434504079	16706	7	3A
0005434504120	16706	8	3B
0005434504313	16706	9	3C
0005434504033	16706	10	3D
0005434503932	16706	11	4A
0005434503990	16706	12	4B
0005434504372	16706	13	4C
0005434504274	16706	14	4D
0005434504235	16706	15	5A
0005434503933	16706	16	5B
0005434503982	16706	17	5C
0005434504128	16706	18	5D
0005434504044	16706	19	6A
0005434504030	16706	20	6D
0005434504112	16706	21	7A
0005434504017	16706	22	7B
0005434504127	16706	23	7C
0005434504077	16706	24	18A
0005434504034	16706	25	18C
0005434504108	16706	26	18D
0005434504025	16706	27	19A
0005434504122	16706	28	19B
0005434504289	16706	29	19C
0005434504026	16706	30	19D
0005434504275	16706	31	20A
0005434504092	16706	32	20C
0005434504209	16706	33	21A
0005434504095	16706	34	21B
0005434504373	16706	35	21C
0005434504121	16706	36	21D
0005434504103	16706	37	22B
0005434504070	16706	38	23A
0005434504067	16706	39	23B
0005434504458	22899	1	1A
0005434504443	22899	2	1B
0005434504435	22899	3	1D
0005434504437	22899	4	2B
0005434504457	22899	5	2C
0005434504456	22899	6	2D
0005434504434	22899	7	3A
0005434504444	22899	8	3B
0005434504462	22899	9	3C
0005434504439	22899	10	3D
0005434504440	22899	11	4A
0005434504428	22899	12	4B
0005434504447	22899	13	4D
0005434504429	22899	14	5C
0005434504452	22899	15	5D
0005434504427	22899	16	6A
0005434504463	22899	17	6B
0005434504451	22899	18	6C
0005434504445	22899	19	6D
0005434504448	22899	20	7A
0005434504431	22899	21	7B
0005434504461	22899	22	7C
0005434504438	22899	23	18A
0005434504424	22899	24	18B
0005434504425	22899	25	18C
0005434504460	22899	26	19A
0005434504455	22899	27	19B
0005434504446	22899	28	19C
0005434504459	22899	29	19D
0005434504449	22899	30	20B
0005434504442	22899	31	20C
0005434504430	22899	32	20D
0005434504453	22899	33	21A
0005434504450	22899	34	21B
0005434504426	22899	35	21C
0005434504441	22899	36	21D
0005434504436	22899	37	22A
0005434504433	22899	38	22C
0005434504454	22899	39	22D
0005434504432	22899	40	23B
0005435078476	2189	1	1A
0005435078466	2189	2	1B
0005435078462	2189	3	1C
0005435078465	2189	4	2A
0005433266697	2189	5	3C
0005433266717	2189	6	4A
0005433266703	2189	7	4D
0005435078479	2189	8	5A
0005435078473	2189	9	5D
0005433266716	2189	10	6A
0005433266707	2189	11	6C
0005435078478	2189	12	7B
0005433266756	2189	13	18A
0005435078463	2189	14	18B
0005435078474	2189	15	18D
0005435078464	2189	16	19A
0005433266748	2189	17	19C
0005435078470	2189	18	19D
0005435078475	2189	19	20A
0005435078468	2189	20	20B
0005433266754	2189	21	20C
0005433266712	2189	22	20D
0005435078471	2189	23	21A
0005435078469	2189	24	22B
0005435078467	2189	25	22C
0005435078477	2189	26	22D
0005435078472	2189	27	23A
0005435078342	24358	1	1B
0005433266801	24358	2	1D
0005435078362	24358	3	2B
0005433266799	24358	4	2D
0005433266800	24358	5	3A
0005435078328	24358	6	4B
0005433266803	24358	7	4D
0005435078329	24358	8	6A
0005435078394	24358	9	6B
0005435078380	24358	10	6D
0005433266802	24358	11	7A
0005435078410	24358	12	7D
0005435078393	24358	13	18C
0005435078383	24358	14	18D
0005433266797	24358	15	19A
0005435078384	24358	16	19B
0005433266796	24358	17	20A
0005433266804	24358	18	21A
0005435078341	24358	19	21C
0005433266798	24358	20	21D
0005435078381	24358	21	23A
0005433266795	24358	22	23B
0005434988827	6642	1	1B
0005435803286	6642	2	2C
0005434988822	6642	3	3A
0005434988823	6642	4	3C
0005434988824	6642	5	4A
0005435803287	6642	6	7A
0005434988825	6642	7	7C
0005434988821	6642	8	18A
0005434988829	6642	9	18D
0005434988830	6642	10	19A
0005434988828	6642	11	19B
0005434988826	6642	12	20A
0005434988831	6642	13	23B
0005435803255	23633	1	1A
0005434988697	23633	2	1B
0005434988696	23633	3	1D
0005434988709	23633	4	2C
0005434988667	23633	5	2D
0005434988675	23633	6	4B
0005434988674	23633	7	4C
0005434988686	23633	8	6B
0005434988708	23633	9	6C
0005434988703	23633	10	6D
0005435803254	23633	11	7B
0005435803256	23633	12	18A
0005435464524	23633	13	18C
0005434988679	23633	14	18D
0005435464525	23633	15	19D
0005434988704	23633	16	20C
0005435803257	23633	17	21B
0005434988678	23633	18	21C
0005434988671	23633	19	21D
0005433454892	30508	1	1A
0005432383503	30508	2	1D
0005433450159	30508	3	2A
0005432383512	30508	4	2C
0005432383522	30508	5	2D
0005432383517	30508	6	2F
0005432383502	30508	7	3A
0005433450142	30508	8	3C
0005433450143	30508	9	3D
0005433450161	30508	10	3F
0005432383520	30508	11	4D
0005432383498	30508	12	4E
0005433450149	30508	13	5A
0005432383500	30508	14	5C
0005433450144	30508	15	5E
0005432383507	30508	16	6A
0005433450147	30508	17	6C
0005432383519	30508	18	6E
0005432383529	30508	19	7A
0005432383526	30508	20	7C
0005433450145	30508	21	7D
0005432383499	30508	22	7E
0005432383496	30508	23	7F
0005432383506	30508	24	8A
0005433450146	30508	25	8C
0005432383513	30508	26	8D
0005432383489	30508	27	8E
0005432383494	30508	28	9A
0005432383516	30508	29	9C
0005433450157	30508	30	9D
0005433450148	30508	31	9E
0005432383527	30508	32	9F
0005432383508	30508	33	10A
0005432383531	30508	34	10D
0005432383490	30508	35	10E
0005432383509	30508	36	10F
0005432383488	30508	37	11A
0005432383511	30508	38	11C
0005433450162	30508	39	11D
0005432383510	30508	40	11F
0005432383530	30508	41	12A
0005433450153	30508	42	12C
0005433450156	30508	43	12D
0005433454893	30508	44	12E
0005432383532	30508	45	12F
0005433454894	30508	46	13C
0005432383497	30508	47	13E
0005433450152	30508	48	13F
0005433453775	30508	49	14A
0005432383515	30508	50	14C
0005432383521	30508	51	14E
0005432383504	30508	52	15A
0005433450160	30508	53	15E
0005432383518	30508	54	15F
0005432383505	30508	55	16C
0005433450154	30508	56	16D
0005433450150	30508	57	16F
0005432383501	30508	58	17A
0005432383514	30508	59	17C
0005433450141	30508	60	17D
0005433450151	30508	61	17E
0005432383492	30508	62	17F
0005432383493	30508	63	18A
0005433450155	30508	64	18C
0005432383528	30508	65	18D
0005432383491	30508	66	18F
0005433450158	30508	67	19A
0005432383495	30508	68	19C
0005432383524	30508	69	19D
0005433453776	30508	70	19E
0005432383523	30508	71	20E
0005432383525	30508	72	20F
0005432382944	31340	1	1A
0005432383159	31340	2	1C
0005432383058	31340	3	1D
0005433449974	31340	4	2A
0005432383034	31340	5	2D
0005433449939	31340	6	3A
0005432383089	31340	7	3F
0005432383185	31340	8	4D
0005432383104	31340	9	4F
0005432383213	31340	10	5A
0005432383071	31340	11	6A
0005432383111	31340	12	6D
0005433449993	31340	13	6E
0005433451618	31340	14	6F
0005432383110	31340	15	7A
0005432383126	31340	16	7C
0005432383186	31340	17	7D
0005432383069	31340	18	7E
0005432383180	31340	19	7F
0005432383061	31340	20	8C
0005433453761	31340	21	8D
0005432383130	31340	22	8E
0005432383103	31340	23	8F
0005432383050	31340	24	9D
0005433449898	31340	25	9E
0005432383125	31340	26	10A
0005433453755	31340	27	10E
0005432383127	31340	28	11D
0005432382928	31340	29	11E
0005432383062	31340	30	11F
0005432383012	31340	31	12A
0005432382979	31340	32	12D
0005432383077	31340	33	12E
0005432383105	31340	34	13A
0005432383102	31340	35	13D
0005432383128	31340	36	13F
0005432383194	31340	37	14C
0005433453756	31340	38	14E
0005432383070	31340	39	15C
0005433450012	31340	40	15F
0005432383224	31340	41	16A
0005432383003	31340	42	16C
0005433449819	31340	43	16E
0005433449820	31340	44	17A
0005432383059	31340	45	17C
0005432383057	31340	46	17D
0005433449931	31340	47	17E
0005433449940	31340	48	17F
0005433453757	31340	49	18A
0005433449899	31340	50	18C
0005432383222	31340	51	18D
0005433449956	31340	52	18E
0005432383199	31340	53	18F
0005433451621	31340	54	19E
0005433449992	31340	55	19F
0005432383223	31340	56	20A
0005432383245	31340	57	20D
0005435548532	26473	1	2B
0005435548530	26473	2	2D
0005435548531	26473	3	4B
0005435548529	26473	4	5A
0005435548534	26473	5	6A
0005435548536	26473	6	7A
0005433788193	26473	7	7C
0005433788191	26473	8	18A
0005433788196	26473	9	19D
0005433788200	26473	10	20A
0005435548533	26473	11	21B
0005435548537	26473	12	21D
0005435548535	26473	13	22B
0005433788192	26473	14	22C
0005433131706	10794	1	1B
0005435299787	10794	2	1C
0005433131715	10794	3	4B
0005433131695	10794	4	4D
0005433126842	10794	5	5A
0005433126823	10794	6	6D
0005433126837	10794	7	7A
0005435304185	10794	8	18D
0005433126843	10794	9	19C
0005433131694	10794	10	19D
0005433131710	10794	11	20A
0005433126838	10794	12	20B
0005435304148	10794	13	21B
0005435304157	10794	14	21C
0005435299786	10794	15	22B
0005433131709	10794	16	23A
0005435302243	29705	1	1A
0005433129318	29705	2	1B
0005435299817	29705	3	1C
0005435302239	29705	4	2A
0005435302240	29705	5	2B
0005435299818	29705	6	3A
0005433129319	29705	7	3C
0005435302241	29705	8	4A
0005433126887	29705	9	4D
0005435299820	29705	10	5B
0005435302244	29705	11	18A
0005433126885	29705	12	19B
0005435299821	29705	13	19C
0005435302242	29705	14	19D
0005433129317	29705	15	20C
0005433129316	29705	16	21B
0005433126886	29705	17	21C
0005433126888	29705	18	21D
0005433129320	29705	19	22A
0005435299819	29705	20	23A
0005434287463	2383	1	1C
0005434287472	2383	2	1D
0005434287470	2383	3	2A
0005434287482	2383	4	2B
0005434287479	2383	5	2C
0005434287467	2383	6	3B
0005434287469	2383	7	3C
0005432264495	2383	8	3D
0005434287462	2383	9	4B
0005434287477	2383	10	4C
0005433110080	2383	11	5A
0005434287481	2383	12	5C
0005434287465	2383	13	5D
0005434287483	2383	14	6B
0005434287474	2383	15	7A
0005432264496	2383	16	7C
0005434287466	2383	17	7D
0005433110015	2383	18	18B
0005433110086	2383	19	18D
0005433110114	2383	20	19A
0005434287475	2383	21	19B
0005434287464	2383	22	19C
0005434287473	2383	23	19D
0005434287471	2383	24	20B
0005433110122	2383	25	20C
0005433110072	2383	26	20D
0005434287476	2383	27	21A
0005434287468	2383	28	21B
0005433110071	2383	29	21C
0005433110079	2383	30	21D
0005434287478	2383	31	22B
0005434287480	2383	32	22C
0005433110043	2383	33	22D
0005433110064	2383	34	23A
0005433110108	2383	35	23B
0005434287235	26830	1	1B
0005433110158	26830	2	1C
0005434287328	26830	3	1D
0005434287329	26830	4	2A
0005434287234	26830	5	2B
0005433110156	26830	6	2C
0005433110153	26830	7	2D
0005433110157	26830	8	3A
0005434287218	26830	9	4A
0005434287330	26830	10	4B
0005433110147	26830	11	4C
0005433110154	26830	12	5B
0005434287293	26830	13	5D
0005434287230	26830	14	6B
0005434287325	26830	15	6D
0005434287243	26830	16	7B
0005434287244	26830	17	7C
0005434287177	26830	18	18C
0005433110155	26830	19	18D
0005433110148	26830	20	19A
0005433110151	26830	21	19B
0005434287327	26830	22	19C
0005434287283	26830	23	19D
0005434287361	26830	24	20A
0005433110150	26830	25	20C
0005434287294	26830	26	20D
0005434287360	26830	27	21A
0005434287311	26830	28	21C
0005434287312	26830	29	22A
0005433110152	26830	30	22B
0005434287238	26830	31	22C
0005434287229	26830	32	22D
0005434287178	26830	33	23A
0005433110149	26830	34	23B
0005435856240	25499	1	1C
0005435856239	25499	2	2B
0005434269088	25499	3	2D
0005435856241	25499	4	3A
0005435856238	25499	5	4D
0005434269098	25499	6	5D
0005435856237	25499	7	5C
0005434272188	25499	8	6D
0005434269097	25499	9	7A
0005434269099	25499	10	7B
0005434272187	25499	11	18A
0005434272192	25499	12	20C
0005434273091	26630	1	1C
0005434272205	26630	2	3B
0005434272206	26630	3	3C
0005435856192	26630	4	4B
0005434272207	26630	5	5B
0005435856170	26630	6	6C
0005434273092	26630	7	18B
0005435856175	26630	8	18D
0005435856193	26630	9	19A
0005435856174	26630	10	21C
0005435856190	26630	11	22D
0005435314873	19078	1	1A
0005434520260	19078	2	1B
0005435314869	19078	3	2A
0005435314861	19078	4	2B
0005435314870	19078	5	2C
0005434520218	19078	6	2D
0005434520255	19078	7	3B
0005434520228	19078	8	3C
0005435314867	19078	9	3D
0005434520205	19078	10	4A
0005434520258	19078	11	4C
0005435314866	19078	12	5B
0005434520261	19078	13	5C
0005435314859	19078	14	5D
0005435314872	19078	15	6A
0005435314860	19078	16	6C
0005435314865	19078	17	6B
0005434520201	19078	18	7A
0005434520249	19078	19	7B
0005435314863	19078	20	7D
0005435314868	19078	21	18A
0005435314871	19078	22	18B
0005434520242	19078	23	18D
0005434520224	19078	24	19A
0005434520251	19078	25	19B
0005434520234	19078	26	19C
0005434520200	19078	27	19D
0005434520219	19078	28	20A
0005434520265	19078	29	20C
0005434520257	19078	30	21A
0005434520248	19078	31	21B
0005434520223	19078	32	21C
0005434520250	19078	33	21D
0005434520252	19078	34	22A
0005434520214	19078	35	22B
0005434520259	19078	36	22C
0005434520247	19078	37	22D
0005435314864	19078	38	23A
0005435314862	19078	39	23B
0005433874375	7788	1	1A
0005433874381	7788	2	1C
0005433874373	7788	3	2A
0005433874376	7788	4	3C
0005433874379	7788	5	3D
0005433874370	7788	6	5A
0005433874378	7788	7	5D
0005433874371	7788	8	6A
0005433874383	7788	9	6C
0005433874372	7788	10	18A
0005433874380	7788	11	18C
0005433874377	7788	12	19A
0005433874382	7788	13	20A
0005433874374	7788	14	23B
0005433874358	32625	1	2A
0005433874348	32625	2	2B
0005433874341	32625	3	2D
0005433874355	32625	4	3A
0005433874352	32625	5	5A
0005433874349	32625	6	7A
0005433874351	32625	7	7D
0005433874347	32625	8	18C
0005433874359	32625	9	18D
0005433874350	32625	10	19C
0005433868757	4791	1	1A
0005433868796	4791	2	1B
0005435860481	4791	3	1C
0005433868761	4791	4	1D
0005433868795	4791	5	2A
0005433868767	4791	6	2B
0005433868784	4791	7	2C
0005433868783	4791	8	2D
0005433868758	4791	9	3A
0005433868766	4791	10	3B
0005433868753	4791	11	3C
0005435860470	4791	12	3D
0005433868764	4791	13	4A
0005433868773	4791	14	4B
0005433868772	4791	15	4C
0005433868777	4791	16	4D
0005433868760	4791	17	5A
0005433868768	4791	18	5B
0005433868765	4791	19	5C
0005433868792	4791	20	5D
0005435860489	4791	21	6A
0005433868771	4791	22	6C
0005433868781	4791	23	6D
0005433868785	4791	24	7A
0005433868782	4791	25	7B
0005433868755	4791	26	7C
0005433868793	4791	27	7D
0005433868780	4791	28	18A
0005435860488	4791	29	18B
0005433868769	4791	30	18C
0005433868789	4791	31	18D
0005433868778	4791	32	19A
0005433868762	4791	33	19B
0005433868770	4791	34	19C
0005433868759	4791	35	19D
0005433868794	4791	36	20A
0005433868779	4791	37	20B
0005433868791	4791	38	20C
0005433868788	4791	39	21A
0005433868774	4791	40	21B
0005433868756	4791	41	21C
0005433868775	4791	42	21D
0005433868754	4791	43	22A
0005433868790	4791	44	22B
0005433868787	4791	45	22C
0005433868763	4791	46	22D
0005433868776	4791	47	23A
0005433868786	4791	48	23B
0005433868500	32617	1	1D
0005433868203	32617	2	2A
0005433868528	32617	3	2C
0005433868352	32617	4	2B
0005435860512	32617	5	3A
0005433868471	32617	6	3B
0005433868260	32617	7	3C
0005433868391	32617	8	3D
0005435860511	32617	9	4A
0005433868321	32617	10	4B
0005433868494	32617	11	4C
0005433868392	32617	12	4D
0005435860513	32617	13	5A
0005433868181	32617	14	5B
0005433868470	32617	15	5C
0005433868495	32617	16	6A
0005433868502	32617	17	6B
0005433868353	32617	18	6C
0005433868452	32617	19	6D
0005433868435	32617	20	7A
0005433868359	32617	21	7B
0005433868360	32617	22	7D
0005433868322	32617	23	18A
0005433868278	32617	24	18B
0005433868261	32617	25	18C
0005433868420	32617	26	18D
0005433868348	32617	27	19A
0005433868320	32617	28	19B
0005433868501	32617	29	19C
0005433868557	32617	30	20A
0005433868550	32617	31	20B
0005433868279	32617	32	20C
0005433868601	32617	33	20D
0005433868358	32617	34	21A
0005433868131	32617	35	21B
0005433868558	32617	36	21C
0005433868381	32617	37	21D
0005433868364	32617	38	22A
0005433868551	32617	39	22B
0005433868472	32617	40	22D
0005433868323	32617	41	23A
0005433868315	32617	42	23B
0005434461665	3429	1	1B
0005435911441	3429	2	2C
0005434663518	3429	3	3B
0005434663522	3429	4	3D
0005435911455	3429	5	4C
0005434460523	3429	6	4D
0005435911440	3429	7	5B
0005435911427	3429	8	5C
0005434461664	3429	9	5D
0005434663527	3429	10	6D
0005434663519	3429	11	7A
0005435911469	3429	12	7B
0005435911470	3429	13	7C
0005434663514	3429	14	18B
0005435911422	3429	15	18A
0005435911421	3429	16	19A
0005434663516	3429	17	19B
0005434663526	3429	18	19C
0005434663521	3429	19	19D
0005434663517	3429	20	20C
0005434460524	3429	21	20D
0005434663515	3429	22	22A
0005434663520	3429	23	22B
0005434663525	3429	24	22C
0005434663523	3429	25	22D
0005434663524	3429	26	23B
0005435911512	12485	1	1B
0005435911518	12485	2	1C
0005434663440	12485	3	1D
0005434663375	12485	4	2A
0005434663390	12485	5	2B
0005434663394	12485	6	2C
0005434460488	12485	7	2D
0005434460498	12485	8	3A
0005435911514	12485	9	3B
0005434663389	12485	10	3C
0005434462783	12485	11	3D
0005434663346	12485	12	4C
0005434663441	12485	13	4D
0005434663411	12485	14	5A
0005434663456	12485	15	5B
0005434663393	12485	16	5D
0005434663414	12485	17	6A
0005434663293	12485	18	6B
0005434663373	12485	19	6D
0005434462773	12485	20	7A
0005434663410	12485	21	7C
0005434462780	12485	22	7B
0005435911511	12485	23	7D
0005435911519	12485	24	18B
0005434460492	12485	25	18A
0005435911517	12485	26	18C
0005434663374	12485	27	18D
0005434663430	12485	28	19A
0005435911516	12485	29	19B
0005434460489	12485	30	19C
0005434460505	12485	31	19D
0005434462785	12485	32	20B
0005434460490	12485	33	20C
0005434460491	12485	34	20D
0005435911513	12485	35	21A
0005434460499	12485	36	21B
0005435911515	12485	37	21C
0005434663292	12485	38	21D
0005434663388	12485	39	22A
0005434462789	12485	40	22B
0005434663372	12485	41	22D
0005434462786	12485	42	23A
0005434663367	12485	43	23B
0005435860511	14517	1	1A
0005433868359	14517	2	1D
0005433868279	14517	3	2A
0005433868452	14517	4	2B
0005433868557	14517	5	2C
0005433868494	14517	6	2D
0005433868181	14517	7	3A
0005433868381	14517	8	3B
0005433868364	14517	9	3C
0005433868278	14517	10	3D
0005433868391	14517	11	4A
0005433868472	14517	12	4C
0005433868321	14517	13	4D
0005433868353	14517	14	5A
0005433868358	14517	15	5B
0005433868320	14517	16	5C
0005433868420	14517	17	5D
0005433868495	14517	18	6A
0005433868323	14517	19	6C
0005433868501	14517	20	6D
0005433868352	14517	21	7A
0005433868203	14517	22	7C
0005435860512	14517	23	7D
0005433868260	14517	24	18A
0005433868500	14517	25	18B
0005433868471	14517	26	18C
0005433868550	14517	27	18D
0005433868322	14517	28	19B
0005433868435	14517	29	19C
0005433868360	14517	30	19D
0005433868528	14517	31	20B
0005433868558	14517	32	20C
0005433868261	14517	33	21A
0005433868315	14517	34	21B
0005433868131	14517	35	21C
0005435860513	14517	36	21D
0005433868502	14517	37	22A
0005433868601	14517	38	22B
0005433868348	14517	39	22C
0005433868392	14517	40	22D
0005433868470	14517	41	23A
0005433868551	14517	42	23B
0005433868751	32699	1	1A
0005433868732	32699	2	1B
0005433868743	32699	3	1C
0005433868740	32699	4	1D
0005433868730	32699	5	2A
0005433868731	32699	6	2B
0005433868726	32699	7	2C
0005433868727	32699	8	2D
0005433868719	32699	9	3A
0005433868741	32699	10	3B
0005433868750	32699	11	3C
0005433868722	32699	12	4A
0005433868713	32699	13	4B
0005433868717	32699	14	4C
0005433868745	32699	15	4D
0005433868725	32699	16	5A
0005433868720	32699	17	5B
0005433868739	32699	18	5C
0005435860479	32699	19	5D
0005433868712	32699	20	6A
0005433868721	32699	21	6B
0005433868718	32699	22	6C
0005433868714	32699	23	6D
0005433868716	32699	24	7A
0005433868723	32699	25	7B
0005433868747	32699	26	7C
0005433868711	32699	27	7D
0005433868729	32699	28	18A
0005433868733	32699	29	18B
0005433868746	32699	30	18C
0005435860478	32699	31	18D
0005433868738	32699	32	19B
0005433868715	32699	33	19C
0005433868748	32699	34	19D
0005433868735	32699	35	20A
0005433868752	32699	36	20B
0005433868734	32699	37	20C
0005433868737	32699	38	21A
0005433868736	32699	39	21B
0005433868744	32699	40	21C
0005433868728	32699	41	21D
0005435860474	32699	42	22B
0005433868742	32699	43	22A
0005433868724	32699	44	22C
0005435860473	32699	45	22D
0005433868749	32699	46	23B
0005432799402	12134	1	1B
0005432799398	12134	2	1C
0005432799460	12134	3	1D
0005432799500	12134	4	2A
0005432799358	12134	5	2B
0005432799371	12134	6	2C
0005432799497	12134	7	4A
0005432799386	12134	8	4C
0005432799372	12134	9	4D
0005432799468	12134	10	5A
0005432799464	12134	11	6C
0005432799577	12134	12	6D
0005432799449	12134	13	7A
0005432799397	12134	14	7C
0005432799578	12134	15	7D
0005432799453	12134	16	18A
0005432799463	12134	17	18C
0005432799516	12134	18	18D
0005432799552	12134	19	19B
0005432799461	12134	20	19C
0005432799502	12134	21	19D
0005432799503	12134	22	20C
0005432799475	12134	23	21D
0005432799522	12134	24	22A
0005432799492	12134	25	22D
0005432799418	12134	26	23B
0005432799651	14824	1	1A
0005432799653	14824	2	1C
0005432799648	14824	3	1D
0005432799650	14824	4	2C
0005432799666	14824	5	3C
0005432799649	14824	6	4A
0005432799665	14824	7	4B
0005432799663	14824	8	5A
0005432799675	14824	9	4D
0005432799669	14824	10	5C
0005432799647	14824	11	5D
0005432799662	14824	12	6A
0005432799659	14824	13	6B
0005432799657	14824	14	6C
0005432799655	14824	15	6D
0005432799673	14824	16	7A
0005432799674	14824	17	7B
0005432799667	14824	18	7C
0005432799672	14824	19	7D
0005432799652	14824	20	18A
0005432799660	14824	21	18B
0005432799670	14824	22	18D
0005432799671	14824	23	19D
0005432799658	14824	24	21A
0005432799664	14824	25	21B
0005432799656	14824	26	21C
0005432799661	14824	27	22B
0005432799654	14824	28	22C
0005432799668	14824	29	23A
0005434408254	7061	1	1A
0005434408297	7061	2	1C
0005434408301	7061	3	1F
0005434408259	7061	4	1D
0005434408271	7061	5	2C
0005434408260	7061	6	2D
0005434299762	7061	7	3A
0005435311051	7061	8	2F
0005434408256	7061	9	3D
0005434299752	7061	10	3F
0005435311015	7061	11	4B
0005434299743	7061	12	4A
0005435311039	7061	13	4C
0005435311046	7061	14	4E
0005434299763	7061	15	4D
0005434408305	7061	16	4F
0005434299758	7061	17	5B
0005434408257	7061	18	5A
0005434408308	7061	19	5C
0005432153996	7061	20	5D
0005434408264	7061	21	5E
0005434408289	7061	22	5F
0005434408273	7061	23	6B
0005434408306	7061	24	6A
0005434299745	7061	25	6C
0005434408280	7061	26	6D
0005434408315	7061	27	6F
0005434299751	7061	28	6E
0005434408285	7061	29	7B
0005434408296	7061	30	7D
0005434408262	7061	31	7E
0005434299748	7061	32	8A
0005434408309	7061	33	7F
0005432153994	7061	34	8B
0005434299742	7061	35	8C
0005435311049	7061	36	8E
0005434408288	7061	37	8D
0005434299765	7061	38	9A
0005434299755	7061	39	8F
0005432108270	7061	40	9B
0005434408284	7061	41	9C
0005434299749	7061	42	9E
0005434408286	7061	43	9D
0005434299764	7061	44	9F
0005435311050	7061	45	10B
0005434408281	7061	46	10D
0005434408287	7061	47	10C
0005432153997	7061	48	10E
0005434408269	7061	49	11B
0005434408293	7061	50	11D
0005434299759	7061	51	11C
0005434408267	7061	52	11E
0005434408265	7061	53	11F
0005434408266	7061	54	12B
0005435293262	7061	55	12A
0005434408258	7061	56	12C
0005434408299	7061	57	12D
0005434408300	7061	58	12E
0005434408317	7061	59	12F
0005434408274	7061	60	13A
0005434408275	7061	61	13C
0005432108272	7061	62	13B
0005434408255	7061	63	13D
0005432153995	7061	64	13E
0005435311040	7061	65	13F
0005434299754	7061	66	14B
0005434408313	7061	67	14A
0005432153998	7061	68	14C
0005432108273	7061	69	14D
0005434408302	7061	70	14E
0005434408272	7061	71	14F
0005434299744	7061	72	15B
0005434408261	7061	73	15A
0005434408290	7061	74	15C
0005435293267	7061	75	15D
0005434408277	7061	76	15F
0005432153993	7061	77	15E
0005434408314	7061	78	16B
0005434299756	7061	79	16C
0005434299750	7061	80	16D
0005434408279	7061	81	16F
0005435311061	7061	82	16E
0005434408303	7061	83	17A
0005434299761	7061	84	17B
0005435293263	7061	85	17C
0005434408270	7061	86	17D
0005435293247	7061	87	17F
0005434408310	7061	88	17E
0005434408282	7061	89	18A
0005434299757	7061	90	18B
0005434408278	7061	91	18D
0005432108271	7061	92	18C
0005435293266	7061	93	18E
0005432153999	7061	94	18F
0005435293256	7061	95	19A
0005434408268	7061	96	19B
0005434299746	7061	97	19C
0005434299753	7061	98	19F
0005434408283	7061	99	20C
0005435311014	7061	100	20B
0005434408291	7061	101	20D
0005434408295	7061	102	20E
0005434299747	7061	103	21A
0005434408298	7061	104	20F
0005434408312	7061	105	21B
0005434408307	7061	106	21D
0005435293222	7061	107	21C
0005434408304	7061	108	21E
0005434299760	7061	109	21F
0005434408292	7061	110	22B
0005435311055	7061	111	22A
0005434408263	7061	112	22C
0005434408316	7061	113	22D
0005435311047	7061	114	22E
0005434408276	7061	115	22F
0005435311064	7061	116	23C
0005434408311	7061	117	23D
0005434408294	7061	118	23F
0005432058412	26893	1	1A
0005434407724	26893	2	1C
0005434407618	26893	3	1D
0005434407456	26893	4	2A
0005435293360	26893	5	1F
0005434407689	26893	6	2C
0005435311149	26893	7	2D
0005434407703	26893	8	3A
0005434407447	26893	9	2F
0005434299471	26893	10	3C
0005434407403	26893	11	3F
0005435311143	26893	12	3D
0005434407846	26893	13	4B
0005435293359	26893	14	4A
0005435311141	26893	15	4D
0005434299612	26893	16	4E
0005434407728	26893	17	4F
0005435293355	26893	18	5A
0005434407718	26893	19	5C
0005434407613	26893	20	5B
0005434407555	26893	21	5D
0005435311140	26893	22	5E
0005434299601	26893	23	5F
0005434407725	26893	24	6A
0005435311153	26893	25	6B
0005434407246	26893	26	6D
0005434407697	26893	27	6E
0005434407391	26893	28	7A
0005434299557	26893	29	6F
0005434299532	26893	30	7B
0005435293357	26893	31	7C
0005434407609	26893	32	7E
0005434407442	26893	33	7D
0005434299505	26893	34	7F
0005434407796	26893	35	8B
0005434407402	26893	36	8C
0005434407844	26893	37	8E
0005434299590	26893	38	8F
0005434407702	26893	39	9B
0005434407784	26893	40	9C
0005435293351	26893	41	9E
0005434407793	26893	42	9D
0005434299575	26893	43	9F
0005434408011	26893	44	10B
0005435293353	26893	45	10D
0005434407628	26893	46	10C
0005434299587	26893	47	11A
0005435311142	26893	48	10E
0005432058410	26893	49	11B
0005434299576	26893	50	11C
0005434299504	26893	51	11D
0005435293358	26893	52	11F
0005434407699	26893	53	12A
0005434407685	26893	54	12B
0005435293352	26893	55	12E
0005434299620	26893	56	12D
0005434407902	26893	57	13B
0005434407568	26893	58	13C
0005434407695	26893	59	13E
0005434299542	26893	60	13F
0005434407443	26893	61	14A
0005434407608	26893	62	14D
0005435311154	26893	63	14C
0005434407573	26893	64	14F
0005434407783	26893	65	15A
0005434407845	26893	66	15B
0005435311155	26893	67	15C
0005434299621	26893	68	15D
0005434407318	26893	69	15E
0005432058411	26893	70	15F
0005435293354	26893	71	16B
0005435311148	26893	72	16E
0005435311150	26893	73	16D
0005434407677	26893	74	16F
0005434299572	26893	75	17B
0005434408010	26893	76	17C
0005434407682	26893	77	17E
0005434407629	26893	78	18A
0005435311146	26893	79	17F
0005434408056	26893	80	18B
0005434407619	26893	81	18D
0005435311152	26893	82	18E
0005434407474	26893	83	19A
0005434407794	26893	84	19B
0005434407698	26893	85	19D
0005434407651	26893	86	19C
0005432058409	26893	87	19E
0005435293356	26893	88	19F
0005435311147	26893	89	20A
0005434299562	26893	90	20C
0005434407452	26893	91	20B
0005434299571	26893	92	20D
0005435311139	26893	93	20F
0005435293361	26893	94	21B
0005434299531	26893	95	21A
0005434407620	26893	96	21C
0005434407650	26893	97	21E
0005434407686	26893	98	22A
0005434407713	26893	99	22B
0005434407849	26893	100	22D
0005435311144	26893	101	22C
0005435311156	26893	102	22F
0005435293350	26893	103	23B
0005435311151	26893	104	23C
0005435311145	26893	105	23E
0005435293349	26893	106	23F
0005432604669	6455	1	1B
0005432604666	6455	2	1C
0005432604675	6455	3	1D
0005432604679	6455	4	2B
0005432604680	6455	5	2A
0005432604688	6455	6	2C
0005432604690	6455	7	2D
0005432604664	6455	8	3A
0005432604694	6455	9	3B
0005432604668	6455	10	3C
0005432604656	6455	11	3D
0005432604682	6455	12	4B
0005432604660	6455	13	4C
0005432604681	6455	14	4D
0005435220489	6455	15	5A
0005432604684	6455	16	5B
0005432604658	6455	17	5C
0005432604671	6455	18	6A
0005432604663	6455	19	6B
0005432604665	6455	20	6C
0005432604676	6455	21	6D
0005432604677	6455	22	7A
0005432604683	6455	23	7B
0005432604662	6455	24	7D
0005432604672	6455	25	18A
0005432604689	6455	26	18B
0005432604667	6455	27	18C
0005434512150	6455	28	18D
0005432604691	6455	29	19A
0005432604686	6455	30	19B
0005432604685	6455	31	19C
0005432604687	6455	32	19D
0005432604661	6455	33	20A
0005432604659	6455	34	20B
0005432604692	6455	35	20D
0005432604673	6455	36	21A
0005432604674	6455	37	21B
0005432604670	6455	38	21C
0005432604695	6455	39	22A
0005432604693	6455	40	22B
0005435218115	6455	41	22C
0005432604678	6455	42	22D
0005432604657	6455	43	23A
0005435218113	6455	44	23B
0005432604297	21397	1	1A
0005432604324	21397	2	1B
0005432604211	21397	3	1C
0005432604225	21397	4	1D
0005432604384	21397	5	2A
0005432604296	21397	6	2B
0005432604412	21397	7	2C
0005432604292	21397	8	2D
0005432604274	21397	9	3A
0005434512099	21397	10	3B
0005432604281	21397	11	3C
0005432604149	21397	12	3D
0005432604446	21397	13	4A
0005432604410	21397	14	4B
0005432604413	21397	15	4C
0005432604157	21397	16	4D
0005432604077	21397	17	5A
0005434512098	21397	18	5B
0005432604310	21397	19	5C
0005432604385	21397	20	5D
0005432604010	21397	21	6A
0005432604213	21397	22	6B
0005432604052	21397	23	6C
0005432604323	21397	24	6D
0005432604534	21397	25	7A
0005432604309	21397	26	7B
0005432604051	21397	27	7C
0005432604192	21397	28	7D
0005432604386	21397	29	18A
0005432604291	21397	30	18C
0005432604221	21397	31	18D
0005432604346	21397	32	19A
0005432604273	21397	33	19C
0005432604170	21397	34	19B
0005432604161	21397	35	20A
0005432604171	21397	36	20B
0005432604222	21397	37	20C
0005432604191	21397	38	20D
0005432604162	21397	39	21A
0005432604172	21397	40	21C
0005434512097	21397	41	21D
0005432604190	21397	42	22A
0005432604287	21397	43	22C
0005432604271	21397	44	22B
0005432604229	21397	45	22D
0005432604299	21397	46	23A
0005432604148	21397	47	23B
0005434907103	15024	1	1A
0005433251740	15024	2	1C
0005434907121	15024	3	1D
0005433251736	15024	4	1F
0005434907240	15024	5	2A
0005434907183	15024	6	2C
0005433251726	15024	7	2D
0005434907221	15024	8	2F
0005434907112	15024	9	3A
0005434907092	15024	10	3C
0005433251725	15024	11	3D
0005433251719	15024	12	3F
0005434907082	15024	13	4A
0005434907064	15024	14	4C
0005434907113	15024	15	4D
0005434907150	15024	16	4E
0005434907123	15024	17	4F
0005434907283	15024	18	5C
0005433251733	15024	19	5E
0005434907057	15024	20	5F
0005434907315	15024	21	6A
0005434906995	15024	22	6C
0005434907237	15024	23	6D
0005434907125	15024	24	6E
0005433251748	15024	25	6F
0005433251731	15024	26	7A
0005434907212	15024	27	7C
0005433251744	15024	28	7D
0005434907034	15024	29	7E
0005433251746	15024	30	8A
0005433251730	15024	31	8C
0005434907203	15024	32	8D
0005434907171	15024	33	8E
0005434907124	15024	34	8F
0005434906950	15024	35	9A
0005433251735	15024	36	9C
0005433251727	15024	37	9D
0005434907164	15024	38	9F
0005434907036	15024	39	10A
0005434907194	15024	40	10C
0005434907035	15024	41	10E
0005433251732	15024	42	10F
0005433251747	15024	43	11A
0005434907236	15024	44	11C
0005434907223	15024	45	11F
0005434907099	15024	46	12A
0005434907231	15024	47	12C
0005434907151	15024	48	12D
0005434907114	15024	49	12E
0005433251737	15024	50	12F
0005433251738	15024	51	13A
0005433251742	15024	52	13C
0005433251728	15024	53	13D
0005433251729	15024	54	13E
0005433251724	15024	55	13F
0005433251720	15024	56	14A
0005433251723	15024	57	14C
0005433251743	15024	58	14D
0005434906929	15024	59	14E
0005433251718	15024	60	14F
0005434907115	15024	61	15C
0005434907135	15024	62	15A
0005434907168	15024	63	15D
0005433251741	15024	64	15E
0005434907063	15024	65	15F
0005434907220	15024	66	16A
0005434907058	15024	67	16C
0005434907163	15024	68	16D
0005434907083	15024	69	16E
0005433251734	15024	70	17A
0005434907204	15024	71	17C
0005433251745	15024	72	17D
0005433251739	15024	73	17F
0005434907238	15024	74	18A
0005434907278	15024	75	18C
0005433251721	15024	76	18D
0005434907033	15024	77	18F
0005434907232	15024	78	19A
0005434906949	15024	79	19C
0005434907206	15024	80	19D
0005434907229	15024	81	19E
0005434907195	15024	82	19F
0005434907179	15024	83	20A
0005433251722	15024	84	20E
0005434907133	15024	85	20F
0005434907685	25865	1	1A
0005434907686	25865	2	1C
0005433251442	25865	3	1D
0005434907706	25865	4	1F
0005433251412	25865	5	2A
0005433251572	25865	6	2C
0005434907691	25865	7	2D
0005433251458	25865	8	2F
0005434907678	25865	9	3A
0005434907700	25865	10	3C
0005434907655	25865	11	3D
0005434907657	25865	12	3F
0005434907701	25865	13	4A
0005434907668	25865	14	4C
0005433251441	25865	15	4D
0005433251463	25865	16	4E
0005433251468	25865	17	4F
0005434907654	25865	18	5A
0005434907681	25865	19	5C
0005433251395	25865	20	5D
0005434907679	25865	21	5E
0005434907684	25865	22	5F
0005433251527	25865	23	6A
0005434907671	25865	24	6C
0005433251470	25865	25	6D
0005434907683	25865	26	6E
0005434907689	25865	27	6F
0005433251320	25865	28	7A
0005434907674	25865	29	7C
0005433251464	25865	30	7D
0005433251448	25865	31	7E
0005434907662	25865	32	7F
0005433251524	25865	33	8A
0005433251413	25865	34	8C
0005433251495	25865	35	8D
0005434907696	25865	36	8E
0005434907698	25865	37	8F
0005433251459	25865	38	9A
0005434907665	25865	39	9C
0005434907687	25865	40	9D
0005434907659	25865	41	9E
0005434907694	25865	42	9F
0005434907673	25865	43	10A
0005433251465	25865	44	10C
0005434907688	25865	45	10D
0005434907682	25865	46	10E
0005433251352	25865	47	11A
0005433251487	25865	48	11C
0005434907667	25865	49	11D
0005434907703	25865	50	11E
0005434907690	25865	51	11F
0005434907697	25865	52	12A
0005433251381	25865	53	12C
0005433251506	25865	54	12D
0005434907669	25865	55	12E
0005433251247	25865	56	12F
0005434907705	25865	57	13A
0005434907704	25865	58	13C
0005433251450	25865	59	13D
0005434907702	25865	60	13F
0005433251469	25865	61	14A
0005434907664	25865	62	14C
0005433251343	25865	63	14F
0005434907661	25865	64	15A
0005434907676	25865	65	15C
0005433251526	25865	66	15D
0005433251485	25865	67	15E
0005434907695	25865	68	15F
0005434907660	25865	69	16A
0005433251467	25865	70	16C
0005433251525	25865	71	16E
0005434907677	25865	72	16F
0005434907680	25865	73	17A
0005434907666	25865	74	17C
0005433251445	25865	75	17D
0005434907656	25865	76	17E
0005434907672	25865	77	17F
0005434907670	25865	78	18C
0005433251443	25865	79	18D
0005434907663	25865	80	18E
0005434907658	25865	81	18F
0005434907692	25865	82	19A
0005433251589	25865	83	19C
0005433251540	25865	84	19D
0005434907699	25865	85	19E
0005433251494	25865	86	20C
0005434907693	25865	87	20E
0005434907675	25865	88	20F
0005433810515	14201	1	1A
0005433008988	14201	2	1C
0005433008989	14201	3	1D
0005433009018	14201	4	1F
0005433008995	14201	5	2C
0005433009022	14201	6	2D
0005433009017	14201	7	3D
0005433008990	14201	8	4E
0005433009021	14201	9	5C
0005433008983	14201	10	5E
0005433009006	14201	11	5F
0005433008986	14201	12	6C
0005433008985	14201	13	6E
0005433009013	14201	14	6F
0005433009023	14201	15	7A
0005433009019	14201	16	7D
0005433009026	14201	17	7F
0005433009007	14201	18	8A
0005433009025	14201	19	8D
0005433009015	14201	20	8E
0005433009010	14201	21	9D
0005433810516	14201	22	10A
0005433009009	14201	23	10C
0005433810525	14201	24	10E
0005433009002	14201	25	10F
0005433009001	14201	26	11C
0005433008997	14201	27	11F
0005433009000	14201	28	12A
0005433009027	14201	29	12C
0005433009016	14201	30	12D
0005433009014	14201	31	12F
0005433008987	14201	32	13A
0005433009012	14201	33	13E
0005433009003	14201	34	14A
0005433008999	14201	35	14E
0005433008994	14201	36	15D
0005433009011	14201	37	15E
0005433009008	14201	38	15F
0005433009024	14201	39	16C
0005433008984	14201	40	16E
0005433008982	14201	41	17C
0005433008991	14201	42	17E
0005433008992	14201	43	18A
0005433009005	14201	44	18C
0005433008996	14201	45	18E
0005433009020	14201	46	19C
0005433008993	14201	47	19F
0005433009004	14201	48	20A
0005433008998	14201	49	20C
0005433810524	14201	50	20D
0005433008674	22832	1	1A
0005433008516	22832	2	1C
0005433008573	22832	3	1F
0005433008620	22832	4	2D
0005433810578	22832	5	2F
0005433810579	22832	6	3D
0005433008409	22832	7	3F
0005433008557	22832	8	4A
0005433008485	22832	9	4C
0005433008427	22832	10	4D
0005433008531	22832	11	4F
0005433008621	22832	12	5A
0005433008660	22832	13	5C
0005433008387	22832	14	5E
0005433008551	22832	15	5F
0005433008675	22832	16	6A
0005433008629	22832	17	6F
0005433008617	22832	18	7A
0005433008431	22832	19	7E
0005433008702	22832	20	8A
0005433008566	22832	21	8D
0005433008546	22832	22	8E
0005433008570	22832	23	9C
0005433008593	22832	24	10C
0005433008673	22832	25	10D
0005433008786	22832	26	10E
0005433008410	22832	27	11E
0005433008701	22832	28	12A
0005433008596	22832	29	12D
0005433008524	22832	30	12F
0005433008484	22832	31	13A
0005433008451	22832	32	13D
0005433008407	22832	33	13E
0005433008540	22832	34	14C
0005433008483	22832	35	14E
0005433008497	22832	36	15D
0005433008622	22832	37	15E
0005433008572	22832	38	15F
0005433008567	22832	39	16D
0005433008537	22832	40	16E
0005433008406	22832	41	17A
0005433008634	22832	42	17D
0005433008388	22832	43	17E
0005433008594	22832	44	18C
0005433008328	22832	45	18F
0005433008430	22832	46	19C
0005433008602	22832	47	19E
0005433008539	22832	48	19F
0005433008428	22832	49	20C
0005433008529	22832	50	20D
0005433008785	22832	51	20E
0005433008611	22832	52	20F
0005434925607	14929	1	3A
0005434925711	14929	2	3F
0005434925689	14929	3	8D
0005434925715	14929	4	8F
0005434925668	14929	5	9F
0005434925695	14929	6	10E
0005434925709	14929	7	11C
0005434925697	14929	8	11D
0005434925688	14929	9	12A
0005434925609	14929	10	12C
0005434925669	14929	11	13C
0005434925698	14929	12	13D
0005434925610	14929	13	14D
0005434925690	14929	14	14E
0005434925708	14929	15	15C
0005434925714	14929	16	19F
0005434925696	14929	17	20C
0005434926045	20497	1	1D
0005434926040	20497	2	4C
0005434926042	20497	3	5C
0005434926046	20497	4	5E
0005434926043	20497	5	6E
0005434926055	20497	6	7A
0005434926050	20497	7	6F
0005434926048	20497	8	8A
0005434926037	20497	9	8E
0005434926056	20497	10	9A
0005434926053	20497	11	9D
0005434926034	20497	12	9E
0005434926044	20497	13	10A
0005434926027	20497	14	10C
0005434926041	20497	15	10D
0005434926030	20497	16	10F
0005434926058	20497	17	11A
0005434926029	20497	18	11C
0005434926026	20497	19	12A
0005434926033	20497	20	12C
0005434926039	20497	21	12D
0005434926028	20497	22	12E
0005434926049	20497	23	12F
0005434926038	20497	24	13A
0005434926054	20497	25	13E
0005434926051	20497	26	14E
0005434926047	20497	27	15F
0005434926032	20497	28	16A
0005434926036	20497	29	16D
0005434926059	20497	30	16F
0005434926052	20497	31	18C
0005434926057	20497	32	18D
0005434926035	20497	33	19A
0005434926031	20497	34	20F
0005435999218	15826	1	1A
0005435488025	15826	2	1B
0005435488028	15826	3	1C
0005435488016	15826	4	2A
0005435488013	15826	5	2B
0005435999191	15826	6	2D
0005435999220	15826	7	3B
0005435488018	15826	8	3C
0005435488019	15826	9	3D
0005435488026	15826	10	4A
0005435488014	15826	11	4B
0005435999208	15826	12	4C
0005435488021	15826	13	4D
0005435999250	15826	14	5A
0005435999209	15826	15	5B
0005435488007	15826	16	5D
0005435999243	15826	17	5C
0005435999244	15826	18	6A
0005435488027	15826	19	6B
0005435488012	15826	20	6D
0005435999251	15826	21	7A
0005435999225	15826	22	7B
0005435488010	15826	23	7C
0005435999247	15826	24	7D
0005435488031	15826	25	18A
0005435999245	15826	26	18B
0005435999232	15826	27	18C
0005435488009	15826	28	18D
0005435488015	15826	29	19C
0005435488020	15826	30	19D
0005435488008	15826	31	20B
0005435999183	15826	32	20C
0005435999219	15826	33	20D
0005435488029	15826	34	21B
0005435488023	15826	35	21C
0005435488011	15826	36	21D
0005435488024	15826	37	22A
0005435999239	15826	38	22C
0005435488030	15826	39	22D
0005435488017	15826	40	23A
0005435488022	15826	41	23B
0005435487754	19693	1	1B
0005435487772	19693	2	1C
0005435487779	19693	3	1D
0005435999381	19693	4	2A
0005435487681	19693	5	2B
0005435487775	19693	6	2C
0005435487800	19693	7	2D
0005435487802	19693	8	3A
0005435487680	19693	9	3B
0005435999384	19693	10	4A
0005435487885	19693	11	4C
0005435999383	19693	12	5A
0005435487767	19693	13	5B
0005435487804	19693	14	5C
0005435487773	19693	15	5D
0005435487711	19693	16	6C
0005435999382	19693	17	7C
0005435487710	19693	18	7D
0005435487682	19693	19	18B
0005435487778	19693	20	18C
0005435487796	19693	21	18D
0005435487839	19693	22	19B
0005435487776	19693	23	19C
0005435487827	19693	24	19D
0005435487811	19693	25	20A
0005435487887	19693	26	20B
0005435487886	19693	27	20C
0005435487668	19693	28	20D
0005435487747	19693	29	21A
0005435487718	19693	30	21B
0005435487795	19693	31	21C
0005435487794	19693	32	21D
0005435487812	19693	33	22B
0005435487756	19693	34	22A
0005435487768	19693	35	22C
0005435487777	19693	36	22D
0005435487799	19693	37	23B
0005435487919	19693	38	23A
0005435839695	5985	1	1C
0005435472843	5985	2	1A
0005435472842	5985	3	1D
0005435839702	5985	4	2A
0005432537058	5985	5	2D
0005435839698	5985	6	3A
0005435839697	5985	7	2F
0005435839691	5985	8	3C
0005435839704	5985	9	4A
0005432537055	5985	10	3F
0005435472823	5985	11	5A
0005435472803	5985	12	6B
0005435839705	5985	13	6E
0005435472835	5985	14	7C
0005435839692	5985	15	7B
0005432537056	5985	16	7E
0005435839696	5985	17	7F
0005435839680	5985	18	8D
0005435472804	5985	19	8F
0005435839694	5985	20	8E
0005435839703	5985	21	9A
0005435472798	5985	22	9C
0005435839699	5985	23	9E
0005435839700	5985	24	9D
0005432658611	5985	25	10B
0005435472759	5985	26	10D
0005435472793	5985	27	11B
0005435839682	5985	28	11D
0005435472750	5985	29	12B
0005435839688	5985	30	12A
0005435839684	5985	31	12D
0005435839687	5985	32	12C
0005435472723	5985	33	13B
0005435839683	5985	34	12F
0005432658609	5985	35	13C
0005435839679	5985	36	13E
0005432659725	5985	37	14E
0005435839686	5985	38	14C
0005432660837	5985	39	14F
0005432142277	5985	40	15B
0005435472735	5985	41	15A
0005435839681	5985	42	15C
0005432537044	5985	43	16B
0005435472786	5985	44	16A
0005435839701	5985	45	16E
0005432142279	5985	46	16D
0005435839677	5985	47	16C
0005435472782	5985	48	17A
0005432142278	5985	49	16F
0005435839690	5985	50	17B
0005435472736	5985	51	17F
0005435839693	5985	52	18A
0005435839678	5985	53	18B
0005432658610	5985	54	18F
0005435472807	5985	55	19F
0005435472787	5985	56	20F
0005435472799	5985	57	21B
0005435839689	5985	58	21D
0005435839685	5985	59	21C
0005432660838	5985	60	21E
0005435472935	18059	1	1A
0005435839399	18059	2	1F
0005435839481	18059	3	1D
0005435839337	18059	4	1C
0005435839563	18059	5	2C
0005435839492	18059	6	2A
0005435472941	18059	7	3A
0005435839373	18059	8	2F
0005435839441	18059	9	4D
0005435472947	18059	10	5C
0005435839338	18059	11	5A
0005435839412	18059	12	5F
0005435472949	18059	13	6B
0005435839432	18059	14	6D
0005435472936	18059	15	6F
0005435472940	18059	16	7B
0005435839382	18059	17	7E
0005435472950	18059	18	7F
0005435472934	18059	19	8B
0005435472943	18059	20	8D
0005435839434	18059	21	8F
0005435472944	18059	22	9A
0005435839440	18059	23	10B
0005435472942	18059	24	9F
0005435472937	18059	25	10E
0005432537077	18059	26	11D
0005435839537	18059	27	11C
0005432660818	18059	28	11F
0005435839500	18059	29	11E
0005432667451	18059	30	12D
0005435472938	18059	31	12E
0005432537078	18059	32	13A
0005435472939	18059	33	12F
0005435472951	18059	34	13C
0005435839445	18059	35	13B
0005432537076	18059	36	13E
0005435839484	18059	37	13F
0005432660814	18059	38	14B
0005435839456	18059	39	14D
0005435839461	18059	40	14C
0005435472946	18059	41	14F
0005435839372	18059	42	14E
0005435839407	18059	43	15B
0005435839499	18059	44	15D
0005435839471	18059	45	16A
0005435839470	18059	46	16E
0005435839377	18059	47	17B
0005432660813	18059	48	17F
0005435839482	18059	49	18D
0005435472945	18059	50	18E
0005435839462	18059	51	19A
0005435839494	18059	52	19B
0005435839519	18059	53	19F
0005435839480	18059	54	20B
0005432660817	18059	55	20A
0005435839536	18059	56	20D
0005435839437	18059	57	20E
0005435472948	18059	58	21A
0005432667450	18059	59	20F
0005435839485	18059	60	21C
0005435839457	18059	61	21B
0005432667452	18059	62	21E
0005435839433	18059	63	21F
0005433285291	23040	1	2A
0005433285240	23040	2	2D
0005433285407	23040	3	2F
0005433285214	23040	4	3F
0005433285222	23040	5	4B
0005433285349	23040	6	4C
0005433285123	23040	7	4E
0005433285234	23040	8	4D
0005433285331	23040	9	5C
0005433285207	23040	10	5D
0005433285345	23040	11	5F
0005433285286	23040	12	5E
0005433285247	23040	13	7E
0005435103984	23040	14	8C
0005433285406	23040	15	8E
0005433285348	23040	16	9F
0005433285315	23040	17	10D
0005433285126	23040	18	11E
0005433285174	23040	19	12D
0005433285351	23040	20	12C
0005433285390	23040	21	12E
0005433285324	23040	22	13C
0005435103985	23040	23	14B
0005433285347	23040	24	14A
0005433285352	23040	25	14C
0005433285242	23040	26	14E
0005433285328	23040	27	14F
0005433285292	23040	28	15A
0005433285346	23040	29	15B
0005433285217	23040	30	16B
0005433285321	23040	31	16F
0005433285124	23040	32	17B
0005433285391	23040	33	17E
0005433285294	23040	34	17F
0005433285312	23040	35	18B
0005433285317	23040	36	18D
0005433285316	23040	37	19D
0005433285206	23040	38	19E
0005433285246	23040	39	20E
0005433285293	23040	40	21B
0005435103986	23040	41	21F
0005433285341	23040	42	22A
0005433285327	23040	43	23A
0005433285376	23040	44	23C
0005435103983	23040	45	23E
0005433285125	23040	46	23D
0005433285218	23040	47	23F
0005433285554	32085	1	1C
0005433285563	32085	2	2A
0005433285572	32085	3	2C
0005433285568	32085	4	2F
0005433285570	32085	5	4C
0005435103906	32085	6	4F
0005433285574	32085	7	5A
0005435103878	32085	8	5D
0005435103879	32085	9	5F
0005433285556	32085	10	6C
0005433285580	32085	11	6D
0005433285561	32085	12	7D
0005433285559	32085	13	8E
0005433285552	32085	14	9A
0005433285575	32085	15	10B
0005433285571	32085	16	12D
0005433285573	32085	17	12E
0005433285560	32085	18	13D
0005433285581	32085	19	13F
0005433285555	32085	20	14B
0005433285569	32085	21	14D
0005435103884	32085	22	15C
0005433285579	32085	23	16E
0005433285567	32085	24	16F
0005433285565	32085	25	17F
0005433285557	32085	26	17E
0005433285551	32085	27	18A
0005433285553	32085	28	18D
0005433285566	32085	29	18F
0005433285578	32085	30	20E
0005433285558	32085	31	21C
0005433285577	32085	32	21F
0005433285576	32085	33	22E
0005435103905	32085	34	23C
0005433285562	32085	35	23D
0005433285564	32085	36	23E
0005435214197	30611	1	1D
0005432527527	30611	2	1A
0005432528195	30611	3	1G
0005432527777	30611	4	2A
0005432527615	30611	5	1K
0005434067691	30611	6	1H
0005432528299	30611	7	2D
0005432528336	30611	8	2C
0005435214198	30611	9	2G
0005432527714	30611	10	3A
0005434067705	30611	11	2K
0005432527782	30611	12	3D
0005432527840	30611	13	3C
0005432528818	30611	14	3K
0005435214143	30611	15	3H
0005432528010	30611	16	3G
0005434067584	30611	17	4C
0005435214168	30611	18	4A
0005435214133	30611	19	4G
0005432527918	30611	20	4D
0005432527599	30611	21	4K
0005432528265	30611	22	4H
0005432528287	30611	23	5C
0005435214184	30611	24	5A
0005434067548	30611	25	5H
0005434067768	30611	26	5D
0005432527865	30611	27	11A
0005432528264	30611	28	11D
0005432211571	30611	29	11F
0005432528650	30611	30	11E
0005432527863	30611	31	11H
0005435214195	30611	32	11G
0005432528306	30611	33	12C
0005432527859	30611	34	12A
0005435214149	30611	35	11K
0005432527833	30611	36	12D
0005435214148	30611	37	12G
0005432211567	30611	38	12F
0005435214164	30611	39	13A
0005432527903	30611	40	12K
0005435214173	30611	41	12H
0005435214169	30611	42	13D
0005432527997	30611	43	13F
0005434067405	30611	44	13H
0005435214167	30611	45	13G
0005432528300	30611	46	14C
0005432528232	30611	47	13K
0005432527874	30611	48	14K
0005432527742	30611	49	14G
0005432527990	30611	50	15A
0005432528304	30611	51	15E
0005432527924	30611	52	15D
0005433656701	30611	53	15H
0005432527835	30611	54	15G
0005432528697	30611	55	15F
0005434067061	30611	56	15K
0005434067673	30611	57	16D
0005432528297	30611	58	16C
0005435214185	30611	59	16F
0005432527824	30611	60	16E
0005432527544	30611	61	16K
0005434067387	30611	62	16H
0005432528329	30611	63	16G
0005432527875	30611	64	17C
0005432527741	30611	65	17A
0005433656703	30611	66	17E
0005435214146	30611	67	17D
0005432528080	30611	68	17G
0005432528363	30611	69	18A
0005432527348	30611	70	17K
0005432527906	30611	71	17H
0005432527892	30611	72	18C
0005432528399	30611	73	18D
0005434067794	30611	74	18G
0005432211568	30611	75	18F
0005432528125	30611	76	18H
0005435214132	30611	77	19A
0005432528313	30611	78	18K
0005435214181	30611	79	19D
0005432527856	30611	80	19C
0005432528397	30611	81	19F
0005432528244	30611	82	19E
0005434067513	30611	83	19H
0005432528001	30611	84	20A
0005432527934	30611	85	19K
0005432528075	30611	86	19J
0005432528231	30611	87	20C
0005432537066	30611	88	20B
0005432527860	30611	89	20D
0005434067324	30611	90	20H
0005432527839	30611	91	20G
0005435214161	30611	92	20F
0005432537062	30611	93	20J
0005435214135	30611	94	21B
0005432528296	30611	95	21A
0005432527670	30611	96	20K
0005435725648	30611	97	21D
0005432527783	30611	98	21C
0005432528126	30611	99	21F
0005432527995	30611	100	21E
0005432528447	30611	101	21H
0005432533297	30611	102	21G
0005432527896	30611	103	22A
0005434067647	30611	104	21K
0005435214177	30611	105	22D
0005432535824	30611	106	22B
0005435214145	30611	107	22E
0005432535835	30611	108	22G
0005434067442	30611	109	22F
0005432527987	30611	110	22K
0005432527974	30611	111	22J
0005435214196	30611	112	22H
0005432527781	30611	113	23B
0005435214187	30611	114	23A
0005435214165	30611	115	23E
0005432527570	30611	116	23D
0005432211569	30611	117	23C
0005435630995	30611	118	23G
0005435214137	30611	119	23J
0005435630996	30611	120	23H
0005435214188	30611	121	24D
0005434067560	30611	122	23K
0005432528459	30611	123	24E
0005434067512	30611	124	25A
0005434067302	30611	125	25D
0005434067406	30611	126	25C
0005432527479	30611	127	25E
0005434067593	30611	128	25H
0005432528245	30611	129	25G
0005432428935	30611	130	26A
0005435214183	30611	131	25K
0005432428932	30611	132	25J
0005432528064	30611	133	26B
0005435214158	30611	134	26E
0005432528337	30611	135	26D
0005432527838	30611	136	26C
0005432159897	30611	137	26G
0005435214190	30611	138	26F
0005435214176	30611	139	26K
0005432527976	30611	140	26J
0005435725645	30611	141	27A
0005432528123	30611	142	27C
0005432428938	30611	143	27B
0005435214138	30611	144	27F
0005434067658	30611	145	27D
0005434067696	30611	146	27H
0005434067641	30611	147	27G
0005432527955	30611	148	28A
0005432527775	30611	149	27K
0005432528699	30611	150	27J
0005432527844	30611	151	28C
0005434067511	30611	152	28B
0005432527847	30611	153	28D
0005435214179	30611	154	28G
0005435214155	30611	155	28F
0005432528298	30611	156	28K
0005434067721	30611	157	28J
0005432528327	30611	158	28H
0005432527808	30611	159	29A
0005435214162	30611	160	29D
0005432527926	30611	161	29C
0005434067496	30611	162	29F
0005432428936	30611	163	29E
0005434067689	30611	164	29H
0005434067184	30611	165	29K
0005432535819	30611	166	29J
0005432527845	30611	167	30C
0005432528553	30611	168	30B
0005432528330	30611	169	30A
0005432528181	30611	170	30E
0005435214142	30611	171	30G
0005432528060	30611	172	30J
0005432537060	30611	173	31A
0005434067378	30611	174	30K
0005432527698	30611	175	31C
0005432535852	30611	176	31B
0005435725649	30611	177	31F
0005432535851	30611	178	31E
0005432527846	30611	179	31D
0005435214139	30611	180	31G
0005432527633	30611	181	32B
0005432428931	30611	182	32A
0005435214186	30611	183	32E
0005435214152	30611	184	32D
0005432528688	30611	185	32G
0005435214140	30611	186	32F
0005435214157	30611	187	32J
0005435725647	30611	188	32H
0005434067238	30611	189	33A
0005435214178	30611	190	33C
0005432527480	30611	191	33B
0005435214160	30611	192	33F
0005434067275	30611	193	33E
0005432159901	30611	194	33G
0005432527977	30611	195	33K
0005434067379	30611	196	33J
0005432527973	30611	197	34C
0005432528016	30611	198	34A
0005435214154	30611	199	34E
0005435214182	30611	200	34D
0005435214131	30611	201	34F
0005432528150	30611	202	34J
0005435214174	30611	203	35B
0005432528371	30611	204	35A
0005435214171	30611	205	34K
0005435214141	30611	206	35D
0005435214134	30611	207	35C
0005432527864	30611	208	35F
0005432528186	30611	209	35J
0005434067640	30611	210	35H
0005432528527	30611	211	35G
0005434067386	30611	212	36A
0005435214199	30611	213	35K
0005434067648	30611	214	36C
0005432528689	30611	215	36B
0005432527843	30611	216	36E
0005432527994	30611	217	36D
0005432528698	30611	218	36G
0005434067573	30611	219	36F
0005432527925	30611	220	36K
0005432159899	30611	221	36J
0005434067704	30611	222	36H
0005435214153	30611	223	37B
0005432528506	30611	224	37A
0005432528002	30611	225	37D
0005435725644	30611	226	37C
0005434067657	30611	227	37F
0005434067439	30611	228	37E
0005432528141	30611	229	37J
0005434067529	30611	230	37H
0005432528266	30611	231	37G
0005432528130	30611	232	38A
0005434067574	30611	233	38C
0005435214189	30611	234	38B
0005434067435	30611	235	38H
0005432527895	30611	236	39B
0005434067549	30611	237	39A
0005435214193	30611	238	38K
0005432528011	30611	239	39D
0005432537067	30611	240	39F
0005432211572	30611	241	39E
0005432528566	30611	242	39H
0005435214170	30611	243	39G
0005434067468	30611	244	39K
0005432211570	30611	245	39J
0005434067281	30611	246	40C
0005435214200	30611	247	40B
0005432528312	30611	248	40G
0005435214192	30611	249	40F
0005432527654	30611	250	40J
0005432528372	30611	251	40H
0005435214172	30611	252	41D
0005432527571	30611	253	41C
0005432528303	30611	254	41F
0005434067362	30611	255	41E
0005432527919	30611	256	41H
0005432528051	30611	257	42A
0005432528052	30611	258	41K
0005432537059	30611	259	42C
0005432528819	30611	260	42B
0005435214150	30611	261	42E
0005435214159	30611	262	42D
0005432528420	30611	263	42G
0005432527526	30611	264	42F
0005432528454	30611	265	42J
0005432535833	30611	266	42H
0005435214147	30611	267	42K
0005432528008	30611	268	43D
0005432527983	30611	269	43C
0005432527669	30611	270	43B
0005432528396	30611	271	43F
0005432528328	30611	272	43E
0005432527965	30611	273	43J
0005432528111	30611	274	43H
0005434067323	30611	275	43G
0005432159898	30611	276	43K
0005435214194	30611	277	44A
0005432528129	30611	278	44D
0005432528692	30611	279	44C
0005434067603	30611	280	44H
0005434067453	30611	281	44G
0005435214175	30611	282	44K
0005432159900	30611	283	44J
0005434067301	30611	284	45B
0005432527999	30611	285	45A
0005432528149	30611	286	45C
0005434067437	30611	287	45F
0005432527456	30611	288	45E
0005434067062	30611	289	45H
0005432528411	30611	290	45G
0005432528305	30611	291	45K
0005432528059	30611	292	46A
0005432528423	30611	293	46E
0005434067690	30611	294	46D
0005432528124	30611	295	46G
0005432527962	30611	296	46F
0005432211573	30611	297	46J
0005432528099	30611	298	46H
0005432527989	30611	299	47C
0005432428937	30611	300	47A
0005435214136	30611	301	47E
0005434067438	30611	302	47D
0005432528455	30611	303	47F
0005432528505	30611	304	47K
0005434067815	30611	305	48D
0005435214144	30611	306	48C
0005435214166	30611	307	48A
0005434067372	30611	308	48E
0005432527996	30611	309	48H
0005435214180	30611	310	48G
0005432527382	30611	311	49A
0005432527964	30611	312	48K
0005432528230	30611	313	49E
0005432528112	30611	314	49D
0005435725646	30611	315	49C
0005434067487	30611	316	49G
0005435214191	30611	317	49K
0005435630994	30611	318	49H
0005435214156	30611	319	50C
0005432527632	30611	320	50A
0005434067590	30611	321	50E
0005432527963	30611	322	50H
0005432528213	30611	323	50G
0005432528421	30611	324	51D
0005435214163	30611	325	50K
0005433656702	30611	326	51E
0005435214151	30611	327	51G
0005435653066	24869	1	1A
0005435652941	24869	2	1C
0005435653001	24869	3	1D
0005435653137	24869	4	1F
0005433368239	24869	5	2A
0005435653052	24869	6	2C
0005433368218	24869	7	2D
0005435653039	24869	8	2F
0005435653123	24869	9	3A
0005433368251	24869	10	3C
0005435653124	24869	11	3D
0005435653151	24869	12	3F
0005435653134	24869	13	4A
0005433368244	24869	14	4C
0005433368228	24869	15	4D
0005435653116	24869	16	4E
0005433368241	24869	17	4F
0005435652922	24869	18	5A
0005433368223	24869	19	5C
0005435652993	24869	20	5D
0005433368234	24869	21	5E
0005435653088	24869	22	5F
0005435653031	24869	23	6A
0005433368242	24869	24	6C
0005433368222	24869	25	6D
0005435653067	24869	26	6F
0005433368233	24869	27	7D
0005435652991	24869	28	7E
0005435653005	24869	29	7F
0005433368221	24869	30	8A
0005433368248	24869	31	8D
0005435652937	24869	32	8E
0005435653069	24869	33	9A
0005435652962	24869	34	9C
0005435653078	24869	35	9F
0005433368252	24869	36	10A
0005433368224	24869	37	10C
0005435652992	24869	38	10D
0005435653150	24869	39	10F
0005433368247	24869	40	10E
0005433368227	24869	41	11A
0005435653142	24869	42	11D
0005433368217	24869	43	11F
0005433368220	24869	44	12A
0005433368231	24869	45	12C
0005435652990	24869	46	12D
0005435653053	24869	47	12E
0005433368225	24869	48	12F
0005433368226	24869	49	13A
0005435653152	24869	50	13C
0005435652981	24869	51	13D
0005433368219	24869	52	13E
0005433368249	24869	53	13F
0005435653138	24869	54	14A
0005435653093	24869	55	14C
0005433368236	24869	56	14D
0005433368240	24869	57	14E
0005433368253	24869	58	14F
0005435653092	24869	59	15C
0005435653112	24869	60	15D
0005435653004	24869	61	15E
0005435653070	24869	62	15F
0005435653153	24869	63	16A
0005433368237	24869	64	16C
0005435653029	24869	65	16E
0005435653136	24869	66	16F
0005433368245	24869	67	17A
0005433368243	24869	68	17C
0005433368230	24869	69	17D
0005435652982	24869	70	17E
0005433368229	24869	71	17F
0005435653111	24869	72	18A
0005435653086	24869	73	18C
0005435653022	24869	74	18D
0005433368235	24869	75	18E
0005435653087	24869	76	18F
0005435653038	24869	77	19A
0005435652963	24869	78	19C
0005435653030	24869	79	19D
0005433368254	24869	80	19E
0005433368232	24869	81	19F
0005433368250	24869	82	20D
0005433368246	24869	83	20E
0005433368238	24869	84	20F
0005435801725	2050	1	1A
0005434980062	2050	2	1B
0005434980079	2050	3	2C
0005434980053	2050	4	2D
0005434980064	2050	5	3A
0005434980073	2050	6	3B
0005434980054	2050	7	3C
0005434980078	2050	8	3D
0005434980071	2050	9	5A
0005434980063	2050	10	5B
0005434980065	2050	11	5C
0005434980056	2050	12	5D
0005434980076	2050	13	6A
0005434980075	2050	14	6C
0005434980074	2050	15	6D
0005434980077	2050	16	7A
0005434980082	2050	17	7C
0005434980072	2050	18	7D
0005434980057	2050	19	18A
0005434980068	2050	20	18B
0005434980069	2050	21	18C
0005434980052	2050	22	18D
0005434980059	2050	23	19A
0005434980055	2050	24	19B
0005434980066	2050	25	19C
0005434980081	2050	26	19D
0005435801724	2050	27	20A
0005434980058	2050	28	20B
0005434980070	2050	29	20C
0005434980060	2050	30	20D
0005434980080	2050	31	21B
0005434980067	2050	32	21C
0005435801726	2050	33	21D
0005434980061	2050	34	22C
0005435801723	2050	35	23A
0005434979690	23557	1	1A
0005434979715	23557	2	1B
0005434979723	23557	3	2A
0005434979651	23557	4	2C
0005435801690	23557	5	3D
0005434979682	23557	6	4A
0005434979737	23557	7	4B
0005434979725	23557	8	4C
0005434979792	23557	9	4D
0005434979681	23557	10	5B
0005434979747	23557	11	5C
0005434979821	23557	12	5D
0005434979624	23557	13	6B
0005434979680	23557	14	6D
0005434979691	23557	15	7B
0005434979724	23557	16	7D
0005434979735	23557	17	18A
0005434979770	23557	18	18B
0005434979801	23557	19	18C
0005434979879	23557	20	19B
0005434979814	23557	21	19D
0005434979642	23557	22	20A
0005434979650	23557	23	20B
0005434979683	23557	24	20C
0005434979769	23557	25	21A
0005434979878	23557	26	21B
0005434979796	23557	27	21C
0005434979705	23557	28	21D
0005434979655	23557	29	22A
0005434979795	23557	30	22B
0005434979703	23557	31	22C
0005434979704	23557	32	23A
0005434952566	2644	1	2A
0005434952564	2644	2	2B
0005434952567	2644	3	5B
0005434952565	2644	4	6B
0005433256430	2631	1	3B
0005434952523	28270	1	1A
0005434952540	28270	2	3B
0005434952541	28270	3	4A
0005434952533	28270	4	4B
0005433256443	28270	5	5B
0005434952528	28270	6	6A
0005433256442	28270	7	6B
0005433112389	19773	1	1A
0005433111526	19773	2	2A
0005433112388	19773	3	3A
0005434302870	19773	4	3B
0005433111527	19773	5	4B
0005434302862	19773	6	6A
0005434137905	11918	1	1A
0005434138031	11918	2	1D
0005434138372	11918	3	1F
0005434138173	11918	4	2A
0005434138091	11918	5	2C
0005434138044	11918	6	2D
0005434138029	11918	7	2F
0005434138036	11918	8	3A
0005434138176	11918	9	3C
0005434138042	11918	10	3D
0005434138055	11918	11	3F
0005434138319	11918	12	4A
0005434137960	11918	13	4C
0005434138373	11918	14	4D
0005434137841	11918	15	4E
0005434138128	11918	16	4F
0005434138026	11918	17	5A
0005434138089	11918	18	5D
0005434138276	11918	19	5E
0005434138104	11918	20	5F
0005434138387	11918	21	6A
0005434138374	11918	22	6C
0005434138117	11918	23	6D
0005434138343	11918	24	6E
0005434137842	11918	25	6F
0005434138341	11918	26	7A
0005434138225	11918	27	7C
0005434138326	11918	28	7D
0005434138163	11918	29	7E
0005434138103	11918	30	8A
0005434137993	11918	31	8C
0005434138054	11918	32	8D
0005434138144	11918	33	8E
0005434138164	11918	34	8F
0005434138363	11918	35	9C
0005434138037	11918	36	9D
0005434138315	11918	37	9E
0005434138335	11918	38	9F
0005434138194	11918	39	10A
0005434138025	11918	40	10C
0005434138183	11918	41	10D
0005434138084	11918	42	10E
0005434138388	11918	43	10F
0005434138138	11918	44	11A
0005434138207	11918	45	11E
0005434138226	11918	46	11F
0005434138153	11918	47	12A
0005434138156	11918	48	12D
0005434138295	11918	49	12E
0005434138270	11918	50	12F
0005434138361	11918	51	13A
0005434138059	11918	52	13C
0005434137994	11918	53	13D
0005434138043	11918	54	13E
0005434138290	11918	55	13F
0005434138377	11918	56	14A
0005434138254	11918	57	14C
0005434138083	11918	58	14D
0005434137939	11918	59	14E
0005434138172	11918	60	14F
0005434138143	11918	61	15A
0005434137940	11918	62	15C
0005434138314	11918	63	15D
0005434138379	11918	64	15E
0005434138061	11918	65	15F
0005434138056	11918	66	16A
0005434137906	11918	67	16D
0005434138154	11918	68	16E
0005434138259	11918	69	16F
0005434138196	11918	70	17A
0005434137953	11918	71	17C
0005434138182	11918	72	17D
0005434138090	11918	73	17E
0005434138165	11918	74	18A
0005434138162	11918	75	18C
0005434138320	11918	76	18D
0005434138307	11918	77	18E
0005434138285	11918	78	18F
0005434138280	11918	79	19A
0005434138306	11918	80	19C
0005434138187	11918	81	19D
0005434138378	11918	82	19E
0005434138155	11918	83	19F
0005434138206	11918	84	20C
0005434138166	11918	85	20D
0005434138334	11918	86	20E
0005434138286	11918	87	20F
0005434138857	28719	1	1A
0005434138863	28719	2	1C
0005434138885	28719	3	1D
0005434138826	28719	4	1F
0005434138875	28719	5	2A
0005434138887	28719	6	2C
0005434138837	28719	7	2D
0005434138822	28719	8	2F
0005434138859	28719	9	3A
0005434138862	28719	10	3C
0005434138810	28719	11	3D
0005434138866	28719	12	3F
0005434138841	28719	13	4A
0005434138829	28719	14	4C
0005434138872	28719	15	4E
0005434138856	28719	16	4F
0005434138819	28719	17	5A
0005434138839	28719	18	5C
0005434138828	28719	19	5D
0005434138867	28719	20	5E
0005434138892	28719	21	5F
0005434138861	28719	22	6A
0005434138833	28719	23	6D
0005434138865	28719	24	6E
0005434138886	28719	25	6F
0005434138840	28719	26	7A
0005434138814	28719	27	7C
0005434138858	28719	28	7D
0005434138816	28719	29	7E
0005434138825	28719	30	8A
0005434138836	28719	31	8C
0005434138838	28719	32	8D
0005434138820	28719	33	8E
0005434138811	28719	34	9A
0005434138842	28719	35	9C
0005434138849	28719	36	9D
0005434138845	28719	37	9E
0005434138860	28719	38	9F
0005434138817	28719	39	10A
0005434138876	28719	40	10C
0005434138864	28719	41	10D
0005434138855	28719	42	10F
0005434138850	28719	43	11A
0005434138818	28719	44	11C
0005434138809	28719	45	11D
0005434138808	28719	46	11E
0005434138827	28719	47	11F
0005434138823	28719	48	12A
0005434138807	28719	49	12C
0005434138868	28719	50	12E
0005434138884	28719	51	12F
0005434138877	28719	52	13A
0005434138812	28719	53	13C
0005434138832	28719	54	13D
0005434138893	28719	55	13E
0005434138883	28719	56	13F
0005434138882	28719	57	14A
0005434138871	28719	58	14C
0005434138878	28719	59	14D
0005434138891	28719	60	14F
0005434138844	28719	61	15A
0005434138843	28719	62	15C
0005434138870	28719	63	15D
0005434138848	28719	64	15E
0005434138879	28719	65	15F
0005434138830	28719	66	16A
0005434138851	28719	67	16C
0005434138854	28719	68	16E
0005434138835	28719	69	16F
0005434138888	28719	70	17A
0005434138852	28719	71	17C
0005434138824	28719	72	17D
0005434138869	28719	73	17E
0005434138815	28719	74	17F
0005434138821	28719	75	18A
0005434138813	28719	76	18C
0005434138847	28719	77	18D
0005434138846	28719	78	18E
0005434138881	28719	79	18F
0005434138834	28719	80	19A
0005434138853	28719	81	19C
0005434138874	28719	82	19E
0005434138880	28719	83	19F
0005434138890	28719	84	20A
0005434138889	28719	85	20C
0005434138873	28719	86	20D
0005434138831	28719	87	20E
0005433538950	6784	1	1B
0005433538949	6784	2	1C
0005433538948	6784	3	3D
0005433538954	6784	4	4B
0005435259756	6784	5	4D
0005433538947	6784	6	5C
0005435259748	6784	7	6C
0005435259754	6784	8	7D
0005433538953	6784	9	19A
0005433538952	6784	10	19B
0005435259761	6784	11	19D
0005433534518	6784	12	21A
0005435259772	6784	13	21B
0005433538951	6784	14	22A
0005435259755	6784	15	22D
0005433534495	25006	1	1B
0005435259797	25006	2	1C
0005433538859	25006	3	2A
0005433538894	25006	4	2B
0005433538846	25006	5	3B
0005433538834	25006	6	3C
0005435259799	25006	7	4B
0005435259796	25006	8	5A
0005435259795	25006	9	6C
0005433538845	25006	10	19B
0005433538886	25006	11	20B
0005435259798	25006	12	20C
0005433538850	25006	13	22C
0005433534496	25006	14	23A
0005433538847	25006	15	23B
0005432922523	818	1	2C
0005432922537	818	2	3D
0005432922545	818	3	4A
0005432922522	818	4	4B
0005433512032	818	5	5A
0005432922536	818	6	5B
0005433512033	818	7	6C
0005432922538	818	8	18B
0005433512028	818	9	20A
0005433512031	818	10	20C
0005433512027	818	11	20D
0005433512030	818	12	21A
0005433512029	818	13	23A
0005433511960	16176	1	1C
0005433511985	16176	2	2B
0005432922562	16176	3	3C
0005433511968	16176	4	3D
0005432922564	16176	5	5A
0005432922561	16176	6	6B
0005432922563	16176	7	7D
0005433511980	16176	8	18D
0005433511967	16176	9	19C
0005433511940	16176	10	20D
0005433511941	16176	11	21C
0005433511970	16176	12	21D
0005433511936	16176	13	22B
0005435852568	4030	1	1A
0005433475740	4030	2	1C
0005433475738	4030	3	3A
0005433475746	4030	4	3C
0005433475737	4030	5	4D
0005433475741	4030	6	5B
0005435852587	4030	7	5C
0005435852585	4030	8	5D
0005433475748	4030	9	6D
0005433475742	4030	10	7A
0005433475747	4030	11	7B
0005433475744	4030	12	7D
0005433475750	4030	13	18C
0005433475743	4030	14	18D
0005433475749	4030	15	19A
0005435852566	4030	16	19B
0005433475745	4030	17	20B
0005433475739	4030	18	20D
0005435852584	4030	19	23A
0005435935053	3694	1	1B
0005435697602	3694	2	1C
0005434950571	3694	3	1D
0005434950572	3694	4	2A
0005435697610	3694	5	2B
0005435697597	3694	6	2C
0005435697611	3694	7	3A
0005435697609	3694	8	3B
0005435697596	3694	9	3C
0005435697607	3694	10	4A
0005435697603	3694	11	4B
0005435697604	3694	12	4C
0005435697589	3694	13	5A
0005435697599	3694	14	4D
0005435935059	3694	15	5B
0005435916180	3694	16	5C
0005435697615	3694	17	5D
0005435935043	3694	18	6A
0005435916179	3694	19	6B
0005435697606	3694	20	6C
0005435697600	3694	21	6D
0005435697613	3694	22	7A
0005435697595	3694	23	7B
0005435697601	3694	24	7C
0005435697592	3694	25	7D
0005435916172	3694	26	18A
0005435697593	3694	27	18C
0005435697591	3694	28	18D
0005435935044	3694	29	19C
0005435935045	3694	30	19D
0005435697590	3694	31	20A
0005435697612	3694	32	20B
0005435697608	3694	33	20C
0005434950573	3694	34	20D
0005435697614	3694	35	21A
0005435697594	3694	36	21B
0005435935052	3694	37	21C
0005435697598	3694	38	21D
0005435697605	3694	39	22A
0005435697617	3694	40	22C
0005435697616	3694	41	22D
0005435916168	3694	42	23A
0005434950570	3694	43	23B
0005435697360	16265	1	1B
0005435916193	16265	2	1C
0005435697416	16265	3	1D
0005435697329	16265	4	2A
0005435697383	16265	5	2B
0005435697390	16265	6	2C
0005435697394	16265	7	2D
0005435697229	16265	8	3A
0005435916194	16265	9	3C
0005435697398	16265	10	3D
0005435697393	16265	11	4A
0005435935070	16265	12	4B
0005435935069	16265	13	4C
0005434950526	16265	14	5A
0005435697323	16265	15	5B
0005435697361	16265	16	5C
0005434950542	16265	17	5D
0005435697334	16265	18	6B
0005435935071	16265	19	6D
0005435935072	16265	20	7A
0005435697349	16265	21	7C
0005435697327	16265	22	7D
0005435697417	16265	23	18D
0005435916195	16265	24	19A
0005434950541	16265	25	19B
0005435697363	16265	26	19C
0005435697404	16265	27	19D
0005434950527	16265	28	20A
0005435697213	16265	29	20B
0005435697328	16265	30	20C
0005435697500	16265	31	20D
0005435916192	16265	32	21A
0005435697378	16265	33	21B
0005435697501	16265	34	21C
0005435697362	16265	35	21D
0005435697392	16265	36	22A
0005435697443	16265	37	22B
0005435697330	16265	38	22C
0005435697257	16265	39	22D
0005435697442	16265	40	23A
0005435697372	16265	41	23B
0005432607607	3952	1	1A
0005434606863	3952	2	1B
0005432607603	3952	3	1C
0005433519498	3952	4	2A
0005433519502	3952	5	2B
0005434604928	3952	6	3B
0005433519499	3952	7	3C
0005435853614	3952	8	4A
0005433519500	3952	9	4B
0005434606865	3952	10	5A
0005433519501	3952	11	5D
0005432607604	3952	12	6C
0005432609769	3952	13	7C
0005434604929	3952	14	18B
0005434606864	3952	15	18C
0005432607605	3952	16	21A
0005432609770	3952	17	21C
0005432607606	3952	18	21D
0005432609768	3952	19	22B
0005432609771	3952	20	22D
0005435853620	3952	21	23A
0005434606822	22032	1	1D
0005435853628	22032	2	2C
0005435853626	22032	3	4D
0005433519446	22032	4	6D
0005435853627	22032	5	19A
0005433519468	22032	6	19D
0005434606821	22032	7	21C
0005434606829	22032	8	22C
0005433519445	22032	9	22D
0005435628758	781	1	1A
0005433349009	781	2	2A
0005433348985	781	3	2B
0005435628757	781	4	3A
0005433348993	781	5	4A
0005433349010	781	6	3B
0005435628755	781	7	4B
0005433348986	781	8	5A
0005433349011	781	9	5B
0005435628754	781	10	6A
0005435628756	781	11	6B
0005433349044	15944	1	1B
0005433349046	15944	2	2A
0005433349042	15944	3	2B
0005433349043	15944	4	3A
0005433349045	15944	5	4A
0005435628714	15944	6	4B
0005435628726	15944	7	5B
0005435628725	15944	8	5A
0005435628727	15944	9	6B
0005434446536	17160	1	1B
0005433158136	17160	2	4A
0005434446534	17160	3	4B
0005434445261	17160	4	5A
0005434446533	17160	5	5B
0005433158137	17160	6	6A
0005434446535	17160	7	6B
0005433159333	17636	1	1B
0005433159335	17636	2	2B
0005433159336	17636	3	4B
0005433159334	17636	4	5B
0005434445244	17636	5	5A
0005435383127	7906	1	1A
0005435132978	7906	2	2A
0005435383149	7906	3	2D
0005435383172	7906	4	3A
0005435132983	7906	5	3B
0005435132976	7906	6	3D
0005435132981	7906	7	5A
0005435132984	7906	8	5B
0005435383173	7906	9	6A
0005435132982	7906	10	7B
0005435132986	7906	11	18A
0005435383126	7906	12	18D
0005435132977	7906	13	19A
0005435132985	7906	14	19D
0005435132979	7906	15	19C
0005435383148	7906	16	20A
0005435132980	7906	17	21C
0005435132923	33068	1	1A
0005435132838	33068	2	1C
0005435132897	33068	3	1D
0005435383200	33068	4	2D
0005435383203	33068	5	3D
0005435383199	33068	6	4C
0005435132843	33068	7	5A
0005435132879	33068	8	6D
0005435132872	33068	9	19A
0005435132898	33068	10	20B
0005435132916	33068	11	20C
0005435383202	33068	12	21C
0005435132900	33068	13	21D
0005435383201	33068	14	22A
0005435132909	33068	15	23B
0005435390218	7483	1	2D
0005435160410	7483	2	3B
0005435160403	7483	3	3C
0005435160404	7483	4	5A
0005435160407	7483	5	5B
0005435160405	7483	6	5C
0005435160408	7483	7	5D
0005435160402	7483	8	6B
0005435160406	7483	9	7D
0005435160409	7483	10	18A
0005435160411	7483	11	18C
0005435160412	7483	12	20A
0005435390245	7483	13	21A
0005435390247	7483	14	22A
0005435390256	7483	15	22B
0005435390257	7483	16	22D
0005435390258	7483	17	23A
0005435160369	29529	1	1C
0005435160339	29529	2	2A
0005435160326	29529	3	3C
0005435390304	29529	4	3D
0005435390306	29529	5	4C
0005435390309	29529	6	5A
0005435390303	29529	7	5C
0005435390308	29529	8	6B
0005435390305	29529	9	6C
0005435390302	29529	10	6D
0005435160308	29529	11	7D
0005435390307	29529	12	18B
0005435160319	29529	13	18D
0005435160334	29529	14	21A
0005435160318	29529	15	23B
0005432394103	18435	1	1A
0005432398208	18435	2	2A
0005432394112	18435	3	1B
0005435178508	18435	4	2B
0005432398218	18435	5	3A
0005432398207	18435	6	3B
0005435179001	18435	7	4A
0005435179000	18435	8	5A
0005432398209	18435	9	5B
0005432394102	18435	10	6A
0005435178509	18435	11	6B
0005435178494	27146	1	1A
0005435178495	27146	2	1B
0005435178501	27146	3	2A
0005432398228	27146	4	3A
0005432398227	27146	5	3B
0005432398230	27146	6	4A
0005432400157	27146	7	4B
0005432398229	27146	8	5B
0005432400158	27146	9	6A
0005432400156	27146	10	6B
0005434191278	9728	1	1B
0005434191279	9728	2	2A
0005434191275	9728	3	4B
0005434191274	9728	4	5B
0005434191277	9728	5	6B
0005434504526	6540	1	1A
0005435104007	6540	2	1C
0005434504510	6540	3	1F
0005434504524	6540	4	2A
0005435104006	6540	5	2C
0005435104000	6540	6	2D
0005435103997	6540	7	2F
0005435103995	6540	8	3C
0005434504505	6540	9	3D
0005435104005	6540	10	3F
0005434504528	6540	11	4D
0005434504517	6540	12	4E
0005434504523	6540	13	4F
0005434504515	6540	14	5C
0005434504531	6540	15	5D
0005434504508	6540	16	6A
0005435104003	6540	17	6C
0005434504518	6540	18	7C
0005434504527	6540	19	8A
0005434504530	6540	20	8E
0005434504519	6540	21	8F
0005435104002	6540	22	9C
0005434504532	6540	23	9E
0005434504522	6540	24	9F
0005434504534	6540	25	10A
0005435103996	6540	26	10C
0005434504538	6540	27	10E
0005434504512	6540	28	10F
0005434504540	6540	29	11C
0005434504544	6540	30	11D
0005435104004	6540	31	11E
0005434504537	6540	32	11F
0005435104001	6540	33	12A
0005435103994	6540	34	12C
0005434504535	6540	35	12D
0005434504543	6540	36	12E
0005434504520	6540	37	13A
0005434504542	6540	38	13D
0005434504536	6540	39	14A
0005434504521	6540	40	14D
0005434504506	6540	41	14E
0005434504513	6540	42	14F
0005435103999	6540	43	15A
0005435104009	6540	44	15F
0005434504511	6540	45	16A
0005434504525	6540	46	16C
0005434504541	6540	47	16F
0005435103998	6540	48	17D
0005434504533	6540	49	17C
0005434504507	6540	50	17F
0005434504545	6540	51	18E
0005434504514	6540	52	18F
0005434504539	6540	53	19D
0005435104008	6540	54	19E
0005434504509	6540	55	19F
0005434504516	6540	56	20C
0005434504529	6540	57	20F
0005434503990	22674	1	1A
0005434504080	22674	2	1C
0005434504128	22674	3	1F
0005435103878	22674	4	4A
0005434504095	22674	5	5C
0005434504017	22674	6	5F
0005434503982	22674	7	6C
0005434504092	22674	8	6D
0005434504077	22674	9	6E
0005434504274	22674	10	6F
0005434504025	22674	11	7A
0005434504127	22674	12	7E
0005434504209	22674	13	8A
0005434504044	22674	14	8C
0005434504120	22674	15	8D
0005434503933	22674	16	8F
0005434504289	22674	17	9A
0005435103905	22674	18	9C
0005434504121	22674	19	9E
0005434504108	22674	20	10C
0005434504033	22674	21	11A
0005434504234	22674	22	11C
0005434504122	22674	23	11F
0005434504112	22674	24	12F
0005434504373	22674	25	14A
0005434504313	22674	26	14C
0005434504372	22674	27	14D
0005435103884	22674	28	15A
0005434504067	22674	29	15D
0005434504079	22674	30	16A
0005434504235	22674	31	16C
0005434503932	22674	32	16D
0005434504141	22674	33	16E
0005434504102	22674	34	17A
0005435103906	22674	35	17C
0005434504103	22674	36	17D
0005434504070	22674	37	17E
0005434504026	22674	38	17F
0005434504275	22674	39	18A
0005434504187	22674	40	18C
0005434504034	22674	41	18D
0005435103879	22674	42	19C
0005434504035	22674	43	20A
0005434504030	22674	44	20E
0005433367785	1694	1	1A
0005433367877	1694	2	1C
0005435653465	1694	3	1D
0005433368006	1694	4	1F
0005435653481	1694	5	2A
0005433367874	1694	6	2C
0005435653474	1694	7	2D
0005433367990	1694	8	2F
0005433367989	1694	9	3A
0005435653478	1694	10	3C
0005433368005	1694	11	3D
0005433367889	1694	12	3F
0005435653487	1694	13	4C
0005435653468	1694	14	4D
0005433367784	1694	15	4E
0005433367999	1694	16	4F
0005435653495	1694	17	5A
0005435653483	1694	18	5C
0005435653461	1694	19	5D
0005435653472	1694	20	5E
0005433367831	1694	21	5F
0005433368056	1694	22	6C
0005435653488	1694	23	6D
0005435653496	1694	24	6E
0005435653486	1694	25	6F
0005433368061	1694	26	7C
0005435653460	1694	27	7E
0005433367935	1694	28	7F
0005435653476	1694	29	8A
0005433368003	1694	30	8C
0005435653477	1694	31	8E
0005433367893	1694	32	8F
0005435653489	1694	33	9A
0005435653466	1694	34	9C
0005433367803	1694	35	9D
0005435653490	1694	36	9E
0005433367983	1694	37	9F
0005433367980	1694	38	10A
0005433367869	1694	39	10C
0005435653462	1694	40	10D
0005435653458	1694	41	10E
0005433367783	1694	42	10F
0005435653475	1694	43	11C
0005435653482	1694	44	11D
0005433367842	1694	45	11E
0005435653493	1694	46	11F
0005433367892	1694	47	12A
0005433367862	1694	48	12C
0005433367981	1694	49	12D
0005435653457	1694	50	12E
0005435653485	1694	51	12F
0005433367865	1694	52	13A
0005433367890	1694	53	13C
0005435653494	1694	54	13D
0005435653464	1694	55	13E
0005435653470	1694	56	13F
0005433368002	1694	57	14A
0005433367923	1694	58	14C
0005433367888	1694	59	14D
0005435653480	1694	60	14E
0005435653484	1694	61	14F
0005433367837	1694	62	15A
0005433367830	1694	63	15C
0005433367897	1694	64	15D
0005435653473	1694	65	15E
0005435653491	1694	66	15F
0005433368063	1694	67	16A
0005433367961	1694	68	16C
0005435653467	1694	69	16D
0005435653463	1694	70	16E
0005433367896	1694	71	16F
0005435653469	1694	72	17C
0005433367895	1694	73	17D
0005433367848	1694	74	17E
0005433367891	1694	75	17F
0005433367873	1694	76	18A
0005435653492	1694	77	18D
0005435653479	1694	78	18E
0005433367868	1694	79	18F
0005435653471	1694	80	19A
0005433367782	1694	81	19E
0005433367859	1694	82	19F
0005433367800	1694	83	20C
0005435653459	1694	84	20D
0005433367795	1694	85	20E
0005433367841	1694	86	20F
0005433368233	21694	1	1A
0005435652992	21694	2	1C
0005435653152	21694	3	1D
0005435653111	21694	4	1F
0005435652981	21694	5	3A
0005433368240	21694	6	3C
0005433368253	21694	7	3D
0005435652937	21694	8	3F
0005433368235	21694	9	4A
0005433368229	21694	10	4C
0005433368226	21694	11	4D
0005433368238	21694	12	4E
0005433368250	21694	13	4F
0005433368228	21694	14	5A
0005433368254	21694	15	5C
0005435653087	21694	16	5D
0005435653137	21694	17	5E
0005433368231	21694	18	5F
0005433368223	21694	19	6A
0005435653092	21694	20	6C
0005435653153	21694	21	6D
0005433368222	21694	22	6E
0005433368236	21694	23	7A
0005435653086	21694	24	7C
0005435652993	21694	25	7D
0005435653038	21694	26	7E
0005433368217	21694	27	7F
0005433368252	21694	28	8A
0005433368242	21694	29	8C
0005435652962	21694	30	8D
0005433368234	21694	31	8E
0005435652982	21694	32	8F
0005435653124	21694	33	9E
0005433368248	21694	34	9F
0005433368230	21694	35	10A
0005435653134	21694	36	10C
0005433368224	21694	37	10E
0005435653093	21694	38	10F
0005435653031	21694	39	11C
0005433368232	21694	40	11D
0005435653067	21694	41	11E
0005433368220	21694	42	11F
0005433368244	21694	43	12A
0005435653088	21694	44	12C
0005435653136	21694	45	12D
0005435652941	21694	46	12E
0005433368241	21694	47	12F
0005435653066	21694	48	13A
0005433368246	21694	49	13C
0005433368225	21694	50	13D
0005433368237	21694	51	13E
0005435653030	21694	52	13F
0005435653001	21694	53	14A
0005433368227	21694	54	14C
0005435653142	21694	55	14D
0005435653029	21694	56	14E
0005435653070	21694	57	14F
0005435653150	21694	58	15A
0005433368249	21694	59	15C
0005435652922	21694	60	15D
0005433368247	21694	61	15E
0005435653078	21694	62	15F
0005433368219	21694	63	16A
0005435653052	21694	64	16C
0005435653005	21694	65	16E
0005433368239	21694	66	16F
0005433368245	21694	67	17A
0005435652990	21694	68	17C
0005435652963	21694	69	17D
0005433368243	21694	70	17E
0005435652991	21694	71	17F
0005433368218	21694	72	18A
0005435653004	21694	73	18C
0005435653053	21694	74	18D
0005433368221	21694	75	18E
0005435653123	21694	76	18F
0005435653116	21694	77	19A
0005435653022	21694	78	19C
0005435653112	21694	79	19F
0005435653039	21694	80	20A
0005435653069	21694	81	20C
0005433368251	21694	82	20D
0005435653151	21694	83	20E
0005435653138	21694	84	20F
0005433986363	4177	1	1C
0005433986370	4177	2	1D
0005433986371	4177	3	2A
0005435788794	4177	4	2C
0005433986390	4177	5	2D
0005433986381	4177	6	2F
0005433986386	4177	7	3D
0005433986405	4177	8	4A
0005433986358	4177	9	4D
0005433986377	4177	10	4E
0005433986365	4177	11	4F
0005433986387	4177	12	5A
0005433986368	4177	13	5D
0005433986376	4177	14	6C
0005435788795	4177	15	7A
0005435788796	4177	16	7D
0005433986400	4177	17	7E
0005433986379	4177	18	7F
0005433986384	4177	19	8A
0005433986389	4177	20	8C
0005433986393	4177	21	8E
0005433986388	4177	22	9A
0005433986367	4177	23	9D
0005433986392	4177	24	10C
0005433986399	4177	25	10D
0005433986357	4177	26	10F
0005433986383	4177	27	11C
0005433986366	4177	28	11D
0005433986398	4177	29	11F
0005433986391	4177	30	12A
0005433986404	4177	31	12C
0005433986360	4177	32	13C
0005433986373	4177	33	13E
0005433986385	4177	34	14A
0005433986362	4177	35	14C
0005433986396	4177	36	14D
0005433986380	4177	37	14E
0005433986359	4177	38	14F
0005433986401	4177	39	15A
0005433986356	4177	40	15C
0005433986369	4177	41	15D
0005433986382	4177	42	16A
0005433986378	4177	43	16E
0005433986364	4177	44	17A
0005433986403	4177	45	17C
0005433986394	4177	46	18A
0005433986361	4177	47	18E
0005433986397	4177	48	19C
0005433986395	4177	49	19D
0005433986372	4177	50	19E
0005433986374	4177	51	20C
0005433986402	4177	52	20E
0005433986375	4177	53	20F
0005435788763	25687	1	1F
0005433985969	25687	2	2D
0005433985785	25687	3	2F
0005433985921	25687	4	4A
0005433985823	25687	5	4E
0005433985972	25687	6	4F
0005433985835	25687	7	5C
0005433985920	25687	8	5E
0005433985764	25687	9	5F
0005433985898	25687	10	6C
0005433985899	25687	11	6D
0005433985763	25687	12	7A
0005433985880	25687	13	7C
0005433985893	25687	14	7D
0005433985881	25687	15	7E
0005435788784	25687	16	8A
0005433985932	25687	17	8C
0005433985754	25687	18	8E
0005433985882	25687	19	9C
0005433985866	25687	20	9F
0005433985984	25687	21	10C
0005433985892	25687	22	10D
0005433985794	25687	23	10F
0005433985986	25687	24	11F
0005433985931	25687	25	12C
0005433985820	25687	26	12F
0005433985756	25687	27	13E
0005433985985	25687	28	14A
0005433985971	25687	29	14C
0005433985817	25687	30	14D
0005435788789	25687	31	14E
0005433985816	25687	32	15E
0005433985788	25687	33	15F
0005433985957	25687	34	16C
0005433985849	25687	35	16E
0005435788783	25687	36	17A
0005433985933	25687	37	17F
0005433985890	25687	38	18A
0005433985958	25687	39	18C
0005433985795	25687	40	18E
0005433985965	25687	41	19A
0005433985894	25687	42	19C
0005435788788	25687	43	20D
0005433985848	25687	44	20E
0005435788764	25687	45	20F
0005435720824	21266	1	4B
0005435720823	21266	2	4C
0005435720822	21266	3	23A
0005434509166	21324	1	1A
0005434509130	21324	2	1B
0005434509180	21324	3	1C
0005434509133	21324	4	1D
0005434509125	21324	5	2A
0005434509162	21324	6	2B
0005434509144	21324	7	2C
0005433168404	21324	8	2D
0005433168412	21324	9	3A
0005434509155	21324	10	3B
0005434509151	21324	11	3D
0005433168409	21324	12	4B
0005434509156	21324	13	4C
0005433168411	21324	14	4D
0005434509139	21324	15	5A
0005434509178	21324	16	5C
0005433168405	21324	17	5D
0005434509161	21324	18	6A
0005434509132	21324	19	6B
0005434509124	21324	20	6D
0005433168407	21324	21	7A
0005434509157	21324	22	7B
0005433168406	21324	23	7C
0005433168413	21324	24	7D
0005434509145	21324	25	18A
0005434509179	21324	26	18B
0005433168408	21324	27	18C
0005433168410	21324	28	18D
0005434509153	21324	29	19A
0005434509168	21324	30	19B
0005433168402	21324	31	19C
0005434509134	21324	32	20A
0005434509158	21324	33	20B
0005433168403	21324	34	20C
0005433168414	21324	35	20D
0005434509164	21324	36	21D
0005434509146	21324	37	22B
0005434509167	21324	38	22D
0005434509131	21324	39	23A
0005434509154	21324	40	23B
0005432655539	17867	1	1A
0005432655495	17867	2	1C
0005434151733	17867	3	1F
0005432661924	17867	4	2C
0005432659708	17867	5	2F
0005432655548	17867	6	3C
0005434151732	17867	7	3F
0005434151734	17867	8	4D
0005432665278	17867	9	4F
0005432869590	17867	10	5A
0005432657458	17867	11	5C
0005432869591	17867	12	7A
0005432869593	17867	13	7F
0005432655582	17867	14	8D
0005432660815	17867	15	8E
0005432664131	17867	16	8F
0005432657445	17867	17	9A
0005432655549	17867	18	9E
0005432663029	17867	19	10A
0005432659707	17867	20	10C
0005432655541	17867	21	10D
0005432869592	17867	22	10E
0005432658600	17867	23	10F
0005432660808	17867	24	12A
0005432658591	17867	25	12D
0005432655555	17867	26	13A
0005432663028	17867	27	13C
0005432655586	17867	28	13F
0005432869589	17867	29	14C
0005432663027	17867	30	14D
0005432658601	17867	31	14E
0005432665279	17867	32	14F
0005432655521	17867	33	15A
0005432660812	17867	34	15D
0005432655512	17867	35	16A
0005432660816	17867	36	16C
0005432666381	17867	37	16D
0005432655513	17867	38	16F
0005432659701	17867	39	17A
0005432661922	17867	40	17D
0005432665270	17867	41	17E
0005432666394	17867	42	17F
0005432655522	17867	43	18A
0005432657459	17867	44	18E
0005432665271	17867	45	19E
0005432655551	17867	46	19F
0005432655540	17867	47	20C
0005432655524	17867	48	20E
0005432655619	26334	1	1A
0005432655626	26334	2	1D
0005432655623	26334	3	2C
0005432869531	26334	4	2F
0005434151705	26334	5	3C
0005432666407	26334	6	4A
0005434151701	26334	7	4C
0005432659724	26334	8	4F
0005432655628	26334	9	5A
0005432869508	26334	10	5C
0005432655627	26334	11	5E
0005432667472	26334	12	5F
0005432666406	26334	13	6D
0005432660836	26334	14	6E
0005434151706	26334	15	6F
0005432659722	26334	16	7A
0005432869522	26334	17	7E
0005432667471	26334	18	8D
0005432655631	26334	19	8E
0005432660835	26334	20	9C
0005432869509	26334	21	9F
0005432655629	26334	22	10D
0005434151702	26334	23	10E
0005432655620	26334	24	11D
0005432869521	26334	25	11F
0005434151697	26334	26	12A
0005432657475	26334	27	12F
0005432657474	26334	28	13C
0005432655621	26334	29	13E
0005434151700	26334	30	14A
0005432666405	26334	31	14C
0005434151703	26334	32	15A
0005434151695	26334	33	15E
0005432657473	26334	34	16A
0005432869507	26334	35	17C
0005432655624	26334	36	18C
0005434151704	26334	37	18D
0005432655622	26334	38	18E
0005432659723	26334	39	19A
0005432665292	26334	40	19D
0005432655630	26334	41	19F
0005432655625	26334	42	20A
0005432665291	26334	43	20D
0005434151696	26334	44	20E
0005432329137	3112	1	1A
0005432329157	3112	2	1F
0005432329147	3112	3	2D
0005433438951	3112	4	2F
0005433438950	3112	5	3C
0005432329156	3112	6	3D
0005433438947	3112	7	3F
0005432287237	3112	8	4A
0005432329153	3112	9	4C
0005432329122	3112	10	4E
0005432329116	3112	11	4F
0005432287239	3112	12	5C
0005432329113	3112	13	5E
0005432329158	3112	14	6A
0005433438949	3112	15	6D
0005432905149	3112	16	6E
0005432329140	3112	17	6F
0005432329128	3112	18	7C
0005432329114	3112	19	7E
0005432329151	3112	20	7F
0005432329124	3112	21	8A
0005432329155	3112	22	8D
0005432329144	3112	23	8E
0005432329132	3112	24	8F
0005432329131	3112	25	9C
0005432329130	3112	26	9E
0005432329115	3112	27	10C
0005432329129	3112	28	10E
0005432329145	3112	29	11A
0005432329149	3112	30	11C
0005432329136	3112	31	11D
0005432329139	3112	32	11E
0005432329142	3112	33	12A
0005432329141	3112	34	12C
0005433438945	3112	35	12D
0005433438953	3112	36	13A
0005432329152	3112	37	13C
0005432329133	3112	38	13D
0005432329138	3112	39	13E
0005432329120	3112	40	13F
0005432329150	3112	41	14A
0005432329148	3112	42	14C
0005433438948	3112	43	14D
0005432329118	3112	44	14F
0005432329117	3112	45	15A
0005432905137	3112	46	15C
0005432905150	3112	47	15D
0005432329127	3112	48	16C
0005432329143	3112	49	16D
0005432329126	3112	50	16E
0005432287238	3112	51	16F
0005433438952	3112	52	17C
0005432329135	3112	53	17D
0005432287235	3112	54	17E
0005432905148	3112	55	18A
0005432329123	3112	56	18D
0005432329146	3112	57	18E
0005432329154	3112	58	18F
0005432329134	3112	59	19C
0005432329119	3112	60	19D
0005433438954	3112	61	19F
0005432329121	3112	62	20A
0005433438946	3112	63	20C
0005432329112	3112	64	20D
0005432287236	3112	65	20E
0005432329125	3112	66	20F
0005432328655	31126	1	1A
0005432905177	31126	2	1C
0005432328656	31126	3	1D
0005432054330	31126	4	1F
0005432328762	31126	5	2A
0005432328772	31126	6	2D
0005432905182	31126	7	2F
0005432328761	31126	8	3A
0005432328831	31126	9	3D
0005432328566	31126	10	4A
0005432328559	31126	11	4C
0005433438874	31126	12	4E
0005432328609	31126	13	4F
0005432328739	31126	14	5C
0005432328639	31126	15	5F
0005432054331	31126	16	6D
0005432905178	31126	17	6E
0005432328491	31126	18	7A
0005432328657	31126	19	7D
0005433438873	31126	20	7F
0005432328536	31126	21	8D
0005432328870	31126	22	8C
0005432328615	31126	23	8E
0005432905181	31126	24	9A
0005433438895	31126	25	9C
0005432328611	31126	26	9E
0005432328775	31126	27	9F
0005432328411	31126	28	10C
0005432328568	31126	29	10D
0005432905180	31126	30	10E
0005432328633	31126	31	10F
0005432328383	31126	32	11A
0005432328782	31126	33	11C
0005433438863	31126	34	11D
0005432328786	31126	35	12A
0005432328751	31126	36	12C
0005432328608	31126	37	12D
0005432328767	31126	38	12F
0005432328763	31126	39	13D
0005432328490	31126	40	13E
0005432905179	31126	41	13F
0005432328814	31126	42	14A
0005433438896	31126	43	14D
0005432328746	31126	44	14E
0005432328731	31126	45	15A
0005432328769	31126	46	15C
0005432328714	31126	47	15D
0005432328755	31126	48	15E
0005432328919	31126	49	15F
0005432328684	31126	50	16A
0005432328783	31126	51	16C
0005432054333	31126	52	16D
0005432328631	31126	53	17A
0005432054332	31126	54	17D
0005432328730	31126	55	17F
0005432328741	31126	56	18A
0005432328791	31126	57	18C
0005432328658	31126	58	18D
0005432328771	31126	59	18E
0005432905183	31126	60	18F
0005433438854	31126	61	19C
0005432328781	31126	62	19E
0005432328745	31126	63	20D
0005432328632	31126	64	20E
0005433438860	31126	65	20F
0005432146218	6195	1	1A
0005435999413	6195	2	2D
0005435487822	6195	3	2C
0005435999410	6195	4	3A
0005435297075	6195	5	4A
0005435487883	6195	6	4C
0005435487880	6195	7	4F
0005435999415	6195	8	5A
0005435297061	6195	9	5C
0005434309871	6195	10	5B
0005435999412	6195	11	5D
0005435297050	6195	12	5E
0005435297067	6195	13	6A
0005435487882	6195	14	5F
0005435487881	6195	15	6B
0005435487867	6195	16	6C
0005435999409	6195	17	6D
0005435487816	6195	18	6E
0005435999405	6195	19	7D
0005435487872	6195	20	7F
0005435297076	6195	21	8A
0005434309867	6195	22	8B
0005435999414	6195	23	8D
0005435999422	6195	24	8C
0005434309873	6195	25	8E
0005435999407	6195	26	9C
0005435297069	6195	27	9F
0005435999420	6195	28	9E
0005434309864	6195	29	10C
0005434309865	6195	30	10D
0005435487895	6195	31	11A
0005435999411	6195	32	11C
0005435297063	6195	33	12B
0005435999421	6195	34	12F
0005435999417	6195	35	13B
0005435999418	6195	36	13F
0005435487817	6195	37	14D
0005435487836	6195	38	15A
0005435297052	6195	39	14F
0005435999416	6195	40	15B
0005434309866	6195	41	15C
0005434309874	6195	42	15F
0005435487853	6195	43	15E
0005435487854	6195	44	16A
0005435487835	6195	45	16D
0005434309875	6195	46	17B
0005435297062	6195	47	17E
0005435487914	6195	48	17D
0005434309870	6195	49	18B
0005435999419	6195	50	18F
0005434309869	6195	51	19A
0005434309876	6195	52	19B
0005435297053	6195	53	19C
0005434309877	6195	54	19D
0005435487877	6195	55	20F
0005435487894	6195	56	21A
0005435999423	6195	57	21B
0005435999406	6195	58	22C
0005435999408	6195	59	22D
0005434309872	6195	60	22F
0005435487769	6195	61	23A
0005434309868	6195	62	23E
0005435999239	19560	1	1C
0005434309784	19560	2	1D
0005435488013	19560	3	2D
0005435488026	19560	4	3A
0005435488028	19560	5	2F
0005434309741	19560	6	3D
0005435488015	19560	7	5A
0005435999243	19560	8	5B
0005435999250	19560	9	5D
0005435488024	19560	10	6A
0005435488022	19560	11	5F
0005435999251	19560	12	6B
0005435999220	19560	13	6C
0005434309725	19560	14	6D
0005435488029	19560	15	6F
0005435297122	19560	16	7A
0005435297124	19560	17	7D
0005435488007	19560	18	8A
0005434309688	19560	19	8D
0005435999245	19560	20	9B
0005434309689	19560	21	9A
0005435488021	19560	22	8F
0005435297123	19560	23	9D
0005435999244	19560	24	10D
0005435488023	19560	25	11A
0005434309740	19560	26	11C
0005435488027	19560	27	11B
0005435488030	19560	28	11D
0005435999219	19560	29	11F
0005435999218	19560	30	13B
0005435999208	19560	31	13E
0005435488011	19560	32	14C
0005435297126	19560	33	14D
0005435488031	19560	34	16A
0005435999232	19560	35	16C
0005435488018	19560	36	17A
0005434309760	19560	37	17B
0005434309753	19560	38	17C
0005435488016	19560	39	18A
0005435488008	19560	40	18B
0005435488014	19560	41	18F
0005435488025	19560	42	19B
0005435488012	19560	43	19D
0005434309765	19560	44	20E
0005435297121	19560	45	21A
0005435297125	19560	46	20F
0005435488010	19560	47	21B
0005435999191	19560	48	21D
0005435488017	19560	49	21C
0005435488009	19560	50	21F
0005435999225	19560	51	22A
0005435488019	19560	52	22B
0005435999209	19560	53	22C
0005435999247	19560	54	23A
0005435999183	19560	55	23D
0005435488020	19560	56	23C
0005434309761	19560	57	23F
0005433186160	1581	1	1A
0005435508469	1581	2	1D
0005434566039	1581	3	2A
0005432291952	1581	4	2C
0005435508466	1581	5	2D
0005435518093	1581	6	2F
0005435518082	1581	7	3D
0005435518083	1581	8	3F
0005435502511	1581	9	4A
0005433186118	1581	10	4D
0005433186126	1581	11	4E
0005435502514	1581	12	4F
0005435502524	1581	13	5A
0005435508472	1581	14	5C
0005435518091	1581	15	5E
0005434566042	1581	16	6C
0005435502528	1581	17	6D
0005433186142	1581	18	6F
0005434566040	1581	19	7A
0005435502520	1581	20	7D
0005435518079	1581	21	7E
0005435508464	1581	22	7F
0005433186117	1581	23	8C
0005435502517	1581	24	8F
0005435502519	1581	25	9A
0005435502529	1581	26	9D
0005434566047	1581	27	9F
0005434566041	1581	28	10C
0005435508467	1581	29	10D
0005433186144	1581	30	10E
0005435518074	1581	31	10F
0005435518077	1581	32	11A
0005434566044	1581	33	11C
0005434566038	1581	34	11D
0005432291953	1581	35	11F
0005435502515	1581	36	12A
0005435518084	1581	37	12C
0005435502527	1581	38	12D
0005435502526	1581	39	12E
0005434566049	1581	40	12F
0005433186159	1581	41	13A
0005433186143	1581	42	13C
0005435508465	1581	43	13D
0005434566043	1581	44	13E
0005435518080	1581	45	13F
0005435502521	1581	46	14A
0005435502512	1581	47	14C
0005435502508	1581	48	14D
0005435502516	1581	49	14E
0005435518078	1581	50	14F
0005435502510	1581	51	15A
0005434566046	1581	52	15D
0005435518076	1581	53	15E
0005435502522	1581	54	15F
0005435518088	1581	55	16A
0005435518092	1581	56	16C
0005434566048	1581	57	16D
0005434566045	1581	58	16F
0005435502518	1581	59	17A
0005435518081	1581	60	17D
0005435518086	1581	61	17E
0005435508468	1581	62	17F
0005435502523	1581	63	18A
0005435518090	1581	64	18C
0005435508470	1581	65	18D
0005435508471	1581	66	18E
0005435518085	1581	67	19A
0005435518073	1581	68	18F
0005435502513	1581	69	19C
0005435502525	1581	70	19D
0005435518087	1581	71	19E
0005435502509	1581	72	19F
0005435508463	1581	73	20A
0005433186102	1581	74	20C
0005435518075	1581	75	20D
0005435518089	1581	76	20E
0005434566037	1581	77	20F
0005435529218	20885	1	1A
0005435529255	20885	2	1C
0005435502412	20885	3	1D
0005434565936	20885	4	1F
0005434565872	20885	5	2A
0005435502364	20885	6	3A
0005435545723	20885	7	3D
0005435529322	20885	8	4A
0005435529234	20885	9	4C
0005434565945	20885	10	4D
0005435502286	20885	11	4E
0005435502285	20885	12	4F
0005435545740	20885	13	5A
0005433186198	20885	14	5D
0005435529265	20885	15	5F
0005433186199	20885	16	6A
0005435529236	20885	17	6C
0005435529263	20885	18	6D
0005433186197	20885	19	6F
0005435502283	20885	20	7A
0005435502328	20885	21	7C
0005435545746	20885	22	7D
0005435502322	20885	23	7E
0005435545727	20885	24	7F
0005435502353	20885	25	8A
0005434565866	20885	26	8D
0005435529304	20885	27	8E
0005435502252	20885	28	8F
0005433186203	20885	29	9C
0005433186201	20885	30	9D
0005435529235	20885	31	9E
0005435502211	20885	32	9F
0005435545751	20885	33	10A
0005435529351	20885	34	10D
0005435502356	20885	35	10E
0005435545745	20885	36	10F
0005434565944	20885	37	11C
0005435502369	20885	38	11E
0005434565942	20885	39	12A
0005435529157	20885	40	12C
0005435502251	20885	41	12D
0005435502393	20885	42	12E
0005435529264	20885	43	12F
0005433186196	20885	44	13A
0005435502394	20885	45	13C
0005434565921	20885	46	13D
0005433186202	20885	47	13E
0005435502413	20885	48	13F
0005435529151	20885	49	14A
0005434565891	20885	50	14D
0005434565898	20885	51	14E
0005434565916	20885	52	14F
0005435502411	20885	53	15D
0005433186200	20885	54	15F
0005435529170	20885	55	16A
0005434565905	20885	56	16C
0005435502249	20885	57	16D
0005435529254	20885	58	16E
0005435545731	20885	59	17A
0005435529237	20885	60	17C
0005435545717	20885	61	17D
0005435529303	20885	62	17E
0005434565897	20885	63	18C
0005434565943	20885	64	18A
0005435502352	20885	65	18E
0005435529145	20885	66	18F
0005435502295	20885	67	19A
0005435502265	20885	68	19D
0005434565904	20885	69	19E
0005435545732	20885	70	19F
0005435529244	20885	71	20A
0005435502290	20885	72	20C
0005435502284	20885	73	20D
0005435529219	20885	74	20E
0005434565865	20885	75	20F
0005435931610	3883	1	1B
0005435153802	3883	2	1D
0005435153806	3883	3	2A
0005435931603	3883	4	3C
0005435931602	3883	5	5D
0005435153805	3883	6	6B
0005435153803	3883	7	18A
0005435153804	3883	8	18D
0005435931599	3883	9	19A
0005435931608	3883	10	19B
0005435931601	3883	11	19D
0005435931607	3883	12	20B
0005435931598	3883	13	21B
0005435153807	3883	14	21D
0005435931637	21874	1	1C
0005435153734	21874	2	1D
0005435931638	21874	3	4D
0005435153773	21874	4	5B
0005435153758	21874	5	6B
0005435153743	21874	6	7B
0005435153735	21874	7	7C
0005435153761	21874	8	19B
0005435931635	21874	9	19C
0005435153744	21874	10	20C
0005435153736	21874	11	21D
0005435931636	21874	12	22A
0005435153748	21874	13	22B
0005432628984	7180	1	2C
0005435225573	7180	2	3A
0005435225586	7180	3	3D
0005432628985	7180	4	4A
0005435225572	7180	5	4C
0005435225589	7180	6	4D
0005432628993	7180	7	5A
0005435225596	7180	8	5B
0005432628990	7180	9	5C
0005432628988	7180	10	5D
0005435225602	7180	11	6A
0005432628991	7180	12	7B
0005432628987	7180	13	18B
0005432628979	7180	14	18D
0005432628986	7180	15	19A
0005432628992	7180	16	19B
0005432628989	7180	17	19D
0005435225606	7180	18	20A
0005432628980	7180	19	20D
0005435225619	7180	20	21A
0005432628983	7180	21	21B
0005432628981	7180	22	22A
0005432628982	7180	23	22C
0005435225571	7180	24	23A
0005435225659	28119	1	2A
0005432628887	28119	2	2B
0005435225658	28119	3	2C
0005435225661	28119	4	2D
0005435225662	28119	5	3A
0005435225660	28119	6	3D
0005432628880	28119	7	4A
0005432628848	28119	8	4B
0005435225663	28119	9	4D
0005432628882	28119	10	5B
0005432628970	28119	11	6A
0005432628876	28119	12	7A
0005435225664	28119	13	7B
0005432628849	28119	14	7D
0005432628912	28119	15	18A
0005435225657	28119	16	18B
0005432628901	28119	17	18D
0005432628892	28119	18	22A
0005432628881	28119	19	23A
0005432628971	28119	20	23B
0005435960086	8759	1	7C
0005435960087	8759	2	18B
0005435960088	8759	3	19D
0005435960064	15269	1	1A
0005435960052	15269	2	2A
0005434267985	15269	3	4A
0005434267986	15269	4	20A
0005435960063	15269	5	21A
0005434267987	15269	6	21C
0005432693335	1175	1	1C
0005432693344	1175	2	1A
0005432693330	1175	3	1D
0005432675282	1175	4	2A
0005432693339	1175	5	1F
0005432675281	1175	6	2D
0005432675276	1175	7	2F
0005432693324	1175	8	3D
0005432693342	1175	9	3C
0005432873313	1175	10	4A
0005432675272	1175	11	4C
0005432693323	1175	12	4F
0005432675270	1175	13	5F
0005432693327	1175	14	5D
0005432693329	1175	15	6C
0005432675277	1175	16	7B
0005432675280	1175	17	7A
0005432693321	1175	18	7C
0005432873315	1175	19	7D
0005432873316	1175	20	8A
0005432693326	1175	21	8F
0005432675271	1175	22	8E
0005432873305	1175	23	9A
0005432675278	1175	24	9F
0005432693345	1175	25	10C
0005432693317	1175	26	10B
0005432677605	1175	27	10F
0005432675268	1175	28	10E
0005432693332	1175	29	11B
0005432693325	1175	30	11D
0005432873285	1175	31	11C
0005432873301	1175	32	11F
0005432675275	1175	33	12D
0005432693331	1175	34	12E
0005432693341	1175	35	13A
0005432693318	1175	36	12F
0005432693328	1175	37	13F
0005432677608	1175	38	13E
0005432693337	1175	39	14C
0005432675279	1175	40	14B
0005432693320	1175	41	14E
0005432693338	1175	42	14D
0005432873312	1175	43	14F
0005432873311	1175	44	15C
0005432693340	1175	45	15F
0005432693347	1175	46	16A
0005432675274	1175	47	16C
0005432693333	1175	48	16B
0005432873317	1175	49	17B
0005432693319	1175	50	17C
0005432675269	1175	51	17F
0005432873304	1175	52	17E
0005432693322	1175	53	18B
0005432677607	1175	54	18A
0005432873286	1175	55	18C
0005432693334	1175	56	18E
0005432677606	1175	57	19A
0005432675273	1175	58	20B
0005432693343	1175	59	20D
0005432693346	1175	60	20F
0005432693316	1175	61	21A
0005432693336	1175	62	21E
0005432677568	17502	1	1D
0005432692891	17502	2	1C
0005432873357	17502	3	1F
0005432873356	17502	4	2D
0005432873362	17502	5	2C
0005432873361	17502	6	3D
0005432693168	17502	7	3F
0005432675071	17502	8	4C
0005432675120	17502	9	5A
0005432675102	17502	10	4F
0005432675163	17502	11	4D
0005432693122	17502	12	5C
0005432693100	17502	13	5F
0005432873360	17502	14	5D
0005432675170	17502	15	6B
0005432693070	17502	16	6A
0005432873355	17502	17	6C
0005432693011	17502	18	6E
0005432675100	17502	19	7A
0005432693048	17502	20	7C
0005432693045	17502	21	7B
0005432677567	17502	22	8A
0005432693121	17502	23	8E
0005432693101	17502	24	8C
0005432675169	17502	25	8F
0005432675108	17502	26	9B
0005432692912	17502	27	9D
0005432675180	17502	28	9E
0005432693158	17502	29	10A
0005432693156	17502	30	10B
0005432693094	17502	31	10D
0005432675164	17502	32	11B
0005432693079	17502	33	11A
0005432675119	17502	34	11C
0005432675155	17502	35	11E
0005432692995	17502	36	12D
0005432692892	17502	37	12C
0005432693106	17502	38	13C
0005432693150	17502	39	13B
0005432873358	17502	40	14A
0005432692974	17502	41	13F
0005432677576	17502	42	13E
0005432693012	17502	43	14C
0005432693105	17502	44	14B
0005432693104	17502	45	14D
0005432677575	17502	46	14F
0005432693151	17502	47	14E
0005432693103	17502	48	15D
0005432675070	17502	49	16A
0005432693044	17502	50	15F
0005432677579	17502	51	16D
0005432675101	17502	52	17A
0005432693028	17502	53	16F
0005432873359	17502	54	17B
0005432693157	17502	55	17F
0005432693095	17502	56	18C
0005432675158	17502	57	18E
0005432693043	17502	58	19A
0005432693029	17502	59	19C
0005432692911	17502	60	19D
0005432675107	17502	61	19F
0005432693020	17502	62	20C
0005432692973	17502	63	21A
0005432675171	17502	64	21C
0005432675083	17502	65	21D
0005433156771	1117	1	2B
0005433156703	1117	2	2C
0005434435333	1117	3	3B
0005433156749	1117	4	3C
0005433156746	1117	5	4A
0005434435332	1117	6	4B
0005433156747	1117	7	4C
0005434435326	1117	8	4D
0005434435329	1117	9	5B
0005434435334	1117	10	5C
0005434435324	1117	11	5D
0005434435330	1117	12	6A
0005433156773	1117	13	6B
0005433156762	1117	14	6C
0005433156779	1117	15	7B
0005434435321	1117	16	7D
0005434435327	1117	17	18A
0005433156778	1117	18	18B
0005434435322	1117	19	18D
0005434435331	1117	20	19D
0005433156702	1117	21	20C
0005433156761	1117	22	20D
0005434435325	1117	23	21D
0005434435323	1117	24	22C
0005433156772	1117	25	22D
0005434435328	1117	26	23B
0005433156835	17275	1	1C
0005434435204	17275	2	1D
0005434435149	17275	3	2D
0005433156834	17275	4	3A
0005434435205	17275	5	3B
0005433156827	17275	6	3C
0005433156828	17275	7	4A
0005433156831	17275	8	4B
0005434435163	17275	9	4C
0005434435209	17275	10	5C
0005433156836	17275	11	5D
0005434435206	17275	12	6B
0005433156833	17275	13	7A
0005434435208	17275	14	7B
0005434435131	17275	15	7C
0005433156830	17275	16	18D
0005434435177	17275	17	19B
0005434435238	17275	18	19C
0005434435203	17275	19	19D
0005434435207	17275	20	20A
0005434435162	17275	21	20D
0005433156832	17275	22	21B
0005433156829	17275	23	22B
0005434435202	17275	24	22C
0005435928160	4074	1	2D
0005435928155	4074	2	6C
0005435086907	4074	3	7D
0005435928135	4074	4	18A
0005435928159	4074	5	19B
0005435086909	4074	6	19C
0005435086908	4074	7	20B
0005435086903	4074	8	20C
0005435086906	4074	9	20D
0005435086905	4074	10	22B
0005435086904	4074	11	22C
0005435928187	24400	1	1B
0005435086809	24400	2	1C
0005435086825	24400	3	2B
0005435086810	24400	4	2D
0005435928190	24400	5	5B
0005435086845	24400	6	5C
0005435086844	24400	7	6B
0005435086849	24400	8	6C
0005435086839	24400	9	19A
0005435086850	24400	10	19D
0005435928189	24400	11	20B
0005435086840	24400	12	20C
0005435928188	24400	13	20D
0005435928186	24400	14	21B
0005435086836	24400	15	22C
0005435907509	4816	1	2A
0005435907515	4816	2	2D
0005434626048	4816	3	4A
0005434626047	4816	4	4C
0005434626051	4816	5	5F
0005435907527	4816	6	6D
0005434626052	4816	7	10A
0005434626053	4816	8	10E
0005435907516	4816	9	10F
0005434626046	4816	10	11A
0005434626054	4816	11	12A
0005434626050	4816	12	12E
0005435907522	4816	13	13D
0005433194852	4816	14	14E
0005434626049	4816	15	17D
0005434626055	4816	16	18C
0005435907528	4816	17	19D
0005433194888	32901	1	1A
0005434625979	32901	2	3F
0005434625981	32901	3	4C
0005433194891	32901	4	5D
0005434625962	32901	5	5F
0005434625961	32901	6	6F
0005435907551	32901	7	11F
0005435907548	32901	8	12E
0005433194890	32901	9	16E
0005435907549	32901	10	17D
0005434625970	32901	11	18A
0005435907550	32901	12	18E
0005435907553	32901	13	18F
0005433194889	32901	14	19A
0005434625978	32901	15	19D
0005435907552	32901	16	20F
0005435785299	13757	1	1A
0005435785453	13757	2	1B
0005435785249	13757	3	1C
0005435785353	13757	4	1D
0005435785356	13757	5	2A
0005435785454	13757	6	2B
0005435785365	13757	7	2D
0005435785250	13757	8	3A
0005435937422	13757	9	3B
0005435937428	13757	10	3C
0005435937426	13757	11	3D
0005435787356	13757	12	4A
0005435785355	13757	13	4B
0005435785274	13757	14	4C
0005435785432	13757	15	4D
0005435937418	13757	16	5A
0005435785220	13757	17	5B
0005435785436	13757	18	5C
0005435785435	13757	19	5D
0005435785467	13757	20	6B
0005435785344	13757	21	6C
0005435785350	13757	22	6D
0005435785273	13757	23	7A
0005435785270	13757	24	7B
0005435785379	13757	25	7C
0005435937423	13757	26	7D
0005435785367	13757	27	18A
0005432195713	13757	28	18B
0005435937427	13757	29	18C
0005435785193	13757	30	18D
0005435785360	13757	31	19A
0005435937420	13757	32	19B
0005435937424	13757	33	19C
0005435785269	13757	34	19D
0005435937419	13757	35	20A
0005432195712	13757	36	20B
0005435785380	13757	37	20C
0005435785354	13757	38	21A
0005435937425	13757	39	21C
0005435785366	13757	40	21D
0005435785318	13757	41	22A
0005435785361	13757	42	22B
0005435785288	13757	43	22C
0005435785323	13757	44	22D
0005435937421	13757	45	23A
0005435785284	13757	46	23B
0005435785645	27440	1	1A
0005435785630	27440	2	1B
0005435785629	27440	3	1D
0005432190660	27440	4	2A
0005435785639	27440	5	2B
0005435937379	27440	6	2D
0005435937388	27440	7	3A
0005435785646	27440	8	3B
0005435785628	27440	9	3C
0005435785638	27440	10	3D
0005435785635	27440	11	4A
0005432190661	27440	12	4B
0005435785621	27440	13	4C
0005435785616	27440	14	4D
0005432190658	27440	15	5A
0005435785627	27440	16	5B
0005435785623	27440	17	5C
0005435937378	27440	18	5D
0005435785632	27440	19	6A
0005435785648	27440	20	6B
0005435937387	27440	21	6C
0005435785631	27440	22	6D
0005435785634	27440	23	7A
0005435785615	27440	24	7C
0005435785640	27440	25	7D
0005435785636	27440	26	18A
0005435937368	27440	27	18B
0005435785619	27440	28	18C
0005435785620	27440	29	18D
0005435785625	27440	30	19A
0005435785618	27440	31	19C
0005435937375	27440	32	19B
0005432190659	27440	33	19D
0005435785642	27440	34	20A
0005435785624	27440	35	20B
0005435785617	27440	36	20D
0005435785633	27440	37	21A
0005435785614	27440	38	21B
0005435787371	27440	39	21C
0005435785644	27440	40	21D
0005435785641	27440	41	22A
0005435785637	27440	42	22B
0005435785643	27440	43	22C
0005435785626	27440	44	22D
0005435785647	27440	45	23A
0005435785622	27440	46	23B
0005434407707	20296	1	1A
0005434407774	20296	2	1F
0005434407593	20296	3	2A
0005434407708	20296	4	2C
0005434407765	20296	5	2D
0005434407913	20296	6	2F
0005435311166	20296	7	3A
0005435311168	20296	8	3C
0005434407588	20296	9	3D
0005434407861	20296	10	3F
0005434408062	20296	11	4A
0005435311177	20296	12	4C
0005434407806	20296	13	4D
0005434407656	20296	14	4E
0005434407850	20296	15	4F
0005434407816	20296	16	5A
0005435311170	20296	17	5C
0005434407813	20296	18	5D
0005434407943	20296	19	6C
0005434407804	20296	20	6E
0005434407800	20296	21	7A
0005434407646	20296	22	7C
0005434407915	20296	23	7D
0005434407634	20296	24	7E
0005435311172	20296	25	7F
0005434407626	20296	26	8A
0005434407779	20296	27	8C
0005434407736	20296	28	8D
0005435311169	20296	29	8E
0005434407926	20296	30	8F
0005434407525	20296	31	9A
0005434407688	20296	32	9C
0005434407881	20296	33	9D
0005434407963	20296	34	9F
0005435311173	20296	35	10A
0005434408035	20296	36	10E
0005434407942	20296	37	10D
0005434407585	20296	38	10F
0005432058420	20296	39	11A
0005434407787	20296	40	11C
0005432058418	20296	41	11E
0005434407745	20296	42	11F
0005434407635	20296	43	12A
0005434407766	20296	44	12D
0005434407658	20296	45	12E
0005434407801	20296	46	12F
0005434407709	20296	47	13A
0005434407805	20296	48	13C
0005435311176	20296	49	13D
0005434407892	20296	50	13E
0005434407782	20296	51	13F
0005434407929	20296	52	14A
0005434407885	20296	53	14C
0005434407818	20296	54	14D
0005435311167	20296	55	14E
0005435311171	20296	56	14F
0005434407647	20296	57	15A
0005435311165	20296	58	15C
0005434407835	20296	59	15D
0005434407819	20296	60	15F
0005434407700	20296	61	16C
0005432058419	20296	62	16D
0005434407884	20296	63	16E
0005434407687	20296	64	16F
0005434407914	20296	65	17A
0005434407825	20296	66	17D
0005435311164	20296	67	17E
0005434407799	20296	68	17F
0005434408087	20296	69	18A
0005434407841	20296	70	18E
0005435311163	20296	71	18F
0005434407587	20296	72	19A
0005434407775	20296	73	19C
0005435311174	20296	74	19D
0005434407880	20296	75	19E
0005434407657	20296	76	19F
0005434407661	20296	77	20D
0005435311175	20296	78	20E
0005434407817	20296	79	20F
0005434408363	27018	1	1A
0005434408365	27018	2	1C
0005434408350	27018	3	1D
0005432154002	27018	4	1F
0005434408362	27018	5	2A
0005432154004	27018	6	2C
0005434408325	27018	7	2F
0005434408331	27018	8	3A
0005434408346	27018	9	3C
0005434408322	27018	10	3F
0005434408352	27018	11	4C
0005434408326	27018	12	4D
0005435311054	27018	13	4F
0005434408380	27018	14	5C
0005434408355	27018	15	5D
0005435311083	27018	16	5E
0005434408353	27018	17	5F
0005434408369	27018	18	6A
0005434408338	27018	19	6C
0005434408354	27018	20	6E
0005434408349	27018	21	6F
0005432154000	27018	22	7A
0005434408370	27018	23	7C
0005434408357	27018	24	7D
0005434408347	27018	25	7E
0005434408376	27018	26	7F
0005434408318	27018	27	8A
0005434408324	27018	28	8C
0005434408321	27018	29	8D
0005434408335	27018	30	8E
0005434408330	27018	31	8F
0005434408348	27018	32	9A
0005432154007	27018	33	9C
0005435311038	27018	34	9D
0005434408320	27018	35	9F
0005434408342	27018	36	10A
0005434408340	27018	37	10C
0005434408334	27018	38	10D
0005434408367	27018	39	10E
0005434408336	27018	40	10F
0005434408319	27018	41	11A
0005432154001	27018	42	11C
0005434408341	27018	43	11E
0005434408368	27018	44	11F
0005435311030	27018	45	12C
0005434408359	27018	46	12D
0005435311079	27018	47	12F
0005434408339	27018	48	13A
0005434408364	27018	49	13C
0005432154006	27018	50	13D
0005434408343	27018	51	13E
0005435311037	27018	52	13F
0005434408328	27018	53	14A
0005434408360	27018	54	14C
0005435311078	27018	55	14D
0005434408358	27018	56	14E
0005434408372	27018	57	14F
0005435311031	27018	58	15A
0005434408351	27018	59	15C
0005434408381	27018	60	15D
0005434408345	27018	61	15E
0005434408344	27018	62	15F
0005434408377	27018	63	16A
0005434408374	27018	64	16C
0005434408327	27018	65	16D
0005434408379	27018	66	16E
0005434408332	27018	67	16F
0005434408366	27018	68	17A
0005434408337	27018	69	17E
0005434408371	27018	70	17F
0005434408373	27018	71	18A
0005435311060	27018	72	18C
0005432154005	27018	73	18D
0005432154008	27018	74	18E
0005434408375	27018	75	18F
0005434408329	27018	76	19A
0005434408356	27018	77	19C
0005434408361	27018	78	19D
0005435311080	27018	79	19E
0005432154003	27018	80	20A
0005434408378	27018	81	20C
0005434408323	27018	82	20D
0005434408333	27018	83	20F
0005434319534	5724	1	2C
0005433124015	5724	2	3C
0005433123925	5724	3	3D
0005433123957	5724	4	3F
0005434311238	5724	5	4D
0005433123930	5724	6	4F
0005432109729	5724	7	5D
0005433123899	5724	8	5F
0005434319531	5724	9	6D
0005434319530	5724	10	6E
0005434319539	5724	11	7E
0005433123926	5724	12	7F
0005432109730	5724	13	8F
0005433123808	5724	14	9D
0005433123853	5724	15	10A
0005433123962	5724	16	11A
0005434319541	5724	17	11E
0005433123807	5724	18	12F
0005433123897	5724	19	13A
0005434319538	5724	20	13E
0005432109728	5724	21	13F
0005434319533	5724	22	15D
0005433124016	5724	23	15E
0005434319529	5724	24	16A
0005433123997	5724	25	16D
0005433123876	5724	26	16F
0005434319535	5724	27	17C
0005434319532	5724	28	17E
0005433123895	5724	29	18A
0005434319540	5724	30	18E
0005434311239	5724	31	19F
0005433123956	5724	32	20A
0005434319536	5724	33	20D
0005433123963	5724	34	20E
0005434319537	5724	35	20F
0005433124133	15677	1	1A
0005433124142	15677	2	1C
0005434319383	15677	3	1F
0005433124120	15677	4	2A
0005434319392	15677	5	2C
0005433124132	15677	6	2F
0005434319394	15677	7	3D
0005434319395	15677	8	3F
0005433124139	15677	9	4A
0005433124134	15677	10	4E
0005434319343	15677	11	5F
0005433124125	15677	12	6C
0005434319355	15677	13	6D
0005433124135	15677	14	7A
0005433124143	15677	15	7E
0005433124123	15677	16	8A
0005434319388	15677	17	9A
0005433124136	15677	18	10F
0005433124127	15677	19	11A
0005433124126	15677	20	11D
0005434319385	15677	21	11E
0005434319407	15677	22	12A
0005433124128	15677	23	12D
0005433124121	15677	24	12F
0005433124124	15677	25	13A
0005434319404	15677	26	13C
0005434319378	15677	27	13E
0005434319398	15677	28	13F
0005434312318	15677	29	14C
0005433124130	15677	30	14D
0005434319389	15677	31	14E
0005434319386	15677	32	14F
0005433124140	15677	33	15D
0005434312314	15677	34	15E
0005433124137	15677	35	15F
0005434319387	15677	36	16C
0005433124129	15677	37	16D
0005434319352	15677	38	16E
0005434311217	15677	39	17C
0005434319399	15677	40	17D
0005434319356	15677	41	17F
0005434319353	15677	42	18C
0005433124141	15677	43	18D
0005433124131	15677	44	18F
0005433124138	15677	45	19D
0005434311222	15677	46	19E
0005434319354	15677	47	20A
0005433124122	15677	48	20C
0005434319406	15677	49	20E
0005434189186	8966	1	2A
0005434484410	8966	2	3C
0005434484409	8966	3	4A
0005434484411	8966	4	4C
0005434189189	8966	5	5D
0005434189203	8966	6	7D
0005434189185	8966	7	18D
0005434484407	8966	8	19B
0005434484406	8966	9	20A
0005434189187	8966	10	20C
0005434484408	8966	11	21D
0005434189165	8966	12	22A
0005434484412	8966	13	22B
0005434189192	8966	14	22C
0005434484332	16667	1	1A
0005434189232	16667	2	1B
0005434484349	16667	3	1C
0005434484363	16667	4	1D
0005434189233	16667	5	6B
0005434484382	16667	6	7C
0005434189235	16667	7	7D
0005434189231	16667	8	18A
0005434189230	16667	9	18D
0005434484339	16667	10	21C
0005434484350	16667	11	22A
0005434189234	16667	12	22D
0005433124131	7673	1	1D
0005433124129	7673	2	4C
0005433124121	7673	3	5D
0005433124127	7673	4	5E
0005433124125	7673	5	6D
0005433124137	7673	6	6E
0005433124123	7673	7	6F
0005433124143	7673	8	7D
0005433124126	7673	9	7E
0005433124135	7673	10	8F
0005433124120	7673	11	9F
0005433124140	7673	12	10D
0005433124136	7673	13	11A
0005433124128	7673	14	11D
0005433124142	7673	15	11F
0005433124124	7673	16	12C
0005433124122	7673	17	12E
0005433124139	7673	18	14E
0005433124130	7673	19	15D
0005433124132	7673	20	15F
0005433124134	7673	21	16F
0005433124141	7673	22	17E
0005433124138	7673	23	18E
0005433124133	7673	24	20D
0005433450170	7672	1	1A
0005432693352	7672	2	1C
0005432693366	7672	3	1F
0005432721145	7672	4	1D
0005432693373	7672	5	2A
0005433450165	7672	6	2C
0005432693374	7672	7	2D
0005432693357	7672	8	2F
0005433450178	7672	9	3D
0005432721144	7672	10	3F
0005432721163	7672	11	4A
0005432693356	7672	12	4C
0005432071601	7672	13	4D
0005432693363	7672	14	4E
0005433450182	7672	15	5A
0005432693376	7672	16	5D
0005433450163	7672	17	5E
0005432721160	7672	18	5F
0005433450171	7672	19	6A
0005432721162	7672	20	6C
0005432693377	7672	21	6D
0005432721154	7672	22	6E
0005432693371	7672	23	6F
0005433450180	7672	24	7D
0005432693360	7672	25	7E
0005433450174	7672	26	7F
0005432693362	7672	27	8A
0005432721148	7672	28	8C
0005433450169	7672	29	8D
0005432721156	7672	30	8F
0005432721157	7672	31	9A
0005432721150	7672	32	9C
0005433450166	7672	33	9D
0005432693368	7672	34	9E
0005433450184	7672	35	9F
0005433450164	7672	36	10A
0005433450168	7672	37	10C
0005432693365	7672	38	10D
0005432693353	7672	39	10E
0005432693364	7672	40	10F
0005432693355	7672	41	11C
0005432693369	7672	42	11E
0005432693361	7672	43	11F
0005433450183	7672	44	12A
0005432721152	7672	45	12C
0005432693370	7672	46	12D
0005432693358	7672	47	12E
0005432721161	7672	48	12F
0005432721168	7672	49	13A
0005432721158	7672	50	13C
0005433450181	7672	51	13D
0005433450172	7672	52	13E
0005432693359	7672	53	13F
0005433450179	7672	54	14A
0005432721149	7672	55	14C
0005432721167	7672	56	14E
0005432721147	7672	57	14F
0005432721153	7672	58	15A
0005432721155	7672	59	15C
0005433450175	7672	60	15D
0005432693354	7672	61	15E
0005433450176	7672	62	15F
0005432721166	7672	63	16A
0005432693367	7672	64	16C
0005432721146	7672	65	16D
0005432693372	7672	66	16E
0005432721159	7672	67	16F
0005433450167	7672	68	17A
0005433450177	7672	69	17D
0005432693348	7672	70	18A
0005433450173	7672	71	18C
0005432721165	7672	72	18D
0005432721143	7672	73	18E
0005432721151	7672	74	18F
0005432693351	7672	75	19A
0005432693349	7672	76	19C
0005432071602	7672	77	19D
0005432693350	7672	78	19E
0005432071603	7672	79	19F
0005432693378	7672	80	20A
0005432721169	7672	81	20C
0005432693375	7672	82	20D
0005432721164	7672	83	20F
0005432693158	30317	1	1F
0005432693094	30317	2	2A
0005433449967	30317	3	2C
0005432692912	30317	4	2D
0005433450040	30317	5	2F
0005433449923	30317	6	3C
0005432693100	30317	7	4A
0005433449948	30317	8	4C
0005433449988	30317	9	4D
0005432692911	30317	10	5C
0005432693048	30317	11	5D
0005432693157	30317	12	5F
0005432693029	30317	13	6A
0005433449912	30317	14	6E
0005433450061	30317	15	6F
0005432692973	30317	16	7A
0005433449953	30317	17	7C
0005432693020	30317	18	7D
0005433449946	30317	19	7F
0005433450062	30317	20	8C
0005432693103	30317	21	8D
0005433450065	30317	22	8E
0005432693122	30317	23	9D
0005433449945	30317	24	9E
0005433449977	30317	25	10C
0005433449995	30317	26	10D
0005432692892	30317	27	10E
0005432693045	30317	28	10F
0005432693070	30317	29	11A
0005433449994	30317	30	11D
0005432692974	30317	31	12A
0005433450052	30317	32	12C
0005433449999	30317	33	12D
0005432693150	30317	34	12E
0005433450118	30317	35	12F
0005433449959	30317	36	13A
0005432693121	30317	37	13F
0005432693106	30317	38	14C
0005432693079	30317	39	14E
0005433449978	30317	40	14F
0005432693044	30317	41	15A
0005433449943	30317	42	15C
0005432693104	30317	43	15D
0005432693012	30317	44	15E
0005432693095	30317	45	15F
0005432693101	30317	46	16A
0005432693043	30317	47	16D
0005432692891	30317	48	16E
0005433449911	30317	49	17A
0005433449947	30317	50	17C
0005433450023	30317	51	17D
0005433449944	30317	52	17F
0005433450117	30317	53	18C
0005433450063	30317	54	18D
0005432693151	30317	55	18E
0005432693028	30317	56	18F
0005432693105	30317	57	19A
0005432692995	30317	58	19C
0005432693156	30317	59	19D
0005433449924	30317	60	19E
0005432693011	30317	61	20A
0005433449966	30317	62	20D
0005433450043	30317	63	20E
0005432693168	30317	64	20F
0005432720998	30318	1	1A
0005433123997	30318	2	1C
0005432720976	30318	3	2C
0005432720720	30318	4	2D
0005432720966	30318	5	3A
0005432720918	30318	6	3F
0005432720936	30318	7	4A
0005433722283	30318	8	4C
0005432721012	30318	9	4D
0005432720977	30318	10	5A
0005433123956	30318	11	5C
0005432721027	30318	12	6C
0005432720937	30318	13	7A
0005432720917	30318	14	7C
0005433123926	30318	15	7E
0005432720957	30318	16	8A
0005433123899	30318	17	8C
0005433123930	30318	18	8D
0005433123807	30318	19	9C
0005432720859	30318	20	9D
0005432721069	30318	21	9E
0005432720965	30318	22	10A
0005433124015	30318	23	10C
0005433123808	30318	24	10D
0005433123963	30318	25	10E
0005432720933	30318	26	11A
0005432721013	30318	27	11D
0005433124016	30318	28	11F
0005432720833	30318	29	12D
0005432720992	30318	30	12F
0005432720870	30318	31	13C
0005433123895	30318	32	13D
0005432721087	30318	33	13F
0005432720892	30318	34	15A
0005433123897	30318	35	15D
0005433123957	30318	36	15F
0005432720938	30318	37	16D
0005433123853	30318	38	16E
0005433722282	30318	39	17A
0005432721038	30318	40	17C
0005432720956	30318	41	17D
0005432721022	30318	42	17E
0005433123962	30318	43	17F
0005432720915	30318	44	18E
0005432720887	30318	45	19A
0005433123925	30318	46	19C
0005432720893	30318	47	19D
0005433123876	30318	48	20A
0005432720952	30318	49	20C
0005432721023	30318	50	20E
0005432720991	30318	51	20F
0005433525139	1400	1	1A
0005434514993	1400	2	1D
0005434586848	1400	3	2D
0005434586857	1400	4	2F
0005433193065	1400	5	3C
0005432968849	1400	6	3D
0005434586846	1400	7	3F
0005434513604	1400	8	4A
0005432271031	1400	9	4C
0005433724846	1400	10	4D
0005433193035	1400	11	4E
0005432968840	1400	12	4F
0005434586849	1400	13	5C
0005434513603	1400	14	5D
0005432927996	1400	15	5F
0005434586859	1400	16	6A
0005433525145	1400	17	6D
0005433724850	1400	18	6F
0005433193094	1400	19	7A
0005434586863	1400	20	7C
0005432968841	1400	21	7D
0005433193005	1400	22	7E
0005432927995	1400	23	8A
0005433193066	1400	24	8C
0005433525136	1400	25	8E
0005433193090	1400	26	8F
0005434586858	1400	27	9A
0005434586850	1400	28	9C
0005433193089	1400	29	9D
0005433193076	1400	30	9E
0005434586854	1400	31	9F
0005433525140	1400	32	10A
0005434586862	1400	33	10C
0005434513605	1400	34	10D
0005434586855	1400	35	10E
0005434514991	1400	36	11A
0005433193126	1400	37	11C
0005434586853	1400	38	11D
0005434586852	1400	39	11E
0005433724848	1400	40	11F
0005433193049	1400	41	12A
0005433525144	1400	42	12C
0005434514992	1400	43	12D
0005434586860	1400	44	12E
0005432271032	1400	45	12F
0005433193074	1400	46	13A
0005432968850	1400	47	13C
0005433193088	1400	48	13E
0005433724849	1400	49	13F
0005433193068	1400	50	14D
0005433193067	1400	51	14E
0005433525137	1400	52	14F
0005432928004	1400	53	15C
0005434586847	1400	54	15D
0005433525141	1400	55	15F
0005433193004	1400	56	16D
0005433724847	1400	57	16F
0005433193026	1400	58	17D
0005434586865	1400	59	17E
0005433525146	1400	60	18A
0005433193036	1400	61	18C
0005434586844	1400	62	18D
0005434586861	1400	63	18E
0005433525143	1400	64	18F
0005433525142	1400	65	19A
0005434586845	1400	66	19C
0005434586843	1400	67	19D
0005434586864	1400	68	19F
0005433525138	1400	69	20A
0005434586842	1400	70	20C
0005434586851	1400	71	20D
0005434586856	1400	72	20E
0005434586866	1400	73	20F
0005433525037	18540	1	1A
0005433525025	18540	2	1C
0005434586694	18540	3	1F
0005434586659	18540	4	2A
0005433193178	18540	5	2C
0005433525026	18540	6	2D
0005433724783	18540	7	3A
0005434586580	18540	8	3C
0005432968862	18540	9	3D
0005433193177	18540	10	3F
0005433525038	18540	11	4A
0005433193169	18540	12	4C
0005433525005	18540	13	4D
0005433525034	18540	14	4E
0005432928032	18540	15	4F
0005433525041	18540	16	5A
0005433724782	18540	17	5C
0005433525029	18540	18	5D
0005433525027	18540	19	5E
0005434586589	18540	20	6A
0005433525061	18540	21	6C
0005434586622	18540	22	6D
0005434586660	18540	23	6E
0005433193164	18540	24	6F
0005434586693	18540	25	7A
0005433193165	18540	26	7C
0005433193176	18540	27	7D
0005433525036	18540	28	7F
0005433724802	18540	29	8A
0005432928033	18540	30	8F
0005433193175	18540	31	10A
0005433724809	18540	32	10C
0005434586596	18540	33	10D
0005434586752	18540	34	10E
0005433193174	18540	35	10F
0005434586630	18540	36	11A
0005434586645	18540	37	11C
0005433193166	18540	38	11D
0005433525048	18540	39	11E
0005433193172	18540	40	11F
0005434586647	18540	41	12A
0005433525047	18540	42	12C
0005434514970	18540	43	12D
0005433525030	18540	44	12E
0005434586526	18540	45	13A
0005432968860	18540	46	13C
0005433525056	18540	47	13D
0005433193171	18540	48	13E
0005433525004	18540	49	14A
0005433724784	18540	50	14C
0005434586621	18540	51	14D
0005433724785	18540	52	14E
0005434586654	18540	53	14F
0005433724808	18540	54	15A
0005434514965	18540	55	15C
0005433193173	18540	56	15E
0005432968863	18540	57	15F
0005433525006	18540	58	16A
0005432928029	18540	59	16C
0005432968861	18540	60	16D
0005433525028	18540	61	16E
0005434586648	18540	62	16F
0005433193170	18540	63	17C
0005434514962	18540	64	17D
0005432928031	18540	65	17F
0005433193168	18540	66	18A
0005432928030	18540	67	18C
0005434586646	18540	68	18D
0005434586584	18540	69	18F
0005434586595	18540	70	19A
0005434514969	18540	71	19C
0005433525003	18540	72	20A
0005434586746	18540	73	20C
0005433193167	18540	74	20D
0005434586528	18540	75	20F
0005435302194	11435	1	1A
0005434344520	11435	2	1B
0005434344527	11435	3	1C
0005434142647	11435	4	1D
0005434344505	11435	5	2A
0005434344503	11435	6	2B
0005434344499	11435	7	2C
0005434344514	11435	8	2D
0005434344516	11435	9	3A
0005434142649	11435	10	3B
0005434344528	11435	11	3C
0005435302214	11435	12	3D
0005434344517	11435	13	4A
0005435302196	11435	14	4B
0005435302173	11435	15	4C
0005435302195	11435	16	4D
0005434344511	11435	17	5A
0005434344500	11435	18	5B
0005434344524	11435	19	5C
0005434344522	11435	20	5D
0005434344510	11435	21	6A
0005434344531	11435	22	6B
0005435302215	11435	23	6C
0005434142648	11435	24	6D
0005434344521	11435	25	7B
0005434344526	11435	26	7C
0005434344506	11435	27	7D
0005434142646	11435	28	18B
0005434344502	11435	29	18C
0005434344508	11435	30	18D
0005434344509	11435	31	19A
0005435302210	11435	32	19B
0005434344525	11435	33	19C
0005434344504	11435	34	19D
0005434344512	11435	35	20A
0005434344519	11435	36	20B
0005434344529	11435	37	20C
0005435305013	11435	38	20D
0005434344532	11435	39	21A
0005434344507	11435	40	21B
0005435302220	11435	41	21C
0005434344513	11435	42	21D
0005434344523	11435	43	22B
0005434344501	11435	44	22C
0005434344530	11435	45	22D
0005434344515	11435	46	23A
0005434344518	11435	47	23B
0005435305034	29806	1	1A
0005434344199	29806	2	1B
0005434344152	29806	3	1D
0005434142612	29806	4	2A
0005434344162	29806	5	2B
0005434344261	29806	6	3A
0005434344154	29806	7	3B
0005435305032	29806	8	3C
0005434344236	29806	9	3D
0005434344217	29806	10	4A
0005435304199	29806	11	4C
0005434344405	29806	12	4D
0005435304200	29806	13	5A
0005435305033	29806	14	5B
0005434344373	29806	15	5C
0005434344222	29806	16	5D
0005434344265	29806	17	6B
0005434344225	29806	18	6C
0005435304201	29806	19	6D
0005434344244	29806	20	7A
0005434344311	29806	21	7B
0005434344273	29806	22	7C
0005434344312	29806	23	7D
0005434142595	29806	24	18B
0005434344190	29806	25	18C
0005435304198	29806	26	18D
0005434344198	29806	27	19A
0005434142599	29806	28	19B
0005434344469	29806	29	20A
0005434344243	29806	30	20B
0005434344242	29806	31	20C
0005434344138	29806	32	20D
0005434344372	29806	33	21A
0005434344153	29806	34	21B
0005434344030	29806	35	21C
0005434344183	29806	36	21D
0005434344221	29806	37	22A
0005435304202	29806	38	22C
0005434344182	29806	39	22D
0005434344285	29806	40	23A
0005434344280	29806	41	23B
0005435824866	1258	1	1C
0005433415725	1258	2	1D
0005433415683	1258	3	2C
0005435824876	1258	4	2F
0005435824874	1258	5	2D
0005435824879	1258	6	3D
0005432284587	1258	7	3C
0005435824870	1258	8	4F
0005435824892	1258	9	5D
0005435824880	1258	10	6B
0005432284585	1258	11	7C
0005433415698	1258	12	8D
0005435824875	1258	13	8C
0005433415738	1258	14	8F
0005433415665	1258	15	9B
0005433415727	1258	16	9A
0005433415643	1258	17	9E
0005435824889	1258	18	10C
0005433415596	1258	19	10B
0005435824890	1258	20	10E
0005435824872	1258	21	10D
0005433415597	1258	22	11A
0005433415709	1258	23	12D
0005432284586	1258	24	13B
0005435824878	1258	25	12F
0005435824868	1258	26	13E
0005435824888	1258	27	14B
0005435824867	1258	28	14E
0005433415666	1258	29	15A
0005433415678	1258	30	15C
0005433415674	1258	31	15D
0005435824881	1258	32	15F
0005435824886	1258	33	16B
0005433415732	1258	34	16D
0005435824885	1258	35	17A
0005433415642	1258	36	17F
0005435824887	1258	37	17E
0005435824871	1258	38	18A
0005433415680	1258	39	18F
0005435824873	1258	40	18D
0005435824869	1258	41	19A
0005433415679	1258	42	19B
0005435824877	1258	43	19D
0005435824882	1258	44	20A
0005435824865	1258	45	20D
0005435824883	1258	46	20C
0005435824884	1258	47	21A
0005433415728	1258	48	21C
0005435824891	1258	49	21B
0005433415691	1258	50	21E
0005433415612	1258	51	21D
0005433415616	1258	52	21F
0005435824648	18027	1	1A
0005435824667	18027	2	1F
0005433415802	18027	3	1D
0005435824724	18027	4	3D
0005435824603	18027	5	4A
0005435824725	18027	6	3F
0005435824612	18027	7	5C
0005433415817	18027	8	5F
0005433415814	18027	9	6D
0005435824647	18027	10	6C
0005433415805	18027	11	6F
0005435824568	18027	12	7A
0005433415806	18027	13	7C
0005435824723	18027	14	7E
0005435824669	18027	15	7F
0005435824601	18027	16	8B
0005435824558	18027	17	8D
0005435824684	18027	18	8C
0005435824578	18027	19	9B
0005435824670	18027	20	9F
0005435824674	18027	21	10B
0005433415811	18027	22	10F
0005435824611	18027	23	11B
0005435824553	18027	24	11C
0005435824567	18027	25	12B
0005433415804	18027	26	12D
0005435824666	18027	27	13B
0005435824660	18027	28	13C
0005435824653	18027	29	13E
0005435824579	18027	30	14B
0005433415812	18027	31	14A
0005435824548	18027	32	14F
0005433415808	18027	33	15B
0005433415807	18027	34	15A
0005433415815	18027	35	15D
0005433415816	18027	36	15F
0005435824637	18027	37	16A
0005435824540	18027	38	16C
0005435824649	18027	39	16F
0005435824624	18027	40	17A
0005435824600	18027	41	17C
0005435824604	18027	42	17E
0005435824596	18027	43	18C
0005435824668	18027	44	18F
0005433415813	18027	45	19C
0005433415803	18027	46	19B
0005435824625	18027	47	19D
0005433415809	18027	48	19F
0005435824726	18027	49	20B
0005435824806	18027	50	20C
0005433415810	18027	51	21B
0005435824580	18027	52	21D
0005434460517	12574	1	2B
0005434461663	12574	2	2C
0005434461658	12574	3	2D
0005434461660	12574	4	3A
0005434460522	12574	5	3C
0005434460520	12574	6	5A
0005434460519	12574	7	5B
0005434460523	12574	8	5D
0005434461662	12574	9	6B
0005434461659	12574	10	6D
0005434460521	12574	11	7B
0005434461661	12574	12	18C
0005434461657	12574	13	19A
0005434460518	12574	14	19B
0005434461664	12574	15	21B
0005434461665	12574	16	21D
0005434460524	12574	17	23B
0005432784304	5649	1	1A
0005435242859	5649	2	1D
0005435476745	5649	3	1F
0005435242847	5649	4	2A
0005435476746	5649	5	2C
0005432784285	5649	6	2D
0005432784276	5649	7	2F
0005435242956	5649	8	3A
0005435242939	5649	9	3C
0005435242921	5649	10	3D
0005435242946	5649	11	3F
0005432784320	5649	12	4C
0005432784303	5649	13	4D
0005432784302	5649	14	4E
0005435476760	5649	15	4F
0005432784293	5649	16	5A
0005432784295	5649	17	5C
0005435476753	5649	18	5E
0005432144019	5649	19	5F
0005432784321	5649	20	6A
0005432784272	5649	21	6C
0005435242868	5649	22	6D
0005432784309	5649	23	6E
0005432784288	5649	24	6F
0005435476762	5649	25	7A
0005432784315	5649	26	7C
0005432784271	5649	27	7D
0005435476740	5649	28	7E
0005435476758	5649	29	7F
0005432784313	5649	30	8A
0005435476748	5649	31	8C
0005432784312	5649	32	8D
0005432784292	5649	33	8E
0005432784297	5649	34	8F
0005435242864	5649	35	9A
0005432784286	5649	36	9C
0005432784278	5649	37	9D
0005432784306	5649	38	9E
0005435242935	5649	39	9F
0005432784283	5649	40	10A
0005432784291	5649	41	10C
0005432784324	5649	42	10E
0005435242878	5649	43	10F
0005435242869	5649	44	11A
0005432784279	5649	45	11C
0005435242879	5649	46	11D
0005432784273	5649	47	11E
0005432784296	5649	48	11F
0005432784284	5649	49	12A
0005432784287	5649	50	12C
0005432784316	5649	51	12D
0005435242865	5649	52	12E
0005432784317	5649	53	12F
0005432784281	5649	54	13A
0005432784307	5649	55	13C
0005432784289	5649	56	13D
0005432784280	5649	57	13E
0005432784308	5649	58	13F
0005432784290	5649	59	14A
0005432784318	5649	60	14C
0005435476759	5649	61	14D
0005432784301	5649	62	14E
0005435242914	5649	63	14F
0005435242850	5649	64	15A
0005435242934	5649	65	15C
0005432784298	5649	66	15D
0005432784325	5649	67	15E
0005432144017	5649	68	15F
0005432784275	5649	69	16A
0005432784314	5649	70	16C
0005432784277	5649	71	16D
0005432784322	5649	72	16E
0005432784282	5649	73	16F
0005432784323	5649	74	17A
0005432144018	5649	75	17C
0005435242800	5649	76	17D
0005432784300	5649	77	17F
0005432784299	5649	78	18A
0005435242904	5649	79	18C
0005435476766	5649	80	18D
0005432784319	5649	81	18E
0005435242752	5649	82	18F
0005432784274	5649	83	19A
0005432784310	5649	84	19C
0005435242858	5649	85	19D
0005432784311	5649	86	19F
0005435242860	5649	87	20A
0005432784305	5649	88	20C
0005432784294	5649	89	20E
0005435242920	5649	90	20F
0005432783800	15384	1	1A
0005435243094	15384	2	1C
0005432784011	15384	3	1F
0005432783812	15384	4	2A
0005435243092	15384	5	2C
0005432783921	15384	6	2D
0005432783883	15384	7	2F
0005435243081	15384	8	3A
0005435476823	15384	9	3C
0005432783938	15384	10	3D
0005432783799	15384	11	3F
0005432783876	15384	12	4A
0005432783689	15384	13	4C
0005432783939	15384	14	4D
0005435243077	15384	15	4E
0005432784012	15384	16	5A
0005432783647	15384	17	5C
0005432783751	15384	18	5D
0005432783768	15384	19	5F
0005432783916	15384	20	6A
0005435243079	15384	21	6C
0005432783729	15384	22	6D
0005432783603	15384	23	6F
0005432783872	15384	24	7A
0005432783699	15384	25	7C
0005432783788	15384	26	7D
0005435243097	15384	27	7E
0005432783892	15384	28	7F
0005435243102	15384	29	8A
0005432783879	15384	30	8C
0005432783744	15384	31	8D
0005435243099	15384	32	8E
0005432784041	15384	33	8F
0005432783597	15384	34	9A
0005435243091	15384	35	9C
0005432783711	15384	36	9D
0005432783769	15384	37	9F
0005432783684	15384	38	10A
0005432783598	15384	39	10C
0005435243090	15384	40	10D
0005435243075	15384	41	10E
0005435243078	15384	42	10F
0005432783743	15384	43	11A
0005432783734	15384	44	11C
0005432784050	15384	45	11D
0005432783750	15384	46	12A
0005432784042	15384	47	12C
0005432783819	15384	48	12D
0005432784051	15384	49	12E
0005435476825	15384	50	12F
0005432783688	15384	51	13A
0005432783881	15384	52	13C
0005432783563	15384	53	13D
0005435243101	15384	54	13F
0005435243088	15384	55	13E
0005432783882	15384	56	14A
0005432783785	15384	57	14C
0005435243100	15384	58	14D
0005435243089	15384	59	14E
0005432783820	15384	60	14F
0005432783807	15384	61	15A
0005435476826	15384	62	15C
0005435243076	15384	63	15E
0005435243080	15384	64	15F
0005432783631	15384	65	16A
0005435243085	15384	66	16C
0005435243086	15384	67	16D
0005435243093	15384	68	16E
0005432783806	15384	69	16F
0005435243082	15384	70	17A
0005432783843	15384	71	17C
0005435243095	15384	72	17D
0005435476824	15384	73	17E
0005432783765	15384	74	17F
0005432783811	15384	75	18A
0005432783891	15384	76	18C
0005435243074	15384	77	18D
0005432783745	15384	78	18E
0005432783712	15384	79	18F
0005435476822	15384	80	19A
0005435243096	15384	81	19C
0005435243087	15384	82	19D
0005435243084	15384	83	19F
0005435243098	15384	84	20A
0005432783599	15384	85	20C
0005432783875	15384	86	20D
0005432783564	15384	87	20E
0005435243083	15384	88	20F
0005435850926	4391	1	1B
0005435850889	4391	2	2A
0005432848446	4391	3	2B
0005434463949	4391	4	2C
0005432848456	4391	5	2D
0005434463951	4391	6	3C
0005435850910	4391	7	3D
0005432848447	4391	8	4D
0005435850931	4391	9	5A
0005432848454	4391	10	5B
0005435850932	4391	11	5C
0005432848442	4391	12	7A
0005432848452	4391	13	7B
0005432848448	4391	14	7C
0005435850953	4391	15	7D
0005434462810	4391	16	18A
0005432848445	4391	17	18B
0005434462811	4391	18	18D
0005432848444	4391	19	19A
0005432848455	4391	20	19B
0005432848451	4391	21	20C
0005432848443	4391	22	20D
0005434462809	4391	23	21A
0005434463950	4391	24	21C
0005432848453	4391	25	22B
0005432848449	4391	26	22D
0005432848450	4391	27	23B
0005434463920	28871	1	1A
0005432848330	28871	2	1B
0005432848316	28871	3	2A
0005435850998	28871	4	2B
0005432848329	28871	5	2C
0005435851000	28871	6	2D
0005435850993	28871	7	3C
0005435850992	28871	8	3D
0005432848321	28871	9	4A
0005432848277	28871	10	5A
0005432848236	28871	11	5B
0005432848286	28871	12	5C
0005432848285	28871	13	5D
0005435850994	28871	14	6C
0005432848299	28871	15	7A
0005432848313	28871	16	7D
0005435850999	28871	17	18A
0005432848281	28871	18	18B
0005432848322	28871	19	18D
0005435850997	28871	20	19A
0005434461650	28871	21	19C
0005432848318	28871	22	19D
0005432848317	28871	23	20A
0005435850996	28871	24	20C
0005435850991	28871	25	21C
0005432848310	28871	26	22B
0005432848319	28871	27	22D
0005432848280	28871	28	23A
0005435850995	28871	29	23B
0005434926120	6318	1	1A
0005434443863	6318	2	1C
0005434443855	6318	3	1D
0005433497265	6318	4	1F
0005434926114	6318	5	2A
0005433497281	6318	6	2C
0005432075262	6318	7	2D
0005434926131	6318	8	2F
0005433497257	6318	9	3A
0005434926104	6318	10	3C
0005433497266	6318	11	3F
0005434926106	6318	12	4A
0005433497259	6318	13	4D
0005434926124	6318	14	4E
0005434926135	6318	15	4F
0005432075264	6318	16	5C
0005434443854	6318	17	5D
0005433497251	6318	18	5E
0005434926101	6318	19	5F
0005432075263	6318	20	6C
0005434443857	6318	21	6D
0005434443856	6318	22	6E
0005433497255	6318	23	7A
0005434443859	6318	24	7C
0005433497273	6318	25	7D
0005434926103	6318	26	7E
0005433497278	6318	27	7F
0005433497250	6318	28	8A
0005433497269	6318	29	8C
0005433497276	6318	30	8D
0005434926113	6318	31	8E
0005433497268	6318	32	8F
0005433497274	6318	33	9A
0005434926121	6318	34	9C
0005434926099	6318	35	9D
0005433497253	6318	36	9F
0005434926125	6318	37	10A
0005433497258	6318	38	10C
0005433497272	6318	39	10D
0005433497263	6318	40	10E
0005434926134	6318	41	10F
0005433497277	6318	42	11A
0005434443858	6318	43	11C
0005434926123	6318	44	11D
0005434443861	6318	45	11E
0005434443869	6318	46	11F
0005434443866	6318	47	12A
0005434926098	6318	48	12C
0005433497260	6318	49	12D
0005434926116	6318	50	12E
0005433497261	6318	51	12F
0005434443865	6318	52	13A
0005434926108	6318	53	13C
0005433497264	6318	54	13D
0005433497270	6318	55	13E
0005434926130	6318	56	13F
0005433497275	6318	57	14A
0005434443860	6318	58	14C
0005433497280	6318	59	14D
0005434926122	6318	60	14E
0005434443864	6318	61	14F
0005434926128	6318	62	15A
0005433497271	6318	63	15C
0005434926105	6318	64	15D
0005434926110	6318	65	15E
0005434926133	6318	66	15F
0005434443868	6318	67	16A
0005433497267	6318	68	16C
0005434926111	6318	69	16D
0005434926118	6318	70	16E
0005434926117	6318	71	17A
0005434443867	6318	72	17C
0005434926119	6318	73	17D
0005434926129	6318	74	17E
0005434926126	6318	75	17F
0005434926132	6318	76	18A
0005434926102	6318	77	18C
0005433497279	6318	78	18D
0005434926127	6318	79	18E
0005434926107	6318	80	18F
0005434926100	6318	81	19A
0005433497254	6318	82	19C
0005434926109	6318	83	19D
0005434926115	6318	84	19E
0005434926112	6318	85	19F
0005433497256	6318	86	20A
0005434443862	6318	87	20C
0005433497252	6318	88	20D
0005433497262	6318	89	20E
0005434925760	20431	1	1A
0005433497032	20431	2	1C
0005434925753	20431	3	1D
0005434925769	20431	4	1F
0005434925824	20431	5	2A
0005433496950	20431	6	2C
0005434443694	20431	7	2D
0005433496964	20431	8	2F
0005434443720	20431	9	3A
0005434925822	20431	10	3C
0005433496987	20431	11	3D
0005434925821	20431	12	4A
0005433497068	20431	13	4C
0005433497159	20431	14	4D
0005433497063	20431	15	4E
0005433497152	20431	16	4F
0005434925764	20431	17	5A
0005434443794	20431	18	5F
0005433497034	20431	19	6A
0005433497151	20431	20	6E
0005434925790	20431	21	6F
0005434443768	20431	22	7C
0005433496963	20431	23	7E
0005433497050	20431	24	7F
0005434443671	20431	25	8A
0005434925809	20431	26	8C
0005434925799	20431	27	8D
0005434925776	20431	28	8E
0005434443699	20431	29	8F
0005433497049	20431	30	9A
0005434925825	20431	31	9C
0005433496826	20431	32	9E
0005434443711	20431	33	10A
0005434925759	20431	34	10C
0005434925823	20431	35	10D
0005434443710	20431	36	10E
0005434925752	20431	37	10F
0005434443727	20431	38	11C
0005434925762	20431	39	11A
0005433497069	20431	40	11D
0005433497081	20431	41	11E
0005434925755	20431	42	12A
0005433497030	20431	43	12C
0005434925765	20431	44	12D
0005433496962	20431	45	12E
0005433496955	20431	46	12F
0005434925791	20431	47	13A
0005434925798	20431	48	13C
0005434443783	20431	49	13D
0005433496915	20431	50	13F
0005433497025	20431	51	14A
0005434925751	20431	52	14C
0005434925784	20431	53	14D
0005433496951	20431	54	14F
0005434925754	20431	55	15A
0005434925810	20431	56	15E
0005434443683	20431	57	15F
0005434443692	20431	58	16A
0005433496825	20431	59	16C
0005434925768	20431	60	16D
0005434925782	20431	61	16E
0005433497209	20431	62	16F
0005433497176	20431	63	17A
0005434443754	20431	64	17D
0005434925783	20431	65	17E
0005433497031	20431	66	18A
0005433497033	20431	67	18C
0005433496988	20431	68	18E
0005433497040	20431	69	18F
0005433496986	20431	70	19A
0005434443709	20431	71	19C
0005434443693	20431	72	19D
0005434443730	20431	73	19E
0005434443782	20431	74	19F
0005434925763	20431	75	20A
0005433497080	20431	76	20C
0005433497147	20431	77	20D
0005434443753	20431	78	20E
0005433497067	20431	79	20F
0005432783927	12205	1	1A
0005432783848	12205	2	1D
0005432783906	12205	3	3C
0005435243121	12205	4	3D
0005435243105	12205	5	3F
0005435243124	12205	6	4A
0005432784049	12205	7	4C
0005432783888	12205	8	4D
0005435243103	12205	9	4E
0005432783952	12205	10	4F
0005432783887	12205	11	5C
0005432783668	12205	12	6F
0005432783583	12205	13	7A
0005435243111	12205	14	7C
0005432783678	12205	15	7D
0005432783897	12205	16	7E
0005432783898	12205	17	7F
0005435243113	12205	18	8D
0005435243127	12205	19	8E
0005435243106	12205	20	8F
0005432783994	12205	21	9A
0005432783948	12205	22	9C
0005432783780	12205	23	9D
0005435243128	12205	24	9E
0005432783735	12205	25	9F
0005432783713	12205	26	10A
0005435243125	12205	27	10C
0005435243119	12205	28	10E
0005435243108	12205	29	10F
0005432783926	12205	30	11A
0005432783779	12205	31	11C
0005432783988	12205	32	11D
0005432783995	12205	33	11F
0005435243112	12205	34	12C
0005435243118	12205	35	12D
0005435243107	12205	36	13A
0005435243110	12205	37	13E
0005435243109	12205	38	13F
0005432783667	12205	39	14C
0005435243120	12205	40	15A
0005432783942	12205	41	15C
0005435243126	12205	42	15F
0005432783855	12205	43	16A
0005435243115	12205	44	16F
0005432783929	12205	45	17A
0005432784003	12205	46	17C
0005435243114	12205	47	17E
0005432783949	12205	48	17F
0005435243122	12205	49	18C
0005432783702	12205	50	18D
0005432783778	12205	51	18E
0005435243104	12205	52	18F
0005432783941	12205	53	19A
0005435243117	12205	54	19C
0005432783849	12205	55	19D
0005435243116	12205	56	19E
0005435243123	12205	57	20A
0005432783553	12205	58	20C
0005432783714	12205	59	20E
0005432783928	12205	60	20F
0005432784253	15436	1	1A
0005432784262	15436	2	1C
0005432784255	15436	3	1D
0005432784261	15436	4	1F
0005435242779	15436	5	2A
0005435242789	15436	6	2C
0005432784233	15436	7	2D
0005432784218	15436	8	2F
0005435242822	15436	9	3A
0005432784268	15436	10	3C
0005435242835	15436	11	3D
0005432784231	15436	12	3F
0005432784222	15436	13	4A
0005432784246	15436	14	4C
0005432784248	15436	15	4D
0005432784232	15436	16	4E
0005435242791	15436	17	4F
0005432784242	15436	18	5A
0005435242792	15436	19	5C
0005435242824	15436	20	5D
0005435242834	15436	21	6A
0005435242765	15436	22	6C
0005432784217	15436	23	6D
0005435242842	15436	24	6E
0005432784228	15436	25	6F
0005435242931	15436	26	7A
0005432784256	15436	27	7C
0005432784254	15436	28	7D
0005432784266	15436	29	7E
0005432784263	15436	30	7F
0005435242766	15436	31	8A
0005432784220	15436	32	8C
0005432784237	15436	33	8D
0005435242833	15436	34	8E
0005432784258	15436	35	8F
0005432784269	15436	36	9A
0005432784259	15436	37	9D
0005432784270	15436	38	9E
0005435242844	15436	39	9F
0005432784244	15436	40	10C
0005432784240	15436	41	10D
0005432784260	15436	42	10E
0005435242820	15436	43	10F
0005432784224	15436	44	11A
0005435242790	15436	45	11C
0005432784225	15436	46	11D
0005435242836	15436	47	11F
0005432784267	15436	48	12A
0005435242772	15436	49	12D
0005432784251	15436	50	12E
0005435242977	15436	51	12F
0005432784230	15436	52	13A
0005432784234	15436	53	13C
0005435242773	15436	54	13D
0005435242778	15436	55	13E
0005435242895	15436	56	14A
0005435242843	15436	57	14C
0005435242893	15436	58	14D
0005432784223	15436	59	14E
0005432784236	15436	60	14F
0005435242900	15436	61	15A
0005435242978	15436	62	15C
0005435242823	15436	63	15D
0005432784252	15436	64	15E
0005432784241	15436	65	15F
0005432784249	15436	66	16C
0005432784226	15436	67	16D
0005432784239	15436	68	16E
0005432784221	15436	69	16F
0005435242899	15436	70	17A
0005432784265	15436	71	17C
0005435242782	15436	72	17D
0005432784243	15436	73	17E
0005432784229	15436	74	17F
0005432784250	15436	75	18A
0005432784227	15436	76	18C
0005432784238	15436	77	18D
0005432784245	15436	78	18F
0005435242959	15436	79	19A
0005432784247	15436	80	19C
0005435242781	15436	81	19E
0005435242756	15436	82	19F
0005432784219	15436	83	20A
0005432784257	15436	84	20C
0005432784235	15436	85	20D
0005435242932	15436	86	20E
0005432784264	15436	87	20F
0005434878169	10113	1	1C
0005434878215	10113	2	1A
0005434878272	10113	3	1F
0005434878489	10113	4	1D
0005434878401	10113	5	2A
0005434878077	10113	6	2D
0005434878381	10113	7	2C
0005434878294	10113	8	3A
0005434878243	10113	9	2F
0005434878510	10113	10	3D
0005434878512	10113	11	3C
0005434878070	10113	12	4A
0005434878329	10113	13	3F
0005434878140	10113	14	4C
0005434877859	10113	15	4F
0005434878347	10113	16	4D
0005434878158	10113	17	5C
0005434878259	10113	18	5A
0005434878378	10113	19	5F
0005434878375	10113	20	5D
0005434878362	10113	21	6B
0005434878424	10113	22	6A
0005434878430	10113	23	6C
0005434878349	10113	24	6E
0005434878440	10113	25	6D
0005434877967	10113	26	7A
0005434878448	10113	27	6F
0005434878125	10113	28	7C
0005434878083	10113	29	7B
0005434878348	10113	30	7E
0005434878392	10113	31	7D
0005434878248	10113	32	8A
0005434878208	10113	33	7F
0005434878230	10113	34	8B
0005434878326	10113	35	8D
0005434878575	10113	36	8C
0005434878181	10113	37	8F
0005434877853	10113	38	8E
0005434878550	10113	39	9B
0005434878124	10113	40	9A
0005434878457	10113	41	9D
0005434878084	10113	42	9C
0005434878257	10113	43	9E
0005434878519	10113	44	10A
0005434877854	10113	45	9F
0005434878324	10113	46	10C
0005434877874	10113	47	10B
0005434878328	10113	48	10E
0005434877918	10113	49	10D
0005434878266	10113	50	10F
0005434878327	10113	51	11B
0005434878072	10113	52	11A
0005434877965	10113	53	11E
0005434877890	10113	54	11D
0005434878159	10113	55	11C
0005434877895	10113	56	11F
0005434878309	10113	57	12B
0005434878258	10113	58	12A
0005434878268	10113	59	12C
0005434877917	10113	60	12E
0005434878361	10113	61	12D
0005434877872	10113	62	13B
0005434878154	10113	63	13A
0005434878388	10113	64	12F
0005434878481	10113	65	13C
0005434878330	10113	66	13E
0005434878482	10113	67	13D
0005434878236	10113	68	14A
0005434878340	10113	69	13F
0005434877879	10113	70	14C
0005434878078	10113	71	14B
0005434878570	10113	72	14D
0005434878425	10113	73	14F
0005434878400	10113	74	14E
0005434878544	10113	75	15A
0005434878518	10113	76	15C
0005434878076	10113	77	15B
0005434878235	10113	78	15E
0005434878325	10113	79	15D
0005434878082	10113	80	16A
0005434877894	10113	81	15F
0005434878189	10113	82	16C
0005434878244	10113	83	16B
0005434878311	10113	84	16E
0005434878461	10113	85	16D
0005434878545	10113	86	16F
0005434878206	10113	87	17B
0005434878139	10113	88	17A
0005434878273	10113	89	17D
0005434878126	10113	90	17C
0005434878255	10113	91	17F
0005434878287	10113	92	17E
0005434878441	10113	93	18B
0005434878533	10113	94	18A
0005434878265	10113	95	18C
0005434878536	10113	96	18E
0005434878480	10113	97	18D
0005434878427	10113	98	19A
0005434878444	10113	99	18F
0005434877964	10113	100	19C
0005434878558	10113	101	19B
0005434878511	10113	102	19D
0005434878549	10113	103	19F
0005434878366	10113	104	19E
0005434878431	10113	105	20B
0005434878439	10113	106	20A
0005434878377	10113	107	20D
0005434878203	10113	108	20C
0005434877980	10113	109	20F
0005434878571	10113	110	20E
0005434878458	10113	111	21A
0005434877839	10113	112	21C
0005434877873	10113	113	21E
0005434878574	10113	114	21D
0005434878227	10113	115	21F
0005434879128	14644	1	1C
0005434879122	14644	2	1A
0005434879126	14644	3	1F
0005434879094	14644	4	1D
0005434879132	14644	5	2A
0005434879112	14644	6	2D
0005434879089	14644	7	3A
0005434879125	14644	8	3D
0005434879058	14644	9	3C
0005435913928	14644	10	3F
0005434879093	14644	11	4D
0005434879098	14644	12	4C
0005434879090	14644	13	4A
0005434879102	14644	14	5A
0005434879116	14644	15	4F
0005434879137	14644	16	5D
0005434879056	14644	17	5C
0005434879143	14644	18	5F
0005434879152	14644	19	6B
0005434758916	14644	20	6A
0005434879076	14644	21	6C
0005434879057	14644	22	6E
0005434879140	14644	23	6D
0005434879120	14644	24	7A
0005434879085	14644	25	6F
0005434879134	14644	26	7C
0005434879139	14644	27	7B
0005434879124	14644	28	7E
0005434879075	14644	29	7F
0005434879055	14644	30	8C
0005434910113	14644	31	8B
0005434879079	14644	32	8A
0005434879091	14644	33	8D
0005434910115	14644	34	8F
0005434879065	14644	35	8E
0005434879084	14644	36	9B
0005434879096	14644	37	9A
0005434879061	14644	38	9C
0005434879066	14644	39	9E
0005434879097	14644	40	9D
0005434879138	14644	41	10A
0005434879136	14644	42	9F
0005434879115	14644	43	10C
0005434879100	14644	44	10B
0005434879067	14644	45	10E
0005434758915	14644	46	10D
0005434879088	14644	47	11A
0005434879099	14644	48	10F
0005434879107	14644	49	11C
0005434879086	14644	50	11B
0005434879110	14644	51	11D
0005434879062	14644	52	11F
0005434879109	14644	53	11E
0005434879078	14644	54	12B
0005434910112	14644	55	12A
0005434879104	14644	56	12D
0005434879068	14644	57	12C
0005434879121	14644	58	12E
0005434879069	14644	59	13A
0005434879113	14644	60	12F
0005434879095	14644	61	13C
0005434879071	14644	62	13B
0005434879123	14644	63	13E
0005434879105	14644	64	13D
0005434879114	14644	65	14A
0005434879141	14644	66	13F
0005434879135	14644	67	14B
0005434879064	14644	68	14D
0005434879082	14644	69	14C
0005434879117	14644	70	14F
0005434879106	14644	71	15B
0005434879133	14644	72	15A
0005434879073	14644	73	15D
0005434879087	14644	74	15C
0005434879108	14644	75	15F
0005434879077	14644	76	15E
0005434879081	14644	77	16B
0005434879118	14644	78	16A
0005434879147	14644	79	16C
0005434879070	14644	80	16D
0005434879151	14644	81	17A
0005434879144	14644	82	16F
0005434879072	14644	83	17B
0005434879119	14644	84	17D
0005434879145	14644	85	17C
0005434879146	14644	86	17F
0005434879103	14644	87	17E
0005434879060	14644	88	18B
0005434879129	14644	89	18D
0005434879149	14644	90	18E
0005434879142	14644	91	19A
0005434879092	14644	92	18F
0005434879083	14644	93	19D
0005434879127	14644	94	19C
0005434879101	14644	95	19F
0005435913930	14644	96	19E
0005434879059	14644	97	20B
0005434879074	14644	98	20A
0005434879080	14644	99	20D
0005434879130	14644	100	20C
0005434879131	14644	101	20F
0005434879150	14644	102	21B
0005434879111	14644	103	21A
0005434879148	14644	104	21C
0005434758914	14644	105	21E
0005434879063	14644	106	21D
0005435660243	9260	1	1A
0005435660239	9260	2	1B
0005434251966	9260	3	2C
0005435660242	9260	4	2D
0005435660241	9260	5	3A
0005435660244	9260	6	3C
0005434251969	9260	7	3D
0005435660246	9260	8	4B
0005434251958	9260	9	4D
0005435660236	9260	10	5A
0005435660240	9260	11	6A
0005434251986	9260	12	6B
0005434251968	9260	13	6C
0005434251945	9260	14	7A
0005434251954	9260	15	7B
0005434251993	9260	16	18A
0005435660247	9260	17	7D
0005435660245	9260	18	18D
0005434252026	9260	19	21A
0005435660238	9260	20	21B
0005434251965	9260	21	21C
0005435660237	9260	22	22D
0005435660146	24648	1	1B
0005434252055	24648	2	2A
0005435660145	24648	3	2C
0005435660123	24648	4	2D
0005434252049	24648	5	3B
0005435660124	24648	6	3C
0005434252051	24648	7	6A
0005434252053	24648	8	6B
0005434252058	24648	9	6C
0005435660138	24648	10	7A
0005434252048	24648	11	7D
0005435660157	24648	12	18A
0005434252052	24648	13	19A
0005434252054	24648	14	20D
0005434252056	24648	15	22C
0005434252050	24648	16	23A
0005434252057	24648	17	23B
0005433681009	2804	1	1A
0005432966936	2804	2	1D
0005433681024	2804	3	1F
0005433680985	2804	4	2A
0005433680991	2804	5	2C
0005433681012	2804	6	2D
0005433681016	2804	7	2F
0005433680994	2804	8	3A
0005433680996	2804	9	3C
0005433680993	2804	10	3D
0005433680988	2804	11	3F
0005432222828	2804	12	4A
0005433680983	2804	13	4C
0005432966964	2804	14	4D
0005432967047	2804	15	4E
0005433681011	2804	16	5D
0005432967021	2804	17	5E
0005433681018	2804	18	5F
0005432967022	2804	19	6A
0005433681028	2804	20	6C
0005432966997	2804	21	6D
0005432966885	2804	22	6E
0005433681025	2804	23	6F
0005433681004	2804	24	7C
0005433680986	2804	25	7E
0005433681015	2804	26	7F
0005432966878	2804	27	8A
0005433681005	2804	28	8C
0005433680992	2804	29	8D
0005433681026	2804	30	8E
0005433681008	2804	31	8F
0005432222829	2804	32	9A
0005432967000	2804	33	9D
0005432967011	2804	34	9E
0005432966905	2804	35	10A
0005432222831	2804	36	10C
0005433680998	2804	37	10D
0005432966886	2804	38	10E
0005433680995	2804	39	10F
0005432966937	2804	40	11A
0005433680987	2804	41	11C
0005433680984	2804	42	11D
0005433681002	2804	43	11E
0005433681000	2804	44	11F
0005432966877	2804	45	12A
0005433681003	2804	46	12C
0005433681019	2804	47	12D
0005433681010	2804	48	12F
0005433681023	2804	49	13A
0005433680989	2804	50	13C
0005433681022	2804	51	13D
0005432967012	2804	52	13E
0005432966938	2804	53	13F
0005433681001	2804	54	14D
0005432222830	2804	55	14E
0005432222832	2804	56	14F
0005433680980	2804	57	15A
0005433681027	2804	58	15C
0005432966904	2804	59	15E
0005433681007	2804	60	15F
0005433680997	2804	61	16A
0005432967062	2804	62	16D
0005433680981	2804	63	16E
0005433680982	2804	64	16F
0005433681020	2804	65	17A
0005432966998	2804	66	17C
0005432966903	2804	67	17D
0005433681006	2804	68	17F
0005433681013	2804	69	18A
0005432967069	2804	70	18C
0005433680999	2804	71	18D
0005432966963	2804	72	18E
0005432966914	2804	73	18F
0005432967010	2804	74	19C
0005433680990	2804	75	19D
0005433681017	2804	76	19E
0005432222833	2804	77	19F
0005432967009	2804	78	20A
0005433681014	2804	79	20C
0005433681021	2804	80	20F
0005432005239	29186	1	1C
0005432967160	29186	2	1D
0005432967183	29186	3	1F
0005433680824	29186	4	2A
0005432967164	29186	5	2C
0005432967159	29186	6	2D
0005432967166	29186	7	2F
0005433680748	29186	8	3A
0005433680688	29186	9	3D
0005432967161	29186	10	3F
0005433680418	29186	11	4A
0005433680427	29186	12	4C
0005432967178	29186	13	4D
0005433680364	29186	14	4F
0005432967169	29186	15	5A
0005432967175	29186	16	5C
0005432967167	29186	17	5D
0005433680612	29186	18	5F
0005433680816	29186	19	6A
0005433680813	29186	20	6C
0005432967163	29186	21	6D
0005433680812	29186	22	6E
0005433680686	29186	23	7A
0005433680641	29186	24	7C
0005433680706	29186	25	7D
0005433680583	29186	26	7E
0005433687692	29186	27	8C
0005433680815	29186	28	8D
0005433680425	29186	29	8E
0005433680744	29186	30	9A
0005433680702	29186	31	9C
0005433680632	29186	32	9D
0005433680705	29186	33	9E
0005432967176	29186	34	10A
0005432967180	29186	35	10C
0005432967177	29186	36	10D
0005433680564	29186	37	10E
0005433680820	29186	38	10F
0005433680498	29186	39	11A
0005433680642	29186	40	11C
0005433680750	29186	41	11D
0005432967185	29186	42	11E
0005432967162	29186	43	11F
0005433680660	29186	44	12C
0005433680604	29186	45	12D
0005433680619	29186	46	12E
0005432967179	29186	47	12F
0005433680636	29186	48	13A
0005433680504	29186	49	13C
0005433680667	29186	50	13E
0005433680749	29186	51	13F
0005432967168	29186	52	14A
0005433680538	29186	53	14C
0005432967171	29186	54	14E
0005432967173	29186	55	14F
0005433680689	29186	56	15A
0005432967158	29186	57	15C
0005432967181	29186	58	15D
0005433680363	29186	59	15E
0005432005240	29186	60	15F
0005433680614	29186	61	16A
0005433680490	29186	62	16C
0005432967172	29186	63	16D
0005433680435	29186	64	16F
0005433680668	29186	65	17A
0005433680503	29186	66	17C
0005433680626	29186	67	17D
0005433680673	29186	68	17F
0005433680635	29186	69	18C
0005433680747	29186	70	18D
0005432967165	29186	71	18F
0005432967174	29186	72	19A
0005433680491	29186	73	19C
0005432967170	29186	74	19D
0005433680752	29186	75	19E
0005433680424	29186	76	19F
0005433684421	29186	77	20A
0005432967184	29186	78	20C
0005433680644	29186	79	20D
0005433680640	29186	80	20E
0005432967182	29186	81	20F
0005433615298	9269	1	1C
0005433615264	9269	2	1F
0005432755106	9269	3	1D
0005433634093	9269	4	2A
0005433615295	9269	5	2C
0005433634087	9269	6	2F
0005433615272	9269	7	2D
0005433634102	9269	8	3A
0005433615267	9269	9	3D
0005433577933	9269	10	3F
0005433615269	9269	11	4A
0005433634104	9269	12	4C
0005433615325	9269	13	4F
0005433615309	9269	14	4D
0005433577927	9269	15	5A
0005433615315	9269	16	5C
0005433615323	9269	17	5F
0005433634089	9269	18	5D
0005434153534	9269	19	6A
0005433615300	9269	20	6D
0005433634088	9269	21	6C
0005433615293	9269	22	6F
0005433615279	9269	23	7A
0005433615263	9269	24	7D
0005434163627	9269	25	7C
0005433615318	9269	26	7F
0005433615306	9269	27	8A
0005433615266	9269	28	8D
0005433634098	9269	29	8C
0005433615317	9269	30	8E
0005433577925	9269	31	8F
0005433634092	9269	32	9C
0005433634103	9269	33	9B
0005433634108	9269	34	9D
0005433615327	9269	35	10B
0005433615324	9269	36	10A
0005433577935	9269	37	9F
0005433615326	9269	38	10C
0005433634096	9269	39	10E
0005433615311	9269	40	10D
0005432756877	9269	41	11B
0005433615276	9269	42	11A
0005433634099	9269	43	11C
0005433577926	9269	44	11D
0005433634113	9269	45	11F
0005434163615	9269	46	11E
0005433615304	9269	47	12A
0005432755105	9269	48	12B
0005433615328	9269	49	12E
0005434163619	9269	50	12D
0005433615312	9269	51	12F
0005433577931	9269	52	13B
0005433615268	9269	53	13A
0005433634116	9269	54	13C
0005433615275	9269	55	13D
0005433615294	9269	56	13E
0005433634086	9269	57	14A
0005433634119	9269	58	14D
0005433634111	9269	59	14C
0005433615282	9269	60	14F
0005433634106	9269	61	15B
0005434153533	9269	62	15A
0005433615277	9269	63	15D
0005433577932	9269	64	15E
0005433615260	9269	65	16A
0005433634110	9269	66	16B
0005434163626	9269	67	16C
0005433615296	9269	68	16E
0005433615305	9269	69	16F
0005434269096	9269	70	17B
0005433615273	9269	71	17A
0005433634091	9269	72	17C
0005433615274	9269	73	17D
0005433634107	9269	74	17F
0005434163554	9269	75	17E
0005433615286	9269	76	18A
0005433615331	9269	77	18B
0005433577934	9269	78	18D
0005434163628	9269	79	18C
0005433615322	9269	80	18E
0005433615321	9269	81	18F
0005433634117	9269	82	19B
0005433634097	9269	83	19D
0005433615281	9269	84	19C
0005433615332	9269	85	19E
0005433634118	9269	86	20B
0005433634090	9269	87	20A
0005433615303	9269	88	20C
0005433615316	9269	89	20E
0005433577924	9269	90	20D
0005433615314	9269	91	20F
0005433615285	9269	92	21B
0005433634105	9269	93	21A
0005433615307	9269	94	21C
0005434163613	9269	95	21E
0005434163614	9269	96	21F
0005433615271	9269	97	22B
0005433615310	9269	98	22A
0005432145127	9269	99	22C
0005433615330	9269	100	22F
0005434163629	9269	101	23A
0005433615313	9269	102	23B
0005433615265	9269	103	23D
0005433634115	9269	104	23C
0005433615278	9269	105	23F
0005433577936	9269	106	23E
0005433634112	9269	107	24A
0005432756878	9269	108	24B
0005433577923	9269	109	24C
0005433615292	9269	110	24E
0005433634101	9269	111	24D
0005433615297	9269	112	25A
0005433615299	9269	113	25D
0005433615289	9269	114	25F
0005433615329	9269	115	26B
0005433634094	9269	116	26A
0005432756879	9269	117	27A
0005432145128	9269	118	27C
0005433634109	9269	119	27E
0005433615288	9269	120	27D
0005432145129	9269	121	27F
0005433615319	9269	122	28B
0005433615290	9269	123	28A
0005433615287	9269	124	28C
0005433634100	9269	125	28E
0005434163630	9269	126	28D
0005433615291	9269	127	28F
0005433577930	9269	128	29A
0005433615283	9269	129	29C
0005433577929	9269	130	29D
0005433634114	9269	131	29F
0005433615262	9269	132	29E
0005433634095	9269	133	30A
0005433615270	9269	134	30B
0005433615301	9269	135	30C
0005433615280	9269	136	30E
0005433577928	9269	137	30D
0005433615261	9269	138	31A
0005433615308	9269	139	30F
0005434163592	9269	140	31B
0005433615284	9269	141	31C
0005434163555	9269	142	31E
0005433615302	9269	143	31D
0005433615320	9269	144	31F
0005433614599	25226	1	1A
0005433614517	25226	2	1C
0005433614620	25226	3	2D
0005433614563	25226	4	2C
0005433577833	25226	5	3A
0005434163695	25226	6	2F
0005433633900	25226	7	3F
0005433577795	25226	8	3D
0005433614624	25226	9	4A
0005433614586	25226	10	4D
0005434163693	25226	11	4C
0005433633748	25226	12	5A
0005433614556	25226	13	4F
0005433633920	25226	14	5D
0005433614816	25226	15	5C
0005435854063	25226	16	6A
0005433614579	25226	17	7A
0005433614774	25226	18	6F
0005433614486	25226	19	7F
0005433633869	25226	20	7D
0005433633693	25226	21	8A
0005433614492	25226	22	8B
0005433614738	25226	23	8C
0005433614339	25226	24	8E
0005433633873	25226	25	8D
0005433614504	25226	26	8F
0005433614708	25226	27	9C
0005433577824	25226	28	9E
0005433614790	25226	29	9D
0005433614428	25226	30	9F
0005433614734	25226	31	10A
0005433614557	25226	32	10C
0005434273092	25226	33	10E
0005433577808	25226	34	10F
0005433633786	25226	35	11A
0005433614968	25226	36	11C
0005434272205	25226	37	11D
0005433577848	25226	38	11F
0005433633674	25226	39	11E
0005433614658	25226	40	12A
0005434163699	25226	41	12B
0005433633711	25226	42	12C
0005434163696	25226	43	12D
0005433633834	25226	44	12E
0005433614516	25226	45	13B
0005433614796	25226	46	13C
0005433614460	25226	47	13D
0005433633692	25226	48	13E
0005433614491	25226	49	14A
0005433614771	25226	50	13F
0005433577856	25226	51	14B
0005433614621	25226	52	14D
0005433614372	25226	53	14C
0005433633840	25226	54	14E
0005434273091	25226	55	15A
0005433614795	25226	56	15C
0005434163697	25226	57	15B
0005433614879	25226	58	15D
0005433633729	25226	59	15F
0005433614855	25226	60	16A
0005433614587	25226	61	16B
0005434163703	25226	62	16D
0005433614436	25226	63	16C
0005434163701	25226	64	16F
0005433614493	25226	65	17A
0005433633897	25226	66	17C
0005433614606	25226	67	17E
0005433633874	25226	68	18A
0005433614596	25226	69	17F
0005433614770	25226	70	18B
0005433577807	25226	71	18C
0005433577889	25226	72	18E
0005433614623	25226	73	18D
0005433577850	25226	74	19E
0005433614392	25226	75	19D
0005433614583	25226	76	19C
0005433614876	25226	77	20A
0005433614490	25226	78	20E
0005433614553	25226	79	20D
0005434272207	25226	80	20F
0005433633770	25226	81	21B
0005433614485	25226	82	21D
0005433577855	25226	83	21C
0005433633737	25226	84	21E
0005433633835	25226	85	21F
0005433614791	25226	86	22C
0005433614678	25226	87	22E
0005433577849	25226	88	22D
0005433614605	25226	89	22F
0005433577851	25226	90	23A
0005433633863	25226	91	23C
0005433614834	25226	92	23B
0005433614699	25226	93	23D
0005433614861	25226	94	23E
0005433577799	25226	95	24A
0005433633573	25226	96	24C
0005434163702	25226	97	24F
0005433614564	25226	98	24E
0005433614687	25226	99	25B
0005433614695	25226	100	25E
0005433614614	25226	101	25D
0005433614747	25226	102	25F
0005433614615	25226	103	26A
0005433614533	25226	104	26B
0005433614580	25226	105	26C
0005433633881	25226	106	26E
0005433614836	25226	107	26F
0005433577847	25226	108	27A
0005433633830	25226	109	27C
0005433614817	25226	110	27B
0005433614366	25226	111	27E
0005433633795	25226	112	27F
0005433633785	25226	113	28A
0005433633885	25226	114	28C
0005433614854	25226	115	28B
0005433577834	25226	116	28E
0005433577794	25226	117	28D
0005433633814	25226	118	29A
0005433633728	25226	119	28F
0005433614525	25226	120	29C
0005434163698	25226	121	29B
0005433633877	25226	122	29D
0005434163694	25226	123	29F
0005433614792	25226	124	29E
0005434272206	25226	125	30A
0005433614688	25226	126	30C
0005433633862	25226	127	30E
0005433577828	25226	128	30D
0005433633710	25226	129	30F
0005433633572	25226	130	31B
0005433614627	25226	131	31A
0005433633870	25226	132	31D
0005434163700	25226	133	31F
0005435947256	4212	1	1A
0005435947247	4212	2	2A
0005432571311	4212	3	1H
0005435947272	4212	4	2H
0005435787349	4212	5	3F
0005435986827	4212	6	3C
0005435986824	4212	7	4B
0005435856203	4212	8	4C
0005435947283	4212	9	5F
0005435856202	4212	10	9G
0005435986826	4212	11	14F
0005432571328	4212	12	16F
0005432184979	4212	13	16H
0005435947301	4212	14	17B
0005435947295	4212	15	17G
0005435856208	4212	16	18E
0005435947282	4212	17	20D
0005435856209	4212	18	20F
0005435947287	4212	19	21F
0005435986823	4212	20	23D
0005432184978	4212	21	23G
0005435787359	4212	22	27A
0005435947191	4212	23	27B
0005435947266	4212	24	27G
0005435787345	4212	25	28A
0005435787358	4212	26	28B
0005435947270	4212	27	28G
0005432571331	4212	28	29A
0005435986825	4212	29	29E
0005435947267	4212	30	30B
0005432184976	4212	31	30A
0005435947246	4212	32	30F
0005435947296	4212	33	30E
0005435947258	4212	34	31A
0005432184977	4212	35	30H
0005434271317	4212	36	32D
0005435947245	4212	37	32E
0005435947271	4212	38	33G
0005432571332	4212	39	34H
0005435947255	4212	40	35A
0005432571310	4212	41	36B
0005435947265	4212	42	36D
0005434271310	4212	43	37A
0005435787357	4212	44	38D
0005435787344	4212	45	39F
0005432571361	26559	1	2C
0005435986760	26559	2	2B
0005435856245	26559	3	2G
0005432571359	26559	4	5A
0005435947393	26559	5	5F
0005435947395	26559	6	5H
0005435947394	26559	7	9B
0005435856242	26559	8	14F
0005435947387	26559	9	14E
0005435856244	26559	10	15B
0005435856243	26559	11	15G
0005435947392	26559	12	15F
0005435986735	26559	13	16A
0005435986793	26559	14	18G
0005432571360	26559	15	19E
0005435986727	26559	16	19G
0005435986778	26559	17	20A
0005435947390	26559	18	20E
0005435986750	26559	19	23B
0005435787375	26559	20	24B
0005435947389	26559	21	27E
0005435947388	26559	22	28A
0005435986780	26559	23	28D
0005435947398	26559	24	29F
0005435986736	26559	25	30E
0005435947385	26559	26	30H
0005435947391	26559	27	31B
0005435986761	26559	28	32E
0005435947397	26559	29	32F
0005435787376	26559	30	35F
0005435947396	26559	31	36A
0005435986728	26559	32	37A
0005435986749	26559	33	36H
0005435947386	26559	34	37F
0005432571358	26559	35	38B
0005433569603	364	1	1C
0005433569611	364	2	1A
0005433569640	364	3	2A
0005433569616	364	4	2C
0005433569645	364	5	2F
0005433569632	364	6	2D
0005433074698	364	7	3C
0005433134133	364	8	3F
0005433569596	364	9	3D
0005432948317	364	10	4C
0005433129271	364	11	4F
0005432948584	364	12	5A
0005433569598	364	13	5C
0005433569644	364	14	5F
0005433569639	364	15	5D
0005433569628	364	16	6A
0005432238991	364	17	6D
0005432948340	364	18	7D
0005432238993	364	19	7C
0005432948593	364	20	7F
0005433569629	364	21	8B
0005433134138	364	22	8D
0005432948626	364	23	9A
0005433074549	364	24	9B
0005433569635	364	25	9D
0005433074689	364	26	9F
0005433569591	364	27	9E
0005433569631	364	28	10A
0005432238992	364	29	10C
0005433134158	364	30	10B
0005432948463	364	31	10E
0005433569584	364	32	10F
0005432948595	364	33	11B
0005432948594	364	34	11A
0005432238995	364	35	11C
0005433074747	364	36	11E
0005432948552	364	37	12A
0005433569609	364	38	11F
0005433569624	364	39	12B
0005433569588	364	40	12D
0005433569599	364	41	12C
0005433569608	364	42	12F
0005433134154	364	43	13A
0005433569634	364	44	13C
0005433569587	364	45	13D
0005433569613	364	46	13E
0005433569594	364	47	14A
0005433569592	364	48	14B
0005432948478	364	49	14C
0005432948583	364	50	15C
0005433569607	364	51	15B
0005433129272	364	52	15D
0005433074748	364	53	15E
0005433569606	364	54	16A
0005433129249	364	55	15F
0005432948442	364	56	16C
0005433134139	364	57	16B
0005433569620	364	58	16D
0005432948572	364	59	16E
0005432948504	364	60	16F
0005432948528	364	61	17B
0005432948464	364	62	17A
0005433929857	364	63	17C
0005433569647	364	64	17E
0005432948476	364	65	17D
0005432948341	364	66	18A
0005433569621	364	67	18B
0005433569597	364	68	18D
0005432948288	364	69	18E
0005432948550	364	70	19B
0005433569637	364	71	19C
0005433074722	364	72	19D
0005433569585	364	73	20A
0005433569612	364	74	20B
0005432948339	364	75	20D
0005433569615	364	76	20C
0005433569595	364	77	20F
0005433134142	364	78	20E
0005433569605	364	79	21A
0005433074744	364	80	21C
0005432948531	364	81	21D
0005433569627	364	82	21F
0005433569646	364	83	22B
0005432948546	364	84	22C
0005433569642	364	85	22E
0005433569593	364	86	22D
0005433129251	364	87	22F
0005433074613	364	88	23A
0005432948627	364	89	23C
0005433569625	364	90	23B
0005433134141	364	91	23D
0005433569589	364	92	24A
0005433569623	364	93	23F
0005433129274	364	94	24B
0005433569638	364	95	24C
0005432948392	364	96	24D
0005433569636	364	97	24F
0005433074655	364	98	25B
0005433569618	364	99	25A
0005433569633	364	100	25D
0005433074649	364	101	25E
0005433134134	364	102	26A
0005433074786	364	103	25F
0005432238996	364	104	26B
0005433569643	364	105	26C
0005432948502	364	106	26E
0005433569590	364	107	26D
0005433129250	364	108	26F
0005432948551	364	109	27B
0005432948477	364	110	27A
0005433074730	364	111	27C
0005433569610	364	112	27D
0005433569601	364	113	28B
0005433569622	364	114	28D
0005433074785	364	115	28C
0005433074775	364	116	28E
0005432948530	364	117	29A
0005433569602	364	118	28F
0005433569600	364	119	29B
0005432238994	364	120	29C
0005433569586	364	121	29F
0005432948529	364	122	29E
0005433569641	364	123	30A
0005433569648	364	124	30B
0005432948557	364	125	30D
0005433569630	364	126	30C
0005433569626	364	127	30E
0005432948503	364	128	30F
0005433569617	364	129	31A
0005433569604	364	130	31C
0005433569614	364	131	31B
0005432948556	364	132	31E
0005433569619	364	133	31F
0005433074983	11610	1	1A
0005433074957	11610	2	1D
0005432948825	11610	3	2A
0005432948839	11610	4	1F
0005433074969	11610	5	2C
0005432948813	11610	6	2D
0005433568917	11610	7	3A
0005433074979	11610	8	3C
0005433074971	11610	9	3F
0005432948834	11610	10	4A
0005433568796	11610	11	4C
0005433568697	11610	12	4D
0005433074974	11610	13	5A
0005432948836	11610	14	4F
0005433074978	11610	15	5F
0005432192347	11610	16	5D
0005433569002	11610	17	6A
0005433134180	11610	18	6C
0005432948818	11610	19	6F
0005433569153	11610	20	6D
0005432948843	11610	21	7A
0005433568855	11610	22	7C
0005432192349	11610	23	7F
0005433568918	11610	24	7D
0005433569172	11610	25	8A
0005433074968	11610	26	8B
0005432948808	11610	27	8D
0005433074977	11610	28	8C
0005433568787	11610	29	8E
0005432948809	11610	30	8F
0005432948832	11610	31	9B
0005432948821	11610	32	9A
0005433569117	11610	33	9C
0005433568646	11610	34	9D
0005433568745	11610	35	9F
0005432948814	11610	36	9E
0005433569036	11610	37	10A
0005433568926	11610	38	10C
0005432948816	11610	39	10B
0005433074955	11610	40	10D
0005433131750	11610	41	10F
0005432948806	11610	42	10E
0005432948845	11610	43	11C
0005433569104	11610	44	11B
0005432948829	11610	45	11E
0005433074981	11610	46	11D
0005433569033	11610	47	11F
0005433569068	11610	48	12A
0005432948840	11610	49	12B
0005433568971	11610	50	12C
0005432948820	11610	51	12E
0005433568982	11610	52	12D
0005433074967	11610	53	12F
0005433074982	11610	54	13A
0005433568897	11610	55	13C
0005433569111	11610	56	13B
0005433569097	11610	57	13E
0005433134178	11610	58	13F
0005433134181	11610	59	14B
0005433074976	11610	60	14A
0005433134182	11610	61	14E
0005433074961	11610	62	15B
0005432948828	11610	63	15A
0005433568886	11610	64	15C
0005433569030	11610	65	15D
0005433074975	11610	66	15E
0005433568965	11610	67	16A
0005433569015	11610	68	15F
0005432948822	11610	69	16C
0005432948817	11610	70	16E
0005433131751	11610	71	16D
0005432948838	11610	72	16F
0005433568811	11610	73	17B
0005432192350	11610	74	17A
0005433569037	11610	75	17D
0005432948846	11610	76	17E
0005433568991	11610	77	18A
0005433131749	11610	78	18C
0005433074980	11610	79	18B
0005432948826	11610	80	18E
0005433568992	11610	81	18F
0005433074964	11610	82	19C
0005433074954	11610	83	19B
0005432948811	11610	84	19D
0005432948830	11610	85	20A
0005432948819	11610	86	19E
0005433074963	11610	87	20B
0005432948815	11610	88	20C
0005433134179	11610	89	20E
0005433568999	11610	90	20D
0005433074960	11610	91	20F
0005432192348	11610	92	21B
0005433568629	11610	93	21C
0005433074966	11610	94	21D
0005433569019	11610	95	21F
0005433569118	11610	96	22B
0005433568848	11610	97	22A
0005433569180	11610	98	22D
0005433568952	11610	99	22F
0005432948827	11610	100	22E
0005432948844	11610	101	23A
0005433074965	11610	102	23C
0005433074970	11610	103	23B
0005433074956	11610	104	23E
0005432948810	11610	105	24A
0005433568968	11610	106	23F
0005432948833	11610	107	24B
0005432948847	11610	108	24E
0005433568915	11610	109	24D
0005433074962	11610	110	24F
0005433569119	11610	111	25A
0005433074972	11610	112	25C
0005433568732	11610	113	25B
0005433569014	11610	114	25D
0005432948831	11610	115	25E
0005433568964	11610	116	26B
0005432948835	11610	117	26D
0005433074973	11610	118	26C
0005433074958	11610	119	26E
0005432948837	11610	120	27B
0005433131752	11610	121	27A
0005433569079	11610	122	27F
0005433568993	11610	123	28B
0005433568951	11610	124	28D
0005432948812	11610	125	28C
0005433569051	11610	126	28E
0005432948841	11610	127	28F
0005433568628	11610	128	29C
0005433568630	11610	129	29B
0005433074959	11610	130	29D
0005433568953	11610	131	29E
0005433569166	11610	132	30A
0005433568636	11610	133	29F
0005433134183	11610	134	30B
0005433568788	11610	135	30D
0005433569043	11610	136	30C
0005433568808	11610	137	30E
0005433568959	11610	138	30F
0005432948823	11610	139	31C
0005432948807	11610	140	31D
0005432948842	11610	141	31E
0005432948824	11610	142	31F
0005433817504	9981	1	1A
0005433817505	9981	2	4A
0005433817507	9981	3	3B
0005434732984	9981	4	4B
0005434732985	9981	5	5B
0005433817506	9981	6	6B
0005433817483	13977	1	1B
0005433817484	13977	2	2B
0005434733015	13977	3	3A
0005433817485	13977	4	3B
0005434733014	13977	5	4A
0005434733012	13977	6	5B
0005434733013	13977	7	6A
0005432226117	2343	1	1A
0005433754725	2343	2	1C
0005433754728	2343	3	1B
0005433754746	2343	4	1F
0005432985028	2343	5	1H
0005433754758	2343	6	1G
0005432869536	2343	7	2C
0005433434628	2343	8	2B
0005432655644	2343	9	2A
0005432985077	2343	10	2F
0005433754739	2343	11	2G
0005433434706	2343	12	3A
0005435982747	2343	13	2H
0005432869498	2343	14	3B
0005432226114	2343	15	3F
0005432869552	2343	16	3C
0005432985089	2343	17	3G
0005432655650	2343	18	4A
0005435982763	2343	19	3H
0005433754764	2343	20	4B
0005435982728	2343	21	4F
0005435982727	2343	22	4G
0005433754762	2343	23	4H
0005433754720	2343	24	5B
0005435982751	2343	25	5A
0005433754723	2343	26	5C
0005433434646	2343	27	5G
0005432869543	2343	28	5F
0005433434720	2343	29	5H
0005433754768	2343	30	9B
0005432226115	2343	31	9A
0005432226113	2343	32	9G
0005433754770	2343	33	11A
0005435982757	2343	34	9H
0005433754769	2343	35	11B
0005435982746	2343	36	11E
0005433754763	2343	37	11D
0005433434774	2343	38	11F
0005433754718	2343	39	11H
0005432300317	2343	40	12A
0005435982750	2343	41	12D
0005433754756	2343	42	12B
0005433754719	2343	43	12E
0005435982749	2343	44	12F
0005433754742	2343	45	12H
0005432655653	2343	46	12G
0005432869526	2343	47	13B
0005432300320	2343	48	13A
0005433754754	2343	49	13E
0005433754744	2343	50	13G
0005433434548	2343	51	13F
0005435982721	2343	52	13H
0005435982759	2343	53	14B
0005435982760	2343	54	14A
0005432985063	2343	55	14E
0005433754741	2343	56	15A
0005432985150	2343	57	14H
0005435982726	2343	58	15D
0005432985109	2343	59	15E
0005432985031	2343	60	15H
0005433754761	2343	61	15G
0005432226112	2343	62	16A
0005432985088	2343	63	16D
0005433434725	2343	64	16B
0005432985064	2343	65	16F
0005432985108	2343	66	16E
0005432984995	2343	67	16G
0005433754734	2343	68	17B
0005433434598	2343	69	17A
0005434731165	2343	70	17D
0005435982739	2343	71	17F
0005432869527	2343	72	17E
0005435982764	2343	73	17G
0005433434769	2343	74	17H
0005432655646	2343	75	18B
0005433754732	2343	76	18A
0005432985002	2343	77	18D
0005432985095	2343	78	18F
0005433434664	2343	79	18E
0005434731163	2343	80	18G
0005435982720	2343	81	19A
0005435982753	2343	82	18H
0005435982756	2343	83	19B
0005435982755	2343	84	19E
0005433754727	2343	85	19D
0005432300318	2343	86	19F
0005433766676	2343	87	19H
0005435982761	2343	88	19G
0005435982732	2343	89	20A
0005433754767	2343	90	20B
0005435982745	2343	91	20E
0005433754772	2343	92	20D
0005433754736	2343	93	20G
0005433764700	2343	94	20H
0005433754749	2343	95	21A
0005432655647	2343	96	21D
0005435982734	2343	97	21B
0005433754743	2343	98	21E
0005435982740	2343	99	21G
0005432985110	2343	100	21F
0005433754765	2343	101	21H
0005433434726	2343	102	22A
0005433754747	2343	103	22D
0005432226118	2343	104	22B
0005435982722	2343	105	22E
0005432985041	2343	106	22G
0005435982754	2343	107	22F
0005433766677	2343	108	23A
0005432300319	2343	109	23E
0005432226116	2343	110	23D
0005435982752	2343	111	23B
0005433754757	2343	112	23F
0005433754755	2343	113	23G
0005435982737	2343	114	23H
0005433434785	2343	115	24B
0005435982730	2343	116	24A
0005435982758	2343	117	24E
0005435982743	2343	118	24D
0005435982744	2343	119	24F
0005432655651	2343	120	24G
0005433754740	2343	121	25D
0005433754733	2343	122	24H
0005433754774	2343	123	25E
0005435982729	2343	124	25F
0005433754729	2343	125	27B
0005434731178	2343	126	27F
0005433764699	2343	127	27G
0005432655655	2343	128	28A
0005432869548	2343	129	27H
0005433434627	2343	130	28B
0005435982731	2343	131	28E
0005434731164	2343	132	28F
0005433754750	2343	133	28H
0005433754735	2343	134	29A
0005432869537	2343	135	29B
0005435982738	2343	136	29E
0005432869544	2343	137	29D
0005432985065	2343	138	29G
0005433434712	2343	139	29F
0005435982725	2343	140	29H
0005433754759	2343	141	30B
0005432655645	2343	142	30A
0005433754726	2343	143	30E
0005432985105	2343	144	30F
0005433754751	2343	145	30G
0005435982748	2343	146	31A
0005433754752	2343	147	30H
0005435982766	2343	148	31B
0005432655649	2343	149	31D
0005433754771	2343	150	31F
0005433434676	2343	151	31E
0005435982742	2343	152	31G
0005434731185	2343	153	32A
0005432985140	2343	154	31H
0005432869525	2343	155	32B
0005432655648	2343	156	32E
0005435982765	2343	157	32D
0005435982762	2343	158	32F
0005432985090	2343	159	32H
0005433754722	2343	160	32G
0005432985152	2343	161	33A
0005433754721	2343	162	33D
0005433754748	2343	163	33B
0005432985149	2343	164	33E
0005433434801	2343	165	33F
0005435982719	2343	166	33G
0005434731177	2343	167	34A
0005433754773	2343	168	34D
0005432985030	2343	169	34B
0005432985091	2343	170	34F
0005435982741	2343	171	34E
0005432985029	2343	172	35A
0005433754731	2343	173	34H
0005433754766	2343	174	35B
0005433754760	2343	175	35D
0005432655654	2343	176	35F
0005433754730	2343	177	35E
0005432869538	2343	178	35H
0005433434780	2343	179	35G
0005435982736	2343	180	36A
0005432985139	2343	181	36D
0005433754738	2343	182	36F
0005435982733	2343	183	36E
0005435982718	2343	184	36G
0005432869549	2343	185	37A
0005435982723	2343	186	36H
0005435982717	2343	187	37B
0005433434696	2343	188	37E
0005435982724	2343	189	37D
0005435982735	2343	190	37F
0005432300316	2343	191	37G
0005432869532	2343	192	37H
0005433434689	2343	193	38D
0005433754737	2343	194	38B
0005433754724	2343	195	38E
0005432655652	2343	196	38F
0005433766674	2343	197	38H
0005433766675	2343	198	38G
0005433754753	2343	199	39E
0005433754745	2343	200	39D
0005433434661	2343	201	39F
0005433754143	26202	1	1A
0005435982386	26202	2	1B
0005433754415	26202	3	1F
0005435982210	26202	4	1C
0005433764673	26202	5	2A
0005435982438	26202	6	1H
0005433764677	26202	7	2C
0005435982436	26202	8	2B
0005435982119	26202	9	2F
0005435982160	26202	10	2H
0005433754424	26202	11	2G
0005435982304	26202	12	3A
0005433754377	26202	13	3B
0005433754329	26202	14	3F
0005435982202	26202	15	3C
0005432869586	26202	16	3G
0005432985364	26202	17	4A
0005432985392	26202	18	4B
0005433434932	26202	19	4F
0005432985374	26202	20	4G
0005433764671	26202	21	5A
0005433754280	26202	22	4H
0005435982385	26202	23	5B
0005433434954	26202	24	5F
0005435982244	26202	25	5C
0005433754262	26202	26	9A
0005433754467	26202	27	5H
0005432985367	26202	28	9B
0005432869585	26202	29	9H
0005435982263	26202	30	9G
0005432869584	26202	31	11B
0005433434952	26202	32	11A
0005433754277	26202	33	11D
0005432051158	26202	34	11F
0005433434940	26202	35	11E
0005433754372	26202	36	11H
0005433766625	26202	37	11G
0005432985378	26202	38	12A
0005433434941	26202	39	12D
0005433753750	26202	40	12B
0005433754320	26202	41	12F
0005435982060	26202	42	12H
0005433754314	26202	43	12G
0005433754166	26202	44	13B
0005432985383	26202	45	13A
0005433434953	26202	46	13G
0005432985395	26202	47	13F
0005432985380	26202	48	14A
0005432655465	26202	49	13H
0005432985365	26202	50	14E
0005435982224	26202	51	14D
0005432049497	26202	52	14F
0005433754214	26202	53	14G
0005435982200	26202	54	15A
0005435982203	26202	55	14H
0005432985376	26202	56	15D
0005432985382	26202	57	15B
0005435982220	26202	58	15E
0005434731209	26202	59	15F
0005433754193	26202	60	15H
0005432655547	26202	61	16A
0005435982444	26202	62	16D
0005435982341	26202	63	16B
0005433434943	26202	64	16E
0005435982347	26202	65	16F
0005435982374	26202	66	16H
0005433754404	26202	67	16G
0005433754414	26202	68	17A
0005435982180	26202	69	17D
0005433434945	26202	70	17B
0005432985391	26202	71	17F
0005435982298	26202	72	17E
0005433434939	26202	73	18A
0005433764682	26202	74	17H
0005435982348	26202	75	17G
0005435982249	26202	76	18B
0005432985381	26202	77	18D
0005433434934	26202	78	18E
0005435982317	26202	79	18G
0005433434948	26202	80	18H
0005435982434	26202	81	19A
0005433754167	26202	82	19E
0005435982250	26202	83	19D
0005433754319	26202	84	19F
0005434731212	26202	85	19H
0005432985384	26202	86	19G
0005432985379	26202	87	20A
0005433434949	26202	88	20D
0005433766650	26202	89	20B
0005433434944	26202	90	20E
0005432985389	26202	91	20F
0005433434931	26202	92	20G
0005432985388	26202	93	21A
0005433434950	26202	94	21B
0005435982143	26202	95	21D
0005435982219	26202	96	21G
0005433754417	26202	97	21F
0005433434957	26202	98	21H
0005432869582	26202	99	22B
0005435982318	26202	100	22A
0005432985390	26202	101	22D
0005432655565	26202	102	22E
0005433754297	26202	103	22G
0005432985368	26202	104	22F
0005433753952	26202	105	22H
0005435982299	26202	106	23A
0005435982277	26202	107	23E
0005432985371	26202	108	23D
0005433754587	26202	109	23F
0005435982292	26202	110	23G
0005435982319	26202	111	24A
0005432869587	26202	112	23H
0005432985386	26202	113	24B
0005432985385	26202	114	24E
0005433754413	26202	115	24D
0005435982201	26202	116	24F
0005433754249	26202	117	24G
0005435982209	26202	118	25D
0005432869588	26202	119	25E
0005433754039	26202	120	25F
0005432655466	26202	121	27B
0005433754410	26202	122	27E
0005432985369	26202	123	27D
0005433434951	26202	124	27G
0005432655471	26202	125	27F
0005432985372	26202	126	27H
0005432869581	26202	127	28A
0005435982139	26202	128	28D
0005433764672	26202	129	28B
0005435982150	26202	130	28E
0005433764681	26202	131	28G
0005435982199	26202	132	28F
0005435982419	26202	133	28H
0005433754208	26202	134	29A
0005433754243	26202	135	29B
0005435982375	26202	136	29E
0005433753886	26202	137	29D
0005432985370	26202	138	29F
0005433754307	26202	139	29G
0005432985363	26202	140	30D
0005433754115	26202	141	30B
0005434731208	26202	142	30G
0005433754533	26202	143	30F
0005433754318	26202	144	31A
0005433434930	26202	145	30H
0005433754175	26202	146	31B
0005433753953	26202	147	31E
0005435982106	26202	148	31D
0005432051156	26202	149	31F
0005433754165	26202	150	31H
0005433434936	26202	151	32B
0005433434947	26202	152	32E
0005432051157	26202	153	32D
0005433434937	26202	154	32F
0005433764683	26202	155	32H
0005433754161	26202	156	32G
0005435982437	26202	157	33A
0005432869583	26202	158	33D
0005435982290	26202	159	33B
0005432655494	26202	160	33E
0005435982303	26202	161	33F
0005433434938	26202	162	33H
0005432985377	26202	163	33G
0005435982445	26202	164	34B
0005433434933	26202	165	34A
0005433434956	26202	166	34D
0005433754142	26202	167	34F
0005433754174	26202	168	34E
0005433754225	26202	169	34G
0005432869580	26202	170	34H
0005433754468	26202	171	35B
0005433766652	26202	172	35A
0005433434929	26202	173	35D
0005433434955	26202	174	35F
0005432985387	26202	175	35E
0005433754296	26202	176	35H
0005435982216	26202	177	35G
0005432985375	26202	178	36B
0005433434946	26202	179	36A
0005433766651	26202	180	36D
0005434731211	26202	181	36E
0005432985393	26202	182	36H
0005433434935	26202	183	36G
0005432985394	26202	184	37A
0005432985373	26202	185	37B
0005433754308	26202	186	37E
0005433434942	26202	187	37D
0005435982142	26202	188	37F
0005432985366	26202	189	37H
0005434731210	26202	190	37G
0005435982316	26202	191	38B
0005433764684	26202	192	38A
0005432655451	26202	193	38D
0005435982354	26202	194	38E
0005435982355	26202	195	38G
0005432049498	26202	196	38H
0005435982141	26202	197	39E
0005433754229	26202	198	39F
0005434375066	1512	1	1A
0005434375069	1512	2	1D
0005433151370	1512	3	1F
0005433931470	1512	4	2A
0005434375072	1512	5	2D
0005434375081	1512	6	2C
0005434375080	1512	7	3A
0005433151449	1512	8	3D
0005433151600	1512	9	3C
0005434375084	1512	10	3F
0005434375095	1512	11	4B
0005433151491	1512	12	4C
0005434375071	1512	13	4E
0005434375101	1512	14	4F
0005434375100	1512	15	5B
0005432267956	1512	16	5A
0005434375089	1512	17	5C
0005433460455	1512	18	5E
0005433151497	1512	19	6A
0005434375091	1512	20	5F
0005433461607	1512	21	6B
0005434375078	1512	22	6D
0005433151454	1512	23	6F
0005433931463	1512	24	6E
0005434375104	1512	25	7A
0005433151584	1512	26	7C
0005433460457	1512	27	7E
0005434375090	1512	28	8B
0005433460456	1512	29	8D
0005434375073	1512	30	8C
0005433151313	1512	31	8E
0005433151443	1512	32	9A
0005433151368	1512	33	9D
0005434375087	1512	34	9C
0005433151498	1512	35	9F
0005434375068	1512	36	10D
0005434375103	1512	37	11A
0005433151426	1512	38	11B
0005434375063	1512	39	11D
0005434375067	1512	40	11C
0005433151356	1512	41	11E
0005434375096	1512	42	11F
0005433460458	1512	43	12B
0005432267959	1512	44	12A
0005434375107	1512	45	12D
0005433151466	1512	46	12C
0005433151444	1512	47	12E
0005433151453	1512	48	12F
0005432267955	1512	49	13B
0005434375102	1512	50	13A
0005434375097	1512	51	13C
0005433931471	1512	52	13D
0005433151355	1512	53	13E
0005433151427	1512	54	13F
0005434375070	1512	55	14B
0005433151599	1512	56	14A
0005434375112	1512	57	14E
0005434375106	1512	58	14F
0005433151591	1512	59	15B
0005434375093	1512	60	15A
0005434375094	1512	61	15D
0005434375085	1512	62	15E
0005434375113	1512	63	15F
0005432267958	1512	64	16B
0005433151406	1512	65	16F
0005433151408	1512	66	16E
0005434375088	1512	67	17B
0005433151402	1512	68	17C
0005434375105	1512	69	17D
0005433461608	1512	70	17E
0005434375110	1512	71	18A
0005434375086	1512	72	17F
0005433151509	1512	73	18B
0005433461609	1512	74	18C
0005433151487	1512	75	18F
0005432267960	1512	76	18E
0005433151524	1512	77	19A
0005434375074	1512	78	19B
0005433931466	1512	79	19D
0005434375109	1512	80	19C
0005433151523	1512	81	19F
0005434375108	1512	82	20B
0005433151371	1512	83	20A
0005433151515	1512	84	20C
0005433151352	1512	85	20E
0005434375098	1512	86	20D
0005433931465	1512	87	21A
0005432267957	1512	88	20F
0005433151601	1512	89	21B
0005434375077	1512	90	21C
0005434375076	1512	91	21D
0005434375083	1512	92	21F
0005434375082	1512	93	21E
0005434375075	1512	94	22B
0005434375092	1512	95	22C
0005434375065	1512	96	22E
0005433151383	1512	97	22D
0005433151181	1512	98	22F
0005433151369	1512	99	23A
0005434375111	1512	100	23B
0005434375099	1512	101	23C
0005433151496	1512	102	23E
0005434375064	1512	103	23D
0005434375079	1512	104	23F
0005433151713	20148	1	1A
0005433151734	20148	2	1C
0005434374630	20148	3	1D
0005433461579	20148	4	1F
0005434374596	20148	5	2C
0005432056334	20148	6	2A
0005433931494	20148	7	2D
0005432056332	20148	8	2F
0005433151712	20148	9	3A
0005433463879	20148	10	3D
0005433463886	20148	11	3C
0005433151727	20148	12	4A
0005433151741	20148	13	4C
0005434374572	20148	14	4B
0005433151720	20148	15	4E
0005433151710	20148	16	4F
0005433463867	20148	17	5A
0005433461578	20148	18	5D
0005433151738	20148	19	5C
0005434374632	20148	20	5F
0005434374460	20148	21	6B
0005434374520	20148	22	6C
0005433463882	20148	23	6E
0005433151714	20148	24	6F
0005433151740	20148	25	7A
0005433461555	20148	26	7C
0005433151715	20148	27	7E
0005434029681	20148	28	7F
0005434374617	20148	29	8A
0005433764699	20148	30	8B
0005433151722	20148	31	8D
0005433931493	20148	32	8C
0005433151724	20148	33	8E
0005433463889	20148	34	9A
0005433151717	20148	35	8F
0005434374461	20148	36	9C
0005433151735	20148	37	9B
0005433463872	20148	38	9E
0005433151737	20148	39	9F
0005432056336	20148	40	10B
0005433151733	20148	41	10C
0005433461574	20148	42	11A
0005434374398	20148	43	10E
0005434374397	20148	44	11C
0005433151730	20148	45	11B
0005434374635	20148	46	11E
0005434374603	20148	47	11D
0005434374597	20148	48	12B
0005433151743	20148	49	12C
0005433151726	20148	50	12E
0005433461565	20148	51	13A
0005433463892	20148	52	13C
0005434374559	20148	53	13B
0005433463890	20148	54	13D
0005433461577	20148	55	13E
0005433463887	20148	56	13F
0005433463880	20148	57	14A
0005433151708	20148	58	14C
0005433151716	20148	59	14B
0005433463893	20148	60	14E
0005433151742	20148	61	15B
0005433461591	20148	62	15A
0005433461575	20148	63	15D
0005434374634	20148	64	15E
0005433461570	20148	65	15F
0005433463883	20148	66	16C
0005433151736	20148	67	16B
0005433463881	20148	68	16D
0005433151721	20148	69	16E
0005433151739	20148	70	17B
0005433151719	20148	71	17A
0005434029680	20148	72	17C
0005433463888	20148	73	17D
0005433151732	20148	74	17F
0005434374462	20148	75	18B
0005433461573	20148	76	18A
0005432056335	20148	77	18D
0005433463884	20148	78	18C
0005434374631	20148	79	18E
0005434029679	20148	80	18F
0005433151709	20148	81	19A
0005433151731	20148	82	19B
0005433461576	20148	83	19D
0005434374600	20148	84	19C
0005433151718	20148	85	19E
0005433463894	20148	86	20B
0005433151729	20148	87	20A
0005433461566	20148	88	20D
0005433461569	20148	89	20E
0005432056333	20148	90	21A
0005433151711	20148	91	20F
0005433764700	20148	92	21C
0005433463885	20148	93	21D
0005434374521	20148	94	21E
0005433461572	20148	95	21F
0005433461583	20148	96	22B
0005433461567	20148	97	22A
0005433461584	20148	98	22C
0005433151723	20148	99	22D
0005433461571	20148	100	22E
0005433151725	20148	101	22F
0005433931495	20148	102	23B
0005433461568	20148	103	23A
0005433461592	20148	104	23D
0005433463891	20148	105	23F
0005433151728	20148	106	23E
0005432424871	570	1	1A
0005432282930	570	2	1D
0005432424875	570	3	2C
0005432424903	570	4	3A
0005432424893	570	5	2F
0005432424870	570	6	3D
0005432424881	570	7	5D
0005432424880	570	8	6D
0005432424879	570	9	7F
0005432282933	570	10	8A
0005432424897	570	11	8B
0005432424890	570	12	8C
0005432424906	570	13	9A
0005432424884	570	14	8F
0005432424902	570	15	9C
0005432424914	570	16	9D
0005432424867	570	17	10B
0005432282928	570	18	10E
0005432424889	570	19	10D
0005432424900	570	20	10F
0005432424901	570	21	11C
0005432282926	570	22	11F
0005432424907	570	23	11E
0005432424886	570	24	12B
0005432424883	570	25	12C
0005432424908	570	26	13A
0005432424888	570	27	13C
0005432424872	570	28	13B
0005432424913	570	29	13D
0005432424898	570	30	14A
0005432282932	570	31	14F
0005432424910	570	32	16A
0005432424866	570	33	16C
0005432424891	570	34	16D
0005432424899	570	35	17C
0005432424869	570	36	17F
0005432282929	570	37	18E
0005432424873	570	38	19B
0005432424864	570	39	19D
0005432424876	570	40	21B
0005432424874	570	41	21E
0005432424877	570	42	22A
0005432424894	570	43	22C
0005432424865	570	44	23A
0005432424895	570	45	23B
0005432424912	570	46	23D
0005432424911	570	47	23F
0005432424878	570	48	24E
0005432424887	570	49	25E
0005432424892	570	50	26A
0005432424904	570	51	26F
0005432424868	570	52	27B
0005432424885	570	53	28A
0005432424909	570	54	29B
0005432424882	570	55	30A
0005432282927	570	56	30B
0005432424905	570	57	30F
0005432424896	570	58	31B
0005432282931	570	59	31E
0005432302366	12863	1	12C
0005432302367	12863	2	23F
0005432424428	12844	1	1D
0005432424417	12844	2	2F
0005432424438	12844	3	3D
0005432424420	12844	4	5D
0005432424232	12844	5	6D
0005432424332	12844	6	7F
0005432424397	12844	7	7D
0005432424432	12844	8	8B
0005432424460	12844	9	8F
0005432424455	12844	10	9D
0005432424398	12844	11	11C
0005432424431	12844	12	11D
0005432424144	12844	13	12A
0005432424454	12844	14	12B
0005432424419	12844	15	13B
0005432424277	12844	16	14A
0005432424440	12844	17	15D
0005432424315	12844	18	15E
0005432424390	12844	19	16C
0005432424331	12844	20	17E
0005432424391	12844	21	18D
0005432424366	12844	22	18F
0005432424392	12844	23	22C
0005432424416	12844	24	22E
0005432424308	12844	25	23B
0005432424412	12844	26	24B
0005432424418	12844	27	25B
0005432424451	12844	28	25F
0005432424320	12844	29	26D
0005432424145	12844	30	27D
0005432424396	12844	31	29A
0005432424387	12844	32	29C
0005432424401	12844	33	29F
0005432424380	12844	34	30A
0005432424402	12844	35	30D
0005432424421	12844	36	31C
0005432424318	12844	37	31E
0005432424335	12844	38	31D
0005434024307	458	1	1A
0005434024371	458	2	1F
0005432235708	458	3	1C
0005433058014	458	4	1G
0005434024316	458	5	2A
0005434024338	458	6	1H
0005434024342	458	7	2B
0005434024329	458	8	2C
0005433057853	458	9	2H
0005434024360	458	10	2G
0005434024349	458	11	3A
0005434024322	458	12	3C
0005434024312	458	13	3G
0005434024373	458	14	4A
0005434024343	458	15	3H
0005432235704	458	16	4B
0005434024321	458	17	4F
0005434024305	458	18	4C
0005433057854	458	19	5A
0005434024347	458	20	4H
0005434024336	458	21	5B
0005434024351	458	22	5F
0005434024334	458	23	5H
0005434024314	458	24	9B
0005433057833	458	25	9H
0005434024319	458	26	11A
0005434024348	458	27	11E
0005433058046	458	28	11D
0005434024323	458	29	11H
0005434024326	458	30	11G
0005434029676	458	31	12D
0005433058089	458	32	12B
0005434024327	458	33	12E
0005434024358	458	34	12G
0005432235709	458	35	12H
0005434376223	458	36	13B
0005433057746	458	37	13F
0005433057915	458	38	14B
0005433684415	458	39	14A
0005433057998	458	40	14D
0005434024369	458	41	14F
0005434024353	458	42	14G
0005434024335	458	43	15A
0005434024317	458	44	15B
0005433057970	458	45	15E
0005433057914	458	46	15D
0005434024365	458	47	15F
0005434024332	458	48	15H
0005433058099	458	49	16A
0005433929627	458	50	16E
0005434024363	458	51	16G
0005434028320	458	52	16H
0005433929601	458	53	17B
0005433057916	458	54	17E
0005433058021	458	55	17G
0005434032062	458	56	18B
0005434024339	458	57	18D
0005433058015	458	58	18F
0005434024311	458	59	18G
0005433058067	458	60	18H
0005434735670	458	61	19B
0005434024340	458	62	19F
0005433057745	458	63	19G
0005434735669	458	64	20A
0005433057873	458	65	19H
0005433057834	458	66	20F
0005434024333	458	67	20H
0005433058017	458	68	20G
0005433057887	458	69	21B
0005433057934	458	70	21F
0005434024366	458	71	21G
0005433057999	458	72	22B
0005433057943	458	73	22A
0005433057874	458	74	22F
0005433929628	458	75	22G
0005434024341	458	76	23A
0005433057855	458	77	23D
0005433684419	458	78	23F
0005434024328	458	79	23E
0005434024304	458	80	23G
0005432235706	458	81	23H
0005433684423	458	82	24A
0005434024364	458	83	24D
0005434024325	458	84	24F
0005434028321	458	85	24G
0005434028319	458	86	24H
0005433058095	458	87	25E
0005432235705	458	88	27A
0005433058018	458	89	27B
0005434024306	458	90	27E
0005434024310	458	91	27F
0005434024318	458	92	27G
0005434024372	458	93	28B
0005434032064	458	94	28D
0005434024313	458	95	28F
0005434735680	458	96	28G
0005432235711	458	97	29A
0005434024368	458	98	29B
0005432235710	458	99	29E
0005434029678	458	100	29D
0005433057917	458	101	29F
0005433057953	458	102	30B
0005433057942	458	103	30A
0005434024359	458	104	30E
0005434032065	458	105	30D
0005434024344	458	106	30G
0005434735662	458	107	30H
0005432045630	458	108	31E
0005434024324	458	109	31D
0005432235707	458	110	31F
0005434024331	458	111	31G
0005434024352	458	112	32A
0005433057761	458	113	31H
0005434029677	458	114	32D
0005434032063	458	115	32B
0005433058047	458	116	32E
0005434024357	458	117	32F
0005434024361	458	118	32H
0005434024354	458	119	32G
0005434024346	458	120	33B
0005434024345	458	121	33E
0005433058121	458	122	33F
0005434024355	458	123	33H
0005433057886	458	124	33G
0005434032061	458	125	34A
0005434028318	458	126	34B
0005433058114	458	127	34E
0005434735661	458	128	34H
0005433057809	458	129	34G
0005433929626	458	130	35D
0005434024350	458	131	36A
0005434024370	458	132	35H
0005434024367	458	133	36D
0005434024362	458	134	36E
0005433058066	458	135	36H
0005433058045	458	136	36G
0005434024309	458	137	37A
0005434024315	458	138	37B
0005433684431	458	139	37E
0005434024337	458	140	38B
0005433058115	458	141	38A
0005433058074	458	142	37H
0005434376224	458	143	38D
0005434024320	458	144	38E
0005434024308	458	145	38H
0005433684420	458	146	38G
0005434024356	458	147	39D
0005434024330	458	148	39F
0005433058246	12676	1	1B
0005433058244	12676	2	1G
0005434023883	12676	3	2A
0005434023596	12676	4	1H
0005433929653	12676	5	2C
0005433058269	12676	6	2G
0005434024062	12676	7	3B
0005432156407	12676	8	3F
0005434023847	12676	9	3C
0005434023871	12676	10	3G
0005433058261	12676	11	3H
0005434023685	12676	12	4C
0005434023725	12676	13	4B
0005434023843	12676	14	4A
0005434023793	12676	15	4F
0005434023788	12676	16	5A
0005433058250	12676	17	4H
0005433929649	12676	18	5F
0005434023650	12676	19	5C
0005432156405	12676	20	9A
0005434735741	12676	21	5H
0005434735740	12676	22	11A
0005433058256	12676	23	9H
0005433058236	12676	24	11B
0005433058273	12676	25	11G
0005434023700	12676	26	11E
0005434023777	12676	27	12A
0005433058247	12676	28	12D
0005434032034	12676	29	12H
0005433058259	12676	30	13A
0005434023965	12676	31	13D
0005434023419	12676	32	13B
0005433058248	12676	33	13E
0005434023726	12676	34	13G
0005434023689	12676	35	13F
0005432157510	12676	36	14A
0005433058254	12676	37	13H
0005434023741	12676	38	14B
0005434023874	12676	39	14D
0005434032035	12676	40	15A
0005433929652	12676	41	15D
0005434023624	12676	42	15B
0005434024021	12676	43	15E
0005433929651	12676	44	15F
0005432156409	12676	45	16A
0005433058242	12676	46	16D
0005434023936	12676	47	16B
0005434023542	12676	48	16E
0005433058243	12676	49	16F
0005434023679	12676	50	16H
0005434023628	12676	51	16G
0005434023957	12676	52	17A
0005433058260	12676	53	17D
0005434023824	12676	54	17E
0005434023718	12676	55	17G
0005434028288	12676	56	17F
0005433058252	12676	57	17H
0005433058264	12676	58	18B
0005434023880	12676	59	18D
0005434023937	12676	60	18F
0005434023928	12676	61	18E
0005434023724	12676	62	18G
0005434024063	12676	63	19A
0005434023512	12676	64	19E
0005434023714	12676	65	19F
0005433058265	12676	66	19G
0005433684440	12676	67	20A
0005433058267	12676	68	19H
0005434023956	12676	69	20D
0005434032039	12676	70	20B
0005433058270	12676	71	20E
0005433058276	12676	72	20F
0005433058258	12676	73	20G
0005433058275	12676	74	21E
0005433058253	12676	75	21D
0005434023713	12676	76	21G
0005433058249	12676	77	21H
0005434024083	12676	78	22A
0005433058251	12676	79	22B
0005434023828	12676	80	22F
0005434032020	12676	81	22G
0005434023723	12676	82	23B
0005434023831	12676	83	23D
0005434023552	12676	84	23F
0005434032038	12676	85	23E
0005434023833	12676	86	23G
0005433058240	12676	87	23H
0005434023387	12676	88	24B
0005434023821	12676	89	24A
0005434023918	12676	90	24D
0005434023794	12676	91	24F
0005433058255	12676	92	24E
0005434023553	12676	93	24G
0005433929650	12676	94	25E
0005433058262	12676	95	25D
0005434023677	12676	96	25F
0005434024020	12676	97	27E
0005433058241	12676	98	27F
0005434023678	12676	99	27H
0005432157509	12676	100	28A
0005434023844	12676	101	28D
0005433684439	12676	102	28B
0005433058271	12676	103	28E
0005433058263	12676	104	28G
0005434023921	12676	105	29A
0005434024071	12676	106	28H
0005433058266	12676	107	29D
0005433684441	12676	108	29B
0005434023917	12676	109	29E
0005434032021	12676	110	29F
0005433058238	12676	111	29G
0005434023688	12676	112	30A
0005433058257	12676	113	30E
0005434023887	12676	114	30G
0005434023929	12676	115	31A
0005434023731	12676	116	30H
0005432156408	12676	117	31B
0005434024089	12676	118	31D
0005434023717	12676	119	31E
0005434023800	12676	120	32A
0005434023701	12676	121	32D
0005434023927	12676	122	32B
0005433058274	12676	123	32F
0005434023647	12676	124	32G
0005433058237	12676	125	33A
0005434024022	12676	126	33D
0005434023942	12676	127	33B
0005434023690	12676	128	33E
0005434023849	12676	129	33G
0005434023848	12676	130	33F
0005434024044	12676	131	34B
0005434032028	12676	132	34A
0005434735737	12676	133	34E
0005434023819	12676	134	34G
0005434023648	12676	135	35B
0005434028297	12676	136	35D
0005434023902	12676	137	35E
0005434023966	12676	138	35F
0005432156406	12676	139	36A
0005434032019	12676	140	35H
0005434023783	12676	141	36B
0005434023955	12676	142	36D
0005434024061	12676	143	36E
0005433058239	12676	144	36G
0005434735738	12676	145	36H
0005434023825	12676	146	37D
0005434023730	12676	147	37B
0005434023581	12676	148	37E
0005434023943	12676	149	37F
0005434023935	12676	150	37H
0005434735736	12676	151	37G
0005434735739	12676	152	38B
0005434023422	12676	153	38D
0005434023810	12676	154	38F
0005434023799	12676	155	38E
0005433058268	12676	156	38G
0005434024070	12676	157	38H
0005433058272	12676	158	39D
0005433058245	12676	159	39F
0005434023827	12676	160	39E
0005433036418	2124	1	1C
0005433036233	2124	2	1B
0005433924185	2124	3	1F
0005433924144	2124	4	1H
0005433929653	2124	5	1G
0005433924188	2124	6	2A
0005433929650	2124	7	2B
0005433924226	2124	8	2F
0005433924174	2124	9	2C
0005433924165	2124	10	2G
0005433036214	2124	11	3A
0005433924146	2124	12	3F
0005433924171	2124	13	3C
0005433924152	2124	14	3G
0005433036256	2124	15	4C
0005433924147	2124	16	4G
0005433924193	2124	17	4F
0005433036401	2124	18	5B
0005433036235	2124	19	5G
0005433924169	2124	20	5H
0005433924218	2124	21	9B
0005432749781	2124	22	9A
0005433924160	2124	23	9G
0005433036435	2124	24	11A
0005433036225	2124	25	11B
0005433036408	2124	26	11D
0005432231664	2124	27	11F
0005433036251	2124	28	11H
0005433036227	2124	29	11G
0005433036517	2124	30	12A
0005433924234	2124	31	12B
0005433924198	2124	32	12E
0005433036198	2124	33	12D
0005433924183	2124	34	12G
0005433924145	2124	35	12F
0005433036011	2124	36	13A
0005433924217	2124	37	13D
0005433924194	2124	38	13E
0005433036582	2124	39	13G
0005433924192	2124	40	13F
0005433036462	2124	41	14E
0005433924227	2124	42	14D
0005433036386	2124	43	14F
0005433924233	2124	44	14G
0005433924204	2124	45	14H
0005433035956	2124	46	15B
0005433924161	2124	47	15E
0005434028297	2124	48	15F
0005433931494	2124	49	15H
0005433924213	2124	50	16D
0005433924210	2124	51	16B
0005433924207	2124	52	16E
0005433036400	2124	53	16F
0005433924200	2124	54	16G
0005433924182	2124	55	17B
0005433036536	2124	56	17A
0005433924221	2124	57	17D
0005433924167	2124	58	17E
0005432749775	2124	59	17G
0005433924143	2124	60	17H
0005432231658	2124	61	18B
0005433924187	2124	62	18A
0005433924199	2124	63	18D
0005433924179	2124	64	18F
0005433924219	2124	65	18E
0005433924225	2124	66	18H
0005433924229	2124	67	18G
0005433924238	2124	68	19A
0005433036258	2124	69	19B
0005433929651	2124	70	19D
0005432231661	2124	71	19F
0005433036285	2124	72	19G
0005433924186	2124	73	20A
0005433924191	2124	74	19H
0005433924157	2124	75	20D
0005433924151	2124	76	20B
0005433924236	2124	77	20E
0005433036319	2124	78	20F
0005433035955	2124	79	20H
0005433924195	2124	80	21A
0005433924173	2124	81	21D
0005432231663	2124	82	21B
0005433924168	2124	83	21E
0005433924237	2124	84	21F
0005433036425	2124	85	21H
0005432231659	2124	86	21G
0005433036399	2124	87	22A
0005433036365	2124	88	22D
0005433924202	2124	89	22B
0005433924164	2124	90	22E
0005433924224	2124	91	22G
0005434028288	2124	92	22F
0005433036272	2124	93	23A
0005433924163	2124	94	22H
0005433924196	2124	95	23B
0005433036118	2124	96	23F
0005432231662	2124	97	23E
0005433924228	2124	98	23G
0005433924178	2124	99	23H
0005433924154	2124	100	24B
0005433924141	2124	101	24A
0005432749776	2124	102	24D
0005433924212	2124	103	24F
0005433924206	2124	104	24E
0005433924176	2124	105	24G
0005433924230	2124	106	24H
0005432749771	2124	107	25E
0005433924142	2124	108	25D
0005432749784	2124	109	27A
0005433036437	2124	110	25F
0005433036463	2124	111	27D
0005433924184	2124	112	27F
0005433924159	2124	113	27E
0005433924205	2124	114	27H
0005433035975	2124	115	27G
0005432231665	2124	116	28A
0005433036439	2124	117	28B
0005433924181	2124	118	28E
0005433924214	2124	119	28D
0005433924175	2124	120	28F
0005433929649	2124	121	28G
0005433924180	2124	122	29A
0005433924162	2124	123	29D
0005433924197	2124	124	29B
0005433036518	2124	125	30B
0005433924153	2124	126	30A
0005433924209	2124	127	30D
0005433924189	2124	128	30E
0005433931493	2124	129	30G
0005433924231	2124	130	31A
0005433924158	2124	131	30H
0005433924232	2124	132	31B
0005433036613	2124	133	31D
0005433924203	2124	134	31F
0005433924155	2124	135	31E
0005433924211	2124	136	31H
0005433036356	2124	137	32B
0005433924220	2124	138	32A
0005432044550	2124	139	32E
0005433036284	2124	140	32D
0005433924148	2124	141	32F
0005432231668	2124	142	32H
0005433036436	2124	143	33D
0005433931495	2124	144	33B
0005433036234	2124	145	33F
0005433924156	2124	146	33H
0005433924208	2124	147	33G
0005433036299	2124	148	34A
0005433036387	2124	149	34D
0005433036364	2124	150	34B
0005433924150	2124	151	34E
0005433036320	2124	152	34G
0005433924177	2124	153	34H
0005433929652	2124	154	35B
0005433924235	2124	155	35A
0005433924172	2124	156	35D
0005433924223	2124	157	35F
0005432231666	2124	158	35E
0005432749788	2124	159	36A
0005433036431	2124	160	35H
0005433035976	2124	161	36B
0005433036257	2124	162	36D
0005433924215	2124	163	36F
0005433036250	2124	164	36G
0005433924170	2124	165	37A
0005433924201	2124	166	36H
0005433924222	2124	167	37B
0005432044551	2124	168	37E
0005432749777	2124	169	37F
0005432231657	2124	170	37H
0005433036197	2124	171	37G
0005433924216	2124	172	38A
0005432231660	2124	173	38D
0005433924166	2124	174	38B
0005433924190	2124	175	38E
0005432231667	2124	176	38H
0005433036273	2124	177	38G
0005433036381	2124	178	39D
0005433924149	2124	179	39F
0005433923774	24100	1	1C
0005433923301	24100	2	1F
0005433923619	24100	3	1H
0005433923074	24100	4	2A
0005433036766	24100	5	2B
0005433036794	24100	6	2F
0005433036803	24100	7	2H
0005432749805	24100	8	3B
0005433036775	24100	9	3H
0005433036812	24100	10	3G
0005433922887	24100	11	4B
0005433923381	24100	12	4A
0005433923393	24100	13	4F
0005433923584	24100	14	5A
0005433923370	24100	15	5F
0005433923281	24100	16	9B
0005433923531	24100	17	9A
0005433931464	24100	18	9H
0005433923591	24100	19	9G
0005433923683	24100	20	11D
0005433923585	24100	21	11B
0005433923385	24100	22	11F
0005432206252	24100	23	12A
0005433923040	24100	24	12B
0005433036793	24100	25	12D
0005432206249	24100	26	12F
0005433036807	24100	27	12G
0005433923473	24100	28	13B
0005433036799	24100	29	13A
0005433923635	24100	30	13D
0005433036784	24100	31	13F
0005433923444	24100	32	13E
0005433931462	24100	33	13G
0005433922847	24100	34	14A
0005433923474	24100	35	13H
0005433923544	24100	36	14B
0005433923294	24100	37	14F
0005433929616	24100	38	14E
0005433036798	24100	39	14G
0005433923382	24100	40	15B
0005433923668	24100	41	15A
0005433036785	24100	42	15D
0005433923322	24100	43	15F
0005433923178	24100	44	15G
0005433036797	24100	45	16A
0005432206248	24100	46	15H
0005433923070	24100	47	16B
0005433036809	24100	48	16E
0005433923634	24100	49	16D
0005434028323	24100	50	16G
0005433036781	24100	51	16H
0005433923454	24100	52	17D
0005433923255	24100	53	17B
0005433036795	24100	54	17E
0005433036801	24100	55	17F
0005433923303	24100	56	17H
0005433036804	24100	57	18B
0005433923364	24100	58	18E
0005433923453	24100	59	18D
0005433923744	24100	60	18F
0005433036800	24100	61	18G
0005433923525	24100	62	18H
0005433923616	24100	63	19A
0005433036790	24100	64	19D
0005433923617	24100	65	19F
0005433036764	24100	66	19E
0005433923065	24100	67	19H
0005433923313	24100	68	20D
0005433923066	24100	69	20B
0005433923157	24100	70	20G
0005433036777	24100	71	20F
0005433929617	24100	72	21A
0005433923336	24100	73	21E
0005433923443	24100	74	21D
0005433036761	24100	75	21G
0005433036805	24100	76	22B
0005433036786	24100	77	22A
0005433036767	24100	78	22F
0005433923195	24100	79	22E
0005432206250	24100	80	22G
0005433923062	24100	81	23A
0005433923192	24100	82	23D
0005433875386	24100	83	23B
0005433923249	24100	84	23F
0005433923094	24100	85	23E
0005433923455	24100	86	24A
0005433929603	24100	87	23H
0005433931467	24100	88	24B
0005433036768	24100	89	24E
0005433923184	24100	90	24D
0005433922848	24100	91	24H
0005433036778	24100	92	24G
0005433923406	24100	93	25E
0005432749806	24100	94	25F
0005433923460	24100	95	27B
0005433923237	24100	96	27E
0005433923177	24100	97	27G
0005433923618	24100	98	28B
0005433923386	24100	99	28E
0005433036765	24100	100	28D
0005433929619	24100	101	28F
0005433923507	24100	102	28H
0005433923283	24100	103	28G
0005432206247	24100	104	29B
0005433036772	24100	105	29E
0005434028322	24100	106	29D
0005433875371	24100	107	29G
0005433036762	24100	108	29F
0005433923667	24100	109	29H
0005433923549	24100	110	30B
0005433036773	24100	111	30A
0005433922975	24100	112	30D
0005433923179	24100	113	30E
0005433923363	24100	114	30G
0005433923548	24100	115	31A
0005433923114	24100	116	30H
0005433036770	24100	117	31D
0005433923093	24100	118	31E
0005433923506	24100	119	31G
0005433036791	24100	120	31F
0005433923324	24100	121	31H
0005433923597	24100	122	32D
0005433923064	24100	123	32B
0005433923063	24100	124	32E
0005433036769	24100	125	32F
0005433036806	24100	126	32G
0005433923191	24100	127	32H
0005433036796	24100	128	33B
0005433923578	24100	129	33D
0005433923615	24100	130	33G
0005433036802	24100	131	33F
0005433923569	24100	132	33H
0005433923193	24100	133	34D
0005433036788	24100	134	34B
0005433036783	24100	135	34E
0005433036779	24100	136	34G
0005433922888	24100	137	34F
0005433875385	24100	138	35A
0005433036780	24100	139	34H
0005433036789	24100	140	35B
0005433036810	24100	141	35D
0005433036763	24100	142	35F
0005433923579	24100	143	35E
0005433931461	24100	144	35G
0005433923236	24100	145	35H
0005433036808	24100	146	36B
0005433036813	24100	147	36E
0005433923614	24100	148	36G
0005433923291	24100	149	37A
0005433036811	24100	150	37B
0005433923348	24100	151	37E
0005433036787	24100	152	37D
0005433036771	24100	153	37F
0005433036774	24100	154	37G
0005433923240	24100	155	38A
0005432206251	24100	156	38E
0005433036776	24100	157	38F
0005432207686	24100	158	38H
0005433036792	24100	159	39E
0005433036782	24100	160	39D
0005433923570	24100	161	39F
0005434726553	292	1	1C
0005433234355	292	2	1A
0005435142709	292	3	1G
0005432277933	292	4	1D
0005433234089	292	5	1K
0005434726541	292	6	1H
0005433289842	292	7	2C
0005434726576	292	8	2A
0005433289869	292	9	2H
0005433234103	292	10	2D
0005434302499	292	11	3A
0005434551738	292	12	2K
0005433234138	292	13	3G
0005432277935	292	14	3D
0005434726657	292	15	3C
0005434726556	292	16	3H
0005434726651	292	17	4C
0005434735735	292	18	4A
0005433234253	292	19	3K
0005433234346	292	20	4G
0005433111508	292	21	4D
0005434551731	292	22	4K
0005434551723	292	23	4H
0005433234304	292	24	5D
0005434726637	292	25	5C
0005434551743	292	26	5A
0005434731207	292	27	5H
0005434726609	292	28	5G
0005435142702	292	29	11A
0005433234124	292	30	5K
0005434551760	292	31	11E
0005434551741	292	32	11D
0005434551716	292	33	11C
0005433181097	292	34	11G
0005434726581	292	35	11F
0005433234060	292	36	11H
0005434551753	292	37	12A
0005433289855	292	38	12E
0005433234534	292	39	12G
0005433181105	292	40	12F
0005433181112	292	41	12K
0005435142706	292	42	12H
0005434551759	292	43	13D
0005434551736	292	44	13C
0005434726534	292	45	13A
0005433766628	292	46	13F
0005434726644	292	47	13E
0005434726638	292	48	13H
0005434726624	292	49	13G
0005433234354	292	50	14A
0005434726639	292	51	14D
0005434551732	292	52	14E
0005433234296	292	53	14K
0005435142707	292	54	14H
0005433289858	292	55	15C
0005434551728	292	56	15A
0005434551763	292	57	15F
0005433181136	292	58	15E
0005434726544	292	59	15D
0005434551721	292	60	15G
0005434726636	292	61	16A
0005433234208	292	62	15K
0005434726573	292	63	15H
0005433234380	292	64	16D
0005433181130	292	65	16C
0005433234229	292	66	16F
0005434726569	292	67	16E
0005433234472	292	68	16H
0005434551750	292	69	16G
0005434551718	292	70	17C
0005434726579	292	71	16K
0005433234243	292	72	17E
0005434726646	292	73	17D
0005433181178	292	74	18A
0005434726633	292	75	17K
0005433234392	292	76	17H
0005434726630	292	77	18B
0005433234297	292	78	18E
0005434726561	292	79	18D
0005433181149	292	80	18C
0005433289843	292	81	18G
0005434551755	292	82	18F
0005433234303	292	83	18J
0005433234063	292	84	18H
0005434551757	292	85	19A
0005435142698	292	86	18K
0005433289845	292	87	19D
0005434726606	292	88	19C
0005433766630	292	89	19B
0005434726626	292	90	19F
0005434726614	292	91	19E
0005434735733	292	92	19J
0005433234254	292	93	19H
0005432277928	292	94	20A
0005434726605	292	95	19K
0005433181070	292	96	20C
0005434551767	292	97	20B
0005434726572	292	98	20E
0005434551766	292	99	20D
0005432277931	292	100	20J
0005434551730	292	101	20H
0005434551734	292	102	21D
0005434551752	292	103	21C
0005434731206	292	104	21B
0005433234657	292	105	21E
0005434726571	292	106	21J
0005434551733	292	107	21H
0005434726618	292	108	21G
0005434726652	292	109	22A
0005433131714	292	110	21K
0005434726610	292	111	22C
0005432277930	292	112	22B
0005434551749	292	113	22E
0005434726623	292	114	22D
0005434731204	292	115	22H
0005433233987	292	116	22G
0005433289859	292	117	22K
0005433234470	292	118	22J
0005434726617	292	119	23B
0005435142699	292	120	23D
0005434726567	292	121	23C
0005433234295	292	122	23G
0005433234460	292	123	23F
0005434726608	292	124	23E
0005433766646	292	125	23H
0005433181104	292	126	24D
0005434551715	292	127	23K
0005434551737	292	128	23J
0005433181069	292	129	24F
0005434551719	292	130	25B
0005434302501	292	131	25A
0005434726535	292	132	24G
0005433234206	292	133	25D
0005433234351	292	134	25C
0005432277938	292	135	25F
0005434726619	292	136	25H
0005433234533	292	137	25G
0005434726604	292	138	25K
0005433234345	292	139	26B
0005434726631	292	140	26A
0005433234202	292	141	26E
0005434726546	292	142	26H
0005433181146	292	143	26G
0005433234459	292	144	26F
0005434551751	292	145	26J
0005434302873	292	146	27B
0005433234113	292	147	27A
0005434726625	292	148	26K
0005434726548	292	149	27C
0005434726595	292	150	27F
0005434726593	292	151	27E
0005433181042	292	152	27D
0005433234503	292	153	27H
0005434726642	292	154	27G
0005434302500	292	155	28A
0005432277932	292	156	27K
0005435142708	292	157	27J
0005434726559	292	158	28C
0005434551744	292	159	28B
0005433234502	292	160	28E
0005433234366	292	161	28D
0005433289852	292	162	28F
0005434726620	292	163	28H
0005434726612	292	164	29A
0005434726562	292	165	29D
0005433289835	292	166	29F
0005434726586	292	167	29H
0005432277929	292	168	29G
0005434551720	292	169	30A
0005432277939	292	170	29K
0005434551729	292	171	29J
0005434726538	292	172	30C
0005434726591	292	173	30B
0005433234158	292	174	30E
0005434551758	292	175	30F
0005433181164	292	176	30K
0005434726550	292	177	30J
0005434726594	292	178	30H
0005434726598	292	179	31B
0005434726558	292	180	31A
0005434032027	292	181	31D
0005434551724	292	182	31C
0005433234199	292	183	31G
0005433234205	292	184	31F
0005434726629	292	185	31E
0005434726656	292	186	31J
0005434726611	292	187	32A
0005433181131	292	188	31K
0005434726539	292	189	32C
0005433181076	292	190	32B
0005434726585	292	191	32D
0005434726650	292	192	32G
0005434726583	292	193	32F
0005434302874	292	194	33B
0005433234282	292	195	33A
0005433181191	292	196	32K
0005433289847	292	197	33C
0005433234382	292	198	33F
0005433234231	292	199	33H
0005435142697	292	200	33G
0005434551735	292	201	34A
0005434726554	292	202	33K
0005434726578	292	203	33J
0005433234458	292	204	34C
0005434726601	292	205	34B
0005434551762	292	206	34E
0005433289856	292	207	34F
0005434726536	292	208	34H
0005433181084	292	209	35B
0005434551717	292	210	35A
0005433131708	292	211	35D
0005434726596	292	212	35C
0005434726588	292	213	35E
0005434551722	292	214	35J
0005434726584	292	215	35H
0005434726654	292	216	35G
0005433234088	292	217	36A
0005434551740	292	218	35K
0005435142705	292	219	36C
0005434726564	292	220	36B
0005433181187	292	221	36E
0005433234214	292	222	36D
0005434726565	292	223	36H
0005433131703	292	224	36G
0005433234285	292	225	36F
0005433181132	292	226	36K
0005434551747	292	227	36J
0005434726634	292	228	37B
0005434551745	292	229	37A
0005433234159	292	230	37E
0005433181208	292	231	37D
0005433181096	292	232	37C
0005434551761	292	233	37J
0005434551713	292	234	37H
0005434726648	292	235	37G
0005433234200	292	236	38A
0005434726628	292	237	37K
0005434726533	292	238	38C
0005433234117	292	239	38B
0005434726603	292	240	38K
0005434551756	292	241	38J
0005434726590	292	242	39A
0005434726574	292	243	39B
0005435142704	292	244	39F
0005433234381	292	245	39E
0005434551726	292	246	39D
0005434726635	292	247	39H
0005434551725	292	248	39G
0005433181087	292	249	39K
0005435142701	292	250	39J
0005434551765	292	251	40C
0005434551754	292	252	40B
0005434726600	292	253	40A
0005434726542	292	254	40E
0005434726597	292	255	40D
0005433181023	292	256	40G
0005434726615	292	257	40K
0005434731205	292	258	40J
0005435142700	292	259	40H
0005434726547	292	260	41B
0005434726560	292	261	41A
0005434735732	292	262	41D
0005434726632	292	263	41G
0005434726607	292	264	41F
0005433234469	292	265	41E
0005434726649	292	266	41J
0005433181089	292	267	41H
0005434726653	292	268	42A
0005434551764	292	269	41K
0005434726563	292	270	42B
0005434551748	292	271	42F
0005434726643	292	272	42E
0005432277936	292	273	42D
0005434726552	292	274	42G
0005434726640	292	275	42J
0005434726545	292	276	42H
0005434735731	292	277	43A
0005434726555	292	278	42K
0005434735734	292	279	43D
0005434726551	292	280	43C
0005434032025	292	281	43B
0005434726592	292	282	43F
0005432277937	292	283	43E
0005434032026	292	284	43H
0005433766645	292	285	43G
0005434726582	292	286	43K
0005433289844	292	287	43J
0005434726566	292	288	44C
0005434726599	292	289	44B
0005433289857	292	290	44A
0005434726616	292	291	44E
0005434551746	292	292	44D
0005434726655	292	293	44G
0005433111509	292	294	44F
0005434551739	292	295	44J
0005434726587	292	296	44H
0005434726540	292	297	45A
0005433234157	292	298	44K
0005434551742	292	299	45F
0005434726645	292	300	45E
0005434726568	292	301	45J
0005435142703	292	302	45H
0005433113543	292	303	45G
0005433181106	292	304	46A
0005433289836	292	305	45K
0005433234302	292	306	46C
0005433234352	292	307	46B
0005434551714	292	308	46D
0005434726613	292	309	46G
0005433234123	292	310	46F
0005434726622	292	311	46K
0005432277927	292	312	46J
0005433131716	292	313	46H
0005434726647	292	314	47C
0005433234116	292	315	47A
0005434726575	292	316	47D
0005434726602	292	317	47F
0005433181077	292	318	47E
0005434726570	292	319	47H
0005434551727	292	320	48C
0005432277934	292	321	48A
0005434726549	292	322	48F
0005434726577	292	323	48D
0005433234147	292	324	48H
0005433234517	292	325	48G
0005434726589	292	326	49C
0005433233873	292	327	49A
0005433289851	292	328	48K
0005434726627	292	329	49E
0005433289837	292	330	49D
0005433181115	292	331	49G
0005435142696	292	332	49F
0005432277926	292	333	49K
0005433234215	292	334	49H
0005434726580	292	335	50C
0005433181116	292	336	50A
0005434726621	292	337	50F
0005434726537	292	338	50E
0005433234268	292	339	50D
0005433234084	292	340	50H
0005434726557	292	341	51D
0005433289854	292	342	50K
0005434726641	292	343	51G
0005434726543	292	344	51F
0005433181335	9837	1	1C
0005435142592	9837	2	1A
0005434725777	9837	3	1G
0005433234782	9837	4	1D
0005434725419	9837	5	1K
0005434725328	9837	6	1H
0005433234783	9837	7	2C
0005433234757	9837	8	2A
0005433181332	9837	9	2G
0005434725950	9837	10	2D
0005433234803	9837	11	2K
0005433234770	9837	12	2H
0005433234786	9837	13	3G
0005434725412	9837	14	3C
0005434551128	9837	15	4C
0005433234758	9837	16	4A
0005434551236	9837	17	3K
0005434725874	9837	18	4G
0005433289915	9837	19	4K
0005433234771	9837	20	4H
0005434551171	9837	21	5D
0005434731163	9837	22	5C
0005433234762	9837	23	5A
0005434725787	9837	24	5H
0005434725609	9837	25	5G
0005434725493	9837	26	11A
0005434726115	9837	27	5K
0005434551103	9837	28	11E
0005433289916	9837	29	11D
0005434725219	9837	30	11C
0005433113556	9837	31	11F
0005434551014	9837	32	11K
0005434725914	9837	33	11H
0005433234764	9837	34	12C
0005433289911	9837	35	12F
0005434725191	9837	36	12E
0005434725222	9837	37	12D
0005434725402	9837	38	12G
0005434551247	9837	39	13A
0005434725576	9837	40	12H
0005434725249	9837	41	13D
0005434551286	9837	42	13F
0005434725678	9837	43	13E
0005434725115	9837	44	13H
0005434551210	9837	45	13G
0005434725759	9837	46	14A
0005434032068	9837	47	13K
0005434725486	9837	48	14E
0005434551204	9837	49	14C
0005433234789	9837	50	14G
0005434726026	9837	51	14F
0005433234792	9837	52	14H
0005435142604	9837	53	15A
0005434725522	9837	54	14K
0005434725925	9837	55	15F
0005434725196	9837	56	15E
0005433234796	9837	57	15H
0005435142609	9837	58	15G
0005433181331	9837	59	16A
0005434731178	9837	60	15K
0005433234778	9837	61	16C
0005434731185	9837	62	16F
0005433234815	9837	63	16E
0005433234807	9837	64	16G
0005433129320	9837	65	17C
0005433181329	9837	66	17A
0005434551431	9837	67	16K
0005434726007	9837	68	17E
0005434725625	9837	69	17D
0005435142554	9837	70	17G
0005434725368	9837	71	17F
0005435142579	9837	72	17K
0005434725468	9837	73	17H
0005433181337	9837	74	18C
0005434725529	9837	75	18B
0005434551170	9837	76	18E
0005435142514	9837	77	18D
0005434725512	9837	78	18G
0005433181345	9837	79	18F
0005434725365	9837	80	18J
0005434725041	9837	81	18H
0005434032066	9837	82	19B
0005434725464	9837	83	19A
0005433181344	9837	84	18K
0005433234756	9837	85	19D
0005433234817	9837	86	19C
0005434551296	9837	87	19H
0005434725285	9837	88	19J
0005434551297	9837	89	20C
0005433766675	9837	90	20B
0005433181325	9837	91	20A
0005434725538	9837	92	20D
0005434725808	9837	93	20G
0005434725277	9837	94	20F
0005434725677	9837	95	20J
0005434725085	9837	96	20H
0005434551027	9837	97	21A
0005433126887	9837	98	20K
0005434735667	9837	99	21D
0005433234798	9837	100	21C
0005433234790	9837	101	21F
0005434725698	9837	102	21J
0005434725355	9837	103	21H
0005434726128	9837	104	22A
0005433234808	9837	105	21K
0005434032069	9837	106	22C
0005434725560	9837	107	22B
0005434551257	9837	108	22F
0005434551323	9837	109	22E
0005434725799	9837	110	22H
0005434725757	9837	111	22K
0005434725084	9837	112	23B
0005434731165	9837	113	23A
0005434725265	9837	114	23D
0005434725809	9837	115	23C
0005434725532	9837	116	23F
0005434725516	9837	117	23E
0005433234813	9837	118	23H
0005434725531	9837	119	23G
0005433234811	9837	120	24D
0005434725567	9837	121	23K
0005434551342	9837	122	23J
0005434551235	9837	123	24F
0005433181324	9837	124	24E
0005433234755	9837	125	25B
0005433234776	9837	126	25A
0005435142605	9837	127	24G
0005434725873	9837	128	25D
0005434724936	9837	129	25C
0005434725774	9837	130	25F
0005433234774	9837	131	25E
0005434551221	9837	132	25H
0005434735702	9837	133	25G
0005433234781	9837	134	26A
0005433234802	9837	135	25K
0005435142546	9837	136	25J
0005433234763	9837	137	26C
0005434725617	9837	138	26D
0005433234809	9837	139	26G
0005433181333	9837	140	26F
0005433234775	9837	141	26K
0005434725367	9837	142	26H
0005433234814	9837	143	27D
0005433234800	9837	144	27C
0005434725601	9837	145	27B
0005434726035	9837	146	27F
0005434725924	9837	147	27H
0005434725352	9837	148	27G
0005435142510	9837	149	27K
0005433234788	9837	150	28B
0005434551129	9837	151	28A
0005434725369	9837	152	28E
0005433181326	9837	153	28D
0005434302435	9837	154	28C
0005434725276	9837	155	28G
0005434551354	9837	156	28F
0005433126888	9837	157	28J
0005434302436	9837	158	28H
0005434724885	9837	159	28K
0005434725779	9837	160	29D
0005433234787	9837	161	29C
0005433234768	9837	162	29B
0005432199313	9837	163	29F
0005434302462	9837	164	29E
0005434735668	9837	165	29J
0005434725349	9837	166	29H
0005434725561	9837	167	29G
0005434551255	9837	168	30C
0005434731177	9837	169	30E
0005434725279	9837	170	30G
0005434725477	9837	171	30F
0005434725589	9837	172	30J
0005434725885	9837	173	30H
0005434551172	9837	174	31B
0005434551287	9837	175	31A
0005434725901	9837	176	30K
0005433234761	9837	177	31D
0005434735687	9837	178	31C
0005435142591	9837	179	31G
0005433129318	9837	180	31F
0005434725463	9837	181	31E
0005433289913	9837	182	31H
0005434551222	9837	183	31K
0005434551348	9837	184	31J
0005435142593	9837	185	32C
0005433129319	9837	186	32B
0005434551003	9837	187	32E
0005434725517	9837	188	32D
0005435142509	9837	189	32G
0005433234766	9837	190	32K
0005433234795	9837	191	32J
0005434725709	9837	192	32H
0005433234793	9837	193	33A
0005433234806	9837	194	33C
0005433234769	9837	195	33B
0005433766674	9837	196	33F
0005433181341	9837	197	33E
0005435142581	9837	198	33J
0005435142612	9837	199	33H
0005434551355	9837	200	33K
0005433289914	9837	201	34C
0005433766677	9837	202	34A
0005433234804	9837	203	34E
0005434725752	9837	204	34D
0005434725582	9837	205	34G
0005434725205	9837	206	34F
0005434725988	9837	207	34K
0005433129316	9837	208	34J
0005433766676	9837	209	34H
0005434725221	9837	210	35B
0005434550881	9837	211	35C
0005434725716	9837	212	35F
0005433129317	9837	213	35H
0005434725760	9837	214	35G
0005433181340	9837	215	36A
0005434726008	9837	216	35K
0005434725465	9837	217	35J
0005434551223	9837	218	36C
0005434724978	9837	219	36B
0005433181339	9837	220	36F
0005433234784	9837	221	36E
0005434551213	9837	222	36H
0005434725630	9837	223	36G
0005433234819	9837	224	36K
0005432199315	9837	225	36J
0005434725679	9837	226	37B
0005434302449	9837	227	37A
0005433181342	9837	228	37D
0005434725354	9837	229	37F
0005433181338	9837	230	37H
0005434551125	9837	231	37G
0005434551372	9837	232	37K
0005432199314	9837	233	37J
0005433234760	9837	234	38C
0005433181334	9837	235	38B
0005433234777	9837	236	38J
0005434725353	9837	237	38H
0005433234772	9837	238	39A
0005433181320	9837	239	39D
0005433234759	9837	240	39C
0005434551134	9837	241	39F
0005433181343	9837	242	39E
0005434725804	9837	243	39K
0005434725467	9837	244	39J
0005433234797	9837	245	40C
0005434725697	9837	246	40B
0005434032067	9837	247	40F
0005434551133	9837	248	40E
0005432199311	9837	249	40D
0005434725715	9837	250	40G
0005434725600	9837	251	40K
0005434551256	9837	252	40H
0005434302437	9837	253	41A
0005434725488	9837	254	41D
0005434725632	9837	255	41C
0005433234773	9837	256	41B
0005434551209	9837	257	41F
0005432199312	9837	258	41E
0005434725028	9837	259	41H
0005434725608	9837	260	41G
0005434551234	9837	261	41K
0005433234765	9837	262	42C
0005434724979	9837	263	42B
0005433234794	9837	264	42A
0005434725629	9837	265	42E
0005434725327	9837	266	42H
0005434725923	9837	267	42G
0005433289912	9837	268	42F
0005433126886	9837	269	42J
0005433234791	9837	270	43B
0005434551124	9837	271	43A
0005434731164	9837	272	42K
0005434725356	9837	273	43D
0005434725286	9837	274	43F
0005434725425	9837	275	43E
0005433181321	9837	276	43H
0005434725333	9837	277	44A
0005434551130	9837	278	43J
0005433181327	9837	279	44C
0005434725810	9837	280	44B
0005433234818	9837	281	44E
0005433181336	9837	282	44D
0005434725413	9837	283	44G
0005434725347	9837	284	44F
0005434726127	9837	285	45A
0005435142545	9837	286	45B
0005434725348	9837	287	45E
0005433234816	9837	288	45H
0005433234779	9837	289	45G
0005433234810	9837	290	46A
0005433234785	9837	291	45K
0005433234767	9837	292	45J
0005434725364	9837	293	46C
0005434725978	9837	294	46E
0005432199309	9837	295	46G
0005433181322	9837	296	46J
0005433181328	9837	297	46H
0005434725624	9837	298	47C
0005433113555	9837	299	47A
0005433181330	9837	300	47D
0005434551294	9837	301	47G
0005434302450	9837	302	47F
0005434725332	9837	303	47E
0005433181323	9837	304	47K
0005434551165	9837	305	47H
0005433126885	9837	306	48D
0005434725528	9837	307	48C
0005434551232	9837	308	48G
0005434551373	9837	309	49C
0005434725590	9837	310	49A
0005434551258	9837	311	48K
0005434725424	9837	312	49D
0005432199310	9837	313	49G
0005433234812	9837	314	49E
0005434551310	9837	315	49K
0005433234799	9837	316	49H
0005434725376	9837	317	50A
0005433234805	9837	318	50E
0005434725633	9837	319	50H
0005434725029	9837	320	50G
0005434725778	9837	321	50F
0005433234801	9837	322	51D
0005434735690	9837	323	50K
0005434725951	9837	324	51F
0005434725492	9837	325	51E
0005433234780	9837	326	51G
0005435213623	7738	1	1C
0005434068237	7738	2	1A
0005435213553	7738	3	1H
0005432529250	7738	4	1G
0005432529168	7738	5	1D
0005435213554	7738	6	2A
0005432069787	7738	7	1K
0005435213566	7738	8	2D
0005435213659	7738	9	2G
0005435725611	7738	10	3A
0005435213661	7738	11	2H
0005432529163	7738	12	3D
0005432529126	7738	13	3K
0005432529218	7738	14	3H
0005432529227	7738	15	4C
0005434068243	7738	16	4A
0005432535877	7738	17	4G
0005435213512	7738	18	4D
0005435213555	7738	19	4K
0005434068204	7738	20	4H
0005432150267	7738	21	5C
0005432529217	7738	22	5A
0005435213556	7738	23	5H
0005432529252	7738	24	5D
0005435213354	7738	25	11A
0005432529210	7738	26	5K
0005435213976	7738	27	11D
0005435630976	7738	28	11C
0005434068240	7738	29	11F
0005434068233	7738	30	11E
0005435213778	7738	31	11H
0005432529231	7738	32	11G
0005434068247	7738	33	12C
0005435213627	7738	34	12A
0005432529138	7738	35	11K
0005435213385	7738	36	12E
0005434068211	7738	37	12D
0005434068239	7738	38	12G
0005435213605	7738	39	12F
0005434068195	7738	40	12K
0005435213565	7738	41	12H
0005432529247	7738	42	13D
0005435213744	7738	43	13C
0005432529166	7738	44	13A
0005434068221	7738	45	13F
0005435213357	7738	46	13E
0005432529242	7738	47	13G
0005432529147	7738	48	14A
0005434068223	7738	49	13K
0005435213702	7738	50	14E
0005435213658	7738	51	14D
0005435213528	7738	52	14C
0005432529131	7738	53	14G
0005435630971	7738	54	14F
0005435725592	7738	55	14K
0005432529149	7738	56	14H
0005432529249	7738	57	15C
0005432529122	7738	58	15A
0005435213526	7738	59	15D
0005432529170	7738	60	15H
0005432529174	7738	61	16A
0005432529158	7738	62	15K
0005432529182	7738	63	16D
0005432533318	7738	64	16C
0005435213458	7738	65	16F
0005435213503	7738	66	16E
0005432529144	7738	67	16H
0005432529251	7738	68	16G
0005432529228	7738	69	17A
0005434068224	7738	70	16K
0005432529151	7738	71	17E
0005435213414	7738	72	17C
0005432529146	7738	73	17H
0005435213271	7738	74	17G
0005432529155	7738	75	17F
0005435213681	7738	76	18A
0005435213592	7738	77	17K
0005435213579	7738	78	18C
0005435213299	7738	79	18B
0005432529129	7738	80	18E
0005434068248	7738	81	18D
0005435213807	7738	82	18G
0005435213401	7738	83	18F
0005435213549	7738	84	18J
0005435213423	7738	85	18H
0005434068202	7738	86	19A
0005432529201	7738	87	19D
0005435213799	7738	88	19C
0005432529238	7738	89	19B
0005432529215	7738	90	19F
0005435213806	7738	91	19E
0005434068187	7738	92	19H
0005434068188	7738	93	19G
0005434068216	7738	94	20C
0005432537077	7738	95	20B
0005432529136	7738	96	20A
0005432428959	7738	97	20E
0005434068227	7738	98	20D
0005435213593	7738	99	20G
0005432529191	7738	100	20F
0005432529214	7738	101	20K
0005432529229	7738	102	20J
0005432529162	7738	103	21B
0005435213453	7738	104	21A
0005434068225	7738	105	21E
0005434068196	7738	106	21F
0005432069791	7738	107	21J
0005432535880	7738	108	21H
0005435213514	7738	109	22A
0005432428961	7738	110	21K
0005432069783	7738	111	22C
0005434068206	7738	112	22D
0005432069790	7738	113	22H
0005432529137	7738	114	22G
0005435213692	7738	115	22F
0005434068234	7738	116	22K
0005432150268	7738	117	22J
0005432529150	7738	118	23B
0005434068226	7738	119	23A
0005435213550	7738	120	23D
0005432529175	7738	121	23C
0005435630957	7738	122	23F
0005435630981	7738	123	23E
0005432150266	7738	124	23J
0005434068203	7738	125	24G
0005432529181	7738	126	24F
0005432529224	7738	127	24E
0005432529211	7738	128	25A
0005435213516	7738	129	25D
0005432529220	7738	130	25C
0005432529245	7738	131	25B
0005432529123	7738	132	25F
0005434068201	7738	133	25E
0005432529213	7738	134	25H
0005434068238	7738	135	25G
0005435213424	7738	136	25J
0005432529153	7738	137	26C
0005432529125	7738	138	26B
0005432529209	7738	139	26A
0005432529230	7738	140	26E
0005434068193	7738	141	26D
0005434068228	7738	142	26G
0005432529128	7738	143	26F
0005434068229	7738	144	26K
0005432529134	7738	145	26J
0005434068207	7738	146	26H
0005432529169	7738	147	27B
0005435213767	7738	148	27A
0005432537076	7738	149	27C
0005432529177	7738	150	27F
0005432529159	7738	151	27E
0005432529178	7738	152	27D
0005434068252	7738	153	27J
0005435213629	7738	154	27H
0005434068218	7738	155	27G
0005432529171	7738	156	28A
0005435213504	7738	157	28C
0005435213452	7738	158	28E
0005432529157	7738	159	28H
0005435213433	7738	160	28G
0005435213356	7738	161	28F
0005435213455	7738	162	28J
0005432529234	7738	163	29A
0005432529141	7738	164	28K
0005432529237	7738	165	29D
0005432529244	7738	166	29C
0005432529232	7738	167	29F
0005435725610	7738	168	29E
0005434068231	7738	169	29J
0005432529167	7738	170	29H
0005435213628	7738	171	30C
0005432529233	7738	172	30B
0005432537078	7738	173	30A
0005434068199	7738	174	30E
0005435213614	7738	175	30D
0005434068186	7738	176	30G
0005435630958	7738	177	30F
0005434068191	7738	178	30J
0005434068250	7738	179	30H
0005434068212	7738	180	30K
0005434068210	7738	181	31D
0005434068220	7738	182	31B
0005435213527	7738	183	31F
0005432069786	7738	184	31E
0005432529208	7738	185	31H
0005432529240	7738	186	31G
0005435213800	7738	187	31K
0005432529200	7738	188	32B
0005434068249	7738	189	32A
0005435213394	7738	190	32E
0005432529219	7738	191	32C
0005432529236	7738	192	32G
0005434068213	7738	193	32J
0005435213587	7738	194	32H
0005432069784	7738	195	33B
0005432529206	7738	196	33A
0005432529154	7738	197	33C
0005432529160	7738	198	33F
0005435213691	7738	199	33E
0005434068230	7738	200	33J
0005432535876	7738	201	33H
0005432535881	7738	202	33G
0005434068245	7738	203	34A
0005432529135	7738	204	33K
0005432529207	7738	205	34C
0005432529203	7738	206	34B
0005432529197	7738	207	34E
0005432529173	7738	208	34D
0005434068222	7738	209	34H
0005432529199	7738	210	34G
0005432069792	7738	211	34F
0005434068241	7738	212	34K
0005435213660	7738	213	34J
0005434068215	7738	214	35B
0005432529195	7738	215	35A
0005435213312	7738	216	35C
0005432529143	7738	217	35F
0005432529239	7738	218	35E
0005434068189	7738	219	35H
0005432529145	7738	220	35G
0005432069785	7738	221	35K
0005435213680	7738	222	36C
0005435213777	7738	223	36F
0005432529185	7738	224	36D
0005435213485	7738	225	36H
0005435213625	7738	226	36G
0005432069795	7738	227	36K
0005432529198	7738	228	36J
0005432529142	7738	229	37B
0005432529152	7738	230	37A
0005435213355	7738	231	37E
0005432529186	7738	232	37D
0005435213564	7738	233	37C
0005432529248	7738	234	37F
0005434068184	7738	235	37H
0005432529190	7738	236	37G
0005432529222	7738	237	37K
0005432529254	7738	238	37J
0005434068214	7738	239	38C
0005435213413	7738	240	38B
0005434068183	7738	241	38J
0005435213353	7738	242	38H
0005434068219	7738	243	39A
0005435213457	7738	244	38K
0005432529202	7738	245	39C
0005434068200	7738	246	39B
0005435213346	7738	247	39G
0005435213441	7738	248	39F
0005432529188	7738	249	39E
0005432529221	7738	250	39D
0005435213820	7738	251	39J
0005432150270	7738	252	39H
0005435213345	7738	253	39K
0005432150265	7738	254	40C
0005435630970	7738	255	40B
0005432150269	7738	256	40A
0005432529132	7738	257	40E
0005432529124	7738	258	40H
0005435725604	7738	259	40G
0005432529235	7738	260	40F
0005434068253	7738	261	40K
0005432529223	7738	262	40J
0005434068205	7738	263	41A
0005432529212	7738	264	41D
0005432529139	7738	265	41C
0005434068254	7738	266	41E
0005434068232	7738	267	41J
0005434068194	7738	268	41H
0005432529216	7738	269	41G
0005434068209	7738	270	42A
0005432150264	7738	271	41K
0005432529196	7738	272	42C
0005432529133	7738	273	42B
0005432529140	7738	274	42E
0005435725614	7738	275	42D
0005432529241	7738	276	42H
0005435213599	7738	277	42G
0005435213769	7738	278	42F
0005434068197	7738	279	42J
0005434068190	7738	280	43B
0005435213515	7738	281	43A
0005432529130	7738	282	42K
0005434068217	7738	283	43D
0005434068236	7738	284	43C
0005435213402	7738	285	43E
0005432529246	7738	286	43G
0005435725591	7738	287	43K
0005435213763	7738	288	43J
0005432069789	7738	289	44B
0005432069794	7738	290	44A
0005432533319	7738	291	44E
0005432529161	7738	292	44D
0005432533317	7738	293	44G
0005434068235	7738	294	44F
0005432529165	7738	295	44K
0005432529194	7738	296	44J
0005432069793	7738	297	44H
0005432529189	7738	298	45B
0005435213459	7738	299	45A
0005434068185	7738	300	45E
0005432529192	7738	301	45D
0005432529183	7738	302	45J
0005435213569	7738	303	45H
0005434068251	7738	304	45G
0005432529243	7738	305	46A
0005432529156	7738	306	45K
0005434068192	7738	307	46B
0005432529127	7738	308	46E
0005432529253	7738	309	46D
0005432529187	7738	310	46H
0005435213600	7738	311	46G
0005432529193	7738	312	46J
0005432529148	7738	313	47C
0005432529176	7738	314	46K
0005434068246	7738	315	47E
0005435213701	7738	316	47D
0005432529180	7738	317	47G
0005435213607	7738	318	47F
0005434068242	7738	319	47K
0005435213662	7738	320	47H
0005435213601	7738	321	48C
0005432529225	7738	322	48A
0005434068244	7738	323	48E
0005435213626	7738	324	48D
0005434068208	7738	325	48H
0005432529164	7738	326	48G
0005432529205	7738	327	48F
0005432529184	7738	328	49A
0005435213604	7738	329	48K
0005435725606	7738	330	49D
0005432529172	7738	331	49G
0005432535879	7738	332	49F
0005432529226	7738	333	49E
0005435213779	7738	334	49K
0005435213272	7738	335	49H
0005432529204	7738	336	50C
0005432428960	7738	337	50A
0005434068255	7738	338	50E
0005435213273	7738	339	50D
0005434068198	7738	340	50H
0005432529179	7738	341	50G
0005432069788	7738	342	50F
0005432529255	7738	343	50K
0005435630969	7738	344	51F
0005432535878	7738	345	51E
0005435213624	7738	346	51D
0005435614744	5351	1	1A
0005432133348	5351	2	1C
0005435614710	5351	3	1G
0005435097294	5351	4	1K
0005435424703	5351	5	1H
0005435305018	5351	6	2C
0005432133352	5351	7	2H
0005434344561	5351	8	2G
0005435614725	5351	9	2D
0005435614731	5351	10	3A
0005435614668	5351	11	2K
0005435614690	5351	12	3G
0005435614651	5351	13	3D
0005435614625	5351	14	3C
0005435614720	5351	15	3H
0005434245109	5351	16	4C
0005435614713	5351	17	4A
0005435424710	5351	18	4G
0005434344562	5351	19	4D
0005435424898	5351	20	4K
0005435614672	5351	21	4H
0005435424863	5351	22	5C
0005435614685	5351	23	5A
0005435319601	5351	24	5H
0005434244907	5351	25	5G
0005435424858	5351	26	5D
0005434573479	5351	27	11A
0005434245018	5351	28	5K
0005435305012	5351	29	11D
0005434245024	5351	30	11C
0005435614654	5351	31	11F
0005434245027	5351	32	11E
0005435614630	5351	33	11K
0005435380310	5351	34	11H
0005434573488	5351	35	11G
0005435614648	5351	36	12C
0005435425084	5351	37	12A
0005434245110	5351	38	12E
0005435424896	5351	39	12G
0005435614716	5351	40	12F
0005435614691	5351	41	13A
0005432133349	5351	42	12K
0005435614659	5351	43	13C
0005435614700	5351	44	13F
0005434573490	5351	45	13D
0005435614626	5351	46	13H
0005435380299	5351	47	14A
0005435491458	5351	48	13K
0005435614628	5351	49	14C
0005435424972	5351	50	14F
0005435614736	5351	51	14K
0005435614677	5351	52	14G
0005432047586	5351	53	15C
0005435614675	5351	54	15A
0005432363413	5351	55	15E
0005432841013	5351	56	15D
0005435614662	5351	57	15H
0005435424776	5351	58	16A
0005435614702	5351	59	15K
0005434245082	5351	60	16D
0005435614707	5351	61	16C
0005435614730	5351	62	16F
0005435614683	5351	63	16H
0005435614645	5351	64	16G
0005435614709	5351	65	17A
0005432133353	5351	66	16K
0005435424871	5351	67	17D
0005435614689	5351	68	17C
0005434244949	5351	69	17G
0005434245033	5351	70	17F
0005433719128	5351	71	17E
0005435319599	5351	72	18A
0005435425191	5351	73	17K
0005435614657	5351	74	17H
0005435319612	5351	75	18B
0005435614688	5351	76	18D
0005435614714	5351	77	18C
0005434573487	5351	78	18G
0005435424839	5351	79	18F
0005435424897	5351	80	18J
0005434344550	5351	81	18H
0005435424865	5351	82	19A
0005435614644	5351	83	18K
0005435425024	5351	84	19D
0005434344548	5351	85	19C
0005435424930	5351	86	19B
0005432133346	5351	87	19G
0005435490260	5351	88	19F
0005435614676	5351	89	19E
0005435490262	5351	90	19H
0005435424920	5351	91	20A
0005435614693	5351	92	20C
0005434656552	5351	93	20B
0005435614655	5351	94	20E
0005434344559	5351	95	20D
0005435614729	5351	96	20G
0005434344557	5351	97	20F
0005435614636	5351	98	20J
0005434344560	5351	99	21A
0005435614742	5351	100	20K
0005435424886	5351	101	21D
0005435424724	5351	102	21C
0005435319591	5351	103	21B
0005435614694	5351	104	21E
0005435614746	5351	105	21H
0005435614718	5351	106	21G
0005435424691	5351	107	22A
0005435319611	5351	108	21K
0005435425086	5351	109	22D
0005435097299	5351	110	22C
0005434573486	5351	111	22E
0005435424723	5351	112	22H
0005434344545	5351	113	22G
0005435424980	5351	114	22K
0005435614681	5351	115	22J
0005434244917	5351	116	23C
0005435424975	5351	117	23B
0005435424778	5351	118	23G
0005435380293	5351	119	23F
0005433719144	5351	120	23J
0005435614637	5351	121	23H
0005435614719	5351	122	23K
0005433719118	5351	123	24F
0005434245040	5351	124	24E
0005435424945	5351	125	25B
0005434573483	5351	126	24G
0005435614667	5351	127	25D
0005434344539	5351	128	25C
0005435614643	5351	129	25F
0005435424982	5351	130	25H
0005432133355	5351	131	25G
0005435614632	5351	132	26A
0005434344553	5351	133	25K
0005434245097	5351	134	25J
0005434244936	5351	135	26B
0005435490263	5351	136	26E
0005435097295	5351	137	26D
0005435614678	5351	138	26C
0005435614653	5351	139	26F
0005435614661	5351	140	26K
0005435425225	5351	141	26J
0005435097291	5351	142	26H
0005435380300	5351	143	27B
0005434344538	5351	144	27A
0005435614674	5351	145	27D
0005435614724	5351	146	27C
0005434344542	5351	147	27F
0005434344565	5351	148	27G
0005434344547	5351	149	27K
0005434244989	5351	150	28B
0005435614723	5351	151	28A
0005435614705	5351	152	28E
0005435614646	5351	153	28D
0005435614670	5351	154	28G
0005434245025	5351	155	28F
0005434244909	5351	156	28J
0005435614722	5351	157	28H
0005435319572	5351	158	29A
0005434244908	5351	159	29C
0005435424864	5351	160	29B
0005434344563	5351	161	29F
0005432133347	5351	162	29E
0005434244937	5351	163	29D
0005435614638	5351	164	29J
0005434573478	5351	165	29H
0005435614715	5351	166	29G
0005432133358	5351	167	29K
0005435614696	5351	168	30C
0005435424974	5351	169	30E
0005435614673	5351	170	30D
0005434656553	5351	171	30G
0005435425173	5351	172	30K
0005434344551	5351	173	30J
0005435319600	5351	174	30H
0005434244950	5351	175	31A
0005435425125	5351	176	31D
0005435614639	5351	177	31C
0005434244967	5351	178	31B
0005434656554	5351	179	31F
0005435424955	5351	180	31E
0005435614679	5351	181	31H
0005434344566	5351	182	31G
0005435614665	5351	183	31K
0005432133357	5351	184	31J
0005434344558	5351	185	32C
0005434344536	5351	186	32B
0005435424718	5351	187	32A
0005435097293	5351	188	32E
0005435555388	5351	189	32D
0005434344564	5351	190	32G
0005435424834	5351	191	32F
0005434344549	5351	192	32J
0005432047584	5351	193	33B
0005435424978	5351	194	33A
0005435614708	5351	195	32K
0005435097290	5351	196	33D
0005435424722	5351	197	33C
0005435614642	5351	198	33F
0005435614652	5351	199	33H
0005435424857	5351	200	33G
0005435097292	5351	201	34A
0005435424762	5351	202	33K
0005435614732	5351	203	34C
0005435614728	5351	204	34B
0005435614739	5351	205	34E
0005435614686	5351	206	34D
0005435614627	5351	207	34F
0005434656557	5351	208	34K
0005432133354	5351	209	34J
0005435614640	5351	210	34H
0005435424804	5351	211	35B
0005435491457	5351	212	35A
0005432363414	5351	213	35D
0005435614745	5351	214	35G
0005435425009	5351	215	35F
0005435425008	5351	216	35E
0005434344555	5351	217	35J
0005434573484	5351	218	35H
0005435614717	5351	219	36A
0005434344552	5351	220	35K
0005432133343	5351	221	36C
0005435614658	5351	222	36B
0005435424991	5351	223	36F
0005434656555	5351	224	36D
0005435614669	5351	225	36G
0005435614647	5351	226	36K
0005435491456	5351	227	36H
0005432133350	5351	228	37B
0005435097296	5351	229	37D
0005435614650	5351	230	37C
0005435614684	5351	231	37F
0005434344554	5351	232	37E
0005435614629	5351	233	37H
0005435614711	5351	234	37G
0005435614706	5351	235	37K
0005435424709	5351	236	37J
0005435424659	5351	237	38C
0005434573485	5351	238	38A
0005434344534	5351	239	38K
0005434573482	5351	240	39B
0005434244993	5351	241	39A
0005435424943	5351	242	39D
0005435614701	5351	243	39C
0005435614741	5351	244	39E
0005432133345	5351	245	39J
0005435614660	5351	246	39H
0005435424791	5351	247	39G
0005434244996	5351	248	40A
0005435614634	5351	249	39K
0005435614712	5351	250	40C
0005434244994	5351	251	40B
0005435097298	5351	252	40D
0005434245122	5351	253	40H
0005434344556	5351	254	40G
0005435614726	5351	255	40F
0005434573491	5351	256	41B
0005435424732	5351	257	41A
0005434245043	5351	258	40K
0005434245019	5351	259	41D
0005435614649	5351	260	41C
0005435425025	5351	261	41E
0005434344544	5351	262	42A
0005435425085	5351	263	42C
0005435042853	5351	264	42B
0005434344533	5351	265	42E
0005432133356	5351	266	42D
0005434344540	5351	267	42G
0005435614743	5351	268	42F
0005434573489	5351	269	42J
0005435042852	5351	270	43B
0005435424708	5351	271	43A
0005435614734	5351	272	42K
0005435424803	5351	273	43C
0005435614735	5351	274	43F
0005435491455	5351	275	43E
0005435614682	5351	276	43G
0005434344543	5351	277	43J
0005432047585	5351	278	44C
0005434244986	5351	279	44B
0005435614664	5351	280	44A
0005435614698	5351	281	44E
0005435614671	5351	282	44D
0005434573480	5351	283	44H
0005435614680	5351	284	44G
0005435614727	5351	285	44F
0005435424882	5351	286	45B
0005434244919	5351	287	45A
0005435425189	5351	288	44K
0005435614738	5351	289	45C
0005435614663	5351	290	45F
0005434344535	5351	291	45E
0005434245046	5351	292	45J
0005435614733	5351	293	45H
0005435614737	5351	294	45G
0005434244890	5351	295	46A
0005434244990	5351	296	45K
0005435614704	5351	297	46E
0005435614687	5351	298	46C
0005435617173	5351	299	46H
0005434245047	5351	300	46G
0005435424907	5351	301	46J
0005435425329	5351	302	47A
0005435614695	5351	303	47E
0005434573477	5351	304	47D
0005434344537	5351	305	47G
0005432133344	5351	306	48A
0005435424942	5351	307	47K
0005435490261	5351	308	47H
0005435614656	5351	309	48F
0005434573481	5351	310	48E
0005434245014	5351	311	48D
0005435424997	5351	312	48H
0005434244881	5351	313	48G
0005435614697	5351	314	49A
0005434344541	5351	315	48K
0005434245035	5351	316	49D
0005435424944	5351	317	49C
0005432133351	5351	318	49F
0005434344546	5351	319	49E
0005435614666	5351	320	49H
0005435614692	5351	321	49G
0005435614635	5351	322	50C
0005435097297	5351	323	50A
0005435614703	5351	324	50E
0005434245053	5351	325	50D
0005435614740	5351	326	50H
0005435614631	5351	327	50G
0005435614633	5351	328	50F
0005435614699	5351	329	51D
0005435614721	5351	330	51F
0005435614641	5351	331	51E
0005435424725	5351	332	51G
0005434344032	10932	1	1C
0005435097182	10932	2	1G
0005435613572	10932	3	1D
0005435425452	10932	4	2A
0005435613609	10932	5	1K
0005435319653	10932	6	1H
0005435425432	10932	7	2D
0005435613119	10932	8	2C
0005435305030	10932	9	2H
0005432165107	10932	10	2G
0005435613929	10932	11	3A
0005435614085	10932	12	2K
0005435613649	10932	13	3D
0005434344204	10932	14	3K
0005435613734	10932	15	3H
0005435042875	10932	16	3G
0005435614167	10932	17	4C
0005434344195	10932	18	4A
0005435425464	10932	19	4H
0005432165111	10932	20	4G
0005435613459	10932	21	4D
0005435613559	10932	22	5A
0005434656575	10932	23	4K
0005435614159	10932	24	5C
0005434245250	10932	25	5H
0005434245249	10932	26	5D
0005434344230	10932	27	11A
0005435491436	10932	28	5K
0005435425460	10932	29	11D
0005432166931	10932	30	11C
0005434573330	10932	31	11E
0005435613482	10932	32	11K
0005435613655	10932	33	11H
0005435097254	10932	34	11G
0005434344201	10932	35	12A
0005435425448	10932	36	12G
0005435425447	10932	37	12F
0005435613623	10932	38	12K
0005432165110	10932	39	13D
0005435425422	10932	40	13C
0005435613302	10932	41	13A
0005435380333	10932	42	13F
0005435425410	10932	43	13E
0005435097192	10932	44	13G
0005435425449	10932	45	14C
0005435097206	10932	46	14A
0005434245241	10932	47	13K
0005432166930	10932	48	14E
0005435304195	10932	49	14D
0005435425473	10932	50	14G
0005435425429	10932	51	14F
0005432166932	10932	52	14K
0005434245251	10932	53	15C
0005435425416	10932	54	15A
0005435097167	10932	55	15E
0005434573389	10932	56	15G
0005435097193	10932	57	15F
0005435425471	10932	58	16A
0005435613583	10932	59	15K
0005435425427	10932	60	15H
0005434343998	10932	61	16D
0005434344145	10932	62	16C
0005435425408	10932	63	16H
0005435613987	10932	64	16G
0005435613120	10932	65	17C
0005435613903	10932	66	17A
0005435097207	10932	67	16K
0005435425454	10932	68	17G
0005435613376	10932	69	17F
0005435613683	10932	70	18A
0005435613928	10932	71	17H
0005434245242	10932	72	18B
0005435613686	10932	73	18E
0005435613744	10932	74	18D
0005435614132	10932	75	18G
0005435613674	10932	76	18F
0005435425462	10932	77	18H
0005435613866	10932	78	19B
0005435319654	10932	79	19A
0005435613811	10932	80	18K
0005432165108	10932	81	19D
0005435614048	10932	82	19C
0005435613801	10932	83	19F
0005434344232	10932	84	19E
0005435425478	10932	85	19H
0005435304193	10932	86	20A
0005434344289	10932	87	19K
0005435613657	10932	88	20C
0005435555372	10932	89	20B
0005434245245	10932	90	20E
0005435425440	10932	91	20D
0005435097169	10932	92	20H
0005435425467	10932	93	20G
0005435097238	10932	94	20F
0005435425468	10932	95	20J
0005435425474	10932	96	21B
0005435097222	10932	97	21A
0005435613762	10932	98	20K
0005435425417	10932	99	21D
0005435613939	10932	100	21C
0005435613675	10932	101	21G
0005435425450	10932	102	21E
0005435614138	10932	103	21J
0005435425443	10932	104	21H
0005435613304	10932	105	21K
0005434344229	10932	106	22D
0005435613999	10932	107	22C
0005435425421	10932	108	22B
0005435613656	10932	109	22F
0005434344171	10932	110	22H
0005434344139	10932	111	22G
0005435097178	10932	112	22K
0005434245239	10932	113	22J
0005435613769	10932	114	23B
0005435319651	10932	115	23A
0005435613697	10932	116	23E
0005435613633	10932	117	23C
0005435613584	10932	118	23F
0005434344192	10932	119	23H
0005435613712	10932	120	23G
0005434344149	10932	121	24D
0005435319656	10932	122	23K
0005434344206	10932	123	23J
0005434573342	10932	124	24E
0005435425409	10932	125	25A
0005435613461	10932	126	25D
0005435425434	10932	127	25C
0005434245258	10932	128	25B
0005434245244	10932	129	25F
0005435425457	10932	130	25E
0005434245238	10932	131	25H
0005435614051	10932	132	25G
0005435425435	10932	133	26A
0005434344200	10932	134	25K
0005435614062	10932	135	25J
0005435425475	10932	136	26C
0005435425459	10932	137	26B
0005435613923	10932	138	26E
0005435613550	10932	139	26D
0005434344202	10932	140	26F
0005434344140	10932	141	26J
0005435425442	10932	142	26H
0005435613616	10932	143	27A
0005435613930	10932	144	27D
0005435613733	10932	145	27C
0005433719174	10932	146	27F
0005435613839	10932	147	27E
0005435305031	10932	148	27G
0005432841033	10932	149	28A
0005435319650	10932	150	27K
0005433719175	10932	151	27J
0005435425465	10932	152	28B
0005435613321	10932	153	28E
0005435613567	10932	154	28D
0005434344231	10932	155	28F
0005435380328	10932	156	28J
0005435425411	10932	157	28H
0005434344082	10932	158	29A
0005435425476	10932	159	28K
0005435425436	10932	160	29D
0005435613544	10932	161	29C
0005435613613	10932	162	29F
0005434245266	10932	163	29E
0005435425414	10932	164	29H
0005435613687	10932	165	29G
0005435425426	10932	166	30A
0005435425424	10932	167	29K
0005435380329	10932	168	30B
0005435612835	10932	169	30E
0005432165109	10932	170	30D
0005435425455	10932	171	30C
0005435613859	10932	172	30G
0005435613325	10932	173	30F
0005435613810	10932	174	30K
0005435613867	10932	175	31B
0005435613833	10932	176	31A
0005435097221	10932	177	31D
0005435613622	10932	178	31C
0005435614061	10932	179	31F
0005434344126	10932	180	31E
0005435425433	10932	181	31H
0005434245257	10932	182	31G
0005435425418	10932	183	31K
0005435612927	10932	184	31J
0005432363447	10932	185	32C
0005435425425	10932	186	32B
0005435425431	10932	187	32A
0005435614063	10932	188	32E
0005434344129	10932	189	32G
0005435613326	10932	190	32F
0005435613858	10932	191	32K
0005435614106	10932	192	32J
0005434245254	10932	193	32H
0005435425470	10932	194	33B
0005435425415	10932	195	33D
0005435613886	10932	196	33C
0005435613545	10932	197	33F
0005435425412	10932	198	33E
0005435304196	10932	199	33J
0005435613820	10932	200	33H
0005435097181	10932	201	33K
0005434344083	10932	202	34C
0005434344172	10932	203	34B
0005434245253	10932	204	34A
0005435613608	10932	205	34E
0005435614050	10932	206	34D
0005435614049	10932	207	34G
0005435612925	10932	208	34K
0005434245243	10932	209	34J
0005435613560	10932	210	34H
0005433719172	10932	211	35B
0005435319658	10932	212	35A
0005434344164	10932	213	35D
0005435613524	10932	214	35C
0005435425423	10932	215	35G
0005435613877	10932	216	35J
0005435042877	10932	217	36A
0005435380330	10932	218	35K
0005435613628	10932	219	36C
0005434245260	10932	220	36B
0005435425466	10932	221	36D
0005435613431	10932	222	36G
0005435425477	10932	223	36F
0005434343920	10932	224	36K
0005435425458	10932	225	36J
0005435319657	10932	226	36H
0005432363446	10932	227	37B
0005435380332	10932	228	37A
0005435614105	10932	229	37F
0005435614306	10932	230	37E
0005435613358	10932	231	37J
0005435613856	10932	232	37H
0005435097175	10932	233	37G
0005434245247	10932	234	38A
0005435425469	10932	235	37K
0005434245240	10932	236	38B
0005435425420	10932	237	38J
0005435614084	10932	238	38H
0005435304194	10932	239	39A
0005435614086	10932	240	39D
0005435425453	10932	241	39G
0005434344128	10932	242	39F
0005432363445	10932	243	39E
0005432841032	10932	244	39H
0005434245262	10932	245	40A
0005435613711	10932	246	39K
0005435042878	10932	247	39J
0005435425437	10932	248	40C
0005435613137	10932	249	40B
0005435613318	10932	250	40E
0005434344105	10932	251	40D
0005435097174	10932	252	40G
0005435425445	10932	253	40F
0005434245263	10932	254	40K
0005435425463	10932	255	40J
0005434344207	10932	256	40H
0005435613359	10932	257	41B
0005435613768	10932	258	41A
0005435613577	10932	259	41C
0005435613808	10932	260	41G
0005435613709	10932	261	41F
0005435613612	10932	262	41E
0005435613857	10932	263	41H
0005434344191	10932	264	42A
0005434245265	10932	265	42C
0005434245261	10932	266	42B
0005434245256	10932	267	42E
0005435613910	10932	268	42D
0005435042876	10932	269	42G
0005435614046	10932	270	42F
0005435305029	10932	271	42H
0005434344033	10932	272	43B
0005435380331	10932	273	42K
0005434245255	10932	274	43E
0005435319655	10932	275	43D
0005435425451	10932	276	43G
0005435319659	10932	277	44A
0005435613806	10932	278	43K
0005435425441	10932	279	43J
0005432363448	10932	280	44C
0005435613121	10932	281	44B
0005435097168	10932	282	44D
0005435613408	10932	283	44G
0005435613707	10932	284	44F
0005435425419	10932	285	44J
0005435613494	10932	286	45B
0005434245248	10932	287	45F
0005435305028	10932	288	45E
0005435613389	10932	289	45D
0005435425439	10932	290	45H
0005435425444	10932	291	45G
0005434245252	10932	292	45K
0005434245259	10932	293	46B
0005435613301	10932	294	46A
0005435425438	10932	295	46E
0005435613411	10932	296	46D
0005433719173	10932	297	46C
0005434573331	10932	298	46G
0005434344308	10932	299	46F
0005435613390	10932	300	46J
0005435613971	10932	301	47A
0005434573348	10932	302	47E
0005434344177	10932	303	47D
0005435425461	10932	304	47C
0005434573210	10932	305	47K
0005435425456	10932	306	47H
0005435613409	10932	307	48C
0005435425428	10932	308	48E
0005435613708	10932	309	48D
0005434344106	10932	310	49A
0005435491447	10932	311	48K
0005434245264	10932	312	49E
0005435613807	10932	313	49D
0005435425413	10932	314	49C
0005435304197	10932	315	49G
0005435614004	10932	316	49F
0005435613610	10932	317	49K
0005434573366	10932	318	50C
0005435425430	10932	319	50A
0005435613343	10932	320	50E
0005434344266	10932	321	50D
0005435612834	10932	322	50H
0005435425446	10932	323	50G
0005435613800	10932	324	50F
0005434573365	10932	325	51D
0005435319652	10932	326	50K
0005435425472	10932	327	51F
0005434245246	10932	328	51G
0005432181923	3225	1	1A
0005433507347	3225	2	1D
0005433507353	3225	3	1C
0005433805688	3225	4	2A
0005433805687	3225	5	1F
0005432181920	3225	6	2C
0005433634122	3225	7	2D
0005432459700	3225	8	2F
0005432460037	3225	9	3C
0005433805692	3225	10	3A
0005432459823	3225	11	3F
0005433507349	3225	12	3D
0005432181929	3225	13	4A
0005432459818	3225	14	4D
0005433507341	3225	15	4C
0005432460010	3225	16	4F
0005432459817	3225	17	5A
0005433634120	3225	18	5C
0005433634121	3225	19	5F
0005432459796	3225	20	5D
0005432459846	3225	21	6A
0005433805707	3225	22	6C
0005433634144	3225	23	7A
0005432459879	3225	24	6F
0005432460164	3225	25	7C
0005433634153	3225	26	7D
0005432459749	3225	27	8A
0005432459682	3225	28	7F
0005433634149	3225	29	8C
0005432459758	3225	30	8E
0005432460009	3225	31	8D
0005433507342	3225	32	9A
0005433634147	3225	33	8F
0005432181919	3225	34	9B
0005433507352	3225	35	9C
0005432459950	3225	36	9D
0005432460000	3225	37	9F
0005432459767	3225	38	10A
0005433634146	3225	39	10C
0005432459880	3225	40	10B
0005433634131	3225	41	10D
0005432459797	3225	42	10F
0005432181927	3225	43	11A
0005432459892	3225	44	11C
0005432459918	3225	45	11B
0005432459819	3225	46	11E
0005433634137	3225	47	11D
0005433805701	3225	48	11F
0005432459798	3225	49	12A
0005433634132	3225	50	12B
0005433805685	3225	51	12C
0005433805712	3225	52	12D
0005433634152	3225	53	12F
0005433805691	3225	54	12E
0005432459968	3225	55	13B
0005432181926	3225	56	13A
0005432459848	3225	57	13C
0005433805715	3225	58	13D
0005433805699	3225	59	13E
0005433805696	3225	60	14A
0005432459829	3225	61	13F
0005432459987	3225	62	14B
0005433805716	3225	63	14C
0005433507346	3225	64	14E
0005432459993	3225	65	14D
0005432181917	3225	66	14F
0005432459893	3225	67	15A
0005433507351	3225	68	15C
0005432459876	3225	69	15B
0005432181932	3225	70	15E
0005433634136	3225	71	15D
0005433805698	3225	72	16A
0005432459881	3225	73	15F
0005432181931	3225	74	16B
0005432181930	3225	75	16D
0005432459747	3225	76	16E
0005432459877	3225	77	16F
0005433634126	3225	78	17B
0005433805697	3225	79	17A
0005433634151	3225	80	17C
0005433634138	3225	81	17E
0005433634133	3225	82	17D
0005433634143	3225	83	17F
0005432460011	3225	84	18A
0005433805713	3225	85	18B
0005433507355	3225	86	18C
0005433634130	3225	87	18E
0005432460028	3225	88	18D
0005433634129	3225	89	19B
0005433634128	3225	90	18F
0005433507343	3225	91	19D
0005433634140	3225	92	19C
0005433634135	3225	93	20A
0005432459999	3225	94	19E
0005433507345	3225	95	20B
0005433805714	3225	96	20C
0005432181934	3225	97	20F
0005432181914	3225	98	20E
0005433805703	3225	99	21A
0005433634139	3225	100	21B
0005433507344	3225	101	21D
0005432459949	3225	102	21C
0005433507350	3225	103	21E
0005432459887	3225	104	21F
0005432459912	3225	105	22B
0005433634124	3225	106	22A
0005433507356	3225	107	22C
0005432459789	3225	108	22D
0005433805689	3225	109	22F
0005433805693	3225	110	22E
0005432181921	3225	111	23B
0005432459649	3225	112	23A
0005432181918	3225	113	23C
0005433634154	3225	114	23D
0005433805695	3225	115	23F
0005433805717	3225	116	23E
0005433805700	3225	117	24C
0005432459746	3225	118	24B
0005433634127	3225	119	24A
0005433634134	3225	120	24D
0005433507354	3225	121	24E
0005432460087	3225	122	24F
0005433805711	3225	123	25A
0005433634141	3225	124	25C
0005432459903	3225	125	25B
0005433634125	3225	126	25D
0005432459773	3225	127	25E
0005433634148	3225	128	25F
0005432459822	3225	129	26B
0005432181922	3225	130	26A
0005432181915	3225	131	26C
0005433805705	3225	132	26E
0005433634150	3225	133	26D
0005433634145	3225	134	26F
0005432459704	3225	135	27B
0005433805690	3225	136	27A
0005433805694	3225	137	27C
0005432459768	3225	138	27D
0005432460038	3225	139	27F
0005432181928	3225	140	27E
0005432459849	3225	141	28B
0005433805709	3225	142	28A
0005432459719	3225	143	28D
0005433634142	3225	144	28F
0005432459913	3225	145	28E
0005432459904	3225	146	29A
0005433805708	3225	147	29C
0005432181925	3225	148	29B
0005432181924	3225	149	29D
0005433634123	3225	150	29E
0005432181933	3225	151	30A
0005433805706	3225	152	29F
0005433507348	3225	153	30B
0005433805710	3225	154	30C
0005432459756	3225	155	30E
0005432181913	3225	156	30D
0005433805686	3225	157	30F
0005432459847	3225	158	31A
0005432181916	3225	159	31C
0005433805704	3225	160	31B
0005433805702	3225	161	31E
0005432459650	3225	162	31D
0005432459948	3225	163	31F
0005435885277	3224	1	1D
0005435885138	3224	2	1F
0005435885398	3224	3	4D
0005435885479	3224	4	5C
0005435885258	3224	5	5D
0005435885105	3224	6	5F
0005435885144	3224	7	7F
0005435885526	3224	8	8E
0005435885344	3224	9	9C
0005435885356	3224	10	10C
0005435885520	3224	11	10E
0005435885331	3224	12	11A
0005435885309	3224	13	11E
0005435885439	3224	14	12D
0005435885418	3224	15	12F
0005435885136	3224	16	13B
0005435885417	3224	17	13D
0005435885323	3224	18	13E
0005435885512	3224	19	14A
0005435885440	3224	20	13F
0005435885432	3224	21	14F
0005435885273	3224	22	15A
0005435885355	3224	23	15F
0005435885552	3224	24	16E
0005435885308	3224	25	17F
0005435885226	3224	26	18C
0005435885298	3224	27	18D
0005435885369	3224	28	18F
0005435885345	3224	29	19C
0005435885237	3224	30	20A
0005435885225	3224	31	21C
0005435885431	3224	32	21E
0005435885143	3224	33	22B
0005435885239	3224	34	22A
0005435885433	3224	35	22D
0005435885330	3224	36	23D
0005435885416	3224	37	24D
0005435885524	3224	38	24F
0005435885441	3224	39	25E
0005435885368	3224	40	25F
0005435885400	3224	41	26A
0005435885415	3224	42	26D
0005435885461	3224	43	26F
0005435885480	3224	44	28A
0005435885223	3224	45	28B
0005435885227	3224	46	28C
0005435885137	3224	47	28E
0005435885367	3224	48	29C
0005435885420	3224	49	30B
0005435885257	3224	50	30D
0005435885215	3224	51	31C
0005435885274	3224	52	31E
0005432460376	8198	1	1A
0005432042850	8198	2	1D
0005432460346	8198	3	1C
0005433507215	8198	4	1F
0005434326276	8198	5	2A
0005432460397	8198	6	2C
0005435885689	8198	7	2D
0005435885686	8198	8	2F
0005435885703	8198	9	3D
0005432460380	8198	10	3C
0005432460371	8198	11	3F
0005435885695	8198	12	4A
0005432460393	8198	13	4C
0005435885716	8198	14	4F
0005432042839	8198	15	4D
0005432460387	8198	16	5A
0005433507186	8198	17	5C
0005432460364	8198	18	6A
0005432460363	8198	19	5F
0005432460356	8198	20	6F
0005432042842	8198	21	6D
0005435885724	8198	22	7A
0005435885701	8198	23	7C
0005435885721	8198	24	7D
0005435885744	8198	25	8A
0005435885713	8198	26	7F
0005435885706	8198	27	8B
0005435885730	8198	28	8C
0005434312340	8198	29	8E
0005432460357	8198	30	8F
0005435885731	8198	31	9A
0005435885696	8198	32	9C
0005432460368	8198	33	9B
0005432460385	8198	34	9D
0005433507149	8198	35	9F
0005433507203	8198	36	10A
0005435885691	8198	37	10C
0005435885692	8198	38	10B
0005435885714	8198	39	10D
0005435885718	8198	40	10F
0005433507166	8198	41	11C
0005433507182	8198	42	11B
0005432460369	8198	43	11E
0005435885735	8198	44	11D
0005435885728	8198	45	12A
0005435885705	8198	46	12C
0005432460349	8198	47	12D
0005435885717	8198	48	12E
0005435885740	8198	49	12F
0005435885732	8198	50	13A
0005435885742	8198	51	13C
0005432460384	8198	52	13E
0005435885722	8198	53	14A
0005432460390	8198	54	13F
0005435885707	8198	55	14E
0005432042845	8198	56	14D
0005432460382	8198	57	15A
0005435885702	8198	58	15B
0005432460367	8198	59	15D
0005435885710	8198	60	15F
0005433507133	8198	61	15E
0005435885699	8198	62	16C
0005432460378	8198	63	16B
0005435885697	8198	64	16D
0005434326277	8198	65	16E
0005432460347	8198	66	17A
0005435885743	8198	67	16F
0005432460375	8198	68	17B
0005432042838	8198	69	17E
0005432042843	8198	70	17D
0005435885726	8198	71	17F
0005435885725	8198	72	18A
0005432460355	8198	73	18B
0005435885698	8198	74	18D
0005435885729	8198	75	18E
0005435885739	8198	76	18F
0005432460351	8198	77	19B
0005435885704	8198	78	19D
0005433507174	8198	79	19C
0005432460372	8198	80	20A
0005435885719	8198	81	19E
0005432042844	8198	82	20B
0005432460392	8198	83	20D
0005435885693	8198	84	20C
0005432460389	8198	85	20F
0005432460377	8198	86	20E
0005432042841	8198	87	21B
0005432460366	8198	88	21A
0005432460398	8198	89	21C
0005432042851	8198	90	21D
0005435885720	8198	91	21F
0005432460383	8198	92	21E
0005432460373	8198	93	22B
0005432042840	8198	94	22A
0005435885715	8198	95	22D
0005432460381	8198	96	22C
0005435885694	8198	97	22F
0005435885712	8198	98	23A
0005435885741	8198	99	23B
0005435885700	8198	100	23D
0005435885738	8198	101	23F
0005434326275	8198	102	24B
0005432460370	8198	103	24A
0005432042848	8198	104	24C
0005432460391	8198	105	24F
0005432460354	8198	106	24E
0005432042846	8198	107	25B
0005432460362	8198	108	25A
0005435885708	8198	109	25C
0005432460350	8198	110	25D
0005432460360	8198	111	25E
0005435885711	8198	112	26A
0005432460396	8198	113	25F
0005433507212	8198	114	26B
0005435885709	8198	115	26D
0005435885727	8198	116	26E
0005435885734	8198	117	26F
0005432460359	8198	118	27A
0005432460352	8198	119	27D
0005432460388	8198	120	27C
0005432460379	8198	121	27E
0005432460348	8198	122	28A
0005435885688	8198	123	27F
0005435885737	8198	124	28B
0005435885687	8198	125	28D
0005432460395	8198	126	28C
0005432460386	8198	127	28E
0005433507216	8198	128	29A
0005432460358	8198	129	29C
0005432460394	8198	130	29D
0005435885690	8198	131	29F
0005435885736	8198	132	29E
0005432042847	8198	133	30B
0005432042849	8198	134	30D
0005435885723	8198	135	30F
0005435885733	8198	136	31B
0005433507183	8198	137	31A
0005432460353	8198	138	31C
0005432460361	8198	139	31D
0005432460365	8198	140	31E
0005432460374	8198	141	31F
0005433805355	8199	1	1C
0005433805408	8199	2	1D
0005433805466	8199	3	1F
0005434271312	8199	4	3A
0005433633795	8199	5	3D
0005433633693	8199	6	4A
0005433805405	8199	7	4D
0005433633885	8199	8	7D
0005433805315	8199	9	8B
0005433805395	8199	10	8C
0005433805422	8199	11	8D
0005433805413	8199	12	9B
0005433633573	8199	13	9D
0005433633862	8199	14	9F
0005434271323	8199	15	10C
0005433805453	8199	16	10B
0005433633835	8199	17	10E
0005433633877	8199	18	11A
0005433633869	8199	19	11C
0005433633692	8199	20	11D
0005433805469	8199	21	11E
0005433633572	8199	22	12B
0005435854063	8199	23	12D
0005433633920	8199	24	12C
0005433805467	8199	25	12F
0005433805350	8199	26	13A
0005433805394	8199	27	13F
0005433805257	8199	28	13E
0005433633674	8199	29	14A
0005433805333	8199	30	14B
0005433633710	8199	31	14E
0005433805317	8199	32	14F
0005433633873	8199	33	15A
0005433633711	8199	34	16A
0005433633874	8199	35	15F
0005433633830	8199	36	16D
0005433633870	8199	37	16F
0005433805291	8199	38	17B
0005433633900	8199	39	17A
0005433805454	8199	40	18A
0005433633728	8199	41	17F
0005433805268	8199	42	18D
0005433805490	8199	43	18F
0005433805409	8199	44	19D
0005433633863	8199	45	19C
0005433633840	8199	46	20C
0005433633785	8199	47	20E
0005433805299	8199	48	20F
0005433805292	8199	49	21C
0005433633737	8199	50	21B
0005433633786	8199	51	21D
0005433633881	8199	52	21F
0005433633748	8199	53	22D
0005433805341	8199	54	22E
0005433805396	8199	55	23D
0005433805431	8199	56	23E
0005433633834	8199	57	23F
0005433805369	8199	58	24E
0005433805403	8199	59	24D
0005434271311	8199	60	25F
0005433633770	8199	61	25E
0005433633729	8199	62	26B
0005433805417	8199	63	26C
0005433805285	8199	64	26F
0005433805503	8199	65	27B
0005433805334	8199	66	27D
0005433633897	8199	67	27F
0005433633814	8199	68	28B
0005433805374	8199	69	28D
0005433805349	8199	70	30E
0005433805404	8199	71	31F
0005433454896	4557	1	1A
0005432728059	4557	2	1C
0005432383569	4557	3	1D
0005433194884	4557	4	1F
0005432383541	4557	5	2A
0005433453777	4557	6	2C
0005432383540	4557	7	2F
0005433722282	4557	8	3A
0005432383539	4557	9	3D
0005433453778	4557	10	4A
0005433194883	4557	11	4D
0005432383563	4557	12	4E
0005432728061	4557	13	4F
0005432383556	4557	14	5A
0005433194881	4557	15	5C
0005432383538	4557	16	5D
0005433194886	4557	17	5E
0005432728051	4557	18	6A
0005432728056	4557	19	6C
0005433194882	4557	20	6D
0005432383543	4557	21	6F
0005433453779	4557	22	7C
0005432728054	4557	23	7D
0005432383568	4557	24	7E
0005433454897	4557	25	8A
0005432383547	4557	26	8C
0005432383537	4557	27	8D
0005433194887	4557	28	8F
0005432383535	4557	29	9A
0005432383570	4557	30	9C
0005432728053	4557	31	9D
0005432728057	4557	32	10D
0005432383533	4557	33	10E
0005432383557	4557	34	10F
0005432383551	4557	35	11A
0005432383536	4557	36	11C
0005432383562	4557	37	11D
0005432383555	4557	38	11E
0005432383564	4557	39	11F
0005432728052	4557	40	12D
0005432383565	4557	41	12E
0005433194879	4557	42	12F
0005433194885	4557	43	13A
0005432728060	4557	44	13C
0005432728049	4557	45	13D
0005432383544	4557	46	13E
0005433454895	4557	47	14A
0005432383550	4557	48	14C
0005432383542	4557	49	14D
0005432383559	4557	50	14E
0005432383546	4557	51	15D
0005433194880	4557	52	15E
0005433722283	4557	53	16A
0005432383545	4557	54	16E
0005432383548	4557	55	16F
0005432383566	4557	56	17C
0005432728058	4557	57	17D
0005433194877	4557	58	17E
0005432383558	4557	59	17F
0005432728050	4557	60	18A
0005433194878	4557	61	18E
0005432383561	4557	62	18F
0005432383553	4557	63	19A
0005432383534	4557	64	19C
0005432383554	4557	65	19F
0005432383549	4557	66	20A
0005432728055	4557	67	20C
0005432383552	4557	68	20D
0005432383560	4557	69	20E
0005432383567	4557	70	20F
0005432383061	30237	1	1A
0005433722202	30237	2	1C
0005432383125	30237	3	2A
0005433722215	30237	4	2C
0005432383185	30237	5	2F
0005433722216	30237	6	3C
0005433451618	30237	7	4A
0005432383127	30237	8	4C
0005433451621	30237	9	4D
0005432383222	30237	10	4E
0005433194852	30237	11	5A
0005432383128	30237	12	5E
0005432383105	30237	13	6A
0005432383050	30237	14	6C
0005432383077	30237	15	6D
0005432727975	30237	16	6E
0005432727929	30237	17	7A
0005432383059	30237	18	7C
0005432383110	30237	19	8D
0005433722211	30237	20	9A
0005432383012	30237	21	9F
0005432383223	30237	22	10C
0005432383058	30237	23	10D
0005432727961	30237	24	10E
0005432383130	30237	25	11A
0005432383213	30237	26	12A
0005432383057	30237	27	12C
0005432382944	30237	28	12D
0005433722212	30237	29	12F
0005432383069	30237	30	13C
0005432383180	30237	31	13D
0005433722201	30237	32	13E
0005433453756	30237	33	13F
0005432383186	30237	34	14C
0005432383245	30237	35	14E
0005432383089	30237	36	14F
0005433453761	30237	37	15A
0005433453757	30237	38	15C
0005432383111	30237	39	15D
0005432383034	30237	40	15E
0005432383070	30237	41	16C
0005432383224	30237	42	16D
0005432383062	30237	43	16E
0005432383071	30237	44	16F
0005432383102	30237	45	17C
0005432383194	30237	46	17E
0005432383103	30237	47	18A
0005432383126	30237	48	18C
0005432383159	30237	49	18D
0005432382928	30237	50	18E
0005432383104	30237	51	18F
0005432383003	30237	52	19A
0005432727960	30237	53	19C
0005432383199	30237	54	19D
0005433453755	30237	55	19E
0005432382979	30237	56	20C
0005433722194	30237	57	20D
0005432727928	30237	58	20E
0005435529457	1712	1	1D
0005435541203	1712	2	1F
0005435529463	1712	3	2A
0005435529458	1712	4	2C
0005435541212	1712	5	3A
0005435541209	1712	6	3D
0005435529466	1712	7	3F
0005435541199	1712	8	4F
0005435529475	1712	9	5A
0005435541221	1712	10	5C
0005432294510	1712	11	5D
0005435541215	1712	12	5E
0005433516973	1712	13	6C
0005435529465	1712	14	6D
0005435529468	1712	15	6E
0005435541211	1712	16	7C
0005433516974	1712	17	7D
0005435529474	1712	18	7F
0005432294509	1712	19	8A
0005435541206	1712	20	8D
0005433516978	1712	21	8E
0005435541200	1712	22	9A
0005433516971	1712	23	9C
0005435541219	1712	24	9D
0005435529461	1712	25	9E
0005435541202	1712	26	10D
0005435541214	1712	27	10E
0005433516970	1712	28	11A
0005433516976	1712	29	11C
0005433516972	1712	30	11F
0005435529464	1712	31	12E
0005435541220	1712	32	13A
0005435529467	1712	33	13C
0005435529471	1712	34	13E
0005435529459	1712	35	13F
0005435529460	1712	36	14A
0005435541207	1712	37	14F
0005432925042	1712	38	15C
0005435541216	1712	39	15E
0005435529462	1712	40	15F
0005435529473	1712	41	16C
0005435541204	1712	42	16D
0005435541217	1712	43	17A
0005435529476	1712	44	17C
0005435529469	1712	45	17D
0005435529456	1712	46	17F
0005435541213	1712	47	18A
0005433516977	1712	48	18C
0005435529470	1712	49	18D
0005435541210	1712	50	18E
0005435529472	1712	51	18F
0005432925043	1712	52	19A
0005433516975	1712	53	19C
0005435541218	1712	54	19D
0005435541201	1712	55	19F
0005435541205	1712	56	20A
0005435541208	1712	57	20F
0005435541042	22028	1	1A
0005435517888	22028	2	1C
0005433516911	22028	3	1D
0005435540912	22028	4	1F
0005435517887	22028	5	2A
0005435517886	22028	6	2C
0005435541011	22028	7	2F
0005435540927	22028	8	3A
0005435517876	22028	9	3F
0005435517927	22028	10	4C
0005433516868	22028	11	4D
0005435517885	22028	12	5A
0005435541022	22028	13	5C
0005433516855	22028	14	5D
0005435540867	22028	15	5E
0005435517855	22028	16	6A
0005435517958	22028	17	6C
0005435541036	22028	18	6D
0005435541072	22028	19	6F
0005435541020	22028	20	7A
0005432925081	22028	21	7D
0005435517905	22028	22	7E
0005435517950	22028	23	7F
0005435517790	22028	24	8E
0005433516872	22028	25	8F
0005433516906	22028	26	9A
0005435517872	22028	27	9C
0005433516910	22028	28	9D
0005435517902	22028	29	9F
0005435540925	22028	30	10A
0005435540979	22028	31	10C
0005435541102	22028	32	10D
0005435541021	22028	33	10F
0005435540911	22028	34	11D
0005435540994	22028	35	11E
0005435517942	22028	36	12F
0005435517949	22028	37	13C
0005432925083	22028	38	13E
0005435540924	22028	39	13F
0005435540913	22028	40	14C
0005435517937	22028	41	14E
0005435541005	22028	42	15A
0005435517884	22028	43	15C
0005435541135	22028	44	15D
0005435517948	22028	45	15E
0005435517926	22028	46	15F
0005435517791	22028	47	16C
0005435517883	22028	48	16D
0005435541035	22028	49	16E
0005432925080	22028	50	16F
0005435541003	22028	51	18C
0005432925082	22028	52	19A
0005435540995	22028	53	19C
0005435540926	22028	54	19D
0005433516907	22028	55	19F
0005435541077	22028	56	20C
0005435540968	22028	57	20D
0005435517868	22028	58	20F
0005432839329	7351	1	1D
0005432839324	7351	2	1F
0005432839320	7351	3	2C
0005432839317	7351	4	2D
0005432839308	7351	5	2F
0005434459005	7351	6	3A
0005434458992	7351	7	3C
0005432839312	7351	8	3D
0005435252702	7351	9	3F
0005435252723	7351	10	4C
0005432839322	7351	11	4D
0005434458997	7351	12	4E
0005434459009	7351	13	4F
0005434459007	7351	14	5A
0005432839334	7351	15	5C
0005435252718	7351	16	5D
0005434459000	7351	17	5E
0005435491440	7351	18	5F
0005432839318	7351	19	6A
0005435252666	7351	20	6D
0005434459003	7351	21	6E
0005435252704	7351	22	6F
0005435252691	7351	23	7A
0005432839335	7351	24	7C
0005432839326	7351	25	7D
0005432839328	7351	26	7E
0005432839310	7351	27	7F
0005432839331	7351	28	8A
0005434459004	7351	29	8C
0005432073421	7351	30	8D
0005435252736	7351	31	8F
0005432839332	7351	32	9A
0005432839339	7351	33	9C
0005432839330	7351	34	9D
0005435252684	7351	35	9E
0005434664952	7351	36	9F
0005432841031	7351	37	10A
0005432839325	7351	38	10C
0005434458995	7351	39	10D
0005432839321	7351	40	10E
0005434458993	7351	41	10F
0005434458990	7351	42	11D
0005434458991	7351	43	11E
0005434458998	7351	44	11F
0005432839336	7351	45	12A
0005435252739	7351	46	12C
0005432839319	7351	47	12D
0005432839333	7351	48	12F
0005432823467	7351	49	13A
0005432839314	7351	50	13C
0005435252731	7351	51	13D
0005435252680	7351	52	13E
0005432073423	7351	53	13F
0005432839311	7351	54	14A
0005432839327	7351	55	14C
0005432073424	7351	56	14D
0005432073425	7351	57	14E
0005434458996	7351	58	14F
0005435252713	7351	59	15A
0005434459006	7351	60	15D
0005435491442	7351	61	15E
0005435252734	7351	62	15F
0005432073422	7351	63	16C
0005435252743	7351	64	16D
0005432839309	7351	65	16E
0005435252735	7351	66	16F
0005434459002	7351	67	17A
0005432839316	7351	68	17C
0005434459001	7351	69	17D
0005432839315	7351	70	17E
0005432839323	7351	71	17F
0005435252712	7351	72	18A
0005435252744	7351	73	18C
0005434458994	7351	74	18D
0005432839337	7351	75	18E
0005435491441	7351	76	18F
0005434459008	7351	77	19C
0005434458988	7351	78	19E
0005432839313	7351	79	19F
0005434458999	7351	80	20A
0005432839338	7351	81	20C
0005435252742	7351	82	20D
0005434458989	7351	83	20E
0005434458987	7351	84	20F
0005432839114	28893	1	1A
0005432839021	28893	2	1C
0005434458801	28893	3	1D
0005434458825	28893	4	1F
0005434458747	28893	5	2A
0005435252871	28893	6	2C
0005434458845	28893	7	2D
0005435252857	28893	8	2F
0005434458834	28893	9	3A
0005435252856	28893	10	3C
0005432823453	28893	11	3D
0005432839018	28893	12	4A
0005435252873	28893	13	4C
0005432839083	28893	14	4D
0005432823455	28893	15	4E
0005432838941	28893	16	4F
0005432839192	28893	17	5A
0005435252861	28893	18	5C
0005434458751	28893	19	5D
0005432839261	28893	20	5E
0005434458787	28893	21	5F
0005432839065	28893	22	6A
0005432839066	28893	23	6C
0005432001042	28893	24	6E
0005432838942	28893	25	6F
0005434458859	28893	26	7A
0005432839023	28893	27	7C
0005434458748	28893	28	7D
0005434458799	28893	29	7E
0005434458750	28893	30	7F
0005435252864	28893	31	8A
0005432839024	28893	32	8C
0005432823454	28893	33	8E
0005435252870	28893	34	8F
0005434664982	28893	35	9A
0005432839171	28893	36	9D
0005432839089	28893	37	10A
0005434458860	28893	38	10C
0005435252872	28893	39	10D
0005432839172	28893	40	10E
0005435252869	28893	41	10F
0005435252865	28893	42	11A
0005434458835	28893	43	11C
0005432839044	28893	44	11D
0005432839028	28893	45	11E
0005434458746	28893	46	12A
0005432841011	28893	47	12C
0005432839025	28893	48	12D
0005434458800	28893	49	12E
0005432839170	28893	50	13A
0005432839111	28893	51	13C
0005435252860	28893	52	13D
0005435252863	28893	53	13E
0005432839075	28893	54	13F
0005432839050	28893	55	14C
0005434458822	28893	56	14D
0005432839043	28893	57	14E
0005434458803	28893	58	14F
0005432839207	28893	59	15A
0005435252858	28893	60	15C
0005434458821	28893	61	15D
0005435252867	28893	62	15F
0005432001041	28893	63	16C
0005432839062	28893	64	16D
0005434458963	28893	65	16E
0005434458826	28893	66	16F
0005432839037	28893	67	17A
0005432839262	28893	68	17C
0005432839063	28893	69	17D
0005432839090	28893	70	17F
0005434458962	28893	71	18A
0005435252866	28893	72	18C
0005435491459	28893	73	18D
0005435252859	28893	74	18E
0005435252862	28893	75	19A
0005434458768	28893	76	19D
0005432839016	28893	77	19E
0005432839020	28893	78	19F
0005432839032	28893	79	20A
0005434458817	28893	80	20C
0005432839015	28893	81	20D
0005435252868	28893	82	20E
0005434458872	28893	83	20F
0005435990686	8815	1	4A
0005435990693	8815	2	4F
0005435990687	8815	3	5D
0005434276037	8815	4	7F
0005435990688	8815	5	8F
0005434276049	8815	6	11C
0005434276027	8815	7	12C
0005435990691	8815	8	14C
0005434276030	8815	9	15C
0005435990689	8815	10	15E
0005435990694	8815	11	17B
0005434276050	8815	12	17F
0005434276051	8815	13	18B
0005434276041	8815	14	18D
0005435990690	8815	15	19A
0005434276038	8815	16	19B
0005435990692	8815	17	20A
0005434276080	15756	1	1D
0005435990612	15756	2	2A
0005435990631	15756	3	3D
0005434276078	15756	4	6B
0005434276083	15756	5	6F
0005435990630	15756	6	7D
0005434276079	15756	7	8B
0005435990629	15756	8	8C
0005435990651	15756	9	8F
0005435990650	15756	10	8E
0005435990661	15756	11	9C
0005434276082	15756	12	10F
0005435990647	15756	13	10E
0005435990641	15756	14	11F
0005435990625	15756	15	12F
0005434276081	15756	16	14C
0005435990611	15756	17	14B
0005435990638	15756	18	15E
0005435990640	15756	19	17C
0005435990646	15756	20	17F
0005435990639	15756	21	18A
0005432909278	2092	1	1A
0005433468417	2092	2	1B
0005432909290	2092	3	1C
0005433468400	2092	4	1D
0005433468415	2092	5	2A
0005432909279	2092	6	2B
0005433468403	2092	7	2C
0005433468416	2092	8	2D
0005432909287	2092	9	3A
0005432909263	2092	10	3B
0005432909293	2092	11	3D
0005433468407	2092	12	4B
0005432909257	2092	13	4C
0005432909270	2092	14	4D
0005433468422	2092	15	5A
0005433468411	2092	16	5B
0005433468409	2092	17	5C
0005433468420	2092	18	5D
0005433468404	2092	19	6A
0005433468424	2092	20	6C
0005433468421	2092	21	6D
0005433468413	2092	22	7B
0005433468406	2092	23	7C
0005433468399	2092	24	7D
0005433468402	2092	25	18A
0005433468410	2092	26	18B
0005433468414	2092	27	18C
0005432909294	2092	28	18D
0005432909288	2092	29	19A
0005433468401	2092	30	19B
0005433468425	2092	31	19D
0005433468423	2092	32	20A
0005432909289	2092	33	20B
0005433468418	2092	34	20C
0005433468412	2092	35	20D
0005433468408	2092	36	21A
0005432909271	2092	37	21B
0005432909281	2092	38	21C
0005433468405	2092	39	21D
0005432909280	2092	40	22A
0005433468419	2092	41	22B
0005432909266	2092	42	22C
0005432909269	2092	43	22D
0005432909258	2092	44	23B
0005434149755	6385	1	1A
0005434149681	6385	2	1C
0005432336144	6385	3	1D
0005432360806	6385	4	1F
0005435177137	6385	5	2C
0005432062279	6385	6	2A
0005432360820	6385	7	2D
0005432360793	6385	8	3D
0005432360810	6385	9	3C
0005432363445	6385	10	3F
0005432360822	6385	11	4B
0005432360814	6385	12	4A
0005435176969	6385	13	4C
0005432360811	6385	14	4E
0005434149704	6385	15	4F
0005432360819	6385	16	5A
0005434149793	6385	17	5C
0005435177095	6385	18	5B
0005432360788	6385	19	5D
0005432360828	6385	20	5E
0005432360816	6385	21	6A
0005435177046	6385	22	6B
0005432360801	6385	23	6C
0005435177096	6385	24	6D
0005432360833	6385	25	6E
0005432360798	6385	26	7A
0005432363448	6385	27	7B
0005432360823	6385	28	7C
0005432360803	6385	29	7D
0005432336141	6385	30	7F
0005432360791	6385	31	7E
0005435177226	6385	32	8A
0005432360794	6385	33	8B
0005432360802	6385	34	8C
0005432360824	6385	35	8F
0005432360832	6385	36	8E
0005435177043	6385	37	9A
0005435177045	6385	38	9B
0005432360795	6385	39	9D
0005432360813	6385	40	10D
0005434149744	6385	41	10C
0005432360799	6385	42	11A
0005432336139	6385	43	10E
0005432336145	6385	44	11C
0005432360790	6385	45	11B
0005432360815	6385	46	11E
0005435177068	6385	47	11D
0005432062278	6385	48	11F
0005435177173	6385	49	12A
0005435723042	6385	50	12C
0005432336147	6385	51	12B
0005432336148	6385	52	12E
0005432360800	6385	53	12D
0005432363446	6385	54	13A
0005432360797	6385	55	13B
0005432360831	6385	56	13D
0005434149757	6385	57	13C
0005432336149	6385	58	13F
0005435723041	6385	59	14D
0005432360830	6385	60	14E
0005434149756	6385	61	15A
0005432062280	6385	62	15C
0005432062277	6385	63	15B
0005432360821	6385	64	15D
0005432360827	6385	65	15E
0005432360818	6385	66	16A
0005432360808	6385	67	15F
0005432336151	6385	68	16B
0005432360825	6385	69	16C
0005432360817	6385	70	16D
0005435177075	6385	71	16E
0005435177112	6385	72	17A
0005435177125	6385	73	17B
0005432360789	6385	74	17D
0005434149766	6385	75	17C
0005432360785	6385	76	17F
0005432360807	6385	77	17E
0005435177211	6385	78	18B
0005432360796	6385	79	18C
0005434149758	6385	80	18E
0005435177113	6385	81	18F
0005434149730	6385	82	19A
0005432336143	6385	83	19C
0005432336142	6385	84	19B
0005432360805	6385	85	19E
0005432363447	6385	86	19F
0005435177061	6385	87	20A
0005432360804	6385	88	20C
0005434149731	6385	89	20B
0005432360787	6385	90	20E
0005435177227	6385	91	20D
0005434149751	6385	92	21A
0005434149724	6385	93	20F
0005435177172	6385	94	21C
0005435176970	6385	95	21B
0005432360809	6385	96	21E
0005432360829	6385	97	22A
0005432360792	6385	98	22B
0005432360826	6385	99	22C
0005432336140	6385	100	22F
0005432336150	6385	101	22E
0005432336146	6385	102	23A
0005432360786	6385	103	23B
0005432360812	6385	104	23C
0005432360464	20997	1	1A
0005434149842	20997	2	1C
0005432336026	20997	3	1D
0005435177325	20997	4	1F
0005435177324	20997	5	2C
0005432336094	20997	6	2A
0005434149834	20997	7	2D
0005432360406	20997	8	2F
0005432363425	20997	9	3C
0005432360285	20997	10	3A
0005432363416	20997	11	3D
0005435177320	20997	12	3F
0005434149837	20997	13	4C
0005432360435	20997	14	4B
0005432360387	20997	15	4E
0005432360436	20997	16	4D
0005435177344	20997	17	4F
0005432360568	20997	18	5B
0005435177331	20997	19	5A
0005435490265	20997	20	5C
0005432335967	20997	21	5D
0005432360364	20997	22	5F
0005435177334	20997	23	5E
0005432336025	20997	24	6B
0005432360449	20997	25	6C
0005434149844	20997	26	6D
0005432360569	20997	27	6E
0005432336029	20997	28	6F
0005432336020	20997	29	7B
0005435177319	20997	30	7A
0005432052774	20997	31	7C
0005432336034	20997	32	7D
0005435177322	20997	33	7F
0005435177341	20997	34	7E
0005432360427	20997	35	8A
0005432360410	20997	36	8B
0005432360452	20997	37	8C
0005432052775	20997	38	8D
0005432360486	20997	39	8F
0005432360426	20997	40	8E
0005432360382	20997	41	9A
0005432360450	20997	42	9B
0005432360520	20997	43	9C
0005435490266	20997	44	9E
0005434149835	20997	45	9D
0005432336056	20997	46	10B
0005432360474	20997	47	10C
0005432363424	20997	48	10E
0005435177338	20997	49	11A
0005432360521	20997	50	11B
0005432360354	20997	51	11D
0005432360388	20997	52	11C
0005432360362	20997	53	11E
0005432360310	20997	54	12A
0005432360359	20997	55	12C
0005432360487	20997	56	12B
0005434149843	20997	57	12E
0005432360380	20997	58	12F
0005432336093	20997	59	13B
0005435177345	20997	60	13A
0005434149839	20997	61	13C
0005434149833	20997	62	13D
0005432336057	20997	63	13E
0005435177339	20997	64	14A
0005434149841	20997	65	13F
0005432360528	20997	66	14B
0005435177326	20997	67	14D
0005432360402	20997	68	14C
0005432336055	20997	69	14E
0005432360529	20997	70	15A
0005432052773	20997	71	14F
0005432363423	20997	72	15B
0005435177335	20997	73	15C
0005432052776	20997	74	15D
0005435177340	20997	75	16A
0005435177332	20997	76	15F
0005432360328	20997	77	16C
0005432360383	20997	78	16B
0005435177333	20997	79	16E
0005432360223	20997	80	16D
0005435490267	20997	81	16F
0005432360403	20997	82	17A
0005435177329	20997	83	17C
0005432360192	20997	84	17D
0005435177330	20997	85	17F
0005432360530	20997	86	18B
0005432360405	20997	87	18C
0005435177336	20997	88	18F
0005432360301	20997	89	18E
0005432360467	20997	90	19A
0005432360428	20997	91	19B
0005435177321	20997	92	19D
0005435177327	20997	93	19C
0005434149840	20997	94	19E
0005435490264	20997	95	19F
0005432360434	20997	96	20A
0005432336060	20997	97	20C
0005432360311	20997	98	20B
0005432360522	20997	99	20D
0005435177323	20997	100	20E
0005435177343	20997	101	20F
0005432335984	20997	102	21B
0005435177328	20997	103	21A
0005432360330	20997	104	21C
0005432360386	20997	105	21D
0005432360217	20997	106	21F
0005432335968	20997	107	22A
0005432360507	20997	108	22B
0005435177337	20997	109	22C
0005435177342	20997	110	22D
0005432336039	20997	111	22F
0005432360329	20997	112	22E
0005434149838	20997	113	23A
0005432360472	20997	114	23B
0005432360336	20997	115	23D
0005432360300	20997	116	23F
0005434149836	20997	117	23E
0005434458811	17697	1	1B
0005434463939	17697	2	1C
0005434458824	17697	3	2A
0005434458865	17697	4	2B
0005434186226	17697	5	2C
0005434463934	17697	6	3A
0005434458776	17697	7	3C
0005434458941	17697	8	5A
0005434458905	17697	9	5C
0005434458775	17697	10	5D
0005434186225	17697	11	6D
0005434448317	17697	12	7A
0005434458904	17697	13	7C
0005434458810	17697	14	7D
0005434448313	17697	15	18A
0005434458887	17697	16	18C
0005434186228	17697	17	18D
0005434458942	17697	18	19A
0005434458876	17697	19	19B
0005434458857	17697	20	19D
0005434458866	17697	21	20C
0005434458851	17697	22	21B
0005434461653	17697	23	22A
0005434186227	17697	24	22D
0005434463935	17697	25	23A
0005434463925	17697	26	23B
0005434458993	29100	1	1D
0005434186204	29100	2	2A
0005434186187	29100	3	2B
0005434459007	29100	4	2C
0005434458988	29100	5	2D
0005434448343	29100	6	3A
0005434186186	29100	7	3B
0005434458999	29100	8	3D
0005434463947	29100	9	4A
0005434458994	29100	10	4B
0005434459005	29100	11	4C
0005434448344	29100	12	4D
0005434458990	29100	13	5A
0005434463948	29100	14	5B
0005434459004	29100	15	5D
0005434458998	29100	16	6B
0005434458992	29100	17	6C
0005434186205	29100	18	6D
0005434459006	29100	19	7A
0005434459003	29100	20	7D
0005434459002	29100	21	18A
0005434459000	29100	22	18B
0005434459001	29100	23	19A
0005434459009	29100	24	19B
0005434186188	29100	25	19C
0005434186192	29100	26	19D
0005434458989	29100	27	20A
0005434458996	29100	28	20C
0005434458991	29100	29	20D
0005434186185	29100	30	21A
0005434458995	29100	31	21D
0005434448345	29100	32	22B
0005434463946	29100	33	22C
0005434458987	29100	34	22D
0005434458997	29100	35	23A
0005434459008	29100	36	23B
0005432604690	21446	1	1A
0005432604673	21446	2	1B
0005432604685	21446	3	1C
0005432604678	21446	4	1D
0005435218113	21446	5	2A
0005432604674	21446	6	2B
0005432604682	21446	7	2D
0005432604683	21446	8	3A
0005432604660	21446	9	3B
0005432604656	21446	10	3C
0005432604663	21446	11	4A
0005432604695	21446	12	4B
0005432604684	21446	13	4C
0005432604691	21446	14	4D
0005432604662	21446	15	5A
0005432604675	21446	16	5B
0005435220489	21446	17	5C
0005432604680	21446	18	5D
0005432604687	21446	19	6A
0005432604693	21446	20	6B
0005432604671	21446	21	6C
0005432604692	21446	22	7A
0005432604672	21446	23	7B
0005432604657	21446	24	7C
0005432604670	21446	25	7D
0005432604666	21446	26	18A
0005432604679	21446	27	18B
0005432604681	21446	28	18C
0005432604667	21446	29	19A
0005432604665	21446	30	19B
0005432604694	21446	31	19C
0005432604688	21446	32	20A
0005432604668	21446	33	20B
0005432604658	21446	34	20C
0005432604686	21446	35	20D
0005432604689	21446	36	21C
0005432604676	21446	37	21D
0005432604677	21446	38	22A
0005432604659	21446	39	22B
0005432604661	21446	40	22C
0005432604664	21446	41	22D
0005432604669	21446	42	23A
0005435218115	21446	43	23B
0005432604415	31710	1	1A
0005432604098	31710	2	1B
0005432604359	31710	3	1C
0005432604259	31710	4	1D
0005432604472	31710	5	2A
0005432604300	31710	6	2B
0005432604131	31710	7	2C
0005432604518	31710	8	2D
0005432604260	31710	9	3A
0005432604337	31710	10	3B
0005432604097	31710	11	3C
0005432604333	31710	12	3D
0005432604315	31710	13	4A
0005432604334	31710	14	4B
0005432604258	31710	15	4C
0005432604511	31710	16	4D
0005432604212	31710	17	5A
0005432604304	31710	18	5C
0005432604374	31710	19	5D
0005432604373	31710	20	6A
0005432604348	31710	21	6B
0005432604223	31710	22	6C
0005432604358	31710	23	6D
0005432604240	31710	24	7A
0005432604332	31710	25	7B
0005432604318	31710	26	7C
0005432604421	31710	27	7D
0005432604335	31710	28	18A
0005432604270	31710	29	18B
0005432604133	31710	30	18C
0005432604360	31710	31	19A
0005432604345	31710	32	18D
0005432604028	31710	33	19B
0005432604302	31710	34	19C
0005432604082	31710	35	19D
0005432604134	31710	36	20A
0005432604239	31710	37	20B
0005432604316	31710	38	20C
0005432604130	31710	39	20D
0005432604510	31710	40	21B
0005432604303	31710	41	21A
0005432604409	31710	42	21C
0005432604224	31710	43	21D
0005432604405	31710	44	22A
0005432604455	31710	45	22B
0005432604338	31710	46	22C
0005432604404	31710	47	22D
0005432604470	31710	48	23A
0005432604220	31710	49	23B
0005434606820	18913	1	3A
0005434606835	18913	2	4A
0005434606832	18913	3	4B
0005434606819	18913	4	5A
0005434606828	18913	5	6B
0005434604925	22399	1	1B
0005434606859	22399	2	2B
0005434606860	22399	3	3A
0005434604926	22399	4	4B
0005434604927	22399	5	5A
0005434606858	22399	6	5B
0005434606862	22399	7	6A
0005434606861	22399	8	6B
0005432747899	374	1	1A
0005432747919	374	2	1C
0005432891010	374	3	1D
0005432749802	374	4	1F
0005432890935	374	5	2C
0005432220042	374	6	2D
0005432747917	374	7	2F
0005432890950	374	8	3A
0005432890983	374	9	3C
0005432891049	374	10	3D
0005432747915	374	11	3F
0005433293248	374	12	4C
0005435154610	374	13	4D
0005432747893	374	14	4F
0005432747902	374	15	5A
0005432890953	374	16	5C
0005432747906	374	17	5D
0005432747896	374	18	5E
0005432747895	374	19	6A
0005432747912	374	20	6C
0005432890970	374	21	6D
0005432747897	374	22	6E
0005432747923	374	23	6F
0005432747892	374	24	7A
0005432753328	374	25	7C
0005432749804	374	26	7D
0005432751555	374	27	7E
0005432747909	374	28	7F
0005432891055	374	29	8A
0005432747926	374	30	8F
0005433875377	374	31	9A
0005432747903	374	32	9D
0005432891075	374	33	9E
0005432753329	374	34	9F
0005432890951	374	35	10C
0005432747910	374	36	10D
0005432747891	374	37	10F
0005433293253	374	38	11A
0005432753331	374	39	11C
0005432747914	374	40	11D
0005432751553	374	41	11E
0005432747913	374	42	11F
0005432747925	374	43	12C
0005432747922	374	44	12E
0005432753327	374	45	12F
0005432890969	374	46	13A
0005432747907	374	47	13C
0005432747920	374	48	13D
0005432747918	374	49	13E
0005433293252	374	50	13F
0005432749803	374	51	14C
0005432891078	374	52	14E
0005433875372	374	53	14F
0005432747921	374	54	15A
0005432747905	374	55	15C
0005432747894	374	56	15D
0005432747924	374	57	15F
0005432220041	374	58	16C
0005432747927	374	59	16D
0005432891082	374	60	16F
0005432747928	374	61	17C
0005432747890	374	62	17D
0005432890975	374	63	17E
0005432747911	374	64	17F
0005432890881	374	65	18A
0005432747900	374	66	18C
0005432220043	374	67	18D
0005432747916	374	68	18E
0005432747908	374	69	19A
0005432891067	374	70	19C
0005432747904	374	71	19D
0005432747898	374	72	19E
0005432747901	374	73	19F
0005433875373	374	74	20C
0005432891061	374	75	20D
0005432753330	374	76	20E
0005432751554	374	77	20F
0005432747592	12088	1	1A
0005432747593	12088	2	1C
0005432747693	12088	3	1D
0005432891194	12088	4	1F
0005432747545	12088	5	2A
0005435154595	12088	6	2C
0005432747710	12088	7	2D
0005435154591	12088	8	2F
0005432891199	12088	9	3A
0005432891192	12088	10	3C
0005432891206	12088	11	3D
0005432891196	12088	12	3F
0005432891198	12088	13	4A
0005433293306	12088	14	4C
0005432747731	12088	15	4E
0005432747695	12088	16	5A
0005432891200	12088	17	5C
0005432747692	12088	18	5D
0005433293308	12088	19	5E
0005432891208	12088	20	5F
0005434153546	12088	21	6A
0005435154592	12088	22	6C
0005432749782	12088	23	6D
0005432747527	12088	24	6E
0005433293310	12088	25	6F
0005432747520	12088	26	7A
0005433293301	12088	27	7C
0005432891201	12088	28	7D
0005432891205	12088	29	7E
0005432747546	12088	30	7F
0005432747547	12088	31	8A
0005432747740	12088	32	8C
0005432747580	12088	33	8F
0005432747748	12088	34	8E
0005432891204	12088	35	9A
0005434153545	12088	36	9C
0005432891202	12088	37	9D
0005433293313	12088	38	9E
0005433293311	12088	39	9F
0005433293304	12088	40	10A
0005432756837	12088	41	10C
0005433293309	12088	42	10D
0005432749792	12088	43	10F
0005432756836	12088	44	11A
0005433293305	12088	45	11C
0005432747777	12088	46	11D
0005434153544	12088	47	11E
0005432747845	12088	48	11F
0005432756828	12088	49	12A
0005433293302	12088	50	12C
0005432214825	12088	51	12D
0005432747844	12088	52	12E
0005433293312	12088	53	12F
0005432747465	12088	54	13A
0005432753315	12088	55	13C
0005435154593	12088	56	13D
0005432747466	12088	57	13E
0005432747591	12088	58	13F
0005432891209	12088	59	14A
0005432891190	12088	60	14C
0005432891207	12088	61	14E
0005432891193	12088	62	14F
0005432891203	12088	63	15A
0005432747739	12088	64	15C
0005432747778	12088	65	15D
0005432747691	12088	66	15E
0005435154594	12088	67	15F
0005432747590	12088	68	16A
0005432747385	12088	69	16C
0005432747561	12088	70	16E
0005432747597	12088	71	16F
0005433293307	12088	72	17A
0005432747589	12088	73	17D
0005432747776	12088	74	17E
0005432756844	12088	75	17F
0005432214823	12088	76	18A
0005433293303	12088	77	18C
0005432747753	12088	78	18D
0005432747711	12088	79	18E
0005432749783	12088	80	18F
0005432747843	12088	81	19A
0005432891191	12088	82	19C
0005433875393	12088	83	19E
0005432747510	12088	84	19F
0005432891195	12088	85	20A
0005432214824	12088	86	20C
0005432747634	12088	87	20D
0005432891197	12088	88	20F
0005432747588	12088	89	20E
0005433525129	18941	1	1A
0005433525126	18941	2	1C
0005432927965	18941	3	2A
0005433525134	18941	4	3A
0005433525135	18941	5	3D
0005433531325	18941	6	5A
0005433533340	18941	7	5B
0005432927964	18941	8	6C
0005433525130	18941	9	7A
0005433525128	18941	10	7D
0005433531324	18941	11	18B
0005433525133	18941	12	18D
0005432927968	18941	13	19A
0005433533339	18941	14	20B
0005433533338	18941	15	21C
0005432927983	18941	16	21D
0005433525131	18941	17	22A
0005433525132	18941	18	22B
0005432927978	18941	19	22C
0005433525127	18941	20	22D
0005432928038	32498	1	1A
0005433531295	32498	2	1C
0005433525044	32498	3	1D
0005433531290	32498	4	2C
0005433525060	32498	5	4B
0005432928039	32498	6	4D
0005433525074	32498	7	5A
0005433531301	32498	8	5B
0005432928034	32498	9	5C
0005432928036	32498	10	7B
0005433525040	32498	11	7C
0005433525042	32498	12	7D
0005433525068	32498	13	18C
0005433525069	32498	14	18D
0005433527256	32498	15	19A
0005432928037	32498	16	19C
0005433525052	32498	17	20A
0005432928035	32498	18	20B
0005432121457	5262	1	1C
0005434824801	5262	2	1A
0005435373391	5262	3	1G
0005435150159	5262	4	1D
0005434824710	5262	5	2A
0005432396281	5262	6	1K
0005435373436	5262	7	1H
0005435304165	5262	8	2C
0005434824808	5262	9	2H
0005435373616	5262	10	2D
0005434824785	5262	11	3A
0005432121460	5262	12	2K
0005434824715	5262	13	3D
0005435373490	5262	14	3C
0005434824698	5262	15	3K
0005434824788	5262	16	3H
0005435373516	5262	17	3G
0005432121469	5262	18	4G
0005435373465	5262	19	4K
0005434824693	5262	20	4H
0005435373194	5262	21	5C
0005434824765	5262	22	5A
0005435373716	5262	23	5H
0005435373514	5262	24	5D
0005435373111	5262	25	11A
0005434824735	5262	26	11D
0005434824752	5262	27	11C
0005435373105	5262	28	11G
0005435372940	5262	29	11F
0005435373580	5262	30	11K
0005434824687	5262	31	12C
0005434558349	5262	32	12A
0005434824746	5262	33	12E
0005434824716	5262	34	12D
0005434824725	5262	35	12G
0005434824773	5262	36	13A
0005435373228	5262	37	12K
0005434824740	5262	38	12H
0005435373375	5262	39	13D
0005434824692	5262	40	13F
0005434824719	5262	41	13E
0005432394142	5262	42	13H
0005435373139	5262	43	13G
0005435373461	5262	44	14A
0005432121462	5262	45	13K
0005434824794	5262	46	14E
0005432396279	5262	47	14D
0005435150158	5262	48	14C
0005432394141	5262	49	14G
0005434824734	5262	50	14F
0005434824771	5262	51	15E
0005435373185	5262	52	15D
0005434824775	5262	53	15G
0005432121464	5262	54	15F
0005434824731	5262	55	15K
0005434824781	5262	56	15H
0005435373460	5262	57	16D
0005435373335	5262	58	16C
0005434824795	5262	59	16F
0005435373447	5262	60	16E
0005434824744	5262	61	16G
0005435373253	5262	62	17A
0005435304178	5262	63	16K
0005435373171	5262	64	17D
0005434824807	5262	65	17C
0005435150161	5262	66	17G
0005434824758	5262	67	17F
0005434824763	5262	68	17E
0005432121459	5262	69	17K
0005435373252	5262	70	17H
0005435373106	5262	71	18C
0005435304170	5262	72	18B
0005434824789	5262	73	18G
0005434824721	5262	74	18F
0005434824694	5262	75	18K
0005434824742	5262	76	18J
0005434824816	5262	77	19B
0005435373444	5262	78	19F
0005434824747	5262	79	19E
0005434824690	5262	80	19D
0005434558350	5262	81	19H
0005434824779	5262	82	19G
0005435299767	5262	83	20A
0005435150150	5262	84	20C
0005435372913	5262	85	20B
0005435150154	5262	86	20E
0005434824713	5262	87	20D
0005435373389	5262	88	20G
0005434824751	5262	89	20F
0005434824770	5262	90	20H
0005435373143	5262	91	21B
0005435373200	5262	92	21A
0005435299803	5262	93	21D
0005434824700	5262	94	21C
0005435373550	5262	95	21F
0005435372879	5262	96	21H
0005434824728	5262	97	22A
0005435372926	5262	98	21K
0005434828721	5262	99	22C
0005434824714	5262	100	22F
0005435373305	5262	101	22E
0005434824800	5262	102	22H
0005434824815	5262	103	22G
0005434664981	5262	104	22K
0005434824743	5262	105	22J
0005434824745	5262	106	23B
0005434824764	5262	107	23A
0005434824708	5262	108	23D
0005435373547	5262	109	23G
0005434831191	5262	110	23E
0005434824761	5262	111	23H
0005432823449	5262	112	24D
0005434824796	5262	113	23K
0005435373488	5262	114	23J
0005435373181	5262	115	25B
0005435373462	5262	116	25D
0005434558351	5262	117	25C
0005434558352	5262	118	25E
0005435373275	5262	119	25J
0005434824720	5262	120	25H
0005435373227	5262	121	25K
0005432823444	5262	122	26D
0005435373226	5262	123	26C
0005435373169	5262	124	26G
0005434824726	5262	125	26F
0005434831192	5262	126	26J
0005435373284	5262	127	26H
0005434824793	5262	128	27B
0005435661918	5262	129	27A
0005435150156	5262	130	27C
0005434664980	5262	131	27F
0005434824756	5262	132	27E
0005435373201	5262	133	27H
0005434824695	5262	134	27G
0005435150160	5262	135	27K
0005435373336	5262	136	27J
0005435373481	5262	137	28C
0005434558348	5262	138	28B
0005435373376	5262	139	28A
0005434824777	5262	140	28E
0005435373438	5262	141	28D
0005434824768	5262	142	28H
0005435373377	5262	143	28G
0005432823452	5262	144	28F
0005434824809	5262	145	28J
0005435373519	5262	146	29B
0005435304171	5262	147	29A
0005435373474	5262	148	28K
0005435373440	5262	149	29C
0005435373435	5262	150	29F
0005434824798	5262	151	29E
0005435373527	5262	152	29G
0005434824804	5262	153	29K
0005432121470	5262	154	29J
0005434824736	5262	155	30C
0005432121468	5262	156	30B
0005434824705	5262	157	30A
0005435373552	5262	158	30E
0005435373141	5262	159	30G
0005434824724	5262	160	30F
0005435373175	5262	161	30H
0005434824703	5262	162	31B
0005434824814	5262	163	30K
0005435373140	5262	164	31D
0005434824767	5262	165	31F
0005435661925	5262	166	31E
0005435179699	5262	167	31J
0005434831190	5262	168	31H
0005435373345	5262	169	31G
0005435373333	5262	170	31K
0005434824730	5262	171	32E
0005435373204	5262	172	32D
0005434824737	5262	173	32C
0005435150155	5262	174	32F
0005434824759	5262	175	32J
0005434824727	5262	176	33B
0005435373352	5262	177	33A
0005434824733	5262	178	32K
0005434824810	5262	179	33C
0005435373625	5262	180	33G
0005435373170	5262	181	33F
0005432396278	5262	182	33E
0005432121458	5262	183	33J
0005434824797	5262	184	33H
0005435373079	5262	185	34A
0005435150163	5262	186	33K
0005434824762	5262	187	34B
0005434558347	5262	188	34E
0005435373338	5262	189	34D
0005434824689	5262	190	34C
0005434824806	5262	191	34G
0005435373154	5262	192	34F
0005435373473	5262	193	34J
0005435373529	5262	194	34H
0005435304177	5262	195	35A
0005432121467	5262	196	35D
0005435373403	5262	197	35C
0005435304159	5262	198	35F
0005434824776	5262	199	35E
0005435150162	5262	200	35H
0005435661935	5262	201	35G
0005434824772	5262	202	36A
0005435373500	5262	203	36C
0005434824688	5262	204	36B
0005434824791	5262	205	36F
0005435299766	5262	206	36E
0005434824729	5262	207	36D
0005432394143	5262	208	36G
0005434824738	5262	209	36K
0005434824691	5262	210	36H
0005435150164	5262	211	37B
0005435373078	5262	212	37A
0005434824748	5262	213	37D
0005435150149	5262	214	37C
0005434824813	5262	215	37E
0005434824755	5262	216	37J
0005432121463	5262	217	37H
0005435299791	5262	218	37G
0005435373229	5262	219	38A
0005434824782	5262	220	37K
0005435373070	5262	221	38C
0005435150153	5262	222	38H
0005434824749	5262	223	39A
0005435373247	5262	224	38K
0005432394140	5262	225	39C
0005434824723	5262	226	39G
0005435373246	5262	227	39E
0005434824706	5262	228	39D
0005435373480	5262	229	39J
0005434824711	5262	230	39H
0005435304166	5262	231	40A
0005434824780	5262	232	40C
0005435372953	5262	233	40B
0005435373033	5262	234	40E
0005435373239	5262	235	40D
0005434824697	5262	236	40H
0005435299783	5262	237	40G
0005432823443	5262	238	40K
0005432121461	5262	239	41A
0005435373346	5262	240	41D
0005434824704	5262	241	41C
0005435373482	5262	242	41H
0005435373142	5262	243	41G
0005435373197	5262	244	42A
0005435373304	5262	245	41K
0005434824754	5262	246	41J
0005432121471	5262	247	42C
0005434824722	5262	248	42B
0005434824802	5262	249	42D
0005432823442	5262	250	42G
0005435373517	5262	251	42F
0005435373424	5262	252	42J
0005434824753	5262	253	42K
0005435373173	5262	254	43D
0005434824786	5262	255	43C
0005435373188	5262	256	43B
0005432121465	5262	257	43F
0005434824790	5262	258	43E
0005432396280	5262	259	43J
0005432396282	5262	260	43H
0005434824766	5262	261	43G
0005434831189	5262	262	44A
0005434558353	5262	263	43K
0005434824811	5262	264	44B
0005435661928	5262	265	44E
0005434824783	5262	266	44G
0005434831188	5262	267	44F
0005434824702	5262	268	44K
0005434824696	5262	269	44J
0005434824778	5262	270	44H
0005435373286	5262	271	45B
0005435373353	5262	272	45A
0005435373245	5262	273	45D
0005435373230	5262	274	45C
0005434824707	5262	275	45F
0005434824717	5262	276	45E
0005435373285	5262	277	45H
0005434824739	5262	278	45G
0005435373299	5262	279	45K
0005434824709	5262	280	45J
0005434824799	5262	281	46B
0005432394139	5262	282	46D
0005434824732	5262	283	46C
0005434824774	5262	284	46F
0005435373193	5262	285	46H
0005435299735	5262	286	47A
0005434824757	5262	287	46K
0005434824805	5262	288	47E
0005435373287	5262	289	47C
0005434824760	5262	290	47G
0005435150152	5262	291	47F
0005434824750	5262	292	48A
0005435150157	5262	293	47K
0005434824787	5262	294	47H
0005435373513	5262	295	48C
0005432823451	5262	296	48F
0005434824769	5262	297	48D
0005434824701	5262	298	48H
0005435373174	5262	299	48G
0005435373425	5262	300	49C
0005435373390	5262	301	49A
0005434824803	5262	302	48K
0005434824784	5262	303	49E
0005435373518	5262	304	49D
0005434824699	5262	305	49G
0005435150151	5262	306	49F
0005434824718	5262	307	49K
0005434558346	5262	308	49H
0005434824741	5262	309	50D
0005434664979	5262	310	50C
0005435304161	5262	311	50A
0005435373294	5262	312	50E
0005435372878	5262	313	50H
0005435373332	5262	314	50G
0005434824792	5262	315	50F
0005434824812	5262	316	50K
0005434824712	5262	317	51F
0005435373340	5262	318	51E
0005432121466	5262	319	51D
0005435373115	5262	320	51G
0005434824178	9901	1	1C
0005434823518	9901	2	1A
0005434823803	9901	3	1D
0005435373852	9901	4	1K
0005435373881	9901	5	1H
0005435373841	9901	6	2D
0005435373884	9901	7	2C
0005434823756	9901	8	3A
0005435373848	9901	9	2K
0005434823568	9901	10	3D
0005434824173	9901	11	3C
0005435150059	9901	12	3K
0005434824075	9901	13	3H
0005434823735	9901	14	4A
0005435661959	9901	15	4D
0005435373842	9901	16	4C
0005435373860	9901	17	4K
0005432400123	9901	18	5A
0005435373863	9901	19	5G
0005435150036	9901	20	11C
0005434558251	9901	21	11A
0005432203132	9901	22	11E
0005435299821	9901	23	11D
0005434823897	9901	24	11K
0005434823335	9901	25	11H
0005434823864	9901	26	12C
0005434823386	9901	27	12D
0005434823494	9901	28	12G
0005434558269	9901	29	12F
0005434558262	9901	30	12K
0005432400132	9901	31	12H
0005435373883	9901	32	13D
0005435373866	9901	33	13C
0005434823743	9901	34	13A
0005435373886	9901	35	13F
0005434823633	9901	36	13G
0005435373877	9901	37	14A
0005435386630	9901	38	14E
0005434824074	9901	39	14D
0005435373871	9901	40	14C
0005435373888	9901	41	14G
0005434823724	9901	42	14F
0005435373858	9901	43	14K
0005434823744	9901	44	14H
0005434823330	9901	45	15C
0005434823556	9901	46	15A
0005435302241	9901	47	15F
0005434823892	9901	48	15E
0005435373836	9901	49	15G
0005434823784	9901	50	15K
0005435373870	9901	51	15H
0005434823709	9901	52	16D
0005434823375	9901	53	16C
0005435150035	9901	54	16A
0005435373862	9901	55	16F
0005434823645	9901	56	16E
0005435386632	9901	57	16K
0005435373844	9901	58	16H
0005435373880	9901	59	17G
0005435373839	9901	60	17F
0005435373837	9901	61	18A
0005434824411	9901	62	17K
0005435373847	9901	63	17H
0005432203130	9901	64	18C
0005434824020	9901	65	18G
0005435735180	9901	66	18E
0005434823695	9901	67	18K
0005434823676	9901	68	18J
0005434823618	9901	69	19B
0005434823619	9901	70	19A
0005434823687	9901	71	19C
0005434823699	9901	72	19J
0005434823592	9901	73	19G
0005435373850	9901	74	20C
0005434823421	9901	75	20D
0005434823698	9901	76	20G
0005435661960	9901	77	20F
0005435373845	9901	78	20J
0005434823531	9901	79	20H
0005434823570	9901	80	21B
0005435373864	9901	81	20K
0005434823307	9901	82	21D
0005435386631	9901	83	21C
0005435299819	9901	84	21G
0005435373853	9901	85	21F
0005434823535	9901	86	21H
0005434823798	9901	87	22A
0005434824116	9901	88	21K
0005434823862	9901	89	22C
0005434823169	9901	90	22B
0005434823934	9901	91	22E
0005434823548	9901	92	22G
0005434823545	9901	93	22F
0005434558252	9901	94	22J
0005434558273	9901	95	23B
0005434823742	9901	96	23A
0005434823918	9901	97	23C
0005434823613	9901	98	23G
0005434823646	9901	99	23H
0005434823923	9901	100	24D
0005435150022	9901	101	23K
0005434824366	9901	102	23J
0005435735181	9901	103	24F
0005434558248	9901	104	24E
0005435373876	9901	105	25B
0005434823495	9901	106	25A
0005434824365	9901	107	24G
0005435373874	9901	108	25F
0005435373869	9901	109	25E
0005435373885	9901	110	25H
0005434823654	9901	111	25G
0005435373838	9901	112	25K
0005434823249	9901	113	25J
0005435302243	9901	114	26C
0005434823350	9901	115	26A
0005432823468	9901	116	26D
0005434823422	9901	117	26G
0005434823881	9901	118	26F
0005432823469	9901	119	26J
0005434823547	9901	120	26H
0005432203131	9901	121	27A
0005434823634	9901	122	27C
0005434823231	9901	123	27F
0005434823308	9901	124	27E
0005434823501	9901	125	27H
0005435150034	9901	126	28C
0005432396218	9901	127	28B
0005434831137	9901	128	28A
0005434824274	9901	129	28E
0005434823427	9901	130	28G
0005434824043	9901	131	28F
0005435373859	9901	132	28K
0005434823522	9901	133	29A
0005435373895	9901	134	29C
0005435302239	9901	135	29F
0005435149947	9901	136	29D
0005434824044	9901	137	29H
0005435150057	9901	138	29G
0005434824131	9901	139	30A
0005434823667	9901	140	29K
0005434823511	9901	141	29J
0005434823588	9901	142	30E
0005434823534	9901	143	30D
0005434823333	9901	144	30C
0005434558272	9901	145	30G
0005434823694	9901	146	30F
0005435302240	9901	147	30K
0005434823404	9901	148	30J
0005434831161	9901	149	31B
0005434824021	9901	150	31A
0005434823572	9901	151	31F
0005435373857	9901	152	31J
0005434823334	9901	153	31G
0005434823817	9901	154	32B
0005434558270	9901	155	32A
0005435373861	9901	156	32D
0005434823533	9901	157	32C
0005434823513	9901	158	32G
0005434823512	9901	159	32F
0005435373835	9901	160	32J
0005435299820	9901	161	32H
0005435373846	9901	162	33B
0005434823816	9901	163	33A
0005434824175	9901	164	33D
0005432396250	9901	165	33C
0005434823137	9901	166	33F
0005434823417	9901	167	33E
0005434823993	9901	168	33K
0005434823491	9901	169	33J
0005432396245	9901	170	34E
0005434824132	9901	171	34C
0005434823558	9901	172	34G
0005434823924	9901	173	34K
0005434823313	9901	174	35B
0005435373882	9901	175	35E
0005435149946	9901	176	35D
0005435373878	9901	177	35C
0005434823823	9901	178	35F
0005434558261	9901	179	35J
0005434824233	9901	180	35H
0005434823971	9901	181	35G
0005435373890	9901	182	36C
0005434823569	9901	183	36B
0005435373889	9901	184	36E
0005432203133	9901	185	36D
0005435373873	9901	186	36H
0005435735182	9901	187	36G
0005435373879	9901	188	36K
0005435373854	9901	189	37C
0005434823677	9901	190	37B
0005432396241	9901	191	37A
0005434823824	9901	192	37E
0005435373892	9901	193	37H
0005434823523	9901	194	37G
0005435373893	9901	195	38A
0005434558271	9901	196	37K
0005432400131	9901	197	38B
0005432396240	9901	198	38J
0005435386635	9901	199	38H
0005435386634	9901	200	39D
0005434823672	9901	201	39C
0005432203128	9901	202	39H
0005434824166	9901	203	39K
0005435373865	9901	204	39J
0005434823788	9901	205	40C
0005432400122	9901	206	40B
0005435373840	9901	207	40E
0005435373875	9901	208	40D
0005434823502	9901	209	40J
0005434823734	9901	210	40H
0005434823445	9901	211	41B
0005435373851	9901	212	41D
0005434823911	9901	213	41C
0005434823532	9901	214	41F
0005435373867	9901	215	41J
0005435735179	9901	216	41H
0005434823972	9901	217	42A
0005435373830	9901	218	42C
0005435373868	9901	219	42B
0005434831138	9901	220	42E
0005435150011	9901	221	42G
0005434823232	9901	222	42H
0005434823673	9901	223	43B
0005434823415	9901	224	43A
0005435373832	9901	225	42K
0005434824117	9901	226	43D
0005435150058	9901	227	43C
0005434823585	9901	228	43F
0005435373887	9901	229	43E
0005435299818	9901	230	43H
0005434823446	9901	231	43G
0005434823896	9901	232	44A
0005435302242	9901	233	43K
0005434823723	9901	234	43J
0005435373872	9901	235	44C
0005434824165	9901	236	44E
0005432203127	9901	237	44D
0005434823876	9901	238	44G
0005435373834	9901	239	44H
0005434823878	9901	240	45A
0005435302244	9901	241	44K
0005434823815	9901	242	45C
0005434823865	9901	243	45B
0005435373855	9901	244	45E
0005434824022	9901	245	45G
0005435299817	9901	246	45J
0005434831162	9901	247	46C
0005435386633	9901	248	46B
0005435179402	9901	249	46A
0005432396217	9901	250	46E
0005435373849	9901	251	46D
0005434823710	9901	252	46G
0005435373894	9901	253	46J
0005435373833	9901	254	47C
0005435373843	9901	255	47A
0005434824279	9901	256	46K
0005434823521	9901	257	47D
0005434823248	9901	258	47F
0005434823519	9901	259	47K
0005432396251	9901	260	47H
0005434823288	9901	261	48C
0005434823274	9901	262	48A
0005434824115	9901	263	48E
0005432203129	9901	264	48H
0005435373891	9901	265	48G
0005434823331	9901	266	49A
0005434823429	9901	267	49E
0005434558268	9901	268	49D
0005434823230	9901	269	49C
0005434823861	9901	270	49G
0005434823387	9901	271	49K
0005435373831	9901	272	49H
0005435373856	9901	273	50A
0005434823783	9901	274	50H
0005434823312	9901	275	50G
0005434823376	9901	276	50F
0005434823138	9901	277	50K
0005434824174	9901	278	51F
0005434823822	9901	279	51E
0005434823377	9901	280	51D
0005434558253	9901	281	51G
0005435082861	7026	1	1C
0005435790333	7026	2	4B
0005435790332	7026	3	4D
0005435790334	7026	4	5A
0005435082863	7026	5	6B
0005435082862	7026	6	19B
0005435082858	7026	7	19D
0005435082857	7026	8	20D
0005435082859	7026	9	22A
0005435082860	7026	10	22B
0005435082823	26004	1	1A
0005435082775	26004	2	1B
0005435082824	26004	3	3B
0005435082792	26004	4	3C
0005435082797	26004	5	4C
0005435082790	26004	6	5D
0005435082798	26004	7	6D
0005435082791	26004	8	19B
0005435082768	26004	9	19D
0005435790302	26004	10	20C
0005435790318	26004	11	20D
0005435790307	26004	12	22C
0005435082774	26004	13	23A
0005434214424	9547	1	1A
0005434756789	9547	2	1D
0005434756810	9547	3	1F
0005434756788	9547	4	2A
0005434214637	9547	5	2C
0005434214492	9547	6	2F
0005434756808	9547	7	3A
0005434214494	9547	8	3C
0005434756823	9547	9	3D
0005434214431	9547	10	3F
0005434214591	9547	11	4A
0005434214566	9547	12	4C
0005434214453	9547	13	4D
0005434756836	9547	14	4E
0005434756825	9547	15	4F
0005434756811	9547	16	5A
0005434756802	9547	17	5C
0005434214465	9547	18	5D
0005434756791	9547	19	5E
0005434214368	9547	20	5F
0005434214318	9547	21	6A
0005434756815	9547	22	6C
0005434756821	9547	23	6D
0005434214726	9547	24	6E
0005434756809	9547	25	6F
0005434756804	9547	26	7A
0005434214454	9547	27	7C
0005434214317	9547	28	7D
0005434756817	9547	29	7E
0005434214491	9547	30	7F
0005434214546	9547	31	8A
0005434214651	9547	32	8C
0005434756790	9547	33	8D
0005434214589	9547	34	8E
0005434214544	9547	35	8F
0005434756814	9547	36	9A
0005434214541	9547	37	9C
0005434756807	9547	38	9D
0005434756803	9547	39	9E
0005434756834	9547	40	9F
0005434756806	9547	41	10A
0005434756829	9547	42	10C
0005434756830	9547	43	10D
0005434756824	9547	44	10E
0005434214543	9547	45	10F
0005434756800	9547	46	11A
0005434214369	9547	47	11C
0005434756826	9547	48	11D
0005434214529	9547	49	11E
0005434214367	9547	50	11F
0005434756813	9547	51	12A
0005434214532	9547	52	12C
0005434214565	9547	53	12D
0005434756787	9547	54	12E
0005434756797	9547	55	12F
0005434214523	9547	56	13A
0005434214667	9547	57	13C
0005434756793	9547	58	13D
0005434214518	9547	59	13F
0005434214505	9547	60	14A
0005434214467	9547	61	14C
0005434214573	9547	62	14D
0005434756837	9547	63	14E
0005434756816	9547	64	14F
0005434756838	9547	65	15A
0005434756822	9547	66	15C
0005434214387	9547	67	15D
0005434756833	9547	68	15E
0005434214557	9547	69	15F
0005434756818	9547	70	16A
0005434756792	9547	71	16C
0005434756796	9547	72	16D
0005434214540	9547	73	16E
0005434756798	9547	74	16F
0005434756839	9547	75	17A
0005434756820	9547	76	17C
0005434214488	9547	77	17D
0005434756794	9547	78	17E
0005434756805	9547	79	17F
0005434214499	9547	80	18A
0005434214766	9547	81	18C
0005434756827	9547	82	18D
0005434214606	9547	83	18E
0005434756819	9547	84	18F
0005434756799	9547	85	19A
0005434756832	9547	86	19C
0005434756828	9547	87	19D
0005434756795	9547	88	19E
0005434756801	9547	89	19F
0005434756831	9547	90	20A
0005434214388	9547	91	20C
0005434756835	9547	92	20D
0005434214430	9547	93	20E
0005434756812	9547	94	20F
0005434756317	28647	1	1A
0005434756318	28647	2	1C
0005434214906	28647	3	1D
0005434756401	28647	4	1F
0005434214905	28647	5	2A
0005434756402	28647	6	2C
0005434756140	28647	7	2D
0005434756312	28647	8	2F
0005434756375	28647	9	3A
0005434214892	28647	10	3C
0005434214931	28647	11	3D
0005434214918	28647	12	3F
0005434756392	28647	13	4A
0005434756378	28647	14	4C
0005434214913	28647	15	4D
0005434756379	28647	16	4E
0005434756407	28647	17	4F
0005434756338	28647	18	5C
0005434214934	28647	19	5D
0005434214920	28647	20	5E
0005434756340	28647	21	5F
0005434214894	28647	22	6A
0005434214911	28647	23	6C
0005434214935	28647	24	6D
0005434756254	28647	25	6E
0005434756300	28647	26	6F
0005434756382	28647	27	7A
0005434756261	28647	28	7C
0005434214937	28647	29	7D
0005434214924	28647	30	7E
0005434214925	28647	31	7F
0005434756356	28647	32	8A
0005434756363	28647	33	8C
0005434214900	28647	34	8D
0005434214904	28647	35	8E
0005434214936	28647	36	8F
0005434756358	28647	37	9A
0005434756139	28647	38	9C
0005434756308	28647	39	9D
0005434214895	28647	40	9E
0005434756286	28647	41	9F
0005434214893	28647	42	10A
0005434214889	28647	43	10C
0005434214908	28647	44	10D
0005434214930	28647	45	10E
0005434214896	28647	46	10F
0005434756385	28647	47	11A
0005434214890	28647	48	11C
0005434756339	28647	49	11D
0005434756434	28647	50	11E
0005434214919	28647	51	11F
0005434214902	28647	52	12A
0005434756360	28647	53	12C
0005434214928	28647	54	12D
0005434214933	28647	55	12E
0005434756355	28647	56	12F
0005434756383	28647	57	13A
0005434214903	28647	58	13C
0005434756381	28647	59	13D
0005434756374	28647	60	13E
0005434756301	28647	61	13F
0005434214927	28647	62	14A
0005434756232	28647	63	14C
0005434214909	28647	64	14D
0005434214899	28647	65	14E
0005434214910	28647	66	14F
0005434756420	28647	67	15A
0005434214932	28647	68	15C
0005434214923	28647	69	15D
0005434214917	28647	70	15E
0005434214907	28647	71	15F
0005434214898	28647	72	16A
0005434214915	28647	73	16C
0005434756423	28647	74	16D
0005434756307	28647	75	16E
0005434214922	28647	76	16F
0005434756233	28647	77	17A
0005434214897	28647	78	17C
0005434756141	28647	79	17D
0005434214891	28647	80	17E
0005434756386	28647	81	17F
0005434214914	28647	82	18A
0005434214916	28647	83	18C
0005434214912	28647	84	18D
0005434214921	28647	85	18E
0005434756357	28647	86	18F
0005434756316	28647	87	19A
0005434756255	28647	88	19C
0005434214888	28647	89	19D
0005434756330	28647	90	19E
0005434756421	28647	91	19F
0005434214929	28647	92	20A
0005434214901	28647	93	20C
0005434214926	28647	94	20D
0005434756387	28647	95	20E
0005434756311	28647	96	20F
0005435100151	10844	1	1A
0005434760202	10844	2	4C
0005435100150	10844	3	18A
0005434760203	10844	4	18C
0005435100149	10844	5	22D
0005434760220	31832	1	4C
0005435100120	31832	2	7A
0005435100131	31832	3	21A
0005435100130	31832	4	21B
0005435100134	31832	5	21D
0005434760219	31832	6	22A
0005434639554	1969	1	1A
0005433202360	1969	2	1B
0005434639564	1969	3	1C
0005433202358	1969	4	1D
0005432290661	1969	5	2A
0005433202356	1969	6	2B
0005434639565	1969	7	2C
0005432290663	1969	8	2D
0005434639561	1969	9	3A
0005433202298	1969	10	3B
0005433202309	1969	11	3C
0005433202398	1969	12	3D
0005434639571	1969	13	4A
0005433202361	1969	14	4B
0005433202355	1969	15	4C
0005434639562	1969	16	4D
0005433202303	1969	17	5A
0005433202384	1969	18	5B
0005434639572	1969	19	5C
0005434639560	1969	20	5D
0005434639551	1969	21	6A
0005434639559	1969	22	6B
0005434639566	1969	23	6C
0005433202385	1969	24	6D
0005434639568	1969	25	7A
0005433202351	1969	26	7B
0005433202417	1969	27	7C
0005434639550	1969	28	7D
0005434639555	1969	29	18B
0005433202359	1969	30	18A
0005432290662	1969	31	18C
0005434639567	1969	32	18D
0005434639552	1969	33	19A
0005433202369	1969	34	19B
0005433202295	1969	35	19C
0005434639549	1969	36	19D
0005434639553	1969	37	20B
0005434639557	1969	38	20C
0005433202366	1969	39	20D
0005434639569	1969	40	21A
0005433202428	1969	41	21B
0005434639556	1969	42	21C
0005433202350	1969	43	21D
0005434639563	1969	44	22A
0005434639570	1969	45	22B
0005434639558	1969	46	22C
0005433202368	1969	47	22D
0005433202418	1969	48	23A
0005433202370	1969	49	23B
0005434639324	23247	1	1A
0005433202491	23247	2	1B
0005434639338	23247	3	1C
0005434639380	23247	4	1D
0005434639381	23247	5	2A
0005433202483	23247	6	2B
0005434639417	23247	7	2C
0005434639255	23247	8	3A
0005433202486	23247	9	3D
0005434639390	23247	10	4B
0005434639291	23247	11	4C
0005433202485	23247	12	4D
0005433202480	23247	13	5B
0005433202481	23247	14	5C
0005434639387	23247	15	5D
0005434639379	23247	16	6D
0005433202489	23247	17	7A
0005434639314	23247	18	7B
0005434639219	23247	19	7C
0005433202479	23247	20	18A
0005434639389	23247	21	7D
0005434639394	23247	22	18B
0005433202487	23247	23	18C
0005434639238	23247	24	18D
0005434639342	23247	25	19A
0005434639337	23247	26	19B
0005434639290	23247	27	19C
0005434639319	23247	28	20A
0005434639386	23247	29	20C
0005433202482	23247	30	21A
0005433202488	23247	31	21B
0005434639300	23247	32	21C
0005434639391	23247	33	21D
0005433202493	23247	34	22A
0005433202492	23247	35	22B
0005434639336	23247	36	22C
0005434639299	23247	37	22D
0005433202490	23247	38	23A
0005433202484	23247	39	23B
0005434601068	6086	1	1A
0005434601054	6086	2	1D
0005433531328	6086	3	1F
0005434601059	6086	4	2C
0005432111307	6086	5	2D
0005434601066	6086	6	2F
0005435326716	6086	7	3C
0005433533344	6086	8	4A
0005434601061	6086	9	4F
0005434601056	6086	10	5A
0005434601063	6086	11	5C
0005435326713	6086	12	6C
0005434601065	6086	13	6E
0005434601069	6086	14	6F
0005433533345	6086	15	7D
0005434601062	6086	16	7E
0005434601044	6086	17	8A
0005433531329	6086	18	8C
0005433533342	6086	19	8D
0005434601060	6086	20	8E
0005434601058	6086	21	8F
0005435326820	6086	22	9A
0005432111308	6086	23	9D
0005435326725	6086	24	9E
0005434601047	6086	25	9F
0005435326791	6086	26	10A
0005434601046	6086	27	10D
0005433531327	6086	28	10E
0005435326707	6086	29	11D
0005434601051	6086	30	11F
0005435326724	6086	31	12A
0005435326709	6086	32	12C
0005435326710	6086	33	12D
0005434601055	6086	34	13D
0005433531330	6086	35	14A
0005435326752	6086	36	14C
0005435326743	6086	37	14D
0005434601067	6086	38	14E
0005434601050	6086	39	14F
0005435326714	6086	40	15A
0005432111306	6086	41	15E
0005435326790	6086	42	15D
0005435326715	6086	43	16A
0005435326729	6086	44	16C
0005434601052	6086	45	16E
0005434601064	6086	46	17A
0005433531326	6086	47	17C
0005433533343	6086	48	18A
0005433533341	6086	49	18C
0005434601049	6086	50	18D
0005434601045	6086	51	18E
0005434601053	6086	52	19C
0005434601057	6086	53	19D
0005434601048	6086	54	19E
0005434601070	6086	55	20A
0005435326726	6086	56	20D
0005435326871	18603	1	1A
0005434600830	18603	2	1C
0005434600803	18603	3	1D
0005435326867	18603	4	2A
0005434600804	18603	5	2D
0005434600896	18603	6	2F
0005434600895	18603	7	3A
0005434600743	18603	8	3F
0005434600843	18603	9	4A
0005434600840	18603	10	4C
0005434600773	18603	11	4E
0005435326872	18603	12	5C
0005434600730	18603	13	6E
0005434600766	18603	14	7D
0005434600836	18603	15	8D
0005434600782	18603	16	9C
0005435326874	18603	17	9E
0005434600957	18603	18	9F
0005434600841	18603	19	10A
0005433527241	18603	20	10C
0005434600763	18603	21	10E
0005435326876	18603	22	10F
0005435326869	18603	23	11A
0005434600783	18603	24	12C
0005434600779	18603	25	12E
0005435326879	18603	26	12F
0005434600835	18603	27	13A
0005434600847	18603	28	13D
0005435326870	18603	29	13E
0005434600884	18603	30	13F
0005434600697	18603	31	14A
0005435326877	18603	32	14D
0005434600780	18603	33	14E
0005434600767	18603	34	15A
0005434600698	18603	35	15E
0005434600735	18603	36	16C
0005434600846	18603	37	16F
0005433531314	18603	38	17A
0005434600786	18603	39	17E
0005434600839	18603	40	17F
0005434600910	18603	41	18C
0005435326873	18603	42	18D
0005434600924	18603	43	19C
0005435326878	18603	44	19D
0005435326875	18603	45	19E
0005434600806	18603	46	20A
0005435326866	18603	47	20E
0005435326868	18603	48	20F
0005434551711	10615	1	1A
0005434551658	10615	2	1C
0005434551671	10615	3	1D
0005434551666	10615	4	1F
0005434551672	10615	5	2A
0005434551696	10615	6	2C
0005434558337	10615	7	2D
0005434558343	10615	8	2F
0005434551678	10615	9	3A
0005434551698	10615	10	3C
0005434554080	10615	11	3D
0005434551661	10615	12	3F
0005434551668	10615	13	4C
0005434551660	10615	14	4D
0005433181010	10615	15	4E
0005434551699	10615	16	4F
0005433181189	10615	17	5A
0005434551695	10615	18	5C
0005434551689	10615	19	5D
0005434551664	10615	20	5E
0005434551712	10615	21	5F
0005434551710	10615	22	6A
0005433181103	10615	23	6C
0005434551686	10615	24	6D
0005433181180	10615	25	6E
0005434551685	10615	26	6F
0005434558341	10615	27	7A
0005434551673	10615	28	7C
0005434551709	10615	29	7D
0005434551659	10615	30	7E
0005434551679	10615	31	7F
0005434551683	10615	32	8A
0005434551681	10615	33	8C
0005434551693	10615	34	8D
0005434558335	10615	35	8E
0005434551702	10615	36	8F
0005433181056	10615	37	9A
0005433181163	10615	38	9C
0005434551662	10615	39	9D
0005434551687	10615	40	9E
0005434551705	10615	41	9F
0005434551665	10615	42	10A
0005433181152	10615	43	10D
0005434558345	10615	44	10E
0005433181083	10615	45	10F
0005434551694	10615	46	11A
0005434551688	10615	47	11C
0005434551701	10615	48	11D
0005434551706	10615	49	11E
0005434551708	10615	50	11F
0005434551676	10615	51	12A
0005434558334	10615	52	12C
0005433181009	10615	53	12D
0005433181054	10615	54	12E
0005434554081	10615	55	12F
0005433181032	10615	56	13A
0005433181091	10615	57	13D
0005434558342	10615	58	13E
0005434551674	10615	59	13F
0005434551682	10615	60	14A
0005433181141	10615	61	14C
0005433181162	10615	62	14D
0005434558344	10615	63	14E
0005434551680	10615	64	15A
0005434551690	10615	65	15C
0005434551691	10615	66	15D
0005433181102	10615	67	15E
0005434558339	10615	68	15F
0005434551667	10615	69	16A
0005434558340	10615	70	16C
0005434551692	10615	71	16D
0005434551697	10615	72	16E
0005433180992	10615	73	16F
0005434551703	10615	74	17A
0005434551670	10615	75	17C
0005434551675	10615	76	17D
0005433180993	10615	77	17E
0005434551700	10615	78	17F
0005433181113	10615	79	18A
0005434551704	10615	80	18C
0005433181179	10615	81	18D
0005433181008	10615	82	18E
0005434558336	10615	83	18F
0005434551677	10615	84	19A
0005433181181	10615	85	19C
0005434551707	10615	86	19D
0005434551669	10615	87	19E
0005433181090	10615	88	19F
0005434558338	10615	89	20A
0005434551663	10615	90	20C
0005434551684	10615	91	20D
0005433181140	10615	92	20E
0005433181327	27687	1	1A
0005433181332	27687	2	2C
0005433181322	27687	3	4C
0005433181342	27687	4	4E
0005433181336	27687	5	5D
0005433181333	27687	6	5E
0005433181330	27687	7	8E
0005433181337	27687	8	10C
0005433181345	27687	9	10D
0005433181331	27687	10	10E
0005433181320	27687	11	11A
0005433181335	27687	12	11C
0005433181341	27687	13	11D
0005433181344	27687	14	11F
0005433181334	27687	15	12A
0005433181340	27687	16	14A
0005433181339	27687	17	15A
0005433181329	27687	18	15C
0005433181323	27687	19	15F
0005433181324	27687	20	16C
0005433181326	27687	21	16D
0005433181321	27687	22	16E
0005433181338	27687	23	18E
0005433181325	27687	24	18F
0005433181328	27687	25	19F
0005433181343	27687	26	20E
0005434551259	27688	1	1A
0005434558234	27688	2	1C
0005434551078	27688	3	1D
0005434551461	27688	4	1F
0005434551149	27688	5	2A
0005434554066	27688	6	2C
0005434551436	27688	7	2D
0005434551470	27688	8	2F
0005434551260	27688	9	3A
0005434551043	27688	10	3C
0005434551039	27688	11	3F
0005434551158	27688	12	4A
0005434551364	27688	13	4D
0005434551150	27688	14	4F
0005434551244	27688	15	5A
0005434551044	27688	16	5C
0005434551331	27688	17	5D
0005434551285	27688	18	5E
0005434551509	27688	19	6C
0005434551371	27688	20	6D
0005434551166	27688	21	6E
0005434551042	27688	22	6F
0005434551549	27688	23	7C
0005434551252	27688	24	7D
0005434551283	27688	25	7E
0005434551536	27688	26	8E
0005434551132	27688	27	8F
0005434551303	27688	28	9C
0005434551229	27688	29	9D
0005434551284	27688	30	9E
0005434551251	27688	31	10A
0005434551088	27688	32	10C
0005434551139	27688	33	10D
0005434551278	27688	34	11D
0005434551366	27688	35	11F
0005434551365	27688	36	12A
0005434558264	27688	37	12C
0005434551154	27688	38	12D
0005434551475	27688	39	12F
0005434551270	27688	40	13C
0005434551073	27688	41	13D
0005434551318	27688	42	13E
0005434551218	27688	43	13F
0005434551277	27688	44	14A
0005434551413	27688	45	14C
0005434551343	27688	46	14E
0005434551548	27688	47	14F
0005434551384	27688	48	15A
0005434551153	27688	49	15C
0005434551250	27688	50	15D
0005434558278	27688	51	15E
0005434551217	27688	52	15F
0005434551282	27688	53	16A
0005434551263	27688	54	16C
0005434551320	27688	55	16D
0005434551254	27688	56	16E
0005434551304	27688	57	16F
0005434558235	27688	58	17A
0005434551469	27688	59	17C
0005434551249	27688	60	17E
0005434551305	27688	61	17F
0005434551319	27688	62	18A
0005434551060	27688	63	18C
0005434551089	27688	64	18D
0005434551404	27688	65	18E
0005434551074	27688	66	19C
0005434551248	27688	67	19D
0005434551090	27688	68	19E
0005434551157	27688	69	19F
0005434551437	27688	70	20A
0005434558277	27688	71	20C
0005434551267	27688	72	20D
0005434551094	27688	73	20E
0005433459258	6134	1	1A
0005433459259	6134	2	1B
0005433459257	6134	3	2A
0005435254478	6134	4	3A
0005433459260	6134	5	4B
0005433459261	6134	6	5A
0005433459262	6134	7	5B
0005435254475	6134	8	6B
0005433459220	19303	1	2A
0005433459219	19303	2	3A
0005433459221	19303	3	3B
0005435254498	19303	4	4A
0005433459231	19303	5	4B
0005433459230	19303	6	5B
0005435254497	19303	7	6B
0005435682512	6713	1	1C
0005432136218	6713	2	1D
0005435437900	6713	3	1F
0005435438031	6713	4	2A
0005435630991	6713	5	2C
0005435438050	6713	6	2D
0005435682520	6713	7	2F
0005435438003	6713	8	3A
0005435682516	6713	9	3D
0005435682517	6713	10	4A
0005435437952	6713	11	4C
0005435221514	6713	12	4D
0005435217713	6713	13	4E
0005435438004	6713	14	4F
0005435437975	6713	15	5A
0005435661958	6713	16	5C
0005435217723	6713	17	5D
0005435682518	6713	18	5E
0005435682510	6713	19	5F
0005435438032	6713	20	6A
0005435682505	6713	21	6C
0005435220320	6713	22	6D
0005435682498	6713	23	6E
0005435682494	6713	24	6F
0005435438073	6713	25	7A
0005435682485	6713	26	7C
0005435661955	6713	27	7D
0005435682491	6713	28	7E
0005435437947	6713	29	7F
0005435437966	6713	30	8A
0005435438049	6713	31	8C
0005435682488	6713	32	8D
0005435437970	6713	33	8E
0005435438022	6713	34	8F
0005435437899	6713	35	9C
0005435437923	6713	36	9D
0005435682499	6713	37	9E
0005435682511	6713	38	9F
0005435682514	6713	39	10A
0005435438029	6713	40	10C
0005435682506	6713	41	10D
0005435682507	6713	42	10E
0005435437974	6713	43	10F
0005432136217	6713	44	11A
0005435630992	6713	45	11D
0005435437922	6713	46	11E
0005435630993	6713	47	11F
0005435682519	6713	48	12A
0005435438015	6713	49	12C
0005435437953	6713	50	12D
0005435661956	6713	51	12E
0005435438030	6713	52	12F
0005432136215	6713	53	13C
0005435221515	6713	54	13D
0005435682501	6713	55	13E
0005435682504	6713	56	13F
0005435438008	6713	57	14A
0005434828696	6713	58	14C
0005435438048	6713	59	14D
0005435661957	6713	60	14E
0005435682489	6713	61	14F
0005435438002	6713	62	15A
0005435682490	6713	63	15C
0005432136216	6713	64	15D
0005435682496	6713	65	15E
0005435682500	6713	66	15F
0005435682486	6713	67	16A
0005435437969	6713	68	16C
0005432136213	6713	69	16D
0005435682497	6713	70	16E
0005434828700	6713	71	16F
0005435437946	6713	72	17A
0005435438009	6713	73	17C
0005435682495	6713	74	17D
0005435682487	6713	75	17E
0005435682508	6713	76	17F
0005435682492	6713	77	18A
0005435438072	6713	78	18C
0005432136214	6713	79	18D
0005435217722	6713	80	18E
0005435682502	6713	81	18F
0005435437910	6713	82	19A
0005435682515	6713	83	19C
0005435682493	6713	84	19D
0005435661954	6713	85	19E
0005435682513	6713	86	19F
0005435682509	6713	87	20A
0005435437911	6713	88	20C
0005435682503	6713	89	20D
0005435220321	6713	90	20E
0005435438012	6713	91	20F
0005435682043	24575	1	1A
0005435682111	24575	2	1C
0005435661938	24575	3	1D
0005435219216	24575	4	1F
0005435438147	24575	5	2A
0005435630976	24575	6	2C
0005435438160	24575	7	2D
0005435630958	24575	8	2F
0005435682313	24575	9	3A
0005435630981	24575	10	3C
0005435682110	24575	11	3D
0005435682143	24575	12	3F
0005435682147	24575	13	4A
0005435438152	24575	14	4C
0005435682239	24575	15	4D
0005435682000	24575	16	4E
0005435682045	24575	17	4F
0005435438157	24575	18	5D
0005435438143	24575	19	5E
0005435438158	24575	20	5F
0005435438159	24575	21	6A
0005435682316	24575	22	6D
0005435438164	24575	23	6E
0005435630957	24575	24	6F
0005435682029	24575	25	7A
0005434828724	24575	26	7C
0005432533317	24575	27	7D
0005435438163	24575	28	7E
0005435219217	24575	29	7F
0005435438145	24575	30	8C
0005435630971	24575	31	8D
0005432533319	24575	32	8E
0005435220338	24575	33	8F
0005435438144	24575	34	9A
0005435682312	24575	35	9C
0005434828722	24575	36	9D
0005435438161	24575	37	9E
0005435220337	24575	38	9F
0005435682262	24575	39	10A
0005435219219	24575	40	10C
0005435682044	24575	41	10D
0005435438165	24575	42	10E
0005435438148	24575	43	10F
0005435630969	24575	44	11A
0005435219218	24575	45	11C
0005435682123	24575	46	11D
0005435630970	24575	47	11E
0005435682062	24575	48	11F
0005435682247	24575	49	12A
0005435438151	24575	50	12C
0005432305771	24575	51	12D
0005435438146	24575	52	12E
0005435682216	24575	53	12F
0005435438153	24575	54	13C
0005435682168	24575	55	13D
0005435682092	24575	56	13E
0005435438155	24575	57	13F
0005435682125	24575	58	14A
0005435682014	24575	59	14C
0005435682061	24575	60	14D
0005435682195	24575	61	14F
0005435682127	24575	62	15A
0005432305773	24575	63	15C
0005435682093	24575	64	15E
0005432305772	24575	65	15F
0005435438162	24575	66	16A
0005435682018	24575	67	16C
0005432533318	24575	68	16D
0005435438150	24575	69	16F
0005435682146	24575	70	17A
0005435682368	24575	71	17D
0005435682263	24575	72	17C
0005435682096	24575	73	17E
0005435220335	24575	74	17F
0005435438156	24575	75	18A
0005432305770	24575	76	18C
0005435682217	24575	77	18D
0005435438149	24575	78	18F
0005434828723	24575	79	19A
0005435682194	24575	80	19C
0005435682215	24575	81	19D
0005435682310	24575	82	19E
0005435438154	24575	83	19F
0005435219220	24575	84	20A
0005435220339	24575	85	20C
0005435220336	24575	86	20D
0005435682153	24575	87	20E
0005435682219	24575	88	20F
0005435106008	11559	1	1C
0005435106010	11559	2	1F
0005435126702	11559	3	2A
0005435126694	11559	4	2D
0005435126706	11559	5	2F
0005435126722	11559	6	3C
0005435106009	11559	7	3D
0005435126697	11559	8	4A
0005435126716	11559	9	5D
0005435126700	11559	10	5E
0005435126709	11559	11	5F
0005435126714	11559	12	6A
0005435126731	11559	13	6C
0005435126690	11559	14	6D
0005435126730	11559	15	6E
0005435126703	11559	16	7A
0005435126701	11559	17	7E
0005435126717	11559	18	7F
0005435126718	11559	19	8A
0005435106007	11559	20	8C
0005435126696	11559	21	8E
0005435126726	11559	22	8F
0005435126715	11559	23	9A
0005435126719	11559	24	10D
0005435126711	11559	25	10F
0005435126708	11559	26	11C
0005435126721	11559	27	11E
0005435126724	11559	28	12C
0005435126691	11559	29	12D
0005435126727	11559	30	13D
0005435126712	11559	31	13F
0005435126698	11559	32	14C
0005435126704	11559	33	14D
0005435126699	11559	34	14E
0005435126689	11559	35	14F
0005435126705	11559	36	15A
0005435126692	11559	37	15C
0005435126695	11559	38	15F
0005435126693	11559	39	16F
0005435126725	11559	40	17F
0005435126707	11559	41	18A
0005435126723	11559	42	18D
0005435126688	11559	43	18E
0005435126713	11559	44	18F
0005435126710	11559	45	19A
0005435126729	11559	46	19E
0005435126728	11559	47	19F
0005435126720	11559	48	20E
0005435126481	31863	1	1A
0005435126470	31863	2	1C
0005435126515	31863	3	1F
0005435126409	31863	4	1D
0005435126446	31863	5	2D
0005435126529	31863	6	2C
0005435126449	31863	7	3A
0005435126445	31863	8	3C
0005435126441	31863	9	3D
0005435105993	31863	10	4D
0005435558111	31863	11	5C
0005435126478	31863	12	5D
0005435105988	31863	13	5F
0005435126389	31863	14	6C
0005435126303	31863	15	6D
0005435126489	31863	16	6E
0005435126380	31863	17	8A
0005435126408	31863	18	8D
0005435126528	31863	19	8F
0005435126410	31863	20	9D
0005435126427	31863	21	9E
0005435126358	31863	22	10A
0005435126432	31863	23	10D
0005435126354	31863	24	10E
0005435126433	31863	25	11A
0005435126337	31863	26	11E
0005435126336	31863	27	11F
0005435098544	31863	28	12F
0005435126331	31863	29	13C
0005435126547	31863	30	13E
0005435126450	31863	31	13F
0005435126527	31863	32	14A
0005435126295	31863	33	14D
0005435126471	31863	34	14E
0005435105992	31863	35	14F
0005435126472	31863	36	15C
0005435126428	31863	37	15E
0005435126488	31863	38	16C
0005435126388	31863	39	17A
0005435126270	31863	40	17D
0005435126332	31863	41	17F
0005435126364	31863	42	18A
0005435126451	31863	43	18C
0005435126363	31863	44	18F
0005435126392	31863	45	19A
0005435126448	31863	46	19C
0005435126271	31863	47	19E
0005435105994	31863	48	19F
0005435126359	31863	49	20A
0005435732284	13522	1	1A
0005433398502	13522	2	1F
0005435732300	13522	3	2A
0005433398511	13522	4	2C
0005433398487	13522	5	2D
0005433398517	13522	6	2F
0005433398503	13522	7	3A
0005433398500	13522	8	4C
0005433398496	13522	9	4E
0005433398493	13522	10	4F
0005433398478	13522	11	5A
0005433398480	13522	12	5C
0005435732306	13522	13	5D
0005435732357	13522	14	5E
0005435732283	13522	15	5F
0005433398485	13522	16	6C
0005433398521	13522	17	6D
0005433398518	13522	18	6F
0005433398498	13522	19	7D
0005433398473	13522	20	7E
0005433398491	13522	21	7F
0005433398516	13522	22	8D
0005435732298	13522	23	8E
0005433398488	13522	24	8F
0005435732346	13522	25	9D
0005433398482	13522	26	9E
0005433398522	13522	27	9F
0005433398513	13522	28	10A
0005435732320	13522	29	10C
0005433398508	13522	30	10D
0005433398477	13522	31	10F
0005433398474	13522	32	11A
0005433398507	13522	33	11C
0005433398520	13522	34	11D
0005435732336	13522	35	11F
0005435732332	13522	36	11E
0005433398481	13522	37	12E
0005435732369	13522	38	12F
0005433398486	13522	39	13A
0005433398519	13522	40	13C
0005433398515	13522	41	13D
0005435732329	13522	42	13F
0005433398497	13522	43	14A
0005433398476	13522	44	14E
0005433398514	13522	45	14F
0005433398484	13522	46	15C
0005433398499	13522	47	15E
0005433398509	13522	48	15F
0005433398512	13522	49	16A
0005433398490	13522	50	16C
0005433398510	13522	51	16D
0005433398506	13522	52	16E
0005433398479	13522	53	17C
0005433398504	13522	54	17D
0005433398475	13522	55	17F
0005433398494	13522	56	18A
0005433398489	13522	57	18C
0005433398471	13522	58	18D
0005435732305	13522	59	18E
0005435732360	13522	60	18F
0005433398472	13522	61	19A
0005433398483	13522	62	19D
0005433398501	13522	63	19E
0005433398505	13522	64	19F
0005433398495	13522	65	20D
0005435732342	13522	66	20E
0005433398492	13522	67	20F
0005435732453	19388	1	1C
0005435732459	19388	2	2C
0005432297301	19388	3	2D
0005433398057	19388	4	2F
0005433398256	19388	5	3A
0005433397984	19388	6	3D
0005433398167	19388	7	3F
0005433397931	19388	8	4A
0005433397972	19388	9	4E
0005433397988	19388	10	4F
0005433397971	19388	11	5C
0005435732455	19388	12	5E
0005433398079	19388	13	6A
0005433397999	19388	14	6D
0005433398087	19388	15	6E
0005433398119	19388	16	7A
0005433398198	19388	17	7C
0005435732447	19388	18	7F
0005433398030	19388	19	8A
0005435732449	19388	20	8C
0005435732452	19388	21	8E
0005435732443	19388	22	8F
0005433397985	19388	23	9A
0005435732442	19388	24	9C
0005433398084	19388	25	9E
0005435732456	19388	26	9F
0005435732454	19388	27	10D
0005433398268	19388	28	10E
0005432297300	19388	29	11A
0005433398059	19388	30	11C
0005433398215	19388	31	11D
0005435732450	19388	32	11E
0005433397998	19388	33	11F
0005433397976	19388	34	12A
0005433398174	19388	35	12F
0005432297302	19388	36	13A
0005433398156	19388	37	13E
0005433398048	19388	38	13F
0005433397863	19388	39	14C
0005435732448	19388	40	14E
0005433398180	19388	41	15A
0005433397932	19388	42	15C
0005435732446	19388	43	15D
0005433397960	19388	44	16C
0005433398207	19388	45	16D
0005435732451	19388	46	16E
0005433397864	19388	47	16F
0005433398060	19388	48	17A
0005435732445	19388	49	17D
0005435732458	19388	50	17F
0005435732457	19388	51	18A
0005433398104	19388	52	18C
0005435732460	19388	53	18D
0005435732444	19388	54	18E
0005433397970	19388	55	18F
0005433398085	19388	56	19A
0005433397907	19388	57	19E
0005433398214	19388	58	20C
0005433398095	19388	59	20D
0005435732441	19388	60	20E
0005435925423	13188	1	1A
0005435069214	13188	2	1C
0005435068879	13188	3	1D
0005435069067	13188	4	1F
0005435069004	13188	5	2A
0005435069002	13188	6	2D
0005435069072	13188	7	2C
0005435925422	13188	8	3A
0005435069098	13188	9	3C
0005435069013	13188	10	3D
0005435069043	13188	11	4A
0005435069230	13188	12	4C
0005435069163	13188	13	4D
0005435069061	13188	14	4E
0005435068931	13188	15	4F
0005435925412	13188	16	5A
0005435069077	13188	17	5D
0005435069093	13188	18	5E
0005435069076	13188	19	5F
0005435068964	13188	20	6A
0005435069119	13188	21	6C
0005435069147	13188	22	6D
0005435069220	13188	23	6E
0005435069236	13188	24	6F
0005435069039	13188	25	7C
0005435069229	13188	26	7D
0005435069162	13188	27	7E
0005435068763	13188	28	8C
0005435069023	13188	29	8D
0005435068947	13188	30	8F
0005435069033	13188	31	9A
0005435069088	13188	32	9C
0005435068759	13188	33	9E
0005435925418	13188	34	9F
0005435069224	13188	35	10A
0005435069040	13188	36	10E
0005435068975	13188	37	10F
0005435069066	13188	38	11A
0005435068957	13188	39	11D
0005435068901	13188	40	11E
0005435069047	13188	41	12A
0005435069083	13188	42	12C
0005435069099	13188	43	12E
0005435068915	13188	44	12F
0005435925413	13188	45	13A
0005435068952	13188	46	13C
0005435925417	13188	47	13E
0005435069127	13188	48	13F
0005435925419	13188	49	14A
0005435069189	13188	50	14D
0005435069048	13188	51	14F
0005435069286	13188	52	15A
0005435069183	13188	53	15C
0005435925416	13188	54	15D
0005435069022	13188	55	15F
0005435068762	13188	56	16A
0005435069058	13188	57	16E
0005435068951	13188	58	16F
0005435068716	13188	59	17A
0005435925421	13188	60	17C
0005435068867	13188	61	17D
0005435069068	13188	62	17E
0005435925415	13188	63	17F
0005435069021	13188	64	18C
0005435068896	13188	65	18D
0005435068958	13188	66	18E
0005435069215	13188	67	18F
0005435068715	13188	68	19A
0005435925420	13188	69	19C
0005435069223	13188	70	19D
0005435068930	13188	71	19E
0005435069221	13188	72	19F
0005435925414	13188	73	20C
0005435068948	13188	74	20D
0005435068963	13188	75	20E
0005435068914	13188	76	20F
0005435069521	15472	1	1D
0005435925332	15472	2	2D
0005435069493	15472	3	2F
0005435069533	15472	4	3C
0005435925309	15472	5	3D
0005435925266	15472	6	4C
0005435069522	15472	7	4D
0005435069485	15472	8	4E
0005435069519	15472	9	5A
0005435069515	15472	10	5C
0005435069510	15472	11	5E
0005435069500	15472	12	5F
0005435069501	15472	13	6A
0005435069507	15472	14	6C
0005435925267	15472	15	6E
0005435069527	15472	16	6F
0005435069494	15472	17	7A
0005435069509	15472	18	7C
0005435069490	15472	19	7D
0005435069525	15472	20	8A
0005435069505	15472	21	8E
0005435069526	15472	22	8F
0005435925291	15472	23	9A
0005435069516	15472	24	9C
0005435069529	15472	25	9E
0005435069514	15472	26	9F
0005435069535	15472	27	10A
0005435069517	15472	28	10D
0005435069487	15472	29	10E
0005435069496	15472	30	10F
0005435069531	15472	31	11A
0005435069484	15472	32	11C
0005435069488	15472	33	11D
0005435925276	15472	34	12A
0005435069532	15472	35	12C
0005435925308	15472	36	12E
0005435069489	15472	37	13A
0005435925226	15472	38	13E
0005435069520	15472	39	13F
0005435069504	15472	40	14A
0005435069528	15472	41	14C
0005435925333	15472	42	14D
0005435925303	15472	43	14E
0005435069495	15472	44	14F
0005435069518	15472	45	15C
0005435925292	15472	46	15D
0005435069530	15472	47	15E
0005435069513	15472	48	15F
0005435069534	15472	49	16A
0005435069506	15472	50	16D
0005435069486	15472	51	16E
0005435069512	15472	52	16F
0005435069502	15472	53	17C
0005435069503	15472	54	17D
0005435069498	15472	55	17F
0005435069497	15472	56	18A
0005435925275	15472	57	18C
0005435069499	15472	58	18E
0005435069492	15472	59	19A
0005435069491	15472	60	19C
0005435069483	15472	61	19D
0005435069524	15472	62	19E
0005435069511	15472	63	19F
0005435069523	15472	64	20A
0005435069508	15472	65	20C
0005435925257	15472	66	20D
0005435925274	15472	67	20E
0005434756425	10734	1	1A
0005434756419	10734	2	1C
0005434756369	10734	3	1D
0005434756297	10734	4	1F
0005434756361	10734	5	2C
0005434214941	10734	6	2D
0005434214940	10734	7	2F
0005434214977	10734	8	3C
0005434756427	10734	9	3D
0005434756323	10734	10	3F
0005434756368	10734	11	4A
0005434756329	10734	12	4C
0005434756435	10734	13	4D
0005434214961	10734	14	4E
0005434214978	10734	15	4F
0005434214959	10734	16	5C
0005434214945	10734	17	5E
0005434756398	10734	18	5F
0005434756298	10734	19	6A
0005434214976	10734	20	6C
0005434214943	10734	21	6D
0005434756488	10734	22	6E
0005434214956	10734	23	6F
0005434214939	10734	24	7A
0005434756263	10734	25	7C
0005434214969	10734	26	7D
0005434214974	10734	27	7F
0005434214952	10734	28	8A
0005434214975	10734	29	8D
0005434214946	10734	30	8E
0005434214967	10734	31	8F
0005434756446	10734	32	9A
0005434756376	10734	33	9C
0005434214972	10734	34	9D
0005434214964	10734	35	9E
0005434756337	10734	36	9F
0005434756436	10734	37	10A
0005434756372	10734	38	10C
0005434214942	10734	39	10D
0005434214947	10734	40	10E
0005434214966	10734	41	11A
0005434214944	10734	42	11C
0005434214973	10734	43	11D
0005434214958	10734	44	11E
0005434756371	10734	45	11F
0005434756442	10734	46	12A
0005434756414	10734	47	12C
0005434756377	10734	48	12E
0005434214954	10734	49	12F
0005434756460	10734	50	13A
0005434756417	10734	51	13D
0005434756438	10734	52	13E
0005434214951	10734	53	13F
0005434214957	10734	54	14A
0005434214980	10734	55	14C
0005434214955	10734	56	14D
0005434756399	10734	57	14F
0005434214963	10734	58	15A
0005434756405	10734	59	15C
0005434214960	10734	60	15D
0005434756359	10734	61	15F
0005434214982	10734	62	16A
0005434756418	10734	63	16C
0005434214948	10734	64	16D
0005434756393	10734	65	16E
0005434214953	10734	66	16F
0005434214950	10734	67	17C
0005434214981	10734	68	17D
0005434756437	10734	69	17F
0005434214970	10734	70	18A
0005434214968	10734	71	18C
0005434214979	10734	72	18D
0005434756426	10734	73	18E
0005434756367	10734	74	18F
0005434214949	10734	75	19A
0005434214962	10734	76	19C
0005434214971	10734	77	19D
0005434756275	10734	78	19E
0005434756274	10734	79	19F
0005434214938	10734	80	20A
0005434214965	10734	81	20C
0005434756406	10734	82	20D
0005434756354	10734	83	20F
0005434214227	28696	1	1A
0005434756766	28696	2	1C
0005434214561	28696	3	1D
0005434756783	28696	4	1F
0005434756769	28696	5	2A
0005434214377	28696	6	2C
0005434214515	28696	7	2D
0005434214421	28696	8	2F
0005434756761	28696	9	3A
0005434214366	28696	10	3C
0005434756750	28696	11	3D
0005434756784	28696	12	3F
0005434214443	28696	13	4A
0005434214607	28696	14	4C
0005434756753	28696	15	4D
0005434214470	28696	16	4F
0005434214479	28696	17	5A
0005434756778	28696	18	5C
0005434214555	28696	19	5D
0005434756781	28696	20	5E
0005434214320	28696	21	5F
0005434756763	28696	22	6A
0005434756780	28696	23	6C
0005434214298	28696	24	6D
0005434756777	28696	25	6E
0005434214423	28696	26	6F
0005434214333	28696	27	7A
0005434214327	28696	28	7C
0005434214539	28696	29	7E
0005434214326	28696	30	7D
0005434756758	28696	31	7F
0005434214512	28696	32	8A
0005434214379	28696	33	8C
0005434756754	28696	34	8D
0005434214355	28696	35	8E
0005434756752	28696	36	8F
0005434756749	28696	37	9A
0005434756779	28696	38	9C
0005434756770	28696	39	9D
0005434214612	28696	40	9E
0005434214376	28696	41	9F
0005434756768	28696	42	10A
0005434214517	28696	43	10C
0005434756751	28696	44	10D
0005434214680	28696	45	10E
0005434214627	28696	46	10F
0005434214332	28696	47	11A
0005434214556	28696	48	11C
0005434214354	28696	49	11D
0005434214594	28696	50	11E
0005434214426	28696	51	11F
0005434214442	28696	52	12A
0005434756762	28696	53	12C
0005434214558	28696	54	12D
0005434214474	28696	55	12E
0005434756773	28696	56	12F
0005434214536	28696	57	13A
0005434214634	28696	58	13C
0005434214480	28696	59	13D
0005434214420	28696	60	13E
0005434756759	28696	61	13F
0005434756760	28696	62	14A
0005434214598	28696	63	14C
0005434756774	28696	64	14D
0005434756756	28696	65	14E
0005434214478	28696	66	14F
0005434756764	28696	67	15A
0005434756755	28696	68	15C
0005434756775	28696	69	15D
0005434756785	28696	70	15E
0005434756786	28696	71	15F
0005434214476	28696	72	16A
0005434214489	28696	73	16C
0005434214214	28696	74	16D
0005434756776	28696	75	16E
0005434756765	28696	76	16F
0005434214473	28696	77	17A
0005434756782	28696	78	17C
0005434214633	28696	79	17D
0005434214398	28696	80	17E
0005434214433	28696	81	17F
0005434214352	28696	82	18A
0005434756772	28696	83	18C
0005434214445	28696	84	18D
0005434756767	28696	85	18E
0005434214397	28696	86	18F
0005434756747	28696	87	19A
0005434756748	28696	88	19C
0005434214533	28696	89	19D
0005434756771	28696	90	19E
0005434214537	28696	91	19F
0005434214353	28696	92	20A
0005434214599	28696	93	20C
0005434214554	28696	94	20E
0005434756757	28696	95	20F
0005435007251	5448	1	1A
0005435007231	5448	2	1C
0005434229474	5448	3	1D
0005435040373	5448	4	2A
0005435040338	5448	5	1F
0005435040347	5448	6	2D
0005435040327	5448	7	2C
0005435040356	5448	8	3A
0005435040377	5448	9	2F
0005435040361	5448	10	3C
0005435007244	5448	11	3F
0005435040352	5448	12	3D
0005435040332	5448	13	4A
0005435040379	5448	14	4C
0005435007245	5448	15	4B
0005435040381	5448	16	4D
0005435007241	5448	17	4E
0005435007235	5448	18	4F
0005435040355	5448	19	5B
0005435007242	5448	20	5A
0005434229390	5448	21	5C
0005435040363	5448	22	5D
0005435040342	5448	23	5E
0005435040350	5448	24	6A
0005435040358	5448	25	5F
0005435040346	5448	26	6C
0005435007249	5448	27	6B
0005432125523	5448	28	6D
0005435040320	5448	29	6F
0005435007229	5448	30	6E
0005434229242	5448	31	7A
0005435040382	5448	32	7C
0005435007247	5448	33	7B
0005434229420	5448	34	7F
0005435040344	5448	35	7E
0005435007232	5448	36	8A
0005434229370	5448	37	8B
0005434229308	5448	38	8C
0005434229320	5448	39	8E
0005434229241	5448	40	8D
0005435040370	5448	41	9A
0005435040362	5448	42	8F
0005435040348	5448	43	9B
0005435040323	5448	44	9D
0005435040371	5448	45	9C
0005435043292	5448	46	9E
0005435040324	5448	47	9F
0005435040353	5448	48	10B
0005435040372	5448	49	10C
0005435040374	5448	50	10E
0005434229264	5448	51	10D
0005435040340	5448	52	11A
0005435040354	5448	53	11C
0005434229409	5448	54	11B
0005435040345	5448	55	11E
0005435007252	5448	56	11F
0005435040369	5448	57	12B
0005435040321	5448	58	12A
0005435040349	5448	59	12D
0005434229294	5448	60	12C
0005435040378	5448	61	12E
0005435040328	5448	62	12F
0005435040318	5448	63	13A
0005434229381	5448	64	13C
0005434229382	5448	65	13B
0005435007239	5448	66	13F
0005435040322	5448	67	13E
0005435040360	5448	68	14A
0005435040375	5448	69	14C
0005432125517	5448	70	14B
0005435007248	5448	71	14D
0005435007237	5448	72	14E
0005435042877	5448	73	14F
0005435040339	5448	74	15A
0005435007238	5448	75	15C
0005432125520	5448	76	15B
0005435040365	5448	77	15D
0005435040343	5448	78	15E
0005434229223	5448	79	15F
0005435040319	5448	80	16B
0005435040331	5448	81	16A
0005435007250	5448	82	16D
0005435040357	5448	83	16C
0005435040334	5448	84	16F
0005434229450	5448	85	16E
0005435040326	5448	86	17A
0005435040376	5448	87	17B
0005435040337	5448	88	17D
0005435040329	5448	89	17C
0005432125516	5448	90	17F
0005435007234	5448	91	17E
0005435040380	5448	92	18A
0005435040333	5448	93	18B
0005435040325	5448	94	18C
0005435040366	5448	95	18D
0005435042878	5448	96	18F
0005435007243	5448	97	18E
0005434229303	5448	98	19A
0005435007246	5448	99	19C
0005435007227	5448	100	19B
0005435007240	5448	101	19E
0005432125519	5448	102	19F
0005435007236	5448	103	20A
0005435007228	5448	104	20B
0005432125522	5448	105	20D
0005435040359	5448	106	20C
0005435040341	5448	107	20E
0005435040368	5448	108	20F
0005435007233	5448	109	21B
0005435040367	5448	110	21A
0005434229319	5448	111	21C
0005435040335	5448	112	21D
0005435040364	5448	113	21E
0005432125518	5448	114	22A
0005435040330	5448	115	21F
0005435042876	5448	116	22B
0005432125521	5448	117	22C
0005435042875	5448	118	22D
0005434229371	5448	119	22E
0005432125515	5448	120	23A
0005434229499	5448	121	22F
0005435040336	5448	122	23B
0005435007230	5448	123	23C
0005434229224	5448	124	23E
0005434229293	5448	125	23D
0005435040351	5448	126	23F
0005434229576	12954	1	1C
0005434229581	12954	2	1A
0005435039938	12954	3	1F
0005435007069	12954	4	1D
0005435039862	12954	5	2C
0005434229577	12954	6	2A
0005435039764	12954	7	2D
0005435007038	12954	8	2F
0005435007071	12954	9	3C
0005435039709	12954	10	3A
0005435039949	12954	11	3D
0005435007068	12954	12	3F
0005434229588	12954	13	4A
0005435039933	12954	14	4C
0005432304434	12954	15	4B
0005435039675	12954	16	4D
0005435039674	12954	17	4F
0005434229582	12954	18	4E
0005435039684	12954	19	5B
0005435039634	12954	20	5A
0005435039894	12954	21	5C
0005435039729	12954	22	5D
0005435039677	12954	23	5E
0005435039944	12954	24	5F
0005435039515	12954	25	6B
0005435006983	12954	26	6A
0005435006981	12954	27	6C
0005435007125	12954	28	6D
0005435007028	12954	29	6F
0005435040064	12954	30	6E
0005434229589	12954	31	7A
0005432304436	12954	32	7C
0005434229578	12954	33	7B
0005435007029	12954	34	7D
0005435039474	12954	35	7E
0005435039873	12954	36	8A
0005435039611	12954	37	7F
0005435007039	12954	38	8B
0005434229568	12954	39	8C
0005435039893	12954	40	8D
0005435039682	12954	41	8F
0005435039992	12954	42	8E
0005435039623	12954	43	9A
0005434229584	12954	44	9B
0005435006970	12954	45	9D
0005434229587	12954	46	9C
0005434229580	12954	47	9E
0005435039782	12954	48	9F
0005435039806	12954	49	10B
0005435039932	12954	50	10C
0005435040070	12954	51	10E
0005435040022	12954	52	10D
0005435040063	12954	53	11A
0005434229571	12954	54	11B
0005434229570	12954	55	11D
0005435039807	12954	56	11C
0005435039553	12954	57	11E
0005435039681	12954	58	12A
0005435039763	12954	59	12C
0005435039845	12954	60	12B
0005435039904	12954	61	12D
0005435007072	12954	62	12E
0005435039615	12954	63	12F
0005435040080	12954	64	13A
0005434229572	12954	65	13C
0005435039762	12954	66	13B
0005435039937	12954	67	13E
0005435039728	12954	68	13D
0005434229569	12954	69	13F
0005435007030	12954	70	14B
0005435007037	12954	71	14A
0005435039750	12954	72	14D
0005435040069	12954	73	14C
0005435039554	12954	74	14F
0005435007014	12954	75	14E
0005435039895	12954	76	15A
0005435039614	12954	77	15B
0005432304433	12954	78	15C
0005435039836	12954	79	15D
0005432304432	12954	80	15F
0005435006982	12954	81	15E
0005434229567	12954	82	16B
0005432304435	12954	83	16A
0005435039759	12954	84	16C
0005435039905	12954	85	16E
0005434229574	12954	86	16D
0005435007136	12954	87	16F
0005435040024	12954	88	17A
0005435007079	12954	89	17B
0005435039475	12954	90	17D
0005435040023	12954	91	17C
0005434229573	12954	92	17F
0005435007049	12954	93	17E
0005435039843	12954	94	18A
0005435039900	12954	95	18B
0005435039758	12954	96	18C
0005435007048	12954	97	18D
0005434229590	12954	98	18F
0005435007080	12954	99	18E
0005434229585	12954	100	19A
0005435007091	12954	101	19B
0005435007027	12954	102	19C
0005435039278	12954	103	19E
0005435007070	12954	104	19D
0005435039965	12954	105	20A
0005435039984	12954	106	20C
0005434229586	12954	107	20B
0005434229575	12954	108	20E
0005435007015	12954	109	20D
0005435039844	12954	110	21A
0005435039746	12954	111	20F
0005435007135	12954	112	21C
0005434229579	12954	113	21B
0005435006987	12954	114	21D
0005435039891	12954	115	21E
0005434229583	12954	116	21F
0005435007050	12954	117	22A
0005435039827	12954	118	22C
0005435007032	12954	119	22B
0005435007047	12954	120	22D
0005435039504	12954	121	22E
0005435007111	12954	122	23A
0005435039736	12954	123	23B
0005435039899	12954	124	23C
0005435039964	12954	125	23D
0005435039745	12954	126	23F
0005435039781	12954	127	23E
0005434411815	14853	1	1A
0005435902659	14853	2	1C
0005434426855	14853	3	1D
0005434426839	14853	4	1F
0005435902714	14853	5	2C
0005434426853	14853	6	2D
0005432188635	14853	7	2F
0005434426862	14853	8	3A
0005434426844	14853	9	3C
0005434426858	14853	10	3D
0005434426843	14853	11	4E
0005435554197	14853	12	5A
0005434426851	14853	13	5C
0005434426856	14853	14	5D
0005435902715	14853	15	5F
0005432188634	14853	16	6A
0005434426847	14853	17	6D
0005432188636	14853	18	6E
0005435902647	14853	19	6F
0005434426849	14853	20	7A
0005435902781	14853	21	7C
0005434426865	14853	22	7E
0005435902593	14853	23	8A
0005434426867	14853	24	8C
0005434426842	14853	25	8D
0005435902730	14853	26	8F
0005434426864	14853	27	9A
0005435902690	14853	28	9C
0005434411814	14853	29	9E
0005434426845	14853	30	10D
0005435554189	14853	31	10F
0005435902738	14853	32	11A
0005434426848	14853	33	11C
0005434426868	14853	34	11D
0005434426854	14853	35	11E
0005434426857	14853	36	11F
0005434426846	14853	37	12C
0005434426850	14853	38	12D
0005435902716	14853	39	12E
0005434426852	14853	40	12F
0005435902707	14853	41	13A
0005434426841	14853	42	13C
0005432188633	14853	43	13D
0005434426838	14853	44	13E
0005434426861	14853	45	13F
0005434426863	14853	46	14A
0005435554196	14853	47	14E
0005434426866	14853	48	15A
0005434426869	14853	49	15D
0005435902733	14853	50	15E
0005434426860	14853	51	16E
0005435554198	14853	52	16F
0005434411817	14853	53	17A
0005434426840	14853	54	17C
0005434411816	14853	55	17D
0005435902592	14853	56	17F
0005434411813	14853	57	18A
0005435902731	14853	58	18E
0005434426859	14853	59	19D
0005435902696	14853	60	19F
0005435902688	14853	61	20A
0005434411812	14853	62	20F
0005434426543	20206	1	1A
0005434426648	20206	2	1C
0005434426561	20206	3	1D
0005435902867	20206	4	1F
0005435902869	20206	5	2F
0005434426692	20206	6	3A
0005435902868	20206	7	3D
0005435554234	20206	8	4C
0005435554235	20206	9	4D
0005434426496	20206	10	4F
0005432059522	20206	11	5A
0005434411775	20206	12	5D
0005434426434	20206	13	5E
0005434426627	20206	14	6A
0005435902864	20206	15	6C
0005435902859	20206	16	6D
0005434426527	20206	17	7A
0005434426497	20206	18	7D
0005435902872	20206	19	8A
0005434411771	20206	20	8D
0005434426660	20206	21	8E
0005435554232	20206	22	8F
0005434426584	20206	23	9A
0005434426691	20206	24	9E
0005434426647	20206	25	9F
0005435902863	20206	26	10A
0005434426671	20206	27	10C
0005434426694	20206	28	10E
0005434426661	20206	29	10F
0005434426664	20206	30	11A
0005434426659	20206	31	11C
0005435902866	20206	32	11E
0005434426560	20206	33	11F
0005435902861	20206	34	12A
0005434426544	20206	35	12D
0005434426658	20206	36	12E
0005434411802	20206	37	13A
0005434426540	20206	38	13C
0005435902874	20206	39	14A
0005434426665	20206	40	14C
0005435902871	20206	41	14F
0005435902865	20206	42	14E
0005435902873	20206	43	15A
0005434426714	20206	44	15D
0005434426599	20206	45	15E
0005434426624	20206	46	16A
0005435902870	20206	47	16C
0005434426605	20206	48	16D
0005434426662	20206	49	17A
0005434426607	20206	50	16F
0005435554231	20206	51	17D
0005435902875	20206	52	17F
0005435902876	20206	53	18A
0005435902860	20206	54	18C
0005434426578	20206	55	18D
0005435902858	20206	56	18F
0005434426723	20206	57	19A
0005435554233	20206	58	19D
0005434426539	20206	59	19E
0005432059523	20206	60	19F
0005434411803	20206	61	20A
0005434426693	20206	62	20E
0005435902862	20206	63	20F
0005433434679	26503	1	1A
0005435982700	26503	2	1C
0005435982681	26503	3	1D
0005435982677	26503	4	1F
0005434273076	26503	5	2A
0005435982674	26503	6	2C
0005434273077	26503	7	2D
0005435982698	26503	8	2F
0005434270207	26503	9	3A
0005435982710	26503	10	3C
0005432300310	26503	11	3D
0005435982699	26503	12	4A
0005435982695	26503	13	4C
0005432300312	26503	14	4E
0005434270206	26503	15	4F
0005433434705	26503	16	5A
0005433434695	26503	17	5C
0005435982693	26503	18	5E
0005435982692	26503	19	5F
0005433434584	26503	20	6A
0005433434670	26503	21	6C
0005433434708	26503	22	6D
0005435982709	26503	23	6E
0005435982691	26503	24	6F
0005435982689	26503	25	7A
0005433434704	26503	26	7C
0005435982702	26503	27	7D
0005435982685	26503	28	7E
0005433434701	26503	29	7F
0005435982694	26503	30	8A
0005435982697	26503	31	8C
0005434273080	26503	32	8D
0005433434693	26503	33	8E
0005435982679	26503	34	8F
0005433434678	26503	35	9A
0005433434604	26503	36	9C
0005435982706	26503	37	9D
0005433434613	26503	38	9E
0005435982711	26503	39	9F
0005435982707	26503	40	10A
0005433434710	26503	41	10C
0005435982696	26503	42	10D
0005432300313	26503	43	10E
0005435982665	26503	44	10F
0005435982714	26503	45	11A
0005435982683	26503	46	11C
0005433434711	26503	47	11D
0005435982680	26503	48	11F
0005435982673	26503	49	12A
0005435982715	26503	50	12C
0005433434748	26503	51	12D
0005433434605	26503	52	12E
0005433434668	26503	53	12F
0005435982666	26503	54	13A
0005435982704	26503	55	13C
0005435982668	26503	56	13D
0005435982703	26503	57	13E
0005435982713	26503	58	13F
0005435982687	26503	59	14A
0005433434687	26503	60	14C
0005435982686	26503	61	14D
0005433434692	26503	62	14E
0005435982708	26503	63	14F
0005435982705	26503	64	15A
0005434273075	26503	65	15C
0005432300314	26503	66	15D
0005433434694	26503	67	15F
0005433434543	26503	68	16A
0005435982712	26503	69	16C
0005433434612	26503	70	16D
0005435982672	26503	71	16E
0005435982682	26503	72	16F
0005435982716	26503	73	17A
0005435982676	26503	74	17C
0005435982684	26503	75	17D
0005433434770	26503	76	17E
0005435982688	26503	77	17F
0005435982671	26503	78	18A
0005435982690	26503	79	18C
0005433434724	26503	80	18D
0005432300315	26503	81	18E
0005435982701	26503	82	18F
0005433434761	26503	83	19A
0005435982669	26503	84	19C
0005435982675	26503	85	19D
0005435982670	26503	86	19E
0005433434707	26503	87	20A
0005433434675	26503	88	19F
0005435982667	26503	89	20C
0005432300311	26503	90	20D
0005435982678	26503	91	20E
0005432300309	26503	92	20F
0005435982106	26687	1	1A
0005433434953	26687	2	1C
0005435982436	26687	3	1D
0005435982445	26687	4	1F
0005435982375	26687	5	2C
0005435982201	26687	6	2D
0005435982143	26687	7	2F
0005435982219	26687	8	3A
0005432051157	26687	9	3C
0005434269124	26687	10	3D
0005435982202	26687	11	4A
0005434270225	26687	12	4C
0005432051158	26687	13	4D
0005435982298	26687	14	4E
0005435982139	26687	15	4F
0005435982444	26687	16	5A
0005434271331	26687	17	5C
0005435982250	26687	18	5D
0005433434929	26687	19	5E
0005435982200	26687	20	5F
0005435982209	26687	21	6A
0005435982249	26687	22	6C
0005433434956	26687	23	6D
0005433434930	26687	24	6E
0005433434937	26687	25	6F
0005435982224	26687	26	7A
0005435982348	26687	27	7C
0005434269123	26687	28	7D
0005433434945	26687	29	7E
0005433434950	26687	30	7F
0005435982150	26687	31	8A
0005433434939	26687	32	8C
0005435982199	26687	33	8D
0005435982244	26687	34	9A
0005435982355	26687	35	9C
0005435982318	26687	36	9D
0005435982160	26687	37	9E
0005435982374	26687	38	9F
0005433434933	26687	39	10A
0005433434940	26687	40	10C
0005435982319	26687	41	10E
0005435982263	26687	42	10F
0005433434941	26687	43	11A
0005435982303	26687	44	11C
0005434269122	26687	45	11E
0005435982434	26687	46	11F
0005433434936	26687	47	12A
0005435982060	26687	48	12C
0005435982210	26687	49	12D
0005435982354	26687	50	12E
0005435982220	26687	51	12F
0005433434955	26687	52	13A
0005433434943	26687	53	13C
0005433434947	26687	54	13D
0005435982385	26687	55	13E
0005433434932	26687	56	13F
0005432051156	26687	57	14A
0005433434946	26687	58	14C
0005435982419	26687	59	14D
0005435982277	26687	60	14E
0005433434942	26687	61	14F
0005435982299	26687	62	15A
0005434271332	26687	63	15C
0005433434954	26687	64	15D
0005433434944	26687	65	15E
0005435982203	26687	66	15F
0005435982141	26687	67	16A
0005433434935	26687	68	16C
0005435982180	26687	69	16D
0005433434934	26687	70	16E
0005433434949	26687	71	16F
0005434270226	26687	72	17A
0005433434951	26687	73	17C
0005433434952	26687	74	17D
0005435982317	26687	75	17E
0005435982341	26687	76	17F
0005435982347	26687	77	18A
0005435982386	26687	78	18C
0005435982438	26687	79	18D
0005435982316	26687	80	18E
0005433434931	26687	81	18F
0005433434957	26687	82	19A
0005435982292	26687	83	19C
0005435982119	26687	84	19D
0005435982437	26687	85	19E
0005435982216	26687	86	19F
0005435982142	26687	87	20A
0005435982290	26687	88	20C
0005433434948	26687	89	20D
0005433434938	26687	90	20E
0005435982304	26687	91	20F
0005432584275	3130	1	1A
0005432584266	3130	2	1B
0005432858033	3130	3	1C
0005432858072	3130	4	1D
0005432584273	3130	5	2A
0005432858112	3130	6	2B
0005432858060	3130	7	2C
0005432584268	3130	8	3A
0005432584261	3130	9	3B
0005432584270	3130	10	3C
0005432584259	3130	11	3D
0005432584267	3130	12	4A
0005432584262	3130	13	4B
0005432216298	3130	14	5A
0005432584260	3130	15	4D
0005432858107	3130	16	5B
0005432584264	3130	17	5D
0005432858068	3130	18	6A
0005432216297	3130	19	6B
0005432858083	3130	20	6C
0005432858100	3130	21	6D
0005432858095	3130	22	7A
0005432584265	3130	23	7B
0005432584276	3130	24	7C
0005432584272	3130	25	7D
0005432858049	3130	26	18A
0005432858071	3130	27	18B
0005432584263	3130	28	18C
0005432858108	3130	29	18D
0005432584254	3130	30	19A
0005432858094	3130	31	19B
0005432584278	3130	32	19C
0005432584256	3130	33	19D
0005432858048	3130	34	20A
0005432858098	3130	35	20B
0005432584277	3130	36	20C
0005432858084	3130	37	20D
0005432584255	3130	38	21A
0005432584274	3130	39	21B
0005432584253	3130	40	21C
0005432584258	3130	41	21D
0005432584257	3130	42	22A
0005432584271	3130	43	22B
0005432858099	3130	44	22C
0005432584269	3130	45	23B
0005432858182	31486	1	1A
0005432858177	31486	2	1B
0005432583993	31486	3	1D
0005432858178	31486	4	2B
0005432858176	31486	5	2D
0005432858181	31486	6	3B
0005432584076	31486	7	3D
0005432858183	31486	8	4B
0005432858174	31486	9	4D
0005432583987	31486	10	5A
0005432584014	31486	11	5B
0005432583980	31486	12	5C
0005432584043	31486	13	5D
0005432584093	31486	14	6A
0005432584028	31486	15	6B
0005432584075	31486	16	6C
0005432583991	31486	17	6D
0005432858179	31486	18	7A
0005432583986	31486	19	7B
0005432584141	31486	20	7C
0005432584062	31486	21	7D
0005432584046	31486	22	18A
0005432584162	31486	23	18C
0005432858180	31486	24	18D
0005432583992	31486	25	19A
0005432584110	31486	26	19B
0005432583997	31486	27	19C
0005432583952	31486	28	19D
0005432858175	31486	29	20A
0005432858173	31486	30	20B
0005432584106	31486	31	20C
0005432858184	31486	32	20D
0005432584055	31486	33	21A
0005432584107	31486	34	21B
0005432584109	31486	35	21C
0005432584143	31486	36	21D
0005432583985	31486	37	22B
0005432584077	31486	38	22C
0005432584054	31486	39	22D
0005432584074	31486	40	23A
0005432584087	31486	41	23B
0005434943440	865	1	2C
0005434943437	865	2	3A
0005433255120	865	3	3B
0005434943432	865	4	4C
0005434943434	865	5	5D
0005434943435	865	6	6D
0005434943436	865	7	7B
0005434943433	865	8	7D
0005434943439	865	9	18B
0005434943431	865	10	18D
0005433255130	865	11	19B
0005433255107	865	12	20C
0005433255121	865	13	21A
0005433255105	865	14	21D
0005433255131	865	15	22B
0005434943438	865	16	22C
0005434943397	16241	1	1A
0005434943381	16241	2	2A
0005434943356	16241	3	3B
0005434943387	16241	4	3C
0005433255171	16241	5	4B
0005434943398	16241	6	4C
0005433255170	16241	7	4D
0005434943388	16241	8	5A
0005433255168	16241	9	5C
0005434943380	16241	10	6A
0005434943333	16241	11	6B
0005433255167	16241	12	7A
0005434943400	16241	13	7D
0005434943366	16241	14	19B
0005433255169	16241	15	19C
0005434943386	16241	16	19D
0005433255166	16241	17	20B
0005434943401	16241	18	21B
0005434943332	16241	19	22A
0005434943399	16241	20	22D
0005433811640	14429	1	2B
0005435653447	21765	1	1C
0005435653420	21765	2	1D
0005435653446	21765	3	1F
0005435653422	21765	4	2A
0005435653426	21765	5	2C
0005435653441	21765	6	2F
0005433367878	21765	7	3A
0005435653438	21765	8	3D
0005433367740	21765	9	3F
0005435653415	21765	10	4A
0005435653452	21765	11	4C
0005433367708	21765	12	4D
0005435653433	21765	13	4E
0005433367885	21765	14	4F
0005435653418	21765	15	5A
0005435653413	21765	16	5C
0005435653436	21765	17	5D
0005435653435	21765	18	5E
0005435653439	21765	19	5F
0005435653443	21765	20	6A
0005435653442	21765	21	6C
0005433367876	21765	22	6D
0005435653444	21765	23	6E
0005435653405	21765	24	7A
0005433367815	21765	25	7C
0005433367714	21765	26	7D
0005433367664	21765	27	7E
0005435653445	21765	28	8A
0005435653417	21765	29	8C
0005435653424	21765	30	8E
0005433367560	21765	31	8F
0005435653423	21765	32	9A
0005433368015	21765	33	9C
0005433367786	21765	34	9D
0005433367955	21765	35	9E
0005435653440	21765	36	9F
0005433367933	21765	37	10A
0005435653408	21765	38	10C
0005435653412	21765	39	10D
0005435653411	21765	40	10E
0005435653451	21765	41	11A
0005433367879	21765	42	11C
0005435653410	21765	43	11D
0005433367863	21765	44	11E
0005433367816	21765	45	11F
0005435653421	21765	46	12A
0005435653409	21765	47	12D
0005433367839	21765	48	12E
0005433367946	21765	49	12F
0005435653449	21765	50	13A
0005433367710	21765	51	13C
0005435653416	21765	52	13D
0005435653455	21765	53	13E
0005435653453	21765	54	13F
0005435653428	21765	55	14A
0005435653407	21765	56	14C
0005433367820	21765	57	14E
0005433367739	21765	58	14D
0005435653406	21765	59	14F
0005433367954	21765	60	15A
0005433367824	21765	61	15C
0005433367844	21765	62	15D
0005435653434	21765	63	15E
0005433368022	21765	64	15F
0005435653414	21765	65	16C
0005435653456	21765	66	16D
0005435653454	21765	67	16E
0005433367941	21765	68	16F
0005433367903	21765	69	17A
0005435653432	21765	70	17C
0005435653437	21765	71	17D
0005433367797	21765	72	17E
0005435653448	21765	73	17F
0005433367814	21765	74	18A
0005433367799	21765	75	18C
0005435653429	21765	76	18D
0005433367918	21765	77	18E
0005435653427	21765	78	18F
0005433367801	21765	79	19A
0005435653431	21765	80	19C
0005433367932	21765	81	19D
0005435653430	21765	82	19E
0005433367834	21765	83	19F
0005435653419	21765	84	20A
0005433367864	21765	85	20C
0005435653425	21765	86	20D
0005435653450	21765	87	20E
0005433367835	21765	88	20F
0005433805693	9348	1	1B
0005433785295	9348	2	1A
0005433763332	9348	3	1C
0005433785284	9348	4	1F
0005434171001	9348	5	1G
0005432666409	9348	6	2A
0005434171031	9348	7	2F
0005433785297	9348	8	2G
0005434171104	9348	9	3A
0005433785271	9348	10	2H
0005433785294	9348	11	3F
0005433763341	9348	12	3C
0005433785268	9348	13	4G
0005433763340	9348	14	5B
0005433763339	9348	15	5A
0005434151713	9348	16	5F
0005433805716	9348	17	5C
0005433785283	9348	18	5G
0005434171023	9348	19	9A
0005433805698	9348	20	5H
0005433805710	9348	21	9B
0005433785273	9348	22	9H
0005432666408	9348	23	11A
0005433785287	9348	24	11E
0005433785278	9348	25	11H
0005433805692	9348	26	11G
0005433805713	9348	27	12A
0005433763333	9348	28	12G
0005433805707	9348	29	13B
0005433785260	9348	30	13E
0005433805701	9348	31	14B
0005433805703	9348	32	14E
0005433805717	9348	33	14F
0005433785292	9348	34	14G
0005433785270	9348	35	14H
0005432667473	9348	36	16A
0005433805687	9348	37	16D
0005433785277	9348	38	16G
0005434151718	9348	39	16H
0005433805700	9348	40	17D
0005434171107	9348	41	17G
0005433763343	9348	42	17F
0005433785282	9348	43	17H
0005433785263	9348	44	18D
0005433763347	9348	45	19E
0005433805688	9348	46	19F
0005434171043	9348	47	19G
0005433763334	9348	48	20B
0005433785274	9348	49	20F
0005433805706	9348	50	20G
0005433763342	9348	51	21A
0005434171030	9348	52	21D
0005433785285	9348	53	21G
0005433805694	9348	54	21H
0005433785276	9348	55	22A
0005433805697	9348	56	22G
0005434171029	9348	57	22F
0005433785290	9348	58	23A
0005432657478	9348	59	23E
0005434171051	9348	60	23G
0005433805685	9348	61	23F
0005433763344	9348	62	24B
0005433805695	9348	63	24A
0005433805696	9348	64	24E
0005433785262	9348	65	25D
0005434151698	9348	66	25F
0005433805704	9348	67	27D
0005432657477	9348	68	27B
0005433805714	9348	69	27G
0005434151712	9348	70	28A
0005433785296	9348	71	27H
0005433763346	9348	72	28E
0005433785286	9348	73	28D
0005433805708	9348	74	28G
0005433785289	9348	75	29A
0005433785267	9348	76	29B
0005433805711	9348	77	29E
0005433785265	9348	78	29H
0005433805691	9348	79	30E
0005433785288	9348	80	30F
0005433785272	9348	81	31F
0005433805686	9348	82	31E
0005433805705	9348	83	32A
0005432657476	9348	84	31H
0005433785281	9348	85	32B
0005433763345	9348	86	32E
0005434171056	9348	87	32D
0005433805690	9348	88	32G
0005433785269	9348	89	33A
0005433763335	9348	90	33G
0005432665294	9348	91	33F
0005433785293	9348	92	34B
0005433763337	9348	93	34F
0005434171091	9348	94	34E
0005433805715	9348	95	34G
0005433785291	9348	96	35A
0005433805689	9348	97	35D
0005433805712	9348	98	35F
0005433763336	9348	99	35H
0005434171152	9348	100	36E
0005434171078	9348	101	36D
0005433785275	9348	102	36F
0005433785280	9348	103	37A
0005433805709	9348	104	37E
0005434151711	9348	105	37F
0005432665293	9348	106	37H
0005433785264	9348	107	37G
0005433785261	9348	108	38A
0005433763338	9348	109	38B
0005433785279	9348	110	38F
0005433785266	9348	111	38H
0005433805699	9348	112	39D
0005433805702	9348	113	39F
0005433784923	26265	1	1A
0005433805333	26265	2	1B
0005433763247	26265	3	1F
0005433784996	26265	4	1C
0005433784951	26265	5	1G
0005434171184	26265	6	2A
0005433785072	26265	7	1H
0005435269807	26265	8	2B
0005433805417	26265	9	2F
0005433805395	26265	10	2C
0005433784867	26265	11	2H
0005433784857	26265	12	3B
0005433763207	26265	13	3F
0005434269121	26265	14	3C
0005433805403	26265	15	4A
0005433763263	26265	16	3H
0005433805268	26265	17	4B
0005433763208	26265	18	4F
0005434171190	26265	19	4G
0005433785172	26265	20	5B
0005433784824	26265	21	5F
0005433784908	26265	22	5C
0005433805299	26265	23	5G
0005433763182	26265	24	5H
0005433784974	26265	25	9H
0005433805257	26265	26	11A
0005433784912	26265	27	11G
0005434171188	26265	28	11F
0005433785025	26265	29	12A
0005433784881	26265	30	11H
0005433784855	26265	31	12E
0005433784901	26265	32	12D
0005433763187	26265	33	12F
0005433785073	26265	34	12H
0005433805334	26265	35	12G
0005433784869	26265	36	13A
0005432659702	26265	37	13E
0005433784883	26265	38	13G
0005433784990	26265	39	13F
0005433805341	26265	40	14D
0005433805285	26265	41	14G
0005433784860	26265	42	15A
0005433805453	26265	43	14H
0005432657435	26265	44	15B
0005433805404	26265	45	15D
0005433805374	26265	46	15F
0005433763210	26265	47	15E
0005434171192	26265	48	15G
0005433805350	26265	49	16A
0005433805431	26265	50	16B
0005433805409	26265	51	16E
0005433784886	26265	52	16F
0005434271330	26265	53	16H
0005432657447	26265	54	17B
0005433784805	26265	55	17D
0005433805291	26265	56	17F
0005433763228	26265	57	17E
0005433805349	26265	58	17G
0005433784847	26265	59	18B
0005433785052	26265	60	18A
0005433805394	26265	61	18E
0005433785030	26265	62	18D
0005433784856	26265	63	18G
0005433763206	26265	64	18F
0005435269803	26265	65	19A
0005432666383	26265	66	18H
0005434171181	26265	67	19B
0005433805467	26265	68	19D
0005435269810	26265	69	19G
0005433763267	26265	70	19E
0005434171187	26265	71	20D
0005432663034	26265	72	20E
0005433805454	26265	73	20F
0005434171185	26265	74	21A
0005433805490	26265	75	21D
0005433785059	26265	76	21F
0005433785163	26265	77	21H
0005432666386	26265	78	21G
0005434171179	26265	79	22E
0005433805469	26265	80	22D
0005435269808	26265	81	22G
0005435269806	26265	82	22F
0005435269802	26265	83	22H
0005435269809	26265	84	23D
0005434171182	26265	85	23F
0005432659699	26265	86	23G
0005433763155	26265	87	24A
0005434151731	26265	88	23H
0005433805396	26265	89	24D
0005435269805	26265	90	24B
0005434270223	26265	91	24E
0005433805369	26265	92	24G
0005433805315	26265	93	24H
0005433784981	26265	94	25F
0005434171189	26265	95	27D
0005434171186	26265	96	27B
0005433785071	26265	97	27A
0005434151730	26265	98	27F
0005433763227	26265	99	27E
0005433784868	26265	100	28A
0005433784825	26265	101	28D
0005435269811	26265	102	28E
0005433805413	26265	103	28F
0005432666384	26265	104	28G
0005433805405	26265	105	28H
0005434271329	26265	106	29G
0005435269812	26265	107	30B
0005434270224	26265	108	30F
0005435269804	26265	109	30G
0005433784850	26265	110	30H
0005433805422	26265	111	31B
0005434171191	26265	112	31A
0005433784882	26265	113	32A
0005433763242	26265	114	32B
0005433784861	26265	115	32E
0005434171183	26265	116	32F
0005433784849	26265	117	32H
0005433805466	26265	118	33A
0005433785090	26265	119	33D
0005432663039	26265	120	33B
0005433763264	26265	121	33F
0005433784848	26265	122	34A
0005433805503	26265	123	34G
0005433784985	26265	124	34H
0005433785029	26265	125	35B
0005433784892	26265	126	35D
0005433805355	26265	127	35F
0005433784954	26265	128	35E
0005433763163	26265	129	36B
0005433763241	26265	130	36F
0005433763192	26265	131	37A
0005433763217	26265	132	36H
0005433805317	26265	133	37B
0005433805408	26265	134	37G
0005433763178	26265	135	37F
0005433763209	26265	136	37H
0005433805292	26265	137	38A
0005433784804	26265	138	38F
0005434171180	26265	139	39E
0005433784896	26265	140	39D
0005433784893	26265	141	39F
0005435929642	4880	1	4B
0005435135713	4880	2	5B
0005435135712	4880	3	6A
0005435929639	4880	4	6C
0005435929643	4880	5	7D
0005435135715	4880	6	18C
0005435135716	4880	7	19A
0005435135714	4880	8	23A
0005435135686	33016	1	1B
0005435929667	33016	2	2C
0005435135687	33016	3	3D
0005435135667	33016	4	4A
0005435929669	33016	5	6D
0005435929668	33016	6	7A
0005435135685	33016	7	7D
0005435135692	33016	8	20D
0005434983333	9459	1	1D
0005434217975	9459	2	2D
0005434217964	9459	3	3A
0005434217974	9459	4	3B
0005434217976	9459	5	4C
0005434983334	9459	6	5B
0005434217965	9459	7	6A
0005434217963	9459	8	7A
0005434983335	9459	9	7D
0005434217968	9459	10	18B
0005434217962	9459	11	18C
0005434217977	9459	12	20D
0005434983336	9459	13	21C
0005434217967	9459	14	23A
0005434217973	9459	15	23B
0005434218006	27362	1	1B
0005434983289	27362	2	1C
0005434218004	27362	3	2C
0005434983301	27362	4	3D
0005434218007	27362	5	4A
0005434983281	27362	6	6C
0005434218005	27362	7	19B
0005434983302	27362	8	19C
0005434983295	27362	9	20D
0005434983314	27362	10	23A
0005433985890	24278	1	1C
0005433985892	24278	2	1B
0005433960775	24278	3	1F
0005433960757	24278	4	2A
0005433960531	24278	5	2F
0005433960770	24278	6	2G
0005433985984	24278	7	2H
0005433960772	24278	8	3C
0005433985971	24278	9	3B
0005433960530	24278	10	3G
0005433960631	24278	11	4B
0005433985816	24278	12	4C
0005433960806	24278	13	4G
0005433985894	24278	14	5A
0005433960799	24278	15	5G
0005433985920	24278	16	5H
0005433985972	24278	17	11E
0005433985835	24278	18	11G
0005433960802	24278	19	11F
0005433960721	24278	20	12E
0005433985957	24278	21	12F
0005433960842	24278	22	12G
0005433960710	24278	23	13D
0005433960800	24278	24	13B
0005433960671	24278	25	13E
0005433960843	24278	26	13H
0005433985794	24278	27	14A
0005433985931	24278	28	14D
0005433985933	24278	29	14G
0005433960752	24278	30	14H
0005433960848	24278	31	15D
0005433985958	24278	32	15B
0005433985932	24278	33	15H
0005433985986	24278	34	16E
0005433985817	24278	35	17A
0005433960807	24278	36	17H
0005433960768	24278	37	18B
0005433960682	24278	38	18A
0005433960824	24278	39	18D
0005433985788	24278	40	18F
0005433985965	24278	41	18H
0005433960835	24278	42	19B
0005433985848	24278	43	20A
0005433960746	24278	44	20D
0005433960742	24278	45	20E
0005433960740	24278	46	20H
0005433960670	24278	47	21A
0005433960846	24278	48	21G
0005433960759	24278	49	21H
0005433960778	24278	50	22G
0005433960792	24278	51	22F
0005433985898	24278	52	22H
0005433960396	24278	53	23A
0005433960755	24278	54	23E
0005433985985	24278	55	23D
0005433960794	24278	56	23G
0005433960737	24278	57	24B
0005433960776	24278	58	24D
0005433960809	24278	59	24G
0005433985823	24278	60	25D
0005433960719	24278	61	25F
0005433985754	24278	62	27B
0005433960741	24278	63	27A
0005433985756	24278	64	27D
0005433960724	24278	65	27F
0005433960777	24278	66	27H
0005433985763	24278	67	28A
0005433985893	24278	68	28B
0005433985820	24278	69	28H
0005433960810	24278	70	29A
0005433985795	24278	71	29E
0005433960739	24278	72	30A
0005433960821	24278	73	29H
0005433985866	24278	74	30G
0005433960783	24278	75	31D
0005433960771	24278	76	31E
0005433960767	24278	77	31G
0005433985882	24278	78	31F
0005433960632	24278	79	32B
0005433960811	24278	80	32H
0005433985785	24278	81	33D
0005433960756	24278	82	33B
0005433960733	24278	83	33F
0005433960734	24278	84	34A
0005433985881	24278	85	34D
0005433960804	24278	86	34F
0005433985921	24278	87	34E
0005433985849	24278	88	35D
0005433985880	24278	89	35F
0005433985764	24278	90	35E
0005433985969	24278	91	35G
0005433960732	24278	92	36G
0005433960720	24278	93	37E
0005433960749	24278	94	38E
0005433985899	24278	95	38G
0005433960833	24278	96	38H
0005433960803	24278	97	39E
0005433961376	25952	1	1A
0005433986337	25952	2	2A
0005433986344	25952	3	2F
0005433961370	25952	4	3A
0005433986351	25952	5	3F
0005433986321	25952	6	4A
0005433986324	25952	7	4F
0005433961346	25952	8	4C
0005433961333	25952	9	4G
0005433961384	25952	10	5C
0005433961367	25952	11	5F
0005433961344	25952	12	9A
0005433986328	25952	13	5G
0005433961379	25952	14	11A
0005433986310	25952	15	9H
0005433986343	25952	16	11B
0005433986318	25952	17	11E
0005433986314	25952	18	11D
0005433961337	25952	19	11F
0005433986311	25952	20	11H
0005433986316	25952	21	12D
0005433986352	25952	22	12B
0005433961371	25952	23	12E
0005433986309	25952	24	12F
0005433961347	25952	25	12H
0005433961381	25952	26	13F
0005433986331	25952	27	13G
0005433961375	25952	28	14A
0005433961331	25952	29	14D
0005433961362	25952	30	15A
0005433961359	25952	31	15G
0005433986340	25952	32	16E
0005433986320	25952	33	17D
0005433986333	25952	34	17B
0005433986345	25952	35	17G
0005433961360	25952	36	17H
0005433961372	25952	37	18A
0005433961380	25952	38	18D
0005433961352	25952	39	18F
0005433986350	25952	40	18G
0005433986308	25952	41	19A
0005433961349	25952	42	19E
0005433961350	25952	43	19F
0005433961361	25952	44	19G
0005433986336	25952	45	20A
0005433961338	25952	46	19H
0005433961374	25952	47	20B
0005433986325	25952	48	20F
0005433986330	25952	49	20H
0005433961369	25952	50	21A
0005433986347	25952	51	21F
0005433986315	25952	52	21H
0005433961335	25952	53	22B
0005433961363	25952	54	22D
0005433961355	25952	55	23B
0005433986341	25952	56	23F
0005433961343	25952	57	23H
0005433986326	25952	58	24A
0005433961368	25952	59	24D
0005433961378	25952	60	24F
0005433986342	25952	61	24E
0005433961339	25952	62	24H
0005433961353	25952	63	24G
0005433986346	25952	64	25F
0005433961365	25952	65	27B
0005433986334	25952	66	27E
0005433961334	25952	67	28A
0005433986327	25952	68	27H
0005433986339	25952	69	28D
0005433961373	25952	70	28B
0005433961330	25952	71	28F
0005433961356	25952	72	28E
0005433986348	25952	73	29A
0005433986329	25952	74	28H
0005433961382	25952	75	29B
0005433986319	25952	76	29D
0005433986322	25952	77	29G
0005433986353	25952	78	29F
0005433961383	25952	79	30B
0005433961364	25952	80	30F
0005433961357	25952	81	30H
0005433961366	25952	82	31B
0005433961351	25952	83	31A
0005433986323	25952	84	31D
0005433986307	25952	85	31F
0005433986313	25952	86	32A
0005433961342	25952	87	32B
0005433961377	25952	88	32F
0005433986306	25952	89	32G
0005433961340	25952	90	33A
0005433961358	25952	91	33E
0005433986349	25952	92	33F
0005433986335	25952	93	33H
0005433961348	25952	94	33G
0005433986355	25952	95	34B
0005433986338	25952	96	34E
0005433986332	25952	97	34H
0005433961336	25952	98	35D
0005433986317	25952	99	35G
0005433986312	25952	100	36F
0005433961329	25952	101	36G
0005433961341	25952	102	37H
0005433961345	25952	103	38E
0005433986354	25952	104	38F
0005433961354	25952	105	39E
0005433961332	25952	106	39F
0005433165863	942	1	1A
0005434480565	942	2	1B
0005433165864	942	3	1D
0005434480551	942	4	2A
0005434480573	942	5	2B
0005434480569	942	6	2C
0005434480562	942	7	2D
0005434480558	942	8	3A
0005433165946	942	9	3B
0005433165885	942	10	3C
0005433165877	942	11	3D
0005432269521	942	12	4A
0005434480572	942	13	4B
0005433165890	942	14	4C
0005434480563	942	15	4D
0005432269522	942	16	5A
0005434480560	942	17	5B
0005433165903	942	18	5C
0005433165924	942	19	5D
0005434480566	942	20	6A
0005433165984	942	21	6B
0005434480561	942	22	6C
0005434480553	942	23	6D
0005433165896	942	24	7A
0005434480556	942	25	7B
0005433165941	942	26	7D
0005434480548	942	27	18B
0005434480559	942	28	18D
0005433165931	942	29	19A
0005433165947	942	30	19B
0005434480567	942	31	19C
0005434480550	942	32	19D
0005434480570	942	33	20A
0005432269520	942	34	20B
0005434480549	942	35	20D
0005434480555	942	36	21A
0005433165935	942	37	21B
0005434480557	942	38	21C
0005434480564	942	39	21D
0005434480554	942	40	22A
0005434480571	942	41	22B
0005433165943	942	42	22C
0005433165889	942	43	22D
0005434480568	942	44	23A
0005434480552	942	45	23B
0005434480348	16601	1	1B
0005434480344	16601	2	2C
0005434480395	16601	3	2D
0005434480263	16601	4	3B
0005434480222	16601	5	3C
0005434480290	16601	6	3D
0005433166029	16601	7	4A
0005434480378	16601	8	4B
0005434480318	16601	9	4C
0005434480394	16601	10	4D
0005434480436	16601	11	5A
0005434480458	16601	12	5B
0005433166023	16601	13	5C
0005434480275	16601	14	5D
0005433166021	16601	15	6A
0005434480362	16601	16	6C
0005433166019	16601	17	7A
0005433166025	16601	18	7B
0005434480347	16601	19	7C
0005433166020	16601	20	18A
0005433166031	16601	21	18B
0005433166026	16601	22	18C
0005433166024	16601	23	18D
0005434480297	16601	24	19A
0005434480457	16601	25	19C
0005433166030	16601	26	19D
0005433166022	16601	27	20A
0005434480274	16601	28	20D
0005434480437	16601	29	21A
0005433166027	16601	30	21B
0005434480309	16601	31	21C
0005433166028	16601	32	21D
0005434480281	16601	33	22A
0005433166018	16601	34	22D
0005434480440	16601	35	23A
0005434480381	16601	36	23B
0005435142693	10353	1	1A
0005435150139	10353	2	1C
0005435150144	10353	3	2A
0005435150140	10353	4	2B
0005435142682	10353	5	2C
0005435150138	10353	6	2D
0005435142687	10353	7	3A
0005435150141	10353	8	3B
0005435150145	10353	9	3C
0005435150137	10353	10	3D
0005435386572	10353	11	4B
0005435386571	10353	12	4C
0005435150146	10353	13	5A
0005435142684	10353	14	5C
0005435150135	10353	15	5D
0005435142686	10353	16	6A
0005435386570	10353	17	6B
0005435386577	10353	18	6D
0005435150147	10353	19	7A
0005435386560	10353	20	7C
0005435150148	10353	21	7D
0005435150143	10353	22	18A
0005435142690	10353	23	18B
0005435142685	10353	24	18D
0005435142688	10353	25	19A
0005435142695	10353	26	19C
0005433289841	10353	27	19D
0005435142689	10353	28	20D
0005435150142	10353	29	21A
0005435142683	10353	30	21B
0005435386583	10353	31	21D
0005433289838	10353	32	22A
0005435142691	10353	33	22B
0005435386576	10353	34	22C
0005435150136	10353	35	22D
0005435142692	10353	36	23A
0005435142694	10353	37	23B
0005435142556	21935	1	1A
0005435149947	21935	2	1B
0005433289917	21935	3	1C
0005435142560	21935	4	1D
0005435142537	21935	5	2B
0005435149946	21935	6	2C
0005433289921	21935	7	2D
0005435142538	21935	8	3A
0005433289920	21935	9	3B
0005435142603	21935	10	3D
0005435150022	21935	11	4A
0005435142577	21935	12	4B
0005435142613	21935	13	4C
0005433289923	21935	14	4D
0005435150011	21935	15	5B
0005435386630	21935	16	5C
0005435386635	21935	17	6A
0005435142559	21935	18	6B
0005435150036	21935	19	6C
0005433289924	21935	20	6D
0005435142555	21935	21	7B
0005435386633	21935	22	7C
0005435150057	21935	23	7D
0005435142602	21935	24	18A
0005435142550	21935	25	18B
0005435150059	21935	26	18C
0005435142539	21935	27	18D
0005433289922	21935	28	19A
0005435142587	21935	29	19B
0005435150034	21935	30	19C
0005435142624	21935	31	19D
0005435142563	21935	32	20A
0005435386632	21935	33	20B
0005433289919	21935	34	20C
0005435386634	21935	35	20D
0005435386631	21935	36	21A
0005433289918	21935	37	21C
0005435142578	21935	38	21D
0005435142586	21935	39	22A
0005435150058	21935	40	22B
0005435142564	21935	41	22C
0005435150035	21935	42	22D
0005435142568	21935	43	23A
0005435142580	21935	44	23B
0005435502305	11198	1	1D
0005434573467	11198	2	2A
0005435545734	11198	3	2D
0005435502386	11198	4	3C
0005435529316	11198	5	3D
0005435502326	11198	6	3F
0005435502403	11198	7	4A
0005435502331	11198	8	4C
0005435529286	11198	9	4D
0005434573466	11198	10	4E
0005434573468	11198	11	5A
0005435502276	11198	12	5C
0005435319556	11198	13	5D
0005435502358	11198	14	5E
0005435502275	11198	15	6A
0005435319569	11198	16	6C
0005435502302	11198	17	6D
0005435529323	11198	18	6E
0005435529259	11198	19	7A
0005435319587	11198	20	7C
0005435529211	11198	21	7D
0005435529224	11198	22	7E
0005435529324	11198	23	7F
0005435529271	11198	24	8A
0005435529325	11198	25	8C
0005434573471	11198	26	8D
0005435529213	11198	27	9A
0005435545729	11198	28	9C
0005435529156	11198	29	9D
0005435502309	11198	30	9E
0005435529258	11198	31	9F
0005434573472	11198	32	10A
0005435529281	11198	33	10C
0005435502329	11198	34	10D
0005435545736	11198	35	10E
0005435502357	11198	36	10F
0005434573470	11198	37	11A
0005435502389	11198	38	11C
0005435502330	11198	39	11E
0005435529163	11198	40	11F
0005435319616	11198	41	12C
0005434573474	11198	42	12D
0005435529162	11198	43	12E
0005435502390	11198	44	12F
0005435502278	11198	45	13A
0005435319617	11198	46	13C
0005434573465	11198	47	13D
0005435319619	11198	48	13E
0005435502310	11198	49	13F
0005435529223	11198	50	14A
0005435319563	11198	51	14D
0005435319620	11198	52	14E
0005435545728	11198	53	14F
0005435319570	11198	54	15A
0005435502359	11198	55	15C
0005435319588	11198	56	15D
0005435529247	11198	57	15E
0005435529222	11198	58	15F
0005435319584	11198	59	16A
0005435529214	11198	60	16D
0005434573475	11198	61	16F
0005435502363	11198	62	17A
0005434573469	11198	63	17E
0005435502404	11198	64	17F
0005435545737	11198	65	18A
0005435502332	11198	66	18C
0005434573476	11198	67	18D
0005435502301	11198	68	18E
0005434573463	11198	69	18F
0005435529155	11198	70	19A
0005435319575	11198	71	19C
0005435319583	11198	72	19D
0005435529315	11198	73	19E
0005435545730	11198	74	19F
0005434573464	11198	75	20A
0005434573473	11198	76	20D
0005434573462	11198	77	20E
0005435502269	11198	78	20F
0005435518063	20917	1	1A
0005435518054	20917	2	1C
0005435518069	20917	3	1D
0005435518058	20917	4	1F
0005435508459	20917	5	2A
0005435518072	20917	6	2C
0005435502487	20917	7	2D
0005435502492	20917	8	2F
0005435502496	20917	9	3A
0005435518065	20917	10	3D
0005435508456	20917	11	3F
0005435508457	20917	12	4A
0005435319666	20917	13	4C
0005435518067	20917	14	4D
0005435508451	20917	15	4E
0005435518064	20917	16	4F
0005435502485	20917	17	5A
0005435518055	20917	18	5C
0005435508461	20917	19	5D
0005435518061	20917	20	5E
0005435508450	20917	21	5F
0005432291950	20917	22	6A
0005435518049	20917	23	6C
0005435518066	20917	24	6D
0005435319664	20917	25	6E
0005435502499	20917	26	6F
0005435518062	20917	27	7C
0005435518068	20917	28	7D
0005434573354	20917	29	7E
0005434573350	20917	30	7F
0005435508453	20917	31	8A
0005434573358	20917	32	8C
0005434573284	20917	33	8D
0005435502495	20917	34	8E
0005434573349	20917	35	8F
0005435508448	20917	36	9A
0005435502486	20917	37	9C
0005435518050	20917	38	9D
0005435502488	20917	39	9E
0005435518056	20917	40	9F
0005435518052	20917	41	10A
0005435518051	20917	42	10C
0005435319662	20917	43	10E
0005435319663	20917	44	10F
0005435508460	20917	45	11A
0005435502500	20917	46	11D
0005434573314	20917	47	11C
0005435319665	20917	48	11E
0005435518057	20917	49	11F
0005435502493	20917	50	12A
0005435502491	20917	51	12C
0005435518059	20917	52	12D
0005434573323	20917	53	12F
0005434573332	20917	54	13A
0005435508452	20917	55	13C
0005432291951	20917	56	13D
0005435508454	20917	57	13F
0005434573343	20917	58	14A
0005435319661	20917	59	14D
0005435502490	20917	60	14E
0005435518060	20917	61	14F
0005434573315	20917	62	15A
0005435518053	20917	63	15C
0005435502501	20917	64	15D
0005435502503	20917	65	15F
0005434573353	20917	66	16A
0005435502489	20917	67	16C
0005435502506	20917	68	16E
0005435319660	20917	69	16F
0005435502505	20917	70	17A
0005434573384	20917	71	17C
0005435508447	20917	72	17D
0005435502504	20917	73	17E
0005435508458	20917	74	17F
0005434573276	20917	75	18A
0005435502497	20917	76	18C
0005435502498	20917	77	18D
0005435502494	20917	78	18E
0005434573310	20917	79	18F
0005435502507	20917	80	19A
0005435518070	20917	81	19C
0005435508455	20917	82	19D
0005435518071	20917	83	19E
0005435319667	20917	84	19F
0005434573385	20917	85	20A
0005435508462	20917	86	20C
0005434573333	20917	87	20D
0005435508449	20917	88	20E
0005435502502	20917	89	20F
0005432693048	2959	1	2C
0005432692911	2959	2	2F
0005432692912	2959	3	3D
0005432693095	2959	4	3F
0005432693121	2959	5	4F
0005432692995	2959	6	5D
0005432693103	2959	7	5E
0005432693150	2959	8	7C
0005432693158	2959	9	7D
0005432693168	2959	10	8D
0005432693012	2959	11	8F
0005432693151	2959	12	9A
0005432693070	2959	13	10A
0005432693020	2959	14	10C
0005432692973	2959	15	11C
0005432693157	2959	16	11D
0005432693029	2959	17	12A
0005432692891	2959	18	13F
0005432693028	2959	19	14D
0005432693079	2959	20	14E
0005432693105	2959	21	15C
0005432693106	2959	22	15A
0005432692892	2959	23	15E
0005432693045	2959	24	16A
0005432693101	2959	25	17A
0005432693094	2959	26	18A
0005432693011	2959	27	18C
0005432693104	2959	28	18E
0005432693100	2959	29	18F
0005432693122	2959	30	19E
0005432692974	2959	31	19F
0005432693043	2959	32	20C
0005432693044	2959	33	20D
0005432693156	2959	34	20F
0005432707013	2960	1	1C
0005432707001	2960	2	1F
0005432217801	2960	3	2C
0005432706996	2960	4	2D
0005433123808	2960	5	3A
0005433123876	2960	6	3C
0005433123930	2960	7	3F
0005432707014	2960	8	4E
0005433123853	2960	9	5D
0005432706993	2960	10	5F
0005432707007	2960	11	6A
0005433124015	2960	12	6C
0005432880827	2960	13	6D
0005432707009	2960	14	6E
0005433123897	2960	15	6F
0005433123956	2960	16	7C
0005432706997	2960	17	7D
0005432880804	2960	18	7E
0005432880869	2960	19	7F
0005432880825	2960	20	8A
0005432217802	2960	21	8C
0005433124016	2960	22	8E
0005432706999	2960	23	8F
0005432880824	2960	24	9A
0005432707008	2960	25	9C
0005432706992	2960	26	9D
0005433123899	2960	27	9E
0005432880792	2960	28	10A
0005433123997	2960	29	10D
0005433123926	2960	30	10E
0005432707004	2960	31	10F
0005432707002	2960	32	11A
0005432707003	2960	33	11C
0005432880819	2960	34	12A
0005432707011	2960	35	12D
0005432880786	2960	36	12E
0005432880839	2960	37	13A
0005432706991	2960	38	13C
0005432706990	2960	39	13D
0005432217800	2960	40	13E
0005432707010	2960	41	14A
0005432880818	2960	42	14C
0005433123962	2960	43	14D
0005433194856	2960	44	14E
0005432706995	2960	45	15A
0005432880771	2960	46	15C
0005432706989	2960	47	16E
0005433123957	2960	48	17E
0005432706998	2960	49	17F
0005432706994	2960	50	18C
0005432217803	2960	51	18D
0005432707012	2960	52	18E
0005432880826	2960	53	18F
0005433123963	2960	54	19A
0005432880788	2960	55	19C
0005433123895	2960	56	19D
0005433123925	2960	57	19E
0005433123807	2960	58	20A
0005432707000	2960	59	20C
0005432707005	2960	60	20E
0005432707006	2960	61	20F
0005433194887	30037	1	1A
0005432693371	30037	2	1C
0005432693361	30037	3	1D
0005432706705	30037	4	1F
0005432693370	30037	5	2A
0005432693365	30037	6	2C
0005432693367	30037	7	2D
0005432693349	30037	8	2F
0005432706772	30037	9	3A
0005432706817	30037	10	3C
0005433194879	30037	11	3D
0005432706848	30037	12	3F
0005432693350	30037	13	4A
0005432706769	30037	14	4C
0005432880947	30037	15	4D
0005433124111	30037	16	4E
0005432693368	30037	17	4F
0005432693362	30037	18	5A
0005432693348	30037	19	5D
0005432693356	30037	20	5C
0005432693375	30037	21	5E
0005433124107	30037	22	5F
0005433194886	30037	23	6A
0005433124112	30037	24	6C
0005433124098	30037	25	6D
0005432706792	30037	26	6E
0005433124101	30037	27	6F
0005432706818	30037	28	7A
0005432693369	30037	29	7C
0005432880953	30037	30	7D
0005433124106	30037	31	7E
0005432706782	30037	32	7F
0005432706820	30037	33	8A
0005432880952	30037	34	8C
0005433124114	30037	35	8D
0005432693377	30037	36	8E
0005432880943	30037	37	8F
0005433124119	30037	38	9A
0005433194884	30037	39	9C
0005432693360	30037	40	9D
0005433124097	30037	41	9E
0005433124115	30037	42	9F
0005432693363	30037	43	10A
0005433194878	30037	44	10C
0005432693378	30037	45	10D
0005433124105	30037	46	10E
0005432706850	30037	47	10F
0005433124109	30037	48	11A
0005432693358	30037	49	11C
0005432880944	30037	50	11D
0005432880942	30037	51	11E
0005433194877	30037	52	11F
0005432693373	30037	53	12A
0005432693353	30037	54	12C
0005433194880	30037	55	12D
0005432880951	30037	56	12E
0005432693372	30037	57	12F
0005432693366	30037	58	13A
0005433124099	30037	59	13C
0005433124113	30037	60	13D
0005432706924	30037	61	13E
0005433124104	30037	62	13F
0005433194882	30037	63	14A
0005433124110	30037	64	14C
0005432880950	30037	65	14D
0005432880946	30037	66	14E
0005433124116	30037	67	14F
0005432693374	30037	68	15A
0005433194881	30037	69	15C
0005432880949	30037	70	15D
0005432880955	30037	71	15E
0005433124100	30037	72	15F
0005432706823	30037	73	16C
0005433124118	30037	74	16D
0005432706800	30037	75	16E
0005432693352	30037	76	16F
0005433124117	30037	77	17A
0005432706786	30037	78	17C
0005432693354	30037	79	17D
0005432706785	30037	80	17E
0005433124108	30037	81	17F
0005432880954	30037	82	18A
0005432693364	30037	83	18C
0005433124102	30037	84	18D
0005432880945	30037	85	18E
0005433124103	30037	86	18F
0005433194883	30037	87	19A
0005432706773	30037	88	19C
0005432880948	30037	89	19D
0005432693357	30037	90	19E
0005433194885	30037	91	19F
0005432693359	30037	92	20A
0005432706897	30037	93	20C
0005432693351	30037	94	20D
0005432693355	30037	95	20E
0005432693376	30037	96	20F
0005434980046	23705	1	1A
0005434980051	23705	2	1B
0005434988824	23705	3	1C
0005434988828	23705	4	1D
0005434980030	23705	5	2A
0005434980044	23705	6	2D
0005434980048	23705	7	3A
0005434988829	23705	8	3D
0005434980036	23705	9	4A
0005434988822	23705	10	4B
0005434988830	23705	11	4C
0005434980031	23705	12	4D
0005434980035	23705	13	5A
0005434980032	23705	14	5B
0005434980040	23705	15	5C
0005434980041	23705	16	5D
0005434980027	23705	17	6A
0005434980045	23705	18	6B
0005434988826	23705	19	6C
0005434980028	23705	20	6D
0005434980034	23705	21	7A
0005434980038	23705	22	7B
0005434988831	23705	23	7C
0005434980049	23705	24	18A
0005434980025	23705	25	18C
0005434980047	23705	26	18D
0005434980033	23705	27	19B
0005434980039	23705	28	19C
0005434988825	23705	29	20A
0005434980026	23705	30	20B
0005434980021	23705	31	20C
0005434980042	23705	32	20D
0005434988827	23705	33	21A
0005434980037	23705	34	21C
0005434980029	23705	35	21B
0005434988823	23705	36	21D
0005434980050	23705	37	22A
0005434980023	23705	38	22B
0005434988821	23705	39	22C
0005434980024	23705	40	22D
0005434980043	23705	41	23A
0005434980022	23705	42	23B
0005434979768	27549	1	1B
0005434988716	27549	2	1C
0005434979779	27549	3	1D
0005434979820	27549	4	2A
0005434979886	27549	5	2B
0005434988733	27549	6	2D
0005434979846	27549	7	3A
0005434979767	27549	8	3B
0005434988715	27549	9	3C
0005434979750	27549	10	3D
0005434979736	27549	11	4A
0005434988751	27549	12	4C
0005434988720	27549	13	4D
0005434979885	27549	14	5A
0005434979712	27549	15	5B
0005434979742	27549	16	5C
0005434979882	27549	17	5D
0005434979766	27549	18	6B
0005434979861	27549	19	6C
0005434988724	27549	20	7A
0005434988731	27549	21	7C
0005434988745	27549	22	7D
0005434988730	27549	23	18A
0005434988743	27549	24	18B
0005434979743	27549	25	18C
0005434979786	27549	26	18D
0005434988726	27549	27	19A
0005434988732	27549	28	19B
0005434988719	27549	29	19C
0005434988741	27549	30	19D
0005434979753	27549	31	20C
0005434979787	27549	32	20D
0005434979855	27549	33	21B
0005434988717	27549	34	21C
0005434979713	27549	35	22A
0005434979817	27549	36	22C
0005434988727	27549	37	23A
0005433113530	10286	1	1D
0005434302498	10286	2	4A
0005434302497	10286	3	4B
0005434302493	10286	4	5A
0005434302494	10286	5	5D
0005434302495	10286	6	6A
0005434302496	10286	7	7C
0005433111489	10286	8	19A
0005433113534	10286	9	19D
0005433113529	10286	10	22D
0005433113555	19633	1	1D
0005434302462	19633	2	2D
0005434302450	19633	3	3B
0005433113556	19633	4	3C
0005434302435	19633	5	5B
0005434302437	19633	6	20A
0005434302449	19633	7	21B
0005434302436	19633	8	22A
0005435069569	3578	1	1A
0005435069583	3578	2	1D
0005435069550	3578	3	2A
0005435069538	3578	4	2C
0005435069564	3578	5	2F
0005435069566	3578	6	3A
0005435069568	3578	7	3C
0005435925336	3578	8	3F
0005435069571	3578	9	4A
0005435069552	3578	10	4C
0005435069580	3578	11	4D
0005435925337	3578	12	4E
0005435069585	3578	13	4F
0005435925278	3578	14	5A
0005435069539	3578	15	5C
0005435925300	3578	16	5D
0005435069586	3578	17	5F
0005435069556	3578	18	6A
0005435925279	3578	19	6E
0005435069581	3578	20	6F
0005435069537	3578	21	7A
0005435925283	3578	22	7D
0005435069584	3578	23	8A
0005435069587	3578	24	9A
0005435069559	3578	25	9D
0005435069570	3578	26	9F
0005435925328	3578	27	10A
0005435925302	3578	28	10C
0005435069540	3578	29	10D
0005435069547	3578	30	10E
0005435069542	3578	31	10F
0005435069557	3578	32	11A
0005435925282	3578	33	11C
0005435069575	3578	34	11E
0005435069545	3578	35	12A
0005435069548	3578	36	12C
0005435069574	3578	37	12E
0005435718995	3578	38	12F
0005435069565	3578	39	13C
0005435069543	3578	40	13E
0005435069560	3578	41	14A
0005435069549	3578	42	14C
0005435069588	3578	43	14D
0005435069558	3578	44	14E
0005435925284	3578	45	15A
0005435925301	3578	46	15C
0005435069573	3578	47	15D
0005435069572	3578	48	15F
0005435069541	3578	49	16A
0005435069551	3578	50	16C
0005435069578	3578	51	16E
0005435069582	3578	52	16F
0005435069553	3578	53	17C
0005435069567	3578	54	17E
0005435069555	3578	55	18D
0005435069563	3578	56	18E
0005435069561	3578	57	18F
0005435069554	3578	58	19A
0005435925272	3578	59	19C
0005435069577	3578	60	19E
0005435069562	3578	61	19F
0005435069579	3578	62	20A
0005435069546	3578	63	20C
0005435069544	3578	64	20D
0005435069536	3578	65	20E
0005435069576	3578	66	20F
0005435925421	15315	1	1C
0005435925419	15315	2	1D
0005435068867	15315	3	1F
0005435069147	15315	4	2C
0005435069061	15315	5	2F
0005435069077	15315	6	3A
0005435069004	15315	7	3D
0005435069068	15315	8	3F
0005435068901	15315	9	4A
0005435069093	15315	10	4C
0005435068958	15315	11	4D
0005435069002	15315	12	4E
0005435068896	15315	13	5A
0005435068763	15315	14	5C
0005435069119	15315	15	5D
0005435069021	15315	16	5E
0005435068759	15315	17	5F
0005435069162	15315	18	6A
0005435925412	15315	19	6D
0005435925418	15315	20	6E
0005435069230	15315	21	6F
0005435925414	15315	22	7A
0005435069221	15315	23	7C
0005435069072	15315	24	7E
0005435068948	15315	25	8D
0005435925420	15315	26	8E
0005435069013	15315	27	8F
0005435069023	15315	28	9A
0005435068963	15315	29	9C
0005435069043	15315	30	9D
0005435069098	15315	31	9F
0005435069215	15315	32	10A
0005435069047	15315	33	10C
0005435068947	15315	34	10D
0005435069183	15315	35	10E
0005435925423	15315	36	10F
0005435068952	15315	37	11A
0005435069058	15315	38	11C
0005435069223	15315	39	11D
0005435069163	15315	40	11E
0005435068914	15315	41	12A
0005435069088	15315	42	12C
0005435069229	15315	43	12D
0005435069236	15315	44	12E
0005435068964	15315	45	12F
0005435069286	15315	46	13C
0005435069022	15315	47	13D
0005435068715	15315	48	13E
0005435069099	15315	49	13F
0005435939895	15315	50	14C
0005435068975	15315	51	14E
0005435068931	15315	52	14F
0005435069048	15315	53	15C
0005435925413	15315	54	15D
0005435068762	15315	55	15E
0005435069220	15315	56	15F
0005435069067	15315	57	16A
0005435068879	15315	58	16C
0005435925417	15315	59	16D
0005435069214	15315	60	16E
0005435925416	15315	61	16F
0005435068915	15315	62	17A
0005435069039	15315	63	17C
0005435068951	15315	64	17D
0005435069040	15315	65	17E
0005435068930	15315	66	17F
0005435068716	15315	67	18A
0005435069127	15315	68	18C
0005435925422	15315	69	18D
0005435069224	15315	70	18F
0005435069076	15315	71	19A
0005435925415	15315	72	19C
0005435069189	15315	73	19F
0005435068957	15315	74	20C
0005435069066	15315	75	20D
0005435069083	15315	76	20E
0005435069033	15315	77	20F
0005432658610	18154	1	1A
0005432660838	18154	2	3A
0005432658611	18154	3	4B
0005432660837	18154	4	5B
0005432658609	18154	5	6A
0005432659725	18154	6	6B
0005432660821	26441	1	1B
0005432660811	26441	2	2A
0005432664134	26441	3	2B
0005432664133	26441	4	5A
0005432664132	26441	5	5B
0005432660822	26441	6	6B
0005432664138	26441	7	6A
0005433102183	108	1	1A
0005432901586	108	2	1F
0005433102170	108	3	2C
0005432677576	108	4	3A
0005433102159	108	5	2F
0005433102168	108	6	3C
0005433102239	108	7	4A
0005433101898	108	8	4F
0005432901656	108	9	5D
0005432901659	108	10	5F
0005432901680	108	11	6C
0005433102161	108	12	6A
0005432901644	108	13	7A
0005433102145	108	14	6F
0005433102166	108	15	7C
0005433102182	108	16	8C
0005433102107	108	17	8B
0005433102207	108	18	8F
0005433102053	108	19	9B
0005432677568	108	20	9C
0005433102098	108	21	9E
0005432919792	108	22	10D
0005432157510	108	23	10C
0005433102150	108	24	10E
0005433102180	108	25	11A
0005433102160	108	26	11C
0005432919921	108	27	11E
0005433102144	108	28	12B
0005432901621	108	29	12D
0005433102061	108	30	12C
0005433102153	108	31	12F
0005432919896	108	32	12E
0005433102062	108	33	13C
0005433102167	108	34	13B
0005433101899	108	35	13E
0005433101873	108	36	13D
0005432901650	108	37	14A
0005433102237	108	38	14B
0005433102067	108	39	15A
0005432901648	108	40	14F
0005433102026	108	41	14E
0005433102073	108	42	15B
0005433102129	108	43	15D
0005433102210	108	44	16D
0005433102099	108	45	17C
0005433102169	108	46	17D
0005432901601	108	47	17F
0005433102092	108	48	18A
0005432919790	108	49	18C
0005432919913	108	50	18D
0005433101982	108	51	18F
0005432677567	108	52	19B
0005433102211	108	53	20A
0005432677579	108	54	19E
0005432919912	108	55	20C
0005433102175	108	56	20E
0005432901660	108	57	21A
0005433102070	108	58	21C
0005433102102	108	59	21F
0005433102163	108	60	21D
0005432901622	108	61	22A
0005433101900	108	62	22B
0005433102054	108	63	22C
0005433102128	108	64	22D
0005432919917	108	65	22F
0005432919919	108	66	23D
0005432901651	108	67	23E
0005433102074	108	68	24A
0005432919920	108	69	23F
0005433102162	108	70	24B
0005432919824	108	71	24D
0005432919886	108	72	24C
0005433102130	108	73	25A
0005432919897	108	74	25C
0005433102215	108	75	25E
0005433102140	108	76	26A
0005432901574	108	77	25F
0005432919924	108	78	26C
0005433102178	108	79	26E
0005433102152	108	80	26D
0005433102108	108	81	26F
0005432157509	108	82	27C
0005433102190	108	83	27D
0005433102101	108	84	27F
0005432919875	108	85	27E
0005433102082	108	86	28C
0005432919911	108	87	28D
0005433102076	108	88	28F
0005432919902	108	89	29B
0005432901646	108	90	29A
0005432919791	108	91	29C
0005433102143	108	92	29D
0005432901647	108	93	29E
0005433102171	108	94	30C
0005432919887	108	95	30E
0005433102189	108	96	30F
0005432677575	108	97	31C
0005432919895	108	98	31D
0005432901705	108	99	31F
0005432817737	109	1	1A
0005432262333	109	2	1D
0005432817742	109	3	2D
0005432262320	109	4	2F
0005432817732	109	5	3C
0005432817741	109	6	3F
0005432817756	109	7	4A
0005432756850	109	8	4D
0005432262328	109	9	4C
0005432817738	109	10	4F
0005432262332	109	11	5D
0005432756849	109	12	6A
0005432262346	109	13	6F
0005432817750	109	14	7C
0005432262317	109	15	7D
0005432817746	109	16	8A
0005432262310	109	17	8B
0005432262326	109	18	8C
0005432262319	109	19	9A
0005432262336	109	20	9C
0005432817744	109	21	9E
0005432817755	109	22	10A
0005432262327	109	23	10C
0005432262335	109	24	10D
0005432262322	109	25	10E
0005432753305	109	26	10F
0005432817754	109	27	11B
0005432262316	109	28	11A
0005432262324	109	29	11C
0005432289016	109	30	11E
0005432817735	109	31	12A
0005432817757	109	32	11F
0005432262345	109	33	12B
0005432817743	109	34	12C
0005432262308	109	35	12E
0005432262309	109	36	13C
0005432262314	109	37	13B
0005432262331	109	38	13D
0005432262303	109	39	14B
0005432289017	109	40	14D
0005432262334	109	41	15D
0005432262347	109	42	16A
0005432817736	109	43	16B
0005432817730	109	44	16E
0005432262349	109	45	16F
0005434153542	109	46	17C
0005432262337	109	47	17E
0005432817739	109	48	18A
0005432817751	109	49	18B
0005432262312	109	50	18D
0005432262344	109	51	18F
0005432262305	109	52	19C
0005432289015	109	53	19B
0005432817734	109	54	19D
0005432817729	109	55	19E
0005432756830	109	56	20C
0005432262348	109	57	20D
0005432262341	109	58	21C
0005432262343	109	59	21D
0005432817728	109	60	21E
0005432817745	109	61	22B
0005432262311	109	62	22F
0005432262340	109	63	22E
0005432817740	109	64	23A
0005432207685	109	65	23D
0005432262330	109	66	23C
0005432262325	109	67	23E
0005432817733	109	68	24A
0005432817731	109	69	24D
0005432262315	109	70	24C
0005434153543	109	71	24F
0005432817747	109	72	24E
0005432817748	109	73	25A
0005432262339	109	74	25F
0005432262304	109	75	26B
0005432262321	109	76	26C
0005432756840	109	77	27A
0005432262342	109	78	27C
0005432207684	109	79	27D
0005432262318	109	80	27E
0005432262313	109	81	28A
0005432262307	109	82	27F
0005432817753	109	83	28B
0005432262323	109	84	29B
0005432262338	109	85	29D
0005432817752	109	86	30A
0005432262306	109	87	29F
0005432262329	109	88	31F
0005432817749	109	89	31E
0005433102635	7996	1	1A
0005433102666	7996	2	1C
0005432753332	7996	3	1D
0005433102634	7996	4	2A
0005432020508	7996	5	1F
0005432020499	7996	6	2D
0005433102637	7996	7	3A
0005433102616	7996	8	2F
0005433102663	7996	9	3C
0005432020513	7996	10	4A
0005432920052	7996	11	3F
0005433102657	7996	12	4C
0005432020498	7996	13	4F
0005432020493	7996	14	4D
0005433102628	7996	15	5A
0005433102648	7996	16	5D
0005433102630	7996	17	5F
0005433102596	7996	18	6D
0005433102604	7996	19	6C
0005433102609	7996	20	6A
0005432920049	7996	21	7A
0005432020506	7996	22	6F
0005432020507	7996	23	7C
0005433102670	7996	24	7F
0005432020502	7996	25	7D
0005433102610	7996	26	8A
0005433102629	7996	27	8B
0005433102623	7996	28	8E
0005432392027	7996	29	8D
0005432920051	7996	30	9A
0005433102601	7996	31	9C
0005433102602	7996	32	9E
0005432020509	7996	33	9D
0005433102614	7996	34	10A
0005432920057	7996	35	9F
0005433102618	7996	36	10B
0005433102620	7996	37	10D
0005432020497	7996	38	10C
0005433102632	7996	39	10E
0005433102615	7996	40	10F
0005433102668	7996	41	11C
0005432020516	7996	42	11B
0005432751559	7996	43	11D
0005432920040	7996	44	11F
0005433102640	7996	45	11E
0005433102655	7996	46	12A
0005432020517	7996	47	12E
0005432020495	7996	48	13A
0005432920056	7996	49	12F
0005433102605	7996	50	13C
0005433102638	7996	51	13B
0005433102653	7996	52	13D
0005433102664	7996	53	13F
0005432677612	7996	54	13E
0005432020520	7996	55	14B
0005433102603	7996	56	14A
0005433102656	7996	57	14D
0005433102643	7996	58	14C
0005433102642	7996	59	14E
0005433102636	7996	60	14F
0005433102611	7996	61	15B
0005433102661	7996	62	15A
0005432020494	7996	63	15C
0005432920044	7996	64	15D
0005433102647	7996	65	15E
0005432020505	7996	66	16A
0005433102599	7996	67	15F
0005432020512	7996	68	16B
0005433102617	7996	69	16C
0005433102607	7996	70	16E
0005433102593	7996	71	16D
0005432020503	7996	72	16F
0005433102613	7996	73	17A
0005433102612	7996	74	17D
0005433102624	7996	75	18A
0005433102662	7996	76	17F
0005432020519	7996	77	18C
0005433102660	7996	78	18B
0005432751557	7996	79	18E
0005433102608	7996	80	18D
0005432677610	7996	81	19C
0005432020518	7996	82	19D
0005433102594	7996	83	19E
0005432920050	7996	84	20B
0005432920055	7996	85	20A
0005433102665	7996	86	20C
0005433102619	7996	87	20E
0005432920043	7996	88	20D
0005433102654	7996	89	20F
0005432392026	7996	90	21A
0005433102650	7996	91	21C
0005432920058	7996	92	21B
0005432020496	7996	93	21E
0005433102652	7996	94	21D
0005433102625	7996	95	22A
0005433102606	7996	96	21F
0005433102659	7996	97	22B
0005432920046	7996	98	22E
0005432020514	7996	99	22F
0005432045631	7996	100	23A
0005432045632	7996	101	23C
0005432920039	7996	102	23B
0005432920053	7996	103	23D
0005432751556	7996	104	23E
0005433102644	7996	105	24A
0005432920048	7996	106	23F
0005433102639	7996	107	24B
0005432020504	7996	108	24E
0005433102622	7996	109	24D
0005433102669	7996	110	24F
0005432753333	7996	111	25C
0005432920042	7996	112	25B
0005432020501	7996	113	25D
0005432677611	7996	114	25F
0005433102621	7996	115	25E
0005432920041	7996	116	26B
0005433102641	7996	117	26A
0005433102595	7996	118	26C
0005433102626	7996	119	26D
0005432044550	7996	120	26F
0005432020511	7996	121	27A
0005432020515	7996	122	27C
0005432920054	7996	123	27B
0005432020500	7996	124	27D
0005433102667	7996	125	27E
0005432677609	7996	126	27F
0005432920047	7996	127	28B
0005433102658	7996	128	28C
0005432392028	7996	129	28E
0005433102600	7996	130	29A
0005433102645	7996	131	28F
0005433102633	7996	132	29B
0005432044551	7996	133	29D
0005433102649	7996	134	29F
0005433102646	7996	135	29E
0005432920038	7996	136	30A
0005433102627	7996	137	30B
0005433102631	7996	138	30C
0005432920045	7996	139	30E
0005433102597	7996	140	30D
0005432020510	7996	141	30F
0005433102598	7996	142	31B
0005433102651	7996	143	31D
0005432751558	7996	144	31F
0005432901776	7997	1	2F
0005432901770	7997	2	4D
0005432901766	7997	3	5D
0005432817551	7997	4	7D
0005432901778	7997	5	8D
0005432817515	7997	6	9A
0005432901775	7997	7	9E
0005432817434	7997	8	10E
0005432901767	7997	9	10F
0005432817506	7997	10	12A
0005432817540	7997	11	12B
0005432817585	7997	12	14F
0005432901765	7997	13	15B
0005432817550	7997	14	15A
0005432817601	7997	15	15D
0005432901762	7997	16	15F
0005432901764	7997	17	15E
0005432901773	7997	18	16D
0005432901772	7997	19	17B
0005432002094	7997	20	18B
0005432002095	7997	21	18E
0005432901763	7997	22	19B
0005432817553	7997	23	19D
0005432901771	7997	24	20B
0005432817541	7997	25	20F
0005432901769	7997	26	20E
0005432817514	7997	27	22D
0005432817568	7997	28	26A
0005432901761	7997	29	25F
0005432901768	7997	30	27F
0005432817500	7997	31	28B
0005432901777	7997	32	28C
0005432817558	7997	33	29F
0005432817557	7997	34	30A
0005432817483	7997	35	31B
0005432901774	7997	36	31D
0005434175746	9662	1	2A
0005434175757	9662	2	1B
0005433870751	9662	3	2B
0005434175752	9662	4	3A
0005434175756	9662	5	3B
0005434175745	9662	6	4A
0005434175764	9662	7	4B
0005434175747	9662	8	5A
0005433870750	9662	9	6A
0005434175744	9662	10	6B
0005434175792	32378	1	3A
0005433870739	32378	2	4A
0005434175790	32378	3	4B
0005434175791	32378	4	5B
0005434175793	32378	5	6A
0005434879132	3487	1	1C
0005435902710	3487	2	1A
0005435841820	3487	3	1H
0005434426886	3487	4	1G
0005435126766	3487	5	1K
0005434938329	3487	6	2C
0005435841821	3487	7	2A
0005435913930	3487	8	2H
0005434938316	3487	9	2G
0005435126767	3487	10	2D
0005434879069	3487	11	3D
0005435626366	3487	12	3C
0005434879059	3487	13	3K
0005434879092	3487	14	3H
0005432799724	3487	15	4C
0005432613900	3487	16	4A
0005432611750	3487	17	4G
0005434879134	3487	18	4D
0005434879098	3487	19	4K
0005432188638	3487	20	4H
0005435126768	3487	21	5D
0005434938327	3487	22	5H
0005435902712	3487	23	11A
0005432799726	3487	24	5K
0005435126747	3487	25	11E
0005434426888	3487	26	11F
0005434879148	3487	27	11H
0005434879115	3487	28	12A
0005432613899	3487	29	11K
0005432188637	3487	30	12E
0005434879130	3487	31	12G
0005434426877	3487	32	12F
0005434879104	3487	33	13A
0005434879066	3487	34	12H
0005434938332	3487	35	13D
0005435626353	3487	36	13F
0005432799733	3487	37	13E
0005435626363	3487	38	13G
0005435902694	3487	39	14A
0005434938317	3487	40	13K
0005434938326	3487	41	14D
0005434879072	3487	42	14G
0005432799714	3487	43	14K
0005434879062	3487	44	14H
0005435902783	3487	45	15C
0005435902732	3487	46	15A
0005434879137	3487	47	15E
0005434879111	3487	48	15D
0005434879076	3487	49	15K
0005434879067	3487	50	16F
0005434879074	3487	51	16E
0005435902759	3487	52	16K
0005434426892	3487	53	16H
0005434879121	3487	54	17A
0005434426879	3487	55	17D
0005434879089	3487	56	17C
0005435914695	3487	57	17G
0005432799730	3487	58	18A
0005435626365	3487	59	17K
0005434879109	3487	60	17H
0005434938314	3487	61	18C
0005435913928	3487	62	18E
0005434426872	3487	63	18D
0005434879133	3487	64	18H
0005432799711	3487	65	18J
0005434426876	3487	66	19A
0005434426885	3487	67	18K
0005434879141	3487	68	19C
0005434879091	3487	69	19F
0005434426887	3487	70	19E
0005434879126	3487	71	19H
0005434426889	3487	72	19G
0005435902758	3487	73	19K
0005435626359	3487	74	20C
0005434879097	3487	75	20E
0005434879123	3487	76	20D
0005434938330	3487	77	20G
0005435914699	3487	78	20F
0005435126762	3487	79	20J
0005434879110	3487	80	20K
0005434879107	3487	81	21D
0005435902775	3487	82	21C
0005434879149	3487	83	21F
0005434879101	3487	84	21E
0005434879102	3487	85	21J
0005434879124	3487	86	21K
0005434426897	3487	87	22D
0005435626369	3487	88	22C
0005435126746	3487	89	22B
0005434879055	3487	90	22E
0005435626351	3487	91	22H
0005434879060	3487	92	22G
0005434879119	3487	93	22F
0005435126770	3487	94	22J
0005434879063	3487	95	23B
0005432799712	3487	96	23A
0005434879081	3487	97	23D
0005434879144	3487	98	23C
0005434879065	3487	99	23F
0005435126757	3487	100	23E
0005435626360	3487	101	23H
0005435126736	3487	102	24D
0005435626344	3487	103	24F
0005435126738	3487	104	24E
0005434879152	3487	105	25B
0005434879150	3487	106	25A
0005434426878	3487	107	25C
0005434426894	3487	108	25F
0005432183486	3487	109	25E
0005435902743	3487	110	25D
0005432799718	3487	111	25H
0005432799732	3487	112	25G
0005434879103	3487	113	25K
0005435626362	3487	114	25J
0005434879100	3487	115	26E
0005435126751	3487	116	26D
0005434879140	3487	117	26C
0005432799723	3487	118	26G
0005435626354	3487	119	26H
0005434426875	3487	120	27B
0005435126741	3487	121	27A
0005434879057	3487	122	27C
0005435626343	3487	123	27F
0005434426873	3487	124	27E
0005435126754	3487	125	27H
0005434879117	3487	126	27K
0005434426899	3487	127	28C
0005432799717	3487	128	28B
0005434879096	3487	129	28A
0005434879129	3487	130	28E
0005435841093	3487	131	28D
0005434879127	3487	132	28G
0005435126750	3487	133	28F
0005434938321	3487	134	28J
0005434879138	3487	135	28H
0005435126756	3487	136	29A
0005435126743	3487	137	28K
0005432613902	3487	138	29D
0005432799713	3487	139	29C
0005434879105	3487	140	29B
0005435126742	3487	141	29F
0005434938318	3487	142	29E
0005432799719	3487	143	29H
0005435126769	3487	144	29G
0005434426882	3487	145	30A
0005434879064	3487	146	29J
0005434879142	3487	147	30C
0005435626349	3487	148	30B
0005434938324	3487	149	30D
0005434879147	3487	150	30G
0005432613901	3487	151	30F
0005434426870	3487	152	30J
0005434879095	3487	153	30H
0005434879079	3487	154	31B
0005434938323	3487	155	31D
0005435902742	3487	156	31C
0005434426896	3487	157	31F
0005435126752	3487	158	31E
0005435626358	3487	159	31J
0005435626348	3487	160	32C
0005435126765	3487	161	32B
0005435126760	3487	162	32E
0005434426893	3487	163	32D
0005435902711	3487	164	32F
0005432799731	3487	165	32J
0005434879082	3487	166	33B
0005434938322	3487	167	32K
0005434879139	3487	168	33F
0005434879056	3487	169	33E
0005435126759	3487	170	33D
0005434879088	3487	171	33H
0005434879070	3487	172	34A
0005432799727	3487	173	33K
0005432183487	3487	174	33J
0005434426884	3487	175	34C
0005434879058	3487	176	34B
0005435902776	3487	177	34E
0005434879068	3487	178	34D
0005434879078	3487	179	34H
0005432799720	3487	180	34G
0005434426891	3487	181	34F
0005434879099	3487	182	34K
0005435126745	3487	183	34J
0005432799710	3487	184	35B
0005434879146	3487	185	35A
0005435126753	3487	186	35D
0005434426898	3487	187	35C
0005432799725	3487	188	35F
0005435626361	3487	189	35E
0005434426871	3487	190	35G
0005435126740	3487	191	36A
0005435914694	3487	192	35K
0005432799707	3487	193	35J
0005435914697	3487	194	36B
0005432799729	3487	195	36E
0005435126755	3487	196	36D
0005434938315	3487	197	36G
0005435126739	3487	198	36J
0005434426881	3487	199	37B
0005432611749	3487	200	36K
0005434426890	3487	201	37C
0005435626347	3487	202	37F
0005434879118	3487	203	37E
0005434879083	3487	204	37J
0005435126749	3487	205	38C
0005434938320	3487	206	38B
0005435626340	3487	207	38A
0005432799722	3487	208	38J
0005434938325	3487	209	38H
0005432799709	3487	210	38K
0005434879080	3487	211	39D
0005435626352	3487	212	39C
0005435914696	3487	213	39F
0005435626367	3487	214	39G
0005432613898	3487	215	40C
0005435126761	3487	216	40F
0005434879086	3487	217	40G
0005434879116	3487	218	40K
0005434879108	3487	219	40H
0005434426880	3487	220	41B
0005432799715	3487	221	41A
0005435126732	3487	222	41D
0005434426895	3487	223	41C
0005435626345	3487	224	41F
0005434879061	3487	225	41E
0005434879112	3487	226	41J
0005434879125	3487	227	41H
0005432799716	3487	228	42A
0005434879075	3487	229	41K
0005435126733	3487	230	42C
0005434938328	3487	231	42B
0005435626368	3487	232	42G
0005434879113	3487	233	42H
0005435126744	3487	234	43A
0005434879071	3487	235	43D
0005434426883	3487	236	43B
0005435914698	3487	237	43F
0005435626346	3487	238	43E
0005435126763	3487	239	44C
0005435126737	3487	240	44A
0005435626370	3487	241	44E
0005432799708	3487	242	44H
0005434879106	3487	243	44G
0005434879131	3487	244	44F
0005435126734	3487	245	44J
0005435626356	3487	246	45A
0005434879084	3487	247	45D
0005435126748	3487	248	45C
0005435126758	3487	249	45F
0005435626350	3487	250	45H
0005434879114	3487	251	45G
0005434879077	3487	252	45J
0005432799721	3487	253	46B
0005434879128	3487	254	46A
0005434879143	3487	255	46E
0005432799728	3487	256	46C
0005435626357	3487	257	46G
0005434879087	3487	258	46J
0005435626364	3487	259	46H
0005434938331	3487	260	47C
0005434879136	3487	261	47A
0005434879085	3487	262	46K
0005432188639	3487	263	47D
0005435126764	3487	264	47G
0005435626342	3487	265	47H
0005435626341	3487	266	48C
0005434879151	3487	267	48F
0005434879135	3487	268	48E
0005434938319	3487	269	48D
0005434879090	3487	270	48G
0005434879094	3487	271	49A
0005435626355	3487	272	48K
0005434879120	3487	273	49G
0005434879093	3487	274	49F
0005434879122	3487	275	49K
0005435902741	3487	276	50C
0005435902682	3487	277	50E
0005434426874	3487	278	50D
0005435126735	3487	279	50H
0005434879073	3487	280	51F
0005434879145	3487	281	51D
0005434426497	14566	1	1D
0005435126385	14566	2	1C
0005434878076	14566	3	1G
0005434877890	14566	4	1K
0005434938185	14566	5	2C
0005434878510	14566	6	2A
0005434426543	14566	7	2G
0005434878330	14566	8	3A
0005432799570	14566	9	3G
0005434878259	14566	10	3D
0005435902875	14566	11	3H
0005432799540	14566	12	3K
0005434938165	14566	13	4D
0005435902872	14566	14	4K
0005434878340	14566	15	4H
0005434938164	14566	16	5D
0005435842333	14566	17	5C
0005434938147	14566	18	5H
0005435126274	14566	19	5G
0005434878255	14566	20	11D
0005435126452	14566	21	11C
0005434426527	14566	22	11F
0005434938211	14566	23	11H
0005434878329	14566	24	11G
0005434426659	14566	25	12C
0005432799494	14566	26	11K
0005432059523	14566	27	12E
0005434426664	14566	28	12D
0005434877894	14566	29	12F
0005434878388	14566	30	13A
0005434878325	14566	31	13F
0005435626160	14566	32	13E
0005435626110	14566	33	13K
0005435626162	14566	34	13G
0005432799447	14566	35	14A
0005434878181	14566	36	14E
0005435902873	14566	37	14D
0005434878430	14566	38	14F
0005434878084	14566	39	14K
0005434938272	14566	40	14H
0005434426496	14566	41	14G
0005435126391	14566	42	15D
0005434878125	14566	43	15C
0005434878480	14566	44	15E
0005434878441	14566	45	15G
0005434877895	14566	46	16A
0005435126453	14566	47	15H
0005435902864	14566	48	16D
0005435902870	14566	49	16F
0005434938191	14566	50	16G
0005434878235	14566	51	17A
0005432799542	14566	52	16K
0005434878294	14566	53	17E
0005434878366	14566	54	17D
0005434877873	14566	55	17C
0005434878243	14566	56	17G
0005434878518	14566	57	17F
0005435902862	14566	58	17K
0005434426599	14566	59	17H
0005435126562	14566	60	18C
0005434878570	14566	61	18A
0005434878139	14566	62	18E
0005435126075	14566	63	18D
0005434878230	14566	64	18G
0005434878248	14566	65	18F
0005434426692	14566	66	18J
0005434938220	14566	67	19B
0005434878273	14566	68	18K
0005435126321	14566	69	19C
0005432799579	14566	70	19F
0005435126372	14566	71	19E
0005435126396	14566	72	19G
0005432799488	14566	73	19K
0005434878140	14566	74	20B
0005435902858	14566	75	20D
0005434426660	14566	76	20G
0005432611730	14566	77	20F
0005434878533	14566	78	20K
0005435126407	14566	79	20J
0005434878244	14566	80	20H
0005434878362	14566	81	21D
0005434878536	14566	82	21C
0005435126531	14566	83	21G
0005434426714	14566	84	21F
0005434426434	14566	85	21E
0005434938148	14566	86	21J
0005435126532	14566	87	22A
0005434878309	14566	88	21K
0005434426605	14566	89	22D
0005435126419	14566	90	22B
0005434426627	14566	91	22E
0005434878311	14566	92	22G
0005434878072	14566	93	22J
0005432799431	14566	94	23B
0005434878078	14566	95	23A
0005434878448	14566	96	23F
0005434938176	14566	97	23E
0005432799458	14566	98	23J
0005434878381	14566	99	23H
0005434878203	14566	100	24D
0005434878571	14566	101	24F
0005434426544	14566	102	25A
0005434938134	14566	103	24G
0005432799571	14566	104	25D
0005432799541	14566	105	25C
0005435902860	14566	106	25B
0005432799487	14566	107	25F
0005434878427	14566	108	25H
0005435126334	14566	109	25K
0005435126306	14566	110	26C
0005434878377	14566	111	26B
0005434878461	14566	112	26A
0005432799389	14566	113	26E
0005434878189	14566	114	26D
0005434877859	14566	115	26G
0005434426624	14566	116	26H
0005435126561	14566	117	26K
0005435126361	14566	118	27D
0005435842332	14566	119	27C
0005434878124	14566	120	27B
0005434426662	14566	121	27F
0005434426693	14566	122	27E
0005434877964	14566	123	27J
0005435126468	14566	124	27H
0005435626124	14566	125	27G
0005434938085	14566	126	27K
0005434878401	14566	127	28B
0005434426648	14566	128	28D
0005435126346	14566	129	28G
0005432799543	14566	130	28F
0005434878458	14566	131	28J
0005435126333	14566	132	28H
0005434878439	14566	133	29A
0005434878169	14566	134	29D
0005434426691	14566	135	29C
0005434878208	14566	136	29E
0005434878272	14566	137	29J
0005434878545	14566	138	29H
0005434878347	14566	139	29G
0005434878457	14566	140	30A
0005432611729	14566	141	29K
0005435902868	14566	142	30B
0005432799370	14566	143	30E
0005434877918	14566	144	30D
0005434426723	14566	145	30G
0005435126275	14566	146	30F
0005435126519	14566	147	30J
0005435126492	14566	148	30H
0005434426607	14566	149	31B
0005435126555	14566	150	31A
0005434878424	14566	151	30K
0005434877967	14566	152	31D
0005434878558	14566	153	31C
0005432799489	14566	154	31F
0005434878400	14566	155	31E
0005432799360	14566	156	31H
0005434877854	14566	157	32A
0005435126395	14566	158	32D
0005435126365	14566	159	32C
0005434938203	14566	160	32G
0005434426540	14566	161	32J
0005434878481	14566	162	33A
0005432799455	14566	163	33D
0005435126326	14566	164	33C
0005434878206	14566	165	33F
0005434878082	14566	166	33E
0005434878268	14566	167	33H
0005434878077	14566	168	34A
0005434878378	14566	169	33J
0005434878512	14566	170	34C
0005434877879	14566	171	34B
0005435902861	14566	172	34E
0005434878265	14566	173	34D
0005435126371	14566	174	34G
0005434878126	14566	175	34F
0005435126210	14566	176	34K
0005432799430	14566	177	34J
0005435902876	14566	178	34H
0005435126353	14566	179	35B
0005434878392	14566	180	35D
0005435902859	14566	181	35C
0005435902863	14566	182	35F
0005434878257	14566	183	35J
0005432799286	14566	184	36A
0005434938210	14566	185	36B
0005434878348	14566	186	36E
0005435902871	14566	187	36H
0005434938182	14566	188	36K
0005434938169	14566	189	36J
0005434878431	14566	190	37B
0005435626128	14566	191	37A
0005434878158	14566	192	37F
0005435126251	14566	193	37E
0005434426661	14566	194	37J
0005434877965	14566	195	37H
0005434878482	14566	196	37G
0005435126325	14566	197	38B
0005434878227	14566	198	38J
0005435626104	14566	199	38H
0005432799528	14566	200	39B
0005434878361	14566	201	38K
0005432799486	14566	202	39C
0005435126421	14566	203	39F
0005434938181	14566	204	39H
0005434878070	14566	205	39G
0005434877853	14566	206	40A
0005432799507	14566	207	39K
0005434878444	14566	208	39J
0005434878215	14566	209	40C
0005435842334	14566	210	40E
0005435126416	14566	211	40D
0005434877980	14566	212	40G
0005435126554	14566	213	40F
0005435126384	14566	214	40J
0005435126366	14566	215	40H
0005435902865	14566	216	41B
0005434877839	14566	217	41A
0005434426665	14566	218	41D
0005434878511	14566	219	41C
0005434877917	14566	220	41J
0005432799514	14566	221	41H
0005434426561	14566	222	41G
0005434878574	14566	223	42A
0005435126259	14566	224	41K
0005434878549	14566	225	42B
0005435126324	14566	226	42F
0005434878575	14566	227	42E
0005432799434	14566	228	42D
0005434878440	14566	229	42H
0005435126347	14566	230	42G
0005435126256	14566	231	43B
0005432059522	14566	232	43A
0005434878328	14566	233	42K
0005434878154	14566	234	43D
0005435626118	14566	235	43C
0005435902869	14566	236	43F
0005434878375	14566	237	43H
0005434426584	14566	238	43K
0005434878519	14566	239	44B
0005435626112	14566	240	44A
0005434426658	14566	241	44F
0005434878266	14566	242	44D
0005435126286	14566	243	44J
0005434878324	14566	244	44H
0005434426694	14566	245	45B
0005435126397	14566	246	45A
0005435126438	14566	247	45D
0005434426647	14566	248	45C
0005434878489	14566	249	45G
0005434426671	14566	250	45K
0005435626103	14566	251	46B
0005434878287	14566	252	46E
0005434426539	14566	253	46D
0005435902866	14566	254	46G
0005434938221	14566	255	46J
0005434878083	14566	256	47A
0005435126467	14566	257	46K
0005432799476	14566	258	47E
0005434878349	14566	259	47D
0005434426560	14566	260	47C
0005434878258	14566	261	47G
0005432799511	14566	262	47K
0005434878236	14566	263	47H
0005435626163	14566	264	48D
0005434878159	14566	265	48C
0005434877874	14566	266	48F
0005435126520	14566	267	48H
0005435126422	14566	268	48G
0005434878326	14566	269	49A
0005435126258	14566	270	48K
0005434878544	14566	271	49E
0005432607573	14566	272	49D
0005434878327	14566	273	49G
0005435126276	14566	274	49F
0005432799513	14566	275	49H
0005434878550	14566	276	50C
0005435626102	14566	277	50A
0005434426578	14566	278	50F
0005435126340	14566	279	50E
0005434938204	14566	280	50D
0005434878425	14566	281	50G
0005435902874	14566	282	51D
0005435626113	14566	283	50K
0005434877872	14566	284	51E
0005435902867	14566	285	51G
0005434325762	3598	1	1B
0005434312338	3598	2	1D
0005434325754	3598	3	2D
0005434325753	3598	4	3D
0005434325759	3598	5	4D
0005434325761	3598	6	5A
0005434325757	3598	7	5D
0005435889908	3598	8	6C
0005434325758	3598	9	7A
0005435889906	3598	10	7C
0005434325755	3598	11	7D
0005434312339	3598	12	18B
0005435889900	3598	13	19B
0005434325760	3598	14	20A
0005434325756	3598	15	21C
0005435889907	3598	16	22D
0005435889952	15646	1	1A
0005435889950	15646	2	1B
0005434325690	15646	3	1D
0005434325676	15646	4	2A
0005435889953	15646	5	2C
0005435889955	15646	6	3D
0005435889951	15646	7	4A
0005434325634	15646	8	4D
0005434325689	15646	9	5B
0005434325688	15646	10	6A
0005434325709	15646	11	6B
0005434325681	15646	12	7B
0005434325713	15646	13	19B
0005434325675	15646	14	19C
0005435889954	15646	15	19D
0005434325678	15646	16	21A
0005434325648	15646	17	21D
0005434325653	15646	18	22D
0005435957838	662	1	1A
0005435957841	662	2	1C
0005435957844	662	3	1D
0005433420399	662	4	2C
0005435957836	662	5	3A
0005435957846	662	6	3B
0005433420400	662	7	3C
0005435957837	662	8	4B
0005435957835	662	9	4D
0005433420413	662	10	5B
0005435957840	662	11	5C
0005435957845	662	12	6D
0005435957834	662	13	18A
0005433420384	662	14	19B
0005435957847	662	15	20A
0005433420397	662	16	20B
0005435957842	662	17	20C
0005435957832	662	18	20D
0005433420371	662	19	21A
0005435957833	662	20	21B
0005433420398	662	21	22A
0005435957843	662	22	22B
0005435957839	662	23	23A
0005435957748	15200	1	1A
0005433420480	15200	2	1C
0005435957665	15200	3	1D
0005433420478	15200	4	2A
0005433420482	15200	5	2B
0005433420481	15200	6	3B
0005435957734	15200	7	3C
0005435957691	15200	8	3D
0005435957738	15200	9	5D
0005435957726	15200	10	6A
0005435957725	15200	11	7B
0005433420484	15200	12	7D
0005433420479	15200	13	20D
0005433420483	15200	14	21B
0005435957724	15200	15	21D
0005435957731	15200	16	22C
0005435957715	15200	17	23B
0005435629417	8860	1	3B
0005435629415	8860	2	4B
0005434247140	8860	3	5A
0005435629416	8860	4	6A
0005434247172	16003	1	1A
0005435629404	16003	2	2B
0005435629408	16003	3	4A
0005435629407	16003	4	6B
0005435163226	29521	1	1A
0005435163209	29521	2	1B
0005435163207	29521	3	1C
0005435933488	29521	4	1D
0005435163215	29521	5	2A
0005435933485	29521	6	2C
0005435163225	29521	7	3A
0005435163223	29521	8	3B
0005435163232	29521	9	3D
0005435933487	29521	10	4A
0005435163213	29521	11	4C
0005435163212	29521	12	5A
0005435163240	29521	13	5B
0005435933486	29521	14	5C
0005435163231	29521	15	6B
0005435163208	29521	16	7A
0005435163210	29521	17	7C
0005435933483	29521	18	7D
0005435933481	29521	19	18B
0005435933479	29521	20	18A
0005435933478	29521	21	18C
0005435163239	29521	22	19A
0005435163238	29521	23	19C
0005435933484	29521	24	19D
0005435163237	29521	25	20A
0005435933480	29521	26	20B
0005435163216	29521	27	20C
0005435933482	29521	28	21C
0005435163196	29521	29	21B
0005435163228	29521	30	22C
0005435163219	29521	31	22D
0005435163227	29521	32	23B
0005435797598	2845	1	1A
0005433404835	2845	2	1C
0005433404798	2845	3	1F
0005435797606	2845	4	2C
0005435797610	2845	5	3F
0005435797599	2845	6	4A
0005435797602	2845	7	4D
0005435797609	2845	8	8C
0005435797611	2845	9	10A
0005435797604	2845	10	12E
0005435797607	2845	11	13E
0005433404792	2845	12	16D
0005435797601	2845	13	17A
0005435797600	2845	14	17C
0005435797605	2845	15	19A
0005435797603	2845	16	19C
0005435797612	2845	17	20C
0005433404827	2845	18	20E
0005435797608	2845	19	20F
0005433404879	29302	1	3C
0005435797514	29302	2	3D
0005435797518	29302	3	5A
0005435797524	29302	4	5C
0005433404881	29302	5	6C
0005435797506	29302	6	8A
0005433404880	29302	7	8D
0005433404882	29302	8	9D
0005435797523	29302	9	10C
0005433404875	29302	10	10E
0005435797479	29302	11	12D
0005435797522	29302	12	13C
0005433404876	29302	13	13D
0005433404877	29302	14	14A
0005435797567	29302	15	15A
0005435797487	29302	16	16F
0005433404878	29302	17	18D
0005435797507	29302	18	19D
0005435797486	29302	19	19E
0005435376359	5834	1	2B
0005435376360	5834	2	5B
0005434948098	5826	1	1A
0005434948101	5826	2	1B
0005434948097	5826	3	2A
0005434948095	5826	4	3A
0005434948094	5826	5	4A
0005434948096	5826	6	5A
0005434948100	5826	7	6A
0005434948099	5826	8	6B
0005434948004	16320	1	1A
0005434948013	16320	2	1B
0005434948017	16320	3	2A
0005434947994	16320	4	2B
0005434948042	16320	5	3A
0005434948001	16320	6	3B
0005434948023	16320	7	4A
0005434948028	16320	8	4B
0005434948018	16320	9	5A
0005434947993	16320	10	5B
0005434948041	16320	11	6A
0005434948027	16320	12	6B
0005433961426	6871	1	1A
0005433961405	6871	2	2C
0005433961407	6871	3	2D
0005433961403	6871	4	2F
0005433961420	6871	5	3F
0005433961423	6871	6	4C
0005433961408	6871	7	4D
0005433961410	6871	8	5E
0005433961406	6871	9	6C
0005433961386	6871	10	6E
0005433961427	6871	11	7F
0005433961402	6871	12	8A
0005433961401	6871	13	9C
0005433961388	6871	14	9D
0005433961404	6871	15	9F
0005433961385	6871	16	10A
0005433961394	6871	17	10C
0005433961387	6871	18	10D
0005433961419	6871	19	10F
0005433961398	6871	20	11A
0005433961428	6871	21	11E
0005433961392	6871	22	11F
0005433961416	6871	23	12A
0005433961425	6871	24	12E
0005433961396	6871	25	12F
0005433961413	6871	26	13C
0005433961414	6871	27	13D
0005433961411	6871	28	14D
0005433961391	6871	29	14F
0005433961389	6871	30	15A
0005433961390	6871	31	15C
0005433961412	6871	32	15F
0005433961417	6871	33	16A
0005433961415	6871	34	16C
0005433961424	6871	35	17C
0005433961393	6871	36	17E
0005433961397	6871	37	18D
0005433961395	6871	38	18E
0005433961421	6871	39	18F
0005433961422	6871	40	19A
0005433961418	6871	41	19C
0005433961399	6871	42	19E
0005433961409	6871	43	19F
0005433961400	6871	44	20A
0005433960666	25712	1	1C
0005433960711	25712	2	1D
0005433960487	25712	3	1F
0005433960745	25712	4	2A
0005433960845	25712	5	2D
0005433960610	25712	6	2F
0005433960581	25712	7	4E
0005433960593	25712	8	5C
0005433960673	25712	9	5F
0005433960813	25712	10	6C
0005433960784	25712	11	6D
0005433960504	25712	12	7A
0005433960702	25712	13	7E
0005433960664	25712	14	8D
0005433960503	25712	15	8E
0005433960516	25712	16	8F
0005433960798	25712	17	9A
0005433960667	25712	18	9C
0005433960594	25712	19	9E
0005433960764	25712	20	10C
0005433960839	25712	21	10D
0005433960782	25712	22	10E
0005433960763	25712	23	11D
0005433960841	25712	24	12A
0005433960844	25712	25	12D
0005433960753	25712	26	12E
0005433960665	25712	27	12F
0005433960703	25712	28	13A
0005433960612	25712	29	13C
0005433960747	25712	30	13D
0005433960651	25712	31	13F
0005433960797	25712	32	14D
0005433960766	25712	33	14F
0005433960829	25712	34	15C
0005433960850	25712	35	15D
0005433960686	25712	36	16A
0005433960754	25712	37	16C
0005433960828	25712	38	16D
0005433960409	25712	39	16E
0005433960765	25712	40	17A
0005433960685	25712	41	17C
0005433960684	25712	42	17E
0005433960834	25712	43	18A
0005433960650	25712	44	19D
0005433960611	25712	45	19E
0005433960808	25712	46	20F
0005435082774	24550	1	1A
0005435082768	24550	2	1B
0005435082790	24550	3	2A
0005435082823	24550	4	3A
0005435082791	24550	5	3B
0005435082775	24550	6	4B
0005435082798	24550	7	4A
0005435082824	24550	8	5B
0005435082792	24550	9	6A
0005435082797	24550	10	6B
0005435082855	26147	1	1B
0005435082853	26147	2	2A
0005435082852	26147	3	3A
0005435082851	26147	4	4B
0005435082856	26147	5	5A
0005435082854	26147	6	5B
0005434245240	5224	1	1A
0005434245239	5224	2	2A
0005434245256	5224	3	1F
0005432166931	5224	4	4F
0005434245257	5224	5	5F
0005434245262	5224	6	7A
0005434245261	5224	7	8F
0005434245247	5224	8	10A
0005434245253	5224	9	11E
0005434245251	5224	10	12E
0005434245244	5224	11	13A
0005434245243	5224	12	14A
0005434245265	5224	13	15D
0005432166932	5224	14	16B
0005434245264	5224	15	17B
0005434245248	5224	16	17A
0005434245266	5224	17	17C
0005434245254	5224	18	17E
0005434245249	5224	19	19B
0005434245263	5224	20	18F
0005434245242	5224	21	19E
0005435286640	5224	22	20A
0005434245246	5224	23	20C
0005434245259	5224	24	22C
0005434245241	5224	25	23A
0005435286642	5224	26	24A
0005434245260	5224	27	23F
0005435286638	5224	28	24B
0005434245245	5224	29	24D
0005434245238	5224	30	25C
0005433534496	5224	31	26A
0005432166930	5224	32	26F
0005434245255	5224	33	27B
0005434245250	5224	34	27C
0005434245252	5224	35	27E
0005433534495	5224	36	29B
0005434245258	5224	37	31A
0005433615343	5225	1	1A
0005433615385	5225	2	1C
0005432105999	5225	3	1F
0005433785295	5225	4	1D
0005433615366	5225	5	2A
0005433615372	5225	6	2D
0005433615377	5225	7	2C
0005433615348	5225	8	3A
0005433615345	5225	9	2F
0005432106033	5225	10	3C
0005432106004	5225	11	3D
0005433615405	5225	12	4A
0005432105988	5225	13	3F
0005432145133	5225	14	4C
0005433615353	5225	15	4D
0005433785275	5225	16	5A
0005432106013	5225	17	4F
0005433615363	5225	18	5D
0005433615382	5225	19	5C
0005432106032	5225	20	5F
0005433615398	5225	21	6A
0005433615351	5225	22	6C
0005432106012	5225	23	6F
0005433615406	5225	24	6D
0005432106016	5225	25	7A
0005433615386	5225	26	7C
0005433615354	5225	27	7D
0005433785286	5225	28	8A
0005432106022	5225	29	7F
0005432106002	5225	30	8B
0005433615338	5225	31	8D
0005433785291	5225	32	8C
0005433785272	5225	33	8E
0005433785271	5225	34	8F
0005433615402	5225	35	9B
0005433785289	5225	36	9A
0005433615337	5225	37	9C
0005433615357	5225	38	9D
0005433615356	5225	39	9F
0005432106005	5225	40	9E
0005433615339	5225	41	10A
0005432105995	5225	42	10B
0005432106026	5225	43	10D
0005433615369	5225	44	10C
0005433785277	5225	45	10E
0005433615381	5225	46	10F
0005433785261	5225	47	11A
0005433615352	5225	48	11C
0005432145131	5225	49	11B
0005433615376	5225	50	11E
0005432665293	5225	51	11D
0005432106010	5225	52	11F
0005432105994	5225	53	12A
0005432106000	5225	54	12C
0005433785288	5225	55	12B
0005433615400	5225	56	12D
0005432106017	5225	57	12E
0005433785263	5225	58	13A
0005433615383	5225	59	12F
0005433615370	5225	60	13C
0005433785269	5225	61	13B
0005433785264	5225	62	13D
0005432106003	5225	63	13F
0005433615364	5225	64	13E
0005432145130	5225	65	14A
0005433615342	5225	66	14C
0005433785260	5225	67	14B
0005432145132	5225	68	14E
0005433615368	5225	69	14D
0005432105998	5225	70	14F
0005432106019	5225	71	15A
0005433615365	5225	72	15C
0005433785294	5225	73	15B
0005433615380	5225	74	15D
0005433615392	5225	75	15F
0005433615334	5225	76	15E
0005433615344	5225	77	16A
0005432106021	5225	78	16B
0005432105992	5225	79	16C
0005433785273	5225	80	16E
0005432106014	5225	81	16D
0005432106011	5225	82	17A
0005432105990	5225	83	16F
0005432106028	5225	84	17B
0005432106015	5225	85	17C
0005432106009	5225	86	17D
0005433615397	5225	87	17E
0005433785297	5225	88	18A
0005432105986	5225	89	17F
0005433615361	5225	90	18B
0005432105991	5225	91	18C
0005432106018	5225	92	18E
0005432105993	5225	93	18D
0005432106027	5225	94	18F
0005432105987	5225	95	19C
0005432105996	5225	96	19B
0005433615390	5225	97	19D
0005433785285	5225	98	20A
0005433615359	5225	99	19E
0005433785268	5225	100	20B
0005432106001	5225	101	20C
0005433615335	5225	102	20E
0005433615367	5225	103	20D
0005433785280	5225	104	20F
0005433785281	5225	105	21A
0005433785290	5225	106	21B
0005433785292	5225	107	21D
0005432665294	5225	108	21C
0005433785283	5225	109	21E
0005433785296	5225	110	22A
0005433615333	5225	111	21F
0005433615393	5225	112	22B
0005433615375	5225	113	22C
0005433615341	5225	114	22E
0005433615399	5225	115	22D
0005432106030	5225	116	22F
0005433615389	5225	117	23A
0005432106024	5225	118	23C
0005432105989	5225	119	23B
0005432666409	5225	120	23D
0005433785293	5225	121	23E
0005433615379	5225	122	24A
0005433615394	5225	123	23F
0005432106006	5225	124	24B
0005433615362	5225	125	24D
0005433615384	5225	126	24C
0005433615346	5225	127	24E
0005432106023	5225	128	24F
0005432105997	5225	129	25A
0005433785276	5225	130	25C
0005433785270	5225	131	25B
0005433615388	5225	132	25D
0005433615371	5225	133	25F
0005433615396	5225	134	25E
0005433785282	5225	135	26A
0005432666408	5225	136	26B
0005432106008	5225	137	26D
0005433615378	5225	138	26C
0005433615401	5225	139	26F
0005433785262	5225	140	26E
0005433785274	5225	141	27B
0005433785279	5225	142	27A
0005433615350	5225	143	27D
0005433615358	5225	144	27C
0005433615391	5225	145	27E
0005433615360	5225	146	28A
0005433785284	5225	147	27F
0005433615340	5225	148	28B
0005433615395	5225	149	28D
0005432667473	5225	150	28C
0005433785266	5225	151	28E
0005433615355	5225	152	28F
0005432106007	5225	153	29B
0005432106029	5225	154	29A
0005433785265	5225	155	29C
0005433615404	5225	156	29D
0005433615336	5225	157	29E
0005432106020	5225	158	30A
0005433785267	5225	159	29F
0005432106031	5225	160	30B
0005433615387	5225	161	30C
0005433615374	5225	162	30E
0005433615373	5225	163	30D
0005432106025	5225	164	30F
0005433615349	5225	165	31A
0005433615347	5225	166	31C
0005433785287	5225	167	31B
0005433615403	5225	168	31D
0005433785278	5225	169	31E
0005432105985	5225	170	31F
0005432335968	5229	1	1C
0005434265371	5229	2	1A
0005435006982	5229	3	2C
0005434229589	5229	4	2F
0005433688801	5229	5	2D
0005434229586	5229	6	3A
0005435007111	5229	7	3C
0005433688812	5229	8	3D
0005434149842	5229	9	4A
0005434265369	5229	10	4C
0005435007091	5229	11	4F
0005434265378	5229	12	4D
0005435007029	5229	13	5C
0005434311222	5229	14	5D
0005434229584	5229	15	6A
0005435007049	5229	16	5F
0005434229581	5229	17	6C
0005432336039	5229	18	6F
0005434265388	5229	19	6D
0005435007030	5229	20	7A
0005434173555	5229	21	7D
0005432336020	5229	22	8A
0005433688800	5229	23	7F
0005434149837	5229	24	8D
0005435007136	5229	25	8C
0005432336060	5229	26	9A
0005435007125	5229	27	9C
0005434265386	5229	28	9B
0005435006987	5229	29	9D
0005434265377	5229	30	9E
0005434149841	5229	31	10A
0005435007032	5229	32	9F
0005434265382	5229	33	10C
0005433815394	5229	34	10B
0005434229588	5229	35	10E
0005434229572	5229	36	11A
0005434265368	5229	37	10F
0005434265383	5229	38	11C
0005434149833	5229	39	11B
0005432336094	5229	40	11D
0005433815393	5229	41	11F
0005434149838	5229	42	11E
0005434229567	5229	43	12B
0005434149839	5229	44	12C
0005434173557	5229	45	12E
0005434229568	5229	46	12D
0005435006983	5229	47	13B
0005434229577	5229	48	13A
0005434265372	5229	49	13C
0005435007015	5229	50	13F
0005434229576	5229	51	14A
0005434229580	5229	52	14D
0005434265384	5229	53	14C
0005435007027	5229	54	15A
0005432336056	5229	55	14F
0005434229590	5229	56	14E
0005434265370	5229	57	15C
0005434173556	5229	58	15E
0005434265387	5229	59	15D
0005433815395	5229	60	16A
0005433815387	5229	61	16C
0005434311217	5229	62	16D
0005432336025	5229	63	16F
0005432336034	5229	64	17A
0005435007079	5229	65	17C
0005434265374	5229	66	17E
0005434229585	5229	67	17D
0005434149834	5229	68	17F
0005432336093	5229	69	18A
0005434265373	5229	70	18C
0005434149835	5229	71	18B
0005433815384	5229	72	18E
0005434229578	5229	73	18D
0005433815385	5229	74	18F
0005435007070	5229	75	19C
0005435006981	5229	76	19E
0005434265381	5229	77	20A
0005434265379	5229	78	20C
0005435007072	5229	79	20B
0005434229575	5229	80	20D
0005434312314	5229	81	20F
0005434265367	5229	82	21C
0005434173558	5229	83	21B
0005434229574	5229	84	21D
0005432335967	5229	85	21E
0005434229583	5229	86	22B
0005434229582	5229	87	22F
0005434229573	5229	88	22E
0005434265364	5229	89	23C
0005433815365	5229	90	23D
0005433815392	5229	91	23E
0005434265365	5229	92	23F
0005435007038	5229	93	24B
0005435007047	5229	94	24C
0005434229570	5229	95	24D
0005435007135	5229	96	24F
0005435007068	5229	97	24E
0005434265375	5229	98	25A
0005435007037	5229	99	25C
0005434265376	5229	100	25B
0005434312318	5229	101	25E
0005432336026	5229	102	25F
0005434265366	5229	103	26B
0005434149844	5229	104	26A
0005434173559	5229	105	26C
0005435006970	5229	106	26E
0005434229569	5229	107	26D
0005435007069	5229	108	26F
0005435007014	5229	109	27A
0005432336029	5229	110	27C
0005432336055	5229	111	27B
0005433688811	5229	112	27D
0005433688799	5229	113	27E
0005433815380	5229	114	28A
0005435007048	5229	115	28B
0005434265380	5229	116	28D
0005434149843	5229	117	28C
0005434229587	5229	118	28E
0005432336057	5229	119	29A
0005434229571	5229	120	29C
0005435007028	5229	121	29B
0005435007080	5229	122	29D
0005433685508	5229	123	29F
0005434149840	5229	124	29E
0005433685507	5229	125	30A
0005435007050	5229	126	30B
0005435007039	5229	127	30C
0005432335984	5229	128	30F
0005434149836	5229	129	30E
0005434265385	5229	130	31B
0005434229579	5229	131	31D
0005435007071	5229	132	31E
0005433815388	5229	133	31F
0005433784849	8625	1	1D
0005435269812	8625	2	2A
0005434245206	8625	3	1F
0005433784912	8625	4	2D
0005434244978	8625	5	3F
0005433784824	8625	6	4F
0005434245186	8625	7	5A
0005433784825	8625	8	5D
0005433784855	8625	9	5F
0005433784985	8625	10	6C
0005432663034	8625	11	6D
0005433784883	8625	12	7A
0005433784882	8625	13	7D
0005433784867	8625	14	7F
0005433784848	8625	15	8A
0005433784805	8625	16	8B
0005433784881	8625	17	9A
0005435269811	8625	18	9C
0005434245207	8625	19	9E
0005433784847	8625	20	9F
0005435269804	8625	21	10C
0005433785073	8625	22	10B
0005433784856	8625	23	10D
0005433784861	8625	24	10E
0005435269803	8625	25	10F
0005435269808	8625	26	11B
0005433784804	8625	27	11A
0005433784868	8625	28	11C
0005434244915	8625	29	11E
0005434245022	8625	30	11D
0005434245080	8625	31	12D
0005433784981	8625	32	12F
0005434244988	8625	33	13C
0005432666383	8625	34	13D
0005435269809	8625	35	13F
0005433784886	8625	36	15E
0005433784850	8625	37	15D
0005433784901	8625	38	16A
0005433785029	8625	39	16B
0005434245079	8625	40	16C
0005433784896	8625	41	16D
0005433785025	8625	42	17C
0005434244944	8625	43	17B
0005433785163	8625	44	17E
0005432659702	8625	45	17D
0005434245070	8625	46	18A
0005434245065	8625	47	18B
0005434244979	8625	48	19B
0005432659699	8625	49	19E
0005433784892	8625	50	20C
0005434244987	8625	51	20D
0005434245187	8625	52	20F
0005434244977	8625	53	20E
0005433785030	8625	54	21A
0005434245205	8625	55	21C
0005433785090	8625	56	21D
0005435269805	8625	57	21F
0005433785072	8625	58	22D
0005433784893	8625	59	22E
0005433784954	8625	60	23A
0005432666386	8625	61	23D
0005433785172	8625	62	23F
0005434245071	8625	63	23E
0005433784860	8625	64	24D
0005434245041	8625	65	24F
0005433785052	8625	66	25A
0005433784869	8625	67	25E
0005433784990	8625	68	26D
0005434245066	8625	69	27A
0005433785071	8625	70	27F
0005433784923	8625	71	28C
0005434245064	8625	72	28F
0005433784951	8625	73	29A
0005432663039	8625	74	29C
0005433784857	8625	75	29D
0005435269806	8625	76	30A
0005435269807	8625	77	29F
0005433785059	8625	78	30C
0005432666384	8625	79	30E
0005433784974	8625	80	30D
0005435269802	8625	81	30F
0005435269810	8625	82	31B
0005433784996	8625	83	31A
0005433784908	8625	84	31D
0005433614876	8626	1	1A
0005433614836	8626	2	1C
0005433614834	8626	3	2A
0005433614556	8626	4	2D
0005433614774	8626	5	3C
0005433614816	8626	6	5C
0005433614428	8626	7	5F
0005433614517	8626	8	5D
0005433614792	8626	9	6C
0005433614516	8626	10	7D
0005433614861	8626	11	8F
0005433614525	8626	12	9E
0005433614855	8626	13	9F
0005433614372	8626	14	10A
0005433614553	8626	15	11A
0005433614627	8626	16	10F
0005433614557	8626	17	11B
0005433614460	8626	18	11D
0005433614688	8626	19	11F
0005433614436	8626	20	11E
0005433614708	8626	21	12B
0005433614599	8626	22	12D
0005433614687	8626	23	12E
0005433614658	8626	24	13B
0005433614620	8626	25	13D
0005433614586	8626	26	13E
0005433614968	8626	27	13F
0005433614621	8626	28	14D
0005433614504	8626	29	14F
0005433614579	8626	30	15B
0005433614879	8626	31	15C
0005433614580	8626	32	16C
0005433614491	8626	33	17A
0005433614695	8626	34	17B
0005433614747	8626	35	17C
0005433614492	8626	36	17E
0005433614392	8626	37	18B
0005433614339	8626	38	18E
0005433614564	8626	39	18F
0005433614583	8626	40	20A
0005433614734	8626	41	20D
0005433614606	8626	42	20F
0005433614615	8626	43	21D
0005433614486	8626	44	21E
0005433614770	8626	45	22A
0005433614587	8626	46	23A
0005433614614	8626	47	23C
0005433614490	8626	48	24B
0005433614605	8626	49	24C
0005433614624	8626	50	24E
0005433614817	8626	51	24D
0005433614366	8626	52	24F
0005433614738	8626	53	25C
0005433614795	8626	54	25D
0005433614596	8626	55	26B
0005433614485	8626	56	27C
0005433614791	8626	57	27D
0005433614796	8626	58	28C
0005433614533	8626	59	28E
0005433614493	8626	60	29C
0005433614771	8626	61	29F
0005433614854	8626	62	29E
0005433614563	8626	63	30A
0005433614678	8626	64	30F
0005433614699	8626	65	31A
0005433614790	8626	66	31C
0005433614623	8626	67	31B
0005434265196	8627	1	1A
0005432035196	8627	2	1C
0005433534518	8627	3	1F
0005435007242	8627	4	1D
0005434265219	8627	5	2A
0005435007244	8627	6	2D
0005432035217	8627	7	3C
0005432336148	8627	8	3A
0005434229474	8627	9	3D
0005435007230	8627	10	4A
0005434229450	8627	11	3F
0005432336147	8627	12	4C
0005432336149	8627	13	4D
0005434265159	8627	14	4F
0005433815429	8627	15	5C
0005434229381	8627	16	5A
0005434149704	8627	17	5F
0005432336146	8627	18	5D
0005432047585	8627	19	6A
0005432035203	8627	20	6D
0005432035206	8627	21	6C
0005432336139	8627	22	6F
0005435007243	8627	23	7A
0005433815433	8627	24	7C
0005433815432	8627	25	7F
0005435286668	8627	26	7D
0005434265226	8627	27	8A
0005432035213	8627	28	8B
0005434229390	8627	29	8C
0005433689930	8627	30	8E
0005433690944	8627	31	8F
0005434265038	8627	32	9A
0005432035208	8627	33	9D
0005434265123	8627	34	9C
0005432035194	8627	35	9B
0005434229308	8627	36	9E
0005432336143	8627	37	9F
0005434229241	8627	38	10C
0005434265115	8627	39	10B
0005432035210	8627	40	10E
0005434265187	8627	41	10D
0005434265222	8627	42	10F
0005432035200	8627	43	11B
0005434265225	8627	44	11E
0005432035198	8627	45	11D
0005435007238	8627	46	11C
0005434265201	8627	47	11F
0005433688828	8627	48	12A
0005434311239	8627	49	12B
0005435007228	8627	50	12C
0005433689932	8627	51	12E
0005434229224	8627	52	12D
0005434173509	8627	53	12F
0005435007252	8627	54	13B
0005435007247	8627	55	13A
0005432336150	8627	56	13C
0005434149681	8627	57	13D
0005432035201	8627	58	13E
0005433815430	8627	59	14A
0005434149756	8627	60	13F
0005433690943	8627	61	14C
0005434149744	8627	62	14B
0005435007235	8627	63	14D
0005434265188	8627	64	15A
0005434229409	8627	65	14F
0005432035202	8627	66	15B
0005434173519	8627	67	15C
0005434265184	8627	68	15D
0005432035212	8627	69	15F
0005435007249	8627	70	15E
0005432336141	8627	71	16A
0005434149793	8627	72	16B
0005432035193	8627	73	16D
0005434265221	8627	74	16C
0005432035195	8627	75	16E
0005434229382	8627	76	16F
0005432336145	8627	77	17B
0005434265185	8627	78	17A
0005432336142	8627	79	17C
0005434149757	8627	80	17E
0005435007246	8627	81	17D
0005433688829	8627	82	17F
0005435007245	8627	83	18A
0005434265198	8627	84	18B
0005434229420	8627	85	18D
0005435007240	8627	86	18C
0005434149758	8627	87	18E
0005432035204	8627	88	18F
0005432035216	8627	89	19C
0005432035192	8627	90	19B
0005432336144	8627	91	19D
0005435007237	8627	92	20A
0005435007234	8627	93	19E
0005432035218	8627	94	20C
0005435007229	8627	95	20E
0005435007241	8627	96	20D
0005435007227	8627	97	21A
0005432035205	8627	98	21B
0005434149755	8627	99	21D
0005433689933	8627	100	21C
0005435286669	8627	101	21E
0005434311238	8627	102	22A
0005432035214	8627	103	22B
0005432047586	8627	104	22C
0005435007231	8627	105	22E
0005434149731	8627	106	22D
0005434229223	8627	107	22F
0005434229242	8627	108	23A
0005432035211	8627	109	23C
0005435007248	8627	110	23B
0005432035197	8627	111	23D
0005434229264	8627	112	23E
0005434173510	8627	113	24A
0005434265180	8627	114	23F
0005434229370	8627	115	24B
0005433815431	8627	116	24D
0005435007239	8627	117	24C
0005432035207	8627	118	24E
0005432336140	8627	119	25A
0005434173520	8627	120	24F
0005434149724	8627	121	25C
0005434265171	8627	122	25B
0005433689931	8627	123	25D
0005434229294	8627	124	25F
0005435007250	8627	125	25E
0005432035199	8627	126	26A
0005434149751	8627	127	26C
0005434265217	8627	128	26E
0005434229293	8627	129	26D
0005434229303	8627	130	26F
0005432336151	8627	131	27A
0005434265150	8627	132	27B
0005434265149	8627	133	27D
0005434149766	8627	134	27E
0005434149730	8627	135	28A
0005434229320	8627	136	27F
0005434229319	8627	137	28B
0005434229371	8627	138	28D
0005432035190	8627	139	28E
0005432047584	8627	140	28F
0005435007236	8627	141	29B
0005435286667	8627	142	29A
0005432035215	8627	143	29C
0005434265200	8627	144	29E
0005432035191	8627	145	30A
0005434229499	8627	146	29F
0005434265029	8627	147	30B
0005434265124	8627	148	30C
0005435007251	8627	149	30D
0005432035209	8627	150	30F
0005433689929	8627	151	31B
0005434265179	8627	152	31A
0005435007232	8627	153	31C
0005434173511	8627	154	31D
0005434265223	8627	155	31F
0005435007233	8627	156	31E
0005433202507	12587	1	1A
0005433202500	12587	2	1B
0005433202499	12587	3	1C
0005434639329	12587	4	1D
0005433202501	12587	5	2A
0005434639335	12587	6	2B
0005434639412	12587	7	2C
0005434639229	12587	8	2D
0005434639193	12587	9	3A
0005434639349	12587	10	3B
0005434639350	12587	11	3C
0005434639356	12587	12	3D
0005433202503	12587	13	4C
0005434639413	12587	14	5A
0005433202502	12587	15	5B
0005433202497	12587	16	5C
0005434639372	12587	17	5D
0005434639262	12587	18	6A
0005433202508	12587	19	6B
0005434639369	12587	20	6C
0005433202494	12587	21	6D
0005434639269	12587	22	7A
0005434639326	12587	23	7B
0005434639302	12587	24	7C
0005434639485	12587	25	7D
0005434639194	12587	26	18A
0005434639333	12587	27	18B
0005433202504	12587	28	18C
0005434639270	12587	29	19A
0005434639464	12587	30	19B
0005433202506	12587	31	19D
0005434639355	12587	32	20A
0005434639340	12587	33	20B
0005433202498	12587	34	20C
0005434639325	12587	35	20D
0005433202496	12587	36	21A
0005434639330	12587	37	21B
0005433202505	12587	38	21C
0005433202495	12587	39	22B
0005434639484	12587	40	22C
0005433202318	23380	1	1A
0005434639541	23380	2	1B
0005434639538	23380	3	1C
0005434639545	23380	4	1D
0005434639524	23380	5	2B
0005434639543	23380	6	2C
0005434639539	23380	7	2D
0005433202435	23380	8	3A
0005434639526	23380	9	3B
0005434639537	23380	10	3C
0005434639547	23380	11	4A
0005433202343	23380	12	4C
0005432290658	23380	13	5A
0005434639525	23380	14	5B
0005434639523	23380	15	5C
0005433202322	23380	16	5D
0005434639527	23380	17	6B
0005434639529	23380	18	6C
0005433202334	23380	19	6D
0005433202329	23380	20	7A
0005434639544	23380	21	7B
0005432290660	23380	22	7C
0005434639540	23380	23	7D
0005434639531	23380	24	18A
0005434639534	23380	25	18B
0005432290659	23380	26	18D
0005434639532	23380	27	19A
0005434639533	23380	28	19B
0005433202331	23380	29	19C
0005434639530	23380	30	19D
0005434639535	23380	31	20A
0005434639528	23380	32	20B
0005434639536	23380	33	20C
0005433202330	23380	34	20D
0005434639522	23380	35	21A
0005433202346	23380	36	21B
0005433202436	23380	37	21C
0005434639542	23380	38	22A
0005433202319	23380	39	21D
0005434639546	23380	40	22B
0005433202338	23380	41	22D
0005433202383	23380	42	23A
0005434639548	23380	43	23B
0005432328783	21082	1	1A
0005432054333	21082	2	1C
0005432328655	21082	3	1D
0005432383114	21082	4	1F
0005432328782	21082	5	2A
0005432328684	21082	6	2D
0005432054331	21082	7	2F
0005432382918	21082	8	3A
0005432328608	21082	9	3C
0005432383115	21082	10	3D
0005432383064	21082	11	4A
0005432382971	21082	12	4C
0005432383192	21082	13	4D
0005432328632	21082	14	4E
0005432383218	21082	15	4F
0005432383226	21082	16	5A
0005432328730	21082	17	5D
0005432328566	21082	18	5E
0005432054332	21082	19	5F
0005432054330	21082	20	6A
0005432328919	21082	21	6C
0005432382988	21082	22	6D
0005432383197	21082	23	6F
0005432382919	21082	24	7A
0005432383217	21082	25	7C
0005432383254	21082	26	7D
0005432328767	21082	27	7E
0005432383332	21082	28	7F
0005432328741	21082	29	8A
0005432383240	21082	30	8C
0005432328870	21082	31	8D
0005432383200	21082	32	8E
0005432383158	21082	33	8F
0005432328761	21082	34	9A
0005432383161	21082	35	9C
0005432383270	21082	36	9D
0005432383227	21082	37	9E
0005432383041	21082	38	9F
0005432383072	21082	39	10A
0005432383036	21082	40	10C
0005432328609	21082	41	10D
0005432328714	21082	42	10E
0005432328762	21082	43	10F
0005432383201	21082	44	11A
0005432328731	21082	45	11C
0005432328536	21082	46	11D
0005432328746	21082	47	11E
0005432328763	21082	48	11F
0005432328769	21082	49	12A
0005432328490	21082	50	12C
0005432383155	21082	51	12D
0005432383113	21082	52	12E
0005432383321	21082	53	12F
0005432328814	21082	54	13A
0005432383157	21082	55	13C
0005432328745	21082	56	13D
0005432328491	21082	57	13E
0005432383119	21082	58	13F
0005432328772	21082	59	14A
0005432328791	21082	60	14C
0005432328775	21082	61	14D
0005432328383	21082	62	14E
0005432383136	21082	63	14F
0005432383035	21082	64	15A
0005432328657	21082	65	15C
0005432328559	21082	66	15D
0005432383331	21082	67	15E
0005432328786	21082	68	15F
0005432328411	21082	69	16A
0005432328739	21082	70	16C
0005432383129	21082	71	16D
0005432328831	21082	72	16E
0005432383156	21082	73	16F
0005432328568	21082	74	17A
0005432328755	21082	75	17C
0005432328658	21082	76	17E
0005432328611	21082	77	17F
0005432328633	21082	78	18A
0005432328656	21082	79	18C
0005432328771	21082	80	18D
0005432328751	21082	81	18E
0005432383160	21082	82	18F
0005432328631	21082	83	19A
0005432383163	21082	84	19C
0005432328639	21082	85	19D
0005432382972	21082	86	19F
0005432383320	21082	87	20A
0005432383118	21082	88	20C
0005432383309	21082	89	20E
0005432328615	21082	90	20D
0005432328781	21082	91	20F
0005432329100	31275	1	1A
0005432329083	31275	2	1C
0005432329102	31275	3	1F
0005432329111	31275	4	1D
0005432383532	31275	5	2A
0005432383516	31275	6	2C
0005432383509	31275	7	2D
0005432329084	31275	8	2F
0005432329074	31275	9	3A
0005432329067	31275	10	3C
0005432383528	31275	11	3D
0005432329087	31275	12	3F
0005432383517	31275	13	4C
0005432329098	31275	14	4D
0005432383525	31275	15	4E
0005432329095	31275	16	4F
0005432329104	31275	17	5A
0005432383496	31275	18	5C
0005432329103	31275	19	5D
0005432287234	31275	20	5E
0005432383507	31275	21	5F
0005432329077	31275	22	6A
0005432329085	31275	23	6C
0005432383488	31275	24	6D
0005432329071	31275	25	6E
0005432329088	31275	26	6F
0005432329093	31275	27	7A
0005432329068	31275	28	7C
0005432383513	31275	29	7D
0005432383512	31275	30	7E
0005432383524	31275	31	7F
0005432383518	31275	32	8A
0005432287230	31275	33	8C
0005432329072	31275	34	8D
0005432329073	31275	35	8E
0005432383495	31275	36	8F
0005432383521	31275	37	9A
0005432383490	31275	38	9C
0005432383493	31275	39	9D
0005432383505	31275	40	9E
0005432383508	31275	41	9F
0005432383498	31275	42	10A
0005432329089	31275	43	10C
0005432383502	31275	44	10D
0005432329082	31275	45	10E
0005432383531	31275	46	10F
0005432329097	31275	47	11A
0005432383522	31275	48	11C
0005432383491	31275	49	11D
0005432329108	31275	50	11E
0005432329079	31275	51	11F
0005432329094	31275	52	12A
0005432383492	31275	53	12C
0005432383523	31275	54	12D
0005432383519	31275	55	12E
0005432383504	31275	56	12F
0005432383510	31275	57	13A
0005432329092	31275	58	13C
0005432329081	31275	59	13D
0005432329070	31275	60	13E
0005432383494	31275	61	13F
0005432383530	31275	62	14A
0005432383497	31275	63	14C
0005432329105	31275	64	14D
0005432329107	31275	65	14E
0005432329106	31275	66	14F
0005432383506	31275	67	15A
0005432287231	31275	68	15C
0005432329066	31275	69	15D
0005432329110	31275	70	15E
0005432383489	31275	71	15F
0005432329078	31275	72	16A
0005432329075	31275	73	16C
0005432287233	31275	74	16E
0005432329076	31275	75	16D
0005432329091	31275	76	16F
0005432287232	31275	77	17A
0005432329109	31275	78	17C
0005432383511	31275	79	17D
0005432383529	31275	80	17E
0005432329099	31275	81	17F
0005432383526	31275	82	18A
0005432383499	31275	83	18C
0005432383520	31275	84	18D
0005432383514	31275	85	18E
0005432383503	31275	86	18F
0005432329080	31275	87	19A
0005432383515	31275	88	19C
0005432383500	31275	89	19D
0005432383527	31275	90	19E
0005432329101	31275	91	19F
0005432329090	31275	92	20A
0005432329086	31275	93	20C
0005432329069	31275	94	20D
0005432383501	31275	95	20E
0005432329096	31275	96	20F
0005432424833	13297	1	1C
0005432424844	13297	2	1D
0005432424823	13297	3	1F
0005432424827	13297	4	2A
0005432424835	13297	5	2C
0005432424829	13297	6	2D
0005432424840	13297	7	3D
0005432424848	13297	8	4A
0005432424824	13297	9	5C
0005432424838	13297	10	5E
0005432424860	13297	11	5F
0005432424862	13297	12	6D
0005432424822	13297	13	6F
0005432424859	13297	14	7C
0005432424856	13297	15	7D
0005432424845	13297	16	7E
0005432424847	13297	17	8D
0005432424828	13297	18	9C
0005432424826	13297	19	9D
0005432424863	13297	20	9F
0005432424857	13297	21	10A
0005432424855	13297	22	10D
0005432424854	13297	23	11A
0005432424850	13297	24	11C
0005432424836	13297	25	12A
0005432424832	13297	26	12F
0005432424837	13297	27	13E
0005432424851	13297	28	14D
0005432424825	13297	29	14E
0005432424839	13297	30	15D
0005432424831	13297	31	15F
0005432424830	13297	32	16A
0005432424842	13297	33	16C
0005432424849	13297	34	16D
0005432424834	13297	35	16F
0005432424846	13297	36	17C
0005432424853	13297	37	18E
0005432424841	13297	38	19C
0005432424861	13297	39	19E
0005432424858	13297	40	20A
0005432424852	13297	41	20C
0005432424843	13297	42	20E
0005432424421	30722	1	2C
0005432424419	30722	2	2D
0005432424380	30722	3	3F
0005432424402	30722	4	4C
0005432424428	30722	5	4F
0005432424335	30722	6	5C
0005432424277	30722	7	6A
0005432424432	30722	8	6E
0005432424418	30722	9	6F
0005432424460	30722	10	7C
0005432424145	30722	11	7D
0005432424144	30722	12	7F
0005432424320	30722	13	8A
0005432424366	30722	14	8E
0005432424392	30722	15	10A
0005432424308	30722	16	10D
0005432424420	30722	17	10E
0005432424398	30722	18	11E
0005432424454	30722	19	11F
0005432424440	30722	20	12C
0005432424387	30722	21	12F
0005432424390	30722	22	13A
0005432424451	30722	23	13C
0005432424391	30722	24	13F
0005432424431	30722	25	14C
0005432424331	30722	26	14D
0005432424315	30722	27	14E
0005432424438	30722	28	15C
0005432424318	30722	29	16A
0005432424396	30722	30	16D
0005432424397	30722	31	16F
0005432424412	30722	32	17A
0005432424232	30722	33	17E
0005432424455	30722	34	17F
0005432424401	30722	35	18D
0005432424332	30722	36	19E
0005432424416	30722	37	20A
0005432424417	30722	38	20F
0005434157485	9604	1	1C
0005432817745	9604	2	1D
0005434157486	9604	3	1F
0005432901658	9604	4	2A
0005432901707	9604	5	2C
0005432822271	9604	6	2F
0005434157530	9604	7	3A
0005432901634	9604	8	3C
0005432901557	9604	9	3D
0005432817738	9604	10	4D
0005432817740	9604	11	4E
0005432822277	9604	12	5A
0005432817754	9604	13	5C
0005432817750	9604	14	5D
0005432901604	9604	15	5E
0005434448347	9604	16	5F
0005432817737	9604	17	6A
0005432822270	9604	18	6C
0005432822276	9604	19	6E
0005432901491	9604	20	7A
0005432817744	9604	21	7C
0005432817749	9604	22	7D
0005432822274	9604	23	7F
0005432817734	9604	24	8A
0005432901691	9604	25	8C
0005434448346	9604	26	8D
0005432901633	9604	27	8E
0005432817735	9604	28	8F
0005432817743	9604	29	9A
0005432822273	9604	30	9C
0005432817752	9604	31	9D
0005432901661	9604	32	9E
0005432901556	9604	33	10A
0005432817746	9604	34	10C
0005432817736	9604	35	10D
0005432822275	9604	36	10F
0005432817756	9604	37	11A
0005432901662	9604	38	11C
0005434448348	9604	39	11D
0005432901617	9604	40	11E
0005434157493	9604	41	11F
0005432817742	9604	42	12A
0005432289017	9604	43	12C
0005434186202	9604	44	12D
0005432817755	9604	45	12E
0005434157520	9604	46	12F
0005432901692	9604	47	13A
0005432817728	9604	48	13F
0005434157491	9604	49	14A
0005432289015	9604	50	14C
0005432817741	9604	51	14D
0005434448349	9604	52	14F
0005432817731	9604	53	15A
0005432817732	9604	54	15D
0005432817757	9604	55	15E
0005432817753	9604	56	15F
0005432901618	9604	57	16C
0005432901475	9604	58	16D
0005432817739	9604	59	16E
0005434157531	9604	60	17A
0005432817733	9604	61	17C
0005432901685	9604	62	17D
0005432289016	9604	63	17E
0005432817748	9604	64	17F
0005432817751	9604	65	18A
0005432817747	9604	66	18C
0005432901476	9604	67	18D
0005432817730	9604	68	18E
0005432901490	9604	69	18F
0005434186198	9604	70	19A
0005432901607	9604	71	19E
0005432817729	9604	72	19F
0005434157477	9604	73	20A
0005432822272	9604	74	20C
0005434157492	9604	75	20F
0005432817585	28953	1	1F
0005432817434	28953	2	3A
0005432901764	28953	3	3C
0005432822192	28953	4	3D
0005432817568	28953	5	3F
0005432817550	28953	6	4A
0005432817553	28953	7	4C
0005432901765	28953	8	4D
0005434157550	28953	9	4E
0005432822211	28953	10	5C
0005432901775	28953	11	6A
0005432901767	28953	12	6C
0005434448320	28953	13	6D
0005434157553	28953	14	7A
0005432817506	28953	15	6F
0005432817551	28953	16	7C
0005432901766	28953	17	7D
0005432901777	28953	18	8A
0005432817514	28953	19	9A
0005434157552	28953	20	9C
0005434157551	28953	21	9D
0005432817540	28953	22	9E
0005432901762	28953	23	9F
0005432901761	28953	24	10A
0005432822233	28953	25	10E
0005434157549	28953	26	10F
0005432901774	28953	27	11C
0005432901778	28953	28	11D
0005432817515	28953	29	11E
0005432901769	28953	30	12C
0005434157555	28953	31	12D
0005434157554	28953	32	12F
0005432901776	28953	33	13C
0005432817500	28953	34	13E
0005432901768	28953	35	13F
0005432822234	28953	36	15A
0005434186224	28953	37	15C
0005432901770	28953	38	15D
0005432822232	28953	39	15E
0005432817541	28953	40	15F
0005432901773	28953	41	16A
0005432002094	28953	42	16D
0005432817483	28953	43	16E
0005432901763	28953	44	16F
0005432002095	28953	45	17D
0005432817558	28953	46	17E
0005434157548	28953	47	17F
0005432817557	28953	48	18A
0005434186223	28953	49	18E
0005434186222	28953	50	19A
0005432901771	28953	51	19C
0005432817601	28953	52	20A
0005432901772	28953	53	20D
0005432613899	15120	1	1A
0005432611750	15120	2	1B
0005435841093	15120	3	2A
0005432613902	15120	4	2B
0005432613900	15120	5	3A
0005432613901	15120	6	4A
0005432611749	15120	7	3B
0005435841820	15120	8	4B
0005435841821	15120	9	5A
0005432613898	15120	10	5B
0005435842334	31640	1	3A
0005432611730	31640	2	3B
0005435842332	31640	3	4A
0005432611729	31640	4	4B
0005435842333	31640	5	5B
0005432607573	31640	6	6A
0005432948455	11888	1	1C
0005433569575	11888	2	1A
0005432948368	11888	3	1F
0005433569556	11888	4	1D
0005433569561	11888	5	2A
0005433569550	11888	6	2F
0005432948374	11888	7	2D
0005432948515	11888	8	3A
0005433569545	11888	9	3D
0005432948652	11888	10	3C
0005433569546	11888	11	4A
0005433569577	11888	12	3F
0005432948293	11888	13	4D
0005433569579	11888	14	4C
0005432948429	11888	15	4F
0005433569565	11888	16	5C
0005432948434	11888	17	5A
0005432948311	11888	18	5F
0005433569578	11888	19	5D
0005433569553	11888	20	6B
0005432948284	11888	21	6C
0005433569544	11888	22	6F
0005432948337	11888	23	6E
0005433569572	11888	24	6D
0005433569552	11888	25	7A
0005433569574	11888	26	7C
0005433569568	11888	27	7B
0005432948197	11888	28	7E
0005433569557	11888	29	8A
0005432948472	11888	30	7F
0005433569580	11888	31	8B
0005433569549	11888	32	8D
0005432948283	11888	33	8F
0005432948154	11888	34	8E
0005432948427	11888	35	9B
0005432948411	11888	36	9A
0005433569547	11888	37	9D
0005432948401	11888	38	9C
0005433569560	11888	39	9F
0005433569582	11888	40	9E
0005433569539	11888	41	10A
0005432948448	11888	42	10D
0005432948548	11888	43	10F
0005432948294	11888	44	10E
0005432948379	11888	45	11B
0005432948259	11888	46	11D
0005432948414	11888	47	11C
0005433569562	11888	48	11F
0005433569540	11888	49	12A
0005432948338	11888	50	12C
0005432948359	11888	51	12F
0005433569569	11888	52	13A
0005432948495	11888	53	13C
0005432948155	11888	54	13B
0005432948209	11888	55	13E
0005433569564	11888	56	13D
0005432948412	11888	57	14A
0005432948260	11888	58	14B
0005432948657	11888	59	14D
0005432948498	11888	60	14F
0005433569583	11888	61	15B
0005433569576	11888	62	15D
0005432948402	11888	63	15C
0005433569554	11888	64	15E
0005433569541	11888	65	15F
0005433569555	11888	66	16C
0005433569563	11888	67	16B
0005432948527	11888	68	16D
0005433569548	11888	69	17A
0005433569566	11888	70	16F
0005433569551	11888	71	16E
0005432948208	11888	72	17B
0005432948310	11888	73	17D
0005432948375	11888	74	17F
0005432948417	11888	75	17E
0005433569542	11888	76	18A
0005432948547	11888	77	18B
0005432948367	11888	78	18F
0005432948533	11888	79	18E
0005432948358	11888	80	18D
0005432948456	11888	81	19B
0005433569570	11888	82	19A
0005432948459	11888	83	19D
0005433569558	11888	84	20A
0005433569571	11888	85	19F
0005433569538	11888	86	19E
0005433569573	11888	87	20B
0005433569581	11888	88	20D
0005433569543	11888	89	20C
0005433569567	11888	90	20F
0005432948441	11888	91	20E
0005433569559	11888	92	21B
0005432948534	11888	93	21A
0005432948499	11888	94	21E
0005432948428	11888	95	21F
0005433569122	25298	1	1A
0005433568988	25298	2	1F
0005433568927	25298	3	1D
0005432948865	25298	4	1C
0005433569121	25298	5	2C
0005432948877	25298	6	2A
0005433568997	25298	7	2F
0005432948857	25298	8	2D
0005432948879	25298	9	3A
0005432948868	25298	10	3D
0005432948884	25298	11	3C
0005433568996	25298	12	4A
0005433569108	25298	13	3F
0005432948858	25298	14	4D
0005433568616	25298	15	4C
0005433568702	25298	16	5A
0005433569109	25298	17	4F
0005432948866	25298	18	5D
0005433569028	25298	19	5C
0005433568881	25298	20	5F
0005433569047	25298	21	6A
0005433569131	25298	22	6D
0005433568793	25298	23	6C
0005432948863	25298	24	6E
0005433569006	25298	25	7A
0005432948850	25298	26	6F
0005433569107	25298	27	7C
0005433568943	25298	28	7B
0005433568869	25298	29	7E
0005433568928	25298	30	8A
0005433568929	25298	31	7F
0005433569083	25298	32	8B
0005432948849	25298	33	8F
0005432948887	25298	34	8E
0005433569013	25298	35	9A
0005432948878	25298	36	9D
0005432948882	25298	37	9C
0005432948873	25298	38	9B
0005433568862	25298	39	9F
0005432948859	25298	40	9E
0005433568875	25298	41	10A
0005432948851	25298	42	10C
0005432948885	25298	43	10B
0005433569031	25298	44	10D
0005432948872	25298	45	11A
0005432948871	25298	46	10F
0005433568984	25298	47	10E
0005433568942	25298	48	11B
0005433569125	25298	49	11D
0005433569110	25298	50	11C
0005432948855	25298	51	11F
0005432948862	25298	52	11E
0005433569145	25298	53	12B
0005433568989	25298	54	12A
0005432948880	25298	55	12F
0005433569005	25298	56	12E
0005432948876	25298	57	12D
0005433569146	25298	58	13A
0005433568954	25298	59	13C
0005433568983	25298	60	13B
0005432948853	25298	61	13E
0005433569044	25298	62	13D
0005432948870	25298	63	14A
0005433569120	25298	64	13F
0005433569070	25298	65	14C
0005433569062	25298	66	14B
0005433569123	25298	67	14D
0005433568938	25298	68	14F
0005432948848	25298	69	14E
0005432948890	25298	70	15B
0005432948867	25298	71	15A
0005432948860	25298	72	15D
0005432948883	25298	73	15C
0005433568960	25298	74	15E
0005432948869	25298	75	16A
0005432948889	25298	76	15F
0005432948881	25298	77	16B
0005432948852	25298	78	16E
0005433569038	25298	79	16D
0005433569130	25298	80	17A
0005433568794	25298	81	16F
0005433569060	25298	82	17B
0005432948864	25298	83	17C
0005432948886	25298	84	17F
0005433568836	25298	85	17E
0005433569144	25298	86	18A
0005433569048	25298	87	18D
0005433569148	25298	88	18C
0005433568944	25298	89	18B
0005433568981	25298	90	18E
0005432948875	25298	91	19A
0005433568874	25298	92	18F
0005432948856	25298	93	19C
0005433568990	25298	94	19D
0005433569101	25298	95	19F
0005432948854	25298	96	19E
0005433569129	25298	97	20B
0005433569026	25298	98	20A
0005433569027	25298	99	20D
0005433569045	25298	100	20C
0005433569098	25298	101	20E
0005432948888	25298	102	21A
0005433568861	25298	103	20F
0005432948874	25298	104	21C
0005433568826	25298	105	21B
0005432948861	25298	106	21E
0005433569126	25298	107	21F
0005434654965	5382	1	1C
0005435340299	5382	2	1D
0005434654953	5382	3	1F
0005434654958	5382	4	2A
0005434654967	5382	5	2D
0005435340261	5382	6	3C
0005434654942	5382	7	3D
0005434654939	5382	8	4A
0005435340295	5382	9	4F
0005432114234	5382	10	5A
0005434654955	5382	11	5C
0005435340277	5382	12	5F
0005434654956	5382	13	6A
0005435340247	5382	14	6C
0005434654951	5382	15	6D
0005434656575	5382	16	6E
0005435340273	5382	17	6F
0005434654941	5382	18	7A
0005434654957	5382	19	7C
0005434654944	5382	20	7D
0005434654950	5382	21	7E
0005434654949	5382	22	7F
0005434654945	5382	23	8A
0005434654948	5382	24	8E
0005435340184	5382	25	9D
0005434654963	5382	26	9F
0005434654954	5382	27	10A
0005434654938	5382	28	10D
0005435340274	5382	29	11D
0005434654946	5382	30	11E
0005434654952	5382	31	12C
0005435555372	5382	32	12D
0005435340242	5382	33	12F
0005435340254	5382	34	13A
0005435340183	5382	35	13C
0005434654959	5382	36	13E
0005435340314	5382	37	14A
0005434654966	5382	38	14C
0005434654947	5382	39	15D
0005432114232	5382	40	15F
0005434654937	5382	41	16A
0005432114231	5382	42	16C
0005434654940	5382	43	16D
0005434654964	5382	44	16E
0005435340315	5382	45	17A
0005432114235	5382	46	17C
0005434654943	5382	47	17F
0005432114233	5382	48	18A
0005435340243	5382	49	18D
0005434654961	5382	50	18E
0005434654962	5382	51	18F
0005434654968	5382	52	19D
0005434654960	5382	53	19E
0005435340294	5382	54	20A
0005435340265	5382	55	20D
0005435340396	12560	1	2F
0005435340398	12560	2	3C
0005434654862	12560	3	3D
0005434654642	12560	4	4A
0005434654704	12560	5	4F
0005435555389	12560	6	5D
0005434654655	12560	7	5E
0005435340404	12560	8	6F
0005434654815	12560	9	7A
0005434654706	12560	10	7D
0005434654656	12560	11	7E
0005435340401	12560	12	8D
0005434654674	12560	13	9D
0005435340403	12560	14	9F
0005435340399	12560	15	10D
0005435340395	12560	16	10E
0005434654654	12560	17	11C
0005434654813	12560	18	11D
0005435340408	12560	19	11F
0005435340405	12560	20	12D
0005435340406	12560	21	13A
0005434654601	12560	22	13D
0005435340402	12560	23	13F
0005434654703	12560	24	14E
0005434654610	12560	25	15C
0005434654647	12560	26	15D
0005435555390	12560	27	15E
0005435340400	12560	28	16C
0005435340407	12560	29	16E
0005434654602	12560	30	16F
0005434654682	12560	31	17C
0005435340409	12560	32	18D
0005434654814	12560	33	19A
0005434654729	12560	34	19E
0005435340397	12560	35	20A
0005434656561	12560	36	20C
0005434654670	12560	37	20E
0005433716405	7419	1	1C
0005433716419	7419	2	1D
0005433716416	7419	3	2A
0005433716411	7419	4	1F
0005433716425	7419	5	2D
0005433722279	7419	6	3C
0005435266152	7419	7	3A
0005433716434	7419	8	3D
0005433716415	7419	9	3F
0005433716447	7419	10	4B
0005433716444	7419	11	4C
0005433716400	7419	12	4E
0005433656700	7419	13	5C
0005433716410	7419	14	5B
0005433716421	7419	15	5D
0005433716412	7419	16	5E
0005433716426	7419	17	6B
0005433716404	7419	18	6A
0005433656699	7419	19	6D
0005433722277	7419	20	6E
0005433716436	7419	21	7A
0005433716399	7419	22	7C
0005433716433	7419	23	7D
0005433716413	7419	24	7E
0005433716441	7419	25	8A
0005433716403	7419	26	8C
0005433716438	7419	27	8D
0005432078162	7419	28	8E
0005432078161	7419	29	9D
0005433716446	7419	30	9C
0005433716437	7419	31	10C
0005433722280	7419	32	10D
0005433716443	7419	33	11A
0005433719170	7419	34	11D
0005433690941	7419	35	11E
0005433716440	7419	36	12A
0005433722278	7419	37	11F
0005433716417	7419	38	12C
0005432078159	7419	39	13A
0005433716431	7419	40	13B
0005433716423	7419	41	13D
0005433716435	7419	42	14A
0005433719171	7419	43	14C
0005433716398	7419	44	14E
0005433716414	7419	45	15B
0005432428930	7419	46	15A
0005433716430	7419	47	15C
0005433719169	7419	48	15D
0005433716418	7419	49	15E
0005433716397	7419	50	16A
0005435266151	7419	51	16B
0005433716442	7419	52	16E
0005433719168	7419	53	17B
0005433716409	7419	54	17A
0005433716408	7419	55	17E
0005432078158	7419	56	17F
0005433716432	7419	57	18B
0005433716420	7419	58	18D
0005433689928	7419	59	18F
0005433656697	7419	60	19B
0005433716439	7419	61	19D
0005433716406	7419	62	19F
0005433716445	7419	63	20C
0005433656698	7419	64	20B
0005432078157	7419	65	20E
0005433688827	7419	66	21B
0005433716401	7419	67	21C
0005433716402	7419	68	21D
0005433716428	7419	69	21E
0005433716427	7419	70	22B
0005433716422	7419	71	22C
0005432078160	7419	72	22D
0005433716429	7419	73	22F
0005433716424	7419	74	23A
0005433690942	7419	75	23B
0005433716407	7419	76	23E
0005433722281	7419	77	23D
0005433716008	29236	1	1A
0005433715943	29236	2	1F
0005433716030	29236	3	2A
0005433715933	29236	4	2C
0005433715908	29236	5	2D
0005433716055	29236	6	2F
0005433716011	29236	7	3C
0005433715963	29236	8	4A
0005433716047	29236	9	4F
0005433716052	29236	10	5D
0005433688811	29236	11	5C
0005433716174	29236	12	5E
0005435266187	29236	13	6B
0005435266190	29236	14	6A
0005433715990	29236	15	6D
0005433685507	29236	16	6E
0005432428961	29236	17	7A
0005433715898	29236	18	7B
0005435266191	29236	19	7D
0005433716034	29236	20	7E
0005433716116	29236	21	8B
0005433715999	29236	22	8F
0005433715829	29236	23	8E
0005432006786	29236	24	9A
0005433715874	29236	25	9B
0005435266186	29236	26	9E
0005433715927	29236	27	9D
0005433715909	29236	28	9F
0005432428959	29236	29	10C
0005433715901	29236	30	10D
0005433716103	29236	31	11A
0005433688800	29236	32	12B
0005435266188	29236	33	12E
0005433715810	29236	34	13A
0005433715988	29236	35	13B
0005433688812	29236	36	13D
0005433688801	29236	37	14C
0005433719156	29236	38	14B
0005433715858	29236	39	14D
0005435266189	29236	40	15A
0005433716029	29236	41	15B
0005433715900	29236	42	15D
0005433716033	29236	43	15F
0005432006788	29236	44	16B
0005433716048	29236	45	16C
0005433716007	29236	46	16D
0005433715830	29236	47	16F
0005433716224	29236	48	17B
0005433715991	29236	49	17A
0005433715934	29236	50	17C
0005432006787	29236	51	17E
0005433716005	29236	52	17D
0005433715899	29236	53	18A
0005433715985	29236	54	18B
0005433716175	29236	55	18D
0005432428960	29236	56	18F
0005433716053	29236	57	18E
0005433715986	29236	58	19A
0005433715890	29236	59	19C
0005433685508	29236	60	19B
0005433715961	29236	61	19D
0005435266185	29236	62	20A
0005433719155	29236	63	20C
0005433715766	29236	64	20F
0005433715857	29236	65	21A
0005433716139	29236	66	21D
0005433688799	29236	67	22A
0005433716138	29236	68	23A
0005433715926	29236	69	22F
0005433716049	29236	70	23B
0005433716046	29236	71	23D
0005433716000	29236	72	23E
0005433715989	29236	73	23F
0005434095401	8693	1	2C
0005434095399	8693	2	2F
0005434095412	8693	3	3F
0005434095406	8693	4	5A
0005434182197	8693	5	6C
0005434095408	8693	6	7D
0005434182191	8693	7	8A
0005434095409	8693	8	8E
0005434182222	8693	9	9C
0005434184666	8693	10	9E
0005434095411	8693	11	10A
0005434184665	8693	12	11F
0005434095403	8693	13	12C
0005434182192	8693	14	13A
0005434182132	8693	15	13E
0005434095400	8693	16	13F
0005434182198	8693	17	14D
0005434182225	8693	18	14F
0005434095405	8693	19	15A
0005434095413	8693	20	15C
0005434184663	8693	21	17E
0005434095402	8693	22	18C
0005434182125	8693	23	19D
0005434095407	8693	24	20A
0005434095410	8693	25	20D
0005434095404	8693	26	20E
0005434182295	11636	1	1C
0005434182303	11636	2	3A
0005434182304	11636	3	3F
0005434184682	11636	4	4A
0005434182302	11636	5	4C
0005434095289	11636	6	4F
0005434095284	11636	7	6D
0005434182294	11636	8	7F
0005434182300	11636	9	8C
0005434182296	11636	10	9F
0005434182301	11636	11	11A
0005434182293	11636	12	12C
0005434095265	11636	13	12E
0005434095296	11636	14	13E
0005434095285	11636	15	13F
0005434182299	11636	16	14C
0005434182297	11636	17	14E
0005434182298	11636	18	16D
0005434183596	11636	19	16E
0005434182292	11636	20	17D
0005434095290	11636	21	19A
0005434183597	11636	22	19F
0005432906547	1467	1	1C
0005435732454	1467	2	1A
0005432906541	1467	3	1D
0005432906532	1467	4	1F
0005435732442	1467	5	2A
0005433397984	1467	6	2C
0005435732460	1467	7	2F
0005433398057	1467	8	3A
0005435732443	1467	9	3D
0005433398167	1467	10	3F
0005433457004	1467	11	4A
0005433397863	1467	12	4C
0005435732450	1467	13	4D
0005433397931	1467	14	4F
0005433457006	1467	15	5A
0005433398215	1467	16	5C
0005433398048	1467	17	5D
0005432297300	1467	18	5F
0005435732446	1467	19	6A
0005433398079	1467	20	6D
0005435732447	1467	21	6E
0005433398095	1467	22	7A
0005433397985	1467	23	7C
0005433397988	1467	24	7D
0005433398268	1467	25	7E
0005433398087	1467	26	7F
0005433398174	1467	27	8A
0005433397998	1467	28	8D
0005433398198	1467	29	8E
0005433397864	1467	30	8F
0005433398180	1467	31	9A
0005435732451	1467	32	9C
0005432906536	1467	33	9D
0005433398030	1467	34	9F
0005433398214	1467	35	10A
0005432297302	1467	36	10D
0005433398084	1467	37	11C
0005433398060	1467	38	11D
0005435732457	1467	39	11E
0005433397960	1467	40	11F
0005435732459	1467	41	12A
0005433397932	1467	42	12C
0005435732453	1467	43	12F
0005432906533	1467	44	13A
0005433397972	1467	45	13C
0005433457005	1467	46	13D
0005435732458	1467	47	13E
0005433398059	1467	48	13F
0005433398156	1467	49	14A
0005432906546	1467	50	14C
0005435732455	1467	51	14D
0005433457008	1467	52	14E
0005433397970	1467	53	14F
0005433397999	1467	54	15A
0005435732441	1467	55	15C
0005435732444	1467	56	15F
0005433398085	1467	57	16A
0005435732448	1467	58	16C
0005433398207	1467	59	16E
0005435732452	1467	60	16F
0005433398256	1467	61	17A
0005435732445	1467	62	17C
0005433398119	1467	63	17E
0005433397971	1467	64	17F
0005433457007	1467	65	18D
0005433397907	1467	66	18E
0005433397976	1467	67	19A
0005432297301	1467	68	19C
0005435732449	1467	69	19D
0005433398104	1467	70	19E
0005432906548	1467	71	20A
0005435732456	1467	72	20F
0005433456982	19285	1	1C
0005435732332	19285	2	1F
0005433398479	19285	3	2A
0005435732329	19285	4	2C
0005433398485	19285	5	2F
0005433456954	19285	6	3A
0005433398512	19285	7	3C
0005433398484	19285	8	3F
0005433398503	19285	9	4C
0005432906559	19285	10	4D
0005433398487	19285	11	4E
0005435732306	19285	12	4F
0005435732305	19285	13	5A
0005433398489	19285	14	5C
0005433398506	19285	15	5D
0005433398513	19285	16	5E
0005433398486	19285	17	5F
0005433398491	19285	18	6E
0005433398514	19285	19	7A
0005433398490	19285	20	7C
0005433398488	19285	21	7D
0005435732342	19285	22	7F
0005433456986	19285	23	8A
0005433456978	19285	24	8C
0005433398473	19285	25	8D
0005433398507	19285	26	8F
0005435732360	19285	27	9D
0005433398472	19285	28	9E
0005435732284	19285	29	9F
0005433398515	19285	30	10A
0005433398501	19285	31	10C
0005435732320	19285	32	10D
0005433398493	19285	33	10E
0005435732283	19285	34	11A
0005433398481	19285	35	11C
0005433398478	19285	36	11F
0005433398495	19285	37	12A
0005433398499	19285	38	12C
0005433398521	19285	39	12D
0005433398474	19285	40	12E
0005433398498	19285	41	13A
0005433398511	19285	42	13C
0005433398518	19285	43	13D
0005435732300	19285	44	13E
0005433398492	19285	45	13F
0005433398502	19285	46	14A
0005433398471	19285	47	14D
0005433456955	19285	48	14E
0005433398510	19285	49	14F
0005433398477	19285	50	15A
0005433398480	19285	51	15C
0005433398496	19285	52	15D
0005433398505	19285	53	15E
0005433398520	19285	54	15F
0005433398519	19285	55	16A
0005433398504	19285	56	16C
0005433398522	19285	57	16D
0005433398475	19285	58	16E
0005433398482	19285	59	16F
0005435732336	19285	60	17A
0005435732298	19285	61	17D
0005435732369	19285	62	17F
0005433398517	19285	63	18A
0005433398494	19285	64	18C
0005433398516	19285	65	18D
0005433456983	19285	66	18E
0005433398509	19285	67	18F
0005432906558	19285	68	19A
0005433398483	19285	69	19C
0005433398500	19285	70	19D
0005432906557	19285	71	19E
0005433398497	19285	72	20A
0005433456985	19285	73	19F
0005433398476	19285	74	20C
0005435732357	19285	75	20D
0005435732346	19285	76	20E
0005433398508	19285	77	20F
0005434443694	17362	1	1A
0005434443683	17362	2	1C
0005434443754	17362	3	2B
0005434443753	17362	4	2D
0005434443783	17362	5	3B
0005434443727	17362	6	3C
0005434443692	17362	7	4C
0005434443693	17362	8	4D
0005434443768	17362	9	5D
0005434443782	17362	10	7A
0005434443710	17362	11	7B
0005434443699	17362	12	18B
0005434443794	17362	13	18C
0005434443730	17362	14	20B
0005434443671	17362	15	21A
0005434443709	17362	16	21B
0005434443711	17362	17	22A
0005434443720	17362	18	22B
0005434443852	20588	1	2C
0005434443839	20588	2	3A
0005434443845	20588	3	3C
0005434443847	20588	4	4B
0005434443841	20588	5	4D
0005434443842	20588	6	6D
0005434443848	20588	7	7A
0005434443849	20588	8	7B
0005434443843	20588	9	18A
0005434443837	20588	10	18D
0005434443850	20588	11	19A
0005434443844	20588	12	19C
0005434443853	20588	13	21B
0005434443846	20588	14	21C
0005434443851	20588	15	21D
0005434443838	20588	16	22A
0005434443840	20588	17	22B
0005435377588	7237	1	1A
0005434954645	7237	2	1B
0005434954646	7237	3	3A
0005434954644	7237	4	4A
0005435377580	7237	5	5A
0005435377602	28338	1	1A
0005434954625	28338	2	2B
0005434954626	28338	3	3A
0005434954607	28338	4	4A
0005434954624	28338	5	6A
0005435377601	28338	6	6B
0005435893643	4450	1	1A
0005435893647	4450	2	1D
0005434351806	4450	3	2A
0005434183586	4450	4	2C
0005434183577	4450	5	3A
0005435893607	4450	6	4A
0005434351817	4450	7	4C
0005435893613	4450	8	4D
0005434351812	4450	9	5B
0005435893644	4450	10	5C
0005434351815	4450	11	5D
0005435893666	4450	12	6C
0005434351810	4450	13	6D
0005434183571	4450	14	7B
0005435893651	4450	15	7C
0005434351807	4450	16	7D
0005434351814	4450	17	18B
0005435893636	4450	18	18C
0005434326277	4450	19	18D
0005435893606	4450	20	19B
0005434351808	4450	21	19D
0005434351816	4450	22	20A
0005434326275	4450	23	20C
0005434351805	4450	24	20D
0005434351811	4450	25	21A
0005434326276	4450	26	21B
0005434351809	4450	27	21C
0005434351813	4450	28	22B
0005435893629	4450	29	22D
0005435893694	29652	1	2C
0005434351696	29652	2	2D
0005434351679	29652	3	3D
0005435893695	29652	4	4B
0005434351678	29652	5	5A
0005434351677	29652	6	5B
0005435893698	29652	7	6B
0005435893696	29652	8	6C
0005434351698	29652	9	19A
0005434351736	29652	10	19C
0005435893693	29652	11	21A
0005435893692	29652	12	21B
0005434351706	29652	13	21C
0005434351686	29652	14	22B
0005435893697	29652	15	22D
0005435893699	29652	16	23A
0005433342698	1078	1	1A
0005433342665	1078	2	1F
0005433343553	1078	3	2A
0005435545805	1078	4	2C
0005433342901	1078	5	2H
0005433343388	1078	6	2G
0005433463920	1078	7	2F
0005432293231	1078	8	3A
0005433342826	1078	9	3B
0005435545799	1078	10	3G
0005433342703	1078	11	4A
0005433342722	1078	12	3H
0005435545804	1078	13	4B
0005433342999	1078	14	4C
0005433342825	1078	15	4G
0005435545806	1078	16	4F
0005435092163	1078	17	5A
0005433159324	1078	18	5B
0005433343034	1078	19	5C
0005434445264	1078	20	5G
0005435092164	1078	21	5F
0005433343053	1078	22	9A
0005435545803	1078	23	5H
0005433342933	1078	24	9B
0005433343176	1078	25	9G
0005434446537	1078	26	9H
0005433343009	1078	27	11B
0005433342666	1078	28	11D
0005433343041	1078	29	11H
0005433343409	1078	30	11G
0005433343328	1078	31	12A
0005433342747	1078	32	12F
0005433343357	1078	33	13A
0005433158123	1078	34	13F
0005435545801	1078	35	13E
0005433342917	1078	36	13H
0005433343050	1078	37	13G
0005433343077	1078	38	14B
0005433343129	1078	39	14A
0005433342915	1078	40	14E
0005433343571	1078	41	14D
0005433342656	1078	42	14F
0005435545797	1078	43	14G
0005433342887	1078	44	14H
0005433343401	1078	45	15E
0005435092167	1078	46	15D
0005433158135	1078	47	15G
0005433343346	1078	48	15F
0005433342961	1078	49	16B
0005433269727	1078	50	16F
0005433342849	1078	51	16E
0005435092162	1078	52	16H
0005433343169	1078	53	17A
0005433343047	1078	54	17D
0005433343184	1078	55	17B
0005433342619	1078	56	17E
0005432293230	1078	57	18A
0005433342779	1078	58	17H
0005433343201	1078	59	18E
0005433342549	1078	60	18F
0005433343223	1078	61	19B
0005433343397	1078	62	19E
0005433343046	1078	63	20A
0005433342902	1078	64	20D
0005433343040	1078	65	20B
0005433343105	1078	66	20F
0005433343196	1078	67	20E
0005433343273	1078	68	20H
0005435092166	1078	69	21B
0005433343121	1078	70	21F
0005435092161	1078	71	21E
0005435545810	1078	72	22D
0005435545800	1078	73	22B
0005433343164	1078	74	22G
0005433343006	1078	75	22F
0005433342672	1078	76	23A
0005433342601	1078	77	22H
0005433343104	1078	78	23F
0005433342952	1078	79	23E
0005433343374	1078	80	24A
0005433343255	1078	81	23H
0005433342760	1078	82	24D
0005433159305	1078	83	24B
0005433462765	1078	84	24H
0005433343049	1078	85	25D
0005433159326	1078	86	27B
0005434445262	1078	87	27E
0005433342704	1078	88	27D
0005433343520	1078	89	27H
0005433342976	1078	90	27G
0005433342951	1078	91	28A
0005433343433	1078	92	28B
0005433343084	1078	93	28E
0005435545798	1078	94	28D
0005433159327	1078	95	28G
0005435545807	1078	96	28F
0005435545809	1078	97	29B
0005433342699	1078	98	29D
0005433342866	1078	99	30A
0005433462766	1078	100	30D
0005433343519	1078	101	30F
0005433343076	1078	102	30E
0005435092165	1078	103	31A
0005433342848	1078	104	31B
0005433343387	1078	105	31E
0005433342638	1078	106	31G
0005433343245	1078	107	32A
0005433342989	1078	108	32D
0005433343146	1078	109	32B
0005433342618	1078	110	32F
0005435545808	1078	111	33A
0005434445263	1078	112	32H
0005433462767	1078	113	33B
0005433269734	1078	114	33E
0005433343267	1078	115	33G
0005433343052	1078	116	33F
0005433342705	1078	117	33H
0005433342149	1078	118	34A
0005433343195	1078	119	34B
0005433342900	1078	120	34E
0005433343254	1078	121	34G
0005433342824	1078	122	34F
0005435545811	1078	123	34H
0005435092160	1078	124	35B
0005433269735	1078	125	35E
0005433343026	1078	126	35D
0005433343385	1078	127	35G
0005433343187	1078	128	35F
0005433343386	1078	129	35H
0005433343375	1078	130	36E
0005433342855	1078	131	36D
0005433463919	1078	132	36F
0005433343188	1078	133	37A
0005433343106	1078	134	37D
0005433343227	1078	135	37E
0005434445265	1078	136	37F
0005435092168	1078	137	37H
0005433342657	1078	138	37G
0005433343243	1078	139	38B
0005435545802	1078	140	38A
0005433342548	1078	141	38E
0005433342934	1078	142	38G
0005433269715	1078	143	39D
0005433342916	1078	144	39F
0005435092106	17070	1	1C
0005433344013	17070	2	1G
0005433343983	17070	3	2A
0005433269766	17070	4	1H
0005433343923	17070	5	2B
0005433344018	17070	6	3B
0005433343987	17070	7	3F
0005433344005	17070	8	3C
0005433343958	17070	9	3G
0005433344006	17070	10	4B
0005433343947	17070	11	4A
0005433344023	17070	12	4F
0005435092086	17070	13	4C
0005433344011	17070	14	5B
0005435508318	17070	15	5G
0005435092054	17070	16	9B
0005433343999	17070	17	9G
0005433343964	17070	18	11A
0005433343990	17070	19	9H
0005433343972	17070	20	11E
0005433343929	17070	21	11H
0005433343970	17070	22	11G
0005433343985	17070	23	12A
0005433343935	17070	24	12D
0005433343922	17070	25	12B
0005433343926	17070	26	12G
0005433343962	17070	27	12F
0005433343934	17070	28	12H
0005433343937	17070	29	13A
0005433343965	17070	30	13D
0005433343980	17070	31	13B
0005433343979	17070	32	13F
0005433343986	17070	33	14D
0005433343967	17070	34	14F
0005433343968	17070	35	14G
0005433269767	17070	36	14H
0005433344016	17070	37	15B
0005433343951	17070	38	15E
0005435092053	17070	39	15H
0005433343982	17070	40	15G
0005433343984	17070	41	16D
0005433344008	17070	42	16B
0005435092090	17070	43	16E
0005433343995	17070	44	16G
0005433343974	17070	45	17D
0005433344012	17070	46	17B
0005435508304	17070	47	17E
0005433343956	17070	48	17F
0005433343993	17070	49	17H
0005433344015	17070	50	18B
0005433343978	17070	51	18A
0005433343954	17070	52	18F
0005435092103	17070	53	18E
0005435092089	17070	54	18G
0005433343931	17070	55	18H
0005433344010	17070	56	19B
0005433269769	17070	57	19A
0005433343992	17070	58	19E
0005435092049	17070	59	19F
0005433343955	17070	60	20A
0005435092085	17070	61	20D
0005433343977	17070	62	20B
0005435092105	17070	63	20E
0005433343994	17070	64	20H
0005434445243	17070	65	20G
0005433344002	17070	66	21D
0005433343924	17070	67	21E
0005433343971	17070	68	21G
0005433343991	17070	69	21H
0005433343952	17070	70	22A
0005435092047	17070	71	22E
0005435508306	17070	72	22G
0005433344014	17070	73	22H
0005435092108	17070	74	23B
0005433343988	17070	75	23F
0005433344022	17070	76	23E
0005433344000	17070	77	23H
0005433344009	17070	78	24H
0005435092055	17070	79	24G
0005433343959	17070	80	25E
0005433343966	17070	81	27A
0005433344007	17070	82	27D
0005433343928	17070	83	27B
0005433344003	17070	84	27F
0005433343960	17070	85	27G
0005433343949	17070	86	28A
0005433343948	17070	87	28D
0005435092114	17070	88	28G
0005434445228	17070	89	29A
0005433343940	17070	90	28H
0005433343938	17070	91	29D
0005433343973	17070	92	29B
0005433343975	17070	93	29F
0005433343946	17070	94	29E
0005433343930	17070	95	29H
0005433343976	17070	96	30B
0005433343941	17070	97	30A
0005433343997	17070	98	30D
0005433343927	17070	99	30E
0005433343998	17070	100	30G
0005433343942	17070	101	31A
0005433343945	17070	102	31E
0005433344004	17070	103	31D
0005435092060	17070	104	31F
0005433343943	17070	105	32A
0005435092048	17070	106	31H
0005433343936	17070	107	32B
0005435092102	17070	108	32E
0005433343981	17070	109	32H
0005433269768	17070	110	33E
0005433343957	17070	111	33F
0005433344019	17070	112	33G
0005433344020	17070	113	34B
0005433343950	17070	114	34D
0005433343989	17070	115	34F
0005433343961	17070	116	34G
0005435092076	17070	117	35A
0005433343939	17070	118	35D
0005433343932	17070	119	35B
0005433343933	17070	120	36B
0005433343969	17070	121	36A
0005433343953	17070	122	36F
0005435508303	17070	123	36G
0005433344021	17070	124	37D
0005433343925	17070	125	38A
0005433344017	17070	126	37H
0005433343944	17070	127	38D
0005435508302	17070	128	38B
0005435092109	17070	129	38E
0005433343996	17070	130	38F
0005433344001	17070	131	39E
0005433343963	17070	132	39D
0005435092113	17070	133	39F
0005434067696	12821	1	1A
0005434067387	12821	2	1D
0005434067468	12821	3	1C
0005434067648	12821	4	2A
0005432433728	12821	5	1F
0005434067647	12821	6	2C
0005434067704	12821	7	2D
0005434081817	12821	8	2F
0005434067584	12821	9	3C
0005432433727	12821	10	3A
0005434081874	12821	11	3D
0005434081832	12821	12	3F
0005434067238	12821	13	4C
0005434081908	12821	14	4B
0005434081909	12821	15	4E
0005434067794	12821	16	5A
0005434081769	12821	17	5B
0005434067573	12821	18	5C
0005434067574	12821	19	5D
0005434067442	12821	20	5F
0005434081955	12821	21	6A
0005433812921	12821	22	6C
0005433989762	12821	23	6E
0005434081838	12821	24	6D
0005432433730	12821	25	7A
0005434081833	12821	26	6F
0005432159897	12821	27	7C
0005434067323	12821	28	7D
0005434067603	12821	29	7E
0005432161172	12821	30	8A
0005434067362	12821	31	8B
0005434067691	12821	32	8C
0005434067275	12821	33	8D
0005434067640	12821	34	8F
0005434081826	12821	35	9A
0005434067768	12821	36	9E
0005434067548	12821	37	9D
0005434067378	12821	38	9F
0005434081923	12821	39	10B
0005434081856	12821	40	10C
0005434067372	12821	41	10E
0005434067512	12821	42	10D
0005434067439	12821	43	11B
0005432159901	12821	44	11C
0005434081875	12821	45	11E
0005434081836	12821	46	11D
0005434067689	12821	47	11F
0005434067641	12821	48	12A
0005434081794	12821	49	12B
0005434067529	12821	50	12D
0005434067302	12821	51	12C
0005434067673	12821	52	12E
0005434081937	12821	53	12F
0005434081816	12821	54	13C
0005434067405	12821	55	13B
0005434081869	12821	56	13E
0005434067061	12821	57	13D
0005434067324	12821	58	14A
0005434067721	12821	59	13F
0005434067705	12821	60	14C
0005434067453	12821	61	14B
0005434067511	12821	62	14D
0005434081903	12821	63	14F
0005432159899	12821	64	14E
0005434081950	12821	65	15A
0005434067513	12821	66	15C
0005434081882	12821	67	15E
0005434081951	12821	68	15D
0005433989766	12821	69	15F
0005434067301	12821	70	16A
0005434081862	12821	71	16B
0005434081855	12821	72	16C
0005434067406	12821	73	16D
0005434067386	12821	74	16F
0005432433726	12821	75	16E
0005434081897	12821	76	17A
0005434067590	12821	77	17B
0005434067438	12821	78	17C
0005434082031	12821	79	17D
0005434067690	12821	80	17E
0005434067560	12821	81	18A
0005434067184	12821	82	17F
0005434081796	12821	83	18C
0005433812922	12821	84	18E
0005434067658	12821	85	19A
0005434067593	12821	86	18F
0005434067062	12821	87	19D
0005434081954	12821	88	19F
0005434067435	12821	89	19E
0005432433729	12821	90	20A
0005434081997	12821	91	20C
0005434067657	12821	92	21A
0005434067379	12821	93	21B
0005434067281	12821	94	21D
0005434082030	12821	95	21F
0005432159900	12821	96	22D
0005434067487	12821	97	22C
0005434067437	12821	98	22F
0005434067496	12821	99	22E
0005434067549	12821	100	23D
0005432161173	12821	101	23C
0005434067815	12821	102	23F
0005432159898	12821	103	23E
0005434082105	30639	1	1A
0005434068158	30639	2	1C
0005434068110	30639	3	1F
0005434068123	30639	4	1D
0005434068141	30639	5	2C
0005432150258	30639	6	2A
0005432150256	30639	7	2D
0005434068131	30639	8	3A
0005434068150	30639	9	2F
0005434068118	30639	10	3C
0005434068173	30639	11	3D
0005433812882	30639	12	3F
0005432150255	30639	13	4B
0005434068149	30639	14	4A
0005434068176	30639	15	4D
0005433989808	30639	16	4C
0005432150259	30639	17	4F
0005434082092	30639	18	4E
0005434082097	30639	19	5A
0005434068155	30639	20	5C
0005433812879	30639	21	5B
0005432150260	30639	22	5D
0005434082096	30639	23	5E
0005434082102	30639	24	5F
0005434026722	30639	25	6A
0005434068181	30639	26	6C
0005434068130	30639	27	6B
0005434082108	30639	28	6D
0005434082101	30639	29	6E
0005434082104	30639	30	7A
0005432150261	30639	31	6F
0005434068113	30639	32	7C
0005434068160	30639	33	7B
0005434068156	30639	34	7D
0005434068122	30639	35	7E
0005434068166	30639	36	8A
0005432150262	30639	37	7F
0005434068136	30639	38	8B
0005434068167	30639	39	8C
0005434068146	30639	40	8E
0005434082098	30639	41	8D
0005434068127	30639	42	8F
0005434068180	30639	43	9A
0005433812886	30639	44	9B
0005434082094	30639	45	9D
0005434068171	30639	46	9C
0005434068138	30639	47	9E
0005434082103	30639	48	9F
0005433812883	30639	49	10B
0005434068182	30639	50	10D
0005434068143	30639	51	10C
0005434026720	30639	52	11A
0005432150263	30639	53	10E
0005434068151	30639	54	11B
0005434082093	30639	55	11C
0005434068161	30639	56	11E
0005434068148	30639	57	11D
0005434068121	30639	58	11F
0005434026717	30639	59	12B
0005434068169	30639	60	12A
0005434068152	30639	61	12C
0005434026721	30639	62	12D
0005434068178	30639	63	12E
0005434026715	30639	64	12F
0005434068168	30639	65	13B
0005434026723	30639	66	13A
0005433989812	30639	67	13D
0005434068135	30639	68	13C
0005434068179	30639	69	13E
0005434068154	30639	70	13F
0005434082106	30639	71	14A
0005434068153	30639	72	14C
0005432186901	30639	73	14B
0005434068128	30639	74	14D
0005434068162	30639	75	14E
0005434068159	30639	76	15A
0005434068129	30639	77	14F
0005434082090	30639	78	15B
0005434068114	30639	79	15D
0005434068163	30639	80	15C
0005434068137	30639	81	15E
0005434026719	30639	82	15F
0005434068139	30639	83	16B
0005434068164	30639	84	16A
0005434068147	30639	85	16D
0005432186899	30639	86	16C
0005434068115	30639	87	16E
0005434082095	30639	88	17A
0005434068133	30639	89	16F
0005434068126	30639	90	17B
0005434082091	30639	91	17C
0005434068174	30639	92	17E
0005434068134	30639	93	17D
0005433812880	30639	94	17F
0005434068165	30639	95	18A
0005432186898	30639	96	18B
0005433812878	30639	97	18C
0005434068175	30639	98	18D
0005433812887	30639	99	18F
0005434068145	30639	100	18E
0005433989811	30639	101	19A
0005434082099	30639	102	19B
0005432186900	30639	103	19C
0005434068144	30639	104	19E
0005433812881	30639	105	19D
0005434082100	30639	106	19F
0005432150257	30639	107	20A
0005434026716	30639	108	20B
0005434068142	30639	109	20D
0005434068112	30639	110	20C
0005433989809	30639	111	20E
0005434068111	30639	112	20F
0005434068177	30639	113	21A
0005432433696	30639	114	21C
0005434068116	30639	115	21B
0005434068119	30639	116	21D
0005432186897	30639	117	21E
0005434068140	30639	118	21F
0005434068172	30639	119	22B
0005433989810	30639	120	22A
0005434026718	30639	121	22C
0005434082107	30639	122	22D
0005433812893	30639	123	22E
0005434068124	30639	124	23A
0005434068117	30639	125	22F
0005434068125	30639	126	23B
0005434068157	30639	127	23C
0005434068132	30639	128	23E
0005434068170	30639	129	23D
0005434068120	30639	130	23F
0005435766775	5516	1	1C
0005433529313	5516	2	1B
0005435766800	5516	3	1F
0005435766809	5516	4	1G
0005434264988	5516	5	2A
0005433527303	5516	6	1H
0005433527304	5516	7	2C
0005435766769	5516	8	2B
0005435766779	5516	9	2F
0005432140525	5516	10	2G
0005435462340	5516	11	2H
0005435766790	5516	12	3B
0005435766756	5516	13	3F
0005435735176	5516	14	3C
0005435766760	5516	15	3G
0005434265151	5516	16	4B
0005435766783	5516	17	4G
0005435462432	5516	18	4H
0005434831151	5516	19	5B
0005435766771	5516	20	5A
0005435462464	5516	21	5C
0005435462536	5516	22	5G
0005435735177	5516	23	9A
0005434265031	5516	24	5H
0005435725640	5516	25	9B
0005435766788	5516	26	9G
0005435462428	5516	27	9H
0005434831145	5516	28	11D
0005435723064	5516	29	11E
0005435766757	5516	30	11H
0005435720833	5516	31	11G
0005435462442	5516	32	12A
0005432140518	5516	33	12B
0005435766794	5516	34	12F
0005433527302	5516	35	12G
0005435766812	5516	36	13B
0005435766808	5516	37	13A
0005435462446	5516	38	13E
0005435766805	5516	39	13G
0005434265191	5516	40	13H
0005435766758	5516	41	14B
0005435766780	5516	42	14A
0005435725639	5516	43	14D
0005434264987	5516	44	14F
0005434265195	5516	45	14G
0005435766764	5516	46	15D
0005435766802	5516	47	15B
0005435766793	5516	48	15E
0005435725641	5516	49	15G
0005435766810	5516	50	15F
0005435766759	5516	51	16A
0005435462447	5516	52	16D
0005434265255	5516	53	16B
0005435766781	5516	54	16E
0005434265177	5516	55	16G
0005435462572	5516	56	16H
0005435766806	5516	57	17B
0005435462401	5516	58	17A
0005432140520	5516	59	17D
0005434831155	5516	60	17F
0005435766796	5516	61	17H
0005432535830	5516	62	18B
0005435462409	5516	63	18E
0005435462344	5516	64	18D
0005435766765	5516	65	18G
0005435723065	5516	66	18F
0005435766791	5516	67	19A
0005434265106	5516	68	18H
0005435766789	5516	69	19B
0005433527301	5516	70	19E
0005435766773	5516	71	19D
0005435462485	5516	72	19H
0005432140523	5516	73	19G
0005435766814	5516	74	20A
0005435722077	5516	75	20E
0005434265202	5516	76	20D
0005434831146	5516	77	20G
0005435462383	5516	78	20F
0005435462463	5516	79	21A
0005435462571	5516	80	20H
0005435766799	5516	81	21E
0005433529312	5516	82	21D
0005434831147	5516	83	21F
0005435766763	5516	84	21H
0005435725642	5516	85	21G
0005435766786	5516	86	22B
0005434265178	5516	87	22A
0005435723062	5516	88	22E
0005435766753	5516	89	22G
0005434265267	5516	90	22F
0005435735174	5516	91	22H
0005435462548	5516	92	23A
0005435462339	5516	93	23E
0005435766778	5516	94	23G
0005434265121	5516	95	23F
0005435766795	5516	96	24B
0005434265122	5516	97	24A
0005435723063	5516	98	24F
0005435462441	5516	99	24G
0005432140519	5516	100	25D
0005435462541	5516	101	25E
0005435766811	5516	102	25F
0005435462268	5516	103	27D
0005435766776	5516	104	27F
0005432140522	5516	105	27E
0005435766807	5516	106	27G
0005433527300	5516	107	28A
0005435766813	5516	108	27H
0005435462294	5516	109	28B
0005435735175	5516	110	28E
0005434265085	5516	111	28F
0005435462293	5516	112	28H
0005435766768	5516	113	28G
0005435766797	5516	114	29A
0005435766782	5516	115	29D
0005435735178	5516	116	29B
0005435766777	5516	117	29E
0005435725643	5516	118	29H
0005435462570	5516	119	29G
0005435462470	5516	120	30A
0005434265199	5516	121	30D
0005435462400	5516	122	30B
0005435766815	5516	123	30F
0005434265045	5516	124	30H
0005435766762	5516	125	31B
0005435462328	5516	126	31E
0005435462267	5516	127	31F
0005432535836	5516	128	31H
0005435462402	5516	129	31G
0005435462456	5516	130	32A
0005432535829	5516	131	32E
0005435766801	5516	132	32D
0005433529314	5516	133	32H
0005435462448	5516	134	33A
0005435766792	5516	135	33D
0005432535850	5516	136	33B
0005434265210	5516	137	33E
0005435735173	5516	138	33F
0005435766804	5516	139	33H
0005435462608	5516	140	33G
0005432140521	5516	141	34A
0005434265132	5516	142	34D
0005434265074	5516	143	34B
0005435766754	5516	144	34E
0005435043284	5516	145	34G
0005434265055	5516	146	34F
0005435462454	5516	147	35A
0005435462487	5516	148	34H
0005435766785	5516	149	35B
0005435766787	5516	150	35D
0005432535837	5516	151	35H
0005434265206	5516	152	35G
0005435462329	5516	153	35F
0005434265138	5516	154	36A
0005435462427	5516	155	36B
0005435462451	5516	156	36D
0005432140524	5516	157	36F
0005435462371	5516	158	36E
0005435766803	5516	159	36G
0005435766774	5516	160	36H
0005435766798	5516	161	37B
0005435766770	5516	162	37E
0005435766761	5516	163	37D
0005435462367	5516	164	37F
0005432535792	5516	165	37H
0005435720832	5516	166	37G
0005435462341	5516	167	38A
0005435722076	5516	168	38D
0005435766767	5516	169	38F
0005435766784	5516	170	38E
0005435766766	5516	171	39D
0005435766755	5516	172	39F
0005435766772	5516	173	39E
0005434831193	13492	1	1A
0005435462762	13492	2	1B
0005435766184	13492	3	1F
0005435462789	13492	4	1G
0005435766158	13492	5	2A
0005435462763	13492	6	1H
0005435766496	13492	7	2C
0005432194551	13492	8	2B
0005435766147	13492	9	2F
0005435766286	13492	10	3A
0005435725591	13492	11	2H
0005435766497	13492	12	3B
0005434831194	13492	13	3C
0005435462765	13492	14	3G
0005434831197	13492	15	3F
0005435766298	13492	16	3H
0005434265372	13492	17	4B
0005435462782	13492	18	4G
0005435766233	13492	19	4F
0005435462769	13492	20	4H
0005435462764	13492	21	5A
0005434265365	13492	22	5C
0005435725614	13492	23	5F
0005435462766	13492	24	5H
0005435462787	13492	25	9B
0005435766382	13492	26	9A
0005434265382	13492	27	11A
0005434265367	13492	28	11E
0005432535881	13492	29	11D
0005435766448	13492	30	11H
0005435725606	13492	31	11G
0005435766469	13492	32	12D
0005435766209	13492	33	12B
0005434265386	13492	34	12F
0005435725604	13492	35	12E
0005435462773	13492	36	12H
0005435766112	13492	37	13B
0005435765997	13492	38	13D
0005435766299	13492	39	13F
0005435766100	13492	40	14A
0005435766078	13492	41	13H
0005435462777	13492	42	13G
0005435766214	13492	43	14B
0005435043292	13492	44	14D
0005435766031	13492	45	14F
0005435766399	13492	46	14E
0005432194550	13492	47	14G
0005432194548	13492	48	15A
0005435462791	13492	49	14H
0005435462771	13492	50	15B
0005435766305	13492	51	15E
0005435766232	13492	52	15D
0005432535876	13492	53	15F
0005435766375	13492	54	15H
0005435462793	13492	55	16A
0005434265377	13492	56	16D
0005435462794	13492	57	16B
0005435462785	13492	58	16F
0005435766171	13492	59	16H
0005435766381	13492	60	17A
0005435462779	13492	61	17B
0005435766378	13492	62	17F
0005435765959	13492	63	17E
0005435462780	13492	64	17G
0005435766438	13492	65	18B
0005435462767	13492	66	18E
0005435720130	13492	67	18G
0005435462796	13492	68	18F
0005434265371	13492	69	19B
0005435725611	13492	70	19E
0005435766110	13492	71	19D
0005432194549	13492	72	19F
0005434831196	13492	73	19H
0005434265387	13492	74	20A
0005434265384	13492	75	20F
0005435766330	13492	76	20G
0005435766101	13492	77	21A
0005435462790	13492	78	21D
0005435766446	13492	79	21B
0005435766111	13492	80	21F
0005435766287	13492	81	21G
0005435766481	13492	82	22A
0005435462775	13492	83	22D
0005435766119	13492	84	22G
0005435766304	13492	85	22F
0005435766253	13492	86	23A
0005435462781	13492	87	22H
0005435766051	13492	88	23B
0005435462774	13492	89	23F
0005435725592	13492	90	23G
0005435766452	13492	91	23H
0005435462768	13492	92	24B
0005434265388	13492	93	24E
0005434265378	13492	94	24D
0005435766395	13492	95	24F
0005435766200	13492	96	24G
0005435462788	13492	97	25D
0005435723042	13492	98	24H
0005435766173	13492	99	25F
0005432535877	13492	100	27B
0005435723041	13492	101	27A
0005432535878	13492	102	27E
0005435766288	13492	103	27H
0005435766231	13492	104	27G
0005432194547	13492	105	28A
0005434265366	13492	106	28E
0005434265385	13492	107	28F
0005435766180	13492	108	29D
0005435766197	13492	109	29G
0005434265364	13492	110	29F
0005435462799	13492	111	29H
0005434265375	13492	112	30B
0005435765826	13492	113	30A
0005435462797	13492	114	30D
0005435766398	13492	115	30E
0005435462795	13492	116	30G
0005435766391	13492	117	30H
0005435462798	13492	118	31B
0005434265379	13492	119	31A
0005435462770	13492	120	31E
0005435462772	13492	121	31D
0005435766148	13492	122	31F
0005435766377	13492	123	31H
0005435766139	13492	124	32B
0005434265380	13492	125	32E
0005435766109	13492	126	32H
0005435766396	13492	127	32G
0005432535879	13492	128	33B
0005434265376	13492	129	33E
0005435766235	13492	130	33H
0005435462776	13492	131	33G
0005434265373	13492	132	34A
0005435735128	13492	133	34B
0005434265381	13492	134	34E
0005435766172	13492	135	34G
0005434265383	13492	136	34F
0005435462786	13492	137	34H
0005435766097	13492	138	35D
0005434265368	13492	139	35F
0005435462778	13492	140	36A
0005435462783	13492	141	35H
0005434265370	13492	142	36B
0005435725610	13492	143	36D
0005434265374	13492	144	36F
0005435766143	13492	145	36E
0005435766384	13492	146	36G
0005435766453	13492	147	37A
0005435462792	13492	148	37E
0005434265369	13492	149	37D
0005435766283	13492	150	37H
0005435735136	13492	151	37G
0005434831195	13492	152	38D
0005435462784	13492	153	38B
0005435766365	13492	154	38F
0005435766306	13492	155	38H
0005432535880	13492	156	39E
0005435766252	13492	157	39D
0005434602902	18635	1	1A
0005434602895	18635	2	2B
0005434602901	18635	3	3A
0005434602903	18635	4	4B
0005434602905	18635	5	6A
0005434602906	18635	6	5B
0005434602904	18635	7	6B
0005434604888	18722	1	1A
0005434514989	18722	2	2A
0005434513602	18722	3	2B
0005435904709	18722	4	3A
0005434513601	18722	5	3B
0005434514988	18722	6	4A
0005435904710	18722	7	4B
0005434604905	18722	8	5B
0005434514990	18722	9	6B
0005434602918	19203	1	1B
0005434602922	19203	2	2A
0005434514973	19203	3	3A
0005434602920	19203	4	3B
0005434514972	19203	5	4A
0005434514954	19203	6	5A
0005434602919	19203	7	5B
0005434602921	19203	8	6A
0005434602917	19203	9	6B
0005432632712	25090	1	1A
0005435844348	25090	2	1D
0005432649391	25090	3	1F
0005435846285	25090	4	2A
0005435846278	25090	5	2C
0005435844349	25090	6	2F
0005432632725	25090	7	3A
0005432649396	25090	8	3C
0005435846280	25090	9	3D
0005432649427	25090	10	3F
0005435846287	25090	11	4C
0005432632706	25090	12	4D
0005432649390	25090	13	4E
0005435844347	25090	14	4F
0005432649420	25090	15	5A
0005432632704	25090	16	5C
0005432632703	25090	17	5D
0005435846286	25090	18	5E
0005432632700	25090	19	5F
0005432632708	25090	20	6A
0005432632734	25090	21	6D
0005432649407	25090	22	6E
0005432649403	25090	23	6F
0005435846277	25090	24	7A
0005432632691	25090	25	7E
0005432632679	25090	26	7F
0005432632690	25090	27	8C
0005435844345	25090	28	8D
0005432649392	25090	29	8F
0005435846282	25090	30	9A
0005432649385	25090	31	9C
0005435844342	25090	32	9D
0005432632664	25090	33	9E
0005432632718	25090	34	10C
0005435844338	25090	35	10E
0005432632688	25090	36	11A
0005432632678	25090	37	11C
0005435844340	25090	38	11D
0005432632689	25090	39	11F
0005432632701	25090	40	12A
0005432632693	25090	41	12C
0005432632728	25090	42	12D
0005432632730	25090	43	12E
0005432632722	25090	44	12F
0005435846283	25090	45	13C
0005432632657	25090	46	13D
0005432632697	25090	47	13E
0005432632719	25090	48	13F
0005432632709	25090	49	14A
0005432632711	25090	50	14C
0005432632705	25090	51	14D
0005432649421	25090	52	14E
0005432632723	25090	53	15A
0005432632707	25090	54	15C
0005435844341	25090	55	15D
0005435846279	25090	56	15E
0005435846281	25090	57	15F
0005435844343	25090	58	16A
0005435844339	25090	59	16C
0005432632692	25090	60	16D
0005435846284	25090	61	16E
0005432649428	25090	62	16F
0005432649406	25090	63	17A
0005432632677	25090	64	17C
0005432632732	25090	65	17E
0005432632684	25090	66	18C
0005435844344	25090	67	19A
0005432632687	25090	68	19C
0005432632702	25090	69	19E
0005432649410	25090	70	19F
0005432632710	25090	71	20C
0005435844346	25090	72	20F
0005432632729	25090	73	20E
0005433285477	1870	1	1A
0005433008543	1870	2	1C
0005433008599	1870	3	1D
0005433008688	1870	4	1F
0005433008618	1870	5	2A
0005433008601	1870	6	2C
0005433285413	1870	7	2F
0005433285374	1870	8	3A
0005433008681	1870	9	3C
0005433810581	1870	10	3D
0005433008680	1870	11	3F
0005433285405	1870	12	4A
0005433008619	1870	13	4D
0005433810582	1870	14	4E
0005433008591	1870	15	4F
0005433008662	1870	16	5A
0005433008625	1870	17	5C
0005433008600	1870	18	5D
0005433285344	1870	19	5E
0005433810580	1870	20	5F
0005433008562	1870	21	6A
0005433008585	1870	22	6C
0005433008584	1870	23	6D
0005433285310	1870	24	6E
0005433008561	1870	25	6F
0005433008719	1870	26	7A
0005433285301	1870	27	7C
0005433008669	1870	28	7D
0005433008664	1870	29	7F
0005433285318	1870	30	8A
0005433008686	1870	31	8C
0005433285311	1870	32	8D
0005433008822	1870	33	8E
0005433285457	1870	34	8F
0005433285514	1870	35	9A
0005433008705	1870	36	9C
0005433285300	1870	37	9E
0005433008810	1870	38	9F
0005433008592	1870	39	10A
0005433285456	1870	40	10C
0005433008624	1870	41	10D
0005433008839	1870	42	10E
0005433008679	1870	43	10F
0005433285459	1870	44	11C
0005433008665	1870	45	11D
0005433285244	1870	46	11E
0005433008663	1870	47	12A
0005433008783	1870	48	12D
0005433285375	1870	49	12E
0005433008687	1870	50	12F
0005433008753	1870	51	13A
0005433008586	1870	52	13C
0005433008700	1870	53	13D
0005433008678	1870	54	13E
0005433008603	1870	55	13F
0005433285337	1870	56	14C
0005433285373	1870	57	14D
0005433008564	1870	58	14E
0005432295905	1870	59	14F
0005433285223	1870	60	15A
0005433008542	1870	61	15C
0005433008577	1870	62	15D
0005433008563	1870	63	15E
0005433285336	1870	64	16A
0005433008647	1870	65	16C
0005433008604	1870	66	16D
0005432295904	1870	67	16E
0005433008633	1870	68	16F
0005433008798	1870	69	17A
0005433285309	1870	70	17C
0005433008590	1870	71	17D
0005433008614	1870	72	17E
0005433285236	1870	73	17F
0005433008644	1870	74	18A
0005433008741	1870	75	18C
0005433285189	1870	76	18D
0005433008752	1870	77	18E
0005433008740	1870	78	18F
0005433008751	1870	79	19A
0005433008606	1870	80	19C
0005432295903	1870	81	19D
0005433008782	1870	82	19E
0005433285342	1870	83	19F
0005433008794	1870	84	20A
0005433008811	1870	85	20C
0005433008648	1870	86	20E
0005433285386	1870	87	20F
0005433009009	22561	1	1A
0005433285581	22561	2	1C
0005433285568	22561	3	1D
0005433008997	22561	4	1F
0005433008983	22561	5	2A
0005433009000	22561	6	2C
0005433285573	22561	7	2F
0005433008996	22561	8	3A
0005433009007	22561	9	3D
0005433008990	22561	10	4A
0005433285564	22561	11	4D
0005433285562	22561	12	4E
0005433008994	22561	13	4F
0005433009019	22561	14	5A
0005433009010	22561	15	5C
0005433285551	22561	16	5D
0005433009025	22561	17	5E
0005433008993	22561	18	6A
0005433008999	22561	19	6C
0005433009013	22561	20	6D
0005433008986	22561	21	6E
0005433009002	22561	22	6F
0005433285561	22561	23	7A
0005433285574	22561	24	7D
0005433009004	22561	25	7E
0005433285580	22561	26	7F
0005433285576	22561	27	8A
0005433009027	22561	28	8C
0005433009001	22561	29	8D
0005433810525	22561	30	8E
0005433285563	22561	31	8F
0005433009003	22561	32	9C
0005433009023	22561	33	9D
0005433285579	22561	34	9E
0005433009012	22561	35	10A
0005433009016	22561	36	10C
0005433285560	22561	37	10D
0005433285565	22561	38	10F
0005433285553	22561	39	11A
0005433285570	22561	40	11C
0005433810516	22561	41	11D
0005433008989	22561	42	11E
0005433285558	22561	43	11F
0005433009015	22561	44	12A
0005433285557	22561	45	12C
0005433009017	22561	46	12E
0005433285566	22561	47	12F
0005433009014	22561	48	13A
0005433009022	22561	49	13C
0005433009026	22561	50	13D
0005433009021	22561	51	13E
0005433009020	22561	52	13F
0005433285556	22561	53	14C
0005433009011	22561	54	14D
0005433285567	22561	55	14E
0005433008988	22561	56	14F
0005433008998	22561	57	15A
0005433285554	22561	58	15C
0005433285569	22561	59	15E
0005433009006	22561	60	16A
0005433285571	22561	61	15F
0005433810524	22561	62	16C
0005433285559	22561	63	16D
0005433285577	22561	64	16E
0005433285552	22561	65	17A
0005433008985	22561	66	17C
0005433285572	22561	67	17E
0005433008982	22561	68	17F
0005433285578	22561	69	18A
0005433009008	22561	70	18C
0005433009018	22561	71	18D
0005433009005	22561	72	18E
0005433008995	22561	73	18F
0005433008992	22561	74	19A
0005433285575	22561	75	19C
0005433009024	22561	76	19E
0005433008987	22561	77	19F
0005433285555	22561	78	20A
0005433008991	22561	79	20C
0005433810515	22561	80	20D
0005433008984	22561	81	20F
0005433847274	5597	1	1F
0005433847230	5597	2	1D
0005433847264	5597	3	1C
0005433847276	5597	4	2C
0005433847272	5597	5	2A
0005433847247	5597	6	2D
0005433847254	5597	7	3A
0005433847251	5597	8	2F
0005433847267	5597	9	4A
0005433847221	5597	10	3F
0005435282515	5597	11	3D
0005433847224	5597	12	4D
0005434173521	5597	13	4C
0005435282601	5597	14	5A
0005433847242	5597	15	4F
0005433847238	5597	16	5C
0005435282403	5597	17	5F
0005435282609	5597	18	6A
0005433847218	5597	19	6D
0005435282543	5597	20	6C
0005433847245	5597	21	6F
0005435282514	5597	22	7A
0005435282494	5597	23	7C
0005433847259	5597	24	7E
0005434173516	5597	25	7D
0005433847261	5597	26	8A
0005433847265	5597	27	7F
0005433847233	5597	28	8C
0005433847270	5597	29	8B
0005433847237	5597	30	8D
0005433847220	5597	31	8F
0005433847241	5597	32	8E
0005433847223	5597	33	9A
0005433847253	5597	34	9C
0005433847255	5597	35	9F
0005433847240	5597	36	9E
0005433847243	5597	37	10A
0005432081569	5597	38	10C
0005433847269	5597	39	10E
0005433847250	5597	40	10D
0005433815427	5597	41	10F
0005433847222	5597	42	11B
0005432081568	5597	43	11A
0005432081571	5597	44	11D
0005433847246	5597	45	11C
0005435282608	5597	46	11F
0005433847258	5597	47	11E
0005433847266	5597	48	12B
0005435282363	5597	49	12A
0005433847225	5597	50	12C
0005433847219	5597	51	12F
0005433847268	5597	52	12E
0005433847227	5597	53	13A
0005433847231	5597	54	13C
0005435282469	5597	55	13B
0005435282437	5597	56	13D
0005433847226	5597	57	14A
0005433847252	5597	58	13F
0005433847271	5597	59	14C
0005433847248	5597	60	14B
0005433847262	5597	61	14D
0005433847260	5597	62	14F
0005435282490	5597	63	14E
0005433847263	5597	64	15A
0005435282552	5597	65	15C
0005433847275	5597	66	16A
0005432081570	5597	67	16B
0005435282495	5597	68	16E
0005433847256	5597	69	16D
0005433847234	5597	70	16C
0005433847273	5597	71	17D
0005433847235	5597	72	17C
0005435282465	5597	73	17F
0005435282649	5597	74	18B
0005433847249	5597	75	18A
0005433847239	5597	76	18C
0005433847232	5597	77	18E
0005435282610	5597	78	18D
0005433815428	5597	79	19A
0005435282650	5597	80	18F
0005433847228	5597	81	19C
0005435282464	5597	82	19B
0005435282641	5597	83	19D
0005433815426	5597	84	19F
0005435282538	5597	85	20C
0005435282517	5597	86	20B
0005433815425	5597	87	20A
0005433847236	5597	88	20D
0005433847244	5597	89	20E
0005433847257	5597	90	21B
0005434173526	5597	91	20F
0005433847229	5597	92	21D
0005435282553	5597	93	21C
0005432081567	5597	94	21E
0005434173515	5597	95	21F
0005433846763	13843	1	1C
0005433846753	13843	2	1D
0005433846728	13843	3	2A
0005433846597	13843	4	1F
0005433846500	13843	5	2D
0005433815380	13843	6	2C
0005433847139	13843	7	3A
0005435282733	13843	8	3D
0005435282750	13843	9	3C
0005433846715	13843	10	3F
0005433846599	13843	11	4D
0005433846663	13843	12	4C
0005433846965	13843	13	4A
0005433846880	13843	14	4F
0005435282735	13843	15	5C
0005435282742	13843	16	5A
0005433815387	13843	17	5F
0005433846679	13843	18	5D
0005433846598	13843	19	6B
0005433815393	13843	20	6C
0005435282748	13843	21	6E
0005433846662	13843	22	6F
0005435282738	13843	23	7C
0005433846661	13843	24	7E
0005435282739	13843	25	7D
0005433846698	13843	26	7F
0005433846621	13843	27	8C
0005433846757	13843	28	8B
0005435282751	13843	29	8E
0005435282734	13843	30	8D
0005433846864	13843	31	8F
0005433846913	13843	32	9B
0005435282743	13843	33	9A
0005433847018	13843	34	9E
0005433846685	13843	35	9D
0005434173557	13843	36	10A
0005433815392	13843	37	10C
0005433846431	13843	38	10B
0005433846643	13843	39	10E
0005433846754	13843	40	10D
0005433846771	13843	41	11A
0005435282745	13843	42	10F
0005435282732	13843	43	11C
0005433815395	13843	44	11B
0005433846805	13843	45	11D
0005433846717	13843	46	11F
0005433815385	13843	47	12A
0005433846644	13843	48	12C
0005435282746	13843	49	12E
0005435282747	13843	50	12D
0005435282741	13843	51	12F
0005433846912	13843	52	13C
0005432003730	13843	53	13B
0005433846322	13843	54	13E
0005433846769	13843	55	14A
0005433846633	13843	56	13F
0005433846954	13843	57	14B
0005433846686	13843	58	14D
0005433815388	13843	59	14F
0005433846791	13843	60	14E
0005433846961	13843	61	15B
0005433846803	13843	62	15A
0005434173555	13843	63	15C
0005434173559	13843	64	15D
0005433846835	13843	65	16A
0005435282736	13843	66	16C
0005435282740	13843	67	16B
0005433846772	13843	68	16D
0005433846417	13843	69	17A
0005433846742	13843	70	16F
0005433846737	13843	71	17C
0005433846687	13843	72	17B
0005433847032	13843	73	17D
0005433846714	13843	74	17E
0005433846950	13843	75	18B
0005432003728	13843	76	18C
0005433815394	13843	77	18E
0005433846736	13843	78	18D
0005433847019	13843	79	19A
0005433815384	13843	80	18F
0005433815365	13843	81	19C
0005435282737	13843	82	19E
0005433846955	13843	83	19D
0005433846758	13843	84	20B
0005435282744	13843	85	20A
0005433846654	13843	86	20D
0005433846989	13843	87	20C
0005434173556	13843	88	20F
0005432003729	13843	89	20E
0005435282749	13843	90	21B
0005433846651	13843	91	21A
0005433846953	13843	92	21D
0005434173558	13843	93	21C
0005433846482	13843	94	21E
0005433846678	13843	95	21F
0005434620771	7841	1	1B
0005435332387	7841	2	2B
0005434620778	7841	3	2C
0005432112535	7841	4	2D
0005434620770	7841	5	3A
0005434620776	7841	6	3B
0005434620781	7841	7	3C
0005434620774	7841	8	4A
0005435332308	7841	9	4B
0005435332307	7841	10	5B
0005434620786	7841	11	5D
0005434620790	7841	12	6A
0005434620780	7841	13	6B
0005434620772	7841	14	6C
0005432112536	7841	15	6D
0005434620779	7841	16	7A
0005435332368	7841	17	18A
0005434620782	7841	18	18B
0005432112537	7841	19	18D
0005434620784	7841	20	19A
0005435332369	7841	21	19D
0005434620773	7841	22	20A
0005434620789	7841	23	20B
0005434620775	7841	24	20C
0005434620787	7841	25	20D
0005434620785	7841	26	21B
0005434620788	7841	27	21C
0005435332366	7841	28	22A
0005434620777	7841	29	22B
0005434620769	7841	30	23A
0005434620783	7841	31	23B
0005434620543	32995	1	1B
0005434620576	32995	2	1C
0005435332430	32995	3	2A
0005435332431	32995	4	2B
0005434620560	32995	5	2D
0005434620727	32995	6	3A
0005434620511	32995	7	3C
0005435332427	32995	8	3D
0005434620680	32995	9	4A
0005435332428	32995	10	4D
0005435332433	32995	11	5B
0005434620575	32995	12	5D
0005435332426	32995	13	6A
0005434620569	32995	14	6B
0005435332425	32995	15	6D
0005434620592	32995	16	7A
0005434620559	32995	17	7D
0005434620540	32995	18	18A
0005434620618	32995	19	18B
0005435332432	32995	20	19C
0005435332424	32995	21	20B
0005434620544	32995	22	21B
0005435332429	32995	23	21C
0005435332434	32995	24	22C
0005434620561	32995	25	22D
0005434620538	32995	26	23B
0005435785676	4265	1	1A
0005435785660	4265	2	1C
0005435918669	4265	3	1D
0005435785677	4265	4	2A
0005435785683	4265	5	2C
0005435937382	4265	6	2D
0005432190664	4265	7	3A
0005435785654	4265	8	3C
0005435937384	4265	9	3D
0005435785649	4265	10	3F
0005435937381	4265	11	4A
0005435937374	4265	12	4D
0005434994109	4265	13	4E
0005435918668	4265	14	4F
0005432190666	4265	15	5A
0005435785678	4265	16	5D
0005435787372	4265	17	5E
0005435785656	4265	18	5F
0005435785679	4265	19	6A
0005435918643	4265	20	6C
0005435785657	4265	21	6D
0005435785684	4265	22	6E
0005435787374	4265	23	7C
0005435787373	4265	24	7A
0005434994110	4265	25	7F
0005434994114	4265	26	8A
0005435918652	4265	27	8D
0005432190665	4265	28	8E
0005435785665	4265	29	9A
0005435785661	4265	30	9C
0005435785666	4265	31	9D
0005435785674	4265	32	9F
0005435785681	4265	33	10A
0005435785671	4265	34	10D
0005432190662	4265	35	10E
0005435785675	4265	36	10F
0005435785658	4265	37	11D
0005435785682	4265	38	11F
0005435785663	4265	39	12C
0005434994106	4265	40	13A
0005435785669	4265	41	13D
0005435918651	4265	42	13E
0005435785655	4265	43	14A
0005435785668	4265	44	14D
0005435785670	4265	45	14E
0005434994112	4265	46	14F
0005435785672	4265	47	15C
0005434994105	4265	48	15E
0005435785680	4265	49	15F
0005434994113	4265	50	16C
0005434994111	4265	51	16E
0005434994108	4265	52	17D
0005434994107	4265	53	17E
0005435785651	4265	54	17F
0005435785659	4265	55	18A
0005435785650	4265	56	18D
0005432190663	4265	57	18E
0005435918648	4265	58	18F
0005435785667	4265	59	19C
0005435937383	4265	60	19D
0005435785664	4265	61	19E
0005435785673	4265	62	19F
0005435785652	4265	63	20A
0005435785662	4265	64	20C
0005435918662	4265	65	20D
0005435785653	4265	66	20F
0005435787358	27273	1	1F
0005435785359	27273	2	2A
0005435937417	27273	3	2C
0005435785340	27273	4	2D
0005435785330	27273	5	3A
0005435785166	27273	6	3C
0005435785462	27273	7	4A
0005435787357	27273	8	4C
0005435787344	27273	9	4D
0005435785223	27273	10	4F
0005432195710	27273	11	5D
0005435785285	27273	12	5E
0005434994010	27273	13	5F
0005435785483	27273	14	6A
0005435918699	27273	15	6C
0005435785339	27273	16	6D
0005434994021	27273	17	6F
0005434994058	27273	18	7A
0005435785227	27273	19	7D
0005435918696	27273	20	7E
0005435785374	27273	21	7F
0005435785264	27273	22	8A
0005435785218	27273	23	9A
0005435785228	27273	24	9D
0005434994030	27273	25	9E
0005435785187	27273	26	10A
0005435918701	27273	27	10C
0005435785243	27273	28	10E
0005435785208	27273	29	10F
0005435785384	27273	30	11A
0005435785179	27273	31	11C
0005435785240	27273	32	11D
0005435785329	27273	33	11E
0005435937416	27273	34	11F
0005435785118	27273	35	12A
0005434994059	27273	36	12C
0005435918698	27273	37	12D
0005435785383	27273	38	12E
0005434994052	27273	39	13C
0005435785225	27273	40	13F
0005434994033	27273	41	14C
0005434994025	27273	42	14D
0005435787345	27273	43	14E
0005435785085	27273	44	15D
0005434994020	27273	45	15F
0005434994022	27273	46	16A
0005435785196	27273	47	16C
0005435918700	27273	48	16E
0005432195711	27273	49	17A
0005435787359	27273	50	17C
0005435918697	27273	51	17D
0005435785161	27273	52	17E
0005435785177	27273	53	17F
0005435785119	27273	54	18A
0005435785219	27273	55	18D
0005434994024	27273	56	18E
0005435785276	27273	57	19A
0005435785183	27273	58	19C
0005435785328	27273	59	19D
0005435787349	27273	60	19E
0005435785331	27273	61	19F
0005435785412	27273	62	20A
0005435785297	27273	63	20C
0005434994060	27273	64	20D
0005435785226	27273	65	20E
0005435785267	27273	66	20F
0005432146217	19871	1	5A
0005432146216	19871	2	7D
0005432146215	19871	3	22D
0005434082113	4730	1	1B
0005433452759	4730	2	1F
0005432186904	4730	3	1G
0005432460334	4730	4	2A
0005432460294	4730	5	1H
0005432568181	4730	6	2C
0005432568196	4730	7	2B
0005432460332	4730	8	2F
0005432571356	4730	9	2H
0005432460308	4730	10	2G
0005432568154	4730	11	3A
0005434082110	4730	12	3B
0005432460327	4730	13	3C
0005432460298	4730	14	3G
0005432568207	4730	15	4A
0005434082117	4730	16	3H
0005432460336	4730	17	4G
0005432568193	4730	18	4H
0005432460323	4730	19	5B
0005432460300	4730	20	5G
0005434082124	4730	21	5H
0005432460295	4730	22	9B
0005432568191	4730	23	9A
0005432460328	4730	24	9H
0005432460339	4730	25	11D
0005432460325	4730	26	11B
0005432568162	4730	27	11A
0005432568163	4730	28	11F
0005432568206	4730	29	11E
0005432568169	4730	30	11H
0005432568152	4730	31	12E
0005432568200	4730	32	12F
0005432170449	4730	33	12H
0005432568155	4730	34	12G
0005432460340	4730	35	13D
0005434082119	4730	36	13F
0005432568177	4730	37	13E
0005432568202	4730	38	13G
0005432460314	4730	39	13H
0005432170447	4730	40	14A
0005434082132	4730	41	14F
0005432568198	4730	42	14E
0005432571354	4730	43	14H
0005432568199	4730	44	14G
0005432460313	4730	45	15D
0005432568183	4730	46	15B
0005434082131	4730	47	15H
0005432460331	4730	48	16A
0005434082125	4730	49	16D
0005432460326	4730	50	16B
0005432568168	4730	51	16F
0005432568188	4730	52	16G
0005433452758	4730	53	17A
0005432170452	4730	54	17D
0005432170450	4730	55	17E
0005432460305	4730	56	17G
0005432568211	4730	57	18A
0005432568178	4730	58	18E
0005434082134	4730	59	18D
0005432460319	4730	60	18G
0005432186903	4730	61	19A
0005432568170	4730	62	18H
0005432460341	4730	63	19B
0005432568156	4730	64	19D
0005434082127	4730	65	19F
0005432568201	4730	66	19E
0005434082123	4730	67	19H
0005432460311	4730	68	19G
0005432568187	4730	69	20A
0005432568153	4730	70	20D
0005432460297	4730	71	20B
0005432460309	4730	72	20E
0005432460296	4730	73	20G
0005432568159	4730	74	20F
0005432460333	4730	75	21A
0005432568171	4730	76	21D
0005432571355	4730	77	21B
0005432460320	4730	78	21E
0005432568194	4730	79	21G
0005432460322	4730	80	21F
0005432460316	4730	81	21H
0005432460335	4730	82	22B
0005432571357	4730	83	22A
0005434082115	4730	84	22D
0005432460293	4730	85	22E
0005432568205	4730	86	22G
0005434082118	4730	87	22F
0005432568179	4730	88	23A
0005432568189	4730	89	23D
0005433726125	4730	90	23E
0005432460345	4730	91	23G
0005434082120	4730	92	24A
0005432568180	4730	93	23H
0005432460306	4730	94	24B
0005432460310	4730	95	24D
0005432568203	4730	96	24H
0005434082130	4730	97	24G
0005432460338	4730	98	25E
0005432460337	4730	99	25F
0005432568157	4730	100	27B
0005432568165	4730	101	27E
0005434082126	4730	102	27D
0005432460303	4730	103	27F
0005432568212	4730	104	27G
0005432568204	4730	105	28A
0005432460292	4730	106	28D
0005432568176	4730	107	28F
0005432568208	4730	108	28H
0005434082135	4730	109	28G
0005434082116	4730	110	29A
0005432460317	4730	111	29D
0005434082129	4730	112	29B
0005432460330	4730	113	29E
0005434082111	4730	114	29G
0005432568164	4730	115	29F
0005432460344	4730	116	29H
0005432186902	4730	117	30E
0005432568175	4730	118	30H
0005432460324	4730	119	30G
0005432568167	4730	120	31B
0005432170446	4730	121	31F
0005432568209	4730	122	31E
0005434082121	4730	123	32A
0005432568174	4730	124	31H
0005432568184	4730	125	32D
0005432460299	4730	126	32F
0005432460315	4730	127	32G
0005432460321	4730	128	33A
0005432460301	4730	129	32H
0005433451637	4730	130	33B
0005432568197	4730	131	33E
0005432568161	4730	132	33F
0005432170451	4730	133	33G
0005432460343	4730	134	34B
0005432568190	4730	135	34A
0005432460302	4730	136	34E
0005432460307	4730	137	34G
0005432568173	4730	138	34F
0005432568182	4730	139	35A
0005432568192	4730	140	35D
0005432568160	4730	141	35F
0005432568166	4730	142	35E
0005434082136	4730	143	35G
0005432568158	4730	144	36A
0005432568185	4730	145	35H
0005432460342	4730	146	36B
0005432568186	4730	147	36E
0005432460312	4730	148	36D
0005434082109	4730	149	36H
0005432460318	4730	150	36G
0005434082112	4730	151	37A
0005432460304	4730	152	37B
0005434082128	4730	153	37D
0005432568172	4730	154	37F
0005434082133	4730	155	37H
0005432568195	4730	156	37G
0005434082114	4730	157	38A
0005432568213	4730	158	38B
0005434082122	4730	159	38E
0005432568210	4730	160	38G
0005432460329	4730	161	38F
0005432170448	4730	162	39D
0005432567864	30526	1	1B
0005432567647	30526	2	1A
0005432567769	30526	3	1F
0005432459868	30526	4	1C
0005432460046	30526	5	1H
0005432567885	30526	6	2A
0005432567533	30526	7	2B
0005432459865	30526	8	2F
0005432567472	30526	9	2C
0005432459884	30526	10	2G
0005432567722	30526	11	3B
0005432459908	30526	12	3G
0005434081862	30526	13	4A
0005432567776	30526	14	4B
0005432459929	30526	15	4C
0005432567800	30526	16	4G
0005432213643	30526	17	4F
0005432567784	30526	18	5G
0005432567834	30526	19	9A
0005432459871	30526	20	5H
0005434081826	30526	21	9H
0005434081950	30526	22	9G
0005432567828	30526	23	11B
0005432459861	30526	24	11E
0005433452744	30526	25	11D
0005434081997	30526	26	11F
0005432459992	30526	27	11G
0005432567785	30526	28	12A
0005432567768	30526	29	12B
0005432567709	30526	30	12E
0005432213641	30526	31	12D
0005434082031	30526	32	12F
0005434081836	30526	33	12G
0005432460019	30526	34	13B
0005432568017	30526	35	13D
0005432459983	30526	36	13E
0005432567833	30526	37	14A
0005432459957	30526	38	13H
0005432567753	30526	39	13G
0005432567835	30526	40	14B
0005432459930	30526	41	14D
0005434081794	30526	42	14F
0005432459809	30526	43	14G
0005432213640	30526	44	14H
0005432567881	30526	45	15B
0005434081909	30526	46	15G
0005432567687	30526	47	15F
0005432459869	30526	48	15E
0005434081817	30526	49	16A
0005434081796	30526	50	16D
0005432567667	30526	51	16B
0005432459702	30526	52	16E
0005432567611	30526	53	16F
0005432459907	30526	54	16H
0005434081856	30526	55	16G
0005432567958	30526	56	17D
0005434081923	30526	57	17E
0005432567911	30526	58	17G
0005432459914	30526	59	17F
0005432459997	30526	60	18A
0005432459637	30526	61	17H
0005432459793	30526	62	18B
0005432459978	30526	63	18E
0005432459899	30526	64	18D
0005432571335	30526	65	18F
0005432567796	30526	66	18G
0005434081937	30526	67	19A
0005432459931	30526	68	19B
0005432459970	30526	69	19D
0005434081951	30526	70	19F
0005434082030	30526	71	19H
0005432567607	30526	72	19G
0005432459864	30526	73	20A
0005432567516	30526	74	20D
0005432567581	30526	75	20F
0005432567411	30526	76	21D
0005432571334	30526	77	21E
0005432459858	30526	78	21G
0005432567786	30526	79	21H
0005434081838	30526	80	22B
0005432213642	30526	81	22A
0005432459937	30526	82	22D
0005432567773	30526	83	22F
0005432567646	30526	84	22E
0005434081855	30526	85	22G
0005434081769	30526	86	22H
0005432567865	30526	87	23B
0005432567534	30526	88	23E
0005432459925	30526	89	23F
0005432567580	30526	90	23G
0005432567817	30526	91	24A
0005432459860	30526	92	23H
0005434081903	30526	93	24B
0005432567537	30526	94	24E
0005432459638	30526	95	24F
0005432571333	30526	96	24H
0005432567540	30526	97	24G
0005432213639	30526	98	25F
0005432567535	30526	99	27B
0005432567827	30526	100	27A
0005432459794	30526	101	27E
0005432567612	30526	102	27G
0005432567811	30526	103	27F
0005432459787	30526	104	28A
0005432459958	30526	105	28B
0005432459882	30526	106	28D
0005432460012	30526	107	28G
0005433452743	30526	108	28F
0005432459923	30526	109	29A
0005432459820	30526	110	28H
0005432459959	30526	111	29D
0005434081875	30526	112	29H
0005432459701	30526	113	29G
0005432459866	30526	114	30A
0005434081908	30526	115	30D
0005432459883	30526	116	30B
0005432567664	30526	117	30E
0005432567536	30526	118	30G
0005433452740	30526	119	31A
0005434081816	30526	120	30H
0005432459916	30526	121	31B
0005434081954	30526	122	31D
0005432567464	30526	123	31E
0005432567859	30526	124	31H
0005434081882	30526	125	31G
0005432213638	30526	126	32A
0005432161172	30526	127	32B
0005432567606	30526	128	32E
0005432567832	30526	129	32D
0005432567532	30526	130	32F
0005434081833	30526	131	32G
0005432567561	30526	132	33A
0005434081832	30526	133	33B
0005433454873	30526	134	33E
0005432567853	30526	135	33D
0005434081955	30526	136	33F
0005432567755	30526	137	33H
0005434081897	30526	138	34A
0005432567688	30526	139	34D
0005432459898	30526	140	34B
0005432459792	30526	141	34E
0005432161173	30526	142	34G
0005432567758	30526	143	35A
0005432568016	30526	144	34H
0005432567757	30526	145	35B
0005432459872	30526	146	35D
0005432567823	30526	147	35F
0005432567634	30526	148	35H
0005433454881	30526	149	36B
0005432567826	30526	150	36A
0005432567560	30526	151	36E
0005432567544	30526	152	36D
0005432567678	30526	153	36F
0005432459799	30526	154	36H
0005432567444	30526	155	37B
0005432460127	30526	156	37E
0005432460128	30526	157	37D
0005432459703	30526	158	37F
0005434081869	30526	159	37H
0005432460002	30526	160	38A
0005432459740	30526	161	38D
0005432567378	30526	162	38E
0005432459743	30526	163	38F
0005434081874	30526	164	38H
0005432459971	30526	165	38G
0005432459960	30526	166	39D
0005432459845	30526	167	39F
0005432567839	30526	168	39E
0005435720832	13583	1	2A
0005435720833	13583	2	3B
0005435722077	13583	3	4A
0005435722076	13583	4	6B
0005435720134	21112	1	2A
0005435720132	21112	2	2B
0005435720133	21112	3	4A
0005432295903	22770	1	3A
0005432295905	22770	2	3B
0005432295904	22770	3	19C
0005435380305	11084	1	1A
0005433344048	11084	2	1C
0005433344106	11084	3	1F
0005433344089	11084	4	1D
0005435097280	11084	5	2A
0005433344042	11084	6	2C
0005433344041	11084	7	2D
0005433344125	11084	8	2F
0005435508388	11084	9	3C
0005433344115	11084	10	3A
0005435097286	11084	11	3D
0005433344120	11084	12	3F
0005433344060	11084	13	4A
0005433344097	11084	14	4C
0005435508346	11084	15	4B
0005433344088	11084	16	4D
0005435097284	11084	17	4E
0005435097285	11084	18	4F
0005433344057	11084	19	5B
0005433344065	11084	20	5A
0005433344075	11084	21	5C
0005433344114	11084	22	5D
0005433344033	11084	23	5E
0005433344054	11084	24	6B
0005433344109	11084	25	6A
0005433344085	11084	26	6C
0005433344069	11084	27	6D
0005433344124	11084	28	6E
0005433344066	11084	29	7A
0005433344078	11084	30	6F
0005433344079	11084	31	7B
0005433344025	11084	32	7C
0005433344056	11084	33	7D
0005433344059	11084	34	7E
0005433344072	11084	35	7F
0005433344077	11084	36	8B
0005433344091	11084	37	8A
0005435508379	11084	38	8C
0005433344082	11084	39	8E
0005433344035	11084	40	8D
0005433344090	11084	41	8F
0005435508363	11084	42	9A
0005433344084	11084	43	9B
0005435380284	11084	44	9C
0005433344105	11084	45	9E
0005433344102	11084	46	9D
0005433344095	11084	47	9F
0005433344068	11084	48	10C
0005433344103	11084	49	10B
0005433344096	11084	50	10E
0005433344104	11084	51	10D
0005433344062	11084	52	11A
0005433344100	11084	53	11B
0005435508329	11084	54	11D
0005433344044	11084	55	11C
0005433344036	11084	56	11E
0005433344024	11084	57	11F
0005435508342	11084	58	12A
0005433344045	11084	59	12B
0005433344087	11084	60	12D
0005433344031	11084	61	12C
0005435508343	11084	62	12E
0005433344027	11084	63	12F
0005433344119	11084	64	13A
0005433344076	11084	65	13B
0005435380283	11084	66	13D
0005433344067	11084	67	13C
0005435508330	11084	68	13E
0005433344080	11084	69	13F
0005433344055	11084	70	14A
0005433344051	11084	71	14B
0005433344049	11084	72	14D
0005433344026	11084	73	14C
0005433344064	11084	74	14E
0005433344123	11084	75	14F
0005433344058	11084	76	15A
0005433344046	11084	77	15C
0005433344092	11084	78	15B
0005433344117	11084	79	15D
0005433344116	11084	80	15F
0005433344043	11084	81	15E
0005433344039	11084	82	16B
0005433344032	11084	83	16A
0005435380306	11084	84	16C
0005433344063	11084	85	16D
0005435097288	11084	86	16E
0005433344110	11084	87	17A
0005433344029	11084	88	16F
0005433344030	11084	89	17B
0005433344111	11084	90	17C
0005433344061	11084	91	17D
0005433344112	11084	92	17E
0005433344107	11084	93	18A
0005435508326	11084	94	17F
0005433344038	11084	95	18C
0005435097281	11084	96	18B
0005433344070	11084	97	18D
0005435380298	11084	98	18E
0005435508331	11084	99	18F
0005435097287	11084	100	19A
0005433344073	11084	101	19C
0005433344053	11084	102	19B
0005433344052	11084	103	19D
0005435508358	11084	104	19F
0005435097282	11084	105	20B
0005433344094	11084	106	20A
0005435097283	11084	107	20C
0005433344118	11084	108	20E
0005433344122	11084	109	20D
0005433344037	11084	110	20F
0005433344086	11084	111	21A
0005433344101	11084	112	21B
0005433344074	11084	113	21D
0005433344093	11084	114	21C
0005433344050	11084	115	21F
0005433344081	11084	116	21E
0005435097289	11084	117	22A
0005433344099	11084	118	22C
0005433344034	11084	119	22B
0005433344083	11084	120	22D
0005433344098	11084	121	22E
0005433344028	11084	122	22F
0005433344108	11084	123	23B
0005433344047	11084	124	23A
0005433344121	11084	125	23C
0005433344113	11084	126	23D
0005433344071	11084	127	23F
0005433344040	11084	128	23E
0005433343374	17108	1	1A
0005433342722	17108	2	1C
0005433342961	17108	3	1D
0005433343357	17108	4	1F
0005433342855	17108	5	2A
0005433343409	17108	6	2D
0005433342656	17108	7	2C
0005433342760	17108	8	2F
0005433343188	17108	9	3A
0005433342848	17108	10	3D
0005433343006	17108	11	3C
0005435545810	17108	12	3F
0005433342672	17108	13	4A
0005435545806	17108	14	4C
0005435545805	17108	15	4B
0005433343433	17108	16	4D
0005435545804	17108	17	4E
0005435380337	17108	18	4F
0005433343053	17108	19	5B
0005435545800	17108	20	5A
0005433343106	17108	21	5C
0005433342934	17108	22	5D
0005433343267	17108	23	5E
0005433343401	17108	24	5F
0005433342548	17108	25	6B
0005433343187	17108	26	6A
0005433342999	17108	27	6C
0005433343146	17108	28	6D
0005432293231	17108	29	6F
0005433342698	17108	30	6E
0005433343387	17108	31	7B
0005433342902	17108	32	7A
0005433343223	17108	33	7C
0005433343046	17108	34	7E
0005433343195	17108	35	7D
0005433342747	17108	36	8A
0005433343164	17108	37	7F
0005433342952	17108	38	8B
0005435097195	17108	39	8C
0005433343176	17108	40	8D
0005435545799	17108	41	8E
0005435097203	17108	42	9A
0005433343026	17108	43	8F
0005433343245	17108	44	9B
0005433343184	17108	45	9D
0005435545811	17108	46	9C
0005435545808	17108	47	9E
0005433343243	17108	48	9F
0005433343084	17108	49	10B
0005433343121	17108	50	10C
0005433343519	17108	51	10D
0005435380336	17108	52	11A
0005435545797	17108	53	10E
0005433342989	17108	54	11B
0005433342619	17108	55	11D
0005433342951	17108	56	11C
0005433342915	17108	57	11E
0005433342826	17108	58	11F
0005433343227	17108	59	12A
0005433343040	17108	60	12B
0005433343105	17108	61	12D
0005435545801	17108	62	12C
0005433343385	17108	63	12E
0005433343009	17108	64	13A
0005433343397	17108	65	12F
0005433342699	17108	66	13B
0005435545802	17108	67	13C
0005433343328	17108	68	13D
0005435097197	17108	69	13E
0005433343034	17108	70	13F
0005435097211	17108	71	14B
0005433342917	17108	72	14A
0005433342666	17108	73	14C
0005432293230	17108	74	14D
0005433342705	17108	75	14F
0005433343052	17108	76	14E
0005433343273	17108	77	15B
0005433343050	17108	78	15A
0005433343553	17108	79	15C
0005433343041	17108	80	15D
0005433342638	17108	81	15E
0005435097196	17108	82	16A
0005433343375	17108	83	15F
0005433342601	17108	84	16B
0005433342933	17108	85	16C
0005435097210	17108	86	16D
0005433343104	17108	87	16F
0005433342976	17108	88	16E
0005433342866	17108	89	17B
0005433342901	17108	90	17A
0005435545798	17108	91	17C
0005435380334	17108	92	17E
0005433343169	17108	93	17D
0005435097204	17108	94	17F
0005433342824	17108	95	18A
0005433343571	17108	96	18B
0005433342657	17108	97	18C
0005433342704	17108	98	18D
0005433342703	17108	99	18F
0005433342887	17108	100	18E
0005435380335	17108	101	19A
0005435097198	17108	102	19B
0005433342849	17108	103	19D
0005433343049	17108	104	19C
0005433343520	17108	105	19F
0005435097202	17108	106	19E
0005435545803	17108	107	20A
0005435545807	17108	108	20C
0005433342618	17108	109	20B
0005433343388	17108	110	20D
0005433343076	17108	111	20E
0005433343077	17108	112	20F
0005433343196	17108	113	21A
0005433343386	17108	114	21C
0005433342149	17108	115	21B
0005433342900	17108	116	21D
0005433343201	17108	117	21E
0005433343255	17108	118	22B
0005433343129	17108	119	22A
0005433342549	17108	120	22C
0005433342916	17108	121	22E
0005435545809	17108	122	22D
0005435380338	17108	123	23A
0005433342825	17108	124	22F
0005433343346	17108	125	23B
0005433343254	17108	126	23C
0005433342665	17108	127	23D
0005433342779	17108	128	23F
0005433343047	17108	129	23E
0005433481240	9117	1	1C
0005432919752	9117	2	2A
0005433507344	9117	3	2C
0005432919830	9117	4	2D
0005433507345	9117	5	2F
0005432919867	9117	6	3A
0005433481239	9117	7	3C
0005433507346	9117	8	3F
0005432919843	9117	9	4A
0005433507354	9117	10	4C
0005434158971	9117	11	4D
0005432919849	9117	12	4E
0005433481237	9117	13	4F
0005432919892	9117	14	5A
0005433481238	9117	15	5C
0005433507350	9117	16	6A
0005432919848	9117	17	6C
0005432919834	9117	18	6E
0005433507355	9117	19	7D
0005432919766	9117	20	8A
0005433481236	9117	21	8C
0005433507349	9117	22	8D
0005432919822	9117	23	8E
0005432919865	9117	24	8F
0005433507356	9117	25	9E
0005434158972	9117	26	10A
0005433481241	9117	27	10D
0005432919882	9117	28	10E
0005433481234	9117	29	10F
0005432919881	9117	30	11C
0005432919931	9117	31	11F
0005433507352	9117	32	12C
0005432919753	9117	33	12D
0005433507343	9117	34	13A
0005432919847	9117	35	13C
0005433507347	9117	36	13D
0005433507342	9117	37	13E
0005433481235	9117	38	14A
0005432919927	9117	39	15A
0005432919850	9117	40	15E
0005432919914	9117	41	15F
0005432919866	9117	42	17A
0005432919891	9117	43	17C
0005433507348	9117	44	17D
0005432919853	9117	45	18A
0005433507341	9117	46	18D
0005433507353	9117	47	18F
0005433507351	9117	48	19F
0005432919928	9117	49	20C
0005432919802	9117	50	20F
0005434158999	20437	1	1D
0005432920070	20437	2	2D
0005432920072	20437	3	3C
0005433507172	20437	4	3D
0005432920076	20437	5	3F
0005432920069	20437	6	4C
0005432920062	20437	7	4D
0005432920064	20437	8	4E
0005433507245	20437	9	4F
0005433481170	20437	10	5D
0005432920080	20437	11	5F
0005432920074	20437	12	6A
0005433507177	20437	13	6C
0005433507187	20437	14	6D
0005433481168	20437	15	6E
0005432920078	20437	16	7A
0005434159003	20437	17	7C
0005434159002	20437	18	7D
0005432920067	20437	19	7E
0005433507236	20437	20	8C
0005432920068	20437	21	8E
0005432920077	20437	22	9D
0005432920081	20437	23	10A
0005433481167	20437	24	10D
0005432920071	20437	25	11E
0005432920059	20437	26	11F
0005432920082	20437	27	12C
0005433481172	20437	28	12E
0005433507206	20437	29	12F
0005432920061	20437	30	13C
0005433507217	20437	31	13D
0005432920065	20437	32	13E
0005433481192	20437	33	13F
0005432920066	20437	34	15A
0005433507237	20437	35	15D
0005433481201	20437	36	16A
0005432920079	20437	37	16E
0005432920075	20437	38	17E
0005434158998	20437	39	17F
0005433507201	20437	40	18D
0005432920060	20437	41	18E
0005433481202	20437	42	18F
0005434159000	20437	43	19C
0005434159001	20437	44	19E
0005432920073	20437	45	19F
0005433507193	20437	46	20C
0005432920063	20437	47	20D
0005432394138	10180	1	1B
0005435178995	10180	2	2A
0005432396277	10180	3	3B
0005435179693	10180	4	4A
0005432396275	10180	5	4B
0005432394137	10180	6	5A
0005435179692	10180	7	6A
0005435178994	10180	8	5B
0005432396276	10180	9	6B
0005432396240	18365	1	1A
0005432396241	18365	2	1B
0005432400123	18365	3	2A
0005432396251	18365	4	3A
0005432396217	18365	5	2B
0005432400122	18365	6	3B
0005435179402	18365	7	4A
0005432396250	18365	8	4B
0005432396218	18365	9	5B
0005432396245	18365	10	5A
0005432400131	18365	11	6A
0005432400132	18365	12	6B
0005435626162	11038	1	1C
0005435126372	11038	2	1D
0005435626102	11038	3	1F
0005435626103	11038	4	2A
0005435554194	11038	5	2C
0005435554191	11038	6	2D
0005435554193	11038	7	2F
0005435126421	11038	8	3A
0005435126365	11038	9	3C
0005435126259	11038	10	3D
0005435626113	11038	11	3F
0005435126306	11038	12	4A
0005435126251	11038	13	4C
0005435126384	11038	14	4D
0005434928325	11038	15	4E
0005435126353	11038	16	4F
0005434411820	11038	17	5E
0005435126210	11038	18	5F
0005435126324	11038	19	6A
0005435626118	11038	20	6C
0005435556703	11038	21	6D
0005435126519	11038	22	6E
0005435126453	11038	23	6F
0005435126562	11038	24	7A
0005435626128	11038	25	7D
0005435126366	11038	26	7E
0005435126520	11038	27	8A
0005435554187	11038	28	8D
0005435126321	11038	29	8E
0005435126276	11038	30	8F
0005435626110	11038	31	9A
0005435554186	11038	32	9C
0005435126407	11038	33	9D
0005435126554	11038	34	9E
0005434411819	11038	35	10A
0005435626160	11038	36	9F
0005435126419	11038	37	10C
0005435126531	11038	38	10D
0005435554195	11038	39	10E
0005435126286	11038	40	10F
0005435626104	11038	41	11C
0005435626124	11038	42	11A
0005435556702	11038	43	11D
0005435554190	11038	44	11E
0005435126334	11038	45	11F
0005435126347	11038	46	12A
0005435126256	11038	47	12C
0005435126325	11038	48	12D
0005435554192	11038	49	12F
0005435126326	11038	50	13A
0005435126340	11038	51	13D
0005435126391	11038	52	13E
0005435556694	11038	53	13F
0005435626163	11038	54	14A
0005435126438	11038	55	14C
0005435126532	11038	56	14D
0005435126395	11038	57	14E
0005435126361	11038	58	14F
0005434928327	11038	59	15A
0005435126555	11038	60	15C
0005435126468	11038	61	15E
0005435126422	11038	62	15F
0005435126371	11038	63	16C
0005435126396	11038	64	16D
0005435126492	11038	65	16E
0005435126258	11038	66	16F
0005435126275	11038	67	17A
0005434928326	11038	68	17C
0005435126385	11038	69	17D
0005435126416	11038	70	17E
0005435126274	11038	71	17F
0005435626112	11038	72	18A
0005435554174	11038	73	18C
0005435126452	11038	74	18D
0005435126346	11038	75	18E
0005434411818	11038	76	18F
0005435126397	11038	77	19D
0005435126075	11038	78	19E
0005435556697	11038	79	19F
0005435126467	11038	80	20A
0005435126333	11038	81	20C
0005435126561	11038	82	20D
0005435554181	11038	83	20E
0005435556704	11038	84	20F
0005435126754	14663	1	1A
0005435626341	14663	2	1C
0005435626361	14663	3	1D
0005435126755	14663	4	2C
0005435126735	14663	5	2F
0005435126762	14663	6	3A
0005435626340	14663	7	3D
0005435626365	14663	8	3F
0005435126734	14663	9	4A
0005435126745	14663	10	4C
0005435126763	14663	11	4D
0005435126742	14663	12	4E
0005435626358	14663	13	4F
0005435126736	14663	14	5A
0005435626367	14663	15	5C
0005435126761	14663	16	5D
0005435126732	14663	17	5E
0005435126739	14663	18	5F
0005435626351	14663	19	6C
0005435126764	14663	20	6D
0005435626359	14663	21	6E
0005435126770	14663	22	6F
0005435626356	14663	23	7A
0005435126744	14663	24	7C
0005435126759	14663	25	7D
0005435626369	14663	26	7E
0005435626349	14663	27	7F
0005435126766	14663	28	8A
0005435626348	14663	29	8C
0005435626353	14663	30	8D
0005435126768	14663	31	8E
0005435126749	14663	32	8F
0005435626342	14663	33	9A
0005435126753	14663	34	9D
0005435126750	14663	35	9E
0005435556715	14663	36	9F
0005434411784	14663	37	10C
0005435126740	14663	38	10D
0005435126757	14663	39	10E
0005435626354	14663	40	11A
0005435626360	14663	41	11C
0005435626364	14663	42	11D
0005434411788	14663	43	12A
0005435126751	14663	44	12C
0005435126746	14663	45	12E
0005435126752	14663	46	12F
0005435626345	14663	47	13A
0005435626343	14663	48	13C
0005435554228	14663	49	13D
0005435126737	14663	50	13E
0005435626355	14663	51	13F
0005435126741	14663	52	14A
0005435626344	14663	53	14D
0005435626370	14663	54	14E
0005435126767	14663	55	14F
0005435626362	14663	56	15A
0005435626366	14663	57	15C
0005435554230	14663	58	15D
0005435626347	14663	59	15E
0005435626368	14663	60	16A
0005435126760	14663	61	16C
0005435126765	14663	62	16D
0005435626350	14663	63	16E
0005435626363	14663	64	16F
0005435126733	14663	65	17C
0005435126738	14663	66	17D
0005435626357	14663	67	17F
0005435126769	14663	68	18C
0005435126758	14663	69	18D
0005434411777	14663	70	18E
0005435126747	14663	71	19A
0005435626346	14663	72	19C
0005435126748	14663	73	19D
0005435554227	14663	74	19E
0005435126756	14663	75	19F
0005435626352	14663	76	20A
0005435556716	14663	77	20C
0005435126743	14663	78	20D
0005435554229	14663	79	20F
0005432398234	7122	1	1A
0005435443335	7122	2	3C
0005435715633	7122	3	3D
0005435715635	7122	4	3F
0005432400162	7122	5	4A
0005432400159	7122	6	4C
0005435216589	7122	7	4D
0005435443326	7122	8	4E
0005432400161	7122	9	5A
0005432400160	7122	10	5D
0005435443322	7122	11	5E
0005435715618	7122	12	5F
0005435715621	7122	13	6D
0005435216588	7122	14	6E
0005432398231	7122	15	6F
0005435715624	7122	16	7C
0005435715623	7122	17	7E
0005435715632	7122	18	7F
0005432400164	7122	19	8A
0005435715628	7122	20	8C
0005435443316	7122	21	8F
0005435443339	7122	22	9C
0005435221057	7122	23	9D
0005435443331	7122	24	9F
0005435715622	7122	25	10D
0005435715625	7122	26	10F
0005435219199	7122	27	11C
0005435443298	7122	28	11D
0005435715617	7122	29	11E
0005432398233	7122	30	12C
0005435216591	7122	31	12E
0005432398232	7122	32	13C
0005435216582	7122	33	13D
0005435443299	7122	34	13F
0005435216580	7122	35	14A
0005435443340	7122	36	14C
0005435443332	7122	37	14D
0005435216590	7122	38	14F
0005435715631	7122	39	15A
0005435715626	7122	40	15C
0005435715629	7122	41	15D
0005435715619	7122	42	15E
0005435715620	7122	43	15F
0005435216581	7122	44	16A
0005435219198	7122	45	16C
0005435715634	7122	46	16D
0005435443327	7122	47	16E
0005435715630	7122	48	16F
0005435219200	7122	49	17A
0005435443300	7122	50	17C
0005435443333	7122	51	17D
0005435443334	7122	52	18F
0005435715627	7122	53	19A
0005432400163	7122	54	19E
0005432398235	7122	55	19F
0005435219197	7122	56	20A
0005435216583	7122	57	20E
0005435715476	27095	1	1A
0005435715391	27095	2	1F
0005435715467	27095	3	2A
0005435715436	27095	4	2F
0005432394099	27095	5	3A
0005435715448	27095	6	3C
0005435715478	27095	7	3D
0005435715447	27095	8	3F
0005435715442	27095	9	4A
0005435443398	27095	10	4F
0005435715531	27095	11	5A
0005435715444	27095	12	5C
0005435715529	27095	13	5E
0005435715504	27095	14	6A
0005432398198	27095	15	7F
0005435443402	27095	16	8C
0005435715450	27095	17	8F
0005432394098	27095	18	9E
0005435715446	27095	19	9F
0005432398197	27095	20	10A
0005432394105	27095	21	10D
0005435715441	27095	22	10E
0005435715481	27095	23	11A
0005435443399	27095	24	11D
0005435715443	27095	25	11E
0005435715475	27095	26	11F
0005432398191	27095	27	12A
0005435443403	27095	28	12D
0005432398196	27095	29	13A
0005435443401	27095	30	13C
0005435443400	27095	31	13D
0005435715482	27095	32	13E
0005435715527	27095	33	13F
0005435715437	27095	34	14C
0005435715466	27095	35	14D
0005432394109	27095	36	14E
0005435715451	27095	37	15C
0005435715470	27095	38	15D
0005435715456	27095	39	15E
0005435715509	27095	40	16A
0005432394113	27095	41	16C
0005435715406	27095	42	16F
0005435443404	27095	43	17C
0005435715510	27095	44	17D
0005435715390	27095	45	18C
0005435443405	27095	46	18D
0005435443397	27095	47	18E
0005435715505	27095	48	19A
0005435443396	27095	49	19C
0005432394097	27095	50	19E
0005432394106	27095	51	20E
0005435715528	27095	52	20F
0005434084975	2732	1	1A
0005434084973	2732	2	2A
0005434084974	2732	3	1B
0005434084976	2732	4	3A
0005433060403	2732	5	3B
0005434084972	2732	6	5A
0005434084971	2732	7	6B
0005434084938	28506	1	1A
0005434084927	28506	2	2A
0005434084939	28506	3	1B
0005434084926	28506	4	2B
0005434084928	28506	5	3A
0005433060437	28506	6	3B
0005434084923	28506	7	4A
0005434084945	28506	8	5A
0005433060439	28506	9	4B
0005434084922	28506	10	5B
0005433060438	28506	11	6B
0005435541073	11412	1	1F
0005435540946	11412	2	3C
0005435517903	11412	3	4A
0005435517935	11412	4	4C
0005435517938	11412	5	5E
0005435517915	11412	6	6A
0005435517960	11412	7	6C
0005435541017	11412	8	6D
0005435541002	11412	9	7A
0005435541027	11412	10	7C
0005435541018	11412	11	8A
0005435541007	11412	12	8D
0005435541029	11412	13	8E
0005435541028	11412	14	9E
0005435540965	11412	15	10A
0005435517936	11412	16	10D
0005435541071	11412	17	10F
0005435517914	11412	18	11C
0005435541016	11412	19	12C
0005435541046	11412	20	12E
0005435540887	11412	21	14C
0005435540947	11412	22	14E
0005435540997	11412	23	15A
0005435541039	11412	24	15F
0005435541070	11412	25	19D
0005435541030	11412	26	19E
0005435541047	11412	27	19F
0005435517900	11412	28	20C
0005435517899	11412	29	20D
0005435541008	11412	30	20E
0005435529433	22268	1	1A
0005435529452	22268	2	1C
0005435529446	22268	3	1F
0005435529448	22268	4	3D
0005435541188	22268	5	4A
0005435541185	22268	6	4C
0005435541177	22268	7	4D
0005435529453	22268	8	4E
0005435541176	22268	9	5A
0005435541182	22268	10	5C
0005435541191	22268	11	5E
0005435529438	22268	12	5F
0005435541194	22268	13	6A
0005435541180	22268	14	6E
0005435529432	22268	15	7D
0005435529441	22268	16	7E
0005435541187	22268	17	7F
0005435529443	22268	18	8A
0005435541186	22268	19	8C
0005435541189	22268	20	8D
0005435541190	22268	21	8E
0005432294507	22268	22	8F
0005432294508	22268	23	9A
0005435541198	22268	24	9E
0005435541195	22268	25	10E
0005435529440	22268	26	11C
0005435529439	22268	27	12A
0005435529455	22268	28	12D
0005435529445	22268	29	13A
0005435529449	22268	30	13E
0005435529444	22268	31	14A
0005435541183	22268	32	14D
0005435529454	22268	33	14E
0005435541184	22268	34	14F
0005435541193	22268	35	15A
0005435529450	22268	36	15C
0005435529451	22268	37	15F
0005435529442	22268	38	16E
0005435529436	22268	39	16F
0005435529437	22268	40	17A
0005435541181	22268	41	17D
0005435541196	22268	42	18A
0005435529435	22268	43	18C
0005435541178	22268	44	18D
0005435541197	22268	45	18E
0005435541179	22268	46	19F
0005435541192	22268	47	20C
0005435529447	22268	48	20D
0005435529434	22268	49	20F
0005434907795	2275	1	1C
0005434907782	2275	2	1D
0005434907778	2275	3	1F
0005434907751	2275	4	2A
0005433251477	2275	5	2C
0005434907783	2275	6	2F
0005434907749	2275	7	3D
0005434907758	2275	8	4A
0005434907766	2275	9	4C
0005433251626	2275	10	4D
0005434907780	2275	11	4F
0005433251449	2275	12	5A
0005433251595	2275	13	5C
0005433251484	2275	14	5D
0005434907785	2275	15	5E
0005434907773	2275	16	5F
0005434907756	2275	17	6A
0005434907746	2275	18	6C
0005433400990	2275	19	6E
0005434907789	2275	20	6F
0005433251500	2275	21	7A
0005434907791	2275	22	7C
0005433251427	2275	23	7E
0005433251419	2275	24	7F
0005434907747	2275	25	8A
0005434907769	2275	26	8C
0005434907774	2275	27	8D
0005434907799	2275	28	8E
0005433251590	2275	29	8F
0005434907796	2275	30	9C
0005433251436	2275	31	9A
0005433400978	2275	32	9D
0005434907792	2275	33	9E
0005434907793	2275	34	10A
0005434907761	2275	35	9F
0005433251584	2275	36	10C
0005434907763	2275	37	10D
0005434907754	2275	38	10E
0005434907770	2275	39	10F
0005434907798	2275	40	11A
0005434907753	2275	41	11D
0005434907750	2275	42	11C
0005434907779	2275	43	11F
0005434907777	2275	44	12A
0005434907775	2275	45	12D
0005434907786	2275	46	12E
0005433400983	2275	47	13A
0005434907768	2275	48	13C
0005434907787	2275	49	13D
0005434907771	2275	50	13E
0005434907765	2275	51	13F
0005434907800	2275	52	14C
0005434907762	2275	53	14D
0005434907759	2275	54	14E
0005434907752	2275	55	14F
0005434907794	2275	56	15A
0005434907790	2275	57	15E
0005433251565	2275	58	15F
0005433251476	2275	59	16A
0005434907797	2275	60	16C
0005434907760	2275	61	16F
0005434907764	2275	62	17C
0005434907767	2275	63	17D
0005434907784	2275	64	17E
0005434907772	2275	65	17F
0005433251404	2275	66	18A
0005434907757	2275	67	18C
0005434907755	2275	68	18E
0005434907748	2275	69	18F
0005434907781	2275	70	19C
0005433251627	2275	71	19E
0005434907788	2275	72	20A
0005433251403	2275	73	20C
0005433251439	2275	74	20D
0005433251585	2275	75	20E
0005434907776	2275	76	20F
0005434907319	25573	1	1A
0005433251750	25573	2	1C
0005434907264	25573	3	1F
0005433251772	25573	4	2A
0005434907320	25573	5	2C
0005434907192	25573	6	2D
0005434907209	25573	7	2F
0005433251761	25573	8	3A
0005433251759	25573	9	3C
0005434907258	25573	10	3D
0005434907311	25573	11	3F
0005433251774	25573	12	4A
0005433401010	25573	13	4C
0005434907276	25573	14	4D
0005434907307	25573	15	4E
0005434907259	25573	16	4F
0005434907341	25573	17	5A
0005434907160	25573	18	5C
0005434907153	25573	19	5D
0005433251749	25573	20	5E
0005433251755	25573	21	5F
0005434907152	25573	22	6A
0005433251757	25573	23	6C
0005434907205	25573	24	6D
0005434907275	25573	25	6F
0005434907177	25573	26	7A
0005433251775	25573	27	7C
0005434907159	25573	28	7D
0005434907346	25573	29	7E
0005433251778	25573	30	7F
0005433251773	25573	31	8C
0005434907210	25573	32	8A
0005433401011	25573	33	8D
0005433251770	25573	34	8E
0005433251769	25573	35	8F
0005433251754	25573	36	9A
0005433251768	25573	37	9C
0005434907165	25573	38	9D
0005433251752	25573	39	9E
0005433401012	25573	40	9F
0005433251779	25573	41	10A
0005434907290	25573	42	10C
0005433251758	25573	43	10D
0005434907312	25573	44	10E
0005434907306	25573	45	10F
0005434907300	25573	46	11A
0005433251776	25573	47	11C
0005434907304	25573	48	11E
0005434907048	25573	49	12A
0005433251764	25573	50	12C
0005434907105	25573	51	12D
0005434907134	25573	52	12E
0005433251765	25573	53	12F
0005433251767	25573	54	13A
0005433251753	25573	55	13C
0005434907339	25573	56	13D
0005434907235	25573	57	13F
0005433251763	25573	58	14A
0005434907321	25573	59	14C
0005433251762	25573	60	14D
0005434907211	25573	61	14F
0005433251766	25573	62	14E
0005434907017	25573	63	15A
0005434907280	25573	64	15C
0005433251780	25573	65	15D
0005433251771	25573	66	15E
0005434907267	25573	67	15F
0005434907347	25573	68	16A
0005434907178	25573	69	16C
0005434907201	25573	70	16E
0005434907340	25573	71	16F
0005433251751	25573	72	17A
0005434907104	25573	73	17C
0005434907250	25573	74	17D
0005434907191	25573	75	17E
0005433251756	25573	76	17F
0005434907272	25573	77	18A
0005434907230	25573	78	18C
0005434907052	25573	79	18D
0005434906871	25573	80	18E
0005434907313	25573	81	18F
0005434907169	25573	82	19A
0005434907170	25573	83	19C
0005433251781	25573	84	19D
0005434907202	25573	85	19E
0005433251777	25573	86	19F
0005434907279	25573	87	20A
0005433251760	25573	88	20C
0005434907130	25573	89	20D
0005434907016	25573	90	20E
0005434907263	25573	91	20F
0005432621173	2541	1	1B
0005432621164	2541	2	1C
0005432621168	2541	3	3D
0005432621170	2541	4	5B
0005432621176	2541	5	6B
0005432621174	2541	6	7B
0005432621171	2541	7	7A
0005432621166	2541	8	7C
0005432862235	2541	9	7D
0005432621172	2541	10	19B
0005432621175	2541	11	19C
0005432862298	2541	12	20A
0005432621165	2541	13	20B
0005432862234	2541	14	21A
0005432621163	2541	15	21B
0005432862313	2541	16	21C
0005432621162	2541	17	22D
0005432621169	2541	18	23A
0005432621167	2541	19	23B
0005432621132	28070	1	1A
0005432621079	28070	2	1B
0005432621055	28070	3	1D
0005432862376	28070	4	2C
0005432621012	28070	5	2D
0005432621030	28070	6	3B
0005432621034	28070	7	3C
0005432862374	28070	8	4A
0005432862377	28070	9	4B
0005432621053	28070	10	4C
0005432621073	28070	11	5A
0005432621101	28070	12	5B
0005432621100	28070	13	5C
0005432621040	28070	14	6A
0005432621031	28070	15	18C
0005432621080	28070	16	18D
0005432862375	28070	17	19B
0005432621067	28070	18	19C
0005432621029	28070	19	20A
0005432862372	28070	20	20B
0005432621011	28070	21	20C
0005432862370	28070	22	21B
0005432862371	28070	23	22D
0005432862373	28070	24	23B
0005434097481	11798	1	2A
0005434097479	11798	2	3A
0005434097480	11798	3	5A
0005434097488	13019	1	4A
0005434097490	13019	2	4B
0005434097489	13019	3	6B
0005433452758	30993	1	4A
0005433452759	30993	2	4B
0005433451637	30993	3	5A
0005433452744	31393	1	1B
0005433454881	31393	2	2A
0005433454873	31393	3	4B
0005433452740	31393	4	6A
0005433452743	31393	5	6B
0005434142625	12026	1	1B
0005434142615	12026	2	1D
0005433134138	12026	3	2D
0005433134133	12026	4	3B
0005433134141	12026	5	3C
0005433134154	12026	6	5B
0005433129274	12026	7	5D
0005434142619	12026	8	6B
0005433134158	12026	9	6C
0005433129272	12026	10	7A
0005434142618	12026	11	7B
0005433129271	12026	12	7D
0005434184669	12026	13	18C
0005434184670	12026	14	19A
0005433134139	12026	15	19B
0005433129250	12026	16	19C
0005433134134	12026	17	20A
0005434142611	12026	18	20B
0005433134142	12026	19	20D
0005433129251	12026	20	21A
0005433129249	12026	21	22A
0005433134183	29821	1	1A
0005433131751	29821	2	1B
0005433134179	29821	3	2B
0005433131750	29821	4	2C
0005434142644	29821	5	3C
0005433134181	29821	6	3D
0005433134182	29821	7	4C
0005433134178	29821	8	4D
0005434184684	29821	9	6C
0005434142645	29821	10	7B
0005434183599	29821	11	18B
0005433131749	29821	12	18D
0005434183598	29821	13	19B
0005434142643	29821	14	19C
0005433131752	29821	15	20A
0005434184683	29821	16	21A
0005433134180	29821	17	21D
0005435935041	16500	1	1A
0005435697565	16500	2	1B
0005435935038	16500	3	1D
0005435697584	16500	4	2B
0005435697582	16500	5	2C
0005435697562	16500	6	2D
0005435697573	16500	7	3B
0005435935051	16500	8	4A
0005435697583	16500	9	4C
0005435697581	16500	10	5A
0005435697568	16500	11	4D
0005435697574	16500	12	5B
0005435697580	16500	13	5C
0005435697564	16500	14	6C
0005435697588	16500	15	6D
0005435697578	16500	16	7B
0005435697566	16500	17	7C
0005435697587	16500	18	7D
0005435697576	16500	19	18A
0005435697579	16500	20	18B
0005435697575	16500	21	18C
0005435697561	16500	22	18D
0005435935050	16500	23	19A
0005435697571	16500	24	19B
0005435935039	16500	25	19D
0005435697563	16500	26	20B
0005435697586	16500	27	20D
0005435697572	16500	28	21A
0005435697577	16500	29	21B
0005435697569	16500	30	21C
0005435697570	16500	31	21D
0005435935040	16500	32	22C
0005435697585	16500	33	22D
0005435697567	16500	34	23A
0005435697346	24718	1	1B
0005435697374	24718	2	1C
0005435697353	24718	3	2B
0005435935073	24718	4	2C
0005435697348	24718	5	3B
0005435697370	24718	6	3C
0005435697343	24718	7	3D
0005435697345	24718	8	4B
0005435697428	24718	9	4C
0005435697420	24718	10	4D
0005435697371	24718	11	5A
0005435697373	24718	12	5D
0005435935075	24718	13	6D
0005435697344	24718	14	7A
0005435697391	24718	15	7B
0005435697421	24718	16	18B
0005435935076	24718	17	19A
0005435697255	24718	18	19B
0005435697397	24718	19	19D
0005435697403	24718	20	20D
0005435697389	24718	21	21A
0005435697422	24718	22	21B
0005435697376	24718	23	21C
0005435935074	24718	24	21D
0005435697388	24718	25	22A
0005435697493	24718	26	22B
0005435697429	24718	27	22D
0005433724844	18778	1	2A
0005433724842	18778	2	2B
0005433724843	18778	3	3A
0005432968844	18778	4	4A
0005432968842	18778	5	4B
0005432968833	18778	6	5B
0005432968832	18778	7	6B
0005433724845	18778	8	6A
0005433724823	21618	1	1A
0005433724821	21618	2	1B
0005432968864	21618	3	2B
0005433724812	21618	4	5A
0005434138938	7294	1	1A
0005434138956	7294	2	1C
0005434138899	7294	3	1D
0005434138945	7294	4	1F
0005434087557	7294	5	2A
0005434138968	7294	6	2C
0005434138942	7294	7	2D
0005434138926	7294	8	2F
0005434138917	7294	9	3A
0005434138944	7294	10	3C
0005434138965	7294	11	3D
0005434138915	7294	12	3F
0005434138913	7294	13	4A
0005434138935	7294	14	4C
0005434087562	7294	15	4D
0005434138916	7294	16	4E
0005434138964	7294	17	4F
0005434138969	7294	18	5A
0005434138947	7294	19	5C
0005434138907	7294	20	5D
0005434138904	7294	21	5E
0005434138970	7294	22	5F
0005434138914	7294	23	6A
0005434138905	7294	24	6C
0005434138928	7294	25	6D
0005434138909	7294	26	6E
0005434138952	7294	27	6F
0005434138924	7294	28	7A
0005434138951	7294	29	7C
0005434138931	7294	30	7F
0005434138975	7294	31	8A
0005434138978	7294	32	8C
0005434138903	7294	33	8D
0005434138906	7294	34	8E
0005434138943	7294	35	8F
0005434138950	7294	36	9A
0005434138919	7294	37	9D
0005434138920	7294	38	9E
0005434087558	7294	39	9F
0005434138966	7294	40	10A
0005434138910	7294	41	10C
0005434138977	7294	42	10D
0005434138896	7294	43	10E
0005434138963	7294	44	10F
0005434087561	7294	45	11A
0005434138936	7294	46	11D
0005434138918	7294	47	11E
0005434138923	7294	48	11F
0005434138898	7294	49	12A
0005434138921	7294	50	12C
0005434138960	7294	51	12E
0005434138961	7294	52	12F
0005434138902	7294	53	13A
0005434087560	7294	54	13C
0005434138971	7294	55	13D
0005434138967	7294	56	13E
0005434138895	7294	57	13F
0005434138973	7294	58	14A
0005434138955	7294	59	14C
0005434138933	7294	60	14D
0005434138948	7294	61	14E
0005434138912	7294	62	15A
0005434138957	7294	63	15C
0005434138959	7294	64	15D
0005434138974	7294	65	15E
0005434138922	7294	66	15F
0005434087559	7294	67	16A
0005434138894	7294	68	16C
0005434138946	7294	69	16D
0005434138897	7294	70	16E
0005434138901	7294	71	16F
0005434138939	7294	72	17A
0005434138930	7294	73	17C
0005434138927	7294	74	17D
0005434138962	7294	75	17E
0005434138932	7294	76	17F
0005434138929	7294	77	18A
0005434138925	7294	78	18C
0005434138976	7294	79	18D
0005434138937	7294	80	18E
0005434138911	7294	81	18F
0005434138972	7294	82	19A
0005434138949	7294	83	19C
0005434138908	7294	84	19D
0005434138900	7294	85	19E
0005434138934	7294	86	19F
0005434138958	7294	87	20A
0005434138954	7294	88	20C
0005434138941	7294	89	20D
0005434138953	7294	90	20E
0005434138940	7294	91	20F
0005434137916	28561	1	1A
0005434138108	28561	2	1C
0005434138075	28561	3	1F
0005434087530	28561	4	2A
0005434137924	28561	5	2C
0005434138017	28561	6	2D
0005434137803	28561	7	2F
0005434138116	28561	8	3A
0005434138180	28561	9	3C
0005434137782	28561	10	3D
0005434087529	28561	11	3F
0005434138073	28561	12	4A
0005434138007	28561	13	4C
0005434087512	28561	14	4D
0005434137851	28561	15	4E
0005434138184	28561	16	4F
0005434138230	28561	17	5A
0005434138078	28561	18	5C
0005434137919	28561	19	5D
0005434138079	28561	20	5E
0005434138133	28561	21	5F
0005434137834	28561	22	6A
0005434138231	28561	23	6C
0005434138087	28561	24	6D
0005434137804	28561	25	6E
0005434137783	28561	26	6F
0005434138002	28561	27	7A
0005434087515	28561	28	7C
0005434137947	28561	29	7D
0005434138023	28561	30	7E
0005434138039	28561	31	7F
0005434138063	28561	32	8A
0005434138032	28561	33	8C
0005434138060	28561	34	8D
0005434137892	28561	35	8E
0005434137930	28561	36	8F
0005434137835	28561	37	9A
0005434138000	28561	38	9C
0005434138018	28561	39	9D
0005434138151	28561	40	9E
0005434087533	28561	41	9F
0005434137805	28561	42	10A
0005434138088	28561	43	10C
0005434138232	28561	44	10D
0005434138118	28561	45	10E
0005434137781	28561	46	10F
0005434137923	28561	47	11A
0005434138234	28561	48	11C
0005434138238	28561	49	11D
0005434138251	28561	50	11E
0005434138261	28561	51	12A
0005434138150	28561	52	12C
0005434138202	28561	53	12D
0005434138062	28561	54	12E
0005434138141	28561	55	12F
0005434087516	28561	56	13A
0005434138185	28561	57	13C
0005434137999	28561	58	13D
0005434138110	28561	59	13E
0005434138233	28561	60	13F
0005434137921	28561	61	14A
0005434087518	28561	62	14C
0005434138239	28561	63	14D
0005434137922	28561	64	14E
0005434137925	28561	65	14F
0005434138016	28561	66	15A
0005434138098	28561	67	15C
0005434138181	28561	68	15D
0005434137918	28561	69	15E
0005434138152	28561	70	15F
0005434138264	28561	71	16A
0005434138249	28561	72	16D
0005434138099	28561	73	16E
0005434137972	28561	74	16F
0005434138201	28561	75	17A
0005434137992	28561	76	17C
0005434137891	28561	77	17D
0005434138109	28561	78	17F
0005434137896	28561	79	18A
0005434137795	28561	80	18C
0005434137869	28561	81	18D
0005434137910	28561	82	18E
0005434137920	28561	83	18F
0005434138142	28561	84	19A
0005434138169	28561	85	19C
0005434138193	28561	86	19D
0005434087534	28561	87	19E
0005434137948	28561	88	19F
0005434137915	28561	89	20A
0005434138140	28561	90	20C
0005434137964	28561	91	20D
0005434087517	28561	92	20E
0005434138076	28561	93	20F
0005433407568	1913	1	1C
0005435808334	1913	2	2A
0005435808335	1913	3	2B
0005435808333	1913	4	2C
0005434610262	1913	5	2D
0005435808332	1913	6	3A
0005433407560	1913	7	4A
0005434610263	1913	8	4C
0005435808328	1913	9	5D
0005433407559	1913	10	6A
0005433407567	1913	11	6B
0005435808330	1913	12	6C
0005434610264	1913	13	7B
0005434610265	1913	14	7D
0005435808336	1913	15	20A
0005435808331	1913	16	21C
0005435808329	1913	17	22B
0005433407606	23077	1	1A
0005435808165	23077	2	1C
0005433407603	23077	3	1D
0005433407609	23077	4	2A
0005435808190	23077	5	2B
0005435808182	23077	6	2C
0005435808214	23077	7	2D
0005434610222	23077	8	3B
0005433407608	23077	9	3C
0005435808218	23077	10	4A
0005433407601	23077	11	4B
0005435808173	23077	12	4C
0005435808199	23077	13	5A
0005435808225	23077	14	5B
0005435808188	23077	15	5D
0005435808159	23077	16	6A
0005435808201	23077	17	6B
0005433407604	23077	18	6C
0005435808197	23077	19	6D
0005434610231	23077	20	7A
0005435808222	23077	21	7C
0005433407605	23077	22	7D
0005435808223	23077	23	18B
0005435808178	23077	24	18C
0005434610223	23077	25	18D
0005435808224	23077	26	19A
0005435808198	23077	27	19B
0005433407611	23077	28	19C
0005435808212	23077	29	19D
0005435808189	23077	30	20A
0005435808195	23077	31	20B
0005435808213	23077	32	20C
0005435808196	23077	33	20D
0005435808194	23077	34	21A
0005435808234	23077	35	21B
0005435808193	23077	36	21D
0005435808221	23077	37	22A
0005433407610	23077	38	22B
0005433407602	23077	39	22D
0005435808233	23077	40	23A
0005433407607	23077	41	23B
0005434504014	16697	1	1A
0005434504104	16697	2	1B
0005434504170	16697	3	1C
0005434504153	16697	4	1D
0005434504161	16697	5	2A
0005434504075	16697	6	2B
0005434504190	16697	7	2C
0005434504173	16697	8	2D
0005434504116	16697	9	3A
0005434504064	16697	10	3B
0005434503994	16697	11	3C
0005434504144	16697	12	3D
0005434504123	16697	13	4A
0005434504183	16697	14	4B
0005434504171	16697	15	4C
0005434504124	16697	16	4D
0005434504106	16697	17	5A
0005434503993	16697	18	5B
0005434504145	16697	19	5C
0005434504015	16697	20	5D
0005434504208	16697	21	6A
0005434504162	16697	22	6B
0005434504069	16697	23	6C
0005434504180	16697	24	6D
0005434504083	16697	25	7A
0005434504047	16697	26	7B
0005434504045	16697	27	7C
0005434504179	16697	28	7D
0005434503989	16697	29	18A
0005434504063	16697	30	18B
0005434504087	16697	31	18C
0005434504105	16697	32	18D
0005434504218	16697	33	19A
0005434504086	16697	34	19B
0005434504207	16697	35	19C
0005434504178	16697	36	19D
0005434504082	16697	37	20A
0005434504216	16697	38	20B
0005434504023	16697	39	20C
0005434504048	16697	40	20D
0005434504160	16697	41	21A
0005434504220	16697	42	21B
0005434504154	16697	43	21C
0005434504223	16697	44	21D
0005434504125	16697	45	22A
0005434504152	16697	46	22B
0005434504150	16697	47	22C
0005434504184	16697	48	22D
0005434504115	16697	49	23A
0005434504151	16697	50	23B
0005434504469	22935	1	1A
0005434504479	22935	2	1B
0005434504486	22935	3	1C
0005434504477	22935	4	1D
0005434504494	22935	5	2B
0005434504474	22935	6	2D
0005434504493	22935	7	3A
0005434504475	22935	8	3B
0005434504471	22935	9	3C
0005434504481	22935	10	3D
0005434504502	22935	11	4A
0005434504497	22935	12	4C
0005434504491	22935	13	4D
0005434504478	22935	14	5A
0005434504476	22935	15	5B
0005434504500	22935	16	5C
0005434504473	22935	17	6B
0005434504490	22935	18	6C
0005434504485	22935	19	6D
0005434504498	22935	20	7A
0005434504467	22935	21	7B
0005434504495	22935	22	7C
0005434504464	22935	23	18A
0005434504499	22935	24	18B
0005434504466	22935	25	18C
0005434504470	22935	26	18D
0005434504487	22935	27	19A
0005434504504	22935	28	19B
0005434504480	22935	29	19C
0005434504465	22935	30	19D
0005434504488	22935	31	20B
0005434504489	22935	32	20D
0005434504472	22935	33	21A
0005434504483	22935	34	21B
0005434504503	22935	35	21C
0005434504468	22935	36	21D
0005434504482	22935	37	22A
0005434504484	22935	38	22B
0005434504492	22935	39	22D
0005434504496	22935	40	23A
0005434504501	22935	41	23B
0005435078486	2229	1	1B
0005433266757	2229	2	1C
0005435078492	2229	3	1D
0005435078480	2229	4	2B
0005433266758	2229	5	2D
0005435078488	2229	6	3D
0005435078485	2229	7	4C
0005435078490	2229	8	5B
0005435078489	2229	9	6B
0005433266730	2229	10	6C
0005435078484	2229	11	6D
0005433266709	2229	12	7B
0005435078493	2229	13	18B
0005435078482	2229	14	19B
0005435078491	2229	15	20A
0005435078487	2229	16	20D
0005435078481	2229	17	21C
0005435078483	2229	18	21D
0005433266759	2229	19	22A
0005433266761	2229	20	23B
0005435078408	24346	1	2A
0005433266814	24346	2	2B
0005433266807	24346	3	4A
0005433266812	24346	4	6C
0005433266810	24346	5	7A
0005433266808	24346	6	18A
0005433266805	24346	7	20D
0005433266811	24346	8	21A
0005433266813	24346	9	22A
0005433266809	24346	10	22B
0005433266806	24346	11	22D
0005434988836	6663	1	1A
0005434988844	6663	2	3A
0005434988842	6663	3	3B
0005434988834	6663	4	4A
0005434988832	6663	5	4D
0005434988837	6663	6	5C
0005434988843	6663	7	7D
0005434988845	6663	8	18A
0005434988838	6663	9	18C
0005435464509	6663	10	20B
0005434988840	6663	11	20C
0005434988835	6663	12	20D
0005434988841	6663	13	21C
0005434988833	6663	14	22B
0005434988839	6663	15	23A
0005434988683	23615	1	1C
0005434988694	23615	2	2D
0005435464526	23615	3	3A
0005434988702	23615	4	4A
0005434988693	23615	5	4D
0005435803269	23615	6	6A
0005435803261	23615	7	6C
0005435464529	23615	8	6D
0005435803273	23615	9	7B
0005434988685	23615	10	7C
0005434988684	23615	11	18A
0005435464528	23615	12	19A
0005435803272	23615	13	21B
0005434988707	23615	14	21C
0005434988695	23615	15	22C
0005434988692	23615	16	22D
0005435464527	23615	17	23A
0005432383543	30505	1	1A
0005432383537	30505	2	1C
0005433450163	30505	3	1D
0005432383550	30505	4	2A
0005433450170	30505	5	2C
0005433454896	30505	6	2D
0005432383542	30505	7	2F
0005433450165	30505	8	3A
0005432383553	30505	9	3D
0005432383560	30505	10	3F
0005432383539	30505	11	4A
0005432383555	30505	12	4D
0005432383559	30505	13	4E
0005432383561	30505	14	4F
0005433450172	30505	15	5A
0005433450177	30505	16	5D
0005432383567	30505	17	6A
0005432383570	30505	18	6D
0005432383538	30505	19	6E
0005432383552	30505	20	7C
0005433450181	30505	21	7D
0005432383558	30505	22	7F
0005433450169	30505	23	8A
0005433450175	30505	24	8C
0005432383536	30505	25	8D
0005432383569	30505	26	8E
0005432383562	30505	27	8F
0005432383548	30505	28	9A
0005433450176	30505	29	9C
0005433453779	30505	30	9D
0005432383565	30505	31	9F
0005433454895	30505	32	10D
0005433450183	30505	33	10E
0005433450173	30505	34	10F
0005432383557	30505	35	11A
0005433450180	30505	36	11D
0005432383535	30505	37	11F
0005432383540	30505	38	12C
0005433450182	30505	39	12D
0005433450178	30505	40	12E
0005433454897	30505	41	13D
0005432383564	30505	42	13E
0005433450174	30505	43	13F
0005433450184	30505	44	14A
0005433450166	30505	45	14C
0005432383549	30505	46	14D
0005433450179	30505	47	14E
0005432383544	30505	48	14F
0005433453777	30505	49	15A
0005432383541	30505	50	15D
0005432383545	30505	51	15E
0005432383533	30505	52	16A
0005432383568	30505	53	17A
0005433450168	30505	54	17C
0005432383551	30505	55	17E
0005432383554	30505	56	17F
0005432383563	30505	57	18A
0005433450164	30505	58	18C
0005432383556	30505	59	18E
0005433453778	30505	60	18F
0005432383547	30505	61	19C
0005432383546	30505	62	19D
0005432383534	30505	63	19E
0005433450167	30505	64	20C
0005433450171	30505	65	20D
0005432383566	30505	66	20E
0005432383017	31332	1	1A
0005433450063	31332	2	1C
0005433449966	31332	3	1F
0005432383112	31332	4	2A
0005433450118	31332	5	2D
0005432383067	31332	6	2F
0005433449945	31332	7	3A
0005432383173	31332	8	3C
0005432382998	31332	9	3D
0005432383005	31332	10	3F
0005432383137	31332	11	4A
0005433449946	31332	12	4C
0005433449943	31332	13	4D
0005432383142	31332	14	4E
0005432383138	31332	15	5C
0005433450062	31332	16	5D
0005433450023	31332	17	5F
0005432383167	31332	18	6A
0005433449953	31332	19	6C
0005432383169	31332	20	6E
0005433450040	31332	21	6F
0005433449947	31332	22	7C
0005432383141	31332	23	7D
0005432383094	31332	24	7E
0005433450065	31332	25	7F
0005432383179	31332	26	8C
0005433449911	31332	27	8D
0005432383093	31332	28	8E
0005432382987	31332	29	9A
0005433449912	31332	30	9C
0005432382993	31332	31	9E
0005432383068	31332	32	9F
0005433449948	31332	33	10A
0005432383014	31332	34	10C
0005433449995	31332	35	10D
0005433450052	31332	36	10E
0005433449923	31332	37	10F
0005432383135	31332	38	11A
0005433449967	31332	39	11C
0005433449988	31332	40	11D
0005433449999	31332	41	12A
0005432383162	31332	42	12D
0005432383188	31332	43	12E
0005433449994	31332	44	13A
0005432383022	31332	45	13C
0005433449959	31332	46	13D
0005432383098	31332	47	13E
0005432383013	31332	48	13F
0005432383097	31332	49	14A
0005432383015	31332	50	14C
0005433450043	31332	51	14E
0005433449924	31332	52	15A
0005432382994	31332	53	15C
0005432383174	31332	54	15D
0005432383143	31332	55	16A
0005432382970	31332	56	16C
0005432382986	31332	57	16D
0005433449977	31332	58	16E
0005433449944	31332	59	17A
0005432383049	31332	60	17C
0005433450061	31332	61	17D
0005433450117	31332	62	17E
0005432383131	31332	63	18A
0005432383146	31332	64	18C
0005432383092	31332	65	18D
0005432383187	31332	66	19D
0005433449978	31332	67	19F
0005432383004	31332	68	20D
0005432383101	31332	69	20F
0005435299792	10778	1	2B
0005433126821	10778	2	3C
0005433126834	10778	3	4D
0005433126815	10778	4	5B
0005435304149	10778	5	5D
0005435304152	10778	6	6B
0005435304167	10778	7	7B
0005433126814	10778	8	7D
0005433126832	10778	9	18A
0005435304153	10778	10	18B
0005435304154	10778	11	18D
0005433126820	10778	12	19A
0005433131713	10778	13	19B
0005433131712	10778	14	19C
0005433126833	10778	15	20C
0005435299823	29732	1	1C
0005435299825	29732	2	1D
0005433126889	29732	3	3B
0005433129324	29732	4	4A
0005435299824	29732	5	4B
0005435302246	29732	6	5B
0005435299826	29732	7	5D
0005433126893	29732	8	6B
0005433126895	29732	9	7A
0005433126891	29732	10	7D
0005435302247	29732	11	19A
0005433129322	29732	12	19B
0005433129323	29732	13	20A
0005433126892	29732	14	20B
0005435302248	29732	15	20C
0005433126890	29732	16	21A
0005433129321	29732	17	21B
0005435299822	29732	18	21D
0005433126894	29732	19	22D
0005435302245	29732	20	23A
0005434287507	2407	1	1A
0005434287496	2407	2	1B
0005434287495	2407	3	1C
0005434287490	2407	4	2A
0005432264499	2407	5	2B
0005434287484	2407	6	2C
0005434287487	2407	7	2D
0005434287500	2407	8	3A
0005434287492	2407	9	3B
0005433110037	2407	10	3C
0005433110011	2407	11	3D
0005433110099	2407	12	4A
0005433110063	2407	13	4B
0005434287506	2407	14	4D
0005434287491	2407	15	5B
0005434287489	2407	16	5C
0005434287499	2407	17	5D
0005434287486	2407	18	6A
0005434287488	2407	19	6B
0005434287503	2407	20	6C
0005434287502	2407	21	6D
0005434287505	2407	22	7A
0005432264497	2407	23	7B
0005434287504	2407	24	7C
0005433110083	2407	25	18A
0005433110087	2407	26	18B
0005433110104	2407	27	18C
0005433110076	2407	28	18D
0005434287498	2407	29	19A
0005434287497	2407	30	19B
0005433110060	2407	31	19C
0005433110058	2407	32	19D
0005433110075	2407	33	20B
0005434287501	2407	34	20C
0005434287485	2407	35	20D
0005433110082	2407	36	21B
0005434287494	2407	37	21C
0005434287493	2407	38	21D
0005433110059	2407	39	22B
0005432264498	2407	40	23A
0005434287355	26842	1	1A
0005434287369	26842	2	1B
0005434287320	26842	3	1D
0005434287219	26842	4	2A
0005434287270	26842	5	2B
0005434287286	26842	6	2C
0005434287316	26842	7	2D
0005434287375	26842	8	3B
0005434287223	26842	9	3C
0005434287214	26842	10	3D
0005434287308	26842	11	4A
0005434287370	26842	12	4C
0005434287287	26842	13	4D
0005434287336	26842	14	5C
0005433110160	26842	15	5D
0005433110166	26842	16	6A
0005434287296	26842	17	6B
0005433110170	26842	18	6C
0005434287249	26842	19	6D
0005433110171	26842	20	7A
0005433110165	26842	21	7B
0005433110173	26842	22	7C
0005433110168	26842	23	7D
0005433110161	26842	24	18A
0005434287350	26842	25	18B
0005433110167	26842	26	18C
0005434287220	26842	27	18D
0005434287304	26842	28	19A
0005433110163	26842	29	19B
0005433110159	26842	30	19C
0005433110172	26842	31	19D
0005434287278	26842	32	20A
0005434287213	26842	33	20C
0005434287277	26842	34	20D
0005433110164	26842	35	21A
0005434287337	26842	36	21C
0005434287279	26842	37	21D
0005434287309	26842	38	22A
0005433110169	26842	39	22C
0005433110162	26842	40	22D
0005434287374	26842	41	23A
0005434272191	25474	1	2D
0005435856243	25474	2	3A
0005435856245	25474	3	3B
0005434269094	25474	4	5B
0005435856242	25474	5	7C
0005435856244	25474	6	7D
0005434272190	25474	7	18B
0005434269095	25474	8	19B
0005434272189	25474	9	19C
0005434269100	25474	10	23A
0005434273093	26621	1	2C
0005434273094	26621	2	4A
0005435854059	26621	3	5A
0005435856187	26621	4	6A
0005434272208	26621	5	6D
0005434272209	26621	6	18D
0005435856198	26621	7	19A
0005435856181	26621	8	19C
0005433650754	7162	1	1A
0005433650757	7162	2	1C
0005433650769	7162	3	1D
0005435263639	7162	4	2A
0005433650773	7162	5	2C
0005433650792	7162	6	2D
0005435263647	7162	7	2F
0005435263601	7162	8	3A
0005435263620	7162	9	3C
0005433650766	7162	10	3D
0005433650775	7162	11	3F
0005433650763	7162	12	4A
0005435263641	7162	13	4C
0005433650782	7162	14	4E
0005433650797	7162	15	5A
0005433650779	7162	16	4F
0005435263630	7162	17	5C
0005435263612	7162	18	5D
0005433650781	7162	19	5F
0005433650788	7162	20	6C
0005433650795	7162	21	6D
0005433650767	7162	22	6E
0005433650796	7162	23	6F
0005433650752	7162	24	7A
0005433650768	7162	25	7D
0005435263570	7162	26	7E
0005435263609	7162	27	8A
0005435263573	7162	28	8D
0005433650793	7162	29	8E
0005435263613	7162	30	9A
0005435263615	7162	31	9C
0005433650789	7162	32	9D
0005433650765	7162	33	9E
0005433650791	7162	34	10C
0005433650755	7162	35	10D
0005435263629	7162	36	10F
0005435263633	7162	37	11A
0005433650790	7162	38	11D
0005433650778	7162	39	11F
0005435263602	7162	40	12A
0005433650786	7162	41	12D
0005433650777	7162	42	12E
0005433650758	7162	43	13A
0005435263627	7162	44	13C
0005433650761	7162	45	13D
0005435263632	7162	46	13E
0005433650762	7162	47	13F
0005435263628	7162	48	14A
0005435263571	7162	49	14D
0005433650771	7162	50	14E
0005433650759	7162	51	14F
0005433650760	7162	52	15C
0005435263640	7162	53	15D
0005435263621	7162	54	16A
0005435263642	7162	55	16C
0005435263635	7162	56	16D
0005433650774	7162	57	16E
0005433650783	7162	58	16F
0005435263565	7162	59	17A
0005433650776	7162	60	17C
0005433650780	7162	61	17E
0005433650772	7162	62	17F
0005433650785	7162	63	18A
0005433650770	7162	64	18C
0005433650794	7162	65	18D
0005433650799	7162	66	18F
0005433650753	7162	67	19A
0005433650798	7162	68	19C
0005433650764	7162	69	19E
0005433650784	7162	70	19F
0005435263572	7162	71	20A
0005435263614	7162	72	20C
0005433650756	7162	73	20D
0005433650787	7162	74	20E
0005433868801	4798	1	1A
0005433868800	4798	2	1B
0005433868815	4798	3	1D
0005433868823	4798	4	2A
0005433868825	4798	5	2B
0005433868799	4798	6	3B
0005433868802	4798	7	3C
0005433868811	4798	8	3D
0005433868821	4798	9	4A
0005433868807	4798	10	4B
0005433868828	4798	11	4C
0005433868833	4798	12	4D
0005433868803	4798	13	5A
0005433868806	4798	14	5C
0005433868826	4798	15	6B
0005433868816	4798	16	6C
0005433868832	4798	17	7A
0005433868831	4798	18	7B
0005433868809	4798	19	7C
0005433868819	4798	20	7D
0005433868797	4798	21	18A
0005433868814	4798	22	18B
0005433868813	4798	23	18C
0005433868812	4798	24	19A
0005433868827	4798	25	19B
0005433868835	4798	26	19C
0005433868808	4798	27	19D
0005433868830	4798	28	20B
0005433868822	4798	29	20C
0005433868818	4798	30	20D
0005433868805	4798	31	21A
0005433868836	4798	32	21B
0005433868798	4798	33	21C
0005433868829	4798	34	21D
0005433868804	4798	35	22A
0005433868820	4798	36	22B
0005433868810	4798	37	22C
0005433868817	4798	38	22D
0005433868834	4798	39	23A
0005433868824	4798	40	23B
0005433868395	32573	1	1A
0005433868371	32573	2	1B
0005433868357	32573	3	1C
0005433868233	32573	4	1D
0005433868439	32573	5	2A
0005433868346	32573	6	2B
0005433868539	32573	7	2D
0005433868561	32573	8	3A
0005433868437	32573	9	3C
0005433868440	32573	10	4A
0005433868234	32573	11	4B
0005433868513	32573	12	4C
0005433868505	32573	13	4D
0005433868376	32573	14	5A
0005433868614	32573	15	5B
0005433868379	32573	16	5C
0005433868401	32573	17	5D
0005433868350	32573	18	6A
0005433868343	32573	19	6B
0005433868396	32573	20	6C
0005433868421	32573	21	6D
0005433868407	32573	22	7B
0005433868400	32573	23	7C
0005433868562	32573	24	18A
0005433868120	32573	25	18B
0005433868341	32573	26	18C
0005433868463	32573	27	18D
0005433868419	32573	28	19A
0005433868351	32573	29	19C
0005433868422	32573	30	19D
0005433868342	32573	31	20A
0005433868347	32573	32	20C
0005433868514	32573	33	20D
0005433868480	32573	34	21A
0005433868232	32573	35	21B
0005433868533	32573	36	21C
0005433868231	32573	37	21D
0005433868616	32573	38	22A
0005433868468	32573	39	22D
0005433868617	32573	40	23A
0005433868540	32573	41	23B
0005434663533	3405	1	1A
0005434663535	3405	2	1B
0005434461667	3405	3	1C
0005434663541	3405	4	1D
0005434663529	3405	5	2A
0005435911494	3405	6	2B
0005435911475	3405	7	2C
0005434663534	3405	8	3A
0005434663528	3405	9	3B
0005435911450	3405	10	3C
0005434663530	3405	11	3D
0005434663531	3405	12	4A
0005434663540	3405	13	4B
0005434461666	3405	14	5C
0005434663532	3405	15	5D
0005435911449	3405	16	6C
0005434663536	3405	17	6D
0005434460525	3405	18	7B
0005435911437	3405	19	7C
0005434663539	3405	20	7D
0005435911458	3405	21	18A
0005434663542	3405	22	18B
0005435911476	3405	23	18C
0005435911448	3405	24	19D
0005434663537	3405	25	20A
0005434663538	3405	26	20C
0005435911459	3405	27	20D
0005435911445	3405	28	21A
0005435911466	3405	29	22B
0005434460526	3405	30	22C
0005435911525	12470	1	1A
0005435911523	12470	2	1C
0005434663449	12470	3	2A
0005434663442	12470	4	2B
0005435911524	12470	5	2C
0005434663443	12470	6	2D
0005435911521	12470	7	3A
0005434663432	12470	8	4B
0005434663458	12470	9	4C
0005434663445	12470	10	5A
0005434663407	12470	11	5D
0005434663450	12470	12	18A
0005434663405	12470	13	18C
0005435911520	12470	14	20C
0005434663457	12470	15	20D
0005435911522	12470	16	22B
0005434663480	12470	17	23A
0005435911526	12470	18	23B
0005433868347	14522	1	1A
0005433868233	14522	2	1B
0005433868513	14522	3	1D
0005433868514	14522	4	2A
0005433868562	14522	5	2B
0005433868422	14522	6	2C
0005433868480	14522	7	3A
0005433868505	14522	8	3B
0005433868379	14522	9	3C
0005433868376	14522	10	3D
0005433868341	14522	11	4A
0005433868533	14522	12	4B
0005433868419	14522	13	4C
0005433868440	14522	14	5A
0005433868231	14522	15	5B
0005433868617	14522	16	5C
0005433868234	14522	17	5D
0005433868561	14522	18	6A
0005433868614	14522	19	6C
0005433868407	14522	20	6D
0005433868351	14522	21	7A
0005433868401	14522	22	7B
0005433868463	14522	23	7C
0005433868421	14522	24	7D
0005433868232	14522	25	18B
0005433868400	14522	26	18C
0005433868346	14522	27	18D
0005433868540	14522	28	19B
0005433868396	14522	29	19C
0005433868395	14522	30	19D
0005433868539	14522	31	20A
0005433868468	14522	32	20B
0005433868371	14522	33	20C
0005433868342	14522	34	20D
0005433868343	14522	35	21A
0005433868439	14522	36	21B
0005433868350	14522	37	21C
0005433868437	14522	38	21D
0005433868616	14522	39	22A
0005433868357	14522	40	23A
0005433868120	14522	41	23B
0005433868780	32685	1	1A
0005433868779	32685	2	1B
0005433868762	32685	3	1C
0005433868781	32685	4	1D
0005433868763	32685	5	2A
0005435860488	32685	6	2C
0005433868770	32685	7	2D
0005433868795	32685	8	3A
0005433868764	32685	9	3C
0005435860489	32685	10	3D
0005433868761	32685	11	4A
0005433868772	32685	12	4B
0005433868782	32685	13	4C
0005433868753	32685	14	4D
0005433868786	32685	15	5A
0005433868783	32685	16	5B
0005433868784	32685	17	5C
0005433868768	32685	18	5D
0005433868760	32685	19	6A
0005433868773	32685	20	6B
0005433868789	32685	21	6C
0005433868787	32685	22	6D
0005433868771	32685	23	7A
0005433868790	32685	24	7B
0005433868767	32685	25	7C
0005433868769	32685	26	7D
0005433868796	32685	27	18A
0005433868755	32685	28	18B
0005433868759	32685	29	18C
0005433868776	32685	30	18D
0005435860481	32685	31	19A
0005433868774	32685	32	19B
0005433868794	32685	33	19C
0005433868778	32685	34	19D
0005435860470	32685	35	20A
0005433868788	32685	36	20B
0005433868754	32685	37	20C
0005433868791	32685	38	20D
0005433868756	32685	39	21A
0005433868792	32685	40	21B
0005433868758	32685	41	21C
0005433868766	32685	42	21D
0005433868765	32685	43	22B
0005433868775	32685	44	22A
0005433868785	32685	45	22C
0005433868793	32685	46	22D
0005433868777	32685	47	23A
0005433868757	32685	48	23B
0005432799511	12135	1	1A
0005432799476	12135	2	1B
0005432799458	12135	3	2A
0005432799542	12135	4	2B
0005432799528	12135	5	2C
0005432799455	12135	6	3A
0005432799431	12135	7	3B
0005432799430	12135	8	3C
0005432799488	12135	9	3D
0005432799540	12135	10	4B
0005432799570	12135	11	5A
0005432799286	12135	12	5C
0005432799434	12135	13	6A
0005432799360	12135	14	6C
0005432799541	12135	15	7A
0005432799579	12135	16	7C
0005432799489	12135	17	7D
0005432799507	12135	18	18A
0005432799513	12135	19	18B
0005432799486	12135	20	18C
0005432799447	12135	21	18D
0005432799494	12135	22	19D
0005432799514	12135	23	20A
0005432799370	12135	24	20C
0005432799389	12135	25	21A
0005432799487	12135	26	21D
0005432799571	12135	27	22D
0005432799543	12135	28	23B
0005432799679	14828	1	1A
0005432799682	14828	2	1B
0005432799700	14828	3	2A
0005432799695	14828	4	2B
0005432799694	14828	5	2C
0005432799680	14828	6	3A
0005432799698	14828	7	3C
0005432799691	14828	8	4C
0005432799692	14828	9	5A
0005432799696	14828	10	5B
0005432799678	14828	11	5D
0005432799702	14828	12	6A
0005432799676	14828	13	7A
0005432799686	14828	14	7C
0005432799699	14828	15	18A
0005432799706	14828	16	18C
0005432799681	14828	17	18D
0005432799688	14828	18	19A
0005432799687	14828	19	19B
0005432799693	14828	20	19C
0005432799689	14828	21	19D
0005432799690	14828	22	20A
0005432799684	14828	23	20B
0005432799685	14828	24	20D
0005432799683	14828	25	21A
0005432799697	14828	26	21B
0005432799705	14828	27	21C
0005432799703	14828	28	21D
0005432799704	14828	29	22A
0005432799701	14828	30	22D
0005432799677	14828	31	23A
0005434408375	7076	1	1A
0005434408354	7076	2	1C
0005434408364	7076	3	1D
0005432154001	7076	4	2A
0005434408348	7076	5	1F
0005432108275	7076	6	2D
0005434299781	7076	7	2C
0005435293281	7076	8	3A
0005435311060	7076	9	2F
0005434408359	7076	10	3F
0005434299776	7076	11	3D
0005435293237	7076	12	4A
0005434299779	7076	13	4B
0005434408340	7076	14	4D
0005435293251	7076	15	4C
0005434408345	7076	16	4E
0005434299772	7076	17	5A
0005432108274	7076	18	5B
0005432154003	7076	19	5D
0005434408367	7076	20	5C
0005434299770	7076	21	5E
0005434408320	7076	22	5F
0005434408341	7076	23	6A
0005434408318	7076	24	6C
0005434408347	7076	25	6B
0005434408372	7076	26	6D
0005434408363	7076	27	6E
0005434408358	7076	28	7A
0005434408333	7076	29	7B
0005435293269	7076	30	7C
0005434408366	7076	31	7E
0005434408350	7076	32	7D
0005435293236	7076	33	8A
0005434299786	7076	34	7F
0005435311037	7076	35	8B
0005434299777	7076	36	8D
0005434408378	7076	37	8C
0005434299769	7076	38	8E
0005435311080	7076	39	9A
0005434408357	7076	40	8F
0005435293264	7076	41	9C
0005434408376	7076	42	9B
0005435293299	7076	43	9E
0005434408329	7076	44	9D
0005435311078	7076	45	9F
0005434408353	7076	46	10B
0005435293249	7076	47	10C
0005434408326	7076	48	10E
0005434299773	7076	49	10D
0005434408346	7076	50	11A
0005434408334	7076	51	11D
0005434299775	7076	52	11C
0005434408327	7076	53	11E
0005434408323	7076	54	11F
0005434408369	7076	55	12A
0005432154006	7076	56	12B
0005434408360	7076	57	12D
0005434408343	7076	58	12C
0005435293298	7076	59	12E
0005432154007	7076	60	13A
0005434408339	7076	61	12F
0005434408344	7076	62	13B
0005434408379	7076	63	13D
0005434408355	7076	64	13C
0005434408365	7076	65	13E
0005434299771	7076	66	14A
0005435293307	7076	67	13F
0005434408374	7076	68	14B
0005434408331	7076	69	14D
0005434408349	7076	70	14C
0005434408338	7076	71	14E
0005434299768	7076	72	14F
0005434408368	7076	73	15A
0005434408321	7076	74	15C
0005434408337	7076	75	15B
0005434408352	7076	76	15D
0005435311038	7076	77	15F
0005434408373	7076	78	15E
0005435293232	7076	79	16A
0005432154004	7076	80	16B
0005432154002	7076	81	16D
0005435293282	7076	82	16C
0005434408328	7076	83	17A
0005435311030	7076	84	16F
0005435293242	7076	85	17B
0005434408332	7076	86	17C
0005434299767	7076	87	17D
0005434408319	7076	88	17F
0005434408335	7076	89	17E
0005434299774	7076	90	18A
0005434299788	7076	91	18C
0005435311079	7076	92	18B
0005434299785	7076	93	18D
0005434408381	7076	94	19A
0005432154005	7076	95	18F
0005434408380	7076	96	19B
0005434299787	7076	97	19D
0005434408325	7076	98	19C
0005434299789	7076	99	19E
0005434408322	7076	100	19F
0005434299766	7076	101	20A
0005434299782	7076	102	20C
0005434408377	7076	103	20B
0005435311054	7076	104	20E
0005434408324	7076	105	20D
0005434299784	7076	106	20F
0005434408342	7076	107	21B
0005434408361	7076	108	21A
0005434299780	7076	109	21D
0005432154000	7076	110	21C
0005434408330	7076	111	21F
0005434408336	7076	112	21E
0005434408370	7076	113	22B
0005434408356	7076	114	22A
0005434299783	7076	115	22D
0005434408371	7076	116	22E
0005435311031	7076	117	23A
0005434408362	7076	118	22F
0005435293223	7076	119	23B
0005432154008	7076	120	23C
0005434299778	7076	121	23D
0005434408351	7076	122	23F
0005435311083	7076	123	23E
0005434299652	26924	1	1A
0005434407630	26924	2	1C
0005434299577	26924	3	1D
0005435311161	26924	4	1F
0005432058415	26924	5	2C
0005434299642	26924	6	2A
0005434408025	26924	7	2D
0005434407748	26924	8	3A
0005434407878	26924	9	2F
0005434407791	26924	10	3D
0005434299708	26924	11	3C
0005434299640	26924	12	3F
0005434299567	26924	13	4A
0005434407426	26924	14	4B
0005434407859	26924	15	4D
0005434407584	26924	16	4C
0005434407631	26924	17	4F
0005434299569	26924	18	5A
0005435311158	26924	19	5C
0005434299657	26924	20	5B
0005435293370	26924	21	5E
0005435293371	26924	22	5F
0005434299568	26924	23	6B
0005434407771	26924	24	6A
0005434299589	26924	25	6C
0005434407758	26924	26	6D
0005434407927	26924	27	6F
0005434407939	26924	28	6E
0005435293373	26924	29	7C
0005434407898	26924	30	7B
0005434407772	26924	31	7D
0005432058413	26924	32	8A
0005432058416	26924	33	8B
0005434407896	26924	34	8D
0005434299588	26924	35	8C
0005434407838	26924	36	8E
0005434407495	26924	37	8F
0005435293369	26924	38	9A
0005435293363	26924	39	9B
0005434407583	26924	40	9D
0005434407773	26924	41	9C
0005434407741	26924	42	9E
0005434299644	26924	43	9F
0005434299507	26924	44	10B
0005434299651	26924	45	10C
0005434407679	26924	46	10E
0005434407753	26924	47	10D
0005434407486	26924	48	11A
0005432058417	26924	49	11B
0005434299624	26924	50	11D
0005434299582	26924	51	11E
0005435311162	26924	52	11F
0005434407678	26924	53	12A
0005434407738	26924	54	12C
0005434407957	26924	55	12B
0005435293367	26924	56	12E
0005434299578	26924	57	12D
0005434407874	26924	58	12F
0005434407494	26924	59	13A
0005435311160	26924	60	13C
0005434407549	26924	61	13B
0005434408024	26924	62	13D
0005434407969	26924	63	13F
0005434299586	26924	64	13E
0005432058414	26924	65	14A
0005435293368	26924	66	14C
0005434407928	26924	67	14B
0005434407714	26924	68	14F
0005435311157	26924	69	15B
0005434407951	26924	70	15A
0005435311159	26924	71	15C
0005434299643	26924	72	15E
0005435293374	26924	73	15F
0005434407792	26924	74	16B
0005434299641	26924	75	16A
0005434407644	26924	76	16C
0005434407540	26924	77	16E
0005434407858	26924	78	16D
0005435293366	26924	79	16F
0005434299655	26924	80	17A
0005434299627	26924	81	17B
0005434299625	26924	82	17C
0005434407601	26924	83	17D
0005434299650	26924	84	17F
0005434407873	26924	85	17E
0005434407561	26924	86	18A
0005434407539	26924	87	18B
0005434407856	26924	88	18C
0005435293364	26924	89	18D
0005434299600	26924	90	18F
0005434407762	26924	91	18E
0005434407715	26924	92	19A
0005434407879	26924	93	19B
0005434407564	26924	94	19D
0005434407855	26924	95	19C
0005434407754	26924	96	19E
0005434407857	26924	97	19F
0005434408023	26924	98	20B
0005434299715	26924	99	20D
0005434407780	26924	100	20C
0005434407577	26924	101	20E
0005434407815	26924	102	20F
0005434299599	26924	103	21A
0005434299707	26924	104	21B
0005434299570	26924	105	21D
0005434407675	26924	106	21E
0005434299462	26924	107	21F
0005434299635	26924	108	22A
0005434407740	26924	109	22C
0005434407781	26924	110	22D
0005435293365	26924	111	22E
0005434299716	26924	112	22F
0005434299656	26924	113	23B
0005435293372	26924	114	23A
0005434299602	26924	115	23C
0005434407557	26924	116	23E
0005435293362	26924	117	23F
0005432604736	6443	1	1A
0005432604697	6443	2	1B
0005432604731	6443	3	1D
0005432604722	6443	4	2B
0005432604707	6443	5	2A
0005432604714	6443	6	2C
0005434512154	6443	7	2D
0005432604703	6443	8	3A
0005434512152	6443	9	3B
0005432604733	6443	10	3D
0005432604728	6443	11	4B
0005432604701	6443	12	4C
0005434512155	6443	13	4D
0005432604717	6443	14	5A
0005432604696	6443	15	5B
0005432604729	6443	16	5C
0005432604699	6443	17	5D
0005432604704	6443	18	6A
0005432604715	6443	19	6B
0005434512151	6443	20	6C
0005432604719	6443	21	6D
0005432604702	6443	22	7A
0005432604726	6443	23	7B
0005434512153	6443	24	7C
0005432604727	6443	25	7D
0005432604706	6443	26	18A
0005432604710	6443	27	18B
0005432604698	6443	28	18C
0005432604732	6443	29	18D
0005432604713	6443	30	19A
0005432604709	6443	31	19B
0005432604718	6443	32	19C
0005432604711	6443	33	19D
0005432604708	6443	34	20A
0005432604720	6443	35	20C
0005432604721	6443	36	20B
0005432604716	6443	37	20D
0005432604725	6443	38	21A
0005432604712	6443	39	21B
0005432604734	6443	40	21C
0005432604705	6443	41	21D
0005432604730	6443	42	22A
0005432604723	6443	43	22B
0005432604735	6443	44	22C
0005432604724	6443	45	22D
0005432604700	6443	46	23B
0005432604258	21396	1	1A
0005432604374	21396	2	1B
0005432604421	21396	3	1C
0005432604337	21396	4	1D
0005432604302	21396	5	2A
0005432604212	21396	6	2B
0005432604316	21396	7	2C
0005432604510	21396	8	2D
0005432604332	21396	9	3A
0005432604409	21396	10	3C
0005432604082	21396	11	3D
0005432604303	21396	12	4A
0005432604373	21396	13	4B
0005432604240	21396	14	4C
0005432604360	21396	15	4D
0005432604134	21396	16	5A
0005432604359	21396	17	5B
0005432604133	21396	18	5C
0005432604358	21396	19	5D
0005432604259	21396	20	6A
0005432604131	21396	21	6B
0005432604415	21396	22	6D
0005432604333	21396	23	6C
0005432604223	21396	24	7A
0005432604130	21396	25	7B
0005432604098	21396	26	7C
0005432604220	21396	27	7D
0005432604472	21396	28	18A
0005432604338	21396	29	18B
0005432604455	21396	30	18C
0005432604345	21396	31	18D
0005432604404	21396	32	19A
0005432604304	21396	33	19B
0005432604315	21396	34	19C
0005432604028	21396	35	19D
0005432604270	21396	36	20A
0005432604260	21396	37	20B
0005432604239	21396	38	20C
0005432604335	21396	39	20D
0005432604348	21396	40	21B
0005432604405	21396	41	21A
0005432604518	21396	42	21C
0005432604097	21396	43	21D
0005432604224	21396	44	22A
0005432604334	21396	45	22C
0005432604470	21396	46	22B
0005432604300	21396	47	22D
0005432604511	21396	48	23A
0005432604318	21396	49	23B
0005434907290	14985	1	1A
0005434907153	14985	2	1C
0005433251773	14985	3	1D
0005433251767	14985	4	1F
0005434907205	14985	5	2A
0005434907339	14985	6	2D
0005434907312	14985	7	3A
0005434907191	14985	8	3C
0005434907319	14985	9	3D
0005433251749	14985	10	3F
0005434906871	14985	11	4A
0005433251765	14985	12	4C
0005433251760	14985	13	4D
0005433251771	14985	14	4E
0005433251764	14985	15	4F
0005433251779	14985	16	5A
0005434907280	14985	17	5C
0005434907304	14985	18	5D
0005434907209	14985	19	5E
0005434907267	14985	20	5F
0005434907017	14985	21	6A
0005434907052	14985	22	6C
0005434907340	14985	23	6D
0005434907165	14985	24	6E
0005433251763	14985	25	6F
0005433251757	14985	26	7A
0005434907346	14985	27	7C
0005434907259	14985	28	7D
0005433251761	14985	29	7E
0005434907258	14985	30	7F
0005434907250	14985	31	8A
0005433251755	14985	32	8C
0005434907178	14985	33	8F
0005434907276	14985	34	9A
0005434907160	14985	35	9C
0005434907311	14985	36	9D
0005433251770	14985	37	9E
0005433251766	14985	38	9F
0005434907202	14985	39	10A
0005434907300	14985	40	10C
0005434907048	14985	41	10D
0005434907235	14985	42	10E
0005433251754	14985	43	10F
0005434907169	14985	44	11A
0005433251752	14985	45	11C
0005434907130	14985	46	11D
0005433251758	14985	47	11E
0005434907201	14985	48	11F
0005433251759	14985	49	12A
0005433251778	14985	50	12C
0005433251780	14985	51	12D
0005434907264	14985	52	12E
0005433251776	14985	53	12F
0005434907307	14985	54	13A
0005434907104	14985	55	13C
0005434907279	14985	56	13D
0005434907170	14985	57	13E
0005434907152	14985	58	13F
0005433251769	14985	59	14A
0005433251750	14985	60	14C
0005434907016	14985	61	14D
0005434907211	14985	62	14E
0005434907320	14985	63	14F
0005434907347	14985	64	15A
0005434907263	14985	65	15C
0005434907306	14985	66	15D
0005434907313	14985	67	15E
0005434907341	14985	68	16C
0005433251774	14985	69	16D
0005433251762	14985	70	16E
0005433251756	14985	71	16F
0005433251777	14985	72	17A
0005434907321	14985	73	17C
0005434907105	14985	74	17D
0005433251751	14985	75	17E
0005434907134	14985	76	18C
0005433251753	14985	77	18D
0005434907272	14985	78	18E
0005434907177	14985	79	18F
0005434907230	14985	80	19C
0005433251775	14985	81	19D
0005433251781	14985	82	19E
0005434907275	14985	83	19F
0005433251772	14985	84	20A
0005434907192	14985	85	20C
0005434907159	14985	86	20D
0005434907210	14985	87	20E
0005433251768	14985	88	20F
0005433251534	25846	1	1A
0005433251420	25846	2	1C
0005433251593	25846	3	1D
0005434907729	25846	4	1F
0005434907742	25846	5	2C
0005433251455	25846	6	2F
0005433251562	25846	7	3A
0005433251512	25846	8	3C
0005434907710	25846	9	3D
0005433251447	25846	10	3F
0005434907741	25846	11	4A
0005434907714	25846	12	4C
0005434907713	25846	13	4E
0005434907740	25846	14	5A
0005434907727	25846	15	5C
0005433251594	25846	16	5D
0005434907733	25846	17	5E
0005433251599	25846	18	5F
0005434907734	25846	19	6A
0005434907715	25846	20	6C
0005433251454	25846	21	6D
0005434907719	25846	22	6E
0005434907712	25846	23	6F
0005434907745	25846	24	7A
0005434907736	25846	25	7C
0005434907716	25846	26	7D
0005433251600	25846	27	7E
0005433251491	25846	28	8A
0005434907735	25846	29	8C
0005433251544	25846	30	8D
0005434907722	25846	31	8E
0005434907730	25846	32	8F
0005433251414	25846	33	9A
0005433251390	25846	34	9C
0005434907709	25846	35	9E
0005434907732	25846	36	9F
0005433251498	25846	37	10A
0005433251428	25846	38	10C
0005433251347	25846	39	10D
0005433251496	25846	40	10E
0005433251453	25846	41	10F
0005433251514	25846	42	11A
0005433251456	25846	43	11C
0005433251434	25846	44	11D
0005434907721	25846	45	11E
0005433251435	25846	46	11F
0005433251466	25846	47	12C
0005433251561	25846	48	12F
0005433251367	25846	49	13A
0005433251611	25846	50	13D
0005434907717	25846	51	13E
0005434907728	25846	52	13F
0005434907737	25846	53	14A
0005434907708	25846	54	14C
0005434907743	25846	55	14D
0005433251505	25846	56	14E
0005433251548	25846	57	14F
0005434907718	25846	58	15A
0005434907711	25846	59	15D
0005433251392	25846	60	15F
0005434907738	25846	61	16A
0005433251510	25846	62	16C
0005433251592	25846	63	16D
0005434907725	25846	64	16E
0005433251480	25846	65	16F
0005433251346	25846	66	17A
0005434907744	25846	67	17C
0005433251433	25846	68	17D
0005434907739	25846	69	17F
0005434907724	25846	70	18A
0005434907723	25846	71	18C
0005433251481	25846	72	18D
0005434907720	25846	73	18E
0005433251338	25846	74	18F
0005433251511	25846	75	19C
0005434907707	25846	76	19D
0005433251488	25846	77	19E
0005434907731	25846	78	19F
0005433251553	25846	79	20A
0005434907726	25846	80	20C
0005433251418	25846	81	20D
0005433251389	25846	82	20E
0005433251489	25846	83	20F
0005433009042	14192	1	2A
0005433009063	14192	2	2C
0005433009050	14192	3	2D
0005433009045	14192	4	2F
0005433009028	14192	5	3A
0005433810526	14192	6	3F
0005433009051	14192	7	4C
0005433009044	14192	8	4E
0005433810533	14192	9	5F
0005433009059	14192	10	6C
0005433009033	14192	11	6D
0005433009071	14192	12	6E
0005433009073	14192	13	7A
0005433009066	14192	14	8A
0005433009068	14192	15	8C
0005433009037	14192	16	8D
0005433009058	14192	17	9A
0005433009065	14192	18	9C
0005433009034	14192	19	9D
0005433009043	14192	20	9F
0005433810521	14192	21	10A
0005433009054	14192	22	10E
0005433009053	14192	23	11A
0005433009035	14192	24	11D
0005433009048	14192	25	12A
0005433009055	14192	26	12E
0005433009069	14192	27	13A
0005433009046	14192	28	13D
0005433009041	14192	29	14A
0005433009031	14192	30	14C
0005433009056	14192	31	14D
0005433009040	14192	32	14E
0005433009032	14192	33	14F
0005433009072	14192	34	15A
0005433009064	14192	35	15C
0005433009049	14192	36	15E
0005433009061	14192	37	16A
0005433009047	14192	38	16D
0005433009039	14192	39	16F
0005433009030	14192	40	17C
0005433810534	14192	41	17F
0005433810529	14192	42	18A
0005433009036	14192	43	18C
0005433009057	14192	44	18D
0005433009067	14192	45	18E
0005433009052	14192	46	18F
0005433009029	14192	47	19C
0005433009070	14192	48	20C
0005433009062	14192	49	20D
0005433009060	14192	50	20E
0005433009038	14192	51	20F
0005433008589	22866	1	1A
0005433008481	22866	2	1C
0005433008666	22866	3	1D
0005433008734	22866	4	1F
0005433008775	22866	5	2A
0005433008883	22866	6	2C
0005433008538	22866	7	3C
0005433008658	22866	8	4C
0005433008616	22866	9	4F
0005433008559	22866	10	5F
0005433008774	22866	11	6C
0005433008750	22866	12	6E
0005433008502	22866	13	6F
0005433008495	22866	14	7A
0005433008530	22866	15	7E
0005433008580	22866	16	7F
0005433008656	22866	17	8A
0005433008615	22866	18	8C
0005433008657	22866	19	8D
0005433008745	22866	20	9C
0005433008713	22866	21	10A
0005433008560	22866	22	10C
0005433008544	22866	23	10D
0005433008442	22866	24	10E
0005433008727	22866	25	11D
0005433008595	22866	26	11E
0005433008683	22866	27	11F
0005433008501	22866	28	12A
0005433008555	22866	29	12C
0005433008496	22866	30	12E
0005433008379	22866	31	12F
0005433008655	22866	32	13F
0005433008882	22866	33	14C
0005433008474	22866	34	14F
0005433008545	22866	35	15C
0005433008541	22866	36	15D
0005433008536	22866	37	15E
0005433008623	22866	38	16D
0005433008746	22866	39	16F
0005433008508	22866	40	17D
0005433008575	22866	41	17F
0005433008316	22866	42	18A
0005433008776	22866	43	18C
0005433008676	22866	44	18F
0005433008482	22866	45	19A
0005433008735	22866	46	19C
0005433008396	22866	47	19D
0005433008682	22866	48	19E
0005433008626	22866	49	19F
0005433008685	22866	50	20E
0005433008550	22866	51	20F
0005434925776	14925	1	2A
0005434925762	14925	2	2D
0005434925755	14925	3	3F
0005434925809	14925	4	4A
0005434925768	14925	5	4F
0005434925769	14925	6	5C
0005434925791	14925	7	6A
0005434925824	14925	8	7A
0005434925798	14925	9	8A
0005434925782	14925	10	8E
0005434925799	14925	11	9C
0005434925825	14925	12	9D
0005434925784	14925	13	9E
0005434925821	14925	14	10F
0005434925822	14925	15	11A
0005434925754	14925	16	12D
0005434925765	14925	17	12E
0005434925752	14925	18	12F
0005434925810	14925	19	13A
0005434925759	14925	20	13D
0005434925764	14925	21	14A
0005434925763	14925	22	14D
0005434925823	14925	23	15E
0005434925790	14925	24	15F
0005434925783	14925	25	18A
0005434925753	14925	26	18D
0005434925751	14925	27	18F
0005434925760	14925	28	20A
0005434926078	20543	1	1D
0005434926095	20543	2	1F
0005434926066	20543	3	2A
0005434926077	20543	4	3A
0005434926064	20543	5	4E
0005434926060	20543	6	5E
0005434926065	20543	7	6D
0005434926076	20543	8	6E
0005434926097	20543	9	7A
0005434926083	20543	10	7C
0005434926073	20543	11	7E
0005434926074	20543	12	7F
0005434926070	20543	13	8F
0005434926075	20543	14	9C
0005434926061	20543	15	9D
0005434926088	20543	16	9E
0005434926069	20543	17	9F
0005434926090	20543	18	10A
0005434926062	20543	19	10C
0005434926063	20543	20	10D
0005434926081	20543	21	10F
0005434926084	20543	22	11C
0005434926079	20543	23	11E
0005434926068	20543	24	12D
0005434926087	20543	25	13E
0005434926072	20543	26	13F
0005434926086	20543	27	14A
0005434926091	20543	28	14D
0005434926089	20543	29	14E
0005434926082	20543	30	15A
0005434926092	20543	31	16C
0005434926094	20543	32	16E
0005434926080	20543	33	17D
0005434926067	20543	34	17F
0005434926093	20543	35	18D
0005434926071	20543	36	19C
0005434926096	20543	37	19F
0005434926085	20543	38	20D
0005435488039	15813	1	1B
0005435488049	15813	2	1C
0005435488032	15813	3	1D
0005435488043	15813	4	2A
0005435488033	15813	5	2B
0005435999193	15813	6	2D
0005435999217	15813	7	3A
0005435999258	15813	8	3B
0005435488045	15813	9	3C
0005435488044	15813	10	3D
0005435488050	15813	11	4C
0005435488038	15813	12	4D
0005435488047	15813	13	5A
0005435999213	15813	14	5B
0005435488036	15813	15	5D
0005435999226	15813	16	6A
0005435999261	15813	17	6B
0005435999235	15813	18	6C
0005435488037	15813	19	6D
0005435488051	15813	20	7B
0005435488046	15813	21	7C
0005435488041	15813	22	18C
0005435999240	15813	23	19A
0005435488040	15813	24	19B
0005435999246	15813	25	19C
0005435488042	15813	26	19D
0005435999241	15813	27	20A
0005435999215	15813	28	20C
0005435488034	15813	29	20D
0005435999257	15813	30	21A
0005435999260	15813	31	21B
0005435999214	15813	32	21C
0005435999259	15813	33	21D
0005435999253	15813	34	22A
0005435488035	15813	35	22B
0005435999176	15813	36	22C
0005435488048	15813	37	22D
0005435999216	15813	38	23A
0005435999197	15813	39	23B
0005435999397	19676	1	1B
0005435999385	19676	2	1C
0005435487706	19676	3	1D
0005435999398	19676	4	2A
0005435999389	19676	5	2C
0005435487873	19676	6	2B
0005435487764	19676	7	2D
0005435487847	19676	8	3A
0005435999403	19676	9	3B
0005435487786	19676	10	4A
0005435487893	19676	11	4B
0005435999399	19676	12	4C
0005435487783	19676	13	4D
0005435999391	19676	14	5A
0005435487850	19676	15	5B
0005435999402	19676	16	5C
0005435487888	19676	17	5D
0005435999393	19676	18	6A
0005435999388	19676	19	6B
0005435487852	19676	20	6C
0005435487766	19676	21	6D
0005435487782	19676	22	7A
0005435487781	19676	23	7B
0005435487789	19676	24	7C
0005435999396	19676	25	7D
0005435999390	19676	26	18A
0005435999394	19676	27	18B
0005435999401	19676	28	18C
0005435487750	19676	29	18D
0005435487849	19676	30	19A
0005435487892	19676	31	19B
0005435999404	19676	32	19D
0005435487748	19676	33	20A
0005435487864	19676	34	20B
0005435999386	19676	35	20C
0005435999400	19676	36	21A
0005435999395	19676	37	21B
0005435487825	19676	38	21C
0005435487765	19676	39	21D
0005435487790	19676	40	22A
0005435487826	19676	41	22B
0005435487851	19676	42	22C
0005435999392	19676	43	22D
0005435487824	19676	44	23A
0005435999387	19676	45	23B
0005432537061	6011	1	1A
0005435839713	6011	2	2D
0005435472854	6011	3	3C
0005435472748	6011	4	3F
0005435472781	6011	5	4F
0005435472756	6011	6	5C
0005432142280	6011	7	5A
0005435839729	6011	8	5D
0005432142282	6011	9	6D
0005435839720	6011	10	6C
0005435472811	6011	11	6E
0005435839708	6011	12	7A
0005435839711	6011	13	6F
0005435839731	6011	14	7E
0005435839723	6011	15	7D
0005435839722	6011	16	8B
0005435839732	6011	17	8F
0005435839715	6011	18	9C
0005432659727	6011	19	9E
0005435472875	6011	20	10A
0005435472871	6011	21	9F
0005435839717	6011	22	11B
0005435839730	6011	23	12B
0005435839724	6011	24	12A
0005432660839	6011	25	12C
0005435839714	6011	26	12F
0005432658612	6011	27	13B
0005435839712	6011	28	13D
0005435839728	6011	29	14A
0005435839718	6011	30	14C
0005435472757	6011	31	14B
0005435839734	6011	32	14D
0005435839707	6011	33	14F
0005435472877	6011	34	14E
0005435472760	6011	35	15B
0005435472806	6011	36	15C
0005435839721	6011	37	15E
0005432142281	6011	38	15D
0005435839733	6011	39	16C
0005435839725	6011	40	16E
0005435839727	6011	41	16D
0005435472876	6011	42	17C
0005435839719	6011	43	17B
0005435472831	6011	44	17A
0005435472812	6011	45	17D
0005432658613	6011	46	17E
0005435472758	6011	47	18C
0005435839709	6011	48	18E
0005435839726	6011	49	18D
0005435472761	6011	50	18F
0005432659726	6011	51	19C
0005435839706	6011	52	19B
0005435472724	6011	53	19E
0005435839716	6011	54	20A
0005435472833	6011	55	20C
0005435472725	6011	56	20F
0005435839710	6011	57	21D
0005435472958	18084	1	1A
0005435472962	18084	2	2F
0005432537079	18084	3	3C
0005432664136	18084	4	4C
0005435839421	18084	5	5C
0005435839284	18084	6	6C
0005435839392	18084	7	6E
0005435472957	18084	8	6F
0005435472955	18084	9	7C
0005435472953	18084	10	7D
0005435839474	18084	11	8A
0005435839420	18084	12	8E
0005435839369	18084	13	8D
0005435839496	18084	14	8C
0005435839324	18084	15	9B
0005432537080	18084	16	9C
0005432664141	18084	17	10E
0005435839504	18084	18	11B
0005435472961	18084	19	11D
0005435472952	18084	20	12B
0005435472963	18084	21	12D
0005435472964	18084	22	12C
0005435472966	18084	23	12F
0005435839495	18084	24	13A
0005435839452	18084	25	13C
0005435839325	18084	26	13B
0005435839581	18084	27	14D
0005435472967	18084	28	15B
0005432660820	18084	29	15C
0005435839579	18084	30	16A
0005435839408	18084	31	16B
0005435472956	18084	32	16F
0005435839285	18084	33	17D
0005432664142	18084	34	17E
0005432664114	18084	35	18D
0005435839453	18084	36	18C
0005435472959	18084	37	19A
0005435839530	18084	38	19D
0005435839538	18084	39	19E
0005435472954	18084	40	20B
0005432664137	18084	41	20A
0005435472965	18084	42	20F
0005435472960	18084	43	21B
0005432667456	18084	44	21A
0005433285374	23034	1	2C
0005433285244	23034	2	2D
0005433285310	23034	3	3D
0005433285344	23034	4	4E
0005433285386	23034	5	4D
0005433285459	23034	6	5A
0005435103987	23034	7	5B
0005435103990	23034	8	5E
0005433285375	23034	9	6E
0005435103992	23034	10	6F
0005433285189	23034	11	7B
0005433285223	23034	12	8E
0005433285413	23034	13	8F
0005433285318	23034	14	9B
0005435103988	23034	15	9D
0005433285457	23034	16	9F
0005433285309	23034	17	10B
0005433285373	23034	18	11F
0005433285311	23034	19	12A
0005435103991	23034	20	13A
0005433285301	23034	21	15F
0005433285456	23034	22	16D
0005433285342	23034	23	18E
0005433285477	23034	24	20A
0005433285336	23034	25	20D
0005433285514	23034	26	21A
0005433285236	23034	27	21D
0005435103993	23034	28	22A
0005433285300	23034	29	22F
0005435103989	23034	30	22E
0005433285337	23034	31	23B
0005433285405	23034	32	23E
0005433285603	32068	1	1C
0005433285611	32068	2	3C
0005433285590	32068	3	3F
0005433285599	32068	4	4D
0005433285596	32068	5	4C
0005435103923	32068	6	5A
0005433285586	32068	7	5F
0005433285587	32068	8	6A
0005433285605	32068	9	6F
0005433285591	32068	10	7A
0005433285588	32068	11	8A
0005435103925	32068	12	8B
0005433285609	32068	13	9B
0005433285606	32068	14	10C
0005433285613	32068	15	11E
0005433285601	32068	16	11F
0005433285584	32068	17	12D
0005433285592	32068	18	12F
0005435103928	32068	19	13E
0005435103914	32068	20	13F
0005433285607	32068	21	14B
0005433285595	32068	22	14A
0005433285612	32068	23	14C
0005433285597	32068	24	14F
0005433285594	32068	25	15C
0005433285608	32068	26	15F
0005433285602	32068	27	17F
0005435103908	32068	28	18E
0005433285585	32068	29	19B
0005433285600	32068	30	19C
0005435103919	32068	31	19D
0005433285610	32068	32	20C
0005433285598	32068	33	20D
0005433285582	32068	34	21C
0005433285604	32068	35	21E
0005433285589	32068	36	22B
0005433285583	32068	37	22E
0005433285593	32068	38	23A
0005435103913	32068	39	23D
0005435103909	32068	40	23E
0005433475712	23874	1	2B
0005433475707	23874	2	2C
0005435852603	23874	3	3A
0005433475706	23874	4	4A
0005433475688	23874	5	4D
0005433475717	23874	6	5A
0005433475720	23874	7	5B
0005433475687	23874	8	7D
0005435852602	23874	9	18A
0005433475705	23874	10	19C
0005435852601	23874	11	20A
0005433475718	23874	12	20C
0005435852600	23874	13	22C
0005432528200	30576	1	1D
0005435214233	30576	2	2A
0005432527978	30576	3	1K
0005434067612	30576	4	2C
0005435725651	30576	5	2G
0005434067645	30576	6	3A
0005434067523	30576	7	2K
0005434067388	30576	8	3D
0005432535843	30576	9	3K
0005435214218	30576	10	3H
0005432528355	30576	11	3G
0005432527958	30576	12	4C
0005432533293	30576	13	4G
0005435214239	30576	14	4D
0005432535844	30576	15	4K
0005432528194	30576	16	4H
0005432428926	30576	17	5H
0005435214205	30576	18	5D
0005435214203	30576	19	11A
0005432535839	30576	20	11D
0005435630997	30576	21	11F
0005435214226	30576	22	11H
0005432528225	30576	23	12C
0005435214243	30576	24	11K
0005432528179	30576	25	12E
0005432533298	30576	26	12D
0005432535840	30576	27	12G
0005432528284	30576	28	12F
0005434067266	30576	29	12K
0005432528183	30576	30	12H
0005432528203	30576	31	13D
0005435214269	30576	32	13F
0005432528520	30576	33	13E
0005435214249	30576	34	13H
0005432528087	30576	35	13G
0005432527720	30576	36	14A
0005432528625	30576	37	13K
0005432527370	30576	38	14D
0005432527972	30576	39	14G
0005432533296	30576	40	14E
0005434067629	30576	41	14K
0005434067679	30576	42	14H
0005432211575	30576	43	15C
0005435214227	30576	44	15A
0005432527857	30576	45	15E
0005433656705	30576	46	15D
0005432528036	30576	47	15H
0005434067553	30576	48	15G
0005432211580	30576	49	15F
0005432211576	30576	50	16A
0005434067540	30576	51	15K
0005434067602	30576	52	16D
0005434067592	30576	53	16F
0005432159905	30576	54	16E
0005432527823	30576	55	16H
0005434067591	30576	56	17A
0005432527868	30576	57	16K
0005435214240	30576	58	17E
0005432527988	30576	59	17D
0005432527751	30576	60	17F
0005432527991	30576	61	17H
0005434067428	30576	62	18C
0005434067750	30576	63	18D
0005432528025	30576	64	18G
0005432528121	30576	65	18E
0005435214210	30576	66	18J
0005434067693	30576	67	18H
0005434067692	30576	68	18K
0005432528192	30576	69	19D
0005435214236	30576	70	19B
0005435214228	30576	71	19F
0005432528246	30576	72	19E
0005432528324	30576	73	19J
0005435214260	30576	74	19H
0005432528384	30576	75	19G
0005433656704	30576	76	20A
0005432527911	30576	77	19K
0005432528949	30576	78	20C
0005435214225	30576	79	20B
0005432527967	30576	80	20D
0005434067670	30576	81	20G
0005435214258	30576	82	20K
0005435214206	30576	83	21B
0005432528348	30576	84	21A
0005432527858	30576	85	21D
0005432528120	30576	86	21F
0005434067764	30576	87	21E
0005432527979	30576	88	21G
0005432528030	30576	89	21K
0005432528162	30576	90	22C
0005432211578	30576	91	22B
0005434067401	30576	92	22H
0005432528522	30576	93	22G
0005435214235	30576	94	22F
0005435214223	30576	95	22K
0005435214250	30576	96	22J
0005432528578	30576	97	23C
0005435214256	30576	98	23A
0005432535856	30576	99	23D
0005434067851	30576	100	23G
0005433656706	30576	101	23F
0005434067980	30576	102	23E
0005434067694	30576	103	23H
0005432528201	30576	104	24D
0005434067531	30576	105	23K
0005435214216	30576	106	23J
0005434067616	30576	107	24G
0005435214204	30576	108	24F
0005434067475	30576	109	24E
0005435214241	30576	110	25B
0005434067289	30576	111	25A
0005435214211	30576	112	25C
0005432528122	30576	113	25F
0005434067601	30576	114	25E
0005432527730	30576	115	25D
0005432528825	30576	116	25J
0005432528311	30576	117	25H
0005432159904	30576	118	26A
0005432527905	30576	119	25K
0005432528237	30576	120	26C
0005434067522	30576	121	26B
0005432528289	30576	122	26D
0005432528182	30576	123	26G
0005432528577	30576	124	26J
0005435214207	30576	125	26H
0005432535857	30576	126	27B
0005432528521	30576	127	27A
0005434067762	30576	128	26K
0005435214245	30576	129	27C
0005435214263	30576	130	27H
0005432528055	30576	131	27G
0005434067753	30576	132	28A
0005435214230	30576	133	27K
0005435214237	30576	134	27J
0005435214231	30576	135	28C
0005434067742	30576	136	28B
0005435725654	30576	137	28D
0005435214220	30576	138	28F
0005435214222	30576	139	28H
0005432528184	30576	140	29B
0005434067723	30576	141	29A
0005432528024	30576	142	28K
0005435725652	30576	143	29D
0005435214255	30576	144	29C
0005432528325	30576	145	29F
0005435214247	30576	146	29E
0005434067353	30576	147	29H
0005434067644	30576	148	29G
0005432528252	30576	149	29K
0005435214201	30576	150	29J
0005432159906	30576	151	30B
0005432527912	30576	152	30A
0005435214264	30576	153	30E
0005432159903	30576	154	30G
0005432211574	30576	155	30F
0005432527936	30576	156	30K
0005432211579	30576	157	30H
0005434067741	30576	158	31B
0005435214254	30576	159	31A
0005432528180	30576	160	31E
0005434067751	30576	161	31H
0005435214248	30576	162	32C
0005432528218	30576	163	32B
0005432527870	30576	164	32E
0005432527975	30576	165	32D
0005434067169	30576	166	32F
0005434067343	30576	167	32J
0005432528066	30576	168	33A
0005434067699	30576	169	32K
0005435214217	30576	170	33C
0005434067720	30576	171	33F
0005432527992	30576	172	33E
0005432528547	30576	173	33H
0005432528199	30576	174	33G
0005432528341	30576	175	34A
0005434067763	30576	176	33K
0005434067409	30576	177	34B
0005435214257	30576	178	34D
0005435214267	30576	179	34C
0005432528207	30576	180	34G
0005432528032	30576	181	34J
0005434067752	30576	182	34H
0005432159902	30576	183	35B
0005432528376	30576	184	34K
0005434067520	30576	185	35D
0005435630998	30576	186	35C
0005435214244	30576	187	35E
0005434067389	30576	188	35H
0005432527966	30576	189	36A
0005434067518	30576	190	35K
0005434067785	30576	191	35J
0005432528386	30576	192	36C
0005432528375	30576	193	36B
0005432528394	30576	194	36D
0005434067736	30576	195	36H
0005432528014	30576	196	36G
0005435214246	30576	197	36F
0005434067656	30576	198	36K
0005432528063	30576	199	36J
0005435214262	30576	200	37A
0005432528219	30576	201	37F
0005432528528	30576	202	37E
0005432528240	30576	203	37H
0005435214209	30576	204	37G
0005432527729	30576	205	37K
0005434067856	30576	206	37J
0005434067425	30576	207	38B
0005435214266	30576	208	38A
0005432527879	30576	209	38H
0005435214214	30576	210	39B
0005432528362	30576	211	39D
0005435214232	30576	212	39C
0005434067481	30576	213	39E
0005435214208	30576	214	39G
0005432533291	30576	215	39K
0005434067458	30576	216	39J
0005432528067	30576	217	40C
0005435214265	30576	218	40B
0005432527968	30576	219	40E
0005434067615	30576	220	40D
0005432528070	30576	221	40F
0005435725653	30576	222	40H
0005435214234	30576	223	41B
0005432528285	30576	224	41C
0005434067519	30576	225	41F
0005434067688	30576	226	41H
0005435214253	30576	227	41K
0005435630999	30576	228	41J
0005435214261	30576	229	42C
0005435214259	30576	230	42B
0005432528361	30576	231	42E
0005434067567	30576	232	42D
0005432527728	30576	233	42G
0005435214213	30576	234	42K
0005435214202	30576	235	42J
0005432528385	30576	236	43B
0005435214219	30576	237	43C
0005432535855	30576	238	43J
0005432527957	30576	239	43H
0005434067446	30576	240	44A
0005432528414	30576	241	43K
0005432528146	30576	242	44B
0005432528208	30576	243	44C
0005434067857	30576	244	44H
0005432528354	30576	245	44G
0005432533292	30576	246	44F
0005432528291	30576	247	44J
0005434067671	30576	248	45A
0005435214238	30576	249	44K
0005432527880	30576	250	45D
0005432533295	30576	251	45C
0005432528417	30576	252	45B
0005432527886	30576	253	45E
0005432527885	30576	254	45J
0005432528163	30576	255	45K
0005432528185	30576	256	46C
0005434067400	30576	257	46A
0005432527887	30576	258	46G
0005432533294	30576	259	46F
0005432535845	30576	260	46H
0005435214224	30576	261	47A
0005435214212	30576	262	46K
0005434067482	30576	263	47E
0005435214242	30576	264	47C
0005435214215	30576	265	47H
0005432211577	30576	266	48C
0005432528395	30576	267	48F
0005432528193	30576	268	48E
0005432528065	30576	269	48H
0005432528554	30576	270	48G
0005434067410	30576	271	49C
0005435214252	30576	272	49A
0005435214268	30576	273	48K
0005435214221	30576	274	49F
0005435214229	30576	275	49E
0005432527956	30576	276	49H
0005432528290	30576	277	49G
0005435725650	30576	278	50C
0005432528239	30576	279	50A
0005434067617	30576	280	49K
0005432528031	30576	281	50E
0005434067426	30576	282	50D
0005435214251	30576	283	50G
0005434067429	30576	284	51D
0005432527696	30576	285	50K
0005432528443	30576	286	51F
0005434067457	30576	287	51G
0005435652888	24823	1	1A
0005435653076	24823	2	1C
0005433368292	24823	3	1D
0005433368267	24823	4	1F
0005433368293	24823	5	2A
0005433368289	24823	6	2D
0005435653118	24823	7	2F
0005435652997	24823	8	3A
0005433368274	24823	9	3C
0005433368279	24823	10	3D
0005433368280	24823	11	4A
0005435652936	24823	12	4C
0005435652935	24823	13	4E
0005435652956	24823	14	4F
0005435653063	24823	15	5A
0005435652886	24823	16	5C
0005435653164	24823	17	5E
0005433368270	24823	18	5F
0005435653021	24823	19	6A
0005435653077	24823	20	6C
0005435653097	24823	21	6D
0005435653156	24823	22	6E
0005435653019	24823	23	6F
0005435653000	24823	24	7A
0005433368286	24823	25	7D
0005435653109	24823	26	7E
0005433368290	24823	27	7F
0005433368282	24823	28	8A
0005433368287	24823	29	8C
0005433368261	24823	30	8D
0005435653075	24823	31	8E
0005435652998	24823	32	8F
0005433368258	24823	33	9A
0005435653099	24823	34	9C
0005433368262	24823	35	9D
0005435652947	24823	36	9E
0005435652996	24823	37	9F
0005435653117	24823	38	10C
0005433368276	24823	39	10D
0005435653090	24823	40	10E
0005435653110	24823	41	10F
0005433368256	24823	42	11A
0005433368284	24823	43	11C
0005435653071	24823	44	11D
0005433368275	24823	45	11E
0005433368277	24823	46	11F
0005435653073	24823	47	12A
0005435653020	24823	48	12D
0005435653085	24823	49	12C
0005435653105	24823	50	12E
0005435653101	24823	51	12F
0005433368278	24823	52	13A
0005435653018	24823	53	13C
0005435652994	24823	54	13D
0005433368255	24823	55	13E
0005435653141	24823	56	13F
0005435653044	24823	57	14A
0005433368272	24823	58	14C
0005435653072	24823	59	14D
0005435653104	24823	60	14E
0005435653064	24823	61	15A
0005433368263	24823	62	15C
0005433368283	24823	63	15D
0005433368266	24823	64	15E
0005435652999	24823	65	15F
0005433368257	24823	66	16A
0005435653080	24823	67	16C
0005435653010	24823	68	16D
0005433368285	24823	69	16E
0005433368281	24823	70	16F
0005435653089	24823	71	17A
0005433368264	24823	72	17C
0005433368273	24823	73	17E
0005435652965	24823	74	17F
0005435653098	24823	75	18A
0005433368265	24823	76	18D
0005435653162	24823	77	18C
0005433368291	24823	78	18E
0005435653011	24823	79	18F
0005433368271	24823	80	19A
0005435652887	24823	81	19D
0005435652957	24823	82	19E
0005433368260	24823	83	19F
0005433368288	24823	84	20A
0005433368259	24823	85	20C
0005435653008	24823	86	20D
0005433368268	24823	87	20E
0005433368269	24823	88	20F
0005435949807	6593	1	4C
0005435949809	6593	2	5A
0005435949812	6593	3	19A
0005435949808	6593	4	20B
0005435949806	6593	5	20C
0005435949810	6593	6	21C
0005435949805	6593	7	22A
0005435949811	6593	8	23A
0005434980093	2020	1	1A
0005434980089	2020	2	1B
0005434980110	2020	3	3A
0005434980094	2020	4	3B
0005434980099	2020	5	3C
0005434980086	2020	6	4B
0005434980112	2020	7	4C
0005434980083	2020	8	4D
0005434980109	2020	9	5C
0005434980108	2020	10	5D
0005434980095	2020	11	6A
0005434980102	2020	12	6B
0005434980085	2020	13	7A
0005434980113	2020	14	7C
0005434980101	2020	15	18A
0005434980098	2020	16	18B
0005434980100	2020	17	18C
0005434980106	2020	18	18D
0005434980097	2020	19	19A
0005434980084	2020	20	19B
0005434980091	2020	21	19C
0005435801728	2020	22	19D
0005435801727	2020	23	20A
0005434980088	2020	24	20B
0005434980105	2020	25	20C
0005434980103	2020	26	21A
0005434980087	2020	27	21D
0005434980096	2020	28	22A
0005434980090	2020	29	22B
0005434980104	2020	30	22C
0005434980111	2020	31	22D
0005434980107	2020	32	23A
0005434980092	2020	33	23B
0005434979713	23559	1	1A
0005435801705	23559	2	1B
0005435801704	23559	3	3A
0005434979779	23559	4	3B
0005434979750	23559	5	3C
0005435801691	23559	6	3D
0005434979817	23559	7	4A
0005434979882	23559	8	4C
0005434979753	23559	9	5C
0005434979768	23559	10	6A
0005434979787	23559	11	6C
0005434979742	23559	12	6D
0005434979885	23559	13	7A
0005434979786	23559	14	18A
0005434979736	23559	15	18B
0005434979861	23559	16	19A
0005434979886	23559	17	20A
0005434979767	23559	18	20C
0005434979855	23559	19	20D
0005434979766	23559	20	21A
0005434979743	23559	21	21D
0005435801703	23559	22	22A
0005434979820	23559	23	22B
0005434979712	23559	24	22D
0005434979846	23559	25	23B
0005434952570	2585	1	1A
0005434952568	2585	2	2A
0005434952571	2585	3	2B
0005434952572	2585	4	4B
0005434952569	2585	5	6A
0005433256427	2562	1	6A
0005433256444	28201	1	1A
0005433256446	28201	2	2B
0005433256447	28201	3	6A
0005433256445	28201	4	6B
0005434302859	19799	1	2A
0005433111529	19799	2	3B
0005434302860	19799	3	4A
0005434302861	19799	4	5B
0005433111528	19799	5	6B
0005434138267	11926	1	1A
0005434138266	11926	2	1C
0005434138186	11926	3	1D
0005434138148	11926	4	1F
0005434138444	11926	5	2A
0005434138416	11926	6	2C
0005434138308	11926	7	2D
0005434138540	11926	8	2F
0005434138268	11926	9	3C
0005434138588	11926	10	3D
0005434138414	11926	11	3F
0005434138711	11926	12	4A
0005434138488	11926	13	4D
0005434138277	11926	14	4E
0005434138468	11926	15	4F
0005434138159	11926	16	5A
0005434138102	11926	17	5C
0005434138253	11926	18	5F
0005434138469	11926	19	6A
0005434138699	11926	20	6C
0005434138198	11926	21	6D
0005434138317	11926	22	6E
0005434138074	11926	23	7A
0005434138304	11926	24	7C
0005434138638	11926	25	7E
0005434138455	11926	26	7F
0005434138278	11926	27	8A
0005434137872	11926	28	8C
0005434138442	11926	29	8D
0005434138693	11926	30	8E
0005434138394	11926	31	8F
0005434138445	11926	32	9A
0005434138431	11926	33	9C
0005434137970	11926	34	9D
0005434138149	11926	35	9E
0005434138351	11926	36	9F
0005434138316	11926	37	10A
0005434138114	11926	38	10C
0005434138281	11926	39	10D
0005434138227	11926	40	10F
0005434138119	11926	41	11C
0005434137895	11926	42	11D
0005434138429	11926	43	11E
0005434138509	11926	44	11F
0005434137966	11926	45	12A
0005434138352	11926	46	12C
0005434138318	11926	47	12D
0005434138710	11926	48	12E
0005434138167	11926	49	12F
0005434138371	11926	50	13A
0005434138273	11926	51	13C
0005434138080	11926	52	13D
0005434138494	11926	53	13E
0005434138557	11926	54	13F
0005434138694	11926	55	14A
0005434138284	11926	56	14C
0005434138252	11926	57	14D
0005434137926	11926	58	14E
0005434138428	11926	59	15A
0005434138435	11926	60	15C
0005434138160	11926	61	15D
0005434138541	11926	62	15E
0005434138392	11926	63	15F
0005434138589	11926	64	16C
0005434138342	11926	65	16D
0005434138430	11926	66	16E
0005434138168	11926	67	16F
0005434138282	11926	68	17A
0005434138269	11926	69	17C
0005434137978	11926	70	17D
0005434138283	11926	71	17E
0005434138539	11926	72	18C
0005434138558	11926	73	18D
0005434137898	11926	74	18E
0005434138458	11926	75	18F
0005434138383	11926	76	19A
0005434138350	11926	77	19C
0005434138272	11926	78	19E
0005434138542	11926	79	19F
0005434138064	11926	80	20C
0005434138370	11926	81	20D
0005434138493	11926	82	20E
0005434138933	28752	1	1A
0005434138897	28752	2	1C
0005434138941	28752	3	1D
0005434138929	28752	4	1F
0005434138922	28752	5	2A
0005434138918	28752	6	2D
0005434138943	28752	7	2F
0005434138912	28752	8	3A
0005434138968	28752	9	3C
0005434138976	28752	10	3D
0005434138936	28752	11	3F
0005434138906	28752	12	4A
0005434138942	28752	13	4C
0005434138928	28752	14	4D
0005434138907	28752	15	4E
0005434138954	28752	16	4F
0005434138909	28752	17	5A
0005434138972	28752	18	5C
0005434138938	28752	19	5D
0005434138913	28752	20	5E
0005434138904	28752	21	5F
0005434138903	28752	22	6A
0005434138962	28752	23	6C
0005434138930	28752	24	6D
0005434138900	28752	25	6F
0005434138896	28752	26	7A
0005434138969	28752	27	7C
0005434138963	28752	28	7D
0005434138894	28752	29	7E
0005434138950	28752	30	8C
0005434138923	28752	31	8D
0005434138966	28752	32	8F
0005434138898	28752	33	9A
0005434138965	28752	34	9D
0005434138915	28752	35	9E
0005434138924	28752	36	9F
0005434138940	28752	37	10A
0005434138925	28752	38	10D
0005434138926	28752	39	10E
0005434138908	28752	40	11A
0005434138973	28752	41	11C
0005434138974	28752	42	11D
0005434138899	28752	43	11E
0005434138953	28752	44	11F
0005434138952	28752	45	12A
0005434138975	28752	46	12C
0005434138945	28752	47	12D
0005434138905	28752	48	12E
0005434138917	28752	49	12F
0005434138911	28752	50	13A
0005434138958	28752	51	13C
0005434138960	28752	52	13D
0005434138939	28752	53	13E
0005434138959	28752	54	13F
0005434138949	28752	55	14A
0005434138978	28752	56	14C
0005434138927	28752	57	14E
0005434138931	28752	58	14D
0005434138957	28752	59	14F
0005434138944	28752	60	15A
0005434138919	28752	61	15D
0005434138947	28752	62	15C
0005434138935	28752	63	15E
0005434138971	28752	64	15F
0005434138955	28752	65	16A
0005434138956	28752	66	16C
0005434138920	28752	67	16D
0005434138934	28752	68	16E
0005434138902	28752	69	16F
0005434138977	28752	70	17C
0005434138937	28752	71	17D
0005434138910	28752	72	17E
0005434138964	28752	73	17F
0005434138967	28752	74	18A
0005434138895	28752	75	18E
0005434138901	28752	76	18F
0005434138951	28752	77	19A
0005434138946	28752	78	19C
0005434138961	28752	79	19D
0005434138916	28752	80	19E
0005434138948	28752	81	19F
0005434138921	28752	82	20A
0005434138914	28752	83	20C
0005434138970	28752	84	20E
0005434138932	28752	85	20F
0005434466512	6568	1	1C
0005435312812	6568	2	2A
0005434466513	6568	3	2C
0005434466514	6568	4	2D
0005434466507	6568	5	3C
0005435312813	6568	6	4C
0005434466506	6568	7	5C
0005434466505	6568	8	6D
0005434466510	6568	9	7A
0005434466509	6568	10	19D
0005434466511	6568	11	20C
0005435312799	6568	12	20D
0005434466508	6568	13	22C
0005433534521	6816	1	1D
0005433538956	6816	2	2D
0005433538955	6816	3	3C
0005433538957	6816	4	3D
0005433538960	6816	5	4C
0005433534520	6816	6	6B
0005433538958	6816	7	6C
0005433534519	6816	8	19A
0005433538962	6816	9	19C
0005435259742	6816	10	20A
0005435259767	6816	11	21D
0005433538959	6816	12	22B
0005433538961	6816	13	22D
0005433538882	24998	1	2A
0005433538876	24998	2	2D
0005433538875	24998	3	3B
0005433538909	24998	4	4A
0005433538915	24998	5	4D
0005433538867	24998	6	5A
0005433538883	24998	7	5D
0005433538927	24998	8	6C
0005433538868	24998	9	7B
0005433538865	24998	10	7C
0005435259802	24998	11	7D
0005433538881	24998	12	18B
0005433534503	24998	13	19B
0005433538864	24998	14	19C
0005433538890	24998	15	19D
0005435259800	24998	16	20B
0005433534501	24998	17	20C
0005433538914	24998	18	21A
0005435259801	24998	19	21B
0005435259803	24998	20	21C
0005433538908	24998	21	22B
0005433512035	850	1	1A
0005433512041	850	2	1C
0005433512037	850	3	2B
0005433512039	850	4	2D
0005433512034	850	5	7A
0005433512042	850	6	7B
0005432922543	850	7	7C
0005433512036	850	8	18D
0005432922539	850	9	20B
0005433512038	850	10	21B
0005432922515	850	11	21C
0005432922534	850	12	22B
0005433512040	850	13	23B
0005432922568	16144	1	1A
0005433511971	16144	2	2C
0005433512003	16144	3	2D
0005432922565	16144	4	4D
0005432922566	16144	5	5A
0005433511966	16144	6	18A
0005433511989	16144	7	18C
0005433511944	16144	8	19B
0005433511990	16144	9	20C
0005433511965	16144	10	21A
0005433511964	16144	11	21B
0005432922567	16144	12	21C
0005433511975	16144	13	22C
0005434950574	3690	1	1A
0005434950577	3690	2	1B
0005435697619	3690	3	1C
0005435697623	3690	4	1D
0005435935061	3690	5	2B
0005434950576	3690	6	2C
0005435697639	3690	7	2D
0005435697638	3690	8	4A
0005435697620	3690	9	4C
0005435697628	3690	10	4D
0005435697626	3690	11	5A
0005435697632	3690	12	5B
0005435697633	3690	13	5D
0005435697618	3690	14	6A
0005435697625	3690	15	6B
0005434950575	3690	16	6C
0005435697629	3690	17	6D
0005435697622	3690	18	7A
0005435697627	3690	19	7B
0005435916174	3690	20	7C
0005435697631	3690	21	18B
0005435697640	3690	22	18C
0005435916173	3690	23	18D
0005435935058	3690	24	19A
0005435697645	3690	25	19B
0005435697634	3690	26	19C
0005435697637	3690	27	19D
0005435697630	3690	28	20B
0005435697635	3690	29	20C
0005435697644	3690	30	20D
0005435697621	3690	31	21A
0005435697641	3690	32	21B
0005435697624	3690	33	21C
0005435697646	3690	34	22A
0005435697643	3690	35	22B
0005435697636	3690	36	23A
0005435697642	3690	37	23B
0005435697255	16302	1	1A
0005435697389	16302	2	1B
0005435935076	16302	3	1C
0005435697493	16302	4	2A
0005435697343	16302	5	2B
0005435697348	16302	6	2C
0005435697371	16302	7	3B
0005435697374	16302	8	3C
0005434950559	16302	9	4B
0005435697422	16302	10	4D
0005435916196	16302	11	4C
0005435697403	16302	12	5A
0005435697373	16302	13	5B
0005435697388	16302	14	5C
0005435697421	16302	15	5D
0005435935073	16302	16	6A
0005435697397	16302	17	6B
0005435697429	16302	18	7C
0005435697428	16302	19	18A
0005435697376	16302	20	18B
0005435935075	16302	21	18C
0005435697345	16302	22	18D
0005435697344	16302	23	20A
0005435697391	16302	24	20B
0005435697370	16302	25	20D
0005434950549	16302	26	21A
0005434950537	16302	27	21B
0005435935074	16302	28	21C
0005435697346	16302	29	22A
0005435697353	16302	30	22D
0005435697420	16302	31	23B
0005433519507	3984	1	1A
0005432609772	3984	2	2A
0005433519505	3984	3	2C
0005434604934	3984	4	2D
0005434604932	3984	5	4C
0005432607610	3984	6	5A
0005432609775	3984	7	5B
0005432607609	3984	8	5D
0005434606866	3984	9	6B
0005433519504	3984	10	6C
0005432609773	3984	11	6D
0005433519506	3984	12	7A
0005433519503	3984	13	7B
0005434604931	3984	14	7C
0005433519508	3984	15	18C
0005432609774	3984	16	18D
0005435842328	3984	17	19A
0005434604933	3984	18	19B
0005434604930	3984	19	20C
0005435904895	3984	20	21A
0005432607611	3984	21	21C
0005432607608	3984	22	23A
0005435853630	22057	1	2C
0005434606820	22057	2	3C
0005434606828	22057	3	5A
0005434606832	22057	4	6A
0005434606819	22057	5	6D
0005435853631	22057	6	7A
0005435853629	22057	7	18A
0005433519447	22057	8	22B
0005433519448	22057	9	23A
0005434606835	22057	10	23B
0005433348988	702	1	1B
0005435628759	702	2	2A
0005435628761	702	3	3B
0005433349020	702	4	4B
0005433348987	702	5	5A
0005433349019	702	6	6A
0005435628760	702	7	6B
0005433349049	15932	1	1A
0005433349051	15932	2	1B
0005435628724	15932	3	2A
0005433349047	15932	4	3A
0005433349050	15932	5	5A
0005433349052	15932	6	5B
0005433349048	15932	7	6A
0005435628747	15932	8	6B
0005434445264	17145	1	1A
0005433159305	17145	2	1B
0005433159324	17145	3	2B
0005433158123	17145	4	3B
0005434445265	17145	5	3A
0005434445263	17145	6	4A
0005433159327	17145	7	4B
0005433159326	17145	8	5A
0005434445262	17145	9	5B
0005434446537	17145	10	6B
0005433158135	17145	11	6A
0005434445240	17666	1	1A
0005434445258	17666	2	3A
0005434445251	17666	3	4A
0005433159337	17666	4	6B
0005435132996	7879	1	2A
0005435383153	7879	2	2B
0005435132988	7879	3	2D
0005435132995	7879	4	3C
0005435132990	7879	5	4C
0005435383147	7879	6	5B
0005435132992	7879	7	5C
0005435383146	7879	8	6B
0005435132997	7879	9	6C
0005435383159	7879	10	7C
0005435132991	7879	11	18D
0005435132989	7879	12	19A
0005435132994	7879	13	20D
0005435132993	7879	14	21D
0005435132987	7879	15	22A
0005435132883	33095	1	1C
0005435132907	33095	2	1D
0005435383204	33095	3	4B
0005435383208	33095	4	4C
0005435383205	33095	5	5B
0005435132884	33095	6	6B
0005435132919	33095	7	7A
0005435383206	33095	8	19C
0005435383207	33095	9	19D
0005435132880	33095	10	21A
0005435132917	33095	11	22C
0005435132918	33095	12	22D
0005435811128	4400	1	3A
0005435938896	4400	2	7A
0005435938895	4400	3	7D
0005435811121	4400	4	9B
0005435811125	4400	5	9C
0005435811130	4400	6	9E
0005435811126	4400	7	10D
0005435938889	4400	8	11C
0005435811127	4400	9	11B
0005435811123	4400	10	11D
0005435811122	4400	11	12D
0005435938887	4400	12	15B
0005435811129	4400	13	17D
0005435938865	4400	14	17E
0005435938888	4400	15	18B
0005435938866	4400	16	20C
0005435811124	4400	17	20F
0005435811104	29443	1	4D
0005435938912	29443	2	5C
0005435811067	29443	3	5A
0005435938911	29443	4	6B
0005435811073	29443	5	5F
0005435811065	29443	6	8C
0005435811076	29443	7	9F
0005435811072	29443	8	10E
0005435938913	29443	9	12C
0005435938915	29443	10	14B
0005435811090	29443	11	16F
0005435938914	29443	12	19C
0005435811105	29443	13	19E
0005435811064	29443	14	20A
0005435811075	29443	15	21B
0005435811054	29443	16	21D
0005435390266	7525	1	2C
0005435160414	7525	2	3B
0005435390249	7525	3	5A
0005435390267	7525	4	5D
0005435390265	7525	5	6B
0005435390253	7525	6	6C
0005435160416	7525	7	7B
0005435160419	7525	8	7C
0005435160420	7525	9	7D
0005435160418	7525	10	18A
0005435390254	7525	11	18B
0005435390248	7525	12	18D
0005435160417	7525	13	19B
0005435160422	7525	14	20B
0005435160421	7525	15	20C
0005435160415	7525	16	21C
0005435390264	7525	17	21D
0005435160413	7525	18	22D
0005435160423	7525	19	23B
0005435390314	29530	1	1B
0005435390315	29530	2	2A
0005435160341	29530	3	3B
0005435390311	29530	4	5B
0005435390313	29530	5	5D
0005435160375	29530	6	6A
0005435160317	29530	7	6D
0005435160360	29530	8	7A
0005435160372	29530	9	7B
0005435160340	29530	10	18C
0005435390310	29530	11	20B
0005435390312	29530	12	20C
0005435160320	29530	13	21C
0005435160371	29530	14	22D
0005435160342	29530	15	23B
0005435178513	18469	1	1A
0005435178510	18469	2	1B
0005432398210	18469	3	2A
0005435178511	18469	4	2B
0005432398199	18469	5	3A
0005432398205	18469	6	3B
0005432394093	18469	7	4A
0005432398204	18469	8	4B
0005435178512	18469	9	5A
0005432394122	18469	10	5B
0005432394123	18469	11	6A
0005432394092	18469	12	6B
0005432398234	27145	1	1A
0005432398235	27145	2	2A
0005432398233	27145	3	3A
0005432400159	27145	4	2B
0005432400160	27145	5	3B
0005432400161	27145	6	4A
0005432400162	27145	7	4B
0005432398231	27145	8	5A
0005432400163	27145	9	5B
0005432400164	27145	10	6A
0005432398232	27145	11	6B
0005432639251	2252	1	1A
0005432639256	2252	2	1D
0005432639250	2252	3	1F
0005432866027	2252	4	2A
0005432639253	2252	5	2C
0005432639271	2252	6	2D
0005432866030	2252	7	2F
0005432639269	2252	8	3D
0005432866036	2252	9	3F
0005432866033	2252	10	4C
0005432865994	2252	11	4E
0005432866022	2252	12	4D
0005432639265	2252	13	5C
0005432639254	2252	14	5F
0005432639262	2252	15	6D
0005432639261	2252	16	7F
0005432866016	2252	17	8A
0005432639257	2252	18	8D
0005432866015	2252	19	8F
0005432639259	2252	20	9A
0005432639245	2252	21	9C
0005432865996	2252	22	10C
0005432639249	2252	23	10E
0005432639258	2252	24	11A
0005432639260	2252	25	10F
0005432866040	2252	26	11D
0005432866010	2252	27	11E
0005432866031	2252	28	11F
0005432639267	2252	29	12C
0005432639263	2252	30	12D
0005432866041	2252	31	12E
0005432639264	2252	32	12F
0005432866011	2252	33	13A
0005432865995	2252	34	13D
0005432639248	2252	35	13F
0005432866053	2252	36	14F
0005432639268	2252	37	15E
0005432866017	2252	38	16A
0005432639246	2252	39	16D
0005432639252	2252	40	17A
0005432639255	2252	41	17F
0005432639266	2252	42	18C
0005432639270	2252	43	18F
0005432866018	2252	44	19C
0005432639247	2252	45	20C
0005432866032	2252	46	20F
0005433811647	24297	1	4C
0005433811645	24297	2	6A
0005433811656	24297	3	7B
0005433811655	24297	4	9C
0005433811649	24297	5	11B
0005433811652	24297	6	17F
0005433811646	24297	7	17E
0005433811654	24297	8	18B
0005433811648	24297	9	18C
0005433811653	24297	10	20A
0005433811651	24297	11	22E
0005433811650	24297	12	23F
0005434191276	9741	1	4A
0005434191286	32767	1	1A
0005434191289	32767	2	1B
0005434191287	32767	3	2A
0005434191295	32767	4	2B
0005434191294	32767	5	3A
0005434191296	32767	6	3B
0005434191293	32767	7	4A
0005434191285	32767	8	4B
0005434191291	32767	9	5A
0005434191288	32767	10	5B
0005434191290	32767	11	6A
0005434191292	32767	12	6B
0005432658579	26494	1	1F
0005432658589	26494	2	3D
0005432665278	26494	3	3C
0005432658584	26494	4	4A
0005432658601	26494	5	5D
0005432665272	26494	6	6A
0005432658587	26494	7	6C
0005432665264	26494	8	7D
0005432658572	26494	9	8D
0005432661900	26494	10	9B
0005432661922	26494	11	9E
0005432658578	26494	12	9F
0005432665270	26494	13	10E
0005432665263	26494	14	11C
0005432665262	26494	15	11E
0005432661911	26494	16	13E
0005432661914	26494	17	13D
0005432658583	26494	18	14C
0005432665274	26494	19	14A
0005432658585	26494	20	14D
0005432658582	26494	21	14E
0005432665261	26494	22	15B
0005432658591	26494	23	15D
0005432665275	26494	24	16A
0005432665279	26494	25	16C
0005432661923	26494	26	16B
0005432665271	26494	27	17B
0005432661919	26494	28	17C
0005432661924	26494	29	17E
0005432658590	26494	30	18C
0005432661918	26494	31	18D
0005432658586	26494	32	19C
0005432658592	26494	33	19B
0005432665269	26494	34	19D
0005432661915	26494	35	20B
0005432658600	26494	36	20D
0005432665273	26494	37	21D
0005432658588	26494	38	21B
0005434504575	6508	1	3C
0005434504556	6508	2	3D
0005434504581	6508	3	3F
0005434504572	6508	4	5C
0005434504573	6508	5	5D
0005434504548	6508	6	6E
0005434504562	6508	7	6F
0005435104013	6508	8	7C
0005434504563	6508	9	8A
0005434504568	6508	10	8C
0005435104011	6508	11	8D
0005434504549	6508	12	8E
0005434504569	6508	13	9A
0005434504560	6508	14	9C
0005435104012	6508	15	9F
0005434504578	6508	16	11D
0005434504567	6508	17	12F
0005434504553	6508	18	13A
0005434504555	6508	19	13C
0005435104010	6508	20	14A
0005434504576	6508	21	14C
0005434504554	6508	22	14E
0005434504558	6508	23	14F
0005434504574	6508	24	15C
0005434504550	6508	25	15E
0005434504579	6508	26	16A
0005434504566	6508	27	16E
0005434504565	6508	28	17A
0005434504552	6508	29	17C
0005434504580	6508	30	17E
0005434504557	6508	31	17F
0005434504547	6508	32	18A
0005434504577	6508	33	18C
0005434504546	6508	34	18D
0005434504551	6508	35	18E
0005434504561	6508	36	19E
0005434504559	6508	37	20A
0005434504571	6508	38	20C
0005434504564	6508	39	20E
0005434504570	6508	40	20F
0005434504144	22664	1	1A
0005434503989	22664	2	1C
0005434504184	22664	3	1D
0005434504045	22664	4	1F
0005434504154	22664	5	2A
0005434504125	22664	6	2D
0005434504170	22664	7	3C
0005434504015	22664	8	3D
0005434504160	22664	9	4A
0005435103908	22664	10	4D
0005435103919	22664	11	5C
0005434504180	22664	12	5D
0005434503993	22664	13	5E
0005434504218	22664	14	6C
0005435103928	22664	15	6E
0005434504171	22664	16	7A
0005434504075	22664	17	7C
0005434504106	22664	18	7E
0005434504150	22664	19	8A
0005435103925	22664	20	8C
0005434504179	22664	21	8D
0005434504162	22664	22	8E
0005434504069	22664	23	8F
0005434504063	22664	24	9D
0005434504220	22664	25	9E
0005434504087	22664	26	9F
0005434504151	22664	27	10A
0005434504023	22664	28	10C
0005434504173	22664	29	10D
0005434504105	22664	30	10E
0005434504104	22664	31	10F
0005434504123	22664	32	11A
0005434504183	22664	33	11D
0005434504153	22664	34	12C
0005435103923	22664	35	12F
0005435103909	22664	36	13A
0005434504190	22664	37	13E
0005434504145	22664	38	13F
0005434504083	22664	39	14D
0005434504178	22664	40	14E
0005434504161	22664	41	14F
0005434503994	22664	42	15A
0005434504208	22664	43	15C
0005434504115	22664	44	15F
0005435103913	22664	45	16A
0005434504047	22664	46	16D
0005434504223	22664	47	16E
0005434504064	22664	48	16F
0005434504082	22664	49	17A
0005434504207	22664	50	17D
0005434504116	22664	51	17E
0005434504124	22664	52	18A
0005434504152	22664	53	18C
0005435103914	22664	54	19A
0005434504048	22664	55	19F
0005434504014	22664	56	20A
0005434504216	22664	57	20C
0005434504086	22664	58	20F
0005435653500	1678	1	1A
0005435653515	1678	2	1C
0005435653539	1678	3	1D
0005435653554	1678	4	1F
0005433367940	1678	5	2A
0005433367913	1678	6	2C
0005433368095	1678	7	2D
0005435653545	1678	8	2F
0005433367949	1678	9	3A
0005435653520	1678	10	3C
0005435653524	1678	11	3D
0005433367938	1678	12	3F
0005433367833	1678	13	4A
0005435653546	1678	14	4C
0005433367947	1678	15	4D
0005435653529	1678	16	4E
0005433367836	1678	17	4F
0005433367951	1678	18	5A
0005435653542	1678	19	5C
0005435653533	1678	20	5D
0005435653502	1678	21	5E
0005435653519	1678	22	5F
0005433368010	1678	23	6A
0005435653525	1678	24	6C
0005433367950	1678	25	6D
0005435653498	1678	26	6E
0005433368157	1678	27	6F
0005433367764	1678	28	7A
0005435653507	1678	29	7C
0005433368011	1678	30	7D
0005435653527	1678	31	7E
0005433367920	1678	32	7F
0005435653509	1678	33	8C
0005433367985	1678	34	8D
0005433367984	1678	35	8E
0005435653532	1678	36	8F
0005435653511	1678	37	9A
0005435653513	1678	38	9C
0005433368216	1678	39	9D
0005435653544	1678	40	9E
0005433367725	1678	41	9F
0005435653517	1678	42	10A
0005435653503	1678	43	10C
0005435653505	1678	44	10D
0005435653548	1678	45	10E
0005435653508	1678	46	10F
0005435653516	1678	47	11A
0005433368007	1678	48	11C
0005435653501	1678	49	11D
0005435653535	1678	50	11E
0005435653526	1678	51	11F
0005435653528	1678	52	12A
0005435653530	1678	53	12C
0005435653536	1678	54	12D
0005435653499	1678	55	12E
0005435653506	1678	56	12F
0005435653550	1678	57	13A
0005435653547	1678	58	13C
0005435653521	1678	59	13D
0005435653543	1678	60	13E
0005435653510	1678	61	13F
0005435653504	1678	62	14A
0005435653556	1678	63	14C
0005433368036	1678	64	14D
0005435653551	1678	65	14E
0005433367840	1678	66	14F
0005433368068	1678	67	15A
0005433368081	1678	68	15C
0005433367945	1678	69	15D
0005435653553	1678	70	15E
0005435653518	1678	71	15F
0005433367986	1678	72	16A
0005433368077	1678	73	16C
0005433368094	1678	74	16D
0005435653531	1678	75	16E
0005435653523	1678	76	16F
0005433368128	1678	77	17C
0005435653540	1678	78	17D
0005435653541	1678	79	17E
0005433368057	1678	80	17F
0005435653514	1678	81	18A
0005435653555	1678	82	18C
0005433368115	1678	83	18D
0005433368012	1678	84	18E
0005435653538	1678	85	18F
0005435653552	1678	86	19A
0005435653549	1678	87	19C
0005435653512	1678	88	19D
0005433367921	1678	89	19E
0005435653537	1678	90	19F
0005433367894	1678	91	20A
0005435653534	1678	92	20C
0005433368158	1678	93	20D
0005435653522	1678	94	20E
0005435653497	1678	95	20F
0005433368275	21715	1	1C
0005435653044	21715	2	1D
0005435653090	21715	3	1F
0005433368283	21715	4	2C
0005435652999	21715	5	2D
0005435653156	21715	6	2F
0005433368292	21715	7	3A
0005435653011	21715	8	3D
0005433368265	21715	9	3F
0005435652996	21715	10	4A
0005435652947	21715	11	4C
0005433368285	21715	12	4D
0005433368273	21715	13	4E
0005433368269	21715	14	4F
0005435652997	21715	15	5A
0005433368264	21715	16	5C
0005433368266	21715	17	5D
0005433368290	21715	18	5E
0005435652956	21715	19	5F
0005435652994	21715	20	6A
0005433368282	21715	21	6C
0005433368287	21715	22	6D
0005435653008	21715	23	6E
0005435652936	21715	24	6F
0005435653019	21715	25	7C
0005433368270	21715	26	7D
0005435652887	21715	27	7E
0005433368291	21715	28	7F
0005435652935	21715	29	8A
0005433368267	21715	30	8C
0005433368284	21715	31	8D
0005433368257	21715	32	8E
0005435652965	21715	33	8F
0005433368259	21715	34	9A
0005435653071	21715	35	9C
0005435653104	21715	36	9D
0005433368293	21715	37	9E
0005435653085	21715	38	9F
0005435653117	21715	39	10A
0005433368281	21715	40	10C
0005435653109	21715	41	10D
0005433368263	21715	42	10E
0005435652886	21715	43	10F
0005433368258	21715	44	11A
0005435653105	21715	45	11C
0005433368268	21715	46	11D
0005435653072	21715	47	11E
0005435652998	21715	48	11F
0005435653141	21715	49	12A
0005435653076	21715	50	12C
0005435653064	21715	51	12E
0005435653080	21715	52	12D
0005435653077	21715	53	12F
0005435653098	21715	54	13C
0005435653118	21715	55	13D
0005435653110	21715	56	13E
0005433368278	21715	57	13F
0005435653099	21715	58	14A
0005433368271	21715	59	14C
0005435653010	21715	60	14D
0005433368272	21715	61	14F
0005435653101	21715	62	15A
0005435652957	21715	63	15C
0005433368277	21715	64	15D
0005435653164	21715	65	15E
0005435653063	21715	66	15F
0005433368274	21715	67	16A
0005435653073	21715	68	16C
0005435653018	21715	69	16D
0005433368262	21715	70	16E
0005435653020	21715	71	16F
0005435653162	21715	72	17C
0005435652888	21715	73	17D
0005433368288	21715	74	17E
0005433368286	21715	75	17F
0005433368255	21715	76	18A
0005433368276	21715	77	18C
0005435653089	21715	78	18D
0005433368261	21715	79	18E
0005433368280	21715	80	18F
0005433368289	21715	81	19A
0005435653097	21715	82	19C
0005433368256	21715	83	19E
0005435653021	21715	84	19F
0005433368260	21715	85	20A
0005435653000	21715	86	20C
0005435653075	21715	87	20D
0005433368279	21715	88	20E
0005434466458	23237	1	2B
0005434466476	23237	2	2D
0005435312831	23237	3	3D
0005434466466	23237	4	4A
0005435312828	23237	5	4C
0005435312833	23237	6	5B
0005435312832	23237	7	5D
0005434466459	23237	8	6A
0005434466467	23237	9	6C
0005434466460	23237	10	7C
0005435312829	23237	11	7D
0005434466484	23237	12	18D
0005434466437	23237	13	19A
0005434466468	23237	14	19D
0005434466498	23237	15	20C
0005434466469	23237	16	21D
0005435312830	23237	17	22D
0005433986454	4151	1	1D
0005433986435	4151	2	2C
0005433986408	4151	3	2F
0005433986434	4151	4	3A
0005433986452	4151	5	3C
0005433986436	4151	6	3D
0005433986410	4151	7	4C
0005433986457	4151	8	4D
0005433986430	4151	9	4E
0005433986423	4151	10	5A
0005433986427	4151	11	5C
0005433986422	4151	12	5D
0005433986419	4151	13	5E
0005433986429	4151	14	5F
0005433986453	4151	15	6C
0005433986409	4151	16	6D
0005433986446	4151	17	6F
0005433986448	4151	18	7D
0005433986416	4151	19	7E
0005433986431	4151	20	8A
0005433986441	4151	21	8E
0005433986440	4151	22	9A
0005433986420	4151	23	9D
0005433986450	4151	24	10A
0005433986451	4151	25	10C
0005433986449	4151	26	10D
0005433986413	4151	27	10E
0005433986445	4151	28	11A
0005433986414	4151	29	11C
0005433986433	4151	30	11E
0005433986439	4151	31	12C
0005433986412	4151	32	12E
0005433986421	4151	33	12F
0005433986415	4151	34	13A
0005433986411	4151	35	13C
0005433986425	4151	36	13E
0005433986407	4151	37	14A
0005435788798	4151	38	14C
0005433986426	4151	39	14E
0005433986417	4151	40	15A
0005433986432	4151	41	15E
0005433986438	4151	42	16C
0005433986406	4151	43	16F
0005433986442	4151	44	17E
0005433986428	4151	45	18A
0005433986458	4151	46	18D
0005435788797	4151	47	18E
0005433986456	4151	48	19A
0005433986418	4151	49	19D
0005433986424	4151	50	19E
0005433986444	4151	51	19F
0005433986437	4151	52	20A
0005433986443	4151	53	20C
0005433986447	4151	54	20D
0005433986455	4151	55	20F
0005435788771	25670	1	1A
0005433985995	25670	2	2A
0005433985988	25670	3	2C
0005433985946	25670	4	2F
0005433986060	25670	5	3C
0005435788773	25670	6	3D
0005433985774	25670	7	3F
0005433985918	25670	8	4A
0005433985831	25670	9	4C
0005433986047	25670	10	4E
0005433986004	25670	11	5A
0005433985891	25670	12	5C
0005433986059	25670	13	5E
0005433986092	25670	14	5F
0005433985968	25670	15	6C
0005433986033	25670	16	6F
0005433985954	25670	17	7A
0005433986052	25670	18	7F
0005433986048	25670	19	8C
0005433986024	25670	20	8D
0005433986078	25670	21	8E
0005433985901	25670	22	8F
0005433985993	25670	23	9A
0005433986076	25670	24	9D
0005433985775	25670	25	9F
0005433986063	25670	26	10A
0005433985843	25670	27	10C
0005433986079	25670	28	10D
0005433985962	25670	29	10E
0005433986119	25670	30	10F
0005433985766	25670	31	11A
0005433986023	25670	32	11C
0005433986014	25670	33	11E
0005433986044	25670	34	11F
0005433985749	25670	35	12A
0005433985868	25670	36	12C
0005433985976	25670	37	12D
0005435788774	25670	38	12E
0005433985902	25670	39	13A
0005433985887	25670	40	14D
0005433986031	25670	41	14E
0005433985859	25670	42	14F
0005433985847	25670	43	15A
0005433986037	25670	44	15C
0005433985951	25670	45	15E
0005433985977	25670	46	15F
0005433985950	25670	47	16C
0005433986007	25670	48	16D
0005435788770	25670	49	16E
0005433985869	25670	50	16F
0005433985945	25670	51	17A
0005433986067	25670	52	17C
0005433986012	25670	53	17D
0005433985973	25670	54	17F
0005435788772	25670	55	18C
0005433986006	25670	56	18D
0005433986009	25670	57	18F
0005433986118	25670	58	19A
0005433986013	25670	59	19E
0005433985758	25670	60	19F
0005433985992	25670	61	20A
0005433986008	25670	62	20D
0005433986005	25670	63	20E
0005434509229	1613	1	1B
0005433168363	1613	2	1C
0005434509233	1613	3	1D
0005434509222	1613	4	2A
0005433168374	1613	5	2C
0005434509225	1613	6	2D
0005433168373	1613	7	3A
0005434509221	1613	8	3B
0005433168367	1613	9	3D
0005433168356	1613	10	4A
0005433168375	1613	11	4C
0005434509219	1613	12	5B
0005434509224	1613	13	5C
0005433168376	1613	14	5D
0005434509226	1613	15	6A
0005433168378	1613	16	6B
0005434509220	1613	17	6C
0005434509231	1613	18	7B
0005433168360	1613	19	7D
0005434509228	1613	20	18A
0005433168377	1613	21	18B
0005433168357	1613	22	18C
0005433168364	1613	23	19A
0005434509218	1613	24	19C
0005433168361	1613	25	19D
0005434509230	1613	26	20A
0005433168358	1613	27	20B
0005434509232	1613	28	20D
0005434509234	1613	29	21B
0005434509223	1613	30	22A
0005433168362	1613	31	22B
0005433168372	1613	32	22C
0005433168369	1613	33	22D
0005433168368	1613	34	23A
0005434509227	1613	35	23B
0005434190400	9027	1	1B
0005434516100	9027	2	2D
0005434190401	9027	3	3C
0005434516097	9027	4	3D
0005434190403	9027	5	4B
0005434190402	9027	6	6B
0005434516098	9027	7	18D
0005434516099	9027	8	19A
0005434516101	9027	9	21A
0005434516102	9027	10	21C
0005434190405	9027	11	21D
0005432661917	17833	1	1A
0005432658606	17833	2	1F
0005432869600	17833	3	2C
0005432655559	17833	4	3A
0005432655556	17833	5	4A
0005432655537	17833	6	4D
0005432658607	17833	7	4E
0005432655535	17833	8	4F
0005432666395	17833	9	5D
0005434151736	17833	10	5E
0005432655570	17833	11	5F
0005432659709	17833	12	6C
0005432665276	17833	13	7A
0005432658608	17833	14	7C
0005432663038	17833	15	7F
0005432657460	17833	16	8D
0005432655558	17833	17	9C
0005432659710	17833	18	9D
0005432655536	17833	19	10A
0005432657461	17833	20	10D
0005432655526	17833	21	10F
0005432655523	17833	22	11A
0005432655534	17833	23	11C
0005432869597	17833	24	11F
0005432661916	17833	25	12C
0005432655557	17833	26	12A
0005432660819	17833	27	12D
0005434151735	17833	28	13A
0005432869598	17833	29	13C
0005432661913	17833	30	13E
0005432663037	17833	31	14A
0005432869599	17833	32	14C
0005432869594	17833	33	15A
0005432665268	17833	34	15D
0005432655538	17833	35	15E
0005432869596	17833	36	16C
0005432869595	17833	37	16D
0005432659715	17833	38	17E
0005434151737	17833	39	18A
0005432657456	17833	40	18D
0005432655546	17833	41	20A
0005432655569	17833	42	20C
0005432667458	17833	43	20D
0005432655643	26302	1	1D
0005432655633	26302	2	2A
0005432666409	26302	3	2D
0005432655639	26302	4	2F
0005432667473	26302	5	3D
0005432869501	26302	6	3F
0005432869524	26302	7	4A
0005432655636	26302	8	4C
0005432655640	26302	9	4D
0005432869487	26302	10	4F
0005434151718	26302	11	5E
0005432655637	26302	12	5F
0005432869523	26302	13	6D
0005432659725	26302	14	6F
0005432655635	26302	15	7A
0005432869502	26302	16	7C
0005432869494	26302	17	8E
0005432657478	26302	18	10E
0005432655632	26302	19	11C
0005432655638	26302	20	11D
0005432658609	26302	21	11F
0005432657477	26302	22	12A
0005432660838	26302	23	12D
0005432665294	26302	24	12F
0005434151712	26302	25	13A
0005432658611	26302	26	13D
0005432658610	26302	27	14D
0005432655634	26302	28	14E
0005434151713	26302	29	14F
0005432657476	26302	30	15C
0005434151698	26302	31	15D
0005434151711	26302	32	15E
0005432666408	26302	33	16C
0005432665293	26302	34	16D
0005432869530	26302	35	16F
0005432660837	26302	36	17A
0005432869514	26302	37	17E
0005432655641	26302	38	18C
0005432655642	26302	39	19F
0005432869515	26302	40	20A
0005432639138	25074	1	1D
0005432639176	25074	2	1F
0005432639079	25074	3	2D
0005432639167	25074	4	2F
0005432866091	25074	5	4E
0005432639161	25074	6	4F
0005432639102	25074	7	5A
0005432639118	25074	8	5C
0005432866082	25074	9	6C
0005432639146	25074	10	6D
0005432639136	25074	11	6E
0005432866083	25074	12	6F
0005432639097	25074	13	7A
0005432866089	25074	14	7D
0005432639164	25074	15	7F
0005432639139	25074	16	8D
0005432866087	25074	17	8E
0005432639124	25074	18	9C
0005432639166	25074	19	9E
0005432866090	25074	20	9F
0005432639135	25074	21	10A
0005432639137	25074	22	10C
0005432866081	25074	23	11E
0005432639080	25074	24	12F
0005432639134	25074	25	14C
0005432639203	25074	26	14E
0005432639122	25074	27	14F
0005432866088	25074	28	15A
0005432639119	25074	29	15D
0005432639163	25074	30	15E
0005432639121	25074	31	16E
0005432866092	25074	32	17C
0005432866093	25074	33	17D
0005432639133	25074	34	18E
0005432639120	25074	35	18F
0005432639175	25074	36	19A
0005432866084	25074	37	19E
0005432866085	25074	38	19F
0005432639165	25074	39	20E
0005432866086	25074	40	20F
0005432329179	3121	1	1A
0005432329187	3121	2	2A
0005432329184	3121	3	2C
0005432329189	3121	4	2D
0005432287240	3121	5	2F
0005432287243	3121	6	3A
0005432329168	3121	7	3D
0005432329170	3121	8	3F
0005432329178	3121	9	4A
0005432329190	3121	10	4D
0005432329164	3121	11	4E
0005432287242	3121	12	4F
0005432905176	3121	13	5A
0005432329166	3121	14	5E
0005432329181	3121	15	6A
0005432329171	3121	16	6C
0005432287244	3121	17	6D
0005432329180	3121	18	6E
0005433438955	3121	19	7A
0005433438958	3121	20	7C
0005432287241	3121	21	7D
0005432329200	3121	22	7E
0005433438961	3121	23	8A
0005432329194	3121	24	8C
0005432329192	3121	25	8F
0005432329174	3121	26	9A
0005432329191	3121	27	9D
0005432905145	3121	28	9E
0005432905144	3121	29	9F
0005433438957	3121	30	10A
0005432329159	3121	31	10C
0005432905151	3121	32	11A
0005432329173	3121	33	11C
0005432329172	3121	34	11D
0005432329186	3121	35	11E
0005432329177	3121	36	11F
0005432329167	3121	37	12D
0005432329161	3121	38	12E
0005432329193	3121	39	12F
0005432329204	3121	40	13A
0005432329203	3121	41	13C
0005433438959	3121	42	13E
0005432905143	3121	43	14A
0005432329198	3121	44	14D
0005432329205	3121	45	15A
0005432329162	3121	46	15C
0005432329197	3121	47	15E
0005432329195	3121	48	16C
0005432329176	3121	49	17C
0005432329160	3121	50	17D
0005432329169	3121	51	17E
0005432329196	3121	52	18A
0005432329183	3121	53	18D
0005432329175	3121	54	18C
0005432329201	3121	55	18E
0005432329199	3121	56	18F
0005433438960	3121	57	19A
0005432329165	3121	58	19C
0005432329185	3121	59	19E
0005433438956	3121	60	19F
0005432329182	3121	61	20D
0005432329188	3121	62	20C
0005432329163	3121	63	20E
0005432329202	3121	64	20F
0005432905186	31119	1	1C
0005432328952	31119	2	1D
0005432054334	31119	3	1F
0005432328845	31119	4	2A
0005432328830	31119	5	2D
0005432054335	31119	6	2F
0005433438883	31119	7	3A
0005432328699	31119	8	3C
0005432328819	31119	9	3D
0005432905187	31119	10	4A
0005432905188	31119	11	4C
0005433438857	31119	12	4D
0005432905184	31119	13	4E
0005432328794	31119	14	4F
0005432328917	31119	15	5A
0005432328906	31119	16	5D
0005432328604	31119	17	6A
0005432328698	31119	18	6C
0005433438882	31119	19	6E
0005432328838	31119	20	6F
0005432328722	31119	21	7A
0005432328554	31119	22	7C
0005432328817	31119	23	7D
0005432328777	31119	24	7E
0005432328805	31119	25	8A
0005433438881	31119	26	8C
0005433438878	31119	27	8D
0005432328804	31119	28	8F
0005432328965	31119	29	9C
0005432905185	31119	30	9D
0005432328968	31119	31	10A
0005432328966	31119	32	10C
0005432328829	31119	33	10D
0005432905189	31119	34	10E
0005432328798	31119	35	10F
0005433438890	31119	36	11A
0005432328818	31119	37	11D
0005432328843	31119	38	11E
0005432905190	31119	39	11F
0005433438885	31119	40	12A
0005432328607	31119	41	12C
0005432328757	31119	42	12D
0005432328744	31119	43	12E
0005432328750	31119	44	12F
0005432328776	31119	45	13A
0005432328662	31119	46	13C
0005432328874	31119	47	13D
0005432328706	31119	48	13F
0005432328696	31119	49	14C
0005432328768	31119	50	14D
0005432328712	31119	51	14F
0005433438853	31119	52	15C
0005433438884	31119	53	15E
0005433438889	31119	54	16A
0005432328553	31119	55	16C
0005432328967	31119	56	16E
0005432328709	31119	57	17C
0005432328841	31119	58	17D
0005432328689	31119	59	17E
0005432328640	31119	60	18A
0005433438856	31119	61	18C
0005432328610	31119	62	18D
0005432328734	31119	63	18E
0005432328721	31119	64	18F
0005432328756	31119	65	19C
0005432328842	31119	66	19D
0005432328606	31119	67	20A
0005433438852	31119	68	20C
0005432328697	31119	69	20D
0005433438850	31119	70	20E
0005433438876	31119	71	20F
0005434309881	6207	1	1A
0005434309883	6207	2	1D
0005435487865	6207	3	2A
0005435487910	6207	4	1F
0005434309880	6207	5	2D
0005435487862	6207	6	2C
0005435487832	6207	7	2F
0005435487924	6207	8	3F
0005435487869	6207	9	4B
0005435487813	6207	10	4D
0005435487828	6207	11	4C
0005435487830	6207	12	5A
0005434309879	6207	13	5C
0005432146220	6207	14	6C
0005435487889	6207	15	7B
0005434309887	6207	16	7C
0005435487785	6207	17	8E
0005435297056	6207	18	8F
0005435487814	6207	19	9C
0005435999426	6207	20	9E
0005435487791	6207	21	9F
0005434309882	6207	22	10C
0005435999432	6207	23	10B
0005434309889	6207	24	10E
0005435487731	6207	25	10D
0005435999429	6207	26	11A
0005434309886	6207	27	12A
0005435487861	6207	28	12C
0005435999431	6207	29	13A
0005435487863	6207	30	13C
0005435487860	6207	31	13B
0005434309890	6207	32	13D
0005435487870	6207	33	13F
0005432146219	6207	34	14A
0005435999424	6207	35	14E
0005435999433	6207	36	15A
0005435487911	6207	37	15C
0005435999425	6207	38	15D
0005435487834	6207	39	15F
0005435297072	6207	40	16B
0005435297090	6207	41	17B
0005435487798	6207	42	17A
0005435999430	6207	43	17D
0005435487784	6207	44	19A
0005435999427	6207	45	19D
0005434309888	6207	46	19F
0005435297060	6207	47	20B
0005435999428	6207	48	20D
0005435487845	6207	49	20E
0005434309884	6207	50	21A
0005434309885	6207	51	20F
0005435487823	6207	52	21B
0005435487923	6207	53	21C
0005435487904	6207	54	21E
0005434309878	6207	55	22A
0005435999434	6207	56	21F
0005435999435	6207	57	22B
0005434309891	6207	58	22F
0005435487831	6207	59	23F
0005435487797	6207	60	23E
0005435297132	19537	1	1A
0005434309766	19537	2	1F
0005435297133	19537	3	2C
0005435999241	19537	4	2A
0005435999217	19537	5	2D
0005435488034	19537	6	2F
0005434309745	19537	7	3C
0005435999193	19537	8	3A
0005435999216	19537	9	3F
0005435999259	19537	10	4F
0005434309818	19537	11	5D
0005434309739	19537	12	6C
0005435999213	19537	13	6D
0005435999226	19537	14	6E
0005434309744	19537	15	6F
0005434309746	19537	16	7D
0005434309738	19537	17	8A
0005435999260	19537	18	9C
0005435488042	19537	19	9B
0005435488051	19537	20	9E
0005435999253	19537	21	10C
0005434309772	19537	22	10B
0005434309778	19537	23	10D
0005434309771	19537	24	10E
0005435488050	19537	25	11B
0005435297134	19537	26	11E
0005435999257	19537	27	11D
0005435999197	19537	28	12A
0005434309764	19537	29	12C
0005435488043	19537	30	12E
0005434309752	19537	31	13A
0005435488033	19537	32	12F
0005435297129	19537	33	13D
0005434309793	19537	34	13E
0005435488049	19537	35	13F
0005434309777	19537	36	14C
0005435999246	19537	37	14D
0005435488048	19537	38	15C
0005435999240	19537	39	15E
0005434309716	19537	40	16A
0005435488038	19537	41	15F
0005434309715	19537	42	16C
0005435488040	19537	43	16E
0005435488039	19537	44	17C
0005435488035	19537	45	17B
0005434309857	19537	46	17F
0005435999261	19537	47	17E
0005435488041	19537	48	18B
0005435488044	19537	49	18F
0005434309720	19537	50	19C
0005435297127	19537	51	19F
0005435297131	19537	52	19E
0005435488047	19537	53	20B
0005435488045	19537	54	20A
0005435488036	19537	55	20E
0005435488037	19537	56	20D
0005434309736	19537	57	21A
0005435999214	19537	58	21C
0005435297128	19537	59	21B
0005435999235	19537	60	21D
0005434309721	19537	61	22A
0005434309734	19537	62	21F
0005434309783	19537	63	22B
0005435999176	19537	64	22D
0005435999215	19537	65	22E
0005435297130	19537	66	23B
0005435999258	19537	67	23A
0005435488032	19537	68	23C
0005435488046	19537	69	23D
0005433186148	1596	1	1A
0005435518112	1596	2	1D
0005434566060	1596	3	2A
0005435502530	1596	4	2D
0005435502547	1596	5	2F
0005435518111	1596	6	3A
0005435508480	1596	7	3C
0005435518114	1596	8	3D
0005435518097	1596	9	4A
0005432291956	1596	10	4C
0005434566054	1596	11	4E
0005434566062	1596	12	4F
0005433186125	1596	13	5A
0005432291954	1596	14	5C
0005435518104	1596	15	5D
0005435518107	1596	16	5E
0005435508475	1596	17	5F
0005435508478	1596	18	6A
0005435502531	1596	19	6C
0005434566056	1596	20	6F
0005435502534	1596	21	7A
0005435502535	1596	22	7C
0005435508477	1596	23	7D
0005435502541	1596	24	7E
0005433186132	1596	25	7F
0005435518106	1596	26	8A
0005435508474	1596	27	8C
0005435518098	1596	28	8D
0005435508479	1596	29	8E
0005433186103	1596	30	8F
0005435502544	1596	31	9A
0005435502552	1596	32	9C
0005435502532	1596	33	9D
0005435502539	1596	34	9E
0005433186135	1596	35	9F
0005435518101	1596	36	10A
0005435508482	1596	37	10C
0005435502550	1596	38	10D
0005435508473	1596	39	10E
0005435508483	1596	40	10F
0005432291955	1596	41	11A
0005433186157	1596	42	11C
0005435518102	1596	43	11D
0005433186131	1596	44	11F
0005434566055	1596	45	12A
0005435502533	1596	46	12C
0005435518096	1596	47	12D
0005433186122	1596	48	12E
0005435518099	1596	49	12F
0005433186123	1596	50	13A
0005435508476	1596	51	13C
0005435502548	1596	52	13D
0005435518110	1596	53	13E
0005435502543	1596	54	13F
0005435518103	1596	55	14A
0005434566059	1596	56	14C
0005433186133	1596	57	14D
0005435502542	1596	58	14F
0005435518094	1596	59	15A
0005435508481	1596	60	15D
0005435502540	1596	61	15E
0005433186134	1596	62	15F
0005435518108	1596	63	16C
0005435502546	1596	64	16D
0005435502545	1596	65	16E
0005435518105	1596	66	16F
0005435518109	1596	67	17A
0005434566061	1596	68	17D
0005434566050	1596	69	17F
0005435518100	1596	70	18C
0005435502551	1596	71	18D
0005435502536	1596	72	18E
0005435502537	1596	73	18F
0005434566052	1596	74	19C
0005435502549	1596	75	19D
0005435518113	1596	76	19F
0005435502538	1596	77	19E
0005434566057	1596	78	20A
0005435518095	1596	79	20C
0005434566051	1596	80	20D
0005434566058	1596	81	20E
0005434566053	1596	82	20F
0005435545736	20869	1	1A
0005433186205	20869	2	1C
0005435529214	20869	3	1D
0005434565922	20869	4	1F
0005435502331	20869	5	2A
0005433186208	20869	6	2D
0005434565902	20869	7	3A
0005433186207	20869	8	2F
0005435502278	20869	9	3C
0005434565920	20869	10	3D
0005435529155	20869	11	3F
0005435502404	20869	12	4A
0005434565935	20869	13	4C
0005435529325	20869	14	4D
0005434565886	20869	15	4E
0005434565941	20869	16	4F
0005435502386	20869	17	5D
0005435545728	20869	18	5E
0005435502302	20869	19	6A
0005434565919	20869	20	6C
0005435502275	20869	21	6D
0005435529162	20869	22	6E
0005435529247	20869	23	6F
0005434565934	20869	24	7A
0005435529163	20869	25	7C
0005434565940	20869	26	7E
0005434565982	20869	27	7F
0005435502358	20869	28	8A
0005434565980	20869	29	8C
0005435502326	20869	30	8D
0005435529316	20869	31	8E
0005433186210	20869	32	8F
0005433186206	20869	33	9A
0005435529324	20869	34	9C
0005434565981	20869	35	9D
0005435502305	20869	36	9E
0005435529323	20869	37	9F
0005435502332	20869	38	10A
0005433186204	20869	39	10C
0005433186212	20869	40	10D
0005434565953	20869	41	10E
0005435529258	20869	42	10F
0005433186209	20869	43	11A
0005435502329	20869	44	11C
0005435502403	20869	45	11D
0005435502301	20869	46	11E
0005435529315	20869	47	11F
0005434565885	20869	48	12A
0005435502357	20869	49	12C
0005435545729	20869	50	12D
0005435529156	20869	51	12E
0005435529224	20869	52	12F
0005435529259	20869	53	13A
0005435545730	20869	54	13D
0005434565954	20869	55	13E
0005434565939	20869	56	13F
0005435529271	20869	57	14C
0005435502310	20869	58	14E
0005435529286	20869	59	14F
0005434565906	20869	60	15A
0005435545734	20869	61	15D
0005435502363	20869	62	15F
0005435529213	20869	63	16C
0005434565888	20869	64	16F
0005435545737	20869	65	17A
0005435529211	20869	66	17C
0005435529222	20869	67	17D
0005435502276	20869	68	17F
0005435502359	20869	69	18C
0005435529223	20869	70	18D
0005434565997	20869	71	18E
0005435502309	20869	72	18F
0005434565901	20869	73	19A
0005433186211	20869	74	19C
0005435502390	20869	75	19D
0005434565937	20869	76	19E
0005435502389	20869	77	19F
0005435529281	20869	78	20A
0005435502330	20869	79	20C
0005435502269	20869	80	20D
0005434565890	20869	81	20E
0005435931623	3910	1	1C
0005435153813	3910	2	3A
0005435153810	3910	3	3B
0005435931594	3910	4	5D
0005435153812	3910	5	6A
0005435153809	3910	6	6D
0005435931593	3910	7	18A
0005435153815	3910	8	18B
0005435153811	3910	9	18D
0005435931609	3910	10	19C
0005435153808	3910	11	21B
0005435153814	3910	12	21D
0005435931622	3910	13	22A
0005435931640	21875	1	1D
0005435153764	21875	2	2A
0005435153751	21875	3	3D
0005435153766	21875	4	4A
0005435153750	21875	5	5C
0005435931639	21875	6	6C
0005435153780	21875	7	18D
0005435153779	21875	8	19C
0005435931642	21875	9	20A
0005435931641	21875	10	21D
0005435931643	21875	11	23A
0005432629004	7173	1	1B
0005435225598	7173	2	1C
0005432629003	7173	3	1D
0005435225566	7173	4	2A
0005432628994	7173	5	2B
0005435225576	7173	6	3A
0005432628996	7173	7	3B
0005432629007	7173	8	4A
0005435225578	7173	9	4D
0005435225597	7173	10	5A
0005432629006	7173	11	5C
0005432629008	7173	12	6A
0005432629005	7173	13	6B
0005435225565	7173	14	6C
0005435225564	7173	15	7C
0005432629001	7173	16	7D
0005432629009	7173	17	18A
0005435225609	7173	18	18B
0005432629000	7173	19	18C
0005435225618	7173	20	19A
0005432628995	7173	21	19D
0005435225617	7173	22	20B
0005435225585	7173	23	20D
0005432628998	7173	24	22B
0005432628999	7173	25	22D
0005432628997	7173	26	23A
0005432629002	7173	27	23B
0005432628855	28142	1	1A
0005435225671	28142	2	1C
0005435225666	28142	3	1D
0005432628925	28142	4	2A
0005432628867	28142	5	2D
0005435225667	28142	6	4B
0005432628905	28142	7	4C
0005432628947	28142	8	5B
0005435225670	28142	9	5D
0005432628872	28142	10	7D
0005435225665	28142	11	18A
0005432628888	28142	12	18B
0005432628871	28142	13	19A
0005432628913	28142	14	19B
0005432628824	28142	15	19C
0005435225669	28142	16	20A
0005432628868	28142	17	20B
0005432628946	28142	18	20C
0005435225668	28142	19	20D
0005432628922	28142	20	21A
0005432628963	28142	21	21C
0005435225673	28142	22	22A
0005435225672	28142	23	22C
0005432628854	28142	24	22D
0005432628860	28142	25	23B
0005435960089	8770	1	2B
0005435960092	8770	2	2D
0005435960091	8770	3	3D
0005434267966	8770	4	4B
0005435960090	8770	5	7C
0005435960065	15260	1	2B
0005434267989	15260	2	2D
0005434267988	15260	3	3D
0005434267990	15260	4	7D
0005432675295	1213	1	2F
0005432693378	1213	2	3C
0005432693372	1213	3	4A
0005432693350	1213	4	3F
0005432675296	1213	5	4C
0005432693359	1213	6	4D
0005432873309	1213	7	5C
0005432677612	1213	8	5F
0005432693365	1213	9	6B
0005432693363	1213	10	6F
0005432675298	1213	11	6D
0005432693361	1213	12	7E
0005432675286	1213	13	7F
0005432693377	1213	14	8B
0005432675292	1213	15	8C
0005432693362	1213	16	8F
0005432873322	1213	17	9B
0005432693360	1213	18	9F
0005432675291	1213	19	9E
0005432693375	1213	20	10A
0005432675289	1213	21	10C
0005432693358	1213	22	10D
0005432675293	1213	23	11F
0005432675297	1213	24	12B
0005432693371	1213	25	12A
0005432693349	1213	26	12C
0005432677611	1213	27	12E
0005432693354	1213	28	13A
0005432873319	1213	29	13C
0005432693366	1213	30	13B
0005432873320	1213	31	13D
0005432693356	1213	32	14A
0005432693348	1213	33	14E
0005432693374	1213	34	14D
0005432693355	1213	35	14C
0005432675284	1213	36	14F
0005432677610	1213	37	15B
0005432675288	1213	38	15F
0005432693373	1213	39	15E
0005432693351	1213	40	15D
0005432693357	1213	41	16A
0005432693368	1213	42	16B
0005432675283	1213	43	17B
0005432693369	1213	44	17D
0005432675285	1213	45	17C
0005432675287	1213	46	17F
0005432693370	1213	47	18A
0005432693353	1213	48	19B
0005432677609	1213	49	19E
0005432675290	1213	50	19D
0005432693367	1213	51	19F
0005432693352	1213	52	21A
0005432693376	1213	53	21C
0005432675294	1213	54	21B
0005432693364	1213	55	21D
0005432693097	17490	1	1C
0005432693077	17490	2	1A
0005432693062	17490	3	1D
0005432675208	17490	4	2A
0005432675131	17490	5	2F
0005432692936	17490	6	3D
0005432693086	17490	7	3F
0005432693022	17490	8	4C
0005432677572	17490	9	4D
0005432675133	17490	10	5D
0005432693090	17490	11	6C
0005432693160	17490	12	6D
0005432873364	17490	13	7B
0005432693149	17490	14	6F
0005432675197	17490	15	7E
0005432675136	17490	16	8C
0005432675159	17490	17	8B
0005432693091	17490	18	8D
0005432675156	17490	19	8F
0005432675209	17490	20	9A
0005432693159	17490	21	9F
0005432693099	17490	22	9D
0005432677569	17490	23	10C
0005432675168	17490	24	10E
0005432693078	17490	25	11A
0005432873366	17490	26	11D
0005432693148	17490	27	11C
0005432693092	17490	28	11F
0005432675181	17490	29	12B
0005432675196	17490	30	12C
0005432692985	17490	31	12E
0005432693080	17490	32	13A
0005432693163	17490	33	13C
0005432675122	17490	34	14B
0005432873369	17490	35	14D
0005432693081	17490	36	14C
0005432693066	17490	37	14F
0005432675067	17490	38	15B
0005432693098	17490	39	16B
0005432675188	17490	40	16D
0005432873368	17490	41	17A
0005432873363	17490	42	17D
0005432873367	17490	43	17E
0005432675154	17490	44	18C
0005432675179	17490	45	19E
0005432693085	17490	46	19F
0005432693072	17490	47	21D
0005432873365	17490	48	21E
0005432675132	17490	49	21F
0005434435342	1122	1	1A
0005434435338	1122	2	1B
0005433156769	1122	3	1C
0005433156759	1122	4	1D
0005434435350	1122	5	2A
0005433156786	1122	6	2D
0005434435344	1122	7	3A
0005434435347	1122	8	3B
0005434435343	1122	9	5D
0005434435336	1122	10	6D
0005433156785	1122	11	7A
0005433156768	1122	12	7B
0005434435348	1122	13	7D
0005434435337	1122	14	18B
0005433156774	1122	15	18C
0005434435339	1122	16	18D
0005434435346	1122	17	19A
0005434435349	1122	18	19B
0005433156801	1122	19	20B
0005434435341	1122	20	20A
0005434435335	1122	21	20C
0005434435345	1122	22	22A
0005433156758	1122	23	22C
0005433156776	1122	24	23A
0005434435340	1122	25	23B
0005433156842	17328	1	1B
0005434435167	17328	2	1D
0005434435157	17328	3	2B
0005434435156	17328	4	2C
0005434435197	17328	5	2D
0005434435236	17328	6	4A
0005434435237	17328	7	4B
0005434435235	17328	8	5A
0005434435215	17328	9	5C
0005433156843	17328	10	6A
0005433156839	17328	11	6B
0005434435241	17328	12	7A
0005433156841	17328	13	18B
0005434435144	17328	14	18C
0005434435240	17328	15	19A
0005434435151	17328	16	19B
0005434435210	17328	17	19C
0005434435266	17328	18	19D
0005434435230	17328	19	21A
0005433156840	17328	20	21B
0005434435298	17328	21	21C
0005434435143	17328	22	21D
0005433156837	17328	23	22B
0005433156838	17328	24	22D
0005435086919	4089	1	1A
0005435086910	4089	2	2D
0005435086917	4089	3	3A
0005435086916	4089	4	4C
0005435086918	4089	5	6A
0005435086913	4089	6	6B
0005435928153	4089	7	7B
0005435086912	4089	8	7D
0005435086915	4089	9	20A
0005435086911	4089	10	20B
0005435086914	4089	11	20D
0005435928154	4089	12	22C
0005435086830	24396	1	3C
0005435928193	24396	2	5B
0005435928192	24396	3	5D
0005435086834	24396	4	6B
0005435086833	24396	5	7B
0005435928191	24396	6	18A
0005435086832	24396	7	18D
0005435086854	24396	8	21D
0005435928194	24396	9	22B
0005435928195	24396	10	23A
0005435551592	11060	1	2F
0005435551561	11060	2	2H
0005435551600	11060	3	4F
0005435551599	11060	4	4C
0005435551597	11060	5	5B
0005435551565	11060	6	5G
0005435551606	11060	7	12G
0005435551578	11060	8	13E
0005435098544	11060	9	13F
0005435551611	11060	10	14E
0005435551581	11060	11	15G
0005435551596	11060	12	16A
0005435551587	11060	13	20G
0005435551593	11060	14	20H
0005435098552	11060	15	21G
0005435098555	11060	16	21H
0005435551560	11060	17	22B
0005435098560	11060	18	22D
0005435551607	11060	19	22G
0005435098559	11060	20	22H
0005435551602	11060	21	24B
0005435551582	11060	22	24A
0005435098551	11060	23	24G
0005435098538	11060	24	30B
0005435551612	11060	25	32B
0005435551620	11060	26	33G
0005435551591	11060	27	34A
0005435551610	11060	28	34D
0005435551595	11060	29	34G
0005435098553	11060	30	36A
0005435098558	11060	31	36B
0005435551601	11060	32	37B
0005435551583	11060	33	37G
0005435098554	11060	34	37H
0005435098539	11060	35	39F
0005433373523	2456	1	1C
0005433373535	2456	2	1D
0005433373565	2456	3	2A
0005433373564	2456	4	2C
0005435706546	2456	5	2D
0005435706560	2456	6	2F
0005433373519	2456	7	3D
0005435706542	2456	8	4A
0005435706549	2456	9	4C
0005435706540	2456	10	4D
0005433373541	2456	11	4F
0005435706563	2456	12	5C
0005435706557	2456	13	5D
0005435706534	2456	14	5E
0005435706559	2456	15	6C
0005435706553	2456	16	6E
0005435706561	2456	17	6F
0005433373547	2456	18	7A
0005435706538	2456	19	7C
0005435706551	2456	20	7F
0005435706565	2456	21	8D
0005435706539	2456	22	8E
0005435706545	2456	23	9A
0005435706558	2456	24	9C
0005435706555	2456	25	10D
0005435706564	2456	26	10F
0005435706556	2456	27	11A
0005435706544	2456	28	11C
0005435706548	2456	29	11D
0005435706567	2456	30	11F
0005435706533	2456	31	13D
0005435706554	2456	32	13E
0005435706541	2456	33	13F
0005435706566	2456	34	15D
0005435706535	2456	35	16D
0005435706547	2456	36	16E
0005433373509	2456	37	17C
0005433373554	2456	38	17E
0005435706536	2456	39	17F
0005435706537	2456	40	18C
0005435706543	2456	41	18D
0005433373530	2456	42	18F
0005433373548	2456	43	19C
0005435706562	2456	44	19D
0005435706552	2456	45	19E
0005433373511	2456	46	20D
0005435706550	2456	47	20F
0005435706493	27021	1	1D
0005435706415	27021	2	3A
0005435706400	27021	3	4D
0005433373630	27021	4	4E
0005435706431	27021	5	5C
0005435706432	27021	6	5E
0005433373635	27021	7	6A
0005433373622	27021	8	6C
0005435706407	27021	9	6D
0005433373621	27021	10	7C
0005435706336	27021	11	7A
0005435706382	27021	12	7D
0005433373633	27021	13	7F
0005435706401	27021	14	8A
0005435706414	27021	15	8C
0005435706342	27021	16	8E
0005433373624	27021	17	8F
0005435706462	27021	18	9A
0005435706383	27021	19	9C
0005433373627	27021	20	10A
0005435706406	27021	21	10C
0005433373629	27021	22	10D
0005433373626	27021	23	10F
0005433373625	27021	24	11A
0005433373619	27021	25	11C
0005435706367	27021	26	11D
0005433373628	27021	27	11E
0005433373620	27021	28	11F
0005435706399	27021	29	12C
0005435706409	27021	30	12D
0005435706335	27021	31	12E
0005433373636	27021	32	13A
0005435706354	27021	33	13D
0005435706402	27021	34	13E
0005435706397	27021	35	14E
0005435706381	27021	36	14F
0005435706437	27021	37	15E
0005435706341	27021	38	16A
0005433373631	27021	39	16F
0005435706343	27021	40	17E
0005435706425	27021	41	17F
0005435706396	27021	42	18A
0005433373618	27021	43	18D
0005435706302	27021	44	18E
0005433373623	27021	45	18F
0005435706366	27021	46	19A
0005435706368	27021	47	19C
0005433373632	27021	48	19E
0005435706403	27021	49	20D
0005433373634	27021	50	20E
0005435706352	27021	51	20F
0005433261609	1321	1	1F
0005434964431	1321	2	1H
0005434964417	1321	3	2B
0005434964437	1321	4	3C
0005433261603	1321	5	3G
0005433261560	1321	6	3H
0005434964430	1321	7	5A
0005434964436	1321	8	11D
0005433261599	1321	9	11F
0005433261593	1321	10	11E
0005434964406	1321	11	11G
0005434964403	1321	12	12G
0005434964407	1321	13	12H
0005432279294	1321	14	13D
0005434964424	1321	15	13G
0005434964421	1321	16	14A
0005432279293	1321	17	15B
0005432279291	1321	18	15G
0005433261588	1321	19	16D
0005434964438	1321	20	16E
0005433261579	1321	21	17A
0005434964433	1321	22	17B
0005434964425	1321	23	18A
0005434964409	1321	24	17H
0005434964441	1321	25	18G
0005434964440	1321	26	19B
0005434964408	1321	27	19D
0005434964404	1321	28	20D
0005433261559	1321	29	20G
0005433261526	1321	30	20F
0005433261600	1321	31	21E
0005434964434	1321	32	22A
0005433261595	1321	33	22F
0005434964420	1321	34	23A
0005434964410	1321	35	24A
0005434964418	1321	36	23H
0005433261565	1321	37	24E
0005433261624	1321	38	24F
0005434964414	1321	39	27A
0005433261556	1321	40	25F
0005434964429	1321	41	27H
0005434964422	1321	42	28D
0005433261508	1321	43	28F
0005434964405	1321	44	31D
0005434964435	1321	45	31H
0005434964426	1321	46	31G
0005434964432	1321	47	32G
0005434964416	1321	48	33A
0005433261589	1321	49	33H
0005432279292	1321	50	34D
0005434964402	1321	51	34H
0005433261580	1321	52	35F
0005434964419	1321	53	36A
0005434964428	1321	54	35H
0005434964411	1321	55	36B
0005434964423	1321	56	36E
0005434964412	1321	57	37A
0005433261566	1321	58	37B
0005434964427	1321	59	38A
0005434964439	1321	60	38D
0005433261557	1321	61	38F
0005434964415	1321	62	38H
0005434964413	1321	63	38G
0005434964270	18254	1	1A
0005434964293	18254	2	1B
0005434964220	18254	3	1F
0005433261664	18254	4	1H
0005433261658	18254	5	2A
0005433261655	18254	6	3C
0005433261650	18254	7	3B
0005433261672	18254	8	3G
0005433261679	18254	9	3H
0005433261668	18254	10	4F
0005433261653	18254	11	4H
0005434964174	18254	12	5A
0005433261649	18254	13	5F
0005434964257	18254	14	5C
0005434964255	18254	15	5G
0005434964222	18254	16	9B
0005434964196	18254	17	9H
0005434964197	18254	18	11D
0005433261652	18254	19	11G
0005433261648	18254	20	11H
0005433261651	18254	21	12B
0005434964221	18254	22	12E
0005434964241	18254	23	12F
0005434964224	18254	24	14A
0005433261667	18254	25	14G
0005434964164	18254	26	15A
0005434964269	18254	27	14H
0005434964126	18254	28	15D
0005434964250	18254	29	15F
0005433261678	18254	30	15G
0005434964263	18254	31	16B
0005434964252	18254	32	16G
0005433261670	18254	33	16F
0005434964230	18254	34	17B
0005433261676	18254	35	17G
0005434964256	18254	36	17H
0005434964163	18254	37	19E
0005434964198	18254	38	19D
0005433261663	18254	39	20A
0005434964208	18254	40	20D
0005434964292	18254	41	21A
0005433261669	18254	42	21D
0005434964175	18254	43	21F
0005434964229	18254	44	21G
0005434964294	18254	45	22B
0005433261660	18254	46	22E
0005433261661	18254	47	22F
0005434964243	18254	48	23G
0005434964260	18254	49	23H
0005434964227	18254	50	24G
0005434964251	18254	51	25F
0005433261675	18254	52	28D
0005434964261	18254	53	28G
0005433261654	18254	54	28F
0005433261673	18254	55	29B
0005434964205	18254	56	29D
0005433261680	18254	57	29G
0005434964242	18254	58	29F
0005433261674	18254	59	30F
0005434964215	18254	60	31A
0005434964244	18254	61	31B
0005434964228	18254	62	32B
0005433261666	18254	63	32F
0005433261665	18254	64	34G
0005434964211	18254	65	35B
0005433261656	18254	66	35D
0005433261657	18254	67	35F
0005434964212	18254	68	36A
0005433261662	18254	69	37D
0005434964199	18254	70	37E
0005433261677	18254	71	37G
0005434964262	18254	72	38A
0005433261659	18254	73	38B
0005434964143	18254	74	39D
0005433261671	18254	75	38H
0005434626057	4827	1	1F
0005433194856	4827	2	3F
0005434626064	4827	3	4F
0005434626058	4827	4	7A
0005434626061	4827	5	7E
0005434626062	4827	6	11C
0005434626060	4827	7	15A
0005434626056	4827	8	16C
0005434626063	4827	9	16F
0005434626059	4827	10	20D
0005435907556	32925	1	5C
0005434625997	32925	2	5E
0005435907555	32925	3	8A
0005434625998	32925	4	10C
0005434626002	32925	5	10E
0005435907557	32925	6	11A
0005434625967	32925	7	11E
0005434625999	32925	8	17D
0005434625966	32925	9	18F
0005435907554	32925	10	19F
0005434625973	32925	11	20A
0005434626003	32925	12	20C
0005435785182	13788	1	1A
0005435785371	13788	2	1B
0005435785447	13788	3	1C
0005435785420	13788	4	2C
0005435785437	13788	5	2D
0005435937429	13788	6	3A
0005435785334	13788	7	3B
0005435785391	13788	8	3C
0005435785325	13788	9	3D
0005432195714	13788	10	4A
0005435785419	13788	11	4B
0005435785349	13788	12	4D
0005435785310	13788	13	5A
0005435785373	13788	14	5B
0005432195715	13788	15	5C
0005435785404	13788	16	5D
0005435785254	13788	17	6A
0005435937430	13788	18	6B
0005435785422	13788	19	6D
0005435785421	13788	20	7B
0005435785438	13788	21	7C
0005435785332	13788	22	7D
0005435937432	13788	23	18A
0005435785390	13788	24	18B
0005435785327	13788	25	18C
0005435937431	13788	26	18D
0005435785370	13788	27	19C
0005435785389	13788	28	19D
0005435785392	13788	29	20A
0005435785426	13788	30	20B
0005435785439	13788	31	20D
0005435785460	13788	32	21A
0005435785275	13788	33	21B
0005435785252	13788	34	21D
0005435785434	13788	35	22A
0005435785423	13788	36	22B
0005435785281	13788	37	22D
0005435785308	13788	38	23A
0005435785444	13788	39	23B
0005435785684	27405	1	1A
0005435787372	27405	2	1B
0005435785662	27405	3	1C
0005432190665	27405	4	1D
0005435785675	27405	5	2A
0005435785653	27405	6	2B
0005435785651	27405	7	2C
0005435785673	27405	8	2D
0005435785661	27405	9	3A
0005435785659	27405	10	3B
0005435785665	27405	11	3C
0005435785682	27405	12	3D
0005435785657	27405	13	4A
0005435787374	27405	14	4B
0005435785654	27405	15	4C
0005432190663	27405	16	4D
0005435785652	27405	17	5A
0005435937382	27405	18	5B
0005435785663	27405	19	5C
0005435785649	27405	20	5D
0005435785664	27405	21	6A
0005435785655	27405	22	6B
0005435785650	27405	23	6C
0005435785679	27405	24	6D
0005435785672	27405	25	7A
0005435785660	27405	26	7B
0005435785680	27405	27	7C
0005435785678	27405	28	7D
0005435785666	27405	29	18A
0005435785658	27405	30	18B
0005435785676	27405	31	18C
0005435785656	27405	32	18D
0005432190664	27405	33	19A
0005435785683	27405	34	19C
0005435937383	27405	35	19B
0005435787373	27405	36	20A
0005435785669	27405	37	20B
0005435785674	27405	38	20C
0005435785667	27405	39	20D
0005435785668	27405	40	21A
0005435937374	27405	41	21B
0005432190666	27405	42	21C
0005435785681	27405	43	21D
0005435937381	27405	44	22A
0005435785677	27405	45	22B
0005435937384	27405	46	22C
0005435785671	27405	47	22D
0005435785670	27405	48	23A
0005432190662	27405	49	23B
0005435311183	20309	1	1A
0005434408088	20309	2	1C
0005434407680	20309	3	1F
0005434407820	20309	4	2A
0005434407693	20309	5	2C
0005434408038	20309	6	2D
0005434407727	20309	7	2F
0005434407852	20309	8	3A
0005434407743	20309	9	3C
0005434407965	20309	10	3D
0005434407964	20309	11	3F
0005434408091	20309	12	4C
0005435311191	20309	13	4A
0005434407749	20309	14	4D
0005434407481	20309	15	4E
0005434407987	20309	16	4F
0005434407977	20309	17	5A
0005434407897	20309	18	5C
0005435311192	20309	19	5D
0005432058425	20309	20	5E
0005432058422	20309	21	6A
0005432058424	20309	22	6C
0005434407990	20309	23	6D
0005434407833	20309	24	6E
0005435311189	20309	25	7A
0005435311190	20309	26	7D
0005434408108	20309	27	7E
0005434408145	20309	28	7F
0005434407824	20309	29	8A
0005434408054	20309	30	8C
0005434407925	20309	31	8E
0005434407970	20309	32	8F
0005434407744	20309	33	9A
0005434408083	20309	34	9C
0005435311195	20309	35	9D
0005434408107	20309	36	9E
0005434408119	20309	37	9F
0005435311182	20309	38	10A
0005434407991	20309	39	10C
0005434407851	20309	40	10D
0005435311197	20309	41	10E
0005434407853	20309	42	10F
0005435311200	20309	43	11A
0005435311194	20309	44	11C
0005434407767	20309	45	11D
0005435311196	20309	46	11E
0005435311184	20309	47	11F
0005434407798	20309	48	12A
0005434407875	20309	49	12C
0005434407826	20309	50	12D
0005434407742	20309	51	12E
0005435311201	20309	52	12F
0005434407976	20309	53	13A
0005434407986	20309	54	13C
0005435311199	20309	55	13D
0005435311188	20309	56	13E
0005435311193	20309	57	13F
0005434407868	20309	58	14A
0005435311186	20309	59	14C
0005434408115	20309	60	14D
0005435311202	20309	61	14E
0005434407751	20309	62	14F
0005432058423	20309	63	15A
0005435311178	20309	64	15C
0005434407917	20309	65	15D
0005434407876	20309	66	15F
0005435311181	20309	67	16A
0005434407839	20309	68	16C
0005435311185	20309	69	16D
0005435311187	20309	70	16F
0005434407910	20309	71	17A
0005434407840	20309	72	17C
0005435311179	20309	73	17D
0005434407681	20309	74	17E
0005435311180	20309	75	17F
0005434407950	20309	76	18A
0005434407909	20309	77	18C
0005434407989	20309	78	18E
0005434407814	20309	79	18F
0005434408037	20309	80	19A
0005434407722	20309	81	19C
0005434407832	20309	82	19D
0005434407940	20309	83	19E
0005435311198	20309	84	19F
0005434408052	20309	85	20A
0005434407797	20309	86	20C
0005434408084	20309	87	20D
0005432058421	20309	88	20E
0005434407676	20309	89	20F
0005434408422	26995	1	1A
0005434408441	26995	2	1C
0005434408389	26995	3	1F
0005434408440	26995	4	2A
0005435311057	26995	5	2C
0005434408382	26995	6	2D
0005434408400	26995	7	3A
0005434408383	26995	8	3C
0005434408430	26995	9	3D
0005434408408	26995	10	4A
0005434408401	26995	11	4D
0005434408391	26995	12	4E
0005434408425	26995	13	5A
0005434408402	26995	14	5C
0005432154009	26995	15	5D
0005434408436	26995	16	5E
0005432154011	26995	17	5F
0005432154013	26995	18	6A
0005434408410	26995	19	6C
0005434408386	26995	20	6D
0005434408424	26995	21	6E
0005434408431	26995	22	6F
0005434408414	26995	23	7A
0005434408415	26995	24	7C
0005432154010	26995	25	7E
0005435311056	26995	26	7F
0005434408385	26995	27	8A
0005434408427	26995	28	8D
0005434408421	26995	29	8F
0005434408409	26995	30	9C
0005434408390	26995	31	9D
0005434408426	26995	32	9E
0005434408403	26995	33	9F
0005434408435	26995	34	10A
0005434408395	26995	35	10C
0005434408434	26995	36	10D
0005434408384	26995	37	10E
0005434408404	26995	38	11C
0005434408417	26995	39	11D
0005434408437	26995	40	11E
0005434408412	26995	41	11F
0005434408407	26995	42	12A
0005434408446	26995	43	12C
0005435311085	26995	44	12D
0005434408396	26995	45	12E
0005434408420	26995	46	12F
0005434408406	26995	47	13A
0005435311052	26995	48	13C
0005434408432	26995	49	13D
0005434408429	26995	50	13E
0005434408399	26995	51	13F
0005434408405	26995	52	14C
0005434408423	26995	53	14D
0005434408418	26995	54	14F
0005434408444	26995	55	15A
0005434408419	26995	56	15C
0005434408394	26995	57	15D
0005435311053	26995	58	15E
0005434408413	26995	59	15F
0005434408397	26995	60	16A
0005434408439	26995	61	16C
0005434408443	26995	62	16E
0005434408387	26995	63	16F
0005434408398	26995	64	17A
0005434408393	26995	65	17C
0005434408442	26995	66	17D
0005434408388	26995	67	17E
0005434408445	26995	68	18A
0005434408433	26995	69	18C
0005435311048	26995	70	18F
0005432154012	26995	71	19A
0005434408392	26995	72	19C
0005434408428	26995	73	19D
0005434408438	26995	74	19E
0005435311042	26995	75	19F
0005435311041	26995	76	20C
0005434408411	26995	77	20D
0005434408416	26995	78	20F
0005434319544	5727	1	1A
0005434319549	5727	2	1C
0005433123986	5727	3	1D
0005434319555	5727	4	2C
0005433123827	5727	5	2D
0005432109731	5727	6	3A
0005434319554	5727	7	3D
0005434319556	5727	8	5C
0005434319558	5727	9	6E
0005432109733	5727	10	6F
0005433123980	5727	11	7E
0005434319551	5727	12	8A
0005434319546	5727	13	8E
0005433123878	5727	14	9A
0005434319547	5727	15	9D
0005433124000	5727	16	9F
0005434319557	5727	17	11A
0005434319553	5727	18	11F
0005433123865	5727	19	12A
0005433123985	5727	20	13C
0005434319543	5727	21	13D
0005434319550	5727	22	14A
0005434319542	5727	23	14E
0005433123906	5727	24	15C
0005432109732	5727	25	15D
0005433123881	5727	26	15F
0005434319552	5727	27	17C
0005433123979	5727	28	17E
0005434311240	5727	29	18C
0005434319545	5727	30	18D
0005434319548	5727	31	18F
0005433123973	5727	32	19F
0005433123936	5727	33	20A
0005434311241	5727	34	20E
0005434319409	15658	1	1A
0005433124144	15658	2	1F
0005433124151	15658	3	2D
0005434319463	15658	4	2F
0005434319468	15658	5	3C
0005433124163	15658	6	4C
0005434319368	15658	7	4D
0005433124154	15658	8	4E
0005434311220	15658	9	4F
0005434312332	15658	10	5C
0005433124152	15658	11	6D
0005433124153	15658	12	7A
0005434319466	15658	13	7C
0005434319427	15658	14	8C
0005433124162	15658	15	8D
0005434319412	15658	16	8E
0005434319347	15658	17	8F
0005434319474	15658	18	9C
0005434319426	15658	19	10C
0005434311219	15658	20	10E
0005434319411	15658	21	11C
0005433124161	15658	22	11E
0005433124160	15658	23	12E
0005433124159	15658	24	12F
0005434319337	15658	25	13C
0005433124149	15658	26	13D
0005433124148	15658	27	13E
0005433124146	15658	28	13F
0005433124150	15658	29	14D
0005434319390	15658	30	14E
0005434319424	15658	31	14F
0005434312311	15658	32	15D
0005433124155	15658	33	16A
0005434319351	15658	34	17E
0005434319336	15658	35	17F
0005433124158	15658	36	18A
0005433124145	15658	37	18D
0005433124157	15658	38	18E
0005434319372	15658	39	19A
0005433124147	15658	40	19D
0005434319369	15658	41	19F
0005434319397	15658	42	20A
0005433124156	15658	43	20C
0005434312331	15658	44	20D
0005433124164	15658	45	20F
0005435220316	24976	1	1B
0005435217708	24976	2	1C
0005435220307	24976	3	2A
0005435220320	24976	4	2D
0005435221514	24976	5	3B
0005435217700	24976	6	4A
0005435217713	24976	7	4B
0005435217723	24976	8	4C
0005435217706	24976	9	5C
0005435217710	24976	10	6A
0005435221516	24976	11	6C
0005435217722	24976	12	6D
0005435221511	24976	13	7A
0005435217704	24976	14	18A
0005435217707	24976	15	18B
0005435217711	24976	16	18C
0005435220317	24976	17	19C
0005435221515	24976	18	20D
0005435217709	24976	19	21B
0005435220321	24976	20	23A
0005434189178	8995	1	1B
0005434484415	8995	2	1C
0005434189202	8995	3	4B
0005434484419	8995	4	7C
0005434189191	8995	5	18A
0005434484416	8995	6	18C
0005434484413	8995	7	18D
0005434484418	8995	8	19A
0005434484417	8995	9	19C
0005434189201	8995	10	21A
0005434484414	8995	11	23A
0005434484356	16637	1	1C
0005434189236	16637	2	2C
0005434484328	16637	3	3A
0005434484353	16637	4	3D
0005434484365	16637	5	4D
0005434484380	16637	6	18A
0005434484354	16637	7	18B
0005434189238	16637	8	19A
0005434189241	16637	9	20B
0005434189240	16637	10	20C
0005434189239	16637	11	21D
0005434484364	16637	12	22B
0005434189237	16637	13	22D
0005433722206	7602	1	1C
0005433124152	7602	2	1F
0005433124155	7602	3	2D
0005433124160	7602	4	6A
0005433124159	7602	5	6C
0005433124164	7602	6	6D
0005433722200	7602	7	6E
0005433124148	7602	8	7A
0005433722204	7602	9	7D
0005433124146	7602	10	7E
0005433124163	7602	11	8E
0005433124156	7602	12	9D
0005433124147	7602	13	9E
0005433124161	7602	14	10D
0005433124157	7602	15	10F
0005433124149	7602	16	11F
0005433124162	7602	17	13C
0005433124151	7602	18	13F
0005433124154	7602	19	15D
0005433124150	7602	20	16D
0005433124144	7602	21	16E
0005433124158	7602	22	17A
0005433722205	7602	23	17D
0005433124145	7602	24	17F
0005433124153	7602	25	19F
0005433450186	7601	1	1A
0005432721194	7601	2	1C
0005432693397	7601	3	1D
0005433450197	7601	4	1F
0005432721191	7601	5	2A
0005432693379	7601	6	2C
0005432693384	7601	7	2D
0005433450187	7601	8	3A
0005432693386	7601	9	3C
0005432721190	7601	10	3D
0005433450191	7601	11	3F
0005432721170	7601	12	4C
0005432693404	7601	13	4D
0005432721174	7601	14	4E
0005432693385	7601	15	5A
0005432721182	7601	16	5D
0005433450189	7601	17	5E
0005433450203	7601	18	6A
0005433450195	7601	19	5F
0005432693405	7601	20	6C
0005432721192	7601	21	6D
0005433450193	7601	22	6E
0005432721196	7601	23	6F
0005432693402	7601	24	7C
0005432693410	7601	25	7D
0005433450199	7601	26	7E
0005432693392	7601	27	7F
0005432693396	7601	28	8A
0005432721189	7601	29	8C
0005433450194	7601	30	8D
0005432693389	7601	31	8E
0005433450205	7601	32	8F
0005432071605	7601	33	9A
0005433450202	7601	34	9D
0005432721195	7601	35	9E
0005432693381	7601	36	9F
0005432721187	7601	37	10A
0005432693390	7601	38	10C
0005433450196	7601	39	10D
0005433450198	7601	40	10E
0005433450206	7601	41	10F
0005432721186	7601	42	11A
0005432693388	7601	43	11C
0005432693380	7601	44	11E
0005432721177	7601	45	11F
0005432693399	7601	46	12A
0005432721180	7601	47	12C
0005432721179	7601	48	12D
0005432721171	7601	49	12E
0005433450192	7601	50	12F
0005432693383	7601	51	13C
0005432693409	7601	52	13D
0005432693393	7601	53	13E
0005432693401	7601	54	13F
0005433450188	7601	55	14A
0005432693387	7601	56	14C
0005432693403	7601	57	14D
0005432721197	7601	58	14E
0005432721183	7601	59	14F
0005433450185	7601	60	15D
0005432721173	7601	61	15E
0005432693408	7601	62	15F
0005432693395	7601	63	16A
0005432693394	7601	64	16D
0005433450204	7601	65	16E
0005432721172	7601	66	16F
0005433450200	7601	67	17A
0005432693382	7601	68	17C
0005432721184	7601	69	17D
0005432693406	7601	70	17E
0005432071604	7601	71	17F
0005433450190	7601	72	18A
0005432693400	7601	73	18C
0005432721181	7601	74	18D
0005432693391	7601	75	18E
0005432721175	7601	76	18F
0005432721193	7601	77	19A
0005432721185	7601	78	19C
0005432693398	7601	79	19D
0005433450201	7601	80	20A
0005432693407	7601	81	20C
0005432721188	7601	82	20D
0005432721176	7601	83	20E
0005432721178	7601	84	20F
0005433449941	30329	1	1A
0005432693159	30329	2	1C
0005433450107	30329	3	2D
0005433450015	30329	4	2F
0005433449934	30329	5	3A
0005432693086	30329	6	3D
0005432693092	30329	7	4A
0005433449989	30329	8	4C
0005433449982	30329	9	4E
0005433450084	30329	10	5A
0005433449935	30329	11	5D
0005433450011	30329	12	5E
0005433450089	30329	13	5F
0005433450013	30329	14	6A
0005432693098	30329	15	6E
0005432693149	30329	16	6F
0005432693077	30329	17	7C
0005433450010	30329	18	7D
0005432693099	30329	19	7E
0005433449984	30329	20	7F
0005432693090	30329	21	8A
0005433450108	30329	22	8D
0005432693022	30329	23	8E
0005432693085	30329	24	8F
0005432693148	30329	25	9A
0005433449955	30329	26	9D
0005433450076	30329	27	9E
0005433450048	30329	28	10A
0005433450047	30329	29	10D
0005433449983	30329	30	10F
0005433449877	30329	31	11F
0005433450083	30329	32	12A
0005433450090	30329	33	12C
0005433449991	30329	34	12D
0005432693078	30329	35	13F
0005432693081	30329	36	14A
0005432693062	30329	37	14D
0005432692985	30329	38	14E
0005433450030	30329	39	15C
0005432693097	30329	40	15F
0005432693091	30329	41	16A
0005433449985	30329	42	16C
0005432693072	30329	43	16E
0005433450031	30329	44	17D
0005432692936	30329	45	17F
0005433450088	30329	46	18A
0005432693066	30329	47	18C
0005432693080	30329	48	18D
0005433450087	30329	49	18E
0005433450021	30329	50	18F
0005433449986	30329	51	19A
0005432693163	30329	52	19D
0005432693160	30329	53	20D
0005433450038	30329	54	20E
0005433449878	30329	55	20F
0005432721073	30330	1	2C
0005432721117	30330	2	2D
0005433123980	30330	3	2F
0005433722290	30330	4	4A
0005432720995	30330	5	4C
0005432720994	30330	6	4F
0005433123985	30330	7	5A
0005433123865	30330	8	5C
0005433722289	30330	9	5F
0005433722288	30330	10	6A
0005433123973	30330	11	7E
0005432720970	30330	12	8A
0005432721005	30330	13	8C
0005433123979	30330	14	8D
0005432720999	30330	15	8F
0005433722285	30330	16	9D
0005433722284	30330	17	9E
0005432721019	30330	18	9F
0005432720934	30330	19	10D
0005433123986	30330	20	10E
0005433722293	30330	21	11F
0005432721016	30330	22	12C
0005433722286	30330	23	12E
0005432720935	30330	24	13F
0005433123878	30330	25	14E
0005433123906	30330	26	15A
0005432720988	30330	27	15D
0005433722291	30330	28	16A
0005432721015	30330	29	16C
0005432720913	30330	30	16F
0005432721116	30330	31	17A
0005432721018	30330	32	17D
0005433123936	30330	33	18C
0005433123827	30330	34	18D
0005433123881	30330	35	18E
0005432720969	30330	36	19A
0005433124000	30330	37	19C
0005432721017	30330	38	19D
0005432721004	30330	39	19E
0005433722292	30330	40	20A
0005433722287	30330	41	20F
0005434586872	1352	1	1A
0005434586887	1352	2	1D
0005433724851	1352	3	1F
0005433193080	1352	4	2C
0005433193078	1352	5	2D
0005433525152	1352	6	2F
0005433193098	1352	7	3A
0005434586883	1352	8	3C
0005432928002	1352	9	3D
0005432271035	1352	10	3F
0005433525154	1352	11	4A
0005433525153	1352	12	4C
0005432927990	1352	13	4D
0005433525156	1352	14	4E
0005432927988	1352	15	4F
0005434586890	1352	16	5A
0005433193092	1352	17	5C
0005433193134	1352	18	5D
0005434586889	1352	19	5E
0005434586893	1352	20	5F
0005434586873	1352	21	6A
0005433525150	1352	22	6C
0005433193097	1352	23	6E
0005432271034	1352	24	6F
0005434513608	1352	25	7A
0005432927994	1352	26	7C
0005433525155	1352	27	7F
0005434586885	1352	28	8A
0005433525147	1352	29	8D
0005434586877	1352	30	8E
0005434586888	1352	31	8F
0005433193083	1352	32	9A
0005433193096	1352	33	9C
0005433193075	1352	34	9D
0005432271036	1352	35	9E
0005433193093	1352	36	9F
0005432271033	1352	37	10A
0005434586871	1352	38	10C
0005433193086	1352	39	10D
0005434586870	1352	40	10F
0005434586869	1352	41	11A
0005434586881	1352	42	11C
0005434586880	1352	43	11D
0005434586875	1352	44	11F
0005433193079	1352	45	12A
0005434586874	1352	46	12D
0005434586891	1352	47	12E
0005433193032	1352	48	12F
0005433193145	1352	49	13A
0005434586867	1352	50	13D
0005434586892	1352	51	13E
0005434513606	1352	52	13F
0005434586876	1352	53	14A
0005433193081	1352	54	14C
0005433724854	1352	55	14D
0005434513607	1352	56	14E
0005434514995	1352	57	14F
0005434586884	1352	58	15C
0005432927993	1352	59	15D
0005432928010	1352	60	15E
0005434586868	1352	61	15F
0005433525149	1352	62	16A
0005433193091	1352	63	16C
0005433193147	1352	64	16D
0005432927986	1352	65	16F
0005434586878	1352	66	17A
0005434514994	1352	67	17C
0005433525151	1352	68	17E
0005432927987	1352	69	17F
0005434586882	1352	70	18C
0005433724852	1352	71	18D
0005433193084	1352	72	18F
0005433193144	1352	73	19A
0005433193045	1352	74	19C
0005434586886	1352	75	19D
0005433724855	1352	76	19E
0005434586879	1352	77	19F
0005433525148	1352	78	20A
0005433525157	1352	79	20C
0005433192968	1352	80	20E
0005433724853	1352	81	20F
0005434514973	18538	1	1D
0005432928036	18538	2	2F
0005433193190	18538	3	3D
0005433525069	18538	4	4D
0005432928038	18538	5	4F
0005433193187	18538	6	5D
0005433525040	18538	7	5E
0005434514972	18538	8	7A
0005434586656	18538	9	7C
0005433193191	18538	10	8A
0005433193179	18538	11	8D
0005433525052	18538	12	8F
0005434586732	18538	13	9A
0005433724823	18538	14	9E
0005433525074	18538	15	9F
0005432968864	18538	16	10A
0005434586769	18538	17	10D
0005432928035	18538	18	10F
0005433193182	18538	19	11A
0005434586730	18538	20	11C
0005433525044	18538	21	12A
0005434586681	18538	22	12C
0005433525068	18538	23	12D
0005434586691	18538	24	12F
0005434586675	18538	25	13C
0005433193183	18538	26	13D
0005433525060	18538	27	14C
0005432928037	18538	28	14D
0005433193180	18538	29	14E
0005433193189	18538	30	14F
0005433193186	18538	31	15C
0005432928034	18538	32	15E
0005432928039	18538	33	15F
0005433193185	18538	34	16A
0005433193188	18538	35	16F
0005433525042	18538	36	17E
0005433724821	18538	37	17F
0005433724812	18538	38	18A
0005434586676	18538	39	18C
0005434586700	18538	40	18E
0005434586642	18538	41	19D
0005434514954	18538	42	19F
0005433193184	18538	43	20E
0005433193181	18538	44	20F
0005434344565	11426	1	1A
0005434142652	11426	2	1B
0005434344557	11426	3	1C
0005434344534	11426	4	2A
0005434142653	11426	5	2B
0005434344536	11426	6	2C
0005434344543	11426	7	2D
0005434344550	11426	8	3A
0005434344560	11426	9	3B
0005435305018	11426	10	3C
0005434344562	11426	11	3D
0005434344555	11426	12	4B
0005434344564	11426	13	4C
0005434344553	11426	14	4D
0005434344540	11426	15	5A
0005434142651	11426	16	5B
0005434344539	11426	17	5C
0005434344548	11426	18	6A
0005434344559	11426	19	6B
0005434344533	11426	20	6C
0005434344554	11426	21	6D
0005434344566	11426	22	7A
0005434344544	11426	23	7B
0005434344545	11426	24	7C
0005434344558	11426	25	7D
0005434344541	11426	26	18A
0005434344538	11426	27	18B
0005434344563	11426	28	18D
0005434344537	11426	29	19A
0005434344546	11426	30	19B
0005434344549	11426	31	19C
0005434344535	11426	32	20A
0005434344561	11426	33	20C
0005434344551	11426	34	21A
0005434142650	11426	35	21B
0005434344547	11426	36	21C
0005434344542	11426	37	21D
0005435305012	11426	38	22A
0005434344552	11426	39	22B
0005434344556	11426	40	22D
0005434344281	29785	1	1A
0005435304207	29785	2	1B
0005434344249	29785	3	1C
0005434344178	29785	4	2A
0005435304208	29785	5	2B
0005434344270	29785	6	2C
0005434344142	29785	7	2D
0005434142615	29785	8	3A
0005434344276	29785	9	3B
0005434344235	29785	10	3C
0005434344301	29785	11	3D
0005434344205	29785	12	4B
0005435304205	29785	13	4C
0005434142619	29785	14	4D
0005434344362	29785	15	5A
0005434344187	29785	16	5B
0005434344267	29785	17	5C
0005434344275	29785	18	5D
0005434344274	29785	19	6A
0005434344278	29785	20	6B
0005434344363	29785	21	6C
0005434142611	29785	22	6D
0005434344179	29785	23	7D
0005434344258	29785	24	18A
0005434344340	29785	25	18B
0005434142618	29785	26	18D
0005434142625	29785	27	19A
0005434344250	29785	28	19B
0005434344254	29785	29	19C
0005434344096	29785	30	19D
0005434344302	29785	31	20A
0005434344262	29785	32	20B
0005434344277	29785	33	20D
0005435304203	29785	34	21A
0005434344341	29785	35	21B
0005435304204	29785	36	21D
0005434344193	29785	37	22A
0005435305035	29785	38	22B
0005435304206	29785	39	22C
0005434344400	29785	40	22D
0005434344392	29785	41	23A
0005435824899	1305	1	1A
0005433415758	1305	2	3A
0005435824916	1305	3	3C
0005435824894	1305	4	3F
0005433415662	1305	5	4C
0005433415761	1305	6	5A
0005435824901	1305	7	5C
0005435824903	1305	8	6B
0005432284589	1305	9	6C
0005432284591	1305	10	7B
0005435824907	1305	11	7F
0005435824920	1305	12	8F
0005433415702	1305	13	9C
0005433415701	1305	14	10A
0005435824915	1305	15	10E
0005435824893	1305	16	11B
0005435824917	1305	17	11D
0005435824904	1305	18	12B
0005435824902	1305	19	13B
0005432284588	1305	20	13A
0005435824900	1305	21	13C
0005435824913	1305	22	13E
0005435824919	1305	23	14C
0005435824911	1305	24	15B
0005435824909	1305	25	15A
0005435824914	1305	26	15C
0005432284590	1305	27	15E
0005435824908	1305	28	16A
0005435824896	1305	29	16B
0005435824918	1305	30	16D
0005435824905	1305	31	17D
0005435824898	1305	32	17E
0005433415648	1305	33	18A
0005435824897	1305	34	18D
0005435824912	1305	35	18F
0005435824910	1305	36	20A
0005433415749	1305	37	19E
0005435824895	1305	38	20E
0005435824906	1305	39	20F
0005435824644	17996	1	1A
0005435824757	17996	2	2A
0005433415827	17996	3	3A
0005433415819	17996	4	3D
0005435824645	17996	5	3F
0005433415825	17996	6	4D
0005435824599	17996	7	5A
0005433415834	17996	8	5D
0005435824745	17996	9	6E
0005435824631	17996	10	6D
0005435824797	17996	11	7A
0005435824597	17996	12	6F
0005433415823	17996	13	7C
0005433415824	17996	14	8A
0005435824705	17996	15	8D
0005435824638	17996	16	8F
0005433415826	17996	17	9C
0005433415832	17996	18	9E
0005435824676	17996	19	10C
0005435824659	17996	20	11A
0005433415820	17996	21	11D
0005435824654	17996	22	11C
0005433415821	17996	23	12A
0005433415833	17996	24	13C
0005435824758	17996	25	13E
0005435824707	17996	26	14A
0005435824708	17996	27	13F
0005433415818	17996	28	14F
0005435824657	17996	29	15C
0005435824643	17996	30	16B
0005435824585	17996	31	17A
0005435824697	17996	32	16F
0005433415831	17996	33	17C
0005433415828	17996	34	18A
0005435824608	17996	35	18B
0005433415822	17996	36	19A
0005433415829	17996	37	18F
0005435824573	17996	38	19C
0005435824598	17996	39	19E
0005435824756	17996	40	20F
0005433415830	17996	41	21C
0005435824634	17996	42	21F
0005435824627	17996	43	21E
0005435824851	17996	44	21D
0005434460503	17527	1	1C
0005434462788	17527	2	2A
0005434462794	17527	3	2C
0005434460495	17527	4	3A
0005434460496	17527	5	3C
0005434460502	17527	6	3D
0005434462792	17527	7	5D
0005434462790	17527	8	7C
0005434462784	17527	9	7D
0005434462791	17527	10	19A
0005434462793	17527	11	20B
0005434462787	17527	12	22D
0005435242883	5627	1	1A
0005432784337	5627	2	1C
0005435242927	5627	3	1D
0005432784336	5627	4	1F
0005432784368	5627	5	2A
0005432784349	5627	6	2C
0005435242918	5627	7	2D
0005432784356	5627	8	2F
0005432784351	5627	9	3A
0005432784380	5627	10	3C
0005432784377	5627	11	3D
0005435242917	5627	12	3F
0005435242885	5627	13	4A
0005432784333	5627	14	4C
0005432784369	5627	15	4D
0005432784362	5627	16	4E
0005435242953	5627	17	4F
0005435242882	5627	18	5A
0005432784348	5627	19	5C
0005435242808	5627	20	5D
0005435242938	5627	21	5E
0005435242884	5627	22	5F
0005432784355	5627	23	6A
0005435476749	5627	24	6C
0005432784376	5627	25	6D
0005432784354	5627	26	6E
0005435242856	5627	27	6F
0005432784345	5627	28	7A
0005435242945	5627	29	7C
0005432784381	5627	30	7D
0005432784331	5627	31	7E
0005435242911	5627	32	7F
0005435242890	5627	33	8A
0005432144020	5627	34	8C
0005432784343	5627	35	8D
0005432784328	5627	36	8E
0005432784361	5627	37	8F
0005432784357	5627	38	9A
0005435476763	5627	39	9C
0005432784372	5627	40	9D
0005432784364	5627	41	9E
0005432784374	5627	42	9F
0005435476757	5627	43	10A
0005435242849	5627	44	10C
0005432784341	5627	45	10D
0005435242861	5627	46	10E
0005435242915	5627	47	10F
0005435242941	5627	48	11A
0005432144021	5627	49	11C
0005435242857	5627	50	11D
0005432784378	5627	51	11E
0005432784359	5627	52	11F
0005432784340	5627	53	12A
0005432784330	5627	54	12C
0005432784358	5627	55	12D
0005432784365	5627	56	12E
0005435242854	5627	57	12F
0005432784375	5627	58	13A
0005435242720	5627	59	13C
0005435242937	5627	60	13D
0005432784342	5627	61	13E
0005432144022	5627	62	13F
0005435242870	5627	63	14A
0005432784363	5627	64	14C
0005432784371	5627	65	14D
0005432784373	5627	66	14E
0005435476756	5627	67	14F
0005432784353	5627	68	15A
0005432784360	5627	69	15C
0005435242940	5627	70	15D
0005432784379	5627	71	15E
0005432784329	5627	72	15F
0005432784339	5627	73	16A
0005432784332	5627	74	16C
0005432784352	5627	75	16D
0005432784326	5627	76	16E
0005435242999	5627	77	16F
0005432784347	5627	78	17A
0005432784327	5627	79	17C
0005432784338	5627	80	17D
0005435242721	5627	81	17E
0005435242923	5627	82	17F
0005435242855	5627	83	18A
0005432784335	5627	84	18D
0005435242905	5627	85	18C
0005432784350	5627	86	18E
0005432784367	5627	87	18F
0005435242891	5627	88	19A
0005435242922	5627	89	19C
0005432784346	5627	90	19D
0005435242873	5627	91	19E
0005435242962	5627	92	19F
0005432784344	5627	93	20A
0005432784370	5627	94	20C
0005435242989	5627	95	20D
0005432784334	5627	96	20E
0005432784366	5627	97	20F
0005435243128	15336	1	1A
0005435243121	15336	2	1C
0005432783849	15336	3	1D
0005435476830	15336	4	2A
0005432783713	15336	5	2C
0005435243126	15336	6	2D
0005435243107	15336	7	2F
0005432783778	15336	8	3A
0005435243115	15336	9	3C
0005435243103	15336	10	3D
0005435243109	15336	11	3F
0005435243127	15336	12	4A
0005435476832	15336	13	4C
0005435243114	15336	14	4D
0005432783888	15336	15	4F
0005432784049	15336	16	4E
0005432783897	15336	17	5A
0005432783948	15336	18	5C
0005435476827	15336	19	5D
0005432783668	15336	20	5E
0005435476828	15336	21	5F
0005432783887	15336	22	6D
0005435476837	15336	23	6E
0005435243118	15336	24	6F
0005432783702	15336	25	7C
0005432783780	15336	26	7D
0005435476831	15336	27	8A
0005432783848	15336	28	8C
0005435476834	15336	29	8D
0005435243116	15336	30	8E
0005432783553	15336	31	8F
0005432783855	15336	32	9F
0005435243113	15336	33	10A
0005432783735	15336	34	10C
0005435243105	15336	35	10D
0005432783928	15336	36	10F
0005435243123	15336	37	11C
0005435243117	15336	38	11E
0005432783941	15336	39	11F
0005432783906	15336	40	12A
0005432783994	15336	41	12E
0005432783714	15336	42	12F
0005435243122	15336	43	13A
0005432783926	15336	44	13D
0005435243111	15336	45	13E
0005435243125	15336	46	14A
0005432783995	15336	47	14C
0005435476833	15336	48	14D
0005432783779	15336	49	14F
0005432783929	15336	50	15A
0005432784003	15336	51	15C
0005435243104	15336	52	15D
0005435476829	15336	53	15E
0005435243112	15336	54	15F
0005435243124	15336	55	16A
0005432783988	15336	56	16D
0005435243119	15336	57	16F
0005435476838	15336	58	17A
0005432783667	15336	59	17C
0005435243106	15336	60	17E
0005432783678	15336	61	18D
0005435476835	15336	62	18C
0005435243108	15336	63	18E
0005432783583	15336	64	18F
0005435243110	15336	65	19A
0005432783949	15336	66	19C
0005435243120	15336	67	19D
0005435476836	15336	68	19E
0005432783952	15336	69	20A
0005432783927	15336	70	20D
0005432783942	15336	71	20E
0005432783898	15336	72	20F
0005435850930	4389	1	1A
0005435850952	4389	2	1B
0005432848460	4389	3	1C
0005434462812	4389	4	2A
0005432848463	4389	5	2C
0005435850893	4389	6	2D
0005432848470	4389	7	3B
0005432848459	4389	8	3C
0005434463953	4389	9	3D
0005434462813	4389	10	4C
0005435850928	4389	11	4D
0005432848468	4389	12	5A
0005435850894	4389	13	5B
0005432848458	4389	14	6A
0005432848464	4389	15	6C
0005434463952	4389	16	6D
0005434462814	4389	17	7B
0005432848462	4389	18	7D
0005435850951	4389	19	18A
0005435850937	4389	20	18B
0005432848461	4389	21	18C
0005432848467	4389	22	18D
0005432848457	4389	23	19A
0005432848469	4389	24	19C
0005435850916	4389	25	19D
0005435850935	4389	26	20A
0005435850943	4389	27	20B
0005435850927	4389	28	20C
0005432848465	4389	29	21B
0005432848466	4389	30	21D
0005435850915	4389	31	22A
0005435850917	4389	32	22D
0005435850936	4389	33	23A
0005432848328	28878	1	2B
0005434463939	28878	2	2C
0005434461653	28878	3	3A
0005432848339	28878	4	4A
0005432848292	28878	5	4B
0005435851006	28878	6	4C
0005432848341	28878	7	4D
0005434463925	28878	8	5B
0005435851005	28878	9	5C
0005435851001	28878	10	6A
0005435851002	28878	11	6C
0005435851010	28878	12	6D
0005432848338	28878	13	7A
0005434463935	28878	14	7B
0005432848282	28878	15	7C
0005435851008	28878	16	18A
0005432848320	28878	17	18C
0005432848343	28878	18	18D
0005432848340	28878	19	19B
0005435851009	28878	20	19C
0005432848326	28878	21	20A
0005435851003	28878	22	21B
0005434463934	28878	23	21D
0005435851004	28878	24	22A
0005435851007	28878	25	22D
0005432848327	28878	26	23A
0005434926159	6269	1	1C
0005433497294	6269	2	1F
0005433497284	6269	3	2A
0005434926154	6269	4	2C
0005432075266	6269	5	2D
0005434926164	6269	6	2F
0005434926143	6269	7	3C
0005433497293	6269	8	3D
0005434443880	6269	9	3F
0005434443877	6269	10	4A
0005433497311	6269	11	4C
0005434443879	6269	12	4D
0005434443882	6269	13	4E
0005434926153	6269	14	4F
0005433497313	6269	15	5A
0005434926137	6269	16	5D
0005433497301	6269	17	5E
0005433497302	6269	18	5F
0005434443886	6269	19	6A
0005434443873	6269	20	6C
0005434926139	6269	21	6D
0005434926141	6269	22	6E
0005434443881	6269	23	6F
0005434926163	6269	24	7A
0005433497285	6269	25	7C
0005433497307	6269	26	7D
0005434926161	6269	27	7E
0005433497288	6269	28	8A
0005433497287	6269	29	8C
0005434926149	6269	30	8E
0005434443885	6269	31	8F
0005433497291	6269	32	9A
0005434926136	6269	33	9C
0005434443871	6269	34	9D
0005434926144	6269	35	9E
0005433497283	6269	36	9F
0005434926138	6269	37	10A
0005433497282	6269	38	10C
0005434926147	6269	39	10F
0005434443884	6269	40	11A
0005434926162	6269	41	11C
0005434443872	6269	42	11D
0005434926155	6269	43	11E
0005433497292	6269	44	11F
0005434443874	6269	45	12A
0005433497305	6269	46	12C
0005433497297	6269	47	12D
0005433497299	6269	48	12F
0005433497289	6269	49	13E
0005434926156	6269	50	13F
0005434926146	6269	51	14A
0005434926152	6269	52	14C
0005434926140	6269	53	14D
0005434926151	6269	54	14E
0005433497303	6269	55	14F
0005434443878	6269	56	15A
0005434926145	6269	57	15C
0005434926165	6269	58	15D
0005434926142	6269	59	15E
0005434926158	6269	60	15F
0005434443875	6269	61	16A
0005433497298	6269	62	16C
0005433497312	6269	63	16D
0005434443870	6269	64	16E
0005434443876	6269	65	16F
0005434926148	6269	66	17A
0005433497300	6269	67	17C
0005433497306	6269	68	17D
0005434926160	6269	69	17E
0005432075265	6269	70	17F
0005433497296	6269	71	18A
0005432075268	6269	72	18C
0005433497286	6269	73	18D
0005433497304	6269	74	18E
0005433497308	6269	75	18F
0005433497295	6269	76	19A
0005434443883	6269	77	19D
0005433497290	6269	78	19E
0005432075267	6269	79	19F
0005434926150	6269	80	20A
0005433497309	6269	81	20C
0005434926157	6269	82	20D
0005433497310	6269	83	20E
0005433496996	20339	1	1A
0005433497112	20339	2	1D
0005434925849	20339	3	1F
0005434925818	20339	4	2A
0005434925856	20339	5	2C
0005434925797	20339	6	2D
0005433497064	20339	7	2F
0005433496985	20339	8	3A
0005434443732	20339	9	3C
0005434925808	20339	10	3D
0005434443728	20339	11	4A
0005434925819	20339	12	4C
0005433497105	20339	13	4D
0005434925807	20339	14	4E
0005433496967	20339	15	4F
0005433496998	20339	16	5A
0005433497197	20339	17	5C
0005434925786	20339	18	5D
0005434925855	20339	19	6A
0005434443747	20339	20	6D
0005433496917	20339	21	6E
0005433497075	20339	22	7A
0005434925853	20339	23	7D
0005434925780	20339	24	7E
0005434443678	20339	25	7F
0005433497046	20339	26	8A
0005433497058	20339	27	8C
0005433497011	20339	28	8E
0005433496968	20339	29	8F
0005434443776	20339	30	9C
0005433497074	20339	31	9D
0005434925816	20339	32	9E
0005434925806	20339	33	10A
0005433497082	20339	34	10C
0005433497041	20339	35	10D
0005434925837	20339	36	10E
0005434925851	20339	37	10F
0005434443721	20339	38	11A
0005434925820	20339	39	11C
0005434443677	20339	40	11E
0005434443775	20339	41	11F
0005434443726	20339	42	12A
0005434925717	20339	43	12C
0005434443725	20339	44	13C
0005434925718	20339	45	13D
0005433497053	20339	46	13E
0005434443676	20339	47	13F
0005434443733	20339	48	14C
0005433496930	20339	49	14D
0005433496997	20339	50	14E
0005434925785	20339	51	14F
0005434443786	20339	52	15A
0005434925817	20339	53	15C
0005434925839	20339	54	15D
0005433497042	20339	55	15E
0005434925832	20339	56	16A
0005433496916	20339	57	16E
0005434925852	20339	58	16F
0005434925779	20339	59	17C
0005433497010	20339	60	17D
0005434925758	20339	61	17E
0005434443766	20339	62	18A
0005434443748	20339	63	18C
0005433497061	20339	64	18D
0005434925836	20339	65	18E
0005434925781	20339	66	18F
0005434925778	20339	67	19C
0005434925777	20339	68	19D
0005433496949	20339	69	19E
0005434443785	20339	70	20A
0005433497062	20339	71	20C
0005433497009	20339	72	20D
0005434925811	20339	73	20E
0005433496979	20339	74	20F
0005432783865	12169	1	1A
0005432783873	12169	2	1C
0005435243137	12169	3	1D
0005432783623	12169	4	1F
0005435243140	12169	5	2A
0005432783758	12169	6	2C
0005432783825	12169	7	2D
0005432783624	12169	8	2F
0005432784110	12169	9	3A
0005432784060	12169	10	3C
0005432783757	12169	11	3D
0005432783749	12169	12	3F
0005432783834	12169	13	4A
0005432784195	12169	14	4C
0005432783959	12169	15	4D
0005435243145	12169	16	4E
0005435243130	12169	17	4F
0005432783787	12169	18	5A
0005435243156	12169	19	5C
0005432784061	12169	20	5D
0005432783595	12169	21	5E
0005435243154	12169	22	5F
0005435243151	12169	23	6A
0005432784001	12169	24	6C
0005432783920	12169	25	6D
0005435243148	12169	26	6E
0005432784128	12169	27	6F
0005432783884	12169	28	7A
0005432784072	12169	29	7C
0005432783748	12169	30	7D
0005432783809	12169	31	7E
0005432783979	12169	32	8A
0005435243136	12169	33	8C
0005432783795	12169	34	8D
0005432784151	12169	35	8E
0005432783934	12169	36	8F
0005432784026	12169	37	9C
0005432783944	12169	38	9D
0005435243157	12169	39	9E
0005432783776	12169	40	9F
0005435243153	12169	41	10A
0005432783803	12169	42	10C
0005432783793	12169	43	10D
0005432783618	12169	44	10E
0005435243138	12169	45	10F
0005432783754	12169	46	11A
0005435243152	12169	47	11C
0005432783919	12169	48	11D
0005432783823	12169	49	11E
0005432783946	12169	50	11F
0005435243132	12169	51	12A
0005432783786	12169	52	12C
0005432784008	12169	53	12D
0005432783782	12169	54	12E
0005432783980	12169	55	12F
0005432783947	12169	56	13C
0005435243144	12169	57	13D
0005435243142	12169	58	13E
0005435243150	12169	59	13F
0005432783596	12169	60	14A
0005435243155	12169	61	14C
0005432783753	12169	62	14D
0005435243147	12169	63	14E
0005435243135	12169	64	14F
0005435243139	12169	65	15A
0005432784025	12169	66	15C
0005435243129	12169	67	15D
0005432783864	12169	68	15E
0005432784002	12169	69	15F
0005432783933	12169	70	16A
0005432783958	12169	71	16C
0005432783954	12169	72	16D
0005432783978	12169	73	16E
0005435243134	12169	74	16F
0005435243141	12169	75	17A
0005432784146	12169	76	17C
0005432783932	12169	77	17D
0005432783956	12169	78	17E
0005432783810	12169	79	17F
0005432783914	12169	80	18A
0005432783960	12169	81	18C
0005432783955	12169	82	18D
0005435243143	12169	83	18E
0005432783836	12169	84	18F
0005435243149	12169	85	19A
0005432784057	12169	86	19C
0005435243131	12169	87	19E
0005435243146	12169	88	19F
0005432783706	12169	89	20A
0005432783869	12169	90	20C
0005432783874	12169	91	20D
0005435243133	12169	92	20E
0005432783860	12169	93	20F
0005432784317	15438	1	1F
0005432784323	15438	2	2A
0005435242869	15438	3	2D
0005432784305	15438	4	2F
0005435242865	15438	5	3A
0005432784324	15438	6	3C
0005432784294	15438	7	3D
0005432784277	15438	8	3F
0005432784299	15438	9	4A
0005432784286	15438	10	4C
0005432784308	15438	11	4D
0005432784315	15438	12	4E
0005432784319	15438	13	4F
0005432784274	15438	14	5A
0005432784321	15438	15	5C
0005435242956	15438	16	5D
0005432784318	15438	17	5E
0005432784275	15438	18	5F
0005432784288	15438	19	6A
0005435242904	15438	20	6C
0005432784320	15438	21	6D
0005432784276	15438	22	6E
0005432784295	15438	23	7A
0005432784278	15438	24	7C
0005435242864	15438	25	7D
0005432784271	15438	26	7E
0005432784273	15438	27	8A
0005435242921	15438	28	8C
0005432784322	15438	29	8D
0005432784280	15438	30	8E
0005432784306	15438	31	8F
0005432784290	15438	32	9C
0005432784307	15438	33	9D
0005432784309	15438	34	9E
0005432784289	15438	35	10A
0005432784293	15438	36	10D
0005435242946	15438	37	10E
0005435242859	15438	38	10F
0005432784285	15438	39	11A
0005432784283	15438	40	11C
0005432784300	15438	41	11D
0005432784311	15438	42	11E
0005435242847	15438	43	11F
0005432784284	15438	44	12A
0005432784310	15438	45	12C
0005435242920	15438	46	12E
0005435242858	15438	47	12F
0005432784279	15438	48	13A
0005432784303	15438	49	13C
0005432784301	15438	50	13D
0005432784325	15438	51	14A
0005435242914	15438	52	14C
0005435242934	15438	53	14D
0005432784282	15438	54	14E
0005432784272	15438	55	15C
0005435242935	15438	56	15E
0005435242879	15438	57	15F
0005432784314	15438	58	16A
0005432784302	15438	59	16C
0005432784296	15438	60	16D
0005435242850	15438	61	16F
0005435242752	15438	62	17A
0005432784287	15438	63	17C
0005432784313	15438	64	17D
0005432784291	15438	65	17E
0005432784312	15438	66	17F
0005432784297	15438	67	18A
0005435242878	15438	68	18D
0005432784292	15438	69	18E
0005432784316	15438	70	19A
0005435242939	15438	71	19C
0005432784298	15438	72	19D
0005435242860	15438	73	19E
0005432784281	15438	74	19F
0005432784304	15438	75	20A
0005435242868	15438	76	20D
0005435242800	15438	77	20F
0005434878470	10081	1	1C
0005434878861	10081	2	1A
0005434878462	10081	3	1F
0005434878229	10081	4	1D
0005434878506	10081	5	2F
0005434878668	10081	6	2D
0005434758905	10081	7	2C
0005434758900	10081	8	3A
0005434878505	10081	9	3D
0005434878859	10081	10	4A
0005434878631	10081	11	3F
0005434878732	10081	12	4C
0005434878557	10081	13	4F
0005434878113	10081	14	4D
0005434878355	10081	15	5C
0005434878488	10081	16	5A
0005434878597	10081	17	5F
0005434877829	10081	18	5D
0005434878690	10081	19	6B
0005434878237	10081	20	6D
0005434878559	10081	21	6C
0005434878153	10081	22	6E
0005434878419	10081	23	7A
0005434878596	10081	24	6F
0005434878446	10081	25	7C
0005434878298	10081	26	7B
0005434878649	10081	27	7E
0005434878184	10081	28	7D
0005434878121	10081	29	8A
0005434878648	10081	30	7F
0005434878411	10081	31	8D
0005434878028	10081	32	8C
0005434878119	10081	33	8F
0005434877914	10081	34	8E
0005434878572	10081	35	9B
0005434878447	10081	36	9A
0005434878405	10081	37	9D
0005434878695	10081	38	9C
0005434878385	10081	39	9E
0005434878474	10081	40	10B
0005434878386	10081	41	10A
0005434878573	10081	42	9F
0005434878195	10081	43	10D
0005434878640	10081	44	11A
0005434878686	10081	45	10F
0005434877913	10081	46	11C
0005434878460	10081	47	11B
0005434878104	10081	48	11D
0005434878569	10081	49	11F
0005434878063	10081	50	11E
0005434878667	10081	51	12B
0005435913963	10081	52	12A
0005434878367	10081	53	12D
0005435913962	10081	54	12F
0005434877828	10081	55	12E
0005434878561	10081	56	13B
0005434878542	10081	57	13A
0005434878451	10081	58	13D
0005434878097	10081	59	13C
0005434878454	10081	60	13F
0005434878247	10081	61	13E
0005434878185	10081	62	14C
0005434878356	10081	63	14B
0005434878030	10081	64	14D
0005434878345	10081	65	14F
0005434878588	10081	66	15A
0005434878466	10081	67	15C
0005435913964	10081	68	15B
0005434878313	10081	69	15E
0005434878372	10081	70	15D
0005434758901	10081	71	16A
0005434878503	10081	72	15F
0005434878292	10081	73	16C
0005434878409	10081	74	16B
0005434878344	10081	75	16D
0005434878560	10081	76	17A
0005434878498	10081	77	16F
0005434878502	10081	78	16E
0005434878120	10081	79	17B
0005434878105	10081	80	17D
0005434878529	10081	81	17C
0005434878555	10081	82	17E
0005434878029	10081	83	18B
0005434878412	10081	84	18A
0005434878810	10081	85	17F
0005434878423	10081	86	18C
0005434878860	10081	87	18E
0005434878360	10081	88	19A
0005434878246	10081	89	18F
0005434878501	10081	90	19C
0005434878504	10081	91	19B
0005434878554	10081	92	19F
0005434878422	10081	93	19E
0005434878811	10081	94	20B
0005434878463	10081	95	20A
0005434878625	10081	96	20D
0005434878062	10081	97	20F
0005434910136	10081	98	20E
0005434878289	10081	99	21A
0005434878359	10081	100	21C
0005434878476	10081	101	21B
0005434877943	10081	102	21F
0005434878312	10081	103	21E
0005434879192	14603	1	1A
0005434879174	14603	2	2A
0005434879198	14603	3	2D
0005434879222	14603	4	2C
0005434879218	14603	5	3A
0005434879232	14603	6	2F
0005434879167	14603	7	3D
0005434879206	14603	8	3C
0005434879207	14603	9	4A
0005434758918	14603	10	3F
0005434879178	14603	11	4C
0005434879226	14603	12	5A
0005434879239	14603	13	4F
0005434879189	14603	14	4D
0005434879210	14603	15	5D
0005434879186	14603	16	5C
0005434879211	14603	17	5F
0005434879200	14603	18	6B
0005434879182	14603	19	6D
0005434879185	14603	20	6C
0005434879188	14603	21	6F
0005434879181	14603	22	6E
0005434879157	14603	23	7A
0005434910105	14603	24	7C
0005434879240	14603	25	7D
0005434879208	14603	26	8A
0005434758917	14603	27	7F
0005434879158	14603	28	7E
0005434879215	14603	29	8B
0005434879191	14603	30	8D
0005434879237	14603	31	8F
0005434879221	14603	32	8E
0005434879225	14603	33	9B
0005434879220	14603	34	9A
0005434879209	14603	35	9D
0005434879162	14603	36	9C
0005434879155	14603	37	9E
0005434879204	14603	38	10B
0005434879219	14603	39	10A
0005434879172	14603	40	9F
0005434879199	14603	41	10C
0005434879248	14603	42	10E
0005434879180	14603	43	10D
0005434879159	14603	44	11A
0005434879171	14603	45	10F
0005434879176	14603	46	11B
0005435913933	14603	47	11E
0005434879156	14603	48	11D
0005434879201	14603	49	11F
0005434879242	14603	50	12B
0005434879154	14603	51	12A
0005434879179	14603	52	12C
0005434879216	14603	53	12F
0005434879193	14603	54	12E
0005434879195	14603	55	12D
0005434879169	14603	56	13B
0005434879153	14603	57	13A
0005434879238	14603	58	13C
0005434879161	14603	59	13D
0005434879196	14603	60	13F
0005434879175	14603	61	13E
0005434879183	14603	62	14B
0005434879235	14603	63	14A
0005434879203	14603	64	14D
0005434879213	14603	65	14F
0005434879187	14603	66	14E
0005434879243	14603	67	15B
0005434879246	14603	68	15A
0005434879229	14603	69	15D
0005434879173	14603	70	15C
0005434879233	14603	71	15F
0005434879194	14603	72	16A
0005434879224	14603	73	16B
0005435913932	14603	74	16E
0005434879228	14603	75	16D
0005434879165	14603	76	16C
0005434879230	14603	77	17A
0005434879231	14603	78	16F
0005434879227	14603	79	17B
0005434879197	14603	80	17D
0005434879190	14603	81	17C
0005434879160	14603	82	17F
0005434879164	14603	83	17E
0005434879244	14603	84	18B
0005434879247	14603	85	18A
0005434879217	14603	86	18D
0005434879184	14603	87	18C
0005434879223	14603	88	18E
0005434879245	14603	89	19A
0005434879234	14603	90	18F
0005434879236	14603	91	19C
0005434879241	14603	92	19B
0005434879214	14603	93	19E
0005434879205	14603	94	19D
0005434910106	14603	95	19F
0005434879177	14603	96	20B
0005434879163	14603	97	20A
0005434879168	14603	98	20D
0005434879212	14603	99	20F
0005434879166	14603	100	20E
0005435913937	14603	101	21C
0005434879202	14603	102	21B
0005435913931	14603	103	21E
0005434879170	14603	104	21F
0005435660251	9261	1	1A
0005435660250	9261	2	1B
0005434252022	9261	3	1C
0005435660257	9261	4	1D
0005435660256	9261	5	2A
0005435660253	9261	6	3C
0005434252000	9261	7	6A
0005434251991	9261	8	6C
0005434252023	9261	9	7A
0005434251999	9261	10	7C
0005435660259	9261	11	18C
0005435660252	9261	12	18D
0005435660249	9261	13	19B
0005434251992	9261	14	20A
0005435660255	9261	15	21A
0005435660248	9261	16	22A
0005435660258	9261	17	22B
0005435660254	9261	18	23A
0005435660178	24662	1	1A
0005435660133	24662	2	1B
0005435660152	24662	3	2B
0005434252059	24662	4	2D
0005434252060	24662	5	4B
0005435660128	24662	6	5A
0005435660127	24662	7	6A
0005435660153	24662	8	6C
0005435660183	24662	9	7C
0005435660182	24662	10	18A
0005434252064	24662	11	7D
0005434252062	24662	12	19D
0005434252063	24662	13	20A
0005434252061	24662	14	20C
0005435660192	24662	15	20D
0005434252067	24662	16	21A
0005434252065	24662	17	21B
0005434252066	24662	18	21C
0005435660101	24662	19	22C
0005433681071	2817	1	1C
0005432966898	2817	2	1D
0005432966909	2817	3	1F
0005433681057	2817	4	2A
0005432967064	2817	5	2C
0005432966926	2817	6	2D
0005432966956	2817	7	2F
0005433681056	2817	8	3A
0005433681042	2817	9	3C
0005432222838	2817	10	3F
0005432967043	2817	11	4A
0005432966990	2817	12	4C
0005433681072	2817	13	4D
0005433681054	2817	14	4E
0005433681029	2817	15	4F
0005432966892	2817	16	5A
0005433681076	2817	17	5C
0005433681067	2817	18	5D
0005432966959	2817	19	5E
0005432966897	2817	20	5F
0005432966975	2817	21	6A
0005433681053	2817	22	6C
0005433681045	2817	23	6D
0005433681037	2817	24	6E
0005432967042	2817	25	6F
0005432966925	2817	26	7C
0005433681039	2817	27	7D
0005433681074	2817	28	7E
0005433681070	2817	29	8A
0005432967044	2817	30	8C
0005433681040	2817	31	8D
0005432222837	2817	32	8E
0005433681036	2817	33	8F
0005433681035	2817	34	9A
0005433681069	2817	35	9C
0005432966923	2817	36	9D
0005433681032	2817	37	9E
0005433684439	2817	38	9F
0005433681059	2817	39	10A
0005433681038	2817	40	10C
0005433681062	2817	41	10D
0005433681049	2817	42	10E
0005432966976	2817	43	10F
0005433681048	2817	44	11A
0005432966910	2817	45	11C
0005433681031	2817	46	11D
0005433681047	2817	47	11E
0005433681055	2817	48	11F
0005432222834	2817	49	12A
0005432966960	2817	50	12D
0005433684441	2817	51	12E
0005433681033	2817	52	12F
0005433681052	2817	53	13A
0005433681078	2817	54	13C
0005433681064	2817	55	13D
0005432222836	2817	56	13E
0005433681058	2817	57	13F
0005433681068	2817	58	14A
0005433681044	2817	59	14C
0005432966933	2817	60	14D
0005432966924	2817	61	14E
0005433681077	2817	62	14F
0005432966939	2817	63	15C
0005432222835	2817	64	15D
0005433681075	2817	65	15E
0005432966945	2817	66	15F
0005432967045	2817	67	16A
0005433681030	2817	68	16C
0005433681063	2817	69	16D
0005433681065	2817	70	16E
0005433681043	2817	71	16F
0005433681034	2817	72	17A
0005433681041	2817	73	17C
0005432966880	2817	74	17D
0005432967008	2817	75	17E
0005432967007	2817	76	18A
0005433681066	2817	77	18C
0005433684440	2817	78	18D
0005433681060	2817	79	18E
0005433681046	2817	80	18F
0005432966891	2817	81	19A
0005433681050	2817	82	19C
0005432966974	2817	83	19D
0005432967046	2817	84	19E
0005433681061	2817	85	19F
0005433681073	2817	86	20A
0005433681051	2817	87	20C
0005432967063	2817	88	20D
0005432966918	2817	89	20E
0005433680718	29141	1	1A
0005433680655	29141	2	1C
0005433680906	29141	3	1D
0005432967196	29141	4	1F
0005433684430	29141	5	2A
0005432967208	29141	6	2C
0005432967189	29141	7	2D
0005433680851	29141	8	2F
0005433680901	29141	9	3C
0005433680684	29141	10	3A
0005432967190	29141	11	3D
0005433680838	29141	12	3F
0005433680907	29141	13	4A
0005433680685	29141	14	4C
0005432967204	29141	15	4D
0005433680877	29141	16	4E
0005432967191	29141	17	4F
0005433680722	29141	18	5A
0005433680704	29141	19	5C
0005432967192	29141	20	5D
0005433680943	29141	21	5E
0005433680755	29141	22	5F
0005433680683	29141	23	6C
0005433690928	29141	24	6A
0005433680873	29141	25	6D
0005433680713	29141	26	6E
0005432967198	29141	27	6F
0005433684429	29141	28	7A
0005432967201	29141	29	7C
0005433680648	29141	30	7D
0005433680616	29141	31	7E
0005432967206	29141	32	7F
0005433680908	29141	33	8A
0005433680799	29141	34	8C
0005433680638	29141	35	8D
0005433680430	29141	36	8E
0005432005243	29141	37	8F
0005433680593	29141	38	9A
0005433680629	29141	39	9C
0005433690937	29141	40	9D
0005433680545	29141	41	9E
0005433680876	29141	42	9F
0005433680547	29141	43	10A
0005433690934	29141	44	10C
0005432967209	29141	45	10D
0005432967205	29141	46	10E
0005432967199	29141	47	10F
0005433680663	29141	48	11A
0005433680681	29141	49	11C
0005433690925	29141	50	11D
0005433680428	29141	51	11E
0005433680800	29141	52	11F
0005433690926	29141	53	12A
0005433680623	29141	54	12C
0005433680900	29141	55	12D
0005433680892	29141	56	12E
0005433690927	29141	57	12F
0005432967187	29141	58	13A
0005432967210	29141	59	13C
0005433690938	29141	60	13D
0005432967197	29141	61	13E
0005433680751	29141	62	13F
0005432967188	29141	63	14A
0005432967200	29141	64	14C
0005433680726	29141	65	14E
0005433680624	29141	66	14F
0005432967193	29141	67	15A
0005433687714	29141	68	15C
0005433680546	29141	69	15D
0005433690933	29141	70	15E
0005433687701	29141	71	16A
0005432967207	29141	72	15F
0005432005241	29141	73	16C
0005433680808	29141	74	16D
0005433680721	29141	75	16E
0005433680852	29141	76	16F
0005433680542	29141	77	17A
0005433680429	29141	78	17C
0005433680687	29141	79	17D
0005433680839	29141	80	17E
0005433687702	29141	81	17F
0005433680628	29141	82	18A
0005433680627	29141	83	18C
0005433680966	29141	84	18D
0005433687713	29141	85	18E
0005433680717	29141	86	18F
0005433680543	29141	87	19A
0005432967194	29141	88	19C
0005433680965	29141	89	19D
0005432005242	29141	90	19E
0005432967202	29141	91	19F
0005432967203	29141	92	20A
0005433680843	29141	93	20C
0005433684433	29141	94	20D
0005432967195	29141	95	20E
0005432967186	29141	96	20F
0005433577937	9285	1	1A
0005433615366	9285	2	1D
0005433634132	9285	3	1C
0005433634144	9285	4	2A
0005434163647	9285	5	1F
0005434272196	9285	6	2C
0005432145133	9285	7	2D
0005434163663	9285	8	2F
0005433615350	9285	9	3D
0005433615358	9285	10	3A
0005433615370	9285	11	4A
0005433615360	9285	12	4D
0005433634142	9285	13	4C
0005433577941	9285	14	4F
0005433615354	9285	15	5A
0005433634141	9285	16	5C
0005433634127	9285	17	5D
0005434269110	9285	18	6D
0005434163625	9285	19	6C
0005433615361	9285	20	6F
0005432755107	9285	21	7A
0005433615374	9285	22	7D
0005433634124	9285	23	7C
0005433634122	9285	24	7F
0005433615401	9285	25	8A
0005433577942	9285	26	8C
0005433615339	9285	27	8B
0005433615383	9285	28	8E
0005433634133	9285	29	8D
0005433615385	9285	30	8F
0005433615334	9285	31	9B
0005433615373	9285	32	9A
0005433634151	9285	33	9C
0005433615392	9285	34	9D
0005433615341	9285	35	9E
0005433615406	9285	36	10A
0005432145130	9285	37	10B
0005433634135	9285	38	10D
0005433615343	9285	39	10C
0005433615345	9285	40	10E
0005434153538	9285	41	10F
0005433634129	9285	42	11B
0005433634149	9285	43	11C
0005433615405	9285	44	11F
0005433615376	9285	45	11E
0005434153531	9285	46	12A
0005433577945	9285	47	12B
0005433615387	9285	48	12D
0005434163622	9285	49	12C
0005433615384	9285	50	12E
0005432755110	9285	51	12F
0005433615364	9285	52	13A
0005433615390	9285	53	13C
0005433615396	9285	54	13B
0005432145131	9285	55	13D
0005433577947	9285	56	13E
0005433634126	9285	57	14A
0005433577950	9285	58	13F
0005433577949	9285	59	14B
0005433615333	9285	60	14C
0005433615368	9285	61	14E
0005433615357	9285	62	14D
0005434163623	9285	63	15A
0005433615344	9285	64	14F
0005433634150	9285	65	15B
0005433634123	9285	66	15C
0005434153537	9285	67	15E
0005433615379	9285	68	15D
0005433634121	9285	69	15F
0005433615338	9285	70	16A
0005432756880	9285	71	16C
0005433615397	9285	72	16B
0005433615340	9285	73	16D
0005432145132	9285	74	16E
0005433615386	9285	75	17A
0005434272197	9285	76	16F
0005433615404	9285	77	17B
0005434163610	9285	78	17C
0005434152789	9285	79	17D
0005433615342	9285	80	17F
0005434153532	9285	81	17E
0005433577946	9285	82	18A
0005433615352	9285	83	18C
0005432755109	9285	84	18B
0005433634131	9285	85	18E
0005432755111	9285	86	19B
0005433615369	9285	87	18F
0005433615389	9285	88	19C
0005433615380	9285	89	19D
0005433634138	9285	90	19E
0005433634148	9285	91	20B
0005433615375	9285	92	20A
0005433634136	9285	93	20C
0005433615371	9285	94	20E
0005433615351	9285	95	20D
0005433615355	9285	96	20F
0005433615402	9285	97	21A
0005433615353	9285	98	21C
0005433577944	9285	99	21B
0005433615398	9285	100	21D
0005434163649	9285	101	21E
0005434163655	9285	102	21F
0005433634152	9285	103	22B
0005432756881	9285	104	22A
0005433577939	9285	105	22C
0005433615400	9285	106	22E
0005433615349	9285	107	22D
0005433634153	9285	108	22F
0005433615381	9285	109	23A
0005433577938	9285	110	23C
0005433634143	9285	111	23B
0005433634137	9285	112	23D
0005434269106	9285	113	23E
0005433615335	9285	114	23F
0005433615346	9285	115	24B
0005433615337	9285	116	24E
0005432756882	9285	117	24D
0005433615388	9285	118	24F
0005433615356	9285	119	25A
0005434163666	9285	120	25C
0005433615378	9285	121	25B
0005433615348	9285	122	25D
0005433615365	9285	123	25E
0005433615363	9285	124	25F
0005432755108	9285	125	26B
0005433634140	9285	126	26A
0005433615391	9285	127	26D
0005434163638	9285	128	26C
0005433634134	9285	129	26F
0005433634154	9285	130	26E
0005433577948	9285	131	27B
0005433634128	9285	132	27A
0005433615367	9285	133	27C
0005433615403	9285	134	27D
0005433634145	9285	135	27F
0005433615362	9285	136	27E
0005433634125	9285	137	28B
0005434272195	9285	138	28A
0005433615395	9285	139	28C
0005433634147	9285	140	28E
0005433577940	9285	141	28D
0005433615399	9285	142	29A
0005433634139	9285	143	29B
0005433615359	9285	144	29D
0005434163648	9285	145	29C
0005433577943	9285	146	29E
0005434163665	9285	147	29F
0005433615394	9285	148	30B
0005433615377	9285	149	30A
0005434152788	9285	150	30D
0005433634130	9285	151	30C
0005433615347	9285	152	30E
0005433615393	9285	153	30F
0005433634146	9285	154	31B
0005433615372	9285	155	31A
0005433634120	9285	156	31C
0005433615336	9285	157	31D
0005433615382	9285	158	31F
0005434152787	9285	159	31E
0005433614704	25222	1	1C
0005433614675	25222	2	1A
0005433614702	25222	3	1D
0005434272208	25222	4	2A
0005433614640	25222	5	1F
0005433633777	25222	6	2F
0005433614869	25222	7	3C
0005433614718	25222	8	3D
0005433577846	25222	9	4A
0005433614901	25222	10	3F
0005433614902	25222	11	4D
0005433633790	25222	12	5A
0005433614561	25222	13	4F
0005433614725	25222	14	5C
0005433615014	25222	15	5F
0005433633699	25222	16	5D
0005433614555	25222	17	6C
0005433633781	25222	18	6D
0005433614464	25222	19	7A
0005433614519	25222	20	6F
0005433577806	25222	21	7C
0005433633780	25222	22	7F
0005433633946	25222	23	7D
0005433614707	25222	24	8C
0005433614967	25222	25	8B
0005433614545	25222	26	8D
0005434163713	25222	27	8E
0005433614798	25222	28	9A
0005433633813	25222	29	8F
0005433614797	25222	30	9B
0005433615024	25222	31	9C
0005433633924	25222	32	9E
0005433614756	25222	33	10A
0005433614661	25222	34	10B
0005433577764	25222	35	10D
0005433577803	25222	36	10C
0005433614657	25222	37	10E
0005434273093	25222	38	10F
0005433633636	25222	39	11A
0005433614536	25222	40	11C
0005433614789	25222	41	11D
0005433614554	25222	42	11F
0005433615012	25222	43	11E
0005433614550	25222	44	12A
0005433577814	25222	45	12C
0005433633730	25222	46	12B
0005433634004	25222	47	12D
0005433615111	25222	48	12E
0005433614527	25222	49	12F
0005433614757	25222	50	13A
0005433614684	25222	51	13C
0005433633805	25222	52	13B
0005433614622	25222	53	13D
0005433614924	25222	54	13E
0005433614698	25222	55	14A
0005433614951	25222	56	13F
0005433614670	25222	57	14C
0005433614373	25222	58	14E
0005433577788	25222	59	14F
0005433615030	25222	60	15B
0005434163708	25222	61	15A
0005433633791	25222	62	15C
0005433633799	25222	63	15D
0005433615013	25222	64	15F
0005433614986	25222	65	15E
0005433614514	25222	66	16B
0005433633925	25222	67	16D
0005434163711	25222	68	16E
0005433577829	25222	69	17B
0005433614685	25222	70	17C
0005433614703	25222	71	17D
0005433614809	25222	72	17E
0005433615029	25222	73	18A
0005433614865	25222	74	17F
0005434163704	25222	75	18B
0005433614672	25222	76	18C
0005433633755	25222	77	18E
0005433633792	25222	78	19B
0005433633889	25222	79	18F
0005434163712	25222	80	19D
0005433614893	25222	81	19C
0005433614671	25222	82	19E
0005433614926	25222	83	20A
0005433614660	25222	84	20C
0005433633766	25222	85	20D
0005433633804	25222	86	20F
0005433614971	25222	87	21B
0005433614846	25222	88	21C
0005433614845	25222	89	21E
0005433633851	25222	90	21D
0005433614959	25222	91	21F
0005433633888	25222	92	22B
0005433633841	25222	93	22A
0005433614799	25222	94	22C
0005433614925	25222	95	22E
0005433634003	25222	96	22F
0005433614864	25222	97	23A
0005433577784	25222	98	23C
0005433614803	25222	99	23B
0005434272209	25222	100	23F
0005434163709	25222	101	23E
0005433614966	25222	102	24B
0005433633724	25222	103	24A
0005433614534	25222	104	24E
0005433577790	25222	105	24F
0005433615101	25222	106	25A
0005433615031	25222	107	25C
0005433614535	25222	108	25D
0005433614513	25222	109	25E
0005434163707	25222	110	25F
0005433577820	25222	111	26B
0005433614461	25222	112	26A
0005433577839	25222	113	26D
0005433633806	25222	114	26C
0005433614940	25222	115	26E
0005433633637	25222	116	26F
0005433577802	25222	117	27B
0005434163705	25222	118	27A
0005433614943	25222	119	27D
0005433633789	25222	120	27F
0005433633923	25222	121	28A
0005433614945	25222	122	28B
0005433633638	25222	123	28E
0005433615059	25222	124	28D
0005434273094	25222	125	28F
0005434163706	25222	126	29A
0005433614872	25222	127	29C
0005433614996	25222	128	29B
0005433614701	25222	129	29D
0005433614706	25222	130	29E
0005433614518	25222	131	29F
0005433614788	25222	132	30A
0005433614674	25222	133	30C
0005433614866	25222	134	30E
0005433614717	25222	135	30F
0005434163714	25222	136	31A
0005433633842	25222	137	31D
0005433615107	25222	138	31E
0005434163710	25222	139	31F
0005435856205	4211	1	1A
0005435947205	4211	2	1H
0005435947274	4211	3	2A
0005435986832	4211	4	2B
0005432571334	4211	5	3A
0005435947347	4211	6	3G
0005435856222	4211	7	4C
0005435947276	4211	8	4H
0005435947253	4211	9	5G
0005435947275	4211	10	11B
0005432571333	4211	11	11H
0005435856223	4211	12	13E
0005434271323	4211	13	13H
0005434271311	4211	14	14D
0005435947231	4211	15	17B
0005435947291	4211	16	17G
0005435947277	4211	17	19F
0005435986830	4211	18	20B
0005435947289	4211	19	20E
0005435856217	4211	20	20F
0005435856204	4211	21	20G
0005435947320	4211	22	20H
0005435947206	4211	23	22E
0005435947207	4211	24	24B
0005435947321	4211	25	24D
0005432184980	4211	26	24E
0005435986829	4211	27	25F
0005435947346	4211	28	28A
0005435986831	4211	29	27H
0005435856225	4211	30	29H
0005434271312	4211	31	32A
0005435986833	4211	32	32D
0005435854062	4211	33	32F
0005435947230	4211	34	33D
0005435947288	4211	35	33F
0005435947260	4211	36	34G
0005435947264	4211	37	34H
0005435986828	4211	38	35A
0005435947298	4211	39	35F
0005432184981	4211	40	36B
0005435947229	4211	41	36D
0005432571335	4211	42	37D
0005435787356	4211	43	37E
0005435947290	4211	44	37F
0005435947273	4211	45	38E
0005435947280	4211	46	39D
0005435986834	4211	47	39F
0005435947400	26592	1	1B
0005435787378	26592	2	1C
0005435947402	26592	3	2B
0005435856248	26592	4	3B
0005435947407	26592	5	4A
0005435947401	26592	6	4F
0005432571364	26592	7	5F
0005435986790	26592	8	11A
0005435787379	26592	9	13B
0005435856247	26592	10	14F
0005435856246	26592	11	14E
0005435947413	26592	12	16E
0005435947411	26592	13	16H
0005435947404	26592	14	17D
0005432571363	26592	15	18E
0005435986759	26592	16	19B
0005435856249	26592	17	19E
0005435986753	26592	18	19D
0005432571362	26592	19	21E
0005435986757	26592	20	21G
0005435986789	26592	21	22D
0005435986788	26592	22	22B
0005435947403	26592	23	24B
0005435986754	26592	24	25E
0005435986774	26592	25	29F
0005435947406	26592	26	30B
0005435947409	26592	27	30G
0005435986765	26592	28	30H
0005435947408	26592	29	31G
0005432571365	26592	30	33B
0005435986773	26592	31	33H
0005435947405	26592	32	35G
0005435986766	26592	33	35H
0005435986755	26592	34	36E
0005435986775	26592	35	36D
0005435787377	26592	36	36H
0005435947410	26592	37	37D
0005435947399	26592	38	38D
0005435947412	26592	39	39F
0005433074766	306	1	1A
0005433569663	306	2	1C
0005433569676	306	3	1F
0005433074752	306	4	2A
0005432948396	306	5	2D
0005433134119	306	6	2C
0005432948571	306	7	2F
0005433569662	306	8	3A
0005432948496	306	9	3C
0005433569675	306	10	3F
0005432948490	306	11	3D
0005433129269	306	12	4A
0005433569686	306	13	4C
0005432948597	306	14	4D
0005433569681	306	15	5A
0005432948591	306	16	4F
0005433569685	306	17	5F
0005432948462	306	18	5D
0005433569654	306	19	6A
0005432948637	306	20	6C
0005433569688	306	21	6F
0005433569702	306	22	6D
0005433569704	306	23	7A
0005432948435	306	24	7C
0005433074617	306	25	8A
0005433129285	306	26	7F
0005432948457	306	27	8B
0005433074676	306	28	8D
0005433569653	306	29	8C
0005432948516	306	30	8E
0005433569683	306	31	8F
0005433569677	306	32	9B
0005432948525	306	33	9A
0005433569666	306	34	9C
0005433569670	306	35	9D
0005433569695	306	36	9F
0005432948505	306	37	9E
0005433134153	306	38	10C
0005433569656	306	39	10E
0005433569680	306	40	10D
0005432948376	306	41	11A
0005433129287	306	42	11B
0005432948506	306	43	11C
0005433569684	306	44	11F
0005433569651	306	45	11E
0005433569669	306	46	12A
0005433569706	306	47	12C
0005432239000	306	48	12B
0005432948608	306	49	12D
0005432948522	306	50	12E
0005432948494	306	51	13A
0005433569655	306	52	12F
0005433569678	306	53	13B
0005433074710	306	54	13C
0005433569682	306	55	13D
0005433129260	306	56	13F
0005433134161	306	57	13E
0005433569673	306	58	14A
0005433569703	306	59	14D
0005433074701	306	60	14C
0005432948521	306	61	14E
0005433134152	306	62	14F
0005433569698	306	63	15B
0005433129270	306	64	15A
0005432948554	306	65	15C
0005433569690	306	66	16A
0005433129289	306	67	15F
0005433569652	306	68	16B
0005432238998	306	69	16D
0005433074753	306	70	16E
0005432238999	306	71	16F
0005433129286	306	72	17A
0005433569705	306	73	17C
0005432948561	306	74	17B
0005432238997	306	75	17E
0005433569660	306	76	17D
0005432948537	306	77	17F
0005433569687	306	78	18A
0005433569667	306	79	18B
0005433074777	306	80	18D
0005432948470	306	81	18C
0005433569679	306	82	18E
0005432239002	306	83	18F
0005433129275	306	84	19B
0005433569701	306	85	19D
0005432948590	306	86	19C
0005433569665	306	87	20A
0005432948526	306	88	19E
0005432948553	306	89	20B
0005433074864	306	90	20D
0005433134129	306	91	20F
0005432948605	306	92	20E
0005433569658	306	93	21A
0005433569689	306	94	21C
0005432948630	306	95	21B
0005433569691	306	96	21D
0005433074702	306	97	21E
0005432948465	306	98	22A
0005432948639	306	99	21F
0005433134155	306	100	22B
0005433134120	306	101	22C
0005433569649	306	102	22D
0005432948416	306	103	22F
0005432948555	306	104	22E
0005433134130	306	105	23A
0005432948562	306	106	23D
0005432948497	306	107	23C
0005433129281	306	108	23F
0005432948267	306	109	23E
0005433569696	306	110	24A
0005432948366	306	111	24B
0005433074845	306	112	24C
0005432948266	306	113	24E
0005433129276	306	114	24D
0005432239001	306	115	24F
0005433074774	306	116	25A
0005433074703	306	117	25B
0005433569699	306	118	25E
0005433569650	306	119	26A
0005433129279	306	120	25F
0005432948538	306	121	26B
0005433569657	306	122	26C
0005433569672	306	123	26E
0005433569692	306	124	26D
0005433569659	306	125	27D
0005433569697	306	126	27C
0005432948638	306	127	27E
0005433074667	306	128	28A
0005433569668	306	129	28C
0005432948489	306	130	28E
0005432948405	306	131	28D
0005433569694	306	132	29A
0005433129278	306	133	28F
0005433569674	306	134	29B
0005433074618	306	135	29E
0005433569700	306	136	29C
0005433569693	306	137	29F
0005433569661	306	138	30A
0005432948612	306	139	30B
0005432948466	306	140	30C
0005432948535	306	141	30D
0005433129288	306	142	31A
0005432948549	306	143	30F
0005433569664	306	144	31B
0005433569671	306	145	31C
0005433074634	306	146	31D
0005433569121	11565	1	1A
0005433134185	11565	2	1C
0005433074985	11565	3	1D
0005433131753	11565	4	1F
0005432948850	11565	5	2D
0005433569109	11565	6	2C
0005433568927	11565	7	3A
0005433074986	11565	8	2F
0005432948872	11565	9	3C
0005432948864	11565	10	3F
0005433568794	11565	11	4A
0005433075011	11565	12	4C
0005433568997	11565	13	4D
0005433569126	11565	14	5A
0005432948884	11565	15	4F
0005433075008	11565	16	5D
0005433569070	11565	17	5C
0005433569044	11565	18	5F
0005432948880	11565	19	6A
0005432948877	11565	20	6D
0005433569028	11565	21	6C
0005433131757	11565	22	6F
0005433569122	11565	23	7D
0005433569145	11565	24	8A
0005433075004	11565	25	7F
0005433568616	11565	26	8B
0005433075012	11565	27	8D
0005432948883	11565	28	8C
0005433568960	11565	29	8E
0005432948881	11565	30	8F
0005433569146	11565	31	9A
0005433569083	11565	32	9C
0005433131756	11565	33	9E
0005433075002	11565	34	10A
0005432948871	11565	35	10B
0005433568942	11565	36	10D
0005433568702	11565	37	10C
0005432948854	11565	38	10E
0005433568988	11565	39	10F
0005433568938	11565	40	11B
0005433569006	11565	41	11A
0005432948857	11565	42	11C
0005433568944	11565	43	11E
0005432948887	11565	44	11D
0005433074988	11565	45	12B
0005433074991	11565	46	12D
0005432948886	11565	47	12C
0005432948879	11565	48	12E
0005433568793	11565	49	12F
0005433134186	11565	50	13A
0005433568996	11565	51	13C
0005433568826	11565	52	13B
0005433569148	11565	53	13D
0005433569062	11565	54	13F
0005432948852	11565	55	13E
0005432948849	11565	56	14A
0005433568869	11565	57	14B
0005433568874	11565	58	14C
0005432948855	11565	59	14D
0005433074993	11565	60	14F
0005433075001	11565	61	14E
0005433568984	11565	62	15A
0005433569026	11565	63	15C
0005433074995	11565	64	15B
0005433568981	11565	65	15E
0005433569110	11565	66	15D
0005432948889	11565	67	15F
0005433075003	11565	68	16B
0005432948888	11565	69	16D
0005432948868	11565	70	16C
0005433569060	11565	71	16E
0005433569131	11565	72	16F
0005432948874	11565	73	17D
0005433074987	11565	74	17C
0005432192354	11565	75	17B
0005433074984	11565	76	17F
0005433075006	11565	77	17E
0005433074999	11565	78	18A
0005433569108	11565	79	18B
0005432192352	11565	80	18D
0005432948856	11565	81	18C
0005433569101	11565	82	18E
0005433131754	11565	83	18F
0005433569048	11565	84	19C
0005433568881	11565	85	19B
0005433569125	11565	86	19D
0005433568943	11565	87	20B
0005433074996	11565	88	20C
0005432948853	11565	89	20D
0005433568954	11565	90	20F
0005433569129	11565	91	21A
0005432948870	11565	92	21B
0005432948867	11565	93	21D
0005433074998	11565	94	21C
0005432948860	11565	95	21E
0005433568861	11565	96	22A
0005432948885	11565	97	22B
0005433568983	11565	98	22C
0005433568836	11565	99	22D
0005433075007	11565	100	22F
0005433568989	11565	101	22E
0005433131755	11565	102	23C
0005433569130	11565	103	23B
0005433075000	11565	104	23D
0005432948873	11565	105	23E
0005432948848	11565	106	23F
0005433569144	11565	107	24B
0005432948875	11565	108	24C
0005433569098	11565	109	24D
0005432948882	11565	110	24F
0005433569027	11565	111	25B
0005433134187	11565	112	25A
0005432948876	11565	113	25D
0005433569005	11565	114	25C
0005433569013	11565	115	25F
0005432948865	11565	116	25E
0005433075010	11565	117	26A
0005432948859	11565	118	26B
0005433569107	11565	119	26C
0005432948851	11565	120	26E
0005433568862	11565	121	26D
0005433568928	11565	122	26F
0005433075005	11565	123	27A
0005432948866	11565	124	27C
0005433074989	11565	125	27B
0005433134184	11565	126	27D
0005432948863	11565	127	27E
0005432192351	11565	128	28A
0005433569038	11565	129	27F
0005433074990	11565	130	28B
0005433074992	11565	131	28D
0005432192353	11565	132	28C
0005432948858	11565	133	28F
0005432948862	11565	134	29B
0005433568875	11565	135	29A
0005433074994	11565	136	29E
0005433569047	11565	137	29D
0005432948861	11565	138	29C
0005432948878	11565	139	29F
0005433568990	11565	140	30A
0005433074997	11565	141	30B
0005433569045	11565	142	30C
0005432948869	11565	143	30F
0005433075009	11565	144	30E
0005433569120	11565	145	31A
0005432948890	11565	146	31B
0005433569123	11565	147	31D
0005433569031	11565	148	31F
0005433568929	11565	149	31E
0005433817508	9977	1	1B
0005433817512	9977	2	2A
0005434732980	9977	3	3A
0005433817511	9977	4	3B
0005433817509	9977	5	4A
0005434732982	9977	6	4B
0005433817510	9977	7	5B
0005434732987	9977	8	6B
0005433817459	13987	1	1A
0005433817468	13987	2	1B
0005433817473	13987	3	2A
0005434733017	13987	4	2B
0005433817469	13987	5	3A
0005433817460	13987	6	4A
0005434733016	13987	7	4B
0005433817474	13987	8	5B
0005433817486	13987	9	6A
0005434733018	13987	10	6B
0005433754775	2348	1	1A
0005433434808	2348	2	1B
0005433754799	2348	3	1F
0005433434640	2348	4	1C
0005435982809	2348	5	1G
0005435982771	2348	6	2A
0005433754802	2348	7	1H
0005433434764	2348	8	2B
0005432869574	2348	9	2C
0005433434803	2348	10	2F
0005432985211	2348	11	3A
0005435982785	2348	12	2H
0005434731176	2348	13	3C
0005433434660	2348	14	3B
0005435982804	2348	15	3F
0005432985260	2348	16	3H
0005433434758	2348	17	4B
0005432226120	2348	18	4A
0005433434644	2348	19	4F
0005433754792	2348	20	4C
0005433434747	2348	21	4G
0005432985009	2348	22	4H
0005433766679	2348	23	5B
0005435982776	2348	24	5A
0005435982795	2348	25	5F
0005435982799	2348	26	5C
0005432985179	2348	27	5G
0005432226119	2348	28	9B
0005433754791	2348	29	9A
0005432655662	2348	30	9G
0005434731173	2348	31	9H
0005434731174	2348	32	11B
0005433754830	2348	33	11A
0005433434641	2348	34	11E
0005432985154	2348	35	11D
0005433754797	2348	36	11F
0005435982801	2348	37	11G
0005435982779	2348	38	12A
0005432984973	2348	39	11H
0005435982792	2348	40	12D
0005432655660	2348	41	12B
0005432985066	2348	42	12E
0005433754813	2348	43	12G
0005435982784	2348	44	12F
0005433434793	2348	45	12H
0005433754826	2348	46	13B
0005432655657	2348	47	13A
0005432985141	2348	48	13D
0005433754786	2348	49	13E
0005433434655	2348	50	13F
0005433434757	2348	51	14B
0005433754821	2348	52	14A
0005433434784	2348	53	14D
0005435982772	2348	54	14F
0005432985159	2348	55	14E
0005435982798	2348	56	14G
0005433766680	2348	57	15A
0005433434714	2348	58	14H
0005433754803	2348	59	15B
0005433754781	2348	60	15E
0005432985099	2348	61	15D
0005432655667	2348	62	15F
0005433754776	2348	63	15H
0005433754794	2348	64	15G
0005433434739	2348	65	16A
0005432300322	2348	66	16D
0005432985164	2348	67	16B
0005433434802	2348	68	16E
0005433754807	2348	69	16F
0005433754804	2348	70	16H
0005432226123	2348	71	16G
0005433754823	2348	72	17B
0005432300325	2348	73	17A
0005433754822	2348	74	17D
0005433754784	2348	75	17E
0005432985143	2348	76	17G
0005435982811	2348	77	17F
0005433434807	2348	78	17H
0005432655663	2348	79	18B
0005432985098	2348	80	18A
0005435982780	2348	81	18E
0005435982770	2348	82	18D
0005435982782	2348	83	18G
0005435982808	2348	84	18F
0005433754779	2348	85	19A
0005433754824	2348	86	18H
0005435982774	2348	87	19B
0005433754816	2348	88	19D
0005433754778	2348	89	19F
0005435982807	2348	90	19E
0005433434685	2348	91	19G
0005433764702	2348	92	20A
0005433764701	2348	93	20D
0005433434614	2348	94	20B
0005432226121	2348	95	20E
0005432985169	2348	96	20F
0005435982778	2348	97	20H
0005435982805	2348	98	20G
0005435982790	2348	99	21A
0005433754809	2348	100	21D
0005433754789	2348	101	21B
0005432655666	2348	102	21E
0005433754819	2348	103	21F
0005435982768	2348	104	21H
0005432655664	2348	105	21G
0005433434691	2348	106	22A
0005432655656	2348	107	22B
0005432985206	2348	108	22E
0005433754793	2348	109	22G
0005432985104	2348	110	23A
0005433754827	2348	111	22H
0005433754810	2348	112	23B
0005435982789	2348	113	23D
0005434731175	2348	114	23F
0005434731154	2348	115	23E
0005432985055	2348	116	23G
0005433434659	2348	117	23H
0005435982803	2348	118	24B
0005435982769	2348	119	24A
0005433754782	2348	120	24D
0005435982793	2348	121	24F
0005434731155	2348	122	24E
0005433754828	2348	123	24H
0005435982802	2348	124	24G
0005432869518	2348	125	25D
0005432984972	2348	126	25E
0005433434656	2348	127	27A
0005432869517	2348	128	25F
0005433754811	2348	129	27B
0005432985008	2348	130	27E
0005433754815	2348	131	27D
0005435982777	2348	132	27F
0005433754785	2348	133	27G
0005433754783	2348	134	28A
0005432985213	2348	135	28D
0005432985155	2348	136	28B
0005432300321	2348	137	28G
0005435982797	2348	138	28F
0005433754829	2348	139	28E
0005432300323	2348	140	29A
0005433754833	2348	141	28H
0005435982783	2348	142	29D
0005433754832	2348	143	29B
0005435982775	2348	144	29E
0005433434734	2348	145	29F
0005433434804	2348	146	29H
0005435982794	2348	147	29G
0005433754780	2348	148	30B
0005432226124	2348	149	30A
0005435982773	2348	150	30E
0005435982788	2348	151	30D
0005432985133	2348	152	30F
0005432300326	2348	153	30G
0005432985163	2348	154	31A
0005432985165	2348	155	30H
0005433766678	2348	156	31B
0005433434754	2348	157	31D
0005435982767	2348	158	31F
0005435982781	2348	159	31E
0005433754817	2348	160	31H
0005433754825	2348	161	32A
0005433754795	2348	162	32B
0005432985160	2348	163	32E
0005433434755	2348	164	32D
0005435982800	2348	165	32F
0005433754812	2348	166	32H
0005435982796	2348	167	32G
0005435982787	2348	168	33A
0005432300324	2348	169	33D
0005435982791	2348	170	33B
0005432226122	2348	171	33E
0005432985132	2348	172	33G
0005432985144	2348	173	33F
0005434731189	2348	174	33H
0005433754790	2348	175	34A
0005432869542	2348	176	34D
0005433754801	2348	177	34F
0005433754796	2348	178	34E
0005432985074	2348	179	34G
0005432985035	2348	180	34H
0005433754814	2348	181	35B
0005433754800	2348	182	35A
0005435982806	2348	183	35D
0005433754787	2348	184	35F
0005433754831	2348	185	35E
0005432655658	2348	186	35G
0005433754806	2348	187	36A
0005432655661	2348	188	35H
0005433754805	2348	189	36B
0005435982810	2348	190	36D
0005433434683	2348	191	36F
0005432985184	2348	192	36G
0005432869573	2348	193	37A
0005432985050	2348	194	36H
0005433434684	2348	195	37B
0005433754820	2348	196	37D
0005432985142	2348	197	37F
0005433754788	2348	198	37H
0005433754818	2348	199	37G
0005433754777	2348	200	38A
0005433754798	2348	201	38D
0005432655665	2348	202	38B
0005433434733	2348	203	38E
0005433754808	2348	204	38F
0005432985049	2348	205	38H
0005432655659	2348	206	38G
0005433434738	2348	207	39D
0005435982786	2348	208	39F
0005432655540	26216	1	1A
0005435982226	26216	2	1C
0005435982396	26216	3	1B
0005433754449	26216	4	1F
0005433754310	26216	5	1H
0005433754423	26216	6	1G
0005433754440	26216	7	2A
0005435982322	26216	8	2C
0005433754180	26216	9	2B
0005435982198	26216	10	2H
0005435982562	26216	11	2G
0005434731215	26216	12	2F
0005435982338	26216	13	3A
0005435982336	26216	14	3B
0005433754309	26216	15	3F
0005433434983	26216	16	3G
0005433754149	26216	17	4A
0005433434982	26216	18	3H
0005433766640	26216	19	4B
0005433754541	26216	20	4C
0005433754575	26216	21	4G
0005435982395	26216	22	4F
0005432869589	26216	23	5A
0005433434966	26216	24	4H
0005435982337	26216	25	5B
0005432985401	26216	26	5C
0005432655522	26216	27	5F
0005433754140	26216	28	5H
0005432655495	26216	29	5G
0005435982239	26216	30	9B
0005432655555	26216	31	9H
0005432655586	26216	32	9G
0005433754463	26216	33	11A
0005433754054	26216	34	11B
0005435982605	26216	35	11D
0005435982388	26216	36	11F
0005435982364	26216	37	11E
0005433754451	26216	38	11H
0005433754450	26216	39	11G
0005433754418	26216	40	12A
0005432049502	26216	41	12D
0005435982458	26216	42	12B
0005433766647	26216	43	12E
0005433434981	26216	44	12G
0005433754148	26216	45	12F
0005433434977	26216	46	12H
0005432985399	26216	47	13A
0005433754452	26216	48	13D
0005433766636	26216	49	13E
0005432869593	26216	50	13G
0005432985406	26216	51	13F
0005433754053	26216	52	14A
0005432985404	26216	53	13H
0005433754226	26216	54	14B
0005433434971	26216	55	14D
0005432655521	26216	56	14F
0005433434965	26216	57	14E
0005432985425	26216	58	14G
0005433754287	26216	59	15A
0005432051160	26216	60	14H
0005435982334	26216	61	15B
0005433754227	26216	62	15E
0005432985418	26216	63	15D
0005435982479	26216	64	15F
0005433754098	26216	65	15G
0005432049501	26216	66	16A
0005432869591	26216	67	16D
0005435982063	26216	68	16B
0005433434963	26216	69	16F
0005433754150	26216	70	16H
0005434731216	26216	71	16G
0005433754245	26216	72	17B
0005433766639	26216	73	17A
0005432985397	26216	74	17D
0005432985426	26216	75	17F
0005433434967	26216	76	17E
0005432049504	26216	77	17G
0005433754384	26216	78	17H
0005433754252	26216	79	18B
0005433434972	26216	80	18A
0005433754192	26216	81	18D
0005433754466	26216	82	18E
0005432985414	26216	83	18F
0005433754542	26216	84	19A
0005433764689	26216	85	18H
0005433434962	26216	86	19D
0005433754258	26216	87	19B
0005433754284	26216	88	19E
0005435982475	26216	89	19F
0005433434985	26216	90	19H
0005432655513	26216	91	19G
0005432655548	26216	92	20A
0005435982371	26216	93	20D
0005433754448	26216	94	20B
0005432985408	26216	95	20E
0005435982287	26216	96	20F
0005435982232	26216	97	20G
0005433754247	26216	98	21A
0005435982560	26216	99	21B
0005433754218	26216	100	21E
0005433754338	26216	101	21D
0005433434959	26216	102	21G
0005435982474	26216	103	21F
0005432049503	26216	104	22A
0005432049499	26216	105	21H
0005432985423	26216	106	22B
0005433766653	26216	107	22D
0005432985407	26216	108	22F
0005435982274	26216	109	22E
0005433434960	26216	110	22G
0005433434969	26216	111	22H
0005435982155	26216	112	23B
0005432985427	26216	113	23A
0005432985415	26216	114	23E
0005432655512	26216	115	23D
0005433754125	26216	116	23F
0005435982061	26216	117	23G
0005433434978	26216	118	23H
0005435982233	26216	119	24B
0005432985411	26216	120	24E
0005433434968	26216	121	24D
0005433754409	26216	122	24F
0005435982404	26216	123	24G
0005432985424	26216	124	25D
0005432985398	26216	125	24H
0005435982313	26216	126	25E
0005433434958	26216	127	27A
0005434731214	26216	128	25F
0005432985428	26216	129	27D
0005435982459	26216	130	27B
0005433434964	26216	131	27E
0005432985413	26216	132	27F
0005432049500	26216	133	27G
0005433754462	26216	134	28A
0005432051159	26216	135	27H
0005432985403	26216	136	28B
0005433434961	26216	137	28E
0005433754392	26216	138	28D
0005433754055	26216	139	28F
0005435982241	26216	140	28H
0005432655582	26216	141	29A
0005433754419	26216	142	29B
0005433434979	26216	143	29E
0005435982423	26216	144	29D
0005432985400	26216	145	29G
0005433754522	26216	146	29F
0005432985402	26216	147	29H
0005433754286	26216	148	30A
0005433754217	26216	149	30B
0005435982227	26216	150	30F
0005433766637	26216	151	30G
0005433434970	26216	152	31A
0005432985420	26216	153	31B
0005435982460	26216	154	31E
0005434731213	26216	155	31D
0005433434975	26216	156	31G
0005435982517	26216	157	31F
0005432869592	26216	158	31H
0005435982399	26216	159	32D
0005435982463	26216	160	32B
0005432985422	26216	161	32A
0005432869590	26216	162	32F
0005433754188	26216	163	32E
0005433434974	26216	164	32H
0005433754179	26216	165	32G
0005433754570	26216	166	33B
0005433754246	26216	167	33A
0005433434984	26216	168	33D
0005432985417	26216	169	33E
0005432051161	26216	170	33G
0005432985421	26216	171	33F
0005432655541	26216	172	33H
0005435982320	26216	173	34B
0005432985419	26216	174	34A
0005434731217	26216	175	34E
0005433434976	26216	176	34G
0005433754178	26216	177	34F
0005435982151	26216	178	35A
0005433434973	26216	179	34H
0005435982062	26216	180	35B
0005435982340	26216	181	35E
0005433754076	26216	182	35D
0005435982561	26216	183	35G
0005432985396	26216	184	35F
0005432985412	26216	185	36B
0005432655551	26216	186	36A
0005433434980	26216	187	36E
0005435982440	26216	188	36D
0005433754204	26216	189	36F
0005433754065	26216	190	36H
0005433754141	26216	191	36G
0005433754169	26216	192	37A
0005433754401	26216	193	37D
0005432655524	26216	194	37B
0005433754576	26216	195	37E
0005435982323	26216	196	37F
0005435982387	26216	197	37H
0005433754391	26216	198	37G
0005433754244	26216	199	38A
0005433754274	26216	200	38D
0005433754399	26216	201	38B
0005432985405	26216	202	38E
0005432655549	26216	203	38G
0005432985409	26216	204	38F
0005432655539	26216	205	38H
0005432985410	26216	206	39D
0005432985416	26216	207	39E
0005433151570	1484	1	1A
0005433151500	1484	2	1C
0005433151505	1484	3	2A
0005434375126	1484	4	1F
0005433151550	1484	5	2C
0005433151575	1484	6	2D
0005433764672	1484	7	2F
0005434375127	1484	8	3C
0005433151581	1484	9	3A
0005433151637	1484	10	3D
0005433151392	1484	11	3F
0005433151540	1484	12	4A
0005434375138	1484	13	4B
0005433151636	1484	14	4C
0005433151337	1484	15	4E
0005434375125	1484	16	4D
0005433151549	1484	17	5A
0005433151336	1484	18	4F
0005434375142	1484	19	5B
0005433151615	1484	20	5D
0005433151598	1484	21	5E
0005433764673	1484	22	6A
0005433151521	1484	23	6B
0005432267966	1484	24	6E
0005434375136	1484	25	7B
0005433764681	1484	26	7A
0005433151380	1484	27	7D
0005434375148	1484	28	7E
0005433151574	1484	29	8A
0005433151571	1484	30	8C
0005434375143	1484	31	8E
0005434375129	1484	32	9A
0005433764671	1484	33	9B
0005433931467	1484	34	9D
0005433461611	1484	35	9C
0005434029655	1484	36	9E
0005434375135	1484	37	10B
0005433151470	1484	38	10C
0005434375144	1484	39	11A
0005432267965	1484	40	11B
0005433151378	1484	41	12A
0005433151391	1484	42	12D
0005434375134	1484	43	12C
0005434375123	1484	44	12F
0005434375137	1484	45	13A
0005432267964	1484	46	13C
0005434375121	1484	47	13B
0005433151565	1484	48	13D
0005434375149	1484	49	13E
0005434375114	1484	50	14A
0005434375131	1484	51	14C
0005433151471	1484	52	14D
0005434375120	1484	53	14F
0005434375140	1484	54	14E
0005433151520	1484	55	15D
0005433931462	1484	56	15E
0005434375128	1484	57	15F
0005433931461	1484	58	16B
0005434375130	1484	59	16A
0005433151465	1484	60	16D
0005434375145	1484	61	16E
0005433151580	1484	62	17A
0005434375146	1484	63	17C
0005433151386	1484	64	17D
0005433764684	1484	65	17F
0005433151613	1484	66	17E
0005434375116	1484	67	18B
0005432267967	1484	68	18A
0005434375141	1484	69	18E
0005432267961	1484	70	18D
0005433764677	1484	71	18F
0005433151457	1484	72	19A
0005434375115	1484	73	19B
0005434375133	1484	74	19E
0005433460459	1484	75	20A
0005434375147	1484	76	20C
0005434375139	1484	77	20B
0005433764683	1484	78	20D
0005433764682	1484	79	21A
0005432267962	1484	80	20F
0005434375117	1484	81	21B
0005433461610	1484	82	21D
0005434375119	1484	83	21E
0005434375132	1484	84	22A
0005434375122	1484	85	21F
0005432267963	1484	86	22C
0005434375124	1484	87	22F
0005433151472	1484	88	22E
0005433151614	1484	89	23A
0005434029656	1484	90	23C
0005434375118	1484	91	23B
0005433931464	1484	92	23E
0005434374862	20143	1	1C
0005434374817	20143	2	1A
0005433764702	20143	3	2A
0005434374919	20143	4	2C
0005433151745	20143	5	2D
0005433151748	20143	6	3A
0005433151756	20143	7	3D
0005434374861	20143	8	3C
0005434374813	20143	9	4A
0005434374734	20143	10	4B
0005434374747	20143	11	4D
0005434374701	20143	12	4C
0005434374551	20143	13	4E
0005433151773	20143	14	4F
0005433931499	20143	15	5B
0005434374728	20143	16	5A
0005433151761	20143	17	5C
0005433151765	20143	18	5F
0005433151764	20143	19	5E
0005434374777	20143	20	6A
0005433151762	20143	21	6C
0005434374837	20143	22	6B
0005434374650	20143	23	6D
0005434374755	20143	24	6E
0005433151753	20143	25	7A
0005433151777	20143	26	7B
0005433151754	20143	27	7D
0005434374825	20143	28	7F
0005433151768	20143	29	8A
0005433151769	20143	30	8B
0005434374797	20143	31	8C
0005433151759	20143	32	8F
0005434374721	20143	33	9A
0005434374803	20143	34	9C
0005432056339	20143	35	9B
0005433151746	20143	36	9D
0005434374678	20143	37	9F
0005434374804	20143	38	10B
0005433151770	20143	39	10C
0005433151757	20143	40	10E
0005434374649	20143	41	10D
0005432056337	20143	42	11A
0005433931496	20143	43	11C
0005433151752	20143	44	11D
0005433931497	20143	45	11F
0005433151774	20143	46	12B
0005433151767	20143	47	12A
0005434374842	20143	48	12D
0005433151755	20143	49	12C
0005434374718	20143	50	12E
0005434374659	20143	51	13A
0005434374698	20143	52	13B
0005434374855	20143	53	13E
0005433151776	20143	54	13F
0005434374722	20143	55	14B
0005434374717	20143	56	14D
0005434374757	20143	57	14E
0005433151766	20143	58	15B
0005433151749	20143	59	15A
0005433151751	20143	60	15C
0005434029682	20143	61	15E
0005434374756	20143	62	16A
0005433151758	20143	63	16B
0005433151771	20143	64	16C
0005433151750	20143	65	16E
0005434374802	20143	66	17D
0005433151775	20143	67	17C
0005434374697	20143	68	17F
0005433151760	20143	69	18B
0005434374836	20143	70	18C
0005433151763	20143	71	18E
0005434374720	20143	72	19A
0005434374709	20143	73	19B
0005434374657	20143	74	19D
0005434029683	20143	75	19F
0005433151744	20143	76	19E
0005434029684	20143	77	20C
0005434374737	20143	78	20B
0005434374696	20143	79	20E
0005433931498	20143	80	20F
0005433151772	20143	81	21A
0005434374735	20143	82	21C
0005434374843	20143	83	21B
0005432056338	20143	84	21D
0005434374727	20143	85	21E
0005434374824	20143	86	21F
0005433151747	20143	87	22B
0005434374844	20143	88	22C
0005433764701	20143	89	22D
0005434374745	20143	90	23A
0005434374798	20143	91	23B
0005434374723	20143	92	23C
0005434374677	20143	93	23F
0005434374700	20143	94	23E
0005432424945	531	1	1A
0005432424948	531	2	2D
0005432282934	531	3	2F
0005432424954	531	4	3D
0005432424951	531	5	5A
0005432424950	531	6	5F
0005432424937	531	7	6D
0005432424961	531	8	7C
0005432424934	531	9	8A
0005432424933	531	10	8B
0005432424935	531	11	8D
0005432424919	531	12	8C
0005432424927	531	13	8F
0005432424949	531	14	9B
0005432424944	531	15	9A
0005432424930	531	16	9D
0005432424952	531	17	9E
0005432424942	531	18	10A
0005432282939	531	19	9F
0005432424932	531	20	10E
0005432424953	531	21	10F
0005432424959	531	22	11E
0005432424924	531	23	11F
0005432424955	531	24	13B
0005432282940	531	25	13D
0005432282938	531	26	13E
0005432424928	531	27	13F
0005432424938	531	28	14D
0005432282936	531	29	15C
0005432424915	531	30	16D
0005432424936	531	31	16F
0005432424931	531	32	17B
0005432282937	531	33	17C
0005432424916	531	34	17D
0005432424921	531	35	18B
0005432424918	531	36	18E
0005432424929	531	37	20C
0005432424920	531	38	20E
0005432424941	531	39	20D
0005432424940	531	40	20F
0005432424957	531	41	22C
0005432424922	531	42	22F
0005432424939	531	43	23A
0005432424925	531	44	24C
0005432424923	531	45	25F
0005432424956	531	46	27B
0005432424946	531	47	27E
0005432282935	531	48	28C
0005432424917	531	49	28E
0005432424947	531	50	29B
0005432424960	531	51	29E
0005432424943	531	52	29F
0005432424958	531	53	30E
0005432424926	531	54	31D
0005432302368	12946	1	2A
0005432302373	12946	2	11F
0005432302369	12946	3	12B
0005432302371	12946	4	17E
0005432302370	12946	5	21E
0005432302372	12946	6	26D
0005432424407	12828	1	1A
0005432424359	12828	2	1D
0005432424429	12828	3	2F
0005432424294	12828	4	3A
0005432424483	12828	5	3F
0005432424506	12828	6	4D
0005432424433	12828	7	4F
0005432424309	12828	8	5D
0005432424377	12828	9	5F
0005432424405	12828	10	8A
0005432424445	12828	11	8C
0005432424490	12828	12	8D
0005432424261	12828	13	9C
0005432424273	12828	14	9E
0005432424293	12828	15	10A
0005432424328	12828	16	10D
0005432424406	12828	17	11D
0005432424446	12828	18	12F
0005432424456	12828	19	14A
0005432424505	12828	20	15C
0005432424478	12828	21	15D
0005432424313	12828	22	15E
0005432424507	12828	23	16A
0005432424511	12828	24	16B
0005432424484	12828	25	17D
0005432424500	12828	26	18B
0005432424453	12828	27	18C
0005432424349	12828	28	18E
0005432424477	12828	29	21A
0005432424501	12828	30	21B
0005432424274	12828	31	21F
0005432424344	12828	32	22F
0005432424497	12828	33	23B
0005432424513	12828	34	24B
0005432424516	12828	35	24D
0005432424479	12828	36	25E
0005432424461	12828	37	25D
0005432424426	12828	38	25F
0005432424400	12828	39	26C
0005432424376	12828	40	27D
0005432424231	12828	41	27E
0005432424275	12828	42	28A
0005432424452	12828	43	28F
0005432424415	12828	44	29D
0005432424414	12828	45	29E
0005432424481	12828	46	31B
0005432424312	12828	47	31A
0005434024398	455	1	1A
0005434024397	455	2	1C
0005434024439	455	3	1G
0005434024374	455	4	2B
0005433057863	455	5	2A
0005433058188	455	6	2F
0005434024407	455	7	2G
0005433057775	455	8	2H
0005434735702	455	9	3C
0005434024403	455	10	3F
0005433057972	455	11	4A
0005433929619	455	12	3H
0005433684421	455	13	4B
0005434024396	455	14	4F
0005432235715	455	15	5A
0005434024377	455	16	9A
0005434024406	455	17	9B
0005434024418	455	18	9G
0005434028323	455	19	11A
0005433057976	455	20	11D
0005434024423	455	21	11F
0005434024412	455	22	11E
0005434024424	455	23	12A
0005432235719	455	24	12B
0005434024413	455	25	12F
0005434024431	455	26	12H
0005433929616	455	27	13A
0005433058082	455	28	13D
0005433058060	455	29	14A
0005432235714	455	30	14D
0005434024404	455	31	14G
0005434024387	455	32	14F
0005434024441	455	33	15B
0005434024379	455	34	15E
0005434024414	455	35	16B
0005433057926	455	36	16E
0005433057925	455	37	16G
0005434024410	455	38	16H
0005434024394	455	39	17D
0005434032068	455	40	17B
0005434024389	455	41	17G
0005434024434	455	42	17H
0005434024436	455	43	18D
0005434024425	455	44	18E
0005434024393	455	45	19B
0005433057839	455	46	19A
0005434032067	455	47	19G
0005434024405	455	48	19H
0005434024380	455	49	20D
0005434024376	455	50	20E
0005434029679	455	51	20F
0005434024420	455	52	21A
0005433058043	455	53	20H
0005434024433	455	54	21H
0005434024409	455	55	22A
0005434024388	455	56	22G
0005434024430	455	57	23A
0005433057864	455	58	22H
0005434024422	455	59	23B
0005434032069	455	60	23F
0005434024417	455	61	23G
0005432235717	455	62	23H
0005434024408	455	63	24B
0005433057960	455	64	24D
0005432235713	455	65	24F
0005434024415	455	66	24G
0005434024382	455	67	25E
0005434735668	455	68	27B
0005433929603	455	69	27E
0005432235712	455	70	27D
0005434024419	455	71	27G
0005434024440	455	72	28A
0005434024391	455	73	27H
0005434024432	455	74	28E
0005434024421	455	75	28F
0005434032066	455	76	28G
0005433057975	455	77	29B
0005434024392	455	78	29E
0005434024378	455	79	29F
0005432045631	455	80	29G
0005434024402	455	81	30B
0005434024383	455	82	30A
0005434024381	455	83	30G
0005434735690	455	84	30H
0005433929617	455	85	31B
0005433058189	455	86	31A
0005432235718	455	87	31E
0005433058004	455	88	32E
0005434024401	455	89	32D
0005432235716	455	90	32F
0005434024411	455	91	33A
0005434024386	455	92	32H
0005434024429	455	93	33D
0005433057927	455	94	33B
0005434735667	455	95	33F
0005433058027	455	96	33H
0005433058116	455	97	34A
0005434024400	455	98	34D
0005433057837	455	99	34B
0005433058028	455	100	34E
0005434029680	455	101	34F
0005432045632	455	102	34H
0005434029681	455	103	35B
0005434024435	455	104	35A
0005434024438	455	105	35E
0005433058019	455	106	35H
0005434024375	455	107	35F
0005434024416	455	108	36D
0005433057971	455	109	36F
0005434735687	455	110	36E
0005434028322	455	111	36G
0005434024395	455	112	37A
0005434024390	455	113	36H
0005433057946	455	114	37B
0005434024428	455	115	37F
0005434024399	455	116	37H
0005434024437	455	117	38A
0005434024384	455	118	38E
0005434024427	455	119	38H
0005434024385	455	120	39D
0005433058020	455	121	39F
0005434024426	455	122	39E
0005434023710	12659	1	1C
0005434023563	12659	2	1F
0005434735744	12659	3	1H
0005433058316	12659	4	1G
0005433058283	12659	5	2A
0005434023768	12659	6	2B
0005433058282	12659	7	2F
0005434032032	12659	8	2G
0005434024068	12659	9	2H
0005433058289	12659	10	3B
0005434735743	12659	11	3H
0005434023733	12659	12	3G
0005434023855	12659	13	4A
0005434023817	12659	14	4B
0005433058292	12659	15	4G
0005434023859	12659	16	4F
0005434023699	12659	17	5A
0005433058308	12659	18	4H
0005434023776	12659	19	5B
0005433058286	12659	20	5C
0005434023923	12659	21	9A
0005434023792	12659	22	9B
0005434023321	12659	23	9G
0005434735746	12659	24	11B
0005434023734	12659	25	11F
0005434024014	12659	26	12B
0005434023486	12659	27	12E
0005434023775	12659	28	12F
0005433058293	12659	29	12G
0005432157511	12659	30	13A
0005434024006	12659	31	13D
0005434029655	12659	32	13B
0005433058285	12659	33	13E
0005433058300	12659	34	13F
0005434032048	12659	35	14A
0005434023780	12659	36	14B
0005434023854	12659	37	14F
0005434023939	12659	38	14E
0005433929655	12659	39	14H
0005434023750	12659	40	14G
0005434024163	12659	41	15D
0005433058284	12659	42	15E
0005434023875	12659	43	15F
0005434023696	12659	44	15H
0005433058278	12659	45	15G
0005434023933	12659	46	16A
0005434023473	12659	47	16B
0005433058298	12659	48	16G
0005434023695	12659	49	16F
0005434023870	12659	50	17A
0005434023697	12659	51	17D
0005434023707	12659	52	17B
0005433058294	12659	53	17F
0005433058297	12659	54	17G
0005434023706	12659	55	18B
0005433058295	12659	56	18F
0005433058302	12659	57	18H
0005434023454	12659	58	19B
0005434023812	12659	59	19F
0005433684443	12659	60	19G
0005433058281	12659	61	20A
0005434023655	12659	62	19H
0005434023907	12659	63	20B
0005434024069	12659	64	20E
0005433058277	12659	65	20G
0005434029656	12659	66	20H
0005433058290	12659	67	21D
0005433058318	12659	68	21E
0005434023864	12659	69	21G
0005434735742	12659	70	22D
0005433058280	12659	71	22B
0005433058313	12659	72	22F
0005433058312	12659	73	22E
0005432157512	12659	74	22G
0005434023861	12659	75	23B
0005434023704	12659	76	23A
0005434023801	12659	77	23D
0005434023672	12659	78	23F
0005434023813	12659	79	23E
0005434032049	12659	80	24D
0005433058303	12659	81	24F
0005434023745	12659	82	25D
0005434023472	12659	83	25E
0005434024019	12659	84	27A
0005434023863	12659	85	27B
0005433058296	12659	86	27E
0005434023654	12659	87	27F
0005433058314	12659	88	27G
0005433058299	12659	89	28A
0005433058315	12659	90	27H
0005433058291	12659	91	28B
0005434023860	12659	92	28E
0005433929657	12659	93	28G
0005433058287	12659	94	29B
0005433058310	12659	95	29E
0005434024005	12659	96	29G
0005434735747	12659	97	29H
0005433058288	12659	98	30B
0005433058301	12659	99	30A
0005433929656	12659	100	30E
0005434028300	12659	101	30F
0005432156411	12659	102	31A
0005434024004	12659	103	30H
0005434023619	12659	104	31B
0005434023541	12659	105	31G
0005434023791	12659	106	31F
0005433058309	12659	107	32B
0005434023705	12659	108	32E
0005434023751	12659	109	32F
0005434028301	12659	110	32H
0005432156413	12659	111	33A
0005432156412	12659	112	33B
0005433929654	12659	113	33D
0005433058306	12659	114	33H
0005434023767	12659	115	34E
0005434023779	12659	116	34G
0005434024216	12659	117	34F
0005433058311	12659	118	34H
0005432156414	12659	119	35D
0005432156410	12659	120	35G
0005434023567	12659	121	35F
0005434023811	12659	122	35H
0005434023862	12659	123	36E
0005434024067	12659	124	36F
0005434023938	12659	125	37A
0005434023922	12659	126	37E
0005433684442	12659	127	37F
0005433058279	12659	128	38D
0005434735745	12659	129	38E
0005433058307	12659	130	38G
0005434023669	12659	131	38F
0005433058305	12659	132	38H
0005433058304	12659	133	39E
0005432156415	12659	134	39D
0005433058317	12659	135	39F
0005433036329	2148	1	1A
0005433924316	2148	2	1B
0005433036477	2148	3	1F
0005433924280	2148	4	1C
0005433931497	2148	5	2A
0005433036349	2148	6	1H
0005433036429	2148	7	2B
0005433924263	2148	8	2F
0005433924304	2148	9	2H
0005433924288	2148	10	2G
0005433924275	2148	11	3A
0005433036510	2148	12	3C
0005433036472	2148	13	3B
0005433924277	2148	14	3F
0005434028301	2148	15	4B
0005433924290	2148	16	4F
0005433036524	2148	17	4C
0005433924311	2148	18	5A
0005433924327	2148	19	4H
0005433924317	2148	20	5B
0005433924286	2148	21	5F
0005433924320	2148	22	5C
0005433924243	2148	23	5G
0005433924297	2148	24	9A
0005433924261	2148	25	5H
0005433036336	2148	26	9B
0005433924239	2148	27	9H
0005433924260	2148	28	11A
0005433036301	2148	29	11B
0005433924334	2148	30	11E
0005433036443	2148	31	11D
0005433924244	2148	32	11G
0005433036333	2148	33	11F
0005433924309	2148	34	12A
0005433036393	2148	35	11H
0005433036326	2148	36	12B
0005433924266	2148	37	12E
0005433924255	2148	38	12F
0005433924256	2148	39	12H
0005433924265	2148	40	12G
0005433924273	2148	41	13B
0005433924259	2148	42	13A
0005432749783	2148	43	13D
0005433924318	2148	44	13E
0005433036509	2148	45	13H
0005432231677	2148	46	14B
0005433924332	2148	47	14E
0005433036230	2148	48	14D
0005432231669	2148	49	14G
0005433924310	2148	50	14F
0005433924270	2148	51	15A
0005433036175	2148	52	14H
0005433924258	2148	53	15B
0005433924330	2148	54	15E
0005433924298	2148	55	15D
0005433924329	2148	56	15F
0005433036255	2148	57	15H
0005433924335	2148	58	16D
0005433924247	2148	59	16B
0005433924246	2148	60	16E
0005433924306	2148	61	16G
0005433036426	2148	62	16H
0005433924242	2148	63	17B
0005433924299	2148	64	17A
0005433036323	2148	65	17F
0005434028300	2148	66	17E
0005433924325	2148	67	17D
0005433036278	2148	68	17G
0005433924319	2148	69	17H
0005433036410	2148	70	18B
0005432231672	2148	71	18A
0005433924303	2148	72	18D
0005433036442	2148	73	18G
0005432231670	2148	74	18H
0005433036413	2148	75	19A
0005433924251	2148	76	19E
0005433036473	2148	77	19G
0005433036478	2148	78	19F
0005433924284	2148	79	19H
0005433036229	2148	80	20D
0005433924323	2148	81	20B
0005433929654	2148	82	20E
0005433036414	2148	83	20G
0005433036268	2148	84	20F
0005433924269	2148	85	21A
0005433036471	2148	86	21D
0005433924248	2148	87	21F
0005433036448	2148	88	21E
0005433924315	2148	89	21H
0005433924292	2148	90	21G
0005432749782	2148	91	22B
0005433924301	2148	92	22A
0005432231675	2148	93	22F
0005433924291	2148	94	22E
0005433924262	2148	95	22G
0005433924249	2148	96	23A
0005433924279	2148	97	22H
0005433924278	2148	98	23B
0005433924321	2148	99	23D
0005433924281	2148	100	23E
0005433924264	2148	101	24A
0005433924296	2148	102	23H
0005433924276	2148	103	24B
0005432231671	2148	104	24E
0005433929656	2148	105	24F
0005433036427	2148	106	24G
0005433924302	2148	107	25D
0005433924289	2148	108	24H
0005433924252	2148	109	25E
0005433036627	2148	110	25F
0005433924254	2148	111	27E
0005433924312	2148	112	27G
0005432231673	2148	113	28A
0005433924295	2148	114	27H
0005433036226	2148	115	28E
0005433924257	2148	116	28D
0005433036529	2148	117	28F
0005433924314	2148	118	28G
0005433924328	2148	119	29A
0005433929657	2148	120	28H
0005433924274	2148	121	29E
0005433924267	2148	122	29D
0005433036523	2148	123	29G
0005433924294	2148	124	29F
0005432044554	2148	125	29H
0005433036554	2148	126	30A
0005433924307	2148	127	30D
0005433036476	2148	128	30E
0005432231674	2148	129	30G
0005433924285	2148	130	30F
0005433924300	2148	131	31A
0005433924283	2148	132	30H
0005433924322	2148	133	31B
0005433036277	2148	134	31F
0005433036328	2148	135	31G
0005433036628	2148	136	32A
0005433036244	2148	137	31H
0005433931499	2148	138	32B
0005433924241	2148	139	32E
0005433924293	2148	140	32D
0005433931496	2148	141	32F
0005433924250	2148	142	32H
0005433036245	2148	143	32G
0005433036441	2148	144	33A
0005433036122	2148	145	33B
0005433924272	2148	146	33E
0005433036327	2148	147	33D
0005433036512	2148	148	33H
0005433931498	2148	149	33G
0005432749792	2148	150	34B
0005433924333	2148	151	34A
0005433924331	2148	152	34E
0005433924253	2148	153	34G
0005433036377	2148	154	34H
0005433924287	2148	155	35B
0005433924271	2148	156	35A
0005433924268	2148	157	35D
0005432044553	2148	158	35G
0005433036392	2148	159	35F
0005433875393	2148	160	35H
0005433924240	2148	161	36F
0005433036481	2148	162	36E
0005433924313	2148	163	37A
0005433924308	2148	164	36H
0005433036325	2148	165	37D
0005433924245	2148	166	37B
0005433036419	2148	167	37F
0005433036447	2148	168	37H
0005433924326	2148	169	37G
0005433924282	2148	170	38A
0005433036513	2148	171	38D
0005432044552	2148	172	38B
0005432231678	2148	173	38E
0005433924324	2148	174	38G
0005433924305	2148	175	38F
0005433036446	2148	176	38H
0005433036409	2148	177	39E
0005432231676	2148	178	39D
0005433929655	2148	179	39F
0005433923329	24098	1	1A
0005433923268	24098	2	1C
0005433923440	24098	3	1B
0005433923327	24098	4	1F
0005433036855	24098	5	1G
0005432207688	24098	6	2B
0005433036818	24098	7	2F
0005433036827	24098	8	2C
0005433923658	24098	9	3B
0005433923409	24098	10	3A
0005433923596	24098	11	3C
0005433923604	24098	12	3G
0005433923752	24098	13	4B
0005433923441	24098	14	4F
0005433923568	24098	15	4C
0005433923574	24098	16	4G
0005433923115	24098	17	4H
0005433036819	24098	18	5B
0005433923211	24098	19	5A
0005433923380	24098	20	5F
0005433923605	24098	21	5C
0005433923675	24098	22	5G
0005433036851	24098	23	9B
0005433923304	24098	24	9A
0005433036848	24098	25	9H
0005433922910	24098	26	9G
0005433036867	24098	27	11B
0005432206254	24098	28	11E
0005433036856	24098	29	11D
0005433036847	24098	30	11F
0005433036837	24098	31	11G
0005433923310	24098	32	12A
0005433924004	24098	33	11H
0005433923228	24098	34	12B
0005433036849	24098	35	12D
0005433036834	24098	36	12G
0005433923573	24098	37	12F
0005433929622	24098	38	12H
0005433923245	24098	39	13A
0005433923761	24098	40	13D
0005433923512	24098	41	13E
0005433922943	24098	42	13G
0005433036821	24098	43	13F
0005433923371	24098	44	14A
0005433036835	24098	45	13H
0005433036841	24098	46	14B
0005433036820	24098	47	14D
0005433923503	24098	48	14F
0005432749809	24098	49	14E
0005433923326	24098	50	14G
0005433923483	24098	51	15A
0005433036828	24098	52	15D
0005433931474	24098	53	15E
0005433923270	24098	54	15G
0005433036824	24098	55	15H
0005433036844	24098	56	16A
0005433036860	24098	57	16B
0005433923008	24098	58	16G
0005433923266	24098	59	16F
0005433924020	24098	60	16H
0005433036842	24098	61	17A
0005432206253	24098	62	17D
0005433036865	24098	63	17B
0005433923717	24098	64	17E
0005433923876	24098	65	17F
0005433923271	24098	66	17H
0005433923697	24098	67	18B
0005433036832	24098	68	18A
0005433923298	24098	69	18F
0005433036858	24098	70	18E
0005433923183	24098	71	18H
0005433036852	24098	72	18G
0005433036853	24098	73	19B
0005433931473	24098	74	19A
0005433036864	24098	75	19D
0005433923530	24098	76	19F
0005433923933	24098	77	19G
0005433923631	24098	78	20A
0005433923903	24098	79	20B
0005433923623	24098	80	20D
0005433923269	24098	81	20F
0005433923311	24098	82	20E
0005433923484	24098	83	20G
0005433923904	24098	84	20H
0005433923499	24098	85	21D
0005432207687	24098	86	21B
0005433931472	24098	87	21H
0005433036862	24098	88	22B
0005433036857	24098	89	22A
0005433036823	24098	90	22F
0005433923575	24098	91	22G
0005433922909	24098	92	22H
0005433929614	24098	93	23B
0005433923720	24098	94	23E
0005434028326	24098	95	23D
0005433929620	24098	96	23F
0005433923521	24098	97	23G
0005433036833	24098	98	24A
0005433923233	24098	99	23H
0005433923328	24098	100	24B
0005433036866	24098	101	24E
0005432206256	24098	102	24F
0005433923751	24098	103	24H
0005433036861	24098	104	24G
0005432749808	24098	105	25D
0005433923159	24098	106	25E
0005433923007	24098	107	27A
0005433923606	24098	108	25F
0005432206258	24098	109	27D
0005433923740	24098	110	27G
0005432749807	24098	111	27F
0005433923727	24098	112	27H
0005433922972	24098	113	28A
0005433929623	24098	114	28B
0005433923232	24098	115	28E
0005433923828	24098	116	28G
0005433923831	24098	117	29A
0005433923212	24098	118	28H
0005433036854	24098	119	29D
0005433923433	24098	120	29B
0005433036817	24098	121	29G
0005433923624	24098	122	29F
0005433923567	24098	123	29H
0005433923712	24098	124	30A
0005433923489	24098	125	30E
0005433036814	24098	126	30G
0005433923603	24098	127	30H
0005433923500	24098	128	31F
0005433036830	24098	129	31E
0005433036836	24098	130	31G
0005433923760	24098	131	32A
0005434028327	24098	132	31H
0005433036840	24098	133	32D
0005433923309	24098	134	32B
0005433923674	24098	135	32E
0005433923365	24098	136	32G
0005432206257	24098	137	32F
0005433923869	24098	138	33B
0005433923576	24098	139	33D
0005433036825	24098	140	33E
0005434028325	24098	141	33F
0005432206255	24098	142	33H
0005433036831	24098	143	33G
0005433036845	24098	144	34A
0005433923875	24098	145	34D
0005433923419	24098	146	34E
0005433036815	24098	147	34G
0005433923515	24098	148	34F
0005433923934	24098	149	34H
0005434028324	24098	150	35D
0005433923325	24098	151	35B
0005433036829	24098	152	35F
0005433923726	24098	153	35E
0005433036826	24098	154	36A
0005433036816	24098	155	35H
0005433923528	24098	156	36B
0005433923739	24098	157	36D
0005433036843	24098	158	36F
0005433923562	24098	159	36E
0005433036863	24098	160	37A
0005433929615	24098	161	37D
0005433923759	24098	162	37E
0005432207689	24098	163	37H
0005433923379	24098	164	37G
0005433036859	24098	165	38B
0005433923116	24098	166	38A
0005433036846	24098	167	38E
0005433036839	24098	168	38F
0005433036838	24098	169	38H
0005433929621	24098	170	38G
0005433036850	24098	171	39E
0005433036822	24098	172	39D
0005433923267	24098	173	39F
0005434302503	289	1	1G
0005434726756	289	2	1D
0005434032038	289	3	1K
0005434726666	289	4	1H
0005433234555	289	5	2C
0005434551783	289	6	2G
0005434726739	289	7	2D
0005433181215	289	8	3G
0005434726751	289	9	3C
0005434726743	289	10	3K
0005434551775	289	11	3H
0005434726706	289	12	4C
0005434726780	289	13	4A
0005433181065	289	14	4G
0005433131701	289	15	4D
0005434726771	289	16	4K
0005434551785	289	17	5C
0005434731211	289	18	5A
0005434726763	289	19	5G
0005434726729	289	20	5D
0005434551774	289	21	5H
0005433766650	289	22	11D
0005434726766	289	23	11C
0005434726727	289	24	11F
0005434726717	289	25	11E
0005433234056	289	26	11K
0005434726758	289	27	11H
0005434726725	289	28	12C
0005434726769	289	29	12A
0005434551789	289	30	12E
0005435142716	289	31	12D
0005435142720	289	32	12F
0005433766652	289	33	12K
0005434551822	289	34	12H
0005433289822	289	35	13D
0005433181072	289	36	13C
0005433131705	289	37	13F
0005434726730	289	38	13E
0005434551805	289	39	13H
0005434726670	289	40	13G
0005433234201	289	41	13K
0005433181234	289	42	14D
0005434726721	289	43	14C
0005433234255	289	44	14F
0005433234275	289	45	14E
0005433181182	289	46	14K
0005433113535	289	47	15C
0005434726678	289	48	15A
0005434726731	289	49	15E
0005434726736	289	50	15D
0005433181167	289	51	15G
0005433126852	289	52	15F
0005434726682	289	53	15K
0005432277940	289	54	15H
0005435142719	289	55	16C
0005432277950	289	56	16A
0005434726757	289	57	16F
0005433234554	289	58	16E
0005434731210	289	59	16G
0005434551768	289	60	17C
0005434032028	289	61	17A
0005434726712	289	62	16K
0005434726722	289	63	17E
0005434726693	289	64	17G
0005434551788	289	65	17F
0005435142715	289	66	17K
0005434726667	289	67	17H
0005434726719	289	68	18C
0005434551807	289	69	18A
0005433181142	289	70	18E
0005434726704	289	71	18G
0005434032039	289	72	18F
0005434726710	289	73	18H
0005433234406	289	74	19A
0005433234194	289	75	18K
0005433234256	289	76	19D
0005434726752	289	77	19C
0005435142711	289	78	19B
0005434726709	289	79	19F
0005434551815	289	80	19E
0005434726770	289	81	19J
0005433234195	289	82	19H
0005432277951	289	83	19G
0005434302502	289	84	19K
0005433234358	289	85	20C
0005434032020	289	86	20A
0005434551804	289	87	20D
0005433234350	289	88	20G
0005434726691	289	89	20F
0005434731208	289	90	20J
0005433181160	289	91	20K
0005434302505	289	92	21F
0005433234189	289	93	21E
0005434726700	289	94	21J
0005434726777	289	95	21G
0005433181050	289	96	22A
0005433234137	289	97	21K
0005433234114	289	98	22C
0005433234301	289	99	22E
0005434551796	289	100	22D
0005432277945	289	101	22H
0005434726755	289	102	22G
0005433234490	289	103	22F
0005433234156	289	104	22K
0005434726695	289	105	22J
0005434551817	289	106	23B
0005432277949	289	107	23A
0005434551818	289	108	23D
0005434726768	289	109	23C
0005433234277	289	110	23G
0005433289848	289	111	23E
0005434726745	289	112	23H
0005432277942	289	113	23K
0005433234340	289	114	24F
0005433126854	289	115	24E
0005433234216	289	116	25A
0005432277944	289	117	24G
0005434726734	289	118	25D
0005434735739	289	119	25C
0005434726669	289	120	25F
0005434726778	289	121	25E
0005433234403	289	122	25H
0005433234274	289	123	25G
0005433181133	289	124	26A
0005434551813	289	125	25K
0005432277946	289	126	26B
0005433766651	289	127	26E
0005434726748	289	128	26D
0005434726697	289	129	26C
0005433234118	289	130	26G
0005434726672	289	131	26F
0005434726659	289	132	26J
0005433289866	289	133	27A
0005434726708	289	134	26K
0005434726713	289	135	27C
0005434726688	289	136	27B
0005433181168	289	137	27F
0005434032034	289	138	27E
0005434726685	289	139	27D
0005434551806	289	140	27H
0005433234556	289	141	27K
0005435142714	289	142	27J
0005435142721	289	143	28A
0005434551800	289	144	28E
0005434302875	289	145	28C
0005434726703	289	146	28G
0005434726663	289	147	28J
0005433181080	289	148	28H
0005433181071	289	149	29A
0005434726698	289	150	28K
0005433131696	289	151	29D
0005434726750	289	152	29C
0005433181139	289	153	29B
0005434302504	289	154	29F
0005434726726	289	155	29J
0005434726728	289	156	29H
0005433126853	289	157	29G
0005433234388	289	158	30A
0005433234399	289	159	29K
0005433234300	289	160	30C
0005434726720	289	161	30B
0005433181206	289	162	30G
0005433234119	289	163	30K
0005434726738	289	164	30J
0005434726776	289	165	30H
0005433234168	289	166	31D
0005434731209	289	167	31C
0005433234160	289	168	31B
0005434551799	289	169	31F
0005433234319	289	170	31E
0005435142710	289	171	31H
0005434551816	289	172	31G
0005432277953	289	173	31K
0005434551781	289	174	31J
0005433234068	289	175	32C
0005434726723	289	176	32B
0005434726683	289	177	32A
0005433766625	289	178	32E
0005434551776	289	179	32D
0005434551802	289	180	32G
0005434726772	289	181	32F
0005434735740	289	182	32J
0005434735741	289	183	32H
0005434726680	289	184	33A
0005434726664	289	185	32K
0005434726747	289	186	33D
0005434726674	289	187	33C
0005435142722	289	188	33F
0005434726702	289	189	33E
0005434726716	289	190	33H
0005434551790	289	191	33K
0005434551787	289	192	33J
0005434726735	289	193	34C
0005434726759	289	194	34B
0005434726668	289	195	34A
0005432277941	289	196	34G
0005434551823	289	197	34F
0005433234232	289	198	35B
0005433289867	289	199	35A
0005433234036	289	200	34K
0005434735737	289	201	35D
0005434726724	289	202	35C
0005434551797	289	203	35F
0005434726718	289	204	35E
0005434735736	289	205	35H
0005433181158	289	206	36A
0005434551819	289	207	35K
0005434551801	289	208	35J
0005434551812	289	209	36C
0005433234511	289	210	36B
0005434726694	289	211	36E
0005434726775	289	212	36G
0005434032021	289	213	36F
0005434551778	289	214	36K
0005434726765	289	215	36J
0005434551810	289	216	37C
0005433181207	289	217	37B
0005434551793	289	218	37A
0005434551820	289	219	37D
0005433289868	289	220	37F
0005433234228	289	221	37E
0005433181183	289	222	38A
0005433234281	289	223	37J
0005434726673	289	224	38C
0005434726737	289	225	38B
0005434726658	289	226	38J
0005434726705	289	227	38H
0005433233854	289	228	39B
0005434735738	289	229	39D
0005432277947	289	230	39C
0005433181049	289	231	39E
0005434551769	289	232	39H
0005434726767	289	233	39G
0005434551811	289	234	40A
0005434551777	289	235	39K
0005434726671	289	236	39J
0005434726707	289	237	40C
0005434726689	289	238	40B
0005434726764	289	239	40E
0005433126829	289	240	40D
0005434726665	289	241	40G
0005434726676	289	242	40F
0005434726741	289	243	40J
0005434551791	289	244	40H
0005434551808	289	245	41B
0005434551794	289	246	40K
0005433181151	289	247	41D
0005433181169	289	248	41C
0005433234120	289	249	41F
0005434726696	289	250	41E
0005433181147	289	251	41H
0005434032019	289	252	41G
0005435142723	289	253	42A
0005435142713	289	254	41K
0005434726761	289	255	42C
0005435142712	289	256	42E
0005433234136	289	257	42D
0005435142717	289	258	42G
0005434551786	289	259	42F
0005434726733	289	260	42J
0005433234422	289	261	42H
0005434032035	289	262	43B
0005434551773	289	263	43A
0005433234191	289	264	43D
0005434551779	289	265	43C
0005434726660	289	266	43F
0005432277952	289	267	43E
0005434726662	289	268	43H
0005432277948	289	269	43G
0005433181225	289	270	43K
0005434726690	289	271	43J
0005434551782	289	272	44C
0005434726773	289	273	44B
0005434551770	289	274	44A
0005433234086	289	275	44E
0005434551821	289	276	44D
0005434726661	289	277	44G
0005434551798	289	278	44F
0005434726714	289	279	44J
0005434726740	289	280	44H
0005433234190	289	281	45A
0005434726711	289	282	44K
0005434551814	289	283	45C
0005433131702	289	284	45B
0005433234104	289	285	45F
0005433181214	289	286	45D
0005434726699	289	287	45J
0005434726753	289	288	45H
0005434726701	289	289	45G
0005434726760	289	290	46A
0005434726675	289	291	45K
0005433111506	289	292	46B
0005434726732	289	293	46E
0005433233855	289	294	46D
0005434726692	289	295	46C
0005434726715	289	296	46G
0005434726746	289	297	46F
0005433234394	289	298	46J
0005434551771	289	299	46H
0005434726749	289	300	47A
0005434726774	289	301	46K
0005433234393	289	302	47E
0005434726742	289	303	47D
0005435142718	289	304	47G
0005434551772	289	305	47F
0005434731212	289	306	47K
0005434726684	289	307	47H
0005433234280	289	308	48D
0005434726681	289	309	48C
0005434551792	289	310	48A
0005434302876	289	311	48E
0005433234127	289	312	48H
0005434551803	289	313	48G
0005434726686	289	314	49A
0005434726754	289	315	48K
0005434726687	289	316	49E
0005433181226	289	317	49C
0005434726744	289	318	49G
0005433289874	289	319	49F
0005434551784	289	320	49H
0005432277943	289	321	50C
0005433289850	289	322	50A
0005434551809	289	323	50D
0005434726779	289	324	50H
0005434726677	289	325	50G
0005434551780	289	326	51D
0005434726762	289	327	50K
0005434726679	289	328	51F
0005434551795	289	329	51G
0005434725495	9819	1	1C
0005434725494	9819	2	1A
0005434725707	9819	3	1G
0005434725421	9819	4	1D
0005433234847	9819	5	2A
0005434725189	9819	6	1K
0005434731175	9819	7	1H
0005433126893	9819	8	2C
0005434551043	9819	9	2H
0005433234821	9819	10	2G
0005434551153	9819	11	2D
0005434725496	9819	12	3A
0005433234837	9819	13	2K
0005433234870	9819	14	3D
0005433234884	9819	15	3C
0005435142624	9819	16	3H
0005434725865	9819	17	3G
0005434726091	9819	18	4A
0005434725211	9819	19	3K
0005434302465	9819	20	4G
0005434551536	9819	21	4C
0005434725823	9819	22	4K
0005433181366	9819	23	4H
0005433234827	9819	24	5C
0005434725971	9819	25	5H
0005434725849	9819	26	5G
0005434551436	9819	27	5D
0005433113559	9819	28	11A
0005434725351	9819	29	5K
0005433234872	9819	30	11D
0005434725980	9819	31	11C
0005434551469	9819	32	11F
0005433181349	9819	33	11E
0005434726052	9819	34	11H
0005435142560	9819	35	11G
0005434725806	9819	36	12C
0005433181347	9819	37	12A
0005434725188	9819	38	11K
0005433234869	9819	39	12E
0005434725750	9819	40	12D
0005433234871	9819	41	12G
0005434725420	9819	42	12F
0005434725882	9819	43	12K
0005434551249	9819	44	12H
0005434551404	9819	45	13D
0005434551252	9819	46	13C
0005434725864	9819	47	13A
0005434725761	9819	48	13F
0005434731189	9819	49	13E
0005433234832	9819	50	13H
0005434726149	9819	51	13G
0005434725210	9819	52	14A
0005434725999	9819	53	14D
0005433234880	9819	54	14G
0005434725170	9819	55	14F
0005433126894	9819	56	14E
0005434551364	9819	57	14K
0005432199319	9819	58	14H
0005434725569	9819	59	15C
0005434302471	9819	60	15A
0005433234820	9819	61	15E
0005434725505	9819	62	15D
0005433181353	9819	63	15H
0005434551320	9819	64	15G
0005434725615	9819	65	15F
0005433181358	9819	66	15K
0005434726053	9819	67	16D
0005434725998	9819	68	16C
0005434726388	9819	69	16A
0005432199322	9819	70	16F
0005434725744	9819	71	16E
0005433234828	9819	72	16K
0005434725718	9819	73	16H
0005434726386	9819	74	16G
0005435142537	9819	75	17C
0005434302451	9819	76	17A
0005433234838	9819	77	17E
0005433181365	9819	78	17D
0005434725591	9819	79	17F
0005433181350	9819	80	18A
0005434731176	9819	81	17K
0005433234834	9819	82	18B
0005433181367	9819	83	18E
0005434725683	9819	84	18D
0005433234850	9819	85	18C
0005434725972	9819	86	18G
0005434551366	9819	87	18F
0005433181362	9819	88	18K
0005434725913	9819	89	18J
0005433234835	9819	90	18H
0005434726034	9819	91	19A
0005434725422	9819	92	19D
0005434735700	9819	93	19C
0005434551303	9819	94	19B
0005433234877	9819	95	19F
0005434725876	9819	96	19E
0005434725932	9819	97	19H
0005434551475	9819	98	19G
0005434551278	9819	99	20A
0005435142613	9819	100	19K
0005434302466	9819	101	19J
0005433234849	9819	102	20C
0005433181348	9819	103	20B
0005434725665	9819	104	20E
0005434551319	9819	105	20D
0005433234840	9819	106	20G
0005433234852	9819	107	20F
0005434725884	9819	108	20K
0005434731154	9819	109	20J
0005433234846	9819	110	20H
0005434725439	9819	111	21B
0005433181364	9819	112	21D
0005434725746	9819	113	21C
0005434725557	9819	114	21G
0005433181357	9819	115	21F
0005434032071	9819	116	21E
0005434725455	9819	117	21J
0005434551090	9819	118	21H
0005433129321	9819	119	22A
0005434725762	9819	120	21K
0005434725825	9819	121	22C
0005434725703	9819	122	22B
0005434725293	9819	123	22F
0005434551470	9819	124	22E
0005434735697	9819	125	22D
0005433181352	9819	126	22H
0005433234859	9819	127	22G
0005434551229	9819	128	22K
0005434725539	9819	129	23B
0005434725792	9819	130	23A
0005434725646	9819	131	23E
0005434551282	9819	132	23D
0005434725721	9819	133	23C
0005434725024	9819	134	23F
0005434726298	9819	135	23J
0005432199317	9819	136	23H
0005434302464	9819	137	23G
0005433234825	9819	138	24D
0005433126895	9819	139	23K
0005434725666	9819	140	24F
0005433234866	9819	141	24E
0005434725657	9819	142	25A
0005433289922	9819	143	24G
0005433234881	9819	144	25D
0005432199318	9819	145	25C
0005434725543	9819	146	25B
0005434725783	9819	147	25F
0005434735677	9819	148	25E
0005434551139	9819	149	25H
0005434725482	9819	150	26A
0005433181354	9819	151	25K
0005434725786	9819	152	25J
0005435142539	9819	153	26B
0005433234879	9819	154	26E
0005434735689	9819	155	26D
0005434725173	9819	156	26C
0005433181370	9819	157	26F
0005434551218	9819	158	26K
0005434725995	9819	159	26J
0005434725549	9819	160	26H
0005433234826	9819	161	27B
0005433234875	9819	162	27A
0005433181346	9819	163	27D
0005434551158	9819	164	27C
0005435142563	9819	165	27F
0005433181369	9819	166	27E
0005434725570	9819	167	27H
0005434725720	9819	168	27G
0005433234822	9819	169	28A
0005432199316	9819	170	27K
0005435142556	9819	171	27J
0005434726109	9819	172	28C
0005433766678	9819	173	28B
0005434551305	9819	174	28E
0005434725650	9819	175	28D
0005434731173	9819	176	28G
0005433766680	9819	177	28F
0005434551157	9819	178	28J
0005434726110	9819	179	28H
0005434551154	9819	180	29B
0005434551371	9819	181	29A
0005433129322	9819	182	28K
0005434725597	9819	183	29D
0005434551343	9819	184	29F
0005434725875	9819	185	29E
0005434551548	9819	186	29H
0005434725667	9819	187	29G
0005433181361	9819	188	29K
0005434551149	9819	189	29J
0005435142602	9819	190	30C
0005433234868	9819	191	30B
0005434725889	9819	192	30A
0005434551437	9819	193	30E
0005434551039	9819	194	30D
0005434725304	9819	195	30H
0005434735699	9819	196	30G
0005435142538	9819	197	30F
0005434551284	9819	198	30K
0005434551259	9819	199	30J
0005434725474	9819	200	31A
0005434725546	9819	201	31D
0005433289918	9819	202	31C
0005434731174	9819	203	31B
0005433234823	9819	204	31G
0005434032074	9819	205	31F
0005433234860	9819	206	31E
0005435142559	9819	207	31H
0005434302469	9819	208	31K
0005433234839	9819	209	31J
0005434551267	9819	210	32C
0005433129323	9819	211	32B
0005433234876	9819	212	32E
0005434726131	9819	213	32D
0005434551260	9819	214	32G
0005433181351	9819	215	32F
0005433234882	9819	216	32J
0005434725169	9819	217	32H
0005434551073	9819	218	33A
0005434725651	9819	219	32K
0005434302452	9819	220	33D
0005433126891	9819	221	33B
0005434551270	9819	222	33F
0005434725107	9819	223	33E
0005434725644	9819	224	33J
0005434551250	9819	225	33H
0005435142568	9819	226	34A
0005434731155	9819	227	34C
0005433234857	9819	228	34B
0005434551089	9819	229	34D
0005433234848	9819	230	34H
0005433113557	9819	231	34K
0005434551331	9819	232	34J
0005434551044	9819	233	35A
0005434725645	9819	234	35D
0005434725023	9819	235	35C
0005434725802	9819	236	35B
0005434726387	9819	237	35F
0005434725827	9819	238	35E
0005434725544	9819	239	35H
0005433181355	9819	240	35G
0005434032073	9819	241	36A
0005434551365	9819	242	35K
0005434551078	9819	243	35J
0005435142578	9819	244	36C
0005433234855	9819	245	36B
0005433234873	9819	246	36E
0005433181360	9819	247	36D
0005433289923	9819	248	36G
0005434726150	9819	249	36K
0005433234854	9819	250	36J
0005434725668	9819	251	36H
0005433113558	9819	252	37B
0005434725826	9819	253	37A
0005435142587	9819	254	37E
0005433234864	9819	255	37D
0005433234874	9819	256	37C
0005433234831	9819	257	37G
0005433234833	9819	258	37F
0005434551060	9819	259	37H
0005434551217	9819	260	38A
0005434725784	9819	261	37K
0005435142603	9819	262	37J
0005434725340	9819	263	38C
0005434725620	9819	264	38B
0005434725933	9819	265	38K
0005434725822	9819	266	38J
0005434302470	9819	267	38H
0005433234865	9819	268	39B
0005433234844	9819	269	39A
0005433181363	9819	270	39D
0005433234878	9819	271	39C
0005432199320	9819	272	39F
0005434551285	9819	273	39E
0005434725606	9819	274	39H
0005433289924	9819	275	39G
0005433234843	9819	276	39K
0005434551549	9819	277	39J
0005434726235	9819	278	40C
0005434725445	9819	279	40B
0005433234824	9819	280	40A
0005434551509	9819	281	40E
0005434724875	9819	282	40D
0005434725106	9819	283	40H
0005434032072	9819	284	40G
0005433234856	9819	285	40F
0005434551088	9819	286	40J
0005433234863	9819	287	41B
0005434551248	9819	288	41A
0005434032070	9819	289	40K
0005435142586	9819	290	41D
0005434551384	9819	291	41C
0005434551244	9819	292	41F
0005434551251	9819	293	41E
0005433126889	9819	294	41J
0005435142564	9819	295	41H
0005433181356	9819	296	41G
0005434726141	9819	297	42A
0005433234861	9819	298	41K
0005433234845	9819	299	42C
0005433234842	9819	300	42B
0005434725711	9819	301	42E
0005434725574	9819	302	42D
0005434725824	9819	303	42H
0005434725781	9819	304	42F
0005434551254	9819	305	42K
0005434725775	9819	306	42J
0005434725895	9819	307	43B
0005434551150	9819	308	43A
0005434725583	9819	309	43D
0005434725890	9819	310	43C
0005433289917	9819	311	43F
0005434725631	9819	312	43E
0005433234867	9819	313	43H
0005432199321	9819	314	43G
0005435142580	9819	315	43K
0005433181359	9819	316	43J
0005434735679	9819	317	44C
0005434726151	9819	318	44B
0005434725616	9819	319	44A
0005434725745	9819	320	44E
0005433289919	9819	321	44D
0005433234841	9819	322	44G
0005433234858	9819	323	44F
0005434735688	9819	324	44J
0005434725550	9819	325	44H
0005434551166	9819	326	45A
0005434725661	9819	327	44K
0005433181371	9819	328	45D
0005433129324	9819	329	45C
0005434551283	9819	330	45B
0005434551094	9819	331	45E
0005434551277	9819	332	45H
0005433289920	9819	333	45G
0005434725973	9819	334	45J
0005434725782	9819	335	46C
0005434725481	9819	336	46B
0005434725298	9819	337	46A
0005434551318	9819	338	46E
0005433234836	9819	339	46D
0005434726021	9819	340	46H
0005435142555	9819	341	46G
0005433234830	9819	342	46F
0005434735676	9819	343	46K
0005434726186	9819	344	46J
0005434551132	9819	345	47C
0005434551042	9819	346	47D
0005434725970	9819	347	47G
0005435142550	9819	348	47F
0005434725497	9819	349	47E
0005434726132	9819	350	47K
0005433289921	9819	351	47H
0005433234862	9819	352	48D
0005433181368	9819	353	48C
0005434551074	9819	354	48F
0005433234829	9819	355	48E
0005434735701	9819	356	48H
0005433234853	9819	357	48G
0005434725473	9819	358	49A
0005434551461	9819	359	48K
0005434725853	9819	360	49E
0005433126890	9819	361	49D
0005434725927	9819	362	49C
0005434725953	9819	363	49G
0005434725993	9819	364	49K
0005433234851	9819	365	50C
0005434735683	9819	366	50A
0005433234883	9819	367	50F
0005434551263	9819	368	50G
0005433126892	9819	369	51D
0005434551413	9819	370	50K
0005435142577	9819	371	50H
0005433766679	9819	372	51F
0005433113560	9819	373	51E
0005434551304	9819	374	51G
0005432529366	7762	1	1C
0005432150277	7762	2	1A
0005432529330	7762	3	1H
0005432529256	7762	4	1G
0005432529353	7762	5	1D
0005435213711	7762	6	2A
0005432533322	7762	7	2C
0005435213743	7762	8	2H
0005432529284	7762	9	2G
0005432529355	7762	10	2D
0005432069800	7762	11	2K
0005432529320	7762	12	3G
0005432069801	7762	13	4C
0005434068268	7762	14	3K
0005432529268	7762	15	4G
0005435213709	7762	16	4K
0005432529360	7762	17	4H
0005432529322	7762	18	5C
0005432529291	7762	19	5G
0005435213574	7762	20	5D
0005434068289	7762	21	11A
0005432529370	7762	22	5K
0005435213813	7762	23	11C
0005435213479	7762	24	11G
0005435630968	7762	25	11F
0005435213664	7762	26	11E
0005432069802	7762	27	11K
0005432529290	7762	28	11H
0005432529379	7762	29	12A
0005434068274	7762	30	12E
0005432150276	7762	31	12D
0005432535886	7762	32	12G
0005432069810	7762	33	12F
0005435213679	7762	34	12K
0005432529335	7762	35	13C
0005435213368	7762	36	13A
0005432529259	7762	37	13F
0005435213591	7762	38	13E
0005434068299	7762	39	13G
0005432529348	7762	40	14C
0005432537080	7762	41	14A
0005432529340	7762	42	13K
0005434068316	7762	43	14G
0005432529314	7762	44	14K
0005432529352	7762	45	14H
0005435213765	7762	46	15A
0005434068263	7762	47	15E
0005432529351	7762	48	15D
0005435213616	7762	49	15H
0005434068310	7762	50	15F
0005432529333	7762	51	16A
0005432150272	7762	52	16D
0005432529338	7762	53	16G
0005432529339	7762	54	16F
0005432529382	7762	55	17C
0005432529305	7762	56	17A
0005434068319	7762	57	16K
0005434068277	7762	58	17E
0005432529297	7762	59	17D
0005434068275	7762	60	17G
0005432428963	7762	61	17F
0005432529277	7762	62	17H
0005432069811	7762	63	18A
0005432069797	7762	64	18E
0005432529337	7762	65	18C
0005434068261	7762	66	18G
0005432150274	7762	67	18F
0005432529384	7762	68	18K
0005432529311	7762	69	18J
0005432529367	7762	70	18H
0005434068321	7762	71	19A
0005434068267	7762	72	19D
0005432529383	7762	73	19C
0005432529332	7762	74	19B
0005434068269	7762	75	19E
0005432529341	7762	76	19H
0005435213568	7762	77	19G
0005432537079	7762	78	20E
0005432529357	7762	79	20D
0005434068311	7762	80	20G
0005434068297	7762	81	21B
0005433656664	7762	82	21A
0005432529287	7762	83	20K
0005432529296	7762	84	21D
0005432533320	7762	85	21C
0005435630953	7762	86	21F
0005432529281	7762	87	21E
0005432529350	7762	88	21J
0005432529343	7762	89	21H
0005432529303	7762	90	21G
0005434068280	7762	91	22A
0005435213611	7762	92	21K
0005432529258	7762	93	22C
0005435213748	7762	94	22E
0005435213613	7762	95	22D
0005432529288	7762	96	22H
0005432529369	7762	97	22G
0005432529318	7762	98	22F
0005432529327	7762	99	22K
0005435213758	7762	100	23A
0005434068259	7762	101	23D
0005432529359	7762	102	23E
0005432529334	7762	103	23J
0005432529374	7762	104	23G
0005432529389	7762	105	23K
0005432529274	7762	106	24F
0005435213714	7762	107	24E
0005432529260	7762	108	24G
0005434068306	7762	109	25D
0005432529307	7762	110	25C
0005432529346	7762	111	25B
0005434068315	7762	112	25J
0005432069796	7762	113	25H
0005435213537	7762	114	25G
0005435213747	7762	115	25K
0005435213951	7762	116	26B
0005432529371	7762	117	26A
0005432529364	7762	118	26E
0005435213920	7762	119	26D
0005432529381	7762	120	26C
0005432529294	7762	121	26H
0005434068273	7762	122	26G
0005435213774	7762	123	26F
0005434068256	7762	124	26J
0005432529331	7762	125	27B
0005432529289	7762	126	26K
0005432529295	7762	127	27C
0005435213811	7762	128	27F
0005432529315	7762	129	27E
0005432529316	7762	130	27D
0005432529292	7762	131	27G
0005434068308	7762	132	28A
0005434068264	7762	133	27K
0005432150279	7762	134	27J
0005432529276	7762	135	28B
0005435213642	7762	136	28E
0005432529309	7762	137	28D
0005432529285	7762	138	28F
0005432529328	7762	139	28K
0005432529362	7762	140	28J
0005434068323	7762	141	29A
0005432529298	7762	142	29D
0005432150278	7762	143	29C
0005432428965	7762	144	29B
0005435213350	7762	145	29F
0005434068314	7762	146	29E
0005432529265	7762	147	29H
0005434068303	7762	148	29K
0005435725602	7762	149	29J
0005434068307	7762	150	30B
0005432529263	7762	151	30A
0005432535885	7762	152	30E
0005434068266	7762	153	30D
0005435213369	7762	154	30F
0005432529280	7762	155	30J
0005434068312	7762	156	30H
0005432529354	7762	157	31B
0005432529358	7762	158	31A
0005434068270	7762	159	30K
0005434068265	7762	160	31C
0005432529257	7762	161	31F
0005432529286	7762	162	31H
0005434068279	7762	163	31G
0005432150271	7762	164	31K
0005432529301	7762	165	31J
0005432069809	7762	166	32C
0005434068327	7762	167	32B
0005434068285	7762	168	32A
0005432529347	7762	169	32E
0005432529306	7762	170	32D
0005435213663	7762	171	32G
0005432529264	7762	172	32K
0005434068320	7762	173	32J
0005432529308	7762	174	32H
0005434068281	7762	175	33D
0005432529321	7762	176	33C
0005434068283	7762	177	33B
0005435213521	7762	178	33F
0005434068276	7762	179	33H
0005432529375	7762	180	34B
0005432529324	7762	181	34A
0005432529378	7762	182	34E
0005434068309	7762	183	34D
0005434068258	7762	184	34H
0005435213718	7762	185	34G
0005432529363	7762	186	34F
0005432069803	7762	187	34K
0005435213536	7762	188	35A
0005435213416	7762	189	35D
0005435213637	7762	190	35B
0005435213897	7762	191	35F
0005432529365	7762	192	35E
0005433656686	7762	193	35H
0005435213801	7762	194	35G
0005434068290	7762	195	36A
0005432529273	7762	196	35K
0005434068262	7762	197	35J
0005432529342	7762	198	36C
0005435213567	7762	199	36B
0005432529336	7762	200	36E
0005434068301	7762	201	36D
0005432529299	7762	202	36H
0005432529376	7762	203	36K
0005432529386	7762	204	37B
0005434068304	7762	205	37A
0005433656668	7762	206	37D
0005432529326	7762	207	37C
0005432529361	7762	208	37F
0005435213819	7762	209	37E
0005434068318	7762	210	37J
0005434068326	7762	211	37H
0005432529356	7762	212	37G
0005435213529	7762	213	38A
0005432529372	7762	214	37K
0005434068294	7762	215	38C
0005434068284	7762	216	38B
0005434068305	7762	217	38H
0005432529387	7762	218	39B
0005435213483	7762	219	39A
0005432529266	7762	220	38K
0005432428962	7762	221	39C
0005434068286	7762	222	39F
0005432529319	7762	223	39E
0005432069808	7762	224	39D
0005435213787	7762	225	39J
0005434068296	7762	226	39H
0005432533321	7762	227	39G
0005432529345	7762	228	40A
0005435725603	7762	229	39K
0005435213666	7762	230	40B
0005432069805	7762	231	40E
0005434068293	7762	232	40D
0005432529302	7762	233	40G
0005432529368	7762	234	40F
0005434068257	7762	235	40K
0005435213598	7762	236	40J
0005434068325	7762	237	41B
0005432529329	7762	238	41A
0005435213716	7762	239	41D
0005432535884	7762	240	41G
0005432069807	7762	241	41F
0005435213450	7762	242	41E
0005432529388	7762	243	41H
0005434068300	7762	244	42A
0005434068260	7762	245	42C
0005432529304	7762	246	42B
0005432529349	7762	247	42E
0005432529279	7762	248	42D
0005432529300	7762	249	42J
0005432529261	7762	250	43B
0005434068302	7762	251	43A
0005432529272	7762	252	43D
0005435213901	7762	253	43C
0005432529282	7762	254	43F
0005435213678	7762	255	43E
0005435213509	7762	256	43J
0005435213522	7762	257	43G
0005435213377	7762	258	44A
0005434068288	7762	259	43K
0005432529317	7762	260	44C
0005432529385	7762	261	44B
0005434068317	7762	262	44E
0005434068292	7762	263	44D
0005432529373	7762	264	44H
0005432529278	7762	265	44F
0005433656666	7762	266	44K
0005434068278	7762	267	44J
0005432150273	7762	268	45A
0005432069799	7762	269	45D
0005434068322	7762	270	45C
0005434068298	7762	271	45F
0005435213707	7762	272	45E
0005432529270	7762	273	45G
0005432529283	7762	274	46A
0005432529380	7762	275	45K
0005432529271	7762	276	45J
0005435630954	7762	277	46B
0005432529312	7762	278	46E
0005434068287	7762	279	46D
0005432529377	7762	280	46C
0005432069804	7762	281	46G
0005432428964	7762	282	46F
0005435213523	7762	283	46K
0005432150275	7762	284	46J
0005435213790	7762	285	46H
0005432529293	7762	286	47C
0005432535882	7762	287	47A
0005435213665	7762	288	47D
0005435213802	7762	289	47G
0005435213812	7762	290	47K
0005432529313	7762	291	47H
0005432529310	7762	292	48C
0005434068295	7762	293	48A
0005433656665	7762	294	48E
0005432529323	7762	295	48H
0005432069806	7762	296	48F
0005434068291	7762	297	49A
0005434068272	7762	298	49E
0005434068271	7762	299	49D
0005432529275	7762	300	49G
0005432535883	7762	301	49F
0005434068313	7762	302	49K
0005432529262	7762	303	49H
0005432529325	7762	304	50C
0005432529267	7762	305	50E
0005432069798	7762	306	50D
0005435725601	7762	307	50H
0005432529269	7762	308	50G
0005432533323	7762	309	50K
0005434068324	7762	310	51F
0005434068282	7762	311	51E
0005435213757	7762	312	51D
0005432529344	7762	313	51G
0005435490266	5303	1	1D
0005432133371	5303	2	1C
0005435614851	5303	3	1A
0005434344580	5303	4	1H
0005434344569	5303	5	1G
0005435425117	5303	6	2A
0005434573500	5303	7	1K
0005435425061	5303	8	2C
0005434244979	5303	9	3A
0005434344585	5303	10	2K
0005435614831	5303	11	3G
0005435424970	5303	12	3D
0005434344570	5303	13	3C
0005435614846	5303	14	3K
0005435319625	5303	15	3H
0005432133367	5303	16	4C
0005435425118	5303	17	4A
0005434344582	5303	18	4G
0005432047588	5303	19	4D
0005434344579	5303	20	4K
0005435425164	5303	21	4H
0005435425186	5303	22	5D
0005434245206	5303	23	5C
0005435614773	5303	24	5A
0005435097302	5303	25	5H
0005435425073	5303	26	11A
0005435614858	5303	27	5K
0005432363416	5303	28	11E
0005434573502	5303	29	11D
0005435614777	5303	30	11C
0005435424979	5303	31	11G
0005435614755	5303	32	11F
0005435614783	5303	33	11K
0005435614789	5303	34	11H
0005435424790	5303	35	12C
0005435614762	5303	36	12A
0005435424998	5303	37	12F
0005435424985	5303	38	12E
0005435425122	5303	39	12D
0005435614775	5303	40	12G
0005433719155	5303	41	12K
0005435424884	5303	42	12H
0005435614818	5303	43	13D
0005435097307	5303	44	13A
0005435614824	5303	45	13F
0005434245205	5303	46	13E
0005435424986	5303	47	13H
0005435614781	5303	48	13G
0005435614797	5303	49	14A
0005435424814	5303	50	13K
0005435614763	5303	51	14D
0005435425108	5303	52	14F
0005435614760	5303	53	14E
0005435491459	5303	54	14K
0005432363425	5303	55	14H
0005435614800	5303	56	14G
0005434344589	5303	57	15C
0005435614804	5303	58	15A
0005434344588	5303	59	15E
0005434344576	5303	60	15D
0005434245070	5303	61	15H
0005435614871	5303	62	15G
0005435614759	5303	63	15F
0005435614788	5303	64	16D
0005435614837	5303	65	16C
0005434573499	5303	66	16A
0005435424817	5303	67	16G
0005434573496	5303	68	16F
0005435614838	5303	69	16E
0005432047590	5303	70	16K
0005435614857	5303	71	16H
0005435097310	5303	72	17E
0005435097305	5303	73	17D
0005432841011	5303	74	17C
0005435614752	5303	75	17G
0005435319608	5303	76	17F
0005432133360	5303	77	18A
0005435425033	5303	78	17K
0005435302211	5303	79	17H
0005435319609	5303	80	18B
0005435614747	5303	81	18E
0005434573492	5303	82	18D
0005434344597	5303	83	18C
0005435424973	5303	84	18H
0005435097304	5303	85	18G
0005434344599	5303	86	18F
0005432133365	5303	87	18J
0005435424987	5303	88	19B
0005435614751	5303	89	18K
0005435424885	5303	90	19D
0005435614841	5303	91	19C
0005432133361	5303	92	19F
0005435614819	5303	93	19E
0005435614842	5303	94	19J
0005435614799	5303	95	19H
0005434344587	5303	96	19G
0005435614865	5303	97	20A
0005435425068	5303	98	19K
0005435614852	5303	99	20C
0005435614870	5303	100	20B
0005434245080	5303	101	20E
0005435614835	5303	102	20D
0005435424727	5303	103	20G
0005435614814	5303	104	20F
0005435425074	5303	105	20K
0005435614873	5303	106	20J
0005435614805	5303	107	21B
0005435614866	5303	108	21A
0005432133370	5303	109	21D
0005435614856	5303	110	21C
0005435490267	5303	111	21E
0005435614793	5303	112	21H
0005432047587	5303	113	22A
0005434344584	5303	114	22C
0005435424760	5303	115	22E
0005435424919	5303	116	22D
0005435097301	5303	117	22G
0005435614832	5303	118	22F
0005432133368	5303	119	22J
0005435614791	5303	120	23B
0005435425205	5303	121	23A
0005435424759	5303	122	23C
0005435614811	5303	123	23F
0005434244915	5303	124	23E
0005435614828	5303	125	23H
0005435425126	5303	126	24D
0005432133363	5303	127	23K
0005435425109	5303	128	23J
0005435614863	5303	129	24F
0005435425185	5303	130	24E
0005435302197	5303	131	25C
0005435614815	5303	132	25B
0005435302208	5303	133	25F
0005434245066	5303	134	25E
0005435614834	5303	135	25D
0005435319589	5303	136	25H
0005435614839	5303	137	25G
0005435424938	5303	138	25K
0005435614796	5303	139	25J
0005435614847	5303	140	26C
0005435424868	5303	141	26B
0005433719156	5303	142	26E
0005434245071	5303	143	26D
0005434344577	5303	144	26G
0005435614867	5303	145	26F
0005432133372	5303	146	26H
0005435614833	5303	147	27A
0005435425161	5303	148	26K
0005435424870	5303	149	27C
0005435614820	5303	150	27B
0005435614750	5303	151	27F
0005435425028	5303	152	27E
0005432133362	5303	153	27J
0005434344567	5303	154	27H
0005435424995	5303	155	27G
0005435319562	5303	156	27K
0005434245064	5303	157	28C
0005434344595	5303	158	28A
0005435425067	5303	159	28E
0005434344574	5303	160	28D
0005435319576	5303	161	28F
0005435614790	5303	162	28H
0005435614864	5303	163	29B
0005435424950	5303	164	28K
0005434245065	5303	165	29D
0005435424770	5303	166	29F
0005435614803	5303	167	29E
0005434344592	5303	168	29H
0005435614753	5303	169	30A
0005435614771	5303	170	29K
0005435614868	5303	171	30C
0005435424996	5303	172	30B
0005435614756	5303	173	30E
0005435614787	5303	174	30D
0005434244988	5303	175	30G
0005435425001	5303	176	31B
0005435424849	5303	177	31A
0005435555389	5303	178	30K
0005435425020	5303	179	31D
0005434344583	5303	180	31C
0005435614816	5303	181	31F
0005432047591	5303	182	31E
0005434573504	5303	183	31H
0005435614817	5303	184	31G
0005432133369	5303	185	31K
0005435097300	5303	186	32B
0005435302204	5303	187	32A
0005432133373	5303	188	32E
0005435614754	5303	189	32D
0005435424953	5303	190	32C
0005435614779	5303	191	32G
0005435614861	5303	192	32F
0005434573493	5303	193	32K
0005435614749	5303	194	32J
0005435614758	5303	195	32H
0005435302216	5303	196	33B
0005434344581	5303	197	33A
0005435614786	5303	198	33D
0005435424937	5303	199	33C
0005435614748	5303	200	33F
0005435614798	5303	201	33H
0005435425072	5303	202	33G
0005435614823	5303	203	33K
0005434244944	5303	204	34C
0005435380282	5303	205	34B
0005435614850	5303	206	34A
0005435424968	5303	207	34E
0005435614774	5303	208	34D
0005435614859	5303	209	34H
0005435424717	5303	210	34G
0005434573497	5303	211	34K
0005434573495	5303	212	34J
0005435614782	5303	213	35A
0005435614810	5303	214	35D
0005434344572	5303	215	35C
0005435614836	5303	216	35G
0005435614801	5303	217	35F
0005434344596	5303	218	35E
0005435614768	5303	219	35J
0005434245041	5303	220	35K
0005435614829	5303	221	36B
0005434573503	5303	222	36A
0005435424682	5303	223	36E
0005435097309	5303	224	36D
0005435614822	5303	225	36G
0005435424949	5303	226	36F
0005435380281	5303	227	36J
0005432047589	5303	228	36H
0005435425123	5303	229	37B
0005435425062	5303	230	36K
0005434245186	5303	231	37D
0005435424850	5303	232	37C
0005435425037	5303	233	37G
0005434244977	5303	234	37F
0005435614764	5303	235	37J
0005435614854	5303	236	37H
0005435614802	5303	237	37K
0005435425039	5303	238	38C
0005435614826	5303	239	38B
0005434245079	5303	240	38A
0005435097311	5303	241	38H
0005435614794	5303	242	39A
0005435424988	5303	243	38K
0005435614872	5303	244	39D
0005435614813	5303	245	39C
0005435614843	5303	246	39F
0005435097303	5303	247	39E
0005435614844	5303	248	39J
0005435424971	5303	249	39H
0005435614784	5303	250	40A
0005432133366	5303	251	40C
0005435425230	5303	252	40B
0005432363424	5303	253	40E
0005435424993	5303	254	40D
0005434573501	5303	255	40G
0005435424799	5303	256	40F
0005435614809	5303	257	40K
0005435614806	5303	258	40J
0005435614869	5303	259	40H
0005435319615	5303	260	41B
0005434344591	5303	261	41A
0005435614825	5303	262	41D
0005435614808	5303	263	41F
0005434656561	5303	264	41E
0005435614840	5303	265	41G
0005435614792	5303	266	42A
0005435614827	5303	267	41K
0005434244978	5303	268	42C
0005435614821	5303	269	42G
0005435614795	5303	270	42F
0005435425165	5303	271	42J
0005435614778	5303	272	42H
0005435614776	5303	273	43B
0005434245207	5303	274	43A
0005434344575	5303	275	42K
0005435319604	5303	276	43C
0005434245187	5303	277	43F
0005435319605	5303	278	43E
0005435302198	5303	279	43H
0005435097306	5303	280	43J
0005434344590	5303	281	44C
0005434244987	5303	282	44B
0005432133364	5303	283	44A
0005435424862	5303	284	44E
0005434573494	5303	285	44D
0005435614785	5303	286	44G
0005435614830	5303	287	44F
0005435425206	5303	288	44K
0005434344568	5303	289	44J
0005435614860	5303	290	44H
0005435614845	5303	291	45B
0005435424869	5303	292	45A
0005435614807	5303	293	45D
0005435424895	5303	294	45F
0005435614849	5303	295	45E
0005435424883	5303	296	45G
0005435319561	5303	297	46A
0005435614769	5303	298	45K
0005435425234	5303	299	45J
0005435424969	5303	300	46C
0005435097308	5303	301	46B
0005434344573	5303	302	46E
0005435614767	5303	303	46D
0005435614772	5303	304	46G
0005434344593	5303	305	46F
0005435614770	5303	306	46K
0005435614780	5303	307	46J
0005435614761	5303	308	46H
0005435614766	5303	309	47C
0005434344578	5303	310	47E
0005435424796	5303	311	47D
0005434344571	5303	312	47G
0005435424702	5303	313	47F
0005435319621	5303	314	47K
0005435302219	5303	315	47H
0005435424800	5303	316	48D
0005435614862	5303	317	48C
0005432133359	5303	318	48E
0005435380288	5303	319	48G
0005432363423	5303	320	48F
0005435555390	5303	321	49A
0005435614853	5303	322	48K
0005434344586	5303	323	49D
0005435380309	5303	324	49G
0005435614855	5303	325	49F
0005434573498	5303	326	49K
0005435425110	5303	327	49H
0005435425040	5303	328	50C
0005435614757	5303	329	50A
0005435490265	5303	330	50E
0005434344594	5303	331	50D
0005435490264	5303	332	50G
0005434344598	5303	333	50F
0005435614765	5303	334	51D
0005434245022	5303	335	50H
0005435614848	5303	336	51F
0005435424992	5303	337	51E
0005435614812	5303	338	51G
0005435319660	10905	1	1A
0005435425517	10905	2	1G
0005435097198	10905	3	2A
0005435555376	10905	4	1K
0005435380336	10905	5	1H
0005435613888	10905	6	2C
0005435614235	10905	7	2H
0005435425507	10905	8	2G
0005434344244	10905	9	2D
0005435425491	10905	10	3A
0005434245272	10905	11	2K
0005432363450	10905	12	3G
0005435613352	10905	13	3H
0005435425511	10905	14	4C
0005435613925	10905	15	4A
0005435425499	10905	16	4G
0005435614059	10905	17	4D
0005434245268	10905	18	5A
0005435613640	10905	19	4K
0005435304201	10905	20	4H
0005435617235	10905	21	5D
0005435425498	10905	22	5G
0005435425481	10905	23	5K
0005435613729	10905	24	11E
0005435425535	10905	25	11D
0005435613392	10905	26	11C
0005435613393	10905	27	11F
0005435613826	10905	28	11G
0005435613844	10905	29	12C
0005435617169	10905	30	12A
0005435614247	10905	31	11K
0005435614234	10905	32	12F
0005434245284	10905	33	12E
0005435097195	10905	34	12D
0005434573350	10905	35	12G
0005435613602	10905	36	12K
0005434245292	10905	37	12H
0005434573333	10905	38	13D
0005435613837	10905	39	13C
0005435613394	10905	40	13A
0005435613724	10905	41	13E
0005434344405	10905	42	13H
0005435613275	10905	43	13G
0005434344469	10905	44	14C
0005435613639	10905	45	14A
0005435613588	10905	46	13K
0005433719176	10905	47	14G
0005435613292	10905	48	14E
0005435613890	10905	49	14K
0005435042879	10905	50	14H
0005435613519	10905	51	15C
0005435304199	10905	52	15A
0005434344312	10905	53	15F
0005435613353	10905	54	15E
0005434245271	10905	55	15G
0005435305033	10905	56	16A
0005434245293	10905	57	15K
0005435617170	10905	58	15H
0005435613960	10905	59	16D
0005435613880	10905	60	16C
0005435425519	10905	61	16F
0005435425533	10905	62	16E
0005435613924	10905	63	16H
0005435425482	10905	64	16G
0005432166937	10905	65	17A
0005435614160	10905	66	16K
0005435425545	10905	67	17D
0005435613710	10905	68	17C
0005434344183	10905	69	17G
0005435613836	10905	70	17F
0005435613667	10905	71	17E
0005435614171	10905	72	17K
0005435613797	10905	73	17H
0005435613706	10905	74	18C
0005435614196	10905	75	18B
0005434573358	10905	76	18A
0005435613668	10905	77	18G
0005435613772	10905	78	18F
0005435425506	10905	79	18K
0005435613895	10905	80	18J
0005435613874	10905	81	19A
0005435319664	10905	82	19C
0005435319666	10905	83	19B
0005434245291	10905	84	19F
0005435425544	10905	85	19E
0005434573276	10905	86	19K
0005435490220	10905	87	19J
0005435613730	10905	88	20C
0005435613765	10905	89	20B
0005434245283	10905	90	20E
0005435425528	10905	91	20D
0005434573353	10905	92	20G
0005435042881	10905	93	20F
0005432363451	10905	94	20K
0005435614060	10905	95	20J
0005434344154	10905	96	20H
0005435614174	10905	97	21A
0005435097203	10905	98	21E
0005435425487	10905	99	21D
0005435614055	10905	100	21C
0005435613834	10905	101	21F
0005435613517	10905	102	21H
0005435425548	10905	103	21G
0005434573385	10905	104	22A
0005435380338	10905	105	21K
0005435097202	10905	106	21J
0005435614161	10905	107	22D
0005432166934	10905	108	22C
0005435613676	10905	109	22B
0005435319663	10905	110	22F
0005434573310	10905	111	22H
0005435380337	10905	112	22G
0005434344222	10905	113	23B
0005435613970	10905	114	23A
0005434573284	10905	115	22K
0005432841034	10905	116	23D
0005435319662	10905	117	23C
0005435613255	10905	118	23F
0005435425492	10905	119	23E
0005435613835	10905	120	23J
0005435614191	10905	121	23H
0005435613980	10905	122	24D
0005435613959	10905	123	23K
0005432165113	10905	124	24F
0005435425514	10905	125	25A
0005435613589	10905	126	25C
0005435613618	10905	127	25B
0005435613879	10905	128	25D
0005435319661	10905	129	25H
0005434245275	10905	130	25G
0005434245287	10905	131	25F
0005435613515	10905	132	26A
0005435614021	10905	133	25J
0005434656577	10905	134	26C
0005435425515	10905	135	26E
0005434245282	10905	136	26D
0005435613961	10905	137	26F
0005435425524	10905	138	26K
0005435613388	10905	139	26J
0005434656576	10905	140	26H
0005435613966	10905	141	27A
0005435613406	10905	142	27D
0005434344199	10905	143	27C
0005435425496	10905	144	27F
0005435613721	10905	145	27E
0005435613735	10905	146	27J
0005434573323	10905	147	27G
0005435425534	10905	148	27K
0005435613902	10905	149	28C
0005435304202	10905	150	28B
0005434245278	10905	151	28E
0005435425516	10905	152	28D
0005435097204	10905	153	28H
0005432165115	10905	154	28G
0005434344225	10905	155	28F
0005434245274	10905	156	28K
0005435613876	10905	157	28J
0005434245296	10905	158	29B
0005434245288	10905	159	29A
0005435614153	10905	160	29D
0005435319665	10905	161	29F
0005435425493	10905	162	29E
0005435425546	10905	163	29H
0005434344285	10905	164	29G
0005435613732	10905	165	30A
0005435614027	10905	166	29K
0005435425529	10905	167	29J
0005435425501	10905	168	30B
0005434573349	10905	169	30E
0005435614002	10905	170	30D
0005434245276	10905	171	30C
0005434573332	10905	172	30G
0005434245290	10905	173	30F
0005435425538	10905	174	30K
0005434344221	10905	175	30J
0005434245289	10905	176	30H
0005435613896	10905	177	31B
0005434573314	10905	178	31A
0005435425513	10905	179	31D
0005435425503	10905	180	31C
0005435613827	10905	181	31E
0005435614134	10905	182	31H
0005435425531	10905	183	31G
0005435613617	10905	184	31K
0005434245277	10905	185	31J
0005435425510	10905	186	32A
0005435614031	10905	187	32E
0005435425497	10905	188	32D
0005435613716	10905	189	32G
0005435042882	10905	190	32F
0005435613720	10905	191	32J
0005435490244	10905	192	32H
0005435613793	10905	193	33B
0005435613915	10905	194	33A
0005435425525	10905	195	32K
0005435319667	10905	196	33D
0005434344280	10905	197	33C
0005435613696	10905	198	33G
0005435613291	10905	199	33F
0005435613493	10905	200	33E
0005435097211	10905	201	33H
0005435097210	10905	202	33K
0005435425486	10905	203	33J
0005432166933	10905	204	34C
0005435425480	10905	205	34B
0005435425532	10905	206	34A
0005435613028	10905	207	34E
0005435425483	10905	208	34D
0005435425500	10905	209	34G
0005435613329	10905	210	34F
0005434344153	10905	211	34K
0005435425550	10905	212	34H
0005435425495	10905	213	35B
0005434573384	10905	214	35D
0005432165120	10905	215	35C
0005435613354	10905	216	35G
0005435613274	10905	217	35F
0005435613719	10905	218	35E
0005434245285	10905	219	35J
0005435614228	10905	220	35H
0005434344236	10905	221	36A
0005435425489	10905	222	35K
0005435425505	10905	223	36D
0005435613791	10905	224	36C
0005435425540	10905	225	36B
0005432841035	10905	226	36E
0005435613889	10905	227	36H
0005432165114	10905	228	36G
0005435613516	10905	229	36F
0005435425536	10905	230	36K
0005434245286	10905	231	36J
0005434573315	10905	232	37B
0005435614233	10905	233	37A
0005435613875	10905	234	37D
0005435613773	10905	235	37C
0005435425537	10905	236	37G
0005435490245	10905	237	37F
0005433719178	10905	238	37H
0005434344138	10905	239	38A
0005435425518	10905	240	37K
0005435305034	10905	241	38C
0005435614395	10905	242	38B
0005435613514	10905	243	38J
0005435425522	10905	244	38H
0005434245294	10905	245	39B
0005435425547	10905	246	39A
0005432166935	10905	247	38K
0005432165117	10905	248	39D
0005435380334	10905	249	39F
0005434344182	10905	250	39E
0005435425490	10905	251	39G
0005435613520	10905	252	40A
0005434344030	10905	253	39K
0005435425508	10905	254	39J
0005435613327	10905	255	40C
0005435613805	10905	256	40B
0005435425520	10905	257	40E
0005434245269	10905	258	40H
0005434573343	10905	259	40G
0005435425502	10905	260	40F
0005435425530	10905	261	41B
0005434344372	10905	262	41A
0005435097197	10905	263	40K
0005435425527	10905	264	41C
0005434344217	10905	265	41F
0005435613870	10905	266	41E
0005435613843	10905	267	41J
0005435613641	10905	268	41H
0005434344190	10905	269	41G
0005435425485	10905	270	42A
0005435425526	10905	271	41K
0005435304200	10905	272	42C
0005435305032	10905	273	42E
0005434245273	10905	274	42D
0005435097196	10905	275	42G
0005435614170	10905	276	42F
0005435614394	10905	277	42K
0005435425479	10905	278	42J
0005435425543	10905	279	42H
0005435425541	10905	280	43B
0005434344311	10905	281	43A
0005434245270	10905	282	43D
0005432165116	10905	283	43C
0005435425488	10905	284	43H
0005435613995	10905	285	43K
0005432363449	10905	286	43J
0005432165112	10905	287	44C
0005435425504	10905	288	44B
0005435613328	10905	289	44A
0005435425494	10905	290	44E
0005433719177	10905	291	44D
0005435613705	10905	292	44G
0005432165119	10905	293	44F
0005435042880	10905	294	44J
0005434245295	10905	295	45B
0005435425512	10905	296	44K
0005434344243	10905	297	45D
0005435613979	10905	298	45C
0005435491445	10905	299	45E
0005434344265	10905	300	45H
0005435555375	10905	301	45G
0005435614248	10905	302	46B
0005435425549	10905	303	46A
0005435613897	10905	304	46E
0005435613984	10905	305	46D
0005435425484	10905	306	46C
0005435425539	10905	307	46G
0005434344198	10905	308	46F
0005435425523	10905	309	46J
0005435613878	10905	310	47C
0005435425521	10905	311	47A
0005435425509	10905	312	47G
0005434344162	10905	313	47F
0005434245280	10905	314	47E
0005435613271	10905	315	47K
0005435613587	10905	316	48C
0005435490223	10905	317	48A
0005435042883	10905	318	48F
0005435380335	10905	319	48E
0005434344261	10905	320	48G
0005434344152	10905	321	49A
0005435614056	10905	322	49D
0005434573354	10905	323	49C
0005435613723	10905	324	49G
0005435425542	10905	325	49F
0005432166936	10905	326	49E
0005434344273	10905	327	49K
0005434344373	10905	328	49H
0005434245281	10905	329	50C
0005435613731	10905	330	50A
0005434245279	10905	331	50F
0005434344242	10905	332	50E
0005435613594	10905	333	50D
0005435613998	10905	334	50H
0005434245267	10905	335	50G
0005435613654	10905	336	50K
0005435614022	10905	337	51F
0005432165118	10905	338	51E
0005435304198	10905	339	51D
0005435613850	10905	340	51G
0005432459743	3232	1	1A
0005432181949	3232	2	1C
0005432459978	3232	3	1D
0005432181938	3232	4	2A
0005432181937	3232	5	1F
0005432181956	3232	6	2D
0005433805731	3232	7	2C
0005433634176	3232	8	3A
0005433805737	3232	9	3C
0005432459884	3232	10	3F
0005433634158	3232	11	3D
0005432459787	3232	12	4A
0005432459883	3232	13	4C
0005433634166	3232	14	4D
0005433507366	3232	15	5A
0005432181946	3232	16	4F
0005432181955	3232	17	5C
0005432181953	3232	18	5F
0005433634169	3232	19	5D
0005432181957	3232	20	6A
0005432459799	3232	21	6D
0005433805729	3232	22	6C
0005433634170	3232	23	6F
0005433805722	3232	24	7A
0005433805732	3232	25	7C
0005432459845	3232	26	7F
0005432459792	3232	27	7D
0005433805741	3232	28	8A
0005433507361	3232	29	8B
0005432181948	3232	30	8C
0005433805748	3232	31	8E
0005433634188	3232	32	8D
0005432459959	3232	33	8F
0005433507373	3232	34	9B
0005433634171	3232	35	9A
0005432459866	3232	36	9C
0005433634172	3232	37	9D
0005433507367	3232	38	9E
0005433634159	3232	39	10A
0005432459871	3232	40	9F
0005432460012	3232	41	10B
0005432181939	3232	42	10C
0005432459931	3232	43	10E
0005432459983	3232	44	10D
0005432460127	3232	45	10F
0005432459820	3232	46	11A
0005433507372	3232	47	11C
0005432181951	3232	48	11B
0005433805724	3232	49	11D
0005432459868	3232	50	11F
0005432459637	3232	51	11E
0005432459702	3232	52	12A
0005433805719	3232	53	12B
0005432460046	3232	54	12D
0005432181940	3232	55	12C
0005432459937	3232	56	12F
0005432459914	3232	57	12E
0005432459916	3232	58	13B
0005432181943	3232	59	13A
0005433805735	3232	60	13C
0005432459992	3232	61	13D
0005433634186	3232	62	13E
0005432181944	3232	63	14A
0005432181945	3232	64	13F
0005433634157	3232	65	14B
0005433507363	3232	66	14D
0005432459925	3232	67	14C
0005433507374	3232	68	14E
0005432181947	3232	69	14F
0005433805723	3232	70	15A
0005433507358	3232	71	15C
0005432459638	3232	72	15B
0005433507368	3232	73	15D
0005432459929	3232	74	15F
0005432459899	3232	75	15E
0005433805745	3232	76	16A
0005432459882	3232	77	16B
0005432459794	3232	78	16C
0005433805736	3232	79	16D
0005432459861	3232	80	17A
0005432459869	3232	81	16F
0005432181935	3232	82	17B
0005433634177	3232	83	17C
0005433634155	3232	84	17E
0005433634168	3232	85	17D
0005433805746	3232	86	17F
0005433805751	3232	87	18A
0005433805747	3232	88	18B
0005433634173	3232	89	18C
0005433805726	3232	90	18E
0005432459865	3232	91	18D
0005432459793	3232	92	19B
0005432459970	3232	93	18F
0005433805743	3232	94	19D
0005433634156	3232	95	19C
0005432459703	3232	96	20A
0005432460019	3232	97	19E
0005433805738	3232	98	20C
0005433634183	3232	99	20B
0005433805742	3232	100	20E
0005433507360	3232	101	20D
0005432460002	3232	102	20F
0005433634179	3232	103	21A
0005433634182	3232	104	21C
0005432459864	3232	105	21B
0005432459960	3232	106	21D
0005433507359	3232	107	21E
0005432459809	3232	108	22A
0005432459958	3232	109	21F
0005432459701	3232	110	22B
0005432459740	3232	111	22C
0005432181950	3232	112	22E
0005433805733	3232	113	22D
0005432459907	3232	114	22F
0005433507376	3232	115	23A
0005432459898	3232	116	23C
0005433507365	3232	117	23B
0005433805727	3232	118	23D
0005432181952	3232	119	23F
0005433634174	3232	120	23E
0005433507362	3232	121	24A
0005432181954	3232	122	24B
0005433507375	3232	123	24D
0005433634184	3232	124	24C
0005433634181	3232	125	24E
0005432181941	3232	126	24F
0005432181936	3232	127	25A
0005432459860	3232	128	25C
0005433507357	3232	129	25B
0005432459997	3232	130	25D
0005433634163	3232	131	25F
0005432459908	3232	132	25E
0005433634178	3232	133	26A
0005433507371	3232	134	26C
0005433805749	3232	135	26B
0005433507370	3232	136	26E
0005433634161	3232	137	26D
0005433805725	3232	138	26F
0005433805718	3232	139	27B
0005432459923	3232	140	27A
0005433805721	3232	141	27C
0005432459872	3232	142	27D
0005433634165	3232	143	27F
0005433634160	3232	144	27E
0005433805720	3232	145	28C
0005433805728	3232	146	28B
0005433805744	3232	147	28A
0005433805750	3232	148	28E
0005433634164	3232	149	28D
0005433634175	3232	150	28F
0005433507364	3232	151	29A
0005433805740	3232	152	29C
0005432460128	3232	153	29B
0005433634189	3232	154	29D
0005433634180	3232	155	29E
0005432459971	3232	156	30A
0005433805734	3232	157	29F
0005433805739	3232	158	30B
0005433507369	3232	159	30D
0005433634185	3232	160	30C
0005432181942	3232	161	30E
0005432459930	3232	162	30F
0005432459957	3232	163	31A
0005432459858	3232	164	31C
0005433634187	3232	165	31B
0005433805730	3232	166	31E
0005433634167	3232	167	31D
0005433634162	3232	168	31F
0005435885458	3233	1	1A
0005435885523	3233	2	2F
0005435885289	3233	3	3C
0005435885335	3233	4	7C
0005435885382	3233	5	8B
0005435885360	3233	6	10A
0005435885288	3233	7	10D
0005435885457	3233	8	10F
0005435885179	3233	9	11B
0005435885235	3233	10	12A
0005435885317	3233	11	13A
0005435885342	3233	12	13B
0005435885343	3233	13	14E
0005435885106	3233	14	14F
0005435885278	3233	15	15D
0005435885374	3233	16	15E
0005435885462	3233	17	17B
0005435885279	3233	18	17D
0005435885482	3233	19	18B
0005435885139	3233	20	18E
0005435885287	3233	21	20B
0005435885379	3233	22	20D
0005435885286	3233	23	21C
0005435885359	3233	24	22B
0005435885271	3233	25	22F
0005435885481	3233	26	23F
0005435885373	3233	27	24C
0005435885270	3233	28	25A
0005435885465	3233	29	26A
0005435885338	3233	30	26B
0005435885364	3233	31	26E
0005435885363	3233	32	28A
0005435885362	3233	33	28B
0005435885096	3233	34	28D
0005435885579	3233	35	29C
0005435885569	3233	36	29E
0005435885483	3233	37	30A
0005435885253	3233	38	30E
0005435885307	3233	39	31B
0005432460412	8179	1	1D
0005435885750	8179	2	1C
0005432042856	8179	3	1F
0005435885748	8179	4	2A
0005435885760	8179	5	2D
0005432460444	8179	6	2C
0005435885754	8179	7	2F
0005433507237	8179	8	3D
0005432460419	8179	9	3C
0005432460450	8179	10	3F
0005432460400	8179	11	4A
0005432460402	8179	12	4C
0005432460417	8179	13	4F
0005435885797	8179	14	5A
0005432460403	8179	15	5C
0005432460414	8179	16	5D
0005435885774	8179	17	5F
0005432460427	8179	18	6D
0005434312342	8179	19	6C
0005432042865	8179	20	6F
0005433507177	8179	21	7F
0005435885789	8179	22	7D
0005432460422	8179	23	8A
0005432460407	8179	24	8C
0005432042863	8179	25	8B
0005435885776	8179	26	8D
0005433507206	8179	27	8E
0005435885756	8179	28	9A
0005435885767	8179	29	8F
0005432042861	8179	30	9B
0005435885779	8179	31	9C
0005435885795	8179	32	9D
0005433507187	8179	33	10A
0005432460445	8179	34	9F
0005432460406	8179	35	10B
0005435885763	8179	36	10D
0005432460404	8179	37	10E
0005432460447	8179	38	11A
0005432460399	8179	39	10F
0005432460435	8179	40	11B
0005432042854	8179	41	11F
0005435885761	8179	42	12C
0005432460437	8179	43	12B
0005432460409	8179	44	12D
0005432460448	8179	45	12E
0005435885751	8179	46	12F
0005432460432	8179	47	13B
0005432460421	8179	48	13D
0005435885772	8179	49	13F
0005435885759	8179	50	13E
0005432460428	8179	51	14B
0005432460443	8179	52	14D
0005432460451	8179	53	14C
0005432460423	8179	54	14E
0005432460439	8179	55	14F
0005432460420	8179	56	15A
0005432460442	8179	57	15C
0005432460436	8179	58	15B
0005432042864	8179	59	15F
0005432042859	8179	60	15E
0005435885773	8179	61	16A
0005435885778	8179	62	16C
0005435885766	8179	63	16B
0005434312343	8179	64	16D
0005434312341	8179	65	16E
0005435885745	8179	66	17A
0005435885762	8179	67	16F
0005432460429	8179	68	17C
0005435885768	8179	69	17B
0005432042852	8179	70	17D
0005435885765	8179	71	17E
0005435885752	8179	72	18B
0005435885791	8179	73	18D
0005432042855	8179	74	18E
0005435885790	8179	75	18F
0005432460410	8179	76	19C
0005432460426	8179	77	19B
0005435885794	8179	78	19D
0005435885780	8179	79	19E
0005432460416	8179	80	20B
0005435885793	8179	81	20A
0005435885746	8179	82	20D
0005435885749	8179	83	20F
0005432460408	8179	84	20E
0005435885792	8179	85	21B
0005435885784	8179	86	21A
0005433507172	8179	87	21D
0005435885771	8179	88	21C
0005435885786	8179	89	21E
0005432460401	8179	90	22A
0005432460449	8179	91	21F
0005435885775	8179	92	22B
0005435885758	8179	93	22C
0005433507193	8179	94	22D
0005435885753	8179	95	22F
0005435885787	8179	96	22E
0005432460441	8179	97	23A
0005432460433	8179	98	23D
0005435885755	8179	99	23F
0005432460434	8179	100	23E
0005432460415	8179	101	24B
0005432042862	8179	102	24A
0005432460431	8179	103	24D
0005432042857	8179	104	24F
0005435885783	8179	105	25B
0005432460413	8179	106	25A
0005435885796	8179	107	25F
0005432460411	8179	108	25E
0005432460440	8179	109	26B
0005435885788	8179	110	26D
0005432460438	8179	111	26C
0005432042858	8179	112	26E
0005432460430	8179	113	26F
0005432460446	8179	114	27B
0005435885770	8179	115	27F
0005435885781	8179	116	28A
0005432042853	8179	117	28B
0005432460452	8179	118	28D
0005435885798	8179	119	28C
0005435885777	8179	120	28E
0005435885757	8179	121	29B
0005435885785	8179	122	29A
0005432460405	8179	123	29D
0005432460418	8179	124	29E
0005432460424	8179	125	29F
0005435885747	8179	126	30B
0005435885769	8179	127	30A
0005433507236	8179	128	30C
0005432460425	8179	129	30E
0005432042860	8179	130	30D
0005435885782	8179	131	30F
0005433507201	8179	132	31B
0005433507245	8179	133	31C
0005433507217	8179	134	31D
0005435885764	8179	135	31E
0005433805498	8181	1	1C
0005433633946	8181	2	2F
0005433633792	8181	3	3A
0005433805626	8181	4	3C
0005433805354	8181	5	4A
0005433633730	8181	6	4D
0005434143727	8181	7	5D
0005433805521	8181	8	6A
0005433633841	8181	9	5F
0005433805483	8181	10	6F
0005433805505	8181	11	6D
0005433633791	8181	12	7A
0005433805387	8181	13	7C
0005434271316	8181	14	7F
0005433633636	8181	15	7D
0005433805468	8181	16	8C
0005433805271	8181	17	8D
0005433805446	8181	18	8E
0005433805389	8181	19	9A
0005433805353	8181	20	9C
0005433805430	8181	21	10A
0005434271318	8181	22	10F
0005433805507	8181	23	11C
0005433805438	8181	24	12A
0005433633804	8181	25	12D
0005434143729	8181	26	12C
0005433633780	8181	27	12E
0005433633699	8181	28	13A
0005433805420	8181	29	13C
0005433805442	8181	30	13E
0005434271309	8181	31	13F
0005433633789	8181	32	14D
0005433633790	8181	33	14F
0005433805491	8181	34	15B
0005433633925	8181	35	15D
0005433633924	8181	36	15F
0005433633842	8181	37	16A
0005433633755	8181	38	16C
0005433633805	8181	39	16D
0005433805284	8181	40	17A
0005433805340	8181	41	16F
0005433805416	8181	42	17B
0005433805339	8181	43	17C
0005433633724	8181	44	17F
0005433805415	8181	45	18A
0005433633638	8181	46	18B
0005433805565	8181	47	18E
0005433805440	8181	48	18D
0005433805388	8181	49	20B
0005433805517	8181	50	20D
0005433805471	8181	51	20E
0005433633806	8181	52	20F
0005433805365	8181	53	22C
0005433633889	8181	54	22E
0005433633851	8181	55	22D
0005433805506	8181	56	22F
0005433805364	8181	57	23B
0005433805504	8181	58	24E
0005433805448	8181	59	24D
0005433805522	8181	60	25A
0005433805484	8181	61	25F
0005433633637	8181	62	25E
0005433805441	8181	63	26B
0005433805366	8181	64	26C
0005433633813	8181	65	26E
0005433634003	8181	66	26D
0005433633799	8181	67	26F
0005433633923	8181	68	27B
0005433633777	8181	69	28C
0005433805419	8181	70	28E
0005433805418	8181	71	28D
0005433805443	8181	72	29B
0005433805412	8181	73	29F
0005433805439	8181	74	29E
0005433633888	8181	75	30A
0005433633781	8181	76	30B
0005433634004	8181	77	31A
0005433633766	8181	78	31E
0005434183587	8182	1	10B
0005433722293	4536	1	1A
0005432383607	4536	2	1C
0005432728073	4536	3	1D
0005432728072	4536	4	1F
0005433722285	4536	5	2D
0005432383578	4536	6	2F
0005433722284	4536	7	3A
0005432383602	4536	8	3F
0005432383600	4536	9	4A
0005432728064	4536	10	4C
0005433722286	4536	11	4D
0005433722289	4536	12	5A
0005433194888	4536	13	5C
0005433453780	4536	14	5D
0005433194890	4536	15	6A
0005432383597	4536	16	6C
0005432383584	4536	17	6D
0005432383587	4536	18	6E
0005432728063	4536	19	6F
0005432383586	4536	20	7A
0005433194889	4536	21	7C
0005432728070	4536	22	7F
0005432383608	4536	23	8A
0005433454898	4536	24	8D
0005432383605	4536	25	8F
0005433722291	4536	26	9A
0005432383606	4536	27	9C
0005432383598	4536	28	9D
0005432728071	4536	29	9E
0005432383591	4536	30	9F
0005432383604	4536	31	10A
0005433453781	4536	32	10C
0005432383590	4536	33	10E
0005432383583	4536	34	10F
0005432383574	4536	35	11C
0005432728069	4536	36	11D
0005432383572	4536	37	11E
0005432383581	4536	38	12A
0005432383603	4536	39	12C
0005432383582	4536	40	12D
0005433722292	4536	41	12F
0005432383601	4536	42	13A
0005432728062	4536	43	13C
0005432383585	4536	44	13E
0005432728067	4536	45	13F
0005432383579	4536	46	14E
0005432383571	4536	47	14F
0005432728065	4536	48	15A
0005433722288	4536	49	15C
0005432383573	4536	50	15D
0005432383588	4536	51	15E
0005432383576	4536	52	15F
0005433194891	4536	53	16A
0005432383577	4536	54	16C
0005432383589	4536	55	16D
0005432728068	4536	56	16E
0005432383594	4536	57	17A
0005433722287	4536	58	17E
0005432383592	4536	59	18A
0005432383596	4536	60	18D
0005432728066	4536	61	18E
0005432383575	4536	62	19D
0005432383580	4536	63	19E
0005432383599	4536	64	19F
0005432383595	4536	65	20A
0005433722290	4536	66	20D
0005432383593	4536	67	20F
0005432382998	30154	1	1A
0005432727918	30154	2	1C
0005432727955	30154	3	1D
0005432727954	30154	4	2A
0005432727951	30154	5	2D
0005432383093	30154	6	2F
0005432383049	30154	7	3A
0005432727917	30154	8	3C
0005432728009	30154	9	3F
0005432727970	30154	10	4C
0005433194856	30154	11	4D
0005432383167	30154	12	4E
0005432382987	30154	13	4F
0005432382994	30154	14	5A
0005432383137	30154	15	6A
0005432727969	30154	16	6C
0005432383142	30154	17	6E
0005432383179	30154	18	6F
0005432727986	30154	19	7A
0005432383169	30154	20	7C
0005432727982	30154	21	7D
0005432383098	30154	22	8A
0005432383017	30154	23	8C
0005432383014	30154	24	8F
0005432383141	30154	25	9A
0005432383162	30154	26	9D
0005432727963	30154	27	9E
0005432382993	30154	28	9F
0005432382986	30154	29	10A
0005432727978	30154	30	10D
0005432383112	30154	31	10E
0005432727988	30154	32	11D
0005432727962	30154	33	11E
0005432383173	30154	34	11F
0005432727946	30154	35	12A
0005432727952	30154	36	12C
0005432383068	30154	37	12E
0005432382970	30154	38	13D
0005432383101	30154	39	13E
0005432383013	30154	40	13F
0005432383022	30154	41	14D
0005432383174	30154	42	14E
0005432383097	30154	43	14F
0005432727977	30154	44	15D
0005432383188	30154	45	15E
0005432727943	30154	46	16A
0005432383005	30154	47	16C
0005432383138	30154	48	16D
0005432383004	30154	49	17A
0005432383131	30154	50	17C
0005432383092	30154	51	17D
0005432727976	30154	52	17F
0005432383187	30154	53	18A
0005432383094	30154	54	18C
0005432383135	30154	55	18E
0005432383146	30154	56	19A
0005432728010	30154	57	19C
0005432727953	30154	58	19E
0005432383143	30154	59	19F
0005432727997	30154	60	20A
0005432383067	30154	61	20E
0005432383015	30154	62	20F
0005435541225	1717	1	1A
0005432294513	1717	2	1D
0005433516981	1717	3	1F
0005435529480	1717	4	2A
0005432925061	1717	5	2C
0005435541242	1717	6	2F
0005433516987	1717	7	3C
0005435529496	1717	8	3F
0005435529488	1717	9	4C
0005435529479	1717	10	5A
0005435529498	1717	11	5C
0005435541232	1717	12	5D
0005432925052	1717	13	5F
0005435529481	1717	14	6A
0005435541231	1717	15	6C
0005435541238	1717	16	6D
0005435541223	1717	17	6E
0005432925053	1717	18	6F
0005435529484	1717	19	7A
0005435529494	1717	20	7E
0005435541236	1717	21	8A
0005433516985	1717	22	8C
0005435541235	1717	23	8D
0005435541240	1717	24	8F
0005433516984	1717	25	9C
0005433516988	1717	26	9D
0005435529482	1717	27	9F
0005433516980	1717	28	10A
0005435529491	1717	29	10D
0005435541222	1717	30	10E
0005435529489	1717	31	11D
0005435529493	1717	32	11E
0005433516979	1717	33	11F
0005435541226	1717	34	12A
0005435529478	1717	35	12D
0005435541241	1717	36	12F
0005432925029	1717	37	13E
0005432294511	1717	38	13F
0005435541227	1717	39	14A
0005435529486	1717	40	14D
0005435541239	1717	41	15C
0005435541229	1717	42	15D
0005432294512	1717	43	15F
0005435529495	1717	44	16A
0005433516982	1717	45	16C
0005435529485	1717	46	16E
0005435541237	1717	47	17A
0005435529477	1717	48	17C
0005435529483	1717	49	17E
0005435541234	1717	50	17F
0005435541228	1717	51	18A
0005435541233	1717	52	18C
0005433516983	1717	53	18D
0005433516986	1717	54	19A
0005432925047	1717	55	19C
0005435529490	1717	56	19E
0005435529487	1717	57	19F
0005435529492	1717	58	20C
0005435529497	1717	59	20D
0005435541224	1717	60	20E
0005435541230	1717	61	20F
0005435540965	21981	1	2A
0005433516919	21981	2	2C
0005433516909	21981	3	2D
0005433516905	21981	4	3A
0005435541002	21981	5	4A
0005435541073	21981	6	4C
0005435540947	21981	7	4D
0005435517903	21981	8	5D
0005435541047	21981	9	6C
0005435541007	21981	10	6D
0005433516886	21981	11	6E
0005435541071	21981	12	6F
0005435517899	21981	13	7A
0005435541029	21981	14	7C
0005433516936	21981	15	7D
0005433516883	21981	16	7E
0005433516929	21981	17	8C
0005435541039	21981	18	8D
0005433516920	21981	19	8F
0005433516897	21981	20	9A
0005435540946	21981	21	9C
0005435541046	21981	22	9E
0005435517936	21981	23	9F
0005435541016	21981	24	10C
0005435541030	21981	25	10D
0005432925086	21981	26	10E
0005435517914	21981	27	10F
0005435517915	21981	28	11A
0005433516898	21981	29	11D
0005435540887	21981	30	11F
0005435541027	21981	31	12E
0005435541008	21981	32	13C
0005432925084	21981	33	13D
0005433516901	21981	34	14C
0005432925089	21981	35	14D
0005433516882	21981	36	15C
0005432925085	21981	37	15D
0005435541028	21981	38	16A
0005432925087	21981	39	16E
0005435541070	21981	40	17A
0005435517960	21981	41	17F
0005435517935	21981	42	18A
0005435541017	21981	43	18D
0005433516900	21981	44	18F
0005435517938	21981	45	19A
0005435517900	21981	46	19C
0005432925088	21981	47	19D
0005435540997	21981	48	19F
0005433516871	21981	49	20A
0005433516857	21981	50	20D
0005435541018	21981	51	20E
0005432073427	7368	1	1A
0005435252799	7368	2	1C
0005434459029	7368	3	1D
0005432839348	7368	4	1F
0005434459025	7368	5	2A
0005434459027	7368	6	2C
0005435252773	7368	7	2F
0005432839365	7368	8	3A
0005434459014	7368	9	3C
0005432839342	7368	10	3D
0005432839350	7368	11	3F
0005434459019	7368	12	4A
0005434459010	7368	13	4D
0005432073426	7368	14	4E
0005435252709	7368	15	4F
0005432823469	7368	16	5A
0005435252690	7368	17	5C
0005435252756	7368	18	5D
0005434459012	7368	19	5E
0005434459013	7368	20	5F
0005432839367	7368	21	6A
0005434459018	7368	22	6D
0005434459024	7368	23	6E
0005435252789	7368	24	6F
0005432839341	7368	25	7A
0005432839345	7368	26	7C
0005432839346	7368	27	7E
0005432839369	7368	28	7F
0005434459016	7368	29	8A
0005432839364	7368	30	8C
0005434459030	7368	31	8E
0005434459026	7368	32	8F
0005432839361	7368	33	9A
0005432839353	7368	34	9C
0005435252782	7368	35	9E
0005432839354	7368	36	9F
0005432839340	7368	37	10A
0005432841032	7368	38	10C
0005435252764	7368	39	10D
0005435252757	7368	40	10F
0005435252675	7368	41	11C
0005432839357	7368	42	11D
0005435252701	7368	43	11E
0005432839351	7368	44	11F
0005432839360	7368	45	12A
0005435491436	7368	46	12C
0005434459020	7368	47	12D
0005432839347	7368	48	12E
0005432839362	7368	49	12F
0005434459022	7368	50	13A
0005435252800	7368	51	13C
0005432839344	7368	52	13D
0005432839363	7368	53	13E
0005432839372	7368	54	13F
0005435252700	7368	55	14A
0005435252699	7368	56	14C
0005434459015	7368	57	14D
0005432839352	7368	58	14F
0005432839366	7368	59	15A
0005435252689	7368	60	15C
0005435252788	7368	61	15D
0005435252783	7368	62	15E
0005434459028	7368	63	15F
0005435491447	7368	64	16A
0005434459011	7368	65	16C
0005435252706	7368	66	16D
0005435252714	7368	67	16E
0005434459017	7368	68	17A
0005432823468	7368	69	17C
0005432839368	7368	70	17D
0005432839371	7368	71	17E
0005435252715	7368	72	17F
0005432839358	7368	73	18A
0005432839349	7368	74	18C
0005435252705	7368	75	18E
0005432841033	7368	76	18F
0005432839355	7368	77	19C
0005432839356	7368	78	19D
0005435252708	7368	79	19E
0005434459021	7368	80	19F
0005434459023	7368	81	20A
0005432839343	7368	82	20C
0005432839359	7368	83	20D
0005435252727	7368	84	20E
0005432839370	7368	85	20F
0005432839113	28907	1	1A
0005434458824	28907	2	1D
0005432839245	28907	3	1F
0005432001043	28907	4	2A
0005435252885	28907	5	2C
0005432839169	28907	6	2D
0005432839136	28907	7	2F
0005434664984	28907	8	3C
0005432839125	28907	9	3D
0005434458857	28907	10	3F
0005435252886	28907	11	4A
0005435252891	28907	12	4F
0005432839198	28907	13	5A
0005432839144	28907	14	5E
0005434458851	28907	15	5F
0005434458810	28907	16	6A
0005432839007	28907	17	6C
0005435252892	28907	18	6D
0005435252887	28907	19	6E
0005432839008	28907	20	6F
0005432839105	28907	21	7C
0005432839186	28907	22	7D
0005432839030	28907	23	7E
0005434458865	28907	24	8A
0005435252879	28907	25	8C
0005434458941	28907	26	8D
0005432839167	28907	27	8E
0005435491460	28907	28	9C
0005435252884	28907	29	9D
0005435252875	28907	30	9E
0005434458887	28907	31	9F
0005435252880	28907	32	10A
0005434458904	28907	33	10C
0005432001044	28907	34	10D
0005432839123	28907	35	10F
0005435491462	28907	36	11A
0005432839185	28907	37	11C
0005432839197	28907	38	11F
0005434458866	28907	39	12A
0005435252889	28907	40	12C
0005435252874	28907	41	12E
0005435252878	28907	42	12F
0005435491461	28907	43	13A
0005432839031	28907	44	13C
0005435252882	28907	45	13E
0005434664983	28907	46	13F
0005434458776	28907	47	14A
0005432839127	28907	48	14C
0005432839046	28907	49	14D
0005434664985	28907	50	14E
0005435252888	28907	51	14F
0005435252876	28907	52	15A
0005432839112	28907	53	15D
0005434458942	28907	54	15E
0005432839168	28907	55	15F
0005435252890	28907	56	16A
0005432839126	28907	57	16C
0005432838991	28907	58	16D
0005434458876	28907	59	16E
0005434458811	28907	60	17A
0005434458905	28907	61	17F
0005432839242	28907	62	18A
0005432838990	28907	63	18C
0005432001045	28907	64	18E
0005435252881	28907	65	19A
0005432839101	28907	66	19D
0005435252883	28907	67	19E
0005432839143	28907	68	19F
0005432839241	28907	69	20A
0005432839091	28907	70	20C
0005435252877	28907	71	20D
0005434458775	28907	72	20E
0005434664986	28907	73	20F
0005435990697	8788	1	2A
0005434276063	8788	2	6A
0005434276058	8788	3	7E
0005434276040	8788	4	8C
0005435990696	8788	5	9F
0005434276059	8788	6	10D
0005434276018	8788	7	10F
0005435990700	8788	8	13C
0005434276053	8788	9	13D
0005435990698	8788	10	18A
0005435990695	8788	11	18F
0005435990699	8788	12	21C
0005434276084	15732	1	3C
0005434276088	15732	2	5A
0005435990663	15732	3	6B
0005435990653	15732	4	7F
0005435990606	15732	5	14D
0005434276087	15732	6	18B
0005434276085	15732	7	18E
0005435990607	15732	8	19A
0005435990652	15732	9	21B
0005434276086	15732	10	20F
0005432427159	20615	1	3D
0005433476893	20615	2	4B
0005432427161	20615	3	5B
0005432427163	20615	4	6C
0005433476898	20615	5	7A
0005432427164	20615	6	7B
0005432427162	20615	7	18A
0005433476899	20615	8	18C
0005433476891	20615	9	19A
0005433476903	20615	10	19D
0005433476900	20615	11	20B
0005433476892	20615	12	20D
0005433476897	20615	13	21A
0005432427160	20615	14	21C
0005432427165	20615	15	22B
0005432427166	20615	16	22C
0005432427146	30859	1	1B
0005432427139	30859	2	2C
0005432427150	30859	3	2D
0005432427142	30859	4	3D
0005433476915	30859	5	4C
0005432427138	30859	6	7A
0005433476913	30859	7	7B
0005433476914	30859	8	20B
0005432427144	30859	9	21D
0005432427132	30859	10	22A
0005433476916	30859	11	22C
0005432427143	30859	12	23A
0005432909337	23839	1	1A
0005433468362	23839	2	2B
0005433468311	23839	3	3D
0005432909341	23839	4	4B
0005433468315	23839	5	5C
0005432909335	23839	6	6A
0005432909332	23839	7	6B
0005432909339	23839	8	6C
0005433468344	23839	9	6D
0005432909334	23839	10	7A
0005433468364	23839	11	7C
0005432909342	23839	12	18B
0005432909340	23839	13	18C
0005433468378	23839	14	19A
0005432909333	23839	15	18D
0005432909336	23839	16	19C
0005433468350	23839	17	20B
0005433468348	23839	18	21A
0005432909338	23839	19	21B
0005433468365	23839	20	21C
0005433468349	23839	21	21D
0005433468331	23839	22	22A
0005433468340	23839	23	22B
0005433468377	23839	24	23A
0005433468300	23839	25	23B
0005432336160	6406	1	1D
0005434149759	6406	2	2A
0005435490220	6406	3	1F
0005434149740	6406	4	2C
0005432336159	6406	5	2D
0005435177191	6406	6	2F
0005434149714	6406	7	3D
0005434149735	6406	8	3C
0005435723048	6406	9	3F
0005432360860	6406	10	4A
0005432360854	6406	11	4D
0005432336156	6406	12	4C
0005435177105	6406	13	4E
0005432360847	6406	14	4F
0005432360859	6406	15	5A
0005432360875	6406	16	5D
0005435177092	6406	17	5C
0005432363449	6406	18	5F
0005432360872	6406	19	5E
0005432360881	6406	20	6A
0005432360850	6406	21	6C
0005432360836	6406	22	6B
0005432360870	6406	23	6D
0005434149799	6406	24	6F
0005434149801	6406	25	6E
0005435177242	6406	26	7A
0005432062284	6406	27	7D
0005432360855	6406	28	7C
0005432360840	6406	29	7F
0005432336154	6406	30	7E
0005432360864	6406	31	8B
0005432360839	6406	32	8C
0005435177009	6406	33	8D
0005432360874	6406	34	8F
0005432360876	6406	35	8E
0005432360852	6406	36	9A
0005432360846	6406	37	9E
0005432336155	6406	38	9D
0005432360863	6406	39	9F
0005432360879	6406	40	10C
0005432062283	6406	41	10B
0005435490245	6406	42	11A
0005432360845	6406	43	11C
0005434149752	6406	44	11B
0005432336153	6406	45	11D
0005432360867	6406	46	11E
0005435177093	6406	47	11F
0005432360880	6406	48	12A
0005432360835	6406	49	12C
0005432360848	6406	50	12B
0005435723043	6406	51	12E
0005432360843	6406	52	12F
0005432360861	6406	53	13A
0005435177156	6406	54	13B
0005432360871	6406	55	13D
0005432360856	6406	56	13E
0005435177157	6406	57	14A
0005435177194	6406	58	13F
0005432360841	6406	59	14C
0005434149713	6406	60	14B
0005432360869	6406	61	14D
0005432360857	6406	62	14F
0005434149736	6406	63	15C
0005432360834	6406	64	15B
0005432360873	6406	65	15D
0005432360853	6406	66	15E
0005432360838	6406	67	15F
0005435723044	6406	68	16B
0005432360862	6406	69	16A
0005432336158	6406	70	16C
0005432360849	6406	71	16E
0005435177201	6406	72	16D
0005432360878	6406	73	16F
0005432360868	6406	74	17C
0005435177106	6406	75	17E
0005435177091	6406	76	17D
0005432062282	6406	77	18A
0005435490223	6406	78	18B
0005432360866	6406	79	18D
0005435490244	6406	80	18C
0005434149726	6406	81	18E
0005432363450	6406	82	18F
0005432360882	6406	83	19A
0005432360877	6406	84	19B
0005432360858	6406	85	19D
0005434149720	6406	86	19F
0005434149721	6406	87	20A
0005434149749	6406	88	20C
0005432360842	6406	89	20B
0005432363451	6406	90	20D
0005435177108	6406	91	20E
0005434149768	6406	92	21A
0005432336162	6406	93	21C
0005432360851	6406	94	21B
0005434149800	6406	95	21D
0005435723047	6406	96	21F
0005432336157	6406	97	21E
0005432062281	6406	98	22A
0005432360837	6406	99	22B
0005432336161	6406	100	22C
0005432336152	6406	101	22D
0005432360865	6406	102	22F
0005432062285	6406	103	22E
0005432360844	6406	104	23A
0005434149754	6406	105	23B
0005435177117	6406	106	23D
0005432360883	6406	107	23C
0005432062286	6406	108	23E
0005434149847	21033	1	1A
0005435177365	21033	2	1C
0005432360400	21033	3	1F
0005432336075	21033	4	1D
0005432360335	21033	5	2C
0005435177369	21033	6	2A
0005434149853	21033	7	2D
0005435490268	21033	8	3A
0005432360563	21033	9	2F
0005432360483	21033	10	3C
0005432360343	21033	11	3D
0005435177355	21033	12	3F
0005432336041	21033	13	4B
0005435177370	21033	14	4A
0005435177349	21033	15	4D
0005432360384	21033	16	4C
0005432360303	21033	17	4E
0005432335957	21033	18	4F
0005432360447	21033	19	5B
0005435177354	21033	20	5A
0005434149850	21033	21	5C
0005435177360	21033	22	5E
0005432360281	21033	23	5F
0005432335975	21033	24	6A
0005432360502	21033	25	6C
0005432336078	21033	26	6B
0005432360304	21033	27	6D
0005432336069	21033	28	6E
0005435177366	21033	29	7A
0005432360443	21033	30	7C
0005434149849	21033	31	7E
0005432360516	21033	32	7D
0005435723068	21033	33	7F
0005432052780	21033	34	8A
0005432360461	21033	35	8B
0005432360239	21033	36	8C
0005435490270	21033	37	8E
0005435177358	21033	38	8D
0005432360404	21033	39	8F
0005435177361	21033	40	9A
0005435177363	21033	41	9C
0005435177367	21033	42	9B
0005432360351	21033	43	9E
0005435723066	21033	44	9D
0005432360198	21033	45	9F
0005432360722	21033	46	10D
0005435177368	21033	47	10C
0005435177352	21033	48	11A
0005432360589	21033	49	10E
0005432360488	21033	50	11C
0005432336085	21033	51	11D
0005432360448	21033	52	11E
0005432360280	21033	53	11F
0005435177356	21033	54	12A
0005432360681	21033	55	12B
0005432360451	21033	56	12D
0005432360585	21033	57	12E
0005432336061	21033	58	12F
0005434149848	21033	59	13A
0005432052777	21033	60	13C
0005432360276	21033	61	13B
0005435723069	21033	62	13D
0005435177357	21033	63	13E
0005432360240	21033	64	13F
0005432360322	21033	65	14B
0005434149855	21033	66	14C
0005432360323	21033	67	14D
0005432360282	21033	68	14E
0005432360683	21033	69	15B
0005432360199	21033	70	15D
0005434149846	21033	71	15E
0005432336079	21033	72	16B
0005432360682	21033	73	16A
0005435177353	21033	74	16C
0005432052779	21033	75	16D
0005432360551	21033	76	16F
0005432360491	21033	77	16E
0005434149851	21033	78	17A
0005432336042	21033	79	17B
0005435177371	21033	80	17C
0005432360399	21033	81	17E
0005435177373	21033	82	17D
0005432360125	21033	83	18A
0005435177350	21033	84	18B
0005432335974	21033	85	18D
0005432360723	21033	86	18C
0005435490269	21033	87	18E
0005435490271	21033	88	19A
0005434149845	21033	89	18F
0005432360442	21033	90	19B
0005435177359	21033	91	19D
0005435177362	21033	92	19C
0005432360446	21033	93	19E
0005432336019	21033	94	19F
0005434149852	21033	95	20A
0005432360629	21033	96	20D
0005435177351	21033	97	20C
0005432360370	21033	98	20E
0005435177347	21033	99	20F
0005432360283	21033	100	21A
0005432336059	21033	101	21C
0005434149854	21033	102	21D
0005432335973	21033	103	21E
0005435723067	21033	104	22A
0005432360429	21033	105	21F
0005435177348	21033	106	22B
0005435177346	21033	107	22C
0005432360273	21033	108	22D
0005432360440	21033	109	22E
0005432360352	21033	110	23A
0005434149856	21033	111	22F
0005432052778	21033	112	23B
0005432360302	21033	113	23C
0005435177364	21033	114	23E
0005435177372	21033	115	23D
0005432360630	21033	116	23F
0005434458841	17734	1	1A
0005434463930	17734	2	1B
0005434458880	17734	3	1D
0005434458910	17734	4	2A
0005434186230	17734	5	3C
0005434458874	17734	6	4A
0005434463933	17734	7	4C
0005434186229	17734	8	5A
0005434458823	17734	9	5B
0005434458844	17734	10	6A
0005434458881	17734	11	6B
0005434458843	17734	12	6C
0005434458964	17734	13	7A
0005434458838	17734	14	7D
0005434463931	17734	15	18A
0005434458871	17734	16	18B
0005434458842	17734	17	18D
0005434458864	17734	18	19C
0005434458870	17734	19	21A
0005434458875	17734	20	21D
0005434463932	17734	21	22C
0005434458903	17734	22	23B
0005434463951	29096	1	1A
0005434459028	29096	2	1B
0005434186202	29096	3	1C
0005434459027	29096	4	1D
0005434462811	29096	5	2A
0005434459022	29096	6	2B
0005434462810	29096	7	2C
0005434459011	29096	8	2D
0005434459023	29096	9	3A
0005434459016	29096	10	3D
0005434459025	29096	11	4B
0005434459015	29096	12	4D
0005434448348	29096	13	5A
0005434448346	29096	14	5D
0005434459024	29096	15	6A
0005434459021	29096	16	6D
0005434459014	29096	17	7B
0005434463949	29096	18	7C
0005434448349	29096	19	7D
0005434448347	29096	20	18A
0005434459026	29096	21	19B
0005434459013	29096	22	20A
0005434459019	29096	23	20B
0005434459020	29096	24	20D
0005434186198	29096	25	21A
0005434459029	29096	26	21B
0005434463950	29096	27	21C
0005434459018	29096	28	21D
0005434459017	29096	29	22B
0005434462809	29096	30	22C
0005434459012	29096	31	22D
0005434459010	29096	32	23A
0005434459030	29096	33	23B
0005432664167	6493	1	1A
0005432663060	6493	2	2D
0005432661951	6493	3	3A
0005432664161	6493	4	3D
0005432663061	6493	5	3C
0005432661949	6493	6	4A
0005432664159	6493	7	4F
0005432661952	6493	8	4D
0005432664171	6493	9	5A
0005432663069	6493	10	5F
0005432664162	6493	11	5D
0005432661948	6493	12	6C
0005432661954	6493	13	6D
0005432663056	6493	14	7A
0005432664164	6493	15	7C
0005432661958	6493	16	7D
0005432661944	6493	17	7F
0005432664168	6493	18	8B
0005432661957	6493	19	8F
0005432664172	6493	20	9B
0005432661947	6493	21	9E
0005432663058	6493	22	9D
0005432664169	6493	23	10C
0005432663064	6493	24	10B
0005432663065	6493	25	10D
0005432664165	6493	26	10F
0005432663063	6493	27	11F
0005432664158	6493	28	11E
0005432663057	6493	29	12B
0005432661950	6493	30	12C
0005432663067	6493	31	12E
0005432663059	6493	32	13A
0005432661953	6493	33	13B
0005432663070	6493	34	13E
0005432661959	6493	35	14F
0005432661946	6493	36	16A
0005432663062	6493	37	16D
0005432664163	6493	38	18B
0005432661945	6493	39	18A
0005432663068	6493	40	18D
0005432664170	6493	41	20A
0005432661956	6493	42	20D
0005432664160	6493	43	20C
0005432663066	6493	44	20E
0005432664166	6493	45	21B
0005432661955	6493	46	21F
0005432604718	21462	1	1A
0005432604730	21462	2	1B
0005432604701	21462	3	1C
0005432604715	21462	4	1D
0005432604728	21462	5	2A
0005432604707	21462	6	2C
0005432604698	21462	7	2D
0005432604697	21462	8	3A
0005432604727	21462	9	3B
0005432604725	21462	10	3C
0005432604723	21462	11	4B
0005432604704	21462	12	4A
0005432604733	21462	13	4C
0005432604724	21462	14	5C
0005432604736	21462	15	5D
0005432604717	21462	16	6A
0005432604721	21462	17	6B
0005432604729	21462	18	6C
0005432604734	21462	19	6D
0005432604716	21462	20	7A
0005432604714	21462	21	7B
0005432604726	21462	22	7C
0005432604699	21462	23	7D
0005432604735	21462	24	18A
0005432604703	21462	25	18B
0005432604713	21462	26	18C
0005432604705	21462	27	18D
0005432604731	21462	28	19B
0005432604711	21462	29	19C
0005432604732	21462	30	19D
0005432604709	21462	31	20A
0005432604722	21462	32	20C
0005432604719	21462	33	21A
0005432604720	21462	34	21B
0005432604700	21462	35	21C
0005432604712	21462	36	21D
0005432604706	21462	37	22A
0005432604708	21462	38	22B
0005432604696	21462	39	22C
0005432604702	21462	40	23A
0005432604710	21462	41	23B
0005432604267	31663	1	1A
0005432604452	31663	2	1B
0005432604181	31663	3	1C
0005432604347	31663	4	1D
0005432604210	31663	5	2A
0005432604180	31663	6	2B
0005432604322	31663	7	2C
0005432604313	31663	8	2D
0005432604441	31663	9	3A
0005432604219	31663	10	3B
0005432604244	31663	11	3C
0005432604311	31663	12	3D
0005432604442	31663	13	4A
0005432604371	31663	14	4C
0005432604114	31663	15	4D
0005432604500	31663	16	5A
0005432604320	31663	17	5B
0005432604367	31663	18	5C
0005432604342	31663	19	5D
0005432604509	31663	20	6A
0005432604392	31663	21	6B
0005432604402	31663	22	6C
0005432604422	31663	23	6D
0005432604501	31663	24	7A
0005432604283	31663	25	7B
0005432604113	31663	26	7C
0005432604372	31663	27	7D
0005432604186	31663	28	18A
0005432604458	31663	29	18B
0005432604478	31663	30	18C
0005432604343	31663	31	19A
0005432604383	31663	32	19B
0005432604382	31663	33	19C
0005432604439	31663	34	19D
0005432604569	31663	35	20A
0005432604418	31663	36	20B
0005432604237	31663	37	20C
0005432604417	31663	38	20D
0005432604344	31663	39	21A
0005432604341	31663	40	21B
0005432604336	31663	41	21C
0005432604497	31663	42	21D
0005432604438	31663	43	22A
0005432604486	31663	44	22B
0005432604282	31663	45	22C
0005432604268	31663	46	22D
0005432604319	31663	47	23A
0005432604487	31663	48	23B
0005433293258	12298	1	1A
0005435154603	12298	2	1D
0005433293231	12298	3	3A
0005433293248	12298	4	3B
0005433293212	12298	5	4D
0005435154604	12298	6	5A
0005435154610	12298	7	5B
0005433293253	12298	8	6A
0005435154605	12298	9	7A
0005433293252	12298	10	7B
0005435154602	12298	11	7D
0005433293263	12298	12	18A
0005433293277	12298	13	18B
0005435154607	12298	14	19B
0005433293251	12298	15	19C
0005433293224	12298	16	19D
0005435154609	12298	17	20C
0005433293276	12298	18	21B
0005433293225	12298	19	22A
0005435154608	12298	20	22C
0005433293262	12298	21	22D
0005435154606	12298	22	23B
0005433473269	23905	1	1B
0005433473273	23905	2	2A
0005435257292	23905	3	2B
0005433473300	23905	4	2C
0005433473264	23905	5	2D
0005433473243	23905	6	3B
0005435257288	23905	7	3C
0005433473272	23905	8	3D
0005435257290	23905	9	4B
0005435257286	23905	10	4C
0005435257291	23905	11	5A
0005433473276	23905	12	5B
0005433473245	23905	13	5C
0005433473233	23905	14	5D
0005435257289	23905	15	6A
0005433473291	23905	16	6B
0005433473235	23905	17	6C
0005433473270	23905	18	6D
0005435257293	23905	19	7B
0005433473240	23905	20	7C
0005433473244	23905	21	7D
0005435257294	23905	22	18B
0005433473222	23905	23	18D
0005433473223	23905	24	19B
0005433473334	23905	25	20A
0005435257296	23905	26	20B
0005433473239	23905	27	20D
0005433473224	23905	28	21A
0005433473290	23905	29	21C
0005435257295	23905	30	21D
0005433473231	23905	31	22B
0005435257287	23905	32	22C
0005433473234	23905	33	23A
0005433473268	23905	34	23B
0005434606833	18884	1	1A
0005435904902	18884	2	3B
0005435904901	18884	3	3A
0005435904903	18884	4	4A
0005435904900	18884	5	4B
0005434606824	18884	6	5A
0005434606865	22290	1	1A
0005434606864	22290	2	2B
0005434604928	22290	3	3B
0005434604929	22290	4	4A
0005434606863	22290	5	5A
0005435904414	3845	1	1A
0005435904412	3845	2	1C
0005434522487	3845	3	2A
0005434522486	3845	4	2C
0005434522483	3845	5	2D
0005434522484	3845	6	3A
0005434522480	3845	7	3C
0005435904413	3845	8	4A
0005434522485	3845	9	4D
0005435904404	3845	10	5A
0005434522481	3845	11	6A
0005434602923	3845	12	7B
0005434522479	3845	13	7C
0005434602926	3845	14	18B
0005434522482	3845	15	18C
0005434602925	3845	16	19B
0005434522488	3845	17	19C
0005434602928	3845	18	20B
0005434602927	3845	19	20C
0005435904408	3845	20	21C
0005435904410	3845	21	21D
0005434602924	3845	22	22B
0005435904432	19062	1	1A
0005434604914	19062	2	1D
0005434602889	19062	3	2A
0005434604881	19062	4	2B
0005434602905	19062	5	2D
0005434522458	19062	6	4B
0005434522465	19062	7	4C
0005435904710	19062	8	4D
0005434604893	19062	9	5D
0005434602902	19062	10	6B
0005434604913	19062	11	6C
0005434602901	19062	12	6D
0005434604905	19062	13	18A
0005435904428	19062	14	18B
0005434604888	19062	15	18C
0005435904431	19062	16	19A
0005435904429	19062	17	19B
0005434522456	19062	18	19D
0005434602903	19062	19	19C
0005434602906	19062	20	20B
0005435904430	19062	21	21A
0005434522459	19062	22	21B
0005434604882	19062	23	22A
0005434602904	19062	24	22B
0005434602895	19062	25	22C
0005435904709	19062	26	23A
0005433875386	371	1	1A
0005433293250	371	2	1C
0005432891060	371	3	1D
0005432747958	371	4	1F
0005433293271	371	5	2A
0005433293281	371	6	2C
0005432747930	371	7	2D
0005432747946	371	8	2F
0005432747955	371	9	3A
0005432891042	371	10	3C
0005432749806	371	11	3D
0005433875371	371	12	3F
0005432891014	371	13	4A
0005432891031	371	14	4C
0005432747962	371	15	4D
0005432747956	371	16	4F
0005433875385	371	17	5A
0005432220046	371	18	5C
0005432747936	371	19	5D
0005432747931	371	20	5E
0005432747948	371	21	5F
0005433293272	371	22	6A
0005432747954	371	23	6C
0005432891064	371	24	6D
0005432891022	371	25	6E
0005432220047	371	26	6F
0005432747968	371	27	7A
0005432220045	371	28	7C
0005432751559	371	29	7D
0005435154611	371	30	7E
0005432747945	371	31	7F
0005432891128	371	32	8A
0005432747960	371	33	8C
0005432891130	371	34	8D
0005432749805	371	35	8E
0005432747935	371	36	9A
0005433293249	371	37	9C
0005433293259	371	38	9E
0005432747965	371	39	9F
0005432747942	371	40	10A
0005433293260	371	41	10C
0005432891129	371	42	10D
0005432747952	371	43	10E
0005432891051	371	44	10F
0005432747957	371	45	11C
0005432747970	371	46	11D
0005432747949	371	47	11E
0005432747932	371	48	11F
0005432747929	371	49	12A
0005432747967	371	50	12C
0005432891074	371	51	12D
0005432747933	371	52	12E
0005432891021	371	53	12F
0005433293236	371	54	13A
0005432753333	371	55	13C
0005432747944	371	56	13E
0005432891041	371	57	14A
0005432891085	371	58	14C
0005432747950	371	59	14D
0005432751556	371	60	14E
0005432747937	371	61	14F
0005432891038	371	62	15A
0005432747951	371	63	15C
0005432747966	371	64	15D
0005432747963	371	65	15E
0005432891104	371	66	15F
0005432747969	371	67	16A
0005432747934	371	68	16C
0005432220044	371	69	16E
0005432747961	371	70	16F
0005432891108	371	71	17A
0005433293242	371	72	17C
0005432891052	371	73	17D
0005432747938	371	74	17E
0005432747964	371	75	17F
0005432751557	371	76	18A
0005432747947	371	77	18C
0005432891032	371	78	18D
0005432747953	371	79	18E
0005432747941	371	80	18F
0005432891012	371	81	19A
0005432753332	371	82	19C
0005432747940	371	83	19D
0005433293261	371	84	19E
0005432747939	371	85	19F
0005432891039	371	86	20A
0005432747943	371	87	20C
0005432747959	371	88	20D
0005432891084	371	89	20E
0005432751558	371	90	20F
0005432891210	12084	1	1C
0005432747701	12084	2	1D
0005432891212	12084	3	1F
0005432747594	12084	4	2A
0005432891228	12084	5	2D
0005432214827	12084	6	2F
0005432891222	12084	7	3A
0005432747703	12084	8	3D
0005432891219	12084	9	3F
0005432747585	12084	10	4A
0005432747609	12084	11	4C
0005432747621	12084	12	4D
0005432747635	12084	13	4E
0005432891221	12084	14	4F
0005432753300	12084	15	5A
0005432891215	12084	16	5D
0005432756846	12084	17	5E
0005432891225	12084	18	5F
0005432891211	12084	19	6A
0005432747729	12084	20	6C
0005432747636	12084	21	6D
0005432891231	12084	22	6E
0005432747574	12084	23	6F
0005432747751	12084	24	7A
0005432747712	12084	25	7C
0005433875396	12084	26	7E
0005432747595	12084	27	7F
0005432747727	12084	28	8A
0005432747713	12084	29	8C
0005432747749	12084	30	8D
0005432747544	12084	31	9C
0005432747611	12084	32	9D
0005432891223	12084	33	9F
0005432747760	12084	34	10C
0005432747423	12084	35	10E
0005432756847	12084	36	10F
0005432747728	12084	37	11C
0005432747659	12084	38	11D
0005432747750	12084	39	11E
0005432891213	12084	40	12A
0005432747622	12084	41	12C
0005432753299	12084	42	12D
0005432891220	12084	43	12E
0005432891218	12084	44	12F
0005432214826	12084	45	13C
0005432891216	12084	46	13E
0005432747469	12084	47	13F
0005432891230	12084	48	14A
0005432753314	12084	49	14C
0005432891224	12084	50	14D
0005432753294	12084	51	14E
0005432747573	12084	52	14F
0005432749787	12084	53	15E
0005432747586	12084	54	15F
0005433875395	12084	55	16A
0005432891217	12084	56	16D
0005432753313	12084	57	16F
0005432747608	12084	58	17A
0005432747752	12084	59	17D
0005432747759	12084	60	17E
0005432891227	12084	61	17F
0005432891229	12084	62	18A
0005432747762	12084	63	18E
0005433875394	12084	64	18F
0005432891214	12084	65	19E
0005432747865	12084	66	19F
0005432747704	12084	67	20A
0005432747761	12084	68	20C
0005432747705	12084	69	20D
0005432749793	12084	70	20E
0005432891226	12084	71	20F
0005433531328	18946	1	1C
0005433525141	18946	2	1D
0005433525137	18946	3	2B
0005433525145	18946	4	2C
0005433533344	18946	5	3B
0005432927996	18946	6	4A
0005433531327	18946	7	5A
0005433533345	18946	8	5C
0005433531326	18946	9	6B
0005432927995	18946	10	6D
0005433525136	18946	11	7B
0005432928004	18946	12	7D
0005433533342	18946	13	18C
0005433533341	18946	14	18D
0005433533343	18946	15	19B
0005433525142	18946	16	19C
0005433525143	18946	17	20C
0005433525140	18946	18	21A
0005433525144	18946	19	21B
0005433525146	18946	20	21C
0005433531329	18946	21	21D
0005433525139	18946	22	22A
0005433525138	18946	23	22C
0005433531330	18946	24	23A
0005433527271	32459	1	1A
0005433525091	32459	2	1B
0005433524987	32459	3	1D
0005433525083	32459	4	2A
0005433531287	32459	5	2B
0005433525090	32459	6	3C
0005432928044	32459	7	3D
0005433527264	32459	8	4A
0005432928045	32459	9	4C
0005433527258	32459	10	4D
0005433525051	32459	11	5A
0005433524994	32459	12	5B
0005433525092	32459	13	5C
0005433524986	32459	14	5D
0005432928042	32459	15	7A
0005433527257	32459	16	7B
0005433527254	32459	17	7D
0005433531296	32459	18	18A
0005433527255	32459	19	18C
0005433527260	32459	20	19B
0005433527263	32459	21	19C
0005433531288	32459	22	19D
0005432928040	32459	23	20B
0005433525050	32459	24	20D
0005432928043	32459	25	20C
0005433531305	32459	26	21A
0005433527272	32459	27	21B
0005433527277	32459	28	21C
0005433531293	32459	29	21D
0005433531297	32459	30	22B
0005433527259	32459	31	22A
0005432928041	32459	32	22D
0005433525084	32459	33	23A
0005435299771	5267	1	1A
0005434824926	5267	2	1G
0005434824943	5267	3	2A
0005435373109	5267	4	1K
0005435373544	5267	5	1H
0005434824881	5267	6	2C
0005434824864	5267	7	2H
0005434824946	5267	8	2D
0005434824928	5267	9	3A
0005432394148	5267	10	3G
0005434828723	5267	11	3C
0005434824924	5267	12	3H
0005434824835	5267	13	4D
0005435373568	5267	14	5A
0005434824945	5267	15	4K
0005434824944	5267	16	4H
0005435386587	5267	17	5C
0005435178993	5267	18	5G
0005435373441	5267	19	5D
0005435373567	5267	20	11A
0005435735136	5267	21	5K
0005435373543	5267	22	11D
0005434824850	5267	23	11F
0005435373325	5267	24	11H
0005434824845	5267	25	11G
0005434824840	5267	26	12C
0005434824907	5267	27	11K
0005435373369	5267	28	12E
0005434824898	5267	29	12G
0005434824860	5267	30	13A
0005435373420	5267	31	12K
0005434558360	5267	32	12H
0005434824892	5267	33	13C
0005434828722	5267	34	13F
0005434824822	5267	35	13E
0005434824844	5267	36	13H
0005435373276	5267	37	13G
0005434824931	5267	38	14A
0005434824908	5267	39	13K
0005434831197	5267	40	14E
0005434824826	5267	41	14D
0005435150177	5267	42	14C
0005435373326	5267	43	14G
0005434824912	5267	44	14F
0005435386566	5267	45	14K
0005435386573	5267	46	15C
0005435304155	5267	47	15A
0005435373385	5267	48	15E
0005435150170	5267	49	15D
0005435373263	5267	50	15H
0005435373621	5267	51	15F
0005432121483	5267	52	15K
0005434824876	5267	53	16C
0005434824910	5267	54	16G
0005435373182	5267	55	16F
0005434824879	5267	56	16E
0005434824940	5267	57	16H
0005435373469	5267	58	17C
0005435373492	5267	59	17A
0005434824935	5267	60	17D
0005435373297	5267	61	17H
0005435373534	5267	62	17F
0005435299785	5267	63	17E
0005435373248	5267	64	17K
0005434824843	5267	65	18B
0005434824875	5267	66	18E
0005434824923	5267	67	18D
0005434824937	5267	68	18J
0005435373066	5267	69	18H
0005434824941	5267	70	19B
0005434824837	5267	71	19A
0005434831195	5267	72	18K
0005432121472	5267	73	19C
0005432121485	5267	74	19G
0005435373456	5267	75	19F
0005434831196	5267	76	19E
0005434824857	5267	77	19H
0005434824916	5267	78	19K
0005435373454	5267	79	19J
0005434824906	5267	80	20C
0005435373540	5267	81	20B
0005435373301	5267	82	20E
0005435304183	5267	83	20D
0005434558362	5267	84	20G
0005434824851	5267	85	20F
0005435373158	5267	86	20H
0005434824831	5267	87	21B
0005434824846	5267	88	21D
0005435373478	5267	89	21C
0005434828724	5267	90	21F
0005432394145	5267	91	21E
0005435373341	5267	92	21G
0005434824832	5267	93	22A
0005434824919	5267	94	21K
0005432121476	5267	95	21J
0005435373428	5267	96	22C
0005434824878	5267	97	22F
0005432121477	5267	98	22E
0005434824861	5267	99	22H
0005434824877	5267	100	22G
0005434824918	5267	101	22K
0005435150176	5267	102	22J
0005435373368	5267	103	23A
0005432823454	5267	104	23D
0005434824936	5267	105	23C
0005432394144	5267	106	23G
0005432396283	5267	107	23F
0005434824927	5267	108	23E
0005435150168	5267	109	23J
0005435373156	5267	110	23H
0005434824899	5267	111	24D
0005435299770	5267	112	24G
0005434831194	5267	113	25D
0005434824865	5267	114	25B
0005434558359	5267	115	25E
0005435373280	5267	116	25G
0005434824911	5267	117	26A
0005435373555	5267	118	25K
0005434824932	5267	119	25J
0005434824909	5267	120	26C
0005435373450	5267	121	26B
0005435373556	5267	122	26D
0005435373585	5267	123	26F
0005434558355	5267	124	26J
0005435299784	5267	125	27B
0005432396286	5267	126	27A
0005434824829	5267	127	27D
0005434824915	5267	128	27C
0005435373350	5267	129	27F
0005434824866	5267	130	27H
0005434824825	5267	131	27G
0005435373491	5267	132	28A
0005434824901	5267	133	27J
0005432121481	5267	134	28E
0005435150173	5267	135	28C
0005435386578	5267	136	28J
0005434824882	5267	137	28H
0005434824853	5267	138	29B
0005434824939	5267	139	29A
0005434824890	5267	140	28K
0005435373429	5267	141	29D
0005434824888	5267	142	29E
0005435150172	5267	143	29H
0005435373593	5267	144	29G
0005435299781	5267	145	29J
0005434824934	5267	146	30B
0005434558356	5267	147	30E
0005434824903	5267	148	30D
0005434824925	5267	149	30C
0005434824904	5267	150	30H
0005435373157	5267	151	30G
0005432121478	5267	152	30J
0005434558354	5267	153	31B
0005435150174	5267	154	31A
0005434824821	5267	155	30K
0005435373110	5267	156	31D
0005435373693	5267	157	31F
0005432121474	5267	158	31H
0005434824894	5267	159	31G
0005434558364	5267	160	31K
0005434824917	5267	161	31J
0005434824818	5267	162	32A
0005435304156	5267	163	32E
0005434824870	5267	164	32D
0005435373472	5267	165	32C
0005432396285	5267	166	32J
0005434824854	5267	167	32H
0005432394147	5267	168	33A
0005434824838	5267	169	32K
0005435150171	5267	170	33D
0005434824883	5267	171	33C
0005434824905	5267	172	33B
0005434824869	5267	173	33F
0005434824874	5267	174	33E
0005434558361	5267	175	33J
0005432121482	5267	176	34A
0005434824887	5267	177	33K
0005435373618	5267	178	34C
0005434824873	5267	179	34B
0005435373617	5267	180	34E
0005434824933	5267	181	34D
0005435150167	5267	182	34K
0005434824920	5267	183	34H
0005435373533	5267	184	35B
0005432823455	5267	185	35D
0005435373573	5267	186	35C
0005434558357	5267	187	35F
0005434824891	5267	188	35E
0005435150165	5267	189	35G
0005434824897	5267	190	36A
0005435373344	5267	191	36C
0005434824871	5267	192	36B
0005434824836	5267	193	36E
0005434831193	5267	194	36D
0005434824872	5267	195	36G
0005432121480	5267	196	36K
0005434824884	5267	197	37B
0005434824858	5267	198	37A
0005434824830	5267	199	37D
0005434824856	5267	200	37C
0005435373393	5267	201	37F
0005434824867	5267	202	37E
0005434824863	5267	203	37J
0005435373259	5267	204	37H
0005432394146	5267	205	37G
0005432121479	5267	206	38B
0005434558363	5267	207	38K
0005432396284	5267	208	39C
0005434824862	5267	209	39B
0005434824819	5267	210	39F
0005435373538	5267	211	39E
0005435386598	5267	212	39J
0005434824913	5267	213	39H
0005434824848	5267	214	39K
0005432121475	5267	215	40C
0005434824896	5267	216	40A
0005434824902	5267	217	40E
0005434824886	5267	218	40G
0005434824823	5267	219	40F
0005434824921	5267	220	40J
0005434824839	5267	221	41B
0005434824847	5267	222	41A
0005435150169	5267	223	41H
0005434824820	5267	224	42C
0005434824868	5267	225	42B
0005435373267	5267	226	42E
0005434824827	5267	227	42G
0005434824852	5267	228	42K
0005434824842	5267	229	42J
0005432121473	5267	230	42H
0005434824833	5267	231	43B
0005435373155	5267	232	43F
0005435735128	5267	233	43D
0005434824817	5267	234	43H
0005434824859	5267	235	43K
0005435373108	5267	236	44B
0005435178991	5267	237	44A
0005435373470	5267	238	44C
0005432121484	5267	239	44H
0005435373327	5267	240	44F
0005435304164	5267	241	44K
0005435373349	5267	242	45B
0005434824900	5267	243	45C
0005434824885	5267	244	45E
0005435386588	5267	245	45G
0005434824942	5267	246	45K
0005432823453	5267	247	45J
0005434824828	5267	248	46B
0005435373159	5267	249	46A
0005435661938	5267	250	46D
0005434824855	5267	251	46H
0005434824889	5267	252	47C
0005435150175	5267	253	47A
0005434824895	5267	254	46K
0005434824922	5267	255	47E
0005434824849	5267	256	47D
0005434824930	5267	257	47G
0005435304182	5267	258	47F
0005435373504	5267	259	47K
0005434824824	5267	260	48E
0005434824938	5267	261	49A
0005434824929	5267	262	49D
0005434824893	5267	263	49G
0005434824880	5267	264	49K
0005435373211	5267	265	49H
0005435373620	5267	266	50C
0005434824834	5267	267	50A
0005434824914	5267	268	50E
0005435150166	5267	269	50G
0005434824841	5267	270	50K
0005434664982	5267	271	51F
0005435386593	5267	272	51E
0005434558358	5267	273	51G
0005434824055	9903	1	1C
0005434824054	9903	2	1A
0005434823277	9903	3	1H
0005435373957	9903	4	1K
0005435373901	9903	5	2C
0005434664964	9903	6	2H
0005434831163	9903	7	2G
0005435373914	9903	8	2D
0005434831144	9903	9	3A
0005435299825	9903	10	2K
0005434831142	9903	11	3G
0005434823902	9903	12	3C
0005434824253	9903	13	3H
0005435373959	9903	14	3K
0005434823869	9903	15	4G
0005434824027	9903	16	5A
0005434823713	9903	17	4K
0005435373947	9903	18	4H
0005434823718	9903	19	5G
0005432396238	9903	20	11A
0005434824114	9903	21	5K
0005434823373	9903	22	11D
0005434823540	9903	23	11C
0005434558235	9903	24	11F
0005435386639	9903	25	11E
0005435373905	9903	26	12C
0005435373912	9903	27	12E
0005434823852	9903	28	12D
0005435179403	9903	29	12G
0005432203135	9903	30	12F
0005434823436	9903	31	13A
0005434823834	9903	32	12H
0005435661963	9903	33	13D
0005432203134	9903	34	13C
0005434831157	9903	35	13F
0005434823819	9903	36	13E
0005434824146	9903	37	14A
0005432203137	9903	38	13K
0005435150006	9903	39	14D
0005434823802	9903	40	14E
0005435373944	9903	41	14K
0005434823946	9903	42	14H
0005435373940	9903	43	15D
0005435373949	9903	44	15A
0005435373919	9903	45	15E
0005434823498	9903	46	15G
0005435373918	9903	47	16A
0005435302247	9903	48	16C
0005434824285	9903	49	16F
0005434823736	9903	50	16E
0005435299822	9903	51	16H
0005435373903	9903	52	17C
0005435373921	9903	53	17A
0005435150039	9903	54	17E
0005435373922	9903	55	17D
0005435373932	9903	56	17G
0005434824088	9903	57	17F
0005434558278	9903	58	18A
0005434823948	9903	59	17K
0005434823829	9903	60	17H
0005435373960	9903	61	18E
0005434823928	9903	62	18D
0005434823474	9903	63	18G
0005434823468	9903	64	18F
0005435386640	9903	65	18J
0005434823485	9903	66	18K
0005432203136	9903	67	19G
0005434823786	9903	68	19E
0005434824287	9903	69	19H
0005435299824	9903	70	20C
0005434823621	9903	71	20A
0005435302246	9903	72	20E
0005434831177	9903	73	20D
0005435373920	9903	74	20K
0005434823410	9903	75	20J
0005435373939	9903	76	20H
0005435386643	9903	77	21A
0005435299826	9903	78	21D
0005434558234	9903	79	21C
0005434823565	9903	80	21B
0005434823279	9903	81	21H
0005435373915	9903	82	21G
0005434823539	9903	83	22A
0005434824006	9903	84	21K
0005434823608	9903	85	21J
0005435373927	9903	86	22F
0005434558264	9903	87	22E
0005434823831	9903	88	22D
0005434823969	9903	89	22J
0005434823717	9903	90	23B
0005434823949	9903	91	23D
0005435373952	9903	92	23C
0005434823541	9903	93	23G
0005432823472	9903	94	23F
0005435373925	9903	95	23E
0005435373948	9903	96	23H
0005435373950	9903	97	23K
0005435386638	9903	98	24F
0005435373953	9903	99	24E
0005434831166	9903	100	25A
0005435373943	9903	101	24G
0005434823839	9903	102	25D
0005434823754	9903	103	25C
0005434824248	9903	104	25B
0005435373913	9903	105	25F
0005434823914	9903	106	25E
0005434824513	9903	107	26A
0005434664963	9903	108	25K
0005434823332	9903	109	25J
0005434823701	9903	110	26C
0005434824210	9903	111	26B
0005435150038	9903	112	26E
0005435373904	9903	113	26G
0005434823632	9903	114	26J
0005434824064	9903	115	27A
0005432823470	9903	116	26K
0005434824110	9903	117	27C
0005434828702	9903	118	27F
0005432396237	9903	119	27H
0005434828706	9903	120	27K
0005432203141	9903	121	27J
0005434824007	9903	122	28B
0005434824062	9903	123	28E
0005435373898	9903	124	28D
0005435373926	9903	125	28F
0005435373923	9903	126	28J
0005434823325	9903	127	28H
0005434824327	9903	128	29A
0005435373937	9903	129	28K
0005432396259	9903	130	29B
0005434823626	9903	131	29F
0005434823305	9903	132	29H
0005435373929	9903	133	29G
0005434823747	9903	134	29J
0005435373956	9903	135	30E
0005435373909	9903	136	30D
0005434823469	9903	137	30J
0005434823663	9903	138	30H
0005434831156	9903	139	31A
0005435373911	9903	140	30K
0005435302245	9903	141	31F
0005435373945	9903	142	31E
0005435735183	9903	143	31J
0005432396242	9903	144	31H
0005434823721	9903	145	31K
0005435373916	9903	146	32A
0005435373900	9903	147	32E
0005435373899	9903	148	32G
0005435373946	9903	149	32F
0005434823702	9903	150	32J
0005435373924	9903	151	32H
0005435735188	9903	152	32K
0005434823664	9903	153	33D
0005434823716	9903	154	33B
0005435373908	9903	155	33F
0005434831135	9903	156	33E
0005434824394	9903	157	33G
0005434823715	9903	158	34A
0005435373902	9903	159	33K
0005435373954	9903	160	34C
0005434823753	9903	161	34B
0005434828703	9903	162	34E
0005435373942	9903	163	34G
0005434831171	9903	164	35B
0005432823471	9903	165	35A
0005434831140	9903	166	35C
0005435373907	9903	167	35F
0005435373928	9903	168	35H
0005435386642	9903	169	36C
0005434824070	9903	170	36E
0005434824296	9903	171	36D
0005434824089	9903	172	36H
0005434824113	9903	173	36G
0005435373930	9903	174	36K
0005435150005	9903	175	36J
0005434823566	9903	176	37B
0005434823324	9903	177	37D
0005435149966	9903	178	37E
0005434824298	9903	179	37J
0005434828705	9903	180	37H
0005434823657	9903	181	37G
0005434823851	9903	182	38C
0005434831134	9903	183	38B
0005434823818	9903	184	38J
0005434823935	9903	185	38H
0005434824035	9903	186	38K
0005435386637	9903	187	39C
0005435373936	9903	188	39B
0005435373917	9903	189	39F
0005434823901	9903	190	39E
0005435735184	9903	191	39J
0005432203139	9903	192	39K
0005434823622	9903	193	40C
0005435373934	9903	194	40B
0005435302248	9903	195	40E
0005434823722	9903	196	40D
0005434823714	9903	197	40H
0005435735186	9903	198	40G
0005434823782	9903	199	40F
0005434831139	9903	200	40J
0005432203138	9903	201	41B
0005434823868	9903	202	41A
0005434824036	9903	203	41C
0005435373931	9903	204	41F
0005435373910	9903	205	41J
0005434823309	9903	206	41G
0005434823600	9903	207	42C
0005434823435	9903	208	42D
0005435386641	9903	209	42F
0005435386636	9903	210	42J
0005434824003	9903	211	42H
0005434823772	9903	212	43B
0005434823835	9903	213	42K
0005434823467	9903	214	43E
0005435373935	9903	215	43H
0005432203140	9903	216	43G
0005434823863	9903	217	44C
0005434823885	9903	218	44B
0005434823703	9903	219	44E
0005434823895	9903	220	44G
0005434824063	9903	221	44F
0005434824008	9903	222	44J
0005434824393	9903	223	44H
0005434823550	9903	224	45B
0005435373933	9903	225	45A
0005435735185	9903	226	45D
0005434823607	9903	227	45F
0005435373906	9903	228	45E
0005435373896	9903	229	45J
0005434828707	9903	230	45H
0005435150023	9903	231	46A
0005434824512	9903	232	45K
0005435373958	9903	233	46C
0005434823407	9903	234	46D
0005435735187	9903	235	46F
0005434823915	9903	236	46K
0005434558277	9903	237	46H
0005435661962	9903	238	47C
0005435373961	9903	239	47E
0005435150037	9903	240	47D
0005434824148	9903	241	47G
0005434823684	9903	242	47F
0005435373955	9903	243	47K
0005434823755	9903	244	47H
0005434824297	9903	245	48C
0005432396255	9903	246	48A
0005435373941	9903	247	48F
0005434824286	9903	248	48E
0005434823460	9903	249	48H
0005434824328	9903	250	48G
0005434823394	9903	251	49E
0005434664966	9903	252	49F
0005434823712	9903	253	49K
0005434831143	9903	254	49H
0005434823866	9903	255	50A
0005435373897	9903	256	50F
0005435299823	9903	257	50E
0005435373951	9903	258	50D
0005434824153	9903	259	50H
0005434823872	9903	260	51D
0005435373938	9903	261	50K
0005435661961	9903	262	51F
0005434823306	9903	263	51G
0005435082865	6995	1	1A
0005435790336	6995	2	1D
0005435790338	6995	3	2B
0005435790335	6995	4	3B
0005435082864	6995	5	3C
0005435082872	6995	6	4A
0005435082868	6995	7	4C
0005435790337	6995	8	5D
0005435082867	6995	9	18B
0005435082869	6995	10	18C
0005435082871	6995	11	19A
0005435082866	6995	12	19C
0005435082870	6995	13	22A
0005435790306	25968	1	1C
0005435082800	25968	2	2A
0005435082786	25968	3	2C
0005435082793	25968	4	4C
0005435082778	25968	5	5B
0005435082784	25968	6	5D
0005435082799	25968	7	6C
0005435082801	25968	8	7C
0005435082788	25968	9	7D
0005435082811	25968	10	19B
0005435082779	25968	11	19D
0005435790316	25968	12	20A
0005435082781	25968	13	21A
0005435790317	25968	14	22C
0005435082812	25968	15	23A
0005434214577	9521	1	1A
0005434214564	9521	2	1C
0005434214783	9521	3	1D
0005434756840	9521	4	1F
0005434214636	9521	5	2A
0005434214759	9521	6	2C
0005434214447	9521	7	2D
0005434214464	9521	8	2F
0005434756846	9521	9	3A
0005434756857	9521	10	3C
0005434214439	9521	11	3D
0005434214649	9521	12	3F
0005434214542	9521	13	4A
0005434756861	9521	14	4C
0005434756842	9521	15	4D
0005434756880	9521	16	4E
0005434214583	9521	17	4F
0005434756863	9521	18	5A
0005434756853	9521	19	5C
0005434756869	9521	20	5D
0005434214538	9521	21	5E
0005434214438	9521	22	5F
0005434756855	9521	23	6A
0005434756847	9521	24	6C
0005434214635	9521	25	6D
0005434214755	9521	26	6E
0005434214575	9521	27	6F
0005434214363	9521	28	7A
0005434214526	9521	29	7C
0005434756877	9521	30	7D
0005434756850	9521	31	7E
0005434756858	9521	32	7F
0005434214756	9521	33	8A
0005434756859	9521	34	8C
0005434214711	9521	35	8D
0005434214614	9521	36	8E
0005434214567	9521	37	8F
0005434756871	9521	38	9A
0005434756865	9521	39	9C
0005434756872	9521	40	9D
0005434214525	9521	41	9E
0005434214760	9521	42	9F
0005434214619	9521	43	10A
0005434756844	9521	44	10C
0005434756875	9521	45	10D
0005434756873	9521	46	10E
0005434214782	9521	47	10F
0005434756867	9521	48	11A
0005434214338	9521	49	11C
0005434756864	9521	50	11D
0005434756868	9521	51	11E
0005434214490	9521	52	11F
0005434756854	9521	53	12A
0005434214411	9521	54	12C
0005434214516	9521	55	12D
0005434756848	9521	56	12E
0005434214574	9521	57	12F
0005434214576	9521	58	13A
0005434214611	9521	59	13C
0005434756849	9521	60	13D
0005434756876	9521	61	13E
0005434214468	9521	62	13F
0005434214498	9521	63	14C
0005434756841	9521	64	14A
0005434214685	9521	65	14D
0005434214527	9521	66	14E
0005434214440	9521	67	14F
0005434756852	9521	68	15A
0005434214616	9521	69	15C
0005434756851	9521	70	15D
0005434214508	9521	71	15E
0005434214509	9521	72	15F
0005434756866	9521	73	16A
0005434214412	9521	74	16C
0005434214618	9521	75	16D
0005434756874	9521	76	16E
0005434214615	9521	77	16F
0005434214463	9521	78	17A
0005434756860	9521	79	17C
0005434214524	9521	80	17D
0005434214638	9521	81	17E
0005434756879	9521	82	17F
0005434214466	9521	83	18A
0005434756856	9521	84	18C
0005434214758	9521	85	18D
0005434756843	9521	86	18E
0005434756845	9521	87	18F
0005434214346	9521	88	19A
0005434214781	9521	89	19C
0005434214623	9521	90	19D
0005434214569	9521	91	19E
0005434214568	9521	92	19F
0005434756878	9521	93	20A
0005434756862	9521	94	20C
0005434214757	9521	95	20D
0005434214446	9521	96	20E
0005434756870	9521	97	20F
0005434756488	28622	1	1A
0005434214944	28622	2	1C
0005434756435	28622	3	1F
0005434214943	28622	4	2A
0005434756436	28622	5	2C
0005434756297	28622	6	2D
0005434214975	28622	7	2F
0005434756367	28622	8	3A
0005434756323	28622	9	3C
0005434756427	28622	10	3D
0005434214971	28622	11	3F
0005434756398	28622	12	4A
0005434756414	28622	13	4C
0005434214948	28622	14	4D
0005434214960	28622	15	4E
0005434214977	28622	16	4F
0005434214951	28622	17	5A
0005434756377	28622	18	5C
0005434756406	28622	19	5E
0005434214974	28622	20	5F
0005434214982	28622	21	6D
0005434214976	28622	22	6E
0005434214945	28622	23	6F
0005434756372	28622	24	7A
0005434756263	28622	25	7D
0005434214964	28622	26	7E
0005434756419	28622	27	7F
0005434756359	28622	28	8A
0005434214967	28622	29	8D
0005434214973	28622	30	8E
0005434756354	28622	31	8F
0005434756361	28622	32	9A
0005434756417	28622	33	9C
0005434756460	28622	34	9D
0005434214952	28622	35	9E
0005434756369	28622	36	9F
0005434214941	28622	37	10A
0005434214939	28622	38	10C
0005434756376	28622	39	10D
0005434214954	28622	40	10E
0005434214980	28622	41	10F
0005434756368	28622	42	11A
0005434214956	28622	43	11C
0005434214955	28622	44	11D
0005434756393	28622	45	11E
0005434214961	28622	46	11F
0005434214958	28622	47	12A
0005434214978	28622	48	12C
0005434756438	28622	49	12D
0005434214940	28622	50	12E
0005434214957	28622	51	12F
0005434214972	28622	52	13A
0005434756298	28622	53	13E
0005434756425	28622	54	13F
0005434756275	28622	55	14A
0005434214938	28622	56	14C
0005434756442	28622	57	14E
0005434214981	28622	58	14F
0005434214949	28622	59	15A
0005434756337	28622	60	15C
0005434756446	28622	61	15D
0005434214962	28622	62	15F
0005434756371	28622	63	16A
0005434214950	28622	64	16C
0005434214946	28622	65	16E
0005434756399	28622	66	17A
0005434214965	28622	67	16F
0005434756418	28622	68	17C
0005434756274	28622	69	17E
0005434214963	28622	70	17F
0005434214942	28622	71	18A
0005434214959	28622	72	18C
0005434214970	28622	73	18D
0005434214953	28622	74	18E
0005434214966	28622	75	18F
0005434756426	28622	76	19C
0005434756329	28622	77	19D
0005434756405	28622	78	19E
0005434214968	28622	79	20A
0005434756437	28622	80	20C
0005434214969	28622	81	20D
0005434214979	28622	82	20E
0005434214947	28622	83	20F
0005435100153	10861	1	18C
0005435100154	10861	2	18D
0005435100152	10861	3	20B
0005435100143	31835	1	2A
0005435100141	31835	2	2C
0005434760222	31835	3	3A
0005435100144	31835	4	4A
0005435100142	31835	5	4B
0005435100140	31835	6	4C
0005434760223	31835	7	6C
0005435100128	31835	8	7C
0005434760221	31835	9	20C
0005434639582	2012	1	1A
0005434639573	2012	2	1B
0005434639584	2012	3	1C
0005433202357	2012	4	1D
0005434639575	2012	5	2A
0005434639578	2012	6	2B
0005432290664	2012	7	2C
0005433202349	2012	8	2D
0005434639593	2012	9	3A
0005434639577	2012	10	3C
0005433202419	2012	11	3D
0005434639587	2012	12	4A
0005433202342	2012	13	4B
0005434639592	2012	14	4C
0005432290665	2012	15	4D
0005433202332	2012	16	5C
0005434639589	2012	17	5D
0005434639595	2012	18	6A
0005434639594	2012	19	6B
0005434639583	2012	20	6C
0005433202323	2012	21	6D
0005434639585	2012	22	7A
0005434639597	2012	23	7B
0005432290666	2012	24	7C
0005434639596	2012	25	7D
0005433202407	2012	26	18A
0005434639580	2012	27	18B
0005433202317	2012	28	18C
0005434639598	2012	29	18D
0005433202386	2012	30	19A
0005434639588	2012	31	19B
0005433202316	2012	32	19D
0005434639586	2012	33	20A
0005434639576	2012	34	20B
0005434639574	2012	35	20C
0005434639591	2012	36	20D
0005434639581	2012	37	21A
0005434639590	2012	38	22A
0005434639579	2012	39	22B
0005433202408	2012	40	22D
0005433202499	23301	1	1B
0005434639340	23301	2	1D
0005434639350	23301	3	2A
0005433202508	23301	4	2B
0005434639484	23301	5	2C
0005433202494	23301	6	2D
0005433202495	23301	7	3A
0005434639335	23301	8	3B
0005434639229	23301	9	3D
0005433202501	23301	10	4A
0005434639369	23301	11	4B
0005434639193	23301	12	4C
0005434639325	23301	13	4D
0005433202497	23301	14	5A
0005433202505	23301	15	5B
0005435948327	23301	16	5C
0005434639302	23301	17	5D
0005434639262	23301	18	6A
0005434639413	23301	19	6B
0005434639270	23301	20	6C
0005433202496	23301	21	6D
0005433202502	23301	22	7A
0005433202506	23301	23	7B
0005434639194	23301	24	7C
0005434639329	23301	25	7D
0005434639269	23301	26	18A
0005434639355	23301	27	18B
0005434639485	23301	28	19A
0005435948328	23301	29	19B
0005433202503	23301	30	19C
0005434639349	23301	31	19D
0005434639333	23301	32	20A
0005433202504	23301	33	20B
0005434639372	23301	34	20C
0005433202498	23301	35	21A
0005434639330	23301	36	21B
0005434639464	23301	37	21C
0005434639412	23301	38	21D
0005434639326	23301	39	22A
0005434639356	23301	40	22C
0005433202500	23301	41	22D
0005433202507	23301	42	23B
0005435326821	6056	1	1C
0005434601091	6056	2	2A
0005435326804	6056	3	2D
0005434601093	6056	4	2F
0005434601085	6056	5	3A
0005432111310	6056	6	3D
0005434601074	6056	7	4C
0005434601080	6056	8	4D
0005435326795	6056	9	4E
0005434601098	6056	10	4F
0005434601094	6056	11	5A
0005434601078	6056	12	5D
0005433533347	6056	13	5E
0005434601083	6056	14	6D
0005434601079	6056	15	6F
0005434601086	6056	16	7C
0005435326764	6056	17	7E
0005433531332	6056	18	7F
0005434601084	6056	19	8C
0005433531334	6056	20	8F
0005434601088	6056	21	8E
0005434601081	6056	22	9C
0005433533346	6056	23	9F
0005433531331	6056	24	10A
0005435326800	6056	25	10C
0005434601095	6056	26	10D
0005433531333	6056	27	10E
0005434601096	6056	28	11C
0005435326765	6056	29	11E
0005434601082	6056	30	12A
0005433533348	6056	31	12C
0005435326803	6056	32	12F
0005434601089	6056	33	13A
0005434601097	6056	34	13E
0005434601077	6056	35	15A
0005434601071	6056	36	15C
0005434601092	6056	37	15F
0005434601072	6056	38	16A
0005432111309	6056	39	16D
0005434601090	6056	40	16E
0005434601087	6056	41	17A
0005433531335	6056	42	17E
0005435326744	6056	43	18C
0005434601075	6056	44	18E
0005435326769	6056	45	19A
0005435326822	6056	46	19C
0005432111311	6056	47	19E
0005434601073	6056	48	19F
0005434601099	6056	49	20A
0005434601076	6056	50	20C
0005434600898	18598	1	1A
0005435326882	18598	2	1C
0005434600874	18598	3	1D
0005433531295	18598	4	2A
0005435326886	18598	5	2F
0005434600869	18598	6	4A
0005433527256	18598	7	4C
0005434600829	18598	8	4D
0005435326880	18598	9	4E
0005434600802	18598	10	5A
0005434600906	18598	11	5C
0005434600742	18598	12	5E
0005435326885	18598	13	5F
0005434600842	18598	14	6C
0005435326891	18598	15	6E
0005433531290	18598	16	7A
0005434600892	18598	17	7C
0005435326889	18598	18	7E
0005434600943	18598	19	7F
0005434600827	18598	20	8D
0005434600942	18598	21	8E
0005434600858	18598	22	9C
0005435326892	18598	23	9D
0005434600897	18598	24	9F
0005434600928	18598	25	10E
0005434600905	18598	26	10F
0005435326887	18598	27	11F
0005435326881	18598	28	12E
0005434600859	18598	29	12F
0005434600754	18598	30	13E
0005434600873	18598	31	13F
0005434600738	18598	32	14A
0005434600900	18598	33	14F
0005435326888	18598	34	15A
0005434600904	18598	35	15E
0005434600875	18598	36	16C
0005434600746	18598	37	17C
0005435326884	18598	38	17D
0005435326893	18598	39	18E
0005434600812	18598	40	18F
0005434600765	18598	41	19A
0005435326890	18598	42	19E
0005433531301	18598	43	20C
0005435326883	18598	44	20D
0005434600828	18598	45	20E
0005434600995	18598	46	20F
0005434551758	10676	1	1A
0005434551727	10676	2	1C
0005433181084	10676	3	1D
0005434554084	10676	4	1F
0005434551741	10676	5	2C
0005434558349	10676	6	2D
0005434551757	10676	7	2F
0005434551726	10676	8	3A
0005434551740	10676	9	3C
0005434551734	10676	10	3D
0005433181191	10676	11	3F
0005434551754	10676	12	4A
0005434551714	10676	13	4C
0005433181070	10676	14	4D
0005434558346	10676	15	4E
0005434551729	10676	16	4F
0005433181149	10676	17	5A
0005434551751	10676	18	5D
0005434554083	10676	19	5C
0005433181112	10676	20	5E
0005434551745	10676	21	5F
0005434551753	10676	22	6A
0005434551716	10676	23	6C
0005433181131	10676	24	6D
0005434551748	10676	25	6E
0005434551749	10676	26	6F
0005434551756	10676	27	7A
0005433181104	10676	28	7C
0005434551738	10676	29	7D
0005433181042	10676	30	7E
0005434558351	10676	31	7F
0005433181136	10676	32	8A
0005433181115	10676	33	8C
0005434551721	10676	34	8D
0005434558347	10676	35	8E
0005434551730	10676	36	8F
0005434558348	10676	37	9C
0005433181076	10676	38	9D
0005434551733	10676	39	9E
0005434551735	10676	40	9F
0005434551764	10676	41	10A
0005434551766	10676	42	10C
0005434551742	10676	43	10D
0005434551767	10676	44	10E
0005434551717	10676	45	10F
0005434551755	10676	46	11A
0005434551750	10676	47	11C
0005434551722	10676	48	11D
0005434554082	10676	49	11E
0005434551739	10676	50	11F
0005434551728	10676	51	12A
0005434558352	10676	52	12C
0005433181087	10676	53	12D
0005434551744	10676	54	12E
0005434551731	10676	55	12F
0005433181106	10676	56	13A
0005433181105	10676	57	13C
0005434558350	10676	58	13D
0005434551759	10676	59	13E
0005433181069	10676	60	13F
0005434551720	10676	61	14A
0005434551713	10676	62	14C
0005434551725	10676	63	14D
0005433181023	10676	64	14E
0005434551718	10676	65	14F
0005434551752	10676	66	15A
0005434551732	10676	67	15C
0005433181096	10676	68	15D
0005434551736	10676	69	15E
0005434551737	10676	70	15F
0005434551724	10676	71	16A
0005433181178	10676	72	16C
0005433181130	10676	73	16D
0005434551765	10676	74	16E
0005434551763	10676	75	16F
0005434551746	10676	76	17A
0005433181164	10676	77	17C
0005433181146	10676	78	17D
0005434558353	10676	79	17E
0005434551723	10676	80	18A
0005433181208	10676	81	18C
0005433181077	10676	82	18D
0005434551747	10676	83	18E
0005433181089	10676	84	18F
0005433181097	10676	85	19A
0005433181132	10676	86	19C
0005433181187	10676	87	19D
0005433181116	10676	88	19E
0005434551743	10676	89	19F
0005434551760	10676	90	20A
0005434551761	10676	91	20C
0005434551715	10676	92	20D
0005434551719	10676	93	20E
0005434551762	10676	94	20F
0005433181347	27743	1	1C
0005433181361	27743	2	1F
0005433181364	27743	3	2A
0005433181363	27743	4	3A
0005433181353	27743	5	3C
0005433181362	27743	6	3F
0005433181368	27743	7	4F
0005433181369	27743	8	6D
0005433181355	27743	9	7C
0005433181370	27743	10	8D
0005433181357	27743	11	10D
0005433181366	27743	12	11D
0005433181358	27743	13	12E
0005433181351	27743	14	13D
0005433181356	27743	15	13E
0005433181349	27743	16	15E
0005433181360	27743	17	15F
0005433181352	27743	18	17A
0005433181371	27743	19	17D
0005433181365	27743	20	18A
0005433181367	27743	21	18C
0005433181354	27743	22	18E
0005433181346	27743	23	19E
0005433181348	27743	24	20A
0005433181350	27743	25	20C
0005433181359	27743	26	20F
0005434551273	27746	1	1A
0005434558274	27746	2	1C
0005434551099	27746	3	1D
0005434551312	27746	4	1F
0005434551447	27746	5	2A
0005434551200	27746	6	2C
0005434558295	27746	7	2D
0005434558256	27746	8	2F
0005434551526	27746	9	3A
0005434558294	27746	10	3C
0005434558291	27746	11	3D
0005434551322	27746	12	3F
0005434558293	27746	13	4D
0005434551321	27746	14	4E
0005434551051	27746	15	5A
0005434551239	27746	16	5D
0005434551147	27746	17	5E
0005434551479	27746	18	5F
0005434558257	27746	19	6A
0005434551194	27746	20	6D
0005434551155	27746	21	6E
0005434558259	27746	22	7A
0005434551480	27746	23	7C
0005434551274	27746	24	7D
0005434551543	27746	25	7E
0005434551408	27746	26	7F
0005434551507	27746	27	8A
0005434551002	27746	28	8D
0005434551389	27746	29	8E
0005434558258	27746	30	9A
0005434551040	27746	31	9C
0005434551107	27746	32	9D
0005434551359	27746	33	9E
0005434551560	27746	34	10A
0005434551466	27746	35	10C
0005434551508	27746	36	10E
0005434551313	27746	37	10F
0005434551390	27746	38	11A
0005434551525	27746	39	11E
0005434551410	27746	40	11F
0005434551339	27746	41	12A
0005434551272	27746	42	12C
0005434551411	27746	43	12D
0005434551415	27746	44	12F
0005434558276	27746	45	14C
0005434551391	27746	46	14D
0005434551358	27746	47	14E
0005434551523	27746	48	14F
0005434551175	27746	49	15A
0005434558245	27746	50	15C
0005434551197	27746	51	15F
0005434551276	27746	52	16C
0005434551511	27746	53	16E
0005434551559	27746	54	16F
0005434551514	27746	55	17A
0005434551240	27746	56	17C
0005434551515	27746	57	17E
0005434551414	27746	58	17F
0005434551497	27746	59	18A
0005434551193	27746	60	18C
0005434551435	27746	61	18D
0005434551227	27746	62	18F
0005434551498	27746	63	19A
0005434551512	27746	64	19C
0005434558292	27746	65	19E
0005434551148	27746	66	19F
0005434551412	27746	67	20C
0005434558275	27746	68	20D
0005434551275	27746	69	20E
0005434558282	27746	70	20F
0005435254473	6146	1	1A
0005435254474	6146	2	1B
0005433459263	6146	3	3A
0005435254485	6146	4	4A
0005433459264	6146	5	5B
0005435254483	6146	6	5A
0005435254499	19344	1	4B
0005435682541	6725	1	1A
0005435437992	6725	2	1C
0005435682530	6725	3	1D
0005435437998	6725	4	1F
0005435682532	6725	5	2A
0005435438005	6725	6	2C
0005435438047	6725	7	2D
0005435438011	6725	8	2F
0005435682525	6725	9	3A
0005432533297	6725	10	3C
0005435438035	6725	11	3D
0005435682539	6725	12	4C
0005435682537	6725	13	4E
0005435438044	6725	14	4F
0005435220312	6725	15	5A
0005435438045	6725	16	5C
0005435719571	6725	17	5D
0005435661960	6725	18	5E
0005435682550	6725	19	6A
0005435682524	6725	20	6C
0005432136219	6725	21	6D
0005435682521	6725	22	6E
0005435437984	6725	23	7A
0005435682548	6725	24	7E
0005435661959	6725	25	7F
0005435682554	6725	26	8A
0005435630996	6725	27	8C
0005435720142	6725	28	8D
0005435437987	6725	29	8F
0005435438069	6725	30	9C
0005435221517	6725	31	9D
0005435682535	6725	32	9E
0005432136220	6725	33	9F
0005435630994	6725	34	10A
0005435682553	6725	35	10C
0005435437997	6725	36	10D
0005435682558	6725	37	10E
0005435682526	6725	38	10F
0005435682559	6725	39	11A
0005435682531	6725	40	11C
0005435682533	6725	41	11D
0005435437939	6725	42	11E
0005435438078	6725	43	11F
0005435719570	6725	44	12A
0005435682529	6725	45	12C
0005435437951	6725	46	12D
0005435438068	6725	47	12E
0005435682544	6725	48	12F
0005432136221	6725	49	13A
0005435437941	6725	50	13C
0005435682560	6725	51	13D
0005435720143	6725	52	13E
0005435437995	6725	53	13F
0005435682556	6725	54	14A
0005435682540	6725	55	14C
0005435630995	6725	56	14D
0005435682545	6725	57	14E
0005435682534	6725	58	14F
0005435438088	6725	59	15A
0005435720141	6725	60	15C
0005435438010	6725	61	15E
0005435682552	6725	62	15F
0005435221518	6725	63	16D
0005435682546	6725	64	16E
0005435682523	6725	65	17A
0005435682543	6725	66	17C
0005435682538	6725	67	17D
0005435682551	6725	68	18A
0005435682555	6725	69	18C
0005435682547	6725	70	18D
0005435682536	6725	71	18F
0005435682542	6725	72	19A
0005435682528	6725	73	19C
0005435682527	6725	74	19E
0005435682557	6725	75	19F
0005435682549	6725	76	20A
0005435437973	6725	77	20C
0005435682522	6725	78	20D
0005435437965	6725	79	20E
0005435438065	6725	80	20F
0005435682154	24599	1	1A
0005435720823	24599	2	1C
0005435682249	24599	3	1D
0005435438185	24599	4	1F
0005435682185	24599	5	2A
0005435661929	24599	6	2C
0005435682094	24599	7	2D
0005435438174	24599	8	2F
0005435682290	24599	9	3A
0005435682063	24599	10	3C
0005435438172	24599	11	3D
0005435682054	24599	12	3F
0005435630953	24599	13	4A
0005435682273	24599	14	4C
0005435682047	24599	15	4D
0005435682393	24599	16	4E
0005435682032	24599	17	4F
0005435682162	24599	18	5A
0005435682075	24599	19	5C
0005435438184	24599	20	5D
0005432533320	24599	21	5F
0005435682256	24599	22	6A
0005434828726	24599	23	6C
0005434828725	24599	24	6E
0005435438175	24599	25	6F
0005435438187	24599	26	7A
0005435682320	24599	27	7C
0005435682289	24599	28	7D
0005435630968	24599	29	7E
0005435682181	24599	30	7F
0005435682361	24599	31	8A
0005435682174	24599	32	8C
0005435438179	24599	33	8E
0005435661915	24599	34	8F
0005432305775	24599	35	9A
0005435682071	24599	36	9D
0005435661930	24599	37	9E
0005435682053	24599	38	9F
0005435682281	24599	39	10A
0005435682175	24599	40	10D
0005435438181	24599	41	10E
0005435682101	24599	42	10F
0005435438178	24599	43	11A
0005435682445	24599	44	11C
0005435438171	24599	45	11D
0005435682298	24599	46	11E
0005435438168	24599	47	11F
0005435682207	24599	48	12A
0005435682186	24599	49	12C
0005435682206	24599	50	12D
0005432533321	24599	51	12E
0005435661916	24599	52	12F
0005432533322	24599	53	13A
0005435682107	24599	54	13C
0005435682172	24599	55	13D
0005435682200	24599	56	13E
0005435720822	24599	57	14A
0005432305774	24599	58	13F
0005435720824	24599	59	14C
0005435682250	24599	60	14D
0005435682285	24599	61	14E
0005432533323	24599	62	14F
0005435438183	24599	63	15A
0005435438186	24599	64	15C
0005434828727	24599	65	15D
0005435630954	24599	66	15E
0005435438170	24599	67	15F
0005435438180	24599	68	16A
0005435438166	24599	69	16C
0005435438176	24599	70	16D
0005435438177	24599	71	16E
0005435438169	24599	72	17A
0005435682180	24599	73	16F
0005435682295	24599	74	17C
0005435682192	24599	75	17D
0005435682072	24599	76	17E
0005435438173	24599	77	17F
0005435682171	24599	78	18A
0005435682163	24599	79	18C
0005435438167	24599	80	18E
0005435682319	24599	81	18F
0005435438182	24599	82	19A
0005435682272	24599	83	19C
0005435682064	24599	84	19D
0005435682208	24599	85	19F
0005435682230	24599	86	20A
0005435682112	24599	87	20C
0005435682394	24599	88	20D
0005435682156	24599	89	20E
0005435682297	24599	90	20F
0005435106011	11539	1	1D
0005435126755	11539	2	2A
0005435126768	11539	3	2D
0005435126763	11539	4	3A
0005435126759	11539	5	3C
0005435126734	11539	6	3F
0005435106013	11539	7	4A
0005435126758	11539	8	4C
0005435126739	11539	9	4D
0005435126740	11539	10	4E
0005435126732	11539	11	5A
0005435126770	11539	12	5C
0005435126746	11539	13	5D
0005435126769	11539	14	5F
0005435126748	11539	15	6A
0005435126737	11539	16	6C
0005435106012	11539	17	6F
0005435126751	11539	18	7A
0005435126733	11539	19	7D
0005435126742	11539	20	7E
0005435126765	11539	21	8A
0005435126745	11539	22	8C
0005435126756	11539	23	8F
0005435558096	11539	24	9A
0005435126750	11539	25	9F
0005435126754	11539	26	10C
0005435126738	11539	27	10D
0005435126747	11539	28	11A
0005435126736	11539	29	11D
0005435558091	11539	30	11E
0005435126767	11539	31	12C
0005435126743	11539	32	12D
0005435126757	11539	33	12F
0005435558093	11539	34	13D
0005435126753	11539	35	13F
0005435126735	11539	36	14C
0005435126761	11539	37	14D
0005435126752	11539	38	15A
0005435126760	11539	39	15E
0005435558092	11539	40	16C
0005435126762	11539	41	17A
0005435126744	11539	42	17C
0005435126764	11539	43	19A
0005435126749	11539	44	19C
0005435126766	11539	45	19D
0005435126741	11539	46	19E
0005435558095	11539	47	20D
0005435558090	11539	48	20F
0005435106007	31892	1	1C
0005435126457	31892	2	1D
0005435105981	31892	3	2C
0005435126473	31892	4	2F
0005435098557	31892	5	3A
0005435126546	31892	6	5E
0005435558113	31892	7	5F
0005435126456	31892	8	6A
0005435098546	31892	9	7C
0005435126482	31892	10	7E
0005435126280	31892	11	7F
0005435126497	31892	12	8C
0005435126454	31892	13	8F
0005435558112	31892	14	9C
0005435105979	31892	15	9E
0005435126496	31892	16	9F
0005435126381	31892	17	10A
0005435098545	31892	18	11A
0005435126349	31892	19	11F
0005435105985	31892	20	12D
0005435558114	31892	21	12E
0005435126495	31892	22	13A
0005435126486	31892	23	13C
0005435126352	31892	24	13D
0005435126065	31892	25	13E
0005435126348	31892	26	13F
0005435126501	31892	27	14A
0005435126455	31892	28	14E
0005435126351	31892	29	15A
0005435126507	31892	30	15C
0005435126406	31892	31	15E
0005435126447	31892	32	16A
0005435126281	31892	33	16E
0005435126302	31892	34	16F
0005435126511	31892	35	17D
0005435126460	31892	36	18A
0005435105980	31892	37	18E
0005435126367	31892	38	18F
0005435126459	31892	39	19A
0005435126458	31892	40	19C
0005435126542	31892	41	19F
0005435126510	31892	42	20A
0005435126368	31892	43	20D
0005435126499	31892	44	20F
0005435732334	13545	1	1A
0005433398559	13545	2	1C
0005433398540	13545	3	2C
0005433398526	13545	4	2D
0005433398527	13545	5	2F
0005433398541	13545	6	3A
0005433398529	13545	7	3C
0005433398542	13545	8	3F
0005435732376	13545	9	5A
0005433398564	13545	10	5E
0005433398566	13545	11	5F
0005435732364	13545	12	6C
0005435732340	13545	13	6E
0005433398567	13545	14	6D
0005435732333	13545	15	6F
0005433398523	13545	16	7A
0005433398530	13545	17	7D
0005433398551	13545	18	7E
0005435732299	13545	19	7F
0005433398539	13545	20	8C
0005433398553	13545	21	8A
0005433398549	13545	22	8D
0005433398537	13545	23	8F
0005433398543	13545	24	9D
0005433398525	13545	25	9E
0005433398535	13545	26	10C
0005433398554	13545	27	10D
0005433398555	13545	28	10E
0005435732302	13545	29	10F
0005433398563	13545	30	11A
0005433398560	13545	31	11C
0005435732335	13545	32	11E
0005433398558	13545	33	12A
0005433398538	13545	34	12D
0005433398547	13545	35	12E
0005433398562	13545	36	12F
0005433398531	13545	37	13A
0005435732331	13545	38	13D
0005433398569	13545	39	13E
0005433398556	13545	40	13F
0005433398570	13545	41	14C
0005435732375	13545	42	14D
0005433398550	13545	43	14E
0005435732356	13545	44	14F
0005433398565	13545	45	15E
0005433398532	13545	46	16A
0005435732373	13545	47	16E
0005433398524	13545	48	16F
0005433398536	13545	49	17C
0005435732339	13545	50	17D
0005433398548	13545	51	17F
0005435732330	13545	52	18A
0005433398533	13545	53	18C
0005433398544	13545	54	18D
0005433398534	13545	55	18E
0005435732301	13545	56	18F
0005433398545	13545	57	19A
0005433398557	13545	58	19D
0005435732282	13545	59	19E
0005433398546	13545	60	19F
0005435732374	13545	61	20A
0005433398528	13545	62	20C
0005433398561	13545	63	20D
0005433398568	13545	64	20E
0005433398552	13545	65	20F
0005435732464	19411	1	1A
0005435732467	19411	2	1C
0005433398083	19411	3	1D
0005433398124	19411	4	1F
0005433398329	19411	5	2A
0005433398114	19411	6	2C
0005433398010	19411	7	2D
0005435732479	19411	8	2F
0005435732472	19411	9	3A
0005433398151	19411	10	3C
0005433397881	19411	11	3F
0005435732461	19411	12	4A
0005433398135	19411	13	4D
0005433398195	19411	14	4F
0005435732469	19411	15	5A
0005435732462	19411	16	5C
0005433398121	19411	17	5F
0005433398243	19411	18	6C
0005433397835	19411	19	6D
0005435732466	19411	20	6E
0005435732481	19411	21	7A
0005433398110	19411	22	7D
0005433398184	19411	23	7E
0005432297304	19411	24	7F
0005433398190	19411	25	8A
0005433398169	19411	26	8D
0005433398211	19411	27	8E
0005435732465	19411	28	8F
0005433398134	19411	29	9A
0005433398183	19411	30	9C
0005433398120	19411	31	9D
0005433398126	19411	32	9E
0005433398136	19411	33	9F
0005435732475	19411	34	10C
0005435732476	19411	35	10F
0005435732471	19411	36	11A
0005433398038	19411	37	11C
0005433397994	19411	38	11D
0005433398026	19411	39	11E
0005433398244	19411	40	11F
0005433397991	19411	41	12A
0005433398082	19411	42	12C
0005435732478	19411	43	12E
0005433398210	19411	44	12F
0005433398175	19411	45	13A
0005432297305	19411	46	13F
0005433398196	19411	47	14A
0005433398109	19411	48	14E
0005433397986	19411	49	15A
0005435732480	19411	50	15E
0005433398260	19411	51	16A
0005433397905	19411	52	16C
0005435732477	19411	53	16D
0005433397830	19411	54	17A
0005433398219	19411	55	17C
0005435732473	19411	56	17D
0005433398125	19411	57	17E
0005433398005	19411	58	18A
0005435732463	19411	59	18D
0005432297303	19411	60	18E
0005433398127	19411	61	18F
0005435732474	19411	62	19A
0005435732468	19411	63	19C
0005433397992	19411	64	19D
0005433398188	19411	65	19F
0005435732470	19411	66	20D
0005433398157	19411	67	20C
0005435069075	13142	1	1A
0005435925428	13142	2	1F
0005435068865	13142	3	2A
0005435925427	13142	4	2D
0005435069050	13142	5	2F
0005435069300	13142	6	3A
0005435069279	13142	7	3D
0005435069145	13142	8	4A
0005435069031	13142	9	4F
0005435068939	13142	10	5C
0005435069404	13142	11	5E
0005435069248	13142	12	5F
0005435925425	13142	13	6A
0005435069030	13142	14	7A
0005435069125	13142	15	7D
0005435068969	13142	16	7F
0005435069207	13142	17	8A
0005435925424	13142	18	8D
0005435069136	13142	19	8F
0005435069164	13142	20	9D
0005435069032	13142	21	9F
0005435069326	13142	22	10E
0005435069122	13142	23	11A
0005435069154	13142	24	11C
0005435069102	13142	25	11E
0005435069000	13142	26	12A
0005435069151	13142	27	12C
0005435069141	13142	28	12D
0005435069135	13142	29	12E
0005435925429	13142	30	12F
0005435925436	13142	31	13A
0005435069165	13142	32	13C
0005435069126	13142	33	13D
0005435925437	13142	34	13F
0005435925430	13142	35	14A
0005435069319	13142	36	14F
0005435068999	13142	37	15D
0005435069069	13142	38	15E
0005435069249	13142	39	15F
0005435069166	13142	40	16A
0005435069176	13142	41	16C
0005435069114	13142	42	16E
0005435069318	13142	43	16F
0005435069140	13142	44	17A
0005435925434	13142	45	17D
0005435925431	13142	46	17F
0005435069259	13142	47	18A
0005435925435	13142	48	18C
0005435069403	13142	49	18D
0005435925426	13142	50	18F
0005435069123	13142	51	19C
0005435925432	13142	52	19E
0005435068968	13142	53	19F
0005435069078	13142	54	20A
0005435925433	13142	55	20E
0005435925336	15513	1	1A
0005435069577	15513	2	1D
0005435069537	15513	3	2A
0005435069569	15513	4	2C
0005435069578	15513	5	2D
0005435069542	15513	6	3A
0005435069576	15513	7	3C
0005435925337	15513	8	3F
0005435069570	15513	9	4C
0005435925328	15513	10	4D
0005435069547	15513	11	4E
0005435069566	15513	12	4F
0005435069585	15513	13	5C
0005435069543	15513	14	5D
0005435069538	15513	15	5F
0005435069581	15513	16	6A
0005435069555	15513	17	6C
0005435925300	15513	18	6D
0005435069550	15513	19	6F
0005435925302	15513	20	7A
0005435069556	15513	21	7C
0005435069586	15513	22	7D
0005435069572	15513	23	7E
0005435069539	15513	24	8A
0005435069546	15513	25	8C
0005435069563	15513	26	8D
0005435925283	15513	27	8E
0005435925272	15513	28	9A
0005435069575	15513	29	9C
0005435069583	15513	30	9D
0005435069558	15513	31	10A
0005435069551	15513	32	10C
0005435069553	15513	33	10E
0005435069559	15513	34	10F
0005435069561	15513	35	11C
0005435069548	15513	36	11F
0005435069541	15513	37	12A
0005435069557	15513	38	13A
0005435069567	15513	39	13D
0005435069564	15513	40	13F
0005435069545	15513	41	14C
0005435069587	15513	42	14D
0005435069574	15513	43	14E
0005435069580	15513	44	14F
0005435925279	15513	45	15A
0005435069540	15513	46	15C
0005435069568	15513	47	15D
0005435925282	15513	48	15E
0005435925278	15513	49	15F
0005435069579	15513	50	16A
0005435069552	15513	51	16C
0005435069584	15513	52	16D
0005435925301	15513	53	16F
0005435069565	15513	54	17A
0005435925284	15513	55	17C
0005435069582	15513	56	18A
0005435069554	15513	57	18D
0005435069573	15513	58	18E
0005435069571	15513	59	19C
0005435069544	15513	60	19D
0005435069588	15513	61	20A
0005435069560	15513	62	20C
0005435069562	15513	63	20D
0005435069549	15513	64	20E
0005435069536	15513	65	20F
0005435808323	23180	1	1A
0005435808310	23180	2	1B
0005435808320	23180	3	1C
0005435808334	23180	4	1D
0005435808330	23180	5	2A
0005435808308	23180	6	2B
0005435808315	23180	7	2C
0005433407551	23180	8	2D
0005435808316	23180	9	3A
0005435808311	23180	10	3B
0005435808325	23180	11	3C
0005433407567	23180	12	3D
0005433407536	23180	13	4A
0005433407546	23180	14	4B
0005433407559	23180	15	4C
0005435808332	23180	16	4D
0005433407568	23180	17	5A
0005435808331	23180	18	5B
0005433407540	23180	19	5C
0005435808324	23180	20	5D
0005435808306	23180	21	6A
0005435808314	23180	22	6B
0005435808326	23180	23	6C
0005435808319	23180	24	6D
0005435808312	23180	25	7A
0005435808313	23180	26	7B
0005435808307	23180	27	7C
0005433407539	23180	28	7D
0005433407554	23180	29	18A
0005435808333	23180	30	18B
0005433407552	23180	31	19A
0005435808328	23180	32	19D
0005435808335	23180	33	20A
0005435808321	23180	34	20B
0005435808327	23180	35	20C
0005435808317	23180	36	20D
0005435808336	23180	37	21B
0005435808322	23180	38	21C
0005433407545	23180	39	21D
0005435808305	23180	40	22A
0005435808329	23180	41	22B
0005435808318	23180	42	22C
0005433407560	23180	43	22D
0005435808309	23180	44	23A
0005433407535	23180	45	23B
0005434756447	10730	1	1A
0005434756380	10730	2	1C
0005434756457	10730	3	1D
0005434756276	10730	4	2A
0005434215028	10730	5	2C
0005434756352	10730	6	2D
0005434214995	10730	7	2F
0005434756469	10730	8	3A
0005434756346	10730	9	3C
0005434756535	10730	10	3D
0005434756540	10730	11	3F
0005434215014	10730	12	4A
0005434215008	10730	13	4C
0005434756475	10730	14	4D
0005434756400	10730	15	4E
0005434215029	10730	16	4F
0005434756430	10730	17	5A
0005434215020	10730	18	5C
0005434215024	10730	19	5D
0005434215001	10730	20	5E
0005434756541	10730	21	6A
0005434756593	10730	22	6C
0005434215025	10730	23	6D
0005434215005	10730	24	6E
0005434215017	10730	25	6F
0005434215018	10730	26	7A
0005434215011	10730	27	7C
0005434215006	10730	28	7D
0005434756455	10730	29	7E
0005434756505	10730	30	7F
0005434756533	10730	31	8A
0005434756511	10730	32	8E
0005434214994	10730	33	8F
0005434756571	10730	34	9A
0005434756343	10730	35	9C
0005434756362	10730	36	9D
0005434756456	10730	37	9E
0005434756496	10730	38	9F
0005434215023	10730	39	10A
0005434215010	10730	40	10C
0005434756512	10730	41	10D
0005434214983	10730	42	10E
0005434214991	10730	43	10F
0005434214999	10730	44	11C
0005434215021	10730	45	11D
0005434756527	10730	46	11E
0005434215022	10730	47	11F
0005434214988	10730	48	12A
0005434756472	10730	49	12D
0005434215026	10730	50	12E
0005434756409	10730	51	12F
0005434214998	10730	52	13A
0005434214990	10730	53	13C
0005434756410	10730	54	13D
0005434756458	10730	55	13E
0005434215000	10730	56	13F
0005434214989	10730	57	14A
0005434756353	10730	58	14C
0005434214985	10730	59	14D
0005434756205	10730	60	14E
0005434215007	10730	61	14F
0005434214993	10730	62	15A
0005434756473	10730	63	15C
0005434215015	10730	64	15D
0005434756534	10730	65	15E
0005434756470	10730	66	15F
0005434214987	10730	67	16A
0005434215016	10730	68	16D
0005434215002	10730	69	16E
0005434756464	10730	70	16F
0005434756424	10730	71	17A
0005434214986	10730	72	17C
0005434215013	10730	73	17D
0005434215012	10730	74	17E
0005434214997	10730	75	17F
0005434215027	10730	76	18A
0005434756408	10730	77	18C
0005434214984	10730	78	18D
0005434215004	10730	79	18E
0005434756506	10730	80	18F
0005434215009	10730	81	19A
0005434756344	10730	82	19C
0005434215003	10730	83	19D
0005434214996	10730	84	19E
0005434756439	10730	85	19F
0005434756370	10730	86	20A
0005434756497	10730	87	20D
0005434215019	10730	88	20E
0005434214992	10730	89	20F
0005434756809	28675	1	1A
0005434756808	28675	2	1C
0005434756812	28675	3	1D
0005434214317	28675	4	1F
0005434214606	28675	5	2A
0005434756810	28675	6	2C
0005434756819	28675	7	2D
0005434756829	28675	8	2F
0005434214541	28675	9	3A
0005434214318	28675	10	3C
0005434214488	28675	11	3D
0005434756788	28675	12	3F
0005434214573	28675	13	4A
0005434756803	28675	14	4C
0005434214467	28675	15	4D
0005434214424	28675	16	4E
0005434756822	28675	17	4F
0005434756799	28675	18	5A
0005434214667	28675	19	5C
0005434214546	28675	20	5D
0005434756805	28675	21	5E
0005434214454	28675	22	5F
0005434756818	28675	23	6A
0005434214540	28675	24	6C
0005434214431	28675	25	6D
0005434214492	28675	26	6E
0005434756836	28675	27	6F
0005434214518	28675	28	7C
0005434756796	28675	29	7D
0005434756792	28675	30	7E
0005434756816	28675	31	7F
0005434756828	28675	32	8A
0005434756831	28675	33	8C
0005434214543	28675	34	8D
0005434214523	28675	35	8E
0005434756813	28675	36	8F
0005434756832	28675	37	9A
0005434214566	28675	38	9C
0005434756838	28675	39	9D
0005434756817	28675	40	9E
0005434214529	28675	41	9F
0005434214505	28675	42	10A
0005434756804	28675	43	10C
0005434756814	28675	44	10D
0005434214387	28675	45	10E
0005434214532	28675	46	10F
0005434214565	28675	47	11A
0005434214368	28675	48	11C
0005434214637	28675	49	11D
0005434214367	28675	50	11E
0005434214591	28675	51	11F
0005434756834	28675	52	12A
0005434214726	28675	53	12C
0005434756807	28675	54	12D
0005434214499	28675	55	12E
0005434756795	28675	56	12F
0005434756824	28675	57	13A
0005434214557	28675	58	13C
0005434756830	28675	59	13D
0005434756837	28675	60	13E
0005434214651	28675	61	13F
0005434756790	28675	62	14A
0005434214453	28675	63	14C
0005434756825	28675	64	14D
0005434214544	28675	65	14E
0005434214369	28675	66	14F
0005434756835	28675	67	15A
0005434756811	28675	68	15C
0005434756815	28675	69	15D
0005434756827	28675	70	15E
0005434214430	28675	71	15F
0005434756820	28675	72	16A
0005434756787	28675	73	16C
0005434756793	28675	74	16E
0005434756821	28675	75	16F
0005434756794	28675	76	17A
0005434756797	28675	77	17C
0005434214388	28675	78	17D
0005434214494	28675	79	17E
0005434756789	28675	80	18A
0005434756839	28675	81	18C
0005434756826	28675	82	18D
0005434214589	28675	83	18E
0005434756823	28675	84	18F
0005434756798	28675	85	19A
0005434214465	28675	86	19C
0005434214766	28675	87	19D
0005434756833	28675	88	19E
0005434756801	28675	89	19F
0005434756791	28675	90	20A
0005434756806	28675	91	20C
0005434756800	28675	92	20D
0005434756802	28675	93	20E
0005434214491	28675	94	20F
0005435040447	5472	1	1A
0005434229473	5472	2	1C
0005435040400	5472	3	1D
0005435040386	5472	4	1F
0005435040391	5472	5	2A
0005434229385	5472	6	2D
0005434229386	5472	7	2C
0005435040427	5472	8	2F
0005435042879	5472	9	3C
0005435007268	5472	10	3A
0005435040395	5472	11	3D
0005435040394	5472	12	3F
0005434229436	5472	13	4B
0005435040420	5472	14	4A
0005434229388	5472	15	4C
0005434229389	5472	16	4D
0005435040435	5472	17	4E
0005435040443	5472	18	5A
0005434229412	5472	19	4F
0005435040411	5472	20	5B
0005432125526	5472	21	5C
0005435007253	5472	22	5D
0005432125530	5472	23	5E
0005435040434	5472	24	6A
0005434229395	5472	25	5F
0005435040442	5472	26	6C
0005435040407	5472	27	6B
0005435040414	5472	28	6D
0005434229444	5472	29	6F
0005435040402	5472	30	6E
0005434229356	5472	31	7A
0005435007261	5472	32	7B
0005435007264	5472	33	7C
0005435007265	5472	34	7E
0005435040441	5472	35	7D
0005435040437	5472	36	7F
0005435040440	5472	37	8A
0005435040397	5472	38	8B
0005435007254	5472	39	8C
0005435040449	5472	40	8E
0005435040389	5472	41	8D
0005435042881	5472	42	8F
0005432125528	5472	43	9A
0005435040390	5472	44	9C
0005435042882	5472	45	9B
0005435040384	5472	46	9D
0005435007275	5472	47	9E
0005435007269	5472	48	9F
0005435040439	5472	49	10C
0005435040404	5472	50	10B
0005435040393	5472	51	10D
0005435007273	5472	52	10E
0005434229403	5472	53	11A
0005435007266	5472	54	11B
0005435040406	5472	55	11C
0005435007257	5472	56	11D
0005435007255	5472	57	11F
0005435042880	5472	58	11E
0005435007272	5472	59	12A
0005435007263	5472	60	12B
0005435040410	5472	61	12D
0005435007262	5472	62	12C
0005435040403	5472	63	12E
0005432125525	5472	64	12F
0005435040409	5472	65	13B
0005435040436	5472	66	13A
0005434229434	5472	67	13D
0005435040412	5472	68	13C
0005435007260	5472	69	13E
0005435040428	5472	70	13F
0005434229383	5472	71	14B
0005435040385	5472	72	14A
0005434229410	5472	73	14C
0005435040387	5472	74	14D
0005435040429	5472	75	14F
0005434229425	5472	76	14E
0005434229445	5472	77	15A
0005435007259	5472	78	15B
0005435040383	5472	79	15C
0005435040444	5472	80	15D
0005435042883	5472	81	15F
0005434229426	5472	82	15E
0005435007271	5472	83	16A
0005435040405	5472	84	16B
0005432125527	5472	85	16D
0005435040421	5472	86	16C
0005435007276	5472	87	16F
0005435040417	5472	88	16E
0005435007256	5472	89	17A
0005435007258	5472	90	17B
0005435040422	5472	91	17C
0005435040408	5472	92	17E
0005435040450	5472	93	17D
0005435040431	5472	94	17F
0005435040433	5472	95	18A
0005435040398	5472	96	18B
0005435040401	5472	97	18C
0005435040419	5472	98	18D
0005435040415	5472	99	18F
0005434229384	5472	100	18E
0005435040425	5472	101	19A
0005435040424	5472	102	19B
0005435040430	5472	103	19C
0005435007277	5472	104	19F
0005435040388	5472	105	20A
0005434229435	5472	106	20B
0005435040413	5472	107	20D
0005434229376	5472	108	20C
0005435040399	5472	109	20E
0005432125524	5472	110	21A
0005435040423	5472	111	20F
0005435040392	5472	112	21C
0005435040418	5472	113	21B
0005435040426	5472	114	21D
0005435040446	5472	115	21E
0005434229396	5472	116	21F
0005435040448	5472	117	22B
0005435007267	5472	118	22A
0005432125529	5472	119	22C
0005434229446	5472	120	22D
0005435040416	5472	121	22E
0005435007274	5472	122	23A
0005434229413	5472	123	22F
0005435007270	5472	124	23B
0005435040445	5472	125	23C
0005435040432	5472	126	23E
0005435040438	5472	127	23D
0005435040396	5472	128	23F
0005435007083	12990	1	1A
0005435039876	12990	2	1C
0005435039784	12990	3	1D
0005435006996	12990	4	1F
0005435007001	12990	5	2F
0005435007057	12990	6	2D
0005435039373	12990	7	2C
0005435039672	12990	8	3C
0005435007092	12990	9	3A
0005435006998	12990	10	3D
0005435039925	12990	11	3F
0005435039849	12990	12	4A
0005434229602	12990	13	4C
0005435039918	12990	14	4B
0005434229606	12990	15	4D
0005435039997	12990	16	4E
0005435039923	12990	17	4F
0005435039696	12990	18	5B
0005435039789	12990	19	5A
0005435039788	12990	20	5C
0005435039808	12990	21	5D
0005435039877	12990	22	5E
0005435039727	12990	23	6A
0005434229611	12990	24	5F
0005435039998	12990	25	6B
0005434229592	12990	26	6C
0005435007082	12990	27	6D
0005434229595	12990	28	6E
0005434229597	12990	29	7A
0005435007058	12990	30	6F
0005434229601	12990	31	7B
0005435039913	12990	32	7C
0005434229593	12990	33	7E
0005435007128	12990	34	7D
0005435039926	12990	35	8A
0005435007000	12990	36	7F
0005434229603	12990	37	8B
0005435039802	12990	38	8C
0005435039872	12990	39	8E
0005435007129	12990	40	8D
0005435040105	12990	41	8F
0005435039644	12990	42	9A
0005435039590	12990	43	9B
0005435039896	12990	44	9D
0005434229608	12990	45	9C
0005435039589	12990	46	9F
0005435039875	12990	47	10B
0005435006999	12990	48	10C
0005432304437	12990	49	10E
0005435039846	12990	50	10D
0005435039848	12990	51	11A
0005435039908	12990	52	11B
0005435039922	12990	53	11D
0005435040037	12990	54	11C
0005435042854	12990	55	11F
0005435040087	12990	56	11E
0005435040034	12990	57	12B
0005435007024	12990	58	12A
0005435039973	12990	59	12C
0005435039950	12990	60	12D
0005435040038	12990	61	12E
0005435007115	12990	62	12F
0005435039879	12990	63	13B
0005434229607	12990	64	13A
0005435039874	12990	65	13C
0005435007053	12990	66	13D
0005434229605	12990	67	13E
0005434229598	12990	68	14A
0005435039871	12990	69	13F
0005434229612	12990	70	14B
0005435039819	12990	71	14C
0005435007007	12990	72	14D
0005434229596	12990	73	14F
0005435007150	12990	74	14E
0005435039974	12990	75	15A
0005435039912	12990	76	15B
0005435039757	12990	77	15C
0005432304439	12990	78	15D
0005435039979	12990	79	15E
0005435042855	12990	80	16A
0005435039878	12990	81	15F
0005435039637	12990	82	16B
0005435040012	12990	83	16C
0005435007056	12990	84	16E
0005435039638	12990	85	16D
0005435039780	12990	86	16F
0005435040055	12990	87	17A
0005435039810	12990	88	17B
0005434229591	12990	89	17C
0005435039673	12990	90	17D
0005435039936	12990	91	17F
0005435007023	12990	92	17E
0005435039928	12990	93	18A
0005435006997	12990	94	18B
0005435007054	12990	95	18C
0005435007063	12990	96	18E
0005435007006	12990	97	18D
0005432304438	12990	98	18F
0005434229599	12990	99	19A
0005435007081	12990	100	19B
0005435039971	12990	101	19D
0005435007093	12990	102	19C
0005435039670	12990	103	19E
0005434229594	12990	104	19F
0005435039664	12990	105	20A
0005435007149	12990	106	20C
0005435007148	12990	107	20B
0005435039847	12990	108	20E
0005435039671	12990	109	20D
0005435040086	12990	110	21A
0005435039940	12990	111	20F
0005435039978	12990	112	21B
0005435039695	12990	113	21C
0005435039939	12990	114	21D
0005435007064	12990	115	21E
0005435039897	12990	116	22A
0005435007044	12990	117	21F
0005435040011	12990	118	22C
0005435039747	12990	119	22B
0005434229600	12990	120	22E
0005434229609	12990	121	22D
0005435039956	12990	122	22F
0005434229604	12990	123	23B
0005435039927	12990	124	23A
0005435039911	12990	125	23C
0005435007112	12990	126	23D
0005434229610	12990	127	23F
0005435039783	12990	128	23E
0005435902682	14873	1	1A
0005434426878	14873	2	1C
0005434426898	14873	3	1D
0005434426877	14873	4	1F
0005435554194	14873	5	3A
0005434426894	14873	6	3C
0005434426876	14873	7	4C
0005432188638	14873	8	4D
0005434426871	14873	9	4F
0005434426892	14873	10	5C
0005435902775	14873	11	5D
0005435902694	14873	12	5F
0005435902776	14873	13	6D
0005434426882	14873	14	6E
0005434426886	14873	15	7C
0005435554192	14873	16	7D
0005435902712	14873	17	7E
0005434426884	14873	18	8A
0005434426881	14873	19	8C
0005435902742	14873	20	8D
0005435902732	14873	21	8E
0005434426879	14873	22	9A
0005435554186	14873	23	9C
0005434426872	14873	24	9D
0005435554191	14873	25	9E
0005434426875	14873	26	9F
0005434426880	14873	27	10A
0005432188639	14873	28	10C
0005434426889	14873	29	10D
0005435902759	14873	30	10F
0005435902711	14873	31	11A
0005435554195	14873	32	11D
0005435902758	14873	33	11E
0005434426883	14873	34	12A
0005435902743	14873	35	12E
0005434426896	14873	36	12F
0005434426897	14873	37	13A
0005434426890	14873	38	13C
0005434426874	14873	39	13D
0005432188637	14873	40	14C
0005435554190	14873	41	14E
0005434426891	14873	42	14F
0005434426873	14873	43	15A
0005434426870	14873	44	15C
0005435902783	14873	45	15F
0005434426899	14873	46	16A
0005434426887	14873	47	16C
0005435902710	14873	48	16F
0005435554181	14873	49	17A
0005434411819	14873	50	17E
0005434426893	14873	51	18A
0005434426895	14873	52	18C
0005435554174	14873	53	18D
0005434426885	14873	54	19A
0005435554193	14873	55	19C
0005434426888	14873	56	19E
0005435902741	14873	57	20C
0005435554187	14873	58	20D
0005434411818	14873	59	20E
0005434411820	14873	60	20F
0005435902886	20229	1	1A
0005434426629	20229	2	2F
0005435902883	20229	3	3A
0005435902893	20229	4	3D
0005435902888	20229	5	3F
0005434426597	20229	6	4F
0005434426728	20229	7	5C
0005434426574	20229	8	5D
0005435902881	20229	9	5E
0005434426757	20229	10	6A
0005434426756	20229	11	6C
0005435554238	20229	12	6D
0005434411779	20229	13	7C
0005434426718	20229	14	7D
0005434426680	20229	15	7E
0005435902891	20229	16	8A
0005434426670	20229	17	8C
0005435554236	20229	18	9C
0005434426667	20229	19	9E
0005434426641	20229	20	9F
0005435902894	20229	21	10C
0005434426628	20229	22	10E
0005434426596	20229	23	11D
0005435902878	20229	24	11E
0005435902892	20229	25	12C
0005434426673	20229	26	12E
0005434426717	20229	27	12F
0005435902877	20229	28	13A
0005434426657	20229	29	13C
0005434426726	20229	30	13D
0005435902889	20229	31	13E
0005435902885	20229	32	13F
0005432059524	20229	33	14A
0005435554239	20229	34	14C
0005435554240	20229	35	14D
0005435902882	20229	36	14E
0005435902884	20229	37	15C
0005434426669	20229	38	15E
0005434426763	20229	39	15F
0005435902887	20229	40	16A
0005434411780	20229	41	16C
0005435554237	20229	42	16D
0005435902890	20229	43	16F
0005434426668	20229	44	18A
0005432059525	20229	45	18C
0005434426549	20229	46	18E
0005435902879	20229	47	18F
0005434426637	20229	48	19A
0005434426640	20229	49	19C
0005434426681	20229	50	19D
0005435902880	20229	51	19F
0005434411774	20229	52	20D
0005434523769	28017	1	1C
0005434559094	28017	2	1D
0005432462532	28017	3	2C
0005434559090	28017	4	5C
0005434523771	28017	5	5F
0005432462534	28017	6	6B
0005434559095	28017	7	6A
0005434523767	28017	8	8F
0005432462531	28017	9	10C
0005432462533	28017	10	10E
0005432462530	28017	11	11B
0005434559089	28017	12	12D
0005434559092	28017	13	12C
0005432462529	28017	14	12F
0005434523780	28017	15	13B
0005434523760	28017	16	14A
0005432462537	28017	17	15F
0005434523776	28017	18	16A
0005432462535	28017	19	16D
0005434523774	28017	20	17A
0005434523770	28017	21	17C
0005434523777	28017	22	17D
0005434559091	28017	23	19C
0005434523775	28017	24	20A
0005434523751	28017	25	20B
0005432462536	28017	26	20F
0005434559093	28017	27	21C
0005434523781	28017	28	23B
0005434559088	28017	29	23E
0005434523799	30896	1	2F
0005434523795	30896	2	3C
0005434559100	30896	3	4D
0005434523798	30896	4	4E
0005432462516	30896	5	5F
0005432462507	30896	6	7D
0005434559101	30896	7	8D
0005434559103	30896	8	8E
0005434523797	30896	9	11C
0005432462510	30896	10	14E
0005434523793	30896	11	15B
0005432462519	30896	12	16D
0005434523796	30896	13	17A
0005432462520	30896	14	17B
0005432462512	30896	15	17C
0005434559102	30896	16	18F
0005434523794	30896	17	20F
0005434523800	30896	18	21B
0005434559104	30896	19	22A
0005433726124	30868	1	2F
0005433726121	30868	2	3A
0005433726114	30868	3	4A
0005433726113	30868	4	7A
0005433726120	30868	5	8B
0005433726125	30868	6	8E
0005433726119	30868	7	9F
0005433726111	30868	8	12D
0005433726122	30868	9	12C
0005433726112	30868	10	14B
0005433726123	30868	11	17C
0005433726118	30868	12	17E
0005433726115	30868	13	17F
0005433726116	30868	14	18E
0005433726117	30868	15	21D
0005433434664	26547	1	1A
0005433434661	26547	2	1C
0005433434598	26547	3	2A
0005435982765	26547	4	3A
0005435982733	26547	5	3C
0005435982738	26547	6	3D
0005435982756	26547	7	4A
0005433434725	26547	8	4D
0005435982735	26547	9	4E
0005435982762	26547	10	4F
0005435982731	26547	11	5A
0005433434774	26547	12	5D
0005435982740	26547	13	5E
0005433434801	26547	14	5F
0005435982766	26547	15	6A
0005435982734	26547	16	6E
0005435982725	26547	17	6F
0005433434689	26547	18	7C
0005433434706	26547	19	7D
0005435982751	26547	20	7E
0005435982742	26547	21	7F
0005435982749	26547	22	8A
0005435982732	26547	23	8C
0005435982737	26547	24	8D
0005435982761	26547	25	8E
0005432300318	26547	26	8F
0005435982750	26547	27	9A
0005435982736	26547	28	9C
0005433434696	26547	29	9D
0005435982724	26547	30	9E
0005432300317	26547	31	9F
0005435982729	26547	32	10A
0005432300316	26547	33	10C
0005435982741	26547	34	10E
0005435982723	26547	35	10F
0005435982747	26547	36	11A
0005435982727	26547	37	11C
0005433434628	26547	38	11D
0005433434780	26547	39	11E
0005435982743	26547	40	11F
0005433434627	26547	41	12A
0005435982760	26547	42	12C
0005433434676	26547	43	12D
0005432300319	26547	44	12E
0005433434548	26547	45	13C
0005433434726	26547	46	13D
0005435982721	26547	47	13E
0005435982730	26547	48	13F
0005435982746	26547	49	14A
0005435982757	26547	50	14D
0005435982745	26547	51	14E
0005435982726	26547	52	14F
0005433434769	26547	53	15A
0005432300320	26547	54	15D
0005435982753	26547	55	15F
0005435982755	26547	56	16A
0005435982752	26547	57	16C
0005435982719	26547	58	16D
0005433434646	26547	59	16E
0005435982764	26547	60	17A
0005435982744	26547	61	17D
0005435982722	26547	62	17E
0005435982717	26547	63	18A
0005435982720	26547	64	18C
0005435982758	26547	65	18D
0005435982728	26547	66	18E
0005435982718	26547	67	19A
0005435982748	26547	68	19C
0005433434712	26547	69	19D
0005433434785	26547	70	19F
0005435982739	26547	71	20A
0005435982759	26547	72	20C
0005433434720	26547	73	20D
0005435982763	26547	74	20E
0005435982754	26547	75	20F
0005433434964	26731	1	1A
0005433434966	26731	2	1C
0005432051160	26731	3	1D
0005433434958	26731	4	1F
0005433434967	26731	5	2A
0005435982463	26731	6	2C
0005433434962	26731	7	2F
0005435982336	26731	8	3D
0005435982423	26731	9	3C
0005433434961	26731	10	3F
0005434271333	26731	11	4A
0005433434970	26731	12	4C
0005435982062	26731	13	4D
0005435982399	26731	14	4E
0005433434969	26731	15	4F
0005435982338	26731	16	5A
0005433434984	26731	17	5C
0005433434968	26731	18	5D
0005435982475	26731	19	5E
0005435982440	26731	20	6A
0005435982313	26731	21	6C
0005435982396	26731	22	6D
0005433434979	26731	23	7A
0005435982334	26731	24	7C
0005435982198	26731	25	7D
0005433434973	26731	26	7E
0005433434971	26731	27	8A
0005435982364	26731	28	8C
0005435982337	26731	29	8D
0005433434975	26731	30	8E
0005435982387	26731	31	8F
0005435982605	26731	32	9A
0005435982151	26731	33	9C
0005435982274	26731	34	9D
0005435982241	26731	35	9E
0005435982561	26731	36	9F
0005432051159	26731	37	10C
0005434270228	26731	38	10E
0005435982388	26731	39	10F
0005435982479	26731	40	11A
0005435982233	26731	41	11C
0005433434985	26731	42	11D
0005435982232	26731	43	11E
0005435982322	26731	44	12A
0005433434980	26731	45	12C
0005433434983	26731	46	12D
0005435982459	26731	47	12E
0005435982460	26731	48	12F
0005435982404	26731	49	13A
0005433434978	26731	50	13D
0005432051161	26731	51	13E
0005434270227	26731	52	14A
0005433434982	26731	53	14C
0005434271334	26731	54	14F
0005435982239	26731	55	15A
0005433434965	26731	56	15C
0005433434959	26731	57	15D
0005435982155	26731	58	15E
0005435982320	26731	59	15F
0005435982323	26731	60	16A
0005435982458	26731	61	16C
0005433434963	26731	62	16E
0005435982517	26731	63	16F
0005433434960	26731	64	17C
0005434269125	26731	65	17D
0005433434972	26731	66	17E
0005435982560	26731	67	17F
0005435982287	26731	68	18A
0005435982562	26731	69	18C
0005435982395	26731	70	18D
0005435982227	26731	71	18E
0005435982061	26731	72	18F
0005433434981	26731	73	19A
0005435982226	26731	74	19C
0005435982340	26731	75	19D
0005435982063	26731	76	19E
0005435982474	26731	77	19F
0005433434974	26731	78	20C
0005433434977	26731	79	20D
0005433434976	26731	80	20E
0005435982371	26731	81	20F
0005433686623	29273	1	1C
0005433686640	29273	2	2B
0005433689916	29273	3	2D
0005433689911	29273	4	3A
0005433686642	29273	5	3C
0005433689908	29273	6	3D
0005433689917	29273	7	5A
0005433686641	29273	8	5C
0005433686639	29273	9	6C
0005433689918	29273	10	6D
0005433689924	29273	11	7B
0005433686620	29273	12	7D
0005433689913	29273	13	18B
0005433689915	29273	14	19B
0005433686624	29273	15	19D
0005433686631	29273	16	20A
0005433689901	29273	17	20B
0005433689907	29273	18	20D
0005433689912	29273	19	21B
0005433686632	29273	20	21D
0005433689906	29273	21	22A
0005433689914	29273	22	23A
0005433686619	29273	23	23B
0005432858122	3174	1	1A
0005432584282	3174	2	1B
0005432584301	3174	3	1D
0005432584299	3174	4	2A
0005432858027	3174	5	2B
0005432584287	3174	6	2C
0005432858065	3174	7	2D
0005432858029	3174	8	3A
0005432584283	3174	9	3B
0005432858026	3174	10	3C
0005432858137	3174	11	3D
0005432216300	3174	12	4A
0005432584279	3174	13	4B
0005432584286	3174	14	4D
0005432584292	3174	15	5C
0005432858057	3174	16	5D
0005432584291	3174	17	6A
0005432584288	3174	18	6B
0005432584281	3174	19	6C
0005432584300	3174	20	7A
0005432584298	3174	21	7B
0005432858047	3174	22	7C
0005432858128	3174	23	7D
0005432584290	3174	24	18A
0005432584305	3174	25	18B
0005432584304	3174	26	18C
0005432858136	3174	27	18D
0005432584285	3174	28	19A
0005432858040	3174	29	19B
0005432584289	3174	30	19C
0005432584280	3174	31	19D
0005432584296	3174	32	20A
0005432584284	3174	33	20B
0005432584303	3174	34	20C
0005432584297	3174	35	20D
0005432584293	3174	36	21A
0005432584295	3174	37	21B
0005432858079	3174	38	21C
0005432216301	3174	39	22A
0005432584302	3174	40	22B
0005432858058	3174	41	22C
0005432216299	3174	42	22D
0005432858028	3174	43	23A
0005432584294	3174	44	23B
0005432858189	31478	1	1C
0005432858186	31478	2	1D
0005432584104	31478	3	2B
0005432584135	31478	4	2C
0005432584154	31478	5	2D
0005432583977	31478	6	3A
0005432858193	31478	7	3B
0005432858190	31478	8	3D
0005432584086	31478	9	4A
0005432858196	31478	10	4B
0005432583978	31478	11	5A
0005432584134	31478	12	5C
0005432584172	31478	13	6A
0005432583969	31478	14	6B
0005432584224	31478	15	7A
0005432858185	31478	16	7B
0005432584144	31478	17	18A
0005432584210	31478	18	18D
0005432858194	31478	19	19A
0005432858187	31478	20	19C
0005432858188	31478	21	20A
0005432584119	31478	22	20B
0005432858192	31478	23	20D
0005432584202	31478	24	21A
0005432584123	31478	25	21B
0005432584105	31478	26	21C
0005432858195	31478	27	21D
0005432858191	31478	28	22A
0005432584155	31478	29	23A
0005434943443	889	1	1A
0005434943445	889	2	1B
0005433255126	889	3	2C
0005434943444	889	4	3B
0005433255116	889	5	4B
0005433255118	889	6	5A
0005434943442	889	7	5C
0005434943446	889	8	6D
0005433255119	889	9	7B
0005433255132	889	10	19A
0005433255117	889	11	20C
0005434943441	889	12	20D
0005434943447	889	13	21A
0005433255136	889	14	21D
0005434943449	889	15	22B
0005434943448	889	16	22C
0005433255122	889	17	22D
0005433255137	889	18	23A
0005434943358	16235	1	1A
0005433255174	16235	2	1C
0005433255176	16235	3	2C
0005433255175	16235	4	3D
0005433255172	16235	5	5C
0005434943357	16235	6	18C
0005434943367	16235	7	19C
0005434943362	16235	8	22C
0005433255173	16235	9	23B
0005435858597	27604	1	1D
0005435858598	27604	2	2A
0005433654775	27604	3	2D
0005435858595	27604	4	3D
0005435858602	27604	5	3F
0005435858599	27604	6	4C
0005433654787	27604	7	4F
0005433654763	27604	8	6B
0005433654800	27604	9	6A
0005435858606	27604	10	7C
0005433654786	27604	11	7F
0005433654778	27604	12	9C
0005433654772	27604	13	9D
0005435858605	27604	14	10A
0005435858600	27604	15	10C
0005435858601	27604	16	11B
0005433654781	27604	17	12F
0005433654774	27604	18	14D
0005435858603	27604	19	14E
0005433654777	27604	20	15B
0005433654789	27604	21	15A
0005435858604	27604	22	15F
0005435858596	27604	23	18B
0005433654755	27604	24	18C
0005433654788	27604	25	19A
0005433654764	27604	26	19F
0005433654809	27604	27	20C
0005435858607	27604	28	21B
0005433654736	27604	29	21A
0005435653477	21776	1	1A
0005433367877	21776	2	1C
0005433368005	21776	3	1D
0005433367795	21776	4	1F
0005435653463	21776	5	2A
0005433367782	21776	6	2C
0005433367785	21776	7	2D
0005433367890	21776	8	2F
0005433367891	21776	9	3A
0005435653466	21776	10	3C
0005433367888	21776	11	3D
0005433367895	21776	12	3F
0005435653479	21776	13	4A
0005435653461	21776	14	4D
0005433367868	21776	15	4C
0005435653487	21776	16	4F
0005433367830	21776	17	5A
0005433368003	21776	18	5C
0005435653468	21776	19	5D
0005435653493	21776	20	5E
0005435653480	21776	21	5F
0005433367862	21776	22	6A
0005433368006	21776	23	6D
0005433368063	21776	24	6E
0005435653494	21776	25	6F
0005433367841	21776	26	7A
0005435653465	21776	27	7C
0005435653492	21776	28	7E
0005435653490	21776	29	7F
0005433367873	21776	30	8A
0005433367865	21776	31	8C
0005435653458	21776	32	8D
0005435653496	21776	33	8E
0005435653484	21776	34	8F
0005433367935	21776	35	9A
0005433367859	21776	36	9C
0005435653470	21776	37	9D
0005433367923	21776	38	9E
0005433367831	21776	39	9F
0005433368002	21776	40	10A
0005435653459	21776	41	10D
0005433367980	21776	42	10E
0005433367889	21776	43	10F
0005433367803	21776	44	11A
0005433367869	21776	45	11C
0005435653457	21776	46	11D
0005435653462	21776	47	11E
0005435653464	21776	48	11F
0005435653469	21776	49	12A
0005433367784	21776	50	12C
0005433367961	21776	51	12D
0005435653475	21776	52	12E
0005435653495	21776	53	13C
0005433367897	21776	54	13D
0005435653476	21776	55	13E
0005433367892	21776	56	13F
0005433367800	21776	57	14A
0005435653489	21776	58	14C
0005433367896	21776	59	14D
0005435653481	21776	60	14E
0005435653483	21776	61	14F
0005433367981	21776	62	15A
0005433367999	21776	63	15C
0005433367837	21776	64	15D
0005433368056	21776	65	15E
0005433367783	21776	66	16E
0005435653473	21776	67	16F
0005433367983	21776	68	17A
0005433367842	21776	69	17C
0005433367990	21776	70	17D
0005435653485	21776	71	17E
0005433367874	21776	72	17F
0005435653482	21776	73	18A
0005433368061	21776	74	18C
0005435653471	21776	75	18D
0005433367893	21776	76	18E
0005435653474	21776	77	18F
0005435653486	21776	78	19A
0005435653488	21776	79	19C
0005435653467	21776	80	19D
0005435653478	21776	81	19E
0005435653472	21776	82	19F
0005435653460	21776	83	20A
0005435653491	21776	84	20D
0005433367848	21776	85	20E
0005433367989	21776	86	20F
0005433785331	9390	1	1G
0005433805746	9390	2	2A
0005433805750	9390	3	1H
0005433805725	9390	4	2B
0005434171113	9390	5	2C
0005433785319	9390	6	4A
0005433805732	9390	7	3H
0005433805749	9390	8	4F
0005433785307	9390	9	4H
0005433805739	9390	10	5B
0005433785318	9390	11	5C
0005433785314	9390	12	5H
0005433785305	9390	13	9B
0005433805729	9390	14	9A
0005434270210	9390	15	11A
0005433785320	9390	16	9H
0005433805726	9390	17	11E
0005433785310	9390	18	11F
0005433785313	9390	19	11H
0005433805738	9390	20	12D
0005433805719	9390	21	12B
0005433805747	9390	22	12E
0005434171063	9390	23	13E
0005433763358	9390	24	13H
0005434171123	9390	25	14B
0005433805744	9390	26	14E
0005434171096	9390	27	14H
0005434171117	9390	28	15G
0005434171118	9390	29	16A
0005433805731	9390	30	16B
0005433785317	9390	31	16G
0005433785325	9390	32	16F
0005433785300	9390	33	16H
0005433785312	9390	34	17D
0005434171074	9390	35	17B
0005433785322	9390	36	17H
0005434151720	9390	37	18F
0005433785303	9390	38	19A
0005432667474	9390	39	19B
0005432657480	9390	40	19D
0005433785309	9390	41	19G
0005433785335	9390	42	20A
0005433763353	9390	43	20E
0005433763357	9390	44	20G
0005433805741	9390	45	20F
0005433785315	9390	46	20H
0005433805724	9390	47	21B
0005434270211	9390	48	21E
0005433763360	9390	49	21G
0005432657481	9390	50	21F
0005433763350	9390	51	22B
0005434171065	9390	52	22G
0005433785324	9390	53	23A
0005433805748	9390	54	23E
0005433763351	9390	55	23G
0005433763361	9390	56	23H
0005433805734	9390	57	24E
0005434171064	9390	58	24F
0005433805742	9390	59	24G
0005434273079	9390	60	25D
0005432666410	9390	61	24H
0005434171126	9390	62	25F
0005433785302	9390	63	27B
0005432667475	9390	64	27E
0005433805727	9390	65	27D
0005434171106	9390	66	27F
0005433785333	9390	67	27G
0005433785304	9390	68	27H
0005433805728	9390	69	28D
0005433763348	9390	70	28E
0005433805733	9390	71	28G
0005433805743	9390	72	29E
0005433805721	9390	73	29D
0005432657479	9390	74	29G
0005433805751	9390	75	29F
0005433785328	9390	76	29H
0005433785321	9390	77	30B
0005433805737	9390	78	30A
0005433785330	9390	79	30D
0005433785323	9390	80	30H
0005432665295	9390	81	31A
0005434171066	9390	82	31D
0005433805740	9390	83	31G
0005433805720	9390	84	32A
0005433805730	9390	85	31H
0005434151719	9390	86	32D
0005433785316	9390	87	32F
0005433805735	9390	88	33A
0005433785326	9390	89	32H
0005432665296	9390	90	33B
0005434273078	9390	91	33E
0005433785299	9390	92	33D
0005432665297	9390	93	33F
0005433763355	9390	94	33G
0005433785306	9390	95	34A
0005433763352	9390	96	34D
0005433785301	9390	97	34G
0005433805718	9390	98	34H
0005434171112	9390	99	35D
0005434171052	9390	100	35E
0005433785298	9390	101	35G
0005433785308	9390	102	36A
0005433805723	9390	103	36E
0005433763356	9390	104	36D
0005433805745	9390	105	36G
0005433763349	9390	106	37B
0005433805722	9390	107	37E
0005433785311	9390	108	37H
0005433785332	9390	109	38A
0005433785334	9390	110	38B
0005433785329	9390	111	38D
0005433785327	9390	112	38F
0005433763359	9390	113	38H
0005433805736	9390	114	39D
0005433763354	9390	115	39F
0005434171200	26252	1	1B
0005432657458	26252	2	1A
0005433785105	26252	3	1F
0005433805443	26252	4	1C
0005434171199	26252	5	1H
0005434171193	26252	6	1G
0005434171204	26252	7	2B
0005435269822	26252	8	2C
0005433805483	26252	9	2G
0005433784962	26252	10	2H
0005435269813	26252	11	3B
0005433805354	26252	12	3C
0005433763188	26252	13	4A
0005433763266	26252	14	4F
0005433784972	26252	15	4C
0005432666394	26252	16	4G
0005434270225	26252	17	5A
0005433763191	26252	18	5F
0005432659701	26252	19	5C
0005433805504	26252	20	5G
0005432657459	26252	21	9A
0005433784838	26252	22	5H
0005433763197	26252	23	9B
0005434171203	26252	24	9G
0005433805506	26252	25	11A
0005433805284	26252	26	11D
0005433785085	26252	27	11F
0005434270226	26252	28	11E
0005433805353	26252	29	12A
0005433785140	26252	30	11H
0005434171194	26252	31	12D
0005433763235	26252	32	12E
0005434171207	26252	33	12G
0005435269823	26252	34	12H
0005433785024	26252	35	13A
0005433805416	26252	36	13D
0005433805565	26252	37	13G
0005434151734	26252	38	14A
0005433784964	26252	39	14B
0005434269124	26252	40	14D
0005433763152	26252	41	14H
0005434171201	26252	42	15D
0005433805387	26252	43	15G
0005434171195	26252	44	15H
0005433805419	26252	45	16A
0005433785075	26252	46	16D
0005433805438	26252	47	16B
0005433805440	26252	48	17D
0005433805468	26252	49	17B
0005433784979	26252	50	18B
0005433805498	26252	51	18E
0005433763288	26252	52	18G
0005434171205	26252	53	18F
0005433805364	26252	54	19B
0005433805491	26252	55	19F
0005433805626	26252	56	19E
0005433763162	26252	57	19H
0005434271332	26252	58	19G
0005433785064	26252	59	20A
0005433805484	26252	60	20D
0005433784950	26252	61	20H
0005433805441	26252	62	20G
0005432657445	26252	63	21D
0005433785123	26252	64	21F
0005433805412	26252	65	21H
0005435269814	26252	66	22B
0005433763236	26252	67	22A
0005433805420	26252	68	22D
0005433784837	26252	69	22E
0005433805339	26252	70	22G
0005432663028	26252	71	22F
0005434171202	26252	72	23A
0005433805388	26252	73	23D
0005433805415	26252	74	23F
0005433784942	26252	75	23H
0005433805522	26252	76	23G
0005433785028	26252	77	24B
0005434171196	26252	78	24D
0005435269820	26252	79	24F
0005433784874	26252	80	24G
0005434269123	26252	81	25D
0005435269818	26252	82	25E
0005433763289	26252	83	27A
0005435269815	26252	84	25F
0005434171197	26252	85	27D
0005435269816	26252	86	27E
0005433763223	26252	87	27H
0005433805389	26252	88	27G
0005433785056	26252	89	28A
0005432666381	26252	90	28B
0005433763222	26252	91	28F
0005434171208	26252	92	28G
0005433785150	26252	93	29B
0005432659707	26252	94	29E
0005433805505	26252	95	29G
0005433763271	26252	96	29F
0005433784995	26252	97	29H
0005433785108	26252	98	30B
0005433805471	26252	99	30A
0005433784989	26252	100	30D
0005434269122	26252	101	30E
0005433763224	26252	102	30G
0005432663027	26252	103	30H
0005433784831	26252	104	31B
0005433805507	26252	105	31A
0005433763198	26252	106	31D
0005433784872	26252	107	31E
0005433805521	26252	108	31H
0005433805365	26252	109	32B
0005434151733	26252	110	32A
0005433805430	26252	111	32E
0005433763204	26252	112	33A
0005433805271	26252	113	32H
0005433785008	26252	114	33E
0005433805340	26252	115	33G
0005433784997	26252	116	33F
0005433805418	26252	117	34F
0005432659708	26252	118	34E
0005433805439	26252	119	34G
0005433784941	26252	120	34H
0005433763196	26252	121	35E
0005435269817	26252	122	35G
0005433805446	26252	123	35F
0005434171198	26252	124	36A
0005433784988	26252	125	36B
0005434151732	26252	126	36E
0005434171206	26252	127	36D
0005433785106	26252	128	36F
0005433805442	26252	129	36G
0005433805448	26252	130	37A
0005433784980	26252	131	36H
0005435269819	26252	132	37B
0005435269821	26252	133	37E
0005433763203	26252	134	37D
0005432663029	26252	135	37F
0005433763190	26252	136	37H
0005433763185	26252	137	38D
0005433805366	26252	138	38B
0005434271331	26252	139	38F
0005433805517	26252	140	38G
0005433784963	26252	141	39D
0005433784873	26252	142	39F
0005435929647	4877	1	1B
0005435929648	4877	2	1D
0005435929652	4877	3	4A
0005435135719	4877	4	7A
0005435135721	4877	5	7C
0005435929650	4877	6	20C
0005435135717	4877	7	21C
0005435135718	4877	8	22D
0005435135720	4877	9	23A
0005435929672	33008	1	4C
0005435135672	33008	2	4D
0005435929671	33008	3	18B
0005435929670	33008	4	19D
0005435135671	33008	5	22A
0005435135681	33008	6	23A
0005434217971	9483	1	3C
0005434983339	9483	2	4D
0005434983340	9483	3	6B
0005434217979	9483	4	6C
0005434983342	9483	5	6D
0005434983338	9483	6	7A
0005434983341	9483	7	19C
0005434217969	9483	8	20B
0005434983337	9483	9	20D
0005434217970	9483	10	22D
0005434218010	27376	1	2B
0005434983299	27376	2	4A
0005434983279	27376	3	4D
0005434218011	27376	4	6B
0005434983298	27376	5	6D
0005434218008	27376	6	7B
0005434218009	27376	7	18C
0005434983280	27376	8	22A
0005434983259	27376	9	22C
0005433960712	24246	1	1A
0005433985968	24246	2	1F
0005433960857	24246	3	1C
0005433985831	24246	4	1H
0005433960812	24246	5	2C
0005433960716	24246	6	3C
0005433960874	24246	7	4A
0005433960930	24246	8	3H
0005433986047	24246	9	4F
0005433960934	24246	10	4C
0005433960699	24246	11	5A
0005433986031	24246	12	4H
0005433960866	24246	13	5B
0005433960694	24246	14	5F
0005433960538	24246	15	9A
0005433985868	24246	16	5H
0005433986059	24246	17	5G
0005433985954	24246	18	9B
0005433986067	24246	19	11A
0005433960801	24246	20	11B
0005433986076	24246	21	11D
0005433960717	24246	22	11F
0005433960923	24246	23	11E
0005433985869	24246	24	11H
0005433985887	24246	25	12A
0005433960693	24246	26	12B
0005433985973	24246	27	12F
0005433960736	24246	28	12H
0005433960787	24246	29	12G
0005433960931	24246	30	13D
0005433960903	24246	31	13F
0005433960933	24246	32	13E
0005433960575	24246	33	13G
0005433960955	24246	34	13H
0005433986012	24246	35	15A
0005433960876	24246	36	15B
0005433985992	24246	37	15F
0005433960688	24246	38	15G
0005433960600	24246	39	16B
0005433960925	24246	40	16F
0005433985843	24246	41	16H
0005433986014	24246	42	17B
0005433960826	24246	43	17F
0005433960791	24246	44	17G
0005433985749	24246	45	18A
0005433986009	24246	46	18D
0005433960867	24246	47	18F
0005433985976	24246	48	19D
0005433985977	24246	49	19F
0005433960858	24246	50	19G
0005433960820	24246	51	20B
0005433985859	24246	52	20E
0005433986092	24246	53	20D
0005433985988	24246	54	20F
0005433960864	24246	55	21D
0005433960900	24246	56	21E
0005433960926	24246	57	21G
0005433960956	24246	58	21F
0005433960860	24246	59	22A
0005433985775	24246	60	22D
0005433960889	24246	61	22E
0005433960932	24246	62	22G
0005433985951	24246	63	22H
0005433960875	24246	64	23A
0005433960859	24246	65	23B
0005433986024	24246	66	23H
0005433985774	24246	67	24B
0005433986063	24246	68	24E
0005433986052	24246	69	24D
0005433986119	24246	70	24F
0005433986008	24246	71	24G
0005433960735	24246	72	24H
0005433960698	24246	73	25E
0005433986078	24246	74	27A
0005433960885	24246	75	27B
0005433986037	24246	76	27D
0005433960796	24246	77	28B
0005433985891	24246	78	28E
0005433960935	24246	79	28F
0005433960840	24246	80	28G
0005433985945	24246	81	29B
0005433986079	24246	82	29A
0005433960952	24246	83	29E
0005433985946	24246	84	29D
0005433985993	24246	85	29F
0005433960788	24246	86	29H
0005433960863	24246	87	30A
0005433960922	24246	88	30F
0005433986005	24246	89	31A
0005433986023	24246	90	31B
0005433985918	24246	91	31D
0005433986048	24246	92	31E
0005433985847	24246	93	31G
0005433960718	24246	94	31H
0005433985766	24246	95	32D
0005433960849	24246	96	33A
0005433985901	24246	97	33E
0005433986006	24246	98	33H
0005433986004	24246	99	33G
0005433985995	24246	100	34F
0005433960948	24246	101	35A
0005433960847	24246	102	34H
0005433986060	24246	103	35B
0005433960901	24246	104	35E
0005433985950	24246	105	35G
0005433985902	24246	106	36A
0005433986033	24246	107	36B
0005433986013	24246	108	36F
0005433986007	24246	109	36H
0005433986044	24246	110	37B
0005433960705	24246	111	37H
0005433986118	24246	112	38B
0005433960899	24246	113	38A
0005433960909	24246	114	38G
0005433985962	24246	115	38H
0005433960886	24246	116	39D
0005433985758	24246	117	39E
0005433986377	25949	1	1B
0005433961394	25949	2	1F
0005433961418	25949	3	1G
0005433961391	25949	4	1H
0005433961416	25949	5	2B
0005433961402	25949	6	2F
0005433986369	25949	7	3B
0005433986365	25949	8	3C
0005433961386	25949	9	5A
0005433986383	25949	10	5B
0005433986392	25949	11	5G
0005433986403	25949	12	5F
0005433961423	25949	13	5H
0005433986361	25949	14	11A
0005433986373	25949	15	11F
0005433961406	25949	16	11E
0005433961427	25949	17	12D
0005433986390	25949	18	13A
0005433986375	25949	19	13D
0005433961412	25949	20	14E
0005433961413	25949	21	14G
0005433986397	25949	22	15B
0005433961395	25949	23	15F
0005433986389	25949	24	15H
0005433986400	25949	25	15G
0005433961409	25949	26	16A
0005433961399	25949	27	16F
0005433986394	25949	28	17B
0005433986370	25949	29	17A
0005433986358	25949	30	18A
0005433961420	25949	31	18H
0005433986393	25949	32	18G
0005433961411	25949	33	18F
0005433986364	25949	34	19B
0005433961397	25949	35	19D
0005433986356	25949	36	19F
0005433961387	25949	37	20B
0005433986362	25949	38	20E
0005433986372	25949	39	20H
0005433961419	25949	40	20G
0005433986401	25949	41	21A
0005433961398	25949	42	21G
0005433986363	25949	43	22D
0005433986387	25949	44	22G
0005433961400	25949	45	22F
0005433961426	25949	46	22H
0005433986374	25949	47	23E
0005433986379	25949	48	23D
0005433986386	25949	49	23F
0005433986395	25949	50	24A
0005433961404	25949	51	23H
0005433986367	25949	52	24D
0005433986368	25949	53	25F
0005433986357	25949	54	27B
0005433986391	25949	55	27F
0005433961428	25949	56	27E
0005433961392	25949	57	27G
0005433961415	25949	58	28A
0005433986405	25949	59	27H
0005433986360	25949	60	28D
0005433986384	25949	61	28E
0005433961385	25949	62	29A
0005433961388	25949	63	29E
0005433961403	25949	64	29F
0005433961390	25949	65	30A
0005433986402	25949	66	29H
0005433986399	25949	67	30F
0005433986381	25949	68	31B
0005433986382	25949	69	31E
0005433961410	25949	70	31F
0005433986359	25949	71	31G
0005433961407	25949	72	33A
0005433961417	25949	73	33B
0005433961396	25949	74	33E
0005433986396	25949	75	33F
0005433961408	25949	76	33G
0005433986380	25949	77	34D
0005433961393	25949	78	35B
0005433986371	25949	79	35A
0005433961414	25949	80	35G
0005433961424	25949	81	36A
0005433961389	25949	82	35H
0005433961425	25949	83	36B
0005433961422	25949	84	36E
0005433961421	25949	85	36D
0005433986398	25949	86	37E
0005433986404	25949	87	37H
0005433986366	25949	88	38A
0005433986388	25949	89	38E
0005433961401	25949	90	38G
0005433986385	25949	91	38F
0005433986378	25949	92	39D
0005433986376	25949	93	39E
0005433961405	25949	94	39F
0005434480579	944	1	1C
0005434480597	944	2	1D
0005433165967	944	3	2A
0005434480577	944	4	2B
0005434480589	944	5	2C
0005432269525	944	6	2D
0005432269524	944	7	3A
0005433165998	944	8	3C
0005434480584	944	9	3D
0005434480581	944	10	4A
0005434480574	944	11	4B
0005433165975	944	12	4C
0005432269523	944	13	4D
0005434480585	944	14	5A
0005433165934	944	15	5B
0005433165966	944	16	5C
0005434480592	944	17	5D
0005433165976	944	18	6A
0005434480598	944	19	6C
0005433165933	944	20	6D
0005434480593	944	21	7A
0005434480576	944	22	7C
0005434480590	944	23	7D
0005434480583	944	24	18A
0005434480575	944	25	18B
0005434480594	944	26	18C
0005434480599	944	27	18D
0005434480580	944	28	19B
0005434480596	944	29	19D
0005433165965	944	30	20A
0005434480582	944	31	20B
0005434480586	944	32	20C
0005433165944	944	33	20D
0005434480591	944	34	21A
0005434480595	944	35	21B
0005434480588	944	36	21C
0005433165970	944	37	21D
0005434480578	944	38	22A
0005433165945	944	39	22B
0005433165963	944	40	22D
0005434480587	944	41	23A
0005434480389	16599	1	1A
0005434480375	16599	2	1B
0005433166034	16599	3	1C
0005433166037	16599	4	2A
0005434480382	16599	5	2B
0005434480339	16599	6	2C
0005434480415	16599	7	2D
0005433166036	16599	8	3B
0005433166041	16599	9	3D
0005434480396	16599	10	4C
0005434480338	16599	11	4D
0005434480326	16599	12	5A
0005433166042	16599	13	5B
0005434480392	16599	14	5C
0005434480307	16599	15	5D
0005434480321	16599	16	6A
0005434480376	16599	17	6B
0005433166038	16599	18	6C
0005434480414	16599	19	7A
0005434480308	16599	20	7B
0005434480273	16599	21	7C
0005433166032	16599	22	18A
0005434480284	16599	23	18B
0005434480446	16599	24	18D
0005434480343	16599	25	19C
0005434480327	16599	26	19D
0005433166033	16599	27	20B
0005433166035	16599	28	21A
0005433166040	16599	29	21D
0005434480296	16599	30	22A
0005433166039	16599	31	22B
0005434480342	16599	32	22C
0005434480346	16599	33	23A
0005435150153	10326	1	1A
0005433289836	10326	2	1B
0005433289854	10326	3	1C
0005433289869	10326	4	1D
0005435150164	10326	5	2A
0005435142705	10326	6	2B
0005433289843	10326	7	2C
0005435142702	10326	8	2D
0005435142709	10326	9	3A
0005433289858	10326	10	3B
0005435150160	10326	11	3D
0005435150157	10326	12	4A
0005433289852	10326	13	4B
0005435142698	10326	14	4C
0005435150155	10326	15	4D
0005435150158	10326	16	5A
0005435150152	10326	17	5B
0005435150156	10326	18	5C
0005435142697	10326	19	5D
0005435150149	10326	20	6A
0005433289856	10326	21	6B
0005435142703	10326	22	6C
0005435142706	10326	23	6D
0005435142701	10326	24	7A
0005435142696	10326	25	7B
0005433289859	10326	26	7C
0005435142699	10326	27	7D
0005435142704	10326	28	18A
0005433289835	10326	29	18B
0005435142700	10326	30	18C
0005433289857	10326	31	18D
0005435142707	10326	32	19A
0005433289855	10326	33	19B
0005435142708	10326	34	19C
0005435150162	10326	35	19D
0005433289844	10326	36	20A
0005435150154	10326	37	20B
0005435150163	10326	38	20C
0005435150151	10326	39	20D
0005433289847	10326	40	21A
0005433289845	10326	41	21B
0005435150150	10326	42	21D
0005435150159	10326	43	22A
0005433289837	10326	44	22B
0005435150161	10326	45	22C
0005433289842	10326	46	22D
0005433289851	10326	47	23A
0005435142590	21916	1	1B
0005435142526	21916	2	1C
0005435386637	21916	3	1D
0005435386643	21916	4	2A
0005435142527	21916	5	2B
0005435142615	21916	6	2C
0005435142531	21916	7	2D
0005435149966	21916	8	3A
0005435142601	21916	9	3C
0005433289931	21916	10	3D
0005435386640	21916	11	4B
0005433289929	21916	12	4C
0005433289927	21916	13	4D
0005433289928	21916	14	5A
0005435142614	21916	15	5B
0005435386642	21916	16	5C
0005435150005	21916	17	6A
0005433289926	21916	18	6B
0005435386639	21916	19	6D
0005435386641	21916	20	7B
0005435150023	21916	21	7C
0005435386638	21916	22	7D
0005435150038	21916	23	18A
0005435142542	21916	24	18B
0005435150039	21916	25	19A
0005435142525	21916	26	19C
0005435150006	21916	27	20A
0005435142524	21916	28	20B
0005433289925	21916	29	20C
0005433289930	21916	30	20D
0005435142530	21916	31	21A
0005435386636	21916	32	21B
0005435142588	21916	33	21C
0005435142543	21916	34	22A
0005435150037	21916	35	22D
0005435142544	21916	36	23B
0005435529298	11190	1	1A
0005435545742	11190	2	1C
0005434573482	11190	3	1D
0005435319611	11190	4	1F
0005434573488	11190	5	2A
0005435529269	11190	6	2C
0005434573485	11190	7	2D
0005435529267	11190	8	3A
0005435502303	11190	9	3C
0005435529285	11190	10	3D
0005435529343	11190	11	4A
0005434573490	11190	12	4C
0005435502385	11190	13	4D
0005435545739	11190	14	4E
0005435545762	11190	15	4F
0005435545738	11190	16	5C
0005435502382	11190	17	5D
0005435529241	11190	18	5E
0005435529240	11190	19	5F
0005435529268	11190	20	6A
0005435529293	11190	21	6D
0005435529332	11190	22	6E
0005435529292	11190	23	6F
0005435529207	11190	24	7A
0005434573486	11190	25	7C
0005434573480	11190	26	7D
0005434573487	11190	27	7E
0005434573489	11190	28	7F
0005435529188	11190	29	8A
0005435502348	11190	30	8C
0005435529341	11190	31	8D
0005434573477	11190	32	8E
0005435529295	11190	33	8F
0005434573479	11190	34	9A
0005435502418	11190	35	9C
0005435529261	11190	36	9D
0005435545741	11190	37	9E
0005435529294	11190	38	9F
0005434573478	11190	39	10C
0005434573491	11190	40	10D
0005435319601	11190	41	10E
0005435529346	11190	42	11C
0005435545763	11190	43	11D
0005435529321	11190	44	11E
0005435319599	11190	45	11F
0005435529302	11190	46	12A
0005435319600	11190	47	12C
0005435502375	11190	48	12E
0005435502304	11190	49	12F
0005435529260	11190	50	13A
0005435545764	11190	51	13D
0005435529348	11190	52	13E
0005435502361	11190	53	13F
0005435502398	11190	54	14A
0005435529275	11190	55	14C
0005435529355	11190	56	14D
0005435529299	11190	57	14E
0005435529394	11190	58	15A
0005435502347	11190	59	15C
0005435529333	11190	60	15D
0005435529208	11190	61	15E
0005434573484	11190	62	15F
0005435529276	11190	63	16A
0005435502279	11190	64	16C
0005435502381	11190	65	16D
0005435502376	11190	66	16E
0005435502399	11190	67	16F
0005435529253	11190	68	17A
0005435529242	11190	69	17C
0005435319612	11190	70	17D
0005434573481	11190	71	17E
0005435502321	11190	72	17F
0005435529245	11190	73	18A
0005435502280	11190	74	18C
0005435529238	11190	75	18D
0005434573483	11190	76	18F
0005435319591	11190	77	19A
0005435502323	11190	78	19C
0005435529345	11190	79	19D
0005435529284	11190	80	19E
0005435529342	11190	81	19F
0005435502419	11190	82	20D
0005435529278	11190	83	20E
0005435319572	11190	84	20F
0005435319668	20909	1	1C
0005435502513	20909	2	1F
0005435518076	20909	3	2A
0005435502510	20909	4	2C
0005435319671	20909	5	2D
0005435518082	20909	6	2F
0005435508467	20909	7	3A
0005435508463	20909	8	3D
0005435502521	20909	9	3F
0005434573379	20909	10	4D
0005435502527	20909	11	5A
0005435518087	20909	12	5C
0005435518074	20909	13	5D
0005435518084	20909	14	5E
0005435502514	20909	15	5F
0005434573351	20909	16	6A
0005435508464	20909	17	6C
0005435518088	20909	18	6D
0005434573296	20909	19	6E
0005435502509	20909	20	7A
0005435502523	20909	21	7C
0005435518080	20909	22	7E
0005435502517	20909	23	7F
0005435518075	20909	24	8A
0005435518086	20909	25	8D
0005435502525	20909	26	8F
0005435502528	20909	27	9C
0005435502512	20909	28	9D
0005435518085	20909	29	9E
0005435518083	20909	30	10A
0005435508469	20909	31	10C
0005435319676	20909	32	10D
0005435319670	20909	33	10E
0005435502516	20909	34	10F
0005435518093	20909	35	11A
0005435518081	20909	36	11D
0005435508468	20909	37	11E
0005435518073	20909	38	11F
0005435502522	20909	39	12A
0005435518092	20909	40	12C
0005435319669	20909	41	12E
0005434573371	20909	42	13A
0005435502524	20909	43	13C
0005435502511	20909	44	13D
0005435508466	20909	45	13E
0005435518089	20909	46	13F
0005435508472	20909	47	14A
0005435518090	20909	48	14C
0005434573370	20909	49	14D
0005435502529	20909	50	15A
0005432291953	20909	51	14F
0005435502515	20909	52	15C
0005435518079	20909	53	15D
0005434573375	20909	54	15E
0005435518077	20909	55	15F
0005434573387	20909	56	16A
0005435508471	20909	57	16C
0005435502508	20909	58	16D
0005435502518	20909	59	16E
0005435518078	20909	60	16F
0005435319673	20909	61	17A
0005435508465	20909	62	17D
0005434573386	20909	63	17E
0005435508470	20909	64	18A
0005435518091	20909	65	18D
0005435319675	20909	66	18E
0005435502520	20909	67	19C
0005432291952	20909	68	19E
0005434573324	20909	69	19F
0005435319674	20909	70	20A
0005435502519	20909	71	20D
0005435502526	20909	72	20E
0005435319672	20909	73	20F
0005432693098	3039	1	1D
0005432693062	3039	2	2F
0005432693078	3039	3	4D
0005432693159	3039	4	4E
0005432693085	3039	5	5A
0005432693080	3039	6	5F
0005432693160	3039	7	6A
0005432693097	3039	8	7C
0005432693090	3039	9	8C
0005432693092	3039	10	8E
0005432692936	3039	11	8F
0005432693086	3039	12	9D
0005432693072	3039	13	10A
0005432693091	3039	14	12C
0005432693077	3039	15	12F
0005432693081	3039	16	13C
0005432692985	3039	17	15E
0005432693099	3039	18	17A
0005432693022	3039	19	18A
0005432693066	3039	20	18F
0005432693163	3039	21	19A
0005432693148	3039	22	19C
0005432693149	3039	23	20F
0005432707023	2995	1	1C
0005432707021	2995	2	2D
0005432880886	2995	3	2F
0005432707033	2995	4	3A
0005432707027	2995	5	3C
0005433123973	2995	6	3F
0005433123980	2995	7	4A
0005432707015	2995	8	4D
0005433123865	2995	9	4F
0005432880813	2995	10	5C
0005432707031	2995	11	5D
0005432217804	2995	12	5E
0005432880845	2995	13	5F
0005433124000	2995	14	6E
0005432880857	2995	15	7E
0005432707025	2995	16	8A
0005432707026	2995	17	8C
0005432880860	2995	18	8D
0005432707037	2995	19	8E
0005433194870	2995	20	8F
0005432707024	2995	21	9A
0005432707038	2995	22	9D
0005432880828	2995	23	10A
0005433123936	2995	24	10D
0005432707032	2995	25	10F
0005432707016	2995	26	11C
0005432707017	2995	27	11D
0005433123906	2995	28	11E
0005432707019	2995	29	11F
0005432707034	2995	30	12C
0005433123985	2995	31	12E
0005432707035	2995	32	12F
0005432707022	2995	33	13A
0005432707028	2995	34	13C
0005432707036	2995	35	13F
0005432880798	2995	36	14C
0005432707039	2995	37	14F
0005433123986	2995	38	15C
0005432707029	2995	39	15F
0005433123827	2995	40	16D
0005432707020	2995	41	16E
0005432707030	2995	42	17E
0005432217805	2995	43	17F
0005432707040	2995	44	18C
0005433123878	2995	45	18E
0005432707018	2995	46	19C
0005433123979	2995	47	19E
0005433123881	2995	48	20C
0005432880797	2995	49	20D
0005432706734	29916	1	1A
0005433124130	29916	2	1C
0005433124123	29916	3	1D
0005432706884	29916	4	1F
0005433124140	29916	5	2A
0005432693393	29916	6	2C
0005432693396	29916	7	2D
0005432693408	29916	8	2F
0005432706764	29916	9	3A
0005432880959	29916	10	3C
0005433124139	29916	11	3F
0005432693380	29916	12	4A
0005432706779	29916	13	4C
0005433124124	29916	14	4D
0005432693387	29916	15	4E
0005432693381	29916	16	4F
0005432693405	29916	17	5A
0005432693402	29916	18	5C
0005433124137	29916	19	5D
0005432693391	29916	20	5E
0005432706885	29916	21	5F
0005433124134	29916	22	6A
0005432693406	29916	23	6C
0005432693400	29916	24	6D
0005432693404	29916	25	6E
0005432880965	29916	26	6F
0005432693410	29916	27	7A
0005432880956	29916	28	7C
0005433124127	29916	29	7D
0005432693398	29916	30	7E
0005433194888	29916	31	7F
0005432693388	29916	32	8A
0005432693397	29916	33	8C
0005432693379	29916	34	8D
0005433124141	29916	35	8E
0005433124132	29916	36	8F
0005432706738	29916	37	9A
0005432880961	29916	38	9C
0005432880958	29916	39	9D
0005432693394	29916	40	9E
0005432693392	29916	41	9F
0005432880969	29916	42	10A
0005432880964	29916	43	10C
0005433124143	29916	44	10D
0005433194891	29916	45	10E
0005432880971	29916	46	10F
0005432706832	29916	47	11A
0005433124142	29916	48	11C
0005433124133	29916	49	11D
0005432693401	29916	50	11E
0005432880970	29916	51	11F
0005433124131	29916	52	12A
0005432706780	29916	53	12C
0005432706865	29916	54	12D
0005432880963	29916	55	12E
0005432880957	29916	56	12F
0005432706878	29916	57	13A
0005433124126	29916	58	13C
0005432693389	29916	59	13D
0005433124136	29916	60	13E
0005432706801	29916	61	13F
0005432706862	29916	62	14A
0005432693399	29916	63	14C
0005432693390	29916	64	14D
0005432880967	29916	65	14E
0005433124128	29916	66	14F
0005433124120	29916	67	15A
0005433194890	29916	68	15C
0005433124122	29916	69	15D
0005432706879	29916	70	15E
0005432880962	29916	71	15F
0005433124129	29916	72	16A
0005432706824	29916	73	16C
0005432706753	29916	74	16D
0005432706844	29916	75	16E
0005432693395	29916	76	16F
0005432706737	29916	77	17A
0005432706861	29916	78	17C
0005432693383	29916	79	17D
0005432693409	29916	80	17E
0005433194889	29916	81	17F
0005433124138	29916	82	18A
0005432693407	29916	83	18C
0005432693403	29916	84	18D
0005433124125	29916	85	18E
0005433124135	29916	86	18F
0005432706761	29916	87	19A
0005432880966	29916	88	19C
0005432693384	29916	89	19D
0005432880968	29916	90	19E
0005432693385	29916	91	19F
0005432706869	29916	92	20A
0005432880960	29916	93	20C
0005433124121	29916	94	20D
0005432693382	29916	95	20E
0005432693386	29916	96	20F
0005434988836	23657	1	1A
0005434980074	23657	2	1B
0005434980079	23657	3	1C
0005434980078	23657	4	1D
0005434980081	23657	5	2A
0005434980066	23657	6	2B
0005434980080	23657	7	2C
0005434980082	23657	8	3A
0005434988837	23657	9	3B
0005434980071	23657	10	3C
0005434988832	23657	11	3D
0005434980073	23657	12	4A
0005434980054	23657	13	4B
0005434980059	23657	14	4C
0005434988840	23657	15	4D
0005434980065	23657	16	5A
0005434980060	23657	17	5B
0005434980076	23657	18	5C
0005434988841	23657	19	5D
0005434988833	23657	20	6B
0005434988845	23657	21	6C
0005434988839	23657	22	6D
0005434980067	23657	23	7A
0005434980068	23657	24	7B
0005434980053	23657	25	7C
0005434980063	23657	26	7D
0005434980056	23657	27	18A
0005434980052	23657	28	18B
0005434988844	23657	29	18C
0005434980057	23657	30	18D
0005434980064	23657	31	19B
0005434988834	23657	32	19C
0005434980055	23657	33	19D
0005434980058	23657	34	20A
0005434988835	23657	35	20B
0005434980070	23657	36	20C
0005434980062	23657	37	20D
0005434980069	23657	38	21A
0005434988843	23657	39	21B
0005434988842	23657	40	21C
0005434988838	23657	41	21D
0005434980077	23657	42	22A
0005434980072	23657	43	22B
0005434980075	23657	44	22D
0005434980061	23657	45	23B
0005434988739	27540	1	1A
0005434979862	27540	2	1C
0005434979699	27540	3	1D
0005434979756	27540	4	2A
0005434988738	27540	5	2B
0005434979956	27540	6	2C
0005434979833	27540	7	3A
0005434979700	27540	8	3B
0005434988734	27540	9	3C
0005434979804	27540	10	3D
0005434988711	27540	11	4A
0005434988705	27540	12	4B
0005434979832	27540	13	4C
0005434988718	27540	14	4D
0005434979788	27540	15	5A
0005434979844	27540	16	5B
0005434979911	27540	17	5D
0005434988756	27540	18	6A
0005434979937	27540	19	6B
0005434988721	27540	20	6C
0005434979936	27540	21	6D
0005434979923	27540	22	7A
0005434979749	27540	23	7B
0005434979893	27540	24	7C
0005434988728	27540	25	7D
0005434979938	27540	26	18A
0005434979894	27540	27	18B
0005434979760	27540	28	18C
0005434979895	27540	29	18D
0005434979863	27540	30	19A
0005434988744	27540	31	19B
0005434988750	27540	32	19C
0005434979945	27540	33	19D
0005434979783	27540	34	20A
0005434979889	27540	35	20B
0005434988712	27540	36	20D
0005434979845	27540	37	21A
0005434979757	27540	38	21B
0005434988710	27540	39	21C
0005434979759	27540	40	21D
0005434979922	27540	41	22A
0005434988740	27540	42	22C
0005434979775	27540	43	22D
0005434979917	27540	44	23A
0005434988706	27540	45	23B
0005433113543	10267	1	2C
0005434302499	10267	2	5A
0005433111508	10267	3	6A
0005434302501	10267	4	6C
0005433111509	10267	5	7C
0005434302873	10267	6	20D
0005434302500	10267	7	21C
0005434302874	10267	8	22B
0005433113560	19602	1	1B
0005433113557	19602	2	1C
0005433113559	19602	3	2B
0005434302464	19602	4	2D
0005433113558	19602	5	3B
0005434302451	19602	6	3D
0005434302470	19602	7	19B
0005434302471	19602	8	19D
0005434302465	19602	9	20B
0005434302452	19602	10	20C
0005434302469	19602	11	21C
0005434302466	19602	12	22C
0005435069627	3544	1	1A
0005435069596	3544	2	1C
0005435069616	3544	3	1D
0005435925298	3544	4	2A
0005435069614	3544	5	2C
0005435069591	3544	6	2F
0005435069603	3544	7	3A
0005435069631	3544	8	3C
0005435069617	3544	9	4A
0005435925295	3544	10	4C
0005435069589	3544	11	4D
0005435069600	3544	12	4E
0005435925277	3544	13	4F
0005435069640	3544	14	5D
0005435069625	3544	15	5E
0005435925311	3544	16	5F
0005435069618	3544	17	6A
0005435925312	3544	18	6C
0005435069634	3544	19	6D
0005435069642	3544	20	6F
0005435069632	3544	21	7A
0005435069590	3544	22	7C
0005435069638	3544	23	7D
0005435718996	3544	24	7E
0005435925306	3544	25	8A
0005435069604	3544	26	8C
0005435069606	3544	27	8F
0005435069619	3544	28	9A
0005435069635	3544	29	9C
0005435069611	3544	30	9E
0005435069633	3544	31	9F
0005435069639	3544	32	10A
0005435069628	3544	33	10C
0005435069626	3544	34	10E
0005435718999	3544	35	10F
0005435925313	3544	36	11A
0005435069601	3544	37	11C
0005435069623	3544	38	11D
0005435069607	3544	39	11E
0005435925297	3544	40	12A
0005435069624	3544	41	12C
0005435925296	3544	42	13A
0005435069613	3544	43	13C
0005435069602	3544	44	13D
0005435069598	3544	45	13F
0005435069599	3544	46	14C
0005435718997	3544	47	14D
0005435069593	3544	48	14F
0005435069595	3544	49	15C
0005435069636	3544	50	15E
0005435069621	3544	51	15F
0005435069609	3544	52	16A
0005435069612	3544	53	16D
0005435069641	3544	54	16E
0005435069637	3544	55	16F
0005435069620	3544	56	17A
0005435925307	3544	57	17E
0005435925288	3544	58	18C
0005435069615	3544	59	18D
0005435069622	3544	60	18E
0005435718998	3544	61	18F
0005435069592	3544	62	19A
0005435069629	3544	63	19D
0005435069610	3544	64	19E
0005435069605	3544	65	19F
0005435069594	3544	66	20A
0005435069608	3544	67	20D
0005435069630	3544	68	20E
0005435069597	3544	69	20F
0005435069114	15294	1	1A
0005435939898	15294	2	1C
0005435069075	15294	3	1D
0005435068969	15294	4	1F
0005435069032	15294	5	2A
0005435925433	15294	6	2D
0005435069000	15294	7	2F
0005435069145	15294	8	3C
0005435069140	15294	9	3D
0005435069176	15294	10	3F
0005435925425	15294	11	4A
0005435069326	15294	12	4D
0005435069318	15294	13	4F
0005435069122	15294	14	5C
0005435069141	15294	15	6A
0005435925435	15294	16	6D
0005435069126	15294	17	6F
0005435069031	15294	18	7A
0005435069151	15294	19	7C
0005435925432	15294	20	7D
0005435069136	15294	21	7E
0005435069030	15294	22	7F
0005435069135	15294	23	8A
0005435069154	15294	24	8C
0005435069300	15294	25	8F
0005435069248	15294	26	9A
0005435068968	15294	27	9F
0005435925436	15294	28	10C
0005435069164	15294	29	10D
0005435939897	15294	30	11A
0005435069125	15294	31	11D
0005435925426	15294	32	11E
0005435925429	15294	33	11F
0005435069249	15294	34	12D
0005435069207	15294	35	13C
0005435069403	15294	36	13D
0005435069069	15294	37	13F
0005435925431	15294	38	14A
0005435069102	15294	39	14C
0005435068865	15294	40	15A
0005435069050	15294	41	15C
0005435069166	15294	42	15D
0005435069259	15294	43	15E
0005435068939	15294	44	15F
0005435069279	15294	45	16C
0005435069123	15294	46	17C
0005435068999	15294	47	17D
0005435069165	15294	48	17E
0005435925428	15294	49	17F
0005435925427	15294	50	18C
0005435069319	15294	51	18D
0005435069078	15294	52	18E
0005435925424	15294	53	19A
0005435925430	15294	54	19E
0005435939896	15294	55	20A
0005435069404	15294	56	20D
0005435925434	15294	57	20E
0005435925437	15294	58	20F
0005432659726	18129	1	1A
0005432658613	18129	2	2B
0005432659727	18129	3	3B
0005432658612	18129	4	4A
0005432660839	18129	5	6B
0005432660812	26382	1	2A
0005432660815	26382	2	3A
0005432664131	26382	3	3B
0005432660816	26382	4	4A
0005432660808	26382	5	6A
0005432901703	27	1	1F
0005432919915	27	2	2C
0005432919937	27	3	2F
0005432919962	27	4	3A
0005432901569	27	5	3C
0005433102044	27	6	3F
0005432919885	27	7	4A
0005433102223	27	8	4F
0005433102149	27	9	5D
0005432157512	27	10	6A
0005432919932	27	11	6C
0005432901663	27	12	6D
0005433102284	27	13	7A
0005432919963	27	14	8A
0005433102156	27	15	7F
0005432919899	27	16	8B
0005433102290	27	17	8D
0005433102110	27	18	8E
0005433102255	27	19	8F
0005433102272	27	20	9B
0005433102289	27	21	9A
0005433102279	27	22	9C
0005433102174	27	23	9D
0005432901682	27	24	10A
0005432901624	27	25	10B
0005433102268	27	26	11A
0005433102133	27	27	11E
0005432901577	27	28	12A
0005433102200	27	29	11F
0005432901637	27	30	12D
0005432677569	27	31	12C
0005432901628	27	32	12F
0005433102254	27	33	13A
0005433102234	27	34	13E
0005433102256	27	35	13F
0005433102198	27	36	14E
0005433102281	27	37	14D
0005433102186	27	38	15C
0005433102045	27	39	15F
0005433102253	27	40	16B
0005432901645	27	41	16D
0005432919877	27	42	16C
0005433102114	27	43	16F
0005433102283	27	44	17A
0005432901664	27	45	17C
0005433102181	27	46	17E
0005432919900	27	47	18A
0005432919938	27	48	18D
0005432919901	27	49	18E
0005433102230	27	50	19C
0005433102235	27	51	19D
0005433102157	27	52	20C
0005433102214	27	53	20B
0005432919991	27	54	20E
0005433102199	27	55	20D
0005433102148	27	56	21C
0005432901615	27	57	21D
0005432677572	27	58	21F
0005432919876	27	59	21E
0005433102173	27	60	22B
0005432901681	27	61	22D
0005432919936	27	62	23B
0005432919861	27	63	23D
0005433102247	27	64	23E
0005432919894	27	65	24B
0005432901652	27	66	24A
0005432901602	27	67	24D
0005433102142	27	68	24E
0005432901578	27	69	24F
0005432901635	27	70	25B
0005432901683	27	71	25C
0005432919910	27	72	25E
0005433102197	27	73	26B
0005433102222	27	74	26E
0005433102113	27	75	26F
0005433102285	27	76	27A
0005433102172	27	77	27B
0005433102213	27	78	27F
0005433102280	27	79	27E
0005433102273	27	80	28A
0005432919898	27	81	28B
0005433102117	27	82	28F
0005432901603	27	83	29A
0005432919908	27	84	29B
0005432901666	27	85	29D
0005433102252	27	86	29F
0005432919916	27	87	29E
0005432901670	27	88	30A
0005432919871	27	89	30C
0005432901636	27	90	30B
0005433102261	27	91	30E
0005432157511	27	92	31C
0005432817775	26	1	2C
0005432262367	26	2	3A
0005432262386	26	3	3C
0005432262387	26	4	3D
0005432817773	26	5	4D
0005432262359	26	6	5A
0005432262373	26	7	4F
0005432289019	26	8	5C
0005432289018	26	9	5F
0005432262391	26	10	6F
0005432262383	26	11	6D
0005432817786	26	12	7A
0005432262352	26	13	7C
0005432262385	26	14	7D
0005432262376	26	15	8A
0005432262362	26	16	8B
0005432262357	26	17	8F
0005432262377	26	18	9B
0005432756837	26	19	9C
0005432289021	26	20	9E
0005432817787	26	21	10A
0005432262395	26	22	10B
0005432262372	26	23	10C
0005432262384	26	24	10F
0005432817779	26	25	11C
0005432817768	26	26	11D
0005432756828	26	27	11F
0005434153545	26	28	11E
0005432262382	26	29	12A
0005432262366	26	30	12C
0005432817778	26	31	12D
0005432262355	26	32	12F
0005432262370	26	33	13D
0005432262392	26	34	13E
0005432817780	26	35	14B
0005432262350	26	36	14A
0005432817763	26	37	14D
0005432262351	26	38	14C
0005432262363	26	39	14F
0005432262375	26	40	15B
0005432262379	26	41	15A
0005432817781	26	42	15D
0005432262388	26	43	15F
0005432262356	26	44	15E
0005432262371	26	45	16A
0005432262390	26	46	16B
0005432756844	26	47	16E
0005432262364	26	48	17B
0005432289020	26	49	17D
0005434153546	26	50	17F
0005432817761	26	51	18D
0005432262358	26	52	18C
0005432817782	26	53	18E
0005432817785	26	54	19B
0005432262361	26	55	18F
0005432262394	26	56	19E
0005432753315	26	57	20B
0005432262369	26	58	20D
0005432262389	26	59	21B
0005432817769	26	60	22A
0005432817764	26	61	22B
0005434153544	26	62	22D
0005432817767	26	63	23A
0005432817765	26	64	23B
0005432262365	26	65	23F
0005432262354	26	66	24D
0005432817770	26	67	24F
0005432817776	26	68	25B
0005432817771	26	69	25E
0005432262360	26	70	26C
0005432262374	26	71	26D
0005432817759	26	72	26F
0005432817772	26	73	27B
0005432756836	26	74	27A
0005432262381	26	75	27D
0005432817766	26	76	27E
0005432262380	26	77	28A
0005432817758	26	78	28B
0005432817760	26	79	28C
0005433687692	26	80	29A
0005432817777	26	81	29B
0005432817774	26	82	29E
0005432262378	26	83	30A
0005432207686	26	84	30D
0005432817783	26	85	31B
0005432262353	26	86	31A
0005432817762	26	87	31C
0005432262368	26	88	31D
0005432817784	26	89	31F
0005432262393	26	90	31E
0005432920079	8089	1	1A
0005433102699	8089	2	1C
0005433102712	8089	3	1D
0005432920081	8089	4	2A
0005432753336	8089	5	1F
0005432020533	8089	6	2D
0005432020541	8089	7	3D
0005433102688	8089	8	3C
0005432751561	8089	9	3A
0005432753334	8089	10	4A
0005433102675	8089	11	3F
0005432920069	8089	12	4F
0005433102672	8089	13	5A
0005432753337	8089	14	5D
0005433102692	8089	15	5C
0005432920082	8089	16	6A
0005432045633	8089	17	6C
0005433102683	8089	18	7A
0005433102704	8089	19	7C
0005433102719	8089	20	7F
0005433102693	8089	21	8C
0005432020525	8089	22	8E
0005433102674	8089	23	9A
0005433102679	8089	24	8F
0005433102697	8089	25	9B
0005432920064	8089	26	9C
0005432753335	8089	27	9F
0005433102716	8089	28	9E
0005433102677	8089	29	10A
0005432044554	8089	30	10D
0005432751562	8089	31	10C
0005432020546	8089	32	10F
0005433102695	8089	33	11B
0005433102701	8089	34	11A
0005432920060	8089	35	11C
0005433102706	8089	36	11F
0005433102696	8089	37	12A
0005432020524	8089	38	12C
0005432044552	8089	39	12D
0005432920071	8089	40	12E
0005433102682	8089	41	13C
0005432020526	8089	42	13E
0005432920078	8089	43	13D
0005432920062	8089	44	14A
0005432920074	8089	45	13F
0005432920065	8089	46	14C
0005433102700	8089	47	14D
0005432392030	8089	48	14E
0005432020531	8089	49	14F
0005432920077	8089	50	15C
0005433102703	8089	51	15F
0005433102708	8089	52	15E
0005432020521	8089	53	16A
0005432020523	8089	54	16C
0005432020527	8089	55	16E
0005433102689	8089	56	16F
0005433102686	8089	57	17B
0005432751560	8089	58	17D
0005433102710	8089	59	18A
0005432020545	8089	60	18C
0005432920061	8089	61	18D
0005433102714	8089	62	18F
0005432020535	8089	63	19C
0005432920075	8089	64	19B
0005432920067	8089	65	19D
0005432020529	8089	66	20A
0005433102673	8089	67	20B
0005432020538	8089	68	20C
0005433102705	8089	69	20D
0005432920066	8089	70	20F
0005432020544	8089	71	20E
0005433102691	8089	72	21B
0005433102694	8089	73	21C
0005432920070	8089	74	21E
0005432392031	8089	75	22A
0005432677615	8089	76	22B
0005432920080	8089	77	22E
0005433102709	8089	78	22F
0005432920068	8089	79	23A
0005432677614	8089	80	23D
0005433102685	8089	81	24A
0005432020542	8089	82	23F
0005432020540	8089	83	24B
0005433102680	8089	84	24D
0005432045634	8089	85	24C
0005433102718	8089	86	24E
0005433102684	8089	87	25B
0005432020528	8089	88	25A
0005432677613	8089	89	25C
0005432020537	8089	90	25E
0005432020547	8089	91	25F
0005433102687	8089	92	26A
0005433102707	8089	93	26C
0005433102717	8089	94	26D
0005432920063	8089	95	27A
0005432020522	8089	96	27C
0005432020539	8089	97	27B
0005432020543	8089	98	27D
0005432920072	8089	99	28A
0005433102698	8089	100	28D
0005433102690	8089	101	28C
0005432020530	8089	102	28E
0005432392029	8089	103	29B
0005433102713	8089	104	29A
0005433102702	8089	105	29C
0005433102671	8089	106	29D
0005432044553	8089	107	29E
0005432920059	8089	108	30A
0005433102681	8089	109	29F
0005432020534	8089	110	30B
0005432020536	8089	111	30C
0005432920076	8089	112	30E
0005433102715	8089	113	30D
0005433102676	8089	114	30F
0005432677616	8089	115	31B
0005433102711	8089	116	31A
0005432020532	8089	117	31D
0005433102678	8089	118	31F
0005432920073	8089	119	31E
0005432817516	8090	1	2F
0005432901779	8090	2	4D
0005432817517	8090	3	4F
0005432817531	8090	4	7D
0005432901792	8090	5	7C
0005432817402	8090	6	7F
0005432901788	8090	7	8B
0005432817467	8090	8	8F
0005432817403	8090	9	9E
0005432817622	8090	10	10E
0005432901796	8090	11	10F
0005432901793	8090	12	11F
0005432901787	8090	13	12D
0005432817432	8090	14	12E
0005432901785	8090	15	13A
0005432817491	8090	16	13E
0005432817588	8090	17	14A
0005432817439	8090	18	14B
0005432002098	8090	19	14C
0005432901791	8090	20	15A
0005432901789	8090	21	15F
0005432901783	8090	22	16D
0005432817635	8090	23	17D
0005432901784	8090	24	18A
0005432901780	8090	25	17F
0005432817532	8090	26	18E
0005432817533	8090	27	19C
0005432817616	8090	28	20B
0005432817530	8090	29	20A
0005432817542	8090	30	21C
0005432901781	8090	31	21D
0005432817518	8090	32	21E
0005432817615	8090	33	22C
0005432901790	8090	34	22F
0005432901794	8090	35	24A
0005432817444	8090	36	24C
0005432817539	8090	37	24F
0005432817554	8090	38	26A
0005432817489	8090	39	26D
0005432901782	8090	40	26F
0005432817473	8090	41	27B
0005432002099	8090	42	27A
0005432817438	8090	43	28A
0005432901786	8090	44	28B
0005432901795	8090	45	28D
0005432002097	8090	46	28E
0005432817433	8090	47	28F
0005432002096	8090	48	29C
0005432901797	8090	49	29B
0005432817472	8090	50	29E
0005432817445	8090	51	30A
0005432817462	8090	52	30D
0005432817536	8090	53	31A
0005432817529	8090	54	31C
0005432817535	8090	55	31D
0005434175762	9683	1	1A
0005434175748	9683	2	1B
0005434175754	9683	3	2B
0005434175765	9683	4	2A
0005434175755	9683	5	3A
0005434175749	9683	6	3B
0005433870754	9683	7	4A
0005433870752	9683	8	4B
0005434175761	9683	9	5B
0005433870753	9683	10	6B
0005434175797	32367	1	1B
0005434175795	32367	2	4B
0005433870731	32367	3	5A
0005434175796	32367	4	6A
0005434175794	32367	5	6B
0005435902687	3492	1	1A
0005434426915	3492	2	1G
0005435626372	3492	3	2C
0005434879243	3492	4	2H
0005434879225	3492	5	2G
0005434879232	3492	6	3A
0005434879176	3492	7	2K
0005434879155	3492	8	3G
0005434426911	3492	9	3D
0005434879191	3492	10	3K
0005435902773	3492	11	3H
0005434879186	3492	12	4C
0005434879203	3492	13	4A
0005435902678	3492	14	4G
0005435126800	3492	15	4D
0005434938352	3492	16	4K
0005434879196	3492	17	4H
0005434879185	3492	18	5A
0005435626373	3492	19	5K
0005434426912	3492	20	11E
0005434879194	3492	21	11D
0005435126777	3492	22	11C
0005434879198	3492	23	11F
0005434879189	3492	24	11K
0005434879179	3492	25	11H
0005435902697	3492	26	12D
0005434426918	3492	27	12G
0005434938345	3492	28	12F
0005432188642	3492	29	13A
0005434426927	3492	30	12H
0005434426900	3492	31	13D
0005435902750	3492	32	13F
0005434426919	3492	33	13H
0005434426903	3492	34	13G
0005434938344	3492	35	14C
0005434879234	3492	36	14A
0005435902764	3492	37	13K
0005435126802	3492	38	14E
0005435841094	3492	39	14D
0005434879215	3492	40	14K
0005432799739	3492	41	14G
0005435126775	3492	42	15A
0005434879226	3492	43	15F
0005434938349	3492	44	15E
0005434879224	3492	45	15D
0005434938341	3492	46	15K
0005432799748	3492	47	15H
0005434879181	3492	48	16D
0005432799736	3492	49	16A
0005434879207	3492	50	16F
0005434426926	3492	51	16E
0005434879240	3492	52	16H
0005434938342	3492	53	17A
0005434879246	3492	54	16K
0005434426920	3492	55	17D
0005435626383	3492	56	17C
0005435626376	3492	57	17G
0005434879228	3492	58	17F
0005435841824	3492	59	17H
0005434879167	3492	60	18A
0005434426910	3492	61	18F
0005434938336	3492	62	18J
0005435126788	3492	63	18H
0005434879164	3492	64	19B
0005434879213	3492	65	19A
0005435626384	3492	66	19D
0005434426906	3492	67	19F
0005434879223	3492	68	19G
0005432183489	3492	69	19K
0005435913932	3492	70	20C
0005435913933	3492	71	20B
0005435126803	3492	72	20A
0005432188641	3492	73	20F
0005434879217	3492	74	20E
0005434879204	3492	75	20D
0005435126809	3492	76	20G
0005434426922	3492	77	20J
0005434879163	3492	78	21B
0005435126793	3492	79	21D
0005434879192	3492	80	21F
0005435126807	3492	81	21E
0005434426909	3492	82	21J
0005434426928	3492	83	21G
0005435126781	3492	84	22A
0005435126771	3492	85	21K
0005434879160	3492	86	22D
0005434879247	3492	87	22C
0005435626377	3492	88	22E
0005432799751	3492	89	22G
0005434879212	3492	90	22F
0005435126785	3492	91	22K
0005435126799	3492	92	23B
0005435126790	3492	93	23A
0005435126794	3492	94	23D
0005434879237	3492	95	23C
0005434938334	3492	96	23F
0005435126797	3492	97	23E
0005435626371	3492	98	23J
0005432799747	3492	99	23G
0005434879236	3492	100	24D
0005432799741	3492	101	23K
0005434879244	3492	102	24F
0005435126783	3492	103	25B
0005432799744	3492	104	25A
0005434938351	3492	105	24G
0005434879211	3492	106	25D
0005434879242	3492	107	25C
0005432799761	3492	108	25F
0005434426923	3492	109	25G
0005434879208	3492	110	26A
0005434879209	3492	111	25K
0005432183490	3492	112	25J
0005432799758	3492	113	26B
0005435126805	3492	114	26D
0005434426908	3492	115	26G
0005434879187	3492	116	26F
0005434879177	3492	117	26J
0005434879233	3492	118	26H
0005432613905	3492	119	27A
0005435126786	3492	120	26K
0005434879168	3492	121	27F
0005435126801	3492	122	27E
0005435902701	3492	123	27D
0005434879210	3492	124	27H
0005435626382	3492	125	27G
0005435902652	3492	126	28A
0005435902686	3492	127	27K
0005434879222	3492	128	27J
0005435126789	3492	129	28C
0005434879159	3492	130	28E
0005434938348	3492	131	28F
0005434938340	3492	132	28J
0005434938346	3492	133	28H
0005434879173	3492	134	29A
0005434879174	3492	135	28K
0005434879190	3492	136	29D
0005434879172	3492	137	29C
0005434879175	3492	138	29B
0005432799762	3492	139	29H
0005434879154	3492	140	29G
0005435126811	3492	141	29K
0005434426924	3492	142	30C
0005434879206	3492	143	30B
0005434879200	3492	144	30A
0005434879161	3492	145	30E
0005435902748	3492	146	30G
0005434426904	3492	147	30K
0005432799755	3492	148	30J
0005434879219	3492	149	30H
0005435126808	3492	150	31B
0005434879221	3492	151	31A
0005434938335	3492	152	31D
0005434879245	3492	153	31F
0005435626380	3492	154	31H
0005435841823	3492	155	31G
0005432799734	3492	156	32A
0005434879230	3492	157	32C
0005432799743	3492	158	32G
0005432613903	3492	159	32K
0005434426902	3492	160	32H
0005432799745	3492	161	33B
0005435913931	3492	162	33A
0005434879238	3492	163	33D
0005434879241	3492	164	33F
0005434426907	3492	165	33H
0005432799757	3492	166	33G
0005432799760	3492	167	34A
0005432799749	3492	168	33K
0005432799752	3492	169	33J
0005434879171	3492	170	34B
0005435626381	3492	171	34E
0005432799754	3492	172	34K
0005434879227	3492	173	34J
0005432799735	3492	174	35D
0005432799738	3492	175	35B
0005434426916	3492	176	36A
0005435126791	3492	177	35K
0005434879216	3492	178	35J
0005432188643	3492	179	36B
0005432799746	3492	180	36E
0005434426925	3492	181	36H
0005434879170	3492	182	36K
0005434879197	3492	183	36J
0005432799737	3492	184	37B
0005434879239	3492	185	37A
0005435626379	3492	186	37D
0005435126806	3492	187	37C
0005435126782	3492	188	37G
0005435913937	3492	189	37F
0005435126795	3492	190	37J
0005435626375	3492	191	37K
0005434426914	3492	192	38C
0005432799742	3492	193	38K
0005434879182	3492	194	38J
0005432799750	3492	195	38H
0005434938337	3492	196	39A
0005435126774	3492	197	39C
0005434879229	3492	198	39E
0005434879165	3492	199	39G
0005435126779	3492	200	40A
0005435126773	3492	201	40E
0005434938339	3492	202	40D
0005435126776	3492	203	40K
0005432799753	3492	204	40H
0005432188640	3492	205	41A
0005434879220	3492	206	41D
0005435902779	3492	207	41F
0005432799759	3492	208	41E
0005434426901	3492	209	41J
0005434879248	3492	210	41H
0005435126792	3492	211	42A
0005434879193	3492	212	41K
0005435126804	3492	213	42C
0005434426913	3492	214	42F
0005432611751	3492	215	42J
0005434938347	3492	216	42H
0005435126772	3492	217	43D
0005434879162	3492	218	43J
0005432799756	3492	219	43G
0005435626374	3492	220	44A
0005434879183	3492	221	44C
0005435126778	3492	222	44H
0005434879156	3492	223	44G
0005434879188	3492	224	44K
0005434879202	3492	225	44J
0005434879157	3492	226	45B
0005434879178	3492	227	45C
0005432799740	3492	228	45F
0005435126812	3492	229	45H
0005435126780	3492	230	45G
0005434879180	3492	231	45J
0005434879205	3492	232	46A
0005434426905	3492	233	46E
0005434938350	3492	234	46D
0005434879158	3492	235	46H
0005432183488	3492	236	46G
0005435902798	3492	237	46F
0005434879184	3492	238	46J
0005434879199	3492	239	47A
0005434879235	3492	240	47E
0005434879214	3492	241	47D
0005434879169	3492	242	47G
0005435126784	3492	243	47F
0005434879231	3492	244	47K
0005435841825	3492	245	47H
0005434426921	3492	246	48D
0005432613904	3492	247	48F
0005434879153	3492	248	48E
0005434879201	3492	249	48H
0005434879166	3492	250	48G
0005435902680	3492	251	49A
0005434938343	3492	252	48K
0005435902679	3492	253	49D
0005435126798	3492	254	49K
0005434426917	3492	255	49G
0005434938338	3492	256	50C
0005434938333	3492	257	50A
0005435902726	3492	258	50E
0005435126796	3492	259	50D
0005434879195	3492	260	50G
0005434879218	3492	261	50F
0005435902653	3492	262	50H
0005435626378	3492	263	51E
0005435126787	3492	264	51D
0005435902797	3492	265	51G
0005435126810	3492	266	51F
0005434426757	14535	1	1C
0005434938276	14535	2	1K
0005434878385	14535	3	2C
0005435902887	14535	4	2G
0005432799448	14535	5	3A
0005434878686	14535	6	3C
0005432799515	14535	7	3K
0005434878649	14535	8	3H
0005434878573	14535	9	4C
0005435126527	14535	10	4A
0005434878312	14535	11	4G
0005434878386	14535	12	4K
0005435126270	14535	13	4H
0005434938249	14535	14	5C
0005434878195	14535	15	5A
0005434878372	14535	16	5H
0005434426574	14535	17	5D
0005434878554	14535	18	11A
0005432059525	14535	19	5K
0005435626187	14535	20	11D
0005435626147	14535	21	11F
0005434878121	14535	22	11K
0005434877913	14535	23	11G
0005435913962	14535	24	12C
0005434878460	14535	25	12E
0005434878690	14535	26	12F
0005432799451	14535	27	13A
0005432799493	14535	28	12H
0005435126332	14535	29	13D
0005434878476	14535	30	13F
0005435126336	14535	31	13E
0005435626214	14535	32	13G
0005435902884	14535	33	14C
0005435626155	14535	34	14A
0005435626144	14535	35	13K
0005435626126	14535	36	14F
0005434426596	14535	37	14K
0005434878345	14535	38	14H
0005435126489	14535	39	14G
0005435126364	14535	40	15D
0005435126441	14535	41	15C
0005434877828	14535	42	15A
0005435913963	14535	43	15F
0005434878029	14535	44	15E
0005434426668	14535	45	16A
0005434878811	14535	46	15K
0005435902894	14535	47	15H
0005435126472	14535	48	16D
0005434938264	14535	49	16E
0005432799417	14535	50	16H
0005435902878	14535	51	16G
0005434878405	14535	52	16K
0005432799450	14535	53	17E
0005434426629	14535	54	17D
0005435626181	14535	55	18A
0005434426667	14535	56	17K
0005434878237	14535	57	18D
0005434878860	14535	58	18G
0005434878298	14535	59	18F
0005434878501	14535	60	18H
0005434426628	14535	61	19B
0005434878859	14535	62	19A
0005435126451	14535	63	19D
0005434878153	14535	64	19F
0005434878596	14535	65	19E
0005435126529	14535	66	19J
0005434878474	14535	67	20B
0005435902893	14535	68	20E
0005435902888	14535	69	20D
0005434878360	14535	70	20F
0005434878597	14535	71	20J
0005435626150	14535	72	21B
0005434938214	14535	73	21D
0005434938197	14535	74	21C
0005434878422	14535	75	21F
0005434878184	14535	76	21E
0005432607577	14535	77	21J
0005434426673	14535	78	21H
0005435626196	14535	79	21K
0005435126448	14535	80	22C
0005434938205	14535	81	22B
0005434878247	14535	82	22E
0005434878367	14535	83	22G
0005434878542	14535	84	22F
0005435626086	14535	85	22J
0005432799484	14535	86	23B
0005434426726	14535	87	23A
0005435126449	14535	88	22K
0005434878502	14535	89	23E
0005434878423	14535	90	23D
0005434938116	14535	91	23C
0005434426718	14535	92	23F
0005435126471	14535	93	23H
0005435126432	14535	94	23K
0005434878289	14535	95	23J
0005434878097	14535	96	24F
0005434878561	14535	97	24E
0005434877943	14535	98	25B
0005434878668	14535	99	24G
0005434878313	14535	100	25D
0005435902883	14535	101	25F
0005434878695	14535	102	25E
0005434878419	14535	103	25H
0005434938189	14535	104	25G
0005435126528	14535	105	25K
0005434878355	14535	106	25J
0005435902892	14535	107	26B
0005432059524	14535	108	26A
0005434878344	14535	109	26H
0005434426763	14535	110	26G
0005435126359	14535	111	26F
0005434878640	14535	112	26K
0005432799509	14535	113	26J
0005434877829	14535	114	27A
0005435126358	14535	115	27D
0005432799585	14535	116	27F
0005434878555	14535	117	27E
0005434426728	14535	118	27J
0005435126433	14535	119	27H
0005435126331	14535	120	27G
0005434878732	14535	121	27K
0005434878861	14535	122	28A
0005435126470	14535	123	28G
0005434878246	14535	124	28F
0005435626156	14535	125	28E
0005435626159	14535	126	28H
0005434426680	14535	127	29D
0005434426641	14535	128	29C
0005435126428	14535	129	29E
0005435842336	14535	130	29J
0005432799547	14535	131	29G
0005435902880	14535	132	30A
0005432799586	14535	133	29K
0005434878625	14535	134	30B
0005432799483	14535	135	30E
0005434878104	14535	136	30D
0005434878504	14535	137	30C
0005435626208	14535	138	30G
0005432799479	14535	139	30F
0005435126363	14535	140	30J
0005434878667	14535	141	30H
0005434426549	14535	142	31B
0005432799416	14535	143	31D
0005434878113	14535	144	31C
0005435126354	14535	145	31F
0005434878063	14535	146	31H
0005435902877	14535	147	31G
0005434938156	14535	148	32C
0005434878028	14535	149	32B
0005434938048	14535	150	32E
0005434938237	14535	151	32D
0005434878506	14535	152	32G
0005434878560	14535	153	32F
0005434938175	14535	154	33B
0005435126478	14535	155	33A
0005435126380	14535	156	33D
0005434878359	14535	157	33C
0005434938251	14535	158	33J
0005434878030	14535	159	33H
0005434878572	14535	160	34A
0005435626213	14535	161	33K
0005435626084	14535	162	34B
0005434878411	14535	163	34E
0005435126337	14535	164	34F
0005434426657	14535	165	34H
0005434426717	14535	166	35B
0005435126445	14535	167	35A
0005434878529	14535	168	34K
0005434878446	14535	169	35D
0005434878447	14535	170	35C
0005434938099	14535	171	35F
0005434426669	14535	172	35E
0005432799474	14535	173	35H
0005435126408	14535	174	36A
0005434878119	14535	175	36F
0005435842335	14535	176	36E
0005435626161	14535	177	36K
0005435914702	14535	178	36J
0005435126410	14535	179	37B
0005435841829	14535	180	37D
0005435126446	14535	181	37C
0005435902889	14535	182	37F
0005434878292	14535	183	37E
0005435626178	14535	184	37J
0005434878470	14535	185	37H
0005434878503	14535	186	37G
0005434878462	14535	187	37K
0005434938206	14535	188	38B
0005434878505	14535	189	38J
0005434426681	14535	190	38H
0005435126515	14535	191	39B
0005435902890	14535	192	39A
0005435626199	14535	193	39D
0005432799485	14535	194	39E
0005435126392	14535	195	39J
0005432799587	14535	196	40A
0005434878463	14535	197	40E
0005432799482	14535	198	40D
0005435626186	14535	199	40H
0005432799422	14535	200	40G
0005434938155	14535	201	40F
0005434938157	14535	202	40J
0005434938049	14535	203	40K
0005434878466	14535	204	41D
0005435902882	14535	205	41B
0005434878648	14535	206	41G
0005435126295	14535	207	41F
0005434878810	14535	208	41H
0005434878062	14535	209	42A
0005434426637	14535	210	41K
0005435126388	14535	211	42E
0005432607574	14535	212	42D
0005435126389	14535	213	42G
0005434938202	14535	214	42F
0005434878498	14535	215	42J
0005435913964	14535	216	42H
0005435626127	14535	217	43B
0005432799573	14535	218	43A
0005434426756	14535	219	42K
0005434878356	14535	220	43D
0005434878559	14535	221	43C
0005435126427	14535	222	43F
0005434878105	14535	223	43E
0005435126547	14535	224	43H
0005432799546	14535	225	43G
0005435126450	14535	226	43K
0005434878185	14535	227	44C
0005432611716	14535	228	44B
0005432799508	14535	229	44D
0005434426670	14535	230	44F
0005435626197	14535	231	44K
0005434426640	14535	232	44J
0005434878588	14535	233	44H
0005432799444	14535	234	45B
0005435902885	14535	235	45A
0005434878412	14535	236	45D
0005434878557	14535	237	45C
0005434938098	14535	238	45F
0005435902891	14535	239	45H
0005434878569	14535	240	45G
0005435126488	14535	241	46A
0005434878451	14535	242	45K
0005434878120	14535	243	46B
0005435126303	14535	244	46D
0005435126409	14535	245	46G
0005435914703	14535	246	46F
0005432799580	14535	247	46J
0005435902881	14535	248	47A
0005434878454	14535	249	47K
0005434938190	14535	250	48D
0005435126481	14535	251	48A
0005432799534	14535	252	48F
0005434878229	14535	253	48E
0005434878488	14535	254	48H
0005435902886	14535	255	48G
0005432799535	14535	256	49A
0005434878409	14535	257	48K
0005434938236	14535	258	49C
0005434426597	14535	259	49F
0005435626180	14535	260	49K
0005434877914	14535	261	49H
0005435902879	14535	262	50C
0005434938196	14535	263	50A
0005432799581	14535	264	50E
0005434878631	14535	265	50D
0005432799480	14535	266	51D
0005435126271	14535	267	51G
0005434325769	3609	1	1A
0005435889881	3609	2	1B
0005434325766	3609	3	1D
0005434325770	3609	4	2B
0005435889912	3609	5	3A
0005435889875	3609	6	4B
0005434325768	3609	7	4C
0005435889911	3609	8	4D
0005435889902	3609	9	5B
0005435889901	3609	10	6C
0005434325767	3609	11	7A
0005434325772	3609	12	7B
0005435889899	3609	13	7C
0005434312340	3609	14	7D
0005435889895	3609	15	18D
0005435889874	3609	16	19A
0005434325765	3609	17	21A
0005434325773	3609	18	21B
0005434325771	3609	19	22B
0005434325764	3609	20	22D
0005434325763	3609	21	23A
0005434325686	15618	1	1D
0005434325683	15618	2	3A
0005434325668	15618	3	3B
0005435889960	15618	4	5A
0005434325682	15618	5	5B
0005434325612	15618	6	5C
0005435889961	15618	7	6D
0005435889958	15618	8	7D
0005435889956	15618	9	19A
0005435889957	15618	10	19B
0005434325710	15618	11	19D
0005435889959	15618	12	20A
0005434325674	15618	13	21A
0005435889962	15618	14	21B
0005434325685	15618	15	22C
0005433420434	622	1	1A
0005433420411	622	2	1B
0005435957855	622	3	2D
0005435957854	622	4	3B
0005435957857	622	5	3C
0005435957858	622	6	4A
0005433420409	622	7	4C
0005433420410	622	8	4D
0005433420433	622	9	5A
0005433420407	622	10	5C
0005435957849	622	11	5D
0005433420412	622	12	7A
0005433420432	622	13	19A
0005435957856	622	14	20A
0005435957848	622	15	20B
0005433420408	622	16	20D
0005435957852	622	17	21A
0005435957859	622	18	21D
0005435957853	622	19	22A
0005435957850	622	20	22B
0005435957851	622	21	22C
0005433420414	622	22	23A
0005435957860	622	23	23B
0005435957749	15163	1	1A
0005433420486	15163	2	1B
0005435957769	15163	3	1C
0005435957756	15163	4	2A
0005435957683	15163	5	2B
0005435957686	15163	6	2D
0005433420490	15163	7	3B
0005435957727	15163	8	3D
0005435957774	15163	9	4B
0005435957697	15163	10	4C
0005435957721	15163	11	5B
0005435957689	15163	12	5C
0005435957729	15163	13	6A
0005435957730	15163	14	6D
0005435957690	15163	15	7B
0005433420488	15163	16	7C
0005435957770	15163	17	7D
0005433420487	15163	18	18A
0005433420485	15163	19	19C
0005435957650	15163	20	19D
0005435957785	15163	21	20A
0005433420493	15163	22	20B
0005433420491	15163	23	20C
0005433420492	15163	24	20D
0005435957687	15163	25	21A
0005435957755	15163	26	21B
0005435957768	15163	27	21C
0005435957657	15163	28	21D
0005435957685	15163	29	22B
0005435957728	15163	30	22C
0005433420489	15163	31	23B
0005434247145	8846	1	1A
0005434247151	8846	2	2B
0005434247157	8846	3	2A
0005434247158	8846	4	5A
0005434247147	8846	5	6B
0005434247174	16061	1	3A
0005434247175	16061	2	5B
0005434247173	16061	3	6B
0005434096745	11826	1	2D
0005434096739	11826	2	5B
0005434096746	11826	3	5D
0005434096736	11826	4	7A
0005434096729	11826	5	20A
0005434096742	11826	6	20B
0005434096738	11826	7	22C
0005434096762	20172	1	1D
0005434096758	20172	2	3A
0005434096759	20172	3	5A
0005434096763	20172	4	5C
0005434096760	20172	5	6D
0005434096761	20172	6	19D
0005434096764	20172	7	20C
0005432645945	25116	1	1C
0005435229499	25116	2	1F
0005432645970	25116	3	2C
0005432645977	25116	4	3A
0005432646030	25116	5	3F
0005432645965	25116	6	4A
0005432645966	25116	7	4C
0005432645981	25116	8	4D
0005435229492	25116	9	4E
0005435229498	25116	10	4F
0005432645972	25116	11	5C
0005432646001	25116	12	5E
0005435229489	25116	13	6C
0005432646015	25116	14	6D
0005432646031	25116	15	6E
0005432645969	25116	16	6F
0005435229487	25116	17	7E
0005435229503	25116	18	8A
0005435229491	25116	19	8C
0005435229501	25116	20	8E
0005435229494	25116	21	9D
0005432645951	25116	22	9F
0005435229505	25116	23	10A
0005432645976	25116	24	10C
0005435229500	25116	25	10D
0005435229507	25116	26	10E
0005435229496	25116	27	10F
0005435229495	25116	28	11A
0005435229488	25116	29	11E
0005432645975	25116	30	11F
0005432645974	25116	31	12D
0005432645992	25116	32	12E
0005432645980	25116	33	12F
0005435229502	25116	34	13C
0005435229506	25116	35	13F
0005432645946	25116	36	14A
0005432645971	25116	37	14D
0005432645993	25116	38	14E
0005432645912	25116	39	14F
0005432646016	25116	40	15C
0005432645963	25116	41	15D
0005432645962	25116	42	16D
0005432645986	25116	43	16E
0005432646017	25116	44	16F
0005435229508	25116	45	17F
0005435229504	25116	46	18A
0005432645952	25116	47	18C
0005435229490	25116	48	18E
0005435229497	25116	49	19F
0005432645973	25116	50	20D
0005435229493	25116	51	20E
0005432645978	25116	52	20F
0005435797619	2856	1	1A
0005435797617	2856	2	1C
0005433404810	2856	3	1F
0005433404833	2856	4	2F
0005433404815	2856	5	3C
0005435797621	2856	6	3F
0005433404808	2856	7	4E
0005433404811	2856	8	4F
0005435797624	2856	9	5F
0005433404794	2856	10	6A
0005435797626	2856	11	6E
0005435797616	2856	12	6F
0005433404797	2856	13	7C
0005433404809	2856	14	8C
0005435797622	2856	15	8D
0005435797623	2856	16	11E
0005435797614	2856	17	12A
0005435797620	2856	18	12C
0005433404842	2856	19	12F
0005435797618	2856	20	13A
0005433404793	2856	21	14A
0005435797613	2856	22	14C
0005433404812	2856	23	15E
0005435797625	2856	24	16D
0005433404834	2856	25	17E
0005435797615	2856	26	18E
0005433404889	29351	1	1C
0005435797472	29351	2	3A
0005435797516	29351	3	3C
0005435797456	29351	4	3F
0005433404884	29351	5	6C
0005435797530	29351	6	7D
0005435797490	29351	7	7E
0005435797473	29351	8	7F
0005433404887	29351	9	8D
0005435797491	29351	10	9E
0005433404885	29351	11	10A
0005435797547	29351	12	11A
0005435797455	29351	13	11E
0005433404886	29351	14	12D
0005435797546	29351	15	14E
0005433404883	29351	16	16C
0005433404888	29351	17	19C
0005435797568	29351	18	20C
0005435797492	29351	19	20E
0005435376363	5784	1	1B
0005435376365	5784	2	3A
0005434948103	5783	1	1A
0005434948105	5783	2	1B
0005434948108	5783	3	2B
0005434948107	5783	4	2A
0005434948106	5783	5	3B
0005434948102	5783	6	4B
0005434948109	5783	7	6A
0005434948104	5783	8	5B
0005435376372	16318	1	1A
0005434948050	16318	2	1B
0005435376374	16318	3	2A
0005434948053	16318	4	3A
0005434948029	16318	5	2B
0005435376371	16318	6	4A
0005435376373	16318	7	3B
0005434948048	16318	8	4B
0005434948098	16318	9	5A
0005435376369	16318	10	5B
0005434948040	16318	11	6A
0005435376370	16318	12	6B
0005433961462	6858	1	1A
0005433961441	6858	2	1D
0005433961450	6858	3	2A
0005433961429	6858	4	2D
0005433961467	6858	5	2F
0005433961446	6858	6	3D
0005433961456	6858	7	4A
0005433961469	6858	8	4C
0005433961466	6858	9	4F
0005433961430	6858	10	5A
0005433961463	6858	11	5C
0005433961447	6858	12	5D
0005433961474	6858	13	5E
0005433961481	6858	14	5F
0005433961477	6858	15	6A
0005433961475	6858	16	6C
0005433961448	6858	17	6D
0005433961432	6858	18	6E
0005433961431	6858	19	7A
0005433961480	6858	20	7C
0005433961473	6858	21	7D
0005433961459	6858	22	7E
0005433961442	6858	23	8D
0005433961437	6858	24	8E
0005433961453	6858	25	8F
0005433961444	6858	26	9D
0005433961479	6858	27	9F
0005433961460	6858	28	10A
0005433961478	6858	29	10C
0005433961468	6858	30	10F
0005433961445	6858	31	11A
0005433961486	6858	32	11C
0005433961455	6858	33	11E
0005433961434	6858	34	11F
0005433961471	6858	35	12A
0005433961443	6858	36	12C
0005433961483	6858	37	12D
0005433961454	6858	38	12E
0005433961465	6858	39	12F
0005433961440	6858	40	13D
0005433961482	6858	41	13F
0005433961451	6858	42	14A
0005433961433	6858	43	14C
0005433961452	6858	44	14D
0005433961461	6858	45	14E
0005433961439	6858	46	14F
0005433961436	6858	47	15D
0005433961470	6858	48	15F
0005433961438	6858	49	16C
0005433961457	6858	50	16D
0005433961472	6858	51	16F
0005433961484	6858	52	17E
0005433961458	6858	53	17F
0005433961435	6858	54	19A
0005433961485	6858	55	19C
0005433961464	6858	56	19D
0005433961449	6858	57	19E
0005433961476	6858	58	20D
0005433960807	25698	1	1A
0005433960771	25698	2	1D
0005433960756	25698	3	1F
0005433960682	25698	4	2C
0005433960835	25698	5	2D
0005433960810	25698	6	3D
0005433960809	25698	7	3F
0005433960803	25698	8	4A
0005433960757	25698	9	4E
0005433960721	25698	10	4F
0005433960772	25698	11	5A
0005433960746	25698	12	5D
0005433960530	25698	13	5F
0005433960783	25698	14	6A
0005433960792	25698	15	6C
0005433960720	25698	16	6D
0005433960777	25698	17	6E
0005433960739	25698	18	7A
0005433960824	25698	19	7C
0005433960794	25698	20	7D
0005433960759	25698	21	7E
0005433960671	25698	22	7F
0005433960776	25698	23	8A
0005433960710	25698	24	8D
0005433960800	25698	25	8F
0005433960775	25698	26	9A
0005433960804	25698	27	9E
0005433960821	25698	28	10A
0005433960799	25698	29	10C
0005433960631	25698	30	10D
0005433960842	25698	31	11A
0005433960802	25698	32	11D
0005433960749	25698	33	11C
0005433960670	25698	34	11E
0005433960632	25698	35	11F
0005433960741	25698	36	12C
0005433960833	25698	37	12D
0005433960846	25698	38	12F
0005433960724	25698	39	13C
0005433960396	25698	40	13F
0005433960811	25698	41	14A
0005433960740	25698	42	14C
0005433960770	25698	43	14F
0005433960843	25698	44	15A
0005433960732	25698	45	15F
0005433960734	25698	46	16A
0005433960737	25698	47	17A
0005433960806	25698	48	17C
0005433960531	25698	49	17D
0005433960778	25698	50	18A
0005433960755	25698	51	18C
0005433960848	25698	52	18D
0005433960767	25698	53	19D
0005433960768	25698	54	19E
0005433960719	25698	55	19F
0005433960733	25698	56	20C
0005433960752	25698	57	20E
0005433960742	25698	58	20F
0005435082784	24556	1	1A
0005435082779	24556	2	1B
0005435082786	24556	3	2A
0005435082788	24556	4	2B
0005435082812	24556	5	3A
0005435082799	24556	6	3B
0005435082781	24556	7	4A
0005435082778	24556	8	4B
0005435082801	24556	9	5A
0005435082793	24556	10	5B
0005435082811	24556	11	6A
0005435082800	24556	12	6B
0005435082857	26094	1	1B
0005435082858	26094	2	2B
0005435082860	26094	3	3B
0005435082859	26094	4	4B
0005435082862	26094	5	5B
0005435082863	26094	6	6A
0005435082861	26094	7	6B
0005435286634	5020	1	4F
0005434245277	5020	2	4D
0005434245287	5020	3	5C
0005432166933	5020	4	6C
0005434245285	5020	5	7A
0005434245275	5020	6	8A
0005434245294	5020	7	9F
0005434245269	5020	8	10B
0005434245270	5020	9	10D
0005434245279	5020	10	11E
0005435286629	5020	11	12B
0005434245273	5020	12	12E
0005434245280	5020	13	12D
0005434245292	5020	14	15A
0005434245276	5020	15	16D
0005434245282	5020	16	17E
0005435286630	5020	17	18D
0005434245295	5020	18	20F
0005434245271	5020	19	21E
0005435286628	5020	20	22A
0005432166937	5020	21	22B
0005434245268	5020	22	22D
0005434245286	5020	23	22F
0005434245296	5020	24	23A
0005434245293	5020	25	23B
0005432166936	5020	26	23F
0005434245278	5020	27	24B
0005434245272	5020	28	24C
0005432166935	5020	29	24D
0005433534501	5020	30	25A
0005432166934	5020	31	25E
0005434245284	5020	32	26A
0005433534503	5020	33	26F
0005434245290	5020	34	27F
0005434245267	5020	35	28E
0005434245281	5020	36	29A
0005434245288	5020	37	29B
0005434245274	5020	38	29F
0005434245291	5020	39	30B
0005434245283	5020	40	31D
0005434245289	5020	41	31F
0005433615423	5021	1	15A
0005433785333	5021	2	1A
0005433615446	5021	3	1D
0005432106046	5021	4	1C
0005432106056	5021	5	2A
0005432666410	5021	6	2C
0005432106055	5021	7	2D
0005433615464	5021	8	3A
0005433615425	5021	9	2F
0005432106047	5021	10	3C
0005433615420	5021	11	3D
0005433615457	5021	12	4A
0005433615481	5021	13	3F
0005433615463	5021	14	4C
0005432106048	5021	15	4F
0005433615459	5021	16	4D
0005433615424	5021	17	5A
0005433615442	5021	18	5D
0005433785324	5021	19	5C
0005432106054	5021	20	6A
0005433785309	5021	21	5F
0005433615407	5021	22	6C
0005433615436	5021	23	6F
0005432106074	5021	24	6D
0005432106066	5021	25	7A
0005432106035	5021	26	7C
0005432106052	5021	27	7F
0005432106051	5021	28	7D
0005433615429	5021	29	8A
0005432106038	5021	30	8B
0005432106057	5021	31	8C
0005433615466	5021	32	8E
0005433615417	5021	33	8D
0005433785331	5021	34	8F
0005433615410	5021	35	9B
0005433615456	5021	36	9A
0005432665296	5021	37	9C
0005432106037	5021	38	9D
0005433615478	5021	39	9E
0005433615458	5021	40	10A
0005433615421	5021	41	9F
0005433785332	5021	42	10B
0005433615460	5021	43	10D
0005432106059	5021	44	10C
0005433615409	5021	45	10E
0005432106075	5021	46	10F
0005433615451	5021	47	11A
0005433785312	5021	48	11C
0005433615476	5021	49	11B
0005433615430	5021	50	11D
0005432106078	5021	51	11F
0005433615437	5021	52	11E
0005433615434	5021	53	12A
0005433785323	5021	54	12B
0005432106081	5021	55	12D
0005433785307	5021	56	12C
0005432106073	5021	57	12E
0005433615439	5021	58	12F
0005433615408	5021	59	13A
0005432667475	5021	60	13C
0005432106041	5021	61	13B
0005433615413	5021	62	13D
0005432106040	5021	63	13E
0005433785326	5021	64	14A
0005432106060	5021	65	13F
0005432665297	5021	66	14C
0005433615469	5021	67	14B
0005433615438	5021	68	14D
0005433615477	5021	69	14E
0005433615472	5021	70	14F
0005432106034	5021	71	15B
0005433615475	5021	72	15C
0005432106062	5021	73	15D
0005432665295	5021	74	15E
0005432106063	5021	75	16A
0005433615479	5021	76	15F
0005433785334	5021	77	16B
0005433615448	5021	78	16D
0005432106072	5021	79	16C
0005433785310	5021	80	16E
0005432106082	5021	81	16F
0005432106069	5021	82	17B
0005432106039	5021	83	17C
0005433615441	5021	84	17D
0005433785321	5021	85	17F
0005432106064	5021	86	17E
0005433785303	5021	87	18A
0005433615449	5021	88	18B
0005433615447	5021	89	18D
0005433615428	5021	90	18C
0005433615470	5021	91	18E
0005432106077	5021	92	19B
0005433615440	5021	93	18F
0005432106068	5021	94	19C
0005433615455	5021	95	19E
0005433615467	5021	96	19D
0005432106049	5021	97	20A
0005433615427	5021	98	20B
0005433615454	5021	99	20C
0005433785328	5021	100	20E
0005433785316	5021	101	20D
0005433785301	5021	102	20F
0005433785300	5021	103	21B
0005432106036	5021	104	21A
0005433615474	5021	105	21C
0005433785329	5021	106	21D
0005433615471	5021	107	21E
0005433785305	5021	108	22A
0005433615462	5021	109	21F
0005433615461	5021	110	22B
0005432106065	5021	111	22C
0005433615411	5021	112	22E
0005432106076	5021	113	22D
0005433785318	5021	114	22F
0005433615435	5021	115	23A
0005433785298	5021	116	23C
0005432106044	5021	117	23B
0005433785335	5021	118	23D
0005433615445	5021	119	23E
0005433615450	5021	120	24A
0005433615465	5021	121	23F
0005433615412	5021	122	24B
0005433615431	5021	123	24C
0005433785327	5021	124	24D
0005433785322	5021	125	24F
0005433615415	5021	126	24E
0005433785299	5021	127	25A
0005433785306	5021	128	25B
0005433615426	5021	129	25D
0005433785311	5021	130	25C
0005433615418	5021	131	25F
0005433785325	5021	132	25E
0005433785319	5021	133	26A
0005433785302	5021	134	26B
0005432106042	5021	135	26C
0005433615419	5021	136	26D
0005432106067	5021	137	26F
0005433615414	5021	138	26E
0005432667474	5021	139	27A
0005433785320	5021	140	27C
0005433615480	5021	141	27B
0005433615473	5021	142	27D
0005433615416	5021	143	27E
0005433615468	5021	144	28A
0005432106058	5021	145	27F
0005433615433	5021	146	28B
0005432106045	5021	147	28D
0005432106043	5021	148	28C
0005433785330	5021	149	28E
0005433785314	5021	150	29A
0005432106071	5021	151	28F
0005433615452	5021	152	29B
0005433785313	5021	153	29C
0005433615444	5021	154	29D
0005433615443	5021	155	29E
0005432106079	5021	156	30A
0005433615432	5021	157	29F
0005432106061	5021	158	30B
0005433785304	5021	159	30C
0005433615453	5021	160	30E
0005433785317	5021	161	30D
0005433785315	5021	162	30F
0005433785308	5021	163	31A
0005432106050	5021	164	31C
0005433615422	5021	165	31B
0005432106070	5021	166	31E
0005432106053	5021	167	31D
0005432106080	5021	168	31F
0005434265413	5031	1	4D
0005433815376	5031	2	5A
0005434229597	5031	3	5D
0005434265398	5031	4	5C
0005434173560	5031	5	6D
0005434265409	5031	6	6F
0005434265397	5031	7	7A
0005434265399	5031	8	7C
0005435006996	5031	9	8A
0005434229605	5031	10	8B
0005434173563	5031	11	8D
0005434149854	5031	12	8C
0005434229595	5031	13	8E
0005434265410	5031	14	8F
0005434265412	5031	15	9A
0005434265405	5031	16	9C
0005434229609	5031	17	9B
0005432336019	5031	18	9D
0005435007000	5031	19	9E
0005435007023	5031	20	1D
0005434265393	5031	21	9F
0005432336075	5031	22	10B
0005434229593	5031	23	10C
0005434265408	5031	24	10E
0005434149847	5031	25	10D
0005434265407	5031	26	10F
0005434311220	5031	27	11C
0005434265392	5031	28	2F
0005434311219	5031	29	11B
0005434149845	5031	30	11D
0005435007057	5031	31	11F
0005434149855	5031	32	11E
0005434265400	5031	33	12B
0005435007115	5031	34	12C
0005434229599	5031	35	12E
0005434229612	5031	36	12D
0005434149848	5031	37	13B
0005435007092	5031	38	13A
0005432336061	5031	39	13C
0005434149851	5031	40	13E
0005434265411	5031	41	13D
0005434265390	5031	42	14A
0005434229600	5031	43	13F
0005434312311	5031	44	14C
0005434229602	5031	45	14E
0005435006997	5031	46	14F
0005434229594	5031	47	15C
0005432336059	5031	48	15B
0005434229611	5031	49	3A
0005435007081	5031	50	15D
0005434265404	5031	51	15F
0005435007064	5031	52	15E
0005435007058	5031	53	16B
0005435007056	5031	54	16C
0005433815404	5031	55	16F
0005435007006	5031	56	16E
0005432336078	5031	57	16D
0005435006998	5031	58	17B
0005435007007	5031	59	17F
0005434173562	5031	60	17E
0005432336085	5031	61	18A
0005432335973	5031	62	3D
0005434265406	5031	63	2A
0005434229592	5031	64	19B
0005434265394	5031	65	18F
0005433688818	5031	66	19C
0005433688810	5031	67	19E
0005434265403	5031	68	20B
0005435007044	5031	69	20C
0005434149852	5031	70	21B
0005435007129	5031	71	21A
0005434229591	5031	72	21C
0005434149849	5031	73	2D
0005432336041	5031	74	21E
0005434229596	5031	75	22A
0005434312331	5031	76	21F
0005434229603	5031	77	22D
0005435007053	5031	78	1C
0005435007149	5031	79	22E
0005434265389	5031	80	23C
0005434149856	5031	81	23D
0005432335975	5031	82	23E
0005434265401	5031	83	23F
0005435007112	5031	84	24B
0005433815377	5031	85	24C
0005434229608	5031	86	24D
0005434229610	5031	87	24F
0005434265395	5031	88	25A
0005434173561	5031	89	25B
0005434312332	5031	90	25D
0005435007024	5031	91	25C
0005434265415	5031	92	25E
0005434229598	5031	93	26A
0005434265414	5031	94	25F
0005434229601	5031	95	26D
0005434265396	5031	96	26C
0005435007093	5031	97	26F
0005434265402	5031	98	27B
0005434229607	5031	99	27A
0005434229606	5031	100	27F
0005435006999	5031	101	27E
0005432336042	5031	102	28A
0005435007063	5031	103	28C
0005432336079	5031	104	28E
0005435007128	5031	105	28F
0005435007150	5031	106	29B
0005435007148	5031	107	29A
0005434149846	5031	108	29C
0005432335957	5031	109	29F
0005435007001	5031	110	29E
0005435007082	5031	111	30A
0005432336069	5031	112	30B
0005434149853	5031	113	30C
0005435007083	5031	114	30E
0005432335974	5031	115	31A
0005434229604	5031	116	31D
0005434149850	5031	117	31E
0005434265391	5031	118	31F
0005435007054	5031	119	4F
0005434245044	8635	1	27A
0005434245092	8635	2	1C
0005434245049	8635	3	1F
0005434245125	8635	4	1D
0005433784989	8635	5	2A
0005432659708	8635	6	2F
0005433785085	8635	7	3A
0005433785075	8635	8	3C
0005434245048	8635	9	3D
0005435269813	8635	10	4A
0005433784962	8635	11	4C
0005433784980	8635	12	4D
0005434245011	8635	13	5A
0005435269818	8635	14	5F
0005434245127	8635	15	6C
0005433784997	8635	16	6F
0005434244965	8635	17	7A
0005433784831	8635	18	7C
0005434245012	8635	19	8A
0005433784950	8635	20	8D
0005435269822	8635	21	8E
0005434245095	8635	22	8F
0005433784837	8635	23	9E
0005432663028	8635	24	9F
0005433785108	8635	25	10E
0005435269814	8635	26	10F
0005434245123	8635	27	11F
0005434245104	8635	28	12D
0005435269816	8635	29	13A
0005434245128	8635	30	13B
0005433785008	8635	31	13F
0005435269817	8635	32	14C
0005433785024	8635	33	14D
0005433785105	8635	34	15B
0005434245113	8635	35	15C
0005432663027	8635	36	15E
0005433784941	8635	37	15F
0005433785028	8635	38	16A
0005434245081	8635	39	16B
0005432666381	8635	40	16D
0005433784988	8635	41	17C
0005432666394	8635	42	17E
0005433784838	8635	43	18C
0005434245037	8635	44	18E
0005435269821	8635	45	18D
0005433784995	8635	46	19C
0005435269820	8635	47	19E
0005433784872	8635	48	21B
0005434245036	8635	49	22B
0005434245000	8635	50	22F
0005432663029	8635	51	22E
0005433785140	8635	52	23A
0005433784963	8635	53	23C
0005433785056	8635	54	24A
0005433784942	8635	55	24B
0005434245112	8635	56	24E
0005433785123	8635	57	24F
0005433785150	8635	58	25A
0005434245129	8635	59	25E
0005432659701	8635	60	25F
0005434245111	8635	61	26D
0005433784964	8635	62	26F
0005434245020	8635	63	26E
0005433784874	8635	64	27C
0005434245124	8635	65	27D
0005433784873	8635	66	27F
0005434245001	8635	67	28A
0005433785106	8635	68	29A
0005432659707	8635	69	29C
0005435269815	8635	70	29D
0005433785064	8635	71	30A
0005434245085	8635	72	29F
0005435269823	8635	73	30B
0005435269819	8635	74	30C
0005433784972	8635	75	31A
0005434245052	8635	76	31B
0005434245091	8635	77	31F
0005433784979	8635	78	31E
0005433614940	8636	1	30A
0005433614901	8636	2	30C
0005433614701	8636	3	30B
0005433614685	8636	4	30D
0005433614527	8636	5	30F
0005433614661	8636	6	31C
0005433614869	8636	7	31E
0005433614519	8636	8	2F
0005433614893	8636	9	3F
0005433614703	8636	10	4D
0005433614464	8636	11	5C
0005433614545	8636	12	5F
0005433615030	8636	13	5D
0005433614707	8636	14	6C
0005433614866	8636	15	6F
0005433615107	8636	16	7D
0005433614672	8636	17	7F
0005433614657	8636	18	8B
0005433614684	8636	19	8F
0005433615012	8636	20	9B
0005433614671	8636	21	9E
0005433614536	8636	22	10A
0005433614797	8636	23	10C
0005433614926	8636	24	2A
0005433614660	8636	25	10F
0005433614966	8636	26	11B
0005433614718	8636	27	11C
0005433614554	8636	28	11D
0005433614725	8636	29	11F
0005433614799	8636	30	12B
0005433614622	8636	31	12E
0005433614675	8636	32	1C
0005433614967	8636	33	12F
0005433614971	8636	34	13B
0005433614698	8636	35	13C
0005433614959	8636	36	14A
0005433614555	8636	37	14C
0005433615014	8636	38	14B
0005433614670	8636	39	14E
0005433614809	8636	40	15C
0005433614702	8636	41	15E
0005433614864	8636	42	15F
0005433615101	8636	43	16F
0005433614788	8636	44	17A
0005433614945	8636	45	17C
0005433615013	8636	46	17E
0005433614561	8636	47	18A
0005433614986	8636	48	18C
0005433614803	8636	49	18B
0005433614902	8636	50	18D
0005433614925	8636	51	19E
0005433615031	8636	52	19D
0005433614872	8636	53	20B
0005433614717	8636	54	20A
0005433614514	8636	55	20E
0005433614951	8636	56	21A
0005433614924	8636	57	21D
0005433615024	8636	58	21C
0005433614550	8636	59	21E
0005433614996	8636	60	22A
0005433614756	8636	61	21F
0005433614461	8636	62	22B
0005433614704	8636	63	22D
0005433614798	8636	64	22C
0005433614535	8636	65	23A
0005433614640	8636	66	23C
0005433614518	8636	67	23E
0005433614846	8636	68	24C
0005433614674	8636	69	24E
0005433614513	8636	70	24F
0005433614373	8636	71	25A
0005433614845	8636	72	25D
0005433614534	8636	73	25E
0005433614757	8636	74	28A
0005433614789	8636	75	28B
0005433615029	8636	76	28D
0005433615059	8636	77	28C
0005433614943	8636	78	29A
0005433615111	8636	79	29C
0005433614706	8636	80	29D
0005433614865	8636	81	29E
0005434173536	8637	1	18B
0005434229383	8637	2	18D
0005434311241	8637	3	18C
0005435007262	8637	4	18E
0005432336156	8637	5	18F
0005435007265	8637	6	19C
0005434173540	8637	7	19B
0005434229426	8637	8	19D
0005435007273	8637	9	20A
0005432035236	8637	10	19E
0005434229403	8637	11	20C
0005434265135	8637	12	20B
0005432035234	8637	13	20E
0005435286671	8637	14	20D
0005432336158	8637	15	20F
0005434149759	8637	16	21C
0005434149726	8637	17	21B
0005434149713	8637	18	21D
0005434229385	8637	19	21E
0005432035223	8637	20	22A
0005435007260	8637	21	22D
0005432035226	8637	22	22F
0005432035235	8637	23	22E
0005434229434	8637	24	23A
0005432047591	8637	25	23D
0005434265181	8637	26	23C
0005435007254	8637	27	23E
0005432035238	8637	28	23F
0005432336157	8637	29	24B
0005434229435	8637	30	24A
0005435286675	8637	31	24C
0005432035221	8637	32	24E
0005432035228	8637	33	25A
0005434149801	8637	34	24F
0005434173537	8637	35	25B
0005434229356	8637	36	25D
0005434149749	8637	37	25C
0005432047588	8637	38	25F
0005433688833	8637	39	25E
0005432336153	8637	40	26A
0005432047589	8637	41	26B
0005432035222	8637	42	26D
0005435007276	8637	43	26C
0005434149720	8637	44	27A
0005434149735	8637	45	26F
0005434229389	8637	46	26E
0005435007277	8637	47	27C
0005434265043	8637	48	27D
0005434149752	8637	49	27E
0005434265213	8637	50	27F
0005433815436	8637	51	28B
0005432336152	8637	52	28A
0005434229395	8637	53	28D
0005433690945	8637	54	28C
0005434229376	8637	55	28F
0005434265259	8637	56	29B
0005432035241	8637	57	29A
0005434149768	8637	58	29D
0005435007255	8637	59	29C
0005435286674	8637	60	30A
0005435007271	8637	61	29F
0005432336154	8637	62	30C
0005434229436	8637	63	30B
0005432035248	8637	64	30E
0005434265165	8637	65	30D
0005432336161	8637	66	30F
0005433688832	8637	67	31B
0005432035244	8637	68	31A
0005434229384	8637	69	31C
0005432035240	8637	70	31D
0005433534521	8637	71	31F
0005432035239	8637	72	31E
0005433815434	8637	73	21A
0005432035245	8637	74	1A
0005435007266	8637	75	1D
0005433690946	8637	76	1C
0005435007264	8637	77	1F
0005432035224	8637	78	2A
0005435007267	8637	79	2D
0005434149736	8637	80	2F
0005433688831	8637	81	3C
0005435007257	8637	82	3D
0005432336160	8637	83	4A
0005434229413	8637	84	3F
0005434149754	8637	85	4C
0005435007272	8637	86	4D
0005432035247	8637	87	5A
0005433815437	8637	88	5C
0005434265058	8637	89	5D
0005434265044	8637	90	6A
0005435286672	8637	91	5F
0005434265260	8637	92	6C
0005434149740	8637	93	6D
0005434229446	8637	94	7A
0005435007263	8637	95	6F
0005435007269	8637	96	7C
0005434229412	8637	97	7D
0005435007253	8637	98	8A
0005433688830	8637	99	8B
0005434265164	8637	100	8D
0005432035227	8637	101	8C
0005434149714	8637	102	8E
0005435007274	8637	103	8F
0005434229444	8637	104	9A
0005434229388	8637	105	9C
0005434265129	8637	106	9B
0005435007261	8637	107	9D
0005435286670	8637	108	9E
0005432035237	8637	109	10A
0005432336162	8637	110	10B
0005434265193	8637	111	10D
0005432035225	8637	112	10C
0005434265144	8637	113	10E
0005432035220	8637	114	10F
0005434229445	8637	115	11B
0005434229425	8637	116	11A
0005433815438	8637	117	11C
0005434229410	8637	118	11D
0005434229473	8637	119	11E
0005432336159	8637	120	12A
0005435007268	8637	121	11F
0005434265069	8637	122	12B
0005432336155	8637	123	12D
0005435007259	8637	124	12C
0005434265170	8637	125	12F
0005434265192	8637	126	12E
0005434149721	8637	127	13A
0005433815435	8637	128	13C
0005432035231	8637	129	13B
0005434149800	8637	130	13D
0005434229386	8637	131	13E
0005435007258	8637	132	14A
0005434265136	8637	133	13F
0005432035232	8637	134	14B
0005432047587	8637	135	14D
0005435007270	8637	136	14C
0005435286673	8637	137	14F
0005433534519	8637	138	15B
0005432035233	8637	139	15A
0005435007275	8637	140	15C
0005432047590	8637	141	15D
0005432035246	8637	142	15F
0005432035230	8637	143	15E
0005433815439	8637	144	16A
0005432035242	8637	145	16B
0005435007256	8637	146	16D
0005434311240	8637	147	16C
0005434229396	8637	148	16E
0005434149799	8637	149	16F
0005432035243	8637	150	17B
0005432035219	8637	151	17C
0005433534520	8637	152	17D
0005432035229	8637	153	17F
0005434639420	12635	1	1A
0005433202513	12635	2	1B
0005434639426	12635	3	1C
0005433202523	12635	4	1D
0005433202522	12635	5	2A
0005433202516	12635	6	2B
0005434639399	12635	7	2C
0005434639419	12635	8	2D
0005434639313	12635	9	3A
0005434639301	12635	10	3B
0005434639327	12635	11	3C
0005434639322	12635	12	3D
0005433202510	12635	13	4A
0005434639287	12635	14	4B
0005434639383	12635	15	4C
0005433202511	12635	16	4D
0005434639368	12635	17	5A
0005434639423	12635	18	5B
0005434639276	12635	19	5C
0005434639396	12635	20	6A
0005434639359	12635	21	6B
0005434639334	12635	22	6C
0005433202520	12635	23	6D
0005434639414	12635	24	7A
0005434639323	12635	25	7B
0005434639406	12635	26	7C
0005434639395	12635	27	7D
0005434639405	12635	28	18A
0005433202512	12635	29	18B
0005434639286	12635	30	18D
0005434639366	12635	31	18C
0005434639398	12635	32	19A
0005434639367	12635	33	19B
0005434639425	12635	34	19C
0005434639312	12635	35	19D
0005433202514	12635	36	20A
0005434639384	12635	37	20B
0005433202521	12635	38	20C
0005434639277	12635	39	20D
0005433202519	12635	40	21A
0005433202517	12635	41	21B
0005433202509	12635	42	21C
0005433202518	12635	43	21D
0005434639447	12635	44	22A
0005434639365	12635	45	22B
0005434639446	12635	46	22C
0005434639328	12635	47	22D
0005433202515	12635	48	23A
0005434639407	12635	49	23B
0005433202298	23356	1	18C
0005434639558	23356	2	1A
0005433202350	23356	3	1B
0005433202384	23356	4	1C
0005434639557	23356	5	1D
0005433202360	23356	6	2A
0005433202398	23356	7	2B
0005433202359	23356	8	2C
0005434639571	23356	9	2D
0005434639564	23356	10	3A
0005434639565	23356	11	3B
0005433202303	23356	12	3D
0005434639549	23356	13	4A
0005434639552	23356	14	4B
0005432290661	23356	15	4C
0005434639572	23356	16	4D
0005432290663	23356	17	5A
0005434639570	23356	18	5B
0005433202351	23356	19	5C
0005433202358	23356	20	5D
0005433202355	23356	21	6A
0005433202417	23356	22	6B
0005434639551	23356	23	6C
0005434639559	23356	24	6D
0005433202418	23356	25	7A
0005434639567	23356	26	7B
0005434639553	23356	27	7C
0005434639563	23356	28	7D
0005433202309	23356	29	18A
0005434639554	23356	30	18B
0005433202295	23356	31	18D
0005433202356	23356	32	19A
0005433202366	23356	33	19B
0005434639562	23356	34	19C
0005434639550	23356	35	19D
0005434639569	23356	36	20A
0005432290662	23356	37	20B
0005434639555	23356	38	20C
0005433202368	23356	39	20D
0005434639560	23356	40	21A
0005433202385	23356	41	21B
0005434639556	23356	42	21C
0005433202361	23356	43	21D
0005433202428	23356	44	22A
0005434639568	23356	45	22B
0005433202369	23356	46	22C
0005433202370	23356	47	22D
0005434639561	23356	48	23A
0005434639566	23356	49	23B
0005432383147	21069	1	1A
0005432328777	21069	2	1C
0005432382995	21069	3	1D
0005432383121	21069	4	1F
0005432383278	21069	5	2A
0005432328699	21069	6	2C
0005432054335	21069	7	2D
0005432328712	21069	8	2F
0005432328697	21069	9	3A
0005432328721	21069	10	3C
0005432383117	21069	11	3D
0005432328689	21069	12	4A
0005432328819	21069	13	3F
0005432383084	21069	14	4C
0005432328842	21069	15	4D
0005432328776	21069	16	4E
0005432383116	21069	17	4F
0005432328829	21069	18	5A
0005432383312	21069	19	5C
0005432328874	21069	20	5D
0005432383150	21069	21	5E
0005432328640	21069	22	5F
0005432383016	21069	23	6C
0005432383154	21069	24	6D
0005432328604	21069	25	6E
0005432328845	21069	26	6F
0005432328843	21069	27	7A
0005432383202	21069	28	7C
0005432383306	21069	29	7D
0005432383260	21069	30	7E
0005432328554	21069	31	7F
0005432328967	21069	32	8A
0005432383171	21069	33	8C
0005432328798	21069	34	8D
0005432328696	21069	35	8E
0005432383311	21069	36	8F
0005432328757	21069	37	9A
0005432054334	21069	38	9C
0005432328794	21069	39	9D
0005432383269	21069	40	9E
0005432328966	21069	41	9F
0005432382996	21069	42	10A
0005432383043	21069	43	10C
0005432383095	21069	44	10D
0005432328610	21069	45	10E
0005432383242	21069	46	10F
0005432328709	21069	47	11A
0005432328818	21069	48	11C
0005432383153	21069	49	11D
0005432328965	21069	50	11E
0005432328805	21069	51	11F
0005432383096	21069	52	12A
0005432328804	21069	53	12C
0005432383183	21069	54	12D
0005432328607	21069	55	12E
0005432383149	21069	56	12F
0005432328917	21069	57	13A
0005432383148	21069	58	13C
0005432328706	21069	59	13D
0005432383042	21069	60	13E
0005432328768	21069	61	13F
0005432328838	21069	62	14A
0005432383264	21069	63	14C
0005432328722	21069	64	14D
0005432383268	21069	65	14E
0005432328734	21069	66	14F
0005432383152	21069	67	15A
0005432383191	21069	68	15C
0005432383241	21069	69	15D
0005432383237	21069	70	15E
0005432328841	21069	71	15F
0005432383232	21069	72	16A
0005432328744	21069	73	16C
0005432383276	21069	74	16D
0005432383170	21069	75	16E
0005432328606	21069	76	16F
0005432383277	21069	77	17A
0005432383243	21069	78	17C
0005432328756	21069	79	17D
0005432328553	21069	80	17E
0005432328662	21069	81	17F
0005432328698	21069	82	18A
0005432328750	21069	83	18C
0005432383203	21069	84	18D
0005432328952	21069	85	18E
0005432383198	21069	86	18F
0005432328968	21069	87	19A
0005432383238	21069	88	19C
0005432383100	21069	89	19D
0005432328817	21069	90	19E
0005432383132	21069	91	19F
0005432328906	21069	92	20A
0005432383239	21069	93	20C
0005432328830	21069	94	20D
0005432383164	21069	95	20E
0005432383099	21069	96	20F
0005432329151	31239	1	1A
0005432383569	31239	2	1D
0005432383554	31239	3	1F
0005432383549	31239	4	2A
0005432329123	31239	5	2C
0005432383551	31239	6	2D
0005432329118	31239	7	2F
0005432329122	31239	8	3C
0005432383534	31239	9	3D
0005432329156	31239	10	3F
0005432383538	31239	11	4A
0005432329146	31239	12	4D
0005432383570	31239	13	4E
0005432329133	31239	14	4F
0005432329141	31239	15	5A
0005432383552	31239	16	5C
0005432329136	31239	17	5D
0005432329127	31239	18	5E
0005432329112	31239	19	5F
0005432329157	31239	20	6A
0005432383563	31239	21	6C
0005432329119	31239	22	6D
0005432383547	31239	23	6E
0005432383535	31239	24	6F
0005432329137	31239	25	7A
0005432383548	31239	26	7C
0005432383553	31239	27	7D
0005432329115	31239	28	7E
0005432329121	31239	29	7F
0005432329139	31239	30	8A
0005432383537	31239	31	8C
0005432383561	31239	32	8D
0005432329130	31239	33	8E
0005432329145	31239	34	8F
0005432383543	31239	35	9A
0005432329116	31239	36	9C
0005432329134	31239	37	9D
0005432329132	31239	38	9E
0005432329158	31239	39	9F
0005432329120	31239	40	10A
0005432383565	31239	41	10C
0005432383533	31239	42	10D
0005432383542	31239	43	10E
0005432383562	31239	44	10F
0005432329150	31239	45	11A
0005432329143	31239	46	11C
0005432383550	31239	47	11D
0005432383558	31239	48	11E
0005432329148	31239	49	11F
0005432329144	31239	50	12C
0005432287235	31239	51	12D
0005432329142	31239	52	12E
0005432383559	31239	53	12F
0005432329131	31239	54	13A
0005432383555	31239	55	13C
0005432383557	31239	56	13D
0005432383568	31239	57	13E
0005432329152	31239	58	13F
0005432329149	31239	59	14A
0005432329135	31239	60	14C
0005432329126	31239	61	14D
0005432383556	31239	62	14E
0005432383560	31239	63	14F
0005432383544	31239	64	15A
0005432329128	31239	65	15C
0005432383536	31239	66	15D
0005432383545	31239	67	15E
0005432383567	31239	68	15F
0005432329155	31239	69	16A
0005432329153	31239	70	16E
0005432383541	31239	71	16F
0005432287238	31239	72	17A
0005432383539	31239	73	17C
0005432329113	31239	74	17D
0005432383540	31239	75	17E
0005432287239	31239	76	17F
0005432329117	31239	77	18A
0005432329125	31239	78	18C
0005432383566	31239	79	18D
0005432329147	31239	80	18E
0005432329154	31239	81	18F
0005432383564	31239	82	19C
0005432329114	31239	83	19D
0005432383546	31239	84	19E
0005432329124	31239	85	19F
0005432329140	31239	86	20A
0005432329129	31239	87	20C
0005432329138	31239	88	20D
0005432287236	31239	89	20E
0005432287237	31239	90	20F
0005433642258	27582	1	1A
0005433642418	27582	2	1D
0005433642271	27582	3	2A
0005433642382	27582	4	2D
0005433642320	27582	5	2F
0005432954021	27582	6	3C
0005432954014	27582	7	4D
0005432954017	27582	8	4E
0005433642376	27582	9	5C
0005433642314	27582	10	5D
0005433642406	27582	11	5E
0005433642307	27582	12	5F
0005432954020	27582	13	6C
0005432954012	27582	14	6D
0005432954023	27582	15	6E
0005433642407	27582	16	7A
0005433642380	27582	17	7D
0005432954022	27582	18	8A
0005432954028	27582	19	8C
0005433642342	27582	20	8E
0005433642411	27582	21	8F
0005432954019	27582	22	9A
0005433642351	27582	23	9E
0005432954013	27582	24	9F
0005432954015	27582	25	10F
0005433642362	27582	26	11C
0005433642383	27582	27	11D
0005432954026	27582	28	11E
0005432954024	27582	29	11F
0005433642328	27582	30	12C
0005433642329	27582	31	12E
0005433642410	27582	32	12F
0005433642324	27582	33	13D
0005433642372	27582	34	14D
0005433642389	27582	35	14E
0005433642313	27582	36	15A
0005432954027	27582	37	15C
0005432954016	27582	38	15D
0005432954018	27582	39	15E
0005433642308	27582	40	16D
0005433642343	27582	41	16F
0005433642371	27582	42	17A
0005433642388	27582	43	17D
0005433642419	27582	44	17F
0005433642330	27582	45	19F
0005433642327	27582	46	20C
0005432954025	27582	47	20D
0005433642341	27582	48	20E
0005432424891	13290	1	1A
0005432424870	13290	2	1C
0005432424898	13290	3	1D
0005432424866	13290	4	1F
0005432424872	13290	5	2A
0005432424892	13290	6	3A
0005432424906	13290	7	3C
0005432424903	13290	8	3D
0005432424910	13290	9	4A
0005432424868	13290	10	4D
0005432424907	13290	11	5C
0005432424885	13290	12	5D
0005432424900	13290	13	5E
0005432424890	13290	14	5F
0005432424878	13290	15	7A
0005432424880	13290	16	7E
0005432424887	13290	17	7F
0005432424893	13290	18	8C
0005432424901	13290	19	8D
0005432424911	13290	20	9A
0005432424914	13290	21	9C
0005432424894	13290	22	9D
0005432424874	13290	23	9F
0005432424875	13290	24	10A
0005432424909	13290	25	10C
0005432424895	13290	26	10E
0005432424902	13290	27	10F
0005432424873	13290	28	11A
0005432424867	13290	29	11D
0005432424905	13290	30	12A
0005432424886	13290	31	12C
0005432424879	13290	32	12D
0005432424882	13290	33	13A
0005432424896	13290	34	13F
0005432424908	13290	35	14A
0005432424883	13290	36	14C
0005432424897	13290	37	14E
0005432424864	13290	38	15E
0005432424881	13290	39	15F
0005432424865	13290	40	16D
0005432424913	13290	41	16F
0005432424869	13290	42	17A
0005432424871	13290	43	17E
0005432424899	13290	44	17F
0005432424912	13290	45	18C
0005432424888	13290	46	18E
0005432424876	13290	47	19A
0005432424884	13290	48	19D
0005432424877	13290	49	20A
0005432424889	13290	50	20E
0005432424904	13290	51	20F
0005432424516	30741	1	1F
0005432424407	30741	2	2C
0005432424507	30741	3	2D
0005432424513	30741	4	2F
0005432424429	30741	5	3A
0005432424293	30741	6	3C
0005432424483	30741	7	3D
0005432424415	30741	8	3F
0005432424426	30741	9	4D
0005432424313	30741	10	4E
0005432424490	30741	11	4F
0005432424477	30741	12	5F
0005432424344	30741	13	6A
0005432424484	30741	14	6C
0005432424231	30741	15	6E
0005432424274	30741	16	6F
0005432424377	30741	17	7C
0005432424400	30741	18	7F
0005432424456	30741	19	8A
0005432424497	30741	20	8E
0005432424481	30741	21	9C
0005432424445	30741	22	9E
0005432424406	30741	23	10A
0005432424501	30741	24	10F
0005432424312	30741	25	12F
0005432424433	30741	26	13A
0005432424294	30741	27	13C
0005432424309	30741	28	13D
0005432424446	30741	29	13F
0005432424478	30741	30	14C
0005432424414	30741	31	14E
0005432424349	30741	32	14F
0005432424405	30741	33	15E
0005432424261	30741	34	15F
0005432424453	30741	35	16D
0005432424275	30741	36	16F
0005432424506	30741	37	17A
0005432424273	30741	38	17D
0005432424505	30741	39	17E
0005432424461	30741	40	17F
0005432424328	30741	41	18A
0005432424452	30741	42	18C
0005432424511	30741	43	18F
0005432424359	30741	44	19A
0005432424376	30741	45	19E
0005432424479	30741	46	19F
0005432424500	30741	47	20F
0005432817787	9617	1	1C
0005432822280	9617	2	1D
0005432817778	9617	3	1F
0005432817784	9617	4	2A
0005434448351	9617	5	2C
0005432817772	9617	6	2D
0005432822282	9617	7	3A
0005432817761	9617	8	3C
0005432822283	9617	9	3D
0005434186208	9617	10	4A
0005432289019	9617	11	4D
0005434157508	9617	12	4E
0005432817783	9617	13	4F
0005432817775	9617	14	5A
0005432901586	9617	15	5E
0005434157501	9617	16	5F
0005432817769	9617	17	6C
0005432817786	9617	18	6D
0005432817773	9617	19	6E
0005432289018	9617	20	6F
0005432817765	9617	21	7C
0005432901680	9617	22	7D
0005432901660	9617	23	7E
0005432901648	9617	24	7F
0005432817774	9617	25	8A
0005432817777	9617	26	8C
0005432817759	9617	27	8D
0005432817766	9617	28	8E
0005432901659	9617	29	8F
0005432822284	9617	30	9A
0005432817762	9617	31	9C
0005432817776	9617	32	9F
0005432817771	9617	33	10C
0005432817768	9617	34	10D
0005432901646	9617	35	10E
0005432817760	9617	36	10F
0005432901644	9617	37	11A
0005432817779	9617	38	11C
0005432817780	9617	39	11F
0005432817758	9617	40	12C
0005432901621	9617	41	12E
0005432817767	9617	42	13A
0005432901651	9617	43	13C
0005432822281	9617	44	13F
0005432822285	9617	45	14C
0005432822279	9617	46	14D
0005434448353	9617	47	14E
0005432817763	9617	48	14F
0005434157509	9617	49	15A
0005432901705	9617	50	15E
0005432901574	9617	51	15F
0005432822278	9617	52	16C
0005432817785	9617	53	16D
0005432901601	9617	54	16E
0005434448350	9617	55	16F
0005432289020	9617	56	17A
0005432817781	9617	57	17D
0005432817764	9617	58	17E
0005432901650	9617	59	17F
0005432289021	9617	60	18A
0005432817782	9617	61	18D
0005432901656	9617	62	18F
0005432817770	9617	63	19A
0005432901647	9617	64	19D
0005434448352	9617	65	20C
0005434157507	9617	66	20D
0005432901622	9617	67	20F
0005432002098	29000	1	1C
0005434157556	29000	2	1A
0005432817472	29000	3	1D
0005434186227	29000	4	1F
0005432817518	29000	5	2A
0005432817489	29000	6	2C
0005432817433	29000	7	3D
0005432817516	29000	8	3F
0005432817615	29000	9	4D
0005432817532	29000	10	4E
0005432901781	29000	11	4F
0005432901780	29000	12	5A
0005432002099	29000	13	5D
0005432901793	29000	14	5E
0005432901779	29000	15	5F
0005432901782	29000	16	6A
0005432817635	29000	17	6C
0005432817530	29000	18	6D
0005432817432	29000	19	6E
0005432817616	29000	20	6F
0005432901794	29000	21	7A
0005432822227	29000	22	7C
0005432817445	29000	23	7D
0005434157561	29000	24	7F
0005432901787	29000	25	8C
0005434448313	29000	26	8E
0005432817539	29000	27	8F
0005432901788	29000	28	9A
0005432817462	29000	29	9D
0005432817554	29000	30	9E
0005432817439	29000	31	10A
0005432822220	29000	32	10C
0005432817402	29000	33	10D
0005434186225	29000	34	10E
0005432822206	29000	35	10F
0005432817529	29000	36	11A
0005432817622	29000	37	11C
0005432817467	29000	38	11D
0005432817542	29000	39	11E
0005432817533	29000	40	11F
0005434157559	29000	41	12A
0005432817531	29000	42	12C
0005432822212	29000	43	12D
0005432822195	29000	44	12E
0005432901795	29000	45	12F
0005432822194	29000	46	13A
0005432817491	29000	47	13C
0005432817438	29000	48	13D
0005432002097	29000	49	13E
0005434157557	29000	50	13F
0005432002096	29000	51	14A
0005432901791	29000	52	14C
0005432817517	29000	53	14D
0005434157558	29000	54	14E
0005432817444	29000	55	14F
0005432817473	29000	56	15A
0005432901797	29000	57	15D
0005432901785	29000	58	15E
0005432901784	29000	59	15F
0005432901789	29000	60	16A
0005432901790	29000	61	16C
0005432817403	29000	62	16D
0005432901783	29000	63	16E
0005432817536	29000	64	16F
0005434448317	29000	65	17E
0005432822225	29000	66	17F
0005432817588	29000	67	18A
0005434157560	29000	68	18C
0005432901786	29000	69	18D
0005432901796	29000	70	19A
0005434157562	29000	71	19D
0005434186228	29000	72	19E
0005432817535	29000	73	19F
0005432822226	29000	74	20C
0005432901792	29000	75	20D
0005434186226	29000	76	20E
0005432822198	29000	77	20F
0005432611751	15070	1	1A
0005435841824	15070	2	2A
0005435841094	15070	3	3A
0005435841823	15070	4	3B
0005432613905	15070	5	4A
0005435841825	15070	6	4B
0005432613903	15070	7	5B
0005432613904	15070	8	6A
0005432607577	31607	1	1B
0005435841829	31607	2	3A
0005432611716	31607	3	5A
0005435842336	31607	4	6A
0005432607574	31607	5	5B
0005435842335	31607	6	6B
0005433569615	11853	1	12C
0005432948584	11853	2	1A
0005432948583	11853	3	1F
0005433569605	11853	4	1D
0005433569640	11853	5	2C
0005433569613	11853	6	2A
0005433569594	11853	7	3A
0005432948557	11853	8	2F
0005433569620	11853	9	3C
0005432948530	11853	10	4A
0005433569648	11853	11	3F
0005432948339	11853	12	3D
0005432948464	11853	13	4F
0005433569638	11853	14	4D
0005433569646	11853	15	5C
0005433569636	11853	16	5D
0005432948392	11853	17	6B
0005433569625	11853	18	6A
0005433569603	11853	19	6D
0005432948478	11853	20	6C
0005432948556	11853	21	6F
0005432948531	11853	22	7A
0005432948552	11853	23	7C
0005433569609	11853	24	7B
0005433569591	11853	25	7E
0005433569596	11853	26	7D
0005433569585	11853	27	7F
0005433569612	11853	28	8C
0005432948477	11853	29	8B
0005433569587	11853	30	8A
0005433569617	11853	31	8D
0005432948463	11853	32	8F
0005432948529	11853	33	8E
0005433569622	11853	34	9B
0005432948550	11853	35	9A
0005433569595	11853	36	9C
0005433569639	11853	37	9F
0005433569623	11853	38	9E
0005433569599	11853	39	9D
0005433569641	11853	40	10B
0005433569598	11853	41	10A
0005433569630	11853	42	10C
0005433569607	11853	43	10D
0005432948593	11853	44	10F
0005433569632	11853	45	10E
0005433569602	11853	46	11B
0005433569588	11853	47	11A
0005432948317	11853	48	11D
0005433569600	11853	49	11F
0005432948288	11853	50	11E
0005433569647	11853	51	12B
0005433569624	11853	52	12F
0005433569601	11853	53	12E
0005432948340	11853	54	13B
0005432948442	11853	55	13E
0005433569608	11853	56	13F
0005433569628	11853	57	14A
0005432948503	11853	58	14F
0005432948551	11853	59	14E
0005433569643	11853	60	15B
0005432948476	11853	61	15A
0005433569611	11853	62	15D
0005432948502	11853	63	15C
0005433569592	11853	64	15E
0005433569627	11853	65	16A
0005433569629	11853	66	15F
0005432948341	11853	67	16C
0005432948528	11853	68	16B
0005433569633	11853	69	16D
0005433569621	11853	70	16F
0005433569597	11853	71	17C
0005432948627	11853	72	17B
0005433569610	11853	73	17A
0005433569637	11853	74	17D
0005433569645	11853	75	17E
0005433569584	11853	76	18A
0005433569589	11853	77	17F
0005432948626	11853	78	18C
0005433569614	11853	79	18B
0005433569590	11853	80	18E
0005433569634	11853	81	18D
0005432948594	11853	82	19A
0005433569635	11853	83	18F
0005433569644	11853	84	19C
0005432948595	11853	85	19B
0005433569619	11853	86	19D
0005433569593	11853	87	20A
0005433569626	11853	88	19F
0005433569642	11853	89	20B
0005433569606	11853	90	20D
0005432948572	11853	91	20C
0005433569631	11853	92	20F
0005433569618	11853	93	20E
0005432948546	11853	94	21A
0005433569616	11853	95	21D
0005433569586	11853	96	21C
0005433569604	11853	97	21B
0005432948504	11853	98	21F
0005432948927	25309	1	1C
0005433569241	25309	2	1A
0005433569075	25309	3	1F
0005433569065	25309	4	1D
0005433568950	25309	5	2C
0005433569057	25309	6	2A
0005433569298	25309	7	2F
0005433569135	25309	8	2D
0005432948911	25309	9	3A
0005432948909	25309	10	3D
0005433568961	25309	11	3C
0005433569225	25309	12	4A
0005433568963	25309	13	3F
0005433569170	25309	14	4D
0005432948906	25309	15	4C
0005432948929	25309	16	4F
0005433569089	25309	17	5C
0005432948894	25309	18	5A
0005433568775	25309	19	5F
0005433569142	25309	20	5D
0005433569012	25309	21	6B
0005433569115	25309	22	6A
0005433569096	25309	23	6D
0005432948915	25309	24	6C
0005433569143	25309	25	6E
0005432948914	25309	26	7A
0005433569116	25309	27	6F
0005432948896	25309	28	7C
0005433569011	25309	29	7B
0005433568962	25309	30	7E
0005433568776	25309	31	7F
0005433569008	25309	32	8B
0005433569158	25309	33	8A
0005433569205	25309	34	8D
0005432948920	25309	35	8C
0005433569152	25309	36	8F
0005433569223	25309	37	8E
0005432948898	25309	38	9B
0005433568931	25309	39	9A
0005432948908	25309	40	9C
0005433569039	25309	41	9F
0005432948930	25309	42	9E
0005433569238	25309	43	10B
0005433569198	25309	44	10A
0005432948904	25309	45	10C
0005432948899	25309	46	10E
0005433568978	25309	47	10D
0005432948903	25309	48	11A
0005433569175	25309	49	10F
0005432948917	25309	50	11C
0005433569147	25309	51	11B
0005433569201	25309	52	11D
0005433569277	25309	53	11F
0005433568932	25309	54	11E
0005432948892	25309	55	12A
0005432948913	25309	56	12D
0005433568857	25309	57	13A
0005433569206	25309	58	12F
0005432948922	25309	59	13C
0005432948900	25309	60	13B
0005433568872	25309	61	13E
0005433569066	25309	62	13D
0005433569061	25309	63	13F
0005432948912	25309	64	14B
0005432948891	25309	65	14A
0005432948926	25309	66	14D
0005433568976	25309	67	14F
0005433568916	25309	68	14E
0005432948919	25309	69	15B
0005433569063	25309	70	15F
0005433569007	25309	71	15E
0005433568856	25309	72	15D
0005432948901	25309	73	16A
0005433569149	25309	74	16C
0005433569207	25309	75	16D
0005432948905	25309	76	17A
0005433569276	25309	77	16F
0005433569208	25309	78	16E
0005432948924	25309	79	17B
0005432948907	25309	80	17D
0005432948928	25309	81	17F
0005433569023	25309	82	18A
0005433569174	25309	83	18C
0005433569090	25309	84	18B
0005432948918	25309	85	18E
0005432948916	25309	86	18D
0005433569167	25309	87	18F
0005433568977	25309	88	19C
0005432948925	25309	89	19B
0005432948893	25309	90	19E
0005433569157	25309	91	19D
0005432948923	25309	92	19F
0005432948910	25309	93	20B
0005432948895	25309	94	20A
0005433569156	25309	95	20D
0005433569224	25309	96	20C
0005433569076	25309	97	21A
0005433569307	25309	98	20F
0005432948902	25309	99	21C
0005432948921	25309	100	21B
0005432948897	25309	101	21E
0005433569134	25309	102	21D
0005434654981	5369	1	1A
0005435340311	5369	2	2A
0005434654997	5369	3	2C
0005434654983	5369	4	2F
0005435340236	5369	5	3A
0005432114236	5369	6	3C
0005434654988	5369	7	3D
0005435340234	5369	8	4A
0005435340224	5369	9	4C
0005432114237	5369	10	4D
0005434654985	5369	11	5A
0005434654995	5369	12	5C
0005435340292	5369	13	5D
0005434654980	5369	14	5E
0005435340286	5369	15	5F
0005435340282	5369	16	6A
0005434654986	5369	17	6C
0005435340284	5369	18	6D
0005435340271	5369	19	6E
0005435340272	5369	20	7A
0005434654976	5369	21	7C
0005434654973	5369	22	7D
0005434654975	5369	23	7E
0005434654994	5369	24	8A
0005435340235	5369	25	8C
0005434654996	5369	26	8E
0005434654991	5369	27	8F
0005435340244	5369	28	9C
0005435340260	5369	29	9E
0005435340333	5369	30	10A
0005434656577	5369	31	10D
0005435340269	5369	32	11A
0005434654987	5369	33	11D
0005434654978	5369	34	11E
0005434654979	5369	35	12A
0005435555376	5369	36	12E
0005435555375	5369	37	12F
0005435340245	5369	38	13A
0005434654990	5369	39	13D
0005434654972	5369	40	13E
0005435340285	5369	41	14A
0005435340267	5369	42	14C
0005434654977	5369	43	14E
0005434654984	5369	44	15A
0005435340336	5369	45	15C
0005434654989	5369	46	16A
0005434654992	5369	47	16E
0005434654993	5369	48	17C
0005434654970	5369	49	17F
0005434654971	5369	50	18A
0005435340302	5369	51	18C
0005434654969	5369	52	18D
0005434654974	5369	53	19D
0005435340268	5369	54	19E
0005435340223	5369	55	19F
0005435340288	5369	56	20A
0005434654982	5369	57	20D
0005434656576	5369	58	20E
0005434654689	12553	1	1A
0005434654749	12553	2	1D
0005434656562	12553	3	2A
0005434654784	12553	4	2D
0005434654661	12553	5	3A
0005435340419	12553	6	3D
0005434654731	12553	7	4A
0005434654648	12553	8	4C
0005434654766	12553	9	4D
0005434654732	12553	10	5A
0005434656566	12553	11	5C
0005434654671	12553	12	5D
0005435340412	12553	13	5F
0005434654599	12553	14	6C
0005434654730	12553	15	6D
0005434654746	12553	16	6F
0005434656568	12553	17	7A
0005435340411	12553	18	7C
0005434654662	12553	19	7D
0005434654650	12553	20	7E
0005435340415	12553	21	7F
0005435340418	12553	22	8C
0005435340424	12553	23	8D
0005435340420	12553	24	8E
0005435555393	12553	25	8F
0005434654770	12553	26	9A
0005435340423	12553	27	9D
0005434654690	12553	28	9E
0005434654707	12553	29	10A
0005434654726	12553	30	10C
0005434654700	12553	31	10D
0005434654776	12553	32	10F
0005434654832	12553	33	11A
0005435340421	12553	34	11D
0005434654663	12553	35	11E
0005435340417	12553	36	11F
0005434654701	12553	37	12C
0005434654649	12553	38	12E
0005435340410	12553	39	12F
0005434654691	12553	40	13C
0005434654697	12553	41	13D
0005435555392	12553	42	13E
0005434654748	12553	43	14A
0005434654785	12553	44	14C
0005434654762	12553	45	14D
0005435555391	12553	46	14E
0005434654744	12553	47	15C
0005435340422	12553	48	15D
0005434654708	12553	49	15E
0005434654728	12553	50	16C
0005434654910	12553	51	16E
0005434654694	12553	52	16F
0005434654854	12553	53	17A
0005434654745	12553	54	17C
0005434656563	12553	55	17D
0005435340414	12553	56	17E
0005434654753	12553	57	17F
0005434654792	12553	58	18A
0005434654833	12553	59	18E
0005434654733	12553	60	18F
0005435340413	12553	61	19A
0005435340416	12553	62	19C
0005434654643	12553	63	19D
0005434654823	12553	64	19E
0005434656567	12553	65	20C
0005434654722	12553	66	20D
0005433716465	7445	1	1A
0005432078166	7445	2	1C
0005432428931	7445	3	1D
0005433716449	7445	4	2A
0005433716480	7445	5	1F
0005433716466	7445	6	2C
0005433689930	7445	7	3F
0005432428937	7445	8	3D
0005433716454	7445	9	4A
0005433716489	7445	10	4B
0005433716459	7445	11	4D
0005433716458	7445	12	4C
0005433716448	7445	13	4E
0005432078165	7445	14	5A
0005433716491	7445	15	5C
0005433716473	7445	16	5D
0005433656701	7445	17	5F
0005433716478	7445	18	6B
0005433716487	7445	19	6D
0005433716460	7445	20	7A
0005432078164	7445	21	6F
0005433716468	7445	22	7B
0005433716452	7445	23	7D
0005433719174	7445	24	7E
0005433716485	7445	25	8A
0005433716455	7445	26	7F
0005433716482	7445	27	8B
0005433716464	7445	28	8D
0005433688828	7445	29	8F
0005433716476	7445	30	9A
0005433689933	7445	31	9C
0005433716469	7445	32	9B
0005433716467	7445	33	9D
0005433716492	7445	34	10B
0005435266147	7445	35	10C
0005433716493	7445	36	11D
0005433716472	7445	37	12A
0005432078163	7445	38	12B
0005432428932	7445	39	12C
0005433719172	7445	40	12E
0005433716494	7445	41	12D
0005433716461	7445	42	12F
0005433722283	7445	43	13B
0005433716463	7445	44	13E
0005433716498	7445	45	13F
0005433656702	7445	46	14A
0005433719175	7445	47	14C
0005433690944	7445	48	14E
0005433716451	7445	49	15A
0005433716497	7445	50	15F
0005432428936	7445	51	16B
0005433716470	7445	52	16E
0005433716475	7445	53	16D
0005433716474	7445	54	17A
0005432428935	7445	55	16F
0005433716488	7445	56	17B
0005433719173	7445	57	18D
0005433716483	7445	58	19B
0005432428938	7445	59	19D
0005433716462	7445	60	19C
0005433716457	7445	61	19E
0005433689931	7445	62	20B
0005433722282	7445	63	20A
0005433716495	7445	64	20D
0005433716484	7445	65	20C
0005433716490	7445	66	20E
0005433716477	7445	67	20F
0005433716453	7445	68	21B
0005433716456	7445	69	21A
0005433716479	7445	70	21C
0005433656703	7445	71	21D
0005433716486	7445	72	21E
0005433716450	7445	73	22A
0005433689932	7445	74	22C
0005433688829	7445	75	22B
0005433716471	7445	76	22E
0005433689929	7445	77	23A
0005433716496	7445	78	23D
0005433716481	7445	79	23F
0005433690943	7445	80	23E
0005433716179	29228	1	1C
0005432428965	29228	2	1A
0005433722200	29228	3	2A
0005433716180	29228	4	2D
0005433715740	29228	5	2C
0005433719153	29228	6	3C
0005433715970	29228	7	3F
0005435266194	29228	8	4B
0005433716044	29228	9	4A
0005432006789	29228	10	4C
0005432428964	29228	11	4D
0005433716113	29228	12	4E
0005433716016	29228	13	4F
0005433719159	29228	14	5C
0005433656664	29228	15	5B
0005433716100	29228	16	5D
0005433688818	29228	17	6A
0005433715893	29228	18	6E
0005433716133	29228	19	7B
0005433716121	29228	20	7C
0005433716032	29228	21	7D
0005433716153	29228	22	7F
0005435266195	29228	23	8B
0005433719151	29228	24	8C
0005433716137	29228	25	8F
0005433719142	29228	26	8E
0005432428962	29228	27	9A
0005433716287	29228	28	9B
0005433716162	29228	29	9E
0005432006790	29228	30	10D
0005433722206	29228	31	11A
0005433719137	29228	32	11E
0005433716288	29228	33	12B
0005433656665	29228	34	12D
0005433715939	29228	35	12F
0005433716099	29228	36	13C
0005433715977	29228	37	14B
0005433719140	29228	38	14D
0005435266192	29228	39	14C
0005433715978	29228	40	14E
0005432006792	29228	41	15A
0005433716130	29228	42	14F
0005433688810	29228	43	15B
0005433719141	29228	44	15D
0005433722204	29228	45	16A
0005433715947	29228	46	15F
0005433656668	29228	47	16C
0005435266193	29228	48	16D
0005433716097	29228	49	16E
0005433719160	29228	50	17A
0005433715946	29228	51	16F
0005433719136	29228	52	17B
0005433716368	29228	53	17C
0005433716010	29228	54	17E
0005432428963	29228	55	17F
0005433715962	29228	56	19A
0005433715976	29228	57	19B
0005433656686	29228	58	19F
0005433716006	29228	59	20B
0005433716098	29228	60	20D
0005433716124	29228	61	20E
0005433716079	29228	62	20F
0005433716045	29228	63	21F
0005433716136	29228	64	22A
0005433716253	29228	65	22B
0005433715957	29228	66	22D
0005433716009	29228	67	22E
0005433656666	29228	68	23A
0005433722205	29228	69	23B
0005433715852	29228	70	23C
0005433716017	29228	71	23E
0005432006791	29228	72	23F
0005434182227	8682	1	1A
0005434182245	8682	2	1F
0005434182186	8682	3	3C
0005434182232	8682	4	4E
0005434182201	8682	5	5E
0005434182202	8682	6	7E
0005434182228	8682	7	8C
0005434095425	8682	8	9E
0005434095416	8682	9	10A
0005434182203	8682	10	10F
0005434182204	8682	11	11D
0005434182246	8682	12	12C
0005434182210	8682	13	12D
0005434182212	8682	14	13A
0005434182185	8682	15	13C
0005434095417	8682	16	13D
0005434095422	8682	17	13F
0005434182247	8682	18	14D
0005434095427	8682	19	14E
0005434095420	8682	20	14F
0005434095418	8682	21	15D
0005434095423	8682	22	16C
0005434182211	8682	23	17A
0005434095421	8682	24	17D
0005434095426	8682	25	17E
0005434095419	8682	26	17F
0005434095415	8682	27	19F
0005434095428	8682	28	20A
0005434095424	8682	29	20C
0005434095414	8682	30	20E
0005434095318	11662	1	1D
0005434182309	11662	2	2D
0005434182316	11662	3	2F
0005434182312	11662	4	3D
0005434182306	11662	5	3F
0005434095306	11662	6	4D
0005434095278	11662	7	4F
0005434095232	11662	8	5C
0005434182313	11662	9	5D
0005434184683	11662	10	7A
0005434182314	11662	11	7C
0005434095322	11662	12	7D
0005434143729	11662	13	7E
0005434183598	11662	14	8C
0005434182311	11662	15	8D
0005434182315	11662	16	9C
0005434095266	11662	17	9E
0005434182307	11662	18	10E
0005434095333	11662	19	10F
0005434184684	11662	20	11A
0005434182317	11662	21	11C
0005434095258	11662	22	11E
0005434182308	11662	23	12E
0005434182310	11662	24	14D
0005434095279	11662	25	14E
0005434095259	11662	26	15A
0005434143727	11662	27	15D
0005434182305	11662	28	15E
0005434095334	11662	29	16C
0005434095303	11662	30	16E
0005434095267	11662	31	17C
0005434095323	11662	32	17E
0005434183599	11662	33	18A
0005434095307	11662	34	19E
0005434095310	11662	35	20F
0005433457010	1425	1	1A
0005433397830	1425	2	1C
0005433398244	1425	3	1D
0005433398175	1425	4	1F
0005433398136	1425	5	2C
0005433398083	1425	6	3A
0005435732476	1425	7	3C
0005435732461	1425	8	3D
0005432297305	1425	9	3F
0005433397986	1425	10	4A
0005433398243	1425	11	4C
0005433398124	1425	12	4D
0005433457013	1425	13	4E
0005435732464	1425	14	5A
0005433398196	1425	15	5D
0005435732472	1425	16	5E
0005433397835	1425	17	5F
0005435732471	1425	18	6A
0005435732474	1425	19	6C
0005435732469	1425	20	6E
0005435732479	1425	21	6F
0005435732473	1425	22	7A
0005435732480	1425	23	7C
0005433398219	1425	24	7D
0005433398260	1425	25	7E
0005435732475	1425	26	8A
0005435732467	1425	27	8D
0005433398125	1425	28	8E
0005433398010	1425	29	9A
0005433397881	1425	30	9C
0005433457012	1425	31	9D
0005433398157	1425	32	9E
0005435732465	1425	33	10C
0005433398121	1425	34	10D
0005435732462	1425	35	10F
0005432297304	1425	36	11A
0005435732468	1425	37	11D
0005433397992	1425	38	12C
0005433457011	1425	39	12D
0005433398169	1425	40	12E
0005433398005	1425	41	13A
0005433398120	1425	42	13C
0005433398184	1425	43	13D
0005433398127	1425	44	13E
0005433398151	1425	45	13F
0005433398195	1425	46	14C
0005433398135	1425	47	14E
0005435732466	1425	48	14F
0005435732470	1425	49	15A
0005433398134	1425	50	15C
0005435732478	1425	51	15D
0005433397991	1425	52	15E
0005433398211	1425	53	15F
0005433398082	1425	54	16A
0005435732477	1425	55	16D
0005435732463	1425	56	16E
0005433398183	1425	57	16F
0005433397994	1425	58	17A
0005433398109	1425	59	17C
0005433398188	1425	60	17E
0005433398126	1425	61	17F
0005435732481	1425	62	18C
0005433398038	1425	63	18D
0005433398329	1425	64	18E
0005433398110	1425	65	18F
0005432297303	1425	66	19A
0005433397905	1425	67	19C
0005433398190	1425	68	19E
0005433398114	1425	69	19F
0005433398210	1425	70	20A
0005433398026	1425	71	20C
0005433457009	1425	72	20E
0005433398542	19269	1	1A
0005433398567	19269	2	1C
0005433398554	19269	3	1D
0005433398538	19269	4	2A
0005433398529	19269	5	2C
0005433398556	19269	6	2D
0005433398533	19269	7	2F
0005433398548	19269	8	3A
0005433398531	19269	9	3C
0005433398549	19269	10	3D
0005433398570	19269	11	4D
0005435732335	19269	12	4E
0005435732375	19269	13	4F
0005435732301	19269	14	5A
0005435732374	19269	15	5C
0005433398541	19269	16	5D
0005433398532	19269	17	5E
0005433398559	19269	18	5F
0005433398536	19269	19	6A
0005435732376	19269	20	6C
0005433398525	19269	21	6D
0005433398535	19269	22	6E
0005433456987	19269	23	6F
0005433398544	19269	24	7C
0005433398550	19269	25	7D
0005433398527	19269	26	7E
0005433398546	19269	27	8A
0005433456981	19269	28	8D
0005433398540	19269	29	9A
0005432906561	19269	30	10A
0005433398565	19269	31	10C
0005433398528	19269	32	10D
0005433398551	19269	33	10E
0005435732333	19269	34	10F
0005433398547	19269	35	11A
0005435732299	19269	36	11D
0005433398555	19269	37	11E
0005435732340	19269	38	12A
0005435732373	19269	39	12E
0005433398558	19269	40	12F
0005433398534	19269	41	13A
0005433398568	19269	42	13C
0005435732334	19269	43	13D
0005433398564	19269	44	13E
0005433398566	19269	45	13F
0005435732364	19269	46	14A
0005435732356	19269	47	14C
0005433398563	19269	48	15C
0005433398569	19269	49	15D
0005433398552	19269	50	15E
0005433398530	19269	51	16A
0005433398543	19269	52	16C
0005433398560	19269	53	16D
0005433398562	19269	54	16E
0005435732331	19269	55	17A
0005433398553	19269	56	17C
0005435732302	19269	57	17D
0005435732330	19269	58	17E
0005433398539	19269	59	17F
0005433398561	19269	60	18A
0005435732339	19269	61	18C
0005433398526	19269	62	18D
0005433398557	19269	63	18E
0005433398523	19269	64	18F
0005433398524	19269	65	19C
0005433398545	19269	66	19D
0005432906560	19269	67	19E
0005435732282	19269	68	20A
0005433398537	19269	69	20E
0005434443678	17335	1	1D
0005434443721	17335	2	2D
0005434443733	17335	3	3A
0005434443785	17335	4	4B
0005434443726	17335	5	5A
0005434443725	17335	6	5B
0005434443766	17335	7	5C
0005434443748	17335	8	6B
0005434443775	17335	9	6C
0005434443776	17335	10	6D
0005434443732	17335	11	7A
0005434443747	17335	12	7B
0005434443677	17335	13	7C
0005434443728	17335	14	18A
0005434443786	17335	15	20A
0005434443676	17335	16	23B
0005434443856	20585	1	3C
0005434443857	20585	2	3D
0005434443863	20585	3	4A
0005434443854	20585	4	4C
0005434443862	20585	5	4D
0005434443859	20585	6	5A
0005434443855	20585	7	18C
0005434443865	20585	8	18D
0005434443869	20585	9	19A
0005434443864	20585	10	19C
0005434443860	20585	11	20B
0005434443867	20585	12	20C
0005434443866	20585	13	21B
0005434443868	20585	14	21D
0005434443861	20585	15	22A
0005434443858	20585	16	23B
0005435377587	7288	1	1A
0005434954648	7288	2	2A
0005434954647	7288	3	2B
0005434954650	7288	4	4A
0005434954649	7288	5	5B
0005435377584	7288	6	6A
0005435377603	28303	1	2A
0005435377604	28303	2	3B
0005434954601	28303	3	6A
0005434351820	4464	1	1A
0005435893685	4464	2	2A
0005434351821	4464	3	2C
0005435893645	4464	4	2D
0005434351827	4464	5	3C
0005434351825	4464	6	3D
0005434351829	4464	7	4C
0005434351818	4464	8	4D
0005435893684	4464	9	5A
0005434351828	4464	10	5B
0005434351822	4464	11	5C
0005435893646	4464	12	6D
0005434351830	4464	13	7B
0005434351826	4464	14	18A
0005434351824	4464	15	19A
0005434351823	4464	16	19B
0005435893675	4464	17	19D
0005435893641	4464	18	20C
0005434351819	4464	19	21B
0005435893701	29682	1	2D
0005435893700	29682	2	3B
0005435893703	29682	3	4A
0005434351697	29682	4	4C
0005434351759	29682	5	5A
0005435893706	29682	6	6B
0005434351721	29682	7	6D
0005434351735	29682	8	7C
0005434351720	29682	9	7D
0005434351758	29682	10	18B
0005435893705	29682	11	20B
0005434351703	29682	12	20D
0005435893704	29682	13	21C
0005435893702	29682	14	22A
0005433343012	1071	1	1A
0005433343348	1071	2	1C
0005433343511	1071	3	1B
0005432293232	1071	4	1G
0005433343203	1071	5	2A
0005433343426	1071	6	1H
0005433462768	1071	7	2C
0005433343390	1071	8	2F
0005433343175	1071	9	3C
0005433343265	1071	10	3G
0005433342994	1071	11	4A
0005433343538	1071	12	4B
0005433343266	1071	13	4C
0005433343291	1071	14	4G
0005434445267	1071	15	4H
0005433343349	1071	16	5B
0005433343497	1071	17	5H
0005433343292	1071	18	5G
0005433343614	1071	19	9A
0005432293234	1071	20	9G
0005435545828	1071	21	9H
0005435545823	1071	22	11D
0005433343171	1071	23	11E
0005433343131	1071	24	11F
0005435092173	1071	25	11G
0005434446539	1071	26	12D
0005433343145	1071	27	12B
0005435545814	1071	28	12H
0005433343547	1071	29	13D
0005433343389	1071	30	13B
0005433343318	1071	31	13F
0005433343351	1071	32	13E
0005435545822	1071	33	13G
0005433343055	1071	34	14A
0005433342501	1071	35	14B
0005433343319	1071	36	14D
0005433343232	1071	37	14F
0005433343548	1071	38	14G
0005433158132	1071	39	15A
0005433343398	1071	40	14H
0005433463923	1071	41	15E
0005435545816	1071	42	15D
0005433343368	1071	43	15F
0005433343606	1071	44	15H
0005433463922	1071	45	16A
0005433343160	1071	46	16D
0005433343221	1071	47	16B
0005435545826	1071	48	16E
0005433343306	1071	49	16G
0005433343163	1071	50	16H
0005433343477	1071	51	17E
0005433343173	1071	52	18A
0005433343165	1071	53	17H
0005435092179	1071	54	18B
0005433343250	1071	55	18F
0005433463921	1071	56	18E
0005433343153	1071	57	18H
0005435092170	1071	58	19B
0005433342814	1071	59	19E
0005433343496	1071	60	19H
0005433343336	1071	61	19G
0005435092176	1071	62	20B
0005433343107	1071	63	20E
0005433343264	1071	64	20F
0005435545812	1071	65	20H
0005435092177	1071	66	20G
0005435092171	1071	67	21D
0005434446538	1071	68	21B
0005435545813	1071	69	21E
0005433343391	1071	70	21F
0005432293233	1071	71	22A
0005433269725	1071	72	22F
0005433462769	1071	73	22H
0005433343483	1071	74	23A
0005434445266	1071	75	23D
0005435545819	1071	76	23F
0005433343590	1071	77	23G
0005435545818	1071	78	24B
0005433343690	1071	79	24A
0005433343210	1071	80	24E
0005433269744	1071	81	24F
0005433343170	1071	82	24G
0005435545825	1071	83	25E
0005433158131	1071	84	27B
0005433269730	1071	85	27A
0005434445268	1071	86	27D
0005433343393	1071	87	27F
0005433342925	1071	88	28A
0005433342897	1071	89	28D
0005433343174	1071	90	28B
0005433343037	1071	91	28E
0005433343108	1071	92	28F
0005433343304	1071	93	29B
0005435092174	1071	94	29A
0005435545817	1071	95	29D
0005435545815	1071	96	29G
0005433343413	1071	97	29H
0005433342924	1071	98	30D
0005433269716	1071	99	30E
0005433342871	1071	100	31A
0005435092169	1071	101	30H
0005435545820	1071	102	31D
0005435545824	1071	103	31E
0005433343233	1071	104	32A
0005433343310	1071	105	31H
0005433343644	1071	106	32B
0005433343399	1071	107	32E
0005432293235	1071	108	33A
0005433343253	1071	109	33D
0005435545827	1071	110	33E
0005433343270	1071	111	33G
0005433343392	1071	112	34B
0005433343123	1071	113	34D
0005433343122	1071	114	34F
0005433342651	1071	115	34H
0005433342931	1071	116	34G
0005433343268	1071	117	35B
0005433342993	1071	118	35A
0005433343043	1071	119	35D
0005433343056	1071	120	35F
0005435092178	1071	121	35E
0005433343172	1071	122	36B
0005433462770	1071	123	36A
0005435092175	1071	124	36D
0005433343180	1071	125	36F
0005435545821	1071	126	36H
0005433158133	1071	127	37D
0005433343073	1071	128	37B
0005433343042	1071	129	37G
0005433343036	1071	130	38D
0005433158128	1071	131	38B
0005433343427	1071	132	38G
0005433158134	1071	133	38H
0005433343572	1071	134	39D
0005433343209	1071	135	39F
0005435092172	1071	136	39E
0005433344037	17056	1	1H
0005433344067	17056	2	2A
0005433344065	17056	3	2C
0005435508346	17056	4	2B
0005433344074	17056	5	2F
0005433344072	17056	6	2G
0005433344056	17056	7	3A
0005433344060	17056	8	2H
0005433344024	17056	9	3B
0005433344031	17056	10	4B
0005433344115	17056	11	4A
0005433344063	17056	12	4C
0005433344055	17056	13	4G
0005435508388	17056	14	5A
0005433344076	17056	15	5B
0005433344029	17056	16	5C
0005433159334	17056	17	5F
0005433269774	17056	18	9B
0005435508358	17056	19	9A
0005433344093	17056	20	9H
0005435092112	17056	21	9G
0005435092126	17056	22	11A
0005433344062	17056	23	11H
0005435508329	17056	24	11G
0005433344114	17056	25	12A
0005433344041	17056	26	12E
0005433344116	17056	27	12G
0005433344106	17056	28	12F
0005433344033	17056	29	12H
0005433344100	17056	30	13B
0005433344094	17056	31	13A
0005433344095	17056	32	13D
0005433344105	17056	33	13E
0005433344117	17056	34	13G
0005435508343	17056	35	13F
0005433344086	17056	36	14A
0005433269772	17056	37	13H
0005433344027	17056	38	14B
0005433344113	17056	39	14F
0005433344104	17056	40	14G
0005435508342	17056	41	15B
0005435092095	17056	42	15A
0005435092110	17056	43	15D
0005433344025	17056	44	15G
0005433344085	17056	45	16A
0005433344118	17056	46	16B
0005435508363	17056	47	16E
0005433344030	17056	48	16H
0005433344043	17056	49	17B
0005433344071	17056	50	17A
0005433344077	17056	51	17D
0005433344069	17056	52	17F
0005435092063	17056	53	17G
0005433344054	17056	54	18A
0005433159335	17056	55	18B
0005435092111	17056	56	18D
0005433344046	17056	57	18F
0005433269775	17056	58	18E
0005433344122	17056	59	18H
0005433344110	17056	60	19E
0005433344078	17056	61	19D
0005433344061	17056	62	20A
0005433344066	17056	63	20F
0005433344123	17056	64	20G
0005433344079	17056	65	21A
0005433344026	17056	66	21D
0005433344124	17056	67	21E
0005435092093	17056	68	21F
0005433344039	17056	69	22A
0005435092065	17056	70	21G
0005435092125	17056	71	22B
0005433344097	17056	72	22D
0005433344090	17056	73	22F
0005433344052	17056	74	22E
0005433344068	17056	75	22G
0005433344082	17056	76	23A
0005433344125	17056	77	22H
0005433344053	17056	78	23B
0005433344096	17056	79	23D
0005434445244	17056	80	23G
0005433344028	17056	81	23F
0005433344049	17056	82	23H
0005433344109	17056	83	24B
0005433344087	17056	84	24D
0005433344083	17056	85	24F
0005433344107	17056	86	24G
0005435092071	17056	87	25F
0005435508330	17056	88	25E
0005435092124	17056	89	27A
0005435508379	17056	90	27H
0005433344044	17056	91	27G
0005433344035	17056	92	28A
0005433344038	17056	93	28B
0005433344098	17056	94	28E
0005433344073	17056	95	28D
0005433344101	17056	96	28G
0005433344064	17056	97	28F
0005433344084	17056	98	29B
0005433344070	17056	99	29A
0005433344111	17056	100	29D
0005435092097	17056	101	29H
0005433344045	17056	102	30B
0005435092064	17056	103	30F
0005433159333	17056	104	30G
0005433344057	17056	105	30H
0005433344036	17056	106	31B
0005433344119	17056	107	31A
0005433344099	17056	108	31D
0005433344032	17056	109	32A
0005435092096	17056	110	31H
0005435092099	17056	111	32B
0005435092092	17056	112	32E
0005433344040	17056	113	32D
0005433269771	17056	114	32F
0005433344091	17056	115	32H
0005433344059	17056	116	32G
0005433344047	17056	117	33A
0005433344080	17056	118	33D
0005433344092	17056	119	33H
0005433344081	17056	120	33G
0005433344112	17056	121	34D
0005433344120	17056	122	34B
0005433344088	17056	123	34G
0005433344103	17056	124	34F
0005435092072	17056	125	34H
0005433344034	17056	126	35D
0005433344058	17056	127	35F
0005433344075	17056	128	35G
0005435092101	17056	129	35H
0005433269770	17056	130	36A
0005433344050	17056	131	36E
0005433269773	17056	132	36D
0005433344051	17056	133	36F
0005433344102	17056	134	37E
0005433344048	17056	135	37D
0005435508331	17056	136	37F
0005433344089	17056	137	38A
0005435092100	17056	138	38B
0005433344121	17056	139	38G
0005433159336	17056	140	38F
0005433344042	17056	141	38H
0005433344108	17056	142	39D
0005435508326	17056	143	39F
0005432851916	1343	1	1C
0005432390238	1343	2	1A
0005432390244	1343	3	1D
0005432390263	1343	4	2A
0005432390241	1343	5	2D
0005432851886	1343	6	2C
0005432392028	1343	7	3C
0005432392025	1343	8	4A
0005432851933	1343	9	4D
0005432851913	1343	10	5C
0005432390245	1343	11	5F
0005432390226	1343	12	5D
0005432390265	1343	13	6A
0005432851941	1343	14	6C
0005432390224	1343	15	6B
0005432390221	1343	16	6F
0005432851932	1343	17	6E
0005432390227	1343	18	6D
0005432390234	1343	19	7B
0005432851901	1343	20	7D
0005432851910	1343	21	8A
0005432390247	1343	22	7E
0005432390253	1343	23	8C
0005432390258	1343	24	8B
0005432851903	1343	25	8D
0005432390240	1343	26	8F
0005432851893	1343	27	8E
0005432390219	1343	28	9A
0005432390222	1343	29	9E
0005432392023	1343	30	10A
0005432390260	1343	31	9F
0005432390259	1343	32	10C
0005432392024	1343	33	10B
0005432390220	1343	34	10E
0005432390262	1343	35	10D
0005432390243	1343	36	11A
0005432851894	1343	37	11B
0005432390218	1343	38	11D
0005432390229	1343	39	11C
0005432390261	1343	40	11F
0005432392018	1343	41	12A
0005432390254	1343	42	12C
0005432851895	1343	43	12B
0005432851887	1343	44	12E
0005432851904	1343	45	13A
0005432392022	1343	46	12F
0005432390249	1343	47	13C
0005432390231	1343	48	13B
0005432390252	1343	49	13E
0005432390242	1343	50	13D
0005432851968	1343	51	14A
0005432392020	1343	52	13F
0005432390237	1343	53	14B
0005432390223	1343	54	14D
0005432390232	1343	55	14C
0005432390239	1343	56	14F
0005432390257	1343	57	15B
0005432851912	1343	58	15A
0005432390250	1343	59	15C
0005432851945	1343	60	16A
0005432392021	1343	61	16B
0005432390233	1343	62	16D
0005432851918	1343	63	16C
0005432390235	1343	64	16F
0005432390230	1343	65	17C
0005432392027	1343	66	17D
0005432390246	1343	67	17E
0005432390255	1343	68	17F
0005432851925	1343	69	18D
0005432390228	1343	70	18C
0005432390256	1343	71	18B
0005432851892	1343	72	19A
0005432390248	1343	73	19B
0005432851900	1343	74	19D
0005432390236	1343	75	20A
0005432851942	1343	76	19E
0005432390251	1343	77	20C
0005432851902	1343	78	20D
0005432392019	1343	79	20E
0005432851915	1343	80	21A
0005432851911	1343	81	20F
0005432390264	1343	82	21C
0005432392026	1343	83	21B
0005432390225	1343	84	21D
0005432159905	12785	1	14C
0005432159902	12785	2	1A
0005433989772	12785	3	1F
0005434067742	12785	4	1D
0005434026703	12785	5	2C
0005434067602	12785	6	2A
0005434067601	12785	7	2D
0005434067425	12785	8	3A
0005434067762	12785	9	3D
0005434081805	12785	10	3C
0005434067980	12785	11	3F
0005434067692	12785	12	4B
0005434081910	12785	13	4A
0005434067612	12785	14	4C
0005434067446	12785	15	4D
0005434067617	12785	16	4E
0005434067751	12785	17	4F
0005432433732	12785	18	5A
0005433812925	12785	19	5B
0005434067694	12785	20	5D
0005432159903	12785	21	5F
0005434067388	12785	22	6B
0005434067645	12785	23	6A
0005434067567	12785	24	6C
0005434081900	12785	25	6D
0005434026708	12785	26	6E
0005434081800	12785	27	6F
0005434067540	12785	28	7B
0005434067457	12785	29	7A
0005434067592	12785	30	7E
0005434067785	12785	31	7D
0005434067523	12785	32	7F
0005434067519	12785	33	8A
0005432433731	12785	34	8B
0005432159906	12785	35	8D
0005433989773	12785	36	8C
0005434067688	12785	37	8E
0005433812924	12785	38	9A
0005434067400	12785	39	8F
0005434067401	12785	40	9B
0005434067389	12785	41	9D
0005434081977	12785	42	9C
0005434067693	12785	43	9E
0005434081961	12785	44	10B
0005434081933	12785	45	10D
0005434067591	12785	46	10C
0005434081899	12785	47	10E
0005434081830	12785	48	11A
0005434067481	12785	49	11C
0005434026707	12785	50	11E
0005434067289	12785	51	11F
0005434067720	12785	52	12B
0005432161176	12785	53	12C
0005434067750	12785	54	12E
0005432433735	12785	55	12D
0005434067343	12785	56	12F
0005434081891	12785	57	13B
0005434067169	12785	58	13A
0005434067644	12785	59	13C
0005434067458	12785	60	13E
0005434067482	12785	61	13D
0005434067723	12785	62	13F
0005434067409	12785	63	14A
0005434067671	12785	64	14D
0005434067553	12785	65	14E
0005434067428	12785	66	14F
0005433812923	12785	67	15B
0005434067429	12785	68	15A
0005434067522	12785	69	15C
0005434081823	12785	70	15E
0005434067736	12785	71	15D
0005434081829	12785	72	16A
0005434067629	12785	73	16C
0005434081865	12785	74	16F
0005432433736	12785	75	16E
0005434067616	12785	76	17A
0005434081972	12785	77	17B
0005434081866	12785	78	17C
0005432159904	12785	79	17E
0005434026714	12785	80	17D
0005434067851	12785	81	18A
0005434067764	12785	82	17F
0005434067741	12785	83	18B
0005434067753	12785	84	18C
0005434067857	12785	85	18F
0005434067752	12785	86	18E
0005434067475	12785	87	19A
0005434067531	12785	88	19B
0005434067699	12785	89	19D
0005432161174	12785	90	19E
0005434081801	12785	91	19F
0005434067410	12785	92	20A
0005434067353	12785	93	20C
0005432433733	12785	94	20B
0005434067656	12785	95	20E
0005434067670	12785	96	20D
0005434067763	12785	97	20F
0005432433734	12785	98	21B
0005434081935	12785	99	21A
0005434081828	12785	100	21C
0005434067426	12785	101	21D
0005433989774	12785	102	21E
0005434082049	12785	103	21F
0005434067615	12785	104	22B
0005434067518	12785	105	22C
0005432161175	12785	106	22D
0005434081911	12785	107	22F
0005434081804	12785	108	22E
0005434067856	12785	109	23B
0005434067520	12785	110	23A
0005433989768	12785	111	23D
0005434067679	12785	112	23C
0005434081841	12785	113	23E
0005434067266	12785	114	23F
0005434068236	30658	1	1A
0005434068193	30658	2	1C
0005434068198	30658	3	1D
0005434068191	30658	4	1F
0005434082126	30658	5	2C
0005432186904	30658	6	2D
0005434082116	30658	7	2F
0005434068216	30658	8	3A
0005434068190	30658	9	3C
0005434068215	30658	10	3F
0005434068184	30658	11	3D
0005432150264	30658	12	4B
0005434068213	30658	13	4A
0005434068210	30658	14	4C
0005434068238	30658	15	4D
0005434068201	30658	16	4E
0005434068247	30658	17	4F
0005434068254	30658	18	5B
0005432186903	30658	19	5A
0005432433711	30658	20	5C
0005432150266	30658	21	5D
0005434068218	30658	22	5F
0005434068237	30658	23	5E
0005434082115	30658	24	6A
0005434082121	30658	25	6B
0005433989814	30658	26	6E
0005432433701	30658	27	6D
0005434068189	30658	28	6F
0005434068209	30658	29	7B
0005432150265	30658	30	7A
0005434068202	30658	31	7C
0005434082120	30658	32	7D
0005432433700	30658	33	7F
0005434068222	30658	34	7E
0005434082109	30658	35	8A
0005434082111	30658	36	8B
0005434068242	30658	37	8D
0005434068223	30658	38	8E
0005434068192	30658	39	9A
0005434082122	30658	40	8F
0005434082110	30658	41	9C
0005434068217	30658	42	9D
0005434068214	30658	43	9E
0005434068220	30658	44	9F
0005434068196	30658	45	10B
0005434068248	30658	46	10C
0005434082114	30658	47	10E
0005433989815	30658	48	10D
0005434068208	30658	49	11A
0005434068253	30658	50	11C
0005434068244	30658	51	11B
0005434068186	30658	52	11D
0005434068255	30658	53	11F
0005434068227	30658	54	12A
0005434082131	30658	55	12B
0005434068235	30658	56	12D
0005434068250	30658	57	12C
0005434068241	30658	58	12E
0005434068228	30658	59	13A
0005434068204	30658	60	12F
0005434068239	30658	61	13B
0005434068232	30658	62	13D
0005432150269	30658	63	13C
0005434068185	30658	64	13E
0005432433690	30658	65	13F
0005434082136	30658	66	14B
0005434068200	30658	67	14A
0005434068188	30658	68	14C
0005432186902	30658	69	14D
0005434068243	30658	70	14E
0005434068225	30658	71	14F
0005434068219	30658	72	15B
0005434082129	30658	73	15A
0005434082135	30658	74	15C
0005434068199	30658	75	15D
0005432150268	30658	76	15E
0005434068230	30658	77	16A
0005434082134	30658	78	15F
0005434068234	30658	79	16B
0005434082127	30658	80	16C
0005434068205	30658	81	16D
0005432433689	30658	82	16E
0005434082113	30658	83	17A
0005434068226	30658	84	16F
0005434068183	30658	85	17B
0005434068231	30658	86	17C
0005434068207	30658	87	18A
0005434082112	30658	88	17F
0005434068249	30658	89	18B
0005434068195	30658	90	18C
0005434082124	30658	91	18E
0005434082125	30658	92	18D
0005434068251	30658	93	18F
0005434068212	30658	94	19A
0005434082128	30658	95	19B
0005433989813	30658	96	19D
0005432150267	30658	97	19C
0005432433712	30658	98	19E
0005434068211	30658	99	19F
0005434082132	30658	100	20A
0005434082123	30658	101	20C
0005434068194	30658	102	20B
0005433989816	30658	103	20D
0005434068233	30658	104	20E
0005434082119	30658	105	20F
0005434068245	30658	106	21B
0005434082130	30658	107	21A
0005432150270	30658	108	21C
0005434082118	30658	109	21D
0005434068229	30658	110	21E
0005434082133	30658	111	22A
0005434068221	30658	112	21F
0005434068224	30658	113	22C
0005434068252	30658	114	22B
0005434068240	30658	115	22E
0005434068187	30658	116	22F
0005434082117	30658	117	23A
0005434068206	30658	118	23D
0005434068203	30658	119	23C
0005434068246	30658	120	23E
0005434068197	30658	121	23F
0005433685544	9039	1	1A
0005433685547	9039	2	1C
0005433687731	9039	3	2B
0005433685551	9039	4	3A
0005433685546	9039	5	3B
0005433685550	9039	6	3C
0005433687730	9039	7	3D
0005433687733	9039	8	4C
0005433686658	9039	9	4D
0005433687732	9039	10	5C
0005433686659	9039	11	6D
0005433685549	9039	12	18A
0005433685545	9039	13	18C
0005433686660	9039	14	19A
0005433687729	9039	15	19D
0005433687728	9039	16	20B
0005433686661	9039	17	20D
0005433686662	9039	18	21C
0005433685548	9039	19	21D
0005435766872	5494	1	1B
0005435462575	5494	2	1A
0005435766856	5494	3	1F
0005435462460	5494	4	1G
0005434265198	5494	5	2A
0005434265150	5494	6	1H
0005435462473	5494	7	2C
0005435462683	5494	8	2G
0005435462669	5494	9	3B
0005435462540	5494	10	3A
0005435462472	5494	11	3F
0005435766870	5494	12	4C
0005434265226	5494	13	4G
0005432140528	5494	14	5B
0005435462374	5494	15	5F
0005435766834	5494	16	5G
0005432140532	5494	17	9B
0005435462502	5494	18	9A
0005435722078	5494	19	9H
0005434265200	5494	20	11D
0005435766846	5494	21	11B
0005435766828	5494	22	11E
0005435462594	5494	23	11F
0005435766817	5494	24	11H
0005435766848	5494	25	11G
0005435735181	5494	26	12A
0005435766869	5494	27	12D
0005434265115	5494	28	12E
0005435766823	5494	29	12F
0005433527308	5494	30	12H
0005435766843	5494	31	12G
0005432140534	5494	32	13B
0005435462514	5494	33	13A
0005435462581	5494	34	13D
0005435462422	5494	35	13E
0005434831162	5494	36	13G
0005434265123	5494	37	13F
0005435725647	5494	38	14A
0005433527306	5494	39	14E
0005435462486	5494	40	14D
0005435462467	5494	41	14B
0005435766824	5494	42	14F
0005435462436	5494	43	14G
0005435720834	5494	44	15D
0005435462444	5494	45	15B
0005435462584	5494	46	15E
0005434265223	5494	47	15F
0005432535835	5494	48	15G
0005435766832	5494	49	16A
0005435462526	5494	50	15H
0005435766865	5494	51	16D
0005434265149	5494	52	16B
0005435766818	5494	53	16F
0005435766833	5494	54	16E
0005435462559	5494	55	16G
0005435766850	5494	56	16H
0005435766867	5494	57	17A
0005434265187	5494	58	17D
0005435462539	5494	59	17E
0005435766826	5494	60	17G
0005432535851	5494	61	17F
0005435766836	5494	62	18A
0005435766825	5494	63	18B
0005435462513	5494	64	18D
0005435766845	5494	65	18F
0005434265180	5494	66	18E
0005435462587	5494	67	18G
0005435766853	5494	68	19A
0005435722079	5494	69	19D
0005433527305	5494	70	19F
0005435462549	5494	71	19E
0005435462576	5494	72	19H
0005435725649	5494	73	19G
0005434265179	5494	74	20A
0005435766861	5494	75	20B
0005435462553	5494	76	20E
0005432140533	5494	77	20D
0005434265185	5494	78	20F
0005432535819	5494	79	20G
0005434265201	5494	80	21A
0005433529318	5494	81	20H
0005435766841	5494	82	21D
0005435766829	5494	83	21B
0005434831137	5494	84	21E
0005434265217	5494	85	21H
0005435462314	5494	86	22A
0005434265038	5494	87	22D
0005435462544	5494	88	22B
0005433529317	5494	89	22G
0005432140529	5494	90	22F
0005435735180	5494	91	22H
0005434265222	5494	92	23B
0005435462407	5494	93	23A
0005435725645	5494	94	23D
0005435725646	5494	95	23F
0005435766840	5494	96	23G
0005435462580	5494	97	23H
0005435766842	5494	98	24A
0005434265221	5494	99	24F
0005435766862	5494	100	24G
0005434265124	5494	101	25D
0005435725644	5494	102	24H
0005435766855	5494	103	25F
0005434265225	5494	104	25E
0005435766849	5494	105	27B
0005435766871	5494	106	27D
0005435766819	5494	107	27F
0005435766835	5494	108	27G
0005434265184	5494	109	28A
0005432535852	5494	110	27H
0005432140526	5494	111	28D
0005435462471	5494	112	28B
0005435766852	5494	113	28F
0005435462585	5494	114	28G
0005435725648	5494	115	29A
0005434265188	5494	116	28H
0005435462380	5494	117	29D
0005435462469	5494	118	29B
0005435766830	5494	119	29E
0005433529316	5494	120	29G
0005435766868	5494	121	29F
0005435766859	5494	122	29H
0005435462465	5494	123	30B
0005435462586	5494	124	30F
0005432535833	5494	125	30E
0005435766820	5494	126	30G
0005435462466	5494	127	31A
0005435766827	5494	128	30H
0005435462568	5494	129	31B
0005434831161	5494	130	31E
0005435766837	5494	131	31D
0005432140531	5494	132	31F
0005435766851	5494	133	31H
0005435462508	5494	134	31G
0005435766866	5494	135	32A
0005435766838	5494	136	32D
0005435462643	5494	137	32B
0005435462558	5494	138	32E
0005433529315	5494	139	32H
0005435766847	5494	140	32G
0005435766839	5494	141	33A
0005435766873	5494	142	33B
0005432535824	5494	143	33E
0005435766863	5494	144	33D
0005435766864	5494	145	33F
0005434831138	5494	146	33H
0005435735179	5494	147	33G
0005435462566	5494	148	34A
0005433527307	5494	149	34D
0005434265159	5494	150	34B
0005435462550	5494	151	34E
0005434265171	5494	152	34G
0005435462416	5494	153	34F
0005435766821	5494	154	34H
0005435462567	5494	155	35D
0005435766874	5494	156	35E
0005435766857	5494	157	35H
0005435766854	5494	158	36B
0005435766822	5494	159	36F
0005432140530	5494	160	36E
0005435766816	5494	161	37A
0005435766831	5494	162	36H
0005435462379	5494	163	37D
0005432140527	5494	164	37B
0005433527309	5494	165	37F
0005434265196	5494	166	37H
0005434265219	5494	167	37G
0005435766860	5494	168	38A
0005435766858	5494	169	38B
0005434265029	5494	170	38E
0005435462455	5494	171	38D
0005435462644	5494	172	38G
0005435766844	5494	173	39E
0005435735182	5494	174	39D
0005435462417	5494	175	39F
0005435766416	13443	1	1A
0005434831199	13443	2	1B
0005435766230	13443	3	1F
0005435462829	13443	4	2A
0005435720132	13443	5	2C
0005435766340	13443	6	2B
0005435462817	13443	7	2F
0005435766470	13443	8	2G
0005434265392	13443	9	3F
0005435462828	13443	10	3G
0005435766343	13443	11	4A
0005435725602	13443	12	3H
0005435462806	13443	13	4B
0005435766059	13443	14	4C
0005435766157	13443	15	4G
0005435462831	13443	16	4H
0005435725603	13443	17	5B
0005435462832	13443	18	5C
0005435766424	13443	19	5H
0005435462812	13443	20	9B
0005434265400	13443	21	9G
0005435766255	13443	22	9H
0005435766366	13443	23	11E
0005432194554	13443	24	11H
0005435462814	13443	25	11G
0005435462821	13443	26	12A
0005435462815	13443	27	12B
0005435462808	13443	28	12E
0005435766477	13443	29	12G
0005435766324	13443	30	12F
0005434265394	13443	31	12H
0005435462827	13443	32	13A
0005435723048	13443	33	13D
0005434265406	13443	34	13F
0005435766144	13443	35	14A
0005435766050	13443	36	14D
0005434265390	13443	37	14B
0005435723044	13443	38	14E
0005432194552	13443	39	14H
0005435462818	13443	40	15B
0005435462824	13443	41	15E
0005435462810	13443	42	15D
0005434831202	13443	43	15F
0005434265409	13443	44	16A
0005435766145	13443	45	16E
0005435766460	13443	46	16G
0005435766341	13443	47	16H
0005435766413	13443	48	17B
0005435766154	13443	49	17A
0005435766429	13443	50	17D
0005435766297	13443	51	17F
0005434265396	13443	52	17E
0005435766302	13443	53	17G
0005435462807	13443	54	17H
0005435766187	13443	55	18B
0005435723047	13443	56	18F
0005435766354	13443	57	18E
0005434265391	13443	58	18G
0005434265408	13443	59	19A
0005434265414	13443	60	18H
0005435766136	13443	61	19D
0005434265389	13443	62	19B
0005434831200	13443	63	19F
0005435462822	13443	64	19E
0005435766220	13443	65	20A
0005435766493	13443	66	20B
0005435766108	13443	67	20E
0005435725601	13443	68	20D
0005435766186	13443	69	20G
0005434265405	13443	70	20F
0005435766222	13443	71	21B
0005434831198	13443	72	21A
0005435462802	13443	73	20H
0005434265397	13443	74	21D
0005435723043	13443	75	21E
0005435766135	13443	76	21G
0005434265404	13443	77	21H
0005435766303	13443	78	22A
0005434265411	13443	79	22E
0005435766166	13443	80	22G
0005435766131	13443	81	22H
0005435462835	13443	82	23E
0005435766151	13443	83	23F
0005435766155	13443	84	23H
0005435766352	13443	85	24B
0005435462820	13443	86	24F
0005435462801	13443	87	24G
0005434265393	13443	88	24H
0005435766271	13443	89	25E
0005432535886	13443	90	27D
0005435462803	13443	91	27B
0005434265403	13443	92	27A
0005435462837	13443	93	27F
0005435766459	13443	94	27H
0005435766156	13443	95	27G
0005434265398	13443	96	28B
0005435766415	13443	97	28F
0005435720134	13443	98	28G
0005432535882	13443	99	29B
0005432194553	13443	100	29D
0005435766364	13443	101	29E
0005435720133	13443	102	30D
0005434265413	13443	103	30G
0005435462805	13443	104	30H
0005435462825	13443	105	31B
0005432535885	13443	106	31G
0005435462819	13443	107	32A
0005435766058	13443	108	31H
0005435766474	13443	109	32B
0005435462826	13443	110	32D
0005435766335	13443	111	32F
0005435766420	13443	112	32H
0005435766152	13443	113	32G
0005434265399	13443	114	33A
0005435462816	13443	115	33D
0005435462800	13443	116	33B
0005434265395	13443	117	33F
0005435462804	13443	118	33G
0005435766419	13443	119	34A
0005435462830	13443	120	34B
0005435462834	13443	121	34E
0005435462813	13443	122	34G
0005435766393	13443	123	34F
0005435766325	13443	124	35A
0005434265401	13443	125	34H
0005435462811	13443	126	35B
0005432535883	13443	127	35D
0005435462836	13443	128	35E
0005434265412	13443	129	35H
0005432535884	13443	130	35G
0005434265410	13443	131	36A
0005435462823	13443	132	36D
0005435766203	13443	133	36E
0005435766356	13443	134	36G
0005435462833	13443	135	37A
0005434265415	13443	136	37D
0005434265402	13443	137	37F
0005435766476	13443	138	37E
0005435766355	13443	139	37H
0005435766117	13443	140	37G
0005435462809	13443	141	38A
0005435766296	13443	142	38E
0005435766256	13443	143	38D
0005434831201	13443	144	38G
0005435766609	13443	145	38F
0005434265407	13443	146	38H
0005435766204	13443	147	39D
0005434604913	18752	1	1A
0005434604882	18752	2	1B
0005434513603	18752	3	2A
0005434514992	18752	4	3A
0005434514991	18752	5	2B
0005434513605	18752	6	3B
0005434604881	18752	7	4A
0005434604914	18752	8	4B
0005434513604	18752	9	5A
0005434514993	18752	10	6A
0005434604893	18752	11	6B
0005434514980	19156	1	2B
0005434514977	19156	2	4B
0005434514976	19156	3	5B
0005435844290	4112	1	1A
0005432649464	4112	2	1F
0005432632806	4112	3	2D
0005435844314	4112	4	2F
0005435844319	4112	5	3F
0005435844333	4112	6	4A
0005432649465	4112	7	4D
0005432632811	4112	8	5A
0005432632815	4112	9	5E
0005432649457	4112	10	6A
0005435846245	4112	11	6C
0005432649460	4112	12	6D
0005432632814	4112	13	7D
0005435846267	4112	14	8A
0005432649468	4112	15	8E
0005432632807	4112	16	8F
0005432632813	4112	17	9E
0005432649461	4112	18	9F
0005432649462	4112	19	10A
0005432649458	4112	20	10D
0005432632812	4112	21	10E
0005432632810	4112	22	11C
0005432632805	4112	23	11E
0005435846262	4112	24	12D
0005435844334	4112	25	12E
0005435844287	4112	26	12F
0005432649467	4112	27	13A
0005435844326	4112	28	14C
0005435846257	4112	29	14E
0005435844332	4112	30	14F
0005432649463	4112	31	15A
0005435844286	4112	32	15D
0005435846250	4112	33	15E
0005432632816	4112	34	16A
0005432632817	4112	35	16C
0005435844323	4112	36	17D
0005435844320	4112	37	17F
0005435844330	4112	38	18A
0005432632808	4112	39	18D
0005432649459	4112	40	18E
0005432632809	4112	41	19A
0005432649466	4112	42	20D
0005435844331	4112	43	20E
0005435844328	4112	44	20F
0005433285419	1839	1	1A
0005433008632	1839	2	1C
0005433008806	1839	3	1F
0005433285432	1839	4	2A
0005433008684	1839	5	2D
0005433285227	1839	6	2F
0005433285357	1839	7	3A
0005433008637	1839	8	3C
0005433008764	1839	9	3D
0005433008631	1839	10	3F
0005433285362	1839	11	4F
0005433285284	1839	12	5A
0005433285329	1839	13	5C
0005433008865	1839	14	6A
0005433285339	1839	15	5F
0005433008736	1839	16	6D
0005433008743	1839	17	6E
0005433810583	1839	18	6F
0005433285296	1839	19	7C
0005433008636	1839	20	7D
0005433285420	1839	21	7E
0005433008868	1839	22	7F
0005433285378	1839	23	8A
0005433008691	1839	24	8D
0005433008670	1839	25	8E
0005433008804	1839	26	8F
0005433008722	1839	27	9A
0005433008690	1839	28	9D
0005433285295	1839	29	9F
0005433008703	1839	30	10A
0005433008840	1839	31	10C
0005433285314	1839	32	10D
0005433285285	1839	33	10E
0005433285377	1839	34	10F
0005433285408	1839	35	11A
0005433285330	1839	36	11D
0005433008725	1839	37	11E
0005433810585	1839	38	11F
0005433285369	1839	39	12A
0005433285384	1839	40	12C
0005433008813	1839	41	12D
0005433008671	1839	42	13A
0005433285358	1839	43	13D
0005433008694	1839	44	13E
0005433008649	1839	45	13F
0005433008852	1839	46	14A
0005433285283	1839	47	14C
0005433008693	1839	48	14D
0005433285361	1839	49	14E
0005432295907	1839	50	14F
0005433285379	1839	51	15A
0005433008716	1839	52	15C
0005433008426	1839	53	15D
0005433285430	1839	54	15E
0005433008765	1839	55	15F
0005433008818	1839	56	16C
0005433008250	1839	57	16D
0005433008763	1839	58	16E
0005433008677	1839	59	16F
0005433008807	1839	60	17A
0005433008781	1839	61	17C
0005433810584	1839	62	17D
0005433285340	1839	63	17F
0005433008661	1839	64	17E
0005433008697	1839	65	18C
0005433008866	1839	66	18D
0005433285415	1839	67	18E
0005432295906	1839	68	19A
0005433008401	1839	69	19C
0005433008704	1839	70	19E
0005433008805	1839	71	19F
0005433008747	1839	72	20A
0005433285350	1839	73	20C
0005433008803	1839	74	20E
0005433008802	1839	75	20F
0005433285583	22571	1	1C
0005433009043	22571	2	1D
0005433285597	22571	3	1F
0005433285612	22571	4	2A
0005433009070	22571	5	2C
0005433009045	22571	6	2D
0005433285605	22571	7	2F
0005433009047	22571	8	3A
0005433285598	22571	9	3C
0005433285599	22571	10	3D
0005433285596	22571	11	3F
0005433009038	22571	12	4C
0005433009029	22571	13	4E
0005433285585	22571	14	4F
0005433285606	22571	15	5A
0005433810521	22571	16	5C
0005433285610	22571	17	5E
0005433285604	22571	18	5F
0005433009034	22571	19	6A
0005433009058	22571	20	6C
0005433009035	22571	21	6D
0005433285588	22571	22	6E
0005433285584	22571	23	6F
0005433009044	22571	24	7C
0005433009055	22571	25	7D
0005433009068	22571	26	7F
0005433009031	22571	27	7E
0005433009054	22571	28	8A
0005433009046	22571	29	8C
0005433009041	22571	30	8D
0005433009032	22571	31	8F
0005433009056	22571	32	9A
0005433009057	22571	33	9D
0005433285589	22571	34	9E
0005433009061	22571	35	9F
0005433009039	22571	36	10A
0005433009030	22571	37	10C
0005433810529	22571	38	10D
0005433009059	22571	39	10E
0005433810526	22571	40	10F
0005433009051	22571	41	11A
0005433009065	22571	42	11C
0005433810534	22571	43	11D
0005433009071	22571	44	11E
0005433285611	22571	45	11F
0005433009072	22571	46	12A
0005433285591	22571	47	12C
0005433285594	22571	48	12D
0005433285613	22571	49	12E
0005433009073	22571	50	12F
0005433285587	22571	51	13A
0005433285590	22571	52	13C
0005433009048	22571	53	13D
0005433285600	22571	54	13E
0005433009069	22571	55	13F
0005433009053	22571	56	14C
0005433009064	22571	57	14D
0005433285608	22571	58	14E
0005433009066	22571	59	14F
0005433285592	22571	60	15A
0005433285601	22571	61	15C
0005433285582	22571	62	15D
0005433285607	22571	63	15E
0005433009042	22571	64	15F
0005433009037	22571	65	16A
0005433009063	22571	66	16C
0005433009052	22571	67	16D
0005433810533	22571	68	16E
0005433009060	22571	69	17A
0005433285602	22571	70	17C
0005433009040	22571	71	17D
0005433285603	22571	72	17E
0005433285586	22571	73	17F
0005433009033	22571	74	18A
0005433009062	22571	75	18D
0005433285593	22571	76	18E
0005433009036	22571	77	19A
0005433285609	22571	78	19C
0005433009067	22571	79	19D
0005433009050	22571	80	19E
0005433009028	22571	81	20C
0005433285595	22571	82	20E
0005433009049	22571	83	20F
0005432751527	12278	1	3A
0005432751533	12278	2	5E
0005432751524	12278	3	5F
0005432755051	12278	4	6C
0005432751498	12278	5	6D
0005432751537	12278	6	6E
0005432751525	12278	7	7D
0005432755054	12278	8	7F
0005434152806	12278	9	8C
0005434152810	12278	10	8D
0005432755059	12278	11	8F
0005434152803	12278	12	9A
0005432755067	12278	13	9C
0005434152807	12278	14	9E
0005432751516	12278	15	10D
0005432755086	12278	16	10E
0005432755071	12278	17	11C
0005434152811	12278	18	11D
0005434152813	12278	19	11E
0005434152805	12278	20	12A
0005432751523	12278	21	12F
0005432755060	12278	22	13A
0005434152809	12278	23	14D
0005432755080	12278	24	16A
0005434152812	12278	25	17A
0005432751518	12278	26	17C
0005434152808	12278	27	18C
0005432755066	12278	28	18E
0005434152804	12278	29	18F
0005432751519	12278	30	19D
0005432755056	12278	31	20A
0005432755068	12278	32	20D
0005435282516	5584	1	1C
0005433847300	5584	2	1A
0005433847329	5584	3	1F
0005433847293	5584	4	1D
0005433847325	5584	5	2C
0005433815430	5584	6	2A
0005435282431	5584	7	2F
0005434173519	5584	8	2D
0005433847295	5584	9	3D
0005435282448	5584	10	3F
0005433847310	5584	11	4D
0005432081577	5584	12	4C
0005434173509	5584	13	4A
0005433847314	5584	14	4F
0005433847298	5584	15	5C
0005435282568	5584	16	5A
0005432081576	5584	17	5F
0005432081574	5584	18	5D
0005433847331	5584	19	6A
0005435282574	5584	20	6C
0005433847278	5584	21	6B
0005434173510	5584	22	6E
0005433847303	5584	23	6D
0005435282575	5584	24	7A
0005433847334	5584	25	6F
0005433847289	5584	26	7C
0005434173520	5584	27	7E
0005433847294	5584	28	7D
0005435282569	5584	29	7F
0005433847309	5584	30	8B
0005435282565	5584	31	8A
0005433847319	5584	32	8D
0005433847318	5584	33	8C
0005433847288	5584	34	8F
0005435282506	5584	35	8E
0005433847296	5584	36	9B
0005433847297	5584	37	9A
0005433847336	5584	38	9C
0005433847282	5584	39	9F
0005433847279	5584	40	9E
0005433847328	5584	41	9D
0005435282498	5584	42	10A
0005435282582	5584	43	10C
0005433847308	5584	44	10B
0005433847312	5584	45	10D
0005433847323	5584	46	10F
0005435282447	5584	47	11B
0005435282544	5584	48	11A
0005433847292	5584	49	11D
0005435282509	5584	50	11C
0005435282588	5584	51	11F
0005433847291	5584	52	12B
0005433847284	5584	53	12A
0005435282545	5584	54	12D
0005433847320	5584	55	12C
0005433847326	5584	56	12E
0005435282507	5584	57	13A
0005435282508	5584	58	12F
0005433847333	5584	59	13C
0005435282566	5584	60	13B
0005435282584	5584	61	13E
0005433847305	5584	62	13D
0005433847285	5584	63	14A
0005433847324	5584	64	13F
0005432081573	5584	65	14C
0005433815431	5584	66	14B
0005433847301	5584	67	14F
0005433847302	5584	68	14E
0005433847283	5584	69	15A
0005433847321	5584	70	15D
0005433847330	5584	71	15C
0005433847337	5584	72	15E
0005433847281	5584	73	16A
0005435282512	5584	74	15F
0005433847306	5584	75	16C
0005435282519	5584	76	16B
0005433815433	5584	77	16E
0005433847290	5584	78	16D
0005433815429	5584	79	16F
0005433847332	5584	80	17B
0005433847307	5584	81	17A
0005434173511	5584	82	17D
0005433847322	5584	83	17C
0005433847299	5584	84	17F
0005435282600	5584	85	17E
0005433847313	5584	86	18B
0005433847286	5584	87	18A
0005433847335	5584	88	18C
0005432081572	5584	89	18E
0005433847304	5584	90	18D
0005435282586	5584	91	18F
0005432081575	5584	92	19B
0005432081578	5584	93	19E
0005433847327	5584	94	19D
0005433847311	5584	95	19F
0005433847280	5584	96	20B
0005433847287	5584	97	20A
0005435282585	5584	98	20D
0005433847317	5584	99	20C
0005433815432	5584	100	20F
0005433847315	5584	101	20E
0005435282587	5584	102	21B
0005433847277	5584	103	21C
0005435282435	5584	104	21E
0005435282480	5584	105	21D
0005433847316	5584	106	21F
0005433846690	13871	1	1C
0005433846801	13871	2	1D
0005433846854	13871	3	2A
0005435282753	13871	4	2D
0005433846768	13871	5	3A
0005435282761	13871	6	2F
0005435282763	13871	7	3D
0005433846723	13871	8	3F
0005433846712	13871	9	4C
0005433847014	13871	10	4F
0005433846785	13871	11	4D
0005433847001	13871	12	5C
0005435282759	13871	13	5A
0005433846683	13871	14	5F
0005434173563	13871	15	5D
0005432003732	13871	16	6B
0005435282766	13871	17	6A
0005433846514	13871	18	6C
0005435282769	13871	19	6F
0005433846665	13871	20	7A
0005433815377	13871	21	7C
0005433846666	13871	22	7E
0005433846933	13871	23	8A
0005433847047	13871	24	7F
0005434173561	13871	25	8C
0005435282755	13871	26	8E
0005433846944	13871	27	8F
0005433846733	13871	28	9B
0005435282760	13871	29	9A
0005433846832	13871	30	9E
0005434173560	13871	31	10B
0005434173562	13871	32	10A
0005432003733	13871	33	9F
0005433846765	13871	34	10C
0005435282768	13871	35	11A
0005433846713	13871	36	11B
0005435282770	13871	37	11E
0005433815404	13871	38	11D
0005433846938	13871	39	12B
0005435282765	13871	40	12A
0005433846830	13871	41	12E
0005433846873	13871	42	12D
0005435282762	13871	43	13A
0005433846831	13871	44	12F
0005433846796	13871	45	13C
0005433846729	13871	46	13E
0005433847000	13871	47	13D
0005435282758	13871	48	14A
0005433846755	13871	49	13F
0005433846937	13871	50	14C
0005435282756	13871	51	14E
0005433846795	13871	52	14D
0005433846888	13871	53	14F
0005433847079	13871	54	15C
0005433846689	13871	55	15E
0005433846924	13871	56	15D
0005432003731	13871	57	16A
0005433815376	13871	58	15F
0005433846900	13871	59	16C
0005435282754	13871	60	16B
0005435282757	13871	61	16D
0005435282752	13871	62	17A
0005433846646	13871	63	17B
0005433846703	13871	64	17C
0005433846928	13871	65	17F
0005433847037	13871	66	17E
0005432003734	13871	67	18B
0005433847095	13871	68	18D
0005433846653	13871	69	19A
0005433846767	13871	70	18F
0005433846923	13871	71	19B
0005433846973	13871	72	19E
0005435282764	13871	73	19D
0005433846784	13871	74	19F
0005433847066	13871	75	20B
0005433846939	13871	76	20A
0005433846645	13871	77	20C
0005433846475	13871	78	20F
0005433846841	13871	79	20E
0005433847078	13871	80	21E
0005433846684	13871	81	21D
0005435282767	13871	82	21F
0005435332339	7848	1	1A
0005434620800	7848	2	1B
0005434620809	7848	3	1D
0005434620792	7848	4	2A
0005434620791	7848	5	3A
0005434620795	7848	6	3B
0005434620803	7848	7	3D
0005435332370	7848	8	4A
0005434620794	7848	9	4B
0005434620805	7848	10	5A
0005435332349	7848	11	5B
0005434620810	7848	12	5D
0005432112539	7848	13	6A
0005434620798	7848	14	6B
0005432112538	7848	15	7B
0005434620808	7848	16	7C
0005434620796	7848	17	18B
0005434620799	7848	18	18C
0005434620793	7848	19	18D
0005434620802	7848	20	19A
0005435332350	7848	21	19C
0005434620806	7848	22	20B
0005434620801	7848	23	20D
0005434620807	7848	24	21A
0005434620797	7848	25	22A
0005434620804	7848	26	23B
0005434620633	32968	1	1A
0005435332443	32968	2	1C
0005434620675	32968	3	1D
0005435332444	32968	4	2A
0005434620625	32968	5	2B
0005435332437	32968	6	3A
0005435332435	32968	7	3C
0005434620638	32968	8	3D
0005434620624	32968	9	4A
0005435332440	32968	10	4B
0005434620613	32968	11	4C
0005434620590	32968	12	5A
0005435332441	32968	13	5C
0005434620701	32968	14	6A
0005434620639	32968	15	6B
0005434620626	32968	16	6D
0005434620674	32968	17	7B
0005434620678	32968	18	7C
0005435332436	32968	19	18A
0005435332438	32968	20	18C
0005435332442	32968	21	19B
0005434620566	32968	22	19D
0005434620571	32968	23	20B
0005435332439	32968	24	21A
0005434620634	32968	25	21B
0005434620589	32968	26	22B
0005434620700	32968	27	23A
0005435785703	4275	1	1A
0005434994118	4275	2	1D
0005435785711	4275	3	1F
0005435785717	4275	4	2C
0005434994119	4275	5	2F
0005435785701	4275	6	3A
0005435785716	4275	7	3D
0005435785715	4275	8	4A
0005435785699	4275	9	4C
0005435918664	4275	10	4E
0005435785686	4275	11	5C
0005435785696	4275	12	5D
0005435785718	4275	13	6D
0005435785708	4275	14	6F
0005432190667	4275	15	7A
0005435785688	4275	16	7C
0005434994116	4275	17	7D
0005435785700	4275	18	8A
0005435785719	4275	19	8C
0005435785694	4275	20	8E
0005435918666	4275	21	8F
0005435785712	4275	22	9C
0005435918665	4275	23	9E
0005435785692	4275	24	9F
0005435785704	4275	25	10A
0005435937401	4275	26	10C
0005435785697	4275	27	10D
0005435785690	4275	28	11F
0005435785705	4275	29	12A
0005435785695	4275	30	12C
0005435785689	4275	31	12E
0005435937393	4275	32	12F
0005435785693	4275	33	13A
0005435787375	4275	34	13D
0005434994117	4275	35	13E
0005435918675	4275	36	14D
0005435937390	4275	37	14E
0005432190669	4275	38	14F
0005434994123	4275	39	15A
0005435785707	4275	40	15C
0005435785702	4275	41	15D
0005432190668	4275	42	15F
0005435937392	4275	43	16A
0005435785706	4275	44	16D
0005434994122	4275	45	17A
0005435785691	4275	46	17C
0005435785687	4275	47	17D
0005435787376	4275	48	17E
0005435785714	4275	49	17F
0005435785713	4275	50	18A
0005435785710	4275	51	18C
0005435918667	4275	52	18D
0005435785685	4275	53	18F
0005434994115	4275	54	19C
0005435918647	4275	55	19E
0005434994124	4275	56	19F
0005435785709	4275	57	20A
0005435785698	4275	58	20C
0005434994121	4275	59	20D
0005434994120	4275	60	20F
0005435785270	27275	1	1D
0005435785269	27275	2	2C
0005435785453	27275	3	2D
0005435785435	27275	4	2F
0005435785350	27275	5	3D
0005435785366	27275	6	3F
0005435785365	27275	7	4A
0005435785249	27275	8	4C
0005435785220	27275	9	4E
0005435918704	27275	10	4F
0005435785380	27275	11	5C
0005435785379	27275	12	5E
0005435785360	27275	13	5F
0005435785323	27275	14	6C
0005435785367	27275	15	6D
0005435937425	27275	16	6E
0005435937428	27275	17	7E
0005435785250	27275	18	8C
0005435785356	27275	19	8D
0005435785273	27275	20	9C
0005432195712	27275	21	9D
0005434994045	27275	22	9F
0005435937420	27275	23	10A
0005435937423	27275	24	10C
0005435937426	27275	25	10E
0005435785355	27275	26	10F
0005432195713	27275	27	11D
0005435785284	27275	28	11E
0005435937418	27275	29	11F
0005435785436	27275	30	12A
0005435785353	27275	31	12D
0005434994026	27275	32	12E
0005434994037	27275	33	12F
0005435937422	27275	34	13A
0005434994001	27275	35	13D
0005434994042	27275	36	13F
0005435785299	27275	37	14A
0005434994040	27275	38	14D
0005435937427	27275	39	14E
0005435937419	27275	40	14F
0005435785361	27275	41	15A
0005435918705	27275	42	15C
0005435937424	27275	43	15F
0005435785454	27275	44	16A
0005435787356	27275	45	16C
0005435785318	27275	46	16E
0005435918702	27275	47	17C
0005435937421	27275	48	17E
0005434994062	27275	49	17F
0005435785432	27275	50	18A
0005435785274	27275	51	18C
0005435785467	27275	52	18E
0005435785288	27275	53	19C
0005435785354	27275	54	19E
0005435918703	27275	55	19F
0005435785193	27275	56	20A
0005434994046	27275	57	20D
0005435785344	27275	58	20E
0005432146218	19854	1	20B
0005434082147	4749	1	1B
0005432460370	4749	2	1F
0005432571358	4749	3	1C
0005432568257	4749	4	1H
0005432568228	4749	5	1G
0005432568263	4749	6	2A
0005432568243	4749	7	2B
0005432460373	4749	8	2F
0005432460379	4749	9	2G
0005432460356	4749	10	2H
0005432460361	4749	11	3B
0005434082157	4749	12	3F
0005434082154	4749	13	3C
0005432460365	4749	14	3G
0005432460354	4749	15	3H
0005432460369	4749	16	4B
0005432460398	4749	17	4C
0005432568274	4749	18	4G
0005432460359	4749	19	5A
0005433726127	4749	20	4H
0005432568242	4749	21	5B
0005432186906	4749	22	5C
0005432460392	4749	23	5H
0005432460376	4749	24	5G
0005432568217	4749	25	9B
0005432568221	4749	26	9A
0005432460364	4749	27	9H
0005434082156	4749	28	11A
0005432568254	4749	29	11D
0005432460378	4749	30	11B
0005432568267	4749	31	11G
0005432186905	4749	32	11F
0005432460355	4749	33	11H
0005432568216	4749	34	12E
0005434082140	4749	35	12F
0005432460395	4749	36	12H
0005432568234	4749	37	12G
0005432568239	4749	38	13B
0005432568235	4749	39	13A
0005433726128	4749	40	13D
0005434082138	4749	41	13E
0005432568253	4749	42	13F
0005433452761	4749	43	14A
0005432568215	4749	44	13H
0005432460367	4749	45	14B
0005432460384	4749	46	14F
0005432568250	4749	47	14E
0005432568255	4749	48	14G
0005432568222	4749	49	15B
0005434082155	4749	50	15F
0005432460352	4749	51	15H
0005432568270	4749	52	15G
0005432568219	4749	53	16B
0005432568245	4749	54	16D
0005432568276	4749	55	16F
0005433726129	4749	56	16H
0005432460388	4749	57	16G
0005434082153	4749	58	17B
0005432568237	4749	59	17A
0005434082139	4749	60	17E
0005434082150	4749	61	17D
0005434082152	4749	62	17G
0005432568258	4749	63	18F
0005432460397	4749	64	19A
0005434082143	4749	65	18H
0005432568256	4749	66	19B
0005432568266	4749	67	19D
0005432568248	4749	68	19H
0005432460371	4749	69	19G
0005432568262	4749	70	20A
0005434082144	4749	71	20D
0005432568260	4749	72	20E
0005432568244	4749	73	20F
0005432460368	4749	74	20G
0005432568268	4749	75	21A
0005432568269	4749	76	21D
0005432460385	4749	77	21E
0005434082142	4749	78	21G
0005432460389	4749	79	21F
0005432460362	4749	80	21H
0005432170456	4749	81	22B
0005432170453	4749	82	22A
0005432568261	4749	83	22E
0005432571361	4749	84	22H
0005432568251	4749	85	23B
0005432568249	4749	86	23A
0005432170457	4749	87	23D
0005432568226	4749	88	23E
0005432568227	4749	89	23F
0005432460390	4749	90	23H
0005432460350	4749	91	24D
0005432460380	4749	92	24F
0005432186909	4749	93	24E
0005432460377	4749	94	24G
0005432460394	4749	95	25D
0005432568273	4749	96	24H
0005432170458	4749	97	25E
0005432460382	4749	98	27A
0005432460396	4749	99	25F
0005432568218	4749	100	27B
0005432170459	4749	101	27D
0005432568264	4749	102	27F
0005432460351	4749	103	27E
0005432460348	4749	104	27H
0005432568240	4749	105	28B
0005434082148	4749	106	28D
0005432568246	4749	107	28F
0005434082151	4749	108	28G
0005432460381	4749	109	29A
0005432460372	4749	110	28H
0005432568247	4749	111	29D
0005432568275	4749	112	29B
0005432460374	4749	113	29F
0005432568259	4749	114	29E
0005432568225	4749	115	29H
0005432568224	4749	116	30F
0005432460383	4749	117	30E
0005432460387	4749	118	30H
0005432460375	4749	119	30G
0005433451638	4749	120	31B
0005432568272	4749	121	31D
0005432568233	4749	122	31E
0005432186908	4749	123	32A
0005432460393	4749	124	32B
0005432568220	4749	125	32D
0005432460391	4749	126	32F
0005432568241	4749	127	32H
0005432568230	4749	128	33A
0005432460349	4749	129	33D
0005432568229	4749	130	33B
0005432460363	4749	131	33E
0005432568238	4749	132	33G
0005434082146	4749	133	33F
0005432568214	4749	134	34A
0005432460360	4749	135	34D
0005434082141	4749	136	34E
0005434082145	4749	137	34G
0005432170455	4749	138	34F
0005434082149	4749	139	35B
0005432568252	4749	140	35E
0005434082137	4749	141	35D
0005432460358	4749	142	35G
0005432460347	4749	143	36A
0005432460366	4749	144	35H
0005432568223	4749	145	36B
0005432460353	4749	146	36F
0005432568232	4749	147	36E
0005432186907	4749	148	36H
0005432568271	4749	149	36G
0005433451639	4749	150	37A
0005433726126	4749	151	37D
0005432460357	4749	152	37H
0005433452760	4749	153	37G
0005432460346	4749	154	38A
0005432571360	4749	155	38D
0005432568231	4749	156	38B
0005432571359	4749	157	38E
0005432568236	4749	158	38H
0005432568265	4749	159	39D
0005432460386	4749	160	39F
0005432170454	4749	161	39E
0005432567899	30567	1	1C
0005433454886	30567	2	1F
0005432567898	30567	3	1G
0005432567978	30567	4	2C
0005432161174	30567	5	2B
0005432567584	30567	6	2H
0005432567682	30567	7	2G
0005432567494	30567	8	3A
0005433452748	30567	9	3B
0005432460094	30567	10	3G
0005434081977	30567	11	3F
0005432213644	30567	12	3H
0005432459878	30567	13	4B
0005432459966	30567	14	4F
0005432567661	30567	15	5C
0005432567512	30567	16	5F
0005432567829	30567	17	9H
0005434081828	30567	18	9G
0005434081823	30567	19	11A
0005433452738	30567	20	11B
0005434081800	30567	21	11E
0005432459986	30567	22	11D
0005432459870	30567	23	11F
0005434081830	30567	24	11H
0005432459813	30567	25	11G
0005432567947	30567	26	12A
0005432460049	30567	27	12B
0005432567727	30567	28	12E
0005432460030	30567	29	12D
0005432459836	30567	30	12G
0005432567931	30567	31	12F
0005432567511	30567	32	13A
0005432459976	30567	33	13D
0005432567600	30567	34	13E
0005432459974	30567	35	13F
0005432460029	30567	36	13H
0005432460018	30567	37	14B
0005433452739	30567	38	14A
0005432567716	30567	39	14E
0005432568119	30567	40	14D
0005432567603	30567	41	14F
0005432459678	30567	42	15A
0005432460020	30567	43	14H
0005432459965	30567	44	15B
0005432567466	30567	45	15E
0005432567967	30567	46	15D
0005432460167	30567	47	15G
0005432567825	30567	48	15F
0005432567719	30567	49	15H
0005434081933	30567	50	16B
0005432567847	30567	51	16A
0005432213645	30567	52	16D
0005432459791	30567	53	16E
0005432459945	30567	54	17B
0005432459924	30567	55	17A
0005432459985	30567	56	17D
0005434081841	30567	57	17F
0005434081910	30567	58	17E
0005432459862	30567	59	17G
0005434081891	30567	60	17H
0005432567884	30567	61	18D
0005432567764	30567	62	18B
0005432459696	30567	63	18E
0005434081935	30567	64	18G
0005432567937	30567	65	19A
0005432567597	30567	66	19B
0005432460086	30567	67	19E
0005432567907	30567	68	19D
0005434081972	30567	69	19F
0005432460044	30567	70	19H
0005432460048	30567	71	20A
0005434559092	30567	72	20B
0005432459977	30567	73	20E
0005432567639	30567	74	20F
0005432567588	30567	75	20H
0005432567601	30567	76	20G
0005432567989	30567	77	21D
0005432459900	30567	78	21E
0005432459956	30567	79	21F
0005432567809	30567	80	21H
0005434081804	30567	81	21G
0005432567676	30567	82	22A
0005432567763	30567	83	22F
0005434081866	30567	84	22E
0005432567674	30567	85	23A
0005432567589	30567	86	23B
0005432567726	30567	87	23F
0005432459954	30567	88	23E
0005434559094	30567	89	23G
0005434081899	30567	90	23H
0005432459744	30567	91	24B
0005432460131	30567	92	24E
0005432567999	30567	93	24D
0005432567677	30567	94	24F
0005432567754	30567	95	24G
0005432460042	30567	96	25E
0005434082049	30567	97	25D
0005434559090	30567	98	27A
0005434081911	30567	99	25F
0005432460064	30567	100	27B
0005432571325	30567	101	27E
0005434081961	30567	102	27D
0005432459875	30567	103	27F
0005432161176	30567	104	28D
0005434081805	30567	105	28B
0005432567507	30567	106	28E
0005432567982	30567	107	28F
0005432568054	30567	108	28H
0005432459967	30567	109	29A
0005432567596	30567	110	29B
0005432459891	30567	111	29D
0005432460058	30567	112	29F
0005432567970	30567	113	29H
0005432568120	30567	114	30A
0005432567846	30567	115	30D
0005434559091	30567	116	30B
0005432460108	30567	117	30E
0005432567666	30567	118	30G
0005432567969	30567	119	31A
0005432459933	30567	120	30H
0005432567746	30567	121	31B
0005432567948	30567	122	31D
0005432459841	30567	123	31F
0005432459788	30567	124	31E
0005432459890	30567	125	31G
0005432567883	30567	126	32A
0005434559093	30567	127	31H
0005432567558	30567	128	32B
0005432459946	30567	129	32D
0005432567675	30567	130	32E
0005432567745	30567	131	32G
0005434559088	30567	132	33A
0005432571326	30567	133	33B
0005432161175	30567	134	33E
0005432567772	30567	135	33H
0005432460050	30567	136	33G
0005432571337	30567	137	34B
0005432568129	30567	138	34A
0005432459932	30567	139	34E
0005432460043	30567	140	34G
0005432459802	30567	141	35B
0005434081801	30567	142	35A
0005434081900	30567	143	35D
0005432567681	30567	144	35E
0005432567741	30567	145	35G
0005432459889	30567	146	35F
0005432567649	30567	147	35H
0005434559089	30567	148	36A
0005432567998	30567	149	36E
0005432567767	30567	150	36D
0005432567766	30567	151	37A
0005433454885	30567	152	36H
0005432460024	30567	153	37B
0005432460085	30567	154	37F
0005434081865	30567	155	37G
0005432459955	30567	156	38A
0005434081829	30567	157	38B
0005432460021	30567	158	38E
0005432567640	30567	159	38G
0005434559095	30567	160	38H
0005432567765	30567	161	39D
0005432567650	30567	162	39F
0005435722079	13585	1	1A
0005435720834	13585	2	1B
0005435722078	13585	3	6B
0005435722055	21129	1	3B
0005435722064	21129	2	5A
0005432295906	22756	1	20D
0005432295907	22756	2	21A
0005435097296	11105	1	1A
0005433344159	11105	2	1C
0005435508381	11105	3	1F
0005435097290	11105	4	1D
0005435380299	11105	5	2A
0005433344187	11105	6	2D
0005433344158	11105	7	2C
0005433344211	11105	8	3A
0005433344213	11105	9	2F
0005433344154	11105	10	3C
0005433344184	11105	11	3F
0005435097294	11105	12	3D
0005433344139	11105	13	4A
0005433344167	11105	14	4C
0005433344149	11105	15	4B
0005433344221	11105	16	4D
0005433344190	11105	17	4E
0005433344174	11105	18	4F
0005433344150	11105	19	5A
0005433344166	11105	20	5C
0005433344170	11105	21	5B
0005433344173	11105	22	5D
0005435380293	11105	23	5F
0005433344160	11105	24	5E
0005435508323	11105	25	6A
0005433344165	11105	26	6B
0005433344194	11105	27	6C
0005433344207	11105	28	6E
0005433344128	11105	29	7A
0005433344185	11105	30	6F
0005433344140	11105	31	7B
0005433344217	11105	32	7C
0005433344195	11105	33	7D
0005433344176	11105	34	7E
0005433344156	11105	35	7F
0005433344151	11105	36	8B
0005433344218	11105	37	8A
0005433344148	11105	38	8C
0005433344164	11105	39	8E
0005433344191	11105	40	8D
0005435097297	11105	41	8F
0005433344152	11105	42	9A
0005433344141	11105	43	9B
0005433344223	11105	44	9D
0005433344157	11105	45	9C
0005435380310	11105	46	9F
0005433344198	11105	47	9E
0005433344210	11105	48	10B
0005435508391	11105	49	10C
0005433344196	11105	50	10D
0005433344203	11105	51	11A
0005433344199	11105	52	10E
0005433344132	11105	53	11B
0005433344131	11105	54	11D
0005433344143	11105	55	11C
0005433344126	11105	56	11E
0005435508374	11105	57	11F
0005435508398	11105	58	12B
0005433344145	11105	59	12A
0005435508385	11105	60	12D
0005433344193	11105	61	12C
0005433344227	11105	62	12E
0005433344133	11105	63	12F
0005435097299	11105	64	13A
0005433344169	11105	65	13B
0005433344208	11105	66	13D
0005433344171	11105	67	13C
0005435097291	11105	68	13E
0005435508354	11105	69	13F
0005433344183	11105	70	14A
0005433344201	11105	71	14C
0005433344212	11105	72	14B
0005433344197	11105	73	14D
0005433344129	11105	74	14E
0005433344226	11105	75	14F
0005433344206	11105	76	15B
0005433344127	11105	77	15A
0005433344225	11105	78	15C
0005433344180	11105	79	15D
0005433344161	11105	80	15E
0005433344177	11105	81	15F
0005435508370	11105	82	16B
0005433344224	11105	83	16A
0005435380300	11105	84	16C
0005433344209	11105	85	16D
0005435508389	11105	86	16E
0005435097292	11105	87	17A
0005433344192	11105	88	16F
0005433344214	11105	89	17B
0005433344147	11105	90	17C
0005433344220	11105	91	17E
0005435508349	11105	92	17D
0005433344146	11105	93	18A
0005433344175	11105	94	17F
0005433344200	11105	95	18C
0005433344163	11105	96	18B
0005435508352	11105	97	18D
0005433344215	11105	98	18E
0005433344136	11105	99	18F
0005433344172	11105	100	19A
0005433344134	11105	101	19B
0005433344181	11105	102	19C
0005435097293	11105	103	19E
0005433344228	11105	104	19D
0005433344142	11105	105	19F
0005433344162	11105	106	20A
0005433344186	11105	107	20C
0005433344219	11105	108	20B
0005433344216	11105	109	20D
0005435097295	11105	110	20E
0005433344179	11105	111	20F
0005433344135	11105	112	21B
0005433344189	11105	113	21A
0005433344188	11105	114	21C
0005433344168	11105	115	21D
0005433344138	11105	116	21E
0005435097298	11105	117	22A
0005433344205	11105	118	21F
0005433344155	11105	119	22B
0005433344153	11105	120	22C
0005433344204	11105	121	22D
0005435508353	11105	122	22F
0005433344178	11105	123	22E
0005433344144	11105	124	23A
0005433344202	11105	125	23B
0005433344130	11105	126	23C
0005433344222	11105	127	23D
0005433344182	11105	128	23E
0005433344137	11105	129	23F
0005433343043	17120	1	1A
0005435545821	17120	2	1C
0005433342925	17120	3	1D
0005433343107	17120	4	1F
0005433343511	17120	5	2C
0005433343319	17120	6	2A
0005433343393	17120	7	2F
0005433343304	17120	8	3C
0005432293232	17120	9	3A
0005435545814	17120	10	3D
0005433343055	17120	11	4A
0005433343391	17120	12	3F
0005433343145	17120	13	4B
0005433343174	17120	14	4D
0005433343160	17120	15	4C
0005435380339	17120	16	4E
0005435097224	17120	17	4F
0005433343310	17120	18	5A
0005433343548	17120	19	5C
0005433343426	17120	20	5B
0005435380343	17120	21	5D
0005433343291	17120	22	5E
0005433342897	17120	23	5F
0005433343690	17120	24	6B
0005433343390	17120	25	6A
0005433342871	17120	26	6C
0005435097212	17120	27	6E
0005433342994	17120	28	6D
0005435545826	17120	29	7A
0005435545812	17120	30	6F
0005435545813	17120	31	7B
0005433343042	17120	32	7C
0005432293234	17120	33	7E
0005433343036	17120	34	7D
0005435097190	17120	35	7F
0005433343012	17120	36	8B
0005433343172	17120	37	8A
0005433343037	17120	38	8D
0005433343368	17120	39	8C
0005435097239	17120	40	8F
0005435545822	17120	41	8E
0005435380342	17120	42	9A
0005433343266	17120	43	9C
0005433343349	17120	44	9B
0005433343221	17120	45	9D
0005433342814	17120	46	9E
0005433343056	17120	47	9F
0005433343180	17120	48	10B
0005433343348	17120	49	10D
0005433343483	17120	50	10C
0005435097205	17120	51	10E
0005435380340	17120	52	11A
0005433343122	17120	53	11B
0005433343123	17120	54	11C
0005435097229	17120	55	11E
0005435545827	17120	56	11D
0005433343336	17120	57	11F
0005435097231	17120	58	12B
0005433343496	17120	59	12A
0005433343170	17120	60	12D
0005435380341	17120	61	12C
0005435097213	17120	62	12E
0005435097228	17120	63	12F
0005435545820	17120	64	13A
0005432293233	17120	65	13C
0005435097226	17120	66	13B
0005432293235	17120	67	13D
0005435545825	17120	68	13E
0005433342651	17120	69	13F
0005433343171	17120	70	14A
0005433342924	17120	71	14C
0005433343233	17120	72	14B
0005433343292	17120	73	14D
0005433343163	17120	74	14E
0005435545823	17120	75	14F
0005433343497	17120	76	15B
0005435545815	17120	77	15A
0005433343614	17120	78	15D
0005433343210	17120	79	15F
0005433343173	17120	80	15E
0005433343253	17120	81	16B
0005433343209	17120	82	16A
0005433343398	17120	83	16C
0005433343318	17120	84	16D
0005435545819	17120	85	16E
0005433343232	17120	86	17A
0005433343547	17120	87	16F
0005435545817	17120	88	17B
0005433343175	17120	89	17C
0005433343203	17120	90	17E
0005433342501	17120	91	17D
0005433342931	17120	92	18A
0005433343399	17120	93	18B
0005433343606	17120	94	18C
0005435097220	17120	95	18E
0005433343389	17120	96	18F
0005435545818	17120	97	19A
0005433343270	17120	98	19B
0005433343477	17120	99	19D
0005433343264	17120	100	19C
0005435545824	17120	101	19E
0005433343538	17120	102	19F
0005433343108	17120	103	20A
0005433343306	17120	104	20C
0005433343268	17120	105	20E
0005433343644	17120	106	20D
0005435097225	17120	107	21A
0005433343427	17120	108	20F
0005435545828	17120	109	21B
0005433343131	17120	110	21D
0005433343351	17120	111	21C
0005435380344	17120	112	21F
0005433343413	17120	113	22A
0005435545816	17120	114	22C
0005433343265	17120	115	22B
0005433343153	17120	116	22E
0005433342993	17120	117	22D
0005433343165	17120	118	22F
0005433343590	17120	119	23A
0005433343073	17120	120	23B
0005433343250	17120	121	23D
0005433343392	17120	122	23E
0005433343572	17120	123	23F
0005433507374	9110	1	1A
0005433481245	9110	2	1D
0005433507360	9110	3	2A
0005432919913	9110	4	2C
0005434158979	9110	5	2D
0005433507370	9110	6	2F
0005433507373	9110	7	3C
0005433481246	9110	8	3D
0005433481249	9110	9	4C
0005433507362	9110	10	4E
0005433507366	9110	11	4F
0005432919921	9110	12	5A
0005432919791	9110	13	5F
0005433507357	9110	14	6C
0005432919897	9110	15	6D
0005433507359	9110	16	7A
0005432919790	9110	17	7D
0005432919895	9110	18	8A
0005433507376	9110	19	8C
0005433481242	9110	20	8E
0005432919792	9110	21	8F
0005434158980	9110	22	9C
0005433507375	9110	23	9E
0005432919902	9110	24	10E
0005432919896	9110	25	11D
0005432919875	9110	26	11E
0005433507358	9110	27	11F
0005432919824	9110	28	12E
0005433507364	9110	29	12F
0005433507371	9110	30	13A
0005433481247	9110	31	13C
0005432919924	9110	32	14A
0005433507361	9110	33	14C
0005433481244	9110	34	14E
0005432919919	9110	35	15A
0005432919917	9110	36	15F
0005434158969	9110	37	16D
0005433481248	9110	38	16F
0005432919886	9110	39	17A
0005433507365	9110	40	17D
0005433481243	9110	41	17F
0005432919911	9110	42	18E
0005432919887	9110	43	18F
0005433507369	9110	44	19A
0005433507372	9110	45	19C
0005433507367	9110	46	19F
0005432919912	9110	47	20A
0005433507368	9110	48	20C
0005432919920	9110	49	20D
0005433507363	9110	50	20E
0005432920097	20473	1	1C
0005433507195	20473	2	2D
0005432920083	20473	3	2F
0005432920089	20473	4	3D
0005433481214	20473	5	4A
0005433481216	20473	6	4E
0005433507130	20473	7	4F
0005433507226	20473	8	5C
0005432920099	20473	9	5E
0005433481215	20473	10	5F
0005433507190	20473	11	7A
0005433507189	20473	12	7E
0005432920096	20473	13	8A
0005433481169	20473	14	8C
0005433481163	20473	15	8D
0005432920085	20473	16	8E
0005432920088	20473	17	9C
0005432920090	20473	18	9D
0005432920084	20473	19	9E
0005433481162	20473	20	10A
0005432920092	20473	21	10E
0005433507120	20473	22	11C
0005433481190	20473	23	11D
0005432920094	20473	24	12A
0005433507210	20473	25	12F
0005433507232	20473	26	13C
0005432920086	20473	27	13E
0005432920091	20473	28	13F
0005432920087	20473	29	14C
0005433507192	20473	30	14D
0005433507102	20473	31	14F
0005432920103	20473	32	15F
0005433481166	20473	33	16C
0005433507199	20473	34	16D
0005433507197	20473	35	16F
0005433507196	20473	36	17A
0005432920102	20473	37	17C
0005433507200	20473	38	17D
0005433507194	20473	39	17E
0005433507103	20473	40	17F
0005433481191	20473	41	18A
0005432920101	20473	42	19A
0005433507211	20473	43	19E
0005433507233	20473	44	19F
0005432920100	20473	45	20C
0005432920098	20473	46	20D
0005432920095	20473	47	20E
0005432920093	20473	48	20F
0005432394142	10201	1	1A
0005432394143	10201	2	1B
0005432396279	10201	3	2B
0005432396282	10201	4	2A
0005432396280	10201	5	3A
0005432396278	10201	6	3B
0005432394141	10201	7	4A
0005432396281	10201	8	4B
0005432394140	10201	9	5A
0005432394139	10201	10	5B
0005435179699	10201	11	6A
0005432396242	18294	1	1B
0005432396255	18294	2	2B
0005432396237	18294	3	3A
0005432396238	18294	4	4B
0005435179403	18294	5	6A
0005432396259	18294	6	6B
0005435626180	11048	1	1A
0005435126527	11048	2	1C
0005434411821	11048	3	1D
0005435126410	11048	4	1F
0005435126445	11048	5	2A
0005435126481	11048	6	2C
0005435626178	11048	7	2D
0005435626150	11048	8	2F
0005435626086	11048	9	3A
0005434928329	11048	10	3C
0005435126331	11048	11	3F
0005434411822	11048	12	4A
0005435126354	11048	13	4C
0005435556708	11048	14	4D
0005435626126	11048	15	4F
0005435626127	11048	16	5D
0005435626186	11048	17	5E
0005435626214	11048	18	6A
0005435126270	11048	19	6C
0005435626147	11048	20	6D
0005435626187	11048	21	6E
0005435626199	11048	22	6F
0005435126336	11048	23	7A
0005434928328	11048	24	7C
0005435554182	11048	25	7E
0005435626196	11048	26	7F
0005435126358	11048	27	8A
0005435126515	11048	28	8C
0005435626213	11048	29	8D
0005435626084	11048	30	8E
0005434928331	11048	31	8F
0005435126433	11048	32	9C
0005435556693	11048	33	9A
0005435126528	11048	34	9D
0005434411825	11048	35	9E
0005435126529	11048	36	10A
0005435126488	11048	37	10C
0005435126446	11048	38	10E
0005435126427	11048	39	10F
0005435626155	11048	40	11C
0005435126271	11048	41	11F
0005435126392	11048	42	12A
0005435556707	11048	43	12C
0005435626144	11048	44	12E
0005434411823	11048	45	12F
0005435626181	11048	46	13A
0005435126470	11048	47	13C
0005435126364	11048	48	13D
0005435554188	11048	49	13E
0005435126303	11048	50	13F
0005435626197	11048	51	14C
0005435126337	11048	52	14D
0005434411824	11048	53	14E
0005435626156	11048	54	14F
0005435126332	11048	55	15A
0005435126409	11048	56	15C
0005435556709	11048	57	15D
0005435126478	11048	58	15E
0005435126450	11048	59	15F
0005435126451	11048	60	16A
0005435126408	11048	61	16C
0005435626159	11048	62	16D
0005435126472	11048	63	16E
0005435126547	11048	64	16F
0005435126432	11048	65	17A
0005434928330	11048	66	17C
0005435126388	11048	67	17D
0005435126448	11048	68	17F
0005435126449	11048	69	18A
0005435126441	11048	70	18C
0005435126489	11048	71	18D
0005435126471	11048	72	18E
0005435126359	11048	73	18F
0005435126428	11048	74	19A
0005435126295	11048	75	19C
0005435126363	11048	76	19D
0005435126389	11048	77	19E
0005435626208	11048	78	19F
0005435626161	11048	79	20E
0005435126380	11048	80	20F
0005435626379	14736	1	1C
0005435126778	14736	2	1D
0005435126775	14736	3	1F
0005435126802	14736	4	2A
0005434411775	14736	5	2C
0005435126805	14736	6	2D
0005435126800	14736	7	2F
0005435126790	14736	8	3A
0005435126812	14736	9	3C
0005435126804	14736	10	3F
0005435126779	14736	11	4C
0005435126798	14736	12	4D
0005435626377	14736	13	4E
0005435626383	14736	14	4F
0005435126808	14736	15	5A
0005435126776	14736	16	5C
0005435126809	14736	17	5E
0005435126773	14736	18	5F
0005435626375	14736	19	6D
0005435626381	14736	20	6E
0005434928294	14736	21	7A
0005435626372	14736	22	7C
0005434928312	14736	23	7D
0005434928308	14736	24	8A
0005434928296	14736	25	8D
0005435126785	14736	26	8E
0005435126807	14736	27	9A
0005435626380	14736	28	9D
0005434411802	14736	29	9C
0005435626378	14736	30	9E
0005435126771	14736	31	9F
0005435554234	14736	32	10A
0005435126788	14736	33	10C
0005434928295	14736	34	10D
0005435126794	14736	35	10F
0005435126783	14736	36	11C
0005435556717	14736	37	11D
0005435626384	14736	38	12A
0005435126789	14736	39	12C
0005435126795	14736	40	12E
0005435126793	14736	41	12F
0005435126784	14736	42	13A
0005435554231	14736	43	13C
0005434411771	14736	44	13D
0005435126799	14736	45	13E
0005435626376	14736	46	13F
0005435126786	14736	47	14A
0005435554235	14736	48	14C
0005435126780	14736	49	14D
0005435126772	14736	50	14E
0005435626371	14736	51	14F
0005435126774	14736	52	15A
0005434928293	14736	53	15D
0005435554232	14736	54	15E
0005435126777	14736	55	15F
0005435626373	14736	56	16A
0005435556718	14736	57	16C
0005435126810	14736	58	16D
0005435126801	14736	59	16E
0005435126796	14736	60	17A
0005434411803	14736	61	17D
0005435126811	14736	62	17E
0005435126787	14736	63	17F
0005435126797	14736	64	18A
0005435126806	14736	65	18C
0005435554233	14736	66	18D
0005435626382	14736	67	18E
0005435126782	14736	68	18F
0005435126803	14736	69	19A
0005435126792	14736	70	19C
0005435126781	14736	71	19D
0005435126791	14736	72	20A
0005435626374	14736	73	20C
0005435443384	7132	1	1F
0005435443361	7132	2	2D
0005435443385	7132	3	3A
0005435219206	7132	4	3C
0005435221060	7132	5	4E
0005435715645	7132	6	4F
0005435443342	7132	7	5A
0005435715639	7132	8	5C
0005432400165	7132	9	5F
0005435715650	7132	10	6A
0005435443323	7132	11	6E
0005435178502	7132	12	6F
0005435443341	7132	13	7A
0005432398239	7132	14	7D
0005435443353	7132	15	7F
0005432398237	7132	16	8D
0005435715644	7132	17	8F
0005435178499	7132	18	9F
0005435715649	7132	19	10C
0005435178497	7132	20	10D
0005435219207	7132	21	10F
0005435715648	7132	22	11C
0005435715638	7132	23	11D
0005435715646	7132	24	11E
0005432400167	7132	25	12C
0005435443343	7132	26	12D
0005435443362	7132	27	13A
0005432400166	7132	28	13C
0005435715651	7132	29	13F
0005435715636	7132	30	14C
0005435715640	7132	31	14D
0005435219208	7132	32	14E
0005435443328	7132	33	14F
0005435178503	7132	34	15D
0005435443383	7132	35	16C
0005435715647	7132	36	16D
0005435715637	7132	37	16E
0005435715643	7132	38	16F
0005435443325	7132	39	17C
0005435178496	7132	40	17D
0005435443336	7132	41	17E
0005435715642	7132	42	17F
0005432398238	7132	43	18A
0005435443350	7132	44	18D
0005435715641	7132	45	19C
0005435443321	7132	46	19E
0005435443297	7132	47	20C
0005432398236	7132	48	20F
0005435443412	27093	1	1A
0005435715501	27093	2	1F
0005435715515	27093	3	2C
0005432394112	27093	4	2D
0005435443407	27093	5	3F
0005432398207	27093	6	4E
0005435715477	27093	7	4F
0005432394103	27093	8	5A
0005435443406	27093	9	5F
0005432394102	27093	10	6A
0005435715574	27093	11	6C
0005432398209	27093	12	6E
0005435179001	27093	13	7A
0005435715519	27093	14	7C
0005435178508	27093	15	8C
0005435715493	27093	16	11C
0005435178509	27093	17	11F
0005435179000	27093	18	12E
0005435443408	27093	19	12F
0005432398218	27093	20	13A
0005435715520	27093	21	13C
0005432398208	27093	22	13E
0005435443409	27093	23	14C
0005435715536	27093	24	14D
0005435443413	27093	25	15E
0005435715492	27093	26	16A
0005435715535	27093	27	16E
0005435715521	27093	28	17F
0005435443410	27093	29	18E
0005435443411	27093	30	19A
0005435715513	27093	31	20D
0005435443414	27093	32	20E
0005434084980	2711	1	1A
0005434084978	2711	2	2A
0005434084979	2711	3	2B
0005434084977	2711	4	4A
0005433060405	2711	5	5B
0005433060406	2711	6	6A
0005434084933	28479	1	1B
0005433060442	28479	2	2B
0005434084957	28479	3	3A
0005433060440	28479	4	3B
0005434084949	28479	5	4B
0005433060441	28479	6	5A
0005434084925	28479	7	6B
0005434084956	28479	8	6A
0005435844310	25200	1	1A
0005432632796	25200	2	2A
0005432632790	25200	3	2D
0005432632799	25200	4	3B
0005432632800	25200	5	3D
0005432632784	25200	6	4C
0005435844316	25200	7	4D
0005435844318	25200	8	5D
0005432632804	25200	9	6A
0005432632803	25200	10	6B
0005432632794	25200	11	6C
0005435844294	25200	12	6D
0005432632798	25200	13	7A
0005435844305	25200	14	7B
0005432632788	25200	15	7D
0005435844292	25200	16	18A
0005435844317	25200	17	19A
0005432632791	25200	18	19B
0005432632795	25200	19	19D
0005432632787	25200	20	20A
0005432632793	25200	21	20C
0005432632786	25200	22	21A
0005432632797	25200	23	21B
0005432632802	25200	24	21C
0005432632785	25200	25	21D
0005432632801	25200	26	22B
0005432632792	25200	27	22A
0005435844293	25200	28	22C
0005432632783	25200	29	23A
0005432632789	25200	30	23B
0005432632750	28162	1	1B
0005435844351	28162	2	1C
0005435844357	28162	3	2A
0005435844350	28162	4	2B
0005435844354	28162	5	2C
0005435844362	28162	6	2D
0005432632751	28162	7	3A
0005432632737	28162	8	3B
0005432632745	28162	9	3C
0005435844360	28162	10	4A
0005432632749	28162	11	4B
0005435844361	28162	12	4C
0005435844355	28162	13	5C
0005432632753	28162	14	5D
0005432632735	28162	15	6B
0005432632738	28162	16	6D
0005432632714	28162	17	7A
0005432632752	28162	18	7C
0005432632686	28162	19	7D
0005435844359	28162	20	18B
0005432632685	28162	21	18C
0005432632717	28162	22	18D
0005435844352	28162	23	19A
0005432632743	28162	24	19B
0005432632754	28162	25	19C
0005432632713	28162	26	19D
0005432632727	28162	27	20A
0005435844353	28162	28	20B
0005432632726	28162	29	20C
0005435844358	28162	30	20D
0005432632721	28162	31	21A
0005435844356	28162	32	21D
0005432632724	28162	33	22C
0005432632736	28162	34	22D
0005432632720	28162	35	23A
0005435517907	11419	1	1A
0005435517976	11419	2	1D
0005435517906	11419	3	3A
0005435541065	11419	4	3D
0005435541050	11419	5	3F
0005435517928	11419	6	6C
0005435517952	11419	7	7A
0005435517873	11419	8	8A
0005435540982	11419	9	9D
0005435517929	11419	10	10A
0005435540983	11419	11	10E
0005435540931	11419	12	12C
0005435541049	11419	13	12D
0005435517889	11419	14	13A
0005435517989	11419	15	13C
0005435541051	11419	16	13F
0005435518011	11419	17	14E
0005435541048	11419	18	15E
0005435541064	11419	19	16F
0005435540974	11419	20	17A
0005435517963	11419	21	17D
0005435541069	11419	22	18E
0005435541125	11419	23	19A
0005435517964	11419	24	19E
0005435541147	11419	25	19F
0005435517962	11419	26	20A
0005435541204	22251	1	1A
0005435541200	22251	2	1C
0005435541216	22251	3	1D
0005435541218	22251	4	2A
0005435541209	22251	5	2C
0005435541213	22251	6	2D
0005435541199	22251	7	3A
0005435541201	22251	8	3C
0005435541217	22251	9	3D
0005435529475	22251	10	3F
0005435541207	22251	11	4C
0005435541215	22251	12	4E
0005435529462	22251	13	5A
0005435529469	22251	14	5C
0005435529458	22251	15	6D
0005435529464	22251	16	6E
0005435541214	22251	17	7E
0005435541210	22251	18	8A
0005435541221	22251	19	8E
0005435529466	22251	20	9D
0005435529463	22251	21	9E
0005435541208	22251	22	10C
0005435541219	22251	23	10D
0005435529468	22251	24	10F
0005435541205	22251	25	11A
0005435541203	22251	26	11C
0005435529457	22251	27	11E
0005435529459	22251	28	12A
0005435529473	22251	29	12C
0005435529470	22251	30	12E
0005435529471	22251	31	13C
0005435529467	22251	32	13E
0005435529460	22251	33	13F
0005435529474	22251	34	14E
0005432294509	22251	35	15C
0005435541206	22251	36	16C
0005435529465	22251	37	16D
0005435529456	22251	38	16E
0005435541220	22251	39	16F
0005435541212	22251	40	17A
0005435541211	22251	41	17D
0005435529476	22251	42	17E
0005432294510	22251	43	18C
0005435529472	22251	44	18F
0005435529461	22251	45	19D
0005435541202	22251	46	20A
0005433251652	2297	1	18A
0005433251583	2297	2	1A
0005434907825	2297	3	1C
0005434907803	2297	4	1D
0005434907833	2297	5	1F
0005434907828	2297	6	2A
0005434907819	2297	7	2C
0005434907807	2297	8	2D
0005434907815	2297	9	2F
0005434907844	2297	10	3A
0005433251546	2297	11	3C
0005433251621	2297	12	3D
0005434907817	2297	13	3F
0005434907808	2297	14	4A
0005434907846	2297	15	4D
0005434907853	2297	16	4E
0005434907834	2297	17	4F
0005434907820	2297	18	5A
0005434907849	2297	19	5C
0005434907830	2297	20	5D
0005434907847	2297	21	5E
0005434907816	2297	22	5F
0005434907850	2297	23	6A
0005433251521	2297	24	6C
0005433251653	2297	25	6D
0005434907845	2297	26	6E
0005433251543	2297	27	6F
0005433251601	2297	28	7A
0005434907806	2297	29	7C
0005433251451	2297	30	7D
0005434907835	2297	31	7E
0005434907842	2297	32	7F
0005433400996	2297	33	8D
0005434907831	2297	34	8E
0005434907843	2297	35	9A
0005434907812	2297	36	9C
0005433251650	2297	37	9D
0005434907841	2297	38	9E
0005433251610	2297	39	9F
0005434907827	2297	40	10A
0005434907821	2297	41	10C
0005433251509	2297	42	10D
0005434907840	2297	43	10E
0005434907822	2297	44	11A
0005434907802	2297	45	11C
0005434907855	2297	46	11D
0005434907823	2297	47	11E
0005434907832	2297	48	11F
0005433251519	2297	49	12A
0005434907805	2297	50	12C
0005434907809	2297	51	12D
0005434907813	2297	52	12E
0005434907836	2297	53	12F
0005433251552	2297	54	13A
0005433251712	2297	55	13C
0005433251499	2297	56	13D
0005434907851	2297	57	13E
0005434907801	2297	58	13F
0005434907818	2297	59	14C
0005434907837	2297	60	14D
0005434907826	2297	61	14E
0005433251609	2297	62	14F
0005434907857	2297	63	15D
0005433251631	2297	64	15E
0005434907856	2297	65	15F
0005433400997	2297	66	16C
0005433251649	2297	67	16D
0005433251713	2297	68	16E
0005434907848	2297	69	16F
0005433251651	2297	70	17A
0005434907814	2297	71	17C
0005434907839	2297	72	17D
0005433251425	2297	73	17E
0005434907852	2297	74	17F
0005434907810	2297	75	18C
0005433251597	2297	76	18D
0005434907804	2297	77	18E
0005433251490	2297	78	18F
0005434907829	2297	79	19A
0005434907824	2297	80	19D
0005434907854	2297	81	19E
0005434907838	2297	82	20A
0005433251533	2297	83	20C
0005433251520	2297	84	20D
0005434907811	2297	85	20E
0005433251721	2297	86	20F
0005434907257	25630	1	1A
0005433251793	25630	2	1C
0005433401015	25630	3	1D
0005434907120	25630	4	1F
0005434907253	25630	5	2A
0005434907286	25630	6	2C
0005433251789	25630	7	2D
0005433251801	25630	8	2F
0005434907213	25630	9	3A
0005434907260	25630	10	3C
0005434907297	25630	11	3D
0005434907093	25630	12	4A
0005433251807	25630	13	4C
0005434907447	25630	14	4D
0005434907428	25630	15	4E
0005434907296	25630	16	4F
0005434907367	25630	17	5A
0005434907281	25630	18	5C
0005434907355	25630	19	5D
0005434907446	25630	20	5E
0005433251785	25630	21	5F
0005433251809	25630	22	6A
0005434907514	25630	23	6C
0005434907368	25630	24	6D
0005433251811	25630	25	6E
0005433401014	25630	26	6F
0005433251797	25630	27	7A
0005434907448	25630	28	7C
0005434907392	25630	29	7D
0005434907338	25630	30	7E
0005434907515	25630	31	7F
0005434907317	25630	32	8A
0005433251808	25630	33	8D
0005434907409	25630	34	8E
0005434907426	25630	35	8F
0005433251795	25630	36	9A
0005434907269	25630	37	9C
0005433251800	25630	38	9D
0005434907291	25630	39	9E
0005434907441	25630	40	9F
0005433251796	25630	41	10A
0005433251786	25630	42	10C
0005434907216	25630	43	10D
0005434907234	25630	44	10E
0005433251799	25630	45	10F
0005434907310	25630	46	11C
0005433251810	25630	47	11D
0005434907287	25630	48	11E
0005433251804	25630	49	11F
0005434907199	25630	50	12A
0005434907394	25630	51	12C
0005434907255	25630	52	12D
0005434907333	25630	53	12F
0005433251782	25630	54	13A
0005434907329	25630	55	13C
0005433251791	25630	56	13D
0005433251784	25630	57	13E
0005433251806	25630	58	13F
0005433251802	25630	59	14C
0005434907331	25630	60	14D
0005434907309	25630	61	14E
0005434907519	25630	62	14F
0005434907416	25630	63	15A
0005433251792	25630	64	15C
0005434907271	25630	65	15D
0005434907496	25630	66	15E
0005433401013	25630	67	16A
0005433251783	25630	68	16C
0005434907518	25630	69	16D
0005434907337	25630	70	16E
0005433251798	25630	71	16F
0005434907332	25630	72	17A
0005434907256	25630	73	17C
0005434907252	25630	74	17D
0005433251788	25630	75	17E
0005434907498	25630	76	17F
0005434907360	25630	77	18A
0005434907308	25630	78	18C
0005434907222	25630	79	18D
0005434907108	25630	80	18E
0005434907427	25630	81	18F
0005433251787	25630	82	19A
0005433251805	25630	83	19C
0005434907330	25630	84	19D
0005433251794	25630	85	19E
0005434907270	25630	86	19F
0005434907251	25630	87	20A
0005433251803	25630	88	20C
0005434907292	25630	89	20D
0005433251790	25630	90	20E
0005432862309	2545	1	1B
0005432621184	2545	2	1C
0005432862310	2545	3	1D
0005432621190	2545	4	2A
0005432621186	2545	5	2B
0005432862351	2545	6	2C
0005432621189	2545	7	2D
0005432621182	2545	8	3A
0005432621181	2545	9	3D
0005432621187	2545	10	4B
0005432621188	2545	11	6B
0005432621183	2545	12	6C
0005432862350	2545	13	7C
0005432862319	2545	14	18A
0005432621185	2545	15	18C
0005432621179	2545	16	19D
0005432621178	2545	17	20A
0005432621180	2545	18	20C
0005432621177	2545	19	22C
0005432621056	28042	1	1D
0005432862382	28042	2	2B
0005432620981	28042	3	2C
0005432621061	28042	4	3A
0005432621093	28042	5	3D
0005432621039	28042	6	4A
0005432621033	28042	7	4D
0005432621032	28042	8	5A
0005432621038	28042	9	7A
0005432621006	28042	10	7D
0005432621091	28042	11	18A
0005432862380	28042	12	18B
0005432862381	28042	13	18C
0005432620982	28042	14	19B
0005432621099	28042	15	19C
0005432621005	28042	16	20A
0005432862378	28042	17	20B
0005432862385	28042	18	21D
0005432862384	28042	19	22A
0005432621014	28042	20	22B
0005432621060	28042	21	22C
0005432862379	28042	22	22D
0005432862383	28042	23	23A
0005432621092	28042	24	23B
0005434097477	11723	1	3A
0005434097473	11723	2	4A
0005434097472	11723	3	6B
0005434191289	28022	1	3F
0005434191295	28022	2	4A
0005434191288	28022	3	4D
0005434191292	28022	4	4E
0005434191291	28022	5	5F
0005434191296	28022	6	11E
0005434191294	28022	7	14C
0005434191293	28022	8	15E
0005434191285	28022	9	15F
0005434191290	28022	10	18A
0005434191286	28022	11	18D
0005434191287	28022	12	20C
0005433452761	31078	1	1A
0005433452760	31078	2	3A
0005433451639	31078	3	4B
0005433451638	31078	4	6B
0005433454886	31422	1	1A
0005433454885	31422	2	1B
0005433452748	31422	3	4A
0005433452739	31422	4	4B
0005433452738	31422	5	5B
0005434184665	11992	1	1A
0005433134119	11992	2	1B
0005433134153	11992	3	1D
0005433129285	11992	4	2A
0005433134120	11992	5	2B
0005433129276	11992	6	2C
0005433129269	11992	7	2D
0005434142610	11992	8	3A
0005433129281	11992	9	3B
0005433129287	11992	10	3D
0005433129278	11992	11	4C
0005433129275	11992	12	5A
0005433129260	11992	13	5B
0005433129279	11992	14	5D
0005433129288	11992	15	7B
0005433134155	11992	16	18C
0005434184663	11992	17	19B
0005433129270	11992	18	19C
0005433134161	11992	19	19D
0005434184666	11992	20	20D
0005433129289	11992	21	21B
0005434142616	11992	22	21C
0005433134129	11992	23	21D
0005433134152	11992	24	22A
0005434142617	11992	25	22B
0005433134130	11992	26	22C
0005433129286	11992	27	22D
0005434184685	29854	1	1C
0005434184686	29854	2	2D
0005434184687	29854	3	3A
0005433134184	29854	4	3B
0005433131753	29854	5	5A
0005433131754	29854	6	6A
0005434142648	29854	7	7D
0005434142649	29854	8	18B
0005433134185	29854	9	18C
0005434183600	29854	10	19A
0005433134186	29854	11	19C
0005434142647	29854	12	20B
0005433131756	29854	13	20C
0005434142646	29854	14	21B
0005433131755	29854	15	21C
0005433134187	29854	16	22C
0005433131757	29854	17	22D
0005434183601	29854	18	23B
0005435697614	16458	1	1A
0005435697591	16458	2	1C
0005435697592	16458	3	1D
0005435697613	16458	4	2A
0005435935045	16458	5	2D
0005435697598	16458	6	3A
0005435697602	16458	7	3D
0005435697599	16458	8	4A
0005435697603	16458	9	4C
0005435697601	16458	10	4D
0005435697594	16458	11	5A
0005435697615	16458	12	5B
0005435697589	16458	13	5C
0005435935059	16458	14	6C
0005435697612	16458	15	6D
0005435935053	16458	16	7A
0005435697590	16458	17	7B
0005435935043	16458	18	7C
0005435697593	16458	19	7D
0005435697604	16458	20	18A
0005435697605	16458	21	18B
0005435697610	16458	22	18C
0005435697600	16458	23	18D
0005435697595	16458	24	19A
0005435697597	16458	25	19B
0005435697609	16458	26	20A
0005435935052	16458	27	20B
0005435697608	16458	28	20C
0005435697611	16458	29	21B
0005435697617	16458	30	21D
0005435697606	16458	31	22A
0005435697596	16458	32	22C
0005435697607	16458	33	22D
0005435697616	16458	34	23A
0005435935044	16458	35	23B
0005435697457	24738	1	1B
0005435697375	24738	2	1D
0005435697418	24738	3	2A
0005435697335	24738	4	2B
0005435697415	24738	5	2D
0005435697304	24738	6	3B
0005435697410	24738	7	3C
0005435697350	24738	8	3D
0005435697310	24738	9	4A
0005435697427	24738	10	4D
0005435697336	24738	11	5A
0005435697411	24738	12	5C
0005435935077	24738	13	6A
0005435697309	24738	14	6B
0005435697364	24738	15	6C
0005435697435	24738	16	7B
0005435697458	24738	17	7C
0005435935079	24738	18	18B
0005435697368	24738	19	18D
0005435697412	24738	20	19A
0005435697462	24738	21	19D
0005435697303	24738	22	20A
0005435697516	24738	23	20C
0005435697385	24738	24	21A
0005435697339	24738	25	21B
0005435697338	24738	26	21C
0005435697386	24738	27	22A
0005435697515	24738	28	22B
0005435697463	24738	29	22C
0005435935078	24738	30	23A
0005433724850	18774	1	1A
0005432968841	18774	2	1B
0005433724848	18774	3	2A
0005433724846	18774	4	2B
0005432968849	18774	5	3B
0005432968840	18774	6	4B
0005433724849	18774	7	5A
0005432968850	18774	8	5B
0005433724847	18774	9	6B
0005432968865	21650	1	1B
0005433724814	21650	2	2A
0005433724806	21650	3	3A
0005433724813	21650	4	4A
0005433724822	21650	5	5B
0005432968866	21650	6	6B
0005434138998	7332	1	1A
0005434139004	7332	2	1C
0005434139030	7332	3	1D
0005434139044	7332	4	1F
0005434138992	7332	5	2C
0005434139045	7332	6	2D
0005434138984	7332	7	2F
0005434139034	7332	8	3D
0005434087565	7332	9	3F
0005434138986	7332	10	4C
0005434138981	7332	11	4D
0005434139024	7332	12	4F
0005434139000	7332	13	5A
0005434139031	7332	14	5C
0005434087563	7332	15	5D
0005434139013	7332	16	5F
0005434139027	7332	17	6A
0005434139001	7332	18	6D
0005434139022	7332	19	6E
0005434139010	7332	20	6F
0005434139017	7332	21	7A
0005434139035	7332	22	7C
0005434139047	7332	23	7D
0005434139032	7332	24	7E
0005434139046	7332	25	8A
0005434139008	7332	26	8C
0005434139029	7332	27	8E
0005434087566	7332	28	8F
0005434138999	7332	29	9A
0005434139043	7332	30	9E
0005434138979	7332	31	10A
0005434139033	7332	32	10C
0005434138987	7332	33	10D
0005434139003	7332	34	10E
0005434139028	7332	35	10F
0005434138996	7332	36	11C
0005434139021	7332	37	11E
0005434139014	7332	38	11F
0005434139037	7332	39	12A
0005434139016	7332	40	12D
0005434138991	7332	41	12E
0005434139007	7332	42	13A
0005434139041	7332	43	13E
0005434139040	7332	44	13F
0005434138989	7332	45	14A
0005434139020	7332	46	14D
0005434138997	7332	47	14E
0005434138982	7332	48	14F
0005434139006	7332	49	15C
0005434138995	7332	50	15D
0005434139026	7332	51	15E
0005434139009	7332	52	16A
0005434139015	7332	53	16C
0005434138983	7332	54	16D
0005434138993	7332	55	16E
0005434139025	7332	56	17A
0005434139005	7332	57	17C
0005434139023	7332	58	17D
0005434138980	7332	59	17E
0005434139012	7332	60	17F
0005434139002	7332	61	18A
0005434139039	7332	62	18D
0005434139038	7332	63	18E
0005434087564	7332	64	18F
0005434138988	7332	65	19C
0005434139036	7332	66	19D
0005434138994	7332	67	19E
0005434139019	7332	68	19F
0005434138990	7332	69	20A
0005434139011	7332	70	20C
0005434139018	7332	71	20D
0005434138985	7332	72	20E
0005434139042	7332	73	20F
0005434138103	28569	1	1A
0005434087493	28569	2	1C
0005434137939	28569	3	1D
0005434138156	28569	4	1F
0005434138054	28569	5	2A
0005434138187	28569	6	2C
0005434138091	28569	7	2D
0005434138343	28569	8	2F
0005434137906	28569	9	3A
0005434138026	28569	10	3C
0005434138164	28569	11	3D
0005434138378	28569	12	3F
0005434138341	28569	13	4A
0005434138089	28569	14	4C
0005434137953	28569	15	4E
0005434138207	28569	16	4F
0005434138084	28569	17	5A
0005434138206	28569	18	5C
0005434138259	28569	19	5D
0005434138326	28569	20	5E
0005434137960	28569	21	5F
0005434138306	28569	22	6A
0005434138196	28569	23	6C
0005434138286	28569	24	6D
0005434138154	28569	25	6E
0005434138387	28569	26	6F
0005434138037	28569	27	7A
0005434138285	28569	28	7C
0005434138377	28569	29	7E
0005434138379	28569	30	7F
0005434137841	28569	31	8A
0005434137994	28569	32	8E
0005434138083	28569	33	8F
0005434138036	28569	34	9A
0005434138144	28569	35	9C
0005434138226	28569	36	9D
0005434137993	28569	37	9E
0005434138372	28569	38	9F
0005434138254	28569	39	10A
0005434138388	28569	40	10C
0005434138172	28569	41	10D
0005434138307	28569	42	10E
0005434138270	28569	43	10F
0005434137940	28569	44	11A
0005434138043	28569	45	11C
0005434087523	28569	46	11D
0005434138128	28569	47	11E
0005434138029	28569	48	11F
0005434138044	28569	49	12A
0005434138059	28569	50	12C
0005434138162	28569	51	12E
0005434138295	28569	52	12F
0005434138061	28569	53	13A
0005434138138	28569	54	13C
0005434138155	28569	55	13D
0005434138173	28569	56	13E
0005434138315	28569	57	13F
0005434138182	28569	58	14A
0005434138117	28569	59	14C
0005434138319	28569	60	14D
0005434138055	28569	61	14E
0005434138194	28569	62	14F
0005434137905	28569	63	15A
0005434138153	28569	64	15C
0005434138280	28569	65	15D
0005434138143	28569	66	15E
0005434138104	28569	67	15F
0005434138335	28569	68	16D
0005434138031	28569	69	16E
0005434138374	28569	70	16F
0005434138276	28569	71	17A
0005434138165	28569	72	17C
0005434138176	28569	73	17D
0005434138290	28569	74	17E
0005434138373	28569	75	17F
0005434138363	28569	76	18A
0005434138166	28569	77	18C
0005434138320	28569	78	18D
0005434138056	28569	79	18E
0005434138334	28569	80	18F
0005434138361	28569	81	19A
0005434137842	28569	82	19C
0005434138025	28569	83	19D
0005434087524	28569	84	19E
0005434138090	28569	85	19F
0005434138314	28569	86	20A
0005434138163	28569	87	20C
0005434138042	28569	88	20D
0005434138183	28569	89	20E
0005434138225	28569	90	20F
0005435808343	1924	1	1A
0005435808345	1924	2	1B
0005435808341	1924	3	1D
0005435808337	1924	4	2C
0005434610266	1924	5	3A
0005435808340	1924	6	3D
0005435808347	1924	7	4B
0005434610268	1924	8	5C
0005433407586	1924	9	5D
0005435808342	1924	10	6A
0005433407555	1924	11	6D
0005433407579	1924	12	7A
0005434610267	1924	13	7B
0005433407537	1924	14	7C
0005435808339	1924	15	18B
0005433407577	1924	16	18D
0005433407574	1924	17	19C
0005433407578	1924	18	19D
0005435808346	1924	19	20A
0005435808344	1924	20	20B
0005435808338	1924	21	21A
0005433407573	1924	22	22B
0005434610228	23095	1	1A
0005434610248	23095	2	19C
0005434610224	23095	3	21A
0005434610225	23095	4	21B
0005434610247	23095	5	22C
0005434503944	16686	1	1A
0005434504245	16686	2	1B
0005434504226	16686	3	1C
0005434504186	16686	4	1D
0005434504238	16686	5	2B
0005434504174	16686	6	2C
0005434504166	16686	7	2D
0005434504297	16686	8	3A
0005434504250	16686	9	3B
0005434504244	16686	10	3C
0005434504189	16686	11	3D
0005434504202	16686	12	4A
0005434504165	16686	13	4B
0005434504175	16686	14	4C
0005434504205	16686	15	4D
0005434504305	16686	16	5A
0005434504232	16686	17	5B
0005434504247	16686	18	5C
0005434504167	16686	19	5D
0005434504172	16686	20	6A
0005434504236	16686	21	6C
0005434504078	16686	22	6D
0005434504237	16686	23	7A
0005434504201	16686	24	7B
0005434504211	16686	25	7C
0005434504310	16686	26	7D
0005434504114	16686	27	18A
0005434504210	16686	28	18B
0005434504231	16686	29	18C
0005434504251	16686	30	18D
0005434504129	16686	31	19A
0005434504177	16686	32	19B
0005434504176	16686	33	19C
0005434504248	16686	34	19D
0005434504271	16686	35	20A
0005434503943	16686	36	20B
0005434503945	16686	37	20D
0005434503992	16686	38	21B
0005434504217	16686	39	21C
0005434504227	16686	40	21D
0005434504146	16686	41	22A
0005434504131	16686	42	22B
0005434504203	16686	43	22C
0005434504185	16686	44	22D
0005434504113	16686	45	23A
0005434504531	22885	1	1A
0005434504522	22885	2	2A
0005434504510	22885	3	2C
0005434504512	22885	4	2D
0005434504525	22885	5	3A
0005434504534	22885	6	3B
0005434504544	22885	7	3C
0005434504537	22885	8	3D
0005434504518	22885	9	4A
0005434504517	22885	10	4B
0005434504532	22885	11	4C
0005434504516	22885	12	4D
0005434504507	22885	13	5A
0005434504513	22885	14	5B
0005434504528	22885	15	5D
0005434504515	22885	16	6A
0005434504545	22885	17	6B
0005434504538	22885	18	6C
0005434504509	22885	19	6D
0005434504529	22885	20	7A
0005434504511	22885	21	7B
0005434504535	22885	22	7C
0005434504526	22885	23	7D
0005434504539	22885	24	18B
0005434504514	22885	25	18C
0005434504524	22885	26	18D
0005434504542	22885	27	19A
0005434504533	22885	28	19B
0005434504508	22885	29	19C
0005434504506	22885	30	19D
0005434504505	22885	31	20A
0005434504530	22885	32	20B
0005434504541	22885	33	20C
0005434504520	22885	34	21A
0005434504519	22885	35	21C
0005434504521	22885	36	21D
0005434504543	22885	37	22A
0005434504527	22885	38	22B
0005434504540	22885	39	22C
0005434504536	22885	40	23A
0005434504523	22885	41	23B
0005433266766	2192	1	1A
0005435078503	2192	2	1B
0005435078509	2192	3	1C
0005435078497	2192	4	2A
0005433266750	2192	5	2B
0005433266677	2192	6	2D
0005433266692	2192	7	3A
0005433266763	2192	8	3C
0005435078501	2192	9	3D
0005433266732	2192	10	4B
0005433266738	2192	11	4C
0005433266724	2192	12	4D
0005435078507	2192	13	5A
0005435078496	2192	14	5D
0005433266767	2192	15	6A
0005433266749	2192	16	6C
0005435078510	2192	17	6D
0005435078500	2192	18	7A
0005435078502	2192	19	7C
0005435078498	2192	20	7D
0005435078495	2192	21	18A
0005433266747	2192	22	19A
0005433266733	2192	23	19B
0005433266752	2192	24	20B
0005433266768	2192	25	20D
0005435078506	2192	26	21A
0005435078499	2192	27	21C
0005435078505	2192	28	21D
0005435078504	2192	29	22A
0005433266737	2192	30	22B
0005435078494	2192	31	22C
0005435078508	2192	32	22D
0005433266769	2192	33	23A
0005433266745	2192	34	23B
0005433266815	24351	1	2C
0005435078326	24351	2	2D
0005433266820	24351	3	3A
0005433266821	24351	4	3B
0005435078327	24351	5	3C
0005435078405	24351	6	3D
0005433266818	24351	7	4B
0005435078367	24351	8	4D
0005435078369	24351	9	5A
0005435078353	24351	10	6B
0005435078360	24351	11	6D
0005433266817	24351	12	7A
0005433266819	24351	13	7B
0005433266822	24351	14	7C
0005435078366	24351	15	7D
0005435078359	24351	16	18B
0005435078370	24351	17	19C
0005435078411	24351	18	20D
0005433266816	24351	19	21B
0005435078406	24351	20	21C
0005433266823	24351	21	21D
0005435078407	24351	22	22A
0005435078371	24351	23	22B
0005435464515	6620	1	1B
0005434988848	6620	2	1C
0005434988857	6620	3	3B
0005435803288	6620	4	3D
0005435803290	6620	5	4A
0005434988856	6620	6	4C
0005435803291	6620	7	5D
0005434988855	6620	8	6A
0005435464505	6620	9	6B
0005434988852	6620	10	6C
0005434988850	6620	11	6D
0005434988853	6620	12	7B
0005435803289	6620	13	7D
0005435464513	6620	14	18C
0005434988858	6620	15	19A
0005434988846	6620	16	20A
0005434988849	6620	17	20D
0005434988854	6620	18	21B
0005434988851	6620	19	21C
0005435464514	6620	20	22A
0005434988847	6620	21	22D
0005434988716	23638	1	1A
0005434988730	23638	2	1B
0005434988727	23638	3	1D
0005434988731	23638	4	6B
0005434988751	23638	5	6C
0005434988719	23638	6	18D
0005434988726	23638	7	19A
0005434988741	23638	8	19B
0005434988720	23638	9	19C
0005434988717	23638	10	19D
0005434988732	23638	11	20D
0005434988733	23638	12	21D
0005434988715	23638	13	22A
0005434988724	23638	14	22C
0005434988745	23638	15	23A
0005434988743	23638	16	23B
0005433450196	30506	1	1C
0005433450187	30506	2	1D
0005432383593	30506	3	1F
0005433450206	30506	4	2A
0005432383599	30506	5	2F
0005433453780	30506	6	3A
0005433450192	30506	7	3D
0005432383571	30506	8	3F
0005432383607	30506	9	4A
0005432383581	30506	10	4E
0005432383586	30506	11	4F
0005432383592	30506	12	5C
0005433450188	30506	13	5D
0005433450198	30506	14	5F
0005432383583	30506	15	6D
0005432383601	30506	16	6E
0005433450186	30506	17	6F
0005432383576	30506	18	7A
0005432383577	30506	19	7D
0005433450194	30506	20	7E
0005432383574	30506	21	8A
0005433450193	30506	22	8C
0005433450201	30506	23	8D
0005432383589	30506	24	8E
0005432383575	30506	25	8F
0005433453781	30506	26	9A
0005433450197	30506	27	9C
0005432383578	30506	28	10C
0005432383594	30506	29	10E
0005433450191	30506	30	11A
0005432383598	30506	31	11C
0005432383584	30506	32	11D
0005432383602	30506	33	11E
0005432383573	30506	34	12A
0005432383588	30506	35	12D
0005433450200	30506	36	12E
0005432383587	30506	37	13A
0005432383585	30506	38	13C
0005432383582	30506	39	13D
0005432383580	30506	40	13E
0005432383604	30506	41	13F
0005432383596	30506	42	14A
0005433450189	30506	43	14E
0005432383606	30506	44	14F
0005433450203	30506	45	15A
0005432383600	30506	46	15D
0005433450205	30506	47	15E
0005433450195	30506	48	16A
0005433450204	30506	49	16C
0005432383591	30506	50	16D
0005432383605	30506	51	16E
0005432383608	30506	52	17E
0005432383590	30506	53	17F
0005432383597	30506	54	18C
0005433450199	30506	55	18D
0005432383603	30506	56	19A
0005432383572	30506	57	19C
0005433450185	30506	58	19D
0005433450202	30506	59	19E
0005433454898	30506	60	19F
0005432383579	30506	61	20A
0005433450190	30506	62	20D
0005432383595	30506	63	20E
0005432382918	31324	1	1A
0005432383160	31324	2	1C
0005432383041	31324	3	1D
0005432383218	31324	4	1F
0005432383163	31324	5	2C
0005432383321	31324	6	2D
0005433449955	31324	7	3C
0005433449989	31324	8	3D
0005432383072	31324	9	4C
0005432382971	31324	10	4E
0005432383035	31324	11	5A
0005433450010	31324	12	5C
0005433449935	31324	13	5D
0005433450030	31324	14	5F
0005433449983	31324	15	6A
0005433449991	31324	16	6C
0005432382972	31324	17	6D
0005433449877	31324	18	6F
0005432383129	31324	19	7C
0005432383309	31324	20	7F
0005432383157	31324	21	8A
0005432383136	31324	22	8C
0005432383119	31324	23	8D
0005432383201	31324	24	8E
0005433453767	31324	25	8F
0005433449941	31324	26	9A
0005432382919	31324	27	9C
0005433449878	31324	28	9D
0005432383118	31324	29	9E
0005432383227	31324	30	9F
0005433450048	31324	31	10A
0005432383158	31324	32	10C
0005433450013	31324	33	10D
0005433449984	31324	34	10E
0005433449985	31324	35	10F
0005432382988	31324	36	11A
0005432383320	31324	37	11C
0005432383226	31324	38	11D
0005432383161	31324	39	11E
0005432383200	31324	40	11F
0005432383114	31324	41	12C
0005433449982	31324	42	12D
0005433450087	31324	43	12E
0005432383332	31324	44	12F
0005432383197	31324	45	13C
0005433449986	31324	46	13D
0005432383240	31324	47	13E
0005433453765	31324	48	13F
0005432383331	31324	49	14A
0005433450011	31324	50	14C
0005433450047	31324	51	14D
0005432383036	31324	52	14E
0005432383217	31324	53	14F
0005433450084	31324	54	15C
0005432383064	31324	55	15D
0005433450021	31324	56	15E
0005433450088	31324	57	15F
0005433450038	31324	58	16A
0005433453766	31324	59	16C
0005433450107	31324	60	17A
0005433450076	31324	61	17C
0005433449934	31324	62	17D
0005433450090	31324	63	17E
0005432383156	31324	64	17F
0005432383254	31324	65	18A
0005432383270	31324	66	18D
0005432383192	31324	67	18E
0005433450015	31324	68	19A
0005432383113	31324	69	19D
0005433450031	31324	70	19E
0005433450083	31324	71	19F
0005433450089	31324	72	20A
0005433450108	31324	73	20D
0005432383155	31324	74	20E
0005432383115	31324	75	20F
0005433788204	26482	1	1C
0005433788197	26482	2	2B
0005435548542	26482	3	3A
0005433788194	26482	4	3C
0005435548539	26482	5	3D
0005433788199	26482	6	4A
0005435548544	26482	7	4C
0005433788195	26482	8	4D
0005435548541	26482	9	5A
0005435548545	26482	10	5D
0005433788181	26482	11	6D
0005433788182	26482	12	7D
0005435548546	26482	13	18B
0005435548538	26482	14	19A
0005433788205	26482	15	19C
0005433788198	26482	16	20C
0005435548543	26482	17	21D
0005435548540	26482	18	22D
0005433131708	10762	1	1A
0005433131716	10762	2	2B
0005435299735	10762	3	3C
0005435304166	10762	4	4D
0005435304171	10762	5	5C
0005435304161	10762	6	5D
0005435304178	10762	7	6A
0005435299803	10762	8	6D
0005435299791	10762	9	18A
0005433131703	10762	10	18B
0005435299783	10762	11	18C
0005435304177	10762	12	19C
0005433131714	10762	13	19D
0005435299766	10762	14	20C
0005435299767	10762	15	21C
0005435304170	10762	16	22A
0005435304165	10762	17	22B
0005435304159	10762	18	23B
0005435299827	29735	1	2C
0005433129327	29735	2	3A
0005435299829	29735	3	3B
0005433129325	29735	4	3D
0005433129328	29735	5	4A
0005433126896	29735	6	5C
0005435299828	29735	7	6C
0005435302252	29735	8	6D
0005433126898	29735	9	7B
0005435302253	29735	10	19D
0005433126897	29735	11	20D
0005435302250	29735	12	21B
0005433129329	29735	13	21C
0005433129326	29735	14	22A
0005435299831	29735	15	22C
0005435302249	29735	16	22D
0005435299830	29735	17	23A
0005435302251	29735	18	23B
0005433110045	2435	1	1A
0005434287518	2435	2	1D
0005432264501	2435	3	2A
0005434287512	2435	4	2C
0005433110077	2435	5	2D
0005433110096	2435	6	3A
0005434287520	2435	7	3B
0005434287516	2435	8	3D
0005434287519	2435	9	4A
0005434287517	2435	10	4C
0005434287510	2435	11	5A
0005433110044	2435	12	5C
0005434287528	2435	13	5D
0005432264500	2435	14	6A
0005434287525	2435	15	6B
0005433110046	2435	16	6C
0005434287508	2435	17	6D
0005434287513	2435	18	7A
0005434287509	2435	19	7B
0005434287521	2435	20	7D
0005433110042	2435	21	18B
0005434287522	2435	22	18D
0005433110110	2435	23	19A
0005434287524	2435	24	19D
0005433110111	2435	25	20A
0005433110078	2435	26	20B
0005434287526	2435	27	20C
0005434287511	2435	28	21A
0005434287523	2435	29	21C
0005434287527	2435	30	22C
0005434287515	2435	31	22D
0005434287514	2435	32	23A
0005434287314	26868	1	1A
0005434287417	26868	2	1B
0005434287371	26868	3	1C
0005433110174	26868	4	1D
0005434287349	26868	5	2A
0005434287354	26868	6	2B
0005434287364	26868	7	3C
0005433110181	26868	8	3D
0005434287305	26868	9	4A
0005434287313	26868	10	5B
0005433110178	26868	11	6A
0005434287326	26868	12	6B
0005434287319	26868	13	6C
0005433110183	26868	14	6D
0005433110180	26868	15	7B
0005434287162	26868	16	7C
0005434287391	26868	17	7D
0005434287303	26868	18	18A
0005433110179	26868	19	18B
0005433110182	26868	20	18D
0005434287318	26868	21	19A
0005434287342	26868	22	19D
0005434287392	26868	23	20A
0005434287353	26868	24	21A
0005434287362	26868	25	21C
0005433110175	26868	26	21D
0005433110177	26868	27	22A
0005433110176	26868	28	22C
0005434287348	26868	29	22D
0005434287372	26868	30	23A
0005434287317	26868	31	23B
0005435856246	25449	1	4D
0005434269096	25449	2	5C
0005435856249	25449	3	5D
0005435856247	25449	4	7D
0005435856248	25449	5	19D
0005435856206	26624	1	3B
0005435856221	26624	2	4A
0005435854060	26624	3	4B
0005435856185	26624	4	19C
0005435856207	26624	5	22C
0005435314832	6110	1	1A
0005435314823	6110	2	1B
0005434520345	6110	3	1C
0005434520360	6110	4	1D
0005434520351	6110	5	2A
0005434520334	6110	6	2B
0005434520339	6110	7	2C
0005435314824	6110	8	2D
0005434520356	6110	9	3A
0005434520355	6110	10	3B
0005434520335	6110	11	3C
0005434520347	6110	12	3D
0005434520361	6110	13	4A
0005435314829	6110	14	4B
0005434520338	6110	15	4C
0005434520342	6110	16	5A
0005434520353	6110	17	4D
0005435314831	6110	18	5B
0005434520352	6110	19	5C
0005435314825	6110	20	6B
0005434520348	6110	21	6C
0005434520343	6110	22	6D
0005434520340	6110	23	7B
0005435314822	6110	24	7A
0005435314841	6110	25	7C
0005434520362	6110	26	7D
0005434520357	6110	27	18A
0005434520344	6110	28	18B
0005434520354	6110	29	18C
0005434520333	6110	30	18D
0005434520346	6110	31	19A
0005434520349	6110	32	19B
0005434520350	6110	33	19C
0005434520337	6110	34	19D
0005434520332	6110	35	20A
0005434520341	6110	36	20B
0005435314827	6110	37	20C
0005435314842	6110	38	20D
0005435314840	6110	39	21A
0005434520358	6110	40	21C
0005435314815	6110	41	21D
0005434520359	6110	42	22A
0005434520331	6110	43	22B
0005434520336	6110	44	22D
0005435314826	6110	45	23B
0005433650611	27637	1	1A
0005435263695	27637	2	1C
0005433650589	27637	3	1D
0005435263693	27637	4	1F
0005433650582	27637	5	2A
0005435263694	27637	6	2C
0005433650602	27637	7	2D
0005433650601	27637	8	2F
0005433650658	27637	9	3A
0005433650667	27637	10	3C
0005433650627	27637	11	3D
0005433650581	27637	12	3F
0005433650661	27637	13	4A
0005435263687	27637	14	4D
0005435263688	27637	15	4C
0005433650624	27637	16	4E
0005435263696	27637	17	4F
0005433650663	27637	18	5A
0005433650625	27637	19	5C
0005435263690	27637	20	5D
0005433650619	27637	21	5E
0005433650642	27637	22	5F
0005433650552	27637	23	6A
0005433650628	27637	24	6C
0005433650688	27637	25	6D
0005433650576	27637	26	6E
0005433650614	27637	27	6F
0005433650610	27637	28	7A
0005433650664	27637	29	7C
0005433650557	27637	30	7D
0005435263691	27637	31	7E
0005433650615	27637	32	7F
0005433650726	27637	33	8A
0005433650598	27637	34	8C
0005433650528	27637	35	8D
0005433650674	27637	36	8E
0005433650671	27637	37	8F
0005433650593	27637	38	9A
0005433650652	27637	39	9C
0005435263697	27637	40	9D
0005433650604	27637	41	9E
0005435263685	27637	42	9F
0005433650587	27637	43	10A
0005433650590	27637	44	10C
0005435263684	27637	45	10D
0005433650551	27637	46	10E
0005433650536	27637	47	10F
0005433650577	27637	48	11A
0005433650584	27637	49	11C
0005435263686	27637	50	11D
0005435263683	27637	51	11E
0005433650606	27637	52	11F
0005433650603	27637	53	12A
0005433650668	27637	54	12C
0005433650655	27637	55	12D
0005433650670	27637	56	12E
0005435263689	27637	57	12F
0005433650588	27637	58	13A
0005433650594	27637	59	13C
0005433650676	27637	60	13D
0005435263680	27637	61	13E
0005433650649	27637	62	13F
0005433650583	27637	63	14A
0005435263679	27637	64	14C
0005433650608	27637	65	14E
0005433650630	27637	66	14D
0005433650678	27637	67	14F
0005433650629	27637	68	15A
0005433650597	27637	69	15C
0005433650727	27637	70	15D
0005433650616	27637	71	15E
0005435263681	27637	72	15F
0005433650596	27637	73	16A
0005433650684	27637	74	16C
0005435263682	27637	75	16D
0005433650687	27637	76	16E
0005433650724	27637	77	16F
0005433650689	27637	78	17A
0005433650626	27637	79	17C
0005433650609	27637	80	17D
0005433650617	27637	81	17E
0005433650641	27637	82	17F
0005433650683	27637	83	18A
0005433650675	27637	84	18C
0005433650679	27637	85	18D
0005433650637	27637	86	18E
0005433650643	27637	87	19A
0005435263692	27637	88	19C
0005433650636	27637	89	19D
0005433650607	27637	90	19E
0005433650650	27637	91	19F
0005433650682	27637	92	20A
0005433650725	27637	93	20C
0005433650638	27637	94	20D
0005433650586	27637	95	20E
0005433650651	27637	96	20F
0005433868863	4764	1	1A
0005433868848	4764	2	1B
0005433868871	4764	3	1C
0005433868866	4764	4	1D
0005433868872	4764	5	2A
0005433868845	4764	6	2B
0005435860483	4764	7	2C
0005433868854	4764	8	2D
0005435860485	4764	9	3A
0005433868867	4764	10	3B
0005433868837	4764	11	3C
0005435860493	4764	12	3D
0005433868855	4764	13	4A
0005433868870	4764	14	4C
0005433868852	4764	15	4D
0005433868874	4764	16	5A
0005435860490	4764	17	5B
0005435860492	4764	18	5C
0005433868851	4764	19	5D
0005433868846	4764	20	6A
0005433868850	4764	21	6B
0005433868873	4764	22	6C
0005433868859	4764	23	6D
0005433868858	4764	24	7A
0005433868869	4764	25	7B
0005433868840	4764	26	7C
0005433868862	4764	27	7D
0005433868842	4764	28	18A
0005433868843	4764	29	18B
0005433868841	4764	30	18C
0005433868853	4764	31	18D
0005433868868	4764	32	19A
0005433868864	4764	33	19B
0005435860484	4764	34	19C
0005433868856	4764	35	19D
0005433868839	4764	36	20A
0005433868847	4764	37	20C
0005433868861	4764	38	20B
0005433868860	4764	39	20D
0005435860491	4764	40	21A
0005433868857	4764	41	21B
0005433868876	4764	42	21C
0005433868838	4764	43	21D
0005433868875	4764	44	22A
0005435860482	4764	45	22B
0005433868844	4764	46	22C
0005433868849	4764	47	22D
0005433868877	4764	48	23A
0005433868865	4764	49	23B
0005433868544	32579	1	1A
0005433868355	32579	2	1B
0005433868328	32579	3	1C
0005433868497	32579	4	1D
0005433868389	32579	5	2A
0005433868434	32579	6	2B
0005433868579	32579	7	2C
0005433868460	32579	8	2D
0005433868581	32579	9	3A
0005433868382	32579	10	3B
0005433868570	32579	11	3C
0005433868354	32579	12	3D
0005433868474	32579	13	4A
0005433868397	32579	14	4B
0005433868388	32579	15	4C
0005433868326	32579	16	4D
0005433868369	32579	17	5A
0005433868490	32579	18	5B
0005433868461	32579	19	5C
0005433868572	32579	20	5D
0005433868580	32579	21	6A
0005433868398	32579	22	6B
0005433868367	32579	23	6C
0005433868489	32579	24	6D
0005433868473	32579	25	7A
0005433868306	32579	26	7B
0005433868380	32579	27	7C
0005433868603	32579	28	7D
0005433868548	32579	29	18A
0005433868469	32579	30	18B
0005433868443	32579	31	18C
0005433868431	32579	32	18D
0005433868430	32579	33	19A
0005433868403	32579	34	19B
0005433868442	32579	35	19C
0005433868547	32579	36	19D
0005433868372	32579	37	20A
0005433868329	32579	38	20B
0005433868327	32579	39	20C
0005433868585	32579	40	20D
0005433868454	32579	41	21A
0005433868602	32579	42	21B
0005433868404	32579	43	21C
0005433868520	32579	44	21D
0005433868368	32579	45	22A
0005433868462	32579	46	22B
0005433868405	32579	47	22C
0005433868390	32579	48	22D
0005433868429	32579	49	23A
0005433868331	32579	50	23B
0005435911456	3453	1	1A
0005435911467	3453	2	1B
0005435911463	3453	3	1C
0005434663553	3453	4	2A
0005434663549	3453	5	2B
0005435911497	3453	6	2C
0005434663554	3453	7	2D
0005435911461	3453	8	3C
0005435911462	3453	9	3D
0005435911468	3453	10	4A
0005435911464	3453	11	4B
0005434663545	3453	12	4C
0005434663546	3453	13	5B
0005434663551	3453	14	5C
0005435911457	3453	15	5D
0005434460527	3453	16	7B
0005434663548	3453	17	7C
0005434460528	3453	18	7D
0005435911496	3453	19	18A
0005434663543	3453	20	18B
0005434663544	3453	21	18D
0005434461668	3453	22	19A
0005434663550	3453	23	20B
0005434663547	3453	24	20D
0005434461669	3453	25	21B
0005434663555	3453	26	22B
0005435911447	3453	27	22D
0005434663552	3453	28	23A
0005434663511	12477	1	1C
0005434663379	12477	2	2B
0005434663409	12477	3	2C
0005434663402	12477	4	5C
0005434663404	12477	5	5D
0005434663420	12477	6	6A
0005435911529	12477	7	6B
0005434663368	12477	8	6C
0005435911531	12477	9	6D
0005434663434	12477	10	7B
0005435911532	12477	11	18B
0005434663413	12477	12	18D
0005434663380	12477	13	19B
0005434663416	12477	14	20A
0005435911527	12477	15	20C
0005435911530	12477	16	21A
0005434663433	12477	17	21B
0005434663415	12477	18	21D
0005435911528	12477	19	22C
0005434663381	12477	20	23A
0005435911533	12477	21	23B
0005433868429	14513	1	1A
0005433868490	14513	2	1B
0005433868520	14513	3	1C
0005433868404	14513	4	1D
0005433868497	14513	5	2A
0005433868547	14513	6	2B
0005433868489	14513	7	2C
0005433868460	14513	8	2D
0005433868388	14513	9	3A
0005433868405	14513	10	3B
0005433868389	14513	11	3C
0005433868570	14513	12	3D
0005433868327	14513	13	4A
0005433868331	14513	14	4B
0005433868329	14513	15	4C
0005433868367	14513	16	4D
0005433868579	14513	17	5A
0005433868326	14513	18	5B
0005433868398	14513	19	5C
0005433868403	14513	20	5D
0005433868461	14513	21	6A
0005433868469	14513	22	6C
0005433868328	14513	23	6B
0005433868431	14513	24	6D
0005433868442	14513	25	7A
0005433868306	14513	26	7B
0005433868474	14513	27	7C
0005433868354	14513	28	7D
0005433868397	14513	29	18A
0005433868372	14513	30	18B
0005433868368	14513	31	18C
0005433868585	14513	32	18D
0005433868355	14513	33	19A
0005433868382	14513	34	19B
0005433868443	14513	35	19C
0005433868454	14513	36	19D
0005433868602	14513	37	20A
0005433868544	14513	38	20B
0005433868572	14513	39	20C
0005433868462	14513	40	20D
0005433868434	14513	41	21A
0005433868603	14513	42	21B
0005433868390	14513	43	21C
0005433868548	14513	44	21D
0005433868581	14513	45	22A
0005433868430	14513	46	22B
0005433868473	14513	47	22C
0005433868380	14513	48	22D
0005433868369	14513	49	23A
0005433868580	14513	50	23B
0005433868809	32683	1	1A
0005433868818	32683	2	1B
0005433868825	32683	3	1C
0005433868806	32683	4	1D
0005433868800	32683	5	2A
0005433868830	32683	6	2B
0005433868814	32683	7	2C
0005433868815	32683	8	2D
0005433868798	32683	9	3A
0005433868812	32683	10	3B
0005433868811	32683	11	3C
0005433868801	32683	12	4A
0005433868833	32683	13	4C
0005433868835	32683	14	4D
0005433868823	32683	15	5A
0005433868834	32683	16	5B
0005433868797	32683	17	5C
0005433868802	32683	18	5D
0005433868808	32683	19	6A
0005433868810	32683	20	6B
0005433868832	32683	21	6C
0005433868817	32683	22	6D
0005433868820	32683	23	7A
0005433868828	32683	24	7B
0005433868803	32683	25	7C
0005433868804	32683	26	7D
0005433868836	32683	27	18A
0005433868821	32683	28	18B
0005433868822	32683	29	19C
0005433868826	32683	30	19D
0005433868831	32683	31	20A
0005433868799	32683	32	20B
0005433868824	32683	33	20C
0005433868805	32683	34	20D
0005433868827	32683	35	21B
0005433868807	32683	36	21C
0005433868819	32683	37	21D
0005433868813	32683	38	22A
0005433868829	32683	39	22C
0005433868816	32683	40	23B
0005432799573	12095	1	1B
0005432799448	12095	2	1C
0005432799482	12095	3	1D
0005432799479	12095	4	2A
0005432799417	12095	5	2B
0005432799587	12095	6	2D
0005432799508	12095	7	3A
0005432799586	12095	8	3D
0005432799483	12095	9	4A
0005432799484	12095	10	4C
0005432799534	12095	11	4D
0005432799547	12095	12	6B
0005432799485	12095	13	6D
0005432799581	12095	14	7B
0005432799515	12095	15	7D
0005432799493	12095	16	18A
0005432799546	12095	17	18B
0005432799509	12095	18	19A
0005432799580	12095	19	19B
0005432799444	12095	20	19C
0005432799450	12095	21	19D
0005432799585	12095	22	20A
0005432799416	12095	23	20D
0005432799535	12095	24	21B
0005432799474	12095	25	22A
0005432799422	12095	26	22B
0005432799451	12095	27	22D
0005432799480	12095	28	23B
0005432799726	14813	1	1B
0005432799717	14813	2	1C
0005432799730	14813	3	2A
0005432799714	14813	4	2D
0005432799733	14813	5	3B
0005432799722	14813	6	4B
0005432799709	14813	7	4C
0005432799721	14813	8	4D
0005432799707	14813	9	5B
0005432799713	14813	10	5C
0005432799727	14813	11	6B
0005432799720	14813	12	6C
0005432799725	14813	13	6D
0005432799731	14813	14	7A
0005432799716	14813	15	7B
0005432799729	14813	16	7D
0005432799715	14813	17	18B
0005432799724	14813	18	18C
0005432799718	14813	19	19B
0005432799723	14813	20	19C
0005432799711	14813	21	19D
0005432799708	14813	22	20B
0005432799719	14813	23	21C
0005432799728	14813	24	22A
0005432799710	14813	25	22B
0005432799732	14813	26	22C
0005432799712	14813	27	23A
0005435311057	7043	1	1A
0005435293297	7043	2	1C
0005434408424	7043	3	1D
0005434299814	7043	4	1F
0005434299798	7043	5	2A
0005435293291	7043	6	2F
0005435293234	7043	7	3C
0005434299797	7043	8	3D
0005434299803	7043	9	4A
0005435293296	7043	10	4B
0005434408396	7043	11	4D
0005434408419	7043	12	5A
0005435311056	7043	13	4F
0005434299806	7043	14	5B
0005434408407	7043	15	5D
0005434408445	7043	16	5E
0005434299801	7043	17	5F
0005434408386	7043	18	6B
0005434408431	7043	19	6A
0005434408404	7043	20	6C
0005434408443	7043	21	6D
0005434299812	7043	22	6E
0005434408408	7043	23	7A
0005434408444	7043	24	6F
0005434299796	7043	25	7B
0005434408438	7043	26	7C
0005432154010	7043	27	7D
0005434408433	7043	28	7F
0005434408384	7043	29	8A
0005434408390	7043	30	8B
0005434408410	7043	31	8C
0005434408388	7043	32	8D
0005434408382	7043	33	8F
0005434299805	7043	34	9A
0005434408441	7043	35	9B
0005434408428	7043	36	9D
0005434408436	7043	37	9C
0005434299808	7043	38	9E
0005434299810	7043	39	9F
0005434299793	7043	40	10B
0005434299792	7043	41	10C
0005434408417	7043	42	10E
0005435311041	7043	43	10D
0005435293277	7043	44	11A
0005434408399	7043	45	11B
0005435293233	7043	46	11D
0005434299790	7043	47	11C
0005432154013	7043	48	11E
0005435293276	7043	49	11F
0005434408414	7043	50	12A
0005435293257	7043	51	12B
0005435293265	7043	52	12D
0005434408383	7043	53	12C
0005432108276	7043	54	12E
0005434408401	7043	55	13B
0005432154011	7043	56	13A
0005435293210	7043	57	13C
0005434408440	7043	58	13D
0005434408389	7043	59	13E
0005434408418	7043	60	13F
0005434299791	7043	61	14B
0005432154012	7043	62	14A
0005435311085	7043	63	14C
0005435311052	7043	64	14E
0005434299809	7043	65	14D
0005434408406	7043	66	15A
0005434408435	7043	67	14F
0005434408387	7043	68	15B
0005435293206	7043	69	15C
0005434408413	7043	70	15D
0005434408394	7043	71	15F
0005434408403	7043	72	15E
0005432154009	7043	73	16A
0005434408434	7043	74	16B
0005434299795	7043	75	16C
0005434408432	7043	76	16D
0005434408425	7043	77	16F
0005435311053	7043	78	17A
0005434408385	7043	79	17B
0005434408446	7043	80	17D
0005434408415	7043	81	17C
0005434408416	7043	82	17E
0005434408405	7043	83	18A
0005434408423	7043	84	17F
0005434408391	7043	85	18B
0005434408437	7043	86	18C
0005434299794	7043	87	18E
0005434408422	7043	88	18D
0005434408397	7043	89	18F
0005434408426	7043	90	19A
0005432108277	7043	91	19C
0005434408442	7043	92	19B
0005434299802	7043	93	19D
0005434408393	7043	94	19E
0005435293211	7043	95	19F
0005434408421	7043	96	20A
0005434408412	7043	97	20C
0005434408400	7043	98	20D
0005435311042	7043	99	20E
0005434408430	7043	100	20F
0005434299811	7043	101	21A
0005434408392	7043	102	21C
0005434408411	7043	103	21B
0005434299804	7043	104	21D
0005434408409	7043	105	21E
0005435311048	7043	106	21F
0005434408427	7043	107	22B
0005434408439	7043	108	22A
0005434408420	7043	109	22C
0005434299799	7043	110	22D
0005434299807	7043	111	22E
0005434408429	7043	112	23A
0005434299813	7043	113	22F
0005434299800	7043	114	23B
0005434408395	7043	115	23C
0005435293207	7043	116	23D
0005434408402	7043	117	23F
0005434408398	7043	118	23E
0005434299615	26915	1	1C
0005434407688	26915	2	1A
0005434407885	26915	3	1D
0005434408062	26915	4	1F
0005434407774	26915	5	2C
0005434299538	26915	6	2A
0005434407765	26915	7	2D
0005434299665	26915	8	3A
0005434407892	26915	9	2F
0005434407585	26915	10	3C
0005434299669	26915	11	3D
0005434407779	26915	12	3F
0005434407745	26915	13	4A
0005435311174	26915	14	4B
0005435311170	26915	15	4D
0005435293377	26915	16	4C
0005435311172	26915	17	4E
0005434407963	26915	18	5A
0005434407915	26915	19	4F
0005435293384	26915	20	5B
0005434407658	26915	21	5D
0005434407700	26915	22	5E
0005435293380	26915	23	5F
0005435293376	26915	24	6A
0005434407825	26915	25	6B
0005434407709	26915	26	6D
0005434407926	26915	27	6F
0005434407707	26915	28	6E
0005435293382	26915	29	7A
0005434299608	26915	30	7C
0005434407635	26915	31	7B
0005432058420	26915	32	7E
0005434299617	26915	33	7D
0005434407661	26915	34	7F
0005434407806	26915	35	8B
0005434407835	26915	36	8C
0005435311167	26915	37	8D
0005434299702	26915	38	8F
0005435293383	26915	39	9A
0005434299667	26915	40	9B
0005434407801	26915	41	9C
0005435293385	26915	42	9D
0005434407818	26915	43	9F
0005435293386	26915	44	9E
0005434408087	26915	45	10B
0005434407805	26915	46	10D
0005434299676	26915	47	11A
0005434407884	26915	48	10E
0005435311165	26915	49	11B
0005435311163	26915	50	11C
0005434407593	26915	51	11D
0005434299616	26915	52	11F
0005434407800	26915	53	12A
0005434407942	26915	54	12C
0005434407525	26915	55	12B
0005434407634	26915	56	12D
0005434407687	26915	57	12E
0005435293379	26915	58	12F
0005435311176	26915	59	13A
0005434407913	26915	60	13B
0005434407646	26915	61	13D
0005434407804	26915	62	13C
0005434299646	26915	63	13F
0005434407817	26915	64	14B
0005435293375	26915	65	14A
0005434299674	26915	66	14D
0005434407813	26915	67	14C
0005434299639	26915	68	14E
0005434299638	26915	69	15A
0005434407799	26915	70	14F
0005434407861	26915	71	15B
0005434407943	26915	72	15C
0005434407881	26915	73	15D
0005434407816	26915	74	15E
0005434407880	26915	75	15F
0005434407626	26915	76	16E
0005435311171	26915	77	16D
0005434299558	26915	78	17A
0005434407819	26915	79	16F
0005434407914	26915	80	17B
0005435311177	26915	81	17C
0005435311169	26915	82	17E
0005432058418	26915	83	17D
0005434299594	26915	84	17F
0005434407929	26915	85	18A
0005434407766	26915	86	18B
0005435293378	26915	87	18C
0005434299614	26915	88	18E
0005435311164	26915	89	18F
0005435311168	26915	90	19B
0005434407708	26915	91	19C
0005434407775	26915	92	19D
0005434299673	26915	93	19F
0005434299626	26915	94	20A
0005435293387	26915	95	20C
0005434407647	26915	96	20B
0005434407841	26915	97	20D
0005434407787	26915	98	20E
0005435293381	26915	99	20F
0005434407850	26915	100	21B
0005435311166	26915	101	21A
0005434407736	26915	102	21D
0005434407588	26915	103	21E
0005432058419	26915	104	21F
0005434407657	26915	105	22B
0005435311173	26915	106	22C
0005434407587	26915	107	22D
0005435311175	26915	108	22E
0005434407656	26915	109	22F
0005434407782	26915	110	23D
0005434299668	26915	111	23C
0005434408035	26915	112	23E
0005432604740	6431	1	1A
0005432604762	6431	2	1B
0005432604756	6431	3	1C
0005435218120	6431	4	1D
0005432604752	6431	5	2A
0005432604765	6431	6	2B
0005432604743	6431	7	2C
0005432604742	6431	8	2D
0005434512157	6431	9	3A
0005432604777	6431	10	3B
0005432604773	6431	11	3C
0005432604768	6431	12	3D
0005432604753	6431	13	4A
0005432604759	6431	14	4B
0005434512156	6431	15	4C
0005432604767	6431	16	4D
0005432604771	6431	17	5A
0005432604764	6431	18	5B
0005432604745	6431	19	5C
0005432604763	6431	20	5D
0005432604774	6431	21	6A
0005432604758	6431	22	6B
0005432604751	6431	23	6D
0005432604746	6431	24	7A
0005432604755	6431	25	7B
0005432604757	6431	26	7C
0005432604761	6431	27	7D
0005432604749	6431	28	18A
0005432604775	6431	29	18B
0005432604772	6431	30	18C
0005432604760	6431	31	18D
0005432604741	6431	32	19A
0005432604769	6431	33	19B
0005432604770	6431	34	19C
0005432604750	6431	35	20A
0005432604747	6431	36	20C
0005432604739	6431	37	20D
0005432604754	6431	38	21A
0005432604744	6431	39	21B
0005432604766	6431	40	21C
0005432604778	6431	41	22A
0005432604776	6431	42	22B
0005432604737	6431	43	22D
0005432604738	6431	44	23A
0005432604748	6431	45	23B
0005432604402	21355	1	1A
0005432604569	21355	2	1B
0005432604442	21355	3	1C
0005432604336	21355	4	1D
0005432604486	21355	5	2A
0005432604439	21355	6	2B
0005432604114	21355	7	2C
0005432604501	21355	8	2D
0005432604487	21355	9	3A
0005432604268	21355	10	3B
0005432604458	21355	11	3C
0005432604319	21355	12	3D
0005434512126	21355	13	4A
0005432604347	21355	14	4B
0005432604500	21355	15	4C
0005432604219	21355	16	5A
0005432604113	21355	17	4D
0005432604283	21355	18	5B
0005432604322	21355	19	5C
0005432604497	21355	20	5D
0005434512125	21355	21	6A
0005432604341	21355	22	6B
0005432604313	21355	23	6C
0005432604343	21355	24	6D
0005432604181	21355	25	7A
0005432604282	21355	26	7B
0005432604478	21355	27	7C
0005432604210	21355	28	7D
0005432604186	21355	29	18A
0005432604267	21355	30	18B
0005432604371	21355	31	18C
0005432604311	21355	32	18D
0005432604244	21355	33	19A
0005432604367	21355	34	19B
0005432604382	21355	35	19C
0005432604452	21355	36	19D
0005432604438	21355	37	20A
0005432604392	21355	38	20B
0005432604237	21355	39	20C
0005432604422	21355	40	20D
0005432604372	21355	41	21A
0005432604383	21355	42	21B
0005432604320	21355	43	21C
0005432604180	21355	44	21D
0005432604342	21355	45	22A
0005432604344	21355	46	22B
0005432604417	21355	47	22C
0005432604441	21355	48	22D
0005432604418	21355	49	23A
0005432604509	21355	50	23B
0005434907426	15010	1	1A
0005433251801	15010	2	1D
0005433251799	15010	3	1F
0005433251785	15010	4	2A
0005434907253	15010	5	2D
0005433251798	15010	6	2F
0005434907428	15010	7	3A
0005434907427	15010	8	3D
0005434907368	15010	9	3F
0005434907409	15010	10	4A
0005433251789	15010	11	4C
0005434907337	15010	12	4D
0005434907251	15010	13	4E
0005434907281	15010	14	4F
0005434907394	15010	15	5A
0005434907446	15010	16	5C
0005434907367	15010	17	5E
0005434907108	15010	18	5F
0005434907308	15010	19	6A
0005433251811	15010	20	6C
0005434907317	15010	21	6D
0005434907496	15010	22	6E
0005434907498	15010	23	6F
0005433251791	15010	24	7A
0005434907120	15010	25	7C
0005433251810	15010	26	7D
0005434907416	15010	27	7E
0005434907199	15010	28	8A
0005433251792	15010	29	8C
0005434907515	15010	30	8D
0005434907270	15010	31	8E
0005434907216	15010	32	8F
0005434907310	15010	33	9A
0005434907518	15010	34	9C
0005433251795	15010	35	9D
0005434907093	15010	36	9E
0005434907441	15010	37	9F
0005434907257	15010	38	10A
0005434907291	15010	39	10D
0005433251784	15010	40	10E
0005434907296	15010	41	10F
0005434907286	15010	42	11A
0005433251783	15010	43	11C
0005434907287	15010	44	11D
0005433251800	15010	45	11E
0005434907255	15010	46	11F
0005433251806	15010	47	12A
0005434907360	15010	48	12C
0005434907332	15010	49	12D
0005433251804	15010	50	12E
0005433251809	15010	51	12F
0005433251808	15010	52	13A
0005434907252	15010	53	13C
0005434907309	15010	54	13D
0005433251803	15010	55	13E
0005434907331	15010	56	14A
0005434907514	15010	57	14D
0005433251805	15010	58	14E
0005434907260	15010	59	14F
0005434907355	15010	60	15A
0005434907519	15010	61	15C
0005434907392	15010	62	15D
0005433251793	15010	63	15E
0005434907292	15010	64	15F
0005434907329	15010	65	16A
0005433251788	15010	66	16C
0005433251796	15010	67	16D
0005434907448	15010	68	16E
0005433251807	15010	69	16F
0005434907271	15010	70	17A
0005433251786	15010	71	17C
0005433251797	15010	72	17D
0005434907333	15010	73	17E
0005434907447	15010	74	17F
0005434907213	15010	75	18A
0005434907222	15010	76	18C
0005434907269	15010	77	18F
0005433251802	15010	78	19A
0005433251790	15010	79	19C
0005434907330	15010	80	19D
0005434907297	15010	81	19E
0005433251787	15010	82	19F
0005434907338	15010	83	20A
0005433251782	15010	84	20C
0005434907234	15010	85	20D
0005433251794	15010	86	20E
0005434907256	15010	87	20F
0005434907755	25845	1	1C
0005434907765	25845	2	1D
0005433251427	25845	3	1F
0005434907753	25845	4	2C
0005434907782	25845	5	2D
0005433251627	25845	6	2F
0005434907746	25845	7	3A
0005434907783	25845	8	3C
0005434907778	25845	9	3D
0005433251404	25845	10	3F
0005434907797	25845	11	4A
0005434907796	25845	12	4C
0005434907785	25845	13	4D
0005434907781	25845	14	4F
0005433251626	25845	15	5A
0005434907772	25845	16	5D
0005433251500	25845	17	5F
0005434907763	25845	18	6C
0005434907754	25845	19	6D
0005433251449	25845	20	6E
0005434907761	25845	21	6F
0005434907749	25845	22	7A
0005433251439	25845	23	7C
0005434907798	25845	24	7D
0005434907794	25845	25	7E
0005434907758	25845	26	7F
0005433251565	25845	27	8C
0005434907757	25845	28	8D
0005433251477	25845	29	8F
0005434907777	25845	30	9E
0005434907776	25845	31	9F
0005433251590	25845	32	10C
0005434907762	25845	33	10D
0005434907767	25845	34	10E
0005433251484	25845	35	10F
0005434907792	25845	36	11A
0005434907784	25845	37	11C
0005434907750	25845	38	11D
0005434907791	25845	39	11E
0005434907790	25845	40	11F
0005434907769	25845	41	12C
0005434907764	25845	42	12E
0005434907786	25845	43	12F
0005433251436	25845	44	13A
0005434907787	25845	45	13C
0005434907768	25845	46	13D
0005434907799	25845	47	13E
0005434907751	25845	48	13F
0005433251419	25845	49	14A
0005434907752	25845	50	14C
0005433251403	25845	51	14D
0005433251476	25845	52	14E
0005434907760	25845	53	14F
0005434907771	25845	54	15A
0005434907779	25845	55	15C
0005433251584	25845	56	15D
0005434907759	25845	57	16D
0005434907795	25845	58	16E
0005434907774	25845	59	16F
0005434907775	25845	60	17A
0005433251595	25845	61	17C
0005434907766	25845	62	17D
0005434907789	25845	63	17F
0005434907793	25845	64	18E
0005434907747	25845	65	18F
0005434907756	25845	66	19C
0005434907780	25845	67	19D
0005434907800	25845	68	19E
0005433251585	25845	69	19F
0005434907748	25845	70	20A
0005434907788	25845	71	20C
0005434907770	25845	72	20D
0005434907773	25845	73	20F
0005433009103	14170	1	1A
0005433009118	14170	2	1F
0005433009114	14170	3	2D
0005433009081	14170	4	2F
0005433009087	14170	5	3A
0005433009090	14170	6	3F
0005433009104	14170	7	4C
0005433009088	14170	8	5A
0005433009096	14170	9	5C
0005433009084	14170	10	5D
0005433009102	14170	11	5E
0005433810532	14170	12	5F
0005433009083	14170	13	6A
0005433009098	14170	14	6E
0005433009111	14170	15	7A
0005433009101	14170	16	7C
0005433009079	14170	17	7D
0005433009100	14170	18	8C
0005433009105	14170	19	8E
0005433009091	14170	20	9C
0005433009074	14170	21	9E
0005433009123	14170	22	9F
0005433009076	14170	23	10D
0005433009093	14170	24	10E
0005433009085	14170	25	11C
0005433009120	14170	26	11E
0005433009097	14170	27	11F
0005433009113	14170	28	12E
0005433009089	14170	29	13C
0005433009092	14170	30	13D
0005433009108	14170	31	13E
0005433009106	14170	32	14A
0005433009115	14170	33	14C
0005433009099	14170	34	14D
0005433009086	14170	35	14F
0005433009095	14170	36	15A
0005433009117	14170	37	15C
0005433009080	14170	38	15E
0005433009110	14170	39	15F
0005433009082	14170	40	16C
0005433009107	14170	41	16D
0005433009122	14170	42	16F
0005433009077	14170	43	17C
0005433009075	14170	44	17E
0005433009119	14170	45	17F
0005433009078	14170	46	18C
0005433009109	14170	47	18D
0005433009121	14170	48	19A
0005433009116	14170	49	19C
0005433009094	14170	50	19D
0005433009112	14170	51	19F
0005433810531	14170	52	20E
0005433008563	22860	1	1A
0005433008585	22860	2	1C
0005433008679	22860	3	2A
0005433008577	22860	4	2C
0005433008664	22860	5	2D
0005433810581	22860	6	2F
0005433008663	22860	7	3A
0005433008625	22860	8	3C
0005433008741	22860	9	3F
0005433008794	22860	10	4A
0005433008681	22860	11	4D
0005433008822	22860	12	4E
0005433008584	22860	13	4F
0005433008678	22860	14	5A
0005433008810	22860	15	5D
0005433008782	22860	16	5F
0005433008624	22860	17	6D
0005433008603	22860	18	6E
0005433008753	22860	19	8A
0005433008686	22860	20	8D
0005433008599	22860	21	9E
0005433008740	22860	22	9F
0005433810582	22860	23	10D
0005433008614	22860	24	10E
0005433008542	22860	25	11A
0005433008751	22860	26	11C
0005433008601	22860	27	11D
0005433008600	22860	28	11F
0005433008564	22860	29	12A
0005433008811	22860	30	12C
0005433008705	22860	31	12D
0005433008562	22860	32	12E
0005433008633	22860	33	13C
0005433008619	22860	34	13D
0005433008647	22860	35	13E
0005433008688	22860	36	13F
0005433008543	22860	37	14C
0005433008604	22860	38	14F
0005433008662	22860	39	15A
0005433008592	22860	40	15C
0005433008665	22860	41	15E
0005433810580	22860	42	16A
0005433008687	22860	43	16C
0005433008644	22860	44	16D
0005433008618	22860	45	16E
0005433008700	22860	46	17A
0005433008606	22860	47	17C
0005433008586	22860	48	17D
0005433008590	22860	49	17F
0005433008752	22860	50	18A
0005433008561	22860	51	18E
0005433008591	22860	52	18F
0005433008719	22860	53	19C
0005433008783	22860	54	19E
0005433008839	22860	55	19F
0005433008680	22860	56	20A
0005433008669	22860	57	20D
0005433008648	22860	58	20C
0005433008798	22860	59	20F
0005434925780	14961	1	4C
0005434925777	14961	2	4E
0005434925817	14961	3	5E
0005434925811	14961	4	5F
0005434925853	14961	5	7A
0005434925718	14961	6	7F
0005434925779	14961	7	8A
0005434925820	14961	8	8C
0005434925806	14961	9	8F
0005434925832	14961	10	9A
0005434925807	14961	11	9E
0005434925786	14961	12	9F
0005434925855	14961	13	10A
0005434925778	14961	14	10D
0005434925839	14961	15	10F
0005434925852	14961	16	11A
0005434925816	14961	17	11F
0005434925818	14961	18	12D
0005434925785	14961	19	14D
0005434925781	14961	20	14E
0005434925797	14961	21	14F
0005434925856	14961	22	15A
0005434925717	14961	23	15E
0005434925808	14961	24	15F
0005434925819	14961	25	16C
0005434925851	14961	26	16E
0005434925836	14961	27	16F
0005434925849	14961	28	19E
0005434925758	14961	29	19F
0005434925837	14961	30	20F
0005434926122	20504	1	1C
0005434926114	20504	2	2A
0005434926131	20504	3	2C
0005434926120	20504	4	3A
0005434926098	20504	5	3D
0005434926119	20504	6	3F
0005434926113	20504	7	4A
0005434926123	20504	8	4C
0005434926109	20504	9	5E
0005434926105	20504	10	5F
0005434926132	20504	11	6A
0005434926126	20504	12	6C
0005434926111	20504	13	6D
0005434926116	20504	14	6E
0005434926106	20504	15	9C
0005434926128	20504	16	9D
0005434926118	20504	17	9E
0005434926135	20504	18	9F
0005434926108	20504	19	10E
0005434926127	20504	20	10F
0005434926101	20504	21	11D
0005434926103	20504	22	12F
0005434926134	20504	23	13F
0005434926100	20504	24	14C
0005434926129	20504	25	14F
0005434926124	20504	26	15E
0005434926133	20504	27	16D
0005434926099	20504	28	16F
0005434926125	20504	29	17D
0005434926130	20504	30	17E
0005434926121	20504	31	17F
0005434926104	20504	32	19A
0005434926112	20504	33	19C
0005434926115	20504	34	19D
0005434926107	20504	35	19E
0005434926102	20504	36	19F
0005434926110	20504	37	20C
0005434926117	20504	38	20F
0005435488062	15795	1	1B
0005435488058	15795	2	1C
0005435999273	15795	3	2A
0005435999282	15795	4	2C
0005435999283	15795	5	2D
0005435999255	15795	6	3A
0005435488052	15795	7	3C
0005435999266	15795	8	3D
0005435488061	15795	9	4A
0005435488069	15795	10	4B
0005435488057	15795	11	4C
0005435999285	15795	12	4D
0005435999267	15795	13	5A
0005435488064	15795	14	5B
0005435488063	15795	15	5C
0005435999274	15795	16	5D
0005435999275	15795	17	6A
0005435999231	15795	18	6B
0005435999254	15795	19	6D
0005435999212	15795	20	7A
0005435488056	15795	21	7B
0005435488054	15795	22	7C
0005435488053	15795	23	7D
0005435488065	15795	24	18A
0005435999264	15795	25	18B
0005435999286	15795	26	18C
0005435999186	15795	27	19A
0005435488073	15795	28	18D
0005435488059	15795	29	19B
0005435488068	15795	30	19C
0005435488071	15795	31	19D
0005435488067	15795	32	20A
0005435999298	15795	33	20B
0005435488072	15795	34	20D
0005435999287	15795	35	21A
0005435488055	15795	36	21B
0005435488070	15795	37	21C
0005435999262	15795	38	21D
0005435999249	15795	39	22A
0005435999211	15795	40	22B
0005435999263	15795	41	22C
0005435488066	15795	42	22D
0005435999297	15795	43	23A
0005435488060	15795	44	23B
0005435999407	19702	1	1A
0005435999408	19702	2	1B
0005435487816	19702	3	1C
0005435487822	19702	4	2A
0005435999416	19702	5	2B
0005435999411	19702	6	3A
0005435999422	19702	7	3B
0005435487880	19702	8	3C
0005435999406	19702	9	3D
0005435487867	19702	10	4B
0005435487872	19702	11	4C
0005435487853	19702	12	5B
0005435999423	19702	13	5C
0005435487769	19702	14	6A
0005435999413	19702	15	6C
0005435999420	19702	16	6D
0005435487883	19702	17	7A
0005435999410	19702	18	7B
0005435487854	19702	19	7D
0005435487817	19702	20	18A
0005435999412	19702	21	18B
0005435999419	19702	22	18C
0005435487836	19702	23	18D
0005435487882	19702	24	19A
0005435487877	19702	25	19B
0005435487914	19702	26	19C
0005435999421	19702	27	19D
0005435999409	19702	28	20A
0005435487895	19702	29	20B
0005435487835	19702	30	21B
0005435999405	19702	31	21D
0005435999415	19702	32	22A
0005435999417	19702	33	22B
0005435999418	19702	34	22C
0005435487881	19702	35	22D
0005435487894	19702	36	23A
0005435999414	19702	37	23B
0005435839744	5999	1	1A
0005432537067	5999	2	1D
0005435839749	5999	3	2F
0005435472829	5999	4	3A
0005435839763	5999	5	4D
0005435839756	5999	6	5C
0005435839753	5999	7	5A
0005435839736	5999	8	5F
0005432659728	5999	9	6D
0005432537066	5999	10	6E
0005435472883	5999	11	7C
0005432660840	5999	12	7E
0005435839751	5999	13	8A
0005432660841	5999	14	7F
0005435839764	5999	15	8D
0005435839743	5999	16	8C
0005432658615	5999	17	8E
0005435472861	5999	18	9A
0005432658614	5999	19	9E
0005432537060	5999	20	10C
0005435839761	5999	21	11C
0005435472862	5999	22	12A
0005435839750	5999	23	12D
0005435839745	5999	24	12B
0005432142285	5999	25	13D
0005435839760	5999	26	14B
0005435839758	5999	27	15D
0005435472863	5999	28	15C
0005435472815	5999	29	15F
0005435839752	5999	30	16C
0005435839757	5999	31	16E
0005432142283	5999	32	16D
0005435472858	5999	33	16F
0005435472855	5999	34	17B
0005435839738	5999	35	17A
0005432142284	5999	36	17D
0005435839755	5999	37	17C
0005435839735	5999	38	17E
0005435472913	5999	39	18B
0005435839759	5999	40	18A
0005435472884	5999	41	18D
0005435839754	5999	42	18C
0005435839737	5999	43	18F
0005435839747	5999	44	18E
0005432659730	5999	45	19A
0005435839762	5999	46	19C
0005432537059	5999	47	19B
0005435839739	5999	48	20A
0005435839740	5999	49	20C
0005435839742	5999	50	20E
0005435839748	5999	51	21A
0005432537062	5999	52	20F
0005435472819	5999	53	21D
0005435839746	5999	54	21C
0005432659729	5999	55	21B
0005435839741	5999	56	21E
0005435617235	5999	57	21F
0005435472969	18043	1	1D
0005435472970	18043	2	1C
0005435472982	18043	3	2C
0005432660821	18043	4	2A
0005435839520	18043	5	2D
0005435472984	18043	6	3A
0005435839550	18043	7	3D
0005435472981	18043	8	4C
0005432664138	18043	9	4A
0005435839548	18043	10	5A
0005432664133	18043	11	5D
0005435839401	18043	12	6C
0005435839488	18043	13	7C
0005432537082	18043	14	7D
0005435839402	18043	15	7F
0005435839547	18043	16	8E
0005435839549	18043	17	9A
0005435839539	18043	18	9C
0005435472971	18043	19	9B
0005435472979	18043	20	9E
0005435839573	18043	21	10C
0005435472983	18043	22	10B
0005435839489	18043	23	10E
0005432660822	18043	24	10F
0005435472980	18043	25	11B
0005432664134	18043	26	12A
0005435472975	18043	27	12C
0005435839516	18043	28	12E
0005435839529	18043	29	12D
0005435472973	18043	30	13A
0005435839391	18043	31	13E
0005435472977	18043	32	14C
0005435472972	18043	33	14B
0005435839490	18043	34	14A
0005435839326	18043	35	14F
0005432537081	18043	36	15B
0005435839483	18043	37	15C
0005435839413	18043	38	16A
0005435839449	18043	39	16C
0005435839400	18043	40	17A
0005435839554	18043	41	17D
0005435472978	18043	42	17C
0005435472974	18043	43	17F
0005435839588	18043	44	17E
0005435839507	18043	45	18A
0005435839493	18043	46	18C
0005435472976	18043	47	18E
0005435839589	18043	48	18D
0005432660811	18043	49	19E
0005435839559	18043	50	19F
0005432664132	18043	51	20A
0005435839487	18043	52	20D
0005435839528	18043	53	20E
0005435472968	18043	54	20F
0005435839506	18043	55	21E
0005435839600	18043	56	21F
0005433285419	23050	1	1A
0005433285420	23050	2	1D
0005433285284	23050	3	2F
0005435104001	23050	4	4A
0005435104003	23050	5	4B
0005433285358	23050	6	4F
0005433285285	23050	7	5E
0005433285329	23050	8	6A
0005433285357	23050	9	6F
0005433285227	23050	10	6E
0005433285384	23050	11	8C
0005433285296	23050	12	8F
0005435103994	23050	13	9C
0005433285340	23050	14	9D
0005435104009	23050	15	10D
0005435104002	23050	16	11E
0005435104007	23050	17	12B
0005433285350	23050	18	12C
0005433285377	23050	19	13A
0005433285379	23050	20	13C
0005435104000	23050	21	14A
0005433285362	23050	22	14C
0005435103996	23050	23	14F
0005433285432	23050	24	15D
0005433285330	23050	25	15F
0005433285339	23050	26	15E
0005433285369	23050	27	16A
0005433285378	23050	28	17A
0005435103998	23050	29	17D
0005435103997	23050	30	17F
0005433285408	23050	31	18E
0005433285430	23050	32	18D
0005433285283	23050	33	19C
0005435103999	23050	34	19E
0005433285361	23050	35	20A
0005435104008	23050	36	20D
0005435103995	23050	37	21B
0005435104004	23050	38	21E
0005435104005	23050	39	22B
0005433285415	23050	40	22C
0005433285295	23050	41	22F
0005435104006	23050	42	23A
0005433285314	23050	43	23F
0005433285627	32064	1	1D
0005433285632	32064	2	3D
0005433285630	32064	3	5A
0005433285620	32064	4	5B
0005433285634	32064	5	6B
0005433285628	32064	6	6C
0005433285626	32064	7	6D
0005433285631	32064	8	7A
0005433285645	32064	9	7F
0005433285621	32064	10	9A
0005433285642	32064	11	8F
0005433285615	32064	12	9B
0005433285643	32064	13	9C
0005433285624	32064	14	11B
0005435103916	32064	15	11E
0005433285636	32064	16	11D
0005433285617	32064	17	12D
0005433285623	32064	18	13A
0005435103926	32064	19	13F
0005433285638	32064	20	14D
0005433285622	32064	21	15A
0005433285629	32064	22	15D
0005433285618	32064	23	16A
0005435103920	32064	24	17D
0005435103910	32064	25	18C
0005433285641	32064	26	18E
0005433285633	32064	27	18F
0005433285625	32064	28	19A
0005433285616	32064	29	19E
0005435103935	32064	30	19F
0005435103934	32064	31	20C
0005433285644	32064	32	20B
0005433285640	32064	33	20E
0005433285637	32064	34	21E
0005433285619	32064	35	21F
0005435103927	32064	36	22C
0005433285635	32064	37	22D
0005433285614	32064	38	23B
0005435103917	32064	39	23D
0005433285639	32064	40	23C
0005434067739	30604	1	1C
0005432528190	30604	2	1A
0005432527849	30604	3	1D
0005434067464	30604	4	2A
0005435214303	30604	5	1K
0005432528263	30604	6	1H
0005432528451	30604	7	2D
0005435214284	30604	8	2C
0005432211584	30604	9	2G
0005434067806	30604	10	3A
0005435214338	30604	11	2K
0005434067877	30604	12	2H
0005435214297	30604	13	3D
0005434067775	30604	14	3C
0005432528565	30604	15	3H
0005435214288	30604	16	3G
0005435214321	30604	17	4A
0005435214277	30604	18	3K
0005432535831	30604	19	4G
0005435214308	30604	20	4D
0005435214273	30604	21	4H
0005432528115	30604	22	5C
0005435214309	30604	23	5G
0005434067726	30604	24	11A
0005432211582	30604	25	5K
0005432528110	30604	26	5H
0005435214301	30604	27	11D
0005432528524	30604	28	11G
0005432528739	30604	29	11F
0005432527682	30604	30	11E
0005435214328	30604	31	11K
0005434067795	30604	32	11H
0005434067638	30604	33	12C
0005432527917	30604	34	12E
0005432211588	30604	35	12D
0005432528273	30604	36	12G
0005432528496	30604	37	12F
0005435214287	30604	38	12K
0005432527948	30604	39	12H
0005434067820	30604	40	13A
0005432528724	30604	41	13F
0005435214333	30604	42	13E
0005432528971	30604	43	13D
0005435214279	30604	44	14A
0005432528343	30604	45	13K
0005435214275	30604	46	14D
0005434067535	30604	47	14C
0005432159907	30604	48	14E
0005434067293	30604	49	14K
0005435214316	30604	50	14H
0005432528220	30604	51	14G
0005432528768	30604	52	15C
0005432527889	30604	53	15A
0005432528283	30604	54	15E
0005432528189	30604	55	15D
0005432528432	30604	56	15H
0005435214339	30604	57	16A
0005432528585	30604	58	15K
0005435214298	30604	59	16D
0005432528682	30604	60	16C
0005432528651	30604	61	16F
0005435214329	30604	62	16E
0005432528487	30604	63	16K
0005435214290	30604	64	16H
0005435725657	30604	65	16G
0005432528749	30604	66	17C
0005432159909	30604	67	17A
0005432528428	30604	68	17E
0005433656708	30604	69	17D
0005432528119	30604	70	17F
0005435214335	30604	71	18A
0005435214292	30604	72	18D
0005434067700	30604	73	18C
0005434067805	30604	74	18G
0005434067609	30604	75	18F
0005432528427	30604	76	18J
0005432528415	30604	77	18H
0005435214332	30604	78	19B
0005432528117	30604	79	19A
0005434067565	30604	80	18K
0005432528680	30604	81	19D
0005434067483	30604	82	19F
0005432211586	30604	83	20A
0005434067634	30604	84	19K
0005435214319	30604	85	20B
0005432528452	30604	86	20E
0005432528333	30604	87	20D
0005432527914	30604	88	20G
0005432527848	30604	89	20F
0005435214293	30604	90	20K
0005435214315	30604	91	20J
0005435214280	30604	92	20H
0005432528294	30604	93	21A
0005434067907	30604	94	21D
0005434067635	30604	95	21C
0005434067842	30604	96	21B
0005434067528	30604	97	21F
0005435214330	30604	98	21H
0005434067552	30604	99	21G
0005434067684	30604	100	22A
0005432537054	30604	101	21K
0005432528009	30604	102	22C
0005432527806	30604	103	22B
0005435214320	30604	104	22H
0005432528302	30604	105	22K
0005432528071	30604	106	22J
0005432528288	30604	107	23A
0005435725659	30604	108	23F
0005432528346	30604	109	23E
0005432527689	30604	110	23J
0005432528081	30604	111	23H
0005432528326	30604	112	23G
0005435214327	30604	113	24F
0005432528315	30604	114	24E
0005432528078	30604	115	25B
0005432528570	30604	116	24G
0005434067812	30604	117	25D
0005435214283	30604	118	25C
0005432528425	30604	119	25E
0005432528131	30604	120	25H
0005432533302	30604	121	25G
0005435214302	30604	122	25F
0005432528876	30604	123	25K
0005434067414	30604	124	25J
0005432528523	30604	125	26B
0005432528582	30604	126	26A
0005434067564	30604	127	26E
0005432527737	30604	128	26G
0005432528018	30604	129	26F
0005434067776	30604	130	26J
0005434067396	30604	131	26H
0005435214299	30604	132	27B
0005434068029	30604	133	27A
0005432428942	30604	134	26K
0005432528410	30604	135	27D
0005432527947	30604	136	27E
0005434067604	30604	137	27G
0005432528404	30604	138	28A
0005432527949	30604	139	28C
0005435214285	30604	140	28B
0005432528665	30604	141	28E
0005432528754	30604	142	28D
0005432528345	30604	143	28G
0005435214304	30604	144	28F
0005432528364	30604	145	28J
0005432528238	30604	146	28H
0005434067779	30604	147	29B
0005435214272	30604	148	28K
0005434067697	30604	149	29D
0005434067888	30604	150	29C
0005434067539	30604	151	29F
0005432528224	30604	152	29E
0005432528391	30604	153	29J
0005434067770	30604	154	29H
0005432528564	30604	155	29G
0005433656707	30604	156	30A
0005432528497	30604	157	30B
0005432528660	30604	158	30E
0005435214296	30604	159	30G
0005434067271	30604	160	30F
0005432528424	30604	161	30J
0005434067610	30604	162	30H
0005432528214	30604	163	31A
0005435214305	30604	164	31D
0005432528272	30604	165	31B
0005435214324	30604	166	31G
0005435214312	30604	167	31F
0005432528176	30604	168	31E
0005435214318	30604	169	31H
0005434067698	30604	170	32A
0005435214282	30604	171	31K
0005432528116	30604	172	31J
0005435214291	30604	173	32C
0005435214295	30604	174	32B
0005433656709	30604	175	32E
0005435725655	30604	176	32D
0005435214337	30604	177	32H
0005435214276	30604	178	32G
0005432528537	30604	179	32J
0005432533299	30604	180	33B
0005432528426	30604	181	33A
0005435214281	30604	182	33D
0005432528681	30604	183	33F
0005432528251	30604	184	33E
0005432528643	30604	185	33H
0005434067456	30604	186	33G
0005434067769	30604	187	34A
0005432528970	30604	188	33K
0005432527869	30604	189	33J
0005435214311	30604	190	34E
0005432528875	30604	191	34D
0005435725658	30604	192	34H
0005432428954	30604	193	34G
0005435214322	30604	194	34F
0005433656711	30604	195	34K
0005434067746	30604	196	34J
0005434067876	30604	197	35B
0005432528453	30604	198	35A
0005432528723	30604	199	35D
0005432528342	30604	200	35C
0005434067942	30604	201	35F
0005432535849	30604	202	35J
0005432528563	30604	203	35H
0005432528188	30604	204	35G
0005432528571	30604	205	36A
0005432211587	30604	206	36C
0005432528383	30604	207	36B
0005432528118	30604	208	36F
0005432528077	30604	209	36D
0005432159910	30604	210	36H
0005432528846	30604	211	37B
0005432527851	30604	212	37A
0005434067532	30604	213	36K
0005434067701	30604	214	37D
0005432159908	30604	215	37C
0005432535848	30604	216	37G
0005434067526	30604	217	37E
0005434067819	30604	218	37K
0005434067850	30604	219	37J
0005434067737	30604	220	38C
0005434067575	30604	221	38B
0005432528787	30604	222	38K
0005435214317	30604	223	38J
0005432528196	30604	224	38H
0005432528282	30604	225	39A
0005432211585	30604	226	39D
0005432527916	30604	227	39C
0005432528732	30604	228	39B
0005435214271	30604	229	39F
0005435631002	30604	230	39E
0005432211581	30604	231	39J
0005434067774	30604	232	39G
0005432528816	30604	233	39K
0005432528241	30604	234	40C
0005434067921	30604	235	40A
0005432528516	30604	236	40F
0005432528486	30604	237	40E
0005432211583	30604	238	40D
0005434067626	30604	239	40H
0005435214325	30604	240	40G
0005435214274	30604	241	40J
0005432533301	30604	242	41B
0005432528339	30604	243	41A
0005434067637	30604	244	40K
0005432528574	30604	245	41D
0005432528198	30604	246	41C
0005434067724	30604	247	41F
0005435214300	30604	248	41E
0005432528398	30604	249	41J
0005432428939	30604	250	41H
0005432528319	30604	251	41G
0005432533300	30604	252	41K
0005435214326	30604	253	42B
0005435214334	30604	254	42A
0005435214314	30604	255	42E
0005432528378	30604	256	42D
0005434067829	30604	257	42F
0005435631001	30604	258	42J
0005434067745	30604	259	42H
0005435725656	30604	260	43A
0005434067530	30604	261	42K
0005432528076	30604	262	43F
0005434067533	30604	263	43E
0005432528340	30604	264	43H
0005432528114	30604	265	43G
0005434067885	30604	266	44A
0005435214278	30604	267	43J
0005432528815	30604	268	44C
0005432528484	30604	269	44B
0005432533312	30604	270	44D
0005432528168	30604	271	44J
0005434067611	30604	272	44H
0005434067546	30604	273	45A
0005435631003	30604	274	45D
0005432528649	30604	275	45C
0005432528091	30604	276	45F
0005434067725	30604	277	45E
0005432528671	30604	278	45J
0005432527638	30604	279	45H
0005435214331	30604	280	45K
0005434067840	30604	281	46C
0005435214336	30604	282	46B
0005432527931	30604	283	46A
0005435214307	30604	284	46E
0005432528450	30604	285	46D
0005432527575	30604	286	46G
0005435214323	30604	287	46F
0005432428925	30604	288	46J
0005432159911	30604	289	46H
0005432528314	30604	290	47C
0005434067554	30604	291	47A
0005432528590	30604	292	46K
0005435631000	30604	293	47D
0005433656710	30604	294	47G
0005434067551	30604	295	47F
0005432528262	30604	296	47E
0005432528301	30604	297	47K
0005432528589	30604	298	47H
0005434067527	30604	299	48C
0005435214289	30604	300	48E
0005432535862	30604	301	48D
0005434067906	30604	302	48H
0005435214313	30604	303	48K
0005432528569	30604	304	49E
0005432527639	30604	305	49C
0005435214270	30604	306	49G
0005432528109	30604	307	49K
0005435214310	30604	308	49H
0005434067872	30604	309	50F
0005432528431	30604	310	50D
0005435214294	30604	311	50G
0005432527888	30604	312	51D
0005435214286	30604	313	50K
0005435214306	30604	314	50H
0005434067270	30604	315	51F
0005432527648	30604	316	51E
0005434067605	30604	317	51G
0005435653144	24852	1	1A
0005433368322	24852	2	1C
0005433368313	24852	3	1D
0005435653035	24852	4	1F
0005435653121	24852	5	2A
0005435653198	24852	6	2C
0005433368320	24852	7	2D
0005433368319	24852	8	2F
0005435653197	24852	9	3A
0005433368298	24852	10	3C
0005435652995	24852	11	3D
0005435653108	24852	12	3F
0005435653184	24852	13	4A
0005435653120	24852	14	4D
0005435653154	24852	15	4E
0005435653190	24852	16	5A
0005435652959	24852	17	5E
0005433368324	24852	18	6A
0005433368317	24852	19	6C
0005435652989	24852	20	6D
0005433368331	24852	21	6E
0005435652952	24852	22	6F
0005433368327	24852	23	7A
0005435652953	24852	24	7C
0005435653024	24852	25	7D
0005433368314	24852	26	7E
0005435653122	24852	27	7F
0005433368316	24852	28	8A
0005435653159	24852	29	8C
0005435653015	24852	30	8D
0005433368309	24852	31	8E
0005433368311	24852	32	8F
0005433368307	24852	33	9C
0005435653193	24852	34	9D
0005433368325	24852	35	9E
0005433368315	24852	36	9F
0005435653135	24852	37	10A
0005435652984	24852	38	10D
0005435653034	24852	39	10E
0005433368312	24852	40	10F
0005435653133	24852	41	11A
0005435653132	24852	42	11C
0005435653051	24852	43	11D
0005433368323	24852	44	11E
0005433368321	24852	45	11F
0005433368310	24852	46	12A
0005435653074	24852	47	12C
0005435653195	24852	48	12D
0005433368318	24852	49	12E
0005435653182	24852	50	12F
0005433368303	24852	51	13A
0005433368297	24852	52	13C
0005433368308	24852	53	13D
0005433368295	24852	54	13E
0005433368330	24852	55	14C
0005433368296	24852	56	14D
0005435653192	24852	57	14E
0005435653126	24852	58	14F
0005433368301	24852	59	15A
0005435653125	24852	60	15C
0005433368299	24852	61	15D
0005435653161	24852	62	15E
0005433368326	24852	63	16A
0005433368294	24852	64	16D
0005433368329	24852	65	16E
0005433368302	24852	66	16F
0005433368304	24852	67	17A
0005435653079	24852	68	17C
0005435653065	24852	69	17D
0005435653016	24852	70	17E
0005435652988	24852	71	17F
0005433368300	24852	72	18A
0005435652923	24852	73	18C
0005435652931	24852	74	18E
0005435653186	24852	75	18F
0005433368328	24852	76	19A
0005433368306	24852	77	19C
0005435653160	24852	78	19D
0005435653042	24852	79	19E
0005435653128	24852	80	20A
0005435653127	24852	81	20C
0005435653185	24852	82	20D
0005433368305	24852	83	20E
0005435653191	24852	84	20F
0005435949778	23313	1	1B
0005435949773	23313	2	1C
0005435949768	23313	3	2A
0005435949767	23313	4	2C
0005435949772	23313	5	3A
0005435949788	23313	6	5C
0005435949774	23313	7	6D
0005435949791	23313	8	20C
0005435949787	23313	9	21A
0005435949779	23313	10	22A
0005435949781	23313	11	22B
0005435949780	23313	12	22C
0005434980142	2045	1	1B
0005434980139	2045	2	1C
0005435801730	2045	3	2B
0005434980134	2045	4	3A
0005434980123	2045	5	3C
0005434980118	2045	6	3D
0005434980115	2045	7	4B
0005435801731	2045	8	4C
0005434980133	2045	9	4D
0005434980141	2045	10	5A
0005434980143	2045	11	5C
0005434980128	2045	12	5D
0005434980129	2045	13	6A
0005434980136	2045	14	6B
0005434980132	2045	15	6D
0005435801729	2045	16	7A
0005434980131	2045	17	7B
0005434980130	2045	18	7C
0005434980116	2045	19	7D
0005434980125	2045	20	18A
0005434980135	2045	21	18B
0005434980126	2045	22	18D
0005434980140	2045	23	19A
0005434980120	2045	24	19B
0005434980138	2045	25	19D
0005434980114	2045	26	20A
0005434980124	2045	27	20B
0005434980117	2045	28	20D
0005434980119	2045	29	21A
0005434980137	2045	30	21D
0005434980127	2045	31	22A
0005434980122	2045	32	22D
0005434980121	2045	33	23A
0005434979757	23541	1	1A
0005434979775	23541	2	1C
0005434979937	23541	3	2C
0005434979783	23541	4	2D
0005434979923	23541	5	3A
0005434979699	23541	6	3C
0005434979862	23541	7	3D
0005434979804	23541	8	4A
0005434979700	23541	9	4D
0005434979917	23541	10	5A
0005434979938	23541	11	5B
0005434979833	23541	12	6B
0005434979889	23541	13	6C
0005435801702	23541	14	6D
0005435801701	23541	15	7A
0005434979936	23541	16	7C
0005434979922	23541	17	18B
0005434979911	23541	18	18C
0005435801692	23541	19	18D
0005434979749	23541	20	19A
0005434979759	23541	21	19D
0005434979760	23541	22	20A
0005434979895	23541	23	20B
0005434979956	23541	24	20C
0005434979945	23541	25	20D
0005434979756	23541	26	21A
0005434979893	23541	27	21B
0005434979832	23541	28	21C
0005434979845	23541	29	21D
0005434979788	23541	30	22A
0005434979894	23541	31	22B
0005434979863	23541	32	22D
0005434979844	23541	33	23B
0005434952574	2633	1	5B
0005434952573	2633	2	6A
0005433256425	2630	1	3B
0005433256428	2630	2	4A
0005433256429	2630	3	5B
0005433256448	28186	1	1A
0005433256449	28186	2	1B
0005434952530	28186	3	3B
0005434952551	28186	4	5B
0005433112391	19836	1	1B
0005433112390	19836	2	2A
0005433111531	19836	3	2B
0005433111532	19836	4	3A
0005434302863	19836	5	3B
0005433111530	19836	6	4A
0005434302864	19836	7	5B
0005434138287	11925	1	1A
0005434138299	11925	2	1C
0005434138298	11925	3	1D
0005434138347	11925	4	1F
0005434138487	11925	5	2A
0005434138105	11925	6	2C
0005434138030	11925	7	2D
0005434138049	11925	8	2F
0005434138340	11925	9	3A
0005434138224	11925	10	3C
0005434138219	11925	11	3D
0005434138275	11925	12	4A
0005434138456	11925	13	4C
0005434137758	11925	14	4D
0005434138204	11925	15	4E
0005434138346	11925	16	4F
0005434138236	11925	17	5A
0005434138213	11925	18	5C
0005434138463	11925	19	5D
0005434138048	11925	20	5E
0005434138274	11925	21	5F
0005434138524	11925	22	6A
0005434138522	11925	23	6D
0005434138525	11925	24	6E
0005434138106	11925	25	6F
0005434138521	11925	26	7A
0005434138516	11925	27	7C
0005434138418	11925	28	7D
0005434138218	11925	29	7E
0005434138297	11925	30	7F
0005434138520	11925	31	8C
0005434138294	11925	32	8D
0005434138041	11925	33	8E
0005434138161	11925	34	8F
0005434138214	11925	35	9A
0005434138077	11925	36	9C
0005434138197	11925	37	9D
0005434137998	11925	38	9E
0005434138403	11925	39	9F
0005434138130	11925	40	10A
0005434138360	11925	41	10C
0005434138336	11925	42	10D
0005434138132	11925	43	10E
0005434138338	11925	44	10F
0005434138223	11925	45	11A
0005434138220	11925	46	11C
0005434138339	11925	47	11D
0005434138301	11925	48	11F
0005434138384	11925	49	12A
0005434138368	11925	50	12C
0005434138483	11925	51	12D
0005434138050	11925	52	12E
0005434138543	11925	53	12F
0005434138415	11925	54	13A
0005434138544	11925	55	13C
0005434138296	11925	56	13D
0005434138288	11925	57	13E
0005434138474	11925	58	13F
0005434138047	11925	59	14C
0005434138453	11925	60	14A
0005434138289	11925	61	14D
0005434138279	11925	62	14E
0005434138131	11925	63	14F
0005434138237	11925	64	15A
0005434138448	11925	65	15C
0005434138462	11925	66	15D
0005434138300	11925	67	15E
0005434138337	11925	68	15F
0005434138330	11925	69	16D
0005434138529	11925	70	16E
0005434138523	11925	71	16F
0005434138389	11925	72	17A
0005434138528	11925	73	17C
0005434138240	11925	74	17D
0005434138345	11925	75	17E
0005434138425	11925	76	17F
0005434138381	11925	77	18A
0005434138380	11925	78	18C
0005434138423	11925	79	18D
0005434138439	11925	80	18E
0005434138512	11925	81	18F
0005434138313	11925	82	19A
0005434138402	11925	83	19C
0005434138069	11925	84	19D
0005434138438	11925	85	19E
0005434138545	11925	86	19F
0005434138382	11925	87	20A
0005434138496	11925	88	20D
0005434138359	11925	89	20E
0005434138293	11925	90	20F
0005434139030	28760	1	1A
0005434138990	28760	2	1C
0005434139004	28760	3	2A
0005434139017	28760	4	2F
0005434139013	28760	5	3A
0005434139010	28760	6	3D
0005434139018	28760	7	4C
0005434139029	28760	8	4D
0005434139042	28760	9	4E
0005434139025	28760	10	4F
0005434139012	28760	11	5C
0005434138993	28760	12	5D
0005434138987	28760	13	5E
0005434139006	28760	14	5F
0005434139023	28760	15	6A
0005434139037	28760	16	6C
0005434138986	28760	17	6D
0005434139014	28760	18	6E
0005434138981	28760	19	6F
0005434139035	28760	20	7A
0005434139026	28760	21	7C
0005434139005	28760	22	7D
0005434139028	28760	23	7F
0005434139022	28760	24	7E
0005434138984	28760	25	8A
0005434138999	28760	26	8C
0005434139003	28760	27	8D
0005434139038	28760	28	8E
0005434139041	28760	29	8F
0005434139036	28760	30	9A
0005434139032	28760	31	9C
0005434139009	28760	32	9F
0005434139044	28760	33	10A
0005434139000	28760	34	10C
0005434138989	28760	35	10D
0005434139001	28760	36	10E
0005434138996	28760	37	10F
0005434138979	28760	38	11D
0005434139047	28760	39	11E
0005434138985	28760	40	11F
0005434139016	28760	41	12A
0005434138998	28760	42	12C
0005434139034	28760	43	12D
0005434138991	28760	44	12E
0005434139027	28760	45	12F
0005434138994	28760	46	13C
0005434138995	28760	47	13D
0005434138988	28760	48	13F
0005434139040	28760	49	14A
0005434138992	28760	50	14C
0005434139019	28760	51	14D
0005434139007	28760	52	15C
0005434139021	28760	53	15D
0005434139046	28760	54	16A
0005434139020	28760	55	16C
0005434139039	28760	56	16D
0005434139024	28760	57	16E
0005434138997	28760	58	17A
0005434139011	28760	59	17E
0005434139043	28760	60	17F
0005434139002	28760	61	18A
0005434139045	28760	62	18D
0005434139008	28760	63	18E
0005434138982	28760	64	18F
0005434139033	28760	65	19A
0005434139031	28760	66	19D
0005434139015	28760	67	19E
0005434138980	28760	68	20C
0005434138983	28760	69	20D
0005434516087	19097	1	1A
0005434513584	19097	2	1C
0005434513586	19097	3	2A
0005434516082	19097	4	2B
0005434516075	19097	5	2D
0005434190428	19097	6	4C
0005434516086	19097	7	4D
0005434190427	19097	8	5A
0005434190424	19097	9	5B
0005434190425	19097	10	6A
0005434190429	19097	11	6B
0005434516081	19097	12	6C
0005434513579	19097	13	7B
0005434516079	19097	14	7C
0005434513588	19097	15	7D
0005434190426	19097	16	18A
0005434513585	19097	17	21B
0005434513574	19097	18	21D
0005434516093	19097	19	22C
0005434513587	19097	20	23B
0005433538966	6817	1	1B
0005433538965	6817	2	1C
0005435259757	6817	3	2B
0005433538969	6817	4	2C
0005435259758	6817	5	2D
0005433538963	6817	6	3B
0005433538968	6817	7	3D
0005433534522	6817	8	4C
0005433538971	6817	9	4D
0005435259781	6817	10	7D
0005435259771	6817	11	18C
0005433538964	6817	12	19A
0005435259769	6817	13	20B
0005435259768	6817	14	20D
0005433534523	6817	15	21D
0005433538970	6817	16	22A
0005433538967	6817	17	22B
0005433534509	25040	1	1A
0005433538921	25040	2	2D
0005433538888	25040	3	3B
0005433538887	25040	4	3C
0005433538857	25040	5	3D
0005433538922	25040	6	4A
0005435259809	25040	7	4D
0005435259805	25040	8	5D
0005435259807	25040	9	6C
0005433538906	25040	10	7A
0005433538866	25040	11	18A
0005435259806	25040	12	19B
0005435259804	25040	13	20A
0005435259810	25040	14	21C
0005435259808	25040	15	22D
0005433512045	849	1	1D
0005433512050	849	2	2B
0005433512047	849	3	2D
0005433512043	849	4	5D
0005432922530	849	5	6B
0005432922532	849	6	7C
0005433512049	849	7	18A
0005433512044	849	8	20D
0005433512048	849	9	21B
0005432922541	849	10	21C
0005433512046	849	11	22A
0005432922531	849	12	22B
0005432922547	849	13	23A
0005433512011	16146	1	1A
0005432922570	16146	2	3A
0005433511969	16146	3	4A
0005432922572	16146	4	4B
0005433511997	16146	5	5B
0005433511949	16146	6	5D
0005433511992	16146	7	6D
0005433511950	16146	8	18A
0005432922569	16146	9	18B
0005433512005	16146	10	18C
0005433511993	16146	11	19B
0005433511977	16146	12	20C
0005432922571	16146	13	21B
0005433512039	16146	14	23A
0005433511996	16146	15	23B
0005433475751	4041	1	1A
0005435852571	4041	2	2C
0005433475756	4041	3	3C
0005433475752	4041	4	4B
0005435852564	4041	5	4D
0005433475759	4041	6	5A
0005433475758	4041	7	6A
0005435852586	4041	8	6C
0005433475753	4041	9	6D
0005435852579	4041	10	7C
0005433475754	4041	11	18C
0005433475755	4041	12	18D
0005435852574	4041	13	19D
0005435852583	4041	14	20D
0005435852575	4041	15	21B
0005433475757	4041	16	21D
0005435852582	4041	17	22C
0005435697670	3683	1	1A
0005435697653	3683	2	1B
0005435697667	3683	3	1C
0005435935057	3683	4	1D
0005435697662	3683	5	2A
0005435697651	3683	6	2B
0005434950578	3683	7	2C
0005435697672	3683	8	2D
0005434950580	3683	9	3B
0005435697673	3683	10	3C
0005435697666	3683	11	3D
0005435697652	3683	12	4B
0005434950581	3683	13	4C
0005435697658	3683	14	4D
0005435697663	3683	15	5A
0005435697659	3683	16	5B
0005435697664	3683	17	5C
0005435697661	3683	18	5D
0005435697657	3683	19	6A
0005435935056	3683	20	6B
0005435916189	3683	21	6C
0005435697669	3683	22	7A
0005435916175	3683	23	7B
0005435697647	3683	24	7C
0005435697674	3683	25	18A
0005435935065	3683	26	18B
0005435697656	3683	27	18D
0005435697660	3683	28	19A
0005434950582	3683	29	19B
0005435697671	3683	30	19C
0005435697668	3683	31	19D
0005434950579	3683	32	20A
0005435697675	3683	33	20B
0005435697649	3683	34	20C
0005435697648	3683	35	20D
0005435697650	3683	36	21A
0005435697655	3683	37	21C
0005435935055	3683	38	22B
0005435697654	3683	39	22C
0005435697665	3683	40	23A
0005435935046	3683	41	23B
0005435916197	16293	1	1A
0005435697427	16293	2	1B
0005435697411	16293	3	1C
0005435697336	16293	4	1D
0005435697303	16293	5	2B
0005435697304	16293	6	2C
0005435697516	16293	7	2D
0005435697310	16293	8	3A
0005434950539	16293	9	3C
0005435697339	16293	10	3D
0005435916198	16293	11	4B
0005435935079	16293	12	4D
0005435697463	16293	13	5A
0005435697457	16293	14	5B
0005435935078	16293	15	5C
0005435916200	16293	16	5D
0005435697386	16293	17	6A
0005435697364	16293	18	6B
0005434950534	16293	19	6C
0005435697368	16293	20	6D
0005435697309	16293	21	7A
0005435697418	16293	22	7B
0005435697435	16293	23	7C
0005435697410	16293	24	7D
0005435697515	16293	25	18A
0005434950523	16293	26	18B
0005435916201	16293	27	18C
0005435697415	16293	28	19A
0005435697462	16293	29	19B
0005435697338	16293	30	19C
0005435697375	16293	31	19D
0005434950533	16293	32	20B
0005435697385	16293	33	20C
0005435697412	16293	34	20D
0005435935077	16293	35	21A
0005435697458	16293	36	22A
0005435697335	16293	37	22B
0005435916199	16293	38	22C
0005435697350	16293	39	22D
0005434950536	16293	40	23B
0005434606869	3960	1	1B
0005432607612	3960	2	1D
0005434606868	3960	3	2B
0005433519512	3960	4	2C
0005433519509	3960	5	3C
0005432607614	3960	6	3D
0005434606867	3960	7	4A
0005432609779	3960	8	4B
0005432607613	3960	9	4C
0005432609778	3960	10	5A
0005435853624	3960	11	5C
0005434604937	3960	12	6B
0005432609776	3960	13	6C
0005435841476	3960	14	6D
0005434604935	3960	15	7B
0005434604936	3960	16	7D
0005432609777	3960	17	18D
0005434606870	3960	18	20A
0005433519511	3960	19	21B
0005432609780	3960	20	21C
0005433519510	3960	21	22A
0005434604938	3960	22	22D
0005433519466	22066	1	1B
0005435904901	22066	2	1D
0005433519472	22066	3	5B
0005433519465	22066	4	6D
0005434606833	22066	5	7C
0005433519491	22066	6	7D
0005433519490	22066	7	18B
0005435853633	22066	8	18D
0005435904900	22066	9	20B
0005434606824	22066	10	20D
0005435853634	22066	11	21A
0005435853632	22066	12	21B
0005435904902	22066	13	21C
0005435904903	22066	14	22B
0005433519489	22066	15	22D
0005433519433	22066	16	23A
0005433349001	787	1	1A
0005433349003	787	2	1B
0005433349005	787	3	2B
0005433349018	787	4	3A
0005433348989	787	5	3B
0005433349000	787	6	4A
0005433349002	787	7	5B
0005433349022	787	8	6A
0005433349004	787	9	6B
0005435628723	15912	1	1B
0005435628719	15912	2	2A
0005433349057	15912	3	2B
0005433349059	15912	4	3A
0005435628720	15912	5	3B
0005433349058	15912	6	4A
0005435628722	15912	7	4B
0005433349055	15912	8	5A
0005433349054	15912	9	5B
0005433349053	15912	10	6A
0005433349056	15912	11	6B
0005434445267	17213	1	1A
0005433158132	17213	2	2A
0005434446539	17213	3	2B
0005433158133	17213	4	3A
0005433158134	17213	5	3B
0005434445268	17213	6	4A
0005433158131	17213	7	5A
0005433158128	17213	8	5B
0005434446538	17213	9	6A
0005434445266	17213	10	6B
0005434445249	17670	1	1A
0005434445245	17670	2	2A
0005434445248	17670	3	3A
0005434445247	17670	4	3B
0005433159339	17670	5	4A
0005434445246	17670	6	6A
0005433159338	17670	7	6B
0005435133000	7858	1	1B
0005435133007	7858	2	1D
0005435133008	7858	3	2B
0005435133002	7858	4	2C
0005435383164	7858	5	2D
0005435383163	7858	6	3A
0005435133006	7858	7	3B
0005435133003	7858	8	3D
0005435132998	7858	9	5A
0005435132999	7858	10	5B
0005435383162	7858	11	5C
0005435383157	7858	12	5D
0005435133001	7858	13	6D
0005435383187	7858	14	7D
0005435133005	7858	15	18C
0005435133004	7858	16	20C
0005435383155	7858	17	21C
0005435383156	7858	18	22D
0005435383209	33061	1	1A
0005435383214	33061	2	1C
0005435383211	33061	3	2A
0005435383212	33061	4	2B
0005435132915	33061	5	2C
0005435132979	33061	6	3B
0005435132963	33061	7	5A
0005435132980	33061	8	5C
0005435132929	33061	9	6D
0005435383213	33061	10	18A
0005435132910	33061	11	18C
0005435383210	33061	12	18D
0005435132889	33061	13	21A
0005435132962	33061	14	21B
0005435132947	33061	15	21C
0005435132890	33061	16	22C
0005435132881	33061	17	23B
0005435390228	7533	1	1A
0005435160425	7533	2	2B
0005435160433	7533	3	3C
0005435390250	7533	4	3D
0005435160428	7533	5	4D
0005435160424	7533	6	5A
0005435160434	7533	7	5D
0005435160426	7533	8	6B
0005435160427	7533	9	6C
0005435390251	7533	10	7D
0005435160435	7533	11	19B
0005435160431	7533	12	20A
0005435160432	7533	13	20C
0005435160430	7533	14	20D
0005435390279	7533	15	22A
0005435160429	7533	16	23B
0005435390319	29533	1	1A
0005435160315	29533	2	2B
0005435390320	29533	3	3D
0005435160316	29533	4	4A
0005435390317	29533	5	4D
0005435160335	29533	6	6D
0005435390318	29533	7	7C
0005435390322	29533	8	19A
0005435160336	29533	9	19B
0005435390321	29533	10	19C
0005435160355	29533	11	20B
0005435160337	29533	12	21B
0005435390316	29533	13	22A
0005435160344	29533	14	23B
0005432394118	18444	1	1B
0005432398194	18444	2	2A
0005432394120	18444	3	2B
0005432398200	18444	4	3A
0005432398201	18444	5	3B
0005432394104	18444	6	4A
0005432394119	18444	7	4B
0005435178514	18444	8	5A
0005432398202	18444	9	5B
0005432398213	18444	10	6B
0005432400165	27143	1	1A
0005435178499	27143	2	1B
0005432398239	27143	3	2B
0005435178496	27143	4	2A
0005432398236	27143	5	3A
0005432400166	27143	6	3B
0005435178503	27143	7	4A
0005435178502	27143	8	4B
0005432398238	27143	9	5A
0005432398237	27143	10	5B
0005435178497	27143	11	6A
0005432400167	27143	12	6B
0005434504606	6537	1	1A
0005434504619	6537	2	1F
0005434504598	6537	3	2A
0005434504599	6537	4	2F
0005434504596	6537	5	3C
0005434504603	6537	6	3D
0005434504618	6537	7	3F
0005434504588	6537	8	4F
0005434504607	6537	9	5D
0005434504592	6537	10	5F
0005434504613	6537	11	6C
0005434504597	6537	12	6D
0005434504593	6537	13	7A
0005434504608	6537	14	8E
0005434504585	6537	15	8F
0005434504604	6537	16	9C
0005434504620	6537	17	10C
0005435104014	6537	18	11A
0005434504589	6537	19	11C
0005434504610	6537	20	11D
0005434504602	6537	21	12A
0005434504612	6537	22	12C
0005434504587	6537	23	12D
0005434504605	6537	24	12E
0005434504622	6537	25	12F
0005434504601	6537	26	13D
0005434504591	6537	27	13F
0005434504584	6537	28	14A
0005434504615	6537	29	14D
0005434504621	6537	30	14E
0005434504590	6537	31	15D
0005434504594	6537	32	15E
0005434504616	6537	33	16C
0005434504583	6537	34	16D
0005435104016	6537	35	16E
0005435104015	6537	36	17A
0005434504614	6537	37	17C
0005434504609	6537	38	17D
0005434504600	6537	39	17F
0005434504586	6537	40	18C
0005434504582	6537	41	18D
0005434504595	6537	42	18E
0005434504617	6537	43	19D
0005434504611	6537	44	20F
0005434504232	22658	1	1A
0005434504217	22658	2	1C
0005434504201	22658	3	1D
0005434504172	22658	4	1F
0005434504297	22658	5	2A
0005434504203	22658	6	2C
0005434504186	22658	7	2D
0005434504236	22658	8	2F
0005434504129	22658	9	3A
0005434504174	22658	10	3D
0005434504175	22658	11	3F
0005434504244	22658	12	4C
0005434504165	22658	13	4D
0005434504248	22658	14	4E
0005434504237	22658	15	5A
0005434503944	22658	16	5F
0005434504271	22658	17	6E
0005434503992	22658	18	7D
0005435103934	22658	19	7E
0005434504305	22658	20	8E
0005434504131	22658	21	8F
0005435103917	22658	22	9A
0005435103916	22658	23	9C
0005434504202	22658	24	9E
0005434503943	22658	25	10A
0005434504189	22658	26	10D
0005434504250	22658	27	10F
0005434504211	22658	28	11A
0005434504167	22658	29	11D
0005434504177	22658	30	11E
0005434504114	22658	31	11F
0005434504245	22658	32	12A
0005434504227	22658	33	12D
0005434504205	22658	34	12E
0005434504166	22658	35	13A
0005434504231	22658	36	13C
0005434504251	22658	37	13D
0005434504247	22658	38	13F
0005435103920	22658	39	14A
0005435103926	22658	40	14D
0005434504226	22658	41	14F
0005434504078	22658	42	15A
0005434504210	22658	43	15C
0005434504310	22658	44	16A
0005435103935	22658	45	17E
0005434504146	22658	46	19A
0005434504185	22658	47	19D
0005435103927	22658	48	19E
0005434504113	22658	49	19F
0005435103910	22658	50	20C
0005434504238	22658	51	20D
0005434504176	22658	52	20E
0005434503945	22658	53	20F
0005433368048	1677	1	1A
0005433367916	1677	2	1C
0005433368091	1677	3	1F
0005435653570	1677	4	2A
0005435653574	1677	5	2D
0005433368049	1677	6	2F
0005433367922	1677	7	3A
0005433367962	1677	8	3D
0005433368000	1677	9	4A
0005435653569	1677	10	4C
0005435653586	1677	11	4D
0005435653557	1677	12	4E
0005433367974	1677	13	5D
0005435653565	1677	14	5E
0005433368040	1677	15	5F
0005435653584	1677	16	6A
0005433368001	1677	17	6D
0005435653568	1677	18	6E
0005433367919	1677	19	6F
0005435653579	1677	20	7A
0005435653591	1677	21	7C
0005435653585	1677	22	7D
0005433367964	1677	23	7E
0005435653582	1677	24	8A
0005435653562	1677	25	8E
0005433367944	1677	26	9A
0005433367901	1677	27	9C
0005435653566	1677	28	9D
0005435653573	1677	29	9E
0005435653558	1677	30	9F
0005433367905	1677	31	10A
0005433368093	1677	32	10F
0005433367899	1677	33	11A
0005435653583	1677	34	11C
0005433367969	1677	35	11D
0005435653560	1677	36	11E
0005433367883	1677	37	11F
0005433367917	1677	38	12A
0005433367988	1677	39	12C
0005435653580	1677	40	12D
0005435653575	1677	41	12E
0005435653590	1677	42	13A
0005435653588	1677	43	13C
0005433367968	1677	44	14A
0005433367875	1677	45	14C
0005433367927	1677	46	14D
0005433368087	1677	47	14F
0005435653592	1677	48	15A
0005433367898	1677	49	15C
0005435653561	1677	50	15D
0005433367948	1677	51	15F
0005435653577	1677	52	16A
0005433367806	1677	53	16C
0005435653563	1677	54	17A
0005435653567	1677	55	17C
0005433368014	1677	56	17D
0005433367900	1677	57	17E
0005433367963	1677	58	17F
0005435653578	1677	59	18A
0005435653571	1677	60	18D
0005435653581	1677	61	18E
0005433367908	1677	62	18F
0005435653576	1677	63	19A
0005433368004	1677	64	19C
0005435653589	1677	65	19D
0005433368088	1677	66	19E
0005435653572	1677	67	19F
0005433368028	1677	68	20A
0005435653564	1677	69	20C
0005433368092	1677	70	20D
0005435653587	1677	71	20E
0005435653559	1677	72	20F
0005435653108	21685	1	1C
0005433368329	21685	2	1D
0005435653160	21685	3	1F
0005433368296	21685	4	2C
0005435653125	21685	5	2D
0005433368316	21685	6	2F
0005435653034	21685	7	3A
0005433368325	21685	8	3C
0005433368310	21685	9	3F
0005435653195	21685	10	3D
0005433368317	21685	11	4A
0005433368312	21685	12	4C
0005433368328	21685	13	4D
0005433368313	21685	14	4E
0005433368322	21685	15	4F
0005435653185	21685	16	5A
0005435652952	21685	17	5C
0005435653191	21685	18	5D
0005433368302	21685	19	5E
0005435653159	21685	20	5F
0005435653128	21685	21	6A
0005433368327	21685	22	6C
0005433368303	21685	23	6D
0005435653024	21685	24	6E
0005433368320	21685	25	6F
0005435653133	21685	26	7A
0005433368326	21685	27	7C
0005435653186	21685	28	7D
0005435653192	21685	29	7E
0005433368297	21685	30	7F
0005435653126	21685	31	8A
0005433368330	21685	32	8C
0005433368304	21685	33	8D
0005433368305	21685	34	8E
0005435652988	21685	35	8F
0005435653016	21685	36	9A
0005435653198	21685	37	9D
0005435653161	21685	38	9E
0005435653042	21685	39	10A
0005435653154	21685	40	10C
0005435653127	21685	41	10D
0005435652953	21685	42	10E
0005435653144	21685	43	10F
0005435653135	21685	44	11A
0005435653051	21685	45	11C
0005433368295	21685	46	11D
0005433368321	21685	47	11E
0005435653035	21685	48	11F
0005435653197	21685	49	12A
0005433368331	21685	50	12C
0005435653065	21685	51	12D
0005435653184	21685	52	12F
0005435653121	21685	53	13A
0005435652984	21685	54	13E
0005435653190	21685	55	14A
0005435652959	21685	56	14C
0005435652931	21685	57	14D
0005433368294	21685	58	14F
0005433368299	21685	59	15C
0005435653015	21685	60	15D
0005433368315	21685	61	15E
0005433368308	21685	62	15F
0005435652923	21685	63	16A
0005433368309	21685	64	16C
0005435653074	21685	65	16D
0005433368319	21685	66	16E
0005435653182	21685	67	16F
0005435652995	21685	68	17A
0005435653193	21685	69	17D
0005433368324	21685	70	17E
0005435653120	21685	71	17F
0005435652989	21685	72	18A
0005433368318	21685	73	18C
0005435653132	21685	74	18D
0005433368306	21685	75	18F
0005433368301	21685	76	19A
0005433368300	21685	77	19C
0005433368311	21685	78	19D
0005435653122	21685	79	19E
0005433368314	21685	80	19F
0005433368307	21685	81	20C
0005433368298	21685	82	20D
0005433368323	21685	83	20E
0005435653079	21685	84	20F
0005433986466	4138	1	1C
0005433986461	4138	2	1D
0005433986484	4138	3	3C
0005433986502	4138	4	3D
0005433986495	4138	5	3F
0005433986486	4138	6	4E
0005433986477	4138	7	5A
0005433986459	4138	8	5C
0005433986490	4138	9	5F
0005433986494	4138	10	6A
0005433986501	4138	11	6C
0005433986474	4138	12	6D
0005433986498	4138	13	6F
0005433986478	4138	14	7C
0005433986500	4138	15	7D
0005435788801	4138	16	7F
0005433986476	4138	17	8D
0005433986470	4138	18	8E
0005433986475	4138	19	9C
0005433986497	4138	20	9E
0005433986491	4138	21	10A
0005435788799	4138	22	10D
0005435788802	4138	23	10E
0005433986464	4138	24	11D
0005433986480	4138	25	11E
0005433986496	4138	26	11F
0005433986483	4138	27	13A
0005435788800	4138	28	13C
0005433986479	4138	29	13D
0005433986467	4138	30	13F
0005433986469	4138	31	14A
0005433986472	4138	32	14C
0005433986471	4138	33	15A
0005433986465	4138	34	15E
0005433986492	4138	35	16D
0005433986493	4138	36	16E
0005433986505	4138	37	16F
0005433986462	4138	38	17A
0005433986489	4138	39	17D
0005433986481	4138	40	17E
0005433986468	4138	41	18C
0005433986504	4138	42	18D
0005433986488	4138	43	18E
0005433986499	4138	44	18F
0005433986460	4138	45	19C
0005433986487	4138	46	19D
0005433986503	4138	47	19F
0005433986473	4138	48	20A
0005433986482	4138	49	20C
0005433986485	4138	50	20D
0005433986463	4138	51	20F
0005433985929	25641	1	1C
0005433985844	25641	2	1F
0005433986143	25641	3	2A
0005433986022	25641	4	2C
0005433986074	25641	5	3A
0005433985767	25641	6	3C
0005433985980	25641	7	4D
0005433985944	25641	8	5A
0005433985923	25641	9	5D
0005433985983	25641	10	5F
0005433985924	25641	11	6A
0005433985889	25641	12	6C
0005433985888	25641	13	6D
0005433985942	25641	14	7A
0005433986151	25641	15	7D
0005433985912	25641	16	8A
0005433985959	25641	17	8C
0005435788775	25641	18	8D
0005433985922	25641	19	8F
0005433985956	25641	20	9A
0005433986095	25641	21	9E
0005433986034	25641	22	10C
0005433986029	25641	23	10E
0005433985943	25641	24	11A
0005433986030	25641	25	12A
0005433986068	25641	26	12C
0005435788780	25641	27	12F
0005433985947	25641	28	13A
0005433985996	25641	29	13E
0005433985982	25641	30	13F
0005433985925	25641	31	14A
0005433986062	25641	32	14C
0005435788779	25641	33	14F
0005433986001	25641	34	15C
0005433986000	25641	35	15E
0005433985911	25641	36	15F
0005433985822	25641	37	16A
0005433985845	25641	38	16C
0005433986002	25641	39	16F
0005433986016	25641	40	17A
0005435788776	25641	41	18A
0005433986096	25641	42	18C
0005433985966	25641	43	18D
0005433986152	25641	44	18F
0005433986061	25641	45	19D
0005433985864	25641	46	19E
0005433985999	25641	47	20C
0005433985927	25641	48	20D
0005433986103	25641	49	20E
0005433461611	20246	1	2A
0005433461597	20246	2	2G
0005433461599	20246	3	3A
0005433461601	20246	4	3H
0005433460446	20246	5	4G
0005433460459	20246	6	11E
0005433460458	20246	7	13A
0005433460448	20246	8	13E
0005433461600	20246	9	13G
0005433461607	20246	10	16B
0005433460451	20246	11	17H
0005433461606	20246	12	18E
0005433460450	20246	13	20E
0005433460457	20246	14	21F
0005433460445	20246	15	21H
0005433461609	20246	16	22B
0005433460456	20246	17	23G
0005433461598	20246	18	24G
0005433461605	20246	19	28D
0005433460454	20246	20	29F
0005433461608	20246	21	29E
0005433460455	20246	22	31D
0005433460452	20246	23	31H
0005433461610	20246	24	33H
0005433461604	20246	25	34H
0005433461603	20246	26	35A
0005433461602	20246	27	35B
0005433460449	20246	28	37H
0005433460447	20246	29	38G
0005433460453	20246	30	39F
0005435720143	24791	1	3B
0005435719570	24791	2	5D
0005435719571	24791	3	7D
0005435720141	24791	4	21B
0005435720142	24791	5	23A
0005433168419	21326	1	1C
0005433168417	21326	2	1D
0005434509173	21326	3	2A
0005434509163	21326	4	2B
0005434509150	21326	5	3B
0005434509176	21326	6	3A
0005434509152	21326	7	3C
0005434509190	21326	8	3D
0005434509175	21326	9	4B
0005434509189	21326	10	4D
0005434509170	21326	11	5D
0005434509165	21326	12	6A
0005433168415	21326	13	6B
0005433168418	21326	14	6D
0005434509160	21326	15	7C
0005433168423	21326	16	7D
0005433168416	21326	17	19A
0005434509182	21326	18	19C
0005433168422	21326	19	20C
0005434509192	21326	20	20D
0005433168420	21326	21	21A
0005434509149	21326	22	21C
0005433168421	21326	23	22A
0005434509213	21326	24	23A
0005434509191	21326	25	23B
0005432664135	17830	1	2A
0005432869603	17830	2	2F
0005432666400	17830	3	3A
0005434151739	17830	4	3D
0005432665280	17830	5	4A
0005432660824	17830	6	5D
0005432869601	17830	7	5E
0005432655568	17830	8	6C
0005432667459	17830	9	6D
0005432665290	17830	10	7D
0005432658596	17830	11	7F
0005432869606	17830	12	8C
0005434151740	17830	13	8F
0005432660828	17830	14	9C
0005432655595	17830	15	9F
0005432655572	17830	16	10A
0005432869605	17830	17	10E
0005432869604	17830	18	10F
0005432657457	17830	19	11C
0005432655543	17830	20	11D
0005432666391	17830	21	13C
0005432655606	17830	22	14E
0005434151738	17830	23	15E
0005432655594	17830	24	15F
0005432655573	17830	25	16A
0005432658598	17830	26	16E
0005432664140	17830	27	16F
0005432657463	17830	28	17A
0005432657455	17830	29	17C
0005432655571	17830	30	18C
0005432658597	17830	31	18D
0005432655566	17830	32	18E
0005432655567	17830	33	19A
0005432869602	17830	34	20A
0005432655576	17830	35	20C
0005432869536	26308	1	1A
0005432869544	26308	2	1C
0005432869532	26308	3	2C
0005432655655	26308	4	3A
0005432667475	26308	5	3C
0005432869526	26308	6	3F
0005432869549	26308	7	4C
0005432869498	26308	8	7A
0005432869525	26308	9	7C
0005432655646	26308	10	7D
0005432665296	26308	11	8C
0005432667474	26308	12	8E
0005432869527	26308	13	8F
0005432869538	26308	14	9C
0005432660839	26308	15	9E
0005434151720	26308	16	10A
0005432658612	26308	17	10D
0005432659726	26308	18	10E
0005432655647	26308	19	11C
0005432655644	26308	20	11E
0005432658613	26308	21	11F
0005432655653	26308	22	12C
0005432655649	26308	23	12D
0005432657481	26308	24	13A
0005432657479	26308	25	13C
0005432655648	26308	26	13E
0005432655654	26308	27	13F
0005432869548	26308	28	15A
0005432869543	26308	29	15D
0005432655651	26308	30	15E
0005432666410	26308	31	16A
0005432665295	26308	32	16D
0005432659727	26308	33	16E
0005432655652	26308	34	16F
0005432869537	26308	35	17C
0005432657480	26308	36	17F
0005432665297	26308	37	18D
0005432655645	26308	38	18E
0005434151719	26308	39	18F
0005432869552	26308	40	19C
0005432655650	26308	41	20E
0005432329243	3105	1	1A
0005432905189	3105	2	1C
0005432329227	3105	3	1F
0005432329232	3105	4	2A
0005433438962	3105	5	2C
0005433438963	3105	6	2D
0005432329228	3105	7	2F
0005432329249	3105	8	3A
0005432329215	3105	9	3C
0005432329245	3105	10	3D
0005432329220	3105	11	3F
0005432329219	3105	12	4A
0005432329222	3105	13	4E
0005432329224	3105	14	5C
0005432329233	3105	15	5D
0005432329242	3105	16	5E
0005432905190	3105	17	6F
0005432329218	3105	18	7A
0005433438967	3105	19	7C
0005432287250	3105	20	8A
0005432329237	3105	21	8C
0005432287245	3105	22	8D
0005432329211	3105	23	8F
0005432329235	3105	24	9A
0005432287249	3105	25	9D
0005432287247	3105	26	9E
0005432329225	3105	27	9F
0005432329213	3105	28	10D
0005432329247	3105	29	11A
0005432329240	3105	30	10F
0005433438968	3105	31	11C
0005432329221	3105	32	11E
0005432329246	3105	33	11F
0005433438965	3105	34	12C
0005432329214	3105	35	12E
0005432329234	3105	36	12F
0005432329238	3105	37	13A
0005432329209	3105	38	13C
0005432329226	3105	39	13D
0005432329216	3105	40	13E
0005433438966	3105	41	14A
0005432329210	3105	42	14C
0005433438964	3105	43	14E
0005432329251	3105	44	14F
0005432287246	3105	45	15C
0005432329244	3105	46	16A
0005432329217	3105	47	16C
0005432287248	3105	48	16F
0005432329230	3105	49	17A
0005432329207	3105	50	17C
0005432329252	3105	51	17D
0005432329223	3105	52	17E
0005432329212	3105	53	18A
0005432329248	3105	54	18C
0005432329241	3105	55	18D
0005432329206	3105	56	18E
0005432329231	3105	57	18F
0005432329208	3105	58	19A
0005432329250	3105	59	19C
0005432329236	3105	60	19E
0005432329239	3105	61	19F
0005432329229	3105	62	20E
0005432328811	31107	1	1C
0005432328787	31107	2	1F
0005433438924	31107	3	2A
0005432905192	31107	4	2C
0005432328941	31107	5	2F
0005432328701	31107	6	3C
0005432328888	31107	7	3D
0005432328853	31107	8	3F
0005433438891	31107	9	4A
0005432328931	31107	10	4C
0005432328849	31107	11	4E
0005432328541	31107	12	4F
0005433438892	31107	13	5D
0005432328812	31107	14	6C
0005433438897	31107	15	6D
0005432328894	31107	16	6E
0005432905193	31107	17	6F
0005432328726	31107	18	7A
0005432328540	31107	19	7C
0005432328759	31107	20	7D
0005432328833	31107	21	7E
0005432905194	31107	22	8A
0005432905195	31107	23	8C
0005432328916	31107	24	8D
0005432328875	31107	25	8E
0005433438898	31107	26	9A
0005432054336	31107	27	9C
0005432328834	31107	28	9F
0005433438937	31107	29	10A
0005432328557	31107	30	10C
0005433438904	31107	31	10D
0005432328679	31107	32	11A
0005432328695	31107	33	11C
0005433438908	31107	34	11D
0005432328687	31107	35	12A
0005432328773	31107	36	12C
0005432328915	31107	37	12D
0005432328876	31107	38	12E
0005432328514	31107	39	12F
0005432054340	31107	40	13A
0005432328691	31107	41	13C
0005433438877	31107	42	13D
0005432328840	31107	43	13E
0005432328854	31107	44	14A
0005432054337	31107	45	14C
0005433438938	31107	46	14E
0005432328558	31107	47	14F
0005433438869	31107	48	15A
0005432905191	31107	49	15D
0005432328788	31107	50	15E
0005433438903	31107	51	15F
0005432328747	31107	52	16A
0005432328821	31107	53	16E
0005432328770	31107	54	16F
0005432328725	31107	55	17F
0005432328621	31107	56	18A
0005433438939	31107	57	18C
0005432054338	31107	58	18D
0005432328515	31107	59	19A
0005432054339	31107	60	19C
0005432328813	31107	61	19D
0005432328740	31107	62	19E
0005432328839	31107	63	19F
0005433438870	31107	64	20C
0005435487855	6192	1	1A
0005435999445	6192	2	1C
0005435487918	6192	3	2A
0005435999456	6192	4	2F
0005432146221	6192	5	3D
0005434309903	6192	6	4C
0005432146222	6192	7	6A
0005435487891	6192	8	5F
0005435999438	6192	9	6D
0005434309904	6192	10	6F
0005435999446	6192	11	6E
0005435297039	6192	12	7C
0005435999443	6192	13	7D
0005435297038	6192	14	8A
0005434309899	6192	15	7F
0005435487964	6192	16	8B
0005434309893	6192	17	8D
0005435487815	6192	18	8E
0005434309905	6192	19	9A
0005435487935	6192	20	8F
0005435999439	6192	21	9C
0005435999440	6192	22	9D
0005435999451	6192	23	10C
0005435999450	6192	24	10E
0005435487974	6192	25	11A
0005435487878	6192	26	11B
0005435487942	6192	27	11C
0005435999453	6192	28	12A
0005435487941	6192	29	12C
0005434309901	6192	30	13A
0005435487879	6192	31	12F
0005435999455	6192	32	13C
0005435999442	6192	33	13D
0005435999444	6192	34	14A
0005434309902	6192	35	13F
0005435487900	6192	36	14B
0005435999437	6192	37	14D
0005434309898	6192	38	14F
0005435999441	6192	39	15A
0005434309895	6192	40	15D
0005435487989	6192	41	16B
0005435999454	6192	42	16C
0005435487903	6192	43	16D
0005435487925	6192	44	16F
0005435487899	6192	45	17A
0005435999452	6192	46	17D
0005434309896	6192	47	17E
0005435487966	6192	48	18A
0005435999449	6192	49	18C
0005435297077	6192	50	18D
0005435487965	6192	51	19A
0005435487856	6192	52	19B
0005435297049	6192	53	19F
0005435999447	6192	54	20A
0005435297066	6192	55	20D
0005435487973	6192	56	20E
0005434309897	6192	57	21A
0005434309900	6192	58	21E
0005434309894	6192	59	22B
0005435999448	6192	60	22C
0005434309892	6192	61	22E
0005435999436	6192	62	22F
0005435297107	6192	63	23B
0005434309757	19551	1	1A
0005435999285	19551	2	2A
0005435488069	19551	3	2C
0005435999286	19551	4	2F
0005435999282	19551	5	3D
0005435488060	19551	6	4A
0005434309768	19551	7	4C
0005435999249	19551	8	4B
0005435488068	19551	9	4D
0005435488067	19551	10	4E
0005434309786	19551	11	5D
0005435488062	19551	12	5E
0005435297139	19551	13	6A
0005435488056	19551	14	6B
0005435999264	19551	15	6C
0005435297138	19551	16	6D
0005434309780	19551	17	6E
0005434309814	19551	18	7A
0005434309773	19551	19	6F
0005435488058	19551	20	7D
0005435999275	19551	21	8A
0005435999263	19551	22	8C
0005435999186	19551	23	9A
0005435999255	19551	24	9C
0005434309800	19551	25	9B
0005435999287	19551	26	9D
0005435488057	19551	27	9F
0005434309680	19551	28	10B
0005435999212	19551	29	10E
0005435999267	19551	30	11D
0005435488063	19551	31	11C
0005435488053	19551	32	11F
0005435999211	19551	33	12B
0005435999297	19551	34	12D
0005435999262	19551	35	12E
0005435488070	19551	36	12F
0005435999266	19551	37	13E
0005435488065	19551	38	14C
0005434309767	19551	39	14B
0005435488054	19551	40	14E
0005435297135	19551	41	14F
0005434309774	19551	42	15C
0005435488059	19551	43	15D
0005435488055	19551	44	15F
0005435297140	19551	45	16D
0005435488072	19551	46	16E
0005435297136	19551	47	17B
0005434309781	19551	48	17D
0005435999231	19551	49	17E
0005435488061	19551	50	17F
0005434309801	19551	51	18B
0005435999283	19551	52	18D
0005435999298	19551	53	18F
0005434309779	19551	54	19B
0005435488073	19551	55	19E
0005435999273	19551	56	19F
0005435999254	19551	57	20A
0005435999274	19551	58	21A
0005435488052	19551	59	22A
0005435297137	19551	60	21F
0005435488071	19551	61	22D
0005435488064	19551	62	23D
0005435488066	19551	63	23E
0005433158155	17536	1	1D
0005434446529	17536	2	4A
0005433158154	17536	3	5C
0005434446516	17536	4	6C
0005433158152	17536	5	6D
0005434446525	17536	6	7C
0005434446526	17536	7	19A
0005434446518	17536	8	19C
0005434446530	17536	9	20A
0005433158157	17536	10	20C
0005433158153	17536	11	20D
0005434446520	17536	12	22C
0005433158156	17536	13	23B
0005435508485	1574	1	1C
0005434566071	1574	2	1D
0005435518119	1574	3	1F
0005434566069	1574	4	2A
0005432291958	1574	5	2C
0005434566067	1574	6	2D
0005434566066	1574	7	2F
0005432291957	1574	8	3C
0005435518125	1574	9	3F
0005435518129	1574	10	4A
0005433186120	1574	11	4D
0005435502554	1574	12	4E
0005435518126	1574	13	4F
0005435502555	1574	14	5A
0005435518116	1574	15	5C
0005435508484	1574	16	5D
0005434566073	1574	17	5E
0005435502564	1574	18	5F
0005435508486	1574	19	6A
0005435508491	1574	20	6C
0005435518120	1574	21	6E
0005435518134	1574	22	6F
0005435502560	1574	23	7A
0005435508488	1574	24	7D
0005434566072	1574	25	7E
0005435502566	1574	26	7F
0005434566075	1574	27	8C
0005435502561	1574	28	8D
0005435502558	1574	29	8E
0005432291959	1574	30	9C
0005435502570	1574	31	9E
0005433186128	1574	32	10A
0005435518127	1574	33	10C
0005435502567	1574	34	10E
0005433186119	1574	35	11A
0005434566065	1574	36	11C
0005435502572	1574	37	11D
0005435502565	1574	38	11E
0005433186158	1574	39	11F
0005434566076	1574	40	12A
0005435518122	1574	41	12C
0005435518128	1574	42	12D
0005435502563	1574	43	12E
0005434566064	1574	44	12F
0005435518123	1574	45	13A
0005435508487	1574	46	13D
0005435518133	1574	47	13E
0005435502557	1574	48	13F
0005433186139	1574	49	14A
0005435508489	1574	50	14C
0005435502562	1574	51	14D
0005435518115	1574	52	14E
0005434566070	1574	53	15C
0005435518124	1574	54	15E
0005435518131	1574	55	15F
0005435518130	1574	56	16A
0005435502553	1574	57	16C
0005435518135	1574	58	16D
0005435508490	1574	59	16F
0005434566074	1574	60	17A
0005434566063	1574	61	17C
0005433186127	1574	62	17E
0005435518132	1574	63	18A
0005435502569	1574	64	18C
0005435502571	1574	65	18D
0005435518118	1574	66	18E
0005435502568	1574	67	18F
0005435502559	1574	68	19A
0005435518121	1574	69	19C
0005435518117	1574	70	19E
0005435502573	1574	71	19F
0005435508492	1574	72	20A
0005434566068	1574	73	20E
0005435502556	1574	74	20F
0005435502304	20851	1	1A
0005435529253	20851	2	1C
0005434565930	20851	3	2A
0005434565956	20851	4	2C
0005435529342	20851	5	2D
0005435529285	20851	6	2F
0005435529242	20851	7	3A
0005433186215	20851	8	3D
0005433186221	20851	9	3F
0005434565957	20851	10	4C
0005435529293	20851	11	4D
0005433186220	20851	12	4E
0005435529269	20851	13	4F
0005435529348	20851	14	5A
0005433186216	20851	15	5C
0005435502419	20851	16	5D
0005435529240	20851	17	5E
0005435545738	20851	18	5F
0005435529321	20851	19	6A
0005434565963	20851	20	6C
0005435502361	20851	21	6D
0005434565955	20851	22	6E
0005435529295	20851	23	6F
0005435529260	20851	24	7A
0005435502381	20851	25	7C
0005435529276	20851	26	7D
0005434565967	20851	27	7E
0005435529355	20851	28	7F
0005434565932	20851	29	8A
0005435502375	20851	30	8C
0005435529268	20851	31	8D
0005435502348	20851	32	8E
0005435529208	20851	33	8F
0005435502385	20851	34	9A
0005435529341	20851	35	9C
0005435529394	20851	36	9D
0005435502347	20851	37	9F
0005433186218	20851	38	10A
0005435545764	20851	39	10C
0005435529188	20851	40	10D
0005435529294	20851	41	10E
0005434565964	20851	42	10F
0005435529267	20851	43	11A
0005435529292	20851	44	11C
0005434565958	20851	45	11D
0005433186213	20851	46	11E
0005433186219	20851	47	11F
0005435529302	20851	48	12A
0005435529343	20851	49	12C
0005435502323	20851	50	12D
0005435529332	20851	51	12E
0005435529333	20851	52	12F
0005435545742	20851	53	13A
0005435529245	20851	54	13C
0005435529238	20851	55	13E
0005434565931	20851	56	13D
0005435545741	20851	57	13F
0005434565966	20851	58	14A
0005435529284	20851	59	14C
0005435502279	20851	60	14D
0005435529275	20851	61	14E
0005435545739	20851	62	14F
0005435502280	20851	63	15A
0005435529241	20851	64	15C
0005435529261	20851	65	15D
0005435529345	20851	66	15E
0005435529346	20851	67	15F
0005435502418	20851	68	16C
0005435529299	20851	69	16E
0005434565900	20851	70	17D
0005433186217	20851	71	17E
0005435545762	20851	72	18C
0005435502399	20851	73	18D
0005435529278	20851	74	18E
0005433186214	20851	75	18F
0005435502321	20851	76	19A
0005435529207	20851	77	19C
0005434565893	20851	78	19D
0005435545763	20851	79	19E
0005434565972	20851	80	19F
0005435529298	20851	81	20A
0005435502398	20851	82	20C
0005435502382	20851	83	20D
0005435502376	20851	84	20E
0005435502303	20851	85	20F
0005435153817	3921	1	1C
0005435931615	3921	2	1D
0005435153819	3921	3	2C
0005435153816	3921	4	3A
0005435931614	3921	5	3C
0005435931595	3921	6	3D
0005435153818	3921	7	4D
0005435153821	3921	8	5B
0005435153820	3921	9	6D
0005435931606	3921	10	23B
0005435153762	21876	1	5A
0005435931645	21876	2	5D
0005435153756	21876	3	6C
0005435153757	21876	4	19D
0005435931644	21876	5	21A
0005435153752	21876	6	22C
0005435931646	21876	7	23B
0005432629018	7218	1	1A
0005432629020	7218	2	1C
0005432629014	7218	3	2B
0005435225604	7218	4	2C
0005432629013	7218	5	2D
0005432629022	7218	6	3B
0005432629010	7218	7	3C
0005432629021	7218	8	4D
0005432629015	7218	9	5A
0005432629012	7218	10	5B
0005432629019	7218	11	6C
0005435225601	7218	12	7B
0005432629024	7218	13	18A
0005435225607	7218	14	18D
0005432629023	7218	15	18C
0005432629016	7218	16	19B
0005432629011	7218	17	20D
0005432629017	7218	18	22B
0005432628910	28114	1	1B
0005432628894	28114	2	2A
0005432628955	28114	3	2C
0005432628956	28114	4	3B
0005432628899	28114	5	3C
0005435225677	28114	6	4A
0005432628890	28114	7	4B
0005432628875	28114	8	4D
0005435225676	28114	9	5B
0005432628895	28114	10	6A
0005432628891	28114	11	6B
0005432628909	28114	12	6C
0005432628900	28114	13	6D
0005432628893	28114	14	7B
0005432628935	28114	15	7C
0005435225679	28114	16	18B
0005432629019	28114	17	18C
0005432628896	28114	18	18D
0005435225678	28114	19	19A
0005435225680	28114	20	20A
0005435225675	28114	21	20C
0005435225681	28114	22	20D
0005432628936	28114	23	21B
0005435225674	28114	24	21D
0005432628937	28114	25	22C
0005432628865	28114	26	23B
0005434267959	8714	1	1A
0005434267968	8714	2	1B
0005434267969	8714	3	2B
0005434267953	8714	4	3D
0005435960094	8714	5	7B
0005434267958	8714	6	18B
0005434267974	8714	7	21D
0005434267952	8714	8	22A
0005435960095	8714	9	22B
0005435960093	8714	10	22C
0005435960096	8714	11	23A
0005434267991	15228	1	1B
0005435960056	15228	2	1C
0005435960067	15228	3	2D
0005435960068	15228	4	4C
0005435960057	15228	5	6B
0005434267993	15228	6	18B
0005435960055	15228	7	18D
0005435960069	15228	8	19D
0005434267994	15228	9	20C
0005435960054	15228	10	22A
0005434267992	15228	11	22B
0005432873326	1217	1	1C
0005432693388	1217	2	1A
0005432693406	1217	3	1F
0005432677614	1217	4	2D
0005432693401	1217	5	3A
0005432693397	1217	6	3C
0005432675312	1217	7	4A
0005432675300	1217	8	3F
0005432693407	1217	9	4F
0005432693409	1217	10	5C
0005432675301	1217	11	5A
0005432873293	1217	12	5F
0005432693393	1217	13	5D
0005432677613	1217	14	6A
0005432693380	1217	15	6C
0005432675314	1217	16	6B
0005432873327	1217	17	7E
0005432693392	1217	18	7D
0005432675313	1217	19	8C
0005432873307	1217	20	8B
0005432693402	1217	21	8D
0005432873298	1217	22	8F
0005432873294	1217	23	8E
0005432873299	1217	24	9B
0005432675306	1217	25	9A
0005432693379	1217	26	9D
0005432675307	1217	27	9C
0005432693405	1217	28	10A
0005432675311	1217	29	9F
0005432873292	1217	30	10C
0005432693381	1217	31	10D
0005432675304	1217	32	10F
0005432873328	1217	33	11B
0005432693394	1217	34	11D
0005432675303	1217	35	11C
0005432693396	1217	36	11F
0005432693391	1217	37	11E
0005432693399	1217	38	12B
0005432693400	1217	39	12E
0005432693404	1217	40	13A
0005432693387	1217	41	13E
0005432675299	1217	42	13F
0005432693398	1217	43	14C
0005432693386	1217	44	14E
0005432693385	1217	45	14D
0005432693384	1217	46	15B
0005432693403	1217	47	15A
0005432693390	1217	48	15C
0005432873291	1217	49	15F
0005432677615	1217	50	16B
0005432693410	1217	51	16D
0005432873325	1217	52	17B
0005432675305	1217	53	17A
0005432677616	1217	54	17D
0005432675308	1217	55	17C
0005432693382	1217	56	18B
0005432873352	1217	57	18A
0005432693408	1217	58	18D
0005432693389	1217	59	19A
0005432675302	1217	60	19B
0005432675309	1217	61	19D
0005432873306	1217	62	20D
0005432693395	1217	63	20C
0005432873308	1217	64	21C
0005432693383	1217	65	21D
0005432675310	1217	66	21F
0005432693042	17484	1	1C
0005432693109	17484	2	1A
0005432675236	17484	3	1D
0005432675237	17484	4	2C
0005432873371	17484	5	1F
0005432873374	17484	6	2F
0005432873376	17484	7	4A
0005432693251	17484	8	4C
0005432873375	17484	9	5A
0005432675178	17484	10	4F
0005432693053	17484	11	4D
0005432693054	17484	12	5C
0005432693108	17484	13	5F
0005432675220	17484	14	5D
0005432693047	17484	15	6C
0005432693110	17484	16	6B
0005432693107	17484	17	7A
0005432693176	17484	18	7B
0005432675140	17484	19	7E
0005432693205	17484	20	7D
0005432693037	17484	21	8B
0005432677595	17484	22	8A
0005432693073	17484	23	8E
0005432873372	17484	24	8D
0005432677593	17484	25	9B
0005432675221	17484	26	9A
0005432677596	17484	27	9E
0005432693142	17484	28	9D
0005432675148	17484	29	10A
0005432693177	17484	30	10B
0005432675186	17484	31	10D
0005432693036	17484	32	10F
0005432693052	17484	33	11B
0005432693252	17484	34	11A
0005432693115	17484	35	11E
0005432677574	17484	36	12A
0005432675176	17484	37	12D
0005432693138	17484	38	12E
0005432677592	17484	39	13A
0005432675203	17484	40	13C
0005432693131	17484	41	13B
0005432693051	17484	42	13E
0005432693139	17484	43	13D
0005432675177	17484	44	14F
0005432693096	17484	45	15D
0005432693102	17484	46	15C
0005432675143	17484	47	15E
0005432693074	17484	48	16A
0005432693116	17484	49	15F
0005432873370	17484	50	16D
0005432677589	17484	51	17A
0005432693130	17484	52	16F
0005432873373	17484	53	16E
0005432693132	17484	54	17B
0005432675139	17484	55	17D
0005432675121	17484	56	18B
0005432675147	17484	57	19C
0005432693038	17484	58	19B
0005432693111	17484	59	19E
0005432677594	17484	60	20C
0005432693181	17484	61	20F
0005432675144	17484	62	21B
0005432675187	17484	63	21A
0005432693035	17484	64	21C
0005432693114	17484	65	21E
0005432693112	17484	66	21D
0005434435357	1107	1	1A
0005434435361	1107	2	1D
0005433156782	1107	3	2B
0005433156724	1107	4	2C
0005433156781	1107	5	3A
0005434435362	1107	6	4B
0005433156780	1107	7	4C
0005434435366	1107	8	5A
0005434435365	1107	9	5B
0005433156723	1107	10	5C
0005434435356	1107	11	6A
0005434435360	1107	12	6C
0005433156789	1107	13	7D
0005433156824	1107	14	18B
0005434435351	1107	15	18D
0005433156803	1107	16	19B
0005434435364	1107	17	19C
0005434435355	1107	18	19D
0005434435363	1107	19	20A
0005434435359	1107	20	20B
0005434435353	1107	21	20C
0005434435358	1107	22	20D
0005434435352	1107	23	21D
0005434435354	1107	24	22A
0005433156763	1107	25	22C
0005433156788	1107	26	23A
0005433156793	1107	27	23B
0005434435250	17298	1	1B
0005433156848	17298	2	4C
0005434435218	17298	3	5D
0005433156844	17298	4	6A
0005433156851	17298	5	6B
0005433156850	17298	6	6C
0005434435220	17298	7	6D
0005434435228	17298	8	7A
0005433156846	17298	9	7C
0005433156849	17298	10	18A
0005434435219	17298	11	18B
0005433156847	17298	12	18C
0005434435192	17298	13	18D
0005433156852	17298	14	19A
0005434435242	17298	15	19B
0005434435274	17298	16	19C
0005434435170	17298	17	20B
0005434435224	17298	18	21A
0005434435284	17298	19	21B
0005434435229	17298	20	21D
0005434435223	17298	21	22A
0005433156845	17298	22	23B
0005435086920	4107	1	2C
0005435086922	4107	2	1A
0005435928144	4107	3	4B
0005435928161	4107	4	4C
0005435928146	4107	5	6C
0005435086924	4107	6	7C
0005435928145	4107	7	18B
0005435928162	4107	8	20A
0005435086923	4107	9	21B
0005435086921	4107	10	23B
0005435086843	24410	1	1A
0005435086857	24410	2	1B
0005435928198	24410	3	3B
0005435086858	24410	4	3D
0005435086879	24410	5	4A
0005435928200	24410	6	4B
0005435086848	24410	7	4C
0005435086861	24410	8	4D
0005435928196	24410	9	5C
0005435086873	24410	10	6D
0005435086878	24410	11	7A
0005435086872	24410	12	7C
0005435086842	24410	13	18A
0005435928197	24410	14	22A
0005435928199	24410	15	23A
0005435551650	17001	1	1B
0005435551662	17001	2	1C
0005435098581	17001	3	3A
0005435098579	17001	4	3F
0005435551656	17001	5	3G
0005435551648	17001	6	3H
0005435551663	17001	7	4G
0005435551651	17001	8	5B
0005435551647	17001	9	9A
0005435098576	17001	10	12D
0005435551645	17001	11	12H
0005435551664	17001	12	14H
0005435551642	17001	13	19E
0005435551660	17001	14	19D
0005435098577	17001	15	19H
0005435098580	17001	16	19G
0005435551652	17001	17	22A
0005435551643	17001	18	23F
0005435551661	17001	19	28E
0005435551659	17001	20	28F
0005435551646	17001	21	31E
0005435551655	17001	22	32H
0005435098578	17001	23	32G
0005435551649	17001	24	33D
0005435098582	17001	25	33G
0005435551657	17001	26	34D
0005435551658	17001	27	34E
0005435551654	17001	28	37E
0005435551653	17001	29	38A
0005435551644	17001	30	39F
0005435907553	4866	1	1C
0005435907552	4866	2	1D
0005435907518	4866	3	2C
0005433194870	4866	4	4D
0005434626065	4866	5	6C
0005435907519	4866	6	6D
0005434626069	4866	7	7F
0005434626070	4866	8	10E
0005434626075	4866	9	11C
0005434626073	4866	10	12C
0005434626071	4866	11	12F
0005434626067	4866	12	17A
0005434626068	4866	13	17D
0005434626074	4866	14	17E
0005434626072	4866	15	18C
0005434626066	4866	16	20E
0005434625987	32906	1	3A
0005434626043	32906	2	3F
0005435907562	32906	3	4C
0005434625972	32906	4	7F
0005434625994	32906	5	9F
0005434625977	32906	6	10D
0005434626020	32906	7	10E
0005434626044	32906	8	10F
0005434626042	32906	9	11D
0005435907561	32906	10	12A
0005434626004	32906	11	12C
0005434626045	32906	12	13A
0005435907558	32906	13	16A
0005434625971	32906	14	16E
0005435907559	32906	15	16F
0005434625932	32906	16	18F
0005435907560	32906	17	20F
0005435937435	13806	1	1A
0005435785479	13806	2	1B
0005435785416	13806	3	1C
0005435785415	13806	4	2A
0005435785403	13806	5	2B
0005435785333	13806	6	2D
0005435785381	13806	7	3B
0005435785346	13806	8	3D
0005435785458	13806	9	4A
0005435785433	13806	10	4B
0005435785263	13806	11	4C
0005435785342	13806	12	4D
0005435787360	13806	13	5A
0005435785424	13806	14	5B
0005435785402	13806	15	5C
0005435785418	13806	16	5D
0005435785500	13806	17	6A
0005435785315	13806	18	6B
0005435785317	13806	19	6C
0005435785488	13806	20	6D
0005435785343	13806	21	7A
0005435785501	13806	22	7C
0005435785414	13806	23	18A
0005435785443	13806	24	7D
0005435785494	13806	25	18B
0005435937433	13806	26	18C
0005435785461	13806	27	19A
0005435785300	13806	28	19B
0005435785527	13806	29	19C
0005435785534	13806	30	19D
0005435937436	13806	31	20A
0005432195716	13806	32	20B
0005435785493	13806	33	20C
0005435785341	13806	34	21A
0005435785345	13806	35	21B
0005435785413	13806	36	21C
0005435785168	13806	37	22A
0005435937434	13806	38	22B
0005432195717	13806	39	22D
0005435785480	13806	40	23A
0005435785316	13806	41	23B
0005435785718	27434	1	1B
0005435785715	27434	2	1C
0005435785712	27434	3	1D
0005435785703	27434	4	2A
0005435785700	27434	5	2B
0005435785693	27434	6	2C
0005435785698	27434	7	2D
0005435785687	27434	8	3A
0005432190669	27434	9	3C
0005435785694	27434	10	3D
0005435785695	27434	11	4A
0005435785709	27434	12	4B
0005432190668	27434	13	4C
0005435785692	27434	14	4D
0005435785688	27434	15	5B
0005435785697	27434	16	5C
0005435785706	27434	17	5D
0005435785714	27434	18	6A
0005435785711	27434	19	6C
0005435785716	27434	20	6D
0005435785699	27434	21	7A
0005435785710	27434	22	7B
0005435785690	27434	23	7C
0005435937393	27434	24	7D
0005432190667	27434	25	18A
0005435785691	27434	26	18B
0005435785701	27434	27	18C
0005435785685	27434	28	18D
0005435937401	27434	29	19A
0005435785705	27434	30	19B
0005435937390	27434	31	19C
0005435785702	27434	32	19D
0005435785719	27434	33	20C
0005435785708	27434	34	20B
0005435787376	27434	35	21A
0005435785713	27434	36	21B
0005435785704	27434	37	21C
0005435785696	27434	38	21D
0005435785686	27434	39	22A
0005435785707	27434	40	22B
0005435785717	27434	41	22C
0005435937392	27434	42	22D
0005435787375	27434	43	23A
0005435785689	27434	44	23B
0005434408016	20281	1	1A
0005435311212	20281	2	1C
0005434408081	20281	3	1D
0005434407920	20281	4	2A
0005435311203	20281	5	2C
0005434408097	20281	6	2D
0005435311204	20281	7	2F
0005434407821	20281	8	3A
0005434407972	20281	9	3C
0005434407597	20281	10	3D
0005435311211	20281	11	3F
0005434407907	20281	12	4A
0005434407899	20281	13	4C
0005435311210	20281	14	4E
0005432058427	20281	15	4F
0005434407955	20281	16	5A
0005434407900	20281	17	5C
0005434408017	20281	18	5D
0005435311207	20281	19	5E
0005434407802	20281	20	5F
0005434408301	20281	21	6A
0005434408048	20281	22	6C
0005434408009	20281	23	6D
0005434407971	20281	24	6F
0005434407761	20281	25	6E
0005434407961	20281	26	7A
0005435311206	20281	27	7C
0005432058429	20281	28	7D
0005434408162	20281	29	7E
0005434408176	20281	30	7F
0005434407958	20281	31	8A
0005434407777	20281	32	8C
0005434407908	20281	33	8D
0005434407968	20281	34	8E
0005434407935	20281	35	8F
0005434407893	20281	36	9A
0005434407860	20281	37	9C
0005434408096	20281	38	9F
0005434407993	20281	39	10A
0005434407962	20281	40	10C
0005434408098	20281	41	10D
0005434408007	20281	42	10E
0005434407960	20281	43	11C
0005434408177	20281	44	11D
0005434408078	20281	45	11E
0005435311219	20281	46	12A
0005435311213	20281	47	11F
0005434407982	20281	48	12D
0005434408008	20281	49	12E
0005434407627	20281	50	12F
0005434407778	20281	51	13A
0005434408031	20281	52	13C
0005435311218	20281	53	13D
0005434407894	20281	54	13E
0005434407967	20281	55	13F
0005434407889	20281	56	14A
0005434407905	20281	57	14C
0005434407981	20281	58	14D
0005434407747	20281	59	14E
0005434407984	20281	60	14F
0005434408163	20281	61	15A
0005434408120	20281	62	15C
0005434408164	20281	63	15D
0005434407596	20281	64	15E
0005435311217	20281	65	15F
0005434407869	20281	66	16A
0005434408026	20281	67	16C
0005434408080	20281	68	16D
0005435311215	20281	69	16E
0005434407890	20281	70	16F
0005432058426	20281	71	17A
0005432058428	20281	72	17C
0005434407906	20281	73	17D
0005435311208	20281	74	17E
0005434407979	20281	75	17F
0005435311205	20281	76	18A
0005435311209	20281	77	18C
0005434407992	20281	78	18D
0005434407954	20281	79	18E
0005434408300	20281	80	18F
0005434407934	20281	81	19A
0005434407980	20281	82	19C
0005434407959	20281	83	19D
0005434407953	20281	84	19E
0005434408077	20281	85	19F
0005435311216	20281	86	20A
0005435311214	20281	87	20C
0005434407684	20281	88	20D
0005434407848	20281	89	20F
0005434408470	26960	1	1A
0005434408506	26960	2	1C
0005434408481	26960	3	1D
0005434408447	26960	4	1F
0005434408486	26960	5	2A
0005434408499	26960	6	2D
0005434408449	26960	7	2F
0005434408505	26960	8	3C
0005434408473	26960	9	3A
0005434408502	26960	10	3D
0005435311063	26960	11	4A
0005434408454	26960	12	4D
0005434408461	26960	13	4F
0005434408487	26960	14	5A
0005434408466	26960	15	5C
0005434408453	26960	16	5E
0005434408477	26960	17	6A
0005434408510	26960	18	6C
0005434408495	26960	19	6D
0005434408480	26960	20	6E
0005434408493	26960	21	7A
0005434408490	26960	22	7C
0005434408460	26960	23	7D
0005434408471	26960	24	7E
0005434408474	26960	25	7F
0005434408482	26960	26	8D
0005435311076	26960	27	8E
0005434408496	26960	28	8F
0005434408455	26960	29	9A
0005434408469	26960	30	9C
0005434408491	26960	31	9D
0005434408468	26960	32	9E
0005434408488	26960	33	9F
0005434408457	26960	34	10A
0005432154019	26960	35	10C
0005434408503	26960	36	10D
0005434408472	26960	37	10F
0005434408508	26960	38	11A
0005435311062	26960	39	11C
0005432154018	26960	40	11D
0005434408476	26960	41	11E
0005434408511	26960	42	12A
0005432154017	26960	43	12C
0005434408497	26960	44	12D
0005434408507	26960	45	12E
0005434408483	26960	46	12F
0005434408492	26960	47	13A
0005434408462	26960	48	13C
0005435311075	26960	49	13D
0005434408489	26960	50	13E
0005435311065	26960	51	13F
0005434408463	26960	52	14A
0005434408452	26960	53	14D
0005434408464	26960	54	14E
0005434408451	26960	55	14F
0005434408475	26960	56	15C
0005434408450	26960	57	15D
0005434408484	26960	58	15E
0005434408509	26960	59	15F
0005434408500	26960	60	16A
0005434408478	26960	61	16C
0005434408448	26960	62	16D
0005434408479	26960	63	16E
0005434408485	26960	64	16F
0005435311086	26960	65	17A
0005434408459	26960	66	17C
0005434408456	26960	67	17E
0005434408494	26960	68	17F
0005432154014	26960	69	18C
0005434408504	26960	70	18D
0005434408465	26960	71	18F
0005434408501	26960	72	19A
0005432154020	26960	73	19E
0005432154016	26960	74	19F
0005434408458	26960	75	20A
0005432154015	26960	76	20C
0005434408498	26960	77	20E
0005434408467	26960	78	20F
0005434319573	5729	1	1A
0005434319575	5729	2	1D
0005433123952	5729	3	2C
0005434319563	5729	4	3A
0005433123953	5729	5	3D
0005434319569	5729	6	3F
0005432109734	5729	7	4C
0005433123971	5729	8	4D
0005434319566	5729	9	5A
0005432109735	5729	10	5C
0005434319561	5729	11	5E
0005433123972	5729	12	6E
0005434319581	5729	13	6F
0005433123934	5729	14	7C
0005433123978	5729	15	7E
0005433123950	5729	16	8C
0005434319559	5729	17	8F
0005434319565	5729	18	9C
0005434319568	5729	19	9D
0005434311242	5729	20	9F
0005434319562	5729	21	10C
0005434319576	5729	22	10E
0005433124045	5729	23	10F
0005434319571	5729	24	11C
0005433124020	5729	25	11D
0005433123935	5729	26	11E
0005434319582	5729	27	11F
0005434319578	5729	28	12D
0005434319579	5729	29	13A
0005433123933	5729	30	13C
0005434319574	5729	31	13F
0005433124026	5729	32	14D
0005434319567	5729	33	15C
0005434319572	5729	34	15E
0005433123949	5729	35	16D
0005433124073	5729	36	16E
0005434311243	5729	37	17D
0005433123922	5729	38	17E
0005434319564	5729	39	18A
0005433124034	5729	40	18D
0005433124047	5729	41	18E
0005433123970	5729	42	18F
0005434319570	5729	43	19A
0005434319580	5729	44	20A
0005434319577	5729	45	20C
0005434319560	5729	46	20F
0005433124168	15690	1	1C
0005433124169	15690	2	1F
0005433124171	15690	3	2D
0005434319447	15690	4	3D
0005433124174	15690	5	4D
0005434319479	15690	6	5C
0005434319433	15690	7	6E
0005434311218	15690	8	6F
0005433124176	15690	9	7C
0005433124177	15690	10	7E
0005434319384	15690	11	8A
0005434319422	15690	12	8E
0005434319405	15690	13	8F
0005434319450	15690	14	10D
0005433124170	15690	15	12A
0005434319430	15690	16	12F
0005433124175	15690	17	13D
0005434319458	15690	18	13E
0005433124167	15690	19	13F
0005434319444	15690	20	14A
0005434311223	15690	21	14D
0005434319415	15690	22	14E
0005434319441	15690	23	15C
0005434312322	15690	24	15F
0005434319400	15690	25	16E
0005434319429	15690	26	16F
0005433124165	15690	27	17F
0005433124172	15690	28	18A
0005434319428	15690	29	18E
0005434319418	15690	30	19A
0005434319414	15690	31	19D
0005434319451	15690	32	19E
0005434319421	15690	33	19F
0005433124173	15690	34	20A
0005433124166	15690	35	20E
0005435220342	31744	1	3D
0005435220344	31744	2	4B
0005435220343	31744	3	5B
0005435219221	31744	4	5D
0005435220340	31744	5	6A
0005435219224	31744	6	6C
0005435220345	31744	7	6D
0005435219223	31744	8	7D
0005435219226	31744	9	18C
0005435219222	31744	10	19C
0005435220341	31744	11	21C
0005435219225	31744	12	21D
0005434484424	8969	1	1B
0005434189190	8969	2	3A
0005434484426	8969	3	3C
0005434484421	8969	4	3D
0005434189209	8969	5	4C
0005434484425	8969	6	5A
0005434484427	8969	7	5B
0005434484420	8969	8	6B
0005434484422	8969	9	20B
0005434189194	8969	10	22A
0005434484423	8969	11	22D
0005434484362	16630	1	2C
0005434189243	16630	2	3A
0005434484358	16630	3	6A
0005434189244	16630	4	6B
0005434484357	16630	5	6D
0005434484390	16630	6	7B
0005434484361	16630	7	18A
0005434484360	16630	8	18C
0005434189245	16630	9	19C
0005434189246	16630	10	20B
0005434189242	16630	11	23B
0005433124168	7582	1	1A
0005433124172	7582	2	1D
0005433124167	7582	3	3D
0005433722225	7582	4	5F
0005433124171	7582	5	6A
0005433722228	7582	6	6D
0005433124177	7582	7	7D
0005433124169	7582	8	7F
0005433124176	7582	9	8A
0005433722229	7582	10	8D
0005433124166	7582	11	11D
0005433722227	7582	12	12D
0005433124170	7582	13	13F
0005433124165	7582	14	15A
0005433124174	7582	15	16F
0005433722199	7582	16	17D
0005433124175	7582	17	17E
0005433124173	7582	18	20C
0005433450224	7580	1	1A
0005432721224	7580	2	1C
0005433450208	7580	3	1D
0005432693430	7580	4	1F
0005432721198	7580	5	2A
0005432693435	7580	6	2C
0005433450223	7580	7	2D
0005432721203	7580	8	2F
0005432693420	7580	9	3C
0005432693423	7580	10	3D
0005433450226	7580	11	3F
0005432721211	7580	12	4A
0005432721214	7580	13	4C
0005432693416	7580	14	4D
0005432693426	7580	15	4E
0005432721219	7580	16	4F
0005433450219	7580	17	5C
0005432693425	7580	18	5E
0005432693418	7580	19	5F
0005432693424	7580	20	6A
0005432721217	7580	21	6C
0005432721200	7580	22	6D
0005432071607	7580	23	6F
0005432693433	7580	24	7A
0005432693411	7580	25	7C
0005432693429	7580	26	7D
0005432693438	7580	27	7E
0005433450217	7580	28	7F
0005432693437	7580	29	8A
0005432721202	7580	30	8D
0005432721204	7580	31	8E
0005432721216	7580	32	8F
0005433450228	7580	33	9C
0005432693428	7580	34	9D
0005433450216	7580	35	9E
0005433450222	7580	36	10A
0005432721212	7580	37	10C
0005432693422	7580	38	10D
0005433450210	7580	39	10E
0005433450207	7580	40	10F
0005433450211	7580	41	11A
0005432693436	7580	42	11D
0005432693427	7580	43	11E
0005433450209	7580	44	12A
0005432071606	7580	45	12C
0005432721210	7580	46	12D
0005432693415	7580	47	12E
0005432721223	7580	48	12F
0005433450227	7580	49	13C
0005432693434	7580	50	13D
0005432721222	7580	51	13E
0005432693412	7580	52	13F
0005432721225	7580	53	14A
0005432693439	7580	54	14C
0005432721199	7580	55	14D
0005432071608	7580	56	14E
0005433450225	7580	57	14F
0005432721206	7580	58	15A
0005432721218	7580	59	15C
0005432693441	7580	60	15D
0005432721208	7580	61	15E
0005433450214	7580	62	15F
0005432693413	7580	63	16C
0005433450212	7580	64	16D
0005433450218	7580	65	16E
0005432693417	7580	66	16F
0005432721213	7580	67	17A
0005432721221	7580	68	17C
0005432721220	7580	69	17D
0005433450215	7580	70	17E
0005432721215	7580	71	17F
0005432693440	7580	72	18C
0005433450213	7580	73	18D
0005432693414	7580	74	18E
0005432693419	7580	75	18F
0005432693432	7580	76	19A
0005433450221	7580	77	19C
0005432721201	7580	78	19D
0005433450220	7580	79	19E
0005432721205	7580	80	19F
0005432721209	7580	81	20A
0005432721207	7580	82	20C
0005432693421	7580	83	20E
0005432693431	7580	84	20F
0005432693108	30335	1	1D
0005432693110	30335	2	2A
0005433450154	30335	3	2C
0005432693181	30335	4	2D
0005432693042	30335	5	3A
0005433450077	30335	6	3C
0005433450094	30335	7	3D
0005433450051	30335	8	3F
0005433450064	30335	9	4E
0005433450050	30335	10	4F
0005432693115	30335	11	5C
0005433450058	30335	12	5D
0005432693138	30335	13	5E
0005432693132	30335	14	5F
0005433450014	30335	15	6A
0005433450157	30335	16	6E
0005432693036	30335	17	6F
0005433450009	30335	18	7A
0005433450095	30335	19	7E
0005433450020	30335	20	7F
0005433450072	30335	21	8A
0005432693109	30335	22	8C
0005432693038	30335	23	8D
0005433450135	30335	24	9A
0005432693051	30335	25	9D
0005433449895	30335	26	10A
0005432693073	30335	27	10D
0005433449979	30335	28	10E
0005432693037	30335	29	10F
0005432693035	30335	30	11A
0005432693054	30335	31	11C
0005433449957	30335	32	11D
0005433450017	30335	33	11E
0005433450028	30335	34	12C
0005433450000	30335	35	12D
0005432693107	30335	36	12E
0005433450049	30335	37	12F
0005432693205	30335	38	13C
0005432693116	30335	39	13E
0005432693112	30335	40	13F
0005432693131	30335	41	14A
0005433450018	30335	42	14C
0005432693142	30335	43	14D
0005432693130	30335	44	14F
0005432693096	30335	45	15C
0005432693251	30335	46	15F
0005433449960	30335	47	16A
0005432693139	30335	48	16D
0005433450008	30335	49	16E
0005433450019	30335	50	16F
0005432693177	30335	51	17A
0005432693074	30335	52	17C
0005432693047	30335	53	17E
0005433450042	30335	54	17F
0005432693052	30335	55	18C
0005433450104	30335	56	18D
0005433450039	30335	57	18E
0005432693252	30335	58	18F
0005432693114	30335	59	19A
0005432693102	30335	60	19D
0005433450073	30335	61	19E
0005433450059	30335	62	19F
0005432693176	30335	63	20A
0005433450158	30335	64	20C
0005432693111	30335	65	20D
0005433449896	30335	66	20E
0005432693053	30335	67	20F
0005433123934	30336	1	1C
0005433123935	30336	2	1D
0005432721046	30336	3	1F
0005433124045	30336	4	2C
0005433123972	30336	5	2F
0005432720932	30336	6	3C
0005433123952	30336	7	3D
0005433123978	30336	8	4C
0005432721036	30336	9	4D
0005432720902	30336	10	4E
0005433722298	30336	11	5A
0005432721187	30336	12	5D
0005432720978	30336	13	5E
0005432720848	30336	14	5F
0005433123950	30336	15	6A
0005432721031	30336	16	6C
0005433722296	30336	17	6E
0005432721143	30336	18	6F
0005432721066	30336	19	7D
0005433124026	30336	20	8A
0005432720963	30336	21	8C
0005433123953	30336	22	8E
0005433722301	30336	23	9A
0005432721010	30336	24	9C
0005432721086	30336	25	9F
0005433722295	30336	26	10A
0005432721080	30336	27	10C
0005432720850	30336	28	10E
0005432721002	30336	29	10F
0005433722297	30336	30	11C
0005432720948	30336	31	11D
0005432721037	30336	32	11F
0005432721145	30336	33	12D
0005433722294	30336	34	12E
0005433124073	30336	35	12F
0005432721003	30336	36	13C
0005432721032	30336	37	13D
0005433722300	30336	38	14A
0005432721062	30336	39	14D
0005433123933	30336	40	14E
0005433124047	30336	41	15A
0005433124020	30336	42	15C
0005433123970	30336	43	15D
0005432720849	30336	44	15E
0005432720945	30336	45	15F
0005432721076	30336	46	16A
0005433124034	30336	47	16D
0005432721047	30336	48	16E
0005432721063	30336	49	17C
0005432721081	30336	50	17D
0005433722302	30336	51	17E
0005432720944	30336	52	17F
0005433123949	30336	53	18A
0005432721065	30336	54	18D
0005433722299	30336	55	18E
0005433123922	30336	56	19C
0005432720996	30336	57	19D
0005433123971	30336	58	19F
0005432721011	30336	59	20D
0005433525159	1403	1	1A
0005434586907	1403	2	1C
0005434513609	1403	3	1D
0005433525162	1403	4	1F
0005433525168	1403	5	2A
0005434586896	1403	6	2D
0005433193119	1403	7	2F
0005433193101	1403	8	3A
0005434513610	1403	9	3C
0005434586897	1403	10	3D
0005434586901	1403	11	4C
0005433193102	1403	12	4D
0005433525167	1403	13	4E
0005434586918	1403	14	5A
0005434586905	1403	15	5C
0005433724856	1403	16	5F
0005433193112	1403	17	6A
0005433525165	1403	18	6C
0005434586898	1403	19	6E
0005433525158	1403	20	7E
0005433193070	1403	21	7F
0005434586894	1403	22	8A
0005433525161	1403	23	8C
0005434586916	1403	24	8E
0005434586908	1403	25	8F
0005434586899	1403	26	9A
0005434586895	1403	27	9F
0005434514997	1403	28	10C
0005434586912	1403	29	10D
0005432968852	1403	30	10E
0005433193100	1403	31	10F
0005434586903	1403	32	11E
0005433193099	1403	33	11F
0005433193118	1403	34	12D
0005434586906	1403	35	13A
0005434586919	1403	36	13D
0005432271037	1403	37	13E
0005432928001	1403	38	14A
0005434514998	1403	39	14D
0005433724859	1403	40	14E
0005433724860	1403	41	14F
0005434586915	1403	42	15A
0005432928003	1403	43	15C
0005434514996	1403	44	15D
0005434514999	1403	45	15F
0005433193050	1403	46	16A
0005434586914	1403	47	16D
0005434586910	1403	48	16E
0005433724857	1403	49	16F
0005434586911	1403	50	17A
0005434586917	1403	51	17C
0005433193113	1403	52	17D
0005433525160	1403	53	17E
0005433525166	1403	54	17F
0005434586900	1403	55	18A
0005433724858	1403	56	18C
0005433193129	1403	57	18D
0005434586902	1403	58	18E
0005433525164	1403	59	19C
0005434586913	1403	60	19E
0005433525163	1403	61	19F
0005433193051	1403	62	20A
0005433193082	1403	63	20C
0005434586909	1403	64	20D
0005434586904	1403	65	20E
0005432968851	1403	66	20F
0005434586705	18494	1	1C
0005433524986	18494	2	1D
0005434586641	18494	3	1F
0005433193193	18494	4	2C
0005434586739	18494	5	2D
0005433524994	18494	6	2F
0005433193204	18494	7	3D
0005433193202	18494	8	3F
0005434514976	18494	9	4A
0005433193194	18494	10	4D
0005432928041	18494	11	5A
0005434586719	18494	12	5C
0005433525083	18494	13	5D
0005434586605	18494	14	5E
0005433525090	18494	15	6C
0005434586560	18494	16	6E
0005433193205	18494	17	6F
0005434586612	18494	18	7C
0005433193192	18494	19	7D
0005434586689	18494	20	8D
0005433193200	18494	21	8F
0005432928045	18494	22	9A
0005433524987	18494	23	9C
0005433724806	18494	24	10A
0005434586683	18494	25	10D
0005434586652	18494	26	10E
0005433193196	18494	27	10F
0005434586688	18494	28	11D
0005433525051	18494	29	11E
0005434514980	18494	30	12D
0005433724822	18494	31	12F
0005434586738	18494	32	13A
0005434586653	18494	33	13D
0005433724814	18494	34	13E
0005432928042	18494	35	13F
0005433193197	18494	36	14A
0005433193198	18494	37	14E
0005433724813	18494	38	14F
0005433193203	18494	39	15E
0005433525092	18494	40	15F
0005432928043	18494	41	16C
0005433525050	18494	42	16E
0005432928040	18494	43	17D
0005433193199	18494	44	17E
0005433525084	18494	45	18A
0005432968865	18494	46	18C
0005432968866	18494	47	18D
0005434514977	18494	48	18F
0005433193201	18494	49	19A
0005433193195	18494	50	19E
0005433525091	18494	51	19F
0005434586685	18494	52	20E
0005432928044	18494	53	20F
0005434344588	11447	1	1A
0005434344573	11447	2	1B
0005434344585	11447	3	1C
0005434344590	11447	4	1D
0005434344598	11447	5	2A
0005434344567	11447	6	2C
0005434344581	11447	7	2D
0005434344577	11447	8	3A
0005435302204	11447	9	3B
0005434344570	11447	10	3C
0005434344574	11447	11	3D
0005434344599	11447	12	4A
0005434344597	11447	13	4B
0005435302211	11447	14	4C
0005434142654	11447	15	5A
0005434344591	11447	16	5B
0005435302219	11447	17	5C
0005434344583	11447	18	5D
0005434344584	11447	19	6A
0005434344582	11447	20	6B
0005434344580	11447	21	6D
0005435302198	11447	22	7A
0005434344594	11447	23	7B
0005434344586	11447	24	7C
0005434344578	11447	25	7D
0005434344572	11447	26	18B
0005434344593	11447	27	18D
0005434344569	11447	28	19A
0005434142655	11447	29	19B
0005434344568	11447	30	19C
0005434344595	11447	31	19D
0005434344579	11447	32	20A
0005434344576	11447	33	20B
0005434142656	11447	34	20C
0005434344575	11447	35	21A
0005434344592	11447	36	21B
0005435302197	11447	37	21C
0005435302208	11447	38	21D
0005434344596	11447	39	22A
0005434344589	11447	40	22B
0005434142657	11447	41	22C
0005434344587	11447	42	22D
0005434344571	11447	43	23A
0005435302216	11447	44	23B
0005435304213	29763	1	1A
0005435305037	29763	2	1B
0005435305036	29763	3	1C
0005434344359	29763	4	2A
0005434344411	29763	5	2B
0005434344188	29763	6	2C
0005435304214	29763	7	2D
0005435304211	29763	8	3A
0005434344316	29763	9	3C
0005434344295	29763	10	3D
0005434142617	29763	11	4A
0005434344361	29763	12	4B
0005434344159	29763	13	4C
0005434344189	29763	14	4D
0005435304212	29763	15	5A
0005434344323	29763	16	5B
0005434344226	29763	17	5C
0005435304210	29763	18	6A
0005434344150	29763	19	6B
0005434344227	29763	20	6D
0005434344360	29763	21	7A
0005434344219	29763	22	7B
0005434344466	29763	23	7C
0005434344286	29763	24	7D
0005434344337	29763	25	18A
0005434344248	29763	26	18B
0005434344342	29763	27	18C
0005434344220	29763	28	18D
0005434344095	29763	29	19A
0005434142616	29763	30	19B
0005434344196	29763	31	19C
0005434344111	29763	32	19D
0005434344151	29763	33	20B
0005434344283	29763	34	20C
0005434344317	29763	35	20D
0005434344324	29763	36	21A
0005434344228	29763	37	21B
0005434344247	29763	38	21C
0005435304209	29763	39	21D
0005434142610	29763	40	22A
0005434344208	29763	41	22B
0005434344404	29763	42	22D
0005434344336	29763	43	23B
0005435824945	1269	1	1A
0005433415707	1269	2	1F
0005433415700	1269	3	2F
0005435824943	1269	4	2D
0005433415729	1269	5	3A
0005435824934	1269	6	4D
0005433415766	1269	7	4C
0005435824936	1269	8	5A
0005433415677	1269	9	4F
0005435824923	1269	10	6B
0005435824941	1269	11	7B
0005435824921	1269	12	7E
0005435824926	1269	13	7F
0005433415645	1269	14	8B
0005435824939	1269	15	8D
0005435824946	1269	16	8F
0005433415737	1269	17	8E
0005433415748	1269	18	9C
0005435824925	1269	19	9E
0005435824932	1269	20	10E
0005435824935	1269	21	10D
0005435824937	1269	22	10F
0005433415675	1269	23	11B
0005435824942	1269	24	11A
0005435824933	1269	25	11D
0005435824938	1269	26	11E
0005435824931	1269	27	12B
0005433415747	1269	28	12A
0005433415708	1269	29	13A
0005435824947	1269	30	13E
0005435824944	1269	31	13F
0005432284593	1269	32	14E
0005435824929	1269	33	15F
0005435824930	1269	34	16B
0005432284594	1269	35	17D
0005433415704	1269	36	18D
0005435824922	1269	37	18C
0005433415705	1269	38	18F
0005432284592	1269	39	19F
0005433415736	1269	40	19E
0005435824924	1269	41	20B
0005435824927	1269	42	20E
0005435824940	1269	43	21B
0005433415706	1269	44	21D
0005435824928	1269	45	21E
0005433415842	17984	1	1C
0005435824760	17984	2	1F
0005435824800	17984	3	2D
0005435824753	17984	4	3A
0005435824692	17984	5	3C
0005435824706	17984	6	4A
0005433415840	17984	7	5C
0005435824662	17984	8	5D
0005435824652	17984	9	6C
0005433415836	17984	10	7E
0005435824759	17984	11	8B
0005435824691	17984	12	8F
0005435824807	17984	13	9A
0005435824664	17984	14	9D
0005435824650	17984	15	9B
0005435824702	17984	16	10A
0005433415839	17984	17	10C
0005433415838	17984	18	10E
0005435824607	17984	19	12D
0005433415850	17984	20	12E
0005433415837	17984	21	13D
0005435824731	17984	22	13B
0005435824685	17984	23	14D
0005435824663	17984	24	14F
0005433415845	17984	25	15A
0005433415846	17984	26	15F
0005435824635	17984	27	15D
0005435824689	17984	28	16B
0005435824620	17984	29	16D
0005433415844	17984	30	17D
0005433415848	17984	31	18C
0005433415851	17984	32	19C
0005433415843	17984	33	19D
0005435824754	17984	34	20A
0005433415847	17984	35	19F
0005433415849	17984	36	20B
0005435824688	17984	37	20D
0005433415835	17984	38	20F
0005433415841	17984	39	21B
0005432784427	5662	1	1A
0005432784433	5662	2	1C
0005435242972	5662	3	1F
0005432784415	5662	4	2A
0005432784393	5662	5	2C
0005432784386	5662	6	2D
0005432144024	5662	7	2F
0005432784418	5662	8	3A
0005432784432	5662	9	3C
0005435242944	5662	10	3D
0005432784420	5662	11	3F
0005432784421	5662	12	4A
0005435476780	5662	13	4C
0005435476778	5662	14	4D
0005435242973	5662	15	4E
0005432784407	5662	16	4F
0005432784425	5662	17	5A
0005432784419	5662	18	5D
0005432784422	5662	19	5E
0005432784390	5662	20	5F
0005432784423	5662	21	6A
0005432784396	5662	22	6C
0005435242930	5662	23	6E
0005432784416	5662	24	6F
0005435476798	5662	25	7A
0005432784384	5662	26	7C
0005432784428	5662	27	7D
0005432784405	5662	28	7E
0005432144026	5662	29	7F
0005435242913	5662	30	8D
0005432784424	5662	31	8E
0005432144023	5662	32	8F
0005435242967	5662	33	9A
0005432784387	5662	34	9C
0005432784385	5662	35	9D
0005432784435	5662	36	9E
0005432784413	5662	37	9F
0005432784411	5662	38	10A
0005432784389	5662	39	10C
0005432784399	5662	40	10D
0005435476800	5662	41	10E
0005432784382	5662	42	10F
0005432144025	5662	43	11A
0005435242906	5662	44	11C
0005435242928	5662	45	11E
0005432784394	5662	46	11F
0005435242942	5662	47	12C
0005432784397	5662	48	12D
0005432784409	5662	49	12E
0005432784395	5662	50	12F
0005432784403	5662	51	13C
0005435476799	5662	52	13D
0005432784434	5662	53	13E
0005435242929	5662	54	13F
0005432784426	5662	55	14A
0005432784406	5662	56	14C
0005432784401	5662	57	14D
0005435476750	5662	58	14E
0005432784388	5662	59	14F
0005432784410	5662	60	15A
0005432784402	5662	61	15C
0005435476755	5662	62	15D
0005432784430	5662	63	15E
0005432784404	5662	64	15F
0005435242982	5662	65	16A
0005432784398	5662	66	16D
0005432784391	5662	67	16F
0005432784429	5662	68	17C
0005432784392	5662	69	17D
0005432784383	5662	70	17E
0005435242957	5662	71	18A
0005432784408	5662	72	18D
0005432784400	5662	73	18E
0005432784417	5662	74	19A
0005432784414	5662	75	19C
0005435476736	5662	76	19E
0005435476751	5662	77	19F
0005435242974	5662	78	20C
0005432784431	5662	79	20D
0005435242821	5662	80	20E
0005432784412	5662	81	20F
0005432783865	15366	1	1A
0005435243143	15366	2	1C
0005432783596	15366	3	1D
0005432783955	15366	4	1F
0005435243130	15366	5	2A
0005435243147	15366	6	2C
0005435243148	15366	7	2D
0005432783753	15366	8	2F
0005432783960	15366	9	3A
0005435243149	15366	10	3C
0005432783595	15366	11	3D
0005435243132	15366	12	3F
0005435243145	15366	13	4A
0005435243146	15366	14	4C
0005435243144	15366	15	4D
0005432783795	15366	16	4E
0005432783874	15366	17	4F
0005432784072	15366	18	5A
0005432784026	15366	19	5C
0005432783869	15366	20	5D
0005432783624	15366	21	5E
0005432784002	15366	22	5F
0005432783776	15366	23	6A
0005432783748	15366	24	6C
0005432783947	15366	25	6D
0005432783786	15366	26	6E
0005432783809	15366	27	6F
0005432784151	15366	28	7A
0005435243152	15366	29	7C
0005432784061	15366	30	7D
0005432784128	15366	31	7E
0005435243136	15366	32	7F
0005435243138	15366	33	8A
0005435243141	15366	34	8C
0005435243142	15366	35	8D
0005435476839	15366	36	8E
0005435243154	15366	37	8F
0005432784146	15366	38	9A
0005435243156	15366	39	9C
0005435243150	15366	40	9D
0005435476841	15366	41	9E
0005435243153	15366	42	9F
0005432783978	15366	43	10A
0005432783914	15366	44	10C
0005432783623	15366	45	10D
0005432783793	15366	46	10E
0005432783758	15366	47	10F
0005435243133	15366	48	11A
0005432783944	15366	49	11C
0005432783959	15366	50	11D
0005432783834	15366	51	11E
0005432784057	15366	52	11F
0005432783803	15366	53	12A
0005432783618	15366	54	12C
0005432783825	15366	55	12D
0005432783757	15366	56	12E
0005432783749	15366	57	12F
0005432783884	15366	58	13A
0005435243134	15366	59	13C
0005435476840	15366	60	13D
0005432783787	15366	61	13E
0005435243140	15366	62	13F
0005432783979	15366	63	14A
0005432783754	15366	64	14C
0005432783932	15366	65	14D
0005432783954	15366	66	14E
0005435243131	15366	67	14F
0005435243137	15366	68	15A
0005435243129	15366	69	15C
0005432784008	15366	70	15D
0005432784195	15366	71	15E
0005432783919	15366	72	15F
0005432783980	15366	73	16A
0005432784001	15366	74	16C
0005432784060	15366	75	16D
0005432783873	15366	76	16E
0005432783810	15366	77	16F
0005432783782	15366	78	17A
0005432783860	15366	79	17C
0005432784110	15366	80	17D
0005432783823	15366	81	17E
0005432783956	15366	82	17F
0005435243135	15366	83	18A
0005432783920	15366	84	18C
0005435243151	15366	85	18D
0005435243139	15366	86	18E
0005432783934	15366	87	19A
0005432783958	15366	88	19C
0005432783836	15366	89	19D
0005435243155	15366	90	19E
0005432783933	15366	91	19F
0005432783864	15366	92	20A
0005435243157	15366	93	20C
0005432783706	15366	94	20D
0005432783946	15366	95	20E
0005432784025	15366	96	20F
0005432848477	4382	1	1A
0005432848474	4382	2	1B
0005435850919	4382	3	1D
0005432848476	4382	4	2A
0005432848478	4382	5	2D
0005432848483	4382	6	3A
0005432848480	4382	7	3C
0005432848473	4382	8	3D
0005435850976	4382	9	4A
0005435850888	4382	10	4B
0005435850945	4382	11	5A
0005435850971	4382	12	5D
0005435850940	4382	13	6A
0005432848482	4382	14	6B
0005435850968	4382	15	6C
0005432848471	4382	16	6D
0005435850975	4382	17	7B
0005432848479	4382	18	7D
0005432848472	4382	19	18A
0005434462815	4382	20	18B
0005432848484	4382	21	18D
0005432848475	4382	22	19A
0005432848486	4382	23	19C
0005435850944	4382	24	19D
0005432848485	4382	25	20B
0005432848481	4382	26	21C
0005434463954	4382	27	23A
0005435851018	28885	1	1C
0005432848356	28885	2	1D
0005434463932	28885	3	3A
0005432848347	28885	4	3C
0005434463933	28885	5	3D
0005435851017	28885	6	4D
0005432848333	28885	7	5A
0005435851014	28885	8	5D
0005435851011	28885	9	6C
0005432848351	28885	10	6D
0005432848372	28885	11	7C
0005435851012	28885	12	7D
0005432848344	28885	13	18A
0005435851015	28885	14	18D
0005432848312	28885	15	20A
0005434463930	28885	16	20B
0005435851016	28885	17	20C
0005434463931	28885	18	21A
0005432848364	28885	19	21D
0005432848355	28885	20	22B
0005432848353	28885	21	22D
0005435851013	28885	22	23A
0005432848342	28885	23	23B
0005434443889	6266	1	1A
0005433497317	6266	2	1C
0005432075270	6266	3	1F
0005434443892	6266	4	2A
0005434443901	6266	5	2C
0005434443893	6266	6	3A
0005434926179	6266	7	3C
0005434443888	6266	8	3D
0005434926178	6266	9	3F
0005433497338	6266	10	4A
0005434443891	6266	11	4C
0005434926181	6266	12	4D
0005433497321	6266	13	4E
0005434443890	6266	14	5C
0005434443895	6266	15	5F
0005434443899	6266	16	6A
0005433497339	6266	17	6C
0005434443896	6266	18	6E
0005433497319	6266	19	7A
0005434926177	6266	20	7C
0005433497340	6266	21	7D
0005433497328	6266	22	7E
0005434926175	6266	23	7F
0005433497343	6266	24	8A
0005433497325	6266	25	8C
0005433497329	6266	26	8E
0005433497327	6266	27	8F
0005434926187	6266	28	9A
0005433497336	6266	29	9C
0005434926185	6266	30	9D
0005434926176	6266	31	9F
0005433497341	6266	32	10C
0005434926169	6266	33	10D
0005434926180	6266	34	10E
0005434926173	6266	35	10F
0005433497318	6266	36	11C
0005434443898	6266	37	11D
0005434926184	6266	38	11E
0005434926171	6266	39	11F
0005434926182	6266	40	12A
0005433497344	6266	41	12C
0005434443887	6266	42	12D
0005433497332	6266	43	12E
0005434926168	6266	44	13A
0005434926174	6266	45	13C
0005433497323	6266	46	13E
0005432075269	6266	47	13F
0005433497345	6266	48	14A
0005433497334	6266	49	14C
0005433497322	6266	50	14D
0005433497331	6266	51	14E
0005433497324	6266	52	15A
0005433497333	6266	53	15C
0005433497326	6266	54	15D
0005434926170	6266	55	15E
0005434926186	6266	56	15F
0005433497330	6266	57	16A
0005434926172	6266	58	16D
0005433497315	6266	59	16E
0005434443900	6266	60	16F
0005434926167	6266	61	17A
0005433497342	6266	62	17C
0005432075271	6266	63	17D
0005433497337	6266	64	17E
0005434926166	6266	65	17F
0005433497346	6266	66	18C
0005434926183	6266	67	18F
0005433497316	6266	68	19A
0005434443902	6266	69	19C
0005433497320	6266	70	19D
0005433497335	6266	71	19E
0005434443897	6266	72	19F
0005433497314	6266	73	20A
0005434443894	6266	74	20D
0005434443645	20328	1	1A
0005434443742	20328	2	1C
0005434925750	20328	3	1D
0005434443755	20328	4	1F
0005433497161	20328	5	2A
0005433497206	20328	6	2C
0005433497092	20328	7	2D
0005434925857	20328	8	2F
0005434443731	20328	9	3C
0005433497162	20328	10	3D
0005433497155	20328	11	3F
0005434443744	20328	12	4D
0005434925793	20328	13	4E
0005433496990	20328	14	4F
0005433497269	20328	15	5A
0005433497083	20328	16	5C
0005433497026	20328	17	5D
0005433497008	20328	18	5F
0005434925800	20328	19	5E
0005434443741	20328	20	6A
0005434925805	20328	21	6D
0005434925960	20328	22	6E
0005434443707	20328	23	6F
0005434443743	20328	24	7A
0005434925848	20328	25	7C
0005433497187	20328	26	7D
0005433497057	20328	27	7E
0005434925921	20328	28	7F
0005434925891	20328	29	8A
0005434925815	20328	30	8C
0005433497079	20328	31	8D
0005433497090	20328	32	8F
0005433497002	20328	33	9A
0005433497186	20328	34	9C
0005434925947	20328	35	9D
0005434443745	20328	36	9E
0005434925874	20328	37	9F
0005434925691	20328	38	10A
0005433496992	20328	39	10C
0005433497154	20328	40	10D
0005434925812	20328	41	10E
0005434925946	20328	42	10F
0005434925789	20328	43	11A
0005433497134	20328	44	11C
0005434443749	20328	45	11E
0005434925792	20328	46	11F
0005434925867	20328	47	12A
0005433497270	20328	48	12D
0005433497118	20328	49	12E
0005434925971	20328	50	12F
0005434925845	20328	51	13A
0005434925859	20328	52	13C
0005434925801	20328	53	13D
0005433497207	20328	54	13E
0005433497119	20328	55	13F
0005434925922	20328	56	14A
0005434443719	20328	57	14C
0005433497102	20328	58	14D
0005433497078	20328	59	14F
0005433496993	20328	60	15A
0005434443781	20328	61	15C
0005434443663	20328	62	15D
0005434925761	20328	63	15E
0005433497097	20328	64	15F
0005434925814	20328	65	16C
0005434925766	20328	66	16E
0005434925804	20328	67	16F
0005433497133	20328	68	17C
0005434925826	20328	69	17D
0005433497085	20328	70	17E
0005433497101	20328	71	17F
0005433497205	20328	72	18A
0005434925961	20328	73	18C
0005434925858	20328	74	18D
0005434925744	20328	75	18E
0005434925883	20328	76	18F
0005434925899	20328	77	19A
0005434443706	20328	78	19D
0005434925920	20328	79	19C
0005433497086	20328	80	19F
0005433497100	20328	81	20A
0005434925892	20328	82	20C
0005434925794	20328	83	20D
0005434925847	20328	84	20E
0005432784028	12192	1	1A
0005435243167	12192	2	1C
0005432783797	12192	3	1D
0005432784069	12192	4	2A
0005432783991	12192	5	2C
0005432783871	12192	6	2D
0005432783896	12192	7	2F
0005432783964	12192	8	3A
0005435243177	12192	9	3C
0005432784070	12192	10	3D
0005435243168	12192	11	3F
0005432783837	12192	12	4A
0005432783840	12192	13	4C
0005432783900	12192	14	4D
0005435243183	12192	15	4E
0005432783804	12192	16	4F
0005435243178	12192	17	5A
0005435243184	12192	18	5C
0005432783818	12192	19	5D
0005432783893	12192	20	5E
0005432783657	12192	21	5F
0005435243174	12192	22	6C
0005432783731	12192	23	6D
0005432783984	12192	24	6E
0005432784139	12192	25	7C
0005432783915	12192	26	7D
0005432784137	12192	27	7E
0005435243172	12192	28	7F
0005432783902	12192	29	8D
0005432783889	12192	30	8E
0005432783817	12192	31	8F
0005432783791	12192	32	9A
0005435243171	12192	33	9C
0005435243160	12192	34	9D
0005432784071	12192	35	9E
0005432783983	12192	36	9F
0005432784020	12192	37	10A
0005432784135	12192	38	10C
0005432783901	12192	39	10D
0005432783953	12192	40	10E
0005432783986	12192	41	11A
0005435243159	12192	42	11C
0005435243162	12192	43	11E
0005432783890	12192	44	11F
0005435243170	12192	45	12A
0005432783808	12192	46	12C
0005432783841	12192	47	12D
0005435243182	12192	48	13A
0005432784150	12192	49	13C
0005432783899	12192	50	13D
0005435243161	12192	51	13E
0005435243166	12192	52	13F
0005432783894	12192	53	14A
0005432784019	12192	54	14E
0005432784010	12192	55	14F
0005432783805	12192	56	15A
0005432783730	12192	57	15C
0005432783658	12192	58	15D
0005432784056	12192	59	15E
0005435243173	12192	60	15F
0005435243179	12192	61	16A
0005432783792	12192	62	16C
0005435243163	12192	63	16D
0005435243165	12192	64	16F
0005432783992	12192	65	17A
0005435243180	12192	66	17C
0005435243169	12192	67	17D
0005435243181	12192	68	17E
0005435243175	12192	69	17F
0005432783951	12192	70	18A
0005432783985	12192	71	18C
0005432783870	12192	72	18D
0005435243176	12192	73	18F
0005435243158	12192	74	19A
0005435243164	12192	75	19C
0005432784109	12192	76	19E
0005432784138	12192	77	19F
0005432784095	12192	78	20A
0005432783732	12192	79	20C
0005432783963	12192	80	20E
0005432783895	12192	81	20F
0005435242856	15439	1	1A
0005432784329	15439	2	1C
0005435242918	15439	3	1D
0005435242953	15439	4	1F
0005432784343	15439	5	2A
0005435242855	15439	6	2C
0005432784369	15439	7	2D
0005435242938	15439	8	2F
0005435242873	15439	9	3A
0005432784359	15439	10	3C
0005435242854	15439	11	3D
0005432784375	15439	12	3F
0005432784379	15439	13	4A
0005432784328	15439	14	4C
0005432784337	15439	15	4D
0005435242870	15439	16	4F
0005432784333	15439	17	5A
0005432784350	15439	18	5C
0005435242861	15439	19	5D
0005435242945	15439	20	5E
0005435242989	15439	21	5F
0005432784363	15439	22	6A
0005432784360	15439	23	6C
0005432784365	15439	24	6D
0005435242720	15439	25	6E
0005432784362	15439	26	6F
0005432784347	15439	27	7A
0005435242885	15439	28	7C
0005435242884	15439	29	7D
0005432784330	15439	30	7E
0005432784361	15439	31	7F
0005432784338	15439	32	8A
0005432784357	15439	33	8C
0005432784355	15439	34	8E
0005432784373	15439	35	8F
0005432784348	15439	36	9A
0005432784372	15439	37	9C
0005435242923	15439	38	9D
0005435242849	15439	39	9E
0005432784342	15439	40	9F
0005435242883	15439	41	10A
0005432784340	15439	42	10C
0005432784358	15439	43	10E
0005432784353	15439	44	10F
0005432784368	15439	45	11A
0005432784376	15439	46	11C
0005435242962	15439	47	11D
0005435242927	15439	48	11E
0005432784367	15439	49	11F
0005435242941	15439	50	12A
0005432784334	15439	51	12C
0005435242937	15439	52	12D
0005432784352	15439	53	12E
0005435242940	15439	54	12F
0005435242999	15439	55	13A
0005432784351	15439	56	13C
0005432784354	15439	57	13D
0005432784370	15439	58	13E
0005432784381	15439	59	13F
0005432784371	15439	60	14A
0005432784331	15439	61	14C
0005432784378	15439	62	14D
0005432784366	15439	63	14E
0005432784336	15439	64	14F
0005432784356	15439	65	15A
0005435242922	15439	66	15C
0005435242721	15439	67	15D
0005432784346	15439	68	15E
0005432784326	15439	69	15F
0005435242882	15439	70	16A
0005435242808	15439	71	16C
0005432784374	15439	72	16D
0005432784335	15439	73	16E
0005432784344	15439	74	16F
0005432784332	15439	75	17A
0005432784327	15439	76	17C
0005432784341	15439	77	17D
0005435242890	15439	78	17E
0005432784339	15439	79	17F
0005435242857	15439	80	18A
0005435242891	15439	81	18E
0005435242911	15439	82	18F
0005432784349	15439	83	19A
0005432784364	15439	84	19C
0005432784345	15439	85	19D
0005435242917	15439	86	19E
0005435242905	15439	87	19F
0005432784380	15439	88	20A
0005432784377	15439	89	20D
0005435242915	15439	90	20F
0005434878088	10106	1	1C
0005434877931	10106	2	1A
0005434758894	10106	3	1D
0005434878479	10106	4	2C
0005434877778	10106	5	2A
0005434878757	10106	6	1F
0005434878791	10106	7	2D
0005434878500	10106	8	2F
0005434878708	10106	9	3D
0005434878434	10106	10	4A
0005434878406	10106	11	3F
0005434878838	10106	12	4C
0005434878387	10106	13	4F
0005434878528	10106	14	4D
0005434878182	10106	15	5C
0005434878376	10106	16	5A
0005434878556	10106	17	5F
0005434878338	10106	18	5D
0005434878437	10106	19	6B
0005434878337	10106	20	6A
0005434878138	10106	21	6C
0005434878238	10106	22	6E
0005434878334	10106	23	6D
0005434878318	10106	24	7A
0005434878336	10106	25	6F
0005434878756	10106	26	7C
0005434878468	10106	27	7B
0005434878303	10106	28	7E
0005434878438	10106	29	7D
0005434878297	10106	30	7F
0005434878744	10106	31	8B
0005434878750	10106	32	8A
0005434878743	10106	33	8D
0005434878790	10106	34	8C
0005434878584	10106	35	8F
0005434877932	10106	36	8E
0005434878760	10106	37	9B
0005434878523	10106	38	9A
0005434878281	10106	39	9D
0005434878722	10106	40	9C
0005434878727	10106	41	9E
0005434878844	10106	42	10A
0005434878040	10106	43	10B
0005435913965	10106	44	10E
0005434878632	10106	45	10D
0005434878156	10106	46	11A
0005434878335	10106	47	11C
0005434879051	10106	48	11B
0005434878547	10106	49	11E
0005434878585	10106	50	11D
0005434878196	10106	51	12B
0005434878763	10106	52	12A
0005434878039	10106	53	12C
0005434878524	10106	54	12E
0005434878310	10106	55	12D
0005434878724	10106	56	13B
0005434878499	10106	57	13A
0005434878768	10106	58	13C
0005434878526	10106	59	13E
0005434878604	10106	60	13F
0005434878728	10106	61	14C
0005434878155	10106	62	14B
0005434878280	10106	63	14A
0005434878271	10106	64	14D
0005434878659	10106	65	14F
0005434878435	10106	66	14E
0005434878467	10106	67	15B
0005434878239	10106	68	15A
0005434878477	10106	69	15C
0005434878706	10106	70	15F
0005434878302	10106	71	15E
0005434878688	10106	72	15D
0005434878428	10106	73	16A
0005434878758	10106	74	16C
0005434910138	10106	75	16D
0005434878745	10106	76	16E
0005434878525	10106	77	17C
0005434878527	10106	78	17B
0005434878687	10106	79	17A
0005434878364	10106	80	17D
0005434878755	10106	81	17F
0005434878622	10106	82	17E
0005434878497	10106	83	18B
0005434878754	10106	84	18E
0005434878513	10106	85	18D
0005434878753	10106	86	19A
0005434878546	10106	87	18F
0005434878509	10106	88	19C
0005434878429	10106	89	19B
0005434877908	10106	90	19E
0005434878522	10106	91	19D
0005434878746	10106	92	19F
0005434878583	10106	93	20C
0005434878339	10106	94	20B
0005434910139	10106	95	20A
0005434878603	10106	96	20D
0005434910137	10106	97	20F
0005434878042	10106	98	20E
0005434879050	10106	99	21A
0005434878660	10106	100	21C
0005434878594	10106	101	21E
0005434878478	10106	102	21D
0005434878520	10106	103	21F
0005434879340	14647	1	1C
0005434879322	14647	2	1A
0005434879253	14647	3	1D
0005434879274	14647	4	2A
0005434879259	14647	5	2D
0005434879249	14647	6	2C
0005434879279	14647	7	3A
0005434879312	14647	8	2F
0005434879285	14647	9	3C
0005434879296	14647	10	4A
0005434879271	14647	11	3F
0005434879284	14647	12	3D
0005434879256	14647	13	4D
0005434879313	14647	14	5A
0005434879332	14647	15	4F
0005434910123	14647	16	5C
0005434758919	14647	17	5F
0005434879344	14647	18	5D
0005434879283	14647	19	6B
0005434879278	14647	20	6A
0005434879263	14647	21	6D
0005434879314	14647	22	6C
0005434879324	14647	23	6E
0005435913934	14647	24	7A
0005434879335	14647	25	6F
0005434879330	14647	26	7B
0005434879339	14647	27	7E
0005434879306	14647	28	7D
0005434879258	14647	29	7F
0005434879295	14647	30	8C
0005434879290	14647	31	8B
0005434879321	14647	32	8A
0005434879300	14647	33	8D
0005434879275	14647	34	9A
0005434879268	14647	35	8F
0005434879291	14647	36	8E
0005435913936	14647	37	9B
0005434879318	14647	38	9D
0005434879260	14647	39	9F
0005434879337	14647	40	9E
0005434879326	14647	41	10A
0005434879331	14647	42	10C
0005434879325	14647	43	10E
0005434879320	14647	44	10D
0005434879252	14647	45	10F
0005434879345	14647	46	11B
0005434758920	14647	47	11A
0005434879277	14647	48	11D
0005434879267	14647	49	11C
0005434879338	14647	50	11F
0005434879304	14647	51	11E
0005434879255	14647	52	12B
0005434879311	14647	53	12A
0005435913935	14647	54	12C
0005434879288	14647	55	12E
0005434879308	14647	56	13A
0005434879323	14647	57	12F
0005434879327	14647	58	13C
0005434879265	14647	59	13B
0005434879334	14647	60	13E
0005434879298	14647	61	13D
0005434879269	14647	62	14A
0005434879282	14647	63	13F
0005434879299	14647	64	14C
0005434879333	14647	65	14B
0005434879262	14647	66	14E
0005434879343	14647	67	14D
0005434879276	14647	68	14F
0005434879250	14647	69	15B
0005434879302	14647	70	15A
0005434879261	14647	71	15D
0005434879289	14647	72	15F
0005434879310	14647	73	15E
0005434879341	14647	74	16C
0005434879317	14647	75	16B
0005434879254	14647	76	16D
0005434879272	14647	77	17A
0005434879329	14647	78	16F
0005434879286	14647	79	16E
0005434758921	14647	80	17C
0005434879273	14647	81	17B
0005434879297	14647	82	17F
0005434879270	14647	83	17E
0005434879293	14647	84	18B
0005434879264	14647	85	18C
0005434879328	14647	86	19A
0005434879281	14647	87	18F
0005434879316	14647	88	19C
0005434879303	14647	89	19B
0005434879336	14647	90	19D
0005434879315	14647	91	19F
0005434879266	14647	92	19E
0005434879307	14647	93	20B
0005434879319	14647	94	20A
0005434879305	14647	95	20D
0005434879309	14647	96	20C
0005434879287	14647	97	20F
0005434879292	14647	98	20E
0005434879301	14647	99	21B
0005434879251	14647	100	21A
0005434879257	14647	101	21D
0005434879280	14647	102	21C
0005434879342	14647	103	21E
0005434879294	14647	104	21F
0005435660264	9236	1	1C
0005435660268	9236	2	1D
0005435660263	9236	3	4A
0005435660269	9236	4	4C
0005434251937	9236	5	5A
0005434251996	9236	6	5B
0005434252027	9236	7	5C
0005435660270	9236	8	6A
0005435660266	9236	9	6B
0005434251977	9236	10	6D
0005434252003	9236	11	7A
0005435660262	9236	12	7B
0005435660260	9236	13	18A
0005434251990	9236	14	18B
0005435660261	9236	15	19A
0005435660267	9236	16	19C
0005434251960	9236	17	19D
0005434251938	9236	18	20B
0005434252019	9236	19	21B
0005434251963	9236	20	21D
0005435660265	9236	21	21C
0005434251997	9236	22	22B
0005434251964	9236	23	22C
0005434251989	9236	24	22D
0005434252068	24633	1	1D
0005434252072	24633	2	2A
0005434252074	24633	3	2B
0005435660100	24633	4	2D
0005434252075	24633	5	3A
0005434252069	24633	6	3B
0005435660155	24633	7	4A
0005435660210	24633	8	4B
0005434252073	24633	9	5A
0005434252070	24633	10	5D
0005434252071	24633	11	6A
0005435660126	24633	12	6D
0005435660224	24633	13	7A
0005434252076	24633	14	7B
0005435660165	24633	15	21A
0005435660189	24633	16	22B
0005435660154	24633	17	22D
0005435660158	24633	18	23B
0005433681119	2772	1	1A
0005432967025	2772	2	1C
0005432222845	2772	3	1D
0005433681108	2772	4	1F
0005433681091	2772	5	2A
0005433681116	2772	6	2C
0005433681090	2772	7	2D
0005432966949	2772	8	2F
0005432967057	2772	9	3A
0005432222843	2772	10	3C
0005432967113	2772	11	3D
0005432966986	2772	12	3F
0005433681081	2772	13	4A
0005432967101	2772	14	4C
0005433681103	2772	15	4D
0005432967099	2772	16	4F
0005432222844	2772	17	4E
0005433681092	2772	18	5A
0005433681080	2772	19	5C
0005432966958	2772	20	5D
0005433681122	2772	21	5E
0005432967076	2772	22	5F
0005433681110	2772	23	6A
0005433681104	2772	24	6C
0005432967006	2772	25	6E
0005433681085	2772	26	6F
0005432967049	2772	27	7A
0005432967017	2772	28	7C
0005433681089	2772	29	7D
0005433681095	2772	30	7E
0005433681086	2772	31	8C
0005433681079	2772	32	8D
0005433681097	2772	33	8E
0005432222839	2772	34	8F
0005432966967	2772	35	9A
0005432967147	2772	36	9C
0005433681113	2772	37	9D
0005432966987	2772	38	9E
0005433681125	2772	39	9F
0005433681088	2772	40	10A
0005432967026	2772	41	10C
0005433681082	2772	42	10D
0005432222842	2772	43	10E
0005433681098	2772	44	11A
0005433681121	2772	45	11C
0005432967100	2772	46	11D
0005432967098	2772	47	11E
0005432967050	2772	48	11F
0005432966970	2772	49	12A
0005433681114	2772	50	12C
0005433681124	2772	51	12D
0005432967089	2772	52	12E
0005433681087	2772	53	12F
0005432967102	2772	54	13A
0005433681107	2772	55	13C
0005432967112	2772	56	13D
0005432967036	2772	57	13E
0005433681096	2772	58	13F
0005432222840	2772	59	14A
0005432966906	2772	60	14C
0005432966969	2772	61	14D
0005433681099	2772	62	14E
0005432222841	2772	63	14F
0005433681123	2772	64	15A
0005432967048	2772	65	15C
0005432966994	2772	66	15D
0005433681083	2772	67	15E
0005433681115	2772	68	15F
0005433681118	2772	69	16A
0005433681084	2772	70	16C
0005433681093	2772	71	16E
0005433681094	2772	72	16D
0005433681102	2772	73	16F
0005433681105	2772	74	17C
0005433684443	2772	75	17D
0005433681112	2772	76	17E
0005433681109	2772	77	17F
0005433681117	2772	78	18A
0005432966907	2772	79	18D
0005432967053	2772	80	18E
0005432967097	2772	81	18F
0005433681106	2772	82	19A
0005433681100	2772	83	19C
0005433681120	2772	84	19D
0005433681101	2772	85	19E
0005433681111	2772	86	19F
0005432966951	2772	87	20A
0005433681126	2772	88	20C
0005432966950	2772	89	20D
0005433684442	2772	90	20E
0005433684422	29175	1	1A
0005432005245	29175	2	1C
0005432967231	29175	3	1D
0005433680682	29175	4	2A
0005433680552	29175	5	2C
0005433680827	29175	6	2D
0005432967227	29175	7	2F
0005433680850	29175	8	3A
0005433680766	29175	9	3C
0005433680611	29175	10	3F
0005433687717	29175	11	4A
0005432005244	29175	12	4D
0005432967230	29175	13	4F
0005433680578	29175	14	5A
0005432967215	29175	15	5C
0005432967216	29175	16	5D
0005433680977	29175	17	5E
0005432967212	29175	18	5F
0005433680610	29175	19	6D
0005433680922	29175	20	6F
0005433680554	29175	21	7A
0005432967220	29175	22	7C
0005433680909	29175	23	7D
0005432967224	29175	24	7E
0005432967235	29175	25	8A
0005432967236	29175	26	8C
0005433687704	29175	27	8E
0005433680669	29175	28	8F
0005433680915	29175	29	9C
0005432967233	29175	30	9D
0005433687703	29175	31	9E
0005433680658	29175	32	10A
0005433680923	29175	33	10C
0005432967229	29175	34	10D
0005432005246	29175	35	10E
0005433680803	29175	36	10F
0005433680768	29175	37	11C
0005432967228	29175	38	11D
0005432967234	29175	39	11E
0005433680609	29175	40	11F
0005432967214	29175	41	12C
0005433680769	29175	42	12D
0005433680763	29175	43	12E
0005433684436	29175	44	13A
0005433680764	29175	45	13C
0005433684438	29175	46	13D
0005432967226	29175	47	13E
0005433680716	29175	48	14A
0005433680767	29175	49	14E
0005432967222	29175	50	14F
0005433680976	29175	51	15A
0005433680659	29175	52	15C
0005432967217	29175	53	15D
0005432967219	29175	54	15F
0005433680679	29175	55	16A
0005432967221	29175	56	16C
0005433680882	29175	57	16E
0005433680916	29175	58	16F
0005433680553	29175	59	17A
0005433680957	29175	60	17C
0005433680579	29175	61	17D
0005433680727	29175	62	17E
0005433684437	29175	63	18A
0005432967218	29175	64	18C
0005432967232	29175	65	18D
0005432967225	29175	66	18E
0005433680956	29175	67	19A
0005433687718	29175	68	19C
0005433680720	29175	69	19D
0005432967213	29175	70	19F
0005433680584	29175	71	20A
0005432967211	29175	72	20C
0005432967223	29175	73	20D
0005433680519	29175	74	20E
0005433680810	29175	75	20F
0005434163657	9274	1	1A
0005433615433	9274	2	1C
0005433615418	9274	3	1D
0005433615478	9274	4	1F
0005433577960	9274	5	2C
0005433634167	9274	6	2A
0005433615480	9274	7	2D
0005433615427	9274	8	3A
0005433615477	9274	9	2F
0005433615428	9274	10	3C
0005433615475	9274	11	3F
0005434163617	9274	12	3D
0005433615456	9274	13	4A
0005434163640	9274	14	4C
0005433634162	9274	15	5A
0005433615457	9274	16	4F
0005433615462	9274	17	5C
0005433577952	9274	18	5F
0005433634188	9274	19	5D
0005433615407	9274	20	6D
0005433634180	9274	21	6C
0005433615438	9274	22	6F
0005433634158	9274	23	7D
0005433577955	9274	24	8A
0005433634170	9274	25	8C
0005433615419	9274	26	8B
0005434152794	9274	27	8D
0005433634159	9274	28	8E
0005433615474	9274	29	9B
0005433634156	9274	30	9C
0005433634160	9274	31	9F
0005433615440	9274	32	10A
0005433615468	9274	33	10B
0005433615460	9274	34	10D
0005433634174	9274	35	10C
0005433615430	9274	36	10E
0005433634185	9274	37	11B
0005433615476	9274	38	11A
0005433577956	9274	39	11C
0005433577963	9274	40	11D
0005433615414	9274	41	11F
0005433634176	9274	42	12A
0005433615449	9274	43	12B
0005433615431	9274	44	12C
0005434163658	9274	45	12E
0005433577954	9274	46	12D
0005432756885	9274	47	12F
0005433615448	9274	48	13B
0005433634183	9274	49	13A
0005433634169	9274	50	13C
0005434152786	9274	51	13D
0005433615443	9274	52	13E
0005433615451	9274	53	14A
0005433634157	9274	54	13F
0005433615408	9274	55	14B
0005434163620	9274	56	14D
0005432755114	9274	57	14C
0005433615424	9274	58	14F
0005433577958	9274	59	15B
0005433577951	9274	60	15A
0005433615426	9274	61	15C
0005433615437	9274	62	15D
0005433634172	9274	63	15F
0005433615481	9274	64	15E
0005433615436	9274	65	16A
0005433615444	9274	66	16B
0005432755113	9274	67	16D
0005433634164	9274	68	16C
0005433634189	9274	69	16E
0005433615467	9274	70	17A
0005433615415	9274	71	16F
0005433615452	9274	72	17C
0005433634168	9274	73	17B
0005433615461	9274	74	17E
0005433577961	9274	75	17D
0005433634171	9274	76	17F
0005434163618	9274	77	18A
0005433615466	9274	78	18B
0005434152793	9274	79	18C
0005433615465	9274	80	18E
0005433634178	9274	81	18F
0005433634187	9274	82	19B
0005433615470	9274	83	19E
0005433634163	9274	84	19D
0005433615417	9274	85	19C
0005433615420	9274	86	20A
0005433615472	9274	87	20C
0005433634181	9274	88	20E
0005433634182	9274	89	20D
0005433577953	9274	90	20F
0005434163656	9274	91	21B
0005433615413	9274	92	21A
0005433634166	9274	93	21C
0005433615471	9274	94	21F
0005432756884	9274	95	21E
0005433634173	9274	96	22B
0005433615422	9274	97	22A
0005433615464	9274	98	22E
0005433615454	9274	99	22D
0005433615421	9274	100	22F
0005433615463	9274	101	23B
0005433634161	9274	102	23A
0005433577966	9274	103	23C
0005433615450	9274	104	23D
0005433577965	9274	105	23E
0005433634186	9274	106	24A
0005434163641	9274	107	23F
0005433615432	9274	108	24B
0005433615429	9274	109	24E
0005433615409	9274	110	25A
0005433615446	9274	111	25C
0005433615411	9274	112	25B
0005433615425	9274	113	25D
0005433577964	9274	114	25F
0005433615473	9274	115	25E
0005433615459	9274	116	26A
0005433615458	9274	117	26B
0005433615410	9274	118	26D
0005433634155	9274	119	26C
0005433615412	9274	120	26E
0005433577959	9274	121	26F
0005434269105	9274	122	27A
0005433634175	9274	123	27C
0005433615469	9274	124	27B
0005433615439	9274	125	27D
0005433615453	9274	126	27E
0005433615447	9274	127	28A
0005433634165	9274	128	27F
0005433615423	9274	129	28D
0005433615434	9274	130	28C
0005433615442	9274	131	28E
0005433577957	9274	132	29A
0005433615435	9274	133	28F
0005433615441	9274	134	29B
0005432756886	9274	135	29C
0005433634177	9274	136	29D
0005433577962	9274	137	29E
0005432756883	9274	138	30B
0005434152785	9274	139	30A
0005433615416	9274	140	30C
0005432755112	9274	141	30E
0005433634179	9274	142	30D
0005433615479	9274	143	30F
0005433615445	9274	144	31A
0005433634184	9274	145	31B
0005433615455	9274	146	31F
0005434163621	9274	147	31E
0005433634094	25241	1	1A
0005433614930	25241	2	1C
0005434163717	25241	3	1D
0005432751518	25241	4	2A
0005433577857	25241	5	1F
0005432751519	25241	6	2C
0005433633776	25241	7	2F
0005433633913	25241	8	2D
0005433614769	25241	9	3C
0005433633891	25241	10	3A
0005433614732	25241	11	3D
0005433614608	25241	12	4A
0005433615011	25241	13	3F
0005433614715	25241	14	4D
0005433614768	25241	15	4C
0005433633958	25241	16	4F
0005434152810	25241	17	5A
0005433615192	25241	18	5C
0005433614988	25241	19	5F
0005433633906	25241	20	5D
0005434152809	25241	21	6A
0005432751525	25241	22	6C
0005433577843	25241	23	6D
0005433614709	25241	24	7A
0005433614731	25241	25	6F
0005433577831	25241	26	7D
0005433633833	25241	27	7C
0005433614710	25241	28	7F
0005432755080	25241	29	8A
0005434163719	25241	30	8C
0005433633708	25241	31	8D
0005433614743	25241	32	9A
0005433577905	25241	33	8F
0005433633884	25241	34	9B
0005433615008	25241	35	9C
0005433614595	25241	36	9E
0005434163718	25241	37	9D
0005434163723	25241	38	9F
0005433614830	25241	39	10A
0005432755067	25241	40	10B
0005433633929	25241	41	10D
0005433614891	25241	42	10C
0005433614936	25241	43	10E
0005433577812	25241	44	11A
0005433614822	25241	45	10F
0005434163721	25241	46	11B
0005433577815	25241	47	11E
0005433633707	25241	48	11D
0005433614900	25241	49	11F
0005433577877	25241	50	12A
0005433633982	25241	51	12C
0005433614794	25241	52	12D
0005433614823	25241	53	12F
0005433614839	25241	54	12E
0005433614906	25241	55	13B
0005432751533	25241	56	13A
0005432755054	25241	57	13C
0005432755066	25241	58	13D
0005432755068	25241	59	13F
0005432751537	25241	60	13E
0005433615094	25241	61	14A
0005433634050	25241	62	14B
0005433633682	25241	63	14D
0005433614973	25241	64	14C
0005434152811	25241	65	14E
0005433614887	25241	66	15B
0005433614886	25241	67	15A
0005433614659	25241	68	15C
0005433614741	25241	69	15D
0005433614921	25241	70	15F
0005433614607	25241	71	15E
0005433633856	25241	72	16B
0005433633907	25241	73	16D
0005433614932	25241	74	16C
0005433577845	25241	75	16E
0005433633837	25241	76	17A
0005433614727	25241	77	16F
0005433614980	25241	78	17C
0005433614812	25241	79	17D
0005433614758	25241	80	17F
0005432755051	25241	81	17E
0005434152805	25241	82	18A
0005433614814	25241	83	18B
0005433614840	25241	84	18C
0005432755059	25241	85	18E
0005434152812	25241	86	19B
0005432751498	25241	87	18F
0005432751523	25241	88	19C
0005433614841	25241	89	19D
0005433577837	25241	90	19E
0005433614720	25241	91	20B
0005433633887	25241	92	20A
0005433614750	25241	93	20C
0005434152806	25241	94	20D
0005433614759	25241	95	20F
0005433633853	25241	96	21A
0005433614726	25241	97	21B
0005432751524	25241	98	21D
0005433633890	25241	99	21C
0005433615084	25241	100	21E
0005432755071	25241	101	22A
0005433614908	25241	102	21F
0005432755086	25241	103	22B
0005433614765	25241	104	22D
0005433633753	25241	105	22C
0005434163724	25241	106	22E
0005433614755	25241	107	22F
0005434163720	25241	108	23B
0005433633966	25241	109	23A
0005433614852	25241	110	23C
0005433634001	25241	111	23D
0005433614853	25241	112	23E
0005433614724	25241	113	24A
0005433577844	25241	114	24B
0005433577841	25241	115	24C
0005434152808	25241	116	24D
0005434163716	25241	117	24F
0005434152807	25241	118	25B
0005433614815	25241	119	25A
0005433633886	25241	120	25C
0005433614716	25241	121	25D
0005433633752	25241	122	25E
0005433614742	25241	123	26A
0005433633772	25241	124	25F
0005433614777	25241	125	26B
0005433577842	25241	126	26C
0005434152803	25241	127	26E
0005433614899	25241	128	26D
0005433577860	25241	129	26F
0005433577861	25241	130	27A
0005433614837	25241	131	27C
0005433634033	25241	132	27B
0005433577804	25241	133	27D
0005434163722	25241	134	27E
0005433633852	25241	135	28A
0005433614639	25241	136	27F
0005433614793	25241	137	28B
0005434152813	25241	138	28C
0005433577890	25241	139	28D
0005433577866	25241	140	29A
0005433615193	25241	141	28F
0005433577805	25241	142	28E
0005433633963	25241	143	29C
0005433614444	25241	144	29B
0005433614540	25241	145	29E
0005432755056	25241	146	29D
0005433614721	25241	147	29F
0005434152804	25241	148	30B
0005433577832	25241	149	30A
0005432751516	25241	150	30C
0005433577862	25241	151	30D
0005434163715	25241	152	31A
0005433614625	25241	153	30F
0005433614838	25241	154	31C
0005432751527	25241	155	31B
0005433614824	25241	156	31D
0005433615026	25241	157	31E
0005432755060	25241	158	31F
0005432571337	4200	1	1F
0005435947309	4200	2	2A
0005435947293	4200	3	2C
0005434271318	4200	4	2H
0005435947307	4200	5	3B
0005432184983	4200	6	4H
0005435947310	4200	7	5H
0005435947314	4200	8	9H
0005435947285	4200	9	11H
0005435986841	4200	10	14G
0005435986838	4200	11	14H
0005435986844	4200	12	15H
0005435856212	4200	13	17B
0005435947306	4200	14	17H
0005434271309	4200	15	18B
0005435986835	4200	16	18D
0005435986837	4200	17	18E
0005435947242	4200	18	18H
0005432571325	4200	19	20A
0005435947261	4200	20	20E
0005435986836	4200	21	20F
0005434271316	4200	22	23A
0005435947316	4200	23	23G
0005435947337	4200	24	27D
0005435947317	4200	25	28F
0005432184984	4200	26	28G
0005435856210	4200	27	30A
0005435856197	4200	28	30F
0005435947311	4200	29	31H
0005432184982	4200	30	32F
0005435947294	4200	31	32G
0005435856213	4200	32	33H
0005435986839	4200	33	34A
0005435947328	4200	34	34G
0005435986842	4200	35	34F
0005435947313	4200	36	35A
0005435986843	4200	37	36E
0005435947243	4200	38	36F
0005435856211	4200	39	37E
0005435947327	4200	40	38B
0005435947241	4200	41	38E
0005432571326	4200	42	39D
0005435986840	4200	43	39F
0005435856253	26561	1	2B
0005435986791	26561	2	4B
0005435856254	26561	3	4C
0005435947417	26561	4	4H
0005435947426	26561	5	5H
0005432571366	26561	6	11H
0005435947415	26561	7	12H
0005435986783	26561	8	13B
0005435856250	26561	9	14B
0005435947416	26561	10	14E
0005435986782	26561	11	16H
0005435947423	26561	12	16G
0005435947428	26561	13	17A
0005435947420	26561	14	18D
0005435856252	26561	15	18H
0005435947418	26561	16	19A
0005435986776	26561	17	20E
0005435947421	26561	18	20G
0005435986784	26561	19	21A
0005435986777	26561	20	21B
0005435947422	26561	21	22D
0005435947414	26561	22	22G
0005435947419	26561	23	24E
0005435947427	26561	24	27D
0005435947425	26561	25	30F
0005435787380	26561	26	31E
0005435986785	26561	27	32H
0005432571368	26561	28	35B
0005435787381	26561	29	35H
0005435947424	26561	30	36D
0005432571367	26561	31	37H
0005435856251	26561	32	39D
0005433134118	313	1	1A
0005432948524	313	2	1D
0005433569734	313	3	1C
0005432948484	313	4	1F
0005433134140	313	5	2A
0005433074796	313	6	2C
0005433074675	313	7	2F
0005432948616	313	8	3A
0005433074797	313	9	3D
0005433134117	313	10	3C
0005432948419	313	11	3F
0005433569740	313	12	4A
0005433074762	313	13	4C
0005432948564	313	14	4F
0005432239006	313	15	4D
0005433569759	313	16	5A
0005433074767	313	17	5C
0005433569764	313	18	5D
0005433569741	313	19	6A
0005433569729	313	20	5F
0005433569727	313	21	6C
0005433569723	313	22	6F
0005432239005	313	23	6D
0005433569725	313	24	7A
0005433129294	313	25	7D
0005433569738	313	26	7C
0005433569745	313	27	8A
0005432948536	313	28	8B
0005432948559	313	29	8D
0005433074788	313	30	8C
0005433569730	313	31	8E
0005432948400	313	32	8F
0005433074772	313	33	9B
0005432948575	313	34	9A
0005433074784	313	35	9C
0005432948480	313	36	9E
0005433569722	313	37	9D
0005433074790	313	38	9F
0005433569736	313	39	10A
0005433074787	313	40	10B
0005432948618	313	41	10D
0005433074662	313	42	10C
0005432948649	313	43	10E
0005433569753	313	44	10F
0005433569717	313	45	11A
0005433569732	313	46	11C
0005432948418	313	47	11B
0005433569744	313	48	11E
0005433569755	313	49	11D
0005433074726	313	50	12A
0005433074830	313	51	11F
0005432948322	313	52	12B
0005433569751	313	53	12C
0005433074768	313	54	12E
0005433569713	313	55	12D
0005433134145	313	56	12F
0005432239008	313	57	13B
0005433134146	313	58	13A
0005433074763	313	59	13D
0005433074842	313	60	13C
0005433074843	313	61	13F
0005433569746	313	62	14A
0005433074805	313	63	14B
0005433074827	313	64	14C
0005432948655	313	65	14E
0005433074711	313	66	14D
0005433569735	313	67	14F
0005433074859	313	68	15A
0005432948664	313	69	15C
0005432239004	313	70	15B
0005433074789	313	71	15E
0005433569757	313	72	15D
0005432239003	313	73	15F
0005433129293	313	74	16A
0005433569742	313	75	16B
0005433074791	313	76	16D
0005433569720	313	77	16C
0005433569752	313	78	16E
0005433569710	313	79	16F
0005433074880	313	80	17B
0005433569762	313	81	17A
0005432239007	313	82	17C
0005433569750	313	83	17D
0005432948264	313	84	17F
0005433569763	313	85	17E
0005432948574	313	86	18A
0005433074858	313	87	18B
0005433074674	313	88	18D
0005433569712	313	89	18C
0005433569733	313	90	18E
0005432948408	313	91	19B
0005432948446	313	92	18F
0005433074773	313	93	19C
0005433569739	313	94	19D
0005433569747	313	95	19E
0005433569716	313	96	20B
0005432948582	313	97	20C
0005433569711	313	98	20D
0005433569714	313	99	20F
0005433569715	313	100	21A
0005433129297	313	101	21C
0005432948483	313	102	21B
0005433074792	313	103	21D
0005433569718	313	104	21F
0005433569728	313	105	21E
0005433569731	313	106	22A
0005432948684	313	107	22C
0005433074688	313	108	22D
0005433569749	313	109	22E
0005433569748	313	110	23A
0005432948409	313	111	23C
0005432948648	313	112	23D
0005432948394	313	113	23E
0005433129298	313	114	24B
0005433074783	313	115	24A
0005433569760	313	116	24D
0005433569724	313	117	24C
0005433569707	313	118	24F
0005432948312	313	119	24E
0005432948321	313	120	25A
0005433569737	313	121	25C
0005433074712	313	122	25B
0005433569743	313	123	25D
0005432948576	313	124	25F
0005433074782	313	125	25E
0005432948449	313	126	26A
0005432948265	313	127	26B
0005433074854	313	128	26C
0005433074725	313	129	26E
0005433569766	313	130	26D
0005432948596	313	131	26F
0005433074844	313	132	27A
0005432948565	313	133	27C
0005432948558	313	134	27B
0005433569761	313	135	27F
0005433074828	313	136	27E
0005433569721	313	137	28A
0005433074850	313	138	28B
0005433569758	313	139	28D
0005432948617	313	140	28C
0005432948410	313	141	28E
0005432948563	313	142	28F
0005433569719	313	143	29B
0005433074713	313	144	29A
0005432948654	313	145	29C
0005432948451	313	146	29D
0005433074663	313	147	29F
0005433569765	313	148	29E
0005433569726	313	149	30B
0005432948395	313	150	30A
0005433569708	313	151	30D
0005433569709	313	152	30C
0005433569754	313	153	30E
0005433129292	313	154	30F
0005433569756	313	155	31B
0005432948393	313	156	31A
0005432948450	313	157	31C
0005432948581	313	158	31D
0005433074798	313	159	31F
0005433074837	313	160	31E
0005433075021	11575	1	1C
0005432948929	11575	2	1A
0005433569298	11575	3	1D
0005433569065	11575	4	2A
0005433569008	11575	5	1F
0005432948897	11575	6	2F
0005433569096	11575	7	2D
0005432948915	11575	8	3C
0005433569198	11575	9	3A
0005433131760	11575	10	3D
0005433075018	11575	11	4A
0005433075033	11575	12	4C
0005432948921	11575	13	4F
0005432948908	11575	14	4D
0005432948905	11575	15	5A
0005433569011	11575	16	5D
0005433569201	11575	17	5C
0005432948916	11575	18	6A
0005432948913	11575	19	5F
0005432948912	11575	20	6D
0005432948891	11575	21	7A
0005433568977	11575	22	7D
0005433075020	11575	23	7C
0005433075016	11575	24	8A
0005433075042	11575	25	8B
0005432192357	11575	26	8C
0005432948900	11575	27	8E
0005433075024	11575	28	8F
0005433569241	11575	29	9C
0005432948926	11575	30	9B
0005433075028	11575	31	9D
0005433131761	11575	32	9E
0005433134188	11575	33	10A
0005433569007	11575	34	9F
0005433075023	11575	35	10C
0005433569152	11575	36	10B
0005433075017	11575	37	10D
0005433569023	11575	38	10E
0005433569277	11575	39	10F
0005433569012	11575	40	11B
0005433134190	11575	41	11A
0005433075041	11575	42	11D
0005433075043	11575	43	11C
0005432948918	11575	44	11F
0005433569175	11575	45	11E
0005432948919	11575	46	12A
0005433569076	11575	47	12B
0005433568776	11575	48	12E
0005433568916	11575	49	12D
0005433134191	11575	50	12F
0005432948914	11575	51	13B
0005432948895	11575	52	13C
0005433075031	11575	53	13E
0005433569276	11575	54	13D
0005433569115	11575	55	14A
0005433075029	11575	56	14C
0005433569157	11575	57	14B
0005432192356	11575	58	14D
0005433075015	11575	59	15A
0005432948909	11575	60	14F
0005433075022	11575	61	14E
0005433568976	11575	62	15B
0005433569206	11575	63	15D
0005432192355	11575	64	15F
0005433568872	11575	65	16A
0005433569207	11575	66	16B
0005432948923	11575	67	16D
0005433075030	11575	68	16E
0005433569134	11575	69	17B
0005432948910	11575	70	17A
0005433075037	11575	71	17C
0005433569135	11575	72	17D
0005433134189	11575	73	17F
0005433569147	11575	74	17E
0005432948902	11575	75	18A
0005433075025	11575	76	18C
0005433569149	11575	77	18B
0005433569061	11575	78	18D
0005433569116	11575	79	18F
0005432948892	11575	80	19C
0005433569224	11575	81	19B
0005433075014	11575	82	19D
0005432948917	11575	83	19E
0005432948924	11575	84	20B
0005433569174	11575	85	20A
0005433568857	11575	86	20D
0005433568950	11575	87	20C
0005432948920	11575	88	20F
0005433568961	11575	89	20E
0005432948930	11575	90	21A
0005432948928	11575	91	21C
0005432948911	11575	92	21B
0005433569143	11575	93	21D
0005433568856	11575	94	21E
0005433568963	11575	95	22A
0005433569205	11575	96	21F
0005433131758	11575	97	22B
0005433568775	11575	98	22C
0005433075026	11575	99	22E
0005433075040	11575	100	22D
0005433569089	11575	101	22F
0005432948903	11575	102	23A
0005433568962	11575	103	23B
0005433568931	11575	104	23D
0005433131759	11575	105	23C
0005433075032	11575	106	23E
0005433075034	11575	107	23F
0005433569066	11575	108	24B
0005433075039	11575	109	24C
0005432948898	11575	110	24E
0005433569156	11575	111	24D
0005433569075	11575	112	24F
0005433075035	11575	113	25C
0005433568978	11575	114	25B
0005432948904	11575	115	25D
0005433569057	11575	116	25E
0005432948907	11575	117	25F
0005432948901	11575	118	26C
0005433075019	11575	119	26B
0005433075027	11575	120	26D
0005432948906	11575	121	26F
0005433075036	11575	122	27B
0005433569039	11575	123	27D
0005433569225	11575	124	27C
0005433075013	11575	125	27F
0005433569167	11575	126	28B
0005433569158	11575	127	28C
0005432948894	11575	128	28E
0005433569208	11575	129	28D
0005433569238	11575	130	29C
0005432948896	11575	131	29B
0005432948925	11575	132	29D
0005433569142	11575	133	29F
0005432948927	11575	134	29E
0005432948922	11575	135	30A
0005432948899	11575	136	30B
0005433569063	11575	137	30C
0005433568932	11575	138	30E
0005433569223	11575	139	30D
0005432948893	11575	140	31A
0005433569307	11575	141	31B
0005433569090	11575	142	31C
0005433569170	11575	143	31D
0005433075038	11575	144	31F
0005433817514	10058	1	2A
0005433817513	10058	2	1B
0005434732990	10058	3	2B
0005434732977	10058	4	4B
0005433817476	13941	1	1A
0005434733021	13941	2	1B
0005434733020	13941	3	2A
0005433817479	13941	4	2B
0005433817477	13941	5	3B
0005434733022	13941	6	3A
0005433817491	13941	7	4A
0005433817480	13941	8	4B
0005434733019	13941	9	5A
0005433817490	13941	10	5B
0005433817481	13941	11	6A
0005433817475	13941	12	6B
0005432985134	2325	1	1A
0005432300328	2325	2	1B
0005432985289	2325	3	1F
0005433754839	2325	4	1C
0005432985173	2325	5	1G
0005435982825	2325	6	2A
0005433434713	2325	7	1H
0005433434783	2325	8	2B
0005432985119	2325	9	2F
0005432985039	2325	10	2C
0005435982838	2325	11	2G
0005432655675	2325	12	3A
0005434731179	2325	13	2H
0005432985315	2325	14	3B
0005432985231	2325	15	3C
0005433754849	2325	16	3G
0005432985189	2325	17	3F
0005432226125	2325	18	4A
0005432655672	2325	19	3H
0005433434672	2325	20	4B
0005433434760	2325	21	4F
0005432300332	2325	22	4C
0005433434759	2325	23	4G
0005433754848	2325	24	5B
0005432985103	2325	25	5A
0005433434767	2325	26	5F
0005435982816	2325	27	5C
0005432869529	2325	28	5G
0005433754870	2325	29	5H
0005433434721	2325	30	9B
0005435982835	2325	31	9A
0005435982832	2325	32	9G
0005433434752	2325	33	11A
0005433754869	2325	34	9H
0005433434680	2325	35	11B
0005433754866	2325	36	11D
0005435982813	2325	37	11F
0005433766681	2325	38	11E
0005435982818	2325	39	11H
0005433754851	2325	40	11G
0005432985137	2325	41	12B
0005433754884	2325	42	12A
0005433434743	2325	43	12E
0005432985172	2325	44	12D
0005433754889	2325	45	12F
0005432985265	2325	46	12H
0005432985007	2325	47	12G
0005433754878	2325	48	13B
0005432869513	2325	49	13A
0005432226131	2325	50	13D
0005433434731	2325	51	13E
0005433754844	2325	52	13G
0005432985038	2325	53	13F
0005433754888	2325	54	14A
0005433434658	2325	55	13H
0005433754868	2325	56	14B
0005432655674	2325	57	14D
0005433754883	2325	58	14F
0005433754885	2325	59	14E
0005433434753	2325	60	14G
0005433754879	2325	61	14H
0005432655677	2325	62	15D
0005433754840	2325	63	15B
0005435982839	2325	64	15A
0005434731180	2325	65	15E
0005433754886	2325	66	15G
0005435982836	2325	67	15F
0005433434681	2325	68	16B
0005433754873	2325	69	16A
0005433754847	2325	70	16D
0005432985258	2325	71	16E
0005432300330	2325	72	16G
0005435982814	2325	73	16F
0005433766682	2325	74	16H
0005433754836	2325	75	17B
0005432985322	2325	76	17A
0005432985136	2325	77	17D
0005435982823	2325	78	17E
0005433754837	2325	79	17G
0005435982831	2325	80	17F
0005435982828	2325	81	18A
0005432226127	2325	82	18D
0005432985076	2325	83	18B
0005432985251	2325	84	18F
0005432985033	2325	85	18E
0005433754857	2325	86	18G
0005432655670	2325	87	18H
0005433754874	2325	88	19D
0005432985283	2325	89	19B
0005435982837	2325	90	19A
0005432985148	2325	91	19E
0005432226130	2325	92	19H
0005432985316	2325	93	19G
0005433434638	2325	94	20A
0005433434809	2325	95	20D
0005435982822	2325	96	20B
0005435982820	2325	97	20E
0005433754887	2325	98	20G
0005433754834	2325	99	20F
0005433754875	2325	100	20H
0005432300331	2325	101	21A
0005433754871	2325	102	21E
0005433754859	2325	103	21D
0005433754860	2325	104	21F
0005433434637	2325	105	21H
0005432985195	2325	106	21G
0005435982815	2325	107	22B
0005435982827	2325	108	22A
0005433754865	2325	109	22D
0005432655669	2325	110	22E
0005432655673	2325	111	22G
0005435982812	2325	112	22F
0005433754853	2325	113	22H
0005432985198	2325	114	23B
0005432985232	2325	115	23A
0005432985170	2325	116	23E
0005435982824	2325	117	23D
0005432226128	2325	118	23F
0005432985097	2325	119	23G
0005432655668	2325	120	23H
0005433434763	2325	121	24B
0005432655678	2325	122	24A
0005432985193	2325	123	24E
0005432985264	2325	124	24D
0005433434663	2325	125	24F
0005433754843	2325	126	24H
0005433766683	2325	127	24G
0005433754841	2325	128	25D
0005433754876	2325	129	25E
0005433754880	2325	130	27A
0005435982834	2325	131	27B
0005432655676	2325	132	27D
0005432869545	2325	133	27F
0005433434671	2325	134	27E
0005432985174	2325	135	27H
0005433434682	2325	136	27G
0005433434765	2325	137	28A
0005433754862	2325	138	28B
0005432985317	2325	139	28E
0005433434826	2325	140	28D
0005433434732	2325	141	28H
0005433434709	2325	142	28G
0005435982841	2325	143	29B
0005433754835	2325	144	29E
0005435982842	2325	145	29D
0005435982843	2325	146	29F
0005432869528	2325	147	29H
0005433766684	2325	148	29G
0005432985259	2325	149	30B
0005433754858	2325	150	30A
0005432985180	2325	151	30E
0005433754852	2325	152	30D
0005433754854	2325	153	30G
0005433754861	2325	154	30F
0005435982819	2325	155	30H
0005433754842	2325	156	31B
0005432655671	2325	157	31A
0005432300329	2325	158	31E
0005432985080	2325	159	31D
0005432985124	2325	160	31H
0005435982821	2325	161	31G
0005433434717	2325	162	32A
0005433434616	2325	163	32B
0005432985249	2325	164	32E
0005432655679	2325	165	32D
0005433754863	2325	166	32F
0005432985120	2325	167	32G
0005434731169	2325	168	33A
0005432226129	2325	169	33B
0005432985075	2325	170	33E
0005435982833	2325	171	33D
0005433754867	2325	172	33G
0005433754882	2325	173	33H
0005435982826	2325	174	34B
0005433754890	2325	175	34A
0005433434700	2325	176	34D
0005432869503	2325	177	34E
0005433434722	2325	178	34G
0005432985252	2325	179	34F
0005433754872	2325	180	34H
0005432985221	2325	181	35B
0005432985146	2325	182	35A
0005433754877	2325	183	35E
0005432985032	2325	184	35D
0005433766685	2325	185	35G
0005432985194	2325	186	35F
0005433754838	2325	187	36A
0005433434766	2325	188	35H
0005432985168	2325	189	36B
0005433754845	2325	190	36D
0005433754846	2325	191	36F
0005432985147	2325	192	36E
0005435982830	2325	193	36G
0005433754864	2325	194	37A
0005433434827	2325	195	36H
0005432985190	2325	196	37B
0005433754881	2325	197	37D
0005433754856	2325	198	37F
0005435982829	2325	199	37E
0005433434716	2325	200	37G
0005432226126	2325	201	38A
0005433434730	2325	202	37H
0005435982840	2325	203	38D
0005435982817	2325	204	38B
0005433754850	2325	205	38E
0005432869546	2325	206	38G
0005433764703	2325	207	38F
0005433434790	2325	208	38H
0005432300327	2325	209	39D
0005433754855	2325	210	39F
0005432985323	2325	211	39E
0005433434987	26194	1	1A
0005433754357	26194	2	1B
0005435982223	26194	3	1F
0005435982515	26194	4	1C
0005432869599	26194	5	1G
0005433754282	26194	6	1H
0005432985447	26194	7	2B
0005435982358	26194	8	2C
0005433754360	26194	9	2G
0005434731218	26194	10	3A
0005432985462	26194	11	2H
0005433434988	26194	12	3B
0005433754455	26194	13	3F
0005433754482	26194	14	3C
0005432985430	26194	15	3G
0005435982346	26194	16	3H
0005432985449	26194	17	4A
0005435982088	26194	18	4C
0005432985437	26194	19	4G
0005435982407	26194	20	4F
0005432655535	26194	21	4H
0005433754212	26194	22	5B
0005435982426	26194	23	5A
0005435982393	26194	24	5C
0005433434986	26194	25	5F
0005433754464	26194	26	5H
0005432985454	26194	27	9B
0005433754295	26194	28	11A
0005435982149	26194	29	9H
0005432985434	26194	30	11D
0005435982416	26194	31	11B
0005433754317	26194	32	11E
0005435982381	26194	33	11F
0005433434990	26194	34	11H
0005432051163	26194	35	11G
0005433435006	26194	36	12A
0005433435001	26194	37	12B
0005432051162	26194	38	12E
0005432655523	26194	39	12D
0005435982628	26194	40	12G
0005433753972	26194	41	12F
0005435982377	26194	42	12H
0005432869598	26194	43	13A
0005433754465	26194	44	13D
0005432985451	26194	45	13B
0005432869595	26194	46	13E
0005435982384	26194	47	13G
0005433754475	26194	48	13F
0005433434997	26194	49	13H
0005432985450	26194	50	14B
0005433754461	26194	51	14A
0005433434995	26194	52	14E
0005432985429	26194	53	14D
0005433754595	26194	54	14F
0005435982528	26194	55	14G
0005432985438	26194	56	15A
0005433435014	26194	57	14H
0005433435009	26194	58	15D
0005434731221	26194	59	15B
0005433754231	26194	60	15E
0005433753991	26194	61	15F
0005435982278	26194	62	15H
0005432051164	26194	63	15G
0005435982087	26194	64	16B
0005433754416	26194	65	16D
0005435982357	26194	66	16E
0005432655526	26194	67	16G
0005435982383	26194	68	16H
0005434731219	26194	69	17B
0005433435011	26194	70	17A
0005435982378	26194	71	17D
0005435982379	26194	72	17G
0005433754236	26194	73	17F
0005433754332	26194	74	18A
0005432655569	26194	75	17H
0005432985461	26194	76	18B
0005433754163	26194	77	18D
0005432985460	26194	78	18F
0005432985446	26194	79	18E
0005433754447	26194	80	18G
0005432985436	26194	81	19A
0005433754356	26194	82	19B
0005435982359	26194	83	19D
0005432985440	26194	84	19F
0005433754515	26194	85	19E
0005435982482	26194	86	19G
0005432869596	26194	87	20A
0005435982586	26194	88	19H
0005432655558	26194	89	20B
0005432655559	26194	90	20E
0005433754510	26194	91	20D
0005433754170	26194	92	20H
0005435982526	26194	93	20G
0005435982470	26194	94	21A
0005434731220	26194	95	21D
0005433754353	26194	96	21B
0005432655557	26194	97	21E
0005433754336	26194	98	21F
0005433754355	26194	99	21H
0005435982411	26194	100	21G
0005433754381	26194	101	22A
0005432985442	26194	102	22E
0005433754380	26194	103	22D
0005435982279	26194	104	22B
0005432985433	26194	105	22F
0005433434998	26194	106	22H
0005433435000	26194	107	22G
0005435982089	26194	108	23B
0005432985435	26194	109	23A
0005433764686	26194	110	23D
0005433754379	26194	111	23E
0005435982410	26194	112	23G
0005432985441	26194	113	23F
0005433435008	26194	114	24A
0005433434996	26194	115	23H
0005433754369	26194	116	24B
0005433754237	26194	117	24D
0005433754171	26194	118	24F
0005435982243	26194	119	24E
0005433434993	26194	120	24G
0005433754305	26194	121	25D
0005435982512	26194	122	24H
0005433766644	26194	123	25E
0005435982483	26194	124	27A
0005433754337	26194	125	25F
0005433754235	26194	126	27D
0005432049506	26194	127	27E
0005433754124	26194	128	27F
0005435982356	26194	129	27H
0005435982480	26194	130	28A
0005433435004	26194	131	28D
0005432869597	26194	132	28B
0005433434991	26194	133	28E
0005433435012	26194	134	28F
0005435982331	26194	135	28H
0005433434994	26194	136	28G
0005432985455	26194	137	29A
0005433435013	26194	138	29D
0005433754456	26194	139	29B
0005432985459	26194	140	29E
0005433766643	26194	141	29G
0005433754400	26194	142	29H
0005433754281	26194	143	30B
0005433754485	26194	144	30A
0005435982471	26194	145	30D
0005433435002	26194	146	30F
0005435982406	26194	147	30E
0005432985448	26194	148	30G
0005432985444	26194	149	31A
0005435982575	26194	150	30H
0005432869600	26194	151	31B
0005433434989	26194	152	31D
0005433435010	26194	153	31F
0005433754412	26194	154	31E
0005432985456	26194	155	31H
0005432985445	26194	156	31G
0005432869594	26194	157	32A
0005432985443	26194	158	32D
0005432985458	26194	159	32B
0005432655538	26194	160	32F
0005433754830	26194	161	32H
0005432049505	26194	162	32G
0005435982321	26194	163	33A
0005435982242	26194	164	33D
0005433754483	26194	165	33E
0005435982418	26194	166	33G
0005432985439	26194	167	33F
0005432655546	26194	168	33H
0005432655534	26194	169	34B
0005433435003	26194	170	34A
0005433754495	26194	171	34D
0005433754420	26194	172	34F
0005432655537	26194	173	34G
0005433434999	26194	174	35A
0005433754230	26194	175	34H
0005433435005	26194	176	35B
0005433754628	26194	177	35E
0005433754303	26194	178	35H
0005433754234	26194	179	35G
0005432655536	26194	180	35F
0005432985431	26194	181	36B
0005433754213	26194	182	36E
0005435982472	26194	183	36D
0005432985432	26194	184	36F
0005432985453	26194	185	36G
0005432985452	26194	186	37A
0005433434992	26194	187	36H
0005432655556	26194	188	37B
0005432985457	26194	189	37E
0005432655570	26194	190	37D
0005433435007	26194	191	37F
0005433754539	26194	192	37H
0005433754359	26194	193	37G
0005433754187	26194	194	38A
0005435982376	26194	195	38E
0005433753973	26194	196	38D
0005433754358	26194	197	38H
0005433764687	26194	198	39E
0005433151527	1531	1	1A
0005433151359	1531	2	1C
0005434375181	1531	3	1D
0005434375157	1531	4	2A
0005434375162	1531	5	1F
0005433151407	1531	6	2D
0005434375182	1531	7	2F
0005433931473	1531	8	3C
0005434029660	1531	9	3A
0005432267970	1531	10	3D
0005434375171	1531	11	3F
0005434375167	1531	12	4B
0005434375177	1531	13	4E
0005433151473	1531	14	5A
0005434375158	1531	15	5C
0005433151404	1531	16	5B
0005433151602	1531	17	5E
0005434375175	1531	18	6A
0005433151499	1531	19	6B
0005433151621	1531	20	6C
0005434375184	1531	21	6D
0005433151388	1531	22	6F
0005434375185	1531	23	6E
0005433151424	1531	24	7A
0005434375174	1531	25	7B
0005433151450	1531	26	7E
0005433151428	1531	27	7D
0005434375159	1531	28	8A
0005433151493	1531	29	7F
0005433151422	1531	30	8B
0005434375150	1531	31	8D
0005433151425	1531	32	8C
0005433151659	1531	33	8E
0005434375160	1531	34	9A
0005434375151	1531	35	9B
0005432267973	1531	36	9D
0005433151375	1531	37	9C
0005434375154	1531	38	9F
0005433151461	1531	39	10C
0005434375152	1531	40	10D
0005433151462	1531	41	11A
0005433151661	1531	42	11B
0005433151622	1531	43	11C
0005433151563	1531	44	11D
0005433931472	1531	45	11F
0005434375188	1531	46	12A
0005434375168	1531	47	12B
0005433151483	1531	48	12D
0005433151532	1531	49	12C
0005433151534	1531	50	12E
0005434375170	1531	51	12F
0005433151561	1531	52	13B
0005433151508	1531	53	13A
0005434375187	1531	54	13C
0005434375183	1531	55	13E
0005433151511	1531	56	14A
0005434375164	1531	57	14C
0005433764689	1531	58	14B
0005433151658	1531	59	14D
0005432267968	1531	60	14F
0005433151474	1531	61	15A
0005434375161	1531	62	15B
0005433461612	1531	63	15E
0005433151479	1531	64	15D
0005433151579	1531	65	15F
0005432267972	1531	66	16B
0005433151547	1531	67	16D
0005433460460	1531	68	16C
0005433151423	1531	69	16E
0005433151526	1531	70	17A
0005433151506	1531	71	16F
0005434375163	1531	72	17B
0005434375153	1531	73	17C
0005433931474	1531	74	17D
0005433151668	1531	75	17E
0005434375156	1531	76	18A
0005433151484	1531	77	18B
0005432267974	1531	78	18C
0005434375176	1531	79	18D
0005434375186	1531	80	18E
0005434375173	1531	81	18F
0005433151387	1531	82	19C
0005434375178	1531	83	19B
0005433151562	1531	84	19D
0005434375165	1531	85	19E
0005433151564	1531	86	20A
0005433151451	1531	87	20B
0005433460461	1531	88	20D
0005433151475	1531	89	20C
0005433151774	1531	90	20E
0005433151476	1531	91	20F
0005433151595	1531	92	21A
0005433151463	1531	93	21C
0005433461613	1531	94	21B
0005433151405	1531	95	21D
0005433151433	1531	96	21E
0005432267971	1531	97	21F
0005433151740	1531	98	22C
0005434375166	1531	99	22B
0005434375172	1531	100	22D
0005433151452	1531	101	22E
0005433151469	1531	102	23A
0005434375180	1531	103	22F
0005434375169	1531	104	23B
0005433151741	1531	105	23D
0005432267969	1531	106	23C
0005434375179	1531	107	23E
0005434375155	1531	108	23F
0005433151800	20106	1	1F
0005433151793	20106	2	1D
0005433151804	20106	3	2A
0005434374864	20106	4	2C
0005434374738	20106	5	2D
0005433151797	20106	6	2F
0005433931501	20106	7	3A
0005434374582	20106	8	3D
0005433151787	20106	9	3C
0005434374519	20106	10	3F
0005433151786	20106	11	4E
0005433931503	20106	12	5A
0005434374821	20106	13	4F
0005434374689	20106	14	5C
0005433151783	20106	15	5B
0005434374472	20106	16	5E
0005434374800	20106	17	5F
0005433151791	20106	18	6B
0005433151779	20106	19	6A
0005433151809	20106	20	6C
0005434374870	20106	21	6E
0005434374590	20106	22	6D
0005433931502	20106	23	6F
0005433151782	20106	24	7A
0005433151789	20106	25	7B
0005434374663	20106	26	7D
0005434374764	20106	27	7F
0005433151808	20106	28	8A
0005434374865	20106	29	8B
0005434374668	20106	30	8E
0005433151812	20106	31	9A
0005434374561	20106	32	8F
0005434374711	20106	33	9B
0005433151788	20106	34	9D
0005434374665	20106	35	9F
0005434374684	20106	36	9E
0005434374863	20106	37	10C
0005434374688	20106	38	10B
0005433151795	20106	39	11A
0005433151799	20106	40	11B
0005434374794	20106	41	11C
0005434374749	20106	42	11E
0005434374810	20106	43	12A
0005432056340	20106	44	12C
0005432056341	20106	45	12B
0005433151781	20106	46	12D
0005433151778	20106	47	12E
0005434374733	20106	48	12F
0005433151796	20106	49	13C
0005433151802	20106	50	13D
0005434374829	20106	51	13E
0005434374823	20106	52	14A
0005433931504	20106	53	14C
0005434374852	20106	54	14B
0005433151784	20106	55	14D
0005434374853	20106	56	14E
0005434374601	20106	57	14F
0005433151780	20106	58	15B
0005433151785	20106	59	15A
0005434374866	20106	60	15C
0005434029686	20106	61	15D
0005433151807	20106	62	15F
0005433151803	20106	63	16A
0005433151811	20106	64	16B
0005433151801	20106	65	16C
0005433151790	20106	66	16E
0005434029685	20106	67	17A
0005433151805	20106	68	17B
0005434374793	20106	69	17C
0005434374741	20106	70	17F
0005434374871	20106	71	17E
0005434374868	20106	72	18A
0005433931500	20106	73	18B
0005434374851	20106	74	18D
0005434374693	20106	75	18E
0005434374669	20106	76	18F
0005434374615	20106	77	19A
0005434374518	20106	78	19B
0005434374681	20106	79	19C
0005433151792	20106	80	19D
0005434374874	20106	81	19F
0005434374710	20106	82	20A
0005433151810	20106	83	20B
0005434374716	20106	84	20D
0005434374880	20106	85	20C
0005434374740	20106	86	20E
0005434374517	20106	87	20F
0005434374686	20106	88	21B
0005433764703	20106	89	21A
0005433151798	20106	90	21C
0005433151806	20106	91	21D
0005434374859	20106	92	21E
0005434374732	20106	93	22A
0005434374739	20106	94	22B
0005433151794	20106	95	22C
0005434374867	20106	96	22D
0005434374827	20106	97	22F
0005434374666	20106	98	22E
0005434374674	20106	99	23B
0005434374715	20106	100	23D
0005432056342	20106	101	23F
0005432056343	20106	102	23E
0005432424982	545	1	1F
0005432424970	545	2	2C
0005432424984	545	3	2A
0005432424972	545	4	3A
0005432282946	545	5	3F
0005432425002	545	6	4A
0005432425005	545	7	4D
0005432424965	545	8	5C
0005432424988	545	9	6A
0005432424967	545	10	5F
0005432282943	545	11	6D
0005432424981	545	12	7C
0005432424986	545	13	7D
0005432424968	545	14	8B
0005432424995	545	15	8D
0005432424991	545	16	9B
0005432424963	545	17	10A
0005432424989	545	18	10D
0005432424974	545	19	11B
0005432425001	545	20	11A
0005432282945	545	21	12B
0005432425008	545	22	12E
0005432425004	545	23	13B
0005432424990	545	24	13D
0005432424971	545	25	15B
0005432424966	545	26	16C
0005432424994	545	27	16B
0005432282941	545	28	17F
0005432282942	545	29	18A
0005432424964	545	30	19B
0005432424997	545	31	20F
0005432424962	545	32	21A
0005432424987	545	33	21C
0005432425007	545	34	21E
0005432424999	545	35	22A
0005432424976	545	36	22C
0005432424979	545	37	23B
0005432424998	545	38	23D
0005432424973	545	39	23F
0005432424975	545	40	24A
0005432424977	545	41	24B
0005432424980	545	42	25B
0005432424985	545	43	25D
0005432424992	545	44	25E
0005432425006	545	45	27A
0005432424969	545	46	26F
0005432424996	545	47	28A
0005432282947	545	48	28F
0005432424983	545	49	30A
0005432282944	545	50	30C
0005432425003	545	51	30D
0005432424993	545	52	30E
0005432425000	545	53	31B
0005432424978	545	54	31E
0005433158154	12832	1	2F
0005433158157	12832	2	5D
0005432302375	12832	3	9C
0005434446516	12832	4	10C
0005434446529	12832	5	14B
0005432302374	12832	6	14D
0005433158155	12832	7	17F
0005434446530	12832	8	19C
0005433158152	12832	9	20B
0005433158153	12832	10	20E
0005434446525	12832	11	23A
0005434446520	12832	12	23E
0005434446526	12832	13	24D
0005433158156	12832	14	24E
0005434446518	12832	15	30E
0005432424536	12888	1	1F
0005432424567	12888	2	1D
0005432424476	12888	3	2A
0005432424555	12888	4	4A
0005432424498	12888	5	3F
0005432424457	12888	6	5C
0005432424566	12888	7	6C
0005432424528	12888	8	6F
0005432424468	12888	9	8C
0005432424489	12888	10	8B
0005432424542	12888	11	9A
0005432424514	12888	12	9B
0005432424439	12888	13	9D
0005432424486	12888	14	9F
0005432424569	12888	15	10C
0005432424543	12888	16	10B
0005432424363	12888	17	10E
0005432424480	12888	18	11A
0005432424568	12888	19	10F
0005432424449	12888	20	11C
0005432424197	12888	21	12E
0005432424466	12888	22	13F
0005432424512	12888	23	14C
0005432424504	12888	24	14F
0005432424523	12888	25	15C
0005432424527	12888	26	16B
0005432424529	12888	27	16E
0005432424442	12888	28	17D
0005432424485	12888	29	17F
0005432424441	12888	30	18C
0005432424499	12888	31	18E
0005432424570	12888	32	19D
0005432424492	12888	33	20C
0005432424493	12888	34	21B
0005432424430	12888	35	21D
0005432424541	12888	36	22C
0005432424362	12888	37	22F
0005432424544	12888	38	23F
0005432424482	12888	39	24B
0005432424488	12888	40	24E
0005432424495	12888	41	24D
0005432424386	12888	42	24F
0005432424444	12888	43	25E
0005432424552	12888	44	26B
0005432424520	12888	45	26C
0005432424475	12888	46	26E
0005432424450	12888	47	27B
0005432424443	12888	48	27C
0005432424423	12888	49	28B
0005432424496	12888	50	29A
0005432424494	12888	51	29C
0005432424534	12888	52	30E
0005432424458	12888	53	30D
0005434024500	470	1	1A
0005434735701	470	2	1B
0005434024504	470	3	1F
0005434024490	470	4	1G
0005432235721	470	5	1H
0005433058138	470	6	2B
0005433929623	470	7	2C
0005434024449	470	8	2H
0005434024465	470	9	2G
0005434024497	470	10	3B
0005433058112	470	11	3F
0005433057842	470	12	3G
0005434024476	470	13	4B
0005434028325	470	14	4F
0005433057903	470	15	4C
0005433058064	470	16	4H
0005434024495	470	17	5F
0005433058022	470	18	5H
0005433057955	470	19	9A
0005433058111	470	20	9H
0005433058031	470	21	11A
0005434735689	470	22	11F
0005434024445	470	23	11E
0005433929614	470	24	11H
0005434024477	470	25	12A
0005434024469	470	26	12D
0005434024479	470	27	12E
0005433058256	470	28	12F
0005434024505	470	29	12H
0005433058110	470	30	12G
0005434024475	470	31	13A
0005434024484	470	32	13E
0005434024448	470	33	13F
0005432235720	470	34	13H
0005433058036	470	35	13G
0005434024488	470	36	14B
0005433057843	470	37	14D
0005434024482	470	38	14F
0005434024462	470	39	14E
0005433058151	470	40	14G
0005434024466	470	41	15A
0005434024491	470	42	14H
0005433058038	470	43	15D
0005434024470	470	44	15B
0005433057956	470	45	15G
0005434024458	470	46	15F
0005434024511	470	47	15H
0005434024464	470	48	16B
0005434024480	470	49	16A
0005434024472	470	50	16G
0005433057985	470	51	16F
0005434024442	470	52	17A
0005434024457	470	53	17B
0005434024471	470	54	17E
0005433057950	470	55	17G
0005433058126	470	56	17F
0005433057825	470	57	18B
0005434024487	470	58	18A
0005433684430	470	59	18D
0005434024508	470	60	18F
0005434735683	470	61	19A
0005433057875	470	62	18H
0005434735697	470	63	19D
0005434024499	470	64	19B
0005433058106	470	65	19F
0005434024501	470	66	19E
0005434024447	470	67	19G
0005434024454	470	68	20A
0005434024473	470	69	19H
0005434024474	470	70	20D
0005434024494	470	71	20B
0005434024460	470	72	20F
0005434032071	470	73	20H
0005432235723	470	74	21F
0005434735699	470	75	22F
0005434028324	470	76	22H
0005432045634	470	77	23B
0005434024509	470	78	23A
0005434024455	470	79	23E
0005434024503	470	80	23G
0005433929615	470	81	23F
0005434024496	470	82	23H
0005434029684	470	83	24A
0005433058029	470	84	24D
0005434024489	470	85	24F
0005433058179	470	86	24H
0005434029683	470	87	25D
0005433057826	470	88	25E
0005434024510	470	89	25F
0005434024506	470	90	27B
0005432235726	470	91	27A
0005433058104	470	92	27E
0005433058191	470	93	27D
0005434024507	470	94	27G
0005434024502	470	95	28A
0005434024461	470	96	27H
0005434024478	470	97	28B
0005433684429	470	98	28E
0005434024493	470	99	28F
0005434735688	470	100	29A
0005433057827	470	101	28H
0005433057841	470	102	29D
0005434024456	470	103	29B
0005434024483	470	104	29E
0005434029682	470	105	29H
0005433684433	470	106	29G
0005434032073	470	107	30F
0005434024467	470	108	30E
0005434028327	470	109	31A
0005433058128	470	110	30H
0005433057929	470	111	31E
0005433929622	470	112	31D
0005434735700	470	113	31B
0005434024453	470	114	31F
0005433058257	470	115	31G
0005434024452	470	116	31H
0005434024444	470	117	32B
0005433058105	470	118	32E
0005433058113	470	119	32F
0005434024446	470	120	32H
0005433057937	470	121	32G
0005433057936	470	122	33A
0005434024486	470	123	33D
0005433058087	470	124	33B
0005434024512	470	125	33E
0005434735679	470	126	33H
0005434032070	470	127	33G
0005432235724	470	128	34D
0005434024492	470	129	34E
0005434032074	470	130	34G
0005434024459	470	131	34F
0005434024468	470	132	35A
0005433057894	470	133	35B
0005434028326	470	134	35D
0005434024463	470	135	35E
0005434024485	470	136	35G
0005434735676	470	137	36A
0005433929621	470	138	35H
0005433058035	470	139	36B
0005432235722	470	140	36F
0005434735677	470	141	36E
0005434024481	470	142	36H
0005434024451	470	143	36G
0005432045633	470	144	37F
0005434024450	470	145	37H
0005434032072	470	146	38D
0005434024443	470	147	38B
0005432235725	470	148	38E
0005433929620	470	149	38G
0005434024498	470	150	38F
0005433058150	470	151	39D
0005433058127	470	152	39F
0005434029660	12697	1	1F
0005433058359	12697	2	1C
0005434023858	12697	3	1G
0005434024131	12697	4	1H
0005434024126	12697	5	2B
0005433058342	12697	6	2C
0005433058324	12697	7	2G
0005434024158	12697	8	3B
0005434024130	12697	9	3A
0005433058345	12697	10	3F
0005434023891	12697	11	4A
0005433684445	12697	12	3H
0005434024146	12697	13	4F
0005434023548	12697	14	4C
0005434023588	12697	15	4G
0005433929660	12697	16	5B
0005433929658	12697	17	5C
0005433058358	12697	18	5G
0005434023905	12697	19	5F
0005433058340	12697	20	9B
0005434023969	12697	21	9A
0005434024103	12697	22	11A
0005433058323	12697	23	9H
0005434024053	12697	24	11D
0005434024161	12697	25	11E
0005434024205	12697	26	11F
0005434024077	12697	27	11G
0005434023970	12697	28	12B
0005434028299	12697	29	12F
0005433058320	12697	30	12H
0005434028307	12697	31	12G
0005433684444	12697	32	13F
0005434023711	12697	33	13E
0005434023761	12697	34	13G
0005433058331	12697	35	13H
0005434023826	12697	36	14B
0005433058339	12697	37	14A
0005433058321	12697	38	14E
0005433058355	12697	39	14D
0005434024011	12697	40	14F
0005433058328	12697	41	14G
0005434023978	12697	42	14H
0005434023971	12697	43	15D
0005433058346	12697	44	15E
0005434024127	12697	45	15F
0005434028298	12697	46	15H
0005434024159	12697	47	16D
0005434024030	12697	48	16E
0005434023838	12697	49	16H
0005433058334	12697	50	16G
0005433058326	12697	51	17B
0005434024052	12697	52	17A
0005434028314	12697	53	17E
0005433058343	12697	54	17G
0005434024111	12697	55	18D
0005434023797	12697	56	18B
0005434023896	12697	57	18E
0005433058332	12697	58	18G
0005434023737	12697	59	19B
0005433058337	12697	60	19A
0005432157514	12697	61	19E
0005434023925	12697	62	19D
0005434023620	12697	63	19F
0005434024110	12697	64	20A
0005434023736	12697	65	19H
0005434023879	12697	66	20D
0005434735749	12697	67	20B
0005434023839	12697	68	20E
0005433929661	12697	69	20F
0005434024010	12697	70	20H
0005434028283	12697	71	21A
0005434023958	12697	72	21D
0005432156416	12697	73	21B
0005434023829	12697	74	22D
0005434023878	12697	75	22B
0005433058351	12697	76	22H
0005433058344	12697	77	23B
0005434032015	12697	78	23E
0005433058330	12697	79	23G
0005433058349	12697	80	23F
0005433058357	12697	81	24A
0005434024081	12697	82	23H
0005433058354	12697	83	24G
0005433058319	12697	84	25D
0005433058353	12697	85	24H
0005434023589	12697	86	27A
0005434023856	12697	87	27B
0005433058350	12697	88	27F
0005433058356	12697	89	28A
0005434023968	12697	90	28D
0005433929659	12697	91	28E
0005434023892	12697	92	28G
0005434024109	12697	93	28H
0005432156417	12697	94	29A
0005434024033	12697	95	29B
0005434023816	12697	96	29E
0005434023806	12697	97	29F
0005433058338	12697	98	29H
0005433058336	12697	99	30D
0005434735748	12697	100	30F
0005434023926	12697	101	30E
0005434023972	12697	102	30H
0005434023959	12697	103	31B
0005434735750	12697	104	31A
0005433058325	12697	105	31D
0005433058348	12697	106	31G
0005434735751	12697	107	32H
0005434024106	12697	108	32G
0005434023836	12697	109	33D
0005433058335	12697	110	33G
0005434023913	12697	111	33F
0005433058347	12697	112	34D
0005433058360	12697	113	34F
0005434024107	12697	114	34E
0005434024162	12697	115	34H
0005434024029	12697	116	35B
0005433058333	12697	117	35D
0005434024075	12697	118	35E
0005433058341	12697	119	35F
0005433058329	12697	120	36A
0005434023721	12697	121	35H
0005434023683	12697	122	36B
0005434024206	12697	123	36E
0005434023837	12697	124	36D
0005434024105	12697	125	36F
0005434023549	12697	126	36H
0005434024160	12697	127	36G
0005433058352	12697	128	37B
0005433058322	12697	129	38B
0005433058327	12697	130	38D
0005434024214	12697	131	38F
0005434023995	12697	132	38E
0005434023967	12697	133	38G
0005432157513	12697	134	39F
0005433529310	13815	1	1F
0005433527304	13815	2	3A
0005433529316	13815	3	4C
0005433529306	13815	4	4A
0005433529311	13815	5	6C
0005433529304	13815	6	7A
0005433529313	13815	7	7C
0005433529317	13815	8	7B
0005433529314	13815	9	8E
0005433529318	13815	10	9C
0005433527308	13815	11	10E
0005433527299	13815	12	12A
0005433529308	13815	13	12D
0005433527302	13815	14	12C
0005433529305	13815	15	13A
0005433527297	13815	16	13F
0005433527298	13815	17	14E
0005433527301	13815	18	14F
0005433527293	13815	19	15B
0005433529309	13815	20	15D
0005433527300	13815	21	15C
0005433529315	13815	22	15E
0005433529307	13815	23	16C
0005433527309	13815	24	16B
0005433527307	13815	25	16D
0005433527294	13815	26	17A
0005433527296	13815	27	17D
0005433527306	13815	28	17C
0005433529312	13815	29	17E
0005433527295	13815	30	18A
0005433527305	13815	31	19C
0005433527303	13815	32	20A
0005433533303	32455	1	1C
0005433533318	32455	2	1A
0005433529281	32455	3	1D
0005433529250	32455	4	5F
0005433533312	32455	5	5D
0005433533300	32455	6	6A
0005433533279	32455	7	6E
0005433529255	32455	8	7A
0005433533320	32455	9	7D
0005433529271	32455	10	7F
0005433533304	32455	11	8A
0005433529291	32455	12	8D
0005433533280	32455	13	8F
0005433533333	32455	14	9E
0005433529256	32455	15	9D
0005433529260	32455	16	10A
0005433529284	32455	17	9F
0005433533332	32455	18	11B
0005433529275	32455	19	11A
0005433533315	32455	20	11D
0005433529280	32455	21	12A
0005433533327	32455	22	13A
0005433533316	32455	23	13C
0005433529262	32455	24	13E
0005433529270	32455	25	14D
0005433533309	32455	26	14E
0005433533313	32455	27	16A
0005433533317	32455	28	15F
0005433529251	32455	29	18B
0005433529254	32455	30	18E
0005433529261	32455	31	18D
0005433529276	32455	32	21B
0005433924354	2146	1	1A
0005432231685	2146	2	1C
0005433924387	2146	3	1B
0005433036372	2146	4	1F
0005433931501	2146	5	1G
0005433036221	2146	6	2A
0005433036302	2146	7	1H
0005433924361	2146	8	2C
0005433924408	2146	9	2B
0005433924346	2146	10	3A
0005433036689	2146	11	3B
0005433924431	2146	12	3C
0005433931504	2146	13	3G
0005433924423	2146	14	3F
0005433036618	2146	15	4A
0005433924397	2146	16	3H
0005433875395	2146	17	4B
0005433931502	2146	18	4F
0005433924388	2146	19	4H
0005433924424	2146	20	5B
0005433924391	2146	21	5C
0005433036267	2146	22	5G
0005433929659	2146	23	5F
0005433924405	2146	24	9B
0005433036508	2146	25	9A
0005433924373	2146	26	9G
0005433924385	2146	27	11A
0005433924339	2146	28	9H
0005432044556	2146	29	11B
0005433924410	2146	30	11E
0005433036619	2146	31	11H
0005433924392	2146	32	11G
0005433924342	2146	33	12A
0005433924377	2146	34	12D
0005433036366	2146	35	12B
0005433924341	2146	36	12E
0005433924368	2146	37	12G
0005432231687	2146	38	12F
0005433924362	2146	39	12H
0005433924353	2146	40	13B
0005433931503	2146	41	13E
0005433924411	2146	42	13G
0005433924336	2146	43	13H
0005433924429	2146	44	14A
0005432231688	2146	45	14D
0005432231689	2146	46	14E
0005433924426	2146	47	14H
0005433036334	2146	48	14G
0005433924402	2146	49	14F
0005432231684	2146	50	15A
0005433924371	2146	51	15B
0005433036654	2146	52	15E
0005433924400	2146	53	15G
0005433924401	2146	54	16A
0005434028307	2146	55	15H
0005433036496	2146	56	16D
0005433924370	2146	57	16B
0005433929658	2146	58	16F
0005434028299	2146	59	16G
0005433036479	2146	60	16H
0005433036590	2146	61	17A
0005434028298	2146	62	17D
0005433036249	2146	63	17F
0005433924404	2146	64	17E
0005433924383	2146	65	18A
0005433036605	2146	66	18D
0005433924398	2146	67	18B
0005433924403	2146	68	18F
0005433924416	2146	69	18E
0005433924343	2146	70	18G
0005433924428	2146	71	19A
0005433036591	2146	72	18H
0005433924386	2146	73	19B
0005433924432	2146	74	19E
0005433924374	2146	75	19D
0005433924363	2146	76	19F
0005433924338	2146	77	19H
0005433924433	2146	78	20B
0005433924382	2146	79	20D
0005433929661	2146	80	20E
0005433924422	2146	81	20H
0005433924412	2146	82	20G
0005433036332	2146	83	21A
0005433036492	2146	84	21D
0005433931500	2146	85	21B
0005433924372	2146	86	21E
0005434028283	2146	87	21G
0005433924395	2146	88	21F
0005433924344	2146	89	21H
0005433036467	2146	90	22A
0005433924357	2146	91	22D
0005433036452	2146	92	22B
0005433924355	2146	93	22E
0005433924337	2146	94	22G
0005433929660	2146	95	22H
0005433924394	2146	96	23B
0005433924350	2146	97	23G
0005433924414	2146	98	23F
0005433924366	2146	99	24A
0005433924413	2146	100	23H
0005433924418	2146	101	24E
0005433036385	2146	102	24F
0005433924359	2146	103	24H
0005432231679	2146	104	24G
0005433924425	2146	105	25D
0005432749793	2146	106	25E
0005433924347	2146	107	27A
0005433036487	2146	108	27B
0005433924376	2146	109	27D
0005433036636	2146	110	27F
0005433924427	2146	111	27E
0005433036491	2146	112	27G
0005433036362	2146	113	28A
0005433036369	2146	114	27H
0005433875396	2146	115	28B
0005433924407	2146	116	28F
0005433924420	2146	117	28G
0005433036606	2146	118	29A
0005433036468	2146	119	29B
0005433924380	2146	120	29E
0005433924409	2146	121	29F
0005432749787	2146	122	30E
0005433036521	2146	123	30D
0005433924364	2146	124	30B
0005433036688	2146	125	30G
0005433924419	2146	126	31A
0005433036276	2146	127	31B
0005433924379	2146	128	31E
0005433924384	2146	129	31D
0005433924349	2146	130	31F
0005433924415	2146	131	32A
0005432044555	2146	132	32D
0005433924352	2146	133	32B
0005433924358	2146	134	32E
0005433924348	2146	135	32G
0005433924351	2146	136	33A
0005433924356	2146	137	32H
0005433924393	2146	138	33B
0005433036374	2146	139	33E
0005433036620	2146	140	33D
0005433924396	2146	141	33G
0005433036236	2146	142	33F
0005433924365	2146	143	34A
0005432231680	2146	144	34D
0005433924381	2146	145	34B
0005433924390	2146	146	34F
0005433924360	2146	147	34E
0005433875394	2146	148	34G
0005433036594	2146	149	34H
0005433924421	2146	150	35B
0005432231683	2146	151	35A
0005433924417	2146	152	35D
0005433924430	2146	153	35E
0005433036495	2146	154	35G
0005433036303	2146	155	36A
0005433036371	2146	156	36E
0005433036522	2146	157	36D
0005433924369	2146	158	36F
0005433036607	2146	159	36G
0005432231686	2146	160	37D
0005433924406	2146	161	37B
0005433924399	2146	162	37E
0005434028314	2146	163	37F
0005433924389	2146	164	37G
0005433036453	2146	165	38A
0005433924340	2146	166	38D
0005432231682	2146	167	38B
0005433036350	2146	168	38E
0005433924375	2146	169	38F
0005432231681	2146	170	38H
0005433924345	2146	171	38G
0005433036484	2146	172	39D
0005433924367	2146	173	39F
0005433924378	2146	174	39E
0005433922945	24140	1	1A
0005433036901	24140	2	1C
0005433036879	24140	3	1B
0005433929631	24140	4	1H
0005433923430	24140	5	1G
0005433923344	24140	6	2A
0005433036909	24140	7	2B
0005434028330	24140	8	2F
0005433923888	24140	9	2C
0005433036914	24140	10	3A
0005433923565	24140	11	2H
0005433929629	24140	12	3B
0005433036878	24140	13	3F
0005432206261	24140	14	3C
0005432206260	24140	15	3G
0005433036890	24140	16	3H
0005432206266	24140	17	4B
0005433923401	24140	18	4A
0005433036868	24140	19	4C
0005433036894	24140	20	4F
0005433036910	24140	21	5A
0005433923435	24140	22	4H
0005433923778	24140	23	5C
0005433923456	24140	24	5G
0005433036916	24140	25	5F
0005433922946	24140	26	5H
0005433923276	24140	27	9B
0005433923650	24140	28	9H
0005433923816	24140	29	11B
0005433923714	24140	30	11D
0005433923626	24140	31	11F
0005433923314	24140	32	11G
0005433036900	24140	33	12A
0005433036917	24140	34	11H
0005433923305	24140	35	12B
0005433923628	24140	36	12E
0005433923786	24140	37	12F
0005433923983	24140	38	12H
0005433923546	24140	39	12G
0005433923535	24140	40	13B
0005433923494	24140	41	13A
0005433923200	24140	42	13D
0005433923638	24140	43	13G
0005432749810	24140	44	13F
0005433923461	24140	45	14A
0005432207692	24140	46	14D
0005433036899	24140	47	14B
0005433923420	24140	48	14G
0005433036898	24140	49	14H
0005433923273	24140	50	15B
0005432206265	24140	51	15A
0005433923819	24140	52	15D
0005433923732	24140	53	15F
0005433923804	24140	54	15G
0005434028328	24140	55	15H
0005433923555	24140	56	16B
0005433036911	24140	57	16E
0005433923534	24140	58	16D
0005433036875	24140	59	16H
0005433923625	24140	60	17D
0005433929611	24140	61	17B
0005433923692	24140	62	17F
0005433923923	24140	63	17E
0005433923620	24140	64	17H
0005433923469	24140	65	18B
0005433036883	24140	66	18A
0005433923754	24140	67	18D
0005433923803	24140	68	18E
0005433036886	24140	69	18G
0005433036881	24140	70	18F
0005433923333	24140	71	18H
0005433036885	24140	72	19E
0005433923795	24140	73	19D
0005433923958	24140	74	19F
0005433923425	24140	75	19G
0005433036915	24140	76	20B
0005433923777	24140	77	20E
0005433036892	24140	78	20F
0005433923357	24140	79	20G
0005433923657	24140	80	21A
0005433923418	24140	81	21B
0005433923421	24140	82	21E
0005433923334	24140	83	21D
0005433923554	24140	84	21G
0005433923609	24140	85	21F
0005433923414	24140	86	21H
0005433036907	24140	87	22B
0005433036921	24140	88	22A
0005433923662	24140	89	22E
0005433036919	24140	90	23A
0005433923661	24140	91	22H
0005433923659	24140	92	23D
0005433036869	24140	93	23F
0005433036893	24140	94	23E
0005434028331	24140	95	23G
0005433923815	24140	96	23H
0005433923335	24140	97	24B
0005433923356	24140	98	24D
0005433923502	24140	99	24F
0005433036876	24140	100	24G
0005433036884	24140	101	25D
0005433923640	24140	102	24H
0005432206263	24140	103	25E
0005433923006	24140	104	27A
0005433036889	24140	105	25F
0005433923354	24140	106	27E
0005433036872	24140	107	27F
0005433036913	24140	108	27H
0005433923818	24140	109	27G
0005433923693	24140	110	28D
0005433923649	24140	111	28B
0005433923293	24140	112	28A
0005433923730	24140	113	28E
0005433036902	24140	114	28H
0005433923691	24140	115	28G
0005433929608	24140	116	29B
0005433923627	24140	117	29E
0005433036896	24140	118	29D
0005433036903	24140	119	29G
0005433923274	24140	120	29F
0005433923542	24140	121	29H
0005433036871	24140	122	30B
0005433923501	24140	123	30D
0005433923594	24140	124	30E
0005433036891	24140	125	30G
0005433036906	24140	126	30F
0005433036895	24140	127	31A
0005433923602	24140	128	30H
0005433923306	24140	129	31B
0005433923792	24140	130	31D
0005434028332	24140	131	31F
0005433036874	24140	132	31E
0005433036873	24140	133	31H
0005433923220	24140	134	31G
0005433923402	24140	135	32A
0005433923470	24140	136	32B
0005433923595	24140	137	32F
0005433931481	24140	138	32H
0005433923887	24140	139	33A
0005433036920	24140	140	33B
0005433036870	24140	141	33E
0005434028329	24140	142	33D
0005432206259	24140	143	33F
0005433923257	24140	144	33H
0005433036905	24140	145	34A
0005433929618	24140	146	34D
0005433923219	24140	147	34B
0005433036882	24140	148	34F
0005432206264	24140	149	34E
0005433931475	24140	150	34H
0005432207691	24140	151	35B
0005433923753	24140	152	35A
0005433929609	24140	153	35D
0005433923566	24140	154	35E
0005433036912	24140	155	35F
0005433923814	24140	156	35H
0005433036918	24140	157	36B
0005433923598	24140	158	36D
0005433923820	24140	159	36F
0005433036877	24140	160	36H
0005433036908	24140	161	36G
0005433923553	24140	162	37E
0005433036897	24140	163	37D
0005433923514	24140	164	37H
0005433036887	24140	165	37G
0005433036888	24140	166	38A
0005433923982	24140	167	38D
0005432207690	24140	168	38B
0005433036880	24140	169	38E
0005433923601	24140	170	38G
0005433923387	24140	171	38F
0005432206262	24140	172	38H
0005433036904	24140	173	39D
0005434551864	249	1	1C
0005434731217	249	2	1A
0005433234333	249	3	1G
0005433234313	249	4	1D
0005434551874	249	5	2A
0005434726898	249	6	1K
0005433234288	249	7	2D
0005433234145	249	8	2C
0005433234146	249	9	2H
0005433181099	249	10	2G
0005434551837	249	11	3A
0005433234416	249	12	2K
0005434726849	249	13	3D
0005434726888	249	14	3C
0005433234240	249	15	3H
0005433766653	249	16	4C
0005434726801	249	17	4A
0005433234450	249	18	3K
0005435142729	249	19	4G
0005433234174	249	20	4D
0005434726902	249	21	4K
0005434551877	249	22	4H
0005433289878	249	23	5C
0005434551830	249	24	5H
0005433181170	249	25	5G
0005434726783	249	26	5D
0005433766639	249	27	11A
0005433234284	249	28	5K
0005433234413	249	29	11E
0005433234415	249	30	11D
0005434551865	249	31	11F
0005434726806	249	32	11K
0005433126849	249	33	11H
0005433234588	249	34	11G
0005433234283	249	35	12C
0005434551825	249	36	12A
0005434551872	249	37	12F
0005435142737	249	38	12E
0005434302506	249	39	12G
0005434726864	249	40	12K
0005432277966	249	41	12H
0005434726874	249	42	13D
0005434726843	249	43	13C
0005434726789	249	44	13A
0005434551850	249	45	13F
0005434726824	249	46	13E
0005433234148	249	47	13H
0005434726886	249	48	13G
0005434726862	249	49	13K
0005433234153	249	50	14E
0005434726840	249	51	14D
0005434726825	249	52	14C
0005433181184	249	53	14G
0005433181144	249	54	14K
0005433234209	249	55	14H
0005434726833	249	56	15A
0005434726781	249	57	15F
0005434551875	249	58	15E
0005433181195	249	59	15D
0005433181093	249	60	15H
0005433289899	249	61	15G
0005433234455	249	62	15K
0005434735743	249	63	16D
0005434726883	249	64	16C
0005434551829	249	65	16A
0005433131721	249	66	16F
0005434551834	249	67	16E
0005434726831	249	68	16H
0005434726839	249	69	16G
0005434726848	249	70	17A
0005434735747	249	71	16K
0005433234546	249	72	17E
0005433234272	249	73	17D
0005433234338	249	74	17C
0005433234467	249	75	17G
0005434551870	249	76	17F
0005434551862	249	77	17K
0005434726836	249	78	17H
0005434726876	249	79	18B
0005435142734	249	80	18A
0005434726810	249	81	18E
0005434551847	249	82	18D
0005432277965	249	83	18C
0005432277960	249	84	18G
0005434551826	249	85	18F
0005434726860	249	86	18H
0005433234269	249	87	19A
0005433766647	249	88	18K
0005434551838	249	89	19C
0005435142725	249	90	19B
0005433181213	249	91	19F
0005434726877	249	92	19E
0005434726809	249	93	19D
0005434726793	249	94	19H
0005435142728	249	95	19G
0005434726785	249	96	19K
0005433181237	249	97	19J
0005433289875	249	98	20B
0005433234276	249	99	20A
0005434726866	249	100	20E
0005433289877	249	101	20D
0005434726857	249	102	20F
0005433234373	249	103	20J
0005434551853	249	104	20H
0005434551868	249	105	21B
0005433234437	249	106	21A
0005434551831	249	107	20K
0005434726856	249	108	21D
0005433234105	249	109	21C
0005434735744	249	110	21F
0005433234139	249	111	21E
0005434726834	249	112	21J
0005433181064	249	113	21H
0005434726852	249	114	21K
0005433234456	249	115	22C
0005433234384	249	116	22F
0005434726844	249	117	22E
0005434726787	249	118	22D
0005434726800	249	119	22H
0005434726788	249	120	22G
0005434551832	249	121	22K
0005434726822	249	122	22J
0005434726899	249	123	23B
0005433234173	249	124	23A
0005434551867	249	125	23D
0005434726853	249	126	23C
0005433234357	249	127	23F
0005434551873	249	128	23E
0005434302511	249	129	23J
0005433234448	249	130	23H
0005433289898	249	131	23G
0005434726821	249	132	24D
0005433234529	249	133	23K
0005434726889	249	134	24F
0005433289876	249	135	24E
0005434726867	249	136	25A
0005434726855	249	137	24G
0005433113540	249	138	25D
0005434726865	249	139	25C
0005434726872	249	140	25B
0005434731214	249	141	25F
0005433111512	249	142	25E
0005434726794	249	143	25H
0005434551836	249	144	25G
0005432277956	249	145	25K
0005433234444	249	146	25J
0005434726841	249	147	26C
0005434551879	249	148	26B
0005434726850	249	149	26A
0005434302508	249	150	26E
0005434726792	249	151	26D
0005433234395	249	152	26G
0005432277954	249	153	26F
0005434726892	249	154	26K
0005432277967	249	155	26J
0005434551878	249	156	26H
0005434726895	249	157	27B
0005433289900	249	158	27A
0005433113544	249	159	27C
0005433181098	249	160	27F
0005434726784	249	161	27E
0005434726791	249	162	27D
0005434726897	249	163	27H
0005433234270	249	164	27G
0005433234306	249	165	28A
0005434726896	249	166	27K
0005434726805	249	167	27J
0005433234198	249	168	28B
0005434032048	249	169	28E
0005432277957	249	170	28C
0005433181244	249	171	28G
0005434726881	249	172	28F
0005433181127	249	173	28J
0005433181092	249	174	28H
0005434726868	249	175	29A
0005434551839	249	176	28K
0005434726904	249	177	29D
0005433181245	249	178	29C
0005433234567	249	179	29B
0005433766640	249	180	29F
0005433234549	249	181	29E
0005433234347	249	182	29J
0005434726887	249	183	29H
0005433181161	249	184	30A
0005433234466	249	185	29K
0005434726808	249	186	30C
0005432277962	249	187	30B
0005432277959	249	188	30E
0005434726858	249	189	30D
0005433234320	249	190	30H
0005433181205	249	191	30G
0005433126844	249	192	30F
0005433234305	249	193	30J
0005434551848	249	194	31B
0005435142733	249	195	31A
0005433234454	249	196	30K
0005434735742	249	197	31D
0005433234568	249	198	31C
0005434726813	249	199	31F
0005434726885	249	200	31E
0005433289840	249	201	31H
0005434551833	249	202	31G
0005433234449	249	203	32A
0005433234238	249	204	31K
0005435142727	249	205	31J
0005434551824	249	206	32C
0005434551845	249	207	32E
0005434726829	249	208	32D
0005434726804	249	209	32G
0005434726818	249	210	32F
0005434032049	249	211	32J
0005434726799	249	212	33A
0005434726827	249	213	32K
0005434726826	249	214	33C
0005434551852	249	215	33B
0005434302509	249	216	33F
0005433126851	249	217	33E
0005434726851	249	218	33H
0005434726832	249	219	33G
0005433234106	249	220	33K
0005434726835	249	221	33J
0005434551869	249	222	34C
0005434726903	249	223	34B
0005434551851	249	224	34A
0005434726798	249	225	34E
0005434726786	249	226	34D
0005434726884	249	227	34G
0005433131711	249	228	34F
0005433234334	249	229	34J
0005433126845	249	230	34H
0005434726845	249	231	35B
0005433234463	249	232	35A
0005434726891	249	233	34K
0005434726846	249	234	35D
0005434551849	249	235	35F
0005433766637	249	236	35E
0005433234679	249	237	35H
0005434551842	249	238	35G
0005434726815	249	239	35K
0005434731213	249	240	35J
0005435142730	249	241	36C
0005434551843	249	242	36A
0005434726875	249	243	36E
0005434726790	249	244	36D
0005435142732	249	245	36H
0005434551828	249	246	36G
0005432277964	249	247	36K
0005434726828	249	248	36J
0005434551827	249	249	37C
0005433234005	249	250	37B
0005434726873	249	251	37A
0005434726863	249	252	37D
0005434726795	249	253	37G
0005434726807	249	254	37F
0005433234179	249	255	37E
0005433289879	249	256	37H
0005433234151	249	257	37K
0005432277961	249	258	38C
0005434726817	249	259	38B
0005434726871	249	260	38A
0005433234225	249	261	38K
0005434726906	249	262	38J
0005434551846	249	263	38H
0005433234223	249	264	39B
0005433131724	249	265	39A
0005434726814	249	266	39D
0005434726861	249	267	39C
0005434551866	249	268	39F
0005434302510	249	269	39J
0005434726847	249	270	39H
0005433289894	249	271	39G
0005433234326	249	272	39K
0005433234241	249	273	40B
0005434551863	249	274	40E
0005434551871	249	275	40D
0005434726901	249	276	40H
0005434302507	249	277	40G
0005434726837	249	278	40F
0005433234436	249	279	40J
0005435142724	249	280	41B
0005433289880	249	281	41A
0005433131720	249	282	40K
0005432277958	249	283	41D
0005433234237	249	284	41C
0005434551859	249	285	41F
0005434726905	249	286	41H
0005434551844	249	287	41G
0005434551858	249	288	42A
0005434726812	249	289	41K
0005434726823	249	290	41J
0005433126848	249	291	42B
0005433234453	249	292	42E
0005434726900	249	293	42D
0005432277963	249	294	42C
0005434735746	249	295	42G
0005433181194	249	296	42F
0005434032032	249	297	42K
0005433181199	249	298	42J
0005434726882	249	299	43C
0005434726782	249	300	43B
0005434551860	249	301	43F
0005433234387	249	302	43H
0005434735745	249	303	43G
0005434726869	249	304	43K
0005434726811	249	305	43J
0005434731216	249	306	44B
0005434726796	249	307	44A
0005433126850	249	308	44D
0005433181143	249	309	44C
0005433126858	249	310	44H
0005433234581	249	311	44F
0005434551841	249	312	44J
0005435142736	249	313	45A
0005433181185	249	314	44K
0005435142726	249	315	45D
0005434726893	249	316	45C
0005434726819	249	317	45B
0005434726854	249	318	45F
0005433234239	249	319	45E
0005434726797	249	320	45H
0005434551855	249	321	46A
0005434726879	249	322	45K
0005434726870	249	323	45J
0005433289893	249	324	46B
0005434726878	249	325	46E
0005434551835	249	326	46D
0005434726816	249	327	46C
0005434551880	249	328	46G
0005434731215	249	329	46F
0005433181193	249	330	46J
0005433131722	249	331	46H
0005433181078	249	332	47A
0005433766636	249	333	46K
0005433131692	249	334	47E
0005434551854	249	335	47D
0005433234337	249	336	47C
0005433234271	249	337	47G
0005435142731	249	338	47F
0005434726803	249	339	47K
0005432277955	249	340	47H
0005434551861	249	341	48D
0005433234635	249	342	48A
0005435142735	249	343	48F
0005433181196	249	344	48E
0005433289839	249	345	48H
0005434551857	249	346	48G
0005433234242	249	347	49A
0005434551840	249	348	48K
0005434726880	249	349	49E
0005434726842	249	350	49D
0005434726838	249	351	49C
0005434551856	249	352	49G
0005433234175	249	353	49F
0005433234589	249	354	49H
0005433131723	249	355	50C
0005434726859	249	356	50A
0005434726894	249	357	50F
0005433234180	249	358	50E
0005434726890	249	359	50D
0005434726820	249	360	50G
0005434726830	249	361	51D
0005433113541	249	362	50K
0005433234307	249	363	50H
0005434726802	249	364	51F
0005434551876	249	365	51E
0005433234938	9844	1	1C
0005433181381	9844	2	1A
0005433181380	9844	3	1H
0005434032076	9844	4	1G
0005434726047	9844	5	1D
0005434726170	9844	6	2H
0005433181390	9844	7	2D
0005434726355	9844	8	3A
0005433766684	9844	9	2K
0005433234896	9844	10	3D
0005434551197	9844	11	3C
0005433234915	9844	12	3H
0005433234899	9844	13	3G
0005434725621	9844	14	4C
0005434725553	9844	15	4A
0005433289930	9844	16	3K
0005433289929	9844	17	5A
0005434551479	9844	18	4K
0005434725437	9844	19	4H
0005434725747	9844	20	5D
0005433234886	9844	21	5G
0005434032079	9844	22	5K
0005434726111	9844	23	11D
0005435142590	9844	24	11C
0005433234918	9844	25	11E
0005434551435	9844	26	11H
0005434551193	9844	27	12C
0005434725323	9844	28	12A
0005433289928	9844	29	12F
0005435142525	9844	30	12E
0005434551273	9844	31	12D
0005433181372	9844	32	12H
0005434731180	9844	33	12K
0005434551410	9844	34	13C
0005433234917	9844	35	13A
0005433234931	9844	36	13F
0005433181396	9844	37	13E
0005433181383	9844	38	13D
0005433181387	9844	39	13H
0005433234898	9844	40	13G
0005434725934	9844	41	14C
0005435142615	9844	42	13K
0005433234926	9844	43	14E
0005433181378	9844	44	14D
0005433234911	9844	45	14G
0005433181379	9844	46	14F
0005434726228	9844	47	14K
0005434726032	9844	48	14H
0005433234900	9844	49	15D
0005433234908	9844	50	15C
0005433234934	9844	51	15A
0005434726006	9844	52	15F
0005434731179	9844	53	15G
0005434551313	9844	54	16A
0005432199323	9844	55	16D
0005434725886	9844	56	16C
0005434725643	9844	57	16F
0005433234919	9844	58	16E
0005433234916	9844	59	16G
0005433289927	9844	60	16K
0005434725816	9844	61	17D
0005433234937	9844	62	17C
0005433181374	9844	63	17H
0005433234945	9844	64	17F
0005434725513	9844	65	17K
0005433181375	9844	66	18C
0005434551408	9844	67	18A
0005433234922	9844	68	18E
0005434725257	9844	69	18D
0005433234913	9844	70	18G
0005434726000	9844	71	18F
0005434726011	9844	72	18J
0005433234904	9844	73	18H
0005434551389	9844	74	19B
0005434725548	9844	75	19A
0005434551411	9844	76	18K
0005434725190	9844	77	19C
0005434551498	9844	78	19F
0005434551511	9844	79	19E
0005434726140	9844	80	19H
0005434726126	9844	81	20A
0005433181388	9844	82	19J
0005434551194	9844	83	20C
0005434725708	9844	84	20E
0005433289926	9844	85	20D
0005434725712	9844	86	20G
0005434726074	9844	87	20K
0005434551512	9844	88	20J
0005434725997	9844	89	20H
0005434725398	9844	90	21B
0005434725587	9844	91	21C
0005434725954	9844	92	21F
0005434725324	9844	93	21J
0005434551148	9844	94	21H
0005434725568	9844	95	21G
0005434725785	9844	96	22A
0005433181385	9844	97	21K
0005434726346	9844	98	22C
0005434725758	9844	99	22B
0005432199325	9844	100	22F
0005433234940	9844	101	22E
0005434726112	9844	102	22H
0005433234933	9844	103	22G
0005433766685	9844	104	22K
0005434726234	9844	105	23B
0005434725440	9844	106	23A
0005434726184	9844	107	23D
0005433129325	9844	108	23C
0005434725748	9844	109	23F
0005433234912	9844	110	23E
0005434726033	9844	111	23H
0005435142601	9844	112	23G
0005433129327	9844	113	24D
0005434551002	9844	114	23K
0005434302458	9844	115	24F
0005432199328	9844	116	24E
0005434725397	9844	117	24G
0005434725898	9844	118	25D
0005434725704	9844	119	25C
0005433234936	9844	120	25F
0005434551515	9844	121	25E
0005434551415	9844	122	25H
0005434725903	9844	123	25G
0005434726005	9844	124	25J
0005433234932	9844	125	26C
0005433234927	9844	126	26E
0005434726278	9844	127	26D
0005433289925	9844	128	26H
0005434725857	9844	129	26G
0005434726354	9844	130	26F
0005433234887	9844	131	26J
0005434551560	9844	132	26K
0005434725831	9844	133	27E
0005434551240	9844	134	27D
0005434032078	9844	135	27H
0005434725441	9844	136	27G
0005433234890	9844	137	27K
0005434725195	9844	138	27J
0005434731169	9844	139	28B
0005434551412	9844	140	28E
0005434726243	9844	141	28C
0005433126896	9844	142	28G
0005433234901	9844	143	28F
0005434726504	9844	144	28J
0005434551466	9844	145	29A
0005435142530	9844	146	29E
0005434032077	9844	147	29D
0005435142543	9844	148	29J
0005433181377	9844	149	30A
0005433181398	9844	150	29K
0005433234941	9844	151	30E
0005433234929	9844	152	30D
0005433234924	9844	153	30G
0005433234893	9844	154	30F
0005434726182	9844	155	30J
0005435142527	9844	156	30H
0005433181395	9844	157	31B
0005434725664	9844	158	31A
0005433289931	9844	159	30K
0005434725566	9844	160	31D
0005434726090	9844	161	31E
0005434725963	9844	162	31H
0005435142544	9844	163	31G
0005434551322	9844	164	32A
0005435142524	9844	165	31K
0005433234885	9844	166	32C
0005433181384	9844	167	32E
0005434551525	9844	168	32D
0005434551359	9844	169	32K
0005434551514	9844	170	32J
0005433234909	9844	171	32H
0005433181394	9844	172	33A
0005433181386	9844	173	33D
0005434725714	9844	174	33C
0005434551312	9844	175	33J
0005433234928	9844	176	33G
0005434551447	9844	177	33K
0005433766681	9844	178	34C
0005434725429	9844	179	34B
0005433113561	9844	180	34A
0005433234894	9844	181	34E
0005434551051	9844	182	34D
0005433234946	9844	183	34G
0005433234930	9844	184	34F
0005434551497	9844	185	34J
0005433234903	9844	186	34H
0005434725904	9844	187	35B
0005434725258	9844	188	35A
0005434726183	9844	189	35D
0005433234888	9844	190	35C
0005434725377	9844	191	35E
0005434726283	9844	192	35J
0005433181373	9844	193	35H
0005433181391	9844	194	35G
0005433181389	9844	195	36A
0005434725931	9844	196	36D
0005432199324	9844	197	36B
0005435142542	9844	198	36E
0005433129328	9844	199	36H
0005434551200	9844	200	36G
0005434551508	9844	201	36F
0005434551390	9844	202	36K
0005433234914	9844	203	36J
0005434725540	9844	204	37B
0005434725572	9844	205	37A
0005434726098	9844	206	37E
0005434551275	9844	207	37D
0005433129326	9844	208	37C
0005434725836	9844	209	37G
0005434551414	9844	210	37H
0005433234905	9844	211	38A
0005433234910	9844	212	37K
0005434551559	9844	213	37J
0005433766682	9844	214	38C
0005434551526	9844	215	38B
0005433181382	9844	216	39B
0005434551107	9844	217	39A
0005432199326	9844	218	38K
0005434551227	9844	219	39D
0005434725518	9844	220	39C
0005433129329	9844	221	39F
0005434726212	9844	222	39E
0005435142526	9844	223	39H
0005434726277	9844	224	40A
0005433126898	9844	225	39K
0005434551507	9844	226	39J
0005434551358	9844	227	40B
0005434725765	9844	228	40E
0005434725795	9844	229	40D
0005433113562	9844	230	40F
0005433234891	9844	231	40K
0005433181376	9844	232	40J
0005433234921	9844	233	40H
0005433234923	9844	234	41B
0005433766683	9844	235	41A
0005434551272	9844	236	41D
0005433234935	9844	237	41C
0005433234939	9844	238	41F
0005434551239	9844	239	41E
0005434726294	9844	240	41H
0005433234902	9844	241	41G
0005434725622	9844	242	42A
0005433234925	9844	243	41K
0005434551480	9844	244	42C
0005434726279	9844	245	42B
0005434725656	9844	246	42F
0005432199329	9844	247	42E
0005433126897	9844	248	42D
0005434725763	9844	249	42J
0005435142588	9844	250	43B
0005434551391	9844	251	43A
0005434726089	9844	252	42K
0005434551321	9844	253	43C
0005434725867	9844	254	43F
0005434725524	9844	255	43E
0005434725623	9844	256	43H
0005434725909	9844	257	43G
0005434725780	9844	258	44A
0005433181397	9844	259	43K
0005434726233	9844	260	44C
0005434551543	9844	261	44B
0005435142531	9844	262	44E
0005434551175	9844	263	44D
0005434725690	9844	264	44H
0005434726503	9844	265	44G
0005434551276	9844	266	44J
0005433234944	9844	267	45B
0005433181393	9844	268	44K
0005434551155	9844	269	45C
0005434726125	9844	270	45F
0005434726104	9844	271	45E
0005434725438	9844	272	45D
0005434725519	9844	273	45H
0005433234889	9844	274	45G
0005434726280	9844	275	45K
0005434725659	9844	276	45J
0005434726075	9844	277	46C
0005433234920	9844	278	46B
0005433234892	9844	279	46E
0005434725866	9844	280	46D
0005434725847	9844	281	46G
0005434551339	9844	282	46F
0005434725967	9844	283	47A
0005434726124	9844	284	47E
0005434551523	9844	285	47D
0005434726242	9844	286	47C
0005433234942	9844	287	47G
0005435142614	9844	288	47F
0005433234895	9844	289	47K
0005434725436	9844	290	47H
0005434302461	9844	291	48C
0005433234907	9844	292	48E
0005433181392	9844	293	48H
0005434032075	9844	294	48G
0005434551147	9844	295	48F
0005433234906	9844	296	49A
0005433234943	9844	297	48K
0005434551040	9844	298	49E
0005434725962	9844	299	49K
0005434726122	9844	300	49H
0005434735698	9844	301	49G
0005432199327	9844	302	50C
0005434725291	9844	303	50A
0005434726479	9844	304	50G
0005434725547	9844	305	50F
0005434551099	9844	306	51D
0005433234947	9844	307	50K
0005434725848	9844	308	51F
0005433234897	9844	309	51E
0005434551274	9844	310	51G
0005434068353	7753	1	1C
0005432537081	7753	2	1A
0005432529398	7753	3	1H
0005435213562	7753	4	1G
0005432529500	7753	5	1D
0005432529447	7753	6	2A
0005432150280	7753	7	1K
0005432529499	7753	8	2C
0005434068337	7753	9	2H
0005432529433	7753	10	2G
0005432150282	7753	11	2D
0005435213913	7753	12	3A
0005432529450	7753	13	2K
0005432529506	7753	14	3D
0005435213864	7753	15	3C
0005432529431	7753	16	3K
0005434068352	7753	17	3H
0005434068336	7753	18	3G
0005435213724	7753	19	4C
0005435213589	7753	20	4D
0005432529396	7753	21	4K
0005432529391	7753	22	4H
0005434068334	7753	23	5C
0005432529427	7753	24	5A
0005433656658	7753	25	5H
0005435725608	7753	26	5D
0005434068342	7753	27	5K
0005432529392	7753	28	11C
0005432529482	7753	29	11F
0005432529481	7753	30	11E
0005434068345	7753	31	11G
0005435213694	7753	32	12A
0005432529400	7753	33	12E
0005434068400	7753	34	12D
0005434068378	7753	35	12C
0005435213577	7753	36	12G
0005435213736	7753	37	12F
0005432529522	7753	38	13A
0005432529454	7753	39	12K
0005432529518	7753	40	13D
0005432529437	7753	41	13F
0005432529393	7753	42	13E
0005434068367	7753	43	14C
0005435213676	7753	44	14A
0005434068358	7753	45	14E
0005434068371	7753	46	14D
0005434068380	7753	47	14G
0005435213876	7753	48	14F
0005432529484	7753	49	14K
0005432529483	7753	50	14H
0005434068372	7753	51	15C
0005434068350	7753	52	15D
0005434068376	7753	53	15H
0005432529467	7753	54	15G
0005432529513	7753	55	15K
0005434068357	7753	56	16D
0005434068392	7753	57	16C
0005432069816	7753	58	16A
0005432529477	7753	59	16F
0005432150285	7753	60	16E
0005435213698	7753	61	16G
0005434068384	7753	62	17A
0005434068340	7753	63	16K
0005435213810	7753	64	17E
0005434068338	7753	65	17F
0005432529397	7753	66	17K
0005435214037	7753	67	17H
0005434068349	7753	68	18B
0005432529459	7753	69	18A
0005432150281	7753	70	18D
0005432529453	7753	71	18C
0005434068359	7753	72	18G
0005432529503	7753	73	18F
0005432529519	7753	74	18K
0005432529412	7753	75	18J
0005434068397	7753	76	18H
0005434068374	7753	77	19D
0005432069819	7753	78	19C
0005432529516	7753	79	19B
0005434068386	7753	80	19F
0005434068348	7753	81	19E
0005432529420	7753	82	19J
0005432529505	7753	83	19H
0005432529405	7753	84	19G
0005435213847	7753	85	20A
0005434068385	7753	86	19K
0005432529478	7753	87	20E
0005434068354	7753	88	20D
0005434068364	7753	89	20C
0005432529486	7753	90	20G
0005432069820	7753	91	20F
0005434068329	7753	92	20K
0005434068360	7753	93	20J
0005435213963	7753	94	20H
0005432428966	7753	95	21B
0005432529514	7753	96	21A
0005434068377	7753	97	21C
0005432069822	7753	98	21E
0005432529413	7753	99	21J
0005432529510	7753	100	21H
0005432529409	7753	101	22A
0005434068399	7753	102	21K
0005435630982	7753	103	22C
0005434068387	7753	104	22B
0005435213469	7753	105	22F
0005432529490	7753	106	22E
0005432529440	7753	107	22H
0005432529507	7753	108	22G
0005434068396	7753	109	22J
0005435213967	7753	110	23B
0005432069813	7753	111	23A
0005432529401	7753	112	23C
0005434068379	7753	113	23G
0005433656657	7753	114	23F
0005432529406	7753	115	23E
0005432529452	7753	116	23H
0005432529429	7753	117	24F
0005435213914	7753	118	24E
0005432150284	7753	119	24D
0005432529511	7753	120	25B
0005432529448	7753	121	25A
0005435213306	7753	122	25C
0005432529411	7753	123	25F
0005435213894	7753	124	25E
0005434068390	7753	125	25D
0005432529512	7753	126	25H
0005432069825	7753	127	25G
0005432069823	7753	128	26A
0005435213505	7753	129	25K
0005432533324	7753	130	25J
0005432529523	7753	131	26B
0005432529443	7753	132	26E
0005432529424	7753	133	26F
0005432529461	7753	134	26K
0005432529489	7753	135	26J
0005434068373	7753	136	26H
0005432529476	7753	137	27B
0005435213723	7753	138	27A
0005432529474	7753	139	27D
0005435725615	7753	140	27C
0005432535887	7753	141	27F
0005434068341	7753	142	27E
0005432529502	7753	143	27H
0005432529493	7753	144	27G
0005432529415	7753	145	28A
0005435213792	7753	146	27K
0005435213903	7753	147	27J
0005434068363	7753	148	28C
0005432529422	7753	149	28D
0005432529399	7753	150	28G
0005432529466	7753	151	28F
0005432529402	7753	152	28J
0005432150287	7753	153	29B
0005434068332	7753	154	29A
0005432150286	7753	155	28K
0005435213784	7753	156	29D
0005432529469	7753	157	29C
0005432529434	7753	158	29F
0005432533325	7753	159	29E
0005432529494	7753	160	29H
0005432529508	7753	161	29G
0005432428968	7753	162	29K
0005432529439	7753	163	29J
0005435213699	7753	164	30C
0005432529423	7753	165	30A
0005432529487	7753	166	30D
0005435213793	7753	167	30G
0005434068339	7753	168	30F
0005435213890	7753	169	30E
0005435213750	7753	170	30J
0005432529504	7753	171	31A
0005432529457	7753	172	31D
0005435213639	7753	173	31C
0005432069821	7753	174	31F
0005432069814	7753	175	31E
0005432529436	7753	176	31J
0005435213740	7753	177	31G
0005434068365	7753	178	31K
0005432529414	7753	179	32C
0005432529475	7753	180	32E
0005432535888	7753	181	32D
0005434068344	7753	182	32G
0005435213737	7753	183	32F
0005432529435	7753	184	32J
0005435213824	7753	185	32H
0005434068382	7753	186	33B
0005435213907	7753	187	33A
0005433656679	7753	188	32K
0005432529404	7753	189	33C
0005434068398	7753	190	33G
0005435725607	7753	191	33F
0005435213460	7753	192	33E
0005432529417	7753	193	33H
0005434068333	7753	194	33K
0005435213746	7753	195	34A
0005435213821	7753	196	34D
0005432529501	7753	197	34G
0005434068383	7753	198	34F
0005432529394	7753	199	34J
0005435213693	7753	200	34H
0005435213717	7753	201	35B
0005435213677	7753	202	35A
0005432529451	7753	203	34K
0005432529465	7753	204	35E
0005434068393	7753	205	35D
0005432529464	7753	206	35F
0005432529426	7753	207	35G
0005434068330	7753	208	36A
0005432529445	7753	209	35K
0005435213837	7753	210	35J
0005432529480	7753	211	36C
0005432529438	7753	212	36B
0005432069812	7753	213	36F
0005432529496	7753	214	36D
0005432537082	7753	215	36H
0005432150283	7753	216	36G
0005434068347	7753	217	36K
0005433656678	7753	218	37B
0005434068355	7753	219	37A
0005432529462	7753	220	37C
0005432529479	7753	221	37E
0005432529468	7753	222	37H
0005435213836	7753	223	37K
0005432529442	7753	224	37J
0005435214038	7753	225	38C
0005435213531	7753	226	38B
0005432069817	7753	227	38J
0005435213588	7753	228	38H
0005434068394	7753	229	39A
0005435213745	7753	230	39D
0005432529471	7753	231	39C
0005432529446	7753	232	39B
0005434068370	7753	233	39E
0005433656663	7753	234	39H
0005432069815	7753	235	39G
0005434068361	7753	236	39K
0005435213590	7753	237	40C
0005435213257	7753	238	40E
0005432529419	7753	239	40D
0005432529470	7753	240	40H
0005432529492	7753	241	40G
0005432529458	7753	242	40F
0005435213754	7753	243	40K
0005432529449	7753	244	40J
0005435213848	7753	245	41C
0005432529407	7753	246	41F
0005432529460	7753	247	41E
0005432529491	7753	248	41H
0005432529403	7753	249	41J
0005435213597	7753	250	42C
0005434068331	7753	251	42B
0005434068388	7753	252	42E
0005432529421	7753	253	42D
0005432529498	7753	254	42G
0005435213785	7753	255	42H
0005434068369	7753	256	43A
0005432529425	7753	257	42K
0005434068346	7753	258	43D
0005432428967	7753	259	43C
0005432529408	7753	260	43F
0005432529430	7753	261	43E
0005432535890	7753	262	43G
0005435213798	7753	263	44A
0005435213640	7753	264	43K
0005432535889	7753	265	43J
0005435213675	7753	266	44C
0005433656682	7753	267	44B
0005435213915	7753	268	44E
0005434068389	7753	269	44D
0005434068391	7753	270	44F
0005432069818	7753	271	44K
0005432529441	7753	272	44J
0005435213823	7753	273	44H
0005435213797	7753	274	45D
0005432529521	7753	275	45F
0005434068362	7753	276	45E
0005432529455	7753	277	45H
0005432529497	7753	278	45G
0005432529395	7753	279	45K
0005434068366	7753	280	45J
0005434068335	7753	281	46A
0005435213764	7753	282	46E
0005435213603	7753	283	46D
0005434068368	7753	284	46G
0005434068381	7753	285	46J
0005432529432	7753	286	47C
0005432529390	7753	287	47A
0005434068375	7753	288	46K
0005432529495	7753	289	47E
0005432529520	7753	290	47D
0005432529473	7753	291	47G
0005432529488	7753	292	47F
0005434068401	7753	293	47H
0005432529485	7753	294	48C
0005432529456	7753	295	48F
0005435213844	7753	296	48E
0005432529472	7753	297	48D
0005432529444	7753	298	48H
0005432529416	7753	299	48G
0005435213846	7753	300	49A
0005435213563	7753	301	48K
0005432069824	7753	302	49D
0005432529517	7753	303	49C
0005432529428	7753	304	49F
0005433656683	7753	305	49K
0005435213695	7753	306	49H
0005432529509	7753	307	49G
0005435213865	7753	308	50C
0005434068343	7753	309	50A
0005432529463	7753	310	50E
0005434068328	7753	311	50G
0005434068356	7753	312	50F
0005434068351	7753	313	51D
0005432529515	7753	314	50K
0005432529418	7753	315	50H
0005432529410	7753	316	51F
0005434068395	7753	317	51E
0005432533326	7753	318	51G
0005434245095	5348	1	1A
0005435614947	5348	2	1G
0005435614895	5348	3	2A
0005435614916	5348	4	1K
0005435614969	5348	5	1H
0005434656567	5348	6	2D
0005433719151	5348	7	2C
0005434245129	5348	8	2H
0005435380296	5348	9	2G
0005434245081	5348	10	3A
0005435380313	5348	11	2K
0005435614993	5348	12	3D
0005435614901	5348	13	3C
0005434344624	5348	14	3K
0005435490269	5348	15	3H
0005435614960	5348	16	3G
0005432133374	5348	17	4C
0005435425244	5348	18	4A
0005435424854	5348	19	4G
0005435425027	5348	20	4D
0005434573507	5348	21	4K
0005434573513	5348	22	4H
0005434344630	5348	23	5C
0005432133376	5348	24	5H
0005434344625	5348	25	5G
0005434344610	5348	26	5D
0005435614890	5348	27	11A
0005434245128	5348	28	11E
0005435614990	5348	29	11D
0005434344627	5348	30	11C
0005432133383	5348	31	11H
0005432133390	5348	32	12C
0005435425000	5348	33	12E
0005434573508	5348	34	12G
0005435380320	5348	35	12F
0005434344628	5348	36	12K
0005435614991	5348	37	12H
0005435614985	5348	38	13D
0005433719137	5348	39	13G
0005434344608	5348	40	13F
0005435424935	5348	41	13E
0005434344601	5348	42	13H
0005434573505	5348	43	13K
0005435614996	5348	44	14E
0005435614972	5348	45	14D
0005434344631	5348	46	14C
0005435614887	5348	47	14G
0005435302199	5348	48	14F
0005435614933	5348	49	14H
0005435614956	5348	50	15C
0005435614918	5348	51	15A
0005435614978	5348	52	14K
0005435425222	5348	53	15F
0005435614906	5348	54	15E
0005435425300	5348	55	15D
0005434245092	5348	56	15H
0005434344616	5348	57	15G
0005435614894	5348	58	16A
0005435425026	5348	59	16D
0005435614948	5348	60	16C
0005435614942	5348	61	16F
0005434656568	5348	62	16E
0005435305020	5348	63	16H
0005434344619	5348	64	16G
0005434573519	5348	65	17A
0005434344623	5348	66	16K
0005434656563	5348	67	17D
0005435614987	5348	68	17C
0005434344634	5348	69	17G
0005434245125	5348	70	17F
0005435614950	5348	71	17K
0005435097314	5348	72	17H
0005435614973	5348	73	18C
0005432047594	5348	74	18B
0005435425100	5348	75	18A
0005435614939	5348	76	18E
0005435097313	5348	77	18G
0005435614943	5348	78	18F
0005434344604	5348	79	18K
0005433719160	5348	80	18J
0005435614905	5348	81	18H
0005435614953	5348	82	19B
0005435614900	5348	83	19A
0005435491462	5348	84	19D
0005435425255	5348	85	19C
0005434245020	5348	86	19F
0005435490270	5348	87	19E
0005435614899	5348	88	19J
0005435424856	5348	89	19H
0005432133384	5348	90	19K
0005434656566	5348	91	20C
0005435614975	5348	92	20B
0005435614965	5348	93	20A
0005433719136	5348	94	20E
0005435614932	5348	95	20D
0005435425245	5348	96	20G
0005435425093	5348	97	20F
0005435425116	5348	98	20K
0005433719140	5348	99	20H
0005434344618	5348	100	21B
0005432047593	5348	101	21D
0005434344609	5348	102	21C
0005432133388	5348	103	21F
0005432133382	5348	104	21J
0005435614875	5348	105	22A
0005435614929	5348	106	22C
0005435614876	5348	107	22B
0005435302209	5348	108	22E
0005434344633	5348	109	22D
0005435097319	5348	110	22K
0005435614986	5348	111	22J
0005435380302	5348	112	22H
0005435424780	5348	113	23C
0005435097315	5348	114	23B
0005435042855	5348	115	23A
0005434245052	5348	116	23E
0005435424747	5348	117	23J
0005435380295	5348	118	23H
0005434245127	5348	119	23G
0005434245104	5348	120	24D
0005434344629	5348	121	24F
0005434344636	5348	122	24E
0005435614877	5348	123	25B
0005435425102	5348	124	24G
0005435614911	5348	125	25C
0005435425287	5348	126	25F
0005435614925	5348	127	25E
0005435614966	5348	128	25J
0005435302201	5348	129	25H
0005435425223	5348	130	25G
0005434344612	5348	131	25K
0005434245000	5348	132	26C
0005435614989	5348	133	26B
0005432133387	5348	134	26A
0005435614994	5348	135	26E
0005435097316	5348	136	26D
0005434245011	5348	137	26G
0005435424948	5348	138	26F
0005435614927	5348	139	26K
0005434245124	5348	140	26H
0005435425221	5348	141	27B
0005435097321	5348	142	27A
0005435042854	5348	143	27D
0005434573518	5348	144	27C
0005434344635	5348	145	27F
0005435614882	5348	146	27E
0005435614938	5348	147	27J
0005435614937	5348	148	27H
0005434245001	5348	149	27G
0005432133377	5348	150	28A
0005434573506	5348	151	27K
0005435555393	5348	152	28C
0005435614923	5348	153	28B
0005435425107	5348	154	28E
0005434573517	5348	155	28D
0005435380301	5348	156	28F
0005435555391	5348	157	28J
0005435614888	5348	158	28H
0005432133378	5348	159	29B
0005435424746	5348	160	29A
0005433719142	5348	161	28K
0005435424927	5348	162	29D
0005434344600	5348	163	29C
0005435614976	5348	164	29F
0005435614970	5348	165	29H
0005434344617	5348	166	29G
0005435614913	5348	167	30A
0005435614908	5348	168	29K
0005435614971	5348	169	29J
0005435614897	5348	170	30C
0005435614914	5348	171	30B
0005434344614	5348	172	30D
0005435614922	5348	173	30G
0005435319594	5348	174	30F
0005433719141	5348	175	30J
0005435380312	5348	176	30H
0005434344603	5348	177	31A
0005435614967	5348	178	30K
0005434344626	5348	179	31D
0005435425181	5348	180	31C
0005434245112	5348	181	31B
0005435614874	5348	182	31F
0005435614893	5348	183	31E
0005435614957	5348	184	31H
0005435614964	5348	185	31G
0005432047592	5348	186	31J
0005435614980	5348	187	32C
0005435380297	5348	188	32A
0005435425082	5348	189	32E
0005435614921	5348	190	32D
0005435319590	5348	191	32G
0005435614935	5348	192	32F
0005435614968	5348	193	32K
0005433719159	5348	194	33A
0005435302200	5348	195	33D
0005434245012	5348	196	33E
0005435614886	5348	197	33H
0005434573509	5348	198	33G
0005435614974	5348	199	33K
0005435305025	5348	200	33J
0005435614879	5348	201	34A
0005434344632	5348	202	34E
0005435614896	5348	203	34D
0005434245111	5348	204	34C
0005435614951	5348	205	34G
0005434573515	5348	206	34F
0005434344605	5348	207	34K
0005435425047	5348	208	34J
0005435614944	5348	209	35B
0005435614892	5348	210	35E
0005435614992	5348	211	35D
0005435425178	5348	212	35F
0005435614988	5348	213	35H
0005435425115	5348	214	35G
0005432133381	5348	215	36A
0005435424977	5348	216	35J
0005435614997	5348	217	36C
0005435425038	5348	218	36B
0005435614881	5348	219	36F
0005434245049	5348	220	36D
0005435425177	5348	221	36G
0005434344611	5348	222	36J
0005435614958	5348	223	36H
0005434344620	5348	224	37B
0005435614963	5348	225	37A
0005435614910	5348	226	36K
0005434344613	5348	227	37D
0005434245113	5348	228	37C
0005435614941	5348	229	37F
0005435614955	5348	230	37E
0005435614961	5348	231	37J
0005435614940	5348	232	37H
0005435424952	5348	233	37G
0005435555392	5348	234	38A
0005435614884	5348	235	37K
0005435614907	5348	236	38B
0005434573516	5348	237	38H
0005435097320	5348	238	39B
0005432133380	5348	239	39A
0005434344602	5348	240	39D
0005435425220	5348	241	39C
0005434344607	5348	242	39F
0005434573510	5348	243	39E
0005435614945	5348	244	39H
0005434344615	5348	245	40A
0005435614946	5348	246	39K
0005435614891	5348	247	39J
0005434244965	5348	248	40C
0005435490268	5348	249	40B
0005435614902	5348	250	40E
0005435424961	5348	251	40D
0005434245044	5348	252	40H
0005435614919	5348	253	40G
0005435425066	5348	254	40F
0005434245085	5348	255	40J
0005434245037	5348	256	41B
0005435614954	5348	257	41D
0005434245048	5348	258	41C
0005432133385	5348	259	41F
0005434344622	5348	260	41E
0005435614915	5348	261	41J
0005435614977	5348	262	41H
0005435614920	5348	263	41G
0005435614981	5348	264	42A
0005435097317	5348	265	41K
0005435319622	5348	266	42C
0005435614982	5348	267	42B
0005435424999	5348	268	42F
0005435425114	5348	269	42E
0005435614984	5348	270	42D
0005434245036	5348	271	42G
0005435302224	5348	272	42K
0005435424951	5348	273	42H
0005435614878	5348	274	43A
0005435425065	5348	275	43C
0005435614912	5348	276	43B
0005435614983	5348	277	43F
0005435614917	5348	278	43D
0005434573511	5348	279	43H
0005435614995	5348	280	43G
0005435097318	5348	281	44A
0005435614930	5348	282	43K
0005435614934	5348	283	44C
0005435614880	5348	284	44E
0005435614936	5348	285	44D
0005435614883	5348	286	44G
0005435614931	5348	287	44F
0005435614949	5348	288	44K
0005435097312	5348	289	44J
0005435614924	5348	290	45A
0005435614952	5348	291	45D
0005435614889	5348	292	45B
0005432133375	5348	293	45F
0005434344621	5348	294	45J
0005435424936	5348	295	45G
0005435614903	5348	296	45K
0005435614959	5348	297	46C
0005435380316	5348	298	46B
0005435490271	5348	299	46A
0005432133389	5348	300	46E
0005435319579	5348	301	46D
0005435424983	5348	302	46G
0005435491461	5348	303	46F
0005435425103	5348	304	46K
0005435614885	5348	305	46H
0005435424666	5348	306	47C
0005435491460	5348	307	47A
0005434656562	5348	308	47E
0005435424965	5348	309	47G
0005435424904	5348	310	47F
0005435425098	5348	311	47K
0005434573514	5348	312	47H
0005435614898	5348	313	48C
0005435614904	5348	314	48A
0005434245123	5348	315	48E
0005434245091	5348	316	48H
0005435425124	5348	317	48F
0005435425140	5348	318	49A
0005435319592	5348	319	49D
0005435614979	5348	320	49C
0005435614928	5348	321	49F
0005435424855	5348	322	49E
0005435614909	5348	323	49K
0005435424833	5348	324	49G
0005433719153	5348	325	50C
0005435614926	5348	326	50A
0005432133386	5348	327	50G
0005434344606	5348	328	51D
0005434573512	5348	329	50H
0005435614962	5348	330	51F
0005432133379	5348	331	51E
0005435425007	5348	332	51G
0005435425599	10912	1	1C
0005435425606	10912	2	1D
0005435490240	10912	3	2A
0005435490230	10912	4	1K
0005435425566	10912	5	2C
0005435617234	10912	6	2G
0005435614580	10912	7	3C
0005435425608	10912	8	3D
0005435425586	10912	9	3K
0005435319670	10912	10	3H
0005435613860	10912	11	4C
0005435614126	10912	12	4A
0005434573324	10912	13	4D
0005435319673	10912	14	4K
0005435425569	10912	15	4H
0005435613619	10912	16	5A
0005434344193	10912	17	5D
0005435319676	10912	18	11A
0005435490238	10912	19	5K
0005434245318	10912	20	11D
0005434344281	10912	21	11C
0005435613997	10912	22	11F
0005435425572	10912	23	11E
0005434344392	10912	24	11K
0005434344274	10912	25	12C
0005435614007	10912	26	12E
0005435097225	10912	27	12D
0005434344341	10912	28	12H
0005435425556	10912	29	12F
0005434245317	10912	30	13A
0005435425554	10912	31	13D
0005435097229	10912	32	13C
0005432165126	10912	33	13E
0005432363454	10912	34	13H
0005435305035	10912	35	13G
0005435614083	10912	36	14A
0005435613996	10912	37	13K
0005435490231	10912	38	14E
0005435490241	10912	39	14G
0005434245313	10912	40	14F
0005435425618	10912	41	14H
0005435425559	10912	42	15C
0005434344254	10912	43	15A
0005434344362	10912	44	14K
0005435425578	10912	45	15F
0005435613932	10912	46	15E
0005435425600	10912	47	15D
0005435097212	10912	48	15H
0005432841037	10912	49	15K
0005435425605	10912	50	16C
0005435380344	10912	51	16A
0005435614009	10912	52	16F
0005435425611	10912	53	16E
0005435319668	10912	54	16K
0005435380342	10912	55	17A
0005435613809	10912	56	17E
0005432165121	10912	57	17C
0005435613533	10912	58	17G
0005435613504	10912	59	17F
0005435490227	10912	60	17K
0005435425612	10912	61	17H
0005432165127	10912	62	18A
0005435613770	10912	63	18E
0005435425577	10912	64	18C
0005434573386	10912	65	18H
0005435613771	10912	66	18G
0005435613569	10912	67	18F
0005434573375	10912	68	18J
0005435425610	10912	69	18K
0005435613822	10912	70	19D
0005435614082	10912	71	19C
0005435614129	10912	72	19B
0005435614519	10912	73	19F
0005435425619	10912	74	19H
0005434573296	10912	75	19G
0005435425613	10912	76	20A
0005434344179	10912	77	20C
0005435613841	10912	78	20B
0005435097224	10912	79	20E
0005435614111	10912	80	20F
0005434344258	10912	81	20J
0005434344270	10912	82	20H
0005435614016	10912	83	21B
0005435097190	10912	84	21A
0005435614181	10912	85	20K
0005435425561	10912	86	21D
0005435614276	10912	87	21C
0005435097213	10912	88	21F
0005435614146	10912	89	21E
0005434344301	10912	90	21G
0005435614389	10912	91	22D
0005435319674	10912	92	22C
0005435425609	10912	93	22B
0005435614125	10912	94	22F
0005435613373	10912	95	22E
0005435614548	10912	96	22H
0005435613498	10912	97	22G
0005435613842	10912	98	22K
0005435097220	10912	99	22J
0005435304205	10912	100	23B
0005435425598	10912	101	23A
0005435613887	10912	102	23D
0005435614283	10912	103	23C
0005435614404	10912	104	23F
0005435425603	10912	105	23E
0005435425616	10912	106	23H
0005434245308	10912	107	23G
0005434573370	10912	108	24D
0005435425570	10912	109	23K
0005435613632	10912	110	24F
0005435614390	10912	111	24E
0005435425558	10912	112	25B
0005435380341	10912	113	25A
0005435425551	10912	114	24G
0005435613561	10912	115	25D
0005432166938	10912	116	25C
0005435319675	10912	117	25E
0005435425573	10912	118	25H
0005434245302	10912	119	25G
0005432363452	10912	120	25F
0005435425557	10912	121	25K
0005434573387	10912	122	26B
0005435614356	10912	123	26E
0005435425591	10912	124	26D
0005435614074	10912	125	26C
0005435425574	10912	126	26G
0005435425560	10912	127	26F
0005435617172	10912	128	26H
0005435614254	10912	129	27B
0005435425575	10912	130	27D
0005435613783	10912	131	27F
0005435425595	10912	132	27E
0005435490239	10912	133	27H
0005435425601	10912	134	27G
0005435614224	10912	135	27K
0005435425576	10912	136	27J
0005435613788	10912	137	28C
0005435425580	10912	138	28B
0005435614520	10912	139	28A
0005435613908	10912	140	28E
0005432165123	10912	141	28D
0005435613653	10912	142	28G
0005432165125	10912	143	28K
0005435380340	10912	144	28J
0005434245321	10912	145	28H
0005434245304	10912	146	29A
0005435614097	10912	147	29D
0005434344178	10912	148	29B
0005434245316	10912	149	29F
0005435425614	10912	150	29E
0005435613840	10912	151	29H
0005435425565	10912	152	29G
0005435613838	10912	153	29J
0005434245303	10912	154	30B
0005434573351	10912	155	30A
0005435613831	10912	156	30J
0005434245301	10912	157	30H
0005433719179	10912	158	31A
0005435425583	10912	159	31D
0005434344142	10912	160	31C
0005434344205	10912	161	31F
0005435614284	10912	162	31E
0005435613659	10912	163	31H
0005435304207	10912	164	31G
0005435425585	10912	165	31K
0005435425593	10912	166	31J
0005435425617	10912	167	32C
0005432166939	10912	168	32A
0005435614089	10912	169	32E
0005434656579	10912	170	32D
0005434245297	10912	171	32G
0005435613652	10912	172	32F
0005435614436	10912	173	32K
0005435425604	10912	174	32J
0005435319669	10912	175	32H
0005435614547	10912	176	33B
0005434344262	10912	177	33A
0005435613473	10912	178	33D
0005435613786	10912	179	33C
0005434245299	10912	180	33E
0005435319671	10912	181	33J
0005432841036	10912	182	33H
0005434344302	10912	183	33G
0005435614392	10912	184	33K
0005435614100	10912	185	34B
0005434245312	10912	186	34A
0005434344250	10912	187	34E
0005435614249	10912	188	34G
0005435425555	10912	189	34F
0005435425596	10912	190	34J
0005435425564	10912	191	34H
0005435304208	10912	192	35B
0005434245319	10912	193	35A
0005435425587	10912	194	35D
0005435614189	10912	195	35C
0005435614040	10912	196	35F
0005435097226	10912	197	35E
0005432165122	10912	198	35G
0005435614110	10912	199	35K
0005435490228	10912	200	35J
0005435614190	10912	201	36C
0005432841038	10912	202	36B
0005434344277	10912	203	36F
0005433719180	10912	204	36E
0005432165128	10912	205	36D
0005434344278	10912	206	36G
0005435614434	10912	207	36K
0005434344276	10912	208	36J
0005435614521	10912	209	36H
0005434344235	10912	210	37C
0005435613444	10912	211	37B
0005435380343	10912	212	37A
0005435613534	10912	213	37D
0005435614522	10912	214	37G
0005435425571	10912	215	37F
0005435613722	10912	216	37E
0005435614099	10912	217	37H
0005435425588	10912	218	37K
0005435614101	10912	219	38C
0005435614157	10912	220	38K
0005435097239	10912	221	38J
0005434344187	10912	222	38H
0005434344340	10912	223	39B
0005435304203	10912	224	39A
0005435614258	10912	225	39C
0005435614546	10912	226	39F
0005434245309	10912	227	39H
0005432363453	10912	228	39G
0005435097228	10912	229	40A
0005434245307	10912	230	39K
0005435613620	10912	231	39J
0005434344363	10912	232	40C
0005435380339	10912	233	40B
0005434245314	10912	234	40E
0005435614508	10912	235	40D
0005435614064	10912	236	40G
0005435613782	10912	237	40K
0005434245311	10912	238	40J
0005435613821	10912	239	40H
0005435614545	10912	240	41B
0005435613931	10912	241	41A
0005435613592	10912	242	41D
0005435304206	10912	243	41C
0005435614435	10912	244	41E
0005435613883	10912	245	41J
0005435613753	10912	246	41G
0005435425567	10912	247	42A
0005435425581	10912	248	41K
0005435614271	10912	249	42B
0005435425563	10912	250	42E
0005434344275	10912	251	42D
0005435613503	10912	252	42F
0005434245315	10912	253	43B
0005435425615	10912	254	43A
0005434245298	10912	255	42K
0005435425589	10912	256	43D
0005434573371	10912	257	43C
0005435613402	10912	258	43F
0005434245305	10912	259	43E
0005434344249	10912	260	43H
0005432166940	10912	261	43G
0005434573379	10912	262	44A
0005432165124	10912	263	43K
0005435097205	10912	264	43J
0005435425607	10912	265	44E
0005435613861	10912	266	44D
0005435613690	10912	267	44C
0005435613660	10912	268	44G
0005435613794	10912	269	44H
0005434344267	10912	270	45A
0005435425584	10912	271	45D
0005435614008	10912	272	45C
0005435425552	10912	273	45F
0005435613562	10912	274	45E
0005435614250	10912	275	45J
0005435425590	10912	276	45H
0005435613737	10912	277	45G
0005435425562	10912	278	46C
0005435614139	10912	279	46B
0005435425620	10912	280	46D
0005435617171	10912	281	46G
0005435097231	10912	282	46F
0005435613621	10912	283	46J
0005434245322	10912	284	46H
0005434245306	10912	285	47D
0005435613967	10912	286	47C
0005434344096	10912	287	47G
0005434245324	10912	288	48A
0005435425594	10912	289	47K
0005435319672	10912	290	47H
0005434245300	10912	291	48C
0005434245325	10912	292	48F
0005435614263	10912	293	48E
0005435425602	10912	294	48D
0005435425592	10912	295	48H
0005435425582	10912	296	48G
0005435613909	10912	297	49A
0005434656578	10912	298	49D
0005434245326	10912	299	49C
0005434344400	10912	300	49F
0005435425553	10912	301	49E
0005435425597	10912	302	49H
0005434245320	10912	303	50C
0005433719181	10912	304	49K
0005435425579	10912	305	50E
0005435613862	10912	306	50D
0005435425568	10912	307	50H
0005435614514	10912	308	50G
0005434245323	10912	309	51D
0005435304204	10912	310	51F
0005435613738	10912	311	51E
0005434245310	10912	312	51G
0005433805770	3391	1	1A
0005432459791	3391	2	1C
0005433805775	3391	3	1F
0005433507377	3391	4	1D
0005433805780	3391	5	2A
0005432459875	3391	6	2C
0005432459924	3391	7	2F
0005432459889	3391	8	2D
0005433634210	3391	9	3A
0005432459696	3391	10	3D
0005433634212	3391	11	3C
0005432459945	3391	12	3F
0005433805763	3391	13	4A
0005432460024	3391	14	4D
0005432181965	3391	15	4C
0005432459891	3391	16	4F
0005432460018	3391	17	5C
0005432460108	3391	18	5F
0005433634208	3391	19	5D
0005433805772	3391	20	6A
0005433805758	3391	21	6C
0005433634197	3391	22	6F
0005433634194	3391	23	6D
0005432459788	3391	24	7A
0005433805769	3391	25	7D
0005433805779	3391	26	7C
0005432459955	3391	27	8A
0005433634217	3391	28	8B
0005432459870	3391	29	8C
0005432459933	3391	30	8E
0005432181976	3391	31	8D
0005433507386	3391	32	9A
0005432459900	3391	33	8F
0005432181960	3391	34	9B
0005433634198	3391	35	9C
0005433805759	3391	36	9E
0005433805782	3391	37	9D
0005433634195	3391	38	9F
0005432460021	3391	39	10A
0005433805771	3391	40	10B
0005433507383	3391	41	10C
0005433634220	3391	42	10E
0005432459966	3391	43	10D
0005433805786	3391	44	10F
0005432460030	3391	45	11B
0005432181974	3391	46	11A
0005432460042	3391	47	11C
0005433805764	3391	48	11D
0005433805785	3391	49	11E
0005432459976	3391	50	12A
0005433634219	3391	51	11F
0005433634222	3391	52	12B
0005433805778	3391	53	12D
0005433634216	3391	54	12C
0005433507380	3391	55	12E
0005433634203	3391	56	12F
0005433634193	3391	57	13A
0005433634209	3391	58	13C
0005433805768	3391	59	13D
0005432460131	3391	60	13E
0005432460085	3391	61	14A
0005432460049	3391	62	13F
0005433634196	3391	63	14B
0005432460064	3391	64	14D
0005432460043	3391	65	14C
0005433634204	3391	66	14F
0005433805788	3391	67	15C
0005433507391	3391	68	15B
0005433507378	3391	69	15E
0005432181967	3391	70	15D
0005432459985	3391	71	16A
0005433634223	3391	72	15F
0005432181975	3391	73	16B
0005432181964	3391	74	16D
0005432459841	3391	75	16C
0005432181959	3391	76	16F
0005432181979	3391	77	16E
0005433634213	3391	78	17A
0005432459967	3391	79	17B
0005433507381	3391	80	17C
0005433805773	3391	81	17D
0005433805757	3391	82	17E
0005432459836	3391	83	18A
0005432181966	3391	84	17F
0005433805761	3391	85	18C
0005432181958	3391	86	18B
0005432459932	3391	87	18D
0005433634202	3391	88	18E
0005432181963	3391	89	18F
0005433805774	3391	90	19C
0005433805765	3391	91	19B
0005432459744	3391	92	19E
0005433634206	3391	93	19D
0005433634190	3391	94	20A
0005432181971	3391	95	20B
0005433507388	3391	96	20C
0005433805753	3391	97	20D
0005432460044	3391	98	20F
0005432181973	3391	99	20E
0005433634224	3391	100	21A
0005433634200	3391	101	21B
0005433507384	3391	102	21D
0005432460167	3391	103	21C
0005433634205	3391	104	21E
0005433805784	3391	105	21F
0005433805755	3391	106	22B
0005432460086	3391	107	22A
0005432459862	3391	108	22C
0005432459678	3391	109	22E
0005433634191	3391	110	23B
0005432459974	3391	111	23A
0005433634214	3391	112	23C
0005432460050	3391	113	23D
0005432181972	3391	114	23E
0005432460029	3391	115	23F
0005433507387	3391	116	24B
0005432460020	3391	117	24A
0005433805752	3391	118	24C
0005433507389	3391	119	24E
0005433805776	3391	120	24D
0005433805783	3391	121	25A
0005432460048	3391	122	24F
0005432181978	3391	123	25C
0005433805754	3391	124	25B
0005432459954	3391	125	25D
0005432459878	3391	126	25F
0005433634199	3391	127	25E
0005432459813	3391	128	26A
0005433634207	3391	129	26B
0005433634218	3391	130	26C
0005432460058	3391	131	26E
0005433507379	3391	132	26D
0005432459986	3391	133	27A
0005432459802	3391	134	26F
0005432181970	3391	135	27B
0005432459946	3391	136	27C
0005433634211	3391	137	27D
0005432181969	3391	138	27F
0005433805762	3391	139	27E
0005433634215	3391	140	28A
0005433805760	3391	141	28B
0005433634201	3391	142	28C
0005433805781	3391	143	28D
0005432460094	3391	144	28F
0005432459965	3391	145	28E
0005432181968	3391	146	29B
0005433634192	3391	147	29A
0005432459956	3391	148	29C
0005433805766	3391	149	29D
0005432181962	3391	150	29F
0005433507382	3391	151	29E
0005433805767	3391	152	30A
0005433805777	3391	153	30B
0005433805756	3391	154	30C
0005432181977	3391	155	30E
0005433634221	3391	156	30D
0005432459890	3391	157	30F
0005432181961	3391	158	31B
0005433805787	3391	159	31A
0005433507390	3391	160	31D
0005433507385	3391	161	31C
0005433507392	3391	162	31F
0005432459977	3391	163	31E
0005435885376	3390	1	1C
0005435885549	3390	2	1F
0005435885340	3390	3	2A
0005435885347	3390	4	2F
0005435885339	3390	5	5C
0005435885605	3390	6	6A
0005435885326	3390	7	6F
0005435885407	3390	8	7D
0005435885272	3390	9	8E
0005435885348	3390	10	9A
0005435885606	3390	11	9D
0005435885454	3390	12	10C
0005435885423	3390	13	10D
0005435885545	3390	14	13B
0005435885463	3390	15	13D
0005435885548	3390	16	13F
0005435885414	3390	17	14F
0005435885386	3390	18	15B
0005435885351	3390	19	15F
0005435885390	3390	20	16A
0005435885546	3390	21	16C
0005435885460	3390	22	16E
0005435885333	3390	23	17A
0005435885559	3390	24	17B
0005435885550	3390	25	17E
0005435885484	3390	26	18B
0005435885691	3390	27	19B
0005435885391	3390	28	20F
0005435885312	3390	29	21A
0005435885551	3390	30	21C
0005435885406	3390	31	21B
0005435885476	3390	32	21D
0005435885313	3390	33	22C
0005435885499	3390	34	22E
0005435885269	3390	35	23A
0005435885572	3390	36	23D
0005435885319	3390	37	23E
0005435885594	3390	38	24C
0005435885389	3390	39	26A
0005435885282	3390	40	26D
0005435885401	3390	41	26E
0005435885358	3390	42	27D
0005435885381	3390	43	27E
0005435885485	3390	44	28C
0005435885547	3390	45	28E
0005435885602	3390	46	28F
0005435885352	3390	47	29B
0005435885577	3390	48	29A
0005435885405	3390	49	29C
0005435885573	3390	50	30A
0005435885320	3390	51	29F
0005435885560	3390	52	30B
0005435885314	3390	53	30C
0005435885395	3390	54	31C
0005435885422	3390	55	31E
0005432460475	8167	1	1F
0005435885824	8167	2	1D
0005435885804	8167	3	2C
0005432460501	8167	4	2F
0005433507200	8167	5	2D
0005432042878	8167	6	3A
0005432460505	8167	7	3D
0005432460468	8167	8	3C
0005433507190	8167	9	3F
0005432460504	8167	10	4A
0005432460491	8167	11	4D
0005432460464	8167	12	4C
0005432460479	8167	13	4F
0005432460460	8167	14	5A
0005435885813	8167	15	5C
0005432460474	8167	16	5F
0005435885829	8167	17	5D
0005435885817	8167	18	6A
0005435885833	8167	19	6F
0005433507197	8167	20	7F
0005432460482	8167	21	7D
0005432042873	8167	22	8A
0005434312345	8167	23	8C
0005432460454	8167	24	8B
0005432460457	8167	25	8D
0005432460502	8167	26	8F
0005435885835	8167	27	9B
0005433507103	8167	28	9A
0005435885805	8167	29	9C
0005432460478	8167	30	9E
0005433507199	8167	31	9D
0005432460498	8167	32	10A
0005432460483	8167	33	9F
0005432460463	8167	34	10B
0005435885802	8167	35	10C
0005432460492	8167	36	10D
0005434312344	8167	37	10F
0005433507189	8167	38	11A
0005432460496	8167	39	11C
0005435885801	8167	40	11E
0005432460461	8167	41	11D
0005432460456	8167	42	11F
0005432460487	8167	43	12B
0005433507196	8167	44	12D
0005432460494	8167	45	12C
0005432460489	8167	46	12E
0005432042874	8167	47	12F
0005432460467	8167	48	13B
0005435885825	8167	49	13A
0005433507210	8167	50	13C
0005432460476	8167	51	13D
0005433507211	8167	52	13E
0005432460473	8167	53	14C
0005435885822	8167	54	14B
0005435885803	8167	55	14D
0005433507194	8167	56	14E
0005432042869	8167	57	15B
0005432042871	8167	58	15C
0005435885806	8167	59	15E
0005432460470	8167	60	15D
0005435885820	8167	61	16A
0005432042867	8167	62	15F
0005435885799	8167	63	16C
0005432042877	8167	64	16E
0005432460462	8167	65	16F
0005435885834	8167	66	17A
0005432042876	8167	67	17C
0005432042868	8167	68	17D
0005432460495	8167	69	17F
0005432460481	8167	70	17E
0005433507232	8167	71	18A
0005432460486	8167	72	18C
0005432042866	8167	73	18B
0005432460458	8167	74	18D
0005432460500	8167	75	18E
0005435885819	8167	76	18F
0005432460485	8167	77	19C
0005435885808	8167	78	19B
0005433507120	8167	79	19D
0005432460490	8167	80	19E
0005432460488	8167	81	20C
0005435885826	8167	82	20B
0005435885821	8167	83	21C
0005435885811	8167	84	21B
0005432460484	8167	85	21D
0005432042870	8167	86	21E
0005432460472	8167	87	22A
0005432460469	8167	88	22B
0005432460471	8167	89	22C
0005433507226	8167	90	22F
0005435885828	8167	91	23B
0005432460480	8167	92	23A
0005433507195	8167	93	23C
0005435885818	8167	94	23D
0005435885812	8167	95	23E
0005432460503	8167	96	24B
0005432460497	8167	97	24C
0005433507233	8167	98	24D
0005433507192	8167	99	24F
0005432460459	8167	100	25A
0005433507130	8167	101	25C
0005432460453	8167	102	25B
0005435885827	8167	103	25D
0005435885823	8167	104	25E
0005435885832	8167	105	26A
0005435885814	8167	106	26B
0005435885800	8167	107	26C
0005432042872	8167	108	26E
0005435885831	8167	109	27A
0005432042879	8167	110	27D
0005432460499	8167	111	27E
0005435885815	8167	112	28B
0005435885816	8167	113	28E
0005432460455	8167	114	28F
0005432460466	8167	115	29B
0005435885809	8167	116	29A
0005432042875	8167	117	29C
0005433507102	8167	118	30A
0005435885810	8167	119	29F
0005432460477	8167	120	30C
0005432460493	8167	121	30E
0005435885830	8167	122	31A
0005432460465	8167	123	31D
0005435885807	8167	124	31F
0005433805476	8325	1	1A
0005433633776	8325	2	1F
0005433633982	8325	3	2A
0005433633837	8325	4	2D
0005433805479	8325	5	4A
0005433634050	8325	6	4C
0005433634033	8325	7	5A
0005433805660	8325	8	5C
0005433805457	8325	9	6D
0005433805279	8325	10	7D
0005433633753	8325	11	8A
0005433633887	8325	12	8C
0005433805380	8325	13	8D
0005433633772	8325	14	9B
0005433805546	8325	15	9D
0005433633853	8325	16	10A
0005433634094	8325	17	10B
0005433634001	8325	18	10E
0005433805386	8325	19	10F
0005433633958	8325	20	11B
0005433633708	8325	21	11D
0005433805632	8325	22	11F
0005433805278	8325	23	12B
0005433633907	8325	24	12F
0005433633891	8325	25	13B
0005433633906	8325	26	13D
0005433633963	8325	27	13E
0005433805553	8325	28	14E
0005433633913	8325	29	15C
0005433805493	8325	30	15D
0005433805385	8325	31	16A
0005434271321	8325	32	16D
0005434271320	8325	33	17A
0005433805363	8325	34	17E
0005433633886	8325	35	18B
0005434271305	8325	36	18E
0005433805373	8325	37	18F
0005433805571	8325	38	20A
0005433805478	8325	39	20B
0005433633890	8325	40	21B
0005433633833	8325	41	21D
0005433805537	8325	42	22B
0005433805381	8325	43	22A
0005433805545	8325	44	22C
0005433805588	8325	45	23A
0005433633852	8325	46	23F
0005433805525	8325	47	23E
0005433633884	8325	48	24E
0005433805465	8325	49	25A
0005433805554	8325	50	25B
0005433805475	8325	51	25F
0005433633856	8325	52	26B
0005433805456	8325	53	26D
0005433805472	8325	54	27A
0005433633929	8325	55	27D
0005433633682	8325	56	29B
0005433633752	8325	57	29C
0005434271306	8325	58	29E
0005433633966	8325	59	30A
0005433633707	8325	60	31C
0005433722296	4621	1	1D
0005432383618	4621	2	2A
0005432383623	4621	3	2C
0005432383632	4621	4	2F
0005432383614	4621	5	3C
0005432728082	4621	6	3F
0005433454899	4621	7	4C
0005433722297	4621	8	4D
0005432383627	4621	9	4F
0005432383624	4621	10	5A
0005433454900	4621	11	5C
0005432728086	4621	12	5D
0005432383634	4621	13	5F
0005433722302	4621	14	6A
0005432728077	4621	15	6C
0005432728076	4621	16	6E
0005433453783	4621	17	6F
0005432383628	4621	18	7C
0005432728080	4621	19	7D
0005432383638	4621	20	7E
0005432383610	4621	21	8D
0005433722298	4621	22	9A
0005433722300	4621	23	9C
0005432383633	4621	24	9E
0005432728083	4621	25	9F
0005432383612	4621	26	10A
0005433722301	4621	27	10C
0005432383611	4621	28	10D
0005433453782	4621	29	10E
0005432383616	4621	30	11C
0005432383621	4621	31	11D
0005433722299	4621	32	11E
0005432383635	4621	33	11F
0005432383617	4621	34	12A
0005432383637	4621	35	12C
0005432728085	4621	36	12E
0005432383620	4621	37	12F
0005433453784	4621	38	13A
0005432728084	4621	39	14A
0005432728078	4621	40	14D
0005432728081	4621	41	14E
0005432383615	4621	42	14F
0005432383629	4621	43	15A
0005432383625	4621	44	15C
0005432383626	4621	45	17C
0005432383636	4621	46	17D
0005432383613	4621	47	17E
0005432383631	4621	48	17F
0005433722294	4621	49	18A
0005432383609	4621	50	18D
0005432728075	4621	51	18E
0005432383622	4621	52	18F
0005432728074	4621	53	19A
0005432383619	4621	54	19C
0005432383630	4621	55	19D
0005433722295	4621	56	20C
0005432728079	4621	57	20F
0005432383041	30252	1	1D
0005432383226	30252	2	2A
0005433453765	30252	3	2D
0005433453766	30252	4	3A
0005432383113	30252	5	3C
0005432382971	30252	6	3F
0005432383197	30252	7	4D
0005432383254	30252	8	4E
0005432383155	30252	9	5C
0005432382918	30252	10	5E
0005432383129	30252	11	5F
0005433194870	30252	12	6C
0005432727957	30252	13	6D
0005432383064	30252	14	6F
0005432727966	30252	15	7A
0005433722204	30252	16	7C
0005432383163	30252	17	7E
0005433722206	30252	18	7F
0005432383136	30252	19	8A
0005432382919	30252	20	8D
0005432727994	30252	21	9A
0005432727967	30252	22	9C
0005432383321	30252	23	9D
0005432727995	30252	24	9E
0005432727959	30252	25	9F
0005432383158	30252	26	10A
0005432383118	30252	27	10C
0005432383160	30252	28	10E
0005432727941	30252	29	10F
0005432383035	30252	30	11D
0005432383119	30252	31	11E
0005432383309	30252	32	12D
0005432727964	30252	33	12F
0005433722205	30252	34	13A
0005432727948	30252	35	13C
0005432383200	30252	36	13E
0005432383115	30252	37	13F
0005432383240	30252	38	14A
0005432727947	30252	39	14C
0005432383156	30252	40	14D
0005432727896	30252	41	14E
0005433453767	30252	42	14F
0005432383201	30252	43	15A
0005432727968	30252	44	15C
0005432383114	30252	45	16A
0005432383227	30252	46	16C
0005432727945	30252	47	16D
0005432383218	30252	48	16E
0005432383270	30252	49	16F
0005432383320	30252	50	17C
0005432383157	30252	51	17D
0005432727985	30252	52	17E
0005432383036	30252	53	17F
0005432382988	30252	54	18A
0005432383161	30252	55	18C
0005432727983	30252	56	18D
0005432383332	30252	57	19A
0005432383072	30252	58	18F
0005433722200	30252	59	19C
0005432727996	30252	60	19E
0005432383331	30252	61	19F
0005432383192	30252	62	20A
0005432383217	30252	63	20D
0005432382972	30252	64	20F
0005435529515	1753	1	1A
0005435529501	1753	2	1C
0005435529513	1753	3	1F
0005433516989	1753	4	2A
0005435529517	1753	5	2C
0005435541251	1753	6	3A
0005435529516	1753	7	3D
0005435541263	1753	8	3F
0005435541258	1753	9	4D
0005432294515	1753	10	4E
0005435541264	1753	11	4F
0005435541250	1753	12	5C
0005435541244	1753	13	5D
0005433516996	1753	14	5E
0005435541254	1753	15	5F
0005432925050	1753	16	6A
0005433516998	1753	17	6D
0005432294514	1753	18	6E
0005435529512	1753	19	6F
0005435541262	1753	20	7A
0005435529499	1753	21	7C
0005435541248	1753	22	7D
0005435541260	1753	23	7F
0005435541249	1753	24	8A
0005435529519	1753	25	8C
0005433516995	1753	26	8E
0005435541247	1753	27	8F
0005435529510	1753	28	9A
0005433516994	1753	29	9D
0005433516993	1753	30	9F
0005435541261	1753	31	10A
0005435541245	1753	32	10C
0005435529505	1753	33	10F
0005435529504	1753	34	11A
0005435541259	1753	35	11C
0005435529509	1753	36	11D
0005435529502	1753	37	11F
0005435529507	1753	38	12C
0005432925048	1753	39	12E
0005435541246	1753	40	12F
0005435541252	1753	41	13A
0005433516992	1753	42	13C
0005435541243	1753	43	13D
0005435529508	1753	44	13E
0005432925037	1753	45	14A
0005435541253	1753	46	14D
0005435529503	1753	47	14E
0005435529518	1753	48	14F
0005433516997	1753	49	16A
0005432925039	1753	50	16C
0005435541257	1753	51	16D
0005435529520	1753	52	16E
0005433516991	1753	53	18C
0005435529500	1753	54	18D
0005435541256	1753	55	18E
0005435541255	1753	56	18F
0005435529506	1753	57	19A
0005432925026	1753	58	19E
0005433516990	1753	59	20A
0005435529514	1753	60	20C
0005435529511	1753	61	20F
0005435517976	22023	1	1C
0005433516887	22023	2	1D
0005435541125	22023	3	1F
0005435517928	22023	4	2F
0005435518011	22023	5	3A
0005432925090	22023	6	4A
0005435517952	22023	7	4D
0005435517989	22023	8	5F
0005435540931	22023	9	6C
0005432925092	22023	10	6D
0005435540983	22023	11	6E
0005433516893	22023	12	6F
0005435540982	22023	13	7A
0005433516913	22023	14	7C
0005435541069	22023	15	7D
0005435517964	22023	16	7E
0005435541065	22023	17	8A
0005435517907	22023	18	8D
0005435541147	22023	19	9D
0005433516960	22023	20	9E
0005433516902	22023	21	10F
0005433516924	22023	22	11D
0005435541064	22023	23	12A
0005435517962	22023	24	12D
0005432925093	22023	25	12F
0005433516890	22023	26	13E
0005433516938	22023	27	14C
0005435541051	22023	28	14D
0005435517963	22023	29	14E
0005435541050	22023	30	15F
0005435540974	22023	31	16D
0005435517873	22023	32	16E
0005435517906	22023	33	17D
0005435541048	22023	34	17C
0005433516925	22023	35	17E
0005435541049	22023	36	18C
0005433516937	22023	37	18E
0005432925091	22023	38	19E
0005435517889	22023	39	20A
0005435517929	22023	40	20D
0005432839380	7390	1	1A
0005434459038	7390	2	1C
0005432073430	7390	3	1D
0005432073431	7390	4	1F
0005432839391	7390	5	2C
0005434459044	7390	6	2D
0005434459042	7390	7	3A
0005432823470	7390	8	2F
0005432073429	7390	9	3C
0005435252772	7390	10	3D
0005432841034	7390	11	3F
0005435491445	7390	12	4A
0005432839402	7390	13	4E
0005432823471	7390	14	4F
0005432839384	7390	15	5A
0005432839403	7390	16	5C
0005432839394	7390	17	5D
0005434664964	7390	18	5E
0005432839374	7390	19	5F
0005432839397	7390	20	6A
0005432839399	7390	21	6C
0005432839378	7390	22	6D
0005434459045	7390	23	6E
0005435252688	7390	24	6F
0005432839386	7390	25	7A
0005434459037	7390	26	7C
0005432839401	7390	27	7E
0005432839382	7390	28	7F
0005434459031	7390	29	8A
0005435252698	7390	30	8C
0005432839387	7390	31	8D
0005432839389	7390	32	8E
0005434459040	7390	33	8F
0005432839393	7390	34	9A
0005432839373	7390	35	9C
0005432839400	7390	36	9D
0005432839375	7390	37	9E
0005432073428	7390	38	10A
0005434459032	7390	39	10D
0005432839376	7390	40	10E
0005434459047	7390	41	10F
0005435252792	7390	42	11C
0005434459050	7390	43	11F
0005434459039	7390	44	12A
0005435252692	7390	45	12D
0005432839390	7390	46	12E
0005432839388	7390	47	12F
0005434459036	7390	48	13A
0005434459048	7390	49	13D
0005432839379	7390	50	13E
0005434459046	7390	51	13F
0005432839377	7390	52	14A
0005432839381	7390	53	14C
0005435252728	7390	54	14D
0005435252716	7390	55	14E
0005434459041	7390	56	14F
0005435252737	7390	57	15C
0005434459035	7390	58	16A
0005435252733	7390	59	16C
0005435252679	7390	60	16E
0005432839398	7390	61	17A
0005435252732	7390	62	17D
0005432839395	7390	63	17C
0005434664963	7390	64	17E
0005434459033	7390	65	17F
0005432839392	7390	66	18A
0005434459043	7390	67	18C
0005432839396	7390	68	18D
0005434459034	7390	69	18E
0005432841035	7390	70	18F
0005432839383	7390	71	19C
0005434664966	7390	72	19D
0005432823472	7390	73	19E
0005432839385	7390	74	19F
0005434459049	7390	75	20D
0005435252774	7390	76	20F
0005432838985	28938	1	1A
0005432841024	28938	2	1C
0005434664987	28938	3	1F
0005435252912	28938	4	2C
0005432839116	28938	5	2D
0005432839052	28938	6	2F
0005435252911	28938	7	3C
0005435252897	28938	8	3D
0005432839141	28938	9	3F
0005432839078	28938	10	4C
0005432839054	28938	11	4D
0005432841017	28938	12	4E
0005432839203	28938	13	4F
0005432839053	28938	14	5A
0005432841018	28938	15	5D
0005435252909	28938	16	5E
0005435252908	28938	17	5F
0005435252896	28938	18	6A
0005432839086	28938	19	6C
0005432823459	28938	20	6D
0005432839088	28938	21	6E
0005434458838	28938	22	7A
0005432839087	28938	23	7C
0005435252907	28938	24	7D
0005435252895	28938	25	7E
0005432839285	28938	26	7F
0005434458964	28938	27	8A
0005432839223	28938	28	8D
0005432839161	28938	29	8E
0005434458903	28938	30	8F
0005432839252	28938	31	9A
0005432839199	28938	32	9C
0005432001047	28938	33	9D
0005432839202	28938	34	9E
0005435252901	28938	35	9F
0005434458871	28938	36	10A
0005432823460	28938	37	10C
0005435252893	28938	38	10D
0005432839135	28938	39	10E
0005432839051	28938	40	10F
0005432839210	28938	41	11A
0005432839200	28938	42	11C
0005432839222	28938	43	11D
0005432839221	28938	44	11E
0005432839079	28938	45	11F
0005435252902	28938	46	12A
0005432001046	28938	47	12C
0005435252898	28938	48	12D
0005432839128	28938	49	12E
0005434458844	28938	50	12F
0005432839085	28938	51	13A
0005432838984	28938	52	13C
0005435252894	28938	53	13D
0005432841012	28938	54	13E
0005434458864	28938	55	13F
0005435252904	28938	56	14A
0005434458842	28938	57	14C
0005435491464	28938	58	14E
0005435252900	28938	59	14F
0005434458880	28938	60	15A
0005432839115	28938	61	15C
0005432839120	28938	62	15D
0005435252899	28938	63	15E
0005435252906	28938	64	15F
0005434458870	28938	65	16A
0005434458875	28938	66	16C
0005434458843	28938	67	16D
0005435252910	28938	68	16E
0005432839235	28938	69	16F
0005435491463	28938	70	17C
0005434458841	28938	71	17E
0005432839153	28938	72	17F
0005432839129	28938	73	18A
0005432839165	28938	74	18C
0005432839251	28938	75	18E
0005435252905	28938	76	18F
0005434458874	28938	77	19A
0005435491465	28938	78	19C
0005434458910	28938	79	19D
0005434458823	28938	80	19F
0005435252903	28938	81	20A
0005434664988	28938	82	20C
0005432839160	28938	83	20D
0005434458881	28938	84	20E
0005432839140	28938	85	20F
0005434276067	8828	1	4A
0005435990706	8828	2	7C
0005435990707	8828	3	8A
0005434276043	8828	4	9B
0005434276039	8828	5	10C
0005434276066	8828	6	10B
0005434276064	8828	7	12C
0005434276072	8828	8	13A
0005435990704	8828	9	13B
0005435990701	8828	10	14C
0005435990702	8828	11	16C
0005434276044	8828	12	17D
0005434276065	8828	13	17E
0005435990705	8828	14	20F
0005435990703	8828	15	21E
0005434276092	15762	1	4A
0005435990616	15762	2	6B
0005434276089	15762	3	6A
0005434276093	15762	4	6D
0005434276094	15762	5	7B
0005435990649	15762	6	9A
0005434276091	15762	7	9C
0005434276095	15762	8	11F
0005435990648	15762	9	15B
0005435990657	15762	10	15C
0005435990617	15762	11	16D
0005434276090	15762	12	17C
0005435990656	15762	13	21C
0005433468430	2096	1	1A
0005433468434	2096	2	1B
0005433468431	2096	3	1D
0005433468428	2096	4	2A
0005433468435	2096	5	2C
0005432909327	2096	6	2D
0005433468426	2096	7	3B
0005433468442	2096	8	3C
0005433468432	2096	9	5A
0005433468427	2096	10	5C
0005433468440	2096	11	5D
0005432909274	2096	12	6A
0005432909297	2096	13	6B
0005432909276	2096	14	6C
0005433468441	2096	15	6D
0005433468429	2096	16	7A
0005433468439	2096	17	7D
0005432909295	2096	18	18A
0005433468443	2096	19	18C
0005433468437	2096	20	19C
0005432909275	2096	21	19D
0005432909328	2096	22	20A
0005432909311	2096	23	20B
0005432909298	2096	24	20C
0005433468436	2096	25	21A
0005432909296	2096	26	21C
0005432909286	2096	27	22B
0005432909285	2096	28	22C
0005432909282	2096	29	22D
0005433468438	2096	30	23A
0005433468433	2096	31	23B
0005435177133	6409	1	1A
0005432360903	6409	2	1C
0005432360909	6409	3	1F
0005432360894	6409	4	1D
0005435177228	6409	5	2A
0005432360921	6409	6	2F
0005432062291	6409	7	3C
0005432363453	6409	8	3D
0005432360905	6409	9	4A
0005432363454	6409	10	4D
0005432360884	6409	11	4C
0005432336169	6409	12	4E
0005432360912	6409	13	4F
0005432360932	6409	14	5A
0005432336163	6409	15	5C
0005432360916	6409	16	5D
0005432360907	6409	17	5E
0005434149787	6409	18	5F
0005432360891	6409	19	6B
0005432360886	6409	20	6C
0005432363452	6409	21	6D
0005435177131	6409	22	6F
0005432062289	6409	23	6E
0005435177223	6409	24	7B
0005435177103	6409	25	7A
0005432360899	6409	26	7C
0005434149762	6409	27	7E
0005435177063	6409	28	7D
0005435177246	6409	29	8A
0005435177132	6409	30	7F
0005435490231	6409	31	8B
0005432360927	6409	32	8C
0005432336173	6409	33	8E
0005432360926	6409	34	9A
0005432360931	6409	35	9B
0005432360908	6409	36	9D
0005432360911	6409	37	9C
0005432360922	6409	38	9E
0005434149786	6409	39	9F
0005435177123	6409	40	10C
0005432360901	6409	41	10E
0005432360918	6409	42	11A
0005435490228	6409	43	11C
0005432360910	6409	44	11F
0005432360904	6409	45	11E
0005435177012	6409	46	12A
0005432360893	6409	47	12C
0005432360929	6409	48	12E
0005435177272	6409	49	12D
0005432360930	6409	50	12F
0005432062290	6409	51	13A
0005432336170	6409	52	13C
0005432062287	6409	53	13D
0005435490239	6409	54	13E
0005435177234	6409	55	13F
0005432360915	6409	56	14B
0005435177217	6409	57	14A
0005432336175	6409	58	14C
0005435177233	6409	59	14D
0005432336174	6409	60	14E
0005432336171	6409	61	15A
0005435723053	6409	62	14F
0005434149781	6409	63	15B
0005435490238	6409	64	15C
0005435177064	6409	65	15E
0005432360897	6409	66	15D
0005435177178	6409	67	15F
0005435177271	6409	68	16A
0005432360888	6409	69	16B
0005432360902	6409	70	16C
0005432360924	6409	71	16D
0005432336168	6409	72	16F
0005432360895	6409	73	16E
0005432336166	6409	74	17A
0005432360920	6409	75	17D
0005435177136	6409	76	17C
0005432336172	6409	77	17E
0005432360906	6409	78	18A
0005435177258	6409	79	17F
0005432360890	6409	80	18B
0005432360892	6409	81	18D
0005434149743	6409	82	18C
0005432360914	6409	83	18E
0005432360896	6409	84	19A
0005435177110	6409	85	19B
0005432360919	6409	86	19E
0005435177148	6409	87	19D
0005432336167	6409	88	19F
0005432062288	6409	89	20A
0005435723038	6409	90	20C
0005432360925	6409	91	21C
0005432360898	6409	92	21B
0005432360923	6409	93	21D
0005432360887	6409	94	21E
0005432360913	6409	95	21F
0005432336164	6409	96	22A
0005432360917	6409	97	22C
0005435490227	6409	98	22B
0005435490230	6409	99	22D
0005432360900	6409	100	22E
0005432336165	6409	101	23A
0005435490241	6409	102	22F
0005432360928	6409	103	23B
0005432360885	6409	104	23C
0005435723037	6409	105	23D
0005435490240	6409	106	23F
0005432360889	6409	107	23E
0005435177391	20991	1	1A
0005435177384	20991	2	1D
0005434149863	20991	3	2A
0005434149857	20991	4	1F
0005435490274	20991	5	2D
0005432360249	20991	6	2F
0005432363426	20991	7	3C
0005432360531	20991	8	3D
0005435177396	20991	9	3F
0005432360489	20991	10	4A
0005432360416	20991	11	4C
0005434149858	20991	12	4B
0005432360346	20991	13	4E
0005432360377	20991	14	4D
0005434149859	20991	15	4F
0005432360455	20991	16	5A
0005435723070	20991	17	5B
0005435177388	20991	18	5D
0005432336051	20991	19	5C
0005432336040	20991	20	5F
0005435177400	20991	21	5E
0005435177394	20991	22	6B
0005435177382	20991	23	6A
0005432360293	20991	24	6E
0005435177377	20991	25	6D
0005432360537	20991	26	6C
0005435177393	20991	27	7A
0005432360307	20991	28	7C
0005432360396	20991	29	7E
0005435177389	20991	30	8A
0005432360347	20991	31	8B
0005435177383	20991	32	8D
0005432360248	20991	33	8C
0005432360332	20991	34	8E
0005432360707	20991	35	8F
0005432360375	20991	36	9A
0005435177395	20991	37	9C
0005432360695	20991	38	9F
0005432336088	20991	39	9E
0005432360318	20991	40	10B
0005432360391	20991	41	10D
0005432360605	20991	42	10E
0005432360345	20991	43	11A
0005432360571	20991	44	11B
0005432360547	20991	45	11D
0005435177376	20991	46	11C
0005432052781	20991	47	11F
0005432360417	20991	48	11E
0005432360306	20991	49	12B
0005434149865	20991	50	12A
0005434149864	20991	51	12C
0005432360458	20991	52	12E
0005432360418	20991	53	12F
0005432360457	20991	54	13B
0005434149867	20991	55	13C
0005435177380	20991	56	13E
0005434149862	20991	57	13F
0005432360499	20991	58	14B
0005432360390	20991	59	14D
0005432336045	20991	60	14E
0005432360357	20991	61	15A
0005432360397	20991	62	15C
0005435177387	20991	63	15B
0005435177401	20991	64	15D
0005432360237	20991	65	16A
0005435177390	20991	66	15F
0005432360358	20991	67	16B
0005432360469	20991	68	16C
0005434149861	20991	69	16E
0005432360490	20991	70	16D
0005434149860	20991	71	17A
0005435177399	20991	72	17B
0005432360534	20991	73	17C
0005435177375	20991	74	17E
0005435177379	20991	75	17D
0005435177378	20991	76	17F
0005432360470	20991	77	18A
0005435177397	20991	78	18B
0005432360614	20991	79	18D
0005432336068	20991	80	18F
0005432360456	20991	81	18E
0005432360572	20991	82	19A
0005432360501	20991	83	19B
0005435490272	20991	84	19C
0005432360430	20991	85	19E
0005434149868	20991	86	19D
0005432336072	20991	87	19F
0005432336071	20991	88	20A
0005432360348	20991	89	20B
0005432360144	20991	90	20D
0005432336052	20991	91	20C
0005432336054	20991	92	20E
0005435177398	20991	93	20F
0005435177381	20991	94	21A
0005432360712	20991	95	21B
0005432360711	20991	96	21D
0005432360473	20991	97	21E
0005432360247	20991	98	22A
0005435490273	20991	99	21F
0005432360331	20991	100	22B
0005432360573	20991	101	22D
0005432360344	20991	102	22E
0005435177385	20991	103	23B
0005435177392	20991	104	23A
0005435177374	20991	105	23C
0005435177386	20991	106	23E
0005434149866	20991	107	23D
0005432360468	20991	108	23F
0005434458916	17731	1	2A
0005434458915	17731	2	2B
0005434448326	17731	3	2C
0005434458908	17731	4	2D
0005434186231	17731	5	3B
0005434458918	17731	6	3C
0005434458846	17731	7	3D
0005434458856	17731	8	4B
0005434458882	17731	9	4C
0005434458778	17731	10	4D
0005434461652	17731	11	5C
0005434186232	17731	12	5D
0005434458938	17731	13	6A
0005434458898	17731	14	6B
0005434461651	17731	15	6C
0005434461646	17731	16	6D
0005434448327	17731	17	7B
0005434458863	17731	18	7C
0005434458886	17731	19	7D
0005434458847	17731	20	18A
0005434458813	17731	21	18C
0005434461655	17731	22	18D
0005434458930	17731	23	20A
0005434448318	17731	24	20B
0005434448328	17731	25	20C
0005434458861	17731	26	21B
0005434463936	17731	27	21C
0005434461647	17731	28	22A
0005434448314	17731	29	22C
0005434458862	17731	30	22D
0005434186233	17731	31	23A
0005434458885	17731	32	23B
0005434462812	29105	1	1A
0005434463952	29105	2	1B
0005434459050	29105	3	1C
0005434459039	29105	4	1D
0005434459036	29105	5	2B
0005434448350	29105	6	2C
0005434459035	29105	7	2D
0005434462814	29105	8	3C
0005434459047	29105	9	3D
0005434459045	29105	10	4A
0005434459042	29105	11	4B
0005434448352	29105	12	4C
0005434459041	29105	13	4D
0005434448353	29105	14	5A
0005434459040	29105	15	5B
0005434186208	29105	16	5D
0005434448351	29105	17	6D
0005434459034	29105	18	7B
0005434459046	29105	19	7C
0005434459048	29105	20	7D
0005434459031	29105	21	18A
0005434459033	29105	22	18B
0005434459043	29105	23	19A
0005434459037	29105	24	20B
0005434459032	29105	25	20C
0005434459049	29105	26	21A
0005434459038	29105	27	22A
0005434463953	29105	28	22B
0005434462813	29105	29	22C
0005434459044	29105	30	23B
0005432604776	21427	1	1A
0005432604743	21427	2	1B
0005432604754	21427	3	1D
0005432604741	21427	4	2A
0005432604766	21427	5	2B
0005432604761	21427	6	2C
0005432604742	21427	7	2D
0005432604774	21427	8	3B
0005432604757	21427	9	3C
0005432604750	21427	10	3D
0005432604778	21427	11	4A
0005432604760	21427	12	4C
0005432604763	21427	13	4D
0005432604739	21427	14	5A
0005432604753	21427	15	5B
0005432604740	21427	16	5C
0005432604737	21427	17	5D
0005432604777	21427	18	6A
0005432604755	21427	19	6B
0005432604745	21427	20	6C
0005432604771	21427	21	6D
0005432604744	21427	22	7A
0005432604764	21427	23	7B
0005432604767	21427	24	7C
0005432604751	21427	25	7D
0005435218120	21427	26	18A
0005432604747	21427	27	18B
0005432604749	21427	28	18C
0005432604775	21427	29	18D
0005432604746	21427	30	19B
0005432604759	21427	31	19D
0005432604769	21427	32	20A
0005432604758	21427	33	20B
0005432604756	21427	34	20C
0005432604752	21427	35	20D
0005432604765	21427	36	21C
0005432604748	21427	37	21D
0005432604768	21427	38	22A
0005432604770	21427	39	22B
0005432604773	21427	40	22C
0005432604762	21427	41	22D
0005432604738	21427	42	23A
0005432604772	21427	43	23B
0005432604459	31704	1	1A
0005432604466	31704	2	1B
0005432604628	31704	3	2B
0005432604388	31704	4	3A
0005432604145	31704	5	3B
0005432604355	31704	6	3C
0005432604429	31704	7	3D
0005432604514	31704	8	4A
0005432604475	31704	9	4B
0005432604387	31704	10	4C
0005432604526	31704	11	5A
0005432604474	31704	12	5B
0005432604349	31704	13	5D
0005432604365	31704	14	6B
0005432604353	31704	15	6C
0005432604279	31704	16	6D
0005435221065	31704	17	7A
0005432604467	31704	18	7D
0005432604532	31704	19	18A
0005432604529	31704	20	18B
0005432604354	31704	21	18C
0005432604563	31704	22	18D
0005432604465	31704	23	19A
0005432604352	31704	24	19B
0005432604562	31704	25	19D
0005432604182	31704	26	20A
0005432604533	31704	27	21D
0005435221064	31704	28	22B
0005432604366	31704	29	22C
0005433293320	29609	1	1A
0005433293322	29609	2	3B
0005433293321	29609	3	4D
0005433293318	29609	4	7C
0005433293315	29609	5	19A
0005433293314	29609	6	19B
0005433293319	29609	7	20B
0005433293323	29609	8	20D
0005433293317	29609	9	21B
0005433293316	29609	10	22D
0005433473363	6680	1	1A
0005433473373	6680	2	1B
0005435257273	6680	3	1C
0005435257233	6680	4	1D
0005433473360	6680	5	2C
0005435257234	6680	6	2B
0005435257254	6680	7	2D
0005433473376	6680	8	3A
0005435257272	6680	9	3B
0005433473353	6680	10	3C
0005435257253	6680	11	3D
0005435257245	6680	12	4A
0005433473368	6680	13	4B
0005435257235	6680	14	4C
0005433473357	6680	15	4D
0005433473359	6680	16	5A
0005433473355	6680	17	5B
0005433473354	6680	18	6B
0005435257257	6680	19	6C
0005435257249	6680	20	7A
0005433473364	6680	21	7C
0005433473349	6680	22	18A
0005433473369	6680	23	18B
0005433473375	6680	24	18C
0005433473348	6680	25	18D
0005433473358	6680	26	19A
0005433473362	6680	27	19B
0005433473352	6680	28	19C
0005433473366	6680	29	19D
0005435257226	6680	30	20A
0005433473370	6680	31	20B
0005433473347	6680	32	20C
0005433473356	6680	33	20D
0005433473374	6680	34	21A
0005433473367	6680	35	21B
0005433473371	6680	36	21C
0005433473365	6680	37	21D
0005433473350	6680	38	22A
0005435257248	6680	39	22B
0005433473372	6680	40	22C
0005433473361	6680	41	22D
0005433473351	6680	42	23A
0005435257256	6680	43	23B
0005434606844	18874	1	1A
0005434606843	18874	2	5B
0005434604934	22398	1	2A
0005434606866	22398	2	1B
0005435904895	22398	3	4A
0005434604930	22398	4	4B
0005434604933	22398	5	5B
0005434604932	22398	6	6A
0005434604931	22398	7	6B
0005432891054	372	1	1A
0005432891046	372	2	1C
0005435154613	372	3	1D
0005432747992	372	4	1F
0005432220051	372	5	2A
0005432753337	372	6	2C
0005432747994	372	7	2D
0005432220048	372	8	2F
0005433293243	372	9	3A
0005432748004	372	10	3C
0005432891066	372	11	3D
0005432748006	372	12	3F
0005432747988	372	13	4A
0005433293270	372	14	4C
0005432748002	372	15	4D
0005432748003	372	16	4E
0005432891058	372	17	4F
0005432747989	372	18	5A
0005433293237	372	19	5C
0005432891095	372	20	5D
0005432891045	372	21	5E
0005432748007	372	22	5F
0005435154612	372	23	6A
0005432747978	372	24	6C
0005432747981	372	25	6D
0005432747976	372	26	6E
0005433293238	372	27	6F
0005432891122	372	28	7C
0005433293275	372	29	7D
0005432747974	372	30	7E
0005432747991	372	31	7F
0005432891106	372	32	8A
0005432748001	372	33	8C
0005432891053	372	34	8D
0005433293273	372	35	8F
0005432891037	372	36	9A
0005432751560	372	37	9C
0005432747975	372	38	9D
0005432751562	372	39	9E
0005432747979	372	40	9F
0005433293282	372	41	10A
0005432748000	372	42	10C
0005432220052	372	43	10D
0005432748008	372	44	10F
0005433293247	372	45	11A
0005432747990	372	46	11C
0005432747987	372	47	11D
0005432747993	372	48	11E
0005432747973	372	49	11F
0005432753334	372	50	12C
0005435154615	372	51	12A
0005432749807	372	52	12D
0005432891147	372	53	12E
0005432748005	372	54	12F
0005432220049	372	55	13C
0005432749808	372	56	13D
0005432747985	372	57	13E
0005432747984	372	58	13F
0005432891127	372	59	14A
0005432747980	372	60	14D
0005432891088	372	61	14E
0005433293274	372	62	14F
0005433293264	372	63	15A
0005432749809	372	64	15C
0005432753335	372	65	15D
0005432747982	372	66	15E
0005432747986	372	67	15F
0005432891081	372	68	16A
0005432891121	372	69	16C
0005432751561	372	70	16D
0005432891148	372	71	16E
0005432891087	372	72	17A
0005435154614	372	73	17C
0005432747996	372	74	17D
0005432747983	372	75	17E
0005432747997	372	76	18A
0005432747977	372	77	18C
0005432891023	372	78	18D
0005432220050	372	79	18E
0005432747971	372	80	18F
0005432753336	372	81	19A
0005432747972	372	82	19C
0005432747998	372	83	19D
0005432747995	372	84	20C
0005432747999	372	85	20D
0005432891094	372	86	20E
0005433293246	372	87	20F
0005432747625	12055	1	1A
0005432747789	12055	2	1D
0005432747837	12055	3	1F
0005432891232	12055	4	2A
0005432891249	12055	5	2C
0005432747678	12055	6	2D
0005432891237	12055	7	2F
0005432756858	12055	8	3D
0005432747526	12055	9	3F
0005432891245	12055	10	4A
0005432753311	12055	11	4C
0005432747679	12055	12	4D
0005432747742	12055	13	4E
0005432753306	12055	14	4F
0005432753309	12055	15	5A
0005432891234	12055	16	5C
0005432747726	12055	17	5D
0005432747706	12055	18	5F
0005432747624	12055	19	6A
0005432891241	12055	20	6C
0005433875397	12055	21	6D
0005432747601	12055	22	6F
0005432891235	12055	23	7A
0005432214828	12055	24	7C
0005432749789	12055	25	7D
0005432756856	12055	26	7E
0005432756854	12055	27	7F
0005432747754	12055	28	8A
0005432747600	12055	29	8C
0005432747723	12055	30	8D
0005432891242	12055	31	9A
0005432747677	12055	32	9C
0005432747577	12055	33	9D
0005432756860	12055	34	9E
0005432891239	12055	35	9F
0005432747801	12055	36	10A
0005432747579	12055	37	10C
0005432891236	12055	38	10D
0005432756843	12055	39	10E
0005432747578	12055	40	10F
0005432756859	12055	41	11C
0005432747690	12055	42	11E
0005432891248	12055	43	11F
0005432891246	12055	44	12C
0005432756853	12055	45	12E
0005432747769	12055	46	12F
0005432747497	12055	47	13A
0005432747689	12055	48	13C
0005432747763	12055	49	13D
0005432747638	12055	50	13E
0005432747735	12055	51	14A
0005432747770	12055	52	14C
0005432747736	12055	53	14D
0005432747741	12055	54	14E
0005432747838	12055	55	14F
0005432747658	12055	56	15A
0005432747535	12055	57	15D
0005432747602	12055	58	15E
0005432756855	12055	59	15F
0005432756842	12055	60	16A
0005432756845	12055	61	16C
0005432891243	12055	62	16D
0005432747637	12055	63	16E
0005432747673	12055	64	16F
0005432753323	12055	65	17C
0005432747667	12055	66	17D
0005432747672	12055	67	17E
0005432753310	12055	68	18A
0005432747878	12055	69	18C
0005432891247	12055	70	18D
0005432747618	12055	71	18F
0005432747717	12055	72	19A
0005432891233	12055	73	19C
0005432756857	12055	74	19D
0005432891238	12055	75	19E
0005432747757	12055	76	19F
0005432891240	12055	77	20A
0005432891244	12055	78	20C
0005432747623	12055	79	20D
0005432747680	12055	80	20E
0005432747867	12055	81	20F
0005432927994	18961	1	1C
0005433525157	18961	2	1D
0005432928010	18961	3	2A
0005433525147	18961	4	2C
0005433531334	18961	5	3A
0005433531331	18961	6	3C
0005433531333	18961	7	3D
0005433525155	18961	8	4A
0005433525150	18961	9	4B
0005433531332	18961	10	4C
0005433525148	18961	11	4D
0005432927986	18961	12	5A
0005432927987	18961	13	5B
0005433525154	18961	14	5D
0005433525149	18961	15	6A
0005432927993	18961	16	6D
0005432927988	18961	17	18B
0005432928002	18961	18	18C
0005433533347	18961	19	19A
0005433533346	18961	20	19B
0005433531335	18961	21	20B
0005433533348	18961	22	20C
0005432927990	18961	23	20D
0005433525151	18961	24	21B
0005433525156	18961	25	21D
0005433525153	18961	26	22C
0005433525152	18961	27	23B
0005432928047	32508	1	1A
0005433531309	32508	2	1B
0005433531307	32508	3	1C
0005433525033	32508	4	2B
0005433531298	32508	5	2C
0005433525049	32508	6	3A
0005433527276	32508	7	3B
0005432928048	32508	8	4B
0005432928046	32508	9	4D
0005433525046	32508	10	5A
0005433525105	32508	11	5B
0005433527268	32508	12	5C
0005433531310	32508	13	5D
0005433525045	32508	14	6A
0005433527265	32508	15	6B
0005432928050	32508	16	6D
0005432928051	32508	17	7A
0005433525097	32508	18	7C
0005433527273	32508	19	18A
0005433525085	32508	20	18B
0005433531299	32508	21	18C
0005433525101	32508	22	18D
0005433531294	32508	23	19C
0005433527274	32508	24	19D
0005433525100	32508	25	20C
0005433525055	32508	26	20D
0005433525104	32508	27	21B
0005433527275	32508	28	21C
0005432928049	32508	29	21D
0005433531300	32508	30	22A
0005433525076	32508	31	22B
0005433525098	32508	32	22C
0005433525054	32508	33	22D
0005433525096	32508	34	23A
0005433525059	32508	35	23B
0005434825074	5273	1	1C
0005435386619	5273	2	1A
0005434831198	5273	3	1H
0005434824956	5273	4	1G
0005435373250	5273	5	2A
0005434825052	5273	6	2C
0005434824980	5273	7	3A
0005434824957	5273	8	2K
0005434664985	5273	9	3D
0005435373373	5273	10	3C
0005434825071	5273	11	3H
0005434825013	5273	12	3G
0005434824962	5273	13	4C
0005435304160	5273	14	4A
0005434825005	5273	15	5C
0005432396287	5273	16	5A
0005434824951	5273	17	5H
0005434825023	5273	18	5G
0005434664986	5273	19	11A
0005434825026	5273	20	5K
0005435150181	5273	21	11D
0005434825073	5273	22	11C
0005434825042	5273	23	11G
0005434824985	5273	24	11F
0005432396291	5273	25	11E
0005434825025	5273	26	11H
0005434824973	5273	27	12C
0005434824990	5273	28	12A
0005434831201	5273	29	11K
0005434824995	5273	30	12E
0005434825056	5273	31	12D
0005435304173	5273	32	12G
0005435373146	5273	33	12F
0005434824968	5273	34	13A
0005434825063	5273	35	12K
0005435150185	5273	36	12H
0005432121495	5273	37	13C
0005435373419	5273	38	13E
0005434824967	5273	39	13H
0005434558369	5273	40	13G
0005435373562	5273	41	13K
0005432121492	5273	42	14D
0005435304147	5273	43	14C
0005434824994	5273	44	14G
0005434825011	5273	45	15A
0005435304176	5273	46	14K
0005435150186	5273	47	15E
0005435373310	5273	48	16A
0005434825059	5273	49	15K
0005434824966	5273	50	16D
0005434825019	5273	51	16C
0005434824989	5273	52	16F
0005434824991	5273	53	16E
0005434825008	5273	54	16G
0005435386579	5273	55	17C
0005435373266	5273	56	17A
0005434831199	5273	57	16K
0005435373486	5273	58	17E
0005434824948	5273	59	17G
0005434824955	5273	60	17F
0005434664983	5273	61	17H
0005434825050	5273	62	18C
0005434824960	5273	63	18B
0005435373378	5273	64	18F
0005435150184	5273	65	18J
0005435373530	5273	66	19B
0005434824970	5273	67	19A
0005432121497	5273	68	18K
0005434825038	5273	69	19D
0005434825039	5273	70	19H
0005434825054	5273	71	19K
0005434824983	5273	72	19J
0005434825037	5273	73	20C
0005434825049	5273	74	20B
0005435661929	5273	75	20D
0005432121496	5273	76	20G
0005434831202	5273	77	20F
0005434824984	5273	78	20K
0005434825035	5273	79	20J
0005435373221	5273	80	20H
0005434824949	5273	81	21D
0005434824974	5273	82	21C
0005434825058	5273	83	21B
0005434825065	5273	84	21F
0005434825041	5273	85	21E
0005434824992	5273	86	21J
0005432121494	5273	87	21H
0005435373354	5273	88	22A
0005435373282	5273	89	21K
0005434825066	5273	90	22C
0005434825017	5273	91	22B
0005435150182	5273	92	22E
0005435373631	5273	93	22H
0005434825006	5273	94	22G
0005435373611	5273	95	22F
0005432396290	5273	96	22K
0005432121488	5273	97	22J
0005432121491	5273	98	23A
0005435386605	5273	99	23C
0005434824958	5273	100	23F
0005435373394	5273	101	23E
0005432121499	5273	102	23J
0005434824965	5273	103	23H
0005434825043	5273	104	23G
0005434825024	5273	105	24F
0005434824999	5273	106	24E
0005434825064	5273	107	25B
0005435373386	5273	108	25A
0005435373560	5273	109	25C
0005434825028	5273	110	25E
0005434825029	5273	111	25D
0005434824993	5273	112	25G
0005434825036	5273	113	26A
0005435373281	5273	114	25K
0005435373068	5273	115	26C
0005435373432	5273	116	26B
0005434825016	5273	117	26D
0005432394151	5273	118	26G
0005432394149	5273	119	26F
0005435373417	5273	120	26J
0005435373566	5273	121	26H
0005434558368	5273	122	27D
0005434825032	5273	123	27H
0005434824964	5273	124	28A
0005434825044	5273	125	28B
0005434825046	5273	126	28D
0005434825033	5273	127	28C
0005434824996	5273	128	28F
0005435373485	5273	129	28J
0005435373561	5273	130	29B
0005434825051	5273	131	29A
0005432121501	5273	132	28K
0005434825003	5273	133	29D
0005434825021	5273	134	29C
0005435150189	5273	135	29H
0005434824988	5273	136	29G
0005435373664	5273	137	30A
0005435150188	5273	138	29K
0005434825067	5273	139	29J
0005435304163	5273	140	30C
0005434558366	5273	141	30B
0005432121487	5273	142	30G
0005435150179	5273	143	30F
0005434825010	5273	144	30K
0005435373418	5273	145	31B
0005434825060	5273	146	31A
0005434824954	5273	147	31D
0005435150191	5273	148	31C
0005434824982	5273	149	31F
0005435373595	5273	150	31E
0005432396292	5273	151	31H
0005435373241	5273	152	31G
0005435661930	5273	153	31K
0005434825057	5273	154	32A
0005435661916	5273	155	32D
0005435373374	5273	156	32F
0005434831200	5273	157	32H
0005434824959	5273	158	33A
0005434824975	5273	159	32K
0005434825045	5273	160	33D
0005435299789	5273	161	33B
0005434825070	5273	162	33J
0005434828726	5273	163	33H
0005434824979	5273	164	33K
0005435373708	5273	165	34C
0005434825053	5273	166	34A
0005435373596	5273	167	34E
0005435373312	5273	168	34D
0005434824961	5273	169	34F
0005435373466	5273	170	34K
0005434825034	5273	171	34J
0005435150187	5273	172	34H
0005432396289	5273	173	35A
0005435373254	5273	174	35D
0005435150180	5273	175	35C
0005434824976	5273	176	35B
0005434824998	5273	177	35F
0005434558374	5273	178	35E
0005434825007	5273	179	35H
0005434558367	5273	180	35G
0005435373512	5273	181	36A
0005432121493	5273	182	35K
0005435373548	5273	183	36C
0005432394152	5273	184	36B
0005434825076	5273	185	36E
0005434824952	5273	186	36G
0005434825012	5273	187	36F
0005435373685	5273	188	36K
0005435386599	5273	189	36J
0005435150192	5273	190	36H
0005435373796	5273	191	37B
0005435373433	5273	192	37E
0005434825040	5273	193	37D
0005434825022	5273	194	37C
0005434828725	5273	195	37G
0005434825061	5273	196	37J
0005434825068	5273	197	37H
0005434825015	5273	198	38A
0005432121498	5273	199	37K
0005434824997	5273	200	38C
0005432121500	5273	201	38B
0005432121486	5273	202	38J
0005434825014	5273	203	38H
0005435304172	5273	204	39B
0005434825020	5273	205	39A
0005432121490	5273	206	39C
0005434825002	5273	207	39F
0005435373430	5273	208	39E
0005435150178	5273	209	39H
0005434825004	5273	210	40G
0005435373365	5273	211	40F
0005435373283	5273	212	40K
0005435373251	5273	213	40J
0005434558370	5273	214	41B
0005434825001	5273	215	41A
0005435373160	5273	216	41F
0005434824950	5273	217	41E
0005434825030	5273	218	41H
0005435386620	5273	219	42A
0005434824986	5273	220	41K
0005434825072	5273	221	41J
0005434558375	5273	222	42C
0005434558373	5273	223	42E
0005435373067	5273	224	42D
0005434824972	5273	225	42F
0005435304146	5273	226	42J
0005435373089	5273	227	42H
0005435304162	5273	228	43B
0005434824953	5273	229	42K
0005434825027	5273	230	43C
0005435150190	5273	231	43G
0005434825062	5273	232	43F
0005435373161	5273	233	43E
0005434824971	5273	234	43H
0005434824963	5273	235	44A
0005435386600	5273	236	43K
0005435373714	5273	237	44B
0005435373088	5273	238	44D
0005434824981	5273	239	44G
0005434825009	5273	240	44F
0005434825069	5273	241	45B
0005435373549	5273	242	45A
0005434558372	5273	243	45C
0005434825055	5273	244	45G
0005435373451	5273	245	45J
0005434824969	5273	246	46B
0005434825075	5273	247	46E
0005435373236	5273	248	46H
0005434824947	5273	249	46G
0005434558365	5273	250	46F
0005432394150	5273	251	47A
0005435661915	5273	252	47E
0005434825031	5273	253	47D
0005435373351	5273	254	47C
0005435304158	5273	255	47G
0005434558371	5273	256	47F
0005434825047	5273	257	47K
0005435373262	5273	258	47H
0005435373539	5273	259	48E
0005434824978	5273	260	48G
0005434825000	5273	261	49A
0005435373372	5273	262	48K
0005435373487	5273	263	49D
0005434828727	5273	264	49C
0005435373392	5273	265	49G
0005434824987	5273	266	49F
0005432121489	5273	267	49K
0005435373467	5273	268	50C
0005434664984	5273	269	50A
0005435150183	5273	270	50F
0005434825048	5273	271	50E
0005435373524	5273	272	50D
0005434824977	5273	273	50G
0005435373355	5273	274	51F
0005434825018	5273	275	51E
0005435373300	5273	276	51D
0005432396288	5273	277	51G
0005434824123	9915	1	1C
0005434823792	9915	2	1A
0005435373995	9915	3	1D
0005435373975	9915	4	2C
0005434823192	9915	5	2H
0005434823916	9915	6	2G
0005434823950	9915	7	3C
0005432203147	9915	8	3K
0005434558257	9915	9	4G
0005435150027	9915	10	4D
0005435374003	9915	11	4K
0005434823655	9915	12	4H
0005435150075	9915	13	5A
0005435386647	9915	14	5H
0005435373963	9915	15	11A
0005435373976	9915	16	11D
0005435386645	9915	17	11C
0005435373997	9915	18	11F
0005435374025	9915	19	11E
0005435373969	9915	20	11H
0005434558245	9915	21	12A
0005434823941	9915	22	12E
0005435374014	9915	23	12D
0005435150014	9915	24	12G
0005435374008	9915	25	12F
0005434823826	9915	26	12K
0005434824009	9915	27	13F
0005434824126	9915	28	13E
0005435150086	9915	29	13G
0005435373968	9915	30	14F
0005434823441	9915	31	14K
0005432203145	9915	32	15C
0005434823484	9915	33	15D
0005434824243	9915	34	15F
0005435374023	9915	35	15K
0005434824331	9915	36	15H
0005434823882	9915	37	16A
0005434823932	9915	38	16F
0005432823473	9915	39	17A
0005434824091	9915	40	17E
0005435373994	9915	41	17D
0005434823805	9915	42	18A
0005435373978	9915	43	17K
0005435373970	9915	44	18C
0005434823883	9915	45	18B
0005434823967	9915	46	18E
0005434823807	9915	47	18H
0005434823827	9915	48	18G
0005434824348	9915	49	18F
0005434828699	9915	50	18J
0005434823483	9915	51	19A
0005435373962	9915	52	18K
0005434828709	9915	53	19E
0005435373981	9915	54	19H
0005435373982	9915	55	20A
0005435373973	9915	56	19J
0005434824269	9915	57	20C
0005435374017	9915	58	20B
0005434824290	9915	59	20D
0005435373983	9915	60	20F
0005434823833	9915	61	20J
0005434823636	9915	62	20H
0005435373965	9915	63	21B
0005434824547	9915	64	21D
0005434823295	9915	65	21F
0005432396254	9915	66	21H
0005435150056	9915	67	22A
0005434824417	9915	68	21K
0005434823578	9915	69	22B
0005434823933	9915	70	22D
0005434824163	9915	71	22H
0005434828711	9915	72	22G
0005434824010	9915	73	22J
0005435302253	9915	74	23E
0005435373977	9915	75	23D
0005432396247	9915	76	23C
0005434823961	9915	77	23G
0005435374022	9915	78	23H
0005434824405	9915	79	23J
0005435374019	9915	80	24F
0005434823458	9915	81	24E
0005434558282	9915	82	25A
0005435373971	9915	83	25F
0005435373972	9915	84	25E
0005435150044	9915	85	25H
0005434558259	9915	86	25G
0005435373986	9915	87	25K
0005435373964	9915	88	25J
0005435386649	9915	89	26A
0005435373980	9915	90	26E
0005434824164	9915	91	26D
0005434823942	9915	92	26G
0005435374020	9915	93	26J
0005434823988	9915	94	26H
0005434824012	9915	95	27A
0005434664955	9915	96	27D
0005435373967	9915	97	27B
0005434824315	9915	98	27F
0005434823594	9915	99	27E
0005435373990	9915	100	27G
0005434824244	9915	101	27J
0005434824416	9915	102	28A
0005434823936	9915	103	28J
0005434823806	9915	104	28H
0005434824121	9915	105	29A
0005435374016	9915	106	28K
0005435374006	9915	107	29C
0005435373979	9915	108	29F
0005435374026	9915	109	29H
0005434558275	9915	110	29G
0005434823481	9915	111	30A
0005432203148	9915	112	29K
0005434823593	9915	113	29J
0005435302249	9915	114	30B
0005434823962	9915	115	30C
0005435374027	9915	116	30G
0005435735192	9915	117	30F
0005435386648	9915	118	30J
0005435661964	9915	119	30H
0005434823193	9915	120	30K
0005435374007	9915	121	31G
0005435374015	9915	122	31E
0005434558295	9915	123	31D
0005434824318	9915	124	31J
0005434824360	9915	125	31H
0005435302250	9915	126	31K
0005434823191	9915	127	32C
0005434824442	9915	128	32G
0005434823794	9915	129	32F
0005435373998	9915	130	32J
0005434823842	9915	131	32H
0005434823828	9915	132	33B
0005434824037	9915	133	33A
0005434824092	9915	134	33G
0005435374002	9915	135	33F
0005434824002	9915	136	33H
0005434823970	9915	137	33K
0005434558293	9915	138	34B
0005435735189	9915	139	34A
0005435150087	9915	140	34E
0005432203143	9915	141	34D
0005434828698	9915	142	34G
0005434558291	9915	143	34F
0005434824127	9915	144	34H
0005434824398	9915	145	35B
0005434824289	9915	146	35A
0005435150088	9915	147	35D
0005434824145	9915	148	35C
0005434824538	9915	149	35E
0005435302252	9915	150	35G
0005435735191	9915	151	36A
0005434828712	9915	152	36C
0005434823990	9915	153	36B
0005434823984	9915	154	36D
0005435373992	9915	155	36H
0005435374010	9915	156	36G
0005434823774	9915	157	36J
0005434824156	9915	158	37B
0005435150013	9915	159	37E
0005435299828	9915	160	37C
0005434824291	9915	161	37F
0005434824390	9915	162	37H
0005434823877	9915	163	37G
0005434823552	9915	164	37K
0005435150028	9915	165	38C
0005432203144	9915	166	38B
0005434823846	9915	167	38J
0005434823981	9915	168	38K
0005432203146	9915	169	39D
0005434558258	9915	170	39C
0005434824057	9915	171	39E
0005434823986	9915	172	39J
0005435302251	9915	173	39H
0005435386644	9915	174	39G
0005434823528	9915	175	40C
0005434823773	9915	176	40B
0005432203142	9915	177	40E
0005435373989	9915	178	40H
0005435150026	9915	179	40G
0005435735190	9915	180	40F
0005435373988	9915	181	40K
0005434824177	9915	182	41B
0005434828710	9915	183	41A
0005435374028	9915	184	41D
0005435386650	9915	185	41C
0005434823985	9915	186	41F
0005434824330	9915	187	41E
0005434823963	9915	188	41H
0005435374012	9915	189	41G
0005435373993	9915	190	42A
0005434824011	9915	191	41K
0005434558256	9915	192	42C
0005435299827	9915	193	42E
0005435661965	9915	194	42D
0005434824176	9915	195	42F
0005435373974	9915	196	42K
0005434823457	9915	197	42J
0005435179404	9915	198	43B
0005435374021	9915	199	43A
0005434558274	9915	200	43D
0005435373999	9915	201	43C
0005434824001	9915	202	43F
0005434824270	9915	203	43E
0005434824288	9915	204	43H
0005434823579	9915	205	43G
0005435150098	9915	206	44A
0005435299830	9915	207	43K
0005432400126	9915	208	43J
0005432396257	9915	209	44C
0005434823560	9915	210	44B
0005435374011	9915	211	44E
0005434823832	9915	212	44D
0005435373987	9915	213	44G
0005434824232	9915	214	44F
0005435373985	9915	215	44J
0005434823957	9915	216	44H
0005435150060	9915	217	45D
0005435299829	9915	218	45C
0005435373996	9915	219	45F
0005434823606	9915	220	45E
0005434823966	9915	221	45H
0005434823757	9915	222	45G
0005434823808	9915	223	45K
0005434823845	9915	224	46C
0005434823987	9915	225	46B
0005435373966	9915	226	46D
0005435374005	9915	227	46G
0005434558276	9915	228	46H
0005435374004	9915	229	47C
0005434824058	9915	230	47D
0005432400107	9915	231	47G
0005434823789	9915	232	47F
0005435374013	9915	233	48A
0005435374009	9915	234	47K
0005434558294	9915	235	47H
0005435374001	9915	236	48C
0005435374024	9915	237	48E
0005435374000	9915	238	48H
0005434823976	9915	239	49A
0005435386646	9915	240	49F
0005435299831	9915	241	49E
0005435373991	9915	242	49K
0005434823964	9915	243	49H
0005434824391	9915	244	50A
0005435374018	9915	245	50F
0005434558292	9915	246	50E
0005434823793	9915	247	51D
0005434823844	9915	248	50K
0005435150076	9915	249	50H
0005434823524	9915	250	51F
0005434828708	9915	251	51E
0005435373984	9915	252	51G
0005435082874	6974	1	1A
0005435790339	6974	2	2C
0005435082877	6974	3	3C
0005435082879	6974	4	5B
0005435082873	6974	5	6D
0005435082880	6974	6	19B
0005435790340	6974	7	20B
0005435082876	6974	8	21B
0005435082878	6974	9	21C
0005435082875	6974	10	21D
0005435082881	6974	11	22C
0005435082803	26008	1	2C
0005435082802	26008	2	4B
0005435790305	26008	3	7D
0005435082806	26008	4	19B
0005435082771	26008	5	20C
0005435082789	26008	6	22C
0005434756914	9515	1	1A
0005434756926	9515	2	1C
0005434756927	9515	3	1F
0005434756889	9515	4	2A
0005434756895	9515	5	2C
0005434214705	9515	6	2D
0005434756923	9515	7	2F
0005434756916	9515	8	3A
0005434214601	9515	9	3C
0005434756904	9515	10	3D
0005434756909	9515	11	3F
0005434214714	9515	12	4A
0005434214580	9515	13	4C
0005434214520	9515	14	4D
0005434214652	9515	15	4E
0005434756911	9515	16	4F
0005434214506	9515	17	5A
0005434756925	9515	18	5C
0005434214632	9515	19	5D
0005434214710	9515	20	5E
0005434756885	9515	21	5F
0005434756908	9515	22	6A
0005434214703	9515	23	6C
0005434756905	9515	24	6D
0005434214704	9515	25	6E
0005434214655	9515	26	6F
0005434756924	9515	27	7A
0005434756910	9515	28	7C
0005434214380	9515	29	7D
0005434214777	9515	30	7E
0005434214507	9515	31	7F
0005434214581	9515	32	8A
0005434756912	9515	33	8C
0005434214600	9515	34	8D
0005434214436	9515	35	8E
0005434756922	9515	36	8F
0005434756886	9515	37	9A
0005434214764	9515	38	9C
0005434756906	9515	39	9D
0005434756921	9515	40	9E
0005434756919	9515	41	9F
0005434756898	9515	42	10A
0005434756920	9515	43	10C
0005434214486	9515	44	10D
0005434756915	9515	45	10E
0005434756890	9515	46	10F
0005434214485	9515	47	11A
0005434756882	9515	48	11C
0005434756883	9515	49	11D
0005434214765	9515	50	11E
0005434756917	9515	51	11F
0005434214806	9515	52	12A
0005434214709	9515	53	12C
0005434756913	9515	54	12D
0005434756896	9515	55	12E
0005434214724	9515	56	12F
0005434214631	9515	57	13A
0005434214493	9515	58	13D
0005434214427	9515	59	13F
0005434756881	9515	60	14A
0005434214372	9515	61	14C
0005434214551	9515	62	14D
0005434756893	9515	63	14E
0005434214501	9515	64	14F
0005434756892	9515	65	15A
0005434214745	9515	66	15C
0005434756907	9515	67	15D
0005434756891	9515	68	15E
0005434214719	9515	69	15F
0005434756884	9515	70	16A
0005434214741	9515	71	16C
0005434756918	9515	72	16D
0005434756902	9515	73	16E
0005434756888	9515	74	16F
0005434214535	9515	75	17A
0005434756887	9515	76	17C
0005434214602	9515	77	17D
0005434214624	9515	78	17E
0005434214521	9515	79	17F
0005434756894	9515	80	18A
0005434756900	9515	81	18C
0005434756903	9515	82	18D
0005434214585	9515	83	18E
0005434756897	9515	84	18F
0005434214720	9515	85	19A
0005434214775	9515	86	19C
0005434214723	9515	87	19D
0005434214625	9515	88	19E
0005434756899	9515	89	19F
0005434214502	9515	90	20A
0005434214744	9515	91	20C
0005434756901	9515	92	20D
0005434214686	9515	93	20E
0005434214484	9515	94	20F
0005434214987	28635	1	1A
0005434756346	28635	2	1D
0005434215006	28635	3	1F
0005434756475	28635	4	2A
0005434756511	28635	5	2C
0005434214984	28635	6	2D
0005434215023	28635	7	2F
0005434215011	28635	8	3A
0005434214998	28635	9	3C
0005434756424	28635	10	3D
0005434215021	28635	11	3F
0005434756496	28635	12	4A
0005434756352	28635	13	4C
0005434756534	28635	14	4D
0005434214991	28635	15	4E
0005434215016	28635	16	4F
0005434756408	28635	17	5A
0005434756370	28635	18	5C
0005434756400	28635	19	5D
0005434756343	28635	20	5F
0005434215019	28635	21	6A
0005434214983	28635	22	6D
0005434215007	28635	23	6E
0005434756470	28635	24	6F
0005434756473	28635	25	7A
0005434214988	28635	26	7C
0005434215003	28635	27	7D
0005434215029	28635	28	7E
0005434756512	28635	29	7F
0005434756205	28635	30	8A
0005434215014	28635	31	8C
0005434215017	28635	32	8D
0005434756409	28635	33	8E
0005434215027	28635	34	8F
0005434756457	28635	35	9A
0005434756430	28635	36	9C
0005434756464	28635	37	9D
0005434756276	28635	38	9F
0005434756455	28635	39	10A
0005434756456	28635	40	10C
0005434756344	28635	41	10D
0005434214993	28635	42	10E
0005434215008	28635	43	10F
0005434215015	28635	44	11A
0005434215002	28635	45	11C
0005434215005	28635	46	11D
0005434756380	28635	47	11E
0005434215022	28635	48	11F
0005434756593	28635	49	12C
0005434756362	28635	50	12D
0005434756505	28635	51	12E
0005434215012	28635	52	12F
0005434756540	28635	53	13A
0005434756527	28635	54	13C
0005434214989	28635	55	13D
0005434215004	28635	56	13E
0005434756410	28635	57	13F
0005434756497	28635	58	14A
0005434756571	28635	59	14C
0005434215000	28635	60	14D
0005434214996	28635	61	14F
0005434756458	28635	62	15A
0005434756439	28635	63	15C
0005434756353	28635	64	15D
0005434215026	28635	65	15E
0005434215013	28635	66	15F
0005434214994	28635	67	16A
0005434214992	28635	68	16C
0005434214997	28635	69	16D
0005434215009	28635	70	16E
0005434215028	28635	71	16F
0005434214986	28635	72	17C
0005434214990	28635	73	17D
0005434756447	28635	74	17E
0005434215024	28635	75	17F
0005434756541	28635	76	18A
0005434756506	28635	77	18C
0005434214995	28635	78	18D
0005434215010	28635	79	18E
0005434214999	28635	80	18F
0005434214985	28635	81	19A
0005434756535	28635	82	19D
0005434756533	28635	83	19E
0005434215025	28635	84	19F
0005434756469	28635	85	20A
0005434756472	28635	86	20C
0005434215018	28635	87	20D
0005434215020	28635	88	20E
0005434215001	28635	89	20F
0005435100156	10838	1	2C
0005434760195	10838	2	4A
0005435100157	10838	3	5B
0005434760196	10838	4	18C
0005435100155	10838	5	20C
0005435100117	31811	1	1A
0005434760224	31811	2	18C
0005434760225	31811	3	20A
0005435100132	31811	4	22C
0005434639599	1981	1	1A
0005433202374	1981	2	1C
0005434639608	1981	3	1D
0005433202372	1981	4	2A
0005434639620	1981	5	2B
0005434639619	1981	6	2C
0005433202378	1981	7	2D
0005432290667	1981	8	3A
0005434639603	1981	9	3B
0005434639611	1981	10	3C
0005433202406	1981	11	3D
0005434639626	1981	12	4A
0005434639606	1981	13	4B
0005432290669	1981	14	4C
0005434639610	1981	15	5A
0005434639612	1981	16	5C
0005434639600	1981	17	5D
0005434639613	1981	18	6A
0005433202442	1981	19	6B
0005433202413	1981	20	6C
0005432290668	1981	21	6D
0005433202373	1981	22	7A
0005433202405	1981	23	7B
0005433202371	1981	24	7C
0005435948337	1981	25	7D
0005434639614	1981	26	18A
0005434639617	1981	27	18B
0005434639625	1981	28	18C
0005433202376	1981	29	18D
0005434639615	1981	30	19A
0005434639601	1981	31	19B
0005434639621	1981	32	19C
0005434639616	1981	33	20A
0005434639623	1981	34	20B
0005434639618	1981	35	20C
0005434639609	1981	36	20D
0005434639624	1981	37	21A
0005433202393	1981	38	21C
0005434639607	1981	39	21D
0005433202395	1981	40	22A
0005434639605	1981	41	22B
0005434639622	1981	42	22C
0005434639604	1981	43	22D
0005434639602	1981	44	23B
0005434639276	23248	1	1A
0005434639313	23248	2	1B
0005433202511	23248	3	1C
0005433202520	23248	4	1D
0005434639287	23248	5	2A
0005433202516	23248	6	2B
0005434639420	23248	7	2C
0005434639419	23248	8	2D
0005434639426	23248	9	3A
0005434639327	23248	10	3B
0005434639323	23248	11	3C
0005434639398	23248	12	3D
0005434639367	23248	13	4A
0005434639406	23248	14	4B
0005434639286	23248	15	4C
0005434639425	23248	16	4D
0005433202519	23248	17	5A
0005433202522	23248	18	5B
0005433202510	23248	19	5C
0005433202514	23248	20	5D
0005434639383	23248	21	6A
0005433202509	23248	22	6B
0005434639368	23248	23	6C
0005434639366	23248	24	6D
0005434639405	23248	25	7A
0005434639399	23248	26	7B
0005434639277	23248	27	7C
0005434639301	23248	28	7D
0005434639322	23248	29	18A
0005434639447	23248	30	18B
0005433202515	23248	31	18C
0005434639396	23248	32	18D
0005433202523	23248	33	19A
0005434639407	23248	34	19B
0005433202521	23248	35	19C
0005434639384	23248	36	19D
0005434639334	23248	37	20A
0005433202512	23248	38	20B
0005433202513	23248	39	20D
0005434639359	23248	40	21A
0005434639446	23248	41	21B
0005434639312	23248	42	21C
0005433202517	23248	43	21D
0005434639328	23248	44	22A
0005433202518	23248	45	22B
0005434639365	23248	46	22C
0005434639395	23248	47	22D
0005434639423	23248	48	23A
0005434639414	23248	49	23B
0005434601112	6087	1	1C
0005435326799	6087	2	1D
0005434601115	6087	3	2A
0005435326745	6087	4	2C
0005433531336	6087	5	2D
0005435326798	6087	6	2F
0005435326793	6087	7	3C
0005434601101	6087	8	4A
0005435326767	6087	9	4D
0005435326777	6087	10	4F
0005434601125	6087	11	5A
0005435326771	6087	12	5C
0005434601126	6087	13	5D
0005435326848	6087	14	6D
0005434601106	6087	15	6F
0005435326731	6087	16	7C
0005435326762	6087	17	7D
0005434601119	6087	18	7E
0005435326751	6087	19	8A
0005434601100	6087	20	8E
0005433533351	6087	21	8F
0005434601110	6087	22	9A
0005434601108	6087	23	9D
0005434601107	6087	24	10C
0005434601113	6087	25	10D
0005433533350	6087	26	10E
0005434601102	6087	27	10F
0005432111313	6087	28	11A
0005434601117	6087	29	11C
0005434601111	6087	30	11D
0005434601118	6087	31	11F
0005434601105	6087	32	12C
0005435326763	6087	33	12E
0005433531337	6087	34	12F
0005435326772	6087	35	13A
0005435326766	6087	36	13C
0005435326746	6087	37	13E
0005434601109	6087	38	14A
0005435326755	6087	39	14D
0005434601116	6087	40	14E
0005433533349	6087	41	14F
0005433533352	6087	42	15A
0005435326849	6087	43	15D
0005435326850	6087	44	15E
0005434601120	6087	45	16C
0005434601103	6087	46	16E
0005433533353	6087	47	17A
0005434601121	6087	48	17C
0005432111312	6087	49	17E
0005434601124	6087	50	17F
0005434601122	6087	51	18C
0005434601114	6087	52	18F
0005434601123	6087	53	19C
0005434601104	6087	54	20D
0005435326768	6087	55	20F
0005434600971	18555	1	1C
0005434600748	18555	2	1D
0005434600978	18555	3	2A
0005434600878	18555	4	2F
0005433531297	18555	5	3A
0005434600800	18555	6	3D
0005434600798	18555	7	3F
0005434600935	18555	8	4A
0005434600966	18555	9	4C
0005434600863	18555	10	4D
0005433531296	18555	11	4F
0005435326904	18555	12	5C
0005433527255	18555	13	5D
0005435326897	18555	14	5E
0005435326907	18555	15	5F
0005433527257	18555	16	6A
0005435326905	18555	17	6C
0005434600930	18555	18	6D
0005434600938	18555	19	6F
0005434600903	18555	20	7A
0005434600891	18555	21	7C
0005434600918	18555	22	7F
0005434600865	18555	23	8A
0005434600816	18555	24	8C
0005435326903	18555	25	8D
0005433531288	18555	26	8F
0005433527271	18555	27	9C
0005434600775	18555	28	9D
0005435326898	18555	29	9F
0005433527277	18555	30	10A
0005433527259	18555	31	10C
0005435326900	18555	32	10D
0005435326906	18555	33	10E
0005434600815	18555	34	10F
0005434600936	18555	35	11A
0005433531293	18555	36	11C
0005433531287	18555	37	11E
0005434600953	18555	38	11F
0005434600959	18555	39	12A
0005434600805	18555	40	12C
0005434600799	18555	41	12E
0005433527254	18555	42	12F
0005434600902	18555	43	13A
0005434600862	18555	44	13C
0005434600861	18555	45	13D
0005433531305	18555	46	13F
0005434600879	18555	47	14A
0005434600967	18555	48	14D
0005433527272	18555	49	14E
0005434600790	18555	50	14F
0005434600982	18555	51	15C
0005434600901	18555	52	15E
0005434600980	18555	53	15F
0005434600831	18555	54	16A
0005434600952	18555	55	16C
0005433527258	18555	56	16F
0005433527263	18555	57	17A
0005435326899	18555	58	17E
0005435326902	18555	59	17D
0005434600998	18555	60	17F
0005434600939	18555	61	18C
0005435326894	18555	62	18D
0005434600826	18555	63	18E
0005434600981	18555	64	18F
0005434600919	18555	65	19C
0005435326895	18555	66	19E
0005433527260	18555	67	19F
0005435326901	18555	68	20A
0005434600860	18555	69	20C
0005435326896	18555	70	20E
0005433527264	18555	71	20F
0005434551799	10595	1	1A
0005434551797	10595	2	1C
0005433181225	10595	3	1D
0005434554085	10595	4	1F
0005434558360	10595	5	2A
0005434558355	10595	6	2C
0005434551804	10595	7	2D
0005433181065	10595	8	2F
0005434551823	10595	9	3A
0005434551769	10595	10	3C
0005434551810	10595	11	3D
0005433181214	10595	12	3F
0005433181139	10595	13	4A
0005434551816	10595	14	4C
0005433181215	10595	15	4D
0005434551813	10595	16	4E
0005434551814	10595	17	4F
0005434551772	10595	18	5A
0005433181206	10595	19	5C
0005433181049	10595	20	5D
0005434551788	10595	21	5E
0005434551809	10595	22	5F
0005434551800	10595	23	6A
0005434558356	10595	24	6C
0005433181226	10595	25	6D
0005434558357	10595	26	6E
0005434551775	10595	27	6F
0005433181072	10595	28	7A
0005433181133	10595	29	7C
0005434551818	10595	30	7D
0005433181168	10595	31	7E
0005434551793	10595	32	7F
0005434551782	10595	33	8A
0005433181169	10595	34	8C
0005434551807	10595	35	8D
0005433181147	10595	36	8E
0005434551801	10595	37	8F
0005434551805	10595	38	9A
0005433181071	10595	39	9C
0005433181151	10595	40	9D
0005433181167	10595	41	9E
0005434551786	10595	42	9F
0005434551815	10595	43	10C
0005434551790	10595	44	10D
0005433181080	10595	45	10E
0005434551796	10595	46	10F
0005434551803	10595	47	11A
0005433181207	10595	48	11C
0005434551777	10595	49	11D
0005434558358	10595	50	11E
0005434558362	10595	51	11F
0005434551783	10595	52	12A
0005434551808	10595	53	12C
0005434551812	10595	54	12D
0005433181158	10595	55	12E
0005433181183	10595	56	13C
0005434551785	10595	57	13A
0005434551776	10595	58	13D
0005433181182	10595	59	13E
0005434551784	10595	60	13F
0005434558364	10595	61	14A
0005434551774	10595	62	14C
0005434551792	10595	63	14D
0005434551819	10595	64	14E
0005434554086	10595	65	14F
0005434551791	10595	66	15A
0005434551768	10595	67	15C
0005434558363	10595	68	15D
0005434551820	10595	69	15E
0005434551773	10595	70	15F
0005434551795	10595	71	16C
0005434551787	10595	72	16D
0005433181160	10595	73	16E
0005434551770	10595	74	16F
0005434551821	10595	75	17A
0005434551794	10595	76	17C
0005433181142	10595	77	17D
0005434558359	10595	78	17E
0005434551778	10595	79	17F
0005433181234	10595	80	18A
0005434551779	10595	81	18C
0005434551817	10595	82	18D
0005434551780	10595	83	18E
0005434551822	10595	84	18F
0005434551771	10595	85	19A
0005434558354	10595	86	19C
0005434558361	10595	87	19D
0005434551789	10595	88	19E
0005434551781	10595	89	19F
0005434551802	10595	90	20A
0005434551806	10595	91	20C
0005434551798	10595	92	20D
0005434551811	10595	93	20E
0005433181050	10595	94	20F
0005433181392	27785	1	2D
0005433181387	27785	2	2F
0005433181380	27785	3	3A
0005433181385	27785	4	4A
0005433181395	27785	5	4E
0005433181397	27785	6	6D
0005433181394	27785	7	6E
0005433181382	27785	8	7C
0005433181396	27785	9	7E
0005433181386	27785	10	8F
0005433181374	27785	11	9D
0005433181381	27785	12	9E
0005433181379	27785	13	10A
0005433181390	27785	14	11E
0005433181384	27785	15	12C
0005433181375	27785	16	12D
0005433181393	27785	17	12F
0005433181376	27785	18	13A
0005433181398	27785	19	13C
0005433181373	27785	20	14A
0005433181383	27785	21	14F
0005433181378	27785	22	15A
0005433181377	27785	23	15C
0005433181388	27785	24	16E
0005433181391	27785	25	17E
0005433181389	27785	26	20C
0005433181372	27785	27	20D
0005434551520	27669	1	1C
0005434551224	27669	2	1F
0005434551102	27669	3	2A
0005434551487	27669	4	2C
0005434551290	27669	5	2D
0005434551538	27669	6	2F
0005434551302	27669	7	3C
0005434551329	27669	8	3F
0005434551534	27669	9	4C
0005434551445	27669	10	4D
0005434551396	27669	11	4F
0005434551394	27669	12	5A
0005434551176	27669	13	5C
0005434558280	27669	14	5D
0005434551610	27669	15	5E
0005434551376	27669	16	5F
0005434551350	27669	17	6A
0005434551425	27669	18	6C
0005434551552	27669	19	6D
0005434551362	27669	20	6E
0005434551301	27669	21	6F
0005434551159	27669	22	7A
0005434551488	27669	23	7C
0005434551446	27669	24	7D
0005434551399	27669	25	7E
0005434558281	27669	26	7F
0005434551237	27669	27	8A
0005434551388	27669	28	8C
0005434551226	27669	29	8D
0005434558285	27669	30	8E
0005434551434	27669	31	8F
0005434551215	27669	32	9A
0005434551416	27669	33	9C
0005434551183	27669	34	9E
0005434551467	27669	35	9F
0005434551225	27669	36	10A
0005434551269	27669	37	10C
0005434551346	27669	38	10D
0005434551314	27669	39	10E
0005434551341	27669	40	10F
0005434558283	27669	41	11C
0005434551432	27669	42	11D
0005434551500	27669	43	11E
0005434551379	27669	44	11F
0005434551383	27669	45	12A
0005434551590	27669	46	12C
0005434551328	27669	47	12E
0005434551295	27669	48	12F
0005434551233	27669	49	13A
0005434551347	27669	50	13C
0005434551444	27669	51	13D
0005434551387	27669	52	13E
0005434551325	27669	53	13F
0005434551340	27669	54	14A
0005434558284	27669	55	14C
0005434551378	27669	56	14D
0005434551324	27669	57	14F
0005434551501	27669	58	15A
0005434551422	27669	59	15C
0005434551216	27669	60	16A
0005434551481	27669	61	16C
0005434551238	27669	62	16D
0005434551587	27669	63	16E
0005434551403	27669	64	16F
0005434551368	27669	65	17A
0005434551309	27669	66	17C
0005434551524	27669	67	17D
0005434551198	27669	68	17E
0005434558302	27669	69	17F
0005434551443	27669	70	18A
0005434551421	27669	71	18C
0005434551395	27669	72	18D
0005434551289	27669	73	18E
0005434551535	27669	74	18F
0005434558301	27669	75	19A
0005434551367	27669	76	19C
0005434551363	27669	77	19D
0005434551212	27669	78	19E
0005434551433	27669	79	19F
0005434558279	27669	80	20A
0005434551401	27669	81	20C
0005434551291	27669	82	20E
0005434551351	27669	83	20F
0005433459265	6122	1	2A
0005433459267	6122	2	2B
0005433459266	6122	3	4A
0005433459268	6122	4	5B
0005433459222	19340	1	1A
0005433459217	19340	2	1B
0005433459223	19340	3	2A
0005435254501	19340	4	2B
0005433459224	19340	5	3A
0005433459241	19340	6	3B
0005433459232	19340	7	4A
0005433459242	19340	8	4B
0005433459233	19340	9	5A
0005433459234	19340	10	5B
0005433459216	19340	11	6A
0005435254500	19340	12	6B
0005435682592	6730	1	1A
0005435438126	6730	2	1C
0005435437961	6730	3	1D
0005435682586	6730	4	1F
0005432136224	6730	5	2A
0005432136222	6730	6	2C
0005435682572	6730	7	2D
0005435682588	6730	8	2F
0005432533296	6730	9	3A
0005435682578	6730	10	3C
0005435682569	6730	11	3D
0005435682605	6730	12	3F
0005435630999	6730	13	4A
0005435682573	6730	14	4C
0005432136226	6730	15	4D
0005434828705	6730	16	4E
0005435682577	6730	17	4F
0005435217714	6730	18	5A
0005435682570	6730	19	5C
0005435682580	6730	20	5D
0005435661963	6730	21	5E
0005435661962	6730	22	5F
0005435438062	6730	23	6A
0005432136225	6730	24	6C
0005434828706	6730	25	6E
0005435682596	6730	26	6F
0005435682589	6730	27	7A
0005435682571	6730	28	7C
0005432533298	6730	29	7D
0005435438087	6730	30	7E
0005432533295	6730	31	8A
0005435682590	6730	32	8C
0005435438086	6730	33	8D
0005435682568	6730	34	8E
0005435437986	6730	35	9A
0005435682599	6730	36	8F
0005435438036	6730	37	9C
0005435437924	6730	38	9D
0005435682576	6730	39	9E
0005435630997	6730	40	9F
0005435630998	6730	41	10A
0005435438018	6730	42	10C
0005435220328	6730	43	10D
0005435438060	6730	44	10E
0005435661961	6730	45	10F
0005435438127	6730	46	11A
0005435438019	6730	47	11F
0005435682579	6730	48	12A
0005432533291	6730	49	12C
0005432533292	6730	50	12D
0005435682582	6730	51	12E
0005435682563	6730	52	12F
0005435682602	6730	53	13A
0005435682565	6730	54	13C
0005435682595	6730	55	13D
0005435682601	6730	56	13E
0005435682583	6730	57	13F
0005435682567	6730	58	14A
0005435682581	6730	59	14C
0005435682600	6730	60	14D
0005435682575	6730	61	14E
0005435682603	6730	62	14F
0005435437851	6730	63	15A
0005432533293	6730	64	15C
0005435682561	6730	65	15D
0005435438061	6730	66	15E
0005432136223	6730	67	15F
0005435682562	6730	68	16C
0005432533294	6730	69	16D
0005435682593	6730	70	16E
0005435682594	6730	71	17A
0005435682566	6730	72	16F
0005435682574	6730	73	17C
0005435682598	6730	74	17D
0005434828703	6730	75	17E
0005435437852	6730	76	17F
0005435438040	6730	77	18A
0005435719572	6730	78	18C
0005434828707	6730	79	18D
0005435682585	6730	80	18E
0005435682597	6730	81	18F
0005435682591	6730	82	19A
0005435682564	6730	83	19C
0005435220322	6730	84	19D
0005434828702	6730	85	19E
0005435437942	6730	86	19F
0005435682587	6730	87	20A
0005435682584	6730	88	20C
0005435682604	6730	89	20D
0005435217715	6730	90	20E
0005435438039	6730	91	20F
0005435682124	24580	1	1A
0005435682024	24580	2	1C
0005432305777	24580	3	1D
0005435438196	24580	4	1F
0005435682065	24580	5	2A
0005435682279	24580	6	2C
0005435438192	24580	7	2F
0005435438207	24580	8	3A
0005435682267	24580	9	3C
0005435438201	24580	10	3D
0005435681947	24580	11	3F
0005435438209	24580	12	4A
0005435682211	24580	13	4C
0005435438199	24580	14	4D
0005435682458	24580	15	4E
0005435682336	24580	16	4F
0005435682104	24580	17	5C
0005435682240	24580	18	5D
0005435682150	24580	19	5F
0005435682236	24580	20	6A
0005435661936	24580	21	6C
0005435682155	24580	22	6D
0005435438194	24580	23	6E
0005435438189	24580	24	6F
0005435661939	24580	25	7A
0005435682046	24580	26	7C
0005435682188	24580	27	7D
0005432533326	24580	28	7E
0005435682165	24580	29	7F
0005435682158	24580	30	8A
0005432533324	24580	31	8C
0005435682253	24580	32	8D
0005435438193	24580	33	8E
0005435682232	24580	34	8F
0005435630982	24580	35	9A
0005435438203	24580	36	9C
0005435682268	24580	37	9D
0005435682321	24580	38	9E
0005435438191	24580	39	9F
0005435438208	24580	40	10A
0005435661937	24580	41	10C
0005435661934	24580	42	10D
0005435438197	24580	43	10E
0005435438204	24580	44	10F
0005435661933	24580	45	11A
0005435682397	24580	46	11C
0005435682350	24580	47	11D
0005434828730	24580	48	11E
0005434828728	24580	49	11F
0005435661931	24580	50	12A
0005435438188	24580	51	12C
0005435438206	24580	52	12E
0005435682191	24580	53	12F
0005435682254	24580	54	13A
0005435682139	24580	55	13C
0005435438200	24580	56	13D
0005435682406	24580	57	13F
0005435682456	24580	58	14A
0005435682357	24580	59	14C
0005435438190	24580	60	14D
0005435438210	24580	61	14E
0005435682337	24580	62	14F
0005434828729	24580	63	15A
0005435682225	24580	64	15C
0005435438198	24580	65	15D
0005435682066	24580	66	15E
0005435682109	24580	67	15F
0005435682277	24580	68	16A
0005435438202	24580	69	16D
0005435661940	24580	70	16E
0005435682315	24580	71	16F
0005435682152	24580	72	17A
0005432533325	24580	73	17C
0005435682199	24580	74	17D
0005435682269	24580	75	17E
0005435438205	24580	76	17F
0005435682398	24580	77	18A
0005435682173	24580	78	18C
0005435682457	24580	79	18D
0005435682338	24580	80	18E
0005432305776	24580	81	18F
0005435682149	24580	82	19A
0005435661932	24580	83	19C
0005435682271	24580	84	19E
0005435682278	24580	85	19F
0005435438195	24580	86	20A
0005435682023	24580	87	20C
0005435681950	24580	88	20D
0005435682243	24580	89	20E
0005435682114	24580	90	20F
0005435126805	11520	1	1D
0005435126794	11520	2	2A
0005435126774	11520	3	2D
0005435126812	11520	4	2F
0005435126800	11520	5	3A
0005435126785	11520	6	3C
0005435126788	11520	7	3D
0005435106014	11520	8	4A
0005435126780	11520	9	4F
0005435126797	11520	10	6A
0005435126802	11520	11	6E
0005435106015	11520	12	7D
0005435126789	11520	13	7F
0005435126781	11520	14	8D
0005435126806	11520	15	8F
0005435126790	11520	16	9A
0005435126799	11520	17	10A
0005435106016	11520	18	11A
0005435126786	11520	19	12A
0005435126783	11520	20	12E
0005435126792	11520	21	13C
0005435126803	11520	22	13E
0005435126793	11520	23	13F
0005435126811	11520	24	14E
0005435126782	11520	25	14F
0005435126796	11520	26	15A
0005435126772	11520	27	15C
0005435126804	11520	28	15D
0005435126771	11520	29	15E
0005435126791	11520	30	15F
0005435126808	11520	31	16A
0005435126773	11520	32	16C
0005435126776	11520	33	17C
0005435126795	11520	34	17D
0005435126777	11520	35	17E
0005435126809	11520	36	17F
0005435126779	11520	37	18D
0005435126787	11520	38	19C
0005435126778	11520	39	19D
0005435126798	11520	40	19E
0005435126810	11520	41	19F
0005435126784	11520	42	20A
0005435126807	11520	43	20C
0005435126801	11520	44	20D
0005435126775	11520	45	20E
0005435126569	31893	1	2A
0005435126568	31893	2	3C
0005435126574	31893	3	3F
0005435126362	31893	4	4C
0005435126545	31893	5	5C
0005435126505	31893	6	5D
0005435126375	31893	7	5F
0005435126463	31893	8	6C
0005435126474	31893	9	6D
0005435558115	31893	10	6E
0005435126672	31893	11	6F
0005435105990	31893	12	7A
0005435126485	31893	13	7D
0005435126310	31893	14	7E
0005435126466	31893	15	7F
0005435126521	31893	16	8A
0005435126573	31893	17	8D
0005435126636	31893	18	8E
0005435126508	31893	19	9C
0005435126335	31893	20	9E
0005435126436	31893	21	10A
0005435126475	31893	22	11C
0005435558117	31893	23	11F
0005435126320	31893	24	12A
0005435126493	31893	25	12C
0005435105987	31893	26	12F
0005435126635	31893	27	13A
0005435126342	31893	28	13D
0005435126435	31893	29	14C
0005435558116	31893	30	15C
0005435105989	31893	31	15E
0005435126311	31893	32	16E
0005435126590	31893	33	17C
0005435126589	31893	34	17D
0005435126538	31893	35	17E
0005435126566	31893	36	18A
0005435098566	31893	37	18C
0005435126506	31893	38	19E
0005435105986	31893	39	20A
0005435126673	31893	40	20C
0005433398594	13557	1	1A
0005433398593	13557	2	1C
0005433398596	13557	3	2A
0005433398602	13557	4	2D
0005433398601	13557	5	2F
0005433398600	13557	6	3A
0005433398581	13557	7	3D
0005433398591	13557	8	3F
0005433398608	13557	9	4D
0005433398598	13557	10	4E
0005435732371	13557	11	5A
0005433398609	13557	12	5E
0005433398587	13557	13	5F
0005433398619	13557	14	6C
0005433398616	13557	15	6D
0005433398584	13557	16	6F
0005433398582	13557	17	7C
0005433398590	13557	18	7E
0005433398577	13557	19	8A
0005433398604	13557	20	8C
0005433398592	13557	21	8E
0005433398603	13557	22	8F
0005433398586	13557	23	9A
0005433398595	13557	24	9E
0005433398578	13557	25	9F
0005433398571	13557	26	10A
0005433398614	13557	27	10C
0005433398599	13557	28	10E
0005433398597	13557	29	10F
0005433398579	13557	30	11A
0005433398617	13557	31	11C
0005433398575	13557	32	11D
0005435732403	13557	33	11F
0005433398615	13557	34	12A
0005433398572	13557	35	12D
0005433398613	13557	36	12E
0005433398605	13557	37	13A
0005433398583	13557	38	13D
0005433398589	13557	39	13E
0005433398580	13557	40	13F
0005435732344	13557	41	14A
0005433398618	13557	42	14D
0005433398620	13557	43	14F
0005435732372	13557	44	15D
0005435732419	13557	45	15E
0005435732385	13557	46	16A
0005433398607	13557	47	16F
0005435732317	13557	48	17C
0005433398573	13557	49	17E
0005433398606	13557	50	17F
0005433398585	13557	51	18A
0005435732337	13557	52	18C
0005433398621	13557	53	18F
0005435732439	13557	54	18E
0005433398576	13557	55	19A
0005433398574	13557	56	19C
0005433398610	13557	57	19E
0005435732338	13557	58	20A
0005433398612	13557	59	20C
0005433398611	13557	60	20D
0005433398588	13557	61	20F
0005435732485	19424	1	1A
0005433398189	19424	2	1C
0005433398221	19424	3	1D
0005433398063	19424	4	1F
0005433398161	19424	5	2C
0005433398025	19424	6	2D
0005433398153	19424	7	3A
0005433398185	19424	8	3C
0005435732490	19424	9	3D
0005433398208	19424	10	3F
0005433398320	19424	11	4C
0005433398186	19424	12	4D
0005435732482	19424	13	4E
0005433398171	19424	14	4F
0005433398047	19424	15	5A
0005433398240	19424	16	5C
0005433398018	19424	17	5F
0005433398261	19424	18	6C
0005433398113	19424	19	6D
0005433398152	19424	20	6E
0005433398154	19424	21	6F
0005433398200	19424	22	7A
0005433398108	19424	23	7E
0005433398105	19424	24	8A
0005433398292	19424	25	8C
0005433398228	19424	26	8E
0005435732483	19424	27	8F
0005433398250	19424	28	9A
0005433398088	19424	29	9C
0005435732486	19424	30	9E
0005433398220	19424	31	9F
0005433398081	19424	32	10D
0005433398181	19424	33	10E
0005435732492	19424	34	10F
0005433398132	19424	35	11A
0005433398036	19424	36	11C
0005435732484	19424	37	11D
0005433398162	19424	38	11E
0005435732489	19424	39	12C
0005433398321	19424	40	12D
0005433398098	19424	41	12E
0005433398011	19424	42	12F
0005433397793	19424	43	13C
0005433398133	19424	44	13D
0005433398342	19424	45	13E
0005433398046	19424	46	13F
0005433398231	19424	47	14A
0005435732488	19424	48	14C
0005433398064	19424	49	14E
0005433398160	19424	50	14F
0005433398117	19424	51	15A
0005433398306	19424	52	15C
0005433398176	19424	53	15D
0005433398257	19424	54	15E
0005433398232	19424	55	15F
0005432297307	19424	56	16A
0005435732487	19424	57	16E
0005433398229	19424	58	17C
0005433398262	19424	59	17E
0005433398170	19424	60	18A
0005433398258	19424	61	18C
0005435732491	19424	62	19A
0005432297306	19424	63	19C
0005433398013	19424	64	19D
0005433398296	19424	65	19F
0005433398019	19424	66	20A
0005433398045	19424	67	20C
0005433398319	19424	68	20E
0005435069197	13135	1	1A
0005435925447	13135	2	1C
0005435925460	13135	3	1D
0005435069227	13135	4	2A
0005435069179	13135	5	2C
0005435925442	13135	6	2F
0005435925453	13135	7	3A
0005435069339	13135	8	3D
0005435069115	13135	9	3F
0005435925451	13135	10	4A
0005435925454	13135	11	4E
0005435069291	13135	12	4F
0005435069313	13135	13	5A
0005435069211	13135	14	5C
0005435925444	13135	15	5D
0005435069281	13135	16	5E
0005435068884	13135	17	5F
0005435069131	13135	18	6A
0005435069330	13135	19	6C
0005435069216	13135	20	6E
0005435069348	13135	21	7C
0005435069168	13135	22	7D
0005435069073	13135	23	7E
0005435069314	13135	24	7F
0005435068937	13135	25	8A
0005435069137	13135	26	8C
0005435925438	13135	27	8E
0005435925441	13135	28	9A
0005435925461	13135	29	9C
0005435925448	13135	30	9F
0005435925455	13135	31	10A
0005435069274	13135	32	10C
0005435069138	13135	33	10D
0005435925446	13135	34	10E
0005435925443	13135	35	10F
0005435068929	13135	36	11A
0005435069258	13135	37	11D
0005435069329	13135	38	11E
0005435068985	13135	39	11F
0005435069346	13135	40	12A
0005435925457	13135	41	12C
0005435069063	13135	42	12D
0005435068986	13135	43	12E
0005435069280	13135	44	12F
0005435069312	13135	45	13A
0005435925456	13135	46	13C
0005435925452	13135	47	13E
0005435069128	13135	48	13F
0005435069027	13135	49	14A
0005435925439	13135	50	14C
0005435925449	13135	51	14D
0005435069160	13135	52	14F
0005435069217	13135	53	15D
0005435069218	13135	54	15E
0005435069142	13135	55	15F
0005435069349	13135	56	16A
0005435069167	13135	57	16C
0005435069386	13135	58	16D
0005435925440	13135	59	16E
0005435069144	13135	60	16F
0005435925458	13135	61	17A
0005435069205	13135	62	17C
0005435069092	13135	63	17D
0005435925450	13135	64	17E
0005435069116	13135	65	18A
0005435069225	13135	66	18C
0005435069226	13135	67	18E
0005435069345	13135	68	18F
0005435069331	13135	69	19A
0005435069143	13135	70	19C
0005435925459	13135	71	19D
0005435925445	13135	72	19E
0005435069044	13135	73	19F
0005435068936	13135	74	20C
0005435069363	13135	75	20E
0005435069615	15491	1	1C
0005435069631	15491	2	1D
0005435069634	15491	3	2A
0005435925311	15491	4	2F
0005435069632	15491	5	2D
0005435069590	15491	6	3C
0005435069604	15491	7	3D
0005435069642	15491	8	3F
0005435069614	15491	9	4C
0005435069628	15491	10	4D
0005435069638	15491	11	4E
0005435069597	15491	12	4F
0005435069622	15491	13	5A
0005435069592	15491	14	5C
0005435069605	15491	15	5D
0005435069616	15491	16	5E
0005435069641	15491	17	5F
0005435069596	15491	18	6A
0005435069629	15491	19	6D
0005435069620	15491	20	6E
0005435069594	15491	21	6F
0005435069600	15491	22	7A
0005435925313	15491	23	7C
0005435069619	15491	24	7F
0005435925312	15491	25	8C
0005435069598	15491	26	8D
0005435069608	15491	27	8E
0005435069624	15491	28	8F
0005435925288	15491	29	9A
0005435069612	15491	30	9D
0005435925307	15491	31	9F
0005435069630	15491	32	10A
0005435069601	15491	33	10D
0005435069599	15491	34	10E
0005435069610	15491	35	10F
0005435069639	15491	36	11A
0005435069607	15491	37	11C
0005435069626	15491	38	11D
0005435925277	15491	39	11F
0005435069589	15491	40	12A
0005435069606	15491	41	12E
0005435069637	15491	42	12F
0005435069625	15491	43	13A
0005435069613	15491	44	13C
0005435069633	15491	45	13E
0005435069611	15491	46	14A
0005435069609	15491	47	14D
0005435925297	15491	48	14E
0005435069591	15491	49	15A
0005435925295	15491	50	15C
0005435069603	15491	51	15E
0005435069636	15491	52	16A
0005435925298	15491	53	16C
0005435069623	15491	54	16D
0005435069602	15491	55	16E
0005435069621	15491	56	16F
0005435069618	15491	57	17A
0005435069635	15491	58	17E
0005435069640	15491	59	18C
0005435069595	15491	60	19A
0005435069617	15491	61	19C
0005435925296	15491	62	19D
0005435069593	15491	63	19E
0005435925306	15491	64	19F
0005435069627	15491	65	20A
0005435808227	29487	1	1A
0005433407616	29487	2	1C
0005435808180	29487	3	1D
0005435808228	29487	4	2A
0005435808168	29487	5	2B
0005433407622	29487	6	2D
0005435808237	29487	7	3A
0005433407626	29487	8	3C
0005433407624	29487	9	3D
0005435808256	29487	10	4A
0005435808175	29487	11	4B
0005435808274	29487	12	4C
0005435808204	29487	13	4D
0005435808241	29487	14	5A
0005435808217	29487	15	5B
0005435808226	29487	16	5C
0005433407612	29487	17	5D
0005435808231	29487	18	6B
0005433407625	29487	19	6C
0005433407620	29487	20	6D
0005435808283	29487	21	7A
0005435808280	29487	22	7B
0005433407613	29487	23	7C
0005433407614	29487	24	18A
0005435808179	29487	25	18B
0005435808265	29487	26	18C
0005435808239	29487	27	18D
0005435808219	29487	28	19A
0005435808187	29487	29	19B
0005435808242	29487	30	19C
0005433407621	29487	31	19D
0005435808232	29487	32	20D
0005435808244	29487	33	21A
0005435808220	29487	34	21B
0005433407619	29487	35	21D
0005433407615	29487	36	22A
0005433407617	29487	37	22B
0005433407618	29487	38	22C
0005433407623	29487	39	22D
0005435808200	29487	40	23A
0005434215049	10691	1	6F
0005434756554	10691	2	1A
0005434756504	10691	3	1C
0005434215058	10691	4	1D
0005434756483	10691	5	1F
0005434215046	10691	6	2A
0005434756521	10691	7	2C
0005434756581	10691	8	2D
0005434215067	10691	9	2F
0005434756451	10691	10	3A
0005434756484	10691	11	3C
0005434215036	10691	12	3D
0005434756384	10691	13	3F
0005434756450	10691	14	4A
0005434756452	10691	15	4C
0005434756465	10691	16	4D
0005434756502	10691	17	4E
0005434756389	10691	18	4F
0005434756492	10691	19	5A
0005434215069	10691	20	5C
0005434756539	10691	21	5D
0005434215074	10691	22	5F
0005434215048	10691	23	6A
0005434756482	10691	24	6C
0005434215065	10691	25	6D
0005434756553	10691	26	6E
0005434756390	10691	27	7A
0005434756413	10691	28	7C
0005434215039	10691	29	7D
0005434215030	10691	30	7E
0005434756415	10691	31	7F
0005434215044	10691	32	8A
0005434215031	10691	33	8C
0005434756445	10691	34	8E
0005434756366	10691	35	8F
0005434215060	10691	36	9A
0005434215054	10691	37	9C
0005434215055	10691	38	9D
0005434756242	10691	39	9E
0005434756515	10691	40	9F
0005434215059	10691	41	10A
0005434756493	10691	42	10C
0005434215076	10691	43	10D
0005434215061	10691	44	10E
0005434756463	10691	45	10F
0005434756440	10691	46	11A
0005434756556	10691	47	11C
0005434215047	10691	48	11D
0005434215041	10691	49	11E
0005434215050	10691	50	11F
0005434756503	10691	51	12A
0005434756449	10691	52	12C
0005434215053	10691	53	12D
0005434215063	10691	54	12E
0005434215032	10691	55	12F
0005434756466	10691	56	13A
0005434756441	10691	57	13C
0005434756516	10691	58	13D
0005434215071	10691	59	13E
0005434215034	10691	60	13F
0005434756462	10691	61	14A
0005434215033	10691	62	14C
0005434215056	10691	63	14D
0005434215057	10691	64	14E
0005434215073	10691	65	14F
0005434756444	10691	66	15A
0005434215072	10691	67	15C
0005434756498	10691	68	15D
0005434215042	10691	69	15E
0005434756432	10691	70	15F
0005434215068	10691	71	16A
0005434215045	10691	72	16C
0005434215075	10691	73	16D
0005434215062	10691	74	16E
0005434756560	10691	75	16F
0005434756477	10691	76	17A
0005434215070	10691	77	17C
0005434756494	10691	78	17D
0005434756550	10691	79	17E
0005434756520	10691	80	17F
0005434215052	10691	81	18A
0005434756555	10691	82	18C
0005434215066	10691	83	18D
0005434756431	10691	84	18E
0005434215035	10691	85	18F
0005434215038	10691	86	19A
0005434756443	10691	87	19C
0005434215077	10691	88	19D
0005434215043	10691	89	19E
0005434215064	10691	90	19F
0005434215037	10691	91	20A
0005434756517	10691	92	20C
0005434215051	10691	93	20D
0005434756549	10691	94	20E
0005434215040	10691	95	20F
0005434756863	28691	1	1A
0005434756867	28691	2	1C
0005434214760	28691	3	1D
0005434214346	28691	4	1F
0005434214577	28691	5	2A
0005434756845	28691	6	2C
0005434756840	28691	7	2D
0005434756880	28691	8	2F
0005434756847	28691	9	3A
0005434756879	28691	10	3C
0005434214782	28691	11	3D
0005434214615	28691	12	3F
0005434214635	28691	13	4A
0005434214412	28691	14	4C
0005434214781	28691	15	4D
0005434214498	28691	16	4E
0005434214575	28691	17	4F
0005434756843	28691	18	5A
0005434214619	28691	19	5C
0005434756854	28691	20	5D
0005434756859	28691	21	5E
0005434756860	28691	22	5F
0005434214757	28691	23	6A
0005434214611	28691	24	6C
0005434214614	28691	25	6D
0005434756872	28691	26	6E
0005434214338	28691	27	6F
0005434214490	28691	28	7A
0005434756850	28691	29	7C
0005434214509	28691	30	7D
0005434214583	28691	31	7E
0005434756851	28691	32	7F
0005434214636	28691	33	8A
0005434756858	28691	34	8C
0005434756877	28691	35	8D
0005434214463	28691	36	8E
0005434214756	28691	37	8F
0005434214623	28691	38	9A
0005434214527	28691	39	9C
0005434214526	28691	40	9D
0005434756868	28691	41	9E
0005434214567	28691	42	9F
0005434214538	28691	43	10A
0005434214783	28691	44	10C
0005434756853	28691	45	10D
0005434756871	28691	46	10E
0005434756876	28691	47	10F
0005434214447	28691	48	11A
0005434756856	28691	49	11C
0005434756874	28691	50	11D
0005434214468	28691	51	11E
0005434214638	28691	52	11F
0005434214568	28691	53	12A
0005434214438	28691	54	12C
0005434214616	28691	55	12D
0005434214516	28691	56	12E
0005434214576	28691	57	12F
0005434214411	28691	58	13A
0005434756870	28691	59	13C
0005434756869	28691	60	13D
0005434214758	28691	61	13E
0005434756849	28691	62	13F
0005434214464	28691	63	14A
0005434214564	28691	64	14C
0005434756864	28691	65	14D
0005434214711	28691	66	14E
0005434756873	28691	67	14F
0005434214649	28691	68	15A
0005434214466	28691	69	15C
0005434756841	28691	70	15D
0005434214755	28691	71	15E
0005434756865	28691	72	15F
0005434214524	28691	73	16A
0005434756855	28691	74	16C
0005434756842	28691	75	16D
0005434756862	28691	76	16E
0005434214618	28691	77	16F
0005434214440	28691	78	17A
0005434756861	28691	79	17C
0005434756852	28691	80	17D
0005434214363	28691	81	17E
0005434214446	28691	82	17F
0005434756848	28691	83	18A
0005434756878	28691	84	18C
0005434756846	28691	85	18D
0005434214685	28691	86	18E
0005434214759	28691	87	18F
0005434214439	28691	88	19A
0005434214574	28691	89	19C
0005434214569	28691	90	19D
0005434214508	28691	91	19E
0005434756875	28691	92	19F
0005434756844	28691	93	20A
0005434214542	28691	94	20C
0005434756866	28691	95	20D
0005434756857	28691	96	20E
0005434214525	28691	97	20F
0005432125537	5434	1	1A
0005435040454	5434	2	1C
0005435040502	5434	3	1D
0005435007288	5434	4	1F
0005435007302	5434	5	2C
0005434229489	5434	6	2A
0005434229359	5434	7	2D
0005435040487	5434	8	2F
0005435040494	5434	9	3C
0005435007299	5434	10	3A
0005435040478	5434	11	3D
0005435040467	5434	12	3F
0005435007293	5434	13	4A
0005435040500	5434	14	4B
0005435040490	5434	15	4D
0005434229560	5434	16	4C
0005435040459	5434	17	4E
0005434229404	5434	18	4F
0005435040516	5434	19	5A
0005435040463	5434	20	5C
0005435007292	5434	21	5B
0005435040465	5434	22	5D
0005435007279	5434	23	5E
0005435040486	5434	24	6A
0005435040482	5434	25	5F
0005435007301	5434	26	6C
0005435040489	5434	27	6B
0005435040473	5434	28	6D
0005435007295	5434	29	6F
0005434229379	5434	30	6E
0005435007280	5434	31	7A
0005434229393	5434	32	7C
0005435007285	5434	33	7B
0005435040501	5434	34	7D
0005435040466	5434	35	7E
0005435040498	5434	36	8A
0005435040488	5434	37	7F
0005435040462	5434	38	8B
0005434229340	5434	39	8C
0005435040475	5434	40	8D
0005434229341	5434	41	8F
0005435040477	5434	42	8E
0005434229363	5434	43	9A
0005434229360	5434	44	9B
0005434229342	5434	45	9D
0005435007281	5434	46	9C
0005435007296	5434	47	9E
0005435040497	5434	48	9F
0005435007298	5434	49	10C
0005432125536	5434	50	10B
0005434229364	5434	51	10E
0005432125532	5434	52	10D
0005435040464	5434	53	11A
0005435007297	5434	54	11B
0005434229559	5434	55	11C
0005435040456	5434	56	11E
0005435040514	5434	57	11D
0005435040468	5434	58	11F
0005435040515	5434	59	12A
0005435040480	5434	60	12C
0005435040476	5434	61	12B
0005434229394	5434	62	12D
0005434229405	5434	63	12E
0005435040481	5434	64	12F
0005435007300	5434	65	13B
0005435040460	5434	66	13A
0005435007283	5434	67	13C
0005435007286	5434	68	13F
0005435040511	5434	69	13E
0005435040470	5434	70	13D
0005435040455	5434	71	14A
0005435040469	5434	72	14C
0005434229423	5434	73	14B
0005432125538	5434	74	14D
0005434229448	5434	75	14E
0005435040471	5434	76	14F
0005435007287	5434	77	15A
0005435040491	5434	78	15C
0005434229447	5434	79	15B
0005435007291	5434	80	15D
0005434229441	5434	81	15E
0005435007303	5434	82	16A
0005434229249	5434	83	15F
0005432125531	5434	84	16B
0005435040495	5434	85	16D
0005434229422	5434	86	16C
0005435040479	5434	87	16E
0005435040452	5434	88	16F
0005435040474	5434	89	17A
0005435040461	5434	90	17B
0005435040512	5434	91	17C
0005434229380	5434	92	17D
0005435040505	5434	93	17F
0005435007282	5434	94	17E
0005435040451	5434	95	18A
0005434229362	5434	96	18B
0005435007290	5434	97	18C
0005434229250	5434	98	18E
0005435040458	5434	99	18D
0005435040506	5434	100	18F
0005435007278	5434	101	19A
0005435040493	5434	102	19B
0005432125535	5434	103	19C
0005435040485	5434	104	19E
0005434229454	5434	105	19D
0005435007294	5434	106	19F
0005435040492	5434	107	20A
0005434229496	5434	108	20B
0005434229453	5434	109	20D
0005435040508	5434	110	20C
0005435040472	5434	111	20E
0005435040509	5434	112	20F
0005434229361	5434	113	21B
0005435040513	5434	114	21A
0005435040499	5434	115	21C
0005435040483	5434	116	21D
0005434229397	5434	117	21E
0005435040507	5434	118	21F
0005435040504	5434	119	22A
0005434229479	5434	120	22C
0005435040453	5434	121	22B
0005435040503	5434	122	22D
0005435040484	5434	123	22E
0005435040457	5434	124	22F
0005435040510	5434	125	23B
0005432125533	5434	126	23A
0005435007284	5434	127	23C
0005435040496	5434	128	23E
0005435007289	5434	129	23D
0005432125534	5434	130	23F
0005435040074	12984	1	1A
0005435039942	12984	2	1C
0005435040110	12984	3	1D
0005435042849	12984	4	1F
0005435042856	12984	5	2C
0005435040156	12984	6	2A
0005435007031	12984	7	2D
0005435039815	12984	8	2F
0005435043289	12984	9	3A
0005435042850	12984	10	3D
0005435039822	12984	11	3C
0005435040052	12984	12	3F
0005435039987	12984	13	4A
0005435039996	12984	14	4B
0005432304441	12984	15	4D
0005435039821	12984	16	4C
0005435042861	12984	17	4E
0005435007097	12984	18	4F
0005435042871	12984	19	5B
0005435039960	12984	20	5A
0005435042870	12984	21	5C
0005434229625	12984	22	5D
0005435039941	12984	23	5E
0005435040115	12984	24	5F
0005434229627	12984	25	6A
0005435039887	12984	26	6C
0005435042851	12984	27	6B
0005434229614	12984	28	6D
0005435039813	12984	29	6F
0005435007127	12984	30	7B
0005435042863	12984	31	7A
0005435040111	12984	32	7C
0005435040088	12984	33	7D
0005435040286	12984	34	8A
0005435039832	12984	35	7F
0005435039943	12984	36	8B
0005435040061	12984	37	8C
0005435040047	12984	38	8D
0005435039748	12984	39	8E
0005435039761	12984	40	9A
0005435007101	12984	41	9B
0005435039809	12984	42	9D
0005435007139	12984	43	9C
0005435040102	12984	44	9E
0005435007117	12984	45	9F
0005435040006	12984	46	10B
0005435007113	12984	47	10D
0005434229634	12984	48	10C
0005435039749	12984	49	10E
0005434229636	12984	50	11A
0005435040025	12984	51	11B
0005432304442	12984	52	11C
0005435039963	12984	53	11E
0005435039814	12984	54	11D
0005435040155	12984	55	12B
0005435042865	12984	56	12D
0005434229616	12984	57	12E
0005434229637	12984	58	12F
0005435007103	12984	59	13A
0005435007183	12984	60	13C
0005434229635	12984	61	13B
0005434229623	12984	62	13D
0005434229628	12984	63	13E
0005434229620	12984	64	13F
0005435007114	12984	65	14B
0005435039867	12984	66	14A
0005434229622	12984	67	14C
0005435039795	12984	68	14E
0005434229630	12984	69	15A
0005435040285	12984	70	14F
0005435039830	12984	71	15C
0005435039796	12984	72	15B
0005435039921	12984	73	15D
0005435039770	12984	74	15E
0005435039947	12984	75	16A
0005434229638	12984	76	15F
0005435042862	12984	77	16B
0005435039823	12984	78	16D
0005435042859	12984	79	16C
0005434229626	12984	80	16F
0005434229613	12984	81	16E
0005435039961	12984	82	17B
0005434229619	12984	83	17C
0005435040046	12984	84	17E
0005435039890	12984	85	17D
0005435040157	12984	86	17F
0005435039706	12984	87	18A
0005434229629	12984	88	18B
0005435039886	12984	89	18C
0005435039880	12984	90	18E
0005434229631	12984	91	18D
0005435042857	12984	92	18F
0005435007065	12984	93	19A
0005434229617	12984	94	19B
0005435039962	12984	95	19E
0005432304443	12984	96	19F
0005435007146	12984	97	20A
0005435007147	12984	98	20B
0005435040140	12984	99	20C
0005435040112	12984	100	20E
0005432304440	12984	101	20D
0005435040019	12984	102	21A
0005434229615	12984	103	20F
0005435039754	12984	104	21B
0005435042869	12984	105	21C
0005435007116	12984	106	21D
0005435040075	12984	107	21E
0005434229632	12984	108	21F
0005435039866	12984	109	22B
0005434229633	12984	110	22C
0005434229618	12984	111	22F
0005435040020	12984	112	22E
0005434229621	12984	113	23A
0005435007134	12984	114	23B
0005435039910	12984	115	23C
0005435039881	12984	116	23E
0005434229624	12984	117	23D
0005435040048	12984	118	23F
0005435902726	14876	1	1A
0005435902797	14876	2	1C
0005434426925	14876	3	1D
0005434411822	14876	4	1F
0005434426923	14876	5	2C
0005434426908	14876	6	2D
0005435902652	14876	7	2F
0005434426924	14876	8	3C
0005434426912	14876	9	4A
0005435902748	14876	10	4C
0005435902680	14876	11	4D
0005434426920	14876	12	5A
0005434426902	14876	13	5C
0005434426914	14876	14	5D
0005434426918	14876	15	5E
0005434426900	14876	16	5F
0005435902653	14876	17	6C
0005434426915	14876	18	7A
0005434426913	14876	19	7D
0005432188642	14876	20	7F
0005434426922	14876	21	8C
0005435902764	14876	22	8D
0005434426903	14876	23	8E
0005434426919	14876	24	8F
0005435902679	14876	25	9A
0005434411824	14876	26	9E
0005434426904	14876	27	10C
0005434411825	14876	28	10D
0005432188640	14876	29	10E
0005434426901	14876	30	10F
0005434426911	14876	31	11A
0005434411823	14876	32	11C
0005434426927	14876	33	11F
0005434426905	14876	34	12A
0005434426928	14876	35	12D
0005434426906	14876	36	12E
0005434426921	14876	37	12F
0005435902697	14876	38	13D
0005434426910	14876	39	13E
0005432188643	14876	40	14D
0005435554188	14876	41	15A
0005435902798	14876	42	15D
0005435902678	14876	43	15F
0005434411821	14876	44	16A
0005435902686	14876	45	16E
0005434426907	14876	46	17A
0005434426916	14876	47	17C
0005434426909	14876	48	17E
0005435554182	14876	49	17F
0005435902773	14876	50	18C
0005434426926	14876	51	18E
0005435902779	14876	52	18F
0005435902687	14876	53	19A
0005432188641	14876	54	19C
0005434426917	14876	55	19D
0005435902750	14876	56	20A
0005435902701	14876	57	20F
0005434411776	20192	1	1C
0005434426686	20192	2	1D
0005434426604	20192	3	2C
0005435902909	20192	4	2D
0005435902912	20192	5	3A
0005435902899	20192	6	3D
0005435902910	20192	7	3F
0005435902903	20192	8	4C
0005434411782	20192	9	4D
0005434426679	20192	10	4F
0005435554246	20192	11	5C
0005434426619	20192	12	5E
0005435902906	20192	13	6A
0005434426715	20192	14	6C
0005432059526	20192	15	6D
0005434426685	20192	16	6E
0005434426585	20192	17	6F
0005434426761	20192	18	7C
0005435902913	20192	19	7D
0005435902895	20192	20	7E
0005435902896	20192	21	8A
0005434426632	20192	22	8C
0005434426606	20192	23	8F
0005434411768	20192	24	9C
0005435902898	20192	25	9F
0005434426737	20192	26	10C
0005434426807	20192	27	10F
0005434426620	20192	28	11A
0005435554242	20192	29	11C
0005432059527	20192	30	11D
0005434426621	20192	31	11E
0005434426733	20192	32	11F
0005434426706	20192	33	12D
0005435902897	20192	34	12E
0005434426615	20192	35	13A
0005435902911	20192	36	13D
0005434426528	20192	37	13E
0005435554244	20192	38	14A
0005435902904	20192	39	14C
0005434426633	20192	40	14F
0005435902905	20192	41	15A
0005434426738	20192	42	15C
0005435902902	20192	43	15D
0005434426663	20192	44	15E
0005435554245	20192	45	15F
0005434426586	20192	46	16A
0005434426710	20192	47	16D
0005434426793	20192	48	16E
0005435902908	20192	49	16F
0005434426734	20192	50	17A
0005434411796	20192	51	17D
0005435902900	20192	52	17F
0005434426808	20192	53	18A
0005435902907	20192	54	18C
0005435902901	20192	55	18D
0005434426595	20192	56	18E
0005434426649	20192	57	19A
0005434426739	20192	58	19D
0005435554241	20192	59	19E
0005434426631	20192	60	19F
0005435554243	20192	61	20C
0005434270210	26509	1	1A
0005432300324	26509	2	1C
0005433434685	26509	3	1D
0005432300325	26509	4	2A
0005433434804	26509	5	2C
0005435982791	26509	6	2D
0005435982784	26509	7	2F
0005433434808	26509	8	3A
0005432300323	26509	9	3C
0005435982769	26509	10	3D
0005433434734	26509	11	3F
0005435982790	26509	12	4A
0005433434684	26509	13	4C
0005433434640	26509	14	4D
0005435982798	26509	15	4E
0005433434754	26509	16	4F
0005435982781	26509	17	5C
0005435982779	26509	18	5D
0005435982788	26509	19	5E
0005435982782	26509	20	5F
0005433434733	26509	21	6A
0005435982785	26509	22	6C
0005435982786	26509	23	6D
0005435982808	26509	24	6E
0005435982797	26509	25	6F
0005435982767	26509	26	7A
0005435982787	26509	27	7C
0005435982800	26509	28	7D
0005435982774	26509	29	7E
0005435982768	26509	30	7F
0005435982806	26509	31	8A
0005433434802	26509	32	8C
0005432300326	26509	33	8D
0005433434659	26509	34	9A
0005435982783	26509	35	9D
0005433434691	26509	36	9E
0005433434793	26509	37	9F
0005433434660	26509	38	10A
0005435982789	26509	39	10C
0005433434764	26509	40	10D
0005433434803	26509	41	10E
0005435982778	26509	42	10F
0005432300322	26509	43	11A
0005433434807	26509	44	11D
0005435982780	26509	45	11E
0005435982805	26509	46	11F
0005435982807	26509	47	12A
0005434270211	26509	48	12D
0005435982771	26509	49	12E
0005435982795	26509	50	12F
0005433434747	26509	51	13A
0005435982804	26509	52	13C
0005433434755	26509	53	13D
0005435982776	26509	54	13E
0005433434714	26509	55	14A
0005433434757	26509	56	14C
0005435982802	26509	57	14D
0005433434784	26509	58	14E
0005435982772	26509	59	14F
0005434273079	26509	60	15A
0005435982793	26509	61	15C
0005434273078	26509	62	15D
0005433434655	26509	63	15E
0005435982794	26509	64	16A
0005435982809	26509	65	16C
0005435982792	26509	66	16D
0005435982770	26509	67	16E
0005433434641	26509	68	17A
0005433434656	26509	69	17C
0005435982799	26509	70	17D
0005435982796	26509	71	17E
0005435982777	26509	72	17F
0005435982811	26509	73	18A
0005435982803	26509	74	18D
0005435982810	26509	75	18E
0005433434614	26509	76	18F
0005432300321	26509	77	19A
0005433434644	26509	78	19C
0005435982775	26509	79	19D
0005435982773	26509	80	19E
0005435982801	26509	81	19F
0005433434739	26509	82	20A
0005433434758	26509	83	20D
0005433434683	26509	84	20E
0005433434738	26509	85	20F
0005432051163	26730	1	1C
0005435982378	26730	2	1D
0005435982088	26730	3	1F
0005435982512	26730	4	2C
0005433435012	26730	5	2A
0005435982482	26730	6	2D
0005435982471	26730	7	2F
0005435982407	26730	8	3A
0005434269126	26730	9	3C
0005435982381	26730	10	3D
0005435982279	26730	11	3F
0005435982393	26730	12	4A
0005435982358	26730	13	4D
0005433435008	26730	14	4E
0005433435005	26730	15	4F
0005433435011	26730	16	5A
0005433434998	26730	17	5C
0005432051162	26730	18	5D
0005435982242	26730	19	5E
0005433434990	26730	20	5F
0005435982278	26730	21	6A
0005432051164	26730	22	6C
0005435982526	26730	23	6D
0005435982515	26730	24	6E
0005433435004	26730	25	6F
0005435982331	26730	26	7A
0005433435014	26730	27	7E
0005433434999	26730	28	8A
0005435982628	26730	29	8C
0005435982472	26730	30	8D
0005435982356	26730	31	8E
0005433435003	26730	32	9A
0005435982321	26730	33	9C
0005435982410	26730	34	9D
0005435982359	26730	35	9F
0005433434991	26730	36	10A
0005433434996	26730	37	10C
0005435982411	26730	38	10D
0005434270230	26730	39	10E
0005433434997	26730	40	10F
0005433435000	26730	41	11A
0005434271336	26730	42	11C
0005433435013	26730	43	11D
0005435982383	26730	44	11E
0005435982089	26730	45	11F
0005433435009	26730	46	12A
0005433435007	26730	47	12C
0005435982346	26730	48	12D
0005435982384	26730	49	12E
0005435982149	26730	50	12F
0005435982416	26730	51	13A
0005435982377	26730	52	13C
0005435982379	26730	53	13D
0005435982418	26730	54	13E
0005433434993	26730	55	13F
0005433435006	26730	56	14C
0005435982483	26730	57	14D
0005433434988	26730	58	14E
0005433435010	26730	59	14F
0005433434992	26730	60	15A
0005435982575	26730	61	15C
0005433435002	26730	62	15D
0005433434987	26730	63	15E
0005433434989	26730	64	15F
0005435982376	26730	65	16A
0005435982586	26730	66	16C
0005433435001	26730	67	16E
0005434271335	26730	68	16F
0005435982243	26730	69	17C
0005434269127	26730	70	17E
0005435982426	26730	71	17F
0005435982480	26730	72	18A
0005433434994	26730	73	18C
0005435982223	26730	74	18D
0005433434986	26730	75	18E
0005435982470	26730	76	18F
0005435982528	26730	77	19A
0005433434995	26730	78	19C
0005434270229	26730	79	19D
0005435982406	26730	80	19E
0005435982357	26730	81	19F
0005434269128	26730	82	20A
0005435982087	26730	83	20F
0005433687729	19509	1	1A
0005433687722	19509	2	1B
0005433686655	19509	3	1C
0005433685539	19509	4	1D
0005433687731	19509	5	2A
0005433687730	19509	6	2B
0005433685550	19509	7	2C
0005433686658	19509	8	2D
0005433687726	19509	9	3A
0005433685551	19509	10	3B
0005433686648	19509	11	3C
0005433687728	19509	12	3D
0005433686662	19509	13	4A
0005433685538	19509	14	4B
0005433686651	19509	15	4C
0005433686660	19509	16	4D
0005433686656	19509	17	5A
0005433687725	19509	18	5B
0005433686657	19509	19	5C
0005433685542	19509	20	5D
0005433687721	19509	21	6A
0005433685545	19509	22	6B
0005433685548	19509	23	6C
0005433685546	19509	24	6D
0005433686661	19509	25	7A
0005433685543	19509	26	7B
0005433685549	19509	27	7C
0005433687719	19509	28	7D
0005433685537	19509	29	18A
0005433686654	19509	30	18B
0005433686647	19509	31	18D
0005433685540	19509	32	19A
0005433687724	19509	33	19B
0005433687727	19509	34	19C
0005433685541	19509	35	19D
0005433687733	19509	36	20B
0005433686653	19509	37	20C
0005433687723	19509	38	20D
0005433685544	19509	39	21A
0005433686659	19509	40	21B
0005433687732	19509	41	21C
0005433685536	19509	42	22A
0005433687720	19509	43	22B
0005433685547	19509	44	22C
0005433686650	19509	45	22D
0005433686652	19509	46	23A
0005433686649	19509	47	23B
0005432584314	3167	1	1A
0005432584325	3167	2	1C
0005432584329	3167	3	1B
0005432584324	3167	4	2A
0005432584321	3167	5	2B
0005432584313	3167	6	2C
0005432216303	3167	7	3A
0005432584320	3167	8	3B
0005432584309	3167	9	3C
0005432858067	3167	10	3D
0005432858138	3167	11	4A
0005432584326	3167	12	4B
0005432858121	3167	13	4C
0005432584307	3167	14	5A
0005432584308	3167	15	5B
0005432584306	3167	16	6B
0005432858103	3167	17	6C
0005432858086	3167	18	7A
0005432584316	3167	19	7B
0005432584327	3167	20	7C
0005432584315	3167	21	7D
0005432584330	3167	22	18D
0005432584319	3167	23	19A
0005432216304	3167	24	19B
0005432858120	3167	25	19C
0005432858116	3167	26	20A
0005432584317	3167	27	20D
0005432584322	3167	28	21A
0005432216302	3167	29	21B
0005432584310	3167	30	21C
0005432584312	3167	31	21D
0005432858075	3167	32	22A
0005432584328	3167	33	22B
0005432858066	3167	34	22C
0005432584323	3167	35	22D
0005432584311	3167	36	23A
0005432584318	3167	37	23B
0005432858205	31495	1	1A
0005432858202	31495	2	1B
0005432584160	31495	3	1D
0005432584175	31495	4	2A
0005432858200	31495	5	2B
0005432584118	31495	6	2C
0005432584128	31495	7	3A
0005432584007	31495	8	3B
0005432858206	31495	9	3C
0005432858208	31495	10	4A
0005432584040	31495	11	4C
0005432584188	31495	12	4D
0005432858201	31495	13	5A
0005432858199	31495	14	5B
0005432584174	31495	15	5C
0005432584173	31495	16	5D
0005432584131	31495	17	6B
0005432584006	31495	18	6C
0005432858209	31495	19	6D
0005432858207	31495	20	7A
0005432584161	31495	21	7B
0005432858197	31495	22	7C
0005432584058	31495	23	7D
0005432584057	31495	24	18A
0005432584129	31495	25	18B
0005432584072	31495	26	18C
0005432858204	31495	27	18D
0005432584140	31495	28	19A
0005432584139	31495	29	19D
0005432858203	31495	30	20D
0005432584049	31495	31	21A
0005432584176	31495	32	21B
0005432584073	31495	33	21C
0005432584169	31495	34	21D
0005432584117	31495	35	22A
0005432584114	31495	36	22C
0005432858198	31495	37	23A
0005432584088	31495	38	23B
0005434943455	888	1	1A
0005434943458	888	2	1B
0005434943450	888	3	1D
0005434943452	888	4	2D
0005434943453	888	5	3A
0005434943459	888	6	4D
0005433255149	888	7	6C
0005434943457	888	8	6D
0005434943454	888	9	18A
0005434943456	888	10	18C
0005433255148	888	11	19A
0005433255133	888	12	19B
0005433255153	888	13	20A
0005433255135	888	14	20D
0005434943451	888	15	21B
0005434943417	16216	1	2A
0005434943365	16216	2	2D
0005434943410	16216	3	4A
0005433255182	16216	4	4B
0005433255183	16216	5	4D
0005433255177	16216	6	6B
0005434943396	16216	7	6C
0005434943404	16216	8	6D
0005434943368	16216	9	7A
0005434943393	16216	10	7C
0005433255178	16216	11	18A
0005434943373	16216	12	18B
0005433255180	16216	13	18C
0005434943395	16216	14	20D
0005433255181	16216	15	21B
0005434943411	16216	16	21C
0005433255179	16216	17	22D
0005433654861	4326	1	1D
0005433654858	4326	2	2A
0005433654854	4326	3	2F
0005435858554	4326	4	3C
0005433654847	4326	5	4C
0005433654864	4326	6	4F
0005435858545	4326	7	6A
0005435858558	4326	8	6E
0005433654863	4326	9	6D
0005433654844	4326	10	7A
0005435858575	4326	11	6F
0005435858535	4326	12	8C
0005433654857	4326	13	8A
0005435858557	4326	14	8F
0005433654846	4326	15	8E
0005435858552	4326	16	9A
0005433654850	4326	17	9C
0005435858555	4326	18	10A
0005433654855	4326	19	10B
0005435858578	4326	20	10E
0005435858562	4326	21	11C
0005433654852	4326	22	12B
0005433654849	4326	23	12A
0005433654860	4326	24	12E
0005435858576	4326	25	12F
0005435858553	4326	26	13E
0005433654853	4326	27	14A
0005433654851	4326	28	15B
0005435858551	4326	29	15E
0005435858546	4326	30	16A
0005435858573	4326	31	16C
0005435858532	4326	32	16B
0005435858550	4326	33	16E
0005433654848	4326	34	17B
0005433654856	4326	35	18A
0005433654845	4326	36	19C
0005435858574	4326	37	19E
0005435858536	4326	38	19F
0005435858577	4326	39	20D
0005433654862	4326	40	20C
0005433654859	4326	41	21A
0005435858565	4326	42	21B
0005433811641	14407	1	1A
0005433811636	14407	2	2A
0005433811635	14407	3	2B
0005433811633	14407	4	4A
0005433811637	14407	5	4B
0005433811642	14407	6	6B
0005433811652	27852	1	1A
0005433811649	27852	2	1B
0005433811650	27852	3	2A
0005433811646	27852	4	2B
0005433811647	27852	5	3A
0005433811645	27852	6	3B
0005433811653	27852	7	4A
0005433811651	27852	8	4B
0005433811654	27852	9	5A
0005433811655	27852	10	5B
0005433811648	27852	11	6A
0005433811656	27852	12	6B
0005435653526	21745	1	1A
0005435653522	21745	2	1C
0005433368115	21745	3	1D
0005435653501	21745	4	1F
0005435653544	21745	5	2A
0005433367836	21745	6	2C
0005433367921	21745	7	2D
0005435653527	21745	8	2F
0005435653513	21745	9	3A
0005433367833	21745	10	3C
0005433368010	21745	11	3D
0005435653497	21745	12	3F
0005435653537	21745	13	4A
0005433367950	21745	14	4C
0005433368128	21745	15	4D
0005433367986	21745	16	4E
0005435653498	21745	17	4F
0005433368077	21745	18	5A
0005435653521	21745	19	5C
0005435653529	21745	20	5D
0005433367938	21745	21	5E
0005435653551	21745	22	5F
0005435653503	21745	23	6A
0005435653499	21745	24	6C
0005435653510	21745	25	6D
0005435653523	21745	26	6E
0005435653545	21745	27	6F
0005435653519	21745	28	7A
0005433367894	21745	29	7C
0005435653518	21745	30	7D
0005435653524	21745	31	7E
0005433367920	21745	32	7F
0005435653548	21745	33	8A
0005433367840	21745	34	8C
0005433368057	21745	35	8D
0005435653525	21745	36	8E
0005435653511	21745	37	8F
0005433367949	21745	38	9A
0005435653543	21745	39	9C
0005435653540	21745	40	9D
0005435653508	21745	41	9E
0005433367951	21745	42	9F
0005435653538	21745	43	10A
0005433368081	21745	44	10C
0005435653535	21745	45	10D
0005433367725	21745	46	10E
0005433368011	21745	47	10F
0005433367913	21745	48	11A
0005435653554	21745	49	11D
0005435653505	21745	50	11E
0005433367947	21745	51	11F
0005433367764	21745	52	12A
0005435653515	21745	53	12C
0005433367985	21745	54	12D
0005433368095	21745	55	12E
0005433367945	21745	56	12F
0005435653534	21745	57	13A
0005435653549	21745	58	13C
0005433368216	21745	59	13D
0005435653516	21745	60	13E
0005435653542	21745	61	13F
0005433368158	21745	62	14A
0005435653546	21745	63	14C
0005435653512	21745	64	14D
0005435653555	21745	65	14E
0005433368157	21745	66	14F
0005435653509	21745	67	15A
0005435653553	21745	68	15C
0005435653507	21745	69	15D
0005433368007	21745	70	15E
0005435653514	21745	71	15F
0005435653506	21745	72	16A
0005435653520	21745	73	16C
0005433367984	21745	74	16D
0005435653504	21745	75	16E
0005435653547	21745	76	16F
0005433367940	21745	77	17A
0005435653500	21745	78	17C
0005433368012	21745	79	17D
0005435653531	21745	80	17E
0005433368068	21745	81	17F
0005435653541	21745	82	18A
0005435653528	21745	83	18C
0005433368036	21745	84	18D
0005435653550	21745	85	18E
0005435653539	21745	86	18F
0005435653556	21745	87	19A
0005433368094	21745	88	19C
0005435653533	21745	89	19E
0005435653536	21745	90	19F
0005435653530	21745	91	20A
0005435653502	21745	92	20C
0005435653532	21745	93	20D
0005435653517	21745	94	20E
0005435653552	21745	95	20F
0005433805783	9361	1	1A
0005434273085	9361	2	1B
0005433805767	9361	3	1F
0005433785350	9361	4	1H
0005434273084	9361	5	2B
0005433763372	9361	6	2F
0005433785336	9361	7	2C
0005433805787	9361	8	2H
0005433785373	9361	9	2G
0005433763363	9361	10	3A
0005433785356	9361	11	3C
0005433805784	9361	12	4C
0005433763375	9361	13	5C
0005433763367	9361	14	5G
0005433763364	9361	15	5F
0005433785357	9361	16	9H
0005433785347	9361	17	9G
0005434270213	9361	18	11A
0005434171068	9361	19	11B
0005434171058	9361	20	11E
0005433763373	9361	21	11G
0005434171130	9361	22	12E
0005433785364	9361	23	12D
0005433763362	9361	24	12H
0005434273082	9361	25	13A
0005433805773	9361	26	13D
0005433805761	9361	27	13G
0005433805759	9361	28	13F
0005432665298	9361	29	14A
0005434171131	9361	30	14D
0005433785340	9361	31	14E
0005434171069	9361	32	14G
0005434171129	9361	33	15A
0005433805772	9361	34	15D
0005433785345	9361	35	15G
0005433785362	9361	36	15F
0005433785348	9361	37	15H
0005433805777	9361	38	16D
0005433805785	9361	39	16H
0005433805760	9361	40	16G
0005434171095	9361	41	17D
0005433763368	9361	42	17F
0005433785374	9361	43	17E
0005433805758	9361	44	17G
0005432657482	9361	45	17H
0005433805769	9361	46	18A
0005433763369	9361	47	18D
0005434171109	9361	48	18B
0005433785349	9361	49	18E
0005433785366	9361	50	18G
0005434171111	9361	51	19A
0005432667477	9361	52	19B
0005433805788	9361	53	19E
0005433805779	9361	54	19G
0005433785372	9361	55	20A
0005433805768	9361	56	20D
0005433785338	9361	57	20H
0005433785341	9361	58	21D
0005433785370	9361	59	21B
0005433785358	9361	60	21G
0005433805765	9361	61	21F
0005434171162	9361	62	21H
0005433785351	9361	63	22F
0005433785346	9361	64	22E
0005433785344	9361	65	23D
0005433785359	9361	66	23F
0005433785369	9361	67	23G
0005433785363	9361	68	23H
0005432666411	9361	69	24A
0005433785368	9361	70	24D
0005433805764	9361	71	24F
0005433785360	9361	72	24H
0005432667476	9361	73	25F
0005433805752	9361	74	25E
0005434171070	9361	75	27A
0005433785365	9361	76	27B
0005433805778	9361	77	27D
0005433805754	9361	78	27E
0005433763370	9361	79	27G
0005434270214	9361	80	27H
0005433805766	9361	81	28D
0005433805781	9361	82	28B
0005433785339	9361	83	28H
0005432657483	9361	84	28G
0005433805757	9361	85	29A
0005433805755	9361	86	29D
0005433805774	9361	87	29E
0005432666412	9361	88	29G
0005433785343	9361	89	30A
0005433805780	9361	90	30D
0005433785361	9361	91	30E
0005433805762	9361	92	31F
0005433785355	9361	93	31G
0005433805771	9361	94	32A
0005434171067	9361	95	32E
0005433763371	9361	96	32D
0005433763365	9361	97	32H
0005433763374	9361	98	33B
0005433805770	9361	99	33E
0005432657484	9361	100	34A
0005433805753	9361	101	34D
0005433785354	9361	102	34B
0005433785342	9361	103	34G
0005433805776	9361	104	34F
0005433805756	9361	105	34H
0005433785337	9361	106	35A
0005433785371	9361	107	35F
0005433805763	9361	108	35E
0005434171125	9361	109	36A
0005433805782	9361	110	36B
0005433805775	9361	111	36E
0005433785352	9361	112	36D
0005433763376	9361	113	37A
0005433785353	9361	114	36H
0005433785367	9361	115	37B
0005433805786	9361	116	38F
0005433763366	9361	117	39D
0005433805380	26268	1	1C
0005432657456	26268	2	1F
0005433763239	26268	3	1G
0005433784992	26268	4	1H
0005433784932	26268	5	2G
0005434151736	26268	6	3B
0005435269828	26268	7	4A
0005433785009	26268	8	3H
0005433805588	26268	9	4C
0005434171221	26268	10	4H
0005433785084	26268	11	5B
0005433805278	26268	12	5A
0005435269825	26268	13	5F
0005433784978	26268	14	5C
0005433763252	26268	15	5G
0005433784891	26268	16	5H
0005433784947	26268	17	9B
0005434271334	26268	18	9A
0005434171213	26268	19	9G
0005433805385	26268	20	11D
0005433805363	26268	21	11F
0005432659710	26268	22	11H
0005435269835	26268	23	12A
0005433763259	26268	24	12B
0005433785096	26268	25	12F
0005434171212	26268	26	12E
0005433805545	26268	27	12H
0005433785152	26268	28	13B
0005435269836	26268	29	13D
0005433805554	26268	30	13E
0005433784798	26268	31	14A
0005434171220	26268	32	14F
0005433784983	26268	33	15A
0005435269832	26268	34	14H
0005433784924	26268	35	15E
0005433805373	26268	36	15H
0005435269830	26268	37	16A
0005433785091	26268	38	16B
0005433805478	26268	39	16E
0005433763250	26268	40	16G
0005435269838	26268	41	17A
0005434171219	26268	42	17D
0005435269824	26268	43	17H
0005434171210	26268	44	18A
0005433805525	26268	45	18E
0005433805479	26268	46	18D
0005433805465	26268	47	18B
0005433784903	26268	48	19D
0005434171216	26268	49	19A
0005434171215	26268	50	19F
0005433784993	26268	51	19E
0005435269831	26268	52	21B
0005435269837	26268	53	21F
0005434171218	26268	54	21E
0005433785176	26268	55	21G
0005432663038	26268	56	22A
0005433784959	26268	57	21H
0005434151737	26268	58	22B
0005433784984	26268	59	22E
0005433785177	26268	60	22F
0005434171211	26268	61	23A
0005434151735	26268	62	22H
0005433784799	26268	63	22G
0005433805553	26268	64	23D
0005433763283	26268	65	23B
0005434171209	26268	66	23F
0005434171217	26268	67	23E
0005433784890	26268	68	23H
0005433805476	26268	69	24B
0005435269826	26268	70	24D
0005433805475	26268	71	24H
0005432659709	26268	72	25E
0005434171222	26268	73	27A
0005432666395	26268	74	27B
0005433784926	26268	75	27D
0005433784994	26268	76	27F
0005433763240	26268	77	28A
0005433763278	26268	78	28D
0005433785058	26268	79	28B
0005432663037	26268	80	28G
0005433805456	26268	81	28H
0005433784975	26268	82	29B
0005433805632	26268	83	29E
0005433784976	26268	84	29G
0005433763275	26268	85	29F
0005433805472	26268	86	29H
0005435269839	26268	87	30B
0005433805457	26268	88	30A
0005433805660	26268	89	30E
0005433763274	26268	90	30D
0005432657460	26268	91	30G
0005434271333	26268	92	31B
0005433785118	26268	93	31F
0005433763201	26268	94	31E
0005434171214	26268	95	31G
0005435269829	26268	96	32A
0005434270228	26268	97	32D
0005433805386	26268	98	32G
0005433784925	26268	99	33D
0005433785023	26268	100	33E
0005433805546	26268	101	33G
0005433784958	26268	102	33F
0005435269834	26268	103	34D
0005432659715	26268	104	35B
0005433784904	26268	105	35E
0005433805381	26268	106	35D
0005433763200	26268	107	35F
0005433763251	26268	108	35H
0005433784929	26268	109	36B
0005434269125	26268	110	36A
0005435269833	26268	111	36F
0005433805279	26268	112	36E
0005433805537	26268	113	36G
0005434270227	26268	114	37B
0005433784931	26268	115	37E
0005433785119	26268	116	37F
0005433785054	26268	117	37H
0005433805493	26268	118	37G
0005433805571	26268	119	38E
0005432657461	26268	120	38H
0005433763199	26268	121	38G
0005435269827	26268	122	39D
0005433785053	26268	123	39F
0005433784991	26268	124	39E
0005435135723	4932	1	1D
0005435929651	4932	2	2A
0005435135724	4932	3	2B
0005435929645	4932	4	4A
0005435135727	4932	5	6A
0005435135726	4932	6	19D
0005435135725	4932	7	20D
0005435135722	4932	8	21D
0005435135728	4932	9	23A
0005435929675	33035	1	1A
0005435135688	33035	2	2B
0005435135689	33035	3	3A
0005435135676	33035	4	3B
0005435929673	33035	5	6A
0005435135680	33035	6	7B
0005435929674	33035	7	19A
0005435135696	33035	8	20D
0005435135695	33035	9	21C
0005435135691	33035	10	22C
0005434983345	9484	1	1A
0005434217990	9484	2	1B
0005434983344	9484	3	1C
0005434983343	9484	4	3D
0005434217983	9484	5	7A
0005434983346	9484	6	21A
0005434983347	9484	7	22A
0005434217953	9484	8	22C
0005434983303	27353	1	3B
0005434218015	27353	2	3C
0005434218014	27353	3	4D
0005434218016	27353	4	5A
0005434983315	27353	5	5B
0005434983316	27353	6	7D
0005434983304	27353	7	19B
0005434218012	27353	8	21A
0005434218013	27353	9	22D
0005433960985	24266	1	1B
0005433986103	24266	2	1F
0005433960687	24266	3	1G
0005433986001	24266	4	2A
0005433986151	24266	5	1H
0005433960987	24266	6	2C
0005433960868	24266	7	2G
0005433960950	24266	8	2F
0005433960888	24266	9	3A
0005433960915	24266	10	2H
0005433986062	24266	11	3F
0005433986002	24266	12	3G
0005433960973	24266	13	4C
0005433960805	24266	14	4A
0005433985844	24266	15	4G
0005433985980	24266	16	5F
0005433960853	24266	17	11D
0005433986068	24266	18	11B
0005433960947	24266	19	11G
0005433960939	24266	20	12D
0005433985944	24266	21	12F
0005433985927	24266	22	13A
0005433985947	24266	23	13D
0005433960993	24266	24	13F
0005433985943	24266	25	13G
0005433960819	24266	26	14D
0005433960882	24266	27	14F
0005433985982	24266	28	14G
0005433960769	24266	29	14H
0005433960940	24266	30	15B
0005433985822	24266	31	15E
0005433986000	24266	32	15F
0005433960827	24266	33	16B
0005433960878	24266	34	16E
0005433960818	24266	35	16H
0005433985922	24266	36	17A
0005433986152	24266	37	17E
0005433985923	24266	38	17F
0005433986034	24266	39	17G
0005433986096	24266	40	18B
0005433960852	24266	41	18D
0005433986095	24266	42	18G
0005433960880	24266	43	19F
0005433960822	24266	44	20A
0005433960984	24266	45	20D
0005433960963	24266	46	20E
0005433960914	24266	47	20H
0005433985956	24266	48	21B
0005433986016	24266	49	21D
0005433960817	24266	50	21F
0005433985996	24266	51	21G
0005433960968	24266	52	22D
0005433960877	24266	53	22B
0005433960962	24266	54	22E
0005433986022	24266	55	22H
0005433985767	24266	56	23A
0005433960913	24266	57	23H
0005433960873	24266	58	24B
0005433960902	24266	59	24D
0005433985999	24266	60	24F
0005433985845	24266	61	24G
0005433985983	24266	62	27B
0005433985966	24266	63	27F
0005433960674	24266	64	27G
0005433986030	24266	65	28A
0005433960748	24266	66	28B
0005433960854	24266	67	28F
0005433960907	24266	68	28E
0005433960976	24266	69	28H
0005433960837	24266	70	28G
0005433960871	24266	71	29D
0005433960815	24266	72	29F
0005433985942	24266	73	30B
0005433960883	24266	74	30A
0005433960851	24266	75	31E
0005433985912	24266	76	32A
0005433960588	24266	77	31H
0005433960823	24266	78	32B
0005433985864	24266	79	32E
0005433960814	24266	80	32F
0005433986143	24266	81	32H
0005433960904	24266	82	33D
0005433960836	24266	83	33E
0005433960761	24266	84	33G
0005433960865	24266	85	33H
0005433986061	24266	86	34D
0005433960760	24266	87	34F
0005433960795	24266	88	34G
0005433960977	24266	89	35A
0005433986029	24266	90	34H
0005433985889	24266	91	35D
0005433985924	24266	92	35F
0005433960884	24266	93	35E
0005433986074	24266	94	36B
0005433985959	24266	95	36E
0005433985888	24266	96	37D
0005433960816	24266	97	37E
0005433985929	24266	98	37G
0005433960975	24266	99	37H
0005433960986	24266	100	38A
0005433960879	24266	101	38F
0005433985911	24266	102	38H
0005433985925	24266	103	39E
0005433960642	24266	104	39F
0005433961437	25935	1	2C
0005433961470	25935	2	3B
0005433986442	25935	3	3C
0005433961481	25935	4	3G
0005433986421	25935	5	3F
0005433961434	25935	6	4A
0005433961486	25935	7	3H
0005433961449	25935	8	4B
0005433986409	25935	9	4C
0005433986452	25935	10	4F
0005433986433	25935	11	5A
0005433986406	25935	12	4H
0005433986417	25935	13	5B
0005433961455	25935	14	9A
0005433986434	25935	15	11A
0005433961484	25935	16	11B
0005433986458	25935	17	11D
0005433986444	25935	18	12B
0005433986432	25935	19	12E
0005433986446	25935	20	12D
0005433986454	25935	21	12G
0005433961445	25935	22	12F
0005433986438	25935	23	12H
0005433986422	25935	24	13B
0005433986411	25935	25	13A
0005433961447	25935	26	14A
0005433986456	25935	27	13H
0005433961438	25935	28	14G
0005433986457	25935	29	14F
0005433961461	25935	30	14H
0005433986419	25935	31	15F
0005433986418	25935	32	15H
0005433961458	25935	33	15G
0005433961452	25935	34	16B
0005433961478	25935	35	16A
0005433961476	25935	36	16G
0005433961431	25935	37	16H
0005433961468	25935	38	17B
0005433961485	25935	39	18B
0005433986448	25935	40	18F
0005433986451	25935	41	19A
0005433986440	25935	42	18H
0005433986450	25935	43	19B
0005433961430	25935	44	19D
0005433986441	25935	45	19F
0005433986436	25935	46	19E
0005433986453	25935	47	20A
0005433961451	25935	48	20B
0005433986410	25935	49	20E
0005433961480	25935	50	21E
0005433961448	25935	51	21D
0005433961441	25935	52	21F
0005433961482	25935	53	21H
0005433986447	25935	54	22B
0005433961443	25935	55	22E
0005433961466	25935	56	23A
0005433986420	25935	57	23B
0005433961456	25935	58	23D
0005433961440	25935	59	23G
0005433986437	25935	60	24A
0005433961467	25935	61	23H
0005433961475	25935	62	24B
0005433961477	25935	63	24E
0005433986407	25935	64	25D
0005433986415	25935	65	24H
0005433986431	25935	66	25E
0005433961469	25935	67	27A
0005433986425	25935	68	27B
0005433986413	25935	69	28A
0005433986423	25935	70	27H
0005433961444	25935	71	28B
0005433986435	25935	72	28E
0005433986427	25935	73	28D
0005433961459	25935	74	29D
0005433961464	25935	75	29B
0005433986428	25935	76	29G
0005433961439	25935	77	30A
0005433986426	25935	78	30E
0005433961483	25935	79	30H
0005433961429	25935	80	31A
0005433986424	25935	81	31D
0005433961457	25935	82	31H
0005433986449	25935	83	32E
0005433961471	25935	84	32D
0005433986439	25935	85	32F
0005433986414	25935	86	32H
0005433986445	25935	87	32G
0005433961446	25935	88	33E
0005433961465	25935	89	33F
0005433961433	25935	90	33H
0005433986429	25935	91	34B
0005433961462	25935	92	34A
0005433961442	25935	93	34D
0005433961435	25935	94	34F
0005433986408	25935	95	34G
0005433961479	25935	96	35E
0005433986443	25935	97	35G
0005433961474	25935	98	36A
0005433986412	25935	99	36B
0005433961450	25935	100	36E
0005433986416	25935	101	37E
0005433961453	25935	102	37D
0005433961460	25935	103	37F
0005433961473	25935	104	37H
0005433986430	25935	105	38D
0005433986455	25935	106	38B
0005433961436	25935	107	38E
0005433961454	25935	108	38F
0005433961472	25935	109	38H
0005433961463	25935	110	39D
0005433961432	25935	111	39E
0005434480621	929	1	1C
0005434480624	929	2	1D
0005433165913	929	3	2A
0005434480609	929	4	2B
0005434480607	929	5	2C
0005434480620	929	6	2D
0005433165991	929	7	3A
0005434480604	929	8	3B
0005433165969	929	9	3C
0005434480617	929	10	3D
0005433165932	929	11	4A
0005434480600	929	12	4B
0005433165914	929	13	4C
0005434480613	929	14	4D
0005434480605	929	15	5A
0005434480603	929	16	5B
0005434480622	929	17	5D
0005434480616	929	18	5C
0005434480611	929	19	6A
0005434480618	929	20	6B
0005434480612	929	21	7A
0005434480602	929	22	7B
0005433165954	929	23	7D
0005434480626	929	24	18A
0005433165942	929	25	18B
0005434480601	929	26	19B
0005434480606	929	27	19C
0005434480610	929	28	19D
0005432269527	929	29	20A
0005433165971	929	30	20B
0005434480608	929	31	20D
0005432269526	929	32	21A
0005434480623	929	33	21B
0005433165920	929	34	21C
0005434480625	929	35	21D
0005434480619	929	36	22A
0005434480615	929	37	23A
0005434480614	929	38	23B
0005434480417	16602	1	1A
0005434480400	16602	2	1C
0005433166054	16602	3	1B
0005433166048	16602	4	1D
0005434480359	16602	5	2A
0005433166043	16602	6	2B
0005433166046	16602	7	2D
0005433166050	16602	8	3B
0005433166049	16602	9	3C
0005433166051	16602	10	3D
0005434480322	16602	11	4B
0005434480332	16602	12	4D
0005434480425	16602	13	5B
0005433166053	16602	14	5C
0005433166055	16602	15	5D
0005434480466	16602	16	6A
0005434480323	16602	17	6B
0005434480408	16602	18	6C
0005434480360	16602	19	6D
0005434480379	16602	20	7B
0005434480426	16602	21	7C
0005433166044	16602	22	7D
0005434480299	16602	23	18B
0005434480433	16602	24	18C
0005434480358	16602	25	18D
0005434480356	16602	26	19B
0005433166047	16602	27	20A
0005434480387	16602	28	20B
0005434480331	16602	29	20C
0005434480345	16602	30	20D
0005433166056	16602	31	21A
0005433166052	16602	32	21C
0005434480216	16602	33	21D
0005433166045	16602	34	22B
0005434480386	16602	35	22C
0005433872517	3196	1	2A
0005433872516	3196	2	4D
0005433872526	3196	3	6A
0005433872522	3196	4	6C
0005433872519	3196	5	6D
0005433872524	3196	6	18A
0005433872518	3196	7	18D
0005433872520	3196	8	19B
0005433872521	3196	9	20B
0005433872523	3196	10	21C
0005433872525	3196	11	22C
0005433872471	32540	1	1A
0005433872507	32540	2	1B
0005433872499	32540	3	1D
0005433872489	32540	4	2B
0005433872500	32540	5	7A
0005433872480	32540	6	7C
0005433872481	32540	7	19A
0005433872488	32540	8	20B
0005433872485	32540	9	21A
0005433872484	32540	10	22B
0005433872495	32540	11	23A
0005435386593	10335	1	1A
0005435386587	10335	2	1B
0005433289866	10335	3	1C
0005435142720	10335	4	1D
0005435142710	10335	5	2A
0005435142711	10335	6	2C
0005435142717	10335	7	3A
0005435142714	10335	8	3B
0005435150165	10335	9	3C
0005435386573	10335	10	3D
0005435142721	10335	11	4A
0005435142719	10335	12	4B
0005435142723	10335	13	4C
0005433289822	10335	14	4D
0005435142715	10335	15	5A
0005435386588	10335	16	5B
0005435150174	10335	17	5C
0005435150176	10335	18	6A
0005435150177	10335	19	6C
0005435142713	10335	20	6D
0005435142712	10335	21	7B
0005433289874	10335	22	7C
0005433289868	10335	23	18A
0005435142722	10335	24	18C
0005435386578	10335	25	18D
0005433289867	10335	26	19A
0005435150172	10335	27	19B
0005433289850	10335	28	19C
0005435150166	10335	29	19D
0005435142718	10335	30	20A
0005435150175	10335	31	20C
0005435150173	10335	32	20D
0005435150169	10335	33	21B
0005435386598	10335	34	21A
0005435386566	10335	35	21C
0005435150168	10335	36	21D
0005435150171	10335	37	22A
0005433289848	10335	38	22C
0005435142716	10335	39	22D
0005435150167	10335	40	23A
0005435150170	10335	41	23B
0005435142611	21953	1	1A
0005433289935	21953	2	1C
0005435142523	21953	3	1D
0005433289936	21953	4	2A
0005435150044	21953	5	2C
0005435150098	21953	6	3A
0005435150027	21953	7	3B
0005435150076	21953	8	3C
0005435150028	21953	9	3D
0005435150086	21953	10	4A
0005433289934	21953	11	4C
0005435150060	21953	12	5A
0005435386644	21953	13	5B
0005433289937	21953	14	5D
0005435150026	21953	15	6A
0005435386650	21953	16	6B
0005435150088	21953	17	6C
0005435142639	21953	18	6D
0005435386649	21953	19	7A
0005435142583	21953	20	7B
0005435142648	21953	21	7C
0005435386646	21953	22	18A
0005435150013	21953	23	18D
0005433289933	21953	24	19A
0005435150087	21953	25	19B
0005435150014	21953	26	19C
0005435150056	21953	27	19D
0005435150075	21953	28	20A
0005435386647	21953	29	20D
0005435386645	21953	30	21B
0005435142574	21953	31	22A
0005433289932	21953	32	22B
0005435142647	21953	33	22D
0005435386648	21953	34	23A
0005433289938	21953	35	23B
0005435319615	11220	1	1A
0005435502430	11220	2	1D
0005435502324	11220	3	1F
0005435529266	11220	4	2C
0005434573503	11220	5	2F
0005435502433	11220	6	3A
0005434573504	11220	7	3C
0005435545756	11220	8	3D
0005435529317	11220	9	4A
0005435545759	11220	10	4C
0005435529212	11220	11	4D
0005435545750	11220	12	4E
0005435529250	11220	13	4F
0005435529230	11220	14	5A
0005435319621	11220	15	5C
0005435529227	11220	16	5D
0005434573502	11220	17	5E
0005435529319	11220	18	5F
0005434573497	11220	19	6A
0005435502325	11220	20	6C
0005434573501	11220	21	6E
0005434573494	11220	22	6F
0005435319576	11220	23	7C
0005435502416	11220	24	7D
0005435502415	11220	25	7E
0005435529307	11220	26	7F
0005435319562	11220	27	8A
0005435319561	11220	28	8C
0005435545757	11220	29	8D
0005434573499	11220	30	8F
0005435529288	11220	31	9A
0005435545791	11220	32	9C
0005435529289	11220	33	9D
0005435502469	11220	34	9E
0005435502365	11220	35	9F
0005435319589	11220	36	10A
0005434573498	11220	37	10C
0005435502377	11220	38	10D
0005435319625	11220	39	10E
0005435529252	11220	40	10F
0005435529330	11220	41	11C
0005435502407	11220	42	11D
0005435529347	11220	43	11E
0005434573500	11220	44	11F
0005434573492	11220	45	12A
0005435529311	11220	46	12C
0005435502408	11220	47	12D
0005435319608	11220	48	12E
0005435529306	11220	49	12F
0005435529251	11220	50	13A
0005434573493	11220	51	13C
0005435502372	11220	52	13E
0005435502455	11220	53	14C
0005435502378	11220	54	14D
0005435502409	11220	55	14E
0005435545760	11220	56	14F
0005435529305	11220	57	15A
0005435502296	11220	58	15D
0005435529312	11220	59	15E
0005435502318	11220	60	15F
0005435319609	11220	61	16A
0005435529287	11220	62	16C
0005435502414	11220	63	16D
0005435502316	11220	64	16E
0005435319604	11220	65	16F
0005435529256	11220	66	17C
0005435529226	11220	67	17D
0005435502434	11220	68	17F
0005435502454	11220	69	18A
0005435502307	11220	70	18C
0005435529320	11220	71	18D
0005435502401	11220	72	18E
0005435545747	11220	73	19A
0005435502306	11220	74	19C
0005435319605	11220	75	19D
0005435502373	11220	76	19E
0005435545724	11220	77	19F
0005435529328	11220	78	20A
0005435545749	11220	79	20D
0005434573495	11220	80	20E
0005434573496	11220	81	20F
0005435502540	20918	1	1A
0005435502542	20918	2	1C
0005434573416	20918	3	1F
0005435518111	20918	4	2A
0005435502535	20918	5	2F
0005435508478	20918	6	3C
0005435502541	20918	7	3D
0005435502544	20918	8	3F
0005435518104	20918	9	4A
0005435518100	20918	10	4C
0005435319685	20918	11	4E
0005434573357	20918	12	4F
0005435502530	20918	13	5A
0005435518098	20918	14	5D
0005435319683	20918	15	5E
0005435502547	20918	16	5F
0005435502551	20918	17	6A
0005435508473	20918	18	6C
0005435502552	20918	19	6D
0005435502537	20918	20	6E
0005434573432	20918	21	7C
0005435508482	20918	22	7D
0005435518109	20918	23	7E
0005435518097	20918	24	7F
0005435502550	20918	25	8A
0005435502546	20918	26	8D
0005435502532	20918	27	8E
0005435502533	20918	28	8F
0005434573361	20918	29	9A
0005432291954	20918	30	9E
0005434573316	20918	31	10A
0005435319684	20918	32	10C
0005432291955	20918	33	10D
0005435518107	20918	34	10F
0005435319679	20918	35	11C
0005434573352	20918	36	11D
0005435508481	20918	37	11E
0005434573374	20918	38	12C
0005435319678	20918	39	12D
0005435502538	20918	40	12E
0005435502536	20918	41	12F
0005435518106	20918	42	13A
0005435518110	20918	43	13C
0005435508475	20918	44	13D
0005435518113	20918	45	13E
0005435502545	20918	46	14A
0005435319681	20918	47	14C
0005435508483	20918	48	14D
0005434573433	20918	49	14E
0005435518099	20918	50	14F
0005434573329	20918	51	15A
0005435502549	20918	52	15C
0005435518105	20918	53	15D
0005435518102	20918	54	15E
0005435518103	20918	55	15F
0005435319682	20918	56	16A
0005435508476	20918	57	16C
0005435518095	20918	58	16D
0005435508477	20918	59	16E
0005435518108	20918	60	16F
0005435319677	20918	61	17A
0005435518094	20918	62	17D
0005435502534	20918	63	17E
0005435508480	20918	64	18A
0005435518101	20918	65	18C
0005435502531	20918	66	18D
0005432291956	20918	67	18E
0005435518096	20918	68	18F
0005435502548	20918	69	19A
0005435508479	20918	70	19C
0005435502543	20918	71	19E
0005435319680	20918	72	19F
0005434573317	20918	73	20A
0005435518112	20918	74	20C
0005435508474	20918	75	20D
0005435502539	20918	76	20E
0005435518114	20918	77	20F
0005433927429	24318	1	1B
0005433927446	24318	2	1C
0005433927448	24318	3	1D
0005433683369	24318	4	2A
0005433683363	24318	5	2B
0005433683359	24318	6	2D
0005433927444	24318	7	3B
0005433683362	24318	8	4B
0005433683360	24318	9	6B
0005433683370	24318	10	7A
0005433927437	24318	11	7C
0005433683364	24318	12	7D
0005433683366	24318	13	18A
0005433927445	24318	14	18B
0005433683365	24318	15	18D
0005433683367	24318	16	19D
0005433683368	24318	17	19C
0005433683361	24318	18	21A
0005433927430	24318	19	21B
0005433683355	29279	1	1B
0005433683335	29279	2	2C
0005433927462	29279	3	3B
0005433927472	29279	4	3D
0005433927465	29279	5	4A
0005433683332	29279	6	5A
0005433927467	29279	7	5D
0005433927468	29279	8	6A
0005433927463	29279	9	7A
0005433927470	29279	10	18B
0005433927471	29279	11	18C
0005433927464	29279	12	19B
0005433683356	29279	13	20A
0005433683333	29279	14	20B
0005433927466	29279	15	22A
0005433927469	29279	16	22D
0005432693181	3013	1	1A
0005432693252	3013	2	1D
0005432693053	3013	3	1F
0005432693042	3013	4	2D
0005432693110	3013	5	2F
0005432693107	3013	6	4C
0005432693132	3013	7	5C
0005432693115	3013	8	5F
0005432693052	3013	9	6D
0005432693142	3013	10	8A
0005432693205	3013	11	8E
0005432693116	3013	12	8F
0005432693138	3013	13	9A
0005432693054	3013	14	10D
0005432693096	3013	15	10E
0005432693074	3013	16	10F
0005432693131	3013	17	11A
0005432693177	3013	18	11C
0005432693111	3013	19	11E
0005432693073	3013	20	11F
0005432693114	3013	21	12C
0005432693112	3013	22	12D
0005432693037	3013	23	12E
0005432693108	3013	24	13F
0005432693176	3013	25	14A
0005432693130	3013	26	14D
0005432693051	3013	27	14E
0005432693102	3013	28	15E
0005432693139	3013	29	15F
0005432693038	3013	30	16C
0005432693047	3013	31	17C
0005432693251	3013	32	18D
0005432693035	3013	33	19D
0005432693036	3013	34	20A
0005432693109	3013	35	20D
0005432707067	2948	1	1C
0005432707059	2948	2	1F
0005432707060	2948	3	2D
0005433123978	2948	4	2F
0005432880844	2948	5	3C
0005432707064	2948	6	3D
0005433123971	2948	7	3F
0005433123922	2948	8	4A
0005433124026	2948	9	4C
0005432707052	2948	10	4D
0005432217808	2948	11	4E
0005432707061	2948	12	5A
0005433123934	2948	13	5D
0005433124034	2948	14	5E
0005432880822	2948	15	5F
0005432707049	2948	16	6A
0005432707056	2948	17	6C
0005432880870	2948	18	6E
0005433124020	2948	19	6F
0005432707046	2948	20	7D
0005433123970	2948	21	7E
0005433124073	2948	22	7F
0005432880852	2948	23	8A
0005432707042	2948	24	8C
0005432880821	2948	25	8D
0005432707066	2948	26	8E
0005433124047	2948	27	8F
0005433194854	2948	28	9A
0005432707043	2948	29	9C
0005432880837	2948	30	9D
0005432880901	2948	31	9F
0005432707062	2948	32	10A
0005433124045	2948	33	10C
0005432707050	2948	34	10D
0005432880871	2948	35	11C
0005432707045	2948	36	11D
0005432707065	2948	37	11F
0005432707054	2948	38	12C
0005432707048	2948	39	12E
0005433123952	2948	40	13A
0005433123935	2948	41	13C
0005433123950	2948	42	13D
0005433194853	2948	43	13E
0005432707041	2948	44	13F
0005433123972	2948	45	14A
0005432707044	2948	46	14C
0005432707058	2948	47	14E
0005432707051	2948	48	14F
0005432880905	2948	49	15C
0005432880899	2948	50	15D
0005433123949	2948	51	16A
0005432707063	2948	52	16D
0005432880855	2948	53	16E
0005432707047	2948	54	17A
0005433123933	2948	55	17C
0005432880843	2948	56	17D
0005432217806	2948	57	18A
0005432707055	2948	58	18C
0005432707057	2948	59	18D
0005432707053	2948	60	18E
0005433123953	2948	61	18F
0005432217807	2948	62	19E
0005432880906	2948	63	20A
0005433194860	2948	64	20D
0005432880975	30047	1	1C
0005433124146	30047	2	1D
0005432693435	30047	3	1F
0005433124152	30047	4	2A
0005432693428	30047	5	2C
0005432706787	30047	6	2D
0005432693429	30047	7	2F
0005433124150	30047	8	3A
0005432706807	30047	9	3C
0005432693425	30047	10	3D
0005432693437	30047	11	3F
0005432693417	30047	12	4A
0005432706814	30047	13	4C
0005432706903	30047	14	4D
0005432693432	30047	15	4E
0005433124161	30047	16	4F
0005433124164	30047	17	5A
0005433124159	30047	18	5C
0005432693436	30047	19	5D
0005432880984	30047	20	5E
0005433124144	30047	21	5F
0005432693415	30047	22	6A
0005432880978	30047	23	6C
0005432693420	30047	24	6D
0005432693411	30047	25	6E
0005433124145	30047	26	6F
0005433124163	30047	27	7A
0005432706810	30047	28	7C
0005432693426	30047	29	7D
0005433124162	30047	30	7E
0005432706847	30047	31	7F
0005432706904	30047	32	8A
0005432706809	30047	33	8C
0005432706845	30047	34	8D
0005433124148	30047	35	8E
0005432693419	30047	36	8F
0005432880979	30047	37	9A
0005432693438	30047	38	9C
0005432706855	30047	39	9D
0005432693427	30047	40	9E
0005432706856	30047	41	9F
0005433124149	30047	42	10A
0005432706956	30047	43	10C
0005432693421	30047	44	10D
0005432706776	30047	45	10E
0005432706811	30047	46	10F
0005432693440	30047	47	11A
0005432706808	30047	48	11C
0005432706822	30047	49	11D
0005432693431	30047	50	11E
0005433124153	30047	51	11F
0005433124155	30047	52	12A
0005432706837	30047	53	12C
0005433124158	30047	54	12D
0005432706700	30047	55	12E
0005432880976	30047	56	12F
0005432880980	30047	57	13A
0005432693418	30047	58	13C
0005432693433	30047	59	13D
0005432706942	30047	60	13E
0005432693412	30047	61	13F
0005432880985	30047	62	14A
0005432693441	30047	63	14C
0005432693414	30047	64	14D
0005432693439	30047	65	14E
0005433124154	30047	66	14F
0005432693424	30047	67	15C
0005432880981	30047	68	15A
0005432880982	30047	69	15D
0005432693423	30047	70	15E
0005432693422	30047	71	15F
0005432693416	30047	72	16A
0005432706757	30047	73	16C
0005432706701	30047	74	16D
0005432880983	30047	75	16E
0005432880972	30047	76	16F
0005433124151	30047	77	17A
0005432706854	30047	78	17C
0005432706849	30047	79	17D
0005432693434	30047	80	17E
0005433124156	30047	81	17F
0005432706880	30047	82	18A
0005433124147	30047	83	18C
0005433124160	30047	84	18D
0005432706836	30047	85	18E
0005432880974	30047	86	18F
0005432706906	30047	87	19A
0005432706858	30047	88	19C
0005432693413	30047	89	19D
0005432706846	30047	90	19E
0005432693430	30047	91	19F
0005433124157	30047	92	20A
0005432880977	30047	93	20C
0005432880973	30047	94	20D
0005432706900	30047	95	20E
0005432706857	30047	96	20F
0005434988853	23692	1	1A
0005434980107	23692	2	1B
0005434980086	23692	3	1C
0005434988849	23692	4	1D
0005434988854	23692	5	2B
0005434980089	23692	6	2C
0005434980113	23692	7	3A
0005434980091	23692	8	3B
0005434980093	23692	9	3C
0005434988850	23692	10	3D
0005434980099	23692	11	4A
0005434980098	23692	12	4B
0005434980096	23692	13	4C
0005434980084	23692	14	4D
0005434988851	23692	15	5A
0005434980106	23692	16	5B
0005434980103	23692	17	5D
0005434988848	23692	18	6A
0005434980087	23692	19	6B
0005434988858	23692	20	6C
0005434980090	23692	21	6D
0005434980101	23692	22	7A
0005434980092	23692	23	7B
0005434980111	23692	24	7C
0005434980095	23692	25	7D
0005434980085	23692	26	18A
0005434980102	23692	27	18B
0005434988846	23692	28	18D
0005434980083	23692	29	19A
0005434980097	23692	30	19B
0005434988847	23692	31	19C
0005434988855	23692	32	19D
0005434980109	23692	33	20A
0005434980104	23692	34	20B
0005434980110	23692	35	20C
0005434988857	23692	36	20D
0005434980100	23692	37	21A
0005434988856	23692	38	21C
0005434980105	23692	39	21B
0005434980108	23692	40	22A
0005434980094	23692	41	22B
0005434988852	23692	42	22C
0005434980112	23692	43	23A
0005434980088	23692	44	23B
0005434979816	27543	1	1A
0005434979754	27543	2	1B
0005434988725	27543	3	1C
0005434979721	27543	4	1D
0005434979828	27543	5	2A
0005434988752	27543	6	2C
0005434979920	27543	7	3A
0005434988775	27543	8	3B
0005434988769	27543	9	3C
0005434988772	27543	10	3D
0005434988776	27543	11	4A
0005434988771	27543	12	4B
0005434979827	27543	13	4C
0005434979822	27543	14	4D
0005434979818	27543	15	5A
0005434988770	27543	16	5B
0005434979875	27543	17	5C
0005434979819	27543	18	5D
0005434979830	27543	19	6A
0005434979748	27543	20	6B
0005434988765	27543	21	6D
0005434979918	27543	22	7A
0005434979739	27543	23	7B
0005434979823	27543	24	7D
0005434979797	27543	25	18A
0005434979755	27543	26	18D
0005434979829	27543	27	19A
0005434988753	27543	28	19B
0005434979740	27543	29	19C
0005434979831	27543	30	19D
0005434979798	27543	31	20A
0005434988754	27543	32	20D
0005434979919	27543	33	21A
0005434979731	27543	34	21C
0005434979815	27543	35	22B
0005434988774	27543	36	22C
0005434988766	27543	37	23A
0005434988755	27543	38	23B
0005434302503	10290	1	1A
0005433111506	10290	2	1C
0005434302505	10290	3	1D
0005434302502	10290	4	3D
0005434302504	10290	5	4B
0005434302876	10290	6	18A
0005434302875	10290	7	18B
0005433113535	10290	8	22A
0005434302458	19606	1	1D
0005434302461	19606	2	7B
0005433113561	19606	3	7C
0005433113562	19606	4	23B
0005435069685	3567	1	1A
0005435069681	3567	2	1C
0005435069656	3567	3	1F
0005435069693	3567	4	2A
0005435069645	3567	5	2C
0005435069678	3567	6	2D
0005435069671	3567	7	2F
0005435939881	3567	8	3A
0005435069683	3567	9	3C
0005435069649	3567	10	3D
0005435069658	3567	11	3F
0005435069666	3567	12	4A
0005435939877	3567	13	4C
0005435939884	3567	14	4D
0005435069691	3567	15	4E
0005435069646	3567	16	4F
0005435069677	3567	17	5E
0005435069690	3567	18	5F
0005435069660	3567	19	6A
0005435069687	3567	20	6C
0005435069667	3567	21	6D
0005435925293	3567	22	6E
0005435069674	3567	23	7A
0005435069663	3567	24	7C
0005435069664	3567	25	7D
0005435069654	3567	26	7E
0005435069694	3567	27	8C
0005435069676	3567	28	8D
0005435925348	3567	29	8E
0005435939885	3567	30	9A
0005435069657	3567	31	9E
0005435069686	3567	32	10A
0005435069669	3567	33	10E
0005435719000	3567	34	10F
0005435069652	3567	35	11A
0005435069662	3567	36	11C
0005435069659	3567	37	11F
0005435069682	3567	38	12C
0005435069692	3567	39	12D
0005435925322	3567	40	12F
0005435069648	3567	41	13A
0005435939883	3567	42	13C
0005435069643	3567	43	13D
0005435069675	3567	44	13E
0005435069670	3567	45	13F
0005435069680	3567	46	14A
0005435069661	3567	47	14C
0005435069665	3567	48	14E
0005435069673	3567	49	15A
0005435069651	3567	50	15D
0005435069672	3567	51	15E
0005435069679	3567	52	16A
0005435719002	3567	53	16C
0005435069668	3567	54	16D
0005435069689	3567	55	16E
0005435925310	3567	56	16F
0005435925377	3567	57	17F
0005435925294	3567	58	18C
0005435069688	3567	59	18D
0005435069650	3567	60	18E
0005435069684	3567	61	18F
0005435069653	3567	62	19A
0005435939882	3567	63	19C
0005435069644	3567	64	19D
0005435719001	3567	65	19E
0005435939878	3567	66	20D
0005435069647	3567	67	20E
0005435069655	3567	68	20F
0005435069137	15333	1	1A
0005435068884	15333	2	1C
0005435069346	15333	3	1D
0005435069179	15333	4	1F
0005435069313	15333	5	2F
0005435925455	15333	6	3A
0005435069216	15333	7	3C
0005435069142	15333	8	3F
0005435069144	15333	9	4A
0005435069227	15333	10	4D
0005435925446	15333	11	4E
0005435069348	15333	12	5A
0005435939904	15333	13	5C
0005435069131	15333	14	5D
0005435939901	15333	15	5E
0005435925443	15333	16	5F
0005435939902	15333	17	6A
0005435925454	15333	18	6C
0005435939900	15333	19	6F
0005435925460	15333	20	7A
0005435069115	15333	21	7C
0005435069349	15333	22	7D
0005435068985	15333	23	7E
0005435925452	15333	24	7F
0005435069225	15333	25	8A
0005435069143	15333	26	8C
0005435069274	15333	27	8D
0005435069314	15333	28	8E
0005435925451	15333	29	8F
0005435069128	15333	30	9A
0005435068936	15333	31	9C
0005435069312	15333	32	9E
0005435069226	15333	33	9F
0005435925447	15333	34	10A
0005435925459	15333	35	10C
0005435069205	15333	36	10D
0005435069345	15333	37	10E
0005435939899	15333	38	11C
0005435925456	15333	39	11D
0005435068929	15333	40	11E
0005435925453	15333	41	11F
0005435069386	15333	42	12A
0005435069363	15333	43	12E
0005435925450	15333	44	12F
0005435069092	15333	45	13A
0005435068937	15333	46	13C
0005435069063	15333	47	13D
0005435925458	15333	48	13E
0005435069258	15333	49	14A
0005435925441	15333	50	14C
0005435950296	15333	51	14D
0005435069138	15333	52	14E
0005435069339	15333	53	14F
0005435068986	15333	54	15A
0005435925440	15333	55	15C
0005435925438	15333	56	15D
0005435069330	15333	57	15E
0005435069116	15333	58	15F
0005435925439	15333	59	16A
0005435069167	15333	60	16C
0005435925444	15333	61	16D
0005435069211	15333	62	16E
0005435069197	15333	63	16F
0005435069168	15333	64	17A
0005435069218	15333	65	17C
0005435069160	15333	66	17D
0005435069280	15333	67	17E
0005435069281	15333	68	17F
0005435925442	15333	69	18A
0005435069217	15333	70	18C
0005435069073	15333	71	18D
0005435069044	15333	72	18E
0005435069291	15333	73	18F
0005435069331	15333	74	19A
0005435925445	15333	75	19D
0005435925449	15333	76	19E
0005435925457	15333	77	19F
0005435069329	15333	78	20A
0005435925448	15333	79	20C
0005435069027	15333	80	20D
0005435925461	15333	81	20E
0005435939903	15333	82	20F
0005432659729	18127	1	1A
0005432659728	18127	2	2A
0005432660840	18127	3	2B
0005432660841	18127	4	4A
0005432658615	18127	5	4B
0005432658614	18127	6	5B
0005432659730	18127	7	6A
0005432660819	26448	1	1A
0005432667458	26448	2	1B
0005433102350	113	1	1F
0005432919809	113	2	1D
0005433102320	113	3	2D
0005432677596	113	4	3A
0005432901704	113	5	3F
0005433102321	113	6	4A
0005433102292	113	7	4C
0005432391996	113	8	4F
0005433102243	113	9	4D
0005433102298	113	10	5C
0005433102331	113	11	5D
0005432919940	113	12	6A
0005433102319	113	13	6C
0005432901616	113	14	7A
0005433102201	113	15	6F
0005433102203	113	16	7C
0005432677592	113	17	7F
0005432901710	113	18	7D
0005432919836	113	19	8B
0005433102343	113	20	8D
0005433102240	113	21	8C
0005432157514	113	22	8E
0005432901736	113	23	8F
0005433102302	113	24	9B
0005433102111	113	25	9E
0005432919923	113	26	9D
0005433102224	113	27	9F
0005432919840	113	28	10A
0005432901605	113	29	10D
0005433102185	113	30	10E
0005433102184	113	31	10F
0005432677574	113	32	11B
0005433102227	113	33	11C
0005433102264	113	34	11D
0005432901675	113	35	11F
0005432901640	113	36	12A
0005433102100	113	37	12C
0005432920001	113	38	12F
0005433102269	113	39	13F
0005432901657	113	40	13E
0005432391998	113	41	14B
0005432677594	113	42	14E
0005433102209	113	43	15A
0005433102139	113	44	15C
0005432901709	113	45	15D
0005432919925	113	46	15F
0005432919952	113	47	15E
0005433102126	113	48	16C
0005432901554	113	49	16E
0005432157513	113	50	17A
0005433102306	113	51	16F
0005432391995	113	52	17B
0005432677595	113	53	17D
0005433102138	113	54	18B
0005433102305	113	55	18D
0005432901731	113	56	18C
0005433102332	113	57	18E
0005433102248	113	58	18F
0005433102204	113	59	19C
0005433102151	113	60	19B
0005432920000	113	61	19D
0005432392000	113	62	19E
0005433102267	113	63	20A
0005432901641	113	64	20C
0005432901642	113	65	20B
0005433102265	113	66	20F
0005433102131	113	67	20E
0005432901643	113	68	21A
0005433102312	113	69	21C
0005433102188	113	70	21B
0005433102225	113	71	21D
0005433102226	113	72	21F
0005433102244	113	73	22B
0005432391999	113	74	23A
0005433102335	113	75	23B
0005432901639	113	76	23F
0005432901606	113	77	23E
0005432901679	113	78	24B
0005432901553	113	79	24C
0005433102249	113	80	24F
0005432392011	113	81	25C
0005432901678	113	82	25B
0005433102270	113	83	25D
0005432919939	113	84	26C
0005433102334	113	85	26B
0005433102192	113	86	26D
0005433102212	113	87	28A
0005432677593	113	88	27F
0005433102266	113	89	28B
0005433102123	113	90	28D
0005433102187	113	91	29B
0005433102242	113	92	29A
0005433102271	113	93	29C
0005432919926	113	94	29D
0005432391992	113	95	29E
0005433102208	113	96	30C
0005433102299	113	97	30E
0005432901676	113	98	30F
0005432919835	113	99	31B
0005432919964	113	100	31A
0005432677589	113	101	31C
0005433102236	113	102	31E
0005433102330	113	103	31F
0005432262397	114	1	1A
0005432262431	114	2	1F
0005432207689	114	3	1D
0005432262403	114	4	2C
0005433687701	114	5	2F
0005433690925	114	6	3A
0005433690933	114	7	3D
0005432817791	114	8	3C
0005433690934	114	9	3F
0005432817816	114	10	4D
0005432817794	114	11	5A
0005432262429	114	12	5D
0005432262400	114	13	6D
0005432817798	114	14	6C
0005432262432	114	15	7A
0005432262437	114	16	6F
0005432817814	114	17	7C
0005432262409	114	18	7D
0005432262422	114	19	8A
0005432817793	114	20	7F
0005433690926	114	21	8D
0005432817788	114	22	8E
0005432262442	114	23	9B
0005432262441	114	24	9A
0005432817803	114	25	9D
0005432817813	114	26	9F
0005432817799	114	27	10A
0005432262404	114	28	10C
0005432817790	114	29	10B
0005432262425	114	30	10E
0005432817800	114	31	10F
0005432756846	114	32	11F
0005432262408	114	33	11E
0005432262407	114	34	12A
0005432262424	114	35	12C
0005432262399	114	36	12B
0005432262418	114	37	12D
0005432817801	114	38	12F
0005432817808	114	39	13B
0005432262401	114	40	13F
0005433687713	114	41	14D
0005432262434	114	42	14C
0005432262426	114	43	14E
0005433687714	114	44	15A
0005432262412	114	45	16A
0005432262439	114	46	16B
0005432262415	114	47	17A
0005432753314	114	48	17C
0005432817807	114	49	17B
0005432817806	114	50	17D
0005432262410	114	51	17F
0005432207687	114	52	18E
0005432817789	114	53	18D
0005432817811	114	54	19B
0005432753313	114	55	18F
0005432262443	114	56	19D
0005432817792	114	57	19E
0005432262396	114	58	20A
0005432262433	114	59	20F
0005432289023	114	60	21B
0005432817810	114	61	21A
0005432262417	114	62	21C
0005432817817	114	63	21F
0005432817815	114	64	22B
0005432262414	114	65	22A
0005432262428	114	66	22C
0005432817805	114	67	22D
0005432262435	114	68	22F
0005433687702	114	69	22E
0005432817796	114	70	23B
0005432262416	114	71	23F
0005433690937	114	72	24B
0005432207688	114	73	24A
0005432262419	114	74	24D
0005432262398	114	75	24F
0005432817802	114	76	25A
0005432262430	114	77	25D
0005432262436	114	78	25C
0005432262427	114	79	26E
0005432262413	114	80	26F
0005432262438	114	81	27A
0005432817809	114	82	27D
0005433690928	114	83	27E
0005432817797	114	84	28A
0005432262406	114	85	27F
0005432289024	114	86	28B
0005432753299	114	87	28D
0005432262440	114	88	28C
0005432817795	114	89	28E
0005433690938	114	90	28F
0005432753300	114	91	29A
0005433690927	114	92	29C
0005432262411	114	93	29B
0005432262423	114	94	29D
0005432289022	114	95	29E
0005432262421	114	96	30A
0005432756847	114	97	29F
0005432262402	114	98	30B
0005432817818	114	99	30C
0005432817804	114	100	30E
0005432817812	114	101	31A
0005432753294	114	102	30F
0005432262420	114	103	31C
0005432262405	114	104	31F
0005432020567	8073	1	1A
0005432920102	8073	2	1C
0005432920091	8073	3	2A
0005433102721	8073	4	1F
0005433102745	8073	5	2C
0005432020571	8073	6	2F
0005432753339	8073	7	3A
0005432020572	8073	8	3D
0005432920101	8073	9	4F
0005432020568	8073	10	4D
0005433102759	8073	11	5D
0005432020549	8073	12	5F
0005432920085	8073	13	6D
0005432677618	8073	14	6C
0005432044555	8073	15	7A
0005432920092	8073	16	6F
0005432392034	8073	17	7C
0005433102723	8073	18	7F
0005432020563	8073	19	7D
0005433102740	8073	20	8C
0005432920100	8073	21	8E
0005433102724	8073	22	9A
0005433102761	8073	23	8F
0005433102726	8073	24	9C
0005432020548	8073	25	9E
0005433102747	8073	26	9D
0005432751565	8073	27	10A
0005432020561	8073	28	10B
0005432920084	8073	29	10E
0005433102762	8073	30	10F
0005432020551	8073	31	11E
0005433102750	8073	32	12A
0005432920093	8073	33	12B
0005432020573	8073	34	12D
0005433102729	8073	35	12C
0005433102728	8073	36	13A
0005433102742	8073	37	12E
0005432920083	8073	38	13B
0005433102720	8073	39	13F
0005432020564	8073	40	13E
0005432020562	8073	41	14A
0005432677619	8073	42	14D
0005433102730	8073	43	14C
0005432920099	8073	44	14E
0005432920098	8073	45	14F
0005433102753	8073	46	15C
0005432020569	8073	47	15B
0005433102754	8073	48	15E
0005432020560	8073	49	15D
0005432020565	8073	50	16A
0005433102722	8073	51	15F
0005433102751	8073	52	16B
0005432020556	8073	53	16C
0005432920097	8073	54	16E
0005432392033	8073	55	16F
0005432045636	8073	56	17B
0005432920089	8073	57	17A
0005433102748	8073	58	17C
0005432920103	8073	59	17D
0005433102746	8073	60	17F
0005433102755	8073	61	18B
0005433102734	8073	62	18C
0005433102727	8073	63	18E
0005432753340	8073	64	18F
0005432920090	8073	65	19C
0005433102749	8073	66	20A
0005432020570	8073	67	19E
0005433102757	8073	68	20C
0005432020553	8073	69	20E
0005433102733	8073	70	21A
0005433102735	8073	71	21C
0005433102737	8073	72	21D
0005432751563	8073	73	21E
0005432920086	8073	74	22A
0005432751564	8073	75	22B
0005433102760	8073	76	22C
0005432920094	8073	77	22E
0005432020555	8073	78	22D
0005432677617	8073	79	23A
0005433102738	8073	80	23B
0005432920087	8073	81	23D
0005432045637	8073	82	23E
0005432020550	8073	83	23F
0005432020554	8073	84	24B
0005433102731	8073	85	24C
0005433102736	8073	86	24D
0005433102732	8073	87	24E
0005433102764	8073	88	25B
0005432020558	8073	89	25C
0005433102756	8073	90	25E
0005432920088	8073	91	26E
0005432920095	8073	92	26D
0005432020557	8073	93	26F
0005433102741	8073	94	27B
0005432020574	8073	95	27A
0005432677620	8073	96	27C
0005433102725	8073	97	27D
0005432045635	8073	98	28A
0005432020559	8073	99	28B
0005433102763	8073	100	28D
0005433102752	8073	101	28F
0005432753338	8073	102	29A
0005433102765	8073	103	29C
0005433102758	8073	104	29D
0005432392032	8073	105	29F
0005432920096	8073	106	30B
0005433102739	8073	107	30A
0005432020552	8073	108	30D
0005432751566	8073	109	30C
0005432044556	8073	110	31C
0005433102743	8073	111	31D
0005433102744	8073	112	31E
0005432020566	8073	113	31F
0005434513585	8043	1	1A
0005432817563	8043	2	2A
0005432817547	8043	3	3F
0005432901812	8043	4	4A
0005432817559	8043	5	5D
0005432817521	8043	6	7D
0005432817446	8043	7	9D
0005432817574	8043	8	9F
0005432901807	8043	9	9E
0005432901801	8043	10	10F
0005432817493	8043	11	11A
0005432817593	8043	12	12B
0005432901799	8043	13	12D
0005432817594	8043	14	12C
0005432817576	8043	15	13C
0005434513586	8043	16	13D
0005432901809	8043	17	14F
0005432901804	8043	18	16C
0005432817749	8043	19	17A
0005432901813	8043	20	17C
0005432817546	8043	21	17B
0005432901814	8043	22	17D
0005432901800	8043	23	17F
0005434513588	8043	24	17E
0005432901806	8043	25	18B
0005432817668	8043	26	18C
0005432817543	8043	27	18F
0005434513574	8043	28	19C
0005434513579	8043	29	19B
0005432901810	8043	30	21B
0005432817447	8043	31	21D
0005432817560	8043	32	21E
0005432817627	8043	33	22B
0005432901798	8043	34	22E
0005434513584	8043	35	23A
0005432817552	8043	36	23D
0005432901808	8043	37	24C
0005432817575	8043	38	24D
0005432817667	8043	39	25A
0005432817520	8043	40	25F
0005432817666	8043	41	26A
0005432901811	8043	42	26B
0005432901802	8043	43	26E
0005432817750	8043	44	27C
0005432817573	8043	45	27E
0005432901805	8043	46	28F
0005432817603	8043	47	29F
0005432901815	8043	48	30B
0005432817494	8043	49	30F
0005432817519	8043	50	31B
0005432817490	8043	51	31C
0005432901803	8043	52	31E
0005434513587	8043	53	31D
0005434175779	9643	1	2B
0005433870755	9643	2	3B
0005434175772	9643	3	4A
0005433870756	9643	4	4B
0005434175780	9643	5	5A
0005434175771	9643	6	5B
0005434175802	32337	1	2A
0005434175800	32337	2	2B
0005434175799	32337	3	3B
0005433870736	32337	4	4B
0005434175798	32337	5	5B
0005434175801	32337	6	6B
0005433870737	32337	7	6A
0005434879264	3500	1	1C
0005434879306	3500	2	1A
0005434879280	3500	3	1H
0005435126820	3500	4	1G
0005434879267	3500	5	2A
0005432188645	3500	6	1K
0005435626386	3500	7	2D
0005435126825	3500	8	2C
0005434426951	3500	9	2H
0005434879273	3500	10	3A
0005434426939	3500	11	2K
0005434426952	3500	12	3D
0005435626390	3500	13	3C
0005435626392	3500	14	3K
0005434879314	3500	15	3H
0005435126854	3500	16	3G
0005435902708	3500	17	4H
0005434879321	3500	18	4G
0005434879261	3500	19	4D
0005434426950	3500	20	5D
0005434879293	3500	21	11A
0005434879283	3500	22	11C
0005435126826	3500	23	11F
0005434879343	3500	24	11E
0005434938354	3500	25	11K
0005434879270	3500	26	11H
0005435913935	3500	27	11G
0005435126853	3500	28	12C
0005435626391	3500	29	12F
0005434938359	3500	30	12E
0005432799782	3500	31	12D
0005435626389	3500	32	12G
0005434426941	3500	33	12K
0005434879289	3500	34	13C
0005432611754	3500	35	13A
0005435126813	3500	36	13E
0005434879278	3500	37	13H
0005434879281	3500	38	13G
0005435126827	3500	39	14A
0005434426932	3500	40	13K
0005435126849	3500	41	14E
0005435902823	3500	42	14D
0005434879276	3500	43	14G
0005432799781	3500	44	14K
0005434879337	3500	45	15C
0005435841097	3500	46	15A
0005434879303	3500	47	15E
0005435902734	3500	48	15H
0005434879318	3500	49	16A
0005435126829	3500	50	15K
0005434938360	3500	51	16D
0005435626385	3500	52	16C
0005434426946	3500	53	16E
0005434426935	3500	54	16H
0005434879274	3500	55	16G
0005434426957	3500	56	17A
0005432188647	3500	57	17G
0005434879249	3500	58	17F
0005434879341	3500	59	17E
0005435126846	3500	60	17K
0005434426940	3500	61	18B
0005434938370	3500	62	18A
0005435626387	3500	63	18G
0005435126850	3500	64	18F
0005435626395	3500	65	18J
0005432799787	3500	66	18H
0005434879275	3500	67	19A
0005434879333	3500	68	18K
0005432611753	3500	69	19C
0005434938372	3500	70	19E
0005434879319	3500	71	19J
0005434426942	3500	72	19H
0005434426953	3500	73	19G
0005435902709	3500	74	19K
0005434879269	3500	75	20C
0005434879334	3500	76	20E
0005434879279	3500	77	20D
0005432799784	3500	78	20H
0005434879311	3500	79	20F
0005434879255	3500	80	20J
0005435126821	3500	81	21B
0005434879317	3500	82	21D
0005434879299	3500	83	21C
0005434426943	3500	84	21F
0005434879335	3500	85	21E
0005434938363	3500	86	21H
0005432799770	3500	87	22A
0005434938371	3500	88	21K
0005434879259	3500	89	22D
0005435626398	3500	90	22C
0005435902671	3500	91	22B
0005434879285	3500	92	22F
0005434426930	3500	93	22G
0005432799764	3500	94	23A
0005435126834	3500	95	23E
0005434938353	3500	96	23D
0005434938364	3500	97	23F
0005434938358	3500	98	23G
0005432799763	3500	99	24D
0005432799769	3500	100	23K
0005432611752	3500	101	24F
0005434879256	3500	102	24E
0005432799791	3500	103	24G
0005432799767	3500	104	25C
0005434879312	3500	105	25B
0005434879290	3500	106	25E
0005432799773	3500	107	25K
0005435126830	3500	108	25J
0005434879253	3500	109	26B
0005435913934	3500	110	26D
0005434426949	3500	111	26G
0005434938357	3500	112	26J
0005435126816	3500	113	26H
0005434938362	3500	114	27B
0005434426959	3500	115	27A
0005435126832	3500	116	27C
0005434879310	3500	117	27E
0005434879326	3500	118	27H
0005434879320	3500	119	27G
0005432799771	3500	120	27K
0005434426938	3500	121	27J
0005435126848	3500	122	28A
0005435126818	3500	123	28C
0005435126835	3500	124	28J
0005434426948	3500	125	29D
0005435902824	3500	126	29C
0005435902745	3500	127	29J
0005434879300	3500	128	29H
0005435126845	3500	129	29G
0005434879336	3500	130	30A
0005434426956	3500	131	29K
0005434879327	3500	132	30E
0005434938356	3500	133	30D
0005432613908	3500	134	30C
0005435902689	3500	135	30G
0005434879266	3500	136	30K
0005432799766	3500	137	31D
0005432799783	3500	138	31C
0005435902771	3500	139	31G
0005434879305	3500	140	31F
0005434879252	3500	141	31E
0005434879291	3500	142	31H
0005434879340	3500	143	32A
0005434879250	3500	144	31K
0005434426945	3500	145	31J
0005432188644	3500	146	32C
0005432613906	3500	147	32B
0005434426931	3500	148	32E
0005432799785	3500	149	32D
0005432799790	3500	150	32G
0005432613907	3500	151	32F
0005435902740	3500	152	32J
0005434879268	3500	153	32H
0005435126823	3500	154	33A
0005434426934	3500	155	33C
0005432799774	3500	156	33B
0005434879260	3500	157	33E
0005434879295	3500	158	33H
0005434879302	3500	159	34B
0005432188646	3500	160	34A
0005435626388	3500	161	34E
0005434879282	3500	162	35B
0005434879315	3500	163	35A
0005434879297	3500	164	34K
0005435126836	3500	165	35E
0005435126817	3500	166	35D
0005435126828	3500	167	35C
0005432799775	3500	168	35J
0005434879251	3500	169	36A
0005432613909	3500	170	36C
0005434879254	3500	171	36F
0005432799786	3500	172	36D
0005435626394	3500	173	36G
0005435126815	3500	174	36K
0005434879329	3500	175	36J
0005434879313	3500	176	37B
0005435902766	3500	177	37A
0005435902723	3500	178	37D
0005434879328	3500	179	37C
0005435126841	3500	180	37F
0005432799779	3500	181	37J
0005435913936	3500	182	37G
0005434938365	3500	183	38A
0005434938355	3500	184	37K
0005435126814	3500	185	38C
0005434426954	3500	186	38B
0005434426955	3500	187	38J
0005434879298	3500	188	38H
0005434879287	3500	189	39A
0005435902803	3500	190	39D
0005434879284	3500	191	39C
0005434426929	3500	192	39B
0005435126831	3500	193	39E
0005434879263	3500	194	39G
0005435126851	3500	195	40A
0005435126822	3500	196	39K
0005434938361	3500	197	40C
0005435126847	3500	198	40E
0005435126838	3500	199	40G
0005432183492	3500	200	40K
0005434879316	3500	201	40J
0005432799772	3500	202	40H
0005434879344	3500	203	41A
0005434879277	3500	204	41B
0005432611755	3500	205	41F
0005435126839	3500	206	41G
0005435126837	3500	207	42A
0005434879301	3500	208	41K
0005434879304	3500	209	41J
0005434426937	3500	210	42C
0005434879332	3500	211	42B
0005434879272	3500	212	42E
0005434879257	3500	213	42H
0005435626396	3500	214	42G
0005435626393	3500	215	42F
0005432799765	3500	216	42J
0005434879309	3500	217	43B
0005434879345	3500	218	43A
0005435126840	3500	219	43D
0005434426958	3500	220	43C
0005432799778	3500	221	43F
0005434426947	3500	222	43E
0005432799776	3500	223	43H
0005434938367	3500	224	43G
0005432799789	3500	225	44C
0005432799788	3500	226	44B
0005432183491	3500	227	44A
0005434879339	3500	228	44D
0005434879338	3500	229	44G
0005434879330	3500	230	44F
0005434938366	3500	231	44K
0005435126833	3500	232	44J
0005435126819	3500	233	45A
0005434879286	3500	234	45D
0005434879294	3500	235	45C
0005432799768	3500	236	45B
0005434879308	3500	237	45E
0005434879307	3500	238	45H
0005434426933	3500	239	45G
0005435902744	3500	240	45K
0005434879324	3500	241	46C
0005434938368	3500	242	46D
0005434879292	3500	243	46G
0005434879288	3500	244	46F
0005434879323	3500	245	46J
0005434879342	3500	246	47A
0005434426936	3500	247	46K
0005434879271	3500	248	47E
0005434879322	3500	249	47D
0005435126842	3500	250	47C
0005434426944	3500	251	47F
0005432799780	3500	252	47K
0005434879331	3500	253	47H
0005435626397	3500	254	48C
0005434879296	3500	255	48A
0005434879325	3500	256	48F
0005434879262	3500	257	48H
0005434938369	3500	258	49E
0005435126824	3500	259	49G
0005435902802	3500	260	49K
0005434879258	3500	261	49H
0005435126843	3500	262	50C
0005435126844	3500	263	50A
0005435126852	3500	264	50E
0005432799777	3500	265	50D
0005434879265	3500	266	50F
0005435902825	3500	267	51F
0005432799655	14541	1	1C
0005435902907	14541	2	1H
0005434938166	14541	3	1D
0005434878364	14541	4	1K
0005434426528	14541	5	2C
0005432799525	14541	6	2H
0005434878745	14541	7	3A
0005434878303	14541	8	3C
0005432611733	14541	9	4A
0005435902913	14541	10	4D
0005434878584	14541	11	5A
0005434938167	14541	12	4K
0005434426733	14541	13	4H
0005434426585	14541	14	5D
0005434878428	14541	15	5C
0005435126458	14541	16	5H
0005434878156	14541	17	5G
0005434878744	14541	18	11D
0005435914704	14541	19	11C
0005432611717	14541	20	11F
0005435626200	14541	21	11H
0005434878547	14541	22	11G
0005432799582	14541	23	12C
0005434938152	14541	24	12D
0005434426649	14541	25	12G
0005432799564	14541	26	12F
0005435626212	14541	27	12K
0005435626146	14541	28	13A
0005434426679	14541	29	13F
0005434878437	14541	30	13E
0005435126546	14541	31	13K
0005432059527	14541	32	13H
0005432059526	14541	33	14C
0005432799454	14541	34	14A
0005434878632	14541	35	14E
0005435126460	14541	36	14G
0005434426715	14541	37	14F
0005434878155	14541	38	14K
0005432799558	14541	39	14H
0005434426615	14541	40	15C
0005432799588	14541	41	15A
0005434878509	14541	42	15D
0005435902904	14541	43	15G
0005434878040	14541	44	15F
0005435126511	14541	45	15K
0005434878687	14541	46	15H
0005432799517	14541	47	16D
0005435626188	14541	48	16C
0005435126510	14541	49	16A
0005434938215	14541	50	16G
0005434878556	14541	51	17A
0005432799504	14541	52	16K
0005434938296	14541	53	17C
0005434879051	14541	54	17G
0005435626183	14541	55	17F
0005434938146	14541	56	17E
0005434878088	14541	57	17K
0005432799429	14541	58	17H
0005434426738	14541	59	18B
0005434878583	14541	60	18A
0005434426706	14541	61	18D
0005434426586	14541	62	18C
0005432799388	14541	63	18G
0005434878339	14541	64	18F
0005435841830	14541	65	18K
0005434878280	14541	66	18J
0005434878335	14541	67	19A
0005434878318	14541	68	19D
0005435626148	14541	69	19C
0005435626171	14541	70	19E
0005434878182	14541	71	20A
0005432607567	14541	72	20B
0005432799553	14541	73	20E
0005434878434	14541	74	20C
0005434878523	14541	75	20G
0005434878239	14541	76	20F
0005434426663	14541	77	20K
0005435902909	14541	78	20J
0005434426633	14541	79	21A
0005434938192	14541	80	21C
0005434878478	14541	81	21F
0005434878743	14541	82	21H
0005434426793	14541	83	21G
0005435902902	14541	84	22A
0005435126281	14541	85	22C
0005432799467	14541	86	22F
0005432799518	14541	87	22D
0005435126351	14541	88	22H
0005434878238	14541	89	22G
0005432611731	14541	90	22K
0005434878763	14541	91	22J
0005434426595	14541	92	23A
0005435126507	14541	93	23C
0005434878522	14541	94	23G
0005434878660	14541	95	23H
0005434426808	14541	96	23J
0005435126482	14541	97	24F
0005435902895	14541	98	24E
0005435626167	14541	99	25A
0005432799499	14541	100	25C
0005435626153	14541	101	25B
0005434878406	14541	102	25F
0005435126367	14541	103	25E
0005434426619	14541	104	25D
0005434938253	14541	105	25J
0005434426620	14541	106	25H
0005434878138	14541	107	26A
0005435126454	14541	108	26C
0005432799462	14541	109	26G
0005435626189	14541	110	26H
0005434938329	14541	111	27B
0005434878526	14541	112	27D
0005435126349	14541	113	27C
0005434878753	14541	114	27F
0005435126542	14541	115	27E
0005432799512	14541	116	28A
0005434426686	14541	117	27K
0005434878727	14541	118	28B
0005432799600	14541	119	28D
0005434878758	14541	120	28G
0005435902906	14541	121	28F
0005435902910	14541	122	28J
0005435626210	14541	123	28H
0005434938254	14541	124	29B
0005434878659	14541	125	29A
0005435902911	14541	126	29D
0005432799505	14541	127	29C
0005435902908	14541	128	29F
0005434426761	14541	129	29E
0005435126496	14541	130	29J
0005432799562	14541	131	29H
0005435902896	14541	132	29G
0005434878310	14541	133	29K
0005434426632	14541	134	30C
0005434878746	14541	135	30B
0005434938307	14541	136	30E
0005434878790	14541	137	30G
0005435126457	14541	138	30F
0005432611718	14541	139	31A
0005435626174	14541	140	31D
0005434878302	14541	141	31C
0005435126368	14541	142	31B
0005434878708	14541	143	31H
0005435126447	14541	144	31J
0005434878688	14541	145	32C
0005434878467	14541	146	32A
0005434938230	14541	147	32E
0005432799651	14541	148	32D
0005435126499	14541	149	32G
0005434877932	14541	150	32F
0005435126065	14541	151	32J
0005434878603	14541	152	32H
0005434878337	14541	153	33A
0005434877908	14541	154	32K
0005434878594	14541	155	33D
0005434878791	14541	156	33C
0005435126486	14541	157	33F
0005434879050	14541	158	33H
0005435126497	14541	159	34C
0005432799549	14541	160	34B
0005434878622	14541	161	34E
0005435902905	14541	162	34D
0005435126348	14541	163	34H
0005434878768	14541	164	34G
0005432799498	14541	165	34F
0005434878760	14541	166	34J
0005434878499	14541	167	35A
0005434426739	14541	168	34K
0005435626209	14541	169	35C
0005435626176	14541	170	35F
0005435126302	14541	171	35J
0005432799524	14541	172	35H
0005434878724	14541	173	35G
0005435126456	14541	174	35K
0005435626207	14541	175	36F
0005435126473	14541	176	36H
0005434878604	14541	177	36G
0005435902897	14541	178	36K
0005432799506	14541	179	36J
0005435902898	14541	180	37D
0005434426685	14541	181	37C
0005435126495	14541	182	37F
0005435902903	14541	183	37E
0005435626177	14541	184	37H
0005434426606	14541	185	38A
0005435913965	14541	186	38C
0005435902901	14541	187	38B
0005434878722	14541	188	38K
0005434938297	14541	189	38J
0005432799597	14541	190	38H
0005434878513	14541	191	39B
0005434426604	14541	192	39A
0005434878757	14541	193	39D
0005434878435	14541	194	39C
0005435626149	14541	195	39F
0005432799466	14541	196	39E
0005434878756	14541	197	39G
0005435626166	14541	198	39J
0005434877778	14541	199	40C
0005434878844	14541	200	40F
0005432607572	14541	201	40E
0005435126459	14541	202	40G
0005434878297	14541	203	40K
0005432799602	14541	204	40J
0005432611721	14541	205	41B
0005434426737	14541	206	41A
0005434878477	14541	207	41C
0005434938142	14541	208	41F
0005434878585	14541	209	41E
0005435126381	14541	210	41G
0005434878706	14541	211	42A
0005435626172	14541	212	41J
0005434878527	14541	213	42C
0005435902912	14541	214	42B
0005434878838	14541	215	42E
0005434878546	14541	216	42D
0005434878525	14541	217	42H
0005434878728	14541	218	42G
0005435126280	14541	219	42J
0005432799550	14541	220	43B
0005432799563	14541	221	43A
0005434878387	14541	222	42K
0005434426710	14541	223	43C
0005434878338	14541	224	43F
0005434878438	14541	225	43H
0005434878429	14541	226	43K
0005435626211	14541	227	44C
0005435126501	14541	228	44B
0005432799423	14541	229	44E
0005435626203	14541	230	44G
0005434878750	14541	231	44F
0005435626125	14541	232	44K
0005435626152	14541	233	44J
0005434426807	14541	234	45B
0005434878497	14541	235	45A
0005434878336	14541	236	45C
0005435626173	14541	237	45D
0005435626058	14541	238	45H
0005432799565	14541	239	45K
0005434878754	14541	240	45J
0005434938193	14541	241	46B
0005434878376	14541	242	46A
0005434878755	14541	243	46E
0005434877931	14541	244	46G
0005434878479	14541	245	46F
0005435902899	14541	246	46J
0005434878500	14541	247	46H
0005434878042	14541	248	47A
0005434878524	14541	249	46K
0005434938292	14541	250	47D
0005435626151	14541	251	47C
0005434938231	14541	252	47F
0005435126352	14541	253	47K
0005434878468	14541	254	47H
0005434938291	14541	255	48D
0005435126455	14541	256	48A
0005435902900	14541	257	48F
0005435126406	14541	258	48E
0005435626179	14541	259	49A
0005435626206	14541	260	48K
0005434878039	14541	261	49E
0005434878271	14541	262	49D
0005434878334	14541	263	49C
0005434426734	14541	264	49G
0005434426621	14541	265	49F
0005434878196	14541	266	49H
0005435626154	14541	267	50A
0005434878520	14541	268	50E
0005434426631	14541	269	50F
0005432799593	14541	270	50K
0005434878281	14541	271	51F
0005434878528	14541	272	51G
0005434312341	3602	1	1A
0005434325784	3602	2	1B
0005434325774	3602	3	1C
0005435889924	3602	4	3B
0005434325776	3602	5	4A
0005435889913	3602	6	5A
0005434325779	3602	7	6A
0005434312342	3602	8	6B
0005434325778	3602	9	6D
0005435889923	3602	10	7A
0005435889914	3602	11	7B
0005434325780	3602	12	7C
0005434325782	3602	13	18C
0005434325775	3602	14	18D
0005434312343	3602	15	19A
0005435889932	3602	16	19B
0005435889927	3602	17	19D
0005434325785	3602	18	20C
0005435889910	3602	19	21A
0005434325781	3602	20	21B
0005434325777	3602	21	21D
0005435889928	3602	22	22A
0005434325783	3602	23	23A
0005435889909	3602	24	22D
0005434325649	15596	1	1A
0005434325723	15596	2	1B
0005435889964	15596	3	1D
0005434325697	15596	4	2D
0005434325733	15596	5	4C
0005434325716	15596	6	5B
0005434325700	15596	7	7C
0005435889966	15596	8	7D
0005434325734	15596	9	19A
0005434325715	15596	10	19D
0005434325699	15596	11	20A
0005434325714	15596	12	20B
0005434325722	15596	13	21A
0005434325696	15596	14	21C
0005435889963	15596	15	21D
0005435889967	15596	16	22A
0005435889965	15596	17	23A
0005435957866	646	1	1B
0005435957875	646	2	1C
0005435957862	646	3	1D
0005435957874	646	4	2B
0005435957864	646	5	2C
0005435957873	646	6	3A
0005435957870	646	7	3D
0005435957867	646	8	4D
0005433420441	646	9	5D
0005435957861	646	10	6A
0005435957865	646	11	6B
0005433420440	646	12	6D
0005435957868	646	13	7B
0005435957871	646	14	7D
0005435957872	646	15	18A
0005435957863	646	16	20D
0005433420426	646	17	21A
0005433420422	646	18	21B
0005433420427	646	19	22B
0005433420474	646	20	22C
0005435957869	646	21	23A
0005435957786	15164	1	1A
0005433420499	15164	2	1B
0005435957714	15164	3	1D
0005435957699	15164	4	2A
0005435957767	15164	5	2B
0005433420502	15164	6	2D
0005435957706	15164	7	3C
0005433420495	15164	8	3B
0005435957701	15164	9	3D
0005435957783	15164	10	4A
0005435957722	15164	11	4B
0005433420501	15164	12	6C
0005433420496	15164	13	6D
0005435957723	15164	14	7D
0005433420500	15164	15	19B
0005433420497	15164	16	19C
0005435957804	15164	17	20D
0005435957700	15164	18	21C
0005433420494	15164	19	21D
0005435957760	15164	20	22A
0005433420503	15164	21	22C
0005433420498	15164	22	22D
0005435957803	15164	23	23A
0005435216583	27263	1	1A
0005435219197	27263	2	2A
0005435219208	27263	3	2C
0005435221060	27263	4	3D
0005435221057	27263	5	4D
0005435216581	27263	6	5A
0005435216580	27263	7	5B
0005435216589	27263	8	5C
0005435216588	27263	9	6B
0005435219199	27263	10	6C
0005435216597	27263	11	6D
0005435219206	27263	12	7B
0005435216592	27263	13	19B
0005435216591	27263	14	19C
0005435219200	27263	15	20A
0005435219207	27263	16	21C
0005435219198	27263	17	21D
0005435216582	27263	18	22A
0005435216590	27263	19	23A
0005435217736	31777	1	1A
0005435216612	31777	2	3A
0005435216609	31777	3	3C
0005435217731	31777	4	3D
0005435217732	31777	5	6A
0005435216608	31777	6	6C
0005435217735	31777	7	7B
0005435217738	31777	8	7C
0005435216613	31777	9	7D
0005435217734	31777	10	18C
0005435217737	31777	11	19C
0005435216607	31777	12	20B
0005435216611	31777	13	21A
0005435216610	31777	14	22B
0005435216614	31777	15	22C
0005435217733	31777	16	23A
0005434247160	8928	1	1B
0005434247155	8928	2	3A
0005434247162	8928	3	2B
0005434247152	8928	4	4B
0005434247163	8928	5	6A
0005434247176	16098	1	1B
0005434247177	16098	2	2A
0005435629406	16098	3	3B
0005434467783	4006	1	2A
0005434467787	4006	2	3D
0005434467782	4006	3	6A
0005434467785	4006	4	7A
0005434467789	4006	5	7D
0005434467784	4006	6	18B
0005434467786	4006	7	19C
0005434467790	4006	8	20D
0005434467788	4006	9	23A
0005434467761	23205	1	2D
0005434467774	23205	2	3C
0005434467763	23205	3	4D
0005434467764	23205	4	5C
0005434467755	23205	5	5D
0005434467756	23205	6	18B
0005434467757	23205	7	19C
0005434467773	23205	8	20D
0005434467772	23205	9	21D
0005435163287	4441	1	1A
0005435163292	4441	2	2D
0005435933477	4441	3	3B
0005435933464	4441	4	3C
0005435163293	4441	5	3D
0005435163281	4441	6	4B
0005435163294	4441	7	4C
0005435933461	4441	8	5A
0005435163285	4441	9	5B
0005435933469	4441	10	6D
0005435163288	4441	11	7D
0005435163279	4441	12	18B
0005435163289	4441	13	18C
0005435933460	4441	14	19A
0005435163286	4441	15	19B
0005435163290	4441	16	19C
0005435163284	4441	17	20A
0005435163280	4441	18	20C
0005435163291	4441	19	22A
0005435163283	4441	20	22B
0005435163282	4441	21	22D
0005435933465	4441	22	23B
0005435163253	29519	1	1C
0005435163264	29519	2	1D
0005435163236	29519	3	2B
0005435933490	29519	4	2D
0005435933489	29519	5	3D
0005435933492	29519	6	5A
0005435163242	29519	7	5B
0005435163241	29519	8	7D
0005435163251	29519	9	20B
0005435163222	29519	10	20C
0005435933493	29519	11	20D
0005435933491	29519	12	21A
0005435933494	29519	13	21B
0005435933495	29519	14	23B
0005435229428	6833	1	1A
0005432646095	6833	2	1C
0005432646103	6833	3	1D
0005435229424	6833	4	2A
0005432646124	6833	5	1F
0005432646100	6833	6	2D
0005435229409	6833	7	3A
0005432646142	6833	8	3C
0005432646119	6833	9	3F
0005435229480	6833	10	4A
0005432646112	6833	11	4C
0005432646131	6833	12	4E
0005432646108	6833	13	5A
0005435229416	6833	14	5C
0005432646139	6833	15	5F
0005432646143	6833	16	6A
0005435229445	6833	17	6C
0005435229425	6833	18	6D
0005432646106	6833	19	6F
0005435229446	6833	20	7A
0005435229418	6833	21	7C
0005435229451	6833	22	7D
0005432646141	6833	23	7F
0005432646107	6833	24	8A
0005432646120	6833	25	8C
0005432646121	6833	26	8D
0005435229449	6833	27	8E
0005435229419	6833	28	8F
0005435229448	6833	29	9A
0005435229407	6833	30	9C
0005432646129	6833	31	9D
0005432646114	6833	32	9E
0005432646104	6833	33	9F
0005432646096	6833	34	10A
0005432646098	6833	35	10C
0005432646092	6833	36	10D
0005432646133	6833	37	10E
0005435229417	6833	38	10F
0005432646111	6833	39	11A
0005435229415	6833	40	11C
0005432646116	6833	41	11D
0005432646145	6833	42	11F
0005432646132	6833	43	12C
0005435229408	6833	44	12A
0005432646105	6833	45	12D
0005432646144	6833	46	12E
0005432646128	6833	47	13A
0005432646138	6833	48	13C
0005435229420	6833	49	13E
0005435229389	6833	50	13F
0005432646136	6833	51	14C
0005435229426	6833	52	14D
0005432646123	6833	53	14E
0005432646109	6833	54	14F
0005432646115	6833	55	15C
0005435229427	6833	56	15A
0005432646140	6833	57	15D
0005432646093	6833	58	15E
0005432646097	6833	59	15F
0005435229388	6833	60	16A
0005432646137	6833	61	16C
0005432646113	6833	62	16D
0005432646118	6833	63	16E
0005432646117	6833	64	16F
0005432646135	6833	65	17A
0005432646130	6833	66	17C
0005432646126	6833	67	17D
0005432646127	6833	68	17E
0005435229456	6833	69	18A
0005435229433	6833	70	18C
0005432646094	6833	71	18D
0005432646125	6833	72	18F
0005432646110	6833	73	19A
0005432646099	6833	74	19C
0005432646102	6833	75	19D
0005435229434	6833	76	19E
0005432646101	6833	77	19F
0005435229436	6833	78	20A
0005432646122	6833	79	20C
0005432646134	6833	80	20D
0005435229455	6833	81	20E
0005435229444	6833	82	20F
0005435797641	2857	1	1D
0005433404823	2857	2	2C
0005435797630	2857	3	3D
0005435797631	2857	4	4C
0005435797638	2857	5	5E
0005435797628	2857	6	6D
0005433404841	2857	7	8F
0005433404824	2857	8	9A
0005433404805	2857	9	9C
0005435797636	2857	10	9D
0005433404838	2857	11	10A
0005433404828	2857	12	11A
0005435797634	2857	13	11D
0005433404839	2857	14	13D
0005435797640	2857	15	14E
0005435797637	2857	16	15A
0005435797627	2857	17	16A
0005435797633	2857	18	16D
0005433404829	2857	19	17E
0005433404825	2857	20	18F
0005435797639	2857	21	19A
0005435797629	2857	22	19D
0005435797632	2857	23	20C
0005435797635	2857	24	20D
0005435797595	29320	1	3A
0005435797596	29320	2	3C
0005435797485	29320	3	4A
0005435797447	29320	4	4F
0005435797551	29320	5	5A
0005433404891	29320	6	6C
0005435797501	29320	7	7D
0005433404893	29320	8	8F
0005435797519	29320	9	9C
0005433404892	29320	10	9E
0005433404896	29320	11	10D
0005435797484	29320	12	14A
0005433404895	29320	13	14F
0005435797500	29320	14	17E
0005435797561	29320	15	18A
0005435797520	29320	16	18C
0005433404894	29320	17	18F
0005433404897	29320	18	19C
0005433404890	29320	19	19D
0005435376358	5777	1	3B
0005435376362	5777	2	5A
0005435376349	5777	3	6B
0005434948113	5731	1	1A
0005434948118	5731	2	1B
0005434948112	5731	3	2A
0005434948117	5731	4	2B
0005434948111	5731	5	3A
0005434948115	5731	6	3B
0005434948120	5731	7	4A
0005434948110	5731	8	4B
0005434948116	5731	9	5A
0005434948114	5731	10	6A
0005434948119	5731	11	6B
0005434948039	16313	1	1A
0005434948046	16313	2	1B
0005435376379	16313	3	2A
0005434948038	16313	4	2B
0005435376376	16313	5	3A
0005435376378	16313	6	3B
0005435376375	16313	7	4A
0005435376377	16313	8	4B
0005434948047	16313	9	5B
0005434948054	16313	10	6A
0005435376380	16313	11	6B
0005433961488	6853	1	1D
0005433961530	6853	2	2A
0005433961520	6853	3	2C
0005433961489	6853	4	4C
0005433961500	6853	5	4D
0005433961512	6853	6	4F
0005433961522	6853	7	5D
0005433961509	6853	8	5F
0005433961521	6853	9	6D
0005433961487	6853	10	6F
0005433961492	6853	11	7D
0005433961491	6853	12	7E
0005433961496	6853	13	7F
0005433961499	6853	14	8A
0005433961493	6853	15	8F
0005433961529	6853	16	9D
0005433961526	6853	17	9F
0005433961503	6853	18	10A
0005433961505	6853	19	10C
0005433961511	6853	20	10D
0005433961524	6853	21	10F
0005433961498	6853	22	11C
0005433961516	6853	23	12D
0005433961490	6853	24	12E
0005433961510	6853	25	12F
0005433961504	6853	26	13A
0005433961525	6853	27	13C
0005433961531	6853	28	14A
0005433961518	6853	29	14C
0005433961513	6853	30	14E
0005433961507	6853	31	14F
0005433961515	6853	32	15D
0005433961508	6853	33	15E
0005433961506	6853	34	15F
0005433961495	6853	35	16A
0005433961501	6853	36	16C
0005433961517	6853	37	16D
0005433961502	6853	38	17A
0005433961494	6853	39	17C
0005433961497	6853	40	18C
0005433961514	6853	41	19C
0005433961519	6853	42	19F
0005433961528	6853	43	20A
0005433961523	6853	44	20E
0005433961527	6853	45	20F
0005433960956	25723	1	1A
0005433960867	25723	2	1D
0005433960840	25723	3	1F
0005433960849	25723	4	2D
0005433960901	25723	5	3A
0005433960788	25723	6	3C
0005433960885	25723	7	3D
0005433960712	25723	8	3F
0005433960718	25723	9	4A
0005433960866	25723	10	4D
0005433960716	25723	11	4E
0005433960933	25723	12	5A
0005433960900	25723	13	5C
0005433960801	25723	14	5D
0005433960736	25723	15	5E
0005433960948	25723	16	5F
0005433960735	25723	17	6D
0005433960935	25723	18	6E
0005433960717	25723	19	7A
0005433960705	25723	20	7C
0005433960930	25723	21	7E
0005433960693	25723	22	7F
0005433960922	25723	23	8A
0005433960600	25723	24	8C
0005433960575	25723	25	8D
0005433960931	25723	26	8E
0005433960847	25723	27	9C
0005433960858	25723	28	9D
0005433960952	25723	29	9E
0005433960860	25723	30	10A
0005433960791	25723	31	10E
0005433960812	25723	32	11A
0005433960926	25723	33	11C
0005433960787	25723	34	11D
0005433960826	25723	35	11E
0005433960932	25723	36	12C
0005433960694	25723	37	12E
0005433960909	25723	38	13A
0005433960925	25723	39	13C
0005433960903	25723	40	13D
0005433960863	25723	41	14A
0005433960820	25723	42	14D
0005433960875	25723	43	14F
0005433960889	25723	44	15A
0005433960688	25723	45	15C
0005433960857	25723	46	15F
0005433960699	25723	47	16A
0005433960796	25723	48	16C
0005433960864	25723	49	16D
0005433960538	25723	50	16F
0005433960874	25723	51	17C
0005433960876	25723	52	17D
0005433960698	25723	53	17E
0005433960859	25723	54	17F
0005433960923	25723	55	18A
0005433960899	25723	56	18D
0005433960934	25723	57	19D
0005433960955	25723	58	19E
0005433960886	25723	59	20A
0005435082802	24536	1	1B
0005435082806	24536	2	2B
0005435082803	24536	3	5B
0005435082789	24536	4	6A
0005435082771	24536	5	6B
0005435082867	26042	1	1A
0005435082868	26042	2	2A
0005435082866	26042	3	2B
0005435082869	26042	4	3A
0005435082865	26042	5	3B
0005435082870	26042	6	4A
0005435082864	26042	7	4B
0005435082871	26042	8	5B
0005435082872	26042	9	6B
0005434245313	5123	1	2C
0005434245297	5123	2	2F
0005434245298	5123	3	5A
0005434245323	5123	4	6A
0005434245299	5123	5	5F
0005435286605	5123	6	8A
0005435286651	5123	7	8F
0005434245320	5123	8	9D
0005434245308	5123	9	9F
0005434245300	5123	10	9E
0005434245309	5123	11	10F
0005434245303	5123	12	11C
0005434245312	5123	13	12A
0005434245311	5123	14	12E
0005434245318	5123	15	12F
0005432166938	5123	16	15B
0005434245305	5123	17	15A
0005434245326	5123	18	16B
0005434245322	5123	19	16C
0005434245301	5123	20	17F
0005434245314	5123	21	18B
0005434245310	5123	22	18D
0005435286647	5123	23	19C
0005434245306	5123	24	19B
0005434245317	5123	25	20A
0005435286632	5123	26	20C
0005434245316	5123	27	21B
0005434245319	5123	28	22B
0005435286650	5123	29	22C
0005435286641	5123	30	22D
0005432166940	5123	31	22E
0005434245315	5123	32	24A
0005433534509	5123	33	24F
0005434245325	5123	34	25C
0005434245321	5123	35	26E
0005435286633	5123	36	27C
0005434245302	5123	37	29C
0005434245307	5123	38	29E
0005434245304	5123	39	29D
0005432166939	5123	40	31C
0005434245324	5123	41	31F
0005433785338	5126	1	1C
0005433785352	5126	2	1A
0005432106095	5126	3	1F
0005432106088	5126	4	1D
0005432106085	5126	5	2A
0005432106123	5126	6	2C
0005433785336	5126	7	2D
0005432106109	5126	8	3A
0005433785368	5126	9	2F
0005433615501	5126	10	3C
0005433615522	5126	11	3F
0005432106110	5126	12	3D
0005433615486	5126	13	4A
0005433615531	5126	14	4C
0005432106108	5126	15	4D
0005433615492	5126	16	5A
0005433615489	5126	17	4F
0005432106124	5126	18	5C
0005433615526	5126	19	5F
0005433615528	5126	20	5D
0005432106113	5126	21	6A
0005432106127	5126	22	6C
0005432106125	5126	23	6D
0005433615541	5126	24	7A
0005433615552	5126	25	6F
0005433785372	5126	26	7C
0005433785364	5126	27	7F
0005432106098	5126	28	7D
0005433615535	5126	29	8A
0005432106112	5126	30	8C
0005432106121	5126	31	8B
0005433785343	5126	32	8D
0005433615488	5126	33	8E
0005432106120	5126	34	8F
0005433785337	5126	35	9B
0005433615491	5126	36	9A
0005433615497	5126	37	9C
0005433785347	5126	38	9E
0005433785356	5126	39	9D
0005433615547	5126	40	9F
0005432145135	5126	41	10A
0005433615498	5126	42	10C
0005432106084	5126	43	10B
0005433785366	5126	44	10E
0005432106122	5126	45	10D
0005432667476	5126	46	10F
0005433785341	5126	47	11A
0005433615553	5126	48	11C
0005432106101	5126	49	11B
0005432106102	5126	50	11D
0005433615505	5126	51	11E
0005433785357	5126	52	12A
0005433615517	5126	53	11F
0005433785363	5126	54	12B
0005432106130	5126	55	12D
0005433615524	5126	56	12C
0005433615484	5126	57	12E
0005432106099	5126	58	12F
0005433615516	5126	59	13B
0005433615542	5126	60	13A
0005433615539	5126	61	13C
0005433615490	5126	62	13E
0005432106105	5126	63	13D
0005432106107	5126	64	14A
0005433615555	5126	65	13F
0005433615518	5126	66	14B
0005432106100	5126	67	14C
0005432106115	5126	68	14E
0005433785362	5126	69	14D
0005433785365	5126	70	15A
0005433615499	5126	71	14F
0005433615550	5126	72	15C
0005433615515	5126	73	15B
0005433615548	5126	74	15E
0005433615483	5126	75	15D
0005432106111	5126	76	16A
0005433615546	5126	77	15F
0005433785344	5126	78	16C
0005432106094	5126	79	16B
0005433615530	5126	80	16E
0005433615507	5126	81	16D
0005432106086	5126	82	16F
0005433615502	5126	83	17B
0005433785367	5126	84	17A
0005432666412	5126	85	17C
0005433615510	5126	86	17D
0005433785345	5126	87	17F
0005433615509	5126	88	17E
0005433615513	5126	89	18A
0005433615511	5126	90	18B
0005433615520	5126	91	18D
0005433785342	5126	92	18C
0005433615532	5126	93	18E
0005433615500	5126	94	18F
0005432106116	5126	95	19C
0005432145136	5126	96	19B
0005432106129	5126	97	19D
0005432106128	5126	98	20A
0005433785349	5126	99	19E
0005433615527	5126	100	20B
0005433785369	5126	101	20C
0005432106089	5126	102	20D
0005433615534	5126	103	20F
0005433785355	5126	104	20E
0005433785351	5126	105	21B
0005433785359	5126	106	21A
0005432106097	5126	107	21C
0005433615495	5126	108	21D
0005433615506	5126	109	21E
0005432106104	5126	110	22A
0005433615554	5126	111	21F
0005433785358	5126	112	22B
0005433785350	5126	113	22C
0005433785373	5126	114	22E
0005432106090	5126	115	22D
0005433615493	5126	116	22F
0005432106091	5126	117	23A
0005432667477	5126	118	23C
0005433615536	5126	119	23B
0005433785340	5126	120	23D
0005433615521	5126	121	23E
0005433785353	5126	122	24A
0005433615540	5126	123	23F
0005433615523	5126	124	24B
0005433615487	5126	125	24C
0005433615485	5126	126	24E
0005432145134	5126	127	24D
0005433615482	5126	128	24F
0005432106117	5126	129	25A
0005433615508	5126	130	25C
0005433615545	5126	131	25B
0005433615504	5126	132	25D
0005433615519	5126	133	25F
0005433615514	5126	134	25E
0005433615556	5126	135	26A
0005433615529	5126	136	26C
0005432665298	5126	137	26B
0005432106092	5126	138	26D
0005433615544	5126	139	26E
0005433785361	5126	140	26F
0005433785348	5126	141	27A
0005433785374	5126	142	27C
0005433615494	5126	143	27B
0005432106114	5126	144	27D
0005432106093	5126	145	27E
0005433615549	5126	146	28A
0005432106096	5126	147	27F
0005432106118	5126	148	28B
0005433615543	5126	149	28D
0005433785370	5126	150	28C
0005433785346	5126	151	28E
0005432106126	5126	152	28F
0005433615538	5126	153	29B
0005433615551	5126	154	29A
0005432106083	5126	155	29C
0005433615525	5126	156	29D
0005432666411	5126	157	29E
0005432106106	5126	158	30A
0005432106119	5126	159	29F
0005433785339	5126	160	30B
0005433615537	5126	161	30C
0005432106103	5126	162	30E
0005433615533	5126	163	30D
0005433615512	5126	164	30F
0005433615496	5126	165	31B
0005433615503	5126	166	31A
0005433785354	5126	167	31C
0005432106087	5126	168	31D
0005433785360	5126	169	31E
0005433785371	5126	170	31F
0005434265438	5193	1	1A
0005433688804	5193	2	1C
0005435269749	5193	3	1F
0005432336088	5193	4	1D
0005435007139	5193	5	2D
0005435007114	5193	6	2C
0005433688815	5193	7	3A
0005433688809	5193	8	2F
0005434229618	5193	9	3F
0005434265436	5193	10	4A
0005432336072	5193	11	4F
0005434229616	5193	12	5A
0005434229627	5193	13	5C
0005434149868	5193	14	5F
0005434229636	5193	15	5D
0005434265422	5193	16	6C
0005434149865	5193	17	6D
0005434229631	5193	18	7A
0005434149864	5193	19	6F
0005435007031	5193	20	7C
0005433815398	5193	21	7F
0005434229617	5193	22	7D
0005434229624	5193	23	8A
0005435007134	5193	24	8D
0005432336068	5193	25	8E
0005434265440	5193	26	9C
0005435007113	5193	27	9F
0005434149862	5193	28	9E
0005434149860	5193	29	10A
0005434229634	5193	30	10B
0005434229629	5193	31	10D
0005434265433	5193	32	10E
0005434265441	5193	33	10F
0005434173564	5193	34	11B
0005434229630	5193	35	11C
0005432336045	5193	36	11D
0005432336052	5193	37	11F
0005433688814	5193	38	11E
0005434265434	5193	39	12C
0005435269761	5193	40	12B
0005435007183	5193	41	12D
0005434265416	5193	42	12F
0005434229620	5193	43	12E
0005435007147	5193	44	13B
0005434149859	5193	45	13E
0005432336071	5193	46	13C
0005435269754	5193	47	14A
0005434312322	5193	48	14C
0005434229625	5193	49	14D
0005434265427	5193	50	15B
0005434149857	5193	51	15A
0005434265437	5193	52	15C
0005435007116	5193	53	15D
0005434173566	5193	54	16A
0005434229615	5193	55	16D
0005434229633	5193	56	16C
0005435007146	5193	57	16E
0005434149867	5193	58	17A
0005434229638	5193	59	16F
0005435007097	5193	60	17B
0005434229613	5193	61	17D
0005433815399	5193	62	17E
0005433815390	5193	63	18A
0005435007103	5193	64	17F
0005434265431	5193	65	18B
0005434265423	5193	66	18D
0005434229635	5193	67	18E
0005434229622	5193	68	19B
0005434229628	5193	69	18F
0005434229619	5193	70	19D
0005434149866	5193	71	20A
0005434149863	5193	72	20C
0005434265429	5193	73	21A
0005434265421	5193	74	21B
0005433688813	5193	75	21D
0005434173565	5193	76	21C
0005434265424	5193	77	21F
0005432336054	5193	78	22A
0005435269750	5193	79	22C
0005434265435	5193	80	22D
0005435269752	5193	81	22F
0005434229623	5193	82	22E
0005434265430	5193	83	23B
0005434229621	5193	84	23D
0005432336051	5193	85	23C
0005434265425	5193	86	24A
0005435269755	5193	87	23F
0005435269748	5193	88	24B
0005434229637	5193	89	24C
0005434265419	5193	90	25C
0005434229632	5193	91	25D
0005434229626	5193	92	25F
0005433688816	5193	93	26A
0005434311223	5193	94	26C
0005434149861	5193	95	26B
0005435007101	5193	96	26F
0005435007127	5193	97	27A
0005433688808	5193	98	27C
0005435269762	5193	99	27B
0005434265418	5193	100	27D
0005434265417	5193	101	27F
0005435007117	5193	102	27E
0005434265420	5193	103	28D
0005435269756	5193	104	28C
0005434229614	5193	105	28F
0005432336040	5193	106	29A
0005435007065	5193	107	29C
0005434311218	5193	108	29D
0005434265432	5193	109	29E
0005435269753	5193	110	30A
0005435269746	5193	111	29F
0005435269751	5193	112	30C
0005434265439	5193	113	30F
0005434149858	5193	114	31B
0005435269747	5193	115	31D
0005434265426	5193	116	31F
0005434265428	5193	117	31E
0005435269832	8647	1	1D
0005433784932	8647	2	2F
0005433784994	8647	3	2D
0005433784984	8647	4	3A
0005433784992	8647	5	3C
0005434245021	8647	6	3D
0005435269827	8647	7	4A
0005435269831	8647	8	4D
0005435269838	8647	9	4F
0005433785023	8647	10	5A
0005434245002	8647	11	5D
0005435269830	8647	12	6D
0005433784904	8647	13	6F
0005434245086	8647	14	7A
0005433785176	8647	15	7F
0005433785058	8647	16	8D
0005433784903	8647	17	8C
0005434245106	8647	18	8F
0005432659709	8647	19	9A
0005434245059	8647	20	9B
0005434245147	8647	21	9E
0005432663037	8647	22	9F
0005434245140	8647	23	10B
0005433784959	8647	24	10D
0005434245149	8647	25	10F
0005435269837	8647	26	11B
0005433784993	8647	27	11A
0005433785096	8647	28	11C
0005434245107	8647	29	11D
0005435269824	8647	30	11E
0005434245030	8647	31	12A
0005433785119	8647	32	12B
0005434245061	8647	33	12D
0005434245077	8647	34	12E
0005434245144	8647	35	13A
0005433784924	8647	36	13E
0005433784958	8647	37	14A
0005435269825	8647	38	14C
0005433784925	8647	39	14D
0005434245148	8647	40	14F
0005434245094	8647	41	15D
0005434245136	8647	42	15E
0005435269839	8647	43	16D
0005434245087	8647	44	16C
0005432659710	8647	45	16F
0005434245056	8647	46	17A
0005434245084	8647	47	17E
0005435269835	8647	48	17D
0005434245116	8647	49	17F
0005433785118	8647	50	18A
0005434245185	8647	51	18C
0005434244976	8647	52	18D
0005434244964	8647	53	18E
0005434245138	8647	54	19B
0005435269833	8647	55	18F
0005434245143	8647	56	20C
0005433785177	8647	57	20E
0005433784799	8647	58	20D
0005433785009	8647	59	20F
0005434245062	8647	60	21C
0005433785054	8647	61	21D
0005433785091	8647	62	21E
0005434245203	8647	63	22B
0005435269836	8647	64	22D
0005433784983	8647	65	22F
0005435269834	8647	66	23C
0005433785152	8647	67	23D
0005434245156	8647	68	23F
0005433784926	8647	69	24B
0005434245029	8647	70	24A
0005433785053	8647	71	24E
0005433784947	8647	72	24D
0005434245135	8647	73	25B
0005432659715	8647	74	25D
0005435269829	8647	75	25F
0005433784978	8647	76	25E
0005434245031	8647	77	26E
0005434245139	8647	78	26D
0005434245117	8647	79	26F
0005435269828	8647	80	27D
0005433784975	8647	81	27F
0005435269826	8647	82	28B
0005433784929	8647	83	28D
0005433784798	8647	84	28E
0005432666395	8647	85	28F
0005434245055	8647	86	29A
0005433785084	8647	87	29F
0005434245063	8647	88	29E
0005433784890	8647	89	30E
0005433784931	8647	90	30F
0005434245060	8647	91	31A
0005432663038	8647	92	31C
0005433784991	8647	93	31B
0005434245067	8647	94	31E
0005433784976	8647	95	31D
0005433784891	8647	96	31F
0005433614812	8646	1	2F
0005433614930	8646	2	3A
0005433614768	8646	3	3C
0005433614777	8646	4	3F
0005433614886	8646	5	3D
0005433615094	8646	6	6C
0005433614750	8646	7	7D
0005433615084	8646	8	7C
0005433614721	8646	9	8D
0005433614444	8646	10	9A
0005433614727	8646	11	9B
0005433615008	8646	12	9E
0005433614822	8646	13	10A
0005433614908	8646	14	10C
0005433615011	8646	15	10D
0005433614838	8646	16	10E
0005433614936	8646	17	10F
0005433614659	8646	18	11B
0005433614716	8646	19	11C
0005433614839	8646	20	12B
0005433614639	8646	21	12D
0005433615192	8646	22	13A
0005433614607	8646	23	13B
0005433614932	8646	24	13D
0005433614742	8646	25	13F
0005433614765	8646	26	15A
0005433614899	8646	27	15E
0005433614900	8646	28	16B
0005433614724	8646	29	16D
0005433615193	8646	30	16E
0005433614891	8646	31	16F
0005433614726	8646	32	17A
0005433614720	8646	33	17C
0005433614853	8646	34	17E
0005433614814	8646	35	17F
0005433614731	8646	36	18F
0005433614980	8646	37	19E
0005433614710	8646	38	20A
0005433614852	8646	39	20C
0005433614758	8646	40	20E
0005433614732	8646	41	21A
0005433614715	8646	42	21C
0005433614769	8646	43	22A
0005433614837	8646	44	22D
0005433614830	8646	45	22F
0005433614595	8646	46	23D
0005433614608	8646	47	23C
0005433614759	8646	48	23F
0005433614906	8646	49	23E
0005433614921	8646	50	24A
0005433614625	8646	51	24D
0005433614841	8646	52	24E
0005433614973	8646	53	25A
0005433614741	8646	54	25F
0005433614988	8646	55	25E
0005433614840	8646	56	26B
0005433614743	8646	57	27C
0005433614823	8646	58	27E
0005433614887	8646	59	28C
0005433614824	8646	60	28B
0005433614540	8646	61	28D
0005433614815	8646	62	29D
0005433614794	8646	63	30D
0005433614755	8646	64	30F
0005433614709	8646	65	31B
0005433615026	8646	66	31A
0005433614793	8646	67	31E
0005432336167	8640	1	1A
0005434229397	8640	2	1D
0005432035257	8640	3	1C
0005435007302	8640	4	1F
0005432035261	8640	5	2C
0005434265311	8640	6	2D
0005434265247	8640	7	3A
0005434173532	8640	8	2F
0005432035272	8640	9	3C
0005434149781	8640	10	3F
0005432035249	8640	11	3D
0005434265209	8640	12	4C
0005435007303	8640	13	4D
0005435007283	8640	14	5A
0005435007284	8640	15	4F
0005435286676	8640	16	5D
0005434265220	8640	17	5C
0005434265182	8640	18	6A
0005434149762	8640	19	5F
0005434265102	8640	20	6C
0005432336172	8640	21	6F
0005432035269	8640	22	7A
0005434229364	8640	23	7C
0005432047592	8640	24	7F
0005433815441	8640	25	7D
0005434229340	8640	26	8A
0005434229489	8640	27	8C
0005435007297	8640	28	8B
0005435007291	8640	29	8D
0005432336168	8640	30	8E
0005434229359	8640	31	9A
0005434265207	8640	32	8F
0005434173539	8640	33	9B
0005434265227	8640	34	9C
0005432035259	8640	35	9D
0005434173518	8640	36	9F
0005434229250	8640	37	10A
0005433815443	8640	38	10C
0005434229380	8640	39	10B
0005434229360	8640	40	10D
0005435007286	8640	41	10E
0005434265186	8640	42	10F
0005434229448	8640	43	11B
0005432035266	8640	44	11A
0005434265261	8640	45	11D
0005434265224	8640	46	11F
0005435007280	8640	47	11E
0005435007282	8640	48	12A
0005435007281	8640	49	12B
0005433815440	8640	50	12D
0005434229560	8640	51	12C
0005434311243	8640	52	12E
0005432336175	8640	53	13A
0005434265257	8640	54	13B
0005432035252	8640	55	13D
0005434265310	8640	56	13C
0005434229447	8640	57	13F
0005433689934	8640	58	13E
0005435286681	8640	59	14A
0005435007296	8640	60	14B
0005432035253	8640	61	14D
0005432047594	8640	62	14C
0005435007292	8640	63	14E
0005434229496	8640	64	14F
0005432336166	8640	65	15A
0005432035270	8640	66	15C
0005432336164	8640	67	15B
0005434265183	8640	68	15D
0005435007301	8640	69	15F
0005433689935	8640	70	15E
0005433690947	8640	71	16A
0005434229404	8640	72	16B
0005434265242	8640	73	16D
0005432336171	8640	74	16C
0005432035255	8640	75	17A
0005432035263	8640	76	16F
0005434229479	8640	77	17B
0005433689936	8640	78	17C
0005434311242	8640	79	17D
0005434229422	8640	80	17F
0005434149743	8640	81	17E
0005435007295	8640	82	18A
0005435007298	8640	83	18B
0005434229363	8640	84	18D
0005432336169	8640	85	18F
0005434229362	8640	86	19C
0005434229453	8640	87	19B
0005435007300	8640	88	19D
0005432047593	8640	89	20A
0005434265107	8640	90	19E
0005434229441	8640	91	20B
0005432336163	8640	92	20C
0005434229342	8640	93	20D
0005434265161	8640	94	20F
0005434265190	8640	95	21A
0005432035251	8640	96	21B
0005434265256	8640	97	21D
0005433534523	8640	98	21E
0005433689937	8640	99	22A
0005435007299	8640	100	21F
0005432035273	8640	101	22B
0005435286679	8640	102	22D
0005435286677	8640	103	22C
0005435007287	8640	104	23B
0005432035268	8640	105	23A
0005434173535	8640	106	23C
0005432336165	8640	107	23D
0005432336174	8640	108	23E
0005434229559	8640	109	24A
0005432336170	8640	110	23F
0005435007285	8640	111	24B
0005432035274	8640	112	24D
0005434265125	8640	113	24E
0005435007278	8640	114	24F
0005432035254	8640	115	25A
0005434265079	8640	116	25B
0005432035250	8640	117	25D
0005432336173	8640	118	25C
0005432035258	8640	119	25F
0005434229341	8640	120	25E
0005432035260	8640	121	26A
0005435007279	8640	122	26B
0005434229423	8640	123	26D
0005433534522	8640	124	26C
0005434265148	8640	125	26E
0005434149786	8640	126	26F
0005434265080	8640	127	27B
0005434265218	8640	128	27A
0005435286680	8640	129	27C
0005435286678	8640	130	27D
0005432035256	8640	131	27E
0005435007293	8640	132	28A
0005434229249	8640	133	27F
0005435007290	8640	134	28B
0005434265246	8640	135	28C
0005432035262	8640	136	28E
0005435007288	8640	137	28D
0005434229454	8640	138	28F
0005435007289	8640	139	29B
0005434229405	8640	140	29A
0005433690948	8640	141	29C
0005434149787	8640	142	29D
0005434229361	8640	143	29F
0005434229393	8640	144	29E
0005434265208	8640	145	30B
0005432035264	8640	146	30A
0005434173531	8640	147	30D
0005434229394	8640	148	30C
0005433815442	8640	149	30E
0005434265108	8640	150	30F
0005435007294	8640	151	31B
0005432035271	8640	152	31A
0005434265245	8640	153	31C
0005432035265	8640	154	31D
0005432035267	8640	155	31F
0005434229379	8640	156	31E
0005433202530	12583	1	1A
0005434639345	12583	2	1B
0005434639486	12583	3	1C
0005433202533	12583	4	1D
0005434639445	12583	5	2A
0005434639272	12583	6	2B
0005434639341	12583	7	2C
0005434639344	12583	8	2D
0005434639404	12583	9	3A
0005434639438	12583	10	3B
0005433202537	12583	11	3C
0005434639343	12583	12	3D
0005434639467	12583	13	4A
0005433202525	12583	14	4B
0005434639468	12583	15	4C
0005434639293	12583	16	4D
0005434639469	12583	17	5A
0005434639273	12583	18	5B
0005434639444	12583	19	5C
0005433202536	12583	20	5D
0005434639373	12583	21	6A
0005434639362	12583	22	6B
0005434639292	12583	23	6C
0005433202526	12583	24	6D
0005433202539	12583	25	7A
0005434639403	12583	26	7C
0005433202538	12583	27	7D
0005433202524	12583	28	18A
0005433202534	12583	29	18B
0005434639295	12583	30	18C
0005433202528	12583	31	18D
0005434639470	12583	32	19A
0005434639297	12583	33	19B
0005433202535	12583	34	19C
0005433202532	12583	35	20A
0005434639364	12583	36	20C
0005434639429	12583	37	20D
0005434639363	12583	38	21A
0005434639374	12583	39	21B
0005434639491	12583	40	21C
0005434639437	12583	41	21D
0005434639351	12583	42	22A
0005434639352	12583	43	22B
0005433202531	12583	44	22C
0005434639402	12583	45	22D
0005433202527	12583	46	23A
0005433202529	12583	47	23B
0005433202317	23354	1	1B
0005432290665	23354	2	1C
0005434639582	23354	3	1D
0005433202323	23354	4	2A
0005433202316	23354	5	2B
0005433202408	23354	6	2C
0005434639587	23354	7	2D
0005434639576	23354	8	3A
0005434639579	23354	9	3B
0005434639574	23354	10	3C
0005434639583	23354	11	4A
0005433202386	23354	12	3D
0005434639581	23354	13	4B
0005434639597	23354	14	4C
0005434639575	23354	15	5A
0005432290666	23354	16	5B
0005433202407	23354	17	5C
0005434639577	23354	18	5D
0005434639578	23354	19	6A
0005434639585	23354	20	6B
0005434639596	23354	21	6C
0005434639584	23354	22	7C
0005434639586	23354	23	7D
0005434639580	23354	24	18B
0005433202419	23354	25	18C
0005434639593	23354	26	18D
0005434639595	23354	27	19A
0005433202357	23354	28	19B
0005434639589	23354	29	19C
0005434639588	23354	30	19D
0005432290664	23354	31	20A
0005433202342	23354	32	20B
0005434639594	23354	33	20C
0005434639590	23354	34	21B
0005433202349	23354	35	21C
0005434639573	23354	36	21D
0005434639598	23354	37	22A
0005433202332	23354	38	22D
0005434639591	23354	39	23A
0005434639592	23354	40	23B
0005432383246	21085	1	1A
0005432328833	21085	2	1C
0005432328812	21085	3	1D
0005432328853	21085	4	1F
0005432328726	21085	5	2A
0005432328941	21085	6	2C
0005432328691	21085	7	2D
0005432383215	21085	8	2F
0005432383108	21085	9	3A
0005432383204	21085	10	3C
0005432328558	21085	11	3D
0005432328839	21085	12	3F
0005432328557	21085	13	4A
0005432054338	21085	14	4C
0005432383319	21085	15	4D
0005432328701	21085	16	4E
0005432383249	21085	17	4F
0005432328515	21085	18	5A
0005432383328	21085	19	5C
0005432383182	21085	20	5D
0005432383196	21085	21	5E
0005432054340	21085	22	6A
0005432328894	21085	23	6C
0005432328679	21085	24	6E
0005432383426	21085	25	6F
0005432383195	21085	26	7A
0005432328849	21085	27	7C
0005432328788	21085	28	7E
0005432054339	21085	29	8A
0005432383172	21085	30	8D
0005432328695	21085	31	8E
0005432328876	21085	32	8F
0005432383251	21085	33	9A
0005432383259	21085	34	9C
0005432383175	21085	35	9D
0005432328541	21085	36	9F
0005432328687	21085	37	10A
0005432328621	21085	38	10C
0005432328725	21085	39	10D
0005432054336	21085	40	10E
0005432383205	21085	41	10F
0005432383244	21085	42	11A
0005432383363	21085	43	11C
0005432383214	21085	44	11D
0005432383296	21085	45	11E
0005432328770	21085	46	11F
0005432383383	21085	47	12A
0005432383294	21085	48	12C
0005432383144	21085	49	12D
0005432383145	21085	50	12E
0005432383272	21085	51	12F
0005432328740	21085	52	13A
0005432328540	21085	53	13C
0005432328875	21085	54	13D
0005432328834	21085	55	14A
0005432328821	21085	56	14C
0005432328759	21085	57	14D
0005432328931	21085	58	14E
0005432383166	21085	59	14F
0005432383176	21085	60	15A
0005432328514	21085	61	15C
0005432383258	21085	62	15D
0005432383250	21085	63	15E
0005432383305	21085	64	15F
0005432328888	21085	65	16A
0005432054337	21085	66	16C
0005432328747	21085	67	16D
0005432383339	21085	68	16E
0005432383106	21085	69	16F
0005432328813	21085	70	17A
0005432328811	21085	71	17C
0005432383231	21085	72	17D
0005432383165	21085	73	17E
0005432383271	21085	74	17F
0005432383341	21085	75	18A
0005432383184	21085	76	18C
0005432328916	21085	77	18D
0005432328915	21085	78	18E
0005432383441	21085	79	18F
0005432383047	21085	80	19A
0005432328773	21085	81	19C
0005432383263	21085	82	19D
0005432383181	21085	83	19E
0005432328787	21085	84	19F
0005432383295	21085	85	20A
0005432383177	21085	86	20C
0005432328840	21085	87	20D
0005432328854	21085	88	20E
0005432383427	21085	89	20F
0005432287241	31279	1	1A
0005432329199	31279	2	1C
0005432329167	31279	3	1D
0005432383583	31279	4	1F
0005432383571	31279	5	2A
0005432383603	31279	6	2C
0005432383584	31279	7	2D
0005432383591	31279	8	2F
0005432329189	31279	9	3A
0005432383594	31279	10	3C
0005432383573	31279	11	3D
0005432383592	31279	12	3F
0005432329173	31279	13	4A
0005432329159	31279	14	4C
0005432329175	31279	15	4D
0005432383587	31279	16	4E
0005432287243	31279	17	4F
0005432383598	31279	18	5A
0005432329198	31279	19	5C
0005432329197	31279	20	5D
0005432383574	31279	21	5E
0005432383605	31279	22	5F
0005432287240	31279	23	6A
0005432329162	31279	24	6C
0005432329194	31279	25	6D
0005432383602	31279	26	6E
0005432287242	31279	27	6F
0005432329164	31279	28	7A
0005432329186	31279	29	7C
0005432383590	31279	30	7D
0005432383599	31279	31	7E
0005432329190	31279	32	8A
0005432329205	31279	33	7F
0005432329187	31279	34	8D
0005432383577	31279	35	8E
0005432329188	31279	36	8F
0005432329200	31279	37	9A
0005432329181	31279	38	9C
0005432383572	31279	39	9D
0005432383601	31279	40	9E
0005432383600	31279	41	9F
0005432329165	31279	42	10A
0005432383597	31279	43	10C
0005432383579	31279	44	10D
0005432383588	31279	45	10E
0005432329171	31279	46	10F
0005432329202	31279	47	11A
0005432383580	31279	48	11C
0005432383581	31279	49	11D
0005432329195	31279	50	11E
0005432383593	31279	51	11F
0005432329166	31279	52	12A
0005432383608	31279	53	12C
0005432329176	31279	54	12D
0005432383582	31279	55	12E
0005432383585	31279	56	12F
0005432329183	31279	57	13A
0005432329174	31279	58	13C
0005432329180	31279	59	13D
0005432329177	31279	60	13E
0005432287244	31279	61	13F
0005432383595	31279	62	14C
0005432329178	31279	63	14D
0005432329184	31279	64	14E
0005432383596	31279	65	14F
0005432329172	31279	66	15A
0005432329161	31279	67	15C
0005432329169	31279	68	15D
0005432383578	31279	69	15E
0005432329163	31279	70	15F
0005432383607	31279	71	16A
0005432383604	31279	72	16C
0005432329196	31279	73	16D
0005432383576	31279	74	16E
0005432329179	31279	75	16F
0005432329185	31279	76	17A
0005432329168	31279	77	17C
0005432329193	31279	78	17F
0005432383606	31279	79	18A
0005432329182	31279	80	18C
0005432383575	31279	81	18D
0005432329192	31279	82	18E
0005432383589	31279	83	18F
0005432329191	31279	84	19A
0005432329201	31279	85	19C
0005432329160	31279	86	19D
0005432329204	31279	87	19E
0005432383586	31279	88	20E
0005432329203	31279	89	20D
0005432329170	31279	90	20F
0005433642489	2472	1	1A
0005433642519	2472	2	1C
0005433642491	2472	3	2A
0005433642511	2472	4	2F
0005432953937	2472	5	3A
0005432953878	2472	6	3C
0005432953927	2472	7	3D
0005432953941	2472	8	3F
0005433642510	2472	9	4C
0005432953942	2472	10	4E
0005432953952	2472	11	4F
0005433642514	2472	12	5A
0005432953987	2472	13	5C
0005433642485	2472	14	5D
0005432953907	2472	15	5E
0005433642499	2472	16	5F
0005432953960	2472	17	6C
0005433642494	2472	18	6D
0005433642502	2472	19	6F
0005433642478	2472	20	7A
0005432953948	2472	21	7C
0005433642512	2472	22	7D
0005433642475	2472	23	7E
0005433642496	2472	24	7F
0005432953965	2472	25	8A
0005433642490	2472	26	8C
0005433642474	2472	27	8E
0005432953951	2472	28	8F
0005433642498	2472	29	9A
0005433642492	2472	30	9C
0005433642493	2472	31	9D
0005433642482	2472	32	9E
0005433642488	2472	33	9F
0005432953938	2472	34	10C
0005433642513	2472	35	10D
0005433642515	2472	36	10E
0005432953917	2472	37	10F
0005432953986	2472	38	11A
0005432953953	2472	39	11D
0005432953966	2472	40	11E
0005432953950	2472	41	12D
0005433642497	2472	42	12E
0005432953920	2472	43	12F
0005433642503	2472	44	13D
0005433642505	2472	45	13E
0005433642486	2472	46	13F
0005433642483	2472	47	14A
0005432953949	2472	48	14D
0005432953916	2472	49	14E
0005433642479	2472	50	14F
0005432953934	2472	51	15A
0005433642481	2472	52	15C
0005433642516	2472	53	15D
0005433642506	2472	54	15E
0005433642477	2472	55	16A
0005432953908	2472	56	16C
0005432953955	2472	57	16D
0005432953961	2472	58	16E
0005433642484	2472	59	16F
0005433642507	2472	60	17A
0005433642500	2472	61	17C
0005433642495	2472	62	17E
0005433642517	2472	63	18A
0005433642508	2472	64	18C
0005433642480	2472	65	18D
0005433642518	2472	66	18F
0005433642509	2472	67	19D
0005432953928	2472	68	19E
0005433642501	2472	69	19F
0005433642504	2472	70	20D
0005433642476	2472	71	20E
0005433642487	2472	72	20F
0005432424915	13312	1	1A
0005432424922	13312	2	1D
0005432424932	13312	3	2D
0005432424946	13312	4	3C
0005432424930	13312	5	4C
0005432424931	13312	6	4E
0005432424949	13312	7	5A
0005432424956	13312	8	5E
0005432424950	13312	9	6A
0005432424957	13312	10	6C
0005432424940	13312	11	6F
0005432424951	13312	12	7A
0005432424936	13312	13	7C
0005432424918	13312	14	7D
0005432424924	13312	15	7E
0005432424948	13312	16	7F
0005432424960	13312	17	8D
0005432424943	13312	18	8E
0005432424953	13312	19	8F
0005432424958	13312	20	9D
0005432424944	13312	21	9E
0005432424920	13312	22	11C
0005432424941	13312	23	11F
0005432424935	13312	24	12A
0005432424954	13312	25	12C
0005432424927	13312	26	12F
0005432424917	13312	27	13A
0005432424926	13312	28	13D
0005432424942	13312	29	13E
0005432424947	13312	30	14A
0005432424921	13312	31	14C
0005432424939	13312	32	14E
0005432424952	13312	33	14F
0005432424916	13312	34	15A
0005432424934	13312	35	15E
0005432424938	13312	36	16A
0005432424961	13312	37	16C
0005432424923	13312	38	16E
0005432424919	13312	39	16F
0005432424928	13312	40	17A
0005432424937	13312	41	17C
0005432424945	13312	42	17D
0005432424933	13312	43	19C
0005432424929	13312	44	19D
0005432424955	13312	45	19E
0005432424959	13312	46	20D
0005432424925	13312	47	20F
0005432424486	30702	1	1A
0005432424495	30702	2	1C
0005432424523	30702	3	1D
0005432424493	30702	4	1F
0005432424475	30702	5	2A
0005432424536	30702	6	2F
0005432424450	30702	7	4A
0005432424570	30702	8	4C
0005432424566	30702	9	4D
0005432424499	30702	10	5D
0005432424496	30702	11	5F
0005432424534	30702	12	6A
0005432424542	30702	13	6C
0005432424468	30702	14	6D
0005432424423	30702	15	6E
0005432424430	30702	16	6F
0005432424567	30702	17	7A
0005432424528	30702	18	7C
0005432424514	30702	19	7D
0005432424443	30702	20	8A
0005432424444	30702	21	8C
0005432424485	30702	22	8E
0005432424476	30702	23	9C
0005432424457	30702	24	9E
0005432424386	30702	25	9F
0005432424541	30702	26	10A
0005432424498	30702	27	10D
0005432424488	30702	28	10E
0005432424512	30702	29	11A
0005432424482	30702	30	11D
0005432424527	30702	31	11E
0005432424529	30702	32	11F
0005432424504	30702	33	12E
0005432424449	30702	34	13C
0005432424544	30702	35	13D
0005432424555	30702	36	13F
0005432424458	30702	37	14A
0005432424466	30702	38	15A
0005432424568	30702	39	16A
0005432424441	30702	40	16D
0005432424197	30702	41	17D
0005432424494	30702	42	17F
0005432424543	30702	43	18A
0005432424442	30702	44	18C
0005432424480	30702	45	18D
0005432424492	30702	46	18E
0005432424552	30702	47	19A
0005432424489	30702	48	19C
0005432424569	30702	49	20A
0005432424363	30702	50	20C
0005432424520	30702	51	20D
0005432424362	30702	52	20E
0005432424439	30702	53	20F
0005432817794	9594	1	1A
0005432901637	9594	2	1C
0005432822286	9594	3	1F
0005432817791	9594	4	2A
0005432822288	9594	5	2C
0005432901624	9594	6	2D
0005432901663	9594	7	2F
0005432822289	9594	8	3A
0005432817798	9594	9	3C
0005432817817	9594	10	3D
0005432901703	9594	11	3F
0005432817796	9594	12	4A
0005432901615	9594	13	4C
0005432901652	9594	14	4D
0005434157490	9594	15	4E
0005434157506	9594	16	4F
0005432817815	9594	17	5A
0005434186193	9594	18	5D
0005434186215	9594	19	5E
0005432901636	9594	20	5F
0005432817804	9594	21	6A
0005432901682	9594	22	6D
0005432817788	9594	23	6E
0005434157505	9594	24	6F
0005434157489	9594	25	7A
0005434157500	9594	26	7C
0005432817799	9594	27	7D
0005432289024	9594	28	7F
0005432901664	9594	29	8A
0005434157518	9594	30	8C
0005432822290	9594	31	8E
0005432817795	9594	32	9A
0005432817811	9594	33	9C
0005432817818	9594	34	9D
0005432822287	9594	35	9E
0005432817803	9594	36	10A
0005432901577	9594	37	10C
0005432817802	9594	38	10D
0005432817807	9594	39	10E
0005432901681	9594	40	11A
0005432817816	9594	41	11C
0005432289022	9594	42	11D
0005432817805	9594	43	11E
0005432901578	9594	44	11F
0005432817790	9594	45	12A
0005432817793	9594	46	12C
0005432901603	9594	47	12D
0005434157479	9594	48	12E
0005432901635	9594	49	12F
0005432817813	9594	50	13A
0005432901670	9594	51	13C
0005432817789	9594	52	13D
0005434157519	9594	53	13E
0005432822292	9594	54	13F
0005432817797	9594	55	14A
0005434186220	9594	56	14C
0005432901666	9594	57	14E
0005432817792	9594	58	14F
0005432901569	9594	59	15A
0005432901628	9594	60	15C
0005432289023	9594	61	15D
0005432901602	9594	62	15E
0005434157473	9594	63	15F
0005432822291	9594	64	16A
0005432822293	9594	65	16D
0005432817806	9594	66	16E
0005434157499	9594	67	16F
0005432901683	9594	68	17D
0005432817809	9594	69	17F
0005432901645	9594	70	17E
0005432817808	9594	71	18A
0005432817800	9594	72	18C
0005434448354	9594	73	18F
0005432817814	9594	74	19A
0005432817810	9594	75	19C
0005432817801	9594	76	19E
0005434448355	9594	77	20D
0005432817812	9594	78	20E
0005432817603	28986	1	1A
0005434157565	28986	2	1C
0005432817446	28986	3	1D
0005432817543	28986	4	1F
0005432822215	28986	5	2A
0005432817593	28986	6	2C
0005434186229	28986	7	2D
0005432822229	28986	8	3A
0005432817576	28986	9	3C
0005432817547	28986	10	3D
0005432817575	28986	11	3F
0005432817493	28986	12	4C
0005432901815	28986	13	4E
0005432901804	28986	14	4F
0005434157563	28986	15	5D
0005432817560	28986	16	5E
0005434157568	28986	17	5F
0005432817594	28986	18	6A
0005434157569	28986	19	6D
0005432817490	28986	20	6F
0005432817574	28986	21	7A
0005432901807	28986	22	7D
0005432901814	28986	23	7E
0005432901806	28986	24	8A
0005432901813	28986	25	8C
0005434157564	28986	26	8D
0005432822230	28986	27	8E
0005432901805	28986	28	8F
0005432901803	28986	29	9E
0005432817750	28986	30	9F
0005432901811	28986	31	10A
0005432817563	28986	32	10D
0005434157567	28986	33	10E
0005432817559	28986	34	10F
0005432822237	28986	35	11A
0005432901802	28986	36	11C
0005432901809	28986	37	11D
0005434157570	28986	38	12D
0005432817519	28986	39	12C
0005432817668	28986	40	13A
0005434157566	28986	41	13C
0005432822216	28986	42	13D
0005432817749	28986	43	14D
0005432901808	28986	44	14E
0005432817520	28986	45	14F
0005434157571	28986	46	15C
0005432817552	28986	47	16D
0005432901799	28986	48	16E
0005432817666	28986	49	16F
0005432901800	28986	50	17A
0005432901810	28986	51	17C
0005432822207	28986	52	17D
0005432817521	28986	53	17E
0005432901798	28986	54	17F
0005432901812	28986	55	18A
0005432817667	28986	56	18D
0005432817573	28986	57	18F
0005432817627	28986	58	19A
0005432901801	28986	59	19D
0005432817546	28986	60	20A
0005432817494	28986	61	20C
0005434186230	28986	62	20D
0005432817447	28986	63	20E
0005432613906	15092	1	1A
0005432611754	15092	2	1B
0005432611753	15092	3	2A
0005432613909	15092	4	3A
0005432613908	15092	5	4A
0005432613907	15092	6	5A
0005435841097	15092	7	4B
0005432611752	15092	8	5B
0005432611755	15092	9	6B
0005432611717	31569	1	1A
0005435841830	31569	2	2A
0005432611718	31569	3	2B
0005432611721	31569	4	4A
0005432611733	31569	5	4B
0005432607567	31569	6	5A
0005432607572	31569	7	5B
0005432611731	31569	8	6A
0005433569662	11854	1	1C
0005432948608	11854	2	1A
0005433569671	11854	3	1F
0005432948490	11854	4	1D
0005433569679	11854	5	2C
0005433569664	11854	6	2A
0005433569655	11854	7	3A
0005433569670	11854	8	2F
0005432948638	11854	9	3C
0005433569680	11854	10	3F
0005433569674	11854	11	4C
0005433569653	11854	12	4F
0005432948376	11854	13	4D
0005433569667	11854	14	5C
0005433569704	11854	15	5A
0005432948605	11854	16	5F
0005432948562	11854	17	6B
0005433569650	11854	18	6C
0005432948496	11854	19	6E
0005433569698	11854	20	6D
0005432948525	11854	21	7A
0005433569675	11854	22	6F
0005433569703	11854	23	7C
0005432948266	11854	24	7B
0005432948535	11854	25	7E
0005433569661	11854	26	7D
0005432948462	11854	27	7F
0005433569699	11854	28	8B
0005433569659	11854	29	8A
0005433569702	11854	30	8E
0005432948549	11854	31	8D
0005433569678	11854	32	8C
0005432948497	11854	33	8F
0005432948561	11854	34	9A
0005432948591	11854	35	9D
0005432948489	11854	36	9C
0005432948457	11854	37	9B
0005432948522	11854	38	9E
0005433569668	11854	39	9F
0005433569673	11854	40	10C
0005432948537	11854	41	10B
0005433569685	11854	42	10E
0005432948554	11854	43	10D
0005432948553	11854	44	11A
0005433569669	11854	45	10F
0005432948612	11854	46	11B
0005432948416	11854	47	11D
0005432948516	11854	48	11C
0005433569693	11854	49	11F
0005433569663	11854	50	11E
0005433569706	11854	51	12B
0005433569649	11854	52	12A
0005432948526	11854	53	12D
0005433569687	11854	54	12C
0005433569697	11854	55	12F
0005433569681	11854	56	12E
0005433569682	11854	57	13A
0005432948505	11854	58	13C
0005433569658	11854	59	13E
0005433569683	11854	60	13F
0005432948630	11854	61	14A
0005433569651	11854	62	14E
0005432948521	11854	63	14D
0005432948538	11854	64	14C
0005432948494	11854	65	15B
0005433569684	11854	66	15A
0005432948366	11854	67	15D
0005433569695	11854	68	15C
0005432948639	11854	69	15E
0005433569654	11854	70	16A
0005433569686	11854	71	15F
0005432948267	11854	72	16B
0005433569688	11854	73	16D
0005432948590	11854	74	16F
0005432948396	11854	75	16E
0005433569665	11854	76	17B
0005432948555	11854	77	17D
0005433569705	11854	78	17C
0005433569700	11854	79	17E
0005433569666	11854	80	18B
0005433569652	11854	81	18A
0005433569694	11854	82	17F
0005433569701	11854	83	18C
0005432948637	11854	84	18E
0005432948405	11854	85	18D
0005432948435	11854	86	19A
0005432948466	11854	87	18F
0005433569677	11854	88	19C
0005433569696	11854	89	19B
0005433569689	11854	90	19D
0005432948465	11854	91	19F
0005433569690	11854	92	19E
0005432948571	11854	93	20B
0005432948597	11854	94	20A
0005433569672	11854	95	20D
0005432948470	11854	96	20C
0005433569660	11854	97	20E
0005432948506	11854	98	21B
0005433569691	11854	99	21A
0005433569692	11854	100	20F
0005433569657	11854	101	21F
0005433569676	11854	102	21E
0005433569656	11854	103	21D
0005432948952	25319	1	1A
0005433569176	25319	2	1F
0005433569195	25319	3	1D
0005432948954	25319	4	1C
0005433568937	25319	5	2D
0005432948934	25319	6	2C
0005433569256	25319	7	3A
0005432948940	25319	8	2F
0005433569069	25319	9	3C
0005432948955	25319	10	4A
0005433568998	25319	11	3F
0005432948962	25319	12	4C
0005432948968	25319	13	4F
0005433569288	25319	14	4D
0005433569236	25319	15	5C
0005432948963	25319	16	5A
0005433568995	25319	17	5F
0005432948950	25319	18	5D
0005433569239	25319	19	6B
0005433569171	25319	20	6A
0005432948964	25319	21	6C
0005433569220	25319	22	6F
0005433569095	25319	23	6E
0005432948931	25319	24	6D
0005433568802	25319	25	7A
0005433569137	25319	26	7C
0005433569283	25319	27	7B
0005433569050	25319	28	7E
0005432948969	25319	29	7F
0005432948959	25319	30	8B
0005433569073	25319	31	8A
0005432948965	25319	32	8D
0005432948953	25319	33	8C
0005432948938	25319	34	8F
0005433568936	25319	35	8E
0005433569286	25319	36	9B
0005432948957	25319	37	9A
0005433569087	25319	38	9C
0005433569287	25319	39	9D
0005433569257	25319	40	10A
0005432948937	25319	41	9F
0005432948958	25319	42	10C
0005432948972	25319	43	10D
0005432948967	25319	44	11A
0005432948948	25319	45	10F
0005433569127	25319	46	10E
0005433569064	25319	47	11C
0005433569221	25319	48	11B
0005433569296	25319	49	11D
0005432948971	25319	50	11F
0005432948945	25319	51	11E
0005432948961	25319	52	12B
0005433569139	25319	53	12A
0005433569136	25319	54	12D
0005433569285	25319	55	12C
0005433569295	25319	56	12E
0005433569248	25319	57	13B
0005433569025	25319	58	13A
0005433568692	25319	59	13C
0005433569165	25319	60	13E
0005432948947	25319	61	13D
0005433569084	25319	62	14A
0005433569194	25319	63	13F
0005432948932	25319	64	14B
0005433569219	25319	65	14D
0005432948949	25319	66	14F
0005432948973	25319	67	14E
0005432948946	25319	68	15B
0005432948943	25319	69	15A
0005433569080	25319	70	15C
0005433569032	25319	71	15F
0005433569297	25319	72	15E
0005432948966	25319	73	15D
0005433568935	25319	74	16A
0005432948951	25319	75	16C
0005432948936	25319	76	16B
0005433569168	25319	77	16E
0005433569074	25319	78	16D
0005432948970	25319	79	17A
0005432948941	25319	80	16F
0005432948935	25319	81	17B
0005433569169	25319	82	17C
0005433569231	25319	83	17E
0005433569249	25319	84	18B
0005433569086	25319	85	18A
0005432948960	25319	86	18C
0005433569203	25319	87	18E
0005433569029	25319	88	18D
0005433568958	25319	89	19A
0005432948939	25319	90	18F
0005433569232	25319	91	19B
0005432948933	25319	92	19D
0005433569281	25319	93	19C
0005433568972	25319	94	19F
0005433569240	25319	95	19E
0005433568873	25319	96	20B
0005433569049	25319	97	20A
0005433569282	25319	98	20C
0005432948956	25319	99	20F
0005432948942	25319	100	20E
0005432948944	25319	101	21B
0005433569250	25319	102	21A
0005433569264	25319	103	21D
0005433569265	25319	104	21E
0005433569202	25319	105	21F
0005433812898	14464	1	1A
0005434026725	14464	2	1D
0005433812905	14464	3	1C
0005433812908	14464	4	2C
0005433808366	14464	5	3F
0005433808382	14464	6	4D
0005434026727	14464	7	5A
0005433812915	14464	8	5D
0005433808376	14464	9	7A
0005432430902	14464	10	6F
0005433808348	14464	11	7E
0005432430904	14464	12	8B
0005433808349	14464	13	8E
0005433808378	14464	14	10A
0005433812894	14464	15	10B
0005432430898	14464	16	10E
0005433808377	14464	17	10D
0005434026726	14464	18	11D
0005434026724	14464	19	11F
0005434026728	14464	20	12B
0005432430905	14464	21	12F
0005433812897	14464	22	13E
0005433812896	14464	23	14A
0005433808368	14464	24	14F
0005432430903	14464	25	15B
0005433812909	14464	26	16C
0005432430906	14464	27	16E
0005433812907	14464	28	17F
0005432430899	14464	29	18C
0005432430907	14464	30	18E
0005433808370	14464	31	19A
0005433808365	14464	32	19B
0005432430901	14464	33	20A
0005432430900	14464	34	20C
0005433812895	14464	35	21A
0005432430908	14464	36	21B
0005433808417	30819	1	1A
0005433812924	30819	2	1D
0005434026698	30819	3	2A
0005433812917	30819	4	2D
0005433808407	30819	5	3A
0005432430866	30819	6	5A
0005432430872	30819	7	4F
0005433808414	30819	8	5C
0005433812921	30819	9	5F
0005433808406	30819	10	6B
0005432430874	30819	11	6A
0005432430855	30819	12	6F
0005433812920	30819	13	7C
0005433812919	30819	14	7B
0005434026699	30819	15	7E
0005433808418	30819	16	8B
0005432430862	30819	17	8C
0005433808416	30819	18	8F
0005432430867	30819	19	9C
0005433808419	30819	20	9B
0005432430854	30819	21	10B
0005432430871	30819	22	9F
0005433808421	30819	23	10E
0005433812925	30819	24	10D
0005434026687	30819	25	10F
0005433812922	30819	26	11B
0005432430861	30819	27	11F
0005433812916	30819	28	12A
0005432430878	30819	29	12C
0005433812918	30819	30	13C
0005433812923	30819	31	13E
0005434026708	30819	32	13D
0005432430869	30819	33	14A
0005434026707	30819	34	14D
0005432430846	30819	35	14F
0005432430863	30819	36	14E
0005433808408	30819	37	15D
0005432430849	30819	38	16A
0005433808405	30819	39	15F
0005433808410	30819	40	16C
0005432430858	30819	41	16D
0005434026688	30819	42	17B
0005433808411	30819	43	18B
0005433808413	30819	44	18D
0005433808415	30819	45	18E
0005434026714	30819	46	19A
0005432430868	30819	47	19C
0005432430864	30819	48	19D
0005433808412	30819	49	19F
0005432430860	30819	50	19E
0005433808409	30819	51	20D
0005432430859	30819	52	20C
0005434026689	30819	53	20E
0005434026703	30819	54	21A
0005433808420	30819	55	20F
0005432430865	30819	56	21F
0005434655007	5386	1	1D
0005434655025	5386	2	2D
0005434655022	5386	3	4A
0005434655001	5386	4	4C
0005435340259	5386	5	4D
0005434655023	5386	6	4E
0005434655012	5386	7	4F
0005434655020	5386	8	5A
0005434655018	5386	9	5C
0005434655013	5386	10	5D
0005434655024	5386	11	5F
0005435340281	5386	12	6A
0005434655000	5386	13	6C
0005435340324	5386	14	6F
0005434655008	5386	15	7A
0005434655004	5386	16	7D
0005434656578	5386	17	7F
0005434655014	5386	18	8D
0005434655011	5386	19	8E
0005435340304	5386	20	8F
0005435340283	5386	21	9C
0005434655019	5386	22	9E
0005432114240	5386	23	9F
0005434656579	5386	24	10A
0005434655026	5386	25	10F
0005435340303	5386	26	11A
0005435340276	5386	27	11C
0005432114241	5386	28	11D
0005435340287	5386	29	11E
0005435340237	5386	30	11F
0005434655009	5386	31	12A
0005432114238	5386	32	12F
0005434655010	5386	33	13A
0005435340370	5386	34	13D
0005435340317	5386	35	14A
0005435340280	5386	36	14C
0005435340301	5386	37	14E
0005434654999	5386	38	15E
0005434655015	5386	39	15F
0005435340300	5386	40	16D
0005434655006	5386	41	16E
0005434655017	5386	42	17A
0005434655016	5386	43	17C
0005432114239	5386	44	17F
0005435340293	5386	45	18A
0005434655003	5386	46	18E
0005434655005	5386	47	19A
0005434655002	5386	48	19D
0005435340296	5386	49	20A
0005434654998	5386	50	20E
0005434655021	5386	51	20F
0005434654756	12532	1	2D
0005434654758	12532	2	3C
0005435340441	12532	3	3D
0005435340428	12532	4	3F
0005435340438	12532	5	4C
0005434654680	12532	6	4D
0005434654810	12532	7	4E
0005434654693	12532	8	4F
0005434654774	12532	9	5A
0005435340432	12532	10	5D
0005435340434	12532	11	5E
0005434654775	12532	12	6A
0005434654727	12532	13	7D
0005435340440	12532	14	7E
0005435340430	12532	15	8A
0005434654840	12532	16	8C
0005434654747	12532	17	8D
0005434654715	12532	18	9A
0005434654764	12532	19	9E
0005435340426	12532	20	9F
0005434654609	12532	21	10A
0005435340439	12532	22	10C
0005434654755	12532	23	10E
0005434654763	12532	24	11A
0005434654839	12532	25	11C
0005435340425	12532	26	11D
0005435555394	12532	27	11E
0005434654802	12532	28	12D
0005435340429	12532	29	12E
0005434656558	12532	30	13D
0005434654718	12532	31	14D
0005434654669	12532	32	14E
0005434654719	12532	33	14F
0005434654679	12532	34	15A
0005434656564	12532	35	15D
0005435340437	12532	36	15E
0005435340427	12532	37	16D
0005434654922	12532	38	16E
0005435340431	12532	39	16F
0005435340435	12532	40	17C
0005434654740	12532	41	18C
0005435340436	12532	42	18E
0005434654705	12532	43	18F
0005434654692	12532	44	19E
0005434654750	12532	45	19F
0005435340433	12532	46	20A
0005434654761	12532	47	20C
0005434654818	12532	48	20E
0005434654757	12532	49	20F
0005432078172	7440	1	1A
0005433716519	7440	2	1D
0005433716523	7440	3	1F
0005433716533	7440	4	2A
0005433716551	7440	5	2F
0005433716502	7440	6	3D
0005432078171	7440	7	3C
0005433716541	7440	8	3F
0005433656704	7440	9	4A
0005433716499	7440	10	4C
0005433719178	7440	11	4E
0005432428926	7440	12	4D
0005433656705	7440	13	5A
0005433716515	7440	14	5D
0005433722289	7440	15	5F
0005432078170	7440	16	6B
0005433722284	7440	17	6C
0005435266142	7440	18	6D
0005433690946	7440	19	6E
0005433716535	7440	20	7B
0005433688831	7440	21	7C
0005433716507	7440	22	7E
0005433716536	7440	23	7D
0005433716503	7440	24	8A
0005433716544	7440	25	8B
0005433716540	7440	26	8E
0005433722292	7440	27	8F
0005433716534	7440	28	9B
0005433722293	7440	29	9D
0005433716511	7440	30	9C
0005433716539	7440	31	10B
0005433716520	7440	32	11B
0005433716521	7440	33	11C
0005432078168	7440	34	11E
0005433688833	7440	35	12A
0005433716501	7440	36	12B
0005433716550	7440	37	12E
0005433716552	7440	38	13A
0005433722288	7440	39	12F
0005433719176	7440	40	13C
0005433688830	7440	41	13B
0005433716529	7440	42	13D
0005433716548	7440	43	13E
0005433716509	7440	44	14A
0005433716514	7440	45	13F
0005433716513	7440	46	14B
0005433722290	7440	47	14D
0005433716526	7440	48	14E
0005433716530	7440	49	15A
0005433722291	7440	50	14F
0005432078167	7440	51	15C
0005433688832	7440	52	16A
0005433716522	7440	53	15F
0005433656706	7440	54	16B
0005432078169	7440	55	16C
0005433716516	7440	56	16F
0005433716543	7440	57	16E
0005433722286	7440	58	17A
0005433716508	7440	59	17B
0005433716524	7440	60	17F
0005433716517	7440	61	17E
0005433716504	7440	62	18A
0005433722287	7440	63	18B
0005433716532	7440	64	18E
0005433716538	7440	65	18D
0005433716505	7440	66	19D
0005433716506	7440	67	19C
0005433716518	7440	68	20A
0005433719177	7440	69	20C
0005433716531	7440	70	20D
0005433716510	7440	71	20F
0005433716537	7440	72	21A
0005433716500	7440	73	21C
0005433690945	7440	74	21F
0005433716546	7440	75	22A
0005433716547	7440	76	22C
0005433716525	7440	77	22B
0005433716512	7440	78	22D
0005433722285	7440	79	23A
0005433716549	7440	80	22F
0005433716527	7440	81	23D
0005433716528	7440	82	23B
0005433716545	7440	83	23E
0005433716542	7440	84	23F
0005435266197	29230	1	1C
0005432428968	29230	2	1F
0005433715949	29230	3	2A
0005433716185	29230	4	3A
0005433722227	29230	5	3D
0005433715940	29230	6	3C
0005433716192	29230	7	4B
0005433719152	29230	8	4E
0005433716080	29230	9	4D
0005433716062	29230	10	5C
0005433716127	29230	11	5F
0005433716131	29230	12	5E
0005433722228	29230	13	6A
0005433716171	29230	14	6D
0005433688815	29230	15	6E
0005433716126	29230	16	7D
0005432006793	29230	17	7E
0005433656658	29230	18	8A
0005433716194	29230	19	7F
0005433688804	29230	20	8B
0005433716193	29230	21	8D
0005433716039	29230	22	8C
0005433719147	29230	23	8E
0005432006794	29230	24	9A
0005435266196	29230	25	8F
0005433716172	29230	26	9B
0005433716256	29230	27	9C
0005433716040	29230	28	9E
0005433688814	29230	29	10E
0005433716132	29230	30	11A
0005432428966	29230	31	11B
0005433716023	29230	32	11D
0005433716163	29230	33	12A
0005435266199	29230	34	12C
0005433716074	29230	35	12D
0005435266198	29230	36	12F
0005433716158	29230	37	13A
0005433656657	29230	38	13C
0005433715997	29230	39	13D
0005433715936	29230	40	14B
0005433716057	29230	41	14D
0005433656663	29230	42	14E
0005433656679	29230	43	15A
0005433716302	29230	44	14F
0005435266200	29230	45	15B
0005433656682	29230	46	15C
0005433716183	29230	47	16A
0005433716122	29230	48	15F
0005433719148	29230	49	16B
0005432006797	29230	50	17A
0005433716058	29230	51	17B
0005433656678	29230	52	17D
0005433716152	29230	53	17C
0005433715998	29230	54	17E
0005432428967	29230	55	18A
0005433715941	29230	56	18B
0005432006796	29230	57	18C
0005433716237	29230	58	18E
0005433688813	29230	59	19C
0005433716022	29230	60	20A
0005433688816	29230	61	20C
0005433716149	29230	62	20B
0005433716221	29230	63	20E
0005432006795	29230	64	20F
0005433656683	29230	65	21B
0005433716301	29230	66	21C
0005433722225	29230	67	21F
0005433722229	29230	68	21E
0005433716125	29230	69	22A
0005433716073	29230	70	22C
0005433688808	29230	71	22E
0005433716068	29230	72	22F
0005433722199	29230	73	23D
0005433716199	29230	74	23C
0005433688809	29230	75	23E
0005434095435	8687	1	1C
0005434095440	8687	2	2A
0005434184664	8687	3	2D
0005434182233	8687	4	3A
0005434182257	8687	5	3D
0005434182242	8687	6	4D
0005434095431	8687	7	4E
0005434095436	8687	8	5A
0005434182243	8687	9	5D
0005434095437	8687	10	7A
0005434095439	8687	11	8D
0005434182237	8687	12	8E
0005434182209	8687	13	9A
0005434182193	8687	14	9C
0005434184672	8687	15	9D
0005434095432	8687	16	9F
0005434182199	8687	17	10D
0005434095433	8687	18	11E
0005434182271	8687	19	12C
0005434182208	8687	20	12D
0005434182270	8687	21	12E
0005434182238	8687	22	13F
0005434095430	8687	23	14D
0005434095442	8687	24	14E
0005434095444	8687	25	14F
0005434182206	8687	26	15D
0005434182258	8687	27	16D
0005434182262	8687	28	16F
0005434095443	8687	29	17A
0005434182261	8687	30	17D
0005434182213	8687	31	17F
0005434184671	8687	32	18C
0005434182205	8687	33	18F
0005434095438	8687	34	19C
0005434182244	8687	35	19D
0005434182241	8687	36	19F
0005434095434	8687	37	20C
0005434095429	8687	38	20E
0005434095441	8687	39	20F
0005434184687	11672	1	1A
0005434182318	11672	2	1D
0005434095346	11672	3	1F
0005434095343	11672	4	2D
0005434182328	11672	5	3C
0005434095317	11672	6	4C
0005434095276	11672	7	5A
0005434184685	11672	8	5C
0005434095347	11672	9	6A
0005434182321	11672	10	7A
0005434095316	11672	11	7E
0005434182326	11672	12	7F
0005434182323	11672	13	8D
0005434095362	11672	14	8F
0005434182329	11672	15	9D
0005434095342	11672	16	9E
0005434095312	11672	17	10A
0005434095353	11672	18	10D
0005434095300	11672	19	10F
0005434095313	11672	20	12C
0005434182327	11672	21	12E
0005434182325	11672	22	13C
0005434095277	11672	23	13D
0005434182322	11672	24	13E
0005434183601	11672	25	13F
0005434095352	11672	26	14D
0005434095304	11672	27	14E
0005434182320	11672	28	15A
0005434095361	11672	29	15E
0005434182330	11672	30	16C
0005434095311	11672	31	16D
0005434095314	11672	32	16F
0005434095272	11672	33	17A
0005434095305	11672	34	17C
0005434182319	11672	35	17D
0005434184686	11672	36	18A
0005434183600	11672	37	19D
0005434095351	11672	38	20C
0005434182324	11672	39	20F
0005433398232	1450	1	1A
0005433398262	1450	2	1C
0005433398257	1450	3	1D
0005433398161	1450	4	1F
0005432297306	1450	5	2A
0005433398152	1450	6	2C
0005433398019	1450	7	2F
0005433398132	1450	8	3F
0005433398220	1450	9	4A
0005433398081	1450	10	4C
0005433398013	1450	11	4F
0005433398064	1450	12	5A
0005433398250	1450	13	5C
0005435732483	1450	14	5D
0005435732489	1450	15	5E
0005435732490	1450	16	5F
0005433398117	1450	17	6D
0005433398113	1450	18	6E
0005433398186	1450	19	7A
0005433398170	1450	20	7C
0005433398063	1450	21	7D
0005433398160	1450	22	7E
0005435732488	1450	23	8A
0005433398221	1450	24	8C
0005435732492	1450	25	8D
0005433398258	1450	26	8E
0005433398321	1450	27	9A
0005433398306	1450	28	9C
0005433398018	1450	29	9D
0005432297307	1450	30	9F
0005433398025	1450	31	10A
0005433398208	1450	32	10C
0005433398200	1450	33	10D
0005433398154	1450	34	10E
0005433398036	1450	35	10F
0005433398342	1450	36	11A
0005433398045	1450	37	11D
0005433398105	1450	38	11E
0005433398296	1450	39	12A
0005433398181	1450	40	12C
0005433397793	1450	41	12D
0005433398231	1450	42	12E
0005433398261	1450	43	13C
0005433398189	1450	44	13E
0005433457014	1450	45	13F
0005433398176	1450	46	14A
0005435732485	1450	47	14C
0005435732487	1450	48	14D
0005433398292	1450	49	14F
0005433457016	1450	50	15A
0005433398047	1450	51	15E
0005433398133	1450	52	15F
0005433398098	1450	53	16A
0005433398011	1450	54	16C
0005433398229	1450	55	16E
0005433457017	1450	56	16F
0005433398108	1450	57	17A
0005433398088	1450	58	17C
0005435732491	1450	59	17E
0005435732482	1450	60	17F
0005435732486	1450	61	18C
0005433398185	1450	62	18D
0005435732484	1450	63	18E
0005433457015	1450	64	19A
0005433398319	1450	65	19C
0005433398240	1450	66	19E
0005433398046	1450	67	19F
0005433398228	1450	68	20A
0005433398171	1450	69	20C
0005433398320	1450	70	20D
0005433398153	1450	71	20E
0005433398162	1450	72	20F
0005433398593	19268	1	1D
0005433398621	19268	2	1F
0005433398600	19268	3	2A
0005433398573	19268	4	2C
0005433398575	19268	5	2D
0005432906562	19268	6	3A
0005433398571	19268	7	3C
0005433456996	19268	8	3D
0005433398588	19268	9	3F
0005433398597	19268	10	4A
0005432906564	19268	11	4D
0005435732419	19268	12	4E
0005433398604	19268	13	4F
0005433398613	19268	14	5C
0005435732344	19268	15	5D
0005433398577	19268	16	6A
0005435732439	19268	17	6C
0005433398601	19268	18	6D
0005432906563	19268	19	6F
0005435732371	19268	20	7A
0005433398602	19268	21	7C
0005433398619	19268	22	7D
0005433456995	19268	23	8A
0005435732338	19268	24	8C
0005433398616	19268	25	8D
0005433398589	19268	26	8E
0005433398608	19268	27	8F
0005433398579	19268	28	9C
0005435732403	19268	29	9E
0005433398583	19268	30	9F
0005433398618	19268	31	10A
0005433398598	19268	32	10C
0005433398599	19268	33	10D
0005433398592	19268	34	10E
0005433398584	19268	35	10F
0005433398611	19268	36	11A
0005433456977	19268	37	11C
0005433398590	19268	38	11F
0005433398609	19268	39	12A
0005433398572	19268	40	12C
0005433398576	19268	41	12D
0005433398574	19268	42	13A
0005433398610	19268	43	13D
0005435732385	19268	44	13E
0005433398612	19268	45	14C
0005433398596	19268	46	14D
0005433398615	19268	47	14F
0005433398606	19268	48	15A
0005433456974	19268	49	15D
0005433398585	19268	50	15E
0005433398595	19268	51	15F
0005433398594	19268	52	16C
0005433398603	19268	53	16E
0005433398586	19268	54	16F
0005433398607	19268	55	17A
0005435732337	19268	56	17C
0005433398582	19268	57	17D
0005435732317	19268	58	17F
0005433456975	19268	59	18A
0005433398580	19268	60	18D
0005433398578	19268	61	18E
0005433398620	19268	62	18F
0005435732372	19268	63	19A
0005433398605	19268	64	19C
0005433398587	19268	65	19D
0005433398581	19268	66	19E
0005433398617	19268	67	19F
0005433398614	19268	68	20C
0005433456969	19268	69	20D
0005433398591	19268	70	20E
0005434443645	17368	1	3B
0005434443755	17368	2	3C
0005434443745	17368	3	5B
0005434443741	17368	4	5D
0005434443749	17368	5	6A
0005434443706	17368	6	7A
0005434443742	17368	7	7B
0005434443731	17368	8	7C
0005434443744	17368	9	18C
0005434443781	17368	10	18D
0005434443743	17368	11	19C
0005434443719	17368	12	21C
0005434443663	17368	13	22B
0005434443707	17368	14	22C
0005434443886	20561	1	1A
0005434443877	20561	2	1C
0005434443879	20561	3	3B
0005434443884	20561	4	3C
0005434443883	20561	5	4D
0005434443881	20561	6	5B
0005434443876	20561	7	7A
0005434443882	20561	8	7C
0005434443885	20561	9	19A
0005434443875	20561	10	19C
0005434443873	20561	11	19D
0005434443870	20561	12	20B
0005434443880	20561	13	20C
0005434443878	20561	14	21B
0005434443872	20561	15	22B
0005434443874	20561	16	22C
0005434443871	20561	17	22D
0005434954651	7260	1	1B
0005435377591	7260	2	3B
0005434954654	7260	3	4A
0005434954652	7260	4	4B
0005434954653	7260	5	5A
0005435377577	7260	6	5B
0005435377589	7260	7	6B
0005434954611	28356	1	2B
0005434954610	28356	2	3A
0005435377605	28356	3	3B
0005434954627	28356	4	5A
0005435377606	28356	5	4B
0005434954628	28356	6	5B
0005435377607	28356	7	6A
0005434351833	4459	1	1B
0005434351840	4459	2	1D
0005434351836	4459	3	1C
0005434351842	4459	4	3C
0005434351839	4459	5	4A
0005434351831	4459	6	5C
0005435893639	4459	7	6A
0005435893654	4459	8	6C
0005434351841	4459	9	6D
0005434351838	4459	10	7A
0005435893655	4459	11	7B
0005434351834	4459	12	18A
0005434351843	4459	13	18B
0005435893673	4459	14	18C
0005434351832	4459	15	18D
0005434351835	4459	16	19A
0005435893662	4459	17	19B
0005435893650	4459	18	19C
0005434351837	4459	19	20A
0005435893649	4459	20	21D
0005434183587	4459	21	22B
0005435893667	4459	22	22C
0005434351769	29638	1	1B
0005435893713	29638	2	2A
0005434351701	29638	3	2B
0005434351680	29638	4	2C
0005434351712	29638	5	4B
0005435893708	29638	6	4C
0005435893707	29638	7	5B
0005434351804	29638	8	5C
0005435893710	29638	9	6A
0005434351683	29638	10	6B
0005435893711	29638	11	6D
0005434351789	29638	12	7A
0005434351684	29638	13	7B
0005434351659	29638	14	18B
0005434351713	29638	15	18D
0005435893709	29638	16	19B
0005434351700	29638	17	20A
0005434351727	29638	18	21A
0005435893712	29638	19	22A
0005434351711	29638	20	22D
0005433269736	1040	1	1B
0005435545829	1040	2	1G
0005432293237	1040	3	2A
0005435545837	1040	4	2F
0005433343465	1040	5	2G
0005433343241	1040	6	2H
0005433343635	1040	7	3B
0005433343111	1040	8	3F
0005433342726	1040	9	3C
0005433343583	1040	10	3G
0005432293236	1040	11	4A
0005433343240	1040	12	4C
0005433343320	1040	13	4G
0005433342940	1040	14	4H
0005433343224	1040	15	5B
0005433342710	1040	16	5F
0005434446543	1040	17	5G
0005434445270	1040	18	9G
0005434446541	1040	19	11A
0005435545833	1040	20	9H
0005433343463	1040	21	11E
0005435092185	1040	22	11F
0005433343262	1040	23	11G
0005433343225	1040	24	12A
0005433343361	1040	25	12B
0005433343603	1040	26	12E
0005433343417	1040	27	12D
0005435092180	1040	28	12G
0005435545841	1040	29	12F
0005433343430	1040	30	12H
0005434445269	1040	31	13D
0005433342911	1040	32	13G
0005433343065	1040	33	13F
0005433343322	1040	34	14A
0005433463925	1040	35	13H
0005435092183	1040	36	14E
0005433343114	1040	37	14H
0005433343197	1040	38	14G
0005433463924	1040	39	14F
0005433343500	1040	40	15B
0005433343215	1040	41	15E
0005433462771	1040	42	15G
0005434446540	1040	43	16A
0005433343464	1040	44	15H
0005433343182	1040	45	16B
0005433343133	1040	46	16F
0005433342958	1040	47	16H
0005434446542	1040	48	17A
0005433343504	1040	49	17E
0005433269714	1040	50	17G
0005435545830	1040	51	17H
0005433343248	1040	52	19B
0005433343222	1040	53	19F
0005433343068	1040	54	19G
0005433343508	1040	55	20A
0005433343289	1040	56	19H
0005435092182	1040	57	20E
0005435545839	1040	58	20D
0005433343418	1040	59	20F
0005433343144	1040	60	20G
0005433343648	1040	61	21A
0005433342640	1040	62	21B
0005433342926	1040	63	21E
0005435545831	1040	64	21D
0005435545832	1040	65	21G
0005433343683	1040	66	21F
0005433269713	1040	67	22A
0005433343281	1040	68	22B
0005433343244	1040	69	22F
0005433342639	1040	70	22E
0005433343637	1040	71	23B
0005433343290	1040	72	23E
0005433343220	1040	73	23H
0005433342709	1040	74	23G
0005433343260	1040	75	24A
0005433343383	1040	76	24E
0005433343280	1040	77	24F
0005433343609	1040	78	24G
0005433343505	1040	79	24H
0005433343407	1040	80	25E
0005433343156	1040	81	25D
0005433343177	1040	82	27E
0005433343377	1040	83	27D
0005433343408	1040	84	27F
0005433159317	1040	85	27G
0005433342725	1040	86	28A
0005433159318	1040	87	28D
0005433343204	1040	88	28F
0005433343579	1040	89	28H
0005433343135	1040	90	29D
0005435545842	1040	91	29G
0005433343314	1040	92	29F
0005433343315	1040	93	29H
0005435092181	1040	94	30D
0005435545840	1040	95	30F
0005433343271	1040	96	30G
0005435545835	1040	97	31F
0005433343416	1040	98	31E
0005433342939	1040	99	31G
0005433343596	1040	100	32A
0005435092189	1040	101	31H
0005435545834	1040	102	32B
0005433343362	1040	103	32D
0005433343636	1040	104	32E
0005433343217	1040	105	33A
0005433343811	1040	106	32H
0005433343249	1040	107	33B
0005433343219	1040	108	33E
0005435092184	1040	109	33D
0005433343585	1040	110	33G
0005435545836	1040	111	34A
0005433343411	1040	112	34D
0005435092188	1040	113	34B
0005435092187	1040	114	34H
0005435545843	1040	115	35B
0005435545838	1040	116	35A
0005433343376	1040	117	35D
0005433343506	1040	118	35F
0005433342943	1040	119	35E
0005433343412	1040	120	35G
0005433343569	1040	121	36A
0005433343302	1040	122	36B
0005433342711	1040	123	37D
0005433343410	1040	124	37F
0005433343700	1040	125	37E
0005433343321	1040	126	37G
0005433269745	1040	127	38B
0005433343582	1040	128	38E
0005433343561	1040	129	38D
0005435092186	1040	130	38H
0005433343363	1040	131	38G
0005433343134	1040	132	39F
0005433344153	17037	1	1C
0005433344167	17037	2	1F
0005435508352	17037	3	1H
0005433344189	17037	4	1G
0005433344225	17037	5	2A
0005433344172	17037	6	2B
0005434445251	17037	7	2F
0005433344127	17037	8	2C
0005433269780	17037	9	4A
0005433344183	17037	10	3H
0005435092146	17037	11	4B
0005435508354	17037	12	4F
0005433344149	17037	13	4C
0005433344223	17037	14	5B
0005435508374	17037	15	5F
0005433344168	17037	16	5C
0005434445240	17037	17	5G
0005433344134	17037	18	9B
0005435092122	17037	19	9A
0005433344186	17037	20	11A
0005435092116	17037	21	11D
0005433344191	17037	22	11F
0005433344221	17037	23	11H
0005433344132	17037	24	12E
0005435092123	17037	25	12D
0005435092145	17037	26	12G
0005433344182	17037	27	13A
0005435508353	17037	28	13D
0005433344194	17037	29	13F
0005433344215	17037	30	13E
0005433344126	17037	31	13G
0005433344224	17037	32	14A
0005433344155	17037	33	13H
0005433344169	17037	34	14B
0005433344150	17037	35	14D
0005433344220	17037	36	14F
0005433344151	17037	37	15B
0005433344214	17037	38	15A
0005435508323	17037	39	15E
0005433344227	17037	40	15D
0005433344176	17037	41	15F
0005433344143	17037	42	15G
0005433344157	17037	43	15H
0005433344185	17037	44	16D
0005433344188	17037	45	16E
0005433344206	17037	46	16G
0005433344165	17037	47	16H
0005433344200	17037	48	17B
0005433344178	17037	49	17A
0005435092040	17037	50	17F
0005435092137	17037	51	18A
0005433344129	17037	52	18D
0005433344135	17037	53	18B
0005433344144	17037	54	19B
0005433344222	17037	55	19A
0005433344192	17037	56	19E
0005433344131	17037	57	19D
0005435508385	17037	58	19G
0005433344138	17037	59	19F
0005433344208	17037	60	20B
0005433344197	17037	61	20D
0005433344210	17037	62	20F
0005433344139	17037	63	20H
0005433344152	17037	64	20G
0005433344154	17037	65	21A
0005433344184	17037	66	21B
0005435092091	17037	67	21E
0005433344166	17037	68	21D
0005433344177	17037	69	21F
0005433344202	17037	70	21H
0005435092028	17037	71	21G
0005433344216	17037	72	22A
0005435508389	17037	73	22D
0005433344173	17037	74	22B
0005433344217	17037	75	22E
0005435092134	17037	76	22G
0005435092098	17037	77	23B
0005433344158	17037	78	23A
0005435508398	17037	79	24A
0005433269776	17037	80	23H
0005433344193	17037	81	24B
0005433344228	17037	82	24D
0005433344140	17037	83	24F
0005433344133	17037	84	24G
0005433344207	17037	85	24H
0005433344136	17037	86	25F
0005435092041	17037	87	25E
0005433344161	17037	88	27A
0005433344128	17037	89	27E
0005433344156	17037	90	27D
0005433344141	17037	91	27F
0005433344145	17037	92	27H
0005433269778	17037	93	27G
0005433344226	17037	94	28B
0005433344137	17037	95	28E
0005435508349	17037	96	28H
0005433344195	17037	97	28G
0005433344163	17037	98	29B
0005433344164	17037	99	29D
0005433344148	17037	100	29F
0005434445258	17037	101	30D
0005433344198	17037	102	30G
0005433344187	17037	103	31A
0005433344212	17037	104	30H
0005433344196	17037	105	31D
0005435508381	17037	106	31F
0005433344201	17037	107	31E
0005433344199	17037	108	31G
0005433344211	17037	109	31H
0005433344174	17037	110	32B
0005433344179	17037	111	32E
0005433344160	17037	112	32F
0005433344218	17037	113	33A
0005433269777	17037	114	33B
0005433344181	17037	115	33E
0005433344162	17037	116	33D
0005433344146	17037	117	33H
0005433344170	17037	118	34A
0005433344159	17037	119	34D
0005433344209	17037	120	35E
0005433344219	17037	121	35G
0005433344203	17037	122	36B
0005433159337	17037	123	36G
0005433344171	17037	124	37A
0005433344130	17037	125	36H
0005435508391	17037	126	37D
0005433344175	17037	127	37B
0005433344213	17037	128	37E
0005433344142	17037	129	37G
0005433344204	17037	130	38A
0005433269779	17037	131	37H
0005433344147	17037	132	38E
0005433344205	17037	133	38G
0005433344180	17037	134	39D
0005435508370	17037	135	39F
0005433344190	17037	136	39E
0005432851973	18262	1	1D
0005432391996	18262	2	2C
0005432851983	18262	3	2D
0005432390107	18262	4	2F
0005432851986	18262	5	3C
0005432391992	18262	6	4A
0005432390161	18262	7	3F
0005432390140	18262	8	4F
0005432851980	18262	9	5C
0005432851974	18262	10	5F
0005432390187	18262	11	5D
0005432390083	18262	12	6A
0005432851991	18262	13	6C
0005432851981	18262	14	6E
0005432390206	18262	15	6D
0005432390142	18262	16	7B
0005432390182	18262	17	7A
0005432390124	18262	18	7C
0005432851977	18262	19	7E
0005432851975	18262	20	7D
0005432390103	18262	21	8A
0005432851985	18262	22	7F
0005432390116	18262	23	8B
0005432390181	18262	24	8E
0005432390141	18262	25	8C
0005432851989	18262	26	8F
0005432851972	18262	27	9A
0005432390065	18262	28	9D
0005432851979	18262	29	9C
0005432851988	18262	30	9B
0005432390127	18262	31	10A
0005432851984	18262	32	9F
0005432390126	18262	33	10B
0005432390157	18262	34	10D
0005432851971	18262	35	11A
0005432390162	18262	36	11C
0005432390168	18262	37	11B
0005432390151	18262	38	11F
0005432390149	18262	39	11E
0005432390179	18262	40	12A
0005432390152	18262	41	12C
0005432390146	18262	42	12E
0005432390123	18262	43	13B
0005432390102	18262	44	13A
0005432390174	18262	45	13C
0005432851976	18262	46	13D
0005432851992	18262	47	14A
0005432390125	18262	48	14B
0005432390148	18262	49	14D
0005432851982	18262	50	14F
0005432851990	18262	51	14E
0005432390169	18262	52	15B
0005432390135	18262	53	15A
0005432392000	18262	54	15D
0005432390164	18262	55	15C
0005432390147	18262	56	16A
0005432390101	18262	57	16B
0005432391999	18262	58	16D
0005432392011	18262	59	16C
0005432390104	18262	60	16F
0005432390159	18262	61	16E
0005432390160	18262	62	17B
0005432390156	18262	63	17A
0005432390153	18262	64	17F
0005432391998	18262	65	17E
0005432390115	18262	66	18A
0005432851987	18262	67	18C
0005432391995	18262	68	18B
0005432851978	18262	69	18F
0005432390184	18262	70	19F
0005432390158	18262	71	20B
0005432390167	18262	72	20A
0005432390108	18262	73	20D
0005432390178	18262	74	21A
0005432390129	18262	75	21D
0005432851970	18262	76	21C
0005432390145	18262	77	21B
0005432851969	18262	78	21E
0005434026711	12800	1	1A
0005434067527	12800	2	1C
0005434067769	12800	3	1D
0005434067906	12800	4	1F
0005434067554	12800	5	2C
0005434067700	12800	6	2A
0005434067637	12800	7	2D
0005434081927	12800	8	2F
0005434067684	12800	9	3D
0005434081960	12800	10	3C
0005434081941	12800	11	3F
0005434067942	12800	12	4A
0005434067726	12800	13	4B
0005434081938	12800	14	4D
0005434068029	12800	15	4C
0005434026705	12800	16	4E
0005434067805	12800	17	5A
0005434067271	12800	18	4F
0005434067464	12800	19	5C
0005433812926	12800	20	5D
0005434081964	12800	21	5E
0005434067770	12800	22	5F
0005434067812	12800	23	6B
0005434026712	12800	24	6A
0005434067528	12800	25	6C
0005432161178	12800	26	6D
0005434067745	12800	27	6E
0005434067565	12800	28	6F
0005434067877	12800	29	7B
0005432433737	12800	30	7A
0005432159907	12800	31	7C
0005434081978	12800	32	7E
0005434067605	12800	33	7D
0005434081982	12800	34	7F
0005432433741	12800	35	8A
0005434026704	12800	36	8B
0005434081853	12800	37	8E
0005434082080	12800	38	8D
0005434067626	12800	39	8F
0005434067842	12800	40	9A
0005434081967	12800	41	9B
0005434067634	12800	42	9C
0005434082014	12800	43	9E
0005434067609	12800	44	9D
0005434067776	12800	45	9F
0005434067840	12800	46	10B
0005434067611	12800	47	10C
0005434067638	12800	48	10E
0005434067876	12800	49	10D
0005434082028	12800	50	11A
0005434082081	12800	51	11B
0005434081885	12800	52	11C
0005434067564	12800	53	11D
0005433812927	12800	54	11F
0005434067539	12800	55	11E
0005434067546	12800	56	12B
0005434067774	12800	57	12A
0005434026706	12800	58	12D
0005434081890	12800	59	12C
0005434067725	12800	60	12E
0005434067921	12800	61	12F
0005434067532	12800	62	13B
0005434067872	12800	63	13A
0005434081952	12800	64	13D
0005434067530	12800	65	13C
0005434067396	12800	66	13E
0005434082029	12800	67	14A
0005434081880	12800	68	13F
0005434067746	12800	69	14B
0005434067604	12800	70	14C
0005434067575	12800	71	14D
0005434067293	12800	72	14E
0005432433739	12800	73	15A
0005434067885	12800	74	14F
0005434067552	12800	75	15C
0005434067698	12800	76	15B
0005434067795	12800	77	15D
0005434067724	12800	78	15E
0005433989780	12800	79	16A
0005434067779	12800	80	15F
0005432433738	12800	81	16B
0005432433740	12800	82	16C
0005432159908	12800	83	16D
0005434067483	12800	84	16F
0005434067701	12800	85	16E
0005434067526	12800	86	17B
0005432159909	12800	87	17A
0005434067888	12800	88	17D
0005434067739	12800	89	17C
0005434067737	12800	90	17E
0005434067456	12800	91	18A
0005434067850	12800	92	18B
0005434067270	12800	93	18D
0005434067535	12800	94	18C
0005434081889	12800	95	18F
0005434081928	12800	96	18E
0005432161177	12800	97	19A
0005434067533	12800	98	19C
0005434081974	12800	99	19D
0005434067907	12800	100	19E
0005434081953	12800	101	19F
0005434081966	12800	102	20A
0005434067610	12800	103	20B
0005434081931	12800	104	20C
0005432159911	12800	105	20E
0005434082013	12800	106	20D
0005432159910	12800	107	21A
0005434067697	12800	108	20F
0005434067775	12800	109	21B
0005434081957	12800	110	21C
0005434067635	12800	111	21D
0005434081924	12800	112	21E
0005434081884	12800	113	21F
0005434081852	12800	114	22B
0005434067819	12800	115	22E
0005434081963	12800	116	22F
0005434067806	12800	117	23B
0005434067829	12800	118	23C
0005434067551	12800	119	23D
0005434067414	12800	120	23E
0005434067820	12800	121	23F
0005434068291	30678	1	1A
0005434068260	30678	2	1C
0005432150277	30678	3	1D
0005434068305	30678	4	2C
0005434082143	30678	5	2A
0005432186905	30678	6	2F
0005432150273	30678	7	3C
0005434068258	30678	8	3F
0005434082153	30678	9	3D
0005434068315	30678	10	4B
0005434082146	30678	11	4C
0005432150279	30678	12	4E
0005434068276	30678	13	4D
0005432186909	30678	14	4F
0005434082156	30678	15	5C
0005432433695	30678	16	5B
0005432186907	30678	17	5D
0005433989818	30678	18	5F
0005433989817	30678	19	5E
0005434082144	30678	20	6A
0005434068279	30678	21	6B
0005434068285	30678	22	6C
0005434068295	30678	23	6E
0005434082157	30678	24	6D
0005434068308	30678	25	6F
0005434068316	30678	26	7B
0005434068306	30678	27	7C
0005434068303	30678	28	7E
0005434068326	30678	29	7D
0005434068275	30678	30	7F
0005434068262	30678	31	8B
0005434082148	30678	32	8A
0005434068287	30678	33	8D
0005434068290	30678	34	8C
0005434068307	30678	35	8E
0005434068288	30678	36	8F
0005433989821	30678	37	9B
0005434068264	30678	38	9A
0005434082141	30678	39	9C
0005434068297	30678	40	9E
0005434082138	30678	41	9D
0005434082151	30678	42	9F
0005432150271	30678	43	10C
0005434068268	30678	44	10B
0005434082147	30678	45	10D
0005432186908	30678	46	10E
0005434068263	30678	47	11A
0005434068266	30678	48	11B
0005433989819	30678	49	11C
0005432433698	30678	50	11E
0005434082150	30678	51	11D
0005434068322	30678	52	11F
0005434068283	30678	53	12B
0005434082142	30678	54	12D
0005434082140	30678	55	12C
0005434068289	30678	56	12E
0005432433718	30678	57	12F
0005434068259	30678	58	13A
0005434082137	30678	59	13B
0005432433688	30678	60	13D
0005434068309	30678	61	13C
0005433989822	30678	62	13E
0005434068312	30678	63	13F
0005434068269	30678	64	14A
0005434068293	30678	65	14C
0005434068320	30678	66	14B
0005434068292	30678	67	14D
0005434068256	30678	68	14F
0005434068310	30678	69	14E
0005434082155	30678	70	15B
0005434068284	30678	71	15A
0005434068257	30678	72	15C
0005434068299	30678	73	15D
0005434068265	30678	74	15E
0005434068273	30678	75	16A
0005434068281	30678	76	15F
0005434068298	30678	77	16B
0005434068324	30678	78	16C
0005432150276	30678	79	16D
0005432433717	30678	80	16F
0005434068286	30678	81	16E
0005434082139	30678	82	17A
0005434082149	30678	83	17B
0005434068261	30678	84	17D
0005432150274	30678	85	17C
0005432150275	30678	86	17F
0005434068282	30678	87	17E
0005434068317	30678	88	18A
0005434068271	30678	89	18B
0005434068313	30678	90	18D
0005434068302	30678	91	18F
0005434068311	30678	92	18E
0005434068327	30678	93	19A
0005434068314	30678	94	19C
0005432433681	30678	95	19B
0005432433713	30678	96	19E
0005434068301	30678	97	19D
0005434068267	30678	98	19F
0005432150278	30678	99	20A
0005434082152	30678	100	20B
0005434068296	30678	101	20D
0005434068300	30678	102	20C
0005434068325	30678	103	20E
0005434068321	30678	104	20F
0005434068270	30678	105	21A
0005434068323	30678	106	21C
0005434068274	30678	107	21B
0005434068277	30678	108	21D
0005434082145	30678	109	21E
0005432150272	30678	110	21F
0005434068318	30678	111	22B
0005433989820	30678	112	22A
0005432186906	30678	113	22C
0005434068278	30678	114	22D
0005434068304	30678	115	22E
0005434068294	30678	116	23A
0005434068272	30678	117	22F
0005434068319	30678	118	23B
0005434068280	30678	119	23C
0005434082154	30678	120	23D
0005432433699	30678	121	23E
0005433686642	19357	1	1D
0005433686640	19357	2	2A
0005433689907	19357	3	2B
0005433686620	19357	4	2D
0005433689917	19357	5	3A
0005433686639	19357	6	3D
0005433689901	19357	7	4A
0005433689912	19357	8	4B
0005433686641	19357	9	5A
0005433686631	19357	10	5B
0005433686623	19357	11	5D
0005433689915	19357	12	6C
0005433689918	19357	13	7D
0005433686624	19357	14	18A
0005433689911	19357	15	18C
0005433689906	19357	16	18D
0005433686619	19357	17	19A
0005433689908	19357	18	19B
0005433689916	19357	19	19C
0005433689913	19357	20	20A
0005433689924	19357	21	20B
0005433686632	19357	22	21B
0005433689914	19357	23	21D
0005435462603	5488	1	1A
0005435462569	5488	2	1B
0005435766928	5488	3	1C
0005435462476	5488	4	1H
0005435766883	5488	5	1G
0005435766934	5488	6	2A
0005435735187	5488	7	2B
0005435766915	5488	8	2F
0005435723069	5488	9	2C
0005434265164	5488	10	3C
0005434831171	5488	11	3B
0005435462415	5488	12	4B
0005434831140	5488	13	4G
0005435462530	5488	14	5B
0005435766896	5488	15	5A
0005432140538	5488	16	5F
0005435766877	5488	17	5C
0005435766911	5488	18	5G
0005434831143	5488	19	9A
0005435722080	5488	20	5H
0005435462500	5488	21	9B
0005435766925	5488	22	9G
0005435735183	5488	23	11A
0005432140537	5488	24	9H
0005435462412	5488	25	11B
0005435766899	5488	26	11E
0005435462681	5488	27	11D
0005435766913	5488	28	11G
0005435462702	5488	29	12A
0005435462660	5488	30	12D
0005435462520	5488	31	12B
0005434265135	5488	32	12E
0005434265181	5488	33	12F
0005435462701	5488	34	12H
0005435766936	5488	35	12G
0005434831134	5488	36	13A
0005432535845	5488	37	13D
0005435766906	5488	38	13B
0005434265192	5488	39	13F
0005435735188	5488	40	13E
0005433529320	5488	41	13G
0005432535844	5488	42	14A
0005435766901	5488	43	13H
0005435766904	5488	44	14B
0005435766902	5488	45	14E
0005435766927	5488	46	14D
0005435766893	5488	47	14F
0005435766880	5488	48	14H
0005435462501	5488	49	15B
0005435766918	5488	50	15A
0005435766894	5488	51	15E
0005435766878	5488	52	15F
0005435462565	5488	53	15H
0005434265058	5488	54	16E
0005435462488	5488	55	16F
0005435766888	5488	56	16H
0005434265170	5488	57	16G
0005432535843	5488	58	17B
0005435766914	5488	59	17A
0005435766912	5488	60	17D
0005435723068	5488	61	17F
0005434831144	5488	62	17E
0005434831157	5488	63	17G
0005432140540	5488	64	17H
0005435766875	5488	65	18B
0005435766926	5488	66	18E
0005435462604	5488	67	18G
0005434831163	5488	68	18F
0005435766882	5488	69	19A
0005435617170	5488	70	18H
0005435735186	5488	71	19B
0005435766881	5488	72	19E
0005435766940	5488	73	19D
0005435462703	5488	74	19F
0005435462521	5488	75	19G
0005435766884	5488	76	20A
0005435766916	5488	77	19H
0005434265193	5488	78	20D
0005434265144	5488	79	20E
0005434831135	5488	80	20F
0005435462583	5488	81	20G
0005435766886	5488	82	21B
0005435722082	5488	83	21A
0005435766917	5488	84	20H
0005434265136	5488	85	21E
0005435766903	5488	86	21G
0005434265165	5488	87	21F
0005434265260	5488	88	21H
0005435766879	5488	89	22A
0005435462518	5488	90	22D
0005435462421	5488	91	22B
0005435723066	5488	92	22E
0005435766900	5488	93	22G
0005435766890	5488	94	22F
0005435766942	5488	95	23A
0005432535839	5488	96	22H
0005435725650	5488	97	23B
0005435766905	5488	98	23E
0005435462453	5488	99	23G
0005435766923	5488	100	23F
0005435766887	5488	101	23H
0005435462505	5488	102	24B
0005433529319	5488	103	24E
0005435462564	5488	104	24D
0005433527311	5488	105	24F
0005434831166	5488	106	25D
0005435766937	5488	107	25F
0005432140541	5488	108	25E
0005435725651	5488	109	27B
0005435766891	5488	110	27E
0005435462519	5488	111	27D
0005435462411	5488	112	27F
0005435462633	5488	113	27G
0005435766889	5488	114	28A
0005435725652	5488	115	28D
0005435462531	5488	116	28B
0005433529322	5488	117	28E
0005435766919	5488	118	28G
0005435766876	5488	119	28H
0005432140535	5488	120	29D
0005434831177	5488	121	29E
0005435766935	5488	122	29G
0005434265069	5488	123	29F
0005434831142	5488	124	29H
0005434265043	5488	125	30A
0005435766897	5488	126	30D
0005435462347	5488	127	30B
0005435766924	5488	128	30G
0005435766922	5488	129	30F
0005435735184	5488	130	30H
0005435462484	5488	131	31D
0005435462582	5488	132	31F
0005435766932	5488	133	31H
0005434265259	5488	134	31G
0005433527310	5488	135	32A
0005432140536	5488	136	32B
0005432535855	5488	137	32E
0005435766941	5488	138	32F
0005435720836	5488	139	32H
0005432140542	5488	140	33D
0005435766895	5488	141	33B
0005435725654	5488	142	33E
0005434265129	5488	143	33F
0005435735185	5488	144	33H
0005435766938	5488	145	33G
0005435617169	5488	146	34A
0005433529321	5488	147	34D
0005435766907	5488	148	34B
0005435766910	5488	149	34F
0005435462532	5488	150	34E
0005435766908	5488	151	34G
0005432140539	5488	152	34H
0005435766931	5488	153	35A
0005435766929	5488	154	35E
0005435462516	5488	155	35D
0005435462534	5488	156	35B
0005435766898	5488	157	35G
0005435720835	5488	158	35H
0005432535840	5488	159	36A
0005434265213	5488	160	36E
0005434265044	5488	161	36D
0005435462605	5488	162	36H
0005435766920	5488	163	37A
0005435462528	5488	164	37B
0005434831156	5488	165	37D
0005435722081	5488	166	37G
0005435766930	5488	167	37F
0005432535857	5488	168	37E
0005434831139	5488	169	38A
0005435723067	5488	170	37H
0005435766933	5488	171	38D
0005435766909	5488	172	38B
0005435766892	5488	173	38E
0005435766939	5488	174	38F
0005435766921	5488	175	38H
0005435462477	5488	176	38G
0005435725653	5488	177	39E
0005432535856	5488	178	39D
0005435766885	5488	179	39F
0005435462852	13444	1	1A
0005435766269	13444	2	1F
0005435462873	13444	3	1G
0005435766183	13444	4	2A
0005435735150	13444	5	1H
0005435462866	13444	6	2C
0005435766468	13444	7	2B
0005435766281	13444	8	2F
0005435766216	13444	9	2G
0005435766423	13444	10	3B
0005435462847	13444	11	3F
0005435766606	13444	12	3H
0005435462856	13444	13	3G
0005435766425	13444	14	4B
0005435462871	13444	15	4C
0005435462859	13444	16	4F
0005435766598	13444	17	4H
0005435722055	13444	18	5F
0005435725608	13444	19	5C
0005435462857	13444	20	5H
0005435766512	13444	21	9B
0005435766550	13444	22	9A
0005435766402	13444	23	9G
0005435462865	13444	24	11A
0005435766285	13444	25	9H
0005435766532	13444	26	11B
0005435735140	13444	27	11D
0005435735148	13444	28	11F
0005435766224	13444	29	11G
0005435723053	13444	30	12A
0005434265418	13444	31	12B
0005435462851	13444	32	12F
0005435766548	13444	33	12H
0005435766266	13444	34	13B
0005435722064	13444	35	13A
0005435766348	13444	36	13E
0005434831203	13444	37	13D
0005435766338	13444	38	13F
0005435766403	13444	39	13H
0005435766346	13444	40	14B
0005435462876	13444	41	14D
0005435725615	13444	42	14F
0005435766300	13444	43	14E
0005435766336	13444	44	14G
0005434265434	13444	45	14H
0005434265426	13444	46	15D
0005435766436	13444	47	15B
0005432535889	13444	48	15E
0005434265431	13444	49	15G
0005435766347	13444	50	15F
0005435462855	13444	51	16B
0005434265437	13444	52	15H
0005435766437	13444	53	16E
0005435766206	13444	54	16F
0005435462864	13444	55	16H
0005435462870	13444	56	17B
0005435766270	13444	57	17D
0005432194558	13444	58	17E
0005435766301	13444	59	17G
0005435766014	13444	60	17F
0005435735152	13444	61	18B
0005435462842	13444	62	18A
0005434265432	13444	63	18F
0005432194555	13444	64	18E
0005435723037	13444	65	18G
0005434265417	13444	66	19A
0005435766428	13444	67	18H
0005435766589	13444	68	19F
0005435462867	13444	69	19E
0005434265428	13444	70	19H
0005434265430	13444	71	19G
0005432535888	13444	72	20D
0005435462839	13444	73	20B
0005435766225	13444	74	20F
0005435735137	13444	75	20G
0005435766226	13444	76	21B
0005435766344	13444	77	21A
0005432194559	13444	78	20H
0005435462868	13444	79	21D
0005435766351	13444	80	21E
0005435462846	13444	81	21F
0005435462840	13444	82	21H
0005434265424	13444	83	21G
0005435735149	13444	84	22D
0005434265419	13444	85	22B
0005434265421	13444	86	22F
0005434265425	13444	87	23A
0005434831206	13444	88	22H
0005435766392	13444	89	23F
0005435766342	13444	90	23G
0005434831204	13444	91	23H
0005435462861	13444	92	24B
0005435766409	13444	93	24D
0005435766248	13444	94	24F
0005432194556	13444	95	24E
0005435462862	13444	96	24G
0005435462844	13444	97	25D
0005435766317	13444	98	24H
0005435766353	13444	99	25E
0005435462860	13444	100	27A
0005435766349	13444	101	27B
0005435462843	13444	102	27E
0005435462874	13444	103	27D
0005435462853	13444	104	27F
0005434265427	13444	105	27G
0005432194560	13444	106	28B
0005432535890	13444	107	28E
0005435735139	13444	108	28F
0005435462849	13444	109	28H
0005435766412	13444	110	29A
0005435766212	13444	111	29B
0005435723038	13444	112	29E
0005435766451	13444	113	29F
0005435462869	13444	114	29H
0005435766240	13444	115	29G
0005435766227	13444	116	30B
0005435766211	13444	117	30A
0005434265420	13444	118	30E
0005435766215	13444	119	30D
0005435462848	13444	120	30H
0005435766334	13444	121	31D
0005435766164	13444	122	31F
0005435462838	13444	123	31E
0005435766408	13444	124	32A
0005435766241	13444	125	32B
0005435766239	13444	126	32E
0005435766284	13444	127	32D
0005434265422	13444	128	32F
0005435462872	13444	129	32H
0005435766265	13444	130	32G
0005434265416	13444	131	33A
0005432194557	13444	132	33B
0005435766116	13444	133	33E
0005435766569	13444	134	33G
0005435765897	13444	135	33H
0005434265440	13444	136	34B
0005434265429	13444	137	34A
0005432535887	13444	138	34D
0005435766417	13444	139	34G
0005434265436	13444	140	34F
0005435462845	13444	141	34H
0005434265435	13444	142	35D
0005435766259	13444	143	35F
0005435462850	13444	144	35G
0005434265438	13444	145	36A
0005435766570	13444	146	35H
0005435766605	13444	147	36D
0005435766350	13444	148	36F
0005435766107	13444	149	36E
0005434831205	13444	150	36G
0005434265439	13444	151	37A
0005435462863	13444	152	36H
0005435725607	13444	153	37B
0005435462858	13444	154	37E
0005434265423	13444	155	37D
0005435766205	13444	156	37F
0005435766426	13444	157	37G
0005435766411	13444	158	38B
0005435766213	13444	159	38A
0005435766339	13444	160	37H
0005435462841	13444	161	38D
0005434265433	13444	162	38E
0005435462854	13444	163	38G
0005434265441	13444	164	38F
0005435766293	13444	165	38H
0005435766292	13444	166	39E
0005435462875	13444	167	39D
0005435766551	13444	168	39F
0005434602896	18708	1	3B
0005434602910	18708	2	5A
0005434514994	18716	1	1A
0005434513606	18716	2	2A
0005434604907	18716	3	3A
0005434604906	18716	4	3B
0005434514995	18716	5	4A
0005434513607	18716	6	4B
0005434604892	18716	7	5A
0005434604908	18716	8	5B
0005434513608	18716	9	6A
0005434602925	19141	1	1B
0005434602923	19141	2	2A
0005434602924	19141	3	3A
0005434602926	19141	4	2B
0005434602928	19141	5	3B
0005434602927	19141	6	4A
0005434514975	19141	7	5A
0005434514984	19141	8	6B
0005435846291	25094	1	1A
0005435846292	25094	2	1C
0005432632753	25094	3	2A
0005432632717	25094	4	2C
0005432632751	25094	5	2D
0005432632736	25094	6	2F
0005435846294	25094	7	3A
0005435844351	25094	8	3C
0005435844356	25094	9	3D
0005435846293	25094	10	4C
0005432632749	25094	11	4F
0005432632720	25094	12	5C
0005432649416	25094	13	6C
0005435844359	25094	14	6D
0005435846288	25094	15	6E
0005432632713	25094	16	7A
0005432649411	25094	17	7C
0005435844355	25094	18	7D
0005432632737	25094	19	7E
0005432632752	25094	20	7F
0005432649397	25094	21	8A
0005432649398	25094	22	8C
0005432632726	25094	23	9A
0005432632738	25094	24	9C
0005432649433	25094	25	9D
0005432632727	25094	26	9E
0005432649399	25094	27	10A
0005435846295	25094	28	10C
0005435844354	25094	29	11C
0005432632724	25094	30	11E
0005432649404	25094	31	11F
0005432632714	25094	32	12C
0005435844353	25094	33	12E
0005435844352	25094	34	12F
0005435844362	25094	35	13A
0005432632743	25094	36	13C
0005435846290	25094	37	13F
0005432632686	25094	38	14D
0005435844357	25094	39	14E
0005432632721	25094	40	14F
0005435844360	25094	41	15C
0005435844361	25094	42	16A
0005432632685	25094	43	16F
0005432649414	25094	44	17A
0005435844358	25094	45	18D
0005432632745	25094	46	18E
0005435844350	25094	47	19A
0005432632735	25094	48	19C
0005432632754	25094	49	19E
0005435846289	25094	50	19F
0005432632750	25094	51	20D
0005433285423	1881	1	1A
0005433285322	1881	2	1C
0005433285414	1881	3	1F
0005433008836	1881	4	2A
0005433285213	1881	5	2C
0005433008761	1881	6	2D
0005433810587	1881	7	2F
0005433285365	1881	8	3A
0005433285332	1881	9	3C
0005433285287	1881	10	3D
0005432295909	1881	11	3F
0005433008724	1881	12	4C
0005433810594	1881	13	4D
0005433008875	1881	14	4E
0005433008515	1881	15	4F
0005433008886	1881	16	5A
0005433285426	1881	17	5C
0005433008845	1881	18	5D
0005433008605	1881	19	5E
0005433008844	1881	20	6A
0005433285402	1881	21	5F
0005433285447	1881	22	6C
0005433008651	1881	23	6E
0005433285469	1881	24	6F
0005433008612	1881	25	7D
0005433810593	1881	26	7C
0005433009023	1881	27	7E
0005433008759	1881	28	7F
0005433008723	1881	29	8A
0005433008583	1881	30	8D
0005433008639	1881	31	8E
0005433285372	1881	32	8F
0005433008814	1881	33	9A
0005433008762	1881	34	9C
0005433810597	1881	35	9D
0005433810592	1881	36	9E
0005433285510	1881	37	9F
0005433285335	1881	38	10A
0005433008729	1881	39	10C
0005433285392	1881	40	10D
0005433285338	1881	41	10E
0005433285438	1881	42	10F
0005433285425	1881	43	11A
0005433285303	1881	44	11C
0005433008698	1881	45	11D
0005433810591	1881	46	11E
0005433285212	1881	47	11F
0005433810588	1881	48	12A
0005433810586	1881	49	12C
0005433285354	1881	50	12D
0005433285360	1881	51	12E
0005433285417	1881	52	12F
0005433810595	1881	53	13A
0005433810596	1881	54	13C
0005433810589	1881	55	13D
0005433008828	1881	56	13E
0005433285395	1881	57	13F
0005433008643	1881	58	14A
0005433285394	1881	59	14C
0005433285334	1881	60	14D
0005433285288	1881	61	14E
0005433285559	1881	62	14F
0005433008827	1881	63	15A
0005433008766	1881	64	15C
0005433008887	1881	65	15D
0005433285359	1881	66	15E
0005433008899	1881	67	15F
0005433285434	1881	68	16A
0005433285353	1881	69	16C
0005433285424	1881	70	16D
0005433008792	1881	71	16E
0005433285439	1881	72	16F
0005433285506	1881	73	17A
0005432295908	1881	74	17C
0005433008642	1881	75	17D
0005433285422	1881	76	18A
0005433285448	1881	77	18D
0005433008699	1881	78	18E
0005433810590	1881	79	18F
0005433008760	1881	80	19A
0005433008793	1881	81	19C
0005433008613	1881	82	19D
0005433285452	1881	83	19E
0005433008787	1881	84	20C
0005433008714	1881	85	20D
0005433285333	1881	86	20E
0005433008695	1881	87	20F
0005433285630	22581	1	1A
0005433009109	22581	2	1C
0005433009089	22581	3	1D
0005433009120	22581	4	1F
0005433285632	22581	5	2A
0005433285633	22581	6	2C
0005433285628	22581	7	2D
0005433009080	22581	8	2F
0005433009119	22581	9	3A
0005433285635	22581	10	3C
0005433285615	22581	11	3D
0005433285640	22581	12	3F
0005433285636	22581	13	4A
0005433009084	22581	14	4C
0005433285638	22581	15	4D
0005433009101	22581	16	4E
0005433009096	22581	17	5C
0005433285619	22581	18	5E
0005433009111	22581	19	5F
0005433009114	22581	20	6A
0005433285645	22581	21	6C
0005433285641	22581	22	6D
0005433009103	22581	23	6E
0005433009098	22581	24	6F
0005433009088	22581	25	7A
0005433285620	22581	26	7C
0005433285642	22581	27	7D
0005433285639	22581	28	7E
0005433009081	22581	29	7F
0005433285643	22581	30	8A
0005433285626	22581	31	8C
0005433009085	22581	32	8D
0005433285622	22581	33	8E
0005433009116	22581	34	9C
0005433009110	22581	35	9D
0005433009112	22581	36	9E
0005433285614	22581	37	9F
0005433009095	22581	38	10A
0005433009083	22581	39	10C
0005433009123	22581	40	10D
0005433285618	22581	41	10E
0005433285616	22581	42	10F
0005433810531	22581	43	11A
0005433285627	22581	44	11C
0005433285625	22581	45	11E
0005433009105	22581	46	11F
0005433009104	22581	47	12A
0005433009102	22581	48	12C
0005433009078	22581	49	12D
0005433009075	22581	50	12E
0005433009079	22581	51	12F
0005433009107	22581	52	13C
0005433009115	22581	53	13D
0005433009082	22581	54	13F
0005433009117	22581	55	14A
0005433285644	22581	56	14C
0005433285623	22581	57	14E
0005433009086	22581	58	14F
0005433009099	22581	59	15A
0005433285617	22581	60	15C
0005433009108	22581	61	15E
0005433009094	22581	62	15F
0005433285629	22581	63	16A
0005433009091	22581	64	16C
0005433009074	22581	65	16D
0005433810532	22581	66	16E
0005433009113	22581	67	16F
0005433009092	22581	68	17A
0005433009122	22581	69	17D
0005433285621	22581	70	17E
0005433009097	22581	71	17F
0005433285624	22581	72	18A
0005433285631	22581	73	18C
0005433009087	22581	74	18D
0005433009093	22581	75	18E
0005433009090	22581	76	18F
0005433009106	22581	77	19A
0005433009077	22581	78	19C
0005433285637	22581	79	19F
0005433009118	22581	80	20A
0005433009121	22581	81	20C
0005433009100	22581	82	20D
0005433285634	22581	83	20E
0005433009076	22581	84	20F
0005432755106	25337	1	2A
0005434153538	25337	2	2D
0005432756874	25337	3	4D
0005432756876	25337	4	4E
0005432755103	25337	5	4F
0005432755099	25337	6	5C
0005432755107	25337	7	5E
0005434153530	25337	8	5F
0005432755110	25337	9	6A
0005432756881	25337	10	6C
0005434153534	25337	11	7C
0005434153537	25337	12	7E
0005432756873	25337	13	8A
0005432755104	25337	14	8E
0005432755097	25337	15	8F
0005432755108	25337	16	9A
0005432756875	25337	17	9C
0005432755100	25337	18	9E
0005434152788	25337	19	10A
0005434152781	25337	20	10D
0005432755102	25337	21	10F
0005434153528	25337	22	11A
0005432756870	25337	23	11F
0005432755105	25337	24	12D
0005434152789	25337	25	12E
0005434152787	25337	26	13C
0005432755109	25337	27	13D
0005432756869	25337	28	14C
0005432756872	25337	29	16C
0005432756877	25337	30	16D
0005432756878	25337	31	16E
0005434153533	25337	32	17A
0005432756871	25337	33	17E
0005432756882	25337	34	17F
0005434153531	25337	35	18E
0005432755111	25337	36	18F
0005434153535	25337	37	19A
0005432755101	25337	38	19C
0005432756879	25337	39	19E
0005432756880	25337	40	20A
0005432755098	25337	41	20C
0005434153532	25337	42	20E
0005433847359	5592	1	1A
0005432081581	5592	2	1F
0005433847339	5592	3	1D
0005432081583	5592	4	1C
0005435282657	5592	5	2A
0005433847348	5592	6	2D
0005433847373	5592	7	2C
0005433847368	5592	8	3A
0005433847358	5592	9	2F
0005432081585	5592	10	3D
0005435282561	5592	11	3C
0005433847392	5592	12	4A
0005433847354	5592	13	3F
0005433815435	5592	14	4C
0005435282663	5592	15	4F
0005435282589	5592	16	4D
0005433815439	5592	17	5C
0005435282636	5592	18	5A
0005433847342	5592	19	5F
0005435282615	5592	20	5D
0005433847378	5592	21	6B
0005433847349	5592	22	6A
0005433847338	5592	23	6D
0005435282583	5592	24	6C
0005433847393	5592	25	6E
0005435282594	5592	26	7B
0005433847381	5592	27	7C
0005434173540	5592	28	7E
0005433847389	5592	29	8A
0005433847341	5592	30	7F
0005433815434	5592	31	8B
0005435282572	5592	32	8C
0005433815437	5592	33	8E
0005432081582	5592	34	9B
0005435282623	5592	35	9A
0005433815438	5592	36	9C
0005435282504	5592	37	9F
0005433847352	5592	38	9E
0005433847385	5592	39	9D
0005435282511	5592	40	10A
0005433847363	5592	41	10C
0005433847346	5592	42	10B
0005433847391	5592	43	10E
0005433847383	5592	44	10D
0005435282573	5592	45	10F
0005435282481	5592	46	11C
0005435282489	5592	47	11B
0005433847395	5592	48	11A
0005435282612	5592	49	11D
0005433847388	5592	50	11F
0005435282524	5592	51	11E
0005433847365	5592	52	12B
0005433847369	5592	53	12A
0005435282539	5592	54	12C
0005433847394	5592	55	12F
0005433847371	5592	56	12E
0005435282499	5592	57	13C
0005435282540	5592	58	13B
0005433847351	5592	59	13D
0005435282409	5592	60	14A
0005433847377	5592	61	13F
0005432081579	5592	62	14B
0005433815436	5592	63	14D
0005433847374	5592	64	14C
0005433847344	5592	65	15A
0005433847364	5592	66	14F
0005433847390	5592	67	14E
0005433847353	5592	68	15B
0005433847362	5592	69	15D
0005433847387	5592	70	15C
0005434173536	5592	71	15E
0005433847370	5592	72	15F
0005433847340	5592	73	16E
0005433847361	5592	74	16D
0005433847350	5592	75	16C
0005433847380	5592	76	17B
0005433847343	5592	77	17A
0005432081584	5592	78	17D
0005435282616	5592	79	17C
0005433847357	5592	80	17F
0005435282525	5592	81	17E
0005433847360	5592	82	18B
0005435282534	5592	83	18C
0005433847384	5592	84	18E
0005433847382	5592	85	18D
0005433847372	5592	86	19A
0005434173537	5592	87	18F
0005435282613	5592	88	19C
0005433847375	5592	89	19B
0005433847386	5592	90	19E
0005433847379	5592	91	19D
0005433847345	5592	92	19F
0005433847376	5592	93	20B
0005432081580	5592	94	20A
0005433847347	5592	95	20D
0005435282454	5592	96	20C
0005433847356	5592	97	20F
0005433847367	5592	98	20E
0005433847355	5592	99	21B
0005435282662	5592	100	21A
0005433847366	5592	101	21C
0005435282453	5592	102	21E
0005433846922	13832	1	1A
0005435282785	13832	2	1F
0005433846710	13832	3	1D
0005433846893	13832	4	2A
0005433846819	13832	5	3A
0005433846871	13832	6	3D
0005433847035	13832	7	3C
0005433846807	13832	8	4A
0005433846966	13832	9	3F
0005433846709	13832	10	4C
0005433847072	13832	11	5A
0005433846907	13832	12	4F
0005433846914	13832	13	5C
0005433846829	13832	14	5F
0005434173566	13832	15	5D
0005435282788	13832	16	6A
0005433846731	13832	17	6D
0005433847067	13832	18	6C
0005432003736	13832	19	6E
0005433846935	13832	20	6F
0005435282780	13832	21	7C
0005433846824	13832	22	7B
0005435282787	13832	23	7E
0005435282772	13832	24	7D
0005433846896	13832	25	8A
0005433846814	13832	26	8B
0005433846901	13832	27	8E
0005433847008	13832	28	8D
0005433846870	13832	29	9B
0005433847021	13832	30	9D
0005433847020	13832	31	9C
0005433846921	13832	32	9E
0005432003737	13832	33	10A
0005433847261	13832	34	9F
0005435282773	13832	35	10C
0005432003738	13832	36	10B
0005435282790	13832	37	11A
0005433846906	13832	38	10F
0005433846915	13832	39	11B
0005435282776	13832	40	11D
0005433846694	13832	41	11C
0005433846804	13832	42	11E
0005433846869	13832	43	12A
0005433846670	13832	44	12B
0005433815390	13832	45	12E
0005433846889	13832	46	12D
0005433815399	13832	47	13B
0005435282774	13832	48	13A
0005433846904	13832	49	13C
0005433846934	13832	50	13E
0005433846897	13832	51	13D
0005433846752	13832	52	14B
0005435282789	13832	53	14A
0005433846910	13832	54	14D
0005433846695	13832	55	14C
0005435282777	13832	56	14F
0005433846837	13832	57	14E
0005435282778	13832	58	15A
0005433846902	13832	59	15D
0005435282771	13832	60	15C
0005433846917	13832	61	15B
0005433846903	13832	62	15E
0005433846815	13832	63	16A
0005433846866	13832	64	15F
0005434173564	13832	65	16E
0005433815398	13832	66	16D
0005433847071	13832	67	16F
0005433846797	13832	68	17C
0005435282779	13832	69	17B
0005435282786	13832	70	17A
0005433846708	13832	71	17D
0005433846908	13832	72	18B
0005433847073	13832	73	18A
0005435282781	13832	74	18C
0005434173565	13832	75	18E
0005435282782	13832	76	19A
0005435282775	13832	77	18F
0005433846656	13832	78	19B
0005433846770	13832	79	19D
0005432003735	13832	80	19F
0005433846751	13832	81	20B
0005435282783	13832	82	20D
0005433846911	13832	83	20C
0005435282784	13832	84	21B
0005433846693	13832	85	21E
0005433846872	13832	86	21D
0005433846823	13832	87	21F
0005434620815	7847	1	1A
0005434620814	7847	2	1B
0005434620812	7847	3	1D
0005434620820	7847	4	2A
0005434620817	7847	5	2B
0005435332391	7847	6	2C
0005435332373	7847	7	2D
0005435332411	7847	8	3A
0005434620816	7847	9	3C
0005434620832	7847	10	3D
0005434620827	7847	11	4A
0005435332410	7847	12	4B
0005434620811	7847	13	4C
0005434620829	7847	14	4D
0005434620824	7847	15	5B
0005435332346	7847	16	6B
0005434620813	7847	17	7A
0005434620825	7847	18	7C
0005435332356	7847	19	7D
0005434620826	7847	20	18B
0005434620819	7847	21	18A
0005434620823	7847	22	18C
0005434620821	7847	23	18D
0005434620830	7847	24	19A
0005432112541	7847	25	19B
0005435332357	7847	26	19D
0005434620818	7847	27	20C
0005435332365	7847	28	21A
0005435332372	7847	29	21B
0005434620828	7847	30	21C
0005434620831	7847	31	22A
0005434620822	7847	32	22B
0005435332371	7847	33	22C
0005432112540	7847	34	23A
0005435332451	32987	1	1B
0005434620586	32987	2	1C
0005434620630	32987	3	2B
0005434620712	32987	4	3A
0005435332453	32987	5	3C
0005435332450	32987	6	4A
0005434620715	32987	7	4B
0005434620636	32987	8	4D
0005434620642	32987	9	5A
0005435332452	32987	10	5B
0005434620628	32987	11	6C
0005434620631	32987	12	6D
0005435332449	32987	13	7A
0005435332445	32987	14	7C
0005435332446	32987	15	18B
0005435332448	32987	16	18C
0005434620698	32987	17	18D
0005434620706	32987	18	19A
0005435332454	32987	19	20A
0005434620707	32987	20	20B
0005434620697	32987	21	20C
0005435332447	32987	22	20D
0005434620635	32987	23	21D
0005434620620	32987	24	22A
0005434620699	32987	25	22B
0005434620542	32987	26	23A
0005434620629	32987	27	23B
0005432190673	4292	1	1A
0005435785735	4292	2	1F
0005435785745	4292	3	2A
0005432190674	4292	4	2C
0005432190670	4292	5	2D
0005435785754	4292	6	3A
0005435787379	4292	7	3D
0005435785737	4292	8	3F
0005435785724	4292	9	4C
0005434994128	4292	10	4E
0005435785749	4292	11	4F
0005434994129	4292	12	5E
0005435785726	4292	13	6A
0005435785721	4292	14	6C
0005435785720	4292	15	6D
0005435937389	4292	16	6E
0005434994126	4292	17	7C
0005435785747	4292	18	7E
0005435787378	4292	19	7F
0005435785731	4292	20	8C
0005435785743	4292	21	9A
0005435785755	4292	22	9D
0005435785725	4292	23	9E
0005435787377	4292	24	9F
0005435785752	4292	25	10A
0005434994131	4292	26	10C
0005435785733	4292	27	11A
0005435785734	4292	28	11C
0005434994127	4292	29	11D
0005435785723	4292	30	11F
0005435785728	4292	31	12A
0005435785729	4292	32	12D
0005434994134	4292	33	12F
0005435918677	4292	34	13C
0005435785753	4292	35	13D
0005435785739	4292	36	14A
0005435785722	4292	37	14E
0005435785748	4292	38	14F
0005435785742	4292	39	15A
0005434994133	4292	40	15C
0005435785736	4292	41	15D
0005432190671	4292	42	15E
0005434994125	4292	43	16C
0005434994130	4292	44	16D
0005435785740	4292	45	16E
0005435785727	4292	46	16F
0005435785738	4292	47	17C
0005435785746	4292	48	17D
0005434994132	4292	49	17E
0005435785750	4292	50	17F
0005435785744	4292	51	18C
0005435785741	4292	52	18D
0005435785732	4292	53	18F
0005435937380	4292	54	19A
0005432190672	4292	55	19C
0005435918676	4292	56	19F
0005435785730	4292	57	20A
0005435785751	4292	58	20D
0005432195715	27278	1	1A
0005435918707	27278	2	1C
0005435937431	27278	3	2D
0005435785254	27278	4	3C
0005435785391	27278	5	3F
0005435785404	27278	6	4C
0005435785419	27278	7	4F
0005435918710	27278	8	5A
0005435785460	27278	9	5C
0005435785439	27278	10	5D
0005435785438	27278	11	5F
0005435785332	27278	12	6A
0005435785392	27278	13	6D
0005434994013	27278	14	7A
0005434994048	27278	15	7E
0005434994014	27278	16	7F
0005435918708	27278	17	8A
0005435785421	27278	18	8C
0005435918711	27278	19	8F
0005435785447	27278	20	9A
0005434994064	27278	21	9C
0005435785281	27278	22	9D
0005434994047	27278	23	9E
0005435785334	27278	24	10A
0005435785420	27278	25	10D
0005435918709	27278	26	11E
0005435785370	27278	27	12C
0005435785426	27278	28	12E
0005435785389	27278	29	13A
0005435937430	27278	30	13C
0005435785371	27278	31	13D
0005435785434	27278	32	13F
0005435785349	27278	33	14A
0005435785423	27278	34	14D
0005435785390	27278	35	14F
0005435785275	27278	36	15C
0005435785308	27278	37	15F
0005435937432	27278	38	16C
0005435785422	27278	39	16D
0005435785437	27278	40	16E
0005435785325	27278	41	17D
0005435785310	27278	42	17E
0005435918706	27278	43	18E
0005435785327	27278	44	18F
0005435785444	27278	45	19C
0005435937429	27278	46	19D
0005435785182	27278	47	20C
0005432195714	27278	48	20D
0005435785252	27278	49	20E
0005435785373	27278	50	20F
0005432146219	19888	1	21A
0005432146220	19888	2	22C
0005434082167	4732	1	1A
0005432460450	4732	2	1C
0005432460407	4732	3	1B
0005432568336	4732	4	1H
0005432460442	4732	5	1G
0005432568302	4732	6	2C
0005432568338	4732	7	2B
0005432170462	4732	8	2A
0005432568308	4732	9	2F
0005434082165	4732	10	2G
0005432460400	4732	11	2H
0005432568314	4732	12	3C
0005432460445	4732	13	3F
0005432571363	4732	14	4A
0005432460426	4732	15	4C
0005432568300	4732	16	4B
0005433726130	4732	17	4F
0005432568291	4732	18	4H
0005432568296	4732	19	5C
0005432460424	4732	20	5G
0005432568311	4732	21	5F
0005432460417	4732	22	5H
0005432571365	4732	23	9B
0005432568307	4732	24	9G
0005432170460	4732	25	11A
0005432568332	4732	26	11B
0005434082169	4732	27	11D
0005432460425	4732	28	11F
0005432460446	4732	29	11H
0005432568280	4732	30	11G
0005432568329	4732	31	12A
0005432568294	4732	32	12D
0005432568339	4732	33	12G
0005432568298	4732	34	13B
0005432568293	4732	35	13A
0005432186911	4732	36	13D
0005432460437	4732	37	13F
0005432568328	4732	38	13G
0005432571362	4732	39	13H
0005434082158	4732	40	14A
0005432568286	4732	41	14F
0005432568310	4732	42	14E
0005432460399	4732	43	14H
0005434082160	4732	44	15E
0005432460410	4732	45	15G
0005434082162	4732	46	15F
0005432568304	4732	47	16B
0005433452763	4732	48	16A
0005432460452	4732	49	15H
0005432568279	4732	50	16D
0005432460401	4732	51	16F
0005432460451	4732	52	16H
0005432568278	4732	53	17A
0005432568321	4732	54	17D
0005432460412	4732	55	17B
0005432568299	4732	56	17F
0005432568297	4732	57	17E
0005432460434	4732	58	18A
0005432568323	4732	59	17H
0005433451640	4732	60	18D
0005432460439	4732	61	18B
0005432186910	4732	62	18E
0005432568285	4732	63	18G
0005432460420	4732	64	18F
0005432568331	4732	65	19A
0005432568284	4732	66	19B
0005432568303	4732	67	19E
0005432460403	4732	68	19H
0005432568281	4732	69	19G
0005432568334	4732	70	20A
0005432460404	4732	71	20B
0005432460402	4732	72	20E
0005432568326	4732	73	20D
0005432460423	4732	74	20G
0005432568306	4732	75	20F
0005432568309	4732	76	21A
0005432460406	4732	77	21B
0005432568312	4732	78	21E
0005433452762	4732	79	21G
0005432460441	4732	80	21F
0005434082168	4732	81	21H
0005432568301	4732	82	22B
0005432170465	4732	83	22A
0005432568305	4732	84	22D
0005432568287	4732	85	22E
0005432170464	4732	86	22G
0005432568318	4732	87	22H
0005434082161	4732	88	23B
0005432460416	4732	89	23D
0005434082175	4732	90	23F
0005432460427	4732	91	23E
0005432460414	4732	92	23H
0005432568337	4732	93	24B
0005432568313	4732	94	24G
0005433451641	4732	95	25D
0005434082172	4732	96	24H
0005432460432	4732	97	25E
0005432460443	4732	98	27B
0005432568290	4732	99	27A
0005432568277	4732	100	27E
0005432568292	4732	101	27D
0005432460419	4732	102	27H
0005432568315	4732	103	27G
0005432568289	4732	104	28A
0005432460435	4732	105	28B
0005432568317	4732	106	28D
0005432186912	4732	107	28E
0005432568330	4732	108	28H
0005432460409	4732	109	28G
0005432460422	4732	110	29A
0005432568335	4732	111	29D
0005432568327	4732	112	29B
0005432460408	4732	113	29E
0005432568322	4732	114	29G
0005432460421	4732	115	29F
0005432460430	4732	116	29H
0005432568325	4732	117	30B
0005432460440	4732	118	30A
0005432571364	4732	119	30D
0005432568288	4732	120	30F
0005432460448	4732	121	30E
0005432460413	4732	122	31B
0005434082170	4732	123	31F
0005432460411	4732	124	31G
0005432460418	4732	125	32A
0005432568283	4732	126	31H
0005432460405	4732	127	32D
0005432568316	4732	128	32B
0005432568324	4732	129	32F
0005432460415	4732	130	32H
0005432568333	4732	131	33A
0005432568320	4732	132	33D
0005434082166	4732	133	33B
0005432460429	4732	134	33E
0005432460436	4732	135	33F
0005434082171	4732	136	33G
0005432460438	4732	137	34A
0005434082173	4732	138	34D
0005432460428	4732	139	35A
0005432568319	4732	140	35D
0005434082159	4732	141	35E
0005432170461	4732	142	35H
0005432460433	4732	143	36A
0005433451642	4732	144	36D
0005432460444	4732	145	36E
0005432568282	4732	146	37B
0005432568295	4732	147	37G
0005432460431	4732	148	37F
0005432460449	4732	149	38A
0005432460447	4732	150	38B
0005432170463	4732	151	38G
0005434082164	4732	152	38F
0005434082163	4732	153	39E
0005434082174	4732	154	39F
0005432460053	30560	1	1A
0005432568027	30560	2	1C
0005432460178	30560	3	1B
0005432459988	30560	4	1F
0005432568057	30560	5	1H
0005434081889	30560	6	2B
0005432459935	30560	7	2F
0005432459921	30560	8	2G
0005432567938	30560	9	3C
0005432161177	30560	10	3B
0005432460091	30560	11	3A
0005434081852	30560	12	3F
0005432459996	30560	13	3G
0005434081938	30560	14	4A
0005434081853	30560	15	4C
0005432571327	30560	16	4B
0005432459825	30560	17	4F
0005432460056	30560	18	4G
0005432460039	30560	19	5A
0005434082081	30560	20	4H
0005432567762	30560	21	5B
0005432460016	30560	22	5C
0005434081964	30560	23	5G
0005434081885	30560	24	5H
0005432460130	30560	25	9B
0005434081960	30560	26	11A
0005432567710	30560	27	11D
0005432459915	30560	28	11B
0005432568059	30560	29	11F
0005432459995	30560	30	11G
0005434082028	30560	31	12A
0005432567608	30560	32	12E
0005434081974	30560	33	13G
0005432459936	30560	34	13F
0005432568001	30560	35	14A
0005432567860	30560	36	14B
0005432460270	30560	37	14E
0005432567587	30560	38	14G
0005432567935	30560	39	15A
0005434081952	30560	40	15D
0005433452731	30560	41	15B
0005434082014	30560	42	15F
0005432567824	30560	43	15H
0005432459944	30560	44	15G
0005432567756	30560	45	16E
0005432459895	30560	46	16F
0005432567792	30560	47	16H
0005432460003	30560	48	17A
0005434081953	30560	49	17D
0005432460107	30560	50	17B
0005432459984	30560	51	17E
0005432568044	30560	52	17F
0005432459832	30560	53	18A
0005432567562	30560	54	18B
0005432568055	30560	55	18F
0005432567798	30560	56	18E
0005432567894	30560	57	18H
0005432460040	30560	58	19A
0005432567728	30560	59	19E
0005432567863	30560	60	19D
0005432567941	30560	61	19F
0005432567915	30560	62	20A
0005432460236	30560	63	20B
0005432459989	30560	64	20D
0005432460068	30560	65	20F
0005432460141	30560	66	20G
0005432213648	30560	67	21A
0005434081928	30560	68	21D
0005432459859	30560	69	21B
0005434081890	30560	70	21G
0005432459803	30560	71	22D
0005432567820	30560	72	22B
0005434081924	30560	73	22E
0005432567797	30560	74	22G
0005432460065	30560	75	22F
0005432568026	30560	76	23A
0005432567652	30560	77	23D
0005432567936	30560	78	23F
0005432460067	30560	79	23E
0005432567793	30560	80	23G
0005432460122	30560	81	23H
0005432567842	30560	82	24B
0005432567810	30560	83	24E
0005432567802	30560	84	24D
0005432459943	30560	85	24F
0005432567744	30560	86	24G
0005432213647	30560	87	25D
0005434081884	30560	88	24H
0005432459844	30560	89	25E
0005432567695	30560	90	27B
0005432460023	30560	91	27A
0005432460237	30560	92	27E
0005432567672	30560	93	27F
0005434082029	30560	94	27G
0005432567599	30560	95	28A
0005432460047	30560	96	27H
0005434081967	30560	97	28E
0005434081880	30560	98	28D
0005434081978	30560	99	28F
0005432460166	30560	100	28H
0005433452732	30560	101	29A
0005434081982	30560	102	29E
0005432567696	30560	103	29D
0005432460275	30560	104	29G
0005432459942	30560	105	29F
0005432567821	30560	106	29H
0005432213646	30560	107	30A
0005432567775	30560	108	30D
0005434081931	30560	109	30B
0005432567878	30560	110	30F
0005432567563	30560	111	30E
0005432567564	30560	112	30G
0005432460191	30560	113	31E
0005432567673	30560	114	31D
0005432460179	30560	115	31F
0005434081927	30560	116	31H
0005432567571	30560	117	31G
0005432460190	30560	118	32B
0005432567740	30560	119	32A
0005432567861	30560	120	32E
0005434081966	30560	121	32F
0005433454884	30560	122	32G
0005432567840	30560	123	33A
0005432460120	30560	124	32H
0005432567761	30560	125	33B
0005434082013	30560	126	33E
0005432161178	30560	127	33D
0005432460204	30560	128	33F
0005432568045	30560	129	33H
0005432213649	30560	130	34B
0005432567900	30560	131	34D
0005432460015	30560	132	34G
0005432460054	30560	133	34F
0005432460052	30560	134	35A
0005434082080	30560	135	34H
0005434081963	30560	136	35E
0005432567893	30560	137	35G
0005432567942	30560	138	36A
0005432568056	30560	139	35H
0005434081957	30560	140	36B
0005432460279	30560	141	36D
0005432571336	30560	142	36F
0005434081941	30560	143	36E
0005432567843	30560	144	37A
0005432459824	30560	145	37D
0005432459922	30560	146	37F
0005432460088	30560	147	38B
0005433454883	30560	148	38E
0005432460089	30560	149	38F
0005432460092	30560	150	38H
0005432460041	30560	151	39E
0005435720835	13595	1	3B
0005435722080	13595	2	4B
0005435722082	13595	3	5A
0005435720836	13595	4	5B
0005435722081	13595	5	6A
0005435722060	21200	1	1B
0005435722061	21200	2	2B
0005435722059	21200	3	3B
0005432295909	22778	1	19D
0005432295908	22778	2	22A
0005433344273	11110	1	1A
0005433344311	11110	2	1C
0005433344262	11110	3	1D
0005433344327	11110	4	1F
0005433344319	11110	5	2C
0005435097302	11110	6	2A
0005433344289	11110	7	2F
0005433344320	11110	8	2D
0005435508310	11110	9	3A
0005433344251	11110	10	3D
0005433344270	11110	11	3C
0005433344318	11110	12	3F
0005433344296	11110	13	4B
0005433344295	11110	14	4A
0005433344240	11110	15	4C
0005433344269	11110	16	4D
0005433344275	11110	17	4E
0005435097307	11110	18	5B
0005433344300	11110	19	5A
0005433344249	11110	20	5C
0005433344297	11110	21	5D
0005433344280	11110	22	5F
0005433344292	11110	23	5E
0005433344231	11110	24	6A
0005433344238	11110	25	6B
0005433344314	11110	26	6C
0005433344246	11110	27	6D
0005433344287	11110	28	6E
0005433344230	11110	29	6F
0005433344326	11110	30	7B
0005433344254	11110	31	7A
0005433344247	11110	32	7C
0005435508338	11110	33	7D
0005435097306	11110	34	7E
0005433344272	11110	35	8A
0005433344293	11110	36	7F
0005433344265	11110	37	8B
0005433344310	11110	38	8D
0005435097305	11110	39	8C
0005433344248	11110	40	8E
0005433344274	11110	41	8F
0005433344261	11110	42	9A
0005435097301	11110	43	9C
0005433344263	11110	44	9B
0005433344294	11110	45	9D
0005433344315	11110	46	9F
0005433344313	11110	47	9E
0005433344244	11110	48	10C
0005433344256	11110	49	10B
0005435508366	11110	50	10D
0005433344260	11110	51	10E
0005433344288	11110	52	11A
0005435508386	11110	53	11B
0005433344281	11110	54	11D
0005433344322	11110	55	11C
0005433344236	11110	56	11E
0005433344259	11110	57	11F
0005435508371	11110	58	12A
0005433344305	11110	59	12C
0005433344325	11110	60	12B
0005433344307	11110	61	12D
0005435508380	11110	62	12E
0005433344284	11110	63	12F
0005433344255	11110	64	13A
0005435097303	11110	65	13B
0005435380282	11110	66	13D
0005435097309	11110	67	13C
0005433344317	11110	68	13E
0005433344282	11110	69	14A
0005435097311	11110	70	13F
0005433344258	11110	71	14B
0005435508365	11110	72	14C
0005433344276	11110	73	14D
0005435097310	11110	74	14E
0005433344264	11110	75	15A
0005435097308	11110	76	14F
0005435508372	11110	77	15C
0005433344241	11110	78	15B
0005435380288	11110	79	15D
0005435380309	11110	80	15E
0005433344321	11110	81	16A
0005433344237	11110	82	15F
0005433344329	11110	83	16B
0005435508378	11110	84	16C
0005433344285	11110	85	16D
0005433344239	11110	86	16E
0005433344252	11110	87	17A
0005433344302	11110	88	16F
0005433344283	11110	89	17B
0005433344268	11110	90	17C
0005433344306	11110	91	17D
0005433344242	11110	92	17F
0005433344324	11110	93	17E
0005433344308	11110	94	18A
0005433344235	11110	95	18B
0005435380281	11110	96	18C
0005435097300	11110	97	18E
0005433344286	11110	98	18D
0005433344232	11110	99	18F
0005433344266	11110	100	19A
0005433344279	11110	101	19C
0005433344290	11110	102	19B
0005433344291	11110	103	19D
0005435508311	11110	104	19E
0005433344245	11110	105	20A
0005433344328	11110	106	19F
0005435097304	11110	107	20B
0005433344243	11110	108	20D
0005433344233	11110	109	20C
0005433344267	11110	110	20E
0005433344278	11110	111	20F
0005433344303	11110	112	21A
0005433344309	11110	113	21B
0005433344257	11110	114	21D
0005433344234	11110	115	21C
0005433344304	11110	116	21E
0005433344301	11110	117	21F
0005433344299	11110	118	22B
0005433344316	11110	119	22A
0005433344312	11110	120	22C
0005433344253	11110	121	22E
0005433344298	11110	122	22D
0005435508387	11110	123	23A
0005433344250	11110	124	22F
0005433344277	11110	125	23B
0005433344323	11110	126	23C
0005435508390	11110	127	23E
0005433344229	11110	128	23D
0005433344271	11110	129	23F
0005433343383	17100	1	1A
0005433343464	17100	2	1C
0005435545836	17100	3	1D
0005433343418	17100	4	2A
0005435380348	17100	5	1F
0005435545834	17100	6	2D
0005433343156	17100	7	2C
0005433343362	17100	8	3A
0005433342943	17100	9	3D
0005433342726	17100	10	3F
0005435380349	17100	11	4A
0005433343648	17100	12	4B
0005433343241	17100	13	4C
0005433343302	17100	14	4D
0005435545843	17100	15	4F
0005433343281	17100	16	5A
0005433343504	17100	17	5C
0005433343811	17100	18	5B
0005435545829	17100	19	5D
0005435545830	17100	20	5F
0005433343249	17100	21	6B
0005432293237	17100	22	6A
0005433343637	17100	23	6D
0005433343217	17100	24	6C
0005433343463	17100	25	6E
0005433343220	17100	26	7B
0005433342958	17100	27	7C
0005433343222	17100	28	7D
0005435545842	17100	29	7E
0005433343068	17100	30	7F
0005433343290	17100	31	8B
0005433343569	17100	32	8A
0005433343134	17100	33	8C
0005433343289	17100	34	8E
0005433343582	17100	35	8F
0005435380351	17100	36	9A
0005432293236	17100	37	9B
0005435097247	17100	38	9C
0005433342939	17100	39	9D
0005433343280	17100	40	9E
0005433343465	17100	41	10C
0005433343224	17100	42	10B
0005433343320	17100	43	9F
0005435380347	17100	44	10E
0005433343111	17100	45	10D
0005433343240	17100	46	11A
0005433343417	17100	47	11B
0005433343508	17100	48	11D
0005435545838	17100	49	11C
0005433343407	17100	50	11E
0005433343412	17100	51	12A
0005433343635	17100	52	12C
0005435097236	17100	53	12B
0005435545841	17100	54	12D
0005433343315	17100	55	12E
0005433343271	17100	56	12F
0005433343376	17100	57	13B
0005433343363	17100	58	13A
0005433342926	17100	59	13C
0005433342711	17100	60	13D
0005433343408	17100	61	13E
0005435545835	17100	62	13F
0005433343248	17100	63	14B
0005433343215	17100	64	14A
0005433343430	17100	65	14C
0005435380346	17100	66	14D
0005433343321	17100	67	14E
0005433343579	17100	68	15A
0005433343065	17100	69	14F
0005433343182	17100	70	15C
0005433343411	17100	71	15B
0005433342640	17100	72	15D
0005433343262	17100	73	15E
0005433343609	17100	74	16A
0005433343506	17100	75	15F
0005435380345	17100	76	16B
0005433343596	17100	77	16C
0005433343585	17100	78	16D
0005433343322	17100	79	16F
0005433343144	17100	80	16E
0005435545833	17100	81	17A
0005433343505	17100	82	17B
0005435545839	17100	83	17C
0005433343377	17100	84	17D
0005433342710	17100	85	17E
0005433343177	17100	86	18A
0005433343700	17100	87	18B
0005433343225	17100	88	18C
0005435097253	17100	89	18E
0005433343361	17100	90	18D
0005433342639	17100	91	18F
0005433343583	17100	92	19A
0005433342940	17100	93	19B
0005433343114	17100	94	19E
0005433343244	17100	95	19D
0005435545837	17100	96	19F
0005435545832	17100	97	20B
0005433343133	17100	98	20A
0005435545831	17100	99	20C
0005433343204	17100	100	20D
0005435380350	17100	101	20E
0005433343314	17100	102	20F
0005433343603	17100	103	21B
0005433343636	17100	104	21A
0005433342911	17100	105	21D
0005435545840	17100	106	21C
0005433343683	17100	107	21E
0005433343561	17100	108	22A
0005433343197	17100	109	21F
0005433342709	17100	110	22B
0005433343260	17100	111	22D
0005433342725	17100	112	22C
0005435097191	17100	113	22E
0005433343416	17100	114	22F
0005433343500	17100	115	23C
0005433343219	17100	116	23E
0005433343135	17100	117	23D
0005433343410	17100	118	23F
0005433481255	9118	1	1A
0005433507387	9118	2	1C
0005433507388	9118	3	1D
0005432919936	9118	4	2C
0005433507385	9118	5	2D
0005433507391	9118	6	2F
0005432919962	9118	7	3A
0005433507381	9118	8	3C
0005433507377	9118	9	3F
0005433507392	9118	10	4F
0005432919938	9118	11	5A
0005432919963	9118	12	5D
0005432919885	9118	13	5E
0005432919901	9118	14	5F
0005432919877	9118	15	6A
0005432919932	9118	16	6C
0005433481254	9118	17	6D
0005432919898	9118	18	6F
0005433481257	9118	19	7A
0005432919991	9118	20	8A
0005432919908	9118	21	8C
0005432919900	9118	22	8E
0005433507379	9118	23	8F
0005433507390	9118	24	9A
0005432919894	9118	25	9C
0005432919937	9118	26	10A
0005433481253	9118	27	10C
0005433481250	9118	28	10E
0005433507383	9118	29	11D
0005432919915	9118	30	11E
0005432919899	9118	31	12F
0005433507378	9118	32	13A
0005433481251	9118	33	13E
0005432919910	9118	34	14A
0005434158975	9118	35	14F
0005433481256	9118	36	15C
0005433507389	9118	37	16F
0005432919871	9118	38	17A
0005432919861	9118	39	17C
0005433507384	9118	40	17E
0005433481252	9118	41	18E
0005433507386	9118	42	18F
0005433507380	9118	43	19C
0005432919916	9118	44	19E
0005432919876	9118	45	19F
0005434158974	9118	46	20C
0005433507382	9118	47	20E
0005433507271	20457	1	1A
0005432920104	20457	2	1C
0005432920109	20457	3	1D
0005432920111	20457	4	2C
0005433507287	20457	5	2F
0005433507169	20457	6	3C
0005432920123	20457	7	4A
0005433507222	20457	8	4E
0005432920108	20457	9	4F
0005433481186	20457	10	5A
0005433507171	20457	11	5C
0005434159004	20457	12	5E
0005432920114	20457	13	6D
0005433507244	20457	14	6E
0005432920115	20457	15	6F
0005432920105	20457	16	7A
0005433507230	20457	17	7C
0005433481204	20457	18	7D
0005433507292	20457	19	7E
0005433481188	20457	20	7F
0005433507317	20457	21	8A
0005433507270	20457	22	8E
0005433507268	20457	23	8F
0005432920121	20457	24	9C
0005433507247	20457	25	9D
0005433481171	20457	26	9F
0005432920117	20457	27	10D
0005432920120	20457	28	10E
0005432920106	20457	29	10F
0005434159009	20457	30	11A
0005433507269	20457	31	11C
0005432920107	20457	32	11D
0005433481205	20457	33	11E
0005433481217	20457	34	11F
0005433481194	20457	35	12C
0005432920112	20457	36	12D
0005433481187	20457	37	12F
0005433507221	20457	38	13E
0005433507106	20457	39	13D
0005434159006	20457	40	14A
0005433507209	20457	41	14C
0005432920116	20457	42	14D
0005433507219	20457	43	15A
0005432920110	20457	44	15C
0005434159008	20457	45	15D
0005433507170	20457	46	16A
0005433507173	20457	47	16D
0005434159005	20457	48	16E
0005433507214	20457	49	17E
0005433507330	20457	50	18A
0005433481193	20457	51	18E
0005432920113	20457	52	18F
0005433507208	20457	53	19C
0005432920119	20457	54	19D
0005432920118	20457	55	19E
0005432920122	20457	56	20C
0005434159007	20457	57	20E
0005432394148	10193	1	1A
0005432396284	10193	2	1B
0005432396285	10193	3	2B
0005432394146	10193	4	2A
0005435178993	10193	5	3A
0005432396286	10193	6	3B
0005435178991	10193	7	4A
0005432394145	10193	8	4B
0005432394144	10193	9	5B
0005432396283	10193	10	6B
0005432394147	10193	11	6A
0005432400126	18380	1	2A
0005432396247	18380	2	2B
0005435179404	18380	3	4A
0005432396254	18380	4	5A
0005432400107	18380	5	5B
0005432396257	18380	6	6B
0005435626173	11032	1	1A
0005435626148	11032	2	1C
0005435554231	11032	3	1D
0005435126458	11032	4	1F
0005435126482	11032	5	2A
0005435626212	11032	6	2D
0005435126459	11032	7	2F
0005435626149	11032	8	3C
0005435626210	11032	9	3F
0005435554205	11032	10	4C
0005435126447	11032	11	4D
0005435626177	11032	12	4E
0005435126457	11032	13	4F
0005435554183	11032	14	5A
0005435554232	11032	15	5C
0005435626166	11032	16	5D
0005435626179	11032	17	5E
0005435626151	11032	18	5F
0005435556699	11032	19	6A
0005435126406	11032	20	6C
0005435126065	11032	21	6F
0005435626172	11032	22	7A
0005434411829	11032	23	7C
0005435554204	11032	24	7D
0005435126486	11032	25	7E
0005435126280	11032	26	7F
0005435126460	11032	27	8A
0005434928332	11032	28	8C
0005434411827	11032	29	8D
0005435626167	11032	30	8E
0005435556691	11032	31	8F
0005435126511	11032	32	9A
0005435126349	11032	33	9D
0005435126281	11032	34	9E
0005435626171	11032	35	9F
0005435126381	11032	36	10A
0005435126455	11032	37	10C
0005435126454	11032	38	10D
0005435626125	11032	39	10E
0005435626146	11032	40	11A
0005435626176	11032	41	11D
0005435126367	11032	42	11E
0005435126351	11032	43	11F
0005435126499	11032	44	12A
0005435126352	11032	45	12C
0005435626209	11032	46	12F
0005435626183	11032	47	13A
0005435126497	11032	48	13C
0005435126456	11032	49	13E
0005435626203	11032	50	13F
0005435126496	11032	51	14A
0005435126510	11032	52	14E
0005435126473	11032	53	14F
0005435626058	11032	54	15A
0005435126302	11032	55	15C
0005435626206	11032	56	15D
0005434411826	11032	57	15E
0005435126495	11032	58	15F
0005435554202	11032	59	16A
0005435626152	11032	60	16C
0005435626207	11032	61	16E
0005435126368	11032	62	16F
0005435126348	11032	63	17D
0005435126507	11032	64	17E
0005435626211	11032	65	17F
0005435626200	11032	66	18C
0005435126546	11032	67	18D
0005435556690	11032	68	18E
0005435626174	11032	69	18F
0005435626189	11032	70	19A
0005435126542	11032	71	19E
0005435626154	11032	72	19F
0005435626188	11032	73	20A
0005434411828	11032	74	20D
0005435126501	11032	75	20E
0005435626153	11032	76	20F
0005435126845	14719	1	1A
0005435126816	14719	2	1D
0005435626396	14719	3	1F
0005435126842	14719	4	2A
0005434411779	14719	5	2C
0005435626395	14719	6	2F
0005435126850	14719	7	3A
0005435126849	14719	8	3C
0005435126828	14719	9	3D
0005435126844	14719	10	3F
0005435126852	14719	11	4A
0005435126840	14719	12	4C
0005435626391	14719	13	4D
0005435626397	14719	14	4E
0005435126814	14719	15	5C
0005435126822	14719	16	5D
0005435556721	14719	17	5E
0005435626394	14719	18	5F
0005435556719	14719	19	6C
0005435126848	14719	20	6D
0005435126829	14719	21	6F
0005435556722	14719	22	7A
0005435126838	14719	23	7C
0005435126818	14719	24	7F
0005435126826	14719	25	8A
0005435126833	14719	26	8C
0005435126823	14719	27	8F
0005435626385	14719	28	9A
0005435626390	14719	29	9C
0005435126846	14719	30	9E
0005435126835	14719	31	9F
0005435554238	14719	32	10C
0005435554240	14719	33	10D
0005435126837	14719	34	10E
0005435626388	14719	35	10F
0005434928309	14719	36	11A
0005435126824	14719	37	11D
0005435626389	14719	38	11F
0005435126843	14719	39	12A
0005435126841	14719	40	12C
0005435126821	14719	41	12D
0005435554236	14719	42	12E
0005435554237	14719	43	12F
0005435626393	14719	44	13A
0005435126839	14719	45	13C
0005434411780	14719	46	13D
0005435126834	14719	47	14A
0005434411774	14719	48	14C
0005435626398	14719	49	14D
0005435126820	14719	50	14E
0005435126854	14719	51	14F
0005435126847	14719	52	15A
0005435126830	14719	53	15C
0005435126853	14719	54	15D
0005435126813	14719	55	15E
0005435126815	14719	56	15F
0005435626392	14719	57	16A
0005435556720	14719	58	16D
0005435126827	14719	59	16E
0005435554239	14719	60	16F
0005435626386	14719	61	17A
0005435126817	14719	62	17E
0005435126825	14719	63	18A
0005435126851	14719	64	18D
0005435126831	14719	65	18F
0005435626387	14719	66	19C
0005435126836	14719	67	19E
0005435126832	14719	68	19F
0005435126819	14719	69	20C
0005434928310	14719	70	20E
0005435715656	7112	1	1C
0005432398242	7112	2	1D
0005435443293	7112	3	2A
0005432400169	7112	4	2C
0005435715658	7112	5	2D
0005435216597	7112	6	3D
0005435715653	7112	7	3F
0005435715659	7112	8	5A
0005435715660	7112	9	8A
0005435216592	7112	10	7F
0005435715652	7112	11	8F
0005435443309	7112	12	9F
0005435715662	7112	13	10C
0005435715655	7112	14	10E
0005435715664	7112	15	11A
0005432398240	7112	16	11C
0005435443292	7112	17	11F
0005435715668	7112	18	12A
0005432400170	7112	19	12F
0005435715665	7112	20	13F
0005435715661	7112	21	14D
0005435715657	7112	22	15C
0005435715654	7112	23	16C
0005435443320	7112	24	16F
0005432398241	7112	25	17C
0005435443319	7112	26	17F
0005435715667	7112	27	18A
0005435715669	7112	28	18E
0005432400168	7112	29	19A
0005435715663	7112	30	19E
0005435715666	7112	31	20A
0005435715502	27065	1	2C
0005435715514	27065	2	3A
0005435715594	27065	3	3F
0005435715523	27065	4	4A
0005432398199	27065	5	4C
0005435715503	27065	6	4E
0005435443421	27065	7	5A
0005435178511	27065	8	5C
0005435443418	27065	9	6A
0005432398205	27065	10	7D
0005435715459	27065	11	7E
0005435715457	27065	12	8E
0005435443415	27065	13	8F
0005435443423	27065	14	9A
0005435715560	27065	15	9E
0005435715522	27065	16	10D
0005432398204	27065	17	11A
0005435715463	27065	18	11C
0005432394123	27065	19	12F
0005432398210	27065	20	14D
0005435178513	27065	21	14E
0005432394093	27065	22	15A
0005435178510	27065	23	15C
0005435715525	27065	24	15D
0005432394092	27065	25	15F
0005435715595	27065	26	16A
0005435178512	27065	27	16C
0005435443419	27065	28	16D
0005435443420	27065	29	16E
0005435715564	27065	30	17C
0005435715593	27065	31	17D
0005435443422	27065	32	17E
0005435715571	27065	33	18A
0005435443416	27065	34	18E
0005435715422	27065	35	19C
0005435443417	27065	36	19D
0005435715421	27065	37	19E
0005435715485	27065	38	20A
0005432394122	27065	39	20F
0005434084981	2760	1	1A
0005434084982	2760	2	3A
0005434084983	2760	3	5A
0005434084985	2760	4	5B
0005433060428	2760	5	6A
0005434084984	2760	6	6B
0005434084947	28520	1	1B
0005433060444	28520	2	2A
0005433060445	28520	3	2B
0005434084934	28520	4	3A
0005434084946	28520	5	3B
0005434084954	28520	6	4A
0005433060443	28520	7	4B
0005434084924	28520	8	5B
0005434084955	28520	9	6A
0005434084935	28520	10	6B
0005435541096	11416	1	1A
0005435517934	11416	2	1C
0005435518015	11416	3	1D
0005435517947	11416	4	1F
0005435517953	11416	5	2C
0005435518001	11416	6	3A
0005435541115	11416	7	3D
0005435541097	11416	8	3C
0005435541062	11416	9	3F
0005435541099	11416	10	4E
0005435518022	11416	11	5C
0005435517939	11416	12	5F
0005435517862	11416	13	6D
0005435541032	11416	14	6C
0005435541138	11416	15	6E
0005435517878	11416	16	7C
0005435541116	11416	17	7F
0005435540999	11416	18	8E
0005435517933	11416	19	8F
0005435540998	11416	20	9C
0005435517861	11416	21	9E
0005435517993	11416	22	9F
0005435541100	11416	23	10A
0005435517954	11416	24	10D
0005435518035	11416	25	11E
0005435541052	11416	26	12D
0005435541079	11416	27	12E
0005435541089	11416	28	13D
0005435517924	11416	29	13F
0005435541019	11416	30	15D
0005435517923	11416	31	15E
0005435541000	11416	32	15F
0005435541134	11416	33	16C
0005435541137	11416	34	16D
0005435517967	11416	35	16F
0005435518037	11416	36	17C
0005435517946	11416	37	17E
0005435540966	11416	38	17F
0005435541033	11416	39	18D
0005435541112	11416	40	18F
0005435517951	11416	41	19D
0005435541040	11416	42	19F
0005435541131	11416	43	20A
0005435541095	11416	44	20D
0005435517877	11416	45	20E
0005435541231	22272	1	1A
0005435541224	22272	2	1D
0005435529493	22272	3	1F
0005435529497	22272	4	2D
0005435529496	22272	5	3D
0005435529495	22272	6	3F
0005435541234	22272	7	4D
0005435529478	22272	8	5A
0005432294513	22272	9	5E
0005432294511	22272	10	5F
0005435541242	22272	11	6A
0005435541235	22272	12	6C
0005435541238	22272	13	6D
0005435529498	22272	14	6E
0005435529484	22272	15	6F
0005435529490	22272	16	7F
0005435529482	22272	17	8C
0005435529483	22272	18	8F
0005435541222	22272	19	9A
0005435529487	22272	20	9C
0005435541226	22272	21	9D
0005435541229	22272	22	9E
0005435529481	22272	23	10C
0005435529488	22272	24	10E
0005435529486	22272	25	11A
0005435529491	22272	26	11F
0005435541241	22272	27	12F
0005435529480	22272	28	13A
0005435541232	22272	29	13D
0005435529477	22272	30	13F
0005435529479	22272	31	14E
0005435529494	22272	32	14F
0005435541236	22272	33	15D
0005432294512	22272	34	15E
0005435541225	22272	35	16E
0005435529485	22272	36	16F
0005435541240	22272	37	17C
0005435541237	22272	38	17E
0005435541223	22272	39	17F
0005435529489	22272	40	18C
0005435541227	22272	41	18D
0005435529492	22272	42	18E
0005435541228	22272	43	19D
0005435541233	22272	44	19F
0005435541230	22272	45	20A
0005435541239	22272	46	20D
0005434907894	2284	1	1A
0005434907863	2284	2	1C
0005433251628	2284	3	1D
0005434907890	2284	4	1F
0005433251523	2284	5	2A
0005433251635	2284	6	2C
0005434907887	2284	7	2D
0005433251402	2284	8	2F
0005434907891	2284	9	3A
0005433251663	2284	10	3C
0005434907879	2284	11	3D
0005433251586	2284	12	3F
0005433251617	2284	13	4A
0005434907870	2284	14	4C
0005434907860	2284	15	4D
0005433251588	2284	16	4E
0005433251401	2284	17	4F
0005434907895	2284	18	5A
0005434907880	2284	19	5C
0005433251697	2284	20	5D
0005434907901	2284	21	5E
0005434907881	2284	22	5F
0005433251618	2284	23	6A
0005433251646	2284	24	6C
0005434907866	2284	25	6D
0005433251596	2284	26	6F
0005434907864	2284	27	7A
0005434907861	2284	28	7C
0005434907871	2284	29	7D
0005433400995	2284	30	7E
0005433251647	2284	31	7F
0005433400994	2284	32	8A
0005433251607	2284	33	8C
0005433251719	2284	34	8D
0005434907897	2284	35	8E
0005434907877	2284	36	8F
0005434907878	2284	37	9A
0005434907882	2284	38	9C
0005433251554	2284	39	9D
0005433251629	2284	40	9F
0005433251528	2284	41	10A
0005433251791	2284	42	10C
0005433251587	2284	43	10E
0005434907885	2284	44	10F
0005434907903	2284	45	11A
0005434907893	2284	46	11C
0005433251539	2284	47	11D
0005433251636	2284	48	11E
0005434907889	2284	49	11F
0005434907896	2284	50	12A
0005434907869	2284	51	12C
0005434907865	2284	52	12D
0005433251560	2284	53	12E
0005434907900	2284	54	13C
0005433251566	2284	55	13D
0005433251473	2284	56	13E
0005433251604	2284	57	13F
0005433251790	2284	58	14A
0005434907862	2284	59	14C
0005433251684	2284	60	14D
0005434907892	2284	61	14E
0005433251529	2284	62	15A
0005434907874	2284	63	15C
0005434907898	2284	64	15D
0005433251608	2284	65	15E
0005433251720	2284	66	16A
0005434907875	2284	67	16D
0005434907867	2284	68	16C
0005434907859	2284	69	16E
0005433251613	2284	70	17A
0005434907899	2284	71	17C
0005433251475	2284	72	17D
0005433251545	2284	73	17E
0005434907886	2284	74	17F
0005434907873	2284	75	18A
0005434907858	2284	76	18C
0005434907902	2284	77	18D
0005434907876	2284	78	18E
0005434907884	2284	79	18F
0005434907883	2284	80	19A
0005434907888	2284	81	19C
0005434907872	2284	82	19D
0005433251507	2284	83	19E
0005433251648	2284	84	19F
0005434907868	2284	85	20A
0005433251555	2284	86	20C
0005433251474	2284	87	20D
0005433400989	2284	88	20F
0005434907408	25631	1	1A
0005434907302	25631	2	1C
0005434907334	25631	3	1D
0005434907314	25631	4	1F
0005433401016	25631	5	2A
0005434907316	25631	6	2C
0005433251832	25631	7	2D
0005434907301	25631	8	3A
0005434907345	25631	9	3C
0005434907227	25631	10	3D
0005434907244	25631	11	3F
0005433251838	25631	12	4A
0005433251824	25631	13	4C
0005433251822	25631	14	4D
0005434907266	25631	15	4E
0005434907175	25631	16	4F
0005433251821	25631	17	5A
0005434907442	25631	18	5C
0005434907425	25631	19	5D
0005434907445	25631	20	5E
0005434907386	25631	21	5F
0005434907433	25631	22	6A
0005434907381	25631	23	6C
0005433251830	25631	24	6D
0005433251843	25631	25	6E
0005434907217	25631	26	6F
0005433251813	25631	27	7A
0005434907401	25631	28	7C
0005434907248	25631	29	7D
0005434907373	25631	30	7E
0005433251831	25631	31	7F
0005433251820	25631	32	8A
0005433251825	25631	33	8C
0005433251817	25631	34	8D
0005434907249	25631	35	8E
0005433251842	25631	36	8F
0005434907379	25631	37	9A
0005434907174	25631	38	9C
0005434907374	25631	39	9D
0005434907429	25631	40	9E
0005434907412	25631	41	9F
0005434907318	25631	42	10A
0005433251837	25631	43	10C
0005434907176	25631	44	10D
0005434907370	25631	45	10E
0005433251834	25631	46	10F
0005434907366	25631	47	11A
0005433251828	25631	48	11C
0005434907268	25631	49	11D
0005433251826	25631	50	11E
0005433251840	25631	51	11F
0005433251812	25631	52	12A
0005433251839	25631	53	12C
0005433251827	25631	54	12D
0005434907395	25631	55	12E
0005433251818	25631	56	12F
0005434907245	25631	57	13C
0005434907387	25631	58	13D
0005433251823	25631	59	13E
0005433251819	25631	60	13F
0005434907391	25631	61	14A
0005434907322	25631	62	14C
0005434907402	25631	63	14D
0005433401017	25631	64	14E
0005434907294	25631	65	14F
0005433251816	25631	66	15A
0005434907285	25631	67	15C
0005433401018	25631	68	15D
0005434907413	25631	69	15E
0005433251815	25631	70	15F
0005434907342	25631	71	16A
0005434907327	25631	72	16C
0005434907371	25631	73	16D
0005434907380	25631	74	16F
0005434907434	25631	75	17A
0005434907382	25631	76	17C
0005433251814	25631	77	17D
0005433251833	25631	78	17E
0005434907274	25631	79	17F
0005434907390	25631	80	18A
0005434907224	25631	81	18C
0005434907303	25631	82	18D
0005434907424	25631	83	18E
0005433251836	25631	84	18F
0005434907349	25631	85	19A
0005434907444	25631	86	19C
0005434907343	25631	87	19D
0005433251829	25631	88	19E
0005433251835	25631	89	19F
0005433251841	25631	90	20A
0005434907265	25631	91	20C
0005434907228	25631	92	20D
0005434907293	25631	93	20E
0005434907298	25631	94	20F
0005432621192	2538	1	1B
0005432862318	2538	2	2A
0005432621194	2538	3	2B
0005432621195	2538	4	2D
0005432862337	2538	5	3A
0005432862317	2538	6	4B
0005432862336	2538	7	5B
0005432621205	2538	8	6C
0005432621196	2538	9	6D
0005432621191	2538	10	7A
0005432621202	2538	11	7D
0005432621197	2538	12	18B
0005432621198	2538	13	20A
0005432621193	2538	14	20D
0005432621204	2538	15	21A
0005432862338	2538	16	21C
0005432621200	2538	17	22B
0005432621203	2538	18	22A
0005432621201	2538	19	22C
0005432621199	2538	20	23B
0005432862387	28090	1	2B
0005432862394	28090	2	3B
0005432862389	28090	3	4A
0005432621112	28090	4	5A
0005432862390	28090	5	7B
0005432862392	28090	6	18A
0005432621082	28090	7	18C
0005432621071	28090	8	18D
0005432621118	28090	9	19B
0005432621083	28090	10	20C
0005432862391	28090	11	20D
0005432621081	28090	12	21D
0005432621068	28090	13	22A
0005432862388	28090	14	22C
0005432862393	28090	15	22D
0005432862386	28090	16	23B
0005434097475	11746	1	1B
0005434097474	11746	2	5A
0005434097478	11746	3	5B
0005434097492	13103	1	3B
0005434097491	13103	2	5A
0005434191264	32870	1	1F
0005434191282	32870	2	5A
0005434191265	32870	3	5D
0005434191279	32870	4	6C
0005434191274	32870	5	6D
0005434191283	32870	6	6F
0005434191268	32870	7	7D
0005434191278	32870	8	7E
0005434191277	32870	9	7F
0005434191271	32870	10	8C
0005434191273	32870	11	12E
0005434191284	32870	12	14F
0005434191276	32870	13	15F
0005434191263	32870	14	18A
0005434191275	32870	15	19D
0005433451640	31052	1	2B
0005433451641	31052	2	3A
0005433451642	31052	3	4A
0005433452763	31052	4	4B
0005433452762	31052	5	6A
0005433452732	31451	1	3A
0005433454883	31451	2	3B
0005433454884	31451	3	5A
0005433452731	31451	4	6A
0005433134146	12009	1	1C
0005433129292	12009	2	2D
0005433134117	12009	3	3B
0005433129294	12009	4	5B
0005433129293	12009	5	5D
0005434142609	12009	6	6A
0005433134118	12009	7	18B
0005433129298	12009	8	18D
0005433134145	12009	9	20B
0005433134140	12009	10	22C
0005433129297	12009	11	23B
0005434184688	29866	1	2A
0005434183603	29866	2	2B
0005433134189	29866	3	3C
0005434183602	29866	4	3D
0005433134188	29866	5	4B
0005433131760	29866	6	4D
0005434142650	29866	7	5C
0005434142653	29866	8	5D
0005433131759	29866	9	6A
0005433131758	29866	10	7A
0005434142651	29866	11	18A
0005434142652	29866	12	18B
0005433134191	29866	13	19B
0005433131761	29866	14	20D
0005433134190	29866	15	21B
0005435798968	1610	1	1C
0005435798965	1610	2	3A
0005435798973	1610	3	3B
0005435798971	1610	4	4B
0005435798961	1610	5	5A
0005435798970	1610	6	5B
0005435798962	1610	7	18A
0005435798964	1610	8	18C
0005435798972	1610	9	19C
0005435798976	1610	10	20C
0005435798963	1610	11	21A
0005435798967	1610	12	21C
0005435798974	1610	13	21D
0005435798966	1610	14	22A
0005435798969	1610	15	22B
0005435798977	1610	16	22D
0005435798975	1610	17	23A
0005435697619	16475	1	1A
0005435697640	16475	2	1D
0005435697633	16475	3	2B
0005435697634	16475	4	2C
0005435697631	16475	5	2D
0005435697637	16475	6	3A
0005435697632	16475	7	3B
0005435697641	16475	8	3C
0005435697635	16475	9	3D
0005435697645	16475	10	4A
0005435697636	16475	11	4D
0005435697628	16475	12	5A
0005435697627	16475	13	5C
0005435697622	16475	14	5D
0005435697643	16475	15	6A
0005435935058	16475	16	6B
0005435697629	16475	17	6D
0005435697646	16475	18	7A
0005435697639	16475	19	7B
0005435697630	16475	20	7C
0005435697642	16475	21	7D
0005435697623	16475	22	18A
0005435697638	16475	23	18B
0005435697618	16475	24	19A
0005435697644	16475	25	20B
0005435697624	16475	26	20C
0005435697625	16475	27	21B
0005435935061	16475	28	21C
0005435697620	16475	29	21D
0005435697626	16475	30	22C
0005435697621	16475	31	23A
0005435697503	24739	1	1D
0005435935082	24739	2	2B
0005435697419	24739	3	2C
0005435697430	24739	4	3A
0005435697484	24739	5	3B
0005435697276	24739	6	4A
0005435697473	24739	7	5A
0005435697402	24739	8	5D
0005435697438	24739	9	7B
0005435697483	24739	10	18A
0005435935081	24739	11	18D
0005435697426	24739	12	19A
0005435697464	24739	13	19B
0005435697502	24739	14	20B
0005435697425	24739	15	20C
0005435697439	24739	16	20D
0005435935080	24739	17	21C
0005435935083	24739	18	23B
0005433724854	18802	1	1A
0005433724851	18802	2	3A
0005433724852	18802	3	5A
0005433724853	18802	4	6A
0005433724855	18802	5	6B
0005433724820	21597	1	1A
0005432968869	21597	2	2A
0005433724819	21597	3	1B
0005433724818	21597	4	2B
0005432968868	21597	5	3A
0005433724838	21597	6	4B
0005433724826	21597	7	5A
0005432968867	21597	8	5B
0005434139127	7349	1	1A
0005434139126	7349	2	1C
0005434139102	7349	3	1D
0005434139108	7349	4	1F
0005434139049	7349	5	2A
0005434087568	7349	6	2C
0005434139090	7349	7	2D
0005434139124	7349	8	2F
0005434139092	7349	9	3A
0005434139110	7349	10	3C
0005434139117	7349	11	3D
0005434139052	7349	12	3F
0005434139048	7349	13	4A
0005434139113	7349	14	4C
0005434087570	7349	15	4D
0005434139125	7349	16	4E
0005434139129	7349	17	4F
0005434139101	7349	18	5A
0005434087567	7349	19	5C
0005434139112	7349	20	5D
0005434139089	7349	21	5E
0005434139068	7349	22	5F
0005434139075	7349	23	6A
0005434139059	7349	24	6C
0005434139081	7349	25	6D
0005434139087	7349	26	6E
0005434139107	7349	27	6F
0005434139053	7349	28	7A
0005434139056	7349	29	7C
0005434139095	7349	30	7D
0005434139100	7349	31	7E
0005434139069	7349	32	7F
0005434139050	7349	33	8A
0005434139064	7349	34	8C
0005434139128	7349	35	8D
0005434139106	7349	36	8E
0005434139079	7349	37	8F
0005434139062	7349	38	9C
0005434139078	7349	39	9A
0005434139077	7349	40	9D
0005434139088	7349	41	9E
0005434139074	7349	42	9F
0005434139097	7349	43	10C
0005434139065	7349	44	10E
0005434139105	7349	45	10F
0005434139058	7349	46	11A
0005434139055	7349	47	11C
0005434139070	7349	48	11D
0005434139123	7349	49	11E
0005434139083	7349	50	12A
0005434139118	7349	51	12C
0005434139085	7349	52	12D
0005434139054	7349	53	12E
0005434139073	7349	54	12F
0005434139091	7349	55	13A
0005434139115	7349	56	13C
0005434087569	7349	57	13E
0005434139084	7349	58	13F
0005434139072	7349	59	14A
0005434139066	7349	60	14C
0005434139057	7349	61	14D
0005434139061	7349	62	14E
0005434139104	7349	63	14F
0005434139063	7349	64	15A
0005434139120	7349	65	15C
0005434139086	7349	66	15D
0005434139060	7349	67	15E
0005434139080	7349	68	15F
0005434139122	7349	69	16A
0005434139093	7349	70	16C
0005434139116	7349	71	16D
0005434139103	7349	72	16F
0005434139076	7349	73	16E
0005434139094	7349	74	17A
0005434139099	7349	75	17C
0005434139067	7349	76	17D
0005434139111	7349	77	17E
0005434139121	7349	78	17F
0005434139096	7349	79	18A
0005434087571	7349	80	18C
0005434139098	7349	81	18D
0005434139051	7349	82	18E
0005434139071	7349	83	19C
0005434139109	7349	84	19E
0005434139082	7349	85	20A
0005434139114	7349	86	20C
0005434139119	7349	87	20D
0005434138148	28573	1	1A
0005434138318	28573	2	1C
0005434138392	28573	3	1D
0005434138444	28573	4	1F
0005434138277	28573	5	2A
0005434138540	28573	6	2C
0005434138588	28573	7	2D
0005434138149	28573	8	3A
0005434138557	28573	9	3C
0005434138711	28573	10	3D
0005434138269	28573	11	3F
0005434138282	28573	12	4A
0005434138541	28573	13	4C
0005434138430	28573	14	4D
0005434137978	28573	15	4E
0005434138416	28573	16	4F
0005434138074	28573	17	5A
0005434138458	28573	18	5D
0005434138469	28573	19	5E
0005434138267	28573	20	5F
0005434138119	28573	21	6A
0005434138102	28573	22	6C
0005434138370	28573	23	6E
0005434138114	28573	24	6F
0005434138558	28573	25	7A
0005434138455	28573	26	7C
0005434138167	28573	27	7D
0005434138693	28573	28	7F
0005434138272	28573	29	8A
0005434138429	28573	30	8C
0005434138278	28573	31	9C
0005434138494	28573	32	9D
0005434138160	28573	33	9E
0005434087510	28573	34	9F
0005434137898	28573	35	10A
0005434138342	28573	36	10C
0005434138638	28573	37	10D
0005434137966	28573	38	10E
0005434138168	28573	39	10F
0005434138281	28573	40	11A
0005434138383	28573	41	11C
0005434138304	28573	42	11D
0005434138542	28573	43	11E
0005434137970	28573	44	11F
0005434138317	28573	45	12A
0005434138352	28573	46	12C
0005434138159	28573	47	12D
0005434138284	28573	48	12E
0005434138268	28573	49	12F
0005434138699	28573	50	13A
0005434087532	28573	51	13C
0005434138266	28573	52	13D
0005434087531	28573	53	13E
0005434138080	28573	54	13F
0005434138431	28573	55	14A
0005434138283	28573	56	14C
0005434138394	28573	57	14D
0005434138273	28573	58	14E
0005434138064	28573	59	14F
0005434138428	28573	60	15A
0005434138488	28573	61	15C
0005434138186	28573	62	15D
0005434138351	28573	63	15E
0005434137872	28573	64	15F
0005434138493	28573	65	16A
0005434138539	28573	66	16C
0005434137926	28573	67	16D
0005434138371	28573	68	16E
0005434137895	28573	69	16F
0005434138468	28573	70	17A
0005434138445	28573	71	17C
0005434138694	28573	72	17D
0005434138710	28573	73	17E
0005434138414	28573	74	17F
0005434087536	28573	75	18A
0005434138252	28573	76	18C
0005434087509	28573	77	18D
0005434138227	28573	78	18E
0005434138308	28573	79	18F
0005434138198	28573	80	19A
0005434138589	28573	81	19D
0005434138316	28573	82	19E
0005434138253	28573	83	19F
0005434138435	28573	84	20A
0005434138442	28573	85	20C
0005434138509	28573	86	20D
0005434138350	28573	87	20F
0005435808356	1916	1	1A
0005433407581	1916	2	1C
0005433407580	1916	3	2A
0005435808358	1916	4	2B
0005433407564	1916	5	2C
0005434610270	1916	6	3D
0005435808354	1916	7	4A
0005435808359	1916	8	4D
0005434610269	1916	9	5A
0005434610271	1916	10	5C
0005435808351	1916	11	5D
0005435808352	1916	12	6B
0005435808348	1916	13	6C
0005435808350	1916	14	7D
0005433407585	1916	15	18C
0005433407572	1916	16	18D
0005433407584	1916	17	20C
0005435808355	1916	18	21B
0005435808349	1916	19	21C
0005435808353	1916	20	22C
0005435808357	1916	21	23B
0005434610252	23106	1	3C
0005434610233	23106	2	18D
0005434610235	23106	3	22B
0005434610234	23106	4	22C
0005434504320	16705	1	1C
0005434504345	16705	2	1D
0005434504132	16705	3	2A
0005434504319	16705	4	2B
0005434504292	16705	5	2C
0005434504258	16705	6	3A
0005434504306	16705	7	3C
0005434504327	16705	8	3D
0005434504324	16705	9	4A
0005434504133	16705	10	4D
0005434504159	16705	11	5C
0005434504323	16705	12	5D
0005434504169	16705	13	6B
0005434504117	16705	14	6C
0005434504138	16705	15	6D
0005434504354	16705	16	7B
0005434504107	16705	17	7A
0005434504158	16705	18	7C
0005434504229	16705	19	18C
0005434504118	16705	20	18D
0005434503996	16705	21	19A
0005434504200	16705	22	19D
0005434504246	16705	23	20B
0005434504111	16705	24	20C
0005434504228	16705	25	20D
0005434504253	16705	26	21A
0005434504366	16705	27	21C
0005434503997	16705	28	21D
0005434504191	16705	29	22C
0005434504168	16705	30	22D
0005434504058	16705	31	23A
0005434504182	16705	32	23B
0005434504568	22880	1	1A
0005434504562	22880	2	1B
0005434504565	22880	3	1C
0005434504567	22880	4	2A
0005434504560	22880	5	2C
0005434504580	22880	6	2D
0005434504569	22880	7	3A
0005434504576	22880	8	3B
0005434504553	22880	9	3C
0005434504570	22880	10	4A
0005434504549	22880	11	4C
0005434504566	22880	12	5A
0005434504546	22880	13	5B
0005434504579	22880	14	5C
0005434504559	22880	15	5D
0005434504572	22880	16	6B
0005434504571	22880	17	6C
0005434504556	22880	18	6D
0005434504577	22880	19	7A
0005434504581	22880	20	7B
0005434504561	22880	21	7D
0005434504550	22880	22	18A
0005434504564	22880	23	18D
0005434504563	22880	24	19A
0005434504578	22880	25	19B
0005434504551	22880	26	19C
0005434504575	22880	27	20A
0005434504548	22880	28	20B
0005434504555	22880	29	20D
0005434504552	22880	30	21C
0005434504558	22880	31	21D
0005434504547	22880	32	22B
0005434504554	22880	33	22A
0005434504574	22880	34	22C
0005434504557	22880	35	22D
0005434504573	22880	36	23A
0005434608349	6500	1	1B
0005434608352	6500	2	2A
0005434608353	6500	3	3B
0005434608341	6500	4	4B
0005434608356	6500	5	5A
0005434608347	6500	6	5D
0005434608351	6500	7	7A
0005434608346	6500	8	7B
0005434608339	6500	9	7D
0005434608340	6500	10	18A
0005434608348	6500	11	19A
0005434608344	6500	12	19B
0005434608355	6500	13	20B
0005434608350	6500	14	20C
0005434608345	6500	15	21A
0005434608342	6500	16	21B
0005434608354	6500	17	22A
0005434608343	6500	18	22C
0005434608357	6500	19	23A
0005434608316	22499	1	1A
0005434608310	22499	2	1D
0005434608333	22499	3	2A
0005434608336	22499	4	2B
0005434608331	22499	5	2C
0005434608317	22499	6	3B
0005434608321	22499	7	3C
0005434608301	22499	8	3D
0005434608302	22499	9	4B
0005434608320	22499	10	5A
0005434608307	22499	11	5B
0005434608306	22499	12	6D
0005434608309	22499	13	7A
0005434608323	22499	14	7B
0005434608303	22499	15	7D
0005434608308	22499	16	18B
0005434608322	22499	17	18C
0005434608313	22499	18	19B
0005434608335	22499	19	19C
0005434608329	22499	20	20D
0005434608312	22499	21	21B
0005434608311	22499	22	23B
0005435078517	2225	1	1D
0005433266740	2225	2	3A
0005435078519	2225	3	3C
0005433266742	2225	4	3D
0005435078524	2225	5	4B
0005435078525	2225	6	4D
0005435078512	2225	7	5B
0005435078516	2225	8	5D
0005433266783	2225	9	6C
0005435078513	2225	10	6D
0005435078514	2225	11	7B
0005433266675	2225	12	7D
0005435078523	2225	13	18A
0005433266741	2225	14	18D
0005435078515	2225	15	19C
0005435078521	2225	16	20C
0005435078511	2225	17	20D
0005435078520	2225	18	21B
0005435078518	2225	19	21C
0005435078522	2225	20	21D
0005433266731	2225	21	23A
0005435078337	24344	1	1B
0005435078392	24344	2	2A
0005433266832	24344	3	2B
0005435078398	24344	4	2D
0005435078399	24344	5	4A
0005435078391	24344	6	4C
0005433266827	24344	7	4D
0005435078294	24344	8	5A
0005433266828	24344	9	5B
0005435078293	24344	10	5C
0005435078343	24344	11	5D
0005433266829	24344	12	6C
0005433266825	24344	13	7A
0005435078400	24344	14	7B
0005435078387	24344	15	7C
0005433266826	24344	16	7D
0005433266831	24344	17	18B
0005435078372	24344	18	18D
0005435078429	24344	19	19A
0005435078356	24344	20	19C
0005435078240	24344	21	20B
0005435078338	24344	22	20C
0005433266824	24344	23	21A
0005435078334	24344	24	22A
0005435078335	24344	25	22B
0005435078357	24344	26	22C
0005435078396	24344	27	22D
0005433266830	24344	28	23A
0005435078397	24344	29	23B
0005435464511	6656	1	1A
0005434988866	6656	2	1B
0005435464522	6656	3	1D
0005434988861	6656	4	2A
0005434988864	6656	5	2B
0005434988869	6656	6	2C
0005434988865	6656	7	3A
0005434988870	6656	8	3B
0005435464510	6656	9	4B
0005434988863	6656	10	4C
0005434988859	6656	11	5A
0005435803294	6656	12	6C
0005435803293	6656	13	18C
0005435464512	6656	14	19D
0005434988862	6656	15	20A
0005434988867	6656	16	20B
0005434988860	6656	17	20D
0005435803292	6656	18	21D
0005435464523	6656	19	22C
0005434988868	6656	20	22D
0005434988728	23631	1	1A
0005434988734	23631	2	1B
0005435803271	23631	3	2B
0005434988740	23631	4	2D
0005434988706	23631	5	3A
0005434988711	23631	6	3C
0005435464531	23631	7	5A
0005434988705	23631	8	5D
0005434988738	23631	9	6A
0005434988712	23631	10	19A
0005434988756	23631	11	19C
0005434988750	23631	12	19D
0005435464532	23631	13	20B
0005434988710	23631	14	21B
0005434988721	23631	15	21C
0005435464530	23631	16	21D
0005434988718	23631	17	22B
0005434988744	23631	18	22C
0005434988739	23631	19	22D
0005433450209	30465	1	1A
0005432383627	30465	2	1F
0005433450210	30465	3	2D
0005433450222	30465	4	2F
0005432383612	30465	5	3A
0005432383610	30465	6	3C
0005432383611	30465	7	4A
0005432383620	30465	8	4C
0005432383621	30465	9	4D
0005432383616	30465	10	4F
0005433450217	30465	11	5D
0005433450215	30465	12	5F
0005432383637	30465	13	6D
0005432383635	30465	14	6E
0005432383634	30465	15	6F
0005432383629	30465	16	7A
0005433450223	30465	17	8A
0005433453783	30465	18	8C
0005433450226	30465	19	8E
0005433450213	30465	20	9A
0005433450225	30465	21	9F
0005432383636	30465	22	10A
0005433450207	30465	23	10C
0005432383632	30465	24	10E
0005432383623	30465	25	10F
0005432383630	30465	26	11A
0005433450221	30465	27	11D
0005433453782	30465	28	11F
0005433450220	30465	29	12A
0005433450214	30465	30	12D
0005432383626	30465	31	12E
0005433454900	30465	32	12F
0005432383631	30465	33	13A
0005432383618	30465	34	13C
0005432383625	30465	35	13D
0005432383628	30465	36	13E
0005433453784	30465	37	13F
0005433454899	30465	38	14A
0005432383624	30465	39	14C
0005432383609	30465	40	14D
0005432383617	30465	41	14E
0005432383614	30465	42	15C
0005432383633	30465	43	15D
0005432383619	30465	44	15E
0005433450211	30465	45	15F
0005433450216	30465	46	16A
0005433450212	30465	47	16E
0005432383615	30465	48	16F
0005433450219	30465	49	17D
0005432383613	30465	50	18A
0005432383638	30465	51	18D
0005433450218	30465	52	19C
0005433450208	30465	53	20A
0005433450224	30465	54	20C
0005433450228	30465	55	20D
0005433450227	30465	56	20E
0005432383622	30465	57	20F
0005432383116	31297	1	1A
0005433450095	31297	2	1C
0005432383100	31297	3	1D
0005432383239	31297	4	2A
0005432383278	31297	5	2C
0005433450051	31297	6	2D
0005433450059	31297	7	2F
0005432383311	31297	8	3A
0005432383198	31297	9	3D
0005432383170	31297	10	3F
0005432382996	31297	11	4C
0005432383243	31297	12	4D
0005433449960	31297	13	4E
0005432383132	31297	14	5A
0005432383306	31297	15	5C
0005433450157	31297	16	5D
0005433450020	31297	17	6A
0005433450018	31297	18	5F
0005433449896	31297	19	6C
0005433450039	31297	20	6D
0005433450077	31297	21	6E
0005433450064	31297	22	6F
0005432383084	31297	23	7A
0005432383043	31297	24	7C
0005433450073	31297	25	7D
0005432383242	31297	26	7E
0005432383154	31297	27	7F
0005432383183	31297	28	8A
0005433453763	31297	29	8C
0005433450008	31297	30	8D
0005432383148	31297	31	8E
0005432383164	31297	32	8F
0005433450058	31297	33	9A
0005432383276	31297	34	9C
0005432383153	31297	35	9D
0005432383191	31297	36	9E
0005433450050	31297	37	10A
0005432383237	31297	38	10C
0005433450049	31297	39	10D
0005432383099	31297	40	10F
0005432383147	31297	41	11A
0005432383121	31297	42	11C
0005433451632	31297	43	11D
0005432383238	31297	44	11E
0005433449979	31297	45	11F
0005432383117	31297	46	12A
0005433450094	31297	47	12C
0005433451631	31297	48	12E
0005432383096	31297	49	12F
0005433450135	31297	50	13A
0005432383268	31297	51	13C
0005433450009	31297	52	13D
0005432383241	31297	53	13E
0005432383202	31297	54	13F
0005433450158	31297	55	14C
0005433450042	31297	56	14E
0005432383269	31297	57	15A
0005432383277	31297	58	14F
0005433450154	31297	59	15D
0005432383150	31297	60	15E
0005433450072	31297	61	15F
0005432383203	31297	62	16A
0005432383149	31297	63	16C
0005432383260	31297	64	16E
0005432383152	31297	65	16F
0005432383312	31297	66	17A
0005432383042	31297	67	17D
0005433450028	31297	68	17E
0005433450019	31297	69	17F
0005432383016	31297	70	18A
0005433449957	31297	71	18C
0005432383232	31297	72	18D
0005433453762	31297	73	18E
0005433450014	31297	74	18F
0005433449895	31297	75	19C
0005432383264	31297	76	19D
0005433450017	31297	77	19E
0005432383171	31297	78	19F
0005433450000	31297	79	20C
0005432383095	31297	80	20D
0005432382995	31297	81	20E
0005433450104	31297	82	20F
0005433788244	20824	1	1D
0005435548476	20824	2	2A
0005433788235	20824	3	2B
0005435548484	20824	4	2C
0005435548489	20824	5	2D
0005435548485	20824	6	3A
0005435548471	20824	7	3C
0005435548473	20824	8	4B
0005435548478	20824	9	4C
0005435548490	20824	10	5A
0005433788236	20824	11	5B
0005433788237	20824	12	6C
0005433788246	20824	13	7A
0005433788243	20824	14	7C
0005433788247	20824	15	18A
0005435548459	20824	16	18D
0005435548492	20824	17	19B
0005435548493	20824	18	19C
0005433788241	20824	19	19D
0005433788248	20824	20	20A
0005435548477	20824	21	20B
0005433788242	20824	22	20C
0005433788240	20824	23	20D
0005435548472	20824	24	21A
0005435548488	20824	25	21B
0005435548463	20824	26	21C
0005433788238	20824	27	22B
0005435548475	20824	28	22C
0005433788239	20824	29	23A
0005433788245	20824	30	23B
0005433126853	10757	1	1B
0005435299784	10757	2	2B
0005433126829	10757	3	3D
0005433131701	10757	4	4A
0005435299785	10757	5	5B
0005433131705	10757	6	5D
0005435304156	10757	7	7C
0005433126852	10757	8	18A
0005435304183	10757	9	18B
0005433126854	10757	10	18D
0005433131702	10757	11	19A
0005435304164	10757	12	20B
0005435299781	10757	13	20C
0005435304155	10757	14	21C
0005435299771	10757	15	21D
0005435304182	10757	16	22B
0005433131696	10757	17	22C
0005435299770	10757	18	23B
0005433129334	29723	1	1A
0005435302255	29723	2	1B
0005435299834	29723	3	1C
0005433126900	29723	4	1D
0005435299833	29723	5	2D
0005435299835	29723	6	4A
0005435302256	29723	7	5A
0005435299832	29723	8	5C
0005435299836	29723	9	6B
0005433126901	29723	10	7A
0005435302258	29723	11	7D
0005433126902	29723	12	18A
0005433126899	29723	13	18B
0005435302257	29723	14	18C
0005435302254	29723	15	18D
0005433129330	29723	16	19B
0005433129332	29723	17	19D
0005433129331	29723	18	21D
0005433129333	29723	19	22A
0005434287537	2410	1	1B
0005433110117	2410	2	1C
0005434287541	2410	3	1D
0005434287548	2410	4	2A
0005434287538	2410	5	2B
0005433110050	2410	6	2C
0005433110068	2410	7	3A
0005432264503	2410	8	3B
0005433110112	2410	9	3C
0005434287550	2410	10	3D
0005433110113	2410	11	4B
0005434287545	2410	12	4C
0005432264502	2410	13	4D
0005434287534	2410	14	5C
0005434287551	2410	15	6A
0005434287532	2410	16	6B
0005434287542	2410	17	6C
0005434287529	2410	18	6D
0005433110052	2410	19	7A
0005434287552	2410	20	7B
0005434287531	2410	21	7C
0005433110065	2410	22	18A
0005434287533	2410	23	18B
0005433110066	2410	24	18C
0005434287543	2410	25	18D
0005434287535	2410	26	19A
0005434287539	2410	27	19B
0005434287549	2410	28	19C
0005434287530	2410	29	20A
0005434287546	2410	30	20C
0005433110089	2410	31	20D
0005434287540	2410	32	21C
0005434287536	2410	33	22A
0005434287547	2410	34	22C
0005434287544	2410	35	22D
0005432264504	2410	36	23B
0005433110188	26822	1	1A
0005433110196	26822	2	1B
0005434287344	26822	3	1C
0005434287434	26822	4	1D
0005434287347	26822	5	2B
0005433110186	26822	6	3B
0005433110184	26822	7	3C
0005433110192	26822	8	3D
0005434287473	26822	9	4A
0005434287468	26822	10	4B
0005434287352	26822	11	4C
0005433110193	26822	12	5B
0005433110194	26822	13	5C
0005434287339	26822	14	5D
0005433110185	26822	15	6A
0005434287376	26822	16	6B
0005434287380	26822	17	6C
0005434287242	26822	18	6D
0005434287262	26822	19	7B
0005434287411	26822	20	7C
0005434287345	26822	21	18A
0005434287418	26822	22	18B
0005434287377	26822	23	18C
0005434287340	26822	24	18D
0005434287346	26822	25	19A
0005434287343	26822	26	19C
0005434287382	26822	27	19D
0005434287282	26822	28	20A
0005434287338	26822	29	20C
0005433110190	26822	30	20D
0005434287433	26822	31	21B
0005434287383	26822	32	21D
0005434287261	26822	33	22A
0005433110191	26822	34	22B
0005433110195	26822	35	22C
0005433110189	26822	36	22D
0005433110187	26822	37	23A
0005434287381	26822	38	23B
0005434272197	25471	1	4A
0005435856251	25471	2	4B
0005434269110	25471	3	4C
0005435856252	25471	4	5B
0005435856254	25471	5	7C
0005435856253	25471	6	19D
0005434272195	25471	7	20A
0005434269106	25471	8	20D
0005435856250	25471	9	21D
0005434272196	25471	10	22D
0005435856202	26633	1	1B
0005435856209	26633	2	1C
0005435856208	26633	3	3D
0005434273095	26633	4	5C
0005434272210	26633	5	6B
0005434273096	26633	6	18A
0005435856203	26633	7	18B
0005435314880	19085	1	1C
0005434520253	19085	2	1D
0005434520270	19085	3	2A
0005434520287	19085	4	2C
0005435314876	19085	5	2D
0005434520268	19085	6	3C
0005435314881	19085	7	3D
0005434520279	19085	8	4A
0005434520276	19085	9	4B
0005435314882	19085	10	4C
0005434520273	19085	11	4D
0005435314883	19085	12	5B
0005434520246	19085	13	5C
0005435314877	19085	14	5D
0005434520226	19085	15	6A
0005434520301	19085	16	6B
0005434520267	19085	17	6C
0005434520280	19085	18	6D
0005435314878	19085	19	7A
0005434520290	19085	20	7B
0005434520225	19085	21	7C
0005435314879	19085	22	7D
0005434520281	19085	23	18B
0005434520254	19085	24	18C
0005434520266	19085	25	18D
0005434520271	19085	26	19A
0005434520324	19085	27	19B
0005434520288	19085	28	19D
0005434520302	19085	29	20B
0005435314875	19085	30	20C
0005434520300	19085	31	20D
0005435314874	19085	32	21A
0005434520269	19085	33	21D
0005434520299	19085	34	22A
0005434520316	19085	35	22D
0005434520303	19085	36	23B
0005433874390	7783	1	1A
0005433874394	7783	2	4C
0005433874384	7783	3	5C
0005433874395	7783	4	6B
0005433874386	7783	5	7A
0005433874392	7783	6	7B
0005433874387	7783	7	18B
0005433874389	7783	8	18C
0005433874393	7783	9	19B
0005433874391	7783	10	20D
0005433874388	7783	11	21C
0005433874385	7783	12	22A
0005433874357	32634	1	3A
0005433874353	32634	2	3D
0005433874356	32634	3	4B
0005433874364	32634	4	5A
0005433874344	32634	5	5B
0005433874363	32634	6	6B
0005433874338	32634	7	18A
0005433874339	32634	8	19B
0005433874345	32634	9	19D
0005433874343	32634	10	20A
0005433874346	32634	11	20B
0005433874354	32634	12	20C
0005433868905	4793	1	1A
0005433868885	4793	2	1B
0005433868906	4793	3	1C
0005433868903	4793	4	1D
0005433868914	4793	5	2B
0005433868878	4793	6	2C
0005433868904	4793	7	2D
0005433868879	4793	8	3A
0005433868889	4793	9	3B
0005433868901	4793	10	3C
0005433868894	4793	11	3D
0005433868881	4793	12	4B
0005433868900	4793	13	4C
0005433868916	4793	14	4D
0005433868910	4793	15	5B
0005433868895	4793	16	5C
0005433868880	4793	17	5D
0005433868888	4793	18	6A
0005433868911	4793	19	6B
0005433868891	4793	20	6C
0005433868882	4793	21	7B
0005433868899	4793	22	7C
0005435860486	4793	23	7D
0005433868897	4793	24	18A
0005433868915	4793	25	18B
0005435860487	4793	26	18C
0005433868892	4793	27	19A
0005433868908	4793	28	19C
0005433868886	4793	29	19D
0005433868909	4793	30	20B
0005433868898	4793	31	20C
0005433868907	4793	32	20D
0005433868893	4793	33	21A
0005433868884	4793	34	21C
0005433868887	4793	35	21D
0005433868896	4793	36	22A
0005433868902	4793	37	22C
0005433868913	4793	38	22B
0005433868890	4793	39	22D
0005433868912	4793	40	23A
0005433868883	4793	41	23B
0005433868568	32611	1	1A
0005433868627	32611	2	2A
0005435860517	32611	3	2B
0005433868538	32611	4	2C
0005435860518	32611	5	2D
0005433868527	32611	6	3A
0005433868742	32611	7	3B
0005433868567	32611	8	3C
0005435860516	32611	9	3D
0005433868630	32611	10	4A
0005433868493	32611	11	4B
0005433868414	32611	12	4C
0005433868564	32611	13	5A
0005433868619	32611	14	5B
0005433868703	32611	15	5C
0005433868415	32611	16	6A
0005433868631	32611	17	6B
0005433868448	32611	18	6D
0005435860514	32611	19	7B
0005433868620	32611	20	7C
0005433868504	32611	21	18C
0005433868309	32611	22	18D
0005433868629	32611	23	19A
0005433868270	32611	24	19B
0005433868529	32611	25	19C
0005433868573	32611	26	19D
0005435860519	32611	27	20B
0005433868565	32611	28	20C
0005433868530	32611	29	20D
0005433868569	32611	30	21A
0005433868453	32611	31	21B
0005435860515	32611	32	21C
0005433868531	32611	33	21D
0005433868503	32611	34	22A
0005433868479	32611	35	22B
0005433868370	32611	36	22C
0005433868451	32611	37	22D
0005433868478	32611	38	23A
0005433868546	32611	39	23B
0005434663566	3406	1	1B
0005434663561	3406	2	1C
0005434461672	3406	3	1D
0005434663558	3406	4	2A
0005434663569	3406	5	2B
0005435911480	3406	6	2D
0005435911485	3406	7	3D
0005434663565	3406	8	4B
0005434663563	3406	9	4C
0005435911474	3406	10	4D
0005434663568	3406	11	5B
0005434663564	3406	12	5C
0005434460530	3406	13	6B
0005434663557	3406	14	7A
0005434461673	3406	15	7B
0005434461670	3406	16	7C
0005435911433	3406	17	18A
0005435911486	3406	18	18C
0005435911481	3406	19	18D
0005434663562	3406	20	19A
0005435911482	3406	21	19B
0005435911473	3406	22	19C
0005434461671	3406	23	19D
0005434663559	3406	24	20A
0005434663567	3406	25	20B
0005434663556	3406	26	20D
0005434460529	3406	27	21C
0005434663560	3406	28	22C
0005434663475	12475	1	1A
0005435911541	12475	2	1B
0005434462792	12475	3	1C
0005435911534	12475	4	1D
0005434462791	12475	5	2A
0005434663377	12475	6	2B
0005435911538	12475	7	2D
0005434462784	12475	8	3A
0005434462793	12475	9	3C
0005434462787	12475	10	3D
0005434663448	12475	11	4C
0005434663491	12475	12	4D
0005434460502	12475	13	5A
0005435911535	12475	14	5B
0005435911539	12475	15	5D
0005434462788	12475	16	6A
0005434663479	12475	17	6C
0005434663425	12475	18	7A
0005434663429	12475	19	7B
0005434663376	12475	20	7C
0005434663424	12475	21	7D
0005434462790	12475	22	18B
0005434460495	12475	23	18A
0005435911537	12475	24	18C
0005434663478	12475	25	18D
0005434460503	12475	26	19C
0005435911540	12475	27	19D
0005434663349	12475	28	20B
0005434462794	12475	29	21B
0005434663378	12475	30	22A
0005435911536	12475	31	22B
0005434663469	12475	32	22C
0005434663426	12475	33	23A
0005434460496	12475	34	23B
0005433868479	14473	1	1B
0005433868478	14473	2	1C
0005433868538	14473	3	1D
0005433868569	14473	4	2A
0005435860516	14473	5	2B
0005433868493	14473	6	2D
0005433868451	14473	7	3A
0005433868504	14473	8	3B
0005433868309	14473	9	3D
0005433868619	14473	10	4A
0005433868529	14473	11	4D
0005433868503	14473	12	4C
0005433868530	14473	13	5A
0005433868531	14473	14	5B
0005433868527	14473	15	5C
0005435860518	14473	16	5D
0005433868631	14473	17	6A
0005435860519	14473	18	6B
0005433868742	14473	19	6D
0005433868415	14473	20	7A
0005433868564	14473	21	7B
0005433868448	14473	22	7C
0005435860514	14473	23	18C
0005435860515	14473	24	18D
0005433868573	14473	25	19B
0005433868370	14473	26	19C
0005435860517	14473	27	19D
0005433868627	14473	28	20A
0005433868620	14473	29	20B
0005433868703	14473	30	20C
0005433868568	14473	31	20D
0005433868630	14473	32	21A
0005433868629	14473	33	21B
0005433868567	14473	34	21C
0005433868453	14473	35	21D
0005433868546	14473	36	22A
0005433868414	14473	37	22D
0005433868565	14473	38	23A
0005433868270	14473	39	23B
0005435860491	32693	1	1A
0005433868874	32693	2	1B
0005433868876	32693	3	1C
0005433868866	32693	4	1D
0005433868863	32693	5	2A
0005433868865	32693	6	2B
0005433868842	32693	7	2C
0005433868845	32693	8	2D
0005433868867	32693	9	3A
0005433868870	32693	10	3B
0005433868873	32693	11	3C
0005433868852	32693	12	3D
0005435860493	32693	13	4A
0005433868872	32693	14	4B
0005433868841	32693	15	4C
0005433868843	32693	16	4D
0005433868855	32693	17	5A
0005433868846	32693	18	5B
0005433868877	32693	19	5C
0005433868838	32693	20	5D
0005433868837	32693	21	6A
0005433868851	32693	22	6B
0005433868844	32693	23	6C
0005433868860	32693	24	6D
0005433868849	32693	25	7A
0005433868871	32693	26	7B
0005433868864	32693	27	7C
0005433868875	32693	28	7D
0005433868861	32693	29	18A
0005433868850	32693	30	18B
0005433868858	32693	31	18C
0005433868853	32693	32	18D
0005433868868	32693	33	19A
0005435860484	32693	34	19B
0005435860492	32693	35	19C
0005433868840	32693	36	19D
0005433868854	32693	37	20B
0005433868869	32693	38	20C
0005435860490	32693	39	20D
0005435860485	32693	40	21A
0005435860483	32693	41	21B
0005433868856	32693	42	21C
0005433868859	32693	43	21D
0005433868839	32693	44	22A
0005433868862	32693	45	22B
0005433868847	32693	46	22C
0005433868857	32693	47	22D
0005435860482	32693	48	23A
0005433868848	32693	49	23B
0005432799525	12133	1	1C
0005432799388	12133	2	2A
0005432799553	12133	3	2C
0005432799564	12133	4	2D
0005432799466	12133	5	3B
0005432799524	12133	6	3C
0005432799651	12133	7	3D
0005432799550	12133	8	4B
0005432799423	12133	9	5B
0005432799499	12133	10	5C
0005432799512	12133	11	6A
0005432799467	12133	12	6B
0005432799588	12133	13	6C
0005432799517	12133	14	6D
0005432799454	12133	15	7A
0005432799462	12133	16	7C
0005432799562	12133	17	7D
0005432799582	12133	18	18A
0005432799505	12133	19	18B
0005432799563	12133	20	18C
0005432799558	12133	21	19A
0005432799504	12133	22	19B
0005432799498	12133	23	19C
0005432799565	12133	24	19D
0005432799429	12133	25	20A
0005432799597	12133	26	20C
0005432799518	12133	27	20D
0005432799655	12133	28	21A
0005432799549	12133	29	21B
0005432799602	12133	30	21C
0005432799593	12133	31	21D
0005432799506	12133	32	22A
0005432799600	12133	33	22B
0005432799754	14805	1	1A
0005432799747	14805	2	1B
0005432799751	14805	3	1C
0005432799737	14805	4	1D
0005432799745	14805	5	2D
0005432799749	14805	6	3B
0005432799752	14805	7	4A
0005432799743	14805	8	4D
0005432799738	14805	9	5A
0005432799742	14805	10	5D
0005432799740	14805	11	6A
0005432799744	14805	12	6C
0005432799760	14805	13	6D
0005432799741	14805	14	7B
0005432799762	14805	15	7C
0005432799759	14805	16	18B
0005432799758	14805	17	18C
0005432799761	14805	18	18D
0005432799736	14805	19	19B
0005432799753	14805	20	19D
0005432799755	14805	21	20B
0005432799750	14805	22	20C
0005432799739	14805	23	20D
0005432799735	14805	24	21A
0005432799756	14805	25	21C
0005432799734	14805	26	21D
0005432799757	14805	27	22A
0005432799746	14805	28	22D
0005432799748	14805	29	23B
0005434408461	7079	1	1A
0005434408487	7079	2	1D
0005434408448	7079	3	1C
0005434408451	7079	4	1F
0005435293295	7079	5	2A
0005435293220	7079	6	2D
0005434299820	7079	7	2C
0005435293311	7079	8	3A
0005434408474	7079	9	2F
0005434299835	7079	10	3D
0005434299817	7079	11	3C
0005435311086	7079	12	3F
0005434408505	7079	13	4A
0005435293246	7079	14	4C
0005434408500	7079	15	4B
0005434299819	7079	16	4D
0005434408447	7079	17	4E
0005435293290	7079	18	4F
0005434299836	7079	19	5B
0005432154016	7079	20	5A
0005434299821	7079	21	5C
0005435311063	7079	22	5D
0005435293324	7079	23	5F
0005432154015	7079	24	5E
0005435293280	7079	25	6B
0005434408510	7079	26	6A
0005434408501	7079	27	6C
0005434408497	7079	28	6D
0005434408507	7079	29	6F
0005434299832	7079	30	6E
0005434299825	7079	31	7A
0005435311076	7079	32	7B
0005434299823	7079	33	7C
0005434408511	7079	34	7E
0005435293289	7079	35	7D
0005434408454	7079	36	7F
0005434299833	7079	37	8B
0005435293260	7079	38	8A
0005434408458	7079	39	8C
0005434408490	7079	40	8E
0005434299818	7079	41	8D
0005434408491	7079	42	8F
0005432154018	7079	43	9A
0005434408463	7079	44	9B
0005434299829	7079	45	9D
0005434408508	7079	46	9C
0005434408480	7079	47	9F
0005434408455	7079	48	9E
0005434408472	7079	49	10B
0005435293218	7079	50	10D
0005434299816	7079	51	10C
0005432154014	7079	52	10E
0005435311065	7079	53	11A
0005435293271	7079	54	11B
0005434299830	7079	55	11C
0005434408482	7079	56	11E
0005434299834	7079	57	11D
0005434408469	7079	58	11F
0005432108280	7079	59	12B
0005434408450	7079	60	12A
0005434408496	7079	61	12C
0005435293288	7079	62	12D
0005435293272	7079	63	12E
0005434408492	7079	64	13A
0005435293273	7079	65	12F
0005435293312	7079	66	13B
0005435311075	7079	67	13C
0005434408481	7079	68	13F
0005432154019	7079	69	13E
0005434408509	7079	70	13D
0005435311062	7079	71	14A
0005434408453	7079	72	14B
0005434408485	7079	73	14D
0005434408462	7079	74	14C
0005434408473	7079	75	14E
0005434408465	7079	76	15A
0005434299822	7079	77	14F
0005434408471	7079	78	15B
0005434408449	7079	79	15C
0005434408478	7079	80	15D
0005434408459	7079	81	15E
0005432154017	7079	82	15F
0005435293278	7079	83	16B
0005435293314	7079	84	16A
0005435293219	7079	85	16C
0005434408503	7079	86	16D
0005434408489	7079	87	16E
0005434299831	7079	88	17A
0005434299815	7079	89	16F
0005434299827	7079	90	17B
0005434408484	7079	91	17D
0005434408470	7079	92	17C
0005432108279	7079	93	17E
0005434408464	7079	94	17F
0005435293279	7079	95	18A
0005434408456	7079	96	18B
0005434408483	7079	97	18C
0005435293323	7079	98	18E
0005435293286	7079	99	18D
0005435293261	7079	100	18F
0005434408479	7079	101	19A
0005432108278	7079	102	19B
0005434408494	7079	103	19D
0005434408466	7079	104	19C
0005434408506	7079	105	19F
0005435293270	7079	106	19E
0005434408504	7079	107	20A
0005434299828	7079	108	20C
0005434408477	7079	109	20B
0005432154020	7079	110	20D
0005434408452	7079	111	20E
0005434408457	7079	112	21A
0005434408460	7079	113	20F
0005434299826	7079	114	21B
0005434408467	7079	115	21D
0005435293317	7079	116	21C
0005434408488	7079	117	21F
0005434408468	7079	118	21E
0005434408475	7079	119	22B
0005434408495	7079	120	22A
0005434299824	7079	121	22C
0005435293221	7079	122	22D
0005434408499	7079	123	22E
0005434408486	7079	124	23A
0005434408476	7079	125	22F
0005434408502	7079	126	23B
0005434299837	7079	127	23C
0005434408493	7079	128	23D
0005435293310	7079	129	23F
0005434408498	7079	130	23E
0005434299659	26901	1	1A
0005434407814	26901	2	1C
0005434407925	26901	3	1D
0005434407977	26901	4	2A
0005434407989	26901	5	1F
0005434407798	26901	6	2C
0005435311182	26901	7	2D
0005434407751	26901	8	3A
0005435311193	26901	9	2F
0005434407743	26901	10	3C
0005434407832	26901	11	3D
0005434408037	26901	12	3F
0005435311189	26901	13	4B
0005434407839	26901	14	4A
0005434407964	26901	15	4D
0005434407991	26901	16	4C
0005435311197	26901	17	4E
0005434299623	26901	18	5A
0005434408088	26901	19	4F
0005435293396	26901	20	5B
0005432058422	26901	21	5C
0005435311180	26901	22	5D
0005434408145	26901	23	5E
0005434299725	26901	24	6A
0005434407976	26901	25	5F
0005434299773	26901	26	6B
0005435311188	26901	27	6D
0005434299697	26901	28	6E
0005435311184	26901	29	6F
0005435311179	26901	30	7A
0005434408107	26901	31	7C
0005434408038	26901	32	7B
0005435293397	26901	33	7D
0005435311178	26901	34	7F
0005435293388	26901	35	8A
0005434407722	26901	36	8B
0005432058425	26901	37	8C
0005435311196	26901	38	8E
0005434408083	26901	39	8D
0005434299710	26901	40	9A
0005434299658	26901	41	9C
0005434407681	26901	42	9B
0005434299613	26901	43	9E
0005434407797	26901	44	9D
0005434407986	26901	45	9F
0005435293394	26901	46	10B
0005434407990	26901	47	10C
0005435311186	26901	48	10E
0005434408108	26901	49	10D
0005435311194	26901	50	11A
0005434408119	26901	51	11B
0005434299631	26901	52	11C
0005432058423	26901	53	11E
0005435293391	26901	54	11D
0005434407727	26901	55	11F
0005435293390	26901	56	12A
0005434408115	26901	57	12B
0005434407875	26901	58	12D
0005434408054	26901	59	12C
0005432058421	26901	60	12E
0005432058424	26901	61	13A
0005434407749	26901	62	12F
0005434407987	26901	63	13C
0005434407910	26901	64	13B
0005435293399	26901	65	13D
0005435311200	26901	66	13E
0005434299647	26901	67	13F
0005434407676	26901	68	14B
0005434407742	26901	69	14A
0005435311191	26901	70	14C
0005434299738	26901	71	14E
0005434407965	26901	72	15A
0005435311199	26901	73	14F
0005434407851	26901	74	15B
0005434408052	26901	75	15D
0005434299660	26901	76	15C
0005435311190	26901	77	15E
0005434407917	26901	78	16A
0005434407826	26901	79	15F
0005434407868	26901	80	16B
0005435293400	26901	81	16C
0005435293389	26901	82	16D
0005434407680	26901	83	16F
0005434407767	26901	84	16E
0005435293392	26901	85	17A
0005434299772	26901	86	17B
0005435311183	26901	87	17C
0005435293398	26901	88	17E
0005434299592	26901	89	17D
0005434299695	26901	90	17F
0005434299593	26901	91	18B
0005434299694	26901	92	18A
0005434407950	26901	93	18D
0005434299737	26901	94	18C
0005434407744	26901	95	18F
0005434407897	26901	96	18E
0005435311185	26901	97	19A
0005434299666	26901	98	19B
0005434407820	26901	99	19C
0005434407481	26901	100	19E
0005434299628	26901	101	19D
0005434407852	26901	102	19F
0005434407876	26901	103	20A
0005434408091	26901	104	20C
0005435293395	26901	105	20B
0005434407853	26901	106	20D
0005434299633	26901	107	20F
0005434407970	26901	108	21A
0005434407693	26901	109	21C
0005434407840	26901	110	21B
0005434407940	26901	111	21D
0005434407833	26901	112	21F
0005435293393	26901	113	21E
0005434407909	26901	114	22A
0005435311192	26901	115	22B
0005435311181	26901	116	22C
0005434299632	26901	117	22D
0005435311202	26901	118	22E
0005434407824	26901	119	23A
0005435311187	26901	120	22F
0005434299663	26901	121	23B
0005434408084	26901	122	23C
0005435311198	26901	123	23E
0005435311201	26901	124	23D
0005435311195	26901	125	23F
0005432604814	6440	1	1A
0005432604808	6440	2	1C
0005432604815	6440	3	1B
0005434512159	6440	4	1D
0005432604800	6440	5	2A
0005432604796	6440	6	2B
0005432604801	6440	7	2C
0005432604794	6440	8	3B
0005432604791	6440	9	3A
0005432604804	6440	10	3C
0005432604810	6440	11	3D
0005432604787	6440	12	4A
0005434512162	6440	13	4B
0005432604786	6440	14	4C
0005432604795	6440	15	4D
0005432604812	6440	16	5A
0005432604792	6440	17	5B
0005432604798	6440	18	5C
0005432604780	6440	19	5D
0005432604809	6440	20	6A
0005434512158	6440	21	6C
0005432604779	6440	22	6D
0005432604782	6440	23	7A
0005432604797	6440	24	7C
0005432604789	6440	25	18A
0005432604802	6440	26	18B
0005432604817	6440	27	18C
0005432604784	6440	28	18D
0005432604783	6440	29	19A
0005432604811	6440	30	19B
0005432604813	6440	31	19C
0005432604805	6440	32	19D
0005432604793	6440	33	20B
0005432604806	6440	34	20C
0005432604788	6440	35	20D
0005432604799	6440	36	21A
0005432604785	6440	37	21B
0005432604781	6440	38	21C
0005432604807	6440	39	21D
0005434512161	6440	40	22A
0005434512160	6440	41	22B
0005432604790	6440	42	22C
0005432604816	6440	43	22D
0005432604803	6440	44	23A
0005432604387	21344	1	1A
0005434512113	21344	2	1B
0005432604467	21344	3	1D
0005434512140	21344	4	2A
0005432604279	21344	5	2C
0005432604533	21344	6	2D
0005432604466	21344	7	3A
0005432604474	21344	8	4B
0005434512119	21344	9	4A
0005432604628	21344	10	4C
0005432604349	21344	11	4D
0005434512127	21344	12	5A
0005432604145	21344	13	5B
0005432604388	21344	14	5C
0005434512134	21344	15	6A
0005435221065	21344	16	6C
0005434512129	21344	17	6D
0005434512117	21344	18	7A
0005432604429	21344	19	7B
0005432604532	21344	20	7C
0005432604365	21344	21	18A
0005432604352	21344	22	18B
0005432604514	21344	23	18C
0005432604465	21344	24	18D
0005434512118	21344	25	19A
0005432604182	21344	26	19C
0005432604562	21344	27	19D
0005432604563	21344	28	20A
0005432604355	21344	29	20B
0005435221064	21344	30	20C
0005432604475	21344	31	20D
0005432604459	21344	32	21A
0005432604526	21344	33	21C
0005432604366	21344	34	21D
0005434512128	21344	35	22A
0005434512112	21344	36	22B
0005432604354	21344	37	22C
0005432604529	21344	38	22D
0005432604353	21344	39	23A
0005434907227	14991	1	1A
0005434907316	14991	2	1C
0005433251838	14991	3	1D
0005433251824	14991	4	1F
0005434907379	14991	5	2A
0005433251841	14991	6	2C
0005433251831	14991	7	2D
0005433251835	14991	8	2F
0005434907303	14991	9	3A
0005434907294	14991	10	3D
0005434907387	14991	11	3F
0005434907298	14991	12	4A
0005434907175	14991	13	4C
0005434907401	14991	14	4D
0005433251843	14991	15	4E
0005434907371	14991	16	4F
0005434907442	14991	17	5C
0005433251826	14991	18	5D
0005433251817	14991	19	5E
0005434907386	14991	20	5F
0005433251825	14991	21	6A
0005433251829	14991	22	6C
0005434907334	14991	23	6D
0005433251816	14991	24	6E
0005434907402	14991	25	6F
0005433251818	14991	26	7A
0005434907412	14991	27	7C
0005434907266	14991	28	7D
0005433251813	14991	29	7E
0005434907248	14991	30	7F
0005434907444	14991	31	8C
0005434907318	14991	32	8D
0005434907174	14991	33	8F
0005433251823	14991	34	9A
0005434907391	14991	35	9C
0005434907373	14991	36	9D
0005434907244	14991	37	9E
0005434907342	14991	38	9F
0005434907434	14991	39	10A
0005434907395	14991	40	10C
0005434907322	14991	41	10D
0005434907274	14991	42	10E
0005433251836	14991	43	10F
0005433251812	14991	44	11A
0005434907425	14991	45	11C
0005434907374	14991	46	11D
0005433251833	14991	47	11E
0005434907249	14991	48	11F
0005433251827	14991	49	12A
0005434907176	14991	50	12D
0005433251830	14991	51	12E
0005434907370	14991	52	12F
0005433251832	14991	53	13A
0005433251837	14991	54	13C
0005434907382	14991	55	13D
0005434907228	14991	56	13E
0005433251819	14991	57	13F
0005433251814	14991	58	14A
0005434907268	14991	59	14C
0005433251834	14991	60	14D
0005433251828	14991	61	14E
0005434907381	14991	62	14F
0005434907265	14991	63	15A
0005434907433	14991	64	15C
0005434907349	14991	65	15D
0005434907366	14991	66	15E
0005434907429	14991	67	15F
0005434907224	14991	68	16A
0005434907390	14991	69	16C
0005433251820	14991	70	16D
0005433251822	14991	71	16E
0005434907245	14991	72	16F
0005434907285	14991	73	17A
0005434907424	14991	74	17C
0005434907408	14991	75	17D
0005433251839	14991	76	17E
0005434907380	14991	77	17F
0005434907345	14991	78	18A
0005434907314	14991	79	18C
0005433251821	14991	80	18D
0005434907413	14991	81	18E
0005434907301	14991	82	18F
0005434907445	14991	83	19A
0005434907302	14991	84	19C
0005434907293	14991	85	19E
0005433251842	14991	86	19F
0005434907343	14991	87	20A
0005433251815	14991	88	20C
0005433251840	14991	89	20D
0005434907217	14991	90	20E
0005434907327	14991	91	20F
0005434907854	25825	1	1A
0005434907806	25825	2	1C
0005434907825	25825	3	1D
0005434907855	25825	4	1F
0005434907836	25825	5	2A
0005434907838	25825	6	2C
0005433251583	25825	7	2D
0005434907824	25825	8	2F
0005434907814	25825	9	3C
0005434907833	25825	10	3D
0005433251653	25825	11	3F
0005434907826	25825	12	4A
0005433251712	25825	13	4C
0005433251490	25825	14	4E
0005434907857	25825	15	4F
0005433251521	25825	16	5A
0005433251649	25825	17	5C
0005433251631	25825	18	5D
0005434907811	25825	19	5E
0005433251520	25825	20	5F
0005434907803	25825	21	6A
0005434907812	25825	22	6C
0005433251621	25825	23	6D
0005434907809	25825	24	6E
0005434907819	25825	25	6F
0005434907845	25825	26	7A
0005434907804	25825	27	7D
0005433251546	25825	28	7E
0005433251597	25825	29	8C
0005434907820	25825	30	8E
0005433251451	25825	31	8F
0005434907830	25825	32	9D
0005433251609	25825	33	9E
0005434907815	25825	34	9F
0005433251543	25825	35	10C
0005434907843	25825	36	10D
0005433251721	25825	37	10E
0005434907851	25825	38	10F
0005434907853	25825	39	11A
0005434907835	25825	40	11D
0005434907818	25825	41	11C
0005434907834	25825	42	11E
0005433251552	25825	43	11F
0005434907822	25825	44	12A
0005434907802	25825	45	12C
0005434907850	25825	46	12D
0005434907847	25825	47	12E
0005433251651	25825	48	12F
0005433251499	25825	49	13A
0005433251509	25825	50	13C
0005434907848	25825	51	13D
0005433251519	25825	52	13E
0005434907839	25825	53	14A
0005434907841	25825	54	14C
0005434907805	25825	55	14D
0005434907832	25825	56	14E
0005434907828	25825	57	15A
0005434907852	25825	58	15C
0005434907842	25825	59	15D
0005434907827	25825	60	15E
0005434907849	25825	61	15F
0005434907840	25825	62	16C
0005434907816	25825	63	16D
0005434907856	25825	64	16E
0005434907808	25825	65	16F
0005433251601	25825	66	17A
0005434907813	25825	67	17D
0005434907823	25825	68	17E
0005434907829	25825	69	17F
0005433251650	25825	70	18A
0005433251425	25825	71	18C
0005434907844	25825	72	18D
0005434907831	25825	73	18E
0005434907801	25825	74	18F
0005434907846	25825	75	19A
0005434907810	25825	76	19C
0005433251713	25825	77	19D
0005434907807	25825	78	19E
0005433251533	25825	79	19F
0005433251610	25825	80	20A
0005433251652	25825	81	20C
0005434907821	25825	82	20D
0005434907817	25825	83	20E
0005434907837	25825	84	20F
0005432607606	22470	1	1A
0005432607607	22470	2	1B
0005432609763	22470	3	1C
0005432607601	22470	4	1D
0005432609771	22470	5	2A
0005432609773	22470	6	2B
0005432609760	22470	7	2C
0005432607605	22470	8	2D
0005432609774	22470	9	3A
0005432609766	22470	10	3B
0005432607597	22470	11	3C
0005432607603	22470	12	4A
0005432609769	22470	13	4D
0005432607596	22470	14	5B
0005432607599	22470	15	5C
0005432609767	22470	16	5D
0005432607609	22470	17	6A
0005432607595	22470	18	6B
0005432609770	22470	19	6D
0005432609765	22470	20	7A
0005432609768	22470	21	7C
0005432607602	22470	22	7D
0005432609764	22470	23	18A
0005435842327	22470	24	18B
0005432609775	22470	25	19A
0005432607594	22470	26	19B
0005432607600	22470	27	19C
0005432607608	22470	28	19D
0005432607598	22470	29	20A
0005432607611	22470	30	20B
0005432607610	22470	31	20C
0005435842328	22470	32	21A
0005432607604	22470	33	21C
0005432609772	22470	34	21D
0005432609762	22470	35	22A
0005432609761	22470	36	22D
0005432609725	31724	1	1A
0005432613867	31724	2	1B
0005432613848	31724	3	1C
0005432613872	31724	4	1D
0005432609734	31724	5	2A
0005432613858	31724	6	2B
0005432609724	31724	7	2C
0005432609719	31724	8	2D
0005432613864	31724	9	3A
0005432613862	31724	10	3B
0005432613863	31724	11	3C
0005432613873	31724	12	3D
0005432613870	31724	13	4A
0005432609723	31724	14	4B
0005432613877	31724	15	4C
0005435841102	31724	16	5A
0005432613861	31724	17	5D
0005432609702	31724	18	6B
0005432613859	31724	19	7A
0005432609718	31724	20	7B
0005432613878	31724	21	7C
0005432613874	31724	22	18A
0005432613876	31724	23	18B
0005432609739	31724	24	18C
0005432613845	31724	25	18D
0005432613871	31724	26	19B
0005432609732	31724	27	19C
0005432613846	31724	28	19D
0005432613865	31724	29	20A
0005432613860	31724	30	20B
0005432609733	31724	31	20D
0005432613866	31724	32	21A
0005432609744	31724	33	21B
0005432609745	31724	34	21C
0005432609731	31724	35	21D
0005432609746	31724	36	22A
0005432613869	31724	37	22B
0005435841103	31724	38	22C
0005432609729	31724	39	22D
0005432609722	31724	40	23A
0005433009144	14175	1	1A
0005433009143	14175	2	1C
0005433810545	14175	3	2F
0005433810541	14175	4	3C
0005433009130	14175	5	3D
0005433009165	14175	6	3F
0005433009147	14175	7	4A
0005433009138	14175	8	4C
0005433009135	14175	9	4D
0005433009124	14175	10	4E
0005433810547	14175	11	4F
0005433009162	14175	12	5A
0005433009136	14175	13	5D
0005433009131	14175	14	6A
0005433009166	14175	15	6C
0005433009142	14175	16	6F
0005433009152	14175	17	7C
0005433009161	14175	18	7D
0005433810544	14175	19	7E
0005433009126	14175	20	8A
0005433009129	14175	21	8C
0005433009132	14175	22	9D
0005433009156	14175	23	9E
0005433009155	14175	24	9F
0005433009164	14175	25	10A
0005433009167	14175	26	10E
0005433009157	14175	27	10F
0005433009137	14175	28	11A
0005433009139	14175	29	11C
0005433009153	14175	30	11E
0005433009149	14175	31	11F
0005433009145	14175	32	12E
0005433009128	14175	33	12F
0005433009127	14175	34	13A
0005433009146	14175	35	13D
0005433009163	14175	36	13E
0005433009134	14175	37	13F
0005433009160	14175	38	14E
0005433009151	14175	39	15A
0005433009159	14175	40	15C
0005433009150	14175	41	16A
0005433009148	14175	42	16F
0005433009140	14175	43	17E
0005433009154	14175	44	17F
0005433009133	14175	45	18A
0005433009125	14175	46	18E
0005433009158	14175	47	19C
0005433810543	14175	48	19E
0005433009141	14175	49	19F
0005433008852	22869	1	1A
0005433008804	22869	2	1D
0005433810585	22869	3	2C
0005433008765	22869	4	3A
0005433008763	22869	5	3C
0005433008694	22869	6	3D
0005433008840	22869	7	3F
0005433008637	22869	8	4A
0005433008716	22869	9	4D
0005433008250	22869	10	4F
0005433008805	22869	11	5D
0005433008631	22869	12	6D
0005433008693	22869	13	7D
0005433008781	22869	14	7E
0005433008743	22869	15	8A
0005433008866	22869	16	8E
0005433008671	22869	17	8F
0005433008677	22869	18	9A
0005433008697	22869	19	9D
0005433008661	22869	20	9F
0005433008725	22869	21	10F
0005433008684	22869	22	11D
0005433008632	22869	23	11F
0005433008764	22869	24	12A
0005433008802	22869	25	12C
0005433008806	22869	26	12E
0005433008703	22869	27	12F
0005433008865	22869	28	13A
0005433008868	22869	29	13C
0005433008736	22869	30	13D
0005433008691	22869	31	13F
0005433008670	22869	32	14A
0005433008813	22869	33	14C
0005433008722	22869	34	14E
0005433810584	22869	35	15C
0005433008690	22869	36	15E
0005433810583	22869	37	15F
0005433008807	22869	38	16D
0005433008401	22869	39	16F
0005433008747	22869	40	18A
0005433008818	22869	41	19D
0005433008649	22869	42	19E
0005433008426	22869	43	20A
0005433008704	22869	44	20C
0005433008803	22869	45	20D
0005433008636	22869	46	20F
0005434925922	14924	1	1A
0005434925867	14924	2	1D
0005434925874	14924	3	1F
0005434925859	14924	4	2D
0005434925848	14924	5	3C
0005434925947	14924	6	3D
0005434925891	14924	7	4A
0005434925691	14924	8	4C
0005434925789	14924	9	4F
0005434925804	14924	10	5C
0005434925815	14924	11	5E
0005434925960	14924	12	5F
0005434925857	14924	13	6A
0005434925794	14924	14	6D
0005434925801	14924	15	6F
0005434925761	14924	16	7A
0005434925814	14924	17	7C
0005434925793	14924	18	9C
0005434925961	14924	19	9F
0005434925971	14924	20	10A
0005434925812	14924	21	10D
0005434925899	14924	22	10E
0005434925792	14924	23	11A
0005434925805	14924	24	11C
0005434925858	14924	25	11F
0005434925845	14924	26	12C
0005434925800	14924	27	12D
0005434925744	14924	28	13C
0005434925766	14924	29	13F
0005434925921	14924	30	16C
0005434925946	14924	31	17D
0005434925826	14924	32	18A
0005434925750	14924	33	18C
0005434925892	14924	34	18D
0005434925920	14924	35	19C
0005434925847	14924	36	20A
0005434925883	14924	37	20C
0005434926152	20520	1	2D
0005434926150	20520	2	3A
0005434926151	20520	3	3D
0005434926140	20520	4	5A
0005434926160	20520	5	5E
0005434926154	20520	6	5F
0005434926139	20520	7	6E
0005434926153	20520	8	7A
0005434926146	20520	9	7C
0005434926149	20520	10	9E
0005434926144	20520	11	10A
0005434926155	20520	12	10E
0005434926138	20520	13	11A
0005434926156	20520	14	12A
0005434926145	20520	15	12D
0005434926158	20520	16	12E
0005434926164	20520	17	13A
0005434926147	20520	18	14C
0005434926163	20520	19	14F
0005434926141	20520	20	15C
0005434926165	20520	21	16A
0005434926162	20520	22	16C
0005434926148	20520	23	17A
0005434926143	20520	24	17E
0005434926157	20520	25	18A
0005434926142	20520	26	18F
0005434926137	20520	27	19A
0005434926136	20520	28	19E
0005434926161	20520	29	19F
0005434926159	20520	30	20C
0005435488094	15809	1	1B
0005435488074	15809	2	2C
0005435999265	15809	3	2D
0005435488086	15809	4	3A
0005435488077	15809	5	3B
0005435999316	15809	6	3C
0005435488093	15809	7	3D
0005435999280	15809	8	4B
0005435488080	15809	9	4D
0005435488084	15809	10	6A
0005435488092	15809	11	6D
0005435488089	15809	12	7B
0005435488078	15809	13	7C
0005435488083	15809	14	7D
0005435999252	15809	15	18A
0005435488088	15809	16	18B
0005435488081	15809	17	18C
0005435999296	15809	18	18D
0005435488087	15809	19	19A
0005435488075	15809	20	19B
0005435999295	15809	21	19C
0005435488076	15809	22	19D
0005435999300	15809	23	20A
0005435999321	15809	24	20B
0005435488090	15809	25	20C
0005435999268	15809	26	20D
0005435999294	15809	27	21A
0005435488079	15809	28	21B
0005435488082	15809	29	21C
0005435999293	15809	30	21D
0005435488085	15809	31	22B
0005435488095	15809	32	22C
0005435999288	15809	33	22D
0005435488091	15809	34	23A
0005435999320	15809	35	23B
0005435487814	19668	1	1A
0005435999430	19668	2	1B
0005435999426	19668	3	1C
0005435487860	19668	4	1D
0005435487862	19668	5	2A
0005435487911	19668	6	2B
0005435999429	19668	7	2C
0005435999433	19668	8	2D
0005435487845	19668	9	3A
0005435487785	19668	10	3B
0005435999434	19668	11	3C
0005435487889	19668	12	3D
0005435487861	19668	13	4A
0005435487924	19668	14	4D
0005435487813	19668	15	5B
0005435999435	19668	16	5C
0005435999428	19668	17	5D
0005435487834	19668	18	6B
0005435487870	19668	19	6C
0005435487865	19668	20	7A
0005435999425	19668	21	7C
0005435487798	19668	22	18A
0005435999431	19668	23	18B
0005435487828	19668	24	18C
0005435487869	19668	25	18D
0005435487831	19668	26	19A
0005435487784	19668	27	19C
0005435487830	19668	28	19D
0005435487863	19668	29	20B
0005435487797	19668	30	20C
0005435487910	19668	31	20D
0005435999432	19668	32	21A
0005435487923	19668	33	21B
0005435487904	19668	34	21C
0005435487823	19668	35	21D
0005435487731	19668	36	22B
0005435487832	19668	37	22C
0005435487791	19668	38	22D
0005435999427	19668	39	23A
0005435999424	19668	40	23B
0005435472795	5983	1	1C
0005435839770	5983	2	1F
0005432660843	5983	3	2A
0005432142290	5983	4	2F
0005435839779	5983	5	3D
0005435472844	5983	6	4C
0005435472845	5983	7	5A
0005435472881	5983	8	4D
0005435472840	5983	9	6B
0005435472751	5983	10	6A
0005435472847	5983	11	6C
0005435472820	5983	12	7A
0005435839771	5983	13	7C
0005435617234	5983	14	7E
0005432660842	5983	15	7D
0005432659731	5983	16	8D
0005435839787	5983	17	8F
0005435839780	5983	18	9C
0005435472849	5983	19	9E
0005435839769	5983	20	9D
0005435839782	5983	21	10F
0005435839773	5983	22	11B
0005435839767	5983	23	11D
0005432142288	5983	24	11E
0005432142287	5983	25	12D
0005432658616	5983	26	12C
0005435472834	5983	27	12E
0005435839778	5983	28	12F
0005435839777	5983	29	13F
0005435839785	5983	30	14A
0005432142286	5983	31	15A
0005435839776	5983	32	14F
0005435472838	5983	33	15B
0005435472841	5983	34	15E
0005435839774	5983	35	16B
0005435839765	5983	36	16A
0005435839768	5983	37	16C
0005435839784	5983	38	16E
0005435472880	5983	39	17A
0005432658617	5983	40	17D
0005435472839	5983	41	17F
0005435839766	5983	42	18A
0005435839775	5983	43	18C
0005435839772	5983	44	19C
0005435472794	5983	45	19B
0005432659732	5983	46	19E
0005432142289	5983	47	19D
0005435839783	5983	48	19F
0005435839781	5983	49	20D
0005435839786	5983	50	20C
0005435839789	5983	51	21A
0005435839791	5983	52	20F
0005435839790	5983	53	21E
0005435839788	5983	54	21F
0005435472991	18052	1	1D
0005435472998	18052	2	2A
0005435472993	18052	3	3A
0005435839442	18052	4	2F
0005435839552	18052	5	3D
0005435472994	18052	6	4C
0005435839422	18052	7	5A
0005435839498	18052	8	4F
0005435839637	18052	9	5F
0005435839509	18052	10	6B
0005435839612	18052	11	6A
0005435473000	18052	12	6F
0005435472990	18052	13	6E
0005432537083	18052	14	6D
0005435473001	18052	15	7C
0005435839595	18052	16	7B
0005435839574	18052	17	7E
0005432660816	18052	18	8B
0005435839455	18052	19	8E
0005435839609	18052	20	9C
0005435839508	18052	21	9E
0005435839510	18052	22	9D
0005432664131	18052	23	10A
0005435839479	18052	24	9F
0005435839448	18052	25	10F
0005435472987	18052	26	11A
0005435839477	18052	27	11C
0005435839478	18052	28	11F
0005435839388	18052	29	11E
0005435839395	18052	30	12C
0005435472986	18052	31	13A
0005435839505	18052	32	13B
0005432660815	18052	33	13E
0005435839502	18052	34	13D
0005435472995	18052	35	13F
0005435839497	18052	36	14B
0005435839501	18052	37	14A
0005435839394	18052	38	14F
0005435839393	18052	39	14E
0005435839556	18052	40	15B
0005432660808	18052	41	15A
0005435839644	18052	42	15C
0005435472992	18052	43	15E
0005432660812	18052	44	15F
0005435839564	18052	45	16D
0005435839459	18052	46	16F
0005435839565	18052	47	17B
0005432537084	18052	48	18B
0005435839476	18052	49	18A
0005435839643	18052	50	18D
0005435839575	18052	51	19A
0005435839557	18052	52	18F
0005435839443	18052	53	19D
0005435839464	18052	54	20B
0005435839636	18052	55	20A
0005435839555	18052	56	20C
0005435472989	18052	57	20F
0005435472988	18052	58	20E
0005435839389	18052	59	21B
0005435472985	18052	60	21A
0005435472996	18052	61	21D
0005435839551	18052	62	21C
0005435472997	18052	63	21E
0005435472999	18052	64	21F
0005433463924	17264	1	1A
0005433463923	17264	2	4A
0005433462761	17264	3	5A
0005433462762	17264	4	11H
0005433462769	17264	5	12F
0005433462764	17264	6	13E
0005433463921	17264	7	14E
0005433463919	17264	8	15H
0005433462768	17264	9	16G
0005433462758	17264	10	18A
0005433463918	17264	11	18G
0005433463914	17264	12	19B
0005433463922	17264	13	19E
0005433463925	17264	14	19G
0005433462765	17264	15	20E
0005433463917	17264	16	22F
0005433462759	17264	17	23E
0005433462771	17264	18	23G
0005433463911	17264	19	24G
0005433463916	17264	20	24H
0005433462763	17264	21	27A
0005433462767	17264	22	30B
0005433462766	17264	23	30E
0005433463912	17264	24	30G
0005433462760	17264	25	31B
0005433462757	17264	26	31A
0005433463920	17264	27	32H
0005433463913	17264	28	33G
0005433462770	17264	29	34A
0005433463915	17264	30	34D
0005435104011	23059	1	1A
0005433285395	23059	2	1C
0005433285287	23059	3	2C
0005433285559	23059	4	5B
0005433285414	23059	5	5C
0005433285212	23059	6	6A
0005433285424	23059	7	6D
0005433285360	23059	8	7F
0005433285359	23059	9	8F
0005433285434	23059	10	9B
0005433285333	23059	11	9D
0005433285402	23059	12	10D
0005433285422	23059	13	11D
0005433285372	23059	14	11F
0005433285425	23059	15	12C
0005433285303	23059	16	12B
0005433285448	23059	17	13A
0005433285365	23059	18	13B
0005433285392	23059	19	13D
0005435104013	23059	20	13E
0005433285469	23059	21	14B
0005433285426	23059	22	15C
0005433285288	23059	23	15D
0005433285213	23059	24	16B
0005433285439	23059	25	16C
0005433285332	23059	26	16F
0005433285354	23059	27	17C
0005433285438	23059	28	17E
0005433285334	23059	29	17D
0005433285335	23059	30	18C
0005433285506	23059	31	18B
0005433285447	23059	32	18D
0005433285353	23059	33	19A
0005433285417	23059	34	20D
0005433285338	23059	35	20E
0005433285322	23059	36	21A
0005435104010	23059	37	21D
0005433285452	23059	38	22B
0005435104012	23059	39	22D
0005433285394	23059	40	22E
0005433285510	23059	41	23B
0005433285423	23059	42	23C
0005433285672	32074	1	2F
0005435103911	32074	2	4A
0005433285675	32074	3	4E
0005433285668	32074	4	5B
0005433285665	32074	5	5A
0005435103939	32074	6	6D
0005433285667	32074	7	7F
0005433285660	32074	8	7E
0005433285651	32074	9	8D
0005433285649	32074	10	9B
0005433285662	32074	11	9C
0005435103933	32074	12	9E
0005433285671	32074	13	9F
0005433285653	32074	14	10B
0005433285648	32074	15	10D
0005433285647	32074	16	10C
0005433285669	32074	17	10E
0005433285658	32074	18	11B
0005433285650	32074	19	14A
0005433285652	32074	20	14D
0005435103940	32074	21	15B
0005433285673	32074	22	15C
0005433285655	32074	23	16E
0005433285657	32074	24	16F
0005435103937	32074	25	17C
0005433285666	32074	26	18F
0005433285646	32074	27	20B
0005433285664	32074	28	21A
0005435103938	32074	29	21B
0005433285661	32074	30	21F
0005433285659	32074	31	22B
0005433285654	32074	32	22E
0005433285663	32074	33	22D
0005433285674	32074	34	22F
0005435103912	32074	35	23C
0005433285670	32074	36	23E
0005433285656	32074	37	23D
0005435214351	30624	1	1C
0005432528270	30624	2	1A
0005432528281	30624	3	1H
0005432528157	30624	4	1G
0005434067398	30624	5	1D
0005432528054	30624	6	1K
0005432527798	30624	7	2D
0005432528735	30624	8	2A
0005434067718	30624	9	2H
0005432211590	30624	10	2G
0005434067576	30624	11	3A
0005432533307	30624	12	2K
0005432535859	30624	13	3D
0005432528434	30624	14	3C
0005435214393	30624	15	3H
0005432528549	30624	16	4C
0005435214382	30624	17	4A
0005435214358	30624	18	5C
0005435214366	30624	19	5A
0005434067719	30624	20	5H
0005435725660	30624	21	5G
0005434067807	30624	22	5D
0005432528708	30624	23	5K
0005432528906	30624	24	11D
0005432528533	30624	25	11C
0005434067818	30624	26	11F
0005435725663	30624	27	11E
0005434067784	30624	28	11K
0005434067822	30624	29	11H
0005434067943	30624	30	12C
0005434068134	30624	31	12F
0005435214406	30624	32	12D
0005435214362	30624	33	12H
0005434067712	30624	34	12G
0005435214405	30624	35	13A
0005434068006	30624	36	12K
0005434067802	30624	37	13D
0005432528834	30624	38	13C
0005434067572	30624	39	13H
0005432528837	30624	40	13G
0005434067711	30624	41	14A
0005432529161	30624	42	13K
0005432528210	30624	43	14E
0005432528911	30624	44	14D
0005434067832	30624	45	14H
0005432528747	30624	46	15C
0005432159912	30624	47	15A
0005434067651	30624	48	15F
0005432528172	30624	49	15E
0005435214408	30624	50	15G
0005435214355	30624	51	15K
0005432528445	30624	52	16D
0005435214364	30624	53	16F
0005434067340	30624	54	16E
0005432528259	30624	55	16H
0005434067664	30624	56	16G
0005432528280	30624	57	17C
0005435214391	30624	58	17A
0005435214403	30624	59	16K
0005432528963	30624	60	17E
0005432211592	30624	61	17D
0005434067402	30624	62	17G
0005434067760	30624	63	17H
0005432528687	30624	64	18C
0005435214359	30624	65	18B
0005432528148	30624	66	18A
0005435214371	30624	67	18E
0005432528534	30624	68	18D
0005434067801	30624	69	18G
0005432528575	30624	70	19B
0005434067578	30624	71	18K
0005432528332	30624	72	19D
0005432528321	30624	73	19C
0005435214344	30624	74	19F
0005432535869	30624	75	19J
0005432528592	30624	76	19H
0005435214390	30624	77	20A
0005435214363	30624	78	19K
0005432528309	30624	79	20C
0005435214348	30624	80	20B
0005435214378	30624	81	20E
0005432528690	30624	82	20D
0005435214376	30624	83	20G
0005432528104	30624	84	20F
0005434067642	30624	85	20K
0005434067773	30624	86	21B
0005434067904	30624	87	21A
0005434067854	30624	88	21D
0005432528206	30624	89	21F
0005432528204	30624	90	21E
0005432528370	30624	91	21H
0005432529050	30624	92	21G
0005432528047	30624	93	22A
0005432535841	30624	94	21K
0005432528144	30624	95	21J
0005432211594	30624	96	22C
0005435214407	30624	97	22B
0005432528127	30624	98	22E
0005432529061	30624	99	22D
0005435214372	30624	100	22H
0005432528509	30624	101	22F
0005434067835	30624	102	22K
0005434067831	30624	103	22J
0005432528344	30624	104	23D
0005432528369	30624	105	23F
0005434067761	30624	106	23E
0005435214345	30624	107	23J
0005432528143	30624	108	23H
0005432528734	30624	109	23G
0005435214341	30624	110	24D
0005435214392	30624	111	24E
0005435725664	30624	112	25B
0005434067780	30624	113	24G
0005435214377	30624	114	25C
0005432528079	30624	115	25E
0005432528809	30624	116	25G
0005432528320	30624	117	25K
0005432528308	30624	118	25J
0005432528962	30624	119	26B
0005435214384	30624	120	26E
0005432528686	30624	121	26D
0005432159913	30624	122	26C
0005435214389	30624	123	26G
0005432211591	30624	124	26F
0005432528145	30624	125	26J
0005432528435	30624	126	27A
0005434067821	30624	127	26K
0005433656712	30624	128	27D
0005434067772	30624	129	27C
0005435214369	30624	130	27F
0005432528448	30624	131	27E
0005432527721	30624	132	27G
0005432528105	30624	133	27K
0005435214360	30624	134	27J
0005435214373	30624	135	28C
0005434067662	30624	136	28B
0005432428951	30624	137	28E
0005434067861	30624	138	28G
0005435631005	30624	139	28F
0005435214342	30624	140	28H
0005432528393	30624	141	29B
0005432528907	30624	142	29A
0005434067882	30624	143	29D
0005432528422	30624	144	29C
0005432528249	30624	145	29F
0005432535847	30624	146	29E
0005435214398	30624	147	29J
0005432528806	30624	148	29H
0005432211596	30624	149	30A
0005434067771	30624	150	29K
0005434067862	30624	151	30C
0005432528848	30624	152	30B
0005435214380	30624	153	30E
0005435631006	30624	154	30G
0005434067803	30624	155	30F
0005434067667	30624	156	30K
0005432527953	30624	157	30J
0005432528519	30624	158	30H
0005432528000	30624	159	31A
0005434068005	30624	160	31D
0005432528808	30624	161	31C
0005433656713	30624	162	31B
0005434067702	30624	163	31E
0005434067683	30624	164	31H
0005435214387	30624	165	31G
0005432528586	30624	166	32A
0005435214402	30624	167	31K
0005434067630	30624	168	31J
0005435214365	30624	169	32C
0005432528607	30624	170	32B
0005432533306	30624	171	32E
0005435214396	30624	172	32D
0005435725662	30624	173	32G
0005434068007	30624	174	32F
0005435214404	30624	175	33A
0005435214349	30624	176	33D
0005435214395	30624	177	33C
0005432528518	30624	178	33B
0005432528392	30624	179	33E
0005432528215	30624	180	33H
0005434067826	30624	181	33G
0005434067777	30624	182	34A
0005434067894	30624	183	33K
0005432528685	30624	184	33J
0005432528085	30624	185	34C
0005432529045	30624	186	34B
0005435214374	30624	187	34E
0005432528492	30624	188	34F
0005432533304	30624	189	34K
0005435214388	30624	190	34J
0005434067786	30624	191	34H
0005435214352	30624	192	35B
0005435214343	30624	193	35D
0005435214385	30624	194	35C
0005432528481	30624	195	35F
0005432528707	30624	196	35E
0005435214340	30624	197	35H
0005432528593	30624	198	35G
0005435214399	30624	199	35K
0005432528743	30624	200	35J
0005435214350	30624	201	36C
0005432528174	30624	202	36A
0005432528205	30624	203	36E
0005432528368	30624	204	36D
0005434067631	30624	205	36F
0005432211589	30624	206	36K
0005435214370	30624	207	36H
0005434067666	30624	208	37B
0005435214353	30624	209	37A
0005435214375	30624	210	37D
0005434067830	30624	211	37C
0005432529086	30624	212	37G
0005432528419	30624	213	37H
0005432528678	30624	214	38A
0005432528170	30624	215	38C
0005435214361	30624	216	38K
0005432528817	30624	217	38H
0005432528740	30624	218	39B
0005432528594	30624	219	39A
0005432528267	30624	220	39C
0005435214356	30624	221	39F
0005432528379	30624	222	39E
0005434068010	30624	223	39J
0005432159914	30624	224	39H
0005434067847	30624	225	39G
0005432528835	30624	226	39K
0005435214368	30624	227	40C
0005432535860	30624	228	40B
0005432528307	30624	229	40G
0005432535842	30624	230	40K
0005432528216	30624	231	40J
0005435214367	30624	232	41A
0005432528169	30624	233	41D
0005435631004	30624	234	41C
0005432428949	30624	235	41B
0005432528279	30624	236	41F
0005434067984	30624	237	41E
0005434067827	30624	238	41H
0005434067646	30624	239	41K
0005435214357	30624	240	41J
0005435725661	30624	241	42B
0005432535838	30624	242	42E
0005432528961	30624	243	42D
0005435214397	30624	244	42G
0005434067710	30624	245	42F
0005432528468	30624	246	42K
0005432528700	30624	247	42J
0005432528470	30624	248	43B
0005432528832	30624	249	43A
0005432529062	30624	250	43D
0005432528902	30624	251	43F
0005434067606	30624	252	43E
0005432527831	30624	253	43H
0005434067652	30624	254	43K
0005435283411	30624	255	43J
0005432533305	30624	256	44C
0005435214379	30624	257	44A
0005432528629	30624	258	44E
0005432528483	30624	259	44D
0005434067747	30624	260	44H
0005434068011	30624	261	44G
0005432528469	30624	262	44F
0005432211595	30624	263	44J
0005432528548	30624	264	45B
0005432528610	30624	265	45A
0005432528480	30624	266	45D
0005435214401	30624	267	45C
0005432528413	30624	268	45F
0005435214394	30624	269	45E
0005432428950	30624	270	45H
0005434067607	30624	271	46A
0005432159915	30624	272	45K
0005435214346	30624	273	45J
0005432528173	30624	274	46C
0005434067623	30624	275	46B
0005432528910	30624	276	46D
0005434067722	30624	277	46H
0005432528532	30624	278	46G
0005435214400	30624	279	46F
0005432537068	30624	280	46J
0005432528209	30624	281	47C
0005432535861	30624	282	47D
0005435214386	30624	283	47G
0005432528084	30624	284	47E
0005435631007	30624	285	47K
0005435214347	30624	286	47H
0005435214354	30624	287	48A
0005435214381	30624	288	48E
0005434067778	30624	289	48H
0005432528382	30624	290	48G
0005432528679	30624	291	48F
0005432528271	30624	292	49D
0005434067800	30624	293	49C
0005432528097	30624	294	49F
0005432528761	30624	295	49E
0005432528472	30624	296	49H
0005432528807	30624	297	50C
0005434067781	30624	298	50E
0005432528137	30624	299	50D
0005432211593	30624	300	50F
0005432528449	30624	301	50H
0005432528494	30624	302	51F
0005432528849	30624	303	51E
0005432528572	30624	304	51D
0005435214383	30624	305	51G
0005435653234	24871	1	1A
0005433368342	24871	2	1C
0005435653114	24871	3	1D
0005433368345	24871	4	1F
0005435653228	24871	5	2A
0005435653176	24871	6	2C
0005435653148	24871	7	2D
0005433368354	24871	8	2F
0005433368346	24871	9	3C
0005433368367	24871	10	3D
0005435653205	24871	11	3F
0005435653095	24871	12	4A
0005433368368	24871	13	4C
0005435653140	24871	14	4D
0005433368360	24871	15	4E
0005435653023	24871	16	4F
0005435653130	24871	17	5A
0005433368357	24871	18	5C
0005433368338	24871	19	5D
0005435653060	24871	20	5E
0005435653007	24871	21	5F
0005435653189	24871	22	6C
0005433368337	24871	23	6D
0005435653233	24871	24	6E
0005435653163	24871	25	6F
0005433368348	24871	26	7A
0005433368347	24871	27	7C
0005433368336	24871	28	7E
0005435653178	24871	29	8A
0005433368361	24871	30	8C
0005433368363	24871	31	8D
0005435653129	24871	32	8E
0005433368355	24871	33	8F
0005435653172	24871	34	9A
0005435653131	24871	35	9C
0005435653211	24871	36	9D
0005433368359	24871	37	9E
0005433368353	24871	38	10A
0005435653043	24871	39	10C
0005435653113	24871	40	10D
0005433368335	24871	41	10E
0005433368332	24871	42	10F
0005435653177	24871	43	11A
0005433368352	24871	44	11C
0005435653227	24871	45	11D
0005435653206	24871	46	11E
0005433368369	24871	47	12A
0005435653081	24871	48	12C
0005433368350	24871	49	12E
0005435653155	24871	50	13A
0005435653006	24871	51	13C
0005435653179	24871	52	13E
0005433368344	24871	53	13F
0005435653199	24871	54	14A
0005435653103	24871	55	14C
0005435652955	24871	56	14D
0005435653237	24871	57	14E
0005435653107	24871	58	15A
0005433368334	24871	59	15C
0005435653147	24871	60	15D
0005435652934	24871	61	15E
0005433368333	24871	62	15F
0005433368366	24871	63	16A
0005433368358	24871	64	16C
0005433368364	24871	65	16D
0005435653210	24871	66	16E
0005435653200	24871	67	16F
0005435653149	24871	68	17A
0005433368351	24871	69	17C
0005435653062	24871	70	17D
0005433368339	24871	71	17E
0005433368349	24871	72	17F
0005435653094	24871	73	18A
0005433368365	24871	74	18C
0005435653188	24871	75	18D
0005435653082	24871	76	18E
0005435653175	24871	77	19A
0005435653223	24871	78	19C
0005433368362	24871	79	19D
0005433368343	24871	80	19E
0005433368340	24871	81	19F
0005435653173	24871	82	20A
0005435653055	24871	83	20C
0005435653061	24871	84	20D
0005433368341	24871	85	20E
0005433368356	24871	86	20F
0005434980146	2017	1	1A
0005434980172	2017	2	1C
0005435801734	2017	3	2C
0005434980158	2017	4	3A
0005434980166	2017	5	3B
0005434980173	2017	6	3D
0005434980150	2017	7	4A
0005434980169	2017	8	4B
0005434980161	2017	9	4C
0005434980174	2017	10	4D
0005434980147	2017	11	5A
0005434980164	2017	12	5C
0005434980162	2017	13	6B
0005434980157	2017	14	6D
0005434980153	2017	15	7B
0005435801733	2017	16	7C
0005434980154	2017	17	7D
0005434980159	2017	18	18A
0005434980160	2017	19	18B
0005434980167	2017	20	18C
0005434980152	2017	21	19A
0005434980155	2017	22	19B
0005434980165	2017	23	19C
0005434980156	2017	24	20B
0005434980171	2017	25	20C
0005434980149	2017	26	20D
0005434980163	2017	27	21A
0005434980168	2017	28	21B
0005435801732	2017	29	21C
0005434980170	2017	30	21D
0005434980145	2017	31	22C
0005434980151	2017	32	22D
0005434980144	2017	33	23A
0005434980148	2017	34	23B
0005435801721	23563	1	1C
0005434979822	23563	2	2A
0005435801710	23563	3	2B
0005434979919	23563	4	2C
0005434979797	23563	5	3A
0005435801711	23563	6	4B
0005434979739	23563	7	4A
0005434979830	23563	8	4C
0005435801697	23563	9	4D
0005435801722	23563	10	5B
0005435801696	23563	11	5C
0005434979748	23563	12	5D
0005434979828	23563	13	6A
0005434979918	23563	14	6B
0005434979875	23563	15	6C
0005434979798	23563	16	6D
0005434979740	23563	17	7A
0005434979920	23563	18	7C
0005434979827	23563	19	7D
0005434979823	23563	20	18A
0005434979721	23563	21	18B
0005434979731	23563	22	18C
0005434979755	23563	23	18D
0005434979819	23563	24	19C
0005435801708	23563	25	19D
0005434979818	23563	26	20A
0005434979831	23563	27	20C
0005434979815	23563	28	21B
0005434979754	23563	29	22C
0005434979829	23563	30	22D
0005434979816	23563	31	23B
0005434952575	2593	1	1A
0005434952578	2593	2	3A
0005434952577	2593	3	5A
0005434952576	2593	4	6B
0005433256432	2612	1	3A
0005433256431	2612	2	3B
0005433256423	2612	3	5B
0005433256450	28261	1	2B
0005434952529	28261	2	3B
0005433111533	19804	1	1A
0005433111534	19804	2	4A
0005433112392	19804	3	5A
0005434138303	11931	1	1C
0005434138606	11931	2	1D
0005434138775	11931	3	2A
0005434138145	11931	4	2C
0005434138328	11931	5	2D
0005434138507	11931	6	2F
0005434138322	11931	7	3A
0005434138922	11931	8	3D
0005434138503	11931	9	3F
0005434138457	11931	10	4A
0005434138449	11931	11	4C
0005434138844	11931	12	4E
0005434138486	11931	13	5A
0005434138654	11931	14	5D
0005434138309	11931	15	5E
0005434138310	11931	16	5F
0005434138510	11931	17	6C
0005434138574	11931	18	6E
0005434138195	11931	19	6F
0005434138499	11931	20	7A
0005434138617	11931	21	7E
0005434138471	11931	22	7F
0005434138125	11931	23	8A
0005434138585	11931	24	8C
0005434138506	11931	25	8D
0005434138399	11931	26	8E
0005434138222	11931	27	8F
0005434138390	11931	28	9C
0005434138461	11931	29	9D
0005434138395	11931	30	9E
0005434138385	11931	31	9F
0005434138605	11931	32	10A
0005434138413	11931	33	10C
0005434138407	11931	34	10D
0005434138386	11931	35	10F
0005434138653	11931	36	11A
0005434138982	11931	37	11E
0005434138242	11931	38	11F
0005434138683	11931	39	12C
0005434138845	11931	40	12D
0005434138479	11931	41	12E
0005434138504	11931	42	12F
0005434138664	11931	43	13A
0005434138312	11931	44	13E
0005434138354	11931	45	13F
0005434138353	11931	46	14A
0005434138481	11931	47	14C
0005434138502	11931	48	14D
0005435283567	11931	49	14E
0005434138601	11931	50	14F
0005434138437	11931	51	15A
0005434138006	11931	52	15C
0005434138495	11931	53	15D
0005434137689	11931	54	15E
0005434138619	11931	55	16A
0005434138622	11931	56	16C
0005434138682	11931	57	16D
0005434138575	11931	58	16E
0005434138465	11931	59	17A
0005434138655	11931	60	17C
0005434138391	11931	61	17D
0005434138263	11931	62	17E
0005434138761	11931	63	17F
0005434138464	11931	64	18C
0005434138531	11931	65	18D
0005434138321	11931	66	18E
0005434137688	11931	67	18F
0005434138393	11931	68	19A
0005434138333	11931	69	19C
0005434138466	11931	70	19D
0005434138573	11931	71	19F
0005434138417	11931	72	20A
0005434138511	11931	73	20C
0005434138419	11931	74	20D
0005434138480	11931	75	20E
0005434138243	11931	76	20F
0005434139093	28750	1	1D
0005434139059	28750	2	1F
0005434139103	28750	3	2C
0005434139049	28750	4	2D
0005434139057	28750	5	2F
0005434139092	28750	6	3A
0005434139069	28750	7	3C
0005434139078	28750	8	3F
0005434139067	28750	9	4A
0005434139052	28750	10	4C
0005434139125	28750	11	4D
0005434139085	28750	12	4E
0005434139100	28750	13	4F
0005434139115	28750	14	5A
0005434139128	28750	15	5C
0005434139088	28750	16	5D
0005434139076	28750	17	5F
0005434139097	28750	18	6A
0005434139095	28750	19	6C
0005434139098	28750	20	6D
0005434139126	28750	21	6E
0005434139120	28750	22	6F
0005434139068	28750	23	7A
0005434139075	28750	24	7D
0005434139058	28750	25	7F
0005434139064	28750	26	8A
0005434139108	28750	27	8C
0005434139111	28750	28	8F
0005434139062	28750	29	9A
0005434139101	28750	30	9C
0005434139079	28750	31	9E
0005434139081	28750	32	9F
0005434139117	28750	33	10A
0005434139116	28750	34	10C
0005434139074	28750	35	10D
0005434139106	28750	36	10E
0005434139096	28750	37	10F
0005434139063	28750	38	11C
0005434139118	28750	39	11D
0005434139072	28750	40	11E
0005434139077	28750	41	11F
0005434139051	28750	42	12A
0005434139082	28750	43	12C
0005434139086	28750	44	12D
0005434139091	28750	45	12E
0005434139112	28750	46	12F
0005434139060	28750	47	13A
0005434139073	28750	48	13C
0005434139054	28750	49	13D
0005434139109	28750	50	13E
0005434139089	28750	51	13F
0005434139065	28750	52	14A
0005434139055	28750	53	14C
0005434139105	28750	54	14D
0005434139053	28750	55	14E
0005434139050	28750	56	14F
0005434139099	28750	57	15A
0005434139122	28750	58	15C
0005434139080	28750	59	15D
0005434139066	28750	60	15E
0005434139119	28750	61	15F
0005434139102	28750	62	16A
0005434139124	28750	63	16D
0005434139110	28750	64	16E
0005434139129	28750	65	16F
0005434139061	28750	66	17A
0005434139083	28750	67	17C
0005434139127	28750	68	17D
0005434139113	28750	69	17F
0005434139090	28750	70	18A
0005434139056	28750	71	18C
0005434139048	28750	72	18E
0005434139107	28750	73	19A
0005434139121	28750	74	19C
0005434139070	28750	75	19D
0005434139104	28750	76	19E
0005434139084	28750	77	19F
0005434139114	28750	78	20A
0005434139087	28750	79	20C
0005434139123	28750	80	20D
0005434139071	28750	81	20E
0005434139094	28750	82	20F
0005433538981	6806	1	1C
0005433538975	6806	2	2A
0005433538977	6806	3	2D
0005433538980	6806	4	3A
0005433538974	6806	5	3B
0005433538978	6806	6	3C
0005433538973	6806	7	6B
0005433538976	6806	8	18C
0005435259764	6806	9	19A
0005433538979	6806	10	19B
0005435259765	6806	11	20D
0005433534524	6806	12	21C
0005433538972	6806	13	21D
0005433534525	6806	14	22B
0005433538932	25018	1	2C
0005433538900	25018	2	3A
0005433534504	25018	3	4A
0005433538919	25018	4	4C
0005433538878	25018	5	4D
0005435259812	25018	6	6D
0005433538880	25018	7	7D
0005435259811	25018	8	18C
0005433538879	25018	9	18D
0005433538918	25018	10	19D
0005433538923	25018	11	21A
0005433538933	25018	12	22D
0005433512059	851	1	1A
0005432922544	851	2	1B
0005433512053	851	3	4D
0005432922542	851	4	5A
0005433512058	851	5	6B
0005433512055	851	6	7B
0005432922526	851	7	18D
0005433512056	851	8	19B
0005433512057	851	9	21B
0005433512051	851	10	21C
0005433512054	851	11	22A
0005433512052	851	12	22D
0005432922575	16128	1	2A
0005432922577	16128	2	2C
0005433511979	16128	3	3B
0005433511973	16128	4	4A
0005432922574	16128	5	4C
0005432922576	16128	6	5B
0005433512033	16128	7	5C
0005433511988	16128	8	6C
0005433512032	16128	9	18B
0005433511984	16128	10	18C
0005433511974	16128	11	20B
0005433512010	16128	12	22A
0005432922573	16128	13	22D
0005435697678	3692	1	1A
0005435697687	3692	2	1B
0005435697683	3692	3	1C
0005435697696	3692	4	2B
0005434950584	3692	5	2C
0005435697679	3692	6	2D
0005435697685	3692	7	3A
0005435697698	3692	8	3B
0005435697701	3692	9	3C
0005434950586	3692	10	3D
0005435935064	3692	11	4A
0005435697694	3692	12	4B
0005435916176	3692	13	4C
0005435697690	3692	14	4D
0005435697697	3692	15	5A
0005434950583	3692	16	5B
0005435697688	3692	17	5C
0005435916169	3692	18	5D
0005435697681	3692	19	6A
0005435697704	3692	20	6B
0005435697682	3692	21	6C
0005435697693	3692	22	6D
0005435697702	3692	23	7B
0005435697703	3692	24	7C
0005435697680	3692	25	18A
0005435697695	3692	26	18B
0005435697700	3692	27	18D
0005435697684	3692	28	19A
0005434950585	3692	29	19B
0005434950587	3692	30	19C
0005435697676	3692	31	20A
0005435916178	3692	32	20C
0005435697677	3692	33	20D
0005435697686	3692	34	21A
0005435916177	3692	35	21B
0005435697699	3692	36	21C
0005435697692	3692	37	22A
0005435697691	3692	38	22B
0005435697689	3692	39	22D
0005435916166	3692	40	23A
0005434950552	16296	1	1A
0005435935080	16296	2	1B
0005435697425	16296	3	2B
0005435697503	16296	4	3B
0005434950561	16296	5	4A
0005435697438	16296	6	4C
0005435935081	16296	7	5D
0005435935083	16296	8	6B
0005435697484	16296	9	7A
0005435697483	16296	10	7C
0005434950562	16296	11	18A
0005434950553	16296	12	18C
0005435697426	16296	13	19A
0005434950558	16296	14	19B
0005435697473	16296	15	19D
0005435935082	16296	16	20D
0005435697276	16296	17	21A
0005435697464	16296	18	21C
0005435697502	16296	19	21D
0005435697419	16296	20	22B
0005435697439	16296	21	22C
0005435697430	16296	22	22D
0005435697402	16296	23	23A
0005434950551	16296	24	23B
0005435853622	3962	1	1B
0005432609782	3962	2	2B
0005435853621	3962	3	2D
0005434604940	3962	4	3B
0005434604942	3962	5	3D
0005432609783	3962	6	4D
0005432607615	3962	7	6A
0005434606872	3962	8	6B
0005435853623	3962	9	6D
0005432607618	3962	10	7A
0005433519515	3962	11	7B
0005434604943	3962	12	7C
0005434606871	3962	13	7D
0005434604939	3962	14	18A
0005433519514	3962	15	19A
0005433519516	3962	16	19B
0005435842329	3962	17	20C
0005435853627	3962	18	20D
0005433519513	3962	19	21A
0005432607616	3962	20	21B
0005432607617	3962	21	22A
0005435842330	3962	22	22B
0005434606873	3962	23	22C
0005432609781	3962	24	22D
0005434604941	3962	25	23A
0005434606844	22044	1	1A
0005432613859	22044	2	1B
0005432609723	22044	3	1C
0005432613870	22044	4	1D
0005432613846	22044	5	2B
0005433519474	22044	6	2C
0005432609702	22044	7	2D
0005432613867	22044	8	3B
0005432613863	22044	9	3C
0005433519475	22044	10	3D
0005432613869	22044	11	4A
0005432613872	22044	12	4B
0005435841102	22044	13	4C
0005432613877	22044	14	4D
0005432613864	22044	15	5A
0005432609722	22044	16	5B
0005432613876	22044	17	5C
0005432613845	22044	18	5D
0005432609731	22044	19	6A
0005432609739	22044	20	6B
0005432613865	22044	21	6C
0005433519486	22044	22	6D
0005432613848	22044	23	7A
0005432613873	22044	24	7B
0005432613861	22044	25	7C
0005432613874	22044	26	7D
0005433519488	22044	27	18A
0005432609746	22044	28	18C
0005432613860	22044	29	18D
0005432613858	22044	30	19A
0005432609744	22044	31	19B
0005432613878	22044	32	19C
0005432609733	22044	33	19D
0005432609745	22044	34	20A
0005432609724	22044	35	20B
0005432613871	22044	36	20C
0005432609719	22044	37	21A
0005432609729	22044	38	21B
0005432613862	22044	39	21C
0005435841103	22044	40	21D
0005432609734	22044	41	22A
0005434606843	22044	42	22B
0005432609732	22044	43	22C
0005432613866	22044	44	22D
0005432609718	22044	45	23A
0005432609725	22044	46	23B
0005435628763	709	1	1A
0005435628762	709	2	1B
0005433349008	709	3	2A
0005433349012	709	4	2B
0005435628766	709	5	3A
0005433349007	709	6	4A
0005435628764	709	7	4B
0005433349029	709	8	5A
0005435628765	709	9	5B
0005433349013	709	10	6A
0005435628767	709	11	6B
0005433349060	15876	1	1A
0005433349064	15876	2	1B
0005433349065	15876	3	2A
0005435628737	15876	4	2B
0005433349061	15876	5	4B
0005435628738	15876	6	5B
0005435628735	15876	7	5A
0005433349062	15876	8	6A
0005433349063	15876	9	6B
0005433159318	17149	1	1A
0005434446543	17149	2	1B
0005434446542	17149	3	3A
0005434446541	17149	4	3B
0005434445269	17149	5	4A
0005434445270	17149	6	4B
0005434446540	17149	7	5A
0005433159317	17149	8	6A
0005433159341	17575	1	1A
0005434445250	17575	2	1B
0005433159340	17575	3	2A
0005433159342	17575	4	4A
0005433159343	17575	5	6A
0005435383181	7876	1	3B
0005435133010	7876	2	4B
0005435133015	7876	3	5A
0005435133017	7876	4	5B
0005435383182	7876	5	7A
0005435133016	7876	6	7B
0005435133014	7876	7	7C
0005435133018	7876	8	18D
0005435133011	7876	9	19D
0005435133013	7876	10	20A
0005435383177	7876	11	20B
0005435133012	7876	12	21A
0005435133009	7876	13	21C
0005435383215	33075	1	1B
0005435132995	33075	2	1D
0005435383216	33075	3	2B
0005435132936	33075	4	2C
0005435132996	33075	5	2D
0005435132943	33075	6	3A
0005435132922	33075	7	3B
0005435132956	33075	8	4D
0005435132906	33075	9	5D
0005435383219	33075	10	6A
0005435132896	33075	11	6C
0005435383218	33075	12	6D
0005435132911	33075	13	7C
0005435383217	33075	14	7D
0005435132895	33075	15	18B
0005435132937	33075	16	18D
0005435132925	33075	17	20B
0005435132938	33075	18	21B
0005435132905	33075	19	21C
0005435132904	33075	20	22B
0005435132926	33075	21	22D
0005435132928	33075	22	23A
0005435938903	4398	1	2A
0005435811137	4398	2	6F
0005435811136	4398	3	8F
0005435938886	4398	4	9F
0005435938891	4398	5	9E
0005435811141	4398	6	11D
0005435811140	4398	7	12A
0005435811138	4398	8	13A
0005435811139	4398	9	13C
0005435938885	4398	10	14A
0005435811134	4398	11	14E
0005435811132	4398	12	14F
0005435811135	4398	13	17B
0005435811133	4398	14	18F
0005435811131	4398	15	20B
0005435938902	4398	16	21F
0005435811074	29450	1	2D
0005435811102	29450	2	4F
0005435811085	29450	3	6A
0005435811071	29450	4	6C
0005435811095	29450	5	7E
0005435811070	29450	6	9E
0005435938920	29450	7	9F
0005435811117	29450	8	10C
0005435938916	29450	9	11A
0005435811077	29450	10	11C
0005435811093	29450	11	13E
0005435938917	29450	12	13F
0005435811082	29450	13	14C
0005435811083	29450	14	14B
0005435811096	29450	15	15E
0005435811084	29450	16	17F
0005435811103	29450	17	18A
0005435938919	29450	18	18E
0005435938918	29450	19	19A
0005435811097	29450	20	18F
0005435938921	29450	21	20E
0005435811094	29450	22	21C
0005435390230	7494	1	1A
0005435160441	7494	2	1C
0005435160443	7494	3	1D
0005435390263	7494	4	2A
0005435160445	7494	5	2C
0005435160442	7494	6	2D
0005435160438	7494	7	4B
0005435160439	7494	8	4D
0005435160446	7494	9	5B
0005435160444	7494	10	6D
0005435390246	7494	11	7C
0005435160437	7494	12	19D
0005435160440	7494	13	20A
0005435160447	7494	14	20D
0005435160436	7494	15	21C
0005435390262	7494	16	21D
0005435160392	29539	1	1A
0005435160404	29539	2	1B
0005435160374	29539	3	3A
0005435390327	29539	4	3C
0005435160301	29539	5	3D
0005435160359	29539	6	4A
0005435160350	29539	7	4C
0005435160300	29539	8	6C
0005435160386	29539	9	6D
0005435160357	29539	10	7A
0005435390328	29539	11	7B
0005435390326	29539	12	7C
0005435390329	29539	13	18A
0005435160377	29539	14	18B
0005435160322	29539	15	18C
0005435160354	29539	16	19A
0005435160384	29539	17	19C
0005435390324	29539	18	20B
0005435390325	29539	19	20D
0005435390323	29539	20	21B
0005435160376	29539	21	21C
0005435160323	29539	22	22A
0005435160385	29539	23	22C
0005435160373	29539	24	23B
0005432394115	18467	1	1A
0005432398203	18467	2	1B
0005432394111	18467	3	2A
0005432398214	18467	4	3A
0005432398223	18467	5	3B
0005432394133	18467	6	4B
0005432394110	18467	7	5A
0005432398215	18467	8	5B
0005432394114	18467	9	6A
0005432398224	18467	10	6B
0005432398240	27142	1	1B
0005432400168	27142	2	2A
0005432398242	27142	3	3A
0005432400169	27142	4	3B
0005432398241	27142	5	4B
0005432400170	27142	6	5A
0005435104023	6521	1	1C
0005434504631	6521	2	1D
0005434504646	6521	3	1F
0005434504663	6521	4	2A
0005434504659	6521	5	3A
0005435104026	6521	6	3C
0005434504632	6521	7	3F
0005434504657	6521	8	4A
0005434504625	6521	9	4C
0005434504661	6521	10	4F
0005434504644	6521	11	5C
0005434504652	6521	12	5D
0005434504623	6521	13	5E
0005435104018	6521	14	5F
0005434504650	6521	15	6D
0005434504639	6521	16	6E
0005435104022	6521	17	7A
0005434504655	6521	18	7C
0005434504638	6521	19	7E
0005434504624	6521	20	8C
0005434504662	6521	21	8D
0005435104017	6521	22	9A
0005434504629	6521	23	9C
0005434504637	6521	24	9D
0005435104029	6521	25	9E
0005435104020	6521	26	9F
0005434504653	6521	27	10A
0005434504640	6521	28	10E
0005434504645	6521	29	10F
0005434504635	6521	30	11D
0005434504626	6521	31	11F
0005434504660	6521	32	12A
0005434504651	6521	33	12C
0005434504641	6521	34	12D
0005434504642	6521	35	12E
0005434504649	6521	36	13A
0005434504628	6521	37	13C
0005435104024	6521	38	13F
0005435104021	6521	39	14C
0005434504643	6521	40	14D
0005435104028	6521	41	14E
0005434504656	6521	42	15D
0005434504647	6521	43	16A
0005434504633	6521	44	16C
0005435104019	6521	45	16F
0005435104027	6521	46	17C
0005434504658	6521	47	17D
0005434504654	6521	48	18C
0005435104025	6521	49	18F
0005434504648	6521	50	19A
0005434504630	6521	51	19C
0005434504634	6521	52	19E
0005434504636	6521	53	20C
0005434504627	6521	54	20E
0005434503996	22645	1	1A
0005434504345	22645	2	1C
0005434504058	22645	3	2A
0005434504306	22645	4	2C
0005434504159	22645	5	3A
0005434504354	22645	6	3F
0005435103940	22645	7	4A
0005434504200	22645	8	4D
0005434504323	22645	9	4E
0005434504258	22645	10	4F
0005434504324	22645	11	5A
0005434504229	22645	12	5D
0005434504319	22645	13	7A
0005435103937	22645	14	7C
0005434503997	22645	15	7E
0005434504117	22645	16	7F
0005434504158	22645	17	8C
0005435103912	22645	18	8D
0005435103933	22645	19	8E
0005434504253	22645	20	9C
0005434504327	22645	21	9D
0005434504169	22645	22	11E
0005434504191	22645	23	11F
0005435103938	22645	24	12D
0005434504168	22645	25	12F
0005435103911	22645	26	13C
0005435103939	22645	27	13D
0005434504366	22645	28	14C
0005434504118	22645	29	14D
0005434504246	22645	30	15F
0005434504111	22645	31	16C
0005434504182	22645	32	16D
0005434504292	22645	33	17D
0005434504107	22645	34	18C
0005434504132	22645	35	18D
0005434504133	22645	36	18F
0005434504320	22645	37	19A
0005434504228	22645	38	20C
0005434504138	22645	39	20D
0005435800111	21309	1	1C
0005435800105	21309	2	2A
0005435800106	21309	3	2B
0005435800109	21309	4	3A
0005435800120	21309	5	3C
0005435800104	21309	6	3D
0005435800099	21309	7	4B
0005435800116	21309	8	4C
0005435800102	21309	9	5B
0005435800117	21309	10	5D
0005435800098	21309	11	7B
0005435800124	21309	12	7C
0005435800121	21309	13	18A
0005435800107	21309	14	18B
0005435800112	21309	15	18D
0005435800115	21309	16	19A
0005435800103	21309	17	19B
0005435800125	21309	18	19D
0005435800100	21309	19	20C
0005435800108	21309	20	21D
0005435800110	21309	21	23B
0005433368187	1643	1	1A
0005433367952	1643	2	1C
0005433367866	1643	3	1F
0005433367937	1643	4	2A
0005433368021	1643	5	2C
0005433367978	1643	6	2D
0005433368151	1643	7	2F
0005433368050	1643	8	3A
0005433367979	1643	9	3C
0005435653602	1643	10	3F
0005433367912	1643	11	4A
0005433368044	1643	12	4D
0005433367991	1643	13	4E
0005433367987	1643	14	4F
0005433368188	1643	15	5A
0005433368138	1643	16	5C
0005433368032	1643	17	5D
0005435653597	1643	18	5E
0005433367975	1643	19	5F
0005435653609	1643	20	6A
0005433368035	1643	21	6D
0005433367838	1643	22	6E
0005433367929	1643	23	6F
0005435653599	1643	24	7D
0005433368239	1643	25	7E
0005435653594	1643	26	7F
0005433368240	1643	27	8A
0005433367884	1643	28	8C
0005433368104	1643	29	8E
0005435653596	1643	30	8F
0005435653593	1643	31	9A
0005433368062	1643	32	9C
0005433367976	1643	33	9D
0005433368137	1643	34	9F
0005435653595	1643	35	10A
0005433367931	1643	36	10C
0005435653608	1643	37	10E
0005433367973	1643	38	10F
0005433367906	1643	39	11C
0005433368125	1643	40	11F
0005433367911	1643	41	12A
0005433368099	1643	42	12C
0005435653610	1643	43	12D
0005433368072	1643	44	13A
0005433368054	1643	45	13C
0005433368079	1643	46	13D
0005433368037	1643	47	13E
0005433367953	1643	48	13F
0005433367930	1643	49	14C
0005433368027	1643	50	14D
0005433368150	1643	51	14E
0005433368071	1643	52	15A
0005435653601	1643	53	15C
0005433368106	1643	54	15D
0005433368102	1643	55	15E
0005435653606	1643	56	15F
0005435653598	1643	57	16A
0005433368051	1643	58	16C
0005433367936	1643	59	16D
0005433368029	1643	60	16E
0005433368039	1643	61	17A
0005435653603	1643	62	17C
0005433368033	1643	63	17D
0005435653605	1643	64	17E
0005433368101	1643	65	17F
0005433368038	1643	66	18A
0005435653607	1643	67	18E
0005435653604	1643	68	18F
0005433368108	1643	69	19A
0005433368134	1643	70	19C
0005433368078	1643	71	19E
0005433368100	1643	72	19F
0005435653600	1643	73	20A
0005433368107	1643	74	20C
0005433368129	1643	75	20D
0005433368139	1643	76	20E
0005433368045	1643	77	20F
0005435653233	21696	1	1C
0005433368346	21696	2	1D
0005435653055	21696	3	1F
0005435653140	21696	4	2C
0005435652934	21696	5	2D
0005435653176	21696	6	2F
0005435653211	21696	7	3A
0005435653205	21696	8	3C
0005435653179	21696	9	3D
0005433368357	21696	10	3F
0005435653228	21696	11	4A
0005433368348	21696	12	4C
0005433368369	21696	13	4D
0005435653189	21696	14	4E
0005435653130	21696	15	4F
0005435653061	21696	16	5A
0005433368338	21696	17	5E
0005433368349	21696	18	6A
0005433368359	21696	19	6C
0005433368351	21696	20	6E
0005435653062	21696	21	6F
0005433368334	21696	22	7A
0005435653081	21696	23	7C
0005435653175	21696	24	7D
0005433368361	21696	25	7E
0005435653200	21696	26	7F
0005433368360	21696	27	8A
0005435653043	21696	28	8C
0005435653177	21696	29	8E
0005433368332	21696	30	8F
0005433368342	21696	31	9A
0005433368350	21696	32	9C
0005433368337	21696	33	9D
0005435652955	21696	34	9E
0005433368368	21696	35	9F
0005433368341	21696	36	10A
0005435653210	21696	37	10C
0005433368354	21696	38	10E
0005435653129	21696	39	10D
0005435653148	21696	40	10F
0005433368365	21696	41	11A
0005435653149	21696	42	11C
0005435653107	21696	43	11D
0005433368362	21696	44	11E
0005435653114	21696	45	11F
0005435653147	21696	46	12A
0005433368366	21696	47	12C
0005433368356	21696	48	12D
0005435653173	21696	49	12E
0005433368333	21696	50	12F
0005435653172	21696	51	13A
0005433368340	21696	52	13C
0005433368355	21696	53	13D
0005435653131	21696	54	13E
0005435653188	21696	55	13F
0005435653095	21696	56	14A
0005435653060	21696	57	14C
0005433368367	21696	58	14D
0005435653206	21696	59	14E
0005435653103	21696	60	14F
0005435653082	21696	61	15A
0005435653113	21696	62	15C
0005435653155	21696	63	15E
0005433368343	21696	64	15F
0005433368358	21696	65	16A
0005433368344	21696	66	16C
0005435653178	21696	67	16D
0005435653227	21696	68	16E
0005435653237	21696	69	17A
0005433368345	21696	70	17C
0005435653006	21696	71	17D
0005433368364	21696	72	17E
0005435653199	21696	73	17F
0005433368336	21696	74	18A
0005433368339	21696	75	18C
0005435653094	21696	76	18D
0005435653007	21696	77	18E
0005435653163	21696	78	18F
0005435653023	21696	79	19A
0005433368353	21696	80	19C
0005433368363	21696	81	19D
0005433368352	21696	82	19E
0005433368335	21696	83	19F
0005433368347	21696	84	20C
0005435653234	21696	85	20D
0005435653223	21696	86	20F
0005433986534	4147	1	1C
0005433986543	4147	2	1D
0005435788804	4147	3	2F
0005433986536	4147	4	3C
0005433986527	4147	5	3F
0005433986540	4147	6	4E
0005433986530	4147	7	4F
0005433986542	4147	8	5C
0005433986535	4147	9	6A
0005433986507	4147	10	6C
0005433986514	4147	11	6E
0005433986545	4147	12	6F
0005433986520	4147	13	7A
0005433986506	4147	14	7C
0005433986517	4147	15	8A
0005433986533	4147	16	8C
0005433986518	4147	17	8D
0005433986532	4147	18	8F
0005433986544	4147	19	9A
0005433986519	4147	20	9D
0005433986529	4147	21	9F
0005433986521	4147	22	10A
0005433986541	4147	23	10D
0005433986528	4147	24	10F
0005435788803	4147	25	11D
0005433986512	4147	26	11E
0005433986513	4147	27	12D
0005433986515	4147	28	13D
0005433986531	4147	29	13F
0005433986510	4147	30	15A
0005433986525	4147	31	15D
0005433986516	4147	32	15E
0005433986524	4147	33	15F
0005433986523	4147	34	17C
0005433986522	4147	35	17D
0005433986546	4147	36	17E
0005433986508	4147	37	18A
0005433986511	4147	38	18C
0005433986509	4147	39	18D
0005433986537	4147	40	18E
0005433986538	4147	41	19A
0005433986539	4147	42	19D
0005433986547	4147	43	19F
0005433986526	4147	44	20C
0005435788777	25689	1	1A
0005433986104	25689	2	1C
0005435788778	25689	3	1F
0005433986223	25689	4	2D
0005433986139	25689	5	2F
0005433986026	25689	6	3A
0005433986194	25689	7	3D
0005433986133	25689	8	3F
0005433986192	25689	9	4C
0005433985975	25689	10	4D
0005433986160	25689	11	4E
0005433986090	25689	12	4F
0005433985991	25689	13	5D
0005433985955	25689	14	5E
0005433986064	25689	15	5F
0005433986102	25689	16	6A
0005433986056	25689	17	6D
0005433986124	25689	18	6E
0005433985939	25689	19	7A
0005433986222	25689	20	7D
0005433986117	25689	21	7F
0005433985974	25689	22	8A
0005433985960	25689	23	8C
0005433986158	25689	24	8F
0005433986106	25689	25	9A
0005433986054	25689	26	9C
0005433986057	25689	27	9D
0005433986049	25689	28	9E
0005433986071	25689	29	9F
0005433986073	25689	30	10A
0005433986070	25689	31	10D
0005433986162	25689	32	10F
0005433986165	25689	33	11A
0005433986075	25689	34	11C
0005433986028	25689	35	11E
0005433986055	25689	36	11F
0005433986157	25689	37	12A
0005433985840	25689	38	12C
0005433986097	25689	39	12D
0005433986116	25689	40	12F
0005433986125	25689	41	13C
0005433986105	25689	42	13D
0005433985861	25689	43	13E
0005433985949	25689	44	14C
0005433986141	25689	45	14D
0005433986098	25689	46	15D
0005433986065	25689	47	15E
0005433986140	25689	48	16A
0005433986159	25689	49	16C
0005433986050	25689	50	16E
0005433986025	25689	51	16F
0005433985948	25689	52	17D
0005433986027	25689	53	17E
0005433986072	25689	54	18A
0005433985997	25689	55	18D
0005433985860	25689	56	18E
0005433985961	25689	57	18F
0005433986132	25689	58	19A
0005433986163	25689	59	19C
0005433986003	25689	60	19E
0005433986126	25689	61	20D
0005433986164	25689	62	20E
0005433986142	25689	63	20F
0005435720826	21252	1	1C
0005435720825	21252	2	4D
0005435719572	24768	1	1C
0005433168389	1620	1	1B
0005434509243	1620	2	1C
0005434509241	1620	3	1D
0005434509248	1620	4	2B
0005434509238	1620	5	2C
0005433168391	1620	6	2D
0005433168387	1620	7	3B
0005434509245	1620	8	3D
0005433168379	1620	9	4A
0005433168388	1620	10	4C
0005433168380	1620	11	4D
0005434509250	1620	12	5A
0005434509247	1620	13	5C
0005433168401	1620	14	6A
0005434509244	1620	15	6C
0005434509249	1620	16	18C
0005434509240	1620	17	19A
0005434509242	1620	18	19B
0005433168390	1620	19	19D
0005434509235	1620	20	20B
0005434509246	1620	21	20C
0005434509237	1620	22	22C
0005434509239	1620	23	22D
0005434509236	1620	24	23A
0005432659720	17823	1	1C
0005432659721	17823	2	1D
0005432869608	17823	3	2A
0005434151742	17823	4	2D
0005432655562	17823	5	2F
0005432661928	17823	6	3C
0005432869611	17823	7	3F
0005432660823	17823	8	4A
0005434151743	17823	9	4C
0005432666385	17823	10	4F
0005432657453	17823	11	5D
0005432655520	17823	12	6C
0005432655531	17823	13	6D
0005432869614	17823	14	6E
0005432869612	17823	15	6F
0005432658593	17823	16	7A
0005432666398	17823	17	7C
0005432655597	17823	18	7D
0005432663051	17823	19	7F
0005432657466	17823	20	8D
0005432659713	17823	21	8E
0005432655552	17823	22	9A
0005432666397	17823	23	9F
0005432665283	17823	24	10A
0005432661920	17823	25	10D
0005432655553	17823	26	10E
0005432655584	17823	27	10F
0005432658594	17823	28	11E
0005432869615	17823	29	12A
0005432667453	17823	30	12C
0005432869613	17823	31	12E
0005432655579	17823	32	12F
0005432661935	17823	33	13A
0005432664139	17823	34	13E
0005432661921	17823	35	13F
0005432655515	17823	36	14A
0005432869610	17823	37	14C
0005432869607	17823	38	14D
0005432655529	17823	39	14F
0005432869609	17823	40	15D
0005432657454	17823	41	15F
0005432655578	17823	42	16A
0005432655589	17823	43	16C
0005432665282	17823	44	16E
0005434151741	17823	45	17A
0005432655577	17823	46	17E
0005432666393	17823	47	17F
0005432666392	17823	48	18A
0005432655550	17823	49	19C
0005432659714	17823	50	19E
0005432660827	17823	51	20C
0005432655627	17823	52	20D
0005432655530	17823	53	20E
0005432655585	17823	54	20F
0005432666411	26333	1	1C
0005432869518	26333	2	1D
0005432660841	26333	3	2A
0005432655656	26333	4	2D
0005432657483	26333	5	3C
0005432655658	26333	6	3D
0005432665298	26333	7	3F
0005432655657	26333	8	4F
0005432659730	26333	9	6A
0005432655665	26333	10	6F
0005432869517	26333	11	7A
0005432655659	26333	12	7E
0005432655667	26333	13	8C
0005432657484	26333	14	10C
0005432655663	26333	15	10D
0005432667476	26333	16	10E
0005432666412	26333	17	11E
0005432655661	26333	18	12A
0005432655660	26333	19	13A
0005432659729	26333	20	14F
0005432658615	26333	21	15A
0005432660840	26333	22	15E
0005432659728	26333	23	15F
0005432869542	26333	24	16A
0005432658614	26333	25	17A
0005432667477	26333	26	17C
0005432657482	26333	27	17D
0005432655664	26333	28	18D
0005432655662	26333	29	19A
0005432869574	26333	30	19D
0005432869573	26333	31	19E
0005432655666	26333	32	20F
0005432866098	25055	1	1D
0005432866105	25055	2	2A
0005432639159	25055	3	2C
0005432866103	25055	4	2F
0005432639132	25055	5	3C
0005432866100	25055	6	4C
0005432866106	25055	7	4D
0005432639160	25055	8	4E
0005432639173	25055	9	6C
0005432866099	25055	10	6D
0005432866096	25055	11	7A
0005432639168	25055	12	7C
0005432639174	25055	13	7F
0005432639162	25055	14	8A
0005432639177	25055	15	8C
0005432639169	25055	16	9C
0005432639153	25055	17	10D
0005432639157	25055	18	11A
0005432639093	25055	19	11C
0005432639152	25055	20	11D
0005432639147	25055	21	12E
0005432866097	25055	22	13C
0005432866104	25055	23	13F
0005432639193	25055	24	15D
0005432639158	25055	25	15E
0005432866101	25055	26	16C
0005432866107	25055	27	17C
0005432866095	25055	28	18D
0005432866094	25055	29	19C
0005432866102	25055	30	19F
0005432866108	25055	31	20D
0005432329282	3098	1	1A
0005432329294	3098	2	1C
0005432329298	3098	3	1D
0005432905139	3098	4	1F
0005432329277	3098	5	2A
0005432329292	3098	6	2C
0005432329265	3098	7	3C
0005432329293	3098	8	3D
0005432905161	3098	9	3F
0005432329287	3098	10	4A
0005432329281	3098	11	4E
0005432329260	3098	12	4F
0005432905141	3098	13	5A
0005432329255	3098	14	5C
0005432329279	3098	15	5D
0005432329254	3098	16	5E
0005432287255	3098	17	5F
0005432329264	3098	18	6E
0005432329274	3098	19	6F
0005432329257	3098	20	7A
0005433438969	3098	21	7D
0005432329296	3098	22	7E
0005432329266	3098	23	7F
0005432329289	3098	24	8A
0005432287251	3098	25	8C
0005432329263	3098	26	8D
0005432905154	3098	27	8E
0005432329290	3098	28	9A
0005432329291	3098	29	9C
0005432329278	3098	30	9E
0005432905163	3098	31	10C
0005432905164	3098	32	10D
0005432329253	3098	33	10F
0005432329262	3098	34	11D
0005432329261	3098	35	11E
0005432905162	3098	36	12A
0005432329276	3098	37	12C
0005432329283	3098	38	12F
0005432329273	3098	39	13A
0005432329275	3098	40	13C
0005432329286	3098	41	13D
0005432329272	3098	42	13E
0005433438970	3098	43	13F
0005432287253	3098	44	14A
0005432329270	3098	45	14C
0005432329256	3098	46	14D
0005432287252	3098	47	14F
0005432905160	3098	48	15A
0005432329280	3098	49	15D
0005432905159	3098	50	15E
0005432329271	3098	51	15F
0005432329297	3098	52	16A
0005432905142	3098	53	16C
0005432905138	3098	54	16D
0005432329285	3098	55	16E
0005432329267	3098	56	17A
0005432329284	3098	57	17C
0005432329295	3098	58	17D
0005432329288	3098	59	17E
0005432329269	3098	60	17F
0005432905140	3098	61	18C
0005432329259	3098	62	18D
0005432329268	3098	63	18F
0005432905153	3098	64	19A
0005432905132	3098	65	19C
0005432329258	3098	66	19D
0005432905131	3098	67	19E
0005432905155	3098	68	20C
0005432287254	3098	69	20E
0005433438919	31139	1	1D
0005432328858	31139	2	1F
0005432328903	31139	3	2D
0005432328878	31139	4	2F
0005433438887	31139	5	3C
0005432328871	31139	6	3D
0005432328663	31139	7	4A
0005432848842	31139	8	4C
0005432328991	31139	9	4D
0005433438893	31139	10	4E
0005432328887	31139	11	4F
0005432328749	31139	12	5C
0005432328907	31139	13	5D
0005432328847	31139	14	5E
0005432905201	31139	15	6C
0005432328857	31139	16	6D
0005433438899	31139	17	6E
0005432328792	31139	18	6F
0005432328886	31139	19	7C
0005432328998	31139	20	7D
0005432328995	31139	21	7E
0005432328809	31139	22	7F
0005432328796	31139	23	8C
0005432328702	31139	24	8E
0005432328895	31139	25	9A
0005432905196	31139	26	9C
0005432328808	31139	27	9D
0005432328867	31139	28	9E
0005432905197	31139	29	9F
0005432905200	31139	30	10A
0005432328900	31139	31	10C
0005432328651	31139	32	10D
0005432328810	31139	33	10E
0005433438888	31139	34	10F
0005432328748	31139	35	11A
0005433438907	31139	36	11D
0005432329048	31139	37	12C
0005432054341	31139	38	12D
0005432328904	31139	39	12F
0005432328760	31139	40	13A
0005432328664	31139	41	13C
0005433438906	31139	42	13F
0005433438925	31139	43	14C
0005432328652	31139	44	14D
0005432328795	31139	45	14F
0005432328999	31139	46	15A
0005432328837	31139	47	15D
0005432328846	31139	48	15E
0005433438886	31139	49	16A
0005432328935	31139	50	16C
0005432328936	31139	51	16D
0005432328703	31139	52	16F
0005432328793	31139	53	17A
0005432905203	31139	54	17C
0005433438918	31139	55	18A
0005432905202	31139	56	18E
0005432328692	31139	57	18F
0005432328934	31139	58	19A
0005432905199	31139	59	19D
0005432328908	31139	60	19E
0005432848841	31139	61	20A
0005432328780	31139	62	20C
0005432905198	31139	63	20D
0005432328779	31139	64	20E
0005434309917	6203	1	1C
0005435487927	6203	2	1A
0005434309909	6203	3	1D
0005435487905	6203	4	2A
0005434309915	6203	5	1F
0005435487808	6203	6	2D
0005432146227	6203	7	2F
0005435297095	6203	8	3A
0005435999467	6203	9	4C
0005435999470	6203	10	4B
0005435999471	6203	11	4D
0005435487840	6203	12	5A
0005435487841	6203	13	5B
0005434309919	6203	14	5D
0005435297074	6203	15	5E
0005435297041	6203	16	6C
0005435999473	6203	17	6D
0005435999462	6203	18	7A
0005435487928	6203	19	7B
0005435297100	6203	20	7D
0005432146226	6203	21	7F
0005435999466	6203	22	8B
0005435487902	6203	23	8C
0005435297099	6203	24	8F
0005432146225	6203	25	9A
0005435487848	6203	26	9D
0005435297084	6203	27	9E
0005435999468	6203	28	10C
0005435487929	6203	29	10E
0005435487948	6203	30	11A
0005435487884	6203	31	11B
0005435999457	6203	32	11E
0005434309906	6203	33	11F
0005435999463	6203	34	12C
0005435999458	6203	35	12B
0005435487810	6203	36	12D
0005435297094	6203	37	12E
0005434309910	6203	38	13A
0005435999459	6203	39	13D
0005435999475	6203	40	13E
0005432146224	6203	41	13F
0005435999461	6203	42	14B
0005435487801	6203	43	14A
0005435487947	6203	44	14C
0005435999474	6203	45	14D
0005435487809	6203	46	15C
0005434309912	6203	47	15E
0005434309916	6203	48	15F
0005434309913	6203	49	16B
0005435999460	6203	50	16C
0005434309911	6203	51	16F
0005435999465	6203	52	17B
0005435487866	6203	53	17E
0005435999472	6203	54	17F
0005434309914	6203	55	18B
0005435999469	6203	56	18D
0005435487901	6203	57	18F
0005435487846	6203	58	19A
0005435297086	6203	59	19B
0005435487871	6203	60	19C
0005435999464	6203	61	19D
0005435297085	6203	62	19F
0005435297096	6203	63	20B
0005435297098	6203	64	20D
0005435487931	6203	65	21A
0005434309908	6203	66	21C
0005435487932	6203	67	21B
0005435487982	6203	68	21D
0005434309907	6203	69	21E
0005435487938	6203	70	22A
0005432146223	6203	71	22D
0005434309918	6203	72	22E
0005435297073	6203	73	23B
0005435297083	6203	74	23C
0005435297042	6203	75	23E
0005435487912	6203	76	23F
0005435999316	19557	1	1A
0005435297147	19557	2	1F
0005435488081	19557	3	1D
0005434309834	19557	4	2C
0005434309833	19557	5	2F
0005434309782	19557	6	3C
0005435999300	19557	7	3D
0005434309824	19557	8	4A
0005435488090	19557	9	4C
0005435488085	19557	10	4D
0005435488075	19557	11	5A
0005435999295	19557	12	5C
0005435488077	19557	13	5B
0005435999321	19557	14	5D
0005435488093	19557	15	5E
0005434309776	19557	16	6A
0005435488088	19557	17	6E
0005434309849	19557	18	6F
0005435999288	19557	19	7C
0005434309835	19557	20	7D
0005434309759	19557	21	7E
0005435999296	19557	22	8A
0005434309769	19557	23	8B
0005435488076	19557	24	8D
0005435999268	19557	25	8F
0005435488095	19557	26	9A
0005435488074	19557	27	9C
0005435999280	19557	28	9F
0005434309787	19557	29	10E
0005435488079	19557	30	11B
0005434309794	19557	31	11C
0005435488083	19557	32	11E
0005435999265	19557	33	12A
0005434309829	19557	34	12B
0005434309799	19557	35	12E
0005435488087	19557	36	12F
0005435297145	19557	37	13D
0005435297146	19557	38	14A
0005435488086	19557	39	13F
0005435999320	19557	40	14B
0005434309828	19557	41	14C
0005435999293	19557	42	14D
0005434309812	19557	43	14E
0005435297148	19557	44	14F
0005435488078	19557	45	15D
0005434309802	19557	46	16A
0005435488091	19557	47	16B
0005435488092	19557	48	16C
0005434309813	19557	49	16E
0005435999294	19557	50	16D
0005434309711	19557	51	17A
0005435297143	19557	52	16F
0005435488084	19557	53	17C
0005434309754	19557	54	17D
0005435297144	19557	55	17F
0005434309755	19557	56	18A
0005435297141	19557	57	18E
0005434309758	19557	58	19D
0005434309735	19557	59	19C
0005434309710	19557	60	19E
0005434309762	19557	61	20B
0005435488089	19557	62	20A
0005435488080	19557	63	20C
0005435488094	19557	64	22B
0005435999252	19557	65	22C
0005435297142	19557	66	23C
0005434309848	19557	67	23D
0005435488082	19557	68	23F
0005435502593	1586	1	1A
0005435508501	1586	2	1C
0005435502592	1586	3	1D
0005434566077	1586	4	1F
0005434566081	1586	5	2A
0005434566086	1586	6	2C
0005435518146	1586	7	2D
0005434566079	1586	8	2F
0005435508498	1586	9	3A
0005434566085	1586	10	3C
0005435502591	1586	11	3D
0005435502585	1586	12	3F
0005435508504	1586	13	4A
0005435502583	1586	14	4C
0005435508494	1586	15	4D
0005435518148	1586	16	4E
0005435518154	1586	17	4F
0005435502582	1586	18	5A
0005434566083	1586	19	5C
0005434566090	1586	20	5E
0005435502586	1586	21	5F
0005434566078	1586	22	6A
0005433186168	1586	23	6C
0005433186098	1586	24	6D
0005435502579	1586	25	6E
0005434566089	1586	26	6F
0005435502588	1586	27	7A
0005435518152	1586	28	7C
0005435518156	1586	29	7E
0005435518151	1586	30	7F
0005435518144	1586	31	8A
0005434566091	1586	32	8C
0005432291960	1586	33	8E
0005435518140	1586	34	8F
0005435518157	1586	35	9A
0005435518145	1586	36	9C
0005435502577	1586	37	9D
0005435508495	1586	38	9E
0005434566082	1586	39	9F
0005435518143	1586	40	10A
0005433186141	1586	41	10C
0005435518147	1586	42	10D
0005435508500	1586	43	10E
0005435502589	1586	44	10F
0005435508497	1586	45	11A
0005435518155	1586	46	11C
0005435508506	1586	47	11E
0005434566087	1586	48	11F
0005434566088	1586	49	12A
0005435502578	1586	50	12C
0005432291961	1586	51	12D
0005433186099	1586	52	12E
0005435502594	1586	53	13C
0005435508502	1586	54	13D
0005435518137	1586	55	13E
0005435502580	1586	56	14A
0005435518142	1586	57	14E
0005435518139	1586	58	15C
0005433186149	1586	59	15D
0005435508493	1586	60	15E
0005435518138	1586	61	16A
0005435518141	1586	62	16C
0005435508505	1586	63	16D
0005435502575	1586	64	16E
0005434566080	1586	65	16F
0005435518153	1586	66	17A
0005434566084	1586	67	17C
0005435502584	1586	68	17D
0005435518149	1586	69	17E
0005435502587	1586	70	17F
0005435508499	1586	71	18A
0005435508507	1586	72	18C
0005435502574	1586	73	18D
0005435502590	1586	74	18E
0005435518150	1586	75	18F
0005435508496	1586	76	19A
0005434566092	1586	77	19C
0005435502581	1586	78	19D
0005435508508	1586	79	19E
0005435508503	1586	80	19F
0005435518136	1586	81	20A
0005435502595	1586	82	20D
0005433186140	1586	83	20C
0005435502576	1586	84	20E
0005433186167	1586	85	20F
0005435502306	20902	1	1A
0005435502430	20902	2	1C
0005435502401	20902	3	1D
0005435529317	20902	4	1F
0005433186229	20902	5	2A
0005435529230	20902	6	2C
0005435502407	20902	7	2F
0005435529212	20902	8	3A
0005435529319	20902	9	3C
0005435529307	20902	10	3D
0005435502318	20902	11	3F
0005435545757	20902	12	4A
0005435529250	20902	13	4D
0005434565987	20902	14	4F
0005435545791	20902	15	5A
0005433186224	20902	16	5C
0005435502409	20902	17	5D
0005433186222	20902	18	5F
0005434565989	20902	19	6A
0005435502365	20902	20	6C
0005435545756	20902	21	6D
0005435502416	20902	22	6F
0005435545724	20902	23	7C
0005435545759	20902	24	7D
0005435529312	20902	25	7F
0005435502307	20902	26	8C
0005435529347	20902	27	8D
0005435502454	20902	28	8F
0005435529252	20902	29	9A
0005434565962	20902	30	9C
0005435502296	20902	31	9E
0005433186228	20902	32	9F
0005435529320	20902	33	10A
0005435502455	20902	34	10D
0005435502415	20902	35	10E
0005433186225	20902	36	11D
0005435529226	20902	37	11F
0005435502378	20902	38	12C
0005435529288	20902	39	12D
0005435529330	20902	40	12E
0005435529305	20902	41	12F
0005435545750	20902	42	13A
0005433186223	20902	43	13C
0005434565928	20902	44	13E
0005435529306	20902	45	13F
0005434565979	20902	46	14A
0005435502377	20902	47	14C
0005435529227	20902	48	14E
0005435529287	20902	49	14F
0005434565978	20902	50	15A
0005435502408	20902	51	15C
0005435529289	20902	52	15D
0005435545760	20902	53	15F
0005435529328	20902	54	16A
0005435529266	20902	55	16C
0005435502433	20902	56	16D
0005434565965	20902	57	16E
0005435545747	20902	58	17A
0005435502434	20902	59	17C
0005435502325	20902	60	17D
0005433186230	20902	61	17E
0005435529256	20902	62	17F
0005435502372	20902	63	18A
0005434566007	20902	64	18D
0005435529251	20902	65	18E
0005435502414	20902	66	18F
0005435529311	20902	67	19A
0005433186227	20902	68	19C
0005434565988	20902	69	19E
0005433186226	20902	70	19F
0005435502324	20902	71	20A
0005435502316	20902	72	20C
0005435502373	20902	73	20D
0005435545749	20902	74	20E
0005435502469	20902	75	20F
0005435153822	3914	1	1C
0005435153823	3914	2	2A
0005435153825	3914	3	3D
0005435153826	3914	4	4B
0005435153824	3914	5	7A
0005435931617	3914	6	18C
0005435153827	3914	7	20C
0005435153828	3914	8	21B
0005435931626	3914	9	22A
0005435931635	3914	10	23A
0005435153759	21877	1	1A
0005435931647	21877	2	1B
0005435153768	21877	3	1C
0005435153770	21877	4	4D
0005435931648	21877	5	5C
0005435153760	21877	6	7A
0005435153767	21877	7	19B
0005435931649	21877	8	20C
0005435153753	21877	9	20D
0005435153769	21877	10	22C
0005432629040	7177	1	1A
0005435225629	7177	2	2A
0005432629032	7177	3	2D
0005432629029	7177	4	3B
0005432629036	7177	5	4C
0005432629039	7177	6	5A
0005435225613	7177	7	5B
0005435225645	7177	8	5C
0005435225584	7177	9	6A
0005432629037	7177	10	6D
0005432629031	7177	11	7C
0005432629030	7177	12	7D
0005435225567	7177	13	18A
0005435225622	7177	14	18B
0005432629038	7177	15	18C
0005432629026	7177	16	19C
0005432629027	7177	17	19D
0005435225634	7177	18	20A
0005432629028	7177	19	20B
0005435225643	7177	20	20C
0005432629033	7177	21	20D
0005435225644	7177	22	21A
0005435225614	7177	23	21B
0005432629034	7177	24	21D
0005432629025	7177	25	22B
0005432629035	7177	26	22C
0005435225583	7177	27	23A
0005432628908	28093	1	1D
0005435225688	28093	2	2A
0005435225687	28093	3	2C
0005432628889	28093	4	2D
0005435225686	28093	5	3D
0005432628924	28093	6	4A
0005432628934	28093	7	4B
0005432628926	28093	8	4C
0005432628933	28093	9	5B
0005432628863	28093	10	6A
0005435225685	28093	11	6C
0005435225684	28093	12	6D
0005435225682	28093	13	7A
0005432628948	28093	14	7D
0005435225689	28093	15	18A
0005432628927	28093	16	19C
0005432628923	28093	17	19D
0005432628873	28093	18	20D
0005432628906	28093	19	21A
0005435225683	28093	20	22A
0005432628907	28093	21	22D
0005434267961	8765	1	3D
0005435960098	8765	2	5A
0005434267950	8765	3	6D
0005435960097	8765	4	18B
0005434267962	8765	5	19A
0005435960099	8765	6	19B
0005434267976	8765	7	20B
0005434267949	8765	8	21B
0005434267998	15273	1	2A
0005435960062	15273	2	4B
0005435960060	15273	3	4C
0005434267997	15273	4	4D
0005435960059	15273	5	5A
0005434267999	15273	6	18C
0005435960076	15273	7	19C
0005435960075	15273	8	21A
0005434267996	15273	9	21D
0005434267995	15273	10	23A
0005432693436	1167	1	1C
0005432675323	1167	2	1A
0005432693431	1167	3	2A
0005432677619	1167	4	1F
0005432693413	1167	5	2F
0005432693428	1167	6	2D
0005432693433	1167	7	3A
0005432693412	1167	8	3D
0005432675320	1167	9	3F
0005432693426	1167	10	4C
0005432675321	1167	11	5C
0005432873303	1167	12	5A
0005432693422	1167	13	5F
0005432693411	1167	14	6B
0005432675318	1167	15	6C
0005432873295	1167	16	6E
0005432693419	1167	17	6F
0005432693416	1167	18	7C
0005432693437	1167	19	7B
0005432675329	1167	20	8D
0005432693430	1167	21	8C
0005432873314	1167	22	8E
0005432677620	1167	23	9F
0005432873302	1167	24	10C
0005432675319	1167	25	10B
0005432675325	1167	26	10E
0005432693417	1167	27	11B
0005432677618	1167	28	11E
0005432873330	1167	29	12A
0005432693434	1167	30	12F
0005432675317	1167	31	13A
0005432693440	1167	32	14A
0005432693429	1167	33	13F
0005432693435	1167	34	14C
0005432693425	1167	35	14B
0005432693424	1167	36	14E
0005432873331	1167	37	15C
0005432675326	1167	38	15B
0005432693414	1167	39	15F
0005432675315	1167	40	15E
0005432675316	1167	41	16E
0005432675322	1167	42	16D
0005432693441	1167	43	17A
0005432693415	1167	44	17F
0005432873318	1167	45	18A
0005432693418	1167	46	18D
0005432693421	1167	47	18C
0005432693432	1167	48	19A
0005432675327	1167	49	19B
0005432675324	1167	50	19E
0005432693439	1167	51	19D
0005432677617	1167	52	19F
0005432693423	1167	53	20C
0005432675328	1167	54	20F
0005432693420	1167	55	20E
0005432693427	1167	56	21A
0005432693438	1167	57	21D
0005432693164	17455	1	1A
0005432675212	17455	2	2C
0005432873382	17455	3	2A
0005432693226	17455	4	2F
0005432873380	17455	5	5C
0005432677585	17455	6	5D
0005432693214	17455	7	6A
0005432693129	17455	8	7A
0005432693089	17455	9	7C
0005432675127	17455	10	7B
0005432693271	17455	11	7E
0005432693136	17455	12	7D
0005432675182	17455	13	8B
0005432693377	17455	14	8D
0005432693241	17455	15	8C
0005432693196	17455	16	8F
0005432675201	17455	17	8E
0005432693155	17455	18	9A
0005432675218	17455	19	9D
0005432675130	17455	20	10C
0005432693229	17455	21	10E
0005432693137	17455	22	11E
0005432693135	17455	23	12F
0005432693141	17455	24	13B
0005432675150	17455	25	13E
0005432873379	17455	26	13D
0005432873377	17455	27	14B
0005432675149	17455	28	14F
0005432873381	17455	29	14E
0005432675233	17455	30	15A
0005432693147	17455	31	15E
0005432693175	17455	32	16B
0005432693186	17455	33	16A
0005432675211	17455	34	16F
0005432693204	17455	35	17C
0005432693190	17455	36	17D
0005432873384	17455	37	17F
0005432693272	17455	38	18B
0005432693165	17455	39	18C
0005432675172	17455	40	18D
0005432693243	17455	41	18F
0005432693140	17455	42	19E
0005432693242	17455	43	19D
0005432693218	17455	44	19F
0005432693262	17455	45	20A
0005432693134	17455	46	20E
0005432873383	17455	47	20D
0005432675234	17455	48	21A
0005432675137	17455	49	21B
0005432873378	17455	50	21F
0005432675183	17455	51	21D
0005433156807	1112	1	1A
0005434435378	1112	2	1B
0005433156787	1112	3	1C
0005433156806	1112	4	1D
0005434435368	1112	5	2A
0005434435380	1112	6	2C
0005434435370	1112	7	2D
0005434435381	1112	8	3A
0005434435372	1112	9	3D
0005434435379	1112	10	4A
0005434435374	1112	11	4B
0005433156742	1112	12	5A
0005433156795	1112	13	5B
0005434435367	1112	14	5D
0005433156741	1112	15	6C
0005434435377	1112	16	6D
0005434435371	1112	17	7D
0005433156798	1112	18	18C
0005433156802	1112	19	18D
0005434435375	1112	20	19A
0005434435373	1112	21	19C
0005434435369	1112	22	20A
0005434435376	1112	23	20C
0005433156816	1112	24	21C
0005434435382	1112	25	21D
0005433156805	1112	26	22C
0005434435234	17304	1	1A
0005434435255	17304	2	1C
0005434435221	17304	3	1D
0005433156858	17304	4	2A
0005434435290	17304	5	2C
0005434435227	17304	6	3D
0005434435195	17304	7	4A
0005433156856	17304	8	5C
0005434435243	17304	9	5D
0005434435260	17304	10	6B
0005433156860	17304	11	6D
0005434435222	17304	12	7A
0005434435239	17304	13	7B
0005434435233	17304	14	7C
0005434435263	17304	15	18A
0005434435182	17304	16	18B
0005434435196	17304	17	19A
0005433156853	17304	18	19B
0005434435282	17304	19	19C
0005433156854	17304	20	19D
0005433156855	17304	21	20C
0005433156857	17304	22	21A
0005434435261	17304	23	21B
0005434435244	17304	24	21D
0005434435181	17304	25	22A
0005434435254	17304	26	22B
0005434435271	17304	27	22C
0005433156861	17304	28	22D
0005433156859	17304	29	23B
0005435086933	4052	1	5A
0005435086927	4052	2	6C
0005435086925	4052	3	6D
0005435086930	4052	4	7A
0005435086932	4052	5	7B
0005435928176	4052	6	18A
0005435086926	4052	7	18D
0005435086928	4052	8	19C
0005435086934	4052	9	20C
0005435086929	4052	10	21A
0005435928149	4052	11	21B
0005435928148	4052	12	21D
0005435086931	4052	13	23A
0005435086868	24381	1	3C
0005435086824	24381	2	5C
0005435928203	24381	3	6B
0005435928204	24381	4	7A
0005435086870	24381	5	7B
0005435086869	24381	6	7C
0005435928202	24381	7	19B
0005435928205	24381	8	20C
0005435928201	24381	9	21C
0005435086871	24381	10	22C
0005434964472	1311	1	1G
0005434964478	1311	2	2B
0005433261586	1311	3	2H
0005433261531	1311	4	3C
0005434964449	1311	5	4C
0005433261610	1311	6	4G
0005433261587	1311	7	5A
0005433261620	1311	8	5G
0005434964455	1311	9	9B
0005434964462	1311	10	9A
0005433261578	1311	11	11B
0005434964456	1311	12	11D
0005434964477	1311	13	11E
0005434964465	1311	14	11G
0005434964469	1311	15	12D
0005432279299	1311	16	12E
0005433261562	1311	17	12F
0005434964467	1311	18	12G
0005434964454	1311	19	13G
0005434964451	1311	20	14F
0005432279297	1311	21	17F
0005433261605	1311	22	17E
0005433261592	1311	23	17G
0005434964453	1311	24	18D
0005432279295	1311	25	18B
0005434964476	1311	26	18F
0005433261627	1311	27	19B
0005434964464	1311	28	19E
0005434964445	1311	29	21F
0005433261577	1311	30	22A
0005434964466	1311	31	21G
0005434964452	1311	32	22G
0005433261590	1311	33	23A
0005433261619	1311	34	23E
0005434964479	1311	35	24B
0005434964448	1311	36	24F
0005434964460	1311	37	25D
0005434964458	1311	38	25E
0005434964474	1311	39	27A
0005434964480	1311	40	27D
0005433261648	1311	41	27B
0005434964468	1311	42	28B
0005433261604	1311	43	28E
0005434964459	1311	44	29E
0005432279296	1311	45	29G
0005432279298	1311	46	29F
0005434964447	1311	47	30G
0005434964461	1311	48	32A
0005433261585	1311	49	32B
0005434964450	1311	50	32E
0005433261598	1311	51	32D
0005433261623	1311	52	33D
0005434964442	1311	53	33H
0005433261597	1311	54	34D
0005433261594	1311	55	34E
0005434964471	1311	56	34F
0005434964443	1311	57	36B
0005434964457	1311	58	37D
0005434964470	1311	59	37F
0005434964475	1311	60	37H
0005434964444	1311	61	38A
0005434964473	1311	62	38G
0005433261611	1311	63	38F
0005434964463	1311	64	39E
0005434964446	1311	65	39F
0005433261690	18252	1	1F
0005434964271	18252	2	1H
0005434964249	18252	3	2B
0005433261699	18252	4	2F
0005434964309	18252	5	3F
0005433261697	18252	6	3H
0005433261687	18252	7	4A
0005434964300	18252	8	5A
0005434964170	18252	9	5F
0005434964247	18252	10	5H
0005434964246	18252	11	9A
0005434964276	18252	12	11G
0005434964209	18252	13	12A
0005433261689	18252	14	12B
0005434964277	18252	15	12E
0005434964272	18252	16	12G
0005434964265	18252	17	13E
0005434964299	18252	18	13H
0005434964297	18252	19	14B
0005434964281	18252	20	14H
0005434964319	18252	21	16G
0005434964169	18252	22	18F
0005434964225	18252	23	19B
0005434964298	18252	24	21B
0005433261684	18252	25	22A
0005433261698	18252	26	22D
0005433261686	18252	27	22F
0005433261695	18252	28	23E
0005433261691	18252	29	23H
0005434964288	18252	30	24E
0005434964343	18252	31	25D
0005434964295	18252	32	27B
0005433261681	18252	33	27H
0005434964226	18252	34	28D
0005434964245	18252	35	28F
0005434964296	18252	36	28H
0005434964287	18252	37	29D
0005434964349	18252	38	29G
0005434964168	18252	39	30B
0005433261685	18252	40	30H
0005434964285	18252	41	31D
0005434964275	18252	42	31H
0005434964264	18252	43	32F
0005433261683	18252	44	32G
0005434964330	18252	45	33A
0005433261688	18252	46	33B
0005434964259	18252	47	33G
0005434964279	18252	48	34A
0005434964248	18252	49	34D
0005433261682	18252	50	34E
0005434964308	18252	51	35B
0005433261694	18252	52	35A
0005433261696	18252	53	36A
0005434964304	18252	54	36E
0005434964278	18252	55	36D
0005433261693	18252	56	36F
0005434964331	18252	57	37E
0005433261692	18252	58	39E
0005434626080	4856	1	3C
0005433194860	4856	2	5E
0005434626084	4856	3	7A
0005435907534	4856	4	11C
0005434626082	4856	5	11E
0005434626079	4856	6	12A
0005435907539	4856	7	12D
0005434626083	4856	8	14E
0005434626076	4856	9	15C
0005434626078	4856	10	16A
0005434626081	4856	11	16E
0005435907533	4856	12	16F
0005433194853	4856	13	17A
0005433194854	4856	14	18E
0005434626077	4856	15	20C
0005433194893	32896	1	3C
0005433194894	32896	2	3D
0005435907563	32896	3	4C
0005434626012	32896	4	4F
0005435907568	32896	5	5C
0005434626013	32896	6	7A
0005434626001	32896	7	8C
0005433194892	32896	8	10A
0005435907565	32896	9	11C
0005435907567	32896	10	12C
0005435907564	32896	11	12E
0005435907566	32896	12	14E
0005434626007	32896	13	14F
0005434626015	32896	14	15A
0005433194895	32896	15	15E
0005434625986	32896	16	16A
0005434626016	32896	17	17D
0005433194897	32896	18	19E
0005433194896	32896	19	19F
0005434626005	32896	20	20E
0005435785495	13770	1	1A
0005435785377	13770	2	1B
0005435785452	13770	3	1C
0005435785520	13770	4	1D
0005435785496	13770	5	2A
0005435787363	13770	6	2B
0005435785484	13770	7	2C
0005435937439	13770	8	2D
0005435785540	13770	9	3A
0005435785394	13770	10	3B
0005435785409	13770	11	3C
0005435785319	13770	12	3D
0005435785396	13770	13	4A
0005435785363	13770	14	4B
0005432195719	13770	15	4C
0005435785431	13770	16	4D
0005435785466	13770	17	5A
0005435937438	13770	18	5B
0005435785387	13770	19	5C
0005435785398	13770	20	5D
0005435785441	13770	21	6A
0005435785485	13770	22	6B
0005435785372	13770	23	6C
0005435785400	13770	24	6D
0005435785567	13770	25	7A
0005435785401	13770	26	7B
0005435785320	13770	27	7C
0005435787365	13770	28	7D
0005435787355	13770	29	18B
0005435937437	13770	30	18A
0005435785348	13770	31	18C
0005435785558	13770	32	18D
0005435785468	13770	33	19B
0005435785499	13770	34	19C
0005435785397	13770	35	19D
0005435785259	13770	36	20A
0005435785455	13770	37	20B
0005435785471	13770	38	20C
0005432195718	13770	39	20D
0005435785347	13770	40	21A
0005435785393	13770	41	21C
0005435787364	13770	42	21B
0005435785503	13770	43	21D
0005435785364	13770	44	22A
0005435785430	13770	45	22B
0005435785417	13770	46	22C
0005435785399	13770	47	22D
0005435785376	13770	48	23A
0005432195720	13770	49	23B
0005435785752	27437	1	1A
0005435785723	27437	2	1D
0005435785739	27437	3	1C
0005435785729	27437	4	2A
0005435785742	27437	5	2B
0005435785753	27437	6	2C
0005435785735	27437	7	2D
0005435785749	27437	8	3A
0005435785732	27437	9	3B
0005435937389	27437	10	3C
0005435787379	27437	11	3D
0005435785751	27437	12	4A
0005435785720	27437	13	4B
0005435785740	27437	14	4C
0005435785745	27437	15	4D
0005435785736	27437	16	5A
0005435785747	27437	17	5B
0005432190672	27437	18	5C
0005435785728	27437	19	5D
0005432190671	27437	20	6B
0005435785725	27437	21	6C
0005435785721	27437	22	6D
0005432190673	27437	23	7A
0005435785733	27437	24	7B
0005435785727	27437	25	7C
0005435785731	27437	26	7D
0005435785746	27437	27	18A
0005435785744	27437	28	18B
0005435785737	27437	29	18C
0005435785741	27437	30	18D
0005435785724	27437	31	19A
0005435787377	27437	32	19B
0005435785730	27437	33	19C
0005435787378	27437	34	19D
0005435785743	27437	35	20A
0005435785722	27437	36	20B
0005435785734	27437	37	20C
0005435785726	27437	38	20D
0005435785750	27437	39	21B
0005435937380	27437	40	21C
0005435785755	27437	41	21D
0005432190670	27437	42	22A
0005435785754	27437	43	22B
0005432190674	27437	44	22C
0005435785738	27437	45	23A
0005435785748	27437	46	23B
0005434407543	20252	1	1A
0005434408174	20252	2	1C
0005434408029	20252	3	1D
0005434407785	20252	4	1F
0005434407810	20252	5	2C
0005434408072	20252	6	2D
0005434408061	20252	7	2F
0005434407983	20252	8	3A
0005434407671	20252	9	3C
0005434408198	20252	10	3D
0005434407904	20252	11	3F
0005434407847	20252	12	4C
0005434408200	20252	13	4D
0005434408213	20252	14	4F
0005434407932	20252	15	5A
0005434407947	20252	16	5C
0005434407903	20252	17	5D
0005434407807	20252	18	5E
0005434407756	20252	19	5F
0005435311223	20252	20	6A
0005434407829	20252	21	6C
0005434407809	20252	22	6D
0005434408203	20252	23	6E
0005434408045	20252	24	6F
0005432058432	20252	25	7A
0005434407729	20252	26	7C
0005434407616	20252	27	7E
0005434407945	20252	28	8A
0005435311220	20252	29	8C
0005434408046	20252	30	8D
0005434407918	20252	31	8E
0005434407949	20252	32	8F
0005434408042	20252	33	9A
0005434408201	20252	34	9C
0005434408205	20252	35	9D
0005434408060	20252	36	9E
0005432058431	20252	37	10A
0005434407952	20252	38	10D
0005434408206	20252	39	10E
0005435311222	20252	40	10F
0005434407757	20252	41	11A
0005432058430	20252	42	11C
0005434407670	20252	43	11E
0005434408053	20252	44	12A
0005434408287	20252	45	12C
0005434408055	20252	46	12D
0005435311225	20252	47	12E
0005434408212	20252	48	12F
0005434408033	20252	49	13A
0005434407770	20252	50	13C
0005435311221	20252	51	13E
0005434407808	20252	52	13F
0005434408288	20252	53	14A
0005434408015	20252	54	14D
0005434407997	20252	55	14E
0005434407933	20252	56	14F
0005434408214	20252	57	15A
0005434407973	20252	58	15C
0005434407706	20252	59	15D
0005434408030	20252	60	15F
0005434408067	20252	61	16A
0005434408172	20252	62	16C
0005434408182	20252	63	16D
0005434408000	20252	64	16F
0005434408211	20252	65	17A
0005434407811	20252	66	17C
0005434408196	20252	67	17D
0005434408185	20252	68	17E
0005434408173	20252	69	17F
0005434408068	20252	70	18A
0005434407946	20252	71	18C
0005434408157	20252	72	18D
0005434408034	20252	73	18E
0005434407863	20252	74	19A
0005434407862	20252	75	19E
0005434407786	20252	76	19F
0005434407978	20252	77	20A
0005434408043	20252	78	20C
0005435311224	20252	79	20E
0005434408555	27008	1	1A
0005434408544	27008	2	1C
0005435311084	27008	3	1D
0005434408524	27008	4	2A
0005435311096	27008	5	2C
0005435311043	27008	6	2D
0005435311068	27008	7	2F
0005434408576	27008	8	3C
0005434408547	27008	9	3D
0005434408573	27008	10	3F
0005434408527	27008	11	4A
0005434408551	27008	12	4C
0005434408561	27008	13	4D
0005435311082	27008	14	4E
0005434408562	27008	15	4F
0005434408570	27008	16	5A
0005434408558	27008	17	5C
0005434408574	27008	18	5D
0005434408537	27008	19	5E
0005435311081	27008	20	5F
0005434408522	27008	21	6A
0005434408523	27008	22	6C
0005434408528	27008	23	6E
0005434408543	27008	24	6D
0005434408532	27008	25	6F
0005434408566	27008	26	7A
0005434408538	27008	27	7C
0005432154025	27008	28	7D
0005434408515	27008	29	7E
0005434408549	27008	30	7F
0005434408525	27008	31	8A
0005434408559	27008	32	8D
0005435311077	27008	33	8E
0005432154024	27008	34	9A
0005434408512	27008	35	9C
0005434408548	27008	36	9D
0005432154028	27008	37	9E
0005434408569	27008	38	9F
0005432154026	27008	39	10A
0005434408521	27008	40	10C
0005434408567	27008	41	10E
0005434408530	27008	42	10F
0005432154021	27008	43	11A
0005434408513	27008	44	11C
0005434408552	27008	45	11D
0005434408568	27008	46	11E
0005434408542	27008	47	11F
0005435311058	27008	48	12A
0005434408572	27008	49	12D
0005434408550	27008	50	12E
0005434408520	27008	51	12F
0005435311069	27008	52	13A
0005434408535	27008	53	13D
0005434408540	27008	54	13E
0005434408526	27008	55	14C
0005434408563	27008	56	14D
0005434408564	27008	57	14E
0005434408533	27008	58	14F
0005432154023	27008	59	15A
0005434408536	27008	60	15C
0005434408531	27008	61	15E
0005434408514	27008	62	15F
0005434408545	27008	63	16A
0005434408546	27008	64	16C
0005434408560	27008	65	16D
0005432154022	27008	66	16E
0005434408554	27008	67	16F
0005434408519	27008	68	17A
0005432154027	27008	69	17C
0005434408534	27008	70	17D
0005434408529	27008	71	17E
0005434408541	27008	72	17F
0005434408539	27008	73	18A
0005434408575	27008	74	18D
0005434408517	27008	75	18E
0005434408556	27008	76	19A
0005434408565	27008	77	19C
0005434408557	27008	78	19D
0005434408571	27008	79	19E
0005435311044	27008	80	19F
0005434408518	27008	81	20C
0005434408516	27008	82	20D
0005434408553	27008	83	20E
0005433123959	5725	1	1C
0005433123994	5725	2	2A
0005433123945	5725	3	2C
0005433123974	5725	4	2F
0005433124042	5725	5	3C
0005433124046	5725	6	3D
0005433123946	5725	7	5A
0005433123920	5725	8	6C
0005432109738	5725	9	6D
0005433123981	5725	10	6F
0005433124041	5725	11	7A
0005433123975	5725	12	7C
0005432109736	5725	13	7D
0005433124037	5725	14	8A
0005433123983	5725	15	8D
0005433124028	5725	16	9A
0005433123958	5725	17	9D
0005433124057	5725	18	9E
0005433124050	5725	19	9F
0005433123984	5725	20	10A
0005433124105	5725	21	10C
0005433124038	5725	22	10D
0005433123995	5725	23	10E
0005433123929	5725	24	10F
0005433123998	5725	25	11A
0005433124021	5725	26	11D
0005433124027	5725	27	12E
0005433123928	5725	28	12F
0005433124095	5725	29	13A
0005433124040	5725	30	13F
0005433123964	5725	31	14F
0005433124043	5725	32	15C
0005433123992	5725	33	15E
0005433124025	5725	34	15F
0005433124024	5725	35	16C
0005433124003	5725	36	16D
0005433123982	5725	37	16E
0005433123919	5725	38	16F
0005433124022	5725	39	17F
0005433123961	5725	40	18A
0005433123918	5725	41	18D
0005433123993	5725	42	18E
0005432109737	5725	43	19A
0005433123987	5725	44	20A
0005433124051	5725	45	20D
0005433123960	5725	46	20E
0005434319416	15657	1	1A
0005433124188	15657	2	1C
0005434319460	15657	3	1F
0005434319453	15657	4	2D
0005434319452	15657	5	3A
0005434312323	15657	6	3C
0005434319465	15657	7	4A
0005434319485	15657	8	4F
0005433124183	15657	9	5A
0005434319535	15657	10	5D
0005433124193	15657	11	6D
0005433124192	15657	12	6E
0005433124199	15657	13	7A
0005433124196	15657	14	7C
0005434319442	15657	15	7F
0005434312324	15657	16	8E
0005434319443	15657	17	9C
0005434319339	15657	18	9D
0005433124200	15657	19	9E
0005434319456	15657	20	9F
0005434319464	15657	21	10A
0005433124182	15657	22	10D
0005433124186	15657	23	10E
0005433124178	15657	24	11A
0005433124191	15657	25	11F
0005433124198	15657	26	12A
0005434319417	15657	27	12D
0005433124195	15657	28	13A
0005433124180	15657	29	13F
0005433124185	15657	30	14C
0005433124181	15657	31	14D
0005433124189	15657	32	14E
0005434319438	15657	33	15D
0005433124201	15657	34	15F
0005433124184	15657	35	16D
0005434319437	15657	36	16E
0005434319338	15657	37	17C
0005433124187	15657	38	17D
0005434319410	15657	39	17E
0005433124197	15657	40	17F
0005433124179	15657	41	18C
0005433124190	15657	42	18D
0005433124194	15657	43	18F
0005434319454	15657	44	19A
0005435221518	24972	1	3A
0005435220322	24972	2	3C
0005435220328	24972	3	3D
0005435220312	24972	4	5D
0005435217714	24972	5	6A
0005435217715	24972	6	19C
0005435221517	24972	7	22A
0005434189215	9006	1	3B
0005434484428	9006	2	4A
0005434484432	9006	3	4B
0005434484430	9006	4	5B
0005434189216	9006	5	5D
0005434189183	9006	6	6A
0005434484431	9006	7	6C
0005434189182	9006	8	18A
0005434189184	9006	9	18C
0005434484429	9006	10	20A
0005434189188	9006	11	21A
0005434189200	9006	12	21B
0005434189214	9006	13	21C
0005434189217	9006	14	21D
0005434484383	16656	1	1A
0005434189251	16656	2	1D
0005434189252	16656	3	2B
0005434189248	16656	4	3B
0005434484384	16656	5	3D
0005434484410	16656	6	5C
0005434189250	16656	7	18A
0005434484403	16656	8	19A
0005434189249	16656	9	19B
0005434484352	16656	10	20A
0005434189247	16656	11	21B
0005434484369	16656	12	21D
0005434484402	16656	13	22B
0005433124189	7637	1	1C
0005433124197	7637	2	2C
0005433124185	7637	3	3F
0005433124192	7637	4	5D
0005433722209	7637	5	6C
0005433722226	7637	6	6D
0005433124201	7637	7	6F
0005433124183	7637	8	7C
0005433124200	7637	9	8D
0005433124190	7637	10	8E
0005433124191	7637	11	8F
0005433722223	7637	12	9C
0005433124188	7637	13	9D
0005433124194	7637	14	9E
0005433124187	7637	15	10A
0005433124178	7637	16	10C
0005433124180	7637	17	10D
0005433124196	7637	18	11A
0005433124195	7637	19	11E
0005433124198	7637	20	12F
0005433124184	7637	21	16A
0005433722222	7637	22	16D
0005433124181	7637	23	17A
0005433124186	7637	24	18D
0005433124193	7637	25	18F
0005433124199	7637	26	18E
0005433124182	7637	27	19A
0005433124179	7637	28	19D
0005432693442	7639	1	1A
0005432721241	7639	2	1D
0005432693443	7639	3	1F
0005433450245	7639	4	2A
0005432693455	7639	5	2C
0005433450240	7639	6	2D
0005432721250	7639	7	2F
0005433450247	7639	8	3A
0005432721226	7639	9	3C
0005433450236	7639	10	3D
0005432721239	7639	11	3F
0005432721249	7639	12	4A
0005433450244	7639	13	4C
0005432071610	7639	14	4D
0005432721228	7639	15	4E
0005432693458	7639	16	4F
0005432071611	7639	17	5A
0005432721251	7639	18	5C
0005432721233	7639	19	5D
0005432721237	7639	20	5E
0005432693461	7639	21	5F
0005432693468	7639	22	6A
0005432693464	7639	23	6D
0005432721247	7639	24	6E
0005432693462	7639	25	6F
0005433450242	7639	26	7A
0005432693456	7639	27	7C
0005433450249	7639	28	7D
0005432721227	7639	29	7F
0005432693447	7639	30	8A
0005432693454	7639	31	8C
0005433450229	7639	32	8D
0005432721246	7639	33	8E
0005433450246	7639	34	8F
0005433450234	7639	35	9D
0005433450232	7639	36	9E
0005432721245	7639	37	9F
0005433450243	7639	38	10A
0005432721238	7639	39	10C
0005432071609	7639	40	10F
0005432721229	7639	41	10E
0005432693472	7639	42	11C
0005432693460	7639	43	11D
0005432721236	7639	44	11E
0005433450250	7639	45	11F
0005432693445	7639	46	12A
0005432693453	7639	47	12C
0005432721231	7639	48	12D
0005432721240	7639	49	12E
0005432693449	7639	50	12F
0005433450230	7639	51	13A
0005432721230	7639	52	13C
0005433450238	7639	53	13D
0005432721243	7639	54	13E
0005433450251	7639	55	13F
0005433450233	7639	56	14A
0005432721248	7639	57	14C
0005432721242	7639	58	14D
0005432721235	7639	59	14E
0005432693473	7639	60	14F
0005432693450	7639	61	15A
0005432693466	7639	62	15C
0005432693465	7639	63	15D
0005433450231	7639	64	15E
0005432693470	7639	65	16A
0005432071612	7639	66	16C
0005432693469	7639	67	16D
0005432721244	7639	68	16E
0005432693471	7639	69	16F
0005432693463	7639	70	17C
0005433450239	7639	71	17D
0005433450235	7639	72	17E
0005432693457	7639	73	17F
0005432693467	7639	74	18C
0005432693459	7639	75	18D
0005433450248	7639	76	18F
0005432721234	7639	77	19A
0005432693452	7639	78	19C
0005433450241	7639	79	19D
0005432693448	7639	80	19F
0005432693451	7639	81	20A
0005433450237	7639	82	20C
0005432693444	7639	83	20D
0005432693446	7639	84	20E
0005432721232	7639	85	20F
0005432693229	30346	1	1F
0005432693155	30346	2	2C
0005432693147	30346	3	2F
0005433449950	30346	4	3F
0005433449990	30346	5	4A
0005433449949	30346	6	4D
0005432693135	30346	7	4E
0005433450026	30346	8	5A
0005433450106	30346	9	5C
0005433450029	30346	10	5D
0005432693377	30346	11	5F
0005432693089	30346	12	6C
0005432693241	30346	13	6E
0005432693165	30346	14	6F
0005432693137	30346	15	7D
0005432693141	30346	16	7E
0005432693271	30346	17	7F
0005432693204	30346	18	8D
0005432693129	30346	19	9A
0005432693272	30346	20	9C
0005432693140	30346	21	9D
0005433450096	30346	22	10A
0005432693190	30346	23	10C
0005433450054	30346	24	10D
0005432693214	30346	25	10E
0005433450079	30346	26	11A
0005432693262	30346	27	11F
0005432693164	30346	28	12D
0005433449928	30346	29	12E
0005433450003	30346	30	13A
0005432693136	30346	31	13D
0005432693175	30346	32	13E
0005433450046	30346	33	14C
0005432693243	30346	34	14F
0005433449971	30346	35	15A
0005433450071	30346	36	15F
0005432693134	30346	37	16C
0005432693226	30346	38	16D
0005432693186	30346	39	17A
0005433450075	30346	40	18C
0005433450082	30346	41	18D
0005432693242	30346	42	18E
0005433450097	30346	43	18F
0005433450027	30346	44	19A
0005433450025	30346	45	19C
0005432693196	30346	46	19D
0005433450116	30346	47	19E
0005433450055	30346	48	19F
0005433450078	30346	49	20A
0005433450086	30346	50	20C
0005432693218	30346	51	20E
0005432720983	30347	1	1A
0005433124095	30347	2	1D
0005433124040	30347	3	2A
0005433124037	30347	4	2C
0005432720920	30347	5	2D
0005432720954	30347	6	3A
0005432721089	30347	7	2F
0005432721030	30347	8	3C
0005432721150	30347	9	3D
0005432721099	30347	10	3F
0005432721104	30347	11	4A
0005433123961	30347	12	4C
0005432721052	30347	13	4D
0005433123974	30347	14	4E
0005433123983	30347	15	4F
0005432721029	30347	16	5A
0005432720973	30347	17	5C
0005433124024	30347	18	5D
0005433722305	30347	19	5E
0005432721097	30347	20	5F
0005433124105	30347	21	6A
0005433124038	30347	22	6C
0005432720919	30347	23	6D
0005433124041	30347	24	6E
0005433124043	30347	25	6F
0005432721084	30347	26	7A
0005433123993	30347	27	7C
0005433123960	30347	28	7D
0005433722306	30347	29	7E
0005432720989	30347	30	7F
0005433123918	30347	31	8A
0005432721103	30347	32	8C
0005432720955	30347	33	8D
0005433123920	30347	34	8E
0005432720960	30347	35	8F
0005432721149	30347	36	9A
0005433124046	30347	37	9C
0005433124027	30347	38	9D
0005433123945	30347	39	9E
0005432721083	30347	40	10A
0005433123959	30347	41	10D
0005433123995	30347	42	10E
0005433123928	30347	43	10F
0005432720967	30347	44	11A
0005432720968	30347	45	11C
0005432720971	30347	46	11D
0005433123984	30347	47	11E
0005433124003	30347	48	12A
0005432721092	30347	49	12C
0005433124051	30347	50	12D
0005432721039	30347	51	12E
0005432720987	30347	52	12F
0005433123992	30347	53	13A
0005432720958	30347	54	13D
0005432720993	30347	55	13E
0005432720921	30347	56	13F
0005433124025	30347	57	14C
0005433722303	30347	58	14D
0005432720979	30347	59	14E
0005432721093	30347	60	15A
0005433124028	30347	61	14F
0005432720959	30347	62	15D
0005433123964	30347	63	15E
0005433722304	30347	64	15F
0005433124022	30347	65	16A
0005432720916	30347	66	16C
0005433124042	30347	67	16D
0005433123919	30347	68	16E
0005433123998	30347	69	16F
0005433722308	30347	70	17A
0005433123982	30347	71	17C
0005433123958	30347	72	17E
0005432720914	30347	73	17F
0005433123981	30347	74	18A
0005433123987	30347	75	18C
0005432720974	30347	76	18D
0005433123946	30347	77	18E
0005432720904	30347	78	18F
0005433124050	30347	79	19A
0005433722307	30347	80	19C
0005433123975	30347	81	19D
0005432721082	30347	82	19E
0005433124021	30347	83	19F
0005433123994	30347	84	20A
0005432721105	30347	85	20C
0005433124057	30347	86	20D
0005432721067	30347	87	20E
0005433123929	30347	88	20F
0005434586941	1377	1	1C
0005433193127	1377	2	1F
0005433525178	1377	3	2A
0005433724862	1377	4	2D
0005433525180	1377	5	2F
0005434586921	1377	6	3C
0005434586934	1377	7	3F
0005434586937	1377	8	4A
0005433193123	1377	9	4C
0005433193140	1377	10	4D
0005432928007	1377	11	4E
0005433193150	1377	12	4F
0005434586925	1377	13	5A
0005432271040	1377	14	5F
0005434586930	1377	15	6A
0005434586926	1377	16	6D
0005434586928	1377	17	6C
0005433525171	1377	18	6E
0005433193110	1377	19	6F
0005434586920	1377	20	7A
0005432928008	1377	21	7E
0005434515001	1377	22	7F
0005434513612	1377	23	8C
0005433193167	1377	24	8D
0005432968857	1377	25	8E
0005434586935	1377	26	8F
0005434586942	1377	27	9A
0005434513613	1377	28	9C
0005434586943	1377	29	9E
0005432968847	1377	30	9F
0005434586922	1377	31	10A
0005433525174	1377	32	10C
0005432271039	1377	33	10D
0005433525172	1377	34	11A
0005433193122	1377	35	11C
0005432968846	1377	36	11D
0005433525176	1377	37	11E
0005432968856	1377	38	11F
0005433193136	1377	39	12E
0005434586927	1377	40	12F
0005432928022	1377	41	13A
0005433193042	1377	42	13C
0005433724861	1377	43	13D
0005434586940	1377	44	13F
0005433525177	1377	45	14C
0005434586933	1377	46	14D
0005434586945	1377	47	14E
0005433525170	1377	48	15A
0005432271038	1377	49	14F
0005433193135	1377	50	15C
0005432968843	1377	51	15D
0005434586936	1377	52	15E
0005433525169	1377	53	16A
0005434586939	1377	54	16D
0005434586924	1377	55	16C
0005434586932	1377	56	16E
0005433724864	1377	57	16F
0005433193111	1377	58	17A
0005434586929	1377	59	17C
0005434586938	1377	60	17D
0005434586923	1377	61	17E
0005433525173	1377	62	18A
0005434513611	1377	63	18C
0005433525175	1377	64	18D
0005432927984	1377	65	18E
0005434586931	1377	66	19A
0005434515000	1377	67	19D
0005433724863	1377	68	19E
0005433193141	1377	69	19F
0005433193137	1377	70	20A
0005433525181	1377	71	20C
0005433525179	1377	72	20D
0005434586944	1377	73	20E
0005433193103	1377	74	20F
0005433525055	18526	1	1A
0005433724820	18526	2	1D
0005433525054	18526	3	1F
0005433525059	18526	4	2A
0005433193206	18526	5	2C
0005434586807	18526	6	2F
0005433193209	18526	7	3A
0005433724826	18526	8	3C
0005434586624	18526	9	3D
0005432928047	18526	10	3F
0005433525085	18526	11	4A
0005433193216	18526	12	4D
0005433193217	18526	13	4E
0005433193210	18526	14	4F
0005434586617	18526	15	5A
0005434586587	18526	16	5C
0005434586770	18526	17	5D
0005434586736	18526	18	5E
0005434586806	18526	19	5F
0005433525100	18526	20	6A
0005434586799	18526	21	6C
0005434586663	18526	22	6D
0005433193214	18526	23	6E
0005434586800	18526	24	6F
0005433193207	18526	25	7D
0005434586664	18526	26	7E
0005433525105	18526	27	7F
0005433193208	18526	28	8C
0005432968869	18526	29	8E
0005433525104	18526	30	8F
0005433525046	18526	31	9A
0005434586795	18526	32	9C
0005433525097	18526	33	9D
0005434514984	18526	34	9E
0005434586714	18526	35	9F
0005434586666	18526	36	10A
0005434586721	18526	37	10C
0005434586609	18526	38	10D
0005433724818	18526	39	10E
0005434586639	18526	40	10F
0005433525101	18526	41	11A
0005434586796	18526	42	11D
0005434514975	18526	43	11E
0005434586716	18526	44	11F
0005434586588	18526	45	12C
0005432928048	18526	46	12D
0005433193213	18526	47	12E
0005433525049	18526	48	12F
0005432928051	18526	49	13A
0005434586737	18526	50	13C
0005434586710	18526	51	13D
0005433724819	18526	52	13E
0005434586611	18526	53	13F
0005434586771	18526	54	14A
0005433193211	18526	55	14C
0005434586662	18526	56	14D
0005432968868	18526	57	14E
0005433525098	18526	58	15A
0005434586779	18526	59	15C
0005433525045	18526	60	15D
0005433724838	18526	61	15E
0005434586715	18526	62	15F
0005433525076	18526	63	16A
0005434586851	18526	64	16C
0005434586852	18526	65	16D
0005434586810	18526	66	16F
0005434586661	18526	67	17C
0005432928049	18526	68	17A
0005433193215	18526	69	17D
0005432928050	18526	70	17E
0005434586695	18526	71	17F
0005432968867	18526	72	18A
0005434586711	18526	73	18C
0005433525096	18526	74	18D
0005434586702	18526	75	18E
0005434586657	18526	76	18F
0005433193212	18526	77	19A
0005432928046	18526	78	19C
0005434586724	18526	79	19D
0005434586720	18526	80	19E
0005434586658	18526	81	19F
0005434586709	18526	82	20A
0005433525033	18526	83	20C
0005433193218	18526	84	20D
0005434586610	18526	85	20F
0005434344636	11422	1	1A
0005435302201	11422	2	1B
0005434344615	11422	3	1C
0005434344616	11422	4	1D
0005434142659	11422	5	2A
0005434344623	11422	6	2B
0005435302224	11422	7	2C
0005434344631	11422	8	2D
0005434344635	11422	9	3A
0005434344611	11422	10	3B
0005434344627	11422	11	3C
0005435302199	11422	12	3D
0005434142660	11422	13	4A
0005434344606	11422	14	4B
0005434344617	11422	15	4C
0005435305020	11422	16	4D
0005434344619	11422	17	5A
0005434344625	11422	18	5B
0005434344614	11422	19	5C
0005435302200	11422	20	5D
0005434344624	11422	21	6A
0005434344613	11422	22	6B
0005434344626	11422	23	6C
0005435302209	11422	24	6D
0005434344607	11422	25	7A
0005434344634	11422	26	7B
0005434344629	11422	27	7D
0005434344609	11422	28	18A
0005434344610	11422	29	18B
0005434344602	11422	30	18C
0005434344603	11422	31	18D
0005435305025	11422	32	19A
0005434344604	11422	33	19B
0005434344605	11422	34	19C
0005434344628	11422	35	19D
0005434344612	11422	36	20A
0005434344600	11422	37	20B
0005434344608	11422	38	20C
0005434142658	11422	39	20D
0005434344601	11422	40	21A
0005434344633	11422	41	21B
0005434344620	11422	42	21D
0005434344630	11422	43	22A
0005434344632	11422	44	22B
0005434142661	11422	45	22C
0005434344618	11422	46	22D
0005434344621	11422	47	23A
0005434344622	11422	48	23B
0005434344329	29760	1	1A
0005435305040	29760	2	1B
0005435304217	29760	3	1C
0005434344284	29760	4	1D
0005434344412	29760	5	2B
0005434344264	29760	6	2C
0005435305039	29760	7	2D
0005434344343	29760	8	3A
0005434344318	29760	9	3B
0005434344322	29760	10	3C
0005434344253	29760	11	3D
0005434344306	29760	12	4A
0005434344338	29760	13	4B
0005434344333	29760	14	4C
0005434344391	29760	15	4D
0005434344165	29760	16	5A
0005434344456	29760	17	5B
0005434344345	29760	18	5C
0005434344279	29760	19	5D
0005434142609	29760	20	6A
0005434344507	29760	21	6C
0005434344305	29760	22	7A
0005434344238	29760	23	7B
0005434344263	29760	24	7C
0005434344303	29760	25	18A
0005434344315	29760	26	18B
0005435304215	29760	27	18C
0005434344309	29760	28	18D
0005434344388	29760	29	19A
0005434344304	29760	30	19B
0005434344310	29760	31	19C
0005434344297	29760	32	19D
0005434344380	29760	33	20B
0005434344166	29760	34	20C
0005434344257	29760	35	20D
0005434344155	29760	36	21A
0005434344459	29760	37	21B
0005434344344	29760	38	21C
0005434344339	29760	39	21D
0005434344218	29760	40	22A
0005435304216	29760	41	22B
0005435305038	29760	42	22C
0005434344237	29760	43	22D
0005434344346	29760	44	23A
0005434344447	29760	45	23B
0005435824953	1289	1	1D
0005435824969	1289	2	1C
0005435824956	1289	3	2A
0005435824962	1289	4	1F
0005435824961	1289	5	3F
0005435824952	1289	6	4D
0005433415722	1289	7	4C
0005435824966	1289	8	4F
0005435824963	1289	9	5C
0005435824973	1289	10	5A
0005435824974	1289	11	5D
0005435824948	1289	12	6C
0005435824960	1289	13	7E
0005433415723	1289	14	7D
0005435824967	1289	15	8A
0005435824975	1289	16	7F
0005433415692	1289	17	8E
0005433415744	1289	18	9B
0005432284596	1289	19	9C
0005433415712	1289	20	9E
0005433415746	1289	21	10B
0005433415703	1289	22	10E
0005433415760	1289	23	11D
0005435824949	1289	24	11C
0005433415719	1289	25	12C
0005433415763	1289	26	13C
0005433415787	1289	27	13E
0005435824972	1289	28	14A
0005433415776	1289	29	14C
0005435824970	1289	30	15B
0005435824968	1289	31	15F
0005435824955	1289	32	15E
0005435824964	1289	33	16F
0005435824971	1289	34	17D
0005433415762	1289	35	17C
0005435824951	1289	36	18A
0005435824954	1289	37	18D
0005435824959	1289	38	19A
0005433415670	1289	39	18F
0005435824965	1289	40	19C
0005433415717	1289	41	19B
0005435824957	1289	42	20A
0005435824950	1289	43	19F
0005435824958	1289	44	21B
0005433415718	1289	45	21D
0005432284595	1289	46	21E
0005435824646	17981	1	1C
0005435824748	17981	2	1A
0005435824795	17981	3	2C
0005435824825	17981	4	2F
0005435824747	17981	5	3C
0005433415862	17981	6	3F
0005435824632	17981	7	5A
0005435824824	17981	8	4F
0005435824718	17981	9	6A
0005433415867	17981	10	6C
0005435824704	17981	11	7A
0005435824746	17981	12	7B
0005435824633	17981	13	7D
0005435824739	17981	14	9A
0005435824703	17981	15	10B
0005435824783	17981	16	10E
0005433415863	17981	17	10F
0005433415865	17981	18	11B
0005435824784	17981	19	11F
0005435824794	17981	20	12E
0005433415857	17981	21	12F
0005433415856	17981	22	13C
0005435824803	17981	23	13E
0005433415858	17981	24	14C
0005435824717	17981	25	14B
0005433415861	17981	26	15A
0005433415859	17981	27	17F
0005433415855	17981	28	18B
0005433415854	17981	29	18C
0005433415868	17981	30	19C
0005433415860	17981	31	19E
0005433415853	17981	32	19F
0005433415852	17981	33	20F
0005433415866	17981	34	21A
0005435824673	17981	35	21D
0005435824779	17981	36	21E
0005433415864	17981	37	21F
0005434461669	12572	1	1C
0005434461672	12572	2	2B
0005434460528	12572	3	3D
0005434461666	12572	4	4D
0005434461671	12572	5	5C
0005434461667	12572	6	6C
0005434460525	12572	7	6D
0005434460530	12572	8	7B
0005434461670	12572	9	7C
0005434460527	12572	10	18A
0005434460529	12572	11	18D
0005434461668	12572	12	19B
0005434461673	12572	13	21B
0005434460526	12572	14	23A
0005435242888	5657	1	1A
0005432784452	5657	2	1C
0005432784484	5657	3	1D
0005435242827	5657	4	1F
0005435242898	5657	5	2A
0005432784483	5657	6	2C
0005435476743	5657	7	2D
0005432784471	5657	8	2F
0005435242853	5657	9	3A
0005435242867	5657	10	3C
0005432784465	5657	11	3D
0005435476783	5657	12	3F
0005435476814	5657	13	4A
0005432784445	5657	14	4C
0005435242887	5657	15	4D
0005432784448	5657	16	4E
0005435242852	5657	17	4F
0005432784447	5657	18	5A
0005432784449	5657	19	5C
0005435242828	5657	20	5D
0005432784455	5657	21	5E
0005432784479	5657	22	6A
0005432784476	5657	23	6C
0005432784486	5657	24	6D
0005435476813	5657	25	6E
0005435243001	5657	26	6F
0005432784485	5657	27	7A
0005435242926	5657	28	7C
0005435476784	5657	29	7D
0005435476805	5657	30	7E
0005435476782	5657	31	8A
0005435476768	5657	32	8C
0005432784481	5657	33	8D
0005432784444	5657	34	8F
0005432144028	5657	35	9A
0005432784450	5657	36	9C
0005432784457	5657	37	9D
0005432784478	5657	38	9E
0005432784442	5657	39	9F
0005432784469	5657	40	10A
0005435243002	5657	41	10C
0005432784456	5657	42	10D
0005432784453	5657	43	10E
0005435242866	5657	44	10F
0005432784480	5657	45	11A
0005432784489	5657	46	11C
0005432784441	5657	47	11D
0005432784458	5657	48	11E
0005432784467	5657	49	11F
0005435242826	5657	50	12A
0005432784446	5657	51	12C
0005435242896	5657	52	12D
0005432784472	5657	53	12E
0005432784461	5657	54	12F
0005432784487	5657	55	13A
0005435242897	5657	56	13C
0005435243034	5657	57	13E
0005432784463	5657	58	13F
0005435243033	5657	59	14A
0005432784436	5657	60	14C
0005432784482	5657	61	14D
0005432784464	5657	62	14E
0005432784475	5657	63	15A
0005432784443	5657	64	15C
0005432784440	5657	65	15D
0005432784459	5657	66	15E
0005432784473	5657	67	15F
0005432784466	5657	68	16C
0005432784454	5657	69	16D
0005435476815	5657	70	16E
0005435242979	5657	71	16F
0005435476810	5657	72	17A
0005432784438	5657	73	17C
0005432784488	5657	74	17D
0005432784477	5657	75	17E
0005432784462	5657	76	17F
0005435243000	5657	77	18A
0005432784439	5657	78	18C
0005435242889	5657	79	18D
0005432144029	5657	80	18E
0005432784460	5657	81	18F
0005432784490	5657	82	19A
0005432144027	5657	83	19D
0005432784468	5657	84	19E
0005432784451	5657	85	19F
0005435242780	5657	86	20A
0005435242925	5657	87	20C
0005432784474	5657	88	20D
0005432784437	5657	89	20E
0005432784470	5657	90	20F
0005435476850	15343	1	1A
0005435243174	15343	2	1C
0005435243177	15343	3	1D
0005435476846	15343	4	1F
0005432783899	15343	5	2A
0005435476842	15343	6	2D
0005432783841	15343	7	2F
0005432784150	15343	8	3C
0005435243166	15343	9	4A
0005435243178	15343	10	4C
0005435243159	15343	11	4D
0005432783992	15343	12	4E
0005432783893	15343	13	4F
0005432783963	15343	14	5A
0005432783953	15343	15	5C
0005435476847	15343	16	5D
0005432784010	15343	17	5E
0005435243170	15343	18	5F
0005432783894	15343	19	6C
0005432783791	15343	20	6D
0005435243172	15343	21	6E
0005432783792	15343	22	6F
0005432784109	15343	23	7A
0005432783890	15343	24	7D
0005432783951	15343	25	7E
0005435243171	15343	26	7F
0005435476845	15343	27	8A
0005435243181	15343	28	8C
0005432783818	15343	29	8D
0005435476844	15343	30	8E
0005432784070	15343	31	8F
0005432784019	15343	32	9A
0005432783817	15343	33	9C
0005432784137	15343	34	9D
0005432784069	15343	35	9E
0005435243175	15343	36	9F
0005432783984	15343	37	10A
0005432783985	15343	38	10C
0005432784135	15343	39	10D
0005432784056	15343	40	10E
0005435476848	15343	41	10F
0005432783657	15343	42	11A
0005432784020	15343	43	11C
0005435243168	15343	44	11D
0005432783808	15343	45	11E
0005435243173	15343	46	11F
0005435243162	15343	47	12A
0005432783896	15343	48	12C
0005435243163	15343	49	12D
0005435476849	15343	50	12E
0005432783900	15343	51	12F
0005432784138	15343	52	13A
0005432783797	15343	53	13C
0005432783964	15343	54	13E
0005432784095	15343	55	13F
0005432783889	15343	56	14A
0005435243161	15343	57	14C
0005432783915	15343	58	14D
0005435243165	15343	59	14E
0005432783804	15343	60	14F
0005432784071	15343	61	15A
0005432783837	15343	62	15C
0005435243176	15343	63	15D
0005432783730	15343	64	15E
0005435243158	15343	65	15F
0005432783732	15343	66	16A
0005435243183	15343	67	16C
0005432783840	15343	68	16D
0005432783991	15343	69	16E
0005432784028	15343	70	16F
0005432783901	15343	71	17A
0005432784139	15343	72	17C
0005432783895	15343	73	17D
0005435243164	15343	74	17E
0005435243160	15343	75	17F
0005432783983	15343	76	18A
0005435243182	15343	77	18C
0005432783658	15343	78	18D
0005435243184	15343	79	18E
0005432783871	15343	80	18F
0005435243169	15343	81	19A
0005432783731	15343	82	19C
0005432783870	15343	83	19D
0005432783986	15343	84	19E
0005432783805	15343	85	19F
0005432783902	15343	86	20A
0005435243180	15343	87	20C
0005435476843	15343	88	20D
0005435243179	15343	89	20F
0005435243167	15343	90	20E
0005435850963	4350	1	1B
0005432848500	4350	2	1C
0005432848494	4350	3	1D
0005435850966	4350	4	2C
0005434462816	4350	5	3B
0005434463955	4350	6	3D
0005435850949	4350	7	4A
0005435850994	4350	8	4C
0005435850961	4350	9	5C
0005432848491	4350	10	6A
0005432848493	4350	11	6B
0005432848490	4350	12	6D
0005434462817	4350	13	7A
0005432848495	4350	14	7B
0005432848492	4350	15	7C
0005432848497	4350	16	7D
0005435850947	4350	17	18A
0005434463956	4350	18	18B
0005432848498	4350	19	18C
0005432848489	4350	20	18D
0005435850960	4350	21	19A
0005435850997	4350	22	20A
0005435850950	4350	23	20C
0005435850924	4350	24	20D
0005432848499	4350	25	21B
0005432848496	4350	26	21C
0005435850962	4350	27	21D
0005432848487	4350	28	22A
0005432848501	4350	29	22B
0005435850946	4350	30	22D
0005434462818	4350	31	23A
0005432848488	4350	32	23B
0005434461646	28837	1	1B
0005435851028	28837	2	2A
0005432848370	28837	3	2B
0005434463936	28837	4	2C
0005432848350	28837	5	3A
0005432848377	28837	6	3B
0005435851024	28837	7	3D
0005435851025	28837	8	4D
0005432848359	28837	9	5A
0005435851019	28837	10	5C
0005434461651	28837	11	6B
0005432848371	28837	12	6C
0005432848395	28837	13	6D
0005432848358	28837	14	7A
0005435851026	28837	15	7C
0005435851021	28837	16	7D
0005432848386	28837	17	18A
0005434461652	28837	18	18C
0005435851023	28837	19	18D
0005432848360	28837	20	19A
0005435851027	28837	21	19B
0005435851022	28837	22	19D
0005434461647	28837	23	20A
0005434461655	28837	24	20B
0005432848412	28837	25	20D
0005435851020	28837	26	21B
0005432848369	28837	27	21C
0005432848401	28837	28	21D
0005433497363	6303	1	1C
0005434443905	6303	2	1D
0005434926192	6303	3	2A
0005434443910	6303	4	2D
0005434926206	6303	5	2F
0005433497368	6303	6	3A
0005433497364	6303	7	3C
0005434443913	6303	8	3D
0005434926188	6303	9	3F
0005433497366	6303	10	4A
0005434926216	6303	11	4C
0005433497350	6303	12	4D
0005433497354	6303	13	4E
0005433497352	6303	14	4F
0005434443919	6303	15	5A
0005433497371	6303	16	5C
0005433497348	6303	17	5D
0005433497369	6303	18	5E
0005433497372	6303	19	5F
0005434926202	6303	20	6A
0005434926218	6303	21	6C
0005434443918	6303	22	6D
0005434926200	6303	23	6E
0005433497353	6303	24	6F
0005434926189	6303	25	7A
0005434926196	6303	26	7C
0005434926205	6303	27	7E
0005433497362	6303	28	7D
0005434926217	6303	29	7F
0005434926208	6303	30	8A
0005434926195	6303	31	8C
0005434443917	6303	32	8D
0005434926194	6303	33	8E
0005434926215	6303	34	9A
0005434926193	6303	35	9C
0005433497355	6303	36	9D
0005434443916	6303	37	9F
0005434443911	6303	38	10A
0005433497365	6303	39	10C
0005432075273	6303	40	10D
0005433497376	6303	41	10E
0005433497349	6303	42	10F
0005434443906	6303	43	11A
0005434443907	6303	44	11C
0005434926203	6303	45	11E
0005434926190	6303	46	11F
0005432075275	6303	47	12A
0005433497351	6303	48	12C
0005434443912	6303	49	12D
0005434443904	6303	50	12E
0005434926220	6303	51	12F
0005434926221	6303	52	13A
0005433497357	6303	53	13E
0005434926204	6303	54	14A
0005434443908	6303	55	14C
0005433497367	6303	56	14D
0005433497373	6303	57	14E
0005432075274	6303	58	14F
0005433497360	6303	59	15A
0005433497361	6303	60	15C
0005434443915	6303	61	15D
0005434926191	6303	62	15E
0005433497374	6303	63	15F
0005433497359	6303	64	16C
0005434926197	6303	65	16D
0005434926210	6303	66	16E
0005432075272	6303	67	16F
0005433497377	6303	68	17A
0005433497370	6303	69	17C
0005434443909	6303	70	17E
0005434926211	6303	71	17F
0005434443903	6303	72	18A
0005434926207	6303	73	18C
0005433497347	6303	74	18D
0005434926199	6303	75	18E
0005434926219	6303	76	18F
0005433497358	6303	77	19A
0005434926209	6303	78	19C
0005434926212	6303	79	19D
0005434926201	6303	80	19E
0005433497356	6303	81	19F
0005434926198	6303	82	20A
0005433497375	6303	83	20C
0005434926213	6303	84	20D
0005434926214	6303	85	20E
0005434443914	6303	86	20F
0005434925770	20368	1	1A
0005434925733	20368	2	1C
0005434443802	20368	3	1D
0005433497214	20368	4	2C
0005433497143	20368	5	2D
0005433497229	20368	6	2F
0005434925895	20368	7	3A
0005433497077	20368	8	3D
0005434925833	20368	9	3F
0005434925885	20368	10	4A
0005433497096	20368	11	4C
0005434443780	20368	12	4E
0005434925988	20368	13	4F
0005433497227	20368	14	5A
0005434925962	20368	15	5E
0005434925854	20368	16	5F
0005433497122	20368	17	6A
0005434925838	20368	18	6C
0005434925757	20368	19	6E
0005434443812	20368	20	6F
0005434925850	20368	21	7A
0005433497142	20368	22	7C
0005434925888	20368	23	7D
0005434443752	20368	24	7E
0005433497120	20368	25	8C
0005434925886	20368	26	8D
0005434925830	20368	27	8F
0005434925865	20368	28	9A
0005433497121	20368	29	9C
0005433497195	20368	30	9E
0005434925978	20368	31	9F
0005434925831	20368	32	10A
0005434443751	20368	33	10C
0005434925835	20368	34	11A
0005434925931	20368	35	11C
0005433497127	20368	36	11D
0005434443779	20368	37	11E
0005433497144	20368	38	11F
0005434925930	20368	39	12A
0005433497160	20368	40	12C
0005433497126	20368	41	12D
0005434443684	20368	42	12E
0005434925731	20368	43	12F
0005433497174	20368	44	13A
0005434925909	20368	45	13C
0005434925730	20368	46	13D
0005434925908	20368	47	13E
0005434925802	20368	48	13F
0005434925977	20368	49	14A
0005434925747	20368	50	14D
0005433497099	20368	51	15A
0005434925827	20368	52	14F
0005433497228	20368	53	15C
0005434925915	20368	54	16C
0005433497073	20368	55	16D
0005434925910	20368	56	16E
0005433497146	20368	57	16F
0005433497213	20368	58	17A
0005434925771	20368	59	17C
0005434925834	20368	60	17D
0005434925796	20368	61	17F
0005434443746	20368	62	18C
0005433497128	20368	63	18D
0005434925803	20368	64	18E
0005433497175	20368	65	19A
0005433497153	20368	66	19F
0005434443712	20368	67	20A
0005433497148	20368	68	20C
0005433497095	20368	69	20D
0005434443716	20368	70	20E
0005434925756	20368	71	20F
0005435243206	12156	1	1A
0005432783931	12156	2	1C
0005432783971	12156	3	1D
0005432783831	12156	4	1F
0005432784047	12156	5	2A
0005432784112	12156	6	2C
0005432783742	12156	7	2D
0005432784079	12156	8	2F
0005432784227	12156	9	3A
0005435243197	12156	10	3C
0005435243199	12156	11	3D
0005435243205	12156	12	3F
0005432783830	12156	13	4A
0005435243191	12156	14	4C
0005432784122	12156	15	4D
0005435243187	12156	16	4E
0005432783923	12156	17	4F
0005432783741	12156	18	5A
0005432783987	12156	19	5C
0005432784089	12156	20	5D
0005432784039	12156	21	5E
0005432784248	12156	22	5F
0005432783967	12156	23	6A
0005432783783	12156	24	6C
0005432783853	12156	25	6D
0005432784086	12156	26	6E
0005435243195	12156	27	6F
0005435243188	12156	28	7A
0005432784048	12156	29	7C
0005432784098	12156	30	7D
0005432784091	12156	31	7E
0005432783845	12156	32	7F
0005432784164	12156	33	8A
0005432783844	12156	34	8C
0005432784232	12156	35	8D
0005432784103	12156	36	8E
0005435243194	12156	37	8F
0005432783930	12156	38	9A
0005432783950	12156	39	9C
0005432784096	12156	40	9D
0005432783740	12156	41	9E
0005432784068	12156	42	9F
0005432784080	12156	43	10A
0005435243186	12156	44	10C
0005432784023	12156	45	10D
0005432784161	12156	46	10E
0005432783886	12156	47	10F
0005432784014	12156	48	11A
0005432783880	12156	49	11C
0005432784064	12156	50	11D
0005435243185	12156	51	11E
0005432784087	12156	52	11F
0005432783977	12156	53	12A
0005432783866	12156	54	12C
0005432784113	12156	55	12E
0005432783687	12156	56	12F
0005432784102	12156	57	13A
0005432783909	12156	58	13C
0005432784073	12156	59	13D
0005435243208	12156	60	13E
0005432783962	12156	61	13F
0005435243200	12156	62	14A
0005435243204	12156	63	14C
0005432783976	12156	64	14D
0005432784165	12156	65	14E
0005435243190	12156	66	14F
0005435243196	12156	67	15A
0005432784101	12156	68	15C
0005432783970	12156	69	15D
0005432784097	12156	70	15E
0005435243202	12156	71	15F
0005432784013	12156	72	16A
0005435243193	12156	73	16C
0005432784074	12156	74	16D
0005432783833	12156	75	16E
0005435243207	12156	76	16F
0005432784027	12156	77	17A
0005435243192	12156	78	17C
0005432783446	12156	79	17D
0005432783784	12156	80	17E
0005432784090	12156	81	17F
0005432783943	12156	82	18A
0005435243203	12156	83	18C
0005432784094	12156	84	18D
0005432784043	12156	85	18E
0005435243189	12156	86	18F
0005435243201	12156	87	19A
0005432784121	12156	88	19C
0005432783885	12156	89	19D
0005435243198	12156	90	19E
0005432784040	12156	91	19F
0005432784099	12156	92	20A
0005432784044	12156	93	20C
0005432783940	12156	94	20D
0005432784088	12156	95	20E
0005432784100	12156	96	20F
0005432784397	15441	1	1A
0005432784408	15441	2	2A
0005432784393	15441	3	2D
0005432784390	15441	4	2F
0005435242913	15441	5	3D
0005435242928	15441	6	3F
0005432784413	15441	7	4A
0005432784435	15441	8	4D
0005432784394	15441	9	4E
0005435242906	15441	10	4F
0005435242973	15441	11	5A
0005435242821	15441	12	5C
0005435242974	15441	13	5E
0005432784429	15441	14	5F
0005435242929	15441	15	6A
0005432784415	15441	16	6C
0005432784427	15441	17	6D
0005432784385	15441	18	6F
0005432784424	15441	19	7A
0005432784422	15441	20	7C
0005432784383	15441	21	7D
0005432784412	15441	22	7E
0005432784387	15441	23	7F
0005432784417	15441	24	8A
0005432784410	15441	25	8C
0005432784389	15441	26	8E
0005432784406	15441	27	8F
0005432784382	15441	28	9A
0005432784391	15441	29	9C
0005435242944	15441	30	9D
0005432784428	15441	31	9F
0005432784414	15441	32	10D
0005432784411	15441	33	10E
0005432784399	15441	34	10F
0005432784433	15441	35	11A
0005435242930	15441	36	11E
0005432784420	15441	37	11F
0005435242942	15441	38	12A
0005432784386	15441	39	12C
0005432784402	15441	40	12D
0005432784423	15441	41	12F
0005432784432	15441	42	13C
0005432784434	15441	43	13D
0005432784421	15441	44	14A
0005432784404	15441	45	14C
0005432784392	15441	46	14D
0005432784384	15441	47	14E
0005432784425	15441	48	14F
0005432784416	15441	49	15A
0005432784419	15441	50	15C
0005432784398	15441	51	15D
0005432784431	15441	52	16A
0005432784418	15441	53	16C
0005435242982	15441	54	16E
0005432784396	15441	55	16F
0005435242967	15441	56	17A
0005432784401	15441	57	17D
0005432784405	15441	58	17F
0005432784395	15441	59	18A
0005432784426	15441	60	18C
0005432784430	15441	61	18F
0005435242957	15441	62	19A
0005432784400	15441	63	19D
0005435242972	15441	64	19E
0005432784388	15441	65	19F
0005432784409	15441	66	20A
0005432784403	15441	67	20C
0005432784407	15441	68	20E
0005434878801	10073	1	1C
0005434878242	10073	2	1A
0005434878725	10073	3	1F
0005434878933	10073	4	1D
0005434878316	10073	5	2A
0005434878369	10073	6	2D
0005434878928	10073	7	2C
0005434878723	10073	8	3A
0005434878234	10073	9	2F
0005434878655	10073	10	3D
0005434878623	10073	11	3C
0005434878784	10073	12	4A
0005434878904	10073	13	3F
0005434878192	10073	14	4C
0005434878165	10073	15	4F
0005434878341	10073	16	4D
0005434878721	10073	17	5D
0005434878190	10073	18	5C
0005434878671	10073	19	5A
0005434878373	10073	20	5F
0005434878901	10073	21	6B
0005434878628	10073	22	6A
0005434878394	10073	23	6D
0005434878197	10073	24	6C
0005434878445	10073	25	6E
0005434878669	10073	26	7A
0005434878395	10073	27	6F
0005434878796	10073	28	7C
0005434878417	10073	29	7E
0005434878415	10073	30	7D
0005434878368	10073	31	8A
0005434910143	10073	32	7F
0005434878577	10073	33	8C
0005434878839	10073	34	8B
0005434878929	10073	35	8D
0005434878586	10073	36	8F
0005434878664	10073	37	8E
0005434878666	10073	38	9B
0005434878782	10073	39	9A
0005434878323	10073	40	9C
0005434878531	10073	41	9E
0005434878645	10073	42	9D
0005434878521	10073	43	10A
0005434878582	10073	44	9F
0005434878681	10073	45	10C
0005434878562	10073	46	10B
0005434878633	10073	47	10E
0005434878670	10073	48	10D
0005434878643	10073	49	10F
0005434878748	10073	50	11B
0005434878634	10073	51	11A
0005434910140	10073	52	11D
0005434878322	10073	53	11C
0005434878600	10073	54	11F
0005434878653	10073	55	11E
0005434878617	10073	56	12B
0005434878730	10073	57	12A
0005434878729	10073	58	12C
0005434878709	10073	59	12E
0005434878308	10073	60	12D
0005434878426	10073	61	13A
0005434878856	10073	62	12F
0005434878624	10073	63	13C
0005434878548	10073	64	13B
0005434878644	10073	65	13E
0005434878589	10073	66	13D
0005434878383	10073	67	14A
0005434878857	10073	68	13F
0005435913968	10073	69	14B
0005434878226	10073	70	14D
0005434878443	10073	71	14C
0005434878225	10073	72	14F
0005434878465	10073	73	14E
0005434878317	10073	74	15B
0005434878855	10073	75	15A
0005434878821	10073	76	15C
0005434878241	10073	77	15E
0005434878858	10073	78	15D
0005434878882	10073	79	16A
0005434878449	10073	80	15F
0005434878579	10073	81	16B
0005434910142	10073	82	16D
0005434878475	10073	83	16C
0005434878534	10073	84	16F
0005434878733	10073	85	16E
0005434878587	10073	86	17B
0005434878618	10073	87	17A
0005434878288	10073	88	17D
0005434878927	10073	89	17C
0005434878698	10073	90	17F
0005434878539	10073	91	17E
0005434878749	10073	92	18A
0005434878296	10073	93	18D
0005434878384	10073	94	18C
0005434878537	10073	95	18B
0005434878783	10073	96	18F
0005435913966	10073	97	18E
0005434878374	10073	98	19A
0005434878654	10073	99	19B
0005434878532	10073	100	19D
0005434878382	10073	101	19C
0005434878127	10073	102	20A
0005434878131	10073	103	19F
0005434878442	10073	104	19E
0005434878232	10073	105	20C
0005434878233	10073	106	20B
0005434758906	10073	107	20D
0005434878231	10073	108	20F
0005434910141	10073	109	20E
0005434878191	10073	110	21B
0005434878464	10073	111	21A
0005434878837	10073	112	21C
0005434878514	10073	113	21E
0005435913967	10073	114	21D
0005434878785	10073	115	21F
0005434879364	14601	1	1C
0005434879396	14601	2	1A
0005434879369	14601	3	1F
0005434879392	14601	4	1D
0005434879362	14601	5	2A
0005434879399	14601	6	2F
0005434879420	14601	7	2D
0005434879391	14601	8	2C
0005434879348	14601	9	3A
0005434879366	14601	10	3D
0005434910114	14601	11	3C
0005434879440	14601	12	4A
0005434879372	14601	13	3F
0005434879425	14601	14	4D
0005434879379	14601	15	4C
0005434879377	14601	16	4F
0005434758922	14601	17	5D
0005434879429	14601	18	5C
0005434879437	14601	19	5F
0005434879430	14601	20	6B
0005434879365	14601	21	6A
0005434879427	14601	22	6D
0005434879436	14601	23	6C
0005434879438	14601	24	7A
0005434879431	14601	25	6F
0005434879418	14601	26	7C
0005434879406	14601	27	7B
0005434879350	14601	28	7E
0005434879388	14601	29	7F
0005434879390	14601	30	8C
0005434879361	14601	31	8A
0005434879356	14601	32	8D
0005434879373	14601	33	8F
0005434879407	14601	34	8E
0005434879410	14601	35	9B
0005434879357	14601	36	9A
0005434879428	14601	37	9D
0005434879393	14601	38	9C
0005434879412	14601	39	9F
0005434879386	14601	40	9E
0005434879375	14601	41	10A
0005434879401	14601	42	10C
0005434879389	14601	43	10B
0005434879367	14601	44	10E
0005434879354	14601	45	10D
0005434879413	14601	46	11A
0005434879368	14601	47	10F
0005434879414	14601	48	11C
0005434879352	14601	49	11B
0005434879346	14601	50	11F
0005434879374	14601	51	11E
0005434879441	14601	52	12B
0005434879384	14601	53	12A
0005434879405	14601	54	12C
0005434879433	14601	55	12E
0005434879395	14601	56	12D
0005434879376	14601	57	13A
0005434879408	14601	58	12F
0005434879347	14601	59	13C
0005434879360	14601	60	13B
0005434879421	14601	61	13E
0005434879370	14601	62	13D
0005434879404	14601	63	13F
0005434879349	14601	64	14C
0005434879397	14601	65	14B
0005434879400	14601	66	14A
0005434879417	14601	67	14D
0005434879378	14601	68	14F
0005434879355	14601	69	14E
0005434879403	14601	70	15A
0005434879394	14601	71	15C
0005434879419	14601	72	15B
0005434758923	14601	73	15D
0005434879439	14601	74	16A
0005434879381	14601	75	15F
0005434879423	14601	76	16B
0005434879434	14601	77	16E
0005434879383	14601	78	16F
0005434879359	14601	79	17B
0005434879398	14601	80	17A
0005434879432	14601	81	17D
0005434879382	14601	82	17C
0005434879424	14601	83	17E
0005434910119	14601	84	18A
0005434879387	14601	85	18B
0005434879416	14601	86	19A
0005434879411	14601	87	19B
0005434879351	14601	88	19E
0005434879363	14601	89	19D
0005434879426	14601	90	20A
0005434879371	14601	91	19F
0005434879402	14601	92	20B
0005434879385	14601	93	20D
0005434879358	14601	94	20C
0005434879422	14601	95	20F
0005434879409	14601	96	20E
0005434879353	14601	97	21B
0005434879415	14601	98	21A
0005434879435	14601	99	21E
0005434879380	14601	100	21F
0005435660278	9250	1	1D
0005435660280	9250	2	2A
0005435660273	9250	3	3D
0005434252001	9250	4	4C
0005434251987	9250	5	5B
0005435660271	9250	6	5C
0005434251980	9250	7	6A
0005435660277	9250	8	7C
0005435660274	9250	9	7D
0005435660272	9250	10	18D
0005435660275	9250	11	19A
0005435660279	9250	12	19D
0005434252012	9250	13	20B
0005434251995	9250	14	21A
0005435660276	9250	15	21B
0005435660281	9250	16	22A
0005434251981	9250	17	22D
0005435660175	24635	1	1A
0005435660149	24635	2	1D
0005435660179	24635	3	3A
0005435660136	24635	4	3B
0005435660180	24635	5	3C
0005435660176	24635	6	4C
0005434252081	24635	7	5A
0005435660174	24635	8	5B
0005435660173	24635	9	5D
0005434252086	24635	10	5C
0005435660181	24635	11	6A
0005435660199	24635	12	6B
0005434252079	24635	13	7A
0005434252085	24635	14	7B
0005435660150	24635	15	7D
0005434252080	24635	16	18D
0005434252078	24635	17	19C
0005435660184	24635	18	20B
0005434252082	24635	19	20D
0005434252077	24635	20	21C
0005434252083	24635	21	22B
0005434252084	24635	22	23A
0005433681164	2810	1	1A
0005433681127	2810	2	1D
0005432966995	2810	3	1F
0005433681149	2810	4	2A
0005433681130	2810	5	2C
0005433681140	2810	6	2D
0005433681169	2810	7	2F
0005433681167	2810	8	3A
0005432967005	2810	9	3D
0005432966920	2810	10	4A
0005433684444	2810	11	4C
0005433681134	2810	12	4D
0005433681157	2810	13	4F
0005433681136	2810	14	5E
0005433681139	2810	15	5F
0005432966954	2810	16	6A
0005433681128	2810	17	6C
0005433681151	2810	18	6D
0005433681156	2810	19	6E
0005433681174	2810	20	6F
0005433681147	2810	21	7A
0005433681144	2810	22	7C
0005433681161	2810	23	7D
0005433681131	2810	24	7F
0005432967014	2810	25	8A
0005433681141	2810	26	8C
0005432967056	2810	27	8D
0005432967083	2810	28	8E
0005432222847	2810	29	8F
0005433681171	2810	30	9A
0005433681155	2810	31	9E
0005433681132	2810	32	10A
0005433681154	2810	33	10C
0005432967119	2810	34	10E
0005433681142	2810	35	10F
0005432967084	2810	36	11A
0005432967001	2810	37	11C
0005433681163	2810	38	11D
0005432966955	2810	39	11E
0005432222849	2810	40	11F
0005433681158	2810	41	12A
0005433681165	2810	42	12E
0005433684445	2810	43	12F
0005432966919	2810	44	13C
0005433681143	2810	45	13D
0005433681133	2810	46	13F
0005433681135	2810	47	14A
0005433681162	2810	48	14C
0005432967077	2810	49	14D
0005432222846	2810	50	14F
0005433681152	2810	51	15A
0005433681172	2810	52	15C
0005433681173	2810	53	15D
0005433681148	2810	54	15F
0005432967078	2810	55	16A
0005433681129	2810	56	16C
0005433681166	2810	57	16D
0005433681145	2810	58	16E
0005433681153	2810	59	17A
0005432966999	2810	60	17E
0005433681160	2810	61	17F
0005432967004	2810	62	18A
0005432967016	2810	63	18C
0005433681146	2810	64	18D
0005433681138	2810	65	18E
0005433681168	2810	66	18F
0005433681159	2810	67	19A
0005433681150	2810	68	19D
0005432967106	2810	69	19E
0005432966953	2810	70	19F
0005432222848	2810	71	20A
0005433681137	2810	72	20C
0005433681170	2810	73	20E
0005432967105	2810	74	20F
0005433680856	29176	1	1A
0005432967257	29176	2	1C
0005432967262	29176	3	1D
0005433680837	29176	4	1F
0005433680633	29176	5	2A
0005432967242	29176	6	2C
0005433690930	29176	7	2D
0005433680646	29176	8	2F
0005433680698	29176	9	3A
0005433680661	29176	10	3D
0005433680793	29176	11	3F
0005432967240	29176	12	4A
0005432967248	29176	13	4C
0005433680807	29176	14	4D
0005432967256	29176	15	4E
0005433680778	29176	16	4F
0005433680728	29176	17	5A
0005432967246	29176	18	5D
0005433680854	29176	19	5E
0005432967261	29176	20	6A
0005432005248	29176	21	6D
0005433680971	29176	22	6E
0005433680472	29176	23	6F
0005433680634	29176	24	7A
0005433680860	29176	25	7C
0005433680818	29176	26	7D
0005432967258	29176	27	7E
0005432967251	29176	28	7F
0005433680870	29176	29	8C
0005432005247	29176	30	8E
0005433680806	29176	31	8F
0005433680825	29176	32	9A
0005433680805	29176	33	9C
0005433690932	29176	34	9D
0005433680701	29176	35	9E
0005433680497	29176	36	9F
0005433680826	29176	37	10A
0005432967241	29176	38	10C
0005433680780	29176	39	10E
0005433680731	29176	40	10D
0005433680835	29176	41	10F
0005432967249	29176	42	11A
0005433680859	29176	43	11C
0005433680779	29176	44	11D
0005432967244	29176	45	11E
0005433680729	29176	46	11F
0005432967250	29176	47	12A
0005432967239	29176	48	12D
0005433680871	29176	49	12E
0005433680653	29176	50	12F
0005433680792	29176	51	13A
0005433680869	29176	52	13C
0005433680765	29176	53	13D
0005433680618	29176	54	13E
0005433680879	29176	55	13F
0005432967245	29176	56	14C
0005433690929	29176	57	14D
0005432005249	29176	58	14E
0005433680817	29176	59	14F
0005432967252	29176	60	15A
0005433680853	29176	61	15D
0005433680662	29176	62	15E
0005432967247	29176	63	16A
0005432967253	29176	64	16C
0005432967243	29176	65	16D
0005433680967	29176	66	16E
0005432967260	29176	67	16F
0005432967238	29176	68	17C
0005433680647	29176	69	17D
0005433680730	29176	70	17E
0005432967255	29176	71	18A
0005433680617	29176	72	18C
0005433680762	29176	73	18D
0005432967254	29176	74	18E
0005433680756	29176	75	18F
0005433680482	29176	76	19A
0005432967237	29176	77	19C
0005433680723	29176	78	19E
0005433680878	29176	79	19F
0005433687707	29176	80	20A
0005432967259	29176	81	20C
0005433680645	29176	82	20D
0005433680481	29176	83	20E
0005433680968	29176	84	20F
0005433634220	9309	1	1A
0005433615506	9309	2	1C
0005433615487	9309	3	1F
0005433615524	9309	4	1D
0005433634219	9309	5	2F
0005434163670	9309	6	2D
0005432145134	9309	7	3C
0005433615514	9309	8	4A
0005434163654	9309	9	4C
0005433615504	9309	10	4F
0005432756888	9309	11	4D
0005433634215	9309	12	5A
0005433615517	9309	13	5D
0005433615512	9309	14	5C
0005433634213	9309	15	6A
0005433634193	9309	16	6D
0005434163653	9309	17	6C
0005433615500	9309	18	6F
0005433634196	9309	19	7A
0005433577974	9309	20	7C
0005433634207	9309	21	7F
0005433615537	9309	22	7D
0005433634203	9309	23	8A
0005432755118	9309	24	8B
0005433634216	9309	25	8C
0005434163639	9309	26	8E
0005433634190	9309	27	8D
0005433634198	9309	28	8F
0005432756887	9309	29	9B
0005433615549	9309	30	9A
0005433577967	9309	31	9C
0005432755117	9309	32	9D
0005434163646	9309	33	10A
0005433634210	9309	34	9F
0005433615552	9309	35	10C
0005433615530	9309	36	10B
0005433615501	9309	37	10E
0005433615516	9309	38	10F
0005433577972	9309	39	11B
0005433615553	9309	40	11A
0005433615499	9309	41	11C
0005433615488	9309	42	11E
0005433634221	9309	43	11D
0005433615538	9309	44	11F
0005433615541	9309	45	12A
0005433577975	9309	46	12B
0005433615542	9309	47	12C
0005433615523	9309	48	12E
0005433634195	9309	49	12F
0005433615495	9309	50	13A
0005433615545	9309	51	13C
0005433615502	9309	52	13B
0005433634223	9309	53	13E
0005433634199	9309	54	14A
0005432755115	9309	55	13F
0005433615489	9309	56	14B
0005433577977	9309	57	14D
0005433577968	9309	58	14C
0005434163642	9309	59	14E
0005433615519	9309	60	15A
0005434163675	9309	61	14F
0005433615548	9309	62	15B
0005433634212	9309	63	15C
0005432755116	9309	64	15D
0005433615539	9309	65	15F
0005433615490	9309	66	16A
0005432145136	9309	67	16C
0005433615482	9309	68	16B
0005434152796	9309	69	16D
0005433634200	9309	70	16E
0005433577973	9309	71	16F
0005433615533	9309	72	17A
0005433615555	9309	73	17C
0005433615554	9309	74	17B
0005433634205	9309	75	17D
0005433615511	9309	76	17F
0005433634194	9309	77	17E
0005433634224	9309	78	18A
0005433577976	9309	79	18B
0005433577978	9309	80	18C
0005433615547	9309	81	18E
0005433615556	9309	82	18D
0005433634197	9309	83	19B
0005433634222	9309	84	18F
0005433615483	9309	85	19E
0005433615485	9309	86	19D
0005433615494	9309	87	19C
0005433577969	9309	88	20A
0005433577971	9309	89	20E
0005433615508	9309	90	20D
0005433634201	9309	91	20F
0005433615546	9309	92	21A
0005433615551	9309	93	21C
0005433615509	9309	94	21B
0005433615496	9309	95	21D
0005433615505	9309	96	21F
0005434163644	9309	97	22B
0005433615507	9309	98	22A
0005433615510	9309	99	22C
0005433615492	9309	100	22D
0005433634202	9309	101	22F
0005433615529	9309	102	22E
0005432756889	9309	103	23A
0005433634206	9309	104	23C
0005433615522	9309	105	23D
0005434272193	9309	106	23F
0005433615534	9309	107	24A
0005434269102	9309	108	24B
0005433577970	9309	109	24D
0005434152795	9309	110	24C
0005433615520	9309	111	24E
0005434163671	9309	112	25B
0005433615493	9309	113	25D
0005433634218	9309	114	25C
0005433634191	9309	115	25E
0005433615497	9309	116	26A
0005434163645	9309	117	25F
0005433615543	9309	118	26D
0005433615535	9309	119	26C
0005433615526	9309	120	26E
0005433634211	9309	121	27B
0005433634192	9309	122	27A
0005433634217	9309	123	27D
0005433615525	9309	124	27C
0005433615503	9309	125	27F
0005433615515	9309	126	27E
0005433615540	9309	127	28D
0005433615521	9309	128	28C
0005433615498	9309	129	28E
0005433634204	9309	130	28F
0005433634208	9309	131	29A
0005433615532	9309	132	29C
0005433615518	9309	133	29B
0005433615531	9309	134	29D
0005433615528	9309	135	29E
0005434272194	9309	136	30A
0005433634214	9309	137	29F
0005433615544	9309	138	30B
0005433615527	9309	139	30D
0005433615513	9309	140	30C
0005433615484	9309	141	30F
0005433615491	9309	142	30E
0005433615486	9309	143	31B
0005433615536	9309	144	31A
0005434163643	9309	145	31C
0005432145135	9309	146	31E
0005433634209	9309	147	31D
0005433615550	9309	148	31F
0005433614946	25238	1	1A
0005433614766	25238	2	1C
0005434163735	25238	3	2A
0005433614784	25238	4	1F
0005433614773	25238	5	3A
0005434163730	25238	6	3C
0005433633951	25238	7	3F
0005433614785	25238	8	4A
0005433614633	25238	9	4D
0005433614760	25238	10	4C
0005434163731	25238	11	4F
0005433614751	25238	12	5A
0005433614589	25238	13	5D
0005433615044	25238	14	5C
0005434273095	25238	15	6A
0005433614654	25238	16	6D
0005433614825	25238	17	7A
0005433614894	25238	18	6F
0005433614962	25238	19	7C
0005433577863	25238	20	7F
0005433614916	25238	21	7D
0005433633942	25238	22	8A
0005433614655	25238	23	8B
0005433614863	25238	24	8D
0005434163733	25238	25	8C
0005433614588	25238	26	8E
0005433615162	25238	27	9A
0005434163732	25238	28	8F
0005434163725	25238	29	9B
0005433633843	25238	30	9E
0005433614892	25238	31	9D
0005433614927	25238	32	9F
0005433633779	25238	33	10A
0005433614749	25238	34	10B
0005433615020	25238	35	10C
0005433615032	25238	36	10E
0005433615033	25238	37	10F
0005433577868	25238	38	11B
0005433614629	25238	39	11A
0005433614764	25238	40	11C
0005433615025	25238	41	11F
0005433614584	25238	42	12A
0005433577893	25238	43	12B
0005433633880	25238	44	12C
0005433614885	25238	45	12D
0005433633922	25238	46	13A
0005433577895	25238	47	12F
0005433633970	25238	48	13B
0005433633969	25238	49	13D
0005433615072	25238	50	14A
0005434163727	25238	51	13F
0005433577876	25238	52	14B
0005433577838	25238	53	14D
0005433615127	25238	54	14C
0005433615144	25238	55	15A
0005433577869	25238	56	14F
0005433633850	25238	57	15B
0005433614963	25238	58	15D
0005433633932	25238	59	15F
0005433614923	25238	60	15E
0005433614953	25238	61	16B
0005434272210	25238	62	16D
0005433577778	25238	63	16C
0005433614896	25238	64	16E
0005434273096	25238	65	16F
0005433615002	25238	66	17A
0005433633931	25238	67	17C
0005435854064	25238	68	17D
0005433577875	25238	69	18A
0005433614767	25238	70	18B
0005433614944	25238	71	18D
0005433614862	25238	72	18C
0005433614737	25238	73	18F
0005433614905	25238	74	19C
0005433614947	25238	75	19B
0005433614585	25238	76	20B
0005433633824	25238	77	20E
0005433614650	25238	78	21A
0005433614934	25238	79	21B
0005434163734	25238	80	21D
0005434163736	25238	81	21C
0005433615173	25238	82	21E
0005433633661	25238	83	21F
0005433615119	25238	84	22B
0005433633930	25238	85	22A
0005433633892	25238	86	22C
0005433614813	25238	87	22E
0005433577853	25238	88	22D
0005433615313	25238	89	22F
0005433633662	25238	90	23A
0005433614897	25238	91	23B
0005433615018	25238	92	23D
0005433614772	25238	93	23E
0005433614736	25238	94	24A
0005433577819	25238	95	24D
0005433614847	25238	96	24C
0005433633832	25238	97	24E
0005433577864	25238	98	24F
0005433614506	25238	99	25A
0005433614763	25238	100	25D
0005433614778	25238	101	25F
0005433633883	25238	102	25E
0005433614961	25238	103	26A
0005433614955	25238	104	26B
0005433614922	25238	105	26D
0005433615019	25238	106	26C
0005433633918	25238	107	26E
0005433614909	25238	108	27A
0005433614917	25238	109	27C
0005433615315	25238	110	27B
0005433633921	25238	111	27D
0005434163726	25238	112	28A
0005433614972	25238	113	27F
0005433614752	25238	114	28B
0005433633979	25238	115	28D
0005433633660	25238	116	28C
0005433577777	25238	117	28E
0005433577894	25238	118	29A
0005433614871	25238	119	28F
0005433633858	25238	120	29D
0005433614895	25238	121	29C
0005433577852	25238	122	29F
0005433633825	25238	123	29E
0005434163729	25238	124	30B
0005433633831	25238	125	30A
0005433615314	25238	126	30D
0005434163728	25238	127	30C
0005433614956	25238	128	30E
0005433614964	25238	129	30F
0005435854065	25238	130	31B
0005433614933	25238	131	31A
0005433577883	25238	132	31D
0005433633879	25238	133	31F
0005433615009	25238	134	31E
0005435947330	4226	1	1C
0005435986850	4226	2	1H
0005435856239	4226	3	2C
0005435947304	4226	4	3B
0005435947259	4226	5	3C
0005435947292	4226	6	4F
0005434271320	4226	7	5C
0005435947257	4226	8	5G
0005435856195	4226	9	11A
0005432184985	4226	10	9H
0005435986845	4226	11	12A
0005435986848	4226	12	14F
0005435947284	4226	13	14E
0005435986851	4226	14	14H
0005435856218	4226	15	17D
0005435856194	4226	16	17G
0005435947236	4226	17	18B
0005435986847	4226	18	18D
0005435787360	4226	19	19B
0005435947332	4226	20	19E
0005435854061	4226	21	20B
0005435947331	4226	22	22F
0005435947352	4226	23	22E
0005435856231	4226	24	22G
0005435947339	4226	25	22H
0005435856232	4226	26	23A
0005435947300	4226	27	23D
0005435947338	4226	28	24B
0005434271305	4226	29	24D
0005432571327	4226	30	25F
0005435856230	4226	31	25E
0005435947281	4226	32	28F
0005434271321	4226	33	29D
0005435947305	4226	34	30E
0005432571336	4226	35	31F
0005432184986	4226	36	34F
0005435986846	4226	37	35A
0005434271306	4226	38	36A
0005435986849	4226	39	36B
0005432184988	4226	40	38E
0005432184987	4226	41	39F
0005435947351	4226	42	39E
0005432571372	26612	1	1H
0005435986792	26612	2	2C
0005435986771	26612	3	2B
0005435947439	26612	4	3C
0005435787382	26612	5	3G
0005435986797	26612	6	4B
0005435947437	26612	7	5G
0005435856259	26612	8	11B
0005435947436	26612	9	12G
0005435947440	26612	10	12F
0005435947438	26612	11	13E
0005435856257	26612	12	13G
0005435787383	26612	13	14E
0005435947430	26612	14	14F
0005432571370	26612	15	14G
0005435947441	26612	16	15A
0005435947443	26612	17	16A
0005435947435	26612	18	15H
0005432571371	26612	19	16F
0005435986747	26612	20	16H
0005435986764	26612	21	17B
0005435947434	26612	22	18E
0005435947442	26612	23	20B
0005435856255	26612	24	21B
0005435947432	26612	25	21H
0005435986772	26612	26	22B
0005435986748	26612	27	22E
0005435947431	26612	28	23D
0005435986796	26612	29	27F
0005435787384	26612	30	27G
0005435947433	26612	31	28F
0005435856256	26612	32	29E
0005435856258	26612	33	31H
0005435947429	26612	34	32H
0005432571369	26612	35	35A
0005433569767	365	1	1D
0005433569793	365	2	1C
0005433074914	365	3	1A
0005433074866	365	4	1F
0005433569806	365	5	2A
0005433569836	365	6	2C
0005433074714	365	7	2F
0005433134163	365	8	2D
0005432239012	365	9	3A
0005433129302	365	10	3C
0005433129303	365	11	3D
0005433134144	365	12	4A
0005432948801	365	13	4C
0005433074813	365	14	4D
0005433569775	365	15	4F
0005433569827	365	16	5C
0005433074794	365	17	5A
0005432948492	365	18	5D
0005432948727	365	19	6A
0005433569798	365	20	5F
0005433074812	365	21	6C
0005433569807	365	22	6F
0005432948673	365	23	6D
0005433074879	365	24	7A
0005433569778	365	25	7D
0005433129291	365	26	7C
0005432948663	365	27	8A
0005432948474	365	28	7F
0005433074793	365	29	8C
0005433074810	365	30	8B
0005433569770	365	31	8E
0005433569803	365	32	8F
0005433569773	365	33	9B
0005433074924	365	34	9A
0005433074839	365	35	9C
0005433569824	365	36	9E
0005433569805	365	37	9D
0005433074696	365	38	9F
0005433569822	365	39	10A
0005432948680	365	40	10C
0005433074822	365	41	10B
0005433074874	365	42	10D
0005432948543	365	43	10E
0005432239011	365	44	11B
0005433569821	365	45	11A
0005432948681	365	46	11C
0005432948672	365	47	11D
0005433074823	365	48	11E
0005432948632	365	49	12A
0005433074875	365	50	11F
0005433074816	365	51	12B
0005432948731	365	52	12D
0005432948431	365	53	12C
0005432239013	365	54	12E
0005432948763	365	55	12F
0005433569786	365	56	13A
0005433074811	365	57	13C
0005432239015	365	58	13B
0005432948599	365	59	13D
0005432948447	365	60	13E
0005433569795	365	61	14A
0005433129290	365	62	13F
0005432239010	365	63	14B
0005433074764	365	64	14D
0005433569783	365	65	14C
0005432948454	365	66	14E
0005433569779	365	67	14F
0005433569812	365	68	15A
0005432948586	365	69	15C
0005433569832	365	70	15B
0005433569788	365	71	15E
0005432948666	365	72	15D
0005433074851	365	73	15F
0005433569781	365	74	16A
0005433569818	365	75	16C
0005433569789	365	76	16B
0005433569797	365	77	16D
0005433569835	365	78	16E
0005433569830	365	79	16F
0005433074821	365	80	17A
0005433074809	365	81	17C
0005432948765	365	82	17B
0005433569799	365	83	17E
0005433569831	365	84	17D
0005433074695	365	85	17F
0005432948683	365	86	18A
0005433569820	365	87	18C
0005433569800	365	88	18B
0005433129296	365	89	18D
0005433074852	365	90	18E
0005432948764	365	91	18F
0005432948598	365	92	19C
0005432948430	365	93	19B
0005432948670	365	94	19D
0005433569796	365	95	19E
0005433569813	365	96	20B
0005432948640	365	97	20A
0005432948475	365	98	20C
0005433569817	365	99	20E
0005432948544	365	100	20D
0005433134143	365	101	20F
0005432948458	365	102	21B
0005433569826	365	103	21A
0005433569809	365	104	21C
0005433569794	365	105	21F
0005433134150	365	106	21E
0005433569772	365	107	21D
0005432239014	365	108	22A
0005433074765	365	109	22B
0005432948790	365	110	22D
0005433569828	365	111	22C
0005432948619	365	112	22E
0005433569811	365	113	22F
0005432239009	365	114	23A
0005433129301	365	115	23C
0005433569808	365	116	23B
0005433569768	365	117	23D
0005433569787	365	118	23E
0005433134149	365	119	24A
0005433074865	365	120	23F
0005433074825	365	121	24B
0005433569804	365	122	24C
0005433569790	365	123	24E
0005433569771	365	124	24D
0005433074840	365	125	24F
0005433569829	365	126	25A
0005432948740	365	127	25B
0005433569819	365	128	25D
0005433569777	365	129	25C
0005433569784	365	130	25F
0005433569780	365	131	25E
0005433569816	365	132	26A
0005433074913	365	133	26B
0005433569823	365	134	26D
0005433134151	365	135	26C
0005433569825	365	136	26E
0005433569782	365	137	27A
0005433074709	365	138	26F
0005432948636	365	139	27C
0005432948485	365	140	27E
0005433569833	365	141	27D
0005432948491	365	142	27F
0005433074757	365	143	28A
0005433569791	365	144	28B
0005433569814	365	145	28C
0005433074668	365	146	28E
0005433569810	365	147	28D
0005433569769	365	148	29A
0005432948674	365	149	28F
0005433074871	365	150	29C
0005432948631	365	151	29B
0005432948570	365	152	29D
0005433569774	365	153	29E
0005432948679	365	154	30A
0005433569815	365	155	29F
0005433569776	365	156	30B
0005432948641	365	157	30D
0005433569785	365	158	30C
0005433134148	365	159	30E
0005433074817	365	160	30F
0005433074915	365	161	31B
0005433569834	365	162	31A
0005433074818	365	163	31C
0005433569801	365	164	31D
0005433569802	365	165	31E
0005433569792	365	166	31F
0005433569283	11562	1	1A
0005432948950	11562	2	1D
0005433568936	11562	3	2A
0005433131766	11562	4	1F
0005433569264	11562	5	2C
0005433569176	11562	6	3A
0005432948935	11562	7	2F
0005433134195	11562	8	3C
0005433569296	11562	9	3D
0005433569281	11562	10	3F
0005433075056	11562	11	4C
0005433569095	11562	12	4D
0005433075053	11562	13	4F
0005432948932	11562	14	5C
0005433569165	11562	15	5F
0005433075045	11562	16	6C
0005433569050	11562	17	6A
0005432948973	11562	18	6D
0005433569168	11562	19	6F
0005433569064	11562	20	7C
0005433075046	11562	21	7F
0005432948941	11562	22	7D
0005432948970	11562	23	8A
0005433569137	11562	24	8C
0005432948957	11562	25	8B
0005433131763	11562	26	8D
0005433075054	11562	27	8E
0005433569220	11562	28	8F
0005433569249	11562	29	9A
0005433569219	11562	30	9C
0005433075047	11562	31	9B
0005432948964	11562	32	9D
0005432192359	11562	33	9E
0005433075067	11562	34	10A
0005433131764	11562	35	9F
0005433569025	11562	36	10B
0005433569073	11562	37	10D
0005432948938	11562	38	10C
0005433075062	11562	39	10E
0005433569239	11562	40	11A
0005433568937	11562	41	11C
0005433569080	11562	42	11B
0005433131765	11562	43	11D
0005433131762	11562	44	11E
0005433569285	11562	45	12A
0005432948972	11562	46	11F
0005433134197	11562	47	12B
0005433075050	11562	48	12C
0005432948953	11562	49	12E
0005433569240	11562	50	12D
0005433569194	11562	51	13A
0005432948943	11562	52	12F
0005433134194	11562	53	13B
0005433569203	11562	54	13C
0005432948937	11562	55	13D
0005433075063	11562	56	13E
0005432948942	11562	57	14A
0005432948951	11562	58	13F
0005432948955	11562	59	14B
0005432948971	11562	60	14D
0005433569248	11562	61	14C
0005433075068	11562	62	14E
0005432948948	11562	63	14F
0005432192360	11562	64	15C
0005433568972	11562	65	15D
0005433569069	11562	66	15E
0005433569236	11562	67	16A
0005433568692	11562	68	16D
0005433075059	11562	69	16C
0005433569127	11562	70	16E
0005433134193	11562	71	16F
0005432948959	11562	72	17B
0005432948939	11562	73	17A
0005433568873	11562	74	17D
0005432948944	11562	75	17F
0005433075061	11562	76	17E
0005433569074	11562	77	18A
0005433569136	11562	78	18B
0005433134192	11562	79	18D
0005433075052	11562	80	18C
0005433569288	11562	81	18E
0005433075070	11562	82	18F
0005433075055	11562	83	19B
0005432948945	11562	84	19D
0005433569032	11562	85	19C
0005433569202	11562	86	20A
0005433075048	11562	87	19E
0005433075058	11562	88	20B
0005432948968	11562	89	20C
0005433075051	11562	90	20D
0005432948946	11562	91	20F
0005433569257	11562	92	21B
0005433569195	11562	93	21C
0005432948963	11562	94	21D
0005433569295	11562	95	21F
0005432948960	11562	96	21E
0005433569084	11562	97	22B
0005433568998	11562	98	22A
0005432948933	11562	99	22C
0005432948969	11562	100	22D
0005433568935	11562	101	22E
0005433569169	11562	102	23A
0005433569029	11562	103	23C
0005432948962	11562	104	23B
0005433568802	11562	105	23D
0005432948947	11562	106	23E
0005433131767	11562	107	23F
0005432948934	11562	108	24C
0005432948966	11562	109	24E
0005433075044	11562	110	24F
0005432948956	11562	111	25B
0005433569221	11562	112	25A
0005432948958	11562	113	25C
0005432948954	11562	114	25D
0005433075057	11562	115	25E
0005433569265	11562	116	25F
0005433075049	11562	117	26B
0005433075066	11562	118	26A
0005432948952	11562	119	26D
0005433569286	11562	120	26C
0005433075069	11562	121	26E
0005432192358	11562	122	26F
0005433075064	11562	123	27A
0005433569297	11562	124	27C
0005433568995	11562	125	27B
0005433569282	11562	126	27D
0005433134196	11562	127	27F
0005433569256	11562	128	27E
0005433569049	11562	129	28A
0005433569087	11562	130	28C
0005433569171	11562	131	28D
0005432948965	11562	132	28E
0005432948967	11562	133	28F
0005433569287	11562	134	29B
0005433075065	11562	135	29D
0005433569231	11562	136	29C
0005432948961	11562	137	29F
0005432948940	11562	138	30D
0005432948931	11562	139	30C
0005433568958	11562	140	30E
0005433569232	11562	141	30F
0005433569086	11562	142	31A
0005432948949	11562	143	31C
0005433569250	11562	144	31B
0005432948936	11562	145	31E
0005433569139	11562	146	31D
0005433075060	11562	147	31F
0005434733002	9959	1	1A
0005433817516	9959	2	2B
0005433817518	9959	3	3A
0005434732996	9959	4	3B
0005434732986	9959	5	4A
0005433817517	9959	6	5A
0005434732993	9959	7	4B
0005434733001	9959	8	6B
0005433817515	9959	9	6A
0005433817482	13990	1	1A
0005434733023	13990	2	2A
0005434733025	13990	3	1B
0005433817500	13990	4	3B
0005433817499	13990	5	4A
0005433817501	13990	6	5B
0005434733024	13990	7	6B
0005432655692	2351	1	1A
0005432226138	2351	2	1B
0005432985135	2351	3	1F
0005432985186	2351	4	1C
0005435982850	2351	5	1G
0005435982854	2351	6	2A
0005433754936	2351	7	1H
0005432869535	2351	8	2C
0005435982852	2351	9	2B
0005432985199	2351	10	2F
0005435982851	2351	11	2G
0005435982845	2351	12	3A
0005432655688	2351	13	2H
0005432985175	2351	14	3B
0005433754893	2351	15	3F
0005432985254	2351	16	3C
0005433434728	2351	17	3G
0005435982858	2351	18	3H
0005435982844	2351	19	4B
0005433766686	2351	20	4A
0005433754924	2351	21	4G
0005432985071	2351	22	4F
0005432985188	2351	23	5A
0005432655680	2351	24	4H
0005435982874	2351	25	5B
0005433754945	2351	26	5C
0005435982861	2351	27	5F
0005432655683	2351	28	9A
0005433434690	2351	29	5H
0005435982853	2351	30	5G
0005432985187	2351	31	9B
0005435982891	2351	32	9G
0005433754907	2351	33	9H
0005433754902	2351	34	11B
0005432985200	2351	35	11A
0005432985246	2351	36	11E
0005433754905	2351	37	11D
0005432300337	2351	38	11F
0005432226137	2351	39	11G
0005432655690	2351	40	12A
0005433754923	2351	41	11H
0005433754935	2351	42	12D
0005433754933	2351	43	12B
0005433754944	2351	44	12E
0005432985256	2351	45	12G
0005433754928	2351	46	12F
0005432300336	2351	47	12H
0005433764704	2351	48	13A
0005435982889	2351	49	13B
0005433754894	2351	50	13F
0005433754948	2351	51	13E
0005435982870	2351	52	13G
0005435982848	2351	53	13H
0005432226133	2351	54	14A
0005432655689	2351	55	14D
0005433434821	2351	56	14B
0005432985299	2351	57	14F
0005433754942	2351	58	14E
0005435982877	2351	59	14G
0005433434834	2351	60	14H
0005432655687	2351	61	15B
0005433754911	2351	62	15A
0005433434781	2351	63	15E
0005435982884	2351	64	15D
0005434731166	2351	65	15F
0005432985245	2351	66	15H
0005433754909	2351	67	15G
0005433434749	2351	68	16A
0005432985101	2351	69	16D
0005435982872	2351	70	16E
0005432985216	2351	71	16F
0005432985138	2351	72	16H
0005433766687	2351	73	16G
0005433754938	2351	74	17B
0005433766689	2351	75	17A
0005433754932	2351	76	17F
0005433434920	2351	77	17E
0005435982863	2351	78	17G
0005432869533	2351	79	18A
0005435982886	2351	80	17H
0005433754934	2351	81	18B
0005434731188	2351	82	18F
0005433754900	2351	83	18E
0005432985300	2351	84	18G
0005433754930	2351	85	19A
0005432985237	2351	86	18H
0005433754919	2351	87	19D
0005435982888	2351	88	19B
0005433754937	2351	89	19E
0005433434777	2351	90	19F
0005433434773	2351	91	19G
0005432985253	2351	92	20A
0005435982879	2351	93	19H
0005433434624	2351	94	20D
0005433754925	2351	95	20B
0005433754892	2351	96	20E
0005432226135	2351	97	20F
0005435982893	2351	98	20G
0005433434751	2351	99	21A
0005433434756	2351	100	21D
0005433754897	2351	101	21B
0005433754927	2351	102	21E
0005432985171	2351	103	21F
0005435982847	2351	104	21H
0005432300334	2351	105	21G
0005433754910	2351	106	22B
0005435982860	2351	107	22A
0005433434779	2351	108	22D
0005433754901	2351	109	22F
0005432226134	2351	110	22E
0005432655693	2351	111	22H
0005433764706	2351	112	22G
0005433754913	2351	113	23B
0005435982885	2351	114	23A
0005432655682	2351	115	23D
0005435982869	2351	116	23F
0005433754917	2351	117	23E
0005432985217	2351	118	23G
0005433754899	2351	119	24A
0005433434750	2351	120	24B
0005433754929	2351	121	24D
0005433754947	2351	122	24F
0005433434823	2351	123	24E
0005433434883	2351	124	24G
0005433754891	2351	125	25D
0005432226136	2351	126	24H
0005433754906	2351	127	25E
0005432985185	2351	128	27A
0005435982868	2351	129	25F
0005432985182	2351	130	27E
0005433754931	2351	131	27D
0005433434782	2351	132	27F
0005433754898	2351	133	27H
0005432985236	2351	134	27G
0005433754912	2351	135	28A
0005435982849	2351	136	28B
0005433434792	2351	137	28E
0005433754896	2351	138	28D
0005432985230	2351	139	28F
0005435982865	2351	140	28H
0005432655684	2351	141	28G
0005435982876	2351	142	29B
0005433764705	2351	143	29E
0005435982857	2351	144	29D
0005434731206	2351	145	29G
0005433754895	2351	146	29F
0005433754921	2351	147	29H
0005435982867	2351	148	30B
0005435982864	2351	149	30D
0005433434921	2351	150	30F
0005435982883	2351	151	30E
0005434731186	2351	152	30G
0005432985261	2351	153	30H
0005433754939	2351	154	31B
0005432300335	2351	155	31A
0005435982866	2351	156	31D
0005432869534	2351	157	31F
0005435982892	2351	158	31E
0005435982887	2351	159	31G
0005432985096	2351	160	31H
0005433754943	2351	161	32D
0005435982859	2351	162	32A
0005433766688	2351	163	32E
0005432655685	2351	164	32F
0005433434771	2351	165	32H
0005433434791	2351	166	32G
0005435982856	2351	167	33A
0005434731184	2351	168	33D
0005433754920	2351	169	33B
0005434731187	2351	170	33E
0005433754946	2351	171	33G
0005433434772	2351	172	33F
0005432985220	2351	173	33H
0005433754941	2351	174	34A
0005433754916	2351	175	34D
0005435982882	2351	176	34B
0005433754915	2351	177	34F
0005435982875	2351	178	34E
0005435982855	2351	179	34G
0005435982846	2351	180	35A
0005435982862	2351	181	34H
0005433434775	2351	182	35B
0005433754918	2351	183	35D
0005435982881	2351	184	35E
0005433754922	2351	185	35H
0005432655681	2351	186	35G
0005435982880	2351	187	36A
0005433754914	2351	188	36B
0005433754940	2351	189	36D
0005432869512	2351	190	36F
0005432300338	2351	191	36E
0005433434884	2351	192	36G
0005433754904	2351	193	37A
0005433754903	2351	194	36H
0005432869541	2351	195	37D
0005433434778	2351	196	37B
0005435982873	2351	197	37G
0005433434729	2351	198	37F
0005432655691	2351	199	37E
0005435982890	2351	200	37H
0005433754926	2351	201	38B
0005432300333	2351	202	38A
0005435982878	2351	203	38D
0005433754908	2351	204	38E
0005432869547	2351	205	38F
0005432655686	2351	206	39D
0005435982871	2351	207	38G
0005432226132	2351	208	39E
0005433434702	2351	209	39F
0005432985483	26189	1	1A
0005433435029	26189	2	1F
0005432985486	26189	3	1C
0005432049508	26189	4	1G
0005432655572	26189	5	2A
0005433754037	26189	6	1H
0005433754383	26189	7	2C
0005433754403	26189	8	2B
0005434731223	26189	9	2F
0005433754405	26189	10	2G
0005433754421	26189	11	3A
0005433754579	26189	12	2H
0005435982420	26189	13	3B
0005432869606	26189	14	3F
0005433754527	26189	15	3G
0005435982345	26189	16	3H
0005433764685	26189	17	4B
0005435982489	26189	18	4A
0005433754411	26189	19	4C
0005433754233	26189	20	4G
0005435982342	26189	21	4F
0005432985471	26189	22	5A
0005433435015	26189	23	4H
0005433435036	26189	24	5B
0005433754630	26189	25	5C
0005435982601	26189	26	5G
0005432985463	26189	27	5F
0005433435042	26189	28	5H
0005432985485	26189	29	9B
0005433754350	26189	30	9A
0005432655595	26189	31	9H
0005433754556	26189	32	11B
0005432985473	26189	33	11A
0005433754342	26189	34	11E
0005435982461	26189	35	11G
0005433435019	26189	36	11F
0005435982382	26189	37	12A
0005433754215	26189	38	12D
0005435982308	26189	39	12B
0005432985489	26189	40	12F
0005433754544	26189	41	12H
0005435982637	26189	42	13B
0005432985477	26189	43	13A
0005435982367	26189	44	13D
0005432655566	26189	45	13F
0005432655594	26189	46	13E
0005433754160	26189	47	13G
0005432655606	26189	48	14A
0005433435041	26189	49	13H
0005432051168	26189	50	14E
0005433754386	26189	51	14D
0005435982452	26189	52	14B
0005432869603	26189	53	14H
0005435982506	26189	54	14G
0005433435020	26189	55	15A
0005432985468	26189	56	15B
0005433754278	26189	57	15E
0005433754772	26189	58	15D
0005433435025	26189	59	15F
0005433754545	26189	60	15H
0005433754580	26189	61	15G
0005433435032	26189	62	16A
0005432985478	26189	63	16D
0005433754325	26189	64	16B
0005435982443	26189	65	16E
0005433435026	26189	66	16G
0005433754406	26189	67	16F
0005435982311	26189	68	16H
0005432985482	26189	69	17A
0005432655543	26189	70	17D
0005435982462	26189	71	17B
0005433435037	26189	72	17F
0005433435040	26189	73	17E
0005433435033	26189	74	17G
0005432049507	26189	75	18A
0005435982312	26189	76	17H
0005435982421	26189	77	18B
0005433754428	26189	78	18E
0005432655571	26189	79	18D
0005433754583	26189	80	18G
0005432985464	26189	81	18F
0005432985474	26189	82	19A
0005433754476	26189	83	19B
0005432985465	26189	84	19E
0005433435024	26189	85	19D
0005433435038	26189	86	19G
0005432985466	26189	87	20A
0005432869604	26189	88	19H
0005434731225	26189	89	20D
0005433754201	26189	90	20B
0005435982353	26189	91	20F
0005433754185	26189	92	20H
0005432655567	26189	93	20G
0005433766656	26189	94	21A
0005435982291	26189	95	21B
0005432985491	26189	96	21E
0005432985476	26189	97	21G
0005433766649	26189	98	21F
0005433754385	26189	99	21H
0005432985479	26189	100	22B
0005435982296	26189	101	22A
0005435982417	26189	102	22D
0005435982539	26189	103	22F
0005433766648	26189	104	22E
0005435982330	26189	105	22G
0005433754288	26189	106	23A
0005433754348	26189	107	22H
0005432985494	26189	108	23B
0005432985467	26189	109	23D
0005433754408	26189	110	23F
0005435982566	26189	111	23E
0005432985493	26189	112	23H
0005435982405	26189	113	23G
0005434731224	26189	114	24B
0005433754324	26189	115	24A
0005435982453	26189	116	24E
0005432869605	26189	117	24D
0005432985490	26189	118	24F
0005432049509	26189	119	24H
0005435982636	26189	120	24G
0005434731222	26189	121	25D
0005435982451	26189	122	25E
0005433435027	26189	123	27A
0005433766661	26189	124	25F
0005435982248	26189	125	27B
0005433754283	26189	126	27E
0005433754496	26189	127	27D
0005433754604	26189	128	27F
0005432869601	26189	129	27G
0005432985492	26189	130	28A
0005435982350	26189	131	27H
0005432985487	26189	132	28B
0005433754279	26189	133	28E
0005433754525	26189	134	28D
0005435982447	26189	135	28F
0005433754443	26189	136	28H
0005435982488	26189	137	28G
0005432655568	26189	138	29A
0005433754458	26189	139	29D
0005433754339	26189	140	29G
0005433435034	26189	141	29F
0005433766641	26189	142	29H
0005435982614	26189	143	30A
0005433754600	26189	144	30D
0005433435018	26189	145	30B
0005435982538	26189	146	30F
0005433754327	26189	147	30E
0005433754326	26189	148	30G
0005433435031	26189	149	30H
0005433754407	26189	150	31B
0005433435039	26189	151	31A
0005433754260	26189	152	31D
0005433754346	26189	153	31F
0005433754438	26189	154	31G
0005433435017	26189	155	32A
0005435982422	26189	156	31H
0005432985472	26189	157	32D
0005433754289	26189	158	32G
0005433754300	26189	159	32F
0005435982484	26189	160	32H
0005432985484	26189	161	33A
0005433435023	26189	162	33B
0005433754578	26189	163	33E
0005432655576	26189	164	33D
0005433754526	26189	165	33F
0005433754232	26189	166	33G
0005432655573	26189	167	34A
0005435982511	26189	168	34D
0005433754349	26189	169	34B
0005435982247	26189	170	34F
0005435982647	26189	171	34H
0005433754436	26189	172	34G
0005433435035	26189	173	35B
0005435982349	26189	174	35A
0005433754435	26189	175	35D
0005435982505	26189	176	35F
0005432985488	26189	177	35E
0005435982481	26189	178	35G
0005435982366	26189	179	36A
0005432985475	26189	180	35H
0005433435016	26189	181	36B
0005432051166	26189	182	36D
0005432985481	26189	183	36F
0005432985469	26189	184	36E
0005435982344	26189	185	36H
0005433435030	26189	186	37A
0005433435028	26189	187	37B
0005435982648	26189	188	37D
0005433435021	26189	189	37E
0005432051167	26189	190	37H
0005432985470	26189	191	37G
0005433435022	26189	192	38A
0005432985480	26189	193	38E
0005435982343	26189	194	38D
0005435982446	26189	195	38F
0005433754601	26189	196	38H
0005432869602	26189	197	38G
0005432051165	26189	198	39E
0005435982352	26189	199	39D
0005435982548	26189	200	39F
0005433151437	1527	1	1C
0005433151551	1527	2	1A
0005433151438	1527	3	1D
0005433151597	1527	4	2A
0005433151623	1527	5	2C
0005434375197	1527	6	2D
0005434375212	1527	7	2F
0005434375201	1527	8	3F
0005434375192	1527	9	3D
0005433461614	1527	10	4B
0005433151490	1527	11	4A
0005433931481	1527	12	4C
0005434375193	1527	13	4E
0005434375217	1527	14	4D
0005434029666	1527	15	5A
0005433151533	1527	16	4F
0005433151619	1527	17	5C
0005433461615	1527	18	5B
0005434375205	1527	19	5D
0005434375218	1527	20	5E
0005434375200	1527	21	5F
0005433151513	1527	22	6C
0005434375196	1527	23	6D
0005433764686	1527	24	6F
0005434375215	1527	25	7B
0005434375224	1527	26	7A
0005434375199	1527	27	7C
0005433151618	1527	28	7E
0005434029665	1527	29	7F
0005433151596	1527	30	8B
0005434375222	1527	31	8A
0005432267979	1527	32	8D
0005433151517	1527	33	8C
0005433151516	1527	34	8E
0005433151648	1527	35	9A
0005433151518	1527	36	9B
0005434375190	1527	37	9D
0005434375206	1527	38	9C
0005434375189	1527	39	9F
0005434375228	1527	40	10B
0005434375221	1527	41	10D
0005433151572	1527	42	11A
0005433151557	1527	43	11B
0005432267978	1527	44	11C
0005432267981	1527	45	11D
0005433151573	1527	46	11F
0005433151647	1527	47	12B
0005434029658	1527	48	12C
0005434375226	1527	49	13A
0005433151707	1527	50	12F
0005434375220	1527	51	13C
0005434029659	1527	52	13B
0005433151552	1527	53	13F
0005432267980	1527	54	14B
0005434375202	1527	55	14A
0005434375210	1527	56	14D
0005433151569	1527	57	14C
0005433151578	1527	58	14E
0005434375211	1527	59	14F
0005433460462	1527	60	15B
0005434375223	1527	61	15A
0005434375225	1527	62	15C
0005433151556	1527	63	15E
0005434375219	1527	64	16A
0005433151588	1527	65	15F
0005433460463	1527	66	16B
0005434375229	1527	67	16C
0005433151507	1527	68	17A
0005434029657	1527	69	16F
0005433151640	1527	70	17B
0005433151558	1527	71	17E
0005434375204	1527	72	17F
0005434029661	1527	73	18B
0005434029668	1527	74	18A
0005432267977	1527	75	18C
0005434375216	1527	76	18E
0005432267976	1527	77	18D
0005433151635	1527	78	18F
0005434375194	1527	79	19A
0005433151559	1527	80	19C
0005433151699	1527	81	19B
0005434375195	1527	82	19D
0005434375208	1527	83	19F
0005434375214	1527	84	19E
0005433151663	1527	85	20A
0005434375207	1527	86	20B
0005434375198	1527	87	20D
0005434375227	1527	88	20E
0005432267975	1527	89	20F
0005433151700	1527	90	21A
0005433461616	1527	91	21B
0005433151568	1527	92	21D
0005433151478	1527	93	21C
0005434375213	1527	94	21F
0005433151734	1527	95	21E
0005434375209	1527	96	22B
0005433151589	1527	97	22A
0005433151447	1527	98	22C
0005433151664	1527	99	22D
0005433764687	1527	100	22E
0005433151607	1527	101	22F
0005433151514	1527	102	23B
0005434375191	1527	103	23A
0005434375203	1527	104	23C
0005434029662	1527	105	23E
0005433931475	1527	106	23D
0005433151662	1527	107	23F
0005434374761	20145	1	1A
0005434375040	20145	2	1C
0005433151844	20145	3	1F
0005434374662	20145	4	1D
0005433151843	20145	5	2A
0005433764706	20145	6	2C
0005434029690	20145	7	2D
0005434374885	20145	8	2F
0005433151838	20145	9	3A
0005433151841	20145	10	3D
0005434029687	20145	11	3F
0005434374750	20145	12	4C
0005434374703	20145	13	4D
0005434374877	20145	14	4E
0005434374644	20145	15	5A
0005433151839	20145	16	4F
0005434374660	20145	17	5B
0005433151837	20145	18	5D
0005432056347	20145	19	5F
0005434374699	20145	20	6A
0005434374826	20145	21	6B
0005434029688	20145	22	6C
0005433151817	20145	23	6D
0005434374760	20145	24	6F
0005433151831	20145	25	7B
0005434374888	20145	26	7C
0005433151823	20145	27	7E
0005434374833	20145	28	7D
0005434374690	20145	29	7F
0005434374995	20145	30	8B
0005433151845	20145	31	8A
0005434029689	20145	32	8C
0005434375003	20145	33	8E
0005433151814	20145	34	9B
0005433151820	20145	35	8F
0005434374648	20145	36	9C
0005434374643	20145	37	9D
0005433151818	20145	38	9F
0005433151826	20145	39	9E
0005433151833	20145	40	10B
0005434374702	20145	41	10D
0005433151836	20145	42	11A
0005434374694	20145	43	11E
0005433151822	20145	44	11F
0005434374840	20145	45	12C
0005433151835	20145	46	12B
0005433764705	20145	47	12F
0005434374882	20145	48	13B
0005433151842	20145	49	13A
0005433151824	20145	50	13D
0005432056344	20145	51	13C
0005433931505	20145	52	13E
0005434374695	20145	53	13F
0005433151816	20145	54	14C
0005434374724	20145	55	14D
0005433151821	20145	56	15B
0005434374932	20145	57	15A
0005433931506	20145	58	15C
0005434374954	20145	59	15D
0005433151846	20145	60	15F
0005433151828	20145	61	16B
0005434374955	20145	62	16D
0005434374726	20145	63	16F
0005433151830	20145	64	17A
0005434375039	20145	65	17B
0005432056345	20145	66	17D
0005433151847	20145	67	17F
0005433151827	20145	68	17E
0005434374661	20145	69	18A
0005433151829	20145	70	18F
0005433151813	20145	71	19A
0005434374876	20145	72	19C
0005434374655	20145	73	19D
0005434374751	20145	74	19E
0005433151834	20145	75	19F
0005434374729	20145	76	20A
0005433151840	20145	77	20C
0005434374683	20145	78	20B
0005432056346	20145	79	20D
0005434374746	20145	80	20E
0005434374917	20145	81	21A
0005434374769	20145	82	21C
0005434374832	20145	83	21B
0005433151825	20145	84	21D
0005434374682	20145	85	21E
0005434374725	20145	86	22A
0005434374767	20145	87	21F
0005434374956	20145	88	22C
0005434374886	20145	89	22D
0005433151819	20145	90	22E
0005433764704	20145	91	23A
0005434374766	20145	92	23B
0005434374770	20145	93	23D
0005433151832	20145	94	23F
0005433151815	20145	95	23E
0005432282948	555	1	1C
0005432425018	555	2	1D
0005432425040	555	3	2C
0005432425033	555	4	3A
0005432425009	555	5	3C
0005432425046	555	6	3D
0005432425021	555	7	4C
0005432425043	555	8	4D
0005432425017	555	9	5F
0005432425034	555	10	6A
0005432425041	555	11	6C
0005432425013	555	12	7C
0005432425030	555	13	7F
0005432425054	555	14	7D
0005432425063	555	15	8A
0005432425049	555	16	8B
0005432282950	555	17	8D
0005432282949	555	18	9A
0005432425050	555	19	9C
0005432425065	555	20	9D
0005432425053	555	21	10A
0005432425070	555	22	10C
0005432425028	555	23	10F
0005432425042	555	24	10E
0005432425029	555	25	11C
0005432425016	555	26	11F
0005432425073	555	27	12D
0005432425015	555	28	12C
0005432425044	555	29	12E
0005432425037	555	30	12F
0005432425051	555	31	14B
0005432425035	555	32	15A
0005432425072	555	33	15E
0005432425068	555	34	15F
0005432425022	555	35	16C
0005432425062	555	36	16B
0005432425060	555	37	17B
0005432282953	555	38	17D
0005432425020	555	39	18A
0005432425074	555	40	18C
0005432425012	555	41	18D
0005432425010	555	42	18E
0005432425014	555	43	19C
0005432425056	555	44	19D
0005432425071	555	45	20A
0005432425048	555	46	20B
0005432425031	555	47	20C
0005432425045	555	48	20D
0005432425024	555	49	20F
0005432425059	555	50	21B
0005432425023	555	51	21D
0005432425055	555	52	22C
0005432425066	555	53	22D
0005432282951	555	54	23C
0005432425075	555	55	23B
0005432425069	555	56	24A
0005432425047	555	57	24F
0005432425061	555	58	25A
0005432425019	555	59	25B
0005432282954	555	60	25D
0005432425039	555	61	25E
0005432425025	555	62	26A
0005432425036	555	63	26B
0005432425011	555	64	26D
0005432425064	555	65	27B
0005432425027	555	66	27D
0005432282952	555	67	27F
0005432425058	555	68	27E
0005432425067	555	69	28A
0005432425026	555	70	28C
0005432425032	555	71	29A
0005432425038	555	72	30F
0005432425052	555	73	31D
0005432425057	555	74	31E
0005432302376	12858	1	18B
0005432302378	12858	2	23F
0005432302379	12858	3	24F
0005432302377	12858	4	28C
0005432424547	12914	1	1A
0005432424564	12914	2	1D
0005432424519	12914	3	2A
0005432424545	12914	4	2C
0005432424563	12914	5	2D
0005432424524	12914	6	3A
0005432424530	12914	7	3D
0005432424436	12914	8	3C
0005432424467	12914	9	3F
0005432424434	12914	10	4C
0005432424361	12914	11	5F
0005432424535	12914	12	6C
0005432424596	12914	13	6D
0005432424462	12914	14	7A
0005432424427	12914	15	8A
0005432424598	12914	16	8B
0005432424522	12914	17	9E
0005432424573	12914	18	10C
0005432424502	12914	19	10E
0005432424576	12914	20	11A
0005432424435	12914	21	11C
0005432424551	12914	22	12C
0005432424517	12914	23	12E
0005432424597	12914	24	13E
0005432424605	12914	25	14D
0005432424565	12914	26	14C
0005432424579	12914	27	15D
0005432424424	12914	28	16D
0005432424472	12914	29	16E
0005432424599	12914	30	17A
0005432424509	12914	31	17C
0005432424559	12914	32	18B
0005432424608	12914	33	18E
0005432424558	12914	34	21E
0005432424581	12914	35	21F
0005432424591	12914	36	22C
0005432424503	12914	37	22E
0005432424508	12914	38	23F
0005432424425	12914	39	24B
0005432424589	12914	40	24E
0005432424580	12914	41	24F
0005432424463	12914	42	25C
0005432424560	12914	43	25E
0005432424575	12914	44	26A
0005432424546	12914	45	27C
0005432424518	12914	46	28C
0005432424521	12914	47	29A
0005432424437	12914	48	29C
0005432424413	12914	49	30C
0005432424459	12914	50	31E
0005433058226	469	1	1C
0005434024543	469	2	1G
0005434024537	469	3	1H
0005433058164	469	4	2B
0005434024570	469	5	2C
0005434024557	469	6	2G
0005432235730	469	7	2H
0005432235732	469	8	3G
0005434032075	469	9	4A
0005434024539	469	10	4B
0005434024565	469	11	4F
0005433684437	469	12	4C
0005434024531	469	13	4G
0005434024574	469	14	5A
0005434024573	469	15	5B
0005434032076	469	16	5G
0005433058030	469	17	5F
0005434024546	469	18	9A
0005433058295	469	19	9G
0005434024577	469	20	11A
0005433058049	469	21	9H
0005434024550	469	22	11B
0005433058044	469	23	11E
0005433057958	469	24	11D
0005433057945	469	25	11H
0005434024523	469	26	12E
0005432235734	469	27	12G
0005434028332	469	28	12F
0005432235733	469	29	13A
0005432235728	469	30	13D
0005434032078	469	31	13G
0005434024548	469	32	13F
0005434024559	469	33	13H
0005434024549	469	34	14B
0005434024554	469	35	14D
0005433058269	469	36	14F
0005434024526	469	37	14E
0005434024517	469	38	14H
0005433058040	469	39	15E
0005432045636	469	40	15F
0005434024524	469	41	15H
0005434024547	469	42	16A
0005433684422	469	43	16D
0005434024544	469	44	16F
0005434024575	469	45	16E
0005433058165	469	46	16G
0005433057965	469	47	17A
0005434024572	469	48	17D
0005434024519	469	49	17E
0005434024536	469	50	17G
0005434024515	469	51	17H
0005433058184	469	52	18B
0005434029686	469	53	18D
0005433057933	469	54	18E
0005433058183	469	55	19A
0005434024535	469	56	18H
0005433929609	469	57	19F
0005434032079	469	58	20A
0005434029685	469	59	19H
0005434024551	469	60	20D
0005433058086	469	61	20B
0005433058109	469	62	20E
0005434024521	469	63	20G
0005434024534	469	64	20H
0005433929611	469	65	21B
0005434024527	469	66	21G
0005434024566	469	67	21F
0005434024561	469	68	22D
0005434024567	469	69	22E
0005434024555	469	70	22G
0005434024571	469	71	22H
0005433929608	469	72	23A
0005434028328	469	73	23D
0005434024542	469	74	23F
0005434024514	469	75	23G
0005434024579	469	76	24A
0005434024538	469	77	23H
0005433058268	469	78	24B
0005434024578	469	79	24D
0005433057944	469	80	24E
0005433058048	469	81	25E
0005434024545	469	82	25F
0005433684438	469	83	27B
0005434024530	469	84	27F
0005434024525	469	85	27E
0005433058039	469	86	27G
0005433058102	469	87	28A
0005434032077	469	88	28B
0005432235727	469	89	28E
0005434024556	469	90	28F
0005433058145	469	91	28G
0005433058034	469	92	28H
0005433929618	469	93	29B
0005434024529	469	94	29E
0005432045637	469	95	29H
0005434024522	469	96	30A
0005434024560	469	97	30F
0005433929629	469	98	30E
0005434028331	469	99	30G
0005433058154	469	100	30H
0005434024553	469	101	31B
0005433057987	469	102	31F
0005433057988	469	103	31G
0005433058230	469	104	32A
0005434024568	469	105	32F
0005434024532	469	106	32G
0005433058075	469	107	33H
0005433929631	469	108	33G
0005433058117	469	109	34A
0005434024562	469	110	34D
0005432235731	469	111	34F
0005433057935	469	112	34E
0005434024569	469	113	34G
0005433058076	469	114	34H
0005434024552	469	115	35B
0005434024563	469	116	35A
0005434024576	469	117	35F
0005432235729	469	118	35E
0005433058071	469	119	35G
0005432045635	469	120	36A
0005432235735	469	121	36D
0005434024520	469	122	36F
0005434028329	469	123	36E
0005434024528	469	124	36G
0005433684436	469	125	37A
0005434024558	469	126	36H
0005434024541	469	127	37E
0005434024516	469	128	37D
0005434024580	469	129	37F
0005434735698	469	130	37G
0005434024564	469	131	38A
0005434024540	469	132	38F
0005434024533	469	133	38E
0005434028330	469	134	38D
0005434024518	469	135	39D
0005434024513	469	136	39F
0005434029662	12644	1	1B
0005434735753	12644	2	1A
0005434023743	12644	3	1C
0005434024104	12644	4	1G
0005434029665	12644	5	2A
0005433058401	12644	6	1H
0005434023981	12644	7	2B
0005434023857	12644	8	2G
0005433058370	12644	9	3A
0005434023964	12644	10	2H
0005433058363	12644	11	3C
0005433058382	12644	12	3F
0005433058377	12644	13	4C
0005433058387	12644	14	4A
0005433058391	12644	15	4F
0005434023910	12644	16	4G
0005433058384	12644	17	5B
0005433058392	12644	18	5A
0005434023909	12644	19	5C
0005434024125	12644	20	5G
0005434024100	12644	21	5F
0005434024047	12644	22	5H
0005433058388	12644	23	9G
0005434024261	12644	24	9H
0005434023738	12644	25	11B
0005434024150	12644	26	11E
0005434023997	12644	27	11D
0005434029659	12644	28	11F
0005433058398	12644	29	12A
0005434029657	12644	30	12D
0005434023915	12644	31	12G
0005433684446	12644	32	12F
0005433058389	12644	33	13A
0005434023982	12644	34	13B
0005434024091	12644	35	13F
0005433058400	12644	36	13E
0005433058399	12644	37	13H
0005434024120	12644	38	14B
0005434023973	12644	39	14A
0005433684447	12644	40	14D
0005433058362	12644	41	14F
0005434735754	12644	42	14E
0005434735752	12644	43	14G
0005434023962	12644	44	15A
0005434024016	12644	45	14H
0005434023931	12644	46	15E
0005434024139	12644	47	15D
0005433058366	12644	48	15F
0005433058394	12644	49	15G
0005434023781	12644	50	15H
0005433058395	12644	51	16D
0005434735757	12644	52	16F
0005434024027	12644	53	16H
0005434024124	12644	54	16G
0005434023912	12644	55	17B
0005433929663	12644	56	17A
0005434023993	12644	57	18A
0005433058386	12644	58	17H
0005433058376	12644	59	18E
0005432156418	12644	60	18G
0005434023667	12644	61	19A
0005432156419	12644	62	19D
0005434029668	12644	63	19F
0005433058396	12644	64	19H
0005433058378	12644	65	20A
0005433058371	12644	66	20B
0005433058379	12644	67	20D
0005433929662	12644	68	20F
0005434023727	12644	69	20H
0005433058364	12644	70	20G
0005434023992	12644	71	21B
0005434024003	12644	72	21A
0005434029666	12644	73	21H
0005434735758	12644	74	21G
0005434023637	12644	75	22B
0005434735755	12644	76	22E
0005434029661	12644	77	22G
0005434024366	12644	78	22H
0005433058368	12644	79	23A
0005434024278	12644	80	23D
0005434032041	12644	81	23B
0005434023680	12644	82	23E
0005433058393	12644	83	23H
0005434024035	12644	84	23G
0005434023945	12644	85	24B
0005432156422	12644	86	24A
0005434023916	12644	87	24D
0005434024145	12644	88	24F
0005434023770	12644	89	24G
0005433929664	12644	90	24H
0005433058381	12644	91	25F
0005434023869	12644	92	25E
0005434024365	12644	93	25D
0005434024260	12644	94	27A
0005433058383	12644	95	27B
0005434032061	12644	96	27E
0005432157516	12644	97	27D
0005434023868	12644	98	27F
0005433058373	12644	99	27G
0005433058390	12644	100	28A
0005434735756	12644	101	27H
0005434023996	12644	102	28B
0005434023638	12644	103	28D
0005434032054	12644	104	28E
0005434023749	12644	105	29B
0005434024078	12644	106	29E
0005434023998	12644	107	29G
0005433058397	12644	108	29F
0005434023795	12644	109	30A
0005434023867	12644	110	29H
0005434023668	12644	111	30D
0005434023782	12644	112	30F
0005434023954	12644	113	30E
0005434024138	12644	114	30G
0005434024082	12644	115	31B
0005434024023	12644	116	31D
0005433058367	12644	117	31F
0005434023991	12644	118	31G
0005433058369	12644	119	32A
0005433058372	12644	120	31H
0005434023681	12644	121	32E
0005433058365	12644	122	32G
0005434024040	12644	123	32F
0005434023932	12644	124	33A
0005433929665	12644	125	33D
0005432156420	12644	126	33F
0005434023748	12644	127	33H
0005434023698	12644	128	34B
0005433058380	12644	129	34E
0005434023771	12644	130	34G
0005434024026	12644	131	34H
0005434024046	12644	132	35B
0005434023985	12644	133	35G
0005434023666	12644	134	35F
0005434023865	12644	135	35H
0005434024028	12644	136	36B
0005434023976	12644	137	36D
0005434023911	12644	138	36F
0005432157515	12644	139	36E
0005434023758	12644	140	36G
0005434024129	12644	141	37B
0005432156421	12644	142	37E
0005434024015	12644	143	37D
0005433058361	12644	144	37F
0005433058374	12644	145	38B
0005434024039	12644	146	38A
0005433058375	12644	147	38E
0005434032051	12644	148	38G
0005434023953	12644	149	38F
0005434029658	12644	150	38H
0005433058385	12644	151	39D
0005433924512	2114	1	1A
0005433924489	2114	2	1B
0005433924458	2114	3	1F
0005433924514	2114	4	1C
0005433036457	2114	5	1G
0005433036530	2114	6	2A
0005433924494	2114	7	1H
0005433036583	2114	8	2C
0005433924521	2114	9	2B
0005433924486	2114	10	2G
0005433036416	2114	11	3A
0005433924518	2114	12	3B
0005433924472	2114	13	3F
0005433036534	2114	14	4A
0005433036493	2114	15	3H
0005433924516	2114	16	4B
0005433924481	2114	17	4F
0005432231690	2114	18	4C
0005432044558	2114	19	4G
0005433924517	2114	20	4H
0005433924435	2114	21	5B
0005433924487	2114	22	5F
0005433924498	2114	23	5H
0005433036376	2114	24	5G
0005433924501	2114	25	9B
0005433036537	2114	26	9G
0005433924480	2114	27	11D
0005433924475	2114	28	11B
0005433924461	2114	29	11E
0005433931505	2114	30	11F
0005432231693	2114	31	11H
0005433924530	2114	32	11G
0005433924528	2114	33	12B
0005433924450	2114	34	12E
0005433036692	2114	35	12F
0005433924497	2114	36	12H
0005433924504	2114	37	12G
0005433036567	2114	38	13A
0005433036538	2114	39	13D
0005433875397	2114	40	13F
0005432044559	2114	41	13E
0005433924449	2114	42	13G
0005433924495	2114	43	14A
0005432231694	2114	44	13H
0005433924456	2114	45	14D
0005432044557	2114	46	14B
0005433924523	2114	47	14E
0005433924500	2114	48	14G
0005433924453	2114	49	14F
0005433924463	2114	50	15A
0005433924490	2114	51	15B
0005433036584	2114	52	15D
0005433924511	2114	53	15F
0005433036354	2114	54	15H
0005433036540	2114	55	15G
0005433036450	2114	56	16A
0005433036565	2114	57	16D
0005433924464	2114	58	16B
0005432231700	2114	59	16E
0005433924492	2114	60	16F
0005433036608	2114	61	16G
0005433036432	2114	62	17A
0005433036086	2114	63	17D
0005433924434	2114	64	17B
0005433929664	2114	65	17E
0005433036531	2114	66	18A
0005433924478	2114	67	18D
0005433924445	2114	68	18F
0005433036475	2114	69	18E
0005433924510	2114	70	18G
0005433036800	2114	71	19D
0005433036412	2114	72	19F
0005433036568	2114	73	19H
0005433924482	2114	74	19G
0005433036482	2114	75	20A
0005433924503	2114	76	20B
0005433924451	2114	77	20F
0005433924505	2114	78	20G
0005433036474	2114	79	21A
0005433924477	2114	80	20H
0005433924442	2114	81	21B
0005433929662	2114	82	21E
0005433036539	2114	83	21H
0005433036614	2114	84	21G
0005433924522	2114	85	22A
0005433924476	2114	86	22B
0005432231692	2114	87	22H
0005433924508	2114	88	23D
0005433931506	2114	89	23F
0005433924441	2114	90	23E
0005433036629	2114	91	23G
0005433036602	2114	92	24A
0005433924485	2114	93	23H
0005432231691	2114	94	24B
0005432231697	2114	95	24D
0005433924483	2114	96	24F
0005433924468	2114	97	24E
0005433924459	2114	98	24H
0005433036616	2114	99	24G
0005433924439	2114	100	25E
0005433924436	2114	101	25D
0005433924454	2114	102	27A
0005433924519	2114	103	25F
0005433924466	2114	104	27B
0005433924455	2114	105	27E
0005433924507	2114	106	27F
0005433924525	2114	107	27G
0005433036458	2114	108	28A
0005433036669	2114	109	27H
0005433924470	2114	110	28B
0005433924473	2114	111	28D
0005433924515	2114	112	28F
0005433924529	2114	113	28E
0005433036337	2114	114	29A
0005433924506	2114	115	28H
0005433924520	2114	116	29D
0005433929663	2114	117	29B
0005433924479	2114	118	29G
0005433924532	2114	119	29F
0005432231699	2114	120	29H
0005433924499	2114	121	30A
0005433036564	2114	122	30D
0005433924531	2114	123	30B
0005433924446	2114	124	30E
0005433924467	2114	125	30G
0005433924509	2114	126	31A
0005433036566	2114	127	30H
0005433924513	2114	128	31B
0005433924447	2114	129	31E
0005433036433	2114	130	31F
0005433924438	2114	131	31H
0005433036494	2114	132	32A
0005432231695	2114	133	32B
0005433036454	2114	134	32D
0005432749789	2114	135	32F
0005433036666	2114	136	32H
0005433924469	2114	137	32G
0005433036603	2114	138	33A
0005433929665	2114	139	33D
0005433924491	2114	140	33B
0005433036516	2114	141	33E
0005433924457	2114	142	33G
0005433924496	2114	143	33H
0005433036535	2114	144	34D
0005433924460	2114	145	34F
0005433924437	2114	146	34E
0005433924484	2114	147	34G
0005433924465	2114	148	34H
0005433924448	2114	149	35E
0005433924452	2114	150	35D
0005433924527	2114	151	35B
0005433924502	2114	152	35G
0005433924443	2114	153	35H
0005433924474	2114	154	36B
0005433924444	2114	155	36A
0005433924524	2114	156	36F
0005433924440	2114	157	36G
0005433924526	2114	158	37B
0005432231696	2114	159	37D
0005433924471	2114	160	37F
0005433924488	2114	161	37H
0005433036615	2114	162	38A
0005432231698	2114	163	38B
0005433036411	2114	164	38E
0005433924462	2114	165	38F
0005433036307	2114	166	38H
0005433036340	2114	167	39E
0005433036353	2114	168	39D
0005433924493	2114	169	39F
0005433875384	24095	1	1A
0005433923611	24095	2	1B
0005433923563	24095	3	1F
0005433036950	24095	4	1G
0005433036955	24095	5	1H
0005433923858	24095	6	2C
0005434028336	24095	7	2B
0005433036953	24095	8	2G
0005433923785	24095	9	2F
0005433923767	24095	10	3A
0005433924227	24095	11	2H
0005433036925	24095	12	3F
0005433036969	24095	13	3G
0005433923745	24095	14	4A
0005433923905	24095	15	4B
0005432749812	24095	16	4C
0005433923353	24095	17	4G
0005433923972	24095	18	4H
0005433923912	24095	19	5B
0005433923194	24095	20	5A
0005433036931	24095	21	5C
0005433923671	24095	22	5G
0005433923538	24095	23	5F
0005433923656	24095	24	5H
0005433923921	24095	25	9B
0005433923424	24095	26	9A
0005433923482	24095	27	9G
0005433923924	24095	28	9H
0005433036923	24095	29	11D
0005433036924	24095	30	11B
0005433923648	24095	31	11E
0005432206267	24095	32	11H
0005433036933	24095	33	11G
0005433923647	24095	34	12A
0005432206268	24095	35	12D
0005433923215	24095	36	12B
0005433036974	24095	37	12E
0005433923859	24095	38	12G
0005433923529	24095	39	12F
0005433923742	24095	40	12H
0005433036971	24095	41	13A
0005433036973	24095	42	13D
0005433923916	24095	43	13E
0005433875382	24095	44	13G
0005433923438	24095	45	13F
0005433923703	24095	46	14A
0005432207694	24095	47	13H
0005433923582	24095	48	14B
0005433036946	24095	49	14E
0005433036941	24095	50	14D
0005433923593	24095	51	14F
0005433036937	24095	52	14H
0005433923361	24095	53	14G
0005433036957	24095	54	15A
0005433923700	24095	55	15D
0005433923559	24095	56	15F
0005433036956	24095	57	15H
0005433923497	24095	58	15G
0005433924045	24095	59	16A
0005433036939	24095	60	16B
0005432749811	24095	61	16E
0005433036922	24095	62	16D
0005433923646	24095	63	16G
0005433924044	24095	64	16F
0005433036961	24095	65	16H
0005433923811	24095	66	17A
0005433875383	24095	67	17D
0005433923813	24095	68	17B
0005433875380	24095	69	17E
0005433923812	24095	70	17G
0005433036962	24095	71	17H
0005433036926	24095	72	18A
0005433036967	24095	73	18D
0005433923136	24095	74	18E
0005433923709	24095	75	18G
0005433923413	24095	76	18H
0005433036945	24095	77	19B
0005433036970	24095	78	19A
0005433923539	24095	79	19E
0005432206269	24095	80	19D
0005433923762	24095	81	19F
0005433036952	24095	82	19H
0005433036932	24095	83	19G
0005433923943	24095	84	20A
0005433923860	24095	85	20D
0005433036951	24095	86	20E
0005433923682	24095	87	20F
0005433923882	24095	88	20H
0005433036934	24095	89	20G
0005434028334	24095	90	21A
0005433036954	24095	91	21D
0005433036963	24095	92	21B
0005434028335	24095	93	21E
0005433923612	24095	94	21H
0005433923681	24095	95	21G
0005433924264	24095	96	22A
0005433923504	24095	97	22B
0005433036958	24095	98	22F
0005433923423	24095	99	22E
0005433036965	24095	100	22G
0005433875379	24095	101	23A
0005433923722	24095	102	22H
0005433923030	24095	103	23B
0005433923633	24095	104	23D
0005433923610	24095	105	23F
0005433036944	24095	106	23E
0005433923702	24095	107	23G
0005433923874	24095	108	24B
0005433923902	24095	109	24A
0005433923784	24095	110	24D
0005433036938	24095	111	24F
0005433036975	24095	112	25D
0005433923817	24095	113	25E
0005433923738	24095	114	27A
0005433036928	24095	115	25F
0005433923749	24095	116	27B
0005433036960	24095	117	27D
0005433036940	24095	118	27F
0005433036935	24095	119	27E
0005433923216	24095	120	27H
0005433923806	24095	121	27G
0005433036966	24095	122	28A
0005433923572	24095	123	28D
0005433036942	24095	124	28B
0005433923973	24095	125	28E
0005433923894	24095	126	28F
0005433923701	24095	127	28H
0005433923927	24095	128	28G
0005433923718	24095	129	29B
0005433924265	24095	130	29A
0005433923347	24095	131	29D
0005433923920	24095	132	29E
0005433036947	24095	133	29G
0005433923926	24095	134	29F
0005433036930	24095	135	29H
0005433923360	24095	136	30B
0005432207693	24095	137	30A
0005433929630	24095	138	30D
0005433923699	24095	139	30F
0005433923527	24095	140	30E
0005433923733	24095	141	30G
0005433875387	24095	142	31A
0005433923422	24095	143	30H
0005432749813	24095	144	31B
0005434028333	24095	145	31E
0005432206270	24095	146	31H
0005433923824	24095	147	31G
0005433036964	24095	148	32A
0005433875378	24095	149	32B
0005433036949	24095	150	32E
0005433923437	24095	151	32D
0005433923641	24095	152	32F
0005433036936	24095	153	32H
0005433036948	24095	154	32G
0005433923496	24095	155	33A
0005433036927	24095	156	33B
0005433923698	24095	157	33E
0005434028337	24095	158	33D
0005433923713	24095	159	33G
0005433923537	24095	160	33F
0005433923526	24095	161	33H
0005433923925	24095	162	34B
0005433923154	24095	163	34A
0005433923794	24095	164	34D
0005433923756	24095	165	34E
0005433923510	24095	166	34G
0005433923670	24095	167	34F
0005433923556	24095	168	34H
0005433924080	24095	169	35D
0005433036972	24095	170	35F
0005433923719	24095	171	35E
0005433923278	24095	172	35H
0005433036943	24095	173	36B
0005432749814	24095	174	36A
0005433036968	24095	175	36F
0005433923187	24095	176	36E
0005433923513	24095	177	36G
0005433923498	24095	178	37A
0005433923201	24095	179	36H
0005433923412	24095	180	37B
0005433923153	24095	181	37D
0005433923457	24095	182	37F
0005433923922	24095	183	37E
0005433924133	24095	184	37H
0005433036959	24095	185	37G
0005433923508	24095	186	38A
0005433923729	24095	187	38D
0005433923485	24095	188	38E
0005433923509	24095	189	38G
0005433036929	24095	190	38H
0005433923411	24095	191	39D
0005433923901	24095	192	39F
0005433875381	24095	193	39E
0005434726950	297	1	1D
0005432277977	297	2	1C
0005434726977	297	3	1A
0005435142745	297	4	1K
0005433181176	297	5	1H
0005434727011	297	6	2C
0005434726916	297	7	2A
0005434726924	297	8	2G
0005432277971	297	9	3A
0005434551884	297	10	2K
0005433181266	297	11	3G
0005434551892	297	12	3C
0005434726998	297	13	3H
0005433126869	297	14	4C
0005433181186	297	15	4A
0005433181171	297	16	4G
0005434551926	297	17	4D
0005434726933	297	18	5A
0005433234618	297	19	4H
0005433234493	297	20	5D
0005434726963	297	21	5C
0005433234134	297	22	5H
0005434735750	297	23	5G
0005434726910	297	24	11A
0005433289846	297	25	5K
0005433766644	297	26	11D
0005434551935	297	27	11F
0005433234133	297	28	11E
0005433234292	297	29	11H
0005433234015	297	30	11G
0005433234078	297	31	12C
0005433181145	297	32	12A
0005433234143	297	33	11K
0005433131728	297	34	12E
0005434726913	297	35	12D
0005433234491	297	36	13A
0005434551894	297	37	12K
0005434726986	297	38	12H
0005434551927	297	39	13D
0005433234293	297	40	13C
0005434727016	297	41	13K
0005432277970	297	42	13H
0005434726989	297	43	13G
0005433766643	297	44	14A
0005434551936	297	45	14D
0005434551888	297	46	14G
0005434726953	297	47	14F
0005434551885	297	48	14E
0005433126870	297	49	14K
0005434551887	297	50	14H
0005433234519	297	51	15C
0005434726956	297	52	15F
0005433234386	297	53	15E
0005435142741	297	54	15D
0005433234249	297	55	15H
0005433234289	297	56	15K
0005433234182	297	57	16D
0005433234482	297	58	16C
0005433234487	297	59	16A
0005433289853	297	60	16F
0005434726978	297	61	16H
0005434551918	297	62	16G
0005433234278	297	63	16K
0005434551922	297	64	17E
0005433234236	297	65	17D
0005434727001	297	66	17C
0005434726948	297	67	17G
0005434726917	297	68	17F
0005434302512	297	69	17H
0005433181121	297	70	18B
0005434726961	297	71	18A
0005434726994	297	72	18E
0005434551900	297	73	18D
0005434551904	297	74	18C
0005434731218	297	75	18H
0005434727002	297	76	18F
0005433234430	297	77	18K
0005434726926	297	78	18J
0005434551902	297	79	19A
0005434726968	297	80	19C
0005434551881	297	81	19B
0005434551893	297	82	19F
0005434727022	297	83	19E
0005434726984	297	84	19G
0005433181125	297	85	20A
0005435142748	297	86	19K
0005434726960	297	87	19J
0005435142739	297	88	20C
0005434726982	297	89	20B
0005434731220	297	90	20E
0005433234593	297	91	20D
0005434551923	297	92	20G
0005434726967	297	93	20F
0005434726936	297	94	20J
0005434551915	297	95	20H
0005435142742	297	96	21B
0005433234439	297	97	21A
0005434551899	297	98	20K
0005434551930	297	99	21D
0005435142750	297	100	21C
0005433289861	297	101	21F
0005434726932	297	102	21J
0005434727015	297	103	21H
0005434727006	297	104	21G
0005433181166	297	105	22A
0005433234325	297	106	22B
0005434551882	297	107	22E
0005434302513	297	108	22G
0005433131734	297	109	22K
0005434726921	297	110	22J
0005433181177	297	111	22H
0005433234526	297	112	23B
0005434726944	297	113	23A
0005434032015	297	114	23D
0005432277978	297	115	23C
0005433181267	297	116	23E
0005434731221	297	117	23J
0005433181107	297	118	23H
0005433181243	297	119	24D
0005434727003	297	120	24F
0005434726975	297	121	24E
0005433234290	297	122	25B
0005434551911	297	123	25A
0005433234512	297	124	24G
0005434551916	297	125	25D
0005432277981	297	126	25C
0005433131744	297	127	25F
0005434726970	297	128	25E
0005434551934	297	129	25G
0005434551925	297	130	26A
0005433181265	297	131	25K
0005434727021	297	132	25J
0005435142744	297	133	26B
0005434726991	297	134	26E
0005433234279	297	135	26D
0005434551933	297	136	26G
0005435142747	297	137	26F
0005434551895	297	138	26H
0005434551929	297	139	27D
0005434551928	297	140	27C
0005432277974	297	141	27B
0005434726995	297	142	27J
0005432277976	297	143	27H
0005434551920	297	144	27G
0005433234069	297	145	27F
0005434726974	297	146	27K
0005433234398	297	147	28B
0005434726954	297	148	28E
0005434551905	297	149	28D
0005434727009	297	150	28G
0005434726923	297	151	28F
0005434302514	297	152	28J
0005434551906	297	153	29D
0005434726925	297	154	29C
0005433181126	297	155	29B
0005433181239	297	156	29F
0005432277973	297	157	29H
0005434727019	297	158	29G
0005433234451	297	159	30A
0005432277972	297	160	29K
0005433234397	297	161	29J
0005434726911	297	162	30B
0005433234518	297	163	30D
0005432277980	297	164	30C
0005434726929	297	165	30G
0005434727017	297	166	30F
0005433234468	297	167	30J
0005434551896	297	168	30H
0005434302515	297	169	31A
0005433234515	297	170	30K
0005434727004	297	171	31D
0005434727018	297	172	31F
0005434726918	297	173	31H
0005434726941	297	174	31G
0005434726908	297	175	32A
0005433234495	297	176	31K
0005434727025	297	177	31J
0005433234310	297	178	32C
0005433234531	297	179	32B
0005434551908	297	180	32E
0005434726945	297	181	32D
0005434551921	297	182	32G
0005433126860	297	183	32F
0005433234452	297	184	32K
0005434727000	297	185	32J
0005434551901	297	186	32H
0005434726981	297	187	33A
0005434726907	297	188	33D
0005434726955	297	189	33C
0005433181108	297	190	33G
0005434551886	297	191	33E
0005433289892	297	192	33J
0005434726942	297	193	33H
0005434726928	297	194	34B
0005434735751	297	195	34A
0005434551913	297	196	34E
0005433181232	297	197	34D
0005434551883	297	198	34G
0005434726920	297	199	34F
0005434726996	297	200	34J
0005433181165	297	201	34H
0005434551912	297	202	35B
0005433234248	297	203	35A
0005434551909	297	204	35D
0005434726988	297	205	35C
0005434726909	297	206	35F
0005433234181	297	207	35E
0005434726934	297	208	35J
0005432277975	297	209	35H
0005433234514	297	210	35G
0005434551897	297	211	36A
0005434551919	297	212	35K
0005434726965	297	213	36C
0005434726971	297	214	36B
0005434726976	297	215	36E
0005434726951	297	216	36D
0005434727026	297	217	36H
0005433181088	297	218	36G
0005433234431	297	219	36K
0005433234447	297	220	37B
0005434551891	297	221	37A
0005434726915	297	222	37D
0005434726962	297	223	37C
0005433181211	297	224	37F
0005434726993	297	225	37E
0005433181238	297	226	37H
0005434727024	297	227	38A
0005433234480	297	228	37K
0005433289864	297	229	38C
0005433234513	297	230	38B
0005434727013	297	231	38H
0005434731219	297	232	39B
0005433234332	297	233	39A
0005433234400	297	234	39D
0005433234424	297	235	39C
0005434726979	297	236	39F
0005434726949	297	237	39E
0005433181231	297	238	39H
0005435142749	297	239	39G
0005434551924	297	240	39K
0005433234652	297	241	39J
0005434726987	297	242	40C
0005433181212	297	243	40E
0005433234016	297	244	40D
0005434735748	297	245	40H
0005434726999	297	246	40G
0005434726992	297	247	40F
0005433131727	297	248	41B
0005433234423	297	249	41A
0005434726930	297	250	40K
0005432277968	297	251	41C
0005434726947	297	252	41F
0005434727010	297	253	41J
0005434551890	297	254	41H
0005434726940	297	255	42A
0005434726943	297	256	41K
0005434726914	297	257	42C
0005433234309	297	258	42B
0005434726958	297	259	42E
0005433234314	297	260	42D
0005434551931	297	261	42G
0005434726912	297	262	42F
0005434726959	297	263	42K
0005433234481	297	264	42J
0005434726927	297	265	42H
0005434726957	297	266	43A
0005434551932	297	267	43D
0005434727012	297	268	43C
0005434726931	297	269	43B
0005434726952	297	270	43F
0005434551917	297	271	43E
0005434726969	297	272	43H
0005434726964	297	273	43G
0005434726990	297	274	43K
0005433181175	297	275	43J
0005433181235	297	276	44C
0005434551914	297	277	44A
0005434551898	297	278	44E
0005433234222	297	279	44G
0005434726973	297	280	44J
0005434551910	297	281	45B
0005433234425	297	282	45A
0005433234132	297	283	44K
0005434726966	297	284	45D
0005434551903	297	285	45C
0005433234186	297	286	45G
0005433111511	297	287	45F
0005434727007	297	288	45E
0005434726983	297	289	45H
0005434727023	297	290	45K
0005432277979	297	291	46B
0005433234418	297	292	46A
0005435142738	297	293	46E
0005434727014	297	294	46D
0005434735749	297	295	46C
0005432277969	297	296	46H
0005434727027	297	297	46G
0005434551889	297	298	46F
0005434726938	297	299	46J
0005434726935	297	300	47C
0005435142746	297	301	47A
0005433234142	297	302	46K
0005434551907	297	303	47E
0005434727005	297	304	47D
0005433234286	297	305	47G
0005434726972	297	306	47F
0005433234376	297	307	47K
0005433234383	297	308	47H
0005433126855	297	309	48C
0005434726919	297	310	48A
0005434726946	297	311	48F
0005434727008	297	312	48D
0005434726939	297	313	48H
0005434727028	297	314	48G
0005434726937	297	315	49A
0005434726985	297	316	48K
0005433234291	297	317	49D
0005433234446	297	318	49C
0005433234419	297	319	49G
0005433234221	297	320	49F
0005433234328	297	321	49E
0005433181255	297	322	49K
0005434727020	297	323	49H
0005435142743	297	324	50C
0005434726980	297	325	50A
0005433181242	297	326	50E
0005435142740	297	327	50G
0005433289860	297	328	50F
0005434726997	297	329	51D
0005434726922	297	330	50K
0005433234339	297	331	50H
0005433111505	297	332	51F
0005433181258	297	333	51E
0005434726253	9835	1	1C
0005433234998	9835	2	1A
0005434551590	9835	3	1G
0005433181421	9835	4	1D
0005434726093	9835	5	2A
0005434725941	9835	6	1K
0005433235003	9835	7	2D
0005433234951	9835	8	2C
0005434725801	9835	9	3A
0005434551314	9835	10	3D
0005434551362	9835	11	3H
0005434032081	9835	12	3G
0005434726410	9835	13	4A
0005434551501	9835	14	3K
0005433235008	9835	15	4G
0005434551176	9835	16	4D
0005433234973	9835	17	5A
0005433181401	9835	18	4H
0005435142611	9835	19	5D
0005434725471	9835	20	5C
0005434551225	9835	21	5G
0005433235000	9835	22	11A
0005433181407	9835	23	5K
0005433181408	9835	24	11C
0005434725912	9835	25	11F
0005432199332	9835	26	11E
0005434725472	9835	27	11K
0005434551444	9835	28	11H
0005433234999	9835	29	12C
0005433234983	9835	30	12A
0005433235009	9835	31	12E
0005433181419	9835	32	12D
0005434726105	9835	33	12G
0005434551610	9835	34	12F
0005433289937	9835	35	12H
0005432199336	9835	36	13D
0005433289934	9835	37	13C
0005434551535	9835	38	13A
0005433234962	9835	39	13F
0005433234977	9835	40	13E
0005434725688	9835	41	14C
0005433289936	9835	42	14A
0005434726038	9835	43	14D
0005433126900	9835	44	14G
0005434551269	9835	45	14K
0005434725662	9835	46	14H
0005433181406	9835	47	15C
0005434725691	9835	48	15A
0005435142647	9835	49	15F
0005434726333	9835	50	15E
0005433181415	9835	51	15D
0005433129330	9835	52	15G
0005434726332	9835	53	16A
0005433289935	9835	54	15K
0005434726176	9835	55	15H
0005434302459	9835	56	16D
0005434551291	9835	57	16F
0005434725803	9835	58	16E
0005433234992	9835	59	16K
0005434726249	9835	60	16H
0005434726605	9835	61	16G
0005433129331	9835	62	17C
0005433234991	9835	63	17A
0005434551587	9835	64	17E
0005434726148	9835	65	17D
0005434725556	9835	66	17G
0005434551534	9835	67	17F
0005434551425	9835	68	18A
0005434725670	9835	69	17K
0005434731184	9835	70	17H
0005433234954	9835	71	18C
0005433234949	9835	72	18B
0005433234978	9835	73	18E
0005434725929	9835	74	18D
0005433234997	9835	75	18G
0005433235010	9835	76	18F
0005433129334	9835	77	18K
0005434725686	9835	78	18H
0005434726336	9835	79	19B
0005433234969	9835	80	19A
0005434725964	9835	81	19D
0005434725545	9835	82	19C
0005434726185	9835	83	19F
0005434551295	9835	84	19E
0005434551302	9835	85	19J
0005434725987	9835	86	19H
0005432199334	9835	87	19G
0005434551379	9835	88	19K
0005434726067	9835	89	20C
0005434726339	9835	90	20B
0005434725966	9835	91	20A
0005434725883	9835	92	20E
0005434731166	9835	93	20D
0005434725949	9835	94	20H
0005434551487	9835	95	20G
0005434726014	9835	96	20F
0005434726418	9835	97	20K
0005434725983	9835	98	21A
0005433181399	9835	99	21D
0005433235012	9835	100	21C
0005435142648	9835	101	21F
0005434551520	9835	102	21E
0005434725907	9835	103	21K
0005434302463	9835	104	21J
0005434731187	9835	105	22D
0005434551363	9835	106	22C
0005433234956	9835	107	22B
0005433234952	9835	108	22E
0005434551396	9835	109	22H
0005434726196	9835	110	22G
0005434725814	9835	111	22K
0005434551183	9835	112	22J
0005434725675	9835	113	23B
0005434551403	9835	114	23A
0005434726334	9835	115	23D
0005433234960	9835	116	23C
0005434726087	9835	117	23G
0005434551552	9835	118	23F
0005434725321	9835	119	23E
0005434551350	9835	120	23H
0005434551422	9835	121	24D
0005433234982	9835	122	23K
0005434551237	9835	123	23J
0005433235011	9835	124	24F
0005433181416	9835	125	24E
0005433234984	9835	126	25B
0005433234985	9835	127	25A
0005434551399	9835	128	25D
0005433181403	9835	129	25C
0005434726147	9835	130	25F
0005434725940	9835	131	25E
0005433181417	9835	132	25H
0005433766688	9835	133	25G
0005434551102	9835	134	25K
0005433181422	9835	135	25J
0005434725939	9835	136	26C
0005432199338	9835	137	26B
0005434725996	9835	138	26A
0005434725948	9835	139	26D
0005434726335	9835	140	26G
0005434725749	9835	141	26K
0005433129332	9835	142	26J
0005434551500	9835	143	26H
0005434726338	9835	144	27B
0005433234968	9835	145	27A
0005434725985	9835	146	27D
0005434551301	9835	147	27F
0005433235002	9835	148	27E
0005433234976	9835	149	27H
0005434551212	9835	150	27G
0005434725635	9835	151	27K
0005434551445	9835	152	27J
0005434551224	9835	153	28B
0005434551538	9835	154	28A
0005433234955	9835	155	28D
0005435142523	9835	156	28C
0005433234966	9835	157	28F
0005433235005	9835	158	28E
0005434726094	9835	159	28K
0005434731188	9835	160	28J
0005434725756	9835	161	28H
0005433113563	9835	162	29B
0005434726036	9835	163	29A
0005434032080	9835	164	29D
0005433126899	9835	165	29C
0005433234995	9835	166	29F
0005433234958	9835	167	29E
0005433234950	9835	168	29J
0005433234963	9835	169	29G
0005433234980	9835	170	30C
0005434726068	9835	171	30B
0005434725908	9835	172	30A
0005433234994	9835	173	30D
0005434726417	9835	174	30G
0005434551421	9835	175	30F
0005433181414	9835	176	30E
0005434551159	9835	177	30H
0005433181410	9835	178	31A
0005434725676	9835	179	30K
0005433289932	9835	180	31D
0005434725877	9835	181	31B
0005434726411	9835	182	31F
0005433181424	9835	183	31E
0005434725475	9835	184	31J
0005434551481	9835	185	31H
0005434731206	9835	186	31G
0005433234986	9835	187	31K
0005434725928	9835	188	32B
0005434551383	9835	189	32A
0005434551347	9835	190	32E
0005432199331	9835	191	32D
0005433234979	9835	192	32C
0005434725322	9835	193	32G
0005434725977	9835	194	32F
0005434726210	9835	195	32J
0005433766689	9835	196	32H
0005434551215	9835	197	33A
0005434726306	9835	198	32K
0005433766686	9835	199	33D
0005433181404	9835	200	33C
0005434032083	9835	201	33F
0005434725984	9835	202	33E
0005434551434	9835	203	33H
0005434725899	9835	204	33G
0005434551416	9835	205	33K
0005434725592	9835	206	34D
0005433234959	9835	207	34C
0005434725800	9835	208	34G
0005433234970	9835	209	34F
0005434551387	9835	210	34J
0005434725769	9835	211	34H
0005434551289	9835	212	35B
0005433234990	9835	213	34K
0005434735717	9835	214	35E
0005434725320	9835	215	35D
0005433234948	9835	216	35C
0005434551378	9835	217	35F
0005434726174	9835	218	35J
0005434032082	9835	219	35H
0005434725729	9835	220	35G
0005434726353	9835	221	36A
0005434725713	9835	222	35K
0005434551309	9835	223	36C
0005434551446	9835	224	36B
0005434725815	9835	225	36F
0005433234975	9835	226	36E
0005434551329	9835	227	36D
0005434725416	9835	228	36K
0005433181418	9835	229	36J
0005434726049	9835	230	36H
0005434725599	9835	231	37B
0005434551198	9835	232	37A
0005434725900	9835	233	37D
0005434725776	9835	234	37G
0005433234965	9835	235	37F
0005434726066	9835	236	37E
0005433181412	9835	237	38A
0005434725994	9835	238	37K
0005433234953	9835	239	38C
0005434726069	9835	240	38B
0005434725687	9835	241	38J
0005434302460	9835	242	38H
0005433235004	9835	243	39B
0005434551376	9835	244	39A
0005434725389	9835	245	38K
0005434726154	9835	246	39D
0005434726043	9835	247	39F
0005434551394	9835	248	39E
0005434726268	9835	249	39H
0005433234964	9835	250	39G
0005433129333	9835	251	40A
0005434551488	9835	252	39K
0005434551351	9835	253	39J
0005434725607	9835	254	40C
0005435142574	9835	255	40B
0005434731186	9835	256	40E
0005434551524	9835	257	40D
0005434551290	9835	258	40G
0005434551340	9835	259	40F
0005433234967	9835	260	40K
0005434551346	9835	261	41B
0005433126901	9835	262	41D
0005434725669	9835	263	41C
0005434725852	9835	264	41F
0005434725565	9835	265	41H
0005433181405	9835	266	41K
0005433181409	9835	267	41J
0005434726130	9835	268	42C
0005434551233	9835	269	42B
0005434726164	9835	270	42E
0005433234972	9835	271	42D
0005434725753	9835	272	42F
0005434551432	9835	273	42K
0005433181413	9835	274	42J
0005433181402	9835	275	42H
0005434725634	9835	276	43A
0005433234971	9835	277	43C
0005433235001	9835	278	43B
0005434725702	9835	279	43F
0005434726165	9835	280	43E
0005434725525	9835	281	43D
0005433234974	9835	282	43H
0005434302474	9835	283	43G
0005434725850	9835	284	43K
0005434725911	9835	285	43J
0005433234989	9835	286	44C
0005433181423	9835	287	44B
0005433181400	9835	288	44A
0005433235013	9835	289	44E
0005433181420	9835	290	44D
0005433234988	9835	291	44G
0005433289938	9835	292	44F
0005432199330	9835	293	44K
0005434551238	9835	294	44J
0005433234987	9835	295	44H
0005434725689	9835	296	45B
0005434551216	9835	297	45A
0005433181411	9835	298	45D
0005433234993	9835	299	45C
0005434726219	9835	300	45F
0005434725730	9835	301	45E
0005434725526	9835	302	45H
0005434726039	9835	303	45G
0005433235007	9835	304	45K
0005434551325	9835	305	45J
0005434725764	9835	306	46C
0005434551443	9835	307	46B
0005434725851	9835	308	46A
0005434726037	9835	309	46E
0005434726167	9835	310	46D
0005434551341	9835	311	46F
0005434726050	9835	312	46J
0005433234957	9835	313	46H
0005434551367	9835	314	47C
0005434551395	9835	315	47A
0005434551433	9835	316	46K
0005433234961	9835	317	47E
0005434551388	9835	318	47D
0005434725728	9835	319	47G
0005434551401	9835	320	47F
0005432199335	9835	321	47K
0005434726155	9835	322	48D
0005433289933	9835	323	48A
0005435142583	9835	324	48F
0005434551324	9835	325	48E
0005433766687	9835	326	48H
0005434726145	9835	327	48G
0005433235006	9835	328	49A
0005434551226	9835	329	49C
0005434725663	9835	330	49F
0005433126902	9835	331	49E
0005434551467	9835	332	49H
0005434725628	9835	333	49G
0005434551368	9835	334	50C
0005432199337	9835	335	50A
0005434726606	9835	336	50E
0005435142639	9835	337	50D
0005433234981	9835	338	50F
0005434726187	9835	339	51D
0005433234996	9835	340	50K
0005434551328	9835	341	50H
0005434726209	9835	342	51F
0005434726175	9835	343	51E
0005432199333	9835	344	51G
0005435213829	7721	1	46K
0005432529566	7721	2	1C
0005432529582	7721	3	1A
0005433656674	7721	4	1G
0005432428971	7721	5	1D
0005432529565	7721	6	1K
0005432428970	7721	7	1H
0005434068428	7721	8	2C
0005434068469	7721	9	2A
0005435213733	7721	10	2H
0005432069835	7721	11	2G
0005432428972	7721	12	2D
0005432529605	7721	13	2K
0005432529555	7721	14	3C
0005432529626	7721	15	3K
0005432529601	7721	16	3H
0005434068468	7721	17	3G
0005432529628	7721	18	4C
0005432529558	7721	19	4A
0005432529652	7721	20	4G
0005434068465	7721	21	4D
0005434068439	7721	22	4K
0005435213873	7721	23	4H
0005435213906	7721	24	5D
0005432529578	7721	25	5C
0005434068464	7721	26	5H
0005432529627	7721	27	5G
0005434068404	7721	28	11A
0005434068455	7721	29	5K
0005434068415	7721	30	11D
0005432529552	7721	31	11C
0005435214058	7721	32	11F
0005434068426	7721	33	11E
0005434068472	7721	34	11K
0005432069829	7721	35	11H
0005434068416	7721	36	11G
0005432150293	7721	37	12A
0005434068442	7721	38	12E
0005434068471	7721	39	12D
0005432529567	7721	40	12G
0005432529617	7721	41	12F
0005432529594	7721	42	12K
0005432069827	7721	43	12H
0005435213839	7721	44	13D
0005432069828	7721	45	13C
0005432529614	7721	46	13A
0005432150292	7721	47	13F
0005432069830	7721	48	13E
0005432529624	7721	49	13H
0005432529550	7721	50	13G
0005434068424	7721	51	14C
0005434068445	7721	52	14A
0005435213866	7721	53	14E
0005432529562	7721	54	14G
0005434068441	7721	55	14F
0005432529584	7721	56	14K
0005434068407	7721	57	14H
0005432529597	7721	58	15C
0005434068431	7721	59	15A
0005435725605	7721	60	15E
0005432069836	7721	61	15D
0005432150289	7721	62	15F
0005432529543	7721	63	16A
0005432529586	7721	64	15K
0005435213749	7721	65	16D
0005432529575	7721	66	16C
0005435213731	7721	67	16F
0005432533328	7721	68	16E
0005432529603	7721	69	16K
0005432529658	7721	70	16G
0005432529641	7721	71	17C
0005432069838	7721	72	17E
0005432529654	7721	73	17D
0005432529657	7721	74	17G
0005432150288	7721	75	17F
0005432529526	7721	76	17K
0005435213730	7721	77	17H
0005434068420	7721	78	18B
0005435213719	7721	79	18A
0005432529539	7721	80	18E
0005432529608	7721	81	18D
0005432529647	7721	82	18H
0005432529588	7721	83	18G
0005432529571	7721	84	18F
0005432529561	7721	85	18K
0005432529634	7721	86	18J
0005432529649	7721	87	19A
0005435214057	7721	88	19D
0005435213922	7721	89	19C
0005434068437	7721	90	19B
0005432529615	7721	91	19F
0005435213898	7721	92	19E
0005432069839	7721	93	19H
0005432535891	7721	94	20A
0005432529609	7721	95	19K
0005432529556	7721	96	19J
0005432529613	7721	97	20C
0005435213755	7721	98	20B
0005435630963	7721	99	20E
0005434068447	7721	100	20D
0005432529528	7721	101	20G
0005434068421	7721	102	20F
0005435213732	7721	103	20H
0005432529653	7721	104	21A
0005432529630	7721	105	20K
0005434068425	7721	106	21D
0005432529625	7721	107	21C
0005432529542	7721	108	21F
0005434068461	7721	109	21E
0005435213700	7721	110	21H
0005435213729	7721	111	21G
0005432529635	7721	112	22A
0005434068405	7721	113	21K
0005435213721	7721	114	22C
0005432529560	7721	115	22F
0005432529534	7721	116	22E
0005435213825	7721	117	22D
0005434068444	7721	118	22H
0005434068411	7721	119	22K
0005432529532	7721	120	22J
0005432529590	7721	121	23B
0005432428969	7721	122	23A
0005434068438	7721	123	23C
0005432529593	7721	124	23H
0005432529537	7721	125	24D
0005435213891	7721	126	23K
0005434068470	7721	127	24G
0005432529533	7721	128	24F
0005432529549	7721	129	25B
0005435213923	7721	130	25C
0005435213720	7721	131	25F
0005432529557	7721	132	25E
0005432529599	7721	133	25J
0005432533327	7721	134	25H
0005434068459	7721	135	25G
0005434068436	7721	136	25K
0005434068451	7721	137	26C
0005434068450	7721	138	26A
0005432529638	7721	139	26E
0005432529546	7721	140	26G
0005434068435	7721	141	26F
0005432529621	7721	142	26J
0005435213766	7721	143	26H
0005432069833	7721	144	26K
0005432529529	7721	145	27C
0005432529536	7721	146	27B
0005435213652	7721	147	27F
0005432069834	7721	148	27E
0005432529607	7721	149	27G
0005434068423	7721	150	27K
0005435213752	7721	151	27J
0005434068410	7721	152	28B
0005435213715	7721	153	28C
0005432529587	7721	154	28F
0005432529618	7721	155	28H
0005434068457	7721	156	29D
0005432529591	7721	157	29C
0005432150291	7721	158	29F
0005435213518	7721	159	29E
0005435213471	7721	160	29K
0005432529540	7721	161	30C
0005434068406	7721	162	30B
0005432529632	7721	163	30A
0005435213742	7721	164	30E
0005432529585	7721	165	30D
0005432529619	7721	166	30G
0005434068458	7721	167	30F
0005432529541	7721	168	30H
0005432529583	7721	169	31B
0005434068454	7721	170	31A
0005435214019	7721	171	30K
0005435214002	7721	172	31D
0005432529642	7721	173	31C
0005434068402	7721	174	31F
0005432529646	7721	175	31E
0005432529589	7721	176	31H
0005435213917	7721	177	31G
0005432069832	7721	178	31K
0005432529633	7721	179	31J
0005434068462	7721	180	32B
0005432529622	7721	181	32A
0005434068414	7721	182	32E
0005434068440	7721	183	32D
0005434068446	7721	184	32G
0005432529569	7721	185	32F
0005434068422	7721	186	32J
0005432529656	7721	187	32H
0005432069837	7721	188	33A
0005435213816	7721	189	32K
0005432529576	7721	190	33D
0005434068433	7721	191	33C
0005432529577	7721	192	33F
0005435213645	7721	193	33E
0005432529644	7721	194	33H
0005432529637	7721	195	33G
0005435213633	7721	196	34A
0005435213919	7721	197	33K
0005435213805	7721	198	34B
0005435213960	7721	199	34E
0005435630964	7721	200	34D
0005435213530	7721	201	34G
0005435213728	7721	202	34F
0005432529551	7721	203	35B
0005435214130	7721	204	35A
0005432529580	7721	205	34K
0005434068463	7721	206	35D
0005435213775	7721	207	35C
0005435213655	7721	208	35F
0005432529568	7721	209	35H
0005434068409	7721	210	35G
0005435213727	7721	211	36A
0005432529616	7721	212	35K
0005434068408	7721	213	35J
0005435213756	7721	214	36C
0005434068412	7721	215	36B
0005432529573	7721	216	36E
0005434068403	7721	217	36D
0005432529623	7721	218	36G
0005432529650	7721	219	36F
0005435213735	7721	220	36K
0005434068417	7721	221	36J
0005432529643	7721	222	37B
0005432529581	7721	223	37D
0005435213650	7721	224	37C
0005432529553	7721	225	37F
0005435213734	7721	226	37E
0005432529579	7721	227	37H
0005432529547	7721	228	37G
0005432529559	7721	229	38A
0005434068460	7721	230	37K
0005432150290	7721	231	38C
0005432529596	7721	232	38B
0005432529564	7721	233	38J
0005435213781	7721	234	39B
0005435213686	7721	235	38K
0005432150294	7721	236	39D
0005432529563	7721	237	39C
0005435214123	7721	238	39F
0005432529572	7721	239	39E
0005435213751	7721	240	39J
0005432535894	7721	241	39H
0005435213722	7721	242	39G
0005432537083	7721	243	40A
0005435213867	7721	244	39K
0005435213705	7721	245	40C
0005435213776	7721	246	40E
0005432529570	7721	247	40D
0005434068443	7721	248	40H
0005432069826	7721	249	40G
0005432537084	7721	250	40F
0005432529531	7721	251	41B
0005432535892	7721	252	41A
0005434068418	7721	253	41E
0005432529611	7721	254	41D
0005432529592	7721	255	41C
0005435213726	7721	256	41F
0005434068466	7721	257	41H
0005435214066	7721	258	41G
0005434068449	7721	259	42A
0005432529538	7721	260	41J
0005432529598	7721	261	42C
0005432529636	7721	262	42B
0005434068452	7721	263	42E
0005434068467	7721	264	42D
0005432529629	7721	265	42G
0005432529574	7721	266	42F
0005432529612	7721	267	42H
0005435213517	7721	268	43B
0005432529600	7721	269	42K
0005434068413	7721	270	43D
0005434068453	7721	271	43C
0005432529645	7721	272	43F
0005432529595	7721	273	43H
0005435213578	7721	274	43G
0005435213475	7721	275	43K
0005434068430	7721	276	43J
0005435213761	7721	277	44C
0005432529544	7721	278	44B
0005432529639	7721	279	44E
0005434068427	7721	280	44D
0005434068429	7721	281	44H
0005432529527	7721	282	44G
0005432529606	7721	283	44F
0005434068456	7721	284	44K
0005435213641	7721	285	44J
0005432529655	7721	286	45A
0005432529651	7721	287	45D
0005435213472	7721	288	45B
0005432535895	7721	289	45E
0005435213712	7721	290	45H
0005435213704	7721	291	45K
0005432529530	7721	292	45J
0005432529535	7721	293	46C
0005432529525	7721	294	46B
0005435213930	7721	295	46A
0005432069840	7721	296	46E
0005435213638	7721	297	46D
0005432150295	7721	298	46F
0005434068419	7721	299	46J
0005435213366	7721	300	46H
0005434068448	7721	301	47C
0005432529602	7721	302	47E
0005435214124	7721	303	47D
0005432529554	7721	304	47G
0005433656673	7721	305	47F
0005434068434	7721	306	47K
0005435213815	7721	307	47H
0005432529604	7721	308	48C
0005432529545	7721	309	48F
0005432529640	7721	310	48E
0005435213703	7721	311	48D
0005435213367	7721	312	48G
0005434068432	7721	313	49D
0005432529610	7721	314	49C
0005432529648	7721	315	49F
0005435213762	7721	316	49E
0005435213454	7721	317	49G
0005432069831	7721	318	50A
0005435213609	7721	319	50E
0005435213902	7721	320	50H
0005432529548	7721	321	50G
0005432529631	7721	322	50F
0005432535893	7721	323	51D
0005432529620	7721	324	50K
0005432529524	7721	325	51E
0005435380319	5353	1	1A
0005435424984	5353	2	2A
0005435425127	5353	3	1K
0005435097325	5353	4	2C
0005435425151	5353	5	2G
0005435615088	5353	6	2D
0005434573524	5353	7	3A
0005435615038	5353	8	2K
0005435615003	5353	9	2H
0005434344644	5353	10	3D
0005435615017	5353	11	3K
0005435490273	5353	12	3H
0005435425159	5353	13	3G
0005435615027	5353	14	4C
0005434245056	5353	15	4A
0005435425298	5353	16	4G
0005435615091	5353	17	4D
0005434245148	5353	18	4K
0005435425266	5353	19	4H
0005435425339	5353	20	5D
0005435042851	5353	21	5C
0005435615043	5353	22	1D
0005435615063	5353	23	5A
0005435615036	5353	24	5H
0005434344668	5353	25	1C
0005432047597	5353	26	5G
0005435615048	5353	27	11D
0005435424954	5353	28	11C
0005435615056	5353	29	11G
0005435615075	5353	30	11E
0005432133400	5353	31	11K
0005435615074	5353	32	11H
0005435425121	5353	33	12C
0005435425270	5353	34	12E
0005435425012	5353	35	12D
0005434344657	5353	36	12G
0005435425018	5353	37	12F
0005435615039	5353	38	13A
0005432841024	5353	39	12H
0005435425078	5353	40	13C
0005435425350	5353	41	13F
0005435615049	5353	42	13E
0005435615024	5353	43	13H
0005434344667	5353	44	13G
0005434245203	5353	45	14C
0005434245106	5353	46	13K
0005434344672	5353	47	14G
0005435425112	5353	48	14K
0005435042869	5353	49	14H
0005434245084	5353	50	15C
0005435615059	5353	51	15E
0005434573533	5353	52	15D
0005435425049	5353	53	15G
0005434344640	5353	54	15F
0005435425261	5353	55	15K
0005435615080	5353	56	16D
0005435615041	5353	57	16C
0005434245135	5353	58	16A
0005435425148	5353	59	16F
0005435425050	5353	60	16E
0005435302218	5353	61	16H
0005435615096	5353	62	17C
0005435491465	5353	63	17A
0005435425453	5353	64	17E
0005434344643	5353	65	17D
0005435615077	5353	66	17G
0005434344645	5353	67	17F
0005435425059	5353	68	17K
0005435615028	5353	69	18C
0005435425032	5353	70	18B
0005435615020	5353	71	18A
0005434573520	5353	72	18E
0005434245055	5353	73	18D
0005434344669	5353	74	18G
0005435425509	5353	75	18F
0005434245062	5353	76	18J
0005435615037	5353	77	18H
0005435615067	5353	78	19A
0005434344665	5353	79	19D
0005434245087	5353	80	19C
0005435425029	5353	81	19B
0005435615058	5353	82	19F
0005435615090	5353	83	19E
0005434344661	5353	84	19J
0005435615005	5353	85	19H
0005435425147	5353	86	19G
0005432133391	5353	87	20A
0005435425516	5353	88	19K
0005435615007	5353	89	20B
0005435425183	5353	90	20E
0005434344655	5353	91	20D
0005435615083	5353	92	20C
0005435615060	5353	93	20G
0005434245147	5353	94	20F
0005435615018	5353	95	20H
0005434344664	5353	96	21B
0005432133399	5353	97	21A
0005434344646	5353	98	21D
0005435319648	5353	99	21C
0005434344660	5353	100	21F
0005435615013	5353	101	21E
0005435425359	5353	102	21H
0005434344637	5353	103	21G
0005435042861	5353	104	22A
0005435615001	5353	105	21K
0005435615026	5353	106	21J
0005435425455	5353	107	22D
0005432047595	5353	108	22C
0005434245029	5353	109	22B
0005435425031	5353	110	22F
0005435042870	5353	111	22G
0005432133395	5353	112	22K
0005434245031	5353	113	22J
0005435425111	5353	114	23B
0005435615095	5353	115	23A
0005434245086	5353	116	23D
0005435614999	5353	117	23C
0005435042849	5353	118	23F
0005435425030	5353	119	23E
0005434344666	5353	120	23J
0005435424859	5353	121	23H
0005435097323	5353	122	23G
0005435615002	5353	123	24D
0005433719152	5353	124	23K
0005435491463	5353	125	24F
0005435615071	5353	126	24E
0005435615044	5353	127	24G
0005434245143	5353	128	25C
0005435319647	5353	129	25B
0005435380326	5353	130	25F
0005434245077	5353	131	25E
0005432133397	5353	132	25H
0005435425041	5353	133	25G
0005435615064	5353	134	25K
0005434573526	5353	135	26C
0005435305015	5353	136	26B
0005435097324	5353	137	26F
0005435615069	5353	138	26D
0005435302205	5353	139	26G
0005434245116	5353	140	26J
0005435490272	5353	141	26H
0005434344650	5353	142	27B
0005435425180	5353	143	27A
0005432363426	5353	144	26K
0005435042850	5353	145	27C
0005432133393	5353	146	27F
0005434573530	5353	147	27D
0005435424903	5353	148	27H
0005435615076	5353	149	27G
0005435425397	5353	150	27K
0005434245060	5353	151	27J
0005435425454	5353	152	28A
0005435615015	5353	153	28E
0005435615047	5353	154	28C
0005434344670	5353	155	28G
0005434344662	5353	156	28F
0005435615078	5353	157	28J
0005432133404	5353	158	29B
0005432133401	5353	159	29A
0005432841012	5353	160	29D
0005435425048	5353	161	29C
0005435425518	5353	162	29F
0005434245185	5353	163	29E
0005434344663	5353	164	29H
0005435615072	5353	165	29G
0005434245021	5353	166	29K
0005435615057	5353	167	29J
0005435425099	5353	168	30B
0005435425311	5353	169	30A
0005435615068	5353	170	30E
0005435425133	5353	171	30D
0005435097326	5353	172	30C
0005435615086	5353	173	30H
0005434573529	5353	174	30G
0005435424946	5353	175	30K
0005434573534	5353	176	30J
0005432047596	5353	177	31B
0005434245140	5353	178	31A
0005432841018	5353	179	31D
0005435425179	5353	180	31C
0005435042865	5353	181	31E
0005435615016	5353	182	31G
0005435305014	5353	183	32A
0005435424902	5353	184	31K
0005435425313	5353	185	32C
0005435425190	5353	186	32B
0005435042862	5353	187	32E
0005434344659	5353	188	32D
0005435615094	5353	189	32G
0005435615062	5353	190	32F
0005435615073	5353	191	32H
0005434245063	5353	192	33B
0005435097329	5353	193	33A
0005435615070	5353	194	33D
0005435425283	5353	195	33C
0005435425312	5353	196	33F
0005434656564	5353	197	33E
0005434344647	5353	198	33H
0005435424947	5353	199	33G
0005435425232	5353	200	33K
0005435615046	5353	201	33J
0005435425243	5353	202	34B
0005435615010	5353	203	34A
0005435615031	5353	204	34E
0005435425004	5353	205	34D
0005433719148	5353	206	34C
0005435615054	5353	207	34F
0005435042857	5353	208	34J
0005434245117	5353	209	34H
0005434344658	5353	210	35B
0005435424976	5353	211	35A
0005432133398	5353	212	35D
0005435425228	5353	213	35C
0005434344654	5353	214	35F
0005434244964	5353	215	35E
0005435615061	5353	216	35J
0005435425088	5353	217	35H
0005435615065	5353	218	35G
0005434344649	5353	219	36A
0005435615000	5353	220	35K
0005435615084	5353	221	36C
0005435615051	5353	222	36B
0005435615004	5353	223	36E
0005435615022	5353	224	36D
0005435615045	5353	225	36H
0005434573525	5353	226	36G
0005435097327	5353	227	36K
0005435425340	5353	228	36J
0005435615052	5353	229	37A
0005435425396	5353	230	37D
0005435615085	5353	231	37C
0005434573521	5353	232	37G
0005432133402	5353	233	37F
0005435555394	5353	234	37E
0005434245030	5353	235	37J
0005435425517	5353	236	37H
0005434245136	5353	237	38C
0005435491464	5353	238	38H
0005434344638	5353	239	38K
0005432133396	5353	240	39C
0005435319610	5353	241	39B
0005435425055	5353	242	39F
0005435425005	5353	243	39E
0005434245094	5353	244	39D
0005435424726	5353	245	39H
0005435615030	5353	246	40A
0005435319614	5353	247	39K
0005435424924	5353	248	39J
0005434344653	5353	249	40C
0005435615011	5353	250	40B
0005434245144	5353	251	40E
0005434245107	5353	252	40D
0005434245067	5353	253	40F
0005434344652	5353	254	40J
0005435424940	5353	255	40H
0005435490274	5353	256	41B
0005434245139	5353	257	41A
0005435319602	5353	258	40K
0005434245061	5353	259	41D
0005434344673	5353	260	41F
0005434573528	5353	261	41E
0005435425152	5353	262	41G
0005434573523	5353	263	42A
0005434245149	5353	264	41K
0005435615066	5353	265	41J
0005435319613	5353	266	42C
0005435425160	5353	267	42B
0005435615029	5353	268	42E
0005435319568	5353	269	42D
0005435425201	5353	270	42G
0005434344639	5353	271	42F
0005435615093	5353	272	42K
0005435042859	5353	273	43B
0005435425089	5353	274	43A
0005435615021	5353	275	43C
0005435615089	5353	276	43F
0005435042871	5353	277	43E
0005435615087	5353	278	43D
0005435615034	5353	279	43H
0005434656558	5353	280	43G
0005435302202	5353	281	44A
0005432841017	5353	282	43K
0005434344656	5353	283	43J
0005432133394	5353	284	44C
0005435425325	5353	285	44B
0005435615032	5353	286	44E
0005435615023	5353	287	44D
0005434344648	5353	288	44H
0005434573527	5353	289	44G
0005435615042	5353	290	44F
0005435615033	5353	291	44K
0005435042863	5353	292	45B
0005434244976	5353	293	45A
0005435042856	5353	294	45D
0005434344641	5353	295	45C
0005432133403	5353	296	45F
0005435615008	5353	297	45E
0005435425141	5353	298	45J
0005434344671	5353	299	45H
0005435615025	5353	300	45G
0005435615009	5353	301	45K
0005435425139	5353	302	46C
0005434573532	5353	303	46B
0005432133392	5353	304	46A
0005435615040	5353	305	46E
0005433719147	5353	306	46D
0005435097331	5353	307	46G
0005435615019	5353	308	46F
0005435425231	5353	309	46J
0005435615055	5353	310	46H
0005435097330	5353	311	47C
0005435425113	5353	312	47A
0005435425006	5353	313	46K
0005434573522	5353	314	47E
0005435424941	5353	315	47D
0005435615079	5353	316	47F
0005435615050	5353	317	47K
0005435614998	5353	318	47H
0005434344651	5353	319	48D
0005434245138	5353	320	48C
0005435615006	5353	321	48A
0005435380271	5353	322	48F
0005435302212	5353	323	48E
0005435097322	5353	324	48H
0005435615035	5353	325	48G
0005435615082	5353	326	49A
0005434573531	5353	327	48K
0005434245156	5353	328	49E
0005435615012	5353	329	49D
0005435425150	5353	330	49G
0005435425134	5353	331	49F
0005435425335	5353	332	49K
0005435424631	5353	333	49H
0005435425071	5353	334	50C
0005434344642	5353	335	50A
0005435615092	5353	336	50E
0005434245002	5353	337	50D
0005435615081	5353	338	50G
0005434245059	5353	339	50F
0005435615053	5353	340	51D
0005435097328	5353	341	50K
0005435302203	5353	342	50H
0005435425508	5353	343	51E
0005435615014	5353	344	51G
0005432165130	10873	1	1D
0005434573433	10873	2	1C
0005435613740	10873	3	1A
0005435614120	10873	4	1G
0005434245327	10873	5	2A
0005435613940	10873	6	1H
0005435425639	10873	7	2C
0005435425641	10873	8	2G
0005434245345	10873	9	2D
0005435613790	10873	10	3C
0005435097247	10873	11	3A
0005434344359	10873	12	2K
0005435614420	10873	13	3D
0005435613604	10873	14	3H
0005434344323	10873	15	4C
0005435614217	10873	16	4A
0005435613865	10873	17	3K
0005435614091	10873	18	4G
0005435614115	10873	19	4D
0005435614230	10873	20	5A
0005435425623	10873	21	4K
0005435425638	10873	22	4H
0005435425625	10873	23	5D
0005435614124	10873	24	5C
0005435380345	10873	25	5H
0005435613975	10873	26	5G
0005434344361	10873	27	11A
0005435613882	10873	28	5K
0005435614526	10873	29	11E
0005434245356	10873	30	11D
0005435305036	10873	31	11C
0005435614338	10873	32	11F
0005435614162	10873	33	11H
0005435425631	10873	34	12C
0005435614337	10873	35	12A
0005435613920	10873	36	11K
0005434344248	10873	37	12E
0005435614332	10873	38	12D
0005435613947	10873	39	12G
0005435614151	10873	40	13A
0005435614172	10873	41	12K
0005435425676	10873	42	13D
0005435614221	10873	43	13C
0005435613955	10873	44	13F
0005435304209	10873	45	13H
0005432166941	10873	46	13G
0005435304213	10873	47	14C
0005435491453	10873	48	14A
0005434344360	10873	49	13K
0005435097191	10873	50	14E
0005435614116	10873	51	14D
0005435613845	10873	52	14F
0005435380348	10873	53	14H
0005435614141	10873	54	15C
0005435613663	10873	55	15A
0005435425677	10873	56	14K
0005435425621	10873	57	15E
0005434245337	10873	58	15D
0005434573374	10873	59	15H
0005435613973	10873	60	15G
0005435425678	10873	61	16A
0005435304214	10873	62	15K
0005434656581	10873	63	16F
0005434245343	10873	64	16H
0005435614498	10873	65	17A
0005435614114	10873	66	16K
0005435425657	10873	67	17E
0005434344336	10873	68	17C
0005432165129	10873	69	17G
0005434344159	10873	70	17F
0005435380347	10873	71	17K
0005435425690	10873	72	17H
0005435319677	10873	73	18C
0005435305037	10873	74	18B
0005435425662	10873	75	18A
0005435425642	10873	76	18D
0005435425658	10873	77	18G
0005434245348	10873	78	18F
0005435490224	10873	79	18J
0005435614015	10873	80	18H
0005432165131	10873	81	19B
0005434573416	10873	82	19A
0005435425660	10873	83	19D
0005435491454	10873	84	19C
0005435425663	10873	85	19F
0005435613946	10873	86	19E
0005434245338	10873	87	19H
0005435614245	10873	88	19G
0005434344283	10873	89	20A
0005435614102	10873	90	19J
0005435614222	10873	91	20C
0005435614176	10873	92	20B
0005435613956	10873	93	20E
0005432165135	10873	94	20D
0005435425681	10873	95	20H
0005435614349	10873	96	20G
0005434573432	10873	97	20F
0005435613796	10873	98	21B
0005435425649	10873	99	21A
0005435613698	10873	100	20K
0005435613948	10873	101	21D
0005434245335	10873	102	21C
0005434245355	10873	103	21F
0005435613847	10873	104	21H
0005435613736	10873	105	22A
0005435614350	10873	106	21K
0005435613433	10873	107	21J
0005435319685	10873	108	22C
0005435614297	10873	109	22B
0005435614093	10873	110	22D
0005435425669	10873	111	22G
0005435614317	10873	112	22F
0005435425628	10873	113	22J
0005435614223	10873	114	22H
0005435425675	10873	115	23B
0005435613758	10873	116	22K
0005434344095	10873	117	23C
0005435614298	10873	118	23F
0005432165136	10873	119	23E
0005434245347	10873	120	23J
0005435613804	10873	121	23H
0005435613746	10873	122	23G
0005435614336	10873	123	24D
0005434344228	10873	124	23K
0005434573316	10873	125	24E
0005435613715	10873	126	25A
0005435613974	10873	127	24G
0005435425637	10873	128	25D
0005435425647	10873	129	25C
0005434245340	10873	130	25B
0005435042884	10873	131	25F
0005435380349	10873	132	25E
0005434245351	10873	133	25H
0005435425668	10873	134	25G
0005435425653	10873	135	26A
0005435613351	10873	136	25K
0005435614147	10873	137	25J
0005435613812	10873	138	26E
0005435425636	10873	139	26D
0005435613944	10873	140	26C
0005434245350	10873	141	26H
0005435613949	10873	142	26G
0005435614164	10873	143	26F
0005435613795	10873	144	26K
0005435614242	10873	145	26J
0005435425670	10873	146	27A
0005435425627	10873	147	27C
0005435319678	10873	148	27F
0005435614079	10873	149	27E
0005435425661	10873	150	27D
0005435614165	10873	151	27G
0005434344295	10873	152	27K
0005435380346	10873	153	27J
0005435614220	10873	154	28B
0005435613525	10873	155	28A
0005433719184	10873	156	28E
0005435425667	10873	157	28D
0005434573329	10873	158	28G
0005435614090	10873	159	28J
0005435319682	10873	160	28H
0005435425683	10873	161	29A
0005434344150	10873	162	29D
0005435425633	10873	163	29C
0005432165134	10873	164	29B
0005434573352	10873	165	29F
0005434344219	10873	166	29H
0005435425622	10873	167	30A
0005435613976	10873	168	29J
0005435613699	10873	169	30C
0005434344342	10873	170	30E
0005434344411	10873	171	30D
0005435319680	10873	172	30H
0005435425686	10873	173	30F
0005435613803	10873	174	30J
0005435614383	10873	175	31A
0005435614014	10873	176	31D
0005435614216	10873	177	31C
0005435613607	10873	178	31F
0005435425645	10873	179	31H
0005435425684	10873	180	31G
0005435425674	10873	181	31K
0005435425656	10873	182	31J
0005435614119	10873	183	32C
0005435614244	10873	184	32E
0005433719185	10873	185	32G
0005435425689	10873	186	32J
0005435425679	10873	187	32H
0005435614467	10873	188	33A
0005435425624	10873	189	32K
0005434573357	10873	190	33D
0005435614282	10873	191	33B
0005435614327	10873	192	33F
0005435425654	10873	193	33E
0005435614280	10873	194	33J
0005435425685	10873	195	33H
0005434245330	10873	196	33G
0005435425655	10873	197	33K
0005435613747	10873	198	34C
0005434245354	10873	199	34B
0005434245342	10873	200	34A
0005435614403	10873	201	34E
0005434344220	10873	202	34G
0005434344317	10873	203	34K
0005432363456	10873	204	34J
0005434245346	10873	205	35B
0005435380350	10873	206	35A
0005435614243	10873	207	35C
0005432841040	10873	208	35F
0005435613846	10873	209	35E
0005435614387	10873	210	35J
0005435425665	10873	211	35G
0005435425680	10873	212	36A
0005435614152	10873	213	35K
0005434245329	10873	214	36C
0005435425688	10873	215	36E
0005435613748	10873	216	36G
0005435613798	10873	217	36K
0005434573361	10873	218	36J
0005435425672	10873	219	37B
0005433719183	10873	220	37A
0005434245336	10873	221	37D
0005435613828	10873	222	37C
0005435614201	10873	223	37F
0005434245334	10873	224	37J
0005434344151	10873	225	37H
0005435614163	10873	226	37G
0005435425630	10873	227	37K
0005435425640	10873	228	38C
0005435614334	10873	229	38A
0005434344227	10873	230	38H
0005435097253	10873	231	39A
0005435613919	10873	232	38K
0005435425673	10873	233	39D
0005432363457	10873	234	39C
0005435614524	10873	235	39B
0005434245328	10873	236	39F
0005434344404	10873	237	39E
0005435614477	10873	238	39H
0005434344226	10873	239	39G
0005435304210	10873	240	39K
0005435614335	10873	241	40C
0005435425666	10873	242	40A
0005434573317	10873	243	40E
0005434344111	10873	244	40D
0005435304211	10873	245	40H
0005435613741	10873	246	40G
0005435613784	10873	247	40J
0005435613749	10873	248	41B
0005434245339	10873	249	41A
0005435613945	10873	250	41D
0005435614241	10873	251	41C
0005435613881	10873	252	41E
0005435425632	10873	253	41H
0005435614087	10873	254	41G
0005434245353	10873	255	41K
0005435614382	10873	256	42B
0005435614405	10873	257	42A
0005435613664	10873	258	42E
0005434344188	10873	259	42D
0005432841039	10873	260	42G
0005432165133	10873	261	42J
0005433719182	10873	262	43B
0005435425629	10873	263	43A
0005434344208	10873	264	42K
0005434245333	10873	265	43D
0005434344196	10873	266	43C
0005435613907	10873	267	43F
0005435425691	10873	268	43E
0005435614117	10873	269	43J
0005435614468	10873	270	43G
0005435425646	10873	271	43K
0005434245349	10873	272	44B
0005435425648	10873	273	44A
0005434245332	10873	274	44E
0005435319684	10873	275	44D
0005435425635	10873	276	44C
0005435425626	10873	277	44H
0005434344337	10873	278	44G
0005435613432	10873	279	44F
0005434344247	10873	280	44K
0005435319679	10873	281	44J
0005435425634	10873	282	45A
0005434344324	10873	283	45D
0005435613994	10873	284	45C
0005435614231	10873	285	45B
0005435425671	10873	286	45F
0005434656580	10873	287	45E
0005435613665	10873	288	45J
0005435380351	10873	289	45H
0005435425664	10873	290	45G
0005435613526	10873	291	45K
0005434245352	10873	292	46C
0005435613666	10873	293	46B
0005435614088	10873	294	46A
0005435425644	10873	295	46E
0005435614478	10873	296	46D
0005435490242	10873	297	46G
0005435425643	10873	298	46F
0005432363455	10873	299	46K
0005435613532	10873	300	46J
0005435614173	10873	301	46H
0005432165132	10873	302	47A
0005435425652	10873	303	47E
0005435425659	10873	304	47D
0005432166942	10873	305	47G
0005435613739	10873	306	47F
0005434245331	10873	307	48A
0005435614041	10873	308	47K
0005435319683	10873	309	47H
0005435319681	10873	310	48C
0005435425650	10873	311	48H
0005434344189	10873	312	48G
0005434245341	10873	313	49A
0005435614166	10873	314	48K
0005434656582	10873	315	49D
0005435614333	10873	316	49C
0005435425651	10873	317	49G
0005434344316	10873	318	49E
0005435614140	10873	319	49H
0005434344466	10873	320	50C
0005435425682	10873	321	50A
0005435097236	10873	322	49K
0005435614281	10873	323	50E
0005435304212	10873	324	50D
0005435614344	10873	325	51D
0005434344286	10873	326	51F
0005434245344	10873	327	51E
0005435425687	10873	328	51G
0005433805793	3226	1	1A
0005433634237	3226	2	1C
0005432181986	3226	3	1F
0005432460107	3226	4	1D
0005433805816	3226	5	2A
0005433634244	3226	6	2C
0005433805796	3226	7	2F
0005432181980	3226	8	2D
0005432459996	3226	9	3A
0005432181996	3226	10	3D
0005433634242	3226	11	3C
0005432181999	3226	12	3F
0005432460053	3226	13	4A
0005432459824	3226	14	4C
0005432460047	3226	15	4F
0005432460056	3226	16	4D
0005433634255	3226	17	5A
0005433805818	3226	18	5C
0005432459944	3226	19	5D
0005432460178	3226	20	6A
0005432181993	3226	21	5F
0005432460065	3226	22	6C
0005432181981	3226	23	6D
0005432460054	3226	24	7A
0005432460040	3226	25	7C
0005433805819	3226	26	7D
0005433634231	3226	27	8A
0005433805791	3226	28	8B
0005433805821	3226	29	8D
0005432459803	3226	30	8C
0005432182003	3226	31	8E
0005433507397	3226	32	9A
0005432181995	3226	33	8F
0005432459859	3226	34	9B
0005432460141	3226	35	9C
0005432181990	3226	36	9E
0005432460039	3226	37	9D
0005432460041	3226	38	10A
0005432181997	3226	39	9F
0005432181991	3226	40	10B
0005432460122	3226	41	10C
0005432459995	3226	42	10E
0005433805789	3226	43	10D
0005433805804	3226	44	10F
0005432459936	3226	45	11A
0005432460088	3226	46	11C
0005432460191	3226	47	11B
0005433634246	3226	48	11E
0005433507400	3226	49	11D
0005432181985	3226	50	12A
0005433634248	3226	51	11F
0005432460236	3226	52	12C
0005433805807	3226	53	12D
0005433634241	3226	54	12E
0005432181998	3226	55	12F
0005432460023	3226	56	13A
0005432460068	3226	57	13C
0005433805813	3226	58	13B
0005432459942	3226	59	13D
0005433805794	3226	60	13E
0005433805806	3226	61	14A
0005433634235	3226	62	13F
0005432459988	3226	63	14B
0005433634233	3226	64	14D
0005433507402	3226	65	14C
0005433507396	3226	66	14E
0005432459989	3226	67	14F
0005433507404	3226	68	15B
0005433634239	3226	69	15A
0005432459943	3226	70	15C
0005432460016	3226	71	15D
0005433507406	3226	72	15F
0005432460237	3226	73	15E
0005432460279	3226	74	16A
0005432460052	3226	75	16B
0005433805810	3226	76	16D
0005433634247	3226	77	16E
0005433507405	3226	78	16F
0005433634226	3226	79	17B
0005433507393	3226	80	17A
0005433634245	3226	81	17C
0005433507399	3226	82	17D
0005433805802	3226	83	17F
0005432459984	3226	84	18A
0005433634228	3226	85	18B
0005433805817	3226	86	18D
0005433634240	3226	87	18C
0005432181989	3226	88	18E
0005433805799	3226	89	19B
0005433634256	3226	90	19C
0005433805795	3226	91	19D
0005433805792	3226	92	19E
0005433805798	3226	93	20A
0005433634252	3226	94	20C
0005433634238	3226	95	20B
0005433805822	3226	96	20D
0005432181983	3226	97	20F
0005432460003	3226	98	20E
0005432459825	3226	99	21A
0005432459935	3226	100	21C
0005432460130	3226	101	21B
0005433634234	3226	102	21D
0005433634251	3226	103	21E
0005433507398	3226	104	21F
0005433805820	3226	105	22B
0005433507401	3226	106	22A
0005433634229	3226	107	22C
0005433507394	3226	108	22E
0005432460166	3226	109	22D
0005432182000	3226	110	22F
0005433634254	3226	111	23B
0005433805803	3226	112	23A
0005432459832	3226	113	23C
0005432181987	3226	114	23D
0005433634243	3226	115	23E
0005433805797	3226	116	23F
0005433507395	3226	117	24B
0005432181994	3226	118	24A
0005432460275	3226	119	24C
0005432460067	3226	120	24E
0005432181982	3226	121	24D
0005432460015	3226	122	24F
0005433634227	3226	123	25B
0005432460120	3226	124	25A
0005432460204	3226	125	25D
0005433805801	3226	126	25F
0005433805815	3226	127	25E
0005432459921	3226	128	26A
0005432182002	3226	129	26C
0005432181988	3226	130	26E
0005432181984	3226	131	26D
0005432460089	3226	132	26F
0005433805812	3226	133	27B
0005433634232	3226	134	27A
0005433805805	3226	135	27C
0005433634250	3226	136	27D
0005433805811	3226	137	27F
0005432459895	3226	138	27E
0005433634236	3226	139	28B
0005433805814	3226	140	28A
0005433634253	3226	141	28C
0005433634225	3226	142	28E
0005433634259	3226	143	28D
0005432181992	3226	144	28F
0005433507403	3226	145	29B
0005432182001	3226	146	29A
0005433634258	3226	147	29C
0005432459844	3226	148	29D
0005432460092	3226	149	29E
0005433634230	3226	150	30A
0005432459922	3226	151	29F
0005433634249	3226	152	30B
0005432459915	3226	153	30D
0005433634257	3226	154	30C
0005433805809	3226	155	31A
0005432460270	3226	156	30F
0005432460190	3226	157	30E
0005432460091	3226	158	31C
0005432460179	3226	159	31B
0005433805790	3226	160	31D
0005433805800	3226	161	31F
0005433805808	3226	162	31E
0005435885491	3227	1	2C
0005435885685	3227	2	3A
0005435885659	3227	3	3D
0005435885571	3227	4	3C
0005435885410	3227	5	4F
0005435885498	3227	6	5D
0005435885411	3227	7	6A
0005435885445	3227	8	6D
0005435885444	3227	9	8B
0005435885438	3227	10	8E
0005435885620	3227	11	8F
0005435885380	3227	12	9C
0005435885664	3227	13	10E
0005435885516	3227	14	11D
0005435885377	3227	15	11E
0005435885621	3227	16	12D
0005435885508	3227	17	12C
0005435885429	3227	18	13B
0005435885442	3227	19	13A
0005435885448	3227	20	13F
0005435885514	3227	21	14B
0005435885500	3227	22	15B
0005435885336	3227	23	15C
0005435885300	3227	24	15D
0005435885697	3227	25	16A
0005435885450	3227	26	16B
0005435885447	3227	27	16D
0005435885660	3227	28	17F
0005435885497	3227	29	17E
0005435885611	3227	30	18F
0005435885403	3227	31	19C
0005435885399	3227	32	20F
0005435885676	3227	33	21B
0005435885299	3227	34	21E
0005435885350	3227	35	22C
0005435885325	3227	36	23A
0005435885492	3227	37	23E
0005435885394	3227	38	24B
0005435885518	3227	39	24D
0005435885544	3227	40	25A
0005435885449	3227	41	25D
0005435885501	3227	42	25F
0005435885409	3227	43	27A
0005435885665	3227	44	28C
0005435885443	3227	45	28E
0005435885472	3227	46	30A
0005435885608	3227	47	30C
0005435885607	3227	48	30E
0005432460540	8172	1	1A
0005435885861	8172	2	1C
0005432460547	8172	3	1F
0005435885847	8172	4	2A
0005432460533	8172	5	2D
0005432042889	8172	6	2F
0005435885850	8172	7	3C
0005432460512	8172	8	4A
0005435885873	8172	9	3F
0005433507169	8172	10	4D
0005435885881	8172	11	4C
0005435885858	8172	12	4F
0005432460517	8172	13	5A
0005435885874	8172	14	5C
0005432460508	8172	15	5F
0005432460509	8172	16	6A
0005435885862	8172	17	6C
0005435885836	8172	18	6D
0005432460554	8172	19	6F
0005432042880	8172	20	7C
0005432460520	8172	21	7D
0005432460543	8172	22	8A
0005435885851	8172	23	8C
0005435885841	8172	24	8B
0005432460521	8172	25	8D
0005432460518	8172	26	8E
0005435885870	8172	27	8F
0005432460523	8172	28	9A
0005432460535	8172	29	9C
0005432042892	8172	30	9B
0005435885837	8172	31	9D
0005435885844	8172	32	9F
0005433507330	8172	33	9E
0005435885843	8172	34	10A
0005435885840	8172	35	10B
0005435885868	8172	36	10D
0005432460506	8172	37	10E
0005434312347	8172	38	11A
0005432460544	8172	39	10F
0005432460530	8172	40	11B
0005433507219	8172	41	11C
0005432460546	8172	42	11E
0005435885877	8172	43	11D
0005435885852	8172	44	11F
0005435885872	8172	45	12A
0005432460549	8172	46	12C
0005432460522	8172	47	12B
0005432460516	8172	48	12E
0005432042882	8172	49	12D
0005432460542	8172	50	13A
0005432460552	8172	51	13C
0005435885876	8172	52	13D
0005432042888	8172	53	13E
0005435885867	8172	54	14A
0005432042887	8172	55	13F
0005435885875	8172	56	14B
0005432460556	8172	57	14E
0005433507208	8172	58	14D
0005432460550	8172	59	14F
0005432460511	8172	60	15B
0005435885856	8172	61	15C
0005432460548	8172	62	15D
0005433507244	8172	63	15F
0005435885839	8172	64	16A
0005433507106	8172	65	16D
0005435885849	8172	66	16E
0005435885860	8172	67	16F
0005435885869	8172	68	17C
0005433507221	8172	69	17B
0005433507209	8172	70	17D
0005432460558	8172	71	17F
0005432460524	8172	72	17E
0005432460538	8172	73	18A
0005433507247	8172	74	18D
0005432460545	8172	75	18C
0005432460519	8172	76	18E
0005433507230	8172	77	19C
0005435885853	8172	78	19B
0005433507317	8172	79	19D
0005432460532	8172	80	20A
0005435885846	8172	81	19E
0005432042894	8172	82	20B
0005432460539	8172	83	20C
0005432460551	8172	84	20D
0005435885863	8172	85	20F
0005435885878	8172	86	20E
0005432460527	8172	87	21A
0005433507222	8172	88	21B
0005435885865	8172	89	21D
0005433507270	8172	90	21C
0005432460555	8172	91	21F
0005432042886	8172	92	21E
0005432460531	8172	93	22C
0005432460536	8172	94	22D
0005435885859	8172	95	22F
0005435885880	8172	96	23A
0005432042890	8172	97	23C
0005432460525	8172	98	23B
0005432460514	8172	99	23D
0005433507292	8172	100	23E
0005432460553	8172	101	24A
0005433507173	8172	102	23F
0005433507268	8172	103	24B
0005432042883	8172	104	24C
0005432460534	8172	105	24D
0005433507170	8172	106	24F
0005432460541	8172	107	24E
0005432460528	8172	108	25B
0005432042891	8172	109	25A
0005432460513	8172	110	25D
0005435885864	8172	111	25E
0005433507269	8172	112	26B
0005432042881	8172	113	26A
0005432460526	8172	114	26D
0005435885879	8172	115	26E
0005433507214	8172	116	26F
0005435885845	8172	117	27A
0005432460529	8172	118	27B
0005435885882	8172	119	27D
0005432042884	8172	120	27F
0005435885871	8172	121	28A
0005432460515	8172	122	28B
0005432460537	8172	123	28D
0005435885857	8172	124	28C
0005435885838	8172	125	28E
0005432042895	8172	126	28F
0005432042893	8172	127	29B
0005435885855	8172	128	29C
0005435885854	8172	129	29E
0005433507171	8172	130	30A
0005432460507	8172	131	29F
0005435885848	8172	132	30C
0005432042885	8172	133	30B
0005435885866	8172	134	30D
0005432460510	8172	135	30F
0005435885842	8172	136	30E
0005433507271	8172	137	31B
0005433507287	8172	138	31A
0005432460557	8172	139	31C
0005434312346	8172	140	31E
0005433805580	8169	1	1F
0005433805613	8169	2	2A
0005433805592	8169	3	2F
0005433805447	8169	4	3C
0005435854064	8169	5	3D
0005434271315	8169	6	4D
0005433633824	8169	7	5C
0005433633825	8169	8	6A
0005433805486	8169	9	5F
0005433633970	8169	10	6D
0005433633858	8169	11	7A
0005433805577	8169	12	6F
0005433805494	8169	13	7D
0005434143738	8169	14	8C
0005433805600	8169	15	8E
0005433633832	8169	16	8F
0005433805643	8169	17	9E
0005433805488	8169	18	9D
0005433633931	8169	19	10D
0005433633892	8169	20	10C
0005433805579	8169	21	10E
0005433805578	8169	22	10F
0005433633883	8169	23	11A
0005433633779	8169	24	11C
0005433805411	8169	25	11E
0005433633850	8169	26	11D
0005433633918	8169	27	12A
0005433805485	8169	28	12C
0005433805492	8169	29	12D
0005433805569	8169	30	13A
0005433805593	8169	31	12F
0005434143734	8169	32	13D
0005433633879	8169	33	13E
0005433805459	8169	34	14C
0005433633942	8169	35	14E
0005433805242	8169	36	15A
0005433805495	8169	37	15D
0005433633930	8169	38	15F
0005433633843	8169	39	15E
0005433633921	8169	40	16A
0005433633932	8169	41	17A
0005433805601	8169	42	17C
0005433633831	8169	43	17D
0005433805423	8169	44	17E
0005434271314	8169	45	18C
0005433633661	8169	46	18B
0005433805570	8169	47	19E
0005433805544	8169	48	20B
0005433805391	8169	49	20A
0005433805451	8169	50	20E
0005435854065	8169	51	21A
0005433805560	8169	52	21E
0005433633969	8169	53	22A
0005433805541	8169	54	23A
0005433805540	8169	55	23C
0005433805561	8169	56	23B
0005433633880	8169	57	23D
0005433805543	8169	58	23F
0005433633660	8169	59	24E
0005433805426	8169	60	25C
0005433805487	8169	61	25E
0005433805489	8169	62	26D
0005433805450	8169	63	26E
0005433805424	8169	64	26F
0005433633951	8169	65	27A
0005433805379	8169	66	27B
0005433805514	8169	67	27D
0005433633979	8169	68	28D
0005433805648	8169	69	29D
0005433633662	8169	70	31A
0005433805515	8169	71	31D
0005433633922	8169	72	31E
0005434183592	8168	1	2C
0005434183589	8168	2	4C
0005434183588	8168	3	10B
0005434183581	8168	4	16E
0005434183591	8168	5	30D
0005432728088	4561	1	1A
0005432728094	4561	2	1C
0005432383667	4561	3	1D
0005432383664	4561	4	1F
0005432383676	4561	5	2A
0005433722304	4561	6	2C
0005433722303	4561	7	2D
0005432383672	4561	8	3C
0005432728090	4561	9	3D
0005432383665	4561	10	3F
0005432383639	4561	11	4A
0005433722307	4561	12	4C
0005432383650	4561	13	4E
0005432728095	4561	14	5D
0005432383648	4561	15	5E
0005433453785	4561	16	5F
0005432383652	4561	17	6A
0005432728093	4561	18	6C
0005433722306	4561	19	6D
0005432728098	4561	20	6E
0005432383649	4561	21	6F
0005432383651	4561	22	7A
0005432383679	4561	23	8A
0005432383677	4561	24	8C
0005432383674	4561	25	8D
0005432383669	4561	26	8E
0005432728099	4561	27	8F
0005433453786	4561	28	9A
0005432728092	4561	29	9C
0005433454902	4561	30	10D
0005432728091	4561	31	10E
0005432383660	4561	32	10F
0005432383678	4561	33	11A
0005432383659	4561	34	11C
0005432383647	4561	35	11E
0005432383653	4561	36	11F
0005432383646	4561	37	12A
0005432383658	4561	38	12D
0005432383644	4561	39	13A
0005432728089	4561	40	13C
0005433454901	4561	41	13D
0005432728087	4561	42	13E
0005432383642	4561	43	14A
0005432383668	4561	44	14C
0005432383663	4561	45	15C
0005432383641	4561	46	15D
0005432383675	4561	47	15E
0005432383666	4561	48	15F
0005432383645	4561	49	16A
0005432383670	4561	50	16C
0005432383671	4561	51	16D
0005432383661	4561	52	16F
0005432383673	4561	53	17A
0005432383654	4561	54	17C
0005433722308	4561	55	17E
0005432383657	4561	56	18A
0005433722305	4561	57	18C
0005432383662	4561	58	18E
0005432383643	4561	59	19C
0005432728096	4561	60	19D
0005432728097	4561	61	19F
0005432383655	4561	62	20A
0005432383656	4561	63	20D
0005432383640	4561	64	20E
0005432383147	30219	1	1A
0005432383116	30219	2	1C
0005432383100	30219	3	1D
0005432383241	30219	4	1F
0005432383153	30219	5	2A
0005433722225	30219	6	2C
0005433453762	30219	7	2D
0005432383121	30219	8	4A
0005432727950	30219	9	4C
0005433194854	30219	10	4D
0005432728022	30219	11	4E
0005432728020	30219	12	4F
0005432383243	30219	13	5A
0005432383311	30219	14	5C
0005432383149	30219	15	5D
0005432383277	30219	16	6A
0005432728023	30219	17	6C
0005433453763	30219	18	6D
0005432383232	30219	19	6E
0005432383042	30219	20	7C
0005433722199	30219	21	7D
0005432383016	30219	22	7F
0005432383191	30219	23	8C
0005432383306	30219	24	8D
0005432383183	30219	25	8E
0005432383264	30219	26	9C
0005433722228	30219	27	9E
0005432382995	30219	28	9F
0005433722227	30219	29	10A
0005432383148	30219	30	10C
0005432383084	30219	31	10D
0005433451632	30219	32	10E
0005432383202	30219	33	10F
0005432383154	30219	34	11C
0005432383278	30219	35	11D
0005432383312	30219	36	11E
0005432383150	30219	37	11F
0005432383096	30219	38	12C
0005432383239	30219	39	12E
0005432728021	30219	40	12F
0005432383268	30219	41	13A
0005432383132	30219	42	13C
0005432382996	30219	43	13F
0005432383117	30219	44	14A
0005432383203	30219	45	14C
0005432383043	30219	46	14D
0005432383276	30219	47	14E
0005432728003	30219	48	15A
0005432383170	30219	49	15C
0005432383095	30219	50	15D
0005432383198	30219	51	15E
0005432727949	30219	52	16A
0005432383269	30219	53	16E
0005432383237	30219	54	16F
0005432383238	30219	55	17A
0005433194853	30219	56	17C
0005433194860	30219	57	17D
0005432383242	30219	58	18A
0005432383099	30219	59	18C
0005432383260	30219	60	18F
0005432727993	30219	61	19A
0005432383164	30219	62	19C
0005433451631	30219	63	20A
0005433722229	30219	64	20C
0005432383171	30219	65	20E
0005432383152	30219	66	20F
0005435541280	1714	1	1A
0005435541267	1714	2	1C
0005435529524	1714	3	1D
0005435529538	1714	4	1F
0005433517004	1714	5	2C
0005435541284	1714	6	2F
0005433517008	1714	7	3A
0005435529533	1714	8	3C
0005432294517	1714	9	3D
0005432925079	1714	10	3F
0005432294518	1714	11	4D
0005435529536	1714	12	4F
0005435541269	1714	13	5A
0005435529528	1714	14	5C
0005435541278	1714	15	5E
0005432294516	1714	16	5F
0005435529540	1714	17	6A
0005435529527	1714	18	6C
0005435541281	1714	19	6D
0005432925078	1714	20	6F
0005435541275	1714	21	7A
0005435529539	1714	22	7C
0005433516999	1714	23	8E
0005435529523	1714	24	8F
0005435541273	1714	25	9A
0005435529541	1714	26	9C
0005433517006	1714	27	9D
0005435529532	1714	28	9E
0005433517003	1714	29	10A
0005435529530	1714	30	10C
0005435541283	1714	31	11A
0005433517000	1714	32	11D
0005435541265	1714	33	11E
0005435541277	1714	34	12E
0005435529534	1714	35	12F
0005432294519	1714	36	13E
0005435529522	1714	37	13F
0005433517001	1714	38	14D
0005435529535	1714	39	14F
0005432925032	1714	40	15A
0005435541270	1714	41	15C
0005435529537	1714	42	15D
0005435541271	1714	43	15E
0005435541285	1714	44	15F
0005432925031	1714	45	16A
0005433517002	1714	46	16C
0005435541272	1714	47	16D
0005433517007	1714	48	16F
0005435529529	1714	49	17A
0005435529521	1714	50	17C
0005435541266	1714	51	17D
0005435541276	1714	52	17E
0005435541268	1714	53	18C
0005435541286	1714	54	18D
0005435529526	1714	55	18F
0005433517005	1714	56	19A
0005435541279	1714	57	19D
0005435529525	1714	58	19E
0005435541274	1714	59	19F
0005435529542	1714	60	20D
0005435529531	1714	61	20E
0005435541282	1714	62	20F
0005435517939	21972	1	1A
0005435517923	21972	2	1C
0005433516922	21972	3	1F
0005433516943	21972	4	2A
0005435541079	21972	5	2C
0005435518037	21972	6	2F
0005435541040	21972	7	3A
0005432925097	21972	8	3C
0005435541032	21972	9	3F
0005435517954	21972	10	4C
0005435541115	21972	11	4D
0005435517993	21972	12	5A
0005432925095	21972	13	5C
0005433516923	21972	14	5D
0005433516917	21972	15	5F
0005435517946	21972	16	6D
0005435540999	21972	17	6E
0005433516899	21972	18	6F
0005435541112	21972	19	7A
0005435518035	21972	20	7C
0005435540966	21972	21	7D
0005435517951	21972	22	7E
0005432925098	21972	23	7F
0005435541052	21972	24	8C
0005435541116	21972	25	8D
0005435541033	21972	26	8F
0005435541062	21972	27	9A
0005435517877	21972	28	9C
0005433516950	21972	29	9D
0005435541095	21972	30	10C
0005433516955	21972	31	10E
0005435517953	21972	32	10F
0005435541131	21972	33	11A
0005435541134	21972	34	11D
0005435518022	21972	35	11E
0005433516904	21972	36	12A
0005435541137	21972	37	12D
0005435517947	21972	38	12F
0005432925094	21972	39	13C
0005435541138	21972	40	13D
0005432925096	21972	41	13E
0005435517862	21972	42	14A
0005435517861	21972	43	14C
0005435541096	21972	44	14E
0005433516840	21972	45	15A
0005435541019	21972	46	15C
0005435517878	21972	47	15D
0005435541099	21972	48	15F
0005433516926	21972	49	16C
0005435517933	21972	50	16D
0005435541100	21972	51	16E
0005435517924	21972	52	16F
0005435541089	21972	53	17A
0005433516921	21972	54	17D
0005433516903	21972	55	18D
0005435517967	21972	56	18E
0005433516918	21972	57	19C
0005435541000	21972	58	19E
0005435541097	21972	59	19F
0005435518001	21972	60	20A
0005435518015	21972	61	20C
0005435517934	21972	62	20E
0005435540998	21972	63	20D
0005432839428	7358	1	1A
0005435252860	7358	2	1C
0005432839406	7358	3	1F
0005434459072	7358	4	2C
0005434459064	7358	5	2F
0005434459070	7358	6	3A
0005432839431	7358	7	3C
0005435252762	7358	8	3D
0005435252777	7358	9	4A
0005432839429	7358	10	4D
0005435252818	7358	11	4E
0005432839410	7358	12	5A
0005435252836	7358	13	5C
0005432839404	7358	14	5D
0005432839434	7358	15	5E
0005432839412	7358	16	5F
0005432839430	7358	17	6A
0005432839408	7358	18	6D
0005432839413	7358	19	6E
0005432839422	7358	20	6F
0005432823473	7358	21	7A
0005432839415	7358	22	7C
0005432839423	7358	23	7D
0005434459063	7358	24	7E
0005434459057	7358	25	7F
0005432839432	7358	26	8A
0005435252753	7358	27	8C
0005432839407	7358	28	8D
0005435252769	7358	29	8F
0005432839427	7358	30	9A
0005432839421	7358	31	9C
0005432839425	7358	32	9D
0005432073434	7358	33	10A
0005434459067	7358	34	10C
0005432839411	7358	35	10D
0005434459058	7358	36	10E
0005434459056	7358	37	10F
0005432839426	7358	38	11A
0005434459062	7358	39	11C
0005432073433	7358	40	11D
0005432839433	7358	41	11E
0005434459071	7358	42	11F
0005432839418	7358	43	12E
0005434664955	7358	44	13C
0005435252797	7358	45	13D
0005434459055	7358	46	13E
0005432839409	7358	47	14C
0005434459068	7358	48	14D
0005432839414	7358	49	14E
0005435252754	7358	50	14F
0005434459059	7358	51	15C
0005434459065	7358	52	15D
0005434459054	7358	53	15E
0005435252817	7358	54	15F
0005432841036	7358	55	16A
0005434459060	7358	56	16C
0005435252755	7358	57	16D
0005435252752	7358	58	16E
0005434459052	7358	59	17C
0005432839405	7358	60	17D
0005432839419	7358	61	17E
0005432841038	7358	62	17F
0005432839416	7358	63	18C
0005434459053	7358	64	18E
0005434459061	7358	65	18F
0005434459051	7358	66	19A
0005432841037	7358	67	19C
0005432839417	7358	68	19D
0005432073435	7358	69	19E
0005432839424	7358	70	19F
0005435252770	7358	71	20A
0005432073432	7358	72	20C
0005434459069	7358	73	20D
0005434459066	7358	74	20E
0005432839420	7358	75	20F
0005432839225	28917	1	1A
0005432839117	28917	2	1D
0005432839219	28917	3	1F
0005432839271	28917	4	2A
0005434458908	28917	5	2C
0005434458915	28917	6	2D
0005432841014	28917	7	3C
0005435252913	28917	8	4A
0005432839220	28917	9	4C
0005435252926	28917	10	4D
0005434458898	28917	11	5A
0005435252920	28917	12	5F
0005435252916	28917	13	6C
0005432839293	28917	14	7C
0005432839266	28917	15	7D
0005434458862	28917	16	7E
0005432839178	28917	17	7F
0005432839209	28917	18	8A
0005435252927	28917	19	8C
0005435252925	28917	20	8E
0005435252924	28917	21	9D
0005432839270	28917	22	9E
0005435252929	28917	23	9F
0005435252914	28917	24	10C
0005434458856	28917	25	10F
0005432839254	28917	26	11C
0005432839152	28917	27	11D
0005432839176	28917	28	11F
0005435252922	28917	29	12A
0005432839124	28917	30	12C
0005434458916	28917	31	12D
0005434458918	28917	32	12E
0005434458778	28917	33	12F
0005434458846	28917	34	13A
0005434458861	28917	35	13C
0005432839208	28917	36	13F
0005435252917	28917	37	14A
0005435252921	28917	38	14C
0005432839216	28917	39	14D
0005435252923	28917	40	15A
0005435252928	28917	41	15C
0005434664989	28917	42	15D
0005432001048	28917	43	15E
0005435252915	28917	44	15F
0005435491467	28917	45	16C
0005434458863	28917	46	16D
0005434458885	28917	47	16E
0005434458930	28917	48	16F
0005434458847	28917	49	18A
0005434458886	28917	50	18C
0005435491466	28917	51	18E
0005432839177	28917	52	18F
0005434458938	28917	53	19C
0005435252919	28917	54	19D
0005435252918	28917	55	19E
0005432839106	28917	56	19F
0005434458813	28917	57	20C
0005434458882	28917	58	20F
0005435990710	8797	1	1D
0005435990711	8797	2	2A
0005435990713	8797	3	7A
0005434276078	8797	4	8A
0005435990712	8797	5	8F
0005435990714	8797	6	10B
0005435990708	8797	7	12D
0005434276052	8797	8	16C
0005435990709	8797	9	17E
0005434276098	15747	1	5F
0005434276096	15747	2	6B
0005435990668	15747	3	7B
0005434276100	15747	4	10A
0005434276099	15747	5	13B
0005435990645	15747	6	16C
0005435990676	15747	7	16E
0005434276097	15747	8	18E
0005435990654	15747	9	20A
0005433476896	20630	1	1A
0005432427169	20630	2	2D
0005432427167	20630	3	5A
0005432427170	20630	4	18C
0005432427168	20630	5	22C
0005433476901	20630	6	23A
0005433476920	30846	1	2A
0005432427145	30846	2	2B
0005433476919	30846	3	2D
0005432427140	30846	4	6A
0005432427147	30846	5	6B
0005432427148	30846	6	7A
0005433476918	30846	7	7C
0005433476917	30846	8	18D
0005432427149	30846	9	20D
0005432360979	6368	1	1A
0005435177188	6368	2	1C
0005432360944	6368	3	1D
0005432360937	6368	4	2A
0005432360959	6368	5	1F
0005435177244	6368	6	2C
0005432360955	6368	7	2D
0005432363456	6368	8	2F
0005432336182	6368	9	3A
0005434149769	6368	10	3D
0005432360980	6368	11	3F
0005435177154	6368	12	4A
0005432360935	6368	13	4B
0005435177142	6368	14	4D
0005432336177	6368	15	4C
0005435177225	6368	16	4F
0005432360966	6368	17	5A
0005435177174	6368	18	5B
0005432336181	6368	19	5D
0005435177218	6368	20	5C
0005432360946	6368	21	5E
0005432360948	6368	22	5F
0005432360950	6368	23	6B
0005434149761	6368	24	6A
0005432360941	6368	25	6C
0005432360968	6368	26	6D
0005432360945	6368	27	6E
0005434149723	6368	28	7A
0005432360970	6368	29	7C
0005432360972	6368	30	7B
0005435177198	6368	31	7D
0005432360977	6368	32	7F
0005435177182	6368	33	7E
0005435177266	6368	34	8A
0005432336179	6368	35	8B
0005434149722	6368	36	8C
0005434149770	6368	37	8E
0005435177181	6368	38	8D
0005435177165	6368	39	8F
0005432360949	6368	40	9A
0005435723060	6368	41	9B
0005435177135	6368	42	9D
0005432363457	6368	43	9C
0005432360951	6368	44	9E
0005432360981	6368	45	9F
0005435177200	6368	46	10B
0005432336176	6368	47	10C
0005432360933	6368	48	10E
0005434149764	6368	49	10D
0005435177160	6368	50	11A
0005435177220	6368	51	11B
0005432062292	6368	52	11D
0005435177127	6368	53	11C
0005435177243	6368	54	11E
0005435177268	6368	55	11F
0005434149760	6368	56	12C
0005435177280	6368	57	12B
0005434149767	6368	58	12E
0005432062294	6368	59	12F
0005432360975	6368	60	13A
0005432336180	6368	61	13B
0005434149783	6368	62	13D
0005432360969	6368	63	13C
0005432336178	6368	64	13E
0005432360967	6368	65	13F
0005435177187	6368	66	14B
0005432360936	6368	67	14A
0005435490224	6368	68	14C
0005432360934	6368	69	14D
0005434149784	6368	70	14E
0005435177204	6368	71	14F
0005435723045	6368	72	15B
0005432360963	6368	73	15A
0005432360965	6368	74	15C
0005432360953	6368	75	15D
0005432360939	6368	76	15E
0005432336183	6368	77	16A
0005432336186	6368	78	15F
0005432360947	6368	79	16C
0005435177263	6368	80	16B
0005432062296	6368	81	16D
0005435177179	6368	82	16E
0005432360978	6368	83	17A
0005432336185	6368	84	16F
0005435177279	6368	85	17B
0005432360962	6368	86	17C
0005435177277	6368	87	17D
0005434149738	6368	88	17E
0005432360956	6368	89	18A
0005432360957	6368	90	17F
0005435177199	6368	91	18B
0005435177128	6368	92	18D
0005432360943	6368	93	18C
0005435177267	6368	94	18F
0005432360964	6368	95	19A
0005432360976	6368	96	19B
0005435490242	6368	97	19C
0005432360973	6368	98	19E
0005435177221	6368	99	19D
0005432360938	6368	100	19F
0005435177262	6368	101	20B
0005434149765	6368	102	20A
0005434149837	6368	103	20D
0005435177183	6368	104	20C
0005432360971	6368	105	20E
0005434149737	6368	106	21A
0005435177224	6368	107	20F
0005432360960	6368	108	21B
0005432360940	6368	109	21D
0005434149771	6368	110	21C
0005432062295	6368	111	21E
0005435177276	6368	112	22A
0005432360961	6368	113	21F
0005432360958	6368	114	22B
0005434149792	6368	115	22C
0005432360974	6368	116	22D
0005435177281	6368	117	22F
0005432360954	6368	118	22E
0005432336184	6368	119	23A
0005432062293	6368	120	23B
0005432360942	6368	121	23C
0005432363455	6368	122	23D
0005434149763	6368	123	23F
0005432360952	6368	124	23E
0005434149871	21013	1	1A
0005435177410	21013	2	1C
0005435177426	21013	3	1D
0005435177417	21013	4	2A
0005435177412	21013	5	1F
0005432336123	21013	6	2C
0005432360381	21013	7	2D
0005432336047	21013	8	2F
0005432360619	21013	9	3A
0005432360554	21013	10	3D
0005432360424	21013	11	3C
0005435177427	21013	12	4A
0005434149879	21013	13	3F
0005435177406	21013	14	4B
0005432360565	21013	15	4D
0005432360667	21013	16	4E
0005432360441	21013	17	4F
0005435177404	21013	18	5A
0005432360444	21013	19	5C
0005432336098	21013	20	5B
0005434149878	21013	21	5D
0005435177413	21013	22	5E
0005432360445	21013	23	5F
0005435177403	21013	24	6B
0005432360401	21013	25	6A
0005432336077	21013	26	6C
0005432360538	21013	27	6D
0005432360611	21013	28	6E
0005435177408	21013	29	6F
0005432360533	21013	30	7B
0005432360532	21013	31	7A
0005432360315	21013	32	7C
0005432360536	21013	33	7D
0005434149880	21013	34	7F
0005432363438	21013	35	7E
0005432360677	21013	36	8A
0005432360598	21013	37	8B
0005434149876	21013	38	8C
0005435177405	21013	39	8D
0005432052784	21013	40	8E
0005435723071	21013	41	9A
0005432360437	21013	42	8F
0005435177402	21013	43	9C
0005435177423	21013	44	9B
0005435177416	21013	45	9D
0005432360407	21013	46	9F
0005432360438	21013	47	9E
0005432360641	21013	48	10B
0005432360373	21013	49	10D
0005435177414	21013	50	10C
0005432336095	21013	51	10E
0005432336116	21013	52	11A
0005432360567	21013	53	11C
0005435177422	21013	54	11B
0005434149874	21013	55	11D
0005435490276	21013	56	11F
0005432360482	21013	57	11E
0005432360492	21013	58	12A
0005435177425	21013	59	12B
0005432336097	21013	60	12D
0005432360566	21013	61	12C
0005432360363	21013	62	12E
0005432360580	21013	63	12F
0005434149875	21013	64	13A
0005435177411	21013	65	13B
0005435177418	21013	66	13C
0005432360494	21013	67	13E
0005432360425	21013	68	13D
0005432360632	21013	69	14A
0005434149869	21013	70	13F
0005432360633	21013	71	14B
0005435177424	21013	72	14C
0005432360476	21013	73	14D
0005435490275	21013	74	14E
0005432360626	21013	75	14F
0005432360705	21013	76	15A
0005432360691	21013	77	15C
0005435177407	21013	78	15B
0005432360523	21013	79	15D
0005432360655	21013	80	15F
0005432336076	21013	81	15E
0005434149872	21013	82	16B
0005432360582	21013	83	16A
0005435490278	21013	84	16C
0005435177421	21013	85	16D
0005432360555	21013	86	16E
0005432360408	21013	87	16F
0005432360453	21013	88	17B
0005432360371	21013	89	17A
0005432360504	21013	90	17C
0005432360584	21013	91	17D
0005434149873	21013	92	17F
0005432360627	21013	93	17E
0005432360411	21013	94	18A
0005432052783	21013	95	18B
0005432360678	21013	96	18D
0005432360654	21013	97	18C
0005434149870	21013	98	18F
0005432360505	21013	99	18E
0005432336101	21013	100	19A
0005432360647	21013	101	19B
0005434149877	21013	102	19C
0005435177420	21013	103	19E
0005432360578	21013	104	19D
0005435723072	21013	105	19F
0005432336096	21013	106	20A
0005434149881	21013	107	20B
0005432360372	21013	108	20D
0005435723073	21013	109	20C
0005432052782	21013	110	20E
0005432360620	21013	111	21A
0005432360561	21013	112	20F
0005432363428	21013	113	21C
0005432363439	21013	114	21B
0005432360524	21013	115	21D
0005432360493	21013	116	21F
0005435177419	21013	117	21E
0005432336046	21013	118	22B
0005435490277	21013	119	22A
0005435177415	21013	120	22C
0005432360648	21013	121	22D
0005432360475	21013	122	22F
0005432360539	21013	123	22E
0005435177409	21013	124	23B
0005435177428	21013	125	23A
0005432360495	21013	126	23D
0005435177429	21013	127	23C
0005432360481	21013	128	23F
0005432336082	21013	129	23E
0005434458899	17714	1	1A
0005434448333	17714	2	1C
0005434458934	17714	3	3A
0005434458973	17714	4	3B
0005434458986	17714	5	3D
0005434458890	17714	6	4A
0005434458888	17714	7	4B
0005434458840	17714	8	4C
0005434458985	17714	9	4D
0005434186237	17714	10	5B
0005434458900	17714	11	5D
0005434458980	17714	12	6A
0005434458901	17714	13	6B
0005434458920	17714	14	6C
0005434458894	17714	15	7A
0005434186234	17714	16	7B
0005434186236	17714	17	18B
0005434458896	17714	18	18C
0005434458891	17714	19	18D
0005434458919	17714	20	19A
0005434458984	17714	21	19B
0005434461645	17714	22	19C
0005434458974	17714	23	20D
0005434458950	17714	24	21B
0005434448335	17714	25	21C
0005434458895	17714	26	21D
0005434448332	17714	27	22A
0005434448334	17714	28	22B
0005434458897	17714	29	22C
0005434458889	17714	30	22D
0005434186235	17714	31	23A
0005434186220	29112	1	1B
0005434459069	29112	2	1C
0005434463954	29112	3	1D
0005434448355	29112	4	2B
0005434459068	29112	5	2A
0005434459054	29112	6	2C
0005434186215	29112	7	2D
0005434459061	29112	8	3D
0005434459057	29112	9	4B
0005434459055	29112	10	4C
0005434459052	29112	11	4D
0005434459058	29112	12	5A
0005434448354	29112	13	5C
0005434459066	29112	14	5D
0005434186193	29112	15	6D
0005434459067	29112	16	7A
0005434459060	29112	17	18A
0005434459071	29112	18	18B
0005434459070	29112	19	18C
0005434459063	29112	20	19B
0005434459051	29112	21	19D
0005434459053	29112	22	20A
0005434459072	29112	23	21A
0005434459059	29112	24	21B
0005434462815	29112	25	21C
0005434459062	29112	26	22A
0005434459065	29112	27	22B
0005434459056	29112	28	22C
0005434459064	29112	29	23A
0005432604805	21464	1	1C
0005432604793	21464	2	1D
0005432604791	21464	3	2A
0005432604797	21464	4	2B
0005432604802	21464	5	2C
0005432604783	21464	6	2D
0005432604781	21464	7	3A
0005432604803	21464	8	3B
0005432604792	21464	9	3C
0005432604780	21464	10	3D
0005432604809	21464	11	4A
0005432604813	21464	12	4B
0005432604810	21464	13	4C
0005432604794	21464	14	5A
0005432604782	21464	15	5B
0005432604807	21464	16	5C
0005432604796	21464	17	6A
0005432604784	21464	18	6B
0005432604789	21464	19	6C
0005432604800	21464	20	6D
0005432604812	21464	21	7A
0005432604816	21464	22	7B
0005432604808	21464	23	7C
0005432604799	21464	24	7D
0005432604804	21464	25	18A
0005432604788	21464	26	18D
0005432604798	21464	27	19A
0005432604779	21464	28	19B
0005432604786	21464	29	19D
0005432604811	21464	30	19C
0005432604801	21464	31	20A
0005432604814	21464	32	20B
0005432604817	21464	33	20C
0005432604790	21464	34	21B
0005432604806	21464	35	21C
0005432604815	21464	36	22A
0005432604787	21464	37	22B
0005432604785	21464	38	22D
0005432604795	21464	39	23A
0005432604598	31656	1	1A
0005432604308	31656	2	1B
0005432604588	31656	3	1C
0005432604419	31656	4	1D
0005432604256	31656	5	2A
0005432604340	31656	6	2C
0005432604426	31656	7	2D
0005432604431	31656	8	3B
0005432604449	31656	9	3A
0005432604489	31656	10	3C
0005432604370	31656	11	3D
0005432604379	31656	12	4A
0005432604457	31656	13	4B
0005432604482	31656	14	4C
0005432604485	31656	15	4D
0005432604558	31656	16	5A
0005432604643	31656	17	5B
0005432604432	31656	18	5C
0005432604502	31656	19	5D
0005432604435	31656	20	6A
0005432604399	31656	21	6B
0005432604395	31656	22	6C
0005432604433	31656	23	6D
0005432604245	31656	24	7A
0005432604380	31656	25	7B
0005432604589	31656	26	7C
0005432604597	31656	27	7D
0005432604437	31656	28	18A
0005432604301	31656	29	18B
0005432604434	31656	30	18C
0005432604634	31656	31	18D
0005432604246	31656	32	19A
0005432604430	31656	33	19B
0005432604423	31656	34	19C
0005432604390	31656	35	19D
0005432604456	31656	36	20A
0005432604463	31656	37	20B
0005432604420	31656	38	20C
0005432604381	31656	39	20D
0005432604633	31656	40	21A
0005432604325	31656	41	21B
0005432604398	31656	42	21C
0005432604306	31656	43	21D
0005432604469	31656	44	22A
0005432604307	31656	45	22B
0005432604369	31656	46	22C
0005432604468	31656	47	22D
0005432604326	31656	48	23B
0005433293260	12317	1	1A
0005433293264	12317	2	1B
0005433293261	12317	3	1C
0005435154615	12317	4	2B
0005433293247	12317	5	3B
0005433293274	12317	6	4C
0005433293237	12317	7	5A
0005433293282	12317	8	5B
0005435154611	12317	9	5D
0005433293246	12317	10	6A
0005433293273	12317	11	6C
0005433293270	12317	12	7A
0005433293242	12317	13	7B
0005435154613	12317	14	7C
0005433293275	12317	15	7D
0005435154612	12317	16	18B
0005433293236	12317	17	18C
0005433293249	12317	18	19A
0005433293259	12317	19	19D
0005433293272	12317	20	20B
0005433293243	12317	21	20D
0005433293271	12317	22	21A
0005433293238	12317	23	21B
0005433293250	12317	24	21C
0005435154614	12317	25	22D
0005433293281	12317	26	23B
0005434606823	18857	1	1A
0005434606826	18857	2	2A
0005434606827	18857	3	1B
0005434606825	18857	4	2B
0005434606846	18857	5	3A
0005434606842	18857	6	4A
0005434606847	18857	7	4B
0005434606831	18857	8	5A
0005434606845	18857	9	6A
0005434604938	22375	1	1B
0005434606869	22375	2	2A
0005434604937	22375	3	2B
0005434606867	22375	4	3B
0005434606868	22375	5	4A
0005434604936	22375	6	5A
0005434604935	22375	7	4B
0005434606870	22375	8	6A
0005432748010	375	1	1A
0005432891116	375	2	1C
0005432891097	375	3	1D
0005432891105	375	4	1F
0005432220053	375	5	2A
0005432891070	375	6	2C
0005432891071	375	7	2D
0005432891098	375	8	2F
0005432749810	375	9	3A
0005432891036	375	10	3D
0005432748018	375	11	3F
0005432751566	375	12	4C
0005432891165	375	13	4D
0005435154618	375	14	4E
0005432753339	375	15	5A
0005432748019	375	16	5C
0005432891089	375	17	5D
0005432220055	375	18	5E
0005432748014	375	19	5F
0005432891069	375	20	6A
0005432891030	375	21	6C
0005432748015	375	22	6D
0005432891156	375	23	6F
0005432748009	375	24	7C
0005432748031	375	25	7D
0005432891044	375	26	8A
0005432748047	375	27	8C
0005432748035	375	28	8D
0005432748037	375	29	8E
0005432751564	375	30	8F
0005435154619	375	31	9A
0005433293257	375	32	9C
0005432891029	375	33	9D
0005432748030	375	34	9E
0005432748040	375	35	9F
0005432748032	375	36	10A
0005432748021	375	37	10C
0005432748045	375	38	10D
0005432748046	375	39	10F
0005432748022	375	40	11A
0005432748043	375	41	11C
0005432753338	375	42	11D
0005432748036	375	43	11F
0005435154616	375	44	12A
0005432891150	375	45	12C
0005432748038	375	46	12D
0005432748044	375	47	12E
0005432891035	375	48	13A
0005432751563	375	49	13D
0005432748011	375	50	13F
0005432220056	375	51	14A
0005432891083	375	52	14C
0005432748023	375	53	14D
0005432891043	375	54	14E
0005432748028	375	55	14F
0005432748042	375	56	15A
0005432891120	375	57	15C
0005432748025	375	58	15D
0005432748026	375	59	15E
0005432748033	375	60	15F
0005432748017	375	61	16A
0005432748012	375	62	16C
0005432220054	375	63	16E
0005432748016	375	64	16F
0005432748034	375	65	17A
0005435154620	375	66	17C
0005432220057	375	67	17E
0005432748013	375	68	17F
0005432748024	375	69	18A
0005432891059	375	70	18C
0005432748029	375	71	18D
0005432748020	375	72	18F
0005432753340	375	73	19A
0005432748041	375	74	19C
0005433293245	375	75	19D
0005432891113	375	76	19F
0005435154617	375	77	20A
0005432748039	375	78	20C
0005432751565	375	79	20D
0005432748027	375	80	20E
0005432891065	375	81	20F
0005432891250	12041	1	1A
0005432747825	12041	2	1C
0005432747665	12041	3	1D
0005432753303	12041	4	1F
0005432747683	12041	5	2A
0005432753319	12041	6	2C
0005432891266	12041	7	2D
0005432747883	12041	8	2F
0005432753302	12041	9	3A
0005433293320	12041	10	3C
0005433293321	12041	11	3D
0005432747671	12041	12	3F
0005432891269	12041	13	4A
0005432747656	12041	14	4C
0005432891251	12041	15	4D
0005433293315	12041	16	4E
0005432749791	12041	17	4F
0005432747652	12041	18	5A
0005432747682	12041	19	5C
0005432891255	12041	20	5D
0005432891264	12041	21	5E
0005432891256	12041	22	5F
0005432747810	12041	23	6A
0005432753304	12041	24	6C
0005432747568	12041	25	6D
0005432747782	12041	26	6E
0005432747725	12041	27	6F
0005432747820	12041	28	7A
0005433293317	12041	29	7C
0005433293319	12041	30	7D
0005432747724	12041	31	7E
0005432214830	12041	32	7F
0005432756851	12041	33	8A
0005432747700	12041	34	8C
0005432747819	12041	35	8D
0005432891261	12041	36	8E
0005432214829	12041	37	8F
0005432747773	12041	38	9A
0005432747648	12041	39	9C
0005432891262	12041	40	9D
0005432891257	12041	41	9E
0005432891253	12041	42	9F
0005432891252	12041	43	10A
0005432753307	12041	44	10C
0005432747707	12041	45	10D
0005432747758	12041	46	10E
0005432891260	12041	47	10F
0005432747666	12041	48	11A
0005432747660	12041	49	11C
0005432747755	12041	50	11D
0005432756865	12041	51	11E
0005432747722	12041	52	11F
0005432747835	12041	53	12A
0005432747548	12041	54	12C
0005433293323	12041	55	12D
0005432747534	12041	56	12E
0005432891265	12041	57	12F
0005432749790	12041	58	13A
0005432747721	12041	59	13C
0005432747662	12041	60	13D
0005432747809	12041	61	13E
0005432747772	12041	62	13F
0005432747781	12041	63	14A
0005432747708	12041	64	14C
0005433293314	12041	65	14D
0005432747614	12041	66	14E
0005432747842	12041	67	14F
0005432747702	12041	68	15A
0005432747821	12041	69	15C
0005432891268	12041	70	15D
0005433293316	12041	71	15E
0005432747743	12041	72	15F
0005432891254	12041	73	16A
0005432891258	12041	74	16C
0005433293318	12041	75	16D
0005432747859	12041	76	16E
0005432891263	12041	77	16F
0005432747684	12041	78	17A
0005432891259	12041	79	17C
0005432747800	12041	80	17D
0005432747639	12041	81	17E
0005432747802	12041	82	17F
0005432747657	12041	83	18A
0005432756852	12041	84	18C
0005432747669	12041	85	18D
0005432747653	12041	86	18E
0005432753318	12041	87	18F
0005432753301	12041	88	19A
0005432747661	12041	89	19C
0005432747764	12041	90	19D
0005432891267	12041	91	19E
0005433293322	12041	92	19F
0005432747815	12041	93	20A
0005432747604	12041	94	20C
0005432749801	12041	95	20D
0005432747603	12041	96	20E
0005432747668	12041	97	20F
0005433525163	18971	1	1D
0005433525160	18971	2	2A
0005433525162	18971	3	2B
0005433525158	18971	4	4B
0005432928003	18971	5	4C
0005433525161	18971	6	4D
0005433533350	18971	7	5C
0005433525159	18971	8	5D
0005433531337	18971	9	6C
0005433533351	18971	10	7D
0005433533352	18971	11	18A
0005433525167	18971	12	18D
0005432928001	18971	13	19C
0005433525168	18971	14	19D
0005433533349	18971	15	21B
0005433533353	18971	16	21C
0005433531336	18971	17	22A
0005433525166	18971	18	22B
0005433525164	18971	19	22D
0005433525165	18971	20	23B
0005433531292	32486	1	1B
0005433525067	32486	2	1C
0005433531308	32486	3	1D
0005433525078	32486	4	2A
0005432928052	32486	5	3C
0005433527261	32486	6	3D
0005433525080	32486	7	4A
0005432928055	32486	8	4C
0005433525057	32486	9	4D
0005433531306	32486	10	5B
0005432928056	32486	11	5D
0005433525108	32486	12	6B
0005433525130	32486	13	7A
0005433525077	32486	14	7B
0005433525079	32486	15	7C
0005433531304	32486	16	18B
0005432928054	32486	17	18C
0005433527262	32486	18	19A
0005432928053	32486	19	19D
0005433525081	32486	20	20B
0005433525071	32486	21	20D
0005433525109	32486	22	21A
0005433525062	32486	23	21D
0005433525063	32486	24	22C
0005433525087	32486	25	22D
0005433525066	32486	26	23A
0005434825094	5272	1	1D
0005432121509	5272	2	1C
0005434664987	5272	3	1A
0005435304192	5272	4	1H
0005435373684	5272	5	1G
0005435373274	5272	6	1K
0005435373330	5272	7	2D
0005434825146	5272	8	2C
0005435373317	5272	9	2A
0005435373331	5272	10	2H
0005435373605	5272	11	2G
0005434558377	5272	12	3A
0005434825156	5272	13	2K
0005434825154	5272	14	3C
0005435661933	5272	15	3H
0005435373571	5272	16	3G
0005434558379	5272	17	4C
0005435150195	5272	18	4A
0005434825110	5272	19	3K
0005435150196	5272	20	4G
0005434825129	5272	21	4K
0005432121514	5272	22	4H
0005435373273	5272	23	5D
0005432394154	5272	24	5A
0005435373828	5272	25	5H
0005434825091	5272	26	5G
0005434825140	5272	27	11A
0005434825158	5272	28	5K
0005434558382	5272	29	11D
0005434825134	5272	30	11C
0005434825084	5272	31	11F
0005434825126	5272	32	11E
0005434825090	5272	33	11K
0005435661939	5272	34	11G
0005434825103	5272	35	12A
0005434825160	5272	36	12E
0005432394153	5272	37	12H
0005434825163	5272	38	12G
0005434825171	5272	39	12F
0005434825118	5272	40	13A
0005435373412	5272	41	13C
0005435373371	5272	42	13F
0005434825120	5272	43	13E
0005434825170	5272	44	13H
0005434831203	5272	45	13G
0005435373322	5272	46	14A
0005435373343	5272	47	13K
0005435373570	5272	48	14E
0005434825099	5272	49	14D
0005435373452	5272	50	14C
0005434825142	5272	51	14G
0005435373062	5272	52	14F
0005435373443	5272	53	14K
0005434825176	5272	54	14H
0005434825196	5272	55	15C
0005435373496	5272	56	15A
0005435150206	5272	57	15E
0005434825089	5272	58	15D
0005435661936	5272	59	15G
0005432121513	5272	60	15F
0005434825165	5272	61	16A
0005434825161	5272	62	15K
0005435178992	5272	63	15H
0005435735149	5272	64	16D
0005434825181	5272	65	16E
0005434825179	5272	66	16H
0005435373776	5272	67	17A
0005434825204	5272	68	16K
0005434825138	5272	69	17E
0005432121511	5272	70	17D
0005434825187	5272	71	17C
0005435373321	5272	72	17G
0005432121512	5272	73	17F
0005434828728	5272	74	17K
0005435373614	5272	75	18C
0005434825184	5272	76	18B
0005435373683	5272	77	18E
0005434825169	5272	78	18H
0005434825175	5272	79	18G
0005435373453	5272	80	18F
0005435373231	5272	81	18J
0005435373209	5272	82	18K
0005434825132	5272	83	19E
0005434825106	5272	84	19G
0005435735148	5272	85	20A
0005435373739	5272	86	19K
0005435373572	5272	87	19J
0005434825141	5272	88	20C
0005435373366	5272	89	20E
0005435386617	5272	90	20D
0005435373827	5272	91	20G
0005435373446	5272	92	20K
0005434825147	5272	93	20J
0005434825079	5272	94	20H
0005434825124	5272	95	21A
0005434825201	5272	96	21D
0005434558380	5272	97	21C
0005435373740	5272	98	21G
0005434825195	5272	99	21E
0005434825136	5272	100	21J
0005434825143	5272	101	21H
0005434825101	5272	102	21K
0005434828730	5272	103	22C
0005434825151	5272	104	22B
0005434825180	5272	105	22E
0005434558381	5272	106	22D
0005434825200	5272	107	22G
0005435373442	5272	108	22K
0005434825135	5272	109	23A
0005434825153	5272	110	23D
0005435150194	5272	111	23F
0005434831206	5272	112	23H
0005435735152	5272	113	23K
0005435150205	5272	114	24G
0005434825137	5272	115	24E
0005432121504	5272	116	25A
0005435373367	5272	117	25D
0005434825085	5272	118	25C
0005434825082	5272	119	25B
0005435373242	5272	120	25F
0005435373455	5272	121	25E
0005434825199	5272	122	25H
0005434825206	5272	123	25G
0005434825166	5272	124	25K
0005432396293	5272	125	25J
0005434825150	5272	126	26B
0005435373508	5272	127	26E
0005435373613	5272	128	26D
0005432823460	5272	129	26C
0005435150197	5272	130	26G
0005434825202	5272	131	26F
0005435373736	5272	132	26J
0005434825189	5272	133	27A
0005434825119	5272	134	26K
0005434825188	5272	135	27B
0005435304169	5272	136	27F
0005432121510	5272	137	27E
0005434825092	5272	138	27G
0005434825152	5272	139	27K
0005434825128	5272	140	27J
0005435386621	5272	141	28B
0005434825191	5272	142	28D
0005435373663	5272	143	28G
0005434825190	5272	144	29A
0005434825111	5272	145	29D
0005435735140	5272	146	29B
0005435661937	5272	147	29F
0005435150203	5272	148	29E
0005432394155	5272	149	29J
0005434825167	5272	150	29G
0005434828729	5272	151	30A
0005435373553	5272	152	30B
0005434825081	5272	153	30D
0005434825186	5272	154	30G
0005435150199	5272	155	30F
0005434825104	5272	156	30E
0005435373599	5272	157	30J
0005435373615	5272	158	31A
0005434825087	5272	159	30K
0005434825149	5272	160	31D
0005434825193	5272	161	31F
0005432121502	5272	162	31J
0005434825172	5272	163	31H
0005435373421	5272	164	31K
0005434825108	5272	165	32A
0005434825083	5272	166	32E
0005435373445	5272	167	32D
0005435179694	5272	168	32G
0005435304194	5272	169	32F
0005432823459	5272	170	32K
0005434825116	5272	171	33B
0005435661932	5272	172	33A
0005435150202	5272	173	33D
0005434825115	5272	174	33F
0005434825162	5272	175	33G
0005432121506	5272	176	33K
0005434831204	5272	177	33J
0005435735137	5272	178	34C
0005434825122	5272	179	34E
0005434825131	5272	180	34H
0005434825100	5272	181	34G
0005435304187	5272	182	34F
0005435373583	5272	183	34K
0005434825113	5272	184	34J
0005434831205	5272	185	35B
0005434825198	5272	186	35D
0005435373422	5272	187	35C
0005434825102	5272	188	35J
0005435373509	5272	189	35H
0005435373569	5272	190	36A
0005435304168	5272	191	35K
0005432121508	5272	192	36B
0005434825127	5272	193	36E
0005434825173	5272	194	36D
0005435150204	5272	195	36H
0005432121505	5272	196	36J
0005435304181	5272	197	37A
0005435373515	5272	198	37E
0005434825114	5272	199	37D
0005434558383	5272	200	37C
0005434825077	5272	201	37J
0005434825139	5272	202	37H
0005435373591	5272	203	37G
0005434825098	5272	204	38A
0005435373624	5272	205	38C
0005434825159	5272	206	38B
0005435386580	5272	207	38J
0005435661940	5272	208	38H
0005434558378	5272	209	39B
0005435150200	5272	210	39A
0005435373413	5272	211	39C
0005435373691	5272	212	39F
0005435661934	5272	213	39G
0005434825133	5272	214	39J
0005435373439	5272	215	40C
0005435150201	5272	216	40E
0005434825123	5272	217	40G
0005434825117	5272	218	40K
0005435373811	5272	219	40J
0005435179695	5272	220	41A
0005432396294	5272	221	41E
0005434825178	5272	222	41D
0005434825097	5272	223	41C
0005434558376	5272	224	41B
0005435373370	5272	225	41J
0005435386604	5272	226	41K
0005434825121	5272	227	42C
0005434825205	5272	228	42B
0005434825078	5272	229	42A
0005434825183	5272	230	42F
0005435304195	5272	231	42E
0005434664988	5272	232	42G
0005435373584	5272	233	42J
0005435386603	5272	234	42K
0005434825088	5272	235	43C
0005434825096	5272	236	43B
0005435735150	5272	237	43F
0005434825157	5272	238	43E
0005432121507	5272	239	43J
0005434825144	5272	240	43G
0005435373243	5272	241	44A
0005434825093	5272	242	44B
0005435299801	5272	243	44E
0005435150193	5272	244	44G
0005434825086	5272	245	44J
0005434825168	5272	246	44H
0005434825105	5272	247	45B
0005435373604	5272	248	45D
0005435150198	5272	249	45C
0005435373588	5272	250	45J
0005434825174	5272	251	45H
0005434825177	5272	252	45G
0005434825164	5272	253	45K
0005435373590	5272	254	46C
0005435373471	5272	255	46E
0005434825125	5272	256	46D
0005435661931	5272	257	46G
0005434825185	5272	258	46F
0005435373337	5272	259	46K
0005434825203	5272	260	46H
0005434825182	5272	261	47A
0005435735139	5272	262	47D
0005435299777	5272	263	47C
0005434825109	5272	264	47G
0005435373318	5272	265	47F
0005434825145	5272	266	47K
0005435373210	5272	267	47H
0005434825130	5272	268	48C
0005434825148	5272	269	48A
0005435373589	5272	270	48F
0005434825112	5272	271	48H
0005434825192	5272	272	48G
0005434825107	5272	273	49A
0005435178997	5272	274	48K
0005434825080	5272	275	49E
0005435373777	5272	276	49D
0005434825194	5272	277	49F
0005435373669	5272	278	49H
0005434825095	5272	279	50A
0005434825155	5272	280	50G
0005435386602	5272	281	50F
0005432121503	5272	282	51D
0005435373592	5272	283	50K
0005434825197	5272	284	51F
0005435373829	5272	285	51E
0005434824604	9933	1	1C
0005434823450	9933	2	1A
0005434824266	9933	3	1D
0005434823999	9933	4	1H
0005434824048	9933	5	2D
0005434823956	9933	6	2A
0005434823974	9933	7	2G
0005434824603	9933	8	3A
0005435374077	9933	9	2K
0005435374063	9933	10	3G
0005434664967	9933	11	3D
0005432203154	9933	12	3C
0005434823944	9933	13	3K
0005435150070	9933	14	3H
0005434823553	9933	15	4C
0005435374064	9933	16	4A
0005434831160	9933	17	4K
0005435661968	9933	18	4H
0005432203151	9933	19	5G
0005434824133	9933	20	5D
0005434831180	9933	21	5K
0005435374067	9933	22	11C
0005435374031	9933	23	11G
0005434831165	9933	24	11F
0005434824458	9933	25	11H
0005434823642	9933	26	12C
0005434558284	9933	27	12A
0005434558281	9933	28	11K
0005432203156	9933	29	12E
0005435150077	9933	30	12D
0005434823994	9933	31	12H
0005435150032	9933	32	12G
0005435374078	9933	33	12F
0005434824140	9933	34	13A
0005434824150	9933	35	12K
0005435150073	9933	36	13C
0005434824503	9933	37	13F
0005435179405	9933	38	13E
0005434824281	9933	39	13H
0005435374057	9933	40	13G
0005435374065	9933	41	14A
0005434558280	9933	42	14C
0005434824477	9933	43	14G
0005435374090	9933	44	14F
0005435374051	9933	45	14H
0005434824305	9933	46	15D
0005434823692	9933	47	15C
0005434823939	9933	48	15A
0005435374085	9933	49	15E
0005434823954	9933	50	15H
0005435374081	9933	51	15G
0005435374034	9933	52	16C
0005435374050	9933	53	16A
0005434823413	9933	54	16E
0005435302258	9933	55	16K
0005434824195	9933	56	16G
0005432396269	9933	57	17A
0005434823656	9933	58	17E
0005434824000	9933	59	17D
0005434823520	9933	60	17C
0005434823973	9933	61	17K
0005434823938	9933	62	17H
0005434823693	9933	63	18B
0005435374044	9933	64	18A
0005434824261	9933	65	18D
0005435150068	9933	66	18K
0005434824124	9933	67	18H
0005435374095	9933	68	19A
0005435374069	9933	69	19D
0005435374091	9933	70	19C
0005432203150	9933	71	19F
0005434824324	9933	72	19E
0005434824469	9933	73	19G
0005435150020	9933	74	19J
0005434824206	9933	75	20B
0005435374043	9933	76	20G
0005435150071	9933	77	20F
0005434824522	9933	78	20H
0005434824134	9933	79	21B
0005434824039	9933	80	21A
0005434824042	9933	81	21D
0005434824186	9933	82	21F
0005435374038	9933	83	21E
0005434558301	9933	84	21G
0005434664970	9933	85	21K
0005435374086	9933	86	22C
0005434824076	9933	87	22B
0005435374046	9933	88	22E
0005434823945	9933	89	22D
0005432203153	9933	90	22G
0005435374074	9933	91	22K
0005432400142	9933	92	22J
0005435374083	9933	93	23A
0005435374030	9933	94	23D
0005435374068	9933	95	23H
0005435735195	9933	96	23G
0005435374096	9933	97	24F
0005435374048	9933	98	24E
0005435150062	9933	99	24G
0005435299833	9933	100	25D
0005435150049	9933	101	25E
0005434824072	9933	102	25H
0005434824319	9933	103	25G
0005434824425	9933	104	25J
0005434823725	9933	105	26B
0005435374053	9933	106	26A
0005434824078	9933	107	26D
0005435374082	9933	108	26C
0005434823975	9933	109	26G
0005435299834	9933	110	26F
0005434831181	9933	111	26H
0005435299835	9933	112	27B
0005435374075	9933	113	27A
0005435150078	9933	114	26K
0005434823873	9933	115	27C
0005432396270	9933	116	27F
0005435150029	9933	117	27E
0005434824147	9933	118	27H
0005435150069	9933	119	27G
0005434558279	9933	120	27K
0005434558285	9933	121	27J
0005435374045	9933	122	28B
0005435374071	9933	123	28A
0005435302257	9933	124	28E
0005434824229	9933	125	28D
0005435150046	9933	126	28H
0005434823937	9933	127	29B
0005434823812	9933	128	28K
0005434824209	9933	129	29C
0005434824426	9933	130	29F
0005434664969	9933	131	29H
0005434824304	9933	132	29G
0005435302254	9933	133	29J
0005434824370	9933	134	30A
0005435374080	9933	135	30C
0005434824325	9933	136	30G
0005434824662	9933	137	30F
0005435374076	9933	138	31B
0005435374042	9933	139	31A
0005434824254	9933	140	31D
0005435735193	9933	141	31C
0005434823955	9933	142	31E
0005434823836	9933	143	31H
0005434824071	9933	144	31K
0005435374036	9933	145	32C
0005434823953	9933	146	32B
0005435374094	9933	147	32D
0005435299836	9933	148	32J
0005434664968	9933	149	33A
0005435735197	9933	150	33D
0005434824332	9933	151	33F
0005434831182	9933	152	33E
0005434823752	9933	153	33H
0005435661969	9933	154	33K
0005434823720	9933	155	34B
0005435374073	9933	156	34A
0005432203149	9933	157	34E
0005434824118	9933	158	34D
0005435374079	9933	159	34G
0005434823554	9933	160	34F
0005434824262	9933	161	34K
0005435302255	9933	162	34J
0005435150072	9933	163	34H
0005435150052	9933	164	35B
0005435150074	9933	165	35A
0005435150085	9933	166	35D
0005435374039	9933	167	35E
0005434823880	9933	168	35H
0005434823991	9933	169	35G
0005434823372	9933	170	36C
0005434823909	9933	171	36B
0005434824038	9933	172	36E
0005435374084	9933	173	36H
0005434824125	9933	174	36G
0005434824523	9933	175	36K
0005435150048	9933	176	37A
0005434824247	9933	177	37D
0005434824109	9933	178	37C
0005435374047	9933	179	37F
0005434823691	9933	180	37G
0005434823796	9933	181	37K
0005434824168	9933	182	38C
0005434824500	9933	183	38B
0005434558302	9933	184	38K
0005432203155	9933	185	38J
0005434828701	9933	186	38H
0005435661966	9933	187	39A
0005434823989	9933	188	39C
0005434823811	9933	189	39F
0005435735194	9933	190	39H
0005434824028	9933	191	39K
0005432823475	9933	192	40B
0005434824228	9933	193	40E
0005435374052	9933	194	40F
0005435374040	9933	195	40J
0005434823904	9933	196	41B
0005434824208	9933	197	41D
0005434824557	9933	198	41C
0005434823414	9933	199	41F
0005434824282	9933	200	41E
0005435735196	9933	201	41H
0005435374059	9933	202	42A
0005435150061	9933	203	41K
0005434831164	9933	204	41J
0005434824369	9933	205	42C
0005434824196	9933	206	42E
0005432823474	9933	207	42G
0005432203152	9933	208	42F
0005434824162	9933	209	43A
0005434824392	9933	210	42K
0005435374092	9933	211	43D
0005435374037	9933	212	43B
0005435374072	9933	213	43G
0005435374066	9933	214	43F
0005434823326	9933	215	43E
0005434823906	9933	216	43H
0005435374032	9933	217	43K
0005435374049	9933	218	44A
0005434824129	9933	219	44E
0005435374058	9933	220	44D
0005434823688	9933	221	44G
0005434824329	9933	222	44F
0005434823732	9933	223	44K
0005435374093	9933	224	44J
0005435374097	9933	225	45B
0005434823995	9933	226	45A
0005432396249	9933	227	45D
0005434824320	9933	228	45F
0005434823951	9933	229	45H
0005434558283	9933	230	46C
0005434824246	9933	231	46B
0005435374041	9933	232	46E
0005434824207	9933	233	46G
0005434824130	9933	234	46F
0005435374033	9933	235	46J
0005435150065	9933	236	47A
0005435374087	9933	237	46K
0005435374089	9933	238	47D
0005435150021	9933	239	47G
0005434823903	9933	240	47F
0005432396246	9933	241	47H
0005435302256	9933	242	48A
0005434824602	9933	243	48F
0005435299832	9933	244	48E
0005435374035	9933	245	48D
0005435150045	9933	246	48H
0005435661967	9933	247	48K
0005435374088	9933	248	49C
0005432400137	9933	249	49G
0005435374070	9933	250	49E
0005434824457	9933	251	49K
0005435374055	9933	252	49H
0005434824077	9933	253	50C
0005435374060	9933	254	50A
0005435374062	9933	255	50D
0005435374029	9933	256	50G
0005435150031	9933	257	50F
0005435374061	9933	258	51D
0005435374056	9933	259	50K
0005434823795	9933	260	51F
0005434823559	9933	261	51E
0005435374054	9933	262	51G
0005435082889	6981	1	1A
0005435082886	6981	2	1D
0005435082890	6981	3	2C
0005435790342	6981	4	3B
0005435082891	6981	5	4B
0005435082888	6981	6	6A
0005435082887	6981	7	7A
0005435082883	6981	8	18B
0005435082884	6981	9	20A
0005435082882	6981	10	20C
0005435082885	6981	11	20D
0005435790341	6981	12	21A
0005435790343	6981	13	22A
0005435082787	25994	1	1B
0005435082819	25994	2	2A
0005435082836	25994	3	4C
0005435082838	25994	4	6C
0005435082810	25994	5	19B
0005435082837	25994	6	20B
0005435082818	25994	7	22A
0005435082794	25994	8	23A
0005434214613	9555	1	1C
0005434756958	9555	2	1D
0005434756946	9555	3	1F
0005434214629	9555	4	2A
0005434214682	9555	5	2C
0005434214671	9555	6	2D
0005434756943	9555	7	2F
0005434214559	9555	8	3A
0005434214718	9555	9	3C
0005434756951	9555	10	3D
0005434214621	9555	11	3F
0005434214698	9555	12	4A
0005434756953	9555	13	4C
0005434756948	9555	14	4D
0005434214622	9555	15	4F
0005434214721	9555	16	5A
0005434214449	9555	17	5C
0005434214448	9555	18	5E
0005434214722	9555	19	5F
0005434756960	9555	20	6A
0005434214560	9555	21	6C
0005434756954	9555	22	6D
0005434214810	9555	23	6E
0005434214661	9555	24	6F
0005434756939	9555	25	7A
0005434756964	9555	26	7C
0005434756930	9555	27	7D
0005434214737	9555	28	7E
0005434214553	9555	29	7F
0005434214414	9555	30	8A
0005434214838	9555	31	8C
0005434214596	9555	32	8E
0005434214534	9555	33	8F
0005434214668	9555	34	9A
0005434214597	9555	35	9C
0005434214646	9555	36	9D
0005434214793	9555	37	9E
0005434756932	9555	38	9F
0005434756940	9555	39	10A
0005434756931	9555	40	10C
0005434214809	9555	41	10D
0005434214669	9555	42	10E
0005434756962	9555	43	10F
0005434214586	9555	44	11A
0005434756942	9555	45	11C
0005434214650	9555	46	11D
0005434756952	9555	47	11E
0005434756936	9555	48	11F
0005434756955	9555	49	12A
0005434214706	9555	50	12C
0005434214610	9555	51	12D
0005434214513	9555	52	12E
0005434756941	9555	53	12F
0005434214588	9555	54	13A
0005434756933	9555	55	13C
0005434756956	9555	56	13D
0005434756944	9555	57	13E
0005434756947	9555	58	13F
0005434214519	9555	59	14A
0005434756937	9555	60	14C
0005434756959	9555	61	14D
0005434214609	9555	62	14E
0005434214628	9555	63	14F
0005434214886	9555	64	15A
0005434214887	9555	65	15E
0005434214699	9555	66	15F
0005434214552	9555	67	16A
0005434214587	9555	68	16C
0005434214413	9555	69	16D
0005434214811	9555	70	16E
0005434214592	9555	71	16F
0005434214419	9555	72	17A
0005434214487	9555	73	17C
0005434214740	9555	74	17D
0005434756938	9555	75	17E
0005434756945	9555	76	17F
0005434214528	9555	77	18A
0005434214504	9555	78	18C
0005434756950	9555	79	18E
0005434756963	9555	80	18F
0005434214681	9555	81	19A
0005434756935	9555	82	19C
0005434756934	9555	83	19D
0005434756961	9555	84	19E
0005434756928	9555	85	19F
0005434756957	9555	86	20A
0005434214593	9555	87	20C
0005434214514	9555	88	20D
0005434756949	9555	89	20E
0005434756929	9555	90	20F
0005434756550	28590	1	1A
0005434215044	28590	2	1C
0005434215035	28590	3	1D
0005434756549	28590	4	1F
0005434756449	28590	5	2A
0005434756466	28590	6	2C
0005434215057	28590	7	2D
0005434756494	28590	8	2F
0005434215040	28590	9	3A
0005434756555	28590	10	3C
0005434215048	28590	11	3D
0005434756484	28590	12	3F
0005434756504	28590	13	4A
0005434756451	28590	14	4C
0005434215069	28590	15	4D
0005434756432	28590	16	4E
0005434215062	28590	17	4F
0005434756520	28590	18	5A
0005434756482	28590	19	5C
0005434756389	28590	20	5D
0005434756431	28590	21	5E
0005434756441	28590	22	5F
0005434756413	28590	23	6A
0005434215053	28590	24	6C
0005434756452	28590	25	6D
0005434215068	28590	26	6E
0005434215066	28590	27	6F
0005434215036	28590	28	7A
0005434215061	28590	29	7C
0005434215075	28590	30	7D
0005434215065	28590	31	7E
0005434756444	28590	32	7F
0005434756477	28590	33	8A
0005434756498	28590	34	8C
0005434756390	28590	35	8D
0005434756445	28590	36	8E
0005434756462	28590	37	8F
0005434215045	28590	38	9A
0005434756516	28590	39	9C
0005434756242	28590	40	9D
0005434756483	28590	41	9E
0005434215041	28590	42	9F
0005434215077	28590	43	10A
0005434215042	28590	44	10D
0005434756492	28590	45	10E
0005434215047	28590	46	10F
0005434756463	28590	47	11A
0005434215059	28590	48	11C
0005434215043	28590	49	11D
0005434756450	28590	50	11E
0005434215038	28590	51	11F
0005434215056	28590	52	12A
0005434215031	28590	53	12C
0005434215049	28590	54	12D
0005434215064	28590	55	12E
0005434756415	28590	56	12F
0005434215039	28590	57	13A
0005434756553	28590	58	13C
0005434756465	28590	59	13D
0005434756554	28590	60	13E
0005434215073	28590	61	13F
0005434215058	28590	62	14A
0005434756502	28590	63	14C
0005434756503	28590	64	14D
0005434215067	28590	65	14E
0005434756366	28590	66	14F
0005434756443	28590	67	15A
0005434756581	28590	68	15C
0005434756556	28590	69	15D
0005434215063	28590	70	15E
0005434215037	28590	71	15F
0005434756384	28590	72	16C
0005434215052	28590	73	16D
0005434756515	28590	74	16E
0005434215074	28590	75	16F
0005434215054	28590	76	17A
0005434756440	28590	77	17C
0005434215076	28590	78	17D
0005434215055	28590	79	17E
0005434215046	28590	80	17F
0005434215033	28590	81	18A
0005434215032	28590	82	18C
0005434215071	28590	83	18D
0005434756493	28590	84	18E
0005434215051	28590	85	18F
0005434215050	28590	86	19A
0005434215072	28590	87	19C
0005434756560	28590	88	19D
0005434756539	28590	89	19E
0005434756517	28590	90	19F
0005434215060	28590	91	20A
0005434215030	28590	92	20C
0005434756521	28590	93	20D
0005434215070	28590	94	20F
0005434215034	28590	95	20E
0005435100160	10834	1	1C
0005435100161	10834	2	2C
0005435100159	10834	3	3B
0005435100158	10834	4	7A
0005434760200	10834	5	19C
0005434760201	10834	6	23B
0005435100129	31823	1	5C
0005434760226	31823	2	5D
0005435100136	31823	3	7A
0005434760228	31823	4	18A
0005434760227	31823	5	18B
0005435100137	31823	6	19B
0005434639639	1978	1	1A
0005434639641	1978	2	1B
0005432290673	1978	3	1C
0005434639643	1978	4	1D
0005433202430	1978	5	2A
0005434639635	1978	6	2B
0005434639648	1978	7	2C
0005434639653	1978	8	2D
0005434639644	1978	9	3A
0005434639629	1978	10	3B
0005433202404	1978	11	3C
0005432290671	1978	12	3D
0005433202459	1978	13	4A
0005434639630	1978	14	4B
0005434639651	1978	15	4C
0005433202403	1978	16	4D
0005434639628	1978	17	5A
0005433202429	1978	18	5B
0005433202410	1978	19	5C
0005434639627	1978	20	5D
0005433202415	1978	21	6A
0005433202354	1978	22	6B
0005433202412	1978	23	6C
0005434639631	1978	24	7B
0005433202414	1978	25	7C
0005433202399	1978	26	7D
0005434639640	1978	27	18A
0005434639652	1978	28	18B
0005432290670	1978	29	18D
0005434639634	1978	30	19A
0005434639636	1978	31	19B
0005434639632	1978	32	19C
0005433202411	1978	33	19D
0005434639637	1978	34	20A
0005432290672	1978	35	20B
0005434639647	1978	36	20C
0005434639633	1978	37	20D
0005434639646	1978	38	21A
0005433202458	1978	39	21B
0005434639650	1978	40	21C
0005434639642	1978	41	21D
0005434639649	1978	42	22A
0005434639645	1978	43	22C
0005434639638	1978	44	22D
0005434639654	1978	45	23A
0005433202400	1978	46	23B
0005434639469	23262	1	1B
0005433202526	23262	2	1C
0005433202530	23262	3	2A
0005434639292	23262	4	2B
0005434639363	23262	5	2C
0005434639362	23262	6	2D
0005433202532	23262	7	3A
0005434639273	23262	8	3B
0005433202527	23262	9	3C
0005433202536	23262	10	3D
0005434639444	23262	11	4A
0005434639374	23262	12	4B
0005434639467	23262	13	4C
0005435948329	23262	14	4D
0005434639343	23262	15	5A
0005433202528	23262	16	5B
0005434639468	23262	17	5C
0005433202525	23262	18	5D
0005434639297	23262	19	6A
0005434639445	23262	20	6B
0005434639402	23262	21	6C
0005434639429	23262	22	6D
0005434639293	23262	23	7A
0005434639351	23262	24	7B
0005434639486	23262	25	7C
0005434639373	23262	26	7D
0005434639437	23262	27	18A
0005434639438	23262	28	18B
0005434639470	23262	29	18C
0005433202524	23262	30	18D
0005434639341	23262	31	19A
0005434639491	23262	32	19B
0005433202535	23262	33	19C
0005434639403	23262	34	19D
0005434639404	23262	35	20A
0005433202533	23262	36	20B
0005433202538	23262	37	20C
0005434639272	23262	38	20D
0005434639352	23262	39	21A
0005433202531	23262	40	21B
0005433202539	23262	41	21C
0005433202534	23262	42	21D
0005434639364	23262	43	22A
0005434639295	23262	44	22B
0005434639345	23262	45	22C
0005434639344	23262	46	22D
0005433202529	23262	47	23A
0005433202537	23262	48	23B
0005435326807	6094	1	1C
0005434601132	6094	2	1F
0005434601136	6094	3	2C
0005434601127	6094	4	2D
0005435326842	6094	5	2F
0005435326794	6094	6	3C
0005433531341	6094	7	3F
0005432111315	6094	8	4C
0005434601137	6094	9	4F
0005432111317	6094	10	5A
0005434601138	6094	11	5C
0005435326789	6094	12	5D
0005434601140	6094	13	5E
0005434601147	6094	14	6D
0005435326782	6094	15	6C
0005434601134	6094	16	6E
0005433531338	6094	17	7C
0005434601131	6094	18	7F
0005434601146	6094	19	8E
0005434601143	6094	20	8F
0005435326805	6094	21	9A
0005435326808	6094	22	9C
0005434601149	6094	23	9E
0005434601144	6094	24	9F
0005434601148	6094	25	10A
0005435326776	6094	26	10D
0005435326806	6094	27	10F
0005434601130	6094	28	11C
0005434601150	6094	29	11E
0005434601152	6094	30	13C
0005432111316	6094	31	13F
0005433533354	6094	32	14A
0005434601128	6094	33	14C
0005434601151	6094	34	14D
0005433533355	6094	35	14F
0005434601129	6094	36	15A
0005434601133	6094	37	15C
0005435326747	6094	38	15D
0005433531340	6094	39	15F
0005432111314	6094	40	16A
0005433531339	6094	41	16C
0005434601135	6094	42	16E
0005434601139	6094	43	17A
0005434601145	6094	44	18A
0005434601153	6094	45	18C
0005435326760	6094	46	18D
0005433533356	6094	47	19A
0005434601142	6094	48	20C
0005434601141	6094	49	20F
0005435326910	18595	1	1A
0005434600947	18595	2	1F
0005434600987	18595	3	2C
0005433531310	18595	4	3C
0005434600949	18595	5	3D
0005433531307	18595	6	4A
0005433527265	18595	7	4E
0005434600962	18595	8	5A
0005433527274	18595	9	5D
0005434600880	18595	10	5F
0005435326919	18595	11	6A
0005434600950	18595	12	6C
0005433531294	18595	13	6D
0005434601009	18595	14	6E
0005434600899	18595	15	7A
0005434600871	18595	16	7D
0005434600960	18595	17	7F
0005433527276	18595	18	8A
0005433527273	18595	19	8F
0005435326914	18595	20	9A
0005435326918	18595	21	9C
0005433531300	18595	22	9D
0005434600911	18595	23	9F
0005433527268	18595	24	10D
0005434600923	18595	25	11A
0005435326912	18595	26	11D
0005434600856	18595	27	12D
0005433531299	18595	28	12E
0005435326908	18595	29	12F
0005433527275	18595	30	13A
0005435326916	18595	31	13C
0005435326911	18595	32	13D
0005435326921	18595	33	13E
0005434600877	18595	34	13F
0005434600955	18595	35	14D
0005434600853	18595	36	15A
0005435326917	18595	37	15C
0005434600824	18595	38	15D
0005433531298	18595	39	15E
0005435326909	18595	40	16A
0005435326920	18595	41	16E
0005435326913	18595	42	17A
0005434600946	18595	43	17D
0005434600823	18595	44	17E
0005433531309	18595	45	18E
0005435326915	18595	46	18F
0005434600890	18595	47	19D
0005434600921	18595	48	19E
0005434600954	18595	49	19F
0005434600983	18595	50	20A
0005434600961	18595	51	20D
0005433181170	10645	1	1A
0005433181196	10645	2	1C
0005434551824	10645	3	1D
0005434558367	10645	4	1F
0005434558374	10645	5	2A
0005433181098	10645	6	2C
0005434551874	10645	7	2D
0005434551873	10645	8	2F
0005434551833	10645	9	3A
0005434551880	10645	10	3C
0005433181143	10645	11	3D
0005434551844	10645	12	3F
0005434551856	10645	13	4A
0005434558365	10645	14	4C
0005433181099	10645	15	4E
0005434551834	10645	16	4F
0005434551857	10645	17	5A
0005433181144	10645	18	5C
0005434551835	10645	19	5D
0005434558372	10645	20	5E
0005433181092	10645	21	5F
0005434551863	10645	22	6A
0005434551827	10645	23	6C
0005434558370	10645	24	6D
0005434551826	10645	25	6E
0005433181199	10645	26	6F
0005434551869	10645	27	7A
0005434551853	10645	28	7C
0005434551838	10645	29	7D
0005434558375	10645	30	7E
0005434551852	10645	31	7F
0005434551850	10645	32	8A
0005433181185	10645	33	8C
0005434551855	10645	34	8D
0005433181184	10645	35	8E
0005434558373	10645	36	8F
0005434551860	10645	37	9A
0005434551845	10645	38	9C
0005434551859	10645	39	9D
0005434551832	10645	40	9E
0005434551829	10645	41	9F
0005434551849	10645	42	10A
0005433181093	10645	43	10C
0005434551878	10645	44	10D
0005434551839	10645	45	10F
0005434551851	10645	46	11A
0005434551842	10645	47	11C
0005433181195	10645	48	11E
0005434551879	10645	49	11F
0005434551837	10645	50	12A
0005433181194	10645	51	12C
0005434551871	10645	52	12D
0005434558371	10645	53	12E
0005433181205	10645	54	12F
0005433181245	10645	55	13A
0005434551841	10645	56	13C
0005434551830	10645	57	13D
0005434551836	10645	58	13E
0005434551868	10645	59	14A
0005434551872	10645	60	13F
0005434554087	10645	61	14C
0005433181078	10645	62	14D
0005433181213	10645	63	14E
0005434551862	10645	64	14F
0005434551864	10645	65	15A
0005434551858	10645	66	15C
0005433181064	10645	67	15D
0005433181237	10645	68	15E
0005433181161	10645	69	15F
0005434551843	10645	70	16A
0005434558369	10645	71	16C
0005433181127	10645	72	16D
0005434551840	10645	73	16E
0005434551870	10645	74	16F
0005434551865	10645	75	17A
0005434551867	10645	76	17C
0005433181193	10645	77	17D
0005434551866	10645	78	17E
0005434551847	10645	79	17F
0005434551854	10645	80	18A
0005434551828	10645	81	18C
0005434558366	10645	82	18D
0005434551825	10645	83	18E
0005434551877	10645	84	18F
0005434551876	10645	85	19A
0005434558368	10645	86	19C
0005434551861	10645	87	19D
0005434551848	10645	88	19E
0005434551846	10645	89	19F
0005434551875	10645	90	20A
0005433181244	10645	91	20C
0005434554088	10645	92	20D
0005434551831	10645	93	20F
0005433181401	27764	1	1D
0005433181406	27764	2	2A
0005433181414	27764	3	4C
0005433181422	27764	4	4E
0005433181416	27764	5	5F
0005433181409	27764	6	6D
0005433181399	27764	7	7A
0005433181411	27764	8	7C
0005433181400	27764	9	7E
0005433181403	27764	10	7F
0005433181407	27764	11	8C
0005433181404	27764	12	8E
0005433181423	27764	13	9D
0005433181420	27764	14	10A
0005433181405	27764	15	10F
0005433181424	27764	16	11D
0005433181419	27764	17	14F
0005433181415	27764	18	15D
0005433181413	27764	19	16A
0005433181417	27764	20	16E
0005433181418	27764	21	16F
0005433181421	27764	22	17C
0005433181410	27764	23	17D
0005433181412	27764	24	19C
0005433181408	27764	25	20C
0005433181402	27764	26	20E
0005434551370	27763	1	1A
0005434551375	27763	2	1C
0005434558296	27763	3	1D
0005434551476	27763	4	1F
0005434551580	27763	5	2A
0005434551245	27763	6	2C
0005434551349	27763	7	2D
0005434551789	27763	8	3A
0005434551361	27763	9	3C
0005434558314	27763	10	3D
0005434551558	27763	11	3F
0005434551385	27763	12	4E
0005434551430	27763	13	4F
0005434551230	27763	14	5A
0005434551405	27763	15	5F
0005434551631	27763	16	6A
0005434551537	27763	17	6D
0005434551532	27763	18	6F
0005434551424	27763	19	7A
0005434551333	27763	20	7C
0005434554073	27763	21	7D
0005434551791	27763	22	8A
0005434551344	27763	23	8C
0005434551545	27763	24	8E
0005434551577	27763	25	8F
0005434551597	27763	26	9C
0005434551790	27763	27	9E
0005434551579	27763	28	9F
0005434551299	27763	29	10A
0005434551589	27763	30	10C
0005434551374	27763	31	10D
0005434554064	27763	32	10E
0005434551578	27763	33	10F
0005434551271	27763	34	11A
0005434551298	27763	35	11D
0005434551356	27763	36	11E
0005434551392	27763	37	12A
0005434551566	27763	38	12D
0005434551450	27763	39	12E
0005434554072	27763	40	12F
0005434551485	27763	41	13A
0005434551496	27763	42	13C
0005434551369	27763	43	13D
0005434551400	27763	44	13E
0005434551677	27763	45	13F
0005434551491	27763	46	14C
0005434551531	27763	47	14D
0005434551595	27763	48	14F
0005434551588	27763	49	15A
0005434551484	27763	50	15D
0005434551671	27763	51	15E
0005434551477	27763	52	15F
0005434554063	27763	53	16A
0005434551454	27763	54	16E
0005434551598	27763	55	16F
0005434554071	27763	56	17C
0005434551203	27763	57	17D
0005434551490	27763	58	17E
0005434551676	27763	59	17F
0005434551380	27763	60	18A
0005434551591	27763	61	18C
0005434551306	27763	62	18D
0005434551357	27763	63	19C
0005434551307	27763	64	19D
0005434551423	27763	65	19F
0005434551451	27763	66	20A
0005434551246	27763	67	20C
0005434551584	27763	68	20D
0005434551112	27763	69	20E
0005433459271	6132	1	1A
0005433459272	6132	2	2A
0005435254487	6132	3	4B
0005433459269	6132	4	4A
0005435254486	6132	5	5B
0005433459270	6132	6	6B
0005433459273	6132	7	6A
0005433459229	19341	1	1A
0005435254502	19341	2	1B
0005433459237	19341	3	2A
0005433459236	19341	4	2B
0005433459240	19341	5	3B
0005435254504	19341	6	4B
0005435254503	19341	7	6B
0005435682626	6729	1	1A
0005432136231	6729	2	1D
0005434828709	6729	3	1F
0005435221519	6729	4	2A
0005435682609	6729	5	2C
0005434828710	6729	6	2D
0005432136228	6729	7	2F
0005435682624	6729	8	3A
0005435631003	6729	9	3C
0005435438108	6729	10	3D
0005435682630	6729	11	3F
0005435437978	6729	12	4A
0005435438034	6729	13	4C
0005435438074	6729	14	4D
0005435682618	6729	15	4E
0005432533300	6729	16	4F
0005435682620	6729	17	5A
0005432136230	6729	18	5C
0005435682621	6729	19	5D
0005435682629	6729	20	5E
0005435682638	6729	21	5F
0005435682636	6729	22	6A
0005435682633	6729	23	6D
0005434828711	6729	24	6E
0005435682616	6729	25	6F
0005434828699	6729	26	7A
0005435631002	6729	27	7C
0005434828708	6729	28	7D
0005435438148	6729	29	7E
0005435437976	6729	30	7F
0005435438098	6729	31	8A
0005435438001	6729	32	8C
0005432533302	6729	33	8D
0005435631001	6729	34	8E
0005435438106	6729	35	9A
0005435682606	6729	36	9C
0005435682637	6729	37	9D
0005435682625	6729	38	9E
0005435438097	6729	39	9F
0005435682635	6729	40	10A
0005435682628	6729	41	10C
0005435217721	6729	42	10D
0005434828698	6729	43	10E
0005432136229	6729	44	10F
0005435438095	6729	45	11C
0005435437972	6729	46	11D
0005435682608	6729	47	11E
0005435682614	6729	48	11F
0005435438056	6729	49	12A
0005435221521	6729	50	12C
0005435661965	6729	51	12D
0005434828712	6729	52	12E
0005435631000	6729	53	12F
0005435438054	6729	54	13A
0005435438096	6729	55	13C
0005435661964	6729	56	13D
0005435438094	6729	57	13E
0005435682607	6729	58	14A
0005435682631	6729	59	14C
0005435220323	6729	60	14D
0005435438059	6729	61	14E
0005435682617	6729	62	14F
0005435438051	6729	63	15A
0005432533312	6729	64	15C
0005432533299	6729	65	15D
0005435682627	6729	66	15F
0005435682615	6729	67	16A
0005435682610	6729	68	16F
0005435682632	6729	69	17A
0005435682622	6729	70	17C
0005435438067	6729	71	17D
0005432136227	6729	72	17E
0005435438052	6729	73	17F
0005435438066	6729	74	18A
0005435682613	6729	75	18C
0005435438107	6729	76	18D
0005435221520	6729	77	18E
0005435682634	6729	78	18F
0005435437991	6729	79	19A
0005435682612	6729	80	19C
0005435220330	6729	81	19D
0005435437977	6729	82	19E
0005435682619	6729	83	19F
0005435438000	6729	84	20A
0005432533301	6729	85	20C
0005435682623	6729	86	20D
0005435682611	6729	87	20E
0005435220319	6729	88	20F
0005435438222	24619	1	1A
0005435682374	24619	2	1C
0005435438225	24619	3	1D
0005435682349	24619	4	1F
0005435682184	24619	5	2C
0005435219221	24619	6	2D
0005435682246	24619	7	3A
0005435682328	24619	8	3D
0005435438232	24619	9	3F
0005435438233	24619	10	4A
0005435438227	24619	11	4C
0005432533327	24619	12	4D
0005435438219	24619	13	4E
0005435438213	24619	14	4F
0005435682375	24619	15	5A
0005435682161	24619	16	5C
0005435682257	24619	17	5E
0005435438220	24619	18	5F
0005435682345	24619	19	6A
0005435682031	24619	20	6C
0005435682160	24619	21	6D
0005435438223	24619	22	6E
0005435630964	24619	23	6F
0005435682329	24619	24	7A
0005434828733	24619	25	7C
0005435682218	24619	26	7D
0005435682159	24619	27	7E
0005432305779	24619	28	8A
0005435219226	24619	29	8C
0005432533328	24619	30	8D
0005435682212	24619	31	8E
0005435682360	24619	32	8F
0005435220341	24619	33	9C
0005435219225	24619	34	9D
0005435682341	24619	35	9E
0005435438212	24619	36	9F
0005435682226	24619	37	10A
0005435220343	24619	38	10C
0005435438216	24619	39	10D
0005435682433	24619	40	10E
0005435682314	24619	41	10F
0005435219222	24619	42	11A
0005435220345	24619	43	11C
0005435682209	24619	44	11E
0005435438226	24619	45	11F
0005435682340	24619	46	12A
0005435438228	24619	47	12C
0005435682245	24619	48	12D
0005432305778	24619	49	12E
0005435682193	24619	50	12F
0005435438231	24619	51	13A
0005435438214	24619	52	13D
0005435682420	24619	53	13E
0005435682342	24619	54	13F
0005435682227	24619	55	14A
0005435438217	24619	56	14C
0005435682291	24619	57	14F
0005435219224	24619	58	15A
0005435682376	24619	59	15D
0005435438215	24619	60	15E
0005435438224	24619	61	16C
0005434828731	24619	62	16D
0005435682214	24619	63	16F
0005434828732	24619	64	17A
0005435682213	24619	65	17C
0005435438229	24619	66	17E
0005435220340	24619	67	17D
0005435682258	24619	68	18A
0005435438221	24619	69	18C
0005435682210	24619	70	18D
0005435682229	24619	71	18E
0005435682231	24619	72	18F
0005435220344	24619	73	19A
0005435682347	24619	74	19C
0005435438218	24619	75	19D
0005435219223	24619	76	19E
0005435438211	24619	77	19F
0005435682346	24619	78	20A
0005435220342	24619	79	20C
0005435438230	24619	80	20D
0005435682292	24619	81	20E
0005435630963	24619	82	20F
0005435126828	11528	1	1F
0005435126848	11528	2	2A
0005435126850	11528	3	2F
0005435106019	11528	4	3A
0005435126821	11528	5	3D
0005435106021	11528	6	4C
0005435126833	11528	7	4F
0005435098582	11528	8	5A
0005435106020	11528	9	5C
0005435126849	11528	10	5D
0005435126813	11528	11	6C
0005435126822	11528	12	6D
0005435126820	11528	13	6E
0005435126851	11528	14	6F
0005435126814	11528	15	7A
0005435098576	11528	16	7D
0005435098579	11528	17	8A
0005435098578	11528	18	8D
0005435126831	11528	19	8C
0005435126846	11528	20	8E
0005435126824	11528	21	8F
0005435126834	11528	22	9A
0005435098577	11528	23	9C
0005435126847	11528	24	9D
0005435126827	11528	25	9E
0005435126854	11528	26	9F
0005435126816	11528	27	10D
0005435126830	11528	28	10E
0005435126841	11528	29	11A
0005435126826	11528	30	11C
0005435126843	11528	31	11D
0005435558099	11528	32	12C
0005435126815	11528	33	12D
0005435558100	11528	34	12E
0005435126818	11528	35	12F
0005435106017	11528	36	13C
0005435098581	11528	37	14A
0005435126839	11528	38	14D
0005435126835	11528	39	14E
0005435098580	11528	40	14F
0005435126838	11528	41	15A
0005435126817	11528	42	15C
0005435126825	11528	43	16A
0005435126842	11528	44	16C
0005435126853	11528	45	17A
0005435126829	11528	46	17E
0005435126840	11528	47	17F
0005435106018	11528	48	18A
0005435126836	11528	49	18C
0005435126852	11528	50	18D
0005435126819	11528	51	18E
0005435126823	11528	52	18F
0005435126832	11528	53	19D
0005435126844	11528	54	19E
0005435126837	11528	55	19F
0005435126845	11528	56	20A
0005435126398	31894	1	1A
0005435126376	31894	2	2A
0005435126544	31894	3	2D
0005435558120	31894	4	2F
0005435126723	31894	5	3A
0005435126425	31894	6	3C
0005435126557	31894	7	3F
0005435126583	31894	8	4A
0005435126465	31894	9	5D
0005435105995	31894	10	5E
0005435126575	31894	11	6A
0005435126523	31894	12	6C
0005435126577	31894	13	6D
0005435126598	31894	14	6E
0005435126430	31894	15	6F
0005435126479	31894	16	7D
0005435126571	31894	17	7E
0005435558119	31894	18	8A
0005435126553	31894	19	8D
0005435126530	31894	20	8E
0005435126503	31894	21	9A
0005435126412	31894	22	9E
0005435126399	31894	23	9F
0005435558118	31894	24	10A
0005435126631	31894	25	10D
0005435126461	31894	26	10E
0005435126570	31894	27	10F
0005435126552	31894	28	11A
0005435126525	31894	29	12A
0005435126444	31894	30	12E
0005435126732	31894	31	12F
0005435126699	31894	32	13C
0005435126374	31894	33	13F
0005435126480	31894	34	14C
0005435126509	31894	35	14E
0005435126462	31894	36	14F
0005435126558	31894	37	15C
0005435126413	31894	38	15D
0005435126373	31894	39	17A
0005435126386	31894	40	17E
0005435126429	31894	41	18A
0005435126490	31894	42	18E
0005435126524	31894	43	18F
0005435105977	31894	44	19A
0005435126491	31894	45	19D
0005435126426	31894	46	19E
0005435126599	31894	47	19F
0005435126387	31894	48	20D
0005435126578	31894	49	20E
0005435126464	31894	50	20F
0005435732365	13538	1	1A
0005433398636	13538	2	1C
0005433398645	13538	3	1F
0005433398628	13538	4	2A
0005433398666	13538	5	2C
0005433398634	13538	6	2F
0005433398663	13538	7	3A
0005433398659	13538	8	3D
0005433398633	13538	9	4D
0005435732391	13538	10	4E
0005435732343	13538	11	4F
0005433398638	13538	12	5A
0005433398640	13538	13	5D
0005433398650	13538	14	5E
0005433398660	13538	15	5F
0005433398649	13538	16	7A
0005433398627	13538	17	6F
0005435732368	13538	18	7F
0005433398639	13538	19	8C
0005433398622	13538	20	8D
0005435732397	13538	21	8E
0005433398655	13538	22	8F
0005435732386	13538	23	9A
0005433398624	13538	24	9C
0005433398654	13538	25	9D
0005433398658	13538	26	10A
0005433398652	13538	27	10C
0005433398665	13538	28	10D
0005433398641	13538	29	10F
0005433398653	13538	30	11C
0005433398664	13538	31	11D
0005433398644	13538	32	11E
0005433398631	13538	33	11F
0005433398632	13538	34	12C
0005435732416	13538	35	12D
0005433398635	13538	36	12E
0005433398661	13538	37	13A
0005433398667	13538	38	13C
0005435732351	13538	39	13F
0005433398669	13538	40	14C
0005433398625	13538	41	14D
0005433398637	13538	42	14E
0005433398643	13538	43	14F
0005433398647	13538	44	15C
0005433398629	13538	45	15F
0005433398630	13538	46	16C
0005433398623	13538	47	16E
0005433398642	13538	48	16F
0005433398668	13538	49	17A
0005435732355	13538	50	17C
0005433398662	13538	51	17E
0005435732390	13538	52	17F
0005433398626	13538	53	18C
0005435732398	13538	54	18D
0005433398648	13538	55	18E
0005433398656	13538	56	19E
0005433398651	13538	57	20A
0005433398646	13538	58	20C
0005433398657	13538	59	20F
0005433398145	19386	1	1A
0005433398218	19386	2	1D
0005433398077	19386	3	1F
0005433398380	19386	4	2A
0005432297309	19386	5	2C
0005433398287	19386	6	2D
0005433398078	19386	7	3A
0005433398061	19386	8	3C
0005433398315	19386	9	3D
0005433398375	19386	10	3F
0005433398332	19386	11	4A
0005433398376	19386	12	4C
0005433398264	19386	13	4D
0005433398107	19386	14	4E
0005433398295	19386	15	4F
0005433398316	19386	16	5A
0005433398369	19386	17	5E
0005433398106	19386	18	5F
0005433398137	19386	19	6A
0005433398039	19386	20	6D
0005433398053	19386	21	6E
0005433398139	19386	22	7A
0005433398052	19386	23	7C
0005433398359	19386	24	7D
0005433398138	19386	25	7E
0005433398277	19386	26	7F
0005433398281	19386	27	8A
0005433398212	19386	28	8C
0005433398150	19386	29	8D
0005433398263	19386	30	8E
0005433398279	19386	31	8F
0005433398070	19386	32	9A
0005433398299	19386	33	9C
0005433398164	19386	34	9D
0005433398118	19386	35	9E
0005433398223	19386	36	9F
0005433398066	19386	37	10A
0005433398246	19386	38	10D
0005433398374	19386	39	10E
0005433398043	19386	40	10F
0005433398177	19386	41	11A
0005433398051	19386	42	11D
0005433398383	19386	43	11F
0005433398100	19386	44	12C
0005433398068	19386	45	12D
0005433398062	19386	46	13A
0005433398141	19386	47	13C
0005433398297	19386	48	13D
0005433398213	19386	49	13E
0005432297308	19386	50	13F
0005433398346	19386	51	14A
0005433398379	19386	52	14C
0005433398360	19386	53	14D
0005433398345	19386	54	15D
0005433398333	19386	55	15F
0005433398291	19386	56	16A
0005433398373	19386	57	16C
0005433398217	19386	58	16D
0005432297310	19386	59	16E
0005433398187	19386	60	16F
0005433398298	19386	61	17A
0005433398149	19386	62	17C
0005433398178	19386	63	17D
0005433398099	19386	64	17E
0005433398140	19386	65	17F
0005433398069	19386	66	18D
0005433398412	19386	67	18E
0005433398293	19386	68	18F
0005433398163	19386	69	19A
0005433398382	19386	70	19C
0005433398294	19386	71	19F
0005433398222	19386	72	20A
0005433398241	19386	73	20C
0005433398361	19386	74	20E
0005433398424	19386	75	20F
0005435069239	13161	1	1A
0005435925466	13161	2	1C
0005435069112	13161	3	1D
0005435069171	13161	4	1F
0005435925465	13161	5	2C
0005435069206	13161	6	2F
0005435069182	13161	7	3A
0005435069086	13161	8	3F
0005435069134	13161	9	4A
0005435069052	13161	10	4C
0005435069180	13161	11	4D
0005435069242	13161	12	5C
0005435069056	13161	13	5D
0005435069146	13161	14	5E
0005435069262	13161	15	5F
0005435069287	13161	16	6A
0005435069255	13161	17	6C
0005435925464	13161	18	6D
0005435925462	13161	19	6F
0005435068955	13161	20	7A
0005435069059	13161	21	7C
0005435069046	13161	22	7D
0005435069024	13161	23	7E
0005435069148	13161	24	7F
0005435069065	13161	25	8C
0005435069260	13161	26	8E
0005435069195	13161	27	8F
0005435069178	13161	28	9A
0005435069308	13161	29	9C
0005435069181	13161	30	9D
0005435925467	13161	31	10A
0005435069250	13161	32	10C
0005435069305	13161	33	10E
0005435069237	13161	34	10F
0005435069090	13161	35	11F
0005435069053	13161	36	12A
0005435069322	13161	37	12D
0005435068976	13161	38	12F
0005435069240	13161	39	13C
0005435069185	13161	40	13D
0005435069091	13161	41	13F
0005435069089	13161	42	14D
0005435069177	13161	43	14E
0005435069155	13161	44	15A
0005435069184	13161	45	15C
0005435069025	13161	46	15E
0005435069213	13161	47	15F
0005435069228	13161	48	16A
0005435069201	13161	49	16C
0005435069124	13161	50	16D
0005435069118	13161	51	17C
0005435069051	13161	52	17D
0005435069064	13161	53	17E
0005435069238	13161	54	18A
0005435069079	13161	55	18D
0005435069202	13161	56	19A
0005435069219	13161	57	19C
0005435069261	13161	58	19D
0005435069194	13161	59	20A
0005435925463	13161	60	20C
0005435069252	13161	61	20D
0005435069243	13161	62	20E
0005435069113	13161	63	20F
0005435069686	15496	1	1A
0005435069661	15496	2	1C
0005435925310	15496	3	1D
0005435069675	15496	4	1F
0005435069670	15496	5	2D
0005435069664	15496	6	2C
0005435069643	15496	7	2F
0005435069682	15496	8	3C
0005435069651	15496	9	3D
0005435069656	15496	10	4D
0005435069648	15496	11	5A
0005435069662	15496	12	5C
0005435925348	15496	13	5E
0005435069685	15496	14	5F
0005435069690	15496	15	6A
0005435925322	15496	16	6E
0005435069669	15496	17	7A
0005435069657	15496	18	7C
0005435069671	15496	19	8A
0005435069687	15496	20	8D
0005435069693	15496	21	8F
0005435069645	15496	22	9F
0005435069659	15496	23	10A
0005435069650	15496	24	10C
0005435069679	15496	25	10E
0005435069680	15496	26	10F
0005435069668	15496	27	11A
0005435069652	15496	28	11C
0005435069660	15496	29	11D
0005435069654	15496	30	11E
0005435069674	15496	31	12C
0005435069655	15496	32	12D
0005435069666	15496	33	12E
0005435925294	15496	34	12F
0005435069649	15496	35	13A
0005435069665	15496	36	13C
0005435069667	15496	37	13D
0005435069653	15496	38	13E
0005435069673	15496	39	13F
0005435069694	15496	40	15D
0005435069658	15496	41	15E
0005435069681	15496	42	16A
0005435069691	15496	43	16C
0005435069663	15496	44	16F
0005435069677	15496	45	17D
0005435925377	15496	46	17F
0005435069689	15496	47	18C
0005435069672	15496	48	18D
0005435069688	15496	49	18E
0005435069683	15496	50	18F
0005435069647	15496	51	19A
0005435069676	15496	52	19C
0005435925293	15496	53	19D
0005435069646	15496	54	19F
0005435069684	15496	55	20A
0005435069644	15496	56	20C
0005435069692	15496	57	20D
0005435069678	15496	58	20F
0005435808350	23176	1	1A
0005435808340	23176	2	1B
0005435808343	23176	3	1D
0005435808345	23176	4	2A
0005433407580	23176	5	2B
0005435808348	23176	6	2C
0005435808351	23176	7	2D
0005433407564	23176	8	3B
0005433407578	23176	9	3D
0005433407555	23176	10	4A
0005435808346	23176	11	4B
0005433407586	23176	12	4C
0005435808341	23176	13	4D
0005433407573	23176	14	5A
0005433407585	23176	15	5B
0005435808359	23176	16	5C
0005433407574	23176	17	5D
0005433407581	23176	18	6A
0005435808358	23176	19	6B
0005435808347	23176	20	6C
0005435808349	23176	21	6D
0005433407577	23176	22	7B
0005435808342	23176	23	7C
0005433407584	23176	24	7D
0005435808339	23176	25	18C
0005435808355	23176	26	18D
0005433407537	23176	27	19B
0005435808352	23176	28	19D
0005435808357	23176	29	20A
0005435808354	23176	30	21B
0005433407572	23176	31	21C
0005435808356	23176	32	21D
0005433407579	23176	33	22A
0005435808337	23176	34	22B
0005435808344	23176	35	22D
0005435808353	23176	36	22C
0005435808338	23176	37	23A
0005434215089	10685	1	1A
0005434756461	10685	2	1C
0005434756500	10685	3	1D
0005434756510	10685	4	1F
0005434215080	10685	5	2A
0005434215086	10685	6	2C
0005434756664	10685	7	2D
0005434215093	10685	8	2F
0005434215099	10685	9	3A
0005434215125	10685	10	3C
0005434215106	10685	11	3D
0005434215120	10685	12	3F
0005434756448	10685	13	4A
0005434215091	10685	14	4C
0005434215083	10685	15	4E
0005434756565	10685	16	4F
0005434215107	10685	17	5A
0005434215114	10685	18	5D
0005434756428	10685	19	5E
0005434756772	10685	20	5F
0005434215094	10685	21	6A
0005434215098	10685	22	6D
0005434756507	10685	23	6E
0005434215102	10685	24	6F
0005434756580	10685	25	7A
0005434215116	10685	26	7C
0005434215112	10685	27	7D
0005434756501	10685	28	7E
0005434756606	10685	29	7F
0005434215103	10685	30	8C
0005434215117	10685	31	8D
0005434756491	10685	32	8E
0005434215113	10685	33	8F
0005434215079	10685	34	9A
0005434215101	10685	35	9D
0005434215084	10685	36	9E
0005434756495	10685	37	9F
0005434215118	10685	38	10A
0005434756479	10685	39	10C
0005434756508	10685	40	10D
0005434756608	10685	41	10E
0005434756429	10685	42	11A
0005434215111	10685	43	11C
0005434756588	10685	44	11D
0005434215119	10685	45	11E
0005434215121	10685	46	11F
0005434756620	10685	47	12A
0005434215078	10685	48	12C
0005434215108	10685	49	12D
0005434215110	10685	50	12E
0005434215092	10685	51	13A
0005434215096	10685	52	13C
0005434215082	10685	53	13D
0005434215105	10685	54	13E
0005434756547	10685	55	14A
0005434215123	10685	56	14C
0005434756559	10685	57	14D
0005434215097	10685	58	14E
0005434215122	10685	59	14F
0005434756592	10685	60	15A
0005434215087	10685	61	15C
0005434215104	10685	62	15E
0005434215115	10685	63	15F
0005434215095	10685	64	16A
0005434756490	10685	65	16C
0005434215100	10685	66	16E
0005434756480	10685	67	16F
0005434756601	10685	68	17A
0005434756489	10685	69	17C
0005434215109	10685	70	17D
0005434756388	10685	71	17E
0005434215085	10685	72	18A
0005434756771	10685	73	18C
0005434215090	10685	74	18E
0005434215088	10685	75	18F
0005434756396	10685	76	19C
0005434215124	10685	77	19D
0005434756587	10685	78	20A
0005434756558	10685	79	20D
0005434756566	10685	80	20E
0005434215081	10685	81	20F
0005434214486	28650	1	1A
0005434214777	28650	2	1C
0005434756893	28650	3	1D
0005434756907	28650	4	1F
0005434214764	28650	5	2A
0005434756920	28650	6	2C
0005434214625	28650	7	2F
0005434756904	28650	8	3A
0005434756913	28650	9	3C
0005434214372	28650	10	3D
0005434756919	28650	11	3F
0005434756890	28650	12	4A
0005434214704	28650	13	4C
0005434214720	28650	14	4D
0005434214521	28650	15	4E
0005434214551	28650	16	4F
0005434214703	28650	17	5A
0005434214765	28650	18	5C
0005434756916	28650	19	5D
0005434756884	28650	20	5E
0005434214520	28650	21	5F
0005434756892	28650	22	6A
0005434214501	28650	23	6C
0005434756925	28650	24	6D
0005434214427	28650	25	6E
0005434756908	28650	26	6F
0005434756914	28650	27	7A
0005434214506	28650	28	7C
0005434756902	28650	29	7D
0005434214709	28650	30	7E
0005434214535	28650	31	7F
0005434214380	28650	32	8C
0005434756898	28650	33	8D
0005434756911	28650	34	8F
0005434214580	28650	35	9A
0005434214602	28650	36	9C
0005434756888	28650	37	9D
0005434214806	28650	38	9E
0005434756915	28650	39	9F
0005434214719	28650	40	10A
0005434214655	28650	41	10C
0005434214741	28650	42	10D
0005434214723	28650	43	10E
0005434756906	28650	44	10F
0005434214631	28650	45	11A
0005434756922	28650	46	11C
0005434756903	28650	47	11D
0005434756881	28650	48	11E
0005434756924	28650	49	11F
0005434214581	28650	50	12A
0005434214485	28650	51	12C
0005434214624	28650	52	12D
0005434214705	28650	53	12E
0005434214686	28650	54	12F
0005434214652	28650	55	13A
0005434756912	28650	56	13C
0005434756926	28650	57	13D
0005434756900	28650	58	13E
0005434756886	28650	59	13F
0005434214507	28650	60	14A
0005434756896	28650	61	14C
0005434214775	28650	62	14D
0005434214493	28650	63	14E
0005434756889	28650	64	14F
0005434214484	28650	65	15A
0005434756895	28650	66	15C
0005434214632	28650	67	15D
0005434214502	28650	68	15E
0005434756883	28650	69	15F
0005434214436	28650	70	16A
0005434756899	28650	71	16C
0005434756905	28650	72	16D
0005434756897	28650	73	16E
0005434756894	28650	74	16F
0005434756921	28650	75	17A
0005434756927	28650	76	17C
0005434214600	28650	77	17D
0005434214710	28650	78	17E
0005434756885	28650	79	17F
0005434214601	28650	80	18A
0005434756882	28650	81	18C
0005434756891	28650	82	18D
0005434756887	28650	83	18E
0005434214714	28650	84	18F
0005434214585	28650	85	19A
0005434214744	28650	86	19C
0005434756923	28650	87	19D
0005434756901	28650	88	19E
0005434756917	28650	89	19F
0005434756910	28650	90	20A
0005434756909	28650	91	20C
0005434214724	28650	92	20D
0005434214745	28650	93	20E
0005434756918	28650	94	20F
0005435007328	5468	1	1A
0005434229339	5468	2	1C
0005435040544	5468	3	1D
0005432125543	5468	4	2A
0005435040556	5468	5	1F
0005435040575	5468	6	2C
0005435007304	5468	7	2D
0005435040531	5468	8	2F
0005435007319	5468	9	3A
0005435377904	5468	10	3D
0005435040526	5468	11	4A
0005435040539	5468	12	3F
0005435007320	5468	13	4B
0005435040552	5468	14	4C
0005435040567	5468	15	4D
0005435040568	5468	16	4E
0005434229491	5468	17	5A
0005434229419	5468	18	4F
0005435040557	5468	19	5B
0005435007305	5468	20	5C
0005435040555	5468	21	5D
0005435040566	5468	22	5E
0005435040574	5468	23	6A
0005435040583	5468	24	5F
0005435040521	5468	25	6B
0005434229584	5468	26	6C
0005434229451	5468	27	6F
0005432125539	5468	28	7B
0005435040543	5468	29	7C
0005434229466	5468	30	7D
0005435040530	5468	31	7E
0005435040564	5468	32	8A
0005435040541	5468	33	7F
0005432125540	5468	34	8B
0005435040565	5468	35	8C
0005435040582	5468	36	8E
0005435040540	5468	37	8D
0005435040576	5468	38	8F
0005435007318	5468	39	9B
0005435040525	5468	40	9D
0005435007327	5468	41	9C
0005435040553	5468	42	9F
0005435040581	5468	43	9E
0005435007316	5468	44	10B
0005435040559	5468	45	10D
0005435040561	5468	46	10C
0005435040548	5468	47	10E
0005435007326	5468	48	11A
0005435040533	5468	49	11B
0005435007312	5468	50	11C
0005435040580	5468	51	11D
0005435040570	5468	52	11E
0005435040536	5468	53	12A
0005435040546	5468	54	12C
0005435007317	5468	55	12E
0005434229477	5468	56	12D
0005434229406	5468	57	12F
0005435040579	5468	58	13B
0005435040578	5468	59	13A
0005435007314	5468	60	13C
0005435042884	5468	61	13D
0005435040563	5468	62	13E
0005435007306	5468	63	13F
0005435007315	5468	64	14B
0005435040537	5468	65	14A
0005435040551	5468	66	14D
0005435040584	5468	67	14C
0005435040535	5468	68	14E
0005435040545	5468	69	14F
0005435040532	5468	70	15B
0005435040527	5468	71	15A
0005435007325	5468	72	15C
0005435007309	5468	73	15D
0005435040517	5468	74	15E
0005434229476	5468	75	16A
0005435040524	5468	76	15F
0005435040549	5468	77	16B
0005432125542	5468	78	16C
0005434229465	5468	79	16E
0005435007313	5468	80	17A
0005435007322	5468	81	16F
0005435040522	5468	82	17B
0005434229449	5468	83	17D
0005434229486	5468	84	17C
0005432125541	5468	85	17F
0005435377905	5468	86	18C
0005435040573	5468	87	18D
0005432125544	5468	88	18F
0005435007308	5468	89	18E
0005435007323	5468	90	19A
0005435040571	5468	91	19B
0005435040519	5468	92	19E
0005435040554	5468	93	19F
0005435040569	5468	94	20B
0005435040558	5468	95	20D
0005435007321	5468	96	20C
0005435040562	5468	97	20E
0005435040560	5468	98	20F
0005435007324	5468	99	21B
0005434229433	5468	100	21A
0005435040547	5468	101	21C
0005435040529	5468	102	21D
0005435040550	5468	103	21E
0005435040542	5468	104	22A
0005435040528	5468	105	21F
0005435040518	5468	106	22B
0005435040520	5468	107	22C
0005435040577	5468	108	22D
0005435007310	5468	109	22F
0005435040534	5468	110	22E
0005435007311	5468	111	23A
0005435040538	5468	112	23B
0005435007307	5468	113	23D
0005435040572	5468	114	23C
0005435040523	5468	115	23E
0005435007159	12966	1	1A
0005435040029	12966	2	1C
0005435040147	12966	3	1F
0005434229654	12966	4	1D
0005435040079	12966	5	2C
0005435039916	12966	6	2A
0005435007186	12966	7	2D
0005435040100	12966	8	2F
0005435007085	12966	9	3A
0005435039755	12966	10	3D
0005435040007	12966	11	3C
0005435007074	12966	12	3F
0005435039791	12966	13	4B
0005435007126	12966	14	4A
0005435007151	12966	15	4C
0005435007051	12966	16	4D
0005435039934	12966	17	4E
0005435007086	12966	18	4F
0005435040009	12966	19	5A
0005435039892	12966	20	5C
0005432304446	12966	21	5B
0005435040096	12966	22	5D
0005434229648	12966	23	5F
0005434229639	12966	24	6B
0005435007046	12966	25	6A
0005435039989	12966	26	6C
0005435040035	12966	27	6D
0005434229641	12966	28	6F
0005435007187	12966	29	6E
0005435039955	12966	30	7B
0005435039659	12966	31	7A
0005435039924	12966	32	7C
0005435039991	12966	33	7E
0005435039909	12966	34	7D
0005435039855	12966	35	7F
0005435040010	12966	36	8A
0005434229644	12966	37	8B
0005435039869	12966	38	8C
0005435040076	12966	39	8D
0005435039870	12966	40	8F
0005435040018	12966	41	8E
0005435040153	12966	42	9A
0005435007098	12966	43	9B
0005435039856	12966	44	9C
0005435039693	12966	45	9E
0005435040008	12966	46	9D
0005435039968	12966	47	9F
0005434229657	12966	48	10C
0005435039790	12966	49	10B
0005435007188	12966	50	10E
0005434229656	12966	51	10D
0005435007145	12966	52	11A
0005435007104	12966	53	11B
0005435040130	12966	54	11C
0005435040021	12966	55	11E
0005435007045	12966	56	11D
0005434229640	12966	57	11F
0005435039999	12966	58	12A
0005435007176	12966	59	12C
0005435007052	12966	60	12B
0005435007167	12966	61	12D
0005435040154	12966	62	12E
0005435040028	12966	63	13A
0005435007099	12966	64	12F
0005435039756	12966	65	13B
0005434229655	12966	66	13C
0005435007106	12966	67	13D
0005435039868	12966	68	13E
0005434229646	12966	69	13F
0005435007026	12966	70	14A
0005435039902	12966	71	14C
0005435040113	12966	72	14B
0005435040059	12966	73	14D
0005435007177	12966	74	14E
0005435039929	12966	75	14F
0005435039811	12966	76	15B
0005435007107	12966	77	15A
0005435007073	12966	78	15C
0005435040005	12966	79	15D
0005435039951	12966	80	15F
0005434229650	12966	81	15E
0005435039730	12966	82	16A
0005435039990	12966	83	16B
0005435040116	12966	84	16C
0005432304447	12966	85	16E
0005435040101	12966	86	16D
0005435039954	12966	87	16F
0005432304444	12966	88	17A
0005434229649	12966	89	17B
0005435040050	12966	90	17C
0005435039812	12966	91	17D
0005435040058	12966	92	17F
0005434229645	12966	93	17E
0005435040148	12966	94	18C
0005435007163	12966	95	18B
0005435039903	12966	96	18A
0005435007175	12966	97	18E
0005435040032	12966	98	18D
0005435040000	12966	99	18F
0005435007161	12966	100	19A
0005434229647	12966	101	19C
0005434229659	12966	102	19B
0005435039952	12966	103	19E
0005435007216	12966	104	19D
0005435039976	12966	105	19F
0005435007108	12966	106	20A
0005434229653	12966	107	20C
0005435040117	12966	108	20B
0005435007105	12966	109	20D
0005435007152	12966	110	20E
0005435040033	12966	111	21A
0005435040045	12966	112	20F
0005434229651	12966	113	21B
0005435039930	12966	114	21C
0005435007160	12966	115	21D
0005435040095	12966	116	21E
0005434229643	12966	117	22A
0005434229642	12966	118	21F
0005434229652	12966	119	22B
0005432304445	12966	120	22C
0005435039931	12966	121	22D
0005435039977	12966	122	22E
0005435007153	12966	123	23A
0005435007124	12966	124	22F
0005435039982	12966	125	23B
0005435007144	12966	126	23C
0005435007087	12966	127	23D
0005434229658	12966	128	23F
0005435039864	12966	129	23E
0005435902671	14905	1	1C
0005434426929	14905	2	2A
0005434426948	14905	3	2C
0005432188644	14905	4	2D
0005434426941	14905	5	2F
0005434426944	14905	6	3A
0005432188645	14905	7	3C
0005434426955	14905	8	3D
0005434426954	14905	9	3F
0005434426937	14905	10	4A
0005435902745	14905	11	4C
0005435902825	14905	12	4E
0005434411829	14905	13	4F
0005434426945	14905	14	5A
0005434426938	14905	15	5D
0005435902766	14905	16	5E
0005434426952	14905	17	6C
0005435902744	14905	18	6D
0005435554205	14905	19	6E
0005435902771	14905	20	6F
0005435554232	14905	21	7A
0005435902740	14905	22	7C
0005435554202	14905	23	7E
0005434426953	14905	24	7F
0005434426933	14905	25	8A
0005434426936	14905	26	8C
0005435902723	14905	27	8D
0005435902708	14905	28	8E
0005435902802	14905	29	8F
0005432188647	14905	30	9A
0005434426930	14905	31	9C
0005435902689	14905	32	9F
0005434426950	14905	33	10A
0005434426934	14905	34	10C
0005434426957	14905	35	10D
0005434426942	14905	36	10E
0005434426946	14905	37	12A
0005434426949	14905	38	12D
0005434426947	14905	39	12F
0005435902734	14905	40	13A
0005432188646	14905	41	13C
0005435554204	14905	42	13D
0005434426939	14905	43	13E
0005434426943	14905	44	13F
0005434426940	14905	45	14A
0005434426951	14905	46	15D
0005434411828	14905	47	15E
0005434426958	14905	48	15F
0005435902823	14905	49	16A
0005435902709	14905	50	16C
0005435902824	14905	51	17C
0005434426931	14905	52	17D
0005434411826	14905	53	18A
0005434411827	14905	54	18C
0005434426956	14905	55	18E
0005434426932	14905	56	19A
0005435554231	14905	57	19C
0005435554183	14905	58	19D
0005434426935	14905	59	19F
0005434426959	14905	60	20C
0005435902803	14905	61	20F
0005434426774	20226	1	1C
0005432059529	20226	2	1D
0005435554248	20226	3	2A
0005434426777	20226	4	2C
0005434426746	20226	5	3A
0005434426865	20226	6	3C
0005435554247	20226	7	4A
0005434426806	20226	8	4C
0005434426740	20226	9	4E
0005434426767	20226	10	4F
0005435902920	20226	11	5A
0005434426677	20226	12	5E
0005434426713	20226	13	5F
0005435902914	20226	14	6D
0005434426650	20226	15	6F
0005434426722	20226	16	7A
0005435902923	20226	17	7C
0005434426701	20226	18	7D
0005435902931	20226	19	7E
0005435902927	20226	20	7F
0005434426651	20226	21	8A
0005434426678	20226	22	8C
0005434426812	20226	23	9D
0005435902928	20226	24	9E
0005434411786	20226	25	10E
0005435554249	20226	26	10F
0005434426700	20226	27	11A
0005435902919	20226	28	11C
0005435902929	20226	29	11F
0005435902925	20226	30	12A
0005435902921	20226	31	12C
0005434426768	20226	32	12E
0005434426675	20226	33	13A
0005435902918	20226	34	13D
0005432059528	20226	35	13E
0005435902926	20226	36	14A
0005434426729	20226	37	14D
0005434426801	20226	38	14F
0005434426775	20226	39	15C
0005435902917	20226	40	15D
0005435902930	20226	41	15E
0005434411792	20226	42	16D
0005434411781	20226	43	16F
0005434426705	20226	44	17C
0005435902924	20226	45	17D
0005434411785	20226	46	17E
0005434426674	20226	47	18D
0005434426696	20226	48	18E
0005435554250	20226	49	19F
0005435902915	20226	50	20A
0005435902922	20226	51	20D
0005434426676	20226	52	20E
0005435902916	20226	53	20F
0005433726096	21653	1	1A
0005433726101	21653	2	4A
0005433726104	21653	3	4D
0005433726079	21653	4	7C
0005433726105	21653	5	9F
0005433726093	21653	6	10B
0005433726103	21653	7	10D
0005433726086	21653	8	12A
0005433726095	21653	9	14D
0005433726110	21653	10	14F
0005433726109	21653	11	16C
0005433726076	21653	12	16E
0005433726097	21653	13	20B
0005433726106	21653	14	23A
0005433726108	21653	15	23B
0005433434731	26525	1	1A
0005433434763	26525	2	1C
0005435982812	26525	3	1D
0005433434680	26525	4	1F
0005433434717	26525	5	2A
0005433434790	26525	6	2F
0005433434826	26525	7	3A
0005433434637	26525	8	3C
0005435982825	26525	9	3D
0005433434672	26525	10	3F
0005435982826	26525	11	4A
0005435982829	26525	12	4C
0005433434783	26525	13	4D
0005435982815	26525	14	4F
0005435982820	26525	15	5C
0005433434709	26525	16	5E
0005433434616	26525	17	5F
0005433434827	26525	18	6A
0005435982822	26525	19	6E
0005435982837	26525	20	6F
0005435982830	26525	21	7C
0005433434658	26525	22	7D
0005432300332	26525	23	7E
0005434273085	26525	24	8A
0005433434743	26525	25	8D
0005435982840	26525	26	8E
0005433434671	26525	27	8F
0005435982814	26525	28	9A
0005435982833	26525	29	9C
0005433434700	26525	30	9D
0005433434713	26525	31	9F
0005433434752	26525	32	10A
0005433434765	26525	33	10C
0005435982839	26525	34	10E
0005433434766	26525	35	10F
0005433434721	26525	36	11A
0005433434730	26525	37	11C
0005435982842	26525	38	11E
0005435982836	26525	39	11F
0005433434663	26525	40	12A
0005435982841	26525	41	12C
0005435982834	26525	42	12D
0005434270214	26525	43	12E
0005435982831	26525	44	12F
0005433434760	26525	45	13A
0005432300331	26525	46	13C
0005434273084	26525	47	13D
0005433434753	26525	48	13E
0005435982813	26525	49	13F
0005433434732	26525	50	14A
0005432300330	26525	51	14D
0005433434809	26525	52	14E
0005435982832	26525	53	14F
0005433434682	26525	54	15A
0005435982824	26525	55	15C
0005435982835	26525	56	15D
0005435982828	26525	57	15F
0005435982817	26525	58	16C
0005433434759	26525	59	16D
0005434273082	26525	60	16E
0005432300328	26525	61	16F
0005432300327	26525	62	17A
0005435982816	26525	63	17C
0005435982819	26525	64	17E
0005435982843	26525	65	17F
0005433434716	26525	66	18A
0005435982838	26525	67	18C
0005433434638	26525	68	18D
0005432300329	26525	69	18F
0005434270213	26525	70	19C
0005433434722	26525	71	19D
0005435982827	26525	72	19F
0005433434681	26525	73	20A
0005435982818	26525	74	20C
0005433434767	26525	75	20D
0005435982823	26525	76	20E
0005435982821	26525	77	20F
0005435982349	26692	1	1A
0005435982484	26692	2	1C
0005435982382	26692	3	1F
0005433435016	26692	4	1D
0005435982421	26692	5	2D
0005433435015	26692	6	2F
0005433435017	26692	7	3A
0005433435021	26692	8	3C
0005435982447	26692	9	3D
0005433435039	26692	10	3F
0005435982548	26692	11	4A
0005433435042	26692	12	4C
0005435982344	26692	13	4D
0005433435018	26692	14	4F
0005435982291	26692	15	5A
0005433435038	26692	16	5C
0005433435035	26692	17	5D
0005435982443	26692	18	5E
0005435982539	26692	19	5F
0005435982353	26692	20	6A
0005433435027	26692	21	6C
0005435982648	26692	22	6D
0005435982247	26692	23	6E
0005435982601	26692	24	6F
0005434270234	26692	25	7A
0005435982352	26692	26	7C
0005432051165	26692	27	7D
0005435982405	26692	28	7E
0005435982461	26692	29	7F
0005435982417	26692	30	8A
0005432051167	26692	31	8C
0005433435036	26692	32	8D
0005435982636	26692	33	8E
0005435982538	26692	34	9A
0005435982422	26692	35	9C
0005432051168	26692	36	9D
0005435982451	26692	37	9E
0005433435026	26692	38	9F
0005434270233	26692	39	10A
0005433435040	26692	40	10C
0005435982452	26692	41	10D
0005435982343	26692	42	10E
0005435982505	26692	43	10F
0005435982481	26692	44	11A
0005434269129	26692	45	11C
0005433435034	26692	46	11D
0005435982637	26692	47	11E
0005435982311	26692	48	12A
0005433435037	26692	49	11F
0005435982614	26692	50	12D
0005435982342	26692	51	12E
0005433435019	26692	52	12F
0005433435041	26692	53	13A
0005435982248	26692	54	13C
0005433435032	26692	55	13D
0005434270231	26692	56	13E
0005434271337	26692	57	13F
0005435982566	26692	58	14A
0005435982350	26692	59	14D
0005435982308	26692	60	14E
0005435982296	26692	61	15A
0005433435030	26692	62	15C
0005435982506	26692	63	15E
0005433435022	26692	64	15F
0005433435023	26692	65	16A
0005435982462	26692	66	16C
0005433435020	26692	67	16D
0005434270232	26692	68	16E
0005434271338	26692	69	16F
0005435982453	26692	70	17A
0005433435024	26692	71	17C
0005435982446	26692	72	17D
0005435982330	26692	73	17F
0005435982488	26692	74	17E
0005433435033	26692	75	18A
0005435982367	26692	76	18C
0005435982647	26692	77	18D
0005435982489	26692	78	18E
0005432051166	26692	79	18F
0005435982312	26692	80	19A
0005435982511	26692	81	19C
0005435982345	26692	82	19D
0005433435028	26692	83	19E
0005433435031	26692	84	19F
0005435982366	26692	85	20A
0005433435029	26692	86	20D
0005433435025	26692	87	20E
0005435982420	26692	88	20F
0005432858154	3175	1	1A
0005432584354	3175	2	1B
0005432858146	3175	3	1C
0005432584349	3175	4	1D
0005432584346	3175	5	2A
0005432584356	3175	6	2B
0005432858142	3175	7	2C
0005432584350	3175	8	2D
0005432858149	3175	9	3B
0005432584352	3175	10	3A
0005432858088	3175	11	3D
0005432858126	3175	12	4B
0005432858101	3175	13	4C
0005432858144	3175	14	5A
0005432584333	3175	15	4D
0005432216306	3175	16	5B
0005432584341	3175	17	5C
0005432858082	3175	18	5D
0005432584355	3175	19	6A
0005432216307	3175	20	6B
0005432584347	3175	21	6C
0005432858087	3175	22	6D
0005432858111	3175	23	7A
0005432584348	3175	24	7B
0005432584353	3175	25	7C
0005432858063	3175	26	7D
0005432584335	3175	27	18A
0005432584339	3175	28	18B
0005432584345	3175	29	18C
0005432584340	3175	30	18D
0005432584336	3175	31	19A
0005432584342	3175	32	19B
0005432216305	3175	33	19C
0005432584344	3175	34	19D
0005432584343	3175	35	20B
0005432584334	3175	36	20C
0005432584338	3175	37	20D
0005432584337	3175	38	21A
0005432858145	3175	39	21B
0005432858069	3175	40	21C
0005432858127	3175	41	21D
0005432584331	3175	42	22A
0005432584351	3175	43	22B
0005432858102	3175	44	22C
0005432858110	3175	45	22D
0005432858089	3175	46	23A
0005432584332	3175	47	23B
0005432858219	31490	1	1A
0005432584223	31490	2	1B
0005432584234	31490	3	1C
0005432584120	31490	4	1D
0005432584099	31490	5	2A
0005432584097	31490	6	2B
0005432584133	31490	7	2C
0005432858212	31490	8	2D
0005432858216	31490	9	3A
0005432858220	31490	10	3B
0005432584089	31490	11	3D
0005432584153	31490	12	4A
0005432858211	31490	13	4C
0005432584066	31490	14	4D
0005432584152	31490	15	5A
0005432584082	31490	16	5B
0005432584096	31490	17	5C
0005432858210	31490	18	5D
0005432584227	31490	19	6A
0005432584027	31490	20	6B
0005432584225	31490	21	6C
0005432858215	31490	22	6D
0005432584180	31490	23	7A
0005432584156	31490	24	7B
0005432584102	31490	25	7C
0005432584148	31490	26	7D
0005432584067	31490	27	18A
0005432584121	31490	28	18B
0005432858221	31490	29	18C
0005432584145	31490	30	18D
0005432584181	31490	31	19A
0005432584235	31490	32	19B
0005432584098	31490	33	19C
0005432584151	31490	34	19D
0005432584090	31490	35	20A
0005432584111	31490	36	20B
0005432584226	31490	37	20C
0005432584146	31490	38	20D
0005432584158	31490	39	21A
0005432584112	31490	40	21B
0005432584177	31490	41	21C
0005432858213	31490	42	22A
0005432584272	31490	43	22B
0005432858217	31490	44	22C
0005432858218	31490	45	22D
0005432584190	31490	46	23A
0005432858214	31490	47	23B
0005433255123	860	1	2A
0005433255145	860	2	4B
0005434943460	860	3	4C
0005434943468	860	4	5B
0005434943467	860	5	5C
0005434943462	860	6	5D
0005434943465	860	7	6B
0005434943464	860	8	6C
0005433255142	860	9	7A
0005434943463	860	10	18A
0005434943466	860	11	18D
0005433255144	860	12	19B
0005434943461	860	13	20A
0005433255124	860	14	22B
0005433255143	860	15	23A
0005433255139	860	16	23B
0005434943389	16191	1	1B
0005434943375	16191	2	1D
0005434943406	16191	3	2B
0005434943384	16191	4	2D
0005434943409	16191	5	3B
0005433255185	16191	6	3D
0005434943379	16191	7	4B
0005434943435	16191	8	4C
0005434943369	16191	9	5D
0005434943391	16191	10	6B
0005434943338	16191	11	6D
0005434943339	16191	12	18A
0005434943376	16191	13	18C
0005434943408	16191	14	19A
0005433255184	16191	15	19B
0005433255186	16191	16	19D
0005434943383	16191	17	20A
0005433255188	16191	18	22C
0005433255187	16191	19	23B
0005433367898	21727	1	1A
0005433367883	21727	2	1C
0005435653566	21727	3	1D
0005433367917	21727	4	2D
0005433368001	21727	5	2F
0005435653560	21727	6	3A
0005435653574	21727	7	3C
0005435653571	21727	8	3F
0005433368040	21727	9	4A
0005433367968	21727	10	4E
0005433367916	21727	11	4F
0005435653584	21727	12	5A
0005433367901	21727	13	5D
0005435653579	21727	14	5E
0005435653559	21727	15	5F
0005435653583	21727	16	6A
0005433367974	21727	17	6D
0005435653572	21727	18	6E
0005435653586	21727	19	6F
0005435653587	21727	20	7C
0005435653570	21727	21	7E
0005435653558	21727	22	8A
0005435653580	21727	23	8D
0005433368004	21727	24	8E
0005435653582	21727	25	8F
0005435653563	21727	26	9A
0005433368093	21727	27	9D
0005435653573	21727	28	9F
0005435653575	21727	29	10A
0005433367963	21727	30	10C
0005435653588	21727	31	10E
0005435653576	21727	32	10F
0005435653590	21727	33	11A
0005433367988	21727	34	11C
0005435653565	21727	35	11D
0005433367806	21727	36	11E
0005433368028	21727	37	11F
0005433367964	21727	38	12A
0005435653577	21727	39	12D
0005433367927	21727	40	12E
0005433367900	21727	41	13A
0005433368048	21727	42	13C
0005435653557	21727	43	13D
0005433367969	21727	44	13E
0005433367922	21727	45	13F
0005433367905	21727	46	14C
0005433367962	21727	47	14E
0005435653585	21727	48	14F
0005435653562	21727	49	15A
0005435653581	21727	50	15D
0005435653569	21727	51	15E
0005435653564	21727	52	15F
0005433368014	21727	53	16C
0005433368091	21727	54	16D
0005435653561	21727	55	16E
0005433367944	21727	56	16F
0005433367899	21727	57	17A
0005433367875	21727	58	17D
0005435653589	21727	59	17E
0005435653568	21727	60	18A
0005435653591	21727	61	17F
0005433368088	21727	62	18D
0005435653578	21727	63	18E
0005435653567	21727	64	18F
0005433367948	21727	65	19A
0005433368000	21727	66	19C
0005433367908	21727	67	19D
0005433368092	21727	68	19E
0005433368049	21727	69	20A
0005435653592	21727	70	20D
0005433368087	21727	71	20E
0005433367919	21727	72	20F
0005433763385	9373	1	1A
0005432657488	9373	2	1F
0005433805818	9373	3	1C
0005432667479	9373	4	1G
0005433805817	9373	5	2B
0005433805797	9373	6	3A
0005433763390	9373	7	3F
0005433805815	9373	8	3G
0005433805801	9373	9	4A
0005434171124	9373	10	3H
0005432665300	9373	11	4B
0005435269751	9373	12	4C
0005433805804	9373	13	4G
0005434151714	9373	14	5B
0005433805792	9373	15	5A
0005433785406	9373	16	5G
0005434171076	9373	17	5F
0005434151717	9373	18	5H
0005433763391	9373	19	11D
0005433785382	9373	20	11E
0005433805806	9373	21	11G
0005432666414	9373	22	12A
0005433785407	9373	23	12E
0005433763377	9373	24	12D
0005433805796	9373	25	12F
0005435269755	9373	26	12H
0005433785399	9373	27	12G
0005433785388	9373	28	13B
0005434171161	9373	29	13D
0005433805812	9373	30	13F
0005433785395	9373	31	13E
0005434171084	9373	32	13G
0005433785398	9373	33	14B
0005433805807	9373	34	14A
0005435269754	9373	35	14E
0005435269761	9373	36	14D
0005435269756	9373	37	14F
0005434171121	9373	38	14G
0005433785377	9373	39	15A
0005433785410	9373	40	15B
0005433785409	9373	41	15D
0005433785404	9373	42	15F
0005433785376	9373	43	15H
0005435269747	9373	44	15G
0005433805809	9373	45	16A
0005434171083	9373	46	16D
0005434171105	9373	47	16G
0005432667478	9373	48	17A
0005434171173	9373	49	17H
0005435269749	9373	50	18B
0005434171174	9373	51	18D
0005432657487	9373	52	18E
0005433785380	9373	53	18G
0005433785401	9373	54	18F
0005433805794	9373	55	18H
0005434151716	9373	56	19B
0005434171119	9373	57	19E
0005433785389	9373	58	19G
0005432666413	9373	59	19F
0005433805799	9373	60	19H
0005434171082	9373	61	20A
0005434270222	9373	62	20B
0005433805805	9373	63	20D
0005434270221	9373	64	20F
0005433805802	9373	65	20H
0005433805810	9373	66	20G
0005433763388	9373	67	21A
0005433805791	9373	68	21B
0005434171086	9373	69	21E
0005435269748	9373	70	21F
0005434171077	9373	71	21G
0005433785391	9373	72	22B
0005433763382	9373	73	22A
0005433785392	9373	74	22D
0005433785387	9373	75	22F
0005433805793	9373	76	23B
0005433763387	9373	77	23D
0005433785378	9373	78	23F
0005433785405	9373	79	23E
0005433785400	9373	80	24A
0005435269750	9373	81	23H
0005433763378	9373	82	24B
0005433785403	9373	83	24D
0005433785383	9373	84	24G
0005435269762	9373	85	24H
0005433805795	9373	86	25F
0005432657485	9373	87	27A
0005433805816	9373	88	27F
0005433785385	9373	89	27E
0005433805800	9373	90	27G
0005432665301	9373	91	27H
0005434171122	9373	92	28B
0005434171108	9373	93	28E
0005433805813	9373	94	28G
0005434171085	9373	95	29A
0005433805819	9373	96	29D
0005433805820	9373	97	29B
0005434151709	9373	98	29E
0005433785390	9373	99	29F
0005433763383	9373	100	29H
0005433805814	9373	101	29G
0005433763381	9373	102	30F
0005433805808	9373	103	30H
0005433763384	9373	104	31B
0005433785397	9373	105	32B
0005433805790	9373	106	32F
0005433805811	9373	107	32G
0005433785375	9373	108	33A
0005433805803	9373	109	32H
0005434171120	9373	110	33D
0005433763386	9373	111	33E
0005433785394	9373	112	33F
0005433785402	9373	113	34A
0005432657489	9373	114	34D
0005433785408	9373	115	34F
0005434171081	9373	116	34E
0005433763389	9373	117	34H
0005432657486	9373	118	35A
0005433805822	9373	119	35B
0005432665299	9373	120	35G
0005435269746	9373	121	36D
0005433763380	9373	122	36F
0005435269752	9373	123	36E
0005433805798	9373	124	37A
0005433785393	9373	125	36H
0005434151715	9373	126	37B
0005433785386	9373	127	37E
0005433785384	9373	128	37D
0005433785396	9373	129	37G
0005433805821	9373	130	37F
0005433805789	9373	131	38D
0005433785381	9373	132	38G
0005434171101	9373	133	38F
0005433785379	9373	134	39D
0005435269753	9373	135	39F
0005433763379	9373	136	39E
0005433785162	26250	1	1F
0005433763260	26250	2	1C
0005433785012	26250	3	2A
0005433805577	26250	4	1H
0005432657463	26250	5	2B
0005432657455	26250	6	2F
0005432657457	26250	7	2H
0005433763246	26250	8	3A
0005435269849	26250	9	3F
0005433805561	26250	10	3G
0005435269842	26250	11	4B
0005433785244	26250	12	4C
0005434269127	26250	13	4H
0005433785000	26250	14	5B
0005433805391	26250	15	5A
0005433763245	26250	16	5C
0005434171229	26250	17	5G
0005435269841	26250	18	5H
0005433785155	26250	19	11A
0005433785113	26250	20	9H
0005433805451	26250	21	11B
0005433785051	26250	22	11G
0005435269846	26250	23	11H
0005434171227	26250	24	12D
0005433763253	26250	25	12B
0005433805486	26250	26	12E
0005433785110	26250	27	12F
0005433763261	26250	28	12H
0005434151739	26250	29	13A
0005433785125	26250	30	13D
0005433805579	26250	31	13G
0005433763254	26250	32	13F
0005433805569	26250	33	14A
0005433805494	26250	34	14E
0005433784953	26250	35	14H
0005433805540	26250	36	14G
0005434171232	26250	37	14F
0005435269854	26250	38	15A
0005433784876	26250	39	15D
0005433785111	26250	40	15F
0005433763285	26250	41	15H
0005433763268	26250	42	15G
0005433805242	26250	43	16A
0005433805643	26250	44	16D
0005433805426	26250	45	16B
0005433785124	26250	46	16E
0005434171230	26250	47	16F
0005434271336	26250	48	16H
0005434271335	26250	49	17B
0005433784952	26250	50	17A
0005435269840	26250	51	17D
0005433785004	26250	52	17E
0005434171224	26250	53	17F
0005433805541	26250	54	17H
0005433805544	26250	55	18B
0005433784998	26250	56	18F
0005435269845	26250	57	18G
0005435269853	26250	58	19A
0005434171233	26250	59	18H
0005434269128	26250	60	19G
0005433805379	26250	61	19F
0005432666400	26250	62	19E
0005433805514	26250	63	20A
0005433805424	26250	64	19H
0005433805492	26250	65	20B
0005432666391	26250	66	20D
0005433805593	26250	67	20H
0005434171235	26250	68	21A
0005434270229	26250	69	21B
0005433763286	26250	70	21F
0005433785038	26250	71	21H
0005433785086	26250	72	22B
0005434171228	26250	73	22D
0005433805570	26250	74	22E
0005433763256	26250	75	22G
0005435269847	26250	76	22F
0005433785097	26250	77	22H
0005435269852	26250	78	23B
0005433785112	26250	79	23A
0005433785133	26250	80	23E
0005433785044	26250	81	24B
0005434171234	26250	82	24D
0005435269844	26250	83	24F
0005433763279	26250	84	25D
0005433784986	26250	85	24H
0005433785141	26250	86	25E
0005433785134	26250	87	27A
0005433805485	26250	88	25F
0005433784999	26250	89	27B
0005433785050	26250	90	27D
0005433763244	26250	91	27F
0005433785079	26250	92	27E
0005435269850	26250	93	27H
0005433805459	26250	94	27G
0005433785121	26250	95	28B
0005433785116	26250	96	28E
0005433785164	26250	97	28F
0005433785115	26250	98	28G
0005433805495	26250	99	29A
0005433805600	26250	100	28H
0005433785144	26250	101	29B
0005433763216	26250	102	29E
0005433805411	26250	103	29F
0005433805450	26250	104	29H
0005433785136	26250	105	30B
0005434171236	26250	106	30D
0005433785120	26250	107	30E
0005434171223	26250	108	30G
0005433763255	26250	109	31A
0005433784987	26250	110	31D
0005433805580	26250	111	31H
0005433785043	26250	112	32B
0005433785011	26250	113	32E
0005433805613	26250	114	32D
0005433805560	26250	115	32G
0005433785005	26250	116	33D
0005434269126	26250	117	33B
0005433785151	26250	118	33E
0005433805648	26250	119	33F
0005433805489	26250	120	33H
0005434171226	26250	121	33G
0005433805487	26250	122	34D
0005434151738	26250	123	34E
0005434171225	26250	124	34G
0005435269843	26250	125	34H
0005433785216	26250	126	35A
0005433805592	26250	127	35D
0005434270230	26250	128	35F
0005433785006	26250	129	35E
0005433785098	26250	130	35H
0005433805601	26250	131	36B
0005433805423	26250	132	36A
0005433805488	26250	133	37B
0005434171231	26250	134	37E
0005435269848	26250	135	37G
0005433805447	26250	136	38A
0005433805515	26250	137	37H
0005433785117	26250	138	38D
0005433805578	26250	139	38F
0005433784949	26250	140	38G
0005433805543	26250	141	38H
0005435269851	26250	142	39D
0005433785049	26250	143	39F
0005434151740	26250	144	39E
0005435135731	4878	1	2A
0005435135729	4878	2	6C
0005435135732	4878	3	6D
0005435135730	4878	4	19D
0005435929662	4878	5	22C
0005435135694	33036	1	1B
0005435135700	33036	2	3A
0005435135699	33036	3	4A
0005435135693	33036	4	5A
0005435929676	33036	5	5C
0005435929677	33036	6	7A
0005435135705	33036	7	19B
0005435135697	33036	8	21C
0005435135698	33036	9	23B
0005434983351	9476	1	2A
0005434217989	9476	2	5C
0005434983352	9476	3	6D
0005434217997	9476	4	7D
0005434983350	9476	5	20A
0005434217988	9476	6	20D
0005434983348	9476	7	22D
0005434983349	9476	8	23A
0005434218019	27350	1	1D
0005434983319	27350	2	3D
0005434983327	27350	3	4B
0005434983311	27350	4	4D
0005434983317	27350	5	5D
0005434983318	27350	6	6A
0005434983326	27350	7	6C
0005434983323	27350	8	7A
0005434218017	27350	9	7D
0005434218018	27350	10	19A
0005434983324	27350	11	20D
0005434218020	27350	12	21B
0005434983340	27350	13	23A
0005433960869	24236	1	1B
0005433986223	24236	2	1F
0005433986090	24236	3	1H
0005433985948	24236	4	1G
0005433986133	24236	5	2A
0005433961090	24236	6	2B
0005433961106	24236	7	2C
0005433986139	24236	8	3A
0005433961059	24236	9	3B
0005433986159	24236	10	3H
0005433986132	24236	11	4C
0005433960966	24236	12	4G
0005433960944	24236	13	4H
0005433960911	24236	14	5G
0005433986098	24236	15	5F
0005433985997	24236	16	5H
0005433961025	24236	17	9B
0005433961013	24236	18	9A
0005433986126	24236	19	9G
0005433986142	24236	20	11A
0005433986071	24236	21	9H
0005433985975	24236	22	11D
0005433986049	24236	23	11B
0005433985840	24236	24	11E
0005433960831	24236	25	11G
0005433961027	24236	26	11F
0005433986057	24236	27	11H
0005433960891	24236	28	12A
0005433986064	24236	29	12E
0005433961011	24236	30	12F
0005433986028	24236	31	13B
0005433961081	24236	32	13E
0005433985961	24236	33	13G
0005433961050	24236	34	14A
0005433961075	24236	35	14E
0005433960991	24236	36	14D
0005433986050	24236	37	14F
0005433986072	24236	38	14H
0005433961088	24236	39	15E
0005433960949	24236	40	15F
0005433985960	24236	41	15H
0005433960978	24236	42	16E
0005433986160	24236	43	16F
0005433960995	24236	44	16H
0005433960958	24236	45	16G
0005433960890	24236	46	17D
0005433960855	24236	47	17G
0005433986106	24236	48	17F
0005433961058	24236	49	18B
0005433986194	24236	50	18A
0005433960898	24236	51	18D
0005433985991	24236	52	18E
0005433986027	24236	53	19A
0005433986192	24236	54	19B
0005433986026	24236	55	19D
0005433986104	24236	56	19F
0005433960905	24236	57	19G
0005433986054	24236	58	20E
0005433986102	24236	59	20F
0005433960830	24236	60	20H
0005433960897	24236	61	20G
0005433960881	24236	62	21A
0005433961030	24236	63	21B
0005433960969	24236	64	21H
0005433986124	24236	65	21G
0005433986164	24236	66	22A
0005433961012	24236	67	22D
0005433960992	24236	68	22E
0005433985861	24236	69	22F
0005433986165	24236	70	23D
0005433961005	24236	71	23G
0005433961009	24236	72	24B
0005433986140	24236	73	24E
0005433985949	24236	74	24F
0005433961089	24236	75	24G
0005433986065	24236	76	25D
0005433961003	24236	77	25F
0005433986163	24236	78	27B
0005433986056	24236	79	27A
0005433985939	24236	80	27F
0005433961024	24236	81	27E
0005433986097	24236	82	27H
0005433961091	24236	83	28E
0005433961060	24236	84	28F
0005433960965	24236	85	28H
0005433960997	24236	86	28G
0005433960896	24236	87	29E
0005433961055	24236	88	29F
0005433986141	24236	89	30D
0005433960892	24236	90	30E
0005433961026	24236	91	30F
0005433961092	24236	92	31A
0005433985955	24236	93	30H
0005433961004	24236	94	31D
0005433960951	24236	95	31G
0005433961049	24236	96	32A
0005433985860	24236	97	32E
0005433986158	24236	98	32G
0005433986116	24236	99	32F
0005433986070	24236	100	33A
0005433960910	24236	101	33B
0005433960750	24236	102	33H
0005433986075	24236	103	33G
0005433960908	24236	104	34B
0005433986162	24236	105	34A
0005433986003	24236	106	34D
0005433986055	24236	107	34G
0005433961008	24236	108	34H
0005433960793	24236	109	35H
0005433961031	24236	110	36B
0005433986125	24236	111	36A
0005433986073	24236	112	36D
0005433960996	24236	113	36F
0005433985974	24236	114	36H
0005433986025	24236	115	36G
0005433986105	24236	116	37B
0005433960979	24236	117	37E
0005433961028	24236	118	37G
0005433961017	24236	119	37F
0005433961086	24236	120	38B
0005433986157	24236	121	38A
0005433960994	24236	122	38D
0005433960945	24236	123	38F
0005433961023	24236	124	38E
0005433986222	24236	125	38G
0005433960751	24236	126	38H
0005433961082	24236	127	39E
0005433986117	24236	128	39F
0005433961528	25907	1	1C
0005433986499	25907	2	2F
0005433986478	25907	3	2H
0005433961501	25907	4	3A
0005433986469	25907	5	3B
0005433986486	25907	6	3G
0005433986492	25907	7	3F
0005433961520	25907	8	4B
0005433986479	25907	9	5A
0005433986491	25907	10	4H
0005433961495	25907	11	5B
0005433961513	25907	12	9H
0005433986504	25907	13	11E
0005433961516	25907	14	11F
0005433986496	25907	15	11H
0005433961488	25907	16	11G
0005433961487	25907	17	12B
0005433961514	25907	18	12D
0005433961517	25907	19	12F
0005433961529	25907	20	12E
0005433986466	25907	21	13A
0005433961502	25907	22	13B
0005433961506	25907	23	13E
0005433986473	25907	24	13G
0005433986493	25907	25	13H
0005433961523	25907	26	14E
0005433986501	25907	27	14G
0005433986482	25907	28	14F
0005433961512	25907	29	15D
0005433986467	25907	30	15F
0005433986463	25907	31	15H
0005433986498	25907	32	16A
0005433986470	25907	33	16D
0005433961503	25907	34	16B
0005433986483	25907	35	17F
0005433961499	25907	36	18D
0005433961511	25907	37	19B
0005433986461	25907	38	19E
0005433986462	25907	39	19F
0005433986497	25907	40	20A
0005433961504	25907	41	19H
0005433961526	25907	42	20D
0005433986503	25907	43	20B
0005433986472	25907	44	20E
0005433961518	25907	45	20G
0005433986460	25907	46	20H
0005433961496	25907	47	21B
0005433986477	25907	48	21D
0005433961494	25907	49	21H
0005433961521	25907	50	21G
0005433961498	25907	51	22D
0005433961493	25907	52	22E
0005433961530	25907	53	23D
0005433986490	25907	54	24A
0005433961490	25907	55	25D
0005433961525	25907	56	27B
0005433986468	25907	57	27E
0005433961519	25907	58	27H
0005433986484	25907	59	27G
0005433986500	25907	60	28B
0005433986485	25907	61	28E
0005433986480	25907	62	28G
0005433961497	25907	63	29B
0005433986459	25907	64	29E
0005433961515	25907	65	30A
0005433986476	25907	66	30F
0005433986487	25907	67	31A
0005433961505	25907	68	31E
0005433986495	25907	69	31D
0005433961492	25907	70	31F
0005433986481	25907	71	32A
0005433986471	25907	72	31H
0005433961500	25907	73	32G
0005433961531	25907	74	33A
0005433986465	25907	75	33E
0005433986502	25907	76	33F
0005433961491	25907	77	33H
0005433961509	25907	78	34D
0005433986474	25907	79	34H
0005433986505	25907	80	35A
0005433986489	25907	81	35F
0005433961507	25907	82	35E
0005433961508	25907	83	35G
0005433986494	25907	84	36A
0005433986464	25907	85	35H
0005433961510	25907	86	36D
0005433961489	25907	87	37A
0005433986488	25907	88	37B
0005433961524	25907	89	37E
0005433961522	25907	90	37F
0005433961527	25907	91	38D
0005433986475	25907	92	39E
0005433165951	971	1	1A
0005433165993	971	2	1B
0005434480630	971	3	1C
0005433165892	971	4	1D
0005432269529	971	5	2A
0005434480651	971	6	2B
0005434480633	971	7	2C
0005434480635	971	8	2D
0005434480644	971	9	3A
0005433165911	971	10	3B
0005433165950	971	11	3C
0005434480648	971	12	3D
0005433165948	971	13	4A
0005434480649	971	14	4B
0005433165893	971	15	4C
0005434480650	971	16	4D
0005433165936	971	17	5A
0005434480631	971	18	5B
0005434480638	971	19	5C
0005434480632	971	20	5D
0005434480639	971	21	6A
0005433166009	971	22	6B
0005434480645	971	23	6C
0005434480628	971	24	6D
0005434480647	971	25	7A
0005434480642	971	26	7B
0005434480629	971	27	7C
0005433165982	971	28	7D
0005434480643	971	29	18A
0005434480627	971	30	18B
0005434480652	971	31	18C
0005433165981	971	32	18D
0005434480637	971	33	19A
0005434480641	971	34	19B
0005433165989	971	35	19C
0005433165912	971	36	19D
0005433165955	971	37	20A
0005433166010	971	38	20B
0005434480636	971	39	20C
0005432269530	971	40	20D
0005434480634	971	41	21A
0005433165949	971	42	21B
0005433165894	971	43	21C
0005434480640	971	44	21D
0005434480653	971	45	22A
0005433165952	971	46	22B
0005432269528	971	47	22C
0005433166000	971	48	22D
0005433165956	971	49	23A
0005434480646	971	50	23B
0005433166068	16564	1	1A
0005434480418	16564	2	1B
0005433166059	16564	3	1C
0005434480377	16564	4	2A
0005434480489	16564	5	2B
0005433166060	16564	6	2C
0005434480270	16564	7	3A
0005434480429	16564	8	3B
0005434480504	16564	9	3C
0005433166058	16564	10	3D
0005434480456	16564	11	4A
0005433166064	16564	12	4B
0005434480547	16564	13	4C
0005434480459	16564	14	4D
0005433166065	16564	15	5A
0005434480428	16564	16	5B
0005433166067	16564	17	5C
0005434480380	16564	18	5D
0005433166066	16564	19	6A
0005434480341	16564	20	6D
0005433166062	16564	21	7A
0005434480503	16564	22	7B
0005433166057	16564	23	7C
0005433166070	16564	24	7D
0005434480353	16564	25	18B
0005434480497	16564	26	18D
0005434480463	16564	27	19B
0005433166063	16564	28	19C
0005434480404	16564	29	20B
0005434480438	16564	30	20C
0005434480352	16564	31	20D
0005434480465	16564	32	21A
0005433166069	16564	33	21B
0005434480464	16564	34	21C
0005434480361	16564	35	22A
0005434480413	16564	36	22B
0005434480462	16564	37	22C
0005434480416	16564	38	22D
0005433166061	16564	39	23A
0005434480498	16564	40	23B
0005433289898	10358	1	1A
0005435142732	10358	2	1B
0005433289893	10358	3	1C
0005435150187	10358	4	1D
0005435150181	10358	5	2A
0005435142727	10358	6	2C
0005435142737	10358	7	2D
0005435150179	10358	8	3A
0005435386579	10358	9	3B
0005433289900	10358	10	3C
0005435142735	10358	11	3D
0005435142728	10358	12	4A
0005433289839	10358	13	4C
0005435386605	10358	14	4D
0005435386619	10358	15	5A
0005435150184	10358	16	5B
0005435150185	10358	17	5C
0005435150188	10358	18	5D
0005435150190	10358	19	6A
0005435150192	10358	20	6B
0005435150183	10358	21	6C
0005433289899	10358	22	6D
0005435150180	10358	23	7A
0005435150189	10358	24	7B
0005435142725	10358	25	7C
0005435386600	10358	26	7D
0005435142734	10358	27	18A
0005435386599	10358	28	18B
0005433289878	10358	29	18C
0005435142726	10358	30	18D
0005435150186	10358	31	19A
0005435142729	10358	32	19B
0005435142724	10358	33	19C
0005435150191	10358	34	19D
0005435142731	10358	35	20A
0005435386620	10358	36	20B
0005435150182	10358	37	20C
0005433289840	10358	38	20D
0005433289877	10358	39	21A
0005433289875	10358	40	21B
0005435142733	10358	41	21C
0005435142736	10358	42	21D
0005435142730	10358	43	22A
0005433289879	10358	44	22B
0005433289880	10358	45	22C
0005433289876	10358	46	22D
0005435150178	10358	47	23A
0005433289894	10358	48	23B
0005435150021	21966	1	1A
0005435142619	21966	2	1B
0005435150065	21966	3	1C
0005435142642	21966	4	1D
0005435142667	21966	5	2A
0005435150085	21966	6	2B
0005435150020	21966	7	2C
0005435150061	21966	8	2D
0005433289946	21966	9	3A
0005435142620	21966	10	3B
0005433289943	21966	11	3D
0005435142595	21966	12	3C
0005435150052	21966	13	4A
0005433289944	21966	14	4B
0005435150049	21966	15	4C
0005435150046	21966	16	4D
0005435142621	21966	17	5A
0005435150073	21966	18	5B
0005435142645	21966	19	5C
0005435142548	21966	20	5D
0005435142594	21966	21	6A
0005435142651	21966	22	6B
0005435142628	21966	23	6C
0005435142618	21966	24	6D
0005435150069	21966	25	7A
0005435150071	21966	26	7B
0005435150070	21966	27	7C
0005433289941	21966	28	7D
0005435150068	21966	29	18A
0005435150029	21966	30	18B
0005435142650	21966	31	18C
0005433289942	21966	32	18D
0005433289947	21966	33	19A
0005433289940	21966	34	19C
0005435150048	21966	35	19B
0005433289945	21966	36	19D
0005435150062	21966	37	20A
0005435150077	21966	38	20B
0005435150032	21966	39	20C
0005435150074	21966	40	20D
0005435150078	21966	41	21A
0005435142656	21966	42	21B
0005435150072	21966	43	21C
0005435142597	21966	44	21D
0005435150031	21966	45	22A
0005435150045	21966	46	22B
0005435142643	21966	47	22C
0005435142599	21966	48	22D
0005435142596	21966	49	23A
0005433289939	21966	50	23B
0005435545752	11235	1	1A
0005435502420	11235	2	1C
0005434573510	11235	3	1F
0005435529326	11235	4	2C
0005435502495	11235	5	2D
0005435529365	11235	6	3C
0005435502346	11235	7	3D
0005435502345	11235	8	3F
0005434573513	11235	9	4A
0005435545754	11235	10	4C
0005435529360	11235	11	4E
0005434573514	11235	12	5A
0005434573511	11235	13	5C
0005435319622	11235	14	5E
0005435502402	11235	15	6A
0005435502341	11235	16	6C
0005434573512	11235	17	6D
0005435529277	11235	18	6E
0005435502406	11235	19	6F
0005435529337	11235	20	7A
0005435529308	11235	21	7C
0005435529329	11235	22	7D
0005435529290	11235	23	8C
0005435502437	11235	24	8D
0005435502494	11235	25	9A
0005435319590	11235	26	9C
0005435529309	11235	27	9D
0005434573508	11235	28	9F
0005434573509	11235	29	10C
0005435319594	11235	30	10D
0005435319592	11235	31	10F
0005435529279	11235	32	11A
0005434573505	11235	33	11D
0005435529300	11235	34	11E
0005435502374	11235	35	12A
0005435502460	11235	36	12C
0005435502342	11235	37	12D
0005435529361	11235	38	13C
0005435545768	11235	39	13D
0005435502435	11235	40	13E
0005435502459	11235	41	13F
0005435529364	11235	42	14A
0005434573519	11235	43	14C
0005435529382	11235	44	14D
0005435319579	11235	45	14E
0005435529291	11235	46	15C
0005435545781	11235	47	15D
0005434573517	11235	48	15E
0005435502338	11235	49	15F
0005435502485	11235	50	16C
0005434573507	11235	51	16E
0005435545783	11235	52	16F
0005434573515	11235	53	17A
0005434573516	11235	54	17D
0005435545780	11235	55	17F
0005435529272	11235	56	18C
0005435545769	11235	57	18D
0005435502349	11235	58	18E
0005435502291	11235	59	19C
0005435529386	11235	60	19D
0005435545748	11235	61	19E
0005434573518	11235	62	20A
0005434573506	11235	63	20C
0005435545753	11235	64	20D
0005435529280	11235	65	20E
0005435529336	11235	66	20F
0005435508492	20952	1	1A
0005435502572	20952	2	1C
0005434573412	20952	3	1D
0005434573413	20952	4	1F
0005434573399	20952	5	2A
0005435502567	20952	6	2C
0005432291959	20952	7	2D
0005435319694	20952	8	2F
0005435508487	20952	9	3A
0005435502568	20952	10	3C
0005434573421	20952	11	3D
0005435502558	20952	12	3F
0005435518128	20952	13	4A
0005435502555	20952	14	4C
0005434573425	20952	15	4D
0005435518129	20952	16	4E
0005435518124	20952	17	5D
0005435502565	20952	18	5E
0005435502573	20952	19	5F
0005435502566	20952	20	6A
0005435518130	20952	21	6C
0005435518131	20952	22	6D
0005434573369	20952	23	6E
0005435518127	20952	24	7C
0005435502559	20952	25	7D
0005435319691	20952	26	7E
0005435502569	20952	27	8A
0005435518119	20952	28	8C
0005435502561	20952	29	8D
0005434573419	20952	30	8E
0005434573445	20952	31	8F
0005435502570	20952	32	9A
0005435508485	20952	33	9C
0005435502553	20952	34	9D
0005435319686	20952	35	9E
0005434573424	20952	36	9F
0005435508489	20952	37	10A
0005434573400	20952	38	10C
0005435502563	20952	39	10D
0005435518118	20952	40	10E
0005435518133	20952	41	10F
0005435502560	20952	42	11A
0005435508491	20952	43	11C
0005434573414	20952	44	11D
0005435319693	20952	45	11E
0005435518123	20952	46	11F
0005435502554	20952	47	12A
0005434573338	20952	48	12D
0005435319692	20952	49	12E
0005435518121	20952	50	12F
0005435508488	20952	51	13A
0005435319695	20952	52	13C
0005435518134	20952	53	13D
0005432291957	20952	54	13E
0005435518120	20952	55	13F
0005434573362	20952	56	14A
0005434573373	20952	57	14C
0005434573347	20952	58	14D
0005435502562	20952	59	14E
0005435508484	20952	60	14F
0005435319689	20952	61	15C
0005435518125	20952	62	15D
0005435518117	20952	63	15E
0005435518135	20952	64	15F
0005435518122	20952	65	16C
0005435319687	20952	66	16D
0005434573372	20952	67	16E
0005434573376	20952	68	16F
0005434573292	20952	69	17A
0005434573339	20952	70	17C
0005435518115	20952	71	17D
0005435319688	20952	72	17F
0005435518132	20952	73	18C
0005435502571	20952	74	18A
0005435508490	20952	75	18E
0005435319690	20952	76	19A
0005435502557	20952	77	19C
0005435508486	20952	78	19D
0005432291958	20952	79	19E
0005435502556	20952	80	19F
0005434573368	20952	81	20A
0005435518126	20952	82	20C
0005435502564	20952	83	20D
0005434573420	20952	84	20E
0005435518116	20952	85	20F
0005432693135	3060	1	4A
0005432693377	3060	2	5C
0005432693196	3060	3	6D
0005432693147	3060	4	6E
0005432693175	3060	5	7E
0005432693214	3060	6	8D
0005432693186	3060	7	9A
0005432693141	3060	8	9C
0005432693241	3060	9	10C
0005432693155	3060	10	11D
0005432693134	3060	11	11F
0005432693218	3060	12	12A
0005432693164	3060	13	12D
0005432693242	3060	14	12F
0005432693137	3060	15	14F
0005432693229	3060	16	15A
0005432693136	3060	17	15D
0005432693226	3060	18	15E
0005432693190	3060	19	16A
0005432693272	3060	20	16C
0005432693271	3060	21	16D
0005432693204	3060	22	16F
0005432693140	3060	23	18A
0005432693262	3060	24	18C
0005432693243	3060	25	18F
0005432693129	3060	26	19A
0005432693089	3060	27	19C
0005432693165	3060	28	19F
0005433123998	3062	1	1A
0005432880893	3062	2	1C
0005433124025	3062	3	1D
0005433124022	3062	4	1F
0005432707076	3062	5	2A
0005433123975	3062	6	2C
0005432880897	3062	7	2D
0005432707082	3062	8	2F
0005433123929	3062	9	3A
0005432707080	3062	10	3C
0005433123984	3062	11	3D
0005433124024	3062	12	3F
0005433123961	3062	13	4A
0005432880842	3062	14	4D
0005433123964	3062	15	4E
0005432707068	3062	16	4F
0005432880865	3062	17	5A
0005433123958	3062	18	5C
0005433123987	3062	19	5D
0005432707087	3062	20	5F
0005433124028	3062	21	6C
0005432707085	3062	22	6E
0005433123919	3062	23	6F
0005432707073	3062	24	7A
0005432880868	3062	25	7C
0005433124003	3062	26	7D
0005433123981	3062	27	7E
0005432880867	3062	28	8A
0005433124037	3062	29	7F
0005433123974	3062	30	8C
0005433123995	3062	31	8D
0005432707074	3062	32	8E
0005433124042	3062	33	8F
0005433123994	3062	34	9A
0005432707093	3062	35	9C
0005433123928	3062	36	9D
0005433123992	3062	37	9E
0005433124027	3062	38	9F
0005432707078	3062	39	10A
0005433123959	3062	40	10C
0005433123946	3062	41	10D
0005433124051	3062	42	10E
0005433123982	3062	43	10F
0005432880878	3062	44	11A
0005433124050	3062	45	11C
0005433124057	3062	46	11D
0005432707072	3062	47	11E
0005432707086	3062	48	11F
0005432217809	3062	49	12A
0005432707079	3062	50	12C
0005432707090	3062	51	12D
0005433124105	3062	52	12E
0005432707083	3062	53	12F
0005432707092	3062	54	13A
0005433124095	3062	55	13C
0005432217811	3062	56	13D
0005432880898	3062	57	13E
0005432707070	3062	58	13F
0005433123983	3062	59	14A
0005433124041	3062	60	14C
0005433123993	3062	61	14D
0005433123945	3062	62	14F
0005432880874	3062	63	15A
0005432707089	3062	64	15C
0005433124021	3062	65	15F
0005432880841	3062	66	16C
0005432707088	3062	67	16D
0005432880866	3062	68	16E
0005433124043	3062	69	16F
0005432880830	3062	70	17A
0005433123920	3062	71	17C
0005432707075	3062	72	17D
0005432880877	3062	73	17E
0005432707084	3062	74	17F
0005432707069	3062	75	18A
0005433123918	3062	76	18C
0005432880815	3062	77	18D
0005432707077	3062	78	18E
0005432880814	3062	79	18F
0005432707081	3062	80	19A
0005432880829	3062	81	19C
0005433124040	3062	82	19D
0005433123960	3062	83	19E
0005432707071	3062	84	19F
0005432217810	3062	85	20A
0005433124046	3062	86	20C
0005433124038	3062	87	20D
0005432880864	3062	88	20E
0005432707091	3062	89	20F
0005432693452	29913	1	1A
0005432706930	29913	2	1C
0005432693461	29913	3	1D
0005432880988	29913	4	1F
0005432693471	29913	5	2A
0005432880997	29913	6	2C
0005432706893	29913	7	2D
0005432706864	29913	8	2F
0005432706892	29913	9	3A
0005432693447	29913	10	3C
0005432706813	29913	11	3D
0005432693473	29913	12	3F
0005432706819	29913	13	4A
0005433124172	29913	14	4C
0005433124169	29913	15	4D
0005432693443	29913	16	4E
0005433124167	29913	17	4F
0005432880987	29913	18	5A
0005432693445	29913	19	5C
0005432693456	29913	20	5D
0005432706842	29913	21	5E
0005432706830	29913	22	5F
0005432706920	29913	23	6A
0005432706918	29913	24	6C
0005432706853	29913	25	6D
0005432706860	29913	26	6E
0005432881001	29913	27	6F
0005432706756	29913	28	7A
0005432693463	29913	29	7C
0005432706950	29913	30	7D
0005432880992	29913	31	7E
0005432706915	29913	32	7F
0005432706916	29913	33	8A
0005433124165	29913	34	8C
0005432693458	29913	35	8D
0005432693446	29913	36	8E
0005433124170	29913	37	8F
0005432693468	29913	38	9A
0005432706868	29913	39	9C
0005432693449	29913	40	9D
0005432706825	29913	41	9E
0005432693462	29913	42	9F
0005432881000	29913	43	10A
0005433124175	29913	44	10C
0005432880996	29913	45	10D
0005432880995	29913	46	10E
0005432706843	29913	47	10F
0005432693455	29913	48	11A
0005432693467	29913	49	11C
0005432706863	29913	50	11D
0005432706948	29913	51	11E
0005432706907	29913	52	11F
0005432693457	29913	53	12A
0005432706919	29913	54	12C
0005433124176	29913	55	12D
0005432693466	29913	56	12E
0005433124171	29913	57	12F
0005432706840	29913	58	13A
0005432880991	29913	59	13C
0005432693454	29913	60	13D
0005432706951	29913	61	13E
0005432706727	29913	62	13F
0005432706921	29913	63	14A
0005432693442	29913	64	14C
0005432706839	29913	65	14D
0005432693444	29913	66	14E
0005432693460	29913	67	14F
0005432706934	29913	68	15A
0005432693448	29913	69	15C
0005432693450	29913	70	15D
0005432693459	29913	71	15E
0005433124168	29913	72	15F
0005432880990	29913	73	16A
0005432880998	29913	74	16C
0005432706774	29913	75	16D
0005432693451	29913	76	16E
0005432706947	29913	77	16F
0005432693472	29913	78	17A
0005432693469	29913	79	17C
0005432880986	29913	80	17D
0005433124173	29913	81	17E
0005432706905	29913	82	17F
0005432693470	29913	83	18A
0005432706909	29913	84	18C
0005432706812	29913	85	18D
0005432693464	29913	86	18E
0005432880993	29913	87	18F
0005433124166	29913	88	19A
0005432706891	29913	89	19C
0005432693453	29913	90	19D
0005432880994	29913	91	19E
0005432880999	29913	92	19F
0005433124174	29913	93	20A
0005432880989	29913	94	20C
0005433124177	29913	95	20D
0005432693465	29913	96	20E
0005432706943	29913	97	20F
0005434980135	23677	1	1A
0005434980126	23677	2	1B
0005434988868	23677	3	1C
0005434980138	23677	4	1D
0005434980121	23677	5	2A
0005434980134	23677	6	2B
0005434980120	23677	7	2C
0005434980141	23677	8	2D
0005434988866	23677	9	3A
0005434980116	23677	10	3B
0005434980139	23677	11	3C
0005434980118	23677	12	3D
0005434980115	23677	13	4A
0005434988861	23677	14	4B
0005434980119	23677	15	4D
0005434980117	23677	16	5A
0005434980127	23677	17	5B
0005434988863	23677	18	5D
0005434980128	23677	19	6B
0005434988869	23677	20	7A
0005434988865	23677	21	7B
0005434980122	23677	22	7C
0005434980132	23677	23	7D
0005434980130	23677	24	18A
0005434980142	23677	25	18B
0005434980143	23677	26	18C
0005434980114	23677	27	19A
0005434980123	23677	28	19B
0005434980133	23677	29	19C
0005434988864	23677	30	19D
0005434988867	23677	31	20B
0005434980140	23677	32	20C
0005434988862	23677	33	20D
0005434980125	23677	34	21B
0005434980129	23677	35	21C
0005434980136	23677	36	21D
0005434988860	23677	37	22A
0005434980124	23677	38	22B
0005434988870	23677	39	22C
0005434988859	23677	40	22D
0005434980137	23677	41	23A
0005434980131	23677	42	23B
0005434979902	27559	1	1A
0005434979884	27559	2	1B
0005434979782	27559	3	1C
0005434988735	27559	4	1D
0005434979925	27559	5	2A
0005434979930	27559	6	2B
0005434979772	27559	7	2C
0005434979856	27559	8	2D
0005434979688	27559	9	3A
0005434979836	27559	10	3B
0005434979933	27559	11	3C
0005434979931	27559	12	3D
0005434979899	27559	13	4A
0005434988713	27559	14	4B
0005434979773	27559	15	4D
0005434979994	27559	16	5A
0005434979929	27559	17	5B
0005434979718	27559	18	5C
0005434979921	27559	19	5D
0005434979874	27559	20	6A
0005434979898	27559	21	6B
0005434979813	27559	22	6C
0005434979781	27559	23	6D
0005434979808	27559	24	7A
0005434979717	27559	25	7B
0005434979872	27559	26	7C
0005434979807	27559	27	7D
0005434979901	27559	28	18A
0005434979897	27559	29	18B
0005434979857	27559	30	18C
0005434988736	27559	31	18D
0005434979865	27559	32	19A
0005434979780	27559	33	19B
0005434979689	27559	34	19C
0005434988722	27559	35	19D
0005434988714	27559	36	20A
0005434979900	27559	37	20B
0005434979963	27559	38	20C
0005434979860	27559	39	20D
0005434979932	27559	40	21A
0005434979877	27559	41	21B
0005434988723	27559	42	21C
0005434979866	27559	43	21D
0005434988748	27559	44	22A
0005434979826	27559	45	22B
0005434979858	27559	46	22C
0005434979774	27559	47	22D
0005434979873	27559	48	23A
0005434988759	27559	49	23B
0005433111512	10263	1	2B
0005434302507	10263	2	2D
0005434302508	10263	3	4B
0005433113541	10263	4	5A
0005433113540	10263	5	6D
0005434302510	10263	6	19B
0005434302506	10263	7	19D
0005434302511	10263	8	20B
0005433113544	10263	9	21D
0005434302509	10263	10	22A
0005433113563	19621	1	2A
0005434302463	19621	2	7D
0005434302460	19621	3	18D
0005434302474	19621	4	21C
0005434302459	19621	5	22D
0005435069695	3542	1	1C
0005435069733	3542	2	1D
0005435069743	3542	3	1F
0005435719009	3542	4	2C
0005435069711	3542	5	2D
0005435925338	3542	6	2F
0005435069723	3542	7	3A
0005435069742	3542	8	3C
0005435925340	3542	9	3D
0005435069745	3542	10	4A
0005435069737	3542	11	4D
0005435069704	3542	12	4E
0005435069709	3542	13	4F
0005435069697	3542	14	5A
0005435069712	3542	15	5D
0005435925317	3542	16	5F
0005435069714	3542	17	6A
0005435069741	3542	18	6D
0005435925321	3542	19	7A
0005435069740	3542	20	7D
0005435719005	3542	21	7E
0005435719004	3542	22	7F
0005435069716	3542	23	8A
0005435069735	3542	24	8C
0005435069747	3542	25	8D
0005435069717	3542	26	8E
0005435069729	3542	27	8F
0005435069701	3542	28	9A
0005435719003	3542	29	9C
0005435069696	3542	30	9E
0005435069730	3542	31	9F
0005435069700	3542	32	10A
0005435069708	3542	33	10D
0005435069732	3542	34	10E
0005435719008	3542	35	10F
0005435069715	3542	36	11A
0005435069727	3542	37	11D
0005435069744	3542	38	11E
0005435719006	3542	39	11F
0005435069720	3542	40	12C
0005435069731	3542	41	12D
0005435069710	3542	42	12E
0005435925339	3542	43	12F
0005435069705	3542	44	13A
0005435069746	3542	45	13C
0005435069698	3542	46	13D
0005435069738	3542	47	13E
0005435925318	3542	48	13F
0005435069728	3542	49	14A
0005435719010	3542	50	14D
0005435069706	3542	51	14E
0005435925330	3542	52	14F
0005435925335	3542	53	15A
0005435069724	3542	54	15C
0005435069713	3542	55	15F
0005435069722	3542	56	16A
0005435719007	3542	57	16C
0005435069748	3542	58	16D
0005435069721	3542	59	16E
0005435069734	3542	60	16F
0005435069702	3542	61	17C
0005435069739	3542	62	17D
0005435069736	3542	63	17F
0005435069699	3542	64	18C
0005435069726	3542	65	18D
0005435069718	3542	66	18E
0005435069719	3542	67	18F
0005435069703	3542	68	19A
0005435069725	3542	69	19C
0005435925331	3542	70	19D
0005435069707	3542	71	20A
0005435925334	3542	72	20D
0005435925325	3542	73	20E
0005435925319	3542	74	20F
0005435069322	15320	1	1C
0005435069089	15320	2	1D
0005435069182	15320	3	2C
0005435925464	15320	4	2D
0005435069134	15320	5	3A
0005435069202	15320	6	3D
0005435069305	15320	7	4A
0005435069260	15320	8	4C
0005435069155	15320	9	4D
0005435925466	15320	10	4E
0005435069255	15320	11	5A
0005435925463	15320	12	5C
0005435069025	15320	13	5D
0005435069250	15320	14	5E
0005435069178	15320	15	5F
0005435069059	15320	16	6A
0005435069261	15320	17	6D
0005435069046	15320	18	6F
0005435069052	15320	19	7E
0005435069185	15320	20	7F
0005435069064	15320	21	8A
0005435069206	15320	22	8F
0005435069113	15320	23	9A
0005435069287	15320	24	9C
0005435069213	15320	25	9D
0005435069148	15320	26	9E
0005435069252	15320	27	10A
0005435069124	15320	28	10C
0005435069243	15320	29	10D
0005435925465	15320	30	10F
0005435069180	15320	31	11A
0005435069056	15320	32	11C
0005435069024	15320	33	11D
0005435068976	15320	34	11E
0005435068955	15320	35	11F
0005435069194	15320	36	12D
0005435925462	15320	37	12E
0005435069146	15320	38	12F
0005435069090	15320	39	13C
0005435069091	15320	40	13F
0005435069228	15320	41	14C
0005435069181	15320	42	14D
0005435069171	15320	43	14E
0005435069238	15320	44	15A
0005435925467	15320	45	15C
0005435069051	15320	46	15D
0005435069177	15320	47	16A
0005435069240	15320	48	16C
0005435069053	15320	49	16D
0005435069079	15320	50	16E
0005435069308	15320	51	16F
0005435069118	15320	52	17C
0005435069201	15320	53	17D
0005435069195	15320	54	17E
0005435069086	15320	55	18A
0005435069262	15320	56	18D
0005435069112	15320	57	19A
0005435069065	15320	58	19C
0005435069242	15320	59	19D
0005435069239	15320	60	19E
0005435069237	15320	61	19F
0005435069219	15320	62	20A
0005435069184	15320	63	20E
0005432660843	18179	1	1A
0005432658617	18179	2	1B
0005432660842	18179	3	2A
0005432659732	18179	4	4A
0005432658616	18179	5	4B
0005432659731	18179	6	6A
0005432667459	26451	1	1B
0005432660824	26451	2	2B
0005432660828	26451	3	3A
0005432664135	26451	4	4A
0005432664140	26451	5	6A
0005433102177	92	1	1A
0005433102414	92	2	1C
0005432920080	92	3	1F
0005433102301	92	4	2D
0005432157516	92	5	2C
0005433102291	92	6	2F
0005432919993	92	7	3C
0005433102310	92	8	3F
0005433102344	92	9	4F
0005433102245	92	10	4D
0005433102258	92	11	5A
0005433102241	92	12	5F
0005432920024	92	13	5D
0005433102296	92	14	6A
0005433102027	92	15	6C
0005432901717	92	16	6D
0005432157515	92	17	6F
0005433102286	92	18	7F
0005432901667	92	19	7D
0005433102300	92	20	8B
0005433102379	92	21	8E
0005433102364	92	22	9B
0005433102378	92	23	9A
0005432919796	92	24	9C
0005433102309	92	25	9F
0005432901688	92	26	10A
0005432901755	92	27	10D
0005432919992	92	28	10E
0005433102318	92	29	10F
0005433102359	92	30	11B
0005433102086	92	31	11E
0005432901695	92	32	12A
0005433102363	92	33	11F
0005433102412	92	34	12B
0005433102282	92	35	12D
0005433102293	92	36	12E
0005433102342	92	37	12F
0005433102328	92	38	13A
0005432901582	92	39	13B
0005432901689	92	40	14A
0005432901696	92	41	13F
0005432919961	92	42	14B
0005432677585	92	43	14E
0005433102311	92	44	14F
0005433102308	92	45	15B
0005432901654	92	46	15A
0005433102085	92	47	15C
0005433102340	92	48	15E
0005432901599	92	49	16A
0005433102317	92	50	16C
0005433102406	92	51	16D
0005432919905	92	52	16E
0005433102158	92	53	17A
0005433102347	92	54	17F
0005433102246	92	55	17E
0005433102205	92	56	18A
0005433102325	92	57	18B
0005433102345	92	58	18C
0005432920081	92	59	18E
0005433102375	92	60	20A
0005432919934	92	61	20B
0005432919804	92	62	20E
0005433102295	92	63	20D
0005432901686	92	64	20F
0005432919999	92	65	21C
0005433102326	92	66	21B
0005432919966	92	67	21D
0005433102307	92	68	21E
0005432919954	92	69	22A
0005433102327	92	70	21F
0005432919970	92	71	22B
0005433102294	92	72	22C
0005432901718	92	73	22F
0005432901655	92	74	22E
0005433102329	92	75	23B
0005432920082	92	76	23E
0005433102251	92	77	23F
0005432901583	92	78	24A
0005433102297	92	79	25A
0005432920071	92	80	25C
0005433102352	92	81	25D
0005432901638	92	82	25E
0005433102365	92	83	26A
0005433102257	92	84	25F
0005433102346	92	85	26B
0005433102316	92	86	26C
0005432901716	92	87	26E
0005433102250	92	88	26D
0005432901653	92	89	27A
0005432919960	92	90	27C
0005433102413	92	91	27D
0005433102341	92	92	28A
0005433102415	92	93	27F
0005432901690	92	94	28B
0005433102333	92	95	28C
0005432901668	92	96	28E
0005433102357	92	97	28F
0005432901769	92	98	29A
0005432901677	92	99	29B
0005433102380	92	100	29D
0005432919893	92	101	29F
0005432901687	92	102	29E
0005433102358	92	103	30A
0005432901742	92	104	30F
0005432901758	92	105	31A
0005432919950	92	106	31C
0005432919918	92	107	31E
0005432262471	91	1	1C
0005432817821	91	2	1A
0005432817839	91	3	1D
0005432262451	91	4	2A
0005432207690	91	5	2C
0005432262452	91	6	2D
0005432817833	91	7	2F
0005432817823	91	8	3C
0005432262447	91	9	3F
0005432817842	91	10	4A
0005432817838	91	11	4C
0005432262464	91	12	4D
0005432756856	91	13	5F
0005432817848	91	14	6D
0005432262486	91	15	6F
0005432753306	91	16	7D
0005432817834	91	17	7C
0005432817847	91	18	7F
0005432817841	91	19	8A
0005432817825	91	20	8B
0005432262463	91	21	8E
0005432262457	91	22	9B
0005432262446	91	23	9C
0005432756854	91	24	9D
0005432207691	91	25	9E
0005432262488	91	26	9F
0005432756860	91	27	10D
0005432262478	91	28	10C
0005432289027	91	29	11A
0005432817844	91	30	11C
0005432262448	91	31	11F
0005432817846	91	32	12A
0005432817826	91	33	12D
0005432753311	91	34	12C
0005432817843	91	35	12F
0005432262467	91	36	13C
0005433687717	91	37	13B
0005432817819	91	38	13D
0005432262453	91	39	13E
0005432262456	91	40	14D
0005432817822	91	41	14C
0005432262450	91	42	14E
0005432262460	91	43	15A
0005432817840	91	44	15D
0005433687703	91	45	16A
0005432817824	91	46	15F
0005432756845	91	47	16C
0005432817845	91	48	16D
0005432756857	91	49	17A
0005432262465	91	50	17B
0005432817827	91	51	17C
0005432753323	91	52	17D
0005432753310	91	53	17F
0005432262477	91	54	18A
0005432817836	91	55	18C
0005432817837	91	56	18B
0005432207692	91	57	18E
0005432262449	91	58	18F
0005432262470	91	59	19C
0005432262455	91	60	20A
0005432262484	91	61	20C
0005432817832	91	62	20B
0005432817835	91	63	21C
0005432262468	91	64	21B
0005432817830	91	65	21D
0005432262444	91	66	21E
0005432262445	91	67	22A
0005432262487	91	68	22B
0005432756855	91	69	22C
0005432262466	91	70	22F
0005432262474	91	71	22E
0005432262476	91	72	23C
0005432289026	91	73	23B
0005432817829	91	74	23E
0005432262458	91	75	24A
0005432262469	91	76	24B
0005432756858	91	77	24C
0005432262482	91	78	24F
0005432262454	91	79	24E
0005432262472	91	80	25C
0005432753309	91	81	25F
0005432262459	91	82	26B
0005432756842	91	83	26C
0005432262480	91	84	26F
0005432262481	91	85	27A
0005432756859	91	86	27B
0005432817849	91	87	27D
0005432289025	91	88	28A
0005432817820	91	89	27F
0005432262490	91	90	28D
0005432756843	91	91	28E
0005432262483	91	92	29C
0005432817828	91	93	29D
0005433687718	91	94	29F
0005432262475	91	95	30B
0005432262462	91	96	30D
0005432262479	91	97	30C
0005432262461	91	98	30F
0005432262473	91	99	31B
0005432262489	91	100	31A
0005432262485	91	101	31C
0005432817831	91	102	31D
0005433687704	91	103	31F
0005432756853	91	104	31E
0005432020589	7953	1	1A
0005432920120	7953	2	1D
0005432920108	7953	3	2A
0005433102787	7953	4	1F
0005432020598	7953	5	2C
0005432920104	7953	6	2D
0005433102777	7953	7	2F
0005432020581	7953	8	3C
0005432677623	7953	9	3D
0005433102810	7953	10	3F
0005433102773	7953	11	4C
0005432020590	7953	12	4D
0005433102803	7953	13	4F
0005432020577	7953	14	5C
0005432392036	7953	15	5F
0005432020594	7953	16	6A
0005433102814	7953	17	6C
0005433102770	7953	18	6F
0005432920117	7953	19	7C
0005433102811	7953	20	7F
0005432920112	7953	21	8C
0005432753344	7953	22	8B
0005433102798	7953	23	8E
0005432020585	7953	24	8F
0005432920119	7953	25	9A
0005433102816	7953	26	9B
0005432020592	7953	27	9E
0005433102768	7953	28	10A
0005432020575	7953	29	9F
0005433102819	7953	30	10C
0005433102790	7953	31	10D
0005433102818	7953	32	10E
0005433102769	7953	33	10F
0005433102808	7953	34	11B
0005432044558	7953	35	11A
0005433102791	7953	36	11F
0005432920105	7953	37	12A
0005432920107	7953	38	12B
0005432020593	7953	39	12D
0005432044559	7953	40	12C
0005432753342	7953	41	12E
0005433102805	7953	42	12F
0005433102809	7953	43	13A
0005432044557	7953	44	13C
0005433102820	7953	45	13B
0005432020579	7953	46	13E
0005433102807	7953	47	13D
0005433102815	7953	48	13F
0005432020580	7953	49	14A
0005432020591	7953	50	14B
0005432920114	7953	51	14D
0005432920116	7953	52	15C
0005432753345	7953	53	15D
0005433102792	7953	54	16A
0005433102804	7953	55	15F
0005433102794	7953	56	16C
0005432392037	7953	57	16B
0005432920111	7953	58	16D
0005432677622	7953	59	16E
0005432045639	7953	60	16F
0005433102780	7953	61	17A
0005432920109	7953	62	17B
0005432920123	7953	63	17F
0005432020595	7953	64	18A
0005433102786	7953	65	18C
0005432392035	7953	66	18D
0005432677624	7953	67	18E
0005433102788	7953	68	19B
0005432020601	7953	69	19C
0005432920113	7953	70	19E
0005432920106	7953	71	20A
0005432753341	7953	72	20E
0005432020599	7953	73	20D
0005433102778	7953	74	21A
0005432045638	7953	75	21B
0005433102800	7953	76	21F
0005433102806	7953	77	21E
0005433102771	7953	78	22C
0005433102783	7953	79	22D
0005432920115	7953	80	22F
0005432020586	7953	81	22E
0005433102795	7953	82	23B
0005432920118	7953	83	23A
0005432020578	7953	84	23D
0005433102781	7953	85	23E
0005432020583	7953	86	24A
0005433102813	7953	87	23F
0005432920122	7953	88	24B
0005432020582	7953	89	24D
0005432020597	7953	90	25A
0005433102799	7953	91	25C
0005433102796	7953	92	25B
0005433102774	7953	93	25E
0005432020588	7953	94	26A
0005433102775	7953	95	25F
0005433102772	7953	96	26C
0005433102789	7953	97	27A
0005432020596	7953	98	26F
0005433102801	7953	99	26E
0005432751569	7953	100	27B
0005433102785	7953	101	27C
0005433102782	7953	102	27F
0005433102797	7953	103	27E
0005433102767	7953	104	28B
0005433102793	7953	105	28D
0005433102802	7953	106	28C
0005433102766	7953	107	28E
0005432753343	7953	108	29A
0005433102817	7953	109	28F
0005432677621	7953	110	29C
0005432751568	7953	111	29E
0005432020576	7953	112	29D
0005432020584	7953	113	30B
0005433102776	7953	114	30A
0005432920110	7953	115	30D
0005432751567	7953	116	30C
0005433102812	7953	117	30F
0005432020602	7953	118	30E
0005433102784	7953	119	31A
0005433102779	7953	120	31C
0005432020600	7953	121	31B
0005432020587	7953	122	31E
0005432920121	7953	123	31F
0005432901819	7952	1	1C
0005432817523	7952	2	1F
0005432817440	7952	3	2F
0005432901830	7952	4	2D
0005432817664	7952	5	3C
0005432817565	7952	6	4A
0005432817591	7952	7	5A
0005432817528	7952	8	4F
0005432901821	7952	9	5F
0005432817569	7952	10	6C
0005432817681	7952	11	7C
0005432817634	7952	12	7F
0005432901827	7952	13	8C
0005432817567	7952	14	9A
0005432002104	7952	15	9B
0005432817680	7952	16	9D
0005432817580	7952	17	9E
0005432817417	7952	18	10C
0005432817566	7952	19	10E
0005432901833	7952	20	11B
0005432901823	7952	21	11D
0005432901820	7952	22	12A
0005432817522	7952	23	12D
0005432901832	7952	24	12E
0005432817492	7952	25	13A
0005432901826	7952	26	13F
0005432817623	7952	27	14B
0005432817475	7952	28	14F
0005432002101	7952	29	15B
0005432817589	7952	30	15C
0005432901831	7952	31	16B
0005432817527	7952	32	16E
0005432817555	7952	33	16D
0005432817715	7952	34	17D
0005432901834	7952	35	18A
0005432817579	7952	36	17F
0005432817587	7952	37	18D
0005432817686	7952	38	18E
0005432901824	7952	39	19B
0005432817614	7952	40	19C
0005432817624	7952	41	19D
0005432817657	7952	42	20C
0005432817525	7952	43	20E
0005432901818	7952	44	20F
0005432817592	7952	45	21C
0005432901825	7952	46	21E
0005432817695	7952	47	23C
0005432817474	7952	48	23B
0005432901816	7952	49	24B
0005432817602	7952	50	24E
0005432901828	7952	51	25B
0005432817556	7952	52	26A
0005432002103	7952	53	26C
0005432901822	7952	54	26E
0005432817586	7952	55	27A
0005432002100	7952	56	28E
0005432817702	7952	57	29A
0005432901817	7952	58	29B
0005432002102	7952	59	29F
0005432817590	7952	60	29E
0005432817598	7952	61	30F
0005432817679	7952	62	31A
0005432901829	7952	63	31C
0005432817656	7952	64	31F
0005433870757	9646	1	1A
0005433870758	9646	2	2A
0005434175770	9646	3	6A
0005434175758	9646	4	5B
0005434175769	9646	5	6B
0005434175803	32323	1	1A
0005433870733	32323	2	2B
0005434175806	32323	3	3A
0005433870745	32323	4	3B
0005434175805	32323	5	4A
0005434175804	32323	6	4B
0005433870735	32323	7	5A
0005433870732	32323	8	5B
0005433870734	32323	9	6A
0005434175807	32323	10	6B
0005432799811	3497	1	1C
0005432799792	3497	2	1D
0005432799801	3497	3	1K
0005434938380	3497	4	1H
0005432799805	3497	5	2A
0005434879397	3497	6	3A
0005434879427	3497	7	2K
0005434426963	3497	8	3D
0005434879408	3497	9	3C
0005434879434	3497	10	3K
0005434879368	3497	11	3H
0005432183495	3497	12	4A
0005432188648	3497	13	4H
0005434879401	3497	14	5D
0005434938378	3497	15	5A
0005435126858	3497	16	5G
0005435126893	3497	17	5K
0005432799809	3497	18	11C
0005435126867	3497	19	11F
0005435626404	3497	20	11K
0005434879349	3497	21	12C
0005434879392	3497	22	12E
0005434879390	3497	23	12D
0005435126873	3497	24	12G
0005434879360	3497	25	12H
0005434879437	3497	26	13D
0005434426969	3497	27	13C
0005434879411	3497	28	13F
0005434879423	3497	29	13E
0005434879439	3497	30	13G
0005434938391	3497	31	14C
0005434879435	3497	32	14A
0005432799819	3497	33	13K
0005435126882	3497	34	14D
0005434879358	3497	35	14G
0005434879363	3497	36	14F
0005434426976	3497	37	14E
0005435126884	3497	38	15A
0005435126870	3497	39	15E
0005434938377	3497	40	15F
0005434879407	3497	41	16A
0005434879432	3497	42	15K
0005435126894	3497	43	15H
0005432799813	3497	44	16C
0005434879385	3497	45	17C
0005435626400	3497	46	17A
0005434879430	3497	47	17H
0005434879393	3497	48	17G
0005434879379	3497	49	18A
0005434426966	3497	50	18C
0005435902719	3497	51	18B
0005434426988	3497	52	18E
0005434426970	3497	53	18D
0005432799817	3497	54	18G
0005435626413	3497	55	18F
0005432611756	3497	56	18K
0005435126895	3497	57	18J
0005434879424	3497	58	19A
0005434879380	3497	59	19D
0005432799806	3497	60	19F
0005435126857	3497	61	19H
0005434879369	3497	62	19K
0005434879364	3497	63	19J
0005434879412	3497	64	20B
0005435626399	3497	65	20E
0005434879414	3497	66	20D
0005435902787	3497	67	20G
0005434938383	3497	68	20K
0005435126871	3497	69	20J
0005435126888	3497	70	20H
0005435126855	3497	71	21A
0005434879371	3497	72	21D
0005435126872	3497	73	21C
0005435126878	3497	74	21F
0005435626402	3497	75	21E
0005434879398	3497	76	22A
0005434879417	3497	77	21K
0005435902703	3497	78	21J
0005435126864	3497	79	22C
0005435126887	3497	80	22F
0005435626401	3497	81	22E
0005434879376	3497	82	22D
0005434879382	3497	83	22G
0005435126889	3497	84	22K
0005432799797	3497	85	22J
0005435626406	3497	86	22H
0005432799815	3497	87	23D
0005432799804	3497	88	23C
0005435126862	3497	89	23G
0005434879403	3497	90	23F
0005435626410	3497	91	23J
0005432799799	3497	92	23H
0005434879396	3497	93	24D
0005434879352	3497	94	23K
0005434938392	3497	95	24E
0005432799807	3497	96	25A
0005435902830	3497	97	25D
0005435126885	3497	98	25G
0005434879422	3497	99	26A
0005434879420	3497	100	25K
0005434879410	3497	101	25J
0005432613910	3497	102	26C
0005434879367	3497	103	26B
0005435126866	3497	104	26E
0005434426968	3497	105	26D
0005435902836	3497	106	26G
0005434938382	3497	107	26F
0005434879431	3497	108	26H
0005435126869	3497	109	27A
0005435841095	3497	110	26K
0005435126861	3497	111	27D
0005432799812	3497	112	27C
0005434879356	3497	113	27F
0005435126868	3497	114	27E
0005434879378	3497	115	27H
0005434879388	3497	116	27K
0005435626408	3497	117	27J
0005434426974	3497	118	28B
0005434879374	3497	119	28A
0005434426980	3497	120	28E
0005435902778	3497	121	28G
0005434426987	3497	122	28H
0005435902727	3497	123	29B
0005432613912	3497	124	29A
0005434879355	3497	125	29C
0005432183493	3497	126	29F
0005434879409	3497	127	29E
0005434879365	3497	128	29J
0005432183494	3497	129	29H
0005434879359	3497	130	29G
0005435626403	3497	131	30A
0005432799808	3497	132	30B
0005434938384	3497	133	30D
0005435126865	3497	134	30F
0005434426984	3497	135	31A
0005435126856	3497	136	31C
0005434938379	3497	137	31G
0005435902717	3497	138	31K
0005435126863	3497	139	31J
0005434879406	3497	140	32C
0005434426962	3497	141	32B
0005434879381	3497	142	32E
0005434879366	3497	143	32D
0005435126890	3497	144	32F
0005435126879	3497	145	33B
0005434879426	3497	146	33A
0005434879348	3497	147	32K
0005434879350	3497	148	33C
0005432799803	3497	149	33F
0005435126874	3497	150	33H
0005434879433	3497	151	33G
0005434938387	3497	152	33K
0005434879373	3497	153	33J
0005434879413	3497	154	34B
0005435126877	3497	155	34A
0005434938373	3497	156	34E
0005432799821	3497	157	34G
0005432611758	3497	158	34F
0005435126883	3497	159	34J
0005434879384	3497	160	35A
0005434879404	3497	161	35D
0005435126892	3497	162	35C
0005432799816	3497	163	35F
0005434938386	3497	164	35H
0005432799820	3497	165	35G
0005434879389	3497	166	35J
0005434879362	3497	167	36D
0005434938375	3497	168	36C
0005434879387	3497	169	36B
0005434879441	3497	170	36G
0005435902702	3497	171	36F
0005434879375	3497	172	36K
0005435126859	3497	173	36H
0005432799800	3497	174	37B
0005435126860	3497	175	37D
0005435626405	3497	176	37C
0005434879415	3497	177	37G
0005434879346	3497	178	37J
0005434879370	3497	179	37H
0005434879361	3497	180	37K
0005434426979	3497	181	38C
0005434879391	3497	182	38B
0005434426983	3497	183	38J
0005434879394	3497	184	38H
0005435126876	3497	185	39B
0005432611757	3497	186	39A
0005434426985	3497	187	38K
0005432799795	3497	188	39E
0005432799810	3497	189	39H
0005435126891	3497	190	39G
0005435841096	3497	191	39K
0005434426972	3497	192	39J
0005435902718	3497	193	40C
0005434938389	3497	194	40B
0005434938381	3497	195	40A
0005432613913	3497	196	40E
0005435626411	3497	197	40D
0005435626412	3497	198	41B
0005434879347	3497	199	41A
0005432799793	3497	200	40K
0005434426982	3497	201	41D
0005435902704	3497	202	41C
0005432799802	3497	203	41E
0005434879402	3497	204	41H
0005434879418	3497	205	42C
0005434879399	3497	206	42B
0005435902792	3497	207	42E
0005434426977	3497	208	42D
0005435126896	3497	209	42H
0005434426961	3497	210	42F
0005434426967	3497	211	42K
0005434879429	3497	212	43A
0005435902837	3497	213	43D
0005434426964	3497	214	43C
0005434879354	3497	215	43F
0005434426978	3497	216	43E
0005435126886	3497	217	43J
0005434879377	3497	218	43H
0005435902793	3497	219	44B
0005434938376	3497	220	44A
0005434879416	3497	221	44D
0005435902751	3497	222	44H
0005434879395	3497	223	44G
0005435126881	3497	224	44F
0005434879419	3497	225	44J
0005434879405	3497	226	45A
0005435126875	3497	227	44K
0005432613911	3497	228	45D
0005434426973	3497	229	45C
0005432799794	3497	230	45F
0005434879353	3497	231	45H
0005434426960	3497	232	46A
0005434879372	3497	233	45J
0005435626407	3497	234	46C
0005434879351	3497	235	46E
0005434426975	3497	236	46D
0005434426971	3497	237	46G
0005432799796	3497	238	46F
0005435902767	3497	239	46J
0005434426986	3497	240	46H
0005434879440	3497	241	46K
0005434938385	3497	242	47C
0005435126880	3497	243	47G
0005434879425	3497	244	47H
0005434879438	3497	245	48D
0005432799814	3497	246	48C
0005432799818	3497	247	48A
0005434426965	3497	248	48F
0005434879421	3497	249	48E
0005432799798	3497	250	48G
0005434879386	3497	251	48K
0005435626409	3497	252	49E
0005434938390	3497	253	49G
0005434938374	3497	254	50C
0005434426981	3497	255	50A
0005434879400	3497	256	50E
0005434879383	3497	257	50D
0005432188650	3497	258	50H
0005432188649	3497	259	50G
0005434879428	3497	260	50F
0005434938388	3497	261	50K
0005434879436	3497	262	51E
0005434879357	3497	263	51G
0005434938238	14587	1	1C
0005434878783	14587	2	1A
0005434878821	14587	3	1D
0005432799477	14587	4	1K
0005435914710	14587	5	1H
0005434878654	14587	6	2C
0005434878449	14587	7	2A
0005435902923	14587	8	2G
0005435626216	14587	9	3A
0005435902916	14587	10	3G
0005434878633	14587	11	3D
0005434878664	14587	12	3C
0005434878928	14587	13	3H
0005434878655	14587	14	4A
0005432607589	14587	15	3K
0005434878709	14587	16	4G
0005435126311	14587	17	4D
0005434878933	14587	18	4K
0005434878231	14587	19	4H
0005435126362	14587	20	5A
0005432799459	14587	21	5H
0005434426676	14587	22	5G
0005435126505	14587	23	11A
0005435914706	14587	24	5K
0005434938252	14587	25	11D
0005435126568	14587	26	11C
0005435626236	14587	27	11G
0005434878373	14587	28	11F
0005435626223	14587	29	11H
0005435126475	14587	30	12C
0005435126673	14587	31	11K
0005434878131	14587	32	12E
0005434878534	14587	33	13A
0005434878317	14587	34	12H
0005435626217	14587	35	13D
0005434878382	14587	36	13C
0005434878589	14587	37	13G
0005435902930	14587	38	13E
0005434878415	14587	39	13H
0005432799527	14587	40	14A
0005434426777	14587	41	13K
0005434426865	14587	42	14D
0005435626257	14587	43	14H
0005434878729	14587	44	14G
0005434938187	14587	45	15A
0005434878322	14587	46	15E
0005435126566	14587	47	15F
0005435626251	14587	48	15K
0005435902919	14587	49	16D
0005432799703	14587	50	16C
0005435126545	14587	51	16A
0005435913968	14587	52	16H
0005435902915	14587	53	17C
0005434878127	14587	54	17E
0005434878426	14587	55	17H
0005432059528	14587	56	18A
0005435126485	14587	57	18E
0005434878644	14587	58	18C
0005435126463	14587	59	18G
0005435626169	14587	60	18J
0005434938195	14587	61	18K
0005434938281	14587	62	19D
0005434878234	14587	63	19C
0005434878197	14587	64	19F
0005435126635	14587	65	19H
0005434426775	14587	66	19K
0005434878368	14587	67	20C
0005432799526	14587	68	20E
0005434938266	14587	69	20D
0005434426767	14587	70	20G
0005434938288	14587	71	20F
0005434878927	14587	72	20K
0005434878577	14587	73	20J
0005435626226	14587	74	20H
0005434878539	14587	75	21B
0005434426675	14587	76	21A
0005435902920	14587	77	21D
0005432799424	14587	78	21C
0005434878837	14587	79	21F
0005434878666	14587	80	21E
0005435126573	14587	81	21J
0005432799478	14587	82	21H
0005434878628	14587	83	21K
0005434878839	14587	84	22C
0005435126636	14587	85	22B
0005434878521	14587	86	22F
0005434938273	14587	87	22E
0005434878394	14587	88	22G
0005434426651	14587	89	22J
0005434426768	14587	90	22H
0005434878514	14587	91	23A
0005432799555	14587	92	22K
0005434878537	14587	93	23D
0005435126375	14587	94	23C
0005435626184	14587	95	23F
0005435902928	14587	96	23E
0005435913966	14587	97	23J
0005434878232	14587	98	23G
0005434878582	14587	99	24D
0005434878316	14587	100	23K
0005434878725	14587	101	24F
0005434878233	14587	102	24E
0005435126310	14587	103	25B
0005434878901	14587	104	25A
0005434878445	14587	105	25C
0005432799575	14587	106	25F
0005434878670	14587	107	25E
0005434878671	14587	108	25H
0005432799568	14587	109	25J
0005432799567	14587	110	26C
0005432799701	14587	111	26B
0005434878801	14587	112	26E
0005435902929	14587	113	26D
0005434878384	14587	114	26G
0005432799531	14587	115	26F
0005435914708	14587	116	26J
0005435902917	14587	117	26H
0005434878464	14587	118	27D
0005435126436	14587	119	27C
0005434878587	14587	120	27B
0005434426729	14587	121	27F
0005432799628	14587	122	27H
0005435126506	14587	123	27K
0005434878532	14587	124	28B
0005435126342	14587	125	28A
0005435841832	14587	126	28E
0005434426722	14587	127	28D
0005434878475	14587	128	28G
0005434878579	14587	129	28F
0005432799539	14587	130	28J
0005434938228	14587	131	28H
0005434938186	14587	132	29B
0005435902925	14587	133	29A
0005435902914	14587	134	29D
0005432607588	14587	135	29H
0005434878586	14587	136	30A
0005432059529	14587	137	30C
0005435626193	14587	138	30E
0005432799481	14587	139	30G
0005432799599	14587	140	30H
0005432607592	14587	141	31B
0005435626168	14587	142	31A
0005435902926	14587	143	31C
0005435126574	14587	144	31F
0005434878882	14587	145	31E
0005434878624	14587	146	31D
0005435126466	14587	147	31H
0005432611714	14587	148	32A
0005434878165	14587	149	31K
0005434426650	14587	150	31J
0005432799572	14587	151	32C
0005435126672	14587	152	32B
0005434878443	14587	153	32E
0005434878784	14587	154	32D
0005435626218	14587	155	32F
0005435914707	14587	156	32J
0005434878417	14587	157	32H
0005435902924	14587	158	33C
0005435126538	14587	159	33F
0005435126320	14587	160	33H
0005435626258	14587	161	33J
0005434878191	14587	162	34B
0005434878904	14587	163	34D
0005435626229	14587	164	34G
0005432799631	14587	165	34F
0005434878296	14587	166	34K
0005434878733	14587	167	34J
0005435126569	14587	168	35A
0005435913967	14587	169	35F
0005435902918	14587	170	35E
0005434878855	14587	171	35H
0005434878192	14587	172	35G
0005434878653	14587	173	36A
0005432799569	14587	174	36C
0005435626170	14587	175	36B
0005432799425	14587	176	36F
0005435626164	14587	177	36G
0005435126493	14587	178	36K
0005432799648	14587	179	36J
0005434878225	14587	180	37E
0005435126335	14587	181	37D
0005434878634	14587	182	37C
0005434878748	14587	183	37G
0005434878721	14587	184	38A
0005435914709	14587	185	37K
0005434878308	14587	186	37J
0005434426701	14587	187	38C
0005434878395	14587	188	38B
0005435126590	14587	189	38J
0005434426700	14587	190	38H
0005434878531	14587	191	39B
0005434938194	14587	192	39A
0005434878442	14587	193	39D
0005435126589	14587	194	39H
0005434426740	14587	195	39G
0005434878562	14587	196	40A
0005434878856	14587	197	39K
0005434878730	14587	198	39J
0005434426678	14587	199	40C
0005434426705	14587	200	40B
0005434878374	14587	201	40F
0005435902922	14587	202	40E
0005435126508	14587	203	40D
0005434938201	14587	204	40G
0005432799574	14587	205	40J
0005435626239	14587	206	40H
0005434878645	14587	207	41A
0005434878341	14587	208	41H
0005435914705	14587	209	41G
0005435126435	14587	210	42A
0005434878226	14587	211	41K
0005434426746	14587	212	42C
0005435626143	14587	213	42B
0005434878617	14587	214	42F
0005434938284	14587	215	42E
0005434878190	14587	216	42D
0005434878242	14587	217	42G
0005434426696	14587	218	43A
0005434878782	14587	219	42K
0005435902931	14587	220	43D
0005434878241	14587	221	43C
0005434878669	14587	222	43F
0005434878723	14587	223	43J
0005435841831	14587	224	43H
0005434878383	14587	225	43G
0005432799532	14587	226	44A
0005435626256	14587	227	43K
0005434878785	14587	228	44E
0005434878681	14587	229	44H
0005434878749	14587	230	44G
0005434878643	14587	231	45A
0005434938282	14587	232	45F
0005435126521	14587	233	45E
0005434878465	14587	234	45G
0005434426806	14587	235	45K
0005434878929	14587	236	46C
0005434878698	14587	237	46B
0005435902927	14587	238	46D
0005434426677	14587	239	46G
0005435626185	14587	240	46F
0005435626227	14587	241	46J
0005434878288	14587	242	47A
0005435902921	14587	243	47E
0005432799551	14587	244	47C
0005435626238	14587	245	47G
0005434878858	14587	246	47F
0005434878323	14587	247	47K
0005434878623	14587	248	47H
0005434878857	14587	249	48A
0005434878618	14587	250	48H
0005434938102	14587	251	48G
0005434426713	14587	252	49A
0005434426801	14587	253	49D
0005434426674	14587	254	49C
0005434938101	14587	255	49G
0005434938226	14587	256	49F
0005435626228	14587	257	49E
0005434426774	14587	258	49H
0005434878548	14587	259	50C
0005435126474	14587	260	50A
0005432799576	14587	261	50E
0005434426812	14587	262	50D
0005434878600	14587	263	50F
0005432799590	14587	264	51D
0005434878369	14587	265	50K
0005434878796	14587	266	50H
0005432799702	14587	267	51F
0005434938227	14587	268	51E
0005435889893	3632	1	1B
0005435889915	3632	2	2C
0005434325790	3632	3	3B
0005434325794	3632	4	3D
0005435889916	3632	5	4A
0005434312344	3632	6	4C
0005435889943	3632	7	5A
0005435889930	3632	8	6A
0005435889945	3632	9	6B
0005434325797	3632	10	6D
0005434325792	3632	11	7A
0005435889889	3632	12	7B
0005434325789	3632	13	7D
0005435889922	3632	14	18C
0005435889929	3632	15	18D
0005434325795	3632	16	19B
0005434325793	3632	17	19C
0005434325791	3632	18	19D
0005435889918	3632	19	20A
0005435889903	3632	20	20C
0005434325786	3632	21	21B
0005434325788	3632	22	21C
0005435889888	3632	23	21D
0005434325796	3632	24	22A
0005435889917	3632	25	22D
0005434312345	3632	26	23A
0005434325787	3632	27	23B
0005434325702	15620	1	1A
0005434325726	15620	2	1C
0005434325711	15620	3	1D
0005435889971	15620	4	2C
0005435889968	15620	5	3A
0005434325750	15620	6	3B
0005434325684	15620	7	3C
0005434325752	15620	8	3D
0005434325672	15620	9	5A
0005435889973	15620	10	5B
0005434325751	15620	11	6A
0005434325692	15620	12	6B
0005435889969	15620	13	6C
0005434325691	15620	14	7C
0005434325717	15620	15	18A
0005434325679	15620	16	18D
0005435889972	15620	17	19B
0005434325698	15620	18	19D
0005434325693	15620	19	20C
0005434325673	15620	20	21B
0005434325712	15620	21	21D
0005435889970	15620	22	22C
0005435957877	645	1	1B
0005435957880	645	2	2C
0005435957891	645	3	3C
0005435957888	645	4	3D
0005435957881	645	5	4C
0005435957884	645	6	4D
0005435957882	645	7	6B
0005435957876	645	8	6C
0005433420429	645	9	7A
0005435957883	645	10	7C
0005435957890	645	11	18C
0005435957887	645	12	19C
0005435957879	645	13	19D
0005435957889	645	14	20C
0005433420438	645	15	21A
0005433420439	645	16	21C
0005433420430	645	17	21D
0005435957886	645	18	22A
0005435957878	645	19	22B
0005435957885	645	20	22C
0005433420508	15196	1	2C
0005433420506	15196	2	3C
0005435957789	15196	3	3D
0005435957757	15196	4	4A
0005433420511	15196	5	4B
0005435957717	15196	6	4C
0005435957792	15196	7	4D
0005435957776	15196	8	5A
0005435957752	15196	9	5D
0005435957712	15196	10	6A
0005435957758	15196	11	6B
0005435957736	15196	12	6D
0005433420512	15196	13	7B
0005435957793	15196	14	7C
0005435957740	15196	15	7D
0005433420507	15196	16	18B
0005435957716	15196	17	18C
0005433420505	15196	18	18D
0005435957711	15196	19	19A
0005435957753	15196	20	19B
0005433420504	15196	21	19D
0005435957720	15196	22	20B
0005435957741	15196	23	20C
0005433420509	15196	24	22B
0005435957742	15196	25	22C
0005433420510	15196	26	23B
0005434995305	23999	1	1A
0005434995301	23999	2	4C
0005434995297	23999	3	4E
0005434995283	23999	4	4F
0005434995304	23999	5	5C
0005434995299	23999	6	7B
0005434995303	23999	7	7A
0005434995298	23999	8	7C
0005434995300	23999	9	14A
0005434995306	23999	10	19E
0005434995302	23999	11	22C
0005434995307	23999	12	23E
0005435629418	8873	1	1A
0005434247153	8873	2	1B
0005435629419	8873	3	3A
0005434247154	8873	4	6A
0005434247179	16058	1	1B
0005435629405	16058	2	3A
0005434247180	16058	3	4B
0005434247178	16058	4	6A
0005433404856	2870	1	1C
0005435797645	2870	2	2C
0005435797651	2870	3	3A
0005435797648	2870	4	3D
0005433404857	2870	5	3F
0005435797657	2870	6	4C
0005435797658	2870	7	4D
0005435797656	2870	8	4F
0005435797646	2870	9	7D
0005435797654	2870	10	8C
0005435797653	2870	11	9A
0005435797644	2870	12	9C
0005435797642	2870	13	12D
0005435797649	2870	14	12F
0005435797655	2870	15	13E
0005435797650	2870	16	15A
0005435797647	2870	17	16D
0005433404858	2870	18	19A
0005435797652	2870	19	19F
0005435797643	2870	20	20D
0005433404904	29314	1	1D
0005435797540	29314	2	1F
0005435797556	29314	3	2A
0005435797554	29314	4	3D
0005435797539	29314	5	3F
0005435797549	29314	6	4C
0005433404899	29314	7	4E
0005433404906	29314	8	5E
0005433404898	29314	9	6C
0005435797495	29314	10	6E
0005433404903	29314	11	7A
0005435797573	29314	12	7F
0005435797538	29314	13	8C
0005435797542	29314	14	9E
0005435797548	29314	15	10A
0005435797543	29314	16	10D
0005435797494	29314	17	11F
0005433404900	29314	18	12C
0005435797564	29314	19	13E
0005433404902	29314	20	14A
0005435797552	29314	21	14C
0005435797553	29314	22	14D
0005435797537	29314	23	16E
0005435797504	29314	24	17A
0005435797521	29314	25	17F
0005435797550	29314	26	18A
0005433404901	29314	27	19A
0005433404905	29314	28	19E
0005435797505	29314	29	20D
0005435376366	5825	1	1B
0005435376367	5825	2	3A
0005435376368	5825	3	3B
0005434948130	5829	1	1A
0005434948125	5829	2	1B
0005434948126	5829	3	2A
0005434948128	5829	4	2B
0005434948121	5829	5	3A
0005434948129	5829	6	3B
0005434948127	5829	7	4B
0005434948122	5829	8	5B
0005434948124	5829	9	6A
0005434948123	5829	10	6B
0005434948035	16325	1	1A
0005434948069	16325	2	1B
0005435376383	16325	3	2A
0005434948068	16325	4	2B
0005435376381	16325	5	3B
0005435376382	16325	6	3A
0005435376387	16325	7	4A
0005435376386	16325	8	4B
0005434948057	16325	9	5A
0005434948056	16325	10	5B
0005435376385	16325	11	6A
0005435376384	16325	12	6B
0005433961563	6888	1	1A
0005433961557	6888	2	1C
0005433961590	6888	3	1F
0005433961565	6888	4	2C
0005433961544	6888	5	2F
0005433961561	6888	6	3A
0005433961547	6888	7	3C
0005433961581	6888	8	3D
0005433961586	6888	9	4A
0005433961583	6888	10	4D
0005433961558	6888	11	4E
0005433961550	6888	12	4F
0005433961580	6888	13	5A
0005433961564	6888	14	5E
0005433961536	6888	15	5F
0005433961551	6888	16	6C
0005433961569	6888	17	6D
0005433961538	6888	18	7F
0005433961556	6888	19	8A
0005433961548	6888	20	8C
0005433961573	6888	21	8E
0005433961532	6888	22	9A
0005433961579	6888	23	9D
0005433961534	6888	24	9E
0005433961567	6888	25	9F
0005433961574	6888	26	10A
0005433961582	6888	27	10C
0005433961571	6888	28	10D
0005433961588	6888	29	10E
0005433961591	6888	30	10F
0005433961560	6888	31	11C
0005433961587	6888	32	11D
0005433961533	6888	33	11E
0005433961540	6888	34	11F
0005433961546	6888	35	12A
0005433961578	6888	36	12C
0005433961537	6888	37	12D
0005433961553	6888	38	12F
0005433961562	6888	39	13A
0005433961554	6888	40	13D
0005433961555	6888	41	13E
0005433961541	6888	42	14A
0005433961589	6888	43	14D
0005433961549	6888	44	15C
0005433961539	6888	45	15D
0005433961572	6888	46	15E
0005433961535	6888	47	16A
0005433961542	6888	48	16D
0005433961577	6888	49	16F
0005433961568	6888	50	17A
0005433961575	6888	51	17D
0005433961543	6888	52	17E
0005433961559	6888	53	18A
0005433961584	6888	54	19A
0005433961566	6888	55	19C
0005433961585	6888	56	19D
0005433961545	6888	57	19E
0005433961576	6888	58	20A
0005433961570	6888	59	19F
0005433961552	6888	60	20C
0005433960877	25750	1	1C
0005433960939	25750	2	1D
0005433960902	25750	3	2C
0005433960871	25750	4	3A
0005433960880	25750	5	3C
0005433960975	25750	6	3D
0005433960817	25750	7	3F
0005433960940	25750	8	4A
0005433960827	25750	9	4C
0005433960748	25750	10	4D
0005433960687	25750	11	5A
0005433960853	25750	12	5D
0005433960818	25750	13	5F
0005433960993	25750	14	6C
0005433960986	25750	15	6E
0005433960882	25750	16	6F
0005433960837	25750	17	7A
0005433960947	25750	18	7C
0005433960907	25750	19	7D
0005433960973	25750	20	7E
0005433960913	25750	21	8A
0005433960977	25750	22	8C
0005433960760	25750	23	8D
0005433960884	25750	24	8E
0005433960852	25750	25	8F
0005433960854	25750	26	9C
0005433960868	25750	27	9D
0005433960888	25750	28	9E
0005433960865	25750	29	9F
0005433960819	25750	30	10A
0005433960950	25750	31	10F
0005433960976	25750	32	11D
0005433960815	25750	33	11C
0005433960795	25750	34	11F
0005433960851	25750	35	12C
0005433960968	25750	36	12E
0005433960985	25750	37	13C
0005433960761	25750	38	13E
0005433960873	25750	39	13F
0005433960769	25750	40	14A
0005433960642	25750	41	14C
0005433960987	25750	42	14E
0005433960836	25750	43	14F
0005433960879	25750	44	15A
0005433960883	25750	45	15C
0005433960962	25750	46	16A
0005433960805	25750	47	16C
0005433960915	25750	48	16D
0005433960878	25750	49	16E
0005433960914	25750	50	16F
0005433960588	25750	51	17D
0005433960814	25750	52	17F
0005433960904	25750	53	18C
0005433960816	25750	54	18D
0005433960963	25750	55	18F
0005433960984	25750	56	19A
0005433960823	25750	57	19D
0005433960674	25750	58	19F
0005433960822	25750	59	20C
0005435082819	24517	1	1A
0005435082794	24517	2	1B
0005435082818	24517	3	2B
0005435082836	24517	4	4A
0005435082810	24517	5	4B
0005435082837	24517	6	5B
0005435082838	24517	7	5A
0005435082787	24517	8	6B
0005435082878	26085	1	1A
0005435082881	26085	2	2B
0005435082873	26085	3	3A
0005435082875	26085	4	3B
0005435082879	26085	5	5A
0005435082877	26085	6	4B
0005435082880	26085	7	5B
0005435082874	26085	8	6A
0005435082876	26085	9	6B
0005433534504	5136	1	1A
0005434245339	5136	2	2D
0005434245354	5136	3	2C
0005434245343	5136	4	3A
0005435286649	5136	5	3C
0005434245327	5136	6	4F
0005435286635	5136	7	6C
0005434245329	5136	8	7A
0005435286645	5136	9	7C
0005434245346	5136	10	10D
0005434245348	5136	11	10C
0005434245337	5136	12	11E
0005434245345	5136	13	12A
0005434245351	5136	14	12C
0005434245336	5136	15	12D
0005434245355	5136	16	14A
0005434245332	5136	17	15B
0005434245350	5136	18	15D
0005435286646	5136	19	15F
0005434245347	5136	20	17A
0005435286644	5136	21	17C
0005434245356	5136	22	18C
0005434245334	5136	23	18D
0005434245342	5136	24	19D
0005434245340	5136	25	20D
0005434245349	5136	26	20F
0005435286654	5136	27	21E
0005434245341	5136	28	22B
0005432166941	5136	29	22D
0005434245333	5136	30	23D
0005434245353	5136	31	23F
0005434245352	5136	32	24D
0005434245330	5136	33	25E
0005434245344	5136	34	27B
0005434245335	5136	35	27F
0005435286648	5136	36	28D
0005435286639	5136	37	30A
0005434245328	5136	38	29F
0005434245338	5136	39	30C
0005432166942	5136	40	30F
0005434245331	5136	41	31B
0005433785394	5135	1	1A
0005432106166	5135	2	1C
0005433785389	5135	3	1F
0005433615621	5135	4	1D
0005433615622	5135	5	2A
0005433785384	5135	6	2C
0005433785404	5135	7	2D
0005432106143	5135	8	3A
0005432666413	5135	9	2F
0005433785407	5135	10	3D
0005433615584	5135	11	3C
0005433615590	5135	12	4A
0005433615620	5135	13	3F
0005433615591	5135	14	4C
0005433615601	5135	15	4D
0005432106165	5135	16	5A
0005433615628	5135	17	4F
0005433785390	5135	18	5C
0005432106175	5135	19	5F
0005432106133	5135	20	5D
0005433615561	5135	21	6A
0005433785376	5135	22	6C
0005433785395	5135	23	6D
0005433785386	5135	24	7A
0005433615573	5135	25	6F
0005433785397	5135	26	7C
0005433785398	5135	27	7F
0005432106132	5135	28	7D
0005433615606	5135	29	8A
0005433785402	5135	30	8B
0005433615602	5135	31	8C
0005433785406	5135	32	8E
0005432106177	5135	33	8D
0005433615607	5135	34	8F
0005432106153	5135	35	9A
0005433615612	5135	36	9C
0005432106169	5135	37	9B
0005433615604	5135	38	9D
0005432106147	5135	39	9F
0005433615619	5135	40	9E
0005432106158	5135	41	10A
0005432145137	5135	42	10C
0005433785410	5135	43	10B
0005433615618	5135	44	10E
0005432106171	5135	45	10D
0005433615560	5135	46	10F
0005433615629	5135	47	11B
0005432665299	5135	48	11A
0005432106161	5135	49	11C
0005433615589	5135	50	11D
0005433615623	5135	51	11E
0005433785405	5135	52	12A
0005433615600	5135	53	11F
0005433785388	5135	54	12B
0005433615587	5135	55	12D
0005433785377	5135	56	12C
0005432667478	5135	57	12E
0005433615575	5135	58	13A
0005432106136	5135	59	12F
0005433615592	5135	60	13C
0005433785375	5135	61	13B
0005432106162	5135	62	13D
0005433615576	5135	63	13F
0005432106134	5135	64	13E
0005432106152	5135	65	14A
0005433615610	5135	66	14B
0005433615583	5135	67	14D
0005433615574	5135	68	14C
0005433615593	5135	69	14E
0005432106168	5135	70	15A
0005433615609	5135	71	14F
0005432106145	5135	72	15B
0005433615580	5135	73	15C
0005433615625	5135	74	15D
0005432106146	5135	75	15E
0005432106139	5135	76	16A
0005432106157	5135	77	15F
0005433785400	5135	78	16B
0005433615569	5135	79	16D
0005433615579	5135	80	16C
0005432665300	5135	81	16E
0005432106180	5135	82	17A
0005433785382	5135	83	16F
0005433785379	5135	84	17B
0005433615581	5135	85	17C
0005432106144	5135	86	17D
0005433615611	5135	87	17F
0005433615567	5135	88	17E
0005433615603	5135	89	18A
0005433615597	5135	90	18B
0005433785396	5135	91	18D
0005433615614	5135	92	18C
0005433615564	5135	93	18E
0005432106154	5135	94	18F
0005433785387	5135	95	19B
0005432106148	5135	96	19D
0005433615557	5135	97	19C
0005433615558	5135	98	20A
0005432106151	5135	99	19E
0005432106149	5135	100	20C
0005432106155	5135	101	20B
0005433785378	5135	102	20D
0005433615616	5135	103	20F
0005432106160	5135	104	20E
0005433615559	5135	105	21B
0005433785409	5135	106	21A
0005433615578	5135	107	21D
0005432106170	5135	108	21C
0005433615627	5135	109	21E
0005433615577	5135	110	21F
0005433785408	5135	111	22B
0005432106176	5135	112	22A
0005433785383	5135	113	22C
0005432106167	5135	114	22E
0005432106174	5135	115	22D
0005433615588	5135	116	23B
0005432106142	5135	117	23A
0005433785385	5135	118	22F
0005432667479	5135	119	23C
0005433615613	5135	120	23D
0005433785392	5135	121	23F
0005433785381	5135	122	23E
0005432106178	5135	123	24A
0005432106141	5135	124	24B
0005433785393	5135	125	24C
0005433615624	5135	126	24E
0005433785401	5135	127	24D
0005433615566	5135	128	24F
0005432106163	5135	129	25A
0005433615595	5135	130	25C
0005433615572	5135	131	25B
0005433615571	5135	132	25D
0005433615626	5135	133	25F
0005433615608	5135	134	25E
0005433615594	5135	135	26B
0005432106131	5135	136	26A
0005433615565	5135	137	26C
0005432665301	5135	138	26E
0005432106137	5135	139	26D
0005433615586	5135	140	26F
0005433615617	5135	141	27A
0005432106140	5135	142	27B
0005432106173	5135	143	27D
0005432106159	5135	144	27C
0005433615585	5135	145	27E
0005432106179	5135	146	28A
0005432106172	5135	147	27F
0005433615615	5135	148	28B
0005433615630	5135	149	28D
0005433615596	5135	150	28C
0005433615631	5135	151	28E
0005432666414	5135	152	28F
0005432106138	5135	153	29B
0005432106164	5135	154	29A
0005433615582	5135	155	29C
0005433785391	5135	156	29E
0005433785399	5135	157	29D
0005433785380	5135	158	29F
0005433615568	5135	159	30B
0005432145138	5135	160	30A
0005433615570	5135	161	30D
0005433785403	5135	162	30C
0005432106156	5135	163	30E
0005433615605	5135	164	30F
0005433615599	5135	165	31B
0005433615598	5135	166	31A
0005433615563	5135	167	31C
0005432106150	5135	168	31E
0005432106135	5135	169	31D
0005433615562	5135	170	31F
0005435007045	5133	1	1A
0005434229653	5133	2	1C
0005434173567	5133	3	1F
0005435007151	5133	4	1D
0005434229644	5133	5	2A
0005435007144	5133	6	2D
0005435007104	5133	7	2F
0005434265454	5133	8	3A
0005435007106	5133	9	4C
0005434265450	5133	10	4F
0005434149872	5133	11	4D
0005435007126	5133	12	5C
0005435007107	5133	13	6A
0005434229646	5133	14	6C
0005434229654	5133	15	6F
0005434265458	5133	16	6D
0005434265456	5133	17	7A
0005434149877	5133	18	7C
0005434149873	5133	19	7D
0005434229657	5133	20	8A
0005434265465	5133	21	8C
0005435007153	5133	22	8B
0005435007163	5133	23	8D
0005434149878	5133	24	8F
0005434265463	5133	25	9A
0005434229649	5133	26	9C
0005435007175	5133	27	9D
0005434265446	5133	28	9F
0005434265444	5133	29	9E
0005434229639	5133	30	10D
0005435007087	5133	31	10E
0005434229651	5133	32	10F
0005435007046	5133	33	11B
0005434229655	5133	34	11A
0005432336101	5133	35	11C
0005434173570	5133	36	11E
0005435007074	5133	37	12D
0005434229658	5133	38	12E
0005435007085	5133	39	12F
0005434312324	5133	40	13B
0005434265443	5133	41	13A
0005435007108	5133	42	13C
0005432336076	5133	43	13D
0005433815405	5133	44	13F
0005432336096	5133	45	13E
0005434149881	5133	46	14A
0005433815391	5133	47	14B
0005435007188	5133	48	14C
0005434265464	5133	49	14E
0005432336116	5133	50	14D
0005435007177	5133	51	14F
0005434265460	5133	52	15B
0005434149879	5133	53	15A
0005432336077	5133	54	15D
0005432336082	5133	55	15E
0005434229645	5133	56	16A
0005435007051	5133	57	15F
0005434229641	5133	58	16B
0005434149880	5133	59	16D
0005432336097	5133	60	16F
0005435007159	5133	61	17B
0005434149869	5133	62	17C
0005434229647	5133	63	17D
0005433688824	5133	64	18A
0005435007216	5133	65	18B
0005434265467	5133	66	18D
0005434265452	5133	67	18F
0005434229656	5133	68	19C
0005434149875	5133	69	19D
0005435007098	5133	70	20C
0005435007086	5133	71	20D
0005434265447	5133	72	20E
0005435007145	5133	73	21A
0005434149870	5133	74	20F
0005434173568	5133	75	21C
0005434265457	5133	76	21B
0005434265468	5133	77	21D
0005434312323	5133	78	21F
0005434265466	5133	79	21E
0005435007160	5133	80	22B
0005434265453	5133	81	22C
0005434229640	5133	82	22D
0005434229648	5133	83	22F
0005434149876	5133	84	22E
0005432336047	5133	85	23C
0005432336123	5133	86	23D
0005434265462	5133	87	23E
0005434265448	5133	88	24A
0005434265459	5133	89	24B
0005434265451	5133	90	24D
0005434173569	5133	91	24E
0005434149871	5133	92	25B
0005435007124	5133	93	25C
0005432336098	5133	94	25F
0005435007176	5133	95	26C
0005433815407	5133	96	26B
0005434265445	5133	97	26A
0005434265461	5133	98	26E
0005435007052	5133	99	26F
0005435007187	5133	100	27B
0005434265455	5133	101	27F
0005434265449	5133	102	28B
0005435007073	5133	103	28D
0005435007167	5133	104	28C
0005434229650	5133	105	28E
0005435007105	5133	106	28F
0005433815386	5133	107	29A
0005434229642	5133	108	29C
0005434229659	5133	109	29B
0005435007186	5133	110	29D
0005434229652	5133	111	29E
0005435007152	5133	112	30A
0005432336046	5133	113	29F
0005435007099	5133	114	30B
0005435007161	5133	115	30C
0005432336095	5133	116	30E
0005433815408	5133	117	30F
0005434265442	5133	118	31B
0005434149874	5133	119	31A
0005434229643	5133	120	31D
0005435007026	5133	121	31F
0005433784987	8597	1	1D
0005434245255	8597	2	2A
0005433785120	8597	3	2C
0005433785051	8597	4	2F
0005433785162	8597	5	2D
0005433784986	8597	6	3A
0005433785113	8597	7	3C
0005435269851	8597	8	3D
0005435269842	8597	9	4D
0005434244991	8597	10	5D
0005433784876	8597	11	5F
0005433785012	8597	12	6F
0005434245219	8597	13	6D
0005433785049	8597	14	7D
0005433785004	8597	15	7F
0005434245045	8597	16	8A
0005435269853	8597	17	8C
0005433785141	8597	18	8F
0005433785244	8597	19	9A
0005433785110	8597	20	9F
0005435269841	8597	21	9E
0005433784999	8597	22	10E
0005433785038	8597	23	10F
0005435269843	8597	24	11C
0005434245058	8597	25	11D
0005432666400	8597	26	11E
0005433785011	8597	27	12B
0005434245105	8597	28	12D
0005435269849	8597	29	12E
0005434245198	8597	30	12F
0005434245108	8597	31	13C
0005433785097	8597	32	14A
0005435269845	8597	33	14C
0005433785121	8597	34	14E
0005433785006	8597	35	15A
0005435269846	8597	36	15C
0005434245245	8597	37	15F
0005435269848	8597	38	16D
0005435269850	8597	39	16C
0005434244992	8597	40	16E
0005433785000	8597	41	17A
0005434245137	8597	42	17C
0005433785098	8597	43	17D
0005433785079	8597	44	17E
0005433785050	8597	45	18A
0005434245246	8597	46	18D
0005433784998	8597	47	18F
0005433785115	8597	48	18E
0005433785086	8597	49	19C
0005435269847	8597	50	19D
0005434245057	8597	51	20B
0005433785043	8597	52	21A
0005434244999	8597	53	21C
0005435269854	8597	54	21B
0005433785164	8597	55	21D
0005434245015	8597	56	22A
0005434245166	8597	57	22B
0005433785044	8597	58	22F
0005433785134	8597	59	23C
0005434245099	8597	60	23F
0005433784952	8597	61	24B
0005433785151	8597	62	24E
0005433785112	8597	63	24F
0005434245200	8597	64	25C
0005432666391	8597	65	26A
0005434245132	8597	66	25F
0005434245098	8597	67	26B
0005435269844	8597	68	26C
0005434245170	8597	69	26E
0005433785124	8597	70	26F
0005433785125	8597	71	27A
0005433784953	8597	72	27C
0005435269852	8597	73	27D
0005433785117	8597	74	27E
0005433785116	8597	75	28D
0005434245199	8597	76	28C
0005433784949	8597	77	28E
0005433785111	8597	78	28F
0005433785136	8597	79	29A
0005435269840	8597	80	29D
0005433785005	8597	81	29F
0005433785144	8597	82	30D
0005433785155	8597	83	30F
0005433785216	8597	84	31C
0005433785133	8597	85	31D
0005434245034	8597	86	31F
0005433614588	8596	1	1A
0005433614766	8596	2	1D
0005433614961	8596	3	2A
0005433614923	8596	4	2D
0005433614964	8596	5	3A
0005433614760	8596	6	3C
0005433614785	8596	7	5A
0005433614916	8596	8	6A
0005433615025	8596	9	6C
0005433614813	8596	10	6F
0005433614584	8596	11	7D
0005433614778	8596	12	8A
0005433615315	8596	13	8B
0005433615019	8596	14	9B
0005433614654	8596	15	9D
0005433614946	8596	16	9F
0005433614944	8596	17	10A
0005433614962	8596	18	10C
0005433615314	8596	19	10E
0005433614767	8596	20	10F
0005433614629	8596	21	11E
0005433614885	8596	22	12C
0005433614862	8596	23	12B
0005433615313	8596	24	13A
0005433614909	8596	25	13B
0005433615072	8596	26	13E
0005433614963	8596	27	13F
0005433614894	8596	28	14B
0005433614751	8596	29	14C
0005433615018	8596	30	14E
0005433614752	8596	31	14D
0005433614655	8596	32	15A
0005433614650	8596	33	14F
0005433615044	8596	34	15E
0005433614927	8596	35	16A
0005433614895	8596	36	16B
0005433614953	8596	37	16C
0005433615119	8596	38	17A
0005433614922	8596	39	17C
0005433614506	8596	40	18A
0005433615009	8596	41	18C
0005433614847	8596	42	18B
0005433614956	8596	43	18F
0005433614896	8596	44	19E
0005433614585	8596	45	20A
0005433614772	8596	46	20C
0005433614897	8596	47	20F
0005433615032	8596	48	21A
0005433614947	8596	49	21B
0005433614736	8596	50	21D
0005433614972	8596	51	21C
0005433614825	8596	52	21E
0005433614863	8596	53	22C
0005433614633	8596	54	22F
0005433615020	8596	55	23C
0005433614917	8596	56	23F
0005433614589	8596	57	24C
0005433614933	8596	58	24D
0005433615162	8596	59	24F
0005433614764	8596	60	25C
0005433614749	8596	61	25D
0005433614892	8596	62	25E
0005433615144	8596	63	27C
0005433615033	8596	64	27D
0005433615127	8596	65	28A
0005433614905	8596	66	28C
0005433614763	8596	67	28B
0005433615173	8596	68	28E
0005433614955	8596	69	28D
0005433614773	8596	70	29A
0005433614737	8596	71	30A
0005433614871	8596	72	29F
0005433615002	8596	73	30E
0005433614784	8596	74	30D
0005433614934	8596	75	30F
0005434229491	8595	1	1A
0005432035282	8595	2	1D
0005434265175	8595	3	1C
0005435007315	8595	4	1F
0005433690949	8595	5	2A
0005434265174	8595	6	2C
0005432035298	8595	7	2F
0005432336180	8595	8	2D
0005432336177	8595	9	3C
0005435286689	8595	10	3A
0005434149738	8595	11	3D
0005432035295	8595	12	4A
0005434265105	8595	13	3F
0005435286687	8595	14	4D
0005434149792	8595	15	5A
0005435007324	8595	16	4F
0005433688837	8595	17	5C
0005435007308	8595	18	5F
0005434265160	8595	19	6A
0005432035275	8595	20	6C
0005432047597	8595	21	6F
0005434265235	8595	22	6D
0005432035300	8595	23	7A
0005434149784	8595	24	7C
0005432336184	8595	25	7F
0005434229451	8595	26	8A
0005434229584	8595	27	8B
0005434265281	8595	28	8D
0005435007325	8595	29	8C
0005434265253	8595	30	8E
0005432047595	8595	31	8F
0005433688836	8595	32	9A
0005435007305	8595	33	9C
0005435286682	8595	34	9B
0005434149837	8595	35	9D
0005434149763	8595	36	9F
0005432336185	8595	37	9E
0005433689938	8595	38	10A
0005435007312	8595	39	10B
0005432035283	8595	40	10D
0005434229433	8595	41	10C
0005432035284	8595	42	10E
0005434173533	8595	43	11A
0005432035290	8595	44	10F
0005434265266	8595	45	11C
0005435007304	8595	46	11B
0005434149771	8595	47	11D
0005433688834	8595	48	11F
0005435007309	8595	49	11E
0005433815444	8595	50	12A
0005432035302	8595	51	12B
0005433688835	8595	52	12D
0005434229486	8595	53	12C
0005432336178	8595	54	12E
0005434149737	8595	55	12F
0005435007319	8595	56	13A
0005432035278	8595	57	13B
0005432336182	8595	58	13D
0005435007326	8595	59	13F
0005434149764	8595	60	13E
0005433534524	8595	61	14A
0005433815447	8595	62	14B
0005432035287	8595	63	14D
0005434265265	8595	64	14C
0005434265269	8595	65	14F
0005435286684	8595	66	14E
0005435007314	8595	67	15B
0005435007311	8595	68	15A
0005432035297	8595	69	15C
0005434173528	8595	70	15E
0005434229406	8595	71	15D
0005434229449	8595	72	15F
0005432035294	8595	73	16A
0005433815446	8595	74	16B
0005434265158	8595	75	16D
0005434265103	8595	76	16E
0005435286688	8595	77	16F
0005435007320	8595	78	17A
0005435286690	8595	79	17C
0005433690950	8595	80	17D
0005432047596	8595	81	17F
0005432035291	8595	82	17E
0005435007318	8595	83	18A
0005435286685	8595	84	18C
0005434149767	8595	85	18B
0005432035303	8595	86	18D
0005435286686	8595	87	18E
0005434149722	8595	88	18F
0005433815448	8595	89	19C
0005432035299	8595	90	19B
0005434265254	8595	91	19D
0005434265205	8595	92	20B
0005434149770	8595	93	20C
0005434265153	8595	94	20D
0005432035301	8595	95	20F
0005432336183	8595	96	20E
0005434149769	8595	97	21B
0005432035288	8595	98	21A
0005435007328	8595	99	21D
0005432336181	8595	100	21C
0005432035289	8595	101	22A
0005434229466	8595	102	21F
0005434265248	8595	103	22B
0005434229476	8595	104	22C
0005434229465	8595	105	22F
0005434265163	8595	106	22E
0005432035280	8595	107	23A
0005434265128	8595	108	23B
0005432035296	8595	109	23D
0005435007313	8595	110	23C
0005432035285	8595	111	23E
0005435286683	8595	112	23F
0005432035277	8595	113	24B
0005432035293	8595	114	24C
0005435007322	8595	115	24F
0005434265104	8595	116	24E
0005435007316	8595	117	25B
0005432035276	8595	118	25D
0005432336176	8595	119	25C
0005435007307	8595	120	25E
0005432035286	8595	121	26B
0005433815445	8595	122	26D
0005434229339	8595	123	26C
0005432035279	8595	124	26F
0005433534525	8595	125	27B
0005434149723	8595	126	27A
0005435007327	8595	127	27C
0005434265228	8595	128	27D
0005434229477	8595	129	27E
0005434149783	8595	130	28A
0005434149761	8595	131	27F
0005435007317	8595	132	28B
0005434265229	8595	133	28D
0005435007306	8595	134	28C
0005434265204	8595	135	28E
0005434265303	8595	136	28F
0005434265293	8595	137	29A
0005432035292	8595	138	29C
0005435007321	8595	139	29B
0005434149760	8595	140	29D
0005434173529	8595	141	29F
0005432035281	8595	142	29E
0005432336179	8595	143	30B
0005434173530	8595	144	30C
0005434229419	8595	145	30D
0005432336186	8595	146	30F
0005434149765	8595	147	31C
0005435007323	8595	148	31E
0005435007310	8595	149	31F
0005433202540	12610	1	1A
0005434639536	12610	2	1C
0005433202547	12610	3	1D
0005433202543	12610	4	2A
0005433202542	12610	5	3B
0005433202545	12610	6	3D
0005433202550	12610	7	4B
0005433202546	12610	8	4C
0005433202541	12610	9	4D
0005434639451	12610	10	5D
0005434639483	12610	11	6A
0005433202549	12610	12	6B
0005434639535	12610	13	6C
0005434639375	12610	14	6D
0005434639480	12610	15	7A
0005434639388	12610	16	7B
0005434639482	12610	17	7D
0005434639397	12610	18	18A
0005434639465	12610	19	18B
0005434639418	12610	20	18C
0005433202553	12610	21	19C
0005434639490	12610	22	19D
0005433202544	12610	23	20A
0005433202552	12610	24	20B
0005434639432	12610	25	20D
0005434639360	12610	26	21A
0005434639481	12610	27	21B
0005434639422	12610	28	21C
0005433202548	12610	29	21D
0005434639489	12610	30	22A
0005434639382	12610	31	22B
0005433202551	12610	32	22D
0005434639346	12610	33	23B
0005434639603	23346	1	1A
0005433202442	23346	2	1B
0005434639611	23346	3	1C
0005432290668	23346	4	1D
0005433202374	23346	5	2A
0005434639618	23346	6	2B
0005433202413	23346	7	2C
0005434639600	23346	8	2D
0005434639605	23346	9	3A
0005434639609	23346	10	3B
0005433202405	23346	11	3C
0005434639602	23346	12	3D
0005433202395	23346	13	4A
0005433202372	23346	14	4B
0005434639610	23346	15	4C
0005434639604	23346	16	5A
0005432290667	23346	17	5B
0005433202393	23346	18	5C
0005434639607	23346	19	5D
0005434639620	23346	20	6A
0005434639625	23346	21	6B
0005432290669	23346	22	6C
0005434639621	23346	23	6D
0005434639622	23346	24	7A
0005434639619	23346	25	7B
0005433202371	23346	26	7C
0005434639601	23346	27	18A
0005433202376	23346	28	18B
0005434639623	23346	29	18D
0005434639624	23346	30	19A
0005434639612	23346	31	19B
0005433202406	23346	32	19C
0005434639615	23346	33	19D
0005434639606	23346	34	20B
0005434639626	23346	35	20C
0005433202373	23346	36	20D
0005434639599	23346	37	21B
0005434639608	23346	38	21C
0005434639613	23346	39	21D
0005433202378	23346	40	22A
0005434639617	23346	41	22C
0005434639614	23346	42	22D
0005434639616	23346	43	23A
0005432328652	21075	1	1C
0005432328904	21075	2	1D
0005432383469	21075	3	1F
0005432383228	21075	4	2A
0005432328903	21075	5	2C
0005432328809	21075	6	3A
0005432848841	21075	7	3C
0005432328792	21075	8	3D
0005432383308	21075	9	3F
0005432383336	21075	10	4A
0005432383207	21075	11	4C
0005432328793	21075	12	4D
0005432328837	21075	13	4E
0005432328664	21075	14	4F
0005432328858	21075	15	5A
0005432328846	21075	16	5C
0005432383225	21075	17	5D
0005432383282	21075	18	5E
0005432328760	21075	19	5F
0005432383313	21075	20	6A
0005432328936	21075	21	6C
0005432328886	21075	22	6D
0005432328702	21075	23	7A
0005432383193	21075	24	7C
0005432383288	21075	25	7D
0005432383470	21075	26	7E
0005432383221	21075	27	7F
0005432328808	21075	28	8A
0005432383151	21075	29	8C
0005432383252	21075	30	8D
0005432328995	21075	31	8E
0005432328780	21075	32	8F
0005432383327	21075	33	9A
0005432383257	21075	34	9C
0005432328991	21075	35	10A
0005432383342	21075	36	10C
0005432383090	21075	37	10D
0005432328871	21075	38	10E
0005432328895	21075	39	10F
0005432383253	21075	40	11A
0005432383287	21075	41	11D
0005432383178	21075	42	11E
0005432328900	21075	43	11F
0005432328857	21075	44	12A
0005432328749	21075	45	12C
0005432383262	21075	46	12D
0005432328999	21075	47	12E
0005432328934	21075	48	12F
0005432328748	21075	49	13C
0005432328887	21075	50	13D
0005432328878	21075	51	13F
0005432383189	21075	52	14A
0005432328908	21075	53	14C
0005432848842	21075	54	14D
0005432328703	21075	55	14E
0005432383345	21075	56	14F
0005432328935	21075	57	15A
0005432328907	21075	58	15C
0005432328663	21075	59	15D
0005432328779	21075	60	15E
0005432383428	21075	61	15F
0005432383211	21075	62	16A
0005432328847	21075	63	16C
0005432329048	21075	64	16D
0005432383283	21075	65	16E
0005432328796	21075	66	16F
0005432383310	21075	67	17C
0005432328867	21075	68	17D
0005432054341	21075	69	17E
0005432328810	21075	70	17F
0005432383344	21075	71	18A
0005432383468	21075	72	18C
0005432328998	21075	73	18D
0005432383343	21075	74	18E
0005432383216	21075	75	18F
0005432383109	21075	76	19A
0005432328692	21075	77	19D
0005432383208	21075	78	19E
0005432328795	21075	79	19F
0005432383220	21075	80	20A
0005432383255	21075	81	20C
0005432383219	21075	82	20D
0005432328651	21075	83	20E
0005432383256	21075	84	20F
0005432329232	31234	1	1A
0005432329225	31234	2	1C
0005432383638	31234	3	1D
0005432383616	31234	4	1F
0005432329220	31234	5	2A
0005432383628	31234	6	2C
0005432383633	31234	7	2F
0005432329222	31234	8	2D
0005432383613	31234	9	3A
0005432383637	31234	10	3C
0005432329251	31234	11	3D
0005432383618	31234	12	3F
0005432329211	31234	13	4A
0005432329227	31234	14	4D
0005432383617	31234	15	5A
0005432329228	31234	16	5C
0005432383623	31234	17	5D
0005432383627	31234	18	5E
0005432329219	31234	19	5F
0005432383609	31234	20	6A
0005432287249	31234	21	6C
0005432329240	31234	22	6D
0005432329226	31234	23	6E
0005432329244	31234	24	6F
0005432383632	31234	25	7A
0005432329214	31234	26	7C
0005432329208	31234	27	7D
0005432329230	31234	28	7E
0005432329250	31234	29	7F
0005432383621	31234	30	8A
0005432329213	31234	31	8C
0005432329241	31234	32	8D
0005432329209	31234	33	8E
0005432329210	31234	34	8F
0005432383610	31234	35	9A
0005432383612	31234	36	9C
0005432287247	31234	37	9E
0005432287250	31234	38	9F
0005432383619	31234	39	10A
0005432329243	31234	40	10C
0005432287248	31234	41	10D
0005432329247	31234	42	10E
0005432287246	31234	43	10F
0005432329239	31234	44	11C
0005432383629	31234	45	11E
0005432329249	31234	46	11F
0005432383635	31234	47	12A
0005432383624	31234	48	12C
0005432329233	31234	49	12E
0005432329245	31234	50	12F
0005432329212	31234	51	13A
0005432383630	31234	52	13D
0005432383611	31234	53	13E
0005432329221	31234	54	13F
0005432329216	31234	55	14D
0005432329242	31234	56	14E
0005432329246	31234	57	14F
0005432329223	31234	58	15A
0005432329207	31234	59	15C
0005432329231	31234	60	15D
0005432383614	31234	61	15E
0005432383615	31234	62	15F
0005432383625	31234	63	16C
0005432329217	31234	64	16E
0005432329252	31234	65	16D
0005432329248	31234	66	17A
0005432329236	31234	67	17C
0005432329224	31234	68	17D
0005432383620	31234	69	17E
0005432329218	31234	70	18A
0005432329229	31234	71	18C
0005432383622	31234	72	18D
0005432329206	31234	73	18E
0005432329234	31234	74	18F
0005432329237	31234	75	19A
0005432383634	31234	76	19C
0005432329235	31234	77	19D
0005432383636	31234	78	19E
0005432287245	31234	79	19F
0005432383631	31234	80	20A
0005432383626	31234	81	20C
0005432329238	31234	82	20D
0005432329215	31234	83	20E
0005432424999	13336	1	1C
0005432424990	13336	2	1D
0005432425006	13336	3	2C
0005432424982	13336	4	2F
0005432424973	13336	5	3C
0005432424965	13336	6	3D
0005432424968	13336	7	3F
0005432424992	13336	8	4C
0005432424971	13336	9	4E
0005432424978	13336	10	5D
0005432424967	13336	11	5E
0005432425003	13336	12	6C
0005432424963	13336	13	7A
0005432424972	13336	14	7C
0005432424970	13336	15	8E
0005432424994	13336	16	8F
0005432425000	13336	17	9A
0005432425004	13336	18	9C
0005432424975	13336	19	9D
0005432424976	13336	20	9E
0005432424964	13336	21	10E
0005432425001	13336	22	12A
0005432424974	13336	23	12C
0005432424997	13336	24	12D
0005432424991	13336	25	12F
0005432425008	13336	26	13D
0005432424984	13336	27	13E
0005432424980	13336	28	13F
0005432424981	13336	29	14A
0005432424998	13336	30	14D
0005432424995	13336	31	14F
0005432424988	13336	32	15F
0005432425007	13336	33	16C
0005432425002	13336	34	16D
0005432424969	13336	35	16E
0005432424985	13336	36	16F
0005432424993	13336	37	17A
0005432424989	13336	38	17D
0005432424987	13336	39	17E
0005432425005	13336	40	17F
0005432424962	13336	41	18C
0005432424996	13336	42	18D
0005432424979	13336	43	18F
0005432424986	13336	44	19A
0005432424966	13336	45	19F
0005432424983	13336	46	20D
0005432424977	13336	47	20E
0005432424462	30753	1	1A
0005432424509	30753	2	1C
0005432424530	30753	3	1F
0005432424472	30753	4	2A
0005432424524	30753	5	2C
0005432424599	30753	6	2D
0005432424425	30753	7	2F
0005432424436	30753	8	3A
0005432424565	30753	9	3D
0005432424434	30753	10	4C
0005432424413	30753	11	4D
0005432424521	30753	12	4E
0005432424522	30753	13	5D
0005432424503	30753	14	6C
0005432424459	30753	15	6E
0005432424546	30753	16	7A
0005432424519	30753	17	7D
0005432424545	30753	18	7E
0005432424573	30753	19	7F
0005432424589	30753	20	8E
0005432424502	30753	21	9C
0005432424558	30753	22	9D
0005432424579	30753	23	10D
0005432424361	30753	24	11A
0005432424424	30753	25	11C
0005432424463	30753	26	11D
0005432424596	30753	27	11E
0005432424508	30753	28	11F
0005432424597	30753	29	12A
0005432424559	30753	30	12C
0005432424598	30753	31	12D
0005432424575	30753	32	12E
0005432424435	30753	33	12F
0005432424437	30753	34	13C
0005432424563	30753	35	13E
0005432424427	30753	36	13F
0005432424608	30753	37	14E
0005432424517	30753	38	15A
0005432424467	30753	39	16A
0005432424591	30753	40	16D
0005432424580	30753	41	17C
0005432424581	30753	42	17E
0005432424551	30753	43	18D
0005432424560	30753	44	18F
0005432424535	30753	45	19C
0005432424547	30753	46	19E
0005432424605	30753	47	19F
0005432424518	30753	48	20C
0005432424564	30753	49	20E
0005432424576	30753	50	20F
0005432817845	9582	1	1A
0005432817848	9582	2	1C
0005434186206	9582	3	1D
0005432817829	9582	4	2A
0005434157502	9582	5	1F
0005432822300	9582	6	2C
0005432901605	9582	7	2D
0005432289027	9582	8	3A
0005432901731	9582	9	3C
0005434157536	9582	10	3F
0005434186207	9582	11	4A
0005432901736	9582	12	4C
0005432817843	9582	13	4D
0005432817820	9582	14	4E
0005432901641	9582	15	5A
0005432817831	9582	16	5C
0005432817846	9582	17	5D
0005434157503	9582	18	5E
0005432822297	9582	19	5F
0005432822295	9582	20	6A
0005432817828	9582	21	6C
0005432817838	9582	22	6D
0005432817822	9582	23	6E
0005432817823	9582	24	6F
0005434186209	9582	25	7A
0005432822299	9582	26	7C
0005434186197	9582	27	7D
0005434448358	9582	28	7E
0005432817837	9582	29	8A
0005432817847	9582	30	8C
0005432901709	9582	31	8E
0005432817842	9582	32	8F
0005432901616	9582	33	9A
0005432901675	9582	34	9C
0005432901554	9582	35	9D
0005432817849	9582	36	9E
0005434448356	9582	37	10A
0005434186214	9582	38	10C
0005432817833	9582	39	10D
0005432817832	9582	40	10E
0005434186210	9582	41	10F
0005432817836	9582	42	11A
0005432817835	9582	43	11C
0005432817824	9582	44	11D
0005432901640	9582	45	11E
0005434186196	9582	46	11F
0005432817825	9582	47	12A
0005432817826	9582	48	12C
0005432901679	9582	49	12D
0005432817839	9582	50	13D
0005432901639	9582	51	13E
0005432901678	9582	52	13F
0005432822296	9582	53	14A
0005432901643	9582	54	14C
0005432901676	9582	55	14D
0005432901606	9582	56	14E
0005432901710	9582	57	15C
0005432822301	9582	58	15E
0005432817844	9582	59	15F
0005432289025	9582	60	16A
0005434448359	9582	61	16C
0005434157523	9582	62	16D
0005432901657	9582	63	16E
0005432817840	9582	64	17A
0005432901553	9582	65	17C
0005432901704	9582	66	17D
0005432817819	9582	67	17E
0005432901642	9582	68	18A
0005432822294	9582	69	18C
0005432817834	9582	70	18E
0005432289026	9582	71	18F
0005434157504	9582	72	19A
0005432817841	9582	73	19C
0005432817821	9582	74	19D
0005432817830	9582	75	19E
0005434186201	9582	76	19F
0005434157524	9582	77	20A
0005434448357	9582	78	20D
0005432822298	9582	79	20E
0005432817827	9582	80	20F
0005432817567	28980	1	1A
0005434186231	28980	2	1C
0005434157573	28980	3	1D
0005432817695	28980	4	1F
0005432817680	28980	5	2C
0005434157576	28980	6	2D
0005432822223	28980	7	2F
0005432817522	28980	8	3A
0005434157574	28980	9	3C
0005432901820	28980	10	3D
0005432817681	28980	11	3F
0005434186233	28980	12	4A
0005432817656	28980	13	4C
0005432817614	28980	14	4D
0005432901831	28980	15	4F
0005432817623	28980	16	5A
0005432817715	28980	17	5C
0005434157575	28980	18	5D
0005432817591	28980	19	5F
0005432817417	28980	20	6A
0005432817565	28980	21	6C
0005432901829	28980	22	6E
0005432901825	28980	23	6F
0005432901823	28980	24	7C
0005432901833	28980	25	7D
0005432822228	28980	26	7E
0005434448328	28980	27	7F
0005432817657	28980	28	8A
0005432817475	28980	29	8C
0005432817525	28980	30	8D
0005432901819	28980	31	8E
0005434157572	28980	32	8F
0005432901830	28980	33	9A
0005434157577	28980	34	9C
0005432002102	28980	35	9D
0005432901827	28980	36	9E
0005432817579	28980	37	10A
0005432817679	28980	38	10C
0005432822218	28980	39	10D
0005432817590	28980	40	10E
0005432822236	28980	41	10F
0005434448318	28980	42	11A
0005432901821	28980	43	11C
0005432901834	28980	44	11D
0005432817602	28980	45	11E
0005432817589	28980	46	11F
0005432817555	28980	47	12A
0005432817664	28980	48	12C
0005432817556	28980	49	12D
0005432901824	28980	50	12E
0005432901832	28980	51	13A
0005432901826	28980	52	13C
0005432817686	28980	53	13D
0005432817523	28980	54	13E
0005432817587	28980	55	13F
0005432817569	28980	56	14A
0005432817528	28980	57	14C
0005432822224	28980	58	14D
0005434186232	28980	59	14E
0005434448327	28980	60	14F
0005432817580	28980	61	15A
0005432817586	28980	62	15D
0005432817598	28980	63	15E
0005432817702	28980	64	15F
0005432901828	28980	65	16A
0005432901818	28980	66	16C
0005432817474	28980	67	16D
0005432817440	28980	68	16E
0005434157578	28980	69	16F
0005432901817	28980	70	17C
0005432901822	28980	71	17D
0005432002101	28980	72	17E
0005434448326	28980	73	17F
0005432002100	28980	74	18A
0005434448314	28980	75	18C
0005432817566	28980	76	18D
0005432817492	28980	77	18E
0005432002104	28980	78	18F
0005432901816	28980	79	19A
0005432817592	28980	80	19C
0005432002103	28980	81	19E
0005432817527	28980	82	19F
0005432817634	28980	83	20C
0005432817624	28980	84	20E
0005432613912	15045	1	1A
0005432613913	15045	2	2A
0005435841096	15045	3	2B
0005432611756	15045	4	3A
0005435841095	15045	5	3B
0005432611757	15045	6	4A
0005432611758	15045	7	4B
0005432613910	15045	8	5B
0005432613911	15045	9	6B
0005435841831	31529	1	1A
0005432607588	31529	2	3A
0005432611714	31529	3	3B
0005432607589	31529	4	4B
0005435841832	31529	5	5A
0005432607592	31529	6	6A
0005433569747	11844	1	1A
0005432948649	11844	2	1C
0005432948264	11844	3	2A
0005433569762	11844	4	1F
0005433569734	11844	5	2D
0005433569736	11844	6	2C
0005433569726	11844	7	3A
0005433569763	11844	8	3C
0005432948654	11844	9	3F
0005432948449	11844	10	3D
0005432948419	11844	11	4D
0005433569766	11844	12	4C
0005433569722	11844	13	4A
0005433569714	11844	14	4F
0005433569725	11844	15	5C
0005432948484	11844	16	5A
0005432948410	11844	17	5F
0005433569710	11844	18	6D
0005433569718	11844	19	6F
0005433569707	11844	20	6E
0005432948451	11844	21	7A
0005433569754	11844	22	7C
0005432948575	11844	23	7B
0005432948524	11844	24	7E
0005433569740	11844	25	7D
0005432948409	11844	26	8A
0005433569730	11844	27	7F
0005432948480	11844	28	8B
0005432948450	11844	29	8D
0005433569746	11844	30	8C
0005432948400	11844	31	8F
0005432948574	11844	32	8E
0005433569735	11844	33	9B
0005433569727	11844	34	9A
0005433569713	11844	35	9D
0005432948408	11844	36	9C
0005433569709	11844	37	9E
0005433569733	11844	38	10A
0005432948564	11844	39	10D
0005433569752	11844	40	10C
0005432948684	11844	41	10B
0005433569731	11844	42	10E
0005432948321	11844	43	11A
0005433569765	11844	44	10F
0005432948395	11844	45	11C
0005433569708	11844	46	11B
0005433569711	11844	47	11D
0005433569744	11844	48	11F
0005432948618	11844	49	11E
0005432948616	11844	50	12B
0005432948559	11844	51	12A
0005432948394	11844	52	12C
0005433569751	11844	53	12E
0005433569723	11844	54	12D
0005433569755	11844	55	13A
0005432948483	11844	56	12F
0005432948581	11844	57	13C
0005433569721	11844	58	13B
0005432948617	11844	59	13E
0005433569719	11844	60	13D
0005432948582	11844	61	14A
0005432948322	11844	62	13F
0005433569715	11844	63	14C
0005433569764	11844	64	14B
0005433569738	11844	65	14F
0005432948265	11844	66	14E
0005433569716	11844	67	15B
0005433569748	11844	68	15C
0005433569745	11844	69	15E
0005433569757	11844	70	15D
0005433569759	11844	71	16A
0005433569741	11844	72	15F
0005432948393	11844	73	16C
0005433569749	11844	74	16B
0005433569760	11844	75	16D
0005432948565	11844	76	17A
0005433569761	11844	77	16F
0005432948664	11844	78	16E
0005433569724	11844	79	17C
0005433569743	11844	80	17B
0005432948576	11844	81	17D
0005433569753	11844	82	17F
0005433569728	11844	83	17E
0005433569720	11844	84	18A
0005433569732	11844	85	18D
0005432948655	11844	86	18C
0005433569737	11844	87	18B
0005432948563	11844	88	18E
0005432948536	11844	89	19A
0005433569758	11844	90	18F
0005432948312	11844	91	19C
0005433569750	11844	92	19B
0005433569756	11844	93	19E
0005432948596	11844	94	19F
0005433569729	11844	95	20B
0005432948446	11844	96	20C
0005433569742	11844	97	20D
0005433569739	11844	98	21B
0005432948648	11844	99	21A
0005432948558	11844	100	20F
0005433569712	11844	101	21C
0005433569717	11844	102	21E
0005432948418	11844	103	21F
0005433569410	25289	1	1C
0005433569466	25289	2	1A
0005433569465	25289	3	1F
0005433569253	25289	4	1D
0005433569267	25289	5	2C
0005432948993	25289	6	2A
0005433569244	25289	7	2D
0005433569234	25289	8	3C
0005432948990	25289	9	2F
0005433569531	25289	10	3D
0005433569182	25289	11	4A
0005432948986	25289	12	3F
0005433569411	25289	13	4D
0005433569311	25289	14	4F
0005433569179	25289	15	5C
0005432948996	25289	16	5A
0005433569451	25289	17	5F
0005433569046	25289	18	5D
0005432949012	25289	19	6B
0005432949007	25289	20	6A
0005433569348	25289	21	6D
0005433569545	25289	22	6C
0005432949009	25289	23	6E
0005433569396	25289	24	7A
0005432949011	25289	25	7C
0005433569163	25289	26	7B
0005433569196	25289	27	7D
0005433568974	25289	28	8A
0005433569245	25289	29	7F
0005433569269	25289	30	7E
0005432949006	25289	31	8B
0005433569040	25289	32	8E
0005433569351	25289	33	8D
0005433569463	25289	34	8C
0005433569018	25289	35	8F
0005433569530	25289	36	9B
0005432948983	25289	37	9D
0005432949001	25289	38	9C
0005432949013	25289	39	9E
0005432948976	25289	40	10A
0005433569085	25289	41	10D
0005433569280	25289	42	10C
0005433569100	25289	43	10B
0005433568880	25289	44	10F
0005432948995	25289	45	10E
0005433569197	25289	46	11B
0005433569467	25289	47	11A
0005433569054	25289	48	11D
0005432948997	25289	49	11F
0005433569291	25289	50	11E
0005433569464	25289	51	12B
0005433569228	25289	52	12A
0005432949000	25289	53	12C
0005432949008	25289	54	12E
0005432948989	25289	55	12D
0005432949003	25289	56	12F
0005433569160	25289	57	13C
0005433568994	25289	58	13B
0005432948987	25289	59	13E
0005433568839	25289	60	14A
0005432949005	25289	61	13F
0005433569151	25289	62	14D
0005432948978	25289	63	14F
0005432948988	25289	64	14E
0005433569072	25289	65	15B
0005433569159	25289	66	15A
0005433569183	25289	67	15F
0005432948979	25289	68	15E
0005432948981	25289	69	16A
0005433569091	25289	70	16C
0005432948982	25289	71	16E
0005432948974	25289	72	16F
0005432948998	25289	73	17C
0005432948975	25289	74	17B
0005432948992	25289	75	17A
0005433568840	25289	76	17D
0005433569290	25289	77	17F
0005432948977	25289	78	18A
0005432948991	25289	79	18B
0005432948980	25289	80	18E
0005433569352	25289	81	18D
0005433569133	25289	82	19A
0005432949004	25289	83	18F
0005432948999	25289	84	19B
0005432948994	25289	85	19D
0005432949002	25289	86	19C
0005433569448	25289	87	19F
0005433568975	25289	88	19E
0005433569193	25289	89	20B
0005432948985	25289	90	20A
0005433569377	25289	91	20C
0005432948984	25289	92	20F
0005433569071	25289	93	20E
0005432949014	25289	94	20D
0005433569132	25289	95	21A
0005433569162	25289	96	21C
0005432949010	25289	97	21E
0005433569255	25289	98	21D
0005433569161	25289	99	21F
0005433811641	27938	1	1D
0005433811642	27938	2	5B
0005433811627	27938	3	5C
0005433811636	27938	4	5E
0005433811629	27938	5	8E
0005433811637	27938	6	9D
0005433811635	27938	7	12D
0005433811640	27938	8	14D
0005433811626	27938	9	17D
0005433811633	27938	10	21D
0005434655035	5368	1	2A
0005434655038	5368	2	2D
0005435340319	5368	3	2F
0005435340325	5368	4	3A
0005435340320	5368	5	3C
0005434655051	5368	6	3D
0005434655039	5368	7	3F
0005434655049	5368	8	4A
0005434655041	5368	9	4C
0005434655052	5368	10	4F
0005434655048	5368	11	5A
0005434655032	5368	12	5D
0005435340350	5368	13	5E
0005432114242	5368	14	5F
0005434655028	5368	15	6C
0005434655030	5368	16	6E
0005435340326	5368	17	7D
0005435340308	5368	18	7E
0005434655034	5368	19	7F
0005434655029	5368	20	8A
0005435340270	5368	21	8C
0005434655033	5368	22	8E
0005435340402	5368	23	9A
0005434655031	5368	24	9C
0005434655045	5368	25	9D
0005434655050	5368	26	10E
0005434655047	5368	27	11A
0005435340366	5368	28	11D
0005434655036	5368	29	11E
0005434655037	5368	30	11F
0005434655055	5368	31	12A
0005435340246	5368	32	12C
0005435340305	5368	33	12E
0005435340310	5368	34	12F
0005434655044	5368	35	13A
0005434655053	5368	36	13F
0005434656582	5368	37	14D
0005434655043	5368	38	14E
0005435340403	5368	39	14F
0005434655054	5368	40	15D
0005435340341	5368	41	16A
0005434655040	5368	42	16E
0005435340367	5368	43	17F
0005435340318	5368	44	18A
0005434656581	5368	45	18D
0005434655042	5368	46	18E
0005435340309	5368	47	19D
0005434656580	5368	48	20A
0005434655046	5368	49	20D
0005434655027	5368	50	20E
0005432114243	5368	51	20F
0005435340449	12503	1	1A
0005434654805	12503	2	1C
0005434654685	12503	3	1D
0005435340443	12503	4	1F
0005435340452	12503	5	2C
0005434654759	12503	6	2F
0005434656565	12503	7	3D
0005434654901	12503	8	4C
0005434654848	12503	9	4F
0005434654699	12503	10	5A
0005435340442	12503	11	5C
0005434654804	12503	12	5D
0005434654723	12503	13	6C
0005434654751	12503	14	6D
0005434654807	12503	15	6E
0005434656556	12503	16	6F
0005435340455	12503	17	7C
0005434654684	12503	18	7D
0005434654822	12503	19	7E
0005435340445	12503	20	7F
0005434654780	12503	21	8A
0005435340450	12503	22	8C
0005434654798	12503	23	8D
0005435340454	12503	24	8F
0005435340446	12503	25	9C
0005435555396	12503	26	9D
0005435340448	12503	27	9E
0005434654888	12503	28	10D
0005434654803	12503	29	10E
0005434654806	12503	30	11A
0005434654686	12503	31	11D
0005435340447	12503	32	12D
0005435555395	12503	33	12E
0005434654808	12503	34	13D
0005435340453	12503	35	13F
0005434654887	12503	36	14E
0005434654875	12503	37	14F
0005435340451	12503	38	15A
0005434654752	12503	39	15C
0005434654741	12503	40	16C
0005434654830	12503	41	17A
0005434654593	12503	42	17D
0005434654855	12503	43	17E
0005434654791	12503	44	17F
0005435340456	12503	45	18A
0005434654838	12503	46	18D
0005434654713	12503	47	18F
0005434654681	12503	48	19D
0005434654856	12503	49	19F
0005435340444	12503	50	20F
0005433716596	7437	1	1D
0005433716562	7437	2	2C
0005433716569	7437	3	2A
0005433656708	7437	4	3A
0005433716566	7437	5	3D
0005433656710	7437	6	3C
0005433716558	7437	7	3F
0005433716580	7437	8	4A
0005433716593	7437	9	4B
0005433716584	7437	10	4C
0005433716583	7437	11	4E
0005433722295	7437	12	4F
0005433716563	7437	13	5B
0005433689935	7437	14	5A
0005433716600	7437	15	5D
0005433716564	7437	16	5F
0005433719181	7437	17	6A
0005433716595	7437	18	6E
0005433716575	7437	19	7B
0005435266143	7437	20	7A
0005433716582	7437	21	7D
0005433716571	7437	22	7E
0005432078177	7437	23	8A
0005433656711	7437	24	8E
0005433716570	7437	25	8D
0005433716560	7437	26	9A
0005433656709	7437	27	8F
0005433716559	7437	28	9B
0005433716592	7437	29	9D
0005433716586	7437	30	9C
0005433716599	7437	31	9F
0005433716573	7437	32	9E
0005433722301	7437	33	10D
0005433690947	7437	34	10E
0005433716589	7437	35	11A
0005433689937	7437	36	11B
0005432428942	7437	37	11D
0005433722298	7437	38	11E
0005432078174	7437	39	11F
0005433722302	7437	40	12C
0005433716601	7437	41	12B
0005432428954	7437	42	12D
0005433716556	7437	43	12E
0005433716557	7437	44	13A
0005433722296	7437	45	12F
0005433722300	7437	46	13C
0005433722294	7437	47	13B
0005433716598	7437	48	13D
0005433716591	7437	49	13F
0005433689934	7437	50	14B
0005433716578	7437	51	14D
0005433656707	7437	52	14F
0005433719179	7437	53	15A
0005433716590	7437	54	15C
0005433689936	7437	55	15B
0005435266148	7437	56	15D
0005433716568	7437	57	15E
0005433722299	7437	58	15F
0005433716577	7437	59	16C
0005432078176	7437	60	16D
0005433716572	7437	61	17A
0005435266149	7437	62	17B
0005432078178	7437	63	17C
0005432428925	7437	64	17D
0005432078173	7437	65	18A
0005433716554	7437	66	17F
0005432428939	7437	67	18B
0005433716579	7437	68	18C
0005433716553	7437	69	18D
0005433690948	7437	70	19A
0005433719180	7437	71	19C
0005433716576	7437	72	19E
0005433716594	7437	73	20A
0005433722297	7437	74	20B
0005432078175	7437	75	20D
0005433716587	7437	76	20C
0005433716597	7437	77	20E
0005433716565	7437	78	21B
0005433716561	7437	79	21A
0005433716567	7437	80	21D
0005433716585	7437	81	22A
0005433716574	7437	82	22C
0005433716555	7437	83	22D
0005433716588	7437	84	23B
0005433716581	7437	85	23C
0005433716041	29226	1	9C
0005433716110	29226	2	1A
0005433716312	29226	3	2A
0005433716222	29226	4	2C
0005433716346	29226	5	3C
0005433716167	29226	6	3F
0005433716292	29226	7	4A
0005433716003	29226	8	5C
0005433716275	29226	9	5D
0005433716144	29226	10	5E
0005433656673	29226	11	6A
0005433716160	29226	12	5F
0005433722223	29226	13	6B
0005433716248	29226	14	6D
0005433716389	29226	15	6E
0005433716096	29226	16	7A
0005433715903	29226	17	7B
0005433715995	29226	18	7C
0005433716069	29226	19	8A
0005433716240	29226	20	7F
0005433716004	29226	21	8C
0005433688824	29226	22	8D
0005433716108	29226	23	8F
0005433719150	29226	24	9B
0005433722209	29226	25	9D
0005433716150	29226	26	9F
0005433656674	29226	27	9E
0005433715956	29226	28	10B
0005433716188	29226	29	10C
0005433716249	29226	30	10D
0005433716166	29226	31	11A
0005433716217	29226	32	11B
0005433716211	29226	33	11E
0005433716234	29226	34	12A
0005432006798	29226	35	12B
0005433716410	29226	36	13A
0005432428971	29226	37	13C
0005433716270	29226	38	13B
0005433715992	29226	39	13D
0005433716035	29226	40	14B
0005433719158	29226	41	14D
0005433716230	29226	42	15B
0005433716112	29226	43	15A
0005433715994	29226	44	15C
0005433716173	29226	45	15D
0005433716151	29226	46	16A
0005433722226	29226	47	16C
0005433716050	29226	48	17A
0005433716078	29226	49	16F
0005433715955	29226	50	17B
0005433716051	29226	51	17D
0005433716411	29226	52	17F
0005433716223	29226	53	18A
0005433716111	29226	54	18B
0005433722222	29226	55	18C
0005433716142	29226	56	18D
0005433716200	29226	57	18F
0005433715993	29226	58	19A
0005433719157	29226	59	19B
0005433716210	29226	60	19D
0005433716143	29226	61	19F
0005433716165	29226	62	20B
0005433716159	29226	63	20D
0005432428972	29226	64	20E
0005433716114	29226	65	21A
0005433716070	29226	66	20F
0005433716247	29226	67	21D
0005433716115	29226	68	21C
0005433716291	29226	69	21E
0005433716311	29226	70	22B
0005433715944	29226	71	22C
0005433716269	29226	72	22D
0005432428970	29226	73	22E
0005433716445	29226	74	23B
0005432428969	29226	75	23D
0005433716091	29226	76	23F
0005433716328	29226	77	23E
0005434095448	8695	1	16E
0005434095446	8695	2	6F
0005434095450	8695	3	6E
0005434095449	8695	4	17A
0005434095447	8695	5	17F
0005434095445	8695	6	19A
0005434095452	8695	7	19F
0005434095454	8695	8	3A
0005434095455	8695	9	9D
0005434184673	8695	10	8E
0005434095453	8695	11	11E
0005434095458	8695	12	12C
0005434182226	8695	13	12D
0005434095451	8695	14	13C
0005434182278	8695	15	1A
0005434095457	8695	16	14A
0005434182277	8695	17	16D
0005434095456	8695	18	4A
0005434095294	11630	1	8A
0005434183603	11630	2	8D
0005434182344	11630	3	8E
0005434095331	11630	4	9A
0005434182332	11630	5	9C
0005434095325	11630	6	9F
0005434182342	11630	7	10E
0005434095281	11630	8	13F
0005434182338	11630	9	11F
0005434095293	11630	10	12F
0005434143738	11630	11	13E
0005434182340	11630	12	11E
0005434095261	11630	13	14C
0005434182341	11630	14	15A
0005434184688	11630	15	15F
0005434095413	11630	16	17D
0005434182331	11630	17	20C
0005434182333	11630	18	20F
0005434182343	11630	19	1C
0005434182336	11630	20	1D
0005434182339	11630	21	1F
0005434143734	11630	22	2F
0005434182334	11630	23	3F
0005434182337	11630	24	5A
0005434095321	11630	25	5D
0005434095378	11630	26	6D
0005434095332	11630	27	7A
0005434183602	11630	28	7D
0005434182335	11630	29	7E
0005433398246	1432	1	12A
0005433398043	1432	2	12C
0005433398373	1432	3	12E
0005433398294	1432	4	12F
0005433398263	1432	5	13A
0005433398061	1432	6	13D
0005433398333	1432	7	13E
0005433398140	1432	8	13F
0005433398412	1432	9	14A
0005433398164	1432	10	14C
0005433398218	1432	11	14D
0005433398295	1432	12	14E
0005433398052	1432	13	14F
0005433398299	1432	14	15A
0005433398375	1432	15	15C
0005433398068	1432	16	15D
0005433398053	1432	17	15E
0005433398213	1432	18	15F
0005433398287	1432	19	16A
0005433398138	1432	20	16C
0005433398177	1432	21	16D
0005433398222	1432	22	16F
0005433398383	1432	23	17C
0005433398293	1432	24	17E
0005433398374	1432	25	17F
0005433398315	1432	26	18D
0005433398291	1432	27	18E
0005433398360	1432	28	18F
0005433398298	1432	29	19E
0005433398066	1432	30	20A
0005432906542	1432	31	19F
0005433457020	1432	32	20C
0005432297308	1432	33	20D
0005433398107	1432	34	20E
0005433398150	1432	35	20F
0005433398141	1432	36	19D
0005432906543	1432	37	1A
0005433398345	1432	38	1C
0005433398187	1432	39	1D
0005433398332	1432	40	1F
0005433398277	1432	41	2A
0005433398212	1432	42	2C
0005433398297	1432	43	2D
0005433457018	1432	44	2F
0005433398382	1432	45	3A
0005433398369	1432	46	3C
0005433398149	1432	47	3D
0005433398099	1432	48	3F
0005433398316	1432	49	4A
0005433398139	1432	50	4D
0005433398223	1432	51	4E
0005433398376	1432	52	4F
0005433398039	1432	53	5A
0005433398118	1432	54	5D
0005433398424	1432	55	5E
0005433398069	1432	56	5F
0005433398078	1432	57	6A
0005433398379	1432	58	6C
0005433398077	1432	59	6D
0005433398380	1432	60	6E
0005433398137	1432	61	6F
0005433398217	1432	62	7C
0005432906545	1432	63	7D
0005433398361	1432	64	7E
0005433398051	1432	65	7F
0005433398062	1432	66	8A
0005433398264	1432	67	8C
0005432297309	1432	68	8E
0005433398070	1432	69	8F
0005433398241	1432	70	9A
0005432297310	1432	71	9C
0005433398145	1432	72	9D
0005432906544	1432	73	9F
0005433398106	1432	74	10A
0005433457019	1432	75	10C
0005433398163	1432	76	10D
0005433398281	1432	77	10E
0005433398359	1432	78	10F
0005433398178	1432	79	11A
0005433398346	1432	80	11C
0005433398279	1432	81	11D
0005433398100	1432	82	11F
0005433398638	19275	1	1C
0005433398663	19275	2	1D
0005433398640	19275	3	2A
0005435732391	19275	4	2C
0005433398649	19275	5	2F
0005433398652	19275	6	3D
0005435732398	19275	7	4A
0005433398664	19275	8	4C
0005435732386	19275	9	4D
0005433398632	19275	10	4F
0005433398661	19275	11	5A
0005433398641	19275	12	5C
0005433398653	19275	13	6A
0005433398657	19275	14	6D
0005433398634	19275	15	6E
0005433398666	19275	16	7A
0005433398659	19275	17	7F
0005433398651	19275	18	8A
0005433398655	19275	19	1A
0005433398669	19275	20	8C
0005433398660	19275	21	8D
0005433398635	19275	22	8E
0005433398629	19275	23	9A
0005433398643	19275	24	9C
0005433398665	19275	25	9D
0005433398626	19275	26	9E
0005433398668	19275	27	9F
0005433398639	19275	28	10A
0005433398650	19275	29	10E
0005435732368	19275	30	10F
0005435732416	19275	31	11C
0005435732351	19275	32	11D
0005435732365	19275	33	11E
0005433398631	19275	34	11F
0005433398622	19275	35	12C
0005433398633	19275	36	12D
0005433398667	19275	37	12F
0005433398644	19275	38	13A
0005433398623	19275	39	13F
0005433456984	19275	40	14A
0005433398648	19275	41	14C
0005435732390	19275	42	14E
0005433398636	19275	43	14F
0005435732343	19275	44	15C
0005433398662	19275	45	15E
0005433398637	19275	46	15F
0005432906565	19275	47	16C
0005433398628	19275	48	16D
0005435732355	19275	49	17C
0005433398645	19275	50	17E
0005433398642	19275	51	17F
0005435732397	19275	52	18A
0005433456976	19275	53	18C
0005433398627	19275	54	18D
0005433398646	19275	55	18F
0005433398630	19275	56	19A
0005432906566	19275	57	19D
0005433398624	19275	58	19E
0005433398625	19275	59	20A
0005433398656	19275	60	20C
0005433398658	19275	61	20D
0005433398647	19275	62	20E
0005433398654	19275	63	20F
0005434443780	17346	1	23B
0005434443746	17346	2	3C
0005434443712	17346	3	6A
0005434443751	17346	4	7A
0005434443779	17346	5	18A
0005434443752	17346	6	18C
0005434443802	17346	7	18D
0005434443684	17346	8	19A
0005434443812	17346	9	20C
0005434443716	17346	10	20D
0005434443887	20572	1	1B
0005434443888	20572	2	2C
0005434443891	20572	3	3B
0005434443897	20572	4	5B
0005434443895	20572	5	6B
0005434443889	20572	6	6D
0005434443902	20572	7	18A
0005434443892	20572	8	18B
0005434443901	20572	9	18D
0005434443890	20572	10	19B
0005434443894	20572	11	19D
0005434443898	20572	12	20C
0005434443893	20572	13	20D
0005434443896	20572	14	21C
0005434443899	20572	15	22A
0005434443900	20572	16	23B
0005434954657	7230	1	1A
0005434954659	7230	2	2B
0005434954658	7230	3	3A
0005434954656	7230	4	3B
0005435377594	7230	5	4A
0005435377595	7230	6	4B
0005435377593	7230	7	5A
0005434954655	7230	8	5B
0005435377592	7230	9	6B
0005435377610	28309	1	1A
0005434954629	28309	2	2A
0005434954621	28309	3	2B
0005434954620	28309	4	3A
0005434954640	28309	5	3B
0005434954617	28309	6	4A
0005434954630	28309	7	4B
0005435377609	28309	8	5B
0005435377608	28309	9	6B
0005434954618	28309	10	6A
0005435893682	4495	1	1C
0005434351853	4495	2	2D
0005434351848	4495	3	3A
0005435893678	4495	4	3B
0005434351852	4495	5	3C
0005434351851	4495	6	5A
0005434351855	4495	7	4D
0005434351849	4495	8	5D
0005434351850	4495	9	6D
0005434351845	4495	10	7D
0005435893660	4495	11	18A
0005434351854	4495	12	18D
0005434351847	4495	13	19A
0005434351844	4495	14	19C
0005434351856	4495	15	21B
0005434351846	4495	16	21C
0005435893614	4495	17	22B
0005435893714	29627	1	1C
0005434351722	29627	2	3D
0005434351724	29627	3	5A
0005435893715	29627	4	5B
0005434351691	29627	5	5D
0005435893720	29627	6	6A
0005434351723	29627	7	6D
0005435893717	29627	8	7B
0005435893719	29627	9	7C
0005435893718	29627	10	18B
0005435893721	29627	11	20C
0005434351786	29627	12	22A
0005435893722	29627	13	22C
0005435893716	29627	14	22D
0005434351726	29627	15	23A
0005433343167	1094	1	2A
0005433343019	1094	2	1H
0005433343110	1094	3	2C
0005433343216	1094	4	2F
0005433343681	1094	5	2G
0005433462773	1094	6	3B
0005433343288	1094	7	3F
0005433343166	1094	8	3G
0005434446547	1094	9	4B
0005433343013	1094	10	4G
0005433343489	1094	11	5A
0005433343360	1094	12	5C
0005434445272	1094	13	5G
0005433343132	1094	14	9G
0005433343337	1094	15	9H
0005435092192	1094	16	11D
0005433343313	1094	17	11F
0005433343794	1094	18	11E
0005433343685	1094	19	11H
0005433343793	1094	20	11G
0005433343421	1094	21	12A
0005433158140	1094	22	12B
0005433269740	1094	23	12F
0005434446546	1094	24	12E
0005433343763	1094	25	12H
0005433343795	1094	26	13D
0005433463929	1094	27	13B
0005433343125	1094	28	13G
0005435092197	1094	29	13F
0005433343696	1094	30	14A
0005433343396	1094	31	14D
0005433343435	1094	32	14E
0005435092195	1094	33	14H
0005433343189	1094	34	15B
0005433343491	1094	35	15F
0005433463927	1094	36	15E
0005433343503	1094	37	16A
0005433343597	1094	38	16D
0005433343551	1094	39	16B
0005433343495	1094	40	16G
0005433343381	1094	41	16H
0005433343126	1094	42	17B
0005434445271	1094	43	17D
0005433343382	1094	44	17E
0005433343305	1094	45	17G
0005433343512	1094	46	17F
0005433343604	1094	47	17H
0005433343544	1094	48	18D
0005433343531	1094	49	18B
0005433342894	1094	50	18F
0005433343119	1094	51	18G
0005433343323	1094	52	19A
0005433343487	1094	53	18H
0005433343014	1094	54	19F
0005434446545	1094	55	19G
0005433343773	1094	56	20A
0005433343358	1094	57	19H
0005433343307	1094	58	20B
0005433269753	1094	59	20F
0005433343494	1094	60	21A
0005433343436	1094	61	21D
0005433343372	1094	62	21B
0005433343384	1094	63	21G
0005433343296	1094	64	21F
0005433343239	1094	65	21H
0005435092191	1094	66	22B
0005433343326	1094	67	22D
0005433343485	1094	68	22F
0005433343574	1094	69	22G
0005433343641	1094	70	23D
0005435092199	1094	71	23B
0005433343439	1094	72	23F
0005433343532	1094	73	23G
0005433343555	1094	74	23H
0005433158138	1094	75	24A
0005433343976	1094	76	24F
0005433343238	1094	77	24E
0005435092198	1094	78	24H
0005433343476	1094	79	25E
0005432293239	1094	80	25D
0005433343566	1094	81	27A
0005433343663	1094	82	25F
0005435545844	1094	83	27D
0005433343554	1094	84	27B
0005433158139	1094	85	27F
0005433343434	1094	86	27G
0005435092193	1094	87	28D
0005433343862	1094	88	28F
0005433343664	1094	89	28E
0005433343474	1094	90	29A
0005433343605	1094	91	29D
0005433343470	1094	92	29G
0005433343469	1094	93	29H
0005433343787	1094	94	30B
0005433342893	1094	95	30E
0005433342990	1094	96	31B
0005432293238	1094	97	31D
0005433343373	1094	98	31F
0005433343342	1094	99	31E
0005433343334	1094	100	32A
0005433343137	1094	101	32B
0005433343668	1094	102	32D
0005433463928	1094	103	32F
0005433343335	1094	104	32E
0005435092194	1094	105	32H
0005433343686	1094	106	32G
0005433343682	1094	107	33D
0005433343020	1094	108	33B
0005433343109	1094	109	33G
0005433343543	1094	110	34G
0005433463926	1094	111	34F
0005433343282	1094	112	35A
0005433343725	1094	113	34H
0005433343486	1094	114	35F
0005433343060	1094	115	35E
0005433462772	1094	116	36B
0005433343516	1094	117	36A
0005433343120	1094	118	36D
0005433343283	1094	119	36F
0005433343475	1094	120	36G
0005433343788	1094	121	37A
0005433343237	1094	122	36H
0005433343016	1094	123	37D
0005433343726	1094	124	37B
0005435092196	1094	125	37G
0005433343630	1094	126	37E
0005434446544	1094	127	37H
0005435092190	1094	128	38D
0005433343018	1094	129	38B
0005433343705	1094	130	38E
0005433343608	1094	131	39D
0005433343242	1094	132	38H
0005433343490	1094	133	39F
0005433343727	1094	134	39E
0005433344261	17079	1	21D
0005433344310	17079	2	1C
0005433159338	17079	3	1F
0005433344273	17079	4	2B
0005433344315	17079	5	2G
0005435092127	17079	6	2F
0005433344230	17079	7	3A
0005435508310	17079	8	3C
0005433344264	17079	9	3B
0005435508380	17079	10	3G
0005433344237	17079	11	3H
0005435508311	17079	12	4B
0005433344302	17079	13	4F
0005433344268	17079	14	4C
0005435092152	17079	15	4H
0005433344309	17079	16	5A
0005433344313	17079	17	5C
0005433344229	17079	18	5B
0005433344316	17079	19	9A
0005433269786	17079	20	5H
0005433344258	17079	21	9H
0005433344272	17079	22	11B
0005433344277	17079	23	11F
0005433344243	17079	24	11G
0005433269785	17079	25	12A
0005435092104	17079	26	11H
0005435092150	17079	27	12B
0005433344320	17079	28	12E
0005433344318	17079	29	12H
0005433344278	17079	30	13D
0005434445248	17079	31	13B
0005433344251	17079	32	13E
0005435092107	17079	33	13G
0005433344321	17079	34	14A
0005433344311	17079	35	13H
0005433344319	17079	36	14B
0005433344280	17079	37	14H
0005433344297	17079	38	14G
0005433344275	17079	39	15A
0005433344238	17079	40	15B
0005433344314	17079	41	15E
0005433344252	17079	42	15F
0005433344322	17079	43	15H
0005435508338	17079	44	16A
0005435508378	17079	45	16D
0005433159339	17079	46	16B
0005433344293	17079	47	16E
0005433344257	17079	48	16G
0005433344285	17079	49	16F
0005433344328	17079	50	17B
0005433344289	17079	51	17A
0005433344294	17079	52	17F
0005433344255	17079	53	17E
0005435508365	17079	54	17G
0005433344317	17079	55	17H
0005433344259	17079	56	18B
0005433344291	17079	57	18A
0005433344288	17079	58	18D
0005433344233	17079	59	18E
0005433344296	17079	60	18G
0005435092118	17079	61	18F
0005433344256	17079	62	18H
0005433344292	17079	63	19A
0005433344266	17079	64	19G
0005433344303	17079	65	20A
0005433344249	17079	66	19H
0005433344246	17079	67	20E
0005433344306	17079	68	20G
0005433344284	17079	69	21E
0005433344260	17079	70	21G
0005433269784	17079	71	22A
0005433344300	17079	72	22E
0005433344281	17079	73	22F
0005433344263	17079	74	22H
0005433344245	17079	75	23A
0005433344279	17079	76	23D
0005433344235	17079	77	23E
0005433344231	17079	78	23G
0005433344287	17079	79	24A
0005433344327	17079	80	24E
0005433344269	17079	81	24D
0005433344236	17079	82	24H
0005435508372	17079	83	24G
0005433344242	17079	84	27A
0005433344262	17079	85	25F
0005434445247	17079	86	27E
0005433344248	17079	87	28A
0005433344286	17079	88	28E
0005433344329	17079	89	28H
0005433344244	17079	90	28G
0005433269781	17079	91	29D
0005433344325	17079	92	29G
0005434445249	17079	93	29F
0005435508366	17079	94	29H
0005433344283	17079	95	30D
0005433344271	17079	96	30F
0005433344324	17079	97	30H
0005433344274	17079	98	31B
0005433344267	17079	99	31A
0005435508387	17079	100	31D
0005433344240	17079	101	31G
0005433344276	17079	102	32D
0005434445245	17079	103	32B
0005433344304	17079	104	32E
0005433344295	17079	105	32F
0005433344326	17079	106	32H
0005433344239	17079	107	32G
0005433344307	17079	108	33A
0005433344253	17079	109	33B
0005433344232	17079	110	33E
0005433344312	17079	111	33D
0005433344290	17079	112	34A
0005433344308	17079	113	34G
0005433344234	17079	114	35A
0005433344298	17079	115	35B
0005433344250	17079	116	35D
0005433344305	17079	117	35H
0005433269782	17079	118	35G
0005435092151	17079	119	36A
0005433269787	17079	120	36B
0005433344241	17079	121	36E
0005433344301	17079	122	36G
0005433344323	17079	123	36H
0005433344247	17079	124	37B
0005433344270	17079	125	37E
0005435508386	17079	126	37D
0005434445246	17079	127	37H
0005433344265	17079	128	38A
0005433344254	17079	129	38D
0005435508390	17079	130	38B
0005433344299	17079	131	38E
0005435508371	17079	132	38F
0005433269783	17079	133	38H
0005435092135	17079	134	39F
0005433344282	17079	135	39E
0005432433743	12782	1	1A
0005434067710	12782	2	1C
0005434026710	12782	3	1F
0005434081917	12782	4	1D
0005434067747	12782	5	2C
0005434067778	12782	6	2A
0005434067803	12782	7	2D
0005434082023	12782	8	3A
0005434067718	12782	9	2F
0005434067862	12782	10	3D
0005434067761	12782	11	3C
0005434067630	12782	12	3F
0005434067340	12782	13	4B
0005434067606	12782	14	4A
0005434067667	12782	15	4D
0005434067646	12782	16	4E
0005434081971	12782	17	4F
0005434082084	12782	18	5B
0005434082000	12782	19	5C
0005434067827	12782	20	5D
0005434067821	12782	21	5F
0005434081995	12782	22	6A
0005434082004	12782	23	6C
0005434067847	12782	24	6D
0005434067607	12782	25	6E
0005434067642	12782	26	7A
0005434067832	12782	27	6F
0005432433742	12782	28	7C
0005434068006	12782	29	7B
0005434067398	12782	30	7D
0005434067773	12782	31	7F
0005434067830	12782	32	7E
0005434067854	12782	33	8A
0005434067651	12782	34	8B
0005432433744	12782	35	8C
0005434026713	12782	36	8D
0005434067822	12782	37	8F
0005434081883	12782	38	8E
0005433989777	12782	39	9A
0005434067904	12782	40	9B
0005434067722	12782	41	9D
0005434067802	12782	42	9E
0005434067771	12782	43	9F
0005434067772	12782	44	10B
0005433812929	12782	45	10C
0005434067835	12782	46	10D
0005434081934	12782	47	11A
0005434068005	12782	48	10E
0005434067861	12782	49	11C
0005434081979	12782	50	11B
0005434067882	12782	51	11F
0005434067683	12782	52	11E
0005434067402	12782	53	12A
0005432159915	12782	54	12C
0005432433747	12782	55	12B
0005434067801	12782	56	12E
0005434068134	12782	57	12D
0005433812931	12782	58	12F
0005432161180	12782	59	13A
0005434067664	12782	60	13B
0005433989782	12782	61	13C
0005434081944	12782	62	13E
0005434067777	12782	63	13D
0005434067780	12782	64	14A
0005433989779	12782	65	13F
0005434067652	12782	66	14B
0005434067666	12782	67	14C
0005434067623	12782	68	14D
0005432159912	12782	69	14E
0005434067807	12782	70	14F
0005432433746	12782	71	15A
0005432433745	12782	72	15C
0005434068007	12782	73	15D
0005434067719	12782	74	15E
0005434067943	12782	75	16A
0005434067760	12782	76	15F
0005434067894	12782	77	16B
0005434081962	12782	78	16C
0005434067800	12782	79	16F
0005432159913	12782	80	16E
0005434026709	12782	81	17A
0005434081872	12782	82	17B
0005434067818	12782	83	17C
0005434067781	12782	84	17D
0005434067572	12782	85	17E
0005434067711	12782	86	18A
0005434067826	12782	87	18B
0005434082001	12782	88	18D
0005434067576	12782	89	18E
0005434067831	12782	90	19A
0005434067712	12782	91	19B
0005433989781	12782	92	19C
0005432159914	12782	93	19D
0005434082022	12782	94	19F
0005434067784	12782	95	19E
0005434082010	12782	96	20B
0005434081980	12782	97	20A
0005433812930	12782	98	20C
0005434068011	12782	99	20D
0005434067786	12782	100	20E
0005434067702	12782	101	20F
0005434081863	12782	102	21A
0005434067662	12782	103	21C
0005434067631	12782	104	21D
0005434067984	12782	105	21E
0005432161179	12782	106	22A
0005434081984	12782	107	22B
0005434067578	12782	108	22C
0005434081965	12782	109	22D
0005434081994	12782	110	22F
0005433989767	12782	111	22E
0005435283411	12782	112	23A
0005434068010	12782	113	23B
0005433812928	12782	114	23C
0005434081873	12782	115	23E
0005434081947	12782	116	23D
0005434082160	30636	1	1A
0005434068359	30636	2	1C
0005433989824	30636	3	1F
0005434026724	30636	4	1D
0005434082165	30636	5	2C
0005434068341	30636	6	2A
0005434068334	30636	7	2D
0005434068383	30636	8	2F
0005434068352	30636	9	3C
0005434068397	30636	10	3A
0005434068329	30636	11	3D
0005434068369	30636	12	3F
0005433812897	30636	13	4B
0005434068366	30636	14	4A
0005434068380	30636	15	4D
0005434082158	30636	16	4E
0005434068367	30636	17	5A
0005432150283	30636	18	4F
0005433812896	30636	19	5B
0005434068381	30636	20	5D
0005432150286	30636	21	5C
0005434068391	30636	22	5E
0005434068331	30636	23	6A
0005434068336	30636	24	5F
0005434068378	30636	25	6C
0005434068351	30636	26	6B
0005433812908	30636	27	6E
0005434082170	30636	28	7A
0005433812909	30636	29	6F
0005434082166	30636	30	7B
0005434068393	30636	31	7C
0005433812898	30636	32	7D
0005434068338	30636	33	7F
0005434082163	30636	34	7E
0005432186912	30636	35	8A
0005434068328	30636	36	8B
0005434068382	30636	37	8D
0005433812894	30636	38	8C
0005434068362	30636	39	8E
0005433989826	30636	40	8F
0005434068370	30636	41	9B
0005434082164	30636	42	9A
0005434082167	30636	43	9D
0005434082159	30636	44	9C
0005434068350	30636	45	9E
0005434068335	30636	46	9F
0005434068343	30636	47	10C
0005434082171	30636	48	10B
0005434068375	30636	49	10D
0005434082168	30636	50	10E
0005434068349	30636	51	11A
0005432433706	30636	52	11B
0005434068376	30636	53	11D
0005434082169	30636	54	11C
0005434068379	30636	55	11E
0005432150281	30636	56	11F
0005432186911	30636	57	12A
0005432433693	30636	58	12C
0005434068347	30636	59	12B
0005434068374	30636	60	12D
0005434068387	30636	61	12E
0005432150280	30636	62	12F
0005434068390	30636	63	13B
0005434082162	30636	64	13A
0005432433684	30636	65	13D
0005434068337	30636	66	13C
0005434068346	30636	67	13E
0005434068368	30636	68	14A
0005434068340	30636	69	13F
0005434068373	30636	70	14C
0005434082161	30636	71	14B
0005434068377	30636	72	14D
0005434068389	30636	73	14E
0005434068400	30636	74	14F
0005434068365	30636	75	15A
0005434068399	30636	76	15C
0005434068361	30636	77	15B
0005434068333	30636	78	15D
0005434068339	30636	79	15F
0005434068360	30636	80	15E
0005434068364	30636	81	16A
0005434068356	30636	82	16B
0005434068330	30636	83	16C
0005434068357	30636	84	16D
0005434068384	30636	85	16E
0005434068332	30636	86	17A
0005432150282	30636	87	16F
0005434068394	30636	88	17B
0005434068401	30636	89	17C
0005434068392	30636	90	17E
0005434068344	30636	91	17D
0005434068353	30636	92	17F
0005434068388	30636	93	18A
0005433989825	30636	94	18B
0005434026727	30636	95	18C
0005432150287	30636	96	18E
0005432150284	30636	97	18D
0005434068385	30636	98	19A
0005433812905	30636	99	18F
0005434068354	30636	100	19B
0005434082174	30636	101	19C
0005434068396	30636	102	19E
0005434068398	30636	103	19F
0005434068371	30636	104	20A
0005434068348	30636	105	20B
0005434068345	30636	106	20C
0005433812907	30636	107	20E
0005434068372	30636	108	20D
0005434068355	30636	109	20F
0005434026725	30636	110	21B
0005434026726	30636	111	21A
0005433812915	30636	112	21C
0005434068342	30636	113	21D
0005432433716	30636	114	21E
0005434068358	30636	115	21F
0005432433702	30636	116	22A
0005434026728	30636	117	22C
0005433812895	30636	118	22B
0005432186910	30636	119	22E
0005433989823	30636	120	22D
0005434068363	30636	121	23A
0005434068395	30636	122	22F
0005434082175	30636	123	23B
0005434068386	30636	124	23C
0005432150285	30636	125	23D
0005434082172	30636	126	23F
0005434082173	30636	127	23E
0005435462561	5524	1	1B
0005434265182	5524	2	1H
0005435462430	5524	3	1G
0005435462542	5524	4	2A
0005435462726	5524	5	2C
0005432140545	5524	6	2B
0005435722085	5524	7	2H
0005435735191	5524	8	2G
0005435766945	5524	9	3A
0005434265224	5524	10	3B
0005435722084	5524	11	3F
0005435766952	5524	12	3C
0005435462437	5524	13	3G
0005435766961	5524	14	4A
0005432535848	5524	15	3H
0005432140547	5524	16	4B
0005432140551	5524	17	4C
0005434265190	5524	18	4F
0005435462495	5524	19	4H
0005435766954	5524	20	5B
0005435766963	5524	21	5A
0005435462538	5524	22	5C
0005435766958	5524	23	5G
0005434265208	5524	24	5F
0005435766970	5524	25	5H
0005435462537	5524	26	9B
0005435462599	5524	27	9A
0005435462481	5524	28	9H
0005435462522	5524	29	9G
0005435766951	5524	30	11A
0005435766953	5524	31	11D
0005433529325	5524	32	11B
0005434265125	5524	33	11E
0005435462480	5524	34	11G
0005435766946	5524	35	11F
0005435766955	5524	36	12A
0005435043289	5524	37	11H
0005435766967	5524	38	12D
0005434265242	5524	39	12B
0005435462588	5524	40	12E
0005435766978	5524	41	12F
0005435725659	5524	42	12H
0005435766972	5524	43	12G
0005433529326	5524	44	13B
0005434265183	5524	45	13A
0005435766973	5524	46	13D
0005435462725	5524	47	13E
0005435462507	5524	48	13G
0005435462719	5524	49	13F
0005434265257	5524	50	13H
0005435462302	5524	51	14B
0005435766964	5524	52	14A
0005435462711	5524	53	14F
0005435462620	5524	54	14E
0005435462746	5524	55	14H
0005435462431	5524	56	14G
0005435725658	5524	57	15A
0005435766960	5524	58	15E
0005434265186	5524	59	15D
0005433529323	5524	60	15F
0005435462543	5524	61	15H
0005434265310	5524	62	15G
0005432140544	5524	63	16B
0005435462625	5524	64	16E
0005433527314	5524	65	16H
0005433529324	5524	66	17B
0005435766983	5524	67	17F
0005435462600	5524	68	17H
0005432140549	5524	69	18D
0005435766943	5524	70	18E
0005435735189	5524	71	18F
0005434265079	5524	72	19A
0005435766944	5524	73	18H
0005435766976	5524	74	19B
0005435766969	5524	75	19F
0005432535862	5524	76	19H
0005435462619	5524	77	20E
0005434265209	5524	78	20F
0005435462631	5524	79	20H
0005435766965	5524	80	20G
0005435766971	5524	81	21A
0005435766962	5524	82	21E
0005435735190	5524	83	21F
0005435462614	5524	84	21G
0005435462668	5524	85	22B
0005435462362	5524	86	22A
0005435462641	5524	87	22D
0005435720838	5524	88	22E
0005433527313	5524	89	22F
0005433527312	5524	90	23B
0005434265245	5524	91	23A
0005435462562	5524	92	23F
0005435722083	5524	93	23E
0005435462682	5524	94	23G
0005435766979	5524	95	23H
0005435766981	5524	96	24A
0005435462494	5524	97	24F
0005435766984	5524	98	24E
0005435462457	5524	99	24G
0005435766966	5524	100	25D
0005434265256	5524	101	25E
0005433527315	5524	102	27A
0005435462720	5524	103	25F
0005435462632	5524	104	27B
0005435462661	5524	105	27E
0005435766959	5524	106	27H
0005435766975	5524	107	27G
0005435725656	5524	108	28A
0005435725657	5524	109	28B
0005434265080	5524	110	28D
0005435725655	5524	111	28F
0005434265311	5524	112	29B
0005435462506	5524	113	29D
0005432140550	5524	114	29G
0005434265108	5524	115	29F
0005435462452	5524	116	29H
0005435462745	5524	117	30A
0005432140546	5524	118	30D
0005435617172	5524	119	30B
0005435766977	5524	120	30E
0005435766985	5524	121	30G
0005435766948	5524	122	30F
0005435766956	5524	123	31B
0005435766947	5524	124	31A
0005434265207	5524	125	31G
0005435766986	5524	126	32A
0005435462425	5524	127	31H
0005435462642	5524	128	32E
0005435462535	5524	129	32D
0005435462589	5524	130	32F
0005434265102	5524	131	33A
0005434265220	5524	132	33E
0005432535849	5524	133	33F
0005435766982	5524	134	33G
0005434265227	5524	135	34A
0005432535831	5524	136	34D
0005435617171	5524	137	34G
0005434265107	5524	138	34H
0005435462615	5524	139	35B
0005432140543	5524	140	35D
0005435462590	5524	141	35E
0005435462606	5524	142	35G
0005435462621	5524	143	35F
0005435723070	5524	144	36A
0005435766949	5524	145	35H
0005435462598	5524	146	36B
0005435735192	5524	147	36D
0005434265148	5524	148	36F
0005435766974	5524	149	36H
0005435766950	5524	150	37A
0005434265161	5524	151	37E
0005434265247	5524	152	37D
0005434265261	5524	153	37F
0005435766957	5524	154	38A
0005434265218	5524	155	38B
0005432140548	5524	156	38E
0005434265246	5524	157	38H
0005435766980	5524	158	38G
0005432140552	5524	159	39E
0005435766968	5524	160	39D
0005435720837	5524	161	39F
0005435462896	13476	1	34B
0005434831209	13476	2	1C
0005435766327	13476	3	1B
0005435462878	13476	4	1F
0005434265452	13476	5	1G
0005435766326	13476	6	2C
0005435766260	13476	7	2B
0005435766504	13476	8	2F
0005435766234	13476	9	3A
0005435723045	13476	10	2H
0005435462884	13476	11	3C
0005434265442	13476	12	3B
0005435766373	13476	13	3F
0005435462914	13476	14	3G
0005434265448	13476	15	4A
0005433529280	13476	16	3H
0005435766320	13476	17	4B
0005435766195	13476	18	4G
0005435766463	13476	19	4H
0005435462893	13476	20	5A
0005434265465	13476	21	5C
0005433533315	13476	22	5G
0005435462890	13476	23	5F
0005435462888	13476	24	5H
0005435766421	13476	25	9B
0005435766149	13476	26	9A
0005433529270	13476	27	9G
0005435766456	13476	28	9H
0005435462917	13476	29	11E
0005432194561	13476	30	11D
0005435766441	13476	31	11F
0005435766475	13476	32	11G
0005433533312	13476	33	12A
0005434265445	13476	34	11H
0005433533320	13476	35	12D
0005435766541	13476	36	12B
0005434265461	13476	37	12E
0005434265459	13476	38	12G
0005434265451	13476	39	12H
0005435735162	13476	40	13A
0005434265444	13476	41	13E
0005435766506	13476	42	13G
0005435766345	13476	43	13F
0005434265467	13476	44	13H
0005435462907	13476	45	14B
0005435722059	13476	46	14D
0005435462902	13476	47	14E
0005434265462	13476	48	14H
0005435766360	13476	49	14G
0005435722061	13476	50	15A
0005435462898	13476	51	15B
0005433529291	13476	52	15E
0005435766536	13476	53	15F
0005435766372	13476	54	15H
0005435462881	13476	55	15G
0005433533317	13476	56	16A
0005432535891	13476	57	16D
0005434265468	13476	58	16B
0005433533309	13476	59	16E
0005434265449	13476	60	16G
0005434265460	13476	61	16H
0005433533300	13476	62	17D
0005435766540	13476	63	17F
0005435766525	13476	64	17E
0005435766514	13476	65	17G
0005435462880	13476	66	18B
0005432535892	13476	67	18D
0005435462889	13476	68	18E
0005435766362	13476	69	18G
0005433533303	13476	70	18F
0005434265456	13476	71	19A
0005433533327	13476	72	18H
0005433529284	13476	73	19D
0005435462913	13476	74	19F
0005433529275	13476	75	19H
0005435462877	13476	76	19G
0005435462882	13476	77	20A
0005435766521	13476	78	20D
0005433529276	13476	79	20B
0005432194564	13476	80	20E
0005435725605	13476	81	20H
0005435462906	13476	82	21A
0005435766505	13476	83	21D
0005435462903	13476	84	21B
0005435462909	13476	85	21F
0005435462895	13476	86	21E
0005433529254	13476	87	21G
0005434265464	13476	88	21H
0005435766168	13476	89	22A
0005433533333	13476	90	22D
0005435766515	13476	91	22B
0005433529271	13476	92	22F
0005435766462	13476	93	22E
0005434265457	13476	94	22H
0005435462912	13476	95	23A
0005435462879	13476	96	23E
0005433529262	13476	97	23D
0005435462908	13476	98	23F
0005434831211	13476	99	23H
0005435723060	13476	100	24B
0005435462904	13476	101	24A
0005433533280	13476	102	24D
0005435722060	13476	103	24F
0005435735142	13476	104	24E
0005434265454	13476	105	24G
0005433533313	13476	106	25D
0005432535894	13476	107	24H
0005435766150	13476	108	25E
0005434265453	13476	109	25F
0005435766262	13476	110	27B
0005435766322	13476	111	27A
0005435462883	13476	112	27D
0005435766261	13476	113	27F
0005434831208	13476	114	27H
0005435462892	13476	115	28B
0005435462887	13476	116	28E
0005435766522	13476	117	28D
0005434265463	13476	118	28F
0005432535893	13476	119	29A
0005435735143	13476	120	28H
0005434831207	13476	121	29D
0005435766167	13476	122	29B
0005435462911	13476	123	29G
0005435462900	13476	124	29F
0005435766127	13476	125	29H
0005435766332	13476	126	30B
0005432194563	13476	127	30D
0005435766359	13476	128	30F
0005433529261	13476	129	30E
0005433529256	13476	130	30H
0005435462905	13476	131	31B
0005432194562	13476	132	31A
0005435766363	13476	133	31D
0005435462910	13476	134	31F
0005432535895	13476	135	31E
0005435462897	13476	136	31G
0005433533304	13476	137	32A
0005434265466	13476	138	31H
0005434265458	13476	139	32D
0005433529260	13476	140	32B
0005435766440	13476	141	32E
0005435766524	13476	142	32G
0005435766406	13476	143	33A
0005433529250	13476	144	32H
0005434831210	13476	145	33B
0005434265446	13476	146	33G
0005435766361	13476	147	33F
0005434265450	13476	148	33H
0005435462885	13476	149	34D
0005435462886	13476	150	34G
0005435462901	13476	151	34F
0005433533316	13476	152	35A
0005434265455	13476	153	34H
0005435462915	13476	154	35F
0005433533318	13476	155	35E
0005435766321	13476	156	35G
0005435462899	13476	157	35H
0005435462894	13476	158	36B
0005435766439	13476	159	36A
0005435766357	13476	160	36D
0005433529251	13476	161	36E
0005435766264	13476	162	36G
0005434265443	13476	163	37D
0005435766371	13476	164	37B
0005435462916	13476	165	38A
0005433533332	13476	166	38D
0005435462891	13476	167	38B
0005433529281	13476	168	38G
0005433533279	13476	169	38F
0005435766454	13476	170	38H
0005435766526	13476	171	39D
0005434265447	13476	172	39F
0005433529255	13476	173	39E
0005434602909	18744	1	2A
0005434602908	18744	2	2B
0005434602907	18744	3	3B
0005434602900	18744	4	6B
0005434513609	18736	1	1A
0005434604897	18736	2	2A
0005434513610	18736	3	1B
0005434514997	18736	4	2B
0005434514999	18736	5	3B
0005434514998	18736	6	4A
0005434604901	18736	7	4B
0005434604902	18736	8	6A
0005434514996	18736	9	5B
0005434604899	18736	10	6B
0005434514971	19173	1	2B
0005434514985	19173	2	5A
0005432632818	4117	1	1C
0005432649469	4117	2	1D
0005432649475	4117	3	1F
0005435844336	4117	4	2A
0005432649474	4117	5	2F
0005432649477	4117	6	3A
0005435844337	4117	7	3D
0005435846251	4117	8	3F
0005435846275	4117	9	4C
0005435846270	4117	10	5E
0005432649470	4117	11	5F
0005432649480	4117	12	6D
0005432649483	4117	13	6F
0005432632823	4117	14	7D
0005432649482	4117	15	7F
0005435846252	4117	16	8A
0005435846253	4117	17	8D
0005435846236	4117	18	8E
0005435844322	4117	19	9D
0005432632820	4117	20	9F
0005432632826	4117	21	11C
0005435844335	4117	22	11D
0005432632821	4117	23	11E
0005432649481	4117	24	12A
0005432632825	4117	25	12F
0005432632828	4117	26	13A
0005435844324	4117	27	13C
0005432632829	4117	28	13D
0005432632822	4117	29	13E
0005432632831	4117	30	14F
0005432649478	4117	31	15E
0005435846254	4117	32	16E
0005432649471	4117	33	17A
0005435846271	4117	34	17C
0005432649479	4117	35	17F
0005432632819	4117	36	18A
0005432632830	4117	37	18E
0005432649472	4117	38	18F
0005435844321	4117	39	19D
0005432632824	4117	40	19E
0005432649476	4117	41	19F
0005435844325	4117	42	20A
0005432632827	4117	43	20D
0005432649473	4117	44	20E
0005433285507	1786	1	1A
0005433008571	1786	2	1C
0005433008945	1786	3	1D
0005433285471	1786	4	1F
0005433008744	1786	5	2A
0005433285482	1786	6	2C
0005433285589	1786	7	2D
0005433285504	1786	8	2F
0005433009025	1786	9	3A
0005433285275	1786	10	3C
0005433008902	1786	11	3D
0005433285299	1786	12	3F
0005433008958	1786	13	4A
0005432295912	1786	14	4C
0005433285399	1786	15	4D
0005433285502	1786	16	4E
0005433008784	1786	17	4F
0005433008966	1786	18	5A
0005433008712	1786	19	5C
0005433285588	1786	20	5D
0005433285489	1786	21	5E
0005433285450	1786	22	6A
0005433008913	1786	23	6C
0005433008851	1786	24	6D
0005433008754	1786	25	6E
0005433008581	1786	26	6F
0005433008755	1786	27	7A
0005433285446	1786	28	7D
0005433285400	1786	29	7E
0005433285398	1786	30	7F
0005433008850	1786	31	8A
0005433285429	1786	32	8D
0005433285427	1786	33	8E
0005433008959	1786	34	9A
0005433008778	1786	35	9C
0005433008568	1786	36	9D
0005433285370	1786	37	9E
0005433008930	1786	38	9F
0005433008874	1786	39	10A
0005433285433	1786	40	10D
0005433285385	1786	41	10E
0005433285389	1786	42	10F
0005433008872	1786	43	11A
0005433285605	1786	44	11C
0005433008928	1786	45	11D
0005433008821	1786	46	11E
0005433285421	1786	47	11F
0005433008533	1786	48	12A
0005433008709	1786	49	12C
0005433285428	1786	50	12D
0005433285449	1786	51	12E
0005433008731	1786	52	12F
0005433285503	1786	53	13A
0005433008706	1786	54	13C
0005433008726	1786	55	13D
0005433008689	1786	56	13E
0005432295910	1786	57	14C
0005433008711	1786	58	14D
0005433008779	1786	59	14E
0005433008730	1786	60	14F
0005433285470	1786	61	15A
0005433008756	1786	62	15C
0005433285435	1786	63	15D
0005433008569	1786	64	15E
0005433285238	1786	65	15F
0005433008668	1786	66	16A
0005432295911	1786	67	16C
0005433285368	1786	68	16D
0005433285325	1786	69	16E
0005433008820	1786	70	16F
0005433285403	1786	71	17A
0005433285480	1786	72	17C
0005433285508	1786	73	17D
0005433008715	1786	74	17E
0005433285436	1786	75	17F
0005433285404	1786	76	18A
0005433009043	1786	77	18C
0005433008667	1786	78	18D
0005433008696	1786	79	18E
0005433285481	1786	80	18F
0005433285277	1786	81	19A
0005433285383	1786	82	19C
0005433285388	1786	83	19D
0005433285387	1786	84	19E
0005433285501	1786	85	19F
0005433008777	1786	86	20A
0005433285401	1786	87	20C
0005433008771	1786	88	20D
0005433008904	1786	89	20E
0005433285606	1786	90	20F
0005433285667	22591	1	1A
0005433009167	22591	2	1C
0005433009134	22591	3	1D
0005433285650	22591	4	2A
0005433009158	22591	5	2C
0005433810544	22591	6	2D
0005433285673	22591	7	2F
0005433009140	22591	8	3A
0005433009154	22591	9	3F
0005433285660	22591	10	4A
0005433285671	22591	11	4C
0005433009161	22591	12	4E
0005433285668	22591	13	4F
0005433285672	22591	14	5A
0005433009163	22591	15	5C
0005433009146	22591	16	5D
0005433009136	22591	17	5E
0005433009143	22591	18	6A
0005433009137	22591	19	6C
0005433009135	22591	20	6D
0005433285651	22591	21	6E
0005433009144	22591	22	6F
0005433009132	22591	23	7A
0005433009156	22591	24	7D
0005433285654	22591	25	7E
0005433009128	22591	26	7F
0005433285670	22591	27	8A
0005433009150	22591	28	8C
0005433009164	22591	29	8E
0005433285652	22591	30	8F
0005433810543	22591	31	9A
0005433009138	22591	32	9C
0005433810541	22591	33	9D
0005433009145	22591	34	9E
0005433009130	22591	35	9F
0005433285646	22591	36	10D
0005433009141	22591	37	10E
0005433009165	22591	38	11A
0005433285649	22591	39	11C
0005433009126	22591	40	11D
0005433285666	22591	41	11E
0005433009148	22591	42	12A
0005433009157	22591	43	12C
0005433009124	22591	44	12D
0005433009131	22591	45	12E
0005433285675	22591	46	12F
0005433009160	22591	47	13A
0005433009155	22591	48	13C
0005433285653	22591	49	13D
0005433285659	22591	50	13F
0005433810545	22591	51	14C
0005433009152	22591	52	14D
0005433009151	22591	53	14E
0005433285656	22591	54	15A
0005433009129	22591	55	15C
0005433285648	22591	56	15E
0005433285663	22591	57	15F
0005433009127	22591	58	16A
0005433009142	22591	59	16C
0005433009159	22591	60	16D
0005433285664	22591	61	16E
0005433009149	22591	62	16F
0005433285658	22591	63	17A
0005433285655	22591	64	17C
0005433285662	22591	65	17D
0005433009153	22591	66	17E
0005433009162	22591	67	18A
0005433009166	22591	68	18C
0005433009147	22591	69	18D
0005433285661	22591	70	18E
0005433285647	22591	71	18F
0005433285674	22591	72	19A
0005433009125	22591	73	19C
0005433285665	22591	74	19D
0005433810547	22591	75	19E
0005433285669	22591	76	19F
0005433009133	22591	77	20A
0005433009139	22591	78	20C
0005433285657	22591	79	20E
0005433847400	5599	1	1C
0005435282522	5599	2	1A
0005435282571	5599	3	1F
0005433847413	5599	4	2A
0005433847456	5599	5	2D
0005433847414	5599	6	2C
0005433847453	5599	7	3A
0005433847454	5599	8	2F
0005435282597	5599	9	3D
0005433847434	5599	10	3C
0005433847439	5599	11	4D
0005432081591	5599	12	4C
0005433847407	5599	13	4A
0005435282521	5599	14	5A
0005433847405	5599	15	4F
0005433847429	5599	16	5D
0005435282592	5599	17	5C
0005433847441	5599	18	5F
0005435282562	5599	19	6B
0005433847433	5599	20	6A
0005435282678	5599	21	6D
0005433847450	5599	22	6C
0005433815441	5599	23	6F
0005433847446	5599	24	6E
0005434173531	5599	25	7A
0005433847449	5599	26	7C
0005433847437	5599	27	7B
0005433847442	5599	28	7E
0005435282679	5599	29	7D
0005434173539	5599	30	7F
0005433847403	5599	31	8B
0005433847409	5599	32	8A
0005435282595	5599	33	8E
0005432081590	5599	34	8D
0005435282570	5599	35	8F
0005435282549	5599	36	9B
0005435282548	5599	37	9A
0005435282619	5599	38	9D
0005433847423	5599	39	9C
0005433847435	5599	40	9E
0005435282671	5599	41	10A
0005433847425	5599	42	10B
0005433847422	5599	43	10D
0005433847406	5599	44	11A
0005433847397	5599	45	10F
0005433847447	5599	46	11B
0005433847399	5599	47	11C
0005433847452	5599	48	11F
0005432081587	5599	49	11E
0005433847421	5599	50	12B
0005435282634	5599	51	12A
0005433847445	5599	52	12D
0005433847426	5599	53	12C
0005435282527	5599	54	12F
0005433847416	5599	55	12E
0005433847396	5599	56	13C
0005435282635	5599	57	13B
0005434173535	5599	58	13E
0005432081586	5599	59	13D
0005433847398	5599	60	13F
0005433847440	5599	61	14C
0005433847402	5599	62	14B
0005433847432	5599	63	14D
0005433815442	5599	64	15A
0005433847431	5599	65	14E
0005433847420	5599	66	15B
0005433847401	5599	67	15D
0005433847451	5599	68	15C
0005433847418	5599	69	15E
0005433847415	5599	70	15F
0005435282528	5599	71	16C
0005433815443	5599	72	16B
0005434173532	5599	73	16E
0005435282523	5599	74	16D
0005433847436	5599	75	17B
0005433847427	5599	76	17F
0005433847412	5599	77	17E
0005433815440	5599	78	18B
0005433847404	5599	79	18A
0005433847430	5599	80	18C
0005433847444	5599	81	18E
0005433847417	5599	82	18D
0005433847419	5599	83	18F
0005433847411	5599	84	19B
0005432081588	5599	85	19A
0005435282642	5599	86	19E
0005433847428	5599	87	19C
0005433847424	5599	88	19F
0005433847410	5599	89	20B
0005432081589	5599	90	20A
0005433847455	5599	91	20D
0005434173518	5599	92	20C
0005435282547	5599	93	20E
0005435282620	5599	94	21B
0005433847448	5599	95	21C
0005433847443	5599	96	21E
0005433847438	5599	97	21D
0005433847408	5599	98	21F
0005433846847	13856	1	1C
0005433847103	13856	2	1A
0005435282810	13856	3	2C
0005435282802	13856	4	2A
0005433846899	13856	5	1F
0005433846743	13856	6	2D
0005433846817	13856	7	3A
0005433846936	13856	8	2F
0005433815391	13856	9	3D
0005433846887	13856	10	3C
0005433846808	13856	11	3F
0005435282798	13856	12	4D
0005433815386	13856	13	4C
0005435282791	13856	14	5A
0005435282795	13856	15	4F
0005433847106	13856	16	5C
0005433846844	13856	17	5F
0005435282805	13856	18	5D
0005433815407	13856	19	6B
0005435282806	13856	20	6A
0005433847009	13856	21	6C
0005433846842	13856	22	6D
0005433846635	13856	23	7A
0005435282804	13856	24	6F
0005433846997	13856	25	7C
0005433846813	13856	26	7B
0005435282809	13856	27	7E
0005433847026	13856	28	7F
0005433846868	13856	29	8B
0005433847129	13856	30	8E
0005433846825	13856	31	8D
0005433847057	13856	32	8C
0005435282807	13856	33	9B
0005433847093	13856	34	9F
0005432003740	13856	35	9E
0005434173570	13856	36	9D
0005433846848	13856	37	10B
0005433846792	13856	38	10A
0005433846867	13856	39	10C
0005433846982	13856	40	10E
0005433846747	13856	41	10D
0005435282808	13856	42	11A
0005433847007	13856	43	10F
0005433846959	13856	44	11C
0005433846863	13856	45	11B
0005434173568	13856	46	11E
0005433846859	13856	47	11D
0005435282811	13856	48	11F
0005433846786	13856	49	12B
0005433846951	13856	50	12A
0005433847059	13856	51	12D
0005433847130	13856	52	12C
0005433846892	13856	53	12E
0005433847065	13856	54	13A
0005433846840	13856	55	13D
0005433847002	13856	56	13C
0005433846827	13856	57	13B
0005435282793	13856	58	13E
0005433847005	13856	59	14A
0005433846744	13856	60	13F
0005435282797	13856	61	14C
0005435282796	13856	62	14B
0005433846741	13856	63	14F
0005433846877	13856	64	14E
0005433846948	13856	65	15A
0005433846787	13856	66	15C
0005433846826	13856	67	15B
0005435282792	13856	68	15F
0005433846820	13856	69	15E
0005433847058	13856	70	15D
0005432003739	13856	71	16C
0005433846720	13856	72	16B
0005433846634	13856	73	16E
0005434173567	13856	74	16D
0005433846865	13856	75	17A
0005433846816	13856	76	16F
0005433846918	13856	77	17B
0005433846856	13856	78	17D
0005433847166	13856	79	17C
0005434173569	13856	80	17F
0005435282801	13856	81	17E
0005433846806	13856	82	18B
0005435282803	13856	83	18D
0005433846821	13856	84	18C
0005433846793	13856	85	18E
0005433847102	13856	86	19A
0005433846746	13856	87	18F
0005435282799	13856	88	19D
0005433846725	13856	89	19C
0005433846719	13856	90	19F
0005433815408	13856	91	19E
0005433846788	13856	92	20B
0005433846727	13856	93	20A
0005435282800	13856	94	20D
0005433846969	13856	95	20E
0005433846828	13856	96	21A
0005433846845	13856	97	20F
0005433847006	13856	98	21C
0005433846855	13856	99	21B
0005435282794	13856	100	21E
0005433815405	13856	101	21D
0005433846726	13856	102	21F
0005435332377	7826	1	1A
0005432112543	7826	2	1C
0005434620853	7826	3	2A
0005434620841	7826	4	2C
0005434620837	7826	5	2D
0005434620851	7826	6	3A
0005432112544	7826	7	3D
0005435332348	7826	8	4A
0005434620847	7826	9	4C
0005434620838	7826	10	5B
0005434620852	7826	11	5C
0005434620846	7826	12	5D
0005435332388	7826	13	6A
0005434620850	7826	14	6B
0005435332358	7826	15	6C
0005432112545	7826	16	7B
0005434620842	7826	17	7C
0005434620839	7826	18	18B
0005434620835	7826	19	18A
0005434620844	7826	20	18D
0005432112542	7826	21	19A
0005434620836	7826	22	19C
0005434620843	7826	23	20A
0005434620845	7826	24	20D
0005434620849	7826	25	21A
0005435332376	7826	26	21B
0005434620833	7826	27	21D
0005434620840	7826	28	22A
0005435332359	7826	29	22B
0005435332398	7826	30	22C
0005434620834	7826	31	23A
0005434620848	7826	32	23B
0005435332457	32955	1	1A
0005434620673	32955	2	1B
0005434620645	32955	3	1C
0005434620662	32955	4	1D
0005434620651	32955	5	2C
0005434620708	32955	6	2D
0005435332460	32955	7	3D
0005435332461	32955	8	4A
0005434620563	32955	9	4B
0005434620692	32955	10	4C
0005434620650	32955	11	4D
0005434620644	32955	12	5A
0005434620677	32955	13	5B
0005435332463	32955	14	5C
0005434620643	32955	15	6A
0005434620614	32955	16	6B
0005434620694	32955	17	6C
0005434620669	32955	18	7C
0005435332464	32955	19	7D
0005435332456	32955	20	18D
0005435332459	32955	21	19A
0005435332455	32955	22	19C
0005434620632	32955	23	19D
0005434620693	32955	24	20A
0005435332462	32955	25	20B
0005435332458	32955	26	20C
0005434620617	32955	27	21A
0005435332465	32955	28	21B
0005434620663	32955	29	21D
0005434620616	32955	30	22A
0005434620695	32955	31	22B
0005434620615	32955	32	22C
0005434620676	32955	33	22D
0005434620709	32955	34	23A
0005435785776	4271	1	1A
0005435785766	4271	2	1F
0005435785765	4271	3	2A
0005435785757	4271	4	2D
0005435785787	4271	5	3D
0005435785775	4271	6	3F
0005435785771	4271	7	4D
0005435785785	4271	8	4E
0005435785784	4271	9	4F
0005435785788	4271	10	5A
0005432190677	4271	11	5D
0005435785756	4271	12	5E
0005434994135	4271	13	5F
0005435785764	4271	14	6C
0005435937395	4271	15	6F
0005435918691	4271	16	7A
0005435918685	4271	17	7C
0005435785789	4271	18	7D
0005435785761	4271	19	7E
0005435785779	4271	20	8A
0005435785780	4271	21	8C
0005435787380	4271	22	8D
0005435785781	4271	23	9A
0005435785759	4271	24	9C
0005435785774	4271	25	9F
0005435785777	4271	26	11A
0005434994143	4271	27	11C
0005435785760	4271	28	11E
0005434994138	4271	29	11F
0005435785790	4271	30	12A
0005434994141	4271	31	12F
0005435918678	4271	32	13F
0005434994136	4271	33	14C
0005434994140	4271	34	14D
0005435785773	4271	35	14E
0005435785772	4271	36	14F
0005434994144	4271	37	15D
0005435787381	4271	38	15E
0005434994137	4271	39	16A
0005435785767	4271	40	16C
0005434994139	4271	41	16F
0005432190676	4271	42	17A
0005435785762	4271	43	17D
0005435785783	4271	44	17E
0005435785786	4271	45	17F
0005435785758	4271	46	18A
0005432190675	4271	47	18C
0005435785768	4271	48	18D
0005435785770	4271	49	19A
0005435785782	4271	50	19D
0005435785778	4271	51	19E
0005435785769	4271	52	19F
0005435785763	4271	53	20D
0005434994142	4271	54	20E
0005435785534	27289	1	1A
0005432195717	27289	2	1C
0005435937435	27289	3	1D
0005435785315	27289	4	1F
0005434994051	27289	5	2D
0005435937436	27289	6	3A
0005435785418	27289	7	3F
0005435785263	27289	8	4C
0005435785527	27289	9	4F
0005435785316	27289	10	5A
0005435785424	27289	11	5E
0005435785494	27289	12	6A
0005432195716	27289	13	6D
0005435785493	27289	14	6E
0005435918714	27289	15	6F
0005435787360	27289	16	7A
0005435785168	27289	17	7E
0005435785333	27289	18	7F
0005435785381	27289	19	8A
0005435785443	27289	20	8D
0005435785300	27289	21	9E
0005435785480	27289	22	10C
0005435785415	27289	23	10E
0005435785501	27289	24	10F
0005435785317	27289	25	11C
0005435918713	27289	26	11D
0005435785345	27289	27	11E
0005435785403	27289	28	11F
0005435785414	27289	29	12C
0005435785413	27289	30	12E
0005434994017	27289	31	13D
0005435785461	27289	32	14D
0005435785416	27289	33	14E
0005435785488	27289	34	14F
0005434994016	27289	35	15A
0005435937433	27289	36	15D
0005435785500	27289	37	15E
0005435918712	27289	38	16A
0005434994018	27289	39	16E
0005435937434	27289	40	17E
0005435785343	27289	41	17F
0005435785433	27289	42	18A
0005435785402	27289	43	18C
0005435918715	27289	44	18E
0005435785341	27289	45	19D
0005435785346	27289	46	19F
0005435785458	27289	47	20D
0005435785342	27289	48	20E
0005435785479	27289	49	20F
0005432146222	19856	1	2C
0005432146221	19856	2	3D
0005432568353	4736	1	1A
0005432460485	4736	2	1G
0005432568345	4736	3	2A
0005432568351	4736	4	1H
0005432460473	4736	5	2F
0005432568357	4736	6	2G
0005432460476	4736	7	3A
0005432568376	4736	8	2H
0005432460486	4736	9	3F
0005434082191	4736	10	3G
0005432460479	4736	11	4A
0005432460494	4736	12	3H
0005432460471	4736	13	4C
0005432460478	4736	14	4G
0005432568370	4736	15	4H
0005432571367	4736	16	5B
0005432568374	4736	17	5A
0005434082178	4736	18	5F
0005432568360	4736	19	9A
0005432460498	4736	20	5H
0005432568366	4736	21	9B
0005432460456	4736	22	11A
0005432568372	4736	23	9H
0005432460455	4736	24	11D
0005432568393	4736	25	11F
0005432568386	4736	26	12D
0005433726131	4736	27	12B
0005432568348	4736	28	12F
0005432568387	4736	29	12E
0005432170471	4736	30	12G
0005432568373	4736	31	12H
0005432460467	4736	32	13A
0005432571366	4736	33	13D
0005434082195	4736	34	13E
0005432460492	4736	35	13G
0005434082190	4736	36	13H
0005432568399	4736	37	14B
0005433452765	4736	38	14A
0005432460483	4736	39	14D
0005432568367	4736	40	14F
0005434082192	4736	41	14G
0005432568368	4736	42	15B
0005432568402	4736	43	15E
0005433451644	4736	44	15D
0005432568401	4736	45	15G
0005434082196	4736	46	15H
0005432568365	4736	47	16A
0005432460464	4736	48	16B
0005432460480	4736	49	16E
0005432186916	4736	50	16F
0005432460459	4736	51	16H
0005432568381	4736	52	16G
0005433451643	4736	53	17A
0005432568364	4736	54	17D
0005432460469	4736	55	17F
0005432568379	4736	56	17E
0005432460503	4736	57	18A
0005432460475	4736	58	17H
0005432460495	4736	59	18F
0005434082179	4736	60	19A
0005432568356	4736	61	18H
0005432568361	4736	62	19B
0005432568394	4736	63	19D
0005432571368	4736	64	19F
0005432460461	4736	65	19G
0005432568371	4736	66	20A
0005432460465	4736	67	20B
0005432568397	4736	68	20D
0005432460496	4736	69	20G
0005432568362	4736	70	20F
0005432568350	4736	71	21A
0005432568358	4736	72	21D
0005432568347	4736	73	21B
0005432568352	4736	74	21E
0005432460463	4736	75	21G
0005432568344	4736	76	21F
0005433726132	4736	77	21H
0005434082176	4736	78	22A
0005432568354	4736	79	22D
0005434082184	4736	80	22F
0005432568388	4736	81	22G
0005434082180	4736	82	23F
0005432460454	4736	83	23E
0005434082181	4736	84	23G
0005432460491	4736	85	24A
0005434082186	4736	86	23H
0005432170472	4736	87	24E
0005432460490	4736	88	24D
0005432568400	4736	89	25D
0005432460477	4736	90	24H
0005432568390	4736	91	25E
0005432460489	4736	92	27A
0005432186914	4736	93	25F
0005432568380	4736	94	27B
0005432170467	4736	95	27F
0005432568392	4736	96	27H
0005434082185	4736	97	27G
0005432460488	4736	98	28A
0005432460484	4736	99	28B
0005432460481	4736	100	28E
0005432460472	4736	101	28G
0005432460457	4736	102	28H
0005434082193	4736	103	29A
0005432568363	4736	104	29E
0005432460462	4736	105	29F
0005432460453	4736	106	29H
0005432460460	4736	107	29G
0005432568385	4736	108	30D
0005432186915	4736	109	30B
0005432568342	4736	110	30F
0005434082189	4736	111	30E
0005432460470	4736	112	30G
0005432460458	4736	113	31A
0005432568349	4736	114	30H
0005432170469	4736	115	31B
0005434082188	4736	116	31D
0005434082177	4736	117	31F
0005432460468	4736	118	31E
0005432460497	4736	119	32A
0005432460482	4736	120	31H
0005432460501	4736	121	32E
0005432568384	4736	122	32G
0005432460466	4736	123	32F
0005432568359	4736	124	33A
0005432568395	4736	125	32H
0005432460474	4736	126	33D
0005432568346	4736	127	33B
0005432170468	4736	128	33E
0005433452766	4736	129	33H
0005432186913	4736	130	34A
0005432568375	4736	131	34D
0005432568369	4736	132	34B
0005432568383	4736	133	34E
0005432460493	4736	134	34H
0005432460504	4736	135	34G
0005432568382	4736	136	35B
0005432460487	4736	137	35D
0005432170466	4736	138	35F
0005432460499	4736	139	35E
0005432568389	4736	140	35G
0005432460500	4736	141	35H
0005432460505	4736	142	36B
0005432568396	4736	143	36E
0005432460502	4736	144	36D
0005434082182	4736	145	36F
0005434082183	4736	146	36H
0005434082187	4736	147	36G
0005432568377	4736	148	37A
0005434082194	4736	149	37B
0005432568391	4736	150	37D
0005432568378	4736	151	38A
0005432568341	4736	152	37H
0005432568340	4736	153	38B
0005432568343	4736	154	38E
0005432568398	4736	155	38G
0005433452764	4736	156	38H
0005432568355	4736	157	39F
0005432170470	4736	158	39E
0005432460129	30525	1	1A
0005432460033	30525	2	1F
0005434081984	30525	3	1C
0005432567781	30525	4	1G
0005432213650	30525	5	2A
0005432568200	30525	6	2B
0005432460083	30525	7	2G
0005432568084	30525	8	2H
0005432460133	30525	9	3B
0005432568029	30525	10	3F
0005432459972	30525	11	3G
0005432213651	30525	12	4A
0005434082001	30525	13	3H
0005432567747	30525	14	4B
0005432460260	30525	15	4C
0005432567985	30525	16	5A
0005432460102	30525	17	4H
0005432161179	30525	18	5B
0005432460156	30525	19	5C
0005434081965	30525	20	5G
0005432567721	30525	21	5F
0005432567830	30525	22	9A
0005432567848	30525	23	11A
0005432567934	30525	24	9H
0005432567959	30525	25	11B
0005432568015	30525	26	11F
0005432567653	30525	27	11H
0005432568031	30525	28	11G
0005432567971	30525	29	12B
0005432460228	30525	30	12F
0005432459938	30525	31	12H
0005432567849	30525	32	12G
0005432568082	30525	33	13B
0005433454893	30525	34	13D
0005432460162	30525	35	13E
0005432459927	30525	36	13G
0005432459939	30525	37	13H
0005432571349	30525	38	14B
0005434081944	30525	39	14D
0005432161180	30525	40	14F
0005432567808	30525	41	14E
0005432567912	30525	42	14G
0005432460374	30525	43	15A
0005433452746	30525	44	14H
0005432460158	30525	45	15E
0005432459831	30525	46	15F
0005432567579	30525	47	15H
0005432567804	30525	48	15G
0005432568013	30525	49	16A
0005432459973	30525	50	16D
0005432460103	30525	51	16E
0005432459926	30525	52	16F
0005432567855	30525	53	16H
0005432460184	30525	54	17A
0005432459940	30525	55	17D
0005433452752	30525	56	17B
0005432460153	30525	57	17E
0005432567795	30525	58	17G
0005432567794	30525	59	18A
0005432459969	30525	60	17H
0005432460159	30525	61	18E
0005432460157	30525	62	18D
0005432567594	30525	63	18F
0005434081962	30525	64	18H
0005432567862	30525	65	19B
0005432459706	30525	66	19D
0005432567965	30525	67	19H
0005434081994	30525	68	20A
0005432567950	30525	69	20E
0005432567805	30525	70	20D
0005432568003	30525	71	20F
0005432460229	30525	72	20G
0005432568159	30525	73	21B
0005432567738	30525	74	21A
0005434081934	30525	75	20H
0005434081995	30525	76	21D
0005432567783	30525	77	21G
0005434082023	30525	78	21H
0005432567735	30525	79	22B
0005434082000	30525	80	22A
0005432567648	30525	81	22D
0005434082084	30525	82	22E
0005432460163	30525	83	22G
0005432213653	30525	84	22F
0005432567961	30525	85	23A
0005432567919	30525	86	22H
0005432568158	30525	87	23B
0005432459707	30525	88	23D
0005432460135	30525	89	23G
0005432567715	30525	90	23F
0005432460155	30525	91	24A
0005432460263	30525	92	23H
0005432567714	30525	93	24B
0005434081971	30525	94	24E
0005432460070	30525	95	24G
0005432460118	30525	96	25D
0005432567739	30525	97	24H
0005432460165	30525	98	25E
0005432459964	30525	99	27A
0005432460409	30525	100	25F
0005434081917	30525	101	27D
0005432568028	30525	102	27F
0005432567868	30525	103	27G
0005432460207	30525	104	28A
0005432567803	30525	105	27H
0005432568083	30525	106	28B
0005432459902	30525	107	28E
0005432460093	30525	108	28D
0005432460104	30525	109	28G
0005434081979	30525	110	28F
0005432567981	30525	111	29A
0005432459830	30525	112	29D
0005432459998	30525	113	29B
0005432460105	30525	114	29F
0005432568136	30525	115	29E
0005432459896	30525	116	29G
0005433452750	30525	117	29H
0005432567844	30525	118	30A
0005432567972	30525	119	30D
0005432460218	30525	120	30B
0005432460022	30525	121	30F
0005432567956	30525	122	30E
0005432460045	30525	123	30G
0005432568107	30525	124	31A
0005434081883	30525	125	30H
0005434081947	30525	126	31B
0005432567957	30525	127	31E
0005432459975	30525	128	31D
0005432460375	30525	129	32A
0005432567831	30525	130	31H
0005432460171	30525	131	32E
0005432460136	30525	132	32G
0005434082022	30525	133	33A
0005434082010	30525	134	32H
0005432460032	30525	135	33D
0005432460051	30525	136	33G
0005433454892	30525	137	33F
0005433452745	30525	138	33H
0005432213652	30525	139	34A
0005432567822	30525	140	34D
0005434082004	30525	141	34B
0005432460078	30525	142	34E
0005432459838	30525	143	34H
0005432460119	30525	144	35D
0005432568155	30525	145	35E
0005432567986	30525	146	35G
0005432567806	30525	147	35F
0005432571351	30525	148	35H
0005432459901	30525	149	36B
0005432567968	30525	150	36A
0005432567960	30525	151	36D
0005432568032	30525	152	36F
0005432460140	30525	153	36H
0005432459994	30525	154	36G
0005432567780	30525	155	37A
0005432460154	30525	156	37B
0005432567984	30525	157	37F
0005432567593	30525	158	37E
0005432567660	30525	159	37H
0005434081873	30525	160	37G
0005434081980	30525	161	38B
0005432460231	30525	162	38E
0005432460084	30525	163	38D
0005432460410	30525	164	38H
0005432571350	30525	165	39D
0005434081863	30525	166	39F
0005434081872	30525	167	39E
0005435720837	13617	1	1A
0005435722084	13617	2	3A
0005435720838	13617	3	4B
0005435722083	13617	4	5A
0005435722085	13617	5	6B
0005435722063	21189	1	1A
0005435722065	21189	2	2A
0005435720135	21189	3	4A
0005435722066	21189	4	6B
0005432295912	22804	1	5A
0005432295910	22804	2	19A
0005432295911	22804	3	22B
0005435380316	11089	1	1A
0005433344403	11089	2	1C
0005433344389	11089	3	2A
0005433344344	11089	4	1F
0005433344384	11089	5	2C
0005433344358	11089	6	2D
0005433344414	11089	7	3A
0005433344425	11089	8	2F
0005433344392	11089	9	3C
0005433344356	11089	10	3F
0005433344390	11089	11	3D
0005433344365	11089	12	4A
0005433344345	11089	13	4C
0005435380302	11089	14	4B
0005433344331	11089	15	4D
0005433344416	11089	16	4E
0005435097313	11089	17	4F
0005433344395	11089	18	5B
0005433344353	11089	19	5A
0005433344405	11089	20	5C
0005433344364	11089	21	5D
0005433344333	11089	22	5F
0005433344338	11089	23	5E
0005433344412	11089	24	6B
0005433344401	11089	25	6A
0005433344360	11089	26	6C
0005435097315	11089	27	6D
0005433344394	11089	28	6E
0005433344363	11089	29	7A
0005433344402	11089	30	6F
0005433344375	11089	31	7B
0005433344342	11089	32	7C
0005435097318	11089	33	7D
0005435097320	11089	34	7E
0005433344388	11089	35	7F
0005435508361	11089	36	8B
0005433344339	11089	37	8A
0005433344366	11089	38	8C
0005433344362	11089	39	8E
0005435097317	11089	40	8D
0005433344399	11089	41	8F
0005433344418	11089	42	9A
0005433344361	11089	43	9C
0005433344383	11089	44	9B
0005433344340	11089	45	9D
0005433344376	11089	46	9F
0005433344385	11089	47	9E
0005433344410	11089	48	10B
0005433344354	11089	49	10E
0005433344431	11089	50	10D
0005433344379	11089	51	11A
0005435380313	11089	52	11B
0005435380297	11089	53	11D
0005433344411	11089	54	11C
0005433344370	11089	55	11F
0005433344387	11089	56	11E
0005433344332	11089	57	12B
0005433344346	11089	58	12D
0005433344404	11089	59	12C
0005433344330	11089	60	12E
0005435097321	11089	61	12F
0005435097314	11089	62	13B
0005433344372	11089	63	13A
0005435508376	11089	64	13C
0005433344429	11089	65	13D
0005433344422	11089	66	13E
0005433344371	11089	67	13F
0005433344352	11089	68	14B
0005433344400	11089	69	14A
0005433344391	11089	70	14C
0005433344407	11089	71	14D
0005433344409	11089	72	14E
0005433344367	11089	73	14F
0005433344423	11089	74	15A
0005433344380	11089	75	15C
0005433344378	11089	76	15B
0005433344368	11089	77	15E
0005435508369	11089	78	15D
0005435380320	11089	79	15F
0005433344420	11089	80	16A
0005433344349	11089	81	16C
0005433344347	11089	82	16B
0005433344369	11089	83	16D
0005433344430	11089	84	16E
0005433344350	11089	85	17A
0005435380312	11089	86	16F
0005433344335	11089	87	17C
0005433344334	11089	88	17D
0005433344393	11089	89	17F
0005433344382	11089	90	17E
0005433344398	11089	91	18A
0005433344386	11089	92	18B
0005433344424	11089	93	18D
0005433344381	11089	94	18C
0005433344413	11089	95	18E
0005433344337	11089	96	18F
0005433344351	11089	97	19A
0005435097319	11089	98	19B
0005435380295	11089	99	19D
0005433344415	11089	100	19C
0005433344417	11089	101	19E
0005433344377	11089	102	19F
0005433344427	11089	103	20A
0005433344374	11089	104	20C
0005433344359	11089	105	20B
0005433344406	11089	106	20D
0005433344396	11089	107	20E
0005433344419	11089	108	20F
0005435097316	11089	109	21B
0005433344428	11089	110	21A
0005435508377	11089	111	21D
0005433344341	11089	112	21C
0005433344432	11089	113	21E
0005433344397	11089	114	21F
0005435380296	11089	115	22A
0005435380301	11089	116	22C
0005433344355	11089	117	22B
0005433344343	11089	118	22D
0005433344348	11089	119	22F
0005433344336	11089	120	22E
0005433344421	11089	121	23A
0005433344357	11089	122	23B
0005433344373	11089	123	23C
0005433344408	11089	124	23D
0005433344426	11089	125	23E
0005435097312	11089	126	23F
0005433343242	17133	1	10B
0005433343020	17133	2	1A
0005433343494	17133	3	1C
0005433343604	17133	4	1D
0005433343681	17133	5	2A
0005433343014	17133	6	1F
0005435380352	17133	7	2D
0005433343726	17133	8	2C
0005433343132	17133	9	2F
0005433342893	17133	10	3C
0005435097233	17133	11	3A
0005433343555	17133	12	3F
0005433343773	17133	13	3D
0005433343126	17133	14	4A
0005433343166	17133	15	4C
0005433343307	17133	16	4B
0005433343384	17133	17	4D
0005433343543	17133	18	4E
0005433343574	17133	19	4F
0005433343016	17133	20	5B
0005435380354	17133	21	5A
0005433343396	17133	22	5E
0005433343334	17133	23	5D
0005433343685	17133	24	5F
0005433343469	17133	25	6B
0005433343605	17133	26	6A
0005433343788	17133	27	6C
0005433343120	17133	28	6D
0005433343337	17133	29	6F
0005433343474	17133	30	6E
0005433343323	17133	31	7A
0005433343436	17133	32	7C
0005433343554	17133	33	7D
0005433343544	17133	34	7E
0005433343373	17133	35	7F
0005433343682	17133	36	8B
0005433343189	17133	37	8A
0005433343110	17133	38	8D
0005435097208	17133	39	8C
0005433343125	17133	40	8E
0005433343018	17133	41	8F
0005433343475	17133	42	9A
0005433343476	17133	43	9B
0005433343503	17133	44	9C
0005435097243	17133	45	9D
0005433343641	17133	46	9F
0005435545844	17133	47	9E
0005433343495	17133	48	10D
0005435097235	17133	49	10C
0005435380353	17133	50	10E
0005435097209	17133	51	11A
0005433343109	17133	52	11B
0005433343237	17133	53	11C
0005433343335	17133	54	11E
0005433343705	17133	55	11D
0005433343725	17133	56	12B
0005433343439	17133	57	12A
0005433343491	17133	58	12C
0005433343283	17133	59	12D
0005433342894	17133	60	12E
0005433343793	17133	61	12F
0005433343305	17133	62	13B
0005433343608	17133	63	13A
0005433343664	17133	64	13C
0005433343421	17133	65	13E
0005433343976	17133	66	13D
0005433343489	17133	67	14A
0005433343862	17133	68	14C
0005433343485	17133	69	14B
0005433343137	17133	70	14D
0005433343060	17133	71	14E
0005433343727	17133	72	14F
0005435380357	17133	73	15B
0005435097259	17133	74	15A
0005433343566	17133	75	15C
0005433343686	17133	76	15D
0005433343372	17133	77	15E
0005435097245	17133	78	15F
0005433343381	17133	79	16B
0005435380355	17133	80	16C
0005433342990	17133	81	16D
0005433343490	17133	82	16F
0005433343551	17133	83	16E
0005433343794	17133	84	17A
0005433343013	17133	85	17B
0005433343119	17133	86	17C
0005433343787	17133	87	17E
0005433343696	17133	88	17D
0005433343313	17133	89	18A
0005433343239	17133	90	17F
0005435097232	17133	91	18B
0005433343282	17133	92	18C
0005433343663	17133	93	18E
0005433343763	17133	94	18D
0005433343238	17133	95	18F
0005433343216	17133	96	19A
0005432293238	17133	97	19B
0005433343288	17133	98	19D
0005433343434	17133	99	19C
0005433343487	17133	100	19E
0005433343795	17133	101	19F
0005435097244	17133	102	20A
0005433343531	17133	103	20C
0005433343167	17133	104	20B
0005433343019	17133	105	20D
0005433343296	17133	106	20E
0005433343360	17133	107	20F
0005435380356	17133	108	21A
0005433343630	17133	109	21C
0005433343435	17133	110	21B
0005433343342	17133	111	21D
0005433343382	17133	112	21E
0005433343358	17133	113	22A
0005435097260	17133	114	21F
0005433343512	17133	115	22B
0005433343668	17133	116	22C
0005433343597	17133	117	22D
0005433343486	17133	118	23A
0005433343532	17133	119	22F
0005433343326	17133	120	23B
0005432293239	17133	121	23C
0005433343516	17133	122	23D
0005435097246	17133	123	23E
0005433343470	17133	124	23F
0005434158986	9099	1	1A
0005433507396	9099	2	1C
0005433481262	9099	3	1D
0005433507401	9099	4	1F
0005434158989	9099	5	2A
0005432919923	9099	6	2D
0005433507403	9099	7	3A
0005433507402	9099	8	3F
0005434158984	9099	9	4A
0005432919840	9099	10	4C
0005433481263	9099	11	4E
0005433481259	9099	12	4F
0005432919940	9099	13	5C
0005433481265	9099	14	5D
0005433507397	9099	15	6D
0005433507394	9099	16	7A
0005433507399	9099	17	8C
0005432919925	9099	18	8E
0005432919964	9099	19	8F
0005432919926	9099	20	9C
0005433481266	9099	21	10D
0005434158973	9099	22	10E
0005433507400	9099	23	10F
0005433481260	9099	24	11C
0005432919809	9099	25	11D
0005432919939	9099	26	11E
0005434158988	9099	27	13A
0005433481261	9099	28	13D
0005434158985	9099	29	14C
0005433507395	9099	30	14D
0005434158983	9099	31	14E
0005433507393	9099	32	15E
0005432920000	9099	33	15F
0005433507406	9099	34	16D
0005432920001	9099	35	16E
0005433507405	9099	36	16F
0005432919835	9099	37	17A
0005433481258	9099	38	17E
0005433481264	9099	39	18F
0005432919836	9099	40	19C
0005433507398	9099	41	19E
0005433507404	9099	42	20A
0005432919952	9099	43	20E
0005433507202	20479	1	1C
0005432920126	20479	2	1D
0005433507204	20479	3	1F
0005433481211	20479	4	2A
0005433507150	20479	5	2C
0005433507250	20479	6	3A
0005432920138	20479	7	3C
0005433481197	20479	8	3D
0005433507178	20479	9	4D
0005432920125	20479	10	4F
0005433507254	20479	11	5D
0005433507284	20479	12	5E
0005433507255	20479	13	5F
0005433507246	20479	14	6C
0005433507251	20479	15	6D
0005433481230	20479	16	6E
0005432920136	20479	17	6F
0005432920129	20479	18	7C
0005432920124	20479	19	7D
0005432920127	20479	20	7E
0005433507264	20479	21	8A
0005433507253	20479	22	8C
0005432920137	20479	23	8D
0005432920141	20479	24	8E
0005432920134	20479	25	9C
0005432920132	20479	26	9D
0005433481195	20479	27	9E
0005432920143	20479	28	9F
0005433507252	20479	29	11C
0005433507179	20479	30	11F
0005432920128	20479	31	12A
0005432920144	20479	32	12C
0005432920131	20479	33	12E
0005433507234	20479	34	13C
0005433507281	20479	35	13D
0005433507213	20479	36	13F
0005433507265	20479	37	14A
0005433507238	20479	38	14C
0005432920140	20479	39	14D
0005432920133	20479	40	15C
0005432920145	20479	41	15E
0005432920130	20479	42	16C
0005432920135	20479	43	16E
0005433481196	20479	44	17C
0005433507280	20479	45	17E
0005433507235	20479	46	17F
0005433507257	20479	47	18C
0005433507205	20479	48	18D
0005433507263	20479	49	18E
0005433507286	20479	50	18F
0005432920142	20479	51	19A
0005432920139	20479	52	19D
0005433507258	20479	53	20F
0005432396288	10157	1	1A
0005432396291	10157	2	1B
0005432396290	10157	3	2A
0005432394150	10157	4	3A
0005432396292	10157	5	4A
0005432396287	10157	6	4B
0005432394152	10157	7	5A
0005432396289	10157	8	5B
0005432394149	10157	9	6A
0005432394151	10157	10	6B
0005432396249	18325	1	1A
0005432400137	18325	2	1B
0005435179405	18325	3	2A
0005432396270	18325	4	3A
0005432396246	18325	5	3B
0005432400142	18325	6	4B
0005432396269	18325	7	5B
0005435126466	10988	1	1A
0005435126375	10988	2	1C
0005434928334	10988	3	1D
0005435126320	10988	4	1F
0005435126521	10988	5	2D
0005435556701	10988	6	3C
0005435126589	10988	7	3D
0005435626226	10988	8	3F
0005435126474	10988	9	4A
0005434411831	10988	10	4C
0005435626227	10988	11	5A
0005435126463	10988	12	5C
0005435626257	10988	13	5D
0005435556700	10988	14	5E
0005435626169	10988	15	6C
0005435626236	10988	16	6D
0005435126342	10988	17	6E
0005435126673	10988	18	6F
0005435126573	10988	19	7A
0005435626256	10988	20	7C
0005435126568	10988	21	7D
0005435626184	10988	22	7E
0005435626239	10988	23	7F
0005435626143	10988	24	8A
0005435126475	10988	25	8F
0005435126436	10988	26	9A
0005435126545	10988	27	9C
0005435626193	10988	28	9E
0005435626228	10988	29	9F
0005435126493	10988	30	10A
0005435626216	10988	31	10C
0005435626185	10988	32	10E
0005435126569	10988	33	11A
0005435626238	10988	34	11E
0005434411832	10988	35	12A
0005435126362	10988	36	12D
0005435126635	10988	37	12E
0005435126310	10988	38	12F
0005434411833	10988	39	13C
0005435626164	10988	40	13D
0005435626170	10988	41	13E
0005435126566	10988	42	13F
0005435626223	10988	43	14A
0005435126574	10988	44	14D
0005435126538	10988	45	14E
0005435126672	10988	46	14F
0005434928335	10988	47	15A
0005434411830	10988	48	15C
0005435626258	10988	49	15D
0005435126435	10988	50	15F
0005435554213	10988	51	16A
0005435126590	10988	52	16D
0005435626251	10988	53	16E
0005435126636	10988	54	16F
0005435626218	10988	55	17A
0005435126506	10988	56	17D
0005435126508	10988	57	17E
0005435626217	10988	58	17F
0005435126505	10988	59	18A
0005435554203	10988	60	18C
0005435626229	10988	61	18D
0005434928333	10988	62	18F
0005435126311	10988	63	19D
0005435126485	10988	64	19E
0005435626168	10988	65	19F
0005435126335	10988	66	20E
0005435126863	14694	1	1F
0005435126855	14694	2	2A
0005435126890	14694	3	3A
0005435554243	14694	4	3C
0005435126894	14694	5	3D
0005435626399	14694	6	4A
0005435626410	14694	7	4C
0005434928302	14694	8	4D
0005435126872	14694	9	4E
0005435126859	14694	10	4F
0005435626412	14694	11	5A
0005435126879	14694	12	5C
0005435626407	14694	13	5E
0005435126864	14694	14	5F
0005435626408	14694	15	6C
0005435126874	14694	16	6D
0005435626400	14694	17	6E
0005435126889	14694	18	6F
0005434411768	14694	19	7A
0005435126862	14694	20	7C
0005435126869	14694	21	7E
0005435126888	14694	22	7F
0005435126860	14694	23	8A
0005435126856	14694	24	8C
0005435126895	14694	25	8D
0005435626406	14694	26	8F
0005435126861	14694	27	8E
0005435126892	14694	28	9A
0005435126878	14694	29	9C
0005435126882	14694	30	9D
0005434411796	14694	31	9F
0005435626401	14694	32	10C
0005435126877	14694	33	10D
0005435626411	14694	34	10E
0005435626404	14694	35	10F
0005435126873	14694	36	11A
0005435556723	14694	37	11C
0005435554242	14694	38	11D
0005434928303	14694	39	11E
0005435126858	14694	40	12C
0005435126885	14694	41	12D
0005435554246	14694	42	12E
0005434928317	14694	43	13A
0005435626403	14694	44	13C
0005435126887	14694	45	13D
0005435626402	14694	46	14A
0005435126896	14694	47	14C
0005435126886	14694	48	14D
0005435626409	14694	49	14E
0005434928318	14694	50	14F
0005435554245	14694	51	15A
0005435626405	14694	52	15C
0005435126880	14694	53	15D
0005435126884	14694	54	15E
0005435626413	14694	55	15F
0005435126881	14694	56	16A
0005435126866	14694	57	16C
0005435126883	14694	58	16D
0005434411782	14694	59	16F
0005435126865	14694	60	17A
0005435126870	14694	61	17C
0005435554241	14694	62	17D
0005435554244	14694	63	17F
0005435126867	14694	64	18C
0005435126871	14694	65	18D
0005435126868	14694	66	18E
0005434928311	14694	67	18F
0005435126876	14694	68	19C
0005434411776	14694	69	19D
0005435126893	14694	70	19F
0005434928304	14694	71	20A
0005435126857	14694	72	20D
0005435126891	14694	73	20E
0005435126875	14694	74	20F
0005435443338	7148	1	1F
0005435715680	7148	2	2A
0005435715671	7148	3	2D
0005435715683	7148	4	2F
0005435221059	7148	5	3A
0005432398246	7148	6	3F
0005435443346	7148	7	4A
0005435216594	7148	8	5E
0005435715673	7148	9	6E
0005435715685	7148	10	7E
0005435715682	7148	11	7F
0005435715687	7148	12	9A
0005432398244	7148	13	9E
0005435715686	7148	14	10C
0005435715670	7148	15	10E
0005435443337	7148	16	10F
0005435715672	7148	17	11A
0005435715677	7148	18	11C
0005432398247	7148	19	11E
0005435221058	7148	20	11F
0005435216593	7148	21	12A
0005435443348	7148	22	12D
0005435715674	7148	23	13E
0005435715678	7148	24	13F
0005435443347	7148	25	14A
0005435219215	7148	26	14D
0005435715684	7148	27	16A
0005435715675	7148	28	16C
0005435216585	7148	29	16E
0005435443368	7148	30	16F
0005432398245	7148	31	17C
0005435715679	7148	32	17F
0005432400172	7148	33	18F
0005432400171	7148	34	19F
0005435715681	7148	35	20A
0005435178500	7148	36	20C
0005432398243	7148	37	20D
0005435715676	7148	38	20E
0005435219214	7148	39	20F
0005435715508	27079	1	1A
0005435715550	27079	2	1F
0005435216614	27079	3	2A
0005435715553	27079	4	2D
0005435715499	27079	5	3A
0005435443425	27079	6	3D
0005435216613	27079	7	3F
0005435715586	27079	8	4A
0005435443434	27079	9	4C
0005435217735	27079	10	4D
0005435715496	27079	11	4E
0005435715516	27079	12	4F
0005435443428	27079	13	5D
0005435217738	27079	14	5E
0005432398202	27079	15	5F
0005432398200	27079	16	6C
0005435715495	27079	17	6D
0005435715549	27079	18	6E
0005435715552	27079	19	6F
0005435715547	27079	20	7A
0005435443432	27079	21	7D
0005435217733	27079	22	7F
0005435715497	27079	23	8A
0005435216612	27079	24	8D
0005435216611	27079	25	8E
0005435217736	27079	26	9D
0005435715518	27079	27	9F
0005435216610	27079	28	10A
0005432394118	27079	29	10C
0005432398213	27079	30	10D
0005432394104	27079	31	10E
0005435443430	27079	32	11D
0005435715585	27079	33	11F
0005435443433	27079	34	12A
0005432398201	27079	35	12C
0005435715548	27079	36	12E
0005432394120	27079	37	12F
0005435443424	27079	38	13C
0005435443429	27079	39	13E
0005435715538	27079	40	13F
0005435217731	27079	41	14D
0005435443426	27079	42	14C
0005435216609	27079	43	15C
0005435178514	27079	44	16A
0005435217737	27079	45	16D
0005435443431	27079	46	16E
0005435443427	27079	47	16F
0005435715507	27079	48	17A
0005435715587	27079	49	17D
0005435715590	27079	50	17E
0005435216607	27079	51	17F
0005432398194	27079	52	18A
0005435715498	27079	53	18C
0005435217732	27079	54	18F
0005435715558	27079	55	19A
0005435216608	27079	56	19C
0005435715551	27079	57	19D
0005435715591	27079	58	19E
0005432394119	27079	59	19F
0005435715506	27079	60	20A
0005435217734	27079	61	20F
0005433060414	2704	1	1A
0005433060431	2704	2	1B
0005434084988	2704	3	3A
0005434084986	2704	4	3B
0005433060432	2704	5	4A
0005434084987	2704	6	4B
0005433060430	2704	7	5A
0005433060423	2704	8	5B
0005434084989	2704	9	6A
0005433060433	2704	10	6B
0005433060447	28468	1	2A
0005434084929	28468	2	2B
0005434084931	28468	3	3B
0005434084932	28468	4	4A
0005434084936	28468	5	4B
0005434084937	28468	6	5A
0005433060446	28468	7	6B
0005435548494	11168	1	1C
0005433788259	11168	2	1D
0005433788257	11168	3	2C
0005433788255	11168	4	3A
0005435548507	11168	5	3B
0005435548483	11168	6	3C
0005435548501	11168	7	3D
0005435548497	11168	8	4A
0005435548491	11168	9	4B
0005433788252	11168	10	5A
0005435548511	11168	11	5B
0005435548503	11168	12	5C
0005435548499	11168	13	5D
0005435548481	11168	14	6A
0005435548480	11168	15	6B
0005433788254	11168	16	6C
0005435548496	11168	17	6D
0005435548482	11168	18	7A
0005435548504	11168	19	7B
0005433788253	11168	20	7C
0005435548486	11168	21	18A
0005433788263	11168	22	18B
0005435548508	11168	23	18C
0005433788251	11168	24	19A
0005433788258	11168	25	19B
0005433788262	11168	26	19C
0005435548487	11168	27	20B
0005435548479	11168	28	20C
0005433788261	11168	29	20D
0005433788260	11168	30	21A
0005435548502	11168	31	21B
0005433788250	11168	32	22A
0005433788249	11168	33	22B
0005435548495	11168	34	22C
0005433788256	11168	35	23B
0005435548543	20681	1	1B
0005435548541	20681	2	1C
0005435548545	20681	3	1D
0005435548538	20681	4	2B
0005433788195	20681	5	2D
0005433788194	20681	6	3C
0005433788182	20681	7	4C
0005433788204	20681	8	5A
0005435548544	20681	9	5B
0005433788199	20681	10	5C
0005433788181	20681	11	7C
0005433788205	20681	12	18B
0005435548539	20681	13	19B
0005435548546	20681	14	20C
0005433788197	20681	15	22A
0005435548542	20681	16	22B
0005435548540	20681	17	22D
0005433788198	20681	18	23B
0005435541084	11404	1	1A
0005435517984	11404	2	1C
0005435517943	11404	3	1F
0005435541113	11404	4	2A
0005435541031	11404	5	2F
0005435541078	11404	6	3A
0005435517983	11404	7	4A
0005435541025	11404	8	4D
0005435541129	11404	9	4F
0005435517959	11404	10	5C
0005435517940	11404	11	5D
0005435541067	11404	12	5E
0005435541091	11404	13	5F
0005435541068	11404	14	6A
0005435517925	11404	15	6F
0005435541092	11404	16	7A
0005435541133	11404	17	7C
0005435517916	11404	18	7D
0005435541108	11404	19	7E
0005435541109	11404	20	7F
0005435541093	11404	21	8D
0005435541034	11404	22	9A
0005435517985	11404	23	8F
0005435517980	11404	24	9E
0005435541013	11404	25	9F
0005435518026	11404	26	10A
0005435541055	11404	27	10C
0005435541184	11404	28	10D
0005435541038	11404	29	10E
0005435517986	11404	30	10F
0005435541053	11404	31	11A
0005435541043	11404	32	11D
0005435541090	11404	33	11E
0005435541063	11404	34	12C
0005435517941	11404	35	13A
0005435518044	11404	36	13D
0005435517956	11404	37	13F
0005435541119	11404	38	14A
0005435541104	11404	39	14C
0005435518075	11404	40	14F
0005435518027	11404	41	15C
0005435541123	11404	42	15D
0005435541024	11404	43	15E
0005435541058	11404	44	15F
0005435541037	11404	45	16A
0005435541120	11404	46	16C
0005435541105	11404	47	16E
0005435517997	11404	48	17C
0005435541054	11404	49	17D
0005435517996	11404	50	18A
0005435517944	11404	51	18D
0005435541012	11404	52	19A
0005435517917	11404	53	19E
0005435518029	11404	54	20A
0005435541124	11404	55	20F
0005435529507	22214	1	1F
0005435529520	22214	2	2A
0005435529511	22214	3	2C
0005435529510	22214	4	2D
0005435541258	22214	5	3C
0005435541263	22214	6	3F
0005435541243	22214	7	4A
0005435529515	22214	8	4C
0005435529505	22214	9	4D
0005435529517	22214	10	4E
0005435529509	22214	11	4F
0005435541252	22214	12	6A
0005435529516	22214	13	6E
0005435541250	22214	14	6F
0005435541251	22214	15	7C
0005435541247	22214	16	7D
0005435529513	22214	17	8A
0005435529499	22214	18	8C
0005435541262	22214	19	8D
0005435541254	22214	20	9D
0005435529500	22214	21	9E
0005435541245	22214	22	9F
0005435541246	22214	23	10A
0005435541256	22214	24	10D
0005435541264	22214	25	10F
0005435541257	22214	26	11A
0005435529504	22214	27	11C
0005435529518	22214	28	11E
0005435541253	22214	29	11D
0005435529506	22214	30	12D
0005435529519	22214	31	13A
0005435541261	22214	32	13D
0005435529512	22214	33	13F
0005435529501	22214	34	14A
0005435541248	22214	35	14D
0005435529508	22214	36	15E
0005435529502	22214	37	16C
0005435541255	22214	38	16E
0005435541260	22214	39	17C
0005432294515	22214	40	17D
0005432294514	22214	41	18F
0005435541244	22214	42	19A
0005435541259	22214	43	19D
0005435541249	22214	44	19F
0005435529514	22214	45	20A
0005435529503	22214	46	20F
0005434907917	2305	1	1A
0005433251559	2305	2	1C
0005434907930	2305	3	1D
0005434907923	2305	4	1F
0005433251603	2305	5	2A
0005433251641	2305	6	2C
0005433251570	2305	7	2D
0005434907909	2305	8	2F
0005434907953	2305	9	3A
0005434907924	2305	10	3C
0005434907907	2305	11	3D
0005433251517	2305	12	3F
0005434907943	2305	13	4A
0005433251730	2305	14	4C
0005433251658	2305	15	4D
0005434907958	2305	16	4E
0005434907939	2305	17	4F
0005434907931	2305	18	5A
0005434907904	2305	19	5C
0005433251633	2305	20	5D
0005434907960	2305	21	5E
0005434907946	2305	22	5F
0005434907936	2305	23	6A
0005434907957	2305	24	6C
0005434907932	2305	25	6D
0005434907959	2305	26	6E
0005433251513	2305	27	6F
0005434907950	2305	28	7A
0005433251716	2305	29	7C
0005434907948	2305	30	7D
0005434907940	2305	31	7F
0005434907908	2305	32	7E
0005434907949	2305	33	8A
0005434907911	2305	34	8C
0005433251557	2305	35	8D
0005434907933	2305	36	8E
0005434907918	2305	37	8F
0005433251666	2305	38	9A
0005433251550	2305	39	9C
0005434907910	2305	40	9D
0005433251665	2305	41	9E
0005434907942	2305	42	9F
0005433251622	2305	43	10A
0005434907922	2305	44	10D
0005434907951	2305	45	10E
0005434907955	2305	46	10F
0005433251582	2305	47	11A
0005434907914	2305	48	11C
0005433251640	2305	49	11D
0005433251681	2305	50	11E
0005434907912	2305	51	11F
0005433251573	2305	52	12A
0005434907925	2305	53	12C
0005433251503	2305	54	12D
0005434907906	2305	55	12E
0005433251634	2305	56	12F
0005434907921	2305	57	13A
0005434907937	2305	58	13C
0005434907913	2305	59	13D
0005434907919	2305	60	13E
0005433251717	2305	61	13F
0005433251531	2305	62	14A
0005433251569	2305	63	14C
0005434907952	2305	64	14D
0005433251657	2305	65	14E
0005433251551	2305	66	14F
0005434907954	2305	67	15A
0005434907941	2305	68	15C
0005434907935	2305	69	15D
0005434907947	2305	70	15E
0005434907945	2305	71	15F
0005433251656	2305	72	16A
0005433251619	2305	73	16C
0005433251623	2305	74	16D
0005434907926	2305	75	16E
0005433251632	2305	76	16F
0005433251563	2305	77	17A
0005434907928	2305	78	17C
0005433401000	2305	79	17D
0005433251814	2305	80	17E
0005433251659	2305	81	17F
0005434907920	2305	82	18A
0005434907944	2305	83	18C
0005434907905	2305	84	18D
0005434907938	2305	85	18E
0005434907956	2305	86	18F
0005434907927	2305	87	19A
0005434907929	2305	88	19C
0005433251639	2305	89	19D
0005433251680	2305	90	19E
0005434907934	2305	91	19F
0005433251558	2305	92	20A
0005433251574	2305	93	20C
0005433401001	2305	94	20D
0005434907915	2305	95	20E
0005434907916	2305	96	20F
0005434907411	25605	1	1A
0005433251846	25605	2	1C
0005434907198	25605	3	1D
0005433251849	25605	4	1F
0005434907595	25605	5	2A
0005434907524	25605	6	2C
0005434907378	25605	7	2D
0005433251853	25605	8	2F
0005434907396	25605	9	3C
0005433251874	25605	10	3D
0005434907601	25605	11	3F
0005433401022	25605	12	4A
0005434907576	25605	13	4D
0005434907575	25605	14	4F
0005434907363	25605	15	5A
0005434907525	25605	16	5C
0005434907625	25605	17	5D
0005433251871	25605	18	5E
0005433401019	25605	19	5F
0005434907362	25605	20	6A
0005434907600	25605	21	6C
0005434907389	25605	22	6D
0005433251857	25605	23	6E
0005434907709	25605	24	6F
0005434907277	25605	25	7A
0005434907351	25605	26	7D
0005434907357	25605	27	7E
0005434907372	25605	28	7F
0005433251859	25605	29	8A
0005433251868	25605	30	8C
0005434907483	25605	31	8D
0005434907388	25605	32	8E
0005433401021	25605	33	8F
0005434907508	25605	34	9A
0005433251867	25605	35	9C
0005434907482	25605	36	9E
0005434907225	25605	37	9F
0005434907418	25605	38	10A
0005433251856	25605	39	10C
0005433251864	25605	40	10E
0005434907526	25605	41	10F
0005434907529	25605	42	11A
0005434907488	25605	43	11D
0005433251847	25605	44	11E
0005433251870	25605	45	11F
0005434907359	25605	46	12A
0005433251844	25605	47	12C
0005434907407	25605	48	12D
0005433251865	25605	49	12E
0005434907470	25605	50	12F
0005433251852	25605	51	13C
0005434907180	25605	52	13D
0005434907481	25605	53	13E
0005433251848	25605	54	13F
0005434907624	25605	55	14A
0005433251860	25605	56	14C
0005434907361	25605	57	14E
0005434907737	25605	58	14F
0005433251854	25605	59	15A
0005434907335	25605	60	15C
0005433251866	25605	61	15D
0005433251869	25605	62	15E
0005434907608	25605	63	15F
0005433251850	25605	64	16A
0005434907697	25605	65	16C
0005434907336	25605	66	16D
0005434907703	25605	67	16E
0005433251863	25605	68	16F
0005433251872	25605	69	17A
0005434907181	25605	70	17D
0005434907647	25605	71	17E
0005433251862	25605	72	18A
0005433251845	25605	73	18D
0005434907440	25605	74	18C
0005434907369	25605	75	18E
0005434907226	25605	76	18F
0005433251855	25605	77	19A
0005433401020	25605	78	19C
0005433251861	25605	79	19D
0005434907261	25605	80	19E
0005433251875	25605	81	19F
0005433251873	25605	82	20A
0005433251858	25605	83	20C
0005433251851	25605	84	20D
0005432621207	2503	1	1A
0005432621210	2503	2	1D
0005432621209	2503	3	2A
0005432621215	2503	4	2B
0005432862327	2503	5	2C
0005432621218	2503	6	2D
0005432862326	2503	7	3B
0005432621212	2503	8	4B
0005432862345	2503	9	4C
0005432621206	2503	10	4D
0005432862328	2503	11	5A
0005432621214	2503	12	5B
0005432621208	2503	13	6C
0005432621220	2503	14	7B
0005432621216	2503	15	7D
0005432862344	2503	16	19B
0005432862330	2503	17	19D
0005432621217	2503	18	20A
0005432621211	2503	19	21A
0005432862354	2503	20	21C
0005432621219	2503	21	21D
0005432862352	2503	22	22A
0005432621213	2503	23	22D
0005432621087	28058	1	1C
0005432862395	28058	2	1D
0005432862397	28058	3	3B
0005432621115	28058	4	4B
0005432621069	28058	5	5A
0005432621052	28058	6	6C
0005432862401	28058	7	7A
0005432621084	28058	8	7C
0005432862396	28058	9	7D
0005432621097	28058	10	18B
0005432862399	28058	11	18C
0005432621088	28058	12	19A
0005432862398	28058	13	19B
0005432621137	28058	14	19C
0005432621070	28058	15	19D
0005432621103	28058	16	22A
0005432621051	28058	17	22C
0005432862400	28058	18	23A
0005434097494	13083	1	2B
0005434097493	13083	2	6A
0005433452766	31024	1	1B
0005433452765	31024	2	2A
0005433451644	31024	3	2B
0005433452764	31024	4	4B
0005433451643	31024	5	6B
0005433452752	31358	1	3A
0005433454893	31358	2	3B
0005433452750	31358	3	4A
0005433452746	31358	4	4B
0005433454892	31358	5	5A
0005433452745	31358	6	6A
0005433129301	12014	1	1C
0005433129290	12014	2	1D
0005433129291	12014	3	2B
0005434142628	12014	4	3A
0005433129296	12014	5	3D
0005434142614	12014	6	4A
0005433129303	12014	7	5C
0005433134150	12014	8	5D
0005434142613	12014	9	6B
0005434184671	12014	10	7A
0005433129302	12014	11	7B
0005433134151	12014	12	7D
0005433134148	12014	13	18C
0005434142626	12014	14	18D
0005434184672	12014	15	19C
0005433134144	12014	16	19D
0005433134149	12014	17	20B
0005434142627	12014	18	20C
0005433134163	12014	19	22C
0005434184664	12014	20	23A
0005433134143	12014	21	23B
0005433134193	29861	1	1B
0005433134197	29861	2	1D
0005433134196	29861	3	2A
0005433131767	29861	4	2B
0005434142655	29861	5	2C
0005433131764	29861	6	4A
0005433134194	29861	7	4B
0005434142657	29861	8	5A
0005434184689	29861	9	5C
0005433131765	29861	10	7B
0005433134192	29861	11	18D
0005434142654	29861	12	19A
0005433131766	29861	13	20A
0005434183604	29861	14	20B
0005433134195	29861	15	20C
0005434142656	29861	16	21B
0005434184690	29861	17	21C
0005433131763	29861	18	22B
0005433131762	29861	19	23A
0005434183605	29861	20	23B
0005435798951	21295	1	2C
0005435798945	21295	2	4C
0005435798944	21295	3	5C
0005435798934	21295	4	6D
0005435798938	21295	5	7A
0005435798952	21295	6	7C
0005435798935	21295	7	19D
0005435798937	21295	8	20A
0005435798936	21295	9	21C
0005435798943	21295	10	22B
0005435798933	21295	11	22C
0005435697661	16497	1	1A
0005435697662	16497	2	1B
0005435697648	16497	3	1C
0005435697655	16497	4	1D
0005435697657	16497	5	2C
0005435697656	16497	6	3A
0005435697649	16497	7	3C
0005435697672	16497	8	4A
0005435697663	16497	9	4B
0005435697671	16497	10	4D
0005435697670	16497	11	5A
0005435935057	16497	12	5C
0005435697675	16497	13	5D
0005435697653	16497	14	6B
0005435697660	16497	15	6D
0005435697650	16497	16	7A
0005435935046	16497	17	7B
0005435697666	16497	18	18A
0005435697664	16497	19	18B
0005435697674	16497	20	18C
0005435935056	16497	21	18D
0005435697669	16497	22	19B
0005435697654	16497	23	20B
0005435697673	16497	24	20C
0005435697667	16497	25	20D
0005435697665	16497	26	21B
0005435697659	16497	27	21C
0005435697647	16497	28	21D
0005435697652	16497	29	22A
0005435697658	16497	30	22B
0005435935065	16497	31	22C
0005435935055	16497	32	22D
0005435697651	16497	33	23A
0005435697668	16497	34	23B
0005435697527	24742	1	1B
0005435697440	24742	2	1C
0005435697387	24742	3	1D
0005435697497	24742	4	2B
0005435697451	24742	5	2C
0005435697452	24742	6	3A
0005435697431	24742	7	3B
0005435697545	24742	8	3C
0005435697367	24742	9	3D
0005435697522	24742	10	4A
0005435697546	24742	11	4C
0005435697432	24742	12	4D
0005435697423	24742	13	5A
0005435697445	24742	14	5B
0005435697434	24742	15	5C
0005435697467	24742	16	5D
0005435697495	24742	17	6B
0005435697377	24742	18	6C
0005435697424	24742	19	6D
0005435697541	24742	20	7C
0005435697542	24742	21	18A
0005435697441	24742	22	18B
0005435697436	24742	23	18C
0005435697471	24742	24	18D
0005435697472	24742	25	19A
0005435697526	24742	26	19B
0005435697414	24742	27	19C
0005435697444	24742	28	19D
0005435697486	24742	29	20B
0005435697504	24742	30	20C
0005435697366	24742	31	21A
0005435697433	24742	32	21B
0005435697446	24742	33	21D
0005435697365	24742	34	22B
0005435697525	24742	35	22C
0005435697530	24742	36	22D
0005435697521	24742	37	23A
0005435697413	24742	38	23B
0005432968852	18769	1	1B
0005433724858	18769	2	2B
0005433724856	18769	3	3B
0005433724857	18769	4	4A
0005433724860	18769	5	5A
0005432968851	18769	6	6A
0005433724859	18769	7	6B
0005432968871	21641	1	1A
0005433724840	21641	2	1B
0005432968870	21641	3	3B
0005433724815	21641	4	4A
0005433724841	21641	5	5A
0005433724839	21641	6	6B
0005434139212	7299	1	1A
0005434139135	7299	2	1C
0005434139202	7299	3	1D
0005434139157	7299	4	1F
0005434139194	7299	5	2A
0005434139192	7299	6	2C
0005434139137	7299	7	2D
0005434087575	7299	8	2F
0005434139179	7299	9	3A
0005434139142	7299	10	3C
0005434087572	7299	11	3D
0005434139165	7299	12	3F
0005434139207	7299	13	4A
0005434139191	7299	14	4C
0005434139158	7299	15	4D
0005434139130	7299	16	4E
0005434139149	7299	17	4F
0005434139213	7299	18	5A
0005434139159	7299	19	5C
0005434139166	7299	20	5E
0005434139134	7299	21	5D
0005434139193	7299	22	5F
0005434139146	7299	23	6C
0005434139164	7299	24	6D
0005434139185	7299	25	6E
0005434139145	7299	26	6F
0005434139175	7299	27	7A
0005434139211	7299	28	7C
0005434139210	7299	29	7D
0005434139181	7299	30	7E
0005434139147	7299	31	7F
0005434139167	7299	32	8A
0005434139154	7299	33	8C
0005434139180	7299	34	8D
0005434139148	7299	35	8E
0005434139152	7299	36	8F
0005434139156	7299	37	9A
0005434139139	7299	38	9C
0005434139177	7299	39	9D
0005434139204	7299	40	9E
0005434139173	7299	41	9F
0005434139182	7299	42	10A
0005434139160	7299	43	10C
0005434139200	7299	44	10D
0005434139190	7299	45	10E
0005434139150	7299	46	10F
0005434139172	7299	47	11A
0005434087576	7299	48	11C
0005434139205	7299	49	11D
0005434139198	7299	50	11E
0005434139195	7299	51	11F
0005434139161	7299	52	12C
0005434139132	7299	53	12D
0005434139203	7299	54	12E
0005434139174	7299	55	12F
0005434139162	7299	56	13A
0005434139209	7299	57	13C
0005434139151	7299	58	13E
0005434139168	7299	59	13F
0005434139199	7299	60	14A
0005434139133	7299	61	14C
0005434139155	7299	62	14D
0005434139214	7299	63	14E
0005434139144	7299	64	14F
0005434139183	7299	65	15A
0005434139140	7299	66	15C
0005434087574	7299	67	15D
0005434139206	7299	68	15E
0005434139143	7299	69	16A
0005434139196	7299	70	16C
0005434139170	7299	71	16D
0005434139187	7299	72	16E
0005434139131	7299	73	17A
0005434139188	7299	74	17C
0005434139171	7299	75	17D
0005434139208	7299	76	17E
0005434139178	7299	77	17F
0005434139163	7299	78	18A
0005434139189	7299	79	18C
0005434139153	7299	80	18D
0005434139136	7299	81	18E
0005434139201	7299	82	18F
0005434139197	7299	83	19A
0005434139184	7299	84	19C
0005434139138	7299	85	19D
0005434139186	7299	86	19F
0005434139176	7299	87	20A
0005434139141	7299	88	20D
0005434087573	7299	89	20E
0005434139169	7299	90	20F
0005434138402	28582	1	1A
0005434138213	28582	2	1C
0005434138524	28582	3	1D
0005434138456	28582	4	1F
0005434087526	28582	5	2A
0005434138528	28582	6	2C
0005434138223	28582	7	2D
0005434138523	28582	8	2F
0005434138077	28582	9	3A
0005434138359	28582	10	3C
0005434138439	28582	11	3D
0005434138340	28582	12	3F
0005434137998	28582	13	4A
0005434138105	28582	14	4C
0005434138520	28582	15	4D
0005434138204	28582	16	4E
0005434138294	28582	17	4F
0005434138522	28582	18	5A
0005434138300	28582	19	5C
0005434138240	28582	20	5D
0005434138197	28582	21	5E
0005434138106	28582	22	5F
0005434138130	28582	23	6A
0005434138448	28582	24	6C
0005434138483	28582	25	6D
0005434138132	28582	26	6E
0005434138403	28582	27	6F
0005434138543	28582	28	7A
0005434138050	28582	29	7C
0005434138287	28582	30	7D
0005434138275	28582	31	7E
0005434138293	28582	32	7F
0005434138288	28582	33	8A
0005434138131	28582	34	8C
0005434138296	28582	35	8D
0005434138298	28582	36	8E
0005434138496	28582	37	8F
0005434138425	28582	38	9A
0005434138297	28582	39	9C
0005434138030	28582	40	9E
0005434138279	28582	41	10A
0005434138330	28582	42	10C
0005434138529	28582	43	10D
0005434138289	28582	44	10E
0005434138438	28582	45	10F
0005434138512	28582	46	11A
0005434138339	28582	47	11C
0005434138384	28582	48	11D
0005434138299	28582	49	11E
0005434138301	28582	50	11F
0005434138360	28582	51	12A
0005434138545	28582	52	12C
0005434137758	28582	53	12D
0005434138415	28582	54	12E
0005434138380	28582	55	12F
0005434138525	28582	56	13A
0005434138368	28582	57	13C
0005434138521	28582	58	13D
0005434138487	28582	59	13E
0005434138048	28582	60	13F
0005434087525	28582	61	14A
0005434138346	28582	62	14C
0005434138069	28582	63	14D
0005434138516	28582	64	14E
0005434138214	28582	65	14F
0005434138423	28582	66	15C
0005434138219	28582	67	15D
0005434138381	28582	68	15E
0005434138274	28582	69	15F
0005434138336	28582	70	16A
0005434138237	28582	71	16C
0005434138463	28582	72	16D
0005434138345	28582	73	16E
0005434138220	28582	74	16F
0005434138453	28582	75	17D
0005434138041	28582	76	17E
0005434138474	28582	77	17F
0005434138049	28582	78	18A
0005434138462	28582	79	18C
0005434138236	28582	80	18D
0005434138544	28582	81	18E
0005434138338	28582	82	18F
0005434138347	28582	83	19A
0005434138389	28582	84	19C
0005434138382	28582	85	19D
0005434138313	28582	86	19E
0005434138161	28582	87	19F
0005434138337	28582	88	20A
0005434138418	28582	89	20C
0005434138218	28582	90	20D
0005434138047	28582	91	20E
0005434138224	28582	92	20F
0005435808363	1948	1	1C
0005434610273	1948	2	2B
0005435808369	1948	3	2D
0005434610274	1948	4	3C
0005435808360	1948	5	3D
0005433407556	1948	6	4B
0005433407570	1948	7	7A
0005433407558	1948	8	7B
0005435808367	1948	9	7D
0005435808366	1948	10	18D
0005434610272	1948	11	19A
0005435808365	1948	12	19B
0005434610275	1948	13	19D
0005435808362	1948	14	20B
0005435808364	1948	15	21A
0005433407557	1948	16	21B
0005435808368	1948	17	21C
0005435808361	1948	18	22A
0005433407626	23113	1	1C
0005435808239	23113	2	1D
0005434610242	23113	3	2B
0005435808175	23113	4	2A
0005433407620	23113	5	2C
0005435808179	23113	6	2D
0005433407615	23113	7	3A
0005435808231	23113	8	3B
0005435808265	23113	9	3C
0005435808226	23113	10	3D
0005433407614	23113	11	4A
0005435808217	23113	12	4B
0005435808241	23113	13	4C
0005434610243	23113	14	4D
0005433407623	23113	15	5A
0005433407616	23113	16	5B
0005435808274	23113	17	5C
0005435808227	23113	18	5D
0005435808232	23113	19	6A
0005433407622	23113	20	6B
0005435808244	23113	21	6C
0005435808219	23113	22	6D
0005435808228	23113	23	7A
0005435808242	23113	24	7B
0005435808237	23113	25	7C
0005433407625	23113	26	7D
0005433407612	23113	27	18A
0005434610257	23113	28	18B
0005435808168	23113	29	18C
0005433407619	23113	30	19A
0005435808220	23113	31	19C
0005435808280	23113	32	19D
0005435808200	23113	33	20A
0005435808283	23113	34	20B
0005433407618	23113	35	20C
0005433407617	23113	36	20D
0005435808187	23113	37	21A
0005433407624	23113	38	21C
0005435808204	23113	39	21D
0005433407613	23113	40	22A
0005435808180	23113	41	22B
0005435808256	23113	42	22D
0005433407621	23113	43	23B
0005434504371	16682	1	1A
0005434504225	16682	2	1C
0005434504337	16682	3	2A
0005434504224	16682	4	2B
0005434504418	16682	5	3A
0005434504219	16682	6	3C
0005434504409	16682	7	4B
0005434504212	16682	8	5B
0005434504286	16682	9	5C
0005434504307	16682	10	5D
0005434504338	16682	11	6C
0005434503972	16682	12	6D
0005434504130	16682	13	7B
0005434504355	16682	14	7C
0005434504285	16682	15	18B
0005434504091	16682	16	18C
0005434504243	16682	17	19A
0005434504204	16682	18	19B
0005434504273	16682	19	20B
0005434504339	16682	20	20D
0005434504214	16682	21	21C
0005434504255	16682	22	21D
0005434504213	16682	23	22A
0005434504193	16682	24	22B
0005434504269	16682	25	23A
0005434504599	22902	1	1B
0005434504612	22902	2	1C
0005434504615	22902	3	1D
0005434504619	22902	4	2A
0005434504621	22902	5	2C
0005434504606	22902	6	3A
0005434504613	22902	7	3B
0005434504607	22902	8	3D
0005434504600	22902	9	4A
0005434504622	22902	10	4B
0005434504594	22902	11	4C
0005434504583	22902	12	4D
0005434504591	22902	13	5A
0005434504617	22902	14	5C
0005434504609	22902	15	5D
0005434504586	22902	16	6A
0005434504589	22902	17	6B
0005434504592	22902	18	6D
0005434504587	22902	19	7A
0005434504602	22902	20	7B
0005434504582	22902	21	7C
0005434504604	22902	22	7D
0005434504620	22902	23	18A
0005434504598	22902	24	18B
0005434504597	22902	25	18C
0005434504590	22902	26	18D
0005434504616	22902	27	19A
0005434504611	22902	28	19D
0005434504584	22902	29	20A
0005434504596	22902	30	20B
0005434504610	22902	31	20C
0005434504605	22902	32	20D
0005434504593	22902	33	21B
0005434504595	22902	34	21C
0005434504614	22902	35	21D
0005434504608	22902	36	22A
0005434504601	22902	37	22B
0005434504588	22902	38	22C
0005434504603	22902	39	22D
0005434504585	22902	40	23A
0005434504618	22902	41	23B
0005433266743	2202	1	1A
0005435078530	2202	2	1C
0005435078528	2202	3	2A
0005435078527	2202	4	2C
0005433266718	2202	5	2D
0005433266764	2202	6	3D
0005435078531	2202	7	4C
0005435078541	2202	8	4D
0005435078532	2202	9	5C
0005433266760	2202	10	5D
0005435078542	2202	11	6A
0005435078526	2202	12	6B
0005435078539	2202	13	6D
0005435078529	2202	14	7A
0005433266715	2202	15	7D
0005433266719	2202	16	18C
0005433266744	2202	17	18D
0005433266765	2202	18	19A
0005435078538	2202	19	20A
0005435078534	2202	20	20D
0005435078533	2202	21	21A
0005435078540	2202	22	21B
0005435078537	2202	23	21C
0005435078536	2202	24	22A
0005435078535	2202	25	22D
0005435078440	24324	1	1B
0005433266834	24324	2	3A
0005433266841	24324	3	3C
0005435078382	24324	4	3D
0005433266833	24324	5	4B
0005433266836	24324	6	4C
0005435078441	24324	7	4D
0005435078431	24324	8	5A
0005433266840	24324	9	5C
0005433266838	24324	10	5D
0005435078345	24324	11	6A
0005433266837	24324	12	6C
0005435078386	24324	13	6D
0005433266839	24324	14	7B
0005435078379	24324	15	7C
0005435078385	24324	16	7D
0005433266842	24324	17	18B
0005435078344	24324	18	18C
0005435078373	24324	19	19A
0005435078409	24324	20	19B
0005435078432	24324	21	20A
0005435078389	24324	22	20B
0005435078347	24324	23	20C
0005435078390	24324	24	20D
0005435078346	24324	25	21A
0005435078358	24324	26	21D
0005435078363	24324	27	22B
0005435078443	24324	28	22D
0005433266835	24324	29	23B
0005434988881	6621	1	1A
0005435803296	6621	2	1B
0005434988872	6621	3	2D
0005434988882	6621	4	3A
0005434988876	6621	5	3B
0005434988884	6621	6	4B
0005434988880	6621	7	5C
0005435803295	6621	8	6B
0005434988875	6621	9	6C
0005435803297	6621	10	7B
0005434988883	6621	11	7D
0005434988879	6621	12	18B
0005434988885	6621	13	19A
0005434988878	6621	14	19D
0005434988874	6621	15	21A
0005434988877	6621	16	21B
0005434988873	6621	17	21C
0005434988871	6621	18	22B
0005435464533	23620	1	1B
0005434988771	23620	2	2B
0005434988754	23620	3	2A
0005434988770	23620	4	2C
0005434988766	23620	5	4B
0005434988774	23620	6	5C
0005435464534	23620	7	5D
0005434988775	23620	8	7A
0005434988755	23620	9	7C
0005434988772	23620	10	20A
0005434988725	23620	11	20D
0005434988776	23620	12	21C
0005434988753	23620	13	22A
0005434988765	23620	14	22C
0005434988752	23620	15	23A
0005434988769	23620	16	23B
0005433454901	30456	1	1C
0005432383661	30456	2	1D
0005432383657	30456	3	1F
0005432383659	30456	4	2A
0005432383660	30456	5	2C
0005433450238	30456	6	2D
0005432383679	30456	7	2F
0005433450229	30456	8	3C
0005432383643	30456	9	3D
0005432383651	30456	10	3F
0005433450232	30456	11	4A
0005433450231	30456	12	4C
0005432383639	30456	13	4D
0005432383675	30456	14	4E
0005432383656	30456	15	4F
0005432383667	30456	16	5A
0005432383663	30456	17	5C
0005432383668	30456	18	5D
0005433450251	30456	19	5E
0005432383670	30456	20	6A
0005432383655	30456	21	6E
0005432383652	30456	22	6F
0005432383654	30456	23	7A
0005433450242	30456	24	7D
0005432383644	30456	25	7E
0005433453785	30456	26	7F
0005432383662	30456	27	8A
0005433450246	30456	28	8C
0005432383645	30456	29	8D
0005432383678	30456	30	8E
0005433453786	30456	31	8F
0005433450236	30456	32	9A
0005433450244	30456	33	9C
0005432383646	30456	34	9D
0005432383666	30456	35	9F
0005432383642	30456	36	10A
0005433450239	30456	37	10C
0005432383671	30456	38	10D
0005432383650	30456	39	10E
0005432383658	30456	40	11A
0005433450235	30456	41	11C
0005432383641	30456	42	11D
0005433450243	30456	43	11E
0005433450233	30456	44	11F
0005433450248	30456	45	12C
0005433450250	30456	46	12D
0005433450249	30456	47	12E
0005432383649	30456	48	13A
0005432383640	30456	49	13E
0005433450241	30456	50	13F
0005432383672	30456	51	14C
0005432383676	30456	52	14E
0005433450247	30456	53	14F
0005433450234	30456	54	15C
0005433454902	30456	55	15F
0005432383674	30456	56	16A
0005433450240	30456	57	16F
0005432383653	30456	58	17C
0005432383673	30456	59	17D
0005432383647	30456	60	18C
0005433450230	30456	61	18D
0005432383648	30456	62	18E
0005433450245	30456	63	19C
0005432383664	30456	64	19D
0005432383677	30456	65	19E
0005432383665	30456	66	19F
0005433450237	30456	67	20E
0005432383669	30456	68	20F
0005433450097	31288	1	1A
0005432383144	31288	2	1C
0005432383341	31288	3	1D
0005432383244	31288	4	1F
0005433451625	31288	5	2A
0005432383182	31288	6	2F
0005432383328	31288	7	3A
0005432383250	31288	8	3C
0005433450025	31288	9	3D
0005433453774	31288	10	3F
0005433453773	31288	11	4A
0005432383427	31288	12	4C
0005433450046	31288	13	4E
0005433450055	31288	14	4F
0005432383426	31288	15	5A
0005433450029	31288	16	5C
0005433450003	31288	17	5D
0005433450026	31288	18	5E
0005432383166	31288	19	5F
0005433449928	31288	20	6A
0005433449990	31288	21	6C
0005433453771	31288	22	6D
0005432383319	31288	23	6F
0005432383363	31288	24	7A
0005432383383	31288	25	7C
0005433449950	31288	26	7D
0005433450054	31288	27	8C
0005432383296	31288	28	9A
0005432383271	31288	29	9C
0005432383176	31288	30	9D
0005432383205	31288	31	9E
0005433450078	31288	32	9F
0005432383108	31288	33	10A
0005432383172	31288	34	10C
0005432383249	31288	35	10D
0005432383106	31288	36	10E
0005433450082	31288	37	10F
0005432383047	31288	38	11C
0005432383145	31288	39	11D
0005432383165	31288	40	11E
0005433453768	31288	41	12A
0005433451622	31288	42	12E
0005432383295	31288	43	12F
0005432383195	31288	44	13C
0005432383251	31288	45	13D
0005433450079	31288	46	13E
0005433451624	31288	47	14D
0005433450106	31288	48	14E
0005433450096	31288	49	14F
0005432383184	31288	50	15A
0005432383246	31288	51	15C
0005432383339	31288	52	15D
0005433450116	31288	53	15E
0005432383294	31288	54	15F
0005432383441	31288	55	16A
0005432383175	31288	56	16C
0005433450086	31288	57	16D
0005433450075	31288	58	16F
0005432383196	31288	59	17C
0005432383263	31288	60	17D
0005432383259	31288	61	17E
0005432383214	31288	62	18A
0005433449949	31288	63	18C
0005433450071	31288	64	18D
0005432383258	31288	65	18E
0005432383181	31288	66	18F
0005432383177	31288	67	19A
0005432383215	31288	68	19C
0005433449971	31288	69	19D
0005432383204	31288	70	19E
0005433450027	31288	71	20A
0005432383231	31288	72	20C
0005433451623	31288	73	20D
0005432383272	31288	74	20E
0005432383305	31288	75	20F
0005433131711	10798	1	1D
0005435304172	10798	2	2D
0005435304176	10798	3	3A
0005435304162	10798	4	3C
0005435304160	10798	5	4D
0005435304147	10798	6	5A
0005433131692	10798	7	5B
0005433126845	10798	8	5C
0005433126858	10798	9	6A
0005435304158	10798	10	6B
0005433126850	10798	11	6C
0005433126848	10798	12	6D
0005433131721	10798	13	7C
0005433131722	10798	14	19A
0005433131724	10798	15	19B
0005433126849	10798	16	19D
0005435304163	10798	17	20A
0005433131723	10798	18	20B
0005435304146	10798	19	20C
0005435299789	10798	20	20D
0005433126851	10798	21	21A
0005433131720	10798	22	21B
0005433126844	10798	23	21C
0005435304173	10798	24	22B
0005433129337	29704	1	1A
0005433126903	29704	2	1B
0005435302259	29704	3	2B
0005435299840	29704	4	3A
0005433126907	29704	5	3C
0005435299842	29704	6	3D
0005435299837	29704	7	5A
0005435302263	29704	8	5D
0005435302262	29704	9	6C
0005433126904	29704	10	7B
0005435299838	29704	11	7C
0005435302260	29704	12	7D
0005435299839	29704	13	18A
0005435299841	29704	14	18D
0005433126905	29704	15	20A
0005433129336	29704	16	20B
0005433129335	29704	17	21A
0005435302261	29704	18	21B
0005433126906	29704	19	21C
0005433129338	29704	20	22A
0005435302264	29704	21	22D
0005434287571	2403	1	1A
0005434287564	2403	2	1B
0005434287570	2403	3	1C
0005433110131	2403	4	2A
0005433110094	2403	5	2B
0005433110070	2403	6	2C
0005433110135	2403	7	2D
0005432264506	2403	8	3A
0005434287555	2403	9	3B
0005434287561	2403	10	4A
0005433110105	2403	11	4B
0005434287574	2403	12	4C
0005433110109	2403	13	4D
0005434287566	2403	14	5A
0005434287559	2403	15	5B
0005433110116	2403	16	5C
0005434287567	2403	17	5D
0005434287557	2403	18	6B
0005434287563	2403	19	6D
0005433110136	2403	20	7B
0005433110142	2403	21	18A
0005433110090	2403	22	18B
0005432264507	2403	23	18C
0005433110139	2403	24	18D
0005433110047	2403	25	19A
0005434287560	2403	26	19B
0005434287554	2403	27	19C
0005434287562	2403	28	19D
0005434287573	2403	29	20A
0005434287568	2403	30	20B
0005432264505	2403	31	20C
0005433110145	2403	32	20D
0005433110143	2403	33	21A
0005434287553	2403	34	21B
0005434287575	2403	35	21C
0005434287569	2403	36	21D
0005434287565	2403	37	22A
0005434287572	2403	38	22B
0005434287556	2403	39	22D
0005433110069	2403	40	23A
0005434287558	2403	41	23B
0005433110204	26860	1	1A
0005434287373	26860	2	1B
0005433110202	26860	3	1C
0005433110208	26860	4	2A
0005434287428	26860	5	2B
0005434287315	26860	6	2D
0005434287306	26860	7	3A
0005434287269	26860	8	3B
0005434287410	26860	9	3C
0005433110198	26860	10	3D
0005433110199	26860	11	4A
0005433110197	26860	12	4B
0005433110201	26860	13	5B
0005434287322	26860	14	5D
0005434287390	26860	15	6A
0005434287310	26860	16	6B
0005434287307	26860	17	6D
0005433110207	26860	18	7B
0005434287351	26860	19	7D
0005434287291	26860	20	18B
0005434287292	26860	21	19A
0005433110200	26860	22	19B
0005434287409	26860	23	19C
0005434287408	26860	24	19D
0005434287366	26860	25	20A
0005434287363	26860	26	20B
0005434287368	26860	27	20C
0005434287271	26860	28	20D
0005434287321	26860	29	21A
0005433110205	26860	30	21B
0005433110206	26860	31	21C
0005433110203	26860	32	22B
0005434287421	26860	33	22C
0005434287240	26860	34	22D
0005434287385	26860	35	23A
0005435856259	25453	1	5A
0005435856258	25453	2	5B
0005435856256	25453	3	5C
0005435856255	25453	4	5D
0005434269105	25453	5	20A
0005435856257	25453	6	21D
0005435856205	26642	1	1B
0005435856217	26642	2	1D
0005435854062	26642	3	2A
0005434272211	26642	4	2B
0005435856223	26642	5	2D
0005434273098	26642	6	3A
0005434273099	26642	7	6B
0005435856225	26642	8	6D
0005435856204	26642	9	18C
0005434273097	26642	10	18D
0005434272212	26642	11	19A
0005435856222	26642	12	20C
0005433868947	4771	1	1A
0005433868928	4771	2	1B
0005433868925	4771	3	1C
0005433868955	4771	4	1D
0005433868930	4771	5	2B
0005433868942	4771	6	2C
0005433868936	4771	7	2D
0005433868953	4771	8	3A
0005433868954	4771	9	3B
0005433868919	4771	10	3C
0005433868952	4771	11	3D
0005433868934	4771	12	4B
0005435860497	4771	13	4C
0005433868927	4771	14	4D
0005433868948	4771	15	5B
0005433868945	4771	16	5D
0005433868921	4771	17	6A
0005433868949	4771	18	6B
0005433868937	4771	19	6C
0005433868938	4771	20	6D
0005433868917	4771	21	7C
0005433868944	4771	22	7D
0005433868946	4771	23	18A
0005433868941	4771	24	18C
0005433868924	4771	25	18D
0005433868940	4771	26	19B
0005433868950	4771	27	19C
0005433868918	4771	28	19D
0005433868931	4771	29	20A
0005433868923	4771	30	20C
0005433868932	4771	31	20D
0005433868933	4771	32	21A
0005433868920	4771	33	21B
0005433868939	4771	34	21C
0005433868929	4771	35	21D
0005433868951	4771	36	22A
0005433868922	4771	37	22B
0005433868943	4771	38	22C
0005433868935	4771	39	23A
0005433868926	4771	40	23B
0005433868488	32609	1	1A
0005433868476	32609	2	1B
0005433868608	32609	3	1C
0005433868618	32609	4	1D
0005433868450	32609	5	2A
0005433868526	32609	6	2C
0005433868485	32609	7	2B
0005433868512	32609	8	3A
0005433868732	32609	9	3B
0005433868545	32609	10	3C
0005433868598	32609	11	3D
0005433868436	32609	12	4A
0005433868335	32609	13	4C
0005433868591	32609	14	4D
0005433868411	32609	15	5A
0005433868481	32609	16	5B
0005433868466	32609	17	5C
0005433868464	32609	18	5D
0005433868668	32609	19	6A
0005433868607	32609	20	6B
0005433868518	32609	21	6C
0005433868584	32609	22	6D
0005433868465	32609	23	7A
0005433868535	32609	24	7B
0005433868517	32609	25	7D
0005433868483	32609	26	18A
0005433868416	32609	27	18B
0005433868475	32609	28	18C
0005433868510	32609	29	18D
0005433868467	32609	30	19A
0005433868484	32609	31	19B
0005433868491	32609	32	19C
0005433868606	32609	33	20A
0005433868446	32609	34	19D
0005433868552	32609	35	20B
0005433868417	32609	36	20C
0005433868519	32609	37	21A
0005433868553	32609	38	21B
0005433868447	32609	39	21C
0005433868669	32609	40	21D
0005433868509	32609	41	22A
0005433868486	32609	42	22B
0005433868487	32609	43	22C
0005433868492	32609	44	22D
0005433868626	32609	45	23A
0005433868560	32609	46	23B
0005434663582	3432	1	1A
0005435911489	3432	2	1D
0005434663573	3432	3	2A
0005434460531	3432	4	2B
0005435911500	3432	5	2D
0005434461674	3432	6	3A
0005435911499	3432	7	3B
0005434663580	3432	8	3D
0005434663574	3432	9	4A
0005435911472	3432	10	4B
0005434663570	3432	11	4C
0005435911501	3432	12	5B
0005435911471	3432	13	5C
0005434461675	3432	14	6B
0005435911492	3432	15	7B
0005434663578	3432	16	7D
0005434460532	3432	17	18A
0005434663581	3432	18	18B
0005435911483	3432	19	19C
0005434663571	3432	20	19D
0005434663576	3432	21	20B
0005434663579	3432	22	20D
0005434663575	3432	23	21B
0005434663577	3432	24	22A
0005434663572	3432	25	23B
0005435911549	12467	1	1A
0005434663490	12467	2	1B
0005434663482	12467	3	1C
0005434663466	12467	4	2A
0005434663439	12467	5	2C
0005434663460	12467	6	3A
0005435911544	12467	7	3B
0005434663452	12467	8	3C
0005435911543	12467	9	4A
0005434663438	12467	10	4C
0005434663431	12467	11	5A
0005434663473	12467	12	5B
0005434663483	12467	13	6A
0005434663451	12467	14	6B
0005435911547	12467	15	6C
0005434663486	12467	16	7A
0005435911545	12467	17	7D
0005434663493	12467	18	18B
0005434663437	12467	19	19A
0005435911546	12467	20	19B
0005434663487	12467	21	19C
0005435911542	12467	22	20B
0005434663481	12467	23	21B
0005434663488	12467	24	21C
0005435911548	12467	25	22B
0005435911550	12467	26	22D
0005434663465	12467	27	23B
0005433868526	14490	1	1A
0005433868626	14490	2	1C
0005433868464	14490	3	1D
0005433868606	14490	4	2A
0005433868618	14490	5	2B
0005433868416	14490	6	2C
0005433868485	14490	7	2D
0005433868450	14490	8	3A
0005433868545	14490	9	3B
0005433868487	14490	10	3C
0005433868492	14490	11	3D
0005433868732	14490	12	4A
0005433868560	14490	13	4B
0005433868488	14490	14	4C
0005433868484	14490	15	4D
0005433868486	14490	16	5B
0005433868552	14490	17	5C
0005433868481	14490	18	5D
0005433868591	14490	19	6A
0005433868475	14490	20	6B
0005433868669	14490	21	6C
0005433868465	14490	22	6D
0005433868584	14490	23	7A
0005433868411	14490	24	7B
0005433868519	14490	25	7C
0005433868608	14490	26	7D
0005433868512	14490	27	18A
0005433868467	14490	28	18B
0005433868668	14490	29	18C
0005433868518	14490	30	18D
0005433868466	14490	31	19B
0005433868607	14490	32	19C
0005433868510	14490	33	19D
0005433868491	14490	34	20A
0005433868553	14490	35	20B
0005433868476	14490	36	20C
0005433868509	14490	37	20D
0005433868535	14490	38	21B
0005433868417	14490	39	21C
0005433868483	14490	40	21D
0005433868446	14490	41	22A
0005433868447	14490	42	22B
0005433868517	14490	43	22C
0005433868436	14490	44	22D
0005433868335	14490	45	23A
0005433868598	14490	46	23B
0005433868901	32665	1	1B
0005433868911	32665	2	1C
0005433868889	32665	3	2A
0005433868894	32665	4	2C
0005433868884	32665	5	2D
0005433868899	32665	6	3A
0005433868895	32665	7	3B
0005433868883	32665	8	3D
0005433868913	32665	9	4A
0005433868892	32665	10	4B
0005433868903	32665	11	4D
0005433868896	32665	12	5B
0005433868916	32665	13	5C
0005435860487	32665	14	6A
0005433868907	32665	15	6B
0005433868878	32665	16	6C
0005433868891	32665	17	6D
0005433868886	32665	18	7A
0005433868897	32665	19	7C
0005433868905	32665	20	7D
0005433868885	32665	21	18A
0005433868893	32665	22	18B
0005433868887	32665	23	18C
0005433868902	32665	24	18D
0005435860486	32665	25	19A
0005433868906	32665	26	19B
0005433868882	32665	27	19C
0005433868910	32665	28	19D
0005433868888	32665	29	20A
0005433868909	32665	30	20C
0005433868898	32665	31	20D
0005433868881	32665	32	21A
0005433868908	32665	33	21B
0005433868900	32665	34	21C
0005433868914	32665	35	21D
0005433868890	32665	36	22A
0005433868904	32665	37	22B
0005433868879	32665	38	22C
0005433868912	32665	39	22D
0005433868880	32665	40	23A
0005433868915	32665	41	23B
0005432799575	12145	1	1A
0005432799569	12145	2	1D
0005432799702	12145	3	2A
0005432799590	12145	4	2C
0005432799648	12145	5	2D
0005432799526	12145	6	3B
0005432799572	12145	7	3C
0005432799599	12145	8	4A
0005432799568	12145	9	4D
0005432799532	12145	10	5A
0005432799628	12145	11	5B
0005432799631	12145	12	5D
0005432799703	12145	13	6C
0005432799425	12145	14	6D
0005432799701	12145	15	7A
0005432799459	12145	16	7C
0005432799551	12145	17	7D
0005432799567	12145	18	18A
0005432799424	12145	19	18D
0005432799527	12145	20	20A
0005432799576	12145	21	20B
0005432799555	12145	22	20D
0005432799539	12145	23	21B
0005432799531	12145	24	21C
0005432799477	12145	25	21D
0005432799478	12145	26	22A
0005432799481	12145	27	22C
0005432799574	12145	28	23A
0005432799774	14795	1	1A
0005432799783	14795	2	1C
0005432799789	14795	3	2B
0005432799772	14795	4	2C
0005432799778	14795	5	2D
0005432799787	14795	6	3B
0005432799786	14795	7	3A
0005432799790	14795	8	3C
0005432799780	14795	9	4A
0005432799781	14795	10	4C
0005432799784	14795	11	4D
0005432799779	14795	12	5A
0005432799771	14795	13	5B
0005432799764	14795	14	5C
0005432799791	14795	15	5D
0005432799763	14795	16	6A
0005432799767	14795	17	6D
0005432799785	14795	18	7A
0005432799775	14795	19	7B
0005432799765	14795	20	7C
0005432799788	14795	21	18A
0005432799773	14795	22	18B
0005432799769	14795	23	18C
0005432799777	14795	24	18D
0005432799768	14795	25	19D
0005432799782	14795	26	20B
0005432799776	14795	27	22B
0005432799770	14795	28	22C
0005432799766	14795	29	23B
0005434299846	7053	1	1A
0005434299847	7053	2	1C
0005434408560	7053	3	1D
0005434408534	7053	4	2A
0005434408549	7053	5	1F
0005434408562	7053	6	2C
0005434299859	7053	7	2D
0005434408529	7053	8	2F
0005435293301	7053	9	3A
0005434408553	7053	10	3D
0005434408516	7053	11	3C
0005434408522	7053	12	3F
0005434408558	7053	13	4A
0005434408519	7053	14	4C
0005434408525	7053	15	4B
0005434408530	7053	16	4D
0005435293328	7053	17	4E
0005434408551	7053	18	5B
0005435293329	7053	19	5A
0005434408545	7053	20	5D
0005434408572	7053	21	5C
0005434408521	7053	22	5E
0005434299842	7053	23	6B
0005434299850	7053	24	6A
0005432154022	7053	25	6C
0005432154025	7053	26	6D
0005434408514	7053	27	6F
0005435293293	7053	28	6E
0005434408515	7053	29	7A
0005434408526	7053	30	7B
0005435311096	7053	31	7C
0005434408564	7053	32	7D
0005434408552	7053	33	7E
0005434408543	7053	34	7F
0005435293306	7053	35	8B
0005435293292	7053	36	8A
0005434408565	7053	37	8C
0005434408520	7053	38	8E
0005434408536	7053	39	8F
0005435311077	7053	40	9A
0005434299854	7053	41	9C
0005434408533	7053	42	9B
0005434408566	7053	43	9E
0005434299851	7053	44	9D
0005434408539	7053	45	9F
0005435293274	7053	46	10C
0005434408527	7053	47	10B
0005435293331	7053	48	10D
0005432108282	7053	49	10E
0005434408544	7053	50	11A
0005435311069	7053	51	11B
0005432154021	7053	52	11C
0005434408531	7053	53	11E
0005434299860	7053	54	11D
0005435293300	7053	55	11F
0005434408532	7053	56	12A
0005434408556	7053	57	12C
0005435311084	7053	58	12B
0005434299857	7053	59	12D
0005434408554	7053	60	12E
0005434408559	7053	61	13A
0005434408573	7053	62	12F
0005434408513	7053	63	13B
0005432108281	7053	64	13C
0005434299838	7053	65	13E
0005434408523	7053	66	13D
0005434408547	7053	67	14A
0005434408548	7053	68	13F
0005435293340	7053	69	14C
0005434408563	7053	70	14B
0005432108283	7053	71	14D
0005432154026	7053	72	14F
0005434299843	7053	73	14E
0005434408528	7053	74	15A
0005434408555	7053	75	15C
0005435311068	7053	76	15B
0005434408557	7053	77	15E
0005434299849	7053	78	15D
0005434408568	7053	79	16A
0005434299855	7053	80	15F
0005435311082	7053	81	16C
0005434408567	7053	82	16B
0005434408561	7053	83	16D
0005434299839	7053	84	16E
0005435311043	7053	85	17B
0005432154023	7053	86	17A
0005434408541	7053	87	17C
0005432154028	7053	88	17E
0005434408512	7053	89	17F
0005434408546	7053	90	18A
0005434408517	7053	91	18B
0005435293275	7053	92	18C
0005434299840	7053	93	18E
0005434299845	7053	94	18D
0005435293330	7053	95	19A
0005432154024	7053	96	18F
0005434408518	7053	97	19B
0005435311044	7053	98	19C
0005434408576	7053	99	19E
0005434408538	7053	100	19D
0005434299848	7053	101	19F
0005434408542	7053	102	20A
0005434408570	7053	103	20B
0005434299844	7053	104	20D
0005434408575	7053	105	20C
0005434408540	7053	106	20E
0005435293305	7053	107	21A
0005434408569	7053	108	20F
0005434299853	7053	109	21B
0005434408574	7053	110	21D
0005434299856	7053	111	21F
0005434299841	7053	112	21E
0005434408571	7053	113	22A
0005434408524	7053	114	22B
0005434408550	7053	115	22E
0005435311058	7053	116	22D
0005434299852	7053	117	22F
0005434408535	7053	118	23A
0005434299858	7053	119	23B
0005435311081	7053	120	23D
0005434408537	7053	121	23E
0005432154027	7053	122	23F
0005434407982	26892	1	1A
0005434408300	26892	2	1C
0005434407962	26892	3	1D
0005434408163	26892	4	1F
0005434408016	26892	5	2C
0005434407934	26892	6	2A
0005434407954	26892	7	2D
0005434408080	26892	8	2F
0005434407980	26892	9	3A
0005434408162	26892	10	3D
0005434408098	26892	11	3F
0005434407960	26892	12	4A
0005435293408	26892	13	4C
0005434407972	26892	14	4B
0005435293413	26892	15	4D
0005434407596	26892	16	4E
0005434408176	26892	17	4F
0005434299699	26892	18	5A
0005434299560	26892	19	5C
0005434408081	26892	20	5B
0005434299753	26892	21	5D
0005434407893	26892	22	5E
0005434408164	26892	23	5F
0005434407899	26892	24	6A
0005434408017	26892	25	6C
0005435311215	26892	26	6D
0005435293405	26892	27	6E
0005434407848	26892	28	7A
0005434299693	26892	29	6F
0005435311218	26892	30	7D
0005434299683	26892	31	7C
0005434407908	26892	32	7B
0005434407984	26892	33	7E
0005434407802	26892	34	7F
0005434408026	26892	35	8A
0005435293412	26892	36	8B
0005435293404	26892	37	8D
0005434407894	26892	38	8C
0005434407955	26892	39	8F
0005435311217	26892	40	8E
0005435311204	26892	41	9A
0005434407821	26892	42	9B
0005435293406	26892	43	9C
0005434407860	26892	44	9E
0005434299698	26892	45	9D
0005434408096	26892	46	10B
0005432058426	26892	47	10C
0005434299591	26892	48	10D
0005434299682	26892	49	11A
0005434299762	26892	50	10E
0005434407890	26892	51	11D
0005434408077	26892	52	11C
0005435311209	26892	53	11F
0005435293407	26892	54	12A
0005434407979	26892	55	12C
0005434299681	26892	56	12B
0005432058427	26892	57	12D
0005434408301	26892	58	12E
0005434407778	26892	59	12F
0005434407900	26892	60	13A
0005434299744	26892	61	13C
0005435311219	26892	62	13B
0005434299735	26892	63	13D
0005434408097	26892	64	13E
0005434407992	26892	65	14A
0005434408078	26892	66	14C
0005434407920	26892	67	14D
0005434407777	26892	68	14F
0005434407761	26892	69	14E
0005434407906	26892	70	15B
0005435311213	26892	71	15C
0005434299561	26892	72	15D
0005435311205	26892	73	15E
0005434408031	26892	74	15F
0005434407959	26892	75	16B
0005435293402	26892	76	16C
0005434299692	26892	77	16E
0005434407993	26892	78	16D
0005434407935	26892	79	17A
0005434408048	26892	80	16F
0005435311208	26892	81	17B
0005432058429	26892	82	17C
0005435311211	26892	83	17E
0005435293411	26892	84	17D
0005435293403	26892	85	17F
0005434407869	26892	86	18A
0005434408008	26892	87	18C
0005434407961	26892	88	18B
0005435311216	26892	89	18D
0005434299712	26892	90	18F
0005434407967	26892	91	18E
0005434407907	26892	92	19A
0005434407968	26892	93	19B
0005434408007	26892	94	19D
0005434408120	26892	95	19C
0005435311214	26892	96	20A
0005432058428	26892	97	19F
0005435311210	26892	98	20C
0005434407958	26892	99	20B
0005434408009	26892	100	20D
0005434407953	26892	101	20E
0005434299680	26892	102	20F
0005435311207	26892	103	21B
0005435293409	26892	104	21C
0005434407684	26892	105	21D
0005435311212	26892	106	21E
0005435293401	26892	107	22A
0005435293410	26892	108	22B
0005434408177	26892	109	22D
0005434407981	26892	110	22C
0005434407627	26892	111	22E
0005434407905	26892	112	23A
0005434407889	26892	113	22F
0005434407747	26892	114	23B
0005435311203	26892	115	23C
0005435311206	26892	116	23D
0005434407971	26892	117	23F
0005434407597	26892	118	23E
0005432604839	6466	1	1A
0005432604832	6466	2	1B
0005432604842	6466	3	1C
0005432604836	6466	4	1D
0005432604820	6466	5	2A
0005432604859	6466	6	2B
0005432604849	6466	7	2C
0005432604853	6466	8	2D
0005432604822	6466	9	3A
0005434512167	6466	10	3B
0005432604821	6466	11	3C
0005432604851	6466	12	3D
0005432604835	6466	13	4A
0005432604856	6466	14	4B
0005432604833	6466	15	4C
0005432604830	6466	16	4D
0005432604818	6466	17	5A
0005432604847	6466	18	5B
0005432604843	6466	19	5C
0005432604855	6466	20	5D
0005434512168	6466	21	6A
0005432604824	6466	22	6B
0005432604852	6466	23	6C
0005432604848	6466	24	6D
0005432604829	6466	25	7A
0005434512164	6466	26	7B
0005432604838	6466	27	7C
0005432604827	6466	28	7D
0005432604819	6466	29	18A
0005434512165	6466	30	18B
0005432604823	6466	31	18C
0005432604857	6466	32	18D
0005432604825	6466	33	19A
0005432604826	6466	34	19B
0005434512166	6466	35	19C
0005432604844	6466	36	19D
0005432604828	6466	37	20A
0005432604834	6466	38	20B
0005432604854	6466	39	20C
0005434512163	6466	40	20D
0005432604846	6466	41	21A
0005434512169	6466	42	21B
0005432604840	6466	43	21C
0005432604841	6466	44	21D
0005432604837	6466	45	22A
0005432604858	6466	46	22B
0005432604831	6466	47	22C
0005435218119	6466	48	22D
0005432604850	6466	49	23A
0005432604845	6466	50	23B
0005432604325	21385	1	20B
0005432604307	21385	2	1A
0005432604449	21385	3	1B
0005432604633	21385	4	1C
0005432604502	21385	5	1D
0005432604246	21385	6	2A
0005432604435	21385	7	2B
0005432604643	21385	8	2C
0005432604558	21385	9	2D
0005432604434	21385	10	3A
0005432604379	21385	11	3B
0005432604485	21385	12	3C
0005432604395	21385	13	3D
0005434512115	21385	14	4A
0005432604399	21385	15	4B
0005432604390	21385	16	4C
0005432604598	21385	17	4D
0005432604370	21385	18	5A
0005432604426	21385	19	5B
0005432604431	21385	20	5C
0005432604340	21385	21	5D
0005432604433	21385	22	6A
0005432604437	21385	23	6B
0005432604469	21385	24	6C
0005432604301	21385	25	6D
0005432604380	21385	26	7A
0005432604245	21385	27	7B
0005432604634	21385	28	7C
0005432604588	21385	29	7D
0005432604468	21385	30	18A
0005432604308	21385	31	18B
0005432604589	21385	32	18C
0005432604256	21385	33	18D
0005432604489	21385	34	19A
0005432604419	21385	35	19B
0005432604430	21385	36	19C
0005432604432	21385	37	19D
0005432604597	21385	38	20A
0005432604398	21385	39	20C
0005432604456	21385	40	20D
0005432604326	21385	41	21A
0005432604423	21385	42	21B
0005434512116	21385	43	21C
0005432604482	21385	44	21D
0005432604306	21385	45	22A
0005432604369	21385	46	22B
0005432604381	21385	47	22C
0005432604420	21385	48	22D
0005432604463	21385	49	23A
0005432604457	21385	50	23B
0005433251860	14993	1	1F
0005434907363	14993	2	2A
0005434907482	14993	3	2C
0005433251865	14993	4	3A
0005434907226	14993	5	3C
0005433251857	14993	6	3D
0005434907576	14993	7	4A
0005433251853	14993	8	4D
0005434907372	14993	9	4E
0005434907351	14993	10	1A
0005434907697	14993	11	4F
0005433251847	14993	12	5A
0005433251852	14993	13	5C
0005434907277	14993	14	5E
0005434907624	14993	15	5F
0005433251854	14993	16	6A
0005434907575	14993	17	6D
0005434907389	14993	18	6E
0005433251875	14993	19	1D
0005434907407	14993	20	6F
0005433251869	14993	21	7A
0005434907396	14993	22	7C
0005433251863	14993	23	7D
0005434907378	14993	24	1C
0005434907369	14993	25	7E
0005433251867	14993	26	7F
0005434907336	14993	27	8A
0005434907357	14993	28	8C
0005433251874	14993	29	8D
0005434907362	14993	30	8E
0005434907181	14993	31	8F
0005434907481	14993	32	9A
0005433251861	14993	33	9C
0005434907525	14993	34	9F
0005434907601	14993	35	10C
0005434907703	14993	36	10D
0005433251846	14993	37	10E
0005433251850	14993	38	10F
0005433251862	14993	39	11A
0005433251871	14993	40	11C
0005433251870	14993	41	11E
0005433251851	14993	42	11F
0005433251848	14993	43	12A
0005434907411	14993	44	12C
0005433251855	14993	45	12D
0005434907361	14993	46	12F
0005434907388	14993	47	13A
0005434907483	14993	48	13D
0005434907647	14993	49	13E
0005433251868	14993	50	14A
0005433251873	14993	51	14C
0005433251859	14993	52	14D
0005434907529	14993	53	14E
0005433251864	14993	54	14F
0005433251845	14993	55	15A
0005434907488	14993	56	15C
0005434907737	14993	57	15D
0005433251844	14993	58	15E
0005433251858	14993	59	15F
0005434907470	14993	60	16A
0005434907709	14993	61	16C
0005433251856	14993	62	16D
0005434907261	14993	63	16E
0005434907524	14993	64	16F
0005434907225	14993	65	17A
0005434907526	14993	66	17C
0005434907440	14993	67	17E
0005434907359	14993	68	18A
0005434907508	14993	69	18C
0005434907198	14993	70	18E
0005434907625	14993	71	18F
0005434907600	14993	72	19A
0005434907418	14993	73	19C
0005433251866	14993	74	19D
0005434907180	14993	75	19E
0005434907608	14993	76	19F
0005433251872	14993	77	20C
0005434907335	14993	78	20D
0005433251849	14993	79	20E
0005434907595	14993	80	20F
0005434907872	25833	1	1A
0005434907880	25833	2	1C
0005434907884	25833	3	1D
0005433251608	25833	4	1F
0005434907891	25833	5	2A
0005433251719	25833	6	2C
0005434907876	25833	7	2D
0005433251523	25833	8	2F
0005434907871	25833	9	3C
0005434907877	25833	10	3D
0005433251560	25833	11	3F
0005434907868	25833	12	4A
0005433251402	25833	13	4C
0005433251528	25833	14	4D
0005433251697	25833	15	4E
0005434907882	25833	16	4F
0005434907878	25833	17	5A
0005433251596	25833	18	5D
0005434907874	25833	19	5F
0005433251475	25833	20	6A
0005434907893	25833	21	6C
0005434907879	25833	22	6D
0005433251539	25833	23	6E
0005434907875	25833	24	6F
0005433251720	25833	25	7A
0005434907858	25833	26	7D
0005434907897	25833	27	7F
0005433251618	25833	28	8A
0005433251586	25833	29	8C
0005434907867	25833	30	8D
0005434907898	25833	31	8E
0005434907883	25833	32	8F
0005433251588	25833	33	9A
0005433251554	25833	34	9C
0005433251663	25833	35	9D
0005434907901	25833	36	9E
0005434907865	25833	37	9F
0005433251555	25833	38	10A
0005433251566	25833	39	10C
0005433251473	25833	40	10D
0005434907903	25833	41	10E
0005434907862	25833	42	10F
0005434907873	25833	43	11A
0005434907870	25833	44	11C
0005433251629	25833	45	11D
0005434907895	25833	46	11E
0005433251791	25833	47	11F
0005433251613	25833	48	12A
0005434907890	25833	49	12C
0005434907863	25833	50	12D
0005434907887	25833	51	12E
0005433251635	25833	52	12F
0005434907860	25833	53	13A
0005433251401	25833	54	13C
0005433251684	25833	55	13D
0005433251636	25833	56	13E
0005433251628	25833	57	13F
0005434907894	25833	58	14A
0005433251648	25833	59	14C
0005433251474	25833	60	14D
0005434907869	25833	61	14F
0005434907902	25833	62	15A
0005434907892	25833	63	15C
0005434907896	25833	64	15D
0005434907900	25833	65	15F
0005433251647	25833	66	16A
0005434907881	25833	67	16C
0005434907885	25833	68	16D
0005434907866	25833	69	16E
0005433251607	25833	70	16F
0005433251604	25833	71	17C
0005433251646	25833	72	17D
0005433251529	25833	73	17F
0005434907861	25833	74	18A
0005434907888	25833	75	18C
0005433251617	25833	76	18D
0005433251790	25833	77	18E
0005433251587	25833	78	18F
0005434907864	25833	79	19A
0005434907899	25833	80	19C
0005434907886	25833	81	19D
0005433251545	25833	82	19E
0005434907889	25833	83	20A
0005433251507	25833	84	20D
0005434907859	25833	85	20E
0005433810535	14199	1	1A
0005433009202	14199	2	1D
0005433009168	14199	3	1F
0005433009170	14199	4	2D
0005433810542	14199	5	2F
0005433009208	14199	6	3C
0005433009210	14199	7	3F
0005433009206	14199	8	4D
0005433009191	14199	9	4F
0005433009209	14199	10	5A
0005433810530	14199	11	5C
0005433009201	14199	12	5D
0005433009207	14199	13	5E
0005433009212	14199	14	5F
0005433009181	14199	15	6A
0005433009174	14199	16	6E
0005433009188	14199	17	7C
0005433009200	14199	18	7D
0005433009179	14199	19	7E
0005433009184	14199	20	8A
0005433009195	14199	21	8D
0005433009173	14199	22	9D
0005433009194	14199	23	9E
0005433009183	14199	24	10A
0005433009203	14199	25	10D
0005433810536	14199	26	10E
0005433009187	14199	27	10F
0005433009197	14199	28	11A
0005433009186	14199	29	11C
0005433009169	14199	30	12A
0005433009178	14199	31	12C
0005433009213	14199	32	12E
0005433009205	14199	33	12F
0005433009175	14199	34	13C
0005433009172	14199	35	14E
0005433009182	14199	36	15A
0005433009190	14199	37	15D
0005433009211	14199	38	15F
0005433009176	14199	39	16C
0005433009171	14199	40	16D
0005433009196	14199	41	17A
0005433009198	14199	42	17E
0005433009214	14199	43	17F
0005433009185	14199	44	18A
0005433009192	14199	45	18C
0005433810554	14199	46	18E
0005433009180	14199	47	19A
0005433009189	14199	48	19D
0005433009204	14199	49	19F
0005433009199	14199	50	20C
0005433009177	14199	51	20D
0005433009193	14199	52	20F
0005433008714	22855	1	1C
0005433008760	22855	2	1D
0005433810594	22855	3	1F
0005433008695	22855	4	2F
0005433008643	22855	5	3A
0005433810595	22855	6	4F
0005433008639	22855	7	5A
0005433810590	22855	8	5E
0005433008793	22855	9	5F
0005433008766	22855	10	6A
0005433008723	22855	11	6D
0005433008827	22855	12	6F
0005433008699	22855	13	7A
0005433008759	22855	14	7C
0005433008651	22855	15	7D
0005433810588	22855	16	7E
0005433008875	22855	17	8A
0005433008583	22855	18	8E
0005433008605	22855	19	9A
0005433008828	22855	20	9F
0005433008613	22855	21	10C
0005433008698	22855	22	10D
0005433008761	22855	23	11C
0005433008729	22855	24	12D
0005433008836	22855	25	12E
0005433810597	22855	26	13C
0005433810596	22855	27	13D
0005433008844	22855	28	13F
0005433008642	22855	29	13E
0005433008724	22855	30	14C
0005433008787	22855	31	14D
0005433008899	22855	32	14E
0005433008792	22855	33	16A
0005433810589	22855	34	16C
0005433810593	22855	35	16D
0005433008762	22855	36	16E
0005433008886	22855	37	16F
0005433810586	22855	38	17C
0005433810591	22855	39	17D
0005433008887	22855	40	17F
0005433008845	22855	41	18C
0005433008612	22855	42	18F
0005433008515	22855	43	19C
0005433810587	22855	44	19E
0005433810592	22855	45	19F
0005433008814	22855	46	20A
0005433009023	22855	47	20D
0005435718981	15524	1	1A
0005435718995	15524	2	2D
0005435718987	15524	3	3A
0005435719002	15524	4	3F
0005435718983	15524	5	6F
0005435718994	15524	6	7D
0005435718986	15524	7	8D
0005435718985	15524	8	9D
0005435718991	15524	9	9F
0005435718989	15524	10	10F
0005435718982	15524	11	11A
0005435718999	15524	12	11C
0005435718984	15524	13	11D
0005435718997	15524	14	11F
0005435718980	15524	15	12D
0005435718993	15524	16	12E
0005435718992	15524	17	13E
0005435718990	15524	18	14D
0005435719000	15524	19	15D
0005435718988	15524	20	18C
0005435718996	15524	21	18E
0005435719001	15524	22	19A
0005435718998	15524	23	19D
0005434925756	14941	1	1A
0005434925802	14941	2	2F
0005434925888	14941	3	3D
0005434925730	14941	4	4C
0005434925733	14941	5	4E
0005434925796	14941	6	5D
0005434925909	14941	7	6A
0005434925830	14941	8	7C
0005434925915	14941	9	7F
0005434925831	14941	10	8C
0005434925962	14941	11	9C
0005434925838	14941	12	9D
0005434925757	14941	13	10A
0005434925865	14941	14	10D
0005434925770	14941	15	11D
0005434925827	14941	16	11F
0005434925803	14941	17	12D
0005434925885	14941	18	13F
0005434925731	14941	19	14A
0005434925771	14941	20	14E
0005434925908	14941	21	15C
0005434925835	14941	22	15F
0005434925988	14941	23	16A
0005434925886	14941	24	16D
0005434925910	14941	25	16F
0005434925978	14941	26	17F
0005434925834	14941	27	17E
0005434925931	14941	28	18A
0005434925930	14941	29	18D
0005434925850	14941	30	18E
0005434925895	14941	31	19C
0005434925747	14941	32	19E
0005434925977	14941	33	20C
0005434925833	14941	34	20E
0005434925854	14941	35	20F
0005434926168	20496	1	1D
0005434926175	20496	2	4A
0005434926169	20496	3	4E
0005434926166	20496	4	4F
0005434926173	20496	5	6A
0005434926177	20496	6	7F
0005434926172	20496	7	9D
0005434926182	20496	8	10A
0005434926170	20496	9	10E
0005434926183	20496	10	11F
0005434926179	20496	11	12A
0005434926180	20496	12	12F
0005434926171	20496	13	13D
0005434926187	20496	14	14D
0005434926181	20496	15	14F
0005434926167	20496	16	15A
0005434926185	20496	17	15E
0005434926178	20496	18	15F
0005434926174	20496	19	16C
0005434926186	20496	20	16E
0005434926176	20496	21	17E
0005434926184	20496	22	18F
0005435999325	15848	1	1A
0005435999200	15848	2	1B
0005435999330	15848	3	1C
0005435488113	15848	4	1D
0005435999317	15848	5	2A
0005435488112	15848	6	2D
0005435488096	15848	7	3A
0005435488105	15848	8	3C
0005435999307	15848	9	3D
0005435488109	15848	10	4A
0005435488118	15848	11	4C
0005435488111	15848	12	4D
0005435999276	15848	13	5A
0005435488107	15848	14	5B
0005435488116	15848	15	5C
0005435488101	15848	16	5D
0005435488110	15848	17	6C
0005435999331	15848	18	6D
0005435488104	15848	19	7A
0005435488100	15848	20	7B
0005435999284	15848	21	7C
0005435488102	15848	22	7D
0005435999256	15848	23	18A
0005435488106	15848	24	18B
0005435999271	15848	25	18C
0005435999272	15848	26	18D
0005435488117	15848	27	19A
0005435999279	15848	28	19B
0005435488099	15848	29	19C
0005435999277	15848	30	19D
0005435488108	15848	31	20A
0005435488097	15848	32	20B
0005435488114	15848	33	20C
0005435999308	15848	34	21B
0005435999201	15848	35	21C
0005435488098	15848	36	21D
0005435999303	15848	37	22A
0005435488103	15848	38	22B
0005435999278	15848	39	22D
0005435488115	15848	40	23B
0005435999448	19692	1	1A
0005435999453	19692	2	1D
0005435999452	19692	3	2A
0005435487935	19692	4	2B
0005435487965	19692	5	2C
0005435487815	19692	6	2D
0005435487925	19692	7	3A
0005435999445	19692	8	3B
0005435487855	19692	9	3D
0005435999447	19692	10	4A
0005435999439	19692	11	4B
0005435487973	19692	12	4C
0005435487879	19692	13	4D
0005435487878	19692	14	5A
0005435487942	19692	15	5B
0005435999446	19692	16	5D
0005435487964	19692	17	6A
0005435999441	19692	18	6B
0005435999438	19692	19	6C
0005435999437	19692	20	7A
0005435999451	19692	21	7B
0005435487989	19692	22	7C
0005435487918	19692	23	7D
0005435999436	19692	24	18B
0005435487941	19692	25	18D
0005435999449	19692	26	19A
0005435999444	19692	27	19B
0005435487899	19692	28	19C
0005435487891	19692	29	19D
0005435487856	19692	30	20A
0005435487966	19692	31	20B
0005435999443	19692	32	20C
0005435487900	19692	33	20D
0005435999456	19692	34	21A
0005435999440	19692	35	21B
0005435487903	19692	36	21C
0005435999454	19692	37	21D
0005435487974	19692	38	22A
0005435999442	19692	39	22B
0005435999450	19692	40	23A
0005435999455	19692	41	23B
0005435472825	6023	1	1A
0005435472774	6023	2	1D
0005435839801	6023	3	2C
0005435839819	6023	4	2A
0005435472882	6023	5	2F
0005435839797	6023	6	3A
0005432658618	6023	7	3D
0005435839812	6023	8	3F
0005435472866	6023	9	5A
0005435472891	6023	10	4D
0005435472909	6023	11	5C
0005435472856	6023	12	5F
0005435839796	6023	13	6B
0005435839800	6023	14	6A
0005435472865	6023	15	6C
0005435839811	6023	16	6F
0005435839814	6023	17	8A
0005435839810	6023	18	8C
0005435839806	6023	19	9A
0005435839794	6023	20	9D
0005435839808	6023	21	10A
0005435839818	6023	22	9F
0005435839817	6023	23	10C
0005435472870	6023	24	10B
0005435472775	6023	25	10D
0005435839799	6023	26	10F
0005435839805	6023	27	10E
0005435839792	6023	28	11B
0005435839804	6023	29	11A
0005435839813	6023	30	12B
0005432660845	6023	31	12C
0005432659733	6023	32	12F
0005432658619	6023	33	12E
0005435839802	6023	34	13A
0005435839809	6023	35	13E
0005435839820	6023	36	14A
0005435839798	6023	37	13F
0005435472933	6023	38	15B
0005432659734	6023	39	15C
0005435839807	6023	40	15D
0005435839815	6023	41	16A
0005432142291	6023	42	16B
0005435839816	6023	43	16D
0005432537054	6023	44	17B
0005435472837	6023	45	17E
0005435472910	6023	46	18A
0005432660844	6023	47	18F
0005435472857	6023	48	18E
0005435839803	6023	49	18D
0005432142292	6023	50	19B
0005435472895	6023	51	19D
0005435839793	6023	52	20A
0005435472836	6023	53	20D
0005435472936	6023	54	20F
0005435472773	6023	55	20E
0005435472867	6023	56	21B
0005435839795	6023	57	21C
0005435472846	6023	58	21F
0005435473002	18056	1	1D
0005435839596	18056	2	3C
0005435473014	18056	3	4C
0005432537085	18056	4	5D
0005435473011	18056	5	5F
0005435839532	18056	6	6B
0005435839668	18056	7	6F
0005435473008	18056	8	7A
0005435473005	18056	9	7D
0005435839597	18056	10	8A
0005435473003	18056	11	7F
0005432667458	18056	12	8D
0005435839543	18056	13	8F
0005432660819	18056	14	8E
0005435839525	18056	15	10A
0005435473010	18056	16	10C
0005435473015	18056	17	10B
0005435839680	18056	18	10E
0005432537086	18056	19	10D
0005435839582	18056	20	11D
0005435473006	18056	21	11C
0005435839641	18056	22	11F
0005435839544	18056	23	11E
0005435839542	18056	24	12E
0005435839615	18056	25	13B
0005435839649	18056	26	13D
0005435473016	18056	27	14B
0005435473017	18056	28	14D
0005435839491	18056	29	14C
0005435473009	18056	30	14E
0005435839518	18056	31	15D
0005435839526	18056	32	16A
0005435839524	18056	33	16D
0005435839625	18056	34	17B
0005435839531	18056	35	17C
0005435473013	18056	36	18B
0005435473004	18056	37	18A
0005435839624	18056	38	18C
0005435473007	18056	39	18F
0005435839523	18056	40	18E
0005435473012	18056	41	19A
0005435839533	18056	42	19B
0005435839613	18056	43	21E
0005433285387	23021	1	8B
0005433285400	23021	2	1C
0005433285275	23021	3	1D
0005433285588	23021	4	1F
0005433285383	23021	5	2C
0005433285481	23021	6	2F
0005433285482	23021	7	3C
0005433285421	23021	8	3A
0005433285606	23021	9	3D
0005433285403	23021	10	4E
0005433285385	23021	11	5C
0005433285238	23021	12	5E
0005433285446	23021	13	6A
0005433285470	23021	14	6F
0005433285404	23021	15	7B
0005433285436	23021	16	7A
0005433285508	23021	17	7D
0005433285449	23021	18	7E
0005435104016	23021	19	8A
0005435104015	23021	20	8F
0005433285299	23021	21	9E
0005433285605	23021	22	9F
0005433285428	23021	23	10C
0005433285502	23021	24	10B
0005433285401	23021	25	10D
0005433285370	23021	26	11F
0005433285325	23021	27	14F
0005433285429	23021	28	15D
0005433285471	23021	29	15E
0005433285435	23021	30	15F
0005433285398	23021	31	16B
0005433285389	23021	32	16F
0005433285503	23021	33	16E
0005433285504	23021	34	17C
0005435104014	23021	35	17E
0005433285433	23021	36	18A
0005433285480	23021	37	18D
0005433285507	23021	38	19E
0005433285277	23021	39	19F
0005433285427	23021	40	20D
0005433285489	23021	41	20F
0005433285450	23021	42	21B
0005433285368	23021	43	21E
0005433285589	23021	44	22A
0005433285501	23021	45	22C
0005433285388	23021	46	22F
0005433285399	23021	47	23F
0005433285685	32073	1	11C
0005433285679	32073	2	11B
0005435103921	32073	3	11E
0005433285697	32073	4	11D
0005433285696	32073	5	12C
0005435103930	32073	6	12E
0005433285704	32073	7	13A
0005433285688	32073	8	14E
0005433285693	32073	9	15C
0005435103929	32073	10	15B
0005433285707	32073	11	16A
0005433285678	32073	12	16E
0005433285683	32073	13	16F
0005433285694	32073	14	17D
0005433285701	32073	15	17F
0005433285703	32073	16	18B
0005433285699	32073	17	19F
0005433285681	32073	18	20E
0005433285682	32073	19	21C
0005435103887	32073	20	22E
0005433285686	32073	21	23B
0005433285689	32073	22	1F
0005433285690	32073	23	3F
0005433285702	32073	24	4A
0005435103918	32073	25	1D
0005433285700	32073	26	5A
0005435103924	32073	27	1C
0005433285692	32073	28	5E
0005433285684	32073	29	5F
0005435103931	32073	30	5C
0005433285691	32073	31	7B
0005433285680	32073	32	7C
0005433285698	32073	33	7F
0005433285705	32073	34	8C
0005433285676	32073	35	9D
0005433285677	32073	36	9C
0005433285687	32073	37	9F
0005433285706	32073	38	10B
0005433285695	32073	39	10D
0005435103922	32073	40	10E
0005433112370	1481	1	16C
0005432802560	1481	2	16B
0005432892755	1481	3	16F
0005433112372	1481	4	17C
0005432802532	1481	5	17B
0005432892769	1481	6	17D
0005432802552	1481	7	17F
0005433112365	1481	8	17E
0005433112367	1481	9	18E
0005432892753	1481	10	18D
0005432802555	1481	11	19D
0005433112363	1481	12	19C
0005432802557	1481	13	19F
0005432802548	1481	14	20D
0005432802547	1481	15	20C
0005432802538	1481	16	21B
0005433112375	1481	17	21E
0005432802537	1481	18	21F
0005432892766	1481	19	18C
0005432802549	1481	20	1F
0005432892772	1481	21	1D
0005432892770	1481	22	2C
0005432802561	1481	23	2A
0005433112369	1481	24	3A
0005432892746	1481	25	3C
0005432802546	1481	26	4A
0005432802562	1481	27	4D
0005432802535	1481	28	4F
0005433112364	1481	29	5D
0005433112362	1481	30	5F
0005432802551	1481	31	6B
0005432892745	1481	32	6A
0005432802556	1481	33	6C
0005432802533	1481	34	6F
0005432802534	1481	35	8A
0005432892747	1481	36	7E
0005432802550	1481	37	8B
0005432802541	1481	38	8D
0005432802545	1481	39	8F
0005432892758	1481	40	8E
0005432892756	1481	41	9F
0005432892764	1481	42	9E
0005432802539	1481	43	10F
0005432892757	1481	44	11B
0005432802542	1481	45	11A
0005432802558	1481	46	11D
0005433112368	1481	47	11F
0005432802554	1481	48	11E
0005432802563	1481	49	13E
0005432892771	1481	50	14B
0005432802553	1481	51	15A
0005432802536	1481	52	14F
0005432802559	1481	53	14E
0005432892775	1481	54	15B
0005432802540	1481	55	15C
0005432802543	1481	56	15F
0005432802544	1481	57	15E
0005433112366	1481	58	15D
0005435852608	23860	1	1A
0005435852604	23860	2	1C
0005433475726	23860	3	3A
0005435852612	23860	4	3D
0005433475714	23860	5	4B
0005435852611	23860	6	5A
0005435852607	23860	7	4D
0005435852613	23860	8	5B
0005433475721	23860	9	6A
0005435852605	23860	10	6B
0005435852610	23860	11	6D
0005433475713	23860	12	7A
0005433475725	23860	13	7D
0005433475727	23860	14	18B
0005435852606	23860	15	18C
0005433475733	23860	16	19A
0005435852609	23860	17	19B
0005433475732	23860	18	20C
0005433475719	23860	19	21B
0005433475716	23860	20	22A
0005433475724	23860	21	22B
0005434067893	30614	1	27H
0005434067901	30614	2	15D
0005434067558	30614	3	25G
0005434068176	30614	4	29A
0005432528623	30614	5	36F
0005432528140	30614	6	44E
0005435725667	30614	7	1A
0005432528558	30614	8	11A
0005432528374	30614	9	19C
0005432528350	30614	10	25B
0005432528274	30614	11	25A
0005435214443	30614	12	27F
0005434067841	30614	13	28J
0005432528057	30614	14	25K
0005432528226	30614	15	27A
0005435214455	30614	16	42K
0005435214420	30614	17	21F
0005434067963	30614	18	32C
0005434067788	30614	19	27B
0005435214444	30614	20	41F
0005435214450	30614	21	28C
0005432528829	30614	22	50E
0005435214419	30614	23	43C
0005433656717	30614	24	40K
0005432528618	30614	25	18F
0005432535864	30614	26	45J
0005434067744	30614	27	29K
0005432528675	30614	28	33D
0005435214411	30614	29	35G
0005432211600	30614	30	35J
0005435214477	30614	31	13G
0005435214441	30614	32	34E
0005432528353	30614	33	33K
0005435214416	30614	34	15F
0005432528647	30614	35	16H
0005432528669	30614	36	41H
0005432528951	30614	37	42C
0005435214415	30614	38	34B
0005435214436	30614	39	23B
0005435214442	30614	40	20J
0005432528695	30614	41	23K
0005432159916	30614	42	28E
0005433656716	30614	43	19B
0005432528879	30614	44	44D
0005435214467	30614	45	23G
0005432528622	30614	46	3K
0005435214425	30614	47	37B
0005435214448	30614	48	30E
0005434068177	30614	49	32J
0005435214475	30614	50	38B
0005435725668	30614	51	11F
0005435214454	30614	52	43A
0005435214474	30614	53	13A
0005432528726	30614	54	21H
0005432529069	30614	55	37G
0005432529092	30614	56	21G
0005432159917	30614	57	30A
0005435214434	30614	58	30B
0005432528634	30614	59	30H
0005432528648	30614	60	16G
0005432528889	30614	61	16A
0005434068175	30614	62	12A
0005432529071	30614	63	27G
0005435214410	30614	64	24E
0005435214458	30614	65	30C
0005432528406	30614	66	5A
0005435631008	30614	67	29D
0005434067661	30614	68	5C
0005434067579	30614	69	20H
0005435214429	30614	70	22J
0005435214471	30614	71	41G
0005435214424	30614	72	50A
0005434067957	30614	73	11K
0005432529101	30614	74	31A
0005432528887	30614	75	37K
0005434068030	30614	76	35F
0005432528439	30614	77	22K
0005435214476	30614	78	40J
0005432528503	30614	79	45E
0005435725666	30614	80	2D
0005432428927	30614	81	43H
0005432528632	30614	82	19K
0005435214465	30614	83	48E
0005432528037	30614	84	47E
0005432528898	30614	85	4G
0005435214423	30614	86	13F
0005432528798	30614	87	47D
0005433656715	30614	88	15H
0005434067884	30614	89	18D
0005432428952	30614	90	39H
0005432211597	30614	91	39A
0005435214469	30614	92	35C
0005432528276	30614	93	42A
0005434067878	30614	94	36E
0005432159920	30614	95	13E
0005435214439	30614	96	17G
0005432528197	30614	97	43F
0005432528090	30614	98	35D
0005432528526	30614	99	20F
0005434067902	30614	100	16E
0005434067964	30614	101	15G
0005435214445	30614	102	24D
0005435214437	30614	103	48H
0005435214463	30614	104	19F
0005435631009	30614	105	22A
0005435214473	30614	106	18H
0005432528366	30614	107	3A
0005432528850	30614	108	27E
0005434067557	30614	109	26C
0005432211602	30614	110	47H
0005434067796	30614	111	13H
0005432528568	30614	112	1H
0005432529091	30614	113	14C
0005432528331	30614	114	36J
0005435214468	30614	115	20D
0005435214449	30614	116	20E
0005434067934	30614	117	4A
0005432528403	30614	118	29B
0005435214421	30614	119	37H
0005432428928	30614	120	46K
0005432528211	30614	121	49G
0005435214456	30614	122	50D
0005432528676	30614	123	26H
0005432528759	30614	124	51G
0005432528796	30614	125	14H
0005435214466	30614	126	43K
0005435214451	30614	127	14D
0005434067920	30614	128	28K
0005434067556	30614	129	22B
0005435214464	30614	130	31F
0005432528599	30614	131	29G
0005432528913	30614	132	33G
0005432528069	30614	133	12K
0005434067828	30614	134	20B
0005432428953	30614	135	30G
0005432528831	30614	136	2K
0005434067908	30614	137	1G
0005434067797	30614	138	34F
0005432528056	30614	139	30J
0005432528402	30614	140	22E
0005432528212	30614	141	1D
0005435214462	30614	142	37A
0005435214435	30614	143	29F
0005432528725	30614	144	33F
0005434067958	30614	145	31C
0005432528644	30614	146	33H
0005435214414	30614	147	11C
0005432528617	30614	148	31D
0005432528813	30614	149	38K
0005434067668	30614	150	38C
0005432528811	30614	151	4C
0005434067935	30614	152	12D
0005432527908	30614	153	12F
0005432528640	30614	154	13K
0005434067809	30614	155	20A
0005435214413	30614	156	26D
0005435214460	30614	157	32H
0005434067883	30614	158	35H
0005434067865	30614	159	36C
0005432528159	30614	160	43D
0005432528760	30614	161	43J
0005434068235	30614	162	44B
0005432535846	30614	163	47F
0005435214438	30614	164	32A
0005434067896	30614	165	22D
0005432528089	30614	166	48D
0005432528852	30614	167	51D
0005432528338	30614	168	46H
0005432528645	30614	169	47C
0005434067900	30614	170	43E
0005432528504	30614	171	31J
0005432528517	30614	172	33B
0005432528805	30614	173	44C
0005435214418	30614	174	16C
0005432528488	30614	175	42F
0005432528828	30614	176	44A
0005432428940	30614	177	42E
0005432528694	30614	178	41B
0005432528635	30614	179	49D
0005434067892	30614	180	40B
0005435214457	30614	181	19H
0005434067706	30614	182	20G
0005432528888	30614	183	49A
0005432528652	30614	184	31E
0005435214452	30614	185	33J
0005432535863	30614	186	25H
0005435725669	30614	187	35E
0005432528365	30614	188	30F
0005434068236	30614	189	36B
0005432528407	30614	190	50K
0005434067804	30614	191	23D
0005434067783	30614	192	1K
0005432528151	30614	193	2C
0005435214409	30614	194	2H
0005432528833	30614	195	49C
0005432528633	30614	196	5D
0005432529030	30614	197	45B
0005432528936	30614	198	5K
0005435214430	30614	199	45H
0005434068085	30614	200	45G
0005432528275	30614	201	45K
0005434067998	30614	202	15C
0005432159919	30614	203	32E
0005434067956	30614	204	15K
0005432527915	30614	205	4K
0005435214470	30614	206	39F
0005432527898	30614	207	26J
0005434068186	30614	208	46B
0005435214428	30614	209	17A
0005432528691	30614	210	27C
0005432528515	30614	211	32F
0005434067983	30614	212	19D
0005435214472	30614	213	46F
0005432527862	30614	214	32K
0005435214426	30614	215	48K
0005432528268	30614	216	51E
0005433656714	30614	217	30K
0005435214422	30614	218	48F
0005432528741	30614	219	48G
0005432528926	30614	220	15E
0005435214431	30614	221	24F
0005432528557	30614	222	28D
0005434067681	30614	223	17D
0005432528800	30614	224	25E
0005432528925	30614	225	39C
0005432528782	30614	226	44H
0005432211603	30614	227	21D
0005432528677	30614	228	26B
0005435725665	30614	229	26G
0005432528624	30614	230	34C
0005435214417	30614	231	3C
0005432528347	30614	232	42B
0005435214459	30614	233	47K
0005435214447	30614	234	24G
0005432528613	30614	235	51F
0005432159918	30614	236	3G
0005432528797	30614	237	13D
0005433656718	30614	238	4D
0005432527907	30614	239	39B
0005432528646	30614	240	34J
0005432528171	30614	241	22F
0005435214433	30614	242	36G
0005432528830	30614	243	14K
0005434067740	30614	244	12E
0005434067933	30614	245	50C
0005434067580	30614	246	28A
0005434068193	30614	247	23E
0005432211599	30614	248	28G
0005434067743	30614	249	32D
0005432428941	30614	250	27J
0005432528373	30614	251	34K
0005434067570	30614	252	42D
0005435214446	30614	253	14F
0005432211604	30614	254	49F
0005435214432	30614	255	49E
0005432528440	30614	256	1C
0005432528712	30614	257	29E
0005435214440	30614	258	27D
0005432528269	30614	259	3H
0005434067825	30614	260	46A
0005435214453	30614	261	23F
0005434067836	30614	262	16F
0005434067787	30614	263	18G
0005432528349	30614	264	21B
0005432211601	30614	265	17H
0005432527927	30614	266	17K
0005432527861	30614	267	37J
0005432528912	30614	268	49K
0005434067569	30614	269	2G
0005432528666	30614	270	38H
0005432528693	30614	271	40H
0005432528401	30614	272	23C
0005432211598	30614	273	49H
0005435214412	30614	274	50H
0005434068187	30614	275	22H
0005432528812	30614	276	29H
0005432211605	30614	277	3D
0005432528456	30614	278	21J
0005434067680	30614	279	21A
0005435214427	30614	280	30D
0005434067903	30614	281	48C
0005435214461	30614	282	18A
0005432528412	30614	283	28B
0005433368386	24840	1	8F
0005435653166	24840	2	9A
0005433368379	24840	3	9C
0005433368378	24840	4	9E
0005433368393	24840	5	9F
0005433368392	24840	6	10A
0005433368391	24840	7	10C
0005435653157	24840	8	10D
0005435653165	24840	9	10E
0005435653239	24840	10	11C
0005433368403	24840	11	11E
0005433368371	24840	12	12A
0005435653056	24840	13	12C
0005433368398	24840	14	12D
0005435653194	24840	15	12E
0005435653218	24840	16	12F
0005433368399	24840	17	13A
0005433368404	24840	18	13C
0005435653222	24840	19	13D
0005433368388	24840	20	13E
0005435653243	24840	21	13F
0005433368376	24840	22	14A
0005435653224	24840	23	14C
0005433368373	24840	24	14D
0005435653247	24840	25	14F
0005435653201	24840	26	15A
0005435653181	24840	27	15C
0005435653050	24840	28	15D
0005435652976	24840	29	15E
0005435653049	24840	30	15F
0005433368395	24840	31	16A
0005433368402	24840	32	16C
0005433368383	24840	33	16D
0005433368394	24840	34	16E
0005435653220	24840	35	16F
0005433368406	24840	36	17A
0005433368384	24840	37	17C
0005435653057	24840	38	17D
0005435653244	24840	39	17F
0005433368370	24840	40	18A
0005435653100	24840	41	18C
0005433368377	24840	42	18E
0005435653115	24840	43	18F
0005435653216	24840	44	19A
0005435653214	24840	45	19C
0005433368375	24840	46	19D
0005433368374	24840	47	19E
0005433368372	24840	48	19F
0005435653167	24840	49	20C
0005435653212	24840	50	20D
0005433368382	24840	51	20F
0005435652918	24840	52	20E
0005435653169	24840	53	3C
0005435653217	24840	54	1A
0005433368400	24840	55	1C
0005435653252	24840	56	2A
0005433368396	24840	57	2C
0005435653238	24840	58	2D
0005433368397	24840	59	2F
0005433368390	24840	60	3A
0005435653180	24840	61	3D
0005433368380	24840	62	4A
0005435653253	24840	63	4D
0005433368407	24840	64	4E
0005435653229	24840	65	4F
0005433368385	24840	66	5A
0005433368381	24840	67	5C
0005433368405	24840	68	5D
0005435653014	24840	69	5E
0005435653245	24840	70	5F
0005435653248	24840	71	6A
0005435653246	24840	72	6C
0005433368401	24840	73	6D
0005433368389	24840	74	7A
0005435653048	24840	75	7D
0005435653215	24840	76	7E
0005433368408	24840	77	7F
0005433368387	24840	78	8A
0005435653221	24840	79	8D
0005434980189	2051	1	21D
0005434980177	2051	2	21B
0005434980191	2051	3	1C
0005434980192	2051	4	21A
0005434980202	2051	5	1D
0005434980205	2051	6	5C
0005434980179	2051	7	23B
0005434980197	2051	8	3D
0005434980200	2051	9	20A
0005434980196	2051	10	2B
0005434980186	2051	11	4A
0005434980190	2051	12	22A
0005434980181	2051	13	3B
0005434980201	2051	14	22C
0005434980203	2051	15	1A
0005435801738	2051	16	20C
0005434980176	2051	17	18A
0005434980188	2051	18	22D
0005434980180	2051	19	6C
0005434980182	2051	20	20D
0005434980195	2051	21	5D
0005434980185	2051	22	19D
0005434980187	2051	23	19A
0005435801736	2051	24	2C
0005434980183	2051	25	18C
0005434980198	2051	26	19B
0005435801737	2051	27	2D
0005434980175	2051	28	6B
0005435801735	2051	29	2A
0005434980184	2051	30	7B
0005434980199	2051	31	23A
0005434980193	2051	32	22B
0005434980204	2051	33	18D
0005434980178	2051	34	21C
0005434980194	2051	35	19C
0005434979899	23571	1	7D
0005434979860	23571	2	1B
0005434979929	23571	3	1C
0005434979933	23571	4	1D
0005434979688	23571	5	2A
0005434979925	23571	6	2B
0005434979689	23571	7	2C
0005434979718	23571	8	3B
0005435801707	23571	9	3A
0005434979897	23571	10	3C
0005434979900	23571	11	3D
0005434979932	23571	12	4A
0005434979866	23571	13	4C
0005434979884	23571	14	4D
0005434979857	23571	15	5A
0005434979826	23571	16	5B
0005434979963	23571	17	5C
0005434979813	23571	18	5D
0005434979930	23571	19	6A
0005434979858	23571	20	6B
0005434979994	23571	21	6C
0005434979872	23571	22	6D
0005434979901	23571	23	7A
0005434979808	23571	24	7B
0005434979782	23571	25	18A
0005434979856	23571	26	18B
0005434979874	23571	27	18C
0005434979773	23571	28	18D
0005434979902	23571	29	19B
0005434979873	23571	30	19C
0005434979717	23571	31	19D
0005434979807	23571	32	20A
0005434979931	23571	33	20B
0005434979836	23571	34	20C
0005434979774	23571	35	20D
0005434979921	23571	36	21B
0005434979772	23571	37	21D
0005434979865	23571	38	21C
0005434979781	23571	39	22A
0005434979898	23571	40	22B
0005434979877	23571	41	22C
0005434979780	23571	42	22D
0005435801715	23571	43	23A
0005434952581	2600	1	1A
0005434952579	2600	2	4B
0005434952583	2600	3	2A
0005434952580	2600	4	3B
0005434952582	2600	5	3A
0005433256438	2606	1	5A
0005433256439	2606	2	1A
0005434952554	28188	1	1A
0005434952543	28188	2	1B
0005434952556	28188	3	2A
0005434952552	28188	4	2B
0005433256451	28188	5	3A
0005434952553	28188	6	3B
0005433256452	28188	7	4A
0005434952545	28188	8	4B
0005434952544	28188	9	6A
0005434952542	28188	10	5B
0005434952537	28188	11	6B
0005433111536	19726	1	2B
0005433112394	19726	2	3A
0005433111535	19726	3	4B
0005433112395	19726	4	1A
0005433112393	19726	5	6A
0005433112368	19995	1	1B
0005433112366	19995	2	5A
0005433112369	19995	3	5B
0005433112367	19995	4	6A
0005433112362	19995	5	6B
0005433112375	19995	6	4B
0005433112370	19995	7	4A
0005433112364	19995	8	3B
0005433112363	19995	9	3A
0005433112372	19995	10	2A
0005433112365	19995	11	2B
0005434138292	11947	1	9C
0005434138697	11947	2	9D
0005434138566	11947	3	9E
0005434138467	11947	4	9F
0005434138657	11947	5	10A
0005434138659	11947	6	10C
0005434138396	11947	7	10D
0005434138190	11947	8	10E
0005434138580	11947	9	10F
0005434138446	11947	10	11A
0005434138365	11947	11	11C
0005434138367	11947	12	11E
0005434138563	11947	13	11F
0005434138257	11947	14	12A
0005434138357	11947	15	12C
0005434138229	11947	16	12E
0005434138835	11947	17	12F
0005434138256	11947	18	13A
0005434138807	11947	19	13D
0005434138501	11947	20	13E
0005434138127	11947	21	13F
0005434138671	11947	22	14A
0005434138404	11947	23	14C
0005434138561	11947	24	14D
0005434138364	11947	25	14E
0005434138366	11947	26	14F
0005434138188	11947	27	15A
0005434138582	11947	28	15C
0005434138534	11947	29	15D
0005434138751	11947	30	15E
0005434138825	11947	31	16A
0005434138344	11947	32	16C
0005434138478	11947	33	16D
0005434138816	11947	34	16E
0005434138401	11947	35	16F
0005434138794	11947	36	17A
0005434138535	11947	37	17C
0005434138579	11947	38	17D
0005434138803	11947	39	17E
0005434138189	11947	40	17F
0005434138768	11947	41	18A
0005434138485	11947	42	18C
0005434138834	11947	43	18D
0005434138708	11947	44	18E
0005434138452	11947	45	18F
0005434138658	11947	46	19A
0005434138228	11947	47	19C
0005434138482	11947	48	19D
0005434138562	11947	49	19E
0005434138719	11947	50	19F
0005434138772	11947	51	20A
0005434138766	11947	52	20D
0005434138567	11947	53	20E
0005434138291	11947	54	20F
0005434138752	11947	55	1A
0005434138489	11947	56	1C
0005434138459	11947	57	1D
0005434138621	11947	58	1F
0005434138676	11947	59	2A
0005434138441	11947	60	2D
0005434138358	11947	61	2F
0005434138517	11947	62	3A
0005434138674	11947	63	3C
0005434138302	11947	64	3F
0005434138514	11947	65	4C
0005434138505	11947	66	4D
0005434138675	11947	67	4E
0005434138477	11947	68	4F
0005434138362	11947	69	5C
0005434138203	11947	70	5D
0005434138436	11947	71	5E
0005434138792	11947	72	5F
0005434138808	11947	73	6A
0005434138795	11947	74	6C
0005434138490	11947	75	6D
0005434138823	11947	76	6E
0005434138836	11947	77	6F
0005434138518	11947	78	7A
0005434138136	11947	79	7C
0005434138782	11947	80	7D
0005434138515	11947	81	7E
0005434138595	11947	82	7F
0005434138137	11947	83	8A
0005434138255	11947	84	8D
0005434138460	11947	85	8E
0005434138793	11947	86	8F
0005434138581	11947	87	9A
0005434139178	28763	1	13A
0005434139199	28763	2	1A
0005434139156	28763	3	1C
0005434139134	28763	4	1D
0005434139190	28763	5	1F
0005434139194	28763	6	2A
0005434139182	28763	7	2C
0005434139148	28763	8	2D
0005434139154	28763	9	2F
0005434139180	28763	10	3A
0005434139162	28763	11	3D
0005434139160	28763	12	4A
0005434139195	28763	13	4C
0005434139204	28763	14	4D
0005434139184	28763	15	4E
0005434139208	28763	16	4F
0005434139164	28763	17	5A
0005434139211	28763	18	5E
0005434139201	28763	19	5F
0005434139147	28763	20	6A
0005434139189	28763	21	6C
0005434139212	28763	22	6D
0005434139168	28763	23	6E
0005434139133	28763	24	6F
0005434139137	28763	25	7A
0005434139131	28763	26	7C
0005434139214	28763	27	7D
0005434139151	28763	28	7E
0005434139206	28763	29	7F
0005434139136	28763	30	8A
0005434139172	28763	31	8E
0005434139142	28763	32	8F
0005434139183	28763	33	9A
0005434139135	28763	34	9C
0005434139132	28763	35	9E
0005434139177	28763	36	9F
0005434139145	28763	37	10A
0005434139169	28763	38	10C
0005434139157	28763	39	10D
0005434139173	28763	40	10E
0005434139207	28763	41	10F
0005434139163	28763	42	11A
0005434139203	28763	43	11C
0005434139196	28763	44	11D
0005434139210	28763	45	11E
0005434139166	28763	46	11F
0005434139193	28763	47	12A
0005434139138	28763	48	12C
0005434139152	28763	49	12D
0005434139197	28763	50	12E
0005434139186	28763	51	12F
0005434139167	28763	52	13D
0005434139140	28763	53	13E
0005434139179	28763	54	14C
0005434139141	28763	55	14D
0005434139200	28763	56	14F
0005434139191	28763	57	15C
0005434139161	28763	58	15D
0005434139174	28763	59	15E
0005434139192	28763	60	15F
0005434139158	28763	61	16A
0005434139176	28763	62	16C
0005434139202	28763	63	16D
0005434139187	28763	64	16E
0005434139165	28763	65	16F
0005434139153	28763	66	17A
0005434139209	28763	67	17C
0005434139146	28763	68	17D
0005434139130	28763	69	17E
0005434139139	28763	70	17F
0005434139143	28763	71	18A
0005434139213	28763	72	18C
0005434139171	28763	73	18D
0005434139149	28763	74	18E
0005434139144	28763	75	18F
0005434139159	28763	76	19A
0005434139155	28763	77	19C
0005434139181	28763	78	19D
0005434139205	28763	79	19E
0005434139188	28763	80	19F
0005434139170	28763	81	20A
0005434139198	28763	82	20C
0005434139175	28763	83	20D
0005434139185	28763	84	20E
0005434139150	28763	85	20F
0005435312814	6574	1	1C
0005435312815	6574	2	2C
0005435312816	6574	3	3B
0005434466523	6574	4	3D
0005434466520	6574	5	5A
0005434466524	6574	6	5B
0005435312823	6574	7	7B
0005434466517	6574	8	18A
0005434466516	6574	9	18D
0005434466518	6574	10	1A
0005434466519	6574	11	19A
0005434466515	6574	12	19B
0005434466521	6574	13	19C
0005434466527	6574	14	19D
0005434466525	6574	15	20B
0005434466526	6574	16	21C
0005434466522	6574	17	21D
0005434466528	6574	18	23A
0005433538987	6783	1	1D
0005435259760	6783	2	2B
0005433538983	6783	3	2C
0005435259770	6783	4	3C
0005433538989	6783	5	3D
0005433538985	6783	6	5A
0005433534527	6783	7	6A
0005433538988	6783	8	6C
0005433534526	6783	9	7B
0005433538990	6783	10	18A
0005435259788	6783	11	18D
0005433538986	6783	12	19B
0005433538984	6783	13	20B
0005433538982	6783	14	22B
0005435259759	6783	15	22D
0005433538905	25045	1	19D
0005433534507	25045	2	1B
0005435259815	25045	3	1C
0005433538893	25045	4	2C
0005435259813	25045	5	3A
0005435259816	25045	6	3C
0005433538930	25045	7	5D
0005433538895	25045	8	6A
0005433538929	25045	9	18C
0005433538924	25045	10	18D
0005433534506	25045	11	20A
0005435259817	25045	12	20C
0005435259814	25045	13	21B
0005433538896	25045	14	22A
0005433538889	25045	15	23B
0005432922546	796	1	1C
0005432922553	796	2	2C
0005433512063	796	3	3D
0005433512067	796	4	5B
0005433512064	796	5	5C
0005432922552	796	6	5D
0005433512065	796	7	6A
0005433512061	796	8	18A
0005433512066	796	9	19A
0005433512060	796	10	19B
0005433512062	796	11	20C
0005433512069	796	12	22B
0005433512068	796	13	22D
0005432922520	796	14	23A
0005433512021	16161	1	22D
0005433512006	16161	2	2B
0005433511995	16161	3	22B
0005433511976	16161	4	3C
0005433512016	16161	5	19D
0005433511994	16161	6	7A
0005433511983	16161	7	19A
0005432922581	16161	8	4B
0005433511982	16161	9	7B
0005432922580	16161	10	1C
0005433511991	16161	11	6D
0005432922579	16161	12	21A
0005433511981	16161	13	20C
0005433511955	16161	14	23B
0005433512009	16161	15	5C
0005432922578	16161	16	20B
0005435852594	4027	1	5D
0005433475761	4027	2	6C
0005433475763	4027	3	7C
0005433475764	4027	4	18B
0005433475762	4027	5	18C
0005433475760	4027	6	20C
0005433475767	4027	7	22B
0005433475765	4027	8	23B
0005435852589	4027	9	3C
0005433475766	4027	10	4B
0005435852591	4027	11	1B
0005435697706	3671	1	6C
0005435697721	3671	2	6D
0005435697708	3671	3	7D
0005435697716	3671	4	18A
0005435697717	3671	5	18D
0005435697725	3671	6	19A
0005435697713	3671	7	19B
0005435697728	3671	8	19C
0005435697719	3671	9	19D
0005434950591	3671	10	20A
0005435916181	3671	11	20C
0005435697724	3671	12	20B
0005435697729	3671	13	20D
0005435697711	3671	14	21A
0005435697715	3671	15	21C
0005435697722	3671	16	22A
0005435697732	3671	17	22B
0005435697710	3671	18	22C
0005435697718	3671	19	23A
0005435916182	3671	20	23B
0005435697712	3671	21	18C
0005435697714	3671	22	1B
0005435697727	3671	23	1C
0005434950590	3671	24	2A
0005435697733	3671	25	2B
0005435697734	3671	26	2C
0005435697709	3671	27	2D
0005435697707	3671	28	3A
0005435697730	3671	29	3B
0005435935072	3671	30	3C
0005435935060	3671	31	3D
0005434950588	3671	32	4B
0005435697723	3671	33	4C
0005435697731	3671	34	4D
0005434950589	3671	35	5A
0005435916185	3671	36	5B
0005435697705	3671	37	5C
0005435697720	3671	38	5D
0005435697726	3671	39	6A
0005435697471	16281	1	1A
0005435697541	16281	2	1B
0005435916202	16281	3	1C
0005435697433	16281	4	1D
0005435697365	16281	5	2A
0005435697441	16281	6	2B
0005435697525	16281	7	2C
0005435697495	16281	8	2D
0005435697431	16281	9	3A
0005434950530	16281	10	3B
0005435916204	16281	11	3C
0005435697546	16281	12	3D
0005434950555	16281	13	4A
0005435697452	16281	14	4B
0005435697423	16281	15	4C
0005435697451	16281	16	4D
0005435697526	16281	17	5A
0005435697432	16281	18	5B
0005434950563	16281	19	5C
0005435697413	16281	20	5D
0005434950568	16281	21	6A
0005435697527	16281	22	6B
0005435697436	16281	23	6C
0005434950564	16281	24	6D
0005435697522	16281	25	7A
0005435697545	16281	26	7B
0005435697440	16281	27	7C
0005435916205	16281	28	7D
0005435697467	16281	29	18A
0005435697387	16281	30	18B
0005435697434	16281	31	18C
0005435697530	16281	32	18D
0005435697414	16281	33	19A
0005435697472	16281	34	19B
0005434950557	16281	35	19C
0005435697446	16281	36	19D
0005435697367	16281	37	20A
0005435697424	16281	38	20B
0005435697521	16281	39	20C
0005434950531	16281	40	20D
0005435697542	16281	41	21A
0005435697444	16281	42	21B
0005435697486	16281	43	21C
0005435697497	16281	44	21D
0005435697445	16281	45	22A
0005435697504	16281	46	22B
0005435697366	16281	47	22C
0005435697377	16281	48	22D
0005435916203	16281	49	23A
0005434950569	16281	50	23B
0005432607619	3949	1	22D
0005432607620	3949	2	1A
0005433519518	3949	3	1C
0005434604946	3949	4	1D
0005435853617	3949	5	2A
0005434606876	3949	6	3A
0005434604944	3949	7	4A
0005434606874	3949	8	4D
0005435904897	3949	9	5A
0005432609786	3949	10	5B
0005433519522	3949	11	5C
0005432609788	3949	12	6C
0005432609785	3949	13	7A
0005435904706	3949	14	7D
0005434604945	3949	15	18A
0005434606875	3949	16	18B
0005433519521	3949	17	18C
0005432609784	3949	18	18D
0005432607623	3949	19	19A
0005433519517	3949	20	20C
0005433519519	3949	21	21A
0005432609787	3949	22	21B
0005435904896	3949	23	21C
0005432607621	3949	24	21D
0005433519520	3949	25	22A
0005432607622	3949	26	22B
0005434606877	3949	27	23A
0005434606825	22037	1	2A
0005433519484	22037	2	2B
0005434606845	22037	3	3B
0005434606823	22037	4	3C
0005434606847	22037	5	4A
0005433519483	22037	6	4D
0005434606827	22037	7	7A
0005434606846	22037	8	7B
0005434606831	22037	9	18B
0005435853635	22037	10	18C
0005434606842	22037	11	19D
0005435853636	22037	12	20D
0005433519471	22037	13	21B
0005433519487	22037	14	21C
0005434606826	22037	15	1D
0005433519485	22037	16	23B
0005435628768	713	1	1A
0005433349017	713	2	2A
0005433349031	713	3	2B
0005433349024	713	4	3A
0005433348995	713	5	3B
0005433349030	713	6	4A
0005433349025	713	7	4B
0005433349026	713	8	5A
0005433349015	713	9	5B
0005433349006	713	10	6A
0005433349034	713	11	6B
0005433349066	15905	1	1A
0005433349070	15905	2	2A
0005435628734	15905	3	2B
0005433349069	15905	4	3A
0005435628743	15905	5	3B
0005433349068	15905	6	5A
0005435628742	15905	7	6A
0005433349067	15905	8	6B
0005433158140	17186	1	1A
0005434445272	17186	2	1B
0005434446544	17186	3	2B
0005434445271	17186	4	4A
0005434446547	17186	5	3B
0005433158139	17186	6	4B
0005434446546	17186	7	5A
0005434446545	17186	8	5B
0005433158138	17186	9	6A
0005434445253	17676	1	1A
0005433159346	17676	2	2B
0005434445252	17676	3	3A
0005433159345	17676	4	3B
0005434445255	17676	5	4A
0005433159344	17676	6	5B
0005434445254	17676	7	6B
0005435383174	7869	1	6B
0005435133028	7869	2	1A
0005435383175	7869	3	1C
0005435383138	7869	4	2A
0005435133025	7869	5	2B
0005435133021	7869	6	2D
0005435383167	7869	7	3A
0005435383168	7869	8	3C
0005435133022	7869	9	3D
0005435133026	7869	10	4C
0005435133019	7869	11	4D
0005435383171	7869	12	5A
0005435133023	7869	13	5B
0005435133024	7869	14	5C
0005435383137	7869	15	5D
0005435383176	7869	16	6C
0005435133020	7869	17	7B
0005435133029	7869	18	18B
0005435133027	7869	19	19D
0005435383169	7869	20	20D
0005435132902	33116	1	3D
0005435132942	33116	2	6D
0005435383224	33116	3	18D
0005435132914	33116	4	3B
0005435132901	33116	5	23B
0005435383221	33116	6	7D
0005435132903	33116	7	22C
0005435383223	33116	8	23A
0005435383222	33116	9	21B
0005435132984	33116	10	7C
0005435383225	33116	11	22A
0005435132945	33116	12	18B
0005435132927	33116	13	1A
0005435383226	33116	14	6B
0005435132953	33116	15	19D
0005435132924	33116	16	4B
0005435383220	33116	17	3A
0005435160450	7516	1	6B
0005435160455	7516	2	1A
0005435390238	7516	3	1D
0005435160449	7516	4	2C
0005435390271	7516	5	4B
0005435160456	7516	6	5B
0005435160448	7516	7	6A
0005435160453	7516	8	6C
0005435160454	7516	9	18C
0005435390239	7516	10	19A
0005435390286	7516	11	20A
0005435160458	7516	12	20B
0005435390293	7516	13	21C
0005435390285	7516	14	21D
0005435160452	7516	15	22A
0005435160457	7516	16	22C
0005435160451	7516	17	22D
0005435390332	29537	1	3A
0005435160393	29537	2	18B
0005435160363	29537	3	3C
0005435390330	29537	4	21B
0005435390334	29537	5	4B
0005435160366	29537	6	6A
0005435160343	29537	7	18A
0005435160394	29537	8	21A
0005435390331	29537	9	22D
0005435160364	29537	10	1B
0005435390333	29537	11	19C
0005435390336	29537	12	5D
0005435160313	29537	13	1A
0005435160314	29537	14	19B
0005435390335	29537	15	2B
0005432398219	18481	1	1A
0005432398206	18481	2	1B
0005432394116	18481	3	2A
0005432398217	18481	4	2B
0005432394121	18481	5	3A
0005435178515	18481	6	3B
0005432394125	18481	7	4A
0005432394124	18481	8	4B
0005435179002	18481	9	5A
0005432398211	18481	10	5B
0005432398212	18481	11	6A
0005432398244	27140	1	5A
0005432398246	27140	2	1A
0005432400172	27140	3	1B
0005432400171	27140	4	3A
0005435178500	27140	5	3B
0005432398247	27140	6	5B
0005432398245	27140	7	6A
0005432398243	27140	8	6B
0005432639275	2242	1	1F
0005432866014	2242	2	2A
0005432639278	2242	3	2C
0005432639283	2242	4	2D
0005432639304	2242	5	2F
0005432866009	2242	6	3A
0005432866038	2242	7	3D
0005432639273	2242	8	3F
0005432639294	2242	9	4D
0005432639302	2242	10	4E
0005432639295	2242	11	5A
0005432866023	2242	12	5F
0005432865999	2242	13	6F
0005432639297	2242	14	8A
0005432639291	2242	15	8C
0005432639303	2242	16	8D
0005432639300	2242	17	8F
0005432866043	2242	18	9A
0005432639287	2242	19	9F
0005432639308	2242	20	10A
0005432639306	2242	21	10D
0005432639289	2242	22	10E
0005432639293	2242	23	11C
0005432639285	2242	24	11D
0005432639286	2242	25	11F
0005432639277	2242	26	12C
0005432639305	2242	27	13C
0005432639281	2242	28	13E
0005432866037	2242	29	13F
0005432639307	2242	30	14A
0005432639282	2242	31	14D
0005432639272	2242	32	14E
0005432639301	2242	33	14F
0005432866051	2242	34	1A
0005432866034	2242	35	15C
0005432639292	2242	36	15D
0005432639274	2242	37	16A
0005432866042	2242	38	16D
0005432639290	2242	39	16E
0005432866039	2242	40	17E
0005432639279	2242	41	18A
0005432639284	2242	42	18C
0005432639276	2242	43	18E
0005432639299	2242	44	19A
0005432866012	2242	45	19C
0005432639288	2242	46	19E
0005432639296	2242	47	20C
0005432639298	2242	48	20D
0005432639280	2242	49	20F
0005434191280	9761	1	3A
0005434191281	9761	2	6B
0005434504680	6524	1	1A
0005435104040	6524	2	1C
0005434504671	6524	3	2A
0005434504703	6524	4	2C
0005434504687	6524	5	2F
0005434504678	6524	6	3D
0005434504685	6524	7	4C
0005434504698	6524	8	4D
0005435104035	6524	9	4E
0005434504664	6524	10	4F
0005434504679	6524	11	5A
0005435104039	6524	12	5C
0005434504674	6524	13	5E
0005434504681	6524	14	6A
0005435104047	6524	15	6C
0005434504667	6524	16	6D
0005435104036	6524	17	6E
0005434504695	6524	18	6F
0005434504677	6524	19	7C
0005434504668	6524	20	7E
0005435104032	6524	21	8A
0005434504699	6524	22	8C
0005435104042	6524	23	8D
0005434504691	6524	24	8E
0005434504696	6524	25	8F
0005434504697	6524	26	9A
0005435104046	6524	27	9E
0005434504676	6524	28	10C
0005434504694	6524	29	10D
0005434504684	6524	30	10E
0005435104045	6524	31	10F
0005435104043	6524	32	11F
0005435104034	6524	33	12A
0005434504670	6524	34	12D
0005434504665	6524	35	12F
0005435104041	6524	36	13A
0005435104031	6524	37	13C
0005434504693	6524	38	14A
0005434504692	6524	39	14C
0005434504690	6524	40	14D
0005434504669	6524	41	14E
0005434504689	6524	42	14F
0005434504673	6524	43	15A
0005434504672	6524	44	15C
0005434504666	6524	45	15D
0005435104038	6524	46	15E
0005435104033	6524	47	16A
0005434504683	6524	48	16C
0005434504675	6524	49	16D
0005435104037	6524	50	17A
0005434504686	6524	51	17E
0005434504688	6524	52	18A
0005434504700	6524	53	18C
0005435104030	6524	54	18E
0005434504682	6524	55	18F
0005435104044	6524	56	19F
0005434504701	6524	57	20D
0005434504702	6524	58	20E
0005434504214	22693	1	1A
0005435103921	22693	2	1F
0005434504193	22693	3	3A
0005434504338	22693	4	3C
0005434504255	22693	5	5A
0005434504213	22693	6	5D
0005435103929	22693	7	5E
0005435103887	22693	8	7E
0005435103922	22693	9	8C
0005434504224	22693	10	8D
0005434504212	22693	11	8F
0005434503972	22693	12	9A
0005435103918	22693	13	9C
0005434504285	22693	14	9D
0005434504371	22693	15	9F
0005434504219	22693	16	10C
0005434504355	22693	17	11D
0005434504243	22693	18	11F
0005434504130	22693	19	12F
0005434504286	22693	20	13A
0005434504418	22693	21	13C
0005434504409	22693	22	13D
0005434504337	22693	23	13F
0005434504307	22693	24	14A
0005435103931	22693	25	14C
0005434504339	22693	26	15C
0005435103930	22693	27	15D
0005434504091	22693	28	15E
0005435103924	22693	29	18F
0005434504269	22693	30	19A
0005434504225	22693	31	19C
0005434504273	22693	32	19D
0005434504204	22693	33	20D
0005435800137	6421	1	1C
0005435800140	6421	2	1D
0005435800142	6421	3	5B
0005435800130	6421	4	5C
0005435800131	6421	5	6A
0005435800139	6421	6	6D
0005435800136	6421	7	7C
0005435800143	6421	8	18D
0005435800129	6421	9	19A
0005435800135	6421	10	19D
0005435800144	6421	11	20C
0005435800138	6421	12	21A
0005435800132	6421	13	21C
0005435800141	6421	14	22B
0005435800133	6421	15	22C
0005435800134	6421	16	23A
0005435653614	1658	1	1A
0005433367970	1658	2	1C
0005433367995	1658	3	1D
0005435653643	1658	4	2C
0005433368211	1658	5	2D
0005435653628	1658	6	2F
0005435653640	1658	7	3A
0005433368083	1658	8	3D
0005435653630	1658	9	3F
0005433368024	1658	10	4C
0005433367872	1658	11	4A
0005433367871	1658	12	4D
0005435653619	1658	13	4E
0005435653642	1658	14	4F
0005433368009	1658	15	5A
0005433367982	1658	16	5D
0005435653611	1658	17	5E
0005435653631	1658	18	5F
0005435653655	1658	19	6A
0005435653649	1658	20	6E
0005433368067	1658	21	6F
0005433368111	1658	22	7A
0005435653625	1658	23	7C
0005433367972	1658	24	7D
0005433368085	1658	25	7E
0005435653648	1658	26	7F
0005435653621	1658	27	8A
0005433367959	1658	28	8C
0005433368066	1658	29	8D
0005435653651	1658	30	8E
0005433368073	1658	31	8F
0005433368084	1658	32	9A
0005435653615	1658	33	9C
0005435653641	1658	34	9D
0005433367994	1658	35	9E
0005435653624	1658	36	10A
0005435653635	1658	37	10C
0005435653644	1658	38	10E
0005435653620	1658	39	10F
0005435653616	1658	40	11A
0005433367992	1658	41	11E
0005433367958	1658	42	11F
0005433367996	1658	43	12A
0005435653627	1658	44	12C
0005435653623	1658	45	12E
0005435653636	1658	46	12F
0005435653637	1658	47	13A
0005433368023	1658	48	13C
0005435653638	1658	49	13D
0005435653618	1658	50	13E
0005433367993	1658	51	13F
0005435653613	1658	52	14A
0005433368105	1658	53	14C
0005433368025	1658	54	14D
0005435653650	1658	55	14E
0005435653633	1658	56	14F
0005435653622	1658	57	15A
0005433368043	1658	58	15C
0005433368112	1658	59	15D
0005435653634	1658	60	16A
0005435653647	1658	61	16C
0005433368113	1658	62	16D
0005435653645	1658	63	16E
0005433368196	1658	64	16F
0005435653617	1658	65	17A
0005433367971	1658	66	17E
0005435653612	1658	67	17F
0005433368238	1658	68	18A
0005435653626	1658	69	18D
0005435653646	1658	70	18E
0005435653652	1658	71	18F
0005433368201	1658	72	19C
0005435653639	1658	73	19D
0005435653653	1658	74	19E
0005435653629	1658	75	19F
0005433368042	1658	76	20A
0005435653654	1658	77	20C
0005433368192	1658	78	20D
0005433368202	1658	79	20E
0005435653632	1658	80	20F
0005435653218	21711	1	9F
0005433368372	21711	2	1C
0005433368378	21711	3	1F
0005433368380	21711	4	2A
0005435653181	21711	5	2C
0005435653048	21711	6	2F
0005435653216	21711	7	3A
0005433368383	21711	8	3C
0005435653244	21711	9	3D
0005433368405	21711	10	3F
0005433368403	21711	11	4A
0005435653214	21711	12	4C
0005433368402	21711	13	4D
0005435653247	21711	14	4E
0005435653180	21711	15	4F
0005435653167	21711	16	5A
0005433368379	21711	17	5D
0005433368377	21711	18	5E
0005433368397	21711	19	5F
0005435653056	21711	20	6A
0005435653245	21711	21	6C
0005433368393	21711	22	6D
0005435653248	21711	23	6E
0005433368376	21711	24	6F
0005435653057	21711	25	7A
0005433368401	21711	26	7D
0005433368399	21711	27	7E
0005435653212	21711	28	8C
0005433368388	21711	29	8E
0005433368371	21711	30	8F
0005433368407	21711	31	9A
0005435653165	21711	32	9C
0005435653049	21711	33	9D
0005435653050	21711	34	9E
0005433368392	21711	35	10A
0005435653252	21711	36	10E
0005433368384	21711	37	10D
0005435653246	21711	38	10F
0005435653100	21711	39	11A
0005435653166	21711	40	11C
0005435653243	21711	41	11F
0005433368370	21711	42	12A
0005435653169	21711	43	12C
0005433368389	21711	44	12D
0005435653222	21711	45	12E
0005435653221	21711	46	13A
0005433368382	21711	47	13D
0005433368375	21711	48	13E
0005435653115	21711	49	14A
0005433368400	21711	50	14C
0005433368398	21711	51	14D
0005435653224	21711	52	14E
0005435653239	21711	53	14F
0005435653201	21711	54	15D
0005435653014	21711	55	15E
0005435652976	21711	56	15F
0005433368391	21711	57	16A
0005433368406	21711	58	16C
0005435653229	21711	59	16D
0005433368395	21711	60	16E
0005435652918	21711	61	16F
0005433368404	21711	62	17A
0005435653220	21711	63	17C
0005433368387	21711	64	17D
0005433368381	21711	65	17F
0005435653157	21711	66	17E
0005435653194	21711	67	18A
0005433368396	21711	68	18C
0005435653215	21711	69	18D
0005433368390	21711	70	18E
0005433368373	21711	71	18F
0005435653253	21711	72	19A
0005433368408	21711	73	19C
0005433368374	21711	74	19E
0005433368385	21711	75	19F
0005433368386	21711	76	20A
0005435653217	21711	77	20C
0005433368394	21711	78	20E
0005435653238	21711	79	20F
0005435627120	23769	1	5B
0005435627119	23769	2	2A
0005435312836	23222	1	1D
0005435312841	23222	2	2A
0005434466465	23222	3	2C
0005434466472	23222	4	2D
0005434466491	23222	5	3C
0005435312839	23222	6	4C
0005434466471	23222	7	4D
0005435312834	23222	8	5B
0005434466477	23222	9	5D
0005434466473	23222	10	6A
0005434466463	23222	11	6C
0005435312835	23222	12	7C
0005434466464	23222	13	7D
0005435312838	23222	14	18D
0005434466475	23222	15	19A
0005434466451	23222	16	19B
0005434466462	23222	17	19C
0005434466490	23222	18	20A
0005434466470	23222	19	20B
0005434466446	23222	20	21D
0005434466487	23222	21	22C
0005435312837	23222	22	22D
0005435312840	23222	23	23A
0005434466493	23222	24	18C
0005434466452	23222	25	1B
0005433986586	4182	1	11C
0005433986550	4182	2	1C
0005433986567	4182	3	6E
0005433986581	4182	4	18C
0005433986562	4182	5	13D
0005433986570	4182	6	19E
0005433986591	4182	7	3C
0005433986555	4182	8	10D
0005433986576	4182	9	11D
0005433986580	4182	10	20E
0005433986588	4182	11	17C
0005433986557	4182	12	19C
0005433986553	4182	13	11F
0005433986577	4182	14	16A
0005433986590	4182	15	1D
0005433986573	4182	16	19D
0005433986575	4182	17	1A
0005433986571	4182	18	6D
0005433986558	4182	19	6C
0005433986559	4182	20	16F
0005433986572	4182	21	20A
0005433986560	4182	22	3F
0005433986565	4182	23	6A
0005433986574	4182	24	19A
0005433986549	4182	25	20F
0005433986598	4182	26	9F
0005433986548	4182	27	13F
0005433986594	4182	28	15E
0005433986552	4182	29	20D
0005433986554	4182	30	19F
0005433986585	4182	31	7F
0005433986599	4182	32	9A
0005435788806	4182	33	6F
0005433986601	4182	34	13C
0005435788805	4182	35	8E
0005433986584	4182	36	12F
0005433986566	4182	37	4A
0005433986556	4182	38	18D
0005433986583	4182	39	16C
0005433986589	4182	40	18E
0005433986579	4182	41	7C
0005433986569	4182	42	18A
0005433986592	4182	43	15A
0005433986587	4182	44	12D
0005433986595	4182	45	7E
0005433986564	4182	46	10F
0005433986593	4182	47	10E
0005433986578	4182	48	17F
0005433986551	4182	49	4F
0005433986600	4182	50	9D
0005433986596	4182	51	8C
0005433986561	4182	52	1F
0005433986568	4182	53	5F
0005433986582	4182	54	4C
0005433986597	4182	55	14E
0005433986563	4182	56	13E
0005433986180	25637	1	9D
0005433986291	25637	2	5A
0005433986017	25637	3	8C
0005433985904	25637	4	15E
0005433986111	25637	5	6F
0005433985963	25637	6	17A
0005433986043	25637	7	4C
0005433985909	25637	8	17E
0005435788790	25637	9	7A
0005433985913	25637	10	12E
0005433986127	25637	11	14E
0005433985914	25637	12	10F
0005433986099	25637	13	2C
0005433986247	25637	14	9E
0005433168430	21323	1	22C
0005434509186	21323	2	7D
0005434509174	21323	3	5C
0005434509201	21323	4	20B
0005434509207	21323	5	20C
0005434509185	21323	6	3B
0005434509208	21323	7	18A
0005434509188	21323	8	6D
0005434509200	21323	9	18C
0005433168431	21323	10	5D
0005433168432	21323	11	22B
0005433168424	21323	12	1A
0005433168428	21323	13	6A
0005434509193	21323	14	5B
0005434509199	21323	15	1C
0005434509181	21323	16	23A
0005433168426	21323	17	3A
0005434509203	21323	18	19D
0005434509187	21323	19	18B
0005434509169	21323	20	4A
0005434509172	21323	21	4C
0005433168425	21323	22	2D
0005433168427	21323	23	7B
0005434509183	21323	24	19B
0005434509171	21323	25	20D
0005434509204	21323	26	21A
0005433168429	21323	27	7A
0005432655591	17818	1	3A
0005432661925	17818	2	3C
0005432666388	17818	3	4A
0005432655623	17818	4	4E
0005432655637	17818	5	5C
0005432659716	17818	6	5E
0005432659717	17818	7	6A
0005432663049	17818	8	6C
0005432666404	17818	9	6F
0005432655563	17818	10	7E
0005432667460	17818	11	7F
0005432657464	17818	12	8A
0005432664149	17818	13	8D
0005432664146	17818	14	8E
0005432657462	17818	15	9E
0005432869618	17818	16	10A
0005432655622	17818	17	10C
0005432869619	17818	18	11A
0005432658595	17818	19	11F
0005432660834	17818	20	12A
0005434151745	17818	21	12C
0005432664156	17818	22	12E
0005432665289	17818	23	13E
0005432657451	17818	24	13F
0005434151747	17818	25	14D
0005432869616	17818	26	14F
0005432659718	17818	27	15C
0005432869617	17818	28	15E
0005432655636	17818	29	15F
0005432661927	17818	30	16A
0005432655590	17818	31	16C
0005432869620	17818	32	16F
0005434151744	17818	33	17C
0005432661934	17818	34	17E
0005432655609	17818	35	18A
0005432665285	17818	36	18D
0005432660833	17818	37	18E
0005434151746	17818	38	18F
0005432666399	17818	39	19D
0005432667461	17818	40	20A
0005432663050	17818	41	20E
0005432666389	17818	42	1A
0005432658599	17818	43	1D
0005432661926	17818	44	1F
0005432664157	17818	45	2C
0005432666390	17818	46	2F
0005432659732	26315	1	8E
0005432657487	26315	2	2A
0005432658616	26315	3	2C
0005434151716	26315	4	2D
0005432655669	26315	5	2F
0005434151709	26315	6	3C
0005432665299	26315	7	4A
0005432655679	26315	8	4C
0005434151714	26315	9	5A
0005432657488	26315	10	5C
0005432660843	26315	11	5F
0005432667478	26315	12	6E
0005432869546	26315	13	7A
0005432869529	26315	14	7F
0005432869503	26315	15	8C
0005434151717	26315	16	8D
0005432655676	26315	17	8F
0005432665300	26315	18	9D
0005432869528	26315	19	10E
0005432655668	26315	20	11A
0005432655672	26315	21	11F
0005432657486	26315	22	12F
0005432655675	26315	23	13A
0005432655674	26315	24	13D
0005432667479	26315	25	13F
0005432658617	26315	26	14C
0005432655670	26315	27	14D
0005432655673	26315	28	14F
0005432657489	26315	29	15A
0005432869513	26315	30	15C
0005432665301	26315	31	16C
0005432657485	26315	32	16E
0005432659731	26315	33	17E
0005434151715	26315	34	18A
0005432869545	26315	35	18D
0005432666414	26315	36	19C
0005432655671	26315	37	19D
0005432655677	26315	38	19E
0005432660842	26315	39	19F
0005432666413	26315	40	20D
0005432655678	26315	41	20E
0005432329300	3122	1	4A
0005432329331	3122	2	15E
0005432905166	3122	3	10F
0005432329327	3122	4	4C
0005432329324	3122	5	8D
0005432329337	3122	6	1C
0005432329323	3122	7	17F
0005432329307	3122	8	9A
0005432905157	3122	9	3A
0005432329322	3122	10	3D
0005432905167	3122	11	6E
0005432329338	3122	12	19A
0005432287259	3122	13	3C
0005432329319	3122	14	8A
0005432329344	3122	15	14E
0005432905206	31150	1	5C
0005432848845	31150	2	1C
0005432328778	31150	3	1D
0005432905204	31150	4	1F
0005432054345	31150	5	2C
0005432328860	31150	6	2D
0005432328852	31150	7	2F
0005432328815	31150	8	3C
0005432054344	31150	9	3D
0005433438944	31150	10	4D
0005432328822	31150	11	4E
0005432329061	31150	12	4F
0005432328823	31150	13	5A
0005432054342	31150	14	5E
0005432329008	31150	15	5F
0005432328732	31150	16	6A
0005432905207	31150	17	6C
0005432328724	31150	18	6D
0005432848846	31150	19	6E
0005432054343	31150	20	7C
0005432329036	31150	21	7D
0005432328630	31150	22	7E
0005432905209	31150	23	7F
0005432329081	31150	24	8C
0005432329016	31150	25	8D
0005432328670	31150	26	9C
0005432905205	31150	27	9D
0005432329035	31150	28	10A
0005432329086	31150	29	10E
0005432905208	31150	30	10F
0005432328954	31150	31	11C
0005432848843	31150	32	11D
0005432328868	31150	33	12A
0005432328902	31150	34	12C
0005432329087	31150	35	12E
0005433438943	31150	36	13C
0005432328464	31150	37	13D
0005432328856	31150	38	13E
0005432328956	31150	39	14E
0005432329034	31150	40	14F
0005432329009	31150	41	15A
0005432328671	31150	42	15D
0005433438945	31150	43	16A
0005432328848	31150	44	16C
0005432328942	31150	45	16F
0005432848844	31150	46	17A
0005432328835	31150	47	17F
0005432328869	31150	48	17E
0005432328571	31150	49	18A
0005432328943	31150	50	18C
0005432328909	31150	51	18F
0005432328955	31150	52	19A
0005432328927	31150	53	19D
0005433438894	31150	54	19E
0005432328881	31150	55	19F
0005432328715	31150	56	20A
0005433438942	31150	57	20C
0005432328913	31150	58	20E
0005435488041	6206	1	2D
0005435487842	6206	2	3A
0005435487961	6206	3	4A
0005435487946	6206	4	4C
0005435999476	6206	5	4F
0005435999481	6206	6	5C
0005435297071	6206	7	5E
0005435487874	6206	8	6B
0005434309920	6206	9	6D
0005434309930	6206	10	1D
0005435487922	6206	11	6F
0005434309924	6206	12	1F
0005434309928	6206	13	6E
0005435297091	6206	14	7D
0005434309933	6206	15	7E
0005435999482	6206	16	8A
0005435999483	6206	17	7F
0005435487957	6206	18	8B
0005435488039	6206	19	8D
0005435487844	6206	20	9B
0005435487930	6206	21	9C
0005435297079	6206	22	9D
0005435488040	6206	23	9F
0005434309932	6206	24	10E
0005435999479	6206	25	11D
0005434309927	6206	26	11F
0005435487921	6206	27	12A
0005435487939	6206	28	12C
0005435297080	6206	29	12E
0005435297078	6206	30	12D
0005435487774	6206	31	14A
0005435487959	6206	32	14C
0005435999478	6206	33	14D
0005435487933	6206	34	14F
0005435487920	6206	35	14E
0005434309921	6206	36	15A
0005435487875	6206	37	15B
0005435297104	6206	38	15D
0005434309923	6206	39	16C
0005435297087	6206	40	16B
0005435487958	6206	41	16E
0005435487897	6206	42	17E
0005435487898	6206	43	17D
0005434309922	6206	44	18A
0005434309931	6206	45	18C
0005435999477	6206	46	18D
0005435487917	6206	47	19A
0005434309926	6206	48	19C
0005435487916	6206	49	19E
0005435487843	6206	50	20A
0005435999480	6206	51	20B
0005434309929	6206	52	20C
0005435297102	6206	53	20E
0005435487909	6206	54	20D
0005435297070	6206	55	20F
0005435297088	6206	56	21C
0005435999484	6206	57	21E
0005434309934	6206	58	22A
0005435487876	6206	59	22C
0005435297092	6206	60	23A
0005435487940	6206	61	23C
0005435487896	6206	62	23E
0005434309925	6206	63	23F
0005435487977	6206	64	2A
0005435999276	19575	1	1C
0005435488115	19575	2	2A
0005435488097	19575	3	2F
0005435999331	19575	4	3C
0005435488114	19575	5	3D
0005435488103	19575	6	4A
0005435488108	19575	7	4D
0005434309792	19575	8	4E
0005435488111	19575	9	4F
0005435297152	19575	10	5B
0005435488112	19575	11	5A
0005434309880	19575	12	5D
0005435999308	19575	13	5F
0005435297154	19575	14	6E
0005435297149	19575	15	7A
0005434309881	19575	16	7D
0005435999330	19575	17	8E
0005435999325	19575	18	9C
0005435488098	19575	19	9B
0005434309795	19575	20	9D
0005435297153	19575	21	10C
0005435999279	19575	22	10D
0005434309830	19575	23	11A
0005435999284	19575	24	11C
0005434309852	19575	25	11D
0005435488106	19575	26	12A
0005435488110	19575	27	12E
0005435488096	19575	28	12F
0005435297150	19575	29	13B
0005435999303	19575	30	13C
0005434309854	19575	31	13D
0005434309853	19575	32	13E
0005434309836	19575	33	13F
0005435999272	19575	34	14C
0005434309791	19575	35	15A
0005435488116	19575	36	15D
0005435297151	19575	37	15F
0005435999317	19575	38	16B
0005435999307	19575	39	16E
0005435488105	19575	40	17B
0005435488102	19575	41	17D
0005435999201	19575	42	17F
0005435488104	19575	43	17E
0005435488101	19575	44	18A
0005434309821	19575	45	18C
0005435999200	19575	46	18D
0005435488100	19575	47	19A
0005435488113	19575	48	18F
0005435999271	19575	49	19C
0005435488118	19575	50	19E
0005435488117	19575	51	20E
0005435999256	19575	52	21B
0005435999277	19575	53	21D
0005435488107	19575	54	21E
0005434309785	19575	55	22A
0005435999278	19575	56	22C
0005435488109	19575	57	22B
0005435488099	19575	58	23B
0005433158161	17555	1	2A
0005433158159	17555	2	2D
0005434446519	17555	3	6C
0005433158160	17555	4	7A
0005433158158	17555	5	19A
0005433158162	17555	6	19B
0005433186173	1576	1	1A
0005433186146	1576	2	1C
0005435518169	1576	3	1F
0005435508510	1576	4	2A
0005433186147	1576	5	2C
0005435518159	1576	6	2F
0005435502605	1576	7	3A
0005435502606	1576	8	3C
0005435518170	1576	9	3D
0005433186165	1576	10	3F
0005434566099	1576	11	4A
0005435502600	1576	12	4C
0005435518172	1576	13	4D
0005435518161	1576	14	4E
0005433186145	1576	15	4F
0005434566098	1576	16	5A
0005433186150	1576	17	5D
0005432291962	1576	18	5E
0005433186161	1576	19	5F
0005435518174	1576	20	6A
0005433186129	1576	21	6C
0005435502609	1576	22	6E
0005433186166	1576	23	6F
0005434566094	1576	24	7C
0005435502596	1576	25	7E
0005435502599	1576	26	8A
0005435502613	1576	27	8C
0005434566095	1576	28	8E
0005435502607	1576	29	9A
0005435502616	1576	30	9C
0005435518168	1576	31	9E
0005435502604	1576	32	10A
0005435502597	1576	33	10C
0005435502602	1576	34	10D
0005435508509	1576	35	10E
0005433186175	1576	36	10F
0005435502614	1576	37	11A
0005435518175	1576	38	11E
0005435508513	1576	39	12A
0005435502598	1576	40	12D
0005435518166	1576	41	12F
0005435502615	1576	42	13A
0005435502611	1576	43	13C
0005433186174	1576	44	13D
0005434566105	1576	45	13E
0005435502603	1576	46	14A
0005433186151	1576	47	14C
0005434566102	1576	48	14E
0005435502601	1576	49	14F
0005435518158	1576	50	15C
0005434566101	1576	51	15D
0005435518163	1576	52	15E
0005435508512	1576	53	15F
0005434566103	1576	54	16C
0005435518164	1576	55	16D
0005435518165	1576	56	16E
0005435518173	1576	57	16F
0005434566100	1576	58	17A
0005435502617	1576	59	17C
0005434566096	1576	60	17F
0005434566093	1576	61	18A
0005435508511	1576	62	18C
0005435518167	1576	63	18E
0005435508514	1576	64	18F
0005433186130	1576	65	19A
0005435518162	1576	66	19C
0005435518160	1576	67	19D
0005434566097	1576	68	19E
0005435502612	1576	69	20A
0005435518171	1576	70	19F
0005434566104	1576	71	20C
0005432291963	1576	72	20D
0005435502610	1576	73	20E
0005435502608	1576	74	20F
0005435529326	20865	1	18A
0005435529291	20865	2	1C
0005435502345	20865	3	1D
0005435545754	20865	4	2D
0005435529382	20865	5	2F
0005435545752	20865	6	3A
0005435502435	20865	7	3C
0005433186236	20865	8	3D
0005435545783	20865	9	3F
0005435529272	20865	10	4A
0005434565948	20865	11	4C
0005433186232	20865	12	4D
0005434566035	20865	13	4F
0005435502495	20865	14	5C
0005434565996	20865	15	5D
0005433186234	20865	16	5E
0005435529329	20865	17	5F
0005435529361	20865	18	6A
0005435529277	20865	19	6C
0005433186238	20865	20	6D
0005435502437	20865	21	6E
0005434566015	20865	22	6F
0005435529364	20865	23	7A
0005434565973	20865	24	7C
0005435529365	20865	25	7F
0005435529280	20865	26	8C
0005435529290	20865	27	8D
0005435502374	20865	28	8E
0005435529308	20865	29	8F
0005433186231	20865	30	9A
0005433186237	20865	31	9C
0005433186235	20865	32	9D
0005435502459	20865	33	9E
0005434565986	20865	34	9F
0005435545768	20865	35	10A
0005434565927	20865	36	10D
0005433186233	20865	37	10E
0005435545780	20865	38	10F
0005435502349	20865	39	11A
0005434565974	20865	40	11D
0005435502338	20865	41	11E
0005435502342	20865	42	12A
0005435502460	20865	43	12C
0005435529300	20865	44	12D
0005435529309	20865	45	12E
0005434566001	20865	46	13A
0005435502346	20865	47	13C
0005435502406	20865	48	13E
0005434565946	20865	49	13F
0005434566036	20865	50	14A
0005434565926	20865	51	14C
0005435502494	20865	52	14D
0005433186239	20865	53	14E
0005435545748	20865	54	14F
0005435502485	20865	55	15C
0005435529279	20865	56	15E
0005435545769	20865	57	15D
0005435529336	20865	58	15F
0005434565959	20865	59	16A
0005435545753	20865	60	16D
0005435529337	20865	61	16E
0005435529386	20865	62	16F
0005434565895	20865	63	17C
0005434566000	20865	64	17F
0005435502402	20865	65	18C
0005435502341	20865	66	18E
0005435545781	20865	67	18F
0005434565947	20865	68	19A
0005435529360	20865	69	19D
0005434565960	20865	70	19E
0005435502420	20865	71	20D
0005435502291	20865	72	20E
0005434565896	20865	73	20F
0005435931618	3904	1	5B
0005435153829	3904	2	2D
0005435153833	3904	3	3A
0005435931604	3904	4	5D
0005435153834	3904	5	3C
0005435153832	3904	6	6C
0005435931611	3904	7	7A
0005435153835	3904	8	7C
0005435153831	3904	9	7D
0005435153830	3904	10	19D
0005435931631	3904	11	22C
0005435931616	3904	12	4A
0005435931651	21878	1	18B
0005435153754	21878	2	2A
0005435931652	21878	3	3C
0005435931650	21878	4	6B
0005435153755	21878	5	6D
0005435931653	21878	6	18C
0005435153798	21878	7	20A
0005435153805	21878	8	20D
0005435153763	21878	9	21C
0005435153799	21878	10	22D
0005435225611	7187	1	1C
0005435225612	7187	2	1D
0005432629052	7187	3	2B
0005432629055	7187	4	2C
0005432629047	7187	5	3C
0005432629048	7187	6	4A
0005432629046	7187	7	4B
0005432629054	7187	8	5A
0005432629042	7187	9	6A
0005435225616	7187	10	6C
0005432629044	7187	11	7A
0005432629050	7187	12	7D
0005432629051	7187	13	18A
0005432629043	7187	14	18D
0005435225650	7187	15	19B
0005432629053	7187	16	20A
0005435225610	7187	17	20B
0005432629041	7187	18	20D
0005435225608	7187	19	21A
0005432629049	7187	20	21D
0005432629045	7187	21	23B
0005432628945	28094	1	6D
0005432628969	28094	2	1A
0005432628918	28094	3	1B
0005432628911	28094	4	3A
0005432628950	28094	5	2D
0005432628930	28094	6	3B
0005435225692	28094	7	3D
0005432629010	28094	8	4A
0005435225695	28094	9	4B
0005432628968	28094	10	4C
0005435225696	28094	11	4D
0005432628917	28094	12	5A
0005435225691	28094	13	5C
0005432628960	28094	14	6A
0005432628985	28094	15	6C
0005435225690	28094	16	7D
0005432628931	28094	17	18B
0005432628944	28094	18	18D
0005435225697	28094	19	19B
0005432628959	28094	20	20D
0005432628949	28094	21	21A
0005432628929	28094	22	21B
0005432628978	28094	23	21C
0005432628928	28094	24	22A
0005435225693	28094	25	22B
0005435225694	28094	26	22C
0005432628904	28094	27	22D
0005432628984	28094	28	23A
0005435960102	8740	1	2B
0005434267963	8740	2	3B
0005435960103	8740	3	4B
0005434267951	8740	4	4D
0005434267954	8740	5	6C
0005435960104	8740	6	19C
0005434267965	8740	7	21A
0005435960100	8740	8	21C
0005435960101	8740	9	22C
0005434268000	15221	1	20A
0005435960070	15221	2	18C
0005434268001	15221	3	2A
0005435960078	15221	4	5D
0005435960071	15221	5	21B
0005435960077	15221	6	19C
0005434268003	15221	7	22D
0005435960082	15221	8	21C
0005435960074	15221	9	6C
0005434268004	15221	10	7B
0005435960079	15221	11	1D
0005434268002	15221	12	1A
0005432675335	1201	1	3A
0005432873324	1201	2	1D
0005432675345	1201	3	2C
0005432693460	1201	4	2A
0005432693462	1201	5	2D
0005432693473	1201	6	3C
0005432675339	1201	7	3F
0005432693466	1201	8	3D
0005432693467	1201	9	4F
0005432693455	1201	10	6A
0005432693464	1201	11	6C
0005432693459	1201	12	6E
0005432693457	1201	13	6D
0005432675344	1201	14	7C
0005432873323	1201	15	7E
0005432677621	1201	16	8E
0005432693446	1201	17	8D
0005432675334	1201	18	8C
0005432693449	1201	19	8F
0005432693442	1201	20	9D
0005432693451	1201	21	10A
0005432675338	1201	22	9F
0005432675342	1201	23	10E
0005432675332	1201	24	11A
0005432693447	1201	25	10F
0005432675337	1201	26	11C
0005432693461	1201	27	11F
0005432675331	1201	28	11E
0005432693456	1201	29	12E
0005432693444	1201	30	12D
0005432873337	1201	31	12F
0005432675343	1201	32	13C
0005432693470	1201	33	14C
0005432693471	1201	34	14B
0005432677622	1201	35	14A
0005432693450	1201	36	15C
0005432675346	1201	37	15F
0005432693468	1201	38	15D
0005432693445	1201	39	16C
0005432675347	1201	40	16F
0005432677624	1201	41	17B
0005432693463	1201	42	17A
0005432675333	1201	43	17D
0005432675330	1201	44	17C
0005432675341	1201	45	17F
0005432693472	1201	46	18A
0005432675340	1201	47	18F
0005432677623	1201	48	19A
0005432693448	1201	49	20B
0005432693469	1201	50	20D
0005432693452	1201	51	20C
0005432675336	1201	52	20F
0005432693453	1201	53	20E
0005432693443	1201	54	21B
0005432693458	1201	55	21D
0005432873321	1201	56	21C
0005432693465	1201	57	21F
0005432693454	1201	58	21E
0005432693197	17493	1	1C
0005432677600	17493	2	1A
0005432693071	17493	3	1F
0005432675198	17493	4	2A
0005432873391	17493	5	2C
0005432693339	17493	6	3C
0005432693064	17493	7	3A
0005432693055	17493	8	3D
0005432693056	17493	9	4A
0005432693337	17493	10	3F
0005432693199	17493	11	5A
0005432693017	17493	12	4F
0005432693174	17493	13	4D
0005432693282	17493	14	6D
0005432693201	17493	15	6E
0005432693336	17493	16	7A
0005432693228	17493	17	7F
0005432677573	17493	18	7E
0005432693254	17493	19	8B
0005432693119	17493	20	8D
0005432693184	17493	21	8C
0005432693239	17493	22	8F
0005432693126	17493	23	9A
0005432693124	17493	24	9D
0005432693125	17493	25	9C
0005432873388	17493	26	10A
0005432677603	17493	27	10C
0005432693255	17493	28	10D
0005432675193	17493	29	10F
0005432675199	17493	30	11B
0005432693146	17493	31	11E
0005432693283	17493	32	12B
0005432693200	17493	33	14A
0005432675200	17493	34	13F
0005432677601	17493	35	13E
0005432677598	17493	36	14B
0005432873390	17493	37	14F
0005432675241	17493	38	15D
0005432693227	17493	39	15C
0005432675216	17493	40	16A
0005432693059	17493	41	15F
0005432693162	17493	42	16C
0005432675224	17493	43	16B
0005432693198	17493	44	16D
0005432677590	17493	45	16F
0005432693016	17493	46	17B
0005432693193	17493	47	17A
0005432693290	17493	48	17D
0005432677599	17493	49	17C
0005432693145	17493	50	18B
0005432873387	17493	51	17F
0005432873386	17493	52	18F
0005432693120	17493	53	19C
0005432693075	17493	54	19B
0005432873385	17493	55	20B
0005432873389	17493	56	20C
0005432675202	17493	57	21B
0005432693240	17493	58	21D
0005432693325	17493	59	21F
0005434435396	1103	1	1A
0005434435394	1103	2	1C
0005434435397	1103	3	1D
0005433156791	1103	4	2B
0005434435388	1103	5	2C
0005434435390	1103	6	2D
0005433156825	1103	7	3A
0005434435391	1103	8	3B
0005433156829	1103	9	4B
0005434435392	1103	10	4A
0005434435386	1103	11	4C
0005433156792	1103	12	5A
0005434435385	1103	13	5B
0005433156808	1103	14	5D
0005434435389	1103	15	6D
0005434435387	1103	16	7B
0005434435398	1103	17	18A
0005434435393	1103	18	18C
0005433156797	1103	19	19A
0005433156827	1103	20	19C
0005433156775	1103	21	19D
0005433156796	1103	22	20B
0005434435384	1103	23	21B
0005434435395	1103	24	21D
0005434435399	1103	25	22C
0005433156790	1103	26	23A
0005434435383	1103	27	23B
0005433156864	17288	1	1B
0005433156870	17288	2	2D
0005434435280	17288	3	3C
0005433156869	17288	4	3D
0005434435248	17288	5	4A
0005434435226	17288	6	4B
0005433156868	17288	7	5B
0005434435212	17288	8	6A
0005434435231	17288	9	6C
0005433156866	17288	10	7C
0005433156867	17288	11	7D
0005434435191	17288	12	18A
0005434435253	17288	13	18B
0005434435281	17288	14	18C
0005433156862	17288	15	19A
0005434435270	17288	16	21A
0005433156865	17288	17	21C
0005434435252	17288	18	22B
0005433156863	17288	19	23A
0005434435211	17288	20	23B
0005435086940	4048	1	23B
0005435086938	4048	2	1D
0005435086936	4048	3	3C
0005435086937	4048	4	6C
0005435928158	4048	5	7C
0005435928156	4048	6	18B
0005435086935	4048	7	18C
0005435928165	4048	8	19A
0005435086939	4048	9	20A
0005435928157	4048	10	20D
0005435928164	4048	11	22C
0005435086880	24438	1	2B
0005435086851	24438	2	2C
0005435928212	24438	3	3A
0005435086852	24438	4	4C
0005435086894	24438	5	4D
0005435086855	24438	6	5A
0005435086881	24438	7	6B
0005435928207	24438	8	7D
0005435086882	24438	9	19C
0005435928209	24438	10	20A
0005435928208	24438	11	20D
0005435086867	24438	12	21B
0005435928211	24438	13	21C
0005435928206	24438	14	21D
0005435928210	24438	15	22C
0005435086856	24438	16	23B
0005435706601	2461	1	1A
0005435706573	2461	2	1C
0005435706570	2461	3	1D
0005433373532	2461	4	1F
0005433373598	2461	5	2A
0005433373569	2461	6	2C
0005433373534	2461	7	2D
0005433373545	2461	8	3A
0005435706568	2461	9	3C
0005435706609	2461	10	3D
0005433373571	2461	11	3F
0005435706586	2461	12	4A
0005435706587	2461	13	4C
0005433373553	2461	14	4E
0005433373567	2461	15	4F
0005435706602	2461	16	5A
0005433373508	2461	17	5C
0005433373518	2461	18	5D
0005435706610	2461	19	5E
0005435706604	2461	20	5F
0005435706597	2461	21	6A
0005435706583	2461	22	6C
0005435706599	2461	23	7A
0005435706607	2461	24	7C
0005435706593	2461	25	7E
0005435706580	2461	26	8A
0005435706592	2461	27	8C
0005435706611	2461	28	8D
0005433373544	2461	29	8E
0005433373556	2461	30	8F
0005433373507	2461	31	9C
0005435706576	2461	32	9D
0005435706600	2461	33	9E
0005435706585	2461	34	9F
0005433373542	2461	35	10A
0005435706581	2461	36	10C
0005435706596	2461	37	10D
0005433373533	2461	38	10E
0005435706577	2461	39	10F
0005435706605	2461	40	11A
0005435706578	2461	41	11C
0005435706598	2461	42	11E
0005433373566	2461	43	11F
0005435706584	2461	44	12A
0005435706614	2461	45	12C
0005435706613	2461	46	12D
0005433373543	2461	47	12E
0005435706574	2461	48	12F
0005435706569	2461	49	13A
0005435706572	2461	50	13C
0005433373561	2461	51	13E
0005435706590	2461	52	13F
0005433373557	2461	53	14C
0005435706579	2461	54	14D
0005435706612	2461	55	14E
0005435706595	2461	56	14F
0005433373549	2461	57	15C
0005435706615	2461	58	15D
0005435706591	2461	59	15F
0005435706588	2461	60	16A
0005433373580	2461	61	16C
0005435706575	2461	62	16D
0005433373550	2461	63	16F
0005435706608	2461	64	17A
0005435706594	2461	65	17C
0005433373585	2461	66	17D
0005435706606	2461	67	17E
0005433373583	2461	68	17F
0005433373587	2461	69	18A
0005435706582	2461	70	18C
0005435706589	2461	71	18D
0005433373586	2461	72	18E
0005435706571	2461	73	19A
0005433373570	2461	74	19D
0005433373596	2461	75	19F
0005433373568	2461	76	20A
0005435706603	2461	77	20C
0005433373581	2461	78	20D
0005433373597	2461	79	20E
0005435706616	2461	80	20F
0005433373656	27028	1	1A
0005435706420	27028	2	1C
0005433373651	27028	3	1D
0005433373640	27028	4	1F
0005433373643	27028	5	2F
0005433373649	27028	6	3D
0005433373658	27028	7	4A
0005433373637	27028	8	4E
0005435706429	27028	9	4F
0005435706502	27028	10	5A
0005435706433	27028	11	5C
0005435706434	27028	12	5E
0005435706377	27028	13	5F
0005435706418	27028	14	6D
0005435706440	27028	15	6E
0005433373662	27028	16	6F
0005433373638	27028	17	7D
0005433373660	27028	18	7E
0005435706421	27028	19	8A
0005435706511	27028	20	8C
0005433373657	27028	21	8D
0005435706353	27028	22	8E
0005433373648	27028	23	8F
0005433373646	27028	24	9A
0005433373639	27028	25	9C
0005433373645	27028	26	9D
0005435706374	27028	27	9F
0005435706441	27028	28	10D
0005435706512	27028	29	10F
0005435706388	27028	30	11C
0005433373641	27028	31	11F
0005433373661	27028	32	12A
0005433373650	27028	33	12E
0005433373655	27028	34	12F
0005433373642	27028	35	13A
0005435706411	27028	36	13C
0005435706468	27028	37	13D
0005435706348	27028	38	13F
0005435706359	27028	39	14C
0005435706422	27028	40	14D
0005433373644	27028	41	14E
0005435706490	27028	42	14F
0005435706435	27028	43	15C
0005435706405	27028	44	15D
0005433373652	27028	45	15E
0005435706439	27028	46	16C
0005433373659	27028	47	16D
0005433373647	27028	48	16E
0005435706362	27028	49	16F
0005435706419	27028	50	17A
0005433373653	27028	51	17C
0005435706510	27028	52	18A
0005435706499	27028	53	18E
0005435706417	27028	54	19C
0005435706349	27028	55	19D
0005435706395	27028	56	19F
0005433373654	27028	57	20C
0005435706416	27028	58	20D
0005435706438	27028	59	20E
0005435706489	27028	60	20F
0005434626087	4875	1	6D
0005434626091	4875	2	10A
0005434626089	4875	3	10F
0005434626086	4875	4	11C
0005434626093	4875	5	12A
0005435907526	4875	6	13C
0005434626088	4875	7	15A
0005434626090	4875	8	15D
0005434626094	4875	9	15F
0005434626085	4875	10	16A
0005434626092	4875	11	17D
0005434626017	32937	1	3A
0005435907570	32937	2	6E
0005435907573	32937	3	8C
0005435907571	32937	4	8E
0005435907569	32937	5	15D
0005435907572	32937	6	18C
0005435785411	13747	1	1A
0005435785512	13747	2	1B
0005435785538	13747	3	1C
0005435785497	13747	4	1D
0005435785407	13747	5	2A
0005435785322	13747	6	2B
0005435785489	13747	7	2C
0005435785511	13747	8	2D
0005435785428	13747	9	3A
0005435785533	13747	10	3B
0005435787361	13747	11	3C
0005435785386	13747	12	3D
0005435785532	13747	13	4B
0005435785535	13747	14	4C
0005435785427	13747	15	4D
0005435785579	13747	16	5A
0005435785498	13747	17	5B
0005435785617	13747	18	5D
0005435785518	13747	19	5C
0005435785314	13747	20	6A
0005432195721	13747	21	6B
0005435785440	13747	22	6C
0005435785326	13747	23	6D
0005432195722	13747	24	7A
0005432195724	13747	25	7B
0005432195723	13747	26	7C
0005435785448	13747	27	7D
0005435785513	13747	28	18A
0005435785362	13747	29	18B
0005435785406	13747	30	18C
0005435787354	13747	31	18D
0005435785450	13747	32	19A
0005435785584	13747	33	19B
0005435785519	13747	34	19C
0005435787362	13747	35	19D
0005435785514	13747	36	20A
0005435785515	13747	37	20B
0005435785385	13747	38	20C
0005435785378	13747	39	20D
0005435937440	13747	40	21A
0005435785335	13747	41	21B
0005435785536	13747	42	21C
0005435785336	13747	43	21D
0005435785506	13747	44	22A
0005435785321	13747	45	22B
0005435785338	13747	46	22C
0005435785572	13747	47	22D
0005435785505	13747	48	23A
0005435785502	13747	49	23B
0005435785788	27447	1	1B
0005435785785	27447	2	1C
0005435785783	27447	3	1D
0005435785770	27447	4	2B
0005435785790	27447	5	2D
0005435785773	27447	6	3A
0005435785784	27447	7	3B
0005435785771	27447	8	3C
0005435785789	27447	9	3D
0005435785777	27447	10	4C
0005435785756	27447	11	4D
0005435785764	27447	12	5A
0005435785769	27447	13	5B
0005435785758	27447	14	5C
0005435785786	27447	15	5D
0005435785761	27447	16	6A
0005435785766	27447	17	6B
0005435937395	27447	18	6C
0005435785765	27447	19	7B
0005435785781	27447	20	7C
0005435785760	27447	21	7D
0005435785776	27447	22	18A
0005435785768	27447	23	18B
0005435785763	27447	24	18C
0005435785767	27447	25	18D
0005435785774	27447	26	19B
0005435787380	27447	27	19C
0005435785757	27447	28	20A
0005435785780	27447	29	20B
0005432190676	27447	30	20C
0005435785778	27447	31	20D
0005435785782	27447	32	21A
0005435785759	27447	33	21B
0005435787381	27447	34	21C
0005432190677	27447	35	21D
0005435785787	27447	36	22A
0005435785762	27447	37	22B
0005435785775	27447	38	22C
0005435785772	27447	39	22D
0005432190675	27447	40	23A
0005435785779	27447	41	23B
0005434408279	20302	1	1A
0005434408018	20302	2	1C
0005434407924	20302	3	1D
0005434407719	20302	4	2A
0005434408226	20302	5	2C
0005434408095	20302	6	2D
0005434408160	20302	7	2F
0005434408207	20302	8	3A
0005434408217	20302	9	3C
0005434408152	20302	10	3D
0005434408006	20302	11	3F
0005434408175	20302	12	4A
0005434408028	20302	13	4C
0005434408126	20302	14	4E
0005435311236	20302	15	4F
0005434408005	20302	16	5A
0005434407975	20302	17	5C
0005435311232	20302	18	5D
0005434408076	20302	19	5E
0005434408135	20302	20	5F
0005434407830	20302	21	6A
0005434408019	20302	22	6C
0005434407831	20302	23	6D
0005435311233	20302	24	6E
0005435311230	20302	25	6F
0005435311228	20302	26	7C
0005434408306	20302	27	7D
0005432058436	20302	28	7E
0005432058434	20302	29	7F
0005434407752	20302	30	8A
0005434407865	20302	31	8C
0005434408014	20302	32	8D
0005434408159	20302	33	8E
0005434408139	20302	34	8F
0005434407570	20302	35	9A
0005434408161	20302	36	9C
0005435311229	20302	37	9E
0005432058433	20302	38	9D
0005434408099	20302	39	9F
0005434408112	20302	40	10A
0005435311231	20302	41	10C
0005434408224	20302	42	10D
0005435311226	20302	43	10E
0005434408049	20302	44	10F
0005435311235	20302	45	11A
0005434408286	20302	46	11C
0005434407937	20302	47	11D
0005434408103	20302	48	11E
0005434408100	20302	49	11F
0005434407720	20302	50	12C
0005434408020	20302	51	12D
0005434407888	20302	52	12E
0005434407923	20302	53	13A
0005434407995	20302	54	13C
0005434408225	20302	55	13D
0005434407922	20302	56	13E
0005434408102	20302	57	13F
0005434408275	20302	58	14A
0005432058435	20302	59	14C
0005434407721	20302	60	14E
0005434408153	20302	61	15A
0005434407948	20302	62	15C
0005434407866	20302	63	15D
0005434407870	20302	64	15F
0005434408130	20302	65	16A
0005434408027	20302	66	16D
0005434407966	20302	67	16E
0005434408166	20302	68	17C
0005434408117	20302	69	17D
0005434408004	20302	70	17E
0005434407659	20302	71	17F
0005434407769	20302	72	18A
0005434407891	20302	73	18C
0005434407871	20302	74	18D
0005434408073	20302	75	18E
0005434408044	20302	76	18F
0005434407883	20302	77	19A
0005435311234	20302	78	19C
0005434408276	20302	79	19D
0005434407886	20302	80	19E
0005434408070	20302	81	19F
0005435311227	20302	82	20A
0005434407974	20302	83	20C
0005434407887	20302	84	20D
0005434407864	20302	85	20E
0005434407867	20302	86	20F
0005432154033	26993	1	1A
0005434408586	26993	2	1D
0005434408580	26993	3	1F
0005434408594	26993	4	2A
0005434408618	26993	5	2C
0005434408640	26993	6	2D
0005434408631	26993	7	2F
0005434408613	26993	8	3A
0005432154029	26993	9	3C
0005432154030	26993	10	3D
0005434408632	26993	11	3F
0005434408616	26993	12	4A
0005434408588	26993	13	4C
0005434408589	26993	14	4D
0005434408583	26993	15	4E
0005434408597	26993	16	4F
0005434408625	26993	17	5A
0005435311067	26993	18	5C
0005434408607	26993	19	5D
0005434408627	26993	20	5E
0005435311072	26993	21	5F
0005435311111	26993	22	6A
0005434408620	26993	23	6C
0005434408614	26993	24	6D
0005435311028	26993	25	6E
0005434408628	26993	26	7A
0005435311089	26993	27	7C
0005434408605	26993	28	7D
0005434408612	26993	29	7E
0005434408596	26993	30	7F
0005434408636	26993	31	8A
0005435311073	26993	32	8C
0005434408637	26993	33	8D
0005434408608	26993	34	8E
0005434408590	26993	35	8F
0005434408577	26993	36	9A
0005434408599	26993	37	9C
0005432154031	26993	38	9D
0005435311103	26993	39	9E
0005434408639	26993	40	9F
0005434408598	26993	41	10A
0005434408634	26993	42	10C
0005434408579	26993	43	10D
0005434408604	26993	44	10E
0005435311104	26993	45	11A
0005434408630	26993	46	11C
0005434408593	26993	47	11D
0005434408610	26993	48	11E
0005434408626	26993	49	11F
0005434408592	26993	50	12C
0005434408633	26993	51	12D
0005434408578	26993	52	12E
0005434408619	26993	53	13A
0005435311093	26993	54	13C
0005434408617	26993	55	13D
0005434408600	26993	56	13F
0005435311090	26993	57	14A
0005434408622	26993	58	14C
0005434408606	26993	59	14D
0005434408635	26993	60	14E
0005434408638	26993	61	14F
0005434408582	26993	62	15A
0005434408629	26993	63	15C
0005434408623	26993	64	15D
0005434408615	26993	65	15E
0005435311027	26993	66	16A
0005435311071	26993	67	16C
0005434408595	26993	68	16D
0005434408609	26993	69	16E
0005434408587	26993	70	16F
0005432154032	26993	71	17A
0005435311066	26993	72	17D
0005435311110	26993	73	17C
0005435311099	26993	74	17E
0005434408591	26993	75	17F
0005432154034	26993	76	18A
0005434408602	26993	77	18C
0005434408624	26993	78	18E
0005434408611	26993	79	18F
0005434408584	26993	80	19A
0005432154035	26993	81	19C
0005434408621	26993	82	19D
0005434408581	26993	83	19F
0005434408601	26993	84	20A
0005434408585	26993	85	20C
0005434408603	26993	86	20E
0005432109741	5721	1	1A
0005433124012	5721	2	1D
0005434319583	5721	3	1F
0005434319589	5721	4	2A
0005434319586	5721	5	2C
0005434319602	5721	6	2F
0005434319596	5721	7	3C
0005434319601	5721	8	3D
0005433123940	5721	9	4C
0005434319590	5721	10	4D
0005434319594	5721	11	4E
0005434319592	5721	12	5A
0005433123871	5721	13	5C
0005433124063	5721	14	5D
0005433124001	5721	15	6D
0005433123991	5721	16	6F
0005434319585	5721	17	7D
0005433123996	5721	18	7E
0005432109740	5721	19	7F
0005433124064	5721	20	9C
0005434319591	5721	21	10A
0005434319599	5721	22	10C
0005434311245	5721	23	10D
0005434311244	5721	24	11D
0005434319600	5721	25	11E
0005433123941	5721	26	12A
0005434319588	5721	27	12D
0005434319595	5721	28	12E
0005434319593	5721	29	13C
0005434319587	5721	30	13F
0005434311246	5721	31	14A
0005433124013	5721	32	14E
0005433123924	5721	33	15C
0005432109739	5721	34	15F
0005432109742	5721	35	16D
0005434319584	5721	36	16C
0005433124002	5721	37	17E
0005433123954	5721	38	18A
0005434319597	5721	39	18D
0005434319598	5721	40	18F
0005433123990	5721	41	20D
0005433123955	5721	42	20F
0005433124202	15675	1	1A
0005433124213	15675	2	1D
0005433124216	15675	3	2A
0005434319467	15675	4	2D
0005433124205	15675	5	3A
0005434319494	15675	6	4A
0005433124204	15675	7	4C
0005433124215	15675	8	5A
0005433124211	15675	9	5D
0005434319505	15675	10	5F
0005434311231	15675	11	6A
0005433124206	15675	12	7C
0005433124214	15675	13	7E
0005433124212	15675	14	7F
0005434311226	15675	15	8C
0005433124217	15675	16	9E
0005434319457	15675	17	10A
0005434319431	15675	18	10C
0005434319413	15675	19	10D
0005433124208	15675	20	10F
0005433124207	15675	21	11C
0005434311227	15675	22	11D
0005434311236	15675	23	11E
0005434319503	15675	24	12A
0005433124209	15675	25	13A
0005434319408	15675	26	13C
0005434319434	15675	27	13F
0005434311235	15675	28	14A
0005434319455	15675	29	14D
0005434319502	15675	30	15C
0005434311228	15675	31	15D
0005433124203	15675	32	15E
0005434319423	15675	33	16A
0005434319475	15675	34	16C
0005434319478	15675	35	16D
0005433124210	15675	36	17D
0005434312319	15675	37	17F
0005434319401	15675	38	18A
0005434319525	15675	39	18E
0005433124218	15675	40	19E
0005434311232	15675	41	19F
0005434319506	15675	42	20D
0005434319499	15675	43	20F
0005435219230	31752	1	3B
0005435220347	31752	2	4C
0005435220349	31752	3	5D
0005435219227	31752	4	7A
0005435220348	31752	5	18A
0005435219229	31752	6	19A
0005435220346	31752	7	19B
0005435219228	31752	8	20B
0005434484434	8960	1	1C
0005434189204	8960	2	4B
0005434484437	8960	3	6A
0005434484436	8960	4	7A
0005434189220	8960	5	18D
0005434484439	8960	6	19A
0005434189219	8960	7	20B
0005434189180	8960	8	20C
0005434484438	8960	9	20D
0005434189179	8960	10	21B
0005434484435	8960	11	21C
0005434189218	8960	12	22B
0005434484433	8960	13	23B
0005434189253	16622	1	20D
0005434484367	16622	2	1B
0005434189257	16622	3	1D
0005434484355	16622	4	2B
0005434484366	16622	5	4A
0005434484335	16622	6	4C
0005434484391	16622	7	4D
0005434484379	16622	8	5C
0005434484381	16622	9	7D
0005434189254	16622	10	18D
0005434484374	16622	11	19A
0005434189256	16622	12	19D
0005434189258	16622	13	20B
0005434189255	16622	14	21C
0005434484373	16622	15	23A
0005434484378	16622	16	23B
0005433124218	7680	1	11D
0005433124212	7680	2	14C
0005433722276	7680	3	5C
0005433124202	7680	4	6F
0005433722256	7680	5	9E
0005433722243	7680	6	7E
0005433722252	7680	7	14E
0005433124214	7680	8	7C
0005433124216	7680	9	10D
0005433124206	7680	10	1A
0005433722275	7680	11	14A
0005433124217	7680	12	16C
0005433722233	7680	13	17A
0005433124213	7680	14	13F
0005433124211	7680	15	17D
0005433124207	7680	16	10A
0005433124215	7680	17	18A
0005433722239	7680	18	7D
0005433722232	7680	19	2A
0005433124210	7680	20	19E
0005433124209	7680	21	1C
0005433722244	7680	22	16F
0005433124208	7680	23	8E
0005433722242	7680	24	7F
0005433722246	7680	25	2C
0005433124203	7680	26	3F
0005433722240	7680	27	12D
0005433722254	7680	28	18F
0005433124205	7680	29	3C
0005433124204	7680	30	11E
0005433722241	7680	31	6C
0005433722255	7680	32	5A
0005433722249	7680	33	19D
0005433722274	7680	34	6D
0005432721262	7679	1	9D
0005432721270	7679	2	9E
0005432721254	7679	3	10A
0005433450263	7679	4	10C
0005432693478	7679	5	10D
0005432693486	7679	6	10E
0005432693489	7679	7	10F
0005433450262	7679	8	11A
0005432721272	7679	9	11C
0005432693500	7679	10	11D
0005433450258	7679	11	11E
0005433450265	7679	12	11F
0005433450272	7679	13	12A
0005432721269	7679	14	12C
0005432693487	7679	15	12D
0005433450254	7679	16	12E
0005432721265	7679	17	12F
0005433450259	7679	18	13A
0005432693475	7679	19	13D
0005433450256	7679	20	13E
0005432721252	7679	21	14A
0005432721253	7679	22	14C
0005432721263	7679	23	14D
0005433450269	7679	24	14E
0005432693503	7679	25	14F
0005432721259	7679	26	15A
0005432693496	7679	27	15C
0005432721275	7679	28	15D
0005433450264	7679	29	16A
0005432721260	7679	30	15F
0005432693481	7679	31	16C
0005432071614	7679	32	16D
0005432721271	7679	33	16E
0005432721258	7679	34	16F
0005432693480	7679	35	17A
0005432721266	7679	36	17C
0005432693491	7679	37	17D
0005432693494	7679	38	17E
0005432693476	7679	39	17F
0005433450260	7679	40	18A
0005432071615	7679	41	18C
0005432693483	7679	42	18D
0005433450268	7679	43	18E
0005432693506	7679	44	18F
0005433450255	7679	45	19A
0005432693474	7679	46	19C
0005433450261	7679	47	19D
0005432693504	7679	48	19E
0005432071613	7679	49	19F
0005433450252	7679	50	20C
0005433450253	7679	51	20A
0005432693488	7679	52	20F
0005432693479	7679	53	13C
0005432693499	7679	54	1C
0005433450257	7679	55	1D
0005433450267	7679	56	1F
0005432721276	7679	57	2A
0005432693497	7679	58	2C
0005432693492	7679	59	2D
0005432721257	7679	60	2F
0005432721261	7679	61	3A
0005433450273	7679	62	3D
0005432693484	7679	63	3F
0005432721274	7679	64	4A
0005432693501	7679	65	4C
0005432721255	7679	66	4D
0005433450266	7679	67	4E
0005432721256	7679	68	4F
0005433450271	7679	69	5A
0005432693493	7679	70	5D
0005432693485	7679	71	5E
0005432721277	7679	72	5F
0005432721279	7679	73	6A
0005432693498	7679	74	6C
0005432693495	7679	75	6E
0005432721264	7679	76	6F
0005432693505	7679	77	7A
0005432693502	7679	78	7C
0005432721273	7679	79	7F
0005432693490	7679	80	8A
0005432721268	7679	81	8C
0005433450270	7679	82	8D
0005432721267	7679	83	8E
0005432721278	7679	84	8F
0005432693482	7679	85	9A
0005432693477	7679	86	9C
0005432693198	30355	1	14D
0005432693125	30355	2	2A
0005432693255	30355	3	4C
0005432693055	30355	4	8C
0005433450036	30355	5	18C
0005432693200	30355	6	2F
0005433449987	30355	7	7E
0005433450056	30355	8	6F
0005433450057	30355	9	10F
0005432693227	30355	10	4A
0005433450070	30355	11	12A
0005433450034	30355	12	17F
0005433450100	30355	13	5F
0005432693282	30355	14	11C
0005432693193	30355	15	17C
0005433449996	30355	16	17A
0005432693174	30355	17	18D
0005433449964	30355	18	19E
0005433450022	30355	19	2D
0005433450035	30355	20	14C
0005433449997	30355	21	7D
0005432693337	30355	22	3D
0005433450091	30355	23	6E
0005432693146	30355	24	15D
0005433450111	30355	25	19F
0005432693283	30355	26	7A
0005432693240	30355	27	20F
0005432693339	30355	28	11D
0005432693071	30355	29	1C
0005432693124	30355	30	9E
0005433450132	30355	31	10C
0005433450127	30355	32	6C
0005433450081	30355	33	12C
0005432693162	30355	34	15F
0005432693336	30355	35	9C
0005432693239	30355	36	4F
0005432693254	30355	37	5D
0005433450126	30355	38	20D
0005432693016	30355	39	5A
0005432693075	30355	40	6D
0005433450092	30355	41	8A
0005432693120	30355	42	3A
0005432693290	30355	43	19D
0005432693228	30355	44	18A
0005433450053	30355	45	9A
0005433450093	30355	46	5E
0005433450136	30355	47	11E
0005432693056	30355	48	14F
0005432693017	30355	49	13F
0005432693126	30355	50	14E
0005433450115	30355	51	16A
0005432693199	30355	52	10A
0005433450074	30355	53	5C
0005432693119	30355	54	6A
0005432693145	30355	55	4D
0005432693184	30355	56	12E
0005432693064	30355	57	15E
0005432693059	30355	58	7F
0005432693197	30355	59	10E
0005433450069	30355	60	20E
0005432693201	30355	61	3F
0005432693325	30355	62	9F
0005432721147	30356	1	2F
0005432721096	30356	2	3C
0005433722311	30356	3	3D
0005433722312	30356	4	4A
0005432720980	30356	5	4C
0005433123954	30356	6	4D
0005432721033	30356	7	4E
0005432721115	30356	8	5E
0005432721070	30356	9	6C
0005432720895	30356	10	6D
0005432720981	30356	11	6F
0005432720997	30356	12	7A
0005433123941	30356	13	7D
0005432721114	30356	14	9A
0005432721053	30356	15	9C
0005432721088	30356	16	9D
0005432720946	30356	17	10D
0005432721165	30356	18	11A
0005433123871	30356	19	12D
0005433123955	30356	20	12F
0005432720931	30356	21	13D
0005433124013	30356	22	13E
0005432721028	30356	23	14A
0005433722313	30356	24	14C
0005433123924	30356	25	14D
0005433722310	30356	26	14F
0005432721102	30356	27	15A
0005433722309	30356	28	15C
0005433124002	30356	29	15D
0005433123990	30356	30	16A
0005433123991	30356	31	16C
0005432720950	30356	32	16D
0005433124001	30356	33	16F
0005433123940	30356	34	17D
0005433123996	30356	35	18C
0005432721101	30356	36	18D
0005432721034	30356	37	18F
0005432721098	30356	38	19D
0005432721120	30356	39	19F
0005433124064	30356	40	20A
0005432721119	30356	41	20D
0005433124063	30356	42	1A
0005432721071	30356	43	1C
0005433124012	30356	44	2A
0005432721045	30356	45	2D
0005432968861	1390	1	9C
0005433724868	1390	2	1A
0005434586947	1390	3	1C
0005434586972	1390	4	1D
0005433525191	1390	5	2A
0005432928000	1390	6	2C
0005434513614	1390	7	2D
0005434586946	1390	8	2F
0005432271044	1390	9	3A
0005432271042	1390	10	3C
0005432928016	1390	11	3D
0005433525183	1390	12	3F
0005434586971	1390	13	4A
0005433193163	1390	14	4C
0005432271041	1390	15	4D
0005434586960	1390	16	4F
0005433193157	1390	17	5A
0005432927999	1390	18	5D
0005434586949	1390	19	5E
0005432271043	1390	20	5F
0005434586958	1390	21	6A
0005434586970	1390	22	6C
0005433193117	1390	23	6E
0005432928015	1390	24	7A
0005433724867	1390	25	7C
0005433193178	1390	26	7D
0005433525186	1390	27	7E
0005434515003	1390	28	7F
0005432928017	1390	29	8A
0005434586969	1390	30	8E
0005432928037	1390	31	9A
0005434586959	1390	32	9F
0005433193175	1390	33	10A
0005433525182	1390	34	10C
0005434586961	1390	35	10E
0005434586956	1390	36	10F
0005433525190	1390	37	11A
0005433724865	1390	38	11C
0005433724869	1390	39	11D
0005434513616	1390	40	11E
0005434513615	1390	41	12A
0005434586955	1390	42	12C
0005434586952	1390	43	12D
0005433525189	1390	44	12E
0005432927991	1390	45	13A
0005433525184	1390	46	13C
0005434586967	1390	47	14C
0005433193177	1390	48	14E
0005433193176	1390	49	14F
0005434586963	1390	50	15C
0005434586957	1390	51	15E
0005434586954	1390	52	16C
0005433193116	1390	53	16D
0005433193133	1390	54	16E
0005434586968	1390	55	16F
0005433525187	1390	56	17A
0005434586962	1390	57	17C
0005434586964	1390	58	17D
0005434586965	1390	59	17E
0005432928018	1390	60	17F
0005434586966	1390	61	18A
0005432968855	1390	62	18C
0005434586950	1390	63	18D
0005434586953	1390	64	18E
0005433525188	1390	65	18F
0005433525185	1390	66	19A
0005434586973	1390	67	19C
0005433193115	1390	68	19D
0005433724866	1390	69	19E
0005434586948	1390	70	19F
0005433193162	1390	71	20A
0005434586951	1390	72	20C
0005434515002	1390	73	20E
0005432928055	18524	1	1A
0005434586761	18524	2	1C
0005433193221	18524	3	1D
0005434586767	18524	4	1F
0005432928056	18524	5	2A
0005433193229	18524	6	2C
0005433525062	18524	7	2D
0005434586788	18524	8	2F
0005434586786	18524	9	3A
0005433193220	18524	10	3C
0005434586798	18524	11	3D
0005433193231	18524	12	4C
0005434586704	18524	13	4D
0005434586636	18524	14	4E
0005434586668	18524	15	4F
0005433525071	18524	16	5A
0005434586696	18524	17	5C
0005434586919	18524	18	5D
0005434586762	18524	19	5E
0005434586758	18524	20	5F
0005433193219	18524	21	6A
0005434586772	18524	22	6C
0005433193224	18524	23	6D
0005434586706	18524	24	6E
0005434586722	18524	25	6F
0005433525077	18524	26	7A
0005434586805	18524	27	7D
0005433193227	18524	28	7E
0005434586837	18524	29	7F
0005434586718	18524	30	8A
0005433525109	18524	31	8C
0005434586787	18524	32	8D
0005432968870	18524	33	8E
0005434586839	18524	34	9D
0005434586756	18524	35	9E
0005432928053	18524	36	9F
0005434586773	18524	37	10A
0005433525057	18524	38	10C
0005432928054	18524	39	10D
0005432968871	18524	40	10E
0005432928052	18524	41	10F
0005433724839	18524	42	11D
0005433525087	18524	43	11E
0005434586918	18524	44	12A
0005433525130	18524	45	12E
0005433193223	18524	46	12F
0005434586759	18524	47	13A
0005433193232	18524	48	13C
0005434586838	18524	49	13D
0005434586697	18524	50	13E
0005434586723	18524	51	13F
0005433525066	18524	52	14A
0005434586717	18524	53	14C
0005433724841	18524	54	14D
0005434586623	18524	55	14F
0005433525080	18524	56	15A
0005433193230	18524	57	15C
0005433525063	18524	58	15E
0005434586757	18524	59	15F
0005433193228	18524	60	16D
0005433525067	18524	61	16E
0005433193226	18524	62	17A
0005433525079	18524	63	17D
0005434586797	18524	64	17E
0005433525081	18524	65	18A
0005433525078	18524	66	18D
0005433193225	18524	67	18E
0005434586792	18524	68	18F
0005433724840	18524	69	19A
0005433193222	18524	70	19C
0005434586690	18524	71	19D
0005434586760	18524	72	19E
0005434514971	18524	73	19F
0005433525108	18524	74	20A
0005433724815	18524	75	20D
0005434514985	18524	76	20E
0005435302218	11472	1	1A
0005434142662	11472	2	1B
0005434344664	11472	3	1C
0005434344654	11472	4	1D
0005434344661	11472	5	2A
0005435302203	11472	6	2B
0005434344668	11472	7	2C
0005434344660	11472	8	2D
0005434344641	11472	9	3A
0005434344639	11472	10	3B
0005434344657	11472	11	3D
0005434344650	11472	12	4A
0005434344649	11472	13	4B
0005434344663	11472	14	4C
0005434344670	11472	15	4D
0005434344659	11472	16	5B
0005434344656	11472	17	5C
0005434344655	11472	18	5D
0005434344666	11472	19	6B
0005435305014	11472	20	6A
0005435302202	11472	21	6C
0005434142663	11472	22	6D
0005434344667	11472	23	7A
0005434344653	11472	24	7B
0005434142664	11472	25	7C
0005434344643	11472	26	7D
0005434344671	11472	27	18A
0005434344637	11472	28	18B
0005434344669	11472	29	18C
0005434344648	11472	30	18D
0005435305015	11472	31	19A
0005434344658	11472	32	19B
0005434344652	11472	33	19C
0005434344651	11472	34	19D
0005434344640	11472	35	20A
0005434344638	11472	36	20B
0005434344645	11472	37	20C
0005434344642	11472	38	20D
0005434344646	11472	39	21A
0005434344665	11472	40	21B
0005434344662	11472	41	21C
0005434142665	11472	42	21D
0005435302212	11472	43	22A
0005434344644	11472	44	22B
0005434344672	11472	45	22C
0005434344673	11472	46	22D
0005434344647	11472	47	23A
0005435302205	11472	48	23B
0005435305041	29784	1	1A
0005434344379	29784	2	1B
0005434142628	29784	3	1C
0005435305042	29784	4	1D
0005435304219	29784	5	2C
0005434344358	29784	6	2D
0005435304220	29784	7	3A
0005435304221	29784	8	3B
0005434344211	29784	9	3C
0005434344486	29784	10	4B
0005434344481	29784	11	4C
0005434344354	29784	12	4D
0005434344169	29784	13	5A
0005434344326	29784	14	5B
0005434142627	29784	15	5D
0005434344511	29784	16	6B
0005434344245	29784	17	6D
0005435304218	29784	18	7B
0005434142613	29784	19	7C
0005434344239	29784	20	7D
0005434344321	29784	21	18C
0005434344378	29784	22	19A
0005434344458	29784	23	19B
0005434344325	29784	24	19D
0005434344352	29784	25	20A
0005434344377	29784	26	20B
0005434344423	29784	27	20C
0005434344271	29784	28	20D
0005434142626	29784	29	21A
0005434344272	29784	30	21B
0005434344376	29784	31	21C
0005434142614	29784	32	22A
0005435304222	29784	33	22B
0005434344436	29784	34	22C
0005434344212	29784	35	22D
0005434344435	29784	36	23A
0005434344307	29784	37	23B
0005435824996	1304	1	13B
0005435824808	17974	1	1C
0005435824711	17974	2	1A
0005435824695	17974	3	1F
0005433415872	17974	4	2A
0005435824778	17974	5	2F
0005435824672	17974	6	3D
0005435824675	17974	7	3C
0005435824694	17974	8	4D
0005435824693	17974	9	4A
0005433415874	17974	10	4F
0005433415879	17974	11	5D
0005435824769	17974	12	5C
0005433415875	17974	13	6A
0005433415880	17974	14	6B
0005435824799	17974	15	7A
0005435824732	17974	16	7C
0005433415884	17974	17	7D
0005435824742	17974	18	8D
0005433415878	17974	19	8C
0005433415871	17974	20	8E
0005433415882	17974	21	9C
0005435824751	17974	22	9B
0005435824682	17974	23	9E
0005435824777	17974	24	9F
0005435824749	17974	25	11B
0005433415873	17974	26	11A
0005433415883	17974	27	11F
0005435824671	17974	28	13A
0005435824771	17974	29	13C
0005435824681	17974	30	13D
0005433415870	17974	31	15B
0005435824791	17974	32	15A
0005435824721	17974	33	15E
0005435824743	17974	34	15F
0005435824775	17974	35	16C
0005435824727	17974	36	16E
0005435824826	17974	37	16D
0005435824770	17974	38	17A
0005435824744	17974	39	17C
0005433415876	17974	40	17F
0005435824859	17974	41	17E
0005435824720	17974	42	18A
0005435824798	17974	43	18F
0005435824700	17974	44	19C
0005433415881	17974	45	19E
0005433415877	17974	46	20A
0005435824701	17974	47	20C
0005435824846	17974	48	20E
0005435824844	17974	49	21B
0005433415869	17974	50	21A
0005435824845	17974	51	21D
0005435824802	17974	52	21F
0005432784517	5666	1	7F
0005432784530	5666	2	1A
0005432144030	5666	3	1C
0005435242995	5666	4	1D
0005435243153	5666	5	1F
0005432784529	5666	6	2A
0005435242903	5666	7	2C
0005435476767	5666	8	2D
0005432784512	5666	9	2F
0005432784513	5666	10	3A
0005435476774	5666	11	3C
0005435476802	5666	12	3D
0005432784526	5666	13	3F
0005432784500	5666	14	4A
0005435476791	5666	15	4C
0005432784537	5666	16	4D
0005432784535	5666	17	4E
0005432784540	5666	18	4F
0005435242951	5666	19	5A
0005432784521	5666	20	5C
0005432784522	5666	21	5D
0005432784515	5666	22	5E
0005432784541	5666	23	5F
0005435242912	5666	24	6A
0005432784519	5666	25	6C
0005435242919	5666	26	6D
0005435476781	5666	27	6E
0005435242984	5666	28	6F
0005432784518	5666	29	7A
0005432144032	5666	30	7D
0005435242960	5666	31	7C
0005435476765	5666	32	7E
0005435242901	5666	33	8A
0005435242994	5666	34	8C
0005432784516	5666	35	8D
0005432784543	5666	36	8E
0005435242996	5666	37	8F
0005435242862	5666	38	9A
0005432784527	5666	39	9C
0005432784544	5666	40	9D
0005432784508	5666	41	9E
0005432784511	5666	42	9F
0005435242886	5666	43	10A
0005432784533	5666	44	10C
0005435476775	5666	45	10D
0005435476779	5666	46	10E
0005432784520	5666	47	10F
0005432784524	5666	48	11A
0005435476789	5666	49	11C
0005432784534	5666	50	11D
0005432784506	5666	51	11E
0005435476801	5666	52	11F
0005435242933	5666	53	12A
0005432784531	5666	54	12C
0005435243020	5666	55	12D
0005435476821	5666	56	12E
0005432144031	5666	57	12F
0005432784525	5666	58	13C
0005432784538	5666	59	13D
0005432784497	5666	60	13E
0005432784503	5666	61	13F
0005432784542	5666	62	14A
0005432784491	5666	63	14C
0005435242863	5666	64	14D
0005432784539	5666	65	14E
0005435242985	5666	66	14F
0005435242802	5666	67	15A
0005432784509	5666	68	15C
0005432784505	5666	69	15D
0005432784514	5666	70	15E
0005432784501	5666	71	15F
0005435476807	5666	72	16A
0005432784495	5666	73	16C
0005432784523	5666	74	16D
0005432784498	5666	75	16E
0005435242902	5666	76	16F
0005435242952	5666	77	17A
0005435476820	5666	78	17C
0005432784528	5666	79	17D
0005432784507	5666	80	17E
0005435476764	5666	81	17F
0005432784504	5666	82	18A
0005432784546	5666	83	18C
0005432784510	5666	84	18E
0005435476773	5666	85	18F
0005435242907	5666	86	19A
0005432784492	5666	87	19C
0005432784496	5666	88	19D
0005432784532	5666	89	19E
0005432784493	5666	90	19F
0005432784536	5666	91	20A
0005432784494	5666	92	20C
0005432784502	5666	93	20D
0005432784545	5666	94	20E
0005432784499	5666	95	20F
0005432784101	15338	1	1C
0005435243195	15338	2	1D
0005432783446	15338	3	1F
0005432784013	15338	4	2A
0005432784098	15338	5	2C
0005432784086	15338	6	2D
0005435243196	15338	7	2F
0005432784068	15338	8	3A
0005432784165	15338	9	3C
0005432783784	15338	10	3D
0005435243191	15338	11	3F
0005435243206	15338	12	4A
0005432784079	15338	13	4C
0005432784122	15338	14	4D
0005432784014	15338	15	4E
0005432783866	15338	16	5A
0005432784113	15338	17	1A
0005432784090	15338	18	4F
0005435243189	15338	19	5C
0005435243185	15338	20	5D
0005432784040	15338	21	5E
0005435243193	15338	22	5F
0005432784232	15338	23	6A
0005432783830	15338	24	6C
0005432783931	15338	25	6D
0005435243197	15338	26	6E
0005432783783	15338	27	6F
0005432784096	15338	28	7A
0005432783853	15338	29	7C
0005432784099	15338	30	7D
0005432784091	15338	31	7E
0005432783742	15338	32	7F
0005432783909	15338	33	8A
0005432783844	15338	34	8C
0005432783940	15338	35	8D
0005435243200	15338	36	8E
0005432784102	15338	37	8F
0005432784103	15338	38	9A
0005432784089	15338	39	9C
0005432784100	15338	40	9D
0005435243199	15338	41	9E
0005432784044	15338	42	9F
0005435243190	15338	43	10A
0005432784047	15338	44	10C
0005435243194	15338	45	10D
0005432784227	15338	46	10E
0005432784080	15338	47	10F
0005432784164	15338	48	11A
0005432784161	15338	49	11C
0005435243208	15338	50	11D
0005432783687	15338	51	11E
0005435243188	15338	52	11F
0005435243207	15338	53	12A
0005432783962	15338	54	12C
0005432783987	15338	55	12D
0005432784248	15338	56	12E
0005432784048	15338	57	12F
0005432783971	15338	58	13A
0005432783976	15338	59	13C
0005435243192	15338	60	13D
0005432784121	15338	61	13E
0005432784094	15338	62	13F
0005435243205	15338	63	14A
0005432783977	15338	64	14C
0005432784039	15338	65	14D
0005432783930	15338	66	14E
0005432783741	15338	67	14F
0005432783880	15338	68	15A
0005432783886	15338	69	15C
0005432783885	15338	70	15D
0005432783831	15338	71	15E
0005432784073	15338	72	15F
0005432783845	15338	73	16A
0005435243187	15338	74	16C
0005432783833	15338	75	16D
0005432783950	15338	76	16E
0005432783923	15338	77	16F
0005432783970	15338	78	17A
0005435243201	15338	79	17C
0005432784074	15338	80	17D
0005432784064	15338	81	17E
0005432783740	15338	82	17F
0005432784097	15338	83	18A
0005432784023	15338	84	18C
0005435243202	15338	85	18D
0005435243204	15338	86	18E
0005432784112	15338	87	18F
0005435243186	15338	88	19A
0005432784088	15338	89	19C
0005432783967	15338	90	19D
0005432784087	15338	91	19E
0005432783943	15338	92	19F
0005435243198	15338	93	20A
0005432784043	15338	94	20D
0005432784027	15338	95	20E
0005435243203	15338	96	20F
0005432848504	4376	1	2A
0005432848507	4376	2	2B
0005432848502	4376	3	2C
0005434463957	4376	4	2D
0005434463958	4376	5	3A
0005432848513	4376	6	3D
0005435850985	4376	7	4A
0005435850955	4376	8	4C
0005434463960	4376	9	4D
0005432848508	4376	10	5B
0005434462820	4376	11	6A
0005432848510	4376	12	6C
0005434463959	4376	13	7A
0005432848505	4376	14	7B
0005435850998	4376	15	19A
0005435850996	4376	16	20A
0005435850918	4376	17	20B
0005434462819	4376	18	20C
0005435850970	4376	19	20D
0005432848503	4376	20	21A
0005432848506	4376	21	22A
0005432848512	4376	22	22B
0005432848514	4376	23	22C
0005432848509	4376	24	22D
0005432848511	4376	25	23A
0005435851032	28877	1	21B
0005432848408	28877	2	1A
0005435851031	28877	3	2B
0005435851036	28877	4	2C
0005432848379	28877	5	2D
0005432848411	28877	6	3A
0005432848375	28877	7	3C
0005432848383	28877	8	3D
0005435851033	28877	9	4D
0005432848393	28877	10	5B
0005435851037	28877	11	5D
0005434461645	28877	12	6B
0005435851034	28877	13	6D
0005435851035	28877	14	7D
0005432848396	28877	15	18A
0005435851029	28877	16	20C
0005432848354	28877	17	20D
0005432848376	28877	18	21C
0005432848324	28877	19	21D
0005432848352	28877	20	22A
0005435851030	28877	21	22D
0005432848384	28877	22	23A
0005432848378	28877	23	23B
0005433497386	6312	1	9D
0005434443925	6312	2	1C
0005434443926	6312	3	1D
0005434926243	6312	4	2A
0005434926230	6312	5	2D
0005434926235	6312	6	2F
0005434926240	6312	7	3A
0005434926244	6312	8	3C
0005434926234	6312	9	3F
0005434926238	6312	10	4A
0005434926228	6312	11	4C
0005434926231	6312	12	4D
0005434926246	6312	13	4F
0005433497399	6312	14	5A
0005433497379	6312	15	5C
0005433497408	6312	16	5D
0005433497398	6312	17	5E
0005434926241	6312	18	5F
0005434926252	6312	19	6A
0005434926224	6312	20	6D
0005434443932	6312	21	6E
0005433497381	6312	22	6F
0005434926232	6312	23	7A
0005432075278	6312	24	7D
0005432075276	6312	25	7E
0005434926226	6312	26	7F
0005433497394	6312	27	8A
0005433497392	6312	28	8C
0005434443921	6312	29	8E
0005434443935	6312	30	8F
0005434443929	6312	31	9A
0005433497401	6312	32	9C
0005433497383	6312	33	1A
0005434443934	6312	34	9E
0005434926229	6312	35	9F
0005433497407	6312	36	10A
0005433497400	6312	37	10C
0005434443920	6312	38	10D
0005433497387	6312	39	10E
0005434443927	6312	40	10F
0005433497393	6312	41	11A
0005433497406	6312	42	11D
0005433497395	6312	43	11E
0005434443933	6312	44	11F
0005433497403	6312	45	12A
0005434443924	6312	46	12C
0005433497405	6312	47	12D
0005434926222	6312	48	12E
0005433497397	6312	49	12F
0005433497388	6312	50	13A
0005434926247	6312	51	13C
0005434443930	6312	52	13D
0005434926236	6312	53	13F
0005433497385	6312	54	14C
0005434926245	6312	55	14D
0005434926249	6312	56	14E
0005433497404	6312	57	14F
0005433497389	6312	58	15A
0005434926248	6312	59	15C
0005434926237	6312	60	15D
0005433497382	6312	61	15E
0005434443923	6312	62	15F
0005434926242	6312	63	16A
0005434443931	6312	64	16C
0005434443928	6312	65	16F
0005434926225	6312	66	17A
0005433497396	6312	67	17C
0005433497409	6312	68	17D
0005434926223	6312	69	17E
0005433497384	6312	70	17F
0005433497390	6312	71	18A
0005432075277	6312	72	18C
0005434443922	6312	73	18E
0005434926250	6312	74	18F
0005433497378	6312	75	19C
0005434926239	6312	76	19D
0005434926227	6312	77	19F
0005433497380	6312	78	20A
0005434926251	6312	79	20C
0005433497402	6312	80	20D
0005433497391	6312	81	20E
0005434926233	6312	82	20F
0005433497140	20402	1	8C
0005433497065	20402	2	1C
0005433497216	20402	3	12E
0005434925925	20402	4	6C
0005434925927	20402	5	15D
0005434925876	20402	6	20C
0005434925841	20402	7	7D
0005433497183	20402	8	13C
0005434925938	20402	9	9A
0005433497087	20402	10	13E
0005433497076	20402	11	4D
0005433497084	20402	12	12F
0005433497223	20402	13	9D
0005434443857	20402	14	17C
0005434443784	20402	15	2D
0005434925869	20402	16	2A
0005434925914	20402	17	5E
0005433497093	20402	18	2C
0005434925928	20402	19	15F
0005434443804	20402	20	10A
0005434925937	20402	21	18D
0005433497094	20402	22	17A
0005434925950	20402	23	3A
0005433497225	20402	24	12A
0005434925870	20402	25	20E
0005433497224	20402	26	19D
0005433497157	20402	27	9E
0005434443729	20402	28	19C
0005433497219	20402	29	18A
0005434925877	20402	30	4F
0005434925881	20402	31	20D
0005434925795	20402	32	15A
0005434925917	20402	33	2F
0005433497260	20402	34	13A
0005434443762	20402	35	12C
0005433497163	20402	36	4E
0005434925952	20402	37	11A
0005434925953	20402	38	3F
0005434443760	20402	39	6D
0005434925843	20402	40	15E
0005433497044	20402	41	8D
0005433497091	20402	42	8F
0005433497116	20402	43	16E
0005434925954	20402	44	15C
0005434925880	20402	45	14E
0005434443773	20402	46	10D
0005433497220	20402	47	10C
0005434925840	20402	48	6F
0005434443701	20402	49	7F
0005434925861	20402	50	18E
0005434443774	20402	51	13F
0005434443772	20402	52	14F
0005433497043	20402	53	7C
0005434925868	20402	54	9C
0005434925934	20402	55	14A
0005434925884	20402	56	4A
0005434925929	20402	57	16C
0005434925842	20402	58	1F
0005434925956	20402	59	5C
0005434925955	20402	60	14C
0005433497130	20402	61	18C
0005434925935	20402	62	8A
0005433497129	20402	63	11E
0005433497169	20402	64	13D
0005434925844	20402	65	16A
0005433497117	20402	66	5F
0005433497066	20402	67	11C
0005434925957	20402	68	19A
0005433497089	20402	69	7E
0005434443826	20402	70	17F
0005434443829	20402	71	1A
0005433497172	20402	72	3C
0005434925911	20402	73	14D
0005433497055	20402	74	18F
0005434925926	20402	75	6A
0005434443771	20402	76	3D
0005433497003	20402	77	10F
0005433497141	20402	78	17E
0005433497158	20402	79	19F
0005433497230	20402	80	20A
0005434443769	20402	81	17D
0005434443803	20402	82	5A
0005434443761	20402	83	7A
0005433497004	20402	84	20F
0005434925875	20402	85	11F
0005433497170	20402	86	19E
0005433497088	20402	87	8E
0005435243216	12185	1	12F
0005432784052	12185	2	13A
0005432784216	12185	3	2D
0005432783903	12185	4	4F
0005432783822	12185	5	14F
0005435243229	12185	6	16E
0005432784035	12185	7	5D
0005435243223	12185	8	20F
0005432784034	12185	9	13E
0005435243211	12185	10	17C
0005432784133	12185	11	16D
0005432784242	12185	12	15A
0005435243220	12185	13	20A
0005432784142	12185	14	10F
0005432783912	12185	15	11C
0005435243234	12185	16	18F
0005435243228	12185	17	19C
0005432784018	12185	18	6F
0005432784153	12185	19	4E
0005432784214	12185	20	10E
0005432783965	12185	21	15D
0005432784235	12185	22	6E
0005432784240	12185	23	17D
0005435243225	12185	24	11F
0005435243209	12185	25	12E
0005432783937	12185	26	19A
0005432783821	12185	27	9C
0005432783862	12185	28	9A
0005432784239	12185	29	15F
0005432784115	12185	30	12A
0005432784155	12185	31	7C
0005435243235	12185	32	13D
0005435243221	12185	33	10D
0005432783910	12185	34	17E
0005435243210	12185	35	19D
0005432784045	12185	36	18D
0005435243231	12185	37	18E
0005432783999	12185	38	14D
0005432783966	12185	39	17F
0005432784030	12185	40	5C
0005432783905	12185	41	15E
0005435243213	12185	42	5E
0005435243215	12185	43	5A
0005435243212	12185	44	4A
0005432783961	12185	45	14A
0005432783990	12185	46	6D
0005432784129	12185	47	20E
0005432784143	12185	48	19E
0005432784215	12185	49	16C
0005432784236	12185	50	8F
0005432783839	12185	51	13F
0005432784130	12185	52	10A
0005432783904	12185	53	1D
0005432784300	12185	54	7A
0005432783838	12185	55	11A
0005432784000	12185	56	18C
0005432784076	12185	57	1C
0005432784085	12185	58	11D
0005435243214	12185	59	9F
0005435243226	12185	60	10C
0005432784279	12185	61	6A
0005432783911	12185	62	12D
0005432784059	12185	63	4C
0005432784081	12185	64	8A
0005432783863	12185	65	16F
0005432784009	12185	66	6C
0005432784037	12185	67	13C
0005432784093	12185	68	3D
0005432784053	12185	69	14C
0005435243222	12185	70	17A
0005432784152	12185	71	9E
0005435243219	12185	72	12C
0005435243237	12185	73	3C
0005435243218	12185	74	1A
0005432784058	12185	75	7D
0005435243224	12185	76	2F
0005432784114	12185	77	11E
0005432783989	12185	78	8C
0005435243232	12185	79	3A
0005432784241	12185	80	15C
0005432784154	12185	81	8E
0005432784036	12185	82	14E
0005435243217	12185	83	2C
0005432784140	12185	84	20D
0005432783913	12185	85	8D
0005432784038	12185	86	20C
0005435243227	12185	87	2A
0005432784078	12185	88	3F
0005435243233	12185	89	4D
0005435243236	12185	90	7E
0005432784029	12185	91	16A
0005435243230	12185	92	5F
0005432784464	15442	1	18E
0005435242896	15442	2	18F
0005435242926	15442	3	19A
0005432784451	15442	4	19D
0005432784489	15442	5	19E
0005432784443	15442	6	19F
0005432784469	15442	7	20A
0005432784473	15442	8	15F
0005432784461	15442	9	20D
0005432784471	15442	10	1A
0005432784480	15442	11	1D
0005435243001	15442	12	1F
0005432784487	15442	13	2C
0005435242897	15442	14	2F
0005432784444	15442	15	3A
0005432784475	15442	16	3C
0005432784467	15442	17	3D
0005432784440	15442	18	3F
0005432784472	15442	19	4A
0005432784468	15442	20	4D
0005432784453	15442	21	4E
0005435242866	15442	22	4F
0005435242979	15442	23	5A
0005432784462	15442	24	5C
0005435243002	15442	25	5D
0005432784479	15442	26	5E
0005432784485	15442	27	5F
0005432784448	15442	28	6A
0005435243033	15442	29	6C
0005435242827	15442	30	6D
0005432784452	15442	31	6E
0005432784447	15442	32	6F
0005432784442	15442	33	7A
0005435242888	15442	34	7C
0005432784456	15442	35	7D
0005432784458	15442	36	7F
0005432784454	15442	37	8A
0005432784436	15442	38	8D
0005435242780	15442	39	8F
0005432784476	15442	40	9C
0005435242925	15442	41	9D
0005432784441	15442	42	9F
0005432784488	15442	43	10A
0005435242852	15442	44	10C
0005432784477	15442	45	10D
0005432784445	15442	46	10E
0005435243000	15442	47	11A
0005432784465	15442	48	11C
0005432784483	15442	49	11D
0005432784490	15442	50	11E
0005432784482	15442	51	11F
0005435242889	15442	52	12A
0005432784450	15442	53	12C
0005432784449	15442	54	12D
0005432784470	15442	55	12E
0005432784484	15442	56	12F
0005432784486	15442	57	13A
0005432784463	15442	58	13C
0005432784481	15442	59	13E
0005435242898	15442	60	13F
0005435243034	15442	61	14A
0005432784466	15442	62	14C
0005432784437	15442	63	14D
0005432784446	15442	64	14E
0005432784438	15442	65	14F
0005432784439	15442	66	15D
0005435242853	15442	67	15E
0005435242887	15442	68	16C
0005435242828	15442	69	16D
0005432784460	15442	70	16E
0005432784474	15442	71	16F
0005432784457	15442	72	17A
0005432784455	15442	73	17C
0005432784478	15442	74	17D
0005435242826	15442	75	17E
0005432784459	15442	76	18A
0005435242867	15442	77	18D
0005434878764	10110	1	6E
0005434878566	10110	2	1C
0005434878552	10110	3	1A
0005434878580	10110	4	1F
0005434878802	10110	5	1D
0005434878841	10110	6	2A
0005434878692	10110	7	2D
0005434878910	10110	8	2C
0005435913973	10110	9	2F
0005434878602	10110	10	3D
0005434878591	10110	11	3C
0005434878726	10110	12	4A
0005434878833	10110	13	3F
0005434878609	10110	14	4D
0005434879053	10110	15	4C
0005434878862	10110	16	4F
0005434878864	10110	17	5C
0005434878719	10110	18	5A
0005435913969	10110	19	5F
0005434878672	10110	20	6B
0005434878607	10110	21	6A
0005434758912	10110	22	6D
0005434878619	10110	23	6C
0005434878353	10110	24	7A
0005434878677	10110	25	6F
0005434758913	10110	26	7B
0005434878598	10110	27	7E
0005434879027	10110	28	7D
0005434878535	10110	29	7F
0005434878832	10110	30	8C
0005434878455	10110	31	8B
0005434878697	10110	32	8A
0005434878606	10110	33	8D
0005435913975	10110	34	9A
0005434879102	10110	35	8F
0005434878831	10110	36	8E
0005434878803	10110	37	9B
0005434878507	10110	38	9D
0005434878615	10110	39	9C
0005434878720	10110	40	9F
0005434877849	10110	41	9E
0005434878735	10110	42	10A
0005434878605	10110	43	10C
0005435913971	10110	44	10B
0005434878616	10110	45	10D
0005434878629	10110	46	11A
0005434878610	10110	47	10F
0005434878491	10110	48	10E
0005434878912	10110	49	11B
0005434878133	10110	50	11E
0005434878576	10110	51	12A
0005434878696	10110	52	12D
0005435913972	10110	53	12C
0005435913974	10110	54	12E
0005434878751	10110	55	13A
0005434878800	10110	56	12F
0005434878228	10110	57	13C
0005434878742	10110	58	13B
0005434878608	10110	59	13E
0005434878830	10110	60	13D
0005435913976	10110	61	13F
0005434878843	10110	62	14C
0005435913970	10110	63	14B
0005434878911	10110	64	14A
0005434878741	10110	65	14D
0005434879023	10110	66	14F
0005434878954	10110	67	14E
0005434878305	10110	68	15B
0005434878935	10110	69	15A
0005434878884	10110	70	15C
0005434878894	10110	71	15E
0005434878842	10110	72	15D
0005434878863	10110	73	16A
0005434910144	10110	74	16C
0005434878578	10110	75	16B
0005434878306	10110	76	16D
0005434879034	10110	77	16E
0005434878166	10110	78	17B
0005434878736	10110	79	17A
0005434878389	10110	80	17D
0005434878581	10110	81	17C
0005434879026	10110	82	17E
0005434878134	10110	83	18B
0005434879022	10110	84	18A
0005434878263	10110	85	18C
0005434878934	10110	86	18F
0005434878766	10110	87	18E
0005434878213	10110	88	19B
0005434878955	10110	89	19C
0005434878642	10110	90	20A
0005434878737	10110	91	19F
0005434878658	10110	92	19E
0005434878553	10110	93	20B
0005434878718	10110	94	20D
0005434878564	10110	95	20C
0005434878691	10110	96	20F
0005434878921	10110	97	20E
0005434878592	10110	98	21A
0005434879054	10110	99	21D
0005434878565	10110	100	21C
0005434878637	10110	101	21B
0005434878538	10110	102	21E
0005434878885	10110	103	21F
0005434879486	14646	1	3C
0005434879471	14646	2	4A
0005434879532	14646	3	3F
0005434879492	14646	4	3D
0005434879504	14646	5	1F
0005434879470	14646	6	4D
0005434879447	14646	7	4C
0005434879523	14646	8	5A
0005434879487	14646	9	4F
0005434879531	14646	10	5C
0005434879484	14646	11	5F
0005434879467	14646	12	5D
0005434879503	14646	13	6B
0005434879507	14646	14	2D
0005434879448	14646	15	6A
0005434879493	14646	16	6D
0005434879498	14646	17	6C
0005434879511	14646	18	6E
0005434879497	14646	19	1C
0005434879457	14646	20	2C
0005434879468	14646	21	7A
0005434879478	14646	22	6F
0005434879505	14646	23	7C
0005434879502	14646	24	7B
0005434879513	14646	25	7F
0005434879481	14646	26	7E
0005434879488	14646	27	8B
0005434879482	14646	28	8D
0005434879463	14646	29	8C
0005434879529	14646	30	8F
0005434879479	14646	31	8E
0005434879472	14646	32	9C
0005434879460	14646	33	9B
0005434879533	14646	34	9F
0005434879462	14646	35	9E
0005434879480	14646	36	9D
0005434879445	14646	37	1A
0005434879530	14646	38	10A
0005434879515	14646	39	10C
0005434879516	14646	40	10B
0005434879465	14646	41	10E
0005434879520	14646	42	10D
0005434879452	14646	43	10F
0005434879485	14646	44	11B
0005434879454	14646	45	11A
0005434879491	14646	46	11F
0005434879510	14646	47	11E
0005434879489	14646	48	12B
0005434879474	14646	49	12A
0005434879443	14646	50	12C
0005434879508	14646	51	12E
0005434879514	14646	52	12D
0005434879469	14646	53	13B
0005434879458	14646	54	12F
0005434879500	14646	55	13C
0005434879518	14646	56	13D
0005434910120	14646	57	14A
0005434879449	14646	58	13E
0005434879477	14646	59	14C
0005434879535	14646	60	14B
0005434879517	14646	61	14F
0005434879528	14646	62	14E
0005434879519	14646	63	15A
0005434879464	14646	64	15D
0005434879446	14646	65	15B
0005434879525	14646	66	1D
0005434879534	14646	67	2A
0005434879490	14646	68	15E
0005434879483	14646	69	16A
0005434879475	14646	70	15F
0005434879455	14646	71	16C
0005434879506	14646	72	16B
0005434879496	14646	73	17A
0005434879521	14646	74	16E
0005434879499	14646	75	17B
0005434879509	14646	76	17D
0005434879451	14646	77	17C
0005434879512	14646	78	17F
0005434758925	14646	79	17E
0005434879522	14646	80	18B
0005434879476	14646	81	18A
0005434879450	14646	82	18E
0005434879444	14646	83	18F
0005434879442	14646	84	19C
0005434879527	14646	85	19B
0005434879526	14646	86	19E
0005434879456	14646	87	19D
0005434879501	14646	88	19F
0005434879461	14646	89	20B
0005434879524	14646	90	20A
0005434879494	14646	91	20D
0005434879537	14646	92	20C
0005434879473	14646	93	20E
0005434879536	14646	94	21B
0005434879453	14646	95	21A
0005434758924	14646	96	21E
0005434879495	14646	97	21F
0005434879466	14646	98	3A
0005434879459	14646	99	2F
0005435660292	9252	1	19A
0005434251970	9252	2	1B
0005435660288	9252	3	1D
0005434252020	9252	4	2B
0005434252016	9252	5	2D
0005434252036	9252	6	3B
0005435660286	9252	7	3C
0005435660293	9252	8	3D
0005435660282	9252	9	4C
0005434251994	9252	10	4D
0005435660285	9252	11	5A
0005434252037	9252	12	5B
0005435660289	9252	13	6A
0005434252021	9252	14	18B
0005435660284	9252	15	18C
0005435660287	9252	16	19B
0005435660291	9252	17	20D
0005435660290	9252	18	21C
0005434252035	9252	19	22C
0005435660283	9252	20	23A
0005434252094	24627	1	1D
0005435660188	24627	2	2A
0005434252091	24627	3	2C
0005435660204	24627	4	3C
0005434252090	24627	5	5B
0005435660187	24627	6	5C
0005434252088	24627	7	5D
0005435660186	24627	8	7A
0005435660160	24627	9	7D
0005434252096	24627	10	18C
0005435660212	24627	11	19A
0005435660207	24627	12	19B
0005435660168	24627	13	19C
0005434252089	24627	14	19D
0005435660169	24627	15	1A
0005435660211	24627	16	20B
0005435660159	24627	17	20C
0005434252095	24627	18	20D
0005434252087	24627	19	21B
0005434252093	24627	20	22C
0005434252092	24627	21	23B
0005435660208	24627	22	1B
0005433681217	2774	1	6F
0005433681220	2774	2	7A
0005433681180	2774	3	7D
0005432967054	2774	4	7E
0005433681179	2774	5	8A
0005432967088	2774	6	8C
0005433681219	2774	7	8D
0005432966978	2774	8	8E
0005433681184	2774	9	8F
0005433681218	2774	10	9A
0005433684446	2774	11	9C
0005433681223	2774	12	9D
0005433681221	2774	13	9E
0005433681191	2774	14	9F
0005433681185	2774	15	10A
0005432967029	2774	16	10C
0005432967035	2774	17	10E
0005433681222	2774	18	11A
0005432966980	2774	19	11C
0005433681195	2774	20	11D
0005432966977	2774	21	11E
0005432967019	2774	22	11F
0005433681178	2774	23	12A
0005433681181	2774	24	12C
0005432966930	2774	25	12D
0005432967075	2774	26	12E
0005433681194	2774	27	12F
0005432967037	2774	28	13A
0005432967020	2774	29	13C
0005433681183	2774	30	13D
0005433681193	2774	31	13E
0005433681197	2774	32	13F
0005432222850	2774	33	14A
0005432967166	2774	34	14C
0005433681213	2774	35	14D
0005433681186	2774	36	14E
0005433681199	2774	37	15A
0005433681188	2774	38	15C
0005432967031	2774	39	15D
0005432967065	2774	40	16A
0005432222853	2774	41	16C
0005433681192	2774	42	16D
0005433681214	2774	43	16E
0005432966972	2774	44	16F
0005432222852	2774	45	17A
0005433681212	2774	46	17C
0005433681189	2774	47	17D
0005433684447	2774	48	17E
0005433681204	2774	49	17F
0005433681190	2774	50	18A
0005433681187	2774	51	18C
0005433681215	2774	52	18D
0005433681196	2774	53	18E
0005432966981	2774	54	18F
0005433681177	2774	55	19A
0005432967061	2774	56	19C
0005433681202	2774	57	19D
0005432967055	2774	58	19E
0005433681216	2774	59	20A
0005433681200	2774	60	20C
0005432967038	2774	61	20D
0005432966952	2774	62	20E
0005433681207	2774	63	20F
0005433681201	2774	64	1C
0005433681205	2774	65	1D
0005433681203	2774	66	1F
0005433681175	2774	67	2A
0005432222854	2774	68	2C
0005432222851	2774	69	2D
0005432967013	2774	70	2F
0005432967136	2774	71	3A
0005433681210	2774	72	3F
0005433681176	2774	73	4A
0005432966979	2774	74	4C
0005432967030	2774	75	4D
0005432966991	2774	76	4E
0005433681182	2774	77	4F
0005433681209	2774	78	5A
0005433681211	2774	79	5C
0005433681206	2774	80	5D
0005432967060	2774	81	5E
0005433681208	2774	82	5F
0005433681198	2774	83	6C
0005432967066	2774	84	6E
0005433690931	29145	1	14F
0005433687715	29145	2	1A
0005433680890	29145	3	1C
0005433681016	29145	4	1D
0005433680821	29145	5	1F
0005433680863	29145	6	2A
0005433680691	29145	7	2C
0005433680861	29145	8	2D
0005433680830	29145	9	2F
0005432967265	29145	10	3A
0005432967280	29145	11	3C
0005432967266	29145	12	3D
0005432967284	29145	13	3F
0005432967268	29145	14	4A
0005432005252	29145	15	4C
0005432967275	29145	16	4D
0005433687711	29145	17	4E
0005433680709	29145	18	4F
0005433680801	29145	19	5A
0005433680889	29145	20	5C
0005432967273	29145	21	5D
0005433684434	29145	22	5E
0005433680724	29145	23	5F
0005433680802	29145	24	6A
0005433680652	29145	25	6C
0005433684427	29145	26	6D
0005432967282	29145	27	6E
0005433680743	29145	28	6F
0005433687716	29145	29	7A
0005433680899	29145	30	7C
0005433680897	29145	31	7D
0005433680846	29145	32	7E
0005432967272	29145	33	7F
0005432967267	29145	34	8A
0005432005251	29145	35	8C
0005432967283	29145	36	8D
0005433680745	29145	37	8E
0005433680797	29145	38	8F
0005432967264	29145	39	9A
0005433681022	29145	40	9C
0005433680784	29145	41	9D
0005433681041	29145	42	9E
0005432967269	29145	43	9F
0005433680710	29145	44	10A
0005432967285	29145	45	10C
0005433680931	29145	46	10D
0005432005250	29145	47	10E
0005433684424	29145	48	10F
0005432967271	29145	49	11A
0005433680847	29145	50	11C
0005433680887	29145	51	11D
0005433680893	29145	52	11E
0005433680785	29145	53	11F
0005433681040	29145	54	12C
0005433690922	29145	55	12A
0005433680615	29145	56	12D
0005432967281	29145	57	12E
0005432967277	29145	58	12F
0005433680651	29145	59	13A
0005433680913	29145	60	13C
0005432967286	29145	61	13D
0005432967287	29145	62	13E
0005433680774	29145	63	13F
0005433681017	29145	64	14A
0005433680845	29145	65	14C
0005432967270	29145	66	14D
0005433681039	29145	67	14E
0005432967278	29145	68	15A
0005433680796	29145	69	15C
0005433680588	29145	70	15D
0005433680690	29145	71	15E
0005433680904	29145	72	15F
0005432967288	29145	73	16A
0005433680905	29145	74	16C
0005433680930	29145	75	16D
0005432967276	29145	76	16E
0005433680714	29145	77	17A
0005433680895	29145	78	16F
0005433680742	29145	79	17C
0005433680898	29145	80	17D
0005433680928	29145	81	17E
0005432967274	29145	82	17F
0005433687712	29145	83	18A
0005432967263	29145	84	18C
0005432967289	29145	85	18D
0005433680864	29145	86	18E
0005433680862	29145	87	18F
0005433680896	29145	88	19A
0005433684428	29145	89	19C
0005433687705	29145	90	19D
0005432967279	29145	91	19E
0005433680932	29145	92	19F
0005433680823	29145	93	20A
0005433680715	29145	94	20C
0005433680872	29145	95	20D
0005433680982	29145	96	20E
0005433680822	29145	97	20F
0005433634231	9297	1	1A
0005433615610	9297	2	1C
0005433615560	9297	3	1D
0005433615602	9297	4	2A
0005433615596	9297	5	1F
0005433615620	9297	6	2C
0005434152802	9297	7	2F
0005433615597	9297	8	2D
0005433615585	9297	9	3A
0005434163650	9297	10	3C
0005433577984	9297	11	3D
0005433615583	9297	12	4A
0005433615628	9297	13	4C
0005433615567	9297	14	4F
0005433615616	9297	15	4D
0005433615605	9297	16	5C
0005433615589	9297	17	5F
0005433615623	9297	18	5D
0005433634230	9297	19	6A
0005433634246	9297	20	6C
0005433615613	9297	21	6F
0005433634237	9297	22	6D
0005433577985	9297	23	7A
0005433615615	9297	24	7F
0005433615569	9297	25	7D
0005434152790	9297	26	8A
0005433634257	9297	27	8B
0005433615565	9297	28	8D
0005433615582	9297	29	8C
0005433634225	9297	30	8E
0005432756892	9297	31	9A
0005433634241	9297	32	8F
0005434269103	9297	33	9B
0005433577981	9297	34	9E
0005433615558	9297	35	9D
0005433615577	9297	36	9F
0005433615629	9297	37	10A
0005433577988	9297	38	10B
0005433615619	9297	39	10D
0005433615580	9297	40	10C
0005433615625	9297	41	10E
0005433615573	9297	42	10F
0005433615612	9297	43	11D
0005433615557	9297	44	12A
0005433615563	9297	45	11F
0005433615607	9297	46	12C
0005433615575	9297	47	12E
0005433615570	9297	48	12D
0005433615591	9297	49	13A
0005433615603	9297	50	12F
0005433577983	9297	51	13C
0005433634243	9297	52	13B
0005433634250	9297	53	13D
0005433615571	9297	54	13F
0005433634256	9297	55	13E
0005433634229	9297	56	14A
0005434163631	9297	57	14C
0005433615562	9297	58	14E
0005433634234	9297	59	14D
0005434163637	9297	60	14F
0005433615609	9297	61	15A
0005433615604	9297	62	15B
0005434269108	9297	63	15E
0005433634245	9297	64	15D
0005433615559	9297	65	16A
0005433615600	9297	66	16B
0005433615594	9297	67	16D
0005433634242	9297	68	16C
0005432756890	9297	69	16E
0005432755119	9297	70	16F
0005433634259	9297	71	17B
0005433615592	9297	72	17A
0005433615568	9297	73	17D
0005434163651	9297	74	17C
0005432756893	9297	75	17F
0005433634228	9297	76	17E
0005433615574	9297	77	18A
0005433634236	9297	78	18B
0005433634249	9297	79	18D
0005433615606	9297	80	18F
0005433634227	9297	81	19C
0005433615614	9297	82	19B
0005433615572	9297	83	19D
0005434269104	9297	84	19E
0005433615621	9297	85	20B
0005433615595	9297	86	20C
0005433634251	9297	87	20D
0005433577991	9297	88	20F
0005432145138	9297	89	20E
0005433577987	9297	90	21B
0005433577980	9297	91	21A
0005433615617	9297	92	21C
0005434269107	9297	93	21D
0005433615593	9297	94	21F
0005433634258	9297	95	22B
0005433615561	9297	96	22A
0005433634255	9297	97	22C
0005433634235	9297	98	22D
0005433615630	9297	99	22F
0005433615599	9297	100	23B
0005433577982	9297	101	23A
0005434152801	9297	102	23D
0005433634247	9297	103	23E
0005433615622	9297	104	24A
0005433634252	9297	105	24B
0005433615588	9297	106	24D
0005432145137	9297	107	24E
0005433634244	9297	108	25B
0005433615587	9297	109	25A
0005433615579	9297	110	25C
0005433615581	9297	111	25D
0005433577979	9297	112	25F
0005433615590	9297	113	25E
0005433577986	9297	114	26A
0005433577990	9297	115	26B
0005433615608	9297	116	26D
0005433615566	9297	117	26C
0005433615564	9297	118	26F
0005433615576	9297	119	27B
0005433615578	9297	120	27A
0005432755120	9297	121	27C
0005433615626	9297	122	27D
0005434163636	9297	123	27E
0005433615631	9297	124	28A
0005433634239	9297	125	28B
0005433634232	9297	126	28D
0005433577989	9297	127	28C
0005433577992	9297	128	28F
0005433615598	9297	129	29A
0005433634253	9297	130	29C
0005433615611	9297	131	29B
0005433615618	9297	132	29E
0005433615584	9297	133	30A
0005433615586	9297	134	29F
0005433634254	9297	135	30B
0005433634238	9297	136	30D
0005433634226	9297	137	30C
0005433615627	9297	138	30E
0005433634248	9297	139	30F
0005432756891	9297	140	31C
0005433634240	9297	141	31B
0005433615624	9297	142	31E
0005433615601	9297	143	31D
0005433634233	9297	144	31F
0005433615021	25214	1	30F
0005433577880	25214	2	1D
0005433614669	25214	3	1C
0005433577858	25214	4	1A
0005433614858	25214	5	1F
0005433633959	25214	6	2A
0005433634012	25214	7	2C
0005433614975	25214	8	2F
0005433633988	25214	9	2D
0005433633828	25214	10	3A
0005433614805	25214	11	3C
0005434272211	25214	12	3F
0005433614860	25214	13	3D
0005433614952	25214	14	4A
0005433577881	25214	15	4D
0005433614992	25214	16	4C
0005433614691	25214	17	5A
0005433633915	25214	18	4F
0005433634047	25214	19	5C
0005433615244	25214	20	5D
0005433614976	25214	21	5F
0005433614910	25214	22	6C
0005433614832	25214	23	6A
0005433634013	25214	24	6F
0005433615133	25214	25	6D
0005434163744	25214	26	7D
0005433614574	25214	27	7C
0005433615134	25214	28	7F
0005433615263	25214	29	8B
0005433615103	25214	30	8A
0005433615118	25214	31	8D
0005433615180	25214	32	8C
0005433614974	25214	33	8E
0005434163740	25214	34	9A
0005433634083	25214	35	8F
0005433614998	25214	36	9C
0005433615288	25214	37	9B
0005433614833	25214	38	9D
0005433633941	25214	39	9F
0005433633940	25214	40	9E
0005433615056	25214	41	10A
0005434163742	25214	42	10B
0005433634020	25214	43	10D
0005433633819	25214	44	10C
0005433614942	25214	45	10E
0005433633818	25214	46	10F
0005433634030	25214	47	11C
0005433614993	25214	48	11B
0005433615201	25214	49	11D
0005433614843	25214	50	11F
0005433633910	25214	51	11E
0005433633829	25214	52	12B
0005433615132	25214	53	12A
0005433614913	25214	54	12C
0005433633939	25214	55	12D
0005433615058	25214	56	12F
0005433577867	25214	57	13B
0005433614453	25214	58	13C
0005433614850	25214	59	13D
0005433614877	25214	60	13E
0005433615028	25214	61	14A
0005433577840	25214	62	13F
0005433633808	25214	63	14C
0005433633905	25214	64	14B
0005433577878	25214	65	14E
0005433577870	25214	66	14D
0005433614842	25214	67	14F
0005433615203	25214	68	15B
0005433614781	25214	69	15A
0005433633975	25214	70	15C
0005433615261	25214	71	15D
0005433614744	25214	72	15F
0005433633973	25214	73	15E
0005433614965	25214	74	16A
0005433633947	25214	75	16C
0005433633935	25214	76	16B
0005433614800	25214	77	16D
0005433633872	25214	78	16E
0005433577817	25214	79	16F
0005433614617	25214	80	17B
0005433633845	25214	81	17A
0005433634084	25214	82	17C
0005433614941	25214	83	18A
0005433577818	25214	84	17F
0005433614978	25214	85	18B
0005433614935	25214	86	18D
0005433614638	25214	87	18C
0005434163745	25214	88	18E
0005433633827	25214	89	18F
0005433615156	25214	90	19C
0005433614883	25214	91	19B
0005433633807	25214	92	19E
0005434163741	25214	93	19D
0005433614689	25214	94	20B
0005433615023	25214	95	20A
0005433633974	25214	96	20C
0005433614997	25214	97	20E
0005433614651	25214	98	20F
0005433614673	25214	99	21A
0005434163743	25214	100	21C
0005433633882	25214	101	21B
0005434163737	25214	102	21D
0005433615057	25214	103	21E
0005434272212	25214	104	21F
0005433614994	25214	105	22B
0005433614867	25214	106	22A
0005433615287	25214	107	22C
0005433633871	25214	108	22E
0005434273097	25214	109	22D
0005433633945	25214	110	23A
0005433615184	25214	111	23C
0005434273098	25214	112	23B
0005433614804	25214	113	23D
0005433615017	25214	114	23E
0005433614779	25214	115	24A
0005433614884	25214	116	23F
0005433614690	25214	117	24B
0005433633820	25214	118	24E
0005433633936	25214	119	24D
0005433633809	25214	120	24F
0005433633901	25214	121	25A
0005433614878	25214	122	25C
0005433614979	25214	123	25B
0005433614819	25214	124	25E
0005434163739	25214	125	25D
0005433614735	25214	126	25F
0005433615151	25214	127	26A
0005433615055	25214	128	26B
0005433634046	25214	129	26D
0005433633775	25214	130	26C
0005433633967	25214	131	26E
0005433577879	25214	132	26F
0005433615202	25214	133	27A
0005434163738	25214	134	27B
0005433614782	25214	135	27D
0005433577859	25214	136	27C
0005433633826	25214	137	27F
0005433614995	25214	138	27E
0005433614851	25214	139	28A
0005433614668	25214	140	28B
0005433614783	25214	141	28D
0005433614818	25214	142	28C
0005433633987	25214	143	28E
0005433615114	25214	144	28F
0005433615080	25214	145	29B
0005434273099	25214	146	29A
0005433614780	25214	147	29C
0005433614907	25214	148	29D
0005433615225	25214	149	29F
0005433633990	25214	150	29E
0005433615262	25214	151	30A
0005433615243	25214	152	30B
0005433615150	25214	153	30D
0005433614844	25214	154	30C
0005433577896	25214	155	30E
0005433615160	25214	156	31A
0005433614806	25214	157	31C
0005433633914	25214	158	31B
0005433614637	25214	159	31D
0005433633844	25214	160	31F
0005433614632	25214	161	31E
0005435947357	4253	1	36A
0005435787364	4253	2	35F
0005435856215	4253	3	34H
0005435856216	4253	4	37F
0005435986855	4253	5	20H
0005435787365	4253	6	32D
0005432571349	4253	7	2H
0005435986852	4253	8	28F
0005435787355	4253	9	37A
0005432571351	4253	10	17E
0005435947329	4253	11	35H
0005435986853	4253	12	19B
0005435856220	4253	13	34A
0005435787363	4253	14	23D
0005435947355	4253	15	36E
0005435947341	4253	16	4F
0005435986854	4253	17	35B
0005432184991	4253	18	28E
0005435947345	4253	19	27B
0005434271314	4253	20	12F
0005432571350	4253	21	30D
0005435947279	4253	22	20G
0005435856224	4253	23	29E
0005435856219	4253	24	25D
0005435856214	4253	25	31H
0005432184990	4253	26	22F
0005435947315	4253	27	12G
0005434271315	4253	28	24F
0005435947340	4253	29	31F
0005435947278	4253	30	22B
0005435947354	4253	31	22H
0005432184989	4253	32	32B
0005435947356	4253	33	5A
0005435856261	26565	1	37A
0005435947454	26565	2	3C
0005432571376	26565	3	36F
0005435947458	26565	4	28D
0005435856260	26565	5	27G
0005435947450	26565	6	27A
0005435947453	26565	7	24F
0005435947457	26565	8	24D
0005435947447	26565	9	2G
0005435947451	26565	10	37G
0005435947446	26565	11	23D
0005435947449	26565	12	20G
0005435947444	26565	13	18E
0005432571374	26565	14	18B
0005432571375	26565	15	17H
0005432571373	26565	16	15F
0005435947456	26565	17	14E
0005435787385	26565	18	14F
0005435856263	26565	19	13G
0005435947448	26565	20	11F
0005435947455	26565	21	11B
0005435787386	26565	22	1F
0005432571377	26565	23	24B
0005435856262	26565	24	37H
0005435947452	26565	25	37F
0005435947445	26565	26	37B
0005433569850	356	1	14D
0005433569890	356	2	14C
0005433074904	356	3	14E
0005433569840	356	4	15A
0005432239018	356	5	14F
0005433569856	356	6	15B
0005432239020	356	7	15C
0005433569876	356	8	15D
0005433074806	356	9	16A
0005433569867	356	10	16B
0005432239017	356	11	16D
0005433569878	356	12	16C
0005433569842	356	13	17A
0005433569872	356	14	16F
0005433569859	356	15	17C
0005433134174	356	16	17B
0005432239021	356	17	17E
0005433569882	356	18	17D
0005432948722	356	19	17F
0005433074932	356	20	18A
0005433134165	356	21	18D
0005433569843	356	22	18C
0005433134159	356	23	18E
0005433569868	356	24	18F
0005432948500	356	25	19C
0005433569844	356	26	19B
0005433074801	356	27	19D
0005433569866	356	28	20A
0005433074894	356	29	19E
0005432948520	356	30	20B
0005433074885	356	31	20C
0005433074758	356	32	20E
0005432948742	356	33	20D
0005433569884	356	34	21D
0005432948780	356	35	21C
0005433569879	356	36	21E
0005433074969	356	37	22A
0005433569873	356	38	21F
0005433074891	356	39	22B
0005433569889	356	40	22D
0005433134156	356	41	22C
0005432948444	356	42	22E
0005433569875	356	43	23B
0005433569895	356	44	23D
0005433569864	356	45	23C
0005432948629	356	46	23E
0005432948514	356	47	24A
0005433074759	356	48	23F
0005433569881	356	49	24B
0005433569851	356	50	24C
0005433569837	356	51	24E
0005432948567	356	52	24D
0005433074733	356	53	24F
0005432948589	356	54	25A
0005432948566	356	55	25B
0005433569902	356	56	25E
0005433569855	356	57	25D
0005433569877	356	58	25F
0005433569845	356	59	26A
0005433569906	356	60	26B
0005432948573	356	61	26D
0005432948745	356	62	26C
0005433569838	356	63	27A
0005432948545	356	64	26F
0005432948569	356	65	26E
0005433074919	356	66	27B
0005433569861	356	67	27C
0005433569883	356	68	27D
0005432948610	356	69	27F
0005433569887	356	70	27E
0005433074734	356	71	28A
0005432239016	356	72	28B
0005433074893	356	73	28C
0005433569892	356	74	28E
0005433569904	356	75	28D
0005433569903	356	76	28F
0005433569860	356	77	29B
0005433569900	356	78	29A
0005433074931	356	79	29D
0005432948445	356	80	29C
0005433074829	356	81	29F
0005433569885	356	82	29E
0005433569848	356	83	30A
0005432948778	356	84	30B
0005433569839	356	85	30C
0005433569897	356	86	30E
0005432948671	356	87	30F
0005433074735	356	88	31A
0005433569899	356	89	31C
0005433569869	356	90	31B
0005432948709	356	91	31D
0005433569898	356	92	31E
0005433569854	356	93	31F
0005432948743	356	94	18B
0005432948509	356	95	1A
0005433569894	356	96	1C
0005433074884	356	97	1D
0005433569888	356	98	2A
0005432948717	356	99	2F
0005433569893	356	100	3A
0005433074909	356	101	3D
0005432239019	356	102	3C
0005432948746	356	103	3F
0005433569886	356	104	4A
0005433569841	356	105	4C
0005433569874	356	106	4F
0005432948814	356	107	5A
0005433074920	356	108	5D
0005433569862	356	109	5C
0005432948568	356	110	6A
0005432948628	356	111	6C
0005432948510	356	112	6D
0005433074970	356	113	6F
0005432948541	356	114	7D
0005433134164	356	115	7C
0005432948432	356	116	7F
0005432948580	356	117	8A
0005433569905	356	118	8C
0005433569865	356	119	8B
0005433569847	356	120	8D
0005433074892	356	121	9A
0005432948609	356	122	8F
0005433074807	356	123	9B
0005433569901	356	124	9C
0005433569857	356	125	9E
0005433569880	356	126	9D
0005433569849	356	127	9F
0005433569871	356	128	10A
0005433569858	356	129	10B
0005433569852	356	130	10C
0005433074761	356	131	10E
0005433569870	356	132	10D
0005433569863	356	133	10F
0005433569907	356	134	11B
0005432948579	356	135	11A
0005433074760	356	136	11C
0005432948675	356	137	11D
0005432948501	356	138	11F
0005432948708	356	139	11E
0005433074754	356	140	12A
0005432948519	356	141	12B
0005433569846	356	142	12C
0005432948721	356	143	12E
0005433569891	356	144	12D
0005433074756	356	145	13A
0005433074815	356	146	13B
0005432948542	356	147	13C
0005433569896	356	148	13D
0005433134168	356	149	13E
0005433569853	356	150	14A
0005432948813	356	151	13F
0005433074755	356	152	14B
0005433075074	11578	1	1A
0005433075095	11578	2	1C
0005433569040	11578	3	1F
0005433134198	11578	4	2A
0005433569196	11578	5	2C
0005433569348	11578	6	2F
0005432949014	11578	7	2D
0005432948996	11578	8	3C
0005433075071	11578	9	3D
0005432948985	11578	10	4A
0005432949000	11578	11	4C
0005432949012	11578	12	4F
0005432192363	11578	13	5A
0005433075096	11578	14	5C
0005433569396	11578	15	5F
0005432948983	11578	16	5D
0005433569311	11578	17	6A
0005433134200	11578	18	6D
0005433131769	11578	19	7A
0005433075073	11578	20	6F
0005433569411	11578	21	7C
0005432948988	11578	22	7D
0005433075083	11578	23	8A
0005433569197	11578	24	8D
0005432948997	11578	25	8C
0005432948980	11578	26	8E
0005432949004	11578	27	8F
0005433075086	11578	28	9A
0005433568975	11578	29	9C
0005432949001	11578	30	9B
0005432949006	11578	31	9E
0005433075093	11578	32	9D
0005433569133	11578	33	10A
0005432948989	11578	34	9F
0005433569162	11578	35	10B
0005433075079	11578	36	10C
0005433569269	11578	37	10E
0005433075088	11578	38	10F
0005433569255	11578	39	11A
0005433569448	11578	40	11C
0005432948987	11578	41	11D
0005432949003	11578	42	11E
0005433569244	11578	43	11F
0005433075077	11578	44	12B
0005433569085	11578	45	12D
0005433569151	11578	46	12C
0005433569545	11578	47	13A
0005433569091	11578	48	12F
0005432949009	11578	49	13C
0005433075092	11578	50	13B
0005433075078	11578	51	13D
0005433075076	11578	52	13E
0005433569234	11578	53	14A
0005433569018	11578	54	13F
0005432948999	11578	55	14B
0005433569072	11578	56	14C
0005433134199	11578	57	14E
0005433569193	11578	58	15A
0005432948998	11578	59	14F
0005433569132	11578	60	15C
0005433568839	11578	61	15B
0005433075098	11578	62	15E
0005433569228	11578	63	15D
0005433569290	11578	64	15F
0005432948977	11578	65	16B
0005433569046	11578	66	16D
0005432948979	11578	67	16F
0005433569071	11578	68	17A
0005433568880	11578	69	17C
0005433569291	11578	70	17D
0005433569159	11578	71	17E
0005432948984	11578	72	18A
0005433075075	11578	73	17F
0005432949007	11578	74	18B
0005433075089	11578	75	18D
0005432948993	11578	76	18E
0005432949011	11578	77	19B
0005433569531	11578	78	18F
0005432948975	11578	79	19C
0005433569182	11578	80	19D
0005433569530	11578	81	20A
0005433075081	11578	82	19E
0005433131768	11578	83	20B
0005433569054	11578	84	20C
0005432192362	11578	85	20E
0005433075094	11578	86	20D
0005432948978	11578	87	20F
0005433131771	11578	88	21C
0005433568974	11578	89	21B
0005432948986	11578	90	21D
0005433569352	11578	91	21F
0005432948994	11578	92	21E
0005433569267	11578	93	22A
0005432949013	11578	94	22B
0005433569100	11578	95	22D
0005433075091	11578	96	22F
0005433569467	11578	97	22E
0005432948976	11578	98	23B
0005432948982	11578	99	23E
0005433075099	11578	100	24A
0005433569163	11578	101	24B
0005432948992	11578	102	24D
0005433075085	11578	103	24C
0005433569466	11578	104	24E
0005432949005	11578	105	25B
0005433134201	11578	106	25A
0005433075084	11578	107	25C
0005432948991	11578	108	25D
0005433131770	11578	109	25E
0005433569410	11578	110	26B
0005433569463	11578	111	26A
0005433569245	11578	112	26C
0005433569377	11578	113	26D
0005433569280	11578	114	26F
0005432948995	11578	115	27A
0005433569253	11578	116	27B
0005432192361	11578	117	27D
0005433569465	11578	118	27E
0005433569161	11578	119	28A
0005433569179	11578	120	27F
0005433075080	11578	121	28B
0005433569451	11578	122	28D
0005432948981	11578	123	28C
0005432948974	11578	124	28E
0005432949002	11578	125	28F
0005432949010	11578	126	29B
0005433075082	11578	127	29C
0005433569351	11578	128	29F
0005433075087	11578	129	29E
0005433569160	11578	130	30A
0005433569464	11578	131	30D
0005432949008	11578	132	30C
0005433075072	11578	133	30E
0005433075097	11578	134	30F
0005432948990	11578	135	31A
0005433568840	11578	136	31B
0005433075090	11578	137	31D
0005433568994	11578	138	31F
0005433569183	11578	139	31E
0005433817520	9962	1	1A
0005433817519	9962	2	1B
0005433817522	9962	3	2B
0005434733000	9962	4	5A
0005433817521	9962	5	6B
0005434733005	9962	6	6A
0005434733027	13962	1	1B
0005434733028	13962	2	2B
0005433817465	13962	3	3A
0005434733029	13962	4	4A
0005433817478	13962	5	3B
0005433817494	13962	6	4B
0005433817466	13962	7	5A
0005433817493	13962	8	5B
0005434733026	13962	9	6A
0005432655553	26168	1	16D
0005433754444	26168	2	1A
0005435982166	26168	3	1C
0005433754599	26168	4	1B
0005432655562	26168	5	1F
0005432985524	26168	6	1G
0005433754422	26168	7	2A
0005432985508	26168	8	1H
0005433754498	26168	9	2C
0005432869608	26168	10	2B
0005433754362	26168	11	2G
0005433435071	26168	12	3A
0005433435063	26168	13	2H
0005433435064	26168	14	3B
0005433435052	26168	15	3F
0005433754491	26168	16	3C
0005433435051	26168	17	3H
0005433435069	26168	18	3G
0005435982465	26168	19	4B
0005432869610	26168	20	4A
0005433435044	26168	21	4C
0005432985521	26168	22	4G
0005433754715	26168	23	4F
0005435982457	26168	24	4H
0005432869609	26168	25	5B
0005433754566	26168	26	5F
0005435982425	26168	27	5C
0005432985502	26168	28	5G
0005433754365	26168	29	9A
0005433754351	26168	30	5H
0005433754537	26168	31	9G
0005434376159	26168	32	9B
0005432985514	26168	33	11A
0005433766665	26168	34	9H
0005435982442	26168	35	11B
0005433754490	26168	36	11E
0005435982598	26168	37	11D
0005435982493	26168	38	11F
0005435982424	26168	39	11G
0005433754557	26168	40	12A
0005432051171	26168	41	11H
0005433754554	26168	42	12D
0005432985510	26168	43	12B
0005432655584	26168	44	12E
0005432049510	26168	45	12F
0005432985516	26168	46	12H
0005432655585	26168	47	12G
0005433766675	26168	48	13B
0005433754567	26168	49	13A
0005433754370	26168	50	13F
0005432869607	26168	51	13E
0005432655552	26168	52	13D
0005432985518	26168	53	13H
0005433754766	26168	54	14B
0005433754640	26168	55	14A
0005433435062	26168	56	14E
0005432655578	26168	57	14D
0005433435047	26168	58	14F
0005432655520	26168	59	14H
0005433435043	26168	60	14G
0005433754547	26168	61	15D
0005432985522	26168	62	15B
0005432985506	26168	63	15A
0005432985503	26168	64	15E
0005433754306	26168	65	15F
0005433435058	26168	66	15H
0005432985515	26168	67	15G
0005433754543	26168	68	16A
0005434731228	26168	69	16B
0005435982464	26168	70	16G
0005432655530	26168	71	16F
0005432049513	26168	72	16H
0005433754616	26168	73	17B
0005435982324	26168	74	17A
0005432655579	26168	75	17E
0005432985495	26168	76	17G
0005435982593	26168	77	17F
0005435982467	26168	78	18A
0005432985525	26168	79	17H
0005435982568	26168	80	18B
0005432051170	26168	81	18D
0005433754364	26168	82	18F
0005435982567	26168	83	18E
0005433754439	26168	84	18G
0005435982486	26168	85	19A
0005434731227	26168	86	18H
0005435982435	26168	87	19B
0005433754376	26168	88	19D
0005433754352	26168	89	19F
0005432655627	26168	90	19E
0005432985497	26168	91	19G
0005433754433	26168	92	20A
0005432985509	26168	93	19H
0005435982543	26168	94	20B
0005433754275	26168	95	20E
0005432985523	26168	96	20F
0005435982394	26168	97	20G
0005432655529	26168	98	21A
0005432655550	26168	99	20H
0005435982294	26168	100	21D
0005435982557	26168	101	21B
0005433754500	26168	102	21E
0005433435050	26168	103	21F
0005433754538	26168	104	21H
0005432655515	26168	105	21G
0005432985498	26168	106	22B
0005433435046	26168	107	22A
0005433754343	26168	108	22D
0005432985501	26168	109	22F
0005433435056	26168	110	22E
0005433435048	26168	111	22G
0005433754474	26168	112	23A
0005435982485	26168	113	22H
0005433754625	26168	114	23B
0005433754492	26168	115	23D
0005433435057	26168	116	23F
0005432655589	26168	117	23E
0005432049514	26168	118	23G
0005433435049	26168	119	24A
0005433754617	26168	120	23H
0005433754553	26168	121	24B
0005433435045	26168	122	24D
0005433754548	26168	123	24F
0005435982532	26168	124	24E
0005432655597	26168	125	24G
0005433754454	26168	126	25D
0005432049511	26168	127	25E
0005432985500	26168	128	27A
0005432985517	26168	129	25F
0005434731229	26168	130	27B
0005433435060	26168	131	27E
0005433435061	26168	132	27D
0005433754291	26168	133	27H
0005435982360	26168	134	27G
0005434731226	26168	135	28A
0005433754693	26168	136	28D
0005432655577	26168	137	28B
0005435982293	26168	138	28E
0005435982494	26168	139	28F
0005433754486	26168	140	28G
0005433754473	26168	141	29B
0005435982565	26168	142	29A
0005432985505	26168	143	28H
0005433754717	26168	144	29E
0005433435067	26168	145	29D
0005432985519	26168	146	29F
0005433754402	26168	147	29H
0005433435054	26168	148	29G
0005433754598	26168	149	30A
0005432985511	26168	150	30D
0005433754363	26168	151	30B
0005433435065	26168	152	30F
0005432985526	26168	153	30E
0005433754344	26168	154	30G
0005435982571	26168	155	30H
0005435982332	26168	156	31B
0005432655531	26168	157	31A
0005434731230	26168	158	31E
0005435982549	26168	159	31D
0005433754712	26168	160	31F
0005435982534	26168	161	31G
0005433764688	26168	162	31H
0005435982520	26168	163	32B
0005435982487	26168	164	32A
0005433754489	26168	165	32E
0005432985520	26168	166	32D
0005432985512	26168	167	32F
0005433435055	26168	168	32G
0005435982456	26168	169	33A
0005433754238	26168	170	33D
0005433754395	26168	171	33E
0005432985507	26168	172	33F
0005432985513	26168	173	33H
0005433754394	26168	174	33G
0005432985504	26168	175	34B
0005433754716	26168	176	34A
0005433754393	26168	177	34D
0005432869614	26168	178	34E
0005432869612	26168	179	34G
0005432985527	26168	180	34F
0005433754290	26168	181	35A
0005433754382	26168	182	34H
0005433754371	26168	183	35B
0005432869615	26168	184	35D
0005432049512	26168	185	35F
0005435982535	26168	186	35E
0005432051169	26168	187	35G
0005435982361	26168	188	35H
0005432869613	26168	189	36B
0005433435070	26168	190	36A
0005433435066	26168	191	36D
0005433754499	26168	192	36F
0005433754713	26168	193	36E
0005433754536	26168	194	36H
0005433754480	26168	195	37A
0005433754720	26168	196	37B
0005435982326	26168	197	37D
0005433435059	26168	198	37F
0005435982564	26168	199	37E
0005432985499	26168	200	37H
0005433754509	26168	201	37G
0005435982563	26168	202	38A
0005435982533	26168	203	38D
0005433435068	26168	204	38B
0005433754434	26168	205	38E
0005435982403	26168	206	38G
0005433435053	26168	207	38F
0005432869611	26168	208	38H
0005435982578	26168	209	39D
0005432985496	26168	210	39F
0005435982466	26168	211	39E
0005434375240	1503	1	21E
0005434375251	1503	2	20E
0005433151657	1503	3	7F
0005434375265	1503	4	20B
0005434375261	1503	5	15A
0005434375237	1503	6	9D
0005433151605	1503	7	1C
0005433151698	1503	8	21C
0005434375233	1503	9	15E
0005434375273	1503	10	12A
0005434375258	1503	11	11E
0005433151485	1503	12	14A
0005433151537	1503	13	23D
0005434375280	1503	14	17B
0005433151546	1503	15	18C
0005434375274	1503	16	16F
0005433151777	1503	17	6B
0005433460464	1503	18	7C
0005433151192	1503	19	6D
0005433151612	1503	20	6E
0005433151538	1503	21	13C
0005433151624	1503	22	12E
0005434375241	1503	23	14C
0005434375249	1503	24	10D
0005434375266	1503	25	2D
0005433151638	1503	26	8A
0005433151656	1503	27	20A
0005434375230	1503	28	23B
0005433151606	1503	29	19A
0005434375242	1503	30	5B
0005433151548	1503	31	17F
0005434375234	1503	32	17C
0005434375250	1503	33	17A
0005433151361	1503	34	11D
0005434375252	1503	35	4F
0005433151541	1503	36	4E
0005434375247	1503	37	16B
0005434375278	1503	38	16C
0005432267983	1503	39	3C
0005433764685	1503	40	14B
0005434375271	1503	41	13E
0005432267985	1503	42	5D
0005433151593	1503	43	19D
0005434375253	1503	44	3A
0005434375243	1503	45	7E
0005434375259	1503	46	3D
0005434375263	1503	47	11B
0005433151543	1503	48	12F
0005433151418	1503	49	13B
0005433151577	1503	50	8C
0005433151492	1503	51	11F
0005434029674	1503	52	14E
0005434375236	1503	53	5A
0005433151594	1503	54	18F
0005434375248	1503	55	20D
0005434375276	1503	56	7D
0005434375244	1503	57	18E
0005434375267	1503	58	20F
0005434375262	1503	59	2F
0005434375231	1503	60	1D
0005432267982	1503	61	10E
0005434375257	1503	62	13D
0005432267988	1503	63	22E
0005433151750	1503	64	16E
0005433151603	1503	65	6A
0005434375235	1503	66	19B
0005433151554	1503	67	21A
0005433151645	1503	68	20C
0005433151643	1503	69	15B
0005433151555	1503	70	8E
0005434375277	1503	71	9A
0005434375264	1503	72	18A
0005434029663	1503	73	15F
0005433151419	1503	74	21D
0005434375239	1503	75	16A
0005433151728	1503	76	14F
0005433151486	1503	77	10B
0005434375256	1503	78	22D
0005434375255	1503	79	13F
0005433151536	1503	80	9F
0005433461617	1503	81	19E
0005433151611	1503	82	13A
0005434375246	1503	83	12B
0005433151641	1503	84	18D
0005434375260	1503	85	12D
0005432267987	1503	86	10C
0005434375254	1503	87	16D
0005433151456	1503	88	1F
0005433151529	1503	89	22B
0005432267984	1503	90	19F
0005433460466	1503	91	2C
0005434375275	1503	92	23C
0005434375232	1503	93	11A
0005434375272	1503	94	8D
0005433460465	1503	95	17E
0005433151576	1503	96	5E
0005434375270	1503	97	6C
0005434375268	1503	98	7A
0005432267986	1503	99	22F
0005433461618	1503	100	17D
0005433151528	1503	101	22C
0005434375245	1503	102	7B
0005434375269	1503	103	5F
0005433151542	1503	104	21F
0005434375238	1503	105	15C
0005433151604	1503	106	1A
0005434029664	1503	107	11C
0005434375279	1503	108	5C
0005434375025	20113	1	4B
0005434375100	20113	2	4E
0005433151859	20113	3	4F
0005434374820	20113	4	5C
0005433151881	20113	5	5B
0005434374809	20113	6	5D
0005434374807	20113	7	5F
0005434374822	20113	8	5E
0005434374949	20113	9	6B
0005433151874	20113	10	6C
0005433151875	20113	11	6D
0005433151858	20113	12	6F
0005433151856	20113	13	6E
0005434374806	20113	14	7C
0005433151876	20113	15	7B
0005433151866	20113	16	7E
0005432056348	20113	17	7D
0005433151879	20113	18	7F
0005433151872	20113	19	8B
0005433151850	20113	20	8C
0005433151878	20113	21	8D
0005434374818	20113	22	8F
0005434374890	20113	23	8E
0005433151852	20113	24	9B
0005434375045	20113	25	9C
0005433151877	20113	26	9E
0005432056351	20113	27	10B
0005433151883	20113	28	10E
0005432056349	20113	29	10D
0005433931508	20113	30	11A
0005434374781	20113	31	11B
0005434374758	20113	32	11D
0005434029692	20113	33	11C
0005433151880	20113	34	11E
0005433764707	20113	35	11F
0005433151868	20113	36	12A
0005433151864	20113	37	12C
0005434374704	20113	38	12E
0005434374706	20113	39	12D
0005434374819	20113	40	12F
0005434029691	20113	41	13A
0005433151857	20113	42	13B
0005434374779	20113	43	13D
0005434375046	20113	44	13C
0005434374796	20113	45	13E
0005434374708	20113	46	14A
0005434374775	20113	47	13F
0005433151865	20113	48	14B
0005434374953	20113	49	14D
0005434374786	20113	50	14C
0005433151870	20113	51	14E
0005434374780	20113	52	15B
0005434374805	20113	53	15A
0005434374714	20113	54	15D
0005432056350	20113	55	15F
0005434374884	20113	56	16A
0005433151853	20113	57	16E
0005433151854	20113	58	17B
0005433151871	20113	59	17D
0005434374830	20113	60	17F
0005433931509	20113	61	18B
0005433151882	20113	62	18D
0005433151873	20113	63	18C
0005433764708	20113	64	18E
0005434374801	20113	65	18F
0005434374812	20113	66	19B
0005433151848	20113	67	19D
0005434374707	20113	68	19C
0005434374795	20113	69	19F
0005434374951	20113	70	20A
0005434374987	20113	71	20B
0005434374883	20113	72	20E
0005433931507	20113	73	20D
0005433151869	20113	74	20F
0005433151855	20113	75	21B
0005434374975	20113	76	21E
0005434374773	20113	77	21F
0005434374935	20113	78	22B
0005433151867	20113	79	22A
0005434374950	20113	80	22C
0005433151862	20113	81	22D
0005433151851	20113	82	22E
0005433151860	20113	83	23A
0005434375009	20113	84	23C
0005434374774	20113	85	23E
0005434374799	20113	86	23D
0005433151861	20113	87	21D
0005434375044	20113	88	1D
0005434374891	20113	89	2C
0005433151863	20113	90	2D
0005433931510	20113	91	3A
0005434374783	20113	92	3C
0005434374923	20113	93	3F
0005433151849	20113	94	4A
0005432425085	596	1	9D
0005432425111	596	2	15B
0005432425077	596	3	13B
0005432425112	596	4	31A
0005432425078	596	5	6C
0005432425116	596	6	29F
0005432425110	596	7	13D
0005432425107	596	8	6D
0005432425102	596	9	1A
0005432425109	596	10	26B
0005432425104	596	11	27B
0005432282959	596	12	20E
0005432425123	596	13	12F
0005432425114	596	14	16E
0005432425093	596	15	19C
0005432425080	596	16	13C
0005432425121	596	17	15E
0005432282956	596	18	2F
0005432425082	596	19	1F
0005432425119	596	20	27E
0005432425097	596	21	8B
0005432425087	596	22	9A
0005432282955	596	23	31D
0005432425108	596	24	30D
0005432282957	596	25	11F
0005432282961	596	26	7F
0005432425101	596	27	27A
0005432425113	596	28	10A
0005432425096	596	29	22D
0005432425088	596	30	14A
0005432425100	596	31	13E
0005432425118	596	32	31C
0005432425089	596	33	29E
0005432425091	596	34	9E
0005432425106	596	35	24C
0005432425081	596	36	19D
0005432425083	596	37	27D
0005432425120	596	38	10F
0005432282960	596	39	7C
0005432425103	596	40	3A
0005432425090	596	41	7D
0005432425084	596	42	11D
0005432425115	596	43	26E
0005432425105	596	44	17F
0005432425122	596	45	5D
0005432425086	596	46	2C
0005432425099	596	47	12E
0005432425076	596	48	20B
0005432425117	596	49	21F
0005432425092	596	50	4D
0005432425079	596	51	28E
0005432425095	596	52	11C
0005432425094	596	53	26A
0005432425098	596	54	23A
0005432282958	596	55	22E
0005433158158	12846	1	31F
0005434446519	12846	2	9F
0005432302382	12846	3	4F
0005432302381	12846	4	9D
0005432302383	12846	5	28C
0005433158160	12846	6	26F
0005433158162	12846	7	24D
0005433158161	12846	8	20E
0005432302380	12846	9	5C
0005433158159	12846	10	17D
0005432424525	12855	1	22B
0005432424470	12855	2	30B
0005432424638	12855	3	3F
0005432424537	12855	4	8C
0005432424650	12855	5	11B
0005432424515	12855	6	1A
0005432424595	12855	7	10B
0005432424603	12855	8	1D
0005432424578	12855	9	8F
0005432424577	12855	10	9E
0005432424635	12855	11	14A
0005432424626	12855	12	14E
0005432424670	12855	13	31E
0005432424584	12855	14	21E
0005432424634	12855	15	11D
0005432424632	12855	16	29F
0005432424393	12855	17	9A
0005432424619	12855	18	12F
0005432424379	12855	19	1F
0005432424600	12855	20	26A
0005432424601	12855	21	11F
0005432424639	12855	22	17E
0005432424526	12855	23	18E
0005432424510	12855	24	23D
0005432424474	12855	25	21A
0005432424673	12855	26	22F
0005432424538	12855	27	10C
0005432424647	12855	28	11A
0005432424663	12855	29	28E
0005432424633	12855	30	13E
0005432424471	12855	31	20F
0005432424620	12855	32	28D
0005432424590	12855	33	17B
0005432424338	12855	34	30D
0005432424469	12855	35	24D
0005432424630	12855	36	24C
0005432424582	12855	37	17D
0005432424587	12855	38	22E
0005432424631	12855	39	25F
0005432424448	12855	40	31F
0005432424627	12855	41	15B
0005432424491	12855	42	24F
0005432424606	12855	43	28C
0005432424614	12855	44	18A
0005432424609	12855	45	21C
0005432424637	12855	46	10A
0005432424664	12855	47	29D
0005432424473	12855	48	16D
0005432424378	12855	49	21F
0005432424583	12855	50	3A
0005432424629	12855	51	25A
0005432424654	12855	52	26F
0005434024638	436	1	35A
0005434024613	436	2	34H
0005434024605	436	3	35D
0005434024624	436	4	35E
0005434024642	436	5	36B
0005434024611	436	6	36E
0005434024589	436	7	36F
0005433058055	436	8	36H
0005434024644	436	9	36G
0005434028335	436	10	37A
0005434024608	436	11	37B
0005433058177	436	12	37F
0005434024585	436	13	37H
0005434024591	436	14	38D
0005432235741	436	15	38B
0005433058149	436	16	38E
0005434024623	436	17	38G
0005434024637	436	18	38H
0005433058083	436	19	39D
0005433058122	436	20	1A
0005434029690	436	21	1F
0005433058080	436	22	2A
0005434029688	436	23	1H
0005434024649	436	24	2C
0005434024599	436	25	2G
0005433058124	436	26	3A
0005434028336	436	27	2H
0005434024622	436	28	3B
0005434024640	436	29	3G
0005434024607	436	30	4A
0005433058170	436	31	4B
0005433058146	436	32	4F
0005434024619	436	33	4G
0005434024625	436	34	5G
0005433058153	436	35	5F
0005433058193	436	36	11A
0005432235740	436	37	11B
0005433058281	436	38	11E
0005434024597	436	39	11D
0005433058272	436	40	11G
0005433058051	436	41	11F
0005433058279	436	42	11H
0005434024616	436	43	12B
0005433058032	436	44	12E
0005434024646	436	45	12G
0005434024610	436	46	12H
0005434024617	436	47	13B
0005433058125	436	48	13D
0005433058054	436	49	13E
0005434028334	436	50	13G
0005434024620	436	51	13F
0005434024630	436	52	13H
0005434024618	436	53	14E
0005434024631	436	54	15A
0005434024615	436	55	15B
0005434024626	436	56	15D
0005432235737	436	57	16B
0005434024643	436	58	16E
0005434024593	436	59	16H
0005433058280	436	60	17B
0005434024641	436	61	17A
0005433058194	436	62	17D
0005434024592	436	63	17E
0005434028337	436	64	17G
0005434024634	436	65	18A
0005433058147	436	66	17H
0005433058081	436	67	18D
0005434029689	436	68	18B
0005434024587	436	69	18E
0005434024609	436	70	18G
0005434024602	436	71	18F
0005434024596	436	72	19B
0005434024603	436	73	19D
0005434024598	436	74	19H
0005432235736	436	75	20A
0005434032080	436	76	20D
0005434024633	436	77	20E
0005434024595	436	78	20H
0005433058131	436	79	20G
0005434024586	436	80	21A
0005433058123	436	81	21B
0005433929630	436	82	21E
0005434024583	436	83	21D
0005432045639	436	84	21G
0005434024628	436	85	21F
0005433058084	436	86	22A
0005434024632	436	87	22D
0005433058118	436	88	22E
0005433057993	436	89	22G
0005434024635	436	90	22F
0005434032081	436	91	22H
0005433058085	436	92	23A
0005433058003	436	93	23E
0005433058050	436	94	23G
0005434024582	436	95	24E
0005434032083	436	96	24H
0005433058144	436	97	24G
0005432235738	436	98	25D
0005434024601	436	99	25E
0005433058143	436	100	27B
0005433057994	436	101	27E
0005434024604	436	102	27F
0005433058208	436	103	27G
0005432235739	436	104	28D
0005434024600	436	105	28B
0005434024588	436	106	28E
0005434024612	436	107	28G
0005434024590	436	108	28H
0005434024648	436	109	29A
0005432045638	436	110	29D
0005434032082	436	111	29B
0005432235742	436	112	29E
0005434024614	436	113	29G
0005433058238	436	114	29H
0005434024594	436	115	30A
0005434024629	436	116	30F
0005434024645	436	117	30E
0005434024647	436	118	30H
0005434029687	436	119	31D
0005434024584	436	120	31F
0005433058135	436	121	31H
0005434735717	436	122	32B
0005433058103	436	123	33B
0005434024606	436	124	33A
0005433058169	436	125	33D
0005434024639	436	126	33E
0005434024621	436	127	33F
0005434028333	436	128	33H
0005434024627	436	129	34D
0005434024581	436	130	34B
0005434024636	436	131	34E
0005433058178	436	132	34G
0005434024149	12696	1	35A
0005433058416	12696	2	1A
0005433058412	12696	3	1B
0005434023948	12696	4	1F
0005434032031	12696	5	1C
0005434735762	12696	6	1G
0005434029663	12696	7	2B
0005433058415	12696	8	2C
0005433929668	12696	9	2G
0005434024155	12696	10	3A
0005434024165	12696	11	2H
0005434023884	12696	12	3B
0005434024156	12696	13	3F
0005434023975	12696	14	3C
0005434024084	12696	15	4A
0005434023934	12696	16	3H
0005434024179	12696	17	4B
0005434024114	12696	18	4C
0005434023980	12696	19	5A
0005433058409	12696	20	4H
0005432156423	12696	21	5B
0005434024293	12696	22	5F
0005434023914	12696	23	5G
0005433058438	12696	24	9H
0005434029664	12696	25	11B
0005434023898	12696	26	11E
0005434024262	12696	27	11F
0005434024229	12696	28	12A
0005434024079	12696	29	12B
0005434024128	12696	30	12E
0005433058440	12696	31	12G
0005433058423	12696	32	12F
0005434024364	12696	33	13A
0005433058441	12696	34	13E
0005434024185	12696	35	13G
0005434024143	12696	36	13H
0005434735759	12696	37	14A
0005434024008	12696	38	14F
0005433929667	12696	39	14G
0005433058429	12696	40	15A
0005434024123	12696	41	15D
0005434024099	12696	42	15B
0005434023820	12696	43	15E
0005433058425	12696	44	15F
0005434023987	12696	45	15H
0005433058420	12696	46	15G
0005433058433	12696	47	16A
0005433058431	12696	48	16D
0005434024007	12696	49	16B
0005434023764	12696	50	16E
0005432156427	12696	51	16G
0005433929669	12696	52	17A
0005434023924	12696	53	17F
0005433058427	12696	54	17E
0005434023949	12696	55	18A
0005433058404	12696	56	17H
0005434024001	12696	57	18B
0005433058417	12696	58	18E
0005433058402	12696	59	18D
0005434023919	12696	60	18F
0005434024000	12696	61	18G
0005433058421	12696	62	19D
0005433058435	12696	63	19B
0005433929666	12696	64	19A
0005433058405	12696	65	19H
0005434024132	12696	66	20B
0005433058419	12696	67	20E
0005433684449	12696	68	20D
0005434023986	12696	69	20G
0005434024294	12696	70	21A
0005432156425	12696	71	20H
0005434023944	12696	72	21F
0005433929670	12696	73	21E
0005434735760	12696	74	22B
0005434024012	12696	75	22A
0005434024230	12696	76	22D
0005434024256	12696	77	22F
0005434024227	12696	78	22H
0005433058410	12696	79	23B
0005434024076	12696	80	23A
0005434023763	12696	81	23D
0005433058437	12696	82	23G
0005433058413	12696	83	23F
0005433058406	12696	84	24B
0005434023899	12696	85	24G
0005432157518	12696	86	25D
0005434024134	12696	87	24H
0005433058403	12696	88	25E
0005433058418	12696	89	27A
0005434032040	12696	90	25F
0005433058432	12696	91	27E
0005434028303	12696	92	27D
0005433058439	12696	93	27F
0005434024094	12696	94	27G
0005433058414	12696	95	28E
0005434024013	12696	96	28F
0005433058436	12696	97	29A
0005434024080	12696	98	29E
0005434024144	12696	99	29D
0005432156426	12696	100	29G
0005433058430	12696	101	30A
0005434023920	12696	102	30B
0005434024108	12696	103	30E
0005434024002	12696	104	30F
0005434024263	12696	105	30H
0005434028308	12696	106	31E
0005434024113	12696	107	31D
0005434029674	12696	108	31F
0005434032033	12696	109	31G
0005432156424	12696	110	32A
0005434024153	12696	111	31H
0005433058426	12696	112	32B
0005434024178	12696	113	32E
0005433058428	12696	114	33A
0005433684448	12696	115	32H
0005432157517	12696	116	33B
0005434735761	12696	117	33H
0005434023930	12696	118	34A
0005434024051	12696	119	34B
0005433058407	12696	120	34G
0005434028302	12696	121	34F
0005433058411	12696	122	34H
0005434023818	12696	123	35B
0005434032043	12696	124	35D
0005434032042	12696	125	35E
0005434024135	12696	126	35G
0005434023897	12696	127	35H
0005433058408	12696	128	36B
0005433058424	12696	129	36A
0005433058422	12696	130	36F
0005434024074	12696	131	37A
0005434023999	12696	132	36H
0005434023753	12696	133	37B
0005434024093	12696	134	37E
0005433058434	12696	135	37D
0005434028304	12696	136	38A
0005434023834	12696	137	38F
0005433036456	2115	1	32D
0005433924612	2115	2	16F
0005433036489	2115	3	13H
0005433924589	2115	4	25D
0005433929668	2115	5	14G
0005433924599	2115	6	12D
0005433924577	2115	7	37D
0005432231711	2115	8	17H
0005433924536	2115	9	23G
0005433924544	2115	10	38D
0005433924555	2115	11	4B
0005433924571	2115	12	3H
0005432231706	2115	13	35E
0005433036558	2115	14	11F
0005433036398	2115	15	34A
0005433924547	2115	16	39F
0005433036658	2115	17	30H
0005433036520	2115	18	29H
0005433924573	2115	19	22G
0005433924560	2115	20	20F
0005433924533	2115	21	23H
0005433924596	2115	22	17E
0005433924579	2115	23	28F
0005433924594	2115	24	32B
0005433036519	2115	25	32G
0005433924595	2115	26	27A
0005433924580	2115	27	25F
0005432231709	2115	28	4C
0005433924602	2115	29	4F
0005433036490	2115	30	4A
0005433924574	2115	31	35A
0005433924620	2115	32	30G
0005433036488	2115	33	20B
0005433036444	2115	34	16A
0005433036803	2115	35	37G
0005433924545	2115	36	12G
0005433924597	2115	37	30A
0005433924603	2115	38	30B
0005433924553	2115	39	31G
0005433036515	2115	40	11B
0005433036502	2115	41	11E
0005433929667	2115	42	11G
0005433036671	2115	43	14D
0005433924584	2115	44	1A
0005432749801	2115	45	16H
0005433036480	2115	46	18D
0005433036645	2115	47	22B
0005432231702	2115	48	23B
0005433036804	2115	49	2B
0005433036192	2115	50	34D
0005432231704	2115	51	18H
0005433924617	2115	52	15D
0005433924598	2115	53	13D
0005433924561	2115	54	23A
0005433924615	2115	55	17B
0005433036404	2115	56	2A
0005433924624	2115	57	9A
0005433931509	2115	58	34E
0005433929670	2115	59	36B
0005433924630	2115	60	5A
0005433924548	2115	61	29G
0005433931508	2115	62	37E
0005433924566	2115	63	1F
0005433036363	2115	64	15B
0005433036341	2115	65	17F
0005433924604	2115	66	39D
0005433924585	2115	67	20H
0005433036483	2115	68	1H
0005433924567	2115	69	24D
0005433924564	2115	70	19A
0005433924626	2115	71	22E
0005434028303	2115	72	36G
0005432231703	2115	73	27D
0005433036672	2115	74	21D
0005433036461	2115	75	38A
0005433036455	2115	76	13E
0005433924629	2115	77	31A
0005433924625	2115	78	13B
0005433924631	2115	79	35D
0005433924622	2115	80	18F
0005433924578	2115	81	27E
0005433924575	2115	82	15F
0005433924628	2115	83	21E
0005433924618	2115	84	17G
0005433924586	2115	85	18A
0005433924616	2115	86	28A
0005433931510	2115	87	19E
0005433924607	2115	88	19F
0005433036747	2115	89	24G
0005433924619	2115	90	20E
0005433929669	2115	91	28D
0005433924562	2115	92	38B
0005433036532	2115	93	29B
0005433924550	2115	94	30E
0005433924608	2115	95	12F
0005433924557	2115	96	12B
0005433924546	2115	97	1G
0005433036562	2115	98	35G
0005433036599	2115	99	9G
0005433924534	2115	100	2C
0005433924601	2115	101	1C
0005432231708	2115	102	12H
0005433924606	2115	103	14E
0005433924535	2115	104	21B
0005433924556	2115	105	35H
0005433924611	2115	106	15H
0005433924552	2115	107	2F
0005433036670	2115	108	12E
0005433931507	2115	109	31F
0005433924614	2115	110	27F
0005434028302	2115	111	16G
0005433924558	2115	112	34G
0005433924569	2115	113	19D
0005433924540	2115	114	14A
0005433924565	2115	115	2G
0005433036646	2115	116	11D
0005433036679	2115	117	23F
0005433036563	2115	118	33B
0005433924592	2115	119	18E
0005433924572	2115	120	19H
0005433924621	2115	121	12A
0005433036542	2115	122	3G
0005433924551	2115	123	11A
0005433924538	2115	124	18G
0005433924600	2115	125	3C
0005433036445	2115	126	29D
0005433924605	2115	127	33G
0005433036598	2115	128	37B
0005432749791	2115	129	4G
0005433924609	2115	130	9H
0005433924549	2115	131	11H
0005432044562	2115	132	16D
0005432044563	2115	133	17A
0005433036593	2115	134	21F
0005433924593	2115	135	22A
0005433924570	2115	136	23E
0005432044560	2115	137	24E
0005432231707	2115	138	28G
0005433036514	2115	139	35F
0005432044561	2115	140	36F
0005433924583	2115	141	34H
0005433924537	2115	142	14H
0005434028304	2115	143	31H
0005433924542	2115	144	30F
0005433924539	2115	145	33H
0005432749790	2115	146	20A
0005433924576	2115	147	20D
0005433924627	2115	148	24A
0005433924554	2115	149	3B
0005433036644	2115	150	16B
0005433929666	2115	151	21A
0005433924587	2115	152	22F
0005433036503	2115	153	16E
0005433924563	2115	154	14F
0005433924541	2115	155	31D
0005433924559	2115	156	28B
0005433036375	2115	157	24F
0005432231705	2115	158	22H
0005433924590	2115	159	3A
0005433924610	2115	160	15G
0005433924543	2115	161	38G
0005433036592	2115	162	22D
0005433924623	2115	163	37A
0005433924581	2115	164	1B
0005433924591	2115	165	9B
0005433924588	2115	166	27G
0005434028308	2115	167	25E
0005433036585	2115	168	4H
0005433924582	2115	169	31E
0005433924613	2115	170	32H
0005433924568	2115	171	31B
0005432231701	2115	172	29F
0005432231710	2115	173	13A
0005433929633	24099	1	13D
0005433923913	24099	2	13E
0005432207696	24099	3	13G
0005433923520	24099	4	13H
0005432206274	24099	5	14A
0005433923847	24099	6	14D
0005433923677	24099	7	14F
0005432206276	24099	8	14E
0005433923639	24099	9	14G
0005433923318	24099	10	15B
0005433923928	24099	11	15E
0005433875392	24099	12	16A
0005433923665	24099	13	15H
0005432207698	24099	14	16D
0005433037010	24099	15	16B
0005433036998	24099	16	16G
0005433923910	24099	17	16F
0005433929637	24099	18	16H
0005433929638	24099	19	17B
0005433037002	24099	20	17A
0005434028339	24099	21	17D
0005433037023	24099	22	17F
0005433036999	24099	23	17E
0005433037007	24099	24	17G
0005433923660	24099	25	18A
0005433923809	24099	26	18B
0005433036993	24099	27	18E
0005433037028	24099	28	18G
0005433923984	24099	29	19A
0005433036986	24099	30	19B
0005433923519	24099	31	19D
0005433036991	24099	32	19E
0005433923359	24099	33	20A
0005433924017	24099	34	19H
0005433924391	24099	35	20B
0005433929639	24099	36	20E
0005433923486	24099	37	20D
0005433924165	24099	38	20F
0005433037008	24099	39	20G
0005433923487	24099	40	21D
0005433037025	24099	41	21B
0005433924168	24099	42	21E
0005433036978	24099	43	21G
0005433923994	24099	44	21F
0005433036994	24099	45	22A
0005433923452	24099	46	22D
0005433037001	24099	47	22B
0005433036980	24099	48	22G
0005433037024	24099	49	22H
0005434028338	24099	50	23B
0005433923583	24099	51	23A
0005433037020	24099	52	23D
0005433923940	24099	53	23F
0005433036989	24099	54	23E
0005433036984	24099	55	24A
0005433923463	24099	56	24B
0005433036992	24099	57	24F
0005433931486	24099	58	25D
0005433923436	24099	59	24H
0005433924282	24099	60	25F
0005433923736	24099	61	27B
0005433923961	24099	62	27A
0005433923571	24099	63	27E
0005433036987	24099	64	27D
0005433923481	24099	65	27F
0005433923488	24099	66	27G
0005433929632	24099	67	28A
0005433924013	24099	68	28B
0005433923960	24099	69	28E
0005433037014	24099	70	28D
0005433036977	24099	71	28F
0005433037015	24099	72	28H
0005432206275	24099	73	28G
0005433036988	24099	74	29B
0005433037013	24099	75	29A
0005433923797	24099	76	29D
0005433036995	24099	77	29E
0005433923908	24099	78	29F
0005433924167	24099	79	30A
0005432749815	24099	80	29H
0005432207695	24099	81	30F
0005433037011	24099	82	30H
0005433037000	24099	83	31B
0005433923480	24099	84	31E
0005433923462	24099	85	31D
0005433923655	24099	86	31F
0005433923798	24099	87	31H
0005433036981	24099	88	31G
0005433923632	24099	89	32B
0005433931488	24099	90	32D
0005433037003	24099	91	32G
0005433923780	24099	92	33A
0005433037017	24099	93	32H
0005432206271	24099	94	33E
0005433037022	24099	95	33D
0005433923907	24099	96	33F
0005433923959	24099	97	33G
0005433037029	24099	98	34D
0005433036997	24099	99	34E
0005433924014	24099	100	34G
0005433923849	24099	101	34F
0005433037012	24099	102	35B
0005433923663	24099	103	35A
0005433924012	24099	104	35D
0005432206273	24099	105	35E
0005433923434	24099	106	35G
0005433036976	24099	107	36A
0005433923552	24099	108	36E
0005433923870	24099	109	36F
0005433037018	24099	110	37A
0005433923770	24099	111	36H
0005433923871	24099	112	37D
0005433929635	24099	113	37G
0005433923932	24099	114	38A
0005433923518	24099	115	37H
0005433036983	24099	116	38D
0005433037027	24099	117	38B
0005433923600	24099	118	38E
0005433923895	24099	119	38G
0005433923664	24099	120	39E
0005433036990	24099	121	34B
0005433036996	24099	122	39D
0005433036982	24099	123	1A
0005433037004	24099	124	1C
0005433923688	24099	125	1B
0005433923779	24099	126	1F
0005433923607	24099	127	1G
0005433923577	24099	128	2A
0005433037019	24099	129	1H
0005433037006	24099	130	2C
0005433923396	24099	131	3A
0005433923862	24099	132	3B
0005433923389	24099	133	3C
0005433923608	24099	134	3H
0005433923946	24099	135	3G
0005433923857	24099	136	3F
0005433923931	24099	137	4A
0005433037021	24099	138	4G
0005433036985	24099	139	4H
0005433923630	24099	140	5B
0005433037016	24099	141	5F
0005432207697	24099	142	5G
0005433037026	24099	143	9B
0005433923690	24099	144	9H
0005433923850	24099	145	11B
0005433037005	24099	146	11F
0005433037009	24099	147	11H
0005433923769	24099	148	11G
0005433931489	24099	149	12D
0005433923856	24099	150	12B
0005433036979	24099	151	12F
0005433923768	24099	152	12H
0005433923728	24099	153	12G
0005432206272	24099	154	13B
0005434551972	281	1	22C
0005432277989	281	2	1G
0005434727077	281	3	1D
0005433113548	281	4	2A
0005432277994	281	5	2G
0005433126859	281	6	3A
0005434727059	281	7	2K
0005434727097	281	8	3G
0005434727104	281	9	3K
0005433234370	281	10	3H
0005434727047	281	11	4C
0005434727054	281	12	4A
0005433131731	281	13	4H
0005434551950	281	14	4G
0005434727142	281	15	4D
0005433234494	281	16	4K
0005434727139	281	17	5C
0005435142758	281	18	5H
0005434727131	281	19	5G
0005434551990	281	20	5D
0005434727044	281	21	11A
0005433181246	281	22	5K
0005434727107	281	23	11D
0005433234545	281	24	11C
0005434551962	281	25	11E
0005434727055	281	26	11K
0005433113538	281	27	11H
0005432277993	281	28	11G
0005433766641	281	29	12A
0005434735758	281	30	12E
0005434032061	281	31	12D
0005434551945	281	32	12G
0005435142762	281	33	12F
0005433234528	281	34	13A
0005433111513	281	35	12K
0005434551971	281	36	13D
0005432277988	281	37	13C
0005434727117	281	38	13F
0005434735754	281	39	13E
0005434551954	281	40	13H
0005434551955	281	41	14C
0005434727137	281	42	14A
0005433113551	281	43	13K
0005434551960	281	44	14D
0005434727064	281	45	14G
0005435142752	281	46	14F
0005434727040	281	47	14E
0005434727057	281	48	14K
0005433181230	281	49	14H
0005433234684	281	50	15A
0005432277986	281	51	15E
0005434032051	281	52	15D
0005434727145	281	53	15G
0005433234476	281	54	16A
0005434551963	281	55	15K
0005434727113	281	56	15H
0005433131726	281	57	16D
0005434727151	281	58	16F
0005434551966	281	59	16E
0005433181229	281	60	16H
0005434727034	281	61	16G
0005433234655	281	62	17C
0005432277982	281	63	17A
0005434727128	281	64	16K
0005434727075	281	65	17E
0005434551987	281	66	17D
0005434727100	281	67	17F
0005434727148	281	68	18A
0005434727052	281	69	17K
0005434551968	281	70	17H
0005434727122	281	71	18C
0005434551957	281	72	18G
0005434727141	281	73	18F
0005433234604	281	74	18J
0005434727088	281	75	18H
0005434551975	281	76	18K
0005434727035	281	77	19D
0005435142756	281	78	19C
0005433234266	281	79	19B
0005434727063	281	80	19F
0005433234541	281	81	19E
0005434551948	281	82	19J
0005434727138	281	83	19H
0005434727144	281	84	19G
0005434727068	281	85	19K
0005433234712	281	86	20C
0005433234628	281	87	20A
0005434727093	281	88	20F
0005434727043	281	89	20E
0005433234599	281	90	20D
0005433181123	281	91	20G
0005434735757	281	92	20K
0005433234817	281	93	20J
0005433766648	281	94	20H
0005434551949	281	95	21B
0005433234646	281	96	21A
0005434727083	281	97	21D
0005434727102	281	98	21C
0005434551964	281	99	21G
0005434727133	281	100	21F
0005434727134	281	101	21E
0005434727101	281	102	21J
0005434727050	281	103	21H
0005434727061	281	104	22A
0005434727058	281	105	21K
0005433111517	281	106	22B
0005435142760	281	107	22E
0005434727103	281	108	22D
0005433234553	281	109	22G
0005433126863	281	110	22F
0005433234348	281	111	22J
0005434727038	281	112	23B
0005434727123	281	113	23A
0005435142755	281	114	22K
0005434727120	281	115	23D
0005433234615	281	116	23C
0005434727096	281	117	23G
0005433234603	281	118	23F
0005434727146	281	119	23E
0005434727046	281	120	23J
0005434727031	281	121	23K
0005434727135	281	122	24G
0005433181188	281	123	24E
0005433234477	281	124	25A
0005434551989	281	125	25D
0005432277990	281	126	25C
0005434727143	281	127	25F
0005434727070	281	128	25E
0005434551976	281	129	25H
0005433234585	281	130	26A
0005434727037	281	131	25K
0005434551974	281	132	25J
0005434727051	281	133	26C
0005432277991	281	134	26B
0005434551988	281	135	26E
0005435142759	281	136	26D
0005434551958	281	137	26G
0005433181172	281	138	26J
0005433181173	281	139	26H
0005434727072	281	140	27B
0005434727118	281	141	27A
0005433234661	281	142	26K
0005434735752	281	143	27D
0005434551947	281	144	27C
0005434551953	281	145	27F
0005434727108	281	146	27E
0005434727049	281	147	27G
0005434727149	281	148	27J
0005434727152	281	149	28C
0005434551984	281	150	28B
0005435142764	281	151	28A
0005433181321	281	152	28D
0005435142754	281	153	28G
0005433766649	281	154	28F
0005434727078	281	155	28K
0005433234530	281	156	28J
0005434551941	281	157	28H
0005434727136	281	158	29A
0005434551946	281	159	29D
0005434731224	281	160	29B
0005434551991	281	161	29F
0005434727039	281	162	29E
0005434727125	281	163	29H
0005433181252	281	164	29G
0005434302516	281	165	30A
0005434727092	281	166	29K
0005434551970	281	167	29J
0005434727147	281	168	30C
0005434727032	281	169	30B
0005433181241	281	170	30E
0005434727066	281	171	30D
0005433234816	281	172	30G
0005433131707	281	173	30F
0005433181122	281	174	30J
0005434727084	281	175	30H
0005434727121	281	176	31B
0005434727098	281	177	30K
0005433289863	281	178	31D
0005434727076	281	179	31C
0005434727116	281	180	31F
0005434727082	281	181	31E
0005434727074	281	182	31H
0005434727090	281	183	31G
0005433766656	281	184	32A
0005434727036	281	185	31K
0005434727095	281	186	31J
0005434551983	281	187	32B
0005434551992	281	188	32E
0005434551940	281	189	32D
0005434032054	281	190	32C
0005434727127	281	191	32G
0005434727081	281	192	32F
0005433234427	281	193	32H
0005433234602	281	194	33B
0005433181150	281	195	33A
0005433234601	281	196	32K
0005434727087	281	197	33D
0005434735755	281	198	33C
0005434727056	281	199	33F
0005433131704	281	200	33E
0005433234544	281	201	33H
0005433234566	281	202	33G
0005434727060	281	203	34A
0005434302517	281	204	33K
0005434302520	281	205	33J
0005432277985	281	206	34E
0005433126865	281	207	34D
0005434551969	281	208	34C
0005432277992	281	209	34H
0005433289889	281	210	34F
0005435142763	281	211	34J
0005433234536	281	212	35A
0005433766661	281	213	35D
0005434727033	281	214	35C
0005433234559	281	215	35F
0005433234349	281	216	35E
0005432277983	281	217	35H
0005433234108	281	218	36A
0005435142753	281	219	35K
0005434727111	281	220	35J
0005433234312	281	221	36C
0005434735756	281	222	36B
0005433234590	281	223	36F
0005433234535	281	224	36E
0005433234414	281	225	36H
0005434551943	281	226	36K
0005434551979	281	227	36J
0005433234656	281	228	37B
0005434032041	281	229	37A
0005433234489	281	230	37E
0005434727065	281	231	37D
0005435142751	281	232	37C
0005434727150	281	233	37F
0005434727130	281	234	37J
0005433113549	281	235	37H
0005433181223	281	236	37G
0005434302519	281	237	37K
0005434727132	281	238	38C
0005433234647	281	239	38B
0005433234441	281	240	38K
0005433131732	281	241	38J
0005433234654	281	242	38H
0005433234695	281	243	39B
0005433234662	281	244	39A
0005434727067	281	245	39F
0005433181260	281	246	39D
0005433234571	281	247	39J
0005434727140	281	248	39H
0005434727124	281	249	39G
0005434551951	281	250	40A
0005434727041	281	251	39K
0005435142757	281	252	40C
0005434551938	281	253	40B
0005434727053	281	254	40E
0005434731223	281	255	40D
0005434727109	281	256	40H
0005433234572	281	257	40G
0005434727091	281	258	40F
0005434551986	281	259	40K
0005434727119	281	260	40J
0005433181148	281	261	41D
0005434727114	281	262	41C
0005433181236	281	263	41B
0005433234696	281	264	41F
0005434551967	281	265	41E
0005434551981	281	266	41H
0005433126861	281	267	42A
0005433234799	281	268	41J
0005433234368	281	269	42C
0005434551942	281	270	42B
0005433234738	281	271	42E
0005434727115	281	272	42D
0005434727129	281	273	42H
0005434727110	281	274	42G
0005434731222	281	275	42F
0005434551952	281	276	42K
0005434551973	281	277	42J
0005434727094	281	278	43B
0005434727089	281	279	43D
0005434727030	281	280	43C
0005434727126	281	281	43F
0005434727112	281	282	43E
0005434551965	281	283	43H
0005434727086	281	284	43G
0005433289862	281	285	44A
0005433234582	281	286	43K
0005434727062	281	287	44C
0005433111514	281	288	44B
0005432277987	281	289	44E
0005433234440	281	290	44D
0005434727042	281	291	44K
0005433113550	281	292	44J
0005434551982	281	293	44H
0005434727106	281	294	45A
0005434551978	281	295	45D
0005434727048	281	296	45C
0005433234417	281	297	45B
0005433131725	281	298	45E
0005434727045	281	299	45J
0005434727080	281	300	45H
0005434731225	281	301	45G
0005434551959	281	302	46A
0005434727073	281	303	45K
0005433234371	281	304	46B
0005433113537	281	305	46E
0005433234353	281	306	46D
0005433234327	281	307	46F
0005432277984	281	308	46K
0005434551937	281	309	47C
0005435142761	281	310	47A
0005434302518	281	311	47E
0005434727069	281	312	47D
0005434735753	281	313	47G
0005433234623	281	314	47F
0005433234369	281	315	48A
0005434727079	281	316	47K
0005434551977	281	317	48F
0005434551961	281	318	48E
0005434727105	281	319	48D
0005433234552	281	320	48G
0005433234627	281	321	49A
0005434727071	281	322	48K
0005434727099	281	323	49D
0005434727029	281	324	49C
0005434551956	281	325	49G
0005433234560	281	326	49F
0005434727085	281	327	49K
0005434551985	281	328	49H
0005433181224	281	329	50C
0005434551944	281	330	50A
0005433234488	281	331	50D
0005433234356	281	332	50G
0005434551980	281	333	50F
0005433234426	281	334	51D
0005433234404	281	335	50H
0005434551939	281	336	51F
0005433181114	281	337	51E
0005433181329	281	338	51G
0005434725897	9864	1	1D
0005433181447	9864	2	1C
0005434726490	9864	3	1A
0005434726024	9864	4	1G
0005433235044	9864	5	2A
0005433181434	9864	6	1K
0005434726269	9864	7	1H
0005432199340	9864	8	2C
0005434551676	9864	9	2H
0005434302478	9864	10	2G
0005434725510	9864	11	3A
0005433181440	9864	12	2K
0005433289946	9864	13	3D
0005434725681	9864	14	3C
0005434726360	9864	15	3H
0005433289945	9864	16	3G
0005434726449	9864	17	4A
0005434726293	9864	18	3K
0005434726078	9864	19	4G
0005433235055	9864	20	4K
0005433235030	9864	21	4H
0005434726436	9864	22	5D
0005433235052	9864	23	5C
0005434731194	9864	24	5H
0005434551344	9864	25	11A
0005434726218	9864	26	5K
0005435142656	9864	27	11D
0005434726304	9864	28	11C
0005433235015	9864	29	11G
0005433235058	9864	30	11F
0005434726320	9864	31	11E
0005434551361	9864	32	11K
0005434551299	9864	33	11H
0005433235051	9864	34	12C
0005433181425	9864	35	12A
0005433289940	9864	36	12E
0005434726341	9864	37	12D
0005434725701	9864	38	12G
0005434725860	9864	39	13A
0005433235065	9864	40	12K
0005433126903	9864	41	12H
0005433235033	9864	42	13D
0005433235069	9864	43	13C
0005434725937	9864	44	13F
0005434725829	9864	45	13E
0005434725856	9864	46	13K
0005433181427	9864	47	13H
0005433181432	9864	48	13G
0005434731183	9864	49	14C
0005434551566	9864	50	14A
0005434551597	9864	51	14D
0005435142642	9864	52	14G
0005434551558	9864	53	14F
0005434551677	9864	54	14K
0005434551245	9864	55	14H
0005433235046	9864	56	15D
0005434725858	9864	57	15C
0005433126907	9864	58	15A
0005434302492	9864	59	15F
0005434725862	9864	60	15G
0005434726272	9864	61	16A
0005434551595	9864	62	15K
0005434032087	9864	63	15H
0005433235068	9864	64	16C
0005434726121	9864	65	16F
0005434551112	9864	66	16E
0005434551298	9864	67	16G
0005434725818	9864	68	17A
0005434551392	9864	69	16K
0005434725817	9864	70	17D
0005434726116	9864	71	17C
0005433235073	9864	72	17G
0005433235020	9864	73	17F
0005434551545	9864	74	17K
0005434726023	9864	75	17H
0005433181430	9864	76	18B
0005433235029	9864	77	18E
0005432199343	9864	78	18D
0005434551588	9864	79	18C
0005435142599	9864	80	18G
0005434726305	9864	81	18F
0005434551369	9864	82	18H
0005434551631	9864	83	19A
0005434725828	9864	84	18K
0005434551578	9864	85	19D
0005433113565	9864	86	19C
0005433766691	9864	87	19F
0005433181446	9864	88	19E
0005434725981	9864	89	19G
0005433235075	9864	90	20A
0005434725861	9864	91	19K
0005433235047	9864	92	19J
0005434551430	9864	93	20C
0005434726072	9864	94	20B
0005434551271	9864	95	20E
0005433181444	9864	96	20D
0005434726202	9864	97	20G
0005433289944	9864	98	20F
0005433289939	9864	99	20J
0005434726040	9864	100	20H
0005433235064	9864	101	21A
0005435142650	9864	102	21C
0005434725916	9864	103	21B
0005433235041	9864	104	21F
0005433235074	9864	105	21H
0005434725859	9864	106	21G
0005434551370	9864	107	22A
0005433126905	9864	108	21J
0005434726458	9864	109	22B
0005434725682	9864	110	22E
0005433181436	9864	111	22D
0005434726168	9864	112	22G
0005434551476	9864	113	22K
0005434551307	9864	114	22J
0005433235045	9864	115	23C
0005434735707	9864	116	23B
0005434032086	9864	117	23A
0005432199341	9864	118	23D
0005433766690	9864	119	23F
0005434725982	9864	120	23E
0005433235063	9864	121	23J
0005434551454	9864	122	23H
0005434725881	9864	123	23G
0005434726076	9864	124	24D
0005433235077	9864	125	23K
0005433235017	9864	126	24E
0005434726013	9864	127	25A
0005434726430	9864	128	24G
0005433235024	9864	129	25D
0005433126904	9864	130	25F
0005434551791	9864	131	25E
0005434725564	9864	132	25H
0005434725595	9864	133	25K
0005433289942	9864	134	25J
0005433235053	9864	135	26B
0005435142548	9864	136	26A
0005433181438	9864	137	26D
0005434726286	9864	138	26G
0005434551496	9864	139	26J
0005433181433	9864	140	26H
0005433113564	9864	141	27B
0005433181448	9864	142	27A
0005434551490	9864	143	26K
0005434726178	9864	144	27C
0005435142597	9864	145	27E
0005434725743	9864	146	27D
0005434726292	9864	147	27H
0005434725700	9864	148	27G
0005433181442	9864	149	28A
0005433181429	9864	150	27K
0005433181445	9864	151	28B
0005433235025	9864	152	28E
0005434725693	9864	153	28C
0005434551598	9864	154	28G
0005435142621	9864	155	28F
0005432199344	9864	156	28J
0005434725921	9864	157	28H
0005434551789	9864	158	29A
0005434551246	9864	159	29D
0005435142628	9864	160	29F
0005434726359	9864	161	29J
0005434551591	9864	162	29H
0005434726144	9864	163	29G
0005433235060	9864	164	30A
0005434725919	9864	165	29K
0005434725732	9864	166	30C
0005433235056	9864	167	30B
0005435142645	9864	168	30E
0005434725554	9864	169	30D
0005434551451	9864	170	30G
0005434726152	9864	171	30F
0005434726764	9864	172	30H
0005434726263	9864	173	31A
0005433129338	9864	174	30K
0005433289947	9864	175	31D
0005433235023	9864	176	31C
0005434726113	9864	177	31F
0005435142595	9864	178	31E
0005434725880	9864	179	31H
0005433235035	9864	180	31G
0005434725833	9864	181	32A
0005434725588	9864	182	31K
0005434551423	9864	183	32C
0005434551477	9864	184	32B
0005433181435	9864	185	32E
0005433235072	9864	186	32D
0005433235076	9864	187	32G
0005434725734	9864	188	32F
0005433235037	9864	189	32J
0005434725917	9864	190	32H
0005433235039	9864	191	33B
0005433235067	9864	192	33A
0005434551306	9864	193	32K
0005433181428	9864	194	33D
0005434725585	9864	195	33C
0005434735708	9864	196	33F
0005434302501	9864	197	33E
0005433766692	9864	198	33J
0005434726153	9864	199	33H
0005435142651	9864	200	33G
0005434726217	9864	201	34A
0005434725960	9864	202	33K
0005433235043	9864	203	34C
0005433235038	9864	204	34B
0005433235061	9864	205	34E
0005434726284	9864	206	34G
0005434726133	9864	207	34F
0005433289941	9864	208	34J
0005435142618	9864	209	34H
0005433235071	9864	210	35B
0005434551230	9864	211	35A
0005433181431	9864	212	35D
0005433235027	9864	213	35F
0005433235040	9864	214	35E
0005434551484	9864	215	35H
0005434551356	9864	216	35G
0005434726321	9864	217	36A
0005434551375	9864	218	35K
0005433235042	9864	219	36E
0005434731170	9864	220	36D
0005434725872	9864	221	36H
0005434725830	9864	222	36G
0005434726027	9864	223	36F
0005433181439	9864	224	36J
0005434551537	9864	225	37A
0005434725733	9864	226	36K
0005434551491	9864	227	37D
0005434551374	9864	228	37G
0005432199342	9864	229	37E
0005434735715	9864	230	37H
0005434725896	9864	231	38A
0005434302500	9864	232	37K
0005433129336	9864	233	37J
0005435142643	9864	234	38C
0005433235019	9864	235	38B
0005434726457	9864	236	38H
0005434725672	9864	237	38K
0005434726237	9864	238	39D
0005434726633	9864	239	39C
0005433235059	9864	240	39B
0005433181426	9864	241	39F
0005433235057	9864	242	39E
0005433181437	9864	243	39G
0005434551580	9864	244	39K
0005434726146	9864	245	39J
0005435142667	9864	246	40B
0005434726134	9864	247	40A
0005434726114	9864	248	40E
0005433235062	9864	249	40D
0005434726070	9864	250	40H
0005434725834	9864	251	40F
0005434726171	9864	252	40K
0005434726285	9864	253	40J
0005434551584	9864	254	41B
0005434032084	9864	255	41D
0005434551589	9864	256	41E
0005434735716	9864	257	41J
0005433235028	9864	258	41H
0005435142596	9864	259	41G
0005434551349	9864	260	42A
0005434725894	9864	261	41K
0005434726048	9864	262	42B
0005434551450	9864	263	42D
0005433235049	9864	264	42C
0005433235032	9864	265	42H
0005432199339	9864	266	42G
0005433235026	9864	267	42F
0005433235014	9864	268	43B
0005433235022	9864	269	43A
0005434726017	9864	270	42K
0005434551579	9864	271	43D
0005434551532	9864	272	43C
0005433113566	9864	273	43F
0005434551790	9864	274	43E
0005434032085	9864	275	43H
0005434725692	9864	276	43G
0005433181443	9864	277	43K
0005434726526	9864	278	43J
0005434731181	9864	279	44B
0005434551531	9864	280	44A
0005433235018	9864	281	44E
0005434032088	9864	282	44D
0005435142620	9864	283	44C
0005434731182	9864	284	44G
0005434302484	9864	285	44F
0005434551405	9864	286	44K
0005434725511	9864	287	44H
0005434725555	9864	288	45A
0005434302477	9864	289	45D
0005433235021	9864	290	45C
0005434726216	9864	291	45B
0005434551357	9864	292	45F
0005434551424	9864	293	45E
0005434551203	9864	294	45G
0005433235054	9864	295	45K
0005434551333	9864	296	45J
0005434726531	9864	297	46B
0005433766693	9864	298	46A
0005434726041	9864	299	46D
0005433235050	9864	300	46C
0005433129337	9864	301	46G
0005434726138	9864	302	46F
0005433181441	9864	303	46J
0005434725979	9864	304	47A
0005434551385	9864	305	46K
0005433235036	9864	306	47E
0005434551380	9864	307	47D
0005433129335	9864	308	47G
0005435142594	9864	309	47F
0005433235048	9864	310	48C
0005433235066	9864	311	48A
0005434725596	9864	312	48F
0005434735711	9864	313	48E
0005434302486	9864	314	48D
0005433289943	9864	315	48H
0005434726169	9864	316	48G
0005434725832	9864	317	49A
0005434551577	9864	318	48K
0005434726071	9864	319	49D
0005434725893	9864	320	49F
0005433235034	9864	321	49E
0005434551485	9864	322	49K
0005434725821	9864	323	49H
0005433126906	9864	324	49G
0005433235031	9864	325	50D
0005434551671	9864	326	50C
0005434725835	9864	327	50A
0005433235070	9864	328	50F
0005434725871	9864	329	50E
0005434725049	9864	330	50H
0005435142619	9864	331	51D
0005434725710	9864	332	50K
0005433235016	9864	333	51E
0005434551400	9864	334	51G
0005434068521	7735	1	1C
0005432529671	7735	2	1A
0005432529789	7735	3	1G
0005432150296	7735	4	2A
0005432529722	7735	5	1K
0005434068481	7735	6	1H
0005432529684	7735	7	2C
0005432069854	7735	8	2G
0005432529739	7735	9	2D
0005435213725	7735	10	3A
0005432529701	7735	11	2K
0005432529773	7735	12	2H
0005432069849	7735	13	3D
0005434068529	7735	14	3C
0005432533329	7735	15	3K
0005432529681	7735	16	3G
0005435213900	7735	17	4G
0005434068500	7735	18	4D
0005432529688	7735	19	4H
0005432529774	7735	20	5D
0005434068540	7735	21	5C
0005432533330	7735	22	5A
0005434068513	7735	23	5G
0005434068546	7735	24	11A
0005432529692	7735	25	5K
0005435213995	7735	26	11D
0005432069855	7735	27	11C
0005432529665	7735	28	11F
0005435214034	7735	29	11E
0005435213979	7735	30	11H
0005434068495	7735	31	12A
0005432529775	7735	32	11K
0005432529729	7735	33	12E
0005435213881	7735	34	12D
0005434068474	7735	35	12C
0005432529750	7735	36	12F
0005434068532	7735	37	12K
0005434068530	7735	38	12H
0005434068498	7735	39	13C
0005432529699	7735	40	13A
0005434068535	7735	41	13H
0005432529741	7735	42	13G
0005432529785	7735	43	14A
0005434068520	7735	44	13K
0005434068480	7735	45	14D
0005432529760	7735	46	14C
0005432529780	7735	47	14F
0005432529735	7735	48	14E
0005435213771	7735	49	14K
0005433656696	7735	50	14G
0005432529778	7735	51	15C
0005432529749	7735	52	15A
0005435214055	7735	53	15F
0005435213561	7735	54	15E
0005432529786	7735	55	15D
0005434068475	7735	56	15H
0005434068544	7735	57	15G
0005432529768	7735	58	16A
0005432529734	7735	59	15K
0005435213893	7735	60	16D
0005432428975	7735	61	16E
0005432529695	7735	62	16H
0005432529661	7735	63	17A
0005432529777	7735	64	17E
0005435630975	7735	65	17D
0005432529715	7735	66	17C
0005435725629	7735	67	17G
0005432529683	7735	68	17F
0005432529720	7735	69	17K
0005432529756	7735	70	18C
0005432529691	7735	71	18A
0005435725613	7735	72	18D
0005432428973	7735	73	18H
0005432529660	7735	74	18G
0005435213991	7735	75	18F
0005432535898	7735	76	18E
0005432529668	7735	77	18J
0005434068508	7735	78	19B
0005432529746	7735	79	19A
0005432529659	7735	80	18K
0005435213912	7735	81	19D
0005435213843	7735	82	19F
0005432529667	7735	83	19E
0005432529723	7735	84	19H
0005432150300	7735	85	19G
0005432529730	7735	86	19K
0005432529758	7735	87	19J
0005435213827	7735	88	20C
0005435213768	7735	89	20A
0005434068493	7735	90	20E
0005435213936	7735	91	20D
0005432529790	7735	92	20H
0005432529744	7735	93	20G
0005434068533	7735	94	20F
0005434068510	7735	95	20K
0005435213935	7735	96	21B
0005432537085	7735	97	21A
0005432069845	7735	98	21D
0005432069853	7735	99	21C
0005432529719	7735	100	21G
0005432150299	7735	101	21F
0005432535897	7735	102	21E
0005435213878	7735	103	21H
0005432529664	7735	104	22A
0005435214129	7735	105	21K
0005434068514	7735	106	21J
0005434068527	7735	107	22C
0005435213978	7735	108	22B
0005432529779	7735	109	22D
0005434068539	7735	110	22H
0005432529772	7735	111	22G
0005432069851	7735	112	22F
0005432529711	7735	113	22J
0005435214088	7735	114	23B
0005432529685	7735	115	23A
0005432529751	7735	116	23D
0005432529742	7735	117	23C
0005435213842	7735	118	23F
0005432529788	7735	119	23E
0005434068483	7735	120	23H
0005434068512	7735	121	23J
0005434068545	7735	122	24F
0005435214007	7735	123	24G
0005432529682	7735	124	25D
0005435213854	7735	125	25C
0005434068482	7735	126	25B
0005432529697	7735	127	25F
0005435213690	7735	128	25H
0005435213851	7735	129	25G
0005432529693	7735	130	26A
0005432069852	7735	131	25K
0005434068486	7735	132	25J
0005434068496	7735	133	26C
0005435213908	7735	134	26E
0005432529714	7735	135	26G
0005432529673	7735	136	26F
0005432529763	7735	137	26K
0005435213983	7735	138	26J
0005432529784	7735	139	26H
0005432069846	7735	140	27B
0005435213833	7735	141	27A
0005432529766	7735	142	27J
0005434068543	7735	143	27H
0005432529710	7735	144	27G
0005435725609	7735	145	28A
0005435213671	7735	146	27K
0005432529680	7735	147	28C
0005434068489	7735	148	28D
0005434068499	7735	149	28F
0005432529669	7735	150	28J
0005432529666	7735	151	28H
0005435213770	7735	152	29A
0005432150297	7735	153	29D
0005435725627	7735	154	29B
0005432069848	7735	155	29F
0005432069842	7735	156	29E
0005432529726	7735	157	29H
0005432529761	7735	158	29G
0005434068525	7735	159	29K
0005434068484	7735	160	29J
0005432529745	7735	161	30C
0005434068497	7735	162	30B
0005432529783	7735	163	30A
0005432529754	7735	164	30E
0005432529771	7735	165	30D
0005435630984	7735	166	30G
0005432069841	7735	167	30F
0005432533331	7735	168	30J
0005435725628	7735	169	30H
0005432069847	7735	170	31A
0005432529743	7735	171	31D
0005434068494	7735	172	31F
0005432529738	7735	173	31E
0005435213961	7735	174	31H
0005432069850	7735	175	31G
0005434068504	7735	176	31K
0005432529764	7735	177	32C
0005432529678	7735	178	32E
0005434068507	7735	179	32D
0005432529696	7735	180	32F
0005432529759	7735	181	32K
0005434068538	7735	182	32J
0005432529753	7735	183	32H
0005432529757	7735	184	33B
0005432529690	7735	185	33D
0005434068503	7735	186	33C
0005435213950	7735	187	33F
0005435213879	7735	188	33J
0005435213921	7735	189	33H
0005432529765	7735	190	33G
0005434068523	7735	191	34C
0005435213832	7735	192	34B
0005434068517	7735	193	34A
0005434068476	7735	194	34E
0005433656695	7735	195	34G
0005432529725	7735	196	34K
0005432529679	7735	197	34J
0005434068492	7735	198	34H
0005434068490	7735	199	35A
0005435213772	7735	200	35D
0005435213909	7735	201	35C
0005432150302	7735	202	35F
0005432529767	7735	203	35E
0005432529718	7735	204	35H
0005435214128	7735	205	35G
0005434068516	7735	206	36A
0005432529731	7735	207	35K
0005435213780	7735	208	36C
0005434068542	7735	209	36B
0005435213882	7735	210	36E
0005432529705	7735	211	36D
0005432529716	7735	212	36G
0005435213905	7735	213	36F
0005432535896	7735	214	36K
0005435725599	7735	215	36H
0005434068528	7735	216	37B
0005432529662	7735	217	37A
0005435213971	7735	218	37D
0005435630978	7735	219	37C
0005432529769	7735	220	37G
0005435213911	7735	221	37E
0005432529787	7735	222	37H
0005432529700	7735	223	38A
0005432069843	7735	224	37K
0005435725600	7735	225	37J
0005432529717	7735	226	38C
0005434068515	7735	227	38J
0005432529672	7735	228	38H
0005434068531	7735	229	39B
0005434068488	7735	230	39A
0005432529732	7735	231	39D
0005432529713	7735	232	39C
0005432529670	7735	233	39F
0005432529689	7735	234	39E
0005435213899	7735	235	39J
0005432529733	7735	236	39H
0005432529752	7735	237	39G
0005432529708	7735	238	40A
0005435214011	7735	239	39K
0005434068524	7735	240	40C
0005432529770	7735	241	40B
0005432529727	7735	242	40E
0005434068505	7735	243	40D
0005435213840	7735	244	40H
0005434068478	7735	245	40G
0005434068536	7735	246	40K
0005432529791	7735	247	40J
0005432529776	7735	248	41A
0005432069844	7735	249	41D
0005435213855	7735	250	41C
0005434068522	7735	251	41F
0005432529721	7735	252	41E
0005435214040	7735	253	41H
0005434068526	7735	254	41G
0005435213895	7735	255	42A
0005435213933	7735	256	41J
0005435213984	7735	257	42C
0005432529712	7735	258	42B
0005434068518	7735	259	42E
0005432535900	7735	260	42D
0005432529737	7735	261	42G
0005432529781	7735	262	42F
0005435213962	7735	263	42J
0005433656688	7735	264	42H
0005434068479	7735	265	43A
0005434068502	7735	266	43C
0005432529755	7735	267	43F
0005432529698	7735	268	43E
0005435213670	7735	269	43J
0005434068534	7735	270	43H
0005435213964	7735	271	43G
0005432529748	7735	272	44B
0005432529703	7735	273	44E
0005434068511	7735	274	44D
0005432428974	7735	275	44G
0005432150298	7735	276	44F
0005434068519	7735	277	45B
0005435214041	7735	278	45A
0005434068485	7735	279	45C
0005432529694	7735	280	45G
0005435283408	7735	281	45F
0005432529676	7735	282	45E
0005434068501	7735	283	45D
0005434068487	7735	284	45H
0005432529663	7735	285	46A
0005432535899	7735	286	45J
0005434068541	7735	287	46C
0005435725612	7735	288	46B
0005432529747	7735	289	46E
0005435630972	7735	290	46H
0005432529675	7735	291	46G
0005433656672	7735	292	46F
0005435214084	7735	293	46J
0005434068506	7735	294	47C
0005435213826	7735	295	47A
0005432529728	7735	296	47E
0005432529702	7735	297	47D
0005432529707	7735	298	47G
0005432529736	7735	299	47F
0005434068473	7735	300	47K
0005434068509	7735	301	48D
0005432529762	7735	302	48C
0005432529709	7735	303	48A
0005434068477	7735	304	48F
0005432529677	7735	305	48E
0005432529706	7735	306	48G
0005435213880	7735	307	49A
0005432529740	7735	308	48K
0005432529687	7735	309	49E
0005435213932	7735	310	49D
0005432529782	7735	311	49G
0005432529686	7735	312	49F
0005434068537	7735	313	49K
0005432150303	7735	314	49H
0005435213977	7735	315	50A
0005432150301	7735	316	50D
0005434068491	7735	317	50H
0005432529724	7735	318	50G
0005432529704	7735	319	50F
0005432537086	7735	320	50K
0005435213773	7735	321	51E
0005435213850	7735	322	51D
0005432529674	7735	323	51G
0005435615187	5344	1	1C
0005435615099	5344	2	1A
0005432047600	5344	3	1G
0005435425208	5344	4	1D
0005435425227	5344	5	2A
0005435425342	5344	6	1K
0005435424767	5344	7	2D
0005435615111	5344	8	2C
0005432133416	5344	9	2G
0005435615202	5344	10	3A
0005435615185	5344	11	2K
0005434573547	5344	12	2H
0005435615179	5344	13	3G
0005435302226	5344	14	3D
0005434245098	5344	15	3C
0005435302225	5344	16	3K
0005435615159	5344	17	3H
0005435425337	5344	18	4C
0005435615170	5344	19	4A
0005435615121	5344	20	4G
0005432133414	5344	21	4D
0005434656556	5344	22	4K
0005435425375	5344	23	4H
0005432363439	5344	24	5D
0005435319676	5344	25	5A
0005433719158	5344	26	5H
0005434344685	5344	27	5G
0005435615180	5344	28	11A
0005435615165	5344	29	5K
0005435615117	5344	30	11E
0005433719150	5344	31	11D
0005435305017	5344	32	11F
0005434344703	5344	33	11K
0005434344706	5344	34	11G
0005435615177	5344	35	12C
0005435490277	5344	36	12A
0005435615203	5344	37	12E
0005435615142	5344	38	12D
0005435425321	5344	39	12H
0005435615174	5344	40	12G
0005432133411	5344	41	12F
0005435425162	5344	42	12K
0005435425258	5344	43	13D
0005435425131	5344	44	13C
0005432841014	5344	45	13A
0005435615160	5344	46	13E
0005435425145	5344	47	13H
0005435425297	5344	48	14C
0005435425044	5344	49	14A
0005435615151	5344	50	13K
0005434344699	5344	51	14D
0005435425015	5344	52	14G
0005435615214	5344	53	14F
0005435425129	5344	54	14E
0005434573537	5344	55	14K
0005435097338	5344	56	14H
0005434344693	5344	57	15C
0005435615108	5344	58	15E
0005435615206	5344	59	15D
0005435615144	5344	60	15G
0005435615217	5344	61	15F
0005434245246	5344	62	16A
0005435425169	5344	63	15K
0005435615176	5344	64	15H
0005434573539	5344	65	16C
0005434244991	5344	66	16F
0005435615135	5344	67	16G
0005435097333	5344	68	17C
0005434573535	5344	69	17A
0005435615097	5344	70	16K
0005435615210	5344	71	17E
0005435425135	5344	72	17D
0005434245015	5344	73	17G
0005435425242	5344	74	17F
0005435425097	5344	75	17K
0005435615120	5344	76	18B
0005435615158	5344	77	18A
0005435425388	5344	78	18E
0005435615213	5344	79	18D
0005435425389	5344	80	18C
0005435424801	5344	81	18H
0005434573548	5344	82	18F
0005435425482	5344	83	18J
0005434344687	5344	84	19B
0005435424928	5344	85	19A
0005434344695	5344	86	18K
0005435615205	5344	87	19C
0005435615122	5344	88	19F
0005435425128	5344	89	19E
0005435615104	5344	90	19J
0005434245219	5344	91	19H
0005435380315	5344	92	19G
0005435615199	5344	93	19K
0005435425240	5344	94	20B
0005435615126	5344	95	20A
0005434573540	5344	96	20E
0005435615164	5344	97	20D
0005435425192	5344	98	20C
0005435319597	5344	99	20G
0005434245045	5344	100	20K
0005435615115	5344	101	20H
0005432133412	5344	102	21A
0005434656565	5344	103	21D
0005434344678	5344	104	21B
0005435615196	5344	105	21F
0005435425303	5344	106	21E
0005435615207	5344	107	21J
0005433719157	5344	108	21H
0005435615169	5344	109	22A
0005435615195	5344	110	22C
0005435490278	5344	111	22B
0005434344691	5344	112	22E
0005434573538	5344	113	22D
0005435380323	5344	114	22H
0005435097336	5344	115	22G
0005434344688	5344	116	22K
0005435097342	5344	117	22J
0005435097335	5344	118	23E
0005434344704	5344	119	23D
0005435319623	5344	120	23C
0005434244999	5344	121	23F
0005435615178	5344	122	23J
0005434344707	5344	123	23H
0005435425319	5344	124	24D
0005435097341	5344	125	23K
0005434344682	5344	126	24G
0005435425174	5344	127	24F
0005435097334	5344	128	24E
0005435615107	5344	129	25C
0005435425095	5344	130	25B
0005435425265	5344	131	25F
0005435615125	5344	132	25E
0005435615119	5344	133	25D
0005435097332	5344	134	25H
0005435615166	5344	135	25G
0005432047598	5344	136	25J
0005435424934	5344	137	26B
0005435425444	5344	138	26A
0005435097339	5344	139	26E
0005435615175	5344	140	26D
0005435615106	5344	141	26G
0005435615172	5344	142	26K
0005434344697	5344	143	26J
0005435425320	5344	144	26H
0005435424917	5344	145	27B
0005434344681	5344	146	27A
0005432047601	5344	147	27D
0005434344708	5344	148	27C
0005435615141	5344	149	27F
0005435615184	5344	150	27E
0005435425057	5344	151	27H
0005435615129	5344	152	27G
0005435319624	5344	153	27K
0005435425445	5344	154	27J
0005435425077	5344	155	28C
0005434245137	5344	156	28B
0005435615124	5344	157	28A
0005435615173	5344	158	28E
0005432133420	5344	159	28D
0005434344700	5344	160	28F
0005435615147	5344	161	28J
0005432047599	5344	162	28H
0005435425184	5344	163	29A
0005434245099	5344	164	28K
0005435615137	5344	165	29D
0005435615191	5344	166	29C
0005435615192	5344	167	29B
0005435615198	5344	168	29E
0005435615101	5344	169	29J
0005432133407	5344	170	29H
0005434344686	5344	171	29G
0005434245108	5344	172	29K
0005435425163	5344	173	30C
0005435615112	5344	174	30A
0005434573544	5344	175	30E
0005435424899	5344	176	30G
0005435615216	5344	177	30F
0005434245170	5344	178	30J
0005435425253	5344	179	30H
0005435615194	5344	180	31B
0005432133418	5344	181	31A
0005434573549	5344	182	30K
0005435615154	5344	183	31D
0005435615168	5344	184	31C
0005435425264	5344	185	31F
0005435380334	5344	186	31E
0005435425246	5344	187	31J
0005435425262	5344	188	31H
0005435425096	5344	189	31G
0005432133406	5344	190	31K
0005435425043	5344	191	32C
0005435615143	5344	192	32B
0005434244992	5344	193	32A
0005434245199	5344	194	32E
0005435380307	5344	195	32G
0005432133419	5344	196	32F
0005435615149	5344	197	32K
0005434573536	5344	198	32J
0005434344694	5344	199	32H
0005435425219	5344	200	33A
0005435490276	5344	201	33D
0005434245245	5344	202	33C
0005435615212	5344	203	33B
0005432363438	5344	204	33E
0005434344689	5344	205	33H
0005435424929	5344	206	33G
0005435615163	5344	207	34A
0005435615145	5344	208	33K
0005435615103	5344	209	33J
0005435615150	5344	210	34B
0005435425014	5344	211	34E
0005434245057	5344	212	34G
0005434245166	5344	213	34F
0005434344684	5344	214	34K
0005435425286	5344	215	34J
0005435615156	5344	216	34H
0005435424881	5344	217	35B
0005434573543	5344	218	35A
0005435615190	5344	219	35D
0005435615148	5344	220	35C
0005432133405	5344	221	35F
0005435615153	5344	222	35E
0005435615215	5344	223	35J
0005434573541	5344	224	35H
0005435615211	5344	225	35G
0005435615100	5344	226	36A
0005435425275	5344	227	35K
0005434344690	5344	228	36D
0005435425136	5344	229	36C
0005435425250	5344	230	36B
0005435425285	5344	231	36E
0005435615110	5344	232	36H
0005435491466	5344	233	36K
0005434344676	5344	234	36J
0005435319598	5344	235	37B
0005435490275	5344	236	37D
0005435615157	5344	237	37G
0005435615193	5344	238	37F
0005435615138	5344	239	37H
0005435615139	5344	240	38A
0005434344679	5344	241	37K
0005435615133	5344	242	37J
0005435097337	5344	243	38C
0005434344683	5344	244	38B
0005435425229	5344	245	38J
0005435615186	5344	246	38H
0005435615181	5344	247	39B
0005434344698	5344	248	39A
0005432133409	5344	249	39D
0005434245058	5344	250	39C
0005435424933	5344	251	39F
0005434573545	5344	252	39E
0005434245105	5344	253	39H
0005435615201	5344	254	39G
0005435615161	5344	255	40A
0005434245132	5344	256	39K
0005435615197	5344	257	40B
0005435425188	5344	258	40E
0005434344674	5344	259	40D
0005434245200	5344	260	40G
0005435615146	5344	261	40F
0005435380308	5344	262	40J
0005435615128	5344	263	40H
0005435615171	5344	264	41B
0005432133408	5344	265	41A
0005435615132	5344	266	41D
0005434245255	5344	267	41C
0005435615130	5344	268	41G
0005435380324	5344	269	41E
0005435615155	5344	270	41J
0005435615182	5344	271	41H
0005435097340	5344	272	42B
0005435425149	5344	273	42E
0005435425524	5344	274	42G
0005432363428	5344	275	42F
0005435425119	5344	276	42J
0005435425241	5344	277	42H
0005434344692	5344	278	43A
0005435615218	5344	279	43B
0005435425104	5344	280	43G
0005435425347	5344	281	43E
0005435425252	5344	282	43D
0005435425483	5344	283	43H
0005435302221	5344	284	44A
0005435425374	5344	285	43K
0005435425132	5344	286	43J
0005434573542	5344	287	44B
0005435425338	5344	288	44E
0005435555396	5344	289	44C
0005435615131	5344	290	44G
0005435615109	5344	291	44F
0005434344705	5344	292	44K
0005435615152	5344	293	44J
0005435425212	5344	294	45B
0005435491467	5344	295	45A
0005432133415	5344	296	45D
0005435425146	5344	297	45C
0005435615134	5344	298	45F
0005435615162	5344	299	45J
0005435380328	5344	300	45H
0005434344701	5344	301	45G
0005435615208	5344	302	46A
0005435302222	5344	303	45K
0005435425301	5344	304	46C
0005435615098	5344	305	46E
0005435615189	5344	306	46D
0005434344680	5344	307	46G
0005434245034	5344	308	46F
0005435615114	5344	309	46J
0005435615113	5344	310	46H
0005435302236	5344	311	47C
0005432133417	5344	312	47A
0005434344696	5344	313	46K
0005435615209	5344	314	47D
0005435615127	5344	315	47G
0005435615136	5344	316	47F
0005435380294	5344	317	48A
0005435615123	5344	318	47H
0005435615105	5344	319	48C
0005435425207	5344	320	48F
0005434344677	5344	321	48D
0005434245198	5344	322	48H
0005432133410	5344	323	48G
0005435425302	5344	324	49A
0005434573546	5344	325	48K
0005434344702	5344	326	49D
0005435615188	5344	327	49C
0005434344675	5344	328	49G
0005435424918	5344	329	49F
0005435555395	5344	330	49E
0005435425120	5344	331	49K
0005432133413	5344	332	49H
0005435615140	5344	333	50C
0005435615102	5344	334	50A
0005435615118	5344	335	50F
0005435615183	5344	336	50E
0005435380317	5344	337	50D
0005435425251	5344	338	50K
0005435615204	5344	339	50H
0005435615167	5344	340	51F
0005435615200	5344	341	51E
0005435615116	5344	342	51D
0005435425726	10922	1	1C
0005435614302	10922	2	1A
0005435614369	10922	3	1H
0005435614123	10922	4	1G
0005435425714	10922	5	1D
0005435425751	10922	6	1K
0005435614071	10922	7	2D
0005435614275	10922	8	2C
0005435613934	10922	9	2H
0005433719187	10922	10	2G
0005434344380	10922	11	3A
0005435614023	10922	12	2K
0005435614410	10922	13	3D
0005434245365	10922	14	3C
0005434573445	10922	15	3H
0005435613899	10922	16	3G
0005434245366	10922	17	4A
0005435614127	10922	18	3K
0005434245364	10922	19	4G
0005435614268	10922	20	4C
0005434245385	10922	21	4K
0005435614194	10922	22	4H
0005435614431	10922	23	5A
0005435614237	10922	24	5H
0005434344346	10922	25	5G
0005435425719	10922	26	11A
0005435425722	10922	27	5K
0005435380356	10922	28	11D
0005435614095	10922	29	11C
0005432165139	10922	30	11F
0005434573399	10922	31	11K
0005434573347	10922	32	11H
0005435097243	10922	33	12C
0005435614033	10922	34	12A
0005434245371	10922	35	12E
0005435305038	10922	36	12D
0005435614212	10922	37	12G
0005434573400	10922	38	12F
0005434573362	10922	39	13A
0005435614378	10922	40	12K
0005434573413	10922	41	12H
0005435097209	10922	42	13C
0005434344303	10922	43	13F
0005435613754	10922	44	13E
0005434344310	10922	45	13H
0005435614036	10922	46	13G
0005435614057	10922	47	14A
0005435614326	10922	48	13K
0005434245370	10922	49	14E
0005435613830	10922	50	14D
0005432363460	10922	51	14C
0005432165140	10922	52	14F
0005435614439	10922	53	14K
0005435614034	10922	54	14G
0005435319690	10922	55	15A
0005432165137	10922	56	15F
0005435425706	10922	57	15E
0005434344315	10922	58	15G
0005435319693	10922	59	16A
0005435425748	10922	60	15K
0005435425695	10922	61	15H
0005435425758	10922	62	16D
0005434573425	10922	63	16C
0005435614239	10922	64	16F
0005434573372	10922	65	16H
0005435425708	10922	66	17C
0005435425732	10922	67	17A
0005435425734	10922	68	16K
0005434344257	10922	69	17E
0005434245384	10922	70	17G
0005432841042	10922	71	17F
0005435097260	10922	72	17H
0005434344344	10922	73	18C
0005434573412	10922	74	18B
0005435614261	10922	75	18A
0005435425712	10922	76	18E
0005435613977	10922	77	18D
0005434245377	10922	78	18F
0005432166946	10922	79	18J
0005435614131	10922	80	18H
0005435614096	10922	81	19B
0005435614032	10922	82	19A
0005435425741	10922	83	18K
0005435555385	10922	84	19D
0005434344456	10922	85	19C
0005435613829	10922	86	19F
0005435097208	10922	87	19E
0005435614195	10922	88	19J
0005434344507	10922	89	19H
0005435614156	10922	90	19G
0005435614379	10922	91	19K
0005434344343	10922	92	20C
0005434344388	10922	93	20E
0005435425746	10922	94	20D
0005434344263	10922	95	20G
0005435425735	10922	96	20F
0005435614267	10922	97	20J
0005435614316	10922	98	20H
0005435425720	10922	99	21B
0005434245375	10922	100	21A
0005435613864	10922	101	21D
0005435613952	10922	102	21C
0005435614236	10922	103	21F
0005434573292	10922	104	21E
0005435614158	10922	105	21H
0005435425703	10922	106	21G
0005434573420	10922	107	21K
0005435613968	10922	108	21J
0005435614285	10922	109	22C
0005435425704	10922	110	22B
0005432841041	10922	111	22F
0005435425747	10922	112	22D
0005435614206	10922	113	22G
0005435614307	10922	114	22J
0005435380354	10922	115	22H
0005435319695	10922	116	23B
0005435614416	10922	117	23A
0005434344329	10922	118	23D
0005435614398	10922	119	23F
0005434344253	10922	120	23E
0005435614286	10922	121	23H
0005434245382	10922	122	24D
0005435613863	10922	123	23K
0005435425700	10922	124	23J
0005435425737	10922	125	24F
0005434245379	10922	126	24E
0005435425754	10922	127	25B
0005435305039	10922	128	24G
0005434245372	10922	129	25C
0005435613926	10922	130	25F
0005435613851	10922	131	25E
0005435425693	10922	132	25D
0005434573338	10922	133	25H
0005435425694	10922	134	25G
0005434573368	10922	135	25K
0005434245378	10922	136	25J
0005435425725	10922	137	26C
0005435425744	10922	138	26B
0005435042888	10922	139	26A
0005435425697	10922	140	26E
0005435614205	10922	141	26D
0005432363461	10922	142	26G
0005434344305	10922	143	26F
0005435425755	10922	144	26K
0005435425742	10922	145	26H
0005435614035	10922	146	27A
0005435614429	10922	147	27D
0005435380357	10922	148	27C
0005435425736	10922	149	27B
0005435425743	10922	150	27F
0005435613571	10922	151	27E
0005435425757	10922	152	27J
0005434245362	10922	153	27H
0005432165143	10922	154	27G
0005435614020	10922	155	27K
0005435380352	10922	156	28C
0005434573373	10922	157	28B
0005435613688	10922	158	28A
0005435305040	10922	159	28E
0005435042886	10922	160	28D
0005435614058	10922	161	28F
0005435614193	10922	162	28J
0005435425731	10922	163	28H
0005434344318	10922	164	29B
0005435425759	10922	165	29A
0005435614313	10922	166	28K
0005435425709	10922	167	29D
0005434245359	10922	168	29C
0005435425692	10922	169	29F
0005432363458	10922	170	29E
0005434245369	10922	171	29J
0005435425745	10922	172	29H
0005435614226	10922	173	29G
0005435319691	10922	174	30A
0005435613283	10922	175	29K
0005435613901	10922	176	30C
0005435614256	10922	177	30H
0005434344165	10922	178	30G
0005435319694	10922	179	30F
0005433719188	10922	180	30K
0005435614012	10922	181	30J
0005435319692	10922	182	31B
0005434344155	10922	183	31A
0005434245367	10922	184	31D
0005435614325	10922	185	31C
0005435613894	10922	186	31G
0005435614133	10922	187	31F
0005435614108	10922	188	31E
0005434245374	10922	189	31H
0005435425723	10922	190	31J
0005435425727	10922	191	32C
0005435613778	10922	192	32A
0005435425696	10922	193	32E
0005434573424	10922	194	32D
0005435425713	10922	195	32G
0005435613546	10922	196	32F
0005434573419	10922	197	32K
0005435555386	10922	198	32J
0005435613927	10922	199	32H
0005435425711	10922	200	33B
0005435614227	10922	201	33D
0005435614072	10922	202	33C
0005434656583	10922	203	33F
0005435614069	10922	204	33E
0005435425705	10922	205	33J
0005435425733	10922	206	33G
0005435425752	10922	207	34A
0005435613905	10922	208	33K
0005434344412	10922	209	34B
0005435613991	10922	210	34E
0005435614411	10922	211	34D
0005435614019	10922	212	34C
0005435613570	10922	213	34F
0005434245383	10922	214	34K
0005434245373	10922	215	34J
0005435614107	10922	216	34H
0005435304215	10922	217	35B
0005435319688	10922	218	35A
0005434344306	10922	219	35C
0005435613892	10922	220	35F
0005432363459	10922	221	35E
0005434245386	10922	222	35H
0005434344264	10922	223	35G
0005435613969	10922	224	36A
0005435425739	10922	225	35K
0005435097246	10922	226	35J
0005434344237	10922	227	36F
0005435613891	10922	228	36E
0005434344297	10922	229	36D
0005432165141	10922	230	36G
0005435614259	10922	231	36J
0005434344218	10922	232	37B
0005435425738	10922	233	37E
0005434573369	10922	234	37D
0005435614272	10922	235	37C
0005435613957	10922	236	37G
0005434344345	10922	237	37F
0005435614006	10922	238	37J
0005434344447	10922	239	37H
0005434344166	10922	240	37K
0005435097233	10922	241	38C
0005432166945	10922	242	38B
0005435614024	10922	243	38A
0005435319689	10922	244	38K
0005435613819	10922	245	38J
0005435555387	10922	246	38H
0005435613403	10922	247	39B
0005435614018	10922	248	39A
0005434245368	10922	249	39D
0005434245380	10922	250	39C
0005435614047	10922	251	39F
0005435319686	10922	252	39H
0005435425760	10922	253	39G
0005435425728	10922	254	39K
0005435425724	10922	255	39J
0005434344333	10922	256	40C
0005434344391	10922	257	40B
0005435614098	10922	258	40A
0005434245358	10922	259	40E
0005435614364	10922	260	40D
0005434344338	10922	261	40G
0005435425698	10922	262	40F
0005435425749	10922	263	40K
0005435555382	10922	264	40J
0005434245357	10922	265	40H
0005435425702	10922	266	41B
0005434344459	10922	267	41A
0005435425715	10922	268	41D
0005435614273	10922	269	41C
0005435425707	10922	270	41E
0005434573414	10922	271	41H
0005435613750	10922	272	42A
0005435614260	10922	273	41J
0005435613900	10922	274	42C
0005435042887	10922	275	42B
0005435042889	10922	276	42E
0005435614324	10922	277	42D
0005434573339	10922	278	42G
0005435097244	10922	279	42F
0005434344309	10922	280	42J
0005435614143	10922	281	43B
0005432165142	10922	282	43A
0005434245363	10922	283	43C
0005435614070	10922	284	43E
0005435614303	10922	285	43H
0005435614103	10922	286	43G
0005435614225	10922	287	43K
0005435097245	10922	288	43J
0005434573376	10922	289	44A
0005434344304	10922	290	44D
0005434344339	10922	291	44C
0005435613855	10922	292	44H
0005435490233	10922	293	44G
0005435380355	10922	294	44F
0005435614211	10922	295	44J
0005435425716	10922	296	45A
0005435097232	10922	297	44K
0005435042885	10922	298	45D
0005435614409	10922	299	45C
0005434344322	10922	300	45B
0005435425699	10922	301	45F
0005435613990	10922	302	45E
0005434344238	10922	303	45J
0005435425729	10922	304	45H
0005434344279	10922	305	45G
0005435614075	10922	306	45K
0005435097235	10922	307	46C
0005435425750	10922	308	46B
0005435614130	10922	309	46A
0005432166943	10922	310	46D
0005432166944	10922	311	46G
0005435304217	10922	312	46F
0005435425753	10922	313	46K
0005435614068	10922	314	46J
0005435613993	10922	315	47A
0005435097259	10922	316	47E
0005435613893	10922	317	47D
0005434245360	10922	318	47C
0005435425756	10922	319	47F
0005435614005	10922	320	47K
0005434245376	10922	321	47H
0005434344284	10922	322	48D
0005435425730	10922	323	48C
0005435425710	10922	324	48A
0005434245381	10922	325	48E
0005434245361	10922	326	48H
0005435614451	10922	327	48G
0005435613779	10922	328	49A
0005435425721	10922	329	48K
0005434573421	10922	330	49D
0005435613983	10922	331	49C
0005435613953	10922	332	49F
0005435380353	10922	333	49K
0005435425701	10922	334	49G
0005435425717	10922	335	50C
0005435614262	10922	336	50A
0005435613761	10922	337	50E
0005435425718	10922	338	50D
0005435614128	10922	339	50H
0005432165138	10922	340	50G
0005435319687	10922	341	50F
0005435614240	10922	342	50K
0005435425740	10922	343	51F
0005435304216	10922	344	51E
0005433719186	10922	345	51D
0005435490232	10922	346	51G
0005433507429	3252	1	1A
0005432459973	3252	2	1C
0005433634266	3252	3	1F
0005432460231	3252	4	1D
0005432182016	3252	5	2A
0005432182004	3252	6	2C
0005433507426	3252	7	2F
0005433634275	3252	8	2D
0005433634277	3252	9	3A
0005432182012	3252	10	3C
0005432459901	3252	11	3F
0005432460184	3252	12	3D
0005432460218	3252	13	4A
0005432459706	3252	14	4C
0005432460165	3252	15	4D
0005432459831	3252	16	5A
0005432182010	3252	17	4F
0005432460263	3252	18	5C
0005432182018	3252	19	5D
0005433507422	3252	20	6A
0005433634284	3252	21	5F
0005432459998	3252	22	6C
0005432460102	3252	23	6F
0005433507410	3252	24	6D
0005432182015	3252	25	7A
0005433507407	3252	26	7D
0005432460083	3252	27	7C
0005432182024	3252	28	8A
0005433507427	3252	29	7F
0005433805837	3252	30	8B
0005432460228	3252	31	8D
0005433634286	3252	32	8C
0005433805838	3252	33	8E
0005432460105	3252	34	9A
0005432459975	3252	35	8F
0005432460260	3252	36	9B
0005432459926	3252	37	9C
0005432182008	3252	38	9E
0005433634282	3252	39	9D
0005433507428	3252	40	9F
0005432460119	3252	41	10A
0005433507415	3252	42	10B
0005432460070	3252	43	10C
0005432460162	3252	44	10E
0005432460133	3252	45	10D
0005432182025	3252	46	10F
0005432459940	3252	47	11B
0005432460103	3252	48	11A
0005432182013	3252	49	11C
0005433634287	3252	50	11D
0005432460045	3252	51	11F
0005433805843	3252	52	11E
0005432460156	3252	53	12A
0005433507416	3252	54	12C
0005433634278	3252	55	12B
0005433805833	3252	56	12E
0005432459838	3252	57	12D
0005433634283	3252	58	12F
0005432460078	3252	59	13B
0005433805836	3252	60	13A
0005432182006	3252	61	13C
0005433507408	3252	62	13D
0005433634280	3252	63	13E
0005433634264	3252	64	14A
0005433634294	3252	65	13F
0005433634272	3252	66	14B
0005433805829	3252	67	14D
0005433507420	3252	68	14C
0005432460135	3252	69	14E
0005433507413	3252	70	14F
0005433507423	3252	71	15A
0005432460154	3252	72	15C
0005432460159	3252	73	15B
0005433634260	3252	74	15E
0005432460155	3252	75	15D
0005432459707	3252	76	15F
0005432182017	3252	77	16A
0005433634285	3252	78	16B
0005433805831	3252	79	16D
0005433805839	3252	80	16C
0005433805840	3252	81	16E
0005433507421	3252	82	16F
0005433634268	3252	83	17B
0005432460153	3252	84	17A
0005432459938	3252	85	17C
0005432460022	3252	86	17E
0005432182007	3252	87	17D
0005433634289	3252	88	17F
0005432459927	3252	89	18A
0005432459964	3252	90	18C
0005432460033	3252	91	18B
0005433507425	3252	92	18E
0005432459902	3252	93	18D
0005432460375	3252	94	19B
0005432459896	3252	95	18F
0005432460157	3252	96	19D
0005433634261	3252	97	19C
0005433634290	3252	98	20A
0005432460129	3252	99	19E
0005433805842	3252	100	20C
0005433634293	3252	101	20B
0005432460093	3252	102	20D
0005432182023	3252	103	20F
0005432182020	3252	104	20E
0005433507411	3252	105	21B
0005432459830	3252	106	21A
0005433634288	3252	107	21D
0005433634279	3252	108	21C
0005432460207	3252	109	21E
0005432182005	3252	110	22A
0005432460158	3252	111	21F
0005432459994	3252	112	22B
0005432460104	3252	113	22C
0005433805823	3252	114	22D
0005433805826	3252	115	22F
0005433805846	3252	116	22E
0005432460374	3252	117	23B
0005432182011	3252	118	23A
0005433805844	3252	119	23D
0005433805832	3252	120	23E
0005433507412	3252	121	24A
0005433805828	3252	122	23F
0005433634276	3252	123	24B
0005433634271	3252	124	24C
0005433805845	3252	125	24D
0005433634273	3252	126	24F
0005433507418	3252	127	24E
0005432182022	3252	128	25A
0005433634267	3252	129	25B
0005432460118	3252	130	25D
0005432460032	3252	131	25C
0005433634265	3252	132	25F
0005433634270	3252	133	25E
0005433634262	3252	134	26B
0005433507419	3252	135	26A
0005432182026	3252	136	26C
0005432460140	3252	137	26E
0005432182009	3252	138	26D
0005432460229	3252	139	26F
0005433634269	3252	140	27B
0005432460051	3252	141	27A
0005432460171	3252	142	27C
0005433634281	3252	143	27D
0005432460163	3252	144	27E
0005432460410	3252	145	28A
0005433805830	3252	146	27F
0005433805841	3252	147	28B
0005433507414	3252	148	28C
0005433805834	3252	149	28E
0005433634274	3252	150	28D
0005432182021	3252	151	28F
0005432459939	3252	152	29B
0005433805825	3252	153	29A
0005432459972	3252	154	29C
0005433805824	3252	155	29D
0005432460136	3252	156	29F
0005432182019	3252	157	29E
0005432460084	3252	158	30A
0005433805835	3252	159	30B
0005432460409	3252	160	30D
0005433507417	3252	161	30C
0005432459969	3252	162	30E
0005433634291	3252	163	30F
0005433507424	3252	164	31A
0005432182014	3252	165	31C
0005433634263	3252	166	31B
0005433634292	3252	167	31D
0005433805827	3252	168	31E
0005433507409	3252	169	31F
0005435885739	3253	1	2C
0005435885609	3253	2	3F
0005435885387	3253	3	4C
0005435885489	3253	4	4F
0005435885555	3253	5	5A
0005435885581	3253	6	6C
0005435885715	3253	7	6F
0005435885259	3253	8	7A
0005435885705	3253	9	8A
0005435885735	3253	10	9A
0005435885610	3253	11	8F
0005435885618	3253	12	9B
0005435885619	3253	13	9C
0005435885404	3253	14	9D
0005435885473	3253	15	9F
0005435885437	3253	16	9E
0005435885536	3253	17	10B
0005435885435	3253	18	11A
0005435885529	3253	19	11D
0005435885570	3253	20	11F
0005435885616	3253	21	12A
0005435885617	3253	22	12B
0005435885393	3253	23	12C
0005435885656	3253	24	12D
0005435885652	3253	25	13B
0005435885528	3253	26	13A
0005435885428	3253	27	13F
0005435885614	3253	28	15B
0005435885296	3253	29	15C
0005435885459	3253	30	15D
0005435885372	3253	31	15F
0005435885534	3253	32	16C
0005435885304	3253	33	16D
0005435885329	3253	34	17B
0005435885556	3253	35	18A
0005435885490	3253	36	18C
0005435885622	3253	37	18E
0005435885535	3253	38	19C
0005435885657	3253	39	19E
0005435885224	3253	40	20A
0005435885436	3253	41	20C
0005435885456	3253	42	21B
0005435885582	3253	43	21C
0005435885388	3253	44	22A
0005435885613	3253	45	22C
0005435885769	3253	46	22E
0005435885580	3253	47	23C
0005435885538	3253	48	23D
0005435885493	3253	49	25D
0005435885425	3253	50	25E
0005435885527	3253	51	26B
0005435885706	3253	52	26F
0005435885475	3253	53	28A
0005435885578	3253	54	28B
0005435885474	3253	55	28D
0005435885297	3253	56	28F
0005435885675	3253	57	29A
0005435885477	3253	58	29C
0005435885471	3253	59	30E
0005435885434	3253	60	31C
0005435885565	3253	61	31F
0005435885904	8192	1	1A
0005432460604	8192	2	1C
0005432460566	8192	3	1D
0005432460581	8192	4	1F
0005432460585	8192	5	2C
0005435885883	8192	6	2A
0005432460608	8192	7	2F
0005435885899	8192	8	3F
0005432460588	8192	9	3D
0005432460603	8192	10	4A
0005432460573	8192	11	4C
0005432460560	8192	12	4F
0005432460570	8192	13	4D
0005435885894	8192	14	5C
0005435885902	8192	15	5D
0005432460567	8192	16	5F
0005435885892	8192	17	6C
0005435885898	8192	18	6F
0005432460561	8192	19	7A
0005432460575	8192	20	7D
0005433507251	8192	21	7C
0005432460562	8192	22	8A
0005432460607	8192	23	7F
0005435885909	8192	24	8B
0005435885907	8192	25	8D
0005432460597	8192	26	9A
0005435885928	8192	27	8F
0005435885900	8192	28	9B
0005432460605	8192	29	9C
0005435885914	8192	30	9E
0005435885912	8192	31	9F
0005432460563	8192	32	10A
0005433507246	8192	33	10B
0005435885925	8192	34	10D
0005433507252	8192	35	10C
0005432460601	8192	36	10E
0005432460598	8192	37	11A
0005432460571	8192	38	10F
0005432042903	8192	39	11B
0005432042908	8192	40	11C
0005432460576	8192	41	11E
0005435885903	8192	42	11D
0005433507280	8192	43	12A
0005435885895	8192	44	11F
0005435885921	8192	45	12B
0005432460594	8192	46	12E
0005435885913	8192	47	12D
0005435885927	8192	48	13C
0005435885889	8192	49	13B
0005432042899	8192	50	13D
0005433507205	8192	51	13F
0005435885929	8192	52	14A
0005432460602	8192	53	14C
0005432460583	8192	54	15A
0005432460609	8192	55	14F
0005433507253	8192	56	14E
0005435885923	8192	57	15C
0005432042907	8192	58	15B
0005433507286	8192	59	15E
0005432460584	8192	60	15D
0005432460599	8192	61	15F
0005433507250	8192	62	16A
0005433507213	8192	63	16B
0005432460600	8192	64	16C
0005435885893	8192	65	16F
0005435885887	8192	66	16E
0005432460595	8192	67	16D
0005435885888	8192	68	17B
0005432460572	8192	69	17A
0005432042904	8192	70	17D
0005432460574	8192	71	17E
0005432042898	8192	72	18B
0005435885922	8192	73	18D
0005432460569	8192	74	18C
0005432460564	8192	75	18E
0005432042902	8192	76	18F
0005432460579	8192	77	19C
0005435885911	8192	78	19B
0005435885890	8192	79	19E
0005435885926	8192	80	19D
0005432460582	8192	81	20B
0005433507254	8192	82	20A
0005432460611	8192	83	20C
0005433507265	8192	84	20E
0005435885886	8192	85	20D
0005432042896	8192	86	20F
0005435885891	8192	87	21B
0005433507150	8192	88	21A
0005435885908	8192	89	21D
0005432042906	8192	90	21C
0005435885884	8192	91	21E
0005434312348	8192	92	21F
0005432460593	8192	93	22A
0005432460596	8192	94	22C
0005433507235	8192	95	22D
0005432460565	8192	96	22F
0005435885885	8192	97	23A
0005432042905	8192	98	23C
0005435885915	8192	99	23D
0005432460591	8192	100	23F
0005432460610	8192	101	23E
0005434312349	8192	102	24A
0005432042901	8192	103	24B
0005432460589	8192	104	24C
0005433507238	8192	105	24E
0005433507281	8192	106	24D
0005435885897	8192	107	24F
0005432460587	8192	108	25B
0005433507179	8192	109	25A
0005435885918	8192	110	25E
0005433507255	8192	111	26A
0005432460586	8192	112	25F
0005433507178	8192	113	26B
0005433507263	8192	114	26C
0005435885916	8192	115	26F
0005432460559	8192	116	26E
0005432460578	8192	117	27A
0005432460606	8192	118	27B
0005432460568	8192	119	27D
0005432460577	8192	120	27C
0005433507202	8192	121	27E
0005435885906	8192	122	28A
0005433507258	8192	123	28D
0005435885924	8192	124	28C
0005432042900	8192	125	28E
0005435885917	8192	126	28F
0005433507257	8192	127	29A
0005433507284	8192	128	29C
0005433507234	8192	129	29E
0005432460592	8192	130	29D
0005433507204	8192	131	29F
0005435885920	8192	132	30B
0005435885910	8192	133	30A
0005433507264	8192	134	30E
0005432460590	8192	135	30D
0005432042897	8192	136	30F
0005435885901	8192	137	31A
0005432460580	8192	138	31C
0005435885905	8192	139	31D
0005435885896	8192	140	31F
0005435885919	8192	141	31E
0005433805551	8193	1	1C
0005433805528	8193	2	1A
0005433805532	8193	3	2A
0005433634013	8193	4	3A
0005433633935	8193	5	3D
0005433805455	8193	6	4A
0005433805563	8193	7	4D
0005433805463	8193	8	5C
0005433805497	8193	9	5D
0005433805669	8193	10	6F
0005433633829	8193	11	7F
0005434143740	8193	12	8B
0005433633819	8193	13	8E
0005433633905	8193	14	9C
0005433633901	8193	15	9F
0005433805562	8193	16	10A
0005433634083	8193	17	10C
0005433633826	8193	18	10E
0005434143739	8193	19	11B
0005433634047	8193	20	11A
0005433633990	8193	21	11C
0005433805444	8193	22	11E
0005433634084	8193	23	12A
0005433633845	8193	24	12B
0005433633940	8193	25	12E
0005433633939	8193	26	12F
0005434143733	8193	27	13B
0005433633844	8193	28	13E
0005433633915	8193	29	14E
0005433634012	8193	30	14F
0005433633967	8193	31	15C
0005433805606	8193	32	15B
0005433805605	8193	33	15D
0005433805434	8193	34	15F
0005433633872	8193	35	16D
0005433805566	8193	36	17A
0005433634020	8193	37	17F
0005433633818	8193	38	18D
0005433633974	8193	39	18C
0005433805523	8193	40	18E
0005433633808	8193	41	19B
0005433805508	8193	42	18F
0005433805421	8193	43	19E
0005433633807	8193	44	20A
0005433633828	8193	45	20D
0005434143730	8193	46	20C
0005433633827	8193	47	20F
0005433634030	8193	48	21D
0005433633775	8193	49	21F
0005433805524	8193	50	22B
0005433805501	8193	51	22C
0005433633988	8193	52	22D
0005433633959	8193	53	23A
0005433805607	8193	54	23D
0005433633914	8193	55	23E
0005433805622	8193	56	24A
0005433805542	8193	57	23F
0005433633882	8193	58	24B
0005433633871	8193	59	24F
0005433633820	8193	60	25C
0005433805445	8193	61	25F
0005433805531	8193	62	26C
0005433805516	8193	63	26B
0005433805547	8193	64	26E
0005433633945	8193	65	27D
0005433633936	8193	66	27E
0005433634046	8193	67	28B
0005433633910	8193	68	28C
0005433633947	8193	69	28E
0005433805435	8193	70	29C
0005433633973	8193	71	29B
0005434271313	8193	72	29D
0005433633975	8193	73	29E
0005433805559	8193	74	30A
0005433633941	8193	75	30B
0005433805604	8193	76	30C
0005433805449	8193	77	30E
0005433633809	8193	78	30F
0005433633987	8193	79	31E
0005434183585	8194	1	11A
0005434183584	8194	2	15E
0005434183579	8194	3	24C
0005434183595	8194	4	24E
0005434183594	8194	5	27B
0005433722312	4640	1	1C
0005432383706	4640	2	1F
0005433194894	4640	3	2D
0005432383701	4640	4	4A
0005433454904	4640	5	4C
0005432728111	4640	6	4D
0005432383683	4640	7	4F
0005433722311	4640	8	5D
0005432728101	4640	9	5F
0005432728109	4640	10	6A
0005432383700	4640	11	6D
0005433722313	4640	12	6E
0005432383685	4640	13	7A
0005432383682	4640	14	6F
0005432728104	4640	15	7D
0005432383703	4640	16	7E
0005433194896	4640	17	7F
0005432383694	4640	18	8C
0005433722310	4640	19	8D
0005432383681	4640	20	8F
0005432383688	4640	21	9C
0005433194895	4640	22	9D
0005432383689	4640	23	10A
0005432383707	4640	24	10C
0005432383686	4640	25	10D
0005432728102	4640	26	11A
0005432728106	4640	27	11F
0005432383695	4640	28	12A
0005432383702	4640	29	12C
0005433453787	4640	30	12D
0005432383692	4640	31	12E
0005432728108	4640	32	12F
0005433194897	4640	33	13D
0005432728112	4640	34	13F
0005432383687	4640	35	14A
0005433194892	4640	36	14E
0005432383680	4640	37	14F
0005432728105	4640	38	15C
0005432728107	4640	39	15D
0005432383696	4640	40	15E
0005432383698	4640	41	15F
0005433194893	4640	42	16C
0005432728103	4640	43	16D
0005432383697	4640	44	16E
0005433722309	4640	45	17C
0005432383708	4640	46	17E
0005432383704	4640	47	17F
0005432383705	4640	48	18A
0005432383693	4640	49	18D
0005432383684	4640	50	18E
0005432728110	4640	51	18F
0005433454903	4640	52	19A
0005432383691	4640	53	19D
0005432728100	4640	54	19F
0005432383690	4640	55	20C
0005432383699	4640	56	20D
0005432383244	30162	1	1D
0005433722226	30162	2	1F
0005432383215	30162	3	2A
0005432727998	30162	4	2C
0005432728019	30162	5	3A
0005432383259	30162	6	3C
0005432383177	30162	7	3D
0005432728012	30162	8	3F
0005432383296	30162	9	4C
0005433453771	30162	10	4D
0005432383328	30162	11	4E
0005432383145	30162	12	4F
0005433722223	30162	13	5C
0005432383250	30162	14	5D
0005433722209	30162	15	6C
0005432383258	30162	16	6D
0005433451622	30162	17	6E
0005432383251	30162	18	6F
0005432383383	30162	19	7A
0005432728017	30162	20	7C
0005432383249	30162	21	7E
0005432383182	30162	22	7F
0005433453774	30162	23	8A
0005432728016	30162	24	8C
0005432383272	30162	25	8D
0005432383214	30162	26	8E
0005432383246	30162	27	9A
0005432727935	30162	28	9C
0005432728041	30162	29	9D
0005432383108	30162	30	9E
0005432383263	30162	31	10E
0005432728011	30162	32	10F
0005432383195	30162	33	11A
0005432383175	30162	34	11C
0005432727936	30162	35	11D
0005432728000	30162	36	11F
0005432383196	30162	37	12A
0005432383294	30162	38	12C
0005432383427	30162	39	12E
0005433451625	30162	40	13A
0005432383363	30162	41	13C
0005433453768	30162	42	13D
0005433722222	30162	43	13E
0005432383176	30162	44	13F
0005432383341	30162	45	14A
0005432383305	30162	46	14C
0005433451623	30162	47	15D
0005432383172	30162	48	15E
0005432383181	30162	49	15F
0005432383339	30162	50	16A
0005432383441	30162	51	16C
0005432383144	30162	52	16D
0005432383231	30162	53	16E
0005432727933	30162	54	16F
0005432383204	30162	55	17A
0005432383165	30162	56	17C
0005432383426	30162	57	17D
0005432383295	30162	58	17E
0005432383205	30162	59	18A
0005432728040	30162	60	18E
0005433453773	30162	61	19A
0005432383319	30162	62	19C
0005432383166	30162	63	19D
0005432383271	30162	64	19E
0005432383047	30162	65	19F
0005432727984	30162	66	20A
0005432383184	30162	67	20C
0005432383106	30162	68	20E
0005433451624	30162	69	20F
0005435541298	1731	1	1D
0005433517013	1731	2	1F
0005435529560	1731	3	2A
0005435529544	1731	4	2C
0005435529559	1731	5	2D
0005435541291	1731	6	2F
0005435529551	1731	7	3A
0005435529546	1731	8	3C
0005435541300	1731	9	3F
0005435541293	1731	10	4D
0005435541288	1731	11	4E
0005432925066	1731	12	4F
0005435541289	1731	13	5C
0005435541287	1731	14	5E
0005435541308	1731	15	5F
0005432925049	1731	16	6A
0005435541292	1731	17	6C
0005435529553	1731	18	6D
0005432925062	1731	19	7A
0005433517011	1731	20	7C
0005435541294	1731	21	7E
0005432925045	1731	22	7F
0005435529558	1731	23	8A
0005435541306	1731	24	8C
0005435529555	1731	25	8D
0005435529547	1731	26	9C
0005435541299	1731	27	9D
0005433517010	1731	28	9E
0005435541310	1731	29	9F
0005435529550	1731	30	10C
0005435541302	1731	31	10D
0005435541295	1731	32	10E
0005435541307	1731	33	11A
0005435541303	1731	34	11C
0005435529561	1731	35	11D
0005432925038	1731	36	11E
0005435541304	1731	37	11F
0005432925046	1731	38	12C
0005435529562	1731	39	12D
0005433517017	1731	40	12E
0005433517012	1731	41	13A
0005433517015	1731	42	13C
0005435541297	1731	43	13D
0005435529543	1731	44	14F
0005435541290	1731	45	15A
0005435529549	1731	46	15E
0005433517018	1731	47	15F
0005435541309	1731	48	16A
0005435529548	1731	49	16C
0005435529557	1731	50	16D
0005432925065	1731	51	16E
0005435541305	1731	52	16F
0005435529563	1731	53	17E
0005435529552	1731	54	18A
0005435541296	1731	55	18C
0005433517014	1731	56	18D
0005433517009	1731	57	18F
0005435529545	1731	58	19A
0005435541301	1731	59	19C
0005433517016	1731	60	19D
0005435529564	1731	61	20A
0005432294520	1731	62	20C
0005435529556	1731	63	20D
0005435529554	1731	64	20E
0005435517980	21971	1	12E
0005435541037	21971	2	1A
0005435541084	21971	3	1C
0005435517986	21971	4	1D
0005435541184	21971	5	2A
0005435541078	21971	6	2C
0005435541123	21971	7	2F
0005433516884	21971	8	3A
0005435517944	21971	9	3C
0005435541054	21971	10	3D
0005435517959	21971	11	4C
0005435541055	21971	12	4D
0005433516885	21971	13	5C
0005435541104	21971	14	5E
0005435517985	21971	15	6A
0005435541043	21971	16	6C
0005433516856	21971	17	6D
0005435541034	21971	18	6E
0005435518075	21971	19	6F
0005433516944	21971	20	7A
0005435541063	21971	21	7D
0005432925102	21971	22	7E
0005435541058	21971	23	7F
0005435541120	21971	24	8C
0005435517997	21971	25	8E
0005435541091	21971	26	9A
0005435541067	21971	27	8F
0005435517916	21971	28	9C
0005435541031	21971	29	9E
0005433516945	21971	30	9F
0005435517941	21971	31	10A
0005433516912	21971	32	10C
0005435517956	21971	33	10F
0005433516933	21971	34	11A
0005435541053	21971	35	11C
0005435541108	21971	36	11D
0005435541025	21971	37	11E
0005435517917	21971	38	11F
0005435541092	21971	39	12A
0005433516939	21971	40	12C
0005435517940	21971	41	12D
0005435517984	21971	42	12F
0005433516961	21971	43	13D
0005435541068	21971	44	13E
0005433516866	21971	45	13F
0005435541038	21971	46	14A
0005433516867	21971	47	14C
0005435541090	21971	48	15C
0005435541109	21971	49	15D
0005435518027	21971	50	15E
0005435517983	21971	51	15F
0005435517925	21971	52	16A
0005435541105	21971	53	16C
0005435518044	21971	54	16D
0005435541133	21971	55	16E
0005433516932	21971	56	16F
0005435541119	21971	57	17A
0005435541093	21971	58	17C
0005435518029	21971	59	17E
0005435541012	21971	60	17F
0005435541129	21971	61	18A
0005435541113	21971	62	18C
0005435541013	21971	63	18E
0005432925101	21971	64	19A
0005435517943	21971	65	19C
0005435518026	21971	66	19D
0005435517996	21971	67	19E
0005435541024	21971	68	19F
0005432925100	21971	69	20A
0005435541124	21971	70	20E
0005432925099	21971	71	20F
0005434459082	7397	1	6F
0005432839452	7397	2	7C
0005435491454	7397	3	1C
0005432839459	7397	4	7D
0005432839444	7397	5	7E
0005434459089	7397	6	7F
0005432841039	7397	7	8C
0005432823474	7397	8	8D
0005434459074	7397	9	8E
0005434459092	7397	10	8F
0005432839437	7397	11	9A
0005434459079	7397	12	9D
0005434459078	7397	13	9E
0005434459076	7397	14	9F
0005432839454	7397	15	10C
0005434664969	7397	16	10D
0005432073438	7397	17	10E
0005432839455	7397	18	10F
0005434459086	7397	19	11A
0005432839441	7397	20	11C
0005432839438	7397	21	11D
0005434664970	7397	22	1D
0005432823475	7397	23	11E
0005432839439	7397	24	12A
0005435252874	7397	25	12C
0005435491453	7397	26	12D
0005434664967	7397	27	13A
0005435252750	7397	28	13C
0005432839453	7397	29	13D
0005432839462	7397	30	13F
0005432839465	7397	31	14A
0005434664968	7397	32	14D
0005434459091	7397	33	14E
0005432073437	7397	34	14F
0005435252805	7397	35	15A
0005432839436	7397	36	15C
0005432839463	7397	37	15D
0005432839451	7397	38	15E
0005432839458	7397	39	15F
0005434459075	7397	40	16A
0005432073436	7397	41	16C
0005434459087	7397	42	16D
0005432839457	7397	43	17A
0005434459077	7397	44	17C
0005432839464	7397	45	17D
0005435252749	7397	46	17E
0005435252781	7397	47	17F
0005434459080	7397	48	18A
0005434459084	7397	49	2A
0005432839435	7397	50	18D
0005435252814	7397	51	18E
0005432839446	7397	52	18F
0005435252852	7397	53	19A
0005434459073	7397	54	19C
0005432839447	7397	55	19F
0005435252793	7397	56	20A
0005432839460	7397	57	20C
0005434459083	7397	58	20D
0005432839450	7397	59	2C
0005432839440	7397	60	2D
0005432839466	7397	61	2F
0005432839442	7397	62	3A
0005434459085	7397	63	3C
0005432839443	7397	64	3D
0005434459093	7397	65	3F
0005432839445	7397	66	4A
0005434459090	7397	67	4C
0005435252807	7397	68	4D
0005435252794	7397	69	1A
0005432839456	7397	70	4E
0005434459088	7397	71	5A
0005435252775	7397	72	5D
0005432839449	7397	73	5E
0005434459081	7397	74	5F
0005432839448	7397	75	6A
0005432841040	7397	76	6C
0005432073439	7397	77	6D
0005432839461	7397	78	6E
0005432839189	28909	1	17D
0005432839227	28909	2	17E
0005432839173	28909	3	17F
0005435252942	28909	4	18A
0005434458974	28909	5	18C
0005432839184	28909	6	18D
0005432839217	28909	7	18E
0005432839187	28909	8	18F
0005432839201	28909	9	19A
0005435252938	28909	10	19C
0005435252940	28909	11	19D
0005432839275	28909	12	19E
0005434458900	28909	13	19F
0005434458973	28909	14	20A
0005434664991	28909	15	20C
0005435252946	28909	16	20D
0005432841027	28909	17	20E
0005432839337	28909	18	20F
0005432839121	28909	19	15A
0005434458950	28909	20	1A
0005432839240	28909	21	1C
0005432839338	28909	22	1D
0005434458894	28909	23	1F
0005434458890	28909	24	2A
0005435252935	28909	25	2C
0005432839193	28909	26	2D
0005434458840	28909	27	3A
0005434458896	28909	28	2F
0005435252936	28909	29	3C
0005434458897	28909	30	3D
0005432839180	28909	31	3F
0005432839188	28909	32	4A
0005432839166	28909	33	4C
0005435252943	28909	34	4D
0005435252948	28909	35	4E
0005434458985	28909	36	4F
0005432839265	28909	37	5A
0005432839181	28909	38	5C
0005432839191	28909	39	5D
0005434458889	28909	40	5E
0005432839218	28909	41	5F
0005432839151	28909	42	6A
0005432839204	28909	43	6C
0005432823458	28909	44	6D
0005432823461	28909	45	6E
0005434458899	28909	46	6F
0005432839164	28909	47	7A
0005434664990	28909	48	7C
0005432823464	28909	49	7D
0005432839174	28909	50	7E
0005435252930	28909	51	7F
0005435252931	28909	52	8A
0005434458934	28909	53	8C
0005435252932	28909	54	8D
0005432001049	28909	55	8E
0005432839194	28909	56	8F
0005432839122	28909	57	9A
0005432839228	28909	58	9C
0005434458984	28909	59	9D
0005434458919	28909	60	9E
0005432839205	28909	61	10A
0005435252939	28909	62	9F
0005434458986	28909	63	10E
0005435252947	28909	64	10D
0005432839339	28909	65	10F
0005435252933	28909	66	11A
0005432001050	28909	67	11C
0005435491469	28909	68	11D
0005432839150	28909	69	11E
0005435252934	28909	70	11F
0005432839162	28909	71	12A
0005432839182	28909	72	12C
0005434664992	28909	73	12D
0005432839239	28909	74	12E
0005432839145	28909	75	12F
0005432823467	28909	76	13A
0005435252945	28909	77	13C
0005432839175	28909	78	13D
0005432839305	28909	79	13E
0005435491468	28909	80	13F
0005434458895	28909	81	14A
0005432839230	28909	82	14C
0005434458920	28909	83	14D
0005435252944	28909	84	14E
0005434458901	28909	85	14F
0005432839274	28909	86	15C
0005435252949	28909	87	15D
0005432839190	28909	88	15E
0005432839163	28909	89	15F
0005434458980	28909	90	16A
0005432839183	28909	91	16C
0005435252941	28909	92	16D
0005434458888	28909	93	16E
0005432841025	28909	94	16F
0005434458891	28909	95	17A
0005435252937	28909	96	17C
0005435990678	15763	1	1F
0005435990637	15763	2	1C
0005435990636	15763	3	2D
0005435990643	15763	4	3C
0005434276105	15763	5	5D
0005434276103	15763	6	9A
0005435990644	15763	7	9C
0005435990679	15763	8	9F
0005434276106	15763	9	10E
0005435990659	15763	10	13A
0005435990628	15763	11	14D
0005435990660	15763	12	15A
0005435990627	15763	13	15C
0005435990642	15763	14	15E
0005434276101	15763	15	16A
0005435990682	15763	16	16E
0005435990670	15763	17	18F
0005434276104	15763	18	20A
0005434276102	15763	19	19F
0005432909300	2077	1	1A
0005433468450	2077	2	1B
0005433468444	2077	3	1D
0005433468455	2077	4	2A
0005433468449	2077	5	2C
0005433468451	2077	6	2D
0005433468461	2077	7	3B
0005433468448	2077	8	4C
0005432909310	2077	9	5A
0005433468457	2077	10	5D
0005433468458	2077	11	6B
0005432909318	2077	12	7A
0005432909304	2077	13	7C
0005433468453	2077	14	18B
0005433468447	2077	15	18C
0005433468454	2077	16	19B
0005433468460	2077	17	19C
0005432909303	2077	18	20A
0005432909308	2077	19	20C
0005433468456	2077	20	20D
0005432909299	2077	21	21B
0005433468452	2077	22	21D
0005432909291	2077	23	22B
0005432909315	2077	24	22C
0005433468446	2077	25	22D
0005433468459	2077	26	23A
0005433468445	2077	27	23B
0005433468354	23842	1	1D
0005432909351	23842	2	6C
0005433468385	23842	3	6D
0005432909344	23842	4	7A
0005433468367	23842	5	7B
0005432909346	23842	6	7C
0005433468353	23842	7	18A
0005433468339	23842	8	18B
0005432909357	23842	9	18D
0005433468384	23842	10	19B
0005433468366	23842	11	19C
0005432909356	23842	12	19D
0005433468397	23842	13	20B
0005433468314	23842	14	20C
0005433468342	23842	15	21A
0005432909349	23842	16	21B
0005433468396	23842	17	21C
0005433468360	23842	18	21D
0005433468363	23842	19	22A
0005432909355	23842	20	22D
0005433468376	23842	21	23A
0005432909347	23842	22	23B
0005432909358	23842	23	1B
0005433468375	23842	24	2B
0005432909350	23842	25	2C
0005433468361	23842	26	1C
0005432909352	23842	27	1A
0005433468341	23842	28	2D
0005432909343	23842	29	3A
0005432909354	23842	30	3B
0005433468391	23842	31	3C
0005433468373	23842	32	4A
0005433468343	23842	33	4B
0005433468338	23842	34	4C
0005433468382	23842	35	4D
0005432909345	23842	36	5A
0005433468336	23842	37	5B
0005433468374	23842	38	5C
0005432909348	23842	39	5D
0005432909353	23842	40	6A
0005432363461	6393	1	5B
0005435177288	6393	2	3D
0005432361020	6393	3	21A
0005432361030	6393	4	18C
0005432361029	6393	5	19A
0005432062300	6393	6	22B
0005432361001	6393	7	17B
0005432360989	6393	8	18F
0005432336198	6393	9	14F
0005435177202	6393	10	23F
0005435177308	6393	11	14C
0005435177355	6393	12	19B
0005434149794	6393	13	16B
0005432361025	6393	14	13D
0005434149802	6393	15	15E
0005432336187	6393	16	2D
0005432360985	6393	17	22F
0005432361000	6393	18	9F
0005432360998	6393	19	14D
0005435177193	6393	20	17C
0005435177245	6393	21	13A
0005435177216	6393	22	7D
0005432062297	6393	23	20C
0005435177034	6393	24	15C
0005435177315	6393	25	13F
0005432360997	6393	26	6C
0005432336197	6393	27	16C
0005435177197	6393	28	8B
0005432361008	6393	29	11F
0005432062298	6393	30	1D
0005435177346	6393	31	23D
0005435177143	6393	32	22E
0005435177249	6393	33	21D
0005432062299	6393	34	5C
0005435177273	6393	35	6D
0005432361028	6393	36	7A
0005432361026	6393	37	19D
0005434149777	6393	38	8E
0005432360988	6393	39	17D
0005432336195	6393	40	12C
0005432360999	6393	41	11E
0005435177301	6393	42	18A
0005435177104	6393	43	20F
0005432363460	6393	44	9E
0005432336191	6393	45	7F
0005432336189	6393	46	2C
0005434149812	6393	47	1C
0005432361013	6393	48	19C
0005432361016	6393	49	14E
0005435177212	6393	50	12D
0005432361011	6393	51	12A
0005432336193	6393	52	17F
0005432360994	6393	53	9A
0005435177152	6393	54	4C
0005432361005	6393	55	23E
0005432361006	6393	56	10E
0005432361004	6393	57	16A
0005432363458	6393	58	23C
0005434149809	6393	59	3C
0005435177253	6393	60	5E
0005432062301	6393	61	15B
0005434149776	6393	62	4A
0005435177316	6393	63	18E
0005432360991	6393	64	9B
0005435177254	6393	65	21B
0005432361010	6393	66	13C
0005435177159	6393	67	16D
0005434149813	6393	68	11B
0005435177257	6393	69	4F
0005435177195	6393	70	17A
0005432361009	6393	71	3A
0005432360990	6393	72	5F
0005435177144	6393	73	6E
0005435177196	6393	74	18B
0005434149830	6393	75	1A
0005432336190	6393	76	13B
0005432361014	6393	77	21F
0005432361027	6393	78	8A
0005432363459	6393	79	8D
0005434149791	6393	80	5A
0005432361015	6393	81	13E
0005432361023	6393	82	20E
0005435177302	6393	83	15D
0005435177213	6393	84	16E
0005435177252	6393	85	8C
0005432361018	6393	86	21C
0005432361017	6393	87	23B
0005435177138	6393	88	7C
0005432360983	6393	89	20D
0005432062302	6393	90	8F
0005435177255	6393	91	10D
0005434149797	6393	92	12E
0005432360993	6393	93	11D
0005432360987	6393	94	16F
0005432361003	6393	95	10C
0005435177256	6393	96	9C
0005432360992	6393	97	4E
0005435177214	6393	98	4D
0005435177203	6393	99	3F
0005432361019	6393	100	11C
0005432360986	6393	101	14B
0005434149811	6393	102	5D
0005432361021	6393	103	19F
0005434149807	6393	104	15A
0005432336194	6393	105	2F
0005435177215	6393	106	20A
0005432360996	6393	107	18D
0005432336192	6393	108	17E
0005432336199	6393	109	22D
0005432361012	6393	110	11A
0005434149750	6393	111	1F
0005432360984	6393	112	23A
0005435177297	6393	113	10B
0005432361024	6393	114	7B
0005435490232	6393	115	22C
0005434149808	6393	116	21E
0005432336196	6393	117	12F
0005432336188	6393	118	6B
0005432361002	6393	119	9D
0005435490233	6393	120	6A
0005432361022	6393	121	4B
0005435177237	6393	122	22A
0005435177320	6393	123	20B
0005432361007	6393	124	14A
0005432360982	6393	125	6F
0005435177296	6393	126	19E
0005432360995	6393	127	7E
0005434149893	21038	1	23E
0005435177432	21038	2	1A
0005432360541	21038	3	1C
0005432360513	21038	4	1D
0005432360349	21038	5	2A
0005434149883	21038	6	1F
0005435177433	21038	7	2C
0005432360512	21038	8	2D
0005432360766	21038	9	2F
0005435177438	21038	10	3A
0005432360510	21038	11	3C
0005432360671	21038	12	3F
0005435177434	21038	13	4A
0005432360615	21038	14	4D
0005435177431	21038	15	4C
0005435177430	21038	16	4E
0005432360706	21038	17	4F
0005432360409	21038	18	5B
0005432360509	21038	19	5C
0005435177450	21038	20	5D
0005432360862	21038	21	5E
0005434149882	21038	22	5F
0005435490281	21038	23	6A
0005435177457	21038	24	6C
0005432336104	21038	25	6B
0005434149887	21038	26	6D
0005432360670	21038	27	6E
0005432360511	21038	28	7B
0005432360818	21038	29	7C
0005432336086	21038	30	7D
0005432360484	21038	31	7F
0005435177448	21038	32	7E
0005432360350	21038	33	8A
0005435177442	21038	34	8B
0005432360612	21038	35	8C
0005432360540	21038	36	8E
0005432360603	21038	37	8D
0005432360701	21038	38	9A
0005432360778	21038	39	8F
0005432360616	21038	40	9B
0005432052786	21038	41	9C
0005434149892	21038	42	9D
0005432360526	21038	43	9F
0005432360553	21038	44	9E
0005434149894	21038	45	10C
0005432360776	21038	46	10B
0005435177437	21038	47	10E
0005432336073	21038	48	10D
0005432360558	21038	49	11A
0005434149885	21038	50	11B
0005432336137	21038	51	11D
0005435490282	21038	52	11C
0005432360586	21038	53	11F
0005432360465	21038	54	11E
0005435177454	21038	55	12B
0005435490279	21038	56	12A
0005435490280	21038	57	12C
0005432336114	21038	58	12E
0005432360590	21038	59	12D
0005432360669	21038	60	12F
0005432336074	21038	61	13A
0005435177453	21038	62	13B
0005432336102	21038	63	13C
0005435177451	21038	64	13F
0005432360631	21038	65	14A
0005432336053	21038	66	14C
0005432336032	21038	67	14B
0005435177440	21038	68	14D
0005434149890	21038	69	14E
0005435177441	21038	70	14F
0005432336066	21038	71	15B
0005435177458	21038	72	15A
0005435177439	21038	73	15C
0005435177443	21038	74	15D
0005432360552	21038	75	16A
0005434149891	21038	76	16C
0005432336033	21038	77	16B
0005434149889	21038	78	16D
0005432336113	21038	79	16F
0005432052785	21038	80	16E
0005435177435	21038	81	17A
0005432360715	21038	82	17B
0005432360716	21038	83	17C
0005432360679	21038	84	17E
0005435177444	21038	85	17D
0005434149886	21038	86	17F
0005432360462	21038	87	18A
0005435177447	21038	88	18B
0005432052787	21038	89	18D
0005432336067	21038	90	18C
0005432360662	21038	91	18E
0005435177445	21038	92	18F
0005435177456	21038	93	19A
0005432360777	21038	94	19B
0005435177446	21038	95	19D
0005432360613	21038	96	19C
0005432360658	21038	97	19E
0005432360636	21038	98	19F
0005435177452	21038	99	20A
0005432360604	21038	100	20C
0005435723074	21038	101	20B
0005432360693	21038	102	20E
0005432360591	21038	103	21A
0005432360692	21038	104	20F
0005432336138	21038	105	21B
0005435177449	21038	106	21D
0005432360769	21038	107	21E
0005432360765	21038	108	22A
0005435177455	21038	109	21F
0005434149884	21038	110	22B
0005432360545	21038	111	22C
0005434149888	21038	112	22D
0005432360546	21038	113	22F
0005432336103	21038	114	22E
0005435177436	21038	115	23A
0005432360459	21038	116	23B
0005432360519	21038	117	23D
0005432360653	21038	118	23C
0005432360680	21038	119	23F
0005434458953	17742	1	23A
0005434458917	17742	2	2B
0005434458956	17742	3	22B
0005434186239	17742	4	4D
0005434458855	17742	5	22C
0005434458954	17742	6	2C
0005434448324	17742	7	4B
0005434458952	17742	8	18D
0005434463937	17742	9	5A
0005434458929	17742	10	18B
0005434458907	17742	11	3D
0005434448325	17742	12	3C
0005434458935	17742	13	1A
0005434458959	17742	14	5C
0005434463942	17742	15	20C
0005434186238	17742	16	5B
0005434448323	17742	17	19C
0005434458936	17742	18	19B
0005434458902	17742	19	7D
0005434461656	17742	20	22D
0005434458909	17742	21	4A
0005434448322	17742	22	1D
0005434458906	17742	23	19D
0005434458877	17742	24	6D
0005434458937	17742	25	23B
0005434448321	17742	26	21C
0005434463955	29081	1	20A
0005434459092	29081	2	20B
0005434459082	29081	3	20C
0005434186210	29081	4	20D
0005434186196	29081	5	21A
0005434186201	29081	6	21C
0005434459073	29081	7	21D
0005434462816	29081	8	22A
0005434448358	29081	9	22B
0005434448359	29081	10	22D
0005434186214	29081	11	23A
0005434186197	29081	12	23B
0005434459093	29081	13	6B
0005434459091	29081	14	1A
0005434459085	29081	15	1D
0005434459087	29081	16	2B
0005434459080	29081	17	2D
0005434459084	29081	18	3A
0005434459088	29081	19	3C
0005434448357	29081	20	3D
0005434186207	29081	21	4A
0005434463956	29081	22	4B
0005434459083	29081	23	4C
0005434459081	29081	24	4D
0005434462817	29081	25	5A
0005434459077	29081	26	5B
0005434459089	29081	27	5D
0005434459078	29081	28	6C
0005434459075	29081	29	6D
0005434448356	29081	30	7A
0005434459090	29081	31	7B
0005434459074	29081	32	7C
0005434462818	29081	33	18A
0005434186209	29081	34	18C
0005434459079	29081	35	18D
0005434186206	29081	36	19A
0005434459086	29081	37	19C
0005434459076	29081	38	19D
0005432604824	21463	1	1A
0005432604850	21463	2	1B
0005432604856	21463	3	1C
0005432604840	21463	4	1D
0005432604827	21463	5	2A
0005432604838	21463	6	2B
0005435218119	21463	7	2C
0005432604857	21463	8	2D
0005432604853	21463	9	3A
0005432604819	21463	10	3C
0005432604842	21463	11	3D
0005432604858	21463	12	4B
0005432604831	21463	13	4A
0005432604855	21463	14	4C
0005432604854	21463	15	5B
0005432604825	21463	16	5C
0005432604846	21463	17	5D
0005432604852	21463	18	6A
0005432604844	21463	19	6B
0005432604826	21463	20	6C
0005432604851	21463	21	7A
0005432604847	21463	22	7B
0005432604823	21463	23	7D
0005432604818	21463	24	18A
0005432604835	21463	25	18B
0005432604829	21463	26	18C
0005432604822	21463	27	18D
0005432604845	21463	28	19A
0005432604836	21463	29	19B
0005432604821	21463	30	19C
0005432604820	21463	31	19D
0005432604848	21463	32	20A
0005432604832	21463	33	20B
0005432604859	21463	34	20D
0005432604839	21463	35	21A
0005432604837	21463	36	21B
0005432604849	21463	37	21C
0005432604834	21463	38	21D
0005432604828	21463	39	22A
0005432604841	21463	40	22C
0005432604833	21463	41	22D
0005432604830	21463	42	23A
0005432604843	21463	43	23B
0005432604525	31714	1	5D
0005432604397	31714	2	1A
0005432604460	31714	3	1B
0005432604503	31714	4	1D
0005432604356	31714	5	2A
0005432604414	31714	6	2B
0005432604528	31714	7	2C
0005432604427	31714	8	2D
0005432604266	31714	9	3A
0005432604440	31714	10	3B
0005432604294	31714	11	3D
0005432604495	31714	12	4A
0005432604473	31714	13	4C
0005432604445	31714	14	4D
0005432604557	31714	15	5A
0005432604621	31714	16	5B
0005432604295	31714	17	5C
0005432604698	31714	18	6A
0005432604443	31714	19	6B
0005432604479	31714	20	6C
0005432604329	31714	21	6D
0005432604620	31714	22	7B
0005432604396	31714	23	7D
0005432604630	31714	24	18A
0005432604619	31714	25	18B
0005432604570	31714	26	18C
0005432604613	31714	27	18D
0005432604265	31714	28	19A
0005432604560	31714	29	19B
0005432604554	31714	30	19C
0005432604555	31714	31	19D
0005432604504	31714	32	20A
0005432604524	31714	33	20B
0005432604550	31714	34	20C
0005432604535	31714	35	21A
0005432604357	31714	36	21B
0005432604428	31714	37	21C
0005432604527	31714	38	21D
0005432604508	31714	39	22B
0005432604561	31714	40	22C
0005432604403	31714	41	22D
0005432604293	31714	42	23A
0005432604444	31714	43	23B
0005433293327	29591	1	1B
0005433293328	29591	2	2A
0005433293333	29591	3	3D
0005433293335	29591	4	5B
0005433293329	29591	5	5D
0005433293336	29591	6	6A
0005433293331	29591	7	6C
0005433293334	29591	8	19B
0005433293330	29591	9	20C
0005433293324	29591	10	21C
0005433293325	29591	11	22A
0005433293332	29591	12	22B
0005433293326	29591	13	22C
0005433473378	6685	1	1A
0005433473382	6685	2	1B
0005435257263	6685	3	2C
0005433473386	6685	4	2D
0005433473389	6685	5	4A
0005433473383	6685	6	4B
0005433473391	6685	7	5A
0005433473387	6685	8	5B
0005433473385	6685	9	5C
0005433473388	6685	10	5D
0005433473379	6685	11	6B
0005433473393	6685	12	18A
0005433473390	6685	13	18D
0005433473392	6685	14	18C
0005433473384	6685	15	19A
0005435257246	6685	16	19C
0005433473394	6685	17	19D
0005435257279	6685	18	20B
0005433473377	6685	19	20C
0005435257255	6685	20	21C
0005433473380	6685	21	22C
0005433473381	6685	22	22D
0005435257247	6685	23	23A
0005433473293	23883	1	1A
0005435257300	23883	2	1B
0005433473297	23883	3	1C
0005433473261	23883	4	1D
0005433473277	23883	5	2A
0005433473258	23883	6	2B
0005433473262	23883	7	2C
0005433473286	23883	8	2D
0005433473259	23883	9	3A
0005435257306	23883	10	3B
0005435257298	23883	11	3C
0005433473301	23883	12	3D
0005433473298	23883	13	4A
0005433473308	23883	14	4B
0005435257305	23883	15	4C
0005433473263	23883	16	4D
0005433473287	23883	17	5A
0005433473279	23883	18	5B
0005433473288	23883	19	5C
0005433473320	23883	20	5D
0005433473317	23883	21	6A
0005433473257	23883	22	6B
0005433473242	23883	23	6C
0005435257302	23883	24	6D
0005433473282	23883	25	7A
0005433473285	23883	26	7B
0005433473336	23883	27	7C
0005433473281	23883	28	7D
0005433473307	23883	29	18A
0005433473309	23883	30	18B
0005433473274	23883	31	18C
0005433473302	23883	32	18D
0005433473275	23883	33	19A
0005433473292	23883	34	19B
0005433473289	23883	35	19C
0005433473280	23883	36	19D
0005433473278	23883	37	20A
0005435257297	23883	38	20B
0005435257299	23883	39	20C
0005433473299	23883	40	20D
0005435257304	23883	41	21A
0005433473324	23883	42	21B
0005433473318	23883	43	21C
0005433473296	23883	44	21D
0005433473335	23883	45	22A
0005433473283	23883	46	22B
0005435257301	23883	47	22C
0005435257303	23883	48	22D
0005433473284	23883	49	23A
0005433473254	23883	50	23B
0005434606838	18841	1	2A
0005434606830	18841	2	3B
0005434604941	22361	1	1A
0005434606873	22361	2	1B
0005434604943	22361	3	2A
0005434604939	22361	4	2B
0005434604942	22361	5	3B
0005434606872	22361	6	4B
0005434604940	22361	7	5B
0005434606871	22361	8	6B
0005434522494	3839	1	4C
0005434602929	3839	2	1D
0005434522492	3839	3	2D
0005434522497	3839	4	3A
0005434522496	3839	5	3B
0005434522491	3839	6	4A
0005434522495	3839	7	6A
0005434602933	3839	8	6C
0005434602932	3839	9	7B
0005434602930	3839	10	18A
0005434602931	3839	11	18B
0005435904416	3839	12	18C
0005434522493	3839	13	19C
0005435904411	3839	14	20A
0005434522489	3839	15	20B
0005434522490	3839	16	20D
0005435904409	3839	17	22A
0005434522498	3839	18	22B
0005435904415	3839	19	22D
0005435904440	19061	1	1A
0005434522446	19061	2	1B
0005434522455	19061	3	1C
0005434522462	19061	4	2B
0005434604892	19061	5	2C
0005434522473	19061	6	2D
0005434602896	19061	7	3A
0005434522463	19061	8	3B
0005435904433	19061	9	3C
0005434522467	19061	10	4A
0005434522464	19061	11	4B
0005435904434	19061	12	4C
0005434604899	19061	13	4D
0005434604907	19061	14	5A
0005434522449	19061	15	5B
0005434522470	19061	16	5D
0005434602907	19061	17	6A
0005434522445	19061	18	6B
0005434602908	19061	19	6C
0005434604897	19061	20	7A
0005434604902	19061	21	7B
0005435904441	19061	22	7D
0005434522453	19061	23	18A
0005434522469	19061	24	18B
0005435904435	19061	25	18C
0005435904438	19061	26	19A
0005434522452	19061	27	19B
0005434522450	19061	28	19D
0005434602900	19061	29	20A
0005434602909	19061	30	20B
0005434522454	19061	31	20C
0005434522468	19061	32	20D
0005434604906	19061	33	21A
0005435904437	19061	34	21B
0005434604908	19061	35	21C
0005435904439	19061	36	21D
0005435904436	19061	37	22A
0005434522457	19061	38	22B
0005434602910	19061	39	23A
0005434604901	19061	40	22D
0005434522472	19061	41	23B
0005433875379	383	1	1A
0005432753341	383	2	1C
0005432748063	383	3	1D
0005432891117	383	4	2A
0005432748066	383	5	2C
0005432220058	383	6	2D
0005432891063	383	7	2F
0005432748058	383	8	3A
0005432748085	383	9	3C
0005432748055	383	10	3D
0005432890997	383	11	3F
0005433293255	383	12	4A
0005433875383	383	13	4C
0005432748079	383	14	4D
0005432891109	383	15	4E
0005433875380	383	16	4F
0005432749814	383	17	5A
0005432753342	383	18	5C
0005432753343	383	19	5E
0005433875384	383	20	5F
0005432748074	383	21	6A
0005432748073	383	22	6D
0005433875381	383	23	6E
0005432748049	383	24	6F
0005432748061	383	25	7A
0005432891048	383	26	7C
0005432748070	383	27	7D
0005433293278	383	28	7E
0005432891126	383	29	7F
0005432891110	383	30	8A
0005432748057	383	31	8D
0005432748052	383	32	8E
0005433293254	383	33	8F
0005432748080	383	34	9A
0005432220059	383	35	9D
0005432748060	383	36	9E
0005433293279	383	37	9F
0005432891101	383	38	10A
0005433293287	383	39	10C
0005433875382	383	40	10D
0005432751569	383	41	10E
0005433293295	383	42	10F
0005432748081	383	43	11A
0005433293296	383	44	11C
0005432748067	383	45	11E
0005432748050	383	46	11F
0005432748062	383	47	12A
0005432748065	383	48	12C
0005433293280	383	49	12D
0005432748051	383	50	12E
0005432748053	383	51	12F
0005432748064	383	52	13A
0005432748075	383	53	13C
0005432748068	383	54	13D
0005432749813	383	55	13E
0005432748077	383	56	14A
0005432748084	383	57	14C
0005433875378	383	58	14D
0005432748059	383	59	14E
0005432891125	383	60	14F
0005432753344	383	61	15A
0005432748086	383	62	15C
0005432749812	383	63	15D
0005432220060	383	64	15E
0005432891203	383	65	15F
0005432748076	383	66	16C
0005432748056	383	67	16D
0005432748078	383	68	16E
0005433875387	383	69	16F
0005432748083	383	70	17A
0005432891062	383	71	17C
0005432751567	383	72	17D
0005432748071	383	73	17E
0005432748054	383	74	17F
0005432748048	383	75	18A
0005432891047	383	76	18C
0005432751568	383	77	18E
0005432748082	383	78	18F
0005432748069	383	79	19A
0005432753345	383	80	19C
0005433293288	383	81	19F
0005432748072	383	82	20C
0005432749811	383	83	20D
0005432891157	383	84	20E
0005432891119	383	85	20F
0005432214833	12046	1	1A
0005435627120	12046	2	2A
0005432747737	12046	3	2D
0005433875399	12046	4	3A
0005433875398	12046	5	3C
0005432747747	12046	6	3D
0005432756835	12046	7	4A
0005432891287	12046	8	4E
0005432747880	12046	9	5C
0005432747687	12046	10	5F
0005432747818	12046	11	6A
0005432749802	12046	12	6F
0005432891274	12046	13	7C
0005432747675	12046	14	7E
0005432756863	12046	15	7F
0005432747793	12046	16	8A
0005432747766	12046	17	8D
0005432891282	12046	18	8F
0005432747826	12046	19	9A
0005432747626	12046	20	9D
0005432747879	12046	21	9E
0005432891289	12046	22	9F
0005432214834	12046	23	10A
0005432747616	12046	24	10C
0005432747688	12046	25	10E
0005432747794	12046	26	10F
0005432747714	12046	27	11A
0005432747612	12046	28	11C
0005432747730	12046	29	11D
0005432891277	12046	30	11F
0005432747767	12046	31	12A
0005432747904	12046	32	12C
0005432891281	12046	33	12F
0005432756868	12046	34	13A
0005432891276	12046	35	13C
0005432756848	12046	36	13E
0005432747816	12046	37	14A
0005432891285	12046	38	14C
0005432891288	12046	39	14D
0005432891279	12046	40	14F
0005432891286	12046	41	15A
0005432214831	12046	42	15D
0005432891272	12046	43	15E
0005432747738	12046	44	15F
0005432747613	12046	45	16A
0005432891270	12046	46	16C
0005432891280	12046	47	16D
0005432747795	12046	48	16E
0005432747791	12046	49	16F
0005435627119	12046	50	17E
0005432747674	12046	51	17F
0005432891278	12046	52	18A
0005432891271	12046	53	18D
0005432747817	12046	54	18F
0005432891284	12046	55	19C
0005432747907	12046	56	19D
0005432214832	12046	57	19E
0005432891283	12046	58	19F
0005432891275	12046	59	20C
0005432747814	12046	60	20E
0005432891273	12046	61	20F
0005433533355	18958	1	1C
0005433525174	18958	2	1D
0005433533354	18958	3	2A
0005433525180	18958	4	2C
0005433531339	18958	5	3C
0005433525178	18958	6	4C
0005433525177	18958	7	4D
0005432928008	18958	8	5B
0005433525172	18958	9	5D
0005432928007	18958	10	6D
0005433525176	18958	11	7A
0005433533356	18958	12	7B
0005433525169	18958	13	7C
0005433525179	18958	14	18B
0005433531338	18958	15	18C
0005433525173	18958	16	18D
0005433531341	18958	17	19B
0005433531340	18958	18	19C
0005432928022	18958	19	19D
0005433525175	18958	20	20B
0005433525170	18958	21	21B
0005433525171	18958	22	21C
0005433525181	18958	23	22A
0005432927984	18958	24	22C
0005433525146	32475	1	1C
0005432928057	32475	2	1D
0005433525075	32475	3	2A
0005433527281	32475	4	2C
0005433525125	32475	5	2D
0005432928059	32475	6	3B
0005433531317	32475	7	3C
0005433527292	32475	8	4D
0005433527280	32475	9	5A
0005432928062	32475	10	5B
0005432928060	32475	11	5D
0005433527279	32475	12	6B
0005433525095	32475	13	6C
0005433525086	32475	14	6D
0005433531316	32475	15	7A
0005433525094	32475	16	7B
0005433525102	32475	17	7C
0005432928058	32475	18	18B
0005433525124	32475	19	18D
0005433525065	32475	20	19A
0005433525123	32475	21	20A
0005432928061	32475	22	20C
0005433525122	32475	23	20D
0005433525039	32475	24	21C
0005433527278	32475	25	22A
0005433525064	32475	26	22C
0005434825248	5300	1	24E
0005435373730	5300	2	1C
0005434825336	5300	3	1H
0005434825256	5300	4	1D
0005434825228	5300	5	2C
0005435373858	5300	6	2A
0005434825258	5300	7	2H
0005434825274	5300	8	2D
0005434825303	5300	9	3A
0005434825297	5300	10	2K
0005434825326	5300	11	3D
0005434831211	5300	12	3H
0005432396299	5300	13	4A
0005435373888	5300	14	3K
0005434825313	5300	15	4G
0005434825208	5300	16	5A
0005432396297	5300	17	4H
0005434825292	5300	18	5D
0005434825257	5300	19	5C
0005434558389	5300	20	5H
0005435373448	5300	21	5G
0005434825254	5300	22	11A
0005432121523	5300	23	11C
0005434825314	5300	24	11F
0005434825281	5300	25	11E
0005434825278	5300	26	11H
0005435373719	5300	27	11G
0005434558396	5300	28	12E
0005434825269	5300	29	12D
0005432396295	5300	30	12G
0005434825317	5300	31	12F
0005435150213	5300	32	12K
0005435373889	5300	33	12H
0005434825300	5300	34	13D
0005434825299	5300	35	13C
0005434825311	5300	36	13E
0005435150217	5300	37	13H
0005434558395	5300	38	13G
0005432121524	5300	39	14A
0005435373525	5300	40	14C
0005434825277	5300	41	14E
0005435373306	5300	42	14K
0005434825287	5300	43	14G
0005432394159	5300	44	15A
0005434828732	5300	45	15E
0005434825289	5300	46	15D
0005434825308	5300	47	15H
0005434825224	5300	48	15F
0005434558385	5300	49	16C
0005434825245	5300	50	16F
0005432121519	5300	51	16H
0005435373293	5300	52	16G
0005434825238	5300	53	17C
0005434825233	5300	54	17A
0005435373497	5300	55	17D
0005434825237	5300	56	17F
0005435373762	5300	57	17H
0005434825306	5300	58	18C
0005434825263	5300	59	18A
0005434825329	5300	60	18E
0005434825218	5300	61	18D
0005432394156	5300	62	18K
0005435150211	5300	63	18J
0005434825291	5300	64	18H
0005435150215	5300	65	19B
0005434825259	5300	66	19A
0005435150209	5300	67	19F
0005434825284	5300	68	19E
0005435299802	5300	69	19H
0005435373603	5300	70	19K
0005434825267	5300	71	19J
0005435150220	5300	72	20C
0005434825283	5300	73	20B
0005434664989	5300	74	20A
0005434825332	5300	75	20E
0005434825325	5300	76	20G
0005434825243	5300	77	20K
0005434825211	5300	78	20H
0005434825323	5300	79	21B
0005434825246	5300	80	21D
0005435373761	5300	81	21F
0005434825270	5300	82	21E
0005434825296	5300	83	21H
0005434825221	5300	84	21G
0005434825225	5300	85	22A
0005434825276	5300	86	22B
0005434825216	5300	87	22E
0005435304174	5300	88	22H
0005434825253	5300	89	22G
0005435150207	5300	90	22F
0005434825236	5300	91	22J
0005434825321	5300	92	23B
0005432121522	5300	93	23A
0005432121517	5300	94	22K
0005435373574	5300	95	23C
0005434825293	5300	96	23F
0005434825288	5300	97	23H
0005434825242	5300	98	23G
0005435373579	5300	99	24D
0005435735143	5300	100	24F
0005434825279	5300	101	24G
0005435373434	5300	102	25D
0005434825207	5300	103	25C
0005435373379	5300	104	25B
0005434558393	5300	105	25E
0005434825241	5300	106	25H
0005435299788	5300	107	25G
0005434825230	5300	108	25K
0005434825210	5300	109	25J
0005435373735	5300	110	26B
0005435386609	5300	111	26E
0005435178996	5300	112	26D
0005435373609	5300	113	26G
0005434825333	5300	114	26F
0005434825240	5300	115	26J
0005434825260	5300	116	27B
0005434825305	5300	117	27A
0005434825213	5300	118	26K
0005434558397	5300	119	27C
0005434825252	5300	120	27E
0005434825331	5300	121	27G
0005434825334	5300	122	27F
0005435150210	5300	123	28A
0005434825295	5300	124	27J
0005434825294	5300	125	28D
0005434825304	5300	126	28F
0005435373679	5300	127	28E
0005435373723	5300	128	28J
0005434825255	5300	129	28H
0005434825212	5300	130	28K
0005435373380	5300	131	29D
0005435373536	5300	132	29C
0005434828733	5300	133	29F
0005435150219	5300	134	29H
0005434825214	5300	135	29G
0005435373414	5300	136	30A
0005434825264	5300	137	29K
0005434825316	5300	138	30C
0005435735162	5300	139	30E
0005434825251	5300	140	30D
0005434825315	5300	141	30F
0005434825235	5300	142	30J
0005435373647	5300	143	30H
0005434825309	5300	144	31A
0005434825266	5300	145	31D
0005434825249	5300	146	31B
0005432121526	5300	147	31E
0005434825217	5300	148	31H
0005435373535	5300	149	31G
0005435386596	5300	150	32A
0005432121527	5300	151	31K
0005432396300	5300	152	31J
0005434558388	5300	153	32C
0005432121525	5300	154	32D
0005432396298	5300	155	32G
0005434558384	5300	156	32J
0005435386595	5300	157	32H
0005434828731	5300	158	33C
0005435150218	5300	159	33B
0005434825234	5300	160	33H
0005434825275	5300	161	33G
0005434825250	5300	162	33K
0005434825223	5300	163	34B
0005435373859	5300	164	34D
0005434825272	5300	165	34G
0005432121528	5300	166	34J
0005434825319	5300	167	35A
0005432396296	5300	168	35J
0005432121529	5300	169	35H
0005432121520	5300	170	36A
0005435304191	5300	171	35K
0005434558387	5300	172	36B
0005435373578	5300	173	36F
0005432394157	5300	174	36E
0005434825227	5300	175	36D
0005434825318	5300	176	36G
0005435150221	5300	177	36K
0005434825229	5300	178	36J
0005435373334	5300	179	36H
0005435386597	5300	180	37D
0005435373526	5300	181	37C
0005434825265	5300	182	37F
0005434825273	5300	183	37H
0005434825290	5300	184	37K
0005434825337	5300	185	38C
0005435373626	5300	186	38B
0005434825244	5300	187	38H
0005434825271	5300	188	39A
0005435735142	5300	189	39C
0005432121521	5300	190	39B
0005434825322	5300	191	39G
0005435373791	5300	192	39F
0005434825262	5300	193	39E
0005434831208	5300	194	40A
0005434825330	5300	195	40C
0005434558398	5300	196	40B
0005434558391	5300	197	40D
0005435373792	5300	198	40G
0005432121516	5300	199	40F
0005434825261	5300	200	40J
0005435150214	5300	201	41B
0005435373575	5300	202	41D
0005432121515	5300	203	41C
0005435373725	5300	204	41F
0005434825222	5300	205	41E
0005434825209	5300	206	41H
0005435150216	5300	207	41G
0005434825301	5300	208	42A
0005435373360	5300	209	41K
0005434831210	5300	210	41J
0005434825324	5300	211	42C
0005435373565	5300	212	42E
0005435304175	5300	213	42G
0005434825285	5300	214	42J
0005434825312	5300	215	42H
0005434825247	5300	216	43A
0005434825335	5300	217	43D
0005434825298	5300	218	43C
0005435373498	5300	219	43H
0005434825320	5300	220	44A
0005434558392	5300	221	43K
0005434825302	5300	222	44B
0005434558394	5300	223	44E
0005435373729	5300	224	44D
0005434825239	5300	225	44F
0005434825268	5300	226	44H
0005434831209	5300	227	45C
0005434825231	5300	228	45B
0005435150212	5300	229	45E
0005435373594	5300	230	45D
0005434825232	5300	231	45J
0005434558386	5300	232	45H
0005435373381	5300	233	45G
0005434825282	5300	234	45K
0005434825280	5300	235	46B
0005435150208	5300	236	46F
0005432394158	5300	237	46J
0005434825220	5300	238	47A
0005434825226	5300	239	46K
0005435373495	5300	240	47E
0005435373292	5300	241	47C
0005434825286	5300	242	47G
0005434825327	5300	243	47K
0005434825328	5300	244	47H
0005435373676	5300	245	48A
0005434825215	5300	246	48F
0005435373279	5300	247	48E
0005435373328	5300	248	48G
0005435386575	5300	249	49G
0005434831207	5300	250	49F
0005434558390	5300	251	49E
0005435373680	5300	252	49K
0005434825307	5300	253	50F
0005435373545	5300	254	50E
0005435373668	5300	255	50D
0005434825310	5300	256	50G
0005435373785	5300	257	51D
0005434825219	5300	258	51F
0005435373546	5300	259	51E
0005432121518	5300	260	51G
0005435374120	9939	1	28E
0005435150030	9939	2	1G
0005435374125	9939	3	1H
0005434824267	9939	4	2C
0005435374150	9939	5	2A
0005432823479	9939	6	3D
0005435150105	9939	7	3H
0005434823369	9939	8	4C
0005434824794	9939	9	1C
0005434823367	9939	10	4A
0005432203158	9939	11	3K
0005434824322	9939	12	4G
0005434824101	9939	13	4K
0005435374155	9939	14	4H
0005434823855	9939	15	5C
0005435299842	9939	16	5K
0005434824219	9939	17	11E
0005435374107	9939	18	11D
0005435374110	9939	19	11C
0005435374100	9939	20	11F
0005434824212	9939	21	11H
0005434824418	9939	22	12C
0005435374121	9939	23	12A
0005435150063	9939	24	12E
0005435374116	9939	25	12D
0005435374104	9939	26	12G
0005434558296	9939	27	12F
0005434824023	9939	28	13A
0005434824272	9939	29	12K
0005434824275	9939	30	12H
0005434824045	9939	31	13D
0005434824456	9939	32	13F
0005435150066	9939	33	13E
0005434824407	9939	34	13G
0005434824409	9939	35	13K
0005434824510	9939	36	14E
0005435374117	9939	37	14D
0005434824105	9939	38	14G
0005434831191	9939	39	14F
0005435150041	9939	40	14K
0005434824595	9939	41	14H
0005434824157	9939	42	15D
0005435374151	9939	43	15C
0005435374113	9939	44	15A
0005434823779	9939	45	15F
0005434824321	9939	46	15E
0005435386658	9939	47	15G
0005434823919	9939	48	15K
0005434824488	9939	49	16D
0005434824073	9939	50	16C
0005434831176	9939	51	16A
0005434824198	9939	52	16H
0005434823940	9939	53	16K
0005434823856	9939	54	17C
0005434823727	9939	55	17H
0005434824452	9939	56	17G
0005434824085	9939	57	17F
0005435374098	9939	58	18B
0005434824534	9939	59	18D
0005434823996	9939	60	18G
0005434824660	9939	61	18F
0005434824106	9939	62	18H
0005434824642	9939	63	19A
0005435374106	9939	64	19D
0005434831178	9939	65	19C
0005434824553	9939	66	19J
0005435299841	9939	67	19H
0005434831175	9939	68	20A
0005435386655	9939	69	19K
0005435299840	9939	70	20C
0005434664965	9939	71	20B
0005435150126	9939	72	20G
0005435302263	9939	73	20F
0005435386651	9939	74	20H
0005434824154	9939	75	21B
0005435386654	9939	76	21A
0005435661970	9939	77	21D
0005434824368	9939	78	21F
0005434824155	9939	79	21E
0005432203160	9939	80	21J
0005434824049	9939	81	21H
0005434824033	9939	82	22A
0005434823706	9939	83	21K
0005435374126	9939	84	22D
0005434824169	9939	85	23B
0005434823689	9939	86	23A
0005434823567	9939	87	23D
0005434824333	9939	88	23C
0005434824624	9939	89	23G
0005435302261	9939	90	23F
0005434824102	9939	91	23E
0005435374159	9939	92	23H
0005432400150	9939	93	24F
0005434824277	9939	94	25A
0005435374146	9939	95	25E
0005434824593	9939	96	25G
0005435386657	9939	97	25K
0005434664962	9939	98	25J
0005434823921	9939	99	26C
0005434823726	9939	100	26A
0005432203161	9939	101	26E
0005434823910	9939	102	26D
0005434824197	9939	103	26G
0005434824509	9939	104	26J
0005434824592	9939	105	26H
0005432400139	9939	106	27B
0005435302260	9939	107	27A
0005434824227	9939	108	26K
0005434824268	9939	109	27D
0005434824449	9939	110	27C
0005435374149	9939	111	27F
0005434824596	9939	112	27E
0005435374119	9939	113	27J
0005435179406	9939	114	27H
0005434823847	9939	115	27G
0005435374148	9939	116	28A
0005435374138	9939	117	1A
0005435735198	9939	118	28D
0005435735199	9939	119	28C
0005435374137	9939	120	28G
0005432400151	9939	121	28F
0005435150067	9939	122	28K
0005434664961	9939	123	28H
0005435374156	9939	124	29B
0005435374130	9939	125	29A
0005432203162	9939	126	29C
0005435150143	9939	127	29F
0005435374127	9939	128	29D
0005434824382	9939	129	29J
0005434824310	9939	130	29H
0005434664960	9939	131	29G
0005435374152	9939	132	30A
0005432203159	9939	133	29K
0005434824408	9939	134	30B
0005435374132	9939	135	30E
0005435374153	9939	136	30C
0005435374123	9939	137	30F
0005435374111	9939	138	30J
0005435374141	9939	139	30H
0005434823650	9939	140	31B
0005435735200	9939	141	30K
0005434824468	9939	142	31D
0005432823477	9939	143	31F
0005432396261	9939	144	31H
0005432396252	9939	145	31G
0005435374143	9939	146	32A
0005434824255	9939	147	31K
0005434824552	9939	148	32C
0005432400133	9939	149	32B
0005435374144	9939	150	32E
0005432823476	9939	151	32G
0005434824084	9939	152	32F
0005434824766	9939	153	33A
0005435374109	9939	154	33D
0005435735202	9939	155	33C
0005435374105	9939	156	33F
0005435299839	9939	157	33E
0005434824793	9939	158	33H
0005434824179	9939	159	33K
0005435374160	9939	160	33J
0005434824112	9939	161	34B
0005432400138	9939	162	34E
0005435374114	9939	163	34D
0005435661971	9939	164	34G
0005435374133	9939	165	34F
0005435299838	9939	166	34J
0005434823166	9939	167	35B
0005434824364	9939	168	34K
0005434824759	9939	169	35D
0005435374112	9939	170	35C
0005434824256	9939	171	35E
0005434823960	9939	172	35H
0005435302264	9939	173	35G
0005435374099	9939	174	36C
0005435302259	9939	175	36B
0005435374158	9939	176	36E
0005434824427	9939	177	36H
0005434824203	9939	178	36K
0005434824069	9939	179	36J
0005434558314	9939	180	37B
0005435374139	9939	181	37A
0005435299837	9939	182	37C
0005434824052	9939	183	37G
0005435150055	9939	184	37E
0005435374145	9939	185	37J
0005432400152	9939	186	38A
0005432400134	9939	187	37K
0005434831170	9939	188	38C
0005434824419	9939	189	38B
0005434824428	9939	190	38J
0005435150064	9939	191	39F
0005434823857	9939	192	39E
0005434824252	9939	193	39D
0005435374124	9939	194	39H
0005434823790	9939	195	39K
0005434824100	9939	196	40C
0005434823707	9939	197	40E
0005434824189	9939	198	40D
0005432823478	9939	199	40H
0005434824309	9939	200	40G
0005435374147	9939	201	40F
0005435374131	9939	202	40K
0005434824138	9939	203	41D
0005435374140	9939	204	41F
0005435374103	9939	205	41E
0005435386652	9939	206	41J
0005435374118	9939	207	42A
0005434823965	9939	208	41K
0005434824025	9939	209	42B
0005434824024	9939	210	42E
0005434824017	9939	211	42D
0005434824090	9939	212	42G
0005434824489	9939	213	42F
0005434824026	9939	214	42J
0005434824141	9939	215	43F
0005435374115	9939	216	43H
0005434824046	9939	217	43G
0005434823690	9939	218	43J
0005434824111	9939	219	44C
0005434823884	9939	220	44A
0005434824344	9939	221	44D
0005432396268	9939	222	44F
0005434824019	9939	223	44J
0005434824533	9939	224	44H
0005432396253	9939	225	45A
0005434824742	9939	226	44K
0005434824314	9939	227	45D
0005434824767	9939	228	45F
0005435374136	9939	229	45H
0005435386653	9939	230	45G
0005434824142	9939	231	45J
0005434824218	9939	232	46B
0005435374129	9939	233	46A
0005434824311	9939	234	46E
0005434823854	9939	235	46D
0005432203157	9939	236	46G
0005435374161	9939	237	46F
0005434823867	9939	238	46K
0005435386656	9939	239	46J
0005434824380	9939	240	46H
0005435374101	9939	241	47C
0005435374154	9939	242	47A
0005435374108	9939	243	47E
0005434824381	9939	244	47G
0005434824137	9939	245	47K
0005435374157	9939	246	47H
0005435150104	9939	247	48E
0005435374128	9939	248	48D
0005435302262	9939	249	48G
0005435374134	9939	250	49A
0005435374122	9939	251	49D
0005434824276	9939	252	49G
0005434823165	9939	253	49F
0005435374135	9939	254	49K
0005435150103	9939	255	49H
0005434823920	9939	256	50C
0005435374102	9939	257	50A
0005434824263	9939	258	50E
0005435735201	9939	259	50G
0005434824824	9939	260	50K
0005434824741	9939	261	51F
0005435150040	9939	262	51E
0005435374142	9939	263	51D
0005434823368	9939	264	51G
0005435790346	7003	1	20C
0005435082896	7003	2	21A
0005435082892	7003	3	23B
0005435790345	7003	4	1B
0005435790344	7003	5	1C
0005435082893	7003	6	3D
0005435082895	7003	7	4B
0005435082897	7003	8	19A
0005435082894	7003	9	20B
0005435790313	25981	1	4C
0005435082828	25981	2	4A
0005435082807	25981	3	3A
0005435082804	25981	4	20D
0005435082805	25981	5	22B
0005435082785	25981	6	1B
0005435790314	25981	7	19D
0005435082827	25981	8	6B
0005435790322	25981	9	18D
0005435082809	25981	10	1D
0005435790321	25981	11	6D
0005435082829	25981	12	22C
0005434214648	9541	1	6A
0005434214563	9541	2	6F
0005434756995	9541	3	7A
0005434756994	9541	4	7C
0005434214734	9541	5	7D
0005434757001	9541	6	7E
0005434214660	9541	7	7F
0005434214808	9541	8	8A
0005434214639	9541	9	8C
0005434756990	9541	10	8E
0005434756996	9541	11	8F
0005434756989	9541	12	9A
0005434214732	9541	13	9C
0005434214497	9541	14	9D
0005434756979	9541	15	9E
0005434756976	9541	16	9F
0005434214511	9541	17	10A
0005434757005	9541	18	10D
0005434214801	9541	19	10E
0005434214644	9541	20	10F
0005434214807	9541	21	11C
0005434756986	9541	22	11D
0005434214692	9541	23	11E
0005434756982	9541	24	11F
0005434756992	9541	25	12A
0005434756998	9541	26	12C
0005434214812	9541	27	12D
0005434214687	9541	28	12E
0005434214640	9541	29	12F
0005434756978	9541	30	13A
0005434756970	9541	31	13C
0005434214733	9541	32	13D
0005434214716	9541	33	13E
0005434214608	9541	34	13F
0005434214819	9541	35	14A
0005434214659	9541	36	14C
0005434756965	9541	37	14D
0005434756973	9541	38	14E
0005434214693	9541	39	14F
0005434757002	9541	40	15A
0005434756997	9541	41	15C
0005434214643	9541	42	15D
0005434214641	9541	43	15E
0005434756977	9541	44	15F
0005434214813	9541	45	16C
0005434756985	9541	46	16D
0005434214769	9541	47	16E
0005434214896	9541	48	16F
0005434756993	9541	49	17A
0005434756968	9541	50	17C
0005434214562	9541	51	17E
0005434756999	9541	52	17F
0005434214691	9541	53	18A
0005434214847	9541	54	18C
0005434756987	9541	55	18D
0005434756988	9541	56	18E
0005434214800	9541	57	18F
0005434214972	9541	58	19A
0005434214645	9541	59	19C
0005434214510	9541	60	19D
0005434214854	9541	61	19E
0005434214595	9541	62	19F
0005434756969	9541	63	20A
0005434757006	9541	64	20C
0005434214895	9541	65	20D
0005434214835	9541	66	20E
0005434756972	9541	67	20F
0005434756975	9541	68	8D
0005434214584	9541	69	1A
0005434214731	9541	70	1C
0005434756981	9541	71	1D
0005434756980	9541	72	1F
0005434757004	9541	73	2A
0005434757000	9541	74	2C
0005434757003	9541	75	2D
0005434756983	9541	76	2F
0005434756974	9541	77	3A
0005434214656	9541	78	3C
0005434756966	9541	79	3F
0005434756971	9541	80	4A
0005434756967	9541	81	4C
0005434756984	9541	82	4D
0005434214642	9541	83	4E
0005434756991	9541	84	4F
0005434214973	9541	85	5A
0005434214730	9541	86	5C
0005434214802	9541	87	5D
0005434214836	9541	88	5F
0005434215116	28617	1	1A
0005434215121	28617	2	1C
0005434215111	28617	3	1D
0005434215082	28617	4	2A
0005434215108	28617	5	2C
0005434215087	28617	6	2D
0005434215107	28617	7	2F
0005434215079	28617	8	3C
0005434215086	28617	9	3D
0005434215093	28617	10	3F
0005434215104	28617	11	4C
0005434215102	28617	12	4D
0005434215105	28617	13	4F
0005434756592	28617	14	5A
0005434215100	28617	15	5C
0005434215092	28617	16	5D
0005434756664	28617	17	5E
0005434215085	28617	18	5F
0005434215091	28617	19	6A
0005434215099	28617	20	6D
0005434756495	28617	21	6E
0005434756490	28617	22	6F
0005434756580	28617	23	7A
0005434215119	28617	24	7C
0005434215110	28617	25	7D
0005434215117	28617	26	7E
0005434215113	28617	27	7F
0005434215098	28617	28	8C
0005434756510	28617	29	8D
0005434215080	28617	30	8E
0005434756588	28617	31	8F
0005434756448	28617	32	9C
0005434215125	28617	33	9D
0005434756508	28617	34	9F
0005434215101	28617	35	10A
0005434215109	28617	36	10D
0005434756566	28617	37	10E
0005434215095	28617	38	10F
0005434756608	28617	39	11A
0005434215103	28617	40	11C
0005434215097	28617	41	11D
0005434756489	28617	42	11F
0005434215096	28617	43	12A
0005434756491	28617	44	12C
0005434215123	28617	45	12D
0005434215112	28617	46	12E
0005434215120	28617	47	12F
0005434756565	28617	48	13A
0005434756500	28617	49	13C
0005434756559	28617	50	13D
0005434215106	28617	51	13E
0005434756771	28617	52	13F
0005434215081	28617	53	14C
0005434756547	28617	54	14E
0005434756620	28617	55	14F
0005434215122	28617	56	15A
0005434756396	28617	57	15C
0005434756772	28617	58	15E
0005434756606	28617	59	15F
0005434215084	28617	60	16C
0005434756428	28617	61	16D
0005434756601	28617	62	16E
0005434215083	28617	63	16F
0005434215089	28617	64	17C
0005434756461	28617	65	17D
0005434756429	28617	66	17F
0005434215118	28617	67	18A
0005434215078	28617	68	18C
0005434756507	28617	69	18D
0005434215115	28617	70	18E
0005434756480	28617	71	18F
0005434215088	28617	72	19A
0005434756388	28617	73	19C
0005434756479	28617	74	19D
0005434756558	28617	75	19E
0005434756587	28617	76	19F
0005434215090	28617	77	20A
0005434215114	28617	78	20C
0005434215094	28617	79	20D
0005434215124	28617	80	20E
0005434756501	28617	81	20F
0005435100164	10826	1	1D
0005434760197	10826	2	7B
0005435100162	10826	3	18B
0005435100163	10826	4	19B
0005434760208	10826	5	22B
0005434760207	10826	6	22D
0005434760204	10826	7	23B
0005435100145	31843	1	3C
0005435100133	31843	2	7A
0005434760230	31843	3	19D
0005434760229	31843	4	20D
0005433202390	1987	1	3A
0005433202391	1987	2	1A
0005432290676	1987	3	1B
0005434639662	1987	4	1C
0005434639681	1987	5	1D
0005434639659	1987	6	2A
0005434639669	1987	7	2B
0005434639672	1987	8	2C
0005433202450	1987	9	2D
0005434639673	1987	10	3B
0005433202377	1987	11	3C
0005433202389	1987	12	3D
0005434639671	1987	13	4A
0005432290678	1987	14	4B
0005433202402	1987	15	4C
0005434639656	1987	16	4D
0005434639665	1987	17	5A
0005433202477	1987	18	5C
0005432290677	1987	19	5B
0005433202449	1987	20	5D
0005432290674	1987	21	6A
0005434639678	1987	22	6B
0005434639668	1987	23	6C
0005433202457	1987	24	6D
0005433202462	1987	25	7A
0005434639661	1987	26	7B
0005432290675	1987	27	7C
0005433202448	1987	28	7D
0005434639674	1987	29	18A
0005433202392	1987	30	18B
0005434639679	1987	31	18C
0005434639658	1987	32	18D
0005433202471	1987	33	19A
0005433202463	1987	34	19B
0005434639675	1987	35	19C
0005434639663	1987	36	19D
0005433202423	1987	37	20A
0005434639655	1987	38	20B
0005434639670	1987	39	20C
0005434639667	1987	40	20D
0005434639657	1987	41	21A
0005434639676	1987	42	21B
0005434639680	1987	43	21C
0005434639666	1987	44	21D
0005434639660	1987	45	22A
0005434639683	1987	46	22B
0005434639664	1987	47	22C
0005434639677	1987	48	22D
0005435948338	1987	49	23A
0005434639682	1987	50	23B
0005433202548	23268	1	1C
0005434639465	23268	2	1D
0005433202550	23268	3	2A
0005434639483	23268	4	2B
0005433202552	23268	5	2C
0005434639346	23268	6	3D
0005433202542	23268	7	4A
0005434639432	23268	8	4B
0005433202541	23268	9	5A
0005433202540	23268	10	5B
0005433202543	23268	11	5D
0005434639481	23268	12	6A
0005433202551	23268	13	6C
0005434639388	23268	14	7A
0005434639422	23268	15	7C
0005434639451	23268	16	7D
0005434639480	23268	17	18A
0005434639397	23268	18	18D
0005434639489	23268	19	19A
0005434639490	23268	20	19B
0005433202547	23268	21	19C
0005433202553	23268	22	19D
0005434639375	23268	23	20A
0005435948330	23268	24	20B
0005434639360	23268	25	20C
0005433202545	23268	26	20D
0005433202546	23268	27	21B
0005433202549	23268	28	21D
0005434639535	23268	29	22A
0005434639482	23268	30	22B
0005434639382	23268	31	22C
0005434639536	23268	32	22D
0005433202544	23268	33	23A
0005434639418	23268	34	23B
0005433533357	6072	1	1C
0005434601169	6072	2	1D
0005434601155	6072	3	2A
0005433531345	6072	4	2D
0005433531346	6072	5	3A
0005434601162	6072	6	3C
0005434601176	6072	7	4D
0005434601170	6072	8	4E
0005434601154	6072	9	4F
0005434601181	6072	10	5A
0005435326833	6072	11	5D
0005434601178	6072	12	5E
0005433531343	6072	13	5F
0005435326834	6072	14	6D
0005434601172	6072	15	7C
0005433533361	6072	16	8A
0005432111318	6072	17	7F
0005434601171	6072	18	8C
0005433533360	6072	19	8E
0005434601161	6072	20	9C
0005435326796	6072	21	9D
0005435326797	6072	22	9E
0005433533359	6072	23	10C
0005434601173	6072	24	10E
0005434601160	6072	25	10F
0005434601164	6072	26	11A
0005434601168	6072	27	11C
0005433531344	6072	28	11D
0005435326818	6072	29	12C
0005435326835	6072	30	12F
0005434601165	6072	31	12E
0005434601159	6072	32	13A
0005434601166	6072	33	13D
0005435326817	6072	34	13F
0005435326869	6072	35	14E
0005434601167	6072	36	14F
0005434601179	6072	37	15A
0005434601156	6072	38	15C
0005435326815	6072	39	15D
0005434601180	6072	40	15E
0005434601158	6072	41	16A
0005434601174	6072	42	16C
0005434601177	6072	43	16D
0005433533358	6072	44	16E
0005432111319	6072	45	17A
0005432111320	6072	46	17F
0005433531342	6072	47	18A
0005435326816	6072	48	18D
0005434601175	6072	49	18E
0005434601163	6072	50	19C
0005434601157	6072	51	20A
0005435326784	6072	52	20D
0005435326783	6072	53	20F
0005435326934	18613	1	1C
0005434601014	18613	2	1D
0005434601005	18613	3	1F
0005434600926	18613	4	2C
0005433531306	18613	5	3A
0005434600801	18613	6	2F
0005434600927	18613	7	3C
0005435326929	18613	8	4A
0005434600817	18613	9	4E
0005434600851	18613	10	5C
0005433527261	18613	11	5F
0005434600818	18613	12	6D
0005435326933	18613	13	6C
0005435326928	18613	14	6F
0005435326936	18613	15	7A
0005435326924	18613	16	7C
0005433531304	18613	17	7F
0005434600825	18613	18	8A
0005433527262	18613	19	8D
0005434600931	18613	20	9A
0005435326931	18613	21	9C
0005435326925	18613	22	9D
0005435326926	18613	23	10C
0005434600857	18613	24	10E
0005434600948	18613	25	12A
0005434600881	18613	26	12C
0005434600932	18613	27	12D
0005433531292	18613	28	12E
0005434601082	18613	29	12F
0005435326937	18613	30	13A
0005433531308	18613	31	13D
0005435326932	18613	32	13F
0005434600819	18613	33	14C
0005435326930	18613	34	14E
0005434601004	18613	35	14F
0005434600925	18613	36	15D
0005434600882	18613	37	15E
0005435326927	18613	38	15F
0005434600870	18613	39	16A
0005434600956	18613	40	16D
0005434600991	18613	41	16E
0005434600864	18613	42	17A
0005435326935	18613	43	18F
0005435326922	18613	44	19E
0005435326923	18613	45	20A
0005434600974	18613	46	20C
0005434600929	18613	47	20D
0005434551927	10652	1	1A
0005434551910	10652	2	1C
0005434551907	10652	3	1D
0005434551897	10652	4	1F
0005434551887	10652	5	2A
0005434554092	10652	6	2C
0005434551924	10652	7	2D
0005434551886	10652	8	2F
0005434551882	10652	9	3A
0005434558377	10652	10	3C
0005434551923	10652	11	3D
0005434551906	10652	12	3F
0005434551919	10652	13	4A
0005434551911	10652	14	4C
0005433181108	10652	15	4D
0005434551901	10652	16	4E
0005434551913	10652	17	4F
0005433181125	10652	18	5A
0005433181175	10652	19	5C
0005434551891	10652	20	5D
0005434551900	10652	21	5E
0005433181165	10652	22	5F
0005434558382	10652	23	6C
0005433181265	10652	24	6D
0005434551905	10652	25	6E
0005434551909	10652	26	6F
0005434551935	10652	27	7A
0005434551889	10652	28	7C
0005434551933	10652	29	7D
0005433181166	10652	30	7E
0005433181121	10652	31	7F
0005434551934	10652	32	8A
0005434551888	10652	33	8C
0005434551930	10652	34	8D
0005433181231	10652	35	8E
0005434558376	10652	36	8F
0005434551883	10652	37	9A
0005434558379	10652	38	9C
0005434551893	10652	39	9D
0005434554091	10652	40	9E
0005433181211	10652	41	9F
0005434551894	10652	42	10A
0005434551936	10652	43	10C
0005434558381	10652	44	10D
0005434558380	10652	45	10E
0005434551926	10652	46	10F
0005433181258	10652	47	11A
0005433181266	10652	48	11C
0005434551928	10652	49	11D
0005433181232	10652	50	11E
0005434551884	10652	51	11F
0005433181107	10652	52	12A
0005434551921	10652	53	12C
0005434551925	10652	54	12D
0005433181239	10652	55	12E
0005434554089	10652	56	12F
0005434551922	10652	57	13A
0005433181171	10652	58	13C
0005433181212	10652	59	13D
0005433181186	10652	60	13E
0005434551892	10652	61	13F
0005433181255	10652	62	14A
0005434551914	10652	63	14C
0005433181238	10652	64	14D
0005434551917	10652	65	14E
0005434551912	10652	66	14F
0005434554090	10652	67	15A
0005433181242	10652	68	15D
0005434551890	10652	69	15C
0005434551915	10652	70	15E
0005433181145	10652	71	15F
0005434551899	10652	72	16A
0005434551918	10652	73	16C
0005434551902	10652	74	16D
0005433181176	10652	75	16E
0005434558383	10652	76	16F
0005434551885	10652	77	17A
0005434551931	10652	78	17C
0005434551916	10652	79	17D
0005434551920	10652	80	17E
0005434551932	10652	81	17F
0005434558378	10652	82	18A
0005434551896	10652	83	18C
0005433181235	10652	84	18D
0005433181088	10652	85	18E
0005434551881	10652	86	18F
0005434551898	10652	87	19A
0005434551908	10652	88	19C
0005434551929	10652	89	19D
0005434551903	10652	90	19E
0005433181267	10652	91	19F
0005433181177	10652	92	20A
0005434551904	10652	93	20C
0005434551895	10652	94	20D
0005433181243	10652	95	20E
0005433181126	10652	96	20F
0005433181431	27712	1	2D
0005433181445	27712	2	2F
0005433181429	27712	3	5D
0005433181436	27712	4	5E
0005433181447	27712	5	6D
0005433181446	27712	6	7F
0005433181426	27712	7	9E
0005433181441	27712	8	9F
0005433181430	27712	9	10C
0005433181438	27712	10	10F
0005433181427	27712	11	11D
0005433181437	27712	12	13F
0005433181444	27712	13	14A
0005433181433	27712	14	14E
0005433181428	27712	15	14F
0005433181434	27712	16	15A
0005433181443	27712	17	16D
0005433181448	27712	18	16E
0005433181425	27712	19	17A
0005433181440	27712	20	18F
0005433181439	27712	21	19C
0005433181435	27712	22	19D
0005433181442	27712	23	20D
0005433181432	27712	24	20F
0005434551680	27711	1	1C
0005434551642	27711	2	1D
0005434551570	27711	3	2A
0005434551540	27711	4	2C
0005434558289	27711	5	3C
0005434551456	27711	6	3D
0005434551177	27711	7	3F
0005434558317	27711	8	4A
0005434551599	27711	9	4D
0005434551553	27711	10	4E
0005434551156	27711	11	4F
0005434551489	27711	12	5D
0005434551635	27711	13	5E
0005434551793	27711	14	6A
0005434551457	27711	15	6C
0005434551619	27711	16	6D
0005434551332	27711	17	6E
0005434551555	27711	18	6F
0005434551492	27711	19	7A
0005434551542	27711	20	7F
0005434551214	27711	21	8A
0005434551620	27711	22	8C
0005434551441	27711	23	9A
0005434551464	27711	24	9C
0005434551407	27711	25	9D
0005434551499	27711	26	9E
0005434558290	27711	27	10A
0005434551541	27711	28	10E
0005434551733	27711	29	10F
0005434551681	27711	30	11A
0005434551428	27711	31	11C
0005434551482	27711	32	11F
0005434551518	27711	33	12A
0005434551406	27711	34	12C
0005434551398	27711	35	13A
0005434551279	27711	36	13D
0005434551583	27711	37	13F
0005434551474	27711	38	14A
0005434551621	27711	39	14E
0005434551822	27711	40	14F
0005434551503	27711	41	15A
0005434551494	27711	42	15C
0005434551641	27711	43	15D
0005434558288	27711	44	15E
0005434551612	27711	45	15F
0005434551554	27711	46	16A
0005434551427	27711	47	16D
0005434551611	27711	48	16E
0005434551465	27711	49	16F
0005434551493	27711	50	17A
0005434551504	27711	51	17C
0005434551529	27711	52	17D
0005434558321	27711	53	17E
0005434558316	27711	54	17F
0005434551397	27711	55	18A
0005434551550	27711	56	18C
0005434551794	27711	57	18E
0005434551539	27711	58	18F
0005434551440	27711	59	19C
0005434558300	27711	60	19D
0005434551572	27711	61	19E
0005434558287	27711	62	19F
0005434554074	27711	63	20C
0005434551386	27711	64	20D
0005433459277	6120	1	1A
0005435254481	6120	2	1B
0005435254479	6120	3	2B
0005433459274	6120	4	3B
0005435254482	6120	5	4A
0005433459276	6120	6	4B
0005435254480	6120	7	5A
0005433459278	6120	8	5B
0005433459275	6120	9	6B
0005433459239	19306	1	1A
0005433459238	19306	2	1B
0005433459235	19306	3	2A
0005433459243	19306	4	2B
0005433459250	19306	5	3A
0005435254505	19306	6	4A
0005435254506	19306	7	5A
0005435682661	6766	1	1A
0005432533305	6766	2	1C
0005432136237	6766	3	1D
0005435682675	6766	4	1F
0005435438138	6766	5	2A
0005435438150	6766	6	2C
0005435682676	6766	7	2D
0005435438057	6766	8	2F
0005435682641	6766	9	3A
0005435438077	6766	10	3C
0005435661969	6766	11	3D
0005435682651	6766	12	3F
0005435438071	6766	13	4A
0005435438025	6766	14	4C
0005435438115	6766	15	4D
0005435682662	6766	16	4E
0005435437968	6766	17	4F
0005432533306	6766	18	5A
0005435682667	6766	19	5C
0005434828701	6766	20	5D
0005435682639	6766	21	5E
0005435438070	6766	22	5F
0005435682679	6766	23	6A
0005432136235	6766	24	6C
0005435438165	6766	25	6D
0005435631005	6766	26	6E
0005435682652	6766	27	6F
0005432136233	6766	28	7A
0005435217718	6766	29	7D
0005435682660	6766	30	7C
0005435682677	6766	31	7E
0005435682656	6766	32	7F
0005435682647	6766	33	8A
0005435438123	6766	34	8C
0005435438137	6766	35	8D
0005435682666	6766	36	8E
0005435682673	6766	37	8F
0005435682672	6766	38	9A
0005435682659	6766	39	9C
0005435682681	6766	40	9D
0005435438041	6766	41	9E
0005435438053	6766	42	9F
0005435438111	6766	43	10A
0005435682671	6766	44	10C
0005435438064	6766	45	10D
0005435438055	6766	46	10E
0005435682664	6766	47	10F
0005432533307	6766	48	11A
0005435438023	6766	49	11D
0005432136232	6766	50	11C
0005432136234	6766	51	11E
0005435438136	6766	52	11F
0005435217725	6766	53	12A
0005435682674	6766	54	12C
0005435682654	6766	55	12D
0005435682649	6766	56	12E
0005435682642	6766	57	12F
0005435438043	6766	58	13A
0005435661968	6766	59	13C
0005435217727	6766	60	13D
0005435682648	6766	61	13E
0005435682650	6766	62	13F
0005435631004	6766	63	14A
0005435682646	6766	64	14C
0005432136236	6766	65	14D
0005435438063	6766	66	14E
0005435438149	6766	67	14F
0005435682669	6766	68	15A
0005435661966	6766	69	15C
0005435682645	6766	70	15D
0005435682643	6766	71	15E
0005435438122	6766	72	15F
0005435682653	6766	73	16A
0005435682658	6766	74	16C
0005435631006	6766	75	16D
0005435631007	6766	76	16E
0005435682663	6766	77	17A
0005435438026	6766	78	16F
0005435438104	6766	79	17C
0005435438103	6766	80	17D
0005435682668	6766	81	17E
0005435438024	6766	82	17F
0005435682665	6766	83	18A
0005435661967	6766	84	18C
0005435682655	6766	85	18D
0005432533304	6766	86	18E
0005435682657	6766	87	18F
0005435438042	6766	88	19A
0005435437967	6766	89	19C
0005435682644	6766	90	19D
0005435682670	6766	91	19E
0005435438164	6766	92	19F
0005435682678	6766	93	20A
0005435438027	6766	94	20C
0005435682680	6766	95	20D
0005435682640	6766	96	20E
0005435438105	6766	97	20F
0005435682322	24605	1	4D
0005435682380	24605	2	1A
0005435682324	24605	3	1C
0005435682204	24605	4	1D
0005432533331	24605	5	1F
0005435438257	24605	6	2A
0005435438256	24605	7	2C
0005435438254	24605	8	2D
0005435438236	24605	9	2F
0005432533329	24605	10	3A
0005435630984	24605	11	3C
0005435438250	24605	12	3F
0005435438253	24605	13	4C
0005435682311	24605	14	4A
0005435682288	24605	15	4F
0005435438239	24605	16	5A
0005435682260	24605	17	5C
0005435630978	24605	18	5E
0005435682293	24605	19	5F
0005435682353	24605	20	6A
0005435720826	24605	21	6C
0005435720825	24605	22	6D
0005435438241	24605	23	6E
0005435682270	24605	24	7A
0005435682222	24605	25	7C
0005435682325	24605	26	7D
0005435438238	24605	27	7E
0005432305780	24605	28	8A
0005435682371	24605	29	8C
0005435438251	24605	30	8D
0005435682413	24605	31	8E
0005434828734	24605	32	8F
0005435682359	24605	33	9A
0005435438234	24605	34	9C
0005435438243	24605	35	9E
0005435682037	24605	36	9F
0005435682399	24605	37	10A
0005435682412	24605	38	10C
0005435682323	24605	39	10D
0005435682223	24605	40	10E
0005435682407	24605	41	10F
0005435682059	24605	42	11C
0005435438245	24605	43	11D
0005435682459	24605	44	11E
0005435682203	24605	45	11F
0005435438249	24605	46	12A
0005435438247	24605	47	12C
0005435438244	24605	48	12E
0005435682137	24605	49	12F
0005434828735	24605	50	13C
0005432305782	24605	51	13D
0005435682382	24605	52	13E
0005435682444	24605	53	13F
0005435682440	24605	54	14A
0005432305781	24605	55	14C
0005435682367	24605	56	14D
0005435661945	24605	57	14E
0005435682286	24605	58	14F
0005435630972	24605	59	15A
0005435438237	24605	60	15C
0005435682261	24605	61	15D
0005435682330	24605	62	15E
0005435438240	24605	63	15F
0005435438252	24605	64	16C
0005435438246	24605	65	16E
0005435438248	24605	66	16F
0005435661944	24605	67	17A
0005435682287	24605	68	17C
0005435438255	24605	69	17D
0005435682202	24605	70	17E
0005435682294	24605	71	17F
0005435682189	24605	72	18A
0005435682379	24605	73	18D
0005432533330	24605	74	18E
0005435682274	24605	75	18F
0005435438242	24605	76	19A
0005435682384	24605	77	19C
0005435682201	24605	78	19D
0005435630975	24605	79	19E
0005435682255	24605	80	20A
0005435682411	24605	81	20C
0005435682248	24605	82	20D
0005435438235	24605	83	20E
0005435126861	11509	1	1C
0005435126875	11509	2	2A
0005435126867	11509	3	2D
0005435126860	11509	4	3D
0005435126872	11509	5	3F
0005435126877	11509	6	4A
0005435126874	11509	7	4D
0005435126895	11509	8	4F
0005435126885	11509	9	5A
0005435126883	11509	10	6A
0005435558094	11509	11	6C
0005435126886	11509	12	6D
0005435126865	11509	13	6E
0005435126859	11509	14	6F
0005435106023	11509	15	7A
0005435126894	11509	16	7E
0005435126887	11509	17	8A
0005435126876	11509	18	8C
0005435126870	11509	19	8D
0005435126878	11509	20	8E
0005435126889	11509	21	9F
0005435126896	11509	22	10A
0005435558108	11509	23	11A
0005435126858	11509	24	11D
0005435126869	11509	25	12C
0005435126863	11509	26	12E
0005435126893	11509	27	1A
0005435126879	11509	28	12F
0005435126884	11509	29	13C
0005435126866	11509	30	13D
0005435106022	11509	31	13E
0005435126873	11509	32	13F
0005435126868	11509	33	14C
0005435126871	11509	34	14E
0005435126881	11509	35	15A
0005435126857	11509	36	15C
0005435126856	11509	37	16A
0005435126880	11509	38	16C
0005435126890	11509	39	16F
0005435126882	11509	40	17E
0005435126862	11509	41	18C
0005435126892	11509	42	18E
0005435126891	11509	43	19A
0005435126864	11509	44	19C
0005435558107	11509	45	19E
0005435126855	11509	46	20A
0005435126888	11509	47	20F
0005435126647	31867	1	1A
0005435126498	31867	2	1D
0005435126423	31867	3	2A
0005435126483	31867	4	2F
0005435126548	31867	5	3A
0005435126514	31867	6	3C
0005435126781	31867	7	3F
0005435126610	31867	8	4E
0005435126632	31867	9	4F
0005435098568	31867	10	5E
0005435126512	31867	11	6A
0005435126609	31867	12	6D
0005435558122	31867	13	6E
0005435126484	31867	14	7D
0005435106002	31867	15	8D
0005435126549	31867	16	8E
0005435126502	31867	17	8F
0005435558123	31867	18	9C
0005435126411	31867	19	9E
0005435126678	31867	20	10C
0005435126664	31867	21	11A
0005435105984	31867	22	11C
0005435126572	31867	23	11D
0005435126500	31867	24	12E
0005435126487	31867	25	13A
0005435126539	31867	26	13C
0005435126526	31867	27	13F
0005435098567	31867	28	14A
0005435126646	31867	29	14D
0005435558121	31867	30	15E
0005435126625	31867	31	15F
0005435126782	31867	32	16C
0005435106011	31867	33	17C
0005435126522	31867	34	17D
0005435106012	31867	35	17F
0005435126424	31867	36	18C
0005435105991	31867	37	18E
0005435105996	31867	38	19C
0005435126565	31867	39	19F
0005435098569	31867	40	20D
0005435126612	31867	41	20F
0005435732348	13543	1	1A
0005435732388	13543	2	1D
0005433398683	13543	3	2A
0005433398690	13543	4	2F
0005433398717	13543	5	3A
0005433398716	13543	6	3C
0005433398672	13543	7	3D
0005433398708	13543	8	3F
0005433398704	13543	9	4C
0005433398710	13543	10	4D
0005433398713	13543	11	4E
0005433398694	13543	12	5A
0005433398670	13543	13	5C
0005433398691	13543	14	5D
0005433398684	13543	15	6A
0005433398702	13543	16	6D
0005433398673	13543	17	6F
0005435732392	13543	18	7A
0005433398700	13543	19	7D
0005433398698	13543	20	7E
0005435732412	13543	21	7F
0005435732413	13543	22	8C
0005433398705	13543	23	8E
0005433398714	13543	24	8F
0005433398706	13543	25	9D
0005435732367	13543	26	9E
0005433398687	13543	27	9F
0005433398711	13543	28	10A
0005433398680	13543	29	10D
0005433398699	13543	30	10F
0005433398681	13543	31	11A
0005433398707	13543	32	11C
0005433398688	13543	33	11E
0005433398692	13543	34	11F
0005433398678	13543	35	12A
0005435732366	13543	36	12C
0005435732381	13543	37	12D
0005433398682	13543	38	12F
0005433398719	13543	39	13A
0005433398686	13543	40	13C
0005433398712	13543	41	13E
0005435732393	13543	42	13F
0005433398709	13543	43	14A
0005433398674	13543	44	14E
0005433398685	13543	45	14F
0005435732347	13543	46	15A
0005433398689	13543	47	15E
0005433398695	13543	48	16A
0005435732378	13543	49	16C
0005433398671	13543	50	16D
0005433398696	13543	51	16F
0005433398718	13543	52	17A
0005435732389	13543	53	17C
0005433398675	13543	54	17E
0005433398677	13543	55	18A
0005435732450	13543	56	18C
0005433398703	13543	57	19A
0005433398701	13543	58	19C
0005433398679	13543	59	19D
0005433398676	13543	60	19E
0005433398715	13543	61	20A
0005433398697	13543	62	20C
0005435732326	13543	63	20D
0005435732325	13543	64	20E
0005433398693	13543	65	20F
0005432297312	19389	1	1A
0005433398111	19389	2	1D
0005433398202	19389	3	1F
0005433398131	19389	4	2A
0005433398401	19389	5	2D
0005433398130	19389	6	2C
0005433398147	19389	7	2F
0005433398238	19389	8	3A
0005433398402	19389	9	3C
0005435732493	19389	10	3F
0005435732496	19389	11	4A
0005432297313	19389	12	4C
0005435732510	19389	13	4D
0005433398336	19389	14	4E
0005433398058	19389	15	5C
0005433398209	19389	16	5D
0005435732507	19389	17	5F
0005433398403	19389	18	6C
0005435732501	19389	19	6D
0005435732495	19389	20	6F
0005433398286	19389	21	7D
0005435732503	19389	22	7E
0005433398304	19389	23	7F
0005435732508	19389	24	8A
0005433398239	19389	25	8C
0005433398259	19389	26	8D
0005433398285	19389	27	8E
0005433398284	19389	28	8F
0005435732505	19389	29	9A
0005435732504	19389	30	9F
0005433398249	19389	31	10A
0005435732494	19389	32	10D
0005435732502	19389	33	10E
0005433398313	19389	34	10F
0005433398182	19389	35	11A
0005435732506	19389	36	11C
0005432297311	19389	37	11D
0005433398385	19389	38	11E
0005433398422	19389	39	12A
0005433398236	19389	40	12C
0005435732497	19389	41	12E
0005433398387	19389	42	12F
0005433398230	19389	43	13A
0005433398370	19389	44	13C
0005435732511	19389	45	13F
0005433398242	19389	46	14A
0005435732499	19389	47	14E
0005433398148	19389	48	14F
0005433398335	19389	49	15A
0005435732500	19389	50	15C
0005433398205	19389	51	16A
0005433398567	19389	52	16F
0005433398203	19389	53	17A
0005433398204	19389	54	17C
0005433398112	19389	55	17D
0005433398191	19389	56	17E
0005435732498	19389	57	17F
0005433398404	19389	58	18A
0005432297314	19389	59	18C
0005433398237	19389	60	18D
0005433398513	19389	61	18E
0005433398303	19389	62	18F
0005433398334	19389	63	19A
0005435732509	19389	64	19C
0005433398388	19389	65	19E
0005433398312	19389	66	20C
0005433398368	19389	67	20D
0005433398159	19389	68	20E
0005433398129	19389	69	20F
0005435069233	13147	1	1A
0005435069360	13147	2	1C
0005435069299	13147	3	2A
0005435069374	13147	4	2C
0005435069521	13147	5	2F
0005435069188	13147	6	3A
0005435069251	13147	7	3C
0005435069036	13147	8	3F
0005435069129	13147	9	4A
0005435069190	13147	10	4C
0005435069200	13147	11	4D
0005435069304	13147	12	4E
0005435069173	13147	13	4F
0005435069520	13147	14	5A
0005435068860	13147	15	5C
0005435069081	13147	16	5D
0005435069172	13147	17	5E
0005435069263	13147	18	6C
0005435069394	13147	19	6D
0005435069303	13147	20	7A
0005435069246	13147	21	7C
0005435925468	13147	22	7D
0005435069354	13147	23	7E
0005435069084	13147	24	7F
0005435069373	13147	25	8A
0005435069270	13147	26	8C
0005435069174	13147	27	8D
0005435069271	13147	28	9A
0005435069391	13147	29	9C
0005435925470	13147	30	9E
0005435069473	13147	31	10A
0005435069153	13147	32	10C
0005435069175	13147	33	10F
0005435069358	13147	34	11C
0005435925471	13147	35	11D
0005435069241	13147	36	11E
0005435069187	13147	37	11F
0005435069359	13147	38	12A
0005435069245	13147	39	12C
0005435069199	13147	40	12E
0005435069019	13147	41	13A
0005435069085	13147	42	13D
0005435069121	13147	43	13E
0005435069443	13147	44	13F
0005435069444	13147	45	14A
0005435069133	13147	46	14D
0005435925469	13147	47	14E
0005435925472	13147	48	14F
0005435069264	13147	49	15A
0005435069080	13147	50	15C
0005435069109	13147	51	15D
0005435069383	13147	52	15E
0005435069466	13147	53	15F
0005435069311	13147	54	16A
0005435069247	13147	55	16C
0005435069117	13147	56	16D
0005435069393	13147	57	16E
0005435069020	13147	58	17A
0005435069060	13147	59	17E
0005435069289	13147	60	17F
0005435069401	13147	61	18C
0005435069353	13147	62	18D
0005435069390	13147	63	18E
0005435069369	13147	64	19A
0005435069372	13147	65	19C
0005435069082	13147	66	19D
0005435069108	13147	67	19F
0005435069120	13147	68	20A
0005435069395	13147	69	20C
0005435069212	13147	70	20E
0005435069132	13147	71	20F
0005435925330	15505	1	1A
0005435069696	15505	2	1C
0005435069722	15505	3	1D
0005435069720	15505	4	2A
0005435069710	15505	5	2C
0005435069719	15505	6	2D
0005435069721	15505	7	2F
0005435069745	15505	8	3A
0005435069737	15505	9	3C
0005435069746	15505	10	3D
0005435069709	15505	11	3F
0005435069703	15505	12	4D
0005435069736	15505	13	4E
0005435069740	15505	14	4F
0005435069711	15505	15	5E
0005435069727	15505	16	5F
0005435069732	15505	17	6A
0005435069747	15505	18	6C
0005435069734	15505	19	6D
0005435069695	15505	20	6F
0005435069699	15505	21	7C
0005435925331	15505	22	7D
0005435069748	15505	23	7F
0005435069706	15505	24	8A
0005435069728	15505	25	8C
0005435925334	15505	26	8D
0005435069708	15505	27	8E
0005435069714	15505	28	9C
0005435925318	15505	29	9E
0005435925321	15505	30	9F
0005435925319	15505	31	10C
0005435069738	15505	32	10E
0005435069731	15505	33	10F
0005435069712	15505	34	11A
0005435069729	15505	35	11C
0005435069705	15505	36	11D
0005435069701	15505	37	11E
0005435069715	15505	38	12A
0005435925339	15505	39	12C
0005435069698	15505	40	12D
0005435069739	15505	41	12E
0005435069743	15505	42	12F
0005435925340	15505	43	13A
0005435069742	15505	44	13C
0005435069700	15505	45	13F
0005435925325	15505	46	14A
0005435925335	15505	47	14E
0005435069725	15505	48	14F
0005435069707	15505	49	15D
0005435069718	15505	50	15F
0005435069716	15505	51	16C
0005435069704	15505	52	16E
0005435069744	15505	53	16F
0005435069733	15505	54	17E
0005435069723	15505	55	18A
0005435069713	15505	56	18C
0005435069697	15505	57	18D
0005435069717	15505	58	18E
0005435069730	15505	59	19A
0005435069726	15505	60	19D
0005435069702	15505	61	19E
0005435925317	15505	62	19F
0005435069735	15505	63	20A
0005435069724	15505	64	20C
0005435925338	15505	65	20D
0005435069741	15505	66	20E
0005435808299	29495	1	1A
0005433407627	29495	2	1B
0005435808250	29495	3	1C
0005435808262	29495	4	1D
0005433407629	29495	5	2A
0005435808253	29495	6	2B
0005435808255	29495	7	3A
0005435808300	29495	8	3B
0005435808240	29495	9	3C
0005435808249	29495	10	3D
0005433407637	29495	11	4A
0005435808264	29495	12	4B
0005433407636	29495	13	4C
0005435808257	29495	14	5A
0005435808295	29495	15	5B
0005435808267	29495	16	5C
0005435808246	29495	17	5D
0005433407633	29495	18	7A
0005433407631	29495	19	7B
0005435808296	29495	20	7C
0005435808258	29495	21	7D
0005433407630	29495	22	18A
0005435808247	29495	23	18B
0005435808238	29495	24	18C
0005433407635	29495	25	18D
0005433407632	29495	26	19C
0005435808254	29495	27	19D
0005435808252	29495	28	20A
0005433407628	29495	29	20B
0005435808278	29495	30	20C
0005435808263	29495	31	21A
0005435808288	29495	32	21B
0005435808279	29495	33	21D
0005435808259	29495	34	22A
0005435808251	29495	35	22B
0005435808248	29495	36	22C
0005433407634	29495	37	23A
0005434215144	10694	1	1A
0005434756538	10694	2	1C
0005434215166	10694	3	1D
0005434215156	10694	4	1F
0005434215155	10694	5	2A
0005434756617	10694	6	2C
0005434756613	10694	7	2F
0005434756687	10694	8	3A
0005434215157	10694	9	3C
0005434756526	10694	10	3D
0005434215136	10694	11	3F
0005434215147	10694	12	4A
0005434215142	10694	13	4C
0005434215164	10694	14	4D
0005434756590	10694	15	4E
0005434215130	10694	16	4F
0005434215134	10694	17	5A
0005434756568	10694	18	5C
0005434756632	10694	19	5D
0005434756573	10694	20	5E
0005434215167	10694	21	5F
0005434756529	10694	22	6A
0005434215131	10694	23	6C
0005434756706	10694	24	6E
0005434756513	10694	25	6F
0005434756552	10694	26	7A
0005434215154	10694	27	7C
0005434756574	10694	28	7D
0005434756618	10694	29	7E
0005434756530	10694	30	7F
0005434215168	10694	31	8A
0005434756499	10694	32	8C
0005434756537	10694	33	8D
0005434756689	10694	34	8E
0005434215133	10694	35	8F
0005434756514	10694	36	9A
0005434756567	10694	37	9C
0005434215158	10694	38	9D
0005434756570	10694	39	9E
0005434756688	10694	40	9F
0005434215171	10694	41	10A
0005434756412	10694	42	10C
0005434215161	10694	43	10D
0005434215165	10694	44	10E
0005434756619	10694	45	10F
0005434215135	10694	46	11A
0005434756704	10694	47	11C
0005434756630	10694	48	11D
0005434215127	10694	49	11E
0005434215141	10694	50	11F
0005434215149	10694	51	12A
0005434215172	10694	52	12C
0005434215145	10694	53	12D
0005434756416	10694	54	12E
0005434756403	10694	55	12F
0005434215163	10694	56	13A
0005434215159	10694	57	13C
0005434215153	10694	58	13D
0005434215170	10694	59	13E
0005434756564	10694	60	13F
0005434215162	10694	61	14A
0005434215148	10694	62	14C
0005434756671	10694	63	14D
0005434215151	10694	64	14E
0005434215146	10694	65	14F
0005434756544	10694	66	15A
0005434756609	10694	67	15C
0005434215169	10694	68	15D
0005434215126	10694	69	15E
0005434756404	10694	70	15F
0005434756536	10694	71	16A
0005434215128	10694	72	16C
0005434215129	10694	73	16D
0005434215137	10694	74	16E
0005434756681	10694	75	16F
0005434756471	10694	76	17A
0005434756454	10694	77	17C
0005434215150	10694	78	17D
0005434756543	10694	79	17E
0005434215139	10694	80	17F
0005434756453	10694	81	18A
0005434215138	10694	82	18C
0005434756583	10694	83	18E
0005434756411	10694	84	18F
0005434756652	10694	85	19A
0005434215152	10694	86	19C
0005434215132	10694	87	19D
0005434756651	10694	88	19E
0005434756604	10694	89	19F
0005434215143	10694	90	20A
0005434215140	10694	91	20C
0005434756569	10694	92	20E
0005434215160	10694	93	20F
0005434756957	28693	1	1A
0005434756942	28693	2	1C
0005434756947	28693	3	1D
0005434214718	28693	4	1F
0005434214661	28693	5	2A
0005434214534	28693	6	2C
0005434756941	28693	7	2D
0005434214519	28693	8	2F
0005434214809	28693	9	3A
0005434756955	28693	10	3C
0005434214597	28693	11	3D
0005434214513	28693	12	4A
0005434214646	28693	13	4C
0005434756948	28693	14	4D
0005434756954	28693	15	4E
0005434756946	28693	16	4F
0005434214671	28693	17	5A
0005434214596	28693	18	5C
0005434756950	28693	19	5D
0005434756944	28693	20	5E
0005434214528	28693	21	5F
0005434756937	28693	22	6A
0005434214737	28693	23	6D
0005434214699	28693	24	6E
0005434214793	28693	25	6F
0005434214449	28693	26	7A
0005434214838	28693	27	7C
0005434214886	28693	28	7E
0005434214413	28693	29	7F
0005434756929	28693	30	8A
0005434214448	28693	31	8C
0005434214609	28693	32	8D
0005434214587	28693	33	8E
0005434756960	28693	34	8F
0005434214650	28693	35	9A
0005434756940	28693	36	9C
0005434756953	28693	37	9D
0005434214682	28693	38	9F
0005434214698	28693	39	10A
0005434214610	28693	40	10C
0005434214514	28693	41	10D
0005434214668	28693	42	10E
0005434214740	28693	43	10F
0005434756951	28693	44	11A
0005434214810	28693	45	11C
0005434756952	28693	46	11D
0005434756958	28693	47	11F
0005434214560	28693	48	12A
0005434214588	28693	49	12C
0005434756934	28693	50	12D
0005434214586	28693	51	12E
0005434214621	28693	52	12F
0005434756959	28693	53	13A
0005434214504	28693	54	13C
0005434756962	28693	55	13D
0005434756956	28693	56	13E
0005434214669	28693	57	13F
0005434214681	28693	58	14A
0005434756936	28693	59	14C
0005434214721	28693	60	14D
0005434214628	28693	61	14E
0005434214622	28693	62	14F
0005434214592	28693	63	15A
0005434756961	28693	64	15C
0005434214629	28693	65	15D
0005434756964	28693	66	15E
0005434214414	28693	67	15F
0005434214553	28693	68	16A
0005434756932	28693	69	16C
0005434214593	28693	70	16D
0005434214559	28693	71	16F
0005434214613	28693	72	17A
0005434756928	28693	73	17C
0005434214419	28693	74	17D
0005434756943	28693	75	17E
0005434756931	28693	76	17F
0005434214487	28693	77	18A
0005434214552	28693	78	18C
0005434756938	28693	79	18D
0005434214722	28693	80	18E
0005434214887	28693	81	18F
0005434756930	28693	82	19A
0005434756945	28693	83	19C
0005434756949	28693	84	19D
0005434214706	28693	85	19E
0005434756933	28693	86	20A
0005434756935	28693	87	20C
0005434756939	28693	88	20D
0005434214811	28693	89	20E
0005434756963	28693	90	20F
0005434229411	5459	1	1A
0005435040595	5459	2	1C
0005435007341	5459	3	1D
0005435040647	5459	4	2A
0005434229437	5459	5	1F
0005435040645	5459	6	2C
0005434229500	5459	7	2D
0005435040652	5459	8	3A
0005435040618	5459	9	2F
0005435040641	5459	10	3C
0005435040599	5459	11	3D
0005435040617	5459	12	4A
0005435007334	5459	13	3F
0005435040639	5459	14	4B
0005435040597	5459	15	4D
0005435007340	5459	16	4C
0005435040611	5459	17	4F
0005432125548	5459	18	4E
0005435040621	5459	19	5A
0005434229501	5459	20	5C
0005435007338	5459	21	5B
0005435040593	5459	22	5D
0005435040594	5459	23	5E
0005434229516	5459	24	5F
0005434229402	5459	25	6A
0005434229462	5459	26	6C
0005435042886	5459	27	6B
0005435007339	5459	28	6D
0005435007352	5459	29	6F
0005435040650	5459	30	7B
0005434229535	5459	31	7A
0005435040596	5459	32	7C
0005435040608	5459	33	7D
0005432125547	5459	34	7E
0005434229457	5459	35	8A
0005435007332	5459	36	7F
0005435040589	5459	37	8B
0005435040616	5459	38	8C
0005435040602	5459	39	8E
0005435040619	5459	40	8D
0005434229481	5459	41	8F
0005435040592	5459	42	9A
0005435007353	5459	43	9B
0005435040640	5459	44	9C
0005435040627	5459	45	9E
0005434229552	5459	46	9D
0005434229438	5459	47	9F
0005435007346	5459	48	10B
0005432125546	5459	49	10C
0005435040649	5459	50	10E
0005435007342	5459	51	10D
0005434229628	5459	52	11A
0005435040610	5459	53	11B
0005432125549	5459	54	11C
0005435040591	5459	55	11E
0005435040586	5459	56	11D
0005435040604	5459	57	11F
0005435040635	5459	58	12A
0005435040601	5459	59	12B
0005435040632	5459	60	12C
0005435007348	5459	61	12E
0005435040613	5459	62	12D
0005435040638	5459	63	12F
0005432125545	5459	64	13A
0005435040612	5459	65	13B
0005435007330	5459	66	13D
0005435040642	5459	67	13C
0005434229498	5459	68	13E
0005435040637	5459	69	13F
0005435040636	5459	70	14A
0005435007347	5459	71	14C
0005435040600	5459	72	14B
0005435040590	5459	73	14D
0005435040622	5459	74	14E
0005435007333	5459	75	14F
0005435040625	5459	76	15A
0005435043293	5459	77	15C
0005435040628	5459	78	15B
0005435040607	5459	79	15D
0005435040646	5459	80	15E
0005435040633	5459	81	16A
0005435040643	5459	82	15F
0005435040629	5459	83	16B
0005435040624	5459	84	16C
0005435007345	5459	85	16D
0005432125550	5459	86	16F
0005435042887	5459	87	16E
0005435040585	5459	88	17B
0005435007335	5459	89	17A
0005435040615	5459	90	17C
0005432125552	5459	91	17D
0005435040620	5459	92	17F
0005435043294	5459	93	17E
0005435040614	5459	94	18A
0005435007337	5459	95	18C
0005435040626	5459	96	18B
0005435007343	5459	97	18D
0005435040609	5459	98	18F
0005435007344	5459	99	18E
0005435040630	5459	100	19A
0005435042885	5459	101	19B
0005435040605	5459	102	19D
0005435007354	5459	103	19C
0005435007350	5459	104	19F
0005435042888	5459	105	19E
0005435007331	5459	106	20A
0005435007349	5459	107	20B
0005435042889	5459	108	20D
0005435040651	5459	109	20C
0005435007351	5459	110	20E
0005435040644	5459	111	20F
0005435007336	5459	112	21B
0005435040648	5459	113	21A
0005435040598	5459	114	21C
0005434229586	5459	115	21D
0005434229480	5459	116	21F
0005435040603	5459	117	21E
0005435040623	5459	118	22B
0005434229585	5459	119	22A
0005434229629	5459	120	22C
0005434229487	5459	121	22D
0005435040606	5459	122	22E
0005435040588	5459	123	23A
0005435040587	5459	124	23B
0005432125551	5459	125	23C
0005435040634	5459	126	23D
0005435040631	5459	127	23F
0005435007329	5459	128	23E
0005435007102	12967	1	1A
0005435040043	12967	2	1C
0005435040177	12967	3	1D
0005434229670	12967	4	2A
0005435040002	12967	5	1F
0005435007005	12967	6	2C
0005435007156	12967	7	2D
0005435039969	12967	8	2F
0005434229669	12967	9	3C
0005435040300	12967	10	3A
0005434229665	12967	11	3D
0005435040219	12967	12	3F
0005435039972	12967	13	4A
0005435007017	12967	14	4B
0005435040073	12967	15	4C
0005432304451	12967	16	4E
0005435040123	12967	17	4D
0005435039888	12967	18	5A
0005435007143	12967	19	4F
0005435039858	12967	20	5C
0005434229668	12967	21	5B
0005434229680	12967	22	5D
0005434229682	12967	23	5E
0005435040056	12967	24	5F
0005435040166	12967	25	6B
0005435040122	12967	26	6A
0005435007170	12967	27	6C
0005435040318	12967	28	6D
0005435007130	12967	29	6E
0005435040137	12967	30	6F
0005435040344	12967	31	7A
0005435007168	12967	32	7C
0005434229662	12967	33	7B
0005435007205	12967	34	7D
0005435040280	12967	35	7F
0005434229666	12967	36	7E
0005435040200	12967	37	8A
0005435040212	12967	38	8B
0005435007137	12967	39	8C
0005432304448	12967	40	8E
0005435040419	12967	41	8D
0005435040319	12967	42	8F
0005435042866	12967	43	9A
0005435040103	12967	44	9D
0005435039829	12967	45	9C
0005434229675	12967	46	9E
0005432304450	12967	47	9F
0005435039825	12967	48	10B
0005435040119	12967	49	10C
0005435040044	12967	50	10E
0005435007259	12967	51	10D
0005435042867	12967	52	11A
0005434229671	12967	53	11C
0005435040036	12967	54	11B
0005434229677	12967	55	11E
0005435040261	12967	56	11D
0005435040158	12967	57	11F
0005435007096	12967	58	12A
0005435007062	12967	59	12C
0005435040184	12967	60	12B
0005435040072	12967	61	12E
0005435040118	12967	62	12D
0005435040136	12967	63	13A
0005435042858	12967	64	12F
0005435039826	12967	65	13B
0005435040281	12967	66	13D
0005435040243	12967	67	13C
0005435040279	12967	68	13E
0005435039958	12967	69	13F
0005435007131	12967	70	14B
0005435040132	12967	71	14A
0005435039698	12967	72	14C
0005435040139	12967	73	14D
0005435040174	12967	74	14E
0005434229681	12967	75	14F
0005434229661	12967	76	15B
0005435040165	12967	77	15A
0005435040138	12967	78	15C
0005434229664	12967	79	15D
0005435040262	12967	80	15F
0005435007109	12967	81	15E
0005435040192	12967	82	16B
0005432304449	12967	83	16A
0005435007095	12967	84	16C
0005434229676	12967	85	16D
0005435040218	12967	86	16E
0005435040199	12967	87	17A
0005435039820	12967	88	16F
0005434229660	12967	89	17B
0005435039953	12967	90	17C
0005435039988	12967	91	17E
0005435039945	12967	92	17D
0005435040182	12967	93	18A
0005435007169	12967	94	17F
0005434229663	12967	95	18B
0005435040252	12967	96	18D
0005435039889	12967	97	18C
0005435040201	12967	98	18F
0005435039981	12967	99	18E
0005434229678	12967	100	19A
0005435040253	12967	101	19B
0005435007132	12967	102	19D
0005434229667	12967	103	19E
0005435007094	12967	104	19F
0005435040260	12967	105	20A
0005435040211	12967	106	20B
0005435039565	12967	107	20C
0005434229673	12967	108	20E
0005435040224	12967	109	20D
0005435039957	12967	110	20F
0005434229672	12967	111	21A
0005434229679	12967	112	21C
0005434229674	12967	113	21B
0005435007157	12967	114	21D
0005435040097	12967	115	21E
0005435040121	12967	116	22A
0005435039946	12967	117	21F
0005435007155	12967	118	22B
0005435040003	12967	119	22C
0005435007171	12967	120	22D
0005435040301	12967	121	22F
0005435040188	12967	122	22E
0005435040294	12967	123	23A
0005435007154	12967	124	23B
0005435040042	12967	125	23C
0005435007016	12967	126	23D
0005435042864	12967	127	23F
0005435040183	12967	128	23E
0005435902718	14892	1	1C
0005435902704	14892	2	1D
0005434426964	14892	3	2D
0005434411832	14892	4	2F
0005434426976	14892	5	3A
0005434411831	14892	6	3C
0005435554203	14892	7	3F
0005434426984	14892	8	4A
0005434426981	14892	9	4D
0005434426987	14892	10	4E
0005434426974	14892	11	4F
0005434426983	14892	12	5C
0005434426980	14892	13	5E
0005435902751	14892	14	6A
0005435902837	14892	15	7E
0005435902703	14892	16	7F
0005434426960	14892	17	8D
0005435902717	14892	18	8E
0005434426979	14892	19	8F
0005434426966	14892	20	9A
0005435902702	14892	21	9C
0005432188650	14892	22	9E
0005434426986	14892	23	10A
0005434426970	14892	24	10D
0005435902836	14892	25	10F
0005434411830	14892	26	11D
0005435902778	14892	27	11E
0005434426978	14892	28	12C
0005434426963	14892	29	12E
0005434426973	14892	30	12F
0005434426971	14892	31	13A
0005434426969	14892	32	13D
0005434411833	14892	33	14A
0005434426962	14892	34	14C
0005434426985	14892	35	14E
0005434426975	14892	36	14F
0005435902727	14892	37	15A
0005434426988	14892	38	16A
0005435902792	14892	39	16C
0005434426961	14892	40	16D
0005435902793	14892	41	17C
0005435902830	14892	42	17D
0005435554213	14892	43	17E
0005435902767	14892	44	17F
0005434426972	14892	45	18A
0005432188648	14892	46	18C
0005434426977	14892	47	18F
0005432188649	14892	48	19A
0005434426982	14892	49	19C
0005434426968	14892	50	19D
0005435902719	14892	51	19E
0005435902787	14892	52	19F
0005434426967	14892	53	20A
0005434426965	14892	54	20D
0005434411798	20187	1	1C
0005435554253	20187	2	1A
0005434426954	20187	3	1D
0005434426847	20187	4	1F
0005434426736	20187	5	2A
0005434426762	20187	6	2C
0005434426790	20187	7	2D
0005435554255	20187	8	3A
0005435902932	20187	9	3C
0005434426821	20187	10	3D
0005435902940	20187	11	3F
0005434426822	20187	12	4C
0005432059530	20187	13	4D
0005435902935	20187	14	4E
0005434426709	20187	15	5A
0005434426786	20187	16	5C
0005434426780	20187	17	5D
0005434426743	20187	18	5E
0005434411790	20187	19	5F
0005435902938	20187	20	6A
0005434426823	20187	21	6C
0005434411793	20187	22	6E
0005434426611	20187	23	6D
0005435554252	20187	24	6F
0005434426744	20187	25	7A
0005435554254	20187	26	7E
0005435902934	20187	27	7F
0005434411799	20187	28	8A
0005434426781	20187	29	8C
0005435902944	20187	30	8D
0005435902948	20187	31	8E
0005435554251	20187	32	8F
0005434411783	20187	33	9A
0005435902936	20187	34	9C
0005434426711	20187	35	9E
0005434426731	20187	36	9F
0005435902933	20187	37	10A
0005435902943	20187	38	10D
0005435902945	20187	39	10E
0005434426754	20187	40	10F
0005434426750	20187	41	12C
0005434426598	20187	42	12D
0005434411791	20187	43	12F
0005434411797	20187	44	13A
0005434426792	20187	45	13D
0005435902941	20187	46	14E
0005435902939	20187	47	14F
0005434426682	20187	48	15C
0005434426732	20187	49	15F
0005434426955	20187	50	16A
0005432059531	20187	51	16C
0005435902949	20187	52	16D
0005434426683	20187	53	16E
0005434426766	20187	54	16F
0005434426749	20187	55	17C
0005434426956	20187	56	17D
0005434411795	20187	57	17F
0005434426818	20187	58	18A
0005434426720	20187	59	18C
0005435902942	20187	60	18D
0005434411778	20187	61	18E
0005435902946	20187	62	19A
0005435902947	20187	63	19C
0005434426791	20187	64	19D
0005435902937	20187	65	19E
0005434426684	20187	66	19F
0005434426846	20187	67	20C
0005434426755	20187	68	20E
0005434426735	20187	69	20F
0005434523792	28006	1	3C
0005432462542	28006	2	5E
0005432462541	28006	3	6A
0005432462539	28006	4	8C
0005432462538	28006	5	9F
0005432462543	28006	6	12C
0005434523778	28006	7	13F
0005434523782	28006	8	16B
0005432462540	28006	9	16F
0005435982876	26532	1	1A
0005435982873	26532	2	1C
0005434270222	26532	3	1F
0005435982852	26532	4	2C
0005435982893	26532	5	2F
0005435982885	26532	6	3A
0005435982851	26532	7	3C
0005432300336	26532	8	3D
0005435982883	26532	9	4A
0005433434749	26532	10	4C
0005435982846	26532	11	4D
0005435982856	26532	12	4E
0005435982868	26532	13	5A
0005435982865	26532	14	5C
0005433434729	26532	15	5D
0005435982854	26532	16	5E
0005435982874	26532	17	5F
0005435982877	26532	18	6C
0005435982892	26532	19	6D
0005433434821	26532	20	6E
0005433434834	26532	21	7A
0005435982857	26532	22	7C
0005433434751	26532	23	7D
0005432300335	26532	24	7E
0005433434883	26532	25	7F
0005433434778	26532	26	8A
0005433434920	26532	27	8C
0005433434750	26532	28	8D
0005435982884	26532	29	8F
0005435982855	26532	30	8E
0005435982888	26532	31	9A
0005433434624	26532	32	9C
0005435982869	26532	33	9D
0005435982845	26532	34	9E
0005433434775	26532	35	9F
0005435982870	26532	36	10A
0005435982861	26532	37	10C
0005433434884	26532	38	10D
0005435982862	26532	39	10E
0005435982859	26532	40	10F
0005433434690	26532	41	11A
0005435982867	26532	42	11C
0005435982872	26532	43	11D
0005433434791	26532	44	11E
0005435982866	26532	45	11F
0005435982887	26532	46	12A
0005432300338	26532	47	12C
0005433434728	26532	48	12D
0005433434792	26532	49	12E
0005433434921	26532	50	12F
0005435982848	26532	51	13A
0005433434773	26532	52	13C
0005432300334	26532	53	13D
0005435982880	26532	54	13E
0005435982879	26532	55	13F
0005435982863	26532	56	14C
0005435982858	26532	57	14E
0005435982849	26532	58	14F
0005433434777	26532	59	15A
0005435982878	26532	60	15C
0005433434771	26532	61	15D
0005435982890	26532	62	15F
0005435982860	26532	63	16A
0005435982889	26532	64	16D
0005435982881	26532	65	16E
0005435982864	26532	66	16F
0005435982850	26532	67	17A
0005433434756	26532	68	17C
0005435982844	26532	69	17D
0005433434702	26532	70	17E
0005433434772	26532	71	17F
0005435982847	26532	72	18A
0005433434779	26532	73	18C
0005432300333	26532	74	18D
0005433434823	26532	75	18E
0005433434782	26532	76	18F
0005435982853	26532	77	19A
0005435982871	26532	78	19C
0005435982882	26532	79	19D
0005435982891	26532	80	19E
0005435982886	26532	81	19F
0005434270221	26532	82	20C
0005432300337	26532	83	20D
0005435982875	26532	84	20E
0005433434781	26532	85	20F
0005433435043	26699	1	8A
0005433435049	26699	2	1A
0005433435055	26699	3	1D
0005435982534	26699	4	1F
0005435982571	26699	5	2A
0005432051171	26699	6	2C
0005435982361	26699	7	2D
0005435982424	26699	8	3A
0005435982567	26699	9	3C
0005435982493	26699	10	3D
0005433435057	26699	11	4A
0005433435053	26699	12	4C
0005435982520	26699	13	4E
0005434269130	26699	14	4F
0005435982486	26699	15	5A
0005434270236	26699	16	5C
0005434271339	26699	17	5D
0005435982456	26699	18	5F
0005433435044	26699	19	6A
0005435982457	26699	20	6D
0005435982535	26699	21	6E
0005433435071	26699	22	6F
0005433435047	26699	23	7A
0005435982465	26699	24	7C
0005435982394	26699	25	7D
0005433435069	26699	26	7E
0005433435050	26699	27	7F
0005433435056	26699	28	8C
0005435982466	26699	29	8D
0005435982532	26699	30	8E
0005435982425	26699	31	8F
0005435982326	26699	32	9A
0005433435054	26699	33	9C
0005435982563	26699	34	9D
0005435982543	26699	35	9E
0005434270237	26699	36	10A
0005435982593	26699	37	10C
0005435982467	26699	38	10E
0005433435064	26699	39	10F
0005433435051	26699	40	11A
0005433435061	26699	41	11C
0005435982549	26699	42	11E
0005435982442	26699	43	11F
0005433435068	26699	44	12A
0005435982403	26699	45	12C
0005435982324	26699	46	12D
0005435982487	26699	47	12E
0005435982533	26699	48	12F
0005435982435	26699	49	13C
0005435982557	26699	50	13D
0005435982464	26699	51	13E
0005433435048	26699	52	13F
0005435982565	26699	53	14A
0005435982564	26699	54	14C
0005435982494	26699	55	14E
0005434271340	26699	56	14F
0005433435045	26699	57	15A
0005435982332	26699	58	15C
0005434270235	26699	59	15D
0005434269131	26699	60	15E
0005433435062	26699	61	15F
0005433435066	26699	62	16A
0005433435059	26699	63	16C
0005435982294	26699	64	16D
0005435982166	26699	65	16E
0005435982568	26699	66	16F
0005433435065	26699	67	17A
0005435982598	26699	68	17C
0005432051170	26699	69	17D
0005433435063	26699	70	17E
0005435982485	26699	71	18A
0005433435060	26699	72	18C
0005432051169	26699	73	18D
0005435982293	26699	74	18F
0005433435067	26699	75	19A
0005435982360	26699	76	19C
0005433435052	26699	77	19D
0005433435070	26699	78	19E
0005433435046	26699	79	19F
0005435982578	26699	80	20C
0005433435058	26699	81	20E
0005433689932	29261	1	6A
0005433689923	29261	2	6B
0005433686643	29261	3	6D
0005433689919	29261	4	18A
0005433686633	29261	5	18C
0005433686634	29261	6	19A
0005433686636	29261	7	19B
0005433689920	29261	8	1A
0005433686645	29261	9	20B
0005433689931	29261	10	22A
0005433689933	29261	11	2B
0005433686635	29261	12	1C
0005433686638	29261	13	2C
0005433689921	29261	14	2A
0005433686637	29261	15	5A
0005433686646	29261	16	5B
0005433686644	29261	17	5D
0005432584362	3132	1	6C
0005432584373	3132	2	7A
0005432584365	3132	3	7C
0005432584381	3132	4	7D
0005432584379	3132	5	18C
0005432584364	3132	6	18D
0005432584358	3132	7	19A
0005432858161	3132	8	19B
0005432584361	3132	9	19C
0005432584359	3132	10	19D
0005432584371	3132	11	20A
0005432858183	3132	12	20D
0005432584374	3132	13	21A
0005432584363	3132	14	21B
0005432216310	3132	15	21C
0005432858074	3132	16	21D
0005432584357	3132	17	22A
0005432216309	3132	18	22B
0005432584372	3132	19	22C
0005432858125	3132	20	23B
0005432216311	3132	21	6D
0005432584369	3132	22	1B
0005432584368	3132	23	1C
0005432584375	3132	24	1D
0005432584376	3132	25	2C
0005432584378	3132	26	2D
0005432584367	3132	27	3A
0005432858090	3132	28	3C
0005432584360	3132	29	3D
0005432216308	3132	30	4A
0005432584377	3132	31	4C
0005432858123	3132	32	5A
0005432858132	3132	33	5B
0005432858182	3132	34	5C
0005432584380	3132	35	5D
0005432584366	3132	36	6A
0005432584370	3132	37	6B
0005432584124	31514	1	1A
0005432858228	31514	2	1B
0005432584243	31514	3	1C
0005432584042	31514	4	1D
0005432584212	31514	5	2A
0005432584195	31514	6	2B
0005432584168	31514	7	3B
0005432584113	31514	8	3D
0005432584277	31514	9	4A
0005432584276	31514	10	4B
0005432858224	31514	11	4D
0005432858229	31514	12	5A
0005432584126	31514	13	5B
0005432858223	31514	14	5C
0005432584220	31514	15	6A
0005432584211	31514	16	6C
0005432584108	31514	17	6D
0005432584183	31514	18	7C
0005432858226	31514	19	7B
0005432858233	31514	20	7D
0005432584041	31514	21	18A
0005432858225	31514	22	18B
0005432858222	31514	23	18C
0005432584184	31514	24	18D
0005432584221	31514	25	19A
0005432584214	31514	26	19B
0005432858230	31514	27	19C
0005432584125	31514	28	19D
0005432584127	31514	29	20B
0005432858232	31514	30	20C
0005432584242	31514	31	20D
0005432858234	31514	32	21A
0005432584209	31514	33	21D
0005432858227	31514	34	22A
0005432858231	31514	35	22D
0005434943472	905	1	23A
0005434943474	905	2	1A
0005434943477	905	3	2A
0005434943471	905	4	2B
0005433255152	905	5	3D
0005434943469	905	6	4B
0005433255134	905	7	4D
0005433255161	905	8	5D
0005433255160	905	9	6C
0005433255147	905	10	18A
0005434943478	905	11	18D
0005434943475	905	12	19B
0005433255151	905	13	21B
0005434943476	905	14	21D
0005434943470	905	15	22A
0005433255162	905	16	22C
0005434943473	905	17	22D
0005433255190	16244	1	1A
0005434943405	16244	2	22C
0005433255191	16244	3	2B
0005434943439	16244	4	2C
0005433255189	16244	5	3C
0005433255193	16244	6	21B
0005434943374	16244	7	18B
0005433255192	16244	8	7B
0005434943392	16244	9	4D
0005434943429	16244	10	21D
0005434943385	16244	11	4B
0005433927517	14378	1	6A
0005433811643	14378	2	1A
0005433811634	14378	3	6B
0005433811638	14378	4	3A
0005433367906	21762	1	4F
0005433367838	21762	2	5A
0005433368129	21762	3	5C
0005433368038	21762	4	5D
0005435653595	21762	5	5F
0005433368240	21762	6	5E
0005433368054	21762	7	6A
0005433367976	21762	8	6C
0005433367973	21762	9	7C
0005435653604	21762	10	7A
0005433368104	21762	11	7D
0005433368100	21762	12	8C
0005433368188	21762	13	8D
0005433368187	21762	14	8E
0005433368062	21762	15	8F
0005433367866	21762	16	9A
0005433368071	21762	17	9C
0005435653610	21762	18	9D
0005433368050	21762	19	9E
0005435653608	21762	20	9F
0005433368139	21762	21	10A
0005435653599	21762	22	10D
0005433368072	21762	23	10E
0005433367931	21762	24	10F
0005433368021	21762	25	11E
0005433368033	21762	26	11F
0005435653600	21762	27	12C
0005433367930	21762	28	12D
0005433367978	21762	29	12E
0005433367953	21762	30	13A
0005433368035	21762	31	13C
0005433367979	21762	32	13D
0005433368039	21762	33	13E
0005433368134	21762	34	13F
0005433367937	21762	35	14E
0005433368125	21762	36	14F
0005433367936	21762	37	15A
0005433367991	21762	38	15D
0005433368029	21762	39	15E
0005435653607	21762	40	15F
0005433367975	21762	41	16A
0005435653601	21762	42	16C
0005435653593	21762	43	16E
0005433368044	21762	44	16F
0005433368137	21762	45	17A
0005435653594	21762	46	17C
0005433368106	21762	47	17D
0005435653609	21762	48	17E
0005433368108	21762	49	17F
0005435653605	21762	50	18C
0005433367929	21762	51	18D
0005433368107	21762	52	18E
0005433368239	21762	53	18F
0005433368051	21762	54	19A
0005433368150	21762	55	19D
0005433368099	21762	56	19E
0005433368138	21762	57	19F
0005433367884	21762	58	20A
0005433368101	21762	59	20C
0005435653598	21762	60	20D
0005433368102	21762	61	20E
0005435653596	21762	62	20F
0005433368078	21762	63	18A
0005435653597	21762	64	1A
0005435653606	21762	65	1C
0005435653603	21762	66	1F
0005435653602	21762	67	2A
0005433367911	21762	68	2C
0005433367987	21762	69	2D
0005433368037	21762	70	2F
0005433367952	21762	71	3A
0005433368027	21762	72	3C
0005433368045	21762	73	3D
0005433368032	21762	74	3F
0005433368079	21762	75	4A
0005433367912	21762	76	4C
0005433368151	21762	77	4E
0005433805823	9347	1	23G
0005433785438	9347	2	17H
0005432665302	9347	3	18H
0005433763393	9347	4	13G
0005434273088	9347	5	24A
0005434171115	9347	6	15E
0005432667481	9347	7	27H
0005433785436	9347	8	27A
0005433763399	9347	9	4C
0005434171079	9347	10	12F
0005433763392	9347	11	4H
0005434270219	9347	12	31H
0005433763396	9347	13	32E
0005433785430	9347	14	37D
0005433805845	9347	15	14E
0005433805843	9347	16	37E
0005434171080	9347	17	20G
0005433785431	9347	18	20A
0005434171102	9347	19	30B
0005433785428	9347	20	18D
0005433763406	9347	21	36H
0005433785433	9347	22	3C
0005434151722	9347	23	2F
0005433763398	9347	24	5B
0005433805844	9347	25	17G
0005433785435	9347	26	11E
0005433763395	9347	27	9A
0005433785440	9347	28	14F
0005433805835	9347	29	34E
0005433785419	9347	30	30F
0005433785447	9347	31	18B
0005433805834	9347	32	39D
0005433785418	9347	33	36B
0005433805831	9347	34	37G
0005433805839	9347	35	14B
0005433805826	9347	36	24D
0005433785448	9347	37	23D
0005433763400	9347	38	33E
0005433805837	9347	39	21B
0005433785414	9347	40	22F
0005433805833	9347	41	23F
0005433785426	9347	42	28G
0005434171158	9347	43	16B
0005433785441	9347	44	32A
0005432667482	9347	45	1A
0005433785413	9347	46	25E
0005434151721	9347	47	33G
0005433785412	9347	48	34D
0005433805832	9347	49	35A
0005433805840	9347	50	37A
0005434171159	9347	51	14A
0005433785421	9347	52	3B
0005433805827	9347	53	24B
0005433785424	9347	54	22A
0005433785429	9347	55	36G
0005433785446	9347	56	27B
0005433785432	9347	57	1G
0005433785443	9347	58	4B
0005433785427	9347	59	14G
0005433785425	9347	60	29H
0005433785422	9347	61	36A
0005433805824	9347	62	35H
0005433763397	9347	63	22B
0005433805830	9347	64	31B
0005433805846	9347	65	3A
0005433785437	9347	66	38H
0005433763402	9347	67	15A
0005432657490	9347	68	29A
0005433805828	9347	69	30A
0005433785420	9347	70	35E
0005434171150	9347	71	30G
0005433785444	9347	72	5C
0005433805829	9347	73	30D
0005433763401	9347	74	21H
0005434171114	9347	75	3H
0005433763404	9347	76	36E
0005434171075	9347	77	22G
0005433763394	9347	78	2G
0005433805838	9347	79	11H
0005433785417	9347	80	38F
0005433785415	9347	81	39F
0005433785434	9347	82	16D
0005432657491	9347	83	17F
0005433805825	9347	84	38B
0005434171151	9347	85	20D
0005433763405	9347	86	34H
0005434171149	9347	87	9B
0005433785439	9347	88	21E
0005433805836	9347	89	30E
0005433805841	9347	90	12D
0005433785445	9347	91	11F
0005433763403	9347	92	19H
0005433785416	9347	93	34B
0005433805842	9347	94	24F
0005434171168	9347	95	31G
0005433785411	9347	96	25F
0005432666416	9347	97	13F
0005432667480	9347	98	11G
0005433785442	9347	99	21G
0005432666415	9347	100	31A
0005433785423	9347	101	9H
0005434151743	26251	1	29D
0005433763272	26251	2	29B
0005434151742	26251	3	29E
0005433785254	26251	4	29F
0005433763308	26251	5	30B
0005433785010	26251	6	30A
0005435269865	26251	7	30F
0005433763248	26251	8	30E
0005433805562	26251	9	30G
0005433805547	26251	10	30H
0005432659720	26251	11	31A
0005433784982	26251	12	31F
0005435269857	26251	13	32D
0005433785205	26251	14	32E
0005434171247	26251	15	32G
0005433805455	26251	16	33D
0005433785189	26251	17	33B
0005435269864	26251	18	33F
0005433805497	26251	19	33H
0005432666392	26251	20	33G
0005433785015	26251	21	34A
0005432666385	26251	22	34B
0005433785206	26251	23	34E
0005433805551	26251	24	35D
0005433785237	26251	25	35F
0005433763282	26251	26	35E
0005435269860	26251	27	35G
0005434171240	26251	28	35H
0005433785197	26251	29	36B
0005434270233	26251	30	36D
0005433805622	26251	31	36F
0005433785040	26251	32	36E
0005433785078	26251	33	36H
0005433805434	26251	34	37B
0005432666393	26251	35	37F
0005433805449	26251	36	37E
0005434171238	26251	37	37H
0005433805542	26251	38	37G
0005435269867	26251	39	38A
0005433785180	26251	40	38D
0005433805563	26251	41	38H
0005433785068	26251	42	39E
0005433785153	26251	43	39D
0005433805669	26251	44	39F
0005433805559	26251	45	34D
0005434171239	26251	46	1B
0005433784784	26251	47	1G
0005432666397	26251	48	1H
0005433805463	26251	49	2B
0005433805501	26251	50	2G
0005434171246	26251	51	3A
0005432659714	26251	52	2H
0005433805532	26251	53	3C
0005434171244	26251	54	3F
0005433763294	26251	55	3G
0005432663051	26251	56	4A
0005433785165	26251	57	3H
0005435269859	26251	58	4F
0005434171245	26251	59	4C
0005434271338	26251	60	5A
0005432659721	26251	61	4H
0005433805531	26251	62	5G
0005433805528	26251	63	9A
0005433763295	26251	64	5H
0005433785137	26251	65	9H
0005432657454	26251	66	11B
0005433763273	26251	67	11D
0005434171243	26251	68	11F
0005434171252	26251	69	11H
0005433763265	26251	70	12A
0005434171251	26251	71	12B
0005433785013	26251	72	12E
0005433763225	26251	73	12F
0005435269861	26251	74	13D
0005433805604	26251	75	13B
0005433785221	26251	76	13E
0005434171248	26251	77	14B
0005433785252	26251	78	14F
0005433785186	26251	79	14H
0005433785022	26251	80	15D
0005433785122	26251	81	15F
0005434151741	26251	82	15H
0005433805435	26251	83	15G
0005434269129	26251	84	16A
0005435269855	26251	85	16D
0005433785204	26251	86	16H
0005433805421	26251	87	17B
0005434171249	26251	88	17D
0005432659713	26251	89	17G
0005433805607	26251	90	18A
0005433763226	26251	91	17H
0005433785207	26251	92	18D
0005433785253	26251	93	18B
0005435269858	26251	94	18E
0005433785076	26251	95	18F
0005433785039	26251	96	18H
0005433805523	26251	97	19F
0005434270231	26251	98	19G
0005434171237	26251	99	20A
0005433785107	26251	100	20G
0005433805606	26251	101	20F
0005434270232	26251	102	21A
0005435269863	26251	103	20H
0005432657466	26251	104	21D
0005433785154	26251	105	21E
0005433805444	26251	106	21F
0005433763309	26251	107	21G
0005434171250	26251	108	22D
0005433785168	26251	109	22G
0005435269856	26251	110	22F
0005433805508	26251	111	22H
0005432666398	26251	112	23B
0005433785093	26251	113	23D
0005435269866	26251	114	23F
0005434171242	26251	115	23G
0005433784783	26251	116	23H
0005434271337	26251	117	24B
0005433763270	26251	118	24E
0005433785257	26251	119	24D
0005433805605	26251	120	24F
0005433805445	26251	121	25D
0005433805566	26251	122	25E
0005433805524	26251	123	27B
0005434171241	26251	124	27F
0005432657453	26251	125	27G
0005433805516	26251	126	28A
0005434270234	26251	127	28E
0005435269862	26251	128	28F
0005433763269	26251	129	28H
0005435269868	26251	130	29A
0005435929654	4897	1	1B
0005435135734	4897	2	3B
0005435929655	4897	3	3C
0005435929664	4897	4	4B
0005435135737	4897	5	4C
0005435929653	4897	6	5B
0005435929656	4897	7	6B
0005435135736	4897	8	6C
0005435929663	4897	9	6D
0005435135733	4897	10	18B
0005435135735	4897	11	19A
0005435135683	33013	1	1C
0005435929680	33013	2	2A
0005435929679	33013	3	3A
0005435135690	33013	4	3B
0005435135682	33013	5	5D
0005435929678	33013	6	20D
0005435135711	33013	7	22D
0005434983357	9512	1	1A
0005434983354	9512	2	2A
0005434983359	9512	3	3C
0005434983358	9512	4	5B
0005434217985	9512	5	6B
0005434217984	9512	6	6D
0005434218001	9512	7	7D
0005434983353	9512	8	18D
0005434217991	9512	9	20B
0005434983356	9512	10	22C
0005434983355	9512	11	23A
0005434218025	27379	1	2B
0005434983309	27379	2	3A
0005434218021	27379	3	4A
0005434983308	27379	4	4B
0005434218022	27379	5	5B
0005434983310	27379	6	5C
0005434218024	27379	7	18C
0005434218026	27379	8	19D
0005434218027	27379	9	20A
0005434218023	27379	10	20B
0005433960895	24277	1	17B
0005433961021	24277	2	1A
0005433986018	24277	3	1B
0005433960872	24277	4	2A
0005433985908	24277	5	1H
0005433986036	24277	6	2H
0005433986111	24277	7	3B
0005433960729	24277	8	4B
0005433986038	24277	9	4A
0005433961036	24277	10	4C
0005433960988	24277	11	4G
0005433986042	24277	12	4F
0005433986291	24277	13	5A
0005433985967	24277	14	5F
0005433986211	24277	15	5H
0005433961164	24277	16	9B
0005433960960	24277	17	9A
0005433961118	24277	18	9H
0005433985964	24277	19	9G
0005433960942	24277	20	11D
0005433960887	24277	21	11B
0005433960929	24277	22	11F
0005433986100	24277	23	11H
0005433961048	24277	24	11G
0005433986084	24277	25	12A
0005433961047	24277	26	12E
0005433986337	24277	27	12D
0005433986212	24277	28	12G
0005433961001	24277	29	13B
0005433986263	24277	30	13E
0005433986171	24277	31	13G
0005433961032	24277	32	13H
0005433986185	24277	33	14B
0005433986228	24277	34	14E
0005433961117	24277	35	14F
0005433986213	24277	36	14H
0005433961161	24277	37	15D
0005433986085	24277	38	15B
0005433986081	24277	39	15G
0005433986122	24277	40	15E
0005433986145	24277	41	15H
0005433961035	24277	42	16D
0005433986240	24277	43	16B
0005433986035	24277	44	16G
0005433961162	24277	45	16F
0005433961052	24277	46	17A
0005433986017	24277	47	17F
0005433985981	24277	48	18E
0005433986180	24277	49	18H
0005433985909	24277	50	19B
0005433960927	24277	51	19E
0005433961010	24277	52	19F
0005433986198	24277	53	19H
0005433961108	24277	54	20B
0005433960832	24277	55	20G
0005433961143	24277	56	21B
0005433960825	24277	57	21F
0005433961155	24277	58	22A
0005433960781	24277	59	22B
0005433961146	24277	60	22E
0005433960928	24277	61	22F
0005433960970	24277	62	22H
0005433960728	24277	63	23B
0005433961000	24277	64	23E
0005433986250	24277	65	23G
0005433960917	24277	66	24A
0005433985913	24277	67	23H
0005433986069	24277	68	24B
0005433961038	24277	69	24D
0005433961037	24277	70	24F
0005433986248	24277	71	24E
0005433986230	24277	72	24G
0005433960919	24277	73	25D
0005433985797	24277	74	24H
0005433960943	24277	75	25E
0005433986043	24277	76	27D
0005433960918	24277	77	27F
0005433986032	24277	78	27E
0005433986191	24277	79	28E
0005433986127	24277	80	28H
0005433961053	24277	81	28G
0005433986187	24277	82	29B
0005433961102	24277	83	29E
0005433960999	24277	84	29F
0005433986237	24277	85	30A
0005433961182	24277	86	30D
0005433961173	24277	87	30F
0005433985903	24277	88	30G
0005433961070	24277	89	30H
0005433960916	24277	90	31B
0005433960980	24277	91	31F
0005433986247	24277	92	32D
0005433961014	24277	93	32B
0005433986210	24277	94	32E
0005433986094	24277	95	32H
0005433986186	24277	96	33D
0005433986197	24277	97	33B
0005433986226	24277	98	33E
0005433986249	24277	99	33G
0005433960941	24277	100	34A
0005433960959	24277	101	34D
0005433961157	24277	102	34F
0005433986170	24277	103	34E
0005433986205	24277	104	34G
0005433961174	24277	105	35B
0005433986051	24277	106	35D
0005433960967	24277	107	35G
0005433985904	24277	108	35F
0005433986188	24277	109	35H
0005433986227	24277	110	36F
0005433985963	24277	111	36E
0005433985914	24277	112	37A
0005433961022	24277	113	36H
0005433986099	24277	114	37B
0005433986385	24277	115	37G
0005433986238	24277	116	37F
0005433960961	24277	117	38B
0005433960989	24277	118	38A
0005433961124	24277	119	38D
0005433986083	24277	120	38E
0005433961156	24277	121	38F
0005433960870	24277	122	38H
0005433961006	24277	123	39E
0005433961172	24277	124	39F
0005433961551	25946	1	1A
0005433986516	25946	2	1B
0005433986508	25946	3	1G
0005433986532	25946	4	2F
0005433961582	25946	5	2H
0005433986547	25946	6	3C
0005433986531	25946	7	3G
0005433986545	25946	8	3F
0005433961536	25946	9	3H
0005433986520	25946	10	4F
0005433961577	25946	11	5G
0005433986514	25946	12	9A
0005433986506	25946	13	5H
0005433961586	25946	14	9B
0005433961575	25946	15	12E
0005433986509	25946	16	12H
0005433961563	25946	17	13D
0005433961569	25946	18	13B
0005433961554	25946	19	13E
0005433986542	25946	20	13G
0005433986510	25946	21	13F
0005433986519	25946	22	14D
0005433986528	25946	23	14F
0005433961580	25946	24	14G
0005433961540	25946	25	15D
0005433986533	25946	26	15H
0005433961564	25946	27	16B
0005433986546	25946	28	16A
0005433961568	25946	29	17A
0005433961549	25946	30	18A
0005433961552	25946	31	18B
0005433961546	25946	32	18E
0005433986525	25946	33	18H
0005433986507	25946	34	19A
0005433961534	25946	35	19H
0005433986534	25946	36	20B
0005433986537	25946	37	20F
0005433986526	25946	38	20H
0005433961535	25946	39	20G
0005433961545	25946	40	21A
0005433986535	25946	41	21B
0005433961533	25946	42	21E
0005433986518	25946	43	21H
0005433986515	25946	44	22B
0005433961576	25946	45	22F
0005433961588	25946	46	22H
0005433986522	25946	47	23E
0005433961587	25946	48	23D
0005433961579	25946	49	23B
0005433961561	25946	50	23F
0005433961542	25946	51	23G
0005433961565	25946	52	24A
0005433961557	25946	53	24B
0005433986539	25946	54	24D
0005433961570	25946	55	24F
0005433986536	25946	56	24G
0005433986511	25946	57	25F
0005433961538	25946	58	27B
0005433986517	25946	59	27D
0005433986538	25946	60	27F
0005433961566	25946	61	27H
0005433961543	25946	62	28E
0005433986512	25946	63	28F
0005433961547	25946	64	29A
0005433961532	25946	65	29E
0005433961578	25946	66	29H
0005433961550	25946	67	30B
0005433961574	25946	68	30A
0005433961571	25946	69	30F
0005433961556	25946	70	30E
0005433961560	25946	71	30G
0005433961581	25946	72	30H
0005433961590	25946	73	31B
0005433986530	25946	74	31A
0005433961559	25946	75	31D
0005433986521	25946	76	31G
0005433961544	25946	77	32A
0005433986524	25946	78	33F
0005433961572	25946	79	33H
0005433961589	25946	80	34D
0005433986527	25946	81	34F
0005433961562	25946	82	34G
0005433961541	25946	83	34H
0005433961584	25946	84	35A
0005433986540	25946	85	35D
0005433961537	25946	86	35B
0005433961585	25946	87	35H
0005433961583	25946	88	36B
0005433961558	25946	89	36D
0005433986529	25946	90	36F
0005433961553	25946	91	36E
0005433986543	25946	92	37A
0005433986544	25946	93	37B
0005433961567	25946	94	37G
0005433986523	25946	95	37F
0005433961573	25946	96	37H
0005433961591	25946	97	38D
0005433961539	25946	98	38B
0005433986513	25946	99	38G
0005433986541	25946	100	39E
0005433961548	25946	101	39D
0005433961555	25946	102	39F
0005433165940	972	1	1A
0005432269533	972	2	1B
0005433165929	972	3	1C
0005434480674	972	4	1D
0005434480675	972	5	2A
0005434480664	972	6	2B
0005434480667	972	7	2C
0005434480657	972	8	2D
0005434480663	972	9	3A
0005434480671	972	10	3B
0005434480660	972	11	3C
0005434480668	972	12	3D
0005434480673	972	13	4C
0005433165988	972	14	4D
0005434480669	972	15	5B
0005433165953	972	16	5C
0005434480661	972	17	5D
0005434480672	972	18	6A
0005434480655	972	19	6B
0005433165928	972	20	6C
0005434480676	972	21	7B
0005434480654	972	22	7C
0005433165999	972	23	7D
0005434480666	972	24	18A
0005434480659	972	25	18B
0005434480665	972	26	19A
0005434480656	972	27	19B
0005434480658	972	28	19C
0005433166012	972	29	20B
0005432269531	972	30	20D
0005433165960	972	31	20C
0005434480662	972	32	21B
0005433165961	972	33	21C
0005434480670	972	34	22C
0005432269532	972	35	22D
0005433165962	972	36	23A
0005433166079	16573	1	1B
0005434480506	16573	2	1C
0005434480507	16573	3	1D
0005434480475	16573	4	2A
0005433166074	16573	5	2B
0005433166077	16573	6	2C
0005434480447	16573	7	2D
0005434480554	16573	8	3A
0005434480495	16573	9	3B
0005433166078	16573	10	3C
0005434480398	16573	11	4A
0005433166073	16573	12	4B
0005433166082	16573	13	4C
0005434480444	16573	14	4D
0005434480443	16573	15	5B
0005434480617	16573	16	5C
0005433166072	16573	17	5D
0005434480431	16573	18	6A
0005434480469	16573	19	6B
0005434480439	16573	20	6C
0005434480508	16573	21	6D
0005434480616	16573	22	7A
0005434480372	16573	23	7C
0005434480445	16573	24	18A
0005434480474	16573	25	18B
0005433166075	16573	26	18C
0005434480365	16573	27	18D
0005433166076	16573	28	19A
0005434480477	16573	29	19D
0005433166081	16573	30	20B
0005434480420	16573	31	20C
0005434480505	16573	32	20D
0005434480494	16573	33	21A
0005434480476	16573	34	21C
0005433166071	16573	35	21D
0005434480553	16573	36	22C
0005433166080	16573	37	22D
0005434480427	16573	38	23A
0005434480430	16573	39	23B
0005433872532	3209	1	1A
0005433872531	3209	2	4A
0005433872527	3209	3	5B
0005433872528	3209	4	5C
0005433872533	3209	5	6C
0005433872530	3209	6	20B
0005433872529	3209	7	21A
0005433872496	32549	1	1C
0005433872501	32549	2	2D
0005433872492	32549	3	4A
0005433872493	32549	4	6B
0005433872502	32549	5	7A
0005435150202	10320	1	1A
0005433289861	10320	2	1B
0005433289853	10320	3	1C
0005435386604	10320	4	1D
0005435142744	10320	5	2A
0005435386617	10320	6	2B
0005435150196	10320	7	2C
0005433289892	10320	8	2D
0005435386580	10320	9	3B
0005435142738	10320	10	3C
0005433289860	10320	11	3D
0005435386603	10320	12	4A
0005435150194	10320	13	4C
0005435150204	10320	14	4D
0005433289846	10320	15	5B
0005435142745	10320	16	5C
0005435150201	10320	17	5D
0005435150205	10320	18	6B
0005435142740	10320	19	6A
0005435150203	10320	20	6C
0005435142742	10320	21	6D
0005435386602	10320	22	7A
0005435150199	10320	23	7B
0005435142750	10320	24	18A
0005435142748	10320	25	18C
0005435150198	10320	26	18D
0005435142746	10320	27	19A
0005433289864	10320	28	19B
0005435150197	10320	29	19D
0005435142749	10320	30	20A
0005435150193	10320	31	20B
0005435150206	10320	32	20C
0005435142739	10320	33	20D
0005435386621	10320	34	21A
0005435142747	10320	35	22A
0005435142743	10320	36	22C
0005435142741	10320	37	22D
0005435150200	10320	38	23A
0005435150195	10320	39	23B
0005433289953	21952	1	1B
0005435150066	21952	2	1C
0005435150064	21952	3	2A
0005435386652	21952	4	2B
0005435142607	21952	5	2C
0005435142634	21952	6	2D
0005435142576	21952	7	3B
0005435142633	21952	8	3C
0005435150067	21952	9	3D
0005435142662	21952	10	4A
0005435386656	21952	11	4B
0005435386653	21952	12	4C
0005433289948	21952	13	4D
0005435386655	21952	14	5A
0005435150055	21952	15	5B
0005433289950	21952	16	5C
0005435150030	21952	17	5D
0005435386651	21952	18	6A
0005435386658	21952	19	6B
0005435386657	21952	20	6C
0005435142661	21952	21	6D
0005435142575	21952	22	7A
0005435150041	21952	23	7B
0005435150063	21952	24	7C
0005435142627	21952	25	7D
0005435142689	21952	26	18A
0005435386654	21952	27	18B
0005435150040	21952	28	18C
0005435150143	21952	29	19A
0005435142623	21952	30	19B
0005435150105	21952	31	19D
0005435142608	21952	32	20A
0005433289951	21952	33	20B
0005435142658	21952	34	20C
0005435142635	21952	35	21A
0005435142688	21952	36	21C
0005433289952	21952	37	21D
0005433289949	21952	38	22A
0005435150103	21952	39	22B
0005435150104	21952	40	22C
0005435142655	21952	41	23A
0005435150126	21952	42	23B
0005435502327	11218	1	1A
0005434573528	11218	2	1C
0005435529434	11218	3	1F
0005435502443	11218	4	2A
0005435545767	11218	5	2C
0005435502337	11218	6	2D
0005435529390	11218	7	2F
0005434573526	11218	8	3A
0005434573531	11218	9	3C
0005435502465	11218	10	3D
0005435502333	11218	11	3F
0005435319648	11218	12	4C
0005434573520	11218	13	4D
0005435529301	11218	14	4E
0005435502473	11218	15	4F
0005434573530	11218	16	5A
0005434573521	11218	17	5C
0005435502334	11218	18	6A
0005435319614	11218	19	6D
0005435502472	11218	20	6E
0005435529433	11218	21	6F
0005435502380	11218	22	7A
0005435502453	11218	23	7D
0005435529313	11218	24	7F
0005435529314	11218	25	8A
0005435502456	11218	26	8C
0005435502468	11218	27	8D
0005435319610	11218	28	8E
0005435502421	11218	29	8F
0005435502351	11218	30	9A
0005435319602	11218	31	9D
0005435502506	11218	32	9E
0005435529404	11218	33	9F
0005435529370	11218	34	10C
0005434573527	11218	35	10E
0005434573532	11218	36	10F
0005435502350	11218	37	11A
0005435319613	11218	38	11D
0005435502457	11218	39	11E
0005435502466	11218	40	11F
0005435502507	11218	41	12A
0005434573523	11218	42	12C
0005435502493	11218	43	12D
0005434573522	11218	44	13A
0005435529399	11218	45	13C
0005435529403	11218	46	13D
0005435502336	11218	47	13E
0005435502379	11218	48	14C
0005434573529	11218	49	14D
0005435529372	11218	50	14E
0005435529338	11218	51	14F
0005435502492	11218	52	15A
0005434573525	11218	53	15C
0005435529401	11218	54	15E
0005435502458	11218	55	16A
0005435529371	11218	56	16E
0005435319647	11218	57	16F
0005435529331	11218	58	17C
0005435502439	11218	59	17D
0005434573534	11218	60	17E
0005434573533	11218	61	17F
0005435529353	11218	62	18F
0005435319568	11218	63	19A
0005435529491	11218	64	19C
0005435502392	11218	65	19D
0005435502440	11218	66	19E
0005435529402	11218	67	19F
0005434573524	11218	68	20A
0005435529412	11218	69	20C
0005435502391	11218	70	20D
0005435529349	11218	71	20E
0005435529411	11218	72	20F
0005435508498	20937	1	1A
0005435508499	20937	2	1C
0005434573367	20937	3	1F
0005435518138	20937	4	2A
0005435502584	20937	5	2C
0005434573363	20937	6	2D
0005435319697	20937	7	2F
0005435518146	20937	8	3A
0005435502587	20937	9	3C
0005435518140	20937	10	3F
0005435502586	20937	11	3D
0005435319703	20937	12	4A
0005435518156	20937	13	4C
0005434573378	20937	14	4D
0005435508493	20937	15	4E
0005435508506	20937	16	4F
0005434573405	20937	17	5A
0005435319701	20937	18	5C
0005435502575	20937	19	5D
0005434573377	20937	20	5E
0005434573355	20937	21	5F
0005435518152	20937	22	6A
0005435502590	20937	23	6D
0005432291961	20937	24	7A
0005435518141	20937	25	7C
0005435502582	20937	26	7D
0005435518139	20937	27	7E
0005434573415	20937	28	7F
0005435518155	20937	29	8A
0005435508494	20937	30	8C
0005435518145	20937	31	8D
0005435319705	20937	32	8E
0005435502580	20937	33	8F
0005435502581	20937	34	9C
0005435518150	20937	35	9D
0005435518149	20937	36	9F
0005435518142	20937	37	9E
0005435502591	20937	38	10A
0005434573434	20937	39	10C
0005435518151	20937	40	10D
0005434573398	20937	41	10E
0005435502583	20937	42	10F
0005435502594	20937	43	11A
0005434573406	20937	44	11C
0005435319698	20937	45	11D
0005435508502	20937	46	11E
0005435508496	20937	47	12A
0005434573448	20937	48	12C
0005435508503	20937	49	12D
0005434573423	20937	50	12E
0005435518153	20937	51	12F
0005435502589	20937	52	13A
0005435508495	20937	53	13C
0005435508500	20937	54	13D
0005435502577	20937	55	13E
0005435518147	20937	56	13F
0005435319704	20937	57	14A
0005432291960	20937	58	14C
0005435518157	20937	59	14D
0005435502576	20937	60	14E
0005434573407	20937	61	14F
0005434573402	20937	62	15A
0005435508497	20937	63	15C
0005435518143	20937	64	15D
0005435508508	20937	65	15E
0005434573403	20937	66	15F
0005435502592	20937	67	16A
0005435508504	20937	68	16C
0005435502588	20937	69	16D
0005435518148	20937	70	16E
0005434573356	20937	71	16F
0005434573390	20937	72	17A
0005435502595	20937	73	17C
0005435502574	20937	74	17D
0005435319702	20937	75	17E
0005435518137	20937	76	17F
0005435319700	20937	77	18A
0005435502579	20937	78	18C
0005435518136	20937	79	18E
0005435518144	20937	80	18F
0005435319699	20937	81	19A
0005435319696	20937	82	19C
0005435518154	20937	83	19D
0005435508505	20937	84	19E
0005435502585	20937	85	19F
0005435502578	20937	86	20A
0005435502593	20937	87	20C
0005435508501	20937	88	20D
0005435508507	20937	89	20E
0005434573388	20937	90	20F
0005432693228	2903	1	15A
0005432693283	2903	2	1C
0005432693254	2903	3	1F
0005432693239	2903	4	2A
0005432693339	2903	5	2D
0005432693198	2903	6	2F
0005432693017	2903	7	4A
0005432693200	2903	8	4C
0005432693255	2903	9	4F
0005432693075	2903	10	5A
0005432693145	2903	11	6D
0005432693055	2903	12	7C
0005432693240	2903	13	7F
0005432693124	2903	14	8A
0005432693201	2903	15	8E
0005432693282	2903	16	10A
0005432693064	2903	17	10F
0005432693337	2903	18	11F
0005432693071	2903	19	12D
0005432693197	2903	20	12E
0005432693162	2903	21	13A
0005432693016	2903	22	13C
0005432693059	2903	23	13D
0005432693184	2903	24	14A
0005432693193	2903	25	14F
0005432693199	2903	26	15E
0005432693125	2903	27	16A
0005432693325	2903	28	16E
0005432693174	2903	29	16F
0005432693119	2903	30	17A
0005432693120	2903	31	17E
0005432693146	2903	32	18E
0005432693290	2903	33	18F
0005432693056	2903	34	19D
0005432693227	2903	35	20A
0005432693336	2903	36	20D
0005432693126	2903	37	20F
0005433123991	2909	1	3C
0005432707097	2909	2	3A
0005433123996	2909	3	2F
0005433124012	2909	4	2D
0005432707115	2909	5	1C
0005432707118	2909	6	2A
0005432707098	2909	7	3F
0005432707110	2909	8	3D
0005432880834	2909	9	4C
0005432880880	2909	10	4D
0005432707109	2909	11	4E
0005433124063	2909	12	4F
0005432707101	2909	13	5C
0005432707119	2909	14	5D
0005432707117	2909	15	5E
0005432707111	2909	16	5F
0005432880849	2909	17	6A
0005432880929	2909	18	6C
0005432880885	2909	19	6D
0005432707094	2909	20	6E
0005432880928	2909	21	6F
0005433194871	2909	22	7C
0005432880873	2909	23	7D
0005432707107	2909	24	7F
0005432880851	2909	25	8C
0005432880881	2909	26	8D
0005432880853	2909	27	9D
0005432880835	2909	28	9E
0005432707106	2909	29	9F
0005433123990	2909	30	10A
0005432880850	2909	31	10C
0005432880909	2909	32	1D
0005432880884	2909	33	10D
0005433124002	2909	34	10E
0005432707103	2909	35	11A
0005432707099	2909	36	11C
0005432880888	2909	37	11D
0005433124064	2909	38	11F
0005432880854	2909	39	12A
0005433124013	2909	40	12C
0005432880920	2909	41	12D
0005433123871	2909	42	12E
0005432217813	2909	43	12F
0005432880879	2909	44	13A
0005432880887	2909	45	13C
0005433123940	2909	46	13F
0005432880919	2909	47	14A
0005433123954	2909	48	14C
0005433194887	2909	49	14D
0005433194872	2909	50	14E
0005432707116	2909	51	14F
0005432707102	2909	52	15D
0005432707108	2909	53	15E
0005432707120	2909	54	16C
0005432707095	2909	55	16D
0005432707096	2909	56	16E
0005432707121	2909	57	16F
0005433123955	2909	58	17C
0005432707114	2909	59	17D
0005432217814	2909	60	17E
0005433124001	2909	61	18C
0005432707100	2909	62	18F
0005432880876	2909	63	19C
0005432707104	2909	64	19E
0005432707105	2909	65	20A
0005433123924	2909	66	20C
0005433123941	2909	67	20D
0005432707112	2909	68	20E
0005432707113	2909	69	20F
0005432217812	2909	70	1A
0005432693494	30008	1	1A
0005432706798	30008	2	1C
0005432693475	30008	3	1F
0005432706910	30008	4	1D
0005432693486	30008	5	2A
0005433124200	30008	6	2C
0005432881014	30008	7	2D
0005432693481	30008	8	2F
0005433124179	30008	9	3A
0005432693476	30008	10	3C
0005432693491	30008	11	3D
0005432693483	30008	12	3F
0005432706874	30008	13	4A
0005432706944	30008	14	4C
0005432693474	30008	15	4D
0005432881010	30008	16	4E
0005433124181	30008	17	4F
0005432693496	30008	18	5A
0005432706933	30008	19	5C
0005433124191	30008	20	5D
0005433124196	30008	21	5E
0005432693489	30008	22	5F
0005433124187	30008	23	6A
0005433124195	30008	24	6C
0005432706967	30008	25	6D
0005432693478	30008	26	6E
0005432693493	30008	27	6F
0005433194896	30008	28	7A
0005432693488	30008	29	7C
0005432693495	30008	30	7D
0005432881015	30008	31	7E
0005433124194	30008	32	7F
0005432693504	30008	33	8A
0005433194895	30008	34	8C
0005432881012	30008	35	8D
0005433124182	30008	36	8E
0005432693480	30008	37	8F
0005433124185	30008	38	9A
0005432706890	30008	39	9C
0005432881011	30008	40	9D
0005433194893	30008	41	9E
0005433124192	30008	42	9F
0005432706889	30008	43	10A
0005432693505	30008	44	10C
0005432706882	30008	45	10D
0005433124197	30008	46	10E
0005432693479	30008	47	10F
0005432881007	30008	48	11A
0005432706873	30008	49	11C
0005432706913	30008	50	11D
0005432693499	30008	51	11E
0005432706902	30008	52	11F
0005433124184	30008	53	12A
0005432706917	30008	54	12C
0005433194894	30008	55	12D
0005432693500	30008	56	12E
0005433124180	30008	57	12F
0005432881006	30008	58	13A
0005432693498	30008	59	13C
0005433124193	30008	60	13D
0005433124198	30008	61	13E
0005432706881	30008	62	13F
0005432706901	30008	63	14A
0005433124178	30008	64	14C
0005433124183	30008	65	14D
0005432693484	30008	66	14E
0005432693485	30008	67	14F
0005432881009	30008	68	15A
0005433124186	30008	69	15C
0005432693492	30008	70	15D
0005432881008	30008	71	15E
0005432693490	30008	72	15F
0005432693501	30008	73	16A
0005432693487	30008	74	16C
0005432693502	30008	75	16D
0005432881002	30008	76	16E
0005432706896	30008	77	16F
0005433124199	30008	78	17A
0005432693482	30008	79	17C
0005432706872	30008	80	17D
0005432881004	30008	81	17E
0005432706960	30008	82	17F
0005432693477	30008	83	18A
0005432881013	30008	84	18C
0005433124188	30008	85	18E
0005433194897	30008	86	18F
0005433124201	30008	87	19A
0005432693497	30008	88	19C
0005432693503	30008	89	19D
0005433194892	30008	90	19E
0005432881003	30008	91	19F
0005432881005	30008	92	20C
0005432706914	30008	93	20A
0005432693506	30008	94	20D
0005433124190	30008	95	20E
0005433124189	30008	96	20F
0005434980171	23674	1	1B
0005434980170	23674	2	1D
0005434980149	23674	3	2A
0005434980157	23674	4	2C
0005434988879	23674	5	2B
0005434980155	23674	6	2D
0005434988882	23674	7	3A
0005434988874	23674	8	3B
0005434988873	23674	9	3C
0005434980174	23674	10	3D
0005434980161	23674	11	4A
0005434980158	23674	12	4B
0005434980166	23674	13	4C
0005434988878	23674	14	4D
0005434980164	23674	15	5A
0005434980172	23674	16	5B
0005434980151	23674	17	5C
0005434980153	23674	18	5D
0005434988883	23674	19	6A
0005434988881	23674	20	6B
0005434988875	23674	21	6C
0005434988877	23674	22	6D
0005434980168	23674	23	7A
0005434988876	23674	24	7B
0005434980173	23674	25	7C
0005434980156	23674	26	18B
0005434988872	23674	27	18C
0005434980147	23674	28	18D
0005434988871	23674	29	19A
0005434980154	23674	30	19B
0005434980165	23674	31	19C
0005434980169	23674	32	19D
0005434988880	23674	33	20A
0005434980148	23674	34	20B
0005434980145	23674	35	20C
0005434980146	23674	36	20D
0005434980152	23674	37	21A
0005434980160	23674	38	21C
0005434980144	23674	39	21B
0005434980163	23674	40	21D
0005434988885	23674	41	22A
0005434980150	23674	42	22B
0005434980162	23674	43	22C
0005434980159	23674	44	22D
0005434980167	23674	45	23A
0005434988884	23674	46	23B
0005434979948	27535	1	1A
0005434988737	27535	2	1C
0005434979990	27535	3	1D
0005434979810	27535	4	2A
0005434988762	27535	5	2B
0005434979881	27535	6	2C
0005434979809	27535	7	2D
0005434979880	27535	8	3A
0005434979967	27535	9	3B
0005434979840	27535	10	3C
0005434979777	27535	11	3D
0005434979903	27535	12	4A
0005434979979	27535	13	4B
0005434979776	27535	14	4C
0005434979976	27535	15	4D
0005434980044	27535	16	5A
0005434979838	27535	17	5B
0005434988763	27535	18	5C
0005434988757	27535	19	5D
0005434988729	27535	20	6A
0005434979989	27535	21	6B
0005434979953	27535	22	6C
0005434979854	27535	23	6D
0005434979835	27535	24	7A
0005434979988	27535	25	7B
0005434980004	27535	26	7C
0005434980080	27535	27	7D
0005434979908	27535	28	18A
0005434979952	27535	29	18B
0005434979980	27535	30	18C
0005434988746	27535	31	18D
0005434979958	27535	32	19A
0005434988747	27535	33	19B
0005434979853	27535	34	19C
0005434979954	27535	35	19D
0005434979837	27535	36	20A
0005434988764	27535	37	20B
0005434979959	27535	38	20C
0005434988742	27535	39	20D
0005434979778	27535	40	21A
0005434979957	27535	41	21B
0005434979907	27535	42	21C
0005434980045	27535	43	21D
0005434988758	27535	44	22A
0005434979904	27535	45	22B
0005434979968	27535	46	22D
0005434979924	27535	47	23A
0005434979871	27535	48	23B
0005433111505	10302	1	3A
0005434302513	10302	2	4C
0005434302512	10302	3	5A
0005434302514	10302	4	20A
0005434302515	10302	5	22A
0005433111511	10302	6	23B
0005434302492	19587	1	6D
0005434302478	19587	2	1C
0005434302486	19587	3	3B
0005434302484	19587	4	4A
0005434302500	19587	5	4B
0005434302501	19587	6	4C
0005433113564	19587	7	5A
0005434302477	19587	8	5B
0005433113565	19587	9	19D
0005433113566	19587	10	20D
0005435069757	3528	1	20F
0005435925344	3528	2	15E
0005435069790	3528	3	15F
0005435939894	3528	4	16A
0005435069771	3528	5	16C
0005435939888	3528	6	16D
0005435925375	3528	7	16E
0005435069753	3528	8	16F
0005435069785	3528	9	17A
0005435069752	3528	10	17C
0005435719017	3528	11	17D
0005435069789	3528	12	17E
0005435925342	3528	13	17F
0005435069794	3528	14	18A
0005435069776	3528	15	18C
0005435719018	3528	16	18D
0005435719011	3528	17	18E
0005435069795	3528	18	18F
0005435950297	3528	19	19A
0005435069799	3528	20	19C
0005435939893	3528	21	19F
0005435925379	3528	22	20A
0005435939889	3528	23	20C
0005435719012	3528	24	20D
0005435069769	3528	25	20E
0005435069773	3528	26	1A
0005435925378	3528	27	1D
0005435069796	3528	28	1F
0005435069760	3528	29	2A
0005435069781	3528	30	2C
0005435069767	3528	31	2D
0005435069788	3528	32	2F
0005435925326	3528	33	3A
0005435069754	3528	34	3C
0005435069793	3528	35	3D
0005435069774	3528	36	4C
0005435069759	3528	37	4F
0005435069770	3528	38	5A
0005435069756	3528	39	5C
0005435069800	3528	40	5D
0005435069779	3528	41	5E
0005435925401	3528	42	5F
0005435925384	3528	43	6A
0005435069755	3528	44	6C
0005435939879	3528	45	6D
0005435719014	3528	46	6E
0005435069765	3528	47	6F
0005435069775	3528	48	7A
0005435069798	3528	49	7C
0005435069797	3528	50	7D
0005435069782	3528	51	7E
0005435719015	3528	52	8A
0005435925341	3528	53	8C
0005435719016	3528	54	8D
0005435069751	3528	55	8E
0005435925343	3528	56	8F
0005435925327	3528	57	9A
0005435719019	3528	58	9C
0005435069783	3528	59	9D
0005435069784	3528	60	9E
0005435939880	3528	61	9F
0005435069766	3528	62	10A
0005435069792	3528	63	10C
0005435069763	3528	64	10D
0005435069786	3528	65	10F
0005435925385	3528	66	11A
0005435069764	3528	67	11D
0005435069768	3528	68	11E
0005435925454	3528	69	12C
0005435069778	3528	70	12A
0005435069749	3528	71	12D
0005435925371	3528	72	12E
0005435719013	3528	73	12F
0005435939890	3528	74	13A
0005435925455	3528	75	13D
0005435069777	3528	76	13E
0005435069772	3528	77	13F
0005435069758	3528	78	14A
0005435069761	3528	79	14C
0005435069791	3528	80	14D
0005435069787	3528	81	14F
0005435069750	3528	82	15A
0005435069780	3528	83	15C
0005435069762	3528	84	15D
0005435068860	15277	1	16C
0005435069391	15277	2	16F
0005435069390	15277	3	15C
0005435069212	15277	4	1F
0005435069354	15277	5	11D
0005435069129	15277	6	3F
0005435069081	15277	7	20D
0005435069394	15277	8	19D
0005435069247	15277	9	16E
0005435069270	15277	10	20F
0005435069271	15277	11	8C
0005435069187	15277	12	15A
0005435069019	15277	13	9D
0005435069190	15277	14	6D
0005435069263	15277	15	19F
0005435069443	15277	16	5D
0005435069444	15277	17	13C
0005435069109	15277	18	12E
0005435069233	15277	19	9F
0005435069120	15277	20	18F
0005435069358	15277	21	11E
0005435069246	15277	22	11C
0005435069374	15277	23	8D
0005435069304	15277	24	7E
0005435069299	15277	25	7C
0005435069466	15277	26	10F
0005435069080	15277	27	14E
0005435069241	15277	28	6A
0005435069117	15277	29	10A
0005435069311	15277	30	14A
0005435069245	15277	31	14C
0005435069251	15277	32	17A
0005435069521	15277	33	19C
0005435069360	15277	34	2C
0005435069132	15277	35	13F
0005435069174	15277	36	5A
0005435069108	15277	37	20C
0005435069401	15277	38	4E
0005435069520	15277	39	12D
0005435925468	15277	40	17E
0005435069200	15277	41	11F
0005435069020	15277	42	12A
0005435069060	15277	43	13A
0005435069121	15277	44	10C
0005435925472	15277	45	11A
0005435069188	15277	46	8E
0005435069264	15277	47	5E
0005435069303	15277	48	12F
0005435069153	15277	49	9E
0005435069373	15277	50	19E
0005435069036	15277	51	1A
0005435069372	15277	52	9C
0005435069173	15277	53	5F
0005435069393	15277	54	12C
0005435069395	15277	55	7D
0005435069172	15277	56	3D
0005435069084	15277	57	17F
0005435069369	15277	58	4C
0005435069082	15277	59	17D
0005435069085	15277	60	3A
0005435069133	15277	61	6E
0005435069359	15277	62	4D
0005435069383	15277	63	5C
0005435069175	15277	64	2A
0005435069289	15277	65	10D
0005435069473	15277	66	4F
0005435925469	15277	67	18E
0005435069353	15277	68	7F
0005435925471	15277	69	16D
0005435069199	15277	70	1C
0005435925470	15277	71	8A
0005432660844	18157	1	6A
0005432659734	18157	2	6B
0005432658618	18157	3	5B
0005432658619	18157	4	1B
0005432660845	18157	5	3B
0005432659733	18157	6	5A
0005432660827	26379	1	3B
0005432660823	26379	2	2A
0005432664139	26379	3	2B
0005432667453	26379	4	5A
0005433102383	47	1	10C
0005433102410	47	2	14A
0005432157518	47	3	15D
0005433102416	47	4	23F
0005432920026	47	5	17D
0005432901721	47	6	3C
0005432919935	47	7	15A
0005433102219	47	8	10A
0005433102366	47	9	5C
0005433102407	47	10	1F
0005433102367	47	11	10D
0005433102338	47	12	22D
0005432901669	47	13	20F
0005433102217	47	14	8F
0005432901698	47	15	30C
0005432901706	47	16	6D
0005433102349	47	17	29F
0005432919884	47	18	31B
0005433102432	47	19	26D
0005433102275	47	20	7D
0005432920013	47	21	22A
0005433102370	47	22	5F
0005433102303	47	23	27C
0005433102304	47	24	13F
0005432677603	47	25	17A
0005432677573	47	26	24F
0005433102418	47	27	9A
0005432919955	47	28	28D
0005433102402	47	29	11D
0005432919978	47	30	19C
0005433102259	47	31	24D
0005433102434	47	32	14C
0005433102141	47	33	15E
0005433102260	47	34	27E
0005432919890	47	35	3A
0005433102386	47	36	18F
0005433102376	47	37	31E
0005433102355	47	38	6F
0005433102287	47	39	4D
0005433102384	47	40	2C
0005433102421	47	41	8B
0005433102396	47	42	14F
0005432901733	47	43	19B
0005433102278	47	44	30D
0005432920003	47	45	31A
0005432901738	47	46	1A
0005432919889	47	47	7C
0005432677590	47	48	11B
0005433102395	47	49	18A
0005433102354	47	50	18C
0005432677598	47	51	25C
0005432901719	47	52	29B
0005433102277	47	53	17B
0005432919948	47	54	24C
0005432919883	47	55	28A
0005432919985	47	56	16A
0005432901722	47	57	22F
0005432677601	47	58	10B
0005433102216	47	59	4F
0005433102374	47	60	21C
0005432919854	47	61	13A
0005432920004	47	62	23A
0005433102401	47	63	25A
0005433102313	47	64	31F
0005432919930	47	65	19E
0005433102419	47	66	15F
0005432901739	47	67	22B
0005433102276	47	68	29E
0005432901720	47	69	5A
0005432920037	47	70	15C
0005432920012	47	71	29A
0005432920023	47	72	15B
0005433102373	47	73	2A
0005433102435	47	74	28B
0005432919977	47	75	29D
0005432920025	47	76	21D
0005433102274	47	77	13E
0005432919933	47	78	11A
0005432920036	47	79	21B
0005432919903	47	80	18B
0005432901723	47	81	1C
0005432677599	47	82	14E
0005432919987	47	83	9F
0005433102417	47	84	3F
0005433102339	47	85	10F
0005433102288	47	86	9E
0005433102218	47	87	8D
0005432901697	47	88	3D
0005433102351	47	89	18D
0005432920035	47	90	22C
0005433102429	47	91	9B
0005433102356	47	92	26F
0005432901732	47	93	2D
0005433102377	47	94	16F
0005432919953	47	95	26E
0005432157517	47	96	5D
0005432919986	47	97	4C
0005432919949	47	98	28E
0005432901757	47	99	31C
0005433102431	47	100	20B
0005433102348	47	101	23E
0005433102369	47	102	10E
0005432919904	47	103	25F
0005432677600	47	104	17C
0005432920002	47	105	1D
0005432262514	46	1	11E
0005432817852	46	2	1A
0005432817861	46	3	1C
0005432817870	46	4	2A
0005432753301	46	5	1F
0005432262524	46	6	3A
0005432817865	46	7	3C
0005432817858	46	8	3F
0005432207693	46	9	4A
0005433690930	46	10	4D
0005432262517	46	11	5A
0005432262532	46	12	4F
0005432817878	46	13	5C
0005432756851	46	14	5D
0005432753307	46	15	6C
0005432262492	46	16	6A
0005432817874	46	17	6F
0005432817877	46	18	7C
0005432262495	46	19	7F
0005432756852	46	20	8A
0005432817879	46	21	8B
0005432817873	46	22	8D
0005433690932	46	23	8E
0005432817872	46	24	9C
0005432262510	46	25	9E
0005432207694	46	26	9D
0005432817866	46	27	9F
0005432753318	46	28	10B
0005432289030	46	29	10E
0005432817875	46	30	11C
0005432262519	46	31	11B
0005432262526	46	32	11F
0005432817863	46	33	12B
0005432289031	46	34	12C
0005432817850	46	35	13A
0005432262511	46	36	12F
0005432262527	46	37	12E
0005432262515	46	38	13B
0005432817851	46	39	13F
0005432262502	46	40	14C
0005432262523	46	41	15A
0005432817868	46	42	15C
0005432262531	46	43	15D
0005432817857	46	44	15F
0005432262534	46	45	16A
0005432262501	46	46	16B
0005432262521	46	47	16C
0005432262528	46	48	16E
0005432817853	46	49	17A
0005432262513	46	50	17C
0005432262507	46	51	17E
0005432262498	46	52	18A
0005432753302	46	53	17F
0005432262497	46	54	18C
0005432262493	46	55	18B
0005432753303	46	56	19B
0005432262535	46	57	20A
0005432262529	46	58	19E
0005432817876	46	59	20B
0005432262506	46	60	20D
0005432262500	46	61	20F
0005432817867	46	62	21A
0005432262516	46	63	21B
0005432753304	46	64	21D
0005432817864	46	65	22A
0005432262504	46	66	21F
0005432262509	46	67	22E
0005432753319	46	68	23A
0005432262491	46	69	23C
0005432817856	46	70	23E
0005432262533	46	71	23F
0005432289028	46	72	24E
0005432817862	46	73	24D
0005433690929	46	74	25A
0005432262503	46	75	25B
0005432262525	46	76	25E
0005432262530	46	77	26B
0005432262536	46	78	26C
0005432262505	46	79	27A
0005432262512	46	80	27C
0005432817869	46	81	27B
0005432262499	46	82	27D
0005432817871	46	83	27E
0005432289029	46	84	28A
0005432817859	46	85	27F
0005432262520	46	86	28B
0005432262522	46	87	29B
0005432289032	46	88	29A
0005432817860	46	89	29C
0005433687707	46	90	29F
0005432262494	46	91	30C
0005432262518	46	92	30F
0005432756865	46	93	31B
0005432817855	46	94	31A
0005432262496	46	95	31C
0005432262508	46	96	31F
0005432817854	46	97	31E
0005432751571	8011	1	26D
0005432020607	8011	2	26F
0005432920129	8011	3	27B
0005432920134	8011	4	27D
0005432020610	8011	5	27E
0005432044560	8011	6	28A
0005433102846	8011	7	27F
0005433102871	8011	8	28B
0005433102840	8011	9	28C
0005433102827	8011	10	29A
0005432020604	8011	11	28F
0005433102854	8011	12	29B
0005433102829	8011	13	29D
0005432020616	8011	14	29F
0005433102821	8011	15	29E
0005433102855	8011	16	30B
0005432020624	8011	17	30F
0005433102836	8011	18	30E
0005432020621	8011	19	31F
0005432020619	8011	20	31E
0005433102826	8011	21	16F
0005432020613	8011	22	17A
0005432753347	8011	23	17E
0005432677628	8011	24	17D
0005432753348	8011	25	18A
0005432020626	8011	26	17F
0005432920126	8011	27	18D
0005432751573	8011	28	18E
0005433102830	8011	29	19C
0005432920142	8011	30	19D
0005432751570	8011	31	19E
0005432677629	8011	32	20B
0005432920127	8011	33	20A
0005433102838	8011	34	20C
0005432392040	8011	35	20D
0005433102850	8011	36	20F
0005432020617	8011	37	21A
0005432020609	8011	38	21C
0005432920141	8011	39	21B
0005432392039	8011	40	21D
0005433102867	8011	41	21E
0005432920137	8011	42	22A
0005432045641	8011	43	21F
0005432920143	8011	44	22B
0005433102843	8011	45	22C
0005433102834	8011	46	22E
0005432020622	8011	47	23A
0005433102837	8011	48	23B
0005433102861	8011	49	23D
0005433102823	8011	50	23C
0005433102839	8011	51	23E
0005433102860	8011	52	23F
0005432020611	8011	53	24B
0005432020605	8011	54	24D
0005432751572	8011	55	24E
0005433102863	8011	56	25A
0005432677627	8011	57	25C
0005433102842	8011	58	25B
0005432920139	8011	59	26A
0005432045640	8011	60	25F
0005432920144	8011	61	26B
0005433102831	8011	62	26C
0005432677625	8011	63	26E
0005433102832	8011	64	27A
0005432020623	8011	65	1C
0005432020612	8011	66	1D
0005433102844	8011	67	2A
0005433102833	8011	68	1F
0005432392038	8011	69	2C
0005432020603	8011	70	2D
0005432920138	8011	71	3A
0005433102845	8011	72	2F
0005433102851	8011	73	3C
0005432020618	8011	74	3D
0005432020620	8011	75	4A
0005432920135	8011	76	4D
0005432920125	8011	77	4F
0005433102866	8011	78	5A
0005432920140	8011	79	5C
0005433102856	8011	80	5D
0005433102870	8011	81	6A
0005433102865	8011	82	5F
0005432920133	8011	83	6D
0005433102828	8011	84	6C
0005433102859	8011	85	6F
0005433102868	8011	86	7D
0005433102853	8011	87	7C
0005432920132	8011	88	8B
0005432677626	8011	89	8E
0005433102841	8011	90	8F
0005432920124	8011	91	9A
0005432020608	8011	92	9B
0005432753346	8011	93	9D
0005433102869	8011	94	9F
0005432044561	8011	95	10D
0005432044562	8011	96	10E
0005432044563	8011	97	10F
0005433102847	8011	98	11A
0005432020629	8011	99	11B
0005432020625	8011	100	11D
0005433102825	8011	101	12A
0005433102849	8011	102	12C
0005433102857	8011	103	12D
0005432020615	8011	104	12E
0005432020627	8011	105	12F
0005433102848	8011	106	13A
0005432920131	8011	107	13C
0005432020628	8011	108	13B
0005433102835	8011	109	13E
0005432920130	8011	110	14A
0005432920136	8011	111	13F
0005433102862	8011	112	14B
0005432920145	8011	113	14D
0005432020614	8011	114	15A
0005432920128	8011	115	14F
0005433102864	8011	116	15E
0005433102852	8011	117	15F
0005433102858	8011	118	16A
0005433102824	8011	119	16B
0005432020606	8011	120	16D
0005433102822	8011	121	16E
0005432817571	8012	1	10F
0005432817660	8012	2	4F
0005432901845	8012	3	7A
0005432901839	8012	4	8D
0005432901847	8012	5	8C
0005432901844	8012	6	9A
0005432817526	8012	7	9D
0005432901835	8012	8	9F
0005432817537	8012	9	10A
0005432817689	8012	10	10D
0005432817609	8012	11	2D
0005432817582	8012	12	11C
0005432901850	8012	13	15D
0005432901848	8012	14	15E
0005432901841	8012	15	17D
0005432901846	8012	16	19B
0005432817512	8012	17	18F
0005432901838	8012	18	19C
0005432817596	8012	19	20B
0005432817751	8012	20	21B
0005432901837	8012	21	21C
0005432817507	8012	22	24C
0005432817597	8012	23	25A
0005432901836	8012	24	25C
0005432817503	8012	25	25E
0005432901840	8012	26	26D
0005432901842	8012	27	27E
0005432817570	8012	28	28D
0005432817665	8012	29	29E
0005432817752	8012	30	30E
0005432901843	8012	31	30D
0005432901849	8012	32	30F
0005433870760	9687	1	3B
0005433870761	9687	2	3A
0005434175784	9687	3	4A
0005433870759	9687	4	2A
0005434175783	9687	5	1A
0005433870738	32371	1	4B
0005434175809	32371	2	5A
0005434175808	32371	3	5B
0005433870741	32371	4	6B
0005433870742	32371	5	2A
0005434175810	32371	6	2B
0005433870740	32371	7	3B
0005434427005	3468	1	34G
0005435626416	3468	2	34F
0005435126926	3468	3	34K
0005432613917	3468	4	34J
0005434879448	3468	5	35A
0005434427001	3468	6	35B
0005434427018	3468	7	35G
0005434879526	3468	8	35F
0005434879510	3468	9	35E
0005432611763	3468	10	35H
0005434426993	3468	11	36C
0005434879454	3468	12	36B
0005434879515	3468	13	36F
0005435126916	3468	14	36E
0005434879474	3468	15	36D
0005435126913	3468	16	36G
0005434879524	3468	17	36K
0005434879536	3468	18	36J
0005434938399	3468	19	36H
0005435626420	3468	20	37D
0005435126914	3468	21	37C
0005432799847	3468	22	37F
0005432611760	3468	23	37E
0005435902737	3468	24	37H
0005434938407	3468	25	37G
0005432799841	3468	26	37K
0005432611761	3468	27	37J
0005434427010	3468	28	38C
0005435902806	3468	29	38J
0005434879461	3468	30	39C
0005434426999	3468	31	39F
0005434938403	3468	32	39G
0005434879488	3468	33	40A
0005435902763	3468	34	39K
0005434879528	3468	35	39J
0005434879472	3468	36	40B
0005434879478	3468	37	40F
0005435626425	3468	38	40E
0005435126925	3468	39	40D
0005432799832	3468	40	40J
0005435626418	3468	41	40H
0005434879490	3468	42	41B
0005435126909	3468	43	41A
0005435902782	3468	44	41F
0005435626426	3468	45	41E
0005434879531	3468	46	41K
0005434427004	3468	47	42C
0005435626417	3468	48	42A
0005434879509	3468	49	42G
0005434879519	3468	50	42J
0005432799846	3468	51	42H
0005434426989	3468	52	43A
0005435902762	3468	53	43C
0005435902784	3468	54	43F
0005434427003	3468	55	43E
0005435126919	3468	56	43D
0005434879498	3468	57	43J
0005434879532	3468	58	44B
0005435902819	3468	59	44E
0005434879506	3468	60	44G
0005434879492	3468	61	44J
0005435126910	3468	62	44H
0005432799849	3468	63	45B
0005434938397	3468	64	45C
0005434879500	3468	65	45E
0005434938411	3468	66	45D
0005432799835	3468	67	45H
0005432799828	3468	68	45G
0005435126930	3468	69	46A
0005434879466	3468	70	45K
0005434879451	3468	71	45J
0005435626414	3468	72	46B
0005434426994	3468	73	46G
0005435126915	3468	74	46F
0005435126935	3468	75	46J
0005435126901	3468	76	47A
0005434426996	3468	77	47E
0005432799827	3468	78	47K
0005435126912	3468	79	48D
0005434938410	3468	80	48C
0005435126906	3468	81	48A
0005435126929	3468	82	48F
0005434879457	3468	83	48E
0005435902818	3468	84	48G
0005432613915	3468	85	49A
0005434427014	3468	86	49E
0005435126902	3468	87	49D
0005434879471	3468	88	49C
0005434427016	3468	89	49K
0005432799839	3468	90	49H
0005434879450	3468	91	50A
0005434879470	3468	92	50E
0005435626415	3468	93	50G
0005434879477	3468	94	50F
0005435626431	3468	95	51D
0005434879449	3468	96	50K
0005434938408	3468	97	50H
0005434938406	3468	98	51F
0005435126928	3468	99	51E
0005434938394	3468	100	51G
0005434426990	3468	101	33B
0005434426995	3468	102	1H
0005434426991	3468	103	1G
0005432799825	3468	104	2A
0005434879512	3468	105	1K
0005434427013	3468	106	2C
0005434879533	3468	107	2H
0005435126931	3468	108	2G
0005435626424	3468	109	2D
0005434879468	3468	110	2K
0005435126917	3468	111	3C
0005435914700	3468	112	3K
0005432799838	3468	113	3G
0005435126903	3468	114	4G
0005435126899	3468	115	4D
0005435126933	3468	116	4K
0005434879482	3468	117	5A
0005434879496	3468	118	5H
0005434879445	3468	119	5G
0005434427002	3468	120	5K
0005434879530	3468	121	11D
0005435126924	3468	122	11C
0005434427007	3468	123	11K
0005434879459	3468	124	12A
0005435902756	3468	125	12E
0005432799831	3468	126	12D
0005434938398	3468	127	12H
0005434879520	3468	128	12G
0005432799823	3468	129	12K
0005434938400	3468	130	13D
0005434879513	3468	131	13A
0005434879487	3468	132	13H
0005434879463	3468	133	13G
0005435126937	3468	134	14A
0005434879504	3468	135	14D
0005434879455	3468	136	14C
0005434427008	3468	137	14F
0005432613914	3468	138	14E
0005434938401	3468	139	14K
0005434879529	3468	140	14H
0005434938395	3468	141	15E
0005434879534	3468	142	15D
0005435126918	3468	143	15G
0005434938409	3468	144	16A
0005435126936	3468	145	15K
0005435126920	3468	146	15H
0005434879456	3468	147	16G
0005434427000	3468	148	17C
0005434879447	3468	149	17D
0005434879507	3468	150	17G
0005435126922	3468	151	17F
0005434879483	3468	152	17K
0005434879443	3468	153	18C
0005435626429	3468	154	18B
0005434427012	3468	155	18A
0005435626427	3468	156	18H
0005432799830	3468	157	18G
0005434426998	3468	158	18F
0005434879535	3468	159	18K
0005432799843	3468	160	18J
0005434879476	3468	161	19B
0005432799834	3468	162	19A
0005435902736	3468	163	19D
0005434426997	3468	164	19C
0005434879458	3468	165	19F
0005432799848	3468	166	19J
0005435126897	3468	167	19G
0005434879462	3468	168	19K
0005434879442	3468	169	20C
0005432799826	3468	170	20D
0005434427006	3468	171	20G
0005434879527	3468	172	20H
0005434879460	3468	173	21B
0005432799842	3468	174	20K
0005434879485	3468	175	21D
0005434879467	3468	176	21E
0005434879525	3468	177	21G
0005432799840	3468	178	22A
0005435126898	3468	179	21K
0005434879523	3468	180	21J
0005434879499	3468	181	22B
0005435902811	3468	182	22H
0005434938405	3468	183	22G
0005434879464	3468	184	22K
0005435626423	3468	185	23A
0005434879494	3468	186	23E
0005434938402	3468	187	23C
0005434879495	3468	188	23F
0005434879475	3468	189	23J
0005434879469	3468	190	23G
0005434879446	3468	191	24D
0005434426992	3468	192	23K
0005435126905	3468	193	24G
0005434879502	3468	194	24F
0005435902735	3468	195	25B
0005434879480	3468	196	25D
0005435126923	3468	197	25F
0005435126934	3468	198	25E
0005432799829	3468	199	25H
0005434879473	3468	200	25G
0005435626422	3468	201	25K
0005434427017	3468	202	25J
0005434879516	3468	203	26B
0005434879465	3468	204	26A
0005432799822	3468	205	26E
0005435126921	3468	206	26G
0005432799824	3468	207	26F
0005435126911	3468	208	27B
0005434879521	3468	209	27A
0005435902752	3468	210	26K
0005434879493	3468	211	27C
0005435626430	3468	212	27F
0005432799844	3468	213	27E
0005434879522	3468	214	27D
0005435626421	3468	215	27H
0005435126900	3468	216	27G
0005434879514	3468	217	27K
0005435126904	3468	218	27J
0005434879479	3468	219	28C
0005435126932	3468	220	28B
0005432799833	3468	221	28A
0005432799845	3468	222	28G
0005432188651	3468	223	28H
0005434879503	3468	224	29B
0005435126908	3468	225	29D
0005432799837	3468	226	29C
0005435902847	3468	227	29F
0005435126927	3468	228	29E
0005435902765	3468	229	29H
0005434879505	3468	230	29G
0005434879453	3468	231	29K
0005434879508	3468	232	29J
0005434879511	3468	233	30B
0005432613918	3468	234	30A
0005434879484	3468	235	30E
0005434879501	3468	236	30D
0005432188652	3468	237	30G
0005434938404	3468	238	30J
0005434427015	3468	239	30H
0005434879517	3468	240	31B
0005434879452	3468	241	31A
0005432613916	3468	242	30K
0005434938396	3468	243	31D
0005435902774	3468	244	31F
0005434427009	3468	245	31G
0005435626428	3468	246	31K
0005434427011	3468	247	31J
0005434879486	3468	248	32C
0005434879491	3468	249	32E
0005435126907	3468	250	32G
0005435626419	3468	251	32F
0005432799836	3468	252	32K
0005434879497	3468	253	32J
0005434879537	3468	254	32H
0005435902757	3468	255	33A
0005434938412	3468	256	33D
0005432611762	3468	257	33C
0005435626432	3468	258	33G
0005434879518	3468	259	33F
0005432183496	3468	260	33E
0005434938393	3468	261	33H
0005434879489	3468	262	34A
0005432611759	3468	263	33K
0005434879481	3468	264	33J
0005434879444	3468	265	34C
0005435126577	14589	1	20J
0005435902934	14589	2	49C
0005434878353	14589	3	46C
0005434426781	14589	4	43F
0005435126374	14589	5	13D
0005435902935	14589	6	36E
0005435126575	14589	7	40C
0005435126523	14589	8	48D
0005435126430	14589	9	27J
0005434878213	14589	10	46J
0005434938305	14589	11	12H
0005434878954	14589	12	40J
0005432799545	14589	13	48H
0005434426822	14589	14	45J
0005432799619	14589	15	24F
0005434426846	14589	16	31A
0005434879054	14589	17	1H
0005432799591	14589	18	34C
0005432607571	14589	19	35D
0005434878305	14589	20	16K
0005432799345	14589	21	27C
0005434426755	14589	22	5H
0005435902949	14589	23	20B
0005435626192	14589	24	43H
0005432799589	14589	25	49A
0005434878830	14589	26	47F
0005432059530	14589	27	42G
0005435626190	14589	28	40D
0005434878841	14589	29	39J
0005434878697	14589	30	4A
0005434878719	14589	31	24D
0005434878864	14589	32	46H
0005435126599	14589	33	19A
0005435126464	14589	34	26D
0005434878565	14589	35	13F
0005432799530	14589	36	45F
0005434426744	14589	37	31C
0005432799621	14589	38	30J
0005432799556	14589	39	29J
0005434938234	14589	40	2K
0005432611715	14589	41	38C
0005435913972	14589	42	18A
0005434878455	14589	43	34H
0005434878955	14589	44	2G
0005434878566	14589	45	3H
0005432799652	14589	46	12C
0005434878912	14589	47	45A
0005434938277	14589	48	44G
0005432799605	14589	49	44B
0005434938199	14589	50	14E
0005434878672	14589	51	23J
0005435626253	14589	52	37G
0005434878741	14589	53	37D
0005435902940	14589	54	35E
0005435126425	14589	55	30H
0005434878863	14589	56	27A
0005434878615	14589	57	32G
0005434878935	14589	58	35H
0005435902941	14589	59	45D
0005432607591	14589	60	39H
0005434878619	14589	61	3A
0005434878507	14589	62	15E
0005434878736	14589	63	42F
0005432799623	14589	64	42K
0005434878592	14589	65	22C
0005434878842	14589	66	46E
0005434938239	14589	67	50A
0005434878580	14589	68	46D
0005435126553	14589	69	19C
0005434878751	14589	70	44H
0005435626220	14589	71	5G
0005434878591	14589	72	30G
0005435626237	14589	73	47E
0005432799523	14589	74	30D
0005432607570	14589	75	3D
0005434426791	14589	76	26K
0005434426743	14589	77	30A
0005434878766	14589	78	43K
0005434426954	14589	79	28H
0005435126571	14589	80	22K
0005432799611	14589	81	22D
0005435913971	14589	82	3K
0005434878921	14589	83	1G
0005432799559	14589	84	2C
0005435902936	14589	85	11E
0005434426818	14589	86	14F
0005435626219	14589	87	18B
0005435126598	14589	88	18J
0005434426955	14589	89	19B
0005434878606	14589	90	25J
0005434878553	14589	91	29E
0005434878389	14589	92	30K
0005435902942	14589	93	32C
0005434878833	14589	94	32J
0005435126480	14589	95	33F
0005434938306	14589	96	39K
0005435902945	14589	97	41F
0005434878696	14589	98	43C
0005432607593	14589	99	38H
0005435126558	14589	100	26C
0005434878608	14589	101	48C
0005434878910	14589	102	43J
0005434426754	14589	103	41A
0005434878538	14589	104	44F
0005434938183	14589	105	23B
0005432611727	14589	106	23A
0005434878306	14589	107	35J
0005434878894	14589	108	16G
0005435126387	14589	109	18K
0005435626244	14589	110	44E
0005435126503	14589	111	5K
0005434878166	14589	112	51D
0005434938200	14589	113	40A
0005435126699	14589	114	4D
0005434878642	14589	115	36H
0005434878564	14589	116	17K
0005434426736	14589	117	46B
0005434878726	14589	118	51G
0005434938232	14589	119	41E
0005434426720	14589	120	37H
0005434878692	14589	121	41D
0005434878610	14589	122	22A
0005434879034	14589	123	45G
0005432799548	14589	124	17H
0005434878800	14589	125	28B
0005435126544	14589	126	39C
0005435126444	14589	127	36D
0005434938260	14589	128	25E
0005434938171	14589	129	42J
0005434938294	14589	130	16D
0005434426823	14589	131	28A
0005435126631	14589	132	39E
0005435126386	14589	133	20D
0005432799346	14589	134	22B
0005435626182	14589	135	17G
0005434938170	14589	136	45H
0005432611726	14589	137	3C
0005435126509	14589	138	36A
0005434878263	14589	139	2A
0005435902932	14589	140	47H
0005434426780	14589	141	40K
0005434938263	14589	142	40H
0005434938304	14589	143	42D
0005434878602	14589	144	46F
0005434878832	14589	145	33E
0005434426611	14589	146	34A
0005435126479	14589	147	18G
0005434426762	14589	148	17D
0005435126462	14589	149	14K
0005435126413	14589	150	25B
0005432799612	14589	151	36K
0005434879022	14589	152	40B
0005434426792	14589	153	16C
0005434878911	14589	154	21A
0005435126723	14589	155	35A
0005434879026	14589	156	23H
0005435126524	14589	157	30C
0005434879027	14589	158	33A
0005434938184	14589	159	19G
0005435126461	14589	160	40F
0005434878658	14589	161	28K
0005435913969	14589	162	19E
0005434878885	14589	163	41B
0005432799561	14589	164	50F
0005435902938	14589	165	13E
0005434426749	14589	166	31H
0005435902944	14589	167	42H
0005435626261	14589	168	15G
0005434878578	14589	169	4C
0005435126412	14589	170	23E
0005432799560	14589	171	4K
0005435902946	14589	172	29B
0005434878605	14589	173	51E
0005434426683	14589	174	49K
0005435902947	14589	175	21C
0005434426684	14589	176	46K
0005435126525	14589	177	32H
0005435913974	14589	178	46A
0005435126557	14589	179	36G
0005434878884	14589	180	39G
0005435126373	14589	181	13H
0005434426766	14589	182	44D
0005434878228	14589	183	12E
0005435902933	14589	184	45B
0005432799533	14589	185	5C
0005435126530	14589	186	23C
0005434878934	14589	187	43B
0005432611738	14589	188	42C
0005434878581	14589	189	22E
0005432799469	14589	190	49D
0005434426598	14589	191	27B
0005432059531	14589	192	22G
0005432799675	14589	193	44C
0005432607590	14589	194	17F
0005435126491	14589	195	29K
0005435913970	14589	196	51F
0005432799557	14589	197	1K
0005434879023	14589	198	45C
0005435902939	14589	199	50C
0005435626198	14589	200	35K
0005435626201	14589	201	34E
0005434878802	14589	202	42E
0005435913973	14589	203	34B
0005434878629	14589	204	26E
0005434878803	14589	205	43G
0005434878742	14589	206	39D
0005435626233	14589	207	48F
0005434878637	14589	208	22H
0005432799699	14589	209	16H
0005435126465	14589	210	23F
0005434426750	14589	211	36B
0005434878607	14589	212	18D
0005434426790	14589	213	25G
0005434938259	14589	214	25F
0005434938269	14589	215	14H
0005432799700	14589	216	49E
0005432799620	14589	217	27F
0005435126399	14589	218	21G
0005435126490	14589	219	19D
0005434878134	14589	220	23G
0005434878576	14589	221	26G
0005435126398	14589	222	26H
0005434878616	14589	223	29D
0005432799396	14589	224	16F
0005434426847	14589	225	41J
0005434878691	14589	226	12D
0005435126376	14589	227	47K
0005434426956	14589	228	31J
0005435126583	14589	229	22F
0005434878843	14589	230	41K
0005434878831	14589	231	30F
0005432799618	14589	232	49F
0005435626259	14589	233	31K
0005435626202	14589	234	47A
0005434426821	14589	235	11G
0005434878735	14589	236	36C
0005434938213	14589	237	24G
0005435626191	14589	238	21F
0005434938233	14589	239	23D
0005434938243	14589	240	47G
0005434938278	14589	241	17A
0005435126429	14589	242	26A
0005434878718	14589	243	21K
0005434426731	14589	244	37A
0005435626234	14589	245	42A
0005434878552	14589	246	18E
0005435626243	14589	247	35B
0005435126570	14589	248	11A
0005434426786	14589	249	15C
0005435902943	14589	250	42B
0005435126578	14589	251	25K
0005434426711	14589	252	37B
0005432607576	14589	253	22J
0005432607575	14589	254	38J
0005434426735	14589	255	35G
0005434878764	14589	256	33C
0005434426682	14589	257	32F
0005434878737	14589	258	29C
0005435126732	14589	259	21D
0005434878535	14589	260	26J
0005435902948	14589	261	1D
0005434877849	14589	262	25D
0005434878862	14589	263	47C
0005434878491	14589	264	50E
0005435126426	14589	265	27E
0005432799544	14589	266	3G
0005435913976	14589	267	50H
0005434878677	14589	268	18H
0005434426732	14589	269	20C
0005435902937	14589	270	2H
0005432799592	14589	271	15F
0005434878609	14589	272	12K
0005434878598	14589	273	15A
0005434426709	14589	274	37J
0005434878720	14589	275	19H
0005435626242	14589	276	29A
0005435913975	14589	277	45E
0005434879102	14589	278	33G
0005434878133	14589	279	14C
0005435126552	14589	280	35F
0005434879053	14589	281	41H
0005434325809	3623	1	22A
0005434325806	3623	2	1C
0005435889920	3623	3	1D
0005434325800	3623	4	3C
0005434312346	3623	5	4B
0005435889937	3623	6	4C
0005434325804	3623	7	4D
0005434325807	3623	8	5A
0005435889921	3623	9	5C
0005434325805	3623	10	6A
0005434325803	3623	11	6B
0005434325802	3623	12	6C
0005435889949	3623	13	7D
0005435889948	3623	14	18D
0005435889931	3623	15	19A
0005434325801	3623	16	19B
0005435889938	3623	17	19C
0005434325799	3623	18	19D
0005434312347	3623	19	20A
0005434325808	3623	20	20C
0005434325810	3623	21	20D
0005434325798	3623	22	21C
0005434325746	15635	1	3A
0005434325720	15635	2	2C
0005435889974	15635	3	4B
0005434325728	15635	4	4C
0005435889977	15635	5	4D
0005434325680	15635	6	5B
0005434325727	15635	7	6A
0005434325721	15635	8	6C
0005434325738	15635	9	18B
0005434325701	15635	10	18C
0005435889975	15635	11	18D
0005435889978	15635	12	21C
0005435889976	15635	13	22B
0005435889979	15635	14	23A
0005433420419	659	1	18D
0005435957894	659	2	5C
0005435957900	659	3	22C
0005435957902	659	4	5A
0005433420454	659	5	7D
0005433420467	659	6	3A
0005435957898	659	7	18B
0005433420468	659	8	6C
0005435957904	659	9	4A
0005435957901	659	10	2A
0005435957897	659	11	5D
0005433420435	659	12	22D
0005435957895	659	13	1C
0005435957903	659	14	18A
0005433420452	659	15	21B
0005435957893	659	16	4C
0005435957892	659	17	19A
0005435957905	659	18	6A
0005433420418	659	19	18C
0005435957896	659	20	2B
0005433420417	659	21	23A
0005435957899	659	22	4B
0005435957773	15175	1	5B
0005435957747	15175	2	21A
0005435957782	15175	3	19A
0005433420519	15175	4	23A
0005435957809	15175	5	19B
0005435957754	15175	6	7C
0005435957735	15175	7	4C
0005435629420	8911	1	6A
0005434247182	16010	1	6A
0005435629409	16010	2	1A
0005434247181	16010	3	4B
0005434096747	11824	1	3D
0005434096749	11824	2	7C
0005434096740	11824	3	19A
0005434096744	11824	4	19D
0005434096743	11824	5	2A
0005434096748	11824	6	7B
0005434096741	11824	7	5D
0005435933462	4438	1	5C
0005435163303	4438	2	20D
0005435163301	4438	3	4B
0005435163304	4438	4	22A
0005435163298	4438	5	6D
0005435163300	4438	6	5A
0005435163299	4438	7	20A
0005435933473	4438	8	3D
0005435933467	4438	9	21D
0005435933468	4438	10	22B
0005435933471	4438	11	5B
0005435163302	4438	12	7D
0005435163297	4438	13	3B
0005435163295	4438	14	7C
0005435933474	4438	15	23A
0005435163296	4438	16	19D
0005435933466	4438	17	20B
0005435933501	29523	1	1B
0005435163266	29523	2	1D
0005435163247	29523	3	2A
0005435163261	29523	4	2B
0005435163273	29523	5	3B
0005435933498	29523	6	4B
0005435163265	29523	7	4D
0005435163244	29523	8	5B
0005435163245	29523	9	6C
0005435163255	29523	10	7A
0005435163256	29523	11	7D
0005435933497	29523	12	18C
0005435163262	29523	13	19D
0005435933499	29523	14	20D
0005435933502	29523	15	21A
0005435933500	29523	16	21B
0005435163248	29523	17	21C
0005435933496	29523	18	22D
0005435163252	29523	19	23A
0005435163267	29523	20	23B
0005435163250	29523	21	1A
0005435797662	2848	1	8F
0005433404845	2848	2	1C
0005435797661	2848	3	1F
0005435797659	2848	4	2D
0005435797660	2848	5	6F
0005433404855	2848	6	7C
0005435797665	2848	7	7D
0005435797663	2848	8	7F
0005433404819	2848	9	8A
0005435797667	2848	10	12A
0005435797668	2848	11	14A
0005433404844	2848	12	15C
0005435797664	2848	13	16A
0005435797669	2848	14	16D
0005435797666	2848	15	18C
0005433404820	2848	16	19A
0005435797670	2848	17	19F
0005433404911	29341	1	1A
0005433404912	29341	2	1C
0005435797557	29341	3	2C
0005433404907	29341	4	3A
0005435797563	29341	5	6A
0005435797560	29341	6	6C
0005435797565	29341	7	6F
0005433404908	29341	8	7A
0005433404909	29341	9	7C
0005435797559	29341	10	7E
0005435797536	29341	11	8C
0005435797562	29341	12	9D
0005435797525	29341	13	9E
0005435797594	29341	14	11A
0005435797535	29341	15	11C
0005435797517	29341	16	12E
0005435797593	29341	17	13D
0005435797515	29341	18	15A
0005435797592	29341	19	15E
0005435797598	29341	20	16C
0005435797566	29341	21	17C
0005435797577	29341	22	18F
0005435797576	29341	23	19C
0005433404910	29341	24	20D
0005435376364	5745	1	1B
0005435376355	5745	2	2B
0005435376356	5745	3	3B
0005434948131	5771	1	1B
0005434948132	5771	2	2A
0005434948133	5771	3	3A
0005434948135	5771	4	3B
0005434948134	5771	5	4B
0005434948136	5771	6	5A
0005434948071	16335	1	1A
0005434948082	16335	2	1B
0005434948073	16335	3	2A
0005435376390	16335	4	2B
0005434948070	16335	5	3A
0005434948075	16335	6	3B
0005434948058	16335	7	4A
0005434948080	16335	8	4B
0005435376391	16335	9	5A
0005434948083	16335	10	5B
0005435376389	16335	11	6A
0005435376388	16335	12	6B
0005433961621	6929	1	18E
0005433961599	6929	2	1A
0005433961604	6929	3	1C
0005433961619	6929	4	1F
0005433961603	6929	5	2D
0005433961641	6929	6	2F
0005433961625	6929	7	3D
0005433961630	6929	8	3F
0005433961642	6929	9	4A
0005433961627	6929	10	4D
0005433961595	6929	11	4E
0005433961635	6929	12	4F
0005433961645	6929	13	5A
0005433961631	6929	14	5C
0005433961634	6929	15	5D
0005433961618	6929	16	5F
0005433961592	6929	17	6A
0005433961601	6929	18	6C
0005433961640	6929	19	6E
0005433961614	6929	20	6F
0005433961594	6929	21	7D
0005433961610	6929	22	7E
0005433961612	6929	23	8D
0005433961639	6929	24	8F
0005433961608	6929	25	9A
0005433961636	6929	26	9C
0005433961598	6929	27	9D
0005433961644	6929	28	10A
0005433961605	6929	29	10C
0005433961611	6929	30	10D
0005433961628	6929	31	10E
0005433961648	6929	32	11C
0005433961629	6929	33	11D
0005433961623	6929	34	11F
0005433961600	6929	35	12C
0005433961613	6929	36	12F
0005433961646	6929	37	13C
0005433961607	6929	38	13D
0005433961609	6929	39	13E
0005433961617	6929	40	13F
0005433961616	6929	41	14A
0005433961647	6929	42	14E
0005433961638	6929	43	14F
0005433961602	6929	44	15D
0005433961633	6929	45	15F
0005433961632	6929	46	16A
0005433961643	6929	47	16D
0005433961637	6929	48	17D
0005433961649	6929	49	17E
0005433961615	6929	50	18C
0005433961597	6929	51	18F
0005433961593	6929	52	19A
0005433961620	6929	53	19D
0005433961624	6929	54	19E
0005433961596	6929	55	19F
0005433961622	6929	56	20A
0005433961626	6929	57	20C
0005433961606	6929	58	20E
0005433961060	25773	1	1A
0005433961024	25773	2	1D
0005433961017	25773	3	2C
0005433960750	25773	4	2D
0005433961005	25773	5	2F
0005433960905	25773	6	3C
0005433960896	25773	7	3D
0005433961106	25773	8	3F
0005433960751	25773	9	4A
0005433961089	25773	10	4D
0005433961049	25773	11	4E
0005433961030	25773	12	4F
0005433961027	25773	13	5A
0005433961055	25773	14	5C
0005433961086	25773	15	5E
0005433961092	25773	16	5F
0005433961009	25773	17	6A
0005433961008	25773	18	6C
0005433961090	25773	19	6D
0005433960958	25773	20	6E
0005433960949	25773	21	6F
0005433960992	25773	22	7C
0005433961088	25773	23	7D
0005433961059	25773	24	7F
0005433961011	25773	25	8A
0005433961023	25773	26	8D
0005433960891	25773	27	8E
0005433960890	25773	28	8F
0005433960978	25773	29	9C
0005433960881	25773	30	9D
0005433961081	25773	31	9E
0005433960831	25773	32	10A
0005433961082	25773	33	10C
0005433960944	25773	34	10E
0005433961025	25773	35	10F
0005433961075	25773	36	11A
0005433960951	25773	37	11C
0005433961013	25773	38	11D
0005433960898	25773	39	11E
0005433961004	25773	40	11F
0005433961003	25773	41	12A
0005433960994	25773	42	12D
0005433961058	25773	43	12E
0005433960855	25773	44	12F
0005433960793	25773	45	13A
0005433960991	25773	46	13E
0005433960908	25773	47	14A
0005433960892	25773	48	14C
0005433961026	25773	49	14E
0005433960969	25773	50	14F
0005433960869	25773	51	15A
0005433961028	25773	52	15F
0005433961012	25773	53	16C
0005433960979	25773	54	16D
0005433960897	25773	55	16E
0005433960830	25773	56	17A
0005433960911	25773	57	17C
0005433961091	25773	58	17E
0005433961031	25773	59	18A
0005433960965	25773	60	18C
0005433960966	25773	61	18D
0005433960910	25773	62	18E
0005433960996	25773	63	18F
0005433960995	25773	64	19A
0005433961050	25773	65	19C
0005433960997	25773	66	20A
0005433960945	25773	67	20D
0005435082804	24503	1	1A
0005435082809	24503	2	1B
0005435082828	24503	3	2A
0005435082827	24503	4	2B
0005435082807	24503	5	5A
0005435082829	24503	6	4B
0005435082805	24503	7	5B
0005435082785	24503	8	6A
0005435082883	26113	1	1A
0005435082889	26113	2	1B
0005435082885	26113	3	2A
0005435082882	26113	4	2B
0005435082888	26113	5	3A
0005435082887	26113	6	3B
0005435082884	26113	7	4A
0005435082886	26113	8	4B
0005435082891	26113	9	5A
0005435082890	26113	10	5B
0005434245385	4978	1	1C
0005432166946	4978	2	2A
0005434245375	4978	3	2C
0005432166945	4978	4	2F
0005433534507	4978	5	3C
0005434245378	4978	6	4F
0005434245359	4978	7	8E
0005434245382	4978	8	8F
0005434245363	4978	9	9A
0005434245376	4978	10	10D
0005434245361	4978	11	12F
0005434245373	4978	12	13A
0005434245358	4978	13	13C
0005434245369	4978	14	13B
0005432166943	4978	15	13F
0005434245365	4978	16	13E
0005434245386	4978	17	15B
0005434245380	4978	18	16A
0005434245366	4978	19	17C
0005435286657	4978	20	17F
0005434245384	4978	21	18D
0005434245367	4978	22	19C
0005434245383	4978	23	20D
0005434245371	4978	24	20F
0005434245370	4978	25	21A
0005434245368	4978	26	21D
0005434245381	4978	27	21E
0005434245374	4978	28	21F
0005434245364	4978	29	22E
0005434245362	4978	30	24B
0005434245372	4978	31	25B
0005434245377	4978	32	25C
0005434245360	4978	33	26D
0005435286643	4978	34	27B
0005435286656	4978	35	27C
0005435286655	4978	36	28A
0005434245357	4978	37	27F
0005433534506	4978	38	28F
0005434245379	4978	39	29A
0005432166944	4978	40	31C
0005432106221	4977	1	14D
0005432106208	4977	2	16A
0005432106209	4977	3	16C
0005433785446	4977	4	16B
0005433615669	4977	5	16D
0005433615659	4977	6	16E
0005433785423	4977	7	17A
0005432667482	4977	8	16F
0005433615693	4977	9	17C
0005433615638	4977	10	17B
0005433615668	4977	11	17D
0005433615677	4977	12	17E
0005433615643	4977	13	18A
0005433785433	4977	14	17F
0005433615644	4977	15	18B
0005433615705	4977	16	18D
0005433615689	4977	17	18C
0005433615632	4977	18	18E
0005433785440	4977	19	18F
0005433615703	4977	20	19B
0005432145139	4977	21	19D
0005433785437	4977	22	19C
0005433615701	4977	23	20A
0005433615641	4977	24	19E
0005432106226	4977	25	20B
0005432106197	4977	26	20C
0005433615633	4977	27	20D
0005433615678	4977	28	20F
0005432106223	4977	29	20E
0005433785443	4977	30	21A
0005433615681	4977	31	21B
0005433615666	4977	32	21D
0005433785448	4977	33	21C
0005432666415	4977	34	21E
0005433615697	4977	35	22A
0005432106227	4977	36	21F
0005432106190	4977	37	22B
0005433615634	4977	38	22C
0005433615654	4977	39	22E
0005433615657	4977	40	22D
0005433615679	4977	41	22F
0005433615645	4977	42	23B
0005433785435	4977	43	23A
0005433785432	4977	44	23D
0005433615649	4977	45	23C
0005432106205	4977	46	23E
0005432106222	4977	47	23F
0005433785422	4977	48	24B
0005432106183	4977	49	24A
0005433615672	4977	50	24D
0005432106200	4977	51	24C
0005433615675	4977	52	24E
0005433785438	4977	53	24F
0005433785436	4977	54	25A
0005433615690	4977	55	25C
0005433615664	4977	56	25B
0005433785425	4977	57	25D
0005433615636	4977	58	25F
0005433615635	4977	59	25E
0005432106184	4977	60	26B
0005433785420	4977	61	26A
0005433615637	4977	62	26D
0005432666416	4977	63	26C
0005433785412	4977	64	26E
0005432106210	4977	65	27A
0005433785421	4977	66	26F
0005433785411	4977	67	27C
0005432667480	4977	68	27B
0005432106220	4977	69	27D
0005433615650	4977	70	27F
0005433615651	4977	71	27E
0005433615702	4977	72	28A
0005432106191	4977	73	28B
0005433785417	4977	74	28D
0005432106186	4977	75	28C
0005433785430	4977	76	28E
0005433785428	4977	77	28F
0005433785426	4977	78	29B
0005432106207	4977	79	29A
0005433615647	4977	80	29C
0005432665302	4977	81	29E
0005433615692	4977	82	29D
0005433615699	4977	83	30A
0005432106216	4977	84	29F
0005433785416	4977	85	30B
0005433615680	4977	86	30D
0005433615655	4977	87	30C
0005432106193	4977	88	30E
0005433615658	4977	89	30F
0005432106192	4977	90	31A
0005433785444	4977	91	31C
0005432106218	4977	92	31B
0005432106201	4977	93	31D
0005432106228	4977	94	31F
0005433615700	4977	95	31E
0005432106187	4977	96	1C
0005433615662	4977	97	1A
0005432106206	4977	98	1D
0005433785442	4977	99	2A
0005433615639	4977	100	1F
0005432106215	4977	101	2C
0005432106224	4977	102	2F
0005433785431	4977	103	2D
0005433785429	4977	104	3A
0005433615665	4977	105	3C
0005433785415	4977	106	3D
0005433615653	4977	107	4A
0005433615695	4977	108	3F
0005432106203	4977	109	4C
0005432106225	4977	110	4F
0005432106217	4977	111	4D
0005433785434	4977	112	5A
0005433785439	4977	113	5C
0005433615660	4977	114	5F
0005433615694	4977	115	5D
0005433785418	4977	116	6A
0005433615670	4977	117	6C
0005433785445	4977	118	6D
0005432667481	4977	119	7A
0005433615706	4977	120	6F
0005433615676	4977	121	7D
0005433615687	4977	122	7C
0005433615698	4977	123	7F
0005433785441	4977	124	8A
0005433615685	4977	125	8C
0005433615667	4977	126	8B
0005433615704	4977	127	8D
0005432106188	4977	128	8E
0005432106211	4977	129	8F
0005433615661	4977	130	9B
0005432106185	4977	131	9A
0005433785419	4977	132	9C
0005432106182	4977	133	9D
0005432106189	4977	134	9F
0005433615691	4977	135	10A
0005433615674	4977	136	10B
0005432106213	4977	137	10C
0005433615640	4977	138	10D
0005432145140	4977	139	10F
0005432106198	4977	140	10E
0005433615696	4977	141	11A
0005433615682	4977	142	11C
0005432106204	4977	143	11B
0005433615646	4977	144	11D
0005432106219	4977	145	11F
0005433615683	4977	146	11E
0005432106212	4977	147	12A
0005432106195	4977	148	12B
0005433615671	4977	149	12C
0005433785427	4977	150	12E
0005432106194	4977	151	12D
0005433615648	4977	152	12F
0005433615656	4977	153	13B
0005432106202	4977	154	13A
0005432106199	4977	155	13C
0005433615684	4977	156	13E
0005432106214	4977	157	13D
0005433615686	4977	158	13F
0005433615673	4977	159	14C
0005433785413	4977	160	14B
0005433615642	4977	161	14A
0005433615688	4977	162	14E
0005433785447	4977	163	14F
0005433615652	4977	164	15B
0005432106181	4977	165	15A
0005433785424	4977	166	15C
0005432106196	4977	167	15E
0005433615663	4977	168	15D
0005433785414	4977	169	15F
0005433815396	4975	1	14A
0005434149893	4975	2	24F
0005434265482	4975	3	25E
0005434265481	4975	4	2D
0005435007170	4975	5	14C
0005435007171	4975	6	4A
0005432336067	4975	7	27C
0005433685525	4975	8	25A
0005433685521	4975	9	25C
0005434173572	4975	10	9D
0005434229668	4975	11	26F
0005432336113	4975	12	31C
0005432336053	4975	13	27F
0005435007109	4975	14	14F
0005434265470	4975	15	18E
0005432336138	4975	16	10D
0005433815403	4975	17	16E
0005435007096	4975	18	9B
0005434265469	4975	19	20A
0005434229682	4975	20	10A
0005434265490	4975	21	14E
0005434229670	4975	22	7C
0005434265486	4975	23	12C
0005434265487	4975	24	23B
0005434229675	4975	25	13C
0005434229679	4975	26	26D
0005434311228	4975	27	15F
0005434265493	4975	28	5C
0005434265474	4975	29	28E
0005434149892	4975	30	11E
0005432336066	4975	31	19D
0005434311235	4975	32	7F
0005434229672	4975	33	29E
0005434149885	4975	34	30E
0005434229676	4975	35	9A
0005434229669	4975	36	8A
0005434265488	4975	37	7D
0005432336104	4975	38	16C
0005434312319	4975	39	18D
0005433815412	4975	40	9F
0005434265492	4975	41	10B
0005434149887	4975	42	8B
0005432336137	4975	43	5F
0005435007095	4975	44	18B
0005434149886	4975	45	26B
0005434265473	4975	46	18F
0005434265476	4975	47	10E
0005432336102	4975	48	24B
0005434173574	4975	49	14D
0005434229663	4975	50	31B
0005434149884	4975	51	31E
0005432336086	4975	52	27B
0005432336114	4975	53	9E
0005435007154	4975	54	20F
0005433685532	4975	55	11B
0005434265472	4975	56	27E
0005433815402	4975	57	20B
0005434229673	4975	58	17A
0005433685533	4975	59	12A
0005434149890	4975	60	23A
0005435007143	4975	61	18C
0005432336103	4975	62	3F
0005434149882	4975	63	29D
0005434229674	4975	64	1F
0005434265480	4975	65	5A
0005435007168	4975	66	28F
0005434229678	4975	67	24D
0005434173571	4975	68	24C
0005434265477	4975	69	10F
0005434229664	4975	70	19C
0005434265483	4975	71	21F
0005434265479	4975	72	26E
0005434229671	4975	73	31D
0005434229665	4975	74	8F
0005434311226	4975	75	22D
0005434229666	4975	76	30A
0005433685522	4975	77	3A
0005435007017	4975	78	15C
0005434265489	4975	79	30B
0005432336073	4975	80	12E
0005434265485	4975	81	2A
0005435007137	4975	82	1C
0005434229661	4975	83	17F
0005435007016	4975	84	17C
0005434265471	4975	85	11C
0005434265475	4975	86	4D
0005434265491	4975	87	29A
0005434311232	4975	88	15E
0005434229667	4975	89	2C
0005435007259	4975	90	6D
0005434265494	4975	91	25D
0005434265484	4975	92	21B
0005434149891	4975	93	16A
0005435007155	4975	94	21D
0005434149888	4975	95	15B
0005434311231	4975	96	19E
0005435007102	4975	97	29C
0005435007132	4975	98	24A
0005434229660	4975	99	12D
0005435007156	4975	100	31A
0005432336074	4975	101	6C
0005435007205	4975	102	11F
0005435007094	4975	103	17B
0005435007131	4975	104	22B
0005434311236	4975	105	25B
0005432336033	4975	106	27D
0005435007169	4975	107	13D
0005434229681	4975	108	9C
0005432336032	4975	109	1A
0005433815401	4975	110	11A
0005434229680	4975	111	4C
0005434149889	4975	112	15D
0005434229662	4975	113	14B
0005435007005	4975	114	7A
0005434173573	4975	115	17E
0005434149894	4975	116	16F
0005435007157	4975	117	10C
0005434229677	4975	118	24E
0005434265478	4975	119	23D
0005435007130	4975	120	6F
0005434149883	4975	121	29F
0005434311227	4975	122	22C
0005435007062	4975	123	28A
0005433685523	4975	124	28B
0005434245023	8557	1	10B
0005434245121	8557	2	10F
0005433785165	8557	3	11C
0005433785186	8557	4	11F
0005434245078	8557	5	11E
0005432666397	8557	6	12A
0005434245130	8557	7	12C
0005432659713	8557	8	13B
0005434245153	8557	9	13A
0005433785204	8557	10	13F
0005435269862	8557	11	14A
0005433785254	8557	12	14B
0005433785221	8557	13	14F
0005433785153	8557	14	15B
0005434245054	8557	15	15A
0005435269859	8557	16	15D
0005434245032	8557	17	16E
0005433785068	8557	18	16D
0005433785237	8557	19	16F
0005432666393	8557	20	17B
0005432666385	8557	21	17C
0005434245042	8557	22	17D
0005433785093	8557	23	17F
0005433785010	8557	24	17E
0005433785078	8557	25	18E
0005435269861	8557	26	19B
0005435269856	8557	27	18F
0005433785013	8557	28	20F
0005433785257	8557	29	21D
0005434245142	8557	30	22A
0005435269866	8557	31	22C
0005434245072	8557	32	22F
0005435269867	8557	33	23B
0005434245160	8557	34	23D
0005433785122	8557	35	24D
0005434245050	8557	36	24F
0005433785206	8557	37	25A
0005433785197	8557	38	25D
0005433785022	8557	39	25F
0005433784783	8557	40	26A
0005433785154	8557	41	26C
0005434245151	8557	42	26E
0005432659721	8557	43	26F
0005432666392	8557	44	27B
0005433785180	8557	45	27C
0005435269863	8557	46	27D
0005432663051	8557	47	27E
0005433784982	8557	48	28C
0005435269868	8557	49	28B
0005433785253	8557	50	28E
0005432666398	8557	51	29A
0005434245131	8557	52	28F
0005433785039	8557	53	29E
0005435269857	8557	54	29D
0005433785207	8557	55	29F
0005434245089	8557	56	30A
0005435269865	8557	57	30B
0005434245026	8557	58	30C
0005433785107	8557	59	31B
0005432659714	8557	60	12D
0005435269860	8557	61	1A
0005433785137	8557	62	1D
0005434245191	8557	63	2A
0005435269864	8557	64	1F
0005433785040	8557	65	3C
0005433784784	8557	66	4D
0005434245152	8557	67	5A
0005435269855	8557	68	5C
0005433785076	8557	69	5F
0005432659720	8557	70	6F
0005433785168	8557	71	7A
0005435269858	8557	72	7C
0005433785015	8557	73	8D
0005433785252	8557	74	8E
0005433785205	8557	75	9B
0005434245159	8557	76	9E
0005433785189	8557	77	9D
0005434245088	8557	78	9F
0005434245120	8557	79	10A
0005433614781	8556	1	1A
0005433615202	8556	2	1F
0005433615028	8556	3	2A
0005433614617	8556	4	2C
0005433614804	8556	5	2D
0005433615288	8556	6	3F
0005433614978	8556	7	4C
0005433614976	8556	8	4F
0005433614689	8556	9	5F
0005433614632	8556	10	6A
0005433615201	8556	11	6C
0005433614992	8556	12	6D
0005433615151	8556	13	7A
0005433615118	8556	14	8A
0005433615056	8556	15	7F
0005433615058	8556	16	8B
0005433615203	8556	17	8C
0005433615055	8556	18	8E
0005433614993	8556	19	8F
0005433614833	8556	20	9B
0005433614668	8556	21	9A
0005433614877	8556	22	9F
0005433615023	8556	23	9E
0005433615244	8556	24	10A
0005433614669	8556	25	10B
0005433615225	8556	26	10D
0005433614907	8556	27	11A
0005433614800	8556	28	10F
0005433615287	8556	29	11B
0005433614994	8556	30	11C
0005433615103	8556	31	11F
0005433615263	8556	32	12A
0005433614453	8556	33	12B
0005433615262	8556	34	12D
0005433614850	8556	35	12C
0005433614783	8556	36	13B
0005433614858	8556	37	13C
0005433614735	8556	38	13E
0005433615156	8556	39	14A
0005433614965	8556	40	14D
0005433614673	8556	41	14C
0005433614779	8556	42	14E
0005433614975	8556	43	14F
0005433615132	8556	44	15C
0005433614744	8556	45	15E
0005433614651	8556	46	16B
0005433614974	8556	47	16D
0005433615134	8556	48	16C
0005433614832	8556	49	16F
0005433615180	8556	50	17B
0005433614844	8556	51	17C
0005433614979	8556	52	17D
0005433614913	8556	53	17F
0005433614995	8556	54	18C
0005433614952	8556	55	18F
0005433614818	8556	56	19D
0005433614941	8556	57	19E
0005433614935	8556	58	20A
0005433614574	8556	59	20C
0005433614997	8556	60	20D
0005433614884	8556	61	20F
0005433615184	8556	62	21A
0005433614910	8556	63	21B
0005433614690	8556	64	21E
0005433614878	8556	65	21F
0005433614998	8556	66	22B
0005433614851	8556	67	22F
0005433615261	8556	68	23D
0005433615057	8556	69	23F
0005433615243	8556	70	23E
0005433614883	8556	71	24B
0005433615017	8556	72	24C
0005433614842	8556	73	24E
0005433615150	8556	74	24F
0005433615133	8556	75	25D
0005433615021	8556	76	27A
0005433614843	8556	77	27F
0005433614780	8556	78	27E
0005433614819	8556	79	28A
0005433614691	8556	80	28C
0005433614805	8556	81	28D
0005433615080	8556	82	28F
0005433614860	8556	83	31E
0005433615160	8556	84	31F
0005433614782	8556	85	31A
0005433614867	8556	86	30D
0005433614806	8556	87	30A
0005433615114	8556	88	30C
0005433614637	8556	89	29D
0005433614942	8556	90	29E
0005433614638	8556	91	29B
0005432035328	8555	1	16B
0005435007333	8555	2	1A
0005432336193	8555	3	1D
0005434173550	8555	4	2A
0005432047600	8555	5	1F
0005435007334	8555	6	2D
0005432035309	8555	7	2C
0005433815449	8555	8	2F
0005435007345	8555	9	3A
0005435007341	8555	10	3C
0005435286693	8555	11	3F
0005435007332	8555	12	3D
0005434229500	8555	13	4A
0005434229411	8555	14	4C
0005435286704	8555	15	4F
0005432035331	8555	16	4D
0005435286705	8555	17	5A
0005434229498	8555	18	5D
0005432336199	8555	19	5C
0005434229535	8555	20	6A
0005433690951	8555	21	6C
0005435286702	8555	22	6D
0005432035329	8555	23	7A
0005432035325	8555	24	7C
0005432336189	8555	25	7F
0005435286691	8555	26	7D
0005434229402	8555	27	8A
0005434229552	8555	28	8C
0005432035308	8555	29	8B
0005432047599	8555	30	8D
0005434265145	8555	31	8F
0005434265270	8555	32	9A
0005435286694	8555	33	9C
0005432336195	8555	34	9B
0005434265203	8555	35	9E
0005434265249	8555	36	9D
0005434229629	8555	37	9F
0005432035311	8555	38	10C
0005432035305	8555	39	10E
0005432336187	8555	40	10D
0005432035307	8555	41	10F
0005435007344	8555	42	11B
0005435007343	8555	43	11A
0005434149830	8555	44	11E
0005434229516	8555	45	11D
0005435007348	8555	46	11C
0005432035324	8555	47	11F
0005433688838	8555	48	12C
0005434265330	8555	49	12B
0005434149776	8555	50	12D
0005435007354	8555	51	12E
0005434173541	8555	52	12F
0005435007349	8555	53	13B
0005434229437	8555	54	13A
0005434229628	8555	55	13C
0005435286692	8555	56	13D
0005434265319	8555	57	13F
0005432336196	8555	58	13E
0005435286708	8555	59	14A
0005432035313	8555	60	14B
0005435286706	8555	61	14D
0005433689940	8555	62	14C
0005434149750	8555	63	14E
0005435007340	8555	64	15A
0005435286707	8555	65	14F
0005434311245	8555	66	15B
0005435007353	8555	67	15C
0005435286697	8555	68	15D
0005432336198	8555	69	15E
0005434229586	8555	70	15F
0005435007336	8555	71	16D
0005435007339	8555	72	16E
0005434149812	8555	73	16F
0005435286701	8555	74	17B
0005435286696	8555	75	17A
0005434149791	8555	76	17C
0005434229481	8555	77	17D
0005433534527	8555	78	17F
0005435007347	8555	79	17E
0005432035330	8555	80	18A
0005432035318	8555	81	18B
0005432035312	8555	82	18C
0005434265378	8555	83	18E
0005434229487	8555	84	18D
0005432035326	8555	85	18F
0005432035319	8555	86	19C
0005435007338	8555	87	19B
0005435286698	8555	88	20A
0005432035315	8555	89	19E
0005434229438	8555	90	20B
0005434149811	8555	91	20C
0005435007331	8555	92	20D
0005435007335	8555	93	20F
0005432035314	8555	94	20E
0005435007329	8555	95	21C
0005432035316	8555	96	21B
0005432035321	8555	97	21D
0005432047598	8555	98	21E
0005434265309	8555	99	22A
0005435286703	8555	100	21F
0005433815450	8555	101	22B
0005434149797	8555	102	22C
0005432336194	8555	103	22D
0005434149802	8555	104	22F
0005432336192	8555	105	22E
0005435286699	8555	106	23A
0005432336188	8555	107	23C
0005433815453	8555	108	23B
0005434311246	8555	109	23D
0005434229585	8555	110	23F
0005434149794	8555	111	24B
0005432336197	8555	112	24A
0005434173542	8555	113	24C
0005432035306	8555	114	24D
0005435286695	8555	115	25A
0005434149807	8555	116	25B
0005435007337	8555	117	25D
0005434229501	8555	118	25E
0005435007351	8555	119	26A
0005433815451	8555	120	26B
0005434229457	8555	121	26C
0005435007346	8555	122	26E
0005432035322	8555	123	26D
0005434149808	8555	124	26F
0005432336190	8555	125	27B
0005432035304	8555	126	27A
0005433815452	8555	127	27C
0005434229462	8555	128	27D
0005434265250	8555	129	27F
0005432035320	8555	130	27E
0005435007352	8555	131	28A
0005434311244	8555	132	28B
0005434149777	8555	133	28C
0005432035310	8555	134	28E
0005433690952	8555	135	28D
0005435007330	8555	136	28F
0005432336191	8555	137	29B
0005432035327	8555	138	29A
0005434149809	8555	139	29D
0005435007342	8555	140	29C
0005433689939	8555	141	29E
0005434265258	8555	142	30B
0005435007350	8555	143	30A
0005435286700	8555	144	30E
0005432035323	8555	145	30D
0005432047601	8555	146	31A
0005433534526	8555	147	31C
0005434173551	8555	148	31B
0005434229480	8555	149	31D
0005432035317	8555	150	31E
0005434149813	8555	151	31F
0005434639331	12601	1	1B
0005434639392	12601	2	1C
0005434639393	12601	3	1D
0005434639411	12601	4	2A
0005434639415	12601	5	2B
0005434639473	12601	6	2C
0005434639436	12601	7	2D
0005434639408	12601	8	3A
0005434639475	12601	9	3B
0005434639339	12601	10	3C
0005434639320	12601	11	3D
0005434639453	12601	12	4A
0005434639435	12601	13	4B
0005433202562	12601	14	4C
0005433202569	12601	15	4D
0005433202564	12601	16	5A
0005434639421	12601	17	5B
0005433202557	12601	18	5C
0005434639463	12601	19	5D
0005434639462	12601	20	6A
0005433202565	12601	21	6B
0005434639376	12601	22	6C
0005434639416	12601	23	6D
0005433202563	12601	24	7A
0005434639431	12601	25	7B
0005433202555	12601	26	7C
0005434639332	12601	27	7D
0005434639443	12601	28	1A
0005434639410	12601	29	18A
0005433202554	12601	30	18B
0005434639385	12601	31	18C
0005434639315	12601	32	18D
0005433202560	12601	33	19B
0005434639476	12601	34	19C
0005434639461	12601	35	19D
0005433202556	12601	36	20A
0005433202558	12601	37	20B
0005434639474	12601	38	20C
0005434639427	12601	39	20D
0005434639316	12601	40	21A
0005433202566	12601	41	21B
0005433202559	12601	42	21C
0005434639450	12601	43	21D
0005433202561	12601	44	22A
0005434639460	12601	45	22B
0005433202568	12601	46	22C
0005433202567	12601	47	22D
0005434639448	12601	48	23A
0005434639348	12601	49	23B
0005434639630	23397	1	1A
0005434639654	23397	2	1B
0005433202415	23397	3	1C
0005434639648	23397	4	1D
0005434639642	23397	5	2A
0005432290670	23397	6	2B
0005434639629	23397	7	2C
0005433202399	23397	8	2D
0005433202458	23397	9	3A
0005434639631	23397	10	3B
0005434639633	23397	11	3C
0005432290673	23397	12	3D
0005434639644	23397	13	4A
0005434639639	23397	14	4B
0005434639638	23397	15	4C
0005434639636	23397	16	4D
0005434639653	23397	17	5A
0005433202404	23397	18	5B
0005434639651	23397	19	5C
0005434639647	23397	20	5D
0005433202354	23397	21	6B
0005432290671	23397	22	6C
0005434639628	23397	23	6D
0005434639627	23397	24	7A
0005433202430	23397	25	7B
0005434639640	23397	26	7C
0005433202429	23397	27	7D
0005434639652	23397	28	18A
0005434639632	23397	29	18B
0005434639635	23397	30	18C
0005434639634	23397	31	18D
0005432290672	23397	32	19A
0005434639650	23397	33	19B
0005434639649	23397	34	19C
0005434639641	23397	35	19D
0005434639637	23397	36	20B
0005433202400	23397	37	20C
0005434639643	23397	38	20D
0005433202414	23397	39	21A
0005434639645	23397	40	21B
0005433202411	23397	41	21C
0005433202403	23397	42	22A
0005433202412	23397	43	22B
0005433202410	23397	44	22D
0005434639646	23397	45	23A
0005433202459	23397	46	23B
0005432328815	21104	1	1C
0005432054342	21104	2	1F
0005432329035	21104	3	1D
0005432329061	21104	4	2A
0005432383279	21104	5	2C
0005432328869	21104	6	2D
0005432383523	21104	7	2F
0005432054343	21104	8	3D
0005432383261	21104	9	3F
0005432383140	21104	10	4D
0005432328860	21104	11	4E
0005432328955	21104	12	4F
0005432383230	21104	13	5A
0005432383522	21104	14	5C
0005432383439	21104	15	5D
0005432328943	21104	16	5E
0005432383266	21104	17	5F
0005432848844	21104	18	6A
0005432328942	21104	19	6C
0005432328724	21104	20	6F
0005432329036	21104	21	7A
0005432383400	21104	22	7C
0005432383368	21104	23	7D
0005432383190	21104	24	7E
0005432328823	21104	25	7F
0005432383265	21104	26	8C
0005432328927	21104	27	8D
0005432383326	21104	28	8E
0005432329009	21104	29	8F
0005432328670	21104	30	9A
0005432383402	21104	31	9C
0005432328913	21104	32	9D
0005432383274	21104	33	9E
0005432329008	21104	34	10A
0005432054345	21104	35	10C
0005432328835	21104	36	10D
0005432383273	21104	37	10E
0005432383421	21104	38	10F
0005432328630	21104	39	11A
0005432054344	21104	40	11C
0005432383236	21104	41	11D
0005432383275	21104	42	11E
0005432328852	21104	43	11F
0005432328778	21104	44	12A
0005432383444	21104	45	12C
0005432383314	21104	46	12D
0005432328571	21104	47	12E
0005432328856	21104	48	12F
0005432848845	21104	49	13C
0005432329087	21104	50	13E
0005432328868	21104	51	13D
0005432328902	21104	52	13F
0005432328671	21104	53	14A
0005432848846	21104	54	14C
0005432328956	21104	55	14D
0005432383297	21104	56	14E
0005432329016	21104	57	14F
0005432328715	21104	58	15A
0005432329034	21104	59	15C
0005432329086	21104	60	15D
0005432848843	21104	61	15E
0005432328848	21104	62	15F
0005432383235	21104	63	16A
0005432328464	21104	64	16C
0005432328909	21104	65	16D
0005432383376	21104	66	16E
0005432383375	21104	67	16F
0005432328881	21104	68	17A
0005432383267	21104	69	17C
0005432328954	21104	70	17D
0005432328732	21104	71	17F
0005432328822	21104	72	18C
0005432383440	21104	73	18E
0005432383399	21104	74	18F
0005432383234	21104	75	19A
0005432383233	21104	76	19C
0005432329081	21104	77	19D
0005432383333	21104	78	19E
0005432383403	21104	79	20A
0005432383315	21104	80	20C
0005432383139	21104	81	20D
0005432383302	21104	82	20E
0005432383229	21104	83	20F
0005432383640	31233	1	1C
0005432329254	31233	2	1D
0005432329284	31233	3	1F
0005432329259	31233	4	2A
0005432329290	31233	5	2C
0005432287255	31233	6	2D
0005432329292	31233	7	2F
0005432383670	31233	8	3A
0005432383674	31233	9	3D
0005432383641	31233	10	3C
0005432329282	31233	11	3F
0005432287253	31233	12	4A
0005432383645	31233	13	4C
0005432329261	31233	14	4D
0005432329277	31233	15	4E
0005432329281	31233	16	4F
0005432329260	31233	17	5A
0005432329269	31233	18	5C
0005432329287	31233	19	5D
0005432287252	31233	20	5E
0005432287254	31233	21	5F
0005432329297	31233	22	6A
0005432329285	31233	23	6C
0005432383679	31233	24	6D
0005432329253	31233	25	6E
0005432383667	31233	26	6F
0005432329262	31233	27	7A
0005432329298	31233	28	7C
0005432383677	31233	29	7D
0005432287251	31233	30	7E
0005432329270	31233	31	7F
0005432383644	31233	32	8A
0005432329272	31233	33	8C
0005432383662	31233	34	8D
0005432383664	31233	35	8E
0005432383653	31233	36	8F
0005432383650	31233	37	9A
0005432383654	31233	38	9D
0005432383643	31233	39	9E
0005432383665	31233	40	9F
0005432329274	31233	41	10A
0005432383668	31233	42	10C
0005432329289	31233	43	10D
0005432383657	31233	44	10E
0005432329293	31233	45	10F
0005432383649	31233	46	11A
0005432383647	31233	47	11C
0005432329268	31233	48	11D
0005432383661	31233	49	11E
0005432383656	31233	50	11F
0005432383652	31233	51	12A
0005432383660	31233	52	12C
0005432383648	31233	53	12D
0005432329266	31233	54	12E
0005432383659	31233	55	13A
0005432329258	31233	56	13C
0005432329295	31233	57	13D
0005432329267	31233	58	13E
0005432329278	31233	59	13F
0005432383658	31233	60	14A
0005432329275	31233	61	14C
0005432329288	31233	62	14D
0005432329257	31233	63	14F
0005432383673	31233	64	15A
0005432329276	31233	65	15C
0005432329273	31233	66	15D
0005432383651	31233	67	15E
0005432329264	31233	68	15F
0005432383639	31233	69	16A
0005432383666	31233	70	16C
0005432329294	31233	71	16D
0005432329271	31233	72	16E
0005432383646	31233	73	17A
0005432329280	31233	74	17C
0005432383671	31233	75	17D
0005432329296	31233	76	17E
0005432383678	31233	77	17F
0005432329283	31233	78	18A
0005432383669	31233	79	18C
0005432383663	31233	80	18D
0005432329256	31233	81	18E
0005432383655	31233	82	18F
0005432329279	31233	83	19A
0005432329263	31233	84	19C
0005432329291	31233	85	19D
0005432383642	31233	86	19E
0005432383676	31233	87	19F
0005432329286	31233	88	20A
0005432383672	31233	89	20C
0005432383675	31233	90	20D
0005432329265	31233	91	20E
0005432329255	31233	92	20F
0005433642541	2473	1	1C
0005432953976	2473	2	1D
0005433642528	2473	3	2C
0005433642542	2473	4	4A
0005433642521	2473	5	4C
0005433642538	2473	6	4D
0005433642527	2473	7	4E
0005433642531	2473	8	4F
0005433642532	2473	9	5A
0005432953969	2473	10	5C
0005432953962	2473	11	5D
0005433642533	2473	12	5E
0005433642537	2473	13	6C
0005433642526	2473	14	6E
0005433642549	2473	15	7A
0005432953943	2473	16	8A
0005433642520	2473	17	8E
0005432953945	2473	18	9C
0005432953946	2473	19	9D
0005433642546	2473	20	9E
0005432953985	2473	21	9F
0005432953940	2473	22	10C
0005433642529	2473	23	10D
0005432953982	2473	24	10F
0005433642539	2473	25	11A
0005433642524	2473	26	11C
0005432953981	2473	27	11D
0005432954010	2473	28	11E
0005432953984	2473	29	11F
0005433642548	2473	30	12C
0005433642543	2473	31	12D
0005433642547	2473	32	12E
0005433642534	2473	33	13A
0005433642544	2473	34	14E
0005433642523	2473	35	15C
0005432953968	2473	36	15D
0005432954011	2473	37	15E
0005433642540	2473	38	16C
0005432953983	2473	39	16E
0005432953958	2473	40	17A
0005433642530	2473	41	17C
0005433642536	2473	42	17D
0005433642545	2473	43	18F
0005433642525	2473	44	19A
0005432953957	2473	45	19C
0005433642522	2473	46	19E
0005432953993	2473	47	19F
0005432953939	2473	48	20A
0005432953967	2473	49	20C
0005433642535	2473	50	20F
0005433642432	27589	1	1C
0005433642468	27589	2	2A
0005433642442	27589	3	2C
0005433642397	27589	4	2D
0005432954037	27589	5	2F
0005433642375	27589	6	3C
0005432954042	27589	7	3D
0005433642390	27589	8	3F
0005432954029	27589	9	4A
0005433642433	27589	10	4C
0005432954030	27589	11	4D
0005433642392	27589	12	4E
0005433642449	27589	13	4F
0005432954036	27589	14	5C
0005432954038	27589	15	5D
0005432954054	27589	16	5E
0005432954048	27589	17	5F
0005433642369	27589	18	6F
0005433642325	27589	19	7A
0005433642336	27589	20	7C
0005433642393	27589	21	7E
0005433642434	27589	22	7F
0005433642398	27589	23	8A
0005433642335	27589	24	8C
0005433642337	27589	25	8D
0005432954053	27589	26	9A
0005433642377	27589	27	9C
0005433642288	27589	28	9D
0005433642408	27589	29	9E
0005433642348	27589	30	9F
0005433642338	27589	31	10C
0005432954043	27589	32	10D
0005432954041	27589	33	10E
0005433642443	27589	34	11D
0005432954045	27589	35	11E
0005432954044	27589	36	12A
0005433642436	27589	37	12D
0005433642312	27589	38	12F
0005432954050	27589	39	13A
0005432954033	27589	40	13E
0005432954052	27589	41	13F
0005433642401	27589	42	14A
0005433642452	27589	43	14C
0005433642395	27589	44	14E
0005433642403	27589	45	14F
0005433642402	27589	46	15A
0005432954051	27589	47	15C
0005432954032	27589	48	15D
0005432954035	27589	49	15F
0005432954040	27589	50	16A
0005433642326	27589	51	16C
0005432954039	27589	52	16D
0005433642448	27589	53	16F
0005433642467	27589	54	17C
0005433642444	27589	55	17D
0005432954031	27589	56	17E
0005432954034	27589	57	17F
0005432954049	27589	58	18A
0005433642400	27589	59	18C
0005433642435	27589	60	18D
0005433642445	27589	61	18E
0005433642378	27589	62	19A
0005432954046	27589	63	19C
0005433642396	27589	64	19D
0005433642437	27589	65	19F
0005433642414	27589	66	20A
0005433642370	27589	67	20D
0005432954047	27589	68	20E
0005433642391	27589	69	20F
0005432425033	13350	1	1A
0005432425032	13350	2	1F
0005432425025	13350	3	2A
0005432425057	13350	4	2D
0005432425036	13350	5	2F
0005432425009	13350	6	3A
0005432425022	13350	7	4A
0005432425017	13350	8	4C
0005432425028	13350	9	4E
0005432425026	13350	10	4F
0005432425066	13350	11	5A
0005432425052	13350	12	5C
0005432425029	13350	13	5D
0005432425047	13350	14	5E
0005432425039	13350	15	6A
0005432425027	13350	16	6F
0005432425018	13350	17	7A
0005432425059	13350	18	7C
0005432425064	13350	19	7D
0005432425011	13350	20	7E
0005432425073	13350	21	7F
0005432425037	13350	22	8A
0005432425075	13350	23	8C
0005432425016	13350	24	8D
0005432425040	13350	25	8E
0005432425050	13350	26	8F
0005432425042	13350	27	9C
0005432425072	13350	28	9E
0005432425034	13350	29	10A
0005432425063	13350	30	10C
0005432425061	13350	31	10F
0005432425054	13350	32	11C
0005432425048	13350	33	11F
0005432425031	13350	34	12C
0005432425046	13350	35	12E
0005432425070	13350	36	13A
0005432425043	13350	37	12F
0005432425010	13350	38	13C
0005432425055	13350	39	13E
0005432425062	13350	40	14A
0005432425067	13350	41	14C
0005432425044	13350	42	14D
0005432425024	13350	43	14E
0005432425056	13350	44	14F
0005432425049	13350	45	15D
0005432425013	13350	46	15E
0005432425058	13350	47	15F
0005432425019	13350	48	16A
0005432425015	13350	49	16C
0005432425071	13350	50	16E
0005432425035	13350	51	16F
0005432425023	13350	52	17A
0005432425069	13350	53	17D
0005432425038	13350	54	17E
0005432425020	13350	55	17F
0005432425030	13350	56	18A
0005432425053	13350	57	18C
0005432425012	13350	58	18D
0005432425060	13350	59	18E
0005432425014	13350	60	19A
0005432425021	13350	61	19C
0005432425041	13350	62	19D
0005432425051	13350	63	19E
0005432425045	13350	64	19F
0005432425074	13350	65	20A
0005432425065	13350	66	20C
0005432425068	13350	67	20E
0005432424635	30706	1	1D
0005432424338	30706	2	2A
0005432424491	30706	3	4C
0005432424595	30706	4	4F
0005432424582	30706	5	6A
0005432424638	30706	6	6D
0005432424587	30706	7	7A
0005432424632	30706	8	7E
0005432424537	30706	9	7F
0005432424647	30706	10	8C
0005432424515	30706	11	8E
0005432424650	30706	12	8F
0005432424631	30706	13	9A
0005432424393	30706	14	9D
0005432424603	30706	15	9F
0005432424609	30706	16	10A
0005432424629	30706	17	10C
0005432424577	30706	18	10D
0005432424525	30706	19	10E
0005432424664	30706	20	10F
0005432424538	30706	21	11A
0005432424614	30706	22	11C
0005432424634	30706	23	11D
0005432424620	30706	24	11E
0005432424469	30706	25	11F
0005432424627	30706	26	12A
0005432424474	30706	27	12E
0005432424471	30706	28	12F
0005432424600	30706	29	13D
0005432424448	30706	30	13E
0005432424606	30706	31	14A
0005432424670	30706	32	14C
0005432424637	30706	33	14D
0005432424378	30706	34	14F
0005432424663	30706	35	15C
0005432424510	30706	36	15E
0005432424583	30706	37	16A
0005432424578	30706	38	16C
0005432424630	30706	39	16D
0005432424633	30706	40	17A
0005432424654	30706	41	17C
0005432424590	30706	42	17D
0005432424584	30706	43	17E
0005432424673	30706	44	18A
0005432424619	30706	45	18C
0005432424526	30706	46	18E
0005432424639	30706	47	19A
0005432424473	30706	48	19C
0005432424626	30706	49	19E
0005432424379	30706	50	19F
0005432424601	30706	51	20C
0005432424470	30706	52	20F
0005432817857	9630	1	1C
0005432817873	9630	2	1F
0005432822307	9630	3	1D
0005432822306	9630	4	2D
0005432817851	9630	5	2F
0005432901718	9630	6	3D
0005432817861	9630	7	4A
0005432901599	9630	8	4D
0005432901655	9630	9	4F
0005432817868	9630	10	5A
0005432901689	9630	11	5C
0005432822303	9630	12	5D
0005432817859	9630	13	5F
0005432822308	9630	14	6A
0005434448360	9630	15	6D
0005432817852	9630	16	6E
0005432901688	9630	17	6F
0005434448362	9630	18	7A
0005432817850	9630	19	7E
0005432901638	9630	20	7F
0005432822309	9630	21	8C
0005432901716	9630	22	8E
0005432901677	9630	23	9A
0005434448361	9630	24	9D
0005432901667	9630	25	10C
0005434157538	9630	26	10D
0005432817855	9630	27	10E
0005432901755	9630	28	11A
0005432901742	9630	29	11C
0005432289030	9630	30	11D
0005432901687	9630	31	11E
0005432817871	9630	32	11F
0005432901717	9630	33	12A
0005432817863	9630	34	12C
0005432901583	9630	35	12D
0005432817866	9630	36	12E
0005432817872	9630	37	12F
0005432817867	9630	38	13A
0005432817856	9630	39	13C
0005432289031	9630	40	13D
0005432289032	9630	41	13E
0005432817862	9630	42	13F
0005432901696	9630	43	14A
0005432817878	9630	44	14C
0005432817876	9630	45	14E
0005432901758	9630	46	14F
0005432901668	9630	47	15A
0005432901654	9630	48	15D
0005432817879	9630	49	15F
0005432289028	9630	50	16A
0005432822305	9630	51	16C
0005432901582	9630	52	16D
0005432822302	9630	53	16E
0005432901769	9630	54	16F
0005432901695	9630	55	17C
0005432901653	9630	56	17D
0005432817875	9630	57	17F
0005432822304	9630	58	18A
0005432817860	9630	59	18C
0005432901690	9630	60	18D
0005432817858	9630	61	18E
0005432817864	9630	62	18F
0005432817877	9630	63	19A
0005432817854	9630	64	19C
0005432817870	9630	65	19D
0005432289029	9630	66	19E
0005432817869	9630	67	19F
0005432817865	9630	68	20A
0005432817853	9630	69	20D
0005432817874	9630	70	20E
0005432901686	9630	71	20F
0005432901837	28960	1	1A
0005434157584	28960	2	1C
0005432901843	28960	3	1D
0005432817503	28960	4	1F
0005432817689	28960	5	2D
0005432822209	28960	6	3A
0005432901839	28960	7	3C
0005434448333	28960	8	4A
0005432901846	28960	9	4C
0005432817597	28960	10	4D
0005432817752	28960	11	4F
0005432817660	28960	12	5C
0005432822248	28960	13	5D
0005432817507	28960	14	5E
0005432822256	28960	15	5F
0005434157581	28960	16	6A
0005432901838	28960	17	6E
0005432817751	28960	18	6F
0005432822273	28960	19	7C
0005432901850	28960	20	7D
0005432817570	28960	21	7E
0005432817609	28960	22	7F
0005432901848	28960	23	8E
0005434186237	28960	24	8F
0005432817512	28960	25	9A
0005434186235	28960	26	9D
0005432817571	28960	27	10E
0005434448332	28960	28	10F
0005432901840	28960	29	11A
0005432817537	28960	30	12A
0005432817665	28960	31	12D
0005434157586	28960	32	12E
0005434157583	28960	33	13C
0005434157580	28960	34	13D
0005432822257	28960	35	13F
0005432901842	28960	36	14A
0005432817596	28960	37	14C
0005432822210	28960	38	14D
0005434157579	28960	39	14E
0005434448334	28960	40	15A
0005432901847	28960	41	15C
0005432901836	28960	42	15E
0005432901835	28960	43	15F
0005432901844	28960	44	16A
0005434157582	28960	45	16D
0005432901845	28960	46	16E
0005432901841	28960	47	17A
0005434186234	28960	48	17D
0005432817526	28960	49	17E
0005434448335	28960	50	17F
0005432901849	28960	51	18C
0005432822208	28960	52	18D
0005434186236	28960	53	19A
0005434157585	28960	54	19E
0005432822247	28960	55	20C
0005432817582	28960	56	20D
0005432822271	28960	57	20E
0005432611760	15077	1	1B
0005432613917	15077	2	2B
0005432611761	15077	3	3A
0005432613915	15077	4	3B
0005432613914	15077	5	4A
0005432611762	15077	6	4B
0005432613916	15077	7	5A
0005432611763	15077	8	5B
0005432613918	15077	9	6A
0005432611759	15077	10	6B
0005432607590	31603	1	1A
0005432607575	31603	2	1B
0005432607593	31603	3	2B
0005432607591	31603	4	3A
0005432607571	31603	5	3B
0005432607576	31603	6	4A
0005432607570	31603	7	4B
0005432611738	31603	8	5A
0005432611715	31603	9	5B
0005432611726	31603	10	6A
0005432611727	31603	11	6B
0005433569767	11869	1	1C
0005432948764	11869	2	1A
0005432948543	11869	3	1F
0005432948491	11869	4	1D
0005433569806	11869	5	2A
0005432948641	11869	6	2D
0005433569813	11869	7	2C
0005433569772	11869	8	3A
0005433569795	11869	9	2F
0005432948683	11869	10	3D
0005433569787	11869	11	3C
0005433569798	11869	12	3F
0005432948727	11869	13	4C
0005433569807	11869	14	4A
0005433569834	11869	15	4F
0005432948458	11869	16	4D
0005433569778	11869	17	5C
0005433569782	11869	18	5A
0005433569824	11869	19	5F
0005433569805	11869	20	5D
0005432948681	11869	21	6B
0005433569784	11869	22	6A
0005433569786	11869	23	6D
0005433569835	11869	24	6C
0005433569779	11869	25	6E
0005433569771	11869	26	7A
0005432948632	11869	27	6F
0005432948731	11869	28	7B
0005432948672	11869	29	7D
0005432948765	11869	30	7F
0005432948475	11869	31	7E
0005433569775	11869	32	8C
0005433569822	11869	33	8B
0005433569797	11869	34	8A
0005432948763	11869	35	8F
0005433569788	11869	36	8E
0005433569816	11869	37	9A
0005433569769	11869	38	9D
0005433569785	11869	39	9C
0005433569814	11869	40	9B
0005433569776	11869	41	9E
0005432948447	11869	42	10A
0005433569780	11869	43	9F
0005432948619	11869	44	10C
0005432948430	11869	45	10B
0005432948640	11869	46	10E
0005433569819	11869	47	10D
0005432948599	11869	48	11A
0005433569801	11869	49	10F
0005433569803	11869	50	11B
0005432948454	11869	51	11D
0005433569781	11869	52	11C
0005433569799	11869	53	11F
0005432948670	11869	54	11E
0005432948790	11869	55	12B
0005433569820	11869	56	12A
0005432948679	11869	57	12D
0005432948474	11869	58	12C
0005433569789	11869	59	12F
0005433569804	11869	60	12E
0005432948431	11869	61	13A
0005432948492	11869	62	13D
0005433569812	11869	63	13C
0005433569818	11869	64	13B
0005432948674	11869	65	13E
0005432948631	11869	66	14A
0005432948663	11869	67	13F
0005433569831	11869	68	14B
0005433569821	11869	69	14E
0005433569809	11869	70	14D
0005433569773	11869	71	14C
0005432948636	11869	72	14F
0005433569808	11869	73	15B
0005433569802	11869	74	15A
0005432948666	11869	75	15C
0005433569823	11869	76	15E
0005433569770	11869	77	15D
0005432948598	11869	78	16A
0005433569817	11869	79	15F
0005433569800	11869	80	16C
0005433569794	11869	81	16B
0005433569783	11869	82	16D
0005433569836	11869	83	17A
0005433569811	11869	84	16E
0005433569830	11869	85	17B
0005433569774	11869	86	17D
0005432948586	11869	87	17F
0005432948680	11869	88	17E
0005433569777	11869	89	18B
0005433569768	11869	90	18A
0005432948801	11869	91	18D
0005433569829	11869	92	18C
0005433569796	11869	93	18E
0005433569827	11869	94	19C
0005433569833	11869	95	19B
0005433569815	11869	96	19A
0005433569825	11869	97	19D
0005432948673	11869	98	20A
0005433569792	11869	99	19F
0005433569826	11869	100	19E
0005433569832	11869	101	20B
0005432948544	11869	102	20C
0005432948740	11869	103	20E
0005433569790	11869	104	20D
0005432948485	11869	105	21A
0005432948570	11869	106	20F
0005433569810	11869	107	21C
0005433569793	11869	108	21E
0005433569828	11869	109	21D
0005433569791	11869	110	21F
0005432949026	25276	1	1C
0005433569353	25276	2	1A
0005433569227	25276	3	1F
0005433569403	25276	4	1D
0005432949053	25276	5	2D
0005433569099	25276	6	2C
0005432949032	25276	7	3A
0005433569314	25276	8	3D
0005432949055	25276	9	3C
0005432949023	25276	10	4A
0005433568987	25276	11	3F
0005433569141	25276	12	4D
0005433569268	25276	13	4C
0005432949046	25276	14	5C
0005433569077	25276	15	5F
0005432949034	25276	16	5D
0005432949040	25276	17	6B
0005432949041	25276	18	6A
0005432949021	25276	19	6C
0005432949018	25276	20	6E
0005433569150	25276	21	6D
0005432949047	25276	22	7C
0005433569251	25276	23	7B
0005432949037	25276	24	7D
0005433569315	25276	25	8A
0005433569210	25276	26	7F
0005432949027	25276	27	8B
0005433569495	25276	28	8D
0005432949028	25276	29	8F
0005432949033	25276	30	8E
0005433569187	25276	31	9A
0005433569181	25276	32	9E
0005433569306	25276	33	10B
0005433569263	25276	34	10C
0005433569252	25276	35	10D
0005432949051	25276	36	11A
0005433569404	25276	37	10F
0005432949048	25276	38	10E
0005433569417	25276	39	11C
0005433569400	25276	40	11B
0005433569191	25276	41	11D
0005432949022	25276	42	11F
0005433569211	25276	43	11E
0005433569432	25276	44	12B
0005433569189	25276	45	12A
0005433569289	25276	46	12D
0005432949024	25276	47	12C
0005432949019	25276	48	12F
0005433569430	25276	49	12E
0005433569325	25276	50	13A
0005432949015	25276	51	13C
0005433569516	25276	52	13B
0005433569022	25276	53	13E
0005432949031	25276	54	14C
0005433569020	25276	55	14B
0005432949054	25276	56	14A
0005432949017	25276	57	14D
0005433569452	25276	58	14F
0005432949029	25276	59	14E
0005433569078	25276	60	15B
0005432949056	25276	61	15A
0005433569226	25276	62	15D
0005433569259	25276	63	15C
0005432949049	25276	64	15E
0005432949020	25276	65	16A
0005433569034	25276	66	16C
0005433569388	25276	67	16D
0005433569515	25276	68	17A
0005432949050	25276	69	16F
0005433569354	25276	70	16E
0005433569426	25276	71	17E
0005433569310	25276	72	17D
0005433569035	25276	73	17C
0005432949038	25276	74	17F
0005432949039	25276	75	18B
0005432949045	25276	76	18A
0005432949052	25276	77	18C
0005433569021	25276	78	18F
0005433569401	25276	79	18E
0005432949016	25276	80	18D
0005432949042	25276	81	19A
0005433569305	25276	82	19C
0005433569385	25276	83	19B
0005433569216	25276	84	19F
0005433569433	25276	85	19E
0005432949035	25276	86	20B
0005432949043	25276	87	20A
0005432949044	25276	88	20D
0005433569190	25276	89	20F
0005433569382	25276	90	20E
0005432949036	25276	91	21B
0005433569266	25276	92	21C
0005432949025	25276	93	21D
0005432949030	25276	94	21F
0005434656583	5365	1	1A
0005435555386	5365	2	1C
0005435340385	5365	3	1F
0005434655074	5365	4	3C
0005435340316	5365	5	3A
0005435340334	5365	6	3D
0005434655066	5365	7	3F
0005435340335	5365	8	4D
0005434655078	5365	9	4F
0005434655083	5365	10	5C
0005434655064	5365	11	5D
0005434655069	5365	12	5E
0005434655065	5365	13	6A
0005434655082	5365	14	6D
0005432114245	5365	15	6E
0005435555385	5365	16	6F
0005435340384	5365	17	7A
0005435340345	5365	18	8D
0005435340342	5365	19	8E
0005434655061	5365	20	9A
0005434655084	5365	21	9C
0005432114247	5365	22	9F
0005434655076	5365	23	10A
0005432114244	5365	24	10E
0005432114246	5365	25	10F
0005434655081	5365	26	11A
0005434655073	5365	27	11C
0005434655070	5365	28	11D
0005434655060	5365	29	11E
0005434655067	5365	30	11F
0005434655062	5365	31	12C
0005435340377	5365	32	12E
0005434655071	5365	33	13D
0005434655058	5365	34	13F
0005435340297	5365	35	14A
0005434655072	5365	36	14F
0005435340279	5365	37	15C
0005434655059	5365	38	15D
0005434655057	5365	39	15F
0005434655079	5365	40	16A
0005434655063	5365	41	16C
0005435340379	5365	42	16D
0005434655075	5365	43	17A
0005434655068	5365	44	17C
0005435340321	5365	45	17D
0005434655077	5365	46	17E
0005434655080	5365	47	18E
0005434655085	5365	48	18F
0005434655056	5365	49	19C
0005435555382	5365	50	20E
0005435555387	5365	51	20F
0005434654769	12515	1	1A
0005435555400	12515	2	1F
0005434654836	12515	3	2A
0005435340459	12515	4	2C
0005434654927	12515	5	2F
0005435340470	12515	6	3C
0005434654919	12515	7	3D
0005435340461	12515	8	3F
0005435340468	12515	9	4A
0005435340466	12515	10	4E
0005434654893	12515	11	4F
0005434654835	12515	12	5C
0005434654874	12515	13	5D
0005435340457	12515	14	5F
0005434654801	12515	15	6C
0005435555398	12515	16	6D
0005434654796	12515	17	7C
0005434654873	12515	18	7D
0005434654820	12515	19	8D
0005435340471	12515	20	8F
0005434654797	12515	21	9C
0005434654916	12515	22	10A
0005434654847	12515	23	10C
0005434654867	12515	24	10E
0005435340462	12515	25	10F
0005434654821	12515	26	11D
0005434654930	12515	27	11F
0005434654859	12515	28	12A
0005434654965	12515	29	12C
0005434654760	12515	30	12D
0005434654880	12515	31	12E
0005434654772	12515	32	12F
0005434654825	12515	33	13C
0005434654879	12515	34	13D
0005434654811	12515	35	13E
0005434654831	12515	36	14A
0005434654809	12515	37	14D
0005434654812	12515	38	14E
0005434656560	12515	39	14F
0005434654824	12515	40	15C
0005434654846	12515	41	15D
0005434654864	12515	42	16C
0005435340464	12515	43	16D
0005434654773	12515	44	16E
0005434654858	12515	45	16F
0005435340460	12515	46	17A
0005435555399	12515	47	17C
0005435340463	12515	48	17D
0005435340458	12515	49	18C
0005434654895	12515	50	18E
0005435340469	12515	51	18F
0005434656571	12515	52	19A
0005435555397	12515	53	19E
0005435340465	12515	54	19F
0005435340467	12515	55	20A
0005434654777	12515	56	20D
0005434654872	12515	57	20F
0005432078182	7462	1	1C
0005433716613	7462	2	1A
0005433716625	7462	3	1D
0005432428950	7462	4	2A
0005433716652	7462	5	1F
0005433716641	7462	6	2C
0005433716626	7462	7	2D
0005435266144	7462	8	3A
0005433716642	7462	9	3F
0005433716635	7462	10	4A
0005433716609	7462	11	4C
0005433716638	7462	12	4E
0005432078181	7462	13	4F
0005433716624	7462	14	5A
0005433716615	7462	15	5C
0005433716634	7462	16	5D
0005433719185	7462	17	5F
0005433716606	7462	18	5E
0005433722308	7462	19	6A
0005433716602	7462	20	6F
0005433716647	7462	21	7B
0005433716620	7462	22	7A
0005433716630	7462	23	7D
0005433722306	7462	24	8B
0005433722304	7462	25	9A
0005433719182	7462	26	8F
0005432428949	7462	27	9B
0005433716611	7462	28	9C
0005435266150	7462	29	9D
0005433690949	7462	30	9F
0005433716607	7462	31	10B
0005432078180	7462	32	11A
0005432078179	7462	33	10E
0005433716618	7462	34	11B
0005433716639	7462	35	11D
0005433716608	7462	36	12D
0005435266153	7462	37	12C
0005433716645	7462	38	12F
0005433688835	7462	39	13B
0005433716644	7462	40	13D
0005435266145	7462	41	13C
0005433716616	7462	42	13E
0005433716623	7462	43	13F
0005435266136	7462	44	14B
0005433716633	7462	45	14A
0005433716631	7462	46	15A
0005433716619	7462	47	15C
0005433690950	7462	48	15B
0005432078183	7462	49	15D
0005433716610	7462	50	15E
0005433716629	7462	51	15F
0005433716646	7462	52	16B
0005433716603	7462	53	16C
0005433716648	7462	54	16E
0005433716612	7462	55	17C
0005433719184	7462	56	17D
0005433716621	7462	57	17F
0005433722303	7462	58	17E
0005435266155	7462	59	18A
0005433719183	7462	60	18B
0005433716649	7462	61	18D
0005433688837	7462	62	18C
0005433716643	7462	63	18E
0005435266156	7462	64	18F
0005433716604	7462	65	19A
0005433716650	7462	66	19C
0005433656713	7462	67	19B
0005433716617	7462	68	19E
0005433716627	7462	69	19D
0005433716651	7462	70	20A
0005433688836	7462	71	20C
0005433716637	7462	72	20B
0005433688834	7462	73	20D
0005433722305	7462	74	20F
0005433656712	7462	75	21A
0005433716628	7462	76	21C
0005433716632	7462	77	21D
0005433716640	7462	78	21E
0005433716622	7462	79	22A
0005432428951	7462	80	21F
0005433716605	7462	81	22D
0005433716614	7462	82	23A
0005433716636	7462	83	22F
0005433722307	7462	84	23D
0005435266154	7462	85	23E
0005433689938	7462	86	23F
0005433716148	29239	1	7E
0005433656672	29239	2	1A
0005433722276	29239	3	1C
0005433716290	29239	4	1F
0005433685525	29239	5	2C
0005432428973	29239	6	2D
0005433716043	29239	7	3A
0005433716177	29239	8	3D
0005433716231	29239	9	3F
0005433685523	29239	10	4A
0005433715974	29239	11	4C
0005432006800	29239	12	4B
0005433716203	29239	13	4D
0005433716268	29239	14	4E
0005435266203	29239	15	4F
0005433716254	29239	16	5B
0005433716012	29239	17	5A
0005433722249	29239	18	5C
0005433716038	29239	19	5D
0005433716128	29239	20	5F
0005433716315	29239	21	5E
0005433716037	29239	22	6B
0005433715966	29239	23	6D
0005433722254	29239	24	6E
0005433722239	29239	25	7A
0005433716105	29239	26	7B
0005432006802	29239	27	7D
0005433685533	29239	28	7C
0005433716042	29239	29	8A
0005433716267	29239	30	7F
0005433716386	29239	31	8B
0005433716176	29239	32	8E
0005433719143	29239	33	8D
0005433716092	29239	34	8F
0005433722255	29239	35	9A
0005433716255	29239	36	9B
0005433716107	29239	37	9C
0005433722233	29239	38	9E
0005435266201	29239	39	9D
0005433719154	29239	40	10C
0005432006803	29239	41	10B
0005433719135	29239	42	10D
0005432006799	29239	43	11A
0005433685522	29239	44	11B
0005433716385	29239	45	11D
0005433716289	29239	46	11C
0005433656688	29239	47	11E
0005433656695	29239	48	11F
0005433716013	29239	49	12A
0005433722256	29239	50	12C
0005433716205	29239	51	12B
0005433716295	29239	52	12D
0005433722241	29239	53	12E
0005433716027	29239	54	13A
0005433716021	29239	55	12F
0005433722240	29239	56	13C
0005433716281	29239	57	13B
0005433716219	29239	58	13D
0005433716361	29239	59	13F
0005433722274	29239	60	14C
0005433722246	29239	61	14E
0005433716334	29239	62	14F
0005433722243	29239	63	15B
0005433716218	29239	64	15A
0005433715996	29239	65	15C
0005433716435	29239	66	15D
0005433722275	29239	67	15E
0005432006801	29239	68	16A
0005433722244	29239	69	16B
0005433722232	29239	70	16C
0005433716065	29239	71	16D
0005433722252	29239	72	16F
0005433716364	29239	73	17A
0005433716303	29239	74	17C
0005433716086	29239	75	17E
0005433716359	29239	76	17D
0005433716314	29239	77	18A
0005435266202	29239	78	18B
0005433716169	29239	79	18D
0005433716279	29239	80	18E
0005433716020	29239	81	19A
0005433719146	29239	82	18F
0005433719163	29239	83	19B
0005433722242	29239	84	19D
0005433685521	29239	85	19C
0005433716360	29239	86	19F
0005433716001	29239	87	20A
0005433716028	29239	88	20C
0005433716391	29239	89	20E
0005433716106	29239	90	20F
0005433716327	29239	91	21A
0005433656696	29239	92	21C
0005433716363	29239	93	21E
0005433716067	29239	94	22A
0005433719161	29239	95	21F
0005432428975	29239	96	22B
0005433716066	29239	97	22C
0005433716204	29239	98	22D
0005433716280	29239	99	22E
0005433716129	29239	100	23A
0005433685532	29239	101	22F
0005432428974	29239	102	23C
0005433716014	29239	103	23D
0005433716002	29239	104	23F
0005433719166	29239	105	23E
0005434182235	8705	1	5C
0005434182287	8705	2	7A
0005434095467	8705	3	7E
0005434182234	8705	4	8C
0005434184680	8705	5	9A
0005434095459	8705	6	9D
0005434182291	8705	7	9F
0005434095461	8705	8	10E
0005434182255	8705	9	11A
0005434182240	8705	10	11C
0005434095466	8705	11	12D
0005434095470	8705	12	13A
0005434182239	8705	13	14A
0005434095471	8705	14	14C
0005434095462	8705	15	14E
0005434182265	8705	16	15C
0005434182218	8705	17	16C
0005434095463	8705	18	16D
0005434182195	8705	19	16F
0005434095464	8705	20	18D
0005434182264	8705	21	20A
0005434182263	8705	22	20C
0005434182219	8705	23	20D
0005434095468	8705	24	1D
0005434184681	8705	25	20E
0005434182333	8705	26	20F
0005434182254	8705	27	3C
0005434095469	8705	28	4C
0005434182236	8705	29	4D
0005434095460	8705	30	4E
0005434095465	8705	31	4F
0005434095472	8705	32	5A
0005434182334	8705	33	2F
0005434184676	8705	34	1C
0005434184674	8705	35	1A
0005434095369	11671	1	20E
0005434095367	11671	2	17F
0005434184689	11671	3	1A
0005434095406	11671	4	1F
0005434182349	11671	5	2A
0005434095330	11671	6	2D
0005434095338	11671	7	3D
0005434095271	11671	8	4D
0005434095329	11671	9	4E
0005434182353	11671	10	5A
0005434143730	11671	11	6D
0005434182354	11671	12	6F
0005434095324	11671	13	7E
0005434182356	11671	14	8E
0005434143740	11671	15	9A
0005434095370	11671	16	9C
0005434095337	11671	17	9D
0005434182350	11671	18	10C
0005434095368	11671	19	10F
0005434184690	11671	20	11D
0005434095360	11671	21	13A
0005434182346	11671	22	13D
0005434143739	11671	23	14E
0005434095348	11671	24	14F
0005434183605	11671	25	15A
0005434182351	11671	26	15C
0005434183604	11671	27	15E
0005434182345	11671	28	16C
0005434182352	11671	29	16D
0005434095383	11671	30	17A
0005434182348	11671	31	17D
0005434182347	11671	32	17E
0005434182355	11671	33	18C
0005434095328	11671	34	18D
0005434143733	11671	35	18F
0005434095373	11671	36	20A
0005433398242	1437	1	20E
0005433398111	1437	2	20F
0005433398058	1437	3	17E
0005433398148	1437	4	1A
0005435732498	1437	5	1C
0005435732495	1437	6	1D
0005433457023	1437	7	1F
0005433398401	1437	8	2C
0005435732502	1437	9	2D
0005433398368	1437	10	2F
0005435732493	1437	11	3A
0005433398237	1437	12	3C
0005433398112	1437	13	3D
0005433398182	1437	14	3F
0005433398230	1437	15	4A
0005433398303	1437	16	4C
0005435732499	1437	17	4D
0005435732505	1437	18	4F
0005433457022	1437	19	5A
0005433398304	1437	20	5D
0005433398203	1437	21	5E
0005433398239	1437	22	5F
0005433398422	1437	23	6A
0005433457021	1437	24	6C
0005433398334	1437	25	6D
0005435732511	1437	26	6F
0005435732507	1437	27	7A
0005433398403	1437	28	7C
0005432297311	1437	29	7D
0005435732497	1437	30	7E
0005435732494	1437	31	8A
0005433398204	1437	32	8C
0005433398284	1437	33	8D
0005433398567	1437	34	8E
0005435732509	1437	35	9C
0005435732496	1437	36	9D
0005433398385	1437	37	9E
0005432297314	1437	38	9F
0005433398335	1437	39	10C
0005433398313	1437	40	10E
0005433398513	1437	41	10F
0005433398336	1437	42	11A
0005433398238	1437	43	11C
0005433398370	1437	44	11D
0005432297313	1437	45	11E
0005433398191	1437	46	11F
0005433398205	1437	47	12A
0005435732501	1437	48	12C
0005433398129	1437	49	12D
0005433398404	1437	50	13D
0005433398286	1437	51	13E
0005435732503	1437	52	13F
0005433398209	1437	53	14A
0005433398249	1437	54	14C
0005433398388	1437	55	14D
0005435732500	1437	56	14E
0005433398202	1437	57	14F
0005433398402	1437	58	15C
0005433398236	1437	59	15D
0005433398147	1437	60	15E
0005435732508	1437	61	16A
0005435732506	1437	62	16C
0005433398285	1437	63	16F
0005433457024	1437	64	17C
0005433398130	1437	65	17F
0005433398159	1437	66	18A
0005433398259	1437	67	18D
0005433398131	1437	68	18E
0005433398387	1437	69	19A
0005435732504	1437	70	19F
0005433398312	1437	71	20A
0005432297312	1437	72	20C
0005435732510	1437	73	20D
0005433398696	19250	1	11F
0005435732348	19250	2	13A
0005433398706	19250	3	11A
0005433398716	19250	4	13C
0005433398714	19250	5	3A
0005433398686	19250	6	14D
0005433398678	19250	7	20D
0005433398719	19250	8	19E
0005433398680	19250	9	4F
0005433398684	19250	10	18C
0005435732412	19250	11	10C
0005433398715	19250	12	2D
0005433398705	19250	13	11C
0005433398704	19250	14	14F
0005433398711	19250	15	6F
0005433398700	19250	16	19D
0005433398699	19250	17	17F
0005435732393	19250	18	16F
0005433398685	19250	19	10E
0005433398689	19250	20	5E
0005432906567	19250	21	19A
0005435732450	19250	22	15D
0005433398717	19250	23	13D
0005433398690	19250	24	8D
0005433398709	19250	25	20C
0005433398697	19250	26	11D
0005433398687	19250	27	7F
0005432906569	19250	28	18E
0005432906568	19250	29	9F
0005433398703	19250	30	2A
0005433398676	19250	31	8A
0005435732392	19250	32	5F
0005433398691	19250	33	2F
0005433398702	19250	34	17E
0005433398670	19250	35	6D
0005435732347	19250	36	11E
0005433398718	19250	37	6A
0005435732366	19250	38	8E
0005433398713	19250	39	9D
0005433398679	19250	40	13E
0005435732413	19250	41	4C
0005435732367	19250	42	12D
0005433398692	19250	43	17A
0005435732388	19250	44	20A
0005433398671	19250	45	8F
0005433398677	19250	46	5D
0005433398693	19250	47	16A
0005435732381	19250	48	5A
0005433398688	19250	49	3F
0005435732326	19250	50	9E
0005435732378	19250	51	14E
0005433398707	19250	52	17C
0005433398674	19250	53	3D
0005433398675	19250	54	12C
0005433398681	19250	55	7C
0005433398708	19250	56	16E
0005433398701	19250	57	6E
0005435732325	19250	58	14C
0005435732389	19250	59	7D
0005433398712	19250	60	16D
0005433398682	19250	61	12A
0005433398694	19250	62	17D
0005433398672	19250	63	7A
0005433398673	19250	64	18F
0005433398695	19250	65	2C
0005432906570	19250	66	18D
0005433398683	19250	67	3C
0005433398710	19250	68	19F
0005433398698	19250	69	12E
0005434443771	17343	1	3B
0005434443803	17343	2	2A
0005434443826	17343	3	3A
0005434443829	17343	4	3C
0005434443760	17343	5	5A
0005434443762	17343	6	5C
0005434443701	17343	7	18B
0005434443761	17343	8	18D
0005434443729	17343	9	19B
0005434443784	17343	10	21B
0005434443773	17343	11	21C
0005434443857	17343	12	21D
0005434443774	17343	13	22A
0005434443804	17343	14	22B
0005434443769	17343	15	22D
0005434443772	17343	16	23A
0005434443917	20595	1	3A
0005434443904	20595	2	5A
0005434443911	20595	3	4C
0005434443919	20595	4	3C
0005434443913	20595	5	3B
0005434443912	20595	6	7C
0005434443910	20595	7	18A
0005434443909	20595	8	18D
0005434443916	20595	9	19B
0005434443903	20595	10	19D
0005434443907	20595	11	20B
0005434443906	20595	12	21C
0005434443914	20595	13	22D
0005434443915	20595	14	23B
0005434443908	20595	15	1B
0005434443905	20595	16	6C
0005434443918	20595	17	5C
0005434954661	7263	1	5B
0005434954660	7263	2	1A
0005434954662	7263	3	4A
0005435377611	28339	1	2A
0005434954619	28339	2	3B
0005434351858	4480	1	22B
0005434351861	4480	2	22C
0005434351867	4480	3	6C
0005434351863	4480	4	1B
0005434183591	4480	5	1C
0005434183592	4480	6	1D
0005434351865	4480	7	2B
0005434351869	4480	8	2D
0005435893680	4480	9	3A
0005435893668	4480	10	3D
0005434351860	4480	11	4B
0005434351862	4480	12	4C
0005434351864	4480	13	6B
0005434183588	4480	14	7C
0005435893665	4480	15	18A
0005434351866	4480	16	19A
0005435893692	4480	17	19B
0005434183581	4480	18	19C
0005435893671	4480	19	19D
0005434351859	4480	20	20A
0005435893693	4480	21	20C
0005434351857	4480	22	20D
0005434351868	4480	23	21A
0005434183589	4480	24	21D
0005434351772	29649	1	5C
0005435893724	29649	2	5D
0005434351756	29649	3	7D
0005434351710	29649	4	19A
0005435893728	29649	5	19C
0005434351793	29649	6	19D
0005435893727	29649	7	20A
0005434351718	29649	8	21A
0005434351741	29649	9	21D
0005434351792	29649	10	22A
0005434351761	29649	11	23B
0005434351731	29649	12	4D
0005434351757	29649	13	3A
0005434351746	29649	14	2D
0005435893723	29649	15	2C
0005435893726	29649	16	2A
0005434351702	29649	17	1D
0005434351747	29649	18	1B
0005435893725	29649	19	1A
0005433343279	1060	1	21E
0005433343194	1060	2	21G
0005433269731	1060	3	22B
0005434446550	1060	4	22D
0005433343301	1060	5	22H
0005433343345	1060	6	23B
0005433343550	1060	7	23F
0005435092207	1060	8	23E
0005433343338	1060	9	23H
0005433269758	1060	10	24B
0005433343316	1060	11	24F
0005434446549	1060	12	24E
0005433343468	1060	13	25D
0005433343039	1060	14	25F
0005433343514	1060	15	25E
0005433343356	1060	16	27B
0005433343656	1060	17	27E
0005433343509	1060	18	27F
0005433343651	1060	19	27G
0005433343708	1060	20	28A
0005433343783	1060	21	28D
0005433343275	1060	22	28E
0005433343428	1060	23	28F
0005433343966	1060	24	28H
0005433343615	1060	25	28G
0005433343620	1060	26	29A
0005433343840	1060	27	29D
0005433342978	1060	28	29B
0005433343492	1060	29	29E
0005433343784	1060	30	29F
0005433343697	1060	31	29H
0005432293241	1060	32	30B
0005433343414	1060	33	30G
0005433343616	1060	34	30F
0005433343964	1060	35	30H
0005433343453	1060	36	31A
0005434445273	1060	37	31D
0005433343732	1060	38	32B
0005433343276	1060	39	32E
0005435092208	1060	40	32D
0005433343333	1060	41	32F
0005433343680	1060	42	33A
0005433343731	1060	43	33D
0005433343527	1060	44	33E
0005433343552	1060	45	33G
0005433343661	1060	46	33H
0005433343751	1060	47	34B
0005433343452	1060	48	34D
0005433343757	1060	49	34H
0005435545846	1060	50	35A
0005435092202	1060	51	35D
0005433343202	1060	52	35G
0005433343611	1060	53	36A
0005433343748	1060	54	35H
0005433269746	1060	55	36B
0005433343432	1060	56	36D
0005433343344	1060	57	36F
0005435092206	1060	58	36G
0005433343549	1060	59	37A
0005433343698	1060	60	36H
0005435092204	1060	61	37B
0005433343300	1060	62	37E
0005433343380	1060	63	37F
0005433343557	1060	64	37H
0005433159320	1060	65	37G
0005432293240	1060	66	38A
0005433343332	1060	67	38E
0005433343431	1060	68	38D
0005433343717	1060	69	38G
0005435092201	1060	70	38F
0005433343568	1060	71	39E
0005433343660	1060	72	39F
0005433343662	1060	73	1A
0005433343193	1060	74	1F
0005433343415	1060	75	1C
0005433269741	1060	76	1G
0005433343652	1060	77	2A
0005433342979	1060	78	2F
0005433343739	1060	79	3A
0005433343498	1060	80	3C
0005435092210	1060	81	3H
0005433343278	1060	82	4F
0005435545845	1060	83	4C
0005433342964	1060	84	4G
0005433158144	1060	85	5A
0005433343405	1060	86	4H
0005433343231	1060	87	5B
0005433343567	1060	88	5C
0005433343513	1060	89	5H
0005433343855	1060	90	9A
0005433343859	1060	91	11A
0005433343331	1060	92	9H
0005433343691	1060	93	11B
0005433343510	1060	94	11E
0005433343766	1060	95	11G
0005433343805	1060	96	12A
0005433342980	1060	97	11H
0005433343965	1060	98	12D
0005435092205	1060	99	12E
0005433343493	1060	100	12F
0005433343584	1060	101	13B
0005433343400	1060	102	13F
0005433158145	1060	103	13E
0005433269732	1060	104	13H
0005433343709	1060	105	13G
0005435092203	1060	106	14D
0005433342963	1060	107	14B
0005433343707	1060	108	14E
0005433343621	1060	109	14G
0005433343533	1060	110	14H
0005433343339	1060	111	15B
0005433343610	1060	112	15F
0005434446548	1060	113	16A
0005433343343	1060	114	16D
0005433343317	1060	115	16G
0005433343454	1060	116	16F
0005433343347	1060	117	16H
0005433343806	1060	118	17F
0005433159321	1060	119	17E
0005433343499	1060	120	17G
0005433343816	1060	121	17H
0005433462774	1060	122	18B
0005435092200	1060	123	18D
0005433343127	1060	124	18F
0005433343575	1060	125	18E
0005433343643	1060	126	19D
0005433343595	1060	127	19B
0005433343594	1060	128	19E
0005433343484	1060	129	19F
0005433343429	1060	130	19H
0005433343573	1060	131	20B
0005433343419	1060	132	20E
0005433343406	1060	133	20D
0005435092209	1060	134	20G
0005432293242	1060	135	20H
0005433462775	1060	136	21D
0005433344402	17026	1	23B
0005433344411	17026	2	1A
0005433344364	17026	3	1C
0005433344339	17026	4	1B
0005433344331	17026	5	1F
0005433344427	17026	6	1G
0005433344417	17026	7	2A
0005435092172	17026	8	1H
0005433344383	17026	9	2B
0005433344336	17026	10	2F
0005433344397	17026	11	2C
0005433344334	17026	12	2G
0005433344409	17026	13	3F
0005433344366	17026	14	3C
0005433344333	17026	15	3G
0005433344380	17026	16	4A
0005433344386	17026	17	4B
0005433344358	17026	18	4F
0005433269789	17026	19	4C
0005433344403	17026	20	5B
0005433344335	17026	21	5G
0005433344350	17026	22	5F
0005433344388	17026	23	9A
0005433344394	17026	24	5H
0005433344422	17026	25	11A
0005433159342	17026	26	9H
0005433344340	17026	27	11D
0005433344342	17026	28	11F
0005433344429	17026	29	11E
0005433344381	17026	30	12A
0005433344416	17026	31	12F
0005433344385	17026	32	12G
0005433344365	17026	33	13A
0005433344371	17026	34	13F
0005433344360	17026	35	13E
0005433344379	17026	36	13G
0005433344343	17026	37	14B
0005433344410	17026	38	14F
0005433344396	17026	39	14H
0005433344404	17026	40	14G
0005433344359	17026	41	15A
0005433344398	17026	42	15B
0005433159341	17026	43	15E
0005435092143	17026	44	15D
0005433344418	17026	45	15F
0005433344375	17026	46	15G
0005433344373	17026	47	16A
0005434445250	17026	48	16F
0005435092136	17026	49	17B
0005433344413	17026	50	17E
0005433344330	17026	51	17G
0005433344428	17026	52	17H
0005433344357	17026	53	18E
0005433269788	17026	54	18F
0005433344415	17026	55	18H
0005433344332	17026	56	19B
0005433344352	17026	57	19F
0005433344382	17026	58	19E
0005433344387	17026	59	20A
0005433344376	17026	60	20E
0005433344419	17026	61	20D
0005433344425	17026	62	20F
0005433344346	17026	63	20H
0005433344420	17026	64	21D
0005433344374	17026	65	21B
0005433344405	17026	66	21F
0005433344431	17026	67	21E
0005433344355	17026	68	21H
0005433344377	17026	69	22A
0005433344424	17026	70	22F
0005435508377	17026	71	22E
0005433344345	17026	72	22G
0005433344432	17026	73	23A
0005433344344	17026	74	23D
0005433344423	17026	75	23H
0005433344430	17026	76	24B
0005433344370	17026	77	24A
0005433344362	17026	78	24F
0005433344353	17026	79	25E
0005433344395	17026	80	25D
0005435092167	17026	81	25F
0005433344338	17026	82	27A
0005433344363	17026	83	27H
0005435092166	17026	84	27G
0005435508361	17026	85	28B
0005433344393	17026	86	28E
0005433344412	17026	87	28D
0005433344369	17026	88	29E
0005433344356	17026	89	30E
0005433344341	17026	90	30G
0005433269790	17026	91	31A
0005433344391	17026	92	31D
0005433344368	17026	93	31F
0005433344389	17026	94	31G
0005433344337	17026	95	32A
0005433344361	17026	96	31H
0005433344351	17026	97	32D
0005433344349	17026	98	32B
0005433159343	17026	99	32F
0005433344400	17026	100	33A
0005433344401	17026	101	33G
0005433344367	17026	102	34A
0005433344354	17026	103	34G
0005435508369	17026	104	34F
0005433344372	17026	105	35B
0005435092149	17026	106	35A
0005433344406	17026	107	35D
0005433269792	17026	108	35F
0005435508376	17026	109	35G
0005433269791	17026	110	36A
0005433344407	17026	111	35H
0005433344390	17026	112	36H
0005433344408	17026	113	36G
0005433344414	17026	114	37D
0005433344399	17026	115	37A
0005433344421	17026	116	37E
0005433344348	17026	117	37G
0005433159340	17026	118	38B
0005435092173	17026	119	38A
0005433344426	17026	120	38E
0005433344384	17026	121	38G
0005433344347	17026	122	39E
0005433344378	17026	123	39D
0005433344392	17026	124	39F
0005432390286	1338	1	2A
0005432390272	1338	2	1F
0005432390284	1338	3	2F
0005432390275	1338	4	3F
0005432390295	1338	5	4D
0005432851943	1338	6	4C
0005432390283	1338	7	4A
0005432851944	1338	8	5C
0005432390273	1338	9	5F
0005432851940	1338	10	6A
0005432390279	1338	11	6C
0005432390277	1338	12	6E
0005432851955	1338	13	7A
0005432392034	1338	14	6F
0005432390267	1338	15	7B
0005432390293	1338	16	7F
0005432390290	1338	17	8D
0005432390299	1338	18	8C
0005432390271	1338	19	8E
0005432851930	1338	20	9B
0005432851921	1338	21	9A
0005432392031	1338	22	9D
0005432851931	1338	23	10E
0005432390280	1338	24	11A
0005432851914	1338	25	10F
0005432851934	1338	26	11C
0005432392030	1338	27	12B
0005432390288	1338	28	12C
0005432851939	1338	29	12E
0005432390287	1338	30	13B
0005432390276	1338	31	13E
0005432392033	1338	32	13D
0005432392032	1338	33	14A
0005432390269	1338	34	13F
0005432851957	1338	35	14B
0005432851949	1338	36	14C
0005432390266	1338	37	14F
0005432390294	1338	38	15A
0005432390298	1338	39	15D
0005432390278	1338	40	15E
0005432392035	1338	41	15F
0005432390281	1338	42	16C
0005432390282	1338	43	16B
0005432392037	1338	44	16E
0005432390300	1338	45	16F
0005432851948	1338	46	17B
0005432390285	1338	47	17D
0005432390291	1338	48	17C
0005432390274	1338	49	17F
0005432851919	1338	50	17E
0005432392036	1338	51	18A
0005432390289	1338	52	18E
0005432851927	1338	53	18D
0005432851929	1338	54	18F
0005432390297	1338	55	19C
0005432851935	1338	56	19B
0005432390270	1338	57	19F
0005432390292	1338	58	20C
0005432851947	1338	59	20B
0005432851920	1338	60	20D
0005432390268	1338	61	20E
0005432390296	1338	62	21D
0005432392029	1338	63	21E
0005434082091	12793	1	1A
0005434067681	12793	2	1C
0005434067580	12793	3	1F
0005434081959	12793	4	1D
0005432161183	12793	5	2C
0005434081925	12793	6	2A
0005432433750	12793	7	2D
0005434067557	12793	8	2F
0005434067744	12793	9	3A
0005434081992	12793	10	3D
0005432433751	12793	11	3C
0005434067883	12793	12	4A
0005434082025	12793	13	4C
0005434081878	12793	14	4B
0005434081919	12793	15	4D
0005434067796	12793	16	4E
0005434067668	12793	17	5A
0005432159920	12793	18	4F
0005433989778	12793	19	5C
0005434067958	12793	20	5B
0005433989786	12793	21	5D
0005434068187	12793	22	5E
0005434068177	12793	23	5F
0005434067743	12793	24	6B
0005434067933	12793	25	6A
0005432161181	12793	26	6C
0005434067908	12793	27	6D
0005434067998	12793	28	6E
0005434067896	12793	29	6F
0005433989792	12793	30	7B
0005434067661	12793	31	7F
0005432433748	12793	32	7E
0005434068235	12793	33	8A
0005434068176	12793	34	8B
0005434081976	12793	35	8C
0005434067900	12793	36	8F
0005434067680	12793	37	8E
0005434082090	12793	38	9A
0005434067783	12793	39	9C
0005434082024	12793	40	9E
0005434081999	12793	41	9D
0005434067892	12793	42	9F
0005432159918	12793	43	10B
0005434067902	12793	44	10C
0005434067740	12793	45	10D
0005434067901	12793	46	11A
0005434067956	12793	47	10E
0005434067884	12793	48	11C
0005432433752	12793	49	11B
0005434068030	12793	50	11D
0005434082071	12793	51	11E
0005434081918	12793	52	11F
0005434067903	12793	53	12A
0005434067964	12793	54	12B
0005433989796	12793	55	12D
0005433989793	12793	56	12C
0005434067706	12793	57	12E
0005434081956	12793	58	13A
0005434067893	12793	59	12F
0005434067963	12793	60	13C
0005433989785	12793	61	13B
0005432159916	12793	62	13D
0005432159919	12793	63	13E
0005434082021	12793	64	13F
0005434067934	12793	65	14C
0005434067983	12793	66	14E
0005434081998	12793	67	15A
0005433989791	12793	68	15C
0005434082073	12793	69	15B
0005433812932	12793	70	15D
0005432159917	12793	71	15F
0005434068193	12793	72	15E
0005434067558	12793	73	16B
0005434067865	12793	74	16C
0005434081888	12793	75	16D
0005434081915	12793	76	16F
0005434067841	12793	77	16E
0005434067787	12793	78	17A
0005434067556	12793	79	17B
0005434068175	12793	80	17C
0005434081948	12793	81	17D
0005434081879	12793	82	17F
0005434067935	12793	83	17E
0005434067836	12793	84	18A
0005434067804	12793	85	18B
0005434067570	12793	86	18C
0005434067809	12793	87	18E
0005434082068	12793	88	18D
0005434081975	12793	89	18F
0005434067828	12793	90	19A
0005434067569	12793	91	19B
0005434067788	12793	92	19C
0005433989787	12793	93	19D
0005434068186	12793	94	19F
0005434081876	12793	95	19E
0005434081822	12793	96	20A
0005434081907	12793	97	20D
0005434067957	12793	98	20C
0005434081898	12793	99	20F
0005434067920	12793	100	21B
0005434068236	12793	101	21D
0005434068085	12793	102	21C
0005434081958	12793	103	21F
0005434067878	12793	104	21E
0005434067825	12793	105	22A
0005434067797	12793	106	22D
0005434081940	12793	107	22E
0005434081887	12793	108	22F
0005433812933	12793	109	23B
0005432161182	12793	110	23A
0005434081936	12793	111	23C
0005432433749	12793	112	23E
0005434067579	12793	113	23D
0005434081877	12793	114	23F
0005434068412	30659	1	1A
0005434068437	30659	2	1C
0005434068445	30659	3	1D
0005432433705	30659	4	1F
0005434068456	30659	5	2C
0005434068405	30659	6	2A
0005432186915	30659	7	2D
0005434068457	30659	8	3A
0005432433703	30659	9	2F
0005434068468	30659	10	3C
0005434082182	30659	11	3F
0005434068407	30659	12	4A
0005434068465	30659	13	4C
0005432150290	30659	14	4B
0005433989832	30659	15	4D
0005434068446	30659	16	4E
0005434082191	30659	17	4F
0005434068431	30659	18	5A
0005434068415	30659	19	5B
0005434068413	30659	20	5D
0005434068424	30659	21	5C
0005434068454	30659	22	5F
0005434082188	30659	23	5E
0005432150292	30659	24	6A
0005434068428	30659	25	6C
0005434068416	30659	26	6D
0005434082187	30659	27	6E
0005432150295	30659	28	6F
0005434082195	30659	29	7B
0005434068470	30659	30	7A
0005434082186	30659	31	7C
0005434068423	30659	32	7D
0005434068460	30659	33	7F
0005433989830	30659	34	7E
0005434082194	30659	35	8A
0005434082193	30659	36	8C
0005432433697	30659	37	8D
0005434082196	30659	38	8F
0005434082192	30659	39	8E
0005434082179	30659	40	9A
0005432433704	30659	41	9B
0005434068444	30659	42	9D
0005434082184	30659	43	9C
0005434068422	30659	44	9F
0005432433709	30659	45	9E
0005434068471	30659	46	10B
0005432186916	30659	47	10C
0005434068429	30659	48	10E
0005433989833	30659	49	10D
0005434068448	30659	50	11A
0005434068432	30659	51	11B
0005434068467	30659	52	11D
0005434068455	30659	53	11C
0005432433686	30659	54	11E
0005434068461	30659	55	11F
0005434068404	30659	56	12B
0005434068414	30659	57	12A
0005434068425	30659	58	12E
0005434068403	30659	59	12D
0005434068406	30659	60	12F
0005434082190	30659	61	13B
0005434082176	30659	62	13D
0005434068451	30659	63	13C
0005433989829	30659	64	13E
0005434082183	30659	65	14A
0005434068410	30659	66	13F
0005432150289	30659	67	14B
0005434068402	30659	68	14D
0005434068464	30659	69	14E
0005434068453	30659	70	14F
0005432433687	30659	71	15A
0005434068421	30659	72	15B
0005433989827	30659	73	15D
0005434082189	30659	74	15C
0005434068419	30659	75	15E
0005434068441	30659	76	16A
0005434068418	30659	77	15F
0005434082177	30659	78	16B
0005432150288	30659	79	16D
0005434068436	30659	80	16F
0005433989831	30659	81	16E
0005434068433	30659	82	17A
0005434068469	30659	83	17B
0005434068420	30659	84	17C
0005434068459	30659	85	17E
0005432433727	30659	86	17D
0005434068447	30659	87	17F
0005434068417	30659	88	18A
0005434082180	30659	89	18C
0005434068466	30659	90	18B
0005434068458	30659	91	18D
0005434068426	30659	92	18E
0005432186913	30659	93	18F
0005432433710	30659	94	19A
0005434068409	30659	95	19B
0005434082178	30659	96	19C
0005434082185	30659	97	19E
0005434068427	30659	98	19D
0005432150291	30659	99	19F
0005434068438	30659	100	20A
0005434068450	30659	101	20D
0005434068449	30659	102	20C
0005434068463	30659	103	20E
0005432186914	30659	104	20F
0005434068443	30659	105	21A
0005434068472	30659	106	21D
0005434082181	30659	107	21C
0005434068439	30659	108	21E
0005433989828	30659	109	22A
0005434068411	30659	110	21F
0005432150294	30659	111	22C
0005434068462	30659	112	22B
0005434068452	30659	113	22D
0005434068435	30659	114	22E
0005434068442	30659	115	22F
0005434068440	30659	116	23B
0005432150293	30659	117	23C
0005434068408	30659	118	23D
0005434068430	30659	119	23E
0005434068434	30659	120	23F
0005435725662	5503	1	1B
0005435722086	5503	2	1G
0005435462578	5503	3	1H
0005435462678	5503	4	2B
0005434265205	5503	5	2F
0005435723073	5503	6	2C
0005434265235	5503	7	3A
0005434265174	5503	8	3F
0005435462545	5503	9	3C
0005435767012	5503	10	3G
0005435767010	5503	11	4B
0005435462552	5503	12	4A
0005434265153	5503	13	4F
0005435462697	5503	14	4C
0005435766988	5503	15	4G
0005432140556	5503	16	5A
0005435725663	5503	17	5C
0005434831181	5503	18	9A
0005435462602	5503	19	5H
0005435767011	5503	20	9B
0005434265248	5503	21	9G
0005434265254	5503	22	11B
0005435767023	5503	23	11A
0005435723071	5503	24	11D
0005432140559	5503	25	11G
0005435462573	5503	26	11F
0005433527318	5503	27	11E
0005435767015	5503	28	11H
0005433527319	5503	29	12A
0005435766990	5503	30	12D
0005433529329	5503	31	12F
0005435767021	5503	32	12E
0005435767030	5503	33	12G
0005435767005	5503	34	12H
0005435462655	5503	35	13D
0005434831182	5503	36	13F
0005435462637	5503	37	13E
0005435462475	5503	38	13G
0005435767013	5503	39	13H
0005434265160	5503	40	14E
0005435767004	5503	41	14H
0005435767009	5503	42	15A
0005435767028	5503	43	15E
0005432535860	5503	44	15D
0005435735193	5503	45	15G
0005434831164	5503	46	15H
0005435735197	5503	47	16A
0005435462551	5503	48	16B
0005435767019	5503	49	16D
0005435767020	5503	50	16H
0005435767029	5503	51	17A
0005435462662	5503	52	17G
0005435766996	5503	53	17H
0005432140555	5503	54	18D
0005432535861	5503	55	18E
0005435735196	5503	56	18G
0005435766998	5503	57	18F
0005432140553	5503	58	19A
0005435462684	5503	59	18H
0005435462624	5503	60	19E
0005434831180	5503	61	19D
0005434265104	5503	62	19G
0005435725664	5503	63	19F
0005434265105	5503	64	19H
0005435767032	5503	65	20D
0005435462696	5503	66	20E
0005435462556	5503	67	20H
0005434265163	5503	68	21A
0005434265128	5503	69	21G
0005434265253	5503	70	21F
0005435462579	5503	71	21H
0005434265175	5503	72	22D
0005435767031	5503	73	22B
0005435766989	5503	74	22G
0005432535841	5503	75	23A
0005435720839	5503	76	23B
0005435462527	5503	77	23F
0005435767001	5503	78	23E
0005433529331	5503	79	23G
0005433529328	5503	80	23H
0005432140554	5503	81	24B
0005435462679	5503	82	24A
0005434265269	5503	83	24F
0005435767006	5503	84	25D
0005435725660	5503	85	24H
0005435462560	5503	86	25E
0005435766995	5503	87	27A
0005432140558	5503	88	27B
0005435462574	5503	89	27E
0005434265303	5503	90	27D
0005435462611	5503	91	27F
0005432535842	5503	92	27G
0005434831165	5503	93	28B
0005434265228	5503	94	28D
0005435462623	5503	95	28F
0005435462555	5503	96	28G
0005434265265	5503	97	29A
0005435462601	5503	98	28H
0005434265103	5503	99	29B
0005435735195	5503	100	29G
0005435767014	5503	101	30B
0005434831160	5503	102	30A
0005435766997	5503	103	30D
0005435722088	5503	104	30E
0005432535859	5503	105	30G
0005435767026	5503	106	30F
0005432535869	5503	107	31A
0005435723072	5503	108	30H
0005435462613	5503	109	31D
0005434265293	5503	110	31E
0005434265229	5503	111	31H
0005435462612	5503	112	32A
0005432140557	5503	113	32B
0005432535847	5503	114	32E
0005435462629	5503	115	32D
0005434265266	5503	116	32F
0005435767016	5503	117	32H
0005435735194	5503	118	33B
0005435462577	5503	119	33A
0005435767008	5503	120	33D
0005433529327	5503	121	33E
0005435767007	5503	122	33F
0005435766987	5503	123	33H
0005435767018	5503	124	33G
0005435767003	5503	125	34B
0005435767025	5503	126	34A
0005435462635	5503	127	34D
0005434265204	5503	128	34E
0005435725661	5503	129	34G
0005433527316	5503	130	35A
0005435767017	5503	131	34H
0005435767024	5503	132	35B
0005435722087	5503	133	35D
0005435766992	5503	134	35F
0005434265281	5503	135	35E
0005435462474	5503	136	35G
0005435767027	5503	137	36A
0005435767000	5503	138	35H
0005435766993	5503	139	36B
0005435462647	5503	140	36E
0005435720840	5503	141	36G
0005435462546	5503	142	37A
0005433529330	5503	143	36H
0005435462529	5503	144	37B
0005432535838	5503	145	37E
0005435766994	5503	146	37H
0005435462638	5503	147	38E
0005434265158	5503	148	38D
0005435766991	5503	149	38F
0005435767022	5503	150	38H
0005435767002	5503	151	38G
0005433527317	5503	152	39D
0005435766999	5503	153	39E
0005435043293	13501	1	1B
0005435766246	13501	2	1A
0005434265492	13501	3	1F
0005435722065	13501	4	1G
0005435766294	13501	5	2A
0005435725600	13501	6	2C
0005432535897	13501	7	2G
0005435766385	13501	8	2H
0005435766486	13501	9	3A
0005435735154	13501	10	3F
0005432194566	13501	11	3C
0005435735153	13501	12	3G
0005434265484	13501	13	4B
0005435766586	13501	14	4A
0005435766620	13501	15	4C
0005435043294	13501	16	4G
0005434265486	13501	17	4F
0005435725599	13501	18	5A
0005435462947	13501	19	4H
0005435462930	13501	20	5B
0005435462945	13501	21	5F
0005434831212	13501	22	5C
0005435462934	13501	23	5G
0005435766500	13501	24	5H
0005432194565	13501	25	9B
0005435766277	13501	26	9G
0005434265490	13501	27	11A
0005435766747	13501	28	11B
0005434265485	13501	29	11E
0005435462920	13501	30	11F
0005435462933	13501	31	11G
0005432194568	13501	32	12A
0005435766295	13501	33	12B
0005435766645	13501	34	12E
0005435462953	13501	35	12D
0005434265481	13501	36	12G
0005435766319	13501	37	13B
0005435462944	13501	38	13A
0005435766242	13501	39	13E
0005435766523	13501	40	13F
0005435766430	13501	41	13H
0005435462937	13501	42	14B
0005434265487	13501	43	14A
0005434831214	13501	44	14D
0005435766482	13501	45	14F
0005432535900	13501	46	14E
0005435462936	13501	47	14G
0005435766394	13501	48	15A
0005435735144	13501	49	15E
0005435722063	13501	50	15F
0005434831216	13501	51	15H
0005435462943	13501	52	16A
0005435766511	13501	53	16D
0005435766273	13501	54	16B
0005434265494	13501	55	16E
0005435725609	13501	56	16F
0005435725627	13501	57	16G
0005435766612	13501	58	17B
0005435766237	13501	59	17F
0005435766488	13501	60	17E
0005435766579	13501	61	18A
0005435462923	13501	62	17H
0005434265472	13501	63	17G
0005435725629	13501	64	18B
0005435462918	13501	65	18D
0005434265480	13501	66	18F
0005435766601	13501	67	18E
0005435462940	13501	68	18H
0005435722066	13501	69	19B
0005435766315	13501	70	19E
0005435766534	13501	71	19D
0005435766600	13501	72	19F
0005434265477	13501	73	19G
0005435766422	13501	74	20A
0005435766238	13501	75	19H
0005435766519	13501	76	20B
0005435766329	13501	77	20E
0005435766435	13501	78	20D
0005435462922	13501	79	20G
0005434265483	13501	80	21B
0005432535896	13501	81	21A
0005435735151	13501	82	20H
0005435766507	13501	83	21F
0005435766257	13501	84	21H
0005435462921	13501	85	21G
0005435766337	13501	86	22B
0005435766318	13501	87	22A
0005434265482	13501	88	22E
0005435766328	13501	89	22G
0005435766489	13501	90	23A
0005435462948	13501	91	22H
0005435766279	13501	92	23D
0005435725613	13501	93	23B
0005435617174	13501	94	23F
0005434265473	13501	95	23G
0005435766278	13501	96	24B
0005435462929	13501	97	24F
0005435766492	13501	98	24E
0005435766527	13501	99	25D
0005435766369	13501	100	24H
0005435766535	13501	101	25E
0005434831213	13501	102	27A
0005435766644	13501	103	27B
0005435462941	13501	104	27F
0005435766386	13501	105	27H
0005435766621	13501	106	27G
0005434265491	13501	107	28A
0005434265470	13501	108	28B
0005435766370	13501	109	28E
0005435462952	13501	110	28F
0005435725612	13501	111	28H
0005435766613	13501	112	28G
0005435766333	13501	113	29A
0005435462949	13501	114	29D
0005435766400	13501	115	29F
0005434265471	13501	116	29G
0005435766387	13501	117	30A
0005435766543	13501	118	30D
0005435766401	13501	119	30E
0005435462938	13501	120	30G
0005435766449	13501	121	30F
0005434265478	13501	122	30H
0005435462950	13501	123	31B
0005435766487	13501	124	31A
0005435720135	13501	125	31E
0005435462942	13501	126	31D
0005432194567	13501	127	31F
0005435766588	13501	128	31G
0005435462946	13501	129	31H
0005435766274	13501	130	32B
0005435766012	13501	131	32D
0005434265469	13501	132	32F
0005435725628	13501	133	32E
0005435462932	13501	134	32G
0005435462925	13501	135	33D
0005435735145	13501	136	33E
0005435462939	13501	137	33F
0005435766272	13501	138	33H
0005434265479	13501	139	33G
0005434265493	13501	140	34A
0005434265476	13501	141	34D
0005432535899	13501	142	34E
0005434831215	13501	143	34G
0005435462924	13501	144	35B
0005435462928	13501	145	35E
0005435766388	13501	146	35G
0005435462926	13501	147	36A
0005435766595	13501	148	35H
0005435766518	13501	149	36B
0005435766646	13501	150	36E
0005435766483	13501	151	36D
0005435462951	13501	152	36H
0005435766748	13501	153	36G
0005435462935	13501	154	36F
0005435766651	13501	155	37A
0005435462927	13501	156	37D
0005435766247	13501	157	37B
0005434265488	13501	158	37E
0005435617175	13501	159	37G
0005434265474	13501	160	37F
0005435462931	13501	161	37H
0005434831217	13501	162	38D
0005435766229	13501	163	38B
0005434265489	13501	164	38F
0005434265475	13501	165	38E
0005435735146	13501	166	38G
0005432535898	13501	167	39E
0005435766513	13501	168	39D
0005435462919	13501	169	39F
0005434602917	18669	1	3A
0005434602911	18669	2	1B
0005434515001	18670	1	5B
0005434513611	18670	2	4B
0005434515000	18670	3	3B
0005434513613	18670	4	5A
0005434513612	18670	5	1B
0005434514974	19218	1	4B
0005435846298	25091	1	9D
0005432649412	25091	2	9F
0005435846303	25091	3	10A
0005435846302	25091	4	10F
0005435846296	25091	5	11A
0005432649400	25091	6	11C
0005435846297	25091	7	12D
0005432649445	25091	8	12E
0005432649430	25091	9	13A
0005432649425	25091	10	4E
0005435846301	25091	11	13D
0005435846299	25091	12	14D
0005432649448	25091	13	15F
0005432649446	25091	14	16F
0005432649431	25091	15	17D
0005432649419	25091	16	17E
0005432649417	25091	17	18D
0005432649447	25091	18	19C
0005435846300	25091	19	19F
0005432649453	25091	20	20E
0005432649395	25091	21	1F
0005432649408	25091	22	3D
0005432649426	25091	23	13C
0005432649432	25091	24	4F
0005432649429	25091	25	5D
0005432649415	25091	26	6E
0005432649418	25091	27	7C
0005432649434	25091	28	8A
0005432649409	25091	29	8C
0005432649413	25091	30	8E
0005433285431	1832	1	11A
0005433008925	1832	2	11C
0005433285453	1832	3	11D
0005433285228	1832	4	11E
0005433008943	1832	5	11F
0005433285483	1832	6	12A
0005432295915	1832	7	12C
0005433008737	1832	8	12D
0005433008788	1832	9	12F
0005433008738	1832	10	13A
0005433810598	1832	11	13E
0005433285484	1832	12	14A
0005433008936	1832	13	14C
0005433008824	1832	14	14E
0005433008808	1832	15	15A
0005433285460	1832	16	15C
0005433008773	1832	17	15D
0005433008854	1832	18	15F
0005433008708	1832	19	16A
0005433008739	1832	20	16C
0005433008717	1832	21	16E
0005433810604	1832	22	16F
0005433009039	1832	23	17A
0005433008809	1832	24	17C
0005433008825	1832	25	17D
0005433008791	1832	26	17E
0005433285272	1832	27	17F
0005433008871	1832	28	18A
0005433008926	1832	29	18C
0005433810603	1832	30	18E
0005433285451	1832	31	18F
0005433008942	1832	32	19A
0005433008975	1832	33	19C
0005433008935	1832	34	19D
0005433008823	1832	35	19E
0005433285540	1832	36	19F
0005433285475	1832	37	20A
0005433810599	1832	38	20C
0005433810601	1832	39	20D
0005433008720	1832	40	20F
0005432295913	1832	41	1A
0005433285542	1832	42	1C
0005433008812	1832	43	1D
0005433008954	1832	44	1F
0005433008721	1832	45	2C
0005433008922	1832	46	2D
0005433285476	1832	47	2F
0005433285229	1832	48	3A
0005432295914	1832	49	3D
0005433008953	1832	50	3F
0005433008937	1832	51	4A
0005433285396	1832	52	4C
0005433285409	1832	53	4D
0005433285539	1832	54	4E
0005433285397	1832	55	4F
0005433008837	1832	56	5A
0005433008628	1832	57	5D
0005433009038	1832	58	5F
0005433008780	1832	59	6A
0005433008718	1832	60	6C
0005433009068	1832	61	6D
0005433285570	1832	62	6E
0005433285569	1832	63	6F
0005433008934	1832	64	7A
0005433008627	1832	65	7D
0005433810605	1832	66	7E
0005433285308	1832	67	7F
0005433285458	1832	68	8D
0005433008873	1832	69	8E
0005433285367	1832	70	9A
0005433285472	1832	71	9D
0005433285607	1832	72	9E
0005433008707	1832	73	9F
0005433810602	1832	74	10A
0005433285518	1832	75	10C
0005433810600	1832	76	10E
0005433008789	1832	77	10F
0005433009186	22599	1	9A
0005433009198	22599	2	1A
0005433009170	22599	3	1F
0005433009193	22599	4	2C
0005433009211	22599	5	2D
0005433810542	22599	6	2F
0005433285676	22599	7	3A
0005433285685	22599	8	3C
0005433009204	22599	9	3D
0005433285679	22599	10	4A
0005433009182	22599	11	4C
0005433009208	22599	12	4D
0005433009185	22599	13	4E
0005433009188	22599	14	4F
0005433285677	22599	15	5C
0005433009184	22599	16	5D
0005433285707	22599	17	5E
0005433285706	22599	18	5F
0005433009214	22599	19	6A
0005433285704	22599	20	6C
0005433285701	22599	21	6D
0005433009199	22599	22	6E
0005433009181	22599	23	6F
0005433285689	22599	24	7C
0005433285694	22599	25	7D
0005433009201	22599	26	7E
0005433285695	22599	27	7F
0005433285678	22599	28	8A
0005433009191	22599	29	8D
0005433009203	22599	30	8E
0005433285682	22599	31	8F
0005433810554	22599	32	9C
0005433009194	22599	33	9D
0005433285691	22599	34	9E
0005433009196	22599	35	10A
0005433285692	22599	36	10C
0005433009213	22599	37	10D
0005433285693	22599	38	10E
0005433009192	22599	39	10F
0005433009200	22599	40	11A
0005433009183	22599	41	11C
0005433285700	22599	42	11D
0005433009176	22599	43	11E
0005433009205	22599	44	11F
0005433009210	22599	45	12A
0005433285696	22599	46	12C
0005433009172	22599	47	12D
0005433009209	22599	48	12F
0005433009168	22599	49	13A
0005433009189	22599	50	13C
0005433285683	22599	51	13D
0005433285686	22599	52	13E
0005433009175	22599	53	13F
0005433810536	22599	54	14A
0005433009178	22599	55	14D
0005433285688	22599	56	14E
0005433285684	22599	57	15A
0005433285687	22599	58	15C
0005433810535	22599	59	15D
0005433285681	22599	60	15E
0005433009197	22599	61	15F
0005433009179	22599	62	16A
0005433285703	22599	63	16C
0005433009180	22599	64	16D
0005433009173	22599	65	16E
0005433285697	22599	66	16F
0005433009174	22599	67	17A
0005433009171	22599	68	17C
0005433285699	22599	69	17D
0005433009212	22599	70	17F
0005433285705	22599	71	18A
0005433285680	22599	72	18C
0005433009195	22599	73	18D
0005433009202	22599	74	18E
0005433009207	22599	75	18F
0005433009206	22599	76	19A
0005433810530	22599	77	19D
0005433009177	22599	78	19F
0005433285698	22599	79	19E
0005433285690	22599	80	20A
0005433285702	22599	81	20C
0005433009169	22599	82	20D
0005433009190	22599	83	20E
0005433009187	22599	84	20F
0005432751543	12286	1	1F
0005432755077	12286	2	2C
0005432751529	12286	3	2D
0005432751512	12286	4	3D
0005432751544	12286	5	3F
0005434152820	12286	6	4C
0005432751540	12286	7	5A
0005434152822	12286	8	5D
0005432755082	12286	9	6A
0005432751513	12286	10	6D
0005432751530	12286	11	6E
0005434152817	12286	12	7C
0005434152814	12286	13	7D
0005432751521	12286	14	7F
0005434152823	12286	15	8C
0005434152819	12286	16	8F
0005432751542	12286	17	10C
0005432755083	12286	18	11A
0005432755085	12286	19	11C
0005434152818	12286	20	11F
0005434152821	12286	21	12E
0005432751531	12286	22	12F
0005432751522	12286	23	13C
0005432751514	12286	24	15E
0005432755079	12286	25	16A
0005432751528	12286	26	16C
0005434152816	12286	27	16E
0005432755084	12286	28	16F
0005434152815	12286	29	18A
0005432751538	12286	30	18D
0005432755076	12286	31	18E
0005432751548	12286	32	19A
0005432755078	12286	33	20D
0005433847505	5605	1	19A
0005433847489	5605	2	1C
0005433847483	5605	3	1A
0005433847470	5605	4	1D
0005435282683	5605	5	2A
0005435282618	5605	6	1F
0005433847458	5605	7	2D
0005433847474	5605	8	2C
0005435282715	5605	9	3A
0005435282744	5605	10	2F
0005433815445	5605	11	3C
0005433847472	5605	12	4A
0005435282567	5605	13	3F
0005433847461	5605	14	4C
0005433847516	5605	15	4F
0005435282655	5605	16	4D
0005433847507	5605	17	5F
0005433847478	5605	18	5D
0005433847463	5605	19	6A
0005432081596	5605	20	6D
0005433847468	5605	21	6C
0005433847482	5605	22	6B
0005433847500	5605	23	6E
0005433847464	5605	24	7A
0005433847479	5605	25	6F
0005433847486	5605	26	7C
0005433847476	5605	27	7E
0005435282617	5605	28	7D
0005435282596	5605	29	8A
0005433847502	5605	30	7F
0005433847509	5605	31	8B
0005432081598	5605	32	8E
0005433847471	5605	33	8D
0005433847488	5605	34	8C
0005435282614	5605	35	8F
0005433847475	5605	36	9B
0005433847501	5605	37	9C
0005433847481	5605	38	9E
0005433847492	5605	39	10A
0005434173528	5605	40	9F
0005434173530	5605	41	10B
0005433847477	5605	42	11A
0005433847493	5605	43	10F
0005433847459	5605	44	10E
0005433847514	5605	45	11C
0005433847494	5605	46	12B
0005433847504	5605	47	12C
0005433847506	5605	48	12E
0005435282633	5605	49	12F
0005433847498	5605	50	13C
0005432081592	5605	51	13B
0005435282660	5605	52	13E
0005433815448	5605	53	13D
0005432081597	5605	54	14A
0005433847469	5605	55	13F
0005435282593	5605	56	14D
0005435282599	5605	57	14C
0005433847511	5605	58	14F
0005432081594	5605	59	14E
0005433847503	5605	60	15A
0005434173533	5605	61	15D
0005433847457	5605	62	15C
0005433847462	5605	63	15F
0005433847508	5605	64	15E
0005433847473	5605	65	16A
0005433847512	5605	66	16C
0005432081595	5605	67	16B
0005435282631	5605	68	16D
0005433847490	5605	69	16F
0005435282576	5605	70	16E
0005435282598	5605	71	17A
0005433847496	5605	72	17D
0005433847460	5605	73	17C
0005433847487	5605	74	17F
0005435282628	5605	75	17E
0005433847466	5605	76	18A
0005433847515	5605	77	18C
0005433847465	5605	78	18E
0005433847510	5605	79	18D
0005433847467	5605	80	18F
0005433815446	5605	81	19C
0005435282632	5605	82	19B
0005433815444	5605	83	19D
0005433847495	5605	84	19E
0005433847485	5605	85	20B
0005433847499	5605	86	20A
0005432081593	5605	87	20D
0005433847484	5605	88	20C
0005433847513	5605	89	21B
0005433847491	5605	90	21A
0005433847480	5605	91	20F
0005433847497	5605	92	21C
0005434173529	5605	93	21F
0005433815447	5605	94	21E
0005433846960	13842	1	1C
0005433847050	13842	2	1A
0005435282818	13842	3	1D
0005435282819	13842	4	2A
0005432003741	13842	5	1F
0005433847052	13842	6	2F
0005433846946	13842	7	2D
0005433847060	13842	8	2C
0005435282822	13842	9	3A
0005435282817	13842	10	3D
0005435282812	13842	11	3C
0005433847056	13842	12	3F
0005433847053	13842	13	4C
0005433846986	13842	14	4A
0005433847040	13842	15	5A
0005435282820	13842	16	4F
0005435282836	13842	17	4D
0005433815403	13842	18	5C
0005433847109	13842	19	5F
0005433846838	13842	20	5D
0005433815396	13842	21	6B
0005433847127	13842	22	6A
0005433847025	13842	23	6C
0005433846957	13842	24	6E
0005435282825	13842	25	6D
0005433847028	13842	26	7A
0005433846839	13842	27	6F
0005433846947	13842	28	7C
0005433846988	13842	29	7B
0005435282831	13842	30	7D
0005435282839	13842	31	8A
0005433815412	13842	32	7E
0005435282816	13842	33	8E
0005433847205	13842	34	8D
0005433815401	13842	35	8C
0005433846970	13842	36	8F
0005433846857	13842	37	9B
0005433846798	13842	38	9C
0005433846952	13842	39	9F
0005433846978	13842	40	9E
0005433846991	13842	41	9D
0005435282835	13842	42	10B
0005435282815	13842	43	10A
0005435282832	13842	44	10C
0005433846858	13842	45	10E
0005435282841	13842	46	10D
0005435282837	13842	47	10F
0005434173573	13842	48	11B
0005433846884	13842	49	11A
0005433847064	13842	50	11D
0005433846987	13842	51	11C
0005433846783	13842	52	11F
0005435282814	13842	53	11E
0005433846996	13842	54	12B
0005433847063	13842	55	12A
0005433846852	13842	56	12C
0005433847069	13842	57	12E
0005433846885	13842	58	12D
0005433846945	13842	59	13A
0005434173574	13842	60	12F
0005433846799	13842	61	13C
0005435282821	13842	62	13B
0005433846886	13842	63	13D
0005433846995	13842	64	14A
0005435282834	13842	65	13F
0005433847033	13842	66	14B
0005432003744	13842	67	14D
0005433846853	13842	68	14C
0005433847041	13842	69	14F
0005433846818	13842	70	14E
0005432003743	13842	71	15B
0005433847096	13842	72	15A
0005435282838	13842	73	15C
0005433815402	13842	74	15F
0005433847022	13842	75	15E
0005435282824	13842	76	15D
0005435282833	13842	77	16A
0005435282840	13842	78	16C
0005435282823	13842	79	16B
0005433846967	13842	80	16F
0005432003742	13842	81	17C
0005433846958	13842	82	17B
0005433846890	13842	83	17D
0005435282813	13842	84	17F
0005433847039	13842	85	17E
0005433846833	13842	86	18A
0005433847055	13842	87	18C
0005435282829	13842	88	18B
0005433847029	13842	89	18E
0005433847010	13842	90	18D
0005435282830	13842	91	18F
0005433847054	13842	92	19C
0005433847051	13842	93	19B
0005435282828	13842	94	19E
0005433846979	13842	95	19D
0005433846964	13842	96	19F
0005433846990	13842	97	20A
0005433847034	13842	98	20C
0005435282827	13842	99	20D
0005434173572	13842	100	21B
0005434173571	13842	101	21A
0005433847011	13842	102	21D
0005433846971	13842	103	21C
0005435282826	13842	104	21E
0005435332385	7808	1	1A
0005435332408	7808	2	1B
0005434620869	7808	3	1C
0005434620856	7808	4	2B
0005434620868	7808	5	2D
0005434620871	7808	6	2C
0005435332386	7808	7	3A
0005434620861	7808	8	3B
0005434620860	7808	9	3C
0005432112546	7808	10	3D
0005435332421	7808	11	4A
0005434620867	7808	12	4B
0005434620872	7808	13	4C
0005432112547	7808	14	5A
0005435332352	7808	15	5B
0005434620865	7808	16	5C
0005435332418	7808	17	5D
0005434620855	7808	18	6C
0005434620858	7808	19	6D
0005435332404	7808	20	7C
0005435332400	7808	21	7D
0005434620854	7808	22	18A
0005435332367	7808	23	18B
0005434620863	7808	24	18C
0005434620866	7808	25	18D
0005434620859	7808	26	19B
0005434620857	7808	27	19C
0005434620862	7808	28	20A
0005435332422	7808	29	20B
0005435332353	7808	30	20D
0005435332423	7808	31	21B
0005435332362	7808	32	21C
0005435332419	7808	33	22A
0005434620873	7808	34	22B
0005434620870	7808	35	22D
0005434620864	7808	36	23B
0005435332475	32988	1	2A
0005434620640	32988	2	2B
0005434620714	32988	3	2C
0005435332468	32988	4	2D
0005434620713	32988	5	4A
0005434620656	32988	6	4B
0005434620637	32988	7	4C
0005434620732	32988	8	4D
0005435332467	32988	9	5A
0005434620679	32988	10	5C
0005434620579	32988	11	5D
0005434620733	32988	12	6A
0005435332474	32988	13	6B
0005435332473	32988	14	6C
0005434620641	32988	15	6D
0005434620716	32988	16	18A
0005434620749	32988	17	18B
0005435332470	32988	18	18C
0005434620687	32988	19	18D
0005434620734	32988	20	19B
0005434620664	32988	21	19C
0005435332469	32988	22	19D
0005434620735	32988	23	20A
0005435332471	32988	24	20B
0005434620719	32988	25	20D
0005434620659	32988	26	21A
0005434620655	32988	27	21C
0005435332472	32988	28	21D
0005434620717	32988	29	22A
0005434620745	32988	30	22C
0005435332466	32988	31	22D
0005435918658	4309	1	3F
0005435785822	4309	2	1C
0005434994146	4309	3	1F
0005435785804	4309	4	2A
0005435937394	4309	5	2C
0005432190679	4309	6	2D
0005435787384	4309	7	4A
0005435785810	4309	8	4C
0005432190678	4309	9	4E
0005435785802	4309	10	5A
0005435785796	4309	11	5E
0005434994147	4309	12	5F
0005435787382	4309	13	6A
0005435937397	4309	14	6C
0005435785794	4309	15	6F
0005435785814	4309	16	7A
0005435785798	4309	17	7C
0005435937398	4309	18	7D
0005435785803	4309	19	7E
0005435918673	4309	20	8A
0005435785807	4309	21	8C
0005435785824	4309	22	8D
0005435785819	4309	23	8E
0005435918682	4309	24	9A
0005435785817	4309	25	9D
0005435918672	4309	26	9E
0005435785800	4309	27	9F
0005435785821	4309	28	10C
0005432190681	4309	29	10D
0005434994145	4309	30	10F
0005435785801	4309	31	11D
0005435937399	4309	32	11E
0005435937396	4309	33	11F
0005434994149	4309	34	12A
0005434994150	4309	35	12C
0005435785791	4309	36	12D
0005435937391	4309	37	12E
0005435785812	4309	38	12F
0005435785811	4309	39	13A
0005434994151	4309	40	13D
0005434994154	4309	41	13F
0005434994153	4309	42	14A
0005435785820	4309	43	14C
0005432190680	4309	44	14D
0005435785799	4309	45	14E
0005435785816	4309	46	14F
0005434994148	4309	47	15A
0005435785795	4309	48	15D
0005435785808	4309	49	15E
0005434994152	4309	50	16A
0005435785805	4309	51	16C
0005435785825	4309	52	16D
0005435785806	4309	53	16E
0005435787383	4309	54	16F
0005435785809	4309	55	17A
0005435785797	4309	56	17C
0005435785826	4309	57	17F
0005435918688	4309	58	18A
0005435918700	4309	59	18E
0005435785818	4309	60	19A
0005435785815	4309	61	19E
0005435785813	4309	62	19F
0005435785823	4309	63	20A
0005435785793	4309	64	20C
0005435785792	4309	65	20D
0005435918701	4309	66	20E
0005435785347	27291	1	1A
0005434994097	27291	2	1C
0005435785484	27291	3	1F
0005435785520	27291	4	2A
0005435785387	27291	5	2F
0005435787364	27291	6	3D
0005435785399	27291	7	4A
0005435937439	27291	8	4C
0005435785455	27291	9	4E
0005435785430	27291	10	5A
0005435785398	27291	11	5C
0005435937437	27291	12	5D
0005432195718	27291	13	5E
0005435785468	27291	14	5F
0005434994111	27291	15	6C
0005435918721	27291	16	6E
0005434994112	27291	17	6F
0005435785471	27291	18	7A
0005434993997	27291	19	7D
0005435785417	27291	20	7E
0005434994039	27291	21	7F
0005435785376	27291	22	8A
0005435918717	27291	23	8D
0005434994068	27291	24	8E
0005435785364	27291	25	8F
0005432195719	27291	26	9A
0005435785441	27291	27	9C
0005435785466	27291	28	9D
0005435785259	27291	29	9E
0005435785363	27291	30	9F
0005435785499	27291	31	10A
0005432195720	27291	32	10D
0005434994075	27291	33	10F
0005435787365	27291	34	11A
0005435787363	27291	35	11C
0005434994080	27291	36	11D
0005435785431	27291	37	11E
0005435785540	27291	38	12A
0005434994079	27291	39	12C
0005435785396	27291	40	12E
0005434994038	27291	41	12F
0005434994076	27291	42	13A
0005434994081	27291	43	13C
0005435785496	27291	44	13D
0005435937438	27291	45	13E
0005435785495	27291	46	13F
0005435918720	27291	47	14F
0005435785485	27291	48	15A
0005434994074	27291	49	15C
0005435785348	27291	50	15D
0005435785394	27291	51	15E
0005435785393	27291	52	15F
0005435785567	27291	53	16A
0005435785320	27291	54	16D
0005435918718	27291	55	16F
0005435785397	27291	56	17A
0005435785319	27291	57	17C
0005435785401	27291	58	17D
0005435785558	27291	59	17E
0005434994101	27291	60	17F
0005435785409	27291	61	18A
0005435785400	27291	62	18C
0005435785372	27291	63	18D
0005435785452	27291	64	18E
0005434994093	27291	65	18F
0005435918719	27291	66	19A
0005435918716	27291	67	19C
0005435787355	27291	68	19D
0005435785377	27291	69	19E
0005435785503	27291	70	20C
0005434994066	27291	71	20E
0005432146223	19899	1	3A
0005432146225	19899	2	3B
0005432146226	19899	3	3C
0005432146224	19899	4	6D
0005432146227	19899	5	7B
0005434082207	4701	1	1B
0005432186918	4701	2	1F
0005432568453	4701	3	1C
0005432460551	4701	4	1G
0005432568408	4701	5	2A
0005432568445	4701	6	1H
0005432170480	4701	7	2C
0005432568430	4701	8	2B
0005434082199	4701	9	2F
0005432460548	4701	10	2G
0005432568436	4701	11	2H
0005432460506	4701	12	3C
0005432460509	4701	13	3B
0005432170474	4701	14	3F
0005432571372	4701	15	4F
0005432568463	4701	16	4C
0005432460525	4701	17	4G
0005434082198	4701	18	5A
0005432460543	4701	19	4H
0005432568415	4701	20	5G
0005432568450	4701	21	5F
0005432460520	4701	22	5H
0005432460542	4701	23	9B
0005434082218	4701	24	9A
0005432460524	4701	25	9H
0005433726133	4701	26	11B
0005432460537	4701	27	11E
0005432571369	4701	28	11D
0005434082216	4701	29	11F
0005432571371	4701	30	11H
0005432568454	4701	31	11G
0005432568437	4701	32	12D
0005434082208	4701	33	12B
0005432460516	4701	34	12E
0005432186917	4701	35	12F
0005432568452	4701	36	12H
0005432460545	4701	37	12G
0005432460530	4701	38	13A
0005432568419	4701	39	13E
0005432460555	4701	40	13F
0005432460532	4701	41	14A
0005432568424	4701	42	13H
0005433452767	4701	43	14B
0005433726135	4701	44	14F
0005432568444	4701	45	14E
0005432568451	4701	46	14G
0005433451645	4701	47	15A
0005432460512	4701	48	14H
0005433451646	4701	49	15B
0005434082210	4701	50	15D
0005432568435	4701	51	15G
0005432460529	4701	52	16A
0005432460507	4701	53	15H
0005434082204	4701	54	16D
0005432460527	4701	55	16B
0005434082217	4701	56	16F
0005432568423	4701	57	16H
0005432170476	4701	58	17D
0005432568428	4701	59	17B
0005432568434	4701	60	17E
0005432568414	4701	61	17G
0005432568412	4701	62	17H
0005432568404	4701	63	18B
0005432460510	4701	64	18F
0005432460556	4701	65	18E
0005432460541	4701	66	18H
0005434082219	4701	67	19D
0005432460544	4701	68	19B
0005432568416	4701	69	19A
0005432460553	4701	70	19E
0005432460538	4701	71	19G
0005432568458	4701	72	19H
0005434082211	4701	73	20D
0005432568417	4701	74	20B
0005433726134	4701	75	20E
0005434082214	4701	76	20F
0005432568421	4701	77	20H
0005432170477	4701	78	20G
0005432568422	4701	79	21A
0005432568456	4701	80	21D
0005432460554	4701	81	21E
0005434082213	4701	82	21F
0005434082209	4701	83	22A
0005432170479	4701	84	22E
0005432568460	4701	85	22G
0005434082206	4701	86	22H
0005434082202	4701	87	23B
0005432460526	4701	88	23A
0005432170478	4701	89	23E
0005432568455	4701	90	23G
0005432568433	4701	91	23F
0005432568447	4701	92	24B
0005432460546	4701	93	24F
0005432460533	4701	94	24G
0005432568438	4701	95	25D
0005432460517	4701	96	25E
0005432460523	4701	97	27B
0005432568432	4701	98	27A
0005432460536	4701	99	27D
0005434082201	4701	100	27F
0005432568442	4701	101	27G
0005432568426	4701	102	28A
0005432571370	4701	103	27H
0005432568410	4701	104	28D
0005432460550	4701	105	28G
0005432568407	4701	106	28F
0005432460539	4701	107	28H
0005432460515	4701	108	29A
0005432568446	4701	109	29B
0005432568403	4701	110	29E
0005434082205	4701	111	29F
0005432568413	4701	112	29G
0005432170475	4701	113	30A
0005432460511	4701	114	30D
0005432460519	4701	115	30F
0005432460557	4701	116	30E
0005432568464	4701	117	30G
0005432568418	4701	118	30H
0005434082215	4701	119	31E
0005432568461	4701	120	31D
0005432460513	4701	121	31G
0005434082212	4701	122	31H
0005432460535	4701	123	32B
0005432568439	4701	124	32G
0005432460547	4701	125	32F
0005432568443	4701	126	32H
0005432460558	4701	127	33A
0005432186919	4701	128	33D
0005432568449	4701	129	33E
0005434082200	4701	130	33F
0005432568440	4701	131	34D
0005432568459	4701	132	34B
0005432460508	4701	133	34F
0005432568462	4701	134	34G
0005432460549	4701	135	34H
0005432460518	4701	136	35D
0005432568441	4701	137	35F
0005432568431	4701	138	35E
0005432568409	4701	139	35G
0005432460521	4701	140	35H
0005432460540	4701	141	36A
0005432568406	4701	142	36E
0005432460534	4701	143	36D
0005432460514	4701	144	36F
0005432568427	4701	145	36G
0005432460531	4701	146	37A
0005434082197	4701	147	36H
0005434082203	4701	148	37B
0005432568425	4701	149	37E
0005432568405	4701	150	37D
0005432568429	4701	151	37F
0005432568411	4701	152	37G
0005432460528	4701	153	37H
0005432568457	4701	154	38D
0005432568448	4701	155	38B
0005432170473	4701	156	38E
0005432460522	4701	157	38F
0005432568420	4701	158	38G
0005432460552	4701	159	39D
0005432571343	30556	1	1A
0005432567995	30556	2	1B
0005432567996	30556	3	1F
0005432460301	30556	4	1H
0005434082091	30556	5	1G
0005432567976	30556	6	2A
0005432460090	30556	7	2F
0005432460112	30556	8	2C
0005433726093	30556	9	2G
0005434081956	30556	10	3A
0005432460001	30556	11	2H
0005432568128	30556	12	3C
0005432459928	30556	13	3B
0005433454880	30556	14	3F
0005432568116	30556	15	3H
0005432568034	30556	16	3G
0005432568046	30556	17	4B
0005432460096	30556	18	4A
0005432460302	30556	19	4F
0005432567749	30556	20	4C
0005432567997	30556	21	4G
0005432567816	30556	22	5A
0005432460075	30556	23	5B
0005432460113	30556	24	5C
0005432567991	30556	25	5G
0005432571347	30556	26	5F
0005434081907	30556	27	9A
0005432460271	30556	28	5H
0005433726104	30556	29	9B
0005432567879	30556	30	9G
0005432459857	30556	31	11A
0005432460145	30556	32	11B
0005433454879	30556	33	11E
0005432568118	30556	34	11D
0005432567812	30556	35	11F
0005432460320	30556	36	11G
0005432460027	30556	37	12A
0005432567913	30556	38	11H
0005432567679	30556	39	12D
0005432567953	30556	40	12B
0005434082071	30556	41	12F
0005434081887	30556	42	12H
0005433726095	30556	43	12G
0005432161181	30556	44	13A
0005434082073	30556	45	13D
0005434081940	30556	46	13B
0005432567814	30556	47	13E
0005432459990	30556	48	13G
0005432459953	30556	49	13F
0005432568198	30556	50	13H
0005434081948	30556	51	14B
0005432568144	30556	52	14A
0005432460147	30556	53	14E
0005432567813	30556	54	14D
0005432567904	30556	55	14F
0005434082090	30556	56	14G
0005432568014	30556	57	15A
0005432460267	30556	58	15B
0005432567943	30556	59	15E
0005432567729	30556	60	15F
0005432460287	30556	61	15G
0005432460077	30556	62	15H
0005433454896	30556	63	16D
0005432460124	30556	64	16B
0005432460111	30556	65	16F
0005434081878	30556	66	16E
0005432567966	30556	67	16H
0005433726106	30556	68	16G
0005432460137	30556	69	17D
0005432568042	30556	70	17B
0005432567591	30556	71	17F
0005432568110	30556	72	17E
0005432460066	30556	73	17G
0005432568171	30556	74	17H
0005432567933	30556	75	18A
0005432567980	30556	76	18D
0005434081976	30556	77	18B
0005434081959	30556	78	18F
0005432459952	30556	79	18E
0005432567964	30556	80	18G
0005432568002	30556	81	18H
0005432567983	30556	82	19B
0005434081992	30556	83	19E
0005433726079	30556	84	19D
0005433726096	30556	85	19H
0005432568181	30556	86	19G
0005433726108	30556	87	20A
0005432460097	30556	88	20B
0005432460134	30556	89	20E
0005432568182	30556	90	20D
0005432567906	30556	91	20G
0005432161182	30556	92	20F
0005432460322	30556	93	20H
0005434082025	30556	94	21A
0005432460138	30556	95	21D
0005432460073	30556	96	21B
0005434081936	30556	97	21G
0005432567874	30556	98	21F
0005432213656	30556	99	21H
0005432460095	30556	100	22A
0005432568094	30556	101	22D
0005432567873	30556	102	22B
0005432567680	30556	103	22F
0005432460123	30556	104	22E
0005433726105	30556	105	22G
0005432460114	30556	106	22H
0005434081918	30556	107	23A
0005434081879	30556	108	23F
0005432460076	30556	109	23G
0005432460101	30556	110	24A
0005432568033	30556	111	23H
0005432460026	30556	112	24B
0005434081999	30556	113	24E
0005432568165	30556	114	24D
0005433452749	30556	115	24F
0005432460246	30556	116	24G
0005432460172	30556	117	25D
0005432460314	30556	118	24H
0005432460074	30556	119	25E
0005432213655	30556	120	25F
0005433726103	30556	121	27D
0005432568180	30556	122	27B
0005434081876	30556	123	27E
0005432460232	30556	124	27F
0005432568169	30556	125	27G
0005432567788	30556	126	28A
0005432567990	30556	127	27H
0005433726086	30556	128	28E
0005432460099	30556	129	28D
0005432567880	30556	130	28G
0005432567954	30556	131	29A
0005432568245	30556	132	28H
0005433726110	30556	133	29B
0005432567815	30556	134	29F
0005432459840	30556	135	29E
0005434081888	30556	136	29D
0005434081898	30556	137	29G
0005434081877	30556	138	29H
0005432567595	30556	139	30B
0005432460315	30556	140	30A
0005432460227	30556	141	30D
0005432568043	30556	142	30F
0005432213657	30556	143	30G
0005432460061	30556	144	30H
0005432567850	30556	145	31B
0005432567836	30556	146	31F
0005432567851	30556	147	31E
0005432567910	30556	148	31G
0005434082024	30556	149	32A
0005434081919	30556	150	32B
0005434081925	30556	151	32D
0005434081822	30556	152	32F
0005434081915	30556	153	32E
0005432460062	30556	154	32G
0005432568087	30556	155	33A
0005432567903	30556	156	32H
0005432161183	30556	157	33E
0005432567554	30556	158	33G
0005432568197	30556	159	33F
0005434081975	30556	160	33H
0005432568065	30556	161	34B
0005432459991	30556	162	34A
0005433454897	30556	163	34G
0005434081958	30556	164	34F
0005434082021	30556	165	34H
0005432568179	30556	166	35B
0005432567955	30556	167	35A
0005432460170	30556	168	35E
0005432567923	30556	169	35D
0005432460193	30556	170	35G
0005432460035	30556	171	35F
0005434082068	30556	172	36A
0005432460146	30556	173	35H
0005432460100	30556	174	36B
0005432567852	30556	175	36D
0005432568066	30556	176	36E
0005432213654	30556	177	36G
0005434081998	30556	178	37A
0005432567926	30556	179	36H
0005432567867	30556	180	37B
0005432460115	30556	181	37D
0005433726076	30556	182	37F
0005433726101	30556	183	37H
0005433726109	30556	184	37G
0005432571348	30556	185	38A
0005432571341	30556	186	38D
0005432568004	30556	187	38B
0005432460266	30556	188	38E
0005432567789	30556	189	38G
0005432568086	30556	190	38F
0005432459909	30556	191	38H
0005432460321	30556	192	39E
0005432571342	30556	193	39D
0005433726097	30556	194	39F
0005435722087	13640	1	2A
0005435720839	13640	2	3A
0005435722086	13640	3	5A
0005435722088	13640	4	6A
0005435720840	13640	5	6B
0005435720137	21140	1	2A
0005435720138	21140	2	2B
0005435722067	21140	3	4B
0005435720139	21140	4	6A
0005435720136	21140	5	6B
0005432295915	22760	1	7B
0005432295913	22760	2	18C
0005432295914	22760	3	21C
0005433344524	11130	1	15E
0005433344466	11130	2	1D
0005433344450	11130	3	1C
0005433344512	11130	4	1A
0005435508415	11130	5	1F
0005433344458	11130	6	2C
0005435508373	11130	7	2A
0005433344495	11130	8	2F
0005433344477	11130	9	2D
0005433344451	11130	10	3C
0005433344436	11130	11	3A
0005435508421	11130	12	3D
0005433344513	11130	13	3F
0005433344519	11130	14	4A
0005435097330	11130	15	4B
0005435508399	11130	16	4D
0005435508441	11130	17	4C
0005433344486	11130	18	4E
0005435508397	11130	19	4F
0005433344479	11130	20	5B
0005433344517	11130	21	5A
0005433344501	11130	22	5C
0005433344480	11130	23	5D
0005433344491	11130	24	5E
0005435380319	11130	25	6A
0005433344470	11130	26	5F
0005433344492	11130	27	6B
0005433344463	11130	28	6C
0005433344438	11130	29	6D
0005433344454	11130	30	6E
0005433344523	11130	31	6F
0005433344518	11130	32	7B
0005433344525	11130	33	7A
0005433344521	11130	34	7C
0005433344499	11130	35	7D
0005433344448	11130	36	7F
0005433344467	11130	37	7E
0005433344471	11130	38	8B
0005433344449	11130	39	8A
0005433344439	11130	40	8C
0005433344465	11130	41	8D
0005433344443	11130	42	8F
0005435508396	11130	43	8E
0005435097325	11130	44	9A
0005433344504	11130	45	9B
0005435097326	11130	46	9C
0005433344472	11130	47	9E
0005435508403	11130	48	9D
0005433344440	11130	49	10B
0005433344457	11130	50	9F
0005433344441	11130	51	10C
0005433344506	11130	52	10E
0005435097323	11130	53	10D
0005435508407	11130	54	11A
0005433344530	11130	55	11B
0005435508408	11130	56	11D
0005435508404	11130	57	11C
0005433344522	11130	58	11E
0005433344445	11130	59	11F
0005433344452	11130	60	12B
0005433344488	11130	61	12A
0005433344533	11130	62	12C
0005435508422	11130	63	12D
0005435097331	11130	64	12E
0005435508402	11130	65	12F
0005433344455	11130	66	13A
0005433344460	11130	67	13B
0005433344435	11130	68	13D
0005433344462	11130	69	13C
0005433344526	11130	70	13E
0005433344484	11130	71	13F
0005433344447	11130	72	14B
0005433344505	11130	73	14A
0005433344520	11130	74	14C
0005433344529	11130	75	14E
0005433344459	11130	76	14D
0005433344469	11130	77	15A
0005435097329	11130	78	14F
0005433344487	11130	79	15B
0005433344531	11130	80	15C
0005433344489	11130	81	15D
0005433344433	11130	82	16A
0005435508416	11130	83	15F
0005433344434	11130	84	16D
0005433344475	11130	85	16C
0005433344497	11130	86	16B
0005435097322	11130	87	16E
0005433344502	11130	88	16F
0005433344453	11130	89	17A
0005433344496	11130	90	17B
0005433344485	11130	91	17C
0005435508405	11130	92	17D
0005433344532	11130	93	17F
0005433344468	11130	94	17E
0005433344481	11130	95	18A
0005433344527	11130	96	18B
0005433344498	11130	97	18C
0005433344456	11130	98	18E
0005435508423	11130	99	18D
0005433344461	11130	100	18F
0005433344493	11130	101	19B
0005433344500	11130	102	19A
0005433344516	11130	103	19C
0005433344474	11130	104	19D
0005433344483	11130	105	19E
0005435380271	11130	106	19F
0005433344478	11130	107	20A
0005435097328	11130	108	20C
0005433344510	11130	109	20B
0005433344511	11130	110	20D
0005433344515	11130	111	20E
0005433344514	11130	112	20F
0005433344482	11130	113	21B
0005433344509	11130	114	21A
0005433344508	11130	115	21C
0005433344507	11130	116	21D
0005433344490	11130	117	21E
0005433344528	11130	118	21F
0005433344503	11130	119	22B
0005433344437	11130	120	22A
0005433344494	11130	121	22C
0005433344464	11130	122	22D
0005433344442	11130	123	22E
0005433344476	11130	124	23A
0005433344473	11130	125	22F
0005433344446	11130	126	23B
0005433344444	11130	127	23C
0005435097327	11130	128	23E
0005435380326	11130	129	23D
0005435097324	11130	130	23F
0005433343484	17096	1	12D
0005433343276	17096	2	1D
0005433343499	17096	3	2A
0005433343594	17096	4	2C
0005433343568	17096	5	2D
0005433343533	17096	6	2F
0005435097230	17096	7	3C
0005433343651	17096	8	3A
0005433343405	17096	9	1A
0005435097227	17096	10	3D
0005433343468	17096	11	3F
0005433343680	17096	12	4A
0005432293241	17096	13	4B
0005433343278	17096	14	4C
0005433343739	17096	15	4E
0005433343783	17096	16	4D
0005433343615	17096	17	4F
0005433343855	17096	18	5B
0005433343429	17096	19	5A
0005433343356	17096	20	5C
0005433343584	17096	21	5D
0005435097242	17096	22	5E
0005433343620	17096	23	5F
0005433343419	17096	24	6A
0005433343732	17096	25	6C
0005433343766	17096	26	6D
0005435097214	17096	27	6E
0005433343573	17096	28	6F
0005433343652	17096	29	7B
0005433343662	17096	30	7A
0005433343344	17096	31	7C
0005433343452	17096	32	7E
0005433343661	17096	33	7D
0005433343784	17096	34	1C
0005433343338	17096	35	8B
0005433342980	17096	36	8A
0005433343806	17096	37	8D
0005433343707	17096	38	8C
0005433343621	17096	39	8E
0005435097255	17096	40	8F
0005433343748	17096	41	9A
0005433343698	17096	42	9B
0005433343575	17096	43	9C
0005433343454	17096	44	9D
0005433343331	17096	45	9F
0005433343414	17096	46	9E
0005433343527	17096	47	10B
0005433343840	17096	48	10C
0005433343493	17096	49	10E
0005433343301	17096	50	10D
0005433343492	17096	51	11A
0005433343567	17096	52	11B
0005433343431	17096	53	11C
0005435097241	17096	54	11E
0005433343345	17096	55	11D
0005433343557	17096	56	12A
0005433343691	17096	57	12C
0005433343127	17096	58	12B
0005433343549	17096	59	1F
0005433343552	17096	60	12E
0005433343343	17096	61	13A
0005435097215	17096	62	13B
0005433343380	17096	63	13D
0005433343513	17096	64	13C
0005433343964	17096	65	13E
0005433343757	17096	66	14A
0005433343816	17096	67	13F
0005433343595	17096	68	14B
0005433343279	17096	69	14E
0005433343510	17096	70	14F
0005435380359	17096	71	15B
0005433343859	17096	72	15A
0005433343643	17096	73	15C
0005433342979	17096	74	15D
0005433343339	17096	75	15E
0005433343300	17096	76	16A
0005435545845	17096	77	15F
0005435097266	17096	78	16B
0005433343708	17096	79	16C
0005433343709	17096	80	16D
0005435380361	17096	81	16E
0005433343751	17096	82	16F
0005435380360	17096	83	17B
0005433343039	17096	84	17A
0005432293240	17096	85	17C
0005433343332	17096	86	17D
0005433343347	17096	87	17F
0005433343202	17096	88	17E
0005432293242	17096	89	18A
0005433343275	17096	90	18B
0005433343193	17096	91	18C
0005433343316	17096	92	18E
0005433343400	17096	93	18D
0005433342978	17096	94	18F
0005433343717	17096	95	19A
0005435097234	17096	96	19B
0005433343194	17096	97	19C
0005433343965	17096	98	19E
0005433343610	17096	99	19D
0005433343611	17096	100	19F
0005433343509	17096	101	20A
0005433343498	17096	102	20C
0005433343317	17096	103	20B
0005433343333	17096	104	20E
0005433343432	17096	105	20D
0005433343415	17096	106	20F
0005433343550	17096	107	21B
0005435380362	17096	108	21A
0005433342964	17096	109	21C
0005433343697	17096	110	21D
0005435545846	17096	111	21F
0005433343805	17096	112	21E
0005433343656	17096	113	22B
0005433343514	17096	114	22A
0005433343731	17096	115	22C
0005433343428	17096	116	22D
0005433343231	17096	117	22F
0005433343453	17096	118	22E
0005433343660	17096	119	23A
0005433342963	17096	120	23B
0005433343966	17096	121	23C
0005435380358	17096	122	23E
0005433343616	17096	123	23D
0005433343406	17096	124	23F
0005433507426	9111	1	6D
0005433507417	9111	2	1D
0005433481273	9111	3	1F
0005433481267	9111	4	3A
0005433507414	9111	5	3C
0005433507427	9111	6	3F
0005433481271	9111	7	4A
0005432919992	9111	8	4C
0005433507408	9111	9	4E
0005432920071	9111	10	4F
0005433507407	9111	11	5C
0005433507415	9111	12	5D
0005433507429	9111	13	5F
0005432919905	9111	14	6C
0005432920082	9111	15	17E
0005433481268	9111	16	18A
0005432919918	9111	17	19A
0005433507410	9111	18	19D
0005432920081	9111	19	19E
0005433507411	9111	20	19F
0005433507423	9111	21	20D
0005432919893	9111	22	1C
0005433507424	9111	23	6F
0005433507413	9111	24	7A
0005432919966	9111	25	7C
0005432919993	9111	26	7E
0005433481272	9111	27	8D
0005433481269	9111	28	9C
0005433507425	9111	29	9E
0005433507412	9111	30	10A
0005433507422	9111	31	10D
0005433507409	9111	32	11A
0005432920080	9111	33	11C
0005433507418	9111	34	11E
0005432919934	9111	35	11F
0005432919960	9111	36	12D
0005433507428	9111	37	12F
0005433507416	9111	38	13A
0005432919804	9111	39	13D
0005432919950	9111	40	14A
0005432920024	9111	41	14D
0005432919970	9111	42	14E
0005432919954	9111	43	14F
0005432919796	9111	44	15A
0005433507420	9111	45	15C
0005433481270	9111	46	16A
0005433507419	9111	47	16C
0005433507421	9111	48	16D
0005432919961	9111	49	16E
0005432919999	9111	50	17A
0005432920163	20491	1	5F
0005433507259	20491	2	11F
0005432920155	20491	3	10F
0005432920164	20491	4	10D
0005433507240	20491	5	20F
0005432920148	20491	6	16C
0005433507191	20491	7	13E
0005433507301	20491	8	5D
0005433507304	20491	9	7D
0005432920161	20491	10	11A
0005433507283	20491	11	16A
0005432920158	20491	12	19E
0005432920147	20491	13	14C
0005433507266	20491	14	17D
0005433507161	20491	15	6C
0005433481235	20491	16	5C
0005432920162	20491	17	2F
0005433481212	20491	18	16E
0005433507299	20491	19	13A
0005433507277	20491	20	8C
0005432920157	20491	21	4C
0005432920154	20491	22	17C
0005433481234	20491	23	4A
0005432920165	20491	24	20A
0005433507262	20491	25	10E
0005433507261	20491	26	15F
0005433481208	20491	27	7C
0005433481206	20491	28	4F
0005433507243	20491	29	20D
0005432920150	20491	30	17F
0005433481207	20491	31	12E
0005433507296	20491	32	14D
0005433507293	20491	33	15A
0005433507279	20491	34	18C
0005432920146	20491	35	13F
0005432920153	20491	36	18D
0005433507260	20491	37	9C
0005433507278	20491	38	7A
0005433507300	20491	39	1F
0005433507295	20491	40	3F
0005432920151	20491	41	13D
0005433507294	20491	42	3A
0005433481213	20491	43	3C
0005433507282	20491	44	7E
0005432920156	20491	45	5A
0005432920149	20491	46	2A
0005432920160	20491	47	1A
0005432920152	20491	48	14F
0005432920159	20491	49	20E
0005433507256	20491	50	6F
0005433507220	20491	51	18E
0005432394153	10147	1	2B
0005432394154	10147	2	3B
0005432396293	10147	3	3A
0005435178997	10147	4	4A
0005432394155	10147	5	5B
0005435179694	10147	6	6B
0005432396294	10147	7	4B
0005435179695	10147	8	1A
0005435178992	10147	9	1B
0005432396268	18383	1	4B
0005432396253	18383	2	1A
0005432400134	18383	3	1B
0005432396261	18383	4	2A
0005432400133	18383	5	2B
0005435179406	18383	6	3A
0005432400138	18383	7	3B
0005432396252	18383	8	4A
0005432400139	18383	9	5A
0005432400150	18383	10	5B
0005432400151	18383	11	6A
0005432400152	18383	12	6B
0005435126509	10962	1	1A
0005435626198	10962	2	1C
0005435626253	10962	3	1D
0005435626192	10962	4	1F
0005435126552	10962	5	2D
0005435126373	10962	6	2F
0005435126598	10962	7	3C
0005434411837	10962	8	3F
0005435126557	10962	9	4D
0005435126732	10962	10	4E
0005435126374	10962	11	4F
0005434928336	10962	12	5A
0005435126464	10962	13	5C
0005435626190	10962	14	5D
0005435126465	10962	15	5E
0005435126575	10962	16	5F
0005435126425	10962	17	6A
0005435126413	10962	18	6D
0005434928337	10962	19	6E
0005435626244	10962	20	7A
0005435126429	10962	21	6F
0005435126570	10962	22	7C
0005435556688	10962	23	7D
0005435626243	10962	24	7E
0005435126386	10962	25	7F
0005435126553	10962	26	8A
0005435126571	10962	27	8C
0005435126398	10962	28	8E
0005435126723	10962	29	8F
0005435126631	10962	30	9D
0005434411836	10962	31	9E
0005435626234	10962	32	9F
0005435626233	10962	33	10A
0005435626191	10962	34	10C
0005435626201	10962	35	10D
0005434928338	10962	36	11A
0005434411834	10962	37	11D
0005435126491	10962	38	11E
0005435126399	10962	39	11F
0005435126462	10962	40	12A
0005435126523	10962	41	12D
0005435126699	10962	42	12F
0005434411835	10962	43	13A
0005435126525	10962	44	13D
0005435126387	10962	45	13E
0005435626182	10962	46	13F
0005435556710	10962	47	14A
0005435554212	10962	48	14C
0005435554206	10962	49	14E
0005435126480	10962	50	14F
0005435126376	10962	51	15A
0005435126479	10962	52	15C
0005435626219	10962	53	15E
0005435126558	10962	54	15F
0005435626237	10962	55	16C
0005435126444	10962	56	16E
0005435626242	10962	57	16D
0005435126503	10962	58	16F
0005435126544	10962	59	17C
0005435626202	10962	60	17D
0005435626220	10962	61	17E
0005435126490	10962	62	17F
0005435126578	10962	63	18A
0005435126461	10962	64	18C
0005435556689	10962	65	18E
0005435626259	10962	66	18F
0005435126412	10962	67	19A
0005435126426	10962	68	19C
0005435126577	10962	69	19E
0005435126524	10962	70	19F
0005435126599	10962	71	20A
0005435126430	10962	72	20C
0005435126583	10962	73	20D
0005435626261	10962	74	20E
0005435126530	10962	75	20F
0005434928301	14742	1	1A
0005435126899	14742	2	1F
0005435126897	14742	3	2A
0005435556725	14742	4	2C
0005435626417	14742	5	3A
0005435626423	14742	6	3C
0005435126916	14742	7	3D
0005435126917	14742	8	3F
0005435126919	14742	9	4A
0005435626415	14742	10	4C
0005435126905	14742	11	4D
0005435126934	14742	12	4E
0005435126935	14742	13	4F
0005435126926	14742	14	5A
0005434928307	14742	15	5C
0005435126937	14742	16	5D
0005435626430	14742	17	5E
0005435626426	14742	18	6A
0005435554248	14742	19	6C
0005435126901	14742	20	6D
0005435626432	14742	21	6E
0005435626421	14742	22	6F
0005435126912	14742	23	7C
0005435626418	14742	24	7E
0005435126928	14742	25	7F
0005435626414	14742	26	8A
0005435126930	14742	27	8C
0005435126904	14742	28	8D
0005435626422	14742	29	8E
0005434411781	14742	30	8F
0005434411785	14742	31	9A
0005435126900	14742	32	9C
0005435126911	14742	33	9D
0005435126903	14742	34	9F
0005435126924	14742	35	10A
0005435126932	14742	36	10C
0005435626425	14742	37	10D
0005435126902	14742	38	10E
0005435126915	14742	39	10F
0005434411792	14742	40	11A
0005435126908	14742	41	11E
0005435126920	14742	42	11F
0005435626428	14742	43	12C
0005435126921	14742	44	12D
0005435626419	14742	45	12E
0005435126918	14742	46	12F
0005435126923	14742	47	13A
0005435626431	14742	48	13C
0005435126929	14742	49	13D
0005435126927	14742	50	13E
0005435126906	14742	51	13F
0005435126936	14742	52	14A
0005434928316	14742	53	14C
0005435126933	14742	54	14D
0005435626427	14742	55	14E
0005435556726	14742	56	15D
0005434411786	14742	57	15F
0005435554250	14742	58	16A
0005435126922	14742	59	16D
0005435626416	14742	60	16F
0005435554247	14742	61	17A
0005435126913	14742	62	17D
0005435126909	14742	63	17E
0005435126914	14742	64	17F
0005435626420	14742	65	18A
0005435126910	14742	66	18C
0005435126931	14742	67	18E
0005435126925	14742	68	18F
0005435554249	14742	69	19A
0005435126898	14742	70	19D
0005435626424	14742	71	19E
0005435556727	14742	72	19F
0005435126907	14742	73	20C
0005435556724	14742	74	20E
0005435626429	14742	75	20F
0005435443373	7127	1	1F
0005435715695	7127	2	2C
0005435179396	7127	3	3D
0005435715705	7127	4	3F
0005435443394	7127	5	4D
0005432398250	7127	6	4E
0005435216587	7127	7	5A
0005435715703	7127	8	5E
0005435221053	7127	9	5F
0005435715701	7127	10	6A
0005435178508	7127	11	7A
0005435443371	7127	12	7E
0005435216586	7127	13	8C
0005432400174	7127	14	8E
0005435715692	7127	15	9A
0005432398248	7127	16	9F
0005435715693	7127	17	10D
0005435715689	7127	18	11A
0005435715691	7127	19	11C
0005435179399	7127	20	11D
0005435221061	7127	21	11E
0005435715702	7127	22	11F
0005435443395	7127	23	12C
0005435715694	7127	24	13A
0005435715696	7127	25	13D
0005435443315	7127	26	13F
0005432398249	7127	27	14A
0005435715700	7127	28	14D
0005435443359	7127	29	15D
0005435443363	7127	30	16D
0005435715704	7127	31	16E
0005435179397	7127	32	17A
0005435715690	7127	33	18A
0005432400175	7127	34	18C
0005435715688	7127	35	18E
0005435443349	7127	36	19C
0005435179398	7127	37	19D
0005435715698	7127	38	19E
0005432400173	7127	39	19F
0005435715697	7127	40	20D
0005435715699	7127	41	20F
0005435715512	27097	1	1A
0005435715597	27097	2	1D
0005435715511	27097	3	2D
0005432394115	27097	4	3F
0005432394110	27097	5	4D
0005432394111	27097	6	4E
0005435443441	27097	7	5A
0005435715556	27097	8	5F
0005435715541	27097	9	6E
0005432398203	27097	10	7D
0005435715546	27097	11	7E
0005435443437	27097	12	7F
0005432394114	27097	13	8C
0005435443439	27097	14	8E
0005435715542	27097	15	8F
0005432398215	27097	16	9C
0005435715567	27097	17	10A
0005435443435	27097	18	10D
0005435715537	27097	19	11A
0005435715491	27097	20	11C
0005435443442	27097	21	11F
0005435715490	27097	22	12C
0005435715555	27097	23	12D
0005435443436	27097	24	13D
0005435715487	27097	25	13F
0005432398223	27097	26	14C
0005432398224	27097	27	14D
0005435715566	27097	28	17F
0005435443443	27097	29	18C
0005435715565	27097	30	19A
0005435443440	27097	31	19F
0005432394133	27097	32	20A
0005432398214	27097	33	20C
0005435443438	27097	34	20D
0005434084994	2722	1	1A
0005434084993	2722	2	2B
0005434084992	2722	3	3B
0005434084995	2722	4	3A
0005434084991	2722	5	4B
0005434084990	2722	6	6B
0005433060449	28498	1	1A
0005434084953	28498	2	1B
0005434084960	28498	3	2A
0005434084952	28498	4	3A
0005433060448	28498	5	3B
0005433060450	28498	6	4A
0005434084948	28498	7	6A
0005434084951	28498	8	6B
0005435541159	11392	1	18A
0005435541175	11392	2	1C
0005435518025	11392	3	1F
0005435518078	11392	4	2A
0005435518016	11392	5	3A
0005435518024	11392	6	3C
0005435541126	11392	7	3F
0005435517988	11392	8	4C
0005435541083	11392	9	5C
0005435541118	11392	10	5D
0005435517998	11392	11	6F
0005435517995	11392	12	7C
0005435541026	11392	13	7D
0005435541173	11392	14	7E
0005435518093	11392	15	8E
0005435517974	11392	16	9D
0005435541117	11392	17	9F
0005435518006	11392	18	10A
0005435541145	11392	19	10D
0005435517919	11392	20	10E
0005435517920	11392	21	10F
0005435517971	11392	22	11F
0005435517981	11392	23	12C
0005435517994	11392	24	12E
0005435517975	11392	25	12D
0005435541189	11392	26	13D
0005435541140	11392	27	13E
0005435517970	11392	28	14E
0005435518012	11392	29	15A
0005435541101	11392	30	15C
0005435541190	11392	31	15D
0005435518047	11392	32	16E
0005435517987	11392	33	17D
0005435518034	11392	34	17E
0005435541174	11392	35	18D
0005435541066	11392	36	20C
0005435541139	11392	37	20E
0005435517982	11392	38	20F
0005435529530	22245	1	10A
0005435541279	22245	2	5F
0005435529537	22245	3	6D
0005435541275	22245	4	6E
0005435529538	22245	5	7A
0005435541271	22245	6	7C
0005435529540	22245	7	8C
0005435529521	22245	8	8F
0005435541281	22245	9	9A
0005435529529	22245	10	9C
0005435529534	22245	11	9D
0005432294518	22245	12	9E
0005435529536	22245	13	9F
0005435529531	22245	14	10C
0005435541269	22245	15	10F
0005435541282	22245	16	11A
0005435541284	22245	17	11C
0005435541283	22245	18	12A
0005435541267	22245	19	12E
0005435541280	22245	20	12F
0005435529535	22245	21	13A
0005435541268	22245	22	13F
0005435541266	22245	23	14C
0005435529541	22245	24	14D
0005435541276	22245	25	14E
0005435541286	22245	26	14F
0005432294516	22245	27	15D
0005435541277	22245	28	16C
0005435541278	22245	29	16E
0005435529532	22245	30	17A
0005435529522	22245	31	17D
0005435541272	22245	32	17E
0005435541274	22245	33	17F
0005435529542	22245	34	18C
0005435529533	22245	35	18E
0005435529527	22245	36	19F
0005435541270	22245	37	20D
0005432294517	22245	38	20F
0005435529523	22245	39	1F
0005432294519	22245	40	1D
0005435529526	22245	41	2A
0005435529539	22245	42	2C
0005435541285	22245	43	3D
0005435529528	22245	44	3F
0005435529525	22245	45	4C
0005435529524	22245	46	4E
0005435541273	22245	47	1C
0005435541265	22245	48	5E
0005434907977	2288	1	14A
0005434907989	2288	2	13C
0005434908005	2288	3	15D
0005434907984	2288	4	12A
0005433251781	2288	5	2A
0005433251542	2288	6	1D
0005433251479	2288	7	3C
0005434907967	2288	8	19D
0005434908013	2288	9	13A
0005434907968	2288	10	10A
0005434908021	2288	11	12D
0005433251672	2288	12	12C
0005434907976	2288	13	20F
0005433251677	2288	14	16D
0005434908002	2288	15	12E
0005434907994	2288	16	11C
0005434908007	2288	17	20E
0005434907964	2288	18	5D
0005434907986	2288	19	8E
0005434907969	2288	20	14D
0005434907990	2288	21	18C
0005434907988	2288	22	5C
0005433251695	2288	23	7E
0005433251577	2288	24	11E
0005434907987	2288	25	7A
0005434907998	2288	26	16E
0005434908019	2288	27	14F
0005434908022	2288	28	13D
0005433251692	2288	29	2F
0005433251690	2288	30	3F
0005433251630	2288	31	3A
0005433251689	2288	32	4E
0005434907996	2288	33	6A
0005433251674	2288	34	7C
0005433251780	2288	35	8D
0005434908017	2288	36	7D
0005434907972	2288	37	20A
0005434908018	2288	38	5A
0005434907979	2288	39	15E
0005434907980	2288	40	17D
0005434908001	2288	41	19C
0005434907962	2288	42	17F
0005434908000	2288	43	3D
0005433251591	2288	44	8A
0005434907999	2288	45	9F
0005434907991	2288	46	11A
0005434907963	2288	47	16A
0005433251735	2288	48	20C
0005434907983	2288	49	19A
0005434907997	2288	50	6E
0005434907982	2288	51	1C
0005433251637	2288	52	10F
0005433251704	2288	53	16C
0005433251678	2288	54	1A
0005434907993	2288	55	16F
0005434908008	2288	56	18A
0005433251703	2288	57	15C
0005434908003	2288	58	17E
0005433251766	2288	59	12F
0005433251693	2288	60	6F
0005434907985	2288	61	4D
0005434907961	2288	62	14E
0005433251691	2288	63	20D
0005434907973	2288	64	8C
0005433251602	2288	65	18F
0005434907975	2288	66	18E
0005434907992	2288	67	13F
0005433251789	2288	68	9C
0005434908010	2288	69	13E
0005434907966	2288	70	15F
0005434907971	2288	71	5E
0005434907974	2288	72	14C
0005434908020	2288	73	10C
0005433251694	2288	74	9A
0005433251673	2288	75	15A
0005434908014	2288	76	6D
0005434908011	2288	77	6C
0005434908004	2288	78	5F
0005434907965	2288	79	2C
0005434908015	2288	80	11F
0005434908009	2288	81	9E
0005434907981	2288	82	2D
0005433251767	2288	83	17C
0005434908006	2288	84	10D
0005434908012	2288	85	19F
0005434907970	2288	86	4A
0005434908016	2288	87	10E
0005434907995	2288	88	19E
0005433251702	2288	89	9D
0005433251478	2288	90	1F
0005434907978	2288	91	18D
0005433251701	2288	92	4C
0005434907462	25593	1	11A
0005434907527	25593	2	11C
0005434907555	25593	3	11D
0005433401023	25593	4	11F
0005434907167	25593	5	12A
0005434907443	25593	6	12C
0005434907364	25593	7	12D
0005434907473	25593	8	12E
0005434907459	25593	9	13A
0005434907469	25593	10	13C
0005434907503	25593	11	13D
0005434907641	25593	12	13E
0005434907630	25593	13	13F
0005434907562	25593	14	14A
0005433251900	25593	15	14C
0005434907512	25593	16	14D
0005434907421	25593	17	14F
0005434907356	25593	18	15A
0005433251894	25593	19	15C
0005433251902	25593	20	15D
0005433251904	25593	21	15E
0005433401025	25593	22	15F
0005434907516	25593	23	16A
0005433251891	25593	24	16C
0005433251897	25593	25	16D
0005433251888	25593	26	16E
0005434907463	25593	27	16F
0005433251887	25593	28	17A
0005434907639	25593	29	17C
0005433251903	25593	30	17D
0005433251899	25593	31	17E
0005434907536	25593	32	17F
0005433251893	25593	33	18A
0005434907430	25593	34	18C
0005434907537	25593	35	18D
0005434907284	25593	36	18E
0005434907474	25593	37	18F
0005433251877	25593	38	19A
0005433251890	25593	39	19C
0005433251889	25593	40	19D
0005434907358	25593	41	19E
0005433251898	25593	42	19F
0005433251885	25593	43	20A
0005434907505	25593	44	20C
0005433251895	25593	45	20F
0005434907420	25593	46	20D
0005434907432	25593	47	1A
0005434907635	25593	48	1C
0005434907431	25593	49	1D
0005434907398	25593	50	1F
0005434907197	25593	51	2A
0005433251892	25593	52	2C
0005434907528	25593	53	2D
0005433251905	25593	54	2F
0005434907530	25593	55	3A
0005434907517	25593	56	3C
0005434907399	25593	57	3D
0005434907634	25593	58	3F
0005433251881	25593	59	4C
0005434907460	25593	60	4D
0005434907513	25593	61	4E
0005434907419	25593	62	4F
0005433251883	25593	63	5A
0005434907166	25593	64	5C
0005434907493	25593	65	5D
0005433251879	25593	66	5E
0005434907629	25593	67	5F
0005433251896	25593	68	6A
0005434907393	25593	69	6C
0005434907640	25593	70	6D
0005434907472	25593	71	6E
0005434907504	25593	72	6F
0005433251906	25593	73	7A
0005434907531	25593	74	7C
0005434907400	25593	75	7D
0005433251878	25593	76	7E
0005433251901	25593	77	7F
0005433401024	25593	78	8A
0005434907506	25593	79	8C
0005434907627	25593	80	8E
0005434907650	25593	81	8F
0005433251876	25593	82	9A
0005433251884	25593	83	9C
0005433251880	25593	84	9D
0005434907348	25593	85	9E
0005434907450	25593	86	10A
0005433251886	25593	87	10C
0005434907521	25593	88	10D
0005433251882	25593	89	10E
0005434907451	25593	90	10F
0005432621233	2498	1	1A
0005432862320	2498	2	1C
0005432862368	2498	3	1D
0005432621222	2498	4	2C
0005432621231	2498	5	2D
0005432621228	2498	6	3C
0005432621234	2498	7	4C
0005432621227	2498	8	6C
0005432621230	2498	9	6D
0005432621221	2498	10	18A
0005432862314	2498	11	19B
0005432621229	2498	12	19C
0005432862329	2498	13	20C
0005432621224	2498	14	20D
0005432621223	2498	15	22B
0005432621232	2498	16	22D
0005432621225	2498	17	23A
0005432621226	2498	18	23B
0005432862404	28081	1	5B
0005432621077	28081	2	1B
0005432862406	28081	3	1C
0005432862409	28081	4	2D
0005432621063	28081	5	3C
0005432621202	28081	6	3D
0005432862408	28081	7	4C
0005432621127	28081	8	4D
0005432621057	28081	9	5A
0005432621096	28081	10	5D
0005432621203	28081	11	7A
0005432862407	28081	12	7D
0005432862402	28081	13	18C
0005432621126	28081	14	19B
0005432862405	28081	15	20A
0005432621062	28081	16	21A
0005432621201	28081	17	21C
0005432621141	28081	18	22A
0005432862403	28081	19	22B
0005432621143	28081	20	22D
0005432621142	28081	21	23A
0005434097483	11717	1	5B
0005434097485	11717	2	1B
0005434097484	11717	3	3A
0005434097482	11717	4	1A
0005434097495	13020	1	6B
0005433451646	31033	1	5A
0005433451645	31033	2	1B
0005433452767	31033	3	4A
0005433454879	31452	1	5B
0005433454880	31452	2	3A
0005433452749	31452	3	2A
0005433454897	31452	4	6B
0005433454896	31452	5	2B
0005434142630	12029	1	21C
0005433134164	12029	2	2C
0005434184673	12029	3	5A
0005433134165	12029	4	5D
0005433134159	12029	5	6B
0005433134168	12029	6	7D
0005433134156	12029	7	18A
0005433134174	12029	8	20D
0005434142629	12029	9	22A
0005433131769	29864	1	2D
0005434183607	29864	2	4C
0005433134198	29864	3	5B
0005434142658	29864	4	7D
0005433134199	29864	5	18B
0005434183606	29864	6	18D
0005433134201	29864	7	19A
0005434142660	29864	8	19C
0005434184692	29864	9	19D
0005434184691	29864	10	20D
0005434142661	29864	11	2C
0005433131770	29864	12	21C
0005433134200	29864	13	21D
0005433131771	29864	14	22B
0005434142659	29864	15	22D
0005433131768	29864	16	23A
0005435697684	16455	1	4D
0005435697686	16455	2	1A
0005435697701	16455	3	1B
0005435935064	16455	4	1D
0005435697696	16455	5	2A
0005435697681	16455	6	3A
0005435697685	16455	7	4A
0005435697676	16455	8	4B
0005435697691	16455	9	5C
0005435697697	16455	10	5D
0005435697700	16455	11	6A
0005435697692	16455	12	6C
0005435697687	16455	13	6D
0005435697689	16455	14	7A
0005435697682	16455	15	7C
0005435697693	16455	16	18A
0005435697702	16455	17	19B
0005435697678	16455	18	19C
0005435697695	16455	19	19D
0005435697699	16455	20	20C
0005435697683	16455	21	20D
0005435697690	16455	22	21A
0005435697704	16455	23	21B
0005435697703	16455	24	21C
0005435697694	16455	25	22A
0005435697698	16455	26	22B
0005435697679	16455	27	22C
0005435697677	16455	28	22D
0005435697680	16455	29	23A
0005435697688	16455	30	23B
0005435697475	24696	1	1A
0005435935087	24696	2	1B
0005435697494	24696	3	1C
0005435697406	24696	4	1D
0005435697437	24696	5	2A
0005435697488	24696	6	2B
0005435697407	24696	7	2D
0005435697474	24696	8	3B
0005435697548	24696	9	3C
0005435697514	24696	10	3D
0005435697450	24696	11	4A
0005435697449	24696	12	4B
0005435697477	24696	13	4C
0005435935084	24696	14	4D
0005435697606	24696	15	5A
0005435697482	24696	16	5C
0005435697461	24696	17	6A
0005435697400	24696	18	6D
0005435697408	24696	19	7A
0005435697581	24696	20	7B
0005435697489	24696	21	7C
0005435697396	24696	22	7D
0005435697395	24696	23	18A
0005435697460	24696	24	18B
0005435935085	24696	25	19B
0005435697351	24696	26	19C
0005435697528	24696	27	19D
0005435697399	24696	28	20A
0005435697405	24696	29	20C
0005435697583	24696	30	20D
0005435697553	24696	31	21A
0005435697381	24696	32	21B
0005435697447	24696	33	21C
0005435935086	24696	34	21D
0005435697584	24696	35	22B
0005435697352	24696	36	22C
0005435697401	24696	37	22D
0005435697479	24696	38	23A
0005435697459	24696	39	23B
0005432968846	18800	1	2A
0005433724861	18800	2	1B
0005432968847	18800	3	2B
0005432968843	18800	4	3B
0005433724864	18800	5	4A
0005432968857	18800	6	4B
0005433724863	18800	7	5A
0005433724862	18800	8	6A
0005432968856	18800	9	6B
0005432968872	21596	1	1A
0005432968874	21596	2	1B
0005433724827	21596	3	3A
0005432968873	21596	4	5A
0005434139244	7335	1	9A
0005434139285	7335	2	1A
0005434139260	7335	3	1C
0005434139251	7335	4	1D
0005434139287	7335	5	1F
0005434139226	7335	6	2A
0005434139217	7335	7	2C
0005434139255	7335	8	2D
0005434139254	7335	9	2F
0005434139237	7335	10	3C
0005434139222	7335	11	3D
0005434139248	7335	12	3F
0005434139239	7335	13	4C
0005434139228	7335	14	4E
0005434087578	7335	15	4F
0005434139243	7335	16	5A
0005434139229	7335	17	5D
0005434139256	7335	18	5E
0005434139220	7335	19	5F
0005434139274	7335	20	6C
0005434139273	7335	21	6D
0005434139218	7335	22	6E
0005434139280	7335	23	6F
0005434139290	7335	24	7A
0005434139261	7335	25	7C
0005434139231	7335	26	7D
0005434139288	7335	27	7E
0005434139216	7335	28	7F
0005434139219	7335	29	8A
0005434139240	7335	30	8C
0005434139262	7335	31	8D
0005434139223	7335	32	8E
0005434139238	7335	33	8F
0005434139283	7335	34	9C
0005434139270	7335	35	9D
0005434139268	7335	36	9E
0005434139246	7335	37	9F
0005434139242	7335	38	10C
0005434139258	7335	39	10D
0005434139236	7335	40	10E
0005434139264	7335	41	10F
0005434087577	7335	42	11A
0005434139279	7335	43	11C
0005434139286	7335	44	11D
0005434139224	7335	45	11E
0005434139284	7335	46	11F
0005434087582	7335	47	12A
0005434139233	7335	48	12C
0005434087579	7335	49	12D
0005434139289	7335	50	12E
0005434139257	7335	51	12F
0005434139263	7335	52	13A
0005434139215	7335	53	13C
0005434087580	7335	54	13D
0005434139234	7335	55	13E
0005434139225	7335	56	13F
0005434139266	7335	57	14A
0005434139277	7335	58	14C
0005434139232	7335	59	14D
0005434139281	7335	60	14E
0005434139291	7335	61	15C
0005434139282	7335	62	15D
0005434139275	7335	63	15E
0005434139227	7335	64	16C
0005434087581	7335	65	16D
0005434139253	7335	66	16E
0005434139259	7335	67	16F
0005434139250	7335	68	17A
0005434139252	7335	69	17C
0005434139221	7335	70	17D
0005434139269	7335	71	17E
0005434139278	7335	72	18A
0005434139230	7335	73	18C
0005434139265	7335	74	18E
0005434139272	7335	75	19A
0005434139247	7335	76	19C
0005434139276	7335	77	19D
0005434139271	7335	78	19E
0005434139249	7335	79	19F
0005434139245	7335	80	20A
0005434139241	7335	81	20C
0005434139267	7335	82	20D
0005434139235	7335	83	20F
0005434138653	28586	1	7E
0005434138510	28586	2	13E
0005434138309	28586	3	18E
0005434138449	28586	4	16F
0005434138328	28586	5	18C
0005434138503	28586	6	6D
0005434138504	28586	7	15A
0005434138393	28586	8	11C
0005434138761	28586	9	7C
0005434138574	28586	10	7D
0005434138844	28586	11	17C
0005434138495	28586	12	17A
0005434138499	28586	13	8A
0005434138222	28586	14	16C
0005434137688	28586	15	19C
0005434138775	28586	16	6F
0005434138457	28586	17	14C
0005434138419	28586	18	14F
0005434138195	28586	19	4A
0005434138125	28586	20	10C
0005434138321	28586	21	16A
0005434138619	28586	22	12A
0005434138322	28586	23	15C
0005434087527	28586	24	5E
0005434138464	28586	25	11F
0005434138573	28586	26	4D
0005434138502	28586	27	20A
0005434138312	28586	28	5D
0005434087542	28586	29	3C
0005434138480	28586	30	19A
0005434138922	28586	31	7A
0005434138481	28586	32	11A
0005434138417	28586	33	13D
0005434138486	28586	34	15D
0005434087541	28586	35	3F
0005434138654	28586	36	5C
0005434138437	28586	37	9F
0005434138242	28586	38	14A
0005434138353	28586	39	12C
0005434087557	28586	40	8C
0005434138585	28586	41	2C
0005434138243	28586	42	9D
0005434138391	28586	43	1F
0005434138145	28586	44	9A
0005434138263	28586	45	10A
0005434138655	28586	46	10D
0005434138006	28586	47	13C
0005434087549	28586	48	13F
0005434138413	28586	49	14E
0005434138982	28586	50	20F
0005434138465	28586	51	1A
0005435283555	28586	52	2D
0005434138386	28586	53	3A
0005434138605	28586	54	4F
0005434138845	28586	55	4E
0005434138385	28586	56	7F
0005434138310	28586	57	3D
0005434138511	28586	58	14D
0005434138399	28586	59	8D
0005434138354	28586	60	11E
0005434087548	28586	61	17E
0005434138664	28586	62	17D
0005434138395	28586	63	12E
0005434138606	28586	64	10F
0005434138333	28586	65	10E
0005434138507	28586	66	19F
0005434138575	28586	67	18D
0005435283567	28586	68	12D
0005434138622	28586	69	15E
0005434138466	28586	70	1D
0005434138461	28586	71	20D
0005434137689	28586	72	16E
0005434138506	28586	73	8F
0005434138407	28586	74	15F
0005434138601	28586	75	18F
0005434087507	28586	76	18A
0005434138683	28586	77	19D
0005434138471	28586	78	9E
0005434138682	28586	79	17F
0005434138390	28586	80	20C
0005434138479	28586	81	19E
0005434138617	28586	82	16D
0005434087550	28586	83	8E
0005434087558	28586	84	20E
0005434138531	28586	85	2A
0005434138303	28586	86	4C
0005435808372	1952	1	5C
0005435808379	1952	2	1A
0005435808370	1952	3	1B
0005433407593	1952	4	2C
0005434610277	1952	5	2D
0005435808375	1952	6	3C
0005435808377	1952	7	4D
0005435808380	1952	8	5B
0005433407594	1952	9	5D
0005434610276	1952	10	6C
0005435808371	1952	11	7B
0005433407576	1952	12	18B
0005435808374	1952	13	18C
0005434610279	1952	14	18D
0005433407575	1952	15	19A
0005435808381	1952	16	19C
0005434610278	1952	17	20A
0005433407592	1952	18	20B
0005435808376	1952	19	21B
0005435808373	1952	20	21C
0005433407569	1952	21	22B
0005435808378	1952	22	22D
0005434610240	23071	1	3A
0005434610249	23071	2	5C
0005434610254	23071	3	6B
0005434610253	23071	4	18A
0005434610239	23071	5	18D
0005434610236	23071	6	19B
0005434610238	23071	7	21C
0005434610237	23071	8	22A
0005434504249	16712	1	1A
0005434504358	16712	2	1B
0005434504137	16712	3	1C
0005434504312	16712	4	1D
0005434504426	16712	5	2A
0005434504272	16712	6	2B
0005434504309	16712	7	2C
0005434504311	16712	8	2D
0005434504333	16712	9	3A
0005434504155	16712	10	3B
0005434504315	16712	11	3C
0005434504242	16712	12	3D
0005434504181	16712	13	4A
0005434504330	16712	14	4B
0005434504299	16712	15	4C
0005434504304	16712	16	4D
0005434504344	16712	17	5B
0005434504316	16712	18	5C
0005434504308	16712	19	5D
0005434504396	16712	20	6A
0005434504288	16712	21	6B
0005434504241	16712	22	6C
0005434504262	16712	23	6D
0005434504379	16712	24	7A
0005434504071	16712	25	7B
0005434504353	16712	26	7C
0005434504378	16712	27	7D
0005434504357	16712	28	18A
0005434504261	16712	29	18B
0005434504302	16712	30	18C
0005434504287	16712	31	18D
0005434504402	16712	32	19A
0005434504215	16712	33	19B
0005434504350	16712	34	19C
0005434504329	16712	35	19D
0005434504256	16712	36	20B
0005434504322	16712	37	20C
0005434504420	16712	38	20D
0005434504428	16712	39	21A
0005434504349	16712	40	21B
0005434504303	16712	41	21C
0005434504321	16712	42	21D
0005434504252	16712	43	22A
0005434504314	16712	44	22B
0005434504317	16712	45	22C
0005434504300	16712	46	22D
0005434504257	16712	47	23A
0005434504334	16712	48	23B
0005434504651	22884	1	19B
0005434504655	22884	2	1A
0005434504643	22884	3	1B
0005434504639	22884	4	1C
0005434504626	22884	5	1D
0005434504648	22884	6	2A
0005434504650	22884	7	2B
0005434504662	22884	8	2C
0005434504633	22884	9	2D
0005434504640	22884	10	3B
0005434504647	22884	11	3C
0005434504623	22884	12	4A
0005434504641	22884	13	4B
0005434504659	22884	14	4C
0005434504642	22884	15	4D
0005434504644	22884	16	5B
0005434504645	22884	17	5C
0005434504652	22884	18	5D
0005434504661	22884	19	6A
0005434504625	22884	20	6B
0005434504632	22884	21	6C
0005434504631	22884	22	6D
0005434504636	22884	23	7A
0005434504653	22884	24	7C
0005434504635	22884	25	7D
0005434504638	22884	26	18A
0005434504660	22884	27	18B
0005434504656	22884	28	18D
0005434504657	22884	29	19A
0005434504627	22884	30	19C
0005434504624	22884	31	19D
0005434504649	22884	32	20A
0005434504637	22884	33	20C
0005434504663	22884	34	20D
0005434504646	22884	35	21A
0005434504654	22884	36	21B
0005434504628	22884	37	21C
0005434504629	22884	38	22B
0005434504658	22884	39	22C
0005434504634	22884	40	22D
0005434504630	22884	41	23B
0005433266735	2172	1	1A
0005435078543	2172	2	1B
0005435078553	2172	3	1D
0005433266722	2172	4	2B
0005435078552	2172	5	3C
0005433266721	2172	6	3D
0005433266739	2172	7	4D
0005435078548	2172	8	5C
0005435078551	2172	9	5D
0005433266723	2172	10	6C
0005435078556	2172	11	6D
0005435078550	2172	12	7A
0005433266782	2172	13	7B
0005435078545	2172	14	18C
0005435078547	2172	15	18D
0005435078558	2172	16	19D
0005435078554	2172	17	20B
0005435078557	2172	18	21A
0005435078544	2172	19	21D
0005435078555	2172	20	22A
0005433266720	2172	21	22C
0005435078549	2172	22	23A
0005435078546	2172	23	23B
0005433266847	24366	1	1A
0005435078428	24366	2	1C
0005433266846	24366	3	1D
0005435078445	24366	4	2A
0005435078452	24366	5	2B
0005435078395	24366	6	2C
0005435078401	24366	7	3A
0005435078454	24366	8	3C
0005435078434	24366	9	3D
0005435078402	24366	10	4A
0005435078424	24366	11	4B
0005435078433	24366	12	5A
0005433266852	24366	13	5C
0005433266850	24366	14	6B
0005435078435	24366	15	6C
0005433266843	24366	16	7A
0005435078492	24366	17	7C
0005435078455	24366	18	7D
0005433266848	24366	19	18B
0005433266844	24366	20	18C
0005433266849	24366	21	20A
0005433266845	24366	22	20D
0005435078423	24366	23	21B
0005433266851	24366	24	22B
0005435078378	24366	25	22C
0005435078418	24366	26	23A
0005435078444	24366	27	23B
0005434988888	6613	1	2D
0005435803299	6613	2	3D
0005434988889	6613	3	4B
0005435803298	6613	4	5B
0005434988887	6613	5	6B
0005434988886	6613	6	18B
0005434988890	6613	7	18D
0005434988891	6613	8	19B
0005434988893	6613	9	20A
0005434988892	6613	10	21A
0005435803300	6613	11	22D
0005435464535	23605	1	2C
0005434988722	23605	2	3A
0005434988723	23605	3	3C
0005435464536	23605	4	3D
0005434988735	23605	5	5A
0005434988748	23605	6	5D
0005435803274	23605	7	6A
0005434988713	23605	8	18C
0005435803270	23605	9	19A
0005434988736	23605	10	19D
0005434988759	23605	11	21C
0005434988714	23605	12	22B
0005432383702	30475	1	7D
0005433450253	30475	2	1A
0005432383688	30475	3	1C
0005433450271	30475	4	1F
0005432383697	30475	5	2D
0005432383693	30475	6	3A
0005433450265	30475	7	3C
0005432383701	30475	8	3D
0005432383692	30475	9	4E
0005433450272	30475	10	5C
0005432383699	30475	11	5E
0005433450268	30475	12	5F
0005433450267	30475	13	6A
0005432383681	30475	14	6C
0005432383691	30475	15	6F
0005433450269	30475	16	7A
0005433453787	30475	17	7C
0005433450254	30475	18	7E
0005433450255	30475	19	8C
0005432383698	30475	20	8D
0005432383683	30475	21	8E
0005432383694	30475	22	8F
0005432383689	30475	23	9A
0005433454903	30475	24	9D
0005433450264	30475	25	10F
0005433450263	30475	26	11A
0005432383684	30475	27	11D
0005432383686	30475	28	11E
0005432383705	30475	29	12A
0005433450270	30475	30	12C
0005433450260	30475	31	12D
0005433454904	30475	32	13A
0005432383690	30475	33	13C
0005433450257	30475	34	13F
0005432383695	30475	35	14A
0005433450252	30475	36	14C
0005432383703	30475	37	14E
0005432383708	30475	38	15A
0005432383700	30475	39	15C
0005432383704	30475	40	15D
0005432383706	30475	41	15F
0005433450266	30475	42	16A
0005433450256	30475	43	16D
0005433450261	30475	44	17A
0005432383707	30475	45	17F
0005432383696	30475	46	18A
0005432383682	30475	47	18C
0005432383685	30475	48	18E
0005432383687	30475	49	19A
0005432383680	30475	50	19E
0005433450258	30475	51	19F
0005433450259	30475	52	20A
0005433450273	30475	53	20C
0005433450262	30475	54	20D
0005432383228	31283	1	1A
0005432383216	31283	2	1F
0005432383282	31283	3	2D
0005433450132	31283	4	2F
0005432383109	31283	5	3A
0005432383193	31283	6	3C
0005432383343	31283	7	3F
0005432383428	31283	8	4A
0005432383344	31283	9	4E
0005432383211	31283	10	4F
0005433450034	31283	11	5A
0005432383221	31283	12	5C
0005432383207	31283	13	5F
0005433450035	31283	14	6A
0005433450074	31283	15	6C
0005433450070	31283	16	6D
0005433450092	31283	17	6F
0005432383283	31283	18	7A
0005432383468	31283	19	7C
0005433450053	31283	20	7E
0005432383342	31283	21	8A
0005433450022	31283	22	8D
0005433450036	31283	23	8E
0005432383262	31283	24	8F
0005433450126	31283	25	9A
0005433450100	31283	26	9C
0005433449964	31283	27	9F
0005432383253	31283	28	10A
0005433450111	31283	29	10C
0005433449996	31283	30	10E
0005432383470	31283	31	10F
0005432383287	31283	32	11C
0005433450069	31283	33	11D
0005432383151	31283	34	11F
0005433450081	31283	35	12A
0005433453770	31283	36	12C
0005433450127	31283	37	12D
0005432383090	31283	38	12E
0005432383288	31283	39	12F
0005432383257	31283	40	13A
0005432383225	31283	41	13D
0005432383256	31283	42	13E
0005432383220	31283	43	13F
0005432383313	31283	44	14C
0005433450093	31283	45	14D
0005432383208	31283	46	14E
0005432383336	31283	47	14F
0005433450057	31283	48	15A
0005432383219	31283	49	15C
0005432383189	31283	50	15D
0005432383345	31283	51	16E
0005433449987	31283	52	16F
0005433451627	31283	53	17A
0005432383310	31283	54	17C
0005433450091	31283	55	17E
0005433450115	31283	56	17F
0005432383252	31283	57	18A
0005433450056	31283	58	18C
0005432383178	31283	59	18D
0005432383255	31283	60	19A
0005432383308	31283	61	19D
0005432383327	31283	62	19E
0005433450136	31283	63	20A
0005432383469	31283	64	20C
0005433449997	31283	65	20D
0005433453764	31283	66	20E
0005435548480	20819	1	1A
0005435548487	20819	2	1D
0005433788255	20819	3	2A
0005435548479	20819	4	2B
0005435548491	20819	5	2C
0005435548502	20819	6	2D
0005435548508	20819	7	3B
0005433788249	20819	8	3C
0005435548495	20819	9	3D
0005433788259	20819	10	4A
0005435548482	20819	11	4C
0005433788256	20819	12	4B
0005433788250	20819	13	4D
0005433788254	20819	14	5A
0005433788262	20819	15	5C
0005435548503	20819	16	5D
0005435548501	20819	17	6A
0005433788257	20819	18	6D
0005435548497	20819	19	7A
0005435548481	20819	20	7C
0005433788261	20819	21	18A
0005433788253	20819	22	18D
0005435548507	20819	23	19A
0005435548499	20819	24	19B
0005433788263	20819	25	19C
0005435548504	20819	26	19D
0005435548494	20819	27	20A
0005433788251	20819	28	20B
0005433788260	20819	29	20D
0005433788252	20819	30	21A
0005435548486	20819	31	21D
0005435548496	20819	32	22A
0005435548483	20819	33	22C
0005433788258	20819	34	23A
0005435548511	20819	35	23B
0005433788216	26487	1	1A
0005433788214	26487	2	1C
0005433788217	26487	3	1D
0005433788229	26487	4	2A
0005433788230	26487	5	2B
0005435548553	26487	6	2D
0005433788207	26487	7	3B
0005435548557	26487	8	3D
0005435548560	26487	9	4A
0005435548558	26487	10	4B
0005433788225	26487	11	4D
0005435548547	26487	12	5B
0005435548554	26487	13	5C
0005435548552	26487	14	5D
0005435548559	26487	15	6A
0005433788209	26487	16	6B
0005435548549	26487	17	6C
0005433788233	26487	18	6D
0005433788206	26487	19	7B
0005435548555	26487	20	7C
0005433788228	26487	21	18A
0005435548551	26487	22	18C
0005435548548	26487	23	19A
0005433788213	26487	24	19B
0005433788212	26487	25	19C
0005433788211	26487	26	19D
0005433788210	26487	27	20C
0005433788215	26487	28	20D
0005433788232	26487	29	21A
0005433788231	26487	30	22A
0005435548556	26487	31	22B
0005433788208	26487	32	22D
0005435548550	26487	33	23A
0005433788222	26487	34	23B
0005433131744	10770	1	1A
0005435299801	10770	2	1B
0005433126870	10770	3	2A
0005433126869	10770	4	3A
0005435304192	10770	5	3D
0005433131728	10770	6	5B
0005435304169	10770	7	5D
0005433131734	10770	8	7B
0005433126860	10770	9	18B
0005435304181	10770	10	19A
0005433131727	10770	11	20A
0005433126855	10770	12	20D
0005435304195	10770	13	21A
0005435304187	10770	14	21B
0005435304194	10770	15	22B
0005435304168	10770	16	22D
0005435299777	10770	17	23A
0005435302268	29706	1	1D
0005435302265	29706	2	2A
0005435299845	29706	3	2B
0005435299843	29706	4	3D
0005433129340	29706	5	4C
0005433126912	29706	6	4D
0005435302267	29706	7	5C
0005433129342	29706	8	6A
0005435302266	29706	9	7B
0005433126909	29706	10	7C
0005433126911	29706	11	7D
0005433126908	29706	12	18B
0005435299846	29706	13	18D
0005435299844	29706	14	21A
0005433129344	29706	15	21B
0005433129343	29706	16	21C
0005433126910	29706	17	22A
0005433129341	29706	18	22D
0005433129339	29706	19	23A
0005433110107	2426	1	1B
0005433110106	2426	2	1C
0005434287579	2426	3	1D
0005433110103	2426	4	2A
0005434287577	2426	5	2C
0005434287595	2426	6	3A
0005433110098	2426	7	3B
0005434287578	2426	8	3D
0005434287585	2426	9	4A
0005434287597	2426	10	4C
0005434287581	2426	11	4D
0005434287586	2426	12	5C
0005434287582	2426	13	5D
0005434287589	2426	14	6A
0005434287588	2426	15	6B
0005434287576	2426	16	6D
0005434287584	2426	17	7A
0005434287590	2426	18	7C
0005433110120	2426	19	7D
0005434287591	2426	20	18A
0005434287580	2426	21	18B
0005433110163	2426	22	18C
0005434287587	2426	23	18D
0005432264509	2426	24	19A
0005433110101	2426	25	19B
0005434287594	2426	26	19D
0005433110148	2426	27	20B
0005434287593	2426	28	20C
0005433110102	2426	29	20D
0005433110097	2426	30	21B
0005434287583	2426	31	21C
0005432264508	2426	32	22A
0005434287596	2426	33	22C
0005434287592	2426	34	22D
0005433110149	2426	35	23A
0005434287447	26846	1	21D
0005434287333	26846	2	1C
0005434287415	26846	3	1D
0005434287388	26846	4	2A
0005433110210	26846	5	2C
0005434287334	26846	6	3A
0005434287359	26846	7	3B
0005433110211	26846	8	3C
0005433110220	26846	9	4C
0005434287485	26846	10	5A
0005433110218	26846	11	5B
0005434287323	26846	12	5C
0005434287324	26846	13	6B
0005434287384	26846	14	6C
0005434287332	26846	15	6D
0005434287402	26846	16	7D
0005433110215	26846	17	18A
0005433110214	26846	18	18B
0005434287486	26846	19	18C
0005434287295	26846	20	18D
0005434287387	26846	21	19A
0005433110213	26846	22	19B
0005434287335	26846	23	19D
0005434287416	26846	24	20A
0005433110209	26846	25	20D
0005433110212	26846	26	21B
0005433110217	26846	27	21C
0005434287484	26846	28	22A
0005433110216	26846	29	22B
0005433110219	26846	30	23A
0005434287367	26846	31	23B
0005435856262	25480	1	1A
0005435856260	25480	2	5A
0005434269102	25480	3	6D
0005434272194	25480	4	7C
0005435856263	25480	5	19B
0005434272193	25480	6	19C
0005435856261	25480	7	21A
0005435856212	26649	1	4A
0005435856213	26649	2	5C
0005435856211	26649	3	19D
0005435856210	26649	4	20D
0005435856197	26649	5	21B
0005434520363	6097	1	1A
0005434520375	6097	2	1B
0005434520371	6097	3	1D
0005434520367	6097	4	2B
0005434520370	6097	5	2D
0005434520379	6097	6	3A
0005435314844	6097	7	3B
0005435314858	6097	8	3D
0005434520365	6097	9	4A
0005435314867	6097	10	4B
0005434520364	6097	11	4C
0005435314851	6097	12	4D
0005434520378	6097	13	5A
0005434520374	6097	14	5B
0005434520381	6097	15	5D
0005435314849	6097	16	6A
0005434520387	6097	17	6B
0005435314830	6097	18	6C
0005435314850	6097	19	6D
0005434520388	6097	20	7A
0005434520373	6097	21	7B
0005435314839	6097	22	7C
0005434520376	6097	23	7D
0005434520386	6097	24	18A
0005434520366	6097	25	18B
0005434520368	6097	26	18C
0005435314834	6097	27	18D
0005434520383	6097	28	19A
0005435314835	6097	29	19B
0005434520372	6097	30	19C
0005434520369	6097	31	19D
0005434520382	6097	32	20A
0005435314857	6097	33	20B
0005434520377	6097	34	20C
0005435314845	6097	35	20D
0005434520384	6097	36	21B
0005435314817	6097	37	21D
0005434520385	6097	38	22A
0005435314873	6097	39	22C
0005435314838	6097	40	22D
0005434520380	6097	41	23A
0005435314846	6097	42	23B
0005433650805	7164	1	1A
0005435263673	7164	2	1C
0005433650838	7164	3	1D
0005433650839	7164	4	1F
0005433650856	7164	5	2A
0005433650803	7164	6	2C
0005435263656	7164	7	2D
0005433650831	7164	8	2F
0005433650863	7164	9	3A
0005433650818	7164	10	3D
0005435263618	7164	11	3F
0005433650814	7164	12	4A
0005433650850	7164	13	4C
0005433650812	7164	14	4D
0005433650844	7164	15	4E
0005433650843	7164	16	4F
0005433650860	7164	17	5A
0005433650853	7164	18	5C
0005433650861	7164	19	5D
0005433650826	7164	20	5E
0005433650821	7164	21	5F
0005433650807	7164	22	6A
0005435263634	7164	23	6D
0005435263648	7164	24	6C
0005433650800	7164	25	6E
0005435263676	7164	26	6F
0005433650815	7164	27	7A
0005435263616	7164	28	7D
0005433650851	7164	29	7C
0005433650820	7164	30	7E
0005433650801	7164	31	7F
0005435263671	7164	32	8A
0005433650832	7164	33	8C
0005433650854	7164	34	8D
0005433650855	7164	35	8E
0005433650829	7164	36	8F
0005433650819	7164	37	9A
0005433650808	7164	38	9C
0005433650817	7164	39	9D
0005433650846	7164	40	9E
0005435263637	7164	41	9F
0005435263638	7164	42	10A
0005433650830	7164	43	10C
0005433650833	7164	44	10D
0005435263659	7164	45	10E
0005433650859	7164	46	10F
0005433650845	7164	47	11A
0005433650848	7164	48	11C
0005433650858	7164	49	11D
0005433650840	7164	50	11E
0005435263654	7164	51	11F
0005435263645	7164	52	12A
0005433650852	7164	53	12C
0005435263672	7164	54	12D
0005435263677	7164	55	12E
0005435263669	7164	56	12F
0005435263670	7164	57	13A
0005435263655	7164	58	13C
0005435263622	7164	59	13D
0005435263617	7164	60	13E
0005433650837	7164	61	13F
0005433650841	7164	62	14A
0005435263644	7164	63	14C
0005433650806	7164	64	14D
0005435263661	7164	65	14E
0005435263643	7164	66	14F
0005433650857	7164	67	15A
0005433650802	7164	68	15C
0005433650849	7164	69	15D
0005435263631	7164	70	15E
0005433650835	7164	71	15F
0005433650836	7164	72	16A
0005433650864	7164	73	16C
0005433650813	7164	74	16D
0005433650810	7164	75	16E
0005435263667	7164	76	16F
0005435263646	7164	77	17A
0005433650824	7164	78	17C
0005433650823	7164	79	17D
0005433650809	7164	80	17E
0005435263625	7164	81	17F
0005433650822	7164	82	18A
0005433650842	7164	83	18C
0005433650827	7164	84	18D
0005433650828	7164	85	18E
0005433650825	7164	86	18F
0005435263653	7164	87	19A
0005433650811	7164	88	19C
0005433650862	7164	89	19D
0005433650847	7164	90	19E
0005433650834	7164	91	19F
0005435263626	7164	92	20A
0005433650816	7164	93	20C
0005435263666	7164	94	20D
0005433650804	7164	95	20E
0005435263619	7164	96	20F
0005433650718	27630	1	1C
0005435263711	27630	2	1D
0005435263703	27630	3	1F
0005433650585	27630	4	2C
0005433650748	27630	5	2D
0005433650697	27630	6	2F
0005435263710	27630	7	3A
0005433650692	27630	8	3C
0005433650731	27630	9	3F
0005433650580	27630	10	4A
0005433650702	27630	11	4C
0005433650747	27630	12	4D
0005435263708	27630	13	4E
0005435263720	27630	14	5C
0005433650648	27630	15	6A
0005435263700	27630	16	6C
0005435263723	27630	17	6D
0005433650708	27630	18	6E
0005435263722	27630	19	7C
0005433650698	27630	20	7D
0005435263702	27630	21	7E
0005435263719	27630	22	7F
0005433650640	27630	23	8A
0005433650662	27630	24	8C
0005433650665	27630	25	8F
0005435263701	27630	26	9A
0005433650680	27630	27	9D
0005433650646	27630	28	9E
0005435263714	27630	29	9F
0005433650645	27630	30	10C
0005433650750	27630	31	10D
0005435263715	27630	32	10F
0005433650644	27630	33	11D
0005435263713	27630	34	11E
0005433650798	27630	35	11F
0005433650669	27630	36	12A
0005435263718	27630	37	12C
0005433650595	27630	38	12D
0005433650653	27630	39	12F
0005433650657	27630	40	13A
0005433650635	27630	41	13C
0005433650751	27630	42	13E
0005433650631	27630	43	13F
0005433650746	27630	44	14A
0005435263706	27630	45	14C
0005433650618	27630	46	14D
0005433650632	27630	47	14E
0005435263721	27630	48	14F
0005433650707	27630	49	15C
0005433650647	27630	50	15D
0005433650766	27630	51	15E
0005433650633	27630	52	15F
0005433650579	27630	53	16A
0005435263698	27630	54	16D
0005435263712	27630	55	16E
0005433650729	27630	56	16F
0005433650699	27630	57	17A
0005435263717	27630	58	17C
0005433650717	27630	59	17D
0005435263716	27630	60	17E
0005435263705	27630	61	17F
0005433650673	27630	62	18A
0005433650681	27630	63	18C
0005433650730	27630	64	18D
0005433650654	27630	65	18F
0005433650639	27630	66	19A
0005435263709	27630	67	19C
0005433650712	27630	68	19D
0005433650736	27630	69	19E
0005435263704	27630	70	19F
0005435263707	27630	71	20C
0005435263699	27630	72	20F
0005433868977	4807	1	1A
0005433868981	4807	2	1B
0005433868972	4807	3	1C
0005433868983	4807	4	1D
0005433868970	4807	5	2A
0005435860499	4807	6	2B
0005433868975	4807	7	2C
0005433868979	4807	8	3A
0005433868958	4807	9	3B
0005433868980	4807	10	3C
0005433868964	4807	11	4A
0005433868992	4807	12	4B
0005435860498	4807	13	4C
0005433868987	4807	14	4D
0005433868985	4807	15	5A
0005433868960	4807	16	5C
0005433868989	4807	17	5D
0005433868965	4807	18	6B
0005433868990	4807	19	6C
0005433868973	4807	20	6D
0005433868957	4807	21	7A
0005433868978	4807	22	7B
0005433868966	4807	23	7C
0005433868963	4807	24	18A
0005433868968	4807	25	18B
0005433868995	4807	26	18C
0005433868962	4807	27	18D
0005433868994	4807	28	19A
0005433868956	4807	29	19B
0005433868993	4807	30	19C
0005433868961	4807	31	19D
0005433868969	4807	32	20A
0005433868984	4807	33	20B
0005433868986	4807	34	20C
0005433868967	4807	35	20D
0005433868971	4807	36	21A
0005433868988	4807	37	21B
0005433868974	4807	38	21D
0005433868976	4807	39	22A
0005433868959	4807	40	22C
0005433868982	4807	41	22B
0005433868991	4807	42	22D
0005433868595	32592	1	1A
0005433868556	32592	2	1B
0005433868516	32592	3	1C
0005433868511	32592	4	1D
0005433868543	32592	5	2A
0005435860520	32592	6	2B
0005433868720	32592	7	2C
0005433868578	32592	8	2D
0005433868432	32592	9	3A
0005433868399	32592	10	3B
0005433868525	32592	11	3C
0005433868555	32592	12	3D
0005433868441	32592	13	4A
0005433868537	32592	14	4B
0005435860524	32592	15	4C
0005433868575	32592	16	4D
0005433868582	32592	17	5B
0005433868642	32592	18	5C
0005435860522	32592	19	6A
0005433868641	32592	20	6B
0005433868636	32592	21	6C
0005433868658	32592	22	6D
0005433868524	32592	23	7A
0005433868693	32592	24	7B
0005433868721	32592	25	7C
0005433868515	32592	26	7D
0005433868596	32592	27	18A
0005433868651	32592	28	18B
0005433868554	32592	29	18C
0005433868654	32592	30	18D
0005433868722	32592	31	19A
0005433868574	32592	32	19B
0005433868706	32592	33	19C
0005435860521	32592	34	19D
0005433868612	32592	35	20A
0005433868542	32592	36	20B
0005435860523	32592	37	20D
0005433868536	32592	38	20C
0005433868366	32592	39	21A
0005433868611	32592	40	21B
0005433868650	32592	41	21C
0005433868637	32592	42	21D
0005433868365	32592	43	22A
0005433868613	32592	44	22B
0005433868615	32592	45	22C
0005433868408	32592	46	22D
0005433868659	32592	47	23A
0005433868728	32592	48	23B
0005434460536	3451	1	1B
0005435911484	3451	2	1D
0005434663596	3451	3	2A
0005434663590	3451	4	3A
0005435911487	3451	5	2D
0005434663584	3451	6	3B
0005434663588	3451	7	3C
0005434663594	3451	8	4A
0005435911491	3451	9	4C
0005434460535	3451	10	4D
0005434663587	3451	11	5B
0005434663595	3451	12	5D
0005434460533	3451	13	6A
0005434663583	3451	14	6B
0005435911488	3451	15	6C
0005435911490	3451	16	6D
0005434663593	3451	17	7A
0005434663591	3451	18	18A
0005434663589	3451	19	18C
0005434461676	3451	20	18D
0005434663586	3451	21	19A
0005434460534	3451	22	19B
0005434663585	3451	23	19C
0005435911513	3451	24	20A
0005435911442	3451	25	20B
0005435911514	3451	26	20D
0005434663597	3451	27	21B
0005434663592	3451	28	21D
0005435911512	3451	29	22D
0005434663508	12466	1	1A
0005434663509	12466	2	1B
0005434663435	12466	3	1C
0005435911553	12466	4	1D
0005434663472	12466	5	2C
0005435911554	12466	6	3C
0005434663464	12466	7	4A
0005435911557	12466	8	4D
0005434663463	12466	9	6D
0005434663471	12466	10	7A
0005434663436	12466	11	7D
0005435911556	12466	12	18A
0005434663454	12466	13	18C
0005434663513	12466	14	19B
0005435911555	12466	15	19D
0005435911552	12466	16	20B
0005435911551	12466	17	21B
0005434663453	12466	18	21D
0005434663470	12466	19	22C
0005434663406	12466	20	22D
0005434663459	12466	21	23B
0005433868399	14507	1	1A
0005433868578	14507	2	1B
0005433868516	14507	3	1C
0005435860523	14507	4	1D
0005433868555	14507	5	2A
0005433868654	14507	6	2B
0005433868612	14507	7	2C
0005433868637	14507	8	2D
0005433868641	14507	9	3A
0005433868721	14507	10	3B
0005433868515	14507	11	3C
0005433868554	14507	12	3D
0005433868636	14507	13	4A
0005433868575	14507	14	4B
0005433868650	14507	15	4D
0005433868441	14507	16	4C
0005433868611	14507	17	5A
0005435860522	14507	18	5B
0005433868524	14507	19	5C
0005433868693	14507	20	5D
0005433868659	14507	21	6A
0005433868615	14507	22	6B
0005435860521	14507	23	6C
0005435860520	14507	24	7A
0005433868642	14507	25	7B
0005433868595	14507	26	7C
0005433868556	14507	27	7D
0005435860524	14507	28	18A
0005433868542	14507	29	18B
0005433868432	14507	30	18C
0005433868525	14507	31	18D
0005433868658	14507	32	19A
0005433868408	14507	33	19B
0005433868706	14507	34	19C
0005433868543	14507	35	19D
0005433868536	14507	36	20A
0005433868596	14507	37	20B
0005433868728	14507	38	20C
0005433868613	14507	39	20D
0005433868574	14507	40	21A
0005433868720	14507	41	21B
0005433868511	14507	42	21C
0005433868365	14507	43	21D
0005433868366	14507	44	22A
0005433868722	14507	45	22B
0005433868651	14507	46	22C
0005433868582	14507	47	22D
0005433868537	14507	48	23B
0005433868940	32652	1	1A
0005433868927	32652	2	1B
0005433868955	32652	3	1C
0005433868954	32652	4	1D
0005433868928	32652	5	2A
0005433868947	32652	6	2B
0005433868920	32652	7	2C
0005433868925	32652	8	2D
0005433868921	32652	9	3A
0005433868943	32652	10	3D
0005433868932	32652	11	4A
0005433868918	32652	12	4C
0005433868939	32652	13	4D
0005433868919	32652	14	5A
0005433868922	32652	15	5B
0005433868941	32652	16	5C
0005433868944	32652	17	5D
0005433868923	32652	18	6B
0005433868938	32652	19	6C
0005433868951	32652	20	6D
0005433868930	32652	21	7C
0005435860497	32652	22	18A
0005433868934	32652	23	18C
0005433868924	32652	24	19A
0005433868949	32652	25	19B
0005433868937	32652	26	19C
0005433868946	32652	27	20A
0005433868945	32652	28	20B
0005433868952	32652	29	20C
0005433868931	32652	30	20D
0005433868948	32652	31	21A
0005433868950	32652	32	21B
0005433868917	32652	33	21C
0005433868933	32652	34	21D
0005433868942	32652	35	22A
0005433868929	32652	36	22B
0005433868935	32652	37	22C
0005433868936	32652	38	22D
0005433868926	32652	39	23A
0005433868953	32652	40	23B
0005432799523	12105	1	1A
0005432799700	12105	2	1B
0005432799545	12105	3	1C
0005432799556	12105	4	1D
0005432799619	12105	5	2A
0005432799345	12105	6	2B
0005432799699	12105	7	2C
0005432799560	12105	8	3C
0005432799396	12105	9	3D
0005432799589	12105	10	4B
0005432799623	12105	11	4D
0005432799469	12105	12	5A
0005432799620	12105	13	5B
0005432799544	12105	14	5C
0005432799621	12105	15	5D
0005432799346	12105	16	6A
0005432799557	12105	17	6D
0005432799561	12105	18	7A
0005432799533	12105	19	7B
0005432799559	12105	20	7C
0005432799530	12105	21	18B
0005432799612	12105	22	18D
0005432799652	12105	23	18C
0005432799592	12105	24	19A
0005432799605	12105	25	20B
0005432799548	12105	26	21B
0005432799611	12105	27	22A
0005432799618	12105	28	22D
0005432799591	12105	29	23A
0005432799675	12105	30	23B
0005432799813	14815	1	1B
0005432799819	14815	2	1C
0005432799796	14815	3	1D
0005432799802	14815	4	2B
0005432799807	14815	5	2C
0005432799805	14815	6	2D
0005432799798	14815	7	3B
0005432799814	14815	8	3D
0005432799794	14815	9	4B
0005432799816	14815	10	4C
0005432799792	14815	11	4D
0005432799820	14815	12	6B
0005432799795	14815	13	6C
0005432799797	14815	14	7A
0005432799799	14815	15	7B
0005432799818	14815	16	18A
0005432799815	14815	17	18B
0005432799809	14815	18	18C
0005432799806	14815	19	18D
0005432799800	14815	20	19A
0005432799810	14815	21	19C
0005432799821	14815	22	20A
0005432799804	14815	23	20B
0005432799817	14815	24	21A
0005432799811	14815	25	21B
0005432799812	14815	26	21C
0005432799808	14815	27	22B
0005432799793	14815	28	22C
0005432799801	14815	29	23A
0005432799803	14815	30	23B
0005434408625	7037	1	9E
0005434408599	7037	2	1A
0005435311103	7037	3	1C
0005435293304	7037	4	1F
0005434408613	7037	5	2C
0005434408602	7037	6	2A
0005435311093	7037	7	2D
0005435293321	7037	8	3C
0005432154035	7037	9	3A
0005434408620	7037	10	4A
0005434299876	7037	11	3F
0005434299871	7037	12	3D
0005434408635	7037	13	4B
0005434408591	7037	14	4C
0005434408618	7037	15	4D
0005435293320	7037	16	4E
0005432154034	7037	17	4F
0005434408623	7037	18	5A
0005434408582	7037	19	5C
0005435311090	7037	20	5B
0005435311067	7037	21	5D
0005435293337	7037	22	5F
0005434408636	7037	23	5E
0005432108285	7037	24	6A
0005434408628	7037	25	6C
0005434408640	7037	26	6B
0005434408600	7037	27	6D
0005435293313	7037	28	6E
0005434408581	7037	29	7A
0005434299863	7037	30	6F
0005434299870	7037	31	7B
0005434408586	7037	32	7C
0005434299862	7037	33	7D
0005432154030	7037	34	7E
0005434408583	7037	35	8A
0005434408639	7037	36	8B
0005435311104	7037	37	8D
0005434408585	7037	38	8C
0005434408609	7037	39	8E
0005434408614	7037	40	8F
0005434299877	7037	41	9A
0005434408588	7037	42	9C
0005434408597	7037	43	9B
0005432154029	7037	44	10B
0005434408624	7037	45	10C
0005434408607	7037	46	10D
0005434408584	7037	47	11A
0005434408601	7037	48	10E
0005435293287	7037	49	11B
0005434299864	7037	50	11C
0005434299865	7037	51	11E
0005435311028	7037	52	11F
0005435311072	7037	53	12A
0005432154033	7037	54	12C
0005434408616	7037	55	12D
0005434299879	7037	56	12E
0005434408632	7037	57	12F
0005434299881	7037	58	13A
0005434299880	7037	59	13C
0005434408606	7037	60	13B
0005435311089	7037	61	13D
0005434299866	7037	62	13E
0005435311066	7037	63	13F
0005434299874	7037	64	14A
0005434299868	7037	65	14C
0005434299882	7037	66	14B
0005434408594	7037	67	14D
0005434408617	7037	68	14E
0005434299873	7037	69	14F
0005434408622	7037	70	15B
0005434408612	7037	71	15A
0005434299878	7037	72	15D
0005434408629	7037	73	15C
0005434299872	7037	74	15F
0005434299875	7037	75	15E
0005434408621	7037	76	16B
0005435311027	7037	77	16C
0005434408631	7037	78	16D
0005434408580	7037	79	16F
0005435311073	7037	80	16E
0005434408611	7037	81	17A
0005432154031	7037	82	17B
0005434408627	7037	83	17D
0005434408634	7037	84	17C
0005435311110	7037	85	17E
0005432154032	7037	86	17F
0005434408626	7037	87	18A
0005434408630	7037	88	18C
0005434299861	7037	89	18D
0005434408633	7037	90	18F
0005434408637	7037	91	18E
0005434408598	7037	92	19A
0005434408592	7037	93	19C
0005434408638	7037	94	19D
0005434299867	7037	95	19E
0005435311111	7037	96	19F
0005434408608	7037	97	20C
0005432108284	7037	98	20B
0005434408615	7037	99	20D
0005434408593	7037	100	20E
0005434408596	7037	101	21A
0005434408605	7037	102	20F
0005434408589	7037	103	21B
0005434408603	7037	104	21C
0005434408579	7037	105	21D
0005434408619	7037	106	21E
0005435311071	7037	107	22A
0005434408604	7037	108	21F
0005434408590	7037	109	22B
0005434408577	7037	110	22C
0005434408610	7037	111	22D
0005435311099	7037	112	22E
0005434408595	7037	113	23A
0005434299883	7037	114	22F
0005434408578	7037	115	23B
0005434408587	7037	116	23C
0005434299869	7037	117	23E
0005435293302	7037	118	23F
0005435293423	26890	1	1A
0005432058430	26890	2	1C
0005434407786	26890	3	1D
0005434299634	26890	4	2A
0005435293422	26890	5	1F
0005434299727	26890	6	2D
0005434407756	26890	7	2F
0005435311223	26890	8	3A
0005434408185	26890	9	3D
0005434408034	26890	10	3F
0005434407729	26890	11	4A
0005434299825	26890	12	4B
0005434407810	26890	13	4C
0005434299810	26890	14	4E
0005434407978	26890	15	4D
0005434408046	26890	16	5A
0005434299636	26890	17	4F
0005434408033	26890	18	5B
0005434299679	26890	19	5C
0005434407807	26890	20	5D
0005435293415	26890	21	5E
0005434407808	26890	22	5F
0005434299649	26890	23	6B
0005435293426	26890	24	6A
0005435293424	26890	25	6C
0005434299728	26890	26	6D
0005434408214	26890	27	6E
0005434407757	26890	28	7A
0005434299606	26890	29	6F
0005434408182	26890	30	7C
0005434407903	26890	31	7B
0005434408287	26890	32	7D
0005434408211	26890	33	7F
0005434299654	26890	34	7E
0005434299811	26890	35	8A
0005435311221	26890	36	8B
0005435311224	26890	37	8D
0005434408015	26890	38	8C
0005435293420	26890	39	8E
0005434299517	26890	40	8F
0005434407904	26890	41	9B
0005434408055	26890	42	9D
0005434299664	26890	43	9C
0005434407973	26890	44	9E
0005434408053	26890	45	9F
0005434407616	26890	46	10B
0005434407670	26890	47	10D
0005434407863	26890	48	10C
0005435293421	26890	49	10E
0005435293417	26890	50	11A
0005434408205	26890	51	11B
0005434408029	26890	52	11D
0005434299672	26890	53	11C
0005434299670	26890	54	12A
0005434408174	26890	55	11F
0005434407811	26890	56	12B
0005434408060	26890	57	12D
0005434408067	26890	58	12C
0005434407946	26890	59	12E
0005434408042	26890	60	12F
0005434299750	26890	61	13A
0005434299721	26890	62	13C
0005434407997	26890	63	13B
0005434407809	26890	64	13D
0005434299690	26890	65	13E
0005434407949	26890	66	14A
0005434408000	26890	67	13F
0005435293416	26890	68	14C
0005432058431	26890	69	14B
0005434299648	26890	70	14D
0005434408203	26890	71	14E
0005434299661	26890	72	15A
0005434299677	26890	73	14F
0005434408206	26890	74	15B
0005434408043	26890	75	15C
0005434408030	26890	76	15D
0005434299718	26890	77	15E
0005434299618	26890	78	15F
0005432058432	26890	79	16B
0005435311222	26890	80	16A
0005434408045	26890	81	16C
0005435311225	26890	82	16E
0005434407671	26890	83	16D
0005434407918	26890	84	17A
0005434407947	26890	85	16F
0005434299709	26890	86	17B
0005435293418	26890	87	17C
0005434299761	26890	88	17D
0005434299696	26890	89	17F
0005434299645	26890	90	17E
0005434407983	26890	91	18A
0005435293419	26890	92	18B
0005434407770	26890	93	18C
0005434299722	26890	94	18E
0005434408196	26890	95	18D
0005434407932	26890	96	18F
0005434408201	26890	97	19A
0005435311220	26890	98	19B
0005434407706	26890	99	19D
0005434407933	26890	100	19C
0005434407862	26890	101	19E
0005434408157	26890	102	19F
0005434407945	26890	103	20B
0005435293425	26890	104	20A
0005434299720	26890	105	20D
0005434299689	26890	106	20C
0005434408068	26890	107	20E
0005434299739	26890	108	20F
0005434407952	26890	109	21B
0005434407543	26890	110	21A
0005434299724	26890	111	21C
0005434408072	26890	112	21D
0005435293414	26890	113	21E
0005434408172	26890	114	21F
0005434408198	26890	115	22B
0005434407847	26890	116	22A
0005434408173	26890	117	22C
0005434408288	26890	118	22E
0005434407785	26890	119	22D
0005434299678	26890	120	23A
0005434408212	26890	121	22F
0005434408200	26890	122	23B
0005434408061	26890	123	23C
0005434299605	26890	124	23E
0005434407829	26890	125	23D
0005434408213	26890	126	23F
0005434512176	6480	1	1A
0005434512173	6480	2	1B
0005432604884	6480	3	1C
0005432604897	6480	4	1D
0005432604866	6480	5	2B
0005432604872	6480	6	2A
0005432604874	6480	7	2C
0005432604861	6480	8	2D
0005432604873	6480	9	3A
0005434512177	6480	10	3B
0005432604894	6480	11	3C
0005432604883	6480	12	3D
0005432604881	6480	13	4A
0005432604889	6480	14	4B
0005432604878	6480	15	4C
0005432604899	6480	16	4D
0005432604860	6480	17	5A
0005432604891	6480	18	5B
0005435218116	6480	19	5C
0005432604867	6480	20	5D
0005432604871	6480	21	6A
0005435218118	6480	22	6B
0005432604865	6480	23	6C
0005432604870	6480	24	6D
0005432604886	6480	25	7A
0005434512172	6480	26	7B
0005432604885	6480	27	7C
0005432604893	6480	28	7D
0005432604898	6480	29	18A
0005432604892	6480	30	18B
0005434512174	6480	31	18C
0005434512175	6480	32	18D
0005432604875	6480	33	19A
0005432604864	6480	34	19B
0005432604880	6480	35	19D
0005432604863	6480	36	19C
0005432604888	6480	37	20A
0005432604877	6480	38	20B
0005432604862	6480	39	20C
0005432604882	6480	40	20D
0005432604876	6480	41	21A
0005432604887	6480	42	21B
0005432604890	6480	43	21C
0005432604895	6480	44	21D
0005434512171	6480	45	22A
0005432604896	6480	46	22B
0005432604869	6480	47	22C
0005432604868	6480	48	22D
0005432604879	6480	49	23A
0005434512170	6480	50	23B
0005432604503	21384	1	1A
0005432604329	21384	2	1B
0005432604698	21384	3	1C
0005432604293	21384	4	1D
0005432604525	21384	5	2A
0005434512135	21384	6	2B
0005432604444	21384	7	2C
0005432604428	21384	8	2D
0005432604619	21384	9	3A
0005432604443	21384	10	3B
0005432604555	21384	11	3C
0005432604266	21384	12	3D
0005432604527	21384	13	4A
0005432604620	21384	14	4B
0005432604295	21384	15	4C
0005432604397	21384	16	4D
0005432604528	21384	17	5A
0005432604460	21384	18	5B
0005432604396	21384	19	5C
0005434512142	21384	20	5D
0005432604440	21384	21	6A
0005432604473	21384	22	6B
0005432604427	21384	23	6C
0005432604508	21384	24	6D
0005432604479	21384	25	7A
0005434512139	21384	26	7B
0005432604265	21384	27	7C
0005432604445	21384	28	7D
0005432604630	21384	29	18A
0005432604294	21384	30	18B
0005432604570	21384	31	18C
0005432604403	21384	32	18D
0005432604557	21384	33	19A
0005432604504	21384	34	19B
0005432604357	21384	35	19C
0005432604550	21384	36	19D
0005432604613	21384	37	20A
0005434512138	21384	38	20B
0005432604621	21384	39	20C
0005432604535	21384	40	20D
0005432604561	21384	41	21B
0005432604356	21384	42	21A
0005434512141	21384	43	21C
0005432604414	21384	44	21D
0005432604554	21384	45	22A
0005432604524	21384	46	22B
0005434512150	21384	47	22C
0005432604495	21384	48	22D
0005432604560	21384	49	23A
0005434512146	21384	50	23B
0005433251895	14999	1	1A
0005433251882	14999	2	1C
0005434907504	14999	3	1F
0005434907505	14999	4	2A
0005433251888	14999	5	2C
0005434907517	14999	6	2F
0005434907459	14999	7	3A
0005433251885	14999	8	3C
0005434907472	14999	9	3D
0005434907521	14999	10	3F
0005434907469	14999	11	4A
0005434907450	14999	12	4C
0005434907432	14999	13	4D
0005434907460	14999	14	4E
0005434907627	14999	15	4F
0005434907537	14999	16	5C
0005434907393	14999	17	5D
0005434907419	14999	18	5E
0005434907650	14999	19	5F
0005433251891	14999	20	6A
0005433251879	14999	21	6C
0005433251877	14999	22	6D
0005434907420	14999	23	6E
0005434907443	14999	24	6F
0005434907364	14999	25	7A
0005433251897	14999	26	7D
0005434907348	14999	27	7E
0005434907463	14999	28	7F
0005433251906	14999	29	8A
0005433251890	14999	30	8C
0005434907634	14999	31	8D
0005434907356	14999	32	8E
0005434907635	14999	33	9C
0005434907528	14999	34	9D
0005433251883	14999	35	9E
0005434907284	14999	36	9F
0005434907398	14999	37	10A
0005434907513	14999	38	10C
0005434907451	14999	39	10D
0005434907197	14999	40	10E
0005433251898	14999	41	10F
0005433251886	14999	42	11A
0005434907506	14999	43	11C
0005433251881	14999	44	11D
0005434907503	14999	45	11E
0005434907421	14999	46	12A
0005434907167	14999	47	12C
0005434907166	14999	48	12D
0005433251887	14999	49	12E
0005434907474	14999	50	12F
0005434907555	14999	51	13A
0005433251900	14999	52	13C
0005434907400	14999	53	13D
0005434907358	14999	54	13E
0005434907562	14999	55	13F
0005434907527	14999	56	14A
0005434907531	14999	57	14C
0005433251892	14999	58	14D
0005434907630	14999	59	14E
0005433251903	14999	60	15C
0005433251904	14999	61	15D
0005433251899	14999	62	15F
0005433251901	14999	63	16A
0005434907640	14999	64	16C
0005434907639	14999	65	16D
0005433251884	14999	66	16E
0005433251905	14999	67	16F
0005434907473	14999	68	17A
0005433251894	14999	69	17C
0005433251902	14999	70	17D
0005433251896	14999	71	17E
0005434907431	14999	72	17F
0005433251893	14999	73	18A
0005433251876	14999	74	18C
0005434907493	14999	75	18D
0005434907516	14999	76	18E
0005434907629	14999	77	18F
0005434907536	14999	78	19A
0005434907399	14999	79	19C
0005434907462	14999	80	19D
0005434907512	14999	81	19E
0005433251878	14999	82	19F
0005434907641	14999	83	20A
0005434907530	14999	84	20C
0005434907430	14999	85	20D
0005433251880	14999	86	20E
0005433251889	14999	87	20F
0005433251717	25872	1	1A
0005434907943	25872	2	1C
0005434907947	25872	3	1D
0005434907960	25872	4	1F
0005434907912	25872	5	2A
0005434907930	25872	6	2D
0005434907959	25872	7	2C
0005434907908	25872	8	2F
0005434907925	25872	9	3A
0005433251582	25872	10	3C
0005434907918	25872	11	3D
0005433251517	25872	12	3F
0005433251531	25872	13	4A
0005434907939	25872	14	4C
0005433251622	25872	15	4D
0005434907928	25872	16	4E
0005434907955	25872	17	4F
0005434907954	25872	18	5A
0005433251641	25872	19	5C
0005434907917	25872	20	5D
0005434907948	25872	21	5E
0005434907915	25872	22	5F
0005434907906	25872	23	6A
0005434907935	25872	24	6C
0005434907926	25872	25	6D
0005434907953	25872	26	6E
0005434907916	25872	27	6F
0005433251657	25872	28	7A
0005434907956	25872	29	7C
0005434907945	25872	30	7D
0005433251639	25872	31	7E
0005434907911	25872	32	8A
0005434907937	25872	33	8C
0005433251573	25872	34	8D
0005434907923	25872	35	8E
0005433251665	25872	36	8F
0005434907958	25872	37	9A
0005434907905	25872	38	9C
0005433251659	25872	39	9D
0005434907931	25872	40	9E
0005433251814	25872	41	9F
0005434907920	25872	42	10A
0005434907904	25872	43	10C
0005433251574	25872	44	10D
0005434907949	25872	45	10E
0005433251658	25872	46	10F
0005433251557	25872	47	11A
0005434907936	25872	48	11D
0005434907909	25872	49	11C
0005433251716	25872	50	11E
0005434907938	25872	51	11F
0005434907942	25872	52	12A
0005434907951	25872	53	12C
0005433251619	25872	54	12D
0005433251730	25872	55	12E
0005434907913	25872	56	13A
0005434907932	25872	57	13D
0005433251570	25872	58	13E
0005434907941	25872	59	13F
0005434907914	25872	60	14A
0005433251634	25872	61	14C
0005433251603	25872	62	14D
0005433251633	25872	63	14E
0005434907922	25872	64	14F
0005433251656	25872	65	15C
0005434907950	25872	66	15A
0005434907957	25872	67	15D
0005433251550	25872	68	15E
0005433251513	25872	69	15F
0005433251503	25872	70	16A
0005434907910	25872	71	16C
0005433251666	25872	72	16D
0005434907952	25872	73	16E
0005433251640	25872	74	16F
0005434907944	25872	75	17A
0005433251559	25872	76	17C
0005434907924	25872	77	17D
0005433251623	25872	78	17E
0005433251558	25872	79	17F
0005434907919	25872	80	18A
0005433251551	25872	81	18D
0005434907907	25872	82	18C
0005434907929	25872	83	18E
0005433251681	25872	84	18F
0005434907927	25872	85	19A
0005433251680	25872	86	19C
0005434907940	25872	87	19D
0005434907934	25872	88	19E
0005434907933	25872	89	19F
0005433251563	25872	90	20A
0005433251569	25872	91	20C
0005434907946	25872	92	20D
0005433251632	25872	93	20E
0005434907921	25872	94	20F
0005433810552	14150	1	1C
0005433810538	14150	2	1D
0005433009222	14150	3	1F
0005433810551	14150	4	2C
0005433009233	14150	5	2D
0005433009240	14150	6	3C
0005433009235	14150	7	4E
0005433009231	14150	8	4F
0005433009245	14150	9	5A
0005433009256	14150	10	5D
0005433009258	14150	11	5E
0005433009230	14150	12	6C
0005433009244	14150	13	6D
0005433810558	14150	14	6E
0005433009247	14150	15	6F
0005433009218	14150	16	7C
0005433009237	14150	17	7D
0005433009241	14150	18	8C
0005433009220	14150	19	8D
0005433009238	14150	20	9A
0005433009225	14150	21	9E
0005433009248	14150	22	10E
0005433009254	14150	23	10F
0005433009239	14150	24	11A
0005433009216	14150	25	11C
0005433009223	14150	26	11F
0005433009242	14150	27	12A
0005433009224	14150	28	12D
0005433009243	14150	29	12F
0005433810539	14150	30	12E
0005433009246	14150	31	13C
0005433009228	14150	32	13D
0005433009255	14150	33	13F
0005433009257	14150	34	14C
0005433009234	14150	35	14D
0005433009250	14150	36	14E
0005433009221	14150	37	15A
0005433009219	14150	38	15E
0005433810557	14150	39	16A
0005433009226	14150	40	16D
0005433009215	14150	41	16E
0005433009252	14150	42	16F
0005433810540	14150	43	17C
0005433009251	14150	44	17F
0005433009217	14150	45	18A
0005433009259	14150	46	18D
0005433810555	14150	47	18E
0005433009253	14150	48	19A
0005433810559	14150	49	19D
0005433009232	14150	50	19F
0005433009249	14150	51	20A
0005433009236	14150	52	20C
0005433009229	14150	53	20D
0005433810565	14150	54	20E
0005433009227	14150	55	20F
0005433008756	22817	1	1D
0005433008696	22817	2	2C
0005433008777	22817	3	3A
0005433008771	22817	4	3F
0005433008754	22817	5	4E
0005433008966	22817	6	5D
0005433008744	22817	7	6C
0005433008568	22817	8	6E
0005433008904	22817	9	6F
0005433008930	22817	10	7C
0005433008902	22817	11	7F
0005433008711	22817	12	8A
0005433008668	22817	13	8E
0005433008874	22817	14	9C
0005433008667	22817	15	9F
0005433008779	22817	16	10C
0005433008959	22817	17	10D
0005433008850	22817	18	10E
0005433009025	22817	19	10F
0005433008851	22817	20	11A
0005433008731	22817	21	11D
0005433008706	22817	22	11F
0005433008928	22817	23	13A
0005433008709	22817	24	13D
0005433008712	22817	25	13E
0005433008689	22817	26	14A
0005433008872	22817	27	14D
0005433008726	22817	28	14F
0005433008755	22817	29	15A
0005433009043	22817	30	15C
0005433008913	22817	31	15D
0005433008821	22817	32	16E
0005433008715	22817	33	17A
0005433008571	22817	34	17E
0005433008820	22817	35	18A
0005433008569	22817	36	18C
0005433008730	22817	37	18D
0005433008958	22817	38	19D
0005433008778	22817	39	19E
0005433008784	22817	40	19F
0005433008945	22817	41	20A
0005433008533	22817	42	20D
0005433008581	22817	43	20F
0005435718885	27123	1	1D
0005435718939	27123	2	2A
0005435718895	27123	3	3C
0005435718949	27123	4	3F
0005435718935	27123	5	4C
0005435718938	27123	6	4F
0005435718933	27123	7	6D
0005435718951	27123	8	6F
0005435718936	27123	9	7A
0005435718945	27123	10	7E
0005435718930	27123	11	8A
0005435718920	27123	12	8E
0005435718894	27123	13	8F
0005435718888	27123	14	9C
0005435718953	27123	15	9D
0005435718955	27123	16	11D
0005435718886	27123	17	11E
0005435718950	27123	18	12C
0005435718977	27123	19	12F
0005435718959	27123	20	13A
0005435718961	27123	21	13C
0005435718965	27123	22	13E
0005435718976	27123	23	13F
0005435718960	27123	24	14C
0005435718928	27123	25	14D
0005435718907	27123	26	15C
0005435718952	27123	27	15E
0005435718964	27123	28	15F
0005435718937	27123	29	16A
0005435718898	27123	30	16C
0005435718934	27123	31	17A
0005435718925	27123	32	17D
0005435718946	27123	33	17E
0005435718906	27123	34	18E
0005435718966	27123	35	20A
0005435718932	27123	36	20E
0005434925842	14947	1	1A
0005434925925	14947	2	1D
0005434925956	14947	3	1F
0005434925914	14947	4	4E
0005434925935	14947	5	4F
0005434925870	14947	6	5A
0005434925952	14947	7	5D
0005434925841	14947	8	5F
0005434925844	14947	9	6C
0005434925938	14947	10	6E
0005434925927	14947	11	6F
0005434925884	14947	12	7C
0005434925876	14947	13	7D
0005434925957	14947	14	7E
0005434925843	14947	15	8D
0005434925877	14947	16	9A
0005434925840	14947	17	9F
0005434925875	14947	18	10F
0005434925869	14947	19	11E
0005434925917	14947	20	14C
0005434925881	14947	21	14D
0005434925954	14947	22	14F
0005434925950	14947	23	15C
0005434925868	14947	24	15D
0005434925953	14947	25	15E
0005434925955	14947	26	16C
0005434925934	14947	27	16D
0005434925911	14947	28	17A
0005434925929	14947	29	17C
0005434925880	14947	30	17E
0005434925928	14947	31	17F
0005434925926	14947	32	18D
0005434925937	14947	33	18E
0005434925861	14947	34	20A
0005434925795	14947	35	20F
0005434926190	20499	1	1F
0005434926189	20499	2	2F
0005434926197	20499	3	3A
0005434926191	20499	4	3D
0005434926201	20499	5	4A
0005434926215	20499	6	4D
0005434926204	20499	7	4F
0005434926207	20499	8	5C
0005434926195	20499	9	5D
0005434926216	20499	10	5E
0005434926219	20499	11	5F
0005434926193	20499	12	6D
0005434926203	20499	13	6E
0005434926198	20499	14	6F
0005434926194	20499	15	7D
0005434926210	20499	16	7F
0005434926218	20499	17	8F
0005434926213	20499	18	9C
0005434926199	20499	19	10A
0005434926192	20499	20	10C
0005434926220	20499	21	10E
0005434926211	20499	22	12C
0005434926200	20499	23	12E
0005434926212	20499	24	13A
0005434926205	20499	25	14D
0005434926206	20499	26	15A
0005434926221	20499	27	15C
0005434926196	20499	28	15F
0005434926209	20499	29	16D
0005434926188	20499	30	17A
0005434926214	20499	31	17D
0005434926208	20499	32	18E
0005434926217	20499	33	20C
0005434926202	20499	34	20D
0005435488127	15846	1	1A
0005435488138	15846	2	1B
0005435488134	15846	3	1C
0005435999324	15846	4	2A
0005435488133	15846	5	2C
0005435999351	15846	6	2D
0005435999326	15846	7	3A
0005435999346	15846	8	3D
0005435999327	15846	9	4A
0005435488124	15846	10	4B
0005435488126	15846	11	4C
0005435488130	15846	12	4D
0005435999341	15846	13	5A
0005435999334	15846	14	5B
0005435488131	15846	15	5C
0005435488139	15846	16	6A
0005435488135	15846	17	6C
0005435488128	15846	18	6D
0005435488137	15846	19	7A
0005435999228	15846	20	7B
0005435999352	15846	21	7C
0005435488123	15846	22	7D
0005435488122	15846	23	18A
0005435488132	15846	24	18C
0005435999376	15846	25	18D
0005435999336	15846	26	19A
0005435488136	15846	27	19C
0005435488125	15846	28	19D
0005435999332	15846	29	20A
0005435488119	15846	30	20B
0005435488129	15846	31	20C
0005435488121	15846	32	20D
0005435488120	15846	33	21A
0005435999377	15846	34	21B
0005435999371	15846	35	21C
0005435999375	15846	36	21D
0005435999323	15846	37	22A
0005435999229	15846	38	22C
0005435999333	15846	39	22D
0005435999353	15846	40	23B
0005435999471	19714	1	1A
0005435487948	19714	2	1B
0005435999475	19714	3	1D
0005435487928	19714	4	2A
0005435487927	19714	5	2B
0005435999472	19714	6	2C
0005435487809	19714	7	2D
0005435487905	19714	8	3A
0005435999463	19714	9	3B
0005435487902	19714	10	3C
0005435487801	19714	11	3D
0005435487866	19714	12	4A
0005435487846	19714	13	4B
0005435999460	19714	14	4C
0005435487884	19714	15	4D
0005435487810	19714	16	5A
0005435487841	19714	17	5B
0005435999459	19714	18	5C
0005435999467	19714	19	6A
0005435487931	19714	20	6C
0005435487808	19714	21	7A
0005435487901	19714	22	7B
0005435999466	19714	23	7C
0005435999458	19714	24	7D
0005435999461	19714	25	18A
0005435999468	19714	26	18B
0005435487938	19714	27	18D
0005435999473	19714	28	19A
0005435999465	19714	29	19B
0005435999470	19714	30	19C
0005435487982	19714	31	20A
0005435999457	19714	32	20B
0005435999462	19714	33	20C
0005435999464	19714	34	20D
0005435999469	19714	35	21A
0005435487848	19714	36	21B
0005435487840	19714	37	21C
0005435487947	19714	38	21D
0005435487871	19714	39	22A
0005435487929	19714	40	22B
0005435487912	19714	41	22C
0005435999474	19714	42	22D
0005435487932	19714	43	23A
0005432537068	6010	1	1C
0005435839843	6010	2	1F
0005435839828	6010	3	1D
0005435472920	6010	4	2F
0005435472935	6010	5	2C
0005435839841	6010	6	3D
0005435472934	6010	7	4A
0005435839838	6010	8	4D
0005435839837	6010	9	4C
0005435839830	6010	10	5D
0005435472830	6010	11	5F
0005435839826	6010	12	6A
0005435839846	6010	13	6D
0005435839829	6010	14	6C
0005435839831	6010	15	6F
0005435839823	6010	16	6E
0005435472827	6010	17	7C
0005435839845	6010	18	7E
0005435472872	6010	19	8B
0005435472826	6010	20	8A
0005435839836	6010	21	8D
0005435839833	6010	22	8E
0005435472864	6010	23	9A
0005432142293	6010	24	9C
0005435839848	6010	25	9D
0005432660846	6010	26	9F
0005432142295	6010	27	11B
0005435472869	6010	28	11E
0005435839825	6010	29	12D
0005432142294	6010	30	12E
0005435839840	6010	31	13A
0005432660847	6010	32	12F
0005435839822	6010	33	13B
0005435839850	6010	34	14A
0005435839834	6010	35	13F
0005435839835	6010	36	14F
0005435839839	6010	37	14E
0005435472873	6010	38	15B
0005435839821	6010	39	15D
0005435472879	6010	40	15F
0005435839849	6010	41	16B
0005432659735	6010	42	16A
0005432660848	6010	43	16C
0005435472898	6010	44	16D
0005435472946	6010	45	16F
0005435839842	6010	46	17A
0005435472928	6010	47	17D
0005435839844	6010	48	17F
0005435472828	6010	49	18C
0005432659736	6010	50	19A
0005432658621	6010	51	18F
0005435839847	6010	52	19C
0005435839827	6010	53	19B
0005435472868	6010	54	19D
0005435839824	6010	55	20B
0005432658620	6010	56	20A
0005435839832	6010	57	20D
0005435472924	6010	58	21D
0005435839630	18083	1	2A
0005435839576	18083	2	2F
0005435473018	18083	3	4A
0005435473031	18083	4	4D
0005435839647	18083	5	5C
0005435839658	18083	6	5A
0005435839705	18083	7	6A
0005435473028	18083	8	6E
0005432667459	18083	9	7F
0005435839558	18083	10	8B
0005435839584	18083	11	8D
0005435839514	18083	12	9B
0005435839628	18083	13	9D
0005435839702	18083	14	9F
0005435473034	18083	15	10C
0005435473027	18083	16	10E
0005435839618	18083	17	10D
0005435839629	18083	18	11D
0005435617236	18083	19	11C
0005435839511	18083	20	12C
0005435473030	18083	21	12F
0005432660828	18083	22	12E
0005435473020	18083	23	13B
0005435473019	18083	24	13A
0005435839617	18083	25	13C
0005435839657	18083	26	13D
0005435839583	18083	27	13F
0005435839663	18083	28	14C
0005435839534	18083	29	14D
0005435473023	18083	30	14F
0005435473024	18083	31	15B
0005432537087	18083	32	15F
0005435839610	18083	33	15E
0005435839486	18083	34	16D
0005435839703	18083	35	16F
0005435473025	18083	36	17B
0005435839594	18083	37	17A
0005435473026	18083	38	17D
0005435473033	18083	39	17F
0005435617237	18083	40	18C
0005432537088	18083	41	18E
0005435473021	18083	42	19A
0005435473029	18083	43	18F
0005435839512	18083	44	19E
0005432664135	18083	45	19C
0005435839611	18083	46	19F
0005435473032	18083	47	20A
0005435839598	18083	48	20D
0005432664140	18083	49	20C
0005435473022	18083	50	21B
0005432660824	18083	51	21F
0005433460427	19910	1	1H
0005433460438	19910	2	2C
0005433460440	19910	3	4A
0005433460413	19910	4	11D
0005433462735	19910	5	11G
0005433462751	19910	6	12A
0005433460444	19910	7	13B
0005433460441	19910	8	13F
0005433462734	19910	9	15G
0005433462749	19910	10	16D
0005433462744	19910	11	17H
0005433460442	19910	12	18A
0005433460432	19910	13	19D
0005433462743	19910	14	19E
0005433462742	19910	15	20D
0005433460430	19910	16	20H
0005433460426	19910	17	21D
0005433462750	19910	18	22G
0005433460443	19910	19	24F
0005433462748	19910	20	25E
0005433460429	19910	21	27A
0005433460428	19910	22	28E
0005433462747	19910	23	28F
0005433460414	19910	24	29H
0005433462727	19910	25	30H
0005433460439	19910	26	32H
0005433460437	19910	27	35H
0005433460431	19910	28	36F
0005433462726	19910	29	36E
0005433460419	19910	30	36G
0005435104019	23057	1	1D
0005433285475	23057	2	1C
0005433285570	23057	3	2A
0005433285396	23057	4	2D
0005433285453	23057	5	4D
0005435104029	23057	6	5C
0005433285458	23057	7	5D
0005433285476	23057	8	6D
0005435104027	23057	9	7B
0005433285460	23057	10	7C
0005435104026	23057	11	7E
0005433285431	23057	12	8B
0005433285228	23057	13	8E
0005433285569	23057	14	9B
0005435104024	23057	15	9D
0005433285539	23057	16	9C
0005433285472	23057	17	11B
0005433285518	23057	18	11D
0005433285272	23057	19	13B
0005433285409	23057	20	13C
0005433285308	23057	21	13E
0005435104023	23057	22	14A
0005435104021	23057	23	14B
0005433285367	23057	24	14F
0005433285607	23057	25	15B
0005435104018	23057	26	15E
0005433285542	23057	27	16A
0005435104022	23057	28	17A
0005435104017	23057	29	18F
0005435104025	23057	30	19A
0005435104028	23057	31	19F
0005433285397	23057	32	20D
0005435104020	23057	33	21C
0005433285451	23057	34	22A
0005433285484	23057	35	22B
0005433285540	23057	36	22E
0005433285483	23057	37	23B
0005433285229	23057	38	23A
0005433285730	32083	1	1A
0005433285733	32083	2	4D
0005433285729	32083	3	4F
0005435103936	32083	4	5C
0005435103953	32083	5	6C
0005433285728	32083	6	6B
0005433285734	32083	7	6D
0005435103915	32083	8	6E
0005433285711	32083	9	6F
0005433285720	32083	10	7B
0005433285722	32083	11	7A
0005433285739	32083	12	7D
0005433285738	32083	13	8A
0005433285731	32083	14	8E
0005433285727	32083	15	10E
0005433285737	32083	16	11B
0005433285709	32083	17	12D
0005433285715	32083	18	13B
0005433285714	32083	19	14B
0005433285718	32083	20	14D
0005433285726	32083	21	15A
0005433285725	32083	22	16A
0005433285724	32083	23	16C
0005435103932	32083	24	17A
0005433285716	32083	25	17C
0005433285712	32083	26	18A
0005433285717	32083	27	18C
0005433285736	32083	28	18D
0005433285713	32083	29	19C
0005433285735	32083	30	19D
0005433285719	32083	31	19E
0005433285721	32083	32	19F
0005433285723	32083	33	21A
0005433285732	32083	34	22B
0005433285708	32083	35	22F
0005433285710	32083	36	23D
0005434302866	19945	1	1C
0005432802493	19945	2	1A
0005434302868	19945	3	2A
0005432892787	19945	4	2D
0005432802486	19945	5	2C
0005432802492	19945	6	3D
0005432802502	19945	7	3C
0005434302854	19945	8	3F
0005434302865	19945	9	4D
0005434302864	19945	10	4C
0005434302858	19945	11	5C
0005432802483	19945	12	5A
0005432892778	19945	13	5F
0005432892782	19945	14	5D
0005432892788	19945	15	6A
0005433112388	19945	16	6E
0005432802498	19945	17	7A
0005433111525	19945	18	7C
0005432802515	19945	19	7B
0005433111523	19945	20	7E
0005434302860	19945	21	8A
0005432892783	19945	22	8B
0005432802485	19945	23	8D
0005432802526	19945	24	8C
0005432802527	19945	25	8E
0005434302870	19945	26	9B
0005432802475	19945	27	9A
0005433112387	19945	28	9C
0005433111526	19945	29	9E
0005432892777	19945	30	9D
0005433111520	19945	31	10A
0005433112391	19945	32	10C
0005433112384	19945	33	10B
0005434302862	19945	34	10E
0005433112385	19945	35	11A
0005432802517	19945	36	10F
0005432802496	19945	37	11B
0005433112392	19945	38	11C
0005433112390	19945	39	11E
0005432892790	19945	40	12B
0005432892780	19945	41	12A
0005432802495	19945	42	12D
0005432892785	19945	43	12C
0005433111522	19945	44	12F
0005432892784	19945	45	12E
0005434302857	19945	46	13B
0005432802516	19945	47	13A
0005432802525	19945	48	13E
0005432892786	19945	49	14A
0005432892776	19945	50	13F
0005434302863	19945	51	14B
0005432802528	19945	52	14E
0005432802514	19945	53	14D
0005434302861	19945	54	14C
0005434302872	19945	55	14F
0005434302859	19945	56	15B
0005432802529	19945	57	15A
0005432802522	19945	58	15D
0005433111530	19945	59	15C
0005432802521	19945	60	15E
0005434302867	19945	61	16A
0005432802518	19945	62	15F
0005432892792	19945	63	16C
0005433112389	19945	64	16B
0005433112386	19945	65	16D
0005432802530	19945	66	16F
0005433111533	19945	67	16E
0005432892781	19945	68	17B
0005432892789	19945	69	17A
0005433111521	19945	70	17D
0005432802491	19945	71	17E
0005434302856	19945	72	18A
0005433111524	19945	73	17F
0005432802477	19945	74	18B
0005432802484	19945	75	18E
0005432892779	19945	76	18D
0005433111531	19945	77	18F
0005433111527	19945	78	19C
0005432802478	19945	79	19E
0005433111529	19945	80	19D
0005433111534	19945	81	19F
0005433111532	19945	82	20B
0005434302855	19945	83	20D
0005433111528	19945	84	20C
0005434302871	19945	85	20F
0005432892791	19945	86	21C
0005434302869	19945	87	20E
0005432802476	19945	88	21F
0005432802482	19945	89	21E
\.


--
-- Data for Name: bookings; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY bookings (book_ref, book_date, total_amount) FROM stdin;
00000F	2017-07-05 03:12:00+03	265700.00
000012	2017-07-14 09:02:00+03	37900.00
000068	2017-08-15 14:27:00+03	18100.00
000181	2017-08-10 13:28:00+03	131800.00
0002D8	2017-08-07 21:40:00+03	23600.00
0002DB	2017-07-29 06:30:00+03	101500.00
0002E0	2017-07-11 16:09:00+03	89600.00
0002F3	2017-07-10 05:31:00+03	69600.00
00034E	2017-08-04 16:52:00+03	73300.00
000352	2017-07-06 02:02:00+03	109500.00
000374	2017-08-12 10:13:00+03	136200.00
00044D	2017-07-30 00:24:00+03	6000.00
00044E	2017-07-17 05:39:00+03	140100.00
0004B0	2017-07-28 09:00:00+03	12000.00
0004E1	2017-07-31 17:34:00+03	139300.00
000511	2017-07-01 03:40:00+03	26700.00
00053F	2017-08-06 03:15:00+03	6000.00
00054E	2017-07-15 10:54:00+03	50700.00
0005E7	2017-07-03 09:25:00+03	28800.00
0005F4	2017-08-09 02:14:00+03	95400.00
0005FF	2017-07-18 03:27:00+03	56300.00
00067B	2017-07-12 02:35:00+03	296700.00
0006C3	2017-08-02 11:42:00+03	59400.00
0006F5	2017-08-04 22:10:00+03	80200.00
000735	2017-07-08 12:19:00+03	51900.00
000769	2017-07-08 18:05:00+03	32800.00
000784	2017-07-27 21:51:00+03	28800.00
0007A9	2017-07-14 08:17:00+03	43200.00
0007ED	2017-07-10 19:18:00+03	137700.00
0007FC	2017-07-04 12:09:00+03	75600.00
000836	2017-08-12 23:28:00+03	23400.00
000842	2017-07-09 22:55:00+03	81700.00
000859	2017-07-05 06:12:00+03	234800.00
000862	2017-08-07 14:23:00+03	45500.00
0008DF	2017-07-25 12:33:00+03	92400.00
0008F4	2017-08-01 00:33:00+03	28000.00
0008FD	2017-07-04 15:58:00+03	24400.00
000909	2017-08-01 04:30:00+03	99700.00
000917	2017-07-27 00:01:00+03	28000.00
00094B	2017-08-15 03:38:00+03	67000.00
00098F	2017-07-23 02:05:00+03	38600.00
000999	2017-07-23 05:37:00+03	31100.00
0009D5	2017-07-16 06:16:00+03	88900.00
0009ED	2017-07-08 14:25:00+03	14000.00
000A1E	2017-07-19 10:25:00+03	80000.00
000A39	2017-07-01 03:29:00+03	23400.00
000AA7	2017-07-13 22:15:00+03	59000.00
000AB3	2017-08-12 06:16:00+03	35400.00
000ADA	2017-07-19 12:06:00+03	124200.00
000B77	2017-07-01 02:39:00+03	68800.00
000B91	2017-07-30 13:41:00+03	24400.00
000B97	2017-07-20 20:32:00+03	101200.00
000BB3	2017-07-07 12:07:00+03	92800.00
000BD8	2017-08-04 19:12:00+03	51200.00
000BFF	2017-08-08 23:05:00+03	136800.00
000C28	2017-07-20 09:04:00+03	28800.00
000C2B	2017-07-28 04:52:00+03	28000.00
000D3C	2017-07-02 18:23:00+03	173500.00
000DBE	2017-07-07 10:20:00+03	149200.00
000DC5	2017-07-24 17:41:00+03	75800.00
000E07	2017-07-19 05:19:00+03	53200.00
000E3A	2017-07-15 20:45:00+03	67600.00
000EA2	2017-08-14 17:35:00+03	54800.00
000EFA	2017-08-12 22:01:00+03	23600.00
000F07	2017-08-01 06:15:00+03	40300.00
000F74	2017-07-11 22:20:00+03	66600.00
000F7D	2017-08-02 09:18:00+03	20600.00
000FAC	2017-07-09 18:30:00+03	168600.00
000FD6	2017-07-29 01:48:00+03	28700.00
00101D	2017-08-11 21:38:00+03	112400.00
00107C	2017-08-10 23:15:00+03	56000.00
001089	2017-08-10 18:47:00+03	46300.00
00111B	2017-07-09 14:30:00+03	29600.00
00114E	2017-08-01 12:17:00+03	6700.00
001164	2017-08-15 13:56:00+03	72400.00
001184	2017-07-27 15:00:00+03	38400.00
001191	2017-07-16 22:54:00+03	66600.00
0011A9	2017-07-31 02:22:00+03	135400.00
001233	2017-08-11 23:09:00+03	47000.00
001269	2017-07-06 02:07:00+03	30000.00
001273	2017-08-01 00:26:00+03	117900.00
00127A	2017-07-18 18:37:00+03	98000.00
0012C1	2017-07-05 05:43:00+03	26000.00
0012E3	2017-07-24 06:07:00+03	125700.00
00132C	2017-07-10 19:59:00+03	12600.00
00133E	2017-07-19 12:28:00+03	271100.00
00138A	2017-07-04 12:52:00+03	372500.00
001436	2017-07-01 14:10:00+03	101200.00
00144F	2017-07-20 08:06:00+03	94700.00
0014C1	2017-08-01 19:11:00+03	44000.00
0014E3	2017-07-08 03:11:00+03	16000.00
00150A	2017-08-08 19:16:00+03	36800.00
001547	2017-07-22 14:19:00+03	52000.00
001628	2017-07-15 10:59:00+03	813300.00
0016AD	2017-08-09 03:47:00+03	55100.00
0016BD	2017-07-16 01:27:00+03	59300.00
0016CB	2017-07-17 20:15:00+03	98400.00
0016D0	2017-07-11 02:12:00+03	52000.00
0016DE	2017-07-14 03:31:00+03	203400.00
001740	2017-08-09 02:04:00+03	73200.00
001751	2017-08-06 13:46:00+03	81300.00
00176F	2017-08-15 16:46:00+03	55800.00
001789	2017-07-19 11:40:00+03	43400.00
00178F	2017-07-10 07:13:00+03	26000.00
001820	2017-07-15 07:11:00+03	49500.00
001892	2017-08-11 16:13:00+03	6700.00
0018AB	2017-08-03 03:29:00+03	277600.00
0018E5	2017-08-04 19:02:00+03	67200.00
001932	2017-08-15 13:22:00+03	13200.00
00193F	2017-07-17 00:15:00+03	55800.00
0019EB	2017-08-12 00:09:00+03	39100.00
001A23	2017-07-18 03:30:00+03	87100.00
001A4A	2017-08-02 04:31:00+03	35900.00
001A6E	2017-07-03 18:06:00+03	21200.00
001A9F	2017-07-01 11:29:00+03	55800.00
001B68	2017-08-10 19:19:00+03	69700.00
001C10	2017-07-14 17:36:00+03	25200.00
001C4B	2017-07-28 01:57:00+03	28000.00
001C89	2017-07-14 07:41:00+03	42700.00
001D91	2017-07-07 00:05:00+03	14600.00
001D96	2017-08-11 12:24:00+03	57200.00
001D9D	2017-08-14 08:43:00+03	26800.00
001E66	2017-07-06 21:54:00+03	25800.00
001E72	2017-08-10 12:48:00+03	19600.00
001E92	2017-07-13 20:36:00+03	45100.00
001EA0	2017-08-12 10:31:00+03	18400.00
001ED4	2017-07-01 10:52:00+03	56000.00
001F08	2017-07-26 17:20:00+03	12700.00
001F1D	2017-08-06 14:49:00+03	29600.00
001F27	2017-08-03 19:10:00+03	39700.00
001FA1	2017-07-17 14:28:00+03	33000.00
001FA7	2017-08-02 00:02:00+03	73200.00
001FF3	2017-07-23 22:34:00+03	542200.00
002160	2017-07-06 18:02:00+03	31900.00
00216F	2017-07-01 16:24:00+03	47200.00
00218C	2017-07-07 19:39:00+03	17000.00
002193	2017-08-10 02:45:00+03	28000.00
0021AA	2017-08-13 12:52:00+03	45100.00
002284	2017-08-05 10:54:00+03	266400.00
002289	2017-07-07 10:50:00+03	123000.00
00229F	2017-08-12 14:42:00+03	58200.00
0022B4	2017-08-13 19:32:00+03	245300.00
002316	2017-08-15 07:31:00+03	257500.00
002365	2017-07-26 09:58:00+03	20200.00
00236B	2017-07-16 21:01:00+03	23400.00
002371	2017-08-10 02:52:00+03	19200.00
00239A	2017-07-02 02:23:00+03	42700.00
00240A	2017-08-05 10:49:00+03	58800.00
002427	2017-07-03 10:17:00+03	23400.00
0024CD	2017-07-23 22:51:00+03	8200.00
00255C	2017-08-01 01:44:00+03	77600.00
0025F1	2017-07-10 15:15:00+03	75600.00
0026F8	2017-06-25 21:15:00+03	58200.00
002705	2017-07-12 02:33:00+03	68900.00
002746	2017-07-17 21:07:00+03	230400.00
00274A	2017-07-23 17:10:00+03	22000.00
002752	2017-07-29 03:51:00+03	147100.00
002775	2017-08-04 21:16:00+03	96200.00
002822	2017-08-04 13:53:00+03	24800.00
002865	2017-07-26 15:41:00+03	31400.00
00287A	2017-07-04 11:08:00+03	72400.00
00297D	2017-08-08 23:19:00+03	25000.00
0029AE	2017-07-23 15:13:00+03	24800.00
0029C1	2017-07-08 02:22:00+03	56000.00
0029D3	2017-08-07 16:12:00+03	397300.00
0029F9	2017-06-30 01:45:00+03	58600.00
002ACE	2017-08-10 20:36:00+03	42800.00
002AF1	2017-08-02 12:57:00+03	123000.00
002B46	2017-08-13 00:49:00+03	11300.00
002B8A	2017-07-09 17:03:00+03	122600.00
002B8F	2017-07-14 09:12:00+03	34000.00
002BB2	2017-08-10 21:39:00+03	28000.00
002BED	2017-08-02 20:40:00+03	52800.00
002C5A	2017-08-14 15:18:00+03	54800.00
002CC4	2017-07-09 13:17:00+03	40000.00
002D3A	2017-07-19 12:22:00+03	23200.00
002DC9	2017-08-08 09:35:00+03	54200.00
002E15	2017-07-27 19:10:00+03	19600.00
002E3A	2017-07-29 02:10:00+03	393000.00
002EA0	2017-08-12 10:37:00+03	39200.00
002EA6	2017-07-30 03:59:00+03	13600.00
002EED	2017-07-30 12:19:00+03	133200.00
002F39	2017-07-19 17:14:00+03	136200.00
002F5F	2017-07-29 03:00:00+03	21600.00
002F96	2017-07-30 12:35:00+03	69400.00
002F9D	2017-07-03 12:59:00+03	25000.00
002FDC	2017-07-24 16:19:00+03	24400.00
002FE3	2017-08-05 21:28:00+03	123000.00
003096	2017-07-23 23:55:00+03	73200.00
00314B	2017-08-14 05:52:00+03	284400.00
0031D2	2017-08-15 17:27:00+03	24200.00
0031D9	2017-08-09 12:28:00+03	112000.00
003241	2017-07-12 08:04:00+03	12000.00
003270	2017-07-18 01:18:00+03	44800.00
003272	2017-07-21 17:22:00+03	66000.00
0032A3	2017-07-08 03:29:00+03	46300.00
003389	2017-07-15 15:19:00+03	122600.00
00338E	2017-07-10 01:02:00+03	55800.00
0033A2	2017-07-31 20:29:00+03	65900.00
00347F	2017-07-29 21:06:00+03	170000.00
0034BB	2017-07-03 02:44:00+03	48600.00
00355C	2017-07-12 08:20:00+03	70500.00
0035B5	2017-08-03 01:27:00+03	29600.00
0035C0	2017-07-10 14:31:00+03	102300.00
0035CC	2017-07-20 06:08:00+03	28800.00
0035EC	2017-08-05 19:38:00+03	52400.00
0035EF	2017-07-11 06:17:00+03	56600.00
003610	2017-07-12 00:52:00+03	203100.00
003623	2017-08-03 14:38:00+03	111600.00
00362F	2017-07-13 21:29:00+03	27400.00
003673	2017-07-09 04:49:00+03	60000.00
003699	2017-07-15 02:01:00+03	93900.00
0036FA	2017-07-13 22:12:00+03	133200.00
003743	2017-07-11 21:30:00+03	52100.00
00380F	2017-07-08 05:45:00+03	37200.00
0038C7	2017-07-31 09:39:00+03	124200.00
00391F	2017-07-30 00:46:00+03	294200.00
003936	2017-07-03 11:55:00+03	47200.00
00395B	2017-07-22 04:08:00+03	136500.00
003974	2017-07-28 13:55:00+03	246000.00
0039D4	2017-07-31 21:58:00+03	29600.00
003BC1	2017-07-03 23:37:00+03	43200.00
003C2F	2017-07-16 19:33:00+03	214100.00
003CF9	2017-07-16 14:10:00+03	10600.00
003D47	2017-07-15 21:46:00+03	21600.00
003D63	2017-08-12 02:17:00+03	36200.00
003D83	2017-08-15 17:06:00+03	36000.00
003D96	2017-08-15 04:18:00+03	65300.00
003E25	2017-08-10 18:37:00+03	16400.00
003E4E	2017-07-24 01:45:00+03	92000.00
003E84	2017-07-19 13:24:00+03	188000.00
003EB0	2017-07-05 11:25:00+03	16400.00
003EB8	2017-08-14 21:40:00+03	48500.00
003FA5	2017-08-10 20:19:00+03	6300.00
00409D	2017-08-14 11:26:00+03	93300.00
0041E6	2017-07-12 01:41:00+03	40900.00
004251	2017-07-15 17:53:00+03	31400.00
00427E	2017-08-06 15:43:00+03	132800.00
0042EF	2017-08-02 07:00:00+03	30800.00
00431A	2017-07-27 02:05:00+03	19600.00
004346	2017-07-06 09:46:00+03	270000.00
00434B	2017-08-12 12:44:00+03	26800.00
004364	2017-07-14 18:30:00+03	22000.00
004380	2017-07-06 12:41:00+03	61800.00
004382	2017-07-31 02:55:00+03	11600.00
00438B	2017-07-10 20:24:00+03	85000.00
004391	2017-08-12 04:29:00+03	28000.00
0043FB	2017-08-10 09:30:00+03	23200.00
004403	2017-08-15 03:44:00+03	94000.00
004428	2017-08-07 12:19:00+03	94300.00
004486	2017-07-02 07:21:00+03	70800.00
0044ED	2017-08-08 22:43:00+03	93900.00
0044FE	2017-07-29 07:15:00+03	69400.00
004554	2017-07-20 19:50:00+03	27900.00
004561	2017-07-22 00:07:00+03	19600.00
0045A7	2017-07-17 08:42:00+03	23600.00
0045DB	2017-07-09 02:33:00+03	119700.00
0045DE	2017-07-17 22:45:00+03	101200.00
004619	2017-08-09 15:48:00+03	96800.00
00462F	2017-07-30 07:10:00+03	57800.00
004637	2017-07-18 03:18:00+03	34000.00
004666	2017-08-14 10:45:00+03	53700.00
00467E	2017-07-13 20:33:00+03	72800.00
004690	2017-08-01 22:54:00+03	40600.00
0046B5	2017-08-13 05:46:00+03	85000.00
0046CE	2017-08-05 02:55:00+03	60100.00
00471D	2017-07-24 07:16:00+03	26800.00
004866	2017-08-12 06:47:00+03	31400.00
0048C4	2017-07-22 22:22:00+03	62000.00
00497A	2017-08-12 08:21:00+03	61800.00
004980	2017-07-18 09:32:00+03	204200.00
0049B5	2017-08-11 05:20:00+03	129700.00
0049CB	2017-08-12 18:14:00+03	56000.00
004A02	2017-07-22 04:19:00+03	55800.00
004A14	2017-08-04 07:59:00+03	28000.00
004A54	2017-07-03 08:13:00+03	15100.00
004A87	2017-07-02 11:05:00+03	29400.00
004A9F	2017-07-29 18:36:00+03	56000.00
004B38	2017-07-16 13:45:00+03	20000.00
004B5C	2017-07-17 17:28:00+03	23500.00
004B6A	2017-07-18 11:57:00+03	55800.00
004B72	2017-08-09 17:26:00+03	57600.00
004B7B	2017-07-25 07:15:00+03	111600.00
004B8E	2017-08-07 22:54:00+03	135600.00
004BC5	2017-07-03 02:59:00+03	66600.00
004C1C	2017-08-09 21:43:00+03	67600.00
004C21	2017-08-14 22:35:00+03	25600.00
004C3F	2017-07-12 05:10:00+03	69500.00
004C69	2017-08-02 14:40:00+03	62000.00
004C8E	2017-07-16 00:23:00+03	65600.00
004C90	2017-07-25 14:03:00+03	64800.00
004C98	2017-07-06 17:27:00+03	57600.00
004D0D	2017-07-07 17:57:00+03	111600.00
004DF7	2017-06-30 05:12:00+03	72300.00
004E04	2017-08-05 08:34:00+03	93200.00
004E44	2017-07-22 12:44:00+03	140000.00
004EC8	2017-07-24 03:42:00+03	132800.00
004EDA	2017-07-05 01:55:00+03	172700.00
004FC8	2017-07-23 05:47:00+03	58400.00
005069	2017-07-02 20:35:00+03	67600.00
00519C	2017-08-10 00:26:00+03	167000.00
0051D5	2017-07-25 22:48:00+03	38800.00
0051D8	2017-07-15 16:29:00+03	23600.00
0051DC	2017-08-15 04:10:00+03	269300.00
005355	2017-07-15 07:21:00+03	133100.00
00535D	2017-08-13 19:21:00+03	19800.00
005380	2017-07-18 15:12:00+03	14400.00
005492	2017-08-11 18:13:00+03	142400.00
00551A	2017-07-25 13:32:00+03	6400.00
005558	2017-06-27 03:02:00+03	28000.00
00556D	2017-07-25 14:08:00+03	68200.00
00558F	2017-08-09 19:38:00+03	28000.00
0055D7	2017-07-20 22:10:00+03	34000.00
005684	2017-07-18 15:48:00+03	58800.00
005696	2017-07-14 20:23:00+03	14000.00
0056B0	2017-07-03 00:57:00+03	28800.00
0056FA	2017-07-10 12:36:00+03	26800.00
005706	2017-08-05 03:22:00+03	57900.00
00571B	2017-07-20 04:40:00+03	468000.00
005769	2017-08-15 02:39:00+03	123600.00
00579F	2017-08-12 05:18:00+03	19600.00
0057D4	2017-07-28 11:45:00+03	206400.00
0057F8	2017-06-28 14:33:00+03	20200.00
00597A	2017-07-22 00:35:00+03	92800.00
0059AA	2017-07-19 14:47:00+03	6200.00
0059D4	2017-07-15 16:48:00+03	14400.00
0059E8	2017-07-10 16:38:00+03	69500.00
005A18	2017-07-29 10:27:00+03	134800.00
005A30	2017-08-14 14:48:00+03	26700.00
005AFA	2017-07-20 12:39:00+03	22600.00
005B3C	2017-07-28 23:48:00+03	67600.00
005BD6	2017-08-07 07:09:00+03	58000.00
005BFF	2017-08-11 21:11:00+03	45200.00
005C0B	2017-07-06 01:25:00+03	269600.00
005C0D	2017-08-02 12:08:00+03	88200.00
005C47	2017-07-26 04:40:00+03	28000.00
005C6C	2017-08-06 19:33:00+03	14400.00
005D11	2017-07-30 12:56:00+03	62000.00
005D5D	2017-08-14 15:08:00+03	53700.00
005E40	2017-07-25 05:06:00+03	6800.00
005E4E	2017-08-14 11:43:00+03	43500.00
005EBE	2017-07-09 11:03:00+03	134400.00
005EC4	2017-07-17 10:31:00+03	21800.00
005F02	2017-07-12 04:51:00+03	23200.00
005F35	2017-07-28 19:44:00+03	68800.00
005FBD	2017-07-01 06:38:00+03	29400.00
00603D	2017-07-16 13:39:00+03	99200.00
006081	2017-07-19 01:19:00+03	90800.00
006084	2017-07-23 18:54:00+03	57600.00
0060D3	2017-07-05 18:28:00+03	52900.00
00610D	2017-07-05 01:49:00+03	103200.00
006132	2017-07-02 16:40:00+03	171100.00
00613D	2017-07-25 15:17:00+03	68800.00
006149	2017-07-21 00:07:00+03	37100.00
006151	2017-08-02 02:10:00+03	34300.00
006157	2017-07-12 02:03:00+03	103200.00
006170	2017-07-26 18:22:00+03	17800.00
0061B4	2017-07-03 13:17:00+03	43600.00
00625D	2017-08-02 12:22:00+03	112000.00
0062DB	2017-08-05 01:05:00+03	34000.00
0062E8	2017-07-11 14:33:00+03	42400.00
006306	2017-08-04 14:43:00+03	29800.00
00635C	2017-07-13 02:47:00+03	13600.00
0063B3	2017-08-10 18:53:00+03	69500.00
0063CA	2017-08-04 03:39:00+03	29400.00
006404	2017-07-04 19:21:00+03	184300.00
006485	2017-07-12 16:59:00+03	37900.00
006498	2017-08-13 12:44:00+03	100600.00
0064D1	2017-08-15 02:09:00+03	65300.00
0064DD	2017-07-20 22:15:00+03	67600.00
0064E3	2017-08-12 06:43:00+03	42800.00
0065DC	2017-08-12 10:44:00+03	19600.00
006603	2017-08-14 00:17:00+03	153300.00
006624	2017-08-11 03:39:00+03	99700.00
00662A	2017-07-30 07:06:00+03	38400.00
0066BE	2017-07-29 19:45:00+03	40800.00
006704	2017-08-14 10:44:00+03	65900.00
006713	2017-07-28 15:09:00+03	46800.00
00673C	2017-08-12 18:47:00+03	87100.00
006837	2017-07-22 19:23:00+03	131100.00
006885	2017-07-24 17:54:00+03	52000.00
006906	2017-07-30 13:46:00+03	339300.00
00697B	2017-07-30 08:24:00+03	220800.00
0069AE	2017-08-04 21:34:00+03	8200.00
006B01	2017-08-03 23:35:00+03	69600.00
006B2A	2017-07-28 07:06:00+03	49800.00
006B6D	2017-07-05 13:58:00+03	84000.00
006B99	2017-08-08 20:47:00+03	14800.00
006BA1	2017-07-10 15:35:00+03	12600.00
006BAA	2017-07-11 12:01:00+03	28800.00
006BFD	2017-07-13 17:51:00+03	199700.00
006C55	2017-07-14 07:05:00+03	62600.00
006C5C	2017-07-31 07:45:00+03	81900.00
006CBB	2017-08-14 17:54:00+03	73600.00
006CC4	2017-07-12 08:20:00+03	6000.00
006D1A	2017-07-25 11:32:00+03	78200.00
006D45	2017-07-22 11:23:00+03	24400.00
006D5C	2017-07-22 22:04:00+03	40000.00
006D91	2017-07-25 22:20:00+03	66400.00
006E4E	2017-08-07 10:25:00+03	398500.00
006E64	2017-08-02 08:41:00+03	111600.00
006EEC	2017-07-22 01:41:00+03	62700.00
006F16	2017-08-05 11:00:00+03	28000.00
006F53	2017-08-14 19:28:00+03	16400.00
006F73	2017-08-05 00:35:00+03	28800.00
006FB9	2017-07-10 18:56:00+03	100600.00
006FBF	2017-07-30 03:49:00+03	21800.00
006FFF	2017-07-06 04:58:00+03	44000.00
00704E	2017-07-25 06:49:00+03	386300.00
007066	2017-07-20 04:37:00+03	46000.00
007085	2017-07-29 15:59:00+03	265800.00
0070BD	2017-07-11 08:32:00+03	115700.00
0070DF	2017-08-10 14:06:00+03	188000.00
0070F5	2017-06-30 22:05:00+03	62600.00
00711E	2017-07-30 03:58:00+03	20200.00
00717E	2017-07-01 09:26:00+03	34000.00
0071AE	2017-07-21 00:42:00+03	46400.00
0071C1	2017-08-09 10:52:00+03	6000.00
007225	2017-07-16 21:43:00+03	39500.00
007232	2017-07-28 06:12:00+03	72400.00
007247	2017-07-27 06:42:00+03	167500.00
00724C	2017-07-22 01:46:00+03	114200.00
007264	2017-08-10 22:11:00+03	18000.00
0072A0	2017-07-07 17:26:00+03	67600.00
0072B1	2017-07-29 02:54:00+03	32700.00
007322	2017-08-03 11:44:00+03	40800.00
00737B	2017-07-10 08:58:00+03	75600.00
007382	2017-07-06 21:29:00+03	26200.00
0073C5	2017-07-07 19:14:00+03	47400.00
0073CF	2017-08-08 07:59:00+03	31000.00
0073D3	2017-07-20 05:51:00+03	131600.00
007407	2017-08-02 04:09:00+03	66000.00
00742A	2017-07-31 08:40:00+03	48800.00
00742E	2017-07-22 18:09:00+03	117200.00
007477	2017-07-12 02:35:00+03	46000.00
0074B9	2017-08-11 01:09:00+03	85600.00
0074DE	2017-07-09 23:39:00+03	40400.00
00752A	2017-08-10 02:55:00+03	283100.00
007602	2017-07-04 02:14:00+03	284400.00
007621	2017-07-16 16:55:00+03	56000.00
007624	2017-08-06 19:24:00+03	31600.00
007638	2017-07-28 03:57:00+03	43500.00
007649	2017-07-31 21:39:00+03	39300.00
0076CE	2017-07-20 05:37:00+03	12600.00
00770C	2017-08-14 20:51:00+03	19600.00
007784	2017-08-04 03:12:00+03	37900.00
0077E1	2017-07-14 15:19:00+03	6000.00
0077FC	2017-08-02 17:23:00+03	31600.00
00794E	2017-07-05 18:37:00+03	13600.00
007989	2017-08-12 13:32:00+03	26000.00
0079F6	2017-07-08 02:16:00+03	28000.00
007A31	2017-08-05 23:41:00+03	62000.00
007A53	2017-07-07 22:11:00+03	112400.00
007A89	2017-07-14 18:46:00+03	122600.00
007AD1	2017-07-08 13:17:00+03	36700.00
007B9B	2017-07-06 20:14:00+03	24200.00
007BE6	2017-07-13 14:21:00+03	56900.00
007C00	2017-07-26 21:34:00+03	52900.00
007C0D	2017-07-13 12:41:00+03	86300.00
007C11	2017-08-05 14:04:00+03	189800.00
007C4E	2017-08-10 10:28:00+03	265600.00
007C7D	2017-07-09 12:57:00+03	77600.00
007CA7	2017-07-29 03:51:00+03	7400.00
007DBF	2017-07-28 07:54:00+03	40800.00
007DE7	2017-07-10 20:28:00+03	46400.00
007DF3	2017-08-04 06:14:00+03	246000.00
007E54	2017-07-28 16:30:00+03	49100.00
007E78	2017-07-05 21:43:00+03	75300.00
007EE9	2017-07-31 14:36:00+03	55800.00
007F37	2017-07-29 10:24:00+03	280500.00
007F74	2017-07-19 11:01:00+03	23400.00
007F94	2017-08-13 07:02:00+03	66600.00
007FA8	2017-07-23 20:55:00+03	47200.00
007FD3	2017-08-08 11:10:00+03	67600.00
007FF3	2017-07-14 14:46:00+03	100700.00
007FFF	2017-07-13 05:32:00+03	56600.00
0080AB	2017-07-10 03:26:00+03	56900.00
0080FD	2017-07-07 07:34:00+03	36200.00
008130	2017-08-07 11:49:00+03	88800.00
00813F	2017-07-24 20:47:00+03	58400.00
00817F	2017-08-14 08:58:00+03	61900.00
008182	2017-07-14 02:09:00+03	31600.00
008191	2017-08-08 11:38:00+03	73300.00
0081C5	2017-07-13 04:37:00+03	27700.00
0081CA	2017-08-12 15:44:00+03	114700.00
008205	2017-08-15 07:56:00+03	36200.00
00823B	2017-07-15 21:09:00+03	26200.00
008279	2017-07-03 14:10:00+03	52900.00
0082C6	2017-07-12 17:56:00+03	76700.00
0082F8	2017-07-29 22:05:00+03	61800.00
00840C	2017-07-28 05:38:00+03	70700.00
008417	2017-07-03 05:32:00+03	55800.00
008441	2017-08-03 02:04:00+03	14000.00
008461	2017-07-01 09:58:00+03	52000.00
008462	2017-07-12 15:53:00+03	23200.00
00849B	2017-08-04 00:28:00+03	89700.00
0084AB	2017-07-24 18:01:00+03	59900.00
0084D4	2017-07-20 12:17:00+03	425500.00
008577	2017-07-26 21:06:00+03	40300.00
0085C7	2017-07-05 01:51:00+03	46400.00
0085DF	2017-07-05 06:24:00+03	168000.00
0085F1	2017-07-20 02:18:00+03	48700.00
0085F5	2017-07-04 02:55:00+03	36200.00
00860F	2017-07-28 14:16:00+03	31600.00
008612	2017-08-03 22:07:00+03	30400.00
0086F0	2017-08-10 11:49:00+03	265200.00
008712	2017-07-23 20:34:00+03	51600.00
008738	2017-07-15 14:53:00+03	23200.00
00878B	2017-07-26 18:10:00+03	64400.00
008791	2017-07-26 07:27:00+03	6000.00
0087C1	2017-06-26 13:43:00+03	28000.00
0087F3	2017-07-28 09:29:00+03	58400.00
0087F5	2017-08-04 12:44:00+03	122700.00
008805	2017-07-20 18:53:00+03	38800.00
008822	2017-06-29 21:33:00+03	64500.00
00885A	2017-08-01 07:21:00+03	55800.00
0088C7	2017-07-03 04:29:00+03	16400.00
008927	2017-08-12 16:55:00+03	117600.00
00893C	2017-07-08 00:18:00+03	32800.00
008978	2017-07-15 08:56:00+03	66600.00
0089F8	2017-07-16 19:47:00+03	257600.00
008A31	2017-06-28 12:12:00+03	56000.00
008A35	2017-08-15 08:55:00+03	38200.00
008A75	2017-08-06 12:43:00+03	90300.00
008A80	2017-08-11 05:55:00+03	90200.00
008B02	2017-07-16 16:54:00+03	52000.00
008B2D	2017-07-16 16:11:00+03	14000.00
008B45	2017-08-06 07:05:00+03	92800.00
008B47	2017-07-11 17:50:00+03	26000.00
008B53	2017-07-28 15:27:00+03	277800.00
008B8B	2017-08-07 14:42:00+03	266400.00
008BBC	2017-07-22 04:09:00+03	139300.00
008C12	2017-07-02 04:51:00+03	59200.00
008C21	2017-07-02 14:05:00+03	116400.00
008C35	2017-08-13 18:16:00+03	14000.00
008CAC	2017-07-07 04:10:00+03	75300.00
008CB6	2017-07-10 04:10:00+03	39500.00
008D61	2017-07-10 20:38:00+03	115600.00
008D90	2017-08-04 20:02:00+03	122800.00
008DB1	2017-07-27 05:48:00+03	88600.00
008DC5	2017-07-10 15:42:00+03	32700.00
008E4E	2017-07-03 01:38:00+03	531300.00
008E62	2017-07-03 14:36:00+03	13400.00
008ED3	2017-07-13 08:09:00+03	46400.00
008F21	2017-08-03 06:32:00+03	40600.00
008F67	2017-08-07 12:15:00+03	52800.00
008FD0	2017-08-11 10:33:00+03	52900.00
008FD2	2017-07-14 04:22:00+03	37900.00
00903C	2017-07-04 11:38:00+03	22100.00
009063	2017-07-09 23:33:00+03	542300.00
009091	2017-07-16 11:48:00+03	46400.00
009099	2017-07-17 14:09:00+03	106200.00
0090A5	2017-07-11 05:14:00+03	167200.00
0090C4	2017-07-30 11:21:00+03	104800.00
0090CF	2017-07-22 04:33:00+03	86300.00
0090DA	2017-06-29 01:11:00+03	125400.00
0090FE	2017-07-14 09:34:00+03	25600.00
0091C5	2017-07-29 19:49:00+03	46000.00
009228	2017-08-02 00:12:00+03	6000.00
00923E	2017-07-28 17:57:00+03	48800.00
0092B6	2017-07-15 08:44:00+03	36200.00
00934F	2017-07-23 06:18:00+03	38800.00
00937F	2017-07-02 06:24:00+03	95600.00
0093B2	2017-07-29 03:16:00+03	20800.00
0093C5	2017-08-14 00:38:00+03	65900.00
0093E2	2017-07-31 02:58:00+03	32800.00
009431	2017-07-30 03:35:00+03	23200.00
009434	2017-08-13 11:42:00+03	41900.00
0094C4	2017-08-06 14:37:00+03	372500.00
00955F	2017-07-31 20:41:00+03	63200.00
0095A3	2017-08-12 01:01:00+03	132800.00
009612	2017-07-18 00:05:00+03	40800.00
009624	2017-07-17 23:09:00+03	131000.00
00967F	2017-07-24 22:36:00+03	123000.00
0096E3	2017-07-05 19:47:00+03	174900.00
009709	2017-07-25 05:51:00+03	155600.00
00970E	2017-08-15 07:59:00+03	395100.00
00970F	2017-07-15 18:16:00+03	56000.00
00973C	2017-08-06 10:16:00+03	147700.00
00975D	2017-08-01 13:30:00+03	58700.00
0097BD	2017-07-08 22:07:00+03	49500.00
009814	2017-07-21 05:45:00+03	139400.00
00982B	2017-07-15 10:45:00+03	146400.00
009852	2017-08-06 13:54:00+03	76600.00
009884	2017-07-06 06:26:00+03	44600.00
0098A2	2017-07-28 03:13:00+03	12700.00
0098BD	2017-08-13 11:26:00+03	32700.00
009954	2017-08-04 22:06:00+03	56000.00
0099A2	2017-07-18 08:02:00+03	26200.00
0099A9	2017-07-18 05:34:00+03	28800.00
009A5B	2017-08-05 16:21:00+03	35200.00
009A73	2017-07-25 09:29:00+03	139400.00
009AAD	2017-08-12 16:52:00+03	54500.00
009AB8	2017-07-23 12:05:00+03	75300.00
009AE0	2017-08-10 16:36:00+03	29400.00
009AE2	2017-07-14 04:49:00+03	61700.00
009B09	2017-07-08 22:54:00+03	135200.00
009BC1	2017-08-10 12:13:00+03	364600.00
009BEA	2017-08-12 15:42:00+03	52400.00
009C62	2017-07-02 11:39:00+03	74300.00
009C73	2017-08-08 22:03:00+03	24400.00
009C80	2017-07-11 08:01:00+03	79200.00
009C82	2017-07-29 03:45:00+03	6000.00
009CF6	2017-08-07 23:50:00+03	92000.00
009D9C	2017-07-02 02:44:00+03	22200.00
009DD6	2017-07-09 11:36:00+03	81600.00
009E4D	2017-06-29 19:44:00+03	117600.00
009EF9	2017-07-14 19:32:00+03	89100.00
009EFC	2017-07-11 05:29:00+03	28800.00
009FC6	2017-07-07 19:15:00+03	210000.00
009FD3	2017-08-14 07:15:00+03	10800.00
00A027	2017-07-07 19:53:00+03	64400.00
00A036	2017-07-14 17:14:00+03	64900.00
00A099	2017-08-10 15:26:00+03	39300.00
00A11C	2017-07-24 21:18:00+03	132800.00
00A164	2017-08-13 16:21:00+03	46300.00
00A165	2017-07-16 02:38:00+03	16400.00
00A179	2017-07-18 08:30:00+03	36200.00
00A210	2017-08-10 08:10:00+03	234200.00
00A251	2017-08-06 01:41:00+03	52700.00
00A27A	2017-07-13 20:39:00+03	23200.00
00A296	2017-07-04 19:03:00+03	111700.00
00A297	2017-07-25 04:25:00+03	24800.00
00A2B7	2017-07-11 23:58:00+03	265700.00
00A2B8	2017-07-06 10:23:00+03	40800.00
00A2BC	2017-08-02 02:40:00+03	66700.00
00A36E	2017-08-01 17:06:00+03	56000.00
00A39B	2017-06-30 19:00:00+03	99300.00
00A3C2	2017-08-04 08:20:00+03	80000.00
00A3E0	2017-07-12 08:45:00+03	49600.00
00A404	2017-07-11 09:35:00+03	96300.00
00A421	2017-07-29 02:21:00+03	67700.00
00A48B	2017-07-11 19:29:00+03	50000.00
00A48F	2017-07-01 17:40:00+03	62800.00
00A59D	2017-08-05 19:09:00+03	16400.00
00A5B1	2017-07-19 02:08:00+03	147100.00
00A614	2017-07-20 01:26:00+03	133200.00
00A672	2017-07-20 15:49:00+03	25600.00
00A676	2017-08-01 06:58:00+03	136200.00
00A69C	2017-08-08 16:15:00+03	137100.00
00A778	2017-08-09 06:48:00+03	99300.00
00A7BA	2017-07-29 01:22:00+03	130400.00
00A7CA	2017-08-08 12:05:00+03	64400.00
00A7FF	2017-07-13 16:38:00+03	23600.00
00A82C	2017-07-12 02:07:00+03	95600.00
00A85A	2017-07-25 14:49:00+03	303300.00
00A8C8	2017-07-30 00:03:00+03	31600.00
00A8F6	2017-07-09 20:31:00+03	90800.00
00A947	2017-07-21 01:32:00+03	24800.00
00A94E	2017-07-19 16:37:00+03	72300.00
00A95D	2017-08-07 01:33:00+03	369000.00
00A968	2017-07-15 04:15:00+03	50800.00
00A96B	2017-07-12 05:37:00+03	90100.00
00A970	2017-07-12 09:35:00+03	92600.00
00A9AF	2017-08-01 06:43:00+03	37900.00
00A9B6	2017-07-24 05:41:00+03	99200.00
00A9F5	2017-07-03 17:40:00+03	71100.00
00AAD8	2017-07-26 00:16:00+03	24600.00
00AB87	2017-07-21 09:05:00+03	258400.00
00ABC2	2017-08-07 17:31:00+03	46800.00
00ABE4	2017-07-06 21:28:00+03	76900.00
00ABE9	2017-07-16 11:42:00+03	67600.00
00AC32	2017-07-16 00:38:00+03	19600.00
00AC52	2017-07-19 03:27:00+03	15400.00
00AC6D	2017-07-06 23:01:00+03	58800.00
00AC94	2017-07-13 02:41:00+03	54500.00
00ACC1	2017-08-10 01:44:00+03	25200.00
00AD0A	2017-07-09 14:49:00+03	369000.00
00AD37	2017-07-13 19:12:00+03	47100.00
00AD72	2017-07-24 01:56:00+03	51300.00
00ADDF	2017-07-13 14:37:00+03	46400.00
00AE01	2017-07-20 05:02:00+03	18600.00
00AEA8	2017-07-30 00:16:00+03	40400.00
00AEE1	2017-08-12 22:27:00+03	81700.00
00AEE8	2017-08-14 08:14:00+03	110200.00
00AEFF	2017-07-30 04:39:00+03	36200.00
00AFED	2017-07-07 03:42:00+03	54500.00
00AFF6	2017-08-10 04:14:00+03	87800.00
00B094	2017-08-02 19:38:00+03	271100.00
00B09E	2017-07-03 15:35:00+03	66600.00
00B116	2017-08-12 06:31:00+03	58000.00
00B161	2017-07-23 22:05:00+03	33300.00
00B168	2017-07-08 01:05:00+03	7400.00
00B199	2017-07-26 14:21:00+03	59800.00
00B22C	2017-08-05 14:12:00+03	40000.00
00B241	2017-07-04 01:45:00+03	89600.00
00B2A0	2017-08-08 10:32:00+03	12000.00
00B2BC	2017-07-17 18:59:00+03	25900.00
00B2D0	2017-07-27 03:16:00+03	207200.00
00B2FC	2017-08-01 08:23:00+03	133100.00
00B2FD	2017-08-05 04:45:00+03	24400.00
00B31B	2017-08-15 13:06:00+03	46300.00
00B347	2017-08-13 11:01:00+03	6800.00
00B36C	2017-08-05 10:56:00+03	131600.00
00B3A3	2017-07-23 08:26:00+03	25600.00
00B3EA	2017-07-26 04:30:00+03	31400.00
00B407	2017-07-05 07:17:00+03	31000.00
00B44B	2017-07-23 04:22:00+03	114400.00
00B45B	2017-07-18 06:56:00+03	40800.00
00B49E	2017-07-12 18:58:00+03	9200.00
00B4B4	2017-07-22 16:29:00+03	21800.00
00B4BB	2017-07-16 09:38:00+03	265700.00
00B525	2017-07-07 22:45:00+03	187800.00
00B550	2017-07-17 15:33:00+03	8000.00
00B55B	2017-07-24 13:15:00+03	185300.00
00B5BC	2017-08-05 03:43:00+03	20400.00
00B61C	2017-07-15 21:10:00+03	79800.00
00B629	2017-07-09 18:40:00+03	14700.00
00B6FE	2017-07-16 05:35:00+03	28700.00
00B70C	2017-07-22 02:47:00+03	23200.00
00B74D	2017-07-28 19:46:00+03	58800.00
00B76F	2017-07-08 08:04:00+03	528000.00
00B798	2017-07-01 21:39:00+03	12400.00
00B7E6	2017-08-07 08:50:00+03	111600.00
00B811	2017-07-30 06:29:00+03	100000.00
00B8B9	2017-08-01 09:28:00+03	13400.00
00B920	2017-07-07 06:30:00+03	93900.00
00B99F	2017-07-10 05:16:00+03	126000.00
00B9A7	2017-07-11 21:35:00+03	26000.00
00B9BF	2017-08-02 00:22:00+03	179300.00
00BA65	2017-08-10 23:08:00+03	153300.00
00BAB4	2017-08-03 20:57:00+03	35800.00
00BACA	2017-07-26 22:35:00+03	30400.00
00BADF	2017-08-14 05:37:00+03	26700.00
00BAF7	2017-07-24 04:30:00+03	49400.00
00BB10	2017-07-03 08:56:00+03	38200.00
00BB3B	2017-07-21 14:13:00+03	57800.00
00BBC5	2017-07-05 07:11:00+03	50300.00
00BBCD	2017-08-05 02:06:00+03	75200.00
00BBF4	2017-07-24 07:27:00+03	21400.00
00BC4F	2017-07-28 15:30:00+03	33100.00
00BC7A	2017-07-27 09:44:00+03	111600.00
00BC84	2017-07-07 06:31:00+03	66600.00
00BC8A	2017-07-05 08:38:00+03	86500.00
00BCCA	2017-07-07 03:32:00+03	180000.00
00BCEC	2017-07-08 12:41:00+03	102100.00
00BDA8	2017-08-04 18:12:00+03	51600.00
00BDAD	2017-07-09 02:51:00+03	18000.00
00BDF1	2017-07-22 03:36:00+03	28800.00
00BDF3	2017-07-12 19:08:00+03	28800.00
00BE07	2017-07-12 23:32:00+03	115200.00
00BEEA	2017-07-28 09:57:00+03	92700.00
00BEEF	2017-07-04 21:18:00+03	258400.00
00BF0F	2017-07-21 05:39:00+03	32700.00
00BF4F	2017-07-01 05:33:00+03	113200.00
00BF87	2017-07-17 01:27:00+03	24400.00
00C024	2017-07-24 10:26:00+03	119500.00
00C04F	2017-07-04 10:05:00+03	35800.00
00C07E	2017-07-06 08:10:00+03	24400.00
00C097	2017-08-09 01:38:00+03	55800.00
00C0B6	2017-08-04 03:05:00+03	399600.00
00C11A	2017-07-03 08:19:00+03	369000.00
00C143	2017-08-05 06:17:00+03	25400.00
00C191	2017-07-06 15:11:00+03	39300.00
00C199	2017-07-18 16:32:00+03	14000.00
00C213	2017-08-03 19:22:00+03	94900.00
00C23F	2017-08-12 04:05:00+03	36000.00
00C242	2017-07-03 14:37:00+03	24700.00
00C252	2017-07-21 05:38:00+03	36200.00
00C278	2017-08-14 12:06:00+03	91600.00
00C2A5	2017-07-04 06:37:00+03	46200.00
00C2E1	2017-08-03 01:20:00+03	142400.00
00C34C	2017-07-27 21:03:00+03	23600.00
00C367	2017-07-16 22:22:00+03	38600.00
00C387	2017-08-10 17:01:00+03	24400.00
00C3B3	2017-08-14 23:07:00+03	22200.00
00C418	2017-07-10 15:24:00+03	39200.00
00C45C	2017-07-11 05:23:00+03	13800.00
00C4CA	2017-08-13 11:24:00+03	52000.00
00C4FE	2017-07-12 03:47:00+03	167400.00
00C57C	2017-08-04 17:30:00+03	149700.00
00C64D	2017-07-23 21:26:00+03	32200.00
00C679	2017-07-26 23:58:00+03	131600.00
00C68E	2017-08-13 08:00:00+03	56000.00
00C6E6	2017-08-04 16:11:00+03	56600.00
00C6F2	2017-07-04 11:33:00+03	25800.00
00C727	2017-07-09 09:00:00+03	45200.00
00C72E	2017-07-09 01:58:00+03	26000.00
00C738	2017-07-28 07:58:00+03	56000.00
00C758	2017-07-09 05:32:00+03	30200.00
00C759	2017-07-17 06:09:00+03	51600.00
00C7B1	2017-08-03 17:30:00+03	73900.00
00C7D5	2017-08-01 06:11:00+03	23800.00
00C811	2017-07-15 07:42:00+03	52900.00
00C812	2017-07-02 16:33:00+03	16400.00
00C82D	2017-07-04 06:38:00+03	23200.00
00C8B6	2017-08-09 09:45:00+03	78300.00
00C8E8	2017-08-07 20:57:00+03	254900.00
00C98E	2017-07-11 08:47:00+03	71300.00
00C9B6	2017-07-19 15:31:00+03	14000.00
00CA37	2017-08-14 15:30:00+03	40800.00
00CA80	2017-07-18 17:30:00+03	50000.00
00CA8B	2017-08-06 15:11:00+03	85000.00
00CABF	2017-08-14 00:33:00+03	193600.00
00CAC2	2017-07-07 19:50:00+03	19000.00
00CAF0	2017-07-01 21:46:00+03	114800.00
00CAF5	2017-07-24 22:25:00+03	36200.00
00CB6A	2017-08-06 01:04:00+03	283100.00
00CBA0	2017-08-14 13:37:00+03	13600.00
00CBE1	2017-07-07 11:54:00+03	76900.00
00CBE2	2017-07-28 07:50:00+03	135400.00
00CCAD	2017-08-08 01:38:00+03	11300.00
00CCBC	2017-07-15 03:06:00+03	64200.00
00CCC6	2017-08-10 07:43:00+03	155600.00
00CCC9	2017-07-04 18:15:00+03	59600.00
00CD91	2017-08-14 21:57:00+03	63600.00
00CD94	2017-07-30 23:15:00+03	186900.00
00CDD3	2017-08-07 02:43:00+03	49600.00
00CDD6	2017-07-09 10:00:00+03	40400.00
00CDFE	2017-08-06 13:43:00+03	129200.00
00CE1C	2017-07-16 09:22:00+03	6300.00
00CE91	2017-07-27 21:59:00+03	27300.00
00CEA1	2017-08-04 06:14:00+03	112200.00
00CEAE	2017-07-05 06:11:00+03	70700.00
00CEB5	2017-07-20 18:22:00+03	109800.00
00CF04	2017-08-14 04:14:00+03	13000.00
00CF0D	2017-08-09 17:11:00+03	172400.00
00CF2F	2017-06-29 10:21:00+03	112600.00
00CF38	2017-07-01 04:23:00+03	26700.00
00D00E	2017-07-06 13:36:00+03	58800.00
00D03D	2017-08-11 01:40:00+03	40000.00
00D07B	2017-07-16 18:57:00+03	25400.00
00D09C	2017-08-11 03:59:00+03	23600.00
00D0A0	2017-08-02 08:57:00+03	594500.00
00D0D4	2017-07-13 04:46:00+03	19600.00
00D138	2017-08-02 01:54:00+03	70500.00
00D1B1	2017-07-16 00:07:00+03	116400.00
00D1D2	2017-07-07 08:32:00+03	16400.00
00D1F7	2017-08-05 22:41:00+03	31600.00
00D1F9	2017-08-12 14:57:00+03	145000.00
00D240	2017-07-11 19:58:00+03	99600.00
00D2C8	2017-07-18 16:17:00+03	131600.00
00D2FF	2017-07-31 00:15:00+03	75600.00
00D309	2017-08-11 13:33:00+03	143600.00
00D367	2017-08-06 00:05:00+03	6700.00
00D380	2017-07-09 09:07:00+03	73600.00
00D396	2017-08-02 15:16:00+03	65900.00
00D413	2017-07-10 09:12:00+03	22000.00
00D4A6	2017-08-15 17:11:00+03	54000.00
00D4A9	2017-08-14 02:48:00+03	54800.00
00D514	2017-07-27 10:16:00+03	37200.00
00D573	2017-07-15 18:20:00+03	45200.00
00D59D	2017-08-14 23:48:00+03	69100.00
00D5AD	2017-07-10 11:28:00+03	6300.00
00D5B8	2017-07-20 09:54:00+03	37600.00
00D5DA	2017-07-03 22:48:00+03	103100.00
00D643	2017-08-13 10:15:00+03	16000.00
00D64E	2017-07-22 14:35:00+03	51300.00
00D697	2017-07-29 13:50:00+03	114600.00
00D75A	2017-07-16 23:21:00+03	20200.00
00D766	2017-07-31 14:26:00+03	36800.00
00D77C	2017-08-13 09:37:00+03	91500.00
00D7EE	2017-08-15 13:22:00+03	33800.00
00D837	2017-07-29 05:38:00+03	79900.00
00D85D	2017-07-15 04:47:00+03	81200.00
00D882	2017-07-12 03:59:00+03	59800.00
00D8D3	2017-07-02 12:04:00+03	67600.00
00D916	2017-07-30 16:41:00+03	28800.00
00D92E	2017-08-13 04:19:00+03	46200.00
00D96A	2017-07-13 22:13:00+03	45100.00
00D984	2017-08-03 02:25:00+03	28000.00
00D9EF	2017-07-29 08:01:00+03	65100.00
00DA58	2017-08-10 19:15:00+03	40800.00
00DA63	2017-08-01 10:19:00+03	12600.00
00DAE4	2017-08-06 12:17:00+03	24000.00
00DAED	2017-08-04 12:21:00+03	67600.00
00DB59	2017-07-31 16:29:00+03	56600.00
00DBC4	2017-08-03 08:09:00+03	12000.00
00DC18	2017-07-14 19:04:00+03	133200.00
00DC51	2017-07-26 12:29:00+03	387300.00
00DC56	2017-07-14 04:48:00+03	80900.00
00DC6F	2017-08-15 12:40:00+03	54500.00
00DC87	2017-08-14 14:44:00+03	42800.00
00DC94	2017-08-08 14:22:00+03	179300.00
00DCB8	2017-08-14 13:25:00+03	54500.00
00DCE0	2017-07-10 10:05:00+03	325500.00
00DD00	2017-08-15 12:16:00+03	26800.00
00DD63	2017-06-30 14:16:00+03	100600.00
00DD74	2017-08-03 10:04:00+03	58000.00
00DD78	2017-07-17 05:44:00+03	193700.00
00DDDA	2017-08-11 23:44:00+03	67100.00
00DDEA	2017-08-09 09:19:00+03	22000.00
00DDEE	2017-07-24 20:17:00+03	20200.00
00DE40	2017-08-05 14:35:00+03	97000.00
00DE63	2017-07-30 21:28:00+03	68900.00
00DE87	2017-07-25 06:16:00+03	62700.00
00DEF1	2017-07-30 20:21:00+03	21800.00
00DF13	2017-07-03 06:28:00+03	66600.00
00DF7A	2017-07-29 05:35:00+03	16400.00
00E028	2017-08-13 11:49:00+03	12800.00
00E059	2017-08-06 11:45:00+03	258400.00
00E0B1	2017-07-28 22:45:00+03	118200.00
00E0B4	2017-07-26 19:32:00+03	46000.00
00E0BE	2017-07-04 07:42:00+03	76800.00
00E11A	2017-07-07 22:19:00+03	285100.00
00E132	2017-07-25 21:29:00+03	201200.00
00E195	2017-07-24 03:19:00+03	30400.00
00E198	2017-07-29 10:58:00+03	135400.00
00E22A	2017-07-17 12:20:00+03	113200.00
00E22F	2017-07-13 15:38:00+03	93400.00
00E24D	2017-07-25 16:13:00+03	79900.00
00E28A	2017-07-16 22:29:00+03	40000.00
00E2A4	2017-06-30 09:04:00+03	532800.00
00E303	2017-08-15 06:18:00+03	87200.00
00E313	2017-07-29 19:04:00+03	49400.00
00E3A1	2017-08-14 05:15:00+03	58400.00
00E3D6	2017-07-30 01:22:00+03	43900.00
00E3E5	2017-07-22 21:04:00+03	369000.00
00E404	2017-07-29 04:44:00+03	26200.00
00E411	2017-08-14 18:08:00+03	160100.00
00E413	2017-08-14 23:04:00+03	27200.00
00E444	2017-07-04 07:12:00+03	145500.00
00E49F	2017-08-02 16:56:00+03	60400.00
00E4FD	2017-07-08 19:33:00+03	118900.00
00E551	2017-08-03 13:53:00+03	120600.00
00E566	2017-07-16 21:28:00+03	91500.00
00E56B	2017-08-12 10:32:00+03	124200.00
00E576	2017-07-14 04:33:00+03	135600.00
00E592	2017-08-07 04:13:00+03	8600.00
00E597	2017-08-08 11:38:00+03	68600.00
00E5DC	2017-07-31 22:18:00+03	58200.00
00E5E8	2017-07-10 05:06:00+03	13400.00
00E603	2017-08-11 11:42:00+03	6000.00
00E648	2017-07-11 19:30:00+03	92800.00
00E6CC	2017-07-14 19:06:00+03	73300.00
00E6D8	2017-07-17 15:08:00+03	44000.00
00E71B	2017-08-01 22:20:00+03	75600.00
00E725	2017-07-10 07:47:00+03	139400.00
00E730	2017-08-01 11:54:00+03	31400.00
00E743	2017-08-12 15:22:00+03	260900.00
00E758	2017-07-04 01:00:00+03	62800.00
00E821	2017-07-19 05:23:00+03	147700.00
00E84F	2017-07-01 19:18:00+03	58700.00
00E867	2017-07-18 03:43:00+03	138100.00
00E885	2017-07-24 09:20:00+03	232500.00
00E8AA	2017-07-17 10:56:00+03	42800.00
00E8BF	2017-07-13 02:01:00+03	58800.00
00E8D6	2017-07-26 17:30:00+03	44800.00
00E9AB	2017-07-01 10:12:00+03	7200.00
00E9D2	2017-07-08 08:51:00+03	101200.00
00E9D6	2017-07-30 13:10:00+03	32200.00
00E9DC	2017-08-03 05:09:00+03	38400.00
00EA00	2017-07-19 03:34:00+03	75200.00
00EAC4	2017-07-30 23:15:00+03	23400.00
00EAD0	2017-07-29 21:52:00+03	103800.00
00EB0D	2017-07-02 18:06:00+03	23200.00
00EB47	2017-07-18 03:33:00+03	246000.00
00EB66	2017-07-22 05:40:00+03	265700.00
00EBC0	2017-08-12 11:55:00+03	125200.00
00EC31	2017-07-14 09:26:00+03	248500.00
00EC69	2017-07-16 22:35:00+03	28000.00
00EC8D	2017-08-10 05:29:00+03	102700.00
00EC9F	2017-07-10 06:09:00+03	91500.00
00ECAB	2017-07-30 22:16:00+03	75300.00
00ED25	2017-08-01 21:17:00+03	24400.00
00ED3C	2017-07-02 11:51:00+03	43400.00
00ED7A	2017-08-09 17:50:00+03	26000.00
00EDF4	2017-08-08 18:33:00+03	20200.00
00EE1A	2017-07-28 08:22:00+03	62600.00
00EE44	2017-07-07 17:07:00+03	269700.00
00EE52	2017-08-14 00:11:00+03	42800.00
00EE6E	2017-08-15 12:28:00+03	336200.00
00EE9F	2017-07-30 22:54:00+03	26000.00
00EF4D	2017-07-26 10:05:00+03	40400.00
00EF5F	2017-08-01 04:39:00+03	75600.00
00EF72	2017-07-07 23:02:00+03	369000.00
00EF8A	2017-07-26 12:00:00+03	112000.00
00EF8D	2017-07-09 17:08:00+03	23200.00
00EFCC	2017-07-08 18:12:00+03	30000.00
00EFE2	2017-08-13 19:25:00+03	138500.00
00EFFB	2017-07-11 08:28:00+03	50800.00
00F023	2017-07-13 02:05:00+03	59800.00
00F03D	2017-06-29 22:12:00+03	19600.00
00F041	2017-07-25 00:53:00+03	99300.00
00F054	2017-08-14 07:42:00+03	129200.00
00F07F	2017-07-17 14:54:00+03	61800.00
00F088	2017-07-05 06:41:00+03	64300.00
00F159	2017-07-08 07:05:00+03	87600.00
00F172	2017-08-09 04:20:00+03	116100.00
00F1CF	2017-07-05 21:29:00+03	24400.00
00F1EF	2017-07-27 15:01:00+03	59000.00
00F20D	2017-07-23 18:19:00+03	81300.00
00F232	2017-07-07 13:25:00+03	62600.00
00F256	2017-07-18 08:35:00+03	73900.00
00F26A	2017-07-06 08:07:00+03	26700.00
00F26D	2017-07-12 09:27:00+03	47500.00
00F2BF	2017-08-07 14:09:00+03	56000.00
00F2E5	2017-08-11 12:31:00+03	26200.00
00F2F1	2017-08-02 04:32:00+03	23400.00
00F31C	2017-07-26 23:03:00+03	84100.00
00F356	2017-08-02 01:18:00+03	62100.00
00F3B9	2017-08-14 07:51:00+03	105000.00
00F3D2	2017-08-03 04:04:00+03	123000.00
00F4EF	2017-07-01 06:01:00+03	28000.00
00F515	2017-06-30 06:44:00+03	20000.00
00F519	2017-07-21 07:33:00+03	135400.00
00F553	2017-07-01 15:33:00+03	56000.00
00F555	2017-07-23 17:00:00+03	61900.00
00F598	2017-07-31 17:54:00+03	177200.00
00F618	2017-07-09 23:36:00+03	99600.00
00F691	2017-08-05 14:02:00+03	56600.00
00F6A2	2017-07-31 00:01:00+03	61800.00
00F703	2017-07-02 22:45:00+03	12400.00
00F716	2017-08-13 04:05:00+03	156000.00
00F73E	2017-08-12 00:46:00+03	531400.00
00F779	2017-08-10 04:15:00+03	47100.00
00F7B1	2017-06-29 14:04:00+03	18600.00
00F7ED	2017-08-12 06:50:00+03	31400.00
00F82A	2017-08-09 19:29:00+03	85000.00
00F915	2017-08-06 08:50:00+03	43800.00
00F97B	2017-07-15 14:48:00+03	28000.00
00F98C	2017-07-17 02:17:00+03	113200.00
00F9DC	2017-08-10 19:21:00+03	14400.00
00F9FB	2017-07-11 18:20:00+03	104800.00
00FA5A	2017-08-10 07:31:00+03	26000.00
00FA77	2017-07-23 01:21:00+03	19800.00
00FAD5	2017-07-07 13:26:00+03	32700.00
00FB45	2017-07-16 09:15:00+03	94700.00
00FB54	2017-08-05 07:42:00+03	68100.00
00FB6B	2017-08-02 06:32:00+03	289800.00
00FB9A	2017-08-14 21:33:00+03	75300.00
00FBC7	2017-08-08 16:05:00+03	35200.00
00FC3D	2017-07-28 06:52:00+03	56600.00
00FC75	2017-07-21 17:37:00+03	54300.00
00FCA9	2017-07-25 05:08:00+03	40400.00
00FCC9	2017-07-14 08:19:00+03	28000.00
00FCD0	2017-07-07 08:02:00+03	25100.00
00FCE4	2017-07-04 01:03:00+03	91200.00
00FD0A	2017-07-31 20:18:00+03	24500.00
00FD6A	2017-07-23 09:32:00+03	167400.00
00FD79	2017-08-07 22:00:00+03	79900.00
00FE5B	2017-07-31 00:22:00+03	207200.00
00FEC5	2017-07-05 02:51:00+03	47600.00
00FEEB	2017-07-11 11:58:00+03	8200.00
00FF90	2017-07-08 18:17:00+03	6000.00
00FF9D	2017-07-12 00:35:00+03	167400.00
00FFAD	2017-07-11 13:27:00+03	55800.00
00FFD1	2017-08-01 11:27:00+03	133200.00
00FFDD	2017-07-24 13:06:00+03	69600.00
010016	2017-07-01 13:16:00+03	25000.00
010084	2017-08-09 23:15:00+03	73300.00
0100D1	2017-07-05 00:01:00+03	131600.00
0100FE	2017-08-01 11:10:00+03	25200.00
010140	2017-08-10 20:35:00+03	190100.00
010153	2017-07-13 00:49:00+03	200000.00
0101A9	2017-08-11 18:09:00+03	191400.00
0101BD	2017-07-28 19:07:00+03	125400.00
0101DE	2017-07-27 23:31:00+03	64700.00
0101FF	2017-07-19 18:43:00+03	134200.00
010203	2017-07-16 01:01:00+03	56600.00
01021B	2017-08-12 08:43:00+03	187600.00
01022D	2017-07-11 00:42:00+03	26800.00
01025C	2017-07-19 07:15:00+03	108600.00
0102A4	2017-07-28 23:46:00+03	15000.00
0102D8	2017-08-09 19:06:00+03	62600.00
010325	2017-07-01 09:34:00+03	33100.00
0103AD	2017-07-03 23:21:00+03	10600.00
0103BE	2017-07-17 22:42:00+03	32800.00
0103D8	2017-08-07 02:45:00+03	21400.00
0103F0	2017-08-03 03:21:00+03	24400.00
01041F	2017-07-24 14:17:00+03	103200.00
010457	2017-07-03 22:51:00+03	116500.00
010477	2017-07-05 11:52:00+03	81800.00
0104AD	2017-07-22 20:35:00+03	26000.00
0104B1	2017-07-15 07:00:00+03	85000.00
0104BE	2017-07-07 03:28:00+03	84500.00
0104C7	2017-08-13 02:04:00+03	26000.00
0104D0	2017-07-02 15:31:00+03	103200.00
0104F5	2017-08-01 20:33:00+03	96200.00
010513	2017-07-05 11:32:00+03	16400.00
010551	2017-07-21 01:13:00+03	51600.00
010562	2017-07-11 20:15:00+03	7800.00
01058F	2017-08-07 09:50:00+03	58200.00
0105FA	2017-08-15 16:37:00+03	81600.00
0106C5	2017-07-11 00:26:00+03	153000.00
0106D9	2017-07-18 03:32:00+03	168000.00
0106F4	2017-07-31 10:20:00+03	254900.00
010719	2017-07-21 11:30:00+03	532800.00
01075F	2017-07-12 10:55:00+03	70100.00
010798	2017-07-12 04:27:00+03	111600.00
0107DE	2017-07-24 23:53:00+03	120900.00
0107FD	2017-08-06 20:49:00+03	12600.00
010885	2017-08-14 10:42:00+03	14800.00
010905	2017-08-13 01:17:00+03	300700.00
01090C	2017-07-12 03:10:00+03	57800.00
010925	2017-07-18 14:29:00+03	81300.00
010937	2017-07-12 13:09:00+03	111600.00
01093F	2017-07-11 03:51:00+03	56000.00
01096D	2017-08-10 00:33:00+03	75300.00
010973	2017-07-04 23:59:00+03	39500.00
010986	2017-08-10 19:32:00+03	94000.00
010998	2017-07-20 23:46:00+03	178800.00
0109C2	2017-07-20 07:42:00+03	66600.00
010A40	2017-07-14 01:48:00+03	40000.00
010A46	2017-07-27 03:22:00+03	48900.00
010A78	2017-07-30 08:53:00+03	119500.00
010A87	2017-07-21 17:21:00+03	13400.00
010B25	2017-08-14 05:29:00+03	35200.00
010B76	2017-07-21 17:39:00+03	88400.00
010BD3	2017-07-07 15:28:00+03	105600.00
010C01	2017-07-11 11:46:00+03	55800.00
010C35	2017-07-11 10:22:00+03	46400.00
010C37	2017-08-03 20:05:00+03	56000.00
010C55	2017-07-02 18:26:00+03	57800.00
010C5C	2017-08-06 18:22:00+03	40600.00
010C66	2017-07-28 23:03:00+03	59200.00
010CA7	2017-07-31 09:22:00+03	284400.00
010CE0	2017-07-09 10:04:00+03	56000.00
010CF4	2017-07-12 18:25:00+03	38000.00
010D69	2017-08-15 02:09:00+03	279000.00
010DBE	2017-08-06 18:33:00+03	103100.00
010DCB	2017-07-14 14:43:00+03	113300.00
010DF1	2017-08-10 12:30:00+03	296400.00
010E06	2017-07-17 12:26:00+03	26000.00
010E0E	2017-07-04 22:28:00+03	12600.00
010E6F	2017-07-07 10:39:00+03	30000.00
010E96	2017-07-09 16:45:00+03	52000.00
010F0A	2017-08-03 18:07:00+03	70700.00
010FA5	2017-07-12 10:02:00+03	50200.00
010FD3	2017-07-23 23:16:00+03	24400.00
01100A	2017-08-03 12:23:00+03	37700.00
01100E	2017-07-14 07:56:00+03	14400.00
011056	2017-07-17 18:18:00+03	62600.00
011078	2017-07-28 16:25:00+03	88900.00
01107F	2017-08-04 13:10:00+03	31200.00
011105	2017-07-12 06:43:00+03	26000.00
01111A	2017-08-15 15:29:00+03	242900.00
01114C	2017-07-06 02:27:00+03	12600.00
011179	2017-07-11 10:43:00+03	68800.00
0111B8	2017-07-19 09:09:00+03	122000.00
011203	2017-07-21 05:05:00+03	79600.00
0112A0	2017-07-23 12:06:00+03	47200.00
0112FF	2017-07-12 13:21:00+03	44500.00
011315	2017-07-24 14:05:00+03	100600.00
01132E	2017-07-16 18:53:00+03	26000.00
011352	2017-07-10 14:41:00+03	127300.00
011400	2017-07-29 21:01:00+03	293400.00
011485	2017-07-20 02:02:00+03	43200.00
0114CF	2017-08-12 10:56:00+03	17600.00
011592	2017-07-17 13:48:00+03	85000.00
0115C7	2017-07-15 16:33:00+03	92900.00
0115D5	2017-07-27 12:54:00+03	55800.00
011603	2017-07-10 11:44:00+03	83000.00
01164E	2017-08-10 02:54:00+03	78500.00
011664	2017-08-12 01:25:00+03	222000.00
01166A	2017-07-14 15:13:00+03	75300.00
011776	2017-07-23 22:10:00+03	22000.00
01177B	2017-08-08 13:31:00+03	135000.00
01177C	2017-08-01 13:38:00+03	56000.00
011793	2017-08-13 03:55:00+03	58800.00
011799	2017-07-13 16:31:00+03	23200.00
0117E7	2017-08-04 15:06:00+03	28000.00
0117F5	2017-08-07 06:17:00+03	124100.00
011854	2017-08-03 10:19:00+03	25000.00
011877	2017-07-23 03:13:00+03	136600.00
0118A6	2017-07-07 12:08:00+03	43000.00
0118A7	2017-07-26 23:06:00+03	21400.00
011948	2017-07-08 18:47:00+03	70100.00
011991	2017-07-07 17:20:00+03	96800.00
0119E9	2017-07-04 18:05:00+03	34000.00
011A1D	2017-07-07 09:14:00+03	18000.00
011A5E	2017-07-11 07:44:00+03	28000.00
011AB0	2017-08-02 20:56:00+03	25600.00
011B65	2017-07-21 04:15:00+03	100200.00
011B7C	2017-08-14 19:33:00+03	83200.00
011B81	2017-07-27 15:08:00+03	54600.00
011BB0	2017-07-10 07:15:00+03	46400.00
011BC6	2017-08-14 18:35:00+03	21800.00
011C0F	2017-07-01 04:41:00+03	27700.00
011DBD	2017-07-12 17:52:00+03	148200.00
011DD3	2017-07-26 02:06:00+03	24400.00
011E40	2017-07-09 10:24:00+03	115900.00
011EFB	2017-07-02 03:28:00+03	8400.00
011F0B	2017-07-16 20:02:00+03	145100.00
011F4A	2017-07-03 21:04:00+03	23200.00
011F80	2017-08-13 11:00:00+03	43900.00
011F96	2017-08-05 13:45:00+03	265700.00
012066	2017-08-13 16:45:00+03	138000.00
01206A	2017-06-28 12:44:00+03	117600.00
012076	2017-07-07 11:56:00+03	216600.00
0120B8	2017-07-08 13:57:00+03	23200.00
0120F7	2017-08-07 09:47:00+03	46400.00
012190	2017-07-19 03:55:00+03	85600.00
0121C7	2017-07-08 11:36:00+03	47600.00
0121E4	2017-07-20 06:42:00+03	53600.00
0121F0	2017-07-15 13:16:00+03	354400.00
012205	2017-07-14 20:56:00+03	24400.00
012213	2017-07-31 13:16:00+03	59900.00
012237	2017-07-22 17:49:00+03	112000.00
012258	2017-08-03 11:24:00+03	11600.00
012278	2017-07-26 11:26:00+03	65900.00
012290	2017-07-06 17:38:00+03	86500.00
0122F6	2017-07-08 02:40:00+03	88800.00
012303	2017-07-08 19:05:00+03	27200.00
012382	2017-07-01 18:08:00+03	46400.00
012430	2017-07-04 16:55:00+03	260700.00
012466	2017-08-13 04:38:00+03	22000.00
01247F	2017-07-30 18:18:00+03	44800.00
0124A4	2017-07-10 15:18:00+03	50600.00
0124D5	2017-07-26 17:06:00+03	30100.00
0124F1	2017-08-05 02:54:00+03	57800.00
012532	2017-08-04 21:33:00+03	56000.00
0125FD	2017-07-03 10:18:00+03	98300.00
012614	2017-07-31 13:04:00+03	19300.00
01262C	2017-07-27 17:32:00+03	140400.00
012641	2017-08-06 23:14:00+03	89600.00
01267F	2017-07-05 08:39:00+03	40800.00
012680	2017-08-10 14:43:00+03	23200.00
01272A	2017-07-06 22:23:00+03	40000.00
01273A	2017-07-07 12:45:00+03	55800.00
0127A1	2017-07-26 14:18:00+03	16400.00
0127AA	2017-07-09 06:45:00+03	56900.00
0127B2	2017-07-01 13:58:00+03	56000.00
0127E1	2017-06-29 20:02:00+03	73500.00
0127E5	2017-07-13 19:00:00+03	99700.00
012815	2017-08-11 23:27:00+03	70700.00
01285A	2017-07-14 23:45:00+03	193700.00
012902	2017-08-11 11:07:00+03	73300.00
0129CD	2017-07-05 14:34:00+03	158100.00
0129DF	2017-07-11 03:15:00+03	13700.00
012A18	2017-07-13 06:47:00+03	62700.00
012A2E	2017-08-02 12:34:00+03	67600.00
012A78	2017-07-23 07:10:00+03	13600.00
012A84	2017-07-06 08:35:00+03	70700.00
012AA8	2017-07-05 12:27:00+03	42800.00
012AC6	2017-08-10 11:43:00+03	103200.00
012B12	2017-06-28 03:30:00+03	47200.00
012B92	2017-08-12 14:38:00+03	32700.00
012C24	2017-08-06 17:34:00+03	46400.00
012C31	2017-07-29 03:52:00+03	167400.00
012C57	2017-07-28 18:06:00+03	55800.00
012C85	2017-08-14 03:15:00+03	369000.00
012C94	2017-07-24 22:27:00+03	62800.00
012CA7	2017-07-28 20:44:00+03	29600.00
012CB4	2017-07-09 19:42:00+03	13000.00
012D00	2017-07-08 22:00:00+03	246000.00
012D3D	2017-07-30 12:53:00+03	73500.00
012E23	2017-07-13 16:32:00+03	538000.00
012E64	2017-07-13 17:38:00+03	56000.00
012EA0	2017-07-27 15:27:00+03	120100.00
012EB6	2017-06-26 11:25:00+03	86600.00
012EBE	2017-07-12 05:52:00+03	93900.00
012EE7	2017-08-14 02:22:00+03	87800.00
012EE9	2017-08-07 06:33:00+03	25800.00
012F9D	2017-07-10 20:09:00+03	172100.00
013044	2017-08-09 00:35:00+03	16400.00
01307C	2017-07-05 05:45:00+03	47100.00
013099	2017-07-08 22:12:00+03	36400.00
013104	2017-08-06 11:39:00+03	55800.00
013110	2017-08-14 13:25:00+03	32800.00
013124	2017-07-19 09:24:00+03	6000.00
013127	2017-07-08 07:22:00+03	14000.00
01313D	2017-07-01 21:36:00+03	40800.00
0131C8	2017-08-12 05:00:00+03	126700.00
0131D9	2017-07-19 01:35:00+03	75300.00
013294	2017-08-12 17:41:00+03	49800.00
0132C4	2017-08-07 05:10:00+03	39400.00
0132F3	2017-08-01 23:22:00+03	18300.00
013315	2017-08-15 14:56:00+03	58700.00
013333	2017-07-27 10:59:00+03	14400.00
013354	2017-08-04 20:17:00+03	52700.00
01337D	2017-07-11 01:38:00+03	59800.00
013420	2017-08-10 22:47:00+03	27200.00
013426	2017-08-03 18:57:00+03	102100.00
01342C	2017-07-26 19:28:00+03	100600.00
01348C	2017-07-27 08:17:00+03	143300.00
0134CC	2017-07-12 19:15:00+03	70500.00
0134D5	2017-07-05 00:42:00+03	62000.00
0134FB	2017-07-24 07:51:00+03	13400.00
01350B	2017-08-05 13:54:00+03	28800.00
013513	2017-07-24 05:57:00+03	52600.00
013514	2017-08-08 12:56:00+03	113700.00
013537	2017-07-19 20:12:00+03	236200.00
013575	2017-08-10 12:14:00+03	57500.00
0135C5	2017-07-01 13:40:00+03	51600.00
0135FD	2017-08-03 20:14:00+03	24200.00
013615	2017-07-15 12:20:00+03	30000.00
01365C	2017-07-20 10:01:00+03	118800.00
013662	2017-08-01 22:46:00+03	12800.00
01367A	2017-07-05 14:11:00+03	55800.00
013682	2017-08-04 20:28:00+03	203400.00
013689	2017-06-29 03:39:00+03	18300.00
0136D7	2017-07-01 22:01:00+03	68100.00
0136F4	2017-08-02 20:26:00+03	257600.00
01377C	2017-07-09 16:27:00+03	135400.00
013796	2017-06-28 18:44:00+03	103500.00
0137A3	2017-07-16 15:44:00+03	37900.00
0137AD	2017-07-14 00:21:00+03	59800.00
0137AE	2017-07-11 10:46:00+03	37600.00
0137B7	2017-07-31 12:28:00+03	57500.00
0137BA	2017-07-19 23:21:00+03	24400.00
013827	2017-07-26 21:07:00+03	23200.00
01390C	2017-08-04 00:46:00+03	137100.00
01394E	2017-08-11 19:50:00+03	142800.00
0139DD	2017-07-10 14:31:00+03	13400.00
013A10	2017-07-14 10:32:00+03	56100.00
013A37	2017-07-20 10:07:00+03	12000.00
013A3A	2017-07-29 16:33:00+03	56000.00
013A9C	2017-08-12 21:16:00+03	136500.00
013AA2	2017-07-14 18:56:00+03	22400.00
013AC1	2017-07-05 22:25:00+03	56900.00
013B57	2017-07-06 16:50:00+03	88900.00
013B66	2017-07-25 11:23:00+03	25400.00
013BC0	2017-07-17 13:24:00+03	31400.00
013BE6	2017-07-16 16:38:00+03	227700.00
013BF3	2017-08-09 19:09:00+03	47400.00
013C26	2017-07-17 12:13:00+03	369000.00
013C53	2017-08-02 02:07:00+03	168000.00
013CE6	2017-07-19 02:35:00+03	47100.00
013D07	2017-07-08 09:54:00+03	108600.00
013D45	2017-07-05 15:31:00+03	48500.00
013D5A	2017-07-28 11:17:00+03	122300.00
013D7F	2017-07-04 09:41:00+03	29200.00
013D87	2017-07-17 07:08:00+03	66000.00
013DD1	2017-07-15 15:34:00+03	29400.00
013DD8	2017-08-04 18:14:00+03	64800.00
013E2E	2017-07-29 14:56:00+03	133200.00
013E94	2017-07-07 00:54:00+03	306200.00
013E9F	2017-08-15 01:37:00+03	26200.00
013EAB	2017-07-20 19:41:00+03	31200.00
013EAE	2017-07-08 17:06:00+03	40000.00
013EF5	2017-07-05 07:27:00+03	135400.00
013EF9	2017-07-10 22:33:00+03	48800.00
013EFC	2017-07-08 02:59:00+03	94400.00
013F09	2017-07-31 13:51:00+03	83600.00
013F28	2017-08-04 14:00:00+03	39800.00
013F90	2017-07-03 13:30:00+03	46800.00
013F92	2017-07-14 17:21:00+03	135600.00
014056	2017-08-14 12:12:00+03	26000.00
01407A	2017-08-11 06:21:00+03	22000.00
014090	2017-08-03 04:16:00+03	64300.00
0140AD	2017-07-11 22:13:00+03	56000.00
01410D	2017-07-25 14:43:00+03	80000.00
01413E	2017-07-24 05:36:00+03	140200.00
014144	2017-07-21 06:03:00+03	83000.00
01414D	2017-07-29 04:54:00+03	12600.00
014242	2017-07-31 09:11:00+03	31600.00
01424B	2017-07-06 21:35:00+03	35200.00
01427C	2017-07-15 23:26:00+03	132800.00
0142DA	2017-07-30 05:55:00+03	39800.00
0142DF	2017-07-30 02:41:00+03	20600.00
01436E	2017-07-28 02:30:00+03	14400.00
014468	2017-07-07 20:39:00+03	41400.00
01447C	2017-07-01 22:47:00+03	42800.00
0144C7	2017-08-08 06:30:00+03	43200.00
014555	2017-07-04 00:36:00+03	72800.00
0145A0	2017-08-08 19:55:00+03	90400.00
014636	2017-07-25 17:52:00+03	47300.00
01471F	2017-08-10 02:44:00+03	12600.00
014778	2017-07-12 00:38:00+03	62600.00
014780	2017-07-29 14:48:00+03	14400.00
01480F	2017-07-28 18:11:00+03	236900.00
01482A	2017-07-17 17:37:00+03	47000.00
01482D	2017-07-08 14:13:00+03	26000.00
014831	2017-07-19 08:06:00+03	86400.00
014838	2017-08-01 20:35:00+03	118500.00
01485C	2017-08-03 19:12:00+03	113200.00
01485F	2017-07-27 16:02:00+03	64700.00
0148BE	2017-07-31 09:21:00+03	132800.00
01492B	2017-07-17 13:06:00+03	81600.00
014A87	2017-08-15 08:23:00+03	36200.00
014A9A	2017-08-04 13:39:00+03	67600.00
014AD6	2017-07-16 07:59:00+03	325500.00
014ADB	2017-08-02 09:44:00+03	349100.00
014C0A	2017-07-21 23:19:00+03	28800.00
014C33	2017-07-27 22:17:00+03	50000.00
014C42	2017-08-14 11:34:00+03	100600.00
014C47	2017-07-05 01:49:00+03	175200.00
014C8E	2017-07-26 19:51:00+03	6000.00
014CC4	2017-07-02 18:46:00+03	111600.00
014D1E	2017-07-30 13:08:00+03	24400.00
014D3B	2017-07-28 14:51:00+03	135600.00
014D49	2017-07-29 06:17:00+03	39100.00
014DBF	2017-08-11 09:02:00+03	65900.00
014DEE	2017-07-11 02:19:00+03	115900.00
014E39	2017-07-13 02:46:00+03	50000.00
014EC4	2017-07-12 01:06:00+03	40000.00
014EC8	2017-07-09 09:09:00+03	81600.00
014F32	2017-07-13 15:42:00+03	23600.00
014F67	2017-07-05 03:58:00+03	50200.00
014F78	2017-08-08 20:54:00+03	80800.00
014F9A	2017-08-05 19:08:00+03	31400.00
014FA3	2017-07-07 18:05:00+03	61200.00
014FCF	2017-08-07 14:23:00+03	66100.00
01510F	2017-07-25 06:00:00+03	27800.00
01515B	2017-08-03 11:51:00+03	18300.00
0151CA	2017-07-31 13:32:00+03	30200.00
01521C	2017-08-03 23:46:00+03	47400.00
015226	2017-08-14 23:47:00+03	65200.00
01524D	2017-08-06 06:16:00+03	67600.00
015271	2017-08-08 22:17:00+03	28800.00
01528B	2017-07-20 05:16:00+03	6800.00
0152B1	2017-07-26 20:30:00+03	160700.00
0152D3	2017-07-26 06:36:00+03	37100.00
0152FF	2017-07-03 14:10:00+03	62600.00
01532F	2017-07-07 16:10:00+03	47000.00
015331	2017-08-05 14:08:00+03	189200.00
01535E	2017-07-19 09:17:00+03	202800.00
01537F	2017-07-20 08:39:00+03	133700.00
0153F6	2017-08-12 12:30:00+03	28800.00
0153FD	2017-07-02 09:10:00+03	53400.00
015400	2017-08-09 08:13:00+03	23200.00
01541E	2017-07-31 05:12:00+03	35600.00
015430	2017-07-04 20:16:00+03	47100.00
0154E2	2017-08-07 10:14:00+03	119500.00
0154EF	2017-07-21 04:20:00+03	31400.00
01554C	2017-08-10 22:39:00+03	16800.00
015593	2017-07-11 13:45:00+03	73500.00
01559A	2017-06-29 16:44:00+03	39200.00
015645	2017-07-26 08:42:00+03	132800.00
015653	2017-08-05 13:56:00+03	19600.00
015684	2017-07-19 02:56:00+03	24400.00
0156A1	2017-07-22 02:45:00+03	56000.00
01570F	2017-08-02 21:54:00+03	72300.00
01571A	2017-08-14 15:19:00+03	369000.00
01574D	2017-07-07 10:43:00+03	59200.00
015753	2017-08-12 04:37:00+03	260300.00
01575B	2017-08-08 04:33:00+03	14800.00
01576A	2017-08-12 16:43:00+03	236000.00
0157FA	2017-07-19 18:16:00+03	31600.00
01580E	2017-07-06 17:28:00+03	103600.00
015810	2017-07-05 06:21:00+03	57600.00
015852	2017-08-12 22:40:00+03	39300.00
015897	2017-07-14 22:38:00+03	35200.00
0158AF	2017-07-15 16:50:00+03	65600.00
0158F8	2017-07-24 14:18:00+03	43600.00
015909	2017-08-10 06:11:00+03	84500.00
015952	2017-07-31 11:10:00+03	112000.00
015954	2017-08-04 03:24:00+03	25600.00
015956	2017-07-26 14:25:00+03	135600.00
015965	2017-06-30 14:43:00+03	129200.00
01596C	2017-08-13 23:53:00+03	125400.00
015A0B	2017-08-14 09:00:00+03	27300.00
015A43	2017-07-21 11:26:00+03	37200.00
015A4E	2017-08-06 03:19:00+03	8600.00
015A8B	2017-07-27 02:47:00+03	6700.00
015AC1	2017-07-01 14:31:00+03	185600.00
015AEA	2017-08-11 20:19:00+03	19800.00
015AED	2017-07-28 12:41:00+03	107300.00
015B3B	2017-08-07 01:19:00+03	37200.00
015B84	2017-08-12 04:34:00+03	61500.00
015B92	2017-07-15 19:18:00+03	112100.00
015BD3	2017-07-07 22:12:00+03	62800.00
015C61	2017-08-12 09:59:00+03	55800.00
015C9A	2017-08-07 17:43:00+03	118400.00
015CD4	2017-08-05 18:04:00+03	95600.00
015CE3	2017-07-10 14:14:00+03	18000.00
015D4B	2017-07-27 22:37:00+03	111600.00
015DE3	2017-08-12 09:58:00+03	57700.00
015DFB	2017-07-13 02:30:00+03	101200.00
015E0D	2017-07-17 12:37:00+03	43300.00
015E11	2017-07-23 15:39:00+03	6800.00
015E34	2017-07-24 14:15:00+03	36800.00
015E44	2017-07-15 17:23:00+03	6700.00
015EC1	2017-07-20 10:53:00+03	61500.00
015EE7	2017-08-08 19:45:00+03	18900.00
015EF5	2017-08-06 23:10:00+03	48800.00
015FA9	2017-07-06 13:36:00+03	140500.00
016016	2017-07-22 09:14:00+03	31200.00
016022	2017-07-22 03:56:00+03	27400.00
016061	2017-07-31 22:24:00+03	42800.00
016064	2017-07-12 12:14:00+03	22000.00
0160E0	2017-07-12 09:22:00+03	203000.00
016107	2017-08-02 16:33:00+03	26100.00
01613F	2017-07-28 18:27:00+03	44800.00
016160	2017-08-11 08:16:00+03	14400.00
01616C	2017-07-16 00:45:00+03	40600.00
016175	2017-08-04 08:57:00+03	50700.00
016195	2017-07-31 08:35:00+03	148200.00
0161C8	2017-07-03 04:30:00+03	92200.00
0161ED	2017-08-02 00:49:00+03	13400.00
016281	2017-08-03 16:56:00+03	38600.00
0162FA	2017-07-27 20:16:00+03	135400.00
016310	2017-07-26 08:37:00+03	44800.00
01631A	2017-08-11 21:53:00+03	193600.00
01637F	2017-07-30 08:40:00+03	29800.00
0163AF	2017-07-23 21:13:00+03	58900.00
0163CC	2017-08-07 21:51:00+03	40000.00
0163EB	2017-07-29 15:51:00+03	51900.00
016431	2017-07-16 12:39:00+03	135400.00
016445	2017-08-13 10:02:00+03	13400.00
0164E1	2017-08-14 23:14:00+03	88600.00
0164EC	2017-06-27 01:59:00+03	39300.00
01655A	2017-07-20 05:31:00+03	28800.00
0165AA	2017-08-03 22:07:00+03	359400.00
0165B7	2017-07-31 15:50:00+03	122300.00
0165D7	2017-07-31 17:20:00+03	214900.00
0165ED	2017-08-09 16:28:00+03	73300.00
016602	2017-07-29 19:08:00+03	260900.00
01661B	2017-07-23 20:10:00+03	55800.00
016626	2017-08-07 09:48:00+03	148200.00
01662D	2017-07-29 20:32:00+03	266400.00
01664C	2017-07-06 05:03:00+03	112000.00
016686	2017-07-12 21:58:00+03	24800.00
016695	2017-08-12 01:29:00+03	123000.00
016768	2017-07-01 14:16:00+03	44800.00
01679D	2017-07-04 12:59:00+03	36000.00
0167A9	2017-06-30 23:08:00+03	24400.00
0167CA	2017-08-12 23:22:00+03	93900.00
0167EF	2017-07-26 00:46:00+03	79900.00
016829	2017-07-25 07:57:00+03	83100.00
016832	2017-07-02 06:34:00+03	44100.00
016884	2017-08-02 22:01:00+03	43600.00
0168A1	2017-07-09 12:58:00+03	26000.00
01690B	2017-08-10 15:21:00+03	40000.00
016954	2017-07-10 16:29:00+03	17200.00
01695C	2017-07-05 10:44:00+03	87700.00
016999	2017-08-13 22:09:00+03	57800.00
016A78	2017-08-06 05:23:00+03	273000.00
016B09	2017-08-15 04:51:00+03	89100.00
016B74	2017-07-31 19:50:00+03	137100.00
016BAB	2017-07-21 15:23:00+03	11600.00
016BBE	2017-07-02 15:23:00+03	14400.00
016BF8	2017-08-13 03:05:00+03	48800.00
016C15	2017-07-28 21:20:00+03	75300.00
016C51	2017-08-06 17:28:00+03	14000.00
016C9C	2017-08-11 19:56:00+03	31600.00
016CDA	2017-07-08 13:50:00+03	56000.00
016D05	2017-08-08 10:37:00+03	189200.00
016D8B	2017-08-03 20:35:00+03	133200.00
016D8C	2017-07-30 03:16:00+03	43800.00
016DCE	2017-07-16 22:26:00+03	55800.00
016DE2	2017-07-09 15:46:00+03	53700.00
016E4E	2017-08-05 15:45:00+03	50000.00
016ED0	2017-08-12 15:03:00+03	67000.00
017036	2017-07-14 10:41:00+03	42400.00
01705D	2017-07-27 01:39:00+03	157400.00
01706D	2017-08-04 07:10:00+03	55800.00
0170B0	2017-08-11 23:16:00+03	59800.00
0170C3	2017-07-20 15:17:00+03	47400.00
017158	2017-08-12 10:33:00+03	147300.00
017159	2017-08-13 08:09:00+03	137600.00
0171B6	2017-07-08 04:53:00+03	38500.00
0172E4	2017-08-14 07:51:00+03	44800.00
017309	2017-07-17 01:03:00+03	32800.00
01730F	2017-07-06 00:12:00+03	136800.00
017352	2017-08-08 16:20:00+03	68100.00
0173E0	2017-07-30 01:13:00+03	101200.00
0173F3	2017-07-16 19:14:00+03	29200.00
01745B	2017-07-10 11:21:00+03	69000.00
01747F	2017-07-24 08:25:00+03	52000.00
0174D0	2017-08-06 11:30:00+03	165800.00
017507	2017-08-04 00:52:00+03	60000.00
017561	2017-08-14 23:35:00+03	94100.00
01758E	2017-07-21 09:15:00+03	69900.00
017596	2017-07-27 00:18:00+03	34100.00
01770F	2017-07-10 21:31:00+03	254900.00
0177A1	2017-07-06 01:34:00+03	131100.00
01780A	2017-07-13 16:06:00+03	6000.00
01787E	2017-07-19 14:23:00+03	14400.00
017883	2017-08-12 07:00:00+03	13400.00
01788F	2017-08-03 10:57:00+03	65600.00
0178F3	2017-08-08 15:23:00+03	26200.00
01796B	2017-08-13 04:29:00+03	26700.00
0179C8	2017-08-12 08:16:00+03	277900.00
0179E3	2017-07-12 01:58:00+03	44800.00
017A18	2017-07-29 12:27:00+03	28000.00
017AA5	2017-08-09 06:40:00+03	27400.00
017AB2	2017-07-27 05:42:00+03	29400.00
017ABC	2017-07-18 13:29:00+03	83200.00
017B5C	2017-07-10 21:01:00+03	191200.00
017BA0	2017-07-18 03:16:00+03	50800.00
017BD4	2017-07-24 02:30:00+03	258000.00
017C73	2017-07-26 09:35:00+03	48800.00
017C74	2017-07-18 20:49:00+03	325600.00
017CBF	2017-07-12 12:55:00+03	40900.00
017CCE	2017-06-30 17:08:00+03	112000.00
017D35	2017-07-15 10:23:00+03	135000.00
017DA9	2017-08-01 22:07:00+03	35200.00
017DD6	2017-08-11 13:48:00+03	175800.00
017DF6	2017-07-27 21:12:00+03	6000.00
017E63	2017-07-17 20:30:00+03	203800.00
017E66	2017-07-23 09:29:00+03	87900.00
017E71	2017-07-20 20:21:00+03	65700.00
017E83	2017-07-12 18:29:00+03	164800.00
017EA6	2017-08-12 05:13:00+03	135600.00
017EB4	2017-08-11 07:13:00+03	66600.00
017ED8	2017-07-27 23:02:00+03	250600.00
017F60	2017-08-08 03:56:00+03	22400.00
017FB4	2017-08-13 04:06:00+03	39400.00
018009	2017-08-15 07:07:00+03	121800.00
018018	2017-07-07 16:47:00+03	266200.00
01801D	2017-08-12 01:22:00+03	274000.00
018052	2017-06-30 08:43:00+03	59800.00
01805B	2017-08-15 01:31:00+03	6000.00
0180B3	2017-08-06 23:10:00+03	13400.00
0180D3	2017-08-12 21:56:00+03	43200.00
01819C	2017-07-23 22:36:00+03	6300.00
0181D0	2017-08-08 06:42:00+03	55800.00
0181EB	2017-07-01 14:23:00+03	54500.00
0181F5	2017-07-06 16:57:00+03	11600.00
018214	2017-06-30 01:28:00+03	54000.00
018215	2017-08-12 15:47:00+03	134400.00
018220	2017-07-26 00:41:00+03	62600.00
01822F	2017-08-03 03:20:00+03	51600.00
018277	2017-07-23 10:15:00+03	90400.00
018288	2017-07-11 14:16:00+03	65500.00
0182A4	2017-07-04 00:00:00+03	58400.00
0182D0	2017-08-15 01:35:00+03	34000.00
0182E7	2017-07-02 13:35:00+03	88800.00
018311	2017-07-07 18:02:00+03	98600.00
01831E	2017-07-07 14:00:00+03	46000.00
01833A	2017-07-06 18:11:00+03	23200.00
018346	2017-07-05 05:43:00+03	32200.00
018381	2017-07-22 00:21:00+03	173900.00
0183D8	2017-08-12 11:31:00+03	27200.00
01846A	2017-07-27 10:12:00+03	70500.00
018477	2017-07-31 12:43:00+03	60400.00
0184C7	2017-08-01 21:26:00+03	204000.00
018505	2017-08-15 04:30:00+03	6800.00
018517	2017-07-07 20:57:00+03	78000.00
018558	2017-07-24 09:56:00+03	54400.00
0185B1	2017-07-22 20:42:00+03	83500.00
0185CC	2017-07-09 18:40:00+03	47100.00
0185EA	2017-07-20 16:14:00+03	12400.00
01863E	2017-08-05 19:14:00+03	239000.00
018651	2017-07-14 19:32:00+03	88800.00
018687	2017-07-31 22:07:00+03	155600.00
0186A6	2017-07-18 01:47:00+03	52800.00
0186AE	2017-07-10 12:08:00+03	20800.00
01870D	2017-08-01 09:59:00+03	14400.00
018753	2017-08-09 23:32:00+03	14000.00
0187AB	2017-07-08 10:49:00+03	61500.00
0187C0	2017-08-02 06:38:00+03	136800.00
0187DF	2017-08-09 14:34:00+03	106100.00
01881E	2017-07-04 19:19:00+03	32800.00
018843	2017-08-01 01:09:00+03	88100.00
018865	2017-07-09 15:06:00+03	121400.00
018895	2017-08-04 21:13:00+03	100600.00
01889A	2017-08-05 23:54:00+03	43500.00
0188C9	2017-07-22 16:56:00+03	82900.00
0188D2	2017-08-02 12:09:00+03	67600.00
018954	2017-07-21 09:46:00+03	6800.00
01895E	2017-07-13 01:22:00+03	139500.00
0189E9	2017-07-20 13:53:00+03	88500.00
0189F2	2017-08-04 01:33:00+03	35800.00
018A71	2017-07-07 04:14:00+03	28800.00
018AC9	2017-07-06 23:41:00+03	28300.00
018AD9	2017-07-17 09:18:00+03	67200.00
018B94	2017-07-31 00:20:00+03	6600.00
018BDD	2017-08-13 02:56:00+03	141400.00
018BEF	2017-06-30 18:54:00+03	52200.00
018C1E	2017-07-10 20:05:00+03	64700.00
018C2F	2017-07-14 23:13:00+03	48800.00
018C3B	2017-08-10 21:19:00+03	62000.00
018C66	2017-07-12 06:01:00+03	66600.00
018CAE	2017-07-04 19:30:00+03	13000.00
018CB6	2017-07-15 23:37:00+03	74600.00
018DCA	2017-08-07 23:38:00+03	36000.00
018E13	2017-07-23 22:54:00+03	46400.00
018E2C	2017-08-11 02:34:00+03	59300.00
018E6A	2017-07-17 16:16:00+03	26000.00
018E94	2017-07-30 20:20:00+03	38800.00
018EA7	2017-07-28 17:31:00+03	169900.00
018ECD	2017-07-02 09:33:00+03	153900.00
018F0F	2017-08-08 20:20:00+03	13600.00
018F2C	2017-08-12 14:00:00+03	23900.00
018F3E	2017-07-24 15:35:00+03	159500.00
018F4D	2017-07-06 04:13:00+03	61800.00
018F6A	2017-07-08 15:26:00+03	78100.00
018F81	2017-07-01 09:39:00+03	37900.00
018F8C	2017-08-12 04:00:00+03	39800.00
019002	2017-07-21 08:45:00+03	40000.00
019028	2017-07-12 15:32:00+03	83000.00
01906A	2017-08-05 22:01:00+03	29400.00
0190B4	2017-07-29 05:09:00+03	69000.00
0190C7	2017-08-08 21:17:00+03	93400.00
0190EA	2017-07-18 13:10:00+03	17600.00
0190F5	2017-07-15 08:25:00+03	94500.00
01915B	2017-07-01 00:34:00+03	531400.00
019213	2017-07-15 07:12:00+03	60400.00
01922F	2017-07-23 14:54:00+03	43600.00
019240	2017-07-26 22:55:00+03	41600.00
019337	2017-07-11 22:33:00+03	177200.00
01933E	2017-07-06 18:43:00+03	46000.00
01935F	2017-08-13 01:01:00+03	190700.00
01936B	2017-07-12 08:00:00+03	246000.00
019372	2017-07-14 14:54:00+03	65500.00
019392	2017-08-14 21:45:00+03	126800.00
019400	2017-07-04 04:41:00+03	26700.00
019417	2017-08-07 20:35:00+03	67400.00
01944F	2017-07-27 22:54:00+03	17800.00
019460	2017-07-02 17:55:00+03	53600.00
0194B4	2017-07-01 22:55:00+03	39400.00
0194BB	2017-08-06 22:17:00+03	24300.00
0194BE	2017-07-17 00:02:00+03	44400.00
01952A	2017-06-29 19:05:00+03	56000.00
019535	2017-07-11 20:09:00+03	270700.00
01957B	2017-08-13 21:05:00+03	29500.00
019599	2017-07-21 00:38:00+03	164600.00
0195F5	2017-08-09 23:14:00+03	42700.00
019608	2017-07-21 16:49:00+03	25000.00
019632	2017-07-20 11:12:00+03	86800.00
019683	2017-08-10 11:01:00+03	399200.00
01968B	2017-07-25 17:25:00+03	179500.00
01968D	2017-07-06 19:43:00+03	37900.00
0196FD	2017-07-13 06:11:00+03	40800.00
019757	2017-08-03 18:22:00+03	133100.00
01976C	2017-07-18 21:53:00+03	12400.00
0197A6	2017-07-21 02:57:00+03	62600.00
0198BC	2017-07-16 17:11:00+03	28700.00
0198E9	2017-08-07 04:43:00+03	193700.00
0198F4	2017-07-30 01:56:00+03	14400.00
019975	2017-07-01 12:35:00+03	84800.00
019A15	2017-07-25 17:45:00+03	28800.00
019AFE	2017-07-18 01:42:00+03	166100.00
019B31	2017-08-09 00:40:00+03	24000.00
019B73	2017-07-24 02:15:00+03	25400.00
019B9C	2017-08-01 04:25:00+03	25400.00
019BAD	2017-06-28 10:27:00+03	112200.00
019BDC	2017-07-28 18:34:00+03	92000.00
019C36	2017-07-21 09:39:00+03	62600.00
019C42	2017-07-20 21:20:00+03	46500.00
019C59	2017-07-21 12:35:00+03	6600.00
019C74	2017-08-09 15:35:00+03	56600.00
019C7C	2017-08-04 18:24:00+03	109300.00
019CB3	2017-07-23 10:32:00+03	135000.00
019CB9	2017-07-01 18:14:00+03	59000.00
019D76	2017-08-11 10:36:00+03	36200.00
019DAE	2017-07-19 22:47:00+03	14000.00
019E1D	2017-07-04 04:54:00+03	55800.00
019E46	2017-07-17 22:58:00+03	379000.00
019E52	2017-06-27 11:56:00+03	19000.00
019E5D	2017-07-15 15:26:00+03	24000.00
019E60	2017-08-05 21:39:00+03	106400.00
019E9A	2017-07-23 21:50:00+03	223200.00
019EC5	2017-07-14 19:03:00+03	47100.00
019ECE	2017-08-04 21:24:00+03	45200.00
019EE0	2017-07-02 22:49:00+03	67600.00
019F09	2017-08-15 13:40:00+03	104500.00
019FA8	2017-08-08 00:56:00+03	13200.00
019FE1	2017-08-07 14:20:00+03	217900.00
019FE5	2017-07-08 10:43:00+03	172100.00
01A13A	2017-07-09 10:25:00+03	193200.00
01A1B1	2017-07-08 12:59:00+03	32800.00
01A1E6	2017-08-10 16:19:00+03	73300.00
01A1FF	2017-08-14 09:45:00+03	31900.00
01A2AE	2017-07-02 02:49:00+03	20400.00
01A375	2017-07-23 02:13:00+03	55800.00
01A3D0	2017-07-09 04:33:00+03	136800.00
01A40F	2017-07-07 15:31:00+03	54600.00
01A42A	2017-08-12 05:58:00+03	133200.00
01A42B	2017-07-28 19:22:00+03	85000.00
01A464	2017-08-10 10:14:00+03	114700.00
01A494	2017-07-18 00:26:00+03	67200.00
01A4CB	2017-07-23 10:56:00+03	74700.00
01A549	2017-07-01 02:42:00+03	81700.00
01A568	2017-07-17 23:12:00+03	20200.00
01A580	2017-07-24 07:04:00+03	60200.00
01A591	2017-07-19 01:57:00+03	38600.00
01A5B0	2017-07-26 18:42:00+03	24000.00
01A646	2017-08-02 21:12:00+03	248400.00
01A684	2017-08-11 21:27:00+03	6000.00
01A6ED	2017-07-17 20:26:00+03	133200.00
01A733	2017-07-14 11:03:00+03	87900.00
01A7AE	2017-07-01 21:30:00+03	23600.00
01A805	2017-07-10 16:05:00+03	136200.00
01A848	2017-08-12 07:33:00+03	63700.00
01A8B4	2017-08-09 08:15:00+03	26000.00
01A8F8	2017-07-30 15:57:00+03	29600.00
01A927	2017-07-02 15:56:00+03	107800.00
01A936	2017-07-31 17:14:00+03	55800.00
01AA0C	2017-07-07 09:07:00+03	23200.00
01AA0F	2017-07-30 14:58:00+03	32200.00
01AA28	2017-08-07 18:11:00+03	23200.00
01AA97	2017-07-24 04:36:00+03	79900.00
01AAF5	2017-08-03 06:14:00+03	318300.00
01AB0A	2017-08-11 15:53:00+03	168000.00
01AB4F	2017-07-24 20:33:00+03	240500.00
01AB9A	2017-07-03 19:06:00+03	86200.00
01ABBD	2017-07-12 00:29:00+03	86200.00
01ABE8	2017-07-07 20:13:00+03	50200.00
01ABFC	2017-08-03 05:26:00+03	46300.00
01AC2A	2017-07-08 10:38:00+03	73200.00
01AC31	2017-07-01 22:36:00+03	8200.00
01AC56	2017-07-08 21:13:00+03	27900.00
01AD1D	2017-08-13 03:36:00+03	23600.00
01AD26	2017-07-28 09:12:00+03	246000.00
01AD5B	2017-07-22 04:00:00+03	12600.00
01AD5F	2017-07-05 19:36:00+03	14000.00
01AD90	2017-07-26 17:22:00+03	44700.00
01AD93	2017-07-10 17:13:00+03	342100.00
01ADB1	2017-08-02 17:52:00+03	37400.00
01ADBE	2017-07-18 10:01:00+03	35200.00
01ADC4	2017-07-09 09:48:00+03	140900.00
01ADDC	2017-07-26 18:04:00+03	112600.00
01ADEA	2017-07-16 10:14:00+03	62000.00
01AE35	2017-07-07 22:04:00+03	24400.00
01AE68	2017-07-05 09:48:00+03	66600.00
01AF4B	2017-06-30 18:11:00+03	29400.00
01AF4C	2017-08-04 11:12:00+03	6000.00
01AF94	2017-07-18 18:58:00+03	78800.00
01AFC3	2017-08-03 17:19:00+03	111600.00
01AFC9	2017-06-30 00:31:00+03	46400.00
01AFD0	2017-06-26 14:51:00+03	85000.00
01AFE3	2017-07-28 10:17:00+03	190700.00
01AFED	2017-07-31 20:00:00+03	117200.00
01B03F	2017-08-06 13:51:00+03	12600.00
01B06B	2017-07-18 21:28:00+03	56000.00
01B070	2017-08-08 18:39:00+03	57800.00
01B0A2	2017-07-25 00:27:00+03	443000.00
01B0A6	2017-08-14 05:29:00+03	40800.00
01B0E1	2017-07-23 00:22:00+03	59800.00
01B12C	2017-07-10 00:58:00+03	32300.00
01B12E	2017-07-14 06:28:00+03	78600.00
01B13E	2017-07-28 08:07:00+03	42700.00
01B182	2017-07-12 15:32:00+03	8600.00
01B1C9	2017-07-03 05:32:00+03	29600.00
01B1F0	2017-07-08 00:22:00+03	123700.00
01B23F	2017-08-12 07:34:00+03	47500.00
01B267	2017-08-02 14:21:00+03	64800.00
01B28B	2017-08-08 04:22:00+03	68000.00
01B32E	2017-08-13 00:43:00+03	96800.00
01B3D6	2017-07-11 11:18:00+03	39700.00
01B3DB	2017-08-07 02:28:00+03	13000.00
01B42C	2017-07-16 08:25:00+03	266400.00
01B43A	2017-08-09 02:15:00+03	265600.00
01B498	2017-08-01 21:58:00+03	135000.00
01B4DC	2017-08-07 11:57:00+03	42400.00
01B53D	2017-07-13 11:01:00+03	19800.00
01B550	2017-07-20 05:39:00+03	131000.00
01B574	2017-07-18 10:17:00+03	49000.00
01B5C3	2017-08-04 02:54:00+03	139700.00
01B63A	2017-08-06 02:03:00+03	23600.00
01B643	2017-07-30 20:18:00+03	28800.00
01B644	2017-08-15 01:19:00+03	26500.00
01B650	2017-07-26 21:45:00+03	56000.00
01B68B	2017-07-26 13:54:00+03	92400.00
01B6F9	2017-07-21 17:36:00+03	59900.00
01B707	2017-08-02 13:58:00+03	44700.00
01B776	2017-08-11 22:50:00+03	55800.00
01B78F	2017-08-09 08:50:00+03	14000.00
01B7E8	2017-08-08 12:26:00+03	233800.00
01B8D0	2017-07-24 13:11:00+03	70800.00
01B91F	2017-08-13 15:15:00+03	13400.00
01B927	2017-08-09 00:05:00+03	66100.00
01B959	2017-08-01 18:14:00+03	120400.00
01B95D	2017-07-22 23:21:00+03	8200.00
01B97B	2017-07-20 11:26:00+03	28000.00
01B980	2017-07-07 04:25:00+03	64500.00
01B9F7	2017-07-13 19:31:00+03	67600.00
01BA30	2017-07-18 12:08:00+03	143600.00
01BABE	2017-07-02 20:30:00+03	202400.00
01BAFD	2017-08-03 12:48:00+03	58000.00
01BAFF	2017-08-04 05:36:00+03	40400.00
01BB10	2017-08-06 06:48:00+03	10800.00
01BB3D	2017-07-11 14:57:00+03	34400.00
01BB50	2017-07-19 12:57:00+03	23200.00
01BB53	2017-07-23 23:54:00+03	58400.00
01BD41	2017-07-24 22:05:00+03	21400.00
01BD6B	2017-07-19 22:08:00+03	167300.00
01BD88	2017-06-30 13:57:00+03	109600.00
01BDA6	2017-07-18 11:39:00+03	36200.00
01BDA7	2017-06-30 23:30:00+03	23100.00
01BDDB	2017-08-01 21:13:00+03	31200.00
01BE28	2017-07-12 00:22:00+03	31600.00
01BE2B	2017-08-03 17:47:00+03	41400.00
01BE43	2017-08-09 18:16:00+03	22100.00
01BE56	2017-07-11 05:17:00+03	26000.00
01BE65	2017-07-18 14:35:00+03	65900.00
01BE7A	2017-07-18 16:16:00+03	74400.00
01BEB8	2017-08-07 01:41:00+03	89700.00
01BEBA	2017-07-05 01:47:00+03	27800.00
01BEF1	2017-08-02 16:28:00+03	38800.00
01BF27	2017-07-04 18:01:00+03	85000.00
01BF36	2017-07-18 04:52:00+03	85000.00
01BF7C	2017-07-01 12:14:00+03	11600.00
01C013	2017-07-28 06:44:00+03	36400.00
01C0AF	2017-08-02 21:10:00+03	103200.00
01C0CA	2017-07-25 09:41:00+03	168000.00
01C0D1	2017-07-02 06:04:00+03	48800.00
01C12D	2017-07-03 11:41:00+03	55800.00
01C198	2017-08-13 21:16:00+03	81200.00
01C20D	2017-07-01 04:41:00+03	66800.00
01C265	2017-06-30 15:56:00+03	82300.00
01C2B6	2017-08-02 07:54:00+03	23200.00
01C2DD	2017-07-06 04:56:00+03	18600.00
01C2E9	2017-07-22 20:10:00+03	50000.00
01C2F3	2017-07-04 20:13:00+03	81900.00
01C36C	2017-07-20 19:36:00+03	99300.00
01C3FC	2017-07-18 01:42:00+03	14400.00
01C43B	2017-07-13 20:15:00+03	24800.00
01C484	2017-07-06 07:29:00+03	29400.00
01C515	2017-07-15 06:11:00+03	80700.00
01C549	2017-07-28 15:49:00+03	43500.00
01C551	2017-07-26 05:06:00+03	56000.00
01C576	2017-07-07 15:49:00+03	136300.00
01C57D	2017-07-18 08:07:00+03	60700.00
01C58F	2017-07-08 12:40:00+03	236000.00
01C738	2017-06-28 00:45:00+03	102300.00
01C763	2017-07-05 20:49:00+03	124000.00
01C77F	2017-07-19 14:31:00+03	38400.00
01C7AC	2017-07-06 04:41:00+03	103200.00
01C89C	2017-08-06 18:19:00+03	28000.00
01C8DA	2017-08-02 06:19:00+03	531600.00
01C924	2017-07-08 14:43:00+03	55800.00
01C941	2017-07-14 21:12:00+03	15900.00
01C97E	2017-07-24 12:20:00+03	27200.00
01C9A4	2017-07-19 23:59:00+03	72400.00
01C9B6	2017-07-03 17:40:00+03	32800.00
01CA2E	2017-07-20 03:25:00+03	12000.00
01CAD6	2017-06-29 20:54:00+03	92900.00
01CAEA	2017-07-31 19:01:00+03	9800.00
01CB1E	2017-07-17 06:09:00+03	36000.00
01CB44	2017-08-11 07:09:00+03	15400.00
01CBAB	2017-07-09 17:54:00+03	85000.00
01CBB7	2017-07-04 08:09:00+03	36200.00
01CBB9	2017-07-07 15:31:00+03	55800.00
01CD1F	2017-07-01 18:46:00+03	141200.00
01CD90	2017-07-15 20:26:00+03	23600.00
01CD9D	2017-07-17 04:56:00+03	52000.00
01CE45	2017-08-04 12:36:00+03	28000.00
01CE51	2017-08-14 15:43:00+03	56000.00
01CE6B	2017-07-17 11:30:00+03	90900.00
01CE7E	2017-07-05 12:01:00+03	50600.00
01CEE8	2017-07-24 03:57:00+03	13400.00
01CEED	2017-07-28 07:22:00+03	16400.00
01CF22	2017-07-29 15:33:00+03	105600.00
01CF77	2017-08-12 10:16:00+03	46400.00
01CFA9	2017-07-23 22:12:00+03	28000.00
01CFAA	2017-08-14 22:11:00+03	43000.00
01CFBD	2017-07-22 01:29:00+03	11800.00
01D00C	2017-08-05 16:05:00+03	167400.00
01D024	2017-08-01 10:36:00+03	14400.00
01D044	2017-07-25 11:33:00+03	28000.00
01D094	2017-07-11 18:24:00+03	37900.00
01D0BB	2017-08-13 07:29:00+03	10100.00
01D101	2017-07-19 08:13:00+03	70000.00
01D110	2017-08-14 17:14:00+03	70700.00
01D13B	2017-08-01 07:30:00+03	15000.00
01D162	2017-07-05 05:24:00+03	35600.00
01D17B	2017-07-27 12:58:00+03	17600.00
01D1A3	2017-08-05 14:40:00+03	31400.00
01D1A9	2017-07-24 23:51:00+03	110400.00
01D1DE	2017-08-10 19:14:00+03	12600.00
01D24E	2017-08-14 15:22:00+03	39300.00
01D271	2017-08-15 06:05:00+03	199800.00
01D2B2	2017-07-15 15:41:00+03	21400.00
01D303	2017-07-31 21:34:00+03	15600.00
01D3B0	2017-07-29 03:14:00+03	241300.00
01D423	2017-07-08 13:21:00+03	39500.00
01D458	2017-07-12 09:44:00+03	28000.00
01D459	2017-07-24 07:28:00+03	77600.00
01D4A8	2017-08-07 08:29:00+03	40000.00
01D50C	2017-07-17 20:27:00+03	67200.00
01D5F2	2017-07-20 05:30:00+03	66800.00
01D704	2017-07-22 11:56:00+03	147700.00
01D725	2017-08-05 11:01:00+03	104400.00
01D740	2017-07-03 19:03:00+03	20600.00
01D74C	2017-08-14 01:32:00+03	135400.00
01D822	2017-07-22 16:48:00+03	62100.00
01D877	2017-07-23 04:41:00+03	123000.00
01D885	2017-07-14 09:17:00+03	24400.00
01D88E	2017-07-16 07:48:00+03	34000.00
01D8B3	2017-07-03 05:54:00+03	141400.00
01D8FE	2017-07-30 15:40:00+03	40800.00
01D92B	2017-07-25 00:27:00+03	25400.00
01D97A	2017-07-05 04:14:00+03	58700.00
01D9D7	2017-08-03 05:44:00+03	201200.00
01D9E4	2017-08-07 12:04:00+03	142800.00
01DA80	2017-07-19 09:52:00+03	63400.00
01DBC1	2017-07-11 18:23:00+03	113800.00
01DBE9	2017-07-18 01:53:00+03	422900.00
01DBFA	2017-08-10 15:33:00+03	34000.00
01DC36	2017-07-25 06:13:00+03	51200.00
01DC3C	2017-08-13 23:16:00+03	140900.00
01DC97	2017-07-11 14:11:00+03	39400.00
01DCC7	2017-08-05 08:32:00+03	28800.00
01DCD5	2017-07-25 06:49:00+03	43700.00
01DCD6	2017-07-04 01:50:00+03	93900.00
01DCE2	2017-07-17 12:03:00+03	28000.00
01DE4E	2017-08-11 18:54:00+03	43200.00
01DF88	2017-08-12 09:41:00+03	123000.00
01DFEB	2017-08-11 03:38:00+03	61800.00
01E0A9	2017-07-20 11:21:00+03	242600.00
01E0D1	2017-08-02 03:43:00+03	159100.00
01E13E	2017-07-13 01:31:00+03	25600.00
01E148	2017-08-01 23:10:00+03	7400.00
01E153	2017-07-21 11:11:00+03	174400.00
01E157	2017-07-07 07:49:00+03	11800.00
01E168	2017-07-30 10:05:00+03	179400.00
01E188	2017-06-27 00:42:00+03	492000.00
01E1E0	2017-07-21 11:14:00+03	123000.00
01E1E1	2017-08-15 08:24:00+03	98400.00
01E20A	2017-07-20 04:51:00+03	27400.00
01E22A	2017-08-04 01:53:00+03	79900.00
01E23B	2017-08-12 05:42:00+03	248300.00
01E247	2017-07-13 11:35:00+03	24400.00
01E257	2017-08-02 13:27:00+03	59900.00
01E2C6	2017-07-09 13:12:00+03	85600.00
01E2D4	2017-08-11 02:28:00+03	27200.00
01E389	2017-07-04 01:55:00+03	41600.00
01E3AF	2017-07-27 02:40:00+03	203000.00
01E3C3	2017-07-07 12:26:00+03	36200.00
01E401	2017-08-08 02:05:00+03	39300.00
01E413	2017-07-22 12:30:00+03	13400.00
01E475	2017-07-08 17:46:00+03	258400.00
01E477	2017-07-23 20:23:00+03	56000.00
01E480	2017-07-14 20:56:00+03	135200.00
01E50A	2017-08-15 16:37:00+03	35200.00
01E597	2017-08-04 18:45:00+03	76600.00
01E5DB	2017-07-03 02:50:00+03	114700.00
01E61E	2017-07-15 01:48:00+03	35200.00
01E638	2017-06-30 18:10:00+03	65700.00
01E6A0	2017-07-15 22:08:00+03	42900.00
01E6AC	2017-07-28 10:16:00+03	23200.00
01E6CF	2017-08-02 16:13:00+03	184500.00
01E707	2017-07-23 22:32:00+03	258400.00
01E788	2017-07-23 03:13:00+03	37900.00
01E796	2017-07-21 19:12:00+03	57800.00
01E7EE	2017-07-24 06:38:00+03	26000.00
01E8C4	2017-07-21 10:37:00+03	20400.00
01E910	2017-08-10 20:26:00+03	29800.00
01E922	2017-07-20 11:10:00+03	26100.00
01E9AF	2017-08-06 00:02:00+03	40700.00
01E9BE	2017-06-28 09:29:00+03	224000.00
01E9CA	2017-08-15 03:07:00+03	136400.00
01EA0E	2017-07-18 04:01:00+03	13400.00
01EA19	2017-08-04 23:09:00+03	39500.00
01EB12	2017-08-09 11:10:00+03	136800.00
01EB85	2017-06-26 06:39:00+03	58400.00
01EC07	2017-07-27 04:19:00+03	139300.00
01EC53	2017-07-22 20:15:00+03	26000.00
01EC90	2017-07-16 01:41:00+03	110500.00
01ECD1	2017-08-09 07:40:00+03	72900.00
01ED26	2017-08-08 14:16:00+03	141600.00
01ED62	2017-07-22 18:46:00+03	25400.00
01ED6C	2017-06-29 18:12:00+03	20000.00
01ED83	2017-07-21 02:01:00+03	147700.00
01ED87	2017-07-22 10:23:00+03	123000.00
01EDB1	2017-07-20 07:59:00+03	56000.00
01EDB7	2017-07-22 09:35:00+03	187800.00
01EDD1	2017-07-06 18:16:00+03	31600.00
01EDF6	2017-07-30 15:01:00+03	17800.00
01EE01	2017-07-05 03:56:00+03	13400.00
01EE31	2017-08-14 00:54:00+03	118300.00
01EE90	2017-07-24 15:42:00+03	43900.00
01EE93	2017-07-20 21:07:00+03	26700.00
01EEC6	2017-07-04 19:20:00+03	7200.00
01EF93	2017-08-07 09:22:00+03	57500.00
01EFE7	2017-07-12 20:37:00+03	71600.00
01F041	2017-07-23 03:58:00+03	58700.00
01F101	2017-07-28 23:52:00+03	339300.00
01F13C	2017-08-06 07:49:00+03	40800.00
01F24A	2017-07-10 02:56:00+03	36000.00
01F253	2017-07-13 22:20:00+03	75600.00
01F2B5	2017-08-05 00:10:00+03	102100.00
01F318	2017-07-24 04:05:00+03	62000.00
01F348	2017-07-28 17:37:00+03	65500.00
01F352	2017-07-10 17:21:00+03	76900.00
01F36F	2017-07-11 21:44:00+03	13600.00
01F37D	2017-08-11 02:10:00+03	32800.00
01F382	2017-08-10 16:17:00+03	10800.00
01F3C0	2017-08-13 07:04:00+03	26200.00
01F464	2017-07-14 13:06:00+03	189800.00
01F5AA	2017-07-29 10:55:00+03	45200.00
01F5C7	2017-07-29 16:53:00+03	26000.00
01F646	2017-07-28 00:17:00+03	77000.00
01F703	2017-07-14 04:19:00+03	202000.00
01F716	2017-07-19 01:26:00+03	174000.00
01F723	2017-07-08 21:03:00+03	185600.00
01F752	2017-07-14 07:54:00+03	289300.00
01F755	2017-07-26 01:43:00+03	109800.00
01F789	2017-07-14 01:49:00+03	28000.00
01F79E	2017-08-05 19:11:00+03	21400.00
01F807	2017-08-08 19:04:00+03	13700.00
01F80E	2017-07-18 05:12:00+03	66600.00
01F813	2017-07-06 16:21:00+03	271100.00
01F876	2017-07-10 16:56:00+03	43200.00
01F8B5	2017-07-19 12:03:00+03	169000.00
01F8E4	2017-07-30 22:57:00+03	32600.00
01F9E8	2017-08-06 17:39:00+03	56600.00
01FA1D	2017-07-09 18:03:00+03	64700.00
01FA39	2017-07-15 14:30:00+03	26800.00
01FA48	2017-07-12 02:36:00+03	46400.00
01FA4A	2017-08-10 02:54:00+03	116500.00
01FB6F	2017-08-06 14:35:00+03	28800.00
01FBA5	2017-07-10 08:27:00+03	28000.00
01FC52	2017-08-06 09:53:00+03	33100.00
01FC7A	2017-07-14 02:22:00+03	23100.00
01FCB1	2017-08-07 00:57:00+03	49800.00
01FCB9	2017-07-12 03:25:00+03	6700.00
01FCE2	2017-07-03 19:42:00+03	20400.00
01FCFE	2017-08-15 01:55:00+03	104500.00
01FD5B	2017-07-19 13:10:00+03	18000.00
01FDDA	2017-07-15 23:05:00+03	169900.00
01FDF1	2017-07-27 23:21:00+03	23600.00
01FE3B	2017-07-11 16:56:00+03	68000.00
01FE5C	2017-07-21 22:06:00+03	26700.00
01FE64	2017-08-03 10:18:00+03	19800.00
01FE70	2017-07-08 13:21:00+03	62700.00
01FE9E	2017-07-04 21:18:00+03	39300.00
01FEB3	2017-08-14 12:58:00+03	58600.00
01FEB5	2017-07-31 19:39:00+03	19600.00
01FEF0	2017-07-17 19:47:00+03	136800.00
01FEFC	2017-08-05 19:01:00+03	134700.00
01FF1F	2017-07-07 14:13:00+03	114700.00
01FF81	2017-08-13 20:27:00+03	46000.00
01FFD9	2017-07-24 00:52:00+03	59800.00
020075	2017-07-16 12:00:00+03	35200.00
02008E	2017-07-13 07:02:00+03	66600.00
0200BD	2017-08-10 00:33:00+03	48300.00
0200C3	2017-07-24 17:41:00+03	41400.00
0200ED	2017-07-28 09:09:00+03	30800.00
020108	2017-07-26 05:35:00+03	29600.00
020159	2017-07-28 09:14:00+03	47400.00
020169	2017-08-15 15:00:00+03	12000.00
020179	2017-07-06 11:11:00+03	39400.00
0201F5	2017-06-24 11:26:00+03	273000.00
0202F1	2017-06-27 02:54:00+03	50800.00
020379	2017-07-15 00:14:00+03	75600.00
0203BF	2017-07-22 13:57:00+03	45600.00
0203C1	2017-07-17 09:11:00+03	246000.00
0203F4	2017-07-30 12:52:00+03	52300.00
020419	2017-07-18 09:14:00+03	67600.00
020433	2017-07-21 00:57:00+03	98800.00
02043B	2017-07-05 10:56:00+03	55900.00
020453	2017-07-18 23:09:00+03	19600.00
020478	2017-07-15 22:48:00+03	89700.00
020495	2017-07-30 20:12:00+03	62800.00
0204DF	2017-08-09 13:00:00+03	130400.00
02051D	2017-07-13 09:35:00+03	103500.00
020548	2017-07-05 18:36:00+03	28800.00
020557	2017-08-13 06:42:00+03	146400.00
0205B2	2017-06-29 15:30:00+03	147800.00
0205FA	2017-08-12 00:24:00+03	71500.00
0206D7	2017-07-11 18:49:00+03	19600.00
0206F0	2017-07-31 02:16:00+03	20000.00
0206FB	2017-08-04 08:36:00+03	40400.00
020756	2017-07-30 16:15:00+03	162700.00
020766	2017-07-31 06:43:00+03	126400.00
0207DA	2017-08-13 04:53:00+03	45500.00
02081E	2017-07-11 23:08:00+03	64800.00
020850	2017-06-30 11:13:00+03	174400.00
02094F	2017-07-12 04:08:00+03	28000.00
020967	2017-07-07 07:04:00+03	54800.00
02097D	2017-07-11 10:31:00+03	193300.00
0209D8	2017-07-12 21:47:00+03	58200.00
0209FB	2017-08-01 23:06:00+03	46300.00
020A1B	2017-07-20 05:35:00+03	358200.00
020A93	2017-07-22 16:48:00+03	12600.00
020ADC	2017-06-29 16:45:00+03	44500.00
020B41	2017-08-13 04:25:00+03	39800.00
020B84	2017-07-03 01:31:00+03	45400.00
020BB8	2017-07-25 07:26:00+03	46800.00
020BC1	2017-07-08 03:09:00+03	88800.00
020BEF	2017-08-10 00:46:00+03	66600.00
020CA3	2017-07-08 10:15:00+03	26000.00
020CC6	2017-08-04 15:28:00+03	265700.00
020CE2	2017-07-02 10:14:00+03	87400.00
020CF3	2017-07-12 16:45:00+03	38800.00
020D1F	2017-07-24 13:17:00+03	54800.00
020D43	2017-07-20 12:16:00+03	14000.00
020D53	2017-07-19 09:24:00+03	20400.00
020D58	2017-07-15 06:57:00+03	153100.00
020E2A	2017-07-04 15:24:00+03	106100.00
020E58	2017-08-11 01:16:00+03	59900.00
020E62	2017-07-14 20:10:00+03	23400.00
020E6C	2017-08-06 06:04:00+03	28700.00
020E98	2017-08-07 12:09:00+03	94800.00
020EB5	2017-07-19 06:18:00+03	23600.00
020ECB	2017-08-13 03:36:00+03	18000.00
020F3A	2017-07-28 07:01:00+03	16400.00
020F3B	2017-08-04 03:17:00+03	57600.00
020F5B	2017-08-15 01:12:00+03	71200.00
020F66	2017-07-23 00:11:00+03	21400.00
020FE2	2017-07-11 20:44:00+03	50600.00
021018	2017-08-03 01:42:00+03	149300.00
021077	2017-07-05 17:32:00+03	19200.00
0210AA	2017-07-11 19:07:00+03	19800.00
0210E3	2017-08-07 07:12:00+03	89000.00
02110D	2017-07-26 21:57:00+03	6600.00
021137	2017-07-22 07:53:00+03	63700.00
021196	2017-07-21 05:11:00+03	32200.00
0211BC	2017-08-08 12:58:00+03	55800.00
0211D7	2017-07-09 15:41:00+03	51300.00
0211F2	2017-08-02 01:35:00+03	28000.00
021226	2017-07-01 21:21:00+03	9200.00
021259	2017-08-05 06:12:00+03	101200.00
0212A1	2017-07-26 23:44:00+03	37900.00
0212DD	2017-07-26 05:44:00+03	40100.00
02130E	2017-07-28 00:32:00+03	20800.00
02131B	2017-07-25 03:46:00+03	38600.00
021348	2017-07-02 07:58:00+03	166900.00
021354	2017-07-10 20:24:00+03	38600.00
021378	2017-07-28 15:32:00+03	105900.00
0213B7	2017-07-20 06:19:00+03	92400.00
021425	2017-07-04 05:39:00+03	266400.00
021447	2017-07-29 22:58:00+03	56900.00
021518	2017-07-06 03:17:00+03	86300.00
0215AD	2017-08-10 20:28:00+03	31200.00
0215F0	2017-07-06 13:35:00+03	14800.00
0215FC	2017-07-23 07:10:00+03	13400.00
021617	2017-07-31 10:31:00+03	133200.00
0216DB	2017-07-21 09:17:00+03	6700.00
021707	2017-07-09 22:30:00+03	98400.00
021758	2017-07-20 13:20:00+03	36200.00
02184A	2017-08-02 14:12:00+03	117900.00
021904	2017-07-24 23:11:00+03	56100.00
021940	2017-08-13 23:18:00+03	56000.00
021949	2017-07-14 23:35:00+03	92800.00
02194A	2017-07-16 07:30:00+03	106400.00
0219C0	2017-07-22 06:58:00+03	112000.00
021A02	2017-08-14 09:21:00+03	59800.00
021A41	2017-07-18 17:41:00+03	26100.00
021A9F	2017-08-07 00:05:00+03	23600.00
021AEF	2017-08-03 23:42:00+03	55800.00
021B19	2017-08-14 18:50:00+03	15900.00
021B62	2017-08-09 00:29:00+03	13200.00
021B9B	2017-06-27 08:26:00+03	24000.00
021B9E	2017-08-05 14:04:00+03	55800.00
021BDA	2017-07-21 15:09:00+03	47200.00
021CAB	2017-07-22 20:56:00+03	67600.00
021CC8	2017-08-13 15:31:00+03	40100.00
021CD1	2017-07-15 06:23:00+03	28000.00
021CD5	2017-07-03 08:42:00+03	15000.00
021D1F	2017-07-01 02:52:00+03	61500.00
021D32	2017-07-05 23:26:00+03	75300.00
021D54	2017-08-15 12:01:00+03	187600.00
021D71	2017-07-19 12:03:00+03	99200.00
021D73	2017-08-06 03:05:00+03	133200.00
021D92	2017-07-16 02:16:00+03	277800.00
021E5B	2017-07-07 07:10:00+03	26700.00
021E75	2017-07-07 13:38:00+03	101700.00
021E78	2017-07-03 09:15:00+03	97900.00
021FB2	2017-07-17 23:59:00+03	114300.00
021FF4	2017-07-07 12:16:00+03	51900.00
02206A	2017-07-27 09:28:00+03	12600.00
022097	2017-06-27 19:03:00+03	82900.00
0220A4	2017-07-16 20:29:00+03	62600.00
0220A7	2017-08-04 04:11:00+03	147100.00
0220A8	2017-07-24 23:00:00+03	66600.00
0220D2	2017-08-03 10:22:00+03	241300.00
0220E7	2017-07-28 19:29:00+03	49600.00
0220F7	2017-07-11 17:23:00+03	85500.00
022106	2017-07-13 14:21:00+03	99300.00
02211E	2017-08-03 01:44:00+03	32800.00
022139	2017-08-15 10:19:00+03	57400.00
022146	2017-07-02 22:00:00+03	18000.00
022164	2017-07-01 03:43:00+03	51000.00
022176	2017-07-02 15:26:00+03	166900.00
02217E	2017-07-04 11:27:00+03	23200.00
02227B	2017-07-08 16:20:00+03	50000.00
022309	2017-07-20 21:11:00+03	133200.00
022315	2017-07-05 08:49:00+03	22000.00
022379	2017-08-08 01:16:00+03	58400.00
0223B1	2017-08-05 21:37:00+03	32800.00
0223C9	2017-07-04 07:40:00+03	118100.00
02241A	2017-08-09 02:37:00+03	55000.00
022422	2017-08-12 14:37:00+03	49800.00
0224AA	2017-07-27 16:14:00+03	273000.00
022545	2017-07-13 07:49:00+03	59800.00
022586	2017-07-31 20:04:00+03	246000.00
0225AE	2017-07-26 01:14:00+03	55600.00
02260E	2017-07-01 09:16:00+03	6700.00
022649	2017-07-06 22:34:00+03	38200.00
02266C	2017-07-10 15:11:00+03	27800.00
0226F6	2017-07-18 03:27:00+03	15400.00
02270F	2017-08-03 18:18:00+03	6800.00
02271E	2017-07-16 17:09:00+03	55800.00
022763	2017-08-14 23:41:00+03	26000.00
022777	2017-08-05 12:17:00+03	44000.00
02277D	2017-07-26 14:01:00+03	12100.00
0227E0	2017-07-12 15:31:00+03	155600.00
0227E6	2017-07-12 15:05:00+03	73500.00
022887	2017-07-23 09:46:00+03	148200.00
0228EB	2017-07-18 18:02:00+03	196800.00
02290F	2017-08-01 22:47:00+03	123000.00
02292D	2017-06-30 14:55:00+03	111200.00
0229BD	2017-08-15 11:38:00+03	93400.00
022A0F	2017-07-22 23:33:00+03	129200.00
022ACE	2017-07-23 10:58:00+03	22000.00
022AE2	2017-07-22 01:42:00+03	24400.00
022AE7	2017-07-10 15:45:00+03	53300.00
022AEB	2017-08-13 18:55:00+03	148200.00
022B32	2017-07-21 20:58:00+03	28000.00
022B50	2017-07-22 04:26:00+03	62600.00
022B51	2017-07-09 16:34:00+03	56600.00
022B95	2017-07-24 16:58:00+03	38000.00
022BA3	2017-08-09 00:09:00+03	69400.00
022BA6	2017-07-11 17:41:00+03	167400.00
022CC3	2017-07-04 01:12:00+03	106400.00
022CEC	2017-08-02 12:00:00+03	75600.00
022D04	2017-07-28 21:19:00+03	119700.00
022D0E	2017-08-12 08:35:00+03	48100.00
022D40	2017-07-01 12:32:00+03	29200.00
022D8B	2017-08-09 04:16:00+03	59400.00
022EBB	2017-07-11 21:02:00+03	386300.00
022EE2	2017-07-05 22:59:00+03	124000.00
022F05	2017-08-03 04:44:00+03	59800.00
022F19	2017-07-18 21:52:00+03	24600.00
022F77	2017-07-05 03:34:00+03	56600.00
023043	2017-08-01 16:30:00+03	51200.00
023059	2017-07-09 15:31:00+03	60000.00
0230B3	2017-07-18 00:01:00+03	39400.00
0230C0	2017-08-07 12:08:00+03	66600.00
0230C2	2017-07-23 21:30:00+03	14300.00
0230C4	2017-07-25 06:52:00+03	37900.00
023140	2017-07-20 11:30:00+03	84500.00
023151	2017-07-06 14:58:00+03	36500.00
0231D4	2017-08-04 19:07:00+03	23400.00
0231D6	2017-08-13 02:37:00+03	99300.00
023232	2017-07-16 02:52:00+03	86600.00
023288	2017-07-09 07:10:00+03	35700.00
023410	2017-08-02 21:54:00+03	168000.00
023429	2017-07-29 21:39:00+03	62900.00
02348C	2017-08-14 11:47:00+03	38800.00
0234DE	2017-08-03 18:57:00+03	43200.00
0234FA	2017-07-23 07:21:00+03	111700.00
023552	2017-07-30 13:21:00+03	166100.00
023703	2017-07-25 08:27:00+03	46000.00
023704	2017-07-08 20:23:00+03	70000.00
02372A	2017-08-14 11:45:00+03	23200.00
023731	2017-07-12 14:04:00+03	115100.00
02373C	2017-07-27 21:09:00+03	126700.00
023751	2017-07-22 11:40:00+03	94500.00
0237EF	2017-07-03 02:51:00+03	38800.00
023814	2017-08-11 06:19:00+03	13200.00
023864	2017-08-14 22:23:00+03	85000.00
023876	2017-08-14 03:01:00+03	38700.00
023949	2017-07-25 02:08:00+03	29500.00
0239A2	2017-06-30 04:38:00+03	31600.00
0239DA	2017-07-13 00:02:00+03	13200.00
023A92	2017-08-13 02:42:00+03	14800.00
023AB5	2017-08-13 13:15:00+03	54300.00
023B46	2017-07-27 04:29:00+03	46200.00
023C0C	2017-08-06 01:14:00+03	21400.00
023C83	2017-07-22 17:47:00+03	27900.00
023CAA	2017-07-29 06:57:00+03	21400.00
023CBC	2017-06-28 13:53:00+03	72200.00
023D00	2017-08-15 10:05:00+03	35400.00
023D68	2017-07-13 09:08:00+03	37400.00
023E13	2017-08-01 18:03:00+03	47100.00
023E6B	2017-07-02 12:26:00+03	20200.00
023ED0	2017-08-03 05:13:00+03	20400.00
023F85	2017-07-09 12:20:00+03	100400.00
023F88	2017-07-31 11:14:00+03	141600.00
023F92	2017-08-15 05:44:00+03	20200.00
023FE9	2017-07-14 05:28:00+03	78800.00
023FF1	2017-07-19 08:23:00+03	29600.00
02401D	2017-07-25 19:33:00+03	48800.00
02408F	2017-07-07 09:09:00+03	60400.00
0240C2	2017-07-04 06:06:00+03	21800.00
0240EF	2017-07-30 11:37:00+03	46500.00
02411C	2017-07-09 13:18:00+03	26000.00
02414D	2017-07-18 03:21:00+03	153200.00
024163	2017-07-03 10:55:00+03	21400.00
02416D	2017-07-09 07:54:00+03	16400.00
024170	2017-07-12 15:14:00+03	34200.00
0241BF	2017-07-02 12:55:00+03	185300.00
02422C	2017-07-08 03:52:00+03	25000.00
02436C	2017-07-10 16:58:00+03	14400.00
0243F0	2017-08-05 15:36:00+03	26000.00
024455	2017-07-31 05:15:00+03	52800.00
02446D	2017-07-29 11:46:00+03	17800.00
024483	2017-08-08 00:59:00+03	20400.00
0244BB	2017-07-28 07:58:00+03	457000.00
0244BF	2017-07-11 04:41:00+03	94800.00
024548	2017-07-23 22:58:00+03	265700.00
024623	2017-07-18 06:14:00+03	532800.00
024627	2017-08-14 03:07:00+03	37600.00
024649	2017-07-13 23:40:00+03	43200.00
024650	2017-08-09 03:52:00+03	119200.00
024694	2017-07-07 10:04:00+03	48800.00
0246E9	2017-07-20 09:35:00+03	272300.00
024730	2017-07-30 10:42:00+03	10600.00
024775	2017-07-31 13:14:00+03	201200.00
0247DF	2017-07-25 15:23:00+03	8200.00
024847	2017-08-12 16:49:00+03	40100.00
02486E	2017-07-14 22:05:00+03	8000.00
0248D4	2017-07-14 07:10:00+03	183100.00
0248E6	2017-07-09 17:19:00+03	100600.00
0248E7	2017-08-05 12:31:00+03	67200.00
024963	2017-07-18 17:45:00+03	13200.00
0249B1	2017-08-09 14:46:00+03	270800.00
0249C4	2017-07-05 09:52:00+03	50600.00
024A05	2017-07-07 21:18:00+03	37900.00
024A0E	2017-07-31 11:35:00+03	58900.00
024A2F	2017-07-18 10:52:00+03	52900.00
024A7B	2017-07-10 06:38:00+03	40800.00
024A9F	2017-07-16 01:21:00+03	86800.00
024AB1	2017-07-27 18:45:00+03	24400.00
024B03	2017-08-09 07:53:00+03	12400.00
024B09	2017-07-19 08:25:00+03	40200.00
024B15	2017-08-11 13:37:00+03	40400.00
024B17	2017-07-19 19:14:00+03	60400.00
024B31	2017-07-21 17:51:00+03	29400.00
024B85	2017-08-06 01:40:00+03	46900.00
024BB9	2017-07-11 03:44:00+03	58600.00
024BD8	2017-07-28 21:49:00+03	281500.00
024C03	2017-07-11 04:14:00+03	67400.00
024C06	2017-08-15 17:53:00+03	36000.00
024C07	2017-07-13 02:42:00+03	169900.00
024C54	2017-06-28 13:18:00+03	87700.00
024D26	2017-07-25 20:50:00+03	29600.00
024D3B	2017-07-23 09:00:00+03	23400.00
024D47	2017-07-21 16:09:00+03	124200.00
024D71	2017-07-29 13:26:00+03	15900.00
024D9E	2017-08-02 16:18:00+03	163600.00
024DBD	2017-07-23 14:25:00+03	119500.00
024DE0	2017-07-24 00:32:00+03	128900.00
024DE1	2017-07-08 07:31:00+03	50600.00
024DE4	2017-07-14 08:08:00+03	14800.00
024E02	2017-08-10 18:28:00+03	200300.00
024E2D	2017-07-15 23:38:00+03	83000.00
024E66	2017-08-08 06:21:00+03	62900.00
024E9B	2017-08-03 11:28:00+03	6000.00
024EB6	2017-07-29 04:55:00+03	177200.00
024EC0	2017-07-15 11:17:00+03	103800.00
024EC6	2017-08-14 13:30:00+03	140300.00
024EE6	2017-07-17 10:02:00+03	88100.00
024F16	2017-07-02 10:16:00+03	26200.00
024F31	2017-07-06 14:02:00+03	112600.00
024F73	2017-08-14 18:23:00+03	399600.00
02500F	2017-07-18 20:11:00+03	87100.00
02506F	2017-08-07 05:54:00+03	28300.00
02510F	2017-07-28 20:19:00+03	167900.00
025112	2017-07-10 11:14:00+03	75300.00
025130	2017-07-23 09:01:00+03	99600.00
025163	2017-07-01 14:01:00+03	54400.00
025185	2017-08-04 05:58:00+03	136200.00
0251AD	2017-08-15 02:03:00+03	131000.00
0251F7	2017-07-06 19:21:00+03	39300.00
025204	2017-06-29 22:54:00+03	66900.00
025267	2017-06-29 12:43:00+03	57600.00
025295	2017-07-10 07:39:00+03	123000.00
025297	2017-08-04 22:35:00+03	14800.00
0252E1	2017-07-25 16:02:00+03	57500.00
0253BE	2017-08-10 17:08:00+03	159800.00
02544E	2017-07-10 20:36:00+03	87800.00
025558	2017-06-27 21:35:00+03	119800.00
0255BA	2017-08-11 16:26:00+03	291600.00
02561B	2017-08-11 21:05:00+03	58900.00
025623	2017-07-14 11:07:00+03	135000.00
02562A	2017-07-10 18:20:00+03	26000.00
0256E8	2017-08-03 15:33:00+03	28800.00
02572E	2017-08-14 14:57:00+03	31400.00
02577F	2017-08-14 20:27:00+03	48500.00
025809	2017-07-23 11:02:00+03	42000.00
02580F	2017-08-05 02:23:00+03	30600.00
025823	2017-07-31 15:03:00+03	28800.00
025824	2017-07-31 14:24:00+03	120900.00
02584E	2017-08-13 20:44:00+03	38400.00
0258A3	2017-08-01 19:02:00+03	37900.00
0258FC	2017-08-12 16:05:00+03	88600.00
0259CE	2017-07-12 19:23:00+03	24400.00
0259E6	2017-07-04 15:24:00+03	40400.00
025A7B	2017-08-02 06:57:00+03	60400.00
025AAA	2017-07-16 20:40:00+03	105000.00
025AC1	2017-08-07 12:16:00+03	95600.00
025AF2	2017-06-26 07:53:00+03	15000.00
025B04	2017-07-07 19:13:00+03	116000.00
025B0F	2017-08-05 14:47:00+03	24400.00
025B1E	2017-08-14 10:31:00+03	23600.00
025B39	2017-08-14 12:21:00+03	28800.00
025B52	2017-07-13 18:17:00+03	16800.00
025BD1	2017-07-05 18:23:00+03	88900.00
025C11	2017-07-25 04:33:00+03	186900.00
025C14	2017-08-09 09:45:00+03	122500.00
025CCE	2017-08-02 04:18:00+03	57300.00
025DF7	2017-07-30 04:06:00+03	16400.00
025E50	2017-07-25 13:23:00+03	56000.00
025E9C	2017-07-07 13:42:00+03	56000.00
025EB0	2017-08-07 09:31:00+03	41800.00
025F01	2017-07-21 22:44:00+03	68800.00
025FDA	2017-08-13 01:17:00+03	36200.00
02606F	2017-08-12 08:55:00+03	91200.00
026080	2017-07-20 16:26:00+03	92100.00
02609A	2017-07-19 05:17:00+03	54300.00
02610A	2017-08-14 14:13:00+03	16400.00
026156	2017-07-27 13:40:00+03	23200.00
026182	2017-08-09 05:55:00+03	399300.00
02621A	2017-08-07 10:08:00+03	24700.00
0262D6	2017-07-07 13:57:00+03	62600.00
026303	2017-07-17 15:28:00+03	21800.00
02630C	2017-06-29 13:03:00+03	66600.00
026311	2017-07-03 12:18:00+03	119400.00
026325	2017-08-15 04:39:00+03	51800.00
02636D	2017-08-13 20:25:00+03	57700.00
02637B	2017-07-04 19:23:00+03	38600.00
02637F	2017-08-08 06:43:00+03	23600.00
0263D7	2017-08-03 02:27:00+03	73600.00
0263F9	2017-07-26 12:36:00+03	114400.00
026467	2017-08-11 12:07:00+03	30200.00
02648E	2017-07-15 07:10:00+03	356200.00
0264E8	2017-07-24 00:11:00+03	170000.00
02655A	2017-07-27 14:44:00+03	135600.00
026565	2017-07-03 14:47:00+03	29600.00
0265A3	2017-07-24 17:24:00+03	185300.00
02660A	2017-06-30 16:01:00+03	37200.00
02660F	2017-08-10 12:45:00+03	169000.00
02662C	2017-07-11 08:06:00+03	46000.00
026636	2017-07-03 07:33:00+03	81700.00
02664B	2017-07-14 05:19:00+03	46400.00
02664D	2017-08-12 20:46:00+03	21400.00
026676	2017-08-03 08:21:00+03	65500.00
0266DA	2017-07-01 15:07:00+03	266500.00
0266EF	2017-07-24 09:57:00+03	36200.00
026782	2017-07-07 18:54:00+03	59200.00
026789	2017-07-23 07:30:00+03	168200.00
026821	2017-07-27 16:33:00+03	192000.00
026866	2017-07-03 07:02:00+03	26800.00
0268FF	2017-07-23 00:25:00+03	67600.00
02690E	2017-07-27 05:27:00+03	40800.00
026928	2017-08-12 01:03:00+03	95100.00
02693E	2017-07-01 05:34:00+03	64200.00
0269CF	2017-08-12 11:37:00+03	69500.00
0269DE	2017-07-22 14:07:00+03	263200.00
0269F9	2017-08-01 12:29:00+03	12600.00
026A44	2017-07-03 00:52:00+03	19600.00
026A51	2017-07-29 21:04:00+03	64400.00
026A73	2017-08-08 15:06:00+03	10600.00
026AE4	2017-08-04 23:48:00+03	96300.00
026B1D	2017-08-14 07:40:00+03	359400.00
026B7F	2017-07-19 15:29:00+03	131100.00
026BD3	2017-07-12 01:55:00+03	44600.00
026C4C	2017-07-28 07:51:00+03	86300.00
026C73	2017-07-18 10:29:00+03	46900.00
026CDE	2017-07-24 09:30:00+03	49100.00
026E55	2017-08-05 10:47:00+03	73600.00
026E5C	2017-07-09 09:17:00+03	86600.00
026E8C	2017-07-24 12:52:00+03	14400.00
026E98	2017-07-13 13:45:00+03	24400.00
026EF5	2017-08-09 19:15:00+03	277800.00
026F39	2017-08-02 10:34:00+03	160000.00
026F3A	2017-08-02 07:07:00+03	21400.00
026FE2	2017-07-17 12:18:00+03	71500.00
026FFF	2017-07-01 06:34:00+03	16400.00
027044	2017-07-22 04:58:00+03	112100.00
02704D	2017-07-07 07:56:00+03	103500.00
02707D	2017-08-12 05:20:00+03	14000.00
02709C	2017-06-27 15:47:00+03	269600.00
0270DA	2017-07-12 00:43:00+03	70200.00
027158	2017-07-27 22:24:00+03	199200.00
027176	2017-07-22 19:59:00+03	27200.00
0271B6	2017-07-22 20:13:00+03	70800.00
0271CD	2017-07-04 12:54:00+03	23600.00
0271EE	2017-07-07 11:30:00+03	59800.00
0271F2	2017-07-03 01:48:00+03	15900.00
0272A2	2017-07-18 03:18:00+03	49100.00
0272BB	2017-08-01 20:47:00+03	125200.00
027318	2017-08-03 22:12:00+03	96300.00
02732B	2017-08-08 00:26:00+03	166100.00
0273BC	2017-07-19 14:50:00+03	69900.00
02740E	2017-08-07 06:50:00+03	11600.00
027457	2017-07-02 04:56:00+03	55800.00
027511	2017-08-06 03:27:00+03	23600.00
027552	2017-08-07 16:58:00+03	68000.00
02755D	2017-07-16 00:35:00+03	35900.00
027588	2017-08-10 14:22:00+03	21800.00
027598	2017-08-15 01:50:00+03	26000.00
027656	2017-07-11 07:34:00+03	231800.00
02768A	2017-07-30 18:42:00+03	18100.00
0276A4	2017-07-08 02:14:00+03	227400.00
0276D6	2017-07-09 07:16:00+03	96300.00
027727	2017-07-21 23:26:00+03	13200.00
02772D	2017-08-04 00:47:00+03	93900.00
027795	2017-07-31 10:28:00+03	62900.00
0277AB	2017-07-08 04:12:00+03	25600.00
0277BB	2017-07-19 10:10:00+03	70500.00
0277CD	2017-07-18 18:29:00+03	8400.00
027820	2017-07-29 15:53:00+03	37200.00
027837	2017-07-05 01:21:00+03	76200.00
027896	2017-07-29 18:07:00+03	171000.00
0278C5	2017-07-15 02:53:00+03	121400.00
02790D	2017-08-06 09:28:00+03	91600.00
02791D	2017-07-06 11:31:00+03	12400.00
02794C	2017-07-12 10:38:00+03	167400.00
027A21	2017-07-19 19:25:00+03	50600.00
027A50	2017-07-24 23:50:00+03	24000.00
027A90	2017-07-18 11:00:00+03	248300.00
027A94	2017-07-23 05:09:00+03	46400.00
027ABB	2017-08-09 22:03:00+03	112000.00
027B53	2017-07-25 06:53:00+03	46300.00
027BA0	2017-07-08 17:45:00+03	16400.00
027BD6	2017-08-01 18:01:00+03	14000.00
027C87	2017-08-10 15:47:00+03	28600.00
027C8D	2017-07-17 10:52:00+03	36200.00
027C9D	2017-08-13 18:30:00+03	45100.00
027CE2	2017-08-02 19:59:00+03	92800.00
027D90	2017-07-24 04:52:00+03	75800.00
027E14	2017-08-03 03:30:00+03	74200.00
027E31	2017-08-13 14:59:00+03	17100.00
027E6F	2017-08-04 05:54:00+03	111600.00
027EDB	2017-08-03 19:33:00+03	56600.00
027F24	2017-07-09 13:40:00+03	48800.00
027F28	2017-08-11 03:31:00+03	136000.00
027F5E	2017-07-05 22:43:00+03	56000.00
027F88	2017-07-29 07:58:00+03	86500.00
028011	2017-07-07 21:38:00+03	18400.00
02805E	2017-07-30 11:28:00+03	201200.00
0280D2	2017-07-15 00:12:00+03	67600.00
028109	2017-07-16 08:24:00+03	56000.00
02811B	2017-07-27 10:40:00+03	52000.00
028126	2017-07-02 19:11:00+03	23400.00
02815B	2017-08-14 15:50:00+03	173100.00
02819D	2017-07-13 15:52:00+03	22000.00
0281EC	2017-07-02 15:38:00+03	26000.00
02821C	2017-08-09 00:26:00+03	64800.00
028250	2017-06-29 18:32:00+03	33800.00
028263	2017-08-06 12:08:00+03	56600.00
0282D4	2017-08-01 23:28:00+03	128600.00
0282DE	2017-07-11 20:47:00+03	163300.00
028316	2017-07-21 17:17:00+03	136200.00
02831D	2017-07-26 09:03:00+03	106100.00
02834F	2017-07-15 03:58:00+03	23600.00
028377	2017-07-12 09:01:00+03	51900.00
0283F6	2017-08-03 12:31:00+03	56300.00
028414	2017-08-03 17:29:00+03	30700.00
028423	2017-07-25 00:30:00+03	43000.00
02842C	2017-07-21 19:07:00+03	185500.00
028437	2017-08-11 16:29:00+03	48800.00
02843E	2017-07-07 19:49:00+03	122500.00
028447	2017-07-07 15:17:00+03	56600.00
028455	2017-07-10 12:18:00+03	38800.00
02848B	2017-07-01 22:47:00+03	86400.00
02848E	2017-08-06 01:00:00+03	6000.00
0284C6	2017-08-04 06:30:00+03	31600.00
028512	2017-07-25 11:48:00+03	19600.00
02855D	2017-07-06 14:40:00+03	28000.00
0285BC	2017-08-09 05:07:00+03	246000.00
0285FA	2017-07-27 11:46:00+03	24800.00
02861D	2017-08-13 14:37:00+03	6700.00
028644	2017-07-18 00:47:00+03	55000.00
0286BD	2017-07-22 19:41:00+03	95400.00
0286E0	2017-07-08 08:27:00+03	26000.00
028718	2017-07-28 17:51:00+03	45300.00
028721	2017-07-01 15:42:00+03	36000.00
02872E	2017-07-02 12:53:00+03	25400.00
028735	2017-07-19 04:38:00+03	177200.00
028820	2017-08-11 21:17:00+03	67800.00
02888B	2017-07-27 21:26:00+03	40800.00
0288CA	2017-07-30 00:31:00+03	119300.00
028907	2017-08-08 14:32:00+03	27600.00
028995	2017-07-09 00:17:00+03	157600.00
0289D6	2017-08-11 21:53:00+03	56000.00
0289DE	2017-07-28 02:52:00+03	128400.00
0289F2	2017-07-18 09:27:00+03	92200.00
028A71	2017-07-19 16:08:00+03	105000.00
028A7C	2017-07-19 18:54:00+03	13000.00
028AA1	2017-07-28 00:19:00+03	56000.00
028AA4	2017-07-07 16:52:00+03	187600.00
028ABF	2017-08-09 02:11:00+03	81600.00
028AC4	2017-07-11 16:12:00+03	16400.00
028B18	2017-08-14 18:06:00+03	69000.00
028B50	2017-07-06 22:17:00+03	55800.00
028BD6	2017-07-28 04:08:00+03	123000.00
028C5B	2017-07-30 06:10:00+03	91300.00
028C5D	2017-07-29 05:27:00+03	46000.00
028C7F	2017-08-14 10:56:00+03	12400.00
028CBD	2017-07-17 06:38:00+03	60400.00
028CF2	2017-07-02 09:51:00+03	85700.00
028CF6	2017-07-28 13:06:00+03	137200.00
028D4E	2017-07-18 13:57:00+03	36100.00
028D70	2017-08-12 08:56:00+03	43800.00
028D79	2017-07-30 20:07:00+03	26700.00
028DEB	2017-08-07 03:40:00+03	23200.00
028E3B	2017-07-15 01:20:00+03	44500.00
028E4C	2017-07-21 13:48:00+03	46000.00
028F10	2017-07-21 11:14:00+03	260900.00
028F1B	2017-07-02 15:45:00+03	30900.00
028F52	2017-08-01 20:20:00+03	125000.00
028FB3	2017-08-11 16:40:00+03	48800.00
028FBB	2017-07-07 05:34:00+03	25400.00
028FF0	2017-08-13 11:38:00+03	35300.00
028FFA	2017-07-10 09:30:00+03	271100.00
0290A5	2017-08-02 12:11:00+03	26300.00
0290BA	2017-08-12 18:50:00+03	56600.00
029106	2017-07-08 09:03:00+03	155600.00
029139	2017-08-14 05:22:00+03	135400.00
02916C	2017-07-21 01:34:00+03	72300.00
0291DB	2017-08-04 11:23:00+03	31400.00
0291EC	2017-07-01 18:23:00+03	83300.00
02922B	2017-07-07 13:25:00+03	32700.00
02928B	2017-07-27 15:57:00+03	190400.00
0292F2	2017-07-16 05:30:00+03	173500.00
0293C5	2017-08-07 07:19:00+03	23200.00
029401	2017-07-04 10:57:00+03	86400.00
02941C	2017-07-13 07:50:00+03	6800.00
029434	2017-06-30 12:18:00+03	77200.00
02945B	2017-07-12 14:39:00+03	23600.00
02945F	2017-07-09 19:29:00+03	117000.00
0294CB	2017-07-24 08:07:00+03	248300.00
0294E3	2017-07-09 17:18:00+03	51900.00
0294ED	2017-07-07 06:37:00+03	192900.00
0294F1	2017-07-01 08:32:00+03	492000.00
029502	2017-07-12 23:52:00+03	43400.00
029555	2017-07-14 20:43:00+03	128800.00
0295D2	2017-07-03 15:32:00+03	28000.00
02960E	2017-07-15 12:28:00+03	46400.00
029624	2017-07-22 08:05:00+03	6800.00
029626	2017-07-03 18:10:00+03	49800.00
02964F	2017-08-13 13:26:00+03	272400.00
02966A	2017-07-14 04:32:00+03	6700.00
02969A	2017-07-21 14:04:00+03	177800.00
0296B3	2017-07-14 23:55:00+03	104000.00
0296D2	2017-08-13 23:28:00+03	13400.00
0296E7	2017-07-23 23:27:00+03	125200.00
02970C	2017-07-02 23:13:00+03	32700.00
029719	2017-07-28 17:13:00+03	6700.00
029742	2017-08-04 12:48:00+03	123000.00
029758	2017-07-24 16:46:00+03	47000.00
0297BD	2017-07-05 02:28:00+03	81300.00
0297C7	2017-08-10 02:25:00+03	36800.00
0297E8	2017-07-07 06:20:00+03	122000.00
02984F	2017-07-09 22:39:00+03	56000.00
029898	2017-07-15 04:12:00+03	50800.00
0298CD	2017-08-08 13:45:00+03	37900.00
029922	2017-08-14 10:57:00+03	26700.00
029968	2017-08-08 02:18:00+03	30200.00
02996A	2017-07-14 22:50:00+03	40800.00
029976	2017-07-19 01:29:00+03	29600.00
029996	2017-08-13 17:34:00+03	65900.00
02999A	2017-08-13 22:07:00+03	202600.00
029AD5	2017-07-21 09:26:00+03	80700.00
029AE8	2017-07-29 14:19:00+03	230000.00
029B46	2017-07-05 04:48:00+03	44200.00
029B79	2017-07-19 02:50:00+03	105200.00
029B8E	2017-07-28 02:52:00+03	11600.00
029B90	2017-07-21 17:26:00+03	13600.00
029BCC	2017-07-24 19:56:00+03	132800.00
029BD4	2017-07-08 18:51:00+03	111600.00
029C1A	2017-07-06 17:27:00+03	64100.00
029C1C	2017-07-19 12:31:00+03	23400.00
029C7D	2017-07-30 18:08:00+03	14400.00
029C8F	2017-08-08 17:57:00+03	23600.00
029C97	2017-07-13 09:50:00+03	72000.00
029CE2	2017-07-09 21:04:00+03	31600.00
029D10	2017-07-15 03:54:00+03	15900.00
029D1A	2017-07-26 11:32:00+03	72300.00
029D3F	2017-07-08 00:26:00+03	44800.00
029D6D	2017-07-15 03:29:00+03	36000.00
029D70	2017-08-15 05:35:00+03	27600.00
029DB8	2017-07-27 21:14:00+03	57300.00
029DD2	2017-08-03 21:22:00+03	120700.00
029F43	2017-07-27 04:17:00+03	54800.00
029F94	2017-07-17 23:48:00+03	26800.00
029FA2	2017-07-08 13:31:00+03	118900.00
029FAF	2017-07-15 15:35:00+03	30200.00
029FCB	2017-07-28 13:26:00+03	59900.00
02A001	2017-07-27 23:16:00+03	54300.00
02A01A	2017-08-13 15:53:00+03	99200.00
02A067	2017-08-11 17:43:00+03	48400.00
02A06B	2017-07-10 02:49:00+03	12000.00
02A074	2017-08-07 04:40:00+03	118200.00
02A0AE	2017-08-15 14:05:00+03	85700.00
02A0C6	2017-07-08 11:17:00+03	78600.00
02A128	2017-08-01 14:06:00+03	98200.00
02A13B	2017-08-05 23:17:00+03	88100.00
02A20D	2017-07-01 07:38:00+03	36200.00
02A214	2017-08-05 08:55:00+03	148200.00
02A3DF	2017-08-12 11:42:00+03	24000.00
02A40A	2017-08-07 17:42:00+03	85000.00
02A438	2017-06-28 23:44:00+03	68600.00
02A4CE	2017-07-23 23:27:00+03	46300.00
02A4E3	2017-07-02 13:56:00+03	25000.00
02A4E4	2017-07-26 11:52:00+03	133200.00
02A53E	2017-07-10 08:35:00+03	123000.00
02A5AB	2017-08-10 15:52:00+03	68000.00
02A6DF	2017-08-04 07:32:00+03	55800.00
02A753	2017-07-18 07:58:00+03	31600.00
02A75E	2017-07-27 22:56:00+03	21400.00
02A76C	2017-07-20 15:52:00+03	24000.00
02A77D	2017-07-10 21:56:00+03	67200.00
02A88D	2017-07-18 05:27:00+03	149300.00
02A8D3	2017-07-25 04:10:00+03	112600.00
02A942	2017-07-20 00:09:00+03	32900.00
02A985	2017-07-07 14:25:00+03	29400.00
02A990	2017-08-10 21:21:00+03	100000.00
02A99B	2017-07-11 13:14:00+03	274400.00
02AA7A	2017-07-25 20:25:00+03	7300.00
02AB35	2017-08-01 23:24:00+03	108600.00
02AB71	2017-07-11 16:01:00+03	54000.00
02ABB3	2017-07-20 00:12:00+03	61800.00
02ABD3	2017-08-10 23:50:00+03	25100.00
02AC8A	2017-07-28 01:02:00+03	35800.00
02AC95	2017-07-26 05:31:00+03	70700.00
02ACEF	2017-08-15 13:31:00+03	139100.00
02ACFD	2017-07-14 08:48:00+03	38400.00
02AD21	2017-08-04 12:30:00+03	61800.00
02AD46	2017-07-28 00:22:00+03	20400.00
02AD6B	2017-08-14 04:19:00+03	21500.00
02AD70	2017-08-02 18:03:00+03	36200.00
02AD8E	2017-08-13 09:44:00+03	81700.00
02ADCC	2017-07-19 11:36:00+03	67700.00
02AE2E	2017-07-29 21:49:00+03	24000.00
02AE32	2017-08-01 21:56:00+03	48200.00
02AE4D	2017-08-09 15:09:00+03	57600.00
02AEA9	2017-08-09 22:02:00+03	8200.00
02AEC7	2017-07-23 13:05:00+03	26000.00
02AEF6	2017-07-21 16:54:00+03	29600.00
02AF07	2017-07-03 20:06:00+03	124200.00
02AF77	2017-08-02 21:51:00+03	91800.00
02AF83	2017-08-05 08:16:00+03	72000.00
02AFCD	2017-07-15 10:09:00+03	46700.00
02B008	2017-08-02 04:00:00+03	56100.00
02B028	2017-08-15 06:04:00+03	38500.00
02B148	2017-07-13 12:35:00+03	43200.00
02B165	2017-08-01 18:11:00+03	31600.00
02B183	2017-07-20 12:17:00+03	136200.00
02B1DC	2017-08-05 03:15:00+03	123000.00
02B1DE	2017-07-15 15:04:00+03	277300.00
02B1EB	2017-07-21 11:53:00+03	38400.00
02B251	2017-07-22 22:34:00+03	19600.00
02B2D8	2017-08-12 12:29:00+03	80000.00
02B326	2017-07-07 00:31:00+03	11800.00
02B32E	2017-07-27 03:51:00+03	82900.00
02B38F	2017-07-20 15:38:00+03	37200.00
02B3C6	2017-07-21 12:39:00+03	26000.00
02B405	2017-08-01 00:59:00+03	266400.00
02B4D0	2017-06-30 07:56:00+03	70600.00
02B51A	2017-07-04 01:39:00+03	56600.00
02B52A	2017-07-26 08:58:00+03	113000.00
02B66A	2017-07-08 17:02:00+03	89700.00
02B6C7	2017-07-30 05:05:00+03	220500.00
02B6F2	2017-07-16 04:21:00+03	47100.00
02B75A	2017-08-07 10:03:00+03	26600.00
02B7BB	2017-07-12 10:24:00+03	53600.00
02B7C9	2017-07-11 06:38:00+03	23400.00
02B7F6	2017-07-30 03:10:00+03	28800.00
02B80C	2017-07-08 20:59:00+03	15100.00
02B828	2017-08-07 20:11:00+03	167400.00
02B894	2017-07-29 18:54:00+03	113600.00
02B8C8	2017-08-01 17:56:00+03	179400.00
02B94D	2017-08-05 04:38:00+03	86800.00
02B990	2017-07-02 02:14:00+03	79600.00
02B997	2017-07-29 07:47:00+03	28800.00
02B9F4	2017-08-01 14:28:00+03	58800.00
02BA11	2017-07-22 04:17:00+03	23400.00
02BAD6	2017-07-01 02:44:00+03	21800.00
02BB2B	2017-07-04 12:30:00+03	37900.00
02BB6E	2017-07-15 05:18:00+03	6700.00
02BB79	2017-07-12 02:33:00+03	55800.00
02BB99	2017-07-15 05:16:00+03	105000.00
02BBB5	2017-07-07 00:22:00+03	136500.00
02BBD2	2017-08-01 06:25:00+03	71900.00
02BBDA	2017-08-13 21:03:00+03	44800.00
02BBEB	2017-07-06 10:43:00+03	56100.00
02BCA8	2017-07-10 10:04:00+03	92900.00
02BDB4	2017-08-14 11:29:00+03	31600.00
02BDF5	2017-07-22 05:31:00+03	57500.00
02BE2B	2017-07-18 04:16:00+03	58600.00
02BE6C	2017-07-09 09:34:00+03	23600.00
02BE7D	2017-07-12 20:49:00+03	67600.00
02BEA6	2017-07-16 15:43:00+03	23200.00
02BF56	2017-07-14 11:56:00+03	21800.00
02BF75	2017-08-15 14:10:00+03	300800.00
02BFAB	2017-07-05 09:21:00+03	393800.00
02BFBE	2017-08-03 07:39:00+03	19600.00
02BFFD	2017-07-23 22:30:00+03	12400.00
02C01B	2017-07-25 21:31:00+03	85700.00
02C18B	2017-07-11 17:35:00+03	12600.00
02C206	2017-07-28 09:25:00+03	265600.00
02C21F	2017-07-14 10:48:00+03	13400.00
02C2BF	2017-07-02 06:39:00+03	31600.00
02C33D	2017-07-07 20:15:00+03	15000.00
02C346	2017-07-13 22:33:00+03	46300.00
02C369	2017-08-12 14:20:00+03	128800.00
02C3B1	2017-07-19 15:33:00+03	170200.00
02C401	2017-07-05 18:03:00+03	272300.00
02C409	2017-07-24 07:58:00+03	124200.00
02C433	2017-08-08 16:49:00+03	25200.00
02C4B6	2017-07-09 07:20:00+03	28800.00
02C537	2017-08-12 00:40:00+03	143100.00
02C53A	2017-07-24 00:39:00+03	56000.00
02C55D	2017-07-03 05:57:00+03	26600.00
02C588	2017-07-30 06:14:00+03	46400.00
02C595	2017-08-02 20:27:00+03	227400.00
02C5B2	2017-08-14 00:13:00+03	28800.00
02C6AE	2017-06-30 00:31:00+03	125200.00
02C6B9	2017-07-26 05:09:00+03	52400.00
02C6D1	2017-07-06 05:29:00+03	26000.00
02C703	2017-08-08 23:08:00+03	13700.00
02C718	2017-07-08 11:08:00+03	75600.00
02C784	2017-08-08 21:31:00+03	50000.00
02C79E	2017-07-16 13:24:00+03	25400.00
02C825	2017-08-02 01:04:00+03	22000.00
02C88C	2017-08-14 00:16:00+03	38400.00
02C8A8	2017-08-08 00:31:00+03	19600.00
02C8B3	2017-08-14 14:41:00+03	18900.00
02C8D0	2017-06-30 08:10:00+03	21800.00
02C8EC	2017-07-13 19:43:00+03	92800.00
02C95F	2017-07-09 12:05:00+03	303500.00
02C962	2017-07-30 03:22:00+03	14000.00
02C994	2017-07-30 15:00:00+03	35800.00
02C9F8	2017-07-10 21:08:00+03	46400.00
02CA21	2017-07-24 23:47:00+03	281500.00
02CA3D	2017-07-30 20:33:00+03	60900.00
02CA52	2017-08-01 17:49:00+03	46800.00
02CAC0	2017-07-24 13:45:00+03	17000.00
02CAF9	2017-07-19 18:26:00+03	86800.00
02CB91	2017-07-09 14:43:00+03	49500.00
02CC04	2017-08-01 18:03:00+03	37100.00
02CC4C	2017-08-04 14:24:00+03	72400.00
02CCCF	2017-08-07 20:34:00+03	52000.00
02CCE9	2017-08-11 06:30:00+03	254800.00
02CCEC	2017-07-10 06:55:00+03	46400.00
02CD0B	2017-07-31 07:16:00+03	23400.00
02CD0E	2017-07-01 07:42:00+03	111600.00
02CD34	2017-07-05 19:30:00+03	199700.00
02CD51	2017-07-29 10:47:00+03	70700.00
02CD92	2017-08-09 09:50:00+03	24600.00
02CE03	2017-07-10 16:46:00+03	43100.00
02CE4C	2017-08-14 23:50:00+03	13600.00
02CE64	2017-07-09 12:05:00+03	83100.00
02CE80	2017-07-17 01:30:00+03	24800.00
02CE9C	2017-07-11 19:36:00+03	28800.00
02D02B	2017-07-22 04:40:00+03	260900.00
02D051	2017-07-24 11:09:00+03	26000.00
02D0D0	2017-07-03 03:21:00+03	40800.00
02D0DC	2017-07-24 22:35:00+03	63200.00
02D1D0	2017-08-04 19:34:00+03	157200.00
02D23D	2017-07-07 15:55:00+03	91800.00
02D2D2	2017-07-03 04:58:00+03	66800.00
02D2FB	2017-07-03 01:41:00+03	132500.00
02D30F	2017-07-15 17:33:00+03	60400.00
02D314	2017-08-13 21:52:00+03	25000.00
02D316	2017-07-13 20:11:00+03	135400.00
02D370	2017-08-08 04:56:00+03	37000.00
02D3C3	2017-07-21 02:39:00+03	20400.00
02D3DA	2017-08-07 07:07:00+03	34000.00
02D432	2017-08-15 03:43:00+03	14000.00
02D4AE	2017-07-05 13:51:00+03	46000.00
02D4D8	2017-08-08 09:01:00+03	62700.00
02D508	2017-08-10 23:11:00+03	28800.00
02D54E	2017-08-15 01:52:00+03	28800.00
02D5F6	2017-08-01 05:06:00+03	75600.00
02D614	2017-07-16 06:10:00+03	70600.00
02D641	2017-07-24 15:33:00+03	105400.00
02D6B0	2017-08-02 10:55:00+03	67800.00
02D6C3	2017-07-19 18:25:00+03	70700.00
02D6E2	2017-07-27 12:41:00+03	30000.00
02D6E7	2017-08-15 15:09:00+03	108900.00
02D6FE	2017-07-10 17:37:00+03	133200.00
02D727	2017-07-18 05:37:00+03	71300.00
02D738	2017-08-08 23:28:00+03	8400.00
02D74A	2017-07-28 22:03:00+03	68900.00
02D753	2017-06-30 09:37:00+03	206200.00
02D7E5	2017-07-23 22:46:00+03	248400.00
02D800	2017-07-13 21:06:00+03	65500.00
02D854	2017-07-06 20:27:00+03	105600.00
02D884	2017-08-01 19:59:00+03	58800.00
02D88E	2017-07-17 08:11:00+03	69500.00
02D92F	2017-07-16 18:25:00+03	39300.00
02DA2A	2017-08-09 03:09:00+03	76600.00
02DABA	2017-08-12 04:45:00+03	27200.00
02DAD7	2017-07-23 02:28:00+03	68100.00
02DB6F	2017-08-04 00:29:00+03	44800.00
02DB7D	2017-07-21 03:02:00+03	111600.00
02DC5E	2017-08-06 05:28:00+03	66600.00
02DC60	2017-08-13 22:29:00+03	39500.00
02DCB7	2017-08-13 08:17:00+03	37600.00
02DCF3	2017-07-20 21:15:00+03	65900.00
02DD54	2017-07-16 13:00:00+03	23600.00
02DD88	2017-08-15 10:51:00+03	21600.00
02DD89	2017-07-20 23:28:00+03	45200.00
02DDB8	2017-07-17 12:11:00+03	175300.00
02DDC5	2017-08-11 13:34:00+03	15400.00
02DDDD	2017-07-31 01:20:00+03	196800.00
02DE2C	2017-07-07 13:16:00+03	241300.00
02DE6C	2017-07-29 08:35:00+03	102100.00
02DEC3	2017-07-01 16:37:00+03	26000.00
02DEC4	2017-07-10 16:02:00+03	413600.00
02DEF1	2017-08-10 06:09:00+03	138000.00
02DF12	2017-07-04 19:15:00+03	12600.00
02DF5D	2017-07-23 10:01:00+03	23600.00
02DF95	2017-08-09 15:55:00+03	209000.00
02E019	2017-07-13 00:53:00+03	6000.00
02E086	2017-08-03 14:45:00+03	13200.00
02E091	2017-07-30 13:25:00+03	167500.00
02E180	2017-07-28 08:15:00+03	56000.00
02E1A4	2017-08-02 03:34:00+03	58200.00
02E1D8	2017-07-15 01:51:00+03	179200.00
02E1DD	2017-07-09 23:25:00+03	27400.00
02E1FE	2017-08-15 08:11:00+03	25100.00
02E230	2017-07-23 02:51:00+03	27200.00
02E245	2017-08-01 12:48:00+03	36200.00
02E25D	2017-07-14 13:43:00+03	73200.00
02E2C9	2017-07-06 00:07:00+03	35400.00
02E2DC	2017-07-01 16:52:00+03	20800.00
02E2DD	2017-07-11 00:10:00+03	135400.00
02E35C	2017-07-08 12:34:00+03	32800.00
02E3B8	2017-08-12 23:52:00+03	106400.00
02E3C9	2017-07-16 02:26:00+03	6300.00
02E3E4	2017-07-24 05:29:00+03	10600.00
02E446	2017-07-18 10:57:00+03	81600.00
02E498	2017-07-18 02:40:00+03	55800.00
02E4E0	2017-08-14 19:24:00+03	133200.00
02E4FA	2017-08-13 14:34:00+03	56900.00
02E513	2017-08-11 02:54:00+03	133100.00
02E55D	2017-07-16 20:39:00+03	169300.00
02E563	2017-07-07 20:58:00+03	26200.00
02E5FE	2017-08-03 15:17:00+03	73400.00
02E64F	2017-07-15 02:54:00+03	39300.00
02E66A	2017-07-08 02:15:00+03	58400.00
02E686	2017-08-04 20:37:00+03	23200.00
02E6B6	2017-07-06 21:39:00+03	6700.00
02E75A	2017-07-23 17:42:00+03	271300.00
02E7AD	2017-07-01 10:59:00+03	50600.00
02E7AF	2017-08-14 14:20:00+03	21800.00
02E80A	2017-07-14 09:55:00+03	167400.00
02E80D	2017-07-17 06:37:00+03	6000.00
02E8E1	2017-07-04 11:06:00+03	129200.00
02E929	2017-07-17 08:36:00+03	55400.00
02E947	2017-08-06 23:59:00+03	53600.00
02E951	2017-07-28 04:04:00+03	123000.00
02E966	2017-07-04 10:16:00+03	90300.00
02E9EC	2017-08-02 01:38:00+03	177600.00
02E9F3	2017-07-31 11:59:00+03	132800.00
02EA09	2017-07-31 04:47:00+03	666000.00
02EA32	2017-07-08 15:00:00+03	59300.00
02EA84	2017-07-08 08:58:00+03	58000.00
02EABE	2017-08-04 07:42:00+03	12600.00
02EB27	2017-08-04 18:39:00+03	55800.00
02EB91	2017-07-03 08:08:00+03	19600.00
02EBEF	2017-07-05 12:34:00+03	22000.00
02EC0E	2017-08-08 12:32:00+03	99300.00
02EC40	2017-07-20 17:37:00+03	301800.00
02EC79	2017-07-11 18:19:00+03	46400.00
02ECB2	2017-07-12 21:43:00+03	31100.00
02ECBD	2017-07-14 13:59:00+03	78300.00
02ECD3	2017-08-07 09:26:00+03	11300.00
02ECD8	2017-07-20 09:27:00+03	26800.00
02ED31	2017-08-09 04:36:00+03	223200.00
02ED51	2017-07-28 19:00:00+03	95600.00
02EDEA	2017-07-21 03:24:00+03	399600.00
02EE23	2017-07-28 10:41:00+03	54700.00
02EE73	2017-07-22 05:36:00+03	12600.00
02EE8A	2017-07-27 04:10:00+03	26000.00
02EEAA	2017-08-08 05:22:00+03	28300.00
02EEE8	2017-07-28 13:35:00+03	51600.00
02EF24	2017-07-02 20:53:00+03	68000.00
02EFF8	2017-07-27 19:40:00+03	24600.00
02F02D	2017-07-26 20:32:00+03	144700.00
02F05C	2017-08-10 09:28:00+03	56000.00
02F0B5	2017-08-14 15:02:00+03	45100.00
02F15E	2017-07-20 15:54:00+03	81200.00
02F1EC	2017-07-01 16:07:00+03	25200.00
02F298	2017-07-18 23:21:00+03	20000.00
02F2AA	2017-07-24 10:40:00+03	83600.00
02F309	2017-08-14 05:15:00+03	189800.00
02F348	2017-08-10 18:49:00+03	23200.00
02F349	2017-08-13 21:38:00+03	176800.00
02F36E	2017-07-12 08:53:00+03	131600.00
02F372	2017-06-29 20:46:00+03	100600.00
02F3B8	2017-06-29 10:05:00+03	27200.00
02F3E3	2017-07-19 03:29:00+03	43000.00
02F3F4	2017-07-29 06:11:00+03	28800.00
02F402	2017-08-12 09:43:00+03	88600.00
02F40F	2017-07-29 05:56:00+03	28000.00
02F425	2017-07-05 03:27:00+03	179700.00
02F486	2017-07-20 13:46:00+03	111600.00
02F4CE	2017-08-03 23:37:00+03	165000.00
02F518	2017-07-15 04:31:00+03	32700.00
02F53B	2017-07-19 18:50:00+03	57500.00
02F54F	2017-07-30 08:45:00+03	40800.00
02F563	2017-07-12 19:07:00+03	89600.00
02F589	2017-07-06 00:05:00+03	55800.00
02F5F4	2017-07-25 07:17:00+03	56600.00
02F66C	2017-08-04 23:31:00+03	46300.00
02F6EC	2017-07-27 15:52:00+03	51900.00
02F6FF	2017-08-08 06:44:00+03	36200.00
02F708	2017-08-01 21:53:00+03	17200.00
02F712	2017-07-26 14:49:00+03	57600.00
02F736	2017-07-07 03:35:00+03	127500.00
02F758	2017-07-23 20:36:00+03	64900.00
02F78A	2017-08-07 00:48:00+03	56000.00
02F7DD	2017-08-10 05:38:00+03	13600.00
02F7E5	2017-08-13 10:40:00+03	26000.00
02F803	2017-07-13 00:43:00+03	196800.00
02F88F	2017-08-08 21:01:00+03	79600.00
02F894	2017-07-13 18:34:00+03	40800.00
02F8BE	2017-08-03 01:22:00+03	92400.00
02F8D0	2017-07-20 12:47:00+03	89200.00
02F8D7	2017-08-03 11:16:00+03	72300.00
02F945	2017-07-29 12:05:00+03	26900.00
02F9CD	2017-07-31 01:43:00+03	97100.00
02FA47	2017-08-10 15:12:00+03	91500.00
02FA75	2017-08-03 03:11:00+03	85500.00
02FA85	2017-07-21 18:15:00+03	12600.00
02FA8E	2017-07-26 07:26:00+03	30200.00
02FB03	2017-08-01 11:14:00+03	21600.00
02FB09	2017-07-13 04:26:00+03	92400.00
02FBC6	2017-08-12 22:20:00+03	29200.00
02FBCE	2017-07-22 19:45:00+03	341900.00
02FBE5	2017-07-25 18:46:00+03	59800.00
02FC66	2017-07-03 15:12:00+03	63500.00
02FD54	2017-07-06 12:05:00+03	38600.00
02FDBB	2017-07-01 15:18:00+03	69500.00
02FDEA	2017-08-15 10:14:00+03	32800.00
02FE49	2017-08-09 05:42:00+03	35200.00
02FF3E	2017-07-07 08:14:00+03	6800.00
02FF6E	2017-07-18 02:53:00+03	23200.00
02FF73	2017-08-12 11:05:00+03	48400.00
02FFB6	2017-07-19 02:28:00+03	152900.00
03008D	2017-07-18 12:37:00+03	115900.00
03013E	2017-08-12 08:12:00+03	46400.00
03014C	2017-08-13 01:57:00+03	14800.00
03016C	2017-07-10 04:11:00+03	67600.00
0301AB	2017-07-25 16:18:00+03	178800.00
0301AF	2017-08-05 23:21:00+03	28000.00
0301B8	2017-07-18 12:28:00+03	19500.00
0301C3	2017-07-09 15:22:00+03	23400.00
0301D5	2017-07-09 00:44:00+03	124300.00
03023B	2017-07-24 12:44:00+03	55800.00
03025E	2017-07-18 22:58:00+03	85700.00
030273	2017-07-14 11:25:00+03	23400.00
030284	2017-07-03 17:20:00+03	149300.00
03028D	2017-08-10 19:51:00+03	34100.00
0302C8	2017-07-02 21:15:00+03	12600.00
0302EE	2017-07-31 14:05:00+03	23600.00
03035D	2017-08-09 19:50:00+03	23200.00
030366	2017-07-26 10:26:00+03	179200.00
030372	2017-07-21 07:29:00+03	37900.00
0303CF	2017-07-31 10:13:00+03	24400.00
0303DD	2017-07-06 05:44:00+03	56200.00
0303E3	2017-08-03 06:53:00+03	60400.00
0303EE	2017-07-28 22:45:00+03	46500.00
03044E	2017-07-05 02:04:00+03	117800.00
03046B	2017-08-12 11:48:00+03	15800.00
030473	2017-07-29 19:35:00+03	86300.00
030493	2017-07-28 00:16:00+03	332100.00
0304C4	2017-08-06 12:31:00+03	248400.00
030549	2017-07-21 18:25:00+03	45200.00
030595	2017-07-10 21:23:00+03	70800.00
0305BF	2017-08-10 03:16:00+03	51900.00
0305C6	2017-07-07 03:50:00+03	283100.00
0305D4	2017-08-15 12:34:00+03	23400.00
0305F1	2017-07-09 19:48:00+03	58400.00
030628	2017-07-23 12:02:00+03	117000.00
0306AC	2017-07-02 15:37:00+03	20200.00
0306D0	2017-07-27 06:35:00+03	48800.00
0306FB	2017-08-11 22:52:00+03	100600.00
030712	2017-07-10 07:14:00+03	22000.00
03072F	2017-08-04 15:55:00+03	28000.00
030747	2017-08-06 14:43:00+03	99200.00
0307B7	2017-07-26 15:49:00+03	187900.00
0307E6	2017-08-15 14:37:00+03	72400.00
0307F3	2017-07-29 12:21:00+03	97200.00
03082A	2017-08-06 10:46:00+03	97900.00
03090F	2017-08-06 14:30:00+03	67600.00
030968	2017-07-24 02:51:00+03	265700.00
030988	2017-07-14 19:21:00+03	45200.00
0309DE	2017-07-26 22:48:00+03	58400.00
030A63	2017-07-27 23:23:00+03	46000.00
030A89	2017-07-13 19:14:00+03	21200.00
030A99	2017-07-05 15:33:00+03	66600.00
030AAE	2017-08-02 03:17:00+03	65000.00
030AD9	2017-07-19 09:45:00+03	57600.00
030AE8	2017-07-22 05:27:00+03	39600.00
030B12	2017-07-22 14:07:00+03	102200.00
030B3B	2017-07-29 14:12:00+03	23600.00
030B52	2017-07-07 19:14:00+03	102600.00
030BBE	2017-07-15 19:23:00+03	55800.00
030BC2	2017-07-17 00:46:00+03	53300.00
030BD2	2017-08-10 16:46:00+03	37900.00
030CD0	2017-07-31 20:38:00+03	63000.00
030CFE	2017-07-08 20:32:00+03	55800.00
030D04	2017-07-02 13:58:00+03	87700.00
030DEA	2017-07-24 05:11:00+03	63500.00
030E1B	2017-07-26 23:58:00+03	52400.00
030E2F	2017-07-04 11:09:00+03	26000.00
030E74	2017-08-05 19:54:00+03	56000.00
030EA2	2017-08-12 23:42:00+03	40000.00
030EAF	2017-08-02 22:06:00+03	92800.00
030F41	2017-07-03 11:48:00+03	173300.00
030F75	2017-08-08 15:13:00+03	97600.00
030F7F	2017-07-13 02:50:00+03	48100.00
030FDF	2017-07-03 02:22:00+03	32700.00
030FEC	2017-07-04 23:18:00+03	12000.00
030FF8	2017-08-05 17:27:00+03	119800.00
0310B2	2017-08-11 15:21:00+03	131100.00
0310E0	2017-07-23 03:10:00+03	6400.00
0310FA	2017-07-11 13:28:00+03	43800.00
031123	2017-08-09 13:37:00+03	25600.00
031125	2017-08-01 21:41:00+03	135600.00
031161	2017-07-18 17:11:00+03	133100.00
03118C	2017-08-10 03:57:00+03	238900.00
0311B0	2017-07-16 11:20:00+03	30900.00
03120B	2017-08-02 16:24:00+03	119200.00
031273	2017-08-03 20:47:00+03	24000.00
0312AC	2017-07-29 20:56:00+03	7200.00
0312D2	2017-07-22 22:02:00+03	114800.00
0312E5	2017-07-09 05:22:00+03	56000.00
03134A	2017-07-13 23:32:00+03	298600.00
0313A6	2017-08-01 05:28:00+03	68100.00
0313E9	2017-07-08 15:48:00+03	84100.00
031412	2017-07-28 01:29:00+03	145100.00
03141B	2017-07-21 20:03:00+03	114500.00
031428	2017-07-29 12:21:00+03	73500.00
031446	2017-08-11 09:14:00+03	55800.00
031498	2017-08-01 22:43:00+03	41400.00
031526	2017-07-15 09:12:00+03	6700.00
031570	2017-07-09 14:05:00+03	14000.00
0315C2	2017-07-27 10:52:00+03	35200.00
031613	2017-07-30 07:55:00+03	13400.00
03163E	2017-07-30 18:46:00+03	21800.00
031672	2017-07-17 10:22:00+03	128800.00
031699	2017-07-17 21:17:00+03	39500.00
031721	2017-07-31 19:28:00+03	68400.00
031726	2017-07-09 08:15:00+03	48800.00
0317B7	2017-08-05 17:33:00+03	56600.00
0317C4	2017-07-24 15:44:00+03	70600.00
0317DE	2017-07-10 13:04:00+03	14000.00
031803	2017-08-13 20:43:00+03	160200.00
03180E	2017-07-11 19:21:00+03	28000.00
031836	2017-07-12 12:45:00+03	15400.00
031847	2017-08-01 21:26:00+03	140900.00
03184C	2017-06-27 18:23:00+03	92700.00
031894	2017-07-27 01:02:00+03	70000.00
0318A8	2017-07-20 14:27:00+03	13800.00
03196A	2017-07-03 08:46:00+03	30200.00
031994	2017-07-13 19:18:00+03	83400.00
031998	2017-07-14 10:32:00+03	115900.00
0319AD	2017-07-13 06:11:00+03	151800.00
0319C3	2017-08-01 18:32:00+03	98000.00
0319D9	2017-07-31 11:07:00+03	25000.00
0319ED	2017-08-11 14:09:00+03	14000.00
031A7D	2017-07-14 07:06:00+03	38000.00
031AE2	2017-08-15 02:34:00+03	92300.00
031B2A	2017-08-01 12:09:00+03	21400.00
031B74	2017-07-24 22:03:00+03	58600.00
031BAD	2017-07-30 15:08:00+03	103900.00
031BC0	2017-06-26 01:00:00+03	46000.00
031BD4	2017-07-10 05:52:00+03	96800.00
031C38	2017-08-05 08:15:00+03	64700.00
031C4B	2017-07-06 09:08:00+03	27900.00
031C66	2017-07-05 18:46:00+03	23100.00
031C6B	2017-08-06 17:23:00+03	120800.00
031CA5	2017-07-11 10:26:00+03	26000.00
031CB5	2017-07-26 06:01:00+03	6800.00
031CDF	2017-08-07 08:46:00+03	76900.00
031CFA	2017-07-13 01:13:00+03	65900.00
031CFF	2017-07-13 11:16:00+03	65900.00
031D27	2017-08-04 01:04:00+03	38600.00
031D29	2017-07-19 00:22:00+03	111600.00
031D75	2017-07-09 10:22:00+03	54800.00
031E39	2017-08-09 04:52:00+03	93900.00
031E5E	2017-08-11 05:00:00+03	161400.00
031E95	2017-06-24 09:28:00+03	46400.00
031F1C	2017-08-09 02:02:00+03	23200.00
031F4A	2017-08-10 08:33:00+03	43800.00
031F5A	2017-07-14 05:07:00+03	112000.00
031FE5	2017-08-04 01:46:00+03	23400.00
032044	2017-07-21 22:46:00+03	199700.00
032080	2017-07-14 07:48:00+03	14000.00
032101	2017-07-17 10:03:00+03	176400.00
032115	2017-08-03 03:57:00+03	56600.00
032128	2017-07-18 09:50:00+03	35700.00
032180	2017-06-29 18:46:00+03	174600.00
03219C	2017-07-12 14:35:00+03	27400.00
032231	2017-06-27 15:09:00+03	71900.00
032232	2017-07-10 14:42:00+03	23400.00
03226E	2017-08-02 02:24:00+03	44000.00
0322A5	2017-08-13 11:46:00+03	83000.00
0322CD	2017-08-15 11:48:00+03	37600.00
0322D9	2017-07-22 23:50:00+03	30000.00
0322E0	2017-08-06 01:55:00+03	76600.00
03242D	2017-08-01 21:08:00+03	30000.00
032497	2017-08-06 04:09:00+03	59300.00
0324B3	2017-07-26 08:04:00+03	65900.00
0324B4	2017-07-25 11:18:00+03	108100.00
0324D7	2017-07-01 16:05:00+03	112000.00
0324E7	2017-07-02 10:40:00+03	32700.00
03258B	2017-07-15 20:55:00+03	73000.00
032630	2017-07-16 16:30:00+03	246000.00
032632	2017-08-14 00:42:00+03	84700.00
03266B	2017-07-06 01:18:00+03	28000.00
03266D	2017-08-07 00:03:00+03	26700.00
0326C9	2017-08-06 17:06:00+03	28800.00
03275E	2017-07-23 03:51:00+03	124100.00
032783	2017-08-10 12:33:00+03	21400.00
032796	2017-08-08 03:19:00+03	98400.00
0327A7	2017-07-15 11:09:00+03	81200.00
0327CC	2017-07-23 22:18:00+03	42800.00
03284C	2017-08-15 00:04:00+03	79700.00
032860	2017-08-12 21:37:00+03	122600.00
0328B0	2017-07-08 15:47:00+03	58000.00
0328BE	2017-07-09 15:36:00+03	54100.00
0328CF	2017-07-19 21:11:00+03	44600.00
0328DD	2017-08-03 13:54:00+03	126300.00
0328E3	2017-07-12 09:40:00+03	13600.00
03290F	2017-07-20 14:18:00+03	38600.00
032A1E	2017-07-19 11:56:00+03	78600.00
032A83	2017-07-26 04:25:00+03	8000.00
032B15	2017-07-30 23:28:00+03	10800.00
032B1C	2017-07-16 19:43:00+03	24400.00
032B98	2017-07-21 06:16:00+03	25800.00
032B99	2017-07-10 04:51:00+03	44800.00
032BB4	2017-07-23 22:04:00+03	75600.00
032BB7	2017-07-07 14:32:00+03	72400.00
032BF8	2017-08-06 05:22:00+03	31600.00
032C5E	2017-07-15 12:42:00+03	189200.00
032CB7	2017-07-24 13:13:00+03	23400.00
032CD1	2017-07-29 05:06:00+03	114500.00
032D09	2017-08-12 01:13:00+03	149300.00
032D37	2017-08-11 23:47:00+03	31200.00
032D3E	2017-07-08 05:42:00+03	20200.00
032E0B	2017-08-09 09:09:00+03	39000.00
032EAF	2017-08-10 00:24:00+03	40900.00
032F02	2017-07-10 04:21:00+03	56600.00
032FA5	2017-07-16 15:20:00+03	22000.00
032FB1	2017-08-09 03:51:00+03	56000.00
033035	2017-08-08 19:01:00+03	15900.00
033083	2017-07-09 22:02:00+03	58800.00
03309C	2017-06-27 11:58:00+03	29600.00
03310E	2017-07-28 19:47:00+03	173900.00
033144	2017-08-02 06:24:00+03	8800.00
03314E	2017-08-10 08:33:00+03	268800.00
033183	2017-08-05 20:34:00+03	22000.00
033192	2017-08-04 17:20:00+03	111600.00
0331D9	2017-08-04 16:34:00+03	68000.00
0331E8	2017-07-17 21:26:00+03	23200.00
033218	2017-07-04 16:08:00+03	22000.00
03321D	2017-07-30 08:41:00+03	159100.00
033265	2017-08-13 19:22:00+03	33800.00
0332A8	2017-07-26 00:07:00+03	21600.00
033372	2017-08-04 06:22:00+03	88100.00
033385	2017-07-05 08:35:00+03	33400.00
033390	2017-08-12 04:52:00+03	93900.00
033394	2017-07-17 20:21:00+03	6000.00
0333E3	2017-07-31 04:04:00+03	24400.00
033414	2017-08-03 05:17:00+03	134400.00
033436	2017-07-29 15:33:00+03	71900.00
033458	2017-08-07 11:19:00+03	70700.00
0334FD	2017-07-02 03:19:00+03	30900.00
033510	2017-07-28 16:16:00+03	67700.00
033537	2017-07-16 08:48:00+03	67000.00
03353C	2017-07-02 00:32:00+03	154400.00
0335D2	2017-08-15 03:19:00+03	272400.00
03367A	2017-07-17 12:20:00+03	68900.00
03368D	2017-08-09 09:35:00+03	46400.00
03369D	2017-08-06 12:21:00+03	44800.00
0336E0	2017-08-14 04:40:00+03	8000.00
0336F4	2017-07-14 09:35:00+03	28800.00
033716	2017-08-12 05:36:00+03	68400.00
033720	2017-08-12 19:18:00+03	14400.00
033733	2017-08-10 11:10:00+03	15400.00
033774	2017-07-04 07:29:00+03	20000.00
0337A0	2017-08-03 05:07:00+03	24400.00
0337CF	2017-07-17 09:55:00+03	286800.00
03380C	2017-07-16 18:20:00+03	66600.00
03380D	2017-08-05 05:07:00+03	179400.00
033844	2017-08-01 03:48:00+03	40400.00
033848	2017-07-07 13:21:00+03	40600.00
03387D	2017-08-07 22:18:00+03	55800.00
033883	2017-07-24 02:39:00+03	53300.00
033929	2017-08-14 17:10:00+03	182200.00
033932	2017-07-16 17:22:00+03	135400.00
03394D	2017-07-03 16:45:00+03	24400.00
033961	2017-07-02 09:41:00+03	15700.00
0339F4	2017-07-15 11:02:00+03	26000.00
0339FC	2017-07-09 00:22:00+03	46800.00
033A10	2017-08-05 17:40:00+03	234700.00
033A12	2017-07-28 05:38:00+03	61200.00
033A87	2017-07-24 18:13:00+03	58400.00
033B0C	2017-07-21 16:59:00+03	109400.00
033B29	2017-07-09 23:31:00+03	73600.00
033B40	2017-08-08 06:58:00+03	56600.00
033BD1	2017-07-31 06:56:00+03	92000.00
033BE7	2017-07-28 09:53:00+03	187200.00
033BE8	2017-08-06 08:45:00+03	130200.00
033C00	2017-07-16 04:14:00+03	23600.00
033CAE	2017-06-29 01:26:00+03	25600.00
033CB9	2017-07-12 19:54:00+03	50800.00
033CCD	2017-06-30 17:00:00+03	132800.00
033CCF	2017-08-02 11:48:00+03	115400.00
033CE2	2017-07-28 17:18:00+03	111600.00
033D22	2017-07-13 17:14:00+03	185300.00
033D40	2017-07-03 01:16:00+03	58100.00
033D6B	2017-07-13 01:54:00+03	36200.00
033DCE	2017-08-01 08:38:00+03	51900.00
033DF1	2017-07-06 16:32:00+03	28000.00
033E10	2017-07-07 19:11:00+03	92000.00
033E39	2017-08-10 18:46:00+03	6600.00
033E82	2017-08-07 00:18:00+03	22000.00
033EEE	2017-07-05 14:01:00+03	46400.00
033EF4	2017-07-29 14:03:00+03	55800.00
033F6B	2017-08-09 09:53:00+03	90600.00
033FBE	2017-07-27 15:05:00+03	28000.00
0340E6	2017-07-11 20:52:00+03	332100.00
03410A	2017-07-12 07:17:00+03	43100.00
034143	2017-07-22 18:18:00+03	76100.00
0341A5	2017-08-07 10:19:00+03	54000.00
03421B	2017-08-06 02:41:00+03	107700.00
0342CD	2017-08-05 01:59:00+03	8000.00
03432F	2017-08-10 17:33:00+03	123000.00
034354	2017-08-03 01:13:00+03	477700.00
034367	2017-07-04 16:44:00+03	265700.00
03436D	2017-07-09 06:37:00+03	27300.00
034379	2017-07-02 17:51:00+03	81800.00
0343AB	2017-07-27 04:54:00+03	119500.00
034426	2017-07-09 00:53:00+03	80000.00
034427	2017-07-04 22:34:00+03	37100.00
03446F	2017-08-13 10:23:00+03	23600.00
034472	2017-08-06 04:33:00+03	87200.00
0344CC	2017-07-10 11:11:00+03	66000.00
034516	2017-08-07 09:12:00+03	74800.00
034581	2017-07-21 05:04:00+03	26800.00
0345C3	2017-08-06 02:28:00+03	40000.00
0345CA	2017-07-19 18:32:00+03	50200.00
0345F9	2017-08-05 13:49:00+03	56000.00
034602	2017-07-08 13:00:00+03	46200.00
03460D	2017-07-06 12:43:00+03	133100.00
03464C	2017-07-02 00:40:00+03	132800.00
03464F	2017-07-14 08:55:00+03	28800.00
0346A0	2017-07-29 13:20:00+03	50600.00
034758	2017-08-07 12:07:00+03	38200.00
03477D	2017-07-08 14:00:00+03	133900.00
0347E9	2017-07-11 04:05:00+03	67900.00
034802	2017-07-26 03:31:00+03	29600.00
034812	2017-08-05 13:07:00+03	113700.00
03481E	2017-08-14 11:26:00+03	24400.00
034838	2017-07-22 14:39:00+03	8400.00
03491E	2017-07-24 15:54:00+03	138600.00
0349A9	2017-08-10 14:43:00+03	38800.00
034A06	2017-08-01 12:43:00+03	76200.00
034A52	2017-08-03 12:24:00+03	60700.00
034A6C	2017-08-02 22:13:00+03	16400.00
034B05	2017-07-28 08:17:00+03	27200.00
034B11	2017-08-01 04:21:00+03	386400.00
034B1A	2017-08-12 07:30:00+03	124200.00
034C3D	2017-08-14 02:31:00+03	65100.00
034C46	2017-07-19 16:06:00+03	30400.00
034C4D	2017-07-29 06:41:00+03	91000.00
034CBB	2017-07-27 00:53:00+03	96800.00
034D2E	2017-07-24 08:19:00+03	394400.00
034DA1	2017-07-27 13:57:00+03	135200.00
034DF3	2017-08-14 08:58:00+03	171400.00
034E4A	2017-07-08 05:21:00+03	298500.00
034E7D	2017-07-30 13:42:00+03	44000.00
034ED0	2017-07-12 23:29:00+03	73500.00
034F38	2017-07-20 17:12:00+03	53400.00
034F85	2017-07-12 23:01:00+03	16400.00
034FBF	2017-08-10 18:37:00+03	52900.00
034FE2	2017-07-11 02:40:00+03	28000.00
03505E	2017-07-28 23:16:00+03	28000.00
035088	2017-07-03 09:28:00+03	51900.00
0350C5	2017-07-12 05:49:00+03	25100.00
0350D3	2017-07-04 03:23:00+03	25600.00
0350E4	2017-07-13 08:17:00+03	38800.00
035115	2017-07-14 14:35:00+03	128800.00
03512A	2017-07-17 19:16:00+03	6700.00
0351B8	2017-08-06 12:15:00+03	24400.00
035218	2017-08-03 01:32:00+03	38400.00
035255	2017-07-13 06:02:00+03	38400.00
03525E	2017-08-13 10:32:00+03	21400.00
035281	2017-07-02 09:55:00+03	116900.00
03533A	2017-07-17 08:56:00+03	43900.00
035391	2017-07-18 01:41:00+03	6800.00
035398	2017-08-04 03:49:00+03	113600.00
0353C6	2017-07-29 00:02:00+03	201200.00
035429	2017-08-05 09:20:00+03	83000.00
03545E	2017-08-01 05:14:00+03	20200.00
0354C0	2017-07-12 14:37:00+03	66800.00
035516	2017-07-03 01:35:00+03	55800.00
035528	2017-08-02 02:43:00+03	147900.00
035542	2017-07-16 17:31:00+03	85000.00
03561D	2017-08-02 06:07:00+03	67600.00
035620	2017-07-08 15:13:00+03	99100.00
035677	2017-07-07 18:00:00+03	78600.00
0356C2	2017-07-25 05:26:00+03	124200.00
035785	2017-07-31 03:09:00+03	68800.00
0357A0	2017-08-05 08:37:00+03	60400.00
0357ED	2017-08-12 14:47:00+03	73200.00
0357F4	2017-08-06 18:25:00+03	90800.00
0358AE	2017-07-22 15:43:00+03	37900.00
035908	2017-07-24 11:57:00+03	13400.00
035937	2017-07-19 14:36:00+03	123000.00
035982	2017-07-28 00:55:00+03	76200.00
0359C3	2017-06-29 17:09:00+03	32800.00
0359EA	2017-07-01 11:08:00+03	72400.00
035A6E	2017-07-17 23:47:00+03	28000.00
035AEC	2017-08-15 13:11:00+03	266400.00
035BCD	2017-07-29 10:38:00+03	41800.00
035C33	2017-07-14 01:47:00+03	40800.00
035D0A	2017-08-04 03:41:00+03	295400.00
035E10	2017-08-04 01:32:00+03	173900.00
035E33	2017-07-02 01:44:00+03	114800.00
035E4A	2017-07-21 21:00:00+03	134800.00
035E5C	2017-07-06 19:47:00+03	258500.00
035E75	2017-07-03 17:46:00+03	58600.00
035EFF	2017-07-20 15:04:00+03	28800.00
035F04	2017-08-11 12:48:00+03	33600.00
035FBA	2017-08-04 18:29:00+03	7400.00
035FD1	2017-07-06 14:10:00+03	114900.00
036043	2017-07-25 00:53:00+03	31400.00
03604F	2017-07-15 04:25:00+03	65500.00
03605B	2017-07-02 16:17:00+03	68800.00
0360E5	2017-08-13 08:31:00+03	112000.00
036115	2017-06-26 06:17:00+03	149000.00
036143	2017-07-02 20:26:00+03	111600.00
03614E	2017-07-13 18:00:00+03	42400.00
0361AB	2017-07-25 00:37:00+03	23400.00
03620F	2017-08-02 11:06:00+03	218200.00
036218	2017-08-02 06:48:00+03	52100.00
03624C	2017-08-04 01:53:00+03	67400.00
03627E	2017-07-26 02:52:00+03	90800.00
0362AB	2017-07-11 22:32:00+03	155600.00
0362ED	2017-08-14 01:34:00+03	21800.00
036317	2017-07-18 07:13:00+03	59800.00
036339	2017-08-12 01:54:00+03	65200.00
03633C	2017-07-18 22:55:00+03	258400.00
036398	2017-08-15 00:20:00+03	23900.00
0363D1	2017-07-27 02:29:00+03	32200.00
0363F7	2017-07-22 09:34:00+03	131100.00
0364C5	2017-08-07 17:21:00+03	73300.00
0364E0	2017-08-15 17:59:00+03	12600.00
0365E4	2017-07-27 06:23:00+03	94400.00
036615	2017-07-27 08:57:00+03	51600.00
036642	2017-07-21 15:30:00+03	64700.00
036659	2017-08-10 15:09:00+03	87400.00
036699	2017-07-08 19:24:00+03	12400.00
0366FA	2017-07-13 23:19:00+03	85000.00
03670E	2017-07-19 22:57:00+03	40800.00
036756	2017-07-03 08:20:00+03	56000.00
036770	2017-07-24 21:32:00+03	23400.00
0367C2	2017-07-18 20:06:00+03	168200.00
0367F7	2017-08-15 07:06:00+03	66600.00
036846	2017-08-05 00:15:00+03	147000.00
036895	2017-08-07 19:35:00+03	70600.00
036920	2017-08-14 06:26:00+03	25200.00
036992	2017-07-26 06:52:00+03	113200.00
036999	2017-07-24 03:15:00+03	132800.00
036A0E	2017-07-09 08:04:00+03	133700.00
036A15	2017-07-27 18:42:00+03	93800.00
036A1D	2017-08-09 08:27:00+03	22200.00
036A28	2017-07-16 15:14:00+03	70600.00
036A7B	2017-08-10 21:37:00+03	47100.00
036ACD	2017-07-09 01:46:00+03	37200.00
036ACF	2017-08-15 17:33:00+03	10800.00
036AD2	2017-07-07 04:29:00+03	40800.00
036AF2	2017-07-31 17:02:00+03	88600.00
036B10	2017-08-04 00:47:00+03	24400.00
036B29	2017-07-14 01:29:00+03	24400.00
036B6E	2017-06-29 06:27:00+03	51900.00
036C56	2017-08-05 09:07:00+03	90600.00
036CD0	2017-07-02 03:15:00+03	250100.00
036D3B	2017-07-13 17:18:00+03	26000.00
036DD0	2017-08-10 11:14:00+03	25800.00
036DEE	2017-07-01 03:46:00+03	52800.00
036E20	2017-08-13 02:15:00+03	103600.00
036E60	2017-08-15 11:09:00+03	49200.00
036EA2	2017-07-04 00:16:00+03	69600.00
036EBA	2017-07-11 06:03:00+03	6300.00
036ED3	2017-07-25 23:29:00+03	52100.00
036ED7	2017-08-10 23:42:00+03	35800.00
036F02	2017-07-16 01:37:00+03	78400.00
036F49	2017-07-19 14:31:00+03	23200.00
03707B	2017-07-08 22:55:00+03	23200.00
037083	2017-07-14 18:24:00+03	24400.00
037090	2017-08-10 19:01:00+03	56900.00
037096	2017-08-04 01:56:00+03	48800.00
0370A4	2017-07-09 13:36:00+03	170000.00
0370DF	2017-07-01 15:35:00+03	56600.00
0370FC	2017-07-05 09:05:00+03	198400.00
0370FF	2017-07-18 10:00:00+03	59200.00
037150	2017-07-31 07:15:00+03	31400.00
03717E	2017-07-23 19:47:00+03	167400.00
037250	2017-08-10 06:21:00+03	13800.00
037292	2017-07-07 09:09:00+03	7200.00
0372E1	2017-08-07 20:26:00+03	54800.00
0372F9	2017-08-01 17:54:00+03	113800.00
037354	2017-07-16 14:54:00+03	20400.00
0373BE	2017-07-08 22:00:00+03	55400.00
0374DA	2017-08-06 09:46:00+03	48500.00
037523	2017-08-03 04:48:00+03	47100.00
037586	2017-07-11 05:29:00+03	68800.00
0375E8	2017-08-03 01:12:00+03	68100.00
0375FB	2017-07-10 01:43:00+03	137100.00
037651	2017-07-26 10:10:00+03	109300.00
03765F	2017-07-13 07:57:00+03	93000.00
0376AF	2017-07-20 23:32:00+03	36400.00
0376C3	2017-07-29 23:48:00+03	92800.00
037712	2017-07-30 19:47:00+03	78100.00
037786	2017-07-28 15:39:00+03	26000.00
037793	2017-06-26 03:20:00+03	141700.00
0377E4	2017-08-10 15:22:00+03	26000.00
0377E5	2017-07-08 22:52:00+03	77900.00
037817	2017-07-01 09:50:00+03	56200.00
037831	2017-07-01 23:21:00+03	46000.00
0378AF	2017-08-08 12:53:00+03	31400.00
0378F9	2017-06-28 19:47:00+03	104100.00
037912	2017-06-27 17:13:00+03	36900.00
03793B	2017-07-22 12:11:00+03	56000.00
037999	2017-06-30 04:30:00+03	28000.00
0379BD	2017-07-07 10:45:00+03	59200.00
0379D5	2017-07-23 23:11:00+03	141600.00
037ADE	2017-08-01 17:53:00+03	27900.00
037B16	2017-07-20 13:52:00+03	284400.00
037B22	2017-07-01 03:06:00+03	409100.00
037B30	2017-07-01 00:54:00+03	86600.00
037B4B	2017-07-13 07:26:00+03	40200.00
037B6A	2017-07-01 05:58:00+03	168000.00
037BA0	2017-07-11 17:24:00+03	46200.00
037C13	2017-07-17 15:50:00+03	39800.00
037D22	2017-07-10 07:16:00+03	71100.00
037D49	2017-08-10 12:20:00+03	61800.00
037D7A	2017-08-09 03:37:00+03	38800.00
037D84	2017-07-11 02:54:00+03	56900.00
037DD7	2017-07-11 20:51:00+03	85000.00
037DE1	2017-07-27 07:38:00+03	24700.00
037DE3	2017-07-09 01:07:00+03	46800.00
037E12	2017-08-14 19:27:00+03	115300.00
037E4E	2017-08-13 14:17:00+03	78300.00
037E69	2017-08-14 07:17:00+03	67700.00
037E7E	2017-07-15 09:43:00+03	38800.00
037EA7	2017-07-07 10:43:00+03	87000.00
037F62	2017-07-11 20:19:00+03	71600.00
037F6A	2017-07-11 16:14:00+03	10700.00
037FDC	2017-07-24 13:42:00+03	14400.00
038022	2017-07-30 13:10:00+03	68000.00
03804A	2017-07-20 07:54:00+03	130000.00
03808D	2017-07-24 06:56:00+03	96800.00
0380D6	2017-08-01 08:17:00+03	111600.00
038114	2017-06-29 01:15:00+03	17000.00
038124	2017-08-11 09:50:00+03	14000.00
038130	2017-08-06 09:22:00+03	69500.00
03813E	2017-08-04 18:03:00+03	46900.00
03814E	2017-07-21 16:28:00+03	47500.00
0381B8	2017-07-28 15:49:00+03	73200.00
0381D2	2017-07-29 04:57:00+03	85000.00
038247	2017-06-30 16:47:00+03	45500.00
038259	2017-07-17 20:00:00+03	67400.00
03828A	2017-07-13 01:46:00+03	65600.00
0382B8	2017-07-04 08:38:00+03	516800.00
03834E	2017-06-29 18:03:00+03	93000.00
03835E	2017-08-04 13:53:00+03	177600.00
038364	2017-08-08 02:58:00+03	30200.00
0383D6	2017-07-22 13:33:00+03	36600.00
0383DE	2017-07-26 10:18:00+03	16400.00
0383E4	2017-08-02 04:38:00+03	40000.00
038421	2017-07-24 21:58:00+03	23200.00
03842B	2017-07-19 00:50:00+03	67700.00
0384A6	2017-07-01 01:43:00+03	30000.00
038521	2017-07-31 01:53:00+03	17000.00
038526	2017-07-14 19:03:00+03	515200.00
03864B	2017-07-13 14:27:00+03	56900.00
038704	2017-07-31 18:44:00+03	15100.00
038718	2017-08-10 02:43:00+03	21800.00
03872A	2017-07-18 12:11:00+03	28800.00
03876E	2017-08-06 21:33:00+03	32600.00
0387F1	2017-08-08 05:41:00+03	62100.00
0387FA	2017-07-17 10:57:00+03	63800.00
038804	2017-08-09 03:32:00+03	67400.00
03886F	2017-08-05 19:08:00+03	12600.00
0388A7	2017-06-29 04:41:00+03	58000.00
0388CD	2017-07-08 17:02:00+03	69500.00
0389A5	2017-08-14 09:11:00+03	12000.00
0389DD	2017-07-07 02:54:00+03	96800.00
038A89	2017-08-12 00:30:00+03	166900.00
038AAF	2017-07-02 23:07:00+03	48800.00
038AFF	2017-07-25 22:20:00+03	47000.00
038B09	2017-07-10 08:12:00+03	39200.00
038B17	2017-07-26 20:58:00+03	73500.00
038B98	2017-07-25 20:32:00+03	56600.00
038C23	2017-07-07 15:18:00+03	31400.00
038C34	2017-07-15 14:43:00+03	26000.00
038CB5	2017-07-26 08:44:00+03	61900.00
038CD4	2017-08-12 00:34:00+03	84000.00
038CDB	2017-07-22 11:22:00+03	20400.00
038D10	2017-08-06 17:03:00+03	20500.00
038D2C	2017-07-25 23:01:00+03	27000.00
038D40	2017-07-28 10:06:00+03	39500.00
038D43	2017-07-10 14:04:00+03	105100.00
038D46	2017-07-20 22:19:00+03	112000.00
038D5E	2017-07-24 01:22:00+03	36700.00
038E38	2017-07-24 17:47:00+03	16400.00
038EB8	2017-08-02 22:34:00+03	155600.00
038ED1	2017-07-25 10:19:00+03	54600.00
038F22	2017-07-04 08:02:00+03	132800.00
038FD5	2017-07-29 04:47:00+03	99200.00
038FE5	2017-08-13 11:48:00+03	44800.00
039012	2017-07-11 06:53:00+03	48800.00
039029	2017-07-01 08:03:00+03	13300.00
039041	2017-07-30 02:45:00+03	29400.00
0390C2	2017-07-23 22:44:00+03	27600.00
039151	2017-06-29 14:58:00+03	114800.00
0391A0	2017-07-29 08:23:00+03	50600.00
0391B7	2017-08-10 13:09:00+03	72500.00
0391DD	2017-07-20 14:52:00+03	168700.00
03926F	2017-07-06 00:10:00+03	139300.00
0392BF	2017-07-26 09:22:00+03	168000.00
0393DE	2017-07-16 17:05:00+03	78500.00
0393E2	2017-07-25 19:03:00+03	133100.00
0393EB	2017-07-05 10:24:00+03	56000.00
0394A1	2017-08-01 09:00:00+03	31000.00
0394FA	2017-07-04 10:10:00+03	56000.00
03954E	2017-07-20 18:16:00+03	44800.00
039574	2017-07-13 18:39:00+03	168000.00
0395AA	2017-07-30 14:00:00+03	40000.00
0395CA	2017-07-28 11:53:00+03	56000.00
0395FB	2017-07-12 08:36:00+03	37300.00
039623	2017-07-18 16:59:00+03	46400.00
039648	2017-08-05 04:13:00+03	21800.00
039662	2017-08-09 18:07:00+03	60400.00
03968D	2017-07-30 15:37:00+03	31000.00
0396F0	2017-08-15 16:28:00+03	16000.00
03971B	2017-07-07 05:40:00+03	6700.00
03973B	2017-07-11 10:54:00+03	111600.00
039760	2017-08-04 01:11:00+03	135400.00
0397AB	2017-07-11 12:05:00+03	31100.00
039801	2017-07-31 05:07:00+03	100200.00
039808	2017-08-03 14:47:00+03	53300.00
039858	2017-07-09 19:46:00+03	10700.00
039893	2017-08-13 12:38:00+03	62700.00
039894	2017-07-30 06:40:00+03	342100.00
0398CF	2017-08-03 15:46:00+03	73600.00
0398E5	2017-08-03 15:12:00+03	55800.00
0398FE	2017-08-13 09:21:00+03	24800.00
03995D	2017-07-22 12:03:00+03	67600.00
0399AA	2017-08-10 20:03:00+03	90800.00
039A02	2017-08-04 23:46:00+03	75600.00
039A0E	2017-07-16 01:44:00+03	27900.00
039A3C	2017-08-10 20:50:00+03	23800.00
039A4A	2017-08-14 11:30:00+03	24400.00
039A50	2017-08-03 11:40:00+03	22600.00
039AAB	2017-07-26 11:12:00+03	59200.00
039AE9	2017-08-12 05:37:00+03	65900.00
039B75	2017-07-28 05:40:00+03	40600.00
039CAE	2017-08-01 03:16:00+03	181100.00
039D39	2017-07-22 23:34:00+03	13200.00
039D90	2017-08-02 20:56:00+03	26000.00
039E03	2017-07-30 18:53:00+03	101200.00
039E30	2017-07-02 07:23:00+03	70200.00
039E3B	2017-07-16 09:02:00+03	57600.00
039E50	2017-07-11 08:26:00+03	61700.00
039E84	2017-07-08 01:54:00+03	90800.00
039EC3	2017-07-15 07:19:00+03	43200.00
039ED9	2017-07-13 04:45:00+03	69900.00
039EFB	2017-07-24 02:46:00+03	56000.00
039F2A	2017-07-13 13:13:00+03	20400.00
039F4C	2017-07-17 20:16:00+03	31600.00
03A029	2017-07-12 03:44:00+03	46400.00
03A0A7	2017-08-14 09:43:00+03	12000.00
03A0D7	2017-08-11 00:26:00+03	36800.00
03A125	2017-07-06 16:54:00+03	21400.00
03A200	2017-08-14 08:17:00+03	65400.00
03A235	2017-08-13 09:44:00+03	168000.00
03A27E	2017-07-02 21:01:00+03	43200.00
03A285	2017-07-11 01:58:00+03	68800.00
03A29C	2017-07-28 15:32:00+03	6300.00
03A2EE	2017-08-05 22:54:00+03	47400.00
03A317	2017-08-06 01:34:00+03	23900.00
03A33C	2017-07-27 04:30:00+03	7800.00
03A365	2017-08-13 02:48:00+03	36200.00
03A3BE	2017-07-28 06:23:00+03	229300.00
03A3EA	2017-07-08 20:20:00+03	61500.00
03A3FC	2017-07-14 01:36:00+03	88200.00
03A4FB	2017-06-29 23:45:00+03	36200.00
03A520	2017-06-29 15:00:00+03	20800.00
03A530	2017-07-31 07:18:00+03	163200.00
03A58F	2017-07-20 04:50:00+03	28800.00
03A59F	2017-07-08 10:06:00+03	28800.00
03A5FA	2017-08-15 16:47:00+03	40800.00
03A604	2017-08-08 13:10:00+03	58600.00
03A61B	2017-07-07 13:36:00+03	75300.00
03A624	2017-07-01 15:40:00+03	38800.00
03A695	2017-07-23 20:34:00+03	27300.00
03A6DA	2017-07-10 19:55:00+03	112000.00
03A6DF	2017-07-05 01:34:00+03	28000.00
03A70A	2017-08-11 12:07:00+03	31600.00
03A752	2017-07-16 00:57:00+03	43200.00
03A798	2017-07-03 01:31:00+03	90400.00
03A79B	2017-08-02 14:03:00+03	141600.00
03A7CA	2017-08-12 12:21:00+03	503000.00
03A7D5	2017-07-12 15:33:00+03	39700.00
03A8BF	2017-07-14 18:02:00+03	40800.00
03A96B	2017-08-13 18:28:00+03	23600.00
03A9A0	2017-08-11 10:02:00+03	54800.00
03A9AE	2017-07-21 04:51:00+03	28000.00
03A9EB	2017-08-12 05:35:00+03	54300.00
03A9EF	2017-08-06 12:26:00+03	69200.00
03AA00	2017-07-31 13:12:00+03	26700.00
03AA4D	2017-08-08 23:35:00+03	40000.00
03AA5B	2017-07-11 20:12:00+03	140500.00
03AAE4	2017-07-06 12:55:00+03	56600.00
03AAE5	2017-08-10 16:29:00+03	68100.00
03AB41	2017-07-28 22:35:00+03	23600.00
03ABE5	2017-07-09 16:32:00+03	23200.00
03ABED	2017-07-24 17:04:00+03	200200.00
03ABF1	2017-08-08 04:39:00+03	46800.00
03AC12	2017-06-30 15:24:00+03	58000.00
03AC3C	2017-08-04 21:57:00+03	136100.00
03AC88	2017-07-28 08:23:00+03	135400.00
03ACAD	2017-06-28 15:28:00+03	16400.00
03ACCC	2017-08-09 12:15:00+03	21800.00
03AD1D	2017-08-07 07:27:00+03	28800.00
03AD2A	2017-07-31 18:37:00+03	87800.00
03AD56	2017-08-09 23:20:00+03	66900.00
03ADA3	2017-08-01 04:27:00+03	68800.00
03ADBD	2017-08-05 15:47:00+03	27800.00
03ADF4	2017-07-21 03:57:00+03	26800.00
03AE3A	2017-08-01 07:37:00+03	56600.00
03AE61	2017-08-05 21:40:00+03	138900.00
03AF22	2017-08-13 19:05:00+03	35600.00
03AF3D	2017-08-15 11:02:00+03	133200.00
03AF98	2017-07-03 12:46:00+03	21800.00
03AFAE	2017-07-31 18:15:00+03	44800.00
03AFDE	2017-08-07 09:39:00+03	75000.00
03B04F	2017-07-04 16:52:00+03	46300.00
03B088	2017-07-22 00:39:00+03	107500.00
03B08A	2017-08-01 22:22:00+03	40600.00
03B08B	2017-08-09 07:30:00+03	95500.00
03B123	2017-07-21 20:08:00+03	111200.00
03B1B7	2017-07-30 17:15:00+03	85000.00
03B1C6	2017-06-29 20:21:00+03	109300.00
03B1C7	2017-08-08 18:44:00+03	65900.00
03B217	2017-07-08 06:47:00+03	101200.00
03B25B	2017-07-14 03:56:00+03	196000.00
03B27E	2017-07-21 23:07:00+03	133200.00
03B2D7	2017-07-27 21:16:00+03	88900.00
03B394	2017-08-08 10:24:00+03	6300.00
03B3D0	2017-08-14 02:38:00+03	130200.00
03B3D4	2017-07-14 17:58:00+03	265700.00
03B3E9	2017-07-13 08:29:00+03	6000.00
03B416	2017-07-06 22:00:00+03	47500.00
03B430	2017-08-11 12:19:00+03	8000.00
03B437	2017-07-31 21:39:00+03	58800.00
03B43A	2017-06-30 22:05:00+03	63400.00
03B4F1	2017-08-11 18:52:00+03	88100.00
03B554	2017-08-13 08:32:00+03	99700.00
03B56B	2017-07-15 11:08:00+03	23600.00
03B59C	2017-08-06 15:57:00+03	98000.00
03B5E1	2017-07-22 20:40:00+03	115800.00
03B604	2017-07-15 13:00:00+03	38200.00
03B647	2017-07-30 16:06:00+03	135200.00
03B66B	2017-07-10 05:01:00+03	193600.00
03B6D5	2017-08-09 23:16:00+03	62800.00
03B73D	2017-07-15 09:02:00+03	131600.00
03B97D	2017-08-15 07:12:00+03	55800.00
03B988	2017-07-23 13:39:00+03	260300.00
03B9B6	2017-07-20 11:05:00+03	57500.00
03B9DB	2017-08-05 21:20:00+03	38600.00
03B9E1	2017-07-14 16:55:00+03	52600.00
03BA01	2017-07-28 16:59:00+03	43600.00
03BA79	2017-07-29 16:49:00+03	55000.00
03BAB7	2017-08-10 13:41:00+03	8200.00
03BAE2	2017-07-19 04:54:00+03	139300.00
03BAE7	2017-08-05 13:09:00+03	44100.00
03BAF0	2017-07-03 11:36:00+03	266400.00
03BB11	2017-08-02 06:50:00+03	109300.00
03BB2B	2017-07-05 16:34:00+03	16400.00
03BB5B	2017-07-21 11:56:00+03	72600.00
03BB5E	2017-08-14 21:22:00+03	61800.00
03BB66	2017-06-26 02:08:00+03	28000.00
03BB6A	2017-07-09 18:14:00+03	26800.00
03BBD8	2017-07-08 08:56:00+03	113200.00
03BBDC	2017-08-10 04:32:00+03	78100.00
03BC20	2017-07-24 15:37:00+03	193600.00
03BC62	2017-07-11 14:27:00+03	147100.00
03BD68	2017-08-05 13:05:00+03	135400.00
03BD7E	2017-07-12 14:36:00+03	8400.00
03BDB0	2017-07-13 08:03:00+03	123000.00
03BE05	2017-07-14 10:07:00+03	175000.00
03BE0B	2017-07-12 17:45:00+03	123000.00
03BE84	2017-08-13 15:30:00+03	40000.00
03BE94	2017-07-24 17:05:00+03	101200.00
03BEAF	2017-08-02 08:39:00+03	68800.00
03BEBE	2017-07-08 07:54:00+03	199800.00
03BF1E	2017-07-02 04:07:00+03	22000.00
03BF7D	2017-07-16 18:22:00+03	25400.00
03BFF6	2017-07-15 23:34:00+03	99200.00
03C2E3	2017-07-22 22:55:00+03	7200.00
03C2F9	2017-07-18 10:22:00+03	36200.00
03C2FD	2017-07-11 12:46:00+03	103000.00
03C3B3	2017-07-11 08:14:00+03	46000.00
03C3BF	2017-08-08 22:13:00+03	62000.00
03C446	2017-08-10 17:31:00+03	32700.00
03C482	2017-07-12 17:58:00+03	32700.00
03C4D7	2017-08-13 05:08:00+03	28000.00
03C519	2017-07-10 22:02:00+03	30000.00
03C548	2017-08-12 13:48:00+03	62800.00
03C55A	2017-08-02 04:51:00+03	36200.00
03C55B	2017-08-03 01:16:00+03	145300.00
03C5D0	2017-08-14 20:31:00+03	55800.00
03C5DE	2017-07-14 00:44:00+03	266400.00
03C620	2017-07-01 09:18:00+03	279200.00
03C63D	2017-08-15 02:35:00+03	18800.00
03C68C	2017-07-01 02:18:00+03	172100.00
03C6C0	2017-07-20 21:58:00+03	16400.00
03C6D2	2017-07-12 09:30:00+03	380700.00
03C6E1	2017-07-01 10:18:00+03	136800.00
03C773	2017-08-03 09:00:00+03	46200.00
03C791	2017-08-06 03:48:00+03	130400.00
03C7BD	2017-08-09 12:12:00+03	56000.00
03C81F	2017-08-10 04:50:00+03	86300.00
03C888	2017-07-20 05:11:00+03	87900.00
03C8A2	2017-08-06 08:23:00+03	42800.00
03C92D	2017-07-06 23:07:00+03	21200.00
03C94F	2017-08-06 04:39:00+03	65900.00
03C99D	2017-07-20 14:24:00+03	54000.00
03C9EB	2017-07-01 17:42:00+03	55800.00
03C9FB	2017-07-14 15:27:00+03	177600.00
03CA2A	2017-08-11 01:06:00+03	260300.00
03CA3E	2017-07-02 04:10:00+03	16400.00
03CAA2	2017-08-06 13:53:00+03	13600.00
03CAE3	2017-07-14 11:33:00+03	112000.00
03CBA4	2017-07-16 05:14:00+03	195900.00
03CBDC	2017-08-15 01:49:00+03	55800.00
03CBE5	2017-07-26 21:26:00+03	77900.00
03CC0D	2017-08-11 14:33:00+03	39500.00
03CC23	2017-06-28 17:02:00+03	89600.00
03CC41	2017-07-04 05:37:00+03	28000.00
03CC5A	2017-07-06 21:11:00+03	121800.00
03CC60	2017-07-16 23:16:00+03	60400.00
03CCC5	2017-06-27 20:54:00+03	54800.00
03CD69	2017-08-12 05:40:00+03	36200.00
03CDB5	2017-07-12 05:27:00+03	171000.00
03CE3A	2017-08-12 14:25:00+03	93000.00
03CE4D	2017-07-21 08:25:00+03	27800.00
03CEF4	2017-07-02 15:14:00+03	87200.00
03CFA4	2017-08-05 07:39:00+03	46000.00
03CFB6	2017-07-01 03:22:00+03	57500.00
03CFD1	2017-07-25 00:54:00+03	50300.00
03D0D2	2017-08-10 12:56:00+03	129000.00
03D13F	2017-07-13 12:41:00+03	55800.00
03D142	2017-07-16 16:39:00+03	38600.00
03D1B6	2017-07-28 19:17:00+03	161200.00
03D1E1	2017-07-11 23:04:00+03	61500.00
03D215	2017-07-03 12:14:00+03	129700.00
03D274	2017-08-03 14:11:00+03	86300.00
03D27B	2017-07-02 20:35:00+03	39100.00
03D310	2017-07-31 05:54:00+03	139300.00
03D3DA	2017-07-04 18:32:00+03	292300.00
03D3E4	2017-08-08 12:57:00+03	102100.00
03D427	2017-08-01 21:34:00+03	56000.00
03D431	2017-07-18 03:59:00+03	248400.00
03D4E5	2017-07-25 19:46:00+03	40800.00
03D505	2017-07-16 22:35:00+03	26300.00
03D507	2017-07-13 13:07:00+03	48800.00
03D58E	2017-07-15 14:24:00+03	55800.00
03D5EA	2017-07-02 16:27:00+03	37800.00
03D610	2017-08-07 23:15:00+03	83900.00
03D625	2017-07-20 02:34:00+03	69000.00
03D670	2017-07-30 14:35:00+03	80700.00
03D69C	2017-07-31 16:56:00+03	69000.00
03D7AB	2017-08-08 16:14:00+03	6000.00
03D7B0	2017-07-29 12:45:00+03	40600.00
03D807	2017-08-15 17:41:00+03	173600.00
03D82A	2017-07-01 16:34:00+03	62000.00
03D877	2017-07-06 19:29:00+03	40300.00
03D8F2	2017-06-29 10:12:00+03	95600.00
03D915	2017-07-13 00:48:00+03	24800.00
03D970	2017-08-10 14:37:00+03	135400.00
03D979	2017-07-22 13:01:00+03	6700.00
03D9C4	2017-06-30 12:13:00+03	125200.00
03D9ED	2017-08-10 20:33:00+03	103900.00
03DA35	2017-08-08 03:43:00+03	23200.00
03DAB0	2017-08-04 16:39:00+03	28200.00
03DADD	2017-07-03 13:51:00+03	59200.00
03DB4F	2017-08-07 07:12:00+03	134400.00
03DB6E	2017-07-21 10:08:00+03	201200.00
03DBAC	2017-08-13 12:46:00+03	131600.00
03DBCB	2017-07-07 18:39:00+03	119500.00
03DC24	2017-07-10 23:30:00+03	187600.00
03DC32	2017-08-13 06:08:00+03	94800.00
03DD16	2017-08-11 17:13:00+03	26700.00
03DD39	2017-07-19 14:44:00+03	16400.00
03DD92	2017-08-08 11:05:00+03	199600.00
03DDBC	2017-08-12 17:25:00+03	62100.00
03DE0A	2017-08-14 03:54:00+03	56900.00
03DE1E	2017-06-30 08:19:00+03	125400.00
03DE51	2017-08-05 03:39:00+03	115600.00
03DE87	2017-08-13 20:29:00+03	136100.00
03DED7	2017-07-03 19:19:00+03	28300.00
03DEE7	2017-07-04 06:27:00+03	134400.00
03DEF8	2017-08-10 14:18:00+03	43000.00
03DF13	2017-07-18 19:37:00+03	58600.00
03DF7D	2017-08-06 11:16:00+03	131600.00
03E00E	2017-07-12 11:06:00+03	55800.00
03E023	2017-08-12 17:40:00+03	52900.00
03E027	2017-08-13 00:05:00+03	45200.00
03E04A	2017-07-07 09:33:00+03	199600.00
03E061	2017-07-24 22:31:00+03	68400.00
03E090	2017-08-10 12:43:00+03	55500.00
03E0B8	2017-07-28 15:23:00+03	14000.00
03E143	2017-08-09 18:09:00+03	158100.00
03E19F	2017-07-28 15:22:00+03	64700.00
03E249	2017-07-13 04:24:00+03	69600.00
03E2E8	2017-07-24 21:56:00+03	136200.00
03E2FB	2017-07-25 01:40:00+03	133100.00
03E355	2017-08-02 01:06:00+03	23200.00
03E356	2017-08-06 21:04:00+03	184300.00
03E3CD	2017-07-23 08:26:00+03	25000.00
03E3F1	2017-07-11 23:07:00+03	100700.00
03E4B5	2017-06-25 09:27:00+03	147700.00
03E504	2017-07-23 17:18:00+03	99200.00
03E51A	2017-07-20 08:23:00+03	59300.00
03E51E	2017-07-28 06:08:00+03	21400.00
03E56E	2017-07-30 10:13:00+03	56900.00
03E59C	2017-08-02 13:08:00+03	12600.00
03E5C5	2017-07-15 06:00:00+03	97900.00
03E5D0	2017-07-30 23:45:00+03	118600.00
03E643	2017-08-10 14:56:00+03	20000.00
03E64F	2017-08-05 09:00:00+03	58400.00
03E65D	2017-07-14 10:07:00+03	149400.00
03E717	2017-07-14 00:37:00+03	26000.00
03E79A	2017-08-09 18:02:00+03	64700.00
03E7BF	2017-06-28 12:59:00+03	27200.00
03E7D4	2017-07-20 15:42:00+03	46300.00
03E820	2017-07-06 11:02:00+03	25100.00
03E82E	2017-07-03 22:20:00+03	68800.00
03E831	2017-08-11 04:49:00+03	84100.00
03E842	2017-07-23 04:29:00+03	15200.00
03E86A	2017-07-19 01:33:00+03	6800.00
03E890	2017-07-09 11:03:00+03	40000.00
03E899	2017-07-16 00:08:00+03	30400.00
03E999	2017-07-28 03:31:00+03	58400.00
03E9D6	2017-07-21 03:55:00+03	23200.00
03EA59	2017-07-05 21:11:00+03	24000.00
03EA6C	2017-07-23 06:43:00+03	78400.00
03EA98	2017-07-31 13:14:00+03	7400.00
03EB3B	2017-07-07 21:36:00+03	6000.00
03EBA6	2017-08-02 00:47:00+03	168700.00
03EBC4	2017-07-02 22:50:00+03	25900.00
03EC2D	2017-07-29 06:00:00+03	153800.00
03EC56	2017-07-29 03:32:00+03	69900.00
03EC73	2017-07-16 18:09:00+03	84100.00
03EC74	2017-08-14 23:21:00+03	54100.00
03EC81	2017-07-08 14:33:00+03	147300.00
03EC95	2017-08-14 03:28:00+03	26700.00
03ECA3	2017-07-05 21:42:00+03	46000.00
03EDBE	2017-08-11 05:15:00+03	16400.00
03EDE4	2017-08-10 02:49:00+03	65600.00
03EDEA	2017-07-03 17:36:00+03	97700.00
03EDF5	2017-08-14 00:26:00+03	86800.00
03EE17	2017-08-08 21:21:00+03	23600.00
03EE38	2017-08-15 00:51:00+03	229900.00
03EE5F	2017-06-27 20:34:00+03	10800.00
03EEBB	2017-07-31 02:18:00+03	266300.00
03EEF2	2017-07-07 03:00:00+03	45200.00
03EF8B	2017-07-09 04:07:00+03	87400.00
03F048	2017-07-26 15:23:00+03	206000.00
03F05F	2017-08-08 12:26:00+03	26200.00
03F06D	2017-07-29 09:36:00+03	46000.00
03F0A3	2017-08-08 07:42:00+03	54500.00
03F0DD	2017-07-21 02:03:00+03	99200.00
03F0ED	2017-07-05 02:57:00+03	81600.00
03F18A	2017-07-07 07:32:00+03	146400.00
03F1BB	2017-08-04 02:47:00+03	204200.00
03F1F6	2017-07-22 16:11:00+03	24400.00
03F220	2017-07-25 14:34:00+03	32900.00
03F22F	2017-07-07 12:03:00+03	44000.00
03F29C	2017-07-27 00:01:00+03	28800.00
03F2A5	2017-07-02 01:33:00+03	6700.00
03F338	2017-08-14 23:59:00+03	32200.00
03F361	2017-07-22 11:27:00+03	149200.00
03F37A	2017-07-14 16:52:00+03	28000.00
03F407	2017-08-12 17:12:00+03	144400.00
03F424	2017-07-13 19:56:00+03	96600.00
03F431	2017-07-23 03:19:00+03	73600.00
03F43E	2017-08-09 20:12:00+03	57400.00
03F43F	2017-08-11 05:23:00+03	45200.00
03F4C2	2017-07-11 06:51:00+03	27200.00
03F585	2017-08-14 05:57:00+03	115600.00
03F58D	2017-07-25 03:50:00+03	31100.00
03F5C6	2017-07-06 13:46:00+03	65400.00
03F662	2017-08-13 09:08:00+03	46300.00
03F716	2017-07-03 03:15:00+03	25400.00
03F740	2017-07-14 21:44:00+03	32700.00
03F776	2017-07-05 02:03:00+03	50600.00
03F79E	2017-08-06 03:21:00+03	75000.00
03F7D8	2017-07-13 09:44:00+03	28000.00
03F7F8	2017-07-21 17:50:00+03	36200.00
03F818	2017-08-12 00:41:00+03	70700.00
03F84A	2017-08-04 05:56:00+03	62600.00
03F855	2017-07-26 11:41:00+03	67400.00
03F896	2017-08-12 03:04:00+03	12400.00
03F89B	2017-08-04 17:39:00+03	54000.00
03F8C0	2017-07-19 14:21:00+03	13400.00
03F8F8	2017-08-07 01:35:00+03	117200.00
03F8F9	2017-07-16 10:46:00+03	93900.00
03F933	2017-07-23 23:59:00+03	81500.00
03F965	2017-07-26 22:02:00+03	6300.00
03F981	2017-07-16 20:58:00+03	139500.00
03F9F2	2017-07-15 06:51:00+03	15800.00
03FA0B	2017-07-08 04:44:00+03	26000.00
03FA43	2017-08-05 06:17:00+03	40400.00
03FA64	2017-07-15 00:25:00+03	13400.00
03FA7A	2017-08-09 07:07:00+03	32800.00
03FACF	2017-08-13 14:16:00+03	25100.00
03FB11	2017-07-16 07:41:00+03	35800.00
03FB19	2017-07-14 21:14:00+03	131600.00
03FB74	2017-07-19 23:18:00+03	28000.00
03FB96	2017-08-04 21:31:00+03	127300.00
03FBA8	2017-07-20 19:52:00+03	32800.00
03FBB4	2017-07-10 03:38:00+03	51900.00
03FC22	2017-07-31 15:35:00+03	12600.00
03FC4C	2017-07-13 17:38:00+03	289800.00
03FC57	2017-07-08 07:25:00+03	44300.00
03FC92	2017-08-02 23:20:00+03	46400.00
03FD0B	2017-06-29 08:25:00+03	15800.00
03FD3D	2017-07-28 16:15:00+03	122300.00
03FD91	2017-08-15 15:31:00+03	32800.00
03FD9C	2017-08-15 12:48:00+03	65500.00
03FDD3	2017-07-08 00:20:00+03	48800.00
03FE47	2017-07-16 22:32:00+03	166500.00
03FE57	2017-07-21 08:25:00+03	155600.00
03FE9D	2017-08-11 01:21:00+03	51400.00
03FEB1	2017-07-23 08:41:00+03	24400.00
03FEC7	2017-08-14 20:54:00+03	192400.00
03FF09	2017-08-08 14:47:00+03	47600.00
03FF0D	2017-07-31 01:17:00+03	50000.00
03FF3A	2017-06-29 06:58:00+03	6000.00
03FF70	2017-07-07 20:22:00+03	47400.00
03FF88	2017-07-05 14:12:00+03	22000.00
03FF8D	2017-07-23 08:52:00+03	67400.00
03FFC2	2017-07-17 17:35:00+03	68800.00
04000A	2017-07-09 01:45:00+03	172100.00
04002B	2017-08-13 19:23:00+03	14000.00
040034	2017-07-19 22:23:00+03	119600.00
0400E5	2017-08-10 07:29:00+03	129500.00
0400F1	2017-07-02 04:23:00+03	29600.00
040104	2017-08-11 19:59:00+03	25200.00
040139	2017-07-16 16:54:00+03	114400.00
040162	2017-08-14 01:53:00+03	131100.00
0402E2	2017-07-27 16:55:00+03	119500.00
0402ED	2017-08-15 17:04:00+03	18600.00
040310	2017-07-14 05:17:00+03	52800.00
040346	2017-07-04 12:56:00+03	47400.00
040405	2017-07-17 19:51:00+03	26200.00
040411	2017-07-15 15:04:00+03	24400.00
04046D	2017-07-23 19:08:00+03	26200.00
040499	2017-07-16 14:53:00+03	30700.00
04049A	2017-07-27 23:32:00+03	132000.00
0404F8	2017-06-30 03:30:00+03	58800.00
040535	2017-08-03 13:47:00+03	23100.00
040547	2017-07-08 13:30:00+03	21400.00
040559	2017-07-26 00:08:00+03	38800.00
04058A	2017-07-07 20:31:00+03	78200.00
040615	2017-08-13 21:23:00+03	62100.00
04061C	2017-07-09 00:40:00+03	52100.00
040675	2017-07-22 04:12:00+03	38600.00
0406BA	2017-07-21 03:54:00+03	6700.00
0406D4	2017-08-02 21:11:00+03	75600.00
0406EF	2017-07-04 16:43:00+03	233000.00
0406F0	2017-08-07 00:54:00+03	131100.00
040781	2017-07-15 09:22:00+03	38100.00
040786	2017-07-23 11:01:00+03	51600.00
040805	2017-08-05 13:45:00+03	38400.00
04081F	2017-08-10 22:29:00+03	62900.00
040865	2017-08-06 20:32:00+03	78200.00
040885	2017-08-08 23:03:00+03	47100.00
0408C1	2017-07-25 12:26:00+03	58600.00
0408CA	2017-07-06 04:32:00+03	29400.00
040951	2017-07-31 04:49:00+03	38800.00
0409B5	2017-08-15 13:58:00+03	46300.00
0409C4	2017-07-14 20:37:00+03	26800.00
040AB2	2017-07-22 07:29:00+03	21400.00
040AB6	2017-07-25 23:06:00+03	32700.00
040B4B	2017-07-28 19:15:00+03	55800.00
040B5D	2017-08-10 08:10:00+03	9200.00
040B6A	2017-07-29 11:48:00+03	101200.00
040B6C	2017-08-06 16:41:00+03	53500.00
040B7F	2017-07-19 12:19:00+03	132800.00
040BAE	2017-08-06 04:36:00+03	67400.00
040C55	2017-07-18 18:39:00+03	36200.00
040C56	2017-08-02 17:59:00+03	23200.00
040C69	2017-08-11 01:34:00+03	12400.00
040CE5	2017-07-18 00:26:00+03	10600.00
040CEF	2017-08-15 11:06:00+03	147400.00
040DAF	2017-07-07 23:52:00+03	47200.00
040DEB	2017-08-15 08:10:00+03	77900.00
040E23	2017-07-23 15:45:00+03	64400.00
040E52	2017-08-12 07:33:00+03	26800.00
040E85	2017-07-27 04:09:00+03	94800.00
040EE5	2017-07-11 17:03:00+03	105000.00
040F26	2017-08-11 07:31:00+03	46200.00
040F27	2017-08-09 01:54:00+03	102100.00
040F91	2017-07-09 17:42:00+03	72000.00
040F92	2017-07-06 06:04:00+03	76700.00
04101A	2017-07-14 01:12:00+03	55800.00
04102C	2017-07-26 05:42:00+03	26000.00
0410AC	2017-07-28 12:14:00+03	66600.00
0410C9	2017-08-04 13:50:00+03	13800.00
041127	2017-08-05 05:16:00+03	24400.00
04117B	2017-07-30 08:44:00+03	273400.00
0411E9	2017-08-14 07:46:00+03	105600.00
0412F7	2017-07-23 09:35:00+03	133200.00
04131A	2017-08-15 02:43:00+03	25200.00
0413D8	2017-07-21 17:06:00+03	12000.00
041452	2017-08-12 11:29:00+03	36200.00
04147A	2017-08-14 17:15:00+03	14400.00
0414D9	2017-08-09 07:29:00+03	45100.00
04150F	2017-07-19 22:51:00+03	19600.00
041521	2017-07-21 21:55:00+03	23200.00
04154A	2017-07-11 23:28:00+03	191200.00
041587	2017-08-14 04:11:00+03	70900.00
0415B3	2017-07-23 15:01:00+03	56600.00
0415B6	2017-07-26 22:29:00+03	28800.00
04167A	2017-08-08 01:06:00+03	17200.00
041697	2017-07-22 08:08:00+03	6000.00
041698	2017-07-16 00:04:00+03	64600.00
0416C6	2017-07-11 06:28:00+03	36800.00
0416F9	2017-08-09 01:03:00+03	32700.00
041718	2017-07-06 21:15:00+03	42000.00
0417EC	2017-08-15 08:50:00+03	66800.00
0417ED	2017-07-07 17:22:00+03	26000.00
0419CA	2017-07-17 00:43:00+03	94000.00
041A14	2017-07-22 01:20:00+03	12000.00
041A53	2017-07-11 04:42:00+03	75200.00
041A89	2017-08-14 03:15:00+03	51800.00
041AA9	2017-07-13 00:19:00+03	75300.00
041AAA	2017-08-10 09:49:00+03	24800.00
041AD8	2017-08-04 23:36:00+03	40000.00
041B10	2017-07-09 22:40:00+03	13600.00
041B2E	2017-08-14 06:04:00+03	22600.00
041B49	2017-08-04 22:23:00+03	78200.00
041B68	2017-08-02 16:46:00+03	57600.00
041B6C	2017-08-09 19:28:00+03	12200.00
041B89	2017-08-05 05:20:00+03	83000.00
041B94	2017-07-26 01:31:00+03	81600.00
041BF7	2017-08-14 06:06:00+03	46200.00
041C3B	2017-07-24 07:36:00+03	26800.00
041C71	2017-08-15 02:29:00+03	21900.00
041CF8	2017-07-08 13:13:00+03	24400.00
041D0B	2017-07-03 16:07:00+03	293100.00
041D21	2017-07-10 03:19:00+03	73100.00
041D26	2017-07-04 03:13:00+03	43200.00
041D55	2017-07-13 21:51:00+03	23200.00
041D62	2017-07-03 21:05:00+03	92600.00
041D8A	2017-07-01 11:02:00+03	166100.00
041E4D	2017-07-10 03:39:00+03	86600.00
041EA6	2017-08-08 03:43:00+03	60600.00
041EC0	2017-08-11 20:52:00+03	30100.00
041EED	2017-08-15 06:28:00+03	249300.00
041F00	2017-08-11 05:38:00+03	83300.00
041F37	2017-08-13 02:19:00+03	160300.00
0420D2	2017-07-08 02:23:00+03	55800.00
0420F0	2017-07-07 01:58:00+03	67700.00
042183	2017-08-15 15:50:00+03	120700.00
04219C	2017-07-26 00:51:00+03	10800.00
0421D0	2017-07-02 14:04:00+03	28000.00
0421D3	2017-07-18 01:14:00+03	81500.00
0421E9	2017-07-23 14:40:00+03	67600.00
042223	2017-08-10 10:42:00+03	124300.00
042230	2017-08-10 17:30:00+03	96800.00
042259	2017-07-09 14:39:00+03	132800.00
042291	2017-07-15 08:24:00+03	289500.00
04229A	2017-08-02 16:54:00+03	92600.00
0422A8	2017-08-11 13:43:00+03	59800.00
0422C5	2017-08-04 09:53:00+03	44700.00
0422CF	2017-07-29 08:00:00+03	26700.00
042356	2017-07-13 00:56:00+03	6700.00
0423A1	2017-07-17 18:29:00+03	36400.00
0423F0	2017-07-25 04:21:00+03	155600.00
0423F4	2017-07-05 17:28:00+03	62600.00
042460	2017-06-28 03:27:00+03	145800.00
042472	2017-07-10 17:36:00+03	85000.00
0424CE	2017-06-30 07:36:00+03	26000.00
0424FA	2017-07-23 22:28:00+03	272400.00
042524	2017-07-14 05:50:00+03	12600.00
042534	2017-07-28 09:01:00+03	161200.00
042572	2017-08-06 12:56:00+03	55800.00
042573	2017-07-09 08:18:00+03	93900.00
0425FC	2017-07-21 04:38:00+03	115900.00
042609	2017-07-08 01:24:00+03	142400.00
042614	2017-08-12 15:15:00+03	52700.00
042618	2017-07-10 14:19:00+03	131600.00
04263C	2017-08-12 22:39:00+03	48300.00
042707	2017-08-03 05:49:00+03	55800.00
042715	2017-07-25 05:41:00+03	147500.00
042740	2017-08-01 07:38:00+03	109200.00
04274C	2017-07-15 05:46:00+03	73600.00
042775	2017-07-11 19:58:00+03	18600.00
04277E	2017-07-17 01:19:00+03	48800.00
0427A6	2017-08-02 06:16:00+03	271200.00
0427B7	2017-07-06 12:27:00+03	162500.00
0427D4	2017-08-08 14:38:00+03	13300.00
042813	2017-08-01 19:11:00+03	131100.00
042816	2017-07-13 02:54:00+03	26700.00
04281D	2017-07-23 06:46:00+03	124200.00
042837	2017-07-17 13:57:00+03	60600.00
04283B	2017-07-31 16:38:00+03	147100.00
042841	2017-08-15 02:09:00+03	61800.00
04285D	2017-08-10 21:10:00+03	23400.00
04286A	2017-08-06 06:08:00+03	8000.00
04289A	2017-07-20 18:05:00+03	6600.00
0428DD	2017-07-08 13:04:00+03	56000.00
042903	2017-07-27 10:02:00+03	131600.00
04290E	2017-07-12 09:15:00+03	332300.00
042A43	2017-07-30 19:07:00+03	21200.00
042A4F	2017-07-06 08:16:00+03	58200.00
042A79	2017-08-12 03:03:00+03	40800.00
042A92	2017-07-26 05:03:00+03	6800.00
042A93	2017-07-08 20:16:00+03	36200.00
042B06	2017-07-09 15:15:00+03	148200.00
042B22	2017-07-27 09:51:00+03	52900.00
042B2D	2017-08-03 17:55:00+03	21400.00
042B6F	2017-07-25 00:09:00+03	94700.00
042BB9	2017-08-02 10:39:00+03	246000.00
042BD9	2017-07-03 12:24:00+03	42800.00
042BEC	2017-07-05 22:14:00+03	32800.00
042C2A	2017-08-01 07:48:00+03	47800.00
042C2C	2017-07-06 21:03:00+03	6700.00
042C39	2017-08-14 17:21:00+03	46400.00
042C82	2017-08-15 10:26:00+03	68400.00
042CB0	2017-07-22 23:44:00+03	88100.00
042CDC	2017-08-10 08:44:00+03	193700.00
042D0D	2017-07-30 09:20:00+03	72700.00
042D5A	2017-07-25 09:26:00+03	48800.00
042D5F	2017-08-03 22:57:00+03	38400.00
042D78	2017-07-15 02:44:00+03	57400.00
042D9D	2017-07-30 20:41:00+03	55800.00
042DFF	2017-08-03 14:30:00+03	155600.00
042E24	2017-07-16 13:23:00+03	59200.00
042E2D	2017-08-06 18:05:00+03	129600.00
042E7A	2017-07-10 15:08:00+03	135400.00
042E88	2017-07-21 14:23:00+03	13400.00
042EC2	2017-07-07 19:00:00+03	26000.00
042ECE	2017-07-29 01:40:00+03	97900.00
042F46	2017-07-03 16:22:00+03	34000.00
042F4D	2017-07-22 09:26:00+03	63300.00
043012	2017-07-29 01:35:00+03	113600.00
043013	2017-07-14 09:49:00+03	13600.00
043066	2017-07-24 19:46:00+03	49200.00
04308C	2017-08-08 13:33:00+03	175200.00
0430AE	2017-07-10 20:11:00+03	21400.00
0430CD	2017-08-01 09:49:00+03	6000.00
0430D4	2017-08-08 19:11:00+03	84000.00
0430DF	2017-07-30 21:26:00+03	132800.00
043115	2017-07-17 18:45:00+03	83200.00
04311E	2017-07-03 06:33:00+03	56600.00
0431C6	2017-08-05 05:05:00+03	134400.00
0431F6	2017-07-14 05:50:00+03	47100.00
043216	2017-07-22 01:54:00+03	59800.00
0432E7	2017-08-11 04:18:00+03	12600.00
043317	2017-08-05 23:59:00+03	37900.00
0433AD	2017-07-01 13:25:00+03	52400.00
0433C2	2017-07-01 01:19:00+03	202800.00
04341E	2017-07-03 09:45:00+03	270700.00
04347A	2017-07-11 14:21:00+03	20400.00
043481	2017-07-06 10:00:00+03	46000.00
043486	2017-07-16 13:25:00+03	278500.00
043533	2017-08-05 07:07:00+03	28700.00
04353C	2017-07-04 14:01:00+03	54800.00
043551	2017-08-14 12:18:00+03	68800.00
04366C	2017-07-17 02:01:00+03	14600.00
043681	2017-08-08 10:01:00+03	83300.00
0436AB	2017-07-12 16:58:00+03	57600.00
043778	2017-07-13 18:33:00+03	55800.00
04377B	2017-07-25 13:40:00+03	78800.00
04377F	2017-07-31 14:12:00+03	52000.00
04378A	2017-07-31 05:40:00+03	96300.00
04379C	2017-08-10 11:51:00+03	8400.00
0437A8	2017-07-08 18:22:00+03	111700.00
0437BD	2017-07-20 06:37:00+03	46000.00
0437BE	2017-08-04 18:28:00+03	16000.00
0439B8	2017-07-07 15:19:00+03	18000.00
0439BF	2017-07-30 03:32:00+03	16800.00
0439C4	2017-07-24 16:50:00+03	21200.00
0439C8	2017-07-08 02:03:00+03	21200.00
0439CB	2017-07-07 19:43:00+03	40000.00
0439EB	2017-08-01 07:55:00+03	386300.00
043A27	2017-07-25 00:09:00+03	103800.00
043A75	2017-07-16 12:28:00+03	52700.00
043ABC	2017-08-13 10:46:00+03	31200.00
043B8D	2017-07-24 04:26:00+03	34000.00
043BC9	2017-08-01 01:25:00+03	101200.00
043BE6	2017-07-11 00:04:00+03	32700.00
043C4A	2017-07-13 09:45:00+03	112600.00
043C65	2017-08-09 20:08:00+03	26600.00
043C72	2017-07-07 07:37:00+03	138000.00
043CEA	2017-08-01 14:40:00+03	136100.00
043D2D	2017-07-07 07:42:00+03	58200.00
043DC3	2017-08-02 06:33:00+03	13600.00
043E03	2017-07-04 20:21:00+03	28800.00
043E17	2017-07-09 10:34:00+03	28400.00
043E4C	2017-07-13 04:55:00+03	139100.00
043E81	2017-08-05 06:37:00+03	6800.00
043EB1	2017-07-10 12:21:00+03	10600.00
043F41	2017-06-28 00:49:00+03	252200.00
043F79	2017-07-22 22:37:00+03	12600.00
043FB8	2017-07-28 04:08:00+03	26000.00
044009	2017-07-02 08:18:00+03	170000.00
04400E	2017-08-09 17:30:00+03	57400.00
04402F	2017-07-16 01:19:00+03	48800.00
044035	2017-07-12 18:15:00+03	53600.00
044065	2017-08-08 09:47:00+03	6300.00
04419B	2017-07-29 14:52:00+03	56000.00
0441E3	2017-08-06 15:42:00+03	32200.00
0441FD	2017-08-03 14:06:00+03	59800.00
0441FE	2017-07-09 03:45:00+03	65500.00
04421C	2017-07-22 21:52:00+03	123000.00
0442FA	2017-08-01 14:23:00+03	258400.00
044310	2017-07-06 17:36:00+03	6000.00
044397	2017-07-31 01:15:00+03	56000.00
0443B0	2017-08-14 07:47:00+03	29800.00
0443D9	2017-07-07 22:22:00+03	68100.00
044420	2017-07-13 18:19:00+03	78800.00
044426	2017-07-12 23:28:00+03	28800.00
044428	2017-08-02 23:24:00+03	68400.00
04449C	2017-07-09 03:26:00+03	130400.00
04452D	2017-07-07 17:23:00+03	92000.00
044561	2017-08-08 06:45:00+03	40000.00
044582	2017-07-19 13:10:00+03	64500.00
0445A4	2017-08-04 22:22:00+03	328400.00
0445E0	2017-08-04 02:52:00+03	92600.00
04460F	2017-08-14 18:36:00+03	115000.00
044616	2017-07-30 17:06:00+03	100600.00
044697	2017-08-05 11:35:00+03	62900.00
0446D9	2017-07-04 03:58:00+03	63700.00
04474F	2017-07-15 18:34:00+03	83600.00
044758	2017-08-08 09:16:00+03	33100.00
0447CF	2017-07-15 14:37:00+03	132800.00
04489B	2017-08-02 13:56:00+03	43100.00
044905	2017-07-20 15:57:00+03	66000.00
044915	2017-07-27 14:59:00+03	85000.00
04494D	2017-08-14 09:37:00+03	24600.00
044965	2017-07-22 06:56:00+03	23200.00
0449F1	2017-07-29 01:01:00+03	28700.00
0449F9	2017-07-18 04:12:00+03	135600.00
044A24	2017-07-07 03:54:00+03	54800.00
044AC2	2017-07-12 14:22:00+03	36000.00
044AC4	2017-07-28 22:02:00+03	72300.00
044ADD	2017-07-17 18:52:00+03	440700.00
044B18	2017-07-26 11:35:00+03	67600.00
044B99	2017-08-04 11:18:00+03	118500.00
044BB8	2017-08-12 20:53:00+03	15800.00
044BC0	2017-08-12 06:26:00+03	126400.00
044BC9	2017-07-07 19:16:00+03	149600.00
044BCA	2017-07-14 20:46:00+03	6600.00
044BF9	2017-08-07 10:20:00+03	16800.00
044BFA	2017-07-17 16:54:00+03	70700.00
044C2A	2017-08-12 01:00:00+03	25100.00
044C2E	2017-07-30 04:06:00+03	47100.00
044CAB	2017-07-14 07:15:00+03	73600.00
044CE5	2017-07-11 06:50:00+03	47500.00
044D0B	2017-08-13 23:06:00+03	67800.00
044D1C	2017-07-31 16:41:00+03	48300.00
044DB9	2017-07-28 15:31:00+03	13000.00
044DEF	2017-08-11 18:46:00+03	23600.00
044E05	2017-07-25 15:40:00+03	123000.00
044E40	2017-07-08 12:26:00+03	39300.00
044E65	2017-06-30 23:18:00+03	131600.00
044E6E	2017-07-31 16:14:00+03	282100.00
044E97	2017-08-01 14:22:00+03	34000.00
044F0B	2017-08-10 21:22:00+03	78000.00
044F3E	2017-07-17 18:33:00+03	112000.00
044F42	2017-08-14 22:32:00+03	104200.00
044F5C	2017-06-28 22:02:00+03	57500.00
044FB3	2017-07-27 15:29:00+03	121400.00
044FD8	2017-07-08 10:47:00+03	26000.00
045005	2017-08-02 21:15:00+03	46300.00
045056	2017-08-01 17:10:00+03	55800.00
045073	2017-07-27 10:59:00+03	56200.00
045101	2017-07-18 02:36:00+03	16400.00
045161	2017-07-19 19:05:00+03	147200.00
045178	2017-07-17 15:58:00+03	31400.00
045182	2017-08-13 16:55:00+03	64400.00
0451D9	2017-08-15 10:51:00+03	200800.00
045214	2017-07-05 00:40:00+03	6000.00
045215	2017-08-14 01:14:00+03	43200.00
04524E	2017-07-21 18:20:00+03	23600.00
045282	2017-07-23 16:34:00+03	54500.00
045286	2017-08-11 11:48:00+03	80000.00
0452AF	2017-07-22 21:29:00+03	88400.00
0452D4	2017-07-20 17:45:00+03	119600.00
0452DC	2017-07-11 14:42:00+03	99200.00
0452FC	2017-08-06 20:10:00+03	67600.00
045313	2017-07-02 19:36:00+03	28000.00
04534B	2017-07-09 00:36:00+03	99200.00
0453B5	2017-08-08 15:18:00+03	96300.00
045428	2017-07-27 09:57:00+03	36000.00
0454A5	2017-07-15 07:28:00+03	12600.00
045553	2017-07-15 05:54:00+03	16800.00
045579	2017-07-13 19:46:00+03	94000.00
0455B7	2017-07-29 06:30:00+03	23200.00
0456BC	2017-08-11 15:52:00+03	98400.00
0456D6	2017-06-27 01:08:00+03	39200.00
04577A	2017-07-18 20:59:00+03	71800.00
04578F	2017-07-17 18:08:00+03	37200.00
0457AD	2017-07-27 11:38:00+03	31600.00
0457C5	2017-07-05 12:43:00+03	121800.00
04581B	2017-07-07 18:52:00+03	34000.00
04589B	2017-07-05 12:25:00+03	53700.00
04589D	2017-08-08 05:14:00+03	12400.00
0458B0	2017-07-28 03:43:00+03	56600.00
0458CC	2017-07-31 12:52:00+03	28800.00
0458D4	2017-08-15 09:40:00+03	28300.00
045954	2017-07-16 18:04:00+03	29600.00
0459F9	2017-07-08 19:02:00+03	14000.00
045A14	2017-07-05 10:06:00+03	38600.00
045A32	2017-07-26 00:46:00+03	36200.00
045AF1	2017-07-07 04:14:00+03	232100.00
045AF2	2017-08-01 15:16:00+03	147700.00
045B1F	2017-07-01 04:58:00+03	198300.00
045BDF	2017-07-27 07:57:00+03	8200.00
045C06	2017-07-26 04:55:00+03	28200.00
045C84	2017-07-10 02:04:00+03	138100.00
045C9B	2017-07-25 20:51:00+03	39500.00
045CBF	2017-08-10 06:38:00+03	32700.00
045D3A	2017-07-23 01:54:00+03	13200.00
045D86	2017-07-05 13:18:00+03	26000.00
045DC1	2017-08-11 00:54:00+03	124300.00
045DCB	2017-08-11 00:41:00+03	41200.00
045DEC	2017-07-23 07:49:00+03	43600.00
045E57	2017-08-09 15:43:00+03	62600.00
045E79	2017-07-15 22:28:00+03	16400.00
045F00	2017-07-03 03:32:00+03	48800.00
045F18	2017-07-22 18:33:00+03	68100.00
045F41	2017-08-07 11:21:00+03	124300.00
045F8F	2017-07-29 01:12:00+03	22600.00
045FB1	2017-07-23 15:20:00+03	57400.00
045FB8	2017-08-04 12:09:00+03	14400.00
045FDB	2017-07-30 06:33:00+03	117200.00
045FF7	2017-07-16 21:28:00+03	39200.00
046012	2017-08-01 21:06:00+03	69000.00
046023	2017-07-26 08:52:00+03	56700.00
0460B9	2017-08-09 19:47:00+03	67000.00
046123	2017-07-10 06:29:00+03	58600.00
046150	2017-08-02 08:13:00+03	25400.00
0461C4	2017-07-31 14:06:00+03	15900.00
046242	2017-08-02 21:24:00+03	40200.00
046274	2017-07-22 01:19:00+03	123000.00
046279	2017-08-13 22:22:00+03	84500.00
046299	2017-07-08 17:17:00+03	193500.00
0462C4	2017-08-14 20:48:00+03	26000.00
0462EF	2017-08-11 03:02:00+03	149300.00
04632B	2017-07-30 23:10:00+03	111600.00
046391	2017-08-06 01:52:00+03	12600.00
0463BC	2017-07-20 12:48:00+03	46200.00
0463C8	2017-08-02 00:07:00+03	128800.00
046440	2017-07-05 17:07:00+03	59800.00
046449	2017-07-28 13:21:00+03	67200.00
04652D	2017-07-14 08:49:00+03	28000.00
046558	2017-08-12 22:13:00+03	207600.00
046587	2017-07-12 14:57:00+03	21800.00
0465CF	2017-07-07 15:36:00+03	24500.00
046628	2017-07-11 04:07:00+03	56000.00
046647	2017-08-14 06:34:00+03	49100.00
046674	2017-07-07 13:38:00+03	55800.00
04669C	2017-08-13 22:13:00+03	11800.00
0466E6	2017-07-21 07:48:00+03	23200.00
0467E6	2017-07-04 14:53:00+03	99700.00
0467EE	2017-07-24 21:48:00+03	61600.00
046807	2017-07-07 14:37:00+03	128400.00
046843	2017-07-09 02:58:00+03	49200.00
04684D	2017-07-29 20:11:00+03	48500.00
046862	2017-07-20 00:56:00+03	152500.00
046866	2017-07-21 11:37:00+03	23200.00
04687E	2017-07-10 22:05:00+03	58400.00
0468C0	2017-07-17 01:44:00+03	52300.00
046949	2017-08-07 14:26:00+03	6700.00
04699E	2017-07-11 22:52:00+03	49900.00
0469E8	2017-07-05 13:47:00+03	43200.00
046A41	2017-08-07 23:29:00+03	91500.00
046AFD	2017-07-11 15:32:00+03	122800.00
046B30	2017-08-13 13:51:00+03	75600.00
046B3A	2017-07-11 08:40:00+03	35600.00
046B70	2017-07-11 10:56:00+03	104600.00
046BB5	2017-07-08 23:07:00+03	75600.00
046BE0	2017-08-02 20:56:00+03	258400.00
046C36	2017-07-22 00:09:00+03	44800.00
046C4A	2017-08-08 07:50:00+03	115600.00
046C62	2017-07-13 08:33:00+03	32700.00
046C94	2017-08-13 19:24:00+03	60200.00
046D08	2017-07-22 20:25:00+03	21400.00
046D73	2017-06-30 16:23:00+03	177200.00
046DB2	2017-08-08 02:51:00+03	9800.00
046E11	2017-07-05 10:16:00+03	405000.00
046E2A	2017-08-04 23:33:00+03	37200.00
046E31	2017-07-19 20:55:00+03	131600.00
046E46	2017-08-04 14:17:00+03	28800.00
046EAC	2017-08-06 09:10:00+03	114700.00
046EC4	2017-07-14 13:06:00+03	64400.00
046F48	2017-07-04 00:25:00+03	57500.00
046FC3	2017-07-24 16:13:00+03	6800.00
046FD4	2017-07-13 16:22:00+03	53300.00
046FE8	2017-08-14 14:32:00+03	46400.00
04701A	2017-08-06 04:22:00+03	105900.00
047037	2017-07-24 07:11:00+03	116800.00
04703D	2017-07-02 01:15:00+03	13400.00
047047	2017-07-17 06:41:00+03	67400.00
047071	2017-07-05 16:36:00+03	62600.00
0470E6	2017-07-29 13:26:00+03	8200.00
047139	2017-07-25 11:19:00+03	56000.00
0471DA	2017-07-09 21:08:00+03	117000.00
047215	2017-07-19 15:14:00+03	88300.00
04723B	2017-08-15 13:39:00+03	228600.00
04726B	2017-07-08 04:38:00+03	84100.00
047344	2017-07-16 01:31:00+03	15400.00
047367	2017-07-13 15:41:00+03	49700.00
047392	2017-07-23 00:24:00+03	92000.00
0473C4	2017-08-03 12:31:00+03	26800.00
047408	2017-07-26 17:18:00+03	13400.00
0474B3	2017-08-03 14:25:00+03	381400.00
0474C4	2017-07-12 02:08:00+03	68000.00
047523	2017-08-09 07:15:00+03	31700.00
04752F	2017-08-10 06:03:00+03	65900.00
04755E	2017-07-18 05:35:00+03	28000.00
04761B	2017-08-04 16:22:00+03	23200.00
047630	2017-08-09 13:29:00+03	67700.00
0476C7	2017-07-01 20:04:00+03	28000.00
0476ED	2017-08-14 01:50:00+03	52700.00
0476FB	2017-07-03 10:33:00+03	44600.00
047769	2017-07-02 03:40:00+03	12000.00
04779A	2017-07-08 06:55:00+03	56000.00
0477BC	2017-06-24 02:01:00+03	25800.00
0477F2	2017-07-14 08:16:00+03	36800.00
04780D	2017-08-04 20:45:00+03	76800.00
047837	2017-07-01 17:45:00+03	168000.00
0478F2	2017-08-11 07:23:00+03	59300.00
047936	2017-07-25 18:45:00+03	39500.00
047942	2017-08-11 04:53:00+03	520600.00
04795A	2017-07-24 14:59:00+03	135400.00
047A33	2017-07-28 01:38:00+03	36200.00
047B23	2017-08-13 13:29:00+03	25100.00
047B53	2017-08-05 11:00:00+03	99300.00
047B6D	2017-08-02 22:14:00+03	44000.00
047BC0	2017-07-08 14:08:00+03	131600.00
047C62	2017-07-30 07:15:00+03	89700.00
047CCB	2017-07-10 23:55:00+03	46500.00
047D7A	2017-07-26 19:01:00+03	83700.00
047D98	2017-07-17 16:31:00+03	65500.00
047DDA	2017-08-15 03:41:00+03	62400.00
047DFC	2017-08-12 18:11:00+03	76300.00
047E12	2017-08-11 22:24:00+03	8200.00
047E50	2017-08-02 06:46:00+03	58400.00
047E77	2017-07-22 04:02:00+03	75300.00
047E8F	2017-07-24 21:58:00+03	19600.00
047E9C	2017-07-16 20:30:00+03	23400.00
047EDE	2017-07-11 11:08:00+03	115900.00
047F28	2017-08-01 21:29:00+03	36500.00
047F74	2017-08-10 14:35:00+03	69500.00
047FDF	2017-07-10 23:50:00+03	20000.00
048005	2017-07-21 19:12:00+03	20600.00
048019	2017-07-23 03:30:00+03	80000.00
048056	2017-07-02 05:39:00+03	272300.00
0480F4	2017-08-10 15:27:00+03	192700.00
04810B	2017-07-24 10:19:00+03	38800.00
04816B	2017-07-08 20:00:00+03	66600.00
048172	2017-07-31 02:04:00+03	28000.00
04817D	2017-07-15 15:28:00+03	92000.00
048213	2017-07-09 18:05:00+03	60600.00
048241	2017-07-25 00:41:00+03	46400.00
048292	2017-07-25 05:39:00+03	112000.00
0482A6	2017-07-16 04:05:00+03	58000.00
048305	2017-07-26 23:58:00+03	23600.00
04831C	2017-07-27 18:37:00+03	16400.00
048361	2017-07-05 18:40:00+03	56000.00
04836E	2017-07-15 08:52:00+03	47000.00
048393	2017-07-07 17:27:00+03	137100.00
0483B7	2017-07-22 00:48:00+03	22000.00
0483FC	2017-07-24 21:51:00+03	492000.00
048501	2017-07-01 20:07:00+03	25000.00
048523	2017-08-11 23:02:00+03	14000.00
048610	2017-07-25 11:18:00+03	6000.00
04865F	2017-07-22 10:47:00+03	161800.00
0486D0	2017-08-05 22:34:00+03	66600.00
048718	2017-07-26 02:47:00+03	55800.00
04877D	2017-07-02 15:13:00+03	164500.00
0487CA	2017-08-15 12:23:00+03	81600.00
0487CE	2017-07-13 12:42:00+03	31400.00
048808	2017-07-19 17:18:00+03	57700.00
04881D	2017-08-13 10:09:00+03	59300.00
048842	2017-07-18 06:51:00+03	67400.00
048861	2017-07-15 03:56:00+03	194300.00
048882	2017-08-10 09:38:00+03	60400.00
04888F	2017-08-11 17:11:00+03	28800.00
048890	2017-07-24 11:06:00+03	26200.00
0488DA	2017-07-23 23:23:00+03	66600.00
0488F7	2017-07-11 12:54:00+03	26800.00
0488F8	2017-08-08 13:58:00+03	31600.00
0489E4	2017-07-15 06:02:00+03	243700.00
048A02	2017-07-24 16:32:00+03	123000.00
048A79	2017-07-23 09:49:00+03	25000.00
048AE9	2017-08-03 03:25:00+03	63300.00
048B1D	2017-07-21 02:00:00+03	50700.00
048B5C	2017-07-16 19:32:00+03	29600.00
048B95	2017-08-13 01:39:00+03	19600.00
048BB9	2017-07-09 19:41:00+03	81500.00
048BD6	2017-07-13 02:13:00+03	62600.00
048C63	2017-07-29 08:06:00+03	230000.00
048C7E	2017-08-14 14:27:00+03	80700.00
048D52	2017-08-08 06:55:00+03	36200.00
048D59	2017-08-14 15:06:00+03	46800.00
048D5E	2017-07-19 01:29:00+03	73600.00
048E02	2017-07-19 04:45:00+03	89600.00
048E31	2017-08-09 03:07:00+03	149300.00
048E34	2017-07-25 06:29:00+03	156500.00
048E3A	2017-07-03 02:40:00+03	37200.00
048E4B	2017-08-01 23:58:00+03	20600.00
048EAF	2017-08-15 02:26:00+03	124200.00
048EC1	2017-07-10 06:44:00+03	265600.00
048ED3	2017-07-26 12:19:00+03	26800.00
048EF5	2017-07-06 02:40:00+03	86400.00
048FA6	2017-07-05 14:47:00+03	26800.00
049029	2017-08-12 08:56:00+03	85000.00
049047	2017-08-06 07:13:00+03	108500.00
04905D	2017-07-13 07:28:00+03	44000.00
049069	2017-07-07 06:48:00+03	42000.00
049071	2017-07-25 03:26:00+03	29400.00
049093	2017-07-13 02:41:00+03	8400.00
0490B3	2017-07-04 18:31:00+03	172100.00
0490BE	2017-07-03 15:09:00+03	32800.00
0490CA	2017-06-29 05:46:00+03	272300.00
0490E2	2017-08-08 16:13:00+03	85700.00
0490E8	2017-08-14 22:16:00+03	46400.00
049134	2017-08-05 09:28:00+03	24400.00
04914D	2017-08-10 09:43:00+03	78200.00
0491A7	2017-07-24 07:02:00+03	56000.00
0491F4	2017-07-16 20:40:00+03	14400.00
049235	2017-07-31 07:18:00+03	70600.00
0492A1	2017-06-28 18:36:00+03	67600.00
0492A9	2017-07-20 11:46:00+03	81500.00
0492CE	2017-08-06 01:13:00+03	7400.00
049324	2017-07-28 06:10:00+03	23100.00
0493D8	2017-08-10 00:18:00+03	67600.00
0493EB	2017-07-05 04:19:00+03	227500.00
049445	2017-08-06 18:22:00+03	27700.00
04948A	2017-07-10 06:46:00+03	23200.00
0494A0	2017-07-31 18:32:00+03	89600.00
0494C9	2017-08-07 18:54:00+03	37500.00
04952D	2017-07-04 16:31:00+03	43100.00
04954C	2017-07-29 08:19:00+03	14000.00
049555	2017-08-03 08:30:00+03	141100.00
04958B	2017-07-26 20:18:00+03	130400.00
04959E	2017-07-18 04:14:00+03	47200.00
0495CB	2017-07-16 13:35:00+03	24800.00
0495E2	2017-07-06 07:02:00+03	8000.00
0495E3	2017-07-05 00:03:00+03	58600.00
04963B	2017-07-15 03:36:00+03	65600.00
0496E7	2017-08-15 08:11:00+03	24000.00
0496F6	2017-07-23 04:56:00+03	116800.00
04971B	2017-08-12 04:03:00+03	54100.00
04974C	2017-08-13 08:53:00+03	14400.00
0497B0	2017-07-15 04:18:00+03	22400.00
0497B6	2017-07-20 07:41:00+03	38200.00
0497D3	2017-07-20 05:41:00+03	266200.00
0497D7	2017-08-08 17:03:00+03	71900.00
0497F2	2017-08-15 01:46:00+03	12600.00
049829	2017-08-09 10:12:00+03	73300.00
049831	2017-07-16 02:29:00+03	28800.00
049882	2017-07-09 03:38:00+03	26000.00
049898	2017-07-25 20:22:00+03	89000.00
0498C2	2017-07-03 02:43:00+03	40800.00
04994F	2017-08-03 17:40:00+03	64500.00
049A09	2017-08-04 21:18:00+03	43600.00
049A16	2017-07-22 10:09:00+03	23200.00
049AF3	2017-07-21 23:47:00+03	35400.00
049B0B	2017-07-09 09:16:00+03	16400.00
049B56	2017-08-10 18:09:00+03	114500.00
049B82	2017-07-01 15:26:00+03	86500.00
049C67	2017-08-04 03:25:00+03	25400.00
049C8F	2017-07-15 12:52:00+03	47000.00
049CA8	2017-07-23 13:36:00+03	25800.00
049CE9	2017-07-04 05:38:00+03	21800.00
049D7E	2017-07-22 06:48:00+03	21800.00
049DF8	2017-07-14 22:21:00+03	56000.00
049E06	2017-07-27 17:52:00+03	44600.00
049E50	2017-07-16 19:16:00+03	278200.00
049E5D	2017-07-04 21:20:00+03	10800.00
049E8F	2017-08-01 17:01:00+03	95600.00
049EB3	2017-08-10 16:24:00+03	18000.00
049EDA	2017-07-31 19:37:00+03	59200.00
049EE9	2017-08-10 06:26:00+03	59200.00
049EEC	2017-07-06 15:58:00+03	56100.00
049F04	2017-08-01 13:36:00+03	85000.00
049F24	2017-08-09 20:49:00+03	54500.00
049F6E	2017-08-04 18:54:00+03	122500.00
049FA5	2017-08-04 13:59:00+03	111600.00
049FD7	2017-07-26 03:28:00+03	226200.00
049FDF	2017-08-04 22:40:00+03	81700.00
049FEB	2017-06-30 07:36:00+03	10800.00
04A008	2017-07-29 05:14:00+03	131100.00
04A011	2017-08-13 04:47:00+03	10100.00
04A02E	2017-07-28 16:44:00+03	97800.00
04A038	2017-08-05 07:46:00+03	40800.00
04A073	2017-07-17 22:26:00+03	119300.00
04A0B1	2017-07-09 08:15:00+03	86600.00
04A0CB	2017-08-12 17:38:00+03	17200.00
04A144	2017-06-26 16:59:00+03	40800.00
04A19D	2017-07-24 22:58:00+03	166000.00
04A1E0	2017-07-04 20:56:00+03	112000.00
04A1F8	2017-08-09 12:41:00+03	191500.00
04A2E0	2017-07-31 17:40:00+03	36200.00
04A31F	2017-08-13 14:24:00+03	22400.00
04A36D	2017-07-15 05:33:00+03	27200.00
04A398	2017-07-14 10:30:00+03	32900.00
04A3C7	2017-08-09 19:37:00+03	139300.00
04A3DE	2017-08-01 22:05:00+03	13700.00
04A402	2017-07-20 08:39:00+03	55600.00
04A410	2017-08-01 18:29:00+03	47000.00
04A490	2017-08-05 02:22:00+03	26700.00
04A4B0	2017-07-24 01:28:00+03	36200.00
04A4B9	2017-07-09 05:26:00+03	76600.00
04A4EF	2017-07-14 05:30:00+03	269400.00
04A582	2017-08-06 08:56:00+03	82900.00
04A58A	2017-07-09 17:34:00+03	34000.00
04A5BF	2017-07-02 05:49:00+03	24400.00
04A5E2	2017-07-03 09:38:00+03	112600.00
04A5FD	2017-07-25 09:59:00+03	59800.00
04A616	2017-07-06 11:23:00+03	199700.00
04A624	2017-08-06 09:15:00+03	58100.00
04A64E	2017-08-08 09:37:00+03	46000.00
04A6A1	2017-08-01 14:44:00+03	6700.00
04A726	2017-08-06 02:14:00+03	42900.00
04A783	2017-08-13 04:28:00+03	56900.00
04A790	2017-07-06 11:05:00+03	84800.00
04A807	2017-07-30 08:33:00+03	58400.00
04A81C	2017-07-10 22:12:00+03	97700.00
04A8A6	2017-07-10 12:26:00+03	57300.00
04A8B0	2017-07-07 22:41:00+03	44000.00
04A8B8	2017-07-31 13:55:00+03	89200.00
04A948	2017-07-09 07:23:00+03	14400.00
04A972	2017-08-09 01:49:00+03	101200.00
04A99F	2017-07-09 15:35:00+03	20400.00
04A9EB	2017-08-14 19:58:00+03	58700.00
04AA24	2017-08-15 07:37:00+03	24300.00
04AA44	2017-07-11 23:08:00+03	105000.00
04AA5F	2017-07-07 00:21:00+03	62700.00
04AAB1	2017-07-05 11:25:00+03	14000.00
04ABA3	2017-08-15 05:03:00+03	31900.00
04ABD7	2017-07-01 17:17:00+03	51500.00
04ABFC	2017-08-11 20:55:00+03	88600.00
04AC07	2017-08-15 09:36:00+03	31700.00
04AC33	2017-07-06 23:27:00+03	105000.00
04AC69	2017-07-07 01:57:00+03	56000.00
04AC8A	2017-07-12 15:08:00+03	199700.00
04AC9E	2017-07-11 22:38:00+03	7400.00
04ACA1	2017-08-08 17:25:00+03	42900.00
04ACC0	2017-07-02 01:22:00+03	75600.00
04ACEE	2017-07-30 14:32:00+03	99300.00
04AD3E	2017-07-01 23:11:00+03	58700.00
04AE07	2017-07-26 19:08:00+03	64600.00
04AE35	2017-07-04 04:35:00+03	187600.00
04AE48	2017-07-10 18:07:00+03	193100.00
04AE53	2017-07-15 14:30:00+03	66100.00
04AE7D	2017-08-13 04:34:00+03	57400.00
04AF34	2017-07-15 16:11:00+03	76100.00
04AF47	2017-08-12 01:23:00+03	189800.00
04B08E	2017-07-19 03:33:00+03	51600.00
04B0CE	2017-07-02 00:20:00+03	14800.00
04B0E7	2017-07-03 18:38:00+03	10600.00
04B0E8	2017-06-28 16:06:00+03	60400.00
04B0F6	2017-07-04 03:39:00+03	35700.00
04B119	2017-08-06 18:51:00+03	74400.00
04B1CB	2017-07-11 20:01:00+03	39600.00
04B1D8	2017-07-03 23:17:00+03	31100.00
04B1DE	2017-08-02 04:52:00+03	11600.00
04B222	2017-08-12 11:50:00+03	55800.00
04B235	2017-06-25 09:47:00+03	41200.00
04B238	2017-07-28 21:59:00+03	40800.00
04B23A	2017-08-10 20:40:00+03	31400.00
04B23E	2017-07-12 06:04:00+03	24800.00
04B251	2017-07-19 02:53:00+03	48400.00
04B27E	2017-07-07 05:47:00+03	179200.00
04B2B6	2017-07-12 17:07:00+03	71500.00
04B2F2	2017-08-05 14:57:00+03	8400.00
04B301	2017-07-23 19:54:00+03	243700.00
04B33F	2017-07-11 05:15:00+03	135000.00
04B405	2017-07-30 14:12:00+03	90400.00
04B472	2017-07-27 09:59:00+03	51600.00
04B48A	2017-07-27 21:53:00+03	40100.00
04B496	2017-07-11 23:11:00+03	103300.00
04B55A	2017-07-01 18:06:00+03	19600.00
04B5DB	2017-08-01 03:36:00+03	57600.00
04B674	2017-07-05 09:42:00+03	28800.00
04B67C	2017-07-29 11:43:00+03	6700.00
04B780	2017-08-12 14:25:00+03	198500.00
04B798	2017-07-06 07:20:00+03	279600.00
04B7A2	2017-06-30 10:12:00+03	234700.00
04B7D3	2017-07-17 18:36:00+03	148700.00
04B80C	2017-07-09 02:40:00+03	54000.00
04B878	2017-07-15 13:29:00+03	67700.00
04B892	2017-07-23 23:29:00+03	65200.00
04B8CF	2017-07-17 01:02:00+03	22000.00
04B8FF	2017-08-07 16:49:00+03	53200.00
04B909	2017-07-14 03:38:00+03	59300.00
04B960	2017-08-10 11:16:00+03	22600.00
04B965	2017-07-09 13:40:00+03	139500.00
04B969	2017-07-06 23:03:00+03	21400.00
04B979	2017-08-10 00:11:00+03	67600.00
04B98A	2017-07-27 00:22:00+03	35400.00
04BA67	2017-08-11 12:26:00+03	26800.00
04BAD5	2017-07-06 23:11:00+03	75300.00
04BB76	2017-07-24 20:03:00+03	67300.00
04BB81	2017-07-20 11:30:00+03	28000.00
04BBA0	2017-08-14 03:13:00+03	45100.00
04BBAD	2017-08-12 03:32:00+03	32800.00
04BC77	2017-07-08 23:40:00+03	23900.00
04BCE1	2017-08-08 00:46:00+03	24800.00
04BDD9	2017-07-11 06:29:00+03	88200.00
04BDED	2017-08-05 01:07:00+03	47000.00
04BE3D	2017-08-07 10:09:00+03	46700.00
04BE51	2017-07-20 04:33:00+03	65900.00
04BE61	2017-07-27 10:34:00+03	23200.00
04BE68	2017-07-14 09:25:00+03	62000.00
04BF0C	2017-07-25 12:25:00+03	55100.00
04C08D	2017-07-25 05:43:00+03	28000.00
04C125	2017-08-12 06:08:00+03	47400.00
04C1CB	2017-07-11 02:32:00+03	36200.00
04C204	2017-07-22 02:12:00+03	202700.00
04C26B	2017-08-09 14:14:00+03	54800.00
04C310	2017-07-21 12:54:00+03	97500.00
04C3A4	2017-08-06 05:26:00+03	123000.00
04C3B9	2017-07-20 23:57:00+03	103800.00
04C3D5	2017-07-08 11:22:00+03	42800.00
04C3E7	2017-07-08 02:27:00+03	66400.00
04C452	2017-07-24 14:57:00+03	24400.00
04C47C	2017-08-13 09:19:00+03	36100.00
04C4F9	2017-07-09 17:50:00+03	85000.00
04C513	2017-07-09 12:41:00+03	59200.00
04C545	2017-08-02 10:16:00+03	112000.00
04C546	2017-08-13 21:43:00+03	64600.00
04C572	2017-07-06 20:13:00+03	35700.00
04C575	2017-07-10 17:18:00+03	21000.00
04C655	2017-08-11 02:10:00+03	17200.00
04C718	2017-08-14 19:50:00+03	40000.00
04C728	2017-07-07 16:24:00+03	136000.00
04C76C	2017-07-28 13:40:00+03	12400.00
04C7E2	2017-08-14 17:48:00+03	91100.00
04C7EA	2017-07-16 11:51:00+03	6700.00
04C918	2017-07-23 15:27:00+03	28000.00
04C9B0	2017-07-31 15:25:00+03	67700.00
04C9E7	2017-08-09 04:19:00+03	56000.00
04CA36	2017-07-09 13:17:00+03	23200.00
04CA7D	2017-07-05 20:46:00+03	146200.00
04CA86	2017-07-25 23:37:00+03	58600.00
04CAE0	2017-08-13 14:21:00+03	49800.00
04CAE4	2017-07-22 13:27:00+03	112000.00
04CAF3	2017-06-30 04:05:00+03	59800.00
04CB2A	2017-06-30 18:26:00+03	54700.00
04CB2C	2017-06-29 09:25:00+03	64100.00
04CB6A	2017-08-01 08:09:00+03	28300.00
04CB82	2017-06-30 14:00:00+03	116000.00
04CC15	2017-08-10 09:03:00+03	126600.00
04CCFE	2017-07-12 04:53:00+03	44800.00
04CD3D	2017-07-24 10:11:00+03	87200.00
04CD47	2017-08-14 14:25:00+03	116100.00
04CD6E	2017-07-16 04:28:00+03	136800.00
04CD72	2017-08-04 21:57:00+03	47200.00
04CD7E	2017-07-17 09:20:00+03	72800.00
04CD83	2017-07-08 07:28:00+03	107300.00
04CDC1	2017-08-13 23:11:00+03	119600.00
04CE07	2017-07-02 01:35:00+03	68800.00
04CEC5	2017-07-08 16:53:00+03	73600.00
04CEF8	2017-07-27 10:58:00+03	40000.00
04CF0C	2017-08-04 22:28:00+03	63400.00
04CF5C	2017-07-26 23:08:00+03	112000.00
04D089	2017-07-22 19:33:00+03	123000.00
04D091	2017-07-16 15:17:00+03	65900.00
04D0B8	2017-07-22 17:25:00+03	88500.00
04D125	2017-08-09 07:02:00+03	76200.00
04D130	2017-07-01 01:00:00+03	56000.00
04D136	2017-07-01 14:29:00+03	109200.00
04D13E	2017-08-11 21:01:00+03	29600.00
04D171	2017-08-10 14:27:00+03	36200.00
04D20E	2017-07-19 02:24:00+03	81600.00
04D22C	2017-07-08 14:00:00+03	84500.00
04D234	2017-06-24 16:16:00+03	28600.00
04D24E	2017-07-25 17:00:00+03	72800.00
04D25A	2017-08-13 02:58:00+03	26000.00
04D382	2017-07-10 19:41:00+03	26700.00
04D398	2017-07-31 10:08:00+03	86800.00
04D3DE	2017-07-19 18:04:00+03	22000.00
04D403	2017-07-08 06:01:00+03	40000.00
04D522	2017-07-27 00:02:00+03	218400.00
04D592	2017-07-25 00:49:00+03	114700.00
04D5FA	2017-08-11 21:03:00+03	25100.00
04D602	2017-07-28 21:43:00+03	40800.00
04D6ED	2017-07-17 02:20:00+03	40600.00
04D754	2017-07-18 02:13:00+03	28700.00
04D76B	2017-08-14 22:01:00+03	38000.00
04D7DA	2017-07-01 22:59:00+03	48000.00
04D7F8	2017-07-17 04:19:00+03	6300.00
04D7FB	2017-07-18 10:28:00+03	44000.00
04D825	2017-07-13 11:00:00+03	75600.00
04D89E	2017-07-18 14:18:00+03	58700.00
04D8CF	2017-08-12 01:27:00+03	67500.00
04D8E0	2017-07-02 16:33:00+03	139300.00
04D930	2017-07-05 07:07:00+03	35700.00
04D94F	2017-08-02 09:57:00+03	12600.00
04D956	2017-07-25 13:41:00+03	32900.00
04D9AC	2017-07-20 07:30:00+03	22000.00
04D9AD	2017-07-10 05:01:00+03	22000.00
04D9B9	2017-07-13 02:49:00+03	67100.00
04DA08	2017-07-06 12:37:00+03	153600.00
04DA8C	2017-07-21 18:16:00+03	19600.00
04DA95	2017-08-14 10:52:00+03	83600.00
04DB2B	2017-08-07 01:02:00+03	61800.00
04DB6F	2017-07-18 07:42:00+03	25200.00
04DBCC	2017-07-22 11:51:00+03	103900.00
04DBD2	2017-07-11 13:30:00+03	124200.00
04DBEF	2017-07-31 05:18:00+03	66600.00
04DBFB	2017-08-05 12:58:00+03	332100.00
04DC34	2017-06-29 13:50:00+03	21500.00
04DC3B	2017-08-01 06:25:00+03	56000.00
04DC3F	2017-07-15 13:14:00+03	135700.00
04DC9A	2017-07-08 16:28:00+03	133200.00
04DCA1	2017-07-11 06:16:00+03	95300.00
04DCA8	2017-07-15 12:28:00+03	282100.00
04DCA9	2017-07-15 19:04:00+03	19600.00
04DD35	2017-08-08 10:34:00+03	90400.00
04DD96	2017-07-20 15:49:00+03	63200.00
04DDC7	2017-07-16 23:48:00+03	29100.00
04DE07	2017-08-05 20:38:00+03	34000.00
04DE0A	2017-07-27 13:37:00+03	102100.00
04DE10	2017-08-03 05:05:00+03	75600.00
04DE97	2017-07-25 10:37:00+03	94000.00
04DEEF	2017-07-01 08:02:00+03	44000.00
04DF3D	2017-07-14 19:59:00+03	83600.00
04DF89	2017-07-15 22:21:00+03	43900.00
04DFF8	2017-07-06 21:23:00+03	111600.00
04E023	2017-07-07 00:46:00+03	82300.00
04E03A	2017-07-07 22:30:00+03	40400.00
04E06E	2017-08-04 00:58:00+03	69000.00
04E0FC	2017-08-14 04:30:00+03	58000.00
04E130	2017-07-22 08:08:00+03	40000.00
04E17F	2017-07-17 04:55:00+03	50600.00
04E19E	2017-07-31 19:33:00+03	37900.00
04E1A6	2017-07-25 00:21:00+03	17600.00
04E232	2017-07-23 17:12:00+03	14000.00
04E285	2017-07-14 23:19:00+03	55600.00
04E2BE	2017-08-13 14:35:00+03	112000.00
04E359	2017-08-02 20:31:00+03	40000.00
04E393	2017-07-07 19:14:00+03	44700.00
04E3B2	2017-08-09 07:56:00+03	90800.00
04E3BC	2017-07-03 08:37:00+03	11800.00
04E41B	2017-07-21 01:43:00+03	112000.00
04E42D	2017-07-06 01:58:00+03	6700.00
04E431	2017-08-09 18:20:00+03	49600.00
04E435	2017-07-03 12:52:00+03	103500.00
04E46B	2017-08-01 10:07:00+03	28800.00
04E50D	2017-07-30 00:32:00+03	47000.00
04E5AC	2017-08-14 22:27:00+03	244600.00
04E5EE	2017-07-26 18:58:00+03	187600.00
04E662	2017-08-13 19:58:00+03	172200.00
04E66D	2017-07-13 23:31:00+03	38200.00
04E6D8	2017-07-05 17:39:00+03	93700.00
04E71B	2017-08-01 19:37:00+03	92100.00
04E73C	2017-07-31 10:50:00+03	42400.00
04E778	2017-07-18 11:18:00+03	67200.00
04E79D	2017-08-07 15:14:00+03	42800.00
04E7C6	2017-07-26 03:37:00+03	14000.00
04E869	2017-07-02 13:44:00+03	92500.00
04E8E1	2017-07-25 06:50:00+03	32800.00
04E8F4	2017-08-08 21:54:00+03	81700.00
04E906	2017-07-27 14:33:00+03	270600.00
04E92D	2017-07-19 20:03:00+03	46400.00
04E969	2017-07-16 16:40:00+03	46000.00
04E99D	2017-08-08 11:08:00+03	47400.00
04E9B6	2017-07-06 05:15:00+03	40400.00
04E9C8	2017-07-10 02:40:00+03	492000.00
04EA31	2017-07-17 19:08:00+03	47000.00
04EA3C	2017-07-01 23:34:00+03	46000.00
04EA5B	2017-07-17 07:34:00+03	103900.00
04EA68	2017-07-15 08:10:00+03	12600.00
04EB2C	2017-07-08 02:49:00+03	153900.00
04EB36	2017-08-12 05:20:00+03	66600.00
04EBAF	2017-07-17 19:57:00+03	26700.00
04EBE7	2017-07-15 05:20:00+03	25400.00
04EBFD	2017-07-21 06:01:00+03	65400.00
04EC2C	2017-08-07 02:31:00+03	31000.00
04EC52	2017-08-04 15:25:00+03	21000.00
04EC69	2017-07-27 02:40:00+03	32700.00
04EC84	2017-07-27 06:21:00+03	58000.00
04ECAC	2017-08-07 00:05:00+03	136100.00
04ECCF	2017-08-13 12:02:00+03	167400.00
04ECD2	2017-08-02 05:31:00+03	31100.00
04ECE9	2017-08-14 13:13:00+03	31700.00
04ED0E	2017-08-10 12:44:00+03	14800.00
04ED12	2017-07-20 22:06:00+03	22200.00
04ED55	2017-07-28 02:12:00+03	40800.00
04EDD0	2017-08-05 11:18:00+03	84800.00
04EE02	2017-07-20 10:03:00+03	56000.00
04EE0B	2017-07-19 20:38:00+03	112000.00
04EE4E	2017-07-03 01:50:00+03	46300.00
04EE53	2017-08-06 13:19:00+03	139300.00
04EE68	2017-07-17 11:18:00+03	73400.00
04EF3C	2017-08-04 22:53:00+03	167400.00
04EF61	2017-07-20 07:48:00+03	46300.00
04EFCB	2017-07-16 20:05:00+03	203300.00
04F064	2017-07-10 02:55:00+03	48800.00
04F170	2017-07-20 03:04:00+03	239700.00
04F180	2017-07-24 05:25:00+03	40000.00
04F1AD	2017-07-12 17:01:00+03	75600.00
04F1DC	2017-08-09 05:09:00+03	214500.00
04F211	2017-07-15 00:28:00+03	23200.00
04F21D	2017-07-19 17:32:00+03	85000.00
04F24C	2017-08-10 03:41:00+03	128100.00
04F254	2017-08-12 11:33:00+03	46400.00
04F2DE	2017-07-18 20:05:00+03	55800.00
04F339	2017-07-04 04:37:00+03	114500.00
04F3E4	2017-07-14 11:35:00+03	24400.00
04F441	2017-07-14 17:54:00+03	40900.00
04F451	2017-07-03 13:29:00+03	39200.00
04F4A6	2017-07-22 22:45:00+03	85500.00
04F4AC	2017-07-05 17:15:00+03	62700.00
04F4D4	2017-07-30 05:59:00+03	92500.00
04F54C	2017-08-11 02:19:00+03	91100.00
04F564	2017-07-01 20:13:00+03	92100.00
04F569	2017-07-24 23:49:00+03	34600.00
04F5C1	2017-07-05 08:19:00+03	43000.00
04F5D2	2017-07-14 14:16:00+03	133200.00
04F62A	2017-08-11 06:13:00+03	13400.00
04F631	2017-08-02 17:21:00+03	22200.00
04F72F	2017-07-23 20:44:00+03	15700.00
04F78D	2017-08-14 05:36:00+03	136200.00
04F79F	2017-07-14 07:44:00+03	32700.00
04F7AD	2017-07-27 18:32:00+03	56000.00
04F889	2017-08-09 13:24:00+03	39300.00
04F8D1	2017-07-19 22:54:00+03	46300.00
04F93A	2017-07-04 14:46:00+03	113800.00
04F974	2017-08-15 10:31:00+03	160800.00
04F975	2017-07-07 15:47:00+03	40300.00
04F9B3	2017-07-18 05:33:00+03	31600.00
04F9CB	2017-08-04 12:18:00+03	84800.00
04FA52	2017-07-31 00:20:00+03	167400.00
04FAF2	2017-07-13 17:50:00+03	75800.00
04FB29	2017-07-23 17:13:00+03	111600.00
04FB47	2017-07-23 16:47:00+03	26000.00
04FB60	2017-08-03 00:48:00+03	59700.00
04FB7C	2017-07-09 23:12:00+03	87000.00
04FBCD	2017-07-17 09:16:00+03	81900.00
04FBEA	2017-07-13 14:10:00+03	6700.00
04FBF0	2017-07-19 12:13:00+03	38000.00
04FBF1	2017-07-05 14:48:00+03	136200.00
04FC09	2017-07-27 12:43:00+03	21200.00
04FC35	2017-08-06 20:20:00+03	738000.00
04FC3C	2017-07-23 14:21:00+03	40800.00
04FCA3	2017-08-12 15:28:00+03	83100.00
04FCD9	2017-08-04 07:39:00+03	28800.00
04FCFC	2017-07-23 19:54:00+03	178700.00
04FD90	2017-07-29 03:27:00+03	90000.00
04FDBF	2017-07-17 09:42:00+03	70200.00
04FDC8	2017-07-27 17:22:00+03	68400.00
04FE1B	2017-08-14 04:35:00+03	80100.00
04FE36	2017-07-26 13:56:00+03	16800.00
04FE8C	2017-08-06 21:37:00+03	189300.00
04FEB0	2017-07-27 18:58:00+03	26000.00
04FEEF	2017-08-10 17:03:00+03	19600.00
04FEFB	2017-07-14 22:58:00+03	135000.00
04FF4B	2017-07-06 02:24:00+03	13600.00
04FF9F	2017-07-04 15:29:00+03	78600.00
04FFC2	2017-07-27 05:59:00+03	63400.00
04FFEE	2017-07-19 01:34:00+03	15900.00
05001B	2017-08-02 10:59:00+03	27200.00
050022	2017-07-05 21:02:00+03	7300.00
05005F	2017-08-11 14:56:00+03	56000.00
0500C6	2017-08-10 02:39:00+03	14800.00
050113	2017-07-26 12:06:00+03	39100.00
050159	2017-07-28 17:53:00+03	35500.00
050161	2017-07-22 03:09:00+03	60400.00
0501DE	2017-07-08 23:01:00+03	36000.00
05020C	2017-08-06 15:06:00+03	396500.00
05027A	2017-07-09 22:13:00+03	33300.00
05029F	2017-07-09 23:59:00+03	131100.00
0502F1	2017-08-09 10:29:00+03	42800.00
05034F	2017-07-01 13:45:00+03	24500.00
050364	2017-07-16 01:27:00+03	170000.00
0503AA	2017-07-04 17:14:00+03	57500.00
0503C1	2017-06-28 23:52:00+03	92100.00
050415	2017-08-05 19:53:00+03	114800.00
050426	2017-07-17 07:12:00+03	44800.00
05045F	2017-07-16 05:45:00+03	22600.00
050463	2017-07-10 04:59:00+03	14400.00
050488	2017-07-12 15:56:00+03	398500.00
050505	2017-07-28 14:26:00+03	55800.00
050558	2017-08-08 09:16:00+03	185600.00
050578	2017-07-18 18:05:00+03	62000.00
050591	2017-07-13 01:46:00+03	66600.00
050594	2017-07-23 19:45:00+03	15100.00
050626	2017-08-15 15:25:00+03	43900.00
050668	2017-07-12 20:08:00+03	57400.00
050671	2017-07-29 02:43:00+03	67800.00
050675	2017-08-07 21:45:00+03	200400.00
050678	2017-07-22 01:00:00+03	18600.00
0506D7	2017-07-19 16:15:00+03	25100.00
05070A	2017-07-16 03:29:00+03	135400.00
050763	2017-07-25 16:12:00+03	186900.00
050782	2017-08-08 00:31:00+03	35800.00
0507D4	2017-07-30 23:26:00+03	260400.00
0507E3	2017-08-06 14:32:00+03	53000.00
05086C	2017-07-06 19:05:00+03	37200.00
05088D	2017-07-26 00:36:00+03	35200.00
0508E9	2017-07-14 15:02:00+03	55800.00
0508EE	2017-08-13 04:41:00+03	56900.00
050982	2017-08-08 05:11:00+03	51300.00
050998	2017-07-25 01:02:00+03	39200.00
050A86	2017-08-14 07:46:00+03	38200.00
050A93	2017-08-01 21:53:00+03	181100.00
050AF6	2017-08-10 14:48:00+03	12000.00
050AFA	2017-07-27 05:25:00+03	93900.00
050B01	2017-07-04 06:27:00+03	22000.00
050B4B	2017-08-02 21:22:00+03	55800.00
050B66	2017-08-09 11:18:00+03	38800.00
050BCC	2017-07-12 07:28:00+03	52600.00
050D19	2017-08-09 19:28:00+03	25400.00
050D55	2017-07-08 00:41:00+03	8200.00
050D66	2017-07-19 02:01:00+03	8000.00
050DC5	2017-07-08 07:09:00+03	8200.00
050DEA	2017-08-13 16:59:00+03	53400.00
050E3B	2017-08-14 15:20:00+03	76400.00
050E3F	2017-08-13 12:46:00+03	62900.00
050EB6	2017-08-01 11:50:00+03	34000.00
050F0B	2017-08-09 11:39:00+03	46600.00
050F21	2017-07-20 12:49:00+03	167500.00
050F3D	2017-08-06 19:54:00+03	26000.00
051003	2017-07-13 01:54:00+03	77900.00
051051	2017-07-30 10:17:00+03	11000.00
0510FD	2017-07-13 05:27:00+03	107700.00
051101	2017-07-24 08:14:00+03	19800.00
05110D	2017-08-08 23:03:00+03	68400.00
051128	2017-08-03 03:19:00+03	37900.00
051139	2017-07-31 20:32:00+03	25200.00
051269	2017-07-25 08:57:00+03	92700.00
051288	2017-07-20 06:48:00+03	72400.00
05139B	2017-07-27 06:39:00+03	112600.00
0513BE	2017-08-12 01:41:00+03	46000.00
0513DA	2017-07-28 20:37:00+03	112000.00
051432	2017-08-11 23:18:00+03	51000.00
05143C	2017-07-02 10:31:00+03	32200.00
05144A	2017-07-18 16:34:00+03	23200.00
05145A	2017-07-06 17:54:00+03	14400.00
0514E4	2017-08-14 09:17:00+03	123000.00
051527	2017-08-15 04:00:00+03	13400.00
05152A	2017-07-21 14:47:00+03	142400.00
051560	2017-08-04 21:10:00+03	80100.00
0515EA	2017-07-29 02:16:00+03	140500.00
051660	2017-08-11 07:56:00+03	40600.00
0516F9	2017-07-12 17:30:00+03	161400.00
051769	2017-08-10 14:07:00+03	124000.00
051795	2017-07-20 20:23:00+03	16400.00
0517F0	2017-07-07 00:19:00+03	133200.00
051805	2017-07-21 20:40:00+03	114800.00
051806	2017-07-31 21:03:00+03	73600.00
05183A	2017-08-14 06:25:00+03	39800.00
05184E	2017-07-25 14:14:00+03	25200.00
0518CD	2017-07-18 14:49:00+03	62900.00
0518D2	2017-07-04 08:51:00+03	123000.00
0518F6	2017-07-29 10:51:00+03	27200.00
05191D	2017-07-11 17:02:00+03	47400.00
051924	2017-07-26 00:48:00+03	43500.00
051975	2017-07-03 04:28:00+03	28000.00
0519C4	2017-07-16 10:28:00+03	39800.00
051A35	2017-07-29 19:55:00+03	110500.00
051A6D	2017-07-22 04:19:00+03	390400.00
051A75	2017-08-13 03:35:00+03	101200.00
051A8E	2017-07-29 06:40:00+03	50700.00
051AE8	2017-07-17 22:13:00+03	24400.00
051B02	2017-07-17 13:08:00+03	24400.00
051B42	2017-06-28 03:52:00+03	54400.00
051B8F	2017-07-01 01:29:00+03	399600.00
051BDD	2017-07-26 21:45:00+03	18700.00
051C01	2017-08-07 10:42:00+03	121400.00
051C0F	2017-07-18 15:24:00+03	10800.00
051CDF	2017-07-01 01:27:00+03	14400.00
051CE5	2017-07-28 13:39:00+03	44600.00
051D15	2017-08-15 06:42:00+03	187600.00
051D1B	2017-07-09 08:23:00+03	36200.00
051D60	2017-07-26 17:15:00+03	64600.00
051D71	2017-07-19 01:38:00+03	30400.00
051DB5	2017-08-08 12:17:00+03	25100.00
051DEA	2017-08-01 17:22:00+03	24700.00
051E6E	2017-08-01 10:28:00+03	47900.00
051E74	2017-08-08 06:57:00+03	70800.00
051E9E	2017-07-23 08:38:00+03	66000.00
051EE6	2017-07-07 07:04:00+03	24400.00
051F5B	2017-06-29 18:33:00+03	90800.00
051F9B	2017-06-26 04:57:00+03	14000.00
051FC5	2017-07-31 03:45:00+03	21800.00
051FDD	2017-08-13 23:13:00+03	21800.00
052047	2017-08-07 13:14:00+03	85600.00
052054	2017-07-06 17:04:00+03	36200.00
052060	2017-06-28 04:51:00+03	29600.00
0520C2	2017-07-29 10:09:00+03	34000.00
05212C	2017-07-30 20:30:00+03	65900.00
05213C	2017-08-09 15:55:00+03	25000.00
052174	2017-07-27 12:09:00+03	43500.00
05223F	2017-08-08 11:36:00+03	83000.00
05224B	2017-07-31 05:20:00+03	37300.00
052286	2017-07-23 18:26:00+03	48800.00
0522A0	2017-07-26 02:00:00+03	70600.00
0522DF	2017-08-11 13:30:00+03	17600.00
05234C	2017-08-01 02:12:00+03	56000.00
052358	2017-07-23 11:27:00+03	58000.00
052415	2017-07-03 07:53:00+03	67000.00
05250A	2017-07-11 21:36:00+03	13600.00
05254B	2017-08-02 06:13:00+03	92900.00
05258C	2017-08-07 13:46:00+03	99200.00
052591	2017-07-14 02:40:00+03	260300.00
052609	2017-08-04 08:33:00+03	114400.00
05267E	2017-07-07 19:31:00+03	369000.00
0526F3	2017-07-07 09:04:00+03	22600.00
052704	2017-08-15 15:37:00+03	14400.00
052747	2017-08-09 13:09:00+03	28800.00
0527A2	2017-07-28 10:47:00+03	79600.00
05283A	2017-07-26 03:35:00+03	92000.00
05285F	2017-08-07 17:25:00+03	28000.00
052908	2017-08-06 15:35:00+03	37000.00
052943	2017-08-06 17:54:00+03	23400.00
052A09	2017-07-30 22:11:00+03	44600.00
052A32	2017-08-05 19:06:00+03	54900.00
052A48	2017-07-19 06:12:00+03	64500.00
052A66	2017-07-20 06:23:00+03	28000.00
052A8C	2017-08-11 01:09:00+03	54100.00
052B15	2017-07-01 05:20:00+03	85000.00
052B5D	2017-08-03 17:43:00+03	86400.00
052B92	2017-06-28 09:41:00+03	64400.00
052BB4	2017-07-09 14:47:00+03	65500.00
052C33	2017-06-30 14:59:00+03	147700.00
052C55	2017-07-04 22:30:00+03	20400.00
052C69	2017-07-29 12:22:00+03	138900.00
052C7E	2017-07-08 02:13:00+03	6000.00
052C83	2017-07-24 09:09:00+03	10700.00
052CC0	2017-08-14 04:37:00+03	134600.00
052D0A	2017-07-15 17:51:00+03	133200.00
052D11	2017-08-15 14:16:00+03	7400.00
052D1D	2017-07-26 14:36:00+03	26000.00
052D46	2017-07-21 18:39:00+03	27300.00
052D65	2017-07-06 02:56:00+03	166100.00
052D81	2017-07-03 01:01:00+03	56000.00
052DD6	2017-08-07 01:34:00+03	91500.00
052DF6	2017-08-08 18:41:00+03	53700.00
052E37	2017-07-26 19:04:00+03	27700.00
052E3D	2017-07-17 06:36:00+03	43200.00
052E47	2017-07-13 05:08:00+03	16000.00
052E4F	2017-07-07 14:33:00+03	105100.00
052E62	2017-07-13 19:46:00+03	32800.00
052E7F	2017-07-31 11:22:00+03	27900.00
052E9C	2017-07-18 09:17:00+03	26000.00
052EA8	2017-07-17 20:14:00+03	138600.00
052EF5	2017-08-02 20:21:00+03	59800.00
052F3F	2017-07-21 00:05:00+03	30000.00
052F41	2017-08-01 01:49:00+03	26000.00
053042	2017-07-10 05:45:00+03	93800.00
0530AE	2017-07-18 03:13:00+03	27500.00
0530BA	2017-07-18 23:43:00+03	57400.00
0530C9	2017-08-14 15:38:00+03	48400.00
053148	2017-07-28 14:44:00+03	303100.00
0531C1	2017-07-26 18:49:00+03	91700.00
0531F0	2017-07-07 22:37:00+03	35200.00
053231	2017-07-16 18:35:00+03	54400.00
05323E	2017-07-04 22:17:00+03	69600.00
053306	2017-07-26 19:54:00+03	27300.00
053319	2017-08-05 18:23:00+03	21400.00
053332	2017-08-12 15:32:00+03	161400.00
053367	2017-07-14 05:24:00+03	179300.00
053476	2017-07-22 09:45:00+03	252200.00
053519	2017-08-10 21:53:00+03	39500.00
053538	2017-07-16 06:25:00+03	39200.00
0535C5	2017-08-15 17:38:00+03	68100.00
053667	2017-07-04 20:32:00+03	48700.00
053686	2017-07-29 08:11:00+03	98700.00
0536B2	2017-08-09 12:38:00+03	147700.00
0536FF	2017-08-10 03:07:00+03	34000.00
053701	2017-07-25 18:44:00+03	123000.00
05372E	2017-07-21 10:49:00+03	56600.00
053750	2017-08-02 07:29:00+03	98400.00
0537C4	2017-07-08 14:00:00+03	3700.00
0537DE	2017-07-16 03:13:00+03	37200.00
0537E9	2017-07-24 02:18:00+03	75600.00
053817	2017-07-23 03:54:00+03	153100.00
05381E	2017-07-29 03:11:00+03	88500.00
05382F	2017-07-17 04:15:00+03	43200.00
053841	2017-07-07 02:10:00+03	54600.00
0538C7	2017-08-07 07:00:00+03	40300.00
053926	2017-08-06 03:06:00+03	29600.00
05394F	2017-07-25 04:48:00+03	57600.00
053951	2017-07-24 07:58:00+03	64500.00
053975	2017-07-30 10:55:00+03	152200.00
0539C3	2017-07-20 21:53:00+03	52000.00
053A1A	2017-07-21 15:09:00+03	44600.00
053A7F	2017-08-12 21:34:00+03	175700.00
053A91	2017-07-15 18:38:00+03	65200.00
053B04	2017-08-13 23:03:00+03	81600.00
053B46	2017-07-13 19:51:00+03	248400.00
053B50	2017-07-28 10:13:00+03	132800.00
053B73	2017-07-16 17:48:00+03	54500.00
053BA6	2017-08-07 13:23:00+03	234000.00
053BCB	2017-07-01 01:08:00+03	82500.00
053BDB	2017-07-04 22:27:00+03	26500.00
053C04	2017-07-16 14:18:00+03	199800.00
053C61	2017-07-11 03:00:00+03	240500.00
053C69	2017-08-04 16:37:00+03	73900.00
053C84	2017-07-27 14:53:00+03	67900.00
053CAA	2017-07-10 14:08:00+03	114100.00
053CDB	2017-07-04 01:05:00+03	40100.00
053CE1	2017-08-05 03:04:00+03	88800.00
053CF1	2017-08-10 12:35:00+03	38400.00
053CF8	2017-07-16 05:29:00+03	122000.00
053D2A	2017-07-19 17:23:00+03	184200.00
053DF9	2017-08-07 21:00:00+03	7300.00
053EDA	2017-08-05 14:08:00+03	273800.00
053EFD	2017-07-14 18:59:00+03	201200.00
053F20	2017-07-07 22:17:00+03	85800.00
053F5B	2017-08-12 08:47:00+03	21800.00
053F5D	2017-08-03 11:06:00+03	68800.00
053F93	2017-07-30 04:26:00+03	29400.00
053FAB	2017-07-11 06:32:00+03	23200.00
053FC4	2017-08-13 06:40:00+03	44800.00
054055	2017-07-25 08:24:00+03	56100.00
05405D	2017-07-24 12:44:00+03	29600.00
054089	2017-07-19 07:02:00+03	110300.00
0540B2	2017-06-30 15:41:00+03	27800.00
0540C1	2017-07-02 22:15:00+03	14700.00
054160	2017-07-17 23:16:00+03	69100.00
054243	2017-08-06 22:59:00+03	291000.00
054392	2017-08-03 14:13:00+03	85700.00
0543D0	2017-08-13 19:16:00+03	46400.00
0543FA	2017-07-14 03:00:00+03	22000.00
05447E	2017-07-03 09:21:00+03	80000.00
0544BB	2017-07-05 15:30:00+03	56000.00
05452A	2017-07-26 13:18:00+03	102700.00
05452D	2017-07-26 09:22:00+03	94200.00
05453B	2017-07-13 17:11:00+03	32800.00
054554	2017-06-26 14:25:00+03	115600.00
0545B8	2017-07-27 19:23:00+03	36200.00
054636	2017-08-08 21:41:00+03	46200.00
054638	2017-07-19 19:05:00+03	64100.00
054650	2017-08-02 17:03:00+03	25600.00
05466E	2017-08-09 14:03:00+03	236000.00
0546AB	2017-07-08 23:23:00+03	10800.00
0546CC	2017-07-18 07:19:00+03	42700.00
0546D0	2017-08-01 02:46:00+03	8000.00
05476B	2017-08-07 21:28:00+03	62800.00
05477F	2017-07-24 17:49:00+03	13600.00
054793	2017-07-02 07:40:00+03	133200.00
05479B	2017-08-13 14:37:00+03	94400.00
0547AC	2017-08-13 01:42:00+03	148700.00
05483A	2017-08-11 14:00:00+03	37800.00
05483D	2017-07-26 19:37:00+03	12400.00
054897	2017-06-27 14:38:00+03	13700.00
0548BD	2017-08-13 08:03:00+03	96800.00
05494F	2017-07-28 19:18:00+03	99600.00
054988	2017-08-12 19:58:00+03	54200.00
0549CD	2017-07-05 01:49:00+03	79300.00
0549F6	2017-08-03 04:48:00+03	6300.00
054A4E	2017-07-22 07:30:00+03	85400.00
054A53	2017-08-10 18:29:00+03	52400.00
054A58	2017-07-16 03:56:00+03	75800.00
054AF4	2017-07-17 00:17:00+03	62900.00
054B12	2017-08-12 22:17:00+03	58200.00
054B62	2017-08-07 16:09:00+03	15800.00
054BBF	2017-08-05 01:28:00+03	23200.00
054BD8	2017-07-09 14:13:00+03	22600.00
054C4D	2017-07-20 00:31:00+03	50600.00
054CD7	2017-07-20 07:41:00+03	40800.00
054CE0	2017-08-08 17:39:00+03	60400.00
054D4E	2017-08-09 00:36:00+03	420500.00
054D69	2017-08-04 08:57:00+03	206400.00
054D83	2017-08-13 21:51:00+03	504400.00
054DFE	2017-08-04 04:52:00+03	116400.00
054E1A	2017-07-20 16:09:00+03	135400.00
054E55	2017-07-30 07:30:00+03	120100.00
054E88	2017-07-22 15:08:00+03	55800.00
054E97	2017-07-07 20:31:00+03	51000.00
054EAC	2017-07-14 05:25:00+03	14000.00
054EB8	2017-08-10 13:00:00+03	20200.00
054EF1	2017-07-22 11:15:00+03	96100.00
054F16	2017-07-15 04:36:00+03	37000.00
054F75	2017-07-04 02:33:00+03	99700.00
054FDE	2017-07-09 07:59:00+03	112000.00
055013	2017-07-06 03:49:00+03	34000.00
05505B	2017-07-03 18:05:00+03	56200.00
0550F4	2017-06-30 05:17:00+03	25200.00
05523D	2017-08-08 23:15:00+03	169900.00
055284	2017-07-05 15:43:00+03	48600.00
0552DA	2017-08-04 23:48:00+03	7200.00
05533B	2017-07-18 12:43:00+03	24600.00
055391	2017-07-11 01:50:00+03	27900.00
0553C0	2017-07-13 00:59:00+03	62800.00
055437	2017-07-23 07:02:00+03	66600.00
055483	2017-08-07 14:30:00+03	40000.00
0554C4	2017-07-18 17:43:00+03	27600.00
05554B	2017-07-27 21:16:00+03	38200.00
0555B5	2017-07-12 04:22:00+03	46000.00
0555E0	2017-07-05 14:37:00+03	173900.00
05560A	2017-08-05 05:08:00+03	28800.00
055684	2017-07-26 17:20:00+03	18300.00
0556CD	2017-08-09 07:05:00+03	532800.00
0556E6	2017-07-10 09:03:00+03	95900.00
0556E9	2017-07-27 01:22:00+03	28300.00
055742	2017-07-09 08:50:00+03	80900.00
055772	2017-07-09 12:49:00+03	89600.00
055797	2017-08-05 00:16:00+03	198400.00
0557BC	2017-07-13 05:22:00+03	173500.00
055816	2017-07-25 06:16:00+03	178700.00
05583D	2017-07-28 06:12:00+03	40800.00
055852	2017-07-06 16:36:00+03	15000.00
055857	2017-07-17 15:59:00+03	14000.00
055858	2017-08-01 17:58:00+03	31400.00
05585A	2017-07-15 04:23:00+03	86600.00
05585C	2017-08-14 04:25:00+03	131200.00
05588D	2017-07-04 18:27:00+03	68800.00
055895	2017-07-15 18:02:00+03	25200.00
0558C8	2017-07-12 09:51:00+03	55800.00
055926	2017-08-04 09:07:00+03	64600.00
05595B	2017-08-09 10:35:00+03	54500.00
055994	2017-07-06 10:47:00+03	181100.00
0559C7	2017-07-03 13:14:00+03	111600.00
055A46	2017-07-24 08:56:00+03	31400.00
055A5E	2017-07-08 16:53:00+03	107500.00
055A87	2017-07-02 15:32:00+03	136000.00
055ABE	2017-08-15 03:18:00+03	16400.00
055AE9	2017-07-05 18:02:00+03	43200.00
055B1A	2017-07-17 14:14:00+03	444600.00
055B49	2017-08-02 05:15:00+03	44100.00
055B4D	2017-08-11 19:34:00+03	48800.00
055BAD	2017-08-12 12:37:00+03	27800.00
055BDC	2017-08-09 05:58:00+03	144700.00
055C99	2017-07-07 05:05:00+03	32200.00
055CAB	2017-07-07 10:32:00+03	29600.00
055CC3	2017-07-19 06:43:00+03	67500.00
055CE5	2017-07-30 18:24:00+03	289800.00
055DB2	2017-08-12 04:31:00+03	135400.00
055DC2	2017-07-14 23:04:00+03	23900.00
055DD3	2017-07-11 01:30:00+03	24700.00
055ED1	2017-07-13 15:05:00+03	106700.00
055EDF	2017-07-17 23:09:00+03	50100.00
055EFE	2017-07-04 00:32:00+03	59800.00
055F53	2017-07-20 23:42:00+03	57300.00
055F7F	2017-07-06 00:35:00+03	18600.00
05606D	2017-08-13 06:59:00+03	330800.00
0560CA	2017-07-21 21:15:00+03	202100.00
056165	2017-08-02 04:35:00+03	260300.00
05616B	2017-07-15 06:16:00+03	22000.00
0561E3	2017-07-24 11:17:00+03	14800.00
0561F9	2017-08-03 13:05:00+03	78300.00
056241	2017-08-11 16:24:00+03	38500.00
0562BE	2017-07-05 16:58:00+03	23400.00
0562C2	2017-07-11 00:04:00+03	89700.00
0562D8	2017-07-04 19:13:00+03	66600.00
0562E2	2017-08-11 22:33:00+03	55800.00
056349	2017-07-08 09:55:00+03	176500.00
056368	2017-07-26 08:53:00+03	117500.00
056398	2017-07-16 05:37:00+03	37900.00
0563BB	2017-07-29 11:33:00+03	68800.00
0563E1	2017-07-16 12:04:00+03	61800.00
0563EF	2017-08-14 15:58:00+03	105000.00
056402	2017-07-09 06:11:00+03	166000.00
056462	2017-07-07 12:04:00+03	40000.00
05647C	2017-06-29 19:58:00+03	75600.00
0564A9	2017-07-01 01:36:00+03	55800.00
0564B4	2017-08-15 07:01:00+03	85700.00
056545	2017-07-07 12:30:00+03	84800.00
056565	2017-07-05 06:03:00+03	80800.00
056664	2017-08-05 12:30:00+03	24700.00
0566A3	2017-08-03 09:19:00+03	52000.00
0566BA	2017-07-17 23:09:00+03	111600.00
0566C2	2017-07-12 00:25:00+03	64800.00
0566CB	2017-07-08 00:03:00+03	144400.00
05671C	2017-07-20 08:27:00+03	24700.00
05671F	2017-07-20 22:31:00+03	99700.00
056721	2017-08-14 17:56:00+03	140300.00
056779	2017-08-06 16:15:00+03	28800.00
0567A0	2017-07-10 19:20:00+03	29400.00
0567FD	2017-07-15 07:57:00+03	14000.00
05685F	2017-07-20 03:56:00+03	27200.00
0568C3	2017-07-18 01:18:00+03	96100.00
0568CB	2017-08-13 03:59:00+03	45100.00
0568F7	2017-07-16 18:17:00+03	50600.00
056967	2017-07-06 13:14:00+03	167400.00
05699B	2017-08-11 20:22:00+03	72600.00
0569B2	2017-08-04 16:54:00+03	37900.00
0569E6	2017-08-13 06:00:00+03	29600.00
0569FB	2017-08-05 15:07:00+03	29400.00
056A10	2017-07-28 13:38:00+03	45400.00
056A16	2017-07-18 16:04:00+03	68100.00
056A1C	2017-08-02 21:09:00+03	24400.00
056A33	2017-08-06 09:10:00+03	92400.00
056A35	2017-08-15 17:38:00+03	70700.00
056A42	2017-07-21 23:23:00+03	240600.00
056A54	2017-08-13 15:49:00+03	51300.00
056A6E	2017-08-12 17:15:00+03	14000.00
056A83	2017-07-31 12:56:00+03	23600.00
056AB1	2017-06-29 09:08:00+03	109800.00
056AD3	2017-07-12 01:15:00+03	36200.00
056B6C	2017-07-04 14:07:00+03	40000.00
056B88	2017-07-12 12:50:00+03	42800.00
056BFB	2017-07-22 17:56:00+03	23600.00
056C13	2017-07-12 07:00:00+03	6000.00
056C4C	2017-08-02 18:52:00+03	48200.00
056C84	2017-07-25 12:43:00+03	67500.00
056CDC	2017-08-06 07:32:00+03	67700.00
056D4E	2017-08-01 09:49:00+03	31200.00
056DB9	2017-07-19 07:41:00+03	26700.00
056DD8	2017-07-16 06:34:00+03	36200.00
056E07	2017-07-31 14:14:00+03	56900.00
056E0C	2017-07-18 23:10:00+03	101200.00
056E57	2017-07-06 12:25:00+03	47000.00
056E59	2017-08-05 15:15:00+03	99600.00
056E72	2017-08-05 08:46:00+03	46200.00
056E93	2017-08-05 11:28:00+03	131600.00
056EAF	2017-07-16 15:33:00+03	57400.00
056EFE	2017-08-09 10:44:00+03	68400.00
056F01	2017-07-19 10:28:00+03	26800.00
056F7F	2017-08-14 00:44:00+03	28800.00
056F82	2017-08-04 03:04:00+03	132000.00
056FC7	2017-07-17 11:02:00+03	341400.00
05702A	2017-08-13 04:50:00+03	93700.00
057045	2017-07-05 10:23:00+03	46000.00
057076	2017-07-18 12:22:00+03	51900.00
057089	2017-08-04 17:03:00+03	28000.00
057103	2017-07-30 17:32:00+03	6700.00
057116	2017-08-10 06:31:00+03	6000.00
057124	2017-07-17 18:49:00+03	173200.00
05719B	2017-07-30 18:12:00+03	47700.00
0571D0	2017-07-14 03:29:00+03	125200.00
0571D1	2017-08-08 18:06:00+03	167400.00
057207	2017-07-28 07:19:00+03	43500.00
057227	2017-07-13 06:44:00+03	133100.00
057258	2017-08-01 11:23:00+03	69600.00
05728B	2017-08-10 01:03:00+03	111600.00
0572AE	2017-07-29 03:27:00+03	136200.00
0572B0	2017-07-24 12:15:00+03	88900.00
0572CB	2017-07-10 21:03:00+03	186900.00
057331	2017-08-12 14:29:00+03	45200.00
057371	2017-07-14 14:59:00+03	142400.00
057387	2017-07-23 07:07:00+03	28800.00
0573BD	2017-07-26 14:12:00+03	28800.00
0573D3	2017-08-10 21:57:00+03	24000.00
0573FC	2017-08-07 22:54:00+03	47500.00
057451	2017-08-15 02:28:00+03	28800.00
057489	2017-07-08 16:28:00+03	43600.00
0574B5	2017-07-15 10:17:00+03	193700.00
057526	2017-07-31 15:29:00+03	101800.00
0575BF	2017-07-18 04:38:00+03	32700.00
0575EF	2017-08-08 15:17:00+03	112600.00
057658	2017-08-02 18:35:00+03	26600.00
05767D	2017-07-26 11:48:00+03	95200.00
057691	2017-07-27 00:00:00+03	16800.00
0576F1	2017-08-14 20:51:00+03	49500.00
05776C	2017-08-09 06:48:00+03	191000.00
057793	2017-07-14 10:41:00+03	103500.00
0577A8	2017-08-06 17:24:00+03	105000.00
0577B5	2017-07-20 03:12:00+03	264000.00
057808	2017-07-10 14:43:00+03	369000.00
057818	2017-07-16 10:12:00+03	115600.00
057873	2017-07-10 20:56:00+03	232100.00
0579B8	2017-07-25 14:42:00+03	54900.00
0579F5	2017-07-30 23:00:00+03	147200.00
057A3B	2017-08-03 21:42:00+03	28000.00
057A41	2017-07-30 03:34:00+03	110500.00
057A4C	2017-08-06 14:24:00+03	89600.00
057AAE	2017-08-15 00:10:00+03	12600.00
057C1C	2017-07-27 16:57:00+03	119400.00
057C3C	2017-07-12 23:06:00+03	75000.00
057C6A	2017-08-06 02:40:00+03	51900.00
057C75	2017-08-03 13:19:00+03	29600.00
057CC2	2017-07-01 20:27:00+03	92900.00
057D57	2017-08-10 02:11:00+03	159800.00
057D64	2017-07-10 23:41:00+03	46000.00
057D8F	2017-08-01 08:51:00+03	48300.00
057DBE	2017-07-22 15:17:00+03	119600.00
057DDA	2017-07-17 20:17:00+03	273400.00
057DDD	2017-07-10 02:59:00+03	6900.00
057E68	2017-07-13 07:16:00+03	109000.00
057E7B	2017-07-23 23:25:00+03	29200.00
057EB6	2017-07-14 15:06:00+03	21800.00
057EC9	2017-06-29 07:27:00+03	140900.00
057ED6	2017-07-19 06:11:00+03	46500.00
057EEF	2017-07-11 03:57:00+03	320400.00
057FB5	2017-08-12 07:39:00+03	34000.00
057FDD	2017-07-25 04:17:00+03	59300.00
05801B	2017-07-18 10:46:00+03	34400.00
058074	2017-07-23 20:44:00+03	135400.00
05809F	2017-08-13 06:30:00+03	114500.00
058115	2017-07-12 23:11:00+03	34400.00
058178	2017-06-30 04:15:00+03	14000.00
05829C	2017-07-05 12:12:00+03	8400.00
0582AF	2017-07-27 23:02:00+03	28000.00
0582DC	2017-07-11 04:02:00+03	114700.00
0583BA	2017-07-05 13:28:00+03	254900.00
0583DF	2017-08-04 20:19:00+03	135400.00
058432	2017-07-15 02:24:00+03	75600.00
058443	2017-07-27 04:11:00+03	111600.00
05847B	2017-07-27 04:26:00+03	61500.00
05848E	2017-07-04 08:34:00+03	25200.00
0584BF	2017-07-30 05:26:00+03	229800.00
0584C5	2017-08-05 19:25:00+03	25200.00
058501	2017-08-11 09:23:00+03	54400.00
058534	2017-08-12 22:47:00+03	67200.00
058588	2017-08-08 20:36:00+03	108000.00
0585A3	2017-07-27 13:02:00+03	46400.00
0585A5	2017-08-01 01:47:00+03	50800.00
05867D	2017-07-13 08:40:00+03	178800.00
058689	2017-08-11 07:53:00+03	56600.00
0586AE	2017-07-27 01:23:00+03	92000.00
0586B0	2017-08-03 06:56:00+03	136400.00
0586EA	2017-07-29 13:50:00+03	90600.00
058761	2017-07-04 06:51:00+03	92800.00
0587E9	2017-07-09 11:02:00+03	419000.00
058857	2017-08-14 19:41:00+03	89700.00
058870	2017-07-25 04:21:00+03	24400.00
05887B	2017-07-14 07:34:00+03	87200.00
0588EF	2017-07-07 01:44:00+03	55900.00
058954	2017-07-12 01:04:00+03	57500.00
05897B	2017-07-02 01:00:00+03	8800.00
058988	2017-07-21 09:38:00+03	123900.00
0589EE	2017-08-10 17:14:00+03	81300.00
058A2D	2017-07-26 13:31:00+03	266400.00
058A7C	2017-07-11 15:14:00+03	29100.00
058A94	2017-07-04 09:55:00+03	164400.00
058AE7	2017-08-06 03:07:00+03	32400.00
058B0E	2017-08-14 00:17:00+03	26800.00
058B3A	2017-07-09 00:34:00+03	167500.00
058B5F	2017-08-03 19:00:00+03	36400.00
058B82	2017-07-06 13:54:00+03	26200.00
058BB3	2017-08-14 14:45:00+03	40700.00
058BB5	2017-07-23 19:07:00+03	45100.00
058BC5	2017-07-18 22:44:00+03	39000.00
058C27	2017-07-16 09:14:00+03	32800.00
058C4B	2017-07-18 03:43:00+03	84500.00
058C53	2017-07-22 05:32:00+03	29400.00
058C97	2017-07-28 21:05:00+03	36200.00
058CA0	2017-07-26 21:14:00+03	57800.00
058D0A	2017-07-31 01:32:00+03	244100.00
058DB2	2017-07-20 19:52:00+03	113700.00
058DB3	2017-08-01 20:39:00+03	51000.00
058DDD	2017-07-20 14:38:00+03	271100.00
058E0A	2017-07-11 03:49:00+03	100600.00
058E36	2017-07-30 05:58:00+03	52000.00
058E51	2017-07-29 07:47:00+03	14000.00
058E80	2017-06-29 17:38:00+03	86800.00
058E88	2017-08-05 15:55:00+03	25600.00
058EBC	2017-08-10 05:36:00+03	29200.00
058F1D	2017-07-08 14:51:00+03	28000.00
058F3B	2017-08-01 04:56:00+03	68400.00
058F75	2017-08-14 23:57:00+03	84100.00
058F7B	2017-07-14 16:47:00+03	42800.00
058FA9	2017-06-30 05:56:00+03	67600.00
058FBC	2017-08-13 06:00:00+03	25600.00
059018	2017-08-04 03:58:00+03	113800.00
05901E	2017-08-10 04:38:00+03	96800.00
059037	2017-08-10 21:47:00+03	40000.00
0590BE	2017-07-20 20:47:00+03	64700.00
059146	2017-08-15 06:45:00+03	106700.00
059149	2017-08-02 03:48:00+03	123700.00
0591A4	2017-08-12 01:45:00+03	29600.00
0591CF	2017-08-07 12:51:00+03	83000.00
0591DA	2017-08-09 12:26:00+03	58900.00
05920D	2017-07-26 09:36:00+03	11300.00
05924B	2017-08-10 16:45:00+03	142800.00
059267	2017-07-22 23:21:00+03	20200.00
05927B	2017-07-07 03:33:00+03	72400.00
05928F	2017-07-05 08:00:00+03	116400.00
05929A	2017-08-07 03:33:00+03	124300.00
0592C3	2017-07-28 23:47:00+03	149400.00
05931C	2017-07-20 17:57:00+03	52000.00
0593AD	2017-07-05 14:50:00+03	131600.00
0593DC	2017-07-15 02:20:00+03	8400.00
0593F4	2017-07-06 17:58:00+03	34400.00
05940A	2017-07-23 11:37:00+03	88100.00
05940C	2017-07-07 04:38:00+03	6700.00
059435	2017-08-13 09:47:00+03	15800.00
059457	2017-08-05 21:49:00+03	30800.00
059488	2017-07-03 04:48:00+03	174400.00
0594B0	2017-08-01 05:25:00+03	136200.00
059503	2017-07-06 04:14:00+03	73600.00
05955D	2017-07-25 13:40:00+03	40800.00
05957F	2017-07-15 22:34:00+03	246000.00
0595AF	2017-07-01 19:27:00+03	128800.00
05968E	2017-07-04 22:43:00+03	75600.00
0596DB	2017-07-16 18:17:00+03	66600.00
059702	2017-07-12 08:47:00+03	41400.00
059727	2017-07-06 20:21:00+03	26000.00
059731	2017-07-28 14:05:00+03	25000.00
059794	2017-07-26 07:48:00+03	23100.00
0597B1	2017-08-09 07:07:00+03	192700.00
0597C5	2017-07-19 07:50:00+03	46500.00
059822	2017-07-11 18:50:00+03	115600.00
0598B1	2017-08-15 07:58:00+03	21800.00
0598E2	2017-07-07 14:38:00+03	23200.00
0599F7	2017-07-29 01:32:00+03	10800.00
059A29	2017-08-10 03:44:00+03	26000.00
059A3A	2017-07-08 14:35:00+03	47000.00
059A6B	2017-07-22 16:16:00+03	115600.00
059A76	2017-07-30 18:47:00+03	53100.00
059A81	2017-07-10 20:55:00+03	15800.00
059A9F	2017-08-03 08:11:00+03	40800.00
059B03	2017-07-27 22:11:00+03	63500.00
059B10	2017-07-03 06:02:00+03	23200.00
059B1E	2017-07-16 20:07:00+03	112000.00
059B68	2017-08-03 03:32:00+03	71600.00
059B9D	2017-07-05 22:33:00+03	28700.00
059C09	2017-08-09 15:19:00+03	11700.00
059C10	2017-08-06 05:29:00+03	55800.00
059C61	2017-07-18 19:58:00+03	56000.00
059C7A	2017-07-31 17:18:00+03	50000.00
059C8C	2017-07-10 01:50:00+03	266400.00
059CD6	2017-07-23 16:31:00+03	88600.00
059CDB	2017-07-29 11:38:00+03	25200.00
059D09	2017-07-18 23:20:00+03	271200.00
059D44	2017-07-08 06:16:00+03	15100.00
059D5E	2017-07-20 10:02:00+03	33000.00
059E32	2017-07-13 21:02:00+03	112000.00
059EF0	2017-07-09 22:33:00+03	76600.00
059FAF	2017-07-04 21:15:00+03	34400.00
059FB3	2017-08-05 01:12:00+03	13200.00
059FC4	2017-07-29 15:43:00+03	40100.00
059FD5	2017-07-28 08:32:00+03	134400.00
05A067	2017-07-01 21:16:00+03	13400.00
05A069	2017-07-30 00:38:00+03	54400.00
05A081	2017-08-04 08:09:00+03	29600.00
05A110	2017-07-31 17:11:00+03	28000.00
05A13E	2017-07-28 01:09:00+03	111700.00
05A1A6	2017-08-14 23:34:00+03	34000.00
05A1D4	2017-07-09 18:14:00+03	132800.00
05A202	2017-07-11 02:28:00+03	12000.00
05A218	2017-07-04 05:37:00+03	119500.00
05A25D	2017-08-07 03:04:00+03	96800.00
05A267	2017-06-30 07:46:00+03	28800.00
05A268	2017-07-14 22:53:00+03	14000.00
05A2CB	2017-07-07 07:08:00+03	8200.00
05A398	2017-07-13 12:12:00+03	60400.00
05A3BC	2017-08-09 15:05:00+03	35700.00
05A3F9	2017-07-08 05:51:00+03	119900.00
05A421	2017-08-10 06:05:00+03	101900.00
05A44D	2017-07-13 21:55:00+03	67200.00
05A472	2017-08-08 02:42:00+03	112000.00
05A4EE	2017-08-12 08:15:00+03	22000.00
05A4F8	2017-07-12 21:33:00+03	246000.00
05A551	2017-07-14 13:03:00+03	281500.00
05A5A9	2017-08-09 12:14:00+03	94000.00
05A682	2017-07-28 21:49:00+03	174000.00
05A6CA	2017-07-13 19:29:00+03	88500.00
05A75C	2017-08-09 08:02:00+03	177600.00
05A777	2017-07-21 20:07:00+03	139400.00
05A803	2017-08-05 08:50:00+03	133200.00
05A8E0	2017-07-31 16:19:00+03	123000.00
05A91A	2017-08-13 05:09:00+03	43800.00
05A96D	2017-08-13 09:02:00+03	46000.00
05A981	2017-08-14 16:51:00+03	18600.00
05A9A3	2017-08-02 11:01:00+03	28800.00
05A9AB	2017-07-25 19:35:00+03	78200.00
05AA46	2017-07-02 22:16:00+03	134400.00
05AAE6	2017-08-13 14:13:00+03	28000.00
05AB16	2017-07-18 05:20:00+03	12000.00
05AB27	2017-07-18 14:51:00+03	46200.00
05AB40	2017-08-09 13:14:00+03	393400.00
05ABD6	2017-07-01 16:48:00+03	65500.00
05ABE9	2017-07-29 16:29:00+03	19600.00
05AC07	2017-07-30 14:02:00+03	57000.00
05AC33	2017-07-25 16:20:00+03	174400.00
05AC46	2017-08-01 01:56:00+03	25200.00
05AC6C	2017-07-29 01:12:00+03	13300.00
05ACE0	2017-08-03 16:36:00+03	23200.00
05ACED	2017-08-09 17:14:00+03	54000.00
05AD1F	2017-07-05 06:38:00+03	6700.00
05AD86	2017-06-29 21:34:00+03	12000.00
05AE59	2017-08-10 09:17:00+03	39300.00
05AED1	2017-07-05 03:23:00+03	67700.00
05AF28	2017-06-26 18:59:00+03	16400.00
05AF52	2017-07-04 19:58:00+03	25600.00
05AF7A	2017-07-09 16:41:00+03	111600.00
05AF8C	2017-07-31 02:05:00+03	92800.00
05AFE6	2017-07-14 17:15:00+03	15000.00
05B02B	2017-07-26 22:06:00+03	13400.00
05B0AF	2017-07-10 19:21:00+03	46400.00
05B0DE	2017-07-30 01:50:00+03	75300.00
05B12F	2017-08-14 07:49:00+03	67600.00
05B150	2017-07-11 20:48:00+03	277000.00
05B164	2017-07-01 22:32:00+03	84500.00
05B18D	2017-07-09 22:01:00+03	129400.00
05B201	2017-07-14 21:52:00+03	32800.00
05B273	2017-07-25 02:42:00+03	34400.00
05B27A	2017-08-04 03:35:00+03	43300.00
05B289	2017-07-22 19:48:00+03	48100.00
05B298	2017-07-29 04:59:00+03	75300.00
05B29F	2017-08-12 17:07:00+03	37700.00
05B2A6	2017-07-28 13:35:00+03	23600.00
05B2BC	2017-07-18 07:38:00+03	60300.00
05B314	2017-07-30 00:47:00+03	114800.00
05B379	2017-07-07 16:57:00+03	59000.00
05B37F	2017-07-01 08:15:00+03	31600.00
05B419	2017-07-24 23:18:00+03	53100.00
05B48E	2017-07-08 23:44:00+03	89700.00
05B499	2017-07-16 13:15:00+03	14000.00
05B4D9	2017-07-05 00:56:00+03	23200.00
05B531	2017-07-24 16:33:00+03	23200.00
05B5DE	2017-07-05 01:05:00+03	40800.00
05B624	2017-07-31 10:34:00+03	62600.00
05B626	2017-07-20 08:19:00+03	189200.00
05B64E	2017-07-03 00:18:00+03	52800.00
05B66B	2017-07-16 14:57:00+03	48800.00
05B66D	2017-07-15 01:02:00+03	130300.00
05B67B	2017-08-14 23:53:00+03	113200.00
05B67C	2017-07-29 04:22:00+03	54800.00
05B73F	2017-08-11 02:14:00+03	18500.00
05B755	2017-07-05 12:18:00+03	23200.00
05B788	2017-07-03 22:49:00+03	36200.00
05B789	2017-08-03 12:22:00+03	58400.00
05B78C	2017-07-26 14:47:00+03	369000.00
05B7C4	2017-08-03 11:17:00+03	14700.00
05B829	2017-07-24 13:05:00+03	45500.00
05B830	2017-07-23 14:31:00+03	12000.00
05B88F	2017-07-19 09:12:00+03	36800.00
05B8CB	2017-07-03 06:18:00+03	42800.00
05B902	2017-07-19 18:03:00+03	52100.00
05B980	2017-08-15 12:14:00+03	131400.00
05B9BA	2017-07-09 05:04:00+03	53300.00
05BA5A	2017-07-06 14:49:00+03	62600.00
05BA88	2017-07-11 09:29:00+03	21400.00
05BAE1	2017-08-13 02:19:00+03	51800.00
05BAF3	2017-07-30 17:14:00+03	115700.00
05BAF4	2017-07-01 11:12:00+03	39200.00
05BAFE	2017-07-03 16:40:00+03	47000.00
05BB0B	2017-07-26 14:41:00+03	6000.00
05BB0E	2017-07-05 21:14:00+03	231800.00
05BB3D	2017-07-26 22:56:00+03	28600.00
05BB6C	2017-07-01 21:01:00+03	229400.00
05BBA3	2017-07-01 21:40:00+03	38500.00
05BBA7	2017-07-27 16:25:00+03	56000.00
05BC2D	2017-08-11 00:08:00+03	43200.00
05BC37	2017-07-28 08:30:00+03	133100.00
05BC58	2017-07-28 19:18:00+03	31000.00
05BC9B	2017-08-02 10:45:00+03	45100.00
05BCD1	2017-07-29 07:49:00+03	56000.00
05BD38	2017-07-17 07:33:00+03	30200.00
05BD77	2017-08-10 22:07:00+03	39800.00
05BDC1	2017-07-21 01:46:00+03	26600.00
05BDD6	2017-07-17 08:28:00+03	115100.00
05BE5D	2017-07-18 02:53:00+03	20600.00
05BE84	2017-07-16 12:40:00+03	16400.00
05BED6	2017-08-09 12:34:00+03	26000.00
05BF0E	2017-07-20 08:47:00+03	49800.00
05BF2D	2017-08-08 09:45:00+03	73600.00
05BF3F	2017-08-07 10:37:00+03	8400.00
05BF46	2017-07-11 13:56:00+03	144000.00
05BF63	2017-07-04 00:51:00+03	45200.00
05BFA4	2017-07-06 09:17:00+03	24000.00
05BFD6	2017-07-30 22:59:00+03	60400.00
05C000	2017-07-25 07:22:00+03	107800.00
05C032	2017-07-04 15:55:00+03	105600.00
05C060	2017-07-08 19:52:00+03	45100.00
05C07E	2017-07-21 11:30:00+03	101200.00
05C113	2017-07-05 09:55:00+03	14000.00
05C15B	2017-08-09 02:20:00+03	83000.00
05C163	2017-07-18 14:26:00+03	23200.00
05C164	2017-08-07 14:12:00+03	105200.00
05C16E	2017-07-04 03:23:00+03	132800.00
05C1D6	2017-07-02 10:39:00+03	85600.00
05C1EC	2017-06-25 15:58:00+03	73500.00
05C253	2017-07-14 03:18:00+03	113600.00
05C28B	2017-07-31 05:15:00+03	129400.00
05C2D1	2017-08-03 10:10:00+03	56000.00
05C2D2	2017-08-09 18:56:00+03	71900.00
05C2F1	2017-07-21 22:03:00+03	66600.00
05C2FE	2017-07-07 07:52:00+03	23200.00
05C310	2017-07-30 07:15:00+03	51300.00
05C319	2017-08-02 05:32:00+03	32800.00
05C361	2017-08-13 12:02:00+03	34000.00
05C392	2017-07-30 10:16:00+03	44800.00
05C3A1	2017-08-13 03:32:00+03	58400.00
05C3B4	2017-07-29 09:38:00+03	39300.00
05C3F5	2017-07-10 09:02:00+03	123000.00
05C426	2017-07-02 06:00:00+03	73600.00
05C42D	2017-07-03 13:51:00+03	12600.00
05C43C	2017-06-30 14:10:00+03	124000.00
05C44B	2017-08-08 21:08:00+03	31600.00
05C46B	2017-07-30 23:40:00+03	68100.00
05C476	2017-08-05 06:24:00+03	118200.00
05C49B	2017-08-06 11:53:00+03	467000.00
05C4B0	2017-07-16 23:05:00+03	49400.00
05C511	2017-08-04 11:06:00+03	136800.00
05C51D	2017-08-04 09:38:00+03	8200.00
05C528	2017-07-07 04:09:00+03	36400.00
05C5B8	2017-07-16 06:47:00+03	44800.00
05C5CC	2017-07-30 23:24:00+03	187600.00
05C5F9	2017-08-12 18:49:00+03	23100.00
05C5FA	2017-07-05 11:58:00+03	69000.00
05C629	2017-08-10 11:02:00+03	26800.00
05C688	2017-07-08 05:38:00+03	47400.00
05C7B7	2017-07-14 14:56:00+03	36200.00
05C804	2017-08-15 16:29:00+03	19600.00
05C854	2017-08-05 22:59:00+03	34200.00
05C85E	2017-08-08 02:46:00+03	185800.00
05C8CD	2017-07-21 18:41:00+03	112200.00
05C8D2	2017-07-15 13:59:00+03	89700.00
05C926	2017-07-23 10:27:00+03	56600.00
05C9E8	2017-07-26 11:25:00+03	39400.00
05C9F5	2017-08-01 18:25:00+03	86800.00
05CA27	2017-08-04 07:49:00+03	184300.00
05CA54	2017-07-04 02:35:00+03	180000.00
05CAE4	2017-08-03 08:10:00+03	56000.00
05CC14	2017-07-26 21:04:00+03	23200.00
05CC87	2017-08-05 04:33:00+03	33300.00
05CCF8	2017-07-18 06:58:00+03	75300.00
05CD5C	2017-07-10 12:20:00+03	68800.00
05CD63	2017-06-27 19:38:00+03	91800.00
05CD66	2017-07-22 05:40:00+03	136500.00
05CD86	2017-08-10 07:01:00+03	23400.00
05CDF0	2017-07-10 02:46:00+03	112000.00
05CDF3	2017-07-23 20:01:00+03	42800.00
05CDFA	2017-08-07 14:09:00+03	119800.00
05CE5C	2017-08-15 00:49:00+03	22100.00
05CE87	2017-07-29 20:35:00+03	91600.00
05CF2D	2017-08-07 18:44:00+03	91800.00
05CF2F	2017-08-03 08:48:00+03	28800.00
05CF75	2017-08-11 12:36:00+03	116500.00
05CFE3	2017-08-01 21:52:00+03	6000.00
05CFF1	2017-07-13 18:25:00+03	160700.00
05D00E	2017-07-30 14:42:00+03	28000.00
05D025	2017-08-10 04:24:00+03	6400.00
05D02F	2017-07-17 12:19:00+03	136500.00
05D064	2017-07-18 23:48:00+03	19600.00
05D08D	2017-07-13 19:53:00+03	25400.00
05D0BF	2017-07-27 19:38:00+03	84500.00
05D19A	2017-07-10 14:16:00+03	16400.00
05D1B8	2017-07-22 17:23:00+03	67600.00
05D1C2	2017-06-29 04:20:00+03	80000.00
05D219	2017-08-13 19:50:00+03	13000.00
05D278	2017-07-11 09:03:00+03	91400.00
05D27B	2017-07-09 11:01:00+03	46400.00
05D2A0	2017-07-21 20:28:00+03	25200.00
05D2A8	2017-08-01 05:56:00+03	24800.00
05D32E	2017-07-26 20:56:00+03	45100.00
05D331	2017-08-01 16:20:00+03	41600.00
05D394	2017-07-22 16:52:00+03	38500.00
05D3A1	2017-08-06 03:19:00+03	106400.00
05D47C	2017-06-30 13:48:00+03	79700.00
05D482	2017-07-07 00:27:00+03	143200.00
05D485	2017-08-14 20:19:00+03	133100.00
05D555	2017-07-31 07:45:00+03	7200.00
05D5B4	2017-08-05 13:19:00+03	67700.00
05D5C8	2017-07-30 17:42:00+03	31600.00
05D622	2017-07-31 07:43:00+03	68100.00
05D662	2017-07-02 11:13:00+03	272400.00
05D686	2017-07-04 04:18:00+03	39800.00
05D6B3	2017-07-23 06:08:00+03	116000.00
05D6C0	2017-07-26 13:58:00+03	60400.00
05D77F	2017-07-30 21:42:00+03	26800.00
05D7D6	2017-07-24 18:31:00+03	131800.00
05D832	2017-06-30 01:19:00+03	14700.00
05D84A	2017-08-11 21:21:00+03	131800.00
05D85D	2017-08-07 14:09:00+03	94200.00
05D8C1	2017-07-19 05:55:00+03	22000.00
05D8DB	2017-07-14 16:04:00+03	35400.00
05D8E0	2017-07-23 21:40:00+03	119500.00
05D8E4	2017-07-29 17:51:00+03	8400.00
05D95B	2017-07-21 03:03:00+03	30200.00
05D95F	2017-07-18 05:00:00+03	13400.00
05D967	2017-07-22 01:25:00+03	44000.00
05D9BB	2017-07-08 08:34:00+03	54800.00
05D9FB	2017-06-25 05:30:00+03	23200.00
05DA4E	2017-07-27 04:09:00+03	22000.00
05DA56	2017-07-30 18:50:00+03	52400.00
05DAC4	2017-07-12 03:44:00+03	30000.00
05DB52	2017-07-04 18:15:00+03	86400.00
05DB67	2017-07-06 12:17:00+03	31600.00
05DB9B	2017-07-15 06:54:00+03	46000.00
05DBB6	2017-07-10 23:01:00+03	37900.00
05DC6C	2017-07-12 15:41:00+03	58400.00
05DC6E	2017-08-01 00:51:00+03	75600.00
05DC83	2017-07-09 22:38:00+03	119500.00
05DC9F	2017-07-13 06:21:00+03	199700.00
05DCB5	2017-07-18 21:23:00+03	17800.00
05DCB9	2017-07-29 06:30:00+03	40800.00
05DCC7	2017-07-26 14:08:00+03	39300.00
05DD2B	2017-07-05 10:27:00+03	79900.00
05DD8C	2017-07-12 03:09:00+03	111600.00
05DE53	2017-08-02 11:58:00+03	145400.00
05DF27	2017-08-14 04:46:00+03	98300.00
05DF37	2017-07-08 10:59:00+03	40800.00
05DF40	2017-07-13 05:04:00+03	33000.00
05DF7D	2017-08-12 12:00:00+03	81000.00
05DF83	2017-07-12 05:49:00+03	36200.00
05E00E	2017-08-03 18:23:00+03	90400.00
05E017	2017-07-20 14:32:00+03	83700.00
05E055	2017-07-26 00:01:00+03	51900.00
05E07C	2017-07-25 17:59:00+03	138600.00
05E088	2017-07-16 23:36:00+03	26000.00
05E0BA	2017-07-05 02:07:00+03	71600.00
05E120	2017-07-10 03:53:00+03	111700.00
05E177	2017-07-27 15:01:00+03	23400.00
05E203	2017-07-24 12:33:00+03	14800.00
05E229	2017-07-29 19:00:00+03	21800.00
05E259	2017-08-09 23:24:00+03	46300.00
05E267	2017-08-09 09:48:00+03	191200.00
05E327	2017-07-10 20:38:00+03	356500.00
05E3CA	2017-07-27 16:35:00+03	48500.00
05E3FF	2017-07-13 04:34:00+03	48800.00
05E45B	2017-07-05 22:19:00+03	112000.00
05E4C8	2017-08-01 16:47:00+03	26000.00
05E5D2	2017-07-16 04:59:00+03	77200.00
05E6A1	2017-07-05 05:59:00+03	26200.00
05E725	2017-07-20 17:50:00+03	15100.00
05E731	2017-08-06 19:59:00+03	40400.00
05E7BA	2017-07-23 11:43:00+03	123000.00
05E816	2017-08-02 11:48:00+03	68000.00
05E866	2017-07-04 10:07:00+03	13300.00
05E8A0	2017-07-16 22:47:00+03	50800.00
05E8CB	2017-07-16 03:39:00+03	52700.00
05E901	2017-07-12 19:27:00+03	133200.00
05E946	2017-07-16 23:13:00+03	123000.00
05E9E9	2017-07-16 23:13:00+03	65900.00
05EA9E	2017-08-01 01:03:00+03	15900.00
05EAB5	2017-07-23 07:32:00+03	48800.00
05EB3C	2017-08-07 14:16:00+03	44700.00
05EB41	2017-08-15 16:03:00+03	136200.00
05EB9A	2017-07-29 11:21:00+03	9800.00
05EBC8	2017-07-24 19:45:00+03	141300.00
05EC0C	2017-07-04 22:54:00+03	45000.00
05EC2F	2017-08-02 22:37:00+03	358800.00
05EC68	2017-07-15 04:34:00+03	49800.00
05ECC0	2017-08-11 11:51:00+03	68100.00
05ECCD	2017-07-31 08:56:00+03	65600.00
05ED9F	2017-07-25 09:46:00+03	46400.00
05EDA1	2017-08-06 02:06:00+03	302400.00
05EDD9	2017-08-14 11:48:00+03	31600.00
05EE28	2017-07-25 10:04:00+03	112600.00
05EE39	2017-06-29 07:38:00+03	36400.00
05EE93	2017-08-05 21:01:00+03	28000.00
05EECE	2017-07-24 11:14:00+03	232800.00
05EED3	2017-08-11 09:37:00+03	46000.00
05EED6	2017-07-17 22:36:00+03	57800.00
05EEDF	2017-07-05 01:22:00+03	12000.00
05EEE2	2017-07-30 12:56:00+03	92900.00
05EEF1	2017-07-10 07:07:00+03	19600.00
05EF11	2017-08-13 11:02:00+03	81800.00
05EF28	2017-07-25 11:59:00+03	55700.00
05EF9A	2017-08-03 11:03:00+03	41800.00
05EFA3	2017-07-27 20:54:00+03	69100.00
05F064	2017-07-08 23:19:00+03	28000.00
05F158	2017-07-06 13:11:00+03	123000.00
05F175	2017-08-13 11:55:00+03	156100.00
05F177	2017-07-14 04:33:00+03	52300.00
05F184	2017-08-09 05:03:00+03	94000.00
05F1E3	2017-07-29 15:41:00+03	54800.00
05F1E4	2017-07-30 03:31:00+03	213600.00
05F1E7	2017-07-18 06:15:00+03	92000.00
05F1F9	2017-07-27 07:18:00+03	52700.00
05F262	2017-07-25 21:57:00+03	52000.00
05F26C	2017-08-07 11:32:00+03	74100.00
05F28E	2017-07-18 05:18:00+03	63500.00
05F2D5	2017-08-06 07:24:00+03	36200.00
05F2E9	2017-07-28 01:44:00+03	15800.00
05F2F4	2017-07-28 10:11:00+03	156500.00
05F2F9	2017-08-01 21:37:00+03	167400.00
05F301	2017-07-16 10:49:00+03	16400.00
05F308	2017-08-15 06:48:00+03	51900.00
05F30E	2017-07-30 05:02:00+03	79800.00
05F35E	2017-07-23 13:28:00+03	133700.00
05F36A	2017-08-08 10:25:00+03	31600.00
05F445	2017-08-12 23:17:00+03	48800.00
05F4A0	2017-08-14 01:08:00+03	116000.00
05F506	2017-07-24 14:33:00+03	147100.00
05F523	2017-07-17 09:26:00+03	49100.00
05F5FE	2017-07-12 19:51:00+03	23600.00
05F612	2017-08-10 17:03:00+03	26200.00
05F620	2017-07-11 03:27:00+03	92000.00
05F674	2017-07-07 06:59:00+03	23600.00
05F682	2017-06-30 10:31:00+03	7400.00
05F68F	2017-08-12 13:34:00+03	67000.00
05F6A4	2017-08-06 16:36:00+03	24400.00
05F6C3	2017-07-30 15:58:00+03	40400.00
05F6DD	2017-07-07 17:40:00+03	69000.00
05F77D	2017-07-26 15:59:00+03	12400.00
05F7A9	2017-06-26 01:04:00+03	48200.00
05F7C0	2017-08-09 07:23:00+03	56000.00
05F7E3	2017-07-13 23:07:00+03	39300.00
05F82A	2017-08-07 01:21:00+03	128400.00
05F82C	2017-08-01 15:12:00+03	37900.00
05F874	2017-07-01 17:49:00+03	83700.00
05F89A	2017-08-12 19:51:00+03	131100.00
05F8D3	2017-08-06 01:44:00+03	44000.00
05F8FB	2017-07-08 17:50:00+03	71900.00
05F912	2017-07-22 04:29:00+03	50800.00
05F983	2017-07-25 20:54:00+03	27600.00
05F992	2017-08-10 14:58:00+03	105000.00
05F996	2017-08-06 00:07:00+03	31000.00
05F9D1	2017-07-12 04:51:00+03	21800.00
05FA54	2017-08-09 04:18:00+03	37900.00
05FA60	2017-06-30 14:38:00+03	55600.00
05FA71	2017-08-12 04:04:00+03	23900.00
05FA81	2017-07-22 16:38:00+03	27200.00
05FB31	2017-08-15 12:21:00+03	136800.00
05FB34	2017-08-09 04:22:00+03	44800.00
05FB41	2017-07-05 01:07:00+03	56000.00
05FB63	2017-08-09 04:04:00+03	42700.00
05FB95	2017-07-09 17:55:00+03	8200.00
05FBBA	2017-08-08 15:34:00+03	62000.00
05FC43	2017-07-26 22:04:00+03	26700.00
05FC94	2017-07-08 05:25:00+03	38400.00
05FD06	2017-07-29 04:22:00+03	248300.00
05FD42	2017-07-28 14:45:00+03	72200.00
05FD43	2017-08-06 10:42:00+03	6700.00
05FD92	2017-07-21 12:57:00+03	31100.00
05FE09	2017-07-18 17:32:00+03	43200.00
05FE63	2017-07-03 10:06:00+03	10700.00
05FEA5	2017-07-25 20:18:00+03	40800.00
05FEC3	2017-07-01 05:04:00+03	24300.00
06001B	2017-07-21 13:10:00+03	17800.00
060056	2017-07-03 15:36:00+03	97800.00
060072	2017-08-10 02:17:00+03	43700.00
0600A5	2017-07-07 12:58:00+03	17200.00
06016B	2017-07-25 03:21:00+03	25400.00
0601CE	2017-07-31 04:48:00+03	8200.00
0601FD	2017-08-07 04:07:00+03	48800.00
060264	2017-07-24 03:45:00+03	135400.00
060293	2017-07-05 15:07:00+03	96800.00
0602E3	2017-08-10 20:49:00+03	136500.00
06035A	2017-08-01 04:22:00+03	72400.00
06035B	2017-08-11 03:23:00+03	23200.00
0603A3	2017-07-09 19:27:00+03	52800.00
0603B2	2017-07-22 23:51:00+03	43600.00
0603D8	2017-08-14 05:17:00+03	101100.00
0603E0	2017-07-12 02:50:00+03	60600.00
060403	2017-07-24 19:57:00+03	21800.00
060447	2017-07-25 08:03:00+03	67600.00
0604C8	2017-07-08 17:42:00+03	25800.00
06054C	2017-07-24 11:05:00+03	20800.00
060573	2017-08-04 16:18:00+03	10600.00
060593	2017-07-09 07:45:00+03	398500.00
0605E8	2017-07-29 01:15:00+03	45100.00
0605F0	2017-08-01 14:19:00+03	67100.00
060622	2017-07-22 12:03:00+03	40100.00
06063C	2017-08-06 10:51:00+03	69000.00
06064E	2017-07-10 12:25:00+03	28800.00
060673	2017-07-03 19:50:00+03	112600.00
06069B	2017-07-22 09:58:00+03	212400.00
0606E3	2017-08-01 23:44:00+03	98400.00
060723	2017-07-26 23:49:00+03	55800.00
06073A	2017-08-10 06:53:00+03	46400.00
06078B	2017-07-29 17:28:00+03	137700.00
06078C	2017-07-20 06:52:00+03	81300.00
0607F5	2017-08-08 05:21:00+03	38600.00
06082A	2017-07-20 09:08:00+03	45200.00
060850	2017-08-15 12:06:00+03	135700.00
06086E	2017-07-30 11:40:00+03	136800.00
06089B	2017-07-18 07:10:00+03	167500.00
06097C	2017-08-01 00:41:00+03	34800.00
0609E0	2017-08-07 17:49:00+03	32000.00
0609FF	2017-06-29 10:36:00+03	24400.00
060A12	2017-07-29 17:56:00+03	93400.00
060A44	2017-07-20 18:46:00+03	397700.00
060AD8	2017-07-28 06:29:00+03	69500.00
060AE7	2017-07-31 18:25:00+03	59200.00
060B64	2017-07-25 17:13:00+03	201200.00
060BA1	2017-07-29 02:02:00+03	28800.00
060BCF	2017-07-20 05:40:00+03	66600.00
060BE2	2017-07-16 04:46:00+03	492000.00
060BF9	2017-08-01 11:05:00+03	55800.00
060C07	2017-08-06 07:35:00+03	24500.00
060C90	2017-07-03 19:59:00+03	34400.00
060D20	2017-07-14 12:41:00+03	26000.00
060D44	2017-07-16 16:45:00+03	21800.00
060DD9	2017-08-15 08:21:00+03	55800.00
060EE8	2017-07-10 21:59:00+03	266400.00
060F43	2017-08-11 03:17:00+03	69700.00
060F8E	2017-07-13 12:30:00+03	89000.00
060FC5	2017-07-13 15:00:00+03	32800.00
060FF6	2017-07-04 23:16:00+03	114300.00
061041	2017-07-23 04:50:00+03	57400.00
061079	2017-07-26 02:53:00+03	76100.00
06107F	2017-08-06 08:08:00+03	56000.00
061084	2017-07-29 15:39:00+03	58500.00
061097	2017-07-04 00:21:00+03	28000.00
061139	2017-07-23 19:44:00+03	31600.00
061183	2017-08-03 17:10:00+03	23600.00
0611CB	2017-08-03 04:05:00+03	257600.00
061236	2017-07-17 14:49:00+03	102100.00
061274	2017-08-10 10:51:00+03	57600.00
061281	2017-07-21 01:36:00+03	108300.00
06128F	2017-07-23 22:00:00+03	59200.00
0612A2	2017-07-26 22:53:00+03	30200.00
0612EB	2017-07-28 12:58:00+03	38400.00
0612F2	2017-07-21 18:33:00+03	59800.00
06139C	2017-07-21 20:40:00+03	11200.00
0613A0	2017-07-15 06:06:00+03	19000.00
0613CE	2017-08-05 08:18:00+03	301800.00
06142D	2017-07-02 12:46:00+03	136200.00
061430	2017-07-27 04:34:00+03	56000.00
06146A	2017-08-02 20:35:00+03	40100.00
06148E	2017-08-05 05:20:00+03	13600.00
06150B	2017-07-25 09:47:00+03	332500.00
06152A	2017-07-08 15:57:00+03	66900.00
061546	2017-07-03 11:32:00+03	100200.00
06154E	2017-07-29 08:58:00+03	24400.00
06158B	2017-08-15 04:09:00+03	37200.00
061591	2017-07-17 13:05:00+03	177600.00
061597	2017-08-14 14:07:00+03	13600.00
0615C4	2017-08-05 16:59:00+03	77900.00
061619	2017-08-01 03:36:00+03	56600.00
06169B	2017-07-11 07:09:00+03	56000.00
061702	2017-08-07 02:52:00+03	86400.00
061703	2017-07-29 23:34:00+03	28000.00
061712	2017-08-01 14:08:00+03	46200.00
06173A	2017-07-20 20:55:00+03	46500.00
06176A	2017-07-17 19:02:00+03	177600.00
06178A	2017-08-07 06:47:00+03	14800.00
0617AD	2017-07-28 08:00:00+03	16400.00
0617E0	2017-07-17 03:38:00+03	18600.00
061834	2017-08-10 22:46:00+03	74700.00
06186B	2017-08-03 00:56:00+03	56900.00
0618D9	2017-08-14 01:02:00+03	79000.00
061922	2017-08-14 12:08:00+03	27700.00
061937	2017-07-14 07:52:00+03	68000.00
061948	2017-08-14 18:24:00+03	23500.00
061983	2017-07-18 06:35:00+03	112000.00
06199B	2017-08-02 01:17:00+03	67900.00
0619A5	2017-08-08 10:51:00+03	188000.00
0619A9	2017-07-06 07:04:00+03	248400.00
0619F6	2017-07-01 06:31:00+03	43000.00
061A4F	2017-07-18 09:41:00+03	62600.00
061A7A	2017-07-21 12:02:00+03	52000.00
061A7D	2017-07-20 04:43:00+03	28000.00
061A8F	2017-08-06 17:51:00+03	24200.00
061ABE	2017-07-04 19:17:00+03	162900.00
061AD1	2017-07-17 19:14:00+03	23200.00
061ADA	2017-07-31 03:32:00+03	59200.00
061B0A	2017-08-15 17:46:00+03	46900.00
061B18	2017-08-14 03:54:00+03	135200.00
061BCE	2017-07-04 15:14:00+03	76600.00
061BD6	2017-08-13 06:09:00+03	406700.00
061C18	2017-07-20 10:02:00+03	26000.00
061C45	2017-07-15 06:15:00+03	103900.00
061C67	2017-07-30 01:08:00+03	206800.00
061C6A	2017-07-16 17:16:00+03	145300.00
061C74	2017-07-06 12:12:00+03	43100.00
061CAB	2017-07-07 05:24:00+03	65900.00
061D4C	2017-08-10 08:46:00+03	12600.00
061D57	2017-07-01 05:32:00+03	28000.00
061D5D	2017-07-09 22:23:00+03	26000.00
061D68	2017-07-14 09:02:00+03	83000.00
061D9A	2017-07-22 21:56:00+03	57600.00
061E73	2017-07-19 01:48:00+03	123200.00
061E78	2017-08-08 19:27:00+03	260900.00
061E81	2017-08-04 21:05:00+03	29600.00
061E96	2017-07-07 20:44:00+03	56000.00
061E9B	2017-07-16 18:13:00+03	59700.00
061EA5	2017-07-10 07:53:00+03	257500.00
061EAD	2017-08-02 04:08:00+03	67200.00
061ED7	2017-07-14 19:00:00+03	116400.00
061F10	2017-08-14 07:58:00+03	96200.00
061F1C	2017-06-30 22:26:00+03	46200.00
061F25	2017-08-05 04:26:00+03	55300.00
061F28	2017-07-17 15:26:00+03	156300.00
061F5A	2017-08-03 11:57:00+03	396500.00
06201D	2017-08-04 15:32:00+03	28000.00
06205A	2017-08-10 09:39:00+03	59300.00
0620BD	2017-08-06 16:05:00+03	10600.00
062172	2017-08-03 16:12:00+03	47000.00
06217A	2017-08-12 10:07:00+03	66800.00
0621A3	2017-07-19 08:39:00+03	54000.00
0621D5	2017-08-06 09:48:00+03	198500.00
0621E6	2017-07-03 10:25:00+03	36400.00
062230	2017-07-25 18:46:00+03	23200.00
06227F	2017-08-01 13:32:00+03	28000.00
062298	2017-06-30 12:31:00+03	88100.00
062316	2017-07-12 07:50:00+03	23200.00
06232E	2017-06-27 02:22:00+03	67100.00
0623A4	2017-07-19 03:44:00+03	22000.00
0623F5	2017-07-25 16:28:00+03	86300.00
0623F6	2017-07-07 15:53:00+03	51900.00
062423	2017-07-03 22:31:00+03	61100.00
062424	2017-07-23 02:56:00+03	26000.00
0624C9	2017-07-28 06:28:00+03	58800.00
0624EC	2017-07-21 21:19:00+03	36200.00
06251E	2017-07-10 04:37:00+03	81300.00
062533	2017-07-26 05:39:00+03	141600.00
06257B	2017-07-07 04:53:00+03	129400.00
062596	2017-07-18 18:26:00+03	6800.00
0625F3	2017-08-08 04:04:00+03	10700.00
06262E	2017-07-08 19:11:00+03	133200.00
062632	2017-07-31 11:32:00+03	60200.00
06263E	2017-07-06 14:54:00+03	70800.00
0626CE	2017-07-20 08:31:00+03	179400.00
0626DD	2017-08-10 06:19:00+03	22100.00
0626DE	2017-08-09 16:08:00+03	73300.00
06272C	2017-07-06 02:57:00+03	31600.00
0627CB	2017-08-08 13:17:00+03	23200.00
0627EE	2017-08-01 10:30:00+03	92100.00
062800	2017-07-06 22:12:00+03	129500.00
06282D	2017-07-12 06:56:00+03	51900.00
062886	2017-07-25 08:13:00+03	32800.00
06288D	2017-08-12 04:07:00+03	16400.00
0628BA	2017-07-10 01:10:00+03	84000.00
062919	2017-08-04 08:16:00+03	122700.00
062938	2017-08-06 07:20:00+03	75300.00
062A84	2017-07-05 17:29:00+03	19800.00
062A85	2017-07-28 08:37:00+03	41800.00
062AB8	2017-08-12 16:00:00+03	133600.00
062ACF	2017-07-26 11:00:00+03	163800.00
062B46	2017-08-10 13:41:00+03	94700.00
062BFC	2017-07-05 04:58:00+03	43200.00
062C1B	2017-07-16 18:01:00+03	75600.00
062C49	2017-07-15 17:37:00+03	12000.00
062C53	2017-07-08 15:13:00+03	148700.00
062C5A	2017-08-07 20:46:00+03	406600.00
062C61	2017-07-02 23:03:00+03	91600.00
062CBF	2017-07-25 01:23:00+03	23600.00
062CDD	2017-07-14 08:38:00+03	39300.00
062D04	2017-07-29 04:03:00+03	59200.00
062E16	2017-07-04 17:19:00+03	258400.00
062E39	2017-07-24 14:02:00+03	11700.00
062E3A	2017-07-14 09:37:00+03	73200.00
062E4F	2017-08-06 01:49:00+03	11600.00
062E89	2017-08-04 18:26:00+03	37900.00
062EC9	2017-07-02 07:43:00+03	44000.00
062F0C	2017-07-04 18:01:00+03	75600.00
062F23	2017-07-16 00:11:00+03	28000.00
062F67	2017-07-02 12:21:00+03	82400.00
062F7D	2017-08-15 11:56:00+03	39300.00
06300C	2017-08-03 14:02:00+03	205200.00
063046	2017-07-22 23:25:00+03	111600.00
063053	2017-07-22 01:11:00+03	113900.00
0630A9	2017-08-01 03:57:00+03	87100.00
0630BA	2017-07-24 07:04:00+03	26000.00
0630DC	2017-08-08 20:52:00+03	21400.00
06313C	2017-08-09 07:15:00+03	56600.00
063151	2017-07-20 04:37:00+03	67600.00
063160	2017-08-15 07:25:00+03	37900.00
063359	2017-08-12 00:51:00+03	12600.00
0633AD	2017-07-18 01:31:00+03	12000.00
063431	2017-07-25 04:40:00+03	111600.00
063462	2017-07-28 21:51:00+03	20400.00
0634CE	2017-07-12 08:06:00+03	123000.00
063525	2017-07-02 12:07:00+03	85600.00
063533	2017-08-10 15:09:00+03	133200.00
063545	2017-08-13 13:10:00+03	68400.00
06358C	2017-08-05 17:03:00+03	36200.00
063591	2017-07-21 16:09:00+03	53300.00
0635C3	2017-07-07 08:27:00+03	43200.00
0635D0	2017-07-22 05:44:00+03	106400.00
0635E2	2017-08-01 20:29:00+03	185000.00
063600	2017-08-11 02:34:00+03	21400.00
06366B	2017-06-29 17:36:00+03	354200.00
063717	2017-07-14 06:26:00+03	23200.00
063726	2017-08-08 12:35:00+03	40000.00
063770	2017-07-09 17:23:00+03	9800.00
0637D8	2017-07-22 14:53:00+03	111600.00
0637E5	2017-07-29 20:34:00+03	399600.00
063860	2017-08-04 07:19:00+03	65500.00
063880	2017-07-27 15:49:00+03	41500.00
063898	2017-08-11 13:20:00+03	16800.00
06389C	2017-07-21 19:04:00+03	27900.00
0638EA	2017-08-11 20:01:00+03	111600.00
0638FD	2017-08-07 15:54:00+03	46200.00
063903	2017-08-12 09:06:00+03	95600.00
06394E	2017-08-03 10:49:00+03	38800.00
06397B	2017-07-15 12:40:00+03	103100.00
0639B0	2017-08-06 23:25:00+03	106400.00
0639CC	2017-07-01 23:41:00+03	22400.00
0639D4	2017-08-11 19:59:00+03	77700.00
063A48	2017-07-12 10:57:00+03	37100.00
063A6E	2017-07-25 23:54:00+03	122500.00
063AE6	2017-08-11 17:39:00+03	81700.00
063B2B	2017-07-06 07:53:00+03	59800.00
063BC1	2017-08-04 19:24:00+03	69500.00
063CAC	2017-07-01 05:53:00+03	44000.00
063CB5	2017-08-08 09:00:00+03	23200.00
063CC3	2017-07-03 04:57:00+03	84500.00
063D38	2017-08-12 07:07:00+03	168000.00
063D4E	2017-07-15 21:37:00+03	25100.00
063DB2	2017-07-10 05:04:00+03	83700.00
063DD0	2017-08-12 20:49:00+03	71900.00
063DE8	2017-08-11 15:49:00+03	44400.00
063E33	2017-08-15 09:29:00+03	18800.00
063E35	2017-07-29 21:54:00+03	27200.00
063E4D	2017-08-04 14:46:00+03	47200.00
063EA1	2017-07-10 02:41:00+03	46400.00
063EA2	2017-07-04 16:16:00+03	71200.00
063F00	2017-06-28 19:30:00+03	28000.00
063F05	2017-06-27 08:11:00+03	35800.00
063F6A	2017-08-05 16:52:00+03	74200.00
063F7A	2017-07-16 21:09:00+03	50800.00
063F8F	2017-08-01 03:38:00+03	99200.00
063F96	2017-06-29 07:58:00+03	43000.00
063F9D	2017-07-13 16:54:00+03	136200.00
063FA3	2017-07-09 21:02:00+03	9200.00
063FCC	2017-07-25 10:51:00+03	50800.00
063FFF	2017-08-07 16:17:00+03	51900.00
0640BA	2017-08-05 08:43:00+03	24400.00
064147	2017-07-19 16:12:00+03	62600.00
064178	2017-07-02 23:27:00+03	98400.00
064242	2017-06-30 00:57:00+03	24500.00
064312	2017-07-09 07:58:00+03	249100.00
064357	2017-07-27 07:52:00+03	39200.00
0643BC	2017-07-04 04:28:00+03	6700.00
064485	2017-07-29 16:55:00+03	92800.00
064492	2017-07-22 10:46:00+03	53400.00
064499	2017-07-20 04:42:00+03	114300.00
06450B	2017-08-13 18:41:00+03	75600.00
064515	2017-07-27 16:23:00+03	12400.00
064529	2017-06-30 16:29:00+03	75600.00
064589	2017-07-22 12:33:00+03	310100.00
064633	2017-07-15 17:09:00+03	22000.00
064643	2017-08-13 21:44:00+03	16400.00
064657	2017-07-25 07:47:00+03	119500.00
0646C6	2017-08-05 10:40:00+03	15000.00
064701	2017-07-28 10:35:00+03	45100.00
064728	2017-08-07 17:43:00+03	25100.00
064749	2017-07-04 12:16:00+03	135400.00
064766	2017-07-14 16:27:00+03	63300.00
06480E	2017-07-25 16:30:00+03	47400.00
064845	2017-07-27 06:30:00+03	109600.00
064884	2017-08-05 14:40:00+03	59200.00
064887	2017-07-27 17:36:00+03	36200.00
064893	2017-07-06 06:43:00+03	12600.00
0648F6	2017-08-15 00:02:00+03	105200.00
0648FF	2017-07-11 14:38:00+03	123000.00
06490C	2017-07-17 23:33:00+03	50000.00
064940	2017-07-21 09:01:00+03	73200.00
06497E	2017-08-07 05:07:00+03	21500.00
064A62	2017-07-01 02:21:00+03	21400.00
064A6F	2017-07-13 18:25:00+03	23200.00
064A71	2017-07-17 14:47:00+03	55800.00
064A76	2017-08-12 02:11:00+03	90600.00
064AD8	2017-07-10 23:23:00+03	78300.00
064AF5	2017-08-04 09:52:00+03	56000.00
064AFC	2017-07-02 09:23:00+03	509800.00
064B4B	2017-07-16 22:02:00+03	68000.00
064B5E	2017-07-18 16:40:00+03	92800.00
064B8C	2017-07-17 06:29:00+03	42800.00
064B91	2017-07-07 21:39:00+03	20400.00
064B97	2017-08-13 06:03:00+03	125700.00
064BEC	2017-07-15 12:06:00+03	22000.00
064BF3	2017-07-12 16:06:00+03	12400.00
064C5D	2017-07-01 18:57:00+03	8800.00
064CE3	2017-07-31 14:07:00+03	28800.00
064D1E	2017-08-09 18:16:00+03	41200.00
064D2E	2017-08-01 09:55:00+03	40000.00
064D47	2017-07-16 23:24:00+03	94900.00
064D94	2017-07-21 19:22:00+03	26200.00
064DBA	2017-08-15 06:26:00+03	37500.00
064DDF	2017-08-05 12:56:00+03	24800.00
064DEE	2017-08-14 21:30:00+03	15000.00
064E22	2017-07-27 20:07:00+03	135400.00
064E3B	2017-07-16 21:36:00+03	226200.00
064E93	2017-08-05 19:11:00+03	26000.00
064F17	2017-07-29 05:44:00+03	99300.00
064F3E	2017-08-05 15:05:00+03	15400.00
064FAF	2017-07-31 22:04:00+03	67600.00
064FD1	2017-07-27 22:41:00+03	36200.00
065041	2017-08-10 17:04:00+03	6700.00
065050	2017-07-13 09:22:00+03	47400.00
065074	2017-08-05 15:32:00+03	125200.00
0650B3	2017-07-30 02:33:00+03	28800.00
0650BC	2017-07-04 02:12:00+03	37900.00
06510C	2017-07-22 23:35:00+03	6000.00
065131	2017-07-22 00:46:00+03	108500.00
065149	2017-07-29 11:13:00+03	106800.00
065177	2017-07-12 00:49:00+03	43100.00
065215	2017-07-27 18:41:00+03	55800.00
06531E	2017-08-02 08:48:00+03	46000.00
065330	2017-07-19 23:34:00+03	210600.00
0653A3	2017-08-05 15:01:00+03	56600.00
0653B5	2017-07-20 09:14:00+03	35300.00
0653B9	2017-08-04 10:08:00+03	58900.00
065425	2017-08-12 13:53:00+03	54600.00
06543A	2017-07-28 17:10:00+03	123000.00
065464	2017-08-10 18:24:00+03	284400.00
06549F	2017-07-10 05:32:00+03	47700.00
0654D0	2017-07-16 03:35:00+03	23400.00
065500	2017-07-12 01:44:00+03	133100.00
065523	2017-08-06 19:33:00+03	62000.00
065531	2017-07-04 20:19:00+03	32700.00
065562	2017-07-04 08:13:00+03	40800.00
065595	2017-08-10 06:10:00+03	15000.00
0655D6	2017-08-15 00:20:00+03	68100.00
0655F4	2017-07-11 13:30:00+03	57600.00
0655F9	2017-07-27 19:00:00+03	60300.00
065639	2017-07-16 01:54:00+03	27600.00
065659	2017-07-06 03:43:00+03	7400.00
06578A	2017-07-14 16:25:00+03	136200.00
0657AE	2017-08-12 06:52:00+03	31400.00
0657B6	2017-07-30 10:24:00+03	56000.00
0657B9	2017-07-18 18:59:00+03	25800.00
0657D7	2017-08-09 12:09:00+03	160200.00
065829	2017-07-11 00:28:00+03	208800.00
065830	2017-07-01 17:11:00+03	12600.00
065838	2017-07-15 00:35:00+03	49300.00
065839	2017-07-15 15:23:00+03	232800.00
0658A8	2017-07-01 03:48:00+03	27300.00
06590D	2017-08-10 07:28:00+03	40800.00
065951	2017-08-03 04:24:00+03	178800.00
06597E	2017-08-06 08:01:00+03	41900.00
0659A9	2017-08-07 10:05:00+03	68600.00
0659C8	2017-08-08 16:02:00+03	13600.00
0659DA	2017-07-17 09:23:00+03	202000.00
065AB9	2017-07-10 09:56:00+03	6000.00
065AFA	2017-07-14 20:32:00+03	65500.00
065B00	2017-08-05 01:11:00+03	88900.00
065B08	2017-08-02 18:09:00+03	13600.00
065B1C	2017-07-06 16:03:00+03	136800.00
065B2E	2017-07-06 11:21:00+03	99300.00
065B63	2017-07-12 20:18:00+03	29300.00
065B87	2017-07-23 15:04:00+03	98300.00
065B8C	2017-08-02 10:22:00+03	369000.00
065B9E	2017-07-28 13:48:00+03	21400.00
065BA5	2017-07-11 08:52:00+03	168000.00
065BAF	2017-08-07 01:33:00+03	97200.00
065BF1	2017-07-08 23:03:00+03	120700.00
065C18	2017-07-04 17:26:00+03	187900.00
065C57	2017-07-16 18:39:00+03	32800.00
065C78	2017-08-10 06:39:00+03	166100.00
065CB4	2017-08-11 13:47:00+03	133100.00
065CEF	2017-07-09 06:46:00+03	28800.00
065D7B	2017-08-05 06:03:00+03	132800.00
065DFC	2017-07-17 20:45:00+03	6000.00
065E18	2017-08-05 08:23:00+03	56000.00
065E1D	2017-08-12 21:33:00+03	28000.00
065E40	2017-08-04 17:38:00+03	173600.00
065E54	2017-08-05 02:06:00+03	242700.00
065E9D	2017-07-14 23:11:00+03	191300.00
065EFF	2017-07-12 12:11:00+03	28800.00
065F1E	2017-08-08 02:03:00+03	202300.00
065F21	2017-07-14 01:23:00+03	286100.00
065F25	2017-07-18 14:02:00+03	103500.00
065FF4	2017-07-30 13:47:00+03	52000.00
0660CA	2017-07-07 23:09:00+03	54800.00
0660CD	2017-07-22 11:07:00+03	116800.00
06611F	2017-07-06 08:28:00+03	64500.00
06615E	2017-07-13 15:00:00+03	29600.00
066160	2017-06-27 16:56:00+03	11600.00
0661AC	2017-07-25 05:29:00+03	39200.00
066245	2017-08-10 22:49:00+03	27800.00
06627E	2017-07-06 05:38:00+03	199700.00
06627F	2017-07-13 11:51:00+03	38500.00
0662CB	2017-07-24 15:15:00+03	46000.00
0662DD	2017-08-05 22:22:00+03	7400.00
06633F	2017-07-11 00:26:00+03	88400.00
06634A	2017-07-19 06:23:00+03	84100.00
06634D	2017-08-07 19:17:00+03	57600.00
066395	2017-08-11 00:37:00+03	21800.00
0663AF	2017-08-04 22:38:00+03	63200.00
0663E9	2017-07-26 15:50:00+03	147700.00
0664E6	2017-07-10 13:15:00+03	153900.00
0665B3	2017-07-17 03:41:00+03	226800.00
0665CC	2017-07-23 23:22:00+03	18000.00
0665D9	2017-07-16 09:54:00+03	62600.00
066630	2017-08-01 00:58:00+03	65500.00
066635	2017-06-30 13:30:00+03	52900.00
06669E	2017-08-10 21:33:00+03	26000.00
0666C6	2017-08-15 05:11:00+03	57600.00
0666CB	2017-07-27 18:47:00+03	32800.00
0666EC	2017-07-31 02:07:00+03	24400.00
0666F4	2017-07-13 06:43:00+03	20200.00
066747	2017-07-20 17:33:00+03	399600.00
06676C	2017-07-19 01:45:00+03	6000.00
0667FC	2017-07-16 01:09:00+03	68800.00
06682D	2017-07-31 08:55:00+03	44000.00
0668A5	2017-07-08 05:25:00+03	12600.00
0668CD	2017-07-10 12:13:00+03	12400.00
0668D9	2017-08-07 17:47:00+03	6000.00
0668E9	2017-07-31 22:00:00+03	100600.00
0668F6	2017-07-11 17:45:00+03	135400.00
066978	2017-07-28 05:57:00+03	58400.00
0669FA	2017-08-14 15:47:00+03	46000.00
066A3C	2017-07-12 09:32:00+03	138800.00
066A5E	2017-07-24 15:06:00+03	112000.00
066A68	2017-08-13 09:50:00+03	15000.00
066ABE	2017-08-04 03:41:00+03	26000.00
066AF3	2017-07-08 23:59:00+03	102800.00
066B30	2017-07-18 15:11:00+03	32800.00
066B3D	2017-07-27 10:34:00+03	65500.00
066B4C	2017-07-04 02:19:00+03	36200.00
066B82	2017-07-30 05:09:00+03	29300.00
066BF9	2017-07-18 03:36:00+03	113500.00
066C9C	2017-07-08 04:31:00+03	155600.00
066CB8	2017-07-10 20:10:00+03	154500.00
066CCF	2017-08-12 18:31:00+03	119500.00
066CEE	2017-07-26 22:10:00+03	65900.00
066CF9	2017-08-08 19:23:00+03	23200.00
066D48	2017-08-06 23:30:00+03	125200.00
066DB6	2017-08-01 06:41:00+03	43400.00
066DEE	2017-08-01 03:03:00+03	27800.00
066DFE	2017-08-15 04:37:00+03	28800.00
066E02	2017-08-05 09:07:00+03	28000.00
066EA0	2017-08-01 03:00:00+03	43600.00
066EB9	2017-07-13 17:27:00+03	119500.00
066F1F	2017-07-07 22:22:00+03	29400.00
066F86	2017-07-08 13:38:00+03	123000.00
066F8B	2017-08-11 11:37:00+03	196700.00
066F91	2017-08-01 15:44:00+03	151200.00
067003	2017-07-14 10:35:00+03	122000.00
067044	2017-07-10 09:07:00+03	29600.00
067064	2017-07-10 18:41:00+03	74400.00
067092	2017-08-15 16:21:00+03	14800.00
06709F	2017-08-04 08:44:00+03	21000.00
067102	2017-07-28 13:27:00+03	12600.00
06712F	2017-07-26 10:03:00+03	56000.00
06713E	2017-07-12 13:03:00+03	56600.00
067158	2017-07-19 07:27:00+03	149100.00
067176	2017-08-05 14:18:00+03	48800.00
0671A8	2017-07-23 03:18:00+03	133200.00
0671C2	2017-08-06 23:43:00+03	46400.00
067229	2017-08-02 10:42:00+03	136100.00
067240	2017-07-27 14:07:00+03	29600.00
067295	2017-07-26 14:22:00+03	81300.00
0672D7	2017-07-23 16:22:00+03	46500.00
067325	2017-07-02 08:48:00+03	123000.00
06736D	2017-08-14 06:58:00+03	41900.00
0673A2	2017-07-25 16:03:00+03	48500.00
0673A7	2017-08-01 09:23:00+03	25900.00
067479	2017-06-27 02:52:00+03	113900.00
0674B9	2017-07-15 17:34:00+03	66000.00
0674CC	2017-07-27 00:38:00+03	112000.00
067554	2017-07-18 02:09:00+03	111700.00
06759C	2017-06-30 10:06:00+03	21400.00
0675B9	2017-07-27 10:12:00+03	61500.00
067637	2017-07-12 22:39:00+03	44800.00
06764E	2017-08-03 09:23:00+03	51200.00
0676DE	2017-08-07 19:08:00+03	19600.00
067714	2017-07-13 23:29:00+03	41300.00
067716	2017-07-14 17:09:00+03	55800.00
067718	2017-07-10 10:08:00+03	38600.00
067749	2017-07-21 04:07:00+03	137600.00
067765	2017-07-26 12:43:00+03	162300.00
0677EE	2017-07-17 18:13:00+03	26000.00
0677F9	2017-07-14 07:13:00+03	68100.00
0677FD	2017-08-13 12:00:00+03	6700.00
067845	2017-08-07 03:28:00+03	24400.00
067888	2017-08-02 06:00:00+03	415700.00
06788B	2017-07-20 04:32:00+03	103500.00
0678BF	2017-07-16 03:26:00+03	117600.00
0678CA	2017-08-10 18:30:00+03	99600.00
067908	2017-07-18 10:41:00+03	79900.00
067923	2017-07-14 06:56:00+03	245400.00
067ABC	2017-07-29 10:49:00+03	48800.00
067ADE	2017-07-24 19:01:00+03	102700.00
067AF5	2017-08-07 06:57:00+03	313200.00
067B37	2017-07-06 18:44:00+03	86800.00
067B50	2017-08-12 06:13:00+03	77200.00
067B69	2017-06-30 21:05:00+03	93600.00
067B8E	2017-07-07 17:21:00+03	44000.00
067BA6	2017-07-16 16:46:00+03	184000.00
067C72	2017-07-24 20:58:00+03	119500.00
067CE7	2017-07-28 09:35:00+03	16800.00
067DC0	2017-07-02 13:57:00+03	38800.00
067DC1	2017-08-05 11:01:00+03	40800.00
067DDB	2017-08-01 17:14:00+03	210000.00
067EDB	2017-06-28 16:51:00+03	35400.00
067F3A	2017-08-04 18:06:00+03	22000.00
067FD5	2017-08-11 12:05:00+03	270200.00
068056	2017-07-29 20:27:00+03	114800.00
068065	2017-08-09 16:30:00+03	133700.00
068088	2017-08-02 16:16:00+03	56000.00
0680C8	2017-08-07 22:27:00+03	21400.00
0680ED	2017-07-13 13:09:00+03	6000.00
0680F1	2017-06-29 13:57:00+03	54300.00
068110	2017-08-02 11:13:00+03	26000.00
068147	2017-07-25 14:36:00+03	48800.00
06815F	2017-08-06 04:30:00+03	26700.00
06818F	2017-08-11 03:14:00+03	136200.00
06825E	2017-08-14 12:54:00+03	26000.00
068287	2017-07-03 19:44:00+03	50400.00
0682B4	2017-07-24 18:24:00+03	65200.00
0682C9	2017-08-05 21:51:00+03	86400.00
0682DF	2017-07-30 19:12:00+03	246000.00
0682E6	2017-08-13 02:38:00+03	23600.00
068304	2017-07-14 02:06:00+03	91600.00
068330	2017-08-04 23:47:00+03	6700.00
06834C	2017-08-13 19:40:00+03	20400.00
06835B	2017-08-01 12:35:00+03	45200.00
0684A1	2017-07-06 06:56:00+03	72400.00
0684AA	2017-07-17 00:45:00+03	100600.00
0684ED	2017-07-07 11:53:00+03	12400.00
068502	2017-07-06 05:34:00+03	64400.00
0686E2	2017-07-18 02:53:00+03	88200.00
0686F6	2017-08-01 13:25:00+03	67700.00
06872B	2017-07-26 23:04:00+03	37900.00
06875C	2017-07-24 21:12:00+03	45200.00
06879D	2017-07-30 23:36:00+03	8200.00
0687D8	2017-07-16 19:40:00+03	26800.00
06886A	2017-07-18 20:10:00+03	40400.00
06889B	2017-07-27 05:22:00+03	46000.00
0688A7	2017-07-23 21:02:00+03	38600.00
068998	2017-07-13 08:11:00+03	27200.00
0689ED	2017-08-14 07:37:00+03	64600.00
068A84	2017-07-05 05:01:00+03	46000.00
068A95	2017-07-23 04:55:00+03	51200.00
068ABE	2017-07-16 12:06:00+03	469300.00
068BAA	2017-07-17 04:23:00+03	56600.00
068BDF	2017-07-07 13:04:00+03	40800.00
068BEA	2017-07-18 15:04:00+03	18000.00
068C46	2017-07-07 14:31:00+03	20600.00
068C7D	2017-07-10 09:40:00+03	114800.00
068CBC	2017-07-23 13:42:00+03	21600.00
068D27	2017-07-20 23:19:00+03	73600.00
068D5E	2017-07-31 20:12:00+03	92100.00
068DD9	2017-07-21 11:41:00+03	34000.00
068DFC	2017-07-05 05:01:00+03	28800.00
068E12	2017-07-14 08:58:00+03	19600.00
068E55	2017-08-06 21:16:00+03	42600.00
068EAF	2017-08-09 07:29:00+03	28000.00
068F42	2017-08-14 01:13:00+03	8400.00
068F4B	2017-07-15 04:20:00+03	28800.00
068F53	2017-08-02 06:25:00+03	38600.00
068F75	2017-07-28 10:50:00+03	176500.00
068F78	2017-07-18 18:35:00+03	34100.00
068F7B	2017-08-12 10:22:00+03	14000.00
068F89	2017-08-04 05:37:00+03	40400.00
068FCC	2017-08-15 12:57:00+03	259800.00
069070	2017-06-29 21:39:00+03	56000.00
0690E6	2017-07-21 16:32:00+03	55800.00
0690EE	2017-07-11 08:03:00+03	35500.00
06912F	2017-08-09 01:49:00+03	28800.00
069202	2017-07-20 19:57:00+03	265700.00
069246	2017-07-17 16:27:00+03	12600.00
0692AA	2017-07-06 11:00:00+03	121800.00
0692EB	2017-07-07 16:27:00+03	187600.00
06932A	2017-07-18 09:04:00+03	19600.00
069353	2017-07-29 02:15:00+03	44800.00
069374	2017-08-11 04:33:00+03	30400.00
06939E	2017-08-05 03:56:00+03	179400.00
0693CB	2017-07-13 19:38:00+03	92400.00
0693FE	2017-08-11 23:32:00+03	141100.00
069412	2017-08-09 08:16:00+03	36200.00
06943C	2017-08-02 21:40:00+03	49100.00
06943D	2017-07-06 10:42:00+03	64400.00
069442	2017-08-04 08:48:00+03	43000.00
069478	2017-07-30 23:34:00+03	205600.00
0694A6	2017-07-12 05:03:00+03	34000.00
0694A9	2017-07-28 22:35:00+03	100600.00
0694D3	2017-07-10 06:07:00+03	28000.00
069560	2017-07-22 23:24:00+03	50600.00
06956E	2017-08-02 21:45:00+03	148800.00
069596	2017-08-05 20:40:00+03	60400.00
0695A4	2017-07-29 18:42:00+03	61500.00
0695A8	2017-07-18 03:37:00+03	78500.00
0695D6	2017-08-06 08:02:00+03	40800.00
0695EF	2017-08-09 17:20:00+03	46300.00
069619	2017-07-20 00:24:00+03	6000.00
069623	2017-08-08 13:44:00+03	48800.00
06963F	2017-08-14 17:00:00+03	91200.00
06965F	2017-07-01 22:46:00+03	6600.00
0696C4	2017-07-22 04:21:00+03	34600.00
0696D8	2017-07-09 01:06:00+03	19800.00
069732	2017-07-15 13:47:00+03	51900.00
069793	2017-07-15 00:06:00+03	47100.00
06979F	2017-08-12 22:17:00+03	43800.00
0697B5	2017-07-21 10:31:00+03	84500.00
0697E1	2017-08-15 07:54:00+03	8200.00
069859	2017-07-01 15:22:00+03	12000.00
069876	2017-08-05 10:24:00+03	75000.00
069883	2017-07-27 12:30:00+03	26800.00
0698ED	2017-08-05 09:09:00+03	58000.00
069A06	2017-08-13 12:55:00+03	51900.00
069A6F	2017-07-16 12:36:00+03	56000.00
069A7F	2017-07-27 11:38:00+03	104600.00
069ABD	2017-08-08 14:08:00+03	25400.00
069B1B	2017-07-09 12:35:00+03	85600.00
069B40	2017-07-15 00:17:00+03	23200.00
069BF5	2017-07-17 22:28:00+03	112000.00
069CD2	2017-07-19 22:18:00+03	265700.00
069D6C	2017-07-11 03:29:00+03	111600.00
069D8B	2017-08-02 12:00:00+03	109800.00
069DA4	2017-08-04 20:08:00+03	23600.00
069DCF	2017-07-01 06:30:00+03	77200.00
069E15	2017-08-05 04:03:00+03	9200.00
069E27	2017-08-09 23:39:00+03	260300.00
069E2C	2017-07-31 15:29:00+03	44600.00
069E34	2017-07-16 02:15:00+03	80200.00
069EB2	2017-08-09 07:53:00+03	85500.00
069EF5	2017-07-24 03:02:00+03	84100.00
069F21	2017-08-10 02:28:00+03	18000.00
069F40	2017-07-28 20:15:00+03	192400.00
069F8F	2017-08-07 19:17:00+03	122300.00
069FB3	2017-07-02 02:55:00+03	28000.00
069FDE	2017-08-12 01:01:00+03	230800.00
069FF1	2017-08-13 00:10:00+03	89700.00
06A080	2017-08-02 13:00:00+03	105100.00
06A0AB	2017-07-13 17:33:00+03	61100.00
06A0E2	2017-07-21 16:31:00+03	26000.00
06A128	2017-07-21 06:42:00+03	71000.00
06A14F	2017-07-05 13:44:00+03	46500.00
06A196	2017-08-11 01:31:00+03	12000.00
06A1AB	2017-08-05 15:24:00+03	58600.00
06A1F1	2017-07-01 08:34:00+03	27300.00
06A21F	2017-07-23 15:02:00+03	76600.00
06A224	2017-07-15 13:22:00+03	114500.00
06A22F	2017-08-11 05:43:00+03	36800.00
06A263	2017-08-12 09:42:00+03	23200.00
06A2B3	2017-07-28 19:38:00+03	23600.00
06A2E6	2017-07-02 04:26:00+03	28000.00
06A31A	2017-07-20 21:08:00+03	59800.00
06A327	2017-07-17 07:49:00+03	67100.00
06A334	2017-07-05 05:59:00+03	28000.00
06A350	2017-07-29 17:32:00+03	30900.00
06A42D	2017-07-30 03:20:00+03	95200.00
06A475	2017-08-02 05:57:00+03	24000.00
06A4A3	2017-06-30 23:37:00+03	16400.00
06A4D6	2017-07-24 12:25:00+03	44000.00
06A504	2017-07-26 01:48:00+03	118300.00
06A528	2017-08-14 04:16:00+03	198600.00
06A551	2017-07-19 01:40:00+03	16400.00
06A5B3	2017-08-14 13:34:00+03	98300.00
06A5E2	2017-08-04 00:48:00+03	59800.00
06A630	2017-08-13 02:44:00+03	67600.00
06A664	2017-07-16 07:55:00+03	34000.00
06A689	2017-07-10 10:47:00+03	54400.00
06A69E	2017-08-03 19:46:00+03	44000.00
06A6BF	2017-08-11 14:56:00+03	15800.00
06A74B	2017-07-21 11:14:00+03	257500.00
06A76D	2017-07-04 14:55:00+03	16400.00
06A7B5	2017-08-05 14:07:00+03	55800.00
06A83D	2017-07-06 21:45:00+03	114500.00
06A8A2	2017-07-30 18:38:00+03	99200.00
06AAB9	2017-08-14 16:31:00+03	73600.00
06AAFE	2017-07-26 19:50:00+03	133200.00
06AB4C	2017-08-05 01:57:00+03	54400.00
06AB86	2017-07-07 01:16:00+03	155400.00
06AB96	2017-07-10 04:05:00+03	95300.00
06ABF1	2017-07-29 15:23:00+03	300700.00
06AC10	2017-07-24 08:30:00+03	189800.00
06AC3F	2017-08-04 22:16:00+03	82900.00
06ACDE	2017-07-09 03:40:00+03	48800.00
06AD2B	2017-07-22 05:50:00+03	39200.00
06ADC5	2017-07-24 15:42:00+03	280000.00
06ADFA	2017-07-14 10:30:00+03	36200.00
06AE0C	2017-08-15 12:33:00+03	173500.00
06AE15	2017-08-15 03:09:00+03	115700.00
06AE1C	2017-07-21 00:07:00+03	19300.00
06AE62	2017-08-03 11:40:00+03	28600.00
06AEAC	2017-07-17 23:44:00+03	12600.00
06AEC3	2017-08-10 06:15:00+03	35500.00
06AF63	2017-08-08 23:56:00+03	49400.00
06AFC7	2017-07-25 14:44:00+03	123600.00
06AFD6	2017-07-16 22:21:00+03	36400.00
06B046	2017-07-05 20:19:00+03	12400.00
06B088	2017-08-14 09:37:00+03	88000.00
06B0AF	2017-07-09 18:47:00+03	78500.00
06B0BC	2017-08-04 23:51:00+03	32800.00
06B0DE	2017-07-09 23:51:00+03	28000.00
06B136	2017-07-01 19:37:00+03	73600.00
06B1C9	2017-07-06 11:14:00+03	193700.00
06B1DB	2017-08-03 20:04:00+03	64700.00
06B229	2017-07-24 00:44:00+03	49600.00
06B276	2017-07-07 02:06:00+03	29600.00
06B361	2017-07-09 22:16:00+03	28800.00
06B3B6	2017-07-27 17:53:00+03	39300.00
06B3BC	2017-08-13 07:21:00+03	144400.00
06B47E	2017-08-08 13:42:00+03	38800.00
06B4F2	2017-07-16 23:41:00+03	67400.00
06B510	2017-07-10 18:44:00+03	40000.00
06B57E	2017-08-10 11:34:00+03	31400.00
06B5AD	2017-07-22 11:45:00+03	87200.00
06B5F1	2017-07-01 14:13:00+03	95200.00
06B60C	2017-07-27 04:19:00+03	203000.00
06B65E	2017-07-28 07:59:00+03	168000.00
06B668	2017-07-10 01:31:00+03	112000.00
06B69D	2017-07-29 17:28:00+03	25400.00
06B715	2017-07-18 19:11:00+03	369000.00
06B72A	2017-08-09 08:56:00+03	38600.00
06B73B	2017-07-24 02:53:00+03	44700.00
06B762	2017-07-05 16:21:00+03	136600.00
06B77D	2017-08-12 09:03:00+03	39800.00
06B7AA	2017-07-01 07:04:00+03	46400.00
06B7FD	2017-08-08 03:47:00+03	131000.00
06B806	2017-08-13 16:07:00+03	27300.00
06B815	2017-07-21 11:13:00+03	13000.00
06B851	2017-07-18 05:56:00+03	119400.00
06B885	2017-07-06 08:59:00+03	24400.00
06B88E	2017-08-11 02:59:00+03	18600.00
06B892	2017-07-06 04:40:00+03	56600.00
06B8B7	2017-07-27 14:50:00+03	252400.00
06B8BE	2017-06-30 01:32:00+03	57400.00
06B8C0	2017-07-25 00:14:00+03	68400.00
06B8E3	2017-08-02 07:22:00+03	77600.00
06B8F4	2017-08-09 09:22:00+03	46000.00
06B96A	2017-08-01 04:20:00+03	31600.00
06B9A7	2017-08-05 18:15:00+03	84300.00
06BA19	2017-07-21 02:23:00+03	80300.00
06BA85	2017-07-25 01:39:00+03	36800.00
06BAC2	2017-08-11 08:13:00+03	47000.00
06BB37	2017-08-09 12:00:00+03	94400.00
06BB41	2017-08-03 21:24:00+03	48500.00
06BB54	2017-08-08 15:12:00+03	141400.00
06BBD4	2017-07-27 23:52:00+03	65200.00
06BBE2	2017-07-20 15:33:00+03	12600.00
06BBFF	2017-08-08 20:39:00+03	12600.00
06BC2F	2017-08-14 18:56:00+03	37900.00
06BC3D	2017-08-09 20:41:00+03	186000.00
06BC47	2017-08-07 12:38:00+03	43500.00
06BCAC	2017-07-16 22:46:00+03	186500.00
06BCBB	2017-07-21 02:47:00+03	147300.00
06BCC7	2017-08-10 13:44:00+03	13400.00
06BCFA	2017-07-16 01:25:00+03	168000.00
06BD2B	2017-08-10 01:04:00+03	56000.00
06BDA8	2017-07-06 21:45:00+03	55800.00
06BDB4	2017-07-24 06:33:00+03	114700.00
06BDC6	2017-07-22 03:45:00+03	123200.00
06BE24	2017-08-04 04:41:00+03	76400.00
06BE6F	2017-08-07 09:11:00+03	13500.00
06BE74	2017-07-31 08:18:00+03	52000.00
06BEDA	2017-07-18 23:32:00+03	21800.00
06BF40	2017-07-05 17:59:00+03	121800.00
06BF57	2017-07-03 12:57:00+03	23200.00
06BF86	2017-07-11 18:46:00+03	132800.00
06BFEF	2017-06-28 20:24:00+03	142300.00
06C06B	2017-08-06 22:01:00+03	44100.00
06C08B	2017-08-03 15:05:00+03	135600.00
06C0AB	2017-08-01 08:06:00+03	266400.00
06C154	2017-08-14 08:51:00+03	144700.00
06C187	2017-07-14 18:31:00+03	130400.00
06C1BC	2017-08-12 18:53:00+03	59200.00
06C1ED	2017-07-16 20:29:00+03	28000.00
06C2C0	2017-07-26 14:40:00+03	30000.00
06C2E7	2017-07-26 17:10:00+03	93900.00
06C30D	2017-08-11 22:01:00+03	99700.00
06C36D	2017-07-23 18:36:00+03	132000.00
06C389	2017-08-14 23:46:00+03	65500.00
06C42F	2017-07-28 11:37:00+03	58600.00
06C50F	2017-07-19 14:41:00+03	6700.00
06C548	2017-07-29 23:52:00+03	39400.00
06C551	2017-07-28 04:38:00+03	6900.00
06C55C	2017-07-31 08:48:00+03	73600.00
06C56C	2017-07-28 08:33:00+03	192900.00
06C59E	2017-07-12 15:40:00+03	18600.00
06C5EC	2017-07-14 13:21:00+03	144400.00
06C608	2017-08-09 02:49:00+03	65600.00
06C6CE	2017-07-13 17:29:00+03	32800.00
06C704	2017-08-13 14:53:00+03	6300.00
06C70D	2017-07-25 14:46:00+03	290400.00
06C731	2017-07-07 08:51:00+03	39300.00
06C733	2017-07-22 21:13:00+03	56000.00
06C746	2017-08-13 17:21:00+03	116700.00
06C763	2017-07-30 13:46:00+03	39200.00
06C789	2017-07-12 03:20:00+03	18800.00
06C800	2017-08-11 08:34:00+03	67600.00
06C80E	2017-07-17 05:51:00+03	45200.00
06C81D	2017-07-14 03:23:00+03	120800.00
06C879	2017-07-09 17:11:00+03	55800.00
06C87A	2017-07-28 20:33:00+03	6000.00
06C896	2017-08-11 20:06:00+03	47500.00
06C89F	2017-08-15 06:37:00+03	43600.00
06C8AA	2017-07-11 18:46:00+03	36200.00
06C8BC	2017-08-14 17:59:00+03	47000.00
06C8CF	2017-07-28 03:02:00+03	29600.00
06C911	2017-07-20 01:12:00+03	59900.00
06C9A4	2017-07-22 23:25:00+03	16400.00
06CA28	2017-07-13 22:51:00+03	103600.00
06CA38	2017-07-27 01:38:00+03	89700.00
06CA56	2017-08-05 16:31:00+03	48800.00
06CA73	2017-07-28 11:34:00+03	133200.00
06CABA	2017-07-30 10:43:00+03	39500.00
06CADA	2017-08-12 11:55:00+03	84600.00
06CAEB	2017-08-03 06:23:00+03	23100.00
06CAF8	2017-07-06 01:12:00+03	26200.00
06CB4D	2017-08-05 07:03:00+03	113600.00
06CB5D	2017-07-26 17:42:00+03	60700.00
06CB5F	2017-07-23 01:02:00+03	21400.00
06CBDD	2017-08-13 08:52:00+03	19600.00
06CC2E	2017-08-09 01:09:00+03	226000.00
06CC3D	2017-08-14 06:42:00+03	62600.00
06CC48	2017-08-06 10:49:00+03	168000.00
06CC78	2017-07-28 02:36:00+03	369000.00
06CCB3	2017-07-29 13:48:00+03	24800.00
06CD08	2017-07-13 08:39:00+03	96300.00
06CD17	2017-08-06 12:13:00+03	31100.00
06CD26	2017-08-12 18:29:00+03	42700.00
06CD30	2017-07-07 09:01:00+03	26700.00
06CD6A	2017-08-04 08:50:00+03	30000.00
06CD77	2017-07-30 05:45:00+03	65600.00
06CDDF	2017-07-07 17:33:00+03	23400.00
06CE33	2017-07-01 14:50:00+03	41200.00
06CE58	2017-07-13 08:46:00+03	51900.00
06CE81	2017-07-16 01:24:00+03	46400.00
06CE8F	2017-08-14 15:57:00+03	182400.00
06CE9B	2017-08-12 23:36:00+03	26700.00
06CEB5	2017-07-18 20:26:00+03	94000.00
06CF0A	2017-08-12 10:53:00+03	98400.00
06CF9D	2017-08-07 06:23:00+03	68800.00
06CFB7	2017-07-15 07:28:00+03	12600.00
06CFBC	2017-07-26 11:44:00+03	56000.00
06CFD5	2017-07-10 01:19:00+03	64600.00
06CFF9	2017-07-23 20:03:00+03	16400.00
06D023	2017-08-11 01:31:00+03	204700.00
06D05A	2017-07-25 04:15:00+03	172100.00
06D080	2017-08-08 02:12:00+03	58600.00
06D09C	2017-07-13 19:11:00+03	123000.00
06D0B1	2017-07-04 02:20:00+03	142400.00
06D126	2017-07-12 01:02:00+03	57900.00
06D1CB	2017-07-29 18:48:00+03	28000.00
06D1DE	2017-07-11 14:48:00+03	29200.00
06D245	2017-08-05 15:38:00+03	50400.00
06D287	2017-08-06 06:53:00+03	212000.00
06D29E	2017-07-13 21:05:00+03	49300.00
06D39F	2017-07-12 17:20:00+03	136100.00
06D3D7	2017-07-11 03:55:00+03	123000.00
06D460	2017-07-14 02:05:00+03	28800.00
06D466	2017-07-11 13:57:00+03	25800.00
06D4D2	2017-06-29 15:22:00+03	31400.00
06D592	2017-07-15 09:44:00+03	14000.00
06D5B2	2017-07-19 19:27:00+03	123900.00
06D615	2017-07-31 17:26:00+03	265200.00
06D640	2017-07-30 05:08:00+03	28600.00
06D645	2017-07-17 11:48:00+03	86600.00
06D676	2017-07-09 00:05:00+03	155400.00
06D703	2017-07-10 10:31:00+03	26000.00
06D743	2017-07-27 14:44:00+03	133200.00
06D7A8	2017-07-20 08:44:00+03	118400.00
06D7BF	2017-08-15 01:22:00+03	27600.00
06D7CA	2017-07-02 13:27:00+03	65500.00
06D7CC	2017-07-03 06:10:00+03	77400.00
06D7F0	2017-08-13 18:33:00+03	56600.00
06D7FB	2017-07-30 00:49:00+03	92000.00
06D861	2017-07-05 03:18:00+03	39300.00
06D8B4	2017-07-05 11:48:00+03	56800.00
06D91D	2017-07-15 08:43:00+03	59100.00
06D9B2	2017-07-20 17:45:00+03	28700.00
06D9B8	2017-08-14 23:38:00+03	120400.00
06D9FA	2017-07-31 15:02:00+03	28800.00
06DA9D	2017-07-27 07:07:00+03	46000.00
06DAD2	2017-08-12 12:27:00+03	25200.00
06DB21	2017-08-13 17:18:00+03	61700.00
06DB89	2017-07-08 15:57:00+03	15700.00
06DBAB	2017-07-20 16:18:00+03	99300.00
06DBAC	2017-08-09 16:11:00+03	92100.00
06DBAD	2017-08-03 00:51:00+03	116800.00
06DBB4	2017-07-01 23:50:00+03	47200.00
06DBCF	2017-07-06 10:08:00+03	46300.00
06DBDC	2017-08-12 19:55:00+03	193100.00
06DBF1	2017-08-06 06:49:00+03	55900.00
06DC3F	2017-07-19 06:52:00+03	66600.00
06DC56	2017-08-13 07:59:00+03	27900.00
06DC9C	2017-08-10 15:37:00+03	66600.00
06DCAC	2017-07-04 13:48:00+03	30800.00
06DCE4	2017-08-07 22:36:00+03	22200.00
06DD05	2017-07-10 06:06:00+03	64800.00
06DDB5	2017-07-10 02:49:00+03	55400.00
06DDBA	2017-07-28 14:23:00+03	132800.00
06DDFA	2017-07-19 06:25:00+03	47300.00
06DED5	2017-07-01 17:06:00+03	35300.00
06DEDD	2017-08-14 12:34:00+03	46400.00
06DF1A	2017-07-23 20:37:00+03	50100.00
06E049	2017-08-02 12:51:00+03	57100.00
06E050	2017-07-23 10:38:00+03	113300.00
06E0A0	2017-08-07 18:30:00+03	135400.00
06E14F	2017-07-19 04:18:00+03	13400.00
06E177	2017-07-30 13:08:00+03	266200.00
06E1A6	2017-07-14 21:20:00+03	66200.00
06E1D3	2017-07-12 19:58:00+03	47200.00
06E233	2017-07-10 01:40:00+03	28800.00
06E264	2017-08-10 17:12:00+03	42700.00
06E2D6	2017-08-12 02:14:00+03	122700.00
06E332	2017-07-09 08:55:00+03	89000.00
06E416	2017-08-06 16:32:00+03	85000.00
06E41B	2017-07-14 06:30:00+03	18000.00
06E45F	2017-07-28 18:39:00+03	38400.00
06E488	2017-08-14 23:07:00+03	32800.00
06E54D	2017-07-12 14:47:00+03	99700.00
06E5CD	2017-08-08 19:56:00+03	42700.00
06E5D4	2017-07-16 04:53:00+03	36200.00
06E61B	2017-08-05 09:37:00+03	28800.00
06E62B	2017-08-12 21:30:00+03	102300.00
06E66B	2017-07-11 18:57:00+03	22000.00
06E6CB	2017-07-17 17:34:00+03	72300.00
06E6D5	2017-07-27 14:07:00+03	135200.00
06E6F8	2017-07-03 04:21:00+03	103500.00
06E83B	2017-08-11 23:49:00+03	16800.00
06E897	2017-07-11 10:55:00+03	6600.00
06E8A1	2017-07-14 07:47:00+03	21800.00
06E8D0	2017-07-09 20:52:00+03	40000.00
06E918	2017-08-11 15:36:00+03	286100.00
06E92E	2017-07-04 02:17:00+03	135000.00
06E93D	2017-07-11 23:37:00+03	50800.00
06E9AA	2017-08-12 02:26:00+03	135400.00
06E9E6	2017-07-05 23:53:00+03	21800.00
06E9FC	2017-08-08 23:45:00+03	66600.00
06E9FD	2017-08-05 04:59:00+03	103900.00
06EA9B	2017-08-01 19:59:00+03	102100.00
06EAAC	2017-07-15 07:03:00+03	92400.00
06EACD	2017-07-02 19:40:00+03	12400.00
06EAFD	2017-08-11 19:29:00+03	25100.00
06EB0A	2017-07-30 22:30:00+03	47200.00
06EB67	2017-08-04 22:51:00+03	24400.00
06EB9E	2017-07-20 18:29:00+03	39600.00
06ECDB	2017-07-02 00:31:00+03	47200.00
06ECF8	2017-08-12 14:49:00+03	26000.00
06EEF8	2017-07-31 04:20:00+03	28800.00
06EF31	2017-07-07 08:49:00+03	94800.00
06EF40	2017-08-14 18:21:00+03	16800.00
06EF66	2017-08-14 03:47:00+03	77800.00
06EFB5	2017-08-02 23:00:00+03	42400.00
06F024	2017-07-18 14:15:00+03	58400.00
06F049	2017-07-22 04:20:00+03	12600.00
06F078	2017-08-09 18:35:00+03	22000.00
06F0BE	2017-08-15 08:59:00+03	62800.00
06F0CE	2017-07-03 05:02:00+03	6000.00
06F102	2017-08-13 09:14:00+03	131600.00
06F1F8	2017-07-03 00:15:00+03	24200.00
06F201	2017-07-06 21:52:00+03	35200.00
06F217	2017-07-15 23:34:00+03	30800.00
06F237	2017-08-05 04:12:00+03	95800.00
06F27E	2017-07-07 11:51:00+03	86500.00
06F2AB	2017-07-29 20:36:00+03	40000.00
06F33A	2017-07-26 10:49:00+03	99000.00
06F35E	2017-07-30 15:17:00+03	56000.00
06F3BC	2017-07-24 20:44:00+03	56000.00
06F429	2017-07-12 11:20:00+03	46300.00
06F4C1	2017-07-16 10:54:00+03	12600.00
06F4F1	2017-07-26 04:37:00+03	61800.00
06F537	2017-07-28 05:33:00+03	187600.00
06F55C	2017-08-09 19:41:00+03	81500.00
06F5F6	2017-07-19 20:39:00+03	81600.00
06F652	2017-07-04 21:01:00+03	55800.00
06F672	2017-08-06 00:20:00+03	238300.00
06F718	2017-07-12 14:38:00+03	58200.00
06F752	2017-07-14 13:08:00+03	133200.00
06F766	2017-07-31 19:50:00+03	47600.00
06F768	2017-07-30 05:00:00+03	529100.00
06F7BE	2017-07-12 17:07:00+03	62800.00
06F808	2017-07-27 18:47:00+03	6800.00
06F83A	2017-07-13 00:00:00+03	61800.00
06F876	2017-07-24 17:15:00+03	48800.00
06F882	2017-07-21 04:19:00+03	53600.00
06F964	2017-07-23 21:36:00+03	79600.00
06F969	2017-07-13 13:31:00+03	97700.00
06F96C	2017-07-23 08:01:00+03	20400.00
06F985	2017-07-07 09:51:00+03	27600.00
06F9B2	2017-08-12 04:48:00+03	97700.00
06F9CE	2017-07-26 07:46:00+03	12600.00
06FA43	2017-07-28 10:03:00+03	117800.00
06FAE4	2017-08-11 11:42:00+03	16000.00
06FB91	2017-08-05 14:19:00+03	70700.00
06FBBF	2017-08-05 11:21:00+03	55700.00
06FC05	2017-07-19 17:07:00+03	50400.00
06FC55	2017-08-03 20:05:00+03	50600.00
06FCCA	2017-07-17 04:21:00+03	51300.00
06FCE2	2017-07-08 02:34:00+03	17800.00
06FD60	2017-07-07 08:01:00+03	179400.00
06FE8C	2017-06-30 19:09:00+03	6600.00
06FE9E	2017-08-04 14:08:00+03	36400.00
06FECB	2017-07-18 09:48:00+03	77900.00
06FED0	2017-07-22 09:58:00+03	136200.00
06FEE5	2017-08-01 04:59:00+03	19200.00
06FF9F	2017-07-02 10:31:00+03	312800.00
070004	2017-07-09 20:44:00+03	81800.00
070009	2017-07-05 02:56:00+03	88500.00
07000F	2017-08-12 03:23:00+03	153300.00
070057	2017-07-11 04:32:00+03	47600.00
070084	2017-08-02 10:21:00+03	98200.00
07008E	2017-08-10 11:00:00+03	61000.00
070091	2017-06-30 21:34:00+03	73600.00
070133	2017-07-29 22:23:00+03	113300.00
070177	2017-07-11 00:24:00+03	27200.00
07018A	2017-07-06 00:02:00+03	49200.00
070198	2017-07-28 23:48:00+03	59800.00
07019F	2017-07-11 00:48:00+03	38600.00
0701DF	2017-07-07 15:32:00+03	48800.00
070274	2017-08-13 22:19:00+03	136200.00
070299	2017-07-09 21:27:00+03	10800.00
0702C7	2017-07-11 18:57:00+03	27200.00
0702F6	2017-07-29 16:03:00+03	34400.00
070319	2017-07-07 19:13:00+03	103500.00
070338	2017-08-11 13:07:00+03	20400.00
070368	2017-07-20 18:13:00+03	30200.00
070383	2017-08-01 04:12:00+03	97800.00
0703D5	2017-07-20 00:37:00+03	91600.00
0703DA	2017-08-14 10:33:00+03	38400.00
07045C	2017-07-21 22:26:00+03	63200.00
0704FB	2017-08-07 18:44:00+03	46000.00
070507	2017-08-01 16:59:00+03	19600.00
0705CC	2017-07-14 16:31:00+03	119500.00
0705FC	2017-07-17 11:51:00+03	111600.00
070682	2017-07-20 04:32:00+03	801200.00
0706B3	2017-08-15 09:17:00+03	96800.00
070704	2017-08-09 17:12:00+03	169900.00
070789	2017-08-09 05:25:00+03	39800.00
070798	2017-07-14 15:58:00+03	307700.00
07079D	2017-08-13 09:12:00+03	16100.00
0707AA	2017-08-11 13:16:00+03	58900.00
0707F9	2017-07-14 16:12:00+03	112200.00
070914	2017-07-26 15:23:00+03	129700.00
070A75	2017-07-03 14:37:00+03	61500.00
070AA7	2017-08-03 16:10:00+03	23200.00
070AF4	2017-08-05 12:34:00+03	83000.00
070B92	2017-07-31 16:19:00+03	147100.00
070C1D	2017-08-13 12:52:00+03	20400.00
070C7C	2017-07-02 10:04:00+03	29400.00
070CEB	2017-07-12 12:21:00+03	40800.00
070D6D	2017-07-25 12:49:00+03	12600.00
070D6F	2017-07-22 13:07:00+03	179300.00
070D98	2017-08-12 13:02:00+03	8000.00
070DFD	2017-07-08 05:58:00+03	135400.00
070E6D	2017-08-08 18:31:00+03	62600.00
070E7E	2017-08-14 10:39:00+03	32400.00
070EA7	2017-07-09 08:18:00+03	69900.00
070EDA	2017-07-09 00:33:00+03	108000.00
070F27	2017-07-04 22:08:00+03	93900.00
07104C	2017-07-13 12:33:00+03	54800.00
071161	2017-07-21 18:14:00+03	23600.00
0711A0	2017-07-24 11:21:00+03	57300.00
0711CE	2017-07-19 21:51:00+03	89700.00
0711E5	2017-07-18 16:33:00+03	189200.00
0711EF	2017-07-23 09:28:00+03	73500.00
071246	2017-07-13 16:29:00+03	12000.00
0712CE	2017-07-29 06:40:00+03	66600.00
0712D5	2017-07-20 17:51:00+03	27800.00
0712F7	2017-07-30 14:14:00+03	39900.00
071347	2017-08-14 13:17:00+03	8000.00
07134B	2017-08-12 02:22:00+03	130100.00
07135E	2017-08-09 01:08:00+03	18000.00
0713A1	2017-07-16 21:40:00+03	39500.00
071401	2017-07-18 13:01:00+03	105000.00
071473	2017-07-19 01:28:00+03	155600.00
071498	2017-07-14 09:03:00+03	28000.00
0714CF	2017-08-13 05:55:00+03	472100.00
071515	2017-08-12 02:49:00+03	48400.00
07151D	2017-07-31 07:48:00+03	55800.00
071532	2017-08-12 12:58:00+03	90400.00
071548	2017-07-31 17:32:00+03	75300.00
0715D4	2017-07-31 16:57:00+03	103900.00
0715F1	2017-07-05 06:00:00+03	56600.00
0715F6	2017-08-13 11:23:00+03	86800.00
07160F	2017-07-06 15:59:00+03	12600.00
07169D	2017-07-22 04:45:00+03	147700.00
0716B3	2017-08-13 14:55:00+03	67700.00
0716DD	2017-08-09 22:07:00+03	62600.00
0716FF	2017-07-24 17:46:00+03	120400.00
07171F	2017-07-22 04:36:00+03	6000.00
071788	2017-07-14 20:56:00+03	111600.00
07185D	2017-07-13 21:22:00+03	39100.00
07191F	2017-07-15 15:18:00+03	71000.00
0719C4	2017-07-18 17:01:00+03	150600.00
0719C5	2017-08-07 20:53:00+03	6000.00
0719D9	2017-07-06 16:54:00+03	28800.00
071A34	2017-08-07 22:13:00+03	28000.00
071A45	2017-07-06 10:52:00+03	16100.00
071AA6	2017-06-28 01:00:00+03	14400.00
071B87	2017-07-16 17:02:00+03	6300.00
071BB2	2017-07-13 20:42:00+03	26800.00
071BB8	2017-08-12 23:07:00+03	186600.00
071C9A	2017-07-23 20:19:00+03	48500.00
071C9C	2017-07-15 14:59:00+03	52700.00
071C9D	2017-08-11 13:31:00+03	29600.00
071CC7	2017-07-11 21:31:00+03	111600.00
071CD5	2017-07-19 03:37:00+03	6800.00
071D09	2017-07-16 23:11:00+03	48600.00
071D0C	2017-08-09 14:49:00+03	72300.00
071D6F	2017-07-05 01:04:00+03	198400.00
071D9B	2017-07-21 17:47:00+03	35400.00
071E13	2017-08-09 15:56:00+03	67400.00
071E3A	2017-07-24 19:24:00+03	71200.00
071E6F	2017-07-18 15:16:00+03	135400.00
071EE9	2017-08-04 01:10:00+03	6000.00
071F85	2017-07-06 03:06:00+03	108500.00
071FB1	2017-08-13 02:58:00+03	95700.00
07204F	2017-07-23 16:28:00+03	142800.00
072157	2017-08-12 23:51:00+03	48300.00
0721C5	2017-07-22 23:12:00+03	30000.00
0721CD	2017-08-11 15:42:00+03	67700.00
072249	2017-08-09 00:46:00+03	81200.00
0722B3	2017-07-07 00:58:00+03	19000.00
0722E8	2017-08-11 03:28:00+03	21500.00
072346	2017-07-05 01:04:00+03	133200.00
072349	2017-07-16 17:21:00+03	31800.00
072355	2017-07-26 23:59:00+03	6000.00
07235A	2017-07-14 03:58:00+03	399600.00
0723AD	2017-07-10 11:07:00+03	69500.00
0723C5	2017-07-21 05:12:00+03	69500.00
072496	2017-07-13 11:57:00+03	125400.00
0724FF	2017-08-13 19:57:00+03	64300.00
07257F	2017-08-04 16:30:00+03	13400.00
07258E	2017-07-20 10:20:00+03	36200.00
072595	2017-08-10 05:08:00+03	133100.00
0725B3	2017-07-20 10:51:00+03	31900.00
0725CC	2017-07-27 15:52:00+03	31000.00
07262E	2017-07-29 16:58:00+03	78500.00
072647	2017-07-03 05:45:00+03	26000.00
072658	2017-07-09 05:42:00+03	27200.00
0726C3	2017-07-22 05:12:00+03	81300.00
072704	2017-07-01 07:20:00+03	75300.00
07276A	2017-07-30 22:13:00+03	25000.00
0727AD	2017-07-25 21:40:00+03	6000.00
072847	2017-08-01 01:26:00+03	199700.00
072909	2017-07-30 04:22:00+03	114800.00
07290C	2017-08-03 11:57:00+03	56100.00
07292F	2017-06-27 15:55:00+03	76600.00
072969	2017-08-06 01:00:00+03	58700.00
072986	2017-08-11 06:56:00+03	29600.00
07299E	2017-07-22 09:00:00+03	406700.00
072A02	2017-08-03 07:24:00+03	133100.00
072A2D	2017-08-03 21:56:00+03	11000.00
072A67	2017-07-30 20:25:00+03	66900.00
072ABF	2017-07-07 14:36:00+03	28000.00
072AD7	2017-07-13 16:16:00+03	52100.00
072AE2	2017-07-02 00:14:00+03	16400.00
072AF6	2017-07-23 13:18:00+03	99200.00
072B30	2017-08-06 23:57:00+03	534300.00
072B56	2017-08-07 12:27:00+03	62800.00
072CA5	2017-08-13 01:16:00+03	59900.00
072CFF	2017-07-19 08:25:00+03	78800.00
072D25	2017-08-11 12:22:00+03	283100.00
072D2B	2017-08-12 19:21:00+03	13400.00
072D4A	2017-08-10 10:20:00+03	312300.00
072E5A	2017-08-13 18:59:00+03	55800.00
072EFD	2017-08-05 16:54:00+03	19600.00
072F26	2017-07-09 19:47:00+03	95300.00
072F28	2017-07-14 14:38:00+03	59400.00
073012	2017-07-20 16:17:00+03	14000.00
073018	2017-08-13 14:26:00+03	27700.00
073096	2017-08-07 07:26:00+03	53100.00
0730E3	2017-07-14 08:19:00+03	114600.00
073123	2017-07-31 10:18:00+03	32700.00
07315E	2017-07-21 12:21:00+03	83600.00
0731D5	2017-07-17 03:54:00+03	48800.00
073217	2017-08-06 05:52:00+03	246000.00
073355	2017-08-07 08:08:00+03	23200.00
073399	2017-08-03 10:16:00+03	22000.00
0733A4	2017-08-05 15:03:00+03	53300.00
0733A6	2017-07-10 10:08:00+03	155600.00
0733D4	2017-08-10 05:33:00+03	369000.00
0733DD	2017-07-24 01:08:00+03	35200.00
0733FF	2017-08-02 10:15:00+03	84500.00
07341A	2017-07-19 12:09:00+03	88600.00
07346E	2017-08-02 11:26:00+03	73600.00
073481	2017-07-18 09:36:00+03	101600.00
073546	2017-07-18 18:22:00+03	172000.00
0735AE	2017-07-16 01:43:00+03	8000.00
073613	2017-08-06 20:05:00+03	23600.00
073616	2017-07-27 21:31:00+03	64100.00
073641	2017-08-04 04:34:00+03	39300.00
073657	2017-08-03 03:52:00+03	58200.00
07365B	2017-07-14 16:46:00+03	116400.00
0736ED	2017-07-26 02:04:00+03	398500.00
073717	2017-07-01 13:20:00+03	58000.00
07372E	2017-08-14 01:06:00+03	32800.00
073755	2017-08-04 14:26:00+03	38300.00
07375A	2017-07-02 14:18:00+03	135600.00
07377C	2017-08-10 12:42:00+03	277800.00
0737AA	2017-07-20 14:29:00+03	128800.00
0737FD	2017-07-20 03:54:00+03	151200.00
073844	2017-08-02 22:23:00+03	19600.00
07389A	2017-08-09 03:39:00+03	133200.00
0738B3	2017-07-14 03:05:00+03	271600.00
0738BB	2017-07-07 22:58:00+03	57600.00
0738BD	2017-08-11 10:23:00+03	94000.00
073931	2017-07-03 07:29:00+03	92000.00
07394B	2017-08-13 07:39:00+03	124300.00
0739C1	2017-07-09 07:19:00+03	28800.00
073A0C	2017-07-03 06:57:00+03	13400.00
073A43	2017-07-22 00:00:00+03	60400.00
073A97	2017-07-22 22:57:00+03	67700.00
073ADB	2017-07-04 14:37:00+03	138900.00
073AF0	2017-07-27 05:49:00+03	31600.00
073BC5	2017-07-16 14:54:00+03	81600.00
073C58	2017-06-28 18:51:00+03	40300.00
073C60	2017-07-30 09:02:00+03	24300.00
073C87	2017-08-10 22:02:00+03	22400.00
073CDE	2017-07-11 12:55:00+03	14000.00
073CE9	2017-08-12 05:22:00+03	89100.00
073CEF	2017-07-31 10:40:00+03	75800.00
073D0D	2017-07-12 04:06:00+03	27200.00
073D61	2017-08-10 09:04:00+03	23600.00
073D78	2017-07-14 08:48:00+03	277900.00
073D88	2017-07-22 11:53:00+03	132800.00
073DFE	2017-07-04 18:18:00+03	24300.00
073E1C	2017-07-29 06:58:00+03	69400.00
073E8A	2017-07-26 22:06:00+03	45600.00
073E8F	2017-08-11 09:08:00+03	135600.00
073EF4	2017-08-13 02:54:00+03	57400.00
073F17	2017-07-14 21:44:00+03	28700.00
073F45	2017-07-28 22:40:00+03	93900.00
073F63	2017-08-15 01:51:00+03	97900.00
073F95	2017-08-10 10:38:00+03	25600.00
074002	2017-07-12 18:01:00+03	12000.00
074065	2017-08-15 09:52:00+03	62600.00
0740C5	2017-07-05 02:04:00+03	62600.00
074115	2017-07-19 13:08:00+03	123000.00
074144	2017-08-14 16:04:00+03	14000.00
07416B	2017-07-14 00:32:00+03	40800.00
07424B	2017-07-19 05:08:00+03	28000.00
074285	2017-07-31 22:20:00+03	13400.00
074294	2017-06-30 03:44:00+03	142800.00
0742D2	2017-07-08 20:46:00+03	160800.00
074337	2017-08-14 20:32:00+03	37200.00
0743AB	2017-08-07 18:57:00+03	113600.00
0743CD	2017-07-28 11:40:00+03	81900.00
07442A	2017-06-26 02:24:00+03	265700.00
0744CC	2017-07-11 18:33:00+03	166400.00
074511	2017-07-09 19:21:00+03	47500.00
074516	2017-07-02 10:13:00+03	402400.00
074520	2017-07-23 19:14:00+03	32800.00
074526	2017-07-25 20:28:00+03	29200.00
074534	2017-08-14 13:37:00+03	40700.00
074560	2017-08-08 00:19:00+03	14400.00
074606	2017-07-16 22:50:00+03	232200.00
07465F	2017-07-04 00:48:00+03	46000.00
074693	2017-07-31 02:32:00+03	55800.00
0746B3	2017-08-13 10:55:00+03	21800.00
07470D	2017-08-12 13:28:00+03	49600.00
07471B	2017-07-29 01:20:00+03	26000.00
0747B7	2017-08-02 17:57:00+03	144700.00
0747CC	2017-07-29 17:01:00+03	113800.00
074817	2017-08-06 12:29:00+03	54500.00
074878	2017-07-20 21:42:00+03	372500.00
0748C1	2017-07-01 16:16:00+03	40000.00
0748F3	2017-07-11 19:33:00+03	320800.00
074950	2017-08-10 13:44:00+03	65600.00
0749A2	2017-08-02 19:36:00+03	82700.00
074A2F	2017-07-20 05:30:00+03	270700.00
074AC9	2017-07-25 00:21:00+03	97800.00
074AF6	2017-07-24 03:54:00+03	21400.00
074B48	2017-07-09 22:25:00+03	86500.00
074BB7	2017-07-08 06:48:00+03	98400.00
074BFD	2017-08-13 06:27:00+03	189200.00
074C2B	2017-08-15 01:42:00+03	134800.00
074C32	2017-07-16 06:32:00+03	112000.00
074C33	2017-07-12 04:30:00+03	398500.00
074C43	2017-07-09 06:54:00+03	67700.00
074C63	2017-08-05 18:42:00+03	155100.00
074CC4	2017-07-22 05:25:00+03	396500.00
074CE7	2017-07-15 00:40:00+03	23200.00
074D23	2017-07-29 12:06:00+03	41400.00
074D3A	2017-07-18 20:57:00+03	34000.00
074D59	2017-07-31 02:44:00+03	23200.00
074DD9	2017-06-30 00:27:00+03	21000.00
074DDE	2017-07-05 11:23:00+03	59800.00
074E48	2017-08-15 16:23:00+03	396500.00
074E86	2017-07-23 19:07:00+03	136200.00
074EB9	2017-07-15 14:36:00+03	67700.00
075011	2017-07-02 12:01:00+03	26000.00
07505A	2017-07-01 21:11:00+03	23400.00
075062	2017-07-13 23:20:00+03	57600.00
075070	2017-07-04 18:08:00+03	56000.00
075075	2017-08-14 02:55:00+03	40800.00
0750C7	2017-08-07 14:11:00+03	156400.00
0750CC	2017-08-06 18:09:00+03	46300.00
075100	2017-07-17 08:19:00+03	73600.00
0751FA	2017-07-17 12:00:00+03	21400.00
075215	2017-08-09 21:50:00+03	182300.00
075273	2017-08-03 00:58:00+03	30300.00
0752C2	2017-08-10 03:34:00+03	137400.00
075381	2017-08-09 14:02:00+03	118600.00
075409	2017-07-30 16:29:00+03	134000.00
07540B	2017-07-20 16:14:00+03	43200.00
075445	2017-08-04 03:19:00+03	83100.00
075448	2017-07-23 06:54:00+03	63800.00
075539	2017-08-09 09:48:00+03	8000.00
07557B	2017-07-06 12:26:00+03	67600.00
07559A	2017-08-03 19:09:00+03	58600.00
0755DB	2017-08-08 22:06:00+03	81200.00
0755DE	2017-07-25 17:41:00+03	50700.00
0755E1	2017-07-02 20:50:00+03	74500.00
075699	2017-08-08 17:51:00+03	32800.00
0756C1	2017-07-26 21:30:00+03	75300.00
0756D1	2017-08-08 19:25:00+03	12600.00
07570E	2017-08-10 20:34:00+03	22000.00
07572D	2017-07-13 23:31:00+03	15000.00
075793	2017-07-09 02:06:00+03	24000.00
0757AA	2017-07-10 04:02:00+03	34000.00
075839	2017-06-30 14:32:00+03	40800.00
07584E	2017-07-21 18:19:00+03	26000.00
07588F	2017-07-10 17:09:00+03	56600.00
075898	2017-08-02 06:08:00+03	76900.00
0758A6	2017-07-02 21:39:00+03	88500.00
0758AB	2017-08-08 13:10:00+03	136800.00
0758C6	2017-07-23 15:17:00+03	56900.00
0758D6	2017-07-31 19:24:00+03	21400.00
0758EC	2017-07-12 05:42:00+03	246000.00
07591D	2017-07-17 11:22:00+03	32800.00
07596C	2017-07-15 08:54:00+03	60400.00
075971	2017-07-05 02:30:00+03	16400.00
075A12	2017-07-24 21:53:00+03	57400.00
075A7E	2017-07-15 05:50:00+03	131800.00
075A86	2017-07-07 15:47:00+03	24400.00
075AAB	2017-08-07 09:18:00+03	61900.00
075AB5	2017-08-12 20:08:00+03	73500.00
075ABB	2017-08-09 12:50:00+03	12400.00
075AFA	2017-08-08 23:18:00+03	96800.00
075B3B	2017-07-08 13:08:00+03	40200.00
075B5D	2017-08-12 08:27:00+03	132800.00
075B6B	2017-07-05 03:06:00+03	56000.00
075C03	2017-07-29 12:08:00+03	46400.00
075C30	2017-07-01 04:26:00+03	10700.00
075C9A	2017-07-21 04:44:00+03	53200.00
075CAF	2017-07-25 15:55:00+03	42400.00
075D2A	2017-08-09 21:31:00+03	12400.00
075D5C	2017-08-09 18:49:00+03	80400.00
075E11	2017-07-04 20:38:00+03	72700.00
075E6D	2017-07-27 15:11:00+03	99800.00
075ED1	2017-07-29 13:23:00+03	31400.00
075EFD	2017-06-30 19:44:00+03	23900.00
075F4D	2017-08-04 22:57:00+03	56600.00
075FB7	2017-07-16 03:31:00+03	184300.00
075FCE	2017-07-27 20:10:00+03	76200.00
075FE7	2017-07-24 11:21:00+03	24800.00
07609A	2017-07-14 11:16:00+03	114700.00
0760F8	2017-08-10 03:12:00+03	80000.00
076175	2017-08-06 06:17:00+03	93000.00
07621B	2017-08-01 07:16:00+03	30200.00
07625B	2017-07-13 07:18:00+03	15900.00
0762A9	2017-08-04 17:52:00+03	26800.00
0762DF	2017-08-02 21:51:00+03	39500.00
0762F9	2017-08-07 09:25:00+03	173400.00
076357	2017-07-30 20:06:00+03	22000.00
0763D0	2017-07-23 04:44:00+03	14000.00
0763EE	2017-08-06 01:22:00+03	106900.00
076427	2017-07-07 14:44:00+03	25400.00
07642B	2017-07-16 04:08:00+03	101200.00
07645B	2017-07-04 23:25:00+03	71900.00
076472	2017-07-12 12:31:00+03	35800.00
07647A	2017-08-12 14:23:00+03	99300.00
0764C9	2017-06-30 14:57:00+03	59700.00
07653B	2017-07-21 00:12:00+03	30200.00
076584	2017-07-25 00:38:00+03	99600.00
0765BE	2017-08-07 17:40:00+03	49600.00
0765FC	2017-07-19 18:02:00+03	164700.00
07664E	2017-08-11 10:02:00+03	46000.00
076670	2017-08-08 17:38:00+03	26800.00
07671B	2017-07-15 16:40:00+03	26000.00
076727	2017-08-06 19:26:00+03	80200.00
076770	2017-07-14 20:52:00+03	124300.00
07682F	2017-07-03 02:44:00+03	76800.00
076874	2017-08-07 18:40:00+03	174000.00
076888	2017-07-17 15:01:00+03	35200.00
076889	2017-07-20 09:29:00+03	79600.00
07688A	2017-07-30 01:39:00+03	16400.00
0768BA	2017-08-02 22:10:00+03	84300.00
0768BB	2017-07-17 05:03:00+03	78300.00
076910	2017-07-09 05:29:00+03	167400.00
076967	2017-07-30 14:02:00+03	47200.00
07696F	2017-07-10 20:50:00+03	138900.00
076989	2017-07-21 03:11:00+03	229900.00
0769AB	2017-07-30 20:17:00+03	17800.00
076A1C	2017-07-13 21:17:00+03	371800.00
076A26	2017-08-06 04:23:00+03	117200.00
076AB5	2017-07-13 09:53:00+03	170200.00
076AD3	2017-08-02 05:31:00+03	37900.00
076B01	2017-07-22 10:10:00+03	203100.00
076B22	2017-07-04 06:18:00+03	188000.00
076B44	2017-07-23 22:40:00+03	16400.00
076B4C	2017-08-08 10:12:00+03	136500.00
076B69	2017-07-23 05:45:00+03	63000.00
076B6A	2017-08-10 16:05:00+03	77900.00
076B76	2017-07-18 10:24:00+03	7300.00
076B8B	2017-08-08 12:59:00+03	397700.00
076C80	2017-07-04 13:57:00+03	30200.00
076C94	2017-07-28 09:55:00+03	85000.00
076C9E	2017-08-05 07:41:00+03	40000.00
076DEE	2017-07-07 00:51:00+03	55800.00
076E3C	2017-08-10 12:49:00+03	37900.00
076EB3	2017-07-10 14:14:00+03	28000.00
076EC7	2017-07-13 05:27:00+03	84500.00
076F16	2017-07-25 00:31:00+03	24400.00
076F1C	2017-07-30 01:10:00+03	269600.00
076F4C	2017-07-05 03:42:00+03	50800.00
076F6F	2017-07-31 12:04:00+03	58600.00
076FAF	2017-08-14 15:56:00+03	38600.00
076FFD	2017-07-05 19:46:00+03	99200.00
077018	2017-07-06 11:56:00+03	12400.00
07702D	2017-07-30 17:18:00+03	73600.00
07703B	2017-07-10 18:59:00+03	31600.00
077044	2017-07-31 19:45:00+03	33100.00
0770B8	2017-07-08 04:28:00+03	67600.00
0770E3	2017-07-21 09:34:00+03	20600.00
0770FC	2017-08-12 18:53:00+03	28700.00
077126	2017-07-04 00:56:00+03	92400.00
077153	2017-07-23 18:30:00+03	166100.00
077155	2017-07-26 22:00:00+03	25200.00
077185	2017-07-12 16:55:00+03	311900.00
0772B1	2017-07-22 10:53:00+03	59300.00
0772E2	2017-07-19 23:06:00+03	4000.00
077315	2017-08-14 02:36:00+03	187800.00
077393	2017-08-04 15:37:00+03	99200.00
07739E	2017-07-17 19:05:00+03	174300.00
0773AE	2017-08-10 16:58:00+03	92100.00
0773D0	2017-08-13 03:16:00+03	17200.00
07745B	2017-08-09 15:32:00+03	67900.00
077469	2017-07-16 00:53:00+03	77900.00
077495	2017-07-12 00:30:00+03	153000.00
0774A4	2017-08-09 21:08:00+03	28800.00
077513	2017-07-11 21:42:00+03	14400.00
077584	2017-07-16 10:06:00+03	29100.00
0775CA	2017-07-24 00:07:00+03	26800.00
0775F4	2017-08-06 10:45:00+03	106600.00
07768C	2017-07-30 00:44:00+03	134400.00
0776C2	2017-07-08 04:49:00+03	21200.00
0776E3	2017-07-28 19:57:00+03	99200.00
0776E8	2017-08-05 21:53:00+03	270500.00
0776F8	2017-07-21 17:45:00+03	69500.00
077736	2017-08-01 22:22:00+03	166100.00
07776D	2017-07-28 08:36:00+03	36400.00
0777BF	2017-08-01 07:54:00+03	67900.00
0777CD	2017-07-23 11:52:00+03	67600.00
0777E2	2017-08-05 01:48:00+03	26000.00
077807	2017-07-26 03:38:00+03	101200.00
077892	2017-07-11 07:28:00+03	52900.00
0778E4	2017-08-05 06:20:00+03	35800.00
0778F8	2017-08-11 07:09:00+03	75500.00
077918	2017-07-18 01:19:00+03	43600.00
07791D	2017-07-26 01:43:00+03	23400.00
077963	2017-07-24 15:24:00+03	116000.00
077971	2017-07-30 11:15:00+03	73600.00
077975	2017-06-29 11:23:00+03	39800.00
0779BE	2017-07-01 19:10:00+03	138000.00
0779F7	2017-07-30 19:17:00+03	12600.00
0779F9	2017-07-14 01:26:00+03	16400.00
077A13	2017-08-11 05:14:00+03	399600.00
077B45	2017-08-03 00:23:00+03	125400.00
077B78	2017-07-02 18:38:00+03	24400.00
077BA7	2017-08-08 14:58:00+03	56900.00
077BB7	2017-07-20 15:45:00+03	85600.00
077BF5	2017-08-10 13:38:00+03	55300.00
077C68	2017-08-03 19:13:00+03	28000.00
077C97	2017-07-14 01:01:00+03	22000.00
077D3B	2017-08-09 04:25:00+03	179200.00
077DDE	2017-07-26 22:26:00+03	40000.00
077E02	2017-08-02 05:25:00+03	189700.00
077E2E	2017-08-01 07:45:00+03	46400.00
077E83	2017-08-13 08:37:00+03	46700.00
077E87	2017-08-09 08:40:00+03	47600.00
077F10	2017-08-08 19:25:00+03	42800.00
077F70	2017-08-01 20:22:00+03	186900.00
077FA3	2017-07-19 01:15:00+03	132800.00
07807F	2017-07-16 15:54:00+03	65500.00
0780A9	2017-08-11 14:08:00+03	128800.00
0780D2	2017-07-14 00:52:00+03	559500.00
0780E4	2017-08-12 20:10:00+03	66600.00
078117	2017-07-02 01:02:00+03	123000.00
07818D	2017-07-31 04:30:00+03	36200.00
0781B5	2017-07-26 16:17:00+03	73500.00
078235	2017-07-28 22:30:00+03	19600.00
07823F	2017-08-09 04:22:00+03	55600.00
07834C	2017-07-07 13:10:00+03	34500.00
07837E	2017-07-21 12:17:00+03	26000.00
07837F	2017-07-15 17:36:00+03	65900.00
0783F9	2017-07-11 04:09:00+03	25000.00
078400	2017-07-28 20:42:00+03	146300.00
078473	2017-07-03 07:03:00+03	123000.00
0784E8	2017-07-15 22:39:00+03	47000.00
07851D	2017-08-11 17:41:00+03	123000.00
07852F	2017-07-30 07:00:00+03	28000.00
078624	2017-07-29 01:53:00+03	200500.00
07865B	2017-08-12 18:28:00+03	40800.00
07865D	2017-07-21 14:18:00+03	177800.00
0786EB	2017-08-02 08:21:00+03	67600.00
0786FB	2017-07-30 09:58:00+03	26000.00
078771	2017-08-05 11:51:00+03	13600.00
078776	2017-07-25 12:35:00+03	8000.00
078779	2017-07-25 05:55:00+03	44900.00
078787	2017-06-30 04:33:00+03	29100.00
07878E	2017-08-02 09:19:00+03	15400.00
0787E5	2017-08-02 03:36:00+03	122000.00
0787E7	2017-08-02 02:23:00+03	37900.00
0787F9	2017-08-15 07:48:00+03	100000.00
078805	2017-07-18 21:10:00+03	70600.00
078838	2017-08-09 20:30:00+03	259000.00
0788DF	2017-07-30 05:43:00+03	25200.00
078920	2017-07-28 01:05:00+03	55800.00
07892D	2017-07-31 14:34:00+03	24500.00
07897E	2017-07-07 03:02:00+03	6700.00
0789E2	2017-07-16 23:08:00+03	36200.00
078A29	2017-07-16 23:57:00+03	139800.00
078A52	2017-07-29 03:44:00+03	73600.00
078A53	2017-07-19 10:51:00+03	12600.00
078A61	2017-07-01 23:08:00+03	19600.00
078A78	2017-07-31 17:19:00+03	52100.00
078A9A	2017-07-01 07:49:00+03	34000.00
078AAA	2017-07-02 11:05:00+03	69500.00
078AC8	2017-07-02 12:28:00+03	25200.00
078B37	2017-07-05 19:21:00+03	176500.00
078B4E	2017-07-25 00:58:00+03	26000.00
078B62	2017-07-05 00:33:00+03	72400.00
078B67	2017-07-14 14:18:00+03	260300.00
078B96	2017-08-06 15:17:00+03	31000.00
078B9A	2017-07-11 10:31:00+03	6700.00
078BAD	2017-08-06 16:30:00+03	134400.00
078BB3	2017-08-07 19:54:00+03	47200.00
078C0E	2017-07-30 22:55:00+03	46400.00
078C3D	2017-07-15 06:00:00+03	16400.00
078C8E	2017-07-24 14:22:00+03	87100.00
078D66	2017-07-30 00:17:00+03	6700.00
078D95	2017-07-07 14:20:00+03	34200.00
078DB3	2017-07-12 01:14:00+03	12600.00
078DDF	2017-07-01 14:52:00+03	67600.00
078DE0	2017-07-12 17:21:00+03	81000.00
078E23	2017-08-09 07:55:00+03	37600.00
078EBE	2017-07-12 00:18:00+03	25600.00
078EE5	2017-07-16 17:23:00+03	67200.00
078EF5	2017-07-03 11:47:00+03	40600.00
078EFF	2017-08-08 13:26:00+03	84000.00
078F0B	2017-07-19 00:57:00+03	68800.00
078F27	2017-08-01 01:02:00+03	153700.00
078F2C	2017-07-14 02:42:00+03	813400.00
078F57	2017-07-11 19:08:00+03	75600.00
078F5F	2017-07-21 20:17:00+03	54500.00
078F60	2017-07-14 14:17:00+03	3700.00
078F7B	2017-06-29 00:09:00+03	40800.00
078F8F	2017-07-25 21:19:00+03	115100.00
078FD9	2017-07-15 17:24:00+03	58600.00
07909A	2017-07-22 02:53:00+03	62300.00
0790CD	2017-07-08 15:47:00+03	133200.00
0790EF	2017-07-26 08:00:00+03	39300.00
07910D	2017-07-10 04:29:00+03	47000.00
0791BC	2017-07-15 03:51:00+03	36200.00
0791E8	2017-08-07 15:18:00+03	85700.00
0791F1	2017-07-22 10:48:00+03	14400.00
079212	2017-07-20 00:06:00+03	49100.00
079231	2017-07-29 07:16:00+03	33300.00
079288	2017-08-14 23:51:00+03	135200.00
07928C	2017-07-09 15:50:00+03	6400.00
0792C0	2017-08-01 11:55:00+03	144400.00
0792D8	2017-07-29 23:52:00+03	24400.00
0792DB	2017-07-05 04:12:00+03	16000.00
07935C	2017-07-11 04:31:00+03	108000.00
07938F	2017-08-06 00:30:00+03	266400.00
079391	2017-07-27 04:16:00+03	6300.00
0793E9	2017-07-28 22:34:00+03	131600.00
079489	2017-07-12 06:46:00+03	49600.00
0794E7	2017-07-12 20:27:00+03	139400.00
07950F	2017-07-04 07:21:00+03	32600.00
079549	2017-08-02 13:31:00+03	61800.00
07954C	2017-08-07 17:17:00+03	147700.00
0795F8	2017-07-28 07:00:00+03	22000.00
079602	2017-07-05 06:25:00+03	12600.00
07961B	2017-07-01 05:23:00+03	76100.00
079691	2017-07-16 07:10:00+03	153300.00
0796AE	2017-08-14 15:01:00+03	54800.00
079700	2017-07-16 10:53:00+03	92700.00
07979C	2017-07-24 15:11:00+03	67200.00
079812	2017-08-07 17:49:00+03	144400.00
079814	2017-08-08 12:20:00+03	46000.00
079836	2017-07-12 05:40:00+03	61500.00
079846	2017-08-07 18:49:00+03	54400.00
0798CE	2017-07-29 02:58:00+03	67700.00
0798F6	2017-07-23 06:18:00+03	68900.00
079920	2017-07-27 12:25:00+03	15000.00
07997D	2017-07-31 09:03:00+03	187800.00
079AB3	2017-07-08 02:50:00+03	48500.00
079AD0	2017-08-10 23:35:00+03	265700.00
079AFD	2017-07-07 18:26:00+03	62900.00
079B13	2017-07-05 11:24:00+03	26800.00
079B14	2017-07-16 03:24:00+03	291000.00
079B5C	2017-08-12 19:58:00+03	24800.00
079BC4	2017-07-11 18:56:00+03	52000.00
079C22	2017-08-13 16:03:00+03	152900.00
079C62	2017-07-14 08:43:00+03	71500.00
079DA4	2017-07-26 18:21:00+03	91700.00
079DC0	2017-07-05 20:13:00+03	81600.00
079DCA	2017-08-07 11:20:00+03	66600.00
079E47	2017-07-12 19:02:00+03	201800.00
079E86	2017-07-17 03:00:00+03	296400.00
079EC2	2017-07-29 23:31:00+03	75200.00
079EC6	2017-07-08 09:02:00+03	12600.00
079EDF	2017-08-15 04:51:00+03	86600.00
079F2F	2017-08-05 14:18:00+03	23200.00
079F61	2017-07-31 12:06:00+03	12600.00
07A046	2017-07-23 11:28:00+03	114300.00
07A05D	2017-07-21 07:11:00+03	47400.00
07A05E	2017-07-22 06:46:00+03	46300.00
07A062	2017-06-30 15:12:00+03	18700.00
07A08B	2017-08-04 07:30:00+03	207200.00
07A0AB	2017-08-07 18:51:00+03	38400.00
07A0CB	2017-07-22 23:54:00+03	60800.00
07A0ED	2017-07-28 03:26:00+03	46300.00
07A14B	2017-08-10 02:50:00+03	47000.00
07A19D	2017-08-04 04:45:00+03	6700.00
07A249	2017-07-14 15:49:00+03	27800.00
07A258	2017-08-14 19:11:00+03	29400.00
07A299	2017-07-30 12:43:00+03	53300.00
07A2C5	2017-07-14 16:04:00+03	27800.00
07A2E3	2017-06-26 18:01:00+03	20200.00
07A39D	2017-07-07 17:26:00+03	21400.00
07A3B0	2017-06-27 22:18:00+03	135000.00
07A3B2	2017-07-08 07:58:00+03	91600.00
07A429	2017-08-10 18:56:00+03	25600.00
07A451	2017-07-02 21:09:00+03	244000.00
07A461	2017-07-08 08:37:00+03	31400.00
07A491	2017-08-12 03:13:00+03	112100.00
07A4C4	2017-07-30 07:06:00+03	28000.00
07A52F	2017-07-20 12:05:00+03	46400.00
07A573	2017-07-11 09:13:00+03	532800.00
07A591	2017-08-12 04:13:00+03	28000.00
07A598	2017-07-21 06:45:00+03	100600.00
07A5E8	2017-07-08 01:55:00+03	68600.00
07A63C	2017-08-06 20:19:00+03	62900.00
07A725	2017-07-13 18:50:00+03	51800.00
07A898	2017-07-16 09:40:00+03	92000.00
07A899	2017-07-11 21:27:00+03	32800.00
07A8F1	2017-07-31 18:14:00+03	51900.00
07A8FA	2017-07-25 20:31:00+03	270600.00
07A92B	2017-07-05 13:27:00+03	24400.00
07A989	2017-07-06 19:39:00+03	129000.00
07A996	2017-07-11 06:28:00+03	22000.00
07A9EB	2017-07-28 20:37:00+03	6000.00
07A9FF	2017-07-16 19:06:00+03	40800.00
07AA35	2017-08-04 14:45:00+03	185600.00
07AA53	2017-06-30 19:40:00+03	28800.00
07AA89	2017-08-08 17:25:00+03	114600.00
07AAC7	2017-08-13 02:47:00+03	28200.00
07ABA1	2017-07-29 01:02:00+03	72300.00
07ABF5	2017-08-13 06:42:00+03	82000.00
07AC0F	2017-07-13 12:34:00+03	107200.00
07AC61	2017-07-10 03:19:00+03	12600.00
07AD10	2017-08-09 10:58:00+03	92400.00
07AD28	2017-07-25 14:50:00+03	75300.00
07AD2D	2017-07-27 19:05:00+03	48800.00
07AD55	2017-07-07 11:07:00+03	446900.00
07AD7E	2017-07-03 12:22:00+03	43200.00
07ADA1	2017-07-09 01:00:00+03	37000.00
07AE10	2017-08-03 04:46:00+03	52000.00
07AE2E	2017-07-14 16:52:00+03	39500.00
07AE99	2017-07-18 02:26:00+03	87000.00
07AEA9	2017-08-10 20:19:00+03	36200.00
07AED9	2017-07-19 20:50:00+03	62600.00
07AF11	2017-08-15 05:58:00+03	27900.00
07AF13	2017-08-15 13:30:00+03	28000.00
07AF15	2017-07-09 09:10:00+03	56200.00
07AF97	2017-07-03 01:54:00+03	64300.00
07AFBC	2017-08-08 17:57:00+03	28700.00
07AFC6	2017-07-10 12:30:00+03	31000.00
07AFC7	2017-07-05 09:18:00+03	11600.00
07AFD8	2017-07-12 00:06:00+03	41900.00
07AFF1	2017-07-16 03:59:00+03	47500.00
07B038	2017-08-11 07:12:00+03	122800.00
07B062	2017-07-14 22:00:00+03	51600.00
07B105	2017-07-25 12:05:00+03	270000.00
07B111	2017-07-13 05:16:00+03	43200.00
07B124	2017-07-07 03:13:00+03	51500.00
07B163	2017-07-30 05:22:00+03	166000.00
07B172	2017-07-15 09:06:00+03	47100.00
07B213	2017-07-16 03:30:00+03	279000.00
07B225	2017-08-03 12:26:00+03	65200.00
07B251	2017-08-01 23:29:00+03	23900.00
07B253	2017-08-14 22:25:00+03	51900.00
07B2D9	2017-08-01 20:36:00+03	13800.00
07B2F0	2017-08-05 12:39:00+03	49800.00
07B30A	2017-08-13 10:14:00+03	59200.00
07B340	2017-07-28 13:14:00+03	67700.00
07B397	2017-07-20 21:52:00+03	44800.00
07B417	2017-08-08 03:17:00+03	187800.00
07B4D9	2017-07-17 22:11:00+03	135200.00
07B4DD	2017-08-14 14:44:00+03	67600.00
07B4E6	2017-07-21 22:57:00+03	81200.00
07B535	2017-08-14 09:55:00+03	42000.00
07B5BB	2017-07-27 12:26:00+03	23200.00
07B5D3	2017-08-11 21:08:00+03	60700.00
07B5FD	2017-07-19 18:16:00+03	131100.00
07B60B	2017-07-18 17:10:00+03	56000.00
07B65C	2017-07-21 16:04:00+03	79000.00
07B6A1	2017-08-04 05:59:00+03	35800.00
07B710	2017-07-11 21:15:00+03	16400.00
07B737	2017-08-08 19:51:00+03	25000.00
07B790	2017-07-21 17:28:00+03	13000.00
07B79A	2017-07-31 11:07:00+03	92600.00
07B7A1	2017-08-07 09:35:00+03	67600.00
07B7EA	2017-07-21 01:07:00+03	135000.00
07B803	2017-07-24 09:22:00+03	297900.00
07B818	2017-07-27 16:20:00+03	252200.00
07B827	2017-07-23 07:12:00+03	20400.00
07B8B9	2017-07-31 17:39:00+03	41800.00
07B90A	2017-07-15 23:33:00+03	56000.00
07B93F	2017-08-06 21:56:00+03	139300.00
07B96C	2017-07-24 22:42:00+03	67600.00
07BA15	2017-07-19 09:30:00+03	69500.00
07BA53	2017-08-14 19:23:00+03	61100.00
07BA6F	2017-07-15 04:17:00+03	27700.00
07BA8F	2017-07-23 15:51:00+03	26200.00
07BB11	2017-07-08 05:48:00+03	62800.00
07BB5F	2017-07-31 04:32:00+03	26200.00
07BC7A	2017-07-09 11:35:00+03	44600.00
07BD45	2017-07-18 16:48:00+03	111600.00
07BD46	2017-08-14 17:18:00+03	223200.00
07BD4B	2017-07-15 14:15:00+03	149000.00
07BD70	2017-08-13 07:30:00+03	12600.00
07BDF6	2017-07-26 12:03:00+03	46200.00
07BE0F	2017-08-03 12:44:00+03	76000.00
07BE72	2017-08-11 00:02:00+03	7400.00
07BEB8	2017-07-28 21:27:00+03	28000.00
07BED6	2017-07-30 19:11:00+03	99300.00
07BF15	2017-07-03 15:34:00+03	36200.00
07BF26	2017-08-04 08:34:00+03	51000.00
07BF52	2017-08-05 21:23:00+03	68800.00
07BF53	2017-07-11 22:40:00+03	43800.00
07BF92	2017-07-15 04:16:00+03	79700.00
07C049	2017-07-14 11:52:00+03	147800.00
07C067	2017-07-09 14:57:00+03	56000.00
07C06E	2017-07-22 18:27:00+03	28800.00
07C074	2017-08-04 01:20:00+03	24600.00
07C07A	2017-07-11 10:53:00+03	47300.00
07C090	2017-07-09 22:36:00+03	52000.00
07C0E8	2017-07-30 23:21:00+03	11800.00
07C17A	2017-07-16 00:57:00+03	13700.00
07C1A3	2017-07-03 10:24:00+03	18000.00
07C1AA	2017-07-03 21:33:00+03	123000.00
07C203	2017-07-25 02:08:00+03	94000.00
07C242	2017-07-21 20:59:00+03	42800.00
07C351	2017-07-30 15:54:00+03	112000.00
07C355	2017-08-09 09:43:00+03	38600.00
07C369	2017-07-01 19:26:00+03	63500.00
07C3DC	2017-07-05 08:24:00+03	46400.00
07C43F	2017-07-21 11:07:00+03	28000.00
07C55A	2017-08-04 06:00:00+03	28800.00
07C572	2017-07-05 21:21:00+03	141100.00
07C577	2017-07-25 03:17:00+03	46400.00
07C5AF	2017-07-06 14:25:00+03	203500.00
07C5BF	2017-08-10 09:08:00+03	46500.00
07C5FC	2017-07-03 22:36:00+03	6000.00
07C628	2017-08-11 12:03:00+03	21400.00
07C6BB	2017-07-26 06:42:00+03	6000.00
07C6E3	2017-07-14 20:05:00+03	68600.00
07C701	2017-07-28 05:44:00+03	88800.00
07C735	2017-07-28 14:08:00+03	15400.00
07C791	2017-08-15 15:53:00+03	67800.00
07C808	2017-08-11 21:50:00+03	40800.00
07C893	2017-07-01 06:14:00+03	16400.00
07C8C0	2017-07-16 08:27:00+03	67600.00
07C8FD	2017-07-13 04:34:00+03	46300.00
07C94C	2017-07-27 11:33:00+03	37200.00
07C975	2017-08-06 21:21:00+03	80400.00
07C9B1	2017-07-09 20:55:00+03	114500.00
07C9DA	2017-07-24 17:34:00+03	15500.00
07C9E1	2017-07-22 15:41:00+03	167400.00
07C9EE	2017-07-31 20:32:00+03	92800.00
07CA7A	2017-07-16 17:10:00+03	6000.00
07CABC	2017-07-05 10:37:00+03	124200.00
07CABE	2017-07-19 01:32:00+03	99200.00
07CACB	2017-07-08 01:09:00+03	11600.00
07CB66	2017-07-19 15:26:00+03	116500.00
07CB6B	2017-08-14 10:46:00+03	81600.00
07CBB4	2017-08-05 23:17:00+03	25400.00
07CBD2	2017-07-24 01:44:00+03	186200.00
07CBD7	2017-07-06 23:13:00+03	11800.00
07CCAF	2017-07-22 15:34:00+03	26000.00
07CCE8	2017-07-24 21:49:00+03	36200.00
07CD75	2017-08-13 12:31:00+03	248300.00
07CD8F	2017-07-29 05:00:00+03	175300.00
07CDA3	2017-07-25 09:02:00+03	20200.00
07CDC7	2017-07-09 20:15:00+03	26700.00
07CDE7	2017-07-10 12:18:00+03	57600.00
07CDF1	2017-07-12 16:56:00+03	14400.00
07CDF2	2017-07-29 22:53:00+03	34400.00
07CE1B	2017-07-23 06:28:00+03	133200.00
07CE1E	2017-06-30 01:29:00+03	171400.00
07CE34	2017-07-21 05:20:00+03	28800.00
07CE99	2017-07-14 02:11:00+03	69700.00
07CF0D	2017-08-05 03:07:00+03	64800.00
07CF1D	2017-07-18 03:46:00+03	24400.00
07CF22	2017-07-05 03:50:00+03	68800.00
07CF4E	2017-07-06 09:42:00+03	120000.00
07CF52	2017-08-09 14:32:00+03	80100.00
07CF5E	2017-08-13 13:07:00+03	54500.00
07CF72	2017-07-29 00:38:00+03	24400.00
07CFC4	2017-07-04 09:52:00+03	14400.00
07D00D	2017-07-17 16:42:00+03	135400.00
07D017	2017-07-12 15:12:00+03	62600.00
07D01D	2017-08-12 08:03:00+03	21400.00
07D029	2017-08-15 12:57:00+03	27800.00
07D04C	2017-08-12 16:29:00+03	52800.00
07D08D	2017-07-16 13:47:00+03	399600.00
07D10F	2017-07-26 12:44:00+03	62700.00
07D170	2017-07-15 12:44:00+03	28000.00
07D18D	2017-07-21 18:21:00+03	147700.00
07D1A0	2017-07-03 08:03:00+03	58100.00
07D1A4	2017-07-04 15:00:00+03	14000.00
07D1AC	2017-07-14 14:39:00+03	23200.00
07D1DC	2017-07-29 12:36:00+03	46800.00
07D216	2017-06-28 14:20:00+03	116000.00
07D21F	2017-08-01 03:25:00+03	133200.00
07D27D	2017-07-29 02:30:00+03	25600.00
07D2A0	2017-07-08 12:49:00+03	68900.00
07D2CC	2017-08-14 22:58:00+03	56700.00
07D352	2017-07-22 00:29:00+03	46800.00
07D35D	2017-08-08 04:37:00+03	27200.00
07D388	2017-07-02 13:42:00+03	133100.00
07D402	2017-08-11 00:21:00+03	166100.00
07D41E	2017-07-20 02:10:00+03	6700.00
07D452	2017-07-09 10:32:00+03	12600.00
07D484	2017-07-11 14:51:00+03	68800.00
07D56A	2017-07-03 22:31:00+03	101200.00
07D56F	2017-07-16 23:32:00+03	85000.00
07D5E6	2017-08-10 22:23:00+03	265600.00
07D5F1	2017-07-30 22:35:00+03	20600.00
07D6C6	2017-08-09 06:05:00+03	53100.00
07D6EC	2017-08-14 23:27:00+03	14400.00
07D700	2017-07-16 15:53:00+03	156300.00
07D714	2017-08-01 07:40:00+03	46800.00
07D7AA	2017-07-18 05:19:00+03	114300.00
07D7BD	2017-08-12 10:52:00+03	31600.00
07D801	2017-08-10 15:23:00+03	226200.00
07D81F	2017-08-08 06:06:00+03	25800.00
07D8DC	2017-07-24 11:32:00+03	29400.00
07D906	2017-07-28 13:32:00+03	46400.00
07DA5A	2017-07-02 15:31:00+03	36200.00
07DAB7	2017-07-16 11:04:00+03	70800.00
07DAF2	2017-07-27 17:39:00+03	6200.00
07DB1A	2017-07-23 00:12:00+03	29600.00
07DB1D	2017-07-15 20:18:00+03	58600.00
07DB49	2017-08-13 18:54:00+03	126200.00
07DB62	2017-08-08 07:06:00+03	36000.00
07DBC3	2017-07-21 23:43:00+03	24800.00
07DBCF	2017-08-02 06:42:00+03	12000.00
07DC6E	2017-07-10 08:07:00+03	20000.00
07DC73	2017-07-31 00:06:00+03	12600.00
07DCAE	2017-08-14 15:10:00+03	24600.00
07DCCE	2017-07-08 19:16:00+03	68500.00
07DDA1	2017-07-28 22:59:00+03	55800.00
07DDBB	2017-08-11 01:34:00+03	189800.00
07DDCD	2017-07-09 05:35:00+03	24400.00
07DE17	2017-08-13 22:40:00+03	185000.00
07DE52	2017-08-11 09:40:00+03	27300.00
07DE8A	2017-07-27 15:39:00+03	83700.00
07DEF8	2017-07-25 23:12:00+03	88200.00
07DF1A	2017-07-10 02:43:00+03	266400.00
07DFA8	2017-08-01 12:32:00+03	183100.00
07DFB4	2017-07-28 16:02:00+03	39800.00
07DFE7	2017-07-05 21:37:00+03	57600.00
07E047	2017-07-21 01:55:00+03	250600.00
07E049	2017-07-14 19:37:00+03	8000.00
07E1C3	2017-08-07 04:00:00+03	94800.00
07E23F	2017-07-23 17:36:00+03	421100.00
07E272	2017-07-31 15:27:00+03	193600.00
07E2AB	2017-08-02 12:47:00+03	37200.00
07E323	2017-07-31 09:30:00+03	114800.00
07E36D	2017-08-08 05:52:00+03	14100.00
07E382	2017-08-15 17:31:00+03	77100.00
07E3AC	2017-07-03 10:10:00+03	31000.00
07E44F	2017-08-13 06:39:00+03	15700.00
07E47F	2017-06-29 01:19:00+03	26000.00
07E50B	2017-07-27 15:59:00+03	62700.00
07E538	2017-07-08 03:18:00+03	36100.00
07E543	2017-07-31 23:53:00+03	50100.00
07E585	2017-07-03 00:36:00+03	102300.00
07E5F8	2017-07-31 13:48:00+03	55000.00
07E603	2017-08-15 05:13:00+03	68700.00
07E668	2017-07-25 19:12:00+03	63800.00
07E66E	2017-07-27 08:12:00+03	202800.00
07E681	2017-07-11 07:36:00+03	43200.00
07E683	2017-07-25 04:39:00+03	65600.00
07E6D8	2017-07-16 12:05:00+03	24800.00
07E76D	2017-08-04 06:25:00+03	83600.00
07E788	2017-07-08 09:35:00+03	271200.00
07E7BA	2017-07-08 23:20:00+03	24400.00
07E7D3	2017-07-26 10:49:00+03	37900.00
07E87F	2017-07-05 15:57:00+03	32200.00
07E890	2017-08-08 04:20:00+03	14400.00
07E8A5	2017-08-08 08:22:00+03	198400.00
07E8F7	2017-07-08 13:27:00+03	44800.00
07E98D	2017-08-11 23:44:00+03	27300.00
07E990	2017-07-10 11:56:00+03	369000.00
07EA30	2017-07-26 14:56:00+03	229900.00
07EA4A	2017-06-29 12:07:00+03	98200.00
07EAC3	2017-07-11 22:24:00+03	50000.00
07EB12	2017-07-26 05:00:00+03	65500.00
07EB9C	2017-07-13 09:30:00+03	30200.00
07EBB1	2017-07-27 01:35:00+03	97600.00
07EBB6	2017-07-09 21:32:00+03	57400.00
07EBC5	2017-07-25 00:45:00+03	13000.00
07EBC7	2017-08-02 06:08:00+03	156300.00
07EBEE	2017-07-05 05:01:00+03	28800.00
07EC65	2017-08-14 18:57:00+03	12600.00
07EC79	2017-07-29 21:45:00+03	95600.00
07ECA9	2017-07-19 06:35:00+03	23400.00
07ECCB	2017-07-20 02:11:00+03	36800.00
07ECE8	2017-07-07 02:17:00+03	133700.00
07ED4A	2017-07-31 03:32:00+03	95200.00
07ED5D	2017-08-12 09:45:00+03	129000.00
07ED62	2017-07-13 02:39:00+03	6700.00
07ED7E	2017-08-02 12:20:00+03	47600.00
07ED94	2017-08-02 19:43:00+03	40600.00
07EDB4	2017-07-29 15:13:00+03	16800.00
07EE48	2017-07-17 13:49:00+03	48500.00
07EE70	2017-07-06 15:07:00+03	139500.00
07EF26	2017-07-17 10:14:00+03	75800.00
07EF4F	2017-07-21 12:18:00+03	29200.00
07EF83	2017-07-19 14:14:00+03	88600.00
07EF9C	2017-08-07 16:28:00+03	47300.00
07EFD9	2017-07-17 07:24:00+03	8200.00
07EFF1	2017-08-14 13:00:00+03	10700.00
07F00A	2017-08-15 01:32:00+03	48800.00
07F00D	2017-06-29 23:55:00+03	46300.00
07F0D1	2017-08-05 01:11:00+03	28800.00
07F0DF	2017-07-30 11:40:00+03	57600.00
07F111	2017-07-19 09:35:00+03	75600.00
07F118	2017-07-02 04:16:00+03	14000.00
07F128	2017-07-31 02:16:00+03	78100.00
07F13A	2017-07-26 19:51:00+03	12600.00
07F13D	2017-07-08 12:23:00+03	123000.00
07F14E	2017-07-10 08:54:00+03	7400.00
07F18A	2017-07-03 06:55:00+03	14400.00
07F1C1	2017-07-10 00:46:00+03	230400.00
07F2A5	2017-08-12 21:24:00+03	81300.00
07F2C1	2017-07-31 11:59:00+03	35800.00
07F2EF	2017-06-30 10:59:00+03	29400.00
07F326	2017-08-14 06:50:00+03	52300.00
07F345	2017-08-11 14:05:00+03	52300.00
07F35A	2017-07-13 23:07:00+03	229000.00
07F37C	2017-07-21 05:54:00+03	98400.00
07F39C	2017-07-23 19:01:00+03	26200.00
07F466	2017-07-12 18:00:00+03	81200.00
07F4D0	2017-08-05 14:39:00+03	50600.00
07F4D1	2017-08-13 22:44:00+03	25600.00
07F535	2017-07-19 00:12:00+03	12600.00
07F578	2017-07-16 17:49:00+03	44500.00
07F5C0	2017-07-04 10:11:00+03	136000.00
07F5EA	2017-07-20 11:08:00+03	398500.00
07F60D	2017-08-07 10:45:00+03	13400.00
07F642	2017-07-14 13:15:00+03	35700.00
07F6A9	2017-07-15 19:11:00+03	78300.00
07F6C6	2017-06-25 22:22:00+03	32700.00
07F6F7	2017-08-02 06:09:00+03	142300.00
07F71A	2017-07-21 17:35:00+03	81900.00
07F749	2017-07-10 12:52:00+03	13600.00
07F795	2017-08-10 00:42:00+03	198400.00
07F7D4	2017-07-11 13:14:00+03	80800.00
07F7EF	2017-08-03 11:00:00+03	36200.00
07F7F4	2017-07-10 12:16:00+03	45400.00
07F832	2017-07-16 23:39:00+03	30200.00
07F86E	2017-08-06 10:38:00+03	37000.00
07F8D7	2017-07-10 16:03:00+03	246000.00
07F8EA	2017-07-08 04:42:00+03	28800.00
07F95F	2017-07-24 00:26:00+03	51600.00
07F981	2017-07-21 03:27:00+03	65800.00
07F989	2017-07-04 10:32:00+03	32700.00
07F9A1	2017-08-13 03:16:00+03	39800.00
07FA66	2017-07-03 14:00:00+03	17600.00
07FA7D	2017-07-14 20:02:00+03	57400.00
07FB4F	2017-07-28 02:17:00+03	106400.00
07FB55	2017-08-02 12:01:00+03	87100.00
07FB59	2017-06-30 00:24:00+03	52000.00
07FB60	2017-07-17 11:11:00+03	11600.00
07FB67	2017-07-04 04:42:00+03	23100.00
07FBB3	2017-07-02 07:29:00+03	148200.00
07FBF2	2017-07-09 16:49:00+03	136100.00
07FBFD	2017-07-13 17:56:00+03	92600.00
07FCE3	2017-08-06 07:57:00+03	37900.00
07FD0F	2017-07-08 23:16:00+03	67800.00
07FD25	2017-07-12 20:22:00+03	23400.00
07FD2B	2017-08-03 08:13:00+03	172100.00
07FD37	2017-08-14 01:20:00+03	36400.00
07FD4A	2017-07-26 17:16:00+03	15000.00
07FD65	2017-07-15 17:15:00+03	135600.00
07FE69	2017-08-11 19:15:00+03	56000.00
07FEEB	2017-08-03 02:37:00+03	48800.00
07FF3D	2017-07-09 19:02:00+03	59300.00
07FF84	2017-08-09 03:30:00+03	68900.00
07FFAA	2017-07-28 10:09:00+03	8000.00
080012	2017-07-16 19:15:00+03	92600.00
08001F	2017-07-22 04:33:00+03	40400.00
0800C1	2017-08-06 15:07:00+03	11600.00
080123	2017-07-31 10:15:00+03	16400.00
08013F	2017-07-06 10:56:00+03	42500.00
080162	2017-07-02 05:02:00+03	57500.00
08019D	2017-08-14 19:39:00+03	531400.00
08020C	2017-07-22 04:59:00+03	42700.00
080269	2017-07-11 06:57:00+03	173500.00
0802E5	2017-07-09 03:31:00+03	46000.00
080330	2017-07-23 16:57:00+03	26000.00
0803B1	2017-07-07 12:53:00+03	65500.00
0803D6	2017-07-14 04:34:00+03	183900.00
080418	2017-07-20 10:07:00+03	76600.00
08043F	2017-07-25 17:07:00+03	22100.00
0804A6	2017-07-10 05:56:00+03	36200.00
0804AC	2017-08-11 13:21:00+03	63400.00
0804C3	2017-07-05 19:31:00+03	40000.00
0804DA	2017-08-02 10:11:00+03	46400.00
0804F6	2017-08-06 15:09:00+03	61200.00
080516	2017-07-03 19:44:00+03	57600.00
080521	2017-08-08 10:26:00+03	31800.00
08052D	2017-06-29 11:42:00+03	30200.00
080534	2017-07-14 21:28:00+03	105200.00
080538	2017-08-06 01:40:00+03	44800.00
0805D9	2017-07-29 17:34:00+03	50600.00
0806AC	2017-08-08 16:18:00+03	51600.00
080706	2017-07-16 22:08:00+03	415300.00
0807CE	2017-08-07 13:22:00+03	136100.00
0807EF	2017-08-03 08:34:00+03	26200.00
0807F0	2017-07-01 10:08:00+03	97600.00
080806	2017-07-17 06:52:00+03	70200.00
08080E	2017-07-05 16:37:00+03	42700.00
080823	2017-08-10 11:04:00+03	202100.00
08083C	2017-07-12 12:28:00+03	28800.00
08087D	2017-07-27 18:18:00+03	133200.00
080882	2017-07-08 13:15:00+03	13400.00
0808F5	2017-07-28 16:33:00+03	18600.00
0808FA	2017-07-26 03:37:00+03	14400.00
08093F	2017-08-07 18:37:00+03	52400.00
08096E	2017-08-07 14:47:00+03	153800.00
08099A	2017-08-02 19:37:00+03	73200.00
0809C7	2017-08-14 02:21:00+03	81700.00
0809E4	2017-08-02 16:05:00+03	56000.00
0809FA	2017-07-16 14:05:00+03	12400.00
080A44	2017-07-10 13:47:00+03	39300.00
080A68	2017-07-09 18:16:00+03	92000.00
080A6F	2017-06-30 17:44:00+03	59000.00
080A97	2017-08-14 09:19:00+03	26700.00
080AF9	2017-07-28 21:16:00+03	83100.00
080B08	2017-07-09 04:59:00+03	24700.00
080B56	2017-08-04 17:21:00+03	19600.00
080BA0	2017-07-30 09:50:00+03	47000.00
080BBD	2017-07-10 06:53:00+03	10800.00
080BCA	2017-08-01 10:18:00+03	47400.00
080C31	2017-08-11 11:55:00+03	42800.00
080C9B	2017-07-26 05:15:00+03	26000.00
080CFA	2017-07-17 20:16:00+03	14400.00
080D3B	2017-08-13 08:20:00+03	35200.00
080D73	2017-07-25 15:37:00+03	103700.00
080D85	2017-07-29 14:16:00+03	27200.00
080DB5	2017-07-19 03:17:00+03	22000.00
080DF7	2017-08-03 11:55:00+03	69500.00
080E11	2017-07-23 08:22:00+03	91900.00
080E30	2017-07-04 11:29:00+03	47200.00
080E42	2017-08-07 17:29:00+03	179400.00
080E5A	2017-07-23 11:53:00+03	79600.00
080E7A	2017-07-26 20:05:00+03	17600.00
080EBD	2017-07-25 16:37:00+03	68000.00
080ED2	2017-08-13 06:53:00+03	173100.00
080ED4	2017-07-14 15:39:00+03	77200.00
080F7D	2017-07-09 05:10:00+03	79600.00
081009	2017-07-30 05:28:00+03	36200.00
08101C	2017-07-07 13:49:00+03	94300.00
08101D	2017-08-13 22:52:00+03	399600.00
081036	2017-07-06 13:07:00+03	112000.00
08106C	2017-07-19 12:38:00+03	26500.00
0810B1	2017-07-05 09:32:00+03	133200.00
0810C1	2017-08-01 16:01:00+03	99200.00
0810CD	2017-07-13 11:00:00+03	266400.00
0810EB	2017-08-04 12:01:00+03	26000.00
0810EE	2017-07-17 17:05:00+03	103800.00
0810F5	2017-07-09 11:28:00+03	40600.00
0810F9	2017-07-19 11:02:00+03	57600.00
081117	2017-08-01 13:02:00+03	72800.00
0811C1	2017-07-14 10:33:00+03	286100.00
0811E2	2017-08-03 04:46:00+03	58400.00
08122D	2017-07-25 14:37:00+03	123900.00
081266	2017-07-25 06:21:00+03	254900.00
081270	2017-07-25 23:02:00+03	43500.00
081310	2017-07-15 03:19:00+03	8000.00
081318	2017-07-02 22:55:00+03	142000.00
081352	2017-08-15 13:55:00+03	38400.00
081383	2017-07-25 15:30:00+03	46200.00
0813DC	2017-07-21 10:22:00+03	27900.00
08148C	2017-07-04 08:24:00+03	265600.00
081574	2017-08-15 01:59:00+03	26000.00
0815A4	2017-07-13 18:40:00+03	6700.00
0815B6	2017-08-05 22:22:00+03	182300.00
0815E6	2017-07-09 02:41:00+03	92100.00
081684	2017-07-18 20:18:00+03	66600.00
0816D0	2017-08-10 21:36:00+03	189200.00
0816D4	2017-07-08 11:55:00+03	124200.00
0816FA	2017-08-10 19:43:00+03	66600.00
08173C	2017-07-12 10:49:00+03	170000.00
081787	2017-07-18 10:16:00+03	25200.00
08179E	2017-07-28 22:49:00+03	26800.00
0817B2	2017-08-13 01:41:00+03	254600.00
081820	2017-07-25 08:39:00+03	76300.00
0818A4	2017-08-15 12:29:00+03	22000.00
081934	2017-08-09 18:31:00+03	36200.00
08193F	2017-07-26 19:15:00+03	22600.00
081944	2017-07-30 01:57:00+03	43200.00
081967	2017-07-16 10:59:00+03	13800.00
08198C	2017-07-21 05:12:00+03	260700.00
081992	2017-08-08 18:43:00+03	28800.00
0819D4	2017-07-02 02:30:00+03	99200.00
081A1A	2017-07-15 05:29:00+03	50600.00
081A3E	2017-07-26 19:28:00+03	23600.00
081A8E	2017-07-16 01:24:00+03	289800.00
081B2F	2017-07-01 11:52:00+03	44400.00
081B37	2017-08-09 18:23:00+03	127800.00
081B55	2017-07-31 11:05:00+03	19600.00
081B83	2017-08-06 13:14:00+03	128800.00
081BFC	2017-07-10 09:23:00+03	44500.00
081CB8	2017-08-06 23:42:00+03	69500.00
081CEC	2017-07-14 15:03:00+03	18600.00
081D33	2017-07-29 20:15:00+03	44700.00
081D4E	2017-07-10 20:19:00+03	46200.00
081D7F	2017-08-05 14:27:00+03	155600.00
081E61	2017-07-28 00:36:00+03	113200.00
081E81	2017-07-09 17:59:00+03	100000.00
081EDF	2017-08-04 08:27:00+03	12000.00
081F53	2017-07-17 23:24:00+03	23200.00
081F7F	2017-07-01 09:14:00+03	111600.00
08201F	2017-07-23 00:12:00+03	139200.00
08203E	2017-08-07 12:22:00+03	26000.00
0820AD	2017-07-19 14:21:00+03	34000.00
0820EA	2017-07-03 21:49:00+03	187800.00
082100	2017-07-12 11:57:00+03	27800.00
082125	2017-07-26 21:39:00+03	26800.00
08218F	2017-08-03 14:10:00+03	100900.00
0821AF	2017-08-11 19:05:00+03	48000.00
0821B6	2017-07-28 10:58:00+03	92000.00
0821BC	2017-07-27 10:31:00+03	24000.00
0821BD	2017-08-03 13:10:00+03	24400.00
082201	2017-07-14 21:08:00+03	28000.00
08220B	2017-08-12 16:42:00+03	61500.00
0822B3	2017-07-29 08:54:00+03	54800.00
0822C9	2017-08-12 04:49:00+03	71800.00
082301	2017-08-12 00:57:00+03	123000.00
082302	2017-07-16 11:56:00+03	32700.00
082331	2017-08-02 17:39:00+03	28000.00
08242B	2017-08-15 04:19:00+03	26000.00
08244D	2017-08-12 14:50:00+03	6000.00
082467	2017-08-13 00:38:00+03	6300.00
082491	2017-07-02 20:12:00+03	19600.00
0824A7	2017-07-31 01:29:00+03	36200.00
0824A9	2017-08-08 19:54:00+03	46400.00
0824C5	2017-07-25 23:36:00+03	112400.00
0824D4	2017-08-02 17:47:00+03	408500.00
08251B	2017-07-21 20:47:00+03	103000.00
082564	2017-07-26 07:21:00+03	28000.00
082565	2017-08-07 11:44:00+03	118000.00
08256D	2017-08-08 17:53:00+03	25100.00
082585	2017-07-12 05:45:00+03	56000.00
0825B9	2017-07-17 04:06:00+03	27200.00
082611	2017-07-25 17:32:00+03	19800.00
082667	2017-08-04 01:11:00+03	62600.00
082677	2017-07-18 04:47:00+03	12400.00
082691	2017-08-01 06:25:00+03	236000.00
0826CC	2017-07-05 02:04:00+03	14400.00
082709	2017-08-13 02:06:00+03	158900.00
082712	2017-08-01 16:29:00+03	257600.00
082717	2017-07-05 14:42:00+03	100200.00
082722	2017-07-31 07:01:00+03	69000.00
08274A	2017-07-25 06:37:00+03	6800.00
0827BE	2017-08-11 17:55:00+03	68400.00
0827E9	2017-07-30 22:24:00+03	163200.00
0827EB	2017-08-10 19:57:00+03	96800.00
0827F2	2017-07-09 08:58:00+03	58000.00
082850	2017-08-02 18:29:00+03	381300.00
08285D	2017-07-15 15:45:00+03	123000.00
08287F	2017-07-08 09:22:00+03	57400.00
0828BF	2017-07-15 15:47:00+03	32300.00
0828C1	2017-07-11 06:12:00+03	84500.00
08299D	2017-07-17 13:59:00+03	67700.00
0829CB	2017-07-18 00:30:00+03	67000.00
0829D5	2017-07-19 08:34:00+03	89600.00
0829DE	2017-08-12 12:27:00+03	25800.00
082A24	2017-07-24 12:21:00+03	72400.00
082A3B	2017-07-15 16:17:00+03	119500.00
082A3E	2017-08-02 16:54:00+03	55800.00
082A8A	2017-07-13 09:34:00+03	33100.00
082A9C	2017-08-14 11:18:00+03	23200.00
082A9E	2017-07-16 18:48:00+03	36700.00
082AC2	2017-08-07 17:20:00+03	55800.00
082ADE	2017-08-01 22:39:00+03	23200.00
082AEF	2017-07-26 15:06:00+03	92800.00
082B00	2017-07-09 10:55:00+03	531400.00
082B30	2017-08-01 09:21:00+03	56600.00
082B40	2017-07-22 21:52:00+03	57500.00
082B65	2017-07-16 17:25:00+03	23200.00
082B85	2017-08-12 20:28:00+03	44600.00
082B94	2017-08-01 14:40:00+03	354400.00
082BC4	2017-06-28 19:47:00+03	76400.00
082BCF	2017-07-01 14:33:00+03	111700.00
082C2F	2017-07-11 11:58:00+03	67600.00
082C4B	2017-08-02 07:17:00+03	58600.00
082C72	2017-07-28 11:27:00+03	283200.00
082C86	2017-07-31 16:23:00+03	260300.00
082CB4	2017-07-31 06:42:00+03	154800.00
082D21	2017-07-24 12:25:00+03	167400.00
082D4F	2017-08-01 22:30:00+03	6800.00
082D50	2017-08-12 19:25:00+03	78200.00
082D76	2017-07-13 05:34:00+03	44600.00
082DA0	2017-08-13 18:03:00+03	62600.00
082E48	2017-07-10 22:31:00+03	111600.00
082E6A	2017-08-08 15:11:00+03	99600.00
082E8A	2017-08-14 06:49:00+03	39300.00
082F0C	2017-08-14 09:18:00+03	172100.00
082F23	2017-06-28 00:50:00+03	40000.00
082FAA	2017-08-05 22:48:00+03	45200.00
082FBE	2017-07-26 23:21:00+03	133900.00
083014	2017-07-29 11:41:00+03	39200.00
08301B	2017-08-11 14:47:00+03	56600.00
0830D4	2017-08-15 11:03:00+03	62000.00
0831A9	2017-07-08 06:02:00+03	67100.00
083207	2017-07-19 02:55:00+03	148200.00
08326E	2017-07-12 04:23:00+03	107000.00
0832A4	2017-08-12 14:27:00+03	24400.00
0832C0	2017-07-02 20:03:00+03	55800.00
0832C6	2017-08-14 03:37:00+03	13400.00
0832D4	2017-07-31 05:38:00+03	55800.00
083330	2017-08-09 21:07:00+03	88600.00
083348	2017-07-18 20:34:00+03	23600.00
0833A5	2017-07-30 12:20:00+03	113600.00
08346A	2017-06-29 15:10:00+03	23200.00
083473	2017-08-11 11:11:00+03	144700.00
0834BB	2017-08-02 02:40:00+03	12200.00
0834D6	2017-07-10 12:24:00+03	55800.00
083508	2017-07-13 01:53:00+03	52900.00
083510	2017-06-30 14:18:00+03	40000.00
08351F	2017-06-30 21:50:00+03	84300.00
08352C	2017-08-11 11:18:00+03	95000.00
083539	2017-07-19 06:36:00+03	27200.00
083555	2017-08-09 23:43:00+03	51900.00
083584	2017-08-10 20:24:00+03	35200.00
083595	2017-07-10 17:12:00+03	73600.00
0835BA	2017-07-10 00:43:00+03	23200.00
0835E1	2017-07-24 18:13:00+03	57600.00
0835EE	2017-07-20 13:13:00+03	107800.00
083655	2017-08-11 08:44:00+03	39500.00
0836D0	2017-08-02 01:53:00+03	46500.00
0836EA	2017-08-14 03:14:00+03	81600.00
08378D	2017-07-01 02:59:00+03	21800.00
0837C1	2017-07-25 07:53:00+03	90000.00
08387C	2017-08-10 08:24:00+03	52000.00
0838B0	2017-07-26 04:37:00+03	56100.00
0838F5	2017-07-16 10:26:00+03	20400.00
083939	2017-08-07 10:49:00+03	123600.00
08394C	2017-07-18 13:45:00+03	52700.00
083952	2017-07-26 22:07:00+03	83700.00
083A7B	2017-07-21 13:24:00+03	50000.00
083A92	2017-07-13 08:15:00+03	75000.00
083AE4	2017-08-04 22:19:00+03	133100.00
083B1F	2017-07-13 14:27:00+03	26800.00
083B42	2017-07-09 23:08:00+03	62200.00
083B64	2017-08-02 12:00:00+03	76600.00
083B77	2017-07-04 11:14:00+03	13200.00
083BB4	2017-08-07 12:44:00+03	57600.00
083BBB	2017-08-14 15:31:00+03	67600.00
083BBD	2017-07-30 11:05:00+03	67200.00
083C00	2017-07-02 18:50:00+03	96100.00
083C77	2017-07-18 12:04:00+03	153200.00
083CBB	2017-07-10 22:52:00+03	479700.00
083CC0	2017-07-10 01:42:00+03	119400.00
083D27	2017-08-09 08:28:00+03	12000.00
083D5B	2017-08-02 12:13:00+03	6000.00
083DBC	2017-08-15 17:37:00+03	7500.00
083DFB	2017-08-04 17:59:00+03	72400.00
083E34	2017-07-17 23:00:00+03	19600.00
083E59	2017-07-17 09:12:00+03	86000.00
083E74	2017-07-15 12:50:00+03	133100.00
083E7D	2017-08-07 22:38:00+03	6800.00
083F2C	2017-07-07 16:22:00+03	24400.00
083F4F	2017-07-03 09:05:00+03	66600.00
083F9D	2017-08-06 16:41:00+03	185700.00
084024	2017-08-01 06:35:00+03	282300.00
084083	2017-07-12 14:48:00+03	50800.00
0840B5	2017-07-05 15:53:00+03	91600.00
084198	2017-07-25 14:59:00+03	36200.00
0841A8	2017-06-30 11:41:00+03	140900.00
0841BB	2017-06-30 00:45:00+03	60300.00
0841BD	2017-07-20 19:56:00+03	118000.00
0841CA	2017-08-14 05:33:00+03	36200.00
084200	2017-07-19 21:35:00+03	73100.00
08420A	2017-07-19 03:42:00+03	45500.00
08425B	2017-08-07 10:53:00+03	104000.00
0842F3	2017-07-26 08:41:00+03	12600.00
0842FF	2017-07-27 16:23:00+03	85000.00
0843AE	2017-08-02 23:28:00+03	58600.00
0843FD	2017-08-10 20:26:00+03	106300.00
084436	2017-08-11 19:35:00+03	44800.00
084450	2017-08-11 07:59:00+03	22000.00
08447F	2017-07-04 20:00:00+03	56000.00
0844AA	2017-08-15 11:55:00+03	42600.00
0844B7	2017-07-24 05:32:00+03	24300.00
084515	2017-08-09 18:00:00+03	106900.00
084538	2017-07-04 08:23:00+03	97200.00
08454E	2017-07-26 10:56:00+03	44800.00
08459F	2017-08-14 19:11:00+03	46800.00
0845E4	2017-07-13 21:28:00+03	29800.00
08460A	2017-08-07 10:57:00+03	49600.00
0846A6	2017-08-06 07:21:00+03	22000.00
08478C	2017-08-02 22:02:00+03	30200.00
08478D	2017-07-26 03:10:00+03	170600.00
08479D	2017-08-01 08:08:00+03	248400.00
0847A6	2017-08-03 08:27:00+03	61800.00
0847BE	2017-07-09 02:33:00+03	60400.00
084836	2017-08-03 19:18:00+03	47100.00
084837	2017-07-28 04:14:00+03	99600.00
08484C	2017-07-25 11:08:00+03	60400.00
08484E	2017-07-15 06:37:00+03	67600.00
0848D1	2017-08-14 09:38:00+03	101100.00
0848DF	2017-07-28 21:15:00+03	46400.00
084926	2017-07-01 00:19:00+03	149200.00
08493C	2017-08-09 18:43:00+03	62600.00
08495B	2017-07-29 16:07:00+03	44800.00
08498B	2017-07-16 18:19:00+03	48600.00
084994	2017-07-28 06:41:00+03	265800.00
0849B0	2017-07-08 23:35:00+03	185600.00
0849DD	2017-07-14 22:59:00+03	26800.00
084AA6	2017-07-31 07:29:00+03	57700.00
084AE7	2017-07-14 05:58:00+03	108500.00
084BFF	2017-07-30 07:08:00+03	46400.00
084C21	2017-07-27 11:18:00+03	265800.00
084C50	2017-07-06 00:59:00+03	56000.00
084C83	2017-08-09 06:48:00+03	103200.00
084CC8	2017-07-14 01:38:00+03	26700.00
084CF8	2017-07-25 06:59:00+03	100700.00
084D02	2017-07-13 11:10:00+03	59800.00
084D04	2017-07-14 12:41:00+03	24400.00
084D2E	2017-08-03 06:50:00+03	24000.00
084D79	2017-07-17 20:55:00+03	95600.00
084DF8	2017-07-08 23:07:00+03	19600.00
084E0B	2017-07-04 05:53:00+03	46000.00
084EAD	2017-07-03 10:27:00+03	201600.00
084EEA	2017-07-16 15:25:00+03	40000.00
084F3C	2017-08-14 20:53:00+03	130900.00
084F45	2017-06-28 23:01:00+03	782000.00
084F66	2017-07-10 06:47:00+03	43000.00
084F7C	2017-07-29 16:49:00+03	27200.00
084FE8	2017-07-13 04:07:00+03	103900.00
08500A	2017-08-09 20:58:00+03	56000.00
08503E	2017-07-13 18:03:00+03	86800.00
0850B0	2017-08-11 10:03:00+03	87400.00
0850C3	2017-08-14 02:28:00+03	15000.00
0850E7	2017-08-08 00:10:00+03	73200.00
0850ED	2017-07-10 23:34:00+03	29600.00
0850F9	2017-07-30 05:18:00+03	123000.00
085107	2017-07-16 07:43:00+03	67000.00
08515D	2017-08-13 02:18:00+03	12400.00
085169	2017-08-08 18:00:00+03	121900.00
0851AB	2017-07-15 23:23:00+03	41600.00
0851FE	2017-07-06 08:55:00+03	26000.00
08521F	2017-06-30 08:24:00+03	49800.00
085229	2017-08-05 23:24:00+03	266300.00
0852E8	2017-07-29 04:39:00+03	34800.00
085321	2017-08-15 03:36:00+03	13400.00
085360	2017-07-04 01:18:00+03	86300.00
0853B6	2017-07-14 04:14:00+03	97900.00
0853D6	2017-08-08 02:56:00+03	8800.00
0853F9	2017-08-05 03:40:00+03	163400.00
08546B	2017-07-18 01:39:00+03	114800.00
0854A8	2017-07-05 05:31:00+03	156500.00
0854E7	2017-07-21 13:00:00+03	260300.00
085514	2017-06-29 01:00:00+03	21400.00
085565	2017-07-08 18:33:00+03	6700.00
08557B	2017-08-06 10:22:00+03	94800.00
08563D	2017-08-14 09:10:00+03	84100.00
085673	2017-07-04 12:20:00+03	74400.00
08568A	2017-07-03 06:09:00+03	23400.00
08571F	2017-08-13 11:30:00+03	131100.00
08573A	2017-08-01 23:38:00+03	35800.00
085749	2017-07-27 04:09:00+03	19600.00
085763	2017-07-16 23:16:00+03	98400.00
0857BD	2017-08-05 09:53:00+03	52800.00
085821	2017-07-31 20:53:00+03	28800.00
08585B	2017-08-09 07:22:00+03	92700.00
0858F1	2017-07-08 03:14:00+03	203100.00
085906	2017-07-27 17:27:00+03	56900.00
08593A	2017-08-04 08:20:00+03	89700.00
08595C	2017-06-28 23:55:00+03	36200.00
08599D	2017-07-22 19:45:00+03	64900.00
0859A9	2017-07-12 07:44:00+03	7400.00
0859D9	2017-07-19 03:20:00+03	68100.00
0859EC	2017-08-02 07:10:00+03	36400.00
0859FA	2017-08-08 20:33:00+03	19600.00
085A29	2017-07-31 11:20:00+03	16400.00
085A42	2017-06-30 13:43:00+03	12400.00
085A8D	2017-08-01 08:58:00+03	88600.00
085AB4	2017-07-01 02:31:00+03	133200.00
085B25	2017-07-05 16:30:00+03	83300.00
085B37	2017-07-31 01:57:00+03	84100.00
085B45	2017-07-26 02:07:00+03	93900.00
085B4D	2017-07-15 22:59:00+03	28800.00
085BAC	2017-07-09 01:47:00+03	128800.00
085BE3	2017-07-17 15:23:00+03	28800.00
085BF7	2017-07-28 07:41:00+03	294200.00
085C20	2017-07-29 03:40:00+03	32400.00
085C36	2017-08-03 19:00:00+03	131600.00
085C72	2017-08-14 12:10:00+03	85000.00
085D80	2017-08-07 19:24:00+03	60900.00
085D81	2017-07-30 21:41:00+03	123000.00
085E29	2017-07-12 15:08:00+03	75300.00
085E91	2017-06-30 01:10:00+03	148200.00
085E9E	2017-08-06 23:11:00+03	19600.00
085ECE	2017-07-17 00:55:00+03	38400.00
085EDB	2017-07-07 20:19:00+03	119600.00
085EDF	2017-07-09 10:24:00+03	69600.00
085EF8	2017-07-04 05:07:00+03	21200.00
085EF9	2017-08-01 21:16:00+03	85000.00
085F4B	2017-08-09 21:30:00+03	123000.00
085FA3	2017-08-07 10:56:00+03	148200.00
086024	2017-07-04 06:01:00+03	70600.00
086052	2017-07-07 12:20:00+03	8200.00
08607A	2017-07-19 20:47:00+03	303100.00
08613E	2017-08-11 22:24:00+03	6300.00
0861B1	2017-07-05 14:46:00+03	7400.00
0861CC	2017-07-25 05:13:00+03	26800.00
086209	2017-07-26 16:56:00+03	39500.00
086220	2017-07-28 00:48:00+03	45500.00
08622E	2017-07-13 15:06:00+03	53100.00
08623E	2017-08-04 15:37:00+03	29600.00
086244	2017-08-01 12:02:00+03	29600.00
08627F	2017-08-02 05:19:00+03	38800.00
086281	2017-07-31 12:46:00+03	26000.00
0862AE	2017-07-22 02:47:00+03	32200.00
0862B5	2017-07-09 07:34:00+03	166900.00
0862D0	2017-07-02 08:39:00+03	113800.00
08642C	2017-08-06 15:31:00+03	67200.00
08644E	2017-07-01 18:23:00+03	123000.00
08646E	2017-07-13 10:03:00+03	111600.00
0864A1	2017-07-29 00:17:00+03	31600.00
0864C5	2017-08-06 04:39:00+03	20600.00
08650D	2017-07-29 16:01:00+03	21800.00
086510	2017-07-01 21:04:00+03	28000.00
08654B	2017-07-15 21:50:00+03	145300.00
08655D	2017-07-25 02:09:00+03	166000.00
086563	2017-07-12 20:19:00+03	140300.00
086624	2017-08-03 02:07:00+03	65600.00
0866AC	2017-08-13 23:38:00+03	402700.00
086706	2017-07-06 11:43:00+03	134700.00
08673E	2017-07-06 05:37:00+03	90800.00
086741	2017-07-25 17:08:00+03	103400.00
086834	2017-08-05 00:34:00+03	142400.00
08683F	2017-07-31 20:46:00+03	6400.00
086919	2017-07-18 11:38:00+03	40800.00
08691E	2017-08-12 18:20:00+03	24400.00
08696D	2017-07-07 12:53:00+03	67200.00
086999	2017-07-03 16:54:00+03	38300.00
086A23	2017-07-04 17:20:00+03	59700.00
086A52	2017-08-01 21:42:00+03	85700.00
086AE2	2017-07-26 03:41:00+03	8400.00
086AF9	2017-08-15 05:49:00+03	34600.00
086B42	2017-08-11 08:33:00+03	47600.00
086BC3	2017-08-15 03:55:00+03	43100.00
086C1C	2017-07-03 20:16:00+03	38300.00
086C2C	2017-07-04 21:17:00+03	6000.00
086C42	2017-07-09 23:53:00+03	60600.00
086C71	2017-07-08 08:52:00+03	131100.00
086CAC	2017-08-06 23:57:00+03	36200.00
086CD1	2017-08-09 04:12:00+03	143100.00
086CF2	2017-08-11 14:04:00+03	86300.00
086CF8	2017-07-25 04:49:00+03	56000.00
086D57	2017-07-05 03:18:00+03	53300.00
086D70	2017-08-06 06:32:00+03	85000.00
086D7F	2017-07-25 08:32:00+03	36000.00
086DD7	2017-07-08 21:20:00+03	45200.00
086E15	2017-08-10 19:28:00+03	48500.00
086E2B	2017-08-15 13:03:00+03	534300.00
086E84	2017-07-08 06:09:00+03	57800.00
086EBA	2017-07-12 07:19:00+03	149300.00
086EC4	2017-07-11 13:34:00+03	28000.00
086EF9	2017-08-01 14:47:00+03	66000.00
086EFA	2017-08-13 06:15:00+03	21800.00
086F1E	2017-07-25 21:36:00+03	12400.00
086F20	2017-08-02 20:32:00+03	40800.00
086F42	2017-07-22 04:56:00+03	23600.00
086FDD	2017-08-12 23:10:00+03	199600.00
086FE6	2017-07-03 19:50:00+03	4100.00
086FFC	2017-07-25 22:02:00+03	81700.00
08702F	2017-07-13 07:13:00+03	101900.00
08705D	2017-07-12 04:03:00+03	17000.00
08706B	2017-07-10 00:33:00+03	6600.00
087081	2017-08-14 02:47:00+03	28800.00
087091	2017-07-20 05:28:00+03	29100.00
0870B2	2017-07-09 10:17:00+03	45000.00
0870F1	2017-07-14 21:28:00+03	54000.00
087106	2017-08-01 18:22:00+03	9800.00
08710E	2017-07-03 21:37:00+03	58800.00
087155	2017-07-22 13:12:00+03	47100.00
08724A	2017-08-09 18:46:00+03	114400.00
087270	2017-07-28 12:55:00+03	167400.00
087298	2017-07-13 04:22:00+03	36000.00
0872B0	2017-07-28 19:33:00+03	13400.00
087327	2017-07-11 04:18:00+03	148700.00
087341	2017-08-06 20:27:00+03	96100.00
0873CF	2017-07-11 23:20:00+03	36200.00
0873DD	2017-07-28 18:31:00+03	20000.00
0873E6	2017-07-04 10:14:00+03	299200.00
087430	2017-07-14 03:15:00+03	27200.00
0874E9	2017-07-08 23:10:00+03	139200.00
087523	2017-08-07 09:56:00+03	133200.00
087533	2017-08-09 22:18:00+03	92800.00
087568	2017-06-29 13:00:00+03	100200.00
08759E	2017-08-06 18:24:00+03	36000.00
0875A6	2017-07-24 22:24:00+03	70500.00
0875DF	2017-07-13 03:09:00+03	66800.00
087641	2017-07-11 18:25:00+03	12000.00
08765E	2017-07-24 18:28:00+03	113000.00
087660	2017-07-08 23:09:00+03	49100.00
0876BD	2017-08-15 07:31:00+03	52600.00
087756	2017-07-18 13:00:00+03	65900.00
0877AF	2017-07-30 07:27:00+03	37700.00
0877CC	2017-07-03 06:44:00+03	73200.00
0877D7	2017-07-13 08:50:00+03	43200.00
0877DB	2017-07-08 12:12:00+03	67600.00
087829	2017-07-19 17:08:00+03	111600.00
08787E	2017-08-04 02:02:00+03	123000.00
0878B4	2017-07-02 03:52:00+03	64600.00
0878CC	2017-08-10 23:13:00+03	54000.00
0878FF	2017-07-16 19:59:00+03	8200.00
087914	2017-07-31 20:33:00+03	43500.00
087929	2017-08-07 16:37:00+03	95600.00
087930	2017-07-10 10:38:00+03	14400.00
087942	2017-07-12 19:30:00+03	147000.00
087958	2017-07-16 19:41:00+03	75300.00
0879FA	2017-06-29 19:56:00+03	19600.00
0879FF	2017-08-01 11:02:00+03	93400.00
087A01	2017-08-05 22:46:00+03	91500.00
087A3B	2017-07-31 01:13:00+03	59800.00
087A90	2017-07-28 03:25:00+03	138900.00
087AA8	2017-07-23 09:52:00+03	28000.00
087ABA	2017-07-04 19:37:00+03	123400.00
087AF5	2017-07-26 07:04:00+03	24400.00
087B05	2017-07-17 17:18:00+03	25200.00
087B49	2017-08-08 13:37:00+03	73100.00
087B4C	2017-07-27 16:40:00+03	187800.00
087B7D	2017-07-05 02:16:00+03	118100.00
087C4E	2017-07-21 01:04:00+03	101200.00
087C96	2017-06-29 14:53:00+03	149200.00
087D84	2017-07-10 05:55:00+03	70700.00
087DC5	2017-07-20 22:01:00+03	14400.00
087E06	2017-07-22 16:27:00+03	95600.00
087EAC	2017-08-02 23:49:00+03	134700.00
087F05	2017-07-14 17:20:00+03	199800.00
087F13	2017-07-08 11:03:00+03	77900.00
087F19	2017-08-08 16:06:00+03	43600.00
087F65	2017-07-20 10:59:00+03	56100.00
087F78	2017-07-18 23:20:00+03	98400.00
087FB6	2017-07-21 11:10:00+03	68800.00
087FD0	2017-07-11 19:52:00+03	50600.00
08801D	2017-08-09 12:38:00+03	112600.00
0880EA	2017-08-01 07:53:00+03	38800.00
08811C	2017-07-09 03:03:00+03	31600.00
088140	2017-08-13 02:58:00+03	52300.00
088189	2017-07-20 14:49:00+03	73600.00
08818D	2017-07-14 10:06:00+03	135600.00
0881A6	2017-07-30 12:55:00+03	14000.00
0881AC	2017-08-04 16:10:00+03	12600.00
0881CD	2017-08-07 09:33:00+03	37600.00
088216	2017-07-28 23:05:00+03	32800.00
088325	2017-07-28 05:03:00+03	36200.00
08836F	2017-07-17 09:42:00+03	75600.00
08838F	2017-07-12 19:49:00+03	46400.00
0883A3	2017-08-06 11:22:00+03	57400.00
0883B2	2017-08-05 08:56:00+03	88400.00
0883B6	2017-07-29 05:34:00+03	127300.00
0883F7	2017-07-19 10:50:00+03	55600.00
0884C8	2017-08-05 22:52:00+03	133100.00
0884F5	2017-07-19 16:19:00+03	6300.00
088535	2017-08-07 15:50:00+03	53400.00
08859B	2017-07-13 12:36:00+03	44600.00
0885A8	2017-07-23 06:51:00+03	45000.00
0885E6	2017-07-18 07:16:00+03	92600.00
088612	2017-07-23 17:58:00+03	93900.00
08862D	2017-07-10 07:07:00+03	28000.00
08862F	2017-07-16 21:03:00+03	89700.00
088645	2017-07-28 10:54:00+03	57600.00
088677	2017-07-13 01:20:00+03	135200.00
0886EE	2017-07-03 18:07:00+03	86500.00
0887F8	2017-08-15 05:59:00+03	12000.00
08882A	2017-08-03 14:07:00+03	69600.00
08885E	2017-06-28 19:23:00+03	95200.00
088875	2017-07-22 11:41:00+03	21600.00
088880	2017-08-11 13:21:00+03	279800.00
0888B1	2017-08-08 12:17:00+03	13700.00
0888C1	2017-08-06 05:04:00+03	21600.00
08896A	2017-08-10 02:24:00+03	133100.00
08898A	2017-07-12 23:47:00+03	6300.00
0889A5	2017-07-25 13:58:00+03	21800.00
0889E8	2017-07-28 10:31:00+03	52900.00
088B04	2017-07-11 11:23:00+03	26000.00
088B1F	2017-07-05 17:13:00+03	188200.00
088B9E	2017-07-06 22:05:00+03	30200.00
088C34	2017-08-11 01:41:00+03	93700.00
088C61	2017-07-28 21:45:00+03	11600.00
088CB0	2017-07-09 07:17:00+03	151200.00
088D27	2017-07-03 18:46:00+03	59700.00
088DB7	2017-07-21 16:24:00+03	199700.00
088DBA	2017-08-05 11:57:00+03	54600.00
088DBD	2017-07-13 08:00:00+03	26800.00
088E4D	2017-07-17 04:09:00+03	73200.00
088E72	2017-07-07 22:32:00+03	46400.00
088FAA	2017-08-10 19:28:00+03	6300.00
088FFA	2017-06-30 21:58:00+03	48800.00
089017	2017-07-11 08:57:00+03	14000.00
089036	2017-07-03 12:04:00+03	6000.00
08906F	2017-07-04 20:41:00+03	44800.00
0890FA	2017-07-28 01:28:00+03	54800.00
08910B	2017-07-08 23:45:00+03	21600.00
08911D	2017-07-16 08:45:00+03	94200.00
08916D	2017-08-12 09:02:00+03	134400.00
0891F4	2017-08-08 03:47:00+03	55800.00
089222	2017-08-14 16:29:00+03	26800.00
0892AA	2017-08-13 20:30:00+03	188800.00
08930A	2017-07-28 16:26:00+03	100600.00
089339	2017-07-19 05:22:00+03	35500.00
089346	2017-07-06 17:01:00+03	152000.00
089362	2017-07-21 21:56:00+03	49200.00
0893C5	2017-07-31 05:19:00+03	7400.00
0893D1	2017-07-21 12:19:00+03	123000.00
0893FC	2017-07-04 15:40:00+03	92900.00
089459	2017-07-21 15:13:00+03	28000.00
08947D	2017-07-21 04:09:00+03	166100.00
089482	2017-08-10 06:53:00+03	246000.00
08958F	2017-07-22 02:18:00+03	88800.00
0895E8	2017-08-08 22:01:00+03	73500.00
08969C	2017-07-30 02:13:00+03	38800.00
0896AE	2017-07-14 00:16:00+03	12700.00
0896CC	2017-07-13 03:06:00+03	118900.00
0896D8	2017-07-15 01:29:00+03	58600.00
0896F4	2017-08-06 04:43:00+03	23600.00
08973E	2017-07-05 23:23:00+03	36200.00
089742	2017-07-15 07:27:00+03	51800.00
08976A	2017-08-03 10:31:00+03	111600.00
0897B4	2017-07-16 20:58:00+03	108000.00
0897D6	2017-07-07 12:34:00+03	43900.00
0897EF	2017-07-26 21:53:00+03	44100.00
089815	2017-07-18 00:12:00+03	27800.00
089832	2017-07-26 17:38:00+03	28000.00
08993D	2017-07-03 02:40:00+03	65500.00
089941	2017-08-09 09:41:00+03	58900.00
089997	2017-07-15 04:08:00+03	135400.00
0899AB	2017-07-12 06:25:00+03	23200.00
0899D7	2017-07-17 22:29:00+03	56000.00
0899E5	2017-08-04 17:26:00+03	40000.00
0899FD	2017-07-13 09:05:00+03	26000.00
089A33	2017-07-14 22:43:00+03	28000.00
089A96	2017-07-12 02:23:00+03	34800.00
089A99	2017-07-23 22:42:00+03	25700.00
089AAD	2017-07-11 01:13:00+03	69600.00
089AD0	2017-07-16 03:51:00+03	38400.00
089B2A	2017-07-22 23:53:00+03	26600.00
089B5C	2017-08-13 07:20:00+03	65900.00
089B7B	2017-08-11 05:51:00+03	41600.00
089B82	2017-07-10 15:33:00+03	92900.00
089B9F	2017-08-04 10:25:00+03	24800.00
089BE1	2017-08-10 05:42:00+03	12400.00
089BF1	2017-07-28 02:10:00+03	38600.00
089C82	2017-07-29 19:12:00+03	39800.00
089CC7	2017-08-12 20:02:00+03	19600.00
089CCC	2017-06-29 09:27:00+03	23200.00
089CDF	2017-07-25 02:26:00+03	44500.00
089D47	2017-08-10 10:51:00+03	137600.00
089D51	2017-08-04 13:35:00+03	56000.00
089D6E	2017-08-06 01:34:00+03	13400.00
089D87	2017-08-05 04:49:00+03	112000.00
089EAF	2017-07-18 11:11:00+03	31600.00
089F0A	2017-08-03 21:41:00+03	36200.00
089FA8	2017-07-01 06:35:00+03	42800.00
089FCD	2017-07-22 11:39:00+03	16400.00
08A03B	2017-07-29 10:50:00+03	26200.00
08A07A	2017-07-18 16:53:00+03	43200.00
08A0CE	2017-07-10 18:29:00+03	12600.00
08A0DB	2017-07-29 08:51:00+03	26600.00
08A0E7	2017-08-10 03:09:00+03	25600.00
08A103	2017-07-07 02:09:00+03	112000.00
08A12B	2017-07-12 01:57:00+03	179200.00
08A15C	2017-08-12 00:53:00+03	76400.00
08A15F	2017-07-20 19:40:00+03	295400.00
08A18A	2017-08-11 23:16:00+03	23600.00
08A208	2017-07-21 15:47:00+03	35200.00
08A21E	2017-07-18 11:45:00+03	316000.00
08A22B	2017-07-23 10:10:00+03	73300.00
08A256	2017-08-03 19:03:00+03	46000.00
08A26A	2017-07-31 15:39:00+03	33600.00
08A2A5	2017-07-07 19:18:00+03	25300.00
08A2D0	2017-07-02 05:33:00+03	28800.00
08A2F6	2017-07-18 05:11:00+03	73400.00
08A376	2017-07-19 17:36:00+03	386300.00
08A378	2017-08-12 18:44:00+03	12000.00
08A3E9	2017-07-21 01:58:00+03	51600.00
08A3EC	2017-07-10 12:33:00+03	47000.00
08A500	2017-07-07 00:03:00+03	27200.00
08A505	2017-07-28 06:02:00+03	55500.00
08A568	2017-08-08 02:51:00+03	273600.00
08A5C7	2017-08-07 16:26:00+03	42700.00
08A5E3	2017-08-07 07:50:00+03	67200.00
08A612	2017-08-05 06:45:00+03	18600.00
08A63B	2017-07-25 17:54:00+03	34400.00
08A66B	2017-07-25 10:13:00+03	14000.00
08A66E	2017-07-09 11:50:00+03	47500.00
08A6D4	2017-08-10 17:36:00+03	274200.00
08A70F	2017-07-14 12:11:00+03	258000.00
08A7CA	2017-07-28 14:06:00+03	135400.00
08A87C	2017-07-26 03:07:00+03	24800.00
08A899	2017-08-15 10:48:00+03	22000.00
08A919	2017-08-04 17:21:00+03	36200.00
08A925	2017-07-24 20:58:00+03	126300.00
08A93D	2017-08-05 17:56:00+03	66600.00
08A968	2017-08-14 06:15:00+03	136200.00
08A98A	2017-07-28 03:59:00+03	57700.00
08A9A7	2017-07-09 06:15:00+03	134800.00
08A9D0	2017-08-10 10:41:00+03	6000.00
08AA28	2017-07-28 10:59:00+03	46000.00
08AA3B	2017-08-09 17:47:00+03	286700.00
08AA44	2017-07-24 02:05:00+03	22100.00
08AACB	2017-07-30 23:56:00+03	28300.00
08AADB	2017-07-04 14:35:00+03	39800.00
08AAEE	2017-07-12 22:19:00+03	46400.00
08AB07	2017-07-03 14:59:00+03	57600.00
08AB54	2017-08-12 05:27:00+03	99700.00
08AC28	2017-07-03 19:47:00+03	43500.00
08AC35	2017-07-27 12:23:00+03	20200.00
08AC94	2017-08-15 11:16:00+03	32800.00
08ACB9	2017-07-15 17:09:00+03	139300.00
08ACD0	2017-08-02 07:03:00+03	23600.00
08AD9C	2017-07-22 13:11:00+03	33300.00
08ADA9	2017-08-03 05:49:00+03	20100.00
08AE2C	2017-07-31 04:47:00+03	56000.00
08AEEB	2017-07-13 19:52:00+03	40300.00
08AF12	2017-08-11 10:51:00+03	124200.00
08AF37	2017-06-28 16:44:00+03	27300.00
08AFC3	2017-07-07 15:57:00+03	39800.00
08AFDD	2017-07-12 07:36:00+03	27400.00
08AFE0	2017-08-03 18:36:00+03	6600.00
08AFE1	2017-08-04 15:17:00+03	28800.00
08B014	2017-08-10 20:18:00+03	22000.00
08B081	2017-07-19 11:51:00+03	35900.00
08B0E7	2017-08-09 01:24:00+03	6300.00
08B128	2017-07-21 02:48:00+03	46800.00
08B12A	2017-08-07 04:06:00+03	296400.00
08B221	2017-07-09 10:41:00+03	224400.00
08B245	2017-07-19 20:29:00+03	31000.00
08B25A	2017-07-21 18:38:00+03	332400.00
08B27A	2017-07-30 14:33:00+03	40400.00
08B2AF	2017-07-13 06:26:00+03	70700.00
08B2D0	2017-07-12 23:14:00+03	58000.00
08B2E4	2017-07-28 03:29:00+03	14800.00
08B351	2017-08-05 14:15:00+03	24200.00
08B372	2017-07-04 15:32:00+03	70100.00
08B412	2017-07-10 14:15:00+03	8200.00
08B478	2017-08-05 20:08:00+03	86400.00
08B4AD	2017-07-21 15:07:00+03	80500.00
08B521	2017-07-26 03:38:00+03	62000.00
08B58A	2017-08-02 10:16:00+03	117600.00
08B58F	2017-07-09 19:56:00+03	398500.00
08B5FC	2017-08-15 01:32:00+03	62600.00
08B63B	2017-07-20 21:57:00+03	56000.00
08B667	2017-07-29 12:28:00+03	24200.00
08B684	2017-08-07 07:12:00+03	190000.00
08B69F	2017-08-08 15:45:00+03	112000.00
08B6AE	2017-07-12 13:48:00+03	28000.00
08B6E6	2017-08-13 21:30:00+03	46000.00
08B70F	2017-07-23 07:10:00+03	43500.00
08B728	2017-08-04 10:00:00+03	139300.00
08B73F	2017-08-13 18:40:00+03	81600.00
08B75C	2017-07-07 15:43:00+03	34600.00
08B772	2017-07-26 18:02:00+03	85200.00
08B79D	2017-08-15 03:44:00+03	26000.00
08B7A4	2017-07-02 21:43:00+03	84000.00
08B7D7	2017-07-06 07:56:00+03	97900.00
08B7E6	2017-07-09 12:34:00+03	67000.00
08B800	2017-07-01 04:01:00+03	135600.00
08B828	2017-07-13 17:26:00+03	99200.00
08B862	2017-07-12 23:13:00+03	75600.00
08B8A7	2017-07-18 04:23:00+03	122400.00
08B8D9	2017-07-10 04:18:00+03	47200.00
08B8DE	2017-08-12 11:25:00+03	28800.00
08B936	2017-07-19 18:45:00+03	67600.00
08B95F	2017-07-19 16:50:00+03	56600.00
08B9C5	2017-07-08 08:37:00+03	46200.00
08BA19	2017-07-15 07:48:00+03	21200.00
08BA49	2017-07-03 07:50:00+03	85700.00
08BA9C	2017-08-12 18:38:00+03	27500.00
08BAB7	2017-08-07 21:17:00+03	23600.00
08BAF4	2017-08-14 13:27:00+03	7300.00
08BB19	2017-08-08 13:47:00+03	7400.00
08BB84	2017-06-29 13:26:00+03	87700.00
08BC6C	2017-08-09 05:15:00+03	57400.00
08BCCB	2017-07-20 21:26:00+03	79900.00
08BCF3	2017-07-18 12:00:00+03	183300.00
08BD1D	2017-08-13 08:58:00+03	114000.00
08BE00	2017-07-10 03:38:00+03	90400.00
08BE07	2017-07-30 05:59:00+03	133200.00
08BE0F	2017-07-01 21:26:00+03	69000.00
08BE45	2017-07-08 19:25:00+03	23200.00
08BEEB	2017-07-02 16:40:00+03	75600.00
08BEF0	2017-07-05 11:40:00+03	39800.00
08BEF2	2017-07-05 20:47:00+03	115900.00
08BF00	2017-07-04 20:05:00+03	86500.00
08BF54	2017-07-14 09:39:00+03	136800.00
08BF57	2017-07-18 09:02:00+03	25900.00
08BFCD	2017-07-25 00:24:00+03	67400.00
08BFD9	2017-07-15 14:29:00+03	81300.00
08C023	2017-06-30 02:57:00+03	14800.00
08C048	2017-08-04 23:17:00+03	58900.00
08C04F	2017-07-29 07:20:00+03	160100.00
08C070	2017-06-30 10:54:00+03	60400.00
08C0D9	2017-08-14 19:22:00+03	213200.00
08C127	2017-08-08 13:35:00+03	290400.00
08C161	2017-07-09 19:32:00+03	32400.00
08C1F4	2017-08-05 14:47:00+03	92900.00
08C1F7	2017-08-11 16:53:00+03	72200.00
08C1F8	2017-08-08 15:05:00+03	47000.00
08C223	2017-08-14 13:01:00+03	23200.00
08C26B	2017-07-09 06:08:00+03	37200.00
08C319	2017-07-20 15:55:00+03	93700.00
08C33F	2017-07-14 10:41:00+03	37500.00
08C366	2017-07-29 10:13:00+03	33300.00
08C373	2017-08-03 15:05:00+03	270800.00
08C374	2017-07-17 14:38:00+03	109300.00
08C3DE	2017-08-13 14:59:00+03	12000.00
08C4EA	2017-07-06 16:09:00+03	125300.00
08C56B	2017-07-19 03:53:00+03	272400.00
08C6BA	2017-07-28 00:38:00+03	36200.00
08C6E5	2017-08-13 21:43:00+03	115100.00
08C770	2017-07-22 08:31:00+03	6300.00
08C779	2017-08-10 06:51:00+03	123900.00
08C821	2017-08-05 10:48:00+03	84000.00
08C827	2017-06-30 03:58:00+03	30200.00
08C83D	2017-08-02 12:49:00+03	140900.00
08C842	2017-07-26 21:32:00+03	18100.00
08C859	2017-07-27 08:54:00+03	113200.00
08C87E	2017-07-10 14:42:00+03	28600.00
08C909	2017-08-01 10:52:00+03	93900.00
08C91E	2017-07-13 10:43:00+03	76200.00
08C9C5	2017-06-30 18:59:00+03	66600.00
08C9F0	2017-08-15 05:08:00+03	46400.00
08CA1E	2017-08-01 12:59:00+03	406700.00
08CA33	2017-07-21 06:38:00+03	128800.00
08CA39	2017-08-15 10:23:00+03	23200.00
08CA3E	2017-07-12 13:52:00+03	6300.00
08CA41	2017-07-24 02:16:00+03	32800.00
08CA5E	2017-07-16 01:27:00+03	99500.00
08CABE	2017-08-07 19:04:00+03	69700.00
08CB35	2017-07-17 20:32:00+03	67200.00
08CBA1	2017-07-14 01:55:00+03	66600.00
08CBC3	2017-07-13 22:01:00+03	234200.00
08CBF1	2017-07-30 23:06:00+03	88100.00
08CD8D	2017-07-28 22:11:00+03	20400.00
08CDE7	2017-08-07 14:17:00+03	94700.00
08CE01	2017-07-03 23:20:00+03	47400.00
08CE1D	2017-08-14 17:04:00+03	272300.00
08CEBA	2017-08-14 20:33:00+03	7800.00
08CEDC	2017-07-26 20:35:00+03	39200.00
08CF15	2017-08-05 16:29:00+03	39100.00
08CF2D	2017-07-31 09:41:00+03	12400.00
08CFB0	2017-07-01 08:40:00+03	29600.00
08D028	2017-07-19 20:16:00+03	56000.00
08D043	2017-07-07 22:17:00+03	63200.00
08D05F	2017-08-03 03:40:00+03	112000.00
08D066	2017-08-05 23:05:00+03	56000.00
08D07A	2017-08-01 05:01:00+03	34000.00
08D093	2017-07-28 14:16:00+03	46000.00
08D130	2017-07-20 05:50:00+03	75600.00
08D18E	2017-07-25 03:56:00+03	29600.00
08D190	2017-08-15 12:46:00+03	67600.00
08D1AF	2017-08-12 06:53:00+03	92800.00
08D1C9	2017-08-11 08:29:00+03	146000.00
08D2C6	2017-07-19 00:50:00+03	44000.00
08D30F	2017-07-27 06:11:00+03	58900.00
08D39E	2017-08-01 03:40:00+03	105300.00
08D3A8	2017-07-16 04:15:00+03	26700.00
08D3DB	2017-07-28 11:08:00+03	47500.00
08D3E1	2017-08-10 22:47:00+03	6300.00
08D453	2017-07-05 18:59:00+03	33200.00
08D495	2017-07-11 08:29:00+03	48800.00
08D550	2017-07-18 06:02:00+03	23200.00
08D554	2017-08-01 04:33:00+03	106400.00
08D5AC	2017-07-26 20:19:00+03	179600.00
08D5DB	2017-07-05 23:40:00+03	67600.00
08D68C	2017-08-01 16:44:00+03	75300.00
08D6EE	2017-07-15 11:28:00+03	23200.00
08D779	2017-07-13 08:08:00+03	277900.00
08D784	2017-07-10 04:02:00+03	22000.00
08D862	2017-08-07 17:42:00+03	27300.00
08D8CF	2017-08-09 16:26:00+03	19200.00
08D9BF	2017-07-13 12:23:00+03	113200.00
08D9F4	2017-08-06 01:24:00+03	168000.00
08DABE	2017-07-17 16:05:00+03	62600.00
08DAE9	2017-08-14 05:59:00+03	28800.00
08DB4C	2017-07-04 08:26:00+03	46300.00
08DB55	2017-07-29 12:12:00+03	16400.00
08DB89	2017-07-21 05:03:00+03	111600.00
08DBAC	2017-08-13 23:53:00+03	28000.00
08DC5C	2017-07-04 22:32:00+03	139100.00
08DC71	2017-07-10 02:21:00+03	56000.00
08DC8A	2017-07-05 17:32:00+03	454500.00
08DC97	2017-07-30 13:40:00+03	105100.00
08DCAD	2017-07-19 17:27:00+03	20900.00
08DD06	2017-08-11 17:23:00+03	61700.00
08DD49	2017-08-13 21:56:00+03	29400.00
08DD58	2017-07-10 15:17:00+03	28800.00
08DD74	2017-07-21 17:57:00+03	48100.00
08DD85	2017-07-13 15:06:00+03	42800.00
08DDDB	2017-08-01 04:34:00+03	83100.00
08DDEC	2017-08-08 13:49:00+03	58800.00
08DE5E	2017-08-04 13:45:00+03	115600.00
08DF51	2017-07-27 04:23:00+03	26000.00
08DF8F	2017-07-07 15:24:00+03	112000.00
08DFF9	2017-07-20 05:48:00+03	58900.00
08DFFB	2017-08-06 21:04:00+03	39500.00
08DFFE	2017-07-06 05:06:00+03	32400.00
08E04D	2017-08-03 11:19:00+03	47400.00
08E12C	2017-07-07 06:56:00+03	12400.00
08E152	2017-08-13 06:15:00+03	47400.00
08E16D	2017-07-14 18:17:00+03	6700.00
08E1A3	2017-08-08 01:31:00+03	66600.00
08E1B5	2017-07-02 09:46:00+03	75800.00
08E219	2017-07-10 15:25:00+03	24700.00
08E269	2017-07-26 18:23:00+03	20200.00
08E26A	2017-07-28 16:56:00+03	88500.00
08E28D	2017-07-24 01:00:00+03	68800.00
08E339	2017-07-07 19:15:00+03	35600.00
08E346	2017-08-02 03:16:00+03	34000.00
08E368	2017-07-28 19:03:00+03	34000.00
08E3A5	2017-08-04 14:30:00+03	99000.00
08E3D8	2017-08-04 07:09:00+03	54400.00
08E3FA	2017-08-12 13:57:00+03	36200.00
08E48C	2017-07-20 17:35:00+03	297600.00
08E51A	2017-07-06 03:33:00+03	173500.00
08E5BF	2017-08-13 02:04:00+03	146400.00
08E5CB	2017-08-02 10:08:00+03	24400.00
08E5D4	2017-07-21 19:17:00+03	36100.00
08E5E3	2017-08-11 20:06:00+03	96300.00
08E5EB	2017-07-18 11:55:00+03	206100.00
08E614	2017-07-28 00:19:00+03	46000.00
08E61E	2017-08-01 22:36:00+03	306500.00
08E637	2017-07-05 23:05:00+03	27200.00
08E642	2017-07-25 08:08:00+03	7400.00
08E643	2017-08-15 10:24:00+03	13200.00
08E6AD	2017-07-18 05:30:00+03	39800.00
08E74B	2017-07-18 07:53:00+03	69500.00
08E74F	2017-07-28 07:22:00+03	145300.00
08E7EE	2017-08-03 13:09:00+03	11800.00
08E803	2017-08-12 20:02:00+03	277600.00
08E812	2017-07-27 05:17:00+03	92900.00
08E85B	2017-07-02 14:56:00+03	170200.00
08E94D	2017-06-29 20:44:00+03	77000.00
08E98D	2017-07-14 04:19:00+03	47400.00
08E9E9	2017-07-07 17:54:00+03	86400.00
08EA55	2017-08-11 07:39:00+03	48800.00
08EA59	2017-07-22 18:13:00+03	61900.00
08EA76	2017-07-12 05:59:00+03	31800.00
08EB0C	2017-07-02 06:31:00+03	16400.00
08EB24	2017-07-31 11:47:00+03	34000.00
08EBA8	2017-07-29 13:56:00+03	24800.00
08EBAD	2017-07-11 23:56:00+03	26700.00
08EC04	2017-08-08 13:24:00+03	153300.00
08EC09	2017-08-09 10:57:00+03	51800.00
08EC87	2017-08-05 05:27:00+03	131800.00
08ECF3	2017-07-20 16:19:00+03	43800.00
08ED13	2017-07-03 17:49:00+03	82200.00
08ED34	2017-07-14 20:01:00+03	55800.00
08ED3E	2017-08-03 18:27:00+03	32900.00
08EE5B	2017-07-13 06:20:00+03	43200.00
08EEC1	2017-07-06 06:38:00+03	62600.00
08EF23	2017-07-05 17:21:00+03	184300.00
08EF3C	2017-08-14 18:10:00+03	180200.00
08EF78	2017-08-14 15:29:00+03	152900.00
08EF95	2017-08-02 09:25:00+03	8200.00
08EFB3	2017-07-01 04:05:00+03	99600.00
08EFD1	2017-07-17 19:37:00+03	56000.00
08F008	2017-08-14 21:25:00+03	31700.00
08F040	2017-07-26 17:57:00+03	29600.00
08F077	2017-07-13 07:07:00+03	515100.00
08F087	2017-07-18 19:19:00+03	101200.00
08F111	2017-07-08 14:48:00+03	150600.00
08F130	2017-08-05 22:27:00+03	265700.00
08F139	2017-08-10 07:51:00+03	198800.00
08F150	2017-07-02 21:30:00+03	275900.00
08F200	2017-07-08 19:25:00+03	28800.00
08F20B	2017-08-04 17:23:00+03	39300.00
08F295	2017-08-07 17:22:00+03	56000.00
08F312	2017-07-12 20:19:00+03	22000.00
08F35D	2017-07-11 00:47:00+03	6900.00
08F363	2017-07-07 13:56:00+03	85600.00
08F38B	2017-07-28 14:22:00+03	62600.00
08F39C	2017-07-12 11:55:00+03	39800.00
08F39E	2017-08-04 13:27:00+03	16000.00
08F425	2017-07-09 23:20:00+03	46000.00
08F450	2017-07-17 18:50:00+03	57400.00
08F456	2017-07-08 07:16:00+03	30000.00
08F497	2017-07-31 10:15:00+03	47800.00
08F4DD	2017-07-31 00:27:00+03	56000.00
08F55A	2017-07-16 07:49:00+03	92900.00
08F567	2017-07-18 14:17:00+03	28800.00
08F56C	2017-08-09 07:31:00+03	77600.00
08F5D7	2017-07-19 10:10:00+03	77200.00
08F5DD	2017-07-10 11:21:00+03	32800.00
08F5E5	2017-07-28 06:04:00+03	89700.00
08F6BC	2017-07-25 12:49:00+03	6700.00
08F6C0	2017-07-24 10:18:00+03	35200.00
08F6F3	2017-08-15 10:37:00+03	11800.00
08F71A	2017-07-11 05:28:00+03	58400.00
08F721	2017-07-21 21:20:00+03	160400.00
08F77C	2017-08-02 11:58:00+03	26000.00
08F7A0	2017-07-21 03:34:00+03	483400.00
08F82C	2017-08-11 02:44:00+03	31600.00
08F831	2017-07-16 19:47:00+03	30400.00
08F83C	2017-07-11 22:44:00+03	26700.00
08F849	2017-07-03 02:41:00+03	12600.00
08F84D	2017-07-12 16:56:00+03	119800.00
08F920	2017-07-15 22:43:00+03	139200.00
08F950	2017-07-29 20:30:00+03	269400.00
08F965	2017-08-15 07:54:00+03	35200.00
08F983	2017-08-10 21:29:00+03	27200.00
08F986	2017-07-15 04:08:00+03	27200.00
08F995	2017-07-19 03:52:00+03	23200.00
08F9AD	2017-06-30 12:08:00+03	135200.00
08FA4F	2017-07-19 01:33:00+03	23200.00
08FA59	2017-07-18 06:13:00+03	139800.00
08FA73	2017-07-03 17:57:00+03	26500.00
08FAF5	2017-08-09 12:09:00+03	46500.00
08FB2E	2017-08-05 22:32:00+03	393800.00
08FB7F	2017-08-13 04:36:00+03	168000.00
08FB81	2017-07-12 14:57:00+03	94300.00
08FBCB	2017-08-02 03:10:00+03	71100.00
08FC1D	2017-07-10 12:48:00+03	114400.00
08FC45	2017-07-05 22:24:00+03	123600.00
08FC60	2017-07-27 03:41:00+03	48500.00
08FC63	2017-08-01 12:47:00+03	6700.00
08FC70	2017-08-06 15:49:00+03	98000.00
08FC95	2017-07-06 13:39:00+03	25100.00
08FCEA	2017-07-09 15:58:00+03	111700.00
08FD92	2017-07-27 18:58:00+03	160000.00
08FDB6	2017-08-02 01:56:00+03	19600.00
08FE19	2017-07-24 10:30:00+03	135600.00
08FE2E	2017-07-18 16:14:00+03	39500.00
08FE40	2017-07-30 03:25:00+03	270700.00
08FE44	2017-07-23 16:48:00+03	28000.00
08FE47	2017-08-03 09:24:00+03	73500.00
08FE69	2017-08-02 04:32:00+03	35800.00
08FECB	2017-07-21 02:25:00+03	135200.00
08FECF	2017-07-03 23:40:00+03	129200.00
08FF03	2017-07-10 18:37:00+03	193700.00
08FF10	2017-08-02 19:54:00+03	238300.00
08FF12	2017-07-31 23:22:00+03	57600.00
08FF58	2017-08-03 22:24:00+03	40800.00
08FF9D	2017-08-13 04:15:00+03	30400.00
09004E	2017-07-20 02:19:00+03	125200.00
090065	2017-07-17 07:08:00+03	32800.00
090086	2017-07-24 02:13:00+03	146100.00
0900B0	2017-07-30 14:46:00+03	100200.00
090117	2017-07-06 20:39:00+03	28000.00
090124	2017-08-14 22:53:00+03	630400.00
090194	2017-07-18 23:40:00+03	27200.00
0901B5	2017-07-03 18:34:00+03	67400.00
09021B	2017-07-17 18:59:00+03	80500.00
090263	2017-08-01 23:15:00+03	87100.00
090279	2017-06-30 01:37:00+03	56100.00
09027C	2017-08-02 13:22:00+03	95200.00
09028B	2017-07-06 17:09:00+03	23600.00
0902BD	2017-06-25 16:27:00+03	128800.00
0902EB	2017-08-14 13:37:00+03	23200.00
0903C9	2017-08-15 12:47:00+03	49600.00
0903CC	2017-07-28 03:09:00+03	62800.00
090457	2017-08-10 14:17:00+03	250500.00
090458	2017-07-26 18:08:00+03	64500.00
09050F	2017-07-15 16:18:00+03	133200.00
09052F	2017-07-26 19:35:00+03	62600.00
090537	2017-07-29 01:26:00+03	134800.00
090555	2017-07-27 08:35:00+03	31600.00
090782	2017-07-01 21:28:00+03	46800.00
090812	2017-07-31 12:40:00+03	124200.00
09086F	2017-08-07 16:08:00+03	111600.00
0908A0	2017-08-11 10:06:00+03	14400.00
0908A4	2017-07-15 02:25:00+03	6000.00
09091A	2017-07-19 00:58:00+03	101200.00
090930	2017-08-06 13:23:00+03	123000.00
090937	2017-07-05 01:54:00+03	65900.00
090960	2017-07-03 18:30:00+03	29300.00
090962	2017-07-31 20:14:00+03	139400.00
090968	2017-08-07 17:15:00+03	24400.00
0909A0	2017-07-18 02:10:00+03	31000.00
0909A5	2017-07-04 23:02:00+03	137600.00
0909CB	2017-07-28 07:52:00+03	37900.00
090A04	2017-07-29 13:08:00+03	46400.00
090A4F	2017-07-17 11:09:00+03	22000.00
090ABA	2017-07-08 00:15:00+03	22400.00
090B5C	2017-07-10 02:51:00+03	188700.00
090B93	2017-07-21 12:55:00+03	171200.00
090BCD	2017-06-30 21:07:00+03	25100.00
090C22	2017-07-22 01:45:00+03	153600.00
090C2E	2017-07-21 23:16:00+03	23200.00
090C7B	2017-08-12 06:18:00+03	13400.00
090C8F	2017-08-12 02:04:00+03	45100.00
090C91	2017-08-08 03:03:00+03	15700.00
090D07	2017-08-11 09:47:00+03	44700.00
090D46	2017-08-13 05:40:00+03	44800.00
090D51	2017-08-06 20:31:00+03	64800.00
090D99	2017-07-11 06:48:00+03	130300.00
090DFF	2017-08-12 19:14:00+03	26000.00
090E0D	2017-08-11 02:00:00+03	98400.00
090E18	2017-07-05 11:12:00+03	22000.00
090E54	2017-07-12 12:55:00+03	23200.00
090E5F	2017-08-14 00:59:00+03	99800.00
090F16	2017-08-01 10:05:00+03	91500.00
090F3B	2017-08-05 17:54:00+03	51900.00
090F57	2017-08-05 20:48:00+03	37200.00
090FB7	2017-08-05 03:06:00+03	75700.00
090FBB	2017-07-23 04:44:00+03	23200.00
091014	2017-07-05 21:29:00+03	54600.00
09104E	2017-08-05 17:54:00+03	141300.00
09107F	2017-08-04 13:56:00+03	50600.00
09109C	2017-08-08 09:06:00+03	23200.00
09110B	2017-07-09 01:10:00+03	272400.00
091143	2017-07-08 19:12:00+03	64600.00
091155	2017-07-08 14:49:00+03	99200.00
0911BF	2017-07-14 19:28:00+03	111600.00
0911ED	2017-08-15 08:09:00+03	81700.00
09121A	2017-07-04 18:28:00+03	47100.00
09121B	2017-07-17 18:30:00+03	54800.00
091229	2017-08-04 14:21:00+03	34000.00
09122D	2017-07-24 14:15:00+03	73600.00
09124F	2017-08-14 13:04:00+03	94300.00
0912A2	2017-07-31 11:58:00+03	102100.00
091383	2017-07-23 14:29:00+03	85700.00
0913C3	2017-07-11 18:10:00+03	39800.00
0913FE	2017-06-29 20:48:00+03	19200.00
091448	2017-08-13 09:19:00+03	66000.00
091456	2017-07-04 03:20:00+03	28800.00
091479	2017-08-12 15:14:00+03	136200.00
0914C9	2017-08-12 09:45:00+03	89600.00
0914CA	2017-08-13 21:25:00+03	13400.00
0914D9	2017-07-17 09:55:00+03	21400.00
0914DE	2017-08-01 05:21:00+03	81300.00
091549	2017-08-11 21:45:00+03	100000.00
09157D	2017-07-17 21:58:00+03	39700.00
09159F	2017-08-03 17:56:00+03	67400.00
0915F6	2017-07-27 08:22:00+03	20200.00
09168C	2017-07-16 15:02:00+03	53500.00
0916D8	2017-07-18 11:04:00+03	40800.00
0916E5	2017-08-04 05:33:00+03	36700.00
09172C	2017-08-03 10:20:00+03	88900.00
091791	2017-07-26 06:41:00+03	25600.00
0917C2	2017-08-01 23:59:00+03	52800.00
09184E	2017-08-06 22:37:00+03	189300.00
09187C	2017-07-30 07:49:00+03	59200.00
0918EB	2017-08-01 02:33:00+03	111700.00
091939	2017-07-16 05:51:00+03	48200.00
09198C	2017-07-12 18:52:00+03	46300.00
0919BA	2017-07-21 04:51:00+03	46000.00
091A41	2017-07-15 16:08:00+03	36000.00
091B09	2017-07-13 20:21:00+03	14000.00
091B30	2017-08-07 05:56:00+03	48800.00
091B5B	2017-08-10 19:54:00+03	28000.00
091BA3	2017-08-03 16:17:00+03	89700.00
091BDE	2017-07-24 16:07:00+03	47100.00
091C1F	2017-08-05 06:13:00+03	61100.00
091C35	2017-07-04 01:30:00+03	204700.00
091C4C	2017-08-03 21:29:00+03	125200.00
091C70	2017-08-15 08:59:00+03	23200.00
091C76	2017-07-13 03:05:00+03	13400.00
091CCF	2017-08-08 23:39:00+03	172100.00
091D47	2017-07-23 22:09:00+03	117200.00
091D48	2017-07-10 14:21:00+03	100600.00
091D68	2017-08-09 13:49:00+03	27300.00
091D80	2017-07-20 23:07:00+03	67000.00
091D84	2017-07-03 22:42:00+03	97700.00
091DA7	2017-07-31 11:36:00+03	108600.00
091DFD	2017-07-19 20:51:00+03	137400.00
091E30	2017-07-30 00:47:00+03	23400.00
091EE4	2017-07-15 01:51:00+03	24700.00
091EE7	2017-08-07 13:44:00+03	20000.00
091F11	2017-07-30 17:14:00+03	19600.00
091F90	2017-08-09 10:41:00+03	54000.00
091FB8	2017-07-05 21:12:00+03	36000.00
092056	2017-07-25 16:31:00+03	64800.00
092081	2017-07-13 19:50:00+03	132800.00
0920A8	2017-07-08 23:39:00+03	30800.00
0920D5	2017-08-01 19:00:00+03	40600.00
0920EF	2017-08-05 12:13:00+03	85000.00
09212E	2017-07-14 09:14:00+03	36200.00
09218A	2017-08-15 16:50:00+03	54800.00
0921A0	2017-07-15 19:06:00+03	102200.00
0921DC	2017-08-02 09:54:00+03	55600.00
092279	2017-08-03 01:30:00+03	57600.00
09228D	2017-07-20 07:21:00+03	102200.00
0922B5	2017-07-25 02:26:00+03	51600.00
0922ED	2017-07-31 06:28:00+03	21600.00
092325	2017-07-08 17:32:00+03	116400.00
092348	2017-07-12 13:31:00+03	65900.00
092378	2017-07-13 19:10:00+03	46000.00
092386	2017-08-03 07:17:00+03	65100.00
0923B1	2017-07-28 20:49:00+03	449500.00
0923FD	2017-07-14 17:04:00+03	67400.00
092437	2017-07-08 19:33:00+03	57500.00
0924C7	2017-07-22 09:31:00+03	58200.00
0925B3	2017-07-27 03:12:00+03	47100.00
092611	2017-07-11 13:05:00+03	85400.00
092620	2017-07-16 17:18:00+03	16400.00
09262A	2017-07-07 17:31:00+03	38500.00
09263B	2017-07-26 16:56:00+03	258400.00
0926F9	2017-06-30 10:28:00+03	37700.00
0927F9	2017-07-21 14:03:00+03	112600.00
092802	2017-06-29 14:40:00+03	47400.00
092828	2017-06-30 10:46:00+03	29600.00
09287C	2017-07-11 20:23:00+03	36800.00
0928D1	2017-07-27 04:50:00+03	77600.00
0928F0	2017-06-30 13:49:00+03	117600.00
09293E	2017-08-05 08:00:00+03	92700.00
092950	2017-08-15 15:51:00+03	13200.00
09299D	2017-07-25 08:36:00+03	3800.00
092A95	2017-08-04 13:55:00+03	37600.00
092AB9	2017-07-05 00:26:00+03	103500.00
092AD4	2017-07-13 02:46:00+03	95200.00
092B74	2017-07-17 04:36:00+03	56000.00
092C39	2017-07-20 07:32:00+03	13700.00
092C9C	2017-07-23 15:35:00+03	64700.00
092CEB	2017-08-07 04:32:00+03	23400.00
092CF4	2017-08-03 21:10:00+03	14000.00
092CFB	2017-07-21 13:22:00+03	46200.00
092D6C	2017-07-25 21:51:00+03	101500.00
092D74	2017-07-22 06:38:00+03	55800.00
092D78	2017-08-15 00:55:00+03	58100.00
092DBC	2017-07-07 12:00:00+03	63200.00
092DC2	2017-07-05 18:47:00+03	20200.00
092E38	2017-07-27 13:41:00+03	57500.00
092E68	2017-08-02 14:26:00+03	169600.00
092E79	2017-07-26 14:08:00+03	117600.00
092EA7	2017-07-23 12:53:00+03	29600.00
092F04	2017-07-14 18:51:00+03	46700.00
092F50	2017-08-03 00:18:00+03	128600.00
092FB2	2017-08-12 19:19:00+03	85000.00
09301C	2017-07-31 15:53:00+03	67600.00
093032	2017-08-12 12:38:00+03	48800.00
093106	2017-08-10 20:42:00+03	284400.00
093153	2017-07-14 19:12:00+03	41300.00
09315D	2017-08-04 23:55:00+03	146300.00
09319D	2017-08-14 13:28:00+03	51900.00
0931D7	2017-07-13 11:19:00+03	28000.00
0931E7	2017-08-01 09:39:00+03	136800.00
0931FB	2017-07-05 23:18:00+03	74800.00
093209	2017-07-18 06:58:00+03	40000.00
093235	2017-07-26 08:48:00+03	65500.00
09327F	2017-07-13 07:43:00+03	91500.00
093377	2017-07-24 09:39:00+03	31600.00
0933AD	2017-08-15 05:05:00+03	75600.00
0933F6	2017-07-23 16:03:00+03	132800.00
093472	2017-07-01 02:31:00+03	6800.00
0934FC	2017-06-29 03:32:00+03	112100.00
093524	2017-07-21 16:11:00+03	28800.00
09355F	2017-07-25 12:09:00+03	27200.00
09357B	2017-07-24 11:38:00+03	75300.00
0935E4	2017-08-14 12:24:00+03	21500.00
093630	2017-07-16 21:34:00+03	179300.00
09365B	2017-08-14 09:00:00+03	36700.00
093697	2017-07-29 02:27:00+03	62600.00
0936A3	2017-08-10 16:35:00+03	72200.00
0936D5	2017-08-01 05:24:00+03	30700.00
09377B	2017-07-25 07:01:00+03	8000.00
093813	2017-07-04 03:34:00+03	58900.00
09384A	2017-08-02 05:29:00+03	28000.00
093853	2017-07-22 19:25:00+03	111600.00
0938EC	2017-07-11 13:52:00+03	29400.00
09390A	2017-08-06 02:24:00+03	74400.00
09395D	2017-08-02 13:01:00+03	23200.00
0939CB	2017-08-10 22:59:00+03	53200.00
093A09	2017-08-15 05:52:00+03	111800.00
093A3A	2017-08-03 15:35:00+03	130400.00
093A4A	2017-07-13 09:52:00+03	14800.00
093A5C	2017-08-10 16:01:00+03	16400.00
093A82	2017-07-19 11:41:00+03	46300.00
093AAE	2017-08-08 05:55:00+03	78600.00
093ABA	2017-07-10 10:32:00+03	18100.00
093ABE	2017-07-09 01:38:00+03	36400.00
093ADF	2017-07-16 16:38:00+03	68900.00
093B85	2017-07-10 03:07:00+03	55800.00
093B9C	2017-07-12 05:39:00+03	36400.00
093BAC	2017-08-04 21:23:00+03	52000.00
093BF3	2017-07-15 21:39:00+03	41400.00
093C72	2017-07-14 05:18:00+03	94000.00
093C7E	2017-07-30 13:02:00+03	32800.00
093CB7	2017-07-11 14:57:00+03	60400.00
093CC6	2017-07-10 07:33:00+03	178800.00
093CD2	2017-08-06 02:30:00+03	38600.00
093D21	2017-07-31 01:26:00+03	44800.00
093D41	2017-06-30 15:01:00+03	32800.00
093D45	2017-07-18 03:32:00+03	136100.00
093D52	2017-07-22 22:26:00+03	46800.00
093DE0	2017-07-17 12:41:00+03	49100.00
093DF8	2017-08-11 17:03:00+03	92600.00
093E50	2017-08-01 03:45:00+03	42700.00
093EAF	2017-07-20 12:53:00+03	136200.00
093EE1	2017-08-07 06:58:00+03	48500.00
093EE5	2017-07-13 10:02:00+03	65500.00
093F77	2017-08-11 05:48:00+03	102100.00
093FC1	2017-07-11 05:50:00+03	81700.00
093FD3	2017-07-23 10:30:00+03	34700.00
093FF8	2017-08-03 06:02:00+03	48800.00
09401F	2017-08-01 03:52:00+03	13700.00
0940D2	2017-07-03 09:39:00+03	84100.00
0940FD	2017-07-13 19:29:00+03	182900.00
094131	2017-07-12 08:00:00+03	32700.00
094156	2017-08-01 04:44:00+03	51800.00
09415F	2017-07-31 17:32:00+03	34400.00
0941CE	2017-07-31 20:55:00+03	11800.00
09420F	2017-08-07 08:52:00+03	174400.00
09421C	2017-08-15 10:19:00+03	39300.00
094281	2017-07-18 20:59:00+03	57700.00
0942BA	2017-08-10 06:48:00+03	54500.00
0942C4	2017-07-04 05:55:00+03	31400.00
0942C6	2017-07-10 10:15:00+03	66400.00
09430B	2017-07-02 13:05:00+03	26200.00
09432E	2017-06-30 02:12:00+03	111600.00
094331	2017-07-09 22:44:00+03	91900.00
0943B2	2017-07-18 08:05:00+03	69100.00
0943E0	2017-07-21 23:53:00+03	122000.00
094409	2017-08-14 00:42:00+03	67300.00
0944C6	2017-07-25 09:55:00+03	90400.00
094552	2017-08-11 16:48:00+03	77200.00
0945F7	2017-07-17 16:13:00+03	99200.00
0945FB	2017-06-28 22:39:00+03	152900.00
0945FE	2017-07-27 16:09:00+03	44000.00
09460C	2017-07-19 07:36:00+03	52000.00
09461E	2017-08-02 15:17:00+03	112000.00
094622	2017-08-01 08:43:00+03	46000.00
09466C	2017-07-28 10:02:00+03	36200.00
0946A3	2017-07-21 08:50:00+03	15900.00
094778	2017-08-10 21:28:00+03	27800.00
094793	2017-07-14 07:26:00+03	232600.00
0947A8	2017-08-15 14:27:00+03	7400.00
0947BC	2017-07-11 11:36:00+03	92400.00
09484A	2017-07-13 15:47:00+03	48500.00
09487B	2017-07-05 09:42:00+03	14800.00
0948AA	2017-08-01 01:07:00+03	229900.00
0948AB	2017-08-12 22:35:00+03	99700.00
0948AD	2017-06-30 17:41:00+03	60400.00
0948BE	2017-07-05 17:17:00+03	69500.00
0948D6	2017-07-23 03:17:00+03	54800.00
0948D9	2017-07-04 21:16:00+03	63800.00
094940	2017-08-01 15:56:00+03	111600.00
09497A	2017-08-02 15:32:00+03	16800.00
09499E	2017-07-01 08:28:00+03	24200.00
0949BD	2017-08-15 06:35:00+03	59700.00
094A22	2017-07-21 00:20:00+03	46200.00
094A41	2017-08-14 10:22:00+03	28800.00
094A69	2017-08-07 17:30:00+03	40000.00
094A84	2017-07-24 07:00:00+03	27200.00
094A8B	2017-08-08 00:05:00+03	13600.00
094AF9	2017-08-12 11:23:00+03	248100.00
094B2B	2017-07-07 05:13:00+03	27300.00
094B9A	2017-07-11 17:37:00+03	104600.00
094C01	2017-08-09 23:04:00+03	147900.00
094D49	2017-07-23 23:45:00+03	54800.00
094D6D	2017-07-08 07:38:00+03	83000.00
094D72	2017-07-06 09:55:00+03	13200.00
094D80	2017-07-20 09:46:00+03	57500.00
094D86	2017-07-26 17:46:00+03	15400.00
094DBC	2017-07-03 20:19:00+03	30200.00
094DC6	2017-08-12 00:34:00+03	63800.00
094DFB	2017-07-26 21:16:00+03	31600.00
094E08	2017-07-29 07:43:00+03	67200.00
094E7B	2017-07-16 12:11:00+03	31100.00
094E7E	2017-07-06 07:45:00+03	59000.00
094E8D	2017-08-10 05:11:00+03	67000.00
094EAE	2017-07-05 13:32:00+03	24300.00
094EF7	2017-07-03 08:59:00+03	31700.00
094F14	2017-07-15 02:44:00+03	112000.00
094F17	2017-08-09 00:33:00+03	139400.00
094F7B	2017-08-06 14:26:00+03	24400.00
094FB5	2017-07-16 23:58:00+03	30200.00
095039	2017-07-19 18:31:00+03	25600.00
0950AC	2017-07-30 18:10:00+03	16400.00
0950E4	2017-07-30 14:24:00+03	33300.00
0950FF	2017-07-23 14:09:00+03	231400.00
095130	2017-08-08 13:05:00+03	91500.00
095178	2017-07-19 19:11:00+03	20200.00
0951B7	2017-08-09 04:38:00+03	99300.00
0951CC	2017-08-07 13:56:00+03	46300.00
095221	2017-07-31 15:10:00+03	29600.00
09522B	2017-08-03 14:18:00+03	127900.00
09524B	2017-08-03 23:23:00+03	46000.00
095262	2017-08-12 06:11:00+03	112000.00
0952AF	2017-08-11 09:06:00+03	52000.00
095321	2017-08-12 09:40:00+03	7200.00
09532D	2017-07-07 09:20:00+03	290500.00
095371	2017-07-09 19:37:00+03	69100.00
0953B9	2017-08-13 08:15:00+03	37700.00
0953C6	2017-07-19 14:46:00+03	31400.00
0953D0	2017-07-07 00:28:00+03	78600.00
0953E0	2017-07-13 06:50:00+03	60400.00
095411	2017-08-04 06:15:00+03	55900.00
09549C	2017-07-02 16:29:00+03	13400.00
0954A2	2017-08-14 11:08:00+03	48800.00
0954AC	2017-08-04 00:53:00+03	40100.00
0954C3	2017-08-15 10:46:00+03	31200.00
095520	2017-07-23 10:59:00+03	6200.00
095559	2017-07-31 00:05:00+03	26000.00
09555E	2017-08-05 14:35:00+03	48800.00
0955A6	2017-08-02 17:04:00+03	21400.00
0955CA	2017-07-09 06:21:00+03	34000.00
0955E2	2017-08-02 07:18:00+03	38200.00
09563C	2017-07-19 17:05:00+03	19800.00
09563D	2017-07-11 16:46:00+03	21800.00
095664	2017-07-23 01:48:00+03	6800.00
095725	2017-07-11 11:14:00+03	46000.00
095794	2017-07-02 09:28:00+03	91200.00
0957BA	2017-07-15 04:20:00+03	101500.00
095811	2017-07-31 07:01:00+03	46400.00
095819	2017-07-28 21:07:00+03	87200.00
09581C	2017-07-21 06:50:00+03	43600.00
09582C	2017-07-24 11:50:00+03	23500.00
0958B1	2017-08-11 10:15:00+03	45200.00
0958BA	2017-06-27 22:46:00+03	113200.00
0958C6	2017-07-12 09:31:00+03	28000.00
0959E5	2017-08-04 13:54:00+03	34800.00
0959EC	2017-07-17 02:41:00+03	28000.00
095A1B	2017-07-09 00:20:00+03	51800.00
095A49	2017-07-07 12:53:00+03	279800.00
095A6A	2017-07-01 07:03:00+03	56000.00
095AB7	2017-08-07 02:21:00+03	37900.00
095ABD	2017-08-13 03:23:00+03	15000.00
095ACC	2017-07-09 01:49:00+03	26800.00
095B0D	2017-07-07 01:26:00+03	17800.00
095B46	2017-08-10 12:42:00+03	10800.00
095B7B	2017-07-28 10:03:00+03	40000.00
095BC4	2017-08-14 19:24:00+03	112000.00
095BE4	2017-07-05 03:03:00+03	28800.00
095D4D	2017-07-15 02:52:00+03	165100.00
095DE3	2017-07-21 01:10:00+03	48800.00
095DF2	2017-07-19 00:34:00+03	12600.00
095E0B	2017-07-25 17:23:00+03	46700.00
095E30	2017-07-10 10:24:00+03	114300.00
095E4D	2017-07-04 05:24:00+03	190200.00
095E5D	2017-07-07 21:39:00+03	134400.00
095E67	2017-07-01 03:27:00+03	38200.00
095E7D	2017-08-12 23:43:00+03	29400.00
095EDA	2017-07-15 10:01:00+03	8400.00
095EE7	2017-07-11 09:42:00+03	28800.00
095EF8	2017-07-02 00:44:00+03	15000.00
095EFE	2017-08-13 19:14:00+03	38800.00
095F1B	2017-07-10 21:00:00+03	27600.00
095F96	2017-07-20 14:39:00+03	236500.00
095F99	2017-07-15 01:11:00+03	67600.00
095FEC	2017-08-13 03:15:00+03	246000.00
096003	2017-07-11 16:07:00+03	39000.00
096040	2017-07-12 09:39:00+03	133200.00
0960F4	2017-07-29 16:00:00+03	540100.00
0960F8	2017-07-20 08:19:00+03	40600.00
09615F	2017-07-05 03:18:00+03	57500.00
0961A1	2017-07-15 15:39:00+03	27200.00
0961A2	2017-07-25 05:40:00+03	47400.00
096316	2017-08-05 12:35:00+03	25000.00
09631B	2017-07-05 07:14:00+03	39200.00
096325	2017-08-14 02:22:00+03	116400.00
096334	2017-08-10 08:53:00+03	196000.00
09633E	2017-08-12 02:40:00+03	41600.00
09639F	2017-08-06 03:20:00+03	55800.00
096432	2017-08-06 20:43:00+03	178300.00
096489	2017-07-29 02:00:00+03	31300.00
0964AC	2017-08-15 15:00:00+03	103300.00
0964CB	2017-07-25 01:43:00+03	170500.00
09653E	2017-06-24 07:16:00+03	67900.00
09658E	2017-07-24 17:57:00+03	94000.00
0965A0	2017-07-20 00:51:00+03	61100.00
0965CD	2017-07-14 12:05:00+03	108500.00
096726	2017-08-14 14:59:00+03	106200.00
096761	2017-07-21 04:33:00+03	87900.00
0967AF	2017-08-10 05:30:00+03	342800.00
0967DB	2017-08-12 04:52:00+03	25600.00
0967E3	2017-08-03 00:56:00+03	96200.00
096805	2017-07-13 05:31:00+03	443000.00
09684A	2017-08-01 12:24:00+03	123000.00
096880	2017-07-25 10:48:00+03	68800.00
0968A9	2017-07-12 15:24:00+03	103000.00
0968B8	2017-08-03 20:20:00+03	6300.00
0968CD	2017-07-20 19:31:00+03	65100.00
096955	2017-06-30 10:11:00+03	51300.00
0969AD	2017-08-14 04:38:00+03	23200.00
096A10	2017-07-20 02:12:00+03	111600.00
096A4F	2017-07-10 23:05:00+03	61200.00
096AC3	2017-08-08 14:46:00+03	173500.00
096AF2	2017-07-12 09:09:00+03	15100.00
096B36	2017-08-11 20:52:00+03	25000.00
096B54	2017-08-12 22:19:00+03	14400.00
096B62	2017-08-05 03:45:00+03	141700.00
096B68	2017-06-30 19:58:00+03	24400.00
096B9C	2017-07-16 08:26:00+03	66000.00
096C4D	2017-08-13 22:41:00+03	266400.00
096C5B	2017-08-07 06:47:00+03	31200.00
096C81	2017-07-27 11:32:00+03	21400.00
096D17	2017-07-26 15:08:00+03	46200.00
096DF3	2017-08-14 20:29:00+03	62700.00
096DFB	2017-07-18 20:09:00+03	410200.00
096E91	2017-07-27 10:01:00+03	265800.00
096E92	2017-07-10 06:11:00+03	114300.00
096EA5	2017-07-07 00:36:00+03	24400.00
096EBA	2017-08-01 13:45:00+03	81800.00
096EF7	2017-07-02 15:41:00+03	86100.00
096F22	2017-07-17 17:02:00+03	243600.00
096F35	2017-07-23 11:13:00+03	177200.00
096F4F	2017-08-09 18:25:00+03	291000.00
096F78	2017-08-07 00:14:00+03	47100.00
097015	2017-07-03 03:06:00+03	6200.00
097078	2017-08-06 21:11:00+03	36900.00
0970F5	2017-07-08 19:36:00+03	38200.00
0971A7	2017-07-23 00:05:00+03	92700.00
0971B4	2017-07-15 19:58:00+03	3400.00
097220	2017-07-26 07:41:00+03	32800.00
097379	2017-07-10 07:53:00+03	317400.00
09737D	2017-07-04 07:57:00+03	51500.00
0973E2	2017-07-11 11:43:00+03	26000.00
097544	2017-08-02 13:22:00+03	155600.00
097591	2017-08-07 05:56:00+03	6000.00
09759A	2017-07-07 05:27:00+03	124300.00
097647	2017-07-10 18:22:00+03	40000.00
09764E	2017-07-19 19:32:00+03	24300.00
097680	2017-07-07 13:37:00+03	56000.00
0976AD	2017-07-06 07:59:00+03	67600.00
0976B0	2017-07-13 11:09:00+03	125200.00
0976EE	2017-08-07 03:16:00+03	38400.00
09773D	2017-07-08 13:30:00+03	39300.00
097741	2017-08-13 02:46:00+03	58200.00
097750	2017-07-05 21:47:00+03	71200.00
097761	2017-08-05 05:21:00+03	133100.00
097764	2017-07-28 06:03:00+03	12600.00
09776E	2017-07-24 10:30:00+03	92800.00
0977A7	2017-07-31 06:01:00+03	10800.00
0977E9	2017-08-12 11:17:00+03	56900.00
0977F0	2017-08-14 08:59:00+03	24400.00
097807	2017-07-28 12:38:00+03	81300.00
097830	2017-07-03 20:34:00+03	58800.00
097848	2017-07-19 09:12:00+03	66600.00
09788D	2017-08-02 13:58:00+03	31100.00
0978A4	2017-08-08 23:15:00+03	516800.00
0978AD	2017-07-05 08:58:00+03	128000.00
0978B4	2017-07-24 06:07:00+03	47400.00
0978D8	2017-07-31 13:32:00+03	20500.00
09790C	2017-07-30 07:17:00+03	43800.00
097940	2017-07-08 11:35:00+03	27200.00
097974	2017-07-17 19:41:00+03	65000.00
0979E5	2017-07-02 15:49:00+03	6300.00
097A4D	2017-07-30 08:44:00+03	107700.00
097A63	2017-07-21 14:19:00+03	40600.00
097A9B	2017-07-27 22:54:00+03	20000.00
097AE3	2017-08-12 17:20:00+03	70500.00
097BAB	2017-06-28 22:25:00+03	65900.00
097C7D	2017-07-19 20:13:00+03	44800.00
097D34	2017-07-17 14:53:00+03	28000.00
097D98	2017-07-20 00:12:00+03	36200.00
097DF7	2017-07-17 21:23:00+03	62600.00
097E19	2017-07-15 03:50:00+03	117200.00
097E42	2017-06-30 17:46:00+03	55800.00
097E61	2017-08-08 01:27:00+03	75600.00
097E63	2017-07-23 11:12:00+03	56600.00
097EF7	2017-08-13 17:55:00+03	265700.00
097F02	2017-07-15 00:11:00+03	82600.00
097F18	2017-07-25 09:01:00+03	9200.00
097F23	2017-07-30 07:33:00+03	675600.00
097F50	2017-07-03 07:29:00+03	26000.00
097F63	2017-07-20 01:49:00+03	131100.00
097FB2	2017-08-08 19:49:00+03	61500.00
098092	2017-07-17 13:39:00+03	10800.00
0980D9	2017-08-02 23:14:00+03	131100.00
0980E4	2017-07-26 07:51:00+03	46400.00
0980FF	2017-07-04 02:23:00+03	12600.00
098130	2017-07-16 07:12:00+03	67600.00
0981AB	2017-07-11 22:48:00+03	161900.00
0981D5	2017-08-07 19:37:00+03	6700.00
0981D9	2017-08-09 08:32:00+03	47700.00
0981DD	2017-07-01 00:50:00+03	98400.00
0981F3	2017-08-03 21:55:00+03	66000.00
098238	2017-07-17 21:23:00+03	248300.00
09825E	2017-08-11 01:16:00+03	56600.00
0982B4	2017-07-06 13:03:00+03	62600.00
0982C5	2017-07-21 15:42:00+03	25000.00
098308	2017-08-14 14:37:00+03	8900.00
0983E0	2017-07-25 15:46:00+03	133200.00
098409	2017-08-05 15:49:00+03	13600.00
098451	2017-08-04 02:22:00+03	120800.00
0984CD	2017-08-08 13:04:00+03	24700.00
0984D7	2017-07-03 10:27:00+03	6300.00
0984FA	2017-07-05 01:04:00+03	12000.00
098531	2017-07-18 22:47:00+03	96300.00
09856A	2017-07-19 10:14:00+03	43700.00
09864B	2017-07-19 10:42:00+03	185600.00
09864E	2017-07-10 00:31:00+03	42000.00
09865C	2017-07-22 19:30:00+03	45100.00
098684	2017-08-05 04:44:00+03	66800.00
09869F	2017-07-21 23:21:00+03	40800.00
098729	2017-08-10 22:03:00+03	59200.00
0987A9	2017-07-24 15:02:00+03	57800.00
0987C0	2017-07-14 18:22:00+03	23200.00
09884F	2017-07-08 13:47:00+03	65900.00
0988A1	2017-07-14 11:34:00+03	57600.00
0988E3	2017-07-28 09:17:00+03	23200.00
09890A	2017-07-08 16:50:00+03	6600.00
098958	2017-07-22 06:33:00+03	55800.00
0989BF	2017-07-19 02:22:00+03	265600.00
098A2D	2017-07-08 17:52:00+03	94300.00
098A2E	2017-07-06 15:39:00+03	26000.00
098A74	2017-07-12 03:02:00+03	158500.00
098A8A	2017-07-30 00:10:00+03	124100.00
098ACB	2017-08-10 22:47:00+03	113800.00
098AD8	2017-07-14 18:44:00+03	34700.00
098B10	2017-08-03 12:13:00+03	65600.00
098BA5	2017-07-12 11:00:00+03	44100.00
098BB0	2017-07-25 02:37:00+03	61400.00
098BD0	2017-07-05 11:07:00+03	270800.00
098BD7	2017-07-18 00:29:00+03	28000.00
098C97	2017-08-06 19:54:00+03	23200.00
098CA8	2017-08-08 14:12:00+03	664200.00
098D7B	2017-07-16 12:29:00+03	58600.00
098D85	2017-07-03 23:52:00+03	105100.00
098DDE	2017-07-11 18:27:00+03	59800.00
098DF3	2017-08-05 09:05:00+03	67200.00
098E00	2017-07-28 20:47:00+03	52400.00
098E02	2017-07-16 03:11:00+03	14400.00
098EA3	2017-08-07 19:07:00+03	61800.00
098EF0	2017-07-08 01:47:00+03	67600.00
098F33	2017-07-03 08:22:00+03	171000.00
098F6C	2017-07-27 23:06:00+03	41600.00
098F88	2017-08-12 10:47:00+03	39200.00
098FCD	2017-08-15 16:45:00+03	97400.00
098FF9	2017-07-20 12:17:00+03	52000.00
099040	2017-07-18 00:01:00+03	136100.00
099077	2017-08-08 06:51:00+03	40100.00
099231	2017-08-09 08:38:00+03	147200.00
099246	2017-07-30 20:33:00+03	15000.00
0992BA	2017-08-03 13:26:00+03	96200.00
0992C2	2017-07-15 08:23:00+03	85000.00
0992C3	2017-07-14 22:09:00+03	67500.00
0992F8	2017-07-31 07:00:00+03	282100.00
0993AF	2017-07-02 17:11:00+03	24400.00
0993D1	2017-07-08 19:49:00+03	43100.00
099441	2017-08-11 07:25:00+03	45100.00
0994B0	2017-07-08 22:11:00+03	75200.00
0994CA	2017-08-15 15:40:00+03	124000.00
0994D5	2017-07-28 14:27:00+03	136100.00
0994E9	2017-07-21 11:46:00+03	24800.00
099569	2017-07-28 12:21:00+03	46000.00
099579	2017-08-06 22:39:00+03	35600.00
0995A0	2017-07-30 02:23:00+03	28600.00
0995B0	2017-08-04 14:43:00+03	43200.00
0995E6	2017-07-08 05:08:00+03	57400.00
0995FA	2017-08-05 12:40:00+03	9200.00
099607	2017-07-06 17:24:00+03	51200.00
099611	2017-07-27 08:56:00+03	71600.00
09975D	2017-07-06 05:16:00+03	55800.00
09977E	2017-08-13 09:50:00+03	52000.00
099836	2017-07-08 17:14:00+03	27200.00
099855	2017-07-22 18:46:00+03	44600.00
09985B	2017-07-21 20:16:00+03	31100.00
09985C	2017-07-15 00:34:00+03	132800.00
0998B5	2017-07-02 12:33:00+03	199700.00
099948	2017-07-16 05:39:00+03	30200.00
09995D	2017-07-16 20:26:00+03	40400.00
0999A5	2017-07-30 00:26:00+03	25600.00
0999B0	2017-08-06 13:54:00+03	174900.00
0999BD	2017-07-30 05:41:00+03	40800.00
0999FE	2017-07-28 10:09:00+03	64800.00
099A03	2017-07-21 15:25:00+03	28000.00
099A4C	2017-07-24 07:02:00+03	73500.00
099A63	2017-07-03 06:43:00+03	23400.00
099B16	2017-07-12 18:14:00+03	63500.00
099B58	2017-07-27 20:32:00+03	132800.00
099B85	2017-07-16 08:01:00+03	114900.00
099BAC	2017-08-10 01:34:00+03	271400.00
099BE2	2017-08-15 00:33:00+03	23200.00
099C2E	2017-07-25 13:39:00+03	49100.00
099C75	2017-07-25 18:07:00+03	10800.00
099CEA	2017-07-30 12:12:00+03	32800.00
099E22	2017-07-11 20:51:00+03	229000.00
099E2B	2017-07-06 16:47:00+03	9200.00
099E32	2017-07-29 04:24:00+03	38400.00
099E59	2017-08-12 03:19:00+03	26000.00
099E6E	2017-07-04 14:37:00+03	115400.00
099FAD	2017-07-17 05:48:00+03	46000.00
099FB3	2017-07-29 18:56:00+03	41200.00
099FED	2017-07-04 06:40:00+03	206400.00
09A013	2017-08-10 06:24:00+03	133100.00
09A031	2017-08-14 12:18:00+03	36200.00
09A03C	2017-07-02 06:36:00+03	26800.00
09A047	2017-07-16 14:52:00+03	81300.00
09A0BE	2017-07-04 10:59:00+03	28800.00
09A0C1	2017-07-12 12:00:00+03	112000.00
09A0FE	2017-07-10 22:24:00+03	28000.00
09A174	2017-08-08 05:35:00+03	103800.00
09A1AC	2017-07-04 18:41:00+03	19600.00
09A1C0	2017-07-27 04:53:00+03	23200.00
09A223	2017-07-05 06:25:00+03	24500.00
09A234	2017-08-07 07:03:00+03	49500.00
09A24E	2017-07-31 17:58:00+03	12400.00
09A253	2017-07-30 14:10:00+03	19900.00
09A26F	2017-08-14 09:36:00+03	12000.00
09A27E	2017-07-01 06:00:00+03	83000.00
09A2E8	2017-07-15 13:37:00+03	39200.00
09A30E	2017-07-15 13:36:00+03	25600.00
09A375	2017-07-07 03:03:00+03	67600.00
09A3B2	2017-07-14 14:01:00+03	27300.00
09A41F	2017-07-26 10:15:00+03	55800.00
09A464	2017-07-17 18:59:00+03	49900.00
09A480	2017-07-11 11:26:00+03	384400.00
09A4AE	2017-07-13 09:20:00+03	6600.00
09A505	2017-07-27 19:18:00+03	6700.00
09A543	2017-07-21 13:42:00+03	85700.00
09A54B	2017-07-02 14:22:00+03	31800.00
09A583	2017-07-30 01:51:00+03	15600.00
09A5C2	2017-07-30 04:21:00+03	21200.00
09A5E3	2017-08-01 11:33:00+03	52000.00
09A60D	2017-08-01 12:18:00+03	78100.00
09A615	2017-07-30 06:30:00+03	112700.00
09A635	2017-08-15 03:41:00+03	36600.00
09A662	2017-07-15 03:59:00+03	91100.00
09A665	2017-07-20 08:10:00+03	15100.00
09A66B	2017-07-19 13:35:00+03	23200.00
09A69E	2017-07-05 07:20:00+03	23600.00
09A767	2017-08-05 08:11:00+03	49500.00
09A785	2017-07-02 20:56:00+03	92800.00
09A822	2017-07-05 21:04:00+03	21200.00
09A842	2017-07-20 02:07:00+03	46200.00
09A93A	2017-08-02 08:56:00+03	68400.00
09A9F1	2017-08-04 22:42:00+03	115700.00
09AA98	2017-07-23 07:49:00+03	23200.00
09AAA0	2017-07-17 20:04:00+03	394800.00
09AB03	2017-08-04 11:09:00+03	42000.00
09AB67	2017-07-21 09:01:00+03	166100.00
09AB6E	2017-07-20 07:41:00+03	44000.00
09ABB7	2017-07-12 02:29:00+03	46000.00
09AC2C	2017-07-30 04:27:00+03	43200.00
09AC70	2017-07-18 04:44:00+03	187800.00
09ACC8	2017-07-30 15:16:00+03	99200.00
09ADCE	2017-07-02 02:55:00+03	25000.00
09AE79	2017-07-17 01:39:00+03	260300.00
09AEDA	2017-06-30 16:58:00+03	7200.00
09AF00	2017-07-19 07:17:00+03	192400.00
09AF42	2017-08-11 02:56:00+03	76600.00
09AF54	2017-08-05 20:03:00+03	111600.00
09AFBD	2017-07-29 14:36:00+03	26000.00
09AFE6	2017-08-02 10:23:00+03	9200.00
09B061	2017-07-09 14:51:00+03	35400.00
09B077	2017-08-05 06:11:00+03	92100.00
09B092	2017-08-12 23:58:00+03	95900.00
09B0A3	2017-07-04 22:15:00+03	6000.00
09B0A7	2017-08-12 05:35:00+03	26000.00
09B0AD	2017-08-05 14:17:00+03	56000.00
09B0E2	2017-07-14 03:30:00+03	8000.00
09B0FD	2017-07-21 17:36:00+03	36200.00
09B0FE	2017-08-05 17:23:00+03	70600.00
09B117	2017-07-14 16:55:00+03	13400.00
09B11A	2017-07-19 18:04:00+03	24400.00
09B156	2017-08-06 00:22:00+03	40200.00
09B18F	2017-08-05 14:44:00+03	7400.00
09B1E2	2017-08-12 02:26:00+03	80900.00
09B22C	2017-08-15 10:06:00+03	17700.00
09B231	2017-08-04 07:31:00+03	40700.00
09B320	2017-07-22 01:57:00+03	65700.00
09B343	2017-07-07 11:29:00+03	24000.00
09B45D	2017-07-27 21:43:00+03	153300.00
09B4A6	2017-07-11 19:12:00+03	46400.00
09B4A9	2017-07-12 23:35:00+03	79600.00
09B4C8	2017-07-23 12:03:00+03	92800.00
09B506	2017-07-24 12:52:00+03	52000.00
09B512	2017-07-08 00:13:00+03	52800.00
09B578	2017-08-09 19:07:00+03	39300.00
09B580	2017-07-12 02:34:00+03	56000.00
09B5F4	2017-07-13 21:09:00+03	54000.00
09B673	2017-08-08 14:49:00+03	15000.00
09B685	2017-07-28 01:15:00+03	204400.00
09B69F	2017-07-12 17:43:00+03	6700.00
09B80E	2017-07-22 16:28:00+03	125600.00
09B825	2017-07-03 06:59:00+03	23200.00
09B827	2017-08-10 12:05:00+03	398500.00
09B830	2017-07-05 07:42:00+03	32700.00
09B983	2017-07-29 09:34:00+03	50800.00
09B986	2017-08-03 06:16:00+03	27200.00
09BA0F	2017-07-02 21:58:00+03	270700.00
09BA4F	2017-07-17 03:08:00+03	25100.00
09BA9B	2017-07-07 21:31:00+03	193600.00
09BAFB	2017-07-13 00:17:00+03	52700.00
09BB97	2017-07-01 14:48:00+03	28000.00
09BBE4	2017-08-07 03:29:00+03	158100.00
09BC76	2017-08-07 04:55:00+03	31800.00
09BC8F	2017-08-04 15:21:00+03	173600.00
09BD67	2017-08-05 12:20:00+03	54800.00
09BE6A	2017-07-12 18:44:00+03	46400.00
09BE76	2017-07-18 02:15:00+03	13000.00
09BE98	2017-07-14 07:59:00+03	54400.00
09BE9D	2017-08-09 18:37:00+03	270700.00
09BF4B	2017-08-06 18:58:00+03	45100.00
09BF56	2017-08-04 13:38:00+03	173400.00
09BF6A	2017-07-05 03:08:00+03	42900.00
09BF81	2017-07-15 07:47:00+03	70800.00
09BF8F	2017-07-22 00:04:00+03	16400.00
09BFDC	2017-08-12 20:59:00+03	55000.00
09C049	2017-07-31 22:32:00+03	57600.00
09C0B0	2017-08-08 20:14:00+03	56000.00
09C0F1	2017-07-04 14:52:00+03	207200.00
09C10C	2017-06-27 18:35:00+03	48100.00
09C11B	2017-08-13 03:31:00+03	119800.00
09C1BC	2017-08-11 17:51:00+03	54700.00
09C1CB	2017-07-30 00:28:00+03	45100.00
09C202	2017-08-13 07:40:00+03	58600.00
09C222	2017-07-04 02:22:00+03	88600.00
09C248	2017-07-26 19:12:00+03	133100.00
09C2AD	2017-07-25 17:26:00+03	26800.00
09C2D2	2017-07-07 22:02:00+03	46400.00
09C377	2017-08-02 23:52:00+03	47200.00
09C3B9	2017-07-25 04:12:00+03	56000.00
09C3E0	2017-07-20 10:56:00+03	27300.00
09C3EE	2017-07-05 04:35:00+03	94700.00
09C400	2017-07-20 16:52:00+03	35200.00
09C401	2017-07-28 01:47:00+03	46000.00
09C42F	2017-08-10 10:43:00+03	146700.00
09C43F	2017-07-08 01:47:00+03	6600.00
09C459	2017-07-23 17:13:00+03	6800.00
09C48C	2017-07-13 00:54:00+03	38800.00
09C493	2017-08-14 00:06:00+03	34000.00
09C504	2017-08-14 20:02:00+03	84100.00
09C519	2017-07-17 21:20:00+03	67600.00
09C5A4	2017-07-18 09:28:00+03	25400.00
09C5A8	2017-07-18 09:41:00+03	101200.00
09C5EF	2017-08-08 03:21:00+03	58900.00
09C6D7	2017-07-25 08:53:00+03	48500.00
09C6F9	2017-07-05 04:05:00+03	21800.00
09C6FE	2017-07-31 15:18:00+03	7200.00
09C710	2017-07-20 09:52:00+03	21800.00
09C75A	2017-08-15 10:33:00+03	94800.00
09C786	2017-07-03 06:34:00+03	52000.00
09C792	2017-08-13 20:14:00+03	9800.00
09C827	2017-08-09 13:22:00+03	10800.00
09C829	2017-07-12 00:13:00+03	43600.00
09C836	2017-07-14 14:24:00+03	28800.00
09C84A	2017-07-04 15:20:00+03	124200.00
09C854	2017-08-05 02:37:00+03	40200.00
09C899	2017-08-12 06:54:00+03	25100.00
09C90C	2017-08-05 19:50:00+03	26000.00
09C92F	2017-07-30 01:01:00+03	16400.00
09C97F	2017-08-02 19:10:00+03	117700.00
09C9DF	2017-08-12 10:03:00+03	65900.00
09CA39	2017-07-30 21:12:00+03	108500.00
09CAB4	2017-08-06 21:30:00+03	112000.00
09CB34	2017-07-05 09:52:00+03	272400.00
09CB7B	2017-07-09 01:10:00+03	81600.00
09CB98	2017-07-08 21:31:00+03	66600.00
09CC57	2017-07-28 13:37:00+03	119500.00
09CCBB	2017-07-12 10:18:00+03	99600.00
09CCC7	2017-07-20 21:45:00+03	62700.00
09CCF2	2017-08-12 02:31:00+03	92100.00
09CD67	2017-08-06 19:05:00+03	47100.00
09CE89	2017-07-26 00:36:00+03	90800.00
09CE93	2017-07-18 17:18:00+03	49800.00
09CEAD	2017-07-17 01:28:00+03	40300.00
09CEC7	2017-08-01 01:53:00+03	73100.00
09CEE8	2017-07-27 05:22:00+03	24800.00
09CF01	2017-07-04 17:00:00+03	229300.00
09CF2F	2017-07-20 06:54:00+03	21200.00
09CF43	2017-07-24 18:01:00+03	258400.00
09CF4B	2017-07-07 08:02:00+03	90400.00
09CFF6	2017-07-01 06:57:00+03	7300.00
09D14C	2017-07-05 20:52:00+03	111600.00
09D231	2017-07-20 07:34:00+03	28000.00
09D258	2017-07-24 02:36:00+03	30200.00
09D275	2017-07-10 15:53:00+03	106100.00
09D296	2017-07-01 11:21:00+03	160700.00
09D2A3	2017-08-09 22:55:00+03	28000.00
09D2FC	2017-06-30 16:55:00+03	18900.00
09D332	2017-07-17 09:54:00+03	56000.00
09D414	2017-07-19 05:56:00+03	14400.00
09D460	2017-07-04 02:27:00+03	145900.00
09D4BB	2017-07-17 07:22:00+03	56600.00
09D4EA	2017-08-01 11:37:00+03	169600.00
09D596	2017-08-06 12:44:00+03	37900.00
09D65F	2017-07-17 10:25:00+03	72200.00
09D681	2017-08-15 07:27:00+03	62000.00
09D6A6	2017-07-10 18:09:00+03	30900.00
09D6B7	2017-07-18 00:36:00+03	198900.00
09D6C6	2017-07-23 12:59:00+03	99300.00
09D6EF	2017-08-12 17:52:00+03	61300.00
09D701	2017-07-14 03:11:00+03	89600.00
09D72E	2017-07-09 17:40:00+03	277300.00
09D737	2017-08-15 10:51:00+03	98400.00
09D764	2017-08-02 00:36:00+03	28800.00
09D793	2017-08-08 20:56:00+03	132800.00
09D847	2017-07-24 18:10:00+03	23200.00
09D86B	2017-08-04 04:41:00+03	88600.00
09D890	2017-08-09 14:48:00+03	9800.00
09D8BB	2017-08-10 19:01:00+03	47200.00
09D8D7	2017-07-20 02:14:00+03	55500.00
09D8F7	2017-08-01 20:56:00+03	77600.00
09D902	2017-07-14 06:28:00+03	221500.00
09D904	2017-07-13 15:53:00+03	26800.00
09D934	2017-07-22 14:46:00+03	6800.00
09D9D6	2017-08-01 13:11:00+03	81300.00
09D9DB	2017-08-10 08:47:00+03	52800.00
09D9FF	2017-07-15 11:19:00+03	148200.00
09DA0B	2017-07-14 12:54:00+03	57400.00
09DA4A	2017-08-01 08:27:00+03	16400.00
09DAFD	2017-07-16 02:35:00+03	14800.00
09DB09	2017-07-09 15:21:00+03	228400.00
09DB0F	2017-08-08 12:43:00+03	64200.00
09DB17	2017-07-21 11:13:00+03	112600.00
09DB45	2017-07-21 23:52:00+03	133100.00
09DB50	2017-07-14 18:44:00+03	46800.00
09DBA7	2017-07-17 15:45:00+03	43700.00
09DBD9	2017-08-13 03:00:00+03	56000.00
09DC09	2017-07-20 05:26:00+03	67600.00
09DCB7	2017-07-08 11:49:00+03	23200.00
09DD28	2017-06-29 09:25:00+03	79700.00
09DD4D	2017-07-29 23:03:00+03	60400.00
09DD57	2017-08-07 04:42:00+03	25900.00
09DE28	2017-07-16 23:13:00+03	62300.00
09DE3D	2017-07-20 22:41:00+03	157200.00
09DE61	2017-08-05 18:06:00+03	147200.00
09DE70	2017-08-01 02:59:00+03	160200.00
09DF35	2017-08-04 07:30:00+03	44800.00
09DFDA	2017-07-31 15:24:00+03	130600.00
09DFFD	2017-07-17 02:28:00+03	88400.00
09E002	2017-08-10 01:14:00+03	23200.00
09E04A	2017-06-29 10:34:00+03	96800.00
09E0F1	2017-08-11 02:43:00+03	68300.00
09E105	2017-07-25 22:37:00+03	15000.00
09E134	2017-08-07 17:05:00+03	40000.00
09E1D7	2017-07-16 22:56:00+03	26000.00
09E1E1	2017-08-14 04:42:00+03	270700.00
09E235	2017-07-25 21:54:00+03	123000.00
09E281	2017-08-09 03:13:00+03	166100.00
09E2FC	2017-07-23 09:24:00+03	49900.00
09E423	2017-07-28 18:11:00+03	48800.00
09E476	2017-07-23 05:56:00+03	69600.00
09E49F	2017-08-13 09:18:00+03	75500.00
09E4A4	2017-08-03 02:42:00+03	28000.00
09E4BB	2017-07-27 17:59:00+03	23600.00
09E57D	2017-08-14 06:35:00+03	290500.00
09E5CE	2017-08-12 23:38:00+03	295200.00
09E67D	2017-07-04 07:47:00+03	47100.00
09E67F	2017-07-04 15:22:00+03	26700.00
09E685	2017-08-10 06:37:00+03	62700.00
09E6CB	2017-07-13 15:16:00+03	99300.00
09E6CF	2017-07-15 09:48:00+03	43500.00
09E6E3	2017-08-04 04:14:00+03	64800.00
09E73C	2017-07-08 09:43:00+03	235200.00
09E760	2017-08-03 11:36:00+03	105600.00
09E77F	2017-07-07 15:02:00+03	88300.00
09E79E	2017-08-09 21:48:00+03	167400.00
09E7A3	2017-06-28 09:38:00+03	40800.00
09E7D3	2017-07-07 18:22:00+03	119800.00
09E80D	2017-08-13 10:22:00+03	113200.00
09E817	2017-07-07 21:43:00+03	206200.00
09E871	2017-07-18 18:29:00+03	91800.00
09E88B	2017-07-19 21:56:00+03	26100.00
09E8AF	2017-07-14 00:21:00+03	26700.00
09E8F8	2017-07-23 22:18:00+03	48600.00
09E906	2017-07-29 13:28:00+03	112000.00
09E956	2017-07-29 03:19:00+03	27300.00
09E9B7	2017-07-18 03:19:00+03	238800.00
09E9C8	2017-08-01 03:30:00+03	43500.00
09E9CA	2017-07-10 06:42:00+03	36200.00
09EA18	2017-07-08 03:06:00+03	66300.00
09EA78	2017-08-02 03:12:00+03	453900.00
09EACC	2017-07-27 03:38:00+03	28800.00
09EAF3	2017-07-18 02:12:00+03	177200.00
09EB32	2017-07-23 09:34:00+03	80000.00
09EB55	2017-08-02 21:15:00+03	111600.00
09EBBB	2017-07-08 01:04:00+03	37600.00
09EBC7	2017-08-14 01:31:00+03	34400.00
09EBDA	2017-07-21 06:10:00+03	492000.00
09EBFE	2017-07-12 17:19:00+03	29400.00
09EC74	2017-08-11 03:05:00+03	79200.00
09EC8A	2017-07-31 20:52:00+03	23200.00
09ECB7	2017-07-02 01:05:00+03	67600.00
09ECC5	2017-07-22 16:08:00+03	101200.00
09ECC6	2017-07-25 22:26:00+03	25200.00
09EDC4	2017-08-07 09:41:00+03	29400.00
09EE19	2017-07-07 16:25:00+03	52000.00
09EF01	2017-07-13 10:01:00+03	58700.00
09EF19	2017-07-26 08:14:00+03	97700.00
09EF22	2017-07-09 08:06:00+03	393000.00
09EF24	2017-07-15 11:23:00+03	76800.00
09EFB2	2017-07-02 11:10:00+03	24400.00
09EFE6	2017-07-30 18:59:00+03	22000.00
09EFFA	2017-07-16 19:49:00+03	13400.00
09F011	2017-08-15 01:09:00+03	6300.00
09F024	2017-08-05 22:44:00+03	13600.00
09F070	2017-08-01 22:55:00+03	65400.00
09F127	2017-07-17 10:20:00+03	36200.00
09F130	2017-08-11 01:40:00+03	75300.00
09F178	2017-07-11 18:03:00+03	15400.00
09F1B9	2017-07-13 00:53:00+03	46000.00
09F2F7	2017-07-13 03:40:00+03	72200.00
09F3A3	2017-08-01 17:32:00+03	165400.00
09F3A5	2017-07-17 15:19:00+03	664500.00
09F3C2	2017-07-20 11:50:00+03	31200.00
09F42C	2017-07-24 11:27:00+03	34000.00
09F433	2017-07-29 08:38:00+03	26200.00
09F435	2017-07-25 19:37:00+03	40400.00
09F4ED	2017-08-08 14:50:00+03	61800.00
09F570	2017-07-17 03:21:00+03	160800.00
09F578	2017-07-31 13:33:00+03	282000.00
09F592	2017-08-07 10:00:00+03	23900.00
09F593	2017-08-10 06:00:00+03	248800.00
09F59E	2017-07-21 18:20:00+03	28800.00
09F61E	2017-07-28 04:07:00+03	23200.00
09F626	2017-07-01 05:26:00+03	26000.00
09F63E	2017-07-15 16:44:00+03	22400.00
09F65B	2017-07-28 18:03:00+03	54800.00
09F685	2017-08-13 01:40:00+03	86600.00
09F6C6	2017-08-07 16:07:00+03	99200.00
09F6C8	2017-08-13 23:08:00+03	59800.00
09F6C9	2017-07-23 13:07:00+03	72400.00
09F6D7	2017-07-25 06:17:00+03	319100.00
09F6F4	2017-07-26 21:36:00+03	15800.00
09F756	2017-08-13 01:25:00+03	51900.00
09F774	2017-07-21 23:38:00+03	64300.00
09F77E	2017-08-15 11:57:00+03	73200.00
09F84A	2017-08-05 00:07:00+03	30200.00
09F851	2017-07-25 07:03:00+03	327700.00
09F927	2017-07-15 10:49:00+03	106700.00
09F939	2017-08-12 13:26:00+03	174400.00
09F9A4	2017-07-28 02:41:00+03	24300.00
09FA2F	2017-06-28 04:29:00+03	25000.00
09FA85	2017-08-09 11:53:00+03	93900.00
09FAB4	2017-08-12 05:35:00+03	83600.00
09FABA	2017-07-12 15:06:00+03	266500.00
09FAF3	2017-07-22 06:24:00+03	56900.00
09FB19	2017-08-14 07:23:00+03	25100.00
09FB62	2017-07-14 01:03:00+03	8200.00
09FB82	2017-08-09 22:01:00+03	38800.00
09FBA1	2017-08-14 06:23:00+03	57600.00
09FBF5	2017-07-24 05:34:00+03	54000.00
09FC36	2017-08-11 12:08:00+03	14700.00
09FC99	2017-07-31 21:32:00+03	48400.00
09FCDC	2017-07-29 12:28:00+03	51300.00
09FDCE	2017-07-25 08:52:00+03	270200.00
09FE07	2017-07-18 14:30:00+03	123000.00
09FE16	2017-07-16 21:13:00+03	85000.00
09FE5F	2017-07-01 05:11:00+03	32400.00
09FE9E	2017-07-27 15:10:00+03	58600.00
09FF33	2017-07-29 01:10:00+03	46900.00
09FFBA	2017-08-08 05:28:00+03	6700.00
09FFDB	2017-08-11 23:59:00+03	112000.00
09FFFA	2017-07-25 10:02:00+03	56600.00
0A0023	2017-06-30 17:25:00+03	88100.00
0A0041	2017-07-05 19:05:00+03	59300.00
0A0067	2017-08-04 23:15:00+03	24000.00
0A0073	2017-07-05 12:55:00+03	111600.00
0A008D	2017-07-14 05:38:00+03	92400.00
0A014E	2017-07-29 06:44:00+03	12600.00
0A015C	2017-07-24 04:12:00+03	11300.00
0A0183	2017-07-14 03:59:00+03	40800.00
0A018F	2017-07-07 18:31:00+03	88200.00
0A01B6	2017-07-08 08:19:00+03	389000.00
0A0216	2017-08-15 10:45:00+03	32800.00
0A0294	2017-07-30 13:30:00+03	34000.00
0A02BA	2017-08-07 09:36:00+03	246000.00
0A02BC	2017-07-27 01:33:00+03	44800.00
0A02D6	2017-07-10 19:07:00+03	289800.00
0A02FE	2017-07-27 09:56:00+03	26800.00
0A0305	2017-07-20 22:44:00+03	76800.00
0A030B	2017-08-11 18:38:00+03	76600.00
0A0310	2017-07-21 04:04:00+03	103400.00
0A037E	2017-08-10 05:05:00+03	28800.00
0A040A	2017-07-11 22:21:00+03	170700.00
0A044C	2017-07-13 07:11:00+03	33100.00
0A045A	2017-08-11 10:51:00+03	38800.00
0A0460	2017-07-29 05:37:00+03	272300.00
0A046B	2017-08-13 10:07:00+03	32800.00
0A046C	2017-08-15 13:02:00+03	40800.00
0A0470	2017-07-05 11:36:00+03	24800.00
0A047B	2017-07-05 01:13:00+03	125200.00
0A049B	2017-07-09 20:30:00+03	28300.00
0A04E6	2017-07-05 09:13:00+03	66600.00
0A0521	2017-07-15 00:12:00+03	56900.00
0A0545	2017-07-26 02:06:00+03	34800.00
0A0550	2017-07-17 09:39:00+03	31700.00
0A0555	2017-08-14 04:47:00+03	83000.00
0A0623	2017-08-09 17:23:00+03	28000.00
0A062C	2017-07-12 22:57:00+03	83400.00
0A06B8	2017-07-02 18:19:00+03	57600.00
0A06B9	2017-07-09 09:49:00+03	94000.00
0A0714	2017-07-25 03:21:00+03	38200.00
0A0739	2017-07-04 22:28:00+03	167500.00
0A073A	2017-08-07 16:41:00+03	38500.00
0A0743	2017-08-06 06:57:00+03	246000.00
0A0753	2017-07-13 11:32:00+03	120700.00
0A076A	2017-07-18 11:29:00+03	11800.00
0A07C2	2017-08-07 23:11:00+03	6700.00
0A082E	2017-07-18 23:33:00+03	283100.00
0A085A	2017-07-12 08:36:00+03	34000.00
0A087A	2017-07-27 19:03:00+03	24700.00
0A0895	2017-07-15 16:22:00+03	21400.00
0A08BB	2017-07-08 17:47:00+03	94200.00
0A093A	2017-07-23 07:17:00+03	23200.00
0A0979	2017-08-06 13:28:00+03	44800.00
0A0A00	2017-08-14 08:11:00+03	62000.00
0A0A13	2017-07-23 12:30:00+03	6700.00
0A0A57	2017-07-30 02:03:00+03	354400.00
0A0AC9	2017-08-08 23:12:00+03	16000.00
0A0AF2	2017-07-01 02:05:00+03	41600.00
0A0AFA	2017-07-09 23:05:00+03	175800.00
0A0B17	2017-07-18 03:51:00+03	118300.00
0A0B83	2017-07-18 02:09:00+03	22000.00
0A0B8A	2017-07-31 22:01:00+03	405100.00
0A0BBA	2017-07-06 22:49:00+03	17600.00
0A0BD3	2017-07-26 03:49:00+03	152300.00
0A0C2F	2017-08-11 17:24:00+03	64100.00
0A0C34	2017-07-17 21:26:00+03	280700.00
0A0C47	2017-07-13 18:50:00+03	66600.00
0A0C99	2017-08-08 01:06:00+03	48800.00
0A0C9E	2017-07-23 20:15:00+03	46000.00
0A0CA5	2017-07-24 09:17:00+03	105400.00
0A0CE3	2017-08-13 03:18:00+03	46800.00
0A0D66	2017-07-29 17:49:00+03	56000.00
0A0D8A	2017-07-10 17:27:00+03	187200.00
0A0DEA	2017-08-11 09:26:00+03	243600.00
0A0DFF	2017-08-10 07:33:00+03	67600.00
0A0E6D	2017-07-07 01:45:00+03	23200.00
0A0E90	2017-07-16 22:42:00+03	126900.00
0A0F64	2017-07-02 12:23:00+03	265600.00
0A0F79	2017-08-10 14:59:00+03	28800.00
0A0FA9	2017-08-10 16:32:00+03	37100.00
0A0FB5	2017-07-18 18:17:00+03	173800.00
0A103A	2017-08-06 07:20:00+03	48300.00
0A103F	2017-07-26 17:00:00+03	31000.00
0A10AD	2017-08-08 11:31:00+03	40800.00
0A10FA	2017-07-29 17:54:00+03	35200.00
0A110F	2017-07-25 20:31:00+03	42800.00
0A111D	2017-07-09 07:10:00+03	125100.00
0A1132	2017-07-28 08:51:00+03	252200.00
0A1144	2017-07-18 18:17:00+03	24800.00
0A1149	2017-07-03 10:58:00+03	293900.00
0A114E	2017-07-06 00:55:00+03	131100.00
0A115F	2017-07-23 01:49:00+03	137800.00
0A119A	2017-08-01 09:00:00+03	95300.00
0A11AD	2017-07-28 22:07:00+03	79800.00
0A11FE	2017-08-14 19:03:00+03	233700.00
0A129C	2017-08-07 02:29:00+03	67200.00
0A12FA	2017-07-14 04:31:00+03	236700.00
0A1334	2017-07-05 01:52:00+03	81600.00
0A1350	2017-08-01 04:05:00+03	28000.00
0A13A1	2017-08-14 01:52:00+03	97400.00
0A13B3	2017-08-09 12:49:00+03	26000.00
0A13B9	2017-08-02 11:05:00+03	46400.00
0A13E7	2017-07-03 06:58:00+03	93900.00
0A13E8	2017-07-31 08:54:00+03	34000.00
0A145E	2017-07-15 19:08:00+03	86300.00
0A147A	2017-07-07 14:24:00+03	65900.00
0A14D7	2017-07-02 06:20:00+03	210800.00
0A1501	2017-07-29 18:20:00+03	38500.00
0A1511	2017-07-21 17:24:00+03	28000.00
0A155E	2017-07-24 17:27:00+03	272700.00
0A1575	2017-07-08 10:08:00+03	59400.00
0A1629	2017-07-23 01:34:00+03	147200.00
0A16B1	2017-08-12 19:18:00+03	13000.00
0A1727	2017-07-08 16:16:00+03	28300.00
0A1755	2017-08-01 00:25:00+03	71200.00
0A17CB	2017-06-30 09:47:00+03	73500.00
0A17D7	2017-07-02 11:03:00+03	12600.00
0A1840	2017-07-22 11:08:00+03	136800.00
0A1855	2017-07-09 09:29:00+03	57800.00
0A186D	2017-07-22 23:32:00+03	189200.00
0A1889	2017-07-15 06:17:00+03	38600.00
0A18A6	2017-08-03 10:10:00+03	28000.00
0A18CF	2017-07-20 09:59:00+03	38800.00
0A18E2	2017-07-27 10:55:00+03	260300.00
0A1926	2017-07-26 07:07:00+03	28000.00
0A1966	2017-07-06 17:55:00+03	24700.00
0A1994	2017-08-06 03:31:00+03	7200.00
0A19A1	2017-08-10 23:14:00+03	62800.00
0A1A09	2017-07-04 06:13:00+03	205900.00
0A1A39	2017-07-29 23:19:00+03	131600.00
0A1A8B	2017-07-04 17:34:00+03	128800.00
0A1A9B	2017-07-15 14:53:00+03	65100.00
0A1BC5	2017-08-15 06:36:00+03	133200.00
0A1C0A	2017-07-27 17:04:00+03	193100.00
0A1C18	2017-07-18 11:57:00+03	46000.00
0A1D52	2017-07-24 01:53:00+03	13400.00
0A1D57	2017-07-09 12:58:00+03	167200.00
0A1E40	2017-07-08 00:23:00+03	21800.00
0A1E70	2017-08-11 04:38:00+03	6000.00
0A1EF5	2017-07-02 18:32:00+03	11700.00
0A1F06	2017-07-03 06:33:00+03	37300.00
0A1F2C	2017-07-28 01:39:00+03	28000.00
0A1F39	2017-08-12 02:04:00+03	46500.00
0A1F87	2017-07-17 06:56:00+03	16400.00
0A1F93	2017-08-02 21:59:00+03	92700.00
0A2054	2017-07-10 04:31:00+03	70400.00
0A2085	2017-07-09 00:21:00+03	26800.00
0A20CC	2017-07-02 18:24:00+03	39300.00
0A216C	2017-08-13 13:57:00+03	31400.00
0A21B1	2017-07-01 22:16:00+03	21200.00
0A2330	2017-07-18 17:53:00+03	160900.00
0A2334	2017-08-02 01:16:00+03	52000.00
0A2335	2017-07-02 16:01:00+03	103000.00
0A2359	2017-08-11 01:26:00+03	47100.00
0A2361	2017-07-24 08:20:00+03	66600.00
0A23F1	2017-08-02 04:12:00+03	67200.00
0A2419	2017-08-11 21:08:00+03	12600.00
0A242D	2017-08-07 00:22:00+03	152500.00
0A24C9	2017-08-09 15:18:00+03	110000.00
0A24FA	2017-06-30 07:49:00+03	111600.00
0A255C	2017-07-29 13:36:00+03	108600.00
0A2571	2017-07-13 22:49:00+03	50200.00
0A2573	2017-07-26 15:38:00+03	24000.00
0A25A4	2017-07-19 10:52:00+03	168000.00
0A25AF	2017-08-13 04:16:00+03	41900.00
0A2635	2017-07-15 09:01:00+03	54000.00
0A2642	2017-07-23 06:00:00+03	408500.00
0A2652	2017-07-11 03:18:00+03	36200.00
0A2678	2017-07-18 17:54:00+03	132800.00
0A26D7	2017-07-18 14:28:00+03	55800.00
0A271B	2017-07-04 15:33:00+03	100800.00
0A2750	2017-08-08 00:42:00+03	8400.00
0A27E5	2017-06-30 07:26:00+03	13400.00
0A282C	2017-07-15 22:57:00+03	14400.00
0A283C	2017-08-14 00:47:00+03	36600.00
0A28A9	2017-08-08 04:29:00+03	167500.00
0A28AC	2017-08-14 22:53:00+03	12600.00
0A28BC	2017-08-04 02:00:00+03	83400.00
0A2916	2017-08-10 13:37:00+03	28000.00
0A2936	2017-07-05 19:54:00+03	8200.00
0A2A00	2017-07-02 13:55:00+03	52300.00
0A2A04	2017-07-01 09:38:00+03	73300.00
0A2AAD	2017-07-11 00:18:00+03	113300.00
0A2AFD	2017-07-10 06:00:00+03	100000.00
0A2B5F	2017-07-04 21:09:00+03	47000.00
0A2B85	2017-07-20 20:06:00+03	6600.00
0A2BDF	2017-08-08 05:01:00+03	28000.00
0A2BF6	2017-07-23 11:38:00+03	394800.00
0A2C1B	2017-07-23 14:39:00+03	44300.00
0A2C5D	2017-07-24 06:42:00+03	167400.00
0A2C90	2017-07-13 06:12:00+03	84500.00
0A2D33	2017-07-06 01:37:00+03	28000.00
0A2D55	2017-07-21 22:28:00+03	15800.00
0A2D97	2017-07-08 05:19:00+03	56900.00
0A2DCD	2017-07-11 22:30:00+03	7800.00
0A2DF7	2017-07-24 12:10:00+03	6800.00
0A2E8C	2017-08-07 06:01:00+03	67600.00
0A2E8E	2017-07-29 12:41:00+03	195800.00
0A2EE6	2017-08-11 15:03:00+03	69500.00
0A2F73	2017-07-11 15:31:00+03	77000.00
0A2FB2	2017-07-14 01:54:00+03	112600.00
0A2FDD	2017-07-02 22:53:00+03	26500.00
0A2FEE	2017-07-28 00:04:00+03	13400.00
0A2FF0	2017-08-05 08:12:00+03	8400.00
0A3028	2017-07-01 23:16:00+03	26200.00
0A3046	2017-08-13 02:41:00+03	119600.00
0A30A7	2017-07-05 14:20:00+03	12400.00
0A30B5	2017-07-30 20:00:00+03	12600.00
0A30F6	2017-07-29 06:22:00+03	60000.00
0A3128	2017-07-04 23:10:00+03	103800.00
0A3226	2017-08-14 10:59:00+03	14800.00
0A3233	2017-07-27 12:14:00+03	7400.00
0A3264	2017-07-08 18:46:00+03	49600.00
0A32C8	2017-07-25 02:31:00+03	61500.00
0A3312	2017-07-07 09:39:00+03	172100.00
0A332D	2017-07-07 09:21:00+03	22000.00
0A3399	2017-08-11 15:43:00+03	40800.00
0A342E	2017-07-01 06:24:00+03	56000.00
0A349C	2017-08-14 04:19:00+03	46800.00
0A34DB	2017-07-20 04:00:00+03	164800.00
0A3500	2017-07-16 01:15:00+03	21800.00
0A3530	2017-08-06 08:02:00+03	26800.00
0A355F	2017-08-12 20:54:00+03	27200.00
0A35B9	2017-07-19 20:16:00+03	32800.00
0A35EF	2017-07-23 23:15:00+03	40000.00
0A365B	2017-08-08 06:46:00+03	8400.00
0A373A	2017-07-03 03:50:00+03	123000.00
0A377B	2017-07-08 22:37:00+03	56600.00
0A378B	2017-07-27 21:49:00+03	78200.00
0A379F	2017-08-15 05:47:00+03	64500.00
0A37D2	2017-08-05 06:52:00+03	67700.00
0A3897	2017-08-14 06:03:00+03	43100.00
0A392A	2017-08-10 06:14:00+03	61800.00
0A39B4	2017-07-06 04:24:00+03	29400.00
0A39CD	2017-08-06 22:18:00+03	135400.00
0A3A1A	2017-08-10 15:06:00+03	94900.00
0A3A21	2017-07-18 19:16:00+03	89700.00
0A3A44	2017-08-12 12:44:00+03	46800.00
0A3A7A	2017-07-07 23:50:00+03	92100.00
0A3A82	2017-07-06 15:48:00+03	14400.00
0A3B0F	2017-07-05 15:42:00+03	606600.00
0A3B14	2017-06-30 03:49:00+03	137600.00
0A3BAC	2017-07-15 04:08:00+03	94000.00
0A3BBA	2017-08-03 14:54:00+03	58000.00
0A3BC7	2017-08-06 03:10:00+03	36400.00
0A3BDF	2017-07-21 12:40:00+03	56600.00
0A3D02	2017-07-31 11:49:00+03	47200.00
0A3D12	2017-08-09 10:39:00+03	111600.00
0A3D56	2017-08-05 16:03:00+03	43200.00
0A3DA5	2017-07-23 05:19:00+03	286700.00
0A3DF4	2017-07-05 08:43:00+03	44800.00
0A3E9E	2017-07-01 07:21:00+03	56600.00
0A3EA2	2017-07-08 03:30:00+03	58900.00
0A3EBA	2017-07-04 18:31:00+03	67200.00
0A3EC9	2017-07-18 03:38:00+03	44800.00
0A3EEB	2017-08-03 20:05:00+03	131100.00
0A3F1C	2017-07-31 09:02:00+03	6700.00
0A3F57	2017-07-09 09:30:00+03	280800.00
0A3FA7	2017-08-06 17:01:00+03	46400.00
0A4098	2017-07-08 15:17:00+03	26800.00
0A40CC	2017-08-08 10:40:00+03	81300.00
0A40E8	2017-06-26 00:07:00+03	188000.00
0A40F2	2017-07-21 07:26:00+03	31600.00
0A4111	2017-07-28 20:45:00+03	67600.00
0A4152	2017-07-18 00:30:00+03	50000.00
0A41A4	2017-07-15 11:10:00+03	49800.00
0A41FB	2017-07-27 15:06:00+03	213800.00
0A422B	2017-07-23 18:54:00+03	53000.00
0A429F	2017-07-17 02:14:00+03	101700.00
0A42C1	2017-08-12 23:15:00+03	69100.00
0A430C	2017-08-02 09:11:00+03	23400.00
0A435A	2017-07-01 22:51:00+03	93900.00
0A438F	2017-07-16 19:28:00+03	28300.00
0A43D2	2017-08-07 04:38:00+03	65900.00
0A43DE	2017-07-05 21:03:00+03	151300.00
0A443F	2017-07-25 11:36:00+03	67400.00
0A4479	2017-06-30 17:40:00+03	55800.00
0A44DE	2017-07-29 02:08:00+03	27200.00
0A44F3	2017-08-15 08:24:00+03	265600.00
0A4539	2017-07-25 11:49:00+03	111600.00
0A4542	2017-08-06 04:06:00+03	58600.00
0A4574	2017-07-14 21:58:00+03	531300.00
0A45CE	2017-07-08 01:50:00+03	7400.00
0A45DB	2017-07-22 09:15:00+03	7400.00
0A462A	2017-08-05 00:14:00+03	29600.00
0A4643	2017-07-31 01:57:00+03	84000.00
0A467C	2017-07-14 05:18:00+03	136200.00
0A474F	2017-07-13 16:58:00+03	23600.00
0A47B8	2017-07-25 13:02:00+03	252200.00
0A4816	2017-07-11 01:52:00+03	94400.00
0A481B	2017-07-28 12:04:00+03	75100.00
0A486B	2017-08-13 09:22:00+03	46000.00
0A48A5	2017-06-30 06:17:00+03	28000.00
0A48C8	2017-08-10 06:57:00+03	78300.00
0A4943	2017-07-31 18:34:00+03	60600.00
0A496D	2017-08-05 10:38:00+03	12600.00
0A4996	2017-07-19 02:12:00+03	38500.00
0A49C4	2017-07-21 04:39:00+03	170800.00
0A49DB	2017-07-16 19:19:00+03	85700.00
0A4A1A	2017-07-27 00:53:00+03	6300.00
0A4A28	2017-07-23 13:49:00+03	111600.00
0A4AAB	2017-08-03 01:38:00+03	84500.00
0A4AF0	2017-08-11 18:04:00+03	51900.00
0A4B08	2017-07-02 08:55:00+03	56100.00
0A4B0C	2017-07-19 06:04:00+03	22000.00
0A4BB6	2017-07-12 15:28:00+03	13000.00
0A4CB4	2017-07-14 13:10:00+03	516000.00
0A4D12	2017-07-30 13:28:00+03	28800.00
0A4D2F	2017-07-22 10:11:00+03	13000.00
0A4D58	2017-07-31 03:33:00+03	89600.00
0A4D5E	2017-08-14 10:32:00+03	139300.00
0A4D9F	2017-07-04 09:11:00+03	135400.00
0A4E10	2017-07-24 02:02:00+03	148200.00
0A4F61	2017-08-01 15:55:00+03	95700.00
0A4FA3	2017-08-09 08:44:00+03	39200.00
0A4FB2	2017-07-07 13:07:00+03	46400.00
0A4FE3	2017-08-06 08:42:00+03	133200.00
0A5022	2017-06-29 15:03:00+03	24800.00
0A504C	2017-08-03 12:31:00+03	47400.00
0A50A6	2017-07-05 08:03:00+03	48800.00
0A50BB	2017-07-02 15:08:00+03	26300.00
0A50F7	2017-08-04 15:00:00+03	13600.00
0A510A	2017-07-25 18:10:00+03	37900.00
0A5146	2017-07-18 16:45:00+03	56000.00
0A5219	2017-08-07 04:33:00+03	131100.00
0A527A	2017-07-11 14:33:00+03	24800.00
0A52F6	2017-08-06 21:38:00+03	265800.00
0A5330	2017-07-11 17:05:00+03	29600.00
0A53D2	2017-07-04 22:55:00+03	67900.00
0A5406	2017-08-09 14:16:00+03	124300.00
0A5431	2017-07-22 03:11:00+03	24000.00
0A549C	2017-07-05 05:08:00+03	102100.00
0A54C1	2017-07-09 03:56:00+03	12000.00
0A54D5	2017-07-12 17:01:00+03	52100.00
0A550F	2017-07-11 05:49:00+03	84500.00
0A5512	2017-07-28 07:32:00+03	27400.00
0A551F	2017-08-11 19:09:00+03	664200.00
0A5547	2017-08-13 16:13:00+03	136800.00
0A5566	2017-07-22 02:25:00+03	73600.00
0A556F	2017-07-15 00:13:00+03	26800.00
0A5572	2017-07-11 16:20:00+03	56600.00
0A557C	2017-07-15 02:38:00+03	87100.00
0A55C7	2017-06-28 18:44:00+03	70700.00
0A55C8	2017-08-04 18:00:00+03	56000.00
0A5646	2017-07-30 18:00:00+03	123000.00
0A5665	2017-07-07 00:34:00+03	75600.00
0A566A	2017-08-02 08:01:00+03	14000.00
0A569C	2017-08-03 03:43:00+03	78300.00
0A56AB	2017-07-01 01:41:00+03	95200.00
0A56D4	2017-07-07 15:10:00+03	25200.00
0A56EB	2017-08-08 16:15:00+03	241400.00
0A5727	2017-07-18 09:50:00+03	94800.00
0A5759	2017-08-13 07:28:00+03	28800.00
0A578B	2017-07-17 17:21:00+03	6700.00
0A5802	2017-08-05 00:37:00+03	415100.00
0A5805	2017-08-08 09:21:00+03	67000.00
0A58CC	2017-07-11 05:47:00+03	14400.00
0A59C6	2017-08-12 23:32:00+03	47200.00
0A5A18	2017-07-31 05:30:00+03	44600.00
0A5A3A	2017-07-05 03:35:00+03	265800.00
0A5A64	2017-08-15 03:00:00+03	20000.00
0A5A91	2017-08-06 09:49:00+03	59800.00
0A5ACD	2017-07-04 23:44:00+03	23600.00
0A5B74	2017-08-15 08:39:00+03	56600.00
0A5B92	2017-08-11 09:07:00+03	116900.00
0A5BA7	2017-07-19 11:32:00+03	25400.00
0A5BD4	2017-08-09 00:49:00+03	28000.00
0A5C48	2017-07-28 04:38:00+03	27700.00
0A5C58	2017-08-03 08:09:00+03	153700.00
0A5C8F	2017-07-05 09:45:00+03	99200.00
0A5CEA	2017-07-30 07:55:00+03	46000.00
0A5D1C	2017-08-06 15:02:00+03	65900.00
0A5D6C	2017-08-06 01:16:00+03	21600.00
0A5DA2	2017-08-09 20:24:00+03	56000.00
0A5EC6	2017-07-10 20:17:00+03	38500.00
0A5F04	2017-08-11 22:43:00+03	54500.00
0A5F15	2017-07-25 13:26:00+03	56000.00
0A5FB2	2017-08-13 23:07:00+03	136200.00
0A5FD9	2017-07-27 08:32:00+03	69500.00
0A5FFF	2017-07-12 05:48:00+03	67600.00
0A6019	2017-08-10 01:54:00+03	25200.00
0A6060	2017-07-22 05:23:00+03	81600.00
0A60D1	2017-07-25 12:44:00+03	289800.00
0A610C	2017-08-09 16:06:00+03	54300.00
0A6119	2017-08-12 12:35:00+03	263200.00
0A61E8	2017-07-27 17:16:00+03	35200.00
0A6267	2017-08-01 22:01:00+03	19500.00
0A626E	2017-08-14 01:22:00+03	69500.00
0A627D	2017-08-08 11:58:00+03	72800.00
0A6282	2017-07-25 15:09:00+03	62900.00
0A62C8	2017-07-28 04:04:00+03	49500.00
0A6320	2017-07-13 18:57:00+03	55000.00
0A6397	2017-07-16 16:18:00+03	13800.00
0A6423	2017-07-06 03:51:00+03	55800.00
0A6462	2017-07-05 06:15:00+03	35600.00
0A64AB	2017-07-10 14:22:00+03	40800.00
0A64BE	2017-07-03 07:26:00+03	25100.00
0A64D3	2017-08-13 08:21:00+03	27200.00
0A650F	2017-08-05 15:38:00+03	399600.00
0A651D	2017-08-09 05:20:00+03	95200.00
0A652A	2017-07-29 00:50:00+03	100600.00
0A6530	2017-07-09 05:30:00+03	305500.00
0A655B	2017-08-14 09:28:00+03	38300.00
0A658B	2017-07-15 05:43:00+03	38800.00
0A658D	2017-08-06 22:10:00+03	8400.00
0A65C7	2017-07-01 00:10:00+03	83000.00
0A65D4	2017-08-02 00:35:00+03	54500.00
0A6606	2017-07-26 07:01:00+03	98400.00
0A6628	2017-08-04 14:33:00+03	53500.00
0A662A	2017-07-16 12:05:00+03	83800.00
0A6687	2017-08-09 11:32:00+03	28000.00
0A66F3	2017-07-05 11:06:00+03	124200.00
0A670B	2017-07-25 19:26:00+03	189800.00
0A671A	2017-08-09 11:56:00+03	90800.00
0A675A	2017-08-15 13:21:00+03	46300.00
0A6781	2017-08-05 21:45:00+03	246000.00
0A68BD	2017-07-04 21:34:00+03	58600.00
0A68C9	2017-07-06 05:02:00+03	92800.00
0A68D4	2017-06-29 22:07:00+03	100600.00
0A68E9	2017-08-13 12:19:00+03	229900.00
0A6969	2017-08-12 15:29:00+03	111700.00
0A6971	2017-07-15 20:14:00+03	28000.00
0A6976	2017-08-03 20:00:00+03	78300.00
0A69FA	2017-07-29 06:51:00+03	44500.00
0A6A2A	2017-07-30 20:04:00+03	209900.00
0A6A88	2017-07-24 21:12:00+03	68800.00
0A6AD6	2017-07-20 13:41:00+03	53400.00
0A6B39	2017-08-02 00:27:00+03	133200.00
0A6B5A	2017-07-04 15:27:00+03	23200.00
0A6B79	2017-07-02 23:15:00+03	47800.00
0A6B7F	2017-07-31 17:25:00+03	179300.00
0A6C0F	2017-07-13 15:07:00+03	170000.00
0A6CB0	2017-07-16 03:34:00+03	48700.00
0A6CBF	2017-08-02 19:09:00+03	24000.00
0A6CDC	2017-07-21 08:19:00+03	69500.00
0A6CEB	2017-08-01 17:31:00+03	202000.00
0A6D3D	2017-07-11 19:05:00+03	29600.00
0A6D5F	2017-07-25 18:19:00+03	14400.00
0A6DAA	2017-07-04 22:49:00+03	43200.00
0A6E14	2017-07-31 15:29:00+03	43100.00
0A6E6F	2017-07-16 13:44:00+03	136200.00
0A6E76	2017-08-13 02:49:00+03	7200.00
0A6EDB	2017-07-25 07:04:00+03	56000.00
0A6EFF	2017-07-15 02:34:00+03	135200.00
0A6F02	2017-06-30 02:27:00+03	52000.00
0A6F41	2017-08-07 17:53:00+03	75600.00
0A6F46	2017-07-11 06:26:00+03	69500.00
0A7048	2017-07-14 23:50:00+03	14000.00
0A70DD	2017-07-23 05:00:00+03	23600.00
0A7106	2017-06-26 22:51:00+03	54000.00
0A7198	2017-08-09 21:00:00+03	64800.00
0A71E7	2017-07-05 05:45:00+03	8000.00
0A7216	2017-07-27 15:18:00+03	46000.00
0A7236	2017-07-09 01:27:00+03	23200.00
0A7245	2017-07-28 21:28:00+03	77200.00
0A7262	2017-08-13 05:44:00+03	93400.00
0A72DC	2017-08-08 03:23:00+03	49100.00
0A72DE	2017-08-14 19:34:00+03	101800.00
0A7301	2017-07-02 16:27:00+03	6000.00
0A7388	2017-08-12 16:40:00+03	85600.00
0A73CF	2017-07-14 14:19:00+03	11800.00
0A73E7	2017-07-06 10:35:00+03	18900.00
0A73ED	2017-07-16 01:52:00+03	18000.00
0A740B	2017-07-21 18:02:00+03	132800.00
0A7419	2017-07-10 18:47:00+03	14000.00
0A7424	2017-08-08 18:25:00+03	98000.00
0A747B	2017-07-13 17:03:00+03	54800.00
0A7480	2017-07-15 21:46:00+03	12600.00
0A7485	2017-07-15 19:48:00+03	126500.00
0A7488	2017-08-09 10:03:00+03	57500.00
0A748D	2017-07-26 18:32:00+03	173200.00
0A74AA	2017-07-12 11:52:00+03	31400.00
0A74E7	2017-08-04 03:41:00+03	169900.00
0A7575	2017-07-16 08:37:00+03	261500.00
0A75AE	2017-08-06 15:20:00+03	15000.00
0A75D9	2017-07-14 17:22:00+03	56000.00
0A7637	2017-08-08 01:17:00+03	24400.00
0A7696	2017-07-27 15:11:00+03	31400.00
0A76BD	2017-08-02 10:47:00+03	25200.00
0A7710	2017-07-22 13:11:00+03	40800.00
0A786A	2017-08-09 19:36:00+03	62800.00
0A7881	2017-08-06 22:33:00+03	14000.00
0A78D5	2017-08-05 18:09:00+03	21800.00
0A7947	2017-08-13 19:18:00+03	84000.00
0A7996	2017-07-20 08:50:00+03	192200.00
0A79E6	2017-07-10 04:49:00+03	107700.00
0A7A13	2017-07-30 22:07:00+03	13400.00
0A7A5A	2017-07-10 04:34:00+03	272400.00
0A7A81	2017-07-31 13:56:00+03	48500.00
0A7A97	2017-07-12 21:30:00+03	17800.00
0A7AF8	2017-08-15 02:52:00+03	55800.00
0A7B2F	2017-08-04 09:01:00+03	64800.00
0A7B53	2017-08-13 23:30:00+03	615000.00
0A7B64	2017-07-23 21:03:00+03	117000.00
0A7B69	2017-07-25 19:33:00+03	168000.00
0A7B76	2017-08-03 06:16:00+03	47100.00
0A7B9D	2017-07-24 02:30:00+03	122700.00
0A7BF7	2017-08-14 17:40:00+03	70800.00
0A7C1E	2017-08-15 12:32:00+03	35900.00
0A7C3F	2017-07-31 09:09:00+03	64200.00
0A7CB6	2017-07-24 10:21:00+03	101700.00
0A7CEA	2017-07-16 16:11:00+03	56600.00
0A7D4B	2017-08-03 09:06:00+03	28300.00
0A7D4C	2017-07-18 15:16:00+03	48800.00
0A7D71	2017-08-09 10:48:00+03	82600.00
0A7D7C	2017-08-13 19:32:00+03	58200.00
0A7DA7	2017-08-13 03:42:00+03	25200.00
0A7DB3	2017-07-08 06:56:00+03	82800.00
0A7E12	2017-07-14 18:19:00+03	57600.00
0A7E3D	2017-08-10 06:07:00+03	229000.00
0A7E60	2017-08-03 21:10:00+03	92800.00
0A7EAC	2017-08-15 13:50:00+03	26000.00
0A7EC0	2017-07-14 04:24:00+03	120700.00
0A7F4B	2017-08-09 06:44:00+03	28000.00
0A7F74	2017-08-03 00:49:00+03	372600.00
0A7F78	2017-08-12 16:35:00+03	260300.00
0A8002	2017-07-24 03:40:00+03	177200.00
0A8016	2017-07-19 23:01:00+03	22400.00
0A802B	2017-07-13 22:30:00+03	191600.00
0A8097	2017-07-28 02:57:00+03	31100.00
0A80FE	2017-08-10 16:36:00+03	28000.00
0A812F	2017-08-04 20:04:00+03	34000.00
0A813C	2017-08-02 14:52:00+03	38800.00
0A81AB	2017-07-07 06:17:00+03	40800.00
0A8203	2017-08-01 13:20:00+03	80300.00
0A8228	2017-07-04 06:14:00+03	67900.00
0A826C	2017-07-07 04:55:00+03	87100.00
0A8306	2017-07-26 08:15:00+03	135600.00
0A8338	2017-07-27 14:14:00+03	99200.00
0A83CC	2017-07-10 16:15:00+03	67700.00
0A83E2	2017-08-05 00:29:00+03	40500.00
0A83E9	2017-08-10 17:07:00+03	78800.00
0A8420	2017-07-23 17:51:00+03	28000.00
0A843B	2017-07-15 18:16:00+03	84000.00
0A847A	2017-07-13 14:02:00+03	21800.00
0A84D7	2017-07-13 12:29:00+03	59700.00
0A8529	2017-08-13 13:55:00+03	93900.00
0A8561	2017-08-15 04:18:00+03	96400.00
0A865E	2017-07-13 17:55:00+03	23200.00
0A86C8	2017-07-31 23:33:00+03	62700.00
0A8783	2017-07-06 17:02:00+03	111600.00
0A878B	2017-07-13 22:39:00+03	32700.00
0A87F7	2017-07-28 06:44:00+03	24400.00
0A885F	2017-07-29 10:52:00+03	136700.00
0A88BB	2017-07-24 02:05:00+03	289500.00
0A8914	2017-07-31 04:35:00+03	28600.00
0A8917	2017-07-25 22:47:00+03	28300.00
0A8942	2017-08-11 08:05:00+03	45200.00
0A895B	2017-07-26 17:36:00+03	22000.00
0A898E	2017-07-05 19:34:00+03	73500.00
0A89B1	2017-07-03 20:19:00+03	123000.00
0A89D6	2017-08-09 18:03:00+03	119500.00
0A89DD	2017-08-03 14:15:00+03	57600.00
0A8A03	2017-07-24 07:51:00+03	102100.00
0A8A3B	2017-08-06 14:27:00+03	54800.00
0A8A75	2017-08-01 07:22:00+03	101900.00
0A8B93	2017-07-08 08:56:00+03	210800.00
0A8BA9	2017-08-13 22:06:00+03	99700.00
0A8BB7	2017-07-16 13:03:00+03	270700.00
0A8BD0	2017-07-17 20:48:00+03	167900.00
0A8C12	2017-08-07 21:05:00+03	59800.00
0A8C21	2017-08-10 13:23:00+03	55800.00
0A8C4A	2017-07-11 01:50:00+03	58000.00
0A8D90	2017-07-18 13:47:00+03	102100.00
0A8DBA	2017-07-22 16:24:00+03	54300.00
0A8DDE	2017-08-15 12:49:00+03	195400.00
0A8DF7	2017-07-09 21:48:00+03	32800.00
0A8E02	2017-07-15 19:41:00+03	40000.00
0A8E5D	2017-07-08 14:23:00+03	20200.00
0A8EAA	2017-07-19 14:54:00+03	67600.00
0A8EB6	2017-07-21 03:53:00+03	52200.00
0A8F3E	2017-08-01 09:35:00+03	75300.00
0A8F40	2017-07-09 15:02:00+03	86800.00
0A8F74	2017-07-24 23:06:00+03	56000.00
0A8F88	2017-07-07 12:34:00+03	27300.00
0A8FC0	2017-07-26 01:24:00+03	399300.00
0A9011	2017-07-04 21:44:00+03	160700.00
0A9092	2017-08-13 06:11:00+03	46000.00
0A90A0	2017-07-04 04:41:00+03	28000.00
0A90C6	2017-07-22 23:06:00+03	25400.00
0A9112	2017-08-11 12:40:00+03	150300.00
0A92BA	2017-07-02 21:09:00+03	72800.00
0A9327	2017-07-30 23:35:00+03	35200.00
0A9356	2017-07-25 21:23:00+03	55500.00
0A9380	2017-07-05 21:40:00+03	28800.00
0A93AF	2017-08-05 20:05:00+03	175800.00
0A93DF	2017-07-10 05:34:00+03	69500.00
0A9428	2017-07-16 15:47:00+03	258400.00
0A9464	2017-07-03 03:23:00+03	42800.00
0A946C	2017-08-02 10:22:00+03	52300.00
0A94B0	2017-06-30 01:51:00+03	38400.00
0A950A	2017-06-30 22:40:00+03	59600.00
0A9510	2017-08-01 20:18:00+03	93900.00
0A9573	2017-07-03 03:34:00+03	61900.00
0A9636	2017-08-14 14:36:00+03	10600.00
0A9641	2017-07-16 08:37:00+03	124200.00
0A9668	2017-07-25 05:26:00+03	39200.00
0A967E	2017-07-13 09:10:00+03	46000.00
0A96DC	2017-08-10 02:44:00+03	46800.00
0A96F8	2017-08-06 05:57:00+03	48300.00
0A970B	2017-06-29 05:54:00+03	55800.00
0A977C	2017-07-18 04:17:00+03	96200.00
0A97A7	2017-07-05 07:02:00+03	61500.00
0A97AC	2017-08-12 05:52:00+03	96800.00
0A983C	2017-07-18 17:43:00+03	96200.00
0A9857	2017-07-29 23:06:00+03	240900.00
0A9881	2017-08-10 11:51:00+03	71100.00
0A9884	2017-07-10 20:44:00+03	135600.00
0A988E	2017-08-13 07:39:00+03	47600.00
0A98A0	2017-07-26 06:14:00+03	31100.00
0A98DA	2017-08-12 04:31:00+03	43800.00
0A98DB	2017-07-30 02:48:00+03	35800.00
0A98FF	2017-07-28 15:53:00+03	7400.00
0A9916	2017-07-13 02:40:00+03	92800.00
0A9942	2017-08-06 02:20:00+03	50200.00
0A99B9	2017-07-25 11:42:00+03	369000.00
0A99D2	2017-07-24 22:17:00+03	51900.00
0A99E7	2017-07-24 17:30:00+03	75300.00
0A9A8F	2017-07-31 15:53:00+03	273600.00
0A9ACC	2017-07-17 01:46:00+03	23600.00
0A9ACE	2017-07-06 09:21:00+03	174600.00
0A9AD3	2017-08-07 08:02:00+03	408500.00
0A9B59	2017-07-13 05:37:00+03	67700.00
0A9B5F	2017-08-08 19:39:00+03	46000.00
0A9BA7	2017-07-15 07:31:00+03	47400.00
0A9BBA	2017-07-15 07:50:00+03	135600.00
0A9BBF	2017-06-30 13:52:00+03	123700.00
0A9BC1	2017-07-02 18:19:00+03	46200.00
0A9BFE	2017-08-13 08:42:00+03	59800.00
0A9C03	2017-07-20 18:21:00+03	6700.00
0A9C4B	2017-07-31 13:14:00+03	27200.00
0A9C8E	2017-07-18 14:51:00+03	62100.00
0A9C91	2017-07-23 23:05:00+03	42700.00
0A9CE5	2017-07-28 23:46:00+03	20100.00
0A9CEE	2017-07-17 06:01:00+03	90400.00
0A9CF7	2017-07-28 22:11:00+03	55000.00
0A9D42	2017-07-27 22:36:00+03	44000.00
0A9DCC	2017-07-11 02:54:00+03	6000.00
0A9E6D	2017-08-10 09:51:00+03	38500.00
0A9EBF	2017-08-05 15:52:00+03	99200.00
0A9F16	2017-07-19 01:24:00+03	47000.00
0A9F30	2017-08-02 18:53:00+03	125200.00
0A9F5A	2017-07-16 15:20:00+03	37400.00
0A9F8D	2017-07-01 18:27:00+03	40800.00
0A9FBE	2017-07-31 12:41:00+03	211100.00
0AA00F	2017-08-14 09:41:00+03	28000.00
0AA044	2017-08-13 20:29:00+03	31100.00
0AA052	2017-07-31 17:33:00+03	51600.00
0AA055	2017-07-11 22:31:00+03	67500.00
0AA07A	2017-07-10 18:09:00+03	125000.00
0AA111	2017-08-12 00:24:00+03	37900.00
0AA138	2017-07-01 01:50:00+03	112000.00
0AA178	2017-07-05 22:18:00+03	62800.00
0AA188	2017-07-03 12:51:00+03	16400.00
0AA1F2	2017-08-06 21:47:00+03	103200.00
0AA229	2017-07-07 17:39:00+03	85300.00
0AA27E	2017-08-09 01:05:00+03	55800.00
0AA295	2017-08-15 08:13:00+03	52700.00
0AA2AA	2017-07-11 20:56:00+03	135400.00
0AA2E3	2017-08-14 14:28:00+03	40600.00
0AA345	2017-07-04 19:00:00+03	44000.00
0AA3DF	2017-07-19 19:49:00+03	55800.00
0AA41E	2017-08-10 21:30:00+03	59200.00
0AA439	2017-08-03 13:05:00+03	73500.00
0AA4BD	2017-08-07 20:25:00+03	126900.00
0AA500	2017-07-23 03:39:00+03	78300.00
0AA584	2017-07-28 20:26:00+03	136200.00
0AA586	2017-07-12 05:21:00+03	161800.00
0AA5A2	2017-07-29 01:25:00+03	67000.00
0AA5A5	2017-08-05 10:18:00+03	50000.00
0AA5AA	2017-07-17 06:11:00+03	25600.00
0AA5D1	2017-07-21 23:27:00+03	49800.00
0AA5DB	2017-08-11 18:16:00+03	28800.00
0AA5EB	2017-07-20 21:20:00+03	93900.00
0AA62C	2017-08-15 07:35:00+03	56000.00
0AA635	2017-08-05 21:10:00+03	65900.00
0AA6B3	2017-08-10 17:17:00+03	112000.00
0AA770	2017-08-13 06:13:00+03	15800.00
0AA79F	2017-08-07 05:11:00+03	70700.00
0AA7B1	2017-07-26 10:45:00+03	199600.00
0AA847	2017-08-08 14:40:00+03	55500.00
0AA853	2017-07-24 14:48:00+03	89400.00
0AA869	2017-08-11 03:54:00+03	18000.00
0AA873	2017-07-13 07:27:00+03	8000.00
0AA888	2017-08-04 03:54:00+03	36000.00
0AA8A6	2017-07-27 21:16:00+03	14400.00
0AA8E6	2017-07-09 15:48:00+03	18600.00
0AA96E	2017-07-23 18:30:00+03	167500.00
0AA9B8	2017-08-06 03:49:00+03	28000.00
0AA9CA	2017-08-11 11:02:00+03	10600.00
0AAA52	2017-07-19 00:18:00+03	37900.00
0AAAC3	2017-08-14 08:46:00+03	36000.00
0AAAEF	2017-07-19 22:45:00+03	23400.00
0AAB1B	2017-08-14 01:11:00+03	57500.00
0AAB98	2017-07-18 05:17:00+03	38600.00
0AABD6	2017-07-09 09:40:00+03	99600.00
0AABDF	2017-07-05 14:04:00+03	88500.00
0AABEC	2017-08-12 08:20:00+03	6000.00
0AABF7	2017-08-06 01:05:00+03	103400.00
0AAC1A	2017-07-06 10:27:00+03	492000.00
0AAC3E	2017-07-25 11:59:00+03	90600.00
0AAC61	2017-08-01 09:54:00+03	35200.00
0AACCD	2017-07-01 21:01:00+03	20200.00
0AACDB	2017-08-08 13:27:00+03	48300.00
0AAD30	2017-07-13 01:52:00+03	48800.00
0AADD9	2017-08-14 06:02:00+03	133200.00
0AADE4	2017-07-28 04:04:00+03	147400.00
0AAE0A	2017-07-01 08:42:00+03	88800.00
0AAE0E	2017-08-03 11:21:00+03	66600.00
0AAE5B	2017-07-24 18:19:00+03	134800.00
0AAEAA	2017-07-10 17:22:00+03	14000.00
0AAEAD	2017-07-23 10:01:00+03	70600.00
0AAEFD	2017-07-15 18:59:00+03	73300.00
0AAF09	2017-08-15 14:07:00+03	130800.00
0AAFAE	2017-07-12 01:49:00+03	75700.00
0AAFB7	2017-07-14 13:30:00+03	72400.00
0AB051	2017-06-30 14:37:00+03	6800.00
0AB089	2017-07-13 09:48:00+03	85700.00
0AB0BB	2017-08-06 21:34:00+03	56000.00
0AB1A9	2017-08-12 14:31:00+03	74000.00
0AB1CC	2017-07-19 10:46:00+03	220800.00
0AB1F2	2017-07-23 09:46:00+03	44500.00
0AB278	2017-07-29 22:32:00+03	12000.00
0AB2A1	2017-06-29 21:49:00+03	22000.00
0AB2AA	2017-07-20 04:29:00+03	58000.00
0AB2DA	2017-07-17 00:05:00+03	6600.00
0AB368	2017-06-30 13:30:00+03	85000.00
0AB3DE	2017-08-12 06:12:00+03	23200.00
0AB411	2017-08-11 11:04:00+03	32800.00
0AB457	2017-06-29 02:54:00+03	113200.00
0AB45D	2017-06-30 18:51:00+03	36800.00
0AB48C	2017-07-03 19:40:00+03	66600.00
0AB4D0	2017-07-25 08:44:00+03	36200.00
0AB52E	2017-07-27 08:21:00+03	170000.00
0AB54F	2017-07-18 15:17:00+03	32800.00
0AB556	2017-07-11 23:18:00+03	128800.00
0AB55B	2017-08-01 00:24:00+03	265700.00
0AB634	2017-08-10 14:38:00+03	32200.00
0AB663	2017-07-08 17:52:00+03	55800.00
0AB678	2017-07-18 17:22:00+03	98400.00
0AB712	2017-07-25 14:31:00+03	23600.00
0AB71B	2017-08-13 19:58:00+03	64800.00
0AB757	2017-07-06 09:42:00+03	26000.00
0AB798	2017-07-18 16:08:00+03	26800.00
0AB87C	2017-07-09 19:57:00+03	61500.00
0AB918	2017-08-04 05:53:00+03	56000.00
0AB948	2017-07-11 11:08:00+03	186900.00
0AB9B7	2017-07-07 07:55:00+03	85000.00
0AB9C2	2017-08-12 19:50:00+03	46300.00
0AB9EE	2017-07-21 22:16:00+03	85000.00
0ABA76	2017-08-04 04:44:00+03	242300.00
0ABA81	2017-08-02 21:26:00+03	286100.00
0ABAED	2017-08-08 11:34:00+03	52300.00
0ABB81	2017-07-27 05:43:00+03	34000.00
0ABBFC	2017-07-06 03:52:00+03	136200.00
0ABC5B	2017-07-20 18:16:00+03	116900.00
0ABCCA	2017-07-09 23:19:00+03	68000.00
0ABD25	2017-07-06 21:10:00+03	39600.00
0ABD84	2017-08-04 14:09:00+03	28000.00
0ABDB5	2017-08-12 13:12:00+03	20800.00
0ABDC2	2017-06-24 07:59:00+03	59100.00
0ABE0E	2017-08-15 01:24:00+03	46200.00
0ABE36	2017-08-13 01:31:00+03	136800.00
0ABE60	2017-07-05 23:27:00+03	52300.00
0ABE65	2017-07-22 04:03:00+03	46000.00
0ABE9A	2017-07-10 12:18:00+03	68800.00
0ABEA7	2017-08-13 09:17:00+03	103000.00
0ABEC7	2017-06-27 16:57:00+03	26000.00
0ABED7	2017-07-21 17:35:00+03	66600.00
0ABEE0	2017-07-13 03:34:00+03	79600.00
0ABEF6	2017-07-25 23:32:00+03	6700.00
0ABF30	2017-08-08 01:59:00+03	46900.00
0ABF70	2017-08-07 17:15:00+03	56000.00
0ABF95	2017-07-06 06:56:00+03	88800.00
0AC020	2017-07-25 10:06:00+03	13400.00
0AC028	2017-07-19 12:50:00+03	64500.00
0AC046	2017-07-27 09:55:00+03	91600.00
0AC04F	2017-07-03 14:23:00+03	51800.00
0AC076	2017-08-12 21:06:00+03	154400.00
0AC0AF	2017-06-25 20:11:00+03	28200.00
0AC0B8	2017-07-17 13:14:00+03	13400.00
0AC0C0	2017-08-06 21:53:00+03	375800.00
0AC179	2017-07-29 21:01:00+03	82900.00
0AC1AA	2017-08-04 01:30:00+03	39000.00
0AC1D1	2017-07-30 05:35:00+03	149200.00
0AC1D2	2017-08-15 09:33:00+03	123000.00
0AC1EE	2017-08-09 03:58:00+03	38300.00
0AC213	2017-07-25 01:58:00+03	160200.00
0AC253	2017-08-13 18:57:00+03	14800.00
0AC349	2017-08-08 06:24:00+03	68800.00
0AC3DB	2017-07-22 06:43:00+03	76600.00
0AC44C	2017-08-10 19:01:00+03	154400.00
0AC49D	2017-07-02 03:55:00+03	21800.00
0AC4C3	2017-08-05 23:28:00+03	28800.00
0AC4FA	2017-07-19 19:04:00+03	39400.00
0AC503	2017-07-30 12:02:00+03	39400.00
0AC52A	2017-07-23 02:10:00+03	101200.00
0AC545	2017-07-08 14:56:00+03	93800.00
0AC55E	2017-08-04 17:10:00+03	287500.00
0AC59E	2017-07-20 00:53:00+03	18900.00
0AC667	2017-08-03 04:28:00+03	76800.00
0AC688	2017-07-16 07:17:00+03	29600.00
0AC6B4	2017-07-02 21:02:00+03	75600.00
0AC7B3	2017-07-10 06:48:00+03	83400.00
0AC7E5	2017-08-15 02:57:00+03	43600.00
0AC84E	2017-07-16 20:23:00+03	189800.00
0AC935	2017-07-28 07:56:00+03	7800.00
0ACA3D	2017-08-14 04:05:00+03	34000.00
0ACA5C	2017-07-28 12:56:00+03	39200.00
0ACB35	2017-08-04 06:37:00+03	100000.00
0ACBA3	2017-07-15 03:31:00+03	28800.00
0ACC01	2017-08-09 16:04:00+03	49500.00
0ACC6E	2017-07-07 17:01:00+03	12700.00
0ACC8E	2017-07-25 04:34:00+03	58600.00
0ACCA1	2017-08-01 04:51:00+03	46400.00
0ACCC3	2017-07-01 00:56:00+03	81600.00
0ACD53	2017-07-26 22:25:00+03	66600.00
0ACDD0	2017-07-08 22:26:00+03	250800.00
0ACDD9	2017-07-13 09:32:00+03	38400.00
0ACDE3	2017-07-28 01:27:00+03	199400.00
0ACDEE	2017-07-22 04:51:00+03	22000.00
0ACDFE	2017-07-31 18:37:00+03	14000.00
0ACE76	2017-07-02 01:48:00+03	22000.00
0ACE89	2017-07-13 06:36:00+03	26800.00
0ACE8B	2017-07-20 21:03:00+03	23600.00
0ACEDB	2017-07-06 15:04:00+03	112000.00
0ACEF6	2017-07-09 06:21:00+03	56000.00
0ACF1B	2017-08-11 06:59:00+03	77200.00
0ACF38	2017-06-30 03:31:00+03	88200.00
0ACFB6	2017-07-26 01:30:00+03	285700.00
0ACFF0	2017-06-29 18:30:00+03	270800.00
0AD03C	2017-07-15 17:35:00+03	84100.00
0AD04F	2017-08-04 11:15:00+03	6800.00
0AD088	2017-08-04 08:35:00+03	115600.00
0AD0C8	2017-07-01 05:10:00+03	24400.00
0AD0D3	2017-08-12 03:23:00+03	75600.00
0AD164	2017-08-09 05:43:00+03	26000.00
0AD18D	2017-07-01 11:20:00+03	81700.00
0AD1A5	2017-08-01 04:16:00+03	28000.00
0AD2A0	2017-07-24 08:28:00+03	37200.00
0AD431	2017-08-12 03:40:00+03	20800.00
0AD435	2017-07-16 09:11:00+03	31400.00
0AD47B	2017-07-25 14:12:00+03	22000.00
0AD495	2017-07-25 08:59:00+03	71600.00
0AD608	2017-07-26 13:35:00+03	60400.00
0AD626	2017-08-09 22:25:00+03	23500.00
0AD62C	2017-07-30 09:33:00+03	76300.00
0AD6F1	2017-07-03 13:43:00+03	55600.00
0AD70E	2017-07-22 10:40:00+03	152200.00
0AD779	2017-08-15 12:22:00+03	62600.00
0AD7E5	2017-07-01 17:58:00+03	12600.00
0AD807	2017-07-01 11:17:00+03	90000.00
0AD84E	2017-08-14 02:41:00+03	54800.00
0AD855	2017-07-24 12:31:00+03	191400.00
0AD85A	2017-08-09 11:08:00+03	56000.00
0AD862	2017-07-08 15:06:00+03	46400.00
0AD8B1	2017-08-04 01:18:00+03	26000.00
0AD8B5	2017-08-11 03:21:00+03	18400.00
0AD8C7	2017-07-05 22:43:00+03	67800.00
0AD997	2017-08-10 16:34:00+03	135600.00
0ADA06	2017-08-12 09:57:00+03	58000.00
0ADA80	2017-07-07 22:13:00+03	10800.00
0ADAA0	2017-07-31 05:00:00+03	193700.00
0ADB38	2017-07-12 07:51:00+03	28000.00
0ADB59	2017-07-19 22:01:00+03	68400.00
0ADB7A	2017-07-20 07:17:00+03	12600.00
0ADBDF	2017-08-11 22:39:00+03	32800.00
0ADBF9	2017-08-07 06:40:00+03	47000.00
0ADC91	2017-08-01 07:13:00+03	57500.00
0ADC9A	2017-07-01 05:20:00+03	28000.00
0ADCB0	2017-08-11 00:49:00+03	52000.00
0ADCB8	2017-08-06 13:58:00+03	182300.00
0ADD00	2017-07-20 08:13:00+03	85700.00
0ADD82	2017-07-24 19:05:00+03	85600.00
0ADE1E	2017-08-15 05:02:00+03	74800.00
0ADE44	2017-08-13 14:41:00+03	69000.00
0ADE57	2017-07-28 06:04:00+03	6700.00
0ADE6F	2017-07-21 07:48:00+03	67500.00
0ADE91	2017-07-06 09:01:00+03	13800.00
0ADE98	2017-07-28 12:56:00+03	49100.00
0ADEB5	2017-08-08 23:17:00+03	40000.00
0ADEC7	2017-07-16 14:02:00+03	75300.00
0ADED5	2017-07-27 23:33:00+03	23200.00
0ADF4F	2017-07-21 02:07:00+03	55800.00
0ADF8B	2017-07-31 22:35:00+03	137600.00
0ADFCD	2017-07-14 20:05:00+03	15100.00
0ADFE1	2017-07-04 10:21:00+03	7400.00
0AE03E	2017-07-20 02:43:00+03	57500.00
0AE045	2017-07-04 07:58:00+03	28000.00
0AE096	2017-07-09 23:11:00+03	56000.00
0AE0D7	2017-07-31 16:47:00+03	66600.00
0AE0D9	2017-07-18 16:25:00+03	387300.00
0AE0DF	2017-07-15 23:25:00+03	32400.00
0AE168	2017-08-03 03:05:00+03	45200.00
0AE186	2017-07-28 20:24:00+03	14800.00
0AE1EB	2017-07-18 10:56:00+03	57500.00
0AE231	2017-08-02 11:41:00+03	39100.00
0AE257	2017-07-15 04:08:00+03	28800.00
0AE29D	2017-08-12 18:46:00+03	39500.00
0AE2A0	2017-08-07 05:49:00+03	95600.00
0AE2B7	2017-08-09 21:27:00+03	58000.00
0AE340	2017-07-27 23:18:00+03	383200.00
0AE353	2017-07-30 15:40:00+03	27200.00
0AE370	2017-07-28 14:12:00+03	57800.00
0AE3A8	2017-08-11 18:53:00+03	131800.00
0AE43B	2017-07-13 20:53:00+03	46400.00
0AE441	2017-08-10 08:51:00+03	100600.00
0AE4C8	2017-07-07 17:44:00+03	13400.00
0AE518	2017-08-10 04:34:00+03	66600.00
0AE531	2017-07-24 14:29:00+03	394800.00
0AE568	2017-07-04 05:36:00+03	94800.00
0AE58F	2017-07-07 14:46:00+03	38400.00
0AE59C	2017-07-22 22:34:00+03	51900.00
0AE645	2017-07-29 13:12:00+03	173900.00
0AE697	2017-07-31 07:17:00+03	26700.00
0AE6A5	2017-07-03 08:06:00+03	95200.00
0AE6B9	2017-08-11 19:44:00+03	135400.00
0AE6CF	2017-07-11 15:16:00+03	37900.00
0AE753	2017-07-06 13:31:00+03	9200.00
0AE756	2017-08-15 02:58:00+03	132800.00
0AE7CB	2017-08-08 02:35:00+03	119800.00
0AE7F9	2017-07-30 02:54:00+03	13800.00
0AE90A	2017-07-07 08:41:00+03	77600.00
0AE925	2017-08-02 21:07:00+03	40400.00
0AE963	2017-08-06 17:51:00+03	46400.00
0AE98A	2017-07-23 06:43:00+03	46000.00
0AE9C7	2017-07-21 12:25:00+03	54300.00
0AE9DF	2017-08-01 22:08:00+03	124200.00
0AEA0B	2017-07-05 13:47:00+03	37900.00
0AEA80	2017-07-24 20:27:00+03	26300.00
0AEAC7	2017-06-27 01:56:00+03	18000.00
0AEAF9	2017-07-28 22:44:00+03	115900.00
0AEB3A	2017-07-20 16:28:00+03	135200.00
0AEB6C	2017-07-20 00:16:00+03	45200.00
0AEBA0	2017-07-07 18:15:00+03	44800.00
0AEBBC	2017-07-07 04:39:00+03	175800.00
0AEC26	2017-07-21 00:31:00+03	28800.00
0AEC38	2017-07-02 16:00:00+03	26000.00
0AEC67	2017-07-08 16:47:00+03	131600.00
0AEC6B	2017-08-14 06:08:00+03	62800.00
0AEC8F	2017-07-09 00:05:00+03	73500.00
0AECAF	2017-07-11 06:30:00+03	39300.00
0AECD3	2017-07-07 21:27:00+03	80000.00
0AED1C	2017-07-03 20:24:00+03	25600.00
0AED5B	2017-07-16 11:21:00+03	92800.00
0AED62	2017-08-14 23:24:00+03	96300.00
0AED6C	2017-07-19 23:59:00+03	70600.00
0AEE04	2017-06-29 09:47:00+03	22000.00
0AEE24	2017-07-30 20:18:00+03	14400.00
0AEE42	2017-08-02 23:35:00+03	135200.00
0AEE5A	2017-07-13 16:06:00+03	86300.00
0AEE78	2017-07-31 20:26:00+03	270700.00
0AEEBB	2017-08-10 08:48:00+03	6000.00
0AEEC6	2017-08-11 07:54:00+03	81700.00
0AEFD5	2017-08-05 15:41:00+03	35200.00
0AF049	2017-08-01 11:14:00+03	28800.00
0AF0BC	2017-07-09 01:36:00+03	66000.00
0AF10B	2017-07-30 21:45:00+03	10600.00
0AF15B	2017-08-11 22:00:00+03	86900.00
0AF178	2017-06-29 12:31:00+03	32800.00
0AF1B9	2017-07-22 08:48:00+03	88000.00
0AF24B	2017-07-02 02:45:00+03	28800.00
0AF2B0	2017-08-01 07:19:00+03	54400.00
0AF39B	2017-07-08 07:52:00+03	38400.00
0AF3FB	2017-07-24 03:55:00+03	263200.00
0AF46D	2017-06-30 05:41:00+03	6000.00
0AF4EC	2017-07-15 04:47:00+03	132800.00
0AF4FA	2017-06-30 23:17:00+03	288900.00
0AF5DD	2017-08-14 14:28:00+03	142800.00
0AF67F	2017-07-12 15:16:00+03	129200.00
0AF6C5	2017-08-06 03:12:00+03	36200.00
0AF6C7	2017-07-19 18:44:00+03	92800.00
0AF6D6	2017-08-12 09:18:00+03	100000.00
0AF754	2017-08-08 09:52:00+03	24400.00
0AF7B0	2017-07-05 21:12:00+03	139500.00
0AF7FB	2017-08-05 16:30:00+03	52400.00
0AF848	2017-07-18 12:00:00+03	44700.00
0AF8A7	2017-07-04 19:27:00+03	20200.00
0AF93B	2017-08-02 04:13:00+03	38600.00
0AF96A	2017-08-08 00:41:00+03	23200.00
0AF98F	2017-07-18 04:05:00+03	46400.00
0AF9B5	2017-08-09 00:03:00+03	52800.00
0AF9CC	2017-07-04 11:50:00+03	32600.00
0AF9F5	2017-07-30 19:58:00+03	73500.00
0AFA62	2017-08-11 05:34:00+03	34100.00
0AFB45	2017-07-05 11:14:00+03	81800.00
0AFB55	2017-07-31 07:50:00+03	39800.00
0AFB57	2017-08-14 05:52:00+03	391800.00
0AFB5E	2017-07-25 18:35:00+03	78000.00
0AFBB2	2017-07-13 03:14:00+03	24300.00
0AFC14	2017-07-28 18:50:00+03	67200.00
0AFC65	2017-08-10 10:35:00+03	62800.00
0AFCCB	2017-07-23 23:41:00+03	12400.00
0AFCDA	2017-07-21 00:34:00+03	55700.00
0AFCF2	2017-07-08 08:52:00+03	139400.00
0AFD65	2017-08-07 01:41:00+03	87600.00
0AFD7C	2017-07-01 14:52:00+03	46400.00
0AFDAB	2017-07-14 18:13:00+03	58400.00
0AFEBF	2017-08-13 16:38:00+03	54400.00
0AFEC6	2017-07-04 02:56:00+03	29000.00
0AFEE6	2017-08-07 22:43:00+03	12800.00
0AFF58	2017-07-20 09:15:00+03	67200.00
0AFF7A	2017-07-06 12:32:00+03	187600.00
0AFFAE	2017-07-08 19:58:00+03	32400.00
0B0004	2017-06-27 02:23:00+03	26000.00
0B0006	2017-08-13 06:32:00+03	40100.00
0B0033	2017-07-12 04:19:00+03	138100.00
0B003F	2017-08-05 21:53:00+03	66600.00
0B0044	2017-07-04 12:49:00+03	72000.00
0B007D	2017-08-07 07:20:00+03	26000.00
0B00B9	2017-07-13 00:24:00+03	46700.00
0B00C2	2017-07-21 05:36:00+03	56900.00
0B012E	2017-08-11 05:38:00+03	135400.00
0B01E1	2017-07-24 22:48:00+03	56800.00
0B0251	2017-08-14 10:22:00+03	99200.00
0B0262	2017-07-29 00:40:00+03	6300.00
0B026A	2017-07-08 06:13:00+03	65900.00
0B026B	2017-08-11 20:48:00+03	94200.00
0B0302	2017-07-09 13:58:00+03	101500.00
0B03A7	2017-07-13 21:14:00+03	206100.00
0B03F7	2017-07-28 01:42:00+03	28000.00
0B0418	2017-08-08 15:56:00+03	44000.00
0B046E	2017-07-17 21:42:00+03	112000.00
0B04A6	2017-08-09 18:18:00+03	46800.00
0B052E	2017-07-22 03:45:00+03	45100.00
0B0555	2017-07-31 12:46:00+03	75300.00
0B057F	2017-07-02 09:22:00+03	155700.00
0B0592	2017-08-14 20:40:00+03	32300.00
0B05B7	2017-07-15 06:51:00+03	96800.00
0B05C9	2017-08-04 22:44:00+03	36200.00
0B05D2	2017-06-27 00:08:00+03	20000.00
0B0638	2017-07-24 13:51:00+03	133100.00
0B06AB	2017-08-02 02:14:00+03	119500.00
0B06B7	2017-07-24 06:22:00+03	52800.00
0B06FF	2017-08-14 10:42:00+03	47200.00
0B0768	2017-07-05 07:10:00+03	51000.00
0B07FC	2017-08-07 16:47:00+03	114700.00
0B0819	2017-07-10 05:49:00+03	124200.00
0B0868	2017-07-29 23:58:00+03	133200.00
0B08D8	2017-08-01 07:34:00+03	35700.00
0B0913	2017-07-24 14:38:00+03	123000.00
0B0974	2017-07-10 18:53:00+03	123900.00
0B0975	2017-08-15 14:53:00+03	271400.00
0B098E	2017-07-21 15:54:00+03	37900.00
0B0996	2017-08-06 15:08:00+03	91800.00
0B09E6	2017-07-10 07:57:00+03	81600.00
0B0A42	2017-08-14 12:02:00+03	156000.00
0B0AA5	2017-08-05 14:45:00+03	16400.00
0B0B1A	2017-08-05 16:46:00+03	47200.00
0B0B63	2017-08-07 21:49:00+03	39800.00
0B0B6F	2017-07-05 03:18:00+03	28000.00
0B0B72	2017-07-12 02:44:00+03	12600.00
0B0B83	2017-07-21 18:33:00+03	16400.00
0B0BDE	2017-07-21 02:43:00+03	97700.00
0B0C12	2017-07-16 01:43:00+03	52400.00
0B0C24	2017-07-04 11:42:00+03	137700.00
0B0C83	2017-07-14 14:36:00+03	233000.00
0B0C9C	2017-07-07 04:27:00+03	67200.00
0B0CA5	2017-07-06 20:22:00+03	85200.00
0B0D0A	2017-06-30 06:41:00+03	53600.00
0B0E05	2017-08-02 18:31:00+03	64300.00
0B0E22	2017-07-17 13:59:00+03	147700.00
0B0E63	2017-07-17 07:05:00+03	56000.00
0B0F67	2017-07-18 17:08:00+03	89700.00
0B0FF5	2017-07-03 17:44:00+03	32800.00
0B10E1	2017-07-31 16:44:00+03	11000.00
0B1107	2017-08-09 10:50:00+03	57500.00
0B11E6	2017-07-08 10:46:00+03	69500.00
0B1222	2017-08-13 13:14:00+03	73600.00
0B126C	2017-07-16 19:10:00+03	37900.00
0B1297	2017-08-06 10:33:00+03	26000.00
0B12AD	2017-07-30 16:15:00+03	26600.00
0B12E6	2017-07-17 04:49:00+03	35800.00
0B12EB	2017-07-16 20:28:00+03	53600.00
0B12F5	2017-07-10 21:38:00+03	92800.00
0B1360	2017-08-15 00:08:00+03	112000.00
0B13AE	2017-07-29 22:47:00+03	81600.00
0B13CB	2017-08-09 12:20:00+03	96800.00
0B13D8	2017-07-20 01:04:00+03	144400.00
0B13E9	2017-08-06 15:18:00+03	200200.00
0B1464	2017-07-22 07:16:00+03	191200.00
0B14CD	2017-07-27 19:48:00+03	187600.00
0B14E0	2017-07-25 05:16:00+03	19600.00
0B14EF	2017-08-10 07:43:00+03	48800.00
0B151A	2017-08-05 17:21:00+03	28800.00
0B1551	2017-07-14 19:05:00+03	16400.00
0B15E6	2017-08-03 04:53:00+03	102100.00
0B15F6	2017-07-19 16:52:00+03	24300.00
0B1632	2017-07-19 13:32:00+03	111600.00
0B1645	2017-07-27 06:57:00+03	70600.00
0B164F	2017-07-16 14:12:00+03	57400.00
0B1671	2017-07-03 05:16:00+03	102800.00
0B1675	2017-07-09 17:09:00+03	39300.00
0B1697	2017-07-19 08:44:00+03	154500.00
0B16FD	2017-07-28 12:35:00+03	60400.00
0B16FF	2017-07-11 02:07:00+03	416600.00
0B17FA	2017-07-13 19:30:00+03	167300.00
0B1814	2017-07-21 22:15:00+03	49200.00
0B1827	2017-08-10 17:02:00+03	28000.00
0B182B	2017-07-15 01:54:00+03	150600.00
0B1855	2017-07-03 06:36:00+03	112000.00
0B1879	2017-07-01 22:40:00+03	16400.00
0B18A8	2017-08-04 18:46:00+03	270000.00
0B18E1	2017-07-31 18:35:00+03	93900.00
0B196C	2017-07-05 12:04:00+03	40800.00
0B19CE	2017-07-17 12:20:00+03	60300.00
0B19E4	2017-07-13 05:59:00+03	38500.00
0B19ED	2017-08-07 18:23:00+03	129600.00
0B1A17	2017-07-02 06:08:00+03	27900.00
0B1A2C	2017-07-20 17:47:00+03	6300.00
0B1A4A	2017-08-10 18:26:00+03	24000.00
0B1AC7	2017-07-02 19:19:00+03	39800.00
0B1ADE	2017-07-04 11:12:00+03	47400.00
0B1B8B	2017-07-05 03:42:00+03	51200.00
0B1BF9	2017-08-10 06:57:00+03	93600.00
0B1C2C	2017-07-31 15:00:00+03	56100.00
0B1C85	2017-07-25 23:15:00+03	16000.00
0B1D39	2017-08-14 17:41:00+03	289800.00
0B1D5C	2017-07-29 01:09:00+03	75600.00
0B1D60	2017-08-08 00:57:00+03	43100.00
0B1DBA	2017-07-25 18:59:00+03	46200.00
0B1DD9	2017-07-20 10:55:00+03	107400.00
0B1E26	2017-07-25 01:37:00+03	79000.00
0B1E3E	2017-07-24 09:04:00+03	73600.00
0B1E5D	2017-07-24 02:36:00+03	60400.00
0B1EDA	2017-07-08 02:06:00+03	34100.00
0B1F3D	2017-07-09 01:10:00+03	62400.00
0B1F95	2017-07-27 22:05:00+03	12200.00
0B1FD1	2017-07-03 13:00:00+03	131100.00
0B20E5	2017-07-24 23:09:00+03	26200.00
0B20EC	2017-07-18 23:59:00+03	56000.00
0B2129	2017-08-10 19:45:00+03	399600.00
0B219E	2017-07-05 03:57:00+03	36000.00
0B21AF	2017-07-17 17:20:00+03	140900.00
0B21BA	2017-07-12 17:25:00+03	194000.00
0B2221	2017-07-05 21:49:00+03	28800.00
0B230E	2017-08-12 06:05:00+03	146300.00
0B231F	2017-08-04 19:27:00+03	340600.00
0B2322	2017-07-03 01:27:00+03	196800.00
0B232C	2017-07-03 08:42:00+03	195800.00
0B23BF	2017-08-11 14:28:00+03	47200.00
0B23DC	2017-07-09 18:45:00+03	14800.00
0B23E6	2017-08-09 01:42:00+03	28000.00
0B2440	2017-07-11 23:28:00+03	22000.00
0B2480	2017-07-26 00:06:00+03	75600.00
0B2491	2017-08-13 20:10:00+03	101500.00
0B24AB	2017-07-27 18:37:00+03	6600.00
0B2530	2017-07-22 02:14:00+03	96300.00
0B253D	2017-07-05 18:57:00+03	252200.00
0B253E	2017-08-13 00:26:00+03	67200.00
0B25AA	2017-08-12 08:13:00+03	677700.00
0B25C5	2017-07-04 08:41:00+03	378400.00
0B2660	2017-07-20 08:02:00+03	12600.00
0B2688	2017-07-02 21:28:00+03	66600.00
0B268F	2017-07-05 12:15:00+03	32800.00
0B2699	2017-07-25 21:26:00+03	59800.00
0B279A	2017-06-30 18:24:00+03	103000.00
0B27A1	2017-07-26 00:36:00+03	68600.00
0B2851	2017-08-01 10:41:00+03	269300.00
0B287F	2017-08-15 05:17:00+03	8000.00
0B28CE	2017-06-28 10:56:00+03	46300.00
0B2938	2017-07-08 01:45:00+03	72300.00
0B2986	2017-07-02 16:01:00+03	54800.00
0B2995	2017-08-01 22:18:00+03	299600.00
0B29B1	2017-07-25 16:09:00+03	48100.00
0B29DD	2017-07-25 05:44:00+03	43000.00
0B29F3	2017-07-26 01:44:00+03	248400.00
0B2A6C	2017-07-11 05:35:00+03	176400.00
0B2A81	2017-07-06 04:50:00+03	21800.00
0B2A87	2017-07-25 07:10:00+03	136800.00
0B2AF9	2017-08-12 01:13:00+03	186200.00
0B2B21	2017-07-21 12:33:00+03	23600.00
0B2B71	2017-07-10 12:16:00+03	25600.00
0B2B78	2017-07-27 06:04:00+03	28600.00
0B2BA7	2017-07-09 12:51:00+03	136200.00
0B2BD4	2017-08-09 05:06:00+03	19800.00
0B2BF2	2017-07-14 16:33:00+03	70200.00
0B2BFC	2017-08-09 09:39:00+03	95700.00
0B2C61	2017-07-09 06:17:00+03	147000.00
0B2C84	2017-07-22 00:46:00+03	174400.00
0B2CEF	2017-08-15 15:15:00+03	147000.00
0B2CF4	2017-07-04 05:36:00+03	112000.00
0B2D07	2017-08-07 08:25:00+03	45200.00
0B2D1E	2017-07-14 13:32:00+03	50300.00
0B2D3E	2017-07-02 07:37:00+03	27200.00
0B2D49	2017-07-28 20:52:00+03	35200.00
0B2DCB	2017-07-20 12:58:00+03	44000.00
0B2E05	2017-07-26 08:17:00+03	266400.00
0B2E0B	2017-08-13 09:37:00+03	120400.00
0B2E43	2017-07-10 22:23:00+03	26800.00
0B2E7E	2017-07-09 04:51:00+03	136200.00
0B2E97	2017-08-13 21:18:00+03	39800.00
0B2EAE	2017-08-10 07:27:00+03	81400.00
0B2EBD	2017-07-16 13:45:00+03	96100.00
0B2F63	2017-07-16 01:26:00+03	128800.00
0B2F80	2017-08-02 10:39:00+03	59800.00
0B2F8C	2017-08-07 22:44:00+03	146300.00
0B2F9C	2017-07-23 13:22:00+03	169900.00
0B2FA3	2017-08-11 02:03:00+03	18000.00
0B2FB4	2017-08-15 12:15:00+03	65900.00
0B2FDC	2017-08-04 18:38:00+03	12600.00
0B2FE2	2017-07-04 12:22:00+03	40000.00
0B2FE5	2017-07-29 15:43:00+03	181600.00
0B30B8	2017-07-11 05:58:00+03	13300.00
0B3143	2017-07-09 11:09:00+03	113600.00
0B31D0	2017-08-11 19:07:00+03	6000.00
0B31D7	2017-08-12 18:23:00+03	66600.00
0B31F6	2017-08-08 01:35:00+03	89700.00
0B321F	2017-06-24 17:18:00+03	70800.00
0B32BB	2017-08-11 16:37:00+03	23200.00
0B32BE	2017-08-07 07:56:00+03	111700.00
0B32CE	2017-07-19 10:54:00+03	10800.00
0B32DB	2017-07-14 14:37:00+03	26000.00
0B32E6	2017-07-31 18:38:00+03	89600.00
0B3363	2017-08-14 07:06:00+03	21200.00
0B33BD	2017-07-12 05:41:00+03	9800.00
0B3440	2017-07-27 16:34:00+03	6800.00
0B34A2	2017-07-06 00:46:00+03	192800.00
0B34CF	2017-07-05 21:21:00+03	28800.00
0B34DF	2017-07-18 15:22:00+03	210600.00
0B3506	2017-08-09 04:45:00+03	37600.00
0B3540	2017-08-15 01:13:00+03	53700.00
0B3559	2017-07-03 20:34:00+03	48800.00
0B3580	2017-07-14 02:31:00+03	68000.00
0B3586	2017-07-14 03:37:00+03	30600.00
0B358B	2017-07-11 23:22:00+03	125100.00
0B3598	2017-07-24 11:08:00+03	16400.00
0B363F	2017-07-15 01:28:00+03	56000.00
0B368D	2017-07-11 10:31:00+03	123000.00
0B36A3	2017-07-15 18:33:00+03	20400.00
0B36EB	2017-07-22 01:08:00+03	231600.00
0B3773	2017-08-01 19:08:00+03	44500.00
0B378C	2017-06-29 01:23:00+03	28800.00
0B37CC	2017-07-05 09:27:00+03	26800.00
0B381A	2017-07-18 03:00:00+03	37700.00
0B3851	2017-07-20 13:31:00+03	92900.00
0B38C6	2017-08-05 18:12:00+03	11600.00
0B38D4	2017-07-25 00:13:00+03	79900.00
0B3900	2017-07-24 05:26:00+03	84500.00
0B393B	2017-07-05 07:06:00+03	11300.00
0B3947	2017-07-18 05:34:00+03	123000.00
0B3948	2017-07-26 02:55:00+03	93700.00
0B3972	2017-07-22 04:42:00+03	135400.00
0B39FF	2017-08-01 14:06:00+03	18900.00
0B3A21	2017-07-08 21:02:00+03	110000.00
0B3A35	2017-07-30 00:48:00+03	89700.00
0B3A43	2017-07-24 21:03:00+03	56600.00
0B3AB3	2017-07-31 17:39:00+03	51800.00
0B3AFB	2017-07-05 16:14:00+03	271100.00
0B3B1D	2017-08-04 22:10:00+03	37800.00
0B3B48	2017-07-27 10:51:00+03	173200.00
0B3B85	2017-07-30 01:44:00+03	57400.00
0B3BA5	2017-07-24 07:54:00+03	88100.00
0B3C4B	2017-07-24 10:55:00+03	79400.00
0B3CC2	2017-08-05 03:55:00+03	136500.00
0B3D15	2017-08-03 13:09:00+03	55800.00
0B3D29	2017-07-16 00:12:00+03	75800.00
0B3E92	2017-07-31 09:26:00+03	38200.00
0B3F0F	2017-07-12 08:06:00+03	8200.00
0B3F72	2017-08-04 22:06:00+03	52100.00
0B3FE0	2017-07-20 08:32:00+03	43500.00
0B3FF5	2017-07-07 08:29:00+03	142400.00
0B3FFA	2017-08-09 09:05:00+03	347100.00
0B403D	2017-07-22 15:35:00+03	57300.00
0B40A3	2017-07-25 17:25:00+03	81700.00
0B40C6	2017-08-15 01:55:00+03	26800.00
0B40CE	2017-07-26 17:34:00+03	121700.00
0B40D8	2017-08-02 20:52:00+03	21800.00
0B416D	2017-07-18 06:39:00+03	46400.00
0B41B7	2017-07-20 12:25:00+03	174100.00
0B41D3	2017-08-04 10:20:00+03	119200.00
0B4206	2017-07-18 23:54:00+03	29600.00
0B426A	2017-07-11 10:10:00+03	112000.00
0B42AE	2017-07-25 00:19:00+03	53300.00
0B4339	2017-07-08 07:51:00+03	398500.00
0B435D	2017-08-05 23:20:00+03	17200.00
0B4366	2017-07-21 03:17:00+03	131100.00
0B4402	2017-07-03 12:38:00+03	22400.00
0B440B	2017-07-08 21:58:00+03	29600.00
0B442A	2017-07-30 19:35:00+03	17800.00
0B443F	2017-08-12 04:28:00+03	36200.00
0B448E	2017-07-21 20:48:00+03	229800.00
0B44AB	2017-07-10 13:06:00+03	41800.00
0B452E	2017-07-04 14:41:00+03	111600.00
0B455B	2017-07-23 04:29:00+03	24500.00
0B45DC	2017-07-11 08:05:00+03	50600.00
0B45E2	2017-07-17 00:22:00+03	27200.00
0B467A	2017-07-11 03:24:00+03	81900.00
0B4684	2017-08-09 03:38:00+03	86800.00
0B46A7	2017-07-24 11:26:00+03	123000.00
0B4705	2017-07-22 19:00:00+03	28800.00
0B471C	2017-08-07 09:00:00+03	65900.00
0B471D	2017-08-13 05:19:00+03	72400.00
0B473E	2017-08-09 13:25:00+03	133200.00
0B4749	2017-08-08 21:22:00+03	20200.00
0B4751	2017-07-23 01:18:00+03	205600.00
0B47A5	2017-08-05 18:25:00+03	24700.00
0B47E9	2017-08-14 07:58:00+03	115600.00
0B481C	2017-07-10 13:22:00+03	46300.00
0B4848	2017-07-21 05:22:00+03	25800.00
0B485C	2017-06-28 02:45:00+03	23600.00
0B48E7	2017-08-11 18:16:00+03	37200.00
0B48FA	2017-08-09 07:57:00+03	23400.00
0B4904	2017-07-20 06:26:00+03	46000.00
0B490D	2017-07-17 07:17:00+03	206700.00
0B494D	2017-08-05 08:34:00+03	46900.00
0B49DA	2017-07-22 21:29:00+03	6700.00
0B4A29	2017-07-10 23:19:00+03	40000.00
0B4AFC	2017-08-11 17:51:00+03	57400.00
0B4B45	2017-06-29 02:56:00+03	14800.00
0B4B5E	2017-08-10 18:39:00+03	200800.00
0B4B6C	2017-07-23 10:57:00+03	167400.00
0B4B97	2017-08-01 14:47:00+03	118600.00
0B4C0F	2017-07-07 10:24:00+03	26000.00
0B4C63	2017-08-09 08:15:00+03	25800.00
0B4C82	2017-08-12 02:55:00+03	31100.00
0B4C8C	2017-07-14 10:17:00+03	289300.00
0B4CF1	2017-07-06 06:11:00+03	133700.00
0B4D2E	2017-08-04 10:45:00+03	49400.00
0B4D46	2017-07-09 04:14:00+03	24800.00
0B4D49	2017-08-03 00:44:00+03	14800.00
0B4D84	2017-08-13 20:49:00+03	62400.00
0B4DBF	2017-08-04 21:59:00+03	92800.00
0B4DE0	2017-08-08 10:32:00+03	56900.00
0B4E4A	2017-08-10 17:14:00+03	93900.00
0B4E88	2017-08-05 14:35:00+03	280700.00
0B4ED1	2017-07-21 21:11:00+03	95200.00
0B4EEC	2017-08-03 16:16:00+03	53000.00
0B4FD1	2017-07-26 19:41:00+03	84600.00
0B501E	2017-07-14 19:49:00+03	60700.00
0B5052	2017-08-15 13:40:00+03	28600.00
0B5075	2017-06-30 10:48:00+03	19800.00
0B50B2	2017-07-22 05:24:00+03	39200.00
0B50C1	2017-07-19 19:31:00+03	30000.00
0B51AD	2017-08-08 06:56:00+03	167400.00
0B51F8	2017-07-09 20:48:00+03	6000.00
0B5221	2017-07-17 13:14:00+03	46400.00
0B5255	2017-08-07 19:48:00+03	30400.00
0B52BD	2017-08-15 01:02:00+03	92800.00
0B52F7	2017-07-11 11:48:00+03	112100.00
0B5304	2017-07-11 23:58:00+03	132800.00
0B5331	2017-07-27 22:48:00+03	66600.00
0B5353	2017-07-20 22:28:00+03	56000.00
0B5356	2017-08-14 06:53:00+03	81700.00
0B5383	2017-07-06 05:20:00+03	20200.00
0B5447	2017-08-13 21:42:00+03	11600.00
0B546C	2017-08-08 13:44:00+03	138000.00
0B549B	2017-07-17 22:27:00+03	233800.00
0B552B	2017-07-28 18:43:00+03	59800.00
0B557D	2017-07-12 02:24:00+03	12000.00
0B55B0	2017-07-06 05:32:00+03	39300.00
0B55CD	2017-08-03 12:30:00+03	14400.00
0B5636	2017-07-27 00:30:00+03	48800.00
0B563A	2017-07-08 20:17:00+03	46000.00
0B5658	2017-08-02 19:58:00+03	123000.00
0B5685	2017-07-21 14:30:00+03	29600.00
0B56DC	2017-08-07 11:32:00+03	23600.00
0B57AA	2017-07-08 03:25:00+03	92100.00
0B57E6	2017-08-13 10:07:00+03	111600.00
0B5937	2017-08-08 06:14:00+03	166000.00
0B5969	2017-07-14 17:29:00+03	399600.00
0B5992	2017-07-23 05:44:00+03	28800.00
0B59D7	2017-07-28 20:20:00+03	56000.00
0B59DC	2017-07-12 04:25:00+03	17600.00
0B5A37	2017-07-16 04:04:00+03	177300.00
0B5A3F	2017-08-11 16:27:00+03	65900.00
0B5A44	2017-07-30 08:01:00+03	123000.00
0B5A76	2017-07-23 15:41:00+03	52000.00
0B5AAD	2017-07-03 00:06:00+03	50800.00
0B5AB1	2017-08-05 20:03:00+03	73500.00
0B5B04	2017-07-10 14:55:00+03	39300.00
0B5B24	2017-07-24 01:48:00+03	169900.00
0B5B61	2017-07-14 10:32:00+03	139100.00
0B5B96	2017-08-03 12:53:00+03	39200.00
0B5BAB	2017-08-12 23:27:00+03	394800.00
0B5BF0	2017-07-28 18:38:00+03	46200.00
0B5C30	2017-07-12 09:04:00+03	23600.00
0B5CD4	2017-07-05 08:16:00+03	115700.00
0B5CD5	2017-08-13 04:15:00+03	35600.00
0B5D35	2017-07-24 23:47:00+03	23200.00
0B5DC6	2017-07-18 14:40:00+03	58600.00
0B5E33	2017-08-08 21:04:00+03	65500.00
0B5E5C	2017-07-09 14:11:00+03	427600.00
0B5E64	2017-07-26 01:36:00+03	132800.00
0B5E6F	2017-07-01 09:50:00+03	55800.00
0B5EAA	2017-07-22 05:40:00+03	61200.00
0B5F41	2017-07-29 13:19:00+03	20400.00
0B5F4B	2017-07-17 05:44:00+03	9800.00
0B5F9D	2017-08-04 19:04:00+03	24400.00
0B5FA2	2017-07-31 01:30:00+03	34100.00
0B5FFA	2017-07-13 00:46:00+03	93900.00
0B6002	2017-08-03 04:10:00+03	28000.00
0B6004	2017-07-30 23:51:00+03	56000.00
0B605E	2017-07-13 23:49:00+03	56000.00
0B60C1	2017-07-15 06:43:00+03	21200.00
0B60DD	2017-08-14 11:04:00+03	66000.00
0B614B	2017-07-26 10:18:00+03	46800.00
0B6155	2017-07-13 14:36:00+03	31400.00
0B61E9	2017-07-25 13:51:00+03	114400.00
0B61FD	2017-07-16 05:02:00+03	31400.00
0B620C	2017-07-19 06:09:00+03	193600.00
0B6220	2017-08-13 00:28:00+03	67000.00
0B62C2	2017-07-08 03:44:00+03	23200.00
0B6356	2017-07-22 04:44:00+03	56100.00
0B63A4	2017-07-20 23:30:00+03	20400.00
0B63AA	2017-07-24 00:16:00+03	7400.00
0B63AF	2017-08-07 14:07:00+03	104800.00
0B63DE	2017-07-12 04:37:00+03	283000.00
0B63F6	2017-07-06 07:44:00+03	174900.00
0B6410	2017-08-13 04:09:00+03	46400.00
0B6438	2017-07-01 17:04:00+03	257500.00
0B6464	2017-08-09 05:07:00+03	304800.00
0B649C	2017-08-01 14:33:00+03	19800.00
0B64FF	2017-08-04 01:08:00+03	56000.00
0B6517	2017-07-05 09:45:00+03	20200.00
0B6584	2017-07-28 23:11:00+03	49800.00
0B65A0	2017-08-15 13:35:00+03	27800.00
0B65C2	2017-07-04 16:31:00+03	21400.00
0B662D	2017-08-12 23:00:00+03	53600.00
0B66D1	2017-08-01 13:43:00+03	67400.00
0B6707	2017-07-12 08:54:00+03	70800.00
0B6761	2017-08-06 13:10:00+03	47100.00
0B67A1	2017-08-03 14:54:00+03	46300.00
0B67B2	2017-07-05 02:06:00+03	278400.00
0B6813	2017-07-10 03:52:00+03	70600.00
0B6838	2017-08-03 05:02:00+03	135400.00
0B68C2	2017-07-27 06:19:00+03	73100.00
0B68F7	2017-08-10 06:27:00+03	32700.00
0B692D	2017-08-11 03:25:00+03	21200.00
0B6954	2017-07-14 08:43:00+03	202300.00
0B6A7C	2017-06-28 11:51:00+03	53300.00
0B6AA1	2017-07-14 06:45:00+03	26700.00
0B6AC5	2017-07-12 20:33:00+03	114800.00
0B6AF0	2017-07-06 03:28:00+03	14400.00
0B6B18	2017-08-04 19:53:00+03	62800.00
0B6B69	2017-07-19 19:58:00+03	193600.00
0B6B88	2017-07-24 15:08:00+03	59700.00
0B6C01	2017-08-08 14:48:00+03	136600.00
0B6CD2	2017-07-27 07:08:00+03	32200.00
0B6D29	2017-07-18 14:08:00+03	14000.00
0B6D34	2017-08-15 10:59:00+03	135300.00
0B6DA9	2017-08-13 22:51:00+03	21800.00
0B6DB9	2017-07-17 20:10:00+03	62600.00
0B6DC0	2017-07-07 21:38:00+03	260900.00
0B6E8A	2017-08-11 11:01:00+03	19600.00
0B6EC6	2017-07-24 04:20:00+03	40200.00
0B6F4A	2017-08-01 21:28:00+03	79600.00
0B6F56	2017-07-21 23:23:00+03	48500.00
0B6FB3	2017-07-13 19:19:00+03	46000.00
0B6FC9	2017-07-06 20:10:00+03	46000.00
0B6FDC	2017-07-24 09:21:00+03	81300.00
0B705A	2017-07-28 15:23:00+03	23200.00
0B70CD	2017-07-18 13:12:00+03	43600.00
0B70D2	2017-07-08 19:22:00+03	36900.00
0B70E0	2017-07-25 23:06:00+03	32500.00
0B7104	2017-07-19 20:40:00+03	19100.00
0B7126	2017-07-25 05:35:00+03	26000.00
0B714A	2017-08-14 15:22:00+03	12200.00
0B71D3	2017-07-22 15:34:00+03	26200.00
0B722B	2017-07-28 04:59:00+03	40600.00
0B725A	2017-07-31 21:07:00+03	55800.00
0B72B0	2017-08-06 14:08:00+03	75300.00
0B72F2	2017-07-01 00:04:00+03	492000.00
0B7325	2017-07-02 05:41:00+03	29400.00
0B736C	2017-07-02 00:45:00+03	56600.00
0B736F	2017-07-19 13:26:00+03	49200.00
0B73BB	2017-08-03 09:51:00+03	42400.00
0B7406	2017-08-12 07:29:00+03	154300.00
0B741A	2017-07-04 15:18:00+03	73200.00
0B7513	2017-07-28 05:59:00+03	152500.00
0B75EB	2017-07-08 17:37:00+03	147900.00
0B7601	2017-07-12 14:08:00+03	111600.00
0B765C	2017-08-15 09:57:00+03	180500.00
0B76CF	2017-07-26 03:53:00+03	61900.00
0B76D1	2017-07-12 21:31:00+03	26800.00
0B76E2	2017-08-13 10:21:00+03	55800.00
0B76F3	2017-08-03 17:04:00+03	24700.00
0B772A	2017-07-19 12:16:00+03	128900.00
0B77D4	2017-07-16 12:58:00+03	62900.00
0B7806	2017-07-07 14:59:00+03	66800.00
0B786C	2017-08-15 16:15:00+03	34000.00
0B789E	2017-07-28 06:36:00+03	155600.00
0B78AF	2017-08-07 15:03:00+03	47200.00
0B7925	2017-07-13 01:17:00+03	42000.00
0B7954	2017-08-04 21:08:00+03	25000.00
0B7A1E	2017-07-26 18:58:00+03	119300.00
0B7A79	2017-07-22 11:02:00+03	57800.00
0B7ABD	2017-07-05 16:49:00+03	146300.00
0B7ABE	2017-07-05 20:35:00+03	123000.00
0B7AEF	2017-07-09 15:15:00+03	147700.00
0B7B13	2017-08-04 22:08:00+03	120700.00
0B7B6F	2017-07-03 10:01:00+03	66600.00
0B7BA8	2017-07-09 05:36:00+03	70500.00
0B7C0E	2017-07-28 19:30:00+03	28000.00
0B7C12	2017-08-11 00:27:00+03	46300.00
0B7D49	2017-08-03 22:03:00+03	179500.00
0B7DD4	2017-06-30 10:58:00+03	24300.00
0B7DEC	2017-07-01 19:17:00+03	117600.00
0B7ECC	2017-08-11 14:41:00+03	103200.00
0B7EE7	2017-07-22 19:13:00+03	132300.00
0B7EF4	2017-07-11 00:25:00+03	119500.00
0B7F50	2017-07-15 12:18:00+03	186900.00
0B7FC3	2017-07-22 18:16:00+03	92400.00
0B7FF5	2017-08-08 07:08:00+03	59000.00
0B7FFE	2017-07-04 19:22:00+03	67200.00
0B8040	2017-08-02 20:54:00+03	102100.00
0B8046	2017-08-02 15:48:00+03	56000.00
0B80A4	2017-08-03 06:20:00+03	20100.00
0B80FC	2017-07-12 06:00:00+03	56900.00
0B8102	2017-07-04 05:52:00+03	94300.00
0B8122	2017-07-10 13:46:00+03	24400.00
0B8139	2017-07-11 12:18:00+03	75600.00
0B814D	2017-07-17 04:59:00+03	136600.00
0B8162	2017-07-23 08:21:00+03	87000.00
0B8191	2017-07-02 01:09:00+03	61900.00
0B8237	2017-08-14 13:25:00+03	23600.00
0B823A	2017-07-23 12:15:00+03	13700.00
0B8245	2017-07-13 08:03:00+03	40800.00
0B826C	2017-08-15 16:52:00+03	27300.00
0B8274	2017-08-09 05:55:00+03	91500.00
0B8285	2017-08-05 04:01:00+03	83100.00
0B829D	2017-07-16 11:20:00+03	95200.00
0B82AB	2017-07-27 16:20:00+03	134400.00
0B8398	2017-08-15 17:32:00+03	147700.00
0B844D	2017-07-20 14:10:00+03	31600.00
0B846E	2017-08-14 08:24:00+03	27200.00
0B84AE	2017-07-14 08:04:00+03	8600.00
0B84B6	2017-07-23 11:23:00+03	49100.00
0B84E9	2017-08-11 16:08:00+03	131000.00
0B8501	2017-07-17 07:07:00+03	105500.00
0B85F3	2017-08-09 00:58:00+03	26000.00
0B86C2	2017-08-02 20:48:00+03	18600.00
0B86D5	2017-07-05 21:12:00+03	90000.00
0B86EE	2017-07-19 08:02:00+03	32800.00
0B87C7	2017-07-06 16:29:00+03	282300.00
0B87D9	2017-08-12 17:20:00+03	57300.00
0B8887	2017-08-02 09:42:00+03	20200.00
0B88D5	2017-08-01 19:52:00+03	122300.00
0B88E3	2017-07-07 20:44:00+03	51900.00
0B88ED	2017-07-26 15:18:00+03	56000.00
0B8988	2017-07-03 21:04:00+03	92800.00
0B89A7	2017-07-21 09:21:00+03	48800.00
0B89C4	2017-08-14 06:22:00+03	106800.00
0B8A07	2017-07-31 16:34:00+03	100600.00
0B8A38	2017-08-05 23:05:00+03	106800.00
0B8A73	2017-07-27 11:18:00+03	124200.00
0B8A76	2017-07-03 10:31:00+03	113600.00
0B8A8C	2017-08-14 01:46:00+03	62600.00
0B8BA8	2017-07-19 22:31:00+03	28800.00
0B8C2C	2017-08-10 20:18:00+03	38800.00
0B8C39	2017-07-25 20:18:00+03	169900.00
0B8C70	2017-07-24 13:57:00+03	123000.00
0B8CA0	2017-07-25 22:53:00+03	57700.00
0B8CB0	2017-07-26 01:09:00+03	6300.00
0B8D58	2017-07-01 10:26:00+03	111600.00
0B8D7F	2017-07-12 17:25:00+03	135200.00
0B8DDD	2017-08-12 01:11:00+03	118000.00
0B8E70	2017-07-28 10:07:00+03	40000.00
0B8EB3	2017-08-01 11:51:00+03	36200.00
0B8F56	2017-07-13 01:36:00+03	68400.00
0B9029	2017-08-01 14:59:00+03	24400.00
0B902C	2017-08-14 23:45:00+03	56000.00
0B906A	2017-08-12 21:57:00+03	75800.00
0B9081	2017-07-25 04:41:00+03	12400.00
0B9084	2017-07-17 10:38:00+03	76400.00
0B90BB	2017-07-21 23:29:00+03	106100.00
0B90D0	2017-08-14 17:04:00+03	135600.00
0B90E6	2017-07-16 13:26:00+03	33200.00
0B90EB	2017-07-28 07:27:00+03	66600.00
0B9100	2017-08-06 17:35:00+03	64500.00
0B9165	2017-07-17 05:58:00+03	185000.00
0B9179	2017-07-29 20:20:00+03	40800.00
0B91A9	2017-08-09 15:13:00+03	73600.00
0B91D9	2017-08-02 18:36:00+03	21400.00
0B91DC	2017-07-17 20:24:00+03	223200.00
0B9263	2017-07-11 02:01:00+03	38400.00
0B9264	2017-07-18 23:53:00+03	13400.00
0B927D	2017-08-09 02:19:00+03	23200.00
0B92A8	2017-07-22 18:54:00+03	49600.00
0B92B8	2017-08-08 05:52:00+03	7400.00
0B92BD	2017-07-11 03:58:00+03	16400.00
0B92F5	2017-07-09 03:46:00+03	13200.00
0B934F	2017-07-03 17:01:00+03	75500.00
0B93DA	2017-07-25 17:26:00+03	70700.00
0B93E4	2017-08-10 00:21:00+03	92400.00
0B93EE	2017-08-01 23:30:00+03	54300.00
0B9489	2017-08-13 16:27:00+03	64400.00
0B94B4	2017-07-27 08:05:00+03	11700.00
0B94BF	2017-07-26 02:41:00+03	155900.00
0B94C3	2017-08-08 07:27:00+03	25200.00
0B94E0	2017-08-04 14:09:00+03	86500.00
0B9500	2017-07-30 11:18:00+03	12600.00
0B959D	2017-07-24 10:27:00+03	25100.00
0B95BA	2017-08-04 22:40:00+03	32800.00
0B95E9	2017-07-26 13:51:00+03	44600.00
0B9651	2017-07-15 06:35:00+03	136500.00
0B96A1	2017-08-06 23:20:00+03	83000.00
0B96F4	2017-08-11 17:17:00+03	70700.00
0B974D	2017-07-14 15:19:00+03	25600.00
0B97A1	2017-07-21 17:12:00+03	40000.00
0B9834	2017-08-07 15:05:00+03	99200.00
0B986D	2017-07-21 05:39:00+03	41600.00
0B9944	2017-07-11 10:32:00+03	28800.00
0B9957	2017-07-19 12:35:00+03	99700.00
0B9A0A	2017-07-24 19:34:00+03	63200.00
0B9A23	2017-07-01 15:37:00+03	128800.00
0B9A48	2017-08-01 13:20:00+03	28000.00
0B9AD7	2017-07-27 17:02:00+03	72300.00
0B9BEC	2017-07-11 22:18:00+03	38400.00
0B9C38	2017-08-01 12:00:00+03	29100.00
0B9C3E	2017-07-21 10:04:00+03	67200.00
0B9C7A	2017-07-18 19:12:00+03	88900.00
0B9C7B	2017-07-19 09:05:00+03	28800.00
0B9C7F	2017-07-17 12:19:00+03	27300.00
0B9CC6	2017-07-17 03:29:00+03	30600.00
0B9CED	2017-07-15 21:06:00+03	95200.00
0B9D7B	2017-07-15 20:46:00+03	42700.00
0B9D8E	2017-06-29 09:51:00+03	109000.00
0B9DE9	2017-07-30 01:10:00+03	23200.00
0B9DFB	2017-07-06 09:02:00+03	155600.00
0B9E1A	2017-08-15 09:46:00+03	46400.00
0B9E4A	2017-06-28 03:15:00+03	28000.00
0B9E61	2017-07-29 04:56:00+03	54000.00
0B9EB6	2017-08-05 08:07:00+03	96100.00
0B9EC1	2017-08-10 23:38:00+03	31700.00
0B9ECB	2017-08-01 19:33:00+03	213200.00
0B9EF1	2017-07-02 05:17:00+03	46400.00
0B9F42	2017-07-24 22:26:00+03	58800.00
0B9F61	2017-08-07 04:39:00+03	18900.00
0B9F8B	2017-08-13 00:30:00+03	36200.00
0B9F8E	2017-08-04 07:07:00+03	64600.00
0B9FAC	2017-07-23 11:38:00+03	28800.00
0BA098	2017-08-09 15:56:00+03	84200.00
0BA0D1	2017-07-24 15:18:00+03	86400.00
0BA15E	2017-07-02 20:14:00+03	177100.00
0BA278	2017-07-22 05:46:00+03	113300.00
0BA2A9	2017-07-15 23:02:00+03	69000.00
0BA2D7	2017-07-12 17:09:00+03	24400.00
0BA308	2017-07-22 11:02:00+03	238200.00
0BA311	2017-07-11 11:48:00+03	47000.00
0BA314	2017-08-03 12:51:00+03	70200.00
0BA319	2017-08-09 21:56:00+03	36200.00
0BA329	2017-07-24 04:42:00+03	24800.00
0BA356	2017-07-19 22:40:00+03	40000.00
0BA357	2017-07-05 05:56:00+03	47200.00
0BA37E	2017-07-18 15:52:00+03	52300.00
0BA3B1	2017-07-10 01:26:00+03	13600.00
0BA3CF	2017-07-24 16:39:00+03	23400.00
0BA3D8	2017-07-01 07:04:00+03	133100.00
0BA4AB	2017-08-08 01:02:00+03	35700.00
0BA528	2017-07-04 02:49:00+03	166100.00
0BA52A	2017-08-15 12:42:00+03	152200.00
0BA54D	2017-07-08 14:01:00+03	192800.00
0BA577	2017-07-04 01:32:00+03	53500.00
0BA589	2017-07-06 08:46:00+03	53700.00
0BA5C8	2017-08-10 12:08:00+03	77400.00
0BA5D5	2017-07-03 05:39:00+03	84500.00
0BA651	2017-07-21 11:16:00+03	67600.00
0BA69C	2017-08-06 10:00:00+03	36800.00
0BA6A2	2017-07-10 08:00:00+03	86300.00
0BA6FC	2017-07-03 06:10:00+03	12600.00
0BA72C	2017-08-09 16:30:00+03	80100.00
0BA77A	2017-08-02 02:10:00+03	121100.00
0BA7CE	2017-07-22 23:25:00+03	20000.00
0BA7F5	2017-08-13 21:19:00+03	26000.00
0BA804	2017-07-08 12:27:00+03	213800.00
0BA81B	2017-07-31 03:52:00+03	166700.00
0BA8DB	2017-08-09 09:57:00+03	31000.00
0BA8E1	2017-07-04 18:25:00+03	14800.00
0BA940	2017-08-08 02:59:00+03	18000.00
0BA94C	2017-07-14 03:46:00+03	78300.00
0BA95F	2017-07-09 13:09:00+03	61800.00
0BA98C	2017-07-05 03:20:00+03	56000.00
0BAA60	2017-07-29 18:48:00+03	56600.00
0BABD0	2017-07-10 11:03:00+03	147700.00
0BABD1	2017-07-21 22:02:00+03	106500.00
0BACCC	2017-08-04 11:02:00+03	8400.00
0BAD05	2017-07-17 14:17:00+03	27700.00
0BAD5D	2017-07-30 13:39:00+03	102200.00
0BAD7F	2017-07-07 20:05:00+03	46200.00
0BADFD	2017-07-19 18:46:00+03	16400.00
0BAE36	2017-07-05 23:24:00+03	28800.00
0BAE4D	2017-08-12 14:33:00+03	25800.00
0BAE80	2017-07-07 22:27:00+03	44800.00
0BAFAB	2017-07-14 11:13:00+03	28000.00
0BAFB8	2017-07-17 21:33:00+03	73600.00
0BAFBF	2017-07-22 14:18:00+03	122700.00
0BAFD0	2017-08-01 13:39:00+03	6700.00
0BB013	2017-08-03 19:57:00+03	67600.00
0BB046	2017-07-20 04:15:00+03	41200.00
0BB054	2017-07-23 16:52:00+03	20200.00
0BB06A	2017-07-02 17:01:00+03	113200.00
0BB073	2017-08-01 21:05:00+03	26800.00
0BB090	2017-08-08 13:49:00+03	35200.00
0BB0BA	2017-07-31 15:25:00+03	37100.00
0BB10F	2017-08-08 04:18:00+03	190000.00
0BB127	2017-07-22 12:41:00+03	23400.00
0BB148	2017-08-15 07:59:00+03	221000.00
0BB14B	2017-07-29 14:32:00+03	39200.00
0BB186	2017-07-30 23:33:00+03	66600.00
0BB18D	2017-07-06 19:20:00+03	46400.00
0BB19D	2017-07-19 04:49:00+03	56100.00
0BB3F2	2017-07-01 10:04:00+03	235900.00
0BB43F	2017-07-09 08:14:00+03	76300.00
0BB46E	2017-07-28 13:51:00+03	12600.00
0BB4A2	2017-07-11 04:59:00+03	34800.00
0BB4AE	2017-08-05 13:46:00+03	186900.00
0BB4DC	2017-07-01 21:38:00+03	78200.00
0BB4F4	2017-08-03 03:24:00+03	37900.00
0BB51D	2017-07-08 03:15:00+03	133100.00
0BB555	2017-07-05 06:53:00+03	67100.00
0BB557	2017-08-12 06:35:00+03	8400.00
0BB592	2017-08-08 20:43:00+03	103000.00
0BB69F	2017-07-25 17:19:00+03	147200.00
0BB711	2017-07-05 00:46:00+03	144700.00
0BB742	2017-07-31 10:42:00+03	67100.00
0BB74D	2017-08-09 08:27:00+03	63700.00
0BB756	2017-07-12 19:07:00+03	56600.00
0BB771	2017-07-10 13:04:00+03	38600.00
0BB7FE	2017-08-07 06:23:00+03	6000.00
0BB80A	2017-07-08 18:42:00+03	68800.00
0BB816	2017-07-31 05:59:00+03	88800.00
0BB867	2017-07-11 06:44:00+03	36200.00
0BB985	2017-07-31 12:04:00+03	35600.00
0BB9CE	2017-07-10 13:33:00+03	68800.00
0BB9DD	2017-08-11 20:38:00+03	26700.00
0BB9FE	2017-06-30 14:22:00+03	80000.00
0BBA27	2017-08-09 20:16:00+03	25200.00
0BBA58	2017-07-27 05:41:00+03	369000.00
0BBA5A	2017-08-11 20:56:00+03	66600.00
0BBAE0	2017-08-14 18:58:00+03	52500.00
0BBAE9	2017-08-12 09:28:00+03	28000.00
0BBB3C	2017-07-30 14:39:00+03	48400.00
0BBB64	2017-08-04 06:52:00+03	88600.00
0BBB72	2017-07-09 19:15:00+03	59000.00
0BBB76	2017-07-06 14:25:00+03	46200.00
0BBB89	2017-07-16 08:40:00+03	44600.00
0BBB8D	2017-08-07 03:23:00+03	23400.00
0BBBED	2017-07-09 11:04:00+03	141300.00
0BBC28	2017-08-14 00:33:00+03	40000.00
0BBC7D	2017-07-31 13:30:00+03	86400.00
0BBC9F	2017-07-18 19:00:00+03	173900.00
0BBCB7	2017-07-05 03:13:00+03	49800.00
0BBCBF	2017-07-22 08:29:00+03	28800.00
0BBCC1	2017-08-06 21:40:00+03	31000.00
0BBD03	2017-07-17 16:51:00+03	125400.00
0BBD06	2017-08-12 12:19:00+03	38400.00
0BBD37	2017-08-14 07:22:00+03	51900.00
0BBD90	2017-07-06 12:00:00+03	246000.00
0BBDDA	2017-08-09 13:12:00+03	92800.00
0BBDF8	2017-07-17 19:22:00+03	23600.00
0BBE11	2017-07-19 07:03:00+03	93800.00
0BBE21	2017-08-09 08:53:00+03	65900.00
0BBE30	2017-07-29 13:04:00+03	27200.00
0BBE56	2017-07-27 04:03:00+03	135600.00
0BBE7A	2017-07-15 00:35:00+03	113600.00
0BBEAC	2017-07-04 18:46:00+03	18600.00
0BBEB2	2017-07-09 21:42:00+03	49600.00
0BBEFE	2017-08-14 08:35:00+03	162400.00
0BBF01	2017-07-26 20:37:00+03	38800.00
0BBF0F	2017-07-14 00:01:00+03	24400.00
0BBF64	2017-07-03 19:35:00+03	201200.00
0BC105	2017-08-05 01:47:00+03	70600.00
0BC137	2017-07-31 05:06:00+03	19600.00
0BC1C6	2017-08-08 03:38:00+03	240600.00
0BC261	2017-07-25 05:57:00+03	190700.00
0BC2BA	2017-08-05 14:23:00+03	11600.00
0BC354	2017-08-05 16:23:00+03	73100.00
0BC366	2017-07-14 16:53:00+03	213600.00
0BC378	2017-08-03 07:42:00+03	6000.00
0BC390	2017-08-07 19:45:00+03	25400.00
0BC405	2017-08-07 17:49:00+03	23600.00
0BC429	2017-08-05 05:40:00+03	26000.00
0BC4C6	2017-08-03 00:25:00+03	43500.00
0BC4DA	2017-07-02 13:57:00+03	28200.00
0BC513	2017-07-29 20:51:00+03	273400.00
0BC534	2017-07-28 13:30:00+03	272900.00
0BC585	2017-07-16 10:24:00+03	10800.00
0BC5AE	2017-07-21 05:02:00+03	83000.00
0BC5BD	2017-07-05 17:30:00+03	7300.00
0BC5CE	2017-07-12 04:55:00+03	295400.00
0BC5EA	2017-08-02 18:42:00+03	14000.00
0BC628	2017-07-26 07:30:00+03	167400.00
0BC64C	2017-07-08 04:16:00+03	6600.00
0BC6A2	2017-07-14 12:57:00+03	246000.00
0BC6AA	2017-07-08 19:24:00+03	132800.00
0BC740	2017-07-11 06:43:00+03	260900.00
0BC7E0	2017-07-08 12:33:00+03	61400.00
0BC89F	2017-08-10 16:33:00+03	52700.00
0BC946	2017-08-03 03:42:00+03	155600.00
0BC98F	2017-08-06 09:34:00+03	38500.00
0BC9DA	2017-07-25 08:58:00+03	296100.00
0BCA79	2017-07-09 08:23:00+03	93900.00
0BCAB9	2017-07-12 16:32:00+03	50000.00
0BCAD0	2017-07-14 13:50:00+03	12600.00
0BCADD	2017-08-14 21:49:00+03	272300.00
0BCAE5	2017-07-28 08:12:00+03	56600.00
0BCAF0	2017-08-05 21:07:00+03	23200.00
0BCB29	2017-07-21 02:02:00+03	70600.00
0BCB42	2017-07-17 04:54:00+03	26800.00
0BCBBB	2017-08-14 12:46:00+03	399600.00
0BCBE0	2017-08-13 20:36:00+03	70400.00
0BCC2F	2017-08-06 08:30:00+03	66600.00
0BCC5D	2017-08-08 01:33:00+03	70800.00
0BCC6D	2017-07-24 18:09:00+03	92000.00
0BCCA0	2017-07-21 16:32:00+03	82900.00
0BCCD5	2017-07-13 05:58:00+03	6000.00
0BCCE1	2017-07-06 13:15:00+03	133200.00
0BCD63	2017-08-12 16:31:00+03	68000.00
0BCD8D	2017-07-13 18:50:00+03	56000.00
0BCD9B	2017-07-20 19:50:00+03	40600.00
0BCDEB	2017-07-25 11:01:00+03	88600.00
0BCDF1	2017-07-22 21:42:00+03	38700.00
0BCDF3	2017-08-06 02:03:00+03	12600.00
0BCE15	2017-07-20 01:10:00+03	64700.00
0BCE2B	2017-07-11 17:09:00+03	85000.00
0BCE66	2017-07-19 22:21:00+03	28800.00
0BCE6F	2017-07-26 21:16:00+03	46400.00
0BCEA4	2017-07-12 11:51:00+03	28000.00
0BCEAB	2017-08-13 02:30:00+03	396500.00
0BCEDE	2017-08-03 07:13:00+03	31600.00
0BCF03	2017-07-17 15:44:00+03	48500.00
0BCF23	2017-07-23 10:52:00+03	45200.00
0BCF35	2017-07-30 02:55:00+03	6700.00
0BCF66	2017-07-02 17:27:00+03	129200.00
0BCFC3	2017-07-04 23:05:00+03	12400.00
0BD039	2017-08-12 20:37:00+03	24000.00
0BD05D	2017-07-29 12:16:00+03	172600.00
0BD08C	2017-08-09 05:20:00+03	64300.00
0BD0D8	2017-07-29 05:12:00+03	133100.00
0BD0F1	2017-08-13 06:04:00+03	65900.00
0BD146	2017-08-03 15:56:00+03	13400.00
0BD152	2017-07-12 03:01:00+03	136200.00
0BD195	2017-07-13 23:48:00+03	246000.00
0BD216	2017-08-13 21:39:00+03	81200.00
0BD28A	2017-08-03 10:03:00+03	55800.00
0BD29A	2017-07-25 01:53:00+03	52700.00
0BD2BB	2017-07-19 11:53:00+03	40800.00
0BD2C0	2017-08-10 23:05:00+03	102100.00
0BD339	2017-08-07 13:40:00+03	40200.00
0BD37A	2017-08-14 01:36:00+03	12000.00
0BD3A9	2017-08-02 01:52:00+03	58800.00
0BD3D1	2017-07-15 02:55:00+03	58000.00
0BD451	2017-08-14 04:19:00+03	65900.00
0BD5A1	2017-08-11 15:42:00+03	35500.00
0BD5E5	2017-07-08 13:30:00+03	16400.00
0BD5F8	2017-08-15 14:57:00+03	75300.00
0BD61B	2017-07-16 06:41:00+03	48800.00
0BD625	2017-07-27 03:40:00+03	89100.00
0BD67D	2017-08-03 12:52:00+03	13400.00
0BD69B	2017-07-22 23:38:00+03	50100.00
0BD6A9	2017-07-12 02:11:00+03	46000.00
0BD6F7	2017-07-06 06:15:00+03	75700.00
0BD73E	2017-07-08 17:46:00+03	57600.00
0BD7A3	2017-08-09 15:01:00+03	14000.00
0BD7C7	2017-08-06 17:13:00+03	36200.00
0BD7E9	2017-07-23 06:29:00+03	83000.00
0BD7EF	2017-08-14 15:25:00+03	38400.00
0BD8DE	2017-07-21 20:38:00+03	93800.00
0BD935	2017-08-09 02:38:00+03	281500.00
0BD937	2017-08-04 18:41:00+03	46400.00
0BD93B	2017-07-28 02:50:00+03	114500.00
0BD986	2017-08-12 21:27:00+03	188000.00
0BD993	2017-07-15 14:06:00+03	133200.00
0BDAB6	2017-08-14 22:53:00+03	396200.00
0BDAC4	2017-07-07 23:21:00+03	22000.00
0BDB44	2017-07-05 19:05:00+03	123000.00
0BDB78	2017-08-03 23:04:00+03	25100.00
0BDBBA	2017-08-03 04:10:00+03	47000.00
0BDBDA	2017-08-08 11:41:00+03	6000.00
0BDC02	2017-07-19 17:30:00+03	58800.00
0BDC26	2017-07-20 10:58:00+03	134400.00
0BDC3D	2017-07-04 07:06:00+03	112000.00
0BDC55	2017-07-21 23:57:00+03	6700.00
0BDD11	2017-07-25 22:55:00+03	38600.00
0BDD8D	2017-08-15 12:13:00+03	42000.00
0BDDB5	2017-08-10 14:10:00+03	144700.00
0BDDC0	2017-08-01 03:29:00+03	52600.00
0BDDE6	2017-07-19 14:32:00+03	81500.00
0BDE96	2017-07-15 14:53:00+03	14400.00
0BDF68	2017-07-17 12:18:00+03	41600.00
0BDFDE	2017-07-09 10:50:00+03	26700.00
0BDFF1	2017-08-05 20:53:00+03	37200.00
0BE000	2017-08-02 08:18:00+03	32800.00
0BE0CD	2017-07-22 05:38:00+03	202700.00
0BE0E0	2017-07-26 19:18:00+03	54800.00
0BE176	2017-06-30 17:57:00+03	31600.00
0BE1AB	2017-07-10 11:39:00+03	39200.00
0BE20E	2017-07-16 02:53:00+03	66000.00
0BE218	2017-08-03 13:24:00+03	16400.00
0BE296	2017-08-11 19:37:00+03	30100.00
0BE2F8	2017-08-14 20:41:00+03	66000.00
0BE353	2017-08-08 15:34:00+03	15400.00
0BE364	2017-07-09 00:12:00+03	99700.00
0BE39B	2017-07-28 02:02:00+03	139200.00
0BE3CD	2017-07-15 21:02:00+03	48800.00
0BE40A	2017-07-10 06:36:00+03	10700.00
0BE432	2017-06-28 11:04:00+03	21400.00
0BE43C	2017-07-26 11:54:00+03	34400.00
0BE443	2017-07-09 05:24:00+03	97000.00
0BE489	2017-07-15 12:44:00+03	223200.00
0BE4C0	2017-08-06 09:42:00+03	23600.00
0BE501	2017-08-12 12:16:00+03	67200.00
0BE532	2017-07-06 01:59:00+03	160200.00
0BE56A	2017-07-16 19:37:00+03	103500.00
0BE579	2017-08-03 04:54:00+03	93900.00
0BE57D	2017-08-10 02:58:00+03	49400.00
0BE57F	2017-07-02 13:00:00+03	40600.00
0BE580	2017-08-07 05:04:00+03	24400.00
0BE5C3	2017-07-04 17:21:00+03	75300.00
0BE5E0	2017-07-16 22:58:00+03	52100.00
0BE63B	2017-07-20 07:25:00+03	197900.00
0BE63C	2017-07-26 12:13:00+03	58000.00
0BE643	2017-08-08 13:49:00+03	47500.00
0BE6B6	2017-07-27 05:10:00+03	167200.00
0BE6B7	2017-08-11 13:44:00+03	26000.00
0BE72D	2017-07-06 00:44:00+03	56000.00
0BE72E	2017-07-14 07:15:00+03	11600.00
0BE770	2017-08-15 06:47:00+03	133100.00
0BE78C	2017-07-29 20:54:00+03	59100.00
0BE78F	2017-07-04 11:36:00+03	64600.00
0BE79F	2017-07-08 18:33:00+03	34800.00
0BE7B9	2017-07-23 11:17:00+03	8200.00
0BE7D3	2017-07-24 04:27:00+03	40100.00
0BE809	2017-07-09 03:24:00+03	16400.00
0BE81E	2017-08-09 04:55:00+03	335400.00
0BE822	2017-08-06 00:34:00+03	78600.00
0BE883	2017-07-22 02:21:00+03	83000.00
0BE891	2017-08-10 06:08:00+03	33400.00
0BE8D8	2017-07-02 04:53:00+03	173600.00
0BE91C	2017-07-02 04:47:00+03	66600.00
0BE932	2017-08-07 02:58:00+03	46400.00
0BE977	2017-07-08 15:05:00+03	223200.00
0BE98B	2017-07-03 06:40:00+03	77900.00
0BE98D	2017-07-09 20:23:00+03	6000.00
0BE991	2017-07-13 23:17:00+03	58400.00
0BE9CC	2017-07-25 10:56:00+03	79600.00
0BE9E0	2017-07-21 13:02:00+03	201800.00
0BEA1E	2017-07-27 12:43:00+03	383200.00
0BEA3D	2017-07-19 06:39:00+03	389000.00
0BEA8F	2017-08-06 09:55:00+03	60400.00
0BEAA1	2017-07-16 12:34:00+03	120900.00
0BEAA3	2017-07-17 08:52:00+03	40000.00
0BEAC8	2017-07-16 00:35:00+03	133200.00
0BEB19	2017-07-02 22:59:00+03	38400.00
0BEB1E	2017-07-19 01:54:00+03	65900.00
0BEC02	2017-08-05 12:01:00+03	75300.00
0BEC24	2017-07-24 11:35:00+03	75600.00
0BEC30	2017-08-07 19:47:00+03	290500.00
0BEC4F	2017-07-01 01:16:00+03	32200.00
0BEC6D	2017-08-05 22:02:00+03	15400.00
0BEC73	2017-07-13 17:07:00+03	113700.00
0BED63	2017-07-01 06:18:00+03	13000.00
0BEDA0	2017-08-02 15:13:00+03	28800.00
0BEDE9	2017-08-12 05:05:00+03	13200.00
0BEE93	2017-07-16 15:20:00+03	26000.00
0BEEBB	2017-08-03 18:57:00+03	16400.00
0BEED3	2017-08-08 03:53:00+03	9200.00
0BEFDD	2017-07-27 19:14:00+03	29500.00
0BF047	2017-07-23 00:53:00+03	91500.00
0BF0DE	2017-08-07 02:30:00+03	97600.00
0BF0E6	2017-07-05 01:59:00+03	51200.00
0BF0ED	2017-07-07 02:05:00+03	12400.00
0BF12B	2017-07-21 23:25:00+03	185500.00
0BF14B	2017-07-06 18:51:00+03	40800.00
0BF151	2017-08-13 16:29:00+03	56000.00
0BF16F	2017-07-25 11:55:00+03	321200.00
0BF197	2017-07-29 18:04:00+03	46300.00
0BF1CE	2017-07-05 15:04:00+03	422900.00
0BF238	2017-08-11 16:49:00+03	73600.00
0BF25B	2017-07-21 20:23:00+03	89700.00
0BF31D	2017-08-12 14:32:00+03	44000.00
0BF359	2017-08-06 03:44:00+03	46000.00
0BF367	2017-08-14 12:31:00+03	10900.00
0BF3C5	2017-08-11 02:10:00+03	30800.00
0BF3F8	2017-06-30 02:43:00+03	25400.00
0BF4B5	2017-07-18 16:21:00+03	66000.00
0BF5B0	2017-07-07 15:21:00+03	33600.00
0BF633	2017-08-04 07:26:00+03	62600.00
0BF663	2017-07-25 06:38:00+03	82200.00
0BF6F5	2017-08-03 18:38:00+03	17800.00
0BF7B4	2017-07-05 11:07:00+03	53400.00
0BF829	2017-07-17 06:40:00+03	109900.00
0BF833	2017-08-04 06:22:00+03	43400.00
0BF8B9	2017-08-10 14:05:00+03	13700.00
0BF8CB	2017-07-29 16:19:00+03	40100.00
0BF8E8	2017-07-07 08:06:00+03	101200.00
0BF8FE	2017-08-07 09:21:00+03	21400.00
0BF94E	2017-07-26 00:39:00+03	35200.00
0BF97A	2017-07-06 18:48:00+03	14000.00
0BF9E9	2017-07-28 23:24:00+03	231400.00
0BFA88	2017-08-11 23:05:00+03	45800.00
0BFAA1	2017-07-22 12:03:00+03	112000.00
0BFAB8	2017-07-09 00:53:00+03	41900.00
0BFACA	2017-07-09 07:12:00+03	12000.00
0BFB83	2017-08-14 04:25:00+03	135400.00
0BFB91	2017-07-15 08:48:00+03	13400.00
0BFBB6	2017-07-21 14:38:00+03	94100.00
0BFBB8	2017-06-28 06:09:00+03	132800.00
0BFC06	2017-08-05 08:20:00+03	128800.00
0BFC46	2017-07-26 19:17:00+03	36200.00
0BFC64	2017-07-31 14:17:00+03	32700.00
0BFC72	2017-08-12 18:33:00+03	63700.00
0BFC75	2017-07-04 16:09:00+03	73600.00
0BFCA1	2017-07-10 14:41:00+03	73500.00
0BFCA3	2017-08-09 20:21:00+03	284600.00
0BFCB4	2017-08-15 16:14:00+03	67200.00
0BFCB9	2017-07-24 13:15:00+03	119500.00
0BFE2B	2017-08-10 22:05:00+03	26000.00
0BFEAC	2017-07-19 02:51:00+03	78300.00
0BFED9	2017-08-10 13:54:00+03	28300.00
0BFF3E	2017-07-02 07:50:00+03	23600.00
0BFF97	2017-07-30 17:54:00+03	30700.00
0BFFA9	2017-07-29 00:51:00+03	22000.00
0BFFF8	2017-07-14 15:06:00+03	515100.00
0C0002	2017-08-05 18:05:00+03	26600.00
0C000C	2017-07-17 21:17:00+03	220800.00
0C0011	2017-08-05 05:40:00+03	81700.00
0C004A	2017-08-02 22:21:00+03	141200.00
0C00BB	2017-07-19 22:12:00+03	152400.00
0C00ED	2017-08-13 14:04:00+03	55800.00
0C00F1	2017-07-18 07:36:00+03	153200.00
0C00FF	2017-08-10 10:52:00+03	170500.00
0C0102	2017-07-05 09:04:00+03	41200.00
0C0194	2017-07-27 00:36:00+03	39200.00
0C020E	2017-08-08 01:04:00+03	47000.00
0C0213	2017-08-03 01:22:00+03	26000.00
0C0244	2017-08-10 18:03:00+03	20400.00
0C024A	2017-08-13 18:45:00+03	28000.00
0C024F	2017-08-10 12:22:00+03	301100.00
0C02B6	2017-07-14 21:16:00+03	225200.00
0C02C7	2017-07-02 05:49:00+03	209900.00
0C02D4	2017-06-29 13:08:00+03	123600.00
0C02F3	2017-07-15 03:09:00+03	95500.00
0C032E	2017-07-21 01:57:00+03	135200.00
0C0376	2017-08-10 10:41:00+03	10700.00
0C039E	2017-08-13 06:07:00+03	148200.00
0C03BD	2017-08-15 05:34:00+03	63800.00
0C03C4	2017-08-14 03:51:00+03	37200.00
0C043A	2017-07-23 08:27:00+03	42800.00
0C0456	2017-08-10 09:54:00+03	257600.00
0C046F	2017-07-24 00:19:00+03	15000.00
0C04DC	2017-07-11 10:22:00+03	22000.00
0C0524	2017-07-08 18:19:00+03	87000.00
0C0558	2017-08-07 03:19:00+03	23200.00
0C0560	2017-07-21 04:13:00+03	38600.00
0C057B	2017-07-17 07:22:00+03	30000.00
0C05DE	2017-07-25 16:38:00+03	24400.00
0C05E1	2017-08-14 03:57:00+03	66400.00
0C0609	2017-07-19 16:36:00+03	76800.00
0C0672	2017-08-10 20:46:00+03	157100.00
0C0694	2017-07-25 14:37:00+03	23200.00
0C06E9	2017-07-12 21:41:00+03	14000.00
0C074D	2017-07-30 02:39:00+03	56000.00
0C075C	2017-07-30 04:25:00+03	68200.00
0C0766	2017-07-18 06:33:00+03	23400.00
0C0786	2017-06-24 19:16:00+03	28000.00
0C079B	2017-07-07 02:32:00+03	23200.00
0C07C8	2017-08-02 06:42:00+03	56900.00
0C07CD	2017-08-11 19:23:00+03	92800.00
0C07E6	2017-07-29 10:51:00+03	25600.00
0C09A7	2017-07-31 13:13:00+03	72400.00
0C09BE	2017-08-13 05:40:00+03	75600.00
0C0A14	2017-07-24 04:30:00+03	134700.00
0C0A28	2017-08-09 21:12:00+03	31400.00
0C0A61	2017-08-04 06:02:00+03	28800.00
0C0A7E	2017-07-25 11:35:00+03	40000.00
0C0B13	2017-07-16 23:10:00+03	96200.00
0C0B2E	2017-07-29 05:49:00+03	67200.00
0C0B6C	2017-08-15 14:20:00+03	58000.00
0C0B7F	2017-07-03 01:03:00+03	56100.00
0C0BED	2017-06-30 04:50:00+03	136100.00
0C0C1E	2017-08-03 21:59:00+03	114000.00
0C0C2A	2017-07-31 09:41:00+03	39500.00
0C0C34	2017-07-15 09:55:00+03	12400.00
0C0D02	2017-07-22 04:12:00+03	139000.00
0C0D1F	2017-06-26 20:51:00+03	123000.00
0C0D4E	2017-07-29 05:40:00+03	84100.00
0C0D9D	2017-08-13 19:54:00+03	7400.00
0C0DC1	2017-07-21 16:15:00+03	7400.00
0C0DCF	2017-08-05 16:59:00+03	44000.00
0C0FE0	2017-07-18 03:27:00+03	136800.00
0C1014	2017-06-27 02:47:00+03	28000.00
0C1020	2017-07-08 17:49:00+03	7200.00
0C1063	2017-07-22 04:32:00+03	74300.00
0C1092	2017-08-15 03:27:00+03	26800.00
0C109C	2017-07-23 12:26:00+03	30000.00
0C10EA	2017-07-19 02:02:00+03	70700.00
0C1120	2017-07-24 18:13:00+03	260300.00
0C1128	2017-08-04 08:30:00+03	8200.00
0C1134	2017-08-14 05:36:00+03	117500.00
0C1147	2017-08-15 03:38:00+03	26800.00
0C114B	2017-07-07 17:42:00+03	26000.00
0C115C	2017-07-14 23:21:00+03	169900.00
0C1162	2017-07-21 08:23:00+03	16400.00
0C117E	2017-07-08 08:40:00+03	229500.00
0C118B	2017-07-29 19:36:00+03	25000.00
0C11AA	2017-07-30 17:19:00+03	86600.00
0C11F6	2017-07-12 10:21:00+03	372500.00
0C1217	2017-07-12 11:23:00+03	46400.00
0C125F	2017-08-04 02:27:00+03	56600.00
0C126E	2017-08-15 08:25:00+03	203500.00
0C1284	2017-07-27 16:09:00+03	42700.00
0C12A8	2017-08-01 06:11:00+03	89700.00
0C12AA	2017-07-29 15:18:00+03	111600.00
0C12BF	2017-07-07 16:29:00+03	28800.00
0C12C0	2017-07-07 19:38:00+03	25200.00
0C132A	2017-08-05 11:52:00+03	65500.00
0C1347	2017-07-06 02:48:00+03	136800.00
0C1367	2017-07-23 18:43:00+03	6700.00
0C13A5	2017-07-23 08:44:00+03	38000.00
0C13D9	2017-08-09 23:57:00+03	16400.00
0C1401	2017-07-12 16:42:00+03	38600.00
0C14AE	2017-08-07 00:23:00+03	8000.00
0C14FC	2017-07-07 00:01:00+03	16400.00
0C1523	2017-07-12 08:00:00+03	14000.00
0C155A	2017-07-06 11:16:00+03	27800.00
0C1568	2017-07-03 23:40:00+03	21400.00
0C1594	2017-07-23 18:47:00+03	8400.00
0C163E	2017-07-30 10:04:00+03	81200.00
0C1654	2017-07-26 13:26:00+03	56000.00
0C16BB	2017-08-05 18:27:00+03	151000.00
0C16F5	2017-07-24 03:38:00+03	26000.00
0C17FB	2017-07-30 13:35:00+03	47100.00
0C183B	2017-07-08 16:19:00+03	71900.00
0C186C	2017-07-02 01:03:00+03	51600.00
0C193D	2017-07-04 23:00:00+03	126700.00
0C1968	2017-08-01 15:21:00+03	54200.00
0C197B	2017-08-07 07:52:00+03	153200.00
0C197C	2017-07-02 10:12:00+03	167400.00
0C1A33	2017-08-10 16:55:00+03	56000.00
0C1A41	2017-08-08 23:04:00+03	56100.00
0C1A58	2017-07-13 21:38:00+03	8600.00
0C1A97	2017-07-20 09:20:00+03	38600.00
0C1A9B	2017-07-19 23:51:00+03	46100.00
0C1AE1	2017-07-22 05:34:00+03	54400.00
0C1B9F	2017-07-11 16:30:00+03	210800.00
0C1BDC	2017-07-24 15:13:00+03	40800.00
0C1BE0	2017-07-31 00:47:00+03	47600.00
0C1BE2	2017-07-02 15:41:00+03	14000.00
0C1C60	2017-07-08 10:46:00+03	74300.00
0C1C7F	2017-07-08 08:37:00+03	11600.00
0C1CF5	2017-07-18 13:52:00+03	53400.00
0C1D1A	2017-08-06 07:42:00+03	16400.00
0C1D50	2017-08-11 21:33:00+03	58400.00
0C1D69	2017-07-14 10:37:00+03	114400.00
0C1DE6	2017-07-29 20:40:00+03	88100.00
0C1E03	2017-08-07 14:50:00+03	283300.00
0C1E40	2017-07-17 16:12:00+03	656800.00
0C1E7C	2017-07-31 17:07:00+03	46200.00
0C1E84	2017-07-02 06:31:00+03	22000.00
0C1EA7	2017-08-05 18:27:00+03	136800.00
0C1ED9	2017-08-14 08:31:00+03	46300.00
0C1EDA	2017-07-16 23:33:00+03	40800.00
0C2013	2017-07-28 08:21:00+03	56000.00
0C2022	2017-07-08 04:31:00+03	75300.00
0C2023	2017-08-02 15:47:00+03	60400.00
0C207B	2017-07-10 02:44:00+03	32700.00
0C2086	2017-08-02 15:29:00+03	86600.00
0C20C4	2017-08-01 18:26:00+03	58000.00
0C212E	2017-08-01 13:00:00+03	63200.00
0C2138	2017-07-21 12:24:00+03	81600.00
0C213B	2017-07-01 22:10:00+03	72200.00
0C220A	2017-07-10 04:02:00+03	68200.00
0C226C	2017-08-06 04:25:00+03	56900.00
0C22A3	2017-08-12 10:46:00+03	94200.00
0C22AC	2017-07-13 06:27:00+03	86800.00
0C22C4	2017-07-01 21:10:00+03	61500.00
0C22CB	2017-07-23 23:52:00+03	11800.00
0C22DF	2017-07-06 15:01:00+03	132000.00
0C232A	2017-07-09 04:26:00+03	100600.00
0C2358	2017-08-01 23:33:00+03	89500.00
0C24CB	2017-07-23 03:46:00+03	266500.00
0C24FA	2017-07-14 07:59:00+03	126300.00
0C2548	2017-07-19 22:47:00+03	86800.00
0C254C	2017-08-14 14:50:00+03	36400.00
0C25AA	2017-08-03 16:08:00+03	139100.00
0C25C7	2017-07-24 09:20:00+03	56600.00
0C2623	2017-08-08 23:15:00+03	64700.00
0C267C	2017-08-11 02:35:00+03	56300.00
0C26F0	2017-08-10 17:32:00+03	140900.00
0C26F9	2017-07-18 17:11:00+03	12600.00
0C26FB	2017-07-13 08:47:00+03	34800.00
0C26FE	2017-07-16 01:37:00+03	28000.00
0C2705	2017-07-11 09:07:00+03	50600.00
0C2742	2017-07-19 05:25:00+03	56600.00
0C2763	2017-08-02 02:27:00+03	58800.00
0C28DA	2017-07-16 14:58:00+03	30000.00
0C2971	2017-07-21 12:48:00+03	57400.00
0C2981	2017-07-01 19:17:00+03	57800.00
0C29CC	2017-08-03 01:55:00+03	55800.00
0C2A0E	2017-08-14 21:12:00+03	32800.00
0C2A43	2017-08-07 07:56:00+03	4000.00
0C2A8B	2017-08-14 11:58:00+03	86800.00
0C2AAB	2017-07-11 07:45:00+03	112000.00
0C2AB2	2017-07-28 03:48:00+03	58800.00
0C2B1A	2017-07-25 07:17:00+03	36200.00
0C2B78	2017-07-20 07:07:00+03	65900.00
0C2C82	2017-07-30 05:07:00+03	67000.00
0C2C88	2017-06-30 15:34:00+03	56000.00
0C2CB7	2017-08-14 08:27:00+03	25600.00
0C2CC4	2017-07-02 16:24:00+03	79600.00
0C2D2F	2017-07-21 03:36:00+03	38600.00
0C2D33	2017-08-11 11:07:00+03	28000.00
0C2D95	2017-08-09 20:36:00+03	136200.00
0C2E46	2017-07-17 02:01:00+03	135200.00
0C2E5C	2017-07-09 07:41:00+03	40800.00
0C2E5D	2017-07-20 13:00:00+03	197600.00
0C2E91	2017-07-04 13:24:00+03	172100.00
0C2EC4	2017-07-23 09:56:00+03	88000.00
0C2EC6	2017-07-08 07:52:00+03	53400.00
0C2ED6	2017-07-15 22:43:00+03	133200.00
0C2F49	2017-07-23 03:15:00+03	17800.00
0C2F66	2017-07-18 08:41:00+03	46000.00
0C2F75	2017-07-04 09:12:00+03	131100.00
0C2FAC	2017-07-23 04:57:00+03	28600.00
0C2FB6	2017-07-21 03:19:00+03	88900.00
0C2FC8	2017-07-13 22:29:00+03	68100.00
0C2FEB	2017-08-10 17:54:00+03	55800.00
0C2FF3	2017-08-14 11:43:00+03	25400.00
0C3017	2017-08-08 10:04:00+03	43600.00
0C3018	2017-07-18 14:52:00+03	56900.00
0C30A4	2017-08-11 07:17:00+03	23600.00
0C3128	2017-08-01 05:58:00+03	66600.00
0C3137	2017-07-11 15:17:00+03	22000.00
0C3146	2017-08-13 01:48:00+03	57800.00
0C3153	2017-07-12 21:59:00+03	167900.00
0C3204	2017-07-23 23:03:00+03	136800.00
0C3229	2017-07-31 23:12:00+03	92700.00
0C3240	2017-07-29 05:39:00+03	42800.00
0C3252	2017-08-04 04:29:00+03	51800.00
0C3282	2017-07-29 23:04:00+03	53400.00
0C32CD	2017-07-23 21:40:00+03	67700.00
0C32ED	2017-07-27 21:51:00+03	65500.00
0C3398	2017-07-26 03:19:00+03	46200.00
0C33A9	2017-07-19 06:19:00+03	47400.00
0C34A1	2017-08-06 17:50:00+03	193700.00
0C34A3	2017-07-05 17:31:00+03	24300.00
0C34A7	2017-07-10 17:14:00+03	28700.00
0C34BB	2017-07-16 17:17:00+03	79600.00
0C3521	2017-08-02 09:35:00+03	53600.00
0C3569	2017-07-26 05:08:00+03	129700.00
0C357B	2017-08-12 14:20:00+03	38800.00
0C3679	2017-08-01 21:50:00+03	14000.00
0C367B	2017-08-06 02:01:00+03	112000.00
0C368F	2017-07-10 07:58:00+03	36200.00
0C3698	2017-07-16 01:50:00+03	29400.00
0C3710	2017-07-28 01:27:00+03	75300.00
0C384A	2017-07-31 21:22:00+03	47400.00
0C38B6	2017-08-03 02:34:00+03	177200.00
0C3909	2017-08-07 15:36:00+03	72600.00
0C392F	2017-07-20 00:20:00+03	75300.00
0C393F	2017-07-16 04:09:00+03	174600.00
0C395D	2017-08-08 07:54:00+03	12600.00
0C3998	2017-08-11 12:50:00+03	136800.00
0C39EF	2017-07-08 03:32:00+03	26000.00
0C3A26	2017-08-08 10:51:00+03	175600.00
0C3B31	2017-07-29 11:54:00+03	40000.00
0C3B4B	2017-08-14 19:06:00+03	34000.00
0C3BB3	2017-08-10 14:19:00+03	76800.00
0C3BFC	2017-07-23 23:58:00+03	105600.00
0C3C0C	2017-07-06 11:15:00+03	36200.00
0C3C35	2017-08-14 13:54:00+03	92700.00
0C3C4A	2017-07-11 08:40:00+03	21800.00
0C3CC8	2017-07-24 10:52:00+03	146200.00
0C3CCC	2017-07-22 00:02:00+03	46100.00
0C3CFD	2017-07-09 20:07:00+03	75600.00
0C3D19	2017-08-06 17:51:00+03	28800.00
0C3DFF	2017-08-13 02:20:00+03	76200.00
0C3E81	2017-06-30 07:54:00+03	178800.00
0C3E87	2017-07-02 15:18:00+03	236300.00
0C3EB0	2017-08-14 20:41:00+03	25200.00
0C3F16	2017-08-11 18:00:00+03	62600.00
0C3F23	2017-07-26 06:59:00+03	12400.00
0C3F30	2017-08-01 01:42:00+03	24400.00
0C3F5E	2017-07-01 01:09:00+03	40400.00
0C3FDD	2017-07-30 00:56:00+03	31600.00
0C3FF7	2017-07-01 15:26:00+03	14700.00
0C4045	2017-07-15 02:23:00+03	136800.00
0C406B	2017-07-11 20:15:00+03	80000.00
0C40D4	2017-07-20 05:38:00+03	32200.00
0C4112	2017-08-09 03:52:00+03	43000.00
0C4128	2017-08-10 15:41:00+03	37000.00
0C417F	2017-08-05 02:52:00+03	399600.00
0C418E	2017-07-11 05:43:00+03	47200.00
0C41FB	2017-08-13 02:41:00+03	80000.00
0C4246	2017-07-27 07:23:00+03	85000.00
0C425F	2017-08-04 23:41:00+03	36400.00
0C4326	2017-07-12 19:38:00+03	117200.00
0C4340	2017-07-16 20:41:00+03	31600.00
0C4388	2017-08-10 11:25:00+03	30200.00
0C43C9	2017-08-09 04:39:00+03	106400.00
0C441E	2017-08-05 04:23:00+03	71200.00
0C442B	2017-08-14 06:51:00+03	99700.00
0C4431	2017-08-13 17:16:00+03	137800.00
0C4432	2017-08-14 06:31:00+03	403300.00
0C4442	2017-07-08 03:14:00+03	133100.00
0C444A	2017-07-27 11:47:00+03	36200.00
0C4463	2017-08-05 21:23:00+03	65100.00
0C4587	2017-07-25 10:12:00+03	61500.00
0C45A0	2017-07-31 00:16:00+03	24800.00
0C45B7	2017-07-18 13:01:00+03	32800.00
0C45CC	2017-08-14 01:04:00+03	50800.00
0C45E6	2017-07-06 14:35:00+03	14800.00
0C461C	2017-07-15 02:09:00+03	26800.00
0C46A6	2017-08-05 00:17:00+03	103800.00
0C46C3	2017-07-29 12:10:00+03	24000.00
0C46E5	2017-07-21 18:41:00+03	148200.00
0C46FF	2017-07-30 19:05:00+03	56600.00
0C4725	2017-07-06 17:17:00+03	28000.00
0C4809	2017-08-11 03:58:00+03	44500.00
0C4864	2017-07-07 22:39:00+03	46000.00
0C4869	2017-07-16 13:44:00+03	24200.00
0C488B	2017-07-21 23:00:00+03	6400.00
0C4894	2017-07-29 11:28:00+03	28800.00
0C489D	2017-08-10 14:29:00+03	24700.00
0C4971	2017-07-12 07:57:00+03	38000.00
0C49B2	2017-07-15 02:28:00+03	186900.00
0C49C9	2017-07-31 19:41:00+03	46200.00
0C49E1	2017-08-11 00:49:00+03	42800.00
0C49F8	2017-07-31 19:56:00+03	15800.00
0C4ACB	2017-07-03 02:34:00+03	78500.00
0C4AD9	2017-08-01 12:32:00+03	88200.00
0C4ADE	2017-07-25 16:01:00+03	12600.00
0C4B52	2017-08-02 18:23:00+03	38600.00
0C4B99	2017-07-19 21:01:00+03	103400.00
0C4C3C	2017-08-15 15:41:00+03	307700.00
0C4CA8	2017-07-08 21:43:00+03	20600.00
0C4D00	2017-07-26 09:24:00+03	64800.00
0C4DD4	2017-08-14 18:59:00+03	6800.00
0C4DFB	2017-08-05 01:25:00+03	32800.00
0C4E57	2017-07-24 06:25:00+03	100600.00
0C4E8C	2017-08-03 14:31:00+03	88100.00
0C4ED1	2017-07-20 22:57:00+03	32800.00
0C4EEE	2017-08-15 02:13:00+03	38600.00
0C4F34	2017-07-29 02:21:00+03	131600.00
0C4F3B	2017-07-19 07:19:00+03	23200.00
0C4F41	2017-07-13 05:17:00+03	76800.00
0C4F8B	2017-07-20 11:39:00+03	99200.00
0C4FA3	2017-07-03 21:00:00+03	248300.00
0C4FCF	2017-08-01 23:07:00+03	46200.00
0C5043	2017-07-26 02:07:00+03	89600.00
0C50EF	2017-07-30 03:00:00+03	81000.00
0C51D7	2017-07-20 17:44:00+03	81300.00
0C5215	2017-08-02 10:05:00+03	20000.00
0C5286	2017-07-02 01:23:00+03	45400.00
0C529C	2017-08-01 07:47:00+03	12600.00
0C52A6	2017-08-15 05:22:00+03	92000.00
0C52D1	2017-07-11 19:18:00+03	37400.00
0C52D4	2017-07-25 01:21:00+03	144300.00
0C52EA	2017-08-09 01:36:00+03	40800.00
0C5371	2017-07-29 05:08:00+03	39300.00
0C53A9	2017-07-25 18:16:00+03	56600.00
0C53C9	2017-07-30 16:17:00+03	89600.00
0C5435	2017-08-03 03:34:00+03	18300.00
0C54C1	2017-08-11 10:32:00+03	52100.00
0C54D5	2017-07-28 22:27:00+03	24800.00
0C5550	2017-08-09 01:27:00+03	54400.00
0C5578	2017-07-03 09:53:00+03	12800.00
0C559B	2017-08-08 14:05:00+03	29600.00
0C55C8	2017-07-28 03:23:00+03	29100.00
0C55CD	2017-07-21 11:22:00+03	6000.00
0C55E4	2017-07-10 05:41:00+03	58600.00
0C5672	2017-07-08 21:04:00+03	43900.00
0C56B7	2017-08-01 06:41:00+03	88500.00
0C5708	2017-07-16 21:11:00+03	55800.00
0C5794	2017-07-14 12:17:00+03	103100.00
0C5835	2017-07-17 14:26:00+03	94200.00
0C585A	2017-07-05 13:38:00+03	99300.00
0C58DD	2017-07-21 11:46:00+03	18600.00
0C5982	2017-08-07 02:59:00+03	16000.00
0C5A4C	2017-07-09 23:24:00+03	136800.00
0C5A82	2017-08-05 18:41:00+03	46300.00
0C5AC5	2017-08-01 02:01:00+03	92400.00
0C5AD7	2017-07-30 16:36:00+03	47200.00
0C5AF9	2017-07-13 09:40:00+03	24000.00
0C5B07	2017-07-05 03:54:00+03	120700.00
0C5B18	2017-07-20 13:06:00+03	113200.00
0C5B6E	2017-08-15 08:26:00+03	28800.00
0C5B7A	2017-07-30 18:56:00+03	168000.00
0C5BA7	2017-07-16 07:29:00+03	14000.00
0C5BCE	2017-06-27 06:21:00+03	16000.00
0C5C36	2017-08-13 13:57:00+03	23900.00
0C5C4E	2017-07-25 22:24:00+03	122100.00
0C5D51	2017-07-11 15:26:00+03	64800.00
0C5D58	2017-07-22 08:10:00+03	55600.00
0C5E49	2017-07-20 07:07:00+03	50600.00
0C5E4A	2017-07-22 02:44:00+03	67600.00
0C5E65	2017-06-28 16:07:00+03	28000.00
0C5E7A	2017-07-06 22:12:00+03	24400.00
0C5E9C	2017-07-14 18:30:00+03	25600.00
0C5EAD	2017-08-01 01:42:00+03	35200.00
0C5F8E	2017-07-18 10:54:00+03	146300.00
0C5F96	2017-07-10 23:09:00+03	119500.00
0C5FCC	2017-07-07 05:58:00+03	24000.00
0C6001	2017-07-30 07:38:00+03	26000.00
0C61AE	2017-07-13 03:44:00+03	38800.00
0C61DE	2017-07-15 22:56:00+03	28000.00
0C61DF	2017-07-14 09:42:00+03	28800.00
0C6217	2017-08-08 06:18:00+03	130800.00
0C6228	2017-07-09 01:47:00+03	50000.00
0C628E	2017-08-07 14:02:00+03	48500.00
0C62BE	2017-07-07 08:11:00+03	22000.00
0C632D	2017-08-03 01:47:00+03	35200.00
0C6332	2017-08-08 01:37:00+03	34000.00
0C633A	2017-07-29 10:56:00+03	32800.00
0C6380	2017-08-14 01:05:00+03	175300.00
0C63E3	2017-07-29 21:51:00+03	615000.00
0C63F1	2017-07-02 01:45:00+03	406700.00
0C6443	2017-07-07 07:07:00+03	25100.00
0C6457	2017-08-08 11:50:00+03	12600.00
0C6459	2017-07-16 00:49:00+03	46400.00
0C646F	2017-07-24 23:50:00+03	79000.00
0C64E9	2017-07-29 09:47:00+03	196100.00
0C6520	2017-07-17 07:44:00+03	52000.00
0C65ED	2017-08-02 05:14:00+03	57700.00
0C66F4	2017-07-30 00:36:00+03	40000.00
0C6712	2017-08-11 10:39:00+03	56900.00
0C6757	2017-07-13 19:34:00+03	27200.00
0C6769	2017-08-13 21:09:00+03	23600.00
0C678D	2017-07-03 11:00:00+03	46200.00
0C688C	2017-08-13 17:56:00+03	40500.00
0C68A4	2017-08-06 01:10:00+03	26200.00
0C68B4	2017-07-04 11:04:00+03	73300.00
0C68EB	2017-08-01 10:27:00+03	48800.00
0C690A	2017-07-05 03:33:00+03	25600.00
0C693A	2017-07-11 13:28:00+03	135600.00
0C697B	2017-08-13 07:22:00+03	35300.00
0C6982	2017-08-08 02:20:00+03	23200.00
0C69D9	2017-08-14 16:24:00+03	28800.00
0C69EA	2017-08-03 01:40:00+03	173600.00
0C6A38	2017-07-27 13:15:00+03	155400.00
0C6AA3	2017-07-01 01:04:00+03	29600.00
0C6AA7	2017-07-22 03:54:00+03	111600.00
0C6AC7	2017-07-05 13:53:00+03	85600.00
0C6B2D	2017-08-07 21:11:00+03	24700.00
0C6B3A	2017-07-02 22:00:00+03	177600.00
0C6C4D	2017-08-02 08:13:00+03	139200.00
0C6C94	2017-08-01 02:12:00+03	145000.00
0C6CC2	2017-07-04 18:33:00+03	51600.00
0C6CEE	2017-07-26 22:41:00+03	46000.00
0C6CF8	2017-07-11 14:35:00+03	99200.00
0C6CFC	2017-07-09 12:41:00+03	24400.00
0C6D21	2017-08-08 03:31:00+03	16400.00
0C6D56	2017-07-04 06:44:00+03	13600.00
0C6D96	2017-08-15 16:55:00+03	31400.00
0C6DAD	2017-08-05 18:42:00+03	76800.00
0C6DC3	2017-08-11 21:53:00+03	54700.00
0C6E02	2017-07-24 03:29:00+03	29600.00
0C6E35	2017-07-28 09:24:00+03	107500.00
0C6EBB	2017-07-25 08:22:00+03	45300.00
0C6EC0	2017-07-10 06:37:00+03	35300.00
0C6ED7	2017-08-13 09:29:00+03	8200.00
0C6F44	2017-07-27 22:01:00+03	11600.00
0C6FCE	2017-08-04 01:54:00+03	46400.00
0C7023	2017-07-12 04:59:00+03	111600.00
0C7038	2017-07-28 08:41:00+03	139400.00
0C703F	2017-08-13 13:19:00+03	103400.00
0C7080	2017-07-08 14:49:00+03	32800.00
0C7163	2017-07-08 23:20:00+03	37900.00
0C720D	2017-07-06 10:18:00+03	112000.00
0C720E	2017-07-21 01:57:00+03	103500.00
0C7223	2017-07-06 18:11:00+03	56600.00
0C7272	2017-07-01 21:48:00+03	6700.00
0C72C0	2017-08-08 04:17:00+03	23600.00
0C72E0	2017-06-27 10:02:00+03	13600.00
0C72EB	2017-07-19 01:03:00+03	27200.00
0C73EA	2017-08-03 05:51:00+03	79600.00
0C7416	2017-07-23 19:12:00+03	135400.00
0C74BD	2017-08-12 06:45:00+03	75300.00
0C74C1	2017-07-15 04:58:00+03	29600.00
0C7630	2017-07-05 01:25:00+03	12000.00
0C7664	2017-07-06 23:30:00+03	99200.00
0C768B	2017-08-12 01:44:00+03	29900.00
0C7732	2017-07-03 12:52:00+03	106600.00
0C7746	2017-07-07 14:14:00+03	13400.00
0C7804	2017-08-14 11:34:00+03	58000.00
0C7821	2017-07-15 19:03:00+03	120400.00
0C7842	2017-07-19 00:18:00+03	190300.00
0C785F	2017-07-14 13:17:00+03	21800.00
0C78CC	2017-07-16 06:17:00+03	85800.00
0C78F2	2017-07-11 17:49:00+03	40100.00
0C7925	2017-08-15 00:28:00+03	24000.00
0C7999	2017-08-03 01:10:00+03	81200.00
0C79B6	2017-07-01 22:39:00+03	24800.00
0C79BB	2017-07-26 05:43:00+03	48800.00
0C79BD	2017-08-08 06:26:00+03	112000.00
0C7A0A	2017-08-11 14:02:00+03	27400.00
0C7A22	2017-07-23 17:38:00+03	25900.00
0C7A8F	2017-07-30 13:39:00+03	263100.00
0C7AA2	2017-08-15 04:33:00+03	135400.00
0C7ACF	2017-08-11 11:06:00+03	39200.00
0C7B2A	2017-07-21 18:28:00+03	89700.00
0C7B2B	2017-07-20 05:11:00+03	169900.00
0C7B3A	2017-07-20 00:08:00+03	121800.00
0C7B5F	2017-07-30 12:00:00+03	46000.00
0C7B67	2017-07-14 19:53:00+03	46200.00
0C7B79	2017-08-03 17:22:00+03	257600.00
0C7BD5	2017-07-25 07:47:00+03	56000.00
0C7BDB	2017-07-29 02:23:00+03	132800.00
0C7BEE	2017-07-26 06:22:00+03	44600.00
0C7C14	2017-07-24 17:10:00+03	113700.00
0C7C23	2017-08-08 09:47:00+03	6700.00
0C7CC8	2017-08-14 19:06:00+03	124300.00
0C7CF9	2017-07-20 20:28:00+03	136800.00
0C7D02	2017-07-27 21:15:00+03	74700.00
0C7D2A	2017-08-03 06:02:00+03	116900.00
0C7D63	2017-07-29 06:56:00+03	26800.00
0C7D6E	2017-08-08 14:12:00+03	87000.00
0C7D87	2017-08-12 23:47:00+03	53100.00
0C7DB7	2017-07-31 15:40:00+03	103200.00
0C7E79	2017-07-19 00:21:00+03	6700.00
0C7F05	2017-07-31 08:13:00+03	125500.00
0C7F2C	2017-08-10 02:27:00+03	266400.00
0C7F3A	2017-07-10 20:04:00+03	55800.00
0C7F3E	2017-06-29 02:49:00+03	88100.00
0C7F40	2017-07-13 16:30:00+03	35700.00
0C7F41	2017-07-21 16:30:00+03	55800.00
0C7F61	2017-07-20 08:02:00+03	86800.00
0C7FFB	2017-07-22 13:17:00+03	133200.00
0C803C	2017-08-09 01:54:00+03	56000.00
0C8043	2017-07-16 20:36:00+03	50600.00
0C80C4	2017-08-05 13:29:00+03	113600.00
0C80D3	2017-07-17 23:22:00+03	58200.00
0C80DF	2017-07-25 19:49:00+03	29400.00
0C8118	2017-08-03 03:18:00+03	23600.00
0C811D	2017-08-06 11:51:00+03	11600.00
0C814A	2017-07-11 00:04:00+03	144700.00
0C825D	2017-08-12 16:21:00+03	22000.00
0C826A	2017-07-24 05:50:00+03	28000.00
0C82AC	2017-08-13 03:22:00+03	13400.00
0C82B6	2017-07-24 23:27:00+03	26200.00
0C82DC	2017-07-27 16:11:00+03	70700.00
0C831F	2017-08-12 08:43:00+03	49600.00
0C833F	2017-06-30 14:20:00+03	45200.00
0C835F	2017-07-12 02:03:00+03	266400.00
0C836D	2017-07-24 07:49:00+03	46000.00
0C838D	2017-08-12 09:48:00+03	109800.00
0C83F0	2017-07-11 00:27:00+03	57800.00
0C8408	2017-07-24 14:53:00+03	19600.00
0C8415	2017-07-25 04:19:00+03	32400.00
0C8477	2017-07-22 13:55:00+03	30000.00
0C8484	2017-08-11 18:11:00+03	46000.00
0C84CD	2017-08-04 15:25:00+03	34000.00
0C84E9	2017-08-03 23:54:00+03	6300.00
0C84F7	2017-07-26 02:34:00+03	8000.00
0C8527	2017-08-03 16:20:00+03	6300.00
0C854C	2017-08-04 15:10:00+03	46400.00
0C8563	2017-08-10 04:34:00+03	64600.00
0C863D	2017-07-24 22:12:00+03	23600.00
0C8699	2017-07-05 06:20:00+03	38500.00
0C869B	2017-08-07 20:32:00+03	55800.00
0C86DD	2017-08-01 19:46:00+03	23200.00
0C8726	2017-07-19 06:06:00+03	37900.00
0C8733	2017-07-22 21:30:00+03	81700.00
0C87B0	2017-08-11 08:50:00+03	113200.00
0C87E2	2017-08-08 06:08:00+03	246000.00
0C880F	2017-06-28 11:02:00+03	46000.00
0C8818	2017-07-18 13:52:00+03	53300.00
0C8846	2017-07-20 20:33:00+03	15000.00
0C8874	2017-07-24 03:36:00+03	35200.00
0C888C	2017-07-25 03:45:00+03	94700.00
0C88AB	2017-07-13 18:15:00+03	93600.00
0C88D7	2017-07-24 09:12:00+03	271200.00
0C88DB	2017-07-23 21:26:00+03	52400.00
0C8939	2017-07-20 12:05:00+03	40800.00
0C8A0A	2017-07-23 03:06:00+03	34800.00
0C8A4A	2017-08-01 03:04:00+03	47200.00
0C8A68	2017-06-29 09:29:00+03	26000.00
0C8AD8	2017-08-09 15:15:00+03	57500.00
0C8ADC	2017-08-12 20:28:00+03	119500.00
0C8AFD	2017-07-12 22:38:00+03	115700.00
0C8B4D	2017-08-07 10:16:00+03	85000.00
0C8B8E	2017-07-05 16:36:00+03	40800.00
0C8C27	2017-07-30 11:02:00+03	46400.00
0C8C8F	2017-07-03 12:15:00+03	27600.00
0C8C91	2017-08-11 05:14:00+03	129600.00
0C8CAF	2017-07-17 17:17:00+03	25000.00
0C8CD3	2017-08-12 14:15:00+03	119800.00
0C8CD5	2017-08-06 10:53:00+03	28000.00
0C8D17	2017-08-01 20:01:00+03	88200.00
0C8D3A	2017-06-29 13:08:00+03	59300.00
0C8D7A	2017-07-18 22:39:00+03	40800.00
0C8D89	2017-07-18 06:15:00+03	28000.00
0C8D9A	2017-07-23 12:46:00+03	53300.00
0C8DA3	2017-07-28 22:53:00+03	53400.00
0C8DF1	2017-06-25 08:53:00+03	73600.00
0C8E81	2017-07-24 11:52:00+03	29100.00
0C8EB8	2017-08-11 20:19:00+03	143700.00
0C8ED9	2017-07-14 10:19:00+03	78100.00
0C8F24	2017-07-22 22:26:00+03	39300.00
0C8F3A	2017-08-03 18:48:00+03	26000.00
0C8F40	2017-07-13 03:51:00+03	60400.00
0C8F46	2017-08-03 08:48:00+03	32400.00
0C8FAF	2017-07-03 16:31:00+03	125800.00
0C8FC5	2017-07-23 10:27:00+03	56000.00
0C8FFB	2017-07-07 07:46:00+03	25200.00
0C90A1	2017-07-20 12:45:00+03	38600.00
0C90F7	2017-07-31 18:51:00+03	114800.00
0C913A	2017-08-13 01:43:00+03	78100.00
0C916B	2017-07-09 04:13:00+03	72400.00
0C916D	2017-07-09 01:37:00+03	28800.00
0C9185	2017-07-08 23:23:00+03	36200.00
0C91AE	2017-08-10 18:14:00+03	29400.00
0C91E6	2017-08-06 18:11:00+03	93400.00
0C922A	2017-08-04 21:01:00+03	92700.00
0C9256	2017-07-26 15:53:00+03	28800.00
0C9284	2017-07-20 05:54:00+03	21800.00
0C92B1	2017-07-11 01:45:00+03	86600.00
0C92D1	2017-07-19 01:04:00+03	101500.00
0C92E0	2017-07-14 14:17:00+03	12600.00
0C932C	2017-07-22 22:42:00+03	59600.00
0C9376	2017-07-08 05:33:00+03	55800.00
0C93E8	2017-07-04 10:55:00+03	22400.00
0C9416	2017-07-23 07:36:00+03	85000.00
0C948B	2017-07-05 23:59:00+03	73400.00
0C94FD	2017-08-13 18:05:00+03	85000.00
0C9532	2017-08-09 18:21:00+03	70600.00
0C9560	2017-08-08 04:49:00+03	29600.00
0C95BD	2017-07-17 13:51:00+03	99300.00
0C964F	2017-07-09 13:52:00+03	35800.00
0C9668	2017-07-19 17:40:00+03	266200.00
0C9682	2017-08-02 05:39:00+03	64700.00
0C968B	2017-07-13 22:30:00+03	105000.00
0C968E	2017-08-04 07:37:00+03	254900.00
0C968F	2017-07-23 09:34:00+03	46400.00
0C96EE	2017-08-05 01:26:00+03	43000.00
0C973D	2017-08-13 09:42:00+03	95600.00
0C9748	2017-08-11 14:48:00+03	88500.00
0C9781	2017-07-11 16:21:00+03	28000.00
0C9809	2017-08-09 01:21:00+03	35300.00
0C9822	2017-07-27 20:05:00+03	26000.00
0C982E	2017-08-13 22:30:00+03	131600.00
0C9856	2017-07-16 12:08:00+03	248500.00
0C987B	2017-07-28 00:39:00+03	174900.00
0C9893	2017-08-09 12:08:00+03	24000.00
0C98DD	2017-07-05 08:05:00+03	65000.00
0C98F2	2017-07-06 01:55:00+03	24800.00
0C98FB	2017-08-11 12:59:00+03	246000.00
0C997A	2017-07-20 13:30:00+03	76400.00
0C9993	2017-08-12 17:16:00+03	40000.00
0C99A9	2017-07-25 22:01:00+03	169900.00
0C9A30	2017-07-05 15:19:00+03	22000.00
0C9A37	2017-07-31 11:38:00+03	49600.00
0C9A42	2017-07-18 11:43:00+03	25100.00
0C9A86	2017-07-08 14:54:00+03	11600.00
0C9AD9	2017-07-03 14:51:00+03	86800.00
0C9B1C	2017-08-06 14:46:00+03	147000.00
0C9B97	2017-08-14 12:52:00+03	43600.00
0C9BCB	2017-07-02 08:30:00+03	166900.00
0C9BD2	2017-07-06 17:49:00+03	46400.00
0C9C76	2017-08-04 08:46:00+03	80700.00
0C9D5A	2017-07-10 08:38:00+03	22000.00
0C9D6E	2017-08-01 05:54:00+03	39300.00
0C9DD0	2017-07-31 05:01:00+03	111600.00
0C9DD7	2017-07-21 17:58:00+03	99300.00
0C9DFD	2017-07-07 15:21:00+03	60700.00
0C9E5E	2017-08-06 12:42:00+03	246000.00
0C9E72	2017-08-08 08:14:00+03	99200.00
0C9EB7	2017-08-10 12:59:00+03	89000.00
0C9EC7	2017-08-06 03:08:00+03	198300.00
0C9F01	2017-07-24 03:36:00+03	187600.00
0C9F0B	2017-07-21 11:38:00+03	246000.00
0C9F86	2017-07-30 03:51:00+03	24400.00
0C9FDE	2017-07-21 01:08:00+03	32800.00
0C9FF2	2017-08-04 18:53:00+03	81600.00
0CA081	2017-07-29 20:34:00+03	69400.00
0CA0C6	2017-07-29 18:25:00+03	27200.00
0CA148	2017-07-09 21:42:00+03	28000.00
0CA14D	2017-07-06 08:24:00+03	27200.00
0CA15B	2017-07-07 19:10:00+03	64200.00
0CA197	2017-08-11 06:19:00+03	81900.00
0CA19A	2017-08-13 03:00:00+03	133200.00
0CA19C	2017-07-16 17:14:00+03	71900.00
0CA1AC	2017-08-08 08:34:00+03	55500.00
0CA1F3	2017-08-15 16:46:00+03	7300.00
0CA298	2017-07-14 05:06:00+03	306600.00
0CA2CF	2017-07-07 22:34:00+03	39600.00
0CA304	2017-08-03 11:36:00+03	74900.00
0CA32A	2017-07-22 04:43:00+03	91100.00
0CA3EB	2017-07-10 01:18:00+03	28000.00
0CA431	2017-08-09 11:21:00+03	76600.00
0CA4A5	2017-08-14 19:50:00+03	111600.00
0CA4B5	2017-07-09 03:19:00+03	25000.00
0CA4C8	2017-07-06 10:00:00+03	70600.00
0CA51C	2017-08-15 10:40:00+03	189800.00
0CA576	2017-08-03 19:35:00+03	184200.00
0CA5D5	2017-07-14 15:01:00+03	155600.00
0CA600	2017-08-11 03:14:00+03	56000.00
0CA6AE	2017-07-20 15:42:00+03	70700.00
0CA722	2017-08-01 13:41:00+03	128800.00
0CA723	2017-07-10 20:47:00+03	14400.00
0CA78D	2017-07-19 10:20:00+03	48700.00
0CA834	2017-07-11 16:45:00+03	239400.00
0CA88C	2017-07-20 10:46:00+03	69600.00
0CA89C	2017-07-20 02:45:00+03	13400.00
0CA8DD	2017-07-11 03:06:00+03	25400.00
0CA924	2017-07-21 10:40:00+03	19600.00
0CA92A	2017-08-07 18:19:00+03	154400.00
0CA97B	2017-06-27 06:59:00+03	114200.00
0CAA05	2017-07-29 15:56:00+03	26000.00
0CAA3B	2017-07-26 02:04:00+03	95700.00
0CAAA4	2017-08-05 18:22:00+03	26000.00
0CAAC4	2017-07-26 21:56:00+03	39600.00
0CAAD6	2017-07-13 05:21:00+03	133100.00
0CAB4B	2017-07-20 14:14:00+03	152500.00
0CABDD	2017-07-15 11:25:00+03	66600.00
0CAC77	2017-07-31 13:55:00+03	11000.00
0CAC7D	2017-08-02 21:13:00+03	23200.00
0CACD2	2017-07-05 14:01:00+03	72200.00
0CACD4	2017-07-12 19:03:00+03	114600.00
0CACD7	2017-07-09 03:44:00+03	396500.00
0CACE6	2017-08-01 20:21:00+03	57300.00
0CAD4F	2017-07-02 16:29:00+03	14400.00
0CAE20	2017-07-24 02:15:00+03	42800.00
0CAE47	2017-08-05 13:07:00+03	67600.00
0CAE55	2017-07-05 16:34:00+03	26000.00
0CAEB9	2017-08-11 01:35:00+03	79600.00
0CAF3F	2017-07-15 04:28:00+03	66000.00
0CAF47	2017-08-03 11:16:00+03	148200.00
0CAF5D	2017-07-08 22:44:00+03	68800.00
0CAF79	2017-07-23 15:36:00+03	24400.00
0CAFE4	2017-07-25 12:17:00+03	135200.00
0CB00B	2017-07-17 04:30:00+03	280400.00
0CB066	2017-08-12 00:21:00+03	50800.00
0CB097	2017-07-30 06:11:00+03	114500.00
0CB0D1	2017-07-16 12:33:00+03	93900.00
0CB11D	2017-07-19 19:59:00+03	23600.00
0CB120	2017-07-15 18:21:00+03	78800.00
0CB15A	2017-08-13 12:17:00+03	67100.00
0CB160	2017-08-13 03:48:00+03	35200.00
0CB1BC	2017-07-25 02:12:00+03	25000.00
0CB28B	2017-08-12 08:13:00+03	23400.00
0CB31C	2017-07-26 14:27:00+03	40800.00
0CB323	2017-07-17 08:03:00+03	20200.00
0CB46F	2017-07-28 16:11:00+03	123000.00
0CB4AB	2017-07-24 11:07:00+03	13700.00
0CB513	2017-08-03 18:53:00+03	27200.00
0CB514	2017-07-13 05:27:00+03	67600.00
0CB516	2017-07-28 04:03:00+03	28300.00
0CB669	2017-07-26 01:45:00+03	168000.00
0CB6A7	2017-07-06 11:39:00+03	168000.00
0CB6B1	2017-06-30 03:37:00+03	13400.00
0CB706	2017-07-04 01:45:00+03	61200.00
0CB72D	2017-07-05 02:47:00+03	532800.00
0CB732	2017-07-29 17:39:00+03	111700.00
0CB748	2017-08-09 08:01:00+03	65600.00
0CB756	2017-08-05 18:32:00+03	139100.00
0CB7E0	2017-07-12 05:04:00+03	28800.00
0CB7FA	2017-06-29 16:09:00+03	45600.00
0CB80D	2017-07-31 05:36:00+03	25000.00
0CB858	2017-08-14 09:26:00+03	28000.00
0CB905	2017-08-14 01:30:00+03	61400.00
0CB91B	2017-08-04 06:14:00+03	84200.00
0CB967	2017-08-03 21:08:00+03	326200.00
0CBA6B	2017-07-31 02:12:00+03	64100.00
0CBAEE	2017-07-01 21:09:00+03	26000.00
0CBB12	2017-08-03 05:47:00+03	28800.00
0CBB66	2017-07-14 14:03:00+03	45200.00
0CBCA7	2017-07-13 16:11:00+03	32400.00
0CBCE4	2017-08-08 06:23:00+03	46800.00
0CBD5D	2017-07-15 20:41:00+03	13000.00
0CBDB0	2017-08-11 15:38:00+03	272400.00
0CBE60	2017-07-24 08:43:00+03	38400.00
0CBEF3	2017-08-14 02:52:00+03	23400.00
0CBF14	2017-08-08 06:43:00+03	99300.00
0CBFB9	2017-08-04 16:29:00+03	40800.00
0CBFF2	2017-07-09 14:26:00+03	24400.00
0CC008	2017-07-23 18:08:00+03	72400.00
0CC037	2017-07-03 13:25:00+03	57600.00
0CC07E	2017-07-20 04:05:00+03	27400.00
0CC09E	2017-07-27 14:35:00+03	111700.00
0CC0C2	2017-08-08 14:17:00+03	73300.00
0CC11F	2017-07-20 21:30:00+03	112400.00
0CC181	2017-08-15 02:12:00+03	76800.00
0CC1B8	2017-07-08 18:16:00+03	23400.00
0CC279	2017-08-04 01:14:00+03	88800.00
0CC286	2017-07-26 12:33:00+03	6700.00
0CC288	2017-08-12 07:34:00+03	86800.00
0CC2C6	2017-07-14 00:13:00+03	14000.00
0CC2EF	2017-07-20 08:27:00+03	236700.00
0CC2F4	2017-07-20 23:28:00+03	119500.00
0CC331	2017-06-30 07:48:00+03	13400.00
0CC348	2017-08-02 12:35:00+03	21400.00
0CC396	2017-07-25 17:07:00+03	50800.00
0CC45B	2017-07-18 04:18:00+03	28000.00
0CC474	2017-07-17 15:27:00+03	26800.00
0CC49F	2017-07-12 15:53:00+03	56000.00
0CC557	2017-07-18 00:26:00+03	46400.00
0CC5C8	2017-07-06 08:33:00+03	46400.00
0CC5D8	2017-07-08 12:50:00+03	24300.00
0CC60B	2017-07-29 18:13:00+03	67100.00
0CC667	2017-08-03 01:15:00+03	16400.00
0CC66D	2017-07-04 21:10:00+03	136200.00
0CC77B	2017-07-10 17:47:00+03	47400.00
0CC78B	2017-08-04 03:24:00+03	38600.00
0CC7E5	2017-07-02 09:14:00+03	166100.00
0CC7F3	2017-07-20 22:12:00+03	37900.00
0CC80C	2017-07-07 00:43:00+03	201200.00
0CC81E	2017-08-10 11:58:00+03	47200.00
0CC8A6	2017-07-05 21:51:00+03	131100.00
0CC8E8	2017-07-06 10:55:00+03	32700.00
0CC8FE	2017-08-09 12:53:00+03	24800.00
0CC919	2017-08-04 21:49:00+03	58200.00
0CC93D	2017-08-08 01:25:00+03	26000.00
0CC95E	2017-08-03 06:58:00+03	66600.00
0CCA04	2017-07-10 09:38:00+03	69000.00
0CCA18	2017-07-11 15:27:00+03	272400.00
0CCA96	2017-07-19 11:20:00+03	82900.00
0CCAAB	2017-07-07 10:22:00+03	52000.00
0CCAE7	2017-07-20 12:18:00+03	21400.00
0CCAEC	2017-07-08 05:57:00+03	88600.00
0CCB6B	2017-07-04 20:28:00+03	112000.00
0CCB97	2017-07-22 22:59:00+03	34000.00
0CCD20	2017-07-03 11:36:00+03	135400.00
0CCD43	2017-08-04 01:20:00+03	13000.00
0CCD69	2017-08-08 09:41:00+03	289300.00
0CCE21	2017-08-04 09:50:00+03	57600.00
0CCE7B	2017-08-13 06:15:00+03	13400.00
0CCE87	2017-07-23 05:10:00+03	88000.00
0CCEA8	2017-08-07 22:23:00+03	12600.00
0CCEBC	2017-08-08 01:43:00+03	605300.00
0CCEDE	2017-07-06 23:45:00+03	121400.00
0CCF12	2017-07-18 00:45:00+03	73300.00
0CCF6C	2017-07-14 06:49:00+03	56600.00
0CCF7C	2017-07-13 22:51:00+03	48800.00
0CCFFB	2017-07-25 22:48:00+03	36200.00
0CD022	2017-07-06 22:52:00+03	133200.00
0CD071	2017-07-10 19:56:00+03	111600.00
0CD07D	2017-07-24 01:41:00+03	57100.00
0CD08F	2017-08-14 18:14:00+03	28000.00
0CD092	2017-07-20 22:47:00+03	177200.00
0CD097	2017-07-10 05:55:00+03	55600.00
0CD120	2017-07-07 15:28:00+03	187800.00
0CD122	2017-07-02 10:48:00+03	117600.00
0CD1BA	2017-07-01 15:48:00+03	53100.00
0CD1C7	2017-08-06 19:24:00+03	48800.00
0CD1E5	2017-07-08 14:20:00+03	23200.00
0CD1F5	2017-07-15 02:25:00+03	16400.00
0CD210	2017-07-14 21:02:00+03	34000.00
0CD21F	2017-07-16 13:05:00+03	46000.00
0CD223	2017-08-04 14:20:00+03	115300.00
0CD23E	2017-07-28 05:26:00+03	203000.00
0CD247	2017-07-10 23:46:00+03	17000.00
0CD274	2017-07-10 09:26:00+03	13400.00
0CD2D6	2017-07-07 10:07:00+03	136200.00
0CD30A	2017-07-22 16:54:00+03	20000.00
0CD311	2017-07-23 15:34:00+03	32700.00
0CD3B9	2017-07-02 02:12:00+03	35700.00
0CD417	2017-07-06 21:32:00+03	67700.00
0CD452	2017-07-13 19:51:00+03	23600.00
0CD54B	2017-07-03 06:26:00+03	51200.00
0CD562	2017-08-01 18:55:00+03	34600.00
0CD58B	2017-08-13 13:12:00+03	6000.00
0CD5D6	2017-08-03 15:23:00+03	64500.00
0CD5DE	2017-06-29 09:32:00+03	37900.00
0CD66F	2017-07-27 01:58:00+03	50200.00
0CD678	2017-08-08 04:38:00+03	124300.00
0CD6BB	2017-07-15 03:10:00+03	111600.00
0CD6DC	2017-08-02 03:12:00+03	16400.00
0CD737	2017-06-26 20:45:00+03	68100.00
0CD7A5	2017-08-05 20:07:00+03	99300.00
0CD7AB	2017-08-05 21:44:00+03	46400.00
0CD7B2	2017-07-08 11:41:00+03	16400.00
0CD7D4	2017-07-23 09:42:00+03	31000.00
0CD82A	2017-07-13 12:11:00+03	54500.00
0CD859	2017-08-15 08:34:00+03	58600.00
0CD860	2017-07-05 05:33:00+03	10800.00
0CD899	2017-08-08 22:28:00+03	43800.00
0CD90F	2017-07-30 02:04:00+03	85700.00
0CD943	2017-07-28 18:58:00+03	78900.00
0CD987	2017-07-13 15:16:00+03	25800.00
0CD9A4	2017-08-05 10:58:00+03	54500.00
0CD9B2	2017-06-27 05:15:00+03	79900.00
0CDA25	2017-07-11 23:38:00+03	56600.00
0CDA6F	2017-08-02 01:01:00+03	24700.00
0CDB21	2017-08-12 11:04:00+03	44000.00
0CDB36	2017-07-06 01:37:00+03	51900.00
0CDB46	2017-07-02 10:02:00+03	103500.00
0CDB82	2017-07-15 04:30:00+03	33100.00
0CDB88	2017-08-11 13:29:00+03	73500.00
0CDB8D	2017-07-15 08:18:00+03	29400.00
0CDBA4	2017-07-13 11:36:00+03	86500.00
0CDBB2	2017-07-05 02:30:00+03	131100.00
0CDC32	2017-07-19 21:05:00+03	62000.00
0CDC7F	2017-08-01 09:48:00+03	39200.00
0CDC8F	2017-07-06 08:41:00+03	111600.00
0CDCF7	2017-06-27 12:23:00+03	184000.00
0CDD2D	2017-07-12 20:08:00+03	51900.00
0CDD52	2017-08-09 09:41:00+03	34000.00
0CDD53	2017-07-21 01:53:00+03	58800.00
0CDD63	2017-07-11 01:37:00+03	152900.00
0CDDDC	2017-07-21 22:01:00+03	66800.00
0CDDEA	2017-08-10 16:37:00+03	55800.00
0CDDFB	2017-08-04 05:40:00+03	76100.00
0CDE06	2017-08-15 17:41:00+03	55800.00
0CDE73	2017-07-31 02:08:00+03	47200.00
0CDEDC	2017-07-20 02:49:00+03	135400.00
0CDF05	2017-07-28 01:44:00+03	57500.00
0CDF37	2017-07-27 14:03:00+03	6800.00
0CDF43	2017-07-22 23:31:00+03	116400.00
0CDF69	2017-07-14 00:26:00+03	120700.00
0CE02E	2017-08-05 18:26:00+03	48900.00
0CE044	2017-06-29 12:01:00+03	15400.00
0CE05E	2017-08-08 01:32:00+03	67600.00
0CE082	2017-07-13 00:28:00+03	6300.00
0CE0DB	2017-07-29 13:23:00+03	55800.00
0CE220	2017-07-05 03:54:00+03	38200.00
0CE296	2017-07-18 08:30:00+03	47600.00
0CE2E9	2017-08-14 02:26:00+03	37700.00
0CE2EE	2017-08-02 14:42:00+03	96400.00
0CE344	2017-07-11 05:47:00+03	38400.00
0CE3A1	2017-07-18 00:50:00+03	99600.00
0CE413	2017-07-03 17:53:00+03	48800.00
0CE43F	2017-07-09 00:12:00+03	69200.00
0CE498	2017-08-09 18:26:00+03	118100.00
0CE4B3	2017-07-07 02:01:00+03	18900.00
0CE51B	2017-07-16 05:25:00+03	375200.00
0CE55F	2017-07-06 11:35:00+03	139100.00
0CE58F	2017-08-06 19:58:00+03	131100.00
0CE5A3	2017-06-28 04:45:00+03	74400.00
0CE636	2017-08-13 17:04:00+03	34800.00
0CE6A2	2017-07-23 10:46:00+03	56600.00
0CE7B0	2017-07-04 07:10:00+03	110500.00
0CE82A	2017-07-27 08:21:00+03	28800.00
0CE853	2017-07-13 09:26:00+03	229400.00
0CE86B	2017-08-12 02:16:00+03	46000.00
0CE86F	2017-07-05 08:39:00+03	47200.00
0CE8E9	2017-08-08 22:50:00+03	81300.00
0CE93F	2017-08-07 15:49:00+03	66600.00
0CE9A4	2017-07-23 00:18:00+03	95600.00
0CE9B6	2017-07-13 12:41:00+03	55800.00
0CEA67	2017-08-08 09:24:00+03	80000.00
0CEB0C	2017-07-26 07:30:00+03	260900.00
0CEBAD	2017-07-31 02:32:00+03	65900.00
0CEC0C	2017-07-21 22:05:00+03	23200.00
0CECC8	2017-07-12 07:25:00+03	120800.00
0CED47	2017-07-04 19:51:00+03	28000.00
0CEDBD	2017-08-12 20:24:00+03	27200.00
0CEE07	2017-07-03 17:16:00+03	28800.00
0CEE2E	2017-07-16 01:26:00+03	68400.00
0CEED6	2017-07-28 10:07:00+03	51800.00
0CEEE9	2017-07-03 00:46:00+03	26000.00
0CEF09	2017-08-01 22:18:00+03	144400.00
0CEF1A	2017-08-13 08:48:00+03	42800.00
0CEF96	2017-07-16 14:12:00+03	43200.00
0CEFE8	2017-07-20 01:56:00+03	24400.00
0CF03C	2017-07-02 19:52:00+03	24400.00
0CF0F1	2017-08-10 11:43:00+03	111000.00
0CF11B	2017-07-15 10:58:00+03	56000.00
0CF192	2017-08-05 06:52:00+03	153700.00
0CF1B7	2017-07-19 22:16:00+03	70700.00
0CF21C	2017-07-02 10:12:00+03	44700.00
0CF23F	2017-08-14 07:42:00+03	67600.00
0CF29E	2017-08-05 11:54:00+03	81900.00
0CF2BB	2017-08-06 15:20:00+03	168000.00
0CF30A	2017-07-22 06:51:00+03	16400.00
0CF35E	2017-08-14 17:51:00+03	40800.00
0CF3E9	2017-08-11 08:04:00+03	168600.00
0CF401	2017-08-07 12:10:00+03	27700.00
0CF4A5	2017-06-27 20:07:00+03	100600.00
0CF561	2017-08-09 21:27:00+03	47700.00
0CF598	2017-07-30 08:22:00+03	136200.00
0CF622	2017-07-06 15:51:00+03	47100.00
0CF639	2017-08-03 18:53:00+03	44600.00
0CF6B0	2017-07-25 08:07:00+03	35200.00
0CF6EE	2017-07-10 09:42:00+03	6700.00
0CF71A	2017-08-14 09:33:00+03	47400.00
0CF720	2017-08-15 06:49:00+03	48800.00
0CF747	2017-07-12 13:27:00+03	72400.00
0CF74E	2017-08-06 23:37:00+03	100200.00
0CF763	2017-07-04 19:21:00+03	185600.00
0CF801	2017-07-30 02:04:00+03	40000.00
0CF844	2017-07-06 19:11:00+03	23200.00
0CF84E	2017-08-05 13:34:00+03	69100.00
0CF8D1	2017-08-13 17:19:00+03	39300.00
0CF922	2017-07-16 17:12:00+03	28000.00
0CF934	2017-08-02 09:17:00+03	70200.00
0CF963	2017-07-16 10:27:00+03	66600.00
0CF9CE	2017-08-06 15:34:00+03	44600.00
0CFA5C	2017-08-12 03:15:00+03	15000.00
0CFA76	2017-08-07 22:14:00+03	49100.00
0CFA7E	2017-06-28 12:37:00+03	18600.00
0CFAFA	2017-07-20 20:53:00+03	47200.00
0CFB37	2017-07-03 02:48:00+03	94700.00
0CFB3D	2017-07-21 17:05:00+03	99700.00
0CFB3F	2017-07-13 03:57:00+03	26700.00
0CFB8B	2017-07-20 10:55:00+03	98700.00
0CFC56	2017-08-07 23:44:00+03	52300.00
0CFC6E	2017-07-09 14:26:00+03	70400.00
0CFC82	2017-07-13 20:46:00+03	21400.00
0CFD2D	2017-07-01 01:29:00+03	31600.00
0CFD45	2017-07-10 02:22:00+03	40600.00
0CFD7C	2017-08-05 18:02:00+03	38800.00
0CFDDD	2017-07-06 03:33:00+03	136200.00
0CFDF1	2017-07-31 11:03:00+03	63200.00
0CFE0B	2017-07-01 03:13:00+03	73500.00
0CFE4D	2017-08-05 21:05:00+03	14800.00
0CFEBD	2017-07-19 21:55:00+03	6200.00
0CFF2F	2017-07-07 23:11:00+03	25400.00
0CFF54	2017-07-11 16:47:00+03	6300.00
0CFF8C	2017-07-18 07:56:00+03	47100.00
0CFFAA	2017-07-03 16:53:00+03	18600.00
0CFFD7	2017-08-04 17:48:00+03	36600.00
0D0096	2017-07-04 23:12:00+03	30600.00
0D00C8	2017-07-31 18:17:00+03	62800.00
0D0104	2017-06-29 19:49:00+03	85000.00
0D01B2	2017-07-24 11:38:00+03	101200.00
0D01C3	2017-07-12 15:55:00+03	28800.00
0D0207	2017-07-06 23:57:00+03	16000.00
0D020A	2017-08-07 14:33:00+03	25100.00
0D0228	2017-08-14 23:59:00+03	46400.00
0D0231	2017-07-28 20:26:00+03	65500.00
0D0279	2017-08-03 12:26:00+03	131600.00
0D0281	2017-08-12 14:19:00+03	206400.00
0D0303	2017-06-30 19:59:00+03	44600.00
0D031A	2017-08-08 07:38:00+03	59400.00
0D0343	2017-07-23 14:24:00+03	64800.00
0D0366	2017-08-07 15:21:00+03	16400.00
0D0397	2017-08-14 14:20:00+03	133100.00
0D043E	2017-07-28 08:58:00+03	23100.00
0D0451	2017-07-04 14:42:00+03	56000.00
0D046F	2017-07-28 08:46:00+03	40800.00
0D0474	2017-07-05 22:23:00+03	43700.00
0D04C3	2017-07-15 09:33:00+03	114300.00
0D0501	2017-07-25 03:28:00+03	6800.00
0D0506	2017-08-13 03:54:00+03	57600.00
0D052B	2017-07-04 06:01:00+03	12200.00
0D0531	2017-07-17 11:26:00+03	38600.00
0D0563	2017-08-04 16:11:00+03	246000.00
0D05C7	2017-08-11 07:15:00+03	54800.00
0D0621	2017-07-07 17:15:00+03	12600.00
0D0646	2017-08-02 18:41:00+03	56000.00
0D0667	2017-07-23 16:18:00+03	47000.00
0D06A9	2017-07-31 13:35:00+03	99200.00
0D0722	2017-07-21 21:50:00+03	54400.00
0D0776	2017-07-08 11:32:00+03	133100.00
0D078C	2017-07-24 23:54:00+03	28800.00
0D0793	2017-07-30 16:03:00+03	20200.00
0D07A5	2017-08-10 03:50:00+03	118800.00
0D07F4	2017-08-01 07:03:00+03	207200.00
0D083B	2017-07-07 02:05:00+03	184000.00
0D089C	2017-07-12 15:45:00+03	30200.00
0D08DC	2017-07-31 01:22:00+03	7300.00
0D0900	2017-08-04 01:24:00+03	87700.00
0D099F	2017-07-27 05:40:00+03	55400.00
0D09AC	2017-07-21 17:46:00+03	36200.00
0D09F2	2017-08-11 03:14:00+03	75300.00
0D0A54	2017-07-13 17:25:00+03	42000.00
0D0AA4	2017-08-13 17:00:00+03	42600.00
0D0AC6	2017-07-15 21:46:00+03	84000.00
0D0B81	2017-07-22 09:02:00+03	27800.00
0D0B82	2017-07-21 20:52:00+03	128800.00
0D0BF4	2017-07-08 15:01:00+03	46000.00
0D0C63	2017-07-12 13:38:00+03	56600.00
0D0D77	2017-08-09 15:12:00+03	62600.00
0D0DB0	2017-08-13 15:22:00+03	98400.00
0D0DEF	2017-07-12 00:04:00+03	393800.00
0D0E3A	2017-07-24 11:37:00+03	20400.00
0D0E84	2017-07-26 00:48:00+03	100200.00
0D0E9F	2017-07-13 07:19:00+03	31700.00
0D0EF2	2017-07-06 13:55:00+03	78600.00
0D0F3F	2017-07-03 09:18:00+03	16400.00
0D0F57	2017-07-03 21:24:00+03	24400.00
0D0F9A	2017-07-21 16:58:00+03	111600.00
0D0FA5	2017-08-05 11:34:00+03	58600.00
0D1047	2017-08-10 07:23:00+03	28800.00
0D10AA	2017-08-10 05:02:00+03	27800.00
0D10B9	2017-07-29 15:14:00+03	83000.00
0D10CF	2017-08-08 18:46:00+03	30300.00
0D1104	2017-07-19 22:10:00+03	121200.00
0D1107	2017-07-17 15:17:00+03	24000.00
0D1177	2017-08-12 11:47:00+03	79500.00
0D1192	2017-08-03 04:05:00+03	369000.00
0D11B8	2017-08-02 09:52:00+03	14000.00
0D127E	2017-08-14 18:40:00+03	71900.00
0D1281	2017-07-14 16:37:00+03	155600.00
0D1291	2017-08-05 15:40:00+03	132500.00
0D1297	2017-08-06 10:05:00+03	57500.00
0D12D0	2017-07-26 12:23:00+03	70700.00
0D133C	2017-07-05 05:15:00+03	119500.00
0D1390	2017-07-25 08:12:00+03	72300.00
0D142F	2017-07-21 02:19:00+03	19600.00
0D14B2	2017-08-10 04:35:00+03	26700.00
0D1508	2017-08-14 06:12:00+03	27300.00
0D15F9	2017-07-20 04:15:00+03	31000.00
0D164F	2017-06-29 19:41:00+03	134200.00
0D1692	2017-07-22 00:34:00+03	12000.00
0D16E6	2017-07-04 17:36:00+03	147700.00
0D16EC	2017-08-14 22:35:00+03	49800.00
0D170E	2017-08-07 01:31:00+03	112700.00
0D1714	2017-07-22 10:00:00+03	43200.00
0D1719	2017-08-03 13:38:00+03	141200.00
0D1769	2017-08-06 14:25:00+03	36200.00
0D1782	2017-07-12 15:38:00+03	119500.00
0D17AF	2017-07-22 01:38:00+03	57400.00
0D17E5	2017-08-11 03:30:00+03	48500.00
0D1807	2017-07-14 21:44:00+03	199800.00
0D188E	2017-07-09 00:03:00+03	88100.00
0D18A6	2017-07-03 18:01:00+03	60400.00
0D190B	2017-08-07 06:14:00+03	51200.00
0D1968	2017-07-17 02:35:00+03	20600.00
0D1A10	2017-07-24 15:13:00+03	75200.00
0D1A3B	2017-07-30 15:13:00+03	44000.00
0D1AE9	2017-07-10 21:05:00+03	21500.00
0D1B34	2017-07-27 01:13:00+03	14800.00
0D1B4D	2017-08-03 23:58:00+03	11800.00
0D1C06	2017-07-13 19:30:00+03	38400.00
0D1CBF	2017-07-20 04:14:00+03	99600.00
0D1D03	2017-07-12 00:03:00+03	44500.00
0D1D21	2017-07-29 22:05:00+03	43500.00
0D1D38	2017-07-31 09:02:00+03	99200.00
0D1DF5	2017-07-31 12:25:00+03	55800.00
0D1E29	2017-08-10 17:37:00+03	21800.00
0D1E31	2017-07-06 16:58:00+03	38800.00
0D1E73	2017-07-26 08:11:00+03	94200.00
0D1E8F	2017-07-14 03:50:00+03	105600.00
0D1E94	2017-08-13 08:27:00+03	58800.00
0D1EA2	2017-07-05 17:45:00+03	83700.00
0D1EA5	2017-07-13 13:09:00+03	92800.00
0D1ED9	2017-07-08 06:48:00+03	75600.00
0D1F2A	2017-07-06 19:43:00+03	166900.00
0D1F82	2017-08-09 16:36:00+03	136800.00
0D1FB4	2017-08-02 13:25:00+03	147700.00
0D2003	2017-07-13 03:42:00+03	167400.00
0D2020	2017-08-13 13:29:00+03	94300.00
0D208C	2017-06-29 03:14:00+03	187800.00
0D20AE	2017-07-19 19:36:00+03	37700.00
0D20CC	2017-06-25 17:37:00+03	18600.00
0D2118	2017-08-06 18:54:00+03	45200.00
0D2159	2017-07-26 16:54:00+03	265800.00
0D219A	2017-08-09 15:35:00+03	34600.00
0D219E	2017-07-22 02:12:00+03	24400.00
0D21A9	2017-07-06 04:04:00+03	59200.00
0D21D6	2017-07-21 05:19:00+03	55800.00
0D21D8	2017-07-05 08:41:00+03	28800.00
0D21FC	2017-07-22 19:27:00+03	24600.00
0D2209	2017-08-06 00:03:00+03	47200.00
0D2376	2017-07-28 21:58:00+03	99300.00
0D2386	2017-08-08 19:09:00+03	325500.00
0D2435	2017-08-05 22:12:00+03	43200.00
0D2441	2017-07-10 04:10:00+03	56600.00
0D2458	2017-07-05 13:20:00+03	354200.00
0D2478	2017-08-14 17:20:00+03	125600.00
0D24A4	2017-07-26 04:29:00+03	75600.00
0D24C0	2017-08-08 12:34:00+03	48900.00
0D24F0	2017-07-18 23:31:00+03	123000.00
0D2525	2017-07-22 02:54:00+03	126000.00
0D252F	2017-07-06 11:47:00+03	23600.00
0D254A	2017-07-17 05:25:00+03	19600.00
0D25A0	2017-07-28 02:23:00+03	119600.00
0D25D6	2017-07-27 11:37:00+03	48400.00
0D260E	2017-07-31 20:07:00+03	114800.00
0D2648	2017-07-23 09:31:00+03	58900.00
0D26B5	2017-08-11 13:08:00+03	40800.00
0D26DB	2017-07-02 13:34:00+03	35700.00
0D274F	2017-07-03 17:36:00+03	25200.00
0D2799	2017-07-18 08:17:00+03	107200.00
0D27B8	2017-08-14 08:40:00+03	41900.00
0D2801	2017-07-26 05:55:00+03	112000.00
0D2808	2017-07-10 23:23:00+03	55800.00
0D282A	2017-08-03 12:18:00+03	38200.00
0D2875	2017-07-17 17:34:00+03	40000.00
0D287E	2017-07-04 22:25:00+03	296400.00
0D2880	2017-07-19 14:20:00+03	119600.00
0D2894	2017-08-07 07:21:00+03	102100.00
0D28E0	2017-07-12 05:30:00+03	54400.00
0D28FB	2017-07-02 00:57:00+03	17200.00
0D2987	2017-08-12 19:55:00+03	69500.00
0D29B5	2017-07-07 04:02:00+03	92800.00
0D29D3	2017-07-22 17:12:00+03	6700.00
0D29F8	2017-07-13 00:08:00+03	58800.00
0D2A80	2017-07-09 06:56:00+03	23200.00
0D2AB2	2017-07-31 07:02:00+03	6000.00
0D2AB6	2017-07-28 01:27:00+03	26000.00
0D2B15	2017-08-13 00:26:00+03	66600.00
0D2B28	2017-07-11 03:39:00+03	124200.00
0D2B2F	2017-08-12 07:34:00+03	64300.00
0D2B81	2017-08-04 09:39:00+03	55800.00
0D2C03	2017-07-15 09:48:00+03	90400.00
0D2C8F	2017-08-01 05:13:00+03	57600.00
0D2CBF	2017-07-21 04:00:00+03	29600.00
0D2CF3	2017-08-03 22:44:00+03	31000.00
0D2D0A	2017-06-30 12:03:00+03	147700.00
0D2D1B	2017-07-28 12:15:00+03	80000.00
0D2D28	2017-07-17 09:51:00+03	67900.00
0D2D5B	2017-07-25 20:19:00+03	168200.00
0D2DFD	2017-07-16 18:02:00+03	64600.00
0D2EE9	2017-08-11 19:42:00+03	58200.00
0D2EFE	2017-07-13 06:15:00+03	38600.00
0D2F30	2017-07-05 07:01:00+03	50600.00
0D2F46	2017-07-13 07:42:00+03	50000.00
0D2F49	2017-07-08 20:18:00+03	27200.00
0D2FAF	2017-08-15 10:12:00+03	25200.00
0D2FC6	2017-07-11 08:25:00+03	74400.00
0D3031	2017-07-14 12:42:00+03	30000.00
0D30B1	2017-07-05 18:50:00+03	65600.00
0D30F2	2017-08-15 08:16:00+03	37200.00
0D3144	2017-07-31 21:03:00+03	17600.00
0D3167	2017-07-11 13:31:00+03	39500.00
0D316D	2017-07-15 11:56:00+03	252200.00
0D316F	2017-08-12 07:48:00+03	54400.00
0D3188	2017-07-17 09:27:00+03	55800.00
0D31F4	2017-08-08 01:14:00+03	272400.00
0D3206	2017-07-23 08:41:00+03	42800.00
0D320A	2017-07-16 06:38:00+03	132400.00
0D323A	2017-07-29 18:25:00+03	113000.00
0D323B	2017-08-10 02:13:00+03	40600.00
0D3241	2017-07-16 20:41:00+03	19600.00
0D3270	2017-07-12 03:35:00+03	75600.00
0D3272	2017-07-06 13:31:00+03	131100.00
0D332F	2017-08-07 23:49:00+03	24800.00
0D335F	2017-07-20 03:19:00+03	265700.00
0D33EE	2017-07-18 15:12:00+03	75300.00
0D345A	2017-07-25 21:19:00+03	70500.00
0D346C	2017-07-08 00:49:00+03	124000.00
0D34A6	2017-07-05 09:49:00+03	92800.00
0D34D9	2017-07-24 13:58:00+03	168400.00
0D34ED	2017-07-25 06:00:00+03	144400.00
0D3544	2017-07-24 16:23:00+03	78300.00
0D3584	2017-07-27 00:18:00+03	26800.00
0D35FA	2017-07-29 15:49:00+03	199700.00
0D3623	2017-07-11 09:34:00+03	103900.00
0D375D	2017-08-13 13:11:00+03	20200.00
0D382F	2017-08-15 05:08:00+03	67800.00
0D384B	2017-07-30 06:02:00+03	117700.00
0D3888	2017-08-11 14:36:00+03	65900.00
0D38AC	2017-08-15 11:50:00+03	277000.00
0D38E7	2017-07-22 13:15:00+03	26700.00
0D38F4	2017-07-29 18:46:00+03	112300.00
0D391D	2017-07-28 20:14:00+03	112000.00
0D39AA	2017-07-26 08:43:00+03	56000.00
0D3A2D	2017-08-03 00:47:00+03	31400.00
0D3A2F	2017-08-02 20:05:00+03	138600.00
0D3A64	2017-07-18 09:50:00+03	180800.00
0D3B14	2017-08-05 23:50:00+03	58200.00
0D3B2F	2017-07-19 03:30:00+03	136200.00
0D3B95	2017-07-17 12:51:00+03	53300.00
0D3BA1	2017-07-19 11:33:00+03	47100.00
0D3BAD	2017-07-29 23:19:00+03	99500.00
0D3BD3	2017-07-29 07:55:00+03	6800.00
0D3BE3	2017-08-09 07:52:00+03	16400.00
0D3D6B	2017-07-15 22:39:00+03	73300.00
0D3DF1	2017-07-20 14:27:00+03	265700.00
0D3DF7	2017-07-04 23:47:00+03	335000.00
0D3F30	2017-07-09 18:13:00+03	56200.00
0D3F58	2017-07-15 02:55:00+03	83000.00
0D3F5D	2017-07-29 08:17:00+03	199700.00
0D3F91	2017-07-26 03:01:00+03	58900.00
0D3FBE	2017-07-26 23:06:00+03	28000.00
0D3FD9	2017-08-08 17:54:00+03	36200.00
0D4020	2017-08-09 16:46:00+03	6000.00
0D4098	2017-08-01 07:27:00+03	38600.00
0D40A8	2017-06-28 00:53:00+03	64800.00
0D40B1	2017-06-29 02:39:00+03	47100.00
0D40E0	2017-08-12 10:07:00+03	57800.00
0D419E	2017-07-16 01:56:00+03	36000.00
0D41A0	2017-08-13 18:29:00+03	30200.00
0D41A2	2017-08-09 12:35:00+03	25800.00
0D41AC	2017-08-07 10:59:00+03	402400.00
0D4247	2017-07-16 15:29:00+03	28000.00
0D425C	2017-07-24 21:10:00+03	152900.00
0D426C	2017-08-06 10:01:00+03	10600.00
0D42D4	2017-07-28 14:34:00+03	96100.00
0D42F9	2017-08-13 00:15:00+03	279200.00
0D437C	2017-07-24 15:13:00+03	93900.00
0D43EE	2017-08-09 23:06:00+03	57400.00
0D4443	2017-07-14 04:17:00+03	34000.00
0D4492	2017-07-12 11:41:00+03	49300.00
0D44BB	2017-08-14 05:00:00+03	28300.00
0D4536	2017-08-06 19:35:00+03	88900.00
0D459E	2017-07-22 03:43:00+03	156500.00
0D45A1	2017-07-31 05:24:00+03	10800.00
0D45C3	2017-07-30 05:11:00+03	155000.00
0D461C	2017-08-10 16:28:00+03	32200.00
0D4638	2017-08-05 19:18:00+03	133100.00
0D46C9	2017-08-14 19:11:00+03	26800.00
0D473C	2017-07-02 14:44:00+03	21000.00
0D4791	2017-07-16 22:04:00+03	14400.00
0D47A2	2017-08-04 09:48:00+03	61500.00
0D47A8	2017-08-10 05:23:00+03	172700.00
0D47D5	2017-08-03 19:26:00+03	30200.00
0D4808	2017-07-31 22:51:00+03	282800.00
0D480E	2017-08-07 23:32:00+03	272400.00
0D4841	2017-07-22 19:30:00+03	26800.00
0D4865	2017-08-06 01:03:00+03	115900.00
0D4881	2017-07-02 11:53:00+03	202800.00
0D48C9	2017-08-14 14:59:00+03	192400.00
0D48F8	2017-08-12 20:50:00+03	99200.00
0D48FD	2017-07-20 22:21:00+03	265600.00
0D48FF	2017-08-07 00:03:00+03	210000.00
0D492C	2017-07-09 05:04:00+03	67200.00
0D49FA	2017-07-11 11:37:00+03	28000.00
0D4A12	2017-07-25 13:48:00+03	57500.00
0D4A51	2017-07-14 09:08:00+03	168300.00
0D4A8E	2017-07-08 09:10:00+03	63500.00
0D4AA2	2017-07-11 04:10:00+03	24400.00
0D4B1A	2017-07-16 16:43:00+03	46400.00
0D4B84	2017-07-15 04:14:00+03	28800.00
0D4BE8	2017-07-27 07:49:00+03	62800.00
0D4C12	2017-07-27 22:49:00+03	128600.00
0D4C57	2017-08-02 08:07:00+03	20000.00
0D4C5D	2017-07-23 11:06:00+03	21400.00
0D4CA1	2017-08-15 00:46:00+03	140500.00
0D4D1D	2017-07-11 20:54:00+03	58000.00
0D4D79	2017-08-12 09:58:00+03	9800.00
0D4DA4	2017-07-27 05:53:00+03	57600.00
0D4DC2	2017-08-04 13:29:00+03	23200.00
0D4E9C	2017-07-18 22:54:00+03	268400.00
0D4EB4	2017-08-12 13:05:00+03	69600.00
0D4FDD	2017-08-10 18:57:00+03	25600.00
0D5087	2017-08-12 02:41:00+03	18300.00
0D50C7	2017-07-20 18:35:00+03	35300.00
0D50F4	2017-07-03 05:43:00+03	19100.00
0D5106	2017-07-26 22:25:00+03	38600.00
0D512D	2017-08-03 21:50:00+03	50100.00
0D519C	2017-07-21 22:02:00+03	271100.00
0D51C4	2017-07-22 23:33:00+03	138000.00
0D51E6	2017-07-19 04:12:00+03	56000.00
0D525C	2017-07-11 05:24:00+03	63700.00
0D526D	2017-08-05 19:31:00+03	83600.00
0D5290	2017-07-26 15:52:00+03	63400.00
0D52CB	2017-08-07 21:51:00+03	28800.00
0D5358	2017-08-01 11:13:00+03	169300.00
0D5366	2017-07-21 18:53:00+03	26000.00
0D53D4	2017-07-16 21:09:00+03	114400.00
0D53EA	2017-07-14 15:23:00+03	26000.00
0D53FC	2017-08-12 04:48:00+03	13800.00
0D5440	2017-08-12 15:20:00+03	8000.00
0D5495	2017-08-07 23:39:00+03	284400.00
0D5504	2017-07-18 07:14:00+03	56000.00
0D551C	2017-08-04 09:42:00+03	16400.00
0D567F	2017-07-25 12:36:00+03	54500.00
0D5681	2017-07-01 03:58:00+03	115000.00
0D5687	2017-07-26 18:27:00+03	83600.00
0D5698	2017-08-06 08:41:00+03	51600.00
0D576F	2017-07-28 14:51:00+03	25400.00
0D578C	2017-07-19 16:42:00+03	66000.00
0D57B2	2017-07-12 01:55:00+03	34700.00
0D57B7	2017-08-11 22:27:00+03	65400.00
0D5827	2017-07-31 23:10:00+03	100600.00
0D588D	2017-07-29 06:20:00+03	33300.00
0D58DF	2017-08-05 04:12:00+03	6000.00
0D5978	2017-07-03 10:17:00+03	75300.00
0D599A	2017-07-06 22:02:00+03	27700.00
0D59F2	2017-07-29 07:47:00+03	136800.00
0D5A15	2017-08-13 07:46:00+03	8600.00
0D5A28	2017-07-03 16:45:00+03	57600.00
0D5A2C	2017-08-09 09:35:00+03	399600.00
0D5A45	2017-07-28 06:34:00+03	115600.00
0D5A56	2017-07-29 18:27:00+03	43200.00
0D5A9F	2017-08-08 05:47:00+03	54400.00
0D5AC8	2017-07-08 15:08:00+03	172000.00
0D5AD5	2017-06-30 12:52:00+03	26000.00
0D5AE3	2017-08-10 14:56:00+03	21200.00
0D5B99	2017-07-30 15:12:00+03	7300.00
0D5BA8	2017-06-29 14:41:00+03	34000.00
0D5BBE	2017-07-18 04:15:00+03	50000.00
0D5C27	2017-06-27 04:59:00+03	26700.00
0D5C5B	2017-08-07 19:35:00+03	20200.00
0D5C69	2017-08-12 00:30:00+03	55800.00
0D5C6F	2017-07-06 02:25:00+03	48800.00
0D5C76	2017-08-07 22:24:00+03	133200.00
0D5CB5	2017-07-11 00:27:00+03	240600.00
0D5CEF	2017-08-03 11:12:00+03	58100.00
0D5D1C	2017-07-15 21:52:00+03	46400.00
0D5D56	2017-07-04 20:25:00+03	67600.00
0D5D94	2017-08-10 01:26:00+03	155200.00
0D5DEC	2017-07-22 23:15:00+03	81700.00
0D5E43	2017-08-14 04:38:00+03	62800.00
0D5E7E	2017-07-24 13:34:00+03	125000.00
0D5F16	2017-08-14 10:05:00+03	28000.00
0D5F1E	2017-07-30 20:42:00+03	84200.00
0D5F2E	2017-07-06 22:32:00+03	141300.00
0D5F82	2017-07-12 00:01:00+03	25100.00
0D5F97	2017-06-29 21:00:00+03	70800.00
0D5FE6	2017-07-19 22:48:00+03	27800.00
0D6057	2017-07-08 05:31:00+03	71100.00
0D60AD	2017-08-06 16:14:00+03	78300.00
0D60C1	2017-07-30 23:59:00+03	333800.00
0D60F8	2017-07-28 02:41:00+03	31600.00
0D610A	2017-07-15 11:48:00+03	168400.00
0D6112	2017-07-20 18:08:00+03	13400.00
0D6197	2017-07-30 00:28:00+03	184000.00
0D61AB	2017-07-10 12:36:00+03	44300.00
0D61B0	2017-07-23 06:13:00+03	55800.00
0D621E	2017-07-22 18:11:00+03	138000.00
0D624A	2017-07-29 15:39:00+03	27000.00
0D6270	2017-07-30 22:55:00+03	248400.00
0D62BF	2017-07-28 18:33:00+03	37100.00
0D6324	2017-07-09 12:44:00+03	369000.00
0D635B	2017-08-11 12:18:00+03	176500.00
0D63AF	2017-07-16 19:33:00+03	126900.00
0D63DA	2017-08-01 12:55:00+03	27200.00
0D640B	2017-07-27 01:44:00+03	125200.00
0D6434	2017-07-08 05:34:00+03	83600.00
0D6456	2017-08-05 19:03:00+03	54000.00
0D64B0	2017-07-18 10:05:00+03	113700.00
0D64C4	2017-07-24 00:16:00+03	244600.00
0D6521	2017-08-01 15:34:00+03	23200.00
0D6524	2017-07-15 22:21:00+03	13400.00
0D6564	2017-08-04 02:37:00+03	68100.00
0D65D3	2017-07-23 12:34:00+03	56000.00
0D6607	2017-08-15 12:59:00+03	26800.00
0D668A	2017-07-24 16:15:00+03	25400.00
0D6690	2017-07-22 15:39:00+03	27900.00
0D66A1	2017-08-04 13:11:00+03	62000.00
0D673F	2017-07-02 04:46:00+03	20400.00
0D6784	2017-07-13 02:37:00+03	80900.00
0D67D0	2017-07-10 10:48:00+03	123000.00
0D6822	2017-07-01 00:10:00+03	18300.00
0D682A	2017-07-15 21:04:00+03	26600.00
0D6869	2017-08-07 21:17:00+03	73200.00
0D68F2	2017-08-08 10:10:00+03	60000.00
0D6962	2017-08-14 22:48:00+03	123000.00
0D699D	2017-07-15 23:39:00+03	43600.00
0D69D7	2017-08-02 17:45:00+03	787500.00
0D6A04	2017-08-11 12:12:00+03	123000.00
0D6A0D	2017-08-06 10:49:00+03	181200.00
0D6AB5	2017-07-27 15:18:00+03	38400.00
0D6B0D	2017-08-15 03:30:00+03	31800.00
0D6B1C	2017-07-31 02:32:00+03	44600.00
0D6B2B	2017-07-11 16:11:00+03	91500.00
0D6B8D	2017-07-03 15:56:00+03	27800.00
0D6BF5	2017-08-12 12:02:00+03	40800.00
0D6C14	2017-07-27 21:41:00+03	38800.00
0D6C7A	2017-07-23 16:24:00+03	99200.00
0D6C97	2017-07-28 03:10:00+03	60700.00
0D6CBD	2017-07-11 19:10:00+03	67800.00
0D6D1E	2017-07-31 03:10:00+03	67600.00
0D6DAD	2017-07-23 04:18:00+03	46400.00
0D6DDD	2017-08-11 16:35:00+03	109600.00
0D6E46	2017-08-06 12:13:00+03	49100.00
0D6E49	2017-07-20 21:02:00+03	69800.00
0D6F7C	2017-07-23 23:42:00+03	133100.00
0D701D	2017-07-25 01:53:00+03	42100.00
0D7026	2017-08-14 01:04:00+03	19800.00
0D702D	2017-07-24 03:40:00+03	62600.00
0D7055	2017-07-25 12:59:00+03	28000.00
0D707D	2017-07-21 04:24:00+03	84100.00
0D719E	2017-06-29 21:53:00+03	98400.00
0D7254	2017-07-31 20:32:00+03	172200.00
0D72FB	2017-07-23 00:36:00+03	99200.00
0D7312	2017-07-10 12:51:00+03	271200.00
0D731E	2017-07-21 03:13:00+03	65500.00
0D732D	2017-07-12 06:47:00+03	123000.00
0D7356	2017-07-07 08:56:00+03	372500.00
0D7387	2017-07-30 05:01:00+03	19600.00
0D7395	2017-07-17 01:14:00+03	27200.00
0D745A	2017-07-05 14:45:00+03	75600.00
0D747B	2017-07-01 02:34:00+03	6000.00
0D74C2	2017-08-13 22:57:00+03	88000.00
0D7565	2017-07-19 00:56:00+03	48800.00
0D7599	2017-08-02 23:53:00+03	90800.00
0D75BE	2017-08-11 11:32:00+03	70700.00
0D75C8	2017-07-21 07:50:00+03	85000.00
0D763D	2017-07-11 17:35:00+03	398600.00
0D7648	2017-06-30 22:15:00+03	67600.00
0D766B	2017-07-15 06:58:00+03	55800.00
0D769B	2017-07-24 18:18:00+03	15000.00
0D76EF	2017-07-16 08:39:00+03	20200.00
0D76F8	2017-07-22 08:48:00+03	74800.00
0D77BB	2017-08-06 04:23:00+03	28000.00
0D77F9	2017-07-29 17:46:00+03	208200.00
0D784D	2017-08-13 09:25:00+03	29100.00
0D7881	2017-08-09 18:08:00+03	124200.00
0D789E	2017-07-12 01:19:00+03	248500.00
0D78CC	2017-08-09 09:36:00+03	62100.00
0D78D7	2017-07-26 04:10:00+03	126100.00
0D79A2	2017-08-13 19:30:00+03	131600.00
0D79E2	2017-07-12 02:56:00+03	23200.00
0D7A8E	2017-07-30 10:41:00+03	18000.00
0D7A92	2017-08-07 00:01:00+03	92800.00
0D7AA5	2017-07-01 08:25:00+03	67200.00
0D7AEA	2017-08-07 12:44:00+03	22000.00
0D7AF2	2017-07-10 00:02:00+03	28000.00
0D7B98	2017-08-02 12:32:00+03	137600.00
0D7BB0	2017-07-02 06:41:00+03	26600.00
0D7C17	2017-08-11 14:05:00+03	26000.00
0D7C1D	2017-07-03 13:08:00+03	31200.00
0D7C22	2017-08-12 23:49:00+03	90000.00
0D7C31	2017-07-30 19:57:00+03	36200.00
0D7C45	2017-07-04 09:49:00+03	27400.00
0D7CF1	2017-08-13 01:34:00+03	283100.00
0D7DAE	2017-07-26 09:31:00+03	70700.00
0D7DB6	2017-08-04 17:27:00+03	24800.00
0D7DD3	2017-07-24 13:59:00+03	60000.00
0D7DF3	2017-08-08 05:10:00+03	142300.00
0D7E37	2017-08-01 21:17:00+03	102100.00
0D7E50	2017-08-02 14:36:00+03	40000.00
0D7E82	2017-07-28 06:50:00+03	40000.00
0D7EE6	2017-07-30 11:02:00+03	88900.00
0D7F43	2017-08-12 20:23:00+03	18600.00
0D7F51	2017-08-12 08:18:00+03	47000.00
0D7F7D	2017-08-14 02:46:00+03	12600.00
0D8036	2017-07-26 21:43:00+03	43100.00
0D804B	2017-07-23 14:05:00+03	51300.00
0D80E5	2017-07-02 14:05:00+03	80900.00
0D80F1	2017-07-21 17:59:00+03	114600.00
0D811B	2017-07-22 04:52:00+03	26700.00
0D814C	2017-07-02 04:09:00+03	125200.00
0D8164	2017-07-04 16:35:00+03	231800.00
0D818C	2017-08-14 09:37:00+03	149200.00
0D81D2	2017-08-01 13:43:00+03	47300.00
0D8207	2017-07-16 12:19:00+03	76900.00
0D8214	2017-07-15 10:30:00+03	26000.00
0D8260	2017-08-04 18:55:00+03	174400.00
0D82A2	2017-07-31 11:03:00+03	153300.00
0D82AE	2017-07-11 12:53:00+03	38400.00
0D82C9	2017-08-13 23:24:00+03	106400.00
0D8367	2017-07-04 00:26:00+03	79400.00
0D8477	2017-08-08 07:31:00+03	103800.00
0D84DB	2017-07-10 05:24:00+03	49900.00
0D84ED	2017-07-09 18:11:00+03	185600.00
0D84FA	2017-07-01 05:07:00+03	20200.00
0D851D	2017-07-30 12:01:00+03	56000.00
0D852D	2017-07-19 15:40:00+03	55800.00
0D857F	2017-07-29 12:28:00+03	15900.00
0D8584	2017-07-27 05:35:00+03	94000.00
0D85B4	2017-08-12 03:31:00+03	59600.00
0D85D6	2017-07-09 01:45:00+03	92600.00
0D869A	2017-07-06 11:49:00+03	96000.00
0D872F	2017-08-10 08:40:00+03	44500.00
0D8734	2017-08-12 22:06:00+03	56600.00
0D8757	2017-08-13 18:01:00+03	37900.00
0D87B9	2017-07-21 00:15:00+03	14900.00
0D87DF	2017-08-07 17:13:00+03	46000.00
0D88AC	2017-08-04 09:16:00+03	8400.00
0D88BF	2017-07-01 20:36:00+03	26800.00
0D89BA	2017-07-06 20:54:00+03	48100.00
0D89FC	2017-08-10 12:07:00+03	49300.00
0D8A18	2017-07-08 11:55:00+03	60400.00
0D8A2C	2017-08-11 01:31:00+03	136800.00
0D8A62	2017-08-09 15:39:00+03	43000.00
0D8A88	2017-07-17 03:27:00+03	26200.00
0D8AAB	2017-07-19 19:47:00+03	265700.00
0D8AE9	2017-08-09 20:27:00+03	37900.00
0D8C3A	2017-07-02 10:34:00+03	14000.00
0D8C3B	2017-08-09 07:57:00+03	32800.00
0D8C52	2017-07-24 18:35:00+03	25800.00
0D8C90	2017-07-19 08:06:00+03	28800.00
0D8D08	2017-06-25 00:14:00+03	119500.00
0D8D0E	2017-08-09 06:41:00+03	26800.00
0D8D72	2017-08-03 22:18:00+03	28800.00
0D8DDC	2017-07-15 18:49:00+03	26200.00
0D8DE8	2017-07-18 13:41:00+03	62000.00
0D8DEA	2017-08-08 00:26:00+03	131600.00
0D8E28	2017-07-06 23:14:00+03	166900.00
0D8E4C	2017-07-12 03:09:00+03	27200.00
0D8E4F	2017-07-12 12:48:00+03	135600.00
0D8E63	2017-08-10 00:40:00+03	109600.00
0D8E64	2017-07-11 17:25:00+03	38600.00
0D8E65	2017-07-08 07:46:00+03	31400.00
0D8EA1	2017-08-15 01:04:00+03	23200.00
0D8EA4	2017-07-08 17:10:00+03	82700.00
0D8EE8	2017-08-04 11:31:00+03	109800.00
0D8F45	2017-07-25 09:19:00+03	79600.00
0D8F48	2017-07-20 18:07:00+03	17000.00
0D8F6D	2017-07-22 17:53:00+03	31600.00
0D904E	2017-06-25 11:17:00+03	206400.00
0D9077	2017-07-12 23:44:00+03	6700.00
0D9147	2017-07-19 04:37:00+03	62700.00
0D9199	2017-08-04 10:22:00+03	13400.00
0D9264	2017-07-16 11:16:00+03	56600.00
0D926A	2017-08-01 20:47:00+03	79600.00
0D9279	2017-08-08 03:54:00+03	31600.00
0D92CC	2017-07-27 06:16:00+03	9300.00
0D92E3	2017-07-04 16:35:00+03	104200.00
0D92F2	2017-08-14 21:36:00+03	106400.00
0D9379	2017-07-26 21:21:00+03	38200.00
0D9382	2017-07-19 09:35:00+03	6700.00
0D94A9	2017-07-01 01:23:00+03	123600.00
0D951C	2017-07-23 12:25:00+03	62100.00
0D9521	2017-06-28 18:53:00+03	57100.00
0D9533	2017-07-06 18:05:00+03	134400.00
0D95B7	2017-08-12 06:57:00+03	12000.00
0D95E5	2017-07-13 17:38:00+03	46200.00
0D961E	2017-06-30 02:38:00+03	16400.00
0D967B	2017-07-16 10:55:00+03	14000.00
0D96A3	2017-07-12 09:00:00+03	81600.00
0D96BE	2017-08-12 14:59:00+03	26700.00
0D974D	2017-08-11 23:27:00+03	117200.00
0D9752	2017-08-04 21:01:00+03	178300.00
0D9772	2017-08-08 07:12:00+03	77400.00
0D9774	2017-07-01 04:38:00+03	26000.00
0D9783	2017-07-21 05:11:00+03	36400.00
0D978B	2017-06-29 20:30:00+03	77600.00
0D987A	2017-08-02 07:38:00+03	25000.00
0D98E8	2017-07-15 23:24:00+03	81900.00
0D99A6	2017-07-09 01:07:00+03	37100.00
0D99BA	2017-08-01 08:13:00+03	135600.00
0D99F4	2017-07-14 14:38:00+03	39700.00
0D9A5B	2017-07-14 02:13:00+03	194200.00
0D9A62	2017-07-20 21:33:00+03	94700.00
0D9A68	2017-07-23 08:19:00+03	34600.00
0D9AD1	2017-07-11 18:14:00+03	32800.00
0D9AD2	2017-08-06 03:52:00+03	184900.00
0D9AEC	2017-07-18 06:17:00+03	57600.00
0D9AFE	2017-07-04 05:43:00+03	61800.00
0D9B3E	2017-08-02 18:47:00+03	14000.00
0D9B5A	2017-08-09 02:07:00+03	42800.00
0D9B6B	2017-07-05 22:55:00+03	123000.00
0D9B74	2017-07-15 01:11:00+03	85000.00
0D9B93	2017-07-26 10:18:00+03	199800.00
0D9B9E	2017-07-22 05:43:00+03	38600.00
0D9BDD	2017-07-04 07:58:00+03	185800.00
0D9C42	2017-07-30 12:36:00+03	94000.00
0D9C6C	2017-07-12 09:41:00+03	186900.00
0D9D02	2017-07-16 02:54:00+03	78800.00
0D9D7C	2017-07-23 02:59:00+03	60400.00
0D9E45	2017-07-15 15:07:00+03	25000.00
0D9E51	2017-08-08 05:53:00+03	112000.00
0D9E81	2017-08-15 13:38:00+03	101000.00
0D9EB1	2017-07-19 01:37:00+03	129600.00
0D9EBB	2017-07-20 04:01:00+03	64800.00
0D9ED6	2017-07-28 04:41:00+03	24700.00
0D9EDD	2017-08-09 02:48:00+03	30200.00
0D9F41	2017-08-05 00:31:00+03	55800.00
0D9F7B	2017-07-06 09:07:00+03	212100.00
0D9FBA	2017-07-06 19:10:00+03	70100.00
0DA02F	2017-07-13 12:41:00+03	23500.00
0DA035	2017-07-23 22:07:00+03	85000.00
0DA05F	2017-07-10 02:48:00+03	56100.00
0DA0E6	2017-07-02 11:53:00+03	54000.00
0DA182	2017-07-22 09:07:00+03	19600.00
0DA18F	2017-07-09 05:35:00+03	21400.00
0DA19F	2017-07-09 23:01:00+03	135400.00
0DA252	2017-07-15 22:55:00+03	191600.00
0DA284	2017-07-06 20:55:00+03	24600.00
0DA2B7	2017-08-15 04:04:00+03	29900.00
0DA2BA	2017-07-20 00:32:00+03	22600.00
0DA2D3	2017-07-24 15:54:00+03	187600.00
0DA32D	2017-08-04 09:38:00+03	94000.00
0DA354	2017-07-19 08:47:00+03	62800.00
0DA355	2017-08-11 18:57:00+03	235200.00
0DA379	2017-07-12 01:26:00+03	28300.00
0DA38F	2017-08-06 19:11:00+03	48800.00
0DA3EA	2017-07-27 09:58:00+03	226200.00
0DA3FC	2017-07-17 14:05:00+03	30000.00
0DA40A	2017-07-11 09:56:00+03	32900.00
0DA422	2017-07-16 10:48:00+03	167400.00
0DA437	2017-07-15 06:35:00+03	37900.00
0DA444	2017-08-07 23:07:00+03	56100.00
0DA4D4	2017-08-08 03:14:00+03	401600.00
0DA4DE	2017-07-25 00:38:00+03	135900.00
0DA4EF	2017-08-14 14:43:00+03	94200.00
0DA4F2	2017-07-31 21:58:00+03	531300.00
0DA4F9	2017-07-07 01:39:00+03	186900.00
0DA596	2017-07-16 22:18:00+03	40800.00
0DA5AA	2017-06-28 17:48:00+03	55900.00
0DA5E2	2017-07-12 01:39:00+03	53400.00
0DA613	2017-07-07 15:45:00+03	41400.00
0DA61E	2017-08-06 17:56:00+03	27200.00
0DA6ED	2017-07-02 02:40:00+03	96800.00
0DA745	2017-08-01 05:31:00+03	446100.00
0DA75F	2017-07-28 17:09:00+03	28800.00
0DA799	2017-07-21 01:54:00+03	50400.00
0DA7B1	2017-07-14 07:29:00+03	43200.00
0DA80A	2017-08-14 02:43:00+03	260300.00
0DA870	2017-08-07 08:17:00+03	78600.00
0DA894	2017-07-18 20:01:00+03	26000.00
0DA8D9	2017-08-10 22:57:00+03	28800.00
0DA8E9	2017-08-13 14:34:00+03	53400.00
0DA972	2017-07-30 22:10:00+03	88900.00
0DA97E	2017-08-15 16:41:00+03	56000.00
0DA9D3	2017-08-14 01:15:00+03	171000.00
0DAA3B	2017-07-15 09:47:00+03	73100.00
0DAA67	2017-08-03 17:44:00+03	135400.00
0DAAA2	2017-08-10 23:33:00+03	46000.00
0DAAAC	2017-07-25 00:49:00+03	17200.00
0DAAC0	2017-07-23 18:19:00+03	128800.00
0DAB10	2017-08-01 18:22:00+03	40800.00
0DAB31	2017-07-27 08:59:00+03	23500.00
0DAB8B	2017-08-14 15:13:00+03	39200.00
0DABAD	2017-07-09 00:44:00+03	27900.00
0DAC09	2017-08-10 10:26:00+03	93500.00
0DAC31	2017-08-08 18:58:00+03	59300.00
0DAC4C	2017-07-25 18:19:00+03	96800.00
0DAC62	2017-08-14 19:22:00+03	240600.00
0DAC68	2017-07-11 23:36:00+03	14800.00
0DAC88	2017-06-30 18:11:00+03	88400.00
0DACDD	2017-07-23 08:05:00+03	25600.00
0DAD2F	2017-08-01 06:10:00+03	155400.00
0DAD4F	2017-07-08 09:42:00+03	14400.00
0DADA1	2017-08-12 09:31:00+03	133100.00
0DADF5	2017-07-24 02:41:00+03	21800.00
0DAE3D	2017-07-25 10:59:00+03	52700.00
0DAE7C	2017-07-10 10:46:00+03	38800.00
0DAE9F	2017-07-09 03:17:00+03	13200.00
0DAEB8	2017-07-20 17:59:00+03	51300.00
0DAF42	2017-07-12 21:22:00+03	32700.00
0DAF45	2017-07-17 10:49:00+03	32200.00
0DAF4F	2017-07-11 21:51:00+03	134700.00
0DAF63	2017-07-17 20:32:00+03	258000.00
0DAF8B	2017-08-15 15:57:00+03	266400.00
0DAFAC	2017-08-10 07:40:00+03	27700.00
0DB0ED	2017-08-06 07:24:00+03	139200.00
0DB0F3	2017-07-14 22:48:00+03	26400.00
0DB103	2017-07-27 07:33:00+03	19600.00
0DB13F	2017-07-04 13:49:00+03	27600.00
0DB149	2017-07-12 19:30:00+03	68800.00
0DB179	2017-07-12 15:24:00+03	257500.00
0DB2A2	2017-07-20 19:10:00+03	31000.00
0DB2A9	2017-07-21 17:57:00+03	53300.00
0DB2C2	2017-08-14 23:06:00+03	52100.00
0DB3C2	2017-08-08 06:15:00+03	24600.00
0DB3CA	2017-07-28 03:11:00+03	246000.00
0DB40A	2017-07-15 20:21:00+03	57600.00
0DB457	2017-07-14 03:40:00+03	31100.00
0DB471	2017-07-01 06:47:00+03	169000.00
0DB480	2017-07-11 02:36:00+03	124000.00
0DB525	2017-06-30 15:31:00+03	15900.00
0DB56E	2017-08-13 13:56:00+03	39500.00
0DB59E	2017-07-26 11:03:00+03	50800.00
0DB5AD	2017-07-05 18:48:00+03	30900.00
0DB5E7	2017-08-13 03:48:00+03	123000.00
0DB5F1	2017-07-14 08:13:00+03	65200.00
0DB66F	2017-07-04 02:24:00+03	28800.00
0DB675	2017-07-01 20:55:00+03	73600.00
0DB68F	2017-07-20 15:44:00+03	35200.00
0DB6D8	2017-07-31 09:24:00+03	65500.00
0DB7D3	2017-07-19 10:21:00+03	45100.00
0DB886	2017-07-25 21:26:00+03	66000.00
0DB887	2017-07-18 09:33:00+03	202100.00
0DB8E8	2017-08-09 22:31:00+03	154400.00
0DB964	2017-07-13 23:15:00+03	128000.00
0DB978	2017-07-30 11:16:00+03	26000.00
0DB97B	2017-07-30 09:20:00+03	46400.00
0DB9A9	2017-07-01 07:59:00+03	57600.00
0DB9DB	2017-07-03 18:49:00+03	40800.00
0DB9EC	2017-07-17 10:17:00+03	100600.00
0DBA69	2017-07-05 02:31:00+03	38700.00
0DBA7C	2017-08-14 22:34:00+03	97900.00
0DBB46	2017-06-27 13:12:00+03	39000.00
0DBB64	2017-06-30 11:35:00+03	70800.00
0DBBC9	2017-07-07 17:15:00+03	90400.00
0DBC03	2017-07-16 22:47:00+03	25600.00
0DBC32	2017-07-15 18:13:00+03	167400.00
0DBCB0	2017-08-11 15:51:00+03	89600.00
0DBCE4	2017-07-31 23:29:00+03	19000.00
0DBD1A	2017-06-30 15:14:00+03	58000.00
0DBD60	2017-06-29 07:51:00+03	36800.00
0DBD83	2017-08-08 07:22:00+03	21000.00
0DBD8A	2017-07-11 18:54:00+03	23600.00
0DBE13	2017-07-18 02:20:00+03	28800.00
0DBE94	2017-07-26 00:22:00+03	134700.00
0DBEBD	2017-08-12 08:56:00+03	17600.00
0DBECD	2017-07-25 16:30:00+03	123600.00
0DBEDD	2017-07-17 00:14:00+03	101200.00
0DBF36	2017-07-01 20:00:00+03	13600.00
0DBFF8	2017-07-08 07:24:00+03	73600.00
0DC077	2017-07-27 18:43:00+03	406600.00
0DC098	2017-06-29 05:55:00+03	92000.00
0DC0A3	2017-07-27 17:37:00+03	269300.00
0DC10D	2017-08-11 02:57:00+03	46500.00
0DC12E	2017-07-01 10:34:00+03	116800.00
0DC166	2017-08-07 00:51:00+03	57500.00
0DC1B4	2017-08-13 14:48:00+03	20200.00
0DC1BA	2017-07-21 19:12:00+03	117800.00
0DC1BC	2017-07-08 13:41:00+03	87600.00
0DC1EA	2017-07-26 22:22:00+03	116500.00
0DC24D	2017-07-31 16:30:00+03	251400.00
0DC254	2017-07-06 03:38:00+03	22000.00
0DC268	2017-07-09 21:26:00+03	31100.00
0DC2A6	2017-07-17 01:27:00+03	97500.00
0DC31F	2017-07-12 12:03:00+03	136200.00
0DC340	2017-08-02 11:12:00+03	44500.00
0DC35E	2017-07-30 13:46:00+03	16400.00
0DC369	2017-08-01 16:39:00+03	56000.00
0DC3B3	2017-07-01 06:11:00+03	65500.00
0DC3CE	2017-08-14 19:13:00+03	23200.00
0DC3E2	2017-07-11 22:46:00+03	46200.00
0DC4FF	2017-07-20 02:44:00+03	46200.00
0DC579	2017-07-28 14:19:00+03	46400.00
0DC5DC	2017-08-12 08:58:00+03	10800.00
0DC62E	2017-08-08 20:29:00+03	92900.00
0DC633	2017-08-08 16:59:00+03	60700.00
0DC66B	2017-08-12 20:45:00+03	122600.00
0DC66E	2017-07-24 03:53:00+03	43800.00
0DC66F	2017-08-12 10:59:00+03	112000.00
0DC679	2017-08-05 06:27:00+03	18900.00
0DC695	2017-08-04 02:02:00+03	24400.00
0DC6CC	2017-08-14 06:07:00+03	14000.00
0DC72A	2017-07-22 23:04:00+03	58600.00
0DC746	2017-07-12 12:38:00+03	26800.00
0DC777	2017-08-07 23:35:00+03	75600.00
0DC78A	2017-07-04 03:31:00+03	65900.00
0DC78B	2017-08-04 03:25:00+03	102100.00
0DC7A9	2017-08-04 01:30:00+03	90000.00
0DC7D2	2017-07-21 17:54:00+03	24800.00
0DC7F8	2017-07-14 03:01:00+03	90600.00
0DC84D	2017-08-08 03:53:00+03	62700.00
0DC935	2017-07-10 14:41:00+03	12400.00
0DC952	2017-07-06 11:34:00+03	37700.00
0DC97D	2017-07-03 07:39:00+03	22100.00
0DC9A0	2017-07-30 22:09:00+03	27800.00
0DC9A3	2017-07-05 11:28:00+03	34800.00
0DC9A5	2017-07-07 02:33:00+03	46800.00
0DC9C1	2017-08-12 10:00:00+03	26800.00
0DCA04	2017-06-29 04:05:00+03	23600.00
0DCA19	2017-07-08 03:08:00+03	44800.00
0DCA55	2017-08-01 03:23:00+03	8400.00
0DCA69	2017-07-31 08:15:00+03	30200.00
0DCA7E	2017-06-30 04:07:00+03	55800.00
0DCB62	2017-08-15 17:48:00+03	21400.00
0DCB72	2017-07-26 06:43:00+03	39200.00
0DCC06	2017-06-30 23:35:00+03	27400.00
0DCC0E	2017-08-05 04:14:00+03	25100.00
0DCC54	2017-07-05 21:01:00+03	48800.00
0DCC7D	2017-07-28 12:43:00+03	13400.00
0DCCA2	2017-07-08 07:54:00+03	48100.00
0DCCA4	2017-07-31 09:05:00+03	188700.00
0DCCF0	2017-08-08 12:14:00+03	17000.00
0DCD0C	2017-07-18 07:13:00+03	52300.00
0DCD43	2017-07-10 01:55:00+03	15400.00
0DCD64	2017-07-24 02:19:00+03	13400.00
0DCD8C	2017-08-02 10:35:00+03	56200.00
0DCD99	2017-07-21 23:58:00+03	106300.00
0DCDE9	2017-08-11 01:22:00+03	22000.00
0DCDEF	2017-07-01 11:27:00+03	129700.00
0DCDF6	2017-07-19 22:25:00+03	258400.00
0DCE2E	2017-07-16 19:42:00+03	55800.00
0DCE4A	2017-07-29 12:18:00+03	48900.00
0DCE7E	2017-08-06 19:13:00+03	13000.00
0DCE82	2017-07-14 13:58:00+03	25600.00
0DCEDD	2017-08-11 14:06:00+03	86300.00
0DCEE3	2017-07-27 09:08:00+03	9800.00
0DCF27	2017-08-02 21:25:00+03	119600.00
0DCF2D	2017-07-18 21:42:00+03	55800.00
0DCFEB	2017-08-01 16:52:00+03	63200.00
0DD09B	2017-07-06 03:26:00+03	56100.00
0DD0C2	2017-07-24 17:49:00+03	136500.00
0DD137	2017-07-24 22:07:00+03	24400.00
0DD15B	2017-07-29 10:32:00+03	13200.00
0DD177	2017-07-31 11:21:00+03	32200.00
0DD178	2017-07-30 08:46:00+03	68400.00
0DD1DF	2017-08-04 04:08:00+03	28800.00
0DD29B	2017-07-07 15:23:00+03	58200.00
0DD2B9	2017-07-31 20:10:00+03	52700.00
0DD2BB	2017-07-06 20:49:00+03	157100.00
0DD2E6	2017-07-05 14:29:00+03	42000.00
0DD2F8	2017-08-13 01:28:00+03	18000.00
0DD2FC	2017-07-13 12:55:00+03	36600.00
0DD314	2017-07-28 21:27:00+03	178300.00
0DD372	2017-07-27 12:18:00+03	206800.00
0DD3CF	2017-07-01 20:16:00+03	27200.00
0DD3E4	2017-07-21 09:02:00+03	28000.00
0DD40E	2017-08-14 08:41:00+03	260900.00
0DD417	2017-07-13 08:37:00+03	7400.00
0DD443	2017-07-19 00:56:00+03	43200.00
0DD474	2017-08-10 03:15:00+03	47200.00
0DD485	2017-07-12 04:05:00+03	19600.00
0DD487	2017-08-04 21:49:00+03	154300.00
0DD48C	2017-08-06 16:03:00+03	36100.00
0DD52D	2017-07-18 12:33:00+03	62000.00
0DD532	2017-08-14 01:50:00+03	21600.00
0DD584	2017-07-23 19:28:00+03	103500.00
0DD5B7	2017-07-30 10:57:00+03	12400.00
0DD60B	2017-07-26 12:52:00+03	14000.00
0DD69D	2017-07-04 22:09:00+03	29600.00
0DD6DC	2017-08-07 06:49:00+03	81300.00
0DD6E7	2017-07-03 04:17:00+03	61800.00
0DD70A	2017-07-25 19:55:00+03	28800.00
0DD727	2017-07-05 14:04:00+03	258400.00
0DD774	2017-07-06 16:24:00+03	134400.00
0DD792	2017-06-27 09:59:00+03	282000.00
0DD816	2017-07-23 13:48:00+03	64700.00
0DD823	2017-08-03 03:57:00+03	54500.00
0DD828	2017-07-16 01:22:00+03	22000.00
0DD869	2017-08-10 15:03:00+03	101200.00
0DD894	2017-07-08 20:38:00+03	6300.00
0DD8BB	2017-07-18 15:45:00+03	168000.00
0DD94A	2017-07-13 07:37:00+03	23400.00
0DD9BE	2017-07-26 22:24:00+03	56000.00
0DD9DD	2017-07-25 19:34:00+03	40600.00
0DDA14	2017-07-10 16:46:00+03	21800.00
0DDA1E	2017-07-05 20:26:00+03	137100.00
0DDA7A	2017-08-01 02:22:00+03	49100.00
0DDAF8	2017-08-07 08:08:00+03	207400.00
0DDB03	2017-07-19 20:06:00+03	166100.00
0DDB45	2017-07-22 17:30:00+03	15000.00
0DDBC4	2017-08-11 01:00:00+03	85700.00
0DDBFB	2017-08-03 14:37:00+03	51600.00
0DDC17	2017-07-13 04:18:00+03	103100.00
0DDD80	2017-08-07 07:37:00+03	147700.00
0DDD95	2017-07-20 08:12:00+03	29300.00
0DDD9A	2017-08-08 17:51:00+03	26000.00
0DDDCC	2017-08-04 03:28:00+03	13400.00
0DDE12	2017-08-13 21:23:00+03	24800.00
0DDE42	2017-07-19 15:22:00+03	24000.00
0DDEA6	2017-07-21 07:35:00+03	35800.00
0DDEFC	2017-08-01 08:35:00+03	62100.00
0DDF34	2017-07-22 06:18:00+03	187600.00
0DDF45	2017-07-20 10:40:00+03	74800.00
0DDF74	2017-07-07 07:33:00+03	78200.00
0DDF88	2017-08-08 16:55:00+03	56100.00
0DDFED	2017-08-14 00:14:00+03	14000.00
0DE02F	2017-07-11 16:16:00+03	81600.00
0DE039	2017-08-01 08:12:00+03	29400.00
0DE03E	2017-07-17 12:05:00+03	32700.00
0DE047	2017-08-05 11:50:00+03	28800.00
0DE07D	2017-08-05 13:10:00+03	44500.00
0DE129	2017-08-06 15:37:00+03	56000.00
0DE131	2017-07-23 07:43:00+03	27800.00
0DE15E	2017-07-19 13:08:00+03	144700.00
0DE196	2017-07-23 13:27:00+03	86800.00
0DE1D1	2017-07-12 16:14:00+03	28000.00
0DE1F9	2017-07-06 00:51:00+03	71900.00
0DE1FA	2017-07-22 13:59:00+03	30200.00
0DE233	2017-07-08 09:23:00+03	46300.00
0DE30D	2017-08-06 18:36:00+03	64500.00
0DE326	2017-08-15 14:30:00+03	73800.00
0DE345	2017-08-15 05:38:00+03	43100.00
0DE37C	2017-07-01 22:21:00+03	58800.00
0DE3DB	2017-07-02 22:02:00+03	55800.00
0DE3F9	2017-08-03 22:27:00+03	26000.00
0DE413	2017-07-29 17:55:00+03	301800.00
0DE44E	2017-07-19 11:03:00+03	36200.00
0DE4CE	2017-07-15 23:03:00+03	192900.00
0DE4D0	2017-07-31 02:30:00+03	27300.00
0DE525	2017-07-24 17:47:00+03	55800.00
0DE53C	2017-07-22 17:49:00+03	123000.00
0DE565	2017-07-30 12:05:00+03	70500.00
0DE599	2017-07-29 14:02:00+03	42800.00
0DE656	2017-08-11 09:58:00+03	46000.00
0DE66D	2017-07-14 12:03:00+03	408500.00
0DE675	2017-07-20 08:58:00+03	24400.00
0DE6E6	2017-07-06 02:25:00+03	56000.00
0DE706	2017-07-11 02:19:00+03	184500.00
0DE709	2017-08-12 07:09:00+03	86800.00
0DE7CC	2017-07-08 21:53:00+03	89700.00
0DE7D5	2017-07-20 13:12:00+03	264000.00
0DE7DA	2017-07-14 02:03:00+03	225900.00
0DE811	2017-07-02 00:33:00+03	43900.00
0DE86C	2017-07-28 07:50:00+03	8400.00
0DE89E	2017-07-23 18:22:00+03	68400.00
0DE8D6	2017-08-11 00:58:00+03	136200.00
0DE927	2017-08-10 19:08:00+03	107400.00
0DE93F	2017-07-07 15:59:00+03	86600.00
0DE9DB	2017-07-27 02:52:00+03	99300.00
0DE9F8	2017-08-07 03:09:00+03	23900.00
0DEA1F	2017-07-04 15:27:00+03	32800.00
0DEA48	2017-07-25 03:22:00+03	224000.00
0DEA52	2017-08-09 02:00:00+03	55800.00
0DEABD	2017-07-18 16:57:00+03	29400.00
0DEB33	2017-07-18 20:04:00+03	22000.00
0DEB9D	2017-08-13 14:47:00+03	140100.00
0DEBC3	2017-07-09 03:17:00+03	76600.00
0DEBE9	2017-08-10 13:45:00+03	28800.00
0DEC16	2017-07-25 02:49:00+03	65900.00
0DEC34	2017-08-14 05:08:00+03	520600.00
0DEC3E	2017-08-05 20:28:00+03	62800.00
0DEC73	2017-07-23 17:28:00+03	75300.00
0DEC7B	2017-07-30 06:21:00+03	191700.00
0DECCB	2017-07-19 14:15:00+03	32900.00
0DECED	2017-07-12 08:17:00+03	57600.00
0DED02	2017-08-11 12:10:00+03	14000.00
0DED05	2017-07-19 18:29:00+03	110500.00
0DED84	2017-07-20 22:04:00+03	56000.00
0DEDC6	2017-08-09 03:37:00+03	88500.00
0DEDFD	2017-07-11 23:19:00+03	10700.00
0DEE04	2017-07-20 00:09:00+03	48800.00
0DEE2C	2017-07-09 17:47:00+03	70700.00
0DEE38	2017-07-06 08:43:00+03	431400.00
0DEE5C	2017-08-09 19:10:00+03	96800.00
0DEE73	2017-07-11 01:21:00+03	77200.00
0DEE93	2017-08-09 01:32:00+03	136800.00
0DEECD	2017-08-08 03:36:00+03	77000.00
0DEEE2	2017-07-25 23:43:00+03	23400.00
0DEF24	2017-07-06 11:12:00+03	55800.00
0DEF50	2017-07-15 21:18:00+03	22000.00
0DEF52	2017-07-18 17:12:00+03	59200.00
0DEFDE	2017-07-08 02:28:00+03	63300.00
0DF068	2017-08-09 03:11:00+03	23200.00
0DF094	2017-08-03 15:43:00+03	70400.00
0DF0B1	2017-07-08 08:48:00+03	57800.00
0DF0DF	2017-08-13 17:38:00+03	100000.00
0DF184	2017-08-14 06:34:00+03	149300.00
0DF187	2017-07-14 04:56:00+03	85000.00
0DF198	2017-07-25 10:55:00+03	144400.00
0DF1C8	2017-07-12 02:41:00+03	134700.00
0DF226	2017-08-10 15:24:00+03	31600.00
0DF324	2017-07-11 06:57:00+03	179200.00
0DF3E5	2017-06-29 18:45:00+03	198300.00
0DF4EA	2017-08-07 04:33:00+03	20000.00
0DF67C	2017-07-07 12:25:00+03	114400.00
0DF720	2017-07-08 00:07:00+03	24400.00
0DF729	2017-08-05 18:09:00+03	83600.00
0DF777	2017-07-08 03:05:00+03	12000.00
0DF77F	2017-08-05 20:17:00+03	234300.00
0DF7A4	2017-07-07 14:09:00+03	260300.00
0DF7B8	2017-07-11 08:21:00+03	32700.00
0DF7BB	2017-07-28 23:59:00+03	43600.00
0DF7C3	2017-07-25 11:11:00+03	56000.00
0DF7F5	2017-07-12 22:29:00+03	27300.00
0DF7F8	2017-08-09 11:35:00+03	48300.00
0DF817	2017-08-01 07:33:00+03	23400.00
0DF827	2017-08-05 17:36:00+03	86000.00
0DF853	2017-07-18 08:01:00+03	14400.00
0DF8A0	2017-07-07 12:08:00+03	52000.00
0DF967	2017-07-13 11:47:00+03	147300.00
0DF970	2017-07-25 02:33:00+03	25100.00
0DF997	2017-07-08 19:30:00+03	89700.00
0DF9A3	2017-07-28 19:31:00+03	22600.00
0DF9DE	2017-07-13 10:10:00+03	120000.00
0DF9DF	2017-07-16 09:49:00+03	28000.00
0DF9E4	2017-07-04 15:53:00+03	11300.00
0DFA75	2017-07-21 01:13:00+03	99000.00
0DFAE3	2017-08-14 02:23:00+03	56000.00
0DFAF0	2017-08-13 11:10:00+03	17600.00
0DFB3B	2017-07-28 07:38:00+03	69000.00
0DFBC6	2017-07-25 14:05:00+03	126500.00
0DFC00	2017-07-02 20:28:00+03	174600.00
0DFC21	2017-07-31 11:15:00+03	44800.00
0DFC4E	2017-07-27 08:35:00+03	10100.00
0DFCD1	2017-07-02 10:16:00+03	58200.00
0DFCF6	2017-07-09 12:47:00+03	45100.00
0DFD5C	2017-07-13 02:33:00+03	6700.00
0DFDC1	2017-08-05 05:23:00+03	64600.00
0DFE03	2017-07-04 20:59:00+03	48800.00
0DFE50	2017-08-01 06:58:00+03	12600.00
0DFE54	2017-08-13 08:13:00+03	182300.00
0DFE65	2017-07-27 05:33:00+03	28000.00
0DFEA5	2017-07-31 16:23:00+03	58200.00
0DFF29	2017-07-11 04:30:00+03	13400.00
0DFF94	2017-07-10 01:41:00+03	156500.00
0E00BC	2017-07-24 05:48:00+03	49500.00
0E00C5	2017-07-07 04:10:00+03	43600.00
0E00F6	2017-06-29 21:12:00+03	43600.00
0E01AE	2017-08-07 03:36:00+03	18800.00
0E0263	2017-07-13 11:05:00+03	249100.00
0E02B9	2017-08-14 01:49:00+03	28000.00
0E02BC	2017-06-29 00:18:00+03	139000.00
0E02EF	2017-07-22 08:42:00+03	58800.00
0E0312	2017-07-08 20:01:00+03	248400.00
0E032E	2017-07-31 09:07:00+03	119500.00
0E0340	2017-07-23 08:16:00+03	135400.00
0E0364	2017-08-14 00:09:00+03	60000.00
0E037E	2017-07-08 11:26:00+03	28000.00
0E0393	2017-08-14 20:59:00+03	72800.00
0E0398	2017-07-06 18:24:00+03	116900.00
0E0403	2017-07-14 03:22:00+03	42700.00
0E042B	2017-07-16 00:38:00+03	28600.00
0E04B6	2017-07-29 13:01:00+03	16000.00
0E04BC	2017-08-09 04:09:00+03	363100.00
0E04DA	2017-08-12 03:21:00+03	68100.00
0E04E4	2017-08-05 16:51:00+03	68800.00
0E05D5	2017-07-16 21:31:00+03	75300.00
0E0694	2017-07-12 00:33:00+03	10800.00
0E06DD	2017-07-22 09:38:00+03	123000.00
0E0730	2017-07-26 00:17:00+03	111600.00
0E073B	2017-07-20 15:25:00+03	46200.00
0E0762	2017-06-30 22:35:00+03	58800.00
0E07AE	2017-07-09 21:55:00+03	143100.00
0E07F9	2017-07-02 09:55:00+03	86300.00
0E08F2	2017-07-13 22:39:00+03	29600.00
0E0911	2017-07-10 11:59:00+03	14900.00
0E0934	2017-08-14 19:00:00+03	94700.00
0E0972	2017-08-12 20:08:00+03	78300.00
0E0994	2017-07-04 12:01:00+03	28000.00
0E0AA9	2017-07-22 03:46:00+03	24400.00
0E0AF3	2017-07-19 12:13:00+03	167400.00
0E0B34	2017-07-27 05:55:00+03	123000.00
0E0B79	2017-07-15 17:27:00+03	31600.00
0E0B87	2017-07-04 13:30:00+03	119600.00
0E0BAB	2017-07-08 17:56:00+03	54400.00
0E0BD1	2017-08-13 01:37:00+03	133200.00
0E0C1D	2017-08-07 14:08:00+03	83600.00
0E0C5B	2017-07-10 03:37:00+03	55800.00
0E0CCE	2017-08-01 09:31:00+03	48800.00
0E0D10	2017-07-16 12:49:00+03	74400.00
0E0D20	2017-07-22 21:28:00+03	97900.00
0E0D42	2017-07-20 21:32:00+03	8200.00
0E0D9B	2017-07-08 00:31:00+03	66000.00
0E0DA5	2017-07-13 09:40:00+03	72200.00
0E0E59	2017-08-11 08:35:00+03	50700.00
0E0E6E	2017-07-06 02:25:00+03	107200.00
0E0E85	2017-07-14 08:25:00+03	14700.00
0E0E90	2017-07-31 08:03:00+03	65300.00
0E0EC4	2017-08-15 07:12:00+03	84000.00
0E0EC7	2017-07-20 07:14:00+03	38600.00
0E0ED2	2017-07-04 01:48:00+03	32700.00
0E0F34	2017-08-14 17:42:00+03	24700.00
0E0F52	2017-07-26 07:39:00+03	28800.00
0E0FC8	2017-08-13 02:30:00+03	99800.00
0E0FCE	2017-07-15 23:56:00+03	14400.00
0E1000	2017-07-08 17:51:00+03	46400.00
0E1039	2017-08-07 07:03:00+03	26000.00
0E1042	2017-08-05 12:43:00+03	132800.00
0E104F	2017-08-09 22:19:00+03	93700.00
0E10B0	2017-08-06 00:10:00+03	12400.00
0E10E9	2017-07-07 10:34:00+03	54400.00
0E110D	2017-07-08 17:23:00+03	26200.00
0E116D	2017-07-01 14:50:00+03	189200.00
0E11DB	2017-08-13 10:08:00+03	123600.00
0E1274	2017-07-22 14:45:00+03	105000.00
0E1370	2017-07-10 08:26:00+03	75500.00
0E1379	2017-07-15 01:54:00+03	32800.00
0E13C7	2017-08-15 07:41:00+03	37100.00
0E13E0	2017-08-14 06:32:00+03	265200.00
0E145A	2017-08-12 22:52:00+03	38800.00
0E1467	2017-07-15 18:09:00+03	77200.00
0E1492	2017-08-06 09:19:00+03	152400.00
0E1498	2017-07-09 13:45:00+03	16400.00
0E14AB	2017-07-04 12:50:00+03	88600.00
0E14CC	2017-07-13 18:26:00+03	32200.00
0E14E6	2017-07-30 12:19:00+03	40800.00
0E155A	2017-08-04 16:49:00+03	58600.00
0E1568	2017-08-10 12:56:00+03	47200.00
0E15F9	2017-08-01 07:39:00+03	64500.00
0E16AF	2017-08-14 17:19:00+03	45000.00
0E16B8	2017-07-31 00:52:00+03	75600.00
0E16F6	2017-07-03 17:08:00+03	41200.00
0E172F	2017-07-08 15:19:00+03	14400.00
0E17EA	2017-07-07 23:32:00+03	29600.00
0E1800	2017-07-01 00:52:00+03	43700.00
0E1806	2017-08-11 01:04:00+03	397700.00
0E1852	2017-08-10 01:50:00+03	21800.00
0E185C	2017-08-13 23:04:00+03	240600.00
0E185D	2017-07-26 14:54:00+03	15800.00
0E186F	2017-07-15 02:33:00+03	91700.00
0E18A8	2017-06-26 01:10:00+03	71100.00
0E18FB	2017-07-22 03:04:00+03	325500.00
0E1911	2017-08-06 16:59:00+03	67100.00
0E192E	2017-08-13 03:01:00+03	111600.00
0E1930	2017-07-19 01:14:00+03	65900.00
0E1975	2017-07-20 15:50:00+03	259300.00
0E1980	2017-07-09 19:44:00+03	36200.00
0E1993	2017-07-12 22:38:00+03	67900.00
0E199E	2017-07-16 12:44:00+03	17600.00
0E19B0	2017-07-24 10:30:00+03	193600.00
0E19E7	2017-07-15 04:45:00+03	99300.00
0E1A1E	2017-08-15 00:01:00+03	12600.00
0E1A7F	2017-07-07 07:35:00+03	236700.00
0E1AC4	2017-08-13 19:27:00+03	9200.00
0E1BA6	2017-07-20 11:32:00+03	88400.00
0E1BC1	2017-07-30 04:09:00+03	226200.00
0E1C7D	2017-08-11 05:54:00+03	6000.00
0E1CA8	2017-08-01 05:13:00+03	31800.00
0E1CE9	2017-07-17 23:47:00+03	112600.00
0E1D66	2017-08-05 06:53:00+03	47400.00
0E1D8D	2017-07-29 02:55:00+03	27400.00
0E1D8F	2017-08-11 17:41:00+03	204200.00
0E1DF6	2017-07-24 04:18:00+03	24400.00
0E1E45	2017-08-02 09:07:00+03	56600.00
0E1E69	2017-07-17 17:19:00+03	73300.00
0E1E9E	2017-08-08 21:28:00+03	28000.00
0E1EEC	2017-08-14 15:03:00+03	173100.00
0E1EF1	2017-08-14 02:30:00+03	143900.00
0E1EF3	2017-07-01 07:26:00+03	24000.00
0E1F00	2017-07-09 18:04:00+03	492000.00
0E1F15	2017-07-22 11:19:00+03	11800.00
0E1F2E	2017-08-04 13:30:00+03	46000.00
0E1FB5	2017-07-23 18:16:00+03	39400.00
0E2093	2017-08-05 11:16:00+03	14400.00
0E20D7	2017-08-11 19:49:00+03	28000.00
0E210F	2017-07-22 15:52:00+03	45200.00
0E218E	2017-07-13 19:07:00+03	179400.00
0E21A1	2017-08-12 15:51:00+03	36100.00
0E21CA	2017-08-14 16:46:00+03	48200.00
0E21F9	2017-07-29 06:32:00+03	60400.00
0E21FB	2017-07-17 16:42:00+03	28000.00
0E2205	2017-07-21 04:35:00+03	18900.00
0E2240	2017-07-16 05:20:00+03	19800.00
0E2290	2017-06-26 11:44:00+03	115900.00
0E22AC	2017-08-06 20:57:00+03	31000.00
0E22F5	2017-08-01 05:07:00+03	67600.00
0E231D	2017-07-17 20:47:00+03	83600.00
0E236D	2017-08-04 03:07:00+03	64800.00
0E23F4	2017-07-17 14:47:00+03	21400.00
0E2409	2017-07-26 21:18:00+03	66600.00
0E2417	2017-07-09 13:04:00+03	88500.00
0E241A	2017-08-07 05:12:00+03	32800.00
0E242A	2017-07-12 23:45:00+03	46300.00
0E2489	2017-07-31 17:54:00+03	145300.00
0E2512	2017-07-22 15:13:00+03	13600.00
0E2536	2017-07-13 03:13:00+03	76600.00
0E25A6	2017-07-17 20:28:00+03	56000.00
0E25A8	2017-07-17 02:43:00+03	40200.00
0E25B5	2017-07-10 21:54:00+03	123000.00
0E25CD	2017-07-07 23:18:00+03	69500.00
0E25E1	2017-06-26 04:48:00+03	44700.00
0E261B	2017-08-08 19:59:00+03	46800.00
0E2627	2017-08-05 02:57:00+03	44700.00
0E264A	2017-07-05 03:53:00+03	61800.00
0E265E	2017-07-07 20:55:00+03	57300.00
0E2690	2017-08-13 23:16:00+03	301800.00
0E26A6	2017-08-15 16:36:00+03	74300.00
0E26AA	2017-07-04 08:58:00+03	248300.00
0E26B4	2017-08-01 09:54:00+03	61900.00
0E27C0	2017-08-10 11:10:00+03	22000.00
0E27C3	2017-08-05 07:52:00+03	66600.00
0E27CB	2017-07-27 12:40:00+03	19600.00
0E2806	2017-08-11 22:05:00+03	26000.00
0E286F	2017-07-21 17:56:00+03	42400.00
0E2877	2017-08-04 02:10:00+03	76600.00
0E2938	2017-07-23 11:32:00+03	93000.00
0E297E	2017-08-07 17:17:00+03	83600.00
0E2996	2017-07-14 19:37:00+03	185600.00
0E2A21	2017-07-04 20:10:00+03	399600.00
0E2A64	2017-07-31 16:12:00+03	37900.00
0E2ABD	2017-08-13 14:48:00+03	111400.00
0E2BAA	2017-07-29 13:24:00+03	140600.00
0E2BAC	2017-07-10 21:40:00+03	63700.00
0E2BB1	2017-08-02 16:55:00+03	112000.00
0E2BC5	2017-06-30 09:30:00+03	271200.00
0E2BDF	2017-07-14 12:45:00+03	35200.00
0E2BE3	2017-07-04 15:42:00+03	77900.00
0E2BF3	2017-07-22 21:00:00+03	139300.00
0E2C78	2017-07-14 22:29:00+03	32800.00
0E2C82	2017-07-22 11:16:00+03	23600.00
0E2CAD	2017-08-05 23:17:00+03	254600.00
0E2CBA	2017-08-14 23:01:00+03	12000.00
0E2D04	2017-07-15 10:11:00+03	62900.00
0E2DCC	2017-08-14 22:36:00+03	38000.00
0E2DD4	2017-07-28 07:41:00+03	26000.00
0E2DDC	2017-07-15 17:18:00+03	67200.00
0E2E01	2017-08-09 03:07:00+03	11800.00
0E2E03	2017-08-02 22:30:00+03	39800.00
0E2EB2	2017-07-12 03:45:00+03	6300.00
0E2EBA	2017-07-19 07:49:00+03	56900.00
0E2F96	2017-08-10 11:37:00+03	271200.00
0E2FE8	2017-07-10 19:09:00+03	9300.00
0E3006	2017-07-15 19:18:00+03	135400.00
0E3043	2017-08-01 02:32:00+03	113900.00
0E30BD	2017-07-19 20:04:00+03	11900.00
0E30C1	2017-07-20 07:20:00+03	67000.00
0E30F5	2017-08-09 19:24:00+03	60400.00
0E3140	2017-07-03 01:44:00+03	14400.00
0E31B0	2017-07-22 21:31:00+03	23600.00
0E3212	2017-08-13 03:38:00+03	43200.00
0E3252	2017-08-04 01:31:00+03	88000.00
0E3258	2017-08-05 03:05:00+03	26200.00
0E3293	2017-07-26 12:56:00+03	28000.00
0E32D0	2017-07-30 02:57:00+03	138600.00
0E3366	2017-08-12 20:08:00+03	135200.00
0E338C	2017-07-22 18:40:00+03	18900.00
0E33FF	2017-08-04 05:03:00+03	164100.00
0E3413	2017-07-24 14:20:00+03	25100.00
0E3443	2017-07-30 22:05:00+03	46400.00
0E3466	2017-07-03 13:08:00+03	86900.00
0E34C2	2017-08-14 19:19:00+03	52700.00
0E34E5	2017-07-04 15:45:00+03	28800.00
0E352D	2017-07-01 12:08:00+03	76800.00
0E3549	2017-07-29 02:17:00+03	16400.00
0E356E	2017-07-31 10:44:00+03	254900.00
0E35DF	2017-07-22 13:36:00+03	148800.00
0E35FB	2017-08-09 02:12:00+03	24400.00
0E362B	2017-08-05 21:11:00+03	20200.00
0E36DF	2017-07-10 10:24:00+03	51900.00
0E371D	2017-07-25 01:50:00+03	31200.00
0E3737	2017-07-04 03:22:00+03	51000.00
0E376C	2017-07-10 01:41:00+03	10800.00
0E37AB	2017-07-12 23:27:00+03	58900.00
0E37BA	2017-08-03 22:09:00+03	26200.00
0E3804	2017-08-13 07:25:00+03	36400.00
0E386C	2017-08-14 07:14:00+03	89000.00
0E387F	2017-07-16 21:28:00+03	85400.00
0E38A2	2017-07-03 18:16:00+03	131100.00
0E38E3	2017-07-22 16:05:00+03	260900.00
0E3915	2017-08-13 04:30:00+03	35900.00
0E392D	2017-08-09 15:26:00+03	258400.00
0E39D4	2017-08-09 14:58:00+03	58600.00
0E3A35	2017-07-30 12:02:00+03	46000.00
0E3A51	2017-08-09 15:40:00+03	306600.00
0E3A8F	2017-08-11 16:08:00+03	166000.00
0E3AD7	2017-07-08 20:11:00+03	25200.00
0E3B23	2017-08-11 17:39:00+03	95700.00
0E3B9F	2017-08-01 04:24:00+03	547000.00
0E3BA1	2017-08-13 03:51:00+03	7200.00
0E3BC7	2017-07-17 15:44:00+03	21800.00
0E3C10	2017-08-07 05:18:00+03	202400.00
0E3C75	2017-07-23 19:30:00+03	129200.00
0E3CB7	2017-07-24 17:08:00+03	21600.00
0E3CD7	2017-07-10 12:00:00+03	28800.00
0E3CE0	2017-08-14 13:53:00+03	40800.00
0E3D21	2017-07-18 21:31:00+03	54800.00
0E3D2B	2017-07-27 03:39:00+03	15900.00
0E3E1B	2017-07-28 14:06:00+03	46400.00
0E3E97	2017-07-14 23:10:00+03	56000.00
0E3EAD	2017-08-06 18:03:00+03	27200.00
0E3F23	2017-07-05 22:42:00+03	23400.00
0E3F46	2017-08-09 07:46:00+03	16400.00
0E3FA4	2017-08-14 11:53:00+03	142300.00
0E3FE2	2017-07-11 06:42:00+03	20600.00
0E401A	2017-07-31 00:10:00+03	107800.00
0E401D	2017-08-05 22:49:00+03	369000.00
0E4025	2017-07-24 03:56:00+03	6000.00
0E4028	2017-08-11 17:44:00+03	26000.00
0E404B	2017-07-09 16:17:00+03	131600.00
0E4098	2017-08-13 02:21:00+03	111600.00
0E40CE	2017-06-29 05:35:00+03	32800.00
0E40F2	2017-07-25 18:25:00+03	58200.00
0E4105	2017-07-27 13:34:00+03	55800.00
0E411D	2017-07-17 07:40:00+03	28800.00
0E412E	2017-07-27 11:01:00+03	36000.00
0E414C	2017-07-14 09:40:00+03	115700.00
0E415A	2017-07-04 01:06:00+03	31600.00
0E4256	2017-08-12 20:18:00+03	14000.00
0E425C	2017-07-12 04:05:00+03	30000.00
0E4280	2017-08-01 09:45:00+03	29600.00
0E4318	2017-07-12 00:19:00+03	25600.00
0E4357	2017-08-03 09:43:00+03	123000.00
0E4364	2017-07-05 07:09:00+03	6000.00
0E4385	2017-08-05 04:30:00+03	81600.00
0E43A3	2017-08-03 15:18:00+03	246000.00
0E43F5	2017-07-04 03:51:00+03	139400.00
0E43FD	2017-08-14 14:33:00+03	74400.00
0E4414	2017-07-07 17:36:00+03	114200.00
0E4446	2017-07-05 23:55:00+03	28000.00
0E4460	2017-07-10 06:11:00+03	43000.00
0E4488	2017-07-15 22:35:00+03	7400.00
0E4508	2017-08-07 12:05:00+03	36200.00
0E4516	2017-08-14 21:03:00+03	26800.00
0E4530	2017-07-25 23:04:00+03	266400.00
0E453A	2017-08-15 17:23:00+03	31600.00
0E456E	2017-07-01 14:12:00+03	10800.00
0E45AE	2017-08-15 09:29:00+03	13400.00
0E4666	2017-08-12 11:08:00+03	147700.00
0E4689	2017-07-26 04:08:00+03	28000.00
0E46EF	2017-08-15 02:34:00+03	42500.00
0E4752	2017-07-18 01:37:00+03	31600.00
0E47A7	2017-08-05 05:50:00+03	142000.00
0E47BB	2017-08-11 06:00:00+03	40600.00
0E480F	2017-07-26 05:31:00+03	19600.00
0E4828	2017-08-07 03:10:00+03	35800.00
0E482D	2017-08-05 10:44:00+03	89200.00
0E4867	2017-07-25 19:40:00+03	65100.00
0E48CA	2017-07-20 16:33:00+03	32800.00
0E4905	2017-07-28 20:06:00+03	202700.00
0E493C	2017-08-14 12:03:00+03	64700.00
0E494D	2017-07-04 09:10:00+03	381500.00
0E4961	2017-08-01 17:13:00+03	31400.00
0E498C	2017-07-17 08:03:00+03	56000.00
0E49C8	2017-07-05 19:15:00+03	6700.00
0E49FE	2017-07-24 00:39:00+03	54800.00
0E4A1C	2017-08-08 09:31:00+03	57700.00
0E4A29	2017-07-21 05:51:00+03	51600.00
0E4A46	2017-07-18 19:10:00+03	47400.00
0E4A5F	2017-07-24 04:53:00+03	26300.00
0E4A80	2017-08-11 12:08:00+03	140800.00
0E4ACF	2017-07-12 23:19:00+03	57400.00
0E4B3C	2017-07-26 15:42:00+03	229600.00
0E4B3E	2017-07-22 00:44:00+03	48800.00
0E4B5B	2017-07-29 14:07:00+03	58400.00
0E4C99	2017-07-29 21:31:00+03	95700.00
0E4CA0	2017-08-03 13:15:00+03	28000.00
0E4D17	2017-07-09 16:13:00+03	123000.00
0E4D35	2017-08-14 01:07:00+03	112600.00
0E4D67	2017-07-20 14:58:00+03	544400.00
0E4DC0	2017-07-30 18:14:00+03	112000.00
0E4DE4	2017-08-13 14:56:00+03	38600.00
0E4E02	2017-07-26 11:42:00+03	55800.00
0E4E11	2017-07-10 20:39:00+03	172600.00
0E4E41	2017-08-04 04:02:00+03	136200.00
0E4E77	2017-08-09 18:40:00+03	12600.00
0E4F25	2017-07-06 12:15:00+03	34000.00
0E4FAE	2017-08-05 01:30:00+03	28000.00
0E5056	2017-07-27 09:42:00+03	25100.00
0E5063	2017-08-10 10:43:00+03	31000.00
0E5066	2017-08-12 19:34:00+03	114800.00
0E5073	2017-07-03 20:45:00+03	28000.00
0E50AA	2017-07-31 15:36:00+03	30600.00
0E50B0	2017-07-04 12:33:00+03	206800.00
0E50E6	2017-08-02 02:42:00+03	405200.00
0E50EB	2017-07-30 08:07:00+03	24400.00
0E510D	2017-07-18 10:12:00+03	48800.00
0E511C	2017-08-10 09:50:00+03	101600.00
0E52CE	2017-07-12 14:07:00+03	75300.00
0E52D6	2017-07-11 05:51:00+03	29000.00
0E52F9	2017-08-10 23:55:00+03	109600.00
0E5311	2017-07-22 08:13:00+03	34800.00
0E5318	2017-08-15 17:16:00+03	6000.00
0E5320	2017-08-13 05:32:00+03	163500.00
0E5363	2017-07-07 21:25:00+03	51600.00
0E53CD	2017-08-13 18:10:00+03	19600.00
0E546A	2017-08-15 15:58:00+03	28000.00
0E5470	2017-07-20 01:25:00+03	11600.00
0E5477	2017-08-01 06:37:00+03	37100.00
0E54FE	2017-07-22 02:07:00+03	11800.00
0E5540	2017-08-01 14:46:00+03	44600.00
0E5635	2017-08-10 20:24:00+03	201200.00
0E565E	2017-08-08 01:31:00+03	51900.00
0E5691	2017-07-17 17:41:00+03	52000.00
0E56A3	2017-07-08 04:05:00+03	140200.00
0E56B8	2017-07-24 07:50:00+03	26000.00
0E56CF	2017-07-11 22:07:00+03	23600.00
0E56EF	2017-07-15 05:56:00+03	64800.00
0E579D	2017-07-06 08:34:00+03	52700.00
0E57DC	2017-07-16 12:36:00+03	46300.00
0E580B	2017-07-21 11:32:00+03	52000.00
0E583F	2017-07-30 03:49:00+03	66000.00
0E5860	2017-07-24 08:39:00+03	39200.00
0E586B	2017-08-02 10:12:00+03	56000.00
0E58A6	2017-07-29 13:22:00+03	16400.00
0E593C	2017-07-07 14:53:00+03	47500.00
0E596E	2017-08-04 08:05:00+03	54800.00
0E598C	2017-06-30 19:57:00+03	42000.00
0E59C7	2017-07-20 20:47:00+03	28000.00
0E59D4	2017-07-23 21:41:00+03	67000.00
0E59E1	2017-07-06 14:33:00+03	28000.00
0E59FB	2017-08-09 05:35:00+03	28000.00
0E5A16	2017-08-07 10:28:00+03	59000.00
0E5A27	2017-07-15 05:24:00+03	89700.00
0E5A44	2017-08-04 12:22:00+03	28000.00
0E5A54	2017-07-18 01:50:00+03	26800.00
0E5AA3	2017-07-06 21:52:00+03	68400.00
0E5AAF	2017-08-13 13:02:00+03	24700.00
0E5ADB	2017-08-08 07:07:00+03	34000.00
0E5B31	2017-08-12 15:21:00+03	41600.00
0E5B78	2017-07-02 10:27:00+03	19600.00
0E5B8D	2017-08-12 08:36:00+03	28700.00
0E5B99	2017-08-03 03:09:00+03	115300.00
0E5B9E	2017-08-08 16:45:00+03	194800.00
0E5C0F	2017-07-15 00:47:00+03	65900.00
0E5C50	2017-08-02 09:17:00+03	88600.00
0E5CD7	2017-07-27 01:23:00+03	270800.00
0E5D5F	2017-08-01 09:14:00+03	20400.00
0E5DA2	2017-08-08 14:33:00+03	34000.00
0E5E45	2017-07-24 12:17:00+03	28000.00
0E5E8B	2017-07-12 05:42:00+03	88900.00
0E5F84	2017-07-15 06:32:00+03	22600.00
0E5F89	2017-08-05 21:01:00+03	384800.00
0E603C	2017-07-08 11:00:00+03	26500.00
0E604A	2017-07-07 10:31:00+03	250800.00
0E6097	2017-07-08 21:06:00+03	34000.00
0E60C9	2017-07-05 12:38:00+03	44600.00
0E60E1	2017-07-15 02:57:00+03	138800.00
0E6133	2017-07-27 08:43:00+03	59800.00
0E614A	2017-07-29 03:35:00+03	22400.00
0E61CB	2017-07-04 05:58:00+03	63300.00
0E629A	2017-07-07 04:06:00+03	95700.00
0E62C7	2017-08-10 02:54:00+03	10700.00
0E62CF	2017-07-31 23:55:00+03	58900.00
0E6324	2017-07-15 20:21:00+03	248300.00
0E6418	2017-07-16 17:20:00+03	25800.00
0E6474	2017-08-06 21:14:00+03	153300.00
0E6475	2017-07-08 13:12:00+03	67700.00
0E647D	2017-07-23 10:04:00+03	77100.00
0E6487	2017-08-09 08:28:00+03	45200.00
0E64B2	2017-07-26 10:13:00+03	60700.00
0E6509	2017-08-10 03:08:00+03	53200.00
0E6532	2017-07-01 09:07:00+03	71600.00
0E6575	2017-08-05 15:51:00+03	9800.00
0E657C	2017-08-12 17:35:00+03	99300.00
0E6580	2017-07-25 08:54:00+03	68800.00
0E65AD	2017-08-07 23:29:00+03	16400.00
0E66BB	2017-07-26 23:29:00+03	56100.00
0E66BD	2017-07-12 12:57:00+03	52100.00
0E66E9	2017-08-05 06:22:00+03	25000.00
0E6712	2017-07-04 11:11:00+03	89600.00
0E6743	2017-08-11 00:57:00+03	12600.00
0E67AB	2017-08-15 05:48:00+03	125200.00
0E67F6	2017-08-03 13:54:00+03	26000.00
0E6808	2017-07-28 05:34:00+03	58800.00
0E6810	2017-08-14 03:48:00+03	122300.00
0E6813	2017-07-14 02:46:00+03	51600.00
0E681B	2017-07-21 20:17:00+03	125100.00
0E6848	2017-08-08 13:55:00+03	17200.00
0E68C8	2017-07-16 04:10:00+03	270800.00
0E6908	2017-08-03 03:42:00+03	26800.00
0E6962	2017-07-27 07:30:00+03	6300.00
0E69AA	2017-08-08 02:39:00+03	22400.00
0E6A11	2017-07-03 12:31:00+03	132800.00
0E6A18	2017-07-14 14:42:00+03	32800.00
0E6A78	2017-07-06 22:43:00+03	44500.00
0E6A80	2017-07-28 18:12:00+03	31400.00
0E6AE6	2017-08-13 08:38:00+03	44000.00
0E6B45	2017-07-28 09:17:00+03	12000.00
0E6BC5	2017-07-06 05:09:00+03	177800.00
0E6BE6	2017-08-09 12:11:00+03	24800.00
0E6C12	2017-07-05 19:54:00+03	80700.00
0E6C2D	2017-07-24 10:28:00+03	43500.00
0E6C4D	2017-07-17 16:52:00+03	51800.00
0E6C6A	2017-07-14 18:47:00+03	87400.00
0E6C94	2017-07-17 18:00:00+03	13400.00
0E6CDB	2017-07-16 22:56:00+03	94000.00
0E6D09	2017-08-01 10:21:00+03	47600.00
0E6D29	2017-07-29 20:31:00+03	44700.00
0E6DD2	2017-08-03 22:13:00+03	123000.00
0E6DEF	2017-07-08 15:41:00+03	29400.00
0E6E1D	2017-08-04 18:19:00+03	265700.00
0E6EC2	2017-07-19 09:56:00+03	100300.00
0E6F2C	2017-07-16 16:16:00+03	118200.00
0E6FB0	2017-07-28 17:13:00+03	136800.00
0E6FFB	2017-07-02 22:46:00+03	28000.00
0E703D	2017-08-02 00:49:00+03	211200.00
0E70D0	2017-08-02 15:20:00+03	27200.00
0E715E	2017-07-13 03:32:00+03	137400.00
0E717D	2017-07-25 11:29:00+03	95600.00
0E7184	2017-07-07 13:30:00+03	93700.00
0E7186	2017-08-10 02:56:00+03	39200.00
0E7192	2017-07-11 00:50:00+03	151100.00
0E71A5	2017-08-01 10:38:00+03	26600.00
0E72E8	2017-08-08 12:44:00+03	32700.00
0E72F6	2017-08-04 05:51:00+03	246000.00
0E733D	2017-08-07 13:00:00+03	87100.00
0E755B	2017-07-10 19:30:00+03	65200.00
0E764B	2017-08-04 06:03:00+03	189800.00
0E764D	2017-08-01 20:05:00+03	196000.00
0E76E2	2017-07-18 00:02:00+03	27200.00
0E76E6	2017-08-04 10:13:00+03	187600.00
0E76EA	2017-08-09 07:29:00+03	12600.00
0E770D	2017-08-04 20:17:00+03	46900.00
0E7782	2017-07-24 23:50:00+03	53600.00
0E7798	2017-07-12 01:19:00+03	75600.00
0E779E	2017-07-01 12:25:00+03	181800.00
0E77DA	2017-07-21 12:23:00+03	43600.00
0E7815	2017-07-21 19:45:00+03	78300.00
0E7831	2017-07-31 04:08:00+03	46400.00
0E7905	2017-06-28 00:51:00+03	45200.00
0E7912	2017-07-02 08:51:00+03	47000.00
0E798F	2017-08-01 18:37:00+03	149100.00
0E7ABB	2017-08-12 10:34:00+03	52700.00
0E7B15	2017-07-16 07:50:00+03	65900.00
0E7B4E	2017-07-05 05:28:00+03	37900.00
0E7B6A	2017-08-06 07:04:00+03	70700.00
0E7B7C	2017-08-08 11:05:00+03	89900.00
0E7BA3	2017-08-13 15:50:00+03	57300.00
0E7BAE	2017-07-13 15:04:00+03	54000.00
0E7C1F	2017-07-16 23:16:00+03	156500.00
0E7CB8	2017-07-22 17:17:00+03	36100.00
0E7D37	2017-07-08 13:47:00+03	265600.00
0E7E4D	2017-07-25 13:27:00+03	32800.00
0E7E59	2017-07-22 18:05:00+03	24000.00
0E7E7A	2017-07-24 02:26:00+03	25100.00
0E7F22	2017-07-05 07:46:00+03	37900.00
0E7F47	2017-07-26 15:06:00+03	59200.00
0E7F4A	2017-08-06 20:54:00+03	65200.00
0E7F55	2017-07-03 18:48:00+03	65600.00
0E7F5D	2017-08-04 19:57:00+03	202300.00
0E7FF1	2017-08-09 12:31:00+03	51300.00
0E8009	2017-07-20 01:38:00+03	23200.00
0E8032	2017-07-03 03:22:00+03	52300.00
0E80A5	2017-07-07 20:44:00+03	130400.00
0E80FF	2017-07-21 01:00:00+03	190400.00
0E81AC	2017-07-09 22:36:00+03	23200.00
0E81FB	2017-08-14 16:00:00+03	107000.00
0E8209	2017-07-20 05:22:00+03	61800.00
0E8230	2017-06-30 19:58:00+03	58400.00
0E8238	2017-07-11 22:08:00+03	24000.00
0E825F	2017-08-04 12:55:00+03	96200.00
0E826C	2017-07-26 16:18:00+03	52300.00
0E830C	2017-07-19 17:24:00+03	46000.00
0E831A	2017-08-08 16:21:00+03	23400.00
0E832B	2017-07-03 01:29:00+03	23200.00
0E83A1	2017-07-03 00:45:00+03	221800.00
0E83A3	2017-07-28 00:43:00+03	26600.00
0E8489	2017-07-26 09:31:00+03	32200.00
0E8495	2017-07-03 13:59:00+03	26800.00
0E84A1	2017-08-01 17:25:00+03	33300.00
0E84D3	2017-07-29 09:06:00+03	88000.00
0E855D	2017-08-10 17:28:00+03	103600.00
0E8573	2017-07-08 00:43:00+03	56600.00
0E85B4	2017-07-18 01:26:00+03	136600.00
0E8614	2017-07-20 05:02:00+03	246000.00
0E8650	2017-07-17 21:58:00+03	23200.00
0E86D0	2017-07-31 22:06:00+03	6000.00
0E870A	2017-08-07 18:16:00+03	45000.00
0E873C	2017-07-01 03:36:00+03	49900.00
0E874F	2017-08-05 09:53:00+03	136800.00
0E8782	2017-08-07 14:56:00+03	60700.00
0E8786	2017-07-04 15:21:00+03	28700.00
0E87EE	2017-08-09 12:02:00+03	94000.00
0E880F	2017-07-13 06:00:00+03	36800.00
0E8812	2017-07-20 19:53:00+03	683500.00
0E8838	2017-07-26 17:48:00+03	68000.00
0E884C	2017-07-04 07:58:00+03	46400.00
0E8873	2017-07-29 23:55:00+03	26800.00
0E88C0	2017-07-11 21:36:00+03	51900.00
0E88C1	2017-07-28 07:00:00+03	27900.00
0E88F2	2017-07-03 15:56:00+03	171100.00
0E891F	2017-07-15 04:50:00+03	536400.00
0E893B	2017-08-04 13:41:00+03	13400.00
0E897C	2017-07-10 13:18:00+03	14400.00
0E89B8	2017-07-19 17:44:00+03	112100.00
0E8A1A	2017-08-06 23:25:00+03	285900.00
0E8A2D	2017-08-02 15:47:00+03	153200.00
0E8A36	2017-07-18 18:23:00+03	28000.00
0E8A3B	2017-08-10 11:47:00+03	24400.00
0E8ABA	2017-07-13 13:51:00+03	68800.00
0E8ADB	2017-07-07 21:44:00+03	229500.00
0E8B1D	2017-07-31 09:52:00+03	73600.00
0E8B38	2017-07-13 21:45:00+03	112000.00
0E8B4B	2017-07-25 21:57:00+03	32800.00
0E8B62	2017-07-16 13:42:00+03	89700.00
0E8B7A	2017-08-08 01:13:00+03	217900.00
0E8B8E	2017-07-09 18:05:00+03	32800.00
0E8B94	2017-07-20 00:04:00+03	42900.00
0E8BDF	2017-07-06 03:42:00+03	85000.00
0E8C11	2017-07-13 17:53:00+03	202400.00
0E8C96	2017-07-25 09:47:00+03	12600.00
0E8CB1	2017-08-07 23:44:00+03	57500.00
0E8D03	2017-08-08 11:33:00+03	30000.00
0E8D28	2017-07-02 16:07:00+03	146300.00
0E8D7B	2017-07-30 11:47:00+03	22400.00
0E8E04	2017-07-18 06:41:00+03	23200.00
0E8E78	2017-07-20 16:33:00+03	27800.00
0E8EAC	2017-08-13 07:22:00+03	115800.00
0E8ECD	2017-07-18 12:42:00+03	55800.00
0E8EFB	2017-07-12 10:08:00+03	49100.00
0E8F15	2017-07-19 22:32:00+03	76600.00
0E8F32	2017-08-09 22:36:00+03	59800.00
0E8F71	2017-07-29 16:03:00+03	26000.00
0E8FA1	2017-07-04 21:28:00+03	31600.00
0E8FA9	2017-07-14 10:21:00+03	112000.00
0E8FE5	2017-08-10 20:10:00+03	56600.00
0E9041	2017-07-22 15:45:00+03	128800.00
0E9078	2017-07-18 14:07:00+03	111600.00
0E908E	2017-07-08 03:39:00+03	112600.00
0E90B8	2017-08-12 15:42:00+03	12600.00
0E90D8	2017-08-12 08:20:00+03	48800.00
0E915B	2017-07-29 07:05:00+03	12400.00
0E916C	2017-08-15 04:08:00+03	81300.00
0E9185	2017-07-23 22:59:00+03	47100.00
0E91F8	2017-07-28 14:42:00+03	54300.00
0E9215	2017-07-28 20:16:00+03	44800.00
0E9230	2017-07-16 20:55:00+03	31200.00
0E9260	2017-07-20 17:20:00+03	32800.00
0E9263	2017-07-22 08:01:00+03	75300.00
0E9295	2017-07-30 11:32:00+03	108600.00
0E9314	2017-07-18 19:21:00+03	68800.00
0E93A3	2017-07-15 16:26:00+03	105600.00
0E93A7	2017-07-07 20:33:00+03	10800.00
0E9414	2017-08-01 09:59:00+03	10600.00
0E94C3	2017-07-11 04:01:00+03	129700.00
0E9523	2017-07-05 13:09:00+03	62600.00
0E9544	2017-07-25 08:00:00+03	56000.00
0E9568	2017-08-08 04:24:00+03	59800.00
0E9595	2017-08-06 14:47:00+03	403300.00
0E95DF	2017-07-24 11:31:00+03	96300.00
0E95E3	2017-07-18 19:46:00+03	97700.00
0E95E9	2017-08-06 05:17:00+03	43500.00
0E9687	2017-08-12 00:46:00+03	123000.00
0E96A0	2017-07-08 00:40:00+03	50600.00
0E96D4	2017-07-21 13:27:00+03	35300.00
0E9731	2017-08-01 01:32:00+03	91100.00
0E9737	2017-08-12 01:40:00+03	111600.00
0E9777	2017-07-14 07:06:00+03	59800.00
0E97A8	2017-07-25 08:22:00+03	73200.00
0E97D6	2017-07-04 15:33:00+03	39000.00
0E97DD	2017-08-05 17:19:00+03	92800.00
0E97E1	2017-08-14 02:05:00+03	406200.00
0E9823	2017-07-16 04:43:00+03	496700.00
0E989C	2017-07-22 18:54:00+03	44000.00
0E98A2	2017-08-02 13:01:00+03	47000.00
0E9924	2017-07-26 08:41:00+03	28000.00
0E993E	2017-07-05 07:05:00+03	58000.00
0E9969	2017-07-14 06:12:00+03	248400.00
0E998E	2017-08-05 07:41:00+03	24400.00
0E9993	2017-07-15 20:56:00+03	59600.00
0E99EC	2017-08-06 06:23:00+03	106700.00
0E9A5A	2017-06-30 03:57:00+03	43200.00
0E9B0A	2017-07-10 20:29:00+03	34000.00
0E9B1A	2017-07-17 01:49:00+03	49500.00
0E9C0A	2017-07-06 18:40:00+03	23400.00
0E9C18	2017-06-30 17:20:00+03	40800.00
0E9C57	2017-07-21 07:35:00+03	40600.00
0E9C63	2017-07-20 23:37:00+03	61800.00
0E9C8A	2017-07-27 19:53:00+03	156500.00
0E9CBA	2017-07-20 21:09:00+03	265700.00
0E9D34	2017-07-16 23:36:00+03	23200.00
0E9DD8	2017-07-22 16:44:00+03	31600.00
0E9DEE	2017-07-17 07:14:00+03	61500.00
0E9E3F	2017-07-03 19:17:00+03	11600.00
0E9E80	2017-07-24 18:46:00+03	68100.00
0E9EB5	2017-08-11 03:29:00+03	21400.00
0E9F0C	2017-07-06 03:53:00+03	117600.00
0E9F83	2017-08-05 14:27:00+03	201800.00
0E9F97	2017-07-16 11:07:00+03	54200.00
0E9FC8	2017-08-03 02:18:00+03	101500.00
0E9FCE	2017-06-28 10:37:00+03	153100.00
0E9FEC	2017-07-10 20:09:00+03	39500.00
0EA000	2017-07-06 09:17:00+03	7400.00
0EA050	2017-08-01 19:33:00+03	88600.00
0EA051	2017-08-11 00:57:00+03	56000.00
0EA07D	2017-07-27 06:35:00+03	26000.00
0EA13C	2017-08-01 16:10:00+03	42700.00
0EA14E	2017-07-05 01:12:00+03	68600.00
0EA193	2017-08-08 00:36:00+03	115900.00
0EA1C0	2017-07-29 02:08:00+03	68400.00
0EA23F	2017-08-07 17:19:00+03	36200.00
0EA268	2017-08-07 14:04:00+03	25800.00
0EA27C	2017-07-14 07:29:00+03	75600.00
0EA365	2017-07-23 17:08:00+03	62800.00
0EA370	2017-07-17 22:26:00+03	44000.00
0EA383	2017-08-02 17:33:00+03	69500.00
0EA3CD	2017-07-13 15:59:00+03	76600.00
0EA3D2	2017-07-13 08:13:00+03	69900.00
0EA3E3	2017-07-19 13:48:00+03	98300.00
0EA44C	2017-07-27 21:21:00+03	131100.00
0EA4DB	2017-07-29 02:27:00+03	28000.00
0EA4DE	2017-08-13 12:41:00+03	177200.00
0EA4E6	2017-07-10 15:40:00+03	35600.00
0EA564	2017-07-04 06:06:00+03	272400.00
0EA5EB	2017-08-02 09:04:00+03	28800.00
0EA613	2017-08-13 16:13:00+03	46400.00
0EA616	2017-07-10 11:45:00+03	39300.00
0EA699	2017-07-03 21:19:00+03	14000.00
0EA6FE	2017-07-19 13:42:00+03	75600.00
0EA716	2017-07-23 02:31:00+03	18500.00
0EA749	2017-07-05 20:13:00+03	108600.00
0EA7A9	2017-07-22 00:04:00+03	135400.00
0EA7EB	2017-07-16 10:20:00+03	70100.00
0EA892	2017-07-25 03:20:00+03	209900.00
0EA8B6	2017-07-12 07:55:00+03	169300.00
0EA8CC	2017-07-21 23:14:00+03	99300.00
0EA904	2017-07-21 08:07:00+03	93900.00
0EA98D	2017-08-09 13:48:00+03	44800.00
0EAA1B	2017-08-12 00:32:00+03	52700.00
0EAA2F	2017-08-15 10:27:00+03	59800.00
0EAA3B	2017-07-10 22:56:00+03	23200.00
0EAA4F	2017-07-14 14:16:00+03	13600.00
0EAA85	2017-07-16 17:26:00+03	46500.00
0EAA9A	2017-07-23 02:50:00+03	175400.00
0EAAA4	2017-07-29 22:17:00+03	27900.00
0EAAC9	2017-08-14 21:25:00+03	112000.00
0EAAE3	2017-07-28 09:53:00+03	13200.00
0EAB13	2017-07-05 21:59:00+03	77200.00
0EABDD	2017-08-12 04:21:00+03	26000.00
0EABF2	2017-07-12 09:29:00+03	155600.00
0EABFE	2017-07-19 21:07:00+03	136200.00
0EAC03	2017-07-06 02:14:00+03	14400.00
0EAC22	2017-07-10 19:12:00+03	170100.00
0EAC3E	2017-07-08 18:47:00+03	136800.00
0EAC4F	2017-07-29 20:24:00+03	28800.00
0EAC84	2017-08-15 10:14:00+03	89200.00
0EACAE	2017-07-28 07:00:00+03	92800.00
0EAD01	2017-07-17 05:41:00+03	67000.00
0EAD0D	2017-08-10 04:02:00+03	10600.00
0EAD35	2017-07-22 19:21:00+03	89600.00
0EAD44	2017-07-28 16:08:00+03	64800.00
0EAD8E	2017-07-11 03:26:00+03	199700.00
0EAE12	2017-08-11 09:40:00+03	82900.00
0EAE68	2017-07-17 01:32:00+03	67600.00
0EAEBE	2017-08-13 13:57:00+03	66600.00
0EAEC6	2017-07-12 20:37:00+03	12000.00
0EAF3A	2017-07-09 02:35:00+03	58000.00
0EB016	2017-07-06 11:09:00+03	156000.00
0EB086	2017-07-14 16:01:00+03	128800.00
0EB0B3	2017-08-05 00:32:00+03	24400.00
0EB100	2017-07-23 19:59:00+03	52000.00
0EB1A4	2017-07-13 12:21:00+03	170700.00
0EB1AB	2017-08-14 22:27:00+03	14700.00
0EB1E9	2017-07-17 09:31:00+03	55800.00
0EB2F3	2017-08-09 14:13:00+03	115700.00
0EB385	2017-07-01 14:23:00+03	55800.00
0EB38D	2017-07-28 21:32:00+03	46200.00
0EB3AD	2017-07-05 13:00:00+03	17200.00
0EB3DB	2017-07-24 08:43:00+03	130900.00
0EB49D	2017-08-10 04:00:00+03	23200.00
0EB4BC	2017-07-27 20:15:00+03	37200.00
0EB4D1	2017-07-29 05:37:00+03	67000.00
0EB4EC	2017-07-03 20:43:00+03	57500.00
0EB524	2017-07-17 08:57:00+03	73300.00
0EB536	2017-07-10 17:34:00+03	26000.00
0EB554	2017-07-23 13:33:00+03	133200.00
0EB5D9	2017-07-28 06:14:00+03	26000.00
0EB656	2017-08-06 20:03:00+03	83800.00
0EB69D	2017-07-06 02:02:00+03	85700.00
0EB6C0	2017-07-10 04:01:00+03	29600.00
0EB752	2017-08-13 20:29:00+03	36800.00
0EB769	2017-07-05 19:15:00+03	59800.00
0EB76A	2017-08-07 15:46:00+03	225200.00
0EB77D	2017-07-11 17:44:00+03	58900.00
0EB849	2017-07-25 11:51:00+03	21800.00
0EB875	2017-08-05 08:07:00+03	6700.00
0EB8DA	2017-08-09 08:36:00+03	73600.00
0EB973	2017-06-29 02:19:00+03	29800.00
0EBAB8	2017-07-06 06:15:00+03	131100.00
0EBADD	2017-07-16 02:31:00+03	22000.00
0EBB95	2017-07-22 04:22:00+03	83200.00
0EBB9D	2017-08-11 02:30:00+03	3700.00
0EBBD8	2017-08-08 15:13:00+03	98400.00
0EBBE5	2017-07-28 02:12:00+03	22000.00
0EBBE7	2017-08-07 16:30:00+03	111600.00
0EBC9F	2017-07-16 10:07:00+03	26500.00
0EBCA1	2017-08-07 07:38:00+03	68100.00
0EBCEC	2017-08-11 15:07:00+03	27400.00
0EBD03	2017-08-13 12:25:00+03	12000.00
0EBD2D	2017-08-10 22:40:00+03	270700.00
0EBD2E	2017-07-18 03:30:00+03	99200.00
0EBD7C	2017-08-12 13:47:00+03	375200.00
0EBD8C	2017-07-14 19:46:00+03	191000.00
0EBDB5	2017-07-17 20:28:00+03	34000.00
0EBE2E	2017-08-14 17:34:00+03	153200.00
0EBE30	2017-08-09 20:34:00+03	130400.00
0EBE48	2017-07-20 10:58:00+03	55800.00
0EBF1B	2017-08-14 04:56:00+03	155600.00
0EBF7A	2017-08-13 08:45:00+03	28800.00
0EBF95	2017-07-22 21:08:00+03	86400.00
0EC015	2017-08-04 14:54:00+03	46200.00
0EC01F	2017-07-15 07:21:00+03	79000.00
0EC056	2017-07-18 04:54:00+03	73600.00
0EC082	2017-08-02 20:29:00+03	25800.00
0EC0BC	2017-08-02 17:10:00+03	156600.00
0EC0FB	2017-07-19 07:54:00+03	31600.00
0EC11C	2017-07-06 17:04:00+03	46400.00
0EC159	2017-07-16 15:17:00+03	20400.00
0EC16F	2017-07-26 05:33:00+03	55800.00
0EC1B5	2017-07-22 09:57:00+03	13000.00
0EC1F7	2017-07-05 20:03:00+03	114400.00
0EC252	2017-07-16 02:08:00+03	38400.00
0EC2F8	2017-08-09 15:44:00+03	25100.00
0EC317	2017-07-10 12:52:00+03	14400.00
0EC339	2017-07-06 12:32:00+03	202000.00
0EC3A2	2017-07-13 19:48:00+03	24400.00
0EC3A8	2017-07-10 21:18:00+03	136800.00
0EC3C0	2017-07-28 17:39:00+03	125600.00
0EC3FA	2017-07-09 07:35:00+03	42800.00
0EC473	2017-08-03 09:08:00+03	338400.00
0EC4C4	2017-07-19 13:42:00+03	52000.00
0EC507	2017-08-12 02:32:00+03	28800.00
0EC544	2017-07-02 17:51:00+03	28300.00
0EC564	2017-07-24 20:40:00+03	398400.00
0EC5AA	2017-07-28 10:14:00+03	47100.00
0EC5CC	2017-07-03 20:30:00+03	135600.00
0EC5FB	2017-07-21 20:21:00+03	12400.00
0EC603	2017-07-29 23:02:00+03	12600.00
0EC6CC	2017-08-03 19:40:00+03	71000.00
0EC6D8	2017-07-05 14:36:00+03	57500.00
0EC772	2017-07-21 06:53:00+03	198400.00
0EC7AA	2017-08-15 11:46:00+03	72300.00
0EC7D1	2017-08-12 23:57:00+03	75500.00
0EC821	2017-07-05 20:31:00+03	46400.00
0EC82A	2017-07-19 12:19:00+03	8000.00
0EC844	2017-07-06 15:05:00+03	14800.00
0EC849	2017-08-07 03:07:00+03	14400.00
0EC861	2017-07-30 12:24:00+03	59200.00
0EC867	2017-08-07 18:58:00+03	28800.00
0EC86F	2017-07-24 16:48:00+03	65500.00
0EC87E	2017-08-14 22:39:00+03	86400.00
0EC8F1	2017-08-09 12:43:00+03	60400.00
0EC964	2017-07-22 17:37:00+03	13400.00
0EC9A7	2017-07-09 07:30:00+03	12200.00
0EC9AE	2017-07-25 07:11:00+03	48800.00
0EC9C5	2017-07-28 19:15:00+03	33000.00
0EC9E2	2017-07-26 13:43:00+03	51900.00
0ECB32	2017-07-28 06:38:00+03	31800.00
0ECB7B	2017-08-15 14:21:00+03	118300.00
0ECB8C	2017-08-07 14:26:00+03	26000.00
0ECC2B	2017-07-31 01:14:00+03	64800.00
0ECC53	2017-07-31 08:00:00+03	108800.00
0ECC58	2017-08-09 12:39:00+03	306500.00
0ECC8C	2017-07-31 12:21:00+03	24400.00
0ECC96	2017-07-05 01:48:00+03	44700.00
0ECC99	2017-08-09 18:25:00+03	78800.00
0ECCBA	2017-07-11 00:44:00+03	34000.00
0ECD43	2017-08-04 16:36:00+03	123000.00
0ECD8C	2017-07-23 21:40:00+03	56000.00
0ECD96	2017-08-09 05:41:00+03	62700.00
0ECE54	2017-07-24 21:09:00+03	142800.00
0ECEA1	2017-08-13 20:42:00+03	36900.00
0ECEEF	2017-07-13 13:45:00+03	104400.00
0ECF73	2017-07-30 15:15:00+03	76600.00
0ECF84	2017-07-13 15:10:00+03	58600.00
0ECFBA	2017-07-17 15:00:00+03	23200.00
0ECFCE	2017-07-09 22:00:00+03	212000.00
0ED007	2017-07-26 21:06:00+03	52300.00
0ED031	2017-07-08 08:54:00+03	30900.00
0ED03A	2017-08-07 08:44:00+03	16400.00
0ED066	2017-07-13 05:06:00+03	6700.00
0ED0A2	2017-08-03 05:32:00+03	138500.00
0ED0ED	2017-07-27 17:55:00+03	23200.00
0ED0F1	2017-07-29 23:41:00+03	100000.00
0ED0F5	2017-08-07 16:58:00+03	21000.00
0ED14F	2017-07-12 05:56:00+03	24400.00
0ED1E8	2017-07-17 07:15:00+03	15700.00
0ED1FC	2017-07-10 03:48:00+03	10600.00
0ED201	2017-08-15 07:35:00+03	60400.00
0ED2ED	2017-08-04 10:23:00+03	15400.00
0ED308	2017-06-29 04:33:00+03	14800.00
0ED33F	2017-07-30 03:52:00+03	123000.00
0ED345	2017-08-12 15:25:00+03	128800.00
0ED358	2017-07-11 03:29:00+03	137600.00
0ED372	2017-07-10 17:02:00+03	55800.00
0ED398	2017-07-08 07:20:00+03	113000.00
0ED44B	2017-08-11 22:38:00+03	151200.00
0ED451	2017-08-14 17:37:00+03	57500.00
0ED48C	2017-07-16 04:28:00+03	38400.00
0ED4AB	2017-07-13 13:27:00+03	31100.00
0ED4AD	2017-07-14 20:19:00+03	42000.00
0ED4E7	2017-07-07 11:09:00+03	46400.00
0ED4F1	2017-07-14 01:42:00+03	67100.00
0ED5CC	2017-08-05 00:56:00+03	44000.00
0ED5F3	2017-08-03 23:25:00+03	58800.00
0ED623	2017-07-08 10:22:00+03	46200.00
0ED676	2017-08-07 10:12:00+03	60300.00
0ED6A5	2017-07-19 07:59:00+03	102100.00
0ED703	2017-08-12 03:18:00+03	39300.00
0ED73D	2017-07-11 09:50:00+03	55800.00
0ED769	2017-08-05 14:08:00+03	60000.00
0ED79F	2017-07-31 22:09:00+03	40600.00
0ED803	2017-08-07 23:10:00+03	92800.00
0ED891	2017-07-09 00:22:00+03	89700.00
0ED8D7	2017-07-14 10:25:00+03	14400.00
0ED8E1	2017-07-03 20:52:00+03	112600.00
0ED8FF	2017-07-08 06:52:00+03	69500.00
0ED92E	2017-07-15 00:52:00+03	54400.00
0ED933	2017-07-02 10:50:00+03	78500.00
0ED9A0	2017-07-05 01:30:00+03	283100.00
0ED9BB	2017-07-17 00:29:00+03	62600.00
0EDAB4	2017-07-08 08:10:00+03	19600.00
0EDAE2	2017-07-27 21:38:00+03	96200.00
0EDAE3	2017-07-15 09:00:00+03	20200.00
0EDAF6	2017-07-05 08:16:00+03	23200.00
0EDB42	2017-08-10 06:50:00+03	41400.00
0EDB8F	2017-07-28 19:55:00+03	29600.00
0EDB9D	2017-08-14 00:23:00+03	42800.00
0EDBDB	2017-07-23 09:04:00+03	97800.00
0EDC1D	2017-08-14 10:49:00+03	241200.00
0EDC2F	2017-07-24 23:38:00+03	127300.00
0EDC6F	2017-07-25 08:33:00+03	137600.00
0EDCF2	2017-08-14 17:59:00+03	46400.00
0EDD0C	2017-07-15 18:55:00+03	150000.00
0EDDEF	2017-08-10 10:51:00+03	18600.00
0EDE03	2017-07-13 21:36:00+03	40000.00
0EDE4C	2017-07-15 18:05:00+03	42800.00
0EDE89	2017-08-06 11:20:00+03	57800.00
0EDF79	2017-08-04 20:11:00+03	151600.00
0EDFC6	2017-08-04 11:19:00+03	116500.00
0EE00E	2017-07-10 18:19:00+03	68800.00
0EE014	2017-07-26 00:44:00+03	135400.00
0EE01D	2017-07-23 05:32:00+03	58900.00
0EE035	2017-07-31 08:52:00+03	103200.00
0EE08C	2017-07-17 22:50:00+03	69500.00
0EE092	2017-08-07 20:55:00+03	6300.00
0EE09B	2017-07-03 07:38:00+03	26800.00
0EE0DA	2017-07-29 22:33:00+03	17000.00
0EE115	2017-06-29 09:18:00+03	46400.00
0EE135	2017-08-04 22:57:00+03	61800.00
0EE13C	2017-07-27 02:37:00+03	18000.00
0EE149	2017-08-04 01:51:00+03	67700.00
0EE1A1	2017-08-15 07:23:00+03	95700.00
0EE22F	2017-07-04 04:22:00+03	136500.00
0EE279	2017-07-18 09:48:00+03	173900.00
0EE2FF	2017-07-23 11:25:00+03	136600.00
0EE363	2017-08-08 00:43:00+03	62400.00
0EE36C	2017-07-28 16:41:00+03	68100.00
0EE3A6	2017-07-16 15:30:00+03	23600.00
0EE58E	2017-08-02 12:22:00+03	46000.00
0EE59E	2017-07-08 20:45:00+03	89600.00
0EE5C0	2017-07-24 05:47:00+03	27300.00
0EE616	2017-07-28 23:10:00+03	41200.00
0EE625	2017-08-04 16:11:00+03	37900.00
0EE629	2017-07-03 01:30:00+03	41200.00
0EE650	2017-07-05 18:45:00+03	49100.00
0EE68E	2017-07-24 14:15:00+03	399600.00
0EE721	2017-07-23 14:26:00+03	6000.00
0EE763	2017-07-11 11:09:00+03	23600.00
0EE77A	2017-08-08 02:10:00+03	40000.00
0EE79C	2017-07-23 12:51:00+03	26100.00
0EE7A0	2017-08-09 05:38:00+03	81600.00
0EE7BF	2017-07-25 06:50:00+03	19600.00
0EE7DC	2017-08-07 20:00:00+03	47900.00
0EE870	2017-07-23 23:04:00+03	133100.00
0EE897	2017-07-28 13:32:00+03	30200.00
0EE8CE	2017-08-12 06:50:00+03	123000.00
0EE8CF	2017-06-30 07:25:00+03	56600.00
0EE8DA	2017-07-31 17:56:00+03	118600.00
0EE8EA	2017-07-05 19:09:00+03	23200.00
0EE910	2017-07-31 22:53:00+03	117000.00
0EE9A7	2017-08-12 18:53:00+03	72400.00
0EEA16	2017-08-08 01:54:00+03	51200.00
0EEA74	2017-06-30 13:37:00+03	6000.00
0EEAE0	2017-07-12 02:12:00+03	14600.00
0EEB12	2017-07-16 00:51:00+03	23400.00
0EEB84	2017-07-17 05:43:00+03	46400.00
0EEB95	2017-08-03 23:35:00+03	65900.00
0EEC13	2017-07-03 17:21:00+03	6300.00
0EEC23	2017-08-09 16:19:00+03	83800.00
0EEC70	2017-08-10 07:19:00+03	112000.00
0EEC74	2017-07-31 19:24:00+03	77900.00
0EED19	2017-08-10 15:07:00+03	19600.00
0EED89	2017-07-19 21:25:00+03	26000.00
0EED8A	2017-07-07 23:56:00+03	47000.00
0EEDAE	2017-07-30 12:25:00+03	14000.00
0EEE70	2017-07-21 05:02:00+03	25100.00
0EEE8A	2017-07-16 10:51:00+03	32800.00
0EEEC5	2017-07-13 07:09:00+03	31700.00
0EEEF9	2017-08-09 01:16:00+03	100200.00
0EEFD8	2017-08-01 23:46:00+03	15800.00
0EEFD9	2017-08-05 21:42:00+03	23600.00
0EF001	2017-07-19 11:13:00+03	92900.00
0EF035	2017-07-29 00:41:00+03	102000.00
0EF0BA	2017-08-10 16:08:00+03	105600.00
0EF13C	2017-07-15 19:31:00+03	47000.00
0EF194	2017-07-23 15:05:00+03	18000.00
0EF2AE	2017-07-22 10:03:00+03	45200.00
0EF2EC	2017-07-29 10:58:00+03	6700.00
0EF323	2017-07-28 08:43:00+03	64800.00
0EF337	2017-07-19 12:45:00+03	28000.00
0EF38A	2017-08-03 01:00:00+03	124200.00
0EF3B9	2017-08-05 11:48:00+03	68400.00
0EF3DF	2017-07-27 08:11:00+03	94800.00
0EF448	2017-07-19 15:58:00+03	18900.00
0EF47E	2017-08-01 22:06:00+03	26800.00
0EF47F	2017-08-02 09:10:00+03	43900.00
0EF48E	2017-08-01 15:12:00+03	27200.00
0EF49A	2017-07-18 06:10:00+03	10800.00
0EF4DA	2017-07-21 00:27:00+03	31400.00
0EF4EE	2017-08-03 04:48:00+03	46400.00
0EF501	2017-07-02 10:35:00+03	78100.00
0EF503	2017-08-11 02:19:00+03	47100.00
0EF589	2017-07-31 13:21:00+03	27900.00
0EF58C	2017-07-05 17:54:00+03	56200.00
0EF599	2017-08-13 01:21:00+03	34400.00
0EF59D	2017-08-06 18:06:00+03	29600.00
0EF62E	2017-07-15 22:58:00+03	134900.00
0EF678	2017-07-01 04:46:00+03	73300.00
0EF69A	2017-07-18 15:19:00+03	52400.00
0EF6DE	2017-07-28 16:53:00+03	34400.00
0EF74D	2017-07-17 16:56:00+03	59800.00
0EF76D	2017-07-24 10:53:00+03	510500.00
0EF798	2017-08-01 06:25:00+03	36200.00
0EF7B2	2017-08-08 13:41:00+03	57800.00
0EF7F6	2017-07-04 09:18:00+03	28800.00
0EF835	2017-08-03 06:14:00+03	16400.00
0EF859	2017-07-22 22:28:00+03	17000.00
0EF8DF	2017-07-06 14:47:00+03	311200.00
0EF8E6	2017-07-04 18:42:00+03	198400.00
0EF915	2017-08-11 14:18:00+03	19600.00
0EF99A	2017-07-02 02:08:00+03	49800.00
0EF99C	2017-07-10 18:05:00+03	67100.00
0EF9AA	2017-08-12 03:21:00+03	43400.00
0EF9E5	2017-07-29 05:24:00+03	92900.00
0EFA52	2017-07-12 11:53:00+03	56000.00
0EFAED	2017-07-30 04:56:00+03	24000.00
0EFAFB	2017-07-29 19:19:00+03	31000.00
0EFB0F	2017-08-01 01:37:00+03	49100.00
0EFBB3	2017-07-12 00:00:00+03	26000.00
0EFC64	2017-08-09 07:06:00+03	32700.00
0EFCBC	2017-08-15 06:35:00+03	6000.00
0EFD20	2017-07-22 03:29:00+03	7400.00
0EFDEE	2017-07-24 18:57:00+03	141200.00
0EFDF0	2017-07-13 19:04:00+03	6000.00
0EFDFB	2017-07-31 01:00:00+03	31400.00
0EFE04	2017-07-05 11:41:00+03	28000.00
0EFE17	2017-08-04 19:55:00+03	299800.00
0EFE69	2017-08-05 02:48:00+03	12600.00
0EFE86	2017-07-18 21:16:00+03	40000.00
0EFF02	2017-07-23 00:28:00+03	27500.00
0EFF15	2017-07-10 15:20:00+03	139200.00
0EFF19	2017-08-04 21:16:00+03	21400.00
0EFF55	2017-07-27 16:38:00+03	11600.00
0EFF89	2017-07-14 20:40:00+03	40400.00
0F007B	2017-08-06 06:17:00+03	38400.00
0F0096	2017-07-10 21:13:00+03	64700.00
0F009D	2017-08-14 08:52:00+03	22000.00
0F00C5	2017-08-13 14:59:00+03	21800.00
0F00F3	2017-07-15 20:27:00+03	73100.00
0F0114	2017-08-15 10:36:00+03	55800.00
0F01A1	2017-07-06 12:54:00+03	58400.00
0F01A3	2017-07-13 17:06:00+03	117000.00
0F01BC	2017-07-26 03:03:00+03	181100.00
0F020D	2017-07-26 02:36:00+03	23600.00
0F0246	2017-06-30 16:40:00+03	69700.00
0F0256	2017-07-10 14:45:00+03	34400.00
0F0268	2017-07-31 02:06:00+03	139400.00
0F0281	2017-07-15 08:10:00+03	81600.00
0F0377	2017-08-15 11:04:00+03	31400.00
0F0381	2017-08-12 16:56:00+03	86800.00
0F038B	2017-08-09 18:36:00+03	100600.00
0F03BE	2017-07-17 19:44:00+03	25400.00
0F03DF	2017-07-13 02:22:00+03	39300.00
0F03E3	2017-08-14 04:55:00+03	17800.00
0F043C	2017-08-11 04:50:00+03	16400.00
0F04A7	2017-07-18 18:55:00+03	46000.00
0F04B5	2017-08-09 06:41:00+03	68900.00
0F04B6	2017-07-24 18:23:00+03	96200.00
0F04DD	2017-07-07 04:29:00+03	532600.00
0F04E4	2017-08-10 05:06:00+03	28800.00
0F0522	2017-07-14 20:55:00+03	159200.00
0F05BC	2017-08-11 19:04:00+03	91800.00
0F0613	2017-06-27 01:45:00+03	108800.00
0F067A	2017-07-12 11:36:00+03	156600.00
0F0682	2017-07-07 16:27:00+03	102600.00
0F0756	2017-08-09 18:55:00+03	102100.00
0F0793	2017-07-23 09:08:00+03	57500.00
0F07B5	2017-07-23 02:15:00+03	246000.00
0F07BB	2017-07-30 23:30:00+03	62000.00
0F07BF	2017-07-13 05:19:00+03	23200.00
0F07E1	2017-07-04 01:42:00+03	175600.00
0F082E	2017-07-21 11:25:00+03	87200.00
0F087C	2017-07-26 00:52:00+03	29600.00
0F088F	2017-07-07 18:52:00+03	43300.00
0F09DD	2017-06-28 06:50:00+03	96200.00
0F0A14	2017-07-10 11:33:00+03	89200.00
0F0A17	2017-07-02 22:34:00+03	38400.00
0F0A43	2017-08-04 19:57:00+03	22000.00
0F0A8A	2017-08-01 15:28:00+03	64600.00
0F0A9C	2017-08-09 08:23:00+03	414000.00
0F0AB2	2017-07-28 21:48:00+03	58400.00
0F0AB8	2017-07-24 17:55:00+03	18800.00
0F0ABD	2017-07-20 09:01:00+03	128000.00
0F0B90	2017-07-09 20:48:00+03	31400.00
0F0BF5	2017-08-12 14:11:00+03	41600.00
0F0C41	2017-07-27 17:27:00+03	122000.00
0F0CA1	2017-08-15 13:20:00+03	86800.00
0F0D32	2017-07-28 10:53:00+03	6300.00
0F0D45	2017-07-21 11:51:00+03	203300.00
0F0D8C	2017-07-16 02:18:00+03	27200.00
0F0DB8	2017-06-30 10:09:00+03	23200.00
0F0DD1	2017-08-10 15:40:00+03	66400.00
0F0DE2	2017-06-30 10:47:00+03	89200.00
0F0DFD	2017-07-02 04:28:00+03	70700.00
0F0E3C	2017-07-25 08:38:00+03	57600.00
0F0EBE	2017-07-30 02:15:00+03	260900.00
0F0F4A	2017-07-10 04:40:00+03	235400.00
0F0F50	2017-07-09 11:30:00+03	59800.00
0F0F8D	2017-07-11 07:26:00+03	163500.00
0F0FA8	2017-08-14 07:07:00+03	179400.00
0F0FED	2017-07-19 00:45:00+03	84500.00
0F1020	2017-08-15 11:58:00+03	123000.00
0F1065	2017-07-12 21:20:00+03	72300.00
0F1072	2017-07-12 05:43:00+03	128900.00
0F10C0	2017-08-02 21:14:00+03	6300.00
0F10D2	2017-07-31 19:19:00+03	94000.00
0F1111	2017-08-10 06:41:00+03	19600.00
0F11D9	2017-07-29 10:33:00+03	174400.00
0F120B	2017-08-01 01:25:00+03	35600.00
0F124E	2017-07-07 19:02:00+03	21400.00
0F1297	2017-07-17 04:04:00+03	69400.00
0F12B7	2017-08-11 11:58:00+03	89600.00
0F12BC	2017-08-03 08:56:00+03	111000.00
0F12E8	2017-08-13 22:04:00+03	55800.00
0F12F3	2017-08-10 06:37:00+03	99200.00
0F132C	2017-07-14 21:00:00+03	56000.00
0F13D2	2017-08-03 06:40:00+03	42700.00
0F13F3	2017-06-29 11:06:00+03	88200.00
0F1400	2017-07-24 05:58:00+03	81800.00
0F1466	2017-07-27 06:02:00+03	19600.00
0F148A	2017-07-10 15:49:00+03	23200.00
0F14B7	2017-07-12 00:44:00+03	61800.00
0F14FE	2017-07-10 15:00:00+03	113200.00
0F1517	2017-07-14 19:22:00+03	535700.00
0F155A	2017-07-04 04:34:00+03	26000.00
0F15AC	2017-07-29 15:10:00+03	52700.00
0F15D0	2017-07-23 19:11:00+03	26200.00
0F164C	2017-07-08 14:36:00+03	89700.00
0F1679	2017-08-09 18:53:00+03	28800.00
0F176A	2017-07-05 09:25:00+03	111600.00
0F17D3	2017-07-26 15:41:00+03	19600.00
0F1809	2017-07-19 23:13:00+03	116400.00
0F183E	2017-07-16 00:20:00+03	129700.00
0F1872	2017-08-04 13:18:00+03	155600.00
0F1887	2017-08-13 04:59:00+03	53900.00
0F18B5	2017-07-04 10:33:00+03	29300.00
0F18C3	2017-07-16 15:26:00+03	67600.00
0F18C5	2017-07-02 07:23:00+03	42800.00
0F18DB	2017-07-22 09:07:00+03	536400.00
0F1906	2017-07-18 23:55:00+03	59800.00
0F191E	2017-08-02 23:08:00+03	28800.00
0F1983	2017-07-25 05:34:00+03	36400.00
0F19A6	2017-08-13 00:02:00+03	94100.00
0F19B4	2017-08-07 06:41:00+03	111600.00
0F19CF	2017-07-19 01:16:00+03	24400.00
0F1A32	2017-07-28 04:54:00+03	111600.00
0F1A89	2017-07-03 06:34:00+03	136500.00
0F1A9B	2017-08-03 16:20:00+03	36800.00
0F1B16	2017-08-13 07:16:00+03	30900.00
0F1B67	2017-08-09 11:02:00+03	75300.00
0F1B72	2017-08-09 03:07:00+03	91600.00
0F1B73	2017-07-30 06:56:00+03	36200.00
0F1B8B	2017-08-12 08:23:00+03	66000.00
0F1BF7	2017-07-11 18:21:00+03	28800.00
0F1BFC	2017-07-01 02:04:00+03	40000.00
0F1C08	2017-07-10 00:52:00+03	75300.00
0F1C37	2017-07-10 07:40:00+03	85000.00
0F1C4C	2017-08-14 02:56:00+03	29600.00
0F1C83	2017-08-04 21:13:00+03	55800.00
0F1CC2	2017-07-07 19:28:00+03	266400.00
0F1CE9	2017-08-12 17:20:00+03	13200.00
0F1D39	2017-08-11 22:45:00+03	72400.00
0F1D85	2017-08-03 07:40:00+03	40400.00
0F1D8C	2017-07-03 02:15:00+03	44800.00
0F1DF3	2017-08-10 09:17:00+03	58200.00
0F1ECB	2017-07-06 01:28:00+03	406100.00
0F1EDD	2017-07-07 11:20:00+03	47400.00
0F1EFE	2017-08-11 03:12:00+03	14800.00
0F1F28	2017-08-10 08:22:00+03	24000.00
0F1F53	2017-07-15 08:18:00+03	77200.00
0F1F55	2017-07-26 14:24:00+03	36800.00
0F1FFA	2017-07-27 11:40:00+03	55800.00
0F2086	2017-07-15 14:36:00+03	23200.00
0F20A1	2017-08-15 02:31:00+03	136200.00
0F210A	2017-08-07 01:39:00+03	32700.00
0F2120	2017-07-16 22:46:00+03	68000.00
0F213E	2017-07-04 08:28:00+03	71100.00
0F21E7	2017-07-30 08:30:00+03	54400.00
0F21EC	2017-07-24 04:19:00+03	27200.00
0F21F2	2017-07-17 12:26:00+03	44000.00
0F2220	2017-08-02 20:36:00+03	50100.00
0F2237	2017-08-04 12:37:00+03	23200.00
0F2239	2017-07-31 08:11:00+03	18000.00
0F2254	2017-07-16 14:32:00+03	63200.00
0F22CF	2017-07-24 13:24:00+03	106700.00
0F22F3	2017-07-20 13:46:00+03	26700.00
0F230D	2017-07-03 08:13:00+03	58800.00
0F2319	2017-07-31 08:54:00+03	168000.00
0F2346	2017-07-05 16:42:00+03	82900.00
0F238E	2017-08-04 13:14:00+03	246000.00
0F247B	2017-07-06 21:25:00+03	19600.00
0F24A7	2017-07-16 17:50:00+03	47400.00
0F24EA	2017-07-28 18:59:00+03	24400.00
0F2508	2017-08-14 13:28:00+03	53100.00
0F258C	2017-07-31 12:22:00+03	47500.00
0F2595	2017-08-14 03:49:00+03	44000.00
0F25A6	2017-07-01 01:06:00+03	26000.00
0F25EF	2017-07-24 00:27:00+03	48800.00
0F25F1	2017-08-07 23:04:00+03	126800.00
0F25FC	2017-08-01 10:07:00+03	57600.00
0F2611	2017-07-03 23:01:00+03	265700.00
0F26B6	2017-08-06 20:50:00+03	56000.00
0F26D1	2017-08-13 04:07:00+03	36200.00
0F26FC	2017-07-27 11:51:00+03	68100.00
0F271F	2017-07-02 14:04:00+03	23200.00
0F279D	2017-07-27 21:34:00+03	32800.00
0F27DA	2017-07-24 21:06:00+03	78100.00
0F2800	2017-08-07 05:19:00+03	16400.00
0F280C	2017-08-08 10:34:00+03	65000.00
0F2875	2017-07-21 11:36:00+03	39300.00
0F288E	2017-07-01 16:32:00+03	28000.00
0F28C1	2017-07-08 06:11:00+03	44800.00
0F28C5	2017-07-30 00:27:00+03	28800.00
0F2915	2017-07-09 20:29:00+03	80400.00
0F295E	2017-07-16 06:48:00+03	46000.00
0F29AE	2017-07-29 05:06:00+03	24400.00
0F29CC	2017-07-05 08:27:00+03	290400.00
0F29EC	2017-08-05 14:53:00+03	25600.00
0F2A0A	2017-07-29 13:50:00+03	55800.00
0F2A27	2017-07-01 07:09:00+03	112000.00
0F2A60	2017-07-19 08:03:00+03	56900.00
0F2BB9	2017-08-03 03:26:00+03	13400.00
0F2BD9	2017-07-26 15:09:00+03	86500.00
0F2BE6	2017-07-28 23:02:00+03	7400.00
0F2C41	2017-07-29 20:28:00+03	62900.00
0F2C6E	2017-08-08 02:46:00+03	67100.00
0F2CA0	2017-07-14 05:22:00+03	21400.00
0F2CCE	2017-07-05 04:29:00+03	289800.00
0F2D5A	2017-08-04 21:14:00+03	23600.00
0F2E61	2017-08-03 20:12:00+03	6700.00
0F2F17	2017-07-04 22:01:00+03	30200.00
0F3017	2017-07-14 04:34:00+03	29600.00
0F3018	2017-08-15 04:29:00+03	68100.00
0F3071	2017-07-28 13:22:00+03	31600.00
0F3072	2017-08-03 02:40:00+03	49300.00
0F3074	2017-07-23 06:12:00+03	8000.00
0F30B3	2017-07-28 03:35:00+03	99300.00
0F30CB	2017-07-14 02:02:00+03	61900.00
0F31EE	2017-08-14 03:28:00+03	210200.00
0F325E	2017-07-31 22:02:00+03	33100.00
0F3283	2017-07-10 22:24:00+03	105600.00
0F3370	2017-08-05 10:27:00+03	47400.00
0F3375	2017-07-26 08:50:00+03	51900.00
0F3385	2017-07-07 17:40:00+03	69500.00
0F33FF	2017-07-15 20:59:00+03	173500.00
0F3404	2017-08-14 19:15:00+03	8000.00
0F3467	2017-07-30 07:21:00+03	32800.00
0F3498	2017-07-07 02:30:00+03	66000.00
0F34F2	2017-07-04 03:42:00+03	199700.00
0F34F3	2017-07-31 22:56:00+03	40400.00
0F34F4	2017-07-07 22:40:00+03	75600.00
0F34FE	2017-08-15 00:43:00+03	56000.00
0F3510	2017-07-03 17:59:00+03	66100.00
0F358C	2017-07-18 16:45:00+03	209700.00
0F35D7	2017-07-24 07:59:00+03	31600.00
0F360C	2017-08-11 20:30:00+03	13600.00
0F362C	2017-08-07 23:30:00+03	118000.00
0F3649	2017-08-06 01:20:00+03	201200.00
0F36A3	2017-08-05 18:35:00+03	136800.00
0F36E8	2017-07-13 15:28:00+03	19600.00
0F372A	2017-07-17 04:07:00+03	47400.00
0F37A8	2017-08-05 13:37:00+03	44800.00
0F380C	2017-07-22 03:48:00+03	14000.00
0F3827	2017-07-17 20:53:00+03	42400.00
0F3884	2017-08-14 21:57:00+03	23200.00
0F388D	2017-07-27 21:27:00+03	75800.00
0F38C7	2017-08-14 04:36:00+03	37200.00
0F391C	2017-08-01 11:16:00+03	65500.00
0F3922	2017-08-12 03:39:00+03	266400.00
0F3A13	2017-07-01 14:58:00+03	33600.00
0F3A81	2017-08-14 03:55:00+03	265600.00
0F3AF0	2017-08-13 05:51:00+03	41800.00
0F3B0E	2017-08-13 13:32:00+03	26500.00
0F3B78	2017-08-06 07:54:00+03	100600.00
0F3B88	2017-07-05 23:26:00+03	43800.00
0F3BE9	2017-07-16 10:56:00+03	68400.00
0F3BFA	2017-07-27 23:30:00+03	67700.00
0F3C1F	2017-07-03 17:15:00+03	44000.00
0F3C54	2017-07-01 01:29:00+03	47400.00
0F3C67	2017-07-24 12:22:00+03	101900.00
0F3CFB	2017-07-29 09:42:00+03	11000.00
0F3D64	2017-07-25 20:09:00+03	38500.00
0F3D87	2017-08-13 15:33:00+03	67600.00
0F3DEA	2017-08-04 00:43:00+03	20900.00
0F3E13	2017-08-06 11:18:00+03	40000.00
0F3E14	2017-07-30 12:51:00+03	11800.00
0F3E79	2017-07-28 21:01:00+03	68100.00
0F3EEC	2017-07-04 03:47:00+03	62800.00
0F3F32	2017-07-09 13:51:00+03	88400.00
0F3FAF	2017-07-26 15:27:00+03	38800.00
0F3FEF	2017-08-10 09:56:00+03	35800.00
0F407D	2017-07-11 01:39:00+03	46400.00
0F4090	2017-07-30 07:43:00+03	65500.00
0F40C7	2017-07-28 20:23:00+03	38600.00
0F40DF	2017-08-01 22:09:00+03	21800.00
0F4123	2017-08-10 13:21:00+03	303500.00
0F413B	2017-07-26 16:16:00+03	56000.00
0F419B	2017-07-24 23:28:00+03	69500.00
0F41E1	2017-07-12 01:19:00+03	59200.00
0F422D	2017-08-02 19:09:00+03	28000.00
0F424C	2017-07-05 13:31:00+03	23600.00
0F42E1	2017-06-29 21:48:00+03	30800.00
0F4325	2017-08-10 02:22:00+03	104000.00
0F4393	2017-07-20 19:46:00+03	21400.00
0F44A0	2017-07-04 23:45:00+03	18600.00
0F44B4	2017-08-10 08:58:00+03	77400.00
0F44D5	2017-07-19 13:09:00+03	14400.00
0F44FE	2017-08-12 13:05:00+03	265700.00
0F455A	2017-07-08 05:29:00+03	49800.00
0F4577	2017-07-05 21:27:00+03	48500.00
0F4590	2017-07-17 05:46:00+03	123000.00
0F4592	2017-07-20 15:02:00+03	93700.00
0F45EE	2017-08-14 10:46:00+03	65500.00
0F46B2	2017-07-29 07:36:00+03	47200.00
0F46D7	2017-07-11 10:55:00+03	38200.00
0F4722	2017-08-07 13:39:00+03	88800.00
0F4777	2017-07-19 06:12:00+03	6000.00
0F4840	2017-07-10 10:28:00+03	515000.00
0F484A	2017-07-24 12:26:00+03	40300.00
0F4870	2017-07-26 21:50:00+03	56000.00
0F4878	2017-07-01 20:25:00+03	192900.00
0F48C3	2017-07-11 08:09:00+03	40000.00
0F48D8	2017-06-30 05:21:00+03	57700.00
0F4977	2017-08-06 08:14:00+03	58700.00
0F49AA	2017-07-08 16:54:00+03	23200.00
0F49FC	2017-07-14 03:14:00+03	23200.00
0F4A25	2017-08-02 23:19:00+03	62100.00
0F4A85	2017-08-12 06:03:00+03	30200.00
0F4ABA	2017-07-29 00:39:00+03	9200.00
0F4AE8	2017-07-16 03:58:00+03	37500.00
0F4AEB	2017-07-31 20:25:00+03	21800.00
0F4B73	2017-07-19 19:46:00+03	26000.00
0F4BDF	2017-08-06 00:37:00+03	38300.00
0F4C06	2017-07-29 09:45:00+03	56600.00
0F4C37	2017-07-28 04:20:00+03	11800.00
0F4CAA	2017-07-20 04:52:00+03	182300.00
0F4CC6	2017-07-15 09:27:00+03	39500.00
0F4CDB	2017-08-13 21:43:00+03	14100.00
0F4CDF	2017-08-09 06:45:00+03	23600.00
0F4D05	2017-07-25 02:57:00+03	58900.00
0F4D07	2017-07-25 20:42:00+03	12400.00
0F4D1D	2017-07-27 21:16:00+03	28000.00
0F4DAB	2017-07-17 21:41:00+03	16400.00
0F4DB4	2017-07-16 07:27:00+03	37900.00
0F4E3E	2017-07-12 02:31:00+03	103500.00
0F4EA7	2017-07-27 15:23:00+03	70700.00
0F4F1C	2017-08-14 18:09:00+03	147700.00
0F4F67	2017-08-03 08:31:00+03	19600.00
0F4F83	2017-07-21 23:46:00+03	22400.00
0F4FBB	2017-07-19 22:21:00+03	72400.00
0F5091	2017-08-15 00:03:00+03	65900.00
0F50FD	2017-08-06 09:23:00+03	88800.00
0F510E	2017-07-08 17:36:00+03	21800.00
0F5120	2017-07-11 20:09:00+03	52400.00
0F5150	2017-08-07 06:42:00+03	85000.00
0F5186	2017-08-05 07:20:00+03	37100.00
0F51BA	2017-07-14 09:12:00+03	57400.00
0F524B	2017-07-13 16:22:00+03	32200.00
0F5263	2017-06-29 14:20:00+03	108500.00
0F528A	2017-07-02 09:17:00+03	34000.00
0F5308	2017-07-03 10:35:00+03	46000.00
0F534E	2017-07-12 18:28:00+03	62800.00
0F53C4	2017-07-08 13:42:00+03	57100.00
0F53D9	2017-07-08 11:26:00+03	87000.00
0F53F6	2017-07-18 22:21:00+03	55800.00
0F5468	2017-08-14 21:10:00+03	104800.00
0F5477	2017-08-11 17:23:00+03	83100.00
0F5496	2017-08-12 18:16:00+03	27800.00
0F54D0	2017-07-28 12:56:00+03	41400.00
0F55BF	2017-07-20 18:31:00+03	23600.00
0F55CA	2017-07-26 07:18:00+03	28800.00
0F561E	2017-07-07 00:49:00+03	79600.00
0F565D	2017-07-22 02:04:00+03	154500.00
0F56A1	2017-08-13 05:44:00+03	53200.00
0F56B5	2017-07-16 19:16:00+03	93900.00
0F56D0	2017-07-21 13:44:00+03	56900.00
0F572B	2017-07-24 16:19:00+03	28800.00
0F5778	2017-07-31 03:28:00+03	56000.00
0F57B3	2017-08-03 22:34:00+03	23400.00
0F580D	2017-07-15 02:15:00+03	38400.00
0F5839	2017-07-14 20:14:00+03	36800.00
0F5893	2017-07-15 12:52:00+03	116700.00
0F58A2	2017-07-10 23:56:00+03	120400.00
0F590E	2017-08-12 03:14:00+03	46000.00
0F59A6	2017-08-02 12:41:00+03	32200.00
0F59A7	2017-07-21 09:56:00+03	55400.00
0F59AE	2017-07-06 07:24:00+03	46000.00
0F59B7	2017-08-14 17:48:00+03	496600.00
0F5A64	2017-07-06 22:42:00+03	15000.00
0F5A74	2017-07-11 19:20:00+03	127000.00
0F5AC1	2017-07-14 05:29:00+03	31600.00
0F5AD5	2017-07-21 19:05:00+03	66400.00
0F5AF8	2017-07-30 18:31:00+03	217800.00
0F5B1A	2017-07-18 10:21:00+03	78800.00
0F5B35	2017-07-17 01:51:00+03	67600.00
0F5B6F	2017-07-22 02:09:00+03	30200.00
0F5C14	2017-07-16 00:09:00+03	36200.00
0F5C29	2017-08-10 04:11:00+03	28800.00
0F5C34	2017-07-16 10:16:00+03	90600.00
0F5C68	2017-06-26 01:31:00+03	40300.00
0F5C7A	2017-07-20 10:14:00+03	58800.00
0F5C95	2017-07-06 00:57:00+03	36800.00
0F5CFB	2017-07-22 12:13:00+03	85000.00
0F5D8D	2017-07-03 17:54:00+03	41200.00
0F5E05	2017-08-02 03:10:00+03	36400.00
0F5E50	2017-07-14 04:55:00+03	27800.00
0F5E66	2017-07-05 20:30:00+03	32700.00
0F5ED6	2017-07-21 20:22:00+03	46800.00
0F5ED9	2017-07-06 20:53:00+03	12600.00
0F5EF9	2017-07-28 13:28:00+03	31000.00
0F5F0A	2017-07-07 07:07:00+03	103500.00
0F5F54	2017-08-04 10:49:00+03	124200.00
0F5F69	2017-08-13 11:30:00+03	72800.00
0F5FCB	2017-07-26 19:36:00+03	55800.00
0F5FD2	2017-08-07 16:21:00+03	11600.00
0F6055	2017-08-15 11:37:00+03	12000.00
0F60C4	2017-07-15 19:00:00+03	118300.00
0F612A	2017-08-15 12:48:00+03	111600.00
0F6135	2017-08-09 00:34:00+03	24400.00
0F6149	2017-07-09 16:24:00+03	43600.00
0F61BF	2017-07-16 00:24:00+03	13200.00
0F61D1	2017-07-24 02:46:00+03	123600.00
0F621D	2017-07-21 00:49:00+03	59800.00
0F622F	2017-07-26 00:05:00+03	68900.00
0F6275	2017-08-09 12:41:00+03	43400.00
0F62B4	2017-07-27 03:35:00+03	35800.00
0F62C5	2017-07-03 22:41:00+03	123000.00
0F62D1	2017-07-16 04:13:00+03	13400.00
0F62ED	2017-08-02 16:58:00+03	88000.00
0F6379	2017-08-04 01:00:00+03	38600.00
0F63AA	2017-08-05 01:08:00+03	96200.00
0F63CD	2017-07-23 20:09:00+03	369000.00
0F63E5	2017-08-15 00:46:00+03	87700.00
0F6406	2017-07-17 18:02:00+03	24400.00
0F643E	2017-07-12 20:46:00+03	67700.00
0F6508	2017-07-01 15:12:00+03	98000.00
0F65A0	2017-07-18 09:05:00+03	26700.00
0F65F8	2017-07-28 22:49:00+03	28000.00
0F6640	2017-08-12 03:28:00+03	79000.00
0F6643	2017-07-19 07:44:00+03	88300.00
0F6694	2017-07-23 17:54:00+03	284400.00
0F6764	2017-07-18 09:25:00+03	92800.00
0F679E	2017-07-24 23:41:00+03	14400.00
0F67A3	2017-07-09 05:15:00+03	45200.00
0F67A8	2017-08-13 13:18:00+03	59800.00
0F6810	2017-08-09 18:21:00+03	242900.00
0F6825	2017-07-23 17:44:00+03	51200.00
0F6842	2017-07-24 08:27:00+03	16400.00
0F6843	2017-07-06 12:22:00+03	56000.00
0F684B	2017-07-05 04:00:00+03	41600.00
0F6879	2017-08-06 23:28:00+03	8000.00
0F687A	2017-07-08 02:39:00+03	62400.00
0F691C	2017-07-30 16:19:00+03	94600.00
0F6981	2017-07-10 08:15:00+03	123900.00
0F69D7	2017-07-05 22:31:00+03	20200.00
0F69F9	2017-06-30 21:16:00+03	15000.00
0F69FB	2017-07-07 03:00:00+03	52300.00
0F6A14	2017-08-14 13:08:00+03	25100.00
0F6A68	2017-07-02 13:55:00+03	87100.00
0F6A78	2017-07-16 03:14:00+03	55800.00
0F6AC7	2017-07-21 12:15:00+03	52000.00
0F6B4D	2017-08-06 09:14:00+03	15000.00
0F6BBA	2017-07-02 05:15:00+03	28000.00
0F6C0B	2017-07-21 22:37:00+03	103700.00
0F6C68	2017-08-02 18:32:00+03	52800.00
0F6C84	2017-08-10 07:15:00+03	13400.00
0F6C9F	2017-07-05 06:16:00+03	85000.00
0F6CBD	2017-07-10 20:12:00+03	14100.00
0F6CDE	2017-07-28 01:39:00+03	50700.00
0F6D07	2017-07-15 10:36:00+03	34800.00
0F6D14	2017-08-13 12:56:00+03	77000.00
0F6D32	2017-07-17 09:49:00+03	167300.00
0F6DAC	2017-08-07 10:53:00+03	55800.00
0F6DEF	2017-07-26 11:07:00+03	55500.00
0F6DF4	2017-08-15 10:13:00+03	467000.00
0F6E06	2017-07-30 17:04:00+03	48800.00
0F6EA0	2017-07-27 18:45:00+03	15100.00
0F6EC4	2017-08-03 21:32:00+03	148700.00
0F6F3B	2017-08-04 17:56:00+03	99200.00
0F6F97	2017-07-17 01:24:00+03	13200.00
0F7046	2017-07-19 07:09:00+03	266400.00
0F704A	2017-07-02 03:36:00+03	55600.00
0F7065	2017-08-15 06:15:00+03	40800.00
0F7071	2017-07-30 19:59:00+03	70800.00
0F7109	2017-07-19 09:35:00+03	49900.00
0F7115	2017-07-12 22:54:00+03	59900.00
0F7134	2017-07-15 06:36:00+03	135600.00
0F7152	2017-07-09 19:23:00+03	37800.00
0F7305	2017-08-06 02:39:00+03	82900.00
0F7383	2017-07-01 23:02:00+03	166000.00
0F73B4	2017-07-04 22:18:00+03	77900.00
0F7425	2017-07-09 22:44:00+03	68800.00
0F7478	2017-07-26 23:27:00+03	73900.00
0F74E0	2017-07-18 11:18:00+03	283700.00
0F74EC	2017-08-02 02:36:00+03	55800.00
0F7524	2017-07-25 09:45:00+03	49500.00
0F753E	2017-07-28 14:31:00+03	77700.00
0F758C	2017-07-15 06:51:00+03	8400.00
0F7591	2017-08-15 16:54:00+03	32800.00
0F75A5	2017-08-04 04:13:00+03	28800.00
0F75DB	2017-07-25 05:38:00+03	81300.00
0F761E	2017-07-24 03:19:00+03	272300.00
0F7648	2017-07-24 21:41:00+03	30200.00
0F7658	2017-07-29 22:55:00+03	44400.00
0F7663	2017-07-16 22:17:00+03	30600.00
0F7678	2017-08-12 11:57:00+03	47000.00
0F76C6	2017-07-26 18:14:00+03	20200.00
0F76D1	2017-07-13 23:37:00+03	120600.00
0F76D7	2017-07-06 22:08:00+03	58600.00
0F76EE	2017-07-18 12:58:00+03	57800.00
0F76F4	2017-07-11 14:33:00+03	14000.00
0F7738	2017-07-08 19:32:00+03	21400.00
0F7753	2017-08-08 16:24:00+03	65400.00
0F778B	2017-08-06 09:01:00+03	36200.00
0F7791	2017-07-21 21:43:00+03	26700.00
0F7799	2017-08-10 01:16:00+03	10800.00
0F77A1	2017-07-04 07:23:00+03	46900.00
0F77BA	2017-08-14 19:21:00+03	77600.00
0F77CA	2017-08-02 08:52:00+03	100600.00
0F77EF	2017-07-05 15:30:00+03	48500.00
0F7831	2017-08-08 13:07:00+03	23200.00
0F783F	2017-07-30 14:59:00+03	33300.00
0F786A	2017-07-23 17:24:00+03	184300.00
0F78A7	2017-07-17 09:39:00+03	28800.00
0F790D	2017-07-18 09:09:00+03	43700.00
0F791A	2017-08-14 12:18:00+03	70800.00
0F79AC	2017-07-24 06:46:00+03	20600.00
0F79B1	2017-07-22 12:49:00+03	289800.00
0F79F6	2017-07-02 20:19:00+03	99700.00
0F7A09	2017-07-26 22:49:00+03	16400.00
0F7A12	2017-08-01 01:41:00+03	46200.00
0F7A21	2017-07-23 13:15:00+03	92000.00
0F7A2D	2017-06-27 21:48:00+03	126000.00
0F7A45	2017-07-05 05:13:00+03	137600.00
0F7AEE	2017-07-10 23:17:00+03	201100.00
0F7AFB	2017-07-15 07:26:00+03	114300.00
0F7B12	2017-07-22 21:46:00+03	21800.00
0F7B9B	2017-08-03 23:31:00+03	79200.00
0F7BA2	2017-07-02 21:56:00+03	24200.00
0F7BA4	2017-08-03 18:58:00+03	186900.00
0F7BE1	2017-08-01 12:00:00+03	147400.00
0F7C01	2017-06-30 17:19:00+03	6000.00
0F7C14	2017-07-28 11:40:00+03	38800.00
0F7C5C	2017-08-03 19:14:00+03	24000.00
0F7CED	2017-08-15 08:18:00+03	28000.00
0F7D70	2017-07-04 01:21:00+03	26200.00
0F7DC6	2017-07-20 14:51:00+03	163300.00
0F7DEE	2017-08-14 21:42:00+03	26700.00
0F7E02	2017-07-04 19:17:00+03	28800.00
0F7E03	2017-08-09 04:14:00+03	57800.00
0F7E3B	2017-08-12 06:15:00+03	79200.00
0F7E4A	2017-08-12 20:36:00+03	27200.00
0F7E50	2017-08-05 23:54:00+03	26000.00
0F7EB1	2017-07-05 13:14:00+03	131000.00
0F7EEE	2017-07-26 03:07:00+03	26800.00
0F7F1E	2017-07-02 08:48:00+03	46400.00
0F7F1F	2017-08-03 07:56:00+03	28800.00
0F7F32	2017-08-04 08:55:00+03	58400.00
0F7F78	2017-07-28 20:25:00+03	66400.00
0F7F87	2017-08-05 14:46:00+03	62900.00
0F7FBD	2017-07-17 00:58:00+03	7200.00
0F800D	2017-08-09 14:22:00+03	43600.00
0F805F	2017-07-02 16:23:00+03	89600.00
0F80BE	2017-07-29 03:35:00+03	208200.00
0F8136	2017-07-07 23:07:00+03	31100.00
0F815B	2017-08-05 20:16:00+03	202800.00
0F8179	2017-07-29 10:09:00+03	73300.00
0F818B	2017-08-12 11:55:00+03	96300.00
0F8192	2017-07-21 22:21:00+03	28000.00
0F81C0	2017-07-09 13:03:00+03	56000.00
0F81C9	2017-07-30 22:20:00+03	54000.00
0F81D5	2017-08-12 09:39:00+03	85000.00
0F81EA	2017-07-11 20:49:00+03	102800.00
0F8252	2017-08-10 19:12:00+03	54500.00
0F827C	2017-07-18 08:53:00+03	103500.00
0F832E	2017-07-22 00:09:00+03	100800.00
0F83DC	2017-06-30 12:14:00+03	28800.00
0F83F5	2017-07-19 09:40:00+03	88900.00
0F8496	2017-07-20 07:05:00+03	83600.00
0F84EC	2017-07-19 15:23:00+03	381400.00
0F84F5	2017-07-07 08:07:00+03	186900.00
0F85D6	2017-06-29 10:30:00+03	75600.00
0F85DA	2017-07-06 18:22:00+03	60000.00
0F8628	2017-07-28 19:23:00+03	33300.00
0F8638	2017-08-05 12:20:00+03	112000.00
0F86B8	2017-07-29 04:26:00+03	88100.00
0F87AE	2017-07-27 22:43:00+03	136800.00
0F87C4	2017-08-06 00:46:00+03	22800.00
0F87E1	2017-08-09 13:03:00+03	320300.00
0F87EC	2017-07-17 03:55:00+03	19600.00
0F882B	2017-07-31 13:56:00+03	83900.00
0F8830	2017-07-03 21:10:00+03	136200.00
0F8879	2017-07-16 09:55:00+03	26700.00
0F88B9	2017-07-20 05:32:00+03	38000.00
0F88BA	2017-08-14 10:19:00+03	38800.00
0F893B	2017-07-01 14:11:00+03	67900.00
0F8956	2017-08-14 09:30:00+03	33800.00
0F897C	2017-06-27 11:09:00+03	97900.00
0F89B2	2017-07-29 23:43:00+03	43400.00
0F89E8	2017-08-12 14:51:00+03	258400.00
0F8A16	2017-07-03 11:12:00+03	47700.00
0F8A31	2017-08-09 09:23:00+03	95200.00
0F8A33	2017-07-06 11:01:00+03	21600.00
0F8AAA	2017-07-10 20:13:00+03	46000.00
0F8AB3	2017-08-05 12:23:00+03	46000.00
0F8AEF	2017-07-06 03:33:00+03	57400.00
0F8AF3	2017-07-12 09:30:00+03	18700.00
0F8B7F	2017-08-03 17:06:00+03	48800.00
0F8BFA	2017-07-01 00:13:00+03	303100.00
0F8C1D	2017-07-08 21:28:00+03	43200.00
0F8C28	2017-07-07 08:50:00+03	31400.00
0F8C4C	2017-08-02 11:19:00+03	148200.00
0F8C7E	2017-08-12 03:49:00+03	57600.00
0F8D37	2017-07-09 20:31:00+03	28000.00
0F8D44	2017-07-30 22:36:00+03	99600.00
0F8D6B	2017-08-03 02:55:00+03	26000.00
0F8DCF	2017-07-30 07:45:00+03	12600.00
0F8DFE	2017-08-14 14:48:00+03	90800.00
0F8E5D	2017-07-07 22:08:00+03	123700.00
0F8EE6	2017-07-19 05:11:00+03	67600.00
0F8EF7	2017-07-13 21:30:00+03	44800.00
0F8F2A	2017-08-11 05:13:00+03	18300.00
0F8F69	2017-08-02 10:15:00+03	56000.00
0F8F87	2017-07-24 10:21:00+03	48800.00
0F8F8B	2017-07-25 11:16:00+03	60300.00
0F8FA3	2017-07-08 18:13:00+03	38800.00
0F8FDE	2017-08-12 21:55:00+03	79400.00
0F8FE0	2017-08-03 06:01:00+03	47200.00
0F9025	2017-07-08 00:29:00+03	39600.00
0F90C4	2017-07-04 04:45:00+03	40600.00
0F9154	2017-07-27 09:50:00+03	176800.00
0F916E	2017-08-08 13:01:00+03	42400.00
0F9191	2017-07-02 16:37:00+03	25100.00
0F9217	2017-07-16 05:01:00+03	108600.00
0F9262	2017-08-04 10:31:00+03	13400.00
0F926F	2017-07-19 01:36:00+03	110500.00
0F9274	2017-07-15 20:27:00+03	7400.00
0F9299	2017-07-08 16:33:00+03	24400.00
0F92A1	2017-07-16 01:40:00+03	131600.00
0F92D6	2017-07-19 16:39:00+03	71800.00
0F931B	2017-08-05 20:32:00+03	58500.00
0F9344	2017-06-29 01:42:00+03	87600.00
0F936E	2017-08-08 03:55:00+03	95200.00
0F9388	2017-08-08 08:05:00+03	139300.00
0F93D7	2017-07-25 19:08:00+03	66600.00
0F93F0	2017-07-20 14:46:00+03	64600.00
0F9513	2017-08-15 16:11:00+03	134400.00
0F9522	2017-08-09 03:43:00+03	12000.00
0F9532	2017-07-14 06:03:00+03	199800.00
0F9601	2017-07-06 13:33:00+03	134400.00
0F9642	2017-07-11 20:40:00+03	97000.00
0F96D8	2017-08-06 19:47:00+03	56200.00
0F978A	2017-08-09 17:34:00+03	26700.00
0F9791	2017-08-09 17:42:00+03	8400.00
0F983A	2017-07-09 17:48:00+03	40300.00
0F9899	2017-07-05 23:45:00+03	73600.00
0F98CC	2017-07-18 10:41:00+03	26800.00
0F98E5	2017-07-15 17:28:00+03	10700.00
0F98FC	2017-08-15 04:14:00+03	255600.00
0F9912	2017-08-04 06:19:00+03	24400.00
0F9917	2017-07-03 08:35:00+03	29600.00
0F993D	2017-07-17 07:00:00+03	53300.00
0F9954	2017-07-11 14:26:00+03	102000.00
0F999D	2017-07-07 22:34:00+03	39600.00
0F9A1E	2017-08-14 19:17:00+03	38400.00
0F9AB5	2017-07-22 02:11:00+03	229500.00
0F9B14	2017-07-07 06:56:00+03	162100.00
0F9B5E	2017-08-04 12:59:00+03	369000.00
0F9B71	2017-06-29 10:19:00+03	6700.00
0F9BA0	2017-07-31 21:42:00+03	380200.00
0F9BED	2017-07-09 18:37:00+03	73300.00
0F9C21	2017-08-01 05:22:00+03	100600.00
0F9C2E	2017-07-26 22:26:00+03	44000.00
0F9C88	2017-07-14 15:35:00+03	246000.00
0F9CD3	2017-07-01 17:34:00+03	45200.00
0F9CDE	2017-08-04 13:20:00+03	50000.00
0F9CFE	2017-07-23 10:56:00+03	79600.00
0F9D39	2017-08-09 05:18:00+03	73300.00
0F9D3E	2017-07-01 05:02:00+03	6700.00
0F9D41	2017-07-29 03:56:00+03	90300.00
0F9D78	2017-08-01 00:22:00+03	78300.00
0F9DC7	2017-07-03 02:19:00+03	84100.00
0F9DDF	2017-07-04 09:14:00+03	25000.00
0F9DE8	2017-06-29 14:09:00+03	26000.00
0F9DFE	2017-07-10 22:03:00+03	28000.00
0F9E3B	2017-07-19 05:38:00+03	138000.00
0F9E46	2017-07-30 03:33:00+03	115900.00
0F9E7F	2017-07-08 15:10:00+03	39300.00
0F9E91	2017-07-14 01:51:00+03	25800.00
0F9EB2	2017-07-17 09:01:00+03	93500.00
0F9ECA	2017-08-12 07:33:00+03	38400.00
0F9EFC	2017-07-30 12:46:00+03	31800.00
0F9FBD	2017-07-18 04:54:00+03	67200.00
0FA063	2017-07-11 01:24:00+03	28300.00
0FA0DD	2017-07-13 12:26:00+03	46400.00
0FA0F2	2017-08-02 23:19:00+03	46000.00
0FA11B	2017-07-09 23:11:00+03	73200.00
0FA1D0	2017-08-07 17:52:00+03	95200.00
0FA20A	2017-07-20 16:16:00+03	58000.00
0FA2FC	2017-07-09 06:43:00+03	38400.00
0FA30F	2017-07-19 05:34:00+03	23200.00
0FA36A	2017-08-02 22:27:00+03	60900.00
0FA397	2017-07-28 05:58:00+03	76600.00
0FA3D1	2017-07-10 17:06:00+03	20200.00
0FA420	2017-07-06 17:20:00+03	55800.00
0FA4B1	2017-08-12 18:29:00+03	46000.00
0FA4CE	2017-08-12 22:07:00+03	57800.00
0FA50F	2017-08-04 02:49:00+03	101600.00
0FA53E	2017-07-24 08:59:00+03	41400.00
0FA5A1	2017-08-03 01:52:00+03	88600.00
0FA5D2	2017-07-31 22:47:00+03	54400.00
0FA5E7	2017-08-15 09:13:00+03	32900.00
0FA632	2017-07-18 19:43:00+03	18800.00
0FA68E	2017-07-15 08:05:00+03	46000.00
0FA6AE	2017-07-11 19:58:00+03	64300.00
0FA6F0	2017-08-09 14:17:00+03	18600.00
0FA7B0	2017-07-04 11:12:00+03	69100.00
0FA7B5	2017-07-18 01:24:00+03	119700.00
0FA805	2017-08-09 13:36:00+03	82900.00
0FA854	2017-08-10 18:35:00+03	106500.00
0FA85C	2017-07-12 14:13:00+03	56800.00
0FA88B	2017-08-14 11:54:00+03	55800.00
0FA88F	2017-07-19 02:09:00+03	46400.00
0FA926	2017-07-19 15:00:00+03	136800.00
0FA93E	2017-07-08 15:54:00+03	123000.00
0FA9AE	2017-07-04 17:18:00+03	147900.00
0FAA50	2017-08-12 17:27:00+03	59100.00
0FAA6B	2017-07-31 15:56:00+03	38800.00
0FAAA7	2017-07-17 12:20:00+03	68800.00
0FAABC	2017-07-31 13:09:00+03	92900.00
0FAAC7	2017-07-25 04:02:00+03	42000.00
0FAAFE	2017-07-21 04:40:00+03	65900.00
0FAB8A	2017-08-06 06:26:00+03	28000.00
0FABB1	2017-08-13 01:24:00+03	258000.00
0FABE8	2017-07-26 04:11:00+03	6700.00
0FAC6E	2017-07-22 19:46:00+03	19600.00
0FAC8A	2017-07-04 10:47:00+03	125400.00
0FAC96	2017-07-21 06:21:00+03	32200.00
0FAC9D	2017-07-24 21:41:00+03	32700.00
0FACB1	2017-07-14 15:53:00+03	37300.00
0FACC9	2017-07-27 02:20:00+03	92900.00
0FACFE	2017-07-21 20:31:00+03	54400.00
0FAD4B	2017-08-08 07:44:00+03	31600.00
0FAD52	2017-07-24 21:33:00+03	39300.00
0FADB9	2017-08-14 12:00:00+03	56000.00
0FAED7	2017-07-29 13:49:00+03	6000.00
0FAF20	2017-08-09 13:30:00+03	113200.00
0FAF5E	2017-07-26 01:17:00+03	25600.00
0FAFE6	2017-07-10 01:46:00+03	49300.00
0FAFEB	2017-07-25 03:07:00+03	175300.00
0FB068	2017-08-07 23:46:00+03	113200.00
0FB0C1	2017-07-13 13:25:00+03	114100.00
0FB0EA	2017-07-07 21:25:00+03	148200.00
0FB139	2017-08-02 12:47:00+03	30200.00
0FB190	2017-08-08 19:30:00+03	60400.00
0FB19D	2017-07-16 05:47:00+03	69100.00
0FB1BB	2017-08-09 21:43:00+03	552000.00
0FB1CD	2017-07-09 13:30:00+03	69500.00
0FB1E2	2017-08-08 08:10:00+03	265800.00
0FB279	2017-07-06 07:55:00+03	65500.00
0FB298	2017-07-31 18:59:00+03	173300.00
0FB29D	2017-07-11 20:06:00+03	40400.00
0FB2B1	2017-08-01 20:12:00+03	12800.00
0FB2DC	2017-07-27 18:16:00+03	10700.00
0FB322	2017-07-15 22:43:00+03	37900.00
0FB38A	2017-07-25 09:16:00+03	25100.00
0FB3CC	2017-08-04 15:08:00+03	168000.00
0FB3D2	2017-07-09 10:58:00+03	38400.00
0FB401	2017-08-14 15:38:00+03	43900.00
0FB440	2017-07-12 07:41:00+03	111600.00
0FB46F	2017-08-09 12:50:00+03	67200.00
0FB47E	2017-08-07 07:08:00+03	25400.00
0FB51B	2017-07-13 10:12:00+03	83000.00
0FB557	2017-07-15 08:02:00+03	32800.00
0FB55A	2017-08-14 08:07:00+03	45100.00
0FB563	2017-08-03 01:21:00+03	15800.00
0FB589	2017-07-22 07:35:00+03	233800.00
0FB5D9	2017-07-18 09:19:00+03	35200.00
0FB66D	2017-08-07 18:56:00+03	34200.00
0FB67F	2017-08-13 23:48:00+03	40400.00
0FB6DB	2017-07-21 15:37:00+03	47100.00
0FB75B	2017-07-17 21:55:00+03	47000.00
0FB7A1	2017-07-18 14:07:00+03	10800.00
0FB7F9	2017-07-14 03:04:00+03	119700.00
0FB835	2017-07-07 03:37:00+03	249100.00
0FB870	2017-08-14 21:55:00+03	46400.00
0FB87F	2017-08-05 00:16:00+03	23400.00
0FB8D5	2017-07-13 21:44:00+03	46400.00
0FB964	2017-07-31 01:46:00+03	59600.00
0FB9A4	2017-08-03 20:59:00+03	135600.00
0FBA0B	2017-08-15 17:31:00+03	47600.00
0FBA2D	2017-07-22 05:18:00+03	94700.00
0FBA40	2017-07-12 21:34:00+03	60200.00
0FBA75	2017-07-27 07:53:00+03	131100.00
0FBAC6	2017-08-10 01:40:00+03	133100.00
0FBB2F	2017-07-05 11:37:00+03	23600.00
0FBB58	2017-07-07 13:35:00+03	76400.00
0FBB62	2017-08-13 17:55:00+03	27000.00
0FBB6D	2017-07-24 15:20:00+03	37900.00
0FBB8D	2017-08-02 06:34:00+03	13400.00
0FBBA1	2017-07-26 02:17:00+03	66000.00
0FBC54	2017-07-31 11:39:00+03	56200.00
0FBC97	2017-07-26 22:21:00+03	87400.00
0FBCA4	2017-08-09 11:26:00+03	24700.00
0FBCEB	2017-07-04 03:09:00+03	26800.00
0FBD37	2017-08-05 04:00:00+03	29800.00
0FBD70	2017-07-17 18:56:00+03	86300.00
0FBD7F	2017-07-13 06:12:00+03	48700.00
0FBD92	2017-08-01 19:35:00+03	36200.00
0FBD9D	2017-07-23 05:35:00+03	99200.00
0FBD9E	2017-07-11 03:15:00+03	49000.00
0FBE85	2017-08-12 22:31:00+03	59300.00
0FBE90	2017-07-07 11:04:00+03	62600.00
0FBE9B	2017-07-11 19:03:00+03	37900.00
0FBEAE	2017-07-26 10:33:00+03	75300.00
0FBF13	2017-08-13 22:36:00+03	23600.00
0FBF51	2017-07-15 20:19:00+03	8000.00
0FBF9E	2017-08-04 00:48:00+03	21400.00
0FBFF3	2017-07-04 19:39:00+03	48800.00
0FBFFE	2017-08-12 19:11:00+03	90700.00
0FC03A	2017-07-04 19:45:00+03	75300.00
0FC16B	2017-07-11 01:48:00+03	32500.00
0FC1B8	2017-07-21 01:32:00+03	73500.00
0FC1D3	2017-07-06 17:36:00+03	92400.00
0FC1EA	2017-08-11 16:50:00+03	136600.00
0FC1F1	2017-07-20 08:16:00+03	73500.00
0FC251	2017-07-18 18:26:00+03	32800.00
0FC27D	2017-08-14 18:06:00+03	124200.00
0FC285	2017-07-05 12:35:00+03	172000.00
0FC32C	2017-08-10 04:59:00+03	54800.00
0FC360	2017-07-12 10:45:00+03	51900.00
0FC3D7	2017-08-04 03:34:00+03	28700.00
0FC3E3	2017-07-07 20:23:00+03	38600.00
0FC3FD	2017-07-06 05:12:00+03	11600.00
0FC431	2017-07-31 05:32:00+03	50300.00
0FC4B6	2017-07-21 12:53:00+03	97700.00
0FC756	2017-08-15 11:10:00+03	14000.00
0FC792	2017-08-14 01:50:00+03	4400.00
0FC7D4	2017-07-13 17:21:00+03	47600.00
0FC806	2017-07-10 02:18:00+03	138000.00
0FC838	2017-07-04 04:10:00+03	35700.00
0FC83B	2017-07-06 21:26:00+03	69100.00
0FC847	2017-07-08 18:40:00+03	13600.00
0FC865	2017-07-04 05:34:00+03	175300.00
0FC87C	2017-07-17 13:02:00+03	45100.00
0FC8A8	2017-08-06 20:20:00+03	186900.00
0FC8E0	2017-08-06 03:54:00+03	70100.00
0FC8F8	2017-08-10 02:04:00+03	8200.00
0FC96C	2017-06-26 15:52:00+03	36200.00
0FC9B3	2017-07-27 22:45:00+03	67800.00
0FCA9B	2017-06-29 20:04:00+03	156300.00
0FCAE3	2017-07-17 09:35:00+03	75600.00
0FCAEF	2017-08-10 09:18:00+03	67400.00
0FCB05	2017-08-01 18:39:00+03	147700.00
0FCBC3	2017-07-29 11:43:00+03	48100.00
0FCC6C	2017-08-14 07:59:00+03	66600.00
0FCC72	2017-08-14 09:22:00+03	105600.00
0FCC80	2017-07-07 20:07:00+03	24200.00
0FCD32	2017-07-16 18:38:00+03	113300.00
0FCD33	2017-08-08 19:35:00+03	149600.00
0FCD37	2017-07-17 02:12:00+03	85700.00
0FCD93	2017-07-09 20:27:00+03	160300.00
0FCD95	2017-07-24 13:15:00+03	27400.00
0FCDE8	2017-07-17 01:01:00+03	50800.00
0FCE20	2017-07-07 22:04:00+03	25400.00
0FCE21	2017-07-12 13:24:00+03	135200.00
0FCE8C	2017-08-13 15:49:00+03	139200.00
0FCF3E	2017-08-06 18:16:00+03	116400.00
0FCF47	2017-07-21 18:49:00+03	66600.00
0FD02A	2017-07-28 01:41:00+03	45200.00
0FD061	2017-07-14 22:16:00+03	16000.00
0FD070	2017-07-27 07:49:00+03	40800.00
0FD0CB	2017-07-04 16:39:00+03	399600.00
0FD0D2	2017-07-16 19:24:00+03	226200.00
0FD114	2017-07-11 18:23:00+03	114400.00
0FD148	2017-07-06 00:36:00+03	223200.00
0FD1EA	2017-07-05 13:01:00+03	63000.00
0FD2BE	2017-07-07 03:16:00+03	105600.00
0FD301	2017-07-09 17:57:00+03	45200.00
0FD317	2017-08-10 03:45:00+03	229500.00
0FD32F	2017-08-08 08:00:00+03	54500.00
0FD330	2017-08-15 13:47:00+03	124600.00
0FD388	2017-07-22 05:33:00+03	273400.00
0FD394	2017-07-08 09:22:00+03	92800.00
0FD3C9	2017-08-10 11:07:00+03	211300.00
0FD3DB	2017-07-04 18:21:00+03	23200.00
0FD42F	2017-07-20 15:42:00+03	116000.00
0FD444	2017-07-28 14:13:00+03	73200.00
0FD491	2017-07-23 14:47:00+03	6800.00
0FD493	2017-08-11 15:07:00+03	36800.00
0FD4CE	2017-08-15 15:28:00+03	27400.00
0FD520	2017-07-01 13:20:00+03	14400.00
0FD55A	2017-08-08 10:29:00+03	25100.00
0FD55F	2017-07-19 13:53:00+03	56100.00
0FD586	2017-07-22 10:50:00+03	38600.00
0FD5D4	2017-07-20 10:41:00+03	20400.00
0FD62B	2017-08-03 04:48:00+03	61800.00
0FD66A	2017-08-12 03:20:00+03	18000.00
0FD673	2017-06-28 02:23:00+03	398400.00
0FD6C2	2017-07-12 04:22:00+03	66600.00
0FD6F1	2017-07-19 19:03:00+03	57500.00
0FD707	2017-08-01 12:13:00+03	53700.00
0FD754	2017-08-06 06:58:00+03	162700.00
0FD77A	2017-07-17 19:56:00+03	99100.00
0FD8A7	2017-08-14 09:49:00+03	51600.00
0FD8D4	2017-07-09 20:47:00+03	29400.00
0FD91B	2017-07-17 11:59:00+03	30800.00
0FD9DD	2017-07-05 19:11:00+03	26700.00
0FD9ED	2017-07-13 12:32:00+03	45900.00
0FDA16	2017-07-25 23:41:00+03	41800.00
0FDA57	2017-07-22 17:56:00+03	57600.00
0FDABC	2017-08-13 07:26:00+03	15700.00
0FDAD8	2017-07-20 00:53:00+03	21800.00
0FDB10	2017-07-07 04:12:00+03	10800.00
0FDB1D	2017-08-10 21:05:00+03	131600.00
0FDBF8	2017-07-13 13:14:00+03	15000.00
0FDC93	2017-07-17 19:46:00+03	96300.00
0FDCDA	2017-06-28 12:35:00+03	28800.00
0FDD07	2017-08-02 04:47:00+03	37900.00
0FDD6B	2017-07-20 05:15:00+03	158400.00
0FDD96	2017-08-05 02:33:00+03	56000.00
0FDDD2	2017-08-08 15:01:00+03	36800.00
0FDE35	2017-08-10 11:16:00+03	51600.00
0FDEB0	2017-07-18 15:59:00+03	45500.00
0FDEC1	2017-07-10 00:57:00+03	64500.00
0FDED3	2017-08-13 14:26:00+03	61200.00
0FDEDE	2017-08-13 16:34:00+03	23200.00
0FDF23	2017-07-06 05:21:00+03	40800.00
0FDFA1	2017-07-13 13:54:00+03	34100.00
0FDFAC	2017-06-29 11:52:00+03	66800.00
0FDFAE	2017-08-05 09:53:00+03	40000.00
0FDFE8	2017-08-04 02:33:00+03	16800.00
0FE02A	2017-07-27 23:46:00+03	92800.00
0FE03C	2017-07-21 06:45:00+03	392100.00
0FE078	2017-08-07 12:48:00+03	40000.00
0FE080	2017-07-26 23:43:00+03	266400.00
0FE0C0	2017-07-28 19:18:00+03	57600.00
0FE0FB	2017-07-29 00:34:00+03	116900.00
0FE121	2017-07-17 00:02:00+03	12600.00
0FE154	2017-08-02 15:20:00+03	55800.00
0FE1F6	2017-07-27 04:22:00+03	56100.00
0FE22D	2017-08-12 15:12:00+03	155600.00
0FE25B	2017-08-15 02:05:00+03	65900.00
0FE264	2017-07-19 17:48:00+03	15400.00
0FE265	2017-07-11 17:13:00+03	387400.00
0FE286	2017-07-22 21:07:00+03	24400.00
0FE28E	2017-07-08 22:38:00+03	27200.00
0FE2A2	2017-07-06 22:56:00+03	36200.00
0FE2BC	2017-07-23 10:48:00+03	66600.00
0FE2F9	2017-08-06 08:51:00+03	32800.00
0FE332	2017-08-05 07:46:00+03	7400.00
0FE41A	2017-07-15 03:48:00+03	78100.00
0FE41E	2017-07-16 15:26:00+03	86600.00
0FE42A	2017-07-13 07:29:00+03	78000.00
0FE430	2017-07-22 17:52:00+03	46300.00
0FE446	2017-08-11 06:51:00+03	38600.00
0FE448	2017-07-02 18:40:00+03	54200.00
0FE44E	2017-07-08 01:56:00+03	61500.00
0FE47A	2017-08-01 03:05:00+03	58600.00
0FE493	2017-07-02 16:31:00+03	10800.00
0FE4C3	2017-07-11 14:57:00+03	119600.00
0FE57C	2017-07-06 20:32:00+03	236000.00
0FE596	2017-06-27 11:28:00+03	21400.00
0FE5CB	2017-08-03 15:17:00+03	77900.00
0FE66C	2017-07-26 09:28:00+03	66600.00
0FE692	2017-07-11 07:10:00+03	92000.00
0FE6EE	2017-07-15 23:33:00+03	28800.00
0FE710	2017-08-05 19:52:00+03	31600.00
0FE728	2017-07-23 13:12:00+03	111600.00
0FE72C	2017-08-03 11:36:00+03	103100.00
0FE75D	2017-07-07 05:48:00+03	78300.00
0FE771	2017-07-25 05:55:00+03	80000.00
0FE775	2017-08-14 20:01:00+03	48800.00
0FE7F7	2017-07-03 08:21:00+03	185400.00
0FE840	2017-08-02 23:29:00+03	25600.00
0FE854	2017-08-12 03:50:00+03	58800.00
0FE874	2017-08-04 04:37:00+03	290500.00
0FE88E	2017-07-23 06:10:00+03	58600.00
0FE8CE	2017-08-12 01:31:00+03	51800.00
0FE8FA	2017-07-04 11:33:00+03	25400.00
0FE8FE	2017-08-01 14:09:00+03	27900.00
0FE958	2017-08-03 00:29:00+03	124000.00
0FE968	2017-08-15 07:16:00+03	64300.00
0FE9FD	2017-08-11 09:27:00+03	283100.00
0FEA3F	2017-08-09 14:48:00+03	204000.00
0FEAB7	2017-07-31 14:37:00+03	83200.00
0FEAB8	2017-08-01 22:58:00+03	35600.00
0FEAE5	2017-07-09 23:38:00+03	13400.00
0FEB25	2017-08-12 05:06:00+03	22000.00
0FEB8E	2017-07-04 04:28:00+03	47500.00
0FEBC1	2017-07-01 15:10:00+03	133200.00
0FEC05	2017-07-15 03:39:00+03	81600.00
0FEC14	2017-07-03 06:30:00+03	85000.00
0FEC41	2017-07-20 14:32:00+03	153200.00
0FEC99	2017-08-11 19:41:00+03	190200.00
0FECB9	2017-07-25 10:40:00+03	20500.00
0FECCB	2017-08-11 01:40:00+03	32700.00
0FED0F	2017-07-10 12:42:00+03	14400.00
0FED49	2017-07-25 10:19:00+03	199700.00
0FED8F	2017-07-15 10:56:00+03	66600.00
0FEDC1	2017-07-15 18:45:00+03	57500.00
0FEDE1	2017-08-14 22:22:00+03	26800.00
0FEE0D	2017-07-15 05:14:00+03	34400.00
0FEE52	2017-07-16 16:45:00+03	133200.00
0FEE76	2017-07-05 18:13:00+03	23900.00
0FEE83	2017-08-02 20:48:00+03	102800.00
0FEEB6	2017-07-18 05:14:00+03	136500.00
0FEEDA	2017-07-06 09:41:00+03	23900.00
0FEEF1	2017-08-12 18:12:00+03	17200.00
0FEEF5	2017-07-09 11:54:00+03	92700.00
0FEF3C	2017-07-20 22:34:00+03	57700.00
0FEFB6	2017-07-31 15:56:00+03	86200.00
0FEFB9	2017-07-03 02:27:00+03	119700.00
0FEFF3	2017-07-15 15:26:00+03	21800.00
0FEFF6	2017-07-21 16:18:00+03	40000.00
0FF006	2017-08-13 01:04:00+03	48100.00
0FF06C	2017-07-06 20:21:00+03	50600.00
0FF126	2017-07-20 01:11:00+03	36200.00
0FF171	2017-07-13 09:55:00+03	28800.00
0FF1AC	2017-08-05 20:35:00+03	70800.00
0FF1BB	2017-07-10 22:39:00+03	23600.00
0FF22B	2017-07-25 23:46:00+03	20400.00
0FF23C	2017-07-21 01:00:00+03	30800.00
0FF26E	2017-07-24 15:14:00+03	35700.00
0FF288	2017-07-04 01:09:00+03	46400.00
0FF2A7	2017-08-11 03:25:00+03	184100.00
0FF2DE	2017-07-31 16:06:00+03	12600.00
0FF2EB	2017-07-31 09:23:00+03	56000.00
0FF36D	2017-07-07 17:16:00+03	47000.00
0FF37C	2017-08-04 17:34:00+03	23200.00
0FF37F	2017-07-19 00:38:00+03	60300.00
0FF399	2017-08-09 18:16:00+03	23600.00
0FF3C7	2017-07-10 18:32:00+03	22400.00
0FF404	2017-07-24 09:30:00+03	117000.00
0FF41A	2017-08-13 17:23:00+03	14700.00
0FF45D	2017-08-14 18:32:00+03	42400.00
0FF467	2017-07-14 04:35:00+03	204800.00
0FF4CC	2017-07-29 13:21:00+03	15400.00
0FF533	2017-07-16 06:49:00+03	168000.00
0FF58B	2017-07-11 07:58:00+03	103500.00
0FF5A9	2017-07-25 09:29:00+03	120400.00
0FF5F8	2017-07-07 10:17:00+03	23200.00
0FF617	2017-07-17 15:50:00+03	243600.00
0FF6C3	2017-08-10 10:59:00+03	76600.00
0FF769	2017-07-09 22:13:00+03	112000.00
0FF780	2017-08-09 12:50:00+03	20600.00
0FF7B4	2017-07-11 05:04:00+03	125200.00
0FF7BC	2017-08-02 08:27:00+03	80900.00
0FF7F3	2017-07-30 17:02:00+03	78200.00
0FF823	2017-07-29 13:01:00+03	85000.00
0FF838	2017-07-04 18:19:00+03	24400.00
0FF83C	2017-07-26 03:47:00+03	56100.00
0FF84B	2017-08-15 09:37:00+03	29800.00
0FF86A	2017-08-11 04:31:00+03	55600.00
0FF8C2	2017-07-07 19:32:00+03	49100.00
0FF8E7	2017-07-19 04:08:00+03	18600.00
0FF91C	2017-08-09 18:15:00+03	20000.00
0FF96C	2017-07-22 15:13:00+03	32800.00
0FF9D2	2017-07-13 17:01:00+03	7400.00
0FFA7F	2017-07-15 09:42:00+03	15700.00
0FFAA1	2017-08-11 10:13:00+03	90400.00
0FFAAB	2017-08-02 01:53:00+03	73500.00
0FFAD4	2017-07-11 05:33:00+03	26700.00
0FFB47	2017-07-14 13:31:00+03	271200.00
0FFB81	2017-08-12 16:04:00+03	43600.00
0FFBA1	2017-08-12 21:06:00+03	37800.00
0FFBBE	2017-07-29 04:11:00+03	44000.00
0FFBF1	2017-08-02 17:59:00+03	81600.00
0FFC47	2017-07-27 22:48:00+03	32700.00
0FFC4D	2017-08-03 23:02:00+03	44000.00
0FFC61	2017-07-25 06:34:00+03	6900.00
0FFC6C	2017-07-08 17:17:00+03	50200.00
0FFCA1	2017-07-18 16:59:00+03	109600.00
0FFD2A	2017-08-09 05:16:00+03	67800.00
0FFD3A	2017-07-11 01:07:00+03	123000.00
0FFD3E	2017-08-13 01:54:00+03	29200.00
0FFD47	2017-08-03 06:08:00+03	199200.00
0FFDAC	2017-07-23 06:35:00+03	24700.00
0FFE25	2017-07-26 05:32:00+03	32800.00
0FFE36	2017-08-08 10:01:00+03	106400.00
0FFE3D	2017-07-12 07:39:00+03	30200.00
0FFE52	2017-07-08 01:55:00+03	30200.00
0FFF0A	2017-08-10 19:50:00+03	17600.00
0FFF1C	2017-07-28 15:00:00+03	13000.00
0FFF34	2017-08-02 23:10:00+03	81700.00
0FFF8B	2017-08-06 10:25:00+03	55800.00
0FFFB6	2017-08-01 06:51:00+03	20200.00
0FFFD9	2017-07-12 00:54:00+03	24200.00
0FFFDF	2017-08-09 02:18:00+03	44000.00
0FFFE9	2017-08-05 06:35:00+03	14000.00
0FFFFE	2017-07-06 05:02:00+03	135000.00
10000F	2017-07-03 04:47:00+03	139500.00
100030	2017-07-15 15:54:00+03	296400.00
100044	2017-07-22 09:14:00+03	67700.00
100078	2017-07-04 01:36:00+03	28800.00
100092	2017-07-09 06:57:00+03	61800.00
1000BB	2017-07-27 13:59:00+03	25400.00
1000DB	2017-07-13 20:59:00+03	9200.00
1000F7	2017-07-29 19:40:00+03	66600.00
10014E	2017-08-04 23:52:00+03	71200.00
10018C	2017-08-08 11:47:00+03	39500.00
1001A3	2017-07-23 10:29:00+03	57600.00
1001DA	2017-08-15 10:13:00+03	31600.00
100206	2017-07-01 16:36:00+03	61800.00
100247	2017-08-02 03:36:00+03	6800.00
1002AC	2017-07-29 22:49:00+03	6000.00
10032B	2017-07-27 01:52:00+03	89600.00
100333	2017-08-06 01:15:00+03	19600.00
100340	2017-08-14 06:33:00+03	55800.00
10034E	2017-07-12 13:29:00+03	28800.00
10034F	2017-07-17 14:27:00+03	63200.00
10036D	2017-08-13 08:09:00+03	65600.00
1003D5	2017-08-12 18:27:00+03	8000.00
1004F1	2017-06-30 14:24:00+03	94000.00
100504	2017-08-09 14:23:00+03	88100.00
100548	2017-07-13 03:02:00+03	181600.00
10054C	2017-07-30 22:56:00+03	73200.00
100580	2017-07-23 20:49:00+03	12400.00
100597	2017-07-14 03:47:00+03	68800.00
10059E	2017-07-04 23:15:00+03	84100.00
1005D2	2017-08-14 03:35:00+03	53100.00
100607	2017-07-05 22:13:00+03	27200.00
10065A	2017-08-05 08:58:00+03	75800.00
10066B	2017-07-08 07:39:00+03	51900.00
1006DC	2017-07-16 07:35:00+03	92000.00
1006E4	2017-08-12 14:40:00+03	36200.00
1006F0	2017-08-15 08:53:00+03	35300.00
1006F5	2017-07-28 08:26:00+03	312700.00
1006F8	2017-08-09 06:51:00+03	122800.00
10078B	2017-08-05 16:55:00+03	28000.00
10079A	2017-08-11 09:41:00+03	239200.00
10079F	2017-07-12 08:56:00+03	100500.00
1007B3	2017-08-10 02:37:00+03	40800.00
1007CF	2017-07-13 08:13:00+03	38800.00
100855	2017-08-10 07:06:00+03	13400.00
100871	2017-07-21 00:27:00+03	64700.00
1008A0	2017-07-22 10:17:00+03	52000.00
1008C8	2017-07-19 06:48:00+03	140100.00
1008DD	2017-08-02 11:32:00+03	68000.00
1008EA	2017-08-15 10:53:00+03	39800.00
1008F1	2017-07-22 16:38:00+03	59000.00
100984	2017-07-07 06:48:00+03	111700.00
1009D2	2017-07-31 19:34:00+03	62600.00
100A0B	2017-07-17 08:53:00+03	290500.00
100A16	2017-08-07 14:54:00+03	104900.00
100A2D	2017-07-18 11:05:00+03	136800.00
100A3D	2017-08-04 00:49:00+03	277900.00
100A44	2017-08-06 21:28:00+03	81300.00
100A61	2017-07-07 13:15:00+03	24300.00
100A6E	2017-08-07 05:38:00+03	56000.00
100ABB	2017-07-25 20:50:00+03	46000.00
100B1C	2017-06-30 14:10:00+03	26000.00
100B26	2017-08-01 14:45:00+03	234700.00
100B41	2017-07-21 05:31:00+03	33400.00
100B56	2017-07-27 20:22:00+03	66600.00
100B7F	2017-07-05 12:42:00+03	86400.00
100BEA	2017-07-19 22:56:00+03	29200.00
100BEE	2017-07-23 10:52:00+03	84100.00
100BF0	2017-07-08 04:20:00+03	31600.00
100C21	2017-07-05 08:07:00+03	28800.00
100C48	2017-07-24 05:49:00+03	89200.00
100C4F	2017-07-20 23:03:00+03	14400.00
100CB3	2017-08-08 11:19:00+03	46200.00
100CE4	2017-07-21 01:56:00+03	86600.00
100CEA	2017-07-27 01:59:00+03	126800.00
100D3E	2017-07-06 14:36:00+03	10800.00
100D45	2017-07-10 17:24:00+03	173200.00
100D93	2017-08-12 06:57:00+03	139100.00
100E28	2017-07-10 01:53:00+03	24400.00
100EFE	2017-08-06 10:55:00+03	87000.00
100F9C	2017-08-01 16:43:00+03	49100.00
100FBD	2017-08-07 04:31:00+03	81600.00
10102D	2017-08-07 18:07:00+03	15900.00
101045	2017-08-03 04:51:00+03	40600.00
10106C	2017-07-20 09:21:00+03	12000.00
10107F	2017-08-04 08:41:00+03	187600.00
101170	2017-06-29 07:28:00+03	123000.00
1011FF	2017-07-04 22:31:00+03	27200.00
10126B	2017-07-08 10:51:00+03	77900.00
10127A	2017-07-22 03:14:00+03	37700.00
1012CF	2017-07-18 08:48:00+03	34000.00
1012F2	2017-07-10 04:34:00+03	8200.00
101314	2017-07-01 12:34:00+03	92800.00
10132A	2017-07-19 11:47:00+03	118000.00
1013AA	2017-08-05 16:28:00+03	63200.00
10145F	2017-07-06 19:55:00+03	46200.00
10146C	2017-08-06 09:19:00+03	24700.00
1014AB	2017-08-12 00:53:00+03	92800.00
1014C9	2017-07-06 16:42:00+03	52900.00
1014E3	2017-07-05 06:34:00+03	62600.00
1014F4	2017-07-03 02:53:00+03	45600.00
101515	2017-08-06 17:25:00+03	128800.00
10154F	2017-07-27 19:20:00+03	46200.00
101567	2017-07-14 00:05:00+03	74800.00
101585	2017-07-09 14:40:00+03	65900.00
101619	2017-07-06 01:07:00+03	139200.00
10164C	2017-07-15 00:53:00+03	16400.00
1016B9	2017-07-31 01:52:00+03	20400.00
1016D5	2017-08-09 10:11:00+03	40400.00
1016F0	2017-07-01 07:23:00+03	68800.00
101718	2017-07-12 19:32:00+03	38800.00
101790	2017-07-24 05:28:00+03	32800.00
1017E4	2017-07-25 19:04:00+03	37900.00
1017F8	2017-07-23 17:18:00+03	55800.00
10184E	2017-08-04 18:10:00+03	26000.00
10186E	2017-07-29 00:00:00+03	25100.00
1018A1	2017-08-10 22:44:00+03	105600.00
1018BC	2017-07-28 12:16:00+03	23200.00
1018DE	2017-07-16 11:21:00+03	62900.00
1018EB	2017-07-05 21:01:00+03	9200.00
10191B	2017-08-07 08:16:00+03	44000.00
101968	2017-07-28 14:42:00+03	46200.00
10196A	2017-08-11 06:39:00+03	83000.00
10197D	2017-07-15 20:50:00+03	94400.00
1019A9	2017-07-07 04:45:00+03	23600.00
1019E3	2017-08-06 19:51:00+03	288600.00
1019F2	2017-08-02 17:35:00+03	36200.00
101A0D	2017-08-04 13:00:00+03	173500.00
101A4D	2017-07-13 20:07:00+03	46700.00
101A50	2017-07-22 21:23:00+03	19600.00
101A89	2017-08-10 03:27:00+03	6000.00
101AB4	2017-07-03 15:45:00+03	25000.00
101AEF	2017-08-01 17:58:00+03	61800.00
101B0D	2017-06-29 04:33:00+03	62600.00
101B68	2017-07-16 03:16:00+03	30200.00
101B6B	2017-08-11 13:15:00+03	118900.00
101BB2	2017-08-03 22:47:00+03	31200.00
101D04	2017-07-15 11:09:00+03	6000.00
101D2F	2017-07-16 19:14:00+03	167400.00
101D45	2017-07-11 15:24:00+03	87200.00
101D8C	2017-07-20 05:05:00+03	193200.00
101D9B	2017-07-26 17:30:00+03	11800.00
101DB2	2017-08-07 15:39:00+03	23200.00
101DB7	2017-07-04 08:55:00+03	65600.00
101DCC	2017-07-20 14:29:00+03	58900.00
101E26	2017-08-06 22:41:00+03	43200.00
101E64	2017-07-01 22:33:00+03	149000.00
101EF9	2017-08-12 16:16:00+03	35900.00
101F05	2017-07-27 01:52:00+03	55600.00
101F19	2017-07-21 20:29:00+03	265600.00
101F30	2017-07-22 15:07:00+03	102100.00
101F4C	2017-07-13 16:48:00+03	378700.00
101FAA	2017-07-19 17:49:00+03	20600.00
101FAF	2017-07-23 21:53:00+03	132800.00
102018	2017-07-24 12:02:00+03	410200.00
10201B	2017-08-13 17:02:00+03	133200.00
10201F	2017-07-09 16:09:00+03	115700.00
102025	2017-07-07 22:43:00+03	257100.00
10203D	2017-08-05 19:33:00+03	46000.00
1020B9	2017-07-18 21:08:00+03	20600.00
102118	2017-08-06 01:56:00+03	132800.00
102178	2017-08-12 01:39:00+03	27200.00
1021B5	2017-08-07 13:23:00+03	12600.00
1021D2	2017-07-30 02:01:00+03	111600.00
1021F8	2017-07-30 13:56:00+03	46300.00
10221E	2017-07-25 02:19:00+03	26700.00
10222D	2017-07-31 12:01:00+03	67600.00
102233	2017-08-11 04:45:00+03	15400.00
10224F	2017-07-30 10:45:00+03	265800.00
1022AF	2017-07-18 04:56:00+03	79800.00
1022B0	2017-07-24 16:52:00+03	59200.00
102329	2017-07-14 10:37:00+03	27900.00
102397	2017-08-02 02:05:00+03	113200.00
102466	2017-07-15 14:09:00+03	55800.00
1024FF	2017-07-27 09:47:00+03	38200.00
1025BF	2017-07-13 07:17:00+03	23200.00
1025CB	2017-07-15 15:00:00+03	108200.00
1025E8	2017-07-29 00:58:00+03	246000.00
102633	2017-07-09 07:36:00+03	75300.00
10264E	2017-07-12 22:03:00+03	99200.00
10265F	2017-07-09 04:09:00+03	26000.00
10268E	2017-08-01 00:29:00+03	369000.00
10272F	2017-07-09 21:41:00+03	25400.00
102793	2017-07-29 15:16:00+03	38300.00
1027BE	2017-08-13 18:40:00+03	53600.00
1027C2	2017-07-22 07:52:00+03	43700.00
102824	2017-08-15 06:20:00+03	24000.00
10287A	2017-08-12 16:58:00+03	16400.00
1028ED	2017-08-06 04:42:00+03	45100.00
102982	2017-08-13 19:03:00+03	58400.00
1029A2	2017-08-06 18:19:00+03	76600.00
102A75	2017-08-03 23:36:00+03	12600.00
102ADB	2017-07-12 08:40:00+03	156400.00
102AF9	2017-07-21 07:20:00+03	56200.00
102B29	2017-07-02 01:28:00+03	189000.00
102BDC	2017-06-29 06:50:00+03	28800.00
102C04	2017-07-21 10:58:00+03	190400.00
102C07	2017-08-11 10:52:00+03	166000.00
102C56	2017-07-19 00:23:00+03	29600.00
102CCB	2017-07-04 16:22:00+03	40800.00
102CE6	2017-08-02 13:48:00+03	58000.00
102CF9	2017-08-06 02:54:00+03	128800.00
102D1B	2017-07-11 01:46:00+03	66600.00
102D5E	2017-07-21 13:36:00+03	14000.00
102E27	2017-08-01 14:07:00+03	81600.00
102E39	2017-07-13 07:42:00+03	170500.00
102E78	2017-07-14 15:36:00+03	10800.00
102EA0	2017-07-28 16:28:00+03	71200.00
102F2D	2017-07-13 03:30:00+03	51300.00
102FE4	2017-07-03 12:22:00+03	58800.00
103003	2017-07-31 17:57:00+03	69000.00
103013	2017-07-07 17:14:00+03	37800.00
1030AE	2017-07-26 10:57:00+03	112000.00
10315F	2017-07-22 18:37:00+03	20000.00
10318D	2017-08-07 00:47:00+03	16400.00
10319A	2017-07-15 12:32:00+03	3400.00
10319E	2017-07-04 15:29:00+03	83300.00
1031DF	2017-07-19 11:36:00+03	40300.00
1031ED	2017-07-26 09:10:00+03	44800.00
1031F1	2017-07-06 15:05:00+03	96200.00
1031F9	2017-08-10 22:18:00+03	91500.00
103201	2017-08-07 03:54:00+03	6700.00
103205	2017-08-12 18:03:00+03	14200.00
103278	2017-07-10 05:13:00+03	66100.00
1032DC	2017-08-12 00:51:00+03	24300.00
10336D	2017-07-25 22:39:00+03	20200.00
1033A9	2017-08-14 16:22:00+03	29600.00
103460	2017-08-03 06:06:00+03	39600.00
10347E	2017-07-25 20:25:00+03	45100.00
103487	2017-07-21 18:14:00+03	38700.00
1034E0	2017-08-05 16:59:00+03	97500.00
10351D	2017-07-02 22:57:00+03	40100.00
1035E2	2017-07-25 12:18:00+03	51400.00
103628	2017-08-03 05:52:00+03	29200.00
10367E	2017-08-13 07:11:00+03	170000.00
1036B6	2017-07-26 15:21:00+03	19600.00
1036E8	2017-07-11 10:09:00+03	92000.00
10374D	2017-08-10 22:05:00+03	39300.00
10385F	2017-08-05 20:14:00+03	246000.00
103891	2017-08-15 17:27:00+03	189100.00
103893	2017-06-30 12:33:00+03	40700.00
10397A	2017-08-11 05:30:00+03	15000.00
1039AF	2017-06-30 02:21:00+03	54800.00
1039DA	2017-08-09 17:37:00+03	22000.00
103A48	2017-07-23 10:55:00+03	173500.00
103AE0	2017-06-29 09:18:00+03	45100.00
103B32	2017-08-13 09:30:00+03	260300.00
103BA7	2017-08-02 11:57:00+03	17600.00
103BFD	2017-07-03 09:35:00+03	60400.00
103C5E	2017-07-19 07:46:00+03	49800.00
103CD9	2017-08-06 21:15:00+03	143100.00
103D5F	2017-07-19 07:35:00+03	65600.00
103D99	2017-08-06 20:46:00+03	67200.00
103DCC	2017-08-07 21:30:00+03	100600.00
103E0E	2017-07-29 08:08:00+03	34400.00
103E2F	2017-07-16 14:52:00+03	81300.00
103ECB	2017-07-01 01:56:00+03	22100.00
103F16	2017-07-24 16:35:00+03	25900.00
1040CB	2017-07-10 05:58:00+03	46500.00
10412B	2017-07-23 11:41:00+03	721300.00
104173	2017-08-11 18:31:00+03	72400.00
1041B6	2017-07-19 00:39:00+03	44600.00
1041D0	2017-07-26 05:15:00+03	103200.00
104205	2017-07-27 15:50:00+03	28800.00
10423B	2017-07-06 10:22:00+03	25200.00
104255	2017-07-10 03:37:00+03	88600.00
10426E	2017-07-08 14:31:00+03	12400.00
104293	2017-07-26 07:20:00+03	57700.00
104321	2017-07-18 20:13:00+03	26000.00
10432B	2017-08-14 18:15:00+03	50000.00
10437E	2017-07-05 16:25:00+03	30200.00
104397	2017-08-12 11:29:00+03	13400.00
1043A9	2017-07-26 07:06:00+03	26200.00
1043D3	2017-07-30 10:06:00+03	40800.00
104488	2017-07-10 09:19:00+03	49100.00
104492	2017-08-10 23:19:00+03	9800.00
10449E	2017-07-05 04:16:00+03	26700.00
1044C0	2017-07-09 17:51:00+03	40800.00
1044C4	2017-07-18 19:58:00+03	55800.00
1044DF	2017-07-11 13:22:00+03	95200.00
104514	2017-08-13 08:26:00+03	31900.00
104550	2017-08-13 23:43:00+03	199700.00
10457B	2017-08-13 03:42:00+03	88800.00
104586	2017-07-15 01:51:00+03	89600.00
10458F	2017-07-02 00:11:00+03	28800.00
1045E1	2017-07-03 20:28:00+03	172100.00
104622	2017-08-12 04:01:00+03	28000.00
104628	2017-08-02 09:01:00+03	38600.00
104652	2017-07-14 19:45:00+03	90000.00
104790	2017-08-05 21:21:00+03	57500.00
1048C5	2017-08-12 12:20:00+03	56600.00
104901	2017-07-11 08:59:00+03	111600.00
104956	2017-08-09 00:48:00+03	23600.00
104990	2017-07-29 04:38:00+03	27200.00
1049C9	2017-07-11 02:19:00+03	36200.00
1049F1	2017-07-28 15:41:00+03	101200.00
104A4E	2017-07-24 22:21:00+03	266400.00
104A51	2017-07-22 16:09:00+03	62600.00
104AD2	2017-07-31 15:20:00+03	112000.00
104ADA	2017-08-14 00:34:00+03	56000.00
104ADB	2017-07-28 03:53:00+03	14800.00
104AEC	2017-07-19 15:55:00+03	55800.00
104B86	2017-08-14 11:08:00+03	13400.00
104BE0	2017-07-08 09:11:00+03	55800.00
104BF6	2017-07-08 05:00:00+03	29600.00
104C0B	2017-08-03 14:26:00+03	64700.00
104C45	2017-08-15 06:19:00+03	135400.00
104CEE	2017-08-08 06:38:00+03	6800.00
104D0B	2017-07-10 00:25:00+03	56600.00
104D1D	2017-07-08 14:52:00+03	20200.00
104D4A	2017-07-08 11:28:00+03	36200.00
104D6A	2017-07-21 05:56:00+03	139300.00
104D88	2017-08-14 23:26:00+03	65900.00
104DA3	2017-08-13 06:33:00+03	369000.00
104DBC	2017-08-12 13:54:00+03	60800.00
104E3D	2017-08-05 15:56:00+03	61800.00
104E5D	2017-07-22 06:19:00+03	11600.00
104E76	2017-07-31 10:41:00+03	69500.00
104E9C	2017-07-07 04:32:00+03	114700.00
104F5F	2017-07-22 21:36:00+03	86800.00
104F71	2017-08-07 15:49:00+03	396100.00
104F7E	2017-08-12 15:05:00+03	103200.00
104F94	2017-08-08 09:19:00+03	25800.00
104FB5	2017-08-05 16:42:00+03	206200.00
105020	2017-08-02 04:31:00+03	86400.00
105072	2017-08-07 10:50:00+03	51900.00
105084	2017-07-04 23:12:00+03	85900.00
105117	2017-07-08 13:37:00+03	88600.00
10516E	2017-07-23 04:47:00+03	40000.00
1051A9	2017-07-25 19:46:00+03	38600.00
1051B4	2017-07-05 06:56:00+03	27800.00
10520A	2017-07-14 21:09:00+03	56000.00
105245	2017-08-12 16:38:00+03	135300.00
1052AA	2017-07-08 01:32:00+03	28800.00
1052FA	2017-07-22 23:35:00+03	135400.00
105318	2017-07-29 11:27:00+03	290600.00
10538F	2017-06-30 06:40:00+03	83000.00
1053B0	2017-07-07 21:44:00+03	81300.00
1053E1	2017-08-01 16:03:00+03	57300.00
1053F6	2017-07-25 20:39:00+03	103400.00
105403	2017-08-10 12:12:00+03	87700.00
105491	2017-08-11 14:32:00+03	113800.00
1054F2	2017-07-28 08:37:00+03	29600.00
105540	2017-07-30 03:05:00+03	151200.00
1055BF	2017-07-13 14:00:00+03	21500.00
1055D7	2017-08-04 01:27:00+03	29600.00
1055EC	2017-08-01 08:24:00+03	75600.00
10562E	2017-07-15 19:10:00+03	133100.00
105653	2017-07-29 11:26:00+03	133100.00
1056D5	2017-07-10 17:16:00+03	198300.00
1056F6	2017-07-10 08:54:00+03	137600.00
10573A	2017-07-23 11:29:00+03	315300.00
105758	2017-08-02 04:49:00+03	22000.00
10575C	2017-07-20 06:30:00+03	67200.00
105820	2017-07-21 23:09:00+03	131100.00
10582E	2017-08-08 11:18:00+03	23400.00
105844	2017-08-08 18:17:00+03	15000.00
10588C	2017-07-07 17:36:00+03	73300.00
105914	2017-08-15 06:16:00+03	120700.00
105943	2017-07-10 04:26:00+03	92800.00
105961	2017-08-10 05:30:00+03	72300.00
10598D	2017-08-03 22:27:00+03	60800.00
105A3D	2017-07-14 06:00:00+03	66600.00
105A6E	2017-07-04 13:49:00+03	73500.00
105A82	2017-07-24 21:16:00+03	123000.00
105A97	2017-08-13 13:12:00+03	199200.00
105B4A	2017-07-24 23:17:00+03	40000.00
105C12	2017-06-30 18:59:00+03	84500.00
105CD4	2017-07-23 19:09:00+03	78200.00
105CDC	2017-07-24 01:29:00+03	58400.00
105D72	2017-08-02 17:08:00+03	28000.00
105D82	2017-07-03 23:43:00+03	97600.00
105E61	2017-07-13 08:40:00+03	545300.00
105EC2	2017-07-04 00:47:00+03	57300.00
105F1E	2017-07-28 14:42:00+03	47200.00
105FBD	2017-08-02 18:03:00+03	83000.00
105FFA	2017-07-15 22:34:00+03	64500.00
106023	2017-07-16 07:14:00+03	64400.00
106040	2017-07-21 17:24:00+03	27000.00
1060AD	2017-08-04 00:39:00+03	36200.00
1060C2	2017-07-10 20:24:00+03	186900.00
106111	2017-08-11 12:59:00+03	81600.00
106114	2017-07-27 01:54:00+03	35700.00
106190	2017-08-02 14:44:00+03	435200.00
1061DD	2017-07-03 05:03:00+03	48500.00
106237	2017-08-13 00:28:00+03	38300.00
106284	2017-07-30 17:06:00+03	37900.00
1062A3	2017-08-15 06:21:00+03	91300.00
1062CC	2017-08-04 15:36:00+03	9800.00
1062CF	2017-07-22 09:26:00+03	60400.00
1062E5	2017-07-01 01:33:00+03	11700.00
10630A	2017-07-30 19:08:00+03	70100.00
1063D2	2017-07-14 02:11:00+03	56000.00
1063ED	2017-07-31 09:52:00+03	36200.00
1063F6	2017-07-05 00:57:00+03	113200.00
106401	2017-07-18 13:09:00+03	93300.00
106423	2017-07-27 23:14:00+03	112400.00
10642B	2017-07-26 05:30:00+03	174200.00
10645B	2017-08-01 01:59:00+03	62600.00
1064B9	2017-07-27 17:57:00+03	420600.00
1064DD	2017-06-28 18:46:00+03	85000.00
106526	2017-08-15 12:25:00+03	24400.00
10653E	2017-07-07 04:43:00+03	13600.00
106602	2017-07-21 13:48:00+03	266400.00
106614	2017-08-14 19:09:00+03	39800.00
10662A	2017-07-27 13:16:00+03	304600.00
106645	2017-07-29 10:41:00+03	59200.00
1066B7	2017-08-01 20:39:00+03	14000.00
1066D0	2017-08-07 11:53:00+03	28000.00
106736	2017-08-09 07:18:00+03	55300.00
106740	2017-08-06 21:14:00+03	36200.00
106766	2017-07-08 09:37:00+03	46800.00
106778	2017-07-25 10:57:00+03	95000.00
10679C	2017-08-12 23:41:00+03	137800.00
106861	2017-07-17 02:36:00+03	283200.00
106862	2017-06-28 20:00:00+03	167400.00
1068B5	2017-08-13 21:04:00+03	42800.00
1068E8	2017-07-06 15:31:00+03	173500.00
106978	2017-07-06 19:48:00+03	16400.00
106988	2017-08-09 01:02:00+03	25400.00
106AC3	2017-07-27 14:18:00+03	37900.00
106B4D	2017-08-05 13:24:00+03	27800.00
106B52	2017-08-09 08:41:00+03	39000.00
106B6B	2017-07-26 00:29:00+03	86800.00
106B71	2017-08-06 21:28:00+03	46400.00
106C55	2017-07-24 13:31:00+03	61800.00
106C5F	2017-07-13 05:09:00+03	14000.00
106C6A	2017-07-15 14:44:00+03	119500.00
106CB4	2017-07-01 16:05:00+03	27700.00
106CEA	2017-08-07 03:00:00+03	88700.00
106E4A	2017-07-26 22:44:00+03	37900.00
106E5E	2017-07-22 21:53:00+03	491600.00
106EF0	2017-07-08 06:58:00+03	101100.00
106F0D	2017-07-27 22:10:00+03	29400.00
106F22	2017-08-12 10:39:00+03	12000.00
106F43	2017-07-23 14:26:00+03	8200.00
106F7A	2017-07-21 06:25:00+03	48800.00
106F99	2017-07-29 14:27:00+03	136200.00
106FA9	2017-08-12 08:30:00+03	124000.00
106FB0	2017-07-15 09:56:00+03	42800.00
106FF2	2017-07-22 00:33:00+03	136200.00
10702E	2017-07-15 13:15:00+03	45100.00
107062	2017-07-07 20:31:00+03	55800.00
107164	2017-07-18 16:13:00+03	39200.00
1071D8	2017-08-08 19:27:00+03	66600.00
10727B	2017-07-23 16:14:00+03	44800.00
10730D	2017-07-17 23:44:00+03	29800.00
107313	2017-07-16 01:56:00+03	171100.00
1073BC	2017-08-02 07:08:00+03	123600.00
1073D2	2017-07-17 11:14:00+03	16800.00
107431	2017-08-03 13:54:00+03	31800.00
107449	2017-08-01 11:10:00+03	16400.00
107450	2017-06-25 17:54:00+03	66600.00
1074F8	2017-08-15 02:36:00+03	56600.00
107570	2017-07-12 04:26:00+03	52100.00
10761F	2017-07-23 03:16:00+03	19600.00
107627	2017-07-20 06:42:00+03	28800.00
10762C	2017-07-31 07:33:00+03	22000.00
10766C	2017-07-31 12:21:00+03	130100.00
1076E0	2017-07-17 06:38:00+03	56100.00
1076EC	2017-07-01 01:42:00+03	30200.00
107752	2017-08-08 08:09:00+03	13600.00
1077B6	2017-08-04 14:38:00+03	119500.00
107827	2017-07-02 10:35:00+03	28000.00
10785C	2017-07-08 23:35:00+03	40800.00
10789F	2017-08-07 18:57:00+03	62600.00
1078A3	2017-07-05 11:17:00+03	149300.00
1078AD	2017-08-15 14:05:00+03	32700.00
1078E6	2017-08-10 20:33:00+03	109600.00
107969	2017-07-14 15:58:00+03	64600.00
1079C1	2017-08-02 21:29:00+03	27900.00
107A7B	2017-08-06 10:50:00+03	61900.00
107AF2	2017-07-10 23:21:00+03	55800.00
107BC9	2017-07-13 19:14:00+03	6800.00
107BDD	2017-08-06 15:32:00+03	103500.00
107C2F	2017-07-05 12:01:00+03	369000.00
107C82	2017-07-18 11:07:00+03	91600.00
107CD1	2017-08-04 05:37:00+03	46500.00
107D1A	2017-07-15 00:56:00+03	151200.00
107D51	2017-07-19 04:04:00+03	123100.00
107D9C	2017-07-31 04:11:00+03	32400.00
107DE4	2017-07-28 00:18:00+03	108600.00
107DFB	2017-07-23 11:24:00+03	31400.00
107E4F	2017-07-04 20:11:00+03	28000.00
107E74	2017-08-03 02:43:00+03	105600.00
107E9C	2017-07-05 22:53:00+03	77200.00
107EC7	2017-07-29 13:33:00+03	98400.00
107EEC	2017-07-10 14:20:00+03	56200.00
107EF1	2017-07-28 14:01:00+03	36600.00
107EF3	2017-07-29 19:40:00+03	133100.00
10805E	2017-08-03 11:01:00+03	131100.00
10809F	2017-07-27 12:45:00+03	32200.00
1080BD	2017-08-06 06:56:00+03	49400.00
1080C4	2017-07-03 01:16:00+03	56600.00
1080E6	2017-07-03 08:21:00+03	51500.00
10810C	2017-08-04 08:25:00+03	174600.00
108122	2017-07-26 20:37:00+03	24400.00
10822C	2017-08-05 15:13:00+03	61200.00
108259	2017-07-21 18:29:00+03	96800.00
108284	2017-07-24 04:12:00+03	9800.00
108286	2017-07-07 13:11:00+03	134000.00
1082EA	2017-08-03 07:37:00+03	51600.00
108312	2017-08-05 18:57:00+03	20200.00
10833C	2017-08-10 03:31:00+03	156600.00
1083B8	2017-07-21 00:20:00+03	37900.00
1083D3	2017-08-05 00:29:00+03	15100.00
1083D8	2017-07-23 11:36:00+03	97900.00
10841E	2017-07-19 11:36:00+03	231200.00
10842B	2017-07-13 17:17:00+03	47400.00
108442	2017-07-26 11:30:00+03	135600.00
1084E3	2017-08-11 01:00:00+03	111600.00
108510	2017-07-02 02:14:00+03	46800.00
108547	2017-07-24 12:44:00+03	46000.00
1085F5	2017-07-04 19:20:00+03	6800.00
10861F	2017-07-22 23:45:00+03	43600.00
10866F	2017-07-24 01:35:00+03	92800.00
108696	2017-07-27 16:56:00+03	92100.00
108768	2017-07-06 14:57:00+03	62600.00
10879C	2017-07-06 16:57:00+03	21400.00
1087C4	2017-08-06 18:23:00+03	26000.00
108827	2017-07-12 21:26:00+03	231900.00
10886E	2017-08-08 20:37:00+03	55800.00
10889C	2017-08-02 07:06:00+03	38600.00
1088B4	2017-07-04 20:47:00+03	58000.00
10890B	2017-08-14 09:07:00+03	56000.00
108939	2017-08-14 14:12:00+03	64600.00
108968	2017-07-06 21:25:00+03	59200.00
10899A	2017-08-13 14:57:00+03	89100.00
1089C2	2017-07-21 03:42:00+03	51900.00
1089DC	2017-08-07 16:56:00+03	123000.00
108A2D	2017-08-07 19:33:00+03	35700.00
108A46	2017-07-31 15:53:00+03	171900.00
108A80	2017-06-29 21:22:00+03	57500.00
108A8F	2017-07-19 11:57:00+03	43000.00
108AA9	2017-06-30 20:02:00+03	136100.00
108B9D	2017-08-05 10:11:00+03	86400.00
108C6F	2017-07-29 22:41:00+03	136800.00
108C86	2017-07-12 06:25:00+03	42700.00
108CE1	2017-07-10 09:00:00+03	14800.00
108D2B	2017-07-23 01:10:00+03	240600.00
108D4C	2017-07-08 01:00:00+03	47100.00
108D56	2017-07-18 21:10:00+03	46400.00
108DC3	2017-07-23 02:20:00+03	13400.00
108DF4	2017-07-30 05:38:00+03	30200.00
108E00	2017-07-28 11:36:00+03	59800.00
108E29	2017-08-11 08:05:00+03	119700.00
108E52	2017-07-25 22:15:00+03	20600.00
108E93	2017-08-15 13:46:00+03	263900.00
108F10	2017-08-07 13:10:00+03	58400.00
108F1D	2017-06-30 18:57:00+03	109600.00
108F52	2017-07-26 18:59:00+03	34000.00
108F9B	2017-07-11 12:03:00+03	46500.00
108FBD	2017-08-03 05:00:00+03	27400.00
10900C	2017-07-26 15:26:00+03	84000.00
10901D	2017-08-15 01:36:00+03	28800.00
109060	2017-07-13 13:22:00+03	12400.00
109174	2017-07-12 17:40:00+03	160200.00
109193	2017-07-21 06:53:00+03	27600.00
1091B9	2017-07-13 09:57:00+03	101200.00
1091E5	2017-07-08 11:05:00+03	24400.00
109202	2017-07-06 03:59:00+03	55800.00
109214	2017-08-05 05:11:00+03	43500.00
109220	2017-06-26 18:42:00+03	26800.00
10925D	2017-07-19 20:36:00+03	68900.00
109275	2017-07-18 03:03:00+03	19600.00
10927C	2017-07-09 14:56:00+03	134600.00
109287	2017-08-06 12:25:00+03	32800.00
1092A9	2017-08-12 16:18:00+03	12400.00
1092C7	2017-07-23 07:44:00+03	234300.00
109342	2017-08-09 08:13:00+03	8200.00
1093CB	2017-07-28 22:44:00+03	47400.00
1093ED	2017-07-21 20:19:00+03	12600.00
109407	2017-08-02 03:49:00+03	119800.00
109410	2017-07-08 17:44:00+03	19600.00
109434	2017-07-21 14:53:00+03	76600.00
10947A	2017-07-05 23:40:00+03	8000.00
10947D	2017-07-13 00:23:00+03	38500.00
1094C0	2017-07-04 13:29:00+03	32900.00
10953C	2017-08-05 00:45:00+03	43900.00
109594	2017-07-10 13:23:00+03	21400.00
1095C0	2017-07-25 05:36:00+03	16400.00
1095D0	2017-08-06 06:29:00+03	38600.00
109633	2017-07-16 04:38:00+03	119300.00
109635	2017-07-02 11:50:00+03	135000.00
10963B	2017-07-18 17:52:00+03	65300.00
10968F	2017-07-28 16:37:00+03	83000.00
10972E	2017-08-05 16:32:00+03	41600.00
10973B	2017-07-29 19:41:00+03	265600.00
1097CF	2017-07-13 18:23:00+03	176800.00
1097D2	2017-07-17 10:43:00+03	51300.00
1097DD	2017-07-08 23:53:00+03	52000.00
10994F	2017-08-03 15:03:00+03	45100.00
1099B6	2017-07-30 21:37:00+03	66300.00
109AAD	2017-07-13 17:15:00+03	48500.00
109ADE	2017-07-23 15:46:00+03	50600.00
109AFB	2017-08-07 14:01:00+03	35800.00
109B02	2017-07-01 19:11:00+03	881100.00
109B2F	2017-08-08 21:05:00+03	28800.00
109B30	2017-08-12 09:15:00+03	11700.00
109B42	2017-07-25 02:49:00+03	94800.00
109B5A	2017-07-02 19:14:00+03	16400.00
109B8B	2017-07-19 20:54:00+03	25100.00
109BB7	2017-08-08 12:46:00+03	35300.00
109BC0	2017-07-22 02:02:00+03	43800.00
109BC2	2017-08-13 07:34:00+03	56000.00
109BC9	2017-08-06 20:22:00+03	60700.00
109C4E	2017-06-29 14:36:00+03	57500.00
109C9D	2017-08-10 12:12:00+03	25100.00
109CA4	2017-08-13 07:13:00+03	57600.00
109CFD	2017-07-30 22:23:00+03	7200.00
109D04	2017-07-21 14:12:00+03	124200.00
109D35	2017-06-29 13:00:00+03	51200.00
109DB1	2017-08-05 16:57:00+03	273000.00
109DEA	2017-08-14 06:53:00+03	56100.00
109E48	2017-07-26 20:37:00+03	101100.00
109E93	2017-07-11 14:41:00+03	106400.00
109F16	2017-07-18 11:37:00+03	181200.00
109F64	2017-07-15 21:42:00+03	265700.00
109FE4	2017-08-06 14:00:00+03	92800.00
10A011	2017-08-10 10:27:00+03	83100.00
10A03D	2017-07-14 13:31:00+03	131600.00
10A056	2017-07-10 18:19:00+03	25400.00
10A06B	2017-07-23 04:43:00+03	32200.00
10A087	2017-07-16 18:11:00+03	79500.00
10A100	2017-08-10 21:17:00+03	99300.00
10A141	2017-07-10 01:29:00+03	14700.00
10A147	2017-08-13 06:57:00+03	23600.00
10A19A	2017-07-26 22:10:00+03	28800.00
10A1C2	2017-07-16 19:35:00+03	64500.00
10A1CB	2017-08-15 01:28:00+03	222400.00
10A1DB	2017-08-08 02:17:00+03	24800.00
10A22D	2017-07-16 17:57:00+03	63500.00
10A232	2017-07-14 22:37:00+03	38800.00
10A346	2017-07-30 04:03:00+03	67200.00
10A3C9	2017-07-15 11:16:00+03	166000.00
10A404	2017-07-31 14:06:00+03	28000.00
10A406	2017-07-20 04:29:00+03	134200.00
10A476	2017-07-11 04:15:00+03	40800.00
10A50D	2017-08-10 17:46:00+03	109200.00
10A54C	2017-08-11 19:34:00+03	37900.00
10A5C9	2017-07-27 11:23:00+03	275700.00
10A604	2017-07-29 05:17:00+03	166100.00
10A641	2017-07-23 19:52:00+03	121100.00
10A67F	2017-07-17 13:38:00+03	56200.00
10A681	2017-08-01 02:39:00+03	123000.00
10A6AF	2017-08-13 21:18:00+03	7300.00
10A6F9	2017-07-17 15:11:00+03	70500.00
10A717	2017-07-19 08:57:00+03	37400.00
10A768	2017-07-27 08:55:00+03	125600.00
10A7A1	2017-07-25 10:03:00+03	47100.00
10A832	2017-08-01 14:47:00+03	27000.00
10A86E	2017-08-02 19:09:00+03	131400.00
10A8CA	2017-07-08 21:03:00+03	39200.00
10A8E9	2017-07-04 14:35:00+03	14000.00
10A8FB	2017-07-14 14:13:00+03	111600.00
10A924	2017-08-02 01:43:00+03	76800.00
10A939	2017-07-01 13:48:00+03	246000.00
10A958	2017-08-15 06:52:00+03	31200.00
10A98E	2017-07-04 13:26:00+03	10700.00
10A9F5	2017-07-31 00:40:00+03	28000.00
10AA0E	2017-07-03 23:24:00+03	113800.00
10AA29	2017-07-09 11:36:00+03	147700.00
10AA8C	2017-08-08 20:00:00+03	55600.00
10AAB6	2017-08-10 19:50:00+03	6300.00
10AB12	2017-08-04 02:43:00+03	46000.00
10AB43	2017-07-10 20:35:00+03	10100.00
10ABE7	2017-07-11 09:43:00+03	99200.00
10ABF3	2017-07-04 07:55:00+03	21400.00
10AC05	2017-07-05 03:03:00+03	43200.00
10AC4F	2017-07-02 14:54:00+03	23200.00
10ACC6	2017-07-28 17:13:00+03	398500.00
10ACE5	2017-07-27 22:05:00+03	120800.00
10ACFE	2017-07-18 23:51:00+03	44800.00
10AD0E	2017-07-10 21:37:00+03	105000.00
10AD12	2017-07-24 00:38:00+03	270800.00
10ADBA	2017-08-10 14:39:00+03	270800.00
10AE05	2017-07-05 08:04:00+03	24600.00
10AE45	2017-06-28 08:59:00+03	23200.00
10AE80	2017-07-15 19:34:00+03	59400.00
10AE9B	2017-07-22 16:56:00+03	18800.00
10AED3	2017-08-13 02:45:00+03	133100.00
10AED6	2017-07-02 10:24:00+03	69000.00
10AEFD	2017-07-25 07:43:00+03	59800.00
10B061	2017-07-29 02:53:00+03	23400.00
10B06F	2017-07-14 05:20:00+03	97900.00
10B07F	2017-07-07 02:01:00+03	132800.00
10B091	2017-07-30 13:48:00+03	67000.00
10B1DB	2017-07-20 10:52:00+03	21000.00
10B2AF	2017-07-11 12:56:00+03	24400.00
10B2B2	2017-07-05 23:56:00+03	37900.00
10B2FA	2017-07-12 21:39:00+03	167400.00
10B327	2017-07-16 16:42:00+03	24400.00
10B340	2017-08-10 22:50:00+03	116900.00
10B3AC	2017-07-26 00:31:00+03	28000.00
10B3F2	2017-07-27 00:02:00+03	13400.00
10B4F6	2017-07-18 16:30:00+03	120800.00
10B50D	2017-07-22 18:51:00+03	46700.00
10B54C	2017-07-14 03:35:00+03	57500.00
10B56E	2017-07-28 06:07:00+03	35900.00
10B573	2017-07-11 11:34:00+03	209800.00
10B5E0	2017-07-13 21:48:00+03	14400.00
10B62C	2017-07-13 19:43:00+03	158500.00
10B6BF	2017-06-28 09:03:00+03	21200.00
10B754	2017-07-23 20:33:00+03	24600.00
10B766	2017-07-26 18:26:00+03	219900.00
10B770	2017-07-28 21:44:00+03	66000.00
10B7A4	2017-07-31 20:34:00+03	40800.00
10B84F	2017-08-03 10:11:00+03	28000.00
10B873	2017-07-16 11:53:00+03	26700.00
10B889	2017-07-30 12:53:00+03	62600.00
10B8FB	2017-07-04 01:38:00+03	76600.00
10B916	2017-07-04 06:11:00+03	92000.00
10B927	2017-08-01 18:49:00+03	133100.00
10B960	2017-08-13 11:03:00+03	29600.00
10B9F7	2017-07-20 11:38:00+03	21000.00
10BA61	2017-07-14 10:11:00+03	54500.00
10BA7F	2017-07-04 07:22:00+03	32100.00
10BA85	2017-07-04 13:46:00+03	12700.00
10BAA1	2017-07-16 14:46:00+03	258400.00
10BAF5	2017-08-15 11:03:00+03	246000.00
10BB04	2017-08-14 22:09:00+03	81600.00
10BB24	2017-08-14 18:54:00+03	18000.00
10BB83	2017-08-06 03:26:00+03	24400.00
10BB86	2017-08-07 23:34:00+03	20200.00
10BBBE	2017-07-05 18:46:00+03	164700.00
10BC74	2017-07-30 10:14:00+03	252200.00
10BCB3	2017-06-30 19:48:00+03	81600.00
10BCD8	2017-08-08 18:20:00+03	168000.00
10BCDC	2017-07-30 07:58:00+03	92600.00
10BCF6	2017-07-01 05:47:00+03	16400.00
10BD2F	2017-07-04 23:11:00+03	39500.00
10BD74	2017-08-13 07:13:00+03	171000.00
10BD87	2017-07-09 13:35:00+03	16400.00
10BD8D	2017-08-03 09:48:00+03	28800.00
10BDB9	2017-06-29 23:28:00+03	188000.00
10BE44	2017-08-02 04:17:00+03	88600.00
10BEAA	2017-08-03 12:07:00+03	23200.00
10BECD	2017-07-26 21:55:00+03	135400.00
10BF17	2017-08-03 12:02:00+03	39000.00
10BF32	2017-07-20 08:23:00+03	30900.00
10BF6F	2017-06-29 15:10:00+03	7400.00
10C007	2017-07-25 15:18:00+03	44800.00
10C079	2017-07-29 21:41:00+03	180800.00
10C0B2	2017-08-15 04:26:00+03	29100.00
10C118	2017-07-28 04:21:00+03	142400.00
10C11E	2017-08-11 22:08:00+03	13400.00
10C144	2017-08-09 10:36:00+03	92800.00
10C148	2017-07-09 05:16:00+03	28800.00
10C1B8	2017-08-09 20:35:00+03	102100.00
10C1D3	2017-07-10 16:27:00+03	61200.00
10C200	2017-07-17 05:17:00+03	92000.00
10C20A	2017-08-14 16:16:00+03	72000.00
10C240	2017-07-06 01:58:00+03	28000.00
10C289	2017-08-01 16:04:00+03	13400.00
10C2CB	2017-06-27 14:30:00+03	31000.00
10C38B	2017-07-02 08:41:00+03	133200.00
10C3B3	2017-07-27 20:08:00+03	37200.00
10C3C7	2017-08-03 03:14:00+03	74400.00
10C3E0	2017-07-01 00:54:00+03	23200.00
10C3E4	2017-07-02 19:54:00+03	50600.00
10C418	2017-07-26 11:46:00+03	13400.00
10C420	2017-08-13 18:04:00+03	16000.00
10C479	2017-07-16 11:45:00+03	13700.00
10C47B	2017-07-05 19:16:00+03	81700.00
10C488	2017-07-15 22:15:00+03	167400.00
10C4AB	2017-07-01 17:08:00+03	23600.00
10C4BD	2017-07-19 02:17:00+03	48800.00
10C528	2017-07-11 01:21:00+03	60400.00
10C575	2017-07-17 00:58:00+03	23600.00
10C5D9	2017-06-29 02:02:00+03	23600.00
10C617	2017-08-01 04:48:00+03	58800.00
10C6BF	2017-07-17 06:32:00+03	61600.00
10C789	2017-08-11 20:44:00+03	46800.00
10C78D	2017-08-12 08:22:00+03	41200.00
10C7E7	2017-07-22 07:21:00+03	25100.00
10C856	2017-07-15 15:29:00+03	39300.00
10C869	2017-08-10 18:48:00+03	53100.00
10C8B1	2017-07-08 20:52:00+03	67700.00
10C8D6	2017-07-19 17:15:00+03	190700.00
10C928	2017-08-07 15:40:00+03	30000.00
10C9A3	2017-07-21 09:28:00+03	27200.00
10C9B7	2017-07-14 12:10:00+03	38800.00
10C9C1	2017-07-30 21:36:00+03	31400.00
10C9DF	2017-07-11 05:11:00+03	66400.00
10CA0C	2017-07-09 12:00:00+03	88600.00
10CA7A	2017-08-04 19:46:00+03	69100.00
10CAA7	2017-08-05 07:02:00+03	28000.00
10CAC3	2017-07-22 22:50:00+03	38200.00
10CAC4	2017-07-09 20:38:00+03	10800.00
10CB2C	2017-07-22 15:42:00+03	67100.00
10CB39	2017-08-11 22:22:00+03	19600.00
10CB47	2017-08-09 01:29:00+03	151200.00
10CBB4	2017-06-30 09:58:00+03	85700.00
10CBC7	2017-08-06 04:37:00+03	42800.00
10CC0F	2017-07-07 07:11:00+03	30900.00
10CCA1	2017-07-22 16:36:00+03	122300.00
10CCBC	2017-07-18 23:47:00+03	39200.00
10CCE3	2017-08-06 03:48:00+03	23400.00
10CD0F	2017-07-28 05:38:00+03	56600.00
10CD2A	2017-08-02 20:25:00+03	26800.00
10CD41	2017-07-16 01:34:00+03	137600.00
10CDCE	2017-07-08 13:20:00+03	173600.00
10CE6B	2017-07-24 19:21:00+03	190200.00
10CE6F	2017-07-09 16:02:00+03	27600.00
10CEB7	2017-07-07 23:55:00+03	143100.00
10CF09	2017-07-18 01:07:00+03	34000.00
10CF12	2017-08-11 22:27:00+03	40800.00
10CF18	2017-07-21 23:10:00+03	19100.00
10CF3F	2017-07-19 02:57:00+03	187900.00
10CF54	2017-07-22 16:50:00+03	6900.00
10CF96	2017-08-06 09:14:00+03	25400.00
10D029	2017-07-05 21:05:00+03	176400.00
10D034	2017-06-26 12:24:00+03	76300.00
10D095	2017-07-24 01:33:00+03	38600.00
10D116	2017-07-05 23:45:00+03	132800.00
10D119	2017-07-12 15:10:00+03	246000.00
10D13F	2017-07-24 07:06:00+03	21400.00
10D154	2017-08-09 22:31:00+03	84000.00
10D168	2017-07-22 07:18:00+03	7400.00
10D19E	2017-07-23 11:14:00+03	13600.00
10D1BC	2017-07-31 22:17:00+03	71900.00
10D1D7	2017-08-11 12:30:00+03	56100.00
10D20B	2017-08-08 01:40:00+03	21400.00
10D221	2017-08-13 14:37:00+03	223200.00
10D229	2017-07-21 11:00:00+03	100600.00
10D2DD	2017-07-29 04:29:00+03	46000.00
10D306	2017-08-05 06:01:00+03	55800.00
10D317	2017-08-07 20:29:00+03	100700.00
10D373	2017-07-02 11:29:00+03	100600.00
10D3C6	2017-07-01 16:35:00+03	72400.00
10D3C8	2017-08-08 15:53:00+03	89600.00
10D41F	2017-07-17 00:16:00+03	23100.00
10D452	2017-07-12 05:44:00+03	62600.00
10D473	2017-07-25 02:24:00+03	136200.00
10D4FC	2017-07-04 22:56:00+03	43200.00
10D528	2017-08-15 15:35:00+03	161000.00
10D529	2017-07-29 23:17:00+03	72300.00
10D538	2017-07-02 09:37:00+03	56000.00
10D54F	2017-08-12 23:37:00+03	42800.00
10D5A7	2017-08-03 12:19:00+03	226200.00
10D63F	2017-07-14 02:47:00+03	31600.00
10D655	2017-08-14 02:52:00+03	28800.00
10D68E	2017-07-25 17:12:00+03	155600.00
10D693	2017-07-21 12:48:00+03	35200.00
10D6A4	2017-07-06 06:11:00+03	21500.00
10D6AD	2017-07-20 19:13:00+03	142400.00
10D6FA	2017-08-07 19:28:00+03	263200.00
10D71D	2017-07-03 08:12:00+03	398500.00
10D79B	2017-07-16 04:44:00+03	38400.00
10D83D	2017-07-12 22:44:00+03	73200.00
10D8A0	2017-08-12 15:01:00+03	14000.00
10D8DE	2017-07-20 09:14:00+03	75300.00
10D935	2017-08-10 06:59:00+03	380700.00
10D950	2017-08-12 20:51:00+03	107200.00
10D968	2017-07-30 08:23:00+03	15000.00
10D96E	2017-08-02 18:15:00+03	28000.00
10D986	2017-07-13 08:37:00+03	39800.00
10D9D5	2017-07-12 19:27:00+03	193600.00
10D9E8	2017-07-31 06:13:00+03	266400.00
10D9EE	2017-07-14 21:48:00+03	86400.00
10DA1C	2017-07-25 22:07:00+03	276000.00
10DA63	2017-08-02 14:26:00+03	65000.00
10DA68	2017-07-11 19:33:00+03	31000.00
10DA7B	2017-07-07 11:02:00+03	198400.00
10DA95	2017-07-03 05:18:00+03	64800.00
10DB19	2017-07-24 19:38:00+03	88300.00
10DB1C	2017-08-10 05:49:00+03	177800.00
10DB70	2017-08-05 02:00:00+03	24000.00
10DBA4	2017-07-08 16:58:00+03	135400.00
10DBCD	2017-07-25 18:37:00+03	23200.00
10DC4C	2017-07-02 02:42:00+03	54000.00
10DC5D	2017-07-07 02:55:00+03	34000.00
10DC6F	2017-07-19 05:23:00+03	25200.00
10DCC7	2017-07-13 05:09:00+03	56000.00
10DCDE	2017-07-20 07:08:00+03	35200.00
10DD11	2017-07-26 15:05:00+03	66000.00
10DD30	2017-08-02 00:52:00+03	90800.00
10DDE0	2017-08-07 19:35:00+03	266400.00
10DE0B	2017-07-05 16:10:00+03	27600.00
10DE25	2017-07-04 14:46:00+03	240500.00
10DF85	2017-08-05 03:06:00+03	82900.00
10DFBC	2017-07-05 04:11:00+03	42800.00
10E025	2017-08-15 12:24:00+03	55800.00
10E032	2017-08-03 16:22:00+03	28000.00
10E042	2017-07-20 22:19:00+03	24400.00
10E052	2017-07-29 10:11:00+03	92800.00
10E0BD	2017-08-07 21:23:00+03	82700.00
10E0C6	2017-06-27 05:03:00+03	48800.00
10E0E6	2017-07-22 18:07:00+03	99200.00
10E0F1	2017-07-25 21:37:00+03	25800.00
10E110	2017-08-01 15:59:00+03	15400.00
10E272	2017-07-11 15:09:00+03	117200.00
10E2BA	2017-07-23 08:26:00+03	223200.00
10E33D	2017-07-28 05:34:00+03	496700.00
10E3C8	2017-07-13 13:05:00+03	24700.00
10E3D1	2017-07-20 08:41:00+03	36400.00
10E405	2017-07-14 14:58:00+03	55800.00
10E444	2017-08-10 15:45:00+03	35800.00
10E609	2017-07-29 20:40:00+03	23600.00
10E60F	2017-07-31 16:39:00+03	39800.00
10E674	2017-07-29 00:55:00+03	79800.00
10E686	2017-07-15 00:28:00+03	46800.00
10E6BA	2017-07-16 20:06:00+03	20400.00
10E6DD	2017-08-03 14:28:00+03	187800.00
10E722	2017-08-10 01:29:00+03	162200.00
10E741	2017-07-16 11:24:00+03	246000.00
10E74F	2017-07-21 16:13:00+03	100300.00
10E77D	2017-07-30 22:16:00+03	14400.00
10E79B	2017-08-09 09:09:00+03	136600.00
10E7C8	2017-08-02 22:17:00+03	33600.00
10E7F7	2017-07-29 08:26:00+03	43100.00
10E808	2017-07-11 23:45:00+03	136800.00
10E843	2017-07-17 00:33:00+03	172600.00
10E848	2017-08-09 21:21:00+03	24400.00
10E865	2017-07-31 10:08:00+03	28800.00
10E960	2017-07-31 02:44:00+03	43900.00
10E99B	2017-07-29 19:29:00+03	30200.00
10E99D	2017-08-11 19:36:00+03	6000.00
10E99F	2017-07-10 21:12:00+03	56000.00
10E9D2	2017-07-24 19:23:00+03	124200.00
10E9F7	2017-08-15 14:08:00+03	84500.00
10EA49	2017-08-03 15:19:00+03	65800.00
10EA6E	2017-07-09 09:17:00+03	67100.00
10EA72	2017-07-09 14:42:00+03	68100.00
10EA89	2017-08-15 15:39:00+03	385000.00
10EA8A	2017-07-27 11:10:00+03	12600.00
10EAC5	2017-07-18 15:36:00+03	85000.00
10EC98	2017-07-02 22:38:00+03	155600.00
10EC9B	2017-08-10 18:51:00+03	192400.00
10EC9F	2017-08-03 05:56:00+03	53600.00
10ECDA	2017-07-05 16:25:00+03	13400.00
10ED85	2017-08-14 09:51:00+03	64800.00
10EDA9	2017-08-01 21:44:00+03	119600.00
10EE39	2017-08-07 09:13:00+03	55100.00
10EE62	2017-07-13 08:06:00+03	60700.00
10EE73	2017-07-09 13:15:00+03	86600.00
10EE9E	2017-08-05 02:34:00+03	23400.00
10EF42	2017-08-07 17:13:00+03	67900.00
10EFB7	2017-08-13 18:10:00+03	75300.00
10F01D	2017-07-17 00:38:00+03	266400.00
10F041	2017-07-03 14:01:00+03	96800.00
10F07D	2017-08-09 13:01:00+03	12200.00
10F08C	2017-07-31 23:32:00+03	164300.00
10F113	2017-07-02 19:50:00+03	213200.00
10F12C	2017-08-07 20:10:00+03	162400.00
10F1A0	2017-08-15 00:57:00+03	46400.00
10F1CD	2017-07-31 19:15:00+03	16400.00
10F265	2017-08-14 11:51:00+03	136200.00
10F2A3	2017-08-14 21:41:00+03	59800.00
10F2E5	2017-07-17 12:49:00+03	61800.00
10F34D	2017-07-25 16:51:00+03	65900.00
10F433	2017-08-08 01:01:00+03	75600.00
10F441	2017-07-30 16:03:00+03	11600.00
10F4A8	2017-08-07 17:45:00+03	13600.00
10F4E9	2017-07-03 12:23:00+03	31200.00
10F4FE	2017-08-03 13:12:00+03	49100.00
10F51D	2017-08-15 05:44:00+03	40800.00
10F541	2017-07-21 00:17:00+03	36000.00
10F548	2017-06-30 20:42:00+03	248400.00
10F558	2017-07-13 15:10:00+03	46000.00
10F568	2017-07-16 06:13:00+03	73200.00
10F590	2017-07-01 07:26:00+03	30200.00
10F5EB	2017-07-19 10:54:00+03	32700.00
10F5F6	2017-07-25 17:05:00+03	24000.00
10F64F	2017-07-15 18:23:00+03	14000.00
10F65B	2017-08-08 16:45:00+03	28800.00
10F70C	2017-07-17 17:09:00+03	242600.00
10F771	2017-07-18 09:11:00+03	143100.00
10F779	2017-08-01 09:03:00+03	48800.00
10F791	2017-08-08 12:14:00+03	40300.00
10F7CC	2017-07-29 01:41:00+03	75300.00
10F85D	2017-07-10 23:10:00+03	42400.00
10F872	2017-08-09 22:47:00+03	134400.00
10F881	2017-07-02 22:24:00+03	28000.00
10F8E7	2017-07-17 11:42:00+03	23200.00
10F91C	2017-07-12 06:21:00+03	47000.00
10F959	2017-07-25 19:08:00+03	110300.00
10F97F	2017-07-30 15:09:00+03	138000.00
10F982	2017-07-27 19:29:00+03	94000.00
10F986	2017-07-08 03:08:00+03	21800.00
10F9F2	2017-08-02 02:08:00+03	15000.00
10FA09	2017-08-14 22:24:00+03	99200.00
10FA77	2017-07-14 14:12:00+03	37900.00
10FA7C	2017-08-10 01:26:00+03	28800.00
10FB07	2017-06-30 21:46:00+03	37900.00
10FB66	2017-07-05 02:13:00+03	43900.00
10FB78	2017-08-01 07:26:00+03	23200.00
10FB79	2017-08-15 04:15:00+03	58600.00
10FB80	2017-07-01 03:32:00+03	155700.00
10FC10	2017-07-25 23:09:00+03	17800.00
10FC20	2017-08-02 01:06:00+03	119700.00
10FC89	2017-07-12 20:37:00+03	169600.00
10FC93	2017-08-10 20:54:00+03	73300.00
10FD04	2017-08-11 12:41:00+03	134400.00
10FD10	2017-08-04 04:28:00+03	28800.00
10FD1E	2017-07-18 11:13:00+03	65200.00
10FD20	2017-07-13 23:36:00+03	95600.00
10FD66	2017-07-25 12:21:00+03	22400.00
10FDCB	2017-08-14 22:08:00+03	31800.00
10FDE7	2017-07-08 02:30:00+03	55800.00
10FE18	2017-07-09 10:01:00+03	101900.00
10FEA2	2017-07-09 00:39:00+03	52000.00
10FEAD	2017-08-01 10:53:00+03	86300.00
10FED2	2017-07-08 01:23:00+03	69500.00
10FEE0	2017-08-12 02:32:00+03	22000.00
10FEEE	2017-08-12 06:17:00+03	181100.00
10FEF1	2017-07-25 06:22:00+03	23900.00
10FF3B	2017-07-07 18:09:00+03	54800.00
10FF66	2017-07-17 17:34:00+03	117600.00
10FFBF	2017-07-30 11:45:00+03	70600.00
10FFFD	2017-07-11 01:38:00+03	81300.00
110078	2017-07-23 04:51:00+03	77000.00
11007A	2017-07-22 02:07:00+03	23200.00
1100A8	2017-07-06 22:40:00+03	148200.00
1100CE	2017-08-07 14:00:00+03	58600.00
1100F5	2017-07-08 00:45:00+03	393000.00
11017B	2017-07-03 04:14:00+03	73500.00
1101A8	2017-08-08 11:52:00+03	12600.00
1101BF	2017-07-26 03:13:00+03	65100.00
1101D7	2017-08-11 07:06:00+03	53800.00
1101EE	2017-07-02 20:23:00+03	133200.00
110312	2017-07-04 20:36:00+03	15000.00
11032E	2017-07-26 01:11:00+03	270700.00
1103DF	2017-08-12 12:41:00+03	54400.00
1103F4	2017-06-28 09:33:00+03	15400.00
110528	2017-08-08 07:34:00+03	66600.00
110551	2017-07-09 10:48:00+03	34400.00
110664	2017-07-12 15:04:00+03	134400.00
110697	2017-07-07 00:51:00+03	52900.00
110718	2017-08-14 19:08:00+03	13400.00
11077D	2017-07-28 02:30:00+03	228900.00
110796	2017-07-04 20:45:00+03	61500.00
1107E0	2017-08-01 12:03:00+03	26700.00
1107EB	2017-07-03 21:02:00+03	75800.00
110854	2017-07-23 01:47:00+03	170000.00
1108DA	2017-07-25 06:04:00+03	103900.00
110902	2017-07-23 17:01:00+03	26800.00
11091A	2017-08-14 03:25:00+03	385700.00
110966	2017-08-12 11:08:00+03	19600.00
1109FA	2017-08-01 06:57:00+03	6300.00
110A10	2017-07-06 00:23:00+03	74600.00
110A11	2017-07-02 01:11:00+03	25600.00
110A1E	2017-07-28 02:59:00+03	311900.00
110A6F	2017-08-04 09:28:00+03	37900.00
110A73	2017-07-07 05:52:00+03	119500.00
110A83	2017-07-14 19:45:00+03	34000.00
110A87	2017-08-02 06:05:00+03	40400.00
110A89	2017-07-19 05:50:00+03	21800.00
110AD0	2017-07-26 19:30:00+03	34100.00
110AF4	2017-08-03 21:21:00+03	137900.00
110B19	2017-08-01 09:06:00+03	217600.00
110B4E	2017-08-12 14:17:00+03	34000.00
110B82	2017-08-12 13:12:00+03	126300.00
110BED	2017-07-10 21:16:00+03	132600.00
110C22	2017-06-26 09:57:00+03	19600.00
110C79	2017-07-06 05:22:00+03	103500.00
110CC5	2017-07-27 06:00:00+03	60600.00
110D01	2017-08-06 03:23:00+03	24400.00
110D45	2017-07-07 12:31:00+03	52300.00
110DA5	2017-07-09 06:34:00+03	9800.00
110DBC	2017-07-13 06:00:00+03	54500.00
110DD5	2017-08-10 10:34:00+03	219300.00
110E12	2017-07-21 08:12:00+03	103900.00
110E13	2017-08-07 11:30:00+03	37100.00
110EC9	2017-07-09 00:44:00+03	157400.00
110EE2	2017-07-13 02:16:00+03	46400.00
110F46	2017-08-11 19:09:00+03	50100.00
110F77	2017-07-18 12:18:00+03	13700.00
110FA9	2017-07-09 22:47:00+03	73600.00
110FCB	2017-07-21 06:23:00+03	32400.00
11105E	2017-07-04 16:07:00+03	24400.00
1110C2	2017-08-02 12:13:00+03	13600.00
1110CF	2017-07-11 17:24:00+03	47100.00
1110D7	2017-07-13 16:55:00+03	46900.00
1110E2	2017-07-14 14:38:00+03	96300.00
1110F9	2017-08-10 05:23:00+03	19800.00
111106	2017-07-03 08:52:00+03	36200.00
11110D	2017-07-14 13:37:00+03	67600.00
1111C9	2017-07-13 08:42:00+03	137600.00
1111D9	2017-08-02 10:51:00+03	64700.00
1111E9	2017-07-12 03:57:00+03	39500.00
111222	2017-07-18 17:35:00+03	266400.00
111249	2017-06-29 00:43:00+03	49400.00
111256	2017-08-02 22:40:00+03	123000.00
111260	2017-07-12 02:26:00+03	28000.00
11126F	2017-07-22 21:29:00+03	81900.00
1112AE	2017-07-20 11:04:00+03	119500.00
111306	2017-07-26 14:48:00+03	21200.00
111321	2017-08-07 00:33:00+03	86400.00
111335	2017-07-04 19:02:00+03	41900.00
111387	2017-08-15 02:59:00+03	102200.00
1113E5	2017-07-17 06:21:00+03	73500.00
1113E9	2017-07-11 12:39:00+03	199200.00
111483	2017-07-22 09:08:00+03	62600.00
1114F2	2017-07-24 20:00:00+03	16400.00
11157A	2017-07-24 16:19:00+03	55800.00
1115C6	2017-08-09 00:51:00+03	50800.00
1115D1	2017-08-15 00:02:00+03	85200.00
1116C6	2017-07-23 01:25:00+03	54000.00
1116D8	2017-08-01 16:53:00+03	133200.00
1116DE	2017-08-15 10:15:00+03	27200.00
111741	2017-07-16 18:07:00+03	81700.00
1117F5	2017-08-14 23:17:00+03	81200.00
1117FD	2017-08-04 08:19:00+03	36200.00
111855	2017-07-30 19:30:00+03	27200.00
1118A6	2017-08-14 10:04:00+03	65900.00
1118B1	2017-08-15 01:16:00+03	23200.00
1118B3	2017-06-29 06:20:00+03	136800.00
1118C7	2017-08-08 03:11:00+03	73600.00
111910	2017-07-13 19:13:00+03	48500.00
111962	2017-07-07 18:21:00+03	155600.00
11197B	2017-06-27 20:20:00+03	65900.00
111A2F	2017-08-13 18:39:00+03	55800.00
111A5F	2017-07-04 04:50:00+03	36600.00
111A62	2017-07-16 20:16:00+03	39200.00
111A64	2017-07-04 21:56:00+03	39200.00
111A6B	2017-07-02 05:52:00+03	53300.00
111A6E	2017-07-23 01:09:00+03	30000.00
111A75	2017-07-13 21:51:00+03	82900.00
111A8D	2017-07-12 04:09:00+03	151000.00
111AA9	2017-07-15 10:17:00+03	42800.00
111AC9	2017-07-20 20:06:00+03	12000.00
111B01	2017-07-29 17:46:00+03	77900.00
111BB1	2017-07-17 00:36:00+03	9800.00
111BCF	2017-08-10 18:24:00+03	201800.00
111BDE	2017-07-19 03:40:00+03	147700.00
111C00	2017-07-23 00:03:00+03	399600.00
111C34	2017-07-14 10:28:00+03	212000.00
111C38	2017-06-30 20:15:00+03	23200.00
111C49	2017-07-21 08:04:00+03	32800.00
111C51	2017-07-03 13:03:00+03	61800.00
111CF1	2017-07-07 19:28:00+03	52900.00
111D20	2017-08-05 11:14:00+03	56000.00
111D3D	2017-07-15 13:03:00+03	109600.00
111DA2	2017-07-11 03:30:00+03	27900.00
111DBA	2017-07-04 06:29:00+03	23200.00
111E3D	2017-07-15 04:54:00+03	68800.00
111EC5	2017-07-27 00:51:00+03	45100.00
111ECB	2017-08-14 08:22:00+03	17800.00
111EE7	2017-08-06 20:53:00+03	105300.00
111EEF	2017-08-12 01:55:00+03	55800.00
111F05	2017-08-04 02:00:00+03	68900.00
111F5D	2017-07-26 08:32:00+03	115900.00
111F8E	2017-07-10 08:07:00+03	81700.00
111FF6	2017-07-26 08:42:00+03	234100.00
111FFD	2017-07-25 23:10:00+03	306200.00
112032	2017-07-08 01:53:00+03	37700.00
11207D	2017-07-25 07:50:00+03	136500.00
11207E	2017-07-16 19:40:00+03	84500.00
1120AE	2017-07-01 12:35:00+03	44000.00
11211E	2017-08-14 01:46:00+03	48300.00
11212C	2017-07-10 22:09:00+03	111000.00
112151	2017-07-13 04:09:00+03	104100.00
11215B	2017-07-06 16:06:00+03	64800.00
112175	2017-08-08 23:31:00+03	133100.00
1121A3	2017-07-30 21:56:00+03	9800.00
1121CB	2017-08-09 16:55:00+03	98400.00
1121E2	2017-07-31 10:47:00+03	56600.00
1121F5	2017-07-23 11:17:00+03	8800.00
112226	2017-07-15 11:33:00+03	62800.00
11224F	2017-08-12 15:42:00+03	38600.00
11228D	2017-08-09 08:07:00+03	118100.00
11229E	2017-07-05 09:57:00+03	28000.00
1122B5	2017-08-10 14:01:00+03	72300.00
112314	2017-08-02 10:58:00+03	74800.00
112340	2017-08-09 02:59:00+03	55800.00
1123B0	2017-08-03 12:15:00+03	24300.00
1123BD	2017-07-29 15:57:00+03	86300.00
112431	2017-07-18 09:07:00+03	70100.00
112462	2017-08-04 23:24:00+03	54800.00
112473	2017-07-30 07:04:00+03	196000.00
1124C2	2017-08-11 00:42:00+03	16400.00
1124C8	2017-08-08 19:46:00+03	66600.00
1124E8	2017-07-05 04:40:00+03	21400.00
11250D	2017-07-25 09:59:00+03	7200.00
112518	2017-08-05 03:36:00+03	68400.00
1125A3	2017-07-29 18:58:00+03	124200.00
11260B	2017-07-22 23:07:00+03	14800.00
11263E	2017-07-19 04:44:00+03	46200.00
11269E	2017-07-27 16:38:00+03	114500.00
1126A1	2017-08-11 09:50:00+03	18000.00
1126A7	2017-07-04 03:15:00+03	115600.00
1126D2	2017-07-30 04:58:00+03	39800.00
1126F2	2017-07-14 19:39:00+03	71900.00
112729	2017-07-20 20:15:00+03	28800.00
112752	2017-08-03 22:13:00+03	30200.00
112753	2017-07-08 01:19:00+03	28000.00
112755	2017-07-04 13:32:00+03	369000.00
11281F	2017-07-26 18:46:00+03	32800.00
112861	2017-08-03 22:38:00+03	29600.00
1129A4	2017-07-12 17:29:00+03	134300.00
1129EE	2017-08-05 10:37:00+03	51900.00
112A78	2017-07-04 01:36:00+03	26500.00
112AB4	2017-07-26 02:55:00+03	102100.00
112AFD	2017-08-06 07:31:00+03	40800.00
112B60	2017-06-27 06:03:00+03	46000.00
112C24	2017-07-14 03:11:00+03	115600.00
112C59	2017-08-08 23:49:00+03	14000.00
112C62	2017-08-02 13:55:00+03	36600.00
112D00	2017-07-13 17:24:00+03	81600.00
112D2B	2017-07-10 20:17:00+03	135600.00
112D57	2017-08-13 12:59:00+03	23200.00
112D6D	2017-07-11 00:52:00+03	79600.00
112DE0	2017-07-11 08:23:00+03	56000.00
112DFA	2017-07-29 23:35:00+03	68400.00
112E30	2017-08-05 19:22:00+03	78800.00
112E45	2017-07-12 02:52:00+03	56600.00
112F09	2017-07-09 08:56:00+03	386300.00
112F22	2017-07-05 02:53:00+03	260300.00
112F3D	2017-07-02 02:10:00+03	6300.00
112FCA	2017-07-04 09:36:00+03	25900.00
113023	2017-07-04 19:49:00+03	59600.00
11303B	2017-07-26 22:27:00+03	136200.00
113099	2017-07-11 02:53:00+03	45200.00
1130FE	2017-07-09 00:05:00+03	55800.00
11313B	2017-08-15 03:32:00+03	64800.00
113159	2017-07-13 08:59:00+03	40400.00
11318F	2017-07-10 19:17:00+03	86600.00
11319E	2017-08-01 19:11:00+03	12400.00
1131EF	2017-07-26 17:41:00+03	44600.00
11322B	2017-07-27 08:01:00+03	56000.00
113267	2017-06-27 01:49:00+03	55600.00
11331D	2017-08-14 18:45:00+03	123000.00
11332F	2017-07-25 14:45:00+03	76600.00
113417	2017-07-28 16:16:00+03	95000.00
113574	2017-07-31 07:03:00+03	61800.00
113583	2017-07-07 10:42:00+03	246000.00
1135A6	2017-08-06 20:49:00+03	52900.00
113837	2017-07-20 17:44:00+03	26000.00
11389E	2017-07-06 14:33:00+03	224000.00
1138DB	2017-08-14 09:11:00+03	10800.00
1138FC	2017-07-16 11:45:00+03	64800.00
11395C	2017-07-07 04:03:00+03	29600.00
113972	2017-07-07 10:12:00+03	34700.00
1139CD	2017-06-29 19:25:00+03	93900.00
1139D4	2017-07-22 08:56:00+03	98000.00
113A40	2017-07-14 21:37:00+03	26800.00
113A97	2017-07-10 09:20:00+03	11800.00
113AA2	2017-08-11 15:05:00+03	70200.00
113B91	2017-07-20 09:29:00+03	92800.00
113BBC	2017-07-22 13:35:00+03	20800.00
113BCD	2017-08-01 05:51:00+03	67800.00
113C04	2017-07-15 13:46:00+03	58000.00
113C0E	2017-08-12 14:44:00+03	22000.00
113C28	2017-08-05 07:38:00+03	37100.00
113C5B	2017-07-01 11:30:00+03	139400.00
113C82	2017-07-19 08:17:00+03	15000.00
113C8B	2017-07-26 19:14:00+03	110200.00
113C95	2017-08-09 13:42:00+03	56000.00
113CB8	2017-08-13 13:21:00+03	131600.00
113CF2	2017-08-14 06:51:00+03	29800.00
113D1D	2017-07-07 17:50:00+03	473400.00
113D67	2017-08-02 20:01:00+03	139400.00
113D98	2017-07-24 11:24:00+03	24800.00
113D99	2017-07-11 23:27:00+03	40800.00
113DCD	2017-08-03 00:03:00+03	135200.00
113E2E	2017-07-12 05:43:00+03	136600.00
113E34	2017-07-30 03:53:00+03	52000.00
113F09	2017-07-10 05:27:00+03	20000.00
113F20	2017-07-10 21:37:00+03	48800.00
113F51	2017-07-15 09:47:00+03	28700.00
11401D	2017-08-11 04:50:00+03	112000.00
11407E	2017-07-08 13:48:00+03	135200.00
1140A6	2017-07-14 06:09:00+03	25800.00
1140B6	2017-07-23 22:31:00+03	10800.00
1140E6	2017-07-13 05:46:00+03	151000.00
11417E	2017-08-02 19:57:00+03	390400.00
114186	2017-08-05 19:45:00+03	11800.00
114199	2017-07-24 14:29:00+03	77500.00
1141BD	2017-07-17 08:31:00+03	32700.00
114213	2017-07-28 16:13:00+03	40600.00
114255	2017-08-04 13:31:00+03	93900.00
11438A	2017-08-05 02:34:00+03	47400.00
1143E3	2017-06-30 20:28:00+03	174800.00
1143EC	2017-08-11 00:15:00+03	7300.00
114426	2017-08-14 05:36:00+03	36800.00
11442E	2017-07-28 21:50:00+03	39200.00
114439	2017-07-26 17:28:00+03	73200.00
11444B	2017-08-07 16:40:00+03	99300.00
1144C7	2017-07-21 21:58:00+03	60800.00
1144E4	2017-07-27 15:56:00+03	27500.00
11450F	2017-07-29 01:09:00+03	58000.00
114557	2017-07-19 17:16:00+03	34000.00
114569	2017-07-20 10:05:00+03	55800.00
1145D7	2017-08-06 12:53:00+03	58600.00
114615	2017-07-21 20:43:00+03	203000.00
11461F	2017-07-28 07:15:00+03	23400.00
11462F	2017-07-11 12:56:00+03	21800.00
11465A	2017-08-08 18:53:00+03	95700.00
114695	2017-07-15 12:20:00+03	52100.00
11472E	2017-07-06 12:31:00+03	20600.00
11473F	2017-06-28 19:18:00+03	55800.00
114812	2017-07-22 07:04:00+03	28000.00
114821	2017-08-04 15:00:00+03	38200.00
114833	2017-06-28 01:00:00+03	134400.00
114840	2017-08-13 06:48:00+03	7400.00
114898	2017-07-15 05:12:00+03	132800.00
1148D6	2017-07-16 00:55:00+03	55800.00
1148D8	2017-08-01 03:05:00+03	272300.00
114919	2017-07-20 04:26:00+03	117200.00
114977	2017-06-30 19:41:00+03	24400.00
1149D7	2017-07-14 15:35:00+03	169900.00
114A1E	2017-07-18 10:32:00+03	128800.00
114A9A	2017-06-29 12:44:00+03	48500.00
114AC8	2017-07-03 23:43:00+03	55800.00
114AD6	2017-08-12 10:23:00+03	38800.00
114AE6	2017-08-08 13:26:00+03	19600.00
114AF0	2017-07-21 20:04:00+03	133700.00
114B0A	2017-08-10 21:44:00+03	48600.00
114B1B	2017-08-04 00:49:00+03	66000.00
114B5E	2017-07-15 05:17:00+03	34000.00
114B85	2017-07-22 18:26:00+03	73300.00
114B8A	2017-07-04 14:19:00+03	21800.00
114BAA	2017-07-16 12:01:00+03	57400.00
114C01	2017-08-07 10:43:00+03	25400.00
114C16	2017-08-02 17:08:00+03	28800.00
114C2A	2017-07-07 16:45:00+03	40000.00
114C61	2017-07-13 23:44:00+03	81300.00
114C67	2017-08-04 17:33:00+03	90600.00
114CCA	2017-07-24 00:43:00+03	23400.00
114CD4	2017-08-05 19:36:00+03	133000.00
114D60	2017-07-16 19:51:00+03	22400.00
114D76	2017-07-31 21:03:00+03	26700.00
114DC6	2017-08-06 15:47:00+03	23600.00
114E24	2017-08-08 15:25:00+03	7200.00
114E38	2017-08-01 04:41:00+03	55500.00
114E4C	2017-07-20 15:55:00+03	40900.00
114E79	2017-07-16 15:01:00+03	40800.00
114E7E	2017-08-04 20:48:00+03	92400.00
114E8B	2017-07-04 07:01:00+03	75200.00
114F7F	2017-07-10 06:38:00+03	86000.00
114FB8	2017-07-24 10:21:00+03	29200.00
114FF4	2017-08-11 10:50:00+03	54400.00
1150A0	2017-07-19 18:47:00+03	39300.00
1150B0	2017-08-06 21:05:00+03	48500.00
1150F8	2017-07-05 18:03:00+03	123000.00
115142	2017-07-13 13:55:00+03	27800.00
11518F	2017-07-13 22:26:00+03	12200.00
1151D6	2017-07-08 02:12:00+03	139500.00
1151F5	2017-07-06 01:39:00+03	47200.00
115255	2017-08-02 10:31:00+03	260300.00
115261	2017-07-02 22:14:00+03	44000.00
1152A7	2017-07-19 09:37:00+03	36200.00
115372	2017-08-13 06:50:00+03	32800.00
115389	2017-08-09 08:05:00+03	6600.00
1153D8	2017-07-07 05:08:00+03	132800.00
1153EC	2017-07-18 03:26:00+03	40800.00
1154BD	2017-07-31 02:57:00+03	26000.00
11553E	2017-08-08 21:36:00+03	118600.00
11557A	2017-08-03 07:00:00+03	198600.00
11558F	2017-08-14 18:19:00+03	38600.00
115664	2017-07-11 18:33:00+03	52000.00
115691	2017-08-04 10:17:00+03	24400.00
11577F	2017-08-11 20:56:00+03	19000.00
1157F3	2017-07-03 06:04:00+03	119800.00
115825	2017-07-19 13:48:00+03	64800.00
115923	2017-07-19 06:13:00+03	31000.00
11598A	2017-07-26 11:49:00+03	30200.00
115990	2017-07-24 14:16:00+03	57500.00
1159CA	2017-07-19 15:39:00+03	96800.00
115A20	2017-07-26 12:19:00+03	28000.00
115A74	2017-07-15 11:52:00+03	62000.00
115A79	2017-07-27 16:20:00+03	135400.00
115B01	2017-06-29 16:42:00+03	62800.00
115B05	2017-08-01 00:03:00+03	55800.00
115B11	2017-07-20 06:36:00+03	202200.00
115B21	2017-07-18 22:47:00+03	200000.00
115B76	2017-08-09 10:57:00+03	166100.00
115B8F	2017-08-02 02:44:00+03	16400.00
115BB6	2017-07-23 14:53:00+03	26000.00
115BB8	2017-07-15 15:41:00+03	406800.00
115BC1	2017-08-04 08:55:00+03	109400.00
115CB0	2017-07-08 02:13:00+03	113100.00
115CDC	2017-07-25 14:48:00+03	83600.00
115CDD	2017-08-14 14:24:00+03	175700.00
115CDE	2017-07-10 06:01:00+03	131100.00
115D2E	2017-07-26 22:54:00+03	23600.00
115D5C	2017-07-12 20:01:00+03	38800.00
115D61	2017-06-28 17:48:00+03	117600.00
115DC6	2017-07-14 23:51:00+03	48800.00
115DD9	2017-08-06 14:20:00+03	64700.00
115DF9	2017-07-04 09:29:00+03	123000.00
115E11	2017-07-02 22:59:00+03	21200.00
115E96	2017-08-10 12:41:00+03	169600.00
115EA0	2017-07-24 21:31:00+03	56000.00
115EC1	2017-07-22 22:18:00+03	85400.00
115ED1	2017-07-29 22:52:00+03	97900.00
115F0D	2017-07-10 13:02:00+03	39300.00
115F0F	2017-08-09 02:12:00+03	46900.00
115F44	2017-07-20 14:01:00+03	12600.00
115FC2	2017-08-11 08:39:00+03	18600.00
115FDA	2017-07-24 21:38:00+03	232700.00
116002	2017-07-17 10:24:00+03	46900.00
11606F	2017-07-22 12:12:00+03	20500.00
116089	2017-07-15 02:07:00+03	88000.00
1160D8	2017-07-28 05:53:00+03	49200.00
116169	2017-07-11 11:07:00+03	29600.00
11619A	2017-08-05 20:45:00+03	14000.00
1161F2	2017-07-13 21:19:00+03	28000.00
116213	2017-07-14 06:36:00+03	35200.00
116234	2017-07-17 02:12:00+03	36800.00
116246	2017-07-21 12:05:00+03	120800.00
116286	2017-07-12 02:17:00+03	135400.00
1162AF	2017-08-02 14:26:00+03	131600.00
1162EC	2017-08-05 16:09:00+03	492000.00
116302	2017-07-28 09:24:00+03	110400.00
116318	2017-07-07 19:16:00+03	46000.00
116419	2017-07-17 13:01:00+03	19600.00
116477	2017-07-30 23:06:00+03	88800.00
11648C	2017-08-07 04:48:00+03	271200.00
1164A9	2017-08-13 01:17:00+03	120100.00
1164C4	2017-08-08 01:12:00+03	14400.00
1164F2	2017-08-09 08:09:00+03	55600.00
11653E	2017-07-16 04:08:00+03	28000.00
116594	2017-08-13 09:59:00+03	19600.00
1165B5	2017-07-02 23:45:00+03	70700.00
1165C5	2017-08-03 20:20:00+03	50700.00
11660E	2017-07-15 20:35:00+03	66100.00
116623	2017-08-11 06:02:00+03	69600.00
11664C	2017-07-19 21:01:00+03	36800.00
116671	2017-07-18 08:43:00+03	24000.00
116680	2017-07-13 07:10:00+03	34000.00
116686	2017-07-04 01:58:00+03	48300.00
1166CB	2017-08-05 04:44:00+03	189200.00
11672C	2017-08-10 13:46:00+03	147700.00
116733	2017-07-06 13:36:00+03	78800.00
116759	2017-07-04 17:57:00+03	18000.00
116877	2017-07-24 09:50:00+03	16400.00
11689F	2017-08-05 13:48:00+03	17800.00
1168C1	2017-07-11 16:33:00+03	58800.00
116907	2017-07-29 18:35:00+03	77200.00
1169B1	2017-07-12 20:51:00+03	14000.00
116A1E	2017-08-14 10:28:00+03	114500.00
116A50	2017-07-26 15:43:00+03	26800.00
116A59	2017-07-18 18:28:00+03	66800.00
116AB9	2017-08-03 11:39:00+03	28800.00
116AE9	2017-07-13 02:57:00+03	58000.00
116B46	2017-08-02 06:23:00+03	18600.00
116B6B	2017-08-08 18:39:00+03	15000.00
116BCD	2017-07-07 04:59:00+03	49100.00
116E65	2017-07-02 22:54:00+03	104200.00
116E77	2017-07-18 17:39:00+03	58000.00
116E90	2017-08-06 18:54:00+03	79600.00
116F2E	2017-07-30 21:18:00+03	56100.00
116F44	2017-08-07 17:24:00+03	152700.00
116F56	2017-07-08 19:58:00+03	47200.00
116F59	2017-07-27 01:20:00+03	28400.00
116FC3	2017-07-02 14:14:00+03	46400.00
117010	2017-08-05 18:16:00+03	58100.00
117023	2017-08-12 20:44:00+03	258400.00
117027	2017-07-21 06:19:00+03	276300.00
11706F	2017-07-26 19:32:00+03	30200.00
11707B	2017-07-18 04:05:00+03	91200.00
1170A9	2017-07-11 21:20:00+03	85000.00
1170C8	2017-07-08 02:17:00+03	31400.00
11715B	2017-07-21 12:53:00+03	40800.00
1171E7	2017-07-14 01:15:00+03	7200.00
117265	2017-08-13 11:55:00+03	390400.00
11726A	2017-07-14 16:45:00+03	18000.00
1172BA	2017-07-19 03:55:00+03	101100.00
1172CC	2017-07-14 19:27:00+03	24400.00
117304	2017-07-01 16:36:00+03	131100.00
117322	2017-07-23 05:04:00+03	148200.00
11737D	2017-08-06 06:42:00+03	28000.00
1173B9	2017-07-04 16:54:00+03	12200.00
1173BB	2017-07-04 23:58:00+03	23600.00
1173C0	2017-07-07 22:46:00+03	125400.00
117456	2017-08-01 02:33:00+03	59800.00
117463	2017-07-29 13:33:00+03	22000.00
11751A	2017-07-17 15:16:00+03	81800.00
117572	2017-07-06 16:45:00+03	28800.00
117578	2017-07-27 02:30:00+03	96100.00
117595	2017-08-11 06:55:00+03	47000.00
1175CF	2017-07-16 08:26:00+03	88800.00
11762D	2017-07-01 07:24:00+03	27300.00
117651	2017-08-13 23:25:00+03	23600.00
117683	2017-07-08 15:42:00+03	47000.00
1176BB	2017-07-23 09:35:00+03	86600.00
1176C5	2017-07-31 12:58:00+03	44700.00
1176C7	2017-07-01 18:04:00+03	88100.00
1176CB	2017-08-08 08:21:00+03	98400.00
117718	2017-08-05 00:18:00+03	27200.00
117727	2017-07-31 07:16:00+03	93900.00
117766	2017-08-08 16:37:00+03	46400.00
1177AC	2017-08-01 12:01:00+03	7400.00
1177C9	2017-07-14 20:54:00+03	66600.00
11782E	2017-07-17 17:53:00+03	83700.00
117875	2017-07-11 11:47:00+03	66900.00
1178FD	2017-07-08 18:26:00+03	66000.00
11792B	2017-07-28 06:45:00+03	18000.00
1179BC	2017-07-02 20:20:00+03	132800.00
1179E5	2017-08-10 06:06:00+03	59200.00
1179EE	2017-08-12 11:57:00+03	25400.00
117A0F	2017-08-10 08:52:00+03	31600.00
117B0E	2017-08-05 17:48:00+03	47600.00
117B6F	2017-07-13 15:43:00+03	77200.00
117B88	2017-08-01 02:22:00+03	189800.00
117BFF	2017-08-10 06:23:00+03	77900.00
117C9C	2017-06-30 16:25:00+03	49300.00
117CCB	2017-07-19 22:37:00+03	94900.00
117CD2	2017-08-11 13:57:00+03	64800.00
117D32	2017-07-18 05:24:00+03	131600.00
117D40	2017-07-09 16:50:00+03	6800.00
117D41	2017-07-29 13:08:00+03	12600.00
117D42	2017-07-31 18:45:00+03	113000.00
117D5C	2017-07-28 12:12:00+03	26000.00
117D81	2017-07-20 17:14:00+03	32800.00
117DB3	2017-06-28 01:19:00+03	30000.00
117DFB	2017-07-13 05:47:00+03	23600.00
117E1D	2017-07-15 21:32:00+03	133200.00
117E9A	2017-08-07 20:24:00+03	316000.00
117EB5	2017-08-15 04:46:00+03	12000.00
117EF2	2017-08-05 08:16:00+03	92800.00
117F03	2017-08-12 16:04:00+03	118700.00
117FB7	2017-08-11 22:38:00+03	32800.00
117FC8	2017-07-24 12:37:00+03	234600.00
118012	2017-07-25 09:37:00+03	51900.00
11801A	2017-08-10 15:42:00+03	112000.00
118027	2017-06-30 02:51:00+03	106800.00
118072	2017-07-11 02:24:00+03	532800.00
118076	2017-08-07 01:28:00+03	40900.00
1180C5	2017-07-04 06:54:00+03	102600.00
1180E0	2017-07-31 01:38:00+03	105200.00
1181B0	2017-07-30 10:26:00+03	70800.00
1181CB	2017-07-07 12:45:00+03	125200.00
118281	2017-08-05 20:08:00+03	78500.00
1182DB	2017-07-08 12:15:00+03	152500.00
11831F	2017-08-08 10:36:00+03	83000.00
118372	2017-08-05 13:47:00+03	26000.00
1183DF	2017-08-08 12:06:00+03	13700.00
11850B	2017-08-12 00:00:00+03	258400.00
11851E	2017-07-17 02:45:00+03	118400.00
118582	2017-08-09 18:56:00+03	87400.00
1185A4	2017-07-14 14:45:00+03	113200.00
1185B8	2017-07-31 09:31:00+03	54300.00
1185C8	2017-08-07 22:00:00+03	49600.00
118618	2017-08-12 06:57:00+03	191500.00
118630	2017-07-02 07:07:00+03	69500.00
118661	2017-08-01 03:08:00+03	30200.00
118662	2017-07-21 12:07:00+03	26800.00
11869E	2017-07-10 08:34:00+03	90400.00
118707	2017-08-03 15:22:00+03	58000.00
11872E	2017-07-07 05:12:00+03	68400.00
118751	2017-07-15 10:48:00+03	194200.00
118838	2017-08-02 02:50:00+03	12400.00
11885D	2017-07-12 20:34:00+03	85700.00
118875	2017-08-10 15:27:00+03	50000.00
1188BA	2017-07-19 14:45:00+03	32800.00
1188D1	2017-07-25 19:23:00+03	201000.00
1188DB	2017-07-22 23:48:00+03	252200.00
1189B4	2017-07-22 08:52:00+03	62600.00
1189C4	2017-07-16 12:22:00+03	27300.00
118AD1	2017-07-02 14:27:00+03	34200.00
118AD9	2017-07-04 00:16:00+03	34800.00
118B26	2017-07-18 00:35:00+03	179300.00
118B2D	2017-08-06 20:19:00+03	101200.00
118B44	2017-07-02 21:39:00+03	31000.00
118B64	2017-07-11 20:24:00+03	42400.00
118B78	2017-08-03 04:56:00+03	49200.00
118BD8	2017-08-04 20:02:00+03	124200.00
118BE5	2017-07-31 06:04:00+03	55800.00
118BFE	2017-07-05 03:24:00+03	45200.00
118C07	2017-08-09 03:57:00+03	14000.00
118C25	2017-07-14 11:28:00+03	69500.00
118C3A	2017-06-30 22:40:00+03	8600.00
118C47	2017-08-14 02:53:00+03	44600.00
118C48	2017-07-02 12:37:00+03	246000.00
118CDB	2017-07-21 21:18:00+03	39200.00
118CE0	2017-07-10 13:27:00+03	50400.00
118D06	2017-08-04 23:06:00+03	153300.00
118D38	2017-08-14 21:56:00+03	89700.00
118DA8	2017-08-12 05:37:00+03	19800.00
118DCB	2017-06-29 03:09:00+03	246000.00
118DE2	2017-07-07 09:59:00+03	66600.00
118DFE	2017-07-09 05:06:00+03	23200.00
118E0A	2017-07-24 08:03:00+03	26000.00
118E56	2017-07-04 14:04:00+03	93400.00
118EBC	2017-07-11 14:04:00+03	22400.00
118F09	2017-08-05 20:36:00+03	196800.00
118F26	2017-07-18 21:52:00+03	30000.00
118F98	2017-07-10 20:48:00+03	6800.00
118FB3	2017-08-09 22:23:00+03	93700.00
118FBB	2017-07-04 10:12:00+03	181600.00
118FE9	2017-08-07 00:05:00+03	26800.00
119065	2017-08-10 04:41:00+03	81900.00
119077	2017-07-11 00:00:00+03	73300.00
11907D	2017-08-03 09:26:00+03	129700.00
1190D5	2017-07-22 16:38:00+03	46200.00
119116	2017-07-19 22:30:00+03	23200.00
119147	2017-07-17 17:03:00+03	18000.00
1192C2	2017-08-14 11:42:00+03	23400.00
119302	2017-07-23 11:39:00+03	6700.00
11935E	2017-07-26 17:22:00+03	15400.00
11940E	2017-08-11 17:23:00+03	20500.00
11954E	2017-08-13 11:17:00+03	109900.00
119560	2017-08-10 05:08:00+03	58800.00
119562	2017-07-22 03:48:00+03	28000.00
11962F	2017-07-17 12:25:00+03	48800.00
1196A7	2017-07-24 00:52:00+03	66400.00
1196CC	2017-07-14 17:59:00+03	55800.00
1196CD	2017-08-05 10:55:00+03	41200.00
1196D5	2017-07-23 04:45:00+03	31400.00
119727	2017-07-24 18:41:00+03	17800.00
119769	2017-08-05 18:50:00+03	58600.00
119778	2017-07-30 23:39:00+03	47100.00
1197B2	2017-07-07 15:13:00+03	63500.00
1197BF	2017-08-12 12:38:00+03	82900.00
119806	2017-08-13 21:14:00+03	42400.00
11980F	2017-07-23 10:26:00+03	99200.00
11981C	2017-08-10 14:42:00+03	26000.00
1198B1	2017-07-18 14:57:00+03	24400.00
11993E	2017-08-10 01:31:00+03	80500.00
119946	2017-07-26 05:04:00+03	15900.00
119974	2017-08-12 13:44:00+03	74900.00
1199A9	2017-07-14 05:18:00+03	182300.00
1199C6	2017-07-25 03:18:00+03	71400.00
119A0D	2017-07-24 09:01:00+03	20700.00
119A4A	2017-07-10 19:59:00+03	32200.00
119AA5	2017-07-23 16:34:00+03	85000.00
119AE5	2017-08-14 06:43:00+03	48600.00
119B07	2017-07-20 03:47:00+03	111600.00
119BCA	2017-08-02 20:30:00+03	27700.00
119BD0	2017-07-12 10:44:00+03	10600.00
119BD5	2017-07-19 06:01:00+03	51500.00
119C18	2017-08-03 23:09:00+03	53700.00
119C1B	2017-07-19 19:06:00+03	135400.00
119C35	2017-07-13 17:00:00+03	32200.00
119C4B	2017-07-29 19:35:00+03	42800.00
119C53	2017-08-08 01:40:00+03	11000.00
119CE1	2017-07-20 07:17:00+03	42800.00
119CFD	2017-07-05 10:46:00+03	67200.00
119D0A	2017-07-23 03:28:00+03	92400.00
119D6F	2017-08-07 08:13:00+03	135800.00
119D70	2017-07-07 21:39:00+03	40400.00
119D72	2017-08-03 07:46:00+03	149800.00
119DBB	2017-07-28 11:39:00+03	47200.00
119E05	2017-08-14 20:17:00+03	99300.00
119E0C	2017-07-07 12:24:00+03	24400.00
119E30	2017-07-15 16:53:00+03	39400.00
119E42	2017-07-20 09:00:00+03	40100.00
119ECE	2017-07-14 05:24:00+03	167900.00
119EDE	2017-07-11 00:30:00+03	187400.00
119F09	2017-07-20 18:04:00+03	33000.00
119F26	2017-07-20 17:30:00+03	78100.00
119F71	2017-07-26 06:30:00+03	17800.00
119F88	2017-07-07 23:08:00+03	112000.00
119F8B	2017-06-30 09:27:00+03	65100.00
119FCE	2017-07-16 07:23:00+03	29600.00
11A024	2017-08-07 08:37:00+03	75800.00
11A062	2017-07-21 18:27:00+03	14800.00
11A0CC	2017-06-28 14:13:00+03	122700.00
11A0DD	2017-07-05 19:56:00+03	31200.00
11A0F3	2017-08-07 06:36:00+03	51900.00
11A0FE	2017-07-18 02:45:00+03	40800.00
11A12E	2017-07-28 11:41:00+03	89600.00
11A133	2017-07-31 11:23:00+03	46400.00
11A1B7	2017-07-15 15:12:00+03	115700.00
11A1BD	2017-07-19 17:18:00+03	155600.00
11A1F3	2017-07-08 12:29:00+03	19600.00
11A242	2017-07-29 08:06:00+03	56000.00
11A27A	2017-07-17 08:10:00+03	52000.00
11A27C	2017-07-29 16:59:00+03	16400.00
11A284	2017-08-01 15:40:00+03	31600.00
11A2A1	2017-07-21 07:52:00+03	100600.00
11A2EB	2017-07-28 19:35:00+03	78100.00
11A334	2017-07-08 12:21:00+03	43500.00
11A33D	2017-07-28 14:02:00+03	46400.00
11A35B	2017-07-20 09:33:00+03	54400.00
11A380	2017-07-20 15:07:00+03	49100.00
11A3D3	2017-07-12 09:31:00+03	56000.00
11A47C	2017-07-11 05:58:00+03	65300.00
11A489	2017-07-19 05:59:00+03	15900.00
11A4A2	2017-07-09 12:04:00+03	56000.00
11A53A	2017-07-23 20:11:00+03	113800.00
11A59E	2017-07-28 01:45:00+03	62900.00
11A60B	2017-08-03 07:13:00+03	26000.00
11A60F	2017-07-01 08:29:00+03	99300.00
11A619	2017-08-12 18:19:00+03	23200.00
11A66B	2017-07-16 06:50:00+03	101200.00
11A687	2017-07-04 02:56:00+03	17200.00
11A6A0	2017-07-02 22:52:00+03	24800.00
11A6C5	2017-07-11 15:21:00+03	46400.00
11A714	2017-07-15 06:09:00+03	104600.00
11A76A	2017-07-28 16:28:00+03	111600.00
11A76F	2017-07-30 21:44:00+03	57500.00
11A817	2017-07-17 12:24:00+03	87200.00
11A830	2017-07-29 02:52:00+03	135900.00
11A86F	2017-07-19 11:15:00+03	24000.00
11A8C3	2017-08-04 12:03:00+03	136000.00
11A91B	2017-08-13 09:50:00+03	12600.00
11A91C	2017-07-17 10:32:00+03	46200.00
11A944	2017-08-14 00:51:00+03	53600.00
11A96C	2017-08-10 20:21:00+03	35300.00
11A9BA	2017-07-25 01:15:00+03	56900.00
11A9C0	2017-07-31 12:56:00+03	25100.00
11A9D5	2017-07-06 15:57:00+03	134000.00
11A9F6	2017-07-22 19:59:00+03	89200.00
11A9FE	2017-07-19 20:42:00+03	87200.00
11AA3F	2017-07-14 13:49:00+03	36900.00
11AA65	2017-08-06 21:36:00+03	23200.00
11AA95	2017-07-29 13:50:00+03	229600.00
11AB62	2017-08-03 07:29:00+03	56000.00
11AB8B	2017-07-07 11:48:00+03	49100.00
11AB8E	2017-07-03 22:41:00+03	56000.00
11ABB3	2017-08-13 07:11:00+03	36700.00
11ABB4	2017-08-02 06:03:00+03	56000.00
11ABBD	2017-08-05 22:31:00+03	80000.00
11ABE5	2017-08-05 08:57:00+03	39600.00
11AC0B	2017-07-10 01:07:00+03	65500.00
11AC18	2017-07-12 12:25:00+03	54300.00
11AC24	2017-08-01 19:13:00+03	12400.00
11AC4B	2017-08-10 01:28:00+03	73100.00
11AC5F	2017-08-14 23:31:00+03	109800.00
11AC7B	2017-07-09 22:38:00+03	46300.00
11AD1A	2017-06-30 22:53:00+03	99200.00
11AD5A	2017-07-21 05:35:00+03	73500.00
11AD6D	2017-07-11 10:57:00+03	35200.00
11AD74	2017-07-14 03:27:00+03	73300.00
11AD82	2017-07-29 07:54:00+03	56000.00
11ADF0	2017-07-16 12:42:00+03	93000.00
11AE09	2017-07-03 12:36:00+03	38500.00
11AE33	2017-08-13 01:00:00+03	52700.00
11AE49	2017-08-15 00:44:00+03	50600.00
11AEC4	2017-07-20 07:10:00+03	6000.00
11AEE7	2017-07-11 07:27:00+03	13600.00
11AF00	2017-08-15 09:33:00+03	62000.00
11AF09	2017-08-07 10:48:00+03	66600.00
11AF72	2017-07-15 21:10:00+03	18600.00
11AF84	2017-07-09 14:49:00+03	168600.00
11AFB6	2017-07-30 00:07:00+03	22000.00
11B054	2017-07-29 20:53:00+03	134700.00
11B060	2017-08-04 20:08:00+03	28800.00
11B0D0	2017-08-02 09:30:00+03	28600.00
11B1C9	2017-07-04 19:42:00+03	85500.00
11B1F3	2017-07-17 07:42:00+03	80900.00
11B1FA	2017-07-24 06:23:00+03	54400.00
11B26B	2017-07-11 09:33:00+03	38000.00
11B2B6	2017-08-02 20:58:00+03	28800.00
11B2B8	2017-07-22 16:46:00+03	26000.00
11B345	2017-07-23 01:12:00+03	46200.00
11B4BD	2017-07-09 03:21:00+03	21400.00
11B4C5	2017-07-17 06:13:00+03	170800.00
11B4E0	2017-07-12 10:53:00+03	35800.00
11B505	2017-07-24 11:43:00+03	19600.00
11B508	2017-07-21 00:41:00+03	42800.00
11B509	2017-06-27 18:58:00+03	6700.00
11B51E	2017-07-10 09:10:00+03	96800.00
11B552	2017-07-23 11:47:00+03	92800.00
11B55E	2017-08-14 04:05:00+03	125400.00
11B5A7	2017-07-21 14:54:00+03	40100.00
11B5CD	2017-08-03 05:34:00+03	46400.00
11B60A	2017-07-07 04:48:00+03	260900.00
11B636	2017-08-03 10:39:00+03	28000.00
11B65F	2017-07-06 22:34:00+03	59600.00
11B679	2017-06-29 23:41:00+03	54500.00
11B688	2017-07-09 03:03:00+03	22000.00
11B6AE	2017-06-30 10:17:00+03	92400.00
11B705	2017-08-09 16:42:00+03	40200.00
11B73C	2017-07-07 04:16:00+03	100600.00
11B7A2	2017-08-01 21:06:00+03	6300.00
11B87D	2017-07-24 00:24:00+03	273600.00
11B88C	2017-08-09 20:53:00+03	64600.00
11B8A2	2017-07-18 23:18:00+03	46400.00
11B934	2017-08-03 10:50:00+03	6000.00
11B936	2017-07-13 01:35:00+03	100600.00
11B94A	2017-07-06 05:48:00+03	105600.00
11B97E	2017-08-07 08:23:00+03	38000.00
11B9DD	2017-08-11 20:58:00+03	68800.00
11BA32	2017-07-05 21:49:00+03	22000.00
11BA79	2017-08-05 08:39:00+03	56000.00
11BA82	2017-07-01 22:53:00+03	36400.00
11BA94	2017-08-10 21:31:00+03	65600.00
11BAE5	2017-07-23 09:31:00+03	166100.00
11BB35	2017-08-06 05:38:00+03	46500.00
11BB52	2017-08-15 08:42:00+03	199700.00
11BB58	2017-07-22 10:17:00+03	22000.00
11BB6D	2017-07-17 12:45:00+03	29400.00
11BB78	2017-07-17 02:18:00+03	28000.00
11BBC9	2017-08-01 19:10:00+03	27700.00
11BC1D	2017-08-04 10:12:00+03	23600.00
11BC51	2017-07-24 02:17:00+03	137600.00
11BCA7	2017-07-10 14:49:00+03	26800.00
11BD19	2017-08-12 18:51:00+03	54000.00
11BD62	2017-08-08 23:10:00+03	23600.00
11BDBC	2017-08-09 12:32:00+03	150400.00
11BE0D	2017-08-05 23:10:00+03	22600.00
11BE2E	2017-08-14 14:51:00+03	81900.00
11BE6F	2017-08-11 15:37:00+03	36100.00
11BFBC	2017-07-26 10:19:00+03	107800.00
11BFD2	2017-07-13 11:59:00+03	58800.00
11C021	2017-07-24 13:02:00+03	177200.00
11C029	2017-07-30 07:44:00+03	172600.00
11C057	2017-07-21 13:55:00+03	136800.00
11C073	2017-07-09 10:03:00+03	86400.00
11C154	2017-07-19 22:27:00+03	134800.00
11C1B3	2017-07-28 23:40:00+03	136200.00
11C1F8	2017-08-13 02:33:00+03	29600.00
11C215	2017-07-01 11:27:00+03	37800.00
11C24A	2017-07-07 18:10:00+03	115800.00
11C293	2017-07-19 21:34:00+03	89600.00
11C2BA	2017-07-27 04:38:00+03	68400.00
11C306	2017-07-17 18:44:00+03	54200.00
11C30C	2017-08-09 14:32:00+03	23600.00
11C351	2017-07-09 05:43:00+03	26200.00
11C389	2017-07-07 06:32:00+03	67700.00
11C3DA	2017-07-30 23:48:00+03	46400.00
11C43F	2017-07-25 05:08:00+03	89200.00
11C45F	2017-07-08 23:23:00+03	40400.00
11C490	2017-08-02 12:13:00+03	32600.00
11C4AC	2017-07-08 14:50:00+03	196900.00
11C532	2017-08-13 08:59:00+03	63500.00
11C533	2017-08-11 16:40:00+03	47100.00
11C559	2017-08-15 14:22:00+03	557400.00
11C5A7	2017-07-11 18:07:00+03	14800.00
11C619	2017-07-19 00:27:00+03	22000.00
11C645	2017-07-17 06:34:00+03	134800.00
11C6DD	2017-07-04 12:04:00+03	22000.00
11C7A7	2017-08-07 05:24:00+03	116900.00
11C7F4	2017-07-27 07:15:00+03	106400.00
11C821	2017-07-14 21:43:00+03	73500.00
11C865	2017-07-16 08:24:00+03	73600.00
11C8AA	2017-07-20 02:07:00+03	112000.00
11C8B0	2017-07-19 02:25:00+03	29400.00
11C905	2017-08-08 16:36:00+03	23200.00
11C969	2017-07-23 22:05:00+03	83600.00
11C97D	2017-07-11 21:46:00+03	109400.00
11CA41	2017-07-21 08:48:00+03	66600.00
11CB23	2017-07-06 12:08:00+03	254900.00
11CB29	2017-08-01 18:31:00+03	162200.00
11CB38	2017-07-17 08:01:00+03	68400.00
11CB39	2017-07-24 22:20:00+03	122800.00
11CB97	2017-08-09 10:29:00+03	32400.00
11CBA9	2017-07-14 22:41:00+03	26700.00
11CBC1	2017-08-03 16:46:00+03	55800.00
11CC68	2017-07-09 07:53:00+03	67600.00
11CC96	2017-08-10 19:25:00+03	105200.00
11CCEF	2017-07-06 16:53:00+03	133100.00
11CD23	2017-07-05 02:44:00+03	76600.00
11CD63	2017-08-02 03:39:00+03	123000.00
11CE11	2017-08-01 04:07:00+03	55800.00
11CE17	2017-08-03 04:08:00+03	236900.00
11CE69	2017-07-20 12:20:00+03	112000.00
11CEA2	2017-08-04 21:36:00+03	23600.00
11CEB2	2017-07-28 13:23:00+03	123600.00
11CEF6	2017-07-14 12:38:00+03	67600.00
11CF89	2017-07-10 13:06:00+03	47100.00
11CFC6	2017-08-13 23:08:00+03	46400.00
11D00F	2017-08-13 08:49:00+03	55800.00
11D024	2017-07-25 16:24:00+03	271100.00
11D02E	2017-07-07 03:24:00+03	29200.00
11D04C	2017-08-10 09:43:00+03	20000.00
11D11D	2017-07-16 07:34:00+03	44800.00
11D142	2017-07-05 11:47:00+03	13400.00
11D1B4	2017-07-07 03:37:00+03	37900.00
11D1F2	2017-07-17 03:10:00+03	56900.00
11D225	2017-07-19 11:40:00+03	60400.00
11D242	2017-06-29 19:07:00+03	55800.00
11D26E	2017-07-11 19:27:00+03	89600.00
11D288	2017-07-19 16:20:00+03	68900.00
11D298	2017-06-29 15:42:00+03	80200.00
11D29B	2017-07-06 15:18:00+03	57600.00
11D312	2017-07-31 12:17:00+03	51800.00
11D355	2017-07-05 05:24:00+03	48500.00
11D39B	2017-07-06 02:51:00+03	205000.00
11D428	2017-06-30 08:36:00+03	260900.00
11D451	2017-08-15 05:13:00+03	13400.00
11D510	2017-08-15 16:04:00+03	29800.00
11D5A6	2017-07-02 04:08:00+03	70200.00
11D5C1	2017-08-03 21:53:00+03	271100.00
11D5CE	2017-07-29 19:35:00+03	12600.00
11D5F0	2017-07-18 19:21:00+03	6800.00
11D65A	2017-08-08 11:06:00+03	64500.00
11D692	2017-07-15 18:32:00+03	23400.00
11D71E	2017-07-20 01:19:00+03	215500.00
11D76C	2017-07-24 23:45:00+03	29800.00
11D810	2017-08-10 10:44:00+03	32800.00
11D899	2017-06-29 20:06:00+03	117200.00
11D8E9	2017-08-13 01:45:00+03	35400.00
11D909	2017-08-06 13:48:00+03	47200.00
11D90F	2017-08-13 15:21:00+03	14200.00
11D91E	2017-08-03 00:38:00+03	31600.00
11D935	2017-07-15 19:30:00+03	40400.00
11D953	2017-08-06 09:15:00+03	56000.00
11D9A3	2017-08-08 12:32:00+03	48800.00
11D9C6	2017-08-07 00:15:00+03	140500.00
11DA1C	2017-07-22 20:08:00+03	137100.00
11DA73	2017-07-05 19:22:00+03	14000.00
11DA82	2017-07-01 20:54:00+03	469500.00
11DA83	2017-07-14 03:10:00+03	36800.00
11DAE1	2017-07-16 10:44:00+03	18600.00
11DB0A	2017-07-04 17:50:00+03	23400.00
11DBCD	2017-07-30 20:46:00+03	67200.00
11DC3D	2017-07-08 15:57:00+03	22200.00
11DC6A	2017-08-11 03:59:00+03	26000.00
11DC9F	2017-07-13 06:42:00+03	31600.00
11DCA0	2017-08-04 16:47:00+03	139100.00
11DCA8	2017-07-06 18:10:00+03	28800.00
11DCE6	2017-07-06 18:43:00+03	51900.00
11DCF9	2017-06-29 13:20:00+03	31700.00
11DD01	2017-07-29 23:44:00+03	113600.00
11DD3B	2017-07-13 14:20:00+03	246400.00
11DD8D	2017-07-05 20:37:00+03	99300.00
11DF14	2017-08-06 16:02:00+03	184200.00
11DF20	2017-08-07 15:54:00+03	13800.00
11DF22	2017-07-05 15:13:00+03	108500.00
11DF72	2017-07-11 11:23:00+03	67600.00
11DFE0	2017-07-13 07:21:00+03	93700.00
11DFE8	2017-08-13 09:39:00+03	56000.00
11DFF0	2017-08-01 05:06:00+03	66100.00
11E021	2017-07-31 02:26:00+03	24400.00
11E053	2017-07-31 03:10:00+03	6000.00
11E05D	2017-08-05 12:36:00+03	23200.00
11E066	2017-07-14 04:52:00+03	120400.00
11E0A3	2017-08-01 03:36:00+03	34000.00
11E0FB	2017-08-03 17:01:00+03	28800.00
11E0FD	2017-07-19 08:18:00+03	50100.00
11E113	2017-07-05 15:28:00+03	51600.00
11E11A	2017-07-03 22:39:00+03	66600.00
11E11B	2017-08-10 01:13:00+03	74900.00
11E16D	2017-07-28 12:14:00+03	24400.00
11E18E	2017-08-03 18:33:00+03	16400.00
11E1BD	2017-07-28 14:08:00+03	38800.00
11E1C6	2017-07-26 02:55:00+03	46200.00
11E1F5	2017-07-30 22:48:00+03	55800.00
11E219	2017-08-15 09:00:00+03	27600.00
11E21E	2017-07-30 21:00:00+03	39400.00
11E23B	2017-08-14 20:29:00+03	6300.00
11E276	2017-07-03 21:21:00+03	46400.00
11E284	2017-07-01 05:39:00+03	40000.00
11E2F7	2017-07-09 20:19:00+03	38600.00
11E32A	2017-07-26 07:30:00+03	39500.00
11E375	2017-08-02 02:58:00+03	14800.00
11E377	2017-08-04 01:10:00+03	27300.00
11E459	2017-07-06 15:06:00+03	56600.00
11E4BA	2017-08-02 06:38:00+03	55800.00
11E4D2	2017-07-10 22:00:00+03	48800.00
11E4F4	2017-07-09 03:32:00+03	85000.00
11E4F6	2017-07-03 09:31:00+03	55900.00
11E4F8	2017-06-26 06:08:00+03	110000.00
11E52A	2017-07-06 23:30:00+03	46000.00
11E54D	2017-07-19 16:12:00+03	6300.00
11E5DC	2017-07-29 08:53:00+03	8000.00
11E5DD	2017-07-31 07:44:00+03	9200.00
11E617	2017-08-12 07:35:00+03	533200.00
11E627	2017-08-12 06:54:00+03	28000.00
11E643	2017-07-30 12:51:00+03	71900.00
11E657	2017-07-25 18:18:00+03	135200.00
11E68F	2017-07-07 06:20:00+03	104700.00
11E69F	2017-07-20 14:40:00+03	26800.00
11E6E8	2017-08-09 23:19:00+03	76800.00
11E756	2017-08-06 19:58:00+03	42800.00
11E780	2017-07-04 05:06:00+03	7400.00
11E78A	2017-07-23 05:25:00+03	34800.00
11E7B2	2017-08-13 11:44:00+03	303300.00
11E7EE	2017-07-25 10:04:00+03	57800.00
11E84A	2017-08-11 11:00:00+03	177200.00
11E863	2017-07-04 15:04:00+03	135000.00
11E88F	2017-07-07 21:15:00+03	100400.00
11E925	2017-07-31 02:17:00+03	78900.00
11E935	2017-08-11 16:38:00+03	411600.00
11E9FE	2017-08-15 06:56:00+03	27400.00
11EABD	2017-07-14 07:32:00+03	42400.00
11EADD	2017-07-06 23:03:00+03	65600.00
11EAE2	2017-07-12 19:59:00+03	137600.00
11EB05	2017-08-07 09:08:00+03	84500.00
11EB2A	2017-07-31 22:55:00+03	113300.00
11EB8E	2017-08-05 21:49:00+03	21400.00
11EBA0	2017-07-22 17:20:00+03	62800.00
11EBBB	2017-07-20 23:20:00+03	118500.00
11EC20	2017-07-09 22:58:00+03	8000.00
11EC33	2017-08-15 03:29:00+03	109000.00
11EC38	2017-07-06 03:20:00+03	167500.00
11ECCA	2017-07-30 00:35:00+03	39600.00
11ECEF	2017-08-05 12:17:00+03	34100.00
11ED05	2017-08-10 23:28:00+03	126400.00
11ED10	2017-06-29 00:02:00+03	6300.00
11ED1A	2017-08-13 04:11:00+03	76300.00
11ED83	2017-08-13 04:56:00+03	106700.00
11EDBB	2017-07-09 22:35:00+03	40000.00
11EDBF	2017-08-03 21:57:00+03	19600.00
11EDCF	2017-07-20 06:45:00+03	37100.00
11EDF0	2017-08-04 11:06:00+03	57500.00
11EE94	2017-07-07 11:11:00+03	289300.00
11EEBA	2017-08-10 22:19:00+03	101100.00
11EEC8	2017-07-06 09:53:00+03	17600.00
11EEE9	2017-07-24 01:50:00+03	62600.00
11EEFB	2017-07-08 17:23:00+03	58200.00
11EFB1	2017-08-11 07:45:00+03	148200.00
11F079	2017-08-02 04:00:00+03	152400.00
11F098	2017-07-25 01:55:00+03	42800.00
11F099	2017-07-09 22:56:00+03	48700.00
11F117	2017-07-26 18:39:00+03	91700.00
11F11A	2017-08-14 21:01:00+03	14400.00
11F123	2017-07-14 04:21:00+03	32800.00
11F15C	2017-07-08 08:14:00+03	47000.00
11F194	2017-07-11 18:44:00+03	6700.00
11F1BC	2017-07-24 11:59:00+03	195800.00
11F20C	2017-07-17 23:24:00+03	31400.00
11F23E	2017-07-06 10:46:00+03	133200.00
11F274	2017-07-11 18:46:00+03	54800.00
11F28C	2017-07-04 05:24:00+03	16400.00
11F292	2017-07-19 11:53:00+03	88400.00
11F2AD	2017-08-05 01:46:00+03	70800.00
11F2BA	2017-06-29 06:08:00+03	64300.00
11F2D0	2017-07-18 01:12:00+03	17600.00
11F2DC	2017-08-01 21:29:00+03	349200.00
11F302	2017-07-27 17:27:00+03	174600.00
11F333	2017-08-13 08:09:00+03	55800.00
11F3B5	2017-06-30 11:01:00+03	32800.00
11F421	2017-08-13 11:51:00+03	194300.00
11F4CF	2017-07-10 14:12:00+03	13600.00
11F517	2017-07-20 09:12:00+03	284300.00
11F53F	2017-07-07 23:38:00+03	88900.00
11F561	2017-07-09 09:42:00+03	136000.00
11F5E5	2017-08-02 20:13:00+03	42700.00
11F620	2017-07-09 08:13:00+03	266400.00
11F6E6	2017-08-07 05:07:00+03	74400.00
11F72B	2017-08-02 07:27:00+03	28600.00
11F7B6	2017-08-14 14:31:00+03	14000.00
11F7E6	2017-07-22 14:16:00+03	55500.00
11F80E	2017-07-19 22:39:00+03	112000.00
11F83C	2017-08-07 20:53:00+03	168000.00
11F858	2017-07-18 12:40:00+03	46400.00
11F8A6	2017-08-06 06:59:00+03	44900.00
11F913	2017-07-07 18:37:00+03	300200.00
11F94A	2017-07-21 01:35:00+03	12400.00
11F967	2017-07-04 21:50:00+03	36800.00
11F98F	2017-07-31 00:09:00+03	173400.00
11F993	2017-08-05 12:36:00+03	14400.00
11F9AA	2017-07-02 10:58:00+03	50000.00
11F9B3	2017-06-27 19:21:00+03	48100.00
11FA7B	2017-07-15 21:39:00+03	148200.00
11FA8C	2017-08-02 14:35:00+03	36200.00
11FB05	2017-07-11 05:05:00+03	193700.00
11FB5C	2017-08-11 06:46:00+03	135400.00
11FB93	2017-07-06 23:27:00+03	54600.00
11FB9E	2017-07-02 22:24:00+03	34000.00
11FBDD	2017-08-13 17:57:00+03	52500.00
11FBF4	2017-08-11 05:42:00+03	114800.00
11FC1F	2017-07-10 16:00:00+03	28800.00
11FC42	2017-07-11 19:58:00+03	31000.00
11FCA5	2017-07-04 19:28:00+03	96300.00
11FCE3	2017-07-12 16:45:00+03	36200.00
11FD22	2017-07-05 06:35:00+03	232300.00
11FE0E	2017-07-01 23:31:00+03	392200.00
11FE1E	2017-07-23 22:20:00+03	44600.00
11FE8C	2017-07-31 19:12:00+03	36700.00
11FEBE	2017-07-25 18:18:00+03	69600.00
11FEBF	2017-07-31 18:16:00+03	19600.00
11FF19	2017-08-05 19:07:00+03	229600.00
11FF63	2017-07-19 22:41:00+03	44000.00
120006	2017-07-07 17:25:00+03	22000.00
120017	2017-07-30 01:35:00+03	58800.00
12001D	2017-07-25 00:22:00+03	100500.00
120023	2017-08-01 18:23:00+03	39600.00
12006B	2017-07-29 09:47:00+03	26000.00
12006E	2017-07-12 14:03:00+03	38400.00
1200E2	2017-07-10 00:22:00+03	26800.00
120107	2017-07-14 20:15:00+03	664200.00
12016B	2017-08-08 15:39:00+03	75300.00
120170	2017-08-14 18:45:00+03	18000.00
120188	2017-07-05 00:50:00+03	23400.00
1201A6	2017-07-30 13:31:00+03	23600.00
1201D3	2017-07-11 05:41:00+03	29600.00
120205	2017-08-12 13:13:00+03	40800.00
12021F	2017-08-09 18:36:00+03	29600.00
120223	2017-07-12 11:02:00+03	6000.00
120224	2017-07-30 08:26:00+03	52700.00
12029C	2017-07-09 07:18:00+03	66600.00
1202C6	2017-07-24 09:20:00+03	20400.00
120303	2017-07-02 16:38:00+03	26000.00
1203B5	2017-07-23 00:10:00+03	16400.00
120412	2017-07-13 18:42:00+03	24800.00
120427	2017-07-25 02:32:00+03	132800.00
120438	2017-06-29 05:54:00+03	51900.00
1204AF	2017-07-07 16:02:00+03	13600.00
120505	2017-07-08 09:59:00+03	21800.00
1205EC	2017-07-05 00:06:00+03	24700.00
120624	2017-08-03 03:21:00+03	10100.00
12064C	2017-08-05 15:25:00+03	16400.00
120682	2017-07-30 17:28:00+03	48800.00
120687	2017-07-02 23:02:00+03	75300.00
1206F5	2017-07-11 21:16:00+03	21400.00
120711	2017-07-01 08:14:00+03	92800.00
120745	2017-08-02 09:02:00+03	34200.00
120752	2017-07-16 02:50:00+03	36200.00
12089D	2017-07-18 20:25:00+03	32700.00
1208D0	2017-07-16 23:23:00+03	46200.00
1208D1	2017-07-07 00:36:00+03	54400.00
1208D9	2017-08-01 08:36:00+03	246000.00
120905	2017-07-28 10:54:00+03	26000.00
120948	2017-07-23 05:02:00+03	14900.00
12097B	2017-07-10 22:57:00+03	46700.00
12099E	2017-08-14 20:23:00+03	6000.00
1209B0	2017-07-30 06:52:00+03	42000.00
1209E3	2017-07-11 07:33:00+03	40600.00
120B30	2017-07-04 12:10:00+03	61500.00
120B90	2017-07-03 06:21:00+03	6800.00
120BC8	2017-07-29 06:00:00+03	205600.00
120C19	2017-07-24 02:43:00+03	66600.00
120C50	2017-07-03 03:27:00+03	46400.00
120D3E	2017-07-09 20:34:00+03	19800.00
120D7F	2017-08-04 08:05:00+03	27800.00
120D81	2017-08-01 17:39:00+03	79200.00
120DC1	2017-07-22 21:02:00+03	26000.00
120DD6	2017-07-10 09:38:00+03	20600.00
120DE2	2017-07-02 04:22:00+03	145300.00
120DEC	2017-07-31 03:23:00+03	56600.00
120DF2	2017-07-30 19:12:00+03	53300.00
120EA0	2017-07-07 21:59:00+03	201200.00
120F8F	2017-07-05 09:15:00+03	134900.00
120FE9	2017-08-11 12:54:00+03	56000.00
121022	2017-08-07 16:28:00+03	22000.00
121040	2017-08-01 04:42:00+03	14000.00
1210E8	2017-07-26 13:47:00+03	21500.00
121107	2017-07-01 00:05:00+03	378400.00
121142	2017-07-04 11:14:00+03	13700.00
1211A3	2017-08-12 22:14:00+03	121500.00
1211B0	2017-07-07 09:10:00+03	63700.00
121263	2017-07-12 04:17:00+03	75500.00
121287	2017-07-27 16:10:00+03	284700.00
1212A5	2017-07-16 19:38:00+03	15100.00
1212B1	2017-08-05 14:52:00+03	55800.00
1212FC	2017-07-18 03:59:00+03	12400.00
121413	2017-08-09 11:38:00+03	56600.00
121494	2017-08-15 13:10:00+03	16400.00
12151A	2017-07-05 06:43:00+03	103900.00
121562	2017-06-28 18:57:00+03	22600.00
1215E2	2017-07-16 09:12:00+03	67200.00
121654	2017-07-31 22:12:00+03	77600.00
121657	2017-08-14 03:26:00+03	47400.00
12165C	2017-08-15 18:00:00+03	187800.00
121682	2017-07-17 01:34:00+03	51600.00
1216B3	2017-08-14 00:13:00+03	42800.00
1216C7	2017-08-07 03:55:00+03	89600.00
1216DF	2017-08-02 11:31:00+03	46400.00
12175C	2017-07-02 00:16:00+03	71600.00
12177F	2017-07-13 17:17:00+03	47400.00
1217A0	2017-08-09 18:35:00+03	56100.00
121801	2017-07-11 07:52:00+03	37200.00
121826	2017-07-12 07:24:00+03	13600.00
121828	2017-07-04 13:18:00+03	24400.00
121833	2017-08-04 05:24:00+03	23200.00
1218B6	2017-06-28 08:22:00+03	111600.00
1218C2	2017-07-12 15:28:00+03	27800.00
1218D8	2017-08-13 09:55:00+03	13400.00
121996	2017-08-13 10:14:00+03	94000.00
1219D3	2017-07-28 03:14:00+03	49800.00
1219E5	2017-07-30 12:03:00+03	201200.00
1219EA	2017-07-12 19:24:00+03	66800.00
1219EC	2017-08-15 02:06:00+03	119500.00
121A0F	2017-08-13 21:12:00+03	65200.00
121A26	2017-07-05 13:43:00+03	146700.00
121A29	2017-07-16 06:58:00+03	28000.00
121A31	2017-06-29 22:03:00+03	20400.00
121A41	2017-07-26 08:56:00+03	67600.00
121A4E	2017-08-15 02:02:00+03	7400.00
121A52	2017-08-09 20:35:00+03	37700.00
121A61	2017-07-23 00:00:00+03	92400.00
121B3E	2017-07-11 17:09:00+03	284400.00
121C2D	2017-08-02 13:36:00+03	28800.00
121D72	2017-08-09 19:29:00+03	58900.00
121DB5	2017-07-07 03:25:00+03	539400.00
121DEE	2017-08-04 23:58:00+03	57300.00
121E73	2017-07-03 21:23:00+03	47700.00
121ECD	2017-07-20 04:33:00+03	21400.00
121EFC	2017-07-15 10:41:00+03	166100.00
121F4A	2017-07-20 18:19:00+03	467000.00
121F50	2017-08-13 13:23:00+03	21800.00
121F94	2017-08-04 07:52:00+03	102200.00
121F96	2017-06-28 05:43:00+03	73100.00
12200C	2017-08-12 05:58:00+03	85000.00
122044	2017-08-06 03:54:00+03	56000.00
122070	2017-08-13 18:02:00+03	9200.00
1220E0	2017-07-31 18:08:00+03	141100.00
122136	2017-06-30 14:25:00+03	6200.00
122140	2017-07-13 18:14:00+03	80100.00
1221E9	2017-07-17 23:42:00+03	74700.00
12226B	2017-07-28 00:23:00+03	93900.00
122289	2017-07-14 13:54:00+03	83700.00
1222A7	2017-07-20 07:06:00+03	58200.00
1222AC	2017-07-02 02:46:00+03	46500.00
1222C3	2017-07-23 22:34:00+03	94800.00
122303	2017-08-11 06:51:00+03	28000.00
122308	2017-07-29 02:54:00+03	57500.00
122341	2017-07-15 06:44:00+03	62700.00
122365	2017-06-28 06:42:00+03	199100.00
1223F5	2017-07-02 19:22:00+03	53300.00
1223FD	2017-06-29 13:17:00+03	53700.00
122440	2017-07-09 17:16:00+03	44800.00
122496	2017-08-06 08:49:00+03	37200.00
1224A6	2017-07-30 03:52:00+03	112000.00
12254E	2017-07-09 17:19:00+03	74800.00
1225CA	2017-07-29 22:29:00+03	79000.00
1225DB	2017-07-08 11:09:00+03	136200.00
12261F	2017-07-15 18:00:00+03	116000.00
12264F	2017-07-13 14:44:00+03	81700.00
1226BB	2017-08-04 13:21:00+03	28800.00
12272E	2017-07-22 11:18:00+03	170400.00
12275C	2017-07-24 23:57:00+03	56000.00
12276B	2017-07-18 15:39:00+03	14900.00
1227A0	2017-08-13 05:57:00+03	23600.00
1227C8	2017-08-04 11:27:00+03	24800.00
1227DD	2017-06-29 20:29:00+03	67000.00
122805	2017-07-15 05:14:00+03	55800.00
1228BE	2017-07-18 04:44:00+03	81700.00
1228C7	2017-07-01 23:04:00+03	54800.00
1228DF	2017-08-02 11:48:00+03	42600.00
1228F3	2017-06-30 00:16:00+03	90400.00
12297F	2017-07-08 04:00:00+03	13700.00
122A16	2017-07-15 11:50:00+03	21400.00
122A1C	2017-07-12 22:50:00+03	136800.00
122A2E	2017-07-25 02:39:00+03	26700.00
122A4E	2017-08-09 11:20:00+03	21800.00
122AD0	2017-08-09 17:43:00+03	14400.00
122B24	2017-07-22 02:44:00+03	7400.00
122B4A	2017-07-26 01:00:00+03	46800.00
122B5E	2017-08-15 16:56:00+03	70600.00
122B94	2017-07-12 06:42:00+03	9200.00
122B99	2017-07-16 13:28:00+03	45200.00
122C1C	2017-07-25 01:52:00+03	27000.00
122C27	2017-08-07 04:52:00+03	92600.00
122C45	2017-07-23 17:21:00+03	125200.00
122C47	2017-08-10 12:44:00+03	51900.00
122C8F	2017-07-26 17:08:00+03	58000.00
122CB8	2017-07-15 13:30:00+03	58800.00
122CC0	2017-07-13 13:55:00+03	175300.00
122CE1	2017-08-01 13:10:00+03	70600.00
122D02	2017-07-19 16:58:00+03	58700.00
122D28	2017-07-19 07:03:00+03	55800.00
122E19	2017-08-06 21:22:00+03	56000.00
122E41	2017-07-26 20:56:00+03	6000.00
122E59	2017-08-14 15:14:00+03	6700.00
122F35	2017-07-03 00:18:00+03	111600.00
122F4C	2017-07-15 02:04:00+03	46000.00
122F57	2017-07-23 04:25:00+03	21800.00
122FE0	2017-08-04 23:42:00+03	37500.00
123031	2017-07-05 05:59:00+03	75300.00
12303B	2017-08-10 04:23:00+03	56100.00
123045	2017-07-11 01:41:00+03	46300.00
123047	2017-07-28 17:20:00+03	377500.00
123061	2017-07-29 19:06:00+03	58600.00
123070	2017-07-30 13:05:00+03	112000.00
12307F	2017-08-02 08:45:00+03	58400.00
1230A5	2017-07-15 05:02:00+03	82500.00
1230C9	2017-07-23 22:08:00+03	64500.00
123176	2017-08-04 09:36:00+03	97900.00
1231F9	2017-08-10 20:26:00+03	37200.00
12324C	2017-07-07 03:27:00+03	40000.00
123289	2017-07-16 08:28:00+03	115100.00
1232A5	2017-08-06 01:11:00+03	72400.00
1232A9	2017-07-04 22:50:00+03	291000.00
1232D3	2017-08-15 12:30:00+03	18600.00
12337F	2017-07-11 20:19:00+03	37300.00
1233AA	2017-07-03 12:54:00+03	42000.00
123491	2017-07-18 12:17:00+03	114800.00
1234A8	2017-07-20 05:35:00+03	7800.00
1234E3	2017-07-30 21:56:00+03	21800.00
123567	2017-08-15 00:12:00+03	34200.00
1235A2	2017-07-30 11:21:00+03	123000.00
1235FA	2017-08-07 05:27:00+03	77000.00
12363F	2017-07-20 03:26:00+03	21400.00
12366A	2017-07-09 02:26:00+03	248500.00
1236F7	2017-07-21 23:01:00+03	94800.00
123736	2017-07-22 22:50:00+03	37200.00
123800	2017-07-10 14:25:00+03	43200.00
12382B	2017-07-02 18:26:00+03	100600.00
123844	2017-07-31 23:14:00+03	78100.00
123888	2017-07-12 07:40:00+03	135600.00
123891	2017-07-11 19:57:00+03	79100.00
12392B	2017-07-11 18:40:00+03	48100.00
123972	2017-07-07 17:29:00+03	6000.00
12397E	2017-07-28 16:21:00+03	168600.00
123988	2017-07-25 18:47:00+03	68600.00
123997	2017-07-08 02:11:00+03	42800.00
123A85	2017-07-25 19:53:00+03	28000.00
123A89	2017-07-18 19:17:00+03	16800.00
123A8D	2017-08-08 22:28:00+03	201800.00
123B4A	2017-07-31 14:56:00+03	135400.00
123B65	2017-07-25 16:36:00+03	99800.00
123BC8	2017-07-06 10:08:00+03	30000.00
123BE6	2017-07-13 13:47:00+03	90000.00
123BFC	2017-07-07 13:37:00+03	14000.00
123C1C	2017-07-22 23:49:00+03	46000.00
123C62	2017-07-26 21:17:00+03	25200.00
123C6A	2017-07-04 06:00:00+03	119500.00
123C6B	2017-07-30 12:23:00+03	28800.00
123C73	2017-08-02 15:45:00+03	25800.00
123C93	2017-07-18 18:18:00+03	148500.00
123CD6	2017-08-14 23:40:00+03	50000.00
123D03	2017-07-06 16:25:00+03	29000.00
123D16	2017-07-28 22:35:00+03	383300.00
123D46	2017-08-08 07:23:00+03	51300.00
123D47	2017-08-15 10:08:00+03	133200.00
123D71	2017-06-30 06:19:00+03	57400.00
123DB3	2017-08-11 22:24:00+03	14800.00
123E6C	2017-08-12 02:56:00+03	45200.00
123EBA	2017-07-12 04:46:00+03	184600.00
123EBB	2017-07-31 00:33:00+03	43200.00
123EC9	2017-07-30 18:03:00+03	28000.00
123EDB	2017-08-08 03:11:00+03	34100.00
123FED	2017-07-23 13:39:00+03	46000.00
12406B	2017-07-21 09:06:00+03	62700.00
124093	2017-07-16 17:28:00+03	31100.00
124094	2017-07-07 05:20:00+03	28000.00
1240D3	2017-07-26 10:37:00+03	111600.00
1240D9	2017-07-19 00:04:00+03	57600.00
1240F1	2017-07-23 17:46:00+03	13400.00
124188	2017-07-07 12:38:00+03	98300.00
124191	2017-07-14 11:56:00+03	57400.00
1241C9	2017-08-14 20:27:00+03	34000.00
1241E3	2017-07-04 21:19:00+03	16400.00
1241EB	2017-07-31 07:24:00+03	114800.00
12423C	2017-07-03 08:49:00+03	398500.00
12424D	2017-07-26 16:37:00+03	24800.00
1242B0	2017-07-03 08:47:00+03	58600.00
12430B	2017-08-04 04:08:00+03	79600.00
124330	2017-08-09 11:48:00+03	76100.00
124346	2017-08-15 01:03:00+03	89700.00
124353	2017-07-21 01:25:00+03	38400.00
1243E5	2017-07-03 15:48:00+03	190100.00
124432	2017-07-12 14:49:00+03	44500.00
124466	2017-07-10 21:31:00+03	12600.00
1244DA	2017-06-30 10:25:00+03	33600.00
124571	2017-07-20 18:23:00+03	21400.00
12458D	2017-07-10 01:35:00+03	89600.00
124609	2017-08-15 08:39:00+03	73300.00
124665	2017-07-18 00:52:00+03	57500.00
124682	2017-08-03 00:55:00+03	21400.00
1246FE	2017-07-11 05:47:00+03	14000.00
124704	2017-07-23 21:46:00+03	24400.00
124739	2017-07-12 21:06:00+03	28000.00
124789	2017-07-02 18:44:00+03	96700.00
12478C	2017-08-03 08:53:00+03	28000.00
1247CA	2017-07-22 04:20:00+03	75300.00
12486E	2017-07-18 15:40:00+03	169300.00
1248A3	2017-07-21 17:23:00+03	88800.00
1248DB	2017-07-15 02:49:00+03	42600.00
124935	2017-07-25 10:47:00+03	26000.00
12495B	2017-08-11 00:37:00+03	37700.00
1249A0	2017-07-05 14:39:00+03	123000.00
1249CF	2017-07-03 21:33:00+03	40100.00
1249F3	2017-08-13 14:05:00+03	90000.00
124A3A	2017-07-14 15:53:00+03	116900.00
124A94	2017-07-17 02:33:00+03	67000.00
124AC5	2017-07-17 19:53:00+03	48800.00
124AF9	2017-08-08 05:46:00+03	36200.00
124B7E	2017-08-11 08:40:00+03	173600.00
124BA2	2017-07-05 20:10:00+03	28800.00
124BCA	2017-08-08 17:02:00+03	61700.00
124C62	2017-07-01 07:45:00+03	12400.00
124C9E	2017-07-06 15:44:00+03	282100.00
124CA3	2017-07-13 00:41:00+03	82900.00
124CCE	2017-08-04 15:07:00+03	89600.00
124D05	2017-07-18 04:50:00+03	37900.00
124D38	2017-07-08 23:59:00+03	67600.00
124E4E	2017-07-13 08:01:00+03	66600.00
124E71	2017-07-17 17:03:00+03	66600.00
124E7C	2017-08-10 09:53:00+03	26300.00
124E83	2017-07-27 14:36:00+03	6300.00
124E93	2017-07-02 07:35:00+03	82000.00
124E9C	2017-07-27 07:11:00+03	85700.00
124F58	2017-07-05 09:47:00+03	149100.00
124F86	2017-07-24 16:10:00+03	258400.00
124F8C	2017-08-14 03:12:00+03	38600.00
124F8D	2017-08-15 00:32:00+03	177200.00
124FB2	2017-07-28 15:18:00+03	8400.00
125042	2017-07-02 14:50:00+03	49100.00
12504E	2017-07-18 18:25:00+03	111600.00
12506B	2017-07-04 23:42:00+03	64100.00
1250B1	2017-07-11 12:26:00+03	92800.00
1250C3	2017-08-14 10:47:00+03	136500.00
125169	2017-08-04 06:37:00+03	18000.00
125189	2017-07-02 05:11:00+03	34100.00
1251C2	2017-07-29 14:13:00+03	44800.00
1251C7	2017-08-07 23:42:00+03	46000.00
1251CD	2017-08-07 16:14:00+03	54000.00
1251EE	2017-08-11 04:16:00+03	25800.00
1251F5	2017-07-28 17:22:00+03	111600.00
1252BA	2017-07-08 21:15:00+03	47000.00
125356	2017-07-14 23:27:00+03	13700.00
125364	2017-08-04 01:07:00+03	47400.00
1253A5	2017-08-11 15:39:00+03	6700.00
1253C1	2017-07-06 01:59:00+03	149300.00
1253E4	2017-07-15 17:32:00+03	49600.00
1253FE	2017-07-15 14:11:00+03	9200.00
12543D	2017-07-31 20:35:00+03	23200.00
125461	2017-07-10 19:56:00+03	26000.00
125474	2017-07-13 11:29:00+03	52800.00
1254C3	2017-07-23 20:50:00+03	67700.00
125504	2017-07-24 09:50:00+03	79200.00
125566	2017-07-16 23:40:00+03	189200.00
125580	2017-07-03 19:06:00+03	386300.00
1255B9	2017-07-31 02:04:00+03	56100.00
1255F8	2017-08-02 01:16:00+03	657900.00
125611	2017-08-10 09:21:00+03	246000.00
12562E	2017-07-18 16:15:00+03	57500.00
125632	2017-08-14 02:11:00+03	52900.00
1256E3	2017-07-11 13:29:00+03	101200.00
125707	2017-07-25 15:04:00+03	32700.00
125713	2017-07-13 13:51:00+03	7400.00
12572C	2017-08-05 08:38:00+03	82700.00
125786	2017-07-16 23:39:00+03	92600.00
1257B9	2017-07-14 19:08:00+03	21200.00
1257C0	2017-07-15 18:37:00+03	74300.00
12583F	2017-08-07 10:13:00+03	36200.00
125859	2017-07-05 15:48:00+03	26000.00
12585B	2017-07-19 05:07:00+03	17200.00
125893	2017-07-24 08:13:00+03	106600.00
125960	2017-07-20 09:26:00+03	6000.00
125998	2017-08-07 13:19:00+03	79600.00
1259ED	2017-07-15 23:37:00+03	92800.00
125A40	2017-07-15 05:28:00+03	31600.00
125A59	2017-07-24 06:25:00+03	135600.00
125AB4	2017-07-09 00:36:00+03	66600.00
125AD5	2017-08-14 12:02:00+03	26500.00
125AF2	2017-08-11 11:09:00+03	85400.00
125B0E	2017-06-30 10:57:00+03	56000.00
125B16	2017-08-07 12:14:00+03	270700.00
125B66	2017-08-08 11:18:00+03	84100.00
125B8B	2017-07-26 17:32:00+03	25400.00
125B96	2017-07-12 18:51:00+03	51600.00
125BAD	2017-07-25 06:26:00+03	75300.00
125BB7	2017-08-13 09:45:00+03	89000.00
125C2B	2017-07-08 18:13:00+03	84500.00
125C35	2017-07-13 10:24:00+03	33200.00
125CB5	2017-08-06 09:49:00+03	22600.00
125D10	2017-07-28 06:23:00+03	46000.00
125D6C	2017-07-26 20:30:00+03	93700.00
125D8E	2017-08-08 14:14:00+03	28000.00
125D9D	2017-07-28 03:06:00+03	124300.00
125DE7	2017-07-02 09:13:00+03	10100.00
125E4C	2017-08-14 11:35:00+03	118300.00
125E4E	2017-07-06 05:32:00+03	91800.00
125E82	2017-07-08 01:04:00+03	13600.00
125EA6	2017-08-10 05:11:00+03	31600.00
125EDF	2017-07-17 13:04:00+03	123000.00
125F3C	2017-07-14 02:41:00+03	113200.00
125F79	2017-07-24 06:12:00+03	69000.00
125F81	2017-07-21 03:22:00+03	46000.00
125FD8	2017-08-06 06:27:00+03	14000.00
125FE3	2017-07-25 03:58:00+03	48800.00
125FF8	2017-07-02 21:54:00+03	400900.00
12602C	2017-08-15 04:44:00+03	46200.00
126039	2017-07-19 17:24:00+03	54700.00
12606D	2017-08-05 05:38:00+03	10600.00
1260CB	2017-08-08 18:35:00+03	23400.00
12614C	2017-07-12 00:56:00+03	21400.00
126193	2017-07-12 02:11:00+03	81300.00
12629D	2017-07-30 16:07:00+03	87900.00
1262BA	2017-07-25 23:57:00+03	76400.00
1262C0	2017-07-27 12:42:00+03	26800.00
126315	2017-08-07 22:11:00+03	62100.00
126341	2017-07-23 16:22:00+03	17200.00
12636D	2017-08-01 20:07:00+03	185500.00
1263A0	2017-08-12 14:33:00+03	88900.00
1263A7	2017-07-08 04:53:00+03	68800.00
1263CE	2017-08-06 15:58:00+03	72200.00
1263ED	2017-07-18 17:24:00+03	13400.00
126427	2017-08-12 10:23:00+03	38300.00
12645D	2017-07-13 02:13:00+03	56000.00
12647D	2017-08-12 17:23:00+03	63500.00
1264E9	2017-07-31 10:19:00+03	68500.00
12651D	2017-07-19 00:52:00+03	136700.00
126522	2017-08-14 08:12:00+03	28000.00
12652F	2017-07-24 08:33:00+03	86400.00
126571	2017-07-04 04:33:00+03	11800.00
12662A	2017-08-05 20:23:00+03	57500.00
126691	2017-07-27 16:41:00+03	6300.00
1266B3	2017-07-15 04:20:00+03	23200.00
126747	2017-07-21 10:30:00+03	147700.00
126799	2017-07-21 06:10:00+03	12000.00
1267AE	2017-07-21 23:21:00+03	72400.00
126843	2017-07-16 00:30:00+03	58200.00
12685A	2017-07-28 11:03:00+03	113500.00
126861	2017-07-14 23:11:00+03	62700.00
12686C	2017-07-09 01:35:00+03	29400.00
126904	2017-07-19 06:25:00+03	26000.00
12698D	2017-07-03 00:17:00+03	14000.00
1269A6	2017-07-22 23:30:00+03	48800.00
126A48	2017-07-22 23:03:00+03	38600.00
126AAE	2017-08-15 09:08:00+03	20200.00
126ADA	2017-08-08 11:35:00+03	47100.00
126BD3	2017-07-11 14:17:00+03	43800.00
126C6E	2017-08-09 06:48:00+03	37200.00
126C77	2017-07-23 17:10:00+03	18600.00
126D2F	2017-07-21 09:05:00+03	95200.00
126DBE	2017-08-06 03:48:00+03	59900.00
126DD3	2017-07-26 20:21:00+03	70200.00
126E75	2017-07-23 12:10:00+03	39800.00
126EA9	2017-08-01 06:41:00+03	92800.00
126F1A	2017-07-03 13:41:00+03	73600.00
126F5E	2017-07-04 20:12:00+03	123000.00
126F86	2017-08-01 05:39:00+03	123700.00
126F90	2017-08-09 15:07:00+03	102500.00
127008	2017-07-18 22:34:00+03	8200.00
1270D0	2017-08-14 07:42:00+03	56000.00
1270DB	2017-07-13 15:14:00+03	64700.00
12710A	2017-07-08 05:25:00+03	12000.00
127171	2017-08-07 21:22:00+03	76600.00
12719C	2017-07-23 16:23:00+03	106800.00
1271A0	2017-08-09 04:30:00+03	112000.00
1271C3	2017-06-29 14:09:00+03	70700.00
1271ED	2017-07-13 07:12:00+03	26500.00
12724B	2017-08-02 15:04:00+03	26000.00
12728D	2017-08-07 00:43:00+03	11000.00
127301	2017-07-06 16:49:00+03	23200.00
127331	2017-08-09 01:51:00+03	10700.00
12737A	2017-08-13 17:15:00+03	143600.00
1273CD	2017-07-14 13:20:00+03	62800.00
127460	2017-08-09 00:39:00+03	20200.00
1274AC	2017-08-14 09:08:00+03	12200.00
12750F	2017-07-14 08:13:00+03	123000.00
127561	2017-07-03 15:58:00+03	26800.00
1275BE	2017-06-30 04:32:00+03	9800.00
1275D0	2017-06-29 03:58:00+03	41400.00
127682	2017-07-06 11:31:00+03	31000.00
1276D6	2017-08-05 13:31:00+03	84100.00
1276ED	2017-07-16 08:58:00+03	91300.00
1277AE	2017-07-29 01:09:00+03	56000.00
1277B3	2017-07-23 12:47:00+03	24500.00
1277B7	2017-07-21 00:31:00+03	133200.00
1277CB	2017-08-03 10:48:00+03	98300.00
1277D5	2017-07-18 11:22:00+03	86400.00
1277E5	2017-07-26 12:49:00+03	16400.00
127856	2017-08-04 14:53:00+03	28300.00
12786D	2017-07-22 00:13:00+03	57700.00
12788A	2017-07-22 03:01:00+03	27200.00
12791B	2017-07-09 05:27:00+03	88600.00
1279D6	2017-07-12 21:18:00+03	72300.00
1279DE	2017-07-06 07:27:00+03	58400.00
1279E5	2017-07-16 21:05:00+03	61400.00
127A40	2017-07-13 02:31:00+03	23600.00
127A49	2017-07-21 15:55:00+03	28800.00
127A93	2017-07-30 06:28:00+03	24400.00
127B01	2017-08-09 04:04:00+03	99300.00
127B8C	2017-08-09 22:35:00+03	69400.00
127BAE	2017-07-14 21:49:00+03	21400.00
127BE1	2017-07-07 13:29:00+03	89600.00
127C29	2017-07-05 15:47:00+03	47000.00
127C7D	2017-08-01 12:01:00+03	81900.00
127C94	2017-07-03 00:50:00+03	261500.00
127CE4	2017-07-19 23:25:00+03	479000.00
127D23	2017-08-03 09:09:00+03	28000.00
127D24	2017-08-07 10:19:00+03	28000.00
127D2F	2017-07-17 15:59:00+03	56000.00
127D94	2017-08-08 18:53:00+03	167500.00
127DA7	2017-07-05 01:24:00+03	46000.00
127DAF	2017-07-09 22:16:00+03	169700.00
127DB3	2017-08-06 19:43:00+03	162200.00
127EB3	2017-07-01 19:50:00+03	6600.00
127EC7	2017-08-03 17:08:00+03	44000.00
127EF2	2017-07-23 18:26:00+03	24400.00
128012	2017-07-06 04:42:00+03	24400.00
128042	2017-08-07 14:52:00+03	32800.00
128050	2017-07-21 22:18:00+03	115800.00
128123	2017-07-22 11:22:00+03	23600.00
128163	2017-07-05 08:27:00+03	63200.00
12818D	2017-07-23 20:40:00+03	170200.00
12820C	2017-07-04 21:52:00+03	56000.00
128225	2017-08-03 22:26:00+03	31400.00
12823C	2017-07-22 22:03:00+03	28800.00
12824A	2017-08-15 10:13:00+03	39300.00
12824D	2017-08-13 08:48:00+03	123000.00
128274	2017-07-30 11:04:00+03	207200.00
128309	2017-08-07 12:05:00+03	27600.00
12830F	2017-08-11 06:07:00+03	65900.00
128322	2017-07-10 04:33:00+03	38200.00
12833E	2017-07-13 11:39:00+03	62800.00
128341	2017-08-03 20:35:00+03	20400.00
1283AB	2017-07-13 14:46:00+03	14000.00
1283B4	2017-07-16 00:27:00+03	68400.00
12842C	2017-07-25 00:34:00+03	234800.00
1284EB	2017-07-26 16:10:00+03	119600.00
1284FE	2017-07-17 22:38:00+03	189700.00
12855D	2017-07-19 02:42:00+03	123600.00
1285F4	2017-07-01 13:44:00+03	8000.00
128638	2017-07-27 09:37:00+03	40800.00
128679	2017-07-08 06:44:00+03	46500.00
128687	2017-07-11 16:43:00+03	57300.00
128724	2017-08-03 00:00:00+03	67800.00
128760	2017-08-03 19:03:00+03	64300.00
1287BF	2017-08-08 03:02:00+03	396300.00
128818	2017-07-06 08:07:00+03	56000.00
12881C	2017-07-29 08:29:00+03	94200.00
128851	2017-08-03 23:57:00+03	86500.00
128855	2017-08-15 17:44:00+03	101500.00
128993	2017-07-30 09:56:00+03	76600.00
1289AA	2017-08-08 08:53:00+03	20200.00
1289EF	2017-07-06 12:07:00+03	61800.00
128A18	2017-07-29 18:49:00+03	42800.00
128A36	2017-08-11 04:31:00+03	103500.00
128A3E	2017-08-05 03:24:00+03	56000.00
128A45	2017-08-09 15:55:00+03	58000.00
128A59	2017-08-05 00:09:00+03	41200.00
128A70	2017-08-02 04:38:00+03	28000.00
128AD2	2017-07-07 20:09:00+03	24800.00
128AF5	2017-08-12 22:30:00+03	62600.00
128BAE	2017-06-28 08:25:00+03	51800.00
128BB0	2017-07-25 16:13:00+03	73600.00
128BBA	2017-07-10 11:22:00+03	51900.00
128BCD	2017-08-15 02:38:00+03	37200.00
128BF4	2017-07-02 11:18:00+03	113200.00
128C15	2017-07-12 08:59:00+03	59800.00
128C2E	2017-07-25 13:23:00+03	57500.00
128C3E	2017-08-07 00:03:00+03	156500.00
128D07	2017-07-30 19:00:00+03	137600.00
128D09	2017-07-18 12:48:00+03	39700.00
128DD7	2017-08-10 23:26:00+03	39500.00
128E23	2017-08-01 10:36:00+03	100600.00
128E2A	2017-07-25 05:19:00+03	22000.00
128E5B	2017-08-05 11:59:00+03	28800.00
128E61	2017-08-12 06:46:00+03	103200.00
128EB4	2017-07-20 09:57:00+03	51300.00
128EC5	2017-07-29 06:48:00+03	31100.00
128EF4	2017-08-05 08:33:00+03	67500.00
128F5A	2017-07-12 09:45:00+03	29600.00
128F76	2017-07-12 04:34:00+03	23400.00
128F86	2017-07-24 15:18:00+03	68000.00
128FAE	2017-07-21 21:50:00+03	12000.00
128FE8	2017-07-12 03:07:00+03	18600.00
12902E	2017-07-17 05:36:00+03	80100.00
129061	2017-07-05 10:13:00+03	102100.00
1290A2	2017-08-13 14:04:00+03	28900.00
1290B3	2017-07-06 22:54:00+03	40400.00
1290C8	2017-07-25 06:25:00+03	50800.00
129121	2017-08-05 15:22:00+03	95600.00
129194	2017-07-27 15:19:00+03	133800.00
1291B6	2017-07-09 13:18:00+03	45200.00
1291B8	2017-07-05 08:49:00+03	86300.00
1291CA	2017-07-29 09:59:00+03	37900.00
129224	2017-08-09 12:39:00+03	325600.00
129247	2017-08-09 20:16:00+03	36000.00
129252	2017-07-13 11:44:00+03	93600.00
129272	2017-07-25 06:36:00+03	148200.00
12929B	2017-07-02 17:52:00+03	89100.00
129309	2017-07-09 16:48:00+03	20000.00
129338	2017-07-19 17:57:00+03	285700.00
129353	2017-07-26 05:56:00+03	73600.00
129370	2017-07-28 00:55:00+03	17200.00
129392	2017-08-08 22:49:00+03	15900.00
1293B9	2017-07-23 04:17:00+03	14800.00
1293CE	2017-07-06 10:24:00+03	46400.00
1293E7	2017-08-05 14:36:00+03	274100.00
129423	2017-07-12 02:32:00+03	48400.00
12942D	2017-07-28 05:21:00+03	234600.00
129434	2017-08-14 13:41:00+03	23400.00
12945D	2017-07-04 02:38:00+03	25800.00
12945E	2017-07-01 16:46:00+03	48800.00
12947A	2017-08-11 20:01:00+03	50600.00
129489	2017-07-21 08:01:00+03	106900.00
1294B9	2017-08-14 03:40:00+03	28000.00
1294E9	2017-08-05 15:50:00+03	55800.00
12950E	2017-07-27 09:13:00+03	47500.00
12953C	2017-07-20 01:47:00+03	12000.00
1295BC	2017-07-02 13:45:00+03	23600.00
129696	2017-08-05 18:56:00+03	10700.00
1296BD	2017-07-22 20:00:00+03	6700.00
1296CC	2017-07-15 13:50:00+03	93900.00
1296F6	2017-07-16 05:07:00+03	44800.00
12973F	2017-07-06 09:03:00+03	170000.00
12976C	2017-08-13 21:11:00+03	86300.00
12976D	2017-07-10 03:19:00+03	50600.00
12978F	2017-08-11 11:28:00+03	137400.00
129796	2017-08-03 11:50:00+03	131100.00
1297C0	2017-07-14 00:14:00+03	66000.00
129803	2017-07-23 11:13:00+03	200500.00
129817	2017-07-13 09:14:00+03	202400.00
12981A	2017-08-12 14:28:00+03	103000.00
129845	2017-07-31 11:45:00+03	130800.00
129940	2017-08-06 10:43:00+03	56100.00
12996F	2017-07-05 18:23:00+03	135400.00
1299DC	2017-07-11 11:37:00+03	46400.00
1299F2	2017-07-05 14:25:00+03	123000.00
129B0C	2017-07-24 19:07:00+03	147600.00
129B1B	2017-07-30 11:24:00+03	266400.00
129B7A	2017-07-12 05:52:00+03	37700.00
129C6E	2017-08-12 06:57:00+03	141600.00
129C8C	2017-08-12 16:56:00+03	32200.00
129C96	2017-07-13 20:33:00+03	29400.00
129CDE	2017-07-15 05:58:00+03	92600.00
129D78	2017-07-24 00:49:00+03	531400.00
129DBA	2017-07-14 14:58:00+03	45100.00
129DFB	2017-08-08 10:59:00+03	22000.00
129E3C	2017-07-11 05:12:00+03	26000.00
129E6C	2017-07-31 04:56:00+03	399600.00
129EEA	2017-08-12 15:43:00+03	98500.00
129F72	2017-07-19 08:41:00+03	24400.00
129F87	2017-06-30 09:18:00+03	14000.00
129F8F	2017-08-14 03:32:00+03	72400.00
129FA4	2017-08-03 21:20:00+03	136200.00
129FDB	2017-07-09 22:15:00+03	34000.00
129FF8	2017-07-30 11:29:00+03	59200.00
12A05A	2017-07-01 00:04:00+03	115400.00
12A08E	2017-07-26 11:52:00+03	100200.00
12A0A2	2017-07-19 15:19:00+03	56900.00
12A0CA	2017-06-27 01:37:00+03	14400.00
12A0DD	2017-07-06 06:12:00+03	75100.00
12A0FC	2017-07-20 03:16:00+03	38600.00
12A16E	2017-08-01 15:09:00+03	90800.00
12A214	2017-07-01 03:55:00+03	6700.00
12A2B1	2017-08-02 00:59:00+03	28000.00
12A2D7	2017-08-09 17:20:00+03	56000.00
12A373	2017-07-22 03:30:00+03	6000.00
12A3C9	2017-08-01 15:26:00+03	53600.00
12A3D9	2017-08-15 14:00:00+03	99300.00
12A3FE	2017-07-30 00:02:00+03	273400.00
12A449	2017-07-30 11:53:00+03	25400.00
12A49C	2017-08-07 15:27:00+03	30700.00
12A4A0	2017-07-17 02:02:00+03	31400.00
12A4E5	2017-08-12 06:33:00+03	25100.00
12A4E7	2017-07-10 18:08:00+03	47100.00
12A4FD	2017-08-03 02:52:00+03	8200.00
12A504	2017-07-30 19:12:00+03	106500.00
12A56D	2017-07-20 20:24:00+03	51300.00
12A5CA	2017-07-08 14:58:00+03	21600.00
12A5E5	2017-07-27 03:22:00+03	13200.00
12A60A	2017-07-06 22:31:00+03	14000.00
12A617	2017-07-23 03:58:00+03	105500.00
12A6A9	2017-07-30 05:34:00+03	51800.00
12A70E	2017-08-01 19:45:00+03	24700.00
12A729	2017-08-15 10:21:00+03	290300.00
12A7AC	2017-07-27 21:33:00+03	133100.00
12A7AF	2017-07-13 00:46:00+03	46400.00
12A7DB	2017-07-18 07:36:00+03	27300.00
12A88A	2017-07-23 04:53:00+03	108200.00
12A8A2	2017-07-24 22:45:00+03	42800.00
12A8E0	2017-08-06 03:45:00+03	14800.00
12A944	2017-08-04 02:48:00+03	101200.00
12A95A	2017-08-06 00:38:00+03	86100.00
12A9A6	2017-08-09 00:22:00+03	56000.00
12A9F1	2017-07-13 02:24:00+03	28000.00
12AA0B	2017-08-03 13:20:00+03	31800.00
12AA12	2017-08-14 10:41:00+03	46400.00
12AAC4	2017-07-15 23:10:00+03	101800.00
12AAF9	2017-08-09 18:52:00+03	136800.00
12AB12	2017-07-05 08:14:00+03	112000.00
12AB15	2017-07-28 14:11:00+03	28800.00
12AB24	2017-07-06 11:07:00+03	27900.00
12AB40	2017-07-23 22:43:00+03	46400.00
12ABAC	2017-08-11 12:11:00+03	23600.00
12AC37	2017-07-23 07:55:00+03	18600.00
12AC89	2017-07-23 07:05:00+03	65500.00
12ACAF	2017-08-15 05:12:00+03	12000.00
12ACE7	2017-07-20 08:28:00+03	286400.00
12ACE9	2017-07-22 02:24:00+03	88500.00
12AD32	2017-08-12 02:00:00+03	81600.00
12AD50	2017-08-14 23:23:00+03	57700.00
12AD70	2017-07-22 11:49:00+03	109800.00
12AD72	2017-07-26 20:47:00+03	44800.00
12ADA9	2017-07-27 03:20:00+03	133200.00
12AE1F	2017-08-09 22:12:00+03	40800.00
12AE85	2017-07-05 16:46:00+03	156400.00
12AE9D	2017-08-11 14:46:00+03	36000.00
12AEA0	2017-08-11 19:04:00+03	62600.00
12AEC1	2017-07-04 06:09:00+03	81300.00
12AED0	2017-07-05 11:09:00+03	100600.00
12AF17	2017-08-08 16:21:00+03	235600.00
12AF97	2017-08-05 17:55:00+03	88800.00
12AF9F	2017-07-30 11:38:00+03	117600.00
12AFB6	2017-08-12 08:29:00+03	56000.00
12AFDB	2017-08-13 16:50:00+03	75300.00
12B073	2017-07-06 09:23:00+03	182300.00
12B0DD	2017-06-25 17:58:00+03	48800.00
12B0F9	2017-08-12 18:14:00+03	225700.00
12B11C	2017-08-07 08:12:00+03	18000.00
12B17D	2017-07-28 06:40:00+03	28800.00
12B1D6	2017-07-09 19:38:00+03	14000.00
12B1D7	2017-08-09 04:56:00+03	67100.00
12B250	2017-07-23 07:11:00+03	72000.00
12B251	2017-07-25 15:05:00+03	89700.00
12B287	2017-07-17 04:55:00+03	27200.00
12B296	2017-07-15 07:18:00+03	24000.00
12B297	2017-06-30 13:35:00+03	59800.00
12B2C7	2017-07-04 14:53:00+03	81300.00
12B2DF	2017-07-13 09:21:00+03	38400.00
12B2F6	2017-07-31 22:57:00+03	406100.00
12B322	2017-07-31 11:18:00+03	17000.00
12B34B	2017-08-09 22:13:00+03	78100.00
12B43D	2017-07-11 14:11:00+03	39800.00
12B456	2017-07-21 22:29:00+03	55800.00
12B4A0	2017-08-14 16:57:00+03	311700.00
12B4A9	2017-07-02 19:11:00+03	57800.00
12B4BB	2017-08-07 08:37:00+03	73200.00
12B565	2017-07-21 16:14:00+03	398600.00
12B588	2017-08-01 07:41:00+03	119300.00
12B5A5	2017-08-01 05:39:00+03	28000.00
12B5CA	2017-07-05 04:27:00+03	18600.00
12B618	2017-07-06 03:00:00+03	54000.00
12B670	2017-07-26 04:28:00+03	81800.00
12B6D5	2017-08-09 04:05:00+03	56000.00
12B6DA	2017-08-02 08:46:00+03	45200.00
12B6DC	2017-07-06 18:07:00+03	290400.00
12B70F	2017-08-05 19:43:00+03	95300.00
12B719	2017-07-07 09:16:00+03	57500.00
12B723	2017-07-24 02:14:00+03	88500.00
12B73C	2017-07-11 10:21:00+03	38400.00
12B742	2017-07-19 21:47:00+03	229600.00
12B783	2017-08-08 19:04:00+03	111700.00
12B7A9	2017-07-11 21:18:00+03	74400.00
12B7BC	2017-08-03 03:31:00+03	277000.00
12B7EB	2017-08-07 07:24:00+03	36200.00
12B886	2017-07-28 19:55:00+03	31600.00
12B8AB	2017-07-14 20:21:00+03	22400.00
12B9A7	2017-07-11 17:32:00+03	52000.00
12B9DE	2017-08-11 11:26:00+03	56600.00
12B9EA	2017-07-13 00:21:00+03	11000.00
12BA09	2017-07-31 19:56:00+03	25000.00
12BA3C	2017-07-01 15:07:00+03	68000.00
12BA4A	2017-07-26 21:37:00+03	69000.00
12BA53	2017-08-08 09:28:00+03	61500.00
12BA55	2017-08-08 23:15:00+03	28300.00
12BA6F	2017-07-18 14:36:00+03	58800.00
12BAA9	2017-07-16 13:47:00+03	55600.00
12BAF6	2017-08-01 16:35:00+03	27900.00
12BB2B	2017-08-15 15:32:00+03	76600.00
12BC8A	2017-08-11 06:10:00+03	15700.00
12BCB6	2017-07-02 14:23:00+03	92800.00
12BCBB	2017-07-19 19:22:00+03	49000.00
12BD0C	2017-08-06 11:50:00+03	30700.00
12BD71	2017-08-05 18:55:00+03	168000.00
12BDF5	2017-08-14 11:59:00+03	12600.00
12BE4C	2017-07-30 11:08:00+03	46200.00
12BE50	2017-07-21 16:05:00+03	238200.00
12BE57	2017-07-04 18:47:00+03	109600.00
12BEB2	2017-08-10 00:45:00+03	69500.00
12BF13	2017-07-10 14:26:00+03	90800.00
12BFCC	2017-08-01 18:53:00+03	14000.00
12BFFE	2017-07-29 12:01:00+03	46800.00
12C00B	2017-07-23 21:12:00+03	81300.00
12C038	2017-08-14 22:24:00+03	6000.00
12C048	2017-07-22 16:37:00+03	89600.00
12C0DB	2017-07-25 20:16:00+03	56100.00
12C17C	2017-08-06 00:56:00+03	26700.00
12C1ED	2017-08-09 04:39:00+03	12400.00
12C2A0	2017-08-05 07:41:00+03	335400.00
12C2B4	2017-07-12 21:22:00+03	120700.00
12C302	2017-08-01 14:05:00+03	28000.00
12C30B	2017-07-15 23:12:00+03	169300.00
12C342	2017-07-11 01:51:00+03	103100.00
12C35F	2017-07-23 12:47:00+03	49100.00
12C3B0	2017-08-10 11:25:00+03	40700.00
12C3BD	2017-07-07 18:24:00+03	54800.00
12C3BE	2017-08-14 15:31:00+03	40800.00
12C469	2017-07-06 16:53:00+03	34000.00
12C4C0	2017-07-03 00:11:00+03	35800.00
12C5B1	2017-07-20 10:41:00+03	78300.00
12C60D	2017-07-21 08:51:00+03	65000.00
12C62F	2017-08-13 20:54:00+03	84500.00
12C634	2017-07-18 00:48:00+03	28800.00
12C63A	2017-07-27 08:52:00+03	90800.00
12C674	2017-07-18 00:38:00+03	60700.00
12C67A	2017-08-14 22:55:00+03	6200.00
12C6BD	2017-08-02 19:56:00+03	56000.00
12C6CC	2017-08-13 05:00:00+03	154400.00
12C71F	2017-07-16 22:11:00+03	57700.00
12C74F	2017-07-31 16:00:00+03	13600.00
12C7AA	2017-08-07 18:43:00+03	28000.00
12C7BA	2017-07-18 13:56:00+03	205500.00
12C81D	2017-08-15 11:08:00+03	40000.00
12C825	2017-07-31 05:30:00+03	37700.00
12C827	2017-07-25 01:47:00+03	16400.00
12C82D	2017-07-17 21:47:00+03	24400.00
12C85A	2017-08-13 22:46:00+03	26600.00
12C886	2017-07-31 08:25:00+03	55900.00
12C88A	2017-07-02 18:33:00+03	6300.00
12C893	2017-07-24 17:08:00+03	25100.00
12C89A	2017-07-20 23:20:00+03	50600.00
12C8D7	2017-08-15 01:04:00+03	8000.00
12C909	2017-07-08 07:44:00+03	126000.00
12C921	2017-08-09 16:22:00+03	126100.00
12C929	2017-07-03 16:56:00+03	64400.00
12C92A	2017-07-02 01:33:00+03	23100.00
12C997	2017-07-30 17:17:00+03	28000.00
12CA0E	2017-08-13 16:29:00+03	73500.00
12CA37	2017-08-08 16:03:00+03	23400.00
12CA65	2017-07-24 05:13:00+03	154500.00
12CA9C	2017-08-10 19:51:00+03	97600.00
12CAC1	2017-07-19 14:39:00+03	24300.00
12CACA	2017-08-13 06:19:00+03	38400.00
12CAF4	2017-08-04 11:16:00+03	34000.00
12CAFD	2017-07-14 01:06:00+03	67000.00
12CB0E	2017-07-22 18:40:00+03	51900.00
12CB14	2017-08-14 21:00:00+03	76600.00
12CB15	2017-07-10 22:56:00+03	107200.00
12CB38	2017-08-02 06:48:00+03	66400.00
12CC0F	2017-06-30 10:18:00+03	24200.00
12CC2D	2017-07-06 17:23:00+03	6000.00
12CC45	2017-07-05 20:57:00+03	87100.00
12CC46	2017-07-11 14:12:00+03	36400.00
12CCB9	2017-07-26 00:40:00+03	27900.00
12CCCA	2017-08-06 12:03:00+03	52300.00
12CD14	2017-07-17 00:55:00+03	56100.00
12CD56	2017-07-28 00:28:00+03	125200.00
12CD84	2017-07-17 14:21:00+03	50200.00
12CD94	2017-08-05 05:21:00+03	56600.00
12CE53	2017-07-28 15:28:00+03	70700.00
12CEC0	2017-07-19 10:18:00+03	50600.00
12CEE1	2017-07-27 18:23:00+03	26200.00
12CF02	2017-07-13 10:20:00+03	306200.00
12CF23	2017-07-19 16:12:00+03	67200.00
12CF8D	2017-07-28 19:24:00+03	57700.00
12CF94	2017-07-28 22:40:00+03	45200.00
12CFCC	2017-07-16 21:26:00+03	28000.00
12CFE7	2017-08-08 09:13:00+03	34000.00
12CFF4	2017-07-15 17:44:00+03	111600.00
12D004	2017-08-07 05:35:00+03	96800.00
12D025	2017-08-10 06:21:00+03	217600.00
12D0B9	2017-08-02 19:25:00+03	54500.00
12D0E0	2017-07-06 15:28:00+03	41200.00
12D166	2017-07-26 14:47:00+03	146300.00
12D171	2017-07-17 21:57:00+03	61400.00
12D1C5	2017-07-03 02:23:00+03	199300.00
12D1E3	2017-08-04 19:07:00+03	123000.00
12D244	2017-07-17 20:56:00+03	234700.00
12D2B1	2017-07-31 00:45:00+03	29000.00
12D2E5	2017-08-14 05:03:00+03	56000.00
12D311	2017-08-14 10:10:00+03	6300.00
12D363	2017-07-12 23:33:00+03	64700.00
12D372	2017-08-07 07:41:00+03	35600.00
12D399	2017-08-11 07:51:00+03	127000.00
12D3D4	2017-07-08 22:30:00+03	70700.00
12D412	2017-07-08 21:40:00+03	57500.00
12D444	2017-07-08 20:27:00+03	51000.00
12D45A	2017-07-09 17:31:00+03	35400.00
12D45D	2017-07-18 00:22:00+03	42700.00
12D482	2017-08-11 22:27:00+03	54800.00
12D4BD	2017-07-09 13:09:00+03	75300.00
12D508	2017-07-27 18:29:00+03	67100.00
12D531	2017-08-06 17:06:00+03	52300.00
12D581	2017-07-01 02:32:00+03	117600.00
12D665	2017-07-08 06:46:00+03	35300.00
12D670	2017-07-07 04:19:00+03	6700.00
12D709	2017-08-11 08:25:00+03	13400.00
12D71F	2017-07-19 01:06:00+03	55800.00
12D720	2017-07-26 18:42:00+03	50100.00
12D7A8	2017-08-12 05:06:00+03	50600.00
12D7B8	2017-07-16 13:47:00+03	42400.00
12D7DD	2017-08-07 01:06:00+03	75800.00
12D7F4	2017-06-30 16:53:00+03	70700.00
12D843	2017-07-04 16:33:00+03	55800.00
12D84D	2017-08-13 21:31:00+03	133200.00
12D85E	2017-07-04 21:43:00+03	70800.00
12D8D6	2017-07-24 11:45:00+03	25600.00
12D917	2017-08-15 10:05:00+03	142300.00
12D98E	2017-07-13 22:42:00+03	110300.00
12D997	2017-07-10 06:51:00+03	302400.00
12D9E6	2017-07-11 14:57:00+03	23600.00
12DA00	2017-07-31 08:49:00+03	139300.00
12DA06	2017-07-01 20:26:00+03	9200.00
12DA3A	2017-08-11 03:51:00+03	113200.00
12DA41	2017-07-31 01:47:00+03	58000.00
12DAB1	2017-08-01 16:14:00+03	47500.00
12DB42	2017-07-13 06:50:00+03	23600.00
12DB4B	2017-08-02 00:22:00+03	56000.00
12DB57	2017-07-20 04:02:00+03	49600.00
12DC56	2017-07-25 15:03:00+03	51900.00
12DC59	2017-07-29 23:22:00+03	149300.00
12DCFE	2017-07-28 12:59:00+03	55800.00
12DD11	2017-07-15 04:56:00+03	88500.00
12DD3C	2017-08-14 02:59:00+03	106100.00
12DD7A	2017-07-11 05:53:00+03	123000.00
12DD83	2017-08-06 07:22:00+03	101200.00
12DD9E	2017-07-31 15:25:00+03	136800.00
12DDB3	2017-07-24 23:19:00+03	107000.00
12DE1C	2017-07-12 14:25:00+03	57400.00
12DE90	2017-07-07 10:51:00+03	372500.00
12DEAA	2017-08-02 21:33:00+03	37600.00
12DEB0	2017-07-29 10:21:00+03	98000.00
12DF2D	2017-07-29 12:13:00+03	54800.00
12DF84	2017-07-27 08:26:00+03	26000.00
12DFE5	2017-07-04 23:37:00+03	32800.00
12DFE8	2017-07-12 11:48:00+03	179200.00
12E005	2017-08-06 14:19:00+03	12600.00
12E05A	2017-06-23 12:59:00+03	95600.00
12E0F5	2017-06-30 03:45:00+03	29600.00
12E13D	2017-07-26 18:06:00+03	142400.00
12E177	2017-07-21 11:05:00+03	29400.00
12E20F	2017-08-05 21:18:00+03	156500.00
12E25F	2017-08-06 12:00:00+03	116400.00
12E282	2017-08-12 19:30:00+03	57600.00
12E298	2017-07-11 10:57:00+03	52000.00
12E332	2017-08-07 07:40:00+03	60600.00
12E339	2017-07-14 22:25:00+03	31400.00
12E364	2017-07-31 22:21:00+03	70600.00
12E367	2017-07-14 18:34:00+03	170800.00
12E3CD	2017-08-09 06:24:00+03	54800.00
12E412	2017-08-05 23:09:00+03	21400.00
12E434	2017-08-09 17:05:00+03	56000.00
12E45F	2017-07-09 20:44:00+03	76400.00
12E48B	2017-07-28 05:49:00+03	153300.00
12E4B6	2017-07-10 09:51:00+03	187600.00
12E4D5	2017-07-22 23:06:00+03	53300.00
12E4EE	2017-07-05 06:31:00+03	6700.00
12E512	2017-08-04 19:34:00+03	124400.00
12E522	2017-07-20 08:46:00+03	167400.00
12E543	2017-07-22 23:56:00+03	52700.00
12E576	2017-07-22 04:22:00+03	24400.00
12E60B	2017-07-08 09:09:00+03	39600.00
12E64D	2017-08-15 08:06:00+03	81600.00
12E677	2017-08-08 18:55:00+03	187600.00
12E694	2017-07-19 10:41:00+03	16400.00
12E6A7	2017-08-10 05:56:00+03	28800.00
12E6CB	2017-08-07 19:07:00+03	57500.00
12E735	2017-07-12 07:22:00+03	40400.00
12E744	2017-07-10 14:56:00+03	40800.00
12E74C	2017-07-17 18:09:00+03	66800.00
12E819	2017-08-09 02:58:00+03	28000.00
12E864	2017-08-11 03:13:00+03	65500.00
12E905	2017-07-19 19:33:00+03	52800.00
12E931	2017-08-12 08:02:00+03	160700.00
12E93D	2017-07-13 16:44:00+03	27700.00
12E967	2017-08-08 00:37:00+03	53200.00
12E99B	2017-07-25 05:15:00+03	112100.00
12E9F5	2017-07-29 20:13:00+03	78600.00
12EA0C	2017-07-10 16:35:00+03	46500.00
12EA11	2017-07-26 06:21:00+03	10100.00
12EB4B	2017-07-24 10:10:00+03	92100.00
12EB6D	2017-07-21 00:56:00+03	36200.00
12EB70	2017-07-28 03:12:00+03	70800.00
12EBB3	2017-07-23 12:26:00+03	31400.00
12ECB5	2017-07-16 02:08:00+03	23900.00
12EDBD	2017-07-22 10:27:00+03	59800.00
12EDFE	2017-07-25 07:23:00+03	73600.00
12EE13	2017-08-06 18:37:00+03	38600.00
12EE45	2017-07-15 10:39:00+03	95300.00
12EF20	2017-08-05 10:37:00+03	123000.00
12EF47	2017-08-02 07:23:00+03	13400.00
12EF6E	2017-08-08 12:55:00+03	13400.00
12EFAD	2017-07-27 22:49:00+03	25100.00
12EFB0	2017-07-09 20:01:00+03	68000.00
12EFF4	2017-08-07 02:32:00+03	56000.00
12F05D	2017-07-24 21:02:00+03	6700.00
12F061	2017-07-26 22:58:00+03	58400.00
12F090	2017-08-06 08:42:00+03	124200.00
12F0AE	2017-07-07 01:35:00+03	25000.00
12F0D4	2017-07-18 05:25:00+03	30200.00
12F0EE	2017-08-04 05:55:00+03	28000.00
12F11E	2017-07-25 20:47:00+03	18600.00
12F14C	2017-08-07 20:44:00+03	169600.00
12F16D	2017-08-11 02:56:00+03	12600.00
12F176	2017-08-02 18:29:00+03	114400.00
12F1D3	2017-08-15 07:10:00+03	46000.00
12F248	2017-08-13 23:53:00+03	24600.00
12F286	2017-08-01 08:25:00+03	28000.00
12F2AE	2017-07-02 15:15:00+03	18900.00
12F328	2017-08-10 03:24:00+03	53300.00
12F366	2017-07-15 01:30:00+03	56000.00
12F3EC	2017-07-29 09:00:00+03	53600.00
12F3F7	2017-08-13 01:43:00+03	24400.00
12F441	2017-07-29 11:52:00+03	38400.00
12F469	2017-07-30 18:19:00+03	99200.00
12F4DD	2017-07-14 18:25:00+03	349100.00
12F503	2017-07-25 06:52:00+03	45100.00
12F52F	2017-07-04 08:18:00+03	243700.00
12F581	2017-07-06 15:20:00+03	133200.00
12F5C2	2017-07-20 18:42:00+03	43200.00
12F5F8	2017-08-03 13:25:00+03	48400.00
12F639	2017-08-07 19:35:00+03	369000.00
12F65E	2017-08-14 21:46:00+03	39200.00
12F6C6	2017-07-13 05:35:00+03	36800.00
12F6EC	2017-07-07 03:07:00+03	10100.00
12F73A	2017-07-11 02:18:00+03	28800.00
12F790	2017-07-23 07:09:00+03	198500.00
12F799	2017-08-01 14:47:00+03	50800.00
12F7B6	2017-07-07 02:39:00+03	73500.00
12F804	2017-08-04 01:13:00+03	38400.00
12F85F	2017-08-03 00:40:00+03	23400.00
12F89B	2017-08-13 23:16:00+03	23600.00
12F90E	2017-07-18 16:19:00+03	24400.00
12F9FD	2017-07-12 20:18:00+03	23400.00
12FA16	2017-08-14 08:36:00+03	14400.00
12FA1B	2017-07-19 16:09:00+03	42800.00
12FA8C	2017-07-11 22:31:00+03	128900.00
12FAAA	2017-07-03 00:31:00+03	38400.00
12FAE1	2017-08-12 10:14:00+03	32800.00
12FAE2	2017-07-13 14:51:00+03	16400.00
12FAEE	2017-07-07 13:23:00+03	177600.00
12FB23	2017-07-03 16:06:00+03	135600.00
12FB97	2017-07-21 10:25:00+03	57500.00
12FBA9	2017-07-24 03:38:00+03	44800.00
12FBDE	2017-07-28 05:11:00+03	18000.00
12FC0F	2017-07-13 00:23:00+03	77200.00
12FCA4	2017-07-31 23:36:00+03	68000.00
12FCD9	2017-07-31 04:45:00+03	229000.00
12FD49	2017-08-02 07:06:00+03	56600.00
12FD5C	2017-07-14 16:13:00+03	35800.00
12FDA0	2017-07-18 13:43:00+03	8200.00
12FE1C	2017-07-16 17:49:00+03	13000.00
12FE5F	2017-07-29 07:02:00+03	58800.00
12FE99	2017-08-07 17:56:00+03	70500.00
12FEBF	2017-07-19 08:22:00+03	75300.00
12FF26	2017-07-18 06:51:00+03	61800.00
12FF39	2017-08-07 00:31:00+03	34000.00
130043	2017-06-29 19:53:00+03	54100.00
130093	2017-07-18 03:48:00+03	33600.00
1300D3	2017-07-10 06:02:00+03	73500.00
1300F3	2017-07-06 19:28:00+03	45100.00
130128	2017-07-01 01:33:00+03	21200.00
130152	2017-07-21 04:19:00+03	31600.00
13015D	2017-07-17 10:25:00+03	45200.00
130166	2017-08-03 03:01:00+03	40600.00
130203	2017-07-14 09:29:00+03	120000.00
1302A2	2017-07-12 19:29:00+03	51200.00
1302C7	2017-07-14 03:03:00+03	27200.00
1302D2	2017-07-25 16:59:00+03	16300.00
130310	2017-08-09 02:05:00+03	59200.00
130316	2017-07-05 00:33:00+03	190100.00
130452	2017-07-16 16:07:00+03	13400.00
130470	2017-07-14 14:44:00+03	31100.00
1305D4	2017-08-14 07:25:00+03	13400.00
130602	2017-07-13 06:52:00+03	15700.00
13060A	2017-08-05 06:16:00+03	15800.00
130612	2017-07-26 08:50:00+03	29500.00
13069D	2017-08-11 19:01:00+03	95600.00
1306A0	2017-07-15 12:20:00+03	90800.00
1306F4	2017-08-03 04:15:00+03	54400.00
130710	2017-08-01 11:16:00+03	124200.00
1307AA	2017-07-02 14:18:00+03	52400.00
1307F9	2017-08-15 14:05:00+03	58800.00
13081C	2017-08-13 23:58:00+03	51900.00
13084B	2017-07-22 23:33:00+03	26000.00
13086C	2017-07-05 00:42:00+03	60400.00
130881	2017-08-08 12:06:00+03	60000.00
130897	2017-07-12 05:32:00+03	12600.00
130915	2017-07-24 09:43:00+03	6000.00
13095A	2017-08-10 15:28:00+03	54800.00
130960	2017-07-05 11:44:00+03	41200.00
130AC5	2017-07-18 20:49:00+03	87400.00
130B26	2017-08-03 08:52:00+03	9800.00
130B3B	2017-07-18 12:04:00+03	35200.00
130B41	2017-07-25 15:22:00+03	61500.00
130B5D	2017-07-25 20:30:00+03	15700.00
130B8D	2017-07-25 06:01:00+03	151500.00
130B92	2017-07-23 06:19:00+03	36200.00
130BAD	2017-07-03 14:24:00+03	83100.00
130BB8	2017-07-23 17:35:00+03	179300.00
130BC8	2017-08-09 06:26:00+03	159200.00
130BE3	2017-07-27 06:23:00+03	99600.00
130C04	2017-07-04 11:34:00+03	74400.00
130C1C	2017-08-11 00:11:00+03	50500.00
130C5B	2017-08-11 10:21:00+03	28000.00
130D21	2017-07-26 00:33:00+03	14000.00
130E42	2017-08-02 02:38:00+03	186900.00
130E4A	2017-07-12 17:09:00+03	16400.00
130E60	2017-07-14 06:25:00+03	55800.00
130E87	2017-07-02 07:31:00+03	111600.00
130E8E	2017-07-22 15:31:00+03	13400.00
130EAE	2017-07-14 13:44:00+03	119600.00
130EE6	2017-07-18 07:38:00+03	23200.00
130F0D	2017-07-01 20:25:00+03	92100.00
130F1F	2017-07-26 05:13:00+03	6300.00
130FEA	2017-08-04 11:36:00+03	169900.00
131052	2017-06-30 21:09:00+03	29400.00
131118	2017-07-19 08:10:00+03	184300.00
1311B5	2017-08-09 08:20:00+03	83000.00
1311D5	2017-07-01 08:48:00+03	89700.00
131235	2017-07-04 16:53:00+03	35800.00
13124A	2017-08-04 01:36:00+03	21800.00
131251	2017-07-28 19:22:00+03	17600.00
131268	2017-07-09 05:21:00+03	32200.00
1312BE	2017-08-13 07:41:00+03	28600.00
131327	2017-08-07 17:36:00+03	32800.00
131355	2017-08-14 05:34:00+03	23600.00
131397	2017-08-09 19:41:00+03	16400.00
1313C7	2017-07-27 01:17:00+03	47000.00
1313CA	2017-07-02 01:43:00+03	59200.00
131431	2017-07-17 19:12:00+03	144700.00
1314A9	2017-07-31 16:50:00+03	28000.00
1314BA	2017-07-07 04:53:00+03	60400.00
1314F2	2017-08-07 12:19:00+03	114400.00
1314FB	2017-07-20 14:18:00+03	22000.00
13155C	2017-07-21 14:13:00+03	33100.00
131566	2017-07-23 06:31:00+03	40000.00
131583	2017-07-10 03:01:00+03	67200.00
1315AD	2017-07-06 22:30:00+03	39300.00
13166B	2017-07-05 10:47:00+03	6000.00
131672	2017-08-15 02:24:00+03	76600.00
13168F	2017-07-10 08:22:00+03	40600.00
131691	2017-07-14 17:52:00+03	431300.00
13173C	2017-07-13 03:34:00+03	56000.00
13176A	2017-08-10 19:14:00+03	22000.00
1317BB	2017-07-01 16:58:00+03	46400.00
1317DF	2017-08-07 08:08:00+03	244200.00
131893	2017-08-04 14:34:00+03	144400.00
1318A8	2017-07-25 04:50:00+03	190100.00
131914	2017-07-18 10:43:00+03	70700.00
1319AD	2017-07-16 19:49:00+03	119500.00
1319BB	2017-08-09 14:07:00+03	12000.00
1319F4	2017-07-12 02:43:00+03	46300.00
131A1B	2017-07-23 17:57:00+03	111600.00
131A37	2017-08-14 23:34:00+03	56000.00
131A72	2017-07-05 10:13:00+03	13400.00
131AA7	2017-07-03 13:16:00+03	95700.00
131AC0	2017-06-29 11:39:00+03	188500.00
131ADC	2017-08-01 20:45:00+03	67000.00
131BD6	2017-08-11 02:49:00+03	180400.00
131C68	2017-07-14 13:16:00+03	30200.00
131C78	2017-08-08 04:16:00+03	16400.00
131C81	2017-07-16 11:37:00+03	23200.00
131CAE	2017-07-25 03:11:00+03	83000.00
131CC6	2017-08-05 22:09:00+03	56000.00
131CDE	2017-08-14 08:59:00+03	88100.00
131D2D	2017-08-12 23:08:00+03	112000.00
131DBA	2017-07-17 20:21:00+03	22000.00
131E0B	2017-08-07 10:52:00+03	24400.00
131E69	2017-07-27 22:00:00+03	126700.00
131E7B	2017-07-05 10:37:00+03	54400.00
131E80	2017-07-07 15:12:00+03	39800.00
131E82	2017-08-03 12:18:00+03	58700.00
131E9C	2017-07-09 10:56:00+03	43500.00
131EE0	2017-07-25 07:27:00+03	67200.00
131F60	2017-07-15 14:26:00+03	97500.00
131FA9	2017-07-21 01:22:00+03	31600.00
132006	2017-07-22 16:23:00+03	176600.00
132019	2017-08-08 09:25:00+03	43900.00
132052	2017-07-18 23:39:00+03	19600.00
132088	2017-08-13 18:07:00+03	65900.00
13209B	2017-07-18 12:01:00+03	48900.00
1320FB	2017-07-10 04:38:00+03	53400.00
132130	2017-08-04 08:18:00+03	24200.00
13216B	2017-07-30 02:01:00+03	43500.00
13218E	2017-07-09 16:24:00+03	95600.00
13219D	2017-07-21 19:58:00+03	35300.00
1321E0	2017-07-24 10:57:00+03	126500.00
13223D	2017-07-05 16:47:00+03	14000.00
132282	2017-08-03 09:49:00+03	40000.00
1322AD	2017-07-19 08:00:00+03	85000.00
13231B	2017-08-13 00:14:00+03	32700.00
132332	2017-08-09 23:35:00+03	31000.00
13236D	2017-08-01 10:04:00+03	59900.00
1323C8	2017-07-25 05:23:00+03	170700.00
132484	2017-07-29 09:53:00+03	63300.00
1324E1	2017-08-12 16:26:00+03	22000.00
132547	2017-08-15 16:38:00+03	19600.00
1325FE	2017-08-01 00:21:00+03	22400.00
13263A	2017-07-27 19:04:00+03	56000.00
13263B	2017-07-05 17:31:00+03	108800.00
132646	2017-07-29 16:39:00+03	44000.00
132658	2017-07-08 10:34:00+03	91100.00
132670	2017-07-09 18:09:00+03	68800.00
132689	2017-08-08 07:17:00+03	26800.00
1327A1	2017-08-08 05:39:00+03	115400.00
132830	2017-07-04 19:50:00+03	44800.00
132902	2017-07-15 08:47:00+03	144400.00
132920	2017-08-04 06:33:00+03	258400.00
132977	2017-08-15 16:55:00+03	34000.00
132983	2017-08-12 11:09:00+03	28000.00
1329A2	2017-08-09 07:35:00+03	56000.00
132A0D	2017-07-19 11:55:00+03	29600.00
132A0E	2017-07-21 20:51:00+03	92700.00
132A55	2017-08-02 06:41:00+03	16400.00
132AD5	2017-07-30 01:45:00+03	46400.00
132B62	2017-07-11 12:03:00+03	131600.00
132B9C	2017-07-04 15:56:00+03	30000.00
132BFF	2017-07-29 22:27:00+03	13600.00
132C0C	2017-08-07 20:52:00+03	46200.00
132C51	2017-08-08 00:34:00+03	77500.00
132CF9	2017-06-28 15:24:00+03	273400.00
132D08	2017-07-29 06:35:00+03	58600.00
132D41	2017-08-13 03:43:00+03	26700.00
132DA5	2017-07-17 08:51:00+03	15900.00
132E51	2017-07-19 00:44:00+03	105000.00
132F5E	2017-08-04 19:01:00+03	35800.00
132FC2	2017-08-14 23:08:00+03	532600.00
132FE6	2017-07-04 21:24:00+03	44800.00
133065	2017-08-09 21:55:00+03	123000.00
13307F	2017-07-14 13:43:00+03	126400.00
133086	2017-07-16 22:25:00+03	43900.00
133089	2017-08-11 20:29:00+03	13400.00
1330B8	2017-07-03 13:36:00+03	26700.00
13311B	2017-07-21 05:14:00+03	32200.00
133137	2017-08-11 10:27:00+03	40600.00
133223	2017-08-12 11:37:00+03	50000.00
133232	2017-07-16 11:13:00+03	26000.00
133265	2017-07-27 11:29:00+03	18500.00
13326C	2017-07-09 12:10:00+03	18600.00
133306	2017-08-05 00:26:00+03	50600.00
133345	2017-08-01 02:01:00+03	83600.00
133361	2017-07-28 20:26:00+03	59800.00
133442	2017-07-27 15:23:00+03	23200.00
133472	2017-07-06 01:10:00+03	74400.00
133498	2017-07-26 09:36:00+03	44800.00
13350D	2017-08-14 22:39:00+03	136200.00
133557	2017-07-10 12:57:00+03	125600.00
13359B	2017-07-25 22:13:00+03	117600.00
1335FF	2017-07-20 14:02:00+03	179700.00
133611	2017-07-05 02:34:00+03	35200.00
13364B	2017-07-11 15:35:00+03	54000.00
1336F3	2017-08-10 17:35:00+03	105000.00
1336F7	2017-07-06 16:22:00+03	121100.00
13376E	2017-07-15 10:14:00+03	24500.00
13379D	2017-07-16 15:18:00+03	78000.00
13379E	2017-08-09 22:10:00+03	35300.00
133877	2017-07-09 09:53:00+03	102000.00
133927	2017-07-17 06:04:00+03	28800.00
133989	2017-08-10 13:39:00+03	50200.00
1339BB	2017-07-09 11:53:00+03	70700.00
1339ED	2017-07-04 17:22:00+03	12600.00
133AFE	2017-08-08 21:26:00+03	49600.00
133B0A	2017-07-27 06:32:00+03	46000.00
133B0E	2017-07-15 10:17:00+03	42800.00
133B42	2017-07-19 13:59:00+03	28800.00
133B76	2017-07-20 21:35:00+03	27200.00
133BA6	2017-08-02 01:10:00+03	87300.00
133BBF	2017-07-20 11:34:00+03	29600.00
133BC1	2017-08-13 10:00:00+03	20000.00
133C1F	2017-07-16 03:40:00+03	23400.00
133D0A	2017-07-10 00:13:00+03	223200.00
133D4A	2017-08-10 21:04:00+03	36200.00
133DD4	2017-08-04 16:05:00+03	34600.00
133EF1	2017-07-09 15:09:00+03	54800.00
133F08	2017-07-08 07:32:00+03	31600.00
133F09	2017-07-15 05:55:00+03	161600.00
133F0B	2017-07-09 18:40:00+03	173600.00
133F25	2017-08-10 01:09:00+03	92800.00
133F81	2017-07-26 11:49:00+03	66600.00
133F87	2017-08-09 04:15:00+03	101100.00
133FB4	2017-07-07 05:49:00+03	55800.00
134195	2017-07-31 04:51:00+03	78300.00
13428E	2017-08-07 10:53:00+03	192400.00
1342D7	2017-07-06 02:23:00+03	55800.00
1342D8	2017-08-10 18:20:00+03	46400.00
1342E8	2017-08-11 00:42:00+03	46200.00
134300	2017-08-15 09:23:00+03	99700.00
134374	2017-08-11 09:33:00+03	29100.00
1343B6	2017-07-05 13:55:00+03	25400.00
1343E2	2017-07-15 07:44:00+03	133200.00
13444A	2017-07-17 00:29:00+03	7400.00
13446C	2017-08-14 18:43:00+03	13400.00
134489	2017-07-07 07:30:00+03	104000.00
1344CB	2017-08-14 16:33:00+03	135600.00
1344D6	2017-07-20 22:59:00+03	43200.00
1344E6	2017-08-09 19:19:00+03	78500.00
1344EA	2017-07-21 07:14:00+03	46800.00
1344F4	2017-07-20 14:48:00+03	142200.00
13451C	2017-07-20 03:50:00+03	29600.00
134520	2017-07-18 22:18:00+03	243600.00
134593	2017-07-09 14:09:00+03	28800.00
13459D	2017-07-25 23:02:00+03	6700.00
13461F	2017-07-28 19:53:00+03	28800.00
134620	2017-07-18 23:47:00+03	57500.00
134634	2017-07-30 09:36:00+03	43100.00
13463C	2017-07-11 06:45:00+03	556700.00
134711	2017-07-13 05:56:00+03	24300.00
134716	2017-07-20 08:06:00+03	102300.00
13472B	2017-07-23 17:53:00+03	44800.00
134784	2017-08-10 03:27:00+03	99200.00
134790	2017-08-11 22:35:00+03	85700.00
1347FA	2017-07-08 15:21:00+03	125200.00
13484D	2017-07-11 23:52:00+03	112000.00
13489C	2017-07-12 18:12:00+03	66400.00
1348A6	2017-07-26 17:04:00+03	48400.00
1349B0	2017-07-27 12:15:00+03	100000.00
1349B9	2017-07-31 00:19:00+03	25400.00
134A02	2017-07-24 20:16:00+03	39400.00
134A28	2017-07-27 14:24:00+03	93900.00
134A2F	2017-07-01 18:07:00+03	74800.00
134A45	2017-07-30 09:55:00+03	36200.00
134A49	2017-07-03 15:39:00+03	23200.00
134AAC	2017-07-04 04:20:00+03	186000.00
134B75	2017-07-02 11:28:00+03	39300.00
134B85	2017-08-04 13:43:00+03	69700.00
134BA4	2017-07-03 02:00:00+03	56000.00
134BD2	2017-07-05 07:43:00+03	56000.00
134CD6	2017-07-19 02:57:00+03	12600.00
134D54	2017-07-22 15:25:00+03	60800.00
134D58	2017-07-07 11:00:00+03	136200.00
134DEA	2017-07-22 07:48:00+03	62000.00
134E05	2017-07-15 10:34:00+03	10600.00
134E59	2017-07-19 20:35:00+03	43700.00
134EBC	2017-08-06 22:01:00+03	166800.00
134EDC	2017-07-24 18:26:00+03	48500.00
134F37	2017-07-23 14:43:00+03	22000.00
134F7F	2017-08-15 10:01:00+03	54600.00
13507C	2017-07-14 14:32:00+03	76800.00
1350A2	2017-07-08 08:18:00+03	52000.00
1350D0	2017-07-23 19:17:00+03	37000.00
13510D	2017-07-01 08:08:00+03	121800.00
13512A	2017-07-31 07:55:00+03	176800.00
135153	2017-08-13 07:21:00+03	79900.00
135161	2017-08-01 07:55:00+03	55800.00
13518B	2017-07-10 14:07:00+03	117200.00
13519D	2017-07-15 14:50:00+03	130200.00
1351DC	2017-07-10 20:05:00+03	83500.00
1351E7	2017-08-03 13:46:00+03	228800.00
135207	2017-07-23 17:57:00+03	354200.00
13526D	2017-07-13 18:49:00+03	12600.00
135275	2017-07-15 21:38:00+03	92800.00
135284	2017-08-03 05:27:00+03	12400.00
1352B8	2017-08-14 01:05:00+03	26800.00
135396	2017-07-02 20:50:00+03	119700.00
135398	2017-07-29 17:01:00+03	369000.00
13541D	2017-08-09 06:15:00+03	47100.00
135441	2017-07-01 15:55:00+03	29600.00
135596	2017-08-10 03:29:00+03	40800.00
1355B9	2017-07-14 06:40:00+03	47200.00
1355CE	2017-08-02 16:23:00+03	78200.00
1355D0	2017-07-15 02:52:00+03	97800.00
1356E4	2017-07-17 08:17:00+03	28800.00
135709	2017-07-17 16:44:00+03	58400.00
135736	2017-07-21 12:42:00+03	117600.00
1357A8	2017-08-03 11:52:00+03	15000.00
135819	2017-08-02 10:32:00+03	55800.00
1358F2	2017-07-21 12:28:00+03	10100.00
135956	2017-07-23 22:57:00+03	69000.00
135992	2017-08-07 11:32:00+03	192400.00
13599D	2017-08-13 04:58:00+03	56200.00
13599F	2017-08-03 12:01:00+03	26500.00
135A00	2017-07-19 10:59:00+03	74700.00
135A2D	2017-07-19 18:50:00+03	28000.00
135AA0	2017-07-09 17:30:00+03	14400.00
135B62	2017-07-29 00:53:00+03	45200.00
135B73	2017-07-29 20:00:00+03	14000.00
135B80	2017-07-02 03:38:00+03	30200.00
135BCE	2017-07-12 23:25:00+03	95400.00
135C23	2017-07-11 20:56:00+03	145300.00
135C52	2017-08-14 16:17:00+03	38600.00
135C92	2017-08-10 13:55:00+03	160100.00
135CC3	2017-07-12 05:50:00+03	40800.00
135CC5	2017-07-11 09:50:00+03	94700.00
135D0B	2017-07-26 05:42:00+03	56100.00
135DBB	2017-07-24 17:59:00+03	14400.00
135EC1	2017-08-03 21:37:00+03	85000.00
135EEB	2017-07-17 15:59:00+03	13000.00
135EEE	2017-07-26 17:23:00+03	179400.00
135F0F	2017-08-04 19:43:00+03	79200.00
135F86	2017-07-21 13:33:00+03	76900.00
135FB9	2017-08-05 11:59:00+03	133700.00
135FBD	2017-07-28 06:02:00+03	38800.00
135FDB	2017-07-10 04:32:00+03	7200.00
136025	2017-08-07 14:10:00+03	44600.00
136027	2017-07-04 12:01:00+03	67900.00
136094	2017-08-05 04:22:00+03	99300.00
1360BA	2017-07-23 01:49:00+03	131000.00
136151	2017-08-01 01:59:00+03	92800.00
136181	2017-08-01 03:18:00+03	33600.00
136183	2017-08-11 01:06:00+03	58600.00
13621E	2017-07-24 03:15:00+03	45500.00
13627B	2017-08-06 02:04:00+03	16400.00
13629E	2017-07-14 11:04:00+03	26200.00
1362AE	2017-07-01 02:43:00+03	73600.00
13634F	2017-07-24 15:28:00+03	273400.00
13646D	2017-07-23 22:58:00+03	73600.00
136496	2017-07-02 12:22:00+03	27800.00
1364D9	2017-07-25 15:29:00+03	31400.00
1364E6	2017-07-15 01:14:00+03	45200.00
136524	2017-07-15 18:10:00+03	57400.00
13655D	2017-08-02 03:38:00+03	62700.00
136574	2017-07-25 13:58:00+03	187600.00
1365CD	2017-07-07 05:23:00+03	21800.00
136666	2017-07-04 20:34:00+03	128500.00
136672	2017-06-28 21:29:00+03	94000.00
1366D7	2017-07-07 13:09:00+03	32700.00
1366FA	2017-08-02 22:34:00+03	65500.00
136713	2017-08-04 05:37:00+03	155100.00
136735	2017-07-27 08:31:00+03	89700.00
136763	2017-07-26 12:57:00+03	24800.00
1367A4	2017-08-11 12:35:00+03	40800.00
136822	2017-07-01 01:52:00+03	114500.00
13691F	2017-07-18 06:32:00+03	47400.00
136975	2017-08-12 19:17:00+03	11600.00
13698A	2017-08-12 09:31:00+03	72200.00
1369CE	2017-07-18 14:06:00+03	27200.00
136A39	2017-08-02 00:49:00+03	38600.00
136A83	2017-08-12 12:05:00+03	152400.00
136A8B	2017-07-11 20:08:00+03	119500.00
136BEE	2017-07-03 10:00:00+03	73500.00
136C12	2017-07-07 16:07:00+03	56000.00
136C4D	2017-08-01 15:35:00+03	13700.00
136C8C	2017-07-25 00:58:00+03	8200.00
136C93	2017-07-11 04:16:00+03	242300.00
136CEA	2017-07-22 21:22:00+03	128800.00
136D06	2017-08-15 12:18:00+03	339300.00
136D15	2017-07-24 03:53:00+03	348800.00
136D1E	2017-07-08 10:29:00+03	69400.00
136D24	2017-08-04 01:54:00+03	23400.00
136D63	2017-08-06 03:05:00+03	153300.00
136D64	2017-07-20 02:54:00+03	385000.00
136D6D	2017-07-16 00:31:00+03	35600.00
136DA0	2017-07-29 00:05:00+03	46400.00
136DB2	2017-07-19 21:06:00+03	306500.00
136DBB	2017-08-03 19:08:00+03	264600.00
136DF5	2017-08-13 03:37:00+03	46200.00
136E19	2017-07-18 19:53:00+03	69400.00
136E40	2017-07-31 12:16:00+03	176500.00
136EA6	2017-08-07 02:58:00+03	54300.00
136F23	2017-07-07 07:57:00+03	12600.00
136F36	2017-07-26 13:06:00+03	33800.00
136F5E	2017-08-12 16:38:00+03	53200.00
136F7F	2017-07-28 08:27:00+03	25000.00
136FF8	2017-07-31 05:00:00+03	28300.00
137074	2017-07-23 00:06:00+03	21200.00
1370BE	2017-07-29 02:35:00+03	135600.00
1370D9	2017-07-26 14:39:00+03	112000.00
137177	2017-07-11 22:41:00+03	46200.00
1371A5	2017-07-09 18:50:00+03	27200.00
137211	2017-07-27 16:26:00+03	75600.00
13729E	2017-07-03 05:44:00+03	53400.00
1372AF	2017-08-12 02:40:00+03	133300.00
1372C5	2017-07-19 01:46:00+03	19600.00
1372DC	2017-08-01 11:41:00+03	65600.00
13730F	2017-07-14 23:22:00+03	28000.00
1373BF	2017-07-12 08:17:00+03	93500.00
1373EF	2017-07-21 20:40:00+03	89600.00
137442	2017-07-13 08:40:00+03	78300.00
13744C	2017-07-21 23:32:00+03	120900.00
137453	2017-07-26 00:19:00+03	81700.00
13747E	2017-07-03 05:31:00+03	75300.00
13747F	2017-07-30 11:00:00+03	61600.00
137485	2017-07-06 03:37:00+03	55800.00
137490	2017-07-16 04:22:00+03	39600.00
1374F3	2017-07-22 06:40:00+03	57600.00
1374F4	2017-08-03 11:25:00+03	40800.00
137570	2017-07-27 21:23:00+03	43200.00
137613	2017-07-22 05:57:00+03	23200.00
137628	2017-07-03 17:18:00+03	52400.00
1376B2	2017-07-11 01:07:00+03	29200.00
1376BE	2017-07-25 13:49:00+03	68000.00
13776F	2017-07-31 03:40:00+03	39000.00
137776	2017-08-09 05:13:00+03	100000.00
1377A9	2017-07-10 12:52:00+03	68800.00
1377BA	2017-08-14 14:30:00+03	39400.00
137845	2017-08-05 23:06:00+03	217600.00
137872	2017-08-10 02:10:00+03	87400.00
1378F2	2017-07-10 09:52:00+03	108600.00
137907	2017-08-14 15:39:00+03	38000.00
137926	2017-07-09 20:27:00+03	160200.00
13793A	2017-07-15 05:48:00+03	42800.00
13794D	2017-08-12 09:28:00+03	78300.00
137960	2017-07-11 04:19:00+03	71400.00
1379B9	2017-07-25 13:54:00+03	36800.00
1379BB	2017-08-03 18:25:00+03	26000.00
1379BE	2017-08-12 17:32:00+03	38400.00
1379C3	2017-07-13 19:15:00+03	68800.00
137A26	2017-07-13 04:46:00+03	44500.00
137AB3	2017-07-11 14:27:00+03	47200.00
137AC6	2017-07-08 11:47:00+03	167500.00
137ACC	2017-08-14 15:54:00+03	119700.00
137AE8	2017-07-14 07:56:00+03	68100.00
137B74	2017-08-11 06:23:00+03	99000.00
137B75	2017-08-10 16:37:00+03	46000.00
137BE6	2017-07-30 18:30:00+03	111600.00
137BF4	2017-07-10 15:10:00+03	131600.00
137C44	2017-07-22 18:06:00+03	16400.00
137C8A	2017-07-11 01:06:00+03	83200.00
137CA8	2017-07-25 21:34:00+03	202300.00
137D21	2017-08-10 10:46:00+03	8400.00
137D3F	2017-07-12 14:57:00+03	32700.00
137D85	2017-08-08 00:00:00+03	260000.00
137D88	2017-07-24 20:55:00+03	100900.00
137DFF	2017-07-28 20:23:00+03	68400.00
137E13	2017-07-30 01:08:00+03	27800.00
137E1C	2017-07-25 08:14:00+03	6800.00
137E2A	2017-07-16 00:28:00+03	15000.00
137E2D	2017-08-06 17:41:00+03	76600.00
137E34	2017-07-31 19:21:00+03	79500.00
137E43	2017-08-15 10:40:00+03	87600.00
137E6F	2017-08-13 01:20:00+03	20600.00
137EAC	2017-08-13 01:39:00+03	58200.00
137EF8	2017-07-07 22:14:00+03	265600.00
137F6D	2017-07-21 13:33:00+03	47100.00
137FB7	2017-07-26 12:02:00+03	189100.00
137FF3	2017-07-30 21:58:00+03	18000.00
13807F	2017-07-24 17:50:00+03	67700.00
1380D6	2017-07-18 02:06:00+03	49300.00
1380DC	2017-07-09 21:23:00+03	26000.00
1380E6	2017-07-03 00:55:00+03	133200.00
138126	2017-07-14 02:44:00+03	65900.00
138181	2017-07-23 20:21:00+03	27200.00
1381C5	2017-06-28 13:01:00+03	40600.00
1381CC	2017-07-02 07:12:00+03	31900.00
1381F1	2017-07-24 02:03:00+03	97900.00
13829C	2017-07-13 20:47:00+03	58800.00
1382EB	2017-07-11 00:45:00+03	140600.00
1382ED	2017-07-10 11:40:00+03	70800.00
138363	2017-07-28 05:41:00+03	91200.00
138365	2017-07-19 17:42:00+03	6000.00
1383A1	2017-07-22 10:20:00+03	31600.00
1383AF	2017-07-22 12:25:00+03	25100.00
1383B5	2017-07-13 19:51:00+03	75500.00
1383D2	2017-07-12 04:14:00+03	23400.00
1383FF	2017-07-13 14:59:00+03	423500.00
138401	2017-08-12 20:23:00+03	13400.00
138487	2017-08-15 14:23:00+03	46400.00
1384AB	2017-07-20 02:57:00+03	119700.00
1384AE	2017-07-14 21:32:00+03	160700.00
1384F2	2017-07-19 03:39:00+03	55000.00
1385B6	2017-07-06 19:37:00+03	28000.00
1385E4	2017-08-03 15:54:00+03	46400.00
1385EB	2017-08-06 05:10:00+03	112000.00
1385ED	2017-07-18 04:26:00+03	406200.00
1385F9	2017-07-15 03:25:00+03	39800.00
138610	2017-08-15 13:08:00+03	21600.00
13863B	2017-07-05 21:57:00+03	135600.00
138650	2017-08-12 21:48:00+03	38600.00
13873A	2017-07-12 12:40:00+03	44000.00
138746	2017-07-24 18:11:00+03	136800.00
138776	2017-07-26 03:34:00+03	56000.00
13878A	2017-08-10 06:48:00+03	99200.00
13879A	2017-08-06 02:01:00+03	92200.00
13882C	2017-08-11 15:24:00+03	24000.00
138889	2017-07-20 02:48:00+03	51900.00
13889B	2017-08-09 09:03:00+03	38800.00
13893C	2017-07-02 03:13:00+03	51300.00
138969	2017-08-05 20:53:00+03	136200.00
1389B9	2017-07-14 05:46:00+03	219600.00
1389C6	2017-08-07 16:51:00+03	29800.00
138A17	2017-07-26 13:52:00+03	275900.00
138A52	2017-07-15 12:39:00+03	15400.00
138A68	2017-07-25 23:36:00+03	128800.00
138A80	2017-07-21 08:04:00+03	31200.00
138A8F	2017-07-27 13:28:00+03	74100.00
138AE2	2017-08-01 15:14:00+03	193600.00
138AF8	2017-08-03 23:54:00+03	73000.00
138B57	2017-08-07 10:56:00+03	92800.00
138B71	2017-07-24 01:34:00+03	138000.00
138B8A	2017-07-26 06:57:00+03	26000.00
138B92	2017-07-23 05:29:00+03	92100.00
138C97	2017-08-08 08:46:00+03	45300.00
138D4B	2017-07-07 20:24:00+03	16800.00
138D6F	2017-06-29 13:22:00+03	56600.00
138D71	2017-06-30 01:12:00+03	27800.00
138DEB	2017-07-20 09:04:00+03	23200.00
138E1D	2017-08-06 23:33:00+03	38600.00
138E7D	2017-07-29 08:35:00+03	136000.00
138E98	2017-08-07 16:53:00+03	6300.00
138EF3	2017-07-24 07:08:00+03	58900.00
138F6F	2017-08-01 13:28:00+03	92800.00
138F76	2017-08-07 00:58:00+03	26800.00
138FB9	2017-07-09 23:41:00+03	73300.00
13906D	2017-07-26 14:37:00+03	75600.00
1390AA	2017-08-01 02:52:00+03	28000.00
1390B2	2017-07-12 14:43:00+03	17800.00
1390CD	2017-07-23 14:17:00+03	40900.00
139117	2017-06-30 13:23:00+03	73600.00
139189	2017-08-08 13:30:00+03	53300.00
1391A1	2017-07-02 03:19:00+03	56000.00
1391A3	2017-07-03 01:05:00+03	28000.00
1391B7	2017-08-04 21:10:00+03	38600.00
139240	2017-07-30 04:54:00+03	58200.00
139272	2017-08-05 15:32:00+03	69500.00
13927A	2017-07-27 14:29:00+03	113300.00
1392A2	2017-08-10 12:03:00+03	75600.00
1392EA	2017-07-26 12:57:00+03	101100.00
13932B	2017-07-03 02:53:00+03	123000.00
1393B0	2017-07-28 23:41:00+03	166000.00
1393B9	2017-07-21 12:01:00+03	56000.00
1393D0	2017-07-28 05:37:00+03	56000.00
1393DC	2017-07-18 04:04:00+03	205600.00
139430	2017-07-24 06:44:00+03	21800.00
139465	2017-07-03 21:07:00+03	19800.00
139473	2017-07-24 12:27:00+03	94700.00
1394AD	2017-07-17 01:14:00+03	39100.00
1394DF	2017-08-13 02:27:00+03	131600.00
1394FA	2017-07-15 04:50:00+03	65500.00
13952B	2017-07-28 08:25:00+03	50100.00
139542	2017-07-29 06:47:00+03	78000.00
139568	2017-07-26 07:34:00+03	327500.00
13959D	2017-07-31 16:02:00+03	49600.00
1395D1	2017-08-12 04:29:00+03	73200.00
1395F1	2017-07-17 08:23:00+03	31800.00
139652	2017-07-29 03:45:00+03	26000.00
13968B	2017-08-04 21:52:00+03	23600.00
139695	2017-07-02 09:34:00+03	81600.00
1396A2	2017-07-19 03:18:00+03	86300.00
1396F2	2017-08-05 01:52:00+03	128800.00
1396F9	2017-07-16 02:44:00+03	399600.00
139708	2017-07-08 09:50:00+03	68100.00
139738	2017-07-06 05:24:00+03	68600.00
139743	2017-06-28 01:25:00+03	50800.00
13974D	2017-08-13 19:35:00+03	45800.00
13978B	2017-07-20 17:59:00+03	70400.00
1397A3	2017-07-09 18:33:00+03	136200.00
13983D	2017-07-11 01:12:00+03	399600.00
139897	2017-07-14 11:20:00+03	12600.00
1398BB	2017-07-16 15:37:00+03	165000.00
1398ED	2017-07-17 02:54:00+03	114300.00
139925	2017-07-03 01:10:00+03	35800.00
139950	2017-07-30 15:58:00+03	12600.00
1399C9	2017-08-11 19:50:00+03	18600.00
1399FA	2017-07-02 06:24:00+03	12400.00
139A5F	2017-07-26 12:53:00+03	56600.00
139B22	2017-08-15 16:09:00+03	49500.00
139B5E	2017-08-04 15:54:00+03	187600.00
139B6B	2017-07-09 01:09:00+03	59000.00
139BA4	2017-08-05 10:51:00+03	369000.00
139BA7	2017-07-24 01:00:00+03	55800.00
139BB4	2017-07-20 00:19:00+03	66600.00
139BE8	2017-07-20 19:42:00+03	67600.00
139C0D	2017-06-30 19:49:00+03	64500.00
139C46	2017-08-04 09:12:00+03	23200.00
139C63	2017-07-25 16:28:00+03	149300.00
139C79	2017-07-13 06:10:00+03	15000.00
139CC8	2017-07-21 03:03:00+03	59800.00
139DD3	2017-08-03 07:13:00+03	26000.00
139E9B	2017-07-09 16:35:00+03	135200.00
139EBD	2017-08-01 03:24:00+03	542300.00
139EF6	2017-07-21 00:19:00+03	54800.00
139F66	2017-08-04 00:50:00+03	15100.00
139F7C	2017-07-24 13:54:00+03	34000.00
139FBE	2017-08-11 23:38:00+03	40800.00
13A0C3	2017-07-16 13:34:00+03	28000.00
13A195	2017-07-12 08:37:00+03	89200.00
13A19A	2017-07-06 17:12:00+03	46800.00
13A1CE	2017-07-22 21:58:00+03	111600.00
13A1E6	2017-08-14 10:35:00+03	34000.00
13A2F2	2017-08-14 10:57:00+03	23200.00
13A328	2017-08-06 09:52:00+03	6000.00
13A3A6	2017-07-28 20:29:00+03	28800.00
13A3CD	2017-07-09 15:54:00+03	45100.00
13A3E6	2017-08-02 13:39:00+03	417800.00
13A494	2017-08-03 05:55:00+03	57800.00
13A4A2	2017-08-03 14:13:00+03	99300.00
13A500	2017-07-08 13:52:00+03	37900.00
13A515	2017-08-09 02:33:00+03	37100.00
13A524	2017-08-11 12:43:00+03	386200.00
13A549	2017-07-03 12:14:00+03	85000.00
13A635	2017-08-13 20:51:00+03	135400.00
13A642	2017-07-12 01:49:00+03	117000.00
13A65D	2017-07-05 01:51:00+03	19600.00
13A689	2017-08-03 12:57:00+03	69500.00
13A699	2017-08-06 20:29:00+03	63200.00
13A6C0	2017-08-11 06:18:00+03	104600.00
13A6DF	2017-07-25 19:24:00+03	6000.00
13A6F5	2017-07-23 19:58:00+03	40800.00
13A6FF	2017-07-22 09:05:00+03	71500.00
13A71C	2017-06-30 09:41:00+03	12600.00
13A816	2017-07-26 19:30:00+03	194200.00
13A818	2017-08-01 06:53:00+03	47100.00
13A81F	2017-08-08 02:13:00+03	111600.00
13A858	2017-08-07 15:59:00+03	298400.00
13A928	2017-06-30 22:25:00+03	34000.00
13A932	2017-07-16 21:17:00+03	46400.00
13A9F1	2017-08-13 21:44:00+03	58700.00
13AA73	2017-08-08 13:44:00+03	66000.00
13AAE6	2017-07-01 21:00:00+03	23600.00
13AB20	2017-08-06 03:53:00+03	34600.00
13AB93	2017-08-10 07:46:00+03	28800.00
13AC6C	2017-07-05 08:53:00+03	177000.00
13AC90	2017-07-11 07:01:00+03	14000.00
13ACE7	2017-07-29 15:10:00+03	49800.00
13ACF3	2017-08-02 12:45:00+03	25100.00
13AD04	2017-07-24 03:31:00+03	85000.00
13AD2C	2017-07-23 17:26:00+03	78100.00
13AD38	2017-08-05 08:59:00+03	398500.00
13AD75	2017-07-29 19:06:00+03	80900.00
13ADDE	2017-08-08 20:28:00+03	27800.00
13AE86	2017-07-31 17:13:00+03	85100.00
13AEAB	2017-07-24 16:09:00+03	54800.00
13AEFC	2017-07-07 23:05:00+03	6000.00
13AF46	2017-08-13 07:11:00+03	133200.00
13AF49	2017-08-12 20:33:00+03	38800.00
13AF74	2017-07-18 07:01:00+03	28800.00
13AFE3	2017-08-01 17:54:00+03	56600.00
13AFF4	2017-08-03 07:13:00+03	67900.00
13B010	2017-07-17 19:21:00+03	271400.00
13B0BA	2017-07-04 23:59:00+03	62600.00
13B0E7	2017-07-14 21:43:00+03	119800.00
13B128	2017-07-19 17:29:00+03	446100.00
13B12E	2017-07-11 20:31:00+03	34000.00
13B138	2017-08-10 02:22:00+03	87000.00
13B1A6	2017-07-29 15:55:00+03	28800.00
13B1CB	2017-07-09 12:14:00+03	185500.00
13B1EA	2017-07-26 17:02:00+03	172700.00
13B1EB	2017-08-08 15:24:00+03	28800.00
13B1FB	2017-07-21 07:45:00+03	119800.00
13B231	2017-08-01 02:12:00+03	62600.00
13B251	2017-07-27 05:15:00+03	23400.00
13B265	2017-07-19 01:53:00+03	69000.00
13B2AB	2017-07-07 02:34:00+03	25400.00
13B2BD	2017-07-19 01:44:00+03	37400.00
13B327	2017-07-31 08:47:00+03	70700.00
13B32A	2017-07-05 23:39:00+03	28000.00
13B368	2017-07-07 18:49:00+03	55800.00
13B3DD	2017-07-31 15:42:00+03	42600.00
13B402	2017-07-05 23:19:00+03	41400.00
13B426	2017-07-14 10:29:00+03	39300.00
13B46F	2017-08-05 23:10:00+03	57600.00
13B48A	2017-07-07 00:18:00+03	64700.00
13B491	2017-07-19 17:56:00+03	24800.00
13B4BA	2017-08-03 13:25:00+03	55500.00
13B578	2017-08-08 03:34:00+03	194400.00
13B5A4	2017-07-06 10:37:00+03	153300.00
13B614	2017-08-14 00:42:00+03	458100.00
13B667	2017-08-08 17:17:00+03	44600.00
13B689	2017-07-23 08:04:00+03	28800.00
13B68D	2017-08-02 17:08:00+03	48800.00
13B6A2	2017-07-14 23:20:00+03	48900.00
13B6B3	2017-08-15 06:07:00+03	52800.00
13B6CD	2017-07-07 00:06:00+03	65900.00
13B6E6	2017-07-12 23:55:00+03	179500.00
13B7DE	2017-08-13 21:30:00+03	21800.00
13B820	2017-08-15 04:42:00+03	46700.00
13B846	2017-07-22 07:38:00+03	152900.00
13B879	2017-08-05 06:36:00+03	23200.00
13B8FF	2017-08-09 03:39:00+03	24200.00
13B906	2017-08-05 15:50:00+03	56600.00
13B90F	2017-08-10 20:09:00+03	64500.00
13B9CF	2017-07-17 08:05:00+03	28800.00
13BA2D	2017-07-30 05:29:00+03	57600.00
13BA7C	2017-07-06 16:52:00+03	59000.00
13BAF1	2017-07-04 09:23:00+03	193300.00
13BB3A	2017-07-23 07:39:00+03	92800.00
13BB7C	2017-07-31 00:23:00+03	116400.00
13BC1B	2017-08-11 16:23:00+03	123000.00
13BC23	2017-07-08 16:09:00+03	8200.00
13BCF2	2017-08-15 06:11:00+03	25200.00
13BD34	2017-07-25 02:17:00+03	102600.00
13BD6A	2017-07-13 23:28:00+03	46400.00
13BDA1	2017-07-15 18:18:00+03	70700.00
13BE18	2017-07-15 04:55:00+03	93700.00
13BE36	2017-07-14 23:30:00+03	33100.00
13BEB4	2017-07-08 06:08:00+03	420500.00
13BEEE	2017-06-29 12:50:00+03	27200.00
13BF19	2017-07-13 20:11:00+03	37900.00
13BF83	2017-07-22 05:02:00+03	44700.00
13BF93	2017-08-10 07:40:00+03	244100.00
13BFE9	2017-07-25 12:50:00+03	39600.00
13BFF2	2017-07-29 21:08:00+03	52900.00
13C035	2017-07-22 14:00:00+03	30600.00
13C165	2017-07-31 20:58:00+03	64600.00
13C181	2017-08-04 11:50:00+03	335800.00
13C208	2017-07-08 18:47:00+03	107700.00
13C20B	2017-08-02 04:43:00+03	123000.00
13C20C	2017-07-02 11:43:00+03	59300.00
13C220	2017-07-06 04:50:00+03	39800.00
13C25F	2017-08-05 23:43:00+03	24400.00
13C27A	2017-08-02 21:05:00+03	83000.00
13C289	2017-08-03 03:59:00+03	295900.00
13C298	2017-08-11 01:57:00+03	67400.00
13C2BB	2017-08-02 08:58:00+03	270800.00
13C2F1	2017-07-18 04:46:00+03	16400.00
13C2F4	2017-07-08 17:54:00+03	31400.00
13C2F5	2017-08-04 07:44:00+03	20000.00
13C2F6	2017-08-15 09:18:00+03	35400.00
13C354	2017-08-05 00:52:00+03	135600.00
13C361	2017-07-25 15:51:00+03	28800.00
13C3EB	2017-08-13 18:34:00+03	201200.00
13C42A	2017-07-25 07:41:00+03	60700.00
13C48D	2017-07-26 08:07:00+03	17600.00
13C4C4	2017-07-08 12:42:00+03	48700.00
13C507	2017-06-30 04:32:00+03	44700.00
13C524	2017-07-14 02:51:00+03	199700.00
13C539	2017-08-04 12:43:00+03	54100.00
13C552	2017-08-15 05:45:00+03	23200.00
13C576	2017-07-04 10:54:00+03	55800.00
13C599	2017-08-13 16:23:00+03	33300.00
13C5AA	2017-08-10 15:58:00+03	19600.00
13C5AC	2017-07-29 14:36:00+03	20500.00
13C60B	2017-08-03 09:59:00+03	124200.00
13C61C	2017-08-04 17:33:00+03	81300.00
13C622	2017-08-12 08:04:00+03	48700.00
13C67D	2017-08-05 21:29:00+03	175900.00
13C688	2017-08-09 16:07:00+03	28000.00
13C69E	2017-08-15 16:03:00+03	47000.00
13C6E4	2017-08-14 11:06:00+03	43500.00
13C705	2017-07-27 14:10:00+03	265600.00
13C767	2017-08-15 01:35:00+03	8200.00
13C78E	2017-07-18 13:01:00+03	56000.00
13C7AD	2017-08-11 00:17:00+03	106600.00
13C7F4	2017-08-01 03:17:00+03	56000.00
13C836	2017-07-22 23:48:00+03	111600.00
13C837	2017-07-23 13:42:00+03	192300.00
13C843	2017-07-06 05:21:00+03	144400.00
13C88A	2017-08-09 10:58:00+03	102300.00
13C910	2017-07-02 16:35:00+03	40000.00
13C976	2017-07-10 03:40:00+03	27200.00
13C9BB	2017-07-07 15:01:00+03	55600.00
13CA0A	2017-07-07 04:34:00+03	67600.00
13CA15	2017-07-13 20:22:00+03	28800.00
13CAC3	2017-08-04 09:05:00+03	52000.00
13CB2D	2017-07-11 04:31:00+03	85700.00
13CB3E	2017-07-18 09:23:00+03	33100.00
13CB5A	2017-07-26 01:38:00+03	44800.00
13CB7C	2017-07-27 05:35:00+03	84100.00
13CBD6	2017-08-14 19:32:00+03	120900.00
13CC9C	2017-07-29 15:45:00+03	23600.00
13CD1C	2017-07-19 07:24:00+03	62800.00
13CD79	2017-08-10 12:47:00+03	60600.00
13CD90	2017-07-24 04:19:00+03	54500.00
13CDB7	2017-08-08 12:19:00+03	97700.00
13CEB1	2017-07-23 00:51:00+03	137600.00
13CF1D	2017-07-21 19:46:00+03	54800.00
13CF53	2017-07-26 19:07:00+03	35200.00
13CFA5	2017-07-18 13:57:00+03	8200.00
13D015	2017-07-19 03:09:00+03	43200.00
13D080	2017-08-15 17:21:00+03	135400.00
13D08B	2017-07-06 21:32:00+03	28800.00
13D0A1	2017-07-10 06:42:00+03	21400.00
13D0DB	2017-07-15 06:25:00+03	13000.00
13D0FF	2017-07-05 17:28:00+03	24400.00
13D146	2017-08-01 03:36:00+03	32200.00
13D20E	2017-07-02 05:13:00+03	12400.00
13D2D1	2017-07-20 01:34:00+03	25600.00
13D2E5	2017-07-03 02:59:00+03	24800.00
13D385	2017-07-12 13:23:00+03	23200.00
13D3CB	2017-08-05 10:52:00+03	21400.00
13D3EE	2017-07-14 07:55:00+03	58600.00
13D431	2017-07-08 04:20:00+03	46000.00
13D491	2017-07-15 10:37:00+03	198400.00
13D4E3	2017-08-10 18:51:00+03	135400.00
13D5B4	2017-06-25 21:53:00+03	97800.00
13D60B	2017-08-10 06:10:00+03	38400.00
13D6A9	2017-07-26 00:43:00+03	67200.00
13D77A	2017-08-07 08:40:00+03	160000.00
13D8AB	2017-07-06 01:12:00+03	72400.00
13D8DB	2017-07-15 15:17:00+03	101200.00
13D936	2017-07-20 14:10:00+03	47100.00
13D938	2017-07-23 14:34:00+03	55800.00
13D94E	2017-07-29 17:44:00+03	15400.00
13D9E0	2017-07-13 04:00:00+03	84000.00
13DA13	2017-07-17 09:56:00+03	34200.00
13DA4A	2017-07-14 11:39:00+03	54300.00
13DB35	2017-07-26 14:17:00+03	52000.00
13DB93	2017-07-12 10:19:00+03	48700.00
13DC10	2017-07-10 06:46:00+03	26000.00
13DC16	2017-08-08 06:17:00+03	139300.00
13DC69	2017-08-11 18:21:00+03	64700.00
13DCF0	2017-07-24 05:11:00+03	95800.00
13DCF2	2017-07-16 19:54:00+03	75600.00
13DCF4	2017-07-02 08:46:00+03	23600.00
13DD4E	2017-08-14 15:11:00+03	156000.00
13DD97	2017-07-13 14:51:00+03	13400.00
13DE31	2017-08-10 18:44:00+03	9200.00
13DEAE	2017-07-12 07:38:00+03	92000.00
13DEF9	2017-07-27 01:44:00+03	30000.00
13DF4F	2017-08-15 03:19:00+03	35300.00
13DF62	2017-08-11 21:50:00+03	76800.00
13DFA5	2017-07-30 07:35:00+03	22000.00
13DFDC	2017-08-09 11:51:00+03	22000.00
13E024	2017-07-21 02:36:00+03	59800.00
13E081	2017-07-11 17:57:00+03	23600.00
13E0A7	2017-08-07 11:48:00+03	38600.00
13E10F	2017-07-07 17:15:00+03	25900.00
13E162	2017-08-15 15:59:00+03	28800.00
13E1B7	2017-08-04 03:48:00+03	41800.00
13E1EB	2017-07-21 21:06:00+03	39200.00
13E204	2017-07-11 06:52:00+03	59200.00
13E284	2017-07-08 04:43:00+03	81700.00
13E29A	2017-08-14 14:41:00+03	134400.00
13E29B	2017-08-11 00:58:00+03	243600.00
13E2C8	2017-06-30 03:05:00+03	396500.00
13E31D	2017-08-11 23:01:00+03	53600.00
13E32A	2017-06-29 22:42:00+03	13700.00
13E349	2017-07-09 22:40:00+03	43600.00
13E34B	2017-08-12 08:59:00+03	364600.00
13E3C8	2017-07-02 08:10:00+03	24600.00
13E404	2017-08-10 10:38:00+03	36700.00
13E47F	2017-07-30 01:33:00+03	14000.00
13E513	2017-07-06 16:32:00+03	14400.00
13E54F	2017-07-17 04:58:00+03	45200.00
13E5F4	2017-07-01 01:21:00+03	59200.00
13E632	2017-08-14 03:24:00+03	235200.00
13E647	2017-07-09 23:38:00+03	38800.00
13E65A	2017-07-14 09:14:00+03	27600.00
13E68E	2017-06-30 17:55:00+03	90600.00
13E6A8	2017-08-09 16:26:00+03	136800.00
13E6BF	2017-07-27 22:35:00+03	109600.00
13E6CD	2017-07-27 09:06:00+03	25900.00
13E70A	2017-07-08 19:34:00+03	62800.00
13E726	2017-07-31 00:38:00+03	135600.00
13E7C8	2017-08-09 23:12:00+03	27800.00
13E7E4	2017-08-03 15:52:00+03	28300.00
13E7E7	2017-07-24 21:39:00+03	136800.00
13E86B	2017-08-07 02:29:00+03	56000.00
13E943	2017-08-07 11:34:00+03	100000.00
13E956	2017-08-02 07:13:00+03	64900.00
13E969	2017-08-01 11:32:00+03	151200.00
13E9AF	2017-07-24 14:29:00+03	179200.00
13E9D9	2017-07-21 06:54:00+03	26000.00
13E9F8	2017-07-23 10:55:00+03	75000.00
13EA4A	2017-08-15 01:50:00+03	73900.00
13EA5B	2017-07-04 15:55:00+03	92900.00
13EA6F	2017-07-04 13:17:00+03	100600.00
13EA76	2017-07-11 15:40:00+03	70800.00
13EB08	2017-06-29 16:10:00+03	16400.00
13EBB8	2017-08-12 11:42:00+03	52000.00
13EBC1	2017-08-04 06:36:00+03	81600.00
13EC3F	2017-07-05 01:39:00+03	27200.00
13EC6B	2017-07-09 18:06:00+03	127200.00
13ECA1	2017-07-31 19:23:00+03	23200.00
13ECB7	2017-07-06 17:23:00+03	311200.00
13ECE1	2017-07-08 23:34:00+03	66800.00
13ECF2	2017-08-13 06:04:00+03	61800.00
13ED9B	2017-08-06 21:53:00+03	6600.00
13EE8E	2017-07-06 06:24:00+03	10800.00
13EEB6	2017-07-04 01:11:00+03	138000.00
13EEFA	2017-07-30 22:31:00+03	6800.00
13EF2B	2017-07-10 15:02:00+03	40800.00
13EF35	2017-08-04 08:27:00+03	57800.00
13EF3E	2017-07-29 07:59:00+03	14000.00
13EFB3	2017-07-05 04:30:00+03	55800.00
13EFE1	2017-07-07 23:39:00+03	193200.00
13EFE3	2017-08-13 10:50:00+03	131100.00
13F00C	2017-07-27 05:14:00+03	56900.00
13F058	2017-07-30 22:03:00+03	24400.00
13F0A4	2017-08-01 13:39:00+03	28000.00
13F11B	2017-07-21 07:03:00+03	46200.00
13F11D	2017-06-28 16:41:00+03	34000.00
13F131	2017-08-03 13:59:00+03	28000.00
13F1C2	2017-07-08 05:58:00+03	266200.00
13F243	2017-07-03 02:48:00+03	64500.00
13F247	2017-08-14 09:11:00+03	59800.00
13F276	2017-07-11 01:24:00+03	56100.00
13F2AB	2017-08-01 15:38:00+03	9800.00
13F2BC	2017-07-15 22:12:00+03	112000.00
13F2BF	2017-07-06 10:05:00+03	53300.00
13F2ED	2017-07-11 16:03:00+03	64100.00
13F348	2017-08-08 22:28:00+03	14800.00
13F36A	2017-08-02 02:25:00+03	241300.00
13F3A0	2017-06-26 10:13:00+03	236700.00
13F408	2017-07-09 16:50:00+03	65600.00
13F447	2017-08-12 23:04:00+03	76600.00
13F452	2017-08-09 01:26:00+03	44700.00
13F48F	2017-08-15 14:43:00+03	150600.00
13F4AD	2017-07-15 02:03:00+03	206400.00
13F503	2017-07-25 06:51:00+03	147400.00
13F50E	2017-07-21 08:41:00+03	25200.00
13F53A	2017-07-31 06:15:00+03	28800.00
13F589	2017-07-25 20:35:00+03	155600.00
13F59D	2017-07-08 20:03:00+03	298500.00
13F620	2017-08-06 09:12:00+03	28000.00
13F64F	2017-07-31 09:59:00+03	103200.00
13F673	2017-07-12 01:30:00+03	59800.00
13F67D	2017-07-18 11:49:00+03	56900.00
13F6C4	2017-06-28 19:10:00+03	6700.00
13F711	2017-07-27 18:03:00+03	72400.00
13F726	2017-07-26 19:46:00+03	33100.00
13F73A	2017-07-16 23:14:00+03	32700.00
13F74D	2017-07-14 17:54:00+03	14000.00
13F7A1	2017-07-03 15:34:00+03	14800.00
13F7B5	2017-07-30 14:24:00+03	18600.00
13F7D5	2017-07-31 03:55:00+03	286100.00
13F7F8	2017-08-03 10:44:00+03	88800.00
13F90A	2017-07-15 23:57:00+03	24300.00
13F92F	2017-07-05 01:02:00+03	56000.00
13F975	2017-07-16 06:51:00+03	57600.00
13FA0E	2017-08-07 17:54:00+03	266400.00
13FA1F	2017-08-05 15:59:00+03	31600.00
13FA4A	2017-07-17 19:11:00+03	59200.00
13FA92	2017-08-07 08:44:00+03	26200.00
13FA9C	2017-07-26 14:41:00+03	123000.00
13FAB6	2017-08-10 22:33:00+03	17200.00
13FAC5	2017-08-08 05:48:00+03	103500.00
13FAC8	2017-06-30 07:19:00+03	147200.00
13FBEC	2017-07-12 21:25:00+03	136500.00
13FBEE	2017-07-01 04:58:00+03	54500.00
13FC3B	2017-08-09 10:07:00+03	68000.00
13FC5E	2017-08-13 05:21:00+03	46900.00
13FCB5	2017-07-18 16:39:00+03	130200.00
13FCD4	2017-07-26 03:10:00+03	29200.00
13FCEC	2017-08-05 00:44:00+03	56000.00
13FDA9	2017-07-06 13:28:00+03	64700.00
13FE14	2017-07-07 08:12:00+03	27200.00
13FE41	2017-08-15 10:33:00+03	11100.00
13FE96	2017-07-18 06:10:00+03	13600.00
13FF76	2017-08-11 21:15:00+03	108200.00
13FFD1	2017-07-01 23:58:00+03	69000.00
13FFEF	2017-07-11 04:25:00+03	39200.00
140014	2017-07-16 18:12:00+03	73600.00
140068	2017-08-11 00:46:00+03	272400.00
14009B	2017-07-14 16:57:00+03	6700.00
1400A7	2017-08-07 23:24:00+03	167500.00
14018E	2017-06-29 23:49:00+03	17200.00
1401AF	2017-08-03 09:40:00+03	50800.00
140210	2017-07-16 13:28:00+03	59800.00
140246	2017-07-17 13:42:00+03	6200.00
1402D2	2017-07-15 11:52:00+03	51900.00
1402F7	2017-08-08 05:13:00+03	627400.00
14030C	2017-07-08 11:38:00+03	58800.00
14030F	2017-07-08 03:25:00+03	73600.00
14035D	2017-08-04 21:37:00+03	40300.00
140412	2017-08-14 02:31:00+03	49600.00
140418	2017-07-15 21:42:00+03	135400.00
1404AB	2017-08-08 20:02:00+03	186100.00
1404B1	2017-08-15 09:13:00+03	125700.00
1404D7	2017-07-24 17:44:00+03	45200.00
1404FE	2017-08-05 18:37:00+03	88900.00
140509	2017-07-06 05:50:00+03	88900.00
1405F9	2017-07-17 18:47:00+03	20400.00
140603	2017-08-14 08:45:00+03	170200.00
140666	2017-07-23 00:43:00+03	182200.00
140696	2017-07-28 08:55:00+03	103200.00
1406E5	2017-07-30 13:37:00+03	12000.00
140743	2017-07-25 06:54:00+03	46400.00
14075B	2017-07-31 18:56:00+03	22000.00
1407D6	2017-07-28 22:09:00+03	58000.00
1407F7	2017-08-01 20:11:00+03	21500.00
14085A	2017-08-08 08:23:00+03	26700.00
140873	2017-06-29 20:10:00+03	48800.00
14087E	2017-07-04 23:36:00+03	21000.00
14089A	2017-07-30 07:37:00+03	75300.00
1408A0	2017-07-08 11:51:00+03	25600.00
1408B2	2017-08-02 11:07:00+03	101000.00
1408B8	2017-08-11 04:20:00+03	28800.00
1408D4	2017-07-18 01:44:00+03	122500.00
1408DB	2017-07-26 11:42:00+03	46500.00
14090F	2017-08-02 15:12:00+03	28800.00
14091E	2017-08-11 01:55:00+03	62900.00
140A0F	2017-07-27 19:08:00+03	38800.00
140A53	2017-07-31 21:06:00+03	128800.00
140AF1	2017-06-30 14:46:00+03	55800.00
140BEB	2017-07-09 02:38:00+03	365600.00
140CA5	2017-08-02 01:10:00+03	94000.00
140CE9	2017-07-22 09:48:00+03	24400.00
140D4C	2017-07-31 05:40:00+03	48800.00
140DCF	2017-08-15 04:51:00+03	36800.00
140E28	2017-07-18 08:57:00+03	154500.00
140E35	2017-08-12 09:26:00+03	84500.00
140E80	2017-07-05 09:34:00+03	48500.00
140E98	2017-07-12 00:57:00+03	55000.00
140EA2	2017-07-17 14:22:00+03	28700.00
140EAF	2017-07-28 12:15:00+03	16400.00
140EB7	2017-07-23 06:00:00+03	139600.00
140F1A	2017-07-03 06:21:00+03	62600.00
140F31	2017-07-09 09:03:00+03	90800.00
140F37	2017-07-07 05:30:00+03	43100.00
140F73	2017-08-06 16:07:00+03	49900.00
141008	2017-08-08 18:24:00+03	67900.00
141063	2017-07-31 01:20:00+03	55600.00
1410BF	2017-07-20 03:39:00+03	67600.00
1410DA	2017-07-26 14:47:00+03	30300.00
141101	2017-07-30 21:17:00+03	64600.00
141139	2017-08-12 09:17:00+03	34000.00
1411A5	2017-08-05 05:55:00+03	23200.00
14122F	2017-07-15 03:07:00+03	198400.00
141235	2017-07-11 07:34:00+03	155600.00
141275	2017-07-02 02:35:00+03	52400.00
1412B9	2017-07-31 01:38:00+03	57600.00
1412F6	2017-07-05 06:35:00+03	99200.00
14130F	2017-07-16 20:48:00+03	32700.00
141325	2017-07-08 12:10:00+03	13400.00
141367	2017-08-04 23:14:00+03	139400.00
14140D	2017-07-31 04:50:00+03	31800.00
141418	2017-08-09 21:24:00+03	28600.00
14144F	2017-07-26 00:21:00+03	211300.00
1414D2	2017-08-08 13:42:00+03	54100.00
1414F3	2017-08-07 10:59:00+03	40400.00
1414F8	2017-07-14 15:44:00+03	260300.00
14154B	2017-07-20 12:48:00+03	12600.00
14155D	2017-08-07 21:01:00+03	28000.00
141598	2017-08-12 12:19:00+03	40000.00
14159D	2017-07-12 01:55:00+03	24400.00
141620	2017-08-13 09:26:00+03	24800.00
14163E	2017-08-09 08:01:00+03	28800.00
14171F	2017-08-05 02:46:00+03	136800.00
14174D	2017-08-07 07:21:00+03	239100.00
141763	2017-08-05 08:28:00+03	39300.00
1417A1	2017-08-15 14:53:00+03	67900.00
1417F5	2017-07-19 15:31:00+03	26000.00
141825	2017-07-27 16:04:00+03	55800.00
14184B	2017-07-31 04:47:00+03	16800.00
14186E	2017-07-09 10:42:00+03	270800.00
141878	2017-07-28 04:01:00+03	56600.00
14194B	2017-07-24 00:21:00+03	265700.00
14197A	2017-08-12 05:58:00+03	56000.00
1419DB	2017-07-28 08:49:00+03	40400.00
141A0D	2017-08-09 15:54:00+03	227400.00
141A1B	2017-08-14 19:16:00+03	27300.00
141A72	2017-07-31 02:42:00+03	113100.00
141AC0	2017-07-16 09:37:00+03	115400.00
141ADD	2017-07-10 03:21:00+03	29200.00
141AFA	2017-07-20 20:38:00+03	73600.00
141C0D	2017-07-10 07:23:00+03	44800.00
141C50	2017-08-04 04:38:00+03	25600.00
141C76	2017-07-29 01:24:00+03	12400.00
141D7E	2017-08-13 07:39:00+03	32100.00
141D82	2017-07-22 19:34:00+03	57600.00
141DB0	2017-07-17 05:15:00+03	6800.00
141E1E	2017-07-03 01:49:00+03	28800.00
141E68	2017-07-31 19:21:00+03	40600.00
141E6C	2017-08-15 12:41:00+03	49600.00
141E83	2017-07-14 02:56:00+03	175300.00
141EED	2017-07-22 15:57:00+03	87900.00
141F65	2017-07-23 21:48:00+03	56600.00
141FA0	2017-07-08 15:31:00+03	34800.00
141FA7	2017-07-24 11:54:00+03	67200.00
14201B	2017-07-27 18:26:00+03	105100.00
142064	2017-07-23 14:36:00+03	7400.00
142075	2017-07-22 12:03:00+03	52400.00
14211A	2017-07-03 11:04:00+03	17800.00
14212D	2017-07-05 01:07:00+03	232300.00
142148	2017-07-22 05:29:00+03	48900.00
142162	2017-07-02 13:12:00+03	23200.00
142190	2017-08-04 21:56:00+03	94000.00
1421BE	2017-07-23 00:31:00+03	16400.00
14223B	2017-07-10 15:12:00+03	27900.00
14226E	2017-08-09 07:57:00+03	52800.00
142290	2017-07-02 07:47:00+03	67600.00
1422A1	2017-07-20 15:56:00+03	121200.00
1422F3	2017-07-22 18:12:00+03	40700.00
142345	2017-07-14 14:32:00+03	13200.00
14238C	2017-07-26 19:29:00+03	74400.00
142438	2017-08-12 18:25:00+03	100000.00
142451	2017-07-11 19:52:00+03	69500.00
142456	2017-07-18 03:51:00+03	35300.00
14245E	2017-08-01 11:00:00+03	37600.00
142491	2017-08-14 10:59:00+03	136400.00
14254B	2017-07-03 08:18:00+03	154300.00
142559	2017-08-08 07:44:00+03	249100.00
14255B	2017-07-24 05:20:00+03	234800.00
1425BD	2017-07-21 05:36:00+03	39000.00
1425D4	2017-07-17 21:34:00+03	85500.00
14268E	2017-08-12 19:12:00+03	20200.00
1426E5	2017-07-24 15:07:00+03	70600.00
142710	2017-08-01 21:54:00+03	43300.00
142741	2017-08-03 20:16:00+03	14000.00
142749	2017-08-12 19:24:00+03	72300.00
1427F5	2017-07-26 13:08:00+03	56100.00
14285B	2017-08-09 15:31:00+03	68100.00
142864	2017-07-16 13:17:00+03	21200.00
14286E	2017-07-25 11:42:00+03	187600.00
142896	2017-08-02 02:08:00+03	124200.00
1428AF	2017-08-09 17:46:00+03	27800.00
1428C5	2017-07-12 07:57:00+03	38800.00
1428EB	2017-07-27 11:24:00+03	10700.00
142916	2017-07-30 07:52:00+03	103800.00
14293C	2017-07-08 17:30:00+03	73600.00
14293D	2017-07-20 03:33:00+03	265800.00
142963	2017-08-14 23:53:00+03	56600.00
142976	2017-07-02 08:10:00+03	54800.00
142993	2017-07-14 04:06:00+03	6700.00
1429B2	2017-07-06 21:21:00+03	86400.00
1429DD	2017-08-13 18:24:00+03	8000.00
1429F0	2017-06-30 12:57:00+03	96300.00
142A0D	2017-06-29 04:27:00+03	26600.00
142A86	2017-07-18 18:03:00+03	28000.00
142AE0	2017-08-10 18:07:00+03	47600.00
142B1A	2017-08-11 22:27:00+03	68800.00
142B20	2017-08-02 06:38:00+03	16400.00
142B2C	2017-07-16 13:24:00+03	132200.00
142BDF	2017-06-30 03:24:00+03	46000.00
142C0C	2017-08-03 03:29:00+03	12600.00
142C57	2017-08-07 10:11:00+03	24400.00
142C65	2017-08-03 05:34:00+03	29600.00
142CC4	2017-07-02 14:30:00+03	12200.00
142CF5	2017-07-27 21:27:00+03	36800.00
142D27	2017-08-02 11:11:00+03	111600.00
142D43	2017-08-15 09:40:00+03	24000.00
142D44	2017-07-14 15:32:00+03	34100.00
142DF1	2017-07-14 10:05:00+03	66600.00
142E07	2017-08-10 00:21:00+03	21800.00
142E12	2017-08-09 04:07:00+03	37200.00
142E40	2017-08-05 13:16:00+03	29500.00
142E48	2017-08-10 19:49:00+03	135000.00
142E50	2017-07-05 09:51:00+03	23200.00
142F7A	2017-08-09 03:44:00+03	26000.00
142FEF	2017-08-07 13:25:00+03	117000.00
143007	2017-07-19 04:34:00+03	123600.00
14300B	2017-07-03 17:13:00+03	119500.00
14300E	2017-08-01 04:22:00+03	85000.00
14301E	2017-08-08 22:15:00+03	24600.00
1430CF	2017-07-10 19:20:00+03	24700.00
143122	2017-07-25 18:24:00+03	28800.00
14315A	2017-08-08 11:25:00+03	229400.00
1431A4	2017-06-28 19:32:00+03	135200.00
1431E3	2017-07-24 22:17:00+03	24300.00
143202	2017-07-06 09:52:00+03	131100.00
143284	2017-07-04 03:48:00+03	36200.00
143297	2017-07-07 20:02:00+03	28000.00
14329B	2017-07-07 11:33:00+03	28800.00
1432F4	2017-07-31 03:29:00+03	131100.00
143340	2017-08-10 19:28:00+03	94400.00
143355	2017-08-13 01:38:00+03	48500.00
1433A8	2017-07-26 11:57:00+03	58200.00
1433B9	2017-08-11 04:09:00+03	20400.00
1433DE	2017-07-19 00:41:00+03	272400.00
1433F8	2017-08-03 05:20:00+03	23600.00
143407	2017-08-07 11:08:00+03	23600.00
143437	2017-07-29 03:15:00+03	124600.00
14343D	2017-07-15 02:39:00+03	57500.00
143493	2017-07-19 09:53:00+03	103800.00
143494	2017-07-20 21:52:00+03	28800.00
143595	2017-08-11 08:05:00+03	51600.00
143599	2017-07-31 23:22:00+03	56600.00
14362B	2017-08-14 18:32:00+03	168300.00
14365A	2017-07-30 23:41:00+03	108000.00
143686	2017-07-07 07:51:00+03	406100.00
1436DA	2017-07-06 11:30:00+03	53300.00
143703	2017-07-07 20:14:00+03	94000.00
143731	2017-07-17 16:13:00+03	67200.00
143786	2017-07-14 09:09:00+03	23200.00
143799	2017-07-13 11:07:00+03	204200.00
1437D5	2017-07-20 07:23:00+03	28000.00
143866	2017-07-21 12:49:00+03	17800.00
143881	2017-08-08 23:42:00+03	44000.00
14389D	2017-07-15 14:52:00+03	55800.00
1438BD	2017-07-18 07:55:00+03	18600.00
1438EE	2017-07-06 03:45:00+03	38600.00
14393D	2017-07-05 16:14:00+03	148900.00
1439AE	2017-07-29 10:49:00+03	68800.00
1439C4	2017-08-10 13:50:00+03	57800.00
1439CC	2017-08-09 13:56:00+03	114900.00
1439F1	2017-07-16 12:14:00+03	6000.00
143A10	2017-07-17 13:27:00+03	123000.00
143AC5	2017-07-18 22:43:00+03	65600.00
143ACE	2017-08-10 08:01:00+03	13400.00
143AF1	2017-07-24 23:28:00+03	132800.00
143B42	2017-08-03 01:26:00+03	56000.00
143B69	2017-07-15 04:15:00+03	25400.00
143BD9	2017-07-29 14:01:00+03	152500.00
143BF8	2017-07-07 23:58:00+03	29200.00
143C00	2017-07-21 01:40:00+03	46200.00
143C21	2017-07-23 01:13:00+03	26700.00
143C23	2017-08-01 17:59:00+03	66800.00
143D22	2017-07-06 23:53:00+03	23200.00
143D24	2017-07-13 16:43:00+03	72400.00
143D38	2017-08-09 00:03:00+03	21600.00
143D48	2017-07-30 16:28:00+03	48800.00
143D50	2017-07-25 09:06:00+03	134600.00
143DA7	2017-07-03 23:06:00+03	56600.00
143DBD	2017-07-17 07:22:00+03	135400.00
143E25	2017-07-27 03:36:00+03	73100.00
143E27	2017-07-07 17:52:00+03	42100.00
143E3F	2017-07-25 00:15:00+03	25800.00
143E80	2017-08-12 03:52:00+03	13000.00
143EFB	2017-07-17 01:11:00+03	13700.00
143F2E	2017-07-06 02:02:00+03	173600.00
143F31	2017-07-11 08:02:00+03	52300.00
143F33	2017-08-13 06:18:00+03	19600.00
14400A	2017-06-30 22:37:00+03	86600.00
1440A7	2017-07-01 13:53:00+03	171900.00
1440B9	2017-08-04 07:38:00+03	22600.00
1440C0	2017-07-11 07:53:00+03	37700.00
1440F6	2017-07-01 00:16:00+03	135600.00
14415B	2017-07-15 09:55:00+03	46000.00
144166	2017-07-20 23:03:00+03	177200.00
14417B	2017-07-15 10:15:00+03	92800.00
1441A0	2017-07-22 02:46:00+03	97700.00
144240	2017-07-11 16:52:00+03	119300.00
14424F	2017-07-08 08:28:00+03	409100.00
14426E	2017-07-02 09:21:00+03	37200.00
144296	2017-07-27 14:26:00+03	6700.00
14429D	2017-07-13 17:16:00+03	114400.00
1442C1	2017-07-22 09:02:00+03	246000.00
144312	2017-08-06 18:18:00+03	26100.00
144318	2017-07-28 16:02:00+03	136200.00
144332	2017-07-28 00:31:00+03	174600.00
144333	2017-07-10 16:33:00+03	118600.00
144377	2017-08-11 04:33:00+03	23600.00
1443A0	2017-06-30 00:40:00+03	159100.00
1443E1	2017-07-21 23:43:00+03	17200.00
144404	2017-07-01 07:49:00+03	25600.00
14447D	2017-07-13 03:19:00+03	65400.00
144503	2017-08-12 12:07:00+03	26800.00
144515	2017-07-24 17:33:00+03	33800.00
144600	2017-07-06 14:46:00+03	38400.00
14467C	2017-08-13 21:28:00+03	192100.00
1446BF	2017-08-07 17:04:00+03	20000.00
1446E7	2017-07-27 09:02:00+03	25800.00
144721	2017-07-27 16:06:00+03	18400.00
144739	2017-07-30 07:03:00+03	38400.00
14477C	2017-08-12 04:35:00+03	148200.00
1447BC	2017-07-10 11:00:00+03	131600.00
1447D8	2017-08-10 13:40:00+03	56800.00
144807	2017-07-14 16:59:00+03	97100.00
144845	2017-07-26 10:35:00+03	119500.00
144981	2017-08-15 11:25:00+03	75600.00
1449D3	2017-08-02 17:54:00+03	173200.00
144A66	2017-07-28 02:42:00+03	46300.00
144A96	2017-07-18 06:05:00+03	67400.00
144AE2	2017-08-08 11:32:00+03	28800.00
144AE4	2017-08-01 00:17:00+03	35800.00
144B10	2017-08-13 08:59:00+03	18600.00
144B17	2017-08-11 10:25:00+03	224000.00
144B35	2017-07-03 06:20:00+03	6700.00
144B54	2017-08-05 05:14:00+03	28000.00
144B6A	2017-07-23 09:15:00+03	28000.00
144B90	2017-07-06 06:48:00+03	47400.00
144BAB	2017-07-29 10:10:00+03	85000.00
144BAE	2017-07-13 09:33:00+03	88800.00
144BBD	2017-07-04 03:58:00+03	62900.00
144BC8	2017-07-02 03:53:00+03	36200.00
144C3C	2017-08-06 00:22:00+03	23200.00
144C5A	2017-07-07 21:00:00+03	418800.00
144C80	2017-08-01 00:57:00+03	38800.00
144C89	2017-08-13 11:29:00+03	23900.00
144C8F	2017-08-04 00:59:00+03	8200.00
144D01	2017-08-04 22:00:00+03	118700.00
144D78	2017-08-05 21:49:00+03	75600.00
144DED	2017-07-16 10:49:00+03	60700.00
144E4B	2017-07-02 19:28:00+03	224000.00
144ED6	2017-08-12 05:16:00+03	15000.00
144EDE	2017-08-14 06:36:00+03	56000.00
144F0C	2017-08-04 09:52:00+03	51900.00
144F16	2017-08-04 19:45:00+03	132800.00
144F39	2017-07-29 12:29:00+03	32400.00
144F3A	2017-07-02 07:47:00+03	14000.00
144F5F	2017-07-18 12:33:00+03	16400.00
144F60	2017-07-20 11:55:00+03	92700.00
144F93	2017-07-12 17:44:00+03	72400.00
144FCB	2017-08-03 17:06:00+03	20200.00
145035	2017-07-10 13:00:00+03	107400.00
145086	2017-08-09 15:15:00+03	143600.00
14508C	2017-07-05 23:53:00+03	39200.00
145096	2017-07-21 17:45:00+03	168000.00
14510D	2017-08-14 09:15:00+03	75300.00
145122	2017-07-11 10:09:00+03	56600.00
145232	2017-08-08 07:09:00+03	111600.00
145244	2017-07-28 18:56:00+03	151400.00
145276	2017-08-08 04:00:00+03	13400.00
145288	2017-07-30 18:36:00+03	21800.00
1452AC	2017-07-18 16:50:00+03	92400.00
1452D9	2017-08-07 20:36:00+03	7300.00
1452FE	2017-08-09 09:49:00+03	25400.00
14530A	2017-08-03 17:34:00+03	36400.00
145378	2017-07-12 20:28:00+03	14000.00
1453BD	2017-08-07 13:02:00+03	139100.00
145426	2017-07-31 03:50:00+03	53600.00
14544C	2017-07-13 16:32:00+03	271400.00
14549D	2017-08-08 10:17:00+03	56000.00
1454BD	2017-07-13 22:12:00+03	38200.00
1454FD	2017-07-22 12:30:00+03	14000.00
145559	2017-07-04 08:31:00+03	28000.00
145563	2017-07-18 12:18:00+03	94700.00
145571	2017-07-14 05:52:00+03	172800.00
1455E3	2017-08-01 05:18:00+03	398600.00
14562E	2017-08-13 01:43:00+03	46500.00
14563C	2017-07-26 22:35:00+03	52000.00
14568D	2017-07-21 19:28:00+03	58000.00
1456DB	2017-06-29 21:40:00+03	39800.00
145721	2017-07-08 15:08:00+03	173500.00
145728	2017-07-18 09:34:00+03	14800.00
1457CF	2017-07-28 03:36:00+03	24400.00
1457D0	2017-07-09 16:51:00+03	23900.00
14581D	2017-07-23 03:09:00+03	6000.00
145830	2017-07-24 01:15:00+03	21400.00
145833	2017-07-14 22:37:00+03	69500.00
145853	2017-07-03 17:45:00+03	24500.00
1458EF	2017-07-25 13:44:00+03	28000.00
145957	2017-06-29 03:02:00+03	18200.00
1459AB	2017-08-07 12:51:00+03	40000.00
145A27	2017-07-20 15:08:00+03	41300.00
145A72	2017-07-19 06:24:00+03	96300.00
145A76	2017-07-20 12:36:00+03	72400.00
145A8A	2017-07-07 19:37:00+03	31100.00
145AA3	2017-07-13 15:06:00+03	23600.00
145AAE	2017-08-07 21:46:00+03	13000.00
145AE9	2017-07-25 12:14:00+03	36400.00
145B02	2017-07-11 02:23:00+03	92800.00
145B14	2017-08-05 17:03:00+03	8400.00
145B20	2017-08-09 22:38:00+03	14400.00
145B76	2017-08-13 03:42:00+03	26700.00
145B96	2017-08-10 14:50:00+03	242600.00
145BCA	2017-08-05 01:11:00+03	36800.00
145BE0	2017-07-26 20:47:00+03	45100.00
145C3C	2017-07-28 09:14:00+03	14400.00
145C40	2017-08-05 04:01:00+03	83000.00
145C79	2017-07-28 20:42:00+03	26600.00
145CA6	2017-08-08 15:51:00+03	239100.00
145CD0	2017-07-21 23:15:00+03	105000.00
145D28	2017-07-28 17:15:00+03	17800.00
145D2B	2017-08-03 08:32:00+03	141600.00
145D9D	2017-07-31 16:38:00+03	113000.00
145DA8	2017-08-03 22:47:00+03	56600.00
145E33	2017-08-01 22:17:00+03	308300.00
145E37	2017-07-31 04:06:00+03	141600.00
145E44	2017-08-13 03:54:00+03	49200.00
145E9B	2017-08-07 03:09:00+03	14800.00
145E9C	2017-07-05 19:43:00+03	177500.00
145EAC	2017-07-24 17:18:00+03	25800.00
145F01	2017-07-20 00:08:00+03	34000.00
145FFE	2017-07-12 10:35:00+03	26000.00
146059	2017-07-21 15:26:00+03	83500.00
146072	2017-07-19 20:16:00+03	167400.00
1460BB	2017-07-11 11:45:00+03	22000.00
1460CD	2017-08-05 19:31:00+03	37800.00
1460F2	2017-07-03 23:28:00+03	55500.00
1460FE	2017-07-18 11:55:00+03	28800.00
14617B	2017-08-07 18:18:00+03	119800.00
146187	2017-07-09 12:19:00+03	111600.00
14618E	2017-08-15 06:17:00+03	39100.00
146263	2017-08-05 23:50:00+03	273600.00
146272	2017-08-07 16:54:00+03	17000.00
14629A	2017-07-10 03:46:00+03	204500.00
1462B8	2017-08-10 06:59:00+03	185800.00
14630E	2017-08-06 06:21:00+03	6000.00
146310	2017-07-13 07:25:00+03	16400.00
146327	2017-07-06 02:56:00+03	35700.00
1463CD	2017-07-09 04:13:00+03	193500.00
146466	2017-07-25 21:14:00+03	72300.00
146478	2017-07-18 22:46:00+03	92800.00
14647F	2017-08-04 12:23:00+03	79600.00
1464AA	2017-08-04 20:09:00+03	58200.00
1464D7	2017-08-11 08:38:00+03	66000.00
14654B	2017-07-17 12:34:00+03	277900.00
14655E	2017-07-24 21:16:00+03	89700.00
146637	2017-08-13 09:45:00+03	135000.00
146655	2017-07-15 13:18:00+03	25200.00
146669	2017-07-31 07:37:00+03	126000.00
1466C2	2017-07-07 15:20:00+03	22100.00
1466CB	2017-08-10 00:51:00+03	18400.00
1466D0	2017-07-11 10:09:00+03	299200.00
146734	2017-07-18 18:46:00+03	131100.00
146778	2017-07-22 14:20:00+03	384400.00
1467BD	2017-07-24 20:15:00+03	46800.00
1467DB	2017-08-14 04:59:00+03	46000.00
146892	2017-07-20 21:27:00+03	57500.00
1468F4	2017-07-15 14:36:00+03	147000.00
146938	2017-07-12 20:51:00+03	53600.00
146940	2017-08-14 06:12:00+03	16400.00
146992	2017-07-10 05:18:00+03	42800.00
1469A6	2017-08-13 10:23:00+03	246000.00
1469AE	2017-07-01 07:03:00+03	11600.00
1469CF	2017-07-13 22:56:00+03	22000.00
1469FD	2017-08-05 01:23:00+03	68400.00
146A3F	2017-08-11 07:15:00+03	56000.00
146A77	2017-07-05 07:07:00+03	45100.00
146A7C	2017-07-28 05:22:00+03	25600.00
146AC7	2017-07-15 12:12:00+03	75300.00
146B4D	2017-07-11 18:21:00+03	58000.00
146BB7	2017-07-31 01:29:00+03	30000.00
146BCE	2017-07-29 08:50:00+03	34000.00
146C23	2017-07-19 22:47:00+03	73600.00
146C7C	2017-08-02 02:13:00+03	155600.00
146C7E	2017-07-24 07:05:00+03	32700.00
146C9A	2017-08-10 22:20:00+03	13600.00
146D62	2017-07-12 18:02:00+03	114600.00
146DC0	2017-08-13 13:55:00+03	69600.00
146DF7	2017-07-17 23:37:00+03	180000.00
146E3E	2017-07-12 06:10:00+03	62800.00
146E89	2017-07-23 20:26:00+03	47900.00
146E99	2017-08-09 20:03:00+03	127300.00
146ED6	2017-08-12 05:13:00+03	8400.00
146F26	2017-08-08 00:41:00+03	56000.00
146F3C	2017-07-30 14:52:00+03	46000.00
146FAA	2017-07-29 23:11:00+03	201200.00
146FD3	2017-07-07 11:40:00+03	97700.00
147017	2017-07-11 13:00:00+03	92800.00
147088	2017-07-20 11:31:00+03	43000.00
147093	2017-08-10 10:44:00+03	71900.00
147095	2017-07-05 19:54:00+03	89600.00
1470EA	2017-08-02 22:56:00+03	44600.00
14710E	2017-08-03 11:17:00+03	8400.00
147159	2017-08-04 21:58:00+03	125600.00
1471A2	2017-06-29 16:03:00+03	16400.00
1471BC	2017-07-19 14:59:00+03	175800.00
147215	2017-08-06 05:39:00+03	26000.00
14721A	2017-08-01 12:59:00+03	130800.00
147227	2017-07-18 19:28:00+03	52000.00
147266	2017-08-08 06:27:00+03	46000.00
1472B0	2017-07-25 10:52:00+03	193000.00
1472C2	2017-07-25 16:54:00+03	89700.00
147306	2017-07-07 06:55:00+03	140900.00
147335	2017-08-11 20:48:00+03	65900.00
147347	2017-07-13 20:17:00+03	22000.00
147356	2017-08-13 07:05:00+03	61900.00
14737E	2017-08-15 09:55:00+03	22400.00
14741F	2017-07-18 05:22:00+03	56000.00
147476	2017-07-16 13:47:00+03	242000.00
1474A4	2017-08-15 00:28:00+03	16000.00
1474E2	2017-08-02 17:53:00+03	28300.00
1474F3	2017-07-30 17:17:00+03	190700.00
147500	2017-08-10 02:28:00+03	19600.00
14753A	2017-07-09 15:40:00+03	83100.00
14755F	2017-07-03 16:45:00+03	56300.00
147561	2017-07-12 20:20:00+03	11800.00
147566	2017-07-17 16:17:00+03	413500.00
14758A	2017-07-16 04:59:00+03	108300.00
1475AB	2017-07-01 15:56:00+03	67400.00
1475F5	2017-07-08 18:40:00+03	35200.00
14760A	2017-08-08 09:57:00+03	7200.00
14769C	2017-07-06 09:02:00+03	246000.00
1476AA	2017-08-13 20:51:00+03	28000.00
14778E	2017-08-10 08:29:00+03	112000.00
14779F	2017-08-14 14:47:00+03	92600.00
14782D	2017-08-12 22:53:00+03	12600.00
147859	2017-07-06 22:46:00+03	128100.00
147879	2017-08-08 09:23:00+03	23200.00
1478D1	2017-07-12 20:35:00+03	58000.00
1478DB	2017-07-08 08:20:00+03	28000.00
1478F2	2017-07-04 07:12:00+03	56000.00
147907	2017-07-16 03:06:00+03	419100.00
147924	2017-07-07 13:01:00+03	26800.00
14793B	2017-07-27 23:58:00+03	62000.00
147956	2017-07-30 14:58:00+03	6000.00
147A13	2017-07-29 14:54:00+03	70700.00
147A84	2017-08-15 14:51:00+03	28000.00
147A9C	2017-07-29 11:37:00+03	99200.00
147AF2	2017-08-12 08:14:00+03	52000.00
147B05	2017-07-31 07:09:00+03	28000.00
147B09	2017-07-02 19:47:00+03	69000.00
147B1F	2017-07-24 19:49:00+03	86400.00
147B2F	2017-08-07 21:46:00+03	47500.00
147B85	2017-07-28 00:56:00+03	19600.00
147B8A	2017-08-13 09:40:00+03	52800.00
147BA9	2017-07-08 17:47:00+03	52400.00
147BE1	2017-07-25 12:11:00+03	369000.00
147C8D	2017-08-10 22:14:00+03	12400.00
147CEF	2017-07-22 23:54:00+03	66800.00
147D97	2017-07-31 16:03:00+03	68000.00
147DEB	2017-08-12 14:14:00+03	75800.00
147E54	2017-07-13 02:58:00+03	20100.00
147E89	2017-08-12 11:45:00+03	24400.00
147E9C	2017-07-27 18:37:00+03	30100.00
147EF9	2017-08-07 11:28:00+03	85400.00
147F35	2017-07-29 12:56:00+03	32800.00
147F7F	2017-08-03 22:33:00+03	167500.00
147FB1	2017-07-23 02:27:00+03	39800.00
1480AF	2017-07-29 09:41:00+03	111600.00
1480E8	2017-07-13 02:14:00+03	84500.00
1480FB	2017-07-12 23:33:00+03	57400.00
148136	2017-08-03 08:16:00+03	122100.00
14817B	2017-07-08 11:45:00+03	57500.00
1481C3	2017-07-14 22:48:00+03	89600.00
1481EE	2017-08-04 18:57:00+03	56600.00
1482DC	2017-08-13 01:56:00+03	123000.00
14835D	2017-07-31 21:09:00+03	40600.00
148379	2017-08-04 14:29:00+03	53500.00
14838F	2017-07-13 19:23:00+03	25000.00
1483C5	2017-07-06 10:19:00+03	102700.00
1483CA	2017-08-02 04:29:00+03	118000.00
1483D2	2017-08-04 12:51:00+03	6600.00
148454	2017-07-27 07:45:00+03	131100.00
148469	2017-08-01 15:39:00+03	84000.00
14846C	2017-08-13 07:58:00+03	64400.00
148471	2017-07-06 13:57:00+03	23200.00
1484F9	2017-07-27 08:24:00+03	23200.00
148510	2017-07-12 02:54:00+03	45200.00
14853A	2017-07-03 16:45:00+03	45200.00
148625	2017-07-02 15:42:00+03	56000.00
148650	2017-07-08 07:31:00+03	31000.00
1486AD	2017-07-09 08:16:00+03	83100.00
1486D7	2017-08-12 06:45:00+03	66200.00
148701	2017-07-23 03:39:00+03	279000.00
14870D	2017-07-01 02:41:00+03	68000.00
148733	2017-08-05 22:02:00+03	58200.00
148787	2017-07-10 02:00:00+03	105600.00
148791	2017-08-01 19:20:00+03	285000.00
148795	2017-07-08 08:21:00+03	349600.00
1487B7	2017-07-21 10:19:00+03	46500.00
1487D5	2017-07-05 16:02:00+03	40000.00
1487D9	2017-07-20 06:26:00+03	90800.00
148871	2017-07-11 19:09:00+03	27600.00
148886	2017-08-04 20:11:00+03	27900.00
1488AA	2017-08-04 07:16:00+03	55800.00
1488C8	2017-08-14 07:19:00+03	11600.00
148937	2017-07-22 07:08:00+03	397100.00
148978	2017-07-02 01:33:00+03	19600.00
14897B	2017-08-01 14:58:00+03	11600.00
1489D2	2017-08-05 18:10:00+03	120700.00
148A0C	2017-07-13 05:08:00+03	26000.00
148A15	2017-07-17 11:31:00+03	11600.00
148ABA	2017-07-22 02:41:00+03	298400.00
148B20	2017-08-04 09:35:00+03	192700.00
148B59	2017-08-14 14:26:00+03	19600.00
148B96	2017-07-16 02:00:00+03	4000.00
148C34	2017-08-06 15:19:00+03	26800.00
148C46	2017-07-12 15:09:00+03	813500.00
148C8E	2017-07-11 21:03:00+03	75600.00
148C95	2017-07-02 08:00:00+03	140900.00
148CA0	2017-08-07 01:02:00+03	131800.00
148CBA	2017-08-08 06:14:00+03	56200.00
148CBF	2017-07-22 06:21:00+03	130800.00
148CC8	2017-08-06 21:48:00+03	23200.00
148CD7	2017-08-13 18:31:00+03	46400.00
148D98	2017-08-03 07:14:00+03	277800.00
148DAC	2017-08-14 01:31:00+03	26400.00
148DC7	2017-08-12 22:11:00+03	14000.00
148E47	2017-08-05 13:08:00+03	122600.00
148EFA	2017-08-07 23:10:00+03	186900.00
148EFD	2017-07-22 12:51:00+03	540400.00
148F00	2017-08-03 21:01:00+03	99200.00
148F27	2017-07-24 18:51:00+03	28000.00
148F36	2017-08-08 21:50:00+03	16400.00
148FA4	2017-07-26 16:07:00+03	68400.00
148FC0	2017-07-23 06:54:00+03	123000.00
148FD9	2017-07-17 20:02:00+03	147000.00
149004	2017-07-30 04:10:00+03	58600.00
149031	2017-07-12 18:53:00+03	31100.00
149054	2017-07-10 05:27:00+03	67800.00
149085	2017-07-11 11:10:00+03	20200.00
1490E6	2017-07-21 08:53:00+03	92800.00
149148	2017-07-13 22:31:00+03	93400.00
1491F2	2017-07-30 22:40:00+03	133200.00
149217	2017-07-08 10:24:00+03	238700.00
149237	2017-07-17 13:02:00+03	10100.00
149271	2017-07-21 00:44:00+03	47400.00
14927C	2017-07-26 14:34:00+03	124200.00
149345	2017-07-06 18:25:00+03	12000.00
149352	2017-07-13 17:03:00+03	80000.00
1493D2	2017-08-09 11:59:00+03	59600.00
149474	2017-08-03 11:57:00+03	36000.00
14947C	2017-08-14 09:22:00+03	67200.00
14949E	2017-07-18 10:07:00+03	55800.00
1494FD	2017-08-09 00:10:00+03	196800.00
149566	2017-07-16 22:30:00+03	14400.00
149577	2017-07-10 21:14:00+03	135400.00
14964D	2017-07-24 16:35:00+03	44000.00
14966D	2017-08-05 20:41:00+03	124000.00
149687	2017-07-24 07:56:00+03	43200.00
149709	2017-08-10 09:52:00+03	14000.00
149756	2017-07-09 20:55:00+03	89700.00
14975D	2017-08-13 07:00:00+03	34400.00
149768	2017-07-10 20:16:00+03	170300.00
149773	2017-07-07 11:25:00+03	13400.00
1497A6	2017-07-17 22:42:00+03	44700.00
1497D6	2017-07-13 23:30:00+03	24200.00
1497F4	2017-07-24 10:03:00+03	32700.00
1498D0	2017-07-12 00:47:00+03	61900.00
1498F7	2017-07-31 01:52:00+03	47200.00
1498FE	2017-07-29 21:25:00+03	62600.00
14998F	2017-07-29 23:24:00+03	28600.00
1499F6	2017-07-29 14:32:00+03	111600.00
149A3C	2017-07-04 08:43:00+03	54100.00
149A5D	2017-08-08 11:53:00+03	70200.00
149AA5	2017-07-10 08:30:00+03	494000.00
149AB8	2017-07-22 16:33:00+03	48500.00
149ACA	2017-07-15 21:56:00+03	35800.00
149B0F	2017-08-06 00:15:00+03	66600.00
149C64	2017-07-19 02:33:00+03	35700.00
149D5D	2017-07-17 11:00:00+03	26800.00
149D97	2017-07-10 19:17:00+03	211600.00
149DA6	2017-07-06 23:02:00+03	29600.00
149DB1	2017-07-18 03:44:00+03	89700.00
149E71	2017-08-10 16:23:00+03	14000.00
149EA2	2017-07-18 11:27:00+03	32800.00
149F1F	2017-08-02 22:16:00+03	46000.00
149F21	2017-07-26 23:33:00+03	112000.00
149FBB	2017-07-06 19:25:00+03	63400.00
149FE2	2017-08-08 08:44:00+03	92400.00
14A07A	2017-08-12 04:03:00+03	45200.00
14A0A6	2017-07-28 09:09:00+03	56000.00
14A0A7	2017-07-08 08:17:00+03	39800.00
14A0CE	2017-08-03 17:13:00+03	18600.00
14A192	2017-08-06 17:49:00+03	139400.00
14A1A4	2017-07-16 21:45:00+03	27200.00
14A1F7	2017-07-27 06:31:00+03	104600.00
14A247	2017-07-19 05:49:00+03	130800.00
14A277	2017-07-06 23:33:00+03	89700.00
14A2D6	2017-07-25 23:59:00+03	43000.00
14A2FD	2017-08-03 00:34:00+03	38400.00
14A310	2017-07-11 12:10:00+03	28000.00
14A313	2017-08-15 04:20:00+03	278400.00
14A32F	2017-07-26 07:01:00+03	24400.00
14A33D	2017-08-09 07:23:00+03	64300.00
14A350	2017-07-25 05:42:00+03	44600.00
14A38C	2017-07-20 04:10:00+03	70700.00
14A3EB	2017-07-10 23:15:00+03	40800.00
14A47A	2017-07-26 11:00:00+03	19600.00
14A4A7	2017-08-07 22:59:00+03	46500.00
14A4DA	2017-07-26 12:40:00+03	92800.00
14A4FC	2017-08-11 01:44:00+03	30400.00
14A54C	2017-08-09 14:24:00+03	134400.00
14A55C	2017-07-27 06:54:00+03	29600.00
14A5C6	2017-07-05 11:08:00+03	46400.00
14A5CF	2017-08-05 00:56:00+03	46000.00
14A5E0	2017-07-05 18:15:00+03	28000.00
14A5E6	2017-08-13 17:07:00+03	10800.00
14A5EC	2017-07-02 12:20:00+03	132800.00
14A609	2017-07-20 02:43:00+03	134000.00
14A679	2017-08-13 18:51:00+03	90400.00
14A6C1	2017-08-02 09:26:00+03	57500.00
14A718	2017-07-17 23:04:00+03	27800.00
14A73E	2017-08-08 10:03:00+03	32500.00
14A748	2017-08-02 13:26:00+03	103600.00
14A836	2017-08-06 05:57:00+03	12400.00
14A843	2017-08-04 21:54:00+03	15100.00
14A895	2017-08-11 08:23:00+03	8000.00
14A8BC	2017-08-07 03:04:00+03	16800.00
14A940	2017-07-23 20:26:00+03	27800.00
14A943	2017-07-07 07:47:00+03	60400.00
14A95F	2017-07-28 13:48:00+03	85800.00
14A972	2017-07-29 14:31:00+03	55800.00
14A9B2	2017-07-26 07:26:00+03	20200.00
14AA52	2017-07-26 17:55:00+03	12600.00
14AAA0	2017-07-06 03:56:00+03	133200.00
14AABF	2017-08-02 12:54:00+03	184300.00
14AB01	2017-07-29 04:30:00+03	7300.00
14ABDE	2017-08-13 18:08:00+03	85000.00
14AC0E	2017-08-10 23:33:00+03	55800.00
14AC36	2017-08-11 03:30:00+03	13400.00
14AC96	2017-08-13 01:42:00+03	149200.00
14ACA4	2017-08-09 17:58:00+03	134800.00
14ACEA	2017-08-01 07:26:00+03	38400.00
14AD14	2017-07-03 22:48:00+03	42800.00
14AD16	2017-06-30 13:42:00+03	30100.00
14AD3A	2017-08-04 10:45:00+03	16400.00
14AD43	2017-07-08 09:39:00+03	41200.00
14ADB3	2017-07-28 05:32:00+03	13600.00
14ADD1	2017-07-07 05:42:00+03	75300.00
14ADE5	2017-07-20 01:45:00+03	10100.00
14AE3E	2017-08-10 21:38:00+03	252200.00
14AE5C	2017-08-09 10:27:00+03	48800.00
14AE99	2017-07-15 16:11:00+03	47400.00
14AEA0	2017-08-07 04:22:00+03	37900.00
14AEF9	2017-07-13 10:00:00+03	194200.00
14AF40	2017-07-07 04:02:00+03	204500.00
14AF86	2017-08-10 19:13:00+03	31700.00
14B04B	2017-07-30 08:25:00+03	25400.00
14B067	2017-07-05 12:17:00+03	85000.00
14B098	2017-08-04 20:17:00+03	34000.00
14B0A0	2017-07-04 13:46:00+03	13400.00
14B0B2	2017-07-02 21:43:00+03	137600.00
14B0BE	2017-08-14 19:49:00+03	43600.00
14B10D	2017-07-21 05:27:00+03	112600.00
14B111	2017-07-17 05:29:00+03	88800.00
14B177	2017-07-05 19:18:00+03	30000.00
14B18B	2017-07-12 18:28:00+03	51600.00
14B1B1	2017-08-14 07:22:00+03	18600.00
14B1E6	2017-08-08 01:25:00+03	75600.00
14B225	2017-07-06 19:37:00+03	172100.00
14B27B	2017-07-12 01:49:00+03	140900.00
14B2A1	2017-08-14 01:35:00+03	92800.00
14B2A8	2017-07-13 13:22:00+03	71800.00
14B32A	2017-07-25 08:27:00+03	10600.00
14B363	2017-08-11 05:17:00+03	80000.00
14B376	2017-07-07 08:41:00+03	6300.00
14B377	2017-07-11 23:05:00+03	114900.00
14B379	2017-07-29 09:13:00+03	93900.00
14B398	2017-07-30 00:04:00+03	113900.00
14B3F4	2017-07-10 02:23:00+03	39300.00
14B40C	2017-08-02 01:31:00+03	40800.00
14B43B	2017-07-11 20:54:00+03	28000.00
14B499	2017-07-06 09:22:00+03	52100.00
14B579	2017-08-12 10:20:00+03	38600.00
14B599	2017-07-18 10:35:00+03	28000.00
14B5E9	2017-07-29 00:24:00+03	39800.00
14B602	2017-07-27 05:35:00+03	199200.00
14B619	2017-08-09 02:35:00+03	46400.00
14B65F	2017-07-03 15:33:00+03	26200.00
14B712	2017-08-01 16:10:00+03	11800.00
14B72F	2017-08-14 10:41:00+03	188100.00
14B7C2	2017-07-09 04:28:00+03	23200.00
14B7FA	2017-07-19 23:06:00+03	136800.00
14B81B	2017-07-08 05:34:00+03	88100.00
14B82A	2017-08-08 14:44:00+03	131600.00
14B833	2017-07-26 08:32:00+03	64600.00
14B846	2017-07-18 00:42:00+03	357600.00
14B871	2017-06-29 14:43:00+03	46200.00
14B8B1	2017-07-28 00:19:00+03	153200.00
14B8F4	2017-07-10 13:47:00+03	133200.00
14B902	2017-07-22 01:30:00+03	44800.00
14B942	2017-07-13 09:12:00+03	9200.00
14B97E	2017-07-30 17:20:00+03	123700.00
14B99E	2017-07-13 15:06:00+03	55600.00
14B9A4	2017-08-04 12:10:00+03	119400.00
14B9AE	2017-08-14 10:52:00+03	59200.00
14B9CB	2017-08-15 02:35:00+03	26800.00
14BA44	2017-07-13 22:45:00+03	13400.00
14BA5F	2017-07-29 13:41:00+03	81600.00
14BAF2	2017-07-30 01:02:00+03	30000.00
14BB44	2017-07-12 00:12:00+03	95200.00
14BB97	2017-08-04 08:08:00+03	24800.00
14BB9C	2017-07-13 16:56:00+03	46300.00
14BBDE	2017-07-24 01:50:00+03	56000.00
14BC48	2017-08-08 14:04:00+03	36200.00
14BCBA	2017-07-09 11:05:00+03	93900.00
14BCD3	2017-07-25 14:59:00+03	131100.00
14BCFA	2017-07-01 01:52:00+03	52400.00
14BD1B	2017-07-18 20:18:00+03	25100.00
14BD43	2017-07-19 00:29:00+03	51000.00
14BD50	2017-07-03 11:52:00+03	34000.00
14BD73	2017-08-08 17:09:00+03	80300.00
14BD8F	2017-08-12 01:48:00+03	119500.00
14BDF5	2017-08-09 08:23:00+03	28000.00
14BE16	2017-07-08 11:24:00+03	37200.00
14BEB8	2017-07-14 15:16:00+03	51800.00
14BF00	2017-08-02 00:47:00+03	62900.00
14BF19	2017-07-11 18:45:00+03	91200.00
14BF1A	2017-07-12 21:41:00+03	66600.00
14BF36	2017-08-07 12:17:00+03	19500.00
14BF74	2017-08-08 07:50:00+03	266300.00
14BFC6	2017-07-06 20:27:00+03	64200.00
14C016	2017-08-06 10:18:00+03	9200.00
14C188	2017-07-07 21:24:00+03	34100.00
14C1D5	2017-06-30 10:05:00+03	42000.00
14C1DE	2017-07-11 11:36:00+03	136800.00
14C20F	2017-07-21 09:49:00+03	28000.00
14C23C	2017-08-06 08:56:00+03	36400.00
14C252	2017-07-29 04:51:00+03	23100.00
14C2F7	2017-07-24 18:54:00+03	138100.00
14C328	2017-07-05 09:13:00+03	27300.00
14C349	2017-08-12 02:50:00+03	135400.00
14C34E	2017-08-03 13:51:00+03	43200.00
14C4AC	2017-07-26 02:27:00+03	28300.00
14C4B1	2017-07-08 21:18:00+03	114800.00
14C4E3	2017-07-22 21:10:00+03	151200.00
14C507	2017-08-07 00:45:00+03	48300.00
14C54F	2017-07-10 04:12:00+03	43600.00
14C573	2017-08-14 18:22:00+03	110800.00
14C581	2017-08-05 11:52:00+03	66000.00
14C5DB	2017-07-13 04:41:00+03	27200.00
14C617	2017-07-21 01:48:00+03	28000.00
14C629	2017-07-31 20:27:00+03	40100.00
14C63B	2017-07-21 20:16:00+03	22000.00
14C656	2017-08-02 15:21:00+03	25000.00
14C665	2017-08-07 12:07:00+03	37100.00
14C6B1	2017-07-03 09:02:00+03	42800.00
14C6CB	2017-07-04 08:05:00+03	46300.00
14C7A2	2017-06-30 05:22:00+03	48800.00
14C830	2017-08-09 09:58:00+03	61800.00
14C91E	2017-07-10 06:47:00+03	23600.00
14C9DD	2017-07-18 01:25:00+03	246000.00
14CA43	2017-07-01 12:36:00+03	54800.00
14CA4A	2017-08-07 01:03:00+03	27300.00
14CA62	2017-07-19 15:54:00+03	28800.00
14CC0A	2017-07-26 16:45:00+03	84500.00
14CC75	2017-07-01 05:38:00+03	108200.00
14CCB3	2017-07-17 14:24:00+03	27200.00
14CD35	2017-08-09 20:50:00+03	9800.00
14CD6C	2017-07-02 11:55:00+03	40100.00
14CE12	2017-07-18 12:44:00+03	123200.00
14CF0F	2017-07-30 04:16:00+03	133100.00
14CF6D	2017-07-13 19:37:00+03	157100.00
14CFBB	2017-08-06 22:10:00+03	73300.00
14CFC0	2017-07-19 01:20:00+03	6700.00
14D002	2017-07-09 11:08:00+03	398500.00
14D01D	2017-07-14 04:12:00+03	6300.00
14D046	2017-07-24 09:24:00+03	6700.00
14D069	2017-08-12 16:02:00+03	128000.00
14D093	2017-07-04 08:31:00+03	129700.00
14D0B6	2017-07-26 15:20:00+03	28000.00
14D12D	2017-08-01 02:34:00+03	12600.00
14D136	2017-07-29 00:20:00+03	55800.00
14D1AD	2017-07-31 19:36:00+03	6000.00
14D235	2017-08-03 00:22:00+03	46500.00
14D274	2017-07-07 11:08:00+03	14100.00
14D2DC	2017-08-12 16:00:00+03	55800.00
14D304	2017-07-14 00:41:00+03	149200.00
14D34D	2017-08-14 14:42:00+03	50000.00
14D389	2017-08-03 10:54:00+03	46200.00
14D3A5	2017-07-23 13:12:00+03	384400.00
14D409	2017-07-22 02:29:00+03	26000.00
14D421	2017-08-05 08:44:00+03	15900.00
14D431	2017-07-19 13:14:00+03	100600.00
14D4A6	2017-07-21 15:02:00+03	46200.00
14D4D7	2017-07-21 22:10:00+03	100600.00
14D4ED	2017-08-13 08:35:00+03	64800.00
14D565	2017-07-14 22:13:00+03	36200.00
14D5F5	2017-08-07 22:59:00+03	49700.00
14D60F	2017-07-31 10:04:00+03	39300.00
14D62B	2017-07-28 03:36:00+03	16400.00
14D660	2017-07-17 06:18:00+03	73500.00
14D678	2017-08-09 10:01:00+03	112000.00
14D76C	2017-08-08 06:18:00+03	16400.00
14D770	2017-07-24 06:06:00+03	123800.00
14D77E	2017-07-15 15:15:00+03	30800.00
14D7D0	2017-08-11 08:18:00+03	52600.00
14D7DF	2017-07-12 10:50:00+03	46400.00
14D841	2017-07-26 18:39:00+03	94600.00
14D855	2017-07-02 14:58:00+03	50600.00
14D8B0	2017-07-29 01:29:00+03	35200.00
14D8D7	2017-08-05 07:52:00+03	75600.00
14D901	2017-08-01 13:28:00+03	28000.00
14D912	2017-08-02 22:44:00+03	93400.00
14D924	2017-07-04 01:17:00+03	137400.00
14D931	2017-07-16 20:25:00+03	13200.00
14D95B	2017-08-08 18:17:00+03	14400.00
14D976	2017-07-31 05:56:00+03	61800.00
14D99A	2017-07-05 07:55:00+03	84100.00
14D9B3	2017-08-11 11:17:00+03	11800.00
14DA1D	2017-07-06 05:56:00+03	114800.00
14DA35	2017-08-09 00:08:00+03	124200.00
14DA3D	2017-07-22 02:07:00+03	23600.00
14DA97	2017-07-19 03:10:00+03	99700.00
14DB61	2017-07-16 19:02:00+03	12600.00
14DB6F	2017-07-13 12:02:00+03	56000.00
14DB8C	2017-07-06 13:14:00+03	117200.00
14DBAD	2017-08-02 03:45:00+03	7400.00
14DBFA	2017-08-09 12:02:00+03	39800.00
14DC34	2017-08-15 11:24:00+03	71600.00
14DC48	2017-08-14 03:56:00+03	113200.00
14DC66	2017-07-20 05:44:00+03	24300.00
14DC96	2017-08-04 09:37:00+03	48800.00
14DCE5	2017-07-02 04:52:00+03	100900.00
14DD1B	2017-07-20 20:09:00+03	43900.00
14DD37	2017-07-02 20:13:00+03	54800.00
14DDA4	2017-07-14 05:58:00+03	36200.00
14DDA9	2017-07-31 15:27:00+03	23200.00
14DDB4	2017-07-11 10:08:00+03	27400.00
14DDD9	2017-07-23 07:46:00+03	26000.00
14DE26	2017-08-15 07:14:00+03	36000.00
14DE2D	2017-07-28 14:13:00+03	113100.00
14DE56	2017-07-11 19:05:00+03	176500.00
14DE64	2017-07-29 17:04:00+03	47800.00
14DEB8	2017-08-05 17:00:00+03	43600.00
14DF42	2017-08-05 05:32:00+03	50600.00
14DF8B	2017-08-04 13:18:00+03	28000.00
14DFBD	2017-08-12 19:54:00+03	65900.00
14DFC1	2017-07-12 17:50:00+03	124200.00
14DFC2	2017-07-22 06:03:00+03	31600.00
14E049	2017-07-01 23:14:00+03	94700.00
14E04C	2017-07-19 22:16:00+03	38400.00
14E070	2017-07-14 23:29:00+03	48800.00
14E0CB	2017-08-08 05:20:00+03	6300.00
14E146	2017-08-12 03:45:00+03	75300.00
14E1AA	2017-07-04 17:37:00+03	37900.00
14E1FC	2017-06-30 21:38:00+03	11800.00
14E23E	2017-07-14 03:08:00+03	70700.00
14E25E	2017-07-24 15:19:00+03	101200.00
14E2B9	2017-08-09 21:25:00+03	25800.00
14E326	2017-08-08 22:57:00+03	20800.00
14E355	2017-08-11 22:37:00+03	19800.00
14E3BF	2017-07-04 06:28:00+03	35200.00
14E42E	2017-07-11 18:16:00+03	46000.00
14E463	2017-08-15 10:16:00+03	21800.00
14E479	2017-07-29 08:26:00+03	134400.00
14E494	2017-08-10 09:07:00+03	97000.00
14E4A0	2017-07-21 20:24:00+03	38400.00
14E542	2017-08-01 16:56:00+03	109600.00
14E5EF	2017-08-07 17:51:00+03	56000.00
14E62C	2017-07-09 00:33:00+03	8400.00
14E63C	2017-08-10 01:07:00+03	34000.00
14E63E	2017-07-30 18:15:00+03	135200.00
14E6B8	2017-08-05 04:37:00+03	46300.00
14E6BF	2017-07-18 19:09:00+03	67100.00
14E6E5	2017-07-19 15:04:00+03	140800.00
14E707	2017-07-25 12:22:00+03	88600.00
14E733	2017-07-10 08:25:00+03	91500.00
14E768	2017-08-07 11:50:00+03	26800.00
14E7DC	2017-08-15 10:41:00+03	19600.00
14E832	2017-07-10 15:10:00+03	6000.00
14E841	2017-07-23 17:25:00+03	188500.00
14E8E8	2017-08-14 16:50:00+03	29400.00
14E8FD	2017-07-28 17:37:00+03	28800.00
14E905	2017-08-04 10:08:00+03	23200.00
14E921	2017-07-11 06:24:00+03	135600.00
14E934	2017-08-13 03:00:00+03	52800.00
14E960	2017-07-30 08:57:00+03	38200.00
14E981	2017-07-14 06:42:00+03	81600.00
14E9A8	2017-07-12 15:52:00+03	6600.00
14E9EA	2017-07-25 17:38:00+03	108500.00
14EA92	2017-08-08 06:16:00+03	47400.00
14EAA2	2017-08-01 06:50:00+03	6800.00
14EADD	2017-07-01 15:24:00+03	28000.00
14EAF1	2017-07-24 04:30:00+03	92800.00
14EB6F	2017-07-29 16:28:00+03	131100.00
14EBBB	2017-07-05 03:29:00+03	46200.00
14EC1A	2017-07-10 01:56:00+03	26800.00
14EC4B	2017-07-13 09:19:00+03	44400.00
14EC51	2017-07-18 13:35:00+03	34000.00
14ECCE	2017-08-07 10:43:00+03	48800.00
14ECD5	2017-07-05 12:52:00+03	47500.00
14ED0B	2017-07-25 02:25:00+03	93000.00
14EDCB	2017-07-13 04:59:00+03	51600.00
14EE04	2017-08-07 06:51:00+03	26000.00
14EE0E	2017-07-27 11:35:00+03	187800.00
14EE55	2017-08-02 00:48:00+03	32200.00
14EE6A	2017-08-10 11:22:00+03	139400.00
14EEE8	2017-08-04 18:53:00+03	104100.00
14EEFC	2017-07-02 18:19:00+03	417000.00
14EFA3	2017-07-05 05:53:00+03	6900.00
14F004	2017-07-03 05:07:00+03	12200.00
14F016	2017-07-16 11:17:00+03	100600.00
14F018	2017-07-11 19:29:00+03	13600.00
14F02C	2017-07-13 07:16:00+03	46300.00
14F033	2017-07-19 09:30:00+03	19600.00
14F08E	2017-06-30 12:50:00+03	25400.00
14F0AD	2017-08-15 03:41:00+03	65900.00
14F0F5	2017-07-24 22:40:00+03	25200.00
14F112	2017-08-13 21:30:00+03	171100.00
14F179	2017-07-04 09:58:00+03	375200.00
14F1BD	2017-07-21 07:20:00+03	119500.00
14F1C0	2017-07-21 22:44:00+03	83400.00
14F1D3	2017-07-14 15:56:00+03	61800.00
14F1FB	2017-07-07 08:57:00+03	56100.00
14F272	2017-08-09 00:09:00+03	36900.00
14F2B6	2017-08-15 11:32:00+03	27400.00
14F2F5	2017-07-27 08:54:00+03	111600.00
14F322	2017-08-15 01:43:00+03	59800.00
14F395	2017-08-04 08:00:00+03	25600.00
14F3BE	2017-07-05 19:57:00+03	8000.00
14F3ED	2017-07-20 15:09:00+03	43600.00
14F431	2017-07-08 23:23:00+03	133200.00
14F45F	2017-07-18 16:56:00+03	40800.00
14F469	2017-07-09 03:35:00+03	32800.00
14F491	2017-08-13 01:44:00+03	98800.00
14F49D	2017-08-08 10:28:00+03	69500.00
14F4AA	2017-07-09 14:40:00+03	28000.00
14F58C	2017-08-03 02:48:00+03	75300.00
14F6A8	2017-07-26 06:56:00+03	255600.00
14F727	2017-07-05 17:19:00+03	129200.00
14F752	2017-07-29 20:11:00+03	90800.00
14F782	2017-08-12 00:27:00+03	34000.00
14F7A9	2017-07-13 13:45:00+03	35300.00
14F801	2017-08-13 22:46:00+03	141000.00
14F836	2017-07-23 20:49:00+03	26700.00
14F85C	2017-07-16 23:00:00+03	56000.00
14F89B	2017-07-11 14:03:00+03	246000.00
14F925	2017-08-08 09:29:00+03	95600.00
14F93A	2017-07-27 04:05:00+03	92000.00
14F964	2017-07-24 08:46:00+03	157200.00
14F9C6	2017-07-19 17:01:00+03	31600.00
14FA7E	2017-07-11 09:37:00+03	40000.00
14FA87	2017-07-23 16:21:00+03	49100.00
14FAE0	2017-07-26 05:37:00+03	56600.00
14FB09	2017-07-18 23:56:00+03	55800.00
14FB6F	2017-08-05 15:34:00+03	64800.00
14FB72	2017-08-12 15:22:00+03	117600.00
14FB73	2017-07-17 02:55:00+03	51900.00
14FB7C	2017-07-21 13:42:00+03	265400.00
14FB7F	2017-07-27 05:52:00+03	102100.00
14FBBD	2017-07-05 08:36:00+03	55800.00
14FBFA	2017-08-09 16:28:00+03	24800.00
14FC43	2017-07-01 21:18:00+03	28000.00
14FC57	2017-07-30 09:29:00+03	70700.00
14FD28	2017-07-05 20:33:00+03	25200.00
14FD57	2017-07-14 17:13:00+03	166000.00
14FDD6	2017-07-31 11:39:00+03	100600.00
14FE20	2017-07-25 10:53:00+03	28700.00
14FE2B	2017-08-06 04:42:00+03	121400.00
14FE74	2017-07-01 13:54:00+03	85000.00
14FEA6	2017-07-13 22:11:00+03	28800.00
14FEC6	2017-08-02 10:39:00+03	67500.00
14FED1	2017-07-30 11:01:00+03	80300.00
14FEE8	2017-08-03 20:17:00+03	40400.00
14FFD5	2017-08-13 04:55:00+03	40000.00
150019	2017-08-14 23:11:00+03	12600.00
150087	2017-08-12 18:31:00+03	36800.00
1500D8	2017-07-28 05:16:00+03	143100.00
15011D	2017-08-03 08:28:00+03	26600.00
1501CA	2017-08-05 22:29:00+03	68100.00
1501F0	2017-07-01 07:28:00+03	53600.00
1501F2	2017-08-10 18:32:00+03	10800.00
1501FB	2017-07-07 12:39:00+03	52600.00
1501FF	2017-06-30 19:03:00+03	45200.00
150227	2017-08-11 12:46:00+03	516600.00
15025E	2017-08-02 08:55:00+03	248300.00
150347	2017-07-18 19:09:00+03	47000.00
150354	2017-07-24 22:38:00+03	123000.00
150368	2017-07-24 06:47:00+03	170600.00
15038C	2017-08-01 03:52:00+03	131100.00
1503A2	2017-08-11 20:31:00+03	49600.00
1503A9	2017-07-06 06:44:00+03	52300.00
150404	2017-08-06 18:06:00+03	149700.00
150411	2017-07-12 08:46:00+03	139400.00
150419	2017-07-18 01:51:00+03	8000.00
150457	2017-07-01 01:07:00+03	66000.00
15049D	2017-08-12 16:20:00+03	198400.00
1505BB	2017-07-11 04:20:00+03	65500.00
1505BF	2017-08-03 13:42:00+03	14000.00
1505D0	2017-07-17 00:43:00+03	40100.00
1505E5	2017-07-10 00:34:00+03	133200.00
1506F5	2017-08-05 16:25:00+03	32000.00
1507E0	2017-06-26 21:02:00+03	42800.00
150836	2017-07-15 04:03:00+03	55600.00
15087B	2017-07-09 01:33:00+03	28800.00
150928	2017-07-19 13:49:00+03	32800.00
150941	2017-07-07 22:32:00+03	66400.00
15095E	2017-08-14 10:04:00+03	28800.00
150983	2017-07-08 03:32:00+03	47100.00
1509BE	2017-07-03 14:14:00+03	34000.00
1509D8	2017-07-15 19:03:00+03	23600.00
150A0B	2017-07-25 19:14:00+03	112600.00
150A44	2017-07-01 10:20:00+03	50300.00
150A8B	2017-07-27 12:17:00+03	46000.00
150ABA	2017-07-05 05:04:00+03	133200.00
150AC2	2017-08-11 09:00:00+03	229400.00
150AE1	2017-07-13 21:06:00+03	61800.00
150AEE	2017-07-07 12:52:00+03	84800.00
150B7C	2017-07-16 13:31:00+03	147000.00
150BF2	2017-07-13 20:47:00+03	55800.00
150C04	2017-08-13 12:31:00+03	280600.00
150C1C	2017-08-02 18:07:00+03	114600.00
150C25	2017-07-04 02:03:00+03	46500.00
150C63	2017-07-22 07:25:00+03	98400.00
150CB9	2017-08-08 11:28:00+03	82200.00
150D81	2017-07-27 10:11:00+03	43200.00
150DD2	2017-07-27 10:37:00+03	46300.00
150E2F	2017-07-23 23:34:00+03	26000.00
150EC8	2017-08-08 18:44:00+03	88800.00
150ECF	2017-07-13 03:26:00+03	15900.00
150F18	2017-07-01 18:41:00+03	6300.00
150F1E	2017-08-05 10:51:00+03	43100.00
150F61	2017-07-18 20:06:00+03	34000.00
150F64	2017-07-20 02:29:00+03	43500.00
150FA3	2017-08-01 19:54:00+03	396500.00
150FBC	2017-07-26 13:33:00+03	13400.00
151022	2017-08-06 19:14:00+03	123600.00
151081	2017-08-11 09:20:00+03	97800.00
1510A9	2017-08-13 21:54:00+03	59000.00
1510E0	2017-07-20 18:23:00+03	69500.00
1510EA	2017-08-12 06:47:00+03	154400.00
1510F2	2017-08-11 11:10:00+03	229400.00
1511C2	2017-07-03 16:32:00+03	19600.00
15126A	2017-07-27 13:41:00+03	126200.00
151293	2017-08-10 04:37:00+03	289800.00
15132F	2017-07-12 10:02:00+03	56100.00
15141A	2017-07-21 02:27:00+03	101200.00
151432	2017-07-05 09:37:00+03	23400.00
151525	2017-08-10 09:33:00+03	92400.00
151552	2017-08-13 12:54:00+03	54400.00
1515B4	2017-07-21 00:14:00+03	39600.00
1515F5	2017-07-12 06:24:00+03	125200.00
151620	2017-08-12 21:42:00+03	136600.00
15167F	2017-07-11 06:23:00+03	29400.00
15169A	2017-07-08 13:00:00+03	6300.00
1516A3	2017-07-09 16:19:00+03	155600.00
1516C4	2017-08-02 08:21:00+03	81200.00
151720	2017-07-28 03:23:00+03	99200.00
151745	2017-07-13 06:35:00+03	28000.00
15174A	2017-07-29 10:45:00+03	29600.00
15176B	2017-07-04 13:23:00+03	433300.00
151786	2017-08-06 18:29:00+03	220100.00
1517F9	2017-07-28 01:49:00+03	58400.00
151800	2017-07-24 13:03:00+03	34600.00
15183C	2017-07-11 05:13:00+03	75600.00
151842	2017-08-05 14:16:00+03	369000.00
1518EC	2017-07-16 14:16:00+03	49300.00
151964	2017-07-31 00:31:00+03	46400.00
1519CE	2017-08-02 03:18:00+03	73300.00
1519E3	2017-07-12 06:20:00+03	61400.00
1519E9	2017-07-06 19:19:00+03	10800.00
151A26	2017-08-08 16:00:00+03	138200.00
151A42	2017-08-05 02:19:00+03	98200.00
151A4B	2017-07-09 03:29:00+03	50400.00
151A52	2017-08-11 12:15:00+03	67200.00
151A8D	2017-07-19 12:01:00+03	44300.00
151AA5	2017-08-13 05:19:00+03	56000.00
151AD5	2017-08-10 11:34:00+03	23400.00
151B2F	2017-08-15 10:04:00+03	76400.00
151C47	2017-08-04 22:31:00+03	81600.00
151C61	2017-08-06 02:35:00+03	111000.00
151CC1	2017-07-08 22:27:00+03	100600.00
151D0F	2017-07-21 20:24:00+03	25600.00
151DE6	2017-08-12 13:56:00+03	82000.00
151DF0	2017-07-22 03:32:00+03	26000.00
151E49	2017-07-24 13:40:00+03	316000.00
151E8E	2017-07-05 04:59:00+03	49400.00
151F38	2017-07-12 02:13:00+03	6300.00
151F65	2017-07-20 18:57:00+03	37900.00
151F8F	2017-08-07 01:28:00+03	55800.00
151F94	2017-08-14 09:17:00+03	25200.00
151FB6	2017-07-08 20:43:00+03	57800.00
1520B0	2017-07-11 00:30:00+03	19800.00
152111	2017-07-08 22:02:00+03	125600.00
15212D	2017-08-15 09:44:00+03	123600.00
15216C	2017-07-06 00:53:00+03	46300.00
152190	2017-07-18 11:14:00+03	135400.00
15219C	2017-08-07 11:39:00+03	99300.00
1521A3	2017-07-27 04:20:00+03	73600.00
152240	2017-07-21 07:10:00+03	24700.00
1522F5	2017-07-10 16:32:00+03	8200.00
152336	2017-07-14 19:16:00+03	28000.00
152346	2017-07-14 02:13:00+03	21400.00
15235E	2017-07-05 22:24:00+03	100000.00
15237C	2017-07-24 17:05:00+03	28800.00
1523DB	2017-07-29 11:59:00+03	69500.00
1523F2	2017-07-26 04:22:00+03	279800.00
152431	2017-07-04 17:14:00+03	99200.00
15257C	2017-08-04 03:06:00+03	35200.00
152593	2017-08-11 23:44:00+03	69000.00
1525AE	2017-07-10 12:48:00+03	84100.00
1525DB	2017-07-22 11:26:00+03	53400.00
15261E	2017-07-14 22:06:00+03	88100.00
152624	2017-07-31 19:01:00+03	135200.00
152638	2017-08-15 13:34:00+03	12600.00
15269D	2017-07-14 17:33:00+03	26200.00
1526B7	2017-07-26 11:59:00+03	59800.00
1527D5	2017-07-21 00:29:00+03	76800.00
1527DC	2017-07-06 22:51:00+03	172600.00
1528D4	2017-07-17 04:25:00+03	16400.00
152971	2017-06-30 20:27:00+03	111600.00
1529B7	2017-07-25 10:13:00+03	14400.00
152A50	2017-06-30 15:39:00+03	43200.00
152A8D	2017-07-18 20:23:00+03	69000.00
152AD8	2017-07-14 17:35:00+03	134400.00
152B19	2017-07-29 00:58:00+03	112000.00
152B55	2017-08-04 02:27:00+03	95900.00
152B67	2017-08-06 03:05:00+03	27400.00
152B78	2017-07-27 10:35:00+03	44100.00
152BCD	2017-07-22 19:53:00+03	31800.00
152BD9	2017-07-29 08:34:00+03	410500.00
152BEA	2017-07-25 12:41:00+03	26000.00
152C8B	2017-07-26 04:11:00+03	26800.00
152CAD	2017-07-25 19:13:00+03	85400.00
152CAE	2017-07-31 11:47:00+03	124200.00
152D0C	2017-07-11 11:36:00+03	41600.00
152D37	2017-07-08 14:38:00+03	515000.00
152D64	2017-07-06 02:43:00+03	202300.00
152DA3	2017-08-08 12:50:00+03	59700.00
152DAA	2017-07-07 20:16:00+03	84500.00
152DD8	2017-07-30 21:07:00+03	52000.00
152E18	2017-07-18 02:20:00+03	55800.00
152E22	2017-07-01 04:31:00+03	131600.00
152E43	2017-07-24 19:01:00+03	43200.00
152E7A	2017-08-02 01:11:00+03	20400.00
152E95	2017-07-28 00:55:00+03	24700.00
152EA5	2017-07-17 07:36:00+03	167400.00
152F28	2017-07-04 03:28:00+03	75300.00
152F2D	2017-08-11 11:06:00+03	50100.00
152F3B	2017-08-11 09:41:00+03	52000.00
152F5D	2017-07-19 13:29:00+03	108400.00
152F61	2017-07-10 02:52:00+03	75600.00
152FEC	2017-08-01 09:52:00+03	40400.00
153037	2017-08-08 10:41:00+03	122400.00
153050	2017-07-13 05:17:00+03	68400.00
153051	2017-07-28 05:19:00+03	26000.00
153078	2017-07-02 12:11:00+03	6800.00
1530B7	2017-07-19 19:04:00+03	42700.00
1530BB	2017-07-11 19:55:00+03	46400.00
1530FA	2017-07-29 08:01:00+03	24400.00
1531A2	2017-07-10 13:12:00+03	100700.00
1531B7	2017-07-31 01:24:00+03	25400.00
1531DD	2017-08-08 09:59:00+03	24000.00
15326F	2017-07-29 17:22:00+03	258000.00
153284	2017-08-12 02:32:00+03	67600.00
1532B0	2017-08-10 14:06:00+03	33000.00
1532FA	2017-07-13 10:26:00+03	91100.00
153334	2017-07-23 10:54:00+03	57800.00
153379	2017-07-11 05:50:00+03	70700.00
153463	2017-08-12 08:23:00+03	25400.00
1535AE	2017-07-17 23:03:00+03	29400.00
1535CB	2017-07-24 20:00:00+03	207700.00
1535CD	2017-07-16 07:23:00+03	59800.00
1536C4	2017-07-02 15:09:00+03	56000.00
1536CC	2017-08-06 02:40:00+03	46200.00
1536CD	2017-08-14 08:29:00+03	89200.00
1536EF	2017-08-12 04:49:00+03	64200.00
153705	2017-08-09 08:56:00+03	8400.00
153728	2017-07-12 19:55:00+03	62100.00
153756	2017-07-18 18:27:00+03	76800.00
1537A5	2017-07-09 05:44:00+03	23200.00
1537B7	2017-08-10 04:59:00+03	18100.00
15381B	2017-07-07 03:50:00+03	89700.00
153874	2017-06-28 15:38:00+03	50400.00
153925	2017-08-09 01:58:00+03	225900.00
153943	2017-08-04 15:04:00+03	37700.00
153969	2017-08-10 20:25:00+03	48700.00
153970	2017-07-22 20:55:00+03	64100.00
153975	2017-08-11 05:21:00+03	39600.00
1539F7	2017-08-13 23:41:00+03	26000.00
153A20	2017-08-03 08:43:00+03	136200.00
153A4C	2017-07-05 20:49:00+03	88500.00
153AD3	2017-07-19 23:13:00+03	83000.00
153B33	2017-07-10 14:52:00+03	66600.00
153B91	2017-07-20 12:58:00+03	28000.00
153B95	2017-07-19 19:41:00+03	61800.00
153BD2	2017-07-27 23:27:00+03	23600.00
153BDB	2017-07-17 17:27:00+03	58800.00
153C0F	2017-07-05 00:06:00+03	517500.00
153C35	2017-08-14 08:43:00+03	15000.00
153C6A	2017-07-21 09:56:00+03	100600.00
153C77	2017-06-27 21:34:00+03	67600.00
153CAD	2017-07-16 09:32:00+03	23200.00
153D3E	2017-08-04 15:16:00+03	55600.00
153D5C	2017-07-17 15:46:00+03	18900.00
153DE2	2017-08-04 05:00:00+03	270000.00
153E30	2017-07-21 13:59:00+03	195900.00
153E32	2017-07-10 02:16:00+03	73600.00
153E42	2017-07-06 10:57:00+03	64600.00
153EB9	2017-08-08 04:21:00+03	14400.00
153EC2	2017-08-14 11:15:00+03	56700.00
153F0B	2017-07-07 23:24:00+03	86600.00
153F2B	2017-07-17 11:36:00+03	99700.00
153F6B	2017-08-08 01:35:00+03	49100.00
153FA0	2017-08-05 20:23:00+03	52000.00
154017	2017-08-03 18:51:00+03	56600.00
154055	2017-06-29 21:36:00+03	119700.00
154085	2017-08-11 01:50:00+03	19200.00
1540E3	2017-08-02 22:30:00+03	266400.00
154107	2017-07-29 09:35:00+03	46300.00
154138	2017-07-15 23:37:00+03	44400.00
15416A	2017-08-05 04:48:00+03	39100.00
154185	2017-08-03 02:47:00+03	65900.00
15419E	2017-07-06 13:39:00+03	67600.00
1541C7	2017-08-15 01:11:00+03	66600.00
1541D0	2017-08-05 06:09:00+03	26000.00
1541E7	2017-07-21 21:04:00+03	137700.00
15424B	2017-08-03 17:38:00+03	46400.00
154290	2017-08-14 01:45:00+03	88900.00
1542B1	2017-07-11 01:15:00+03	58700.00
154307	2017-06-29 03:14:00+03	73500.00
154320	2017-07-29 12:03:00+03	155600.00
154337	2017-08-12 22:45:00+03	26200.00
15434F	2017-07-13 13:29:00+03	40000.00
15435C	2017-08-14 00:23:00+03	48800.00
154423	2017-06-30 17:13:00+03	26000.00
15456D	2017-07-09 20:32:00+03	17800.00
1545BC	2017-07-23 00:45:00+03	24400.00
154610	2017-08-10 21:53:00+03	28800.00
154634	2017-07-13 16:29:00+03	24400.00
154635	2017-08-11 23:49:00+03	28000.00
154692	2017-07-25 09:35:00+03	317200.00
15469E	2017-06-30 11:12:00+03	101200.00
15476C	2017-08-12 20:11:00+03	153000.00
15479E	2017-07-05 12:54:00+03	26000.00
1547E7	2017-08-08 23:09:00+03	6000.00
154833	2017-07-15 22:25:00+03	47000.00
154897	2017-07-08 01:11:00+03	70600.00
1548BA	2017-08-13 22:11:00+03	81600.00
1548CB	2017-07-18 05:37:00+03	28800.00
1548D6	2017-08-03 11:47:00+03	46400.00
154914	2017-08-08 19:36:00+03	196800.00
15492F	2017-07-29 23:16:00+03	187600.00
15493E	2017-08-08 19:16:00+03	13800.00
154977	2017-07-30 09:21:00+03	29200.00
154993	2017-07-23 09:33:00+03	46000.00
154A60	2017-07-26 13:36:00+03	28800.00
154A7D	2017-07-06 02:59:00+03	229600.00
154A99	2017-07-27 10:53:00+03	304200.00
154AC1	2017-07-25 04:57:00+03	49100.00
154AF2	2017-08-02 17:16:00+03	113300.00
154B17	2017-07-05 12:22:00+03	32800.00
154B32	2017-08-14 22:43:00+03	59100.00
154B64	2017-08-03 23:03:00+03	186900.00
154B81	2017-08-14 21:36:00+03	24400.00
154BC3	2017-08-09 20:34:00+03	46000.00
154BD6	2017-08-14 04:52:00+03	46900.00
154D1F	2017-07-11 06:55:00+03	56000.00
154D45	2017-07-05 11:24:00+03	6800.00
154DAB	2017-07-25 08:22:00+03	53200.00
154DBD	2017-07-06 14:20:00+03	6000.00
154DCF	2017-08-15 05:23:00+03	24300.00
154E1D	2017-08-14 19:10:00+03	55800.00
154E6E	2017-08-02 17:17:00+03	36700.00
154F09	2017-08-05 21:26:00+03	81300.00
154F0C	2017-07-31 22:12:00+03	56100.00
154FC2	2017-08-05 11:14:00+03	69600.00
154FD4	2017-08-13 14:37:00+03	94900.00
154FEF	2017-07-31 02:46:00+03	184300.00
155039	2017-07-20 11:23:00+03	54200.00
15506B	2017-08-14 15:43:00+03	42800.00
155074	2017-08-11 14:57:00+03	62000.00
15507C	2017-07-17 02:24:00+03	12600.00
15510E	2017-07-15 00:12:00+03	172100.00
155119	2017-07-05 12:07:00+03	25000.00
15516A	2017-08-08 17:17:00+03	100800.00
155173	2017-08-05 09:30:00+03	135400.00
155188	2017-08-05 13:43:00+03	47600.00
1551A7	2017-08-07 21:40:00+03	99200.00
1551D8	2017-08-04 08:40:00+03	56000.00
155218	2017-08-06 17:36:00+03	286100.00
155269	2017-07-16 03:12:00+03	135400.00
1552A8	2017-07-19 23:14:00+03	94000.00
155303	2017-07-04 03:26:00+03	38700.00
155318	2017-07-06 13:09:00+03	189700.00
15537A	2017-08-07 16:00:00+03	93700.00
155432	2017-07-01 01:57:00+03	86300.00
155460	2017-08-12 09:22:00+03	78900.00
155463	2017-07-09 23:27:00+03	190400.00
1554A8	2017-06-30 20:18:00+03	31100.00
1554CE	2017-08-15 01:53:00+03	124100.00
15550D	2017-08-02 00:38:00+03	69500.00
15551C	2017-07-18 00:51:00+03	24400.00
155545	2017-07-31 08:33:00+03	59200.00
155554	2017-08-05 06:41:00+03	89200.00
155574	2017-08-06 00:06:00+03	28000.00
1555FE	2017-07-22 08:42:00+03	62600.00
155615	2017-07-18 20:46:00+03	67600.00
155697	2017-08-10 07:13:00+03	31200.00
1556FC	2017-07-24 04:13:00+03	56000.00
155712	2017-07-29 21:36:00+03	84500.00
1557DD	2017-07-16 05:01:00+03	26100.00
155866	2017-07-13 10:29:00+03	85000.00
155937	2017-07-20 06:19:00+03	65500.00
155943	2017-07-18 12:36:00+03	71600.00
1559FB	2017-07-05 06:49:00+03	75600.00
155ABE	2017-07-26 14:29:00+03	28800.00
155AEE	2017-07-10 10:19:00+03	81600.00
155B22	2017-07-02 21:16:00+03	77900.00
155B62	2017-08-11 18:49:00+03	10700.00
155B8A	2017-07-13 07:30:00+03	31600.00
155B97	2017-08-04 06:21:00+03	112000.00
155BC2	2017-08-03 03:56:00+03	56000.00
155BCF	2017-07-25 22:34:00+03	112000.00
155BD8	2017-07-14 09:40:00+03	44800.00
155BEA	2017-07-24 09:19:00+03	123000.00
155C63	2017-07-21 10:22:00+03	40000.00
155C66	2017-08-12 11:00:00+03	63000.00
155C6F	2017-08-06 07:37:00+03	138000.00
155C80	2017-07-04 03:46:00+03	31100.00
155C91	2017-07-05 22:03:00+03	67600.00
155CFC	2017-08-07 05:04:00+03	44800.00
155CFD	2017-07-29 04:13:00+03	70600.00
155D23	2017-07-21 04:10:00+03	32400.00
155D3D	2017-07-23 03:23:00+03	149300.00
155D90	2017-08-10 02:45:00+03	131100.00
155DBA	2017-07-12 17:33:00+03	65900.00
155DD2	2017-08-12 11:52:00+03	75300.00
155DD5	2017-07-19 02:56:00+03	34000.00
155DE9	2017-07-06 19:12:00+03	160200.00
155DF4	2017-07-14 16:56:00+03	14000.00
155EA6	2017-07-14 17:54:00+03	26700.00
155ED5	2017-07-30 09:43:00+03	57500.00
155ED6	2017-08-12 17:18:00+03	49800.00
155EE0	2017-07-18 12:48:00+03	45200.00
155F26	2017-07-10 03:43:00+03	47500.00
155F28	2017-06-28 12:31:00+03	26000.00
155F58	2017-07-24 20:34:00+03	28100.00
155F5A	2017-07-20 12:30:00+03	46300.00
155FF1	2017-07-25 10:51:00+03	135400.00
156019	2017-07-19 17:36:00+03	48500.00
156031	2017-07-22 07:21:00+03	43200.00
1560AB	2017-07-02 09:25:00+03	99200.00
1560B8	2017-07-16 06:41:00+03	23400.00
15611A	2017-08-12 09:10:00+03	133200.00
1561D6	2017-07-30 11:49:00+03	106200.00
1561D9	2017-08-14 16:17:00+03	14000.00
156284	2017-07-30 01:08:00+03	20400.00
1562CD	2017-07-13 09:09:00+03	137600.00
1562D8	2017-08-11 12:03:00+03	93900.00
1562E7	2017-07-11 14:37:00+03	58800.00
1562F1	2017-07-19 00:17:00+03	59300.00
156304	2017-07-12 20:57:00+03	15100.00
1563F8	2017-08-01 17:28:00+03	32200.00
1564A2	2017-07-22 23:23:00+03	42400.00
15651B	2017-07-14 10:31:00+03	39500.00
15653A	2017-07-26 01:32:00+03	101200.00
156562	2017-07-10 06:54:00+03	84100.00
15656F	2017-08-13 09:31:00+03	27400.00
15657F	2017-07-28 06:39:00+03	21800.00
15658E	2017-07-16 03:01:00+03	258500.00
15659E	2017-08-01 23:36:00+03	68800.00
1565EE	2017-06-30 21:16:00+03	316000.00
156622	2017-07-16 06:43:00+03	135400.00
1566A0	2017-07-29 17:30:00+03	33100.00
1566B3	2017-07-15 20:21:00+03	101200.00
1566FE	2017-07-26 17:13:00+03	27800.00
15679E	2017-07-11 06:08:00+03	130400.00
1567CF	2017-08-07 17:52:00+03	170000.00
156823	2017-08-15 15:36:00+03	25600.00
15685E	2017-08-08 05:43:00+03	114800.00
1568A9	2017-07-18 19:55:00+03	399600.00
1568BA	2017-07-05 10:42:00+03	41200.00
1568D5	2017-07-19 05:54:00+03	21400.00
156904	2017-07-02 13:46:00+03	233800.00
15690D	2017-07-13 09:26:00+03	14000.00
1569C0	2017-07-08 16:28:00+03	87900.00
156A0B	2017-07-29 05:51:00+03	56000.00
156A55	2017-07-30 04:13:00+03	116800.00
156A6D	2017-07-15 08:34:00+03	19800.00
156A9F	2017-08-13 09:49:00+03	102100.00
156ABC	2017-07-02 18:51:00+03	272400.00
156ADF	2017-07-03 02:49:00+03	75600.00
156AFB	2017-07-27 05:00:00+03	30700.00
156BE2	2017-08-02 11:42:00+03	46900.00
156C41	2017-07-22 11:01:00+03	99200.00
156C9A	2017-08-05 14:10:00+03	130600.00
156CCA	2017-07-09 12:35:00+03	75300.00
156CCB	2017-07-23 14:21:00+03	280000.00
156CDB	2017-07-26 15:41:00+03	127300.00
156DCF	2017-07-15 15:30:00+03	23500.00
156DD3	2017-08-07 05:08:00+03	55800.00
156E45	2017-08-02 17:59:00+03	26000.00
156ED4	2017-08-10 18:12:00+03	81600.00
156EDA	2017-08-05 22:23:00+03	258400.00
156EE4	2017-07-12 21:44:00+03	93900.00
156FA5	2017-07-09 06:31:00+03	418500.00
156FFD	2017-08-14 12:50:00+03	57500.00
157007	2017-07-14 01:54:00+03	32800.00
15701C	2017-08-05 14:38:00+03	174000.00
157043	2017-07-25 18:02:00+03	7400.00
15706B	2017-07-21 16:45:00+03	39600.00
1570E6	2017-07-15 15:54:00+03	71200.00
1570F3	2017-08-05 23:27:00+03	48800.00
1570FA	2017-07-11 02:53:00+03	100600.00
157153	2017-07-07 00:32:00+03	39600.00
157181	2017-07-06 07:21:00+03	140900.00
15721B	2017-07-03 10:57:00+03	29200.00
15722B	2017-07-29 07:37:00+03	62600.00
157260	2017-07-11 03:53:00+03	38400.00
15731E	2017-07-19 14:19:00+03	91600.00
157341	2017-07-06 16:05:00+03	68400.00
157368	2017-07-30 06:32:00+03	201800.00
15737B	2017-07-21 23:56:00+03	49200.00
1573A5	2017-08-09 15:42:00+03	85000.00
1573D4	2017-08-10 03:21:00+03	61700.00
1573DF	2017-07-27 14:57:00+03	6700.00
1574AF	2017-07-18 10:12:00+03	82200.00
1574B8	2017-07-28 15:33:00+03	38600.00
1574C5	2017-07-11 20:33:00+03	101200.00
1574D3	2017-08-04 19:09:00+03	67200.00
15752F	2017-07-29 16:39:00+03	25600.00
157539	2017-07-29 14:30:00+03	62700.00
157547	2017-08-14 14:31:00+03	24400.00
157580	2017-08-10 13:33:00+03	311200.00
1575A5	2017-07-09 07:46:00+03	138600.00
1575A8	2017-08-06 01:37:00+03	96200.00
1575B2	2017-07-20 10:02:00+03	83000.00
157613	2017-07-12 08:34:00+03	79900.00
157627	2017-07-25 11:51:00+03	193600.00
15763D	2017-08-13 10:18:00+03	13600.00
157644	2017-07-18 08:31:00+03	123000.00
157679	2017-07-05 22:52:00+03	36200.00
1576EA	2017-07-28 06:18:00+03	67000.00
157739	2017-07-31 03:56:00+03	163100.00
157766	2017-08-10 22:07:00+03	44000.00
15779F	2017-08-10 22:23:00+03	143200.00
1577AB	2017-07-26 21:32:00+03	81300.00
1577B9	2017-07-14 13:39:00+03	12400.00
1577C0	2017-08-12 07:49:00+03	38200.00
1577E0	2017-07-28 07:28:00+03	65200.00
157825	2017-08-02 21:46:00+03	59800.00
157843	2017-07-22 22:58:00+03	48800.00
157878	2017-08-10 23:53:00+03	18600.00
1578E2	2017-07-12 06:39:00+03	92400.00
157912	2017-07-05 17:44:00+03	23400.00
157917	2017-07-16 11:31:00+03	75300.00
157922	2017-07-24 15:17:00+03	28800.00
15797C	2017-07-07 07:44:00+03	22100.00
1579AF	2017-08-03 05:42:00+03	23200.00
1579D7	2017-07-30 17:46:00+03	32500.00
1579EF	2017-07-27 14:42:00+03	17800.00
157A5C	2017-07-20 11:52:00+03	124200.00
157AD9	2017-07-12 11:40:00+03	31600.00
157ADF	2017-08-02 01:04:00+03	39700.00
157B6E	2017-07-15 13:25:00+03	6700.00
157BB2	2017-07-03 06:05:00+03	67900.00
157BD9	2017-07-20 15:38:00+03	32700.00
157BF5	2017-07-27 03:40:00+03	23600.00
157C86	2017-08-10 20:57:00+03	36200.00
157D2B	2017-07-07 00:21:00+03	37900.00
157DA0	2017-08-11 09:41:00+03	92900.00
157DE2	2017-08-01 06:50:00+03	16400.00
157DE7	2017-06-30 00:11:00+03	28000.00
157DFE	2017-07-04 20:25:00+03	80000.00
157E48	2017-08-07 19:36:00+03	42800.00
157E6F	2017-07-18 18:59:00+03	41600.00
157EB6	2017-08-03 02:58:00+03	38400.00
157F14	2017-07-07 09:24:00+03	143100.00
157F8D	2017-07-21 19:42:00+03	38300.00
157FA8	2017-07-22 13:29:00+03	67500.00
157FAD	2017-07-10 12:39:00+03	114900.00
158082	2017-07-05 18:15:00+03	68000.00
15809B	2017-08-10 03:57:00+03	135200.00
1580DC	2017-08-08 23:48:00+03	59800.00
158149	2017-07-03 11:08:00+03	119600.00
1581BE	2017-07-27 21:16:00+03	31600.00
1581DE	2017-08-12 00:25:00+03	112000.00
158270	2017-08-10 13:44:00+03	51900.00
1582B2	2017-07-22 09:23:00+03	272500.00
1582E9	2017-07-15 09:45:00+03	68800.00
15832F	2017-07-23 16:12:00+03	17800.00
1583D2	2017-07-31 04:05:00+03	532600.00
1583F8	2017-07-27 06:24:00+03	6700.00
1583FD	2017-08-11 01:07:00+03	19000.00
158402	2017-08-05 12:24:00+03	25100.00
15843A	2017-07-17 10:49:00+03	24300.00
15846E	2017-07-08 09:05:00+03	152300.00
1584B4	2017-07-11 17:09:00+03	21400.00
158507	2017-07-15 07:07:00+03	32300.00
1585A2	2017-08-01 12:16:00+03	115700.00
1585AF	2017-07-13 08:08:00+03	46000.00
1585E9	2017-07-19 11:03:00+03	102000.00
1585EC	2017-07-17 00:44:00+03	6700.00
158617	2017-07-24 05:32:00+03	112000.00
158687	2017-07-19 15:43:00+03	63300.00
1586D3	2017-07-08 12:55:00+03	47100.00
158721	2017-07-27 09:12:00+03	70400.00
158727	2017-08-08 07:43:00+03	81700.00
15873B	2017-07-26 15:02:00+03	33400.00
158741	2017-07-11 21:13:00+03	51300.00
158781	2017-08-04 13:48:00+03	46000.00
158797	2017-08-10 03:40:00+03	12000.00
158813	2017-08-09 05:25:00+03	94200.00
158861	2017-07-13 04:23:00+03	39600.00
158868	2017-08-03 09:04:00+03	14000.00
1588DF	2017-07-31 13:32:00+03	118800.00
158940	2017-07-20 06:17:00+03	7300.00
15899C	2017-07-24 22:17:00+03	75100.00
1589B2	2017-07-27 18:18:00+03	172100.00
1589B6	2017-08-11 14:04:00+03	85000.00
1589D5	2017-07-20 00:11:00+03	43900.00
1589DA	2017-07-20 11:20:00+03	57500.00
158A0A	2017-08-01 02:24:00+03	54000.00
158A38	2017-07-18 01:57:00+03	56600.00
158A68	2017-08-14 22:18:00+03	86800.00
158AB1	2017-07-15 07:04:00+03	46000.00
158B20	2017-08-04 12:32:00+03	105600.00
158B2D	2017-08-05 07:12:00+03	65000.00
158B3D	2017-07-22 08:11:00+03	45100.00
158B94	2017-08-06 03:56:00+03	73500.00
158BA2	2017-07-07 19:36:00+03	52000.00
158BBB	2017-07-23 11:00:00+03	38500.00
158BDB	2017-07-05 01:40:00+03	133200.00
158C70	2017-07-20 02:20:00+03	35400.00
158CAE	2017-07-12 07:04:00+03	43300.00
158CBA	2017-06-29 09:12:00+03	26000.00
158CD2	2017-08-07 16:07:00+03	92700.00
158D2B	2017-07-01 05:46:00+03	437700.00
158DCC	2017-07-18 03:57:00+03	29600.00
158E66	2017-06-28 16:40:00+03	23200.00
158EBF	2017-07-30 08:50:00+03	6800.00
158EE8	2017-07-21 14:50:00+03	88600.00
158F77	2017-08-01 13:22:00+03	21800.00
158FA8	2017-08-06 09:51:00+03	56900.00
159061	2017-07-19 06:20:00+03	12600.00
159082	2017-07-10 01:01:00+03	6700.00
15908C	2017-07-07 05:00:00+03	73600.00
1590F2	2017-08-02 17:00:00+03	28000.00
15912F	2017-07-05 05:10:00+03	77500.00
159184	2017-07-31 17:02:00+03	18600.00
15919C	2017-07-02 00:12:00+03	35300.00
1591A9	2017-08-13 22:34:00+03	67200.00
1591B9	2017-06-30 22:32:00+03	79200.00
1591DA	2017-08-04 18:57:00+03	27200.00
1591E3	2017-07-03 20:14:00+03	76600.00
15920A	2017-07-25 18:27:00+03	468700.00
159216	2017-07-20 13:59:00+03	44000.00
159219	2017-08-12 17:38:00+03	66000.00
159222	2017-07-12 06:20:00+03	99200.00
159250	2017-07-25 14:32:00+03	174000.00
15925A	2017-08-02 11:54:00+03	44900.00
15926A	2017-07-22 09:04:00+03	75700.00
159295	2017-07-28 12:13:00+03	26000.00
159423	2017-06-28 10:07:00+03	26700.00
15942F	2017-07-23 17:00:00+03	176000.00
159460	2017-07-17 07:56:00+03	58600.00
1594BD	2017-08-05 10:39:00+03	31100.00
159507	2017-07-04 21:08:00+03	54000.00
159544	2017-07-01 18:30:00+03	28000.00
1595F4	2017-07-23 01:25:00+03	135600.00
15966C	2017-07-22 08:49:00+03	30200.00
1596A6	2017-07-13 04:56:00+03	38800.00
1596B2	2017-07-26 11:39:00+03	34000.00
1596F3	2017-08-01 22:41:00+03	28000.00
159720	2017-07-24 09:25:00+03	52000.00
159725	2017-08-13 01:51:00+03	133100.00
15973D	2017-07-15 08:24:00+03	156500.00
159744	2017-08-10 22:25:00+03	137400.00
159783	2017-06-30 04:10:00+03	95200.00
1597F0	2017-07-05 08:22:00+03	111600.00
15980C	2017-07-06 12:49:00+03	65900.00
1598A8	2017-08-12 11:50:00+03	39200.00
1598B8	2017-06-28 12:00:00+03	49200.00
159987	2017-07-14 15:12:00+03	21400.00
159997	2017-07-12 09:38:00+03	124000.00
1599BC	2017-07-04 09:02:00+03	22600.00
1599E7	2017-08-13 04:03:00+03	75700.00
1599EE	2017-08-06 15:16:00+03	11200.00
159A12	2017-08-08 20:56:00+03	79400.00
159A1F	2017-07-10 11:16:00+03	50600.00
159A2F	2017-07-13 14:53:00+03	126500.00
159A70	2017-08-08 20:40:00+03	42700.00
159AB7	2017-07-17 10:35:00+03	13300.00
159AE2	2017-07-04 11:45:00+03	133200.00
159B82	2017-08-12 22:20:00+03	57100.00
159BDC	2017-07-24 02:23:00+03	44700.00
159C12	2017-07-03 13:19:00+03	44800.00
159C2C	2017-07-30 02:06:00+03	111700.00
159C5C	2017-08-13 00:24:00+03	54000.00
159C71	2017-08-07 20:54:00+03	77100.00
159D2C	2017-08-12 09:45:00+03	26200.00
159D57	2017-07-12 08:34:00+03	70800.00
159D77	2017-08-04 14:18:00+03	40800.00
159E41	2017-07-16 12:19:00+03	52000.00
159E77	2017-07-16 05:28:00+03	28000.00
159EE5	2017-07-27 17:35:00+03	32800.00
159F0D	2017-08-08 19:47:00+03	26000.00
159F8D	2017-06-27 10:52:00+03	26500.00
159F8E	2017-07-01 06:49:00+03	81700.00
15A03E	2017-07-31 12:01:00+03	71200.00
15A040	2017-08-09 10:26:00+03	59600.00
15A047	2017-08-05 03:55:00+03	65300.00
15A084	2017-07-26 14:18:00+03	136600.00
15A085	2017-07-29 23:16:00+03	29600.00
15A09A	2017-07-14 02:03:00+03	68000.00
15A0D9	2017-07-15 21:33:00+03	147000.00
15A0E5	2017-07-02 02:51:00+03	516000.00
15A186	2017-07-24 09:07:00+03	55800.00
15A1BB	2017-08-01 05:54:00+03	52000.00
15A25C	2017-08-13 06:27:00+03	21400.00
15A2C3	2017-07-30 09:16:00+03	27800.00
15A34C	2017-07-31 02:30:00+03	57700.00
15A365	2017-07-18 07:22:00+03	86300.00
15A3DF	2017-07-27 03:04:00+03	53300.00
15A416	2017-08-13 10:03:00+03	170000.00
15A467	2017-07-17 13:35:00+03	78300.00
15A469	2017-07-30 16:28:00+03	44500.00
15A5AC	2017-07-16 15:44:00+03	15100.00
15A5B4	2017-07-08 12:11:00+03	265600.00
15A618	2017-08-05 00:12:00+03	133100.00
15A653	2017-07-02 06:40:00+03	16400.00
15A6B6	2017-08-07 06:46:00+03	69500.00
15A7C3	2017-08-13 03:15:00+03	26800.00
15A8E8	2017-07-12 13:09:00+03	181600.00
15A90C	2017-08-11 20:02:00+03	126500.00
15A936	2017-07-11 05:37:00+03	59300.00
15A9CC	2017-07-15 10:02:00+03	6300.00
15AA80	2017-07-30 00:53:00+03	12200.00
15AB32	2017-07-29 05:23:00+03	35600.00
15AB39	2017-07-12 23:12:00+03	148100.00
15AB66	2017-08-10 03:51:00+03	202700.00
15AB88	2017-08-02 14:06:00+03	59800.00
15AB91	2017-07-28 10:42:00+03	28800.00
15AC32	2017-07-28 05:14:00+03	27800.00
15AC72	2017-07-09 03:53:00+03	62600.00
15AC98	2017-08-15 08:21:00+03	16400.00
15ACFE	2017-07-27 13:00:00+03	42800.00
15AD3B	2017-08-06 17:48:00+03	64700.00
15ADB4	2017-07-23 00:25:00+03	26000.00
15ADD2	2017-08-03 07:11:00+03	38500.00
15AE04	2017-07-31 20:51:00+03	7200.00
15AE44	2017-08-03 16:57:00+03	95600.00
15AE45	2017-07-30 02:17:00+03	94000.00
15AE4C	2017-07-24 10:59:00+03	84500.00
15AE74	2017-07-27 12:55:00+03	18900.00
15AF85	2017-07-08 08:05:00+03	168000.00
15AFD3	2017-08-01 23:50:00+03	28000.00
15AFFE	2017-07-16 14:28:00+03	57400.00
15B04A	2017-08-11 05:28:00+03	89600.00
15B0CE	2017-07-26 06:23:00+03	48500.00
15B0EB	2017-07-20 02:57:00+03	209900.00
15B108	2017-08-09 00:34:00+03	56100.00
15B191	2017-08-15 13:37:00+03	6600.00
15B19A	2017-06-28 03:29:00+03	52300.00
15B223	2017-08-04 23:45:00+03	111600.00
15B246	2017-07-08 12:00:00+03	40800.00
15B25C	2017-08-12 11:04:00+03	54500.00
15B25F	2017-07-04 14:10:00+03	36800.00
15B28F	2017-08-01 11:38:00+03	57500.00
15B295	2017-08-08 22:18:00+03	38500.00
15B296	2017-07-21 20:19:00+03	22600.00
15B2EA	2017-08-05 20:58:00+03	71800.00
15B3AF	2017-07-14 03:05:00+03	247600.00
15B3E9	2017-08-08 03:27:00+03	14000.00
15B47A	2017-06-30 13:52:00+03	176000.00
15B47E	2017-07-08 00:27:00+03	23400.00
15B492	2017-07-18 08:21:00+03	6800.00
15B4C2	2017-07-28 14:57:00+03	24800.00
15B4FD	2017-07-23 19:25:00+03	73400.00
15B4FF	2017-07-27 05:16:00+03	14400.00
15B528	2017-07-21 07:38:00+03	139800.00
15B540	2017-08-10 08:09:00+03	6000.00
15B58D	2017-08-11 13:22:00+03	30000.00
15B599	2017-07-05 08:22:00+03	57100.00
15B5A4	2017-07-24 03:49:00+03	59800.00
15B5B9	2017-07-13 21:14:00+03	40800.00
15B650	2017-07-21 04:59:00+03	265800.00
15B674	2017-08-02 16:25:00+03	12600.00
15B67C	2017-07-27 08:53:00+03	114400.00
15B695	2017-07-07 13:38:00+03	194000.00
15B6BD	2017-08-10 16:13:00+03	57400.00
15B6DF	2017-08-02 18:58:00+03	27800.00
15B6E4	2017-07-26 05:38:00+03	76600.00
15B6FA	2017-07-06 16:53:00+03	14400.00
15B72D	2017-07-20 22:58:00+03	86400.00
15B7C4	2017-07-19 18:58:00+03	49500.00
15B7D1	2017-07-26 05:10:00+03	50000.00
15B87F	2017-08-07 00:32:00+03	43000.00
15B886	2017-07-22 14:39:00+03	40000.00
15B8A2	2017-07-22 06:35:00+03	138600.00
15B8B0	2017-08-13 20:54:00+03	46400.00
15B8BF	2017-08-09 15:35:00+03	149300.00
15B8EE	2017-08-02 22:39:00+03	46400.00
15B928	2017-08-05 18:27:00+03	13000.00
15B973	2017-07-12 10:46:00+03	22000.00
15B9B9	2017-07-10 08:25:00+03	25100.00
15B9D2	2017-07-05 13:34:00+03	70800.00
15BA60	2017-07-10 15:21:00+03	24400.00
15BA93	2017-07-23 15:23:00+03	75300.00
15BB30	2017-06-26 20:48:00+03	115700.00
15BB8F	2017-07-09 19:39:00+03	13400.00
15BB9B	2017-08-03 21:08:00+03	35600.00
15BBD7	2017-07-13 13:13:00+03	98100.00
15BC0E	2017-07-12 16:00:00+03	14000.00
15BC66	2017-07-30 08:58:00+03	23400.00
15BCFD	2017-08-03 02:30:00+03	26000.00
15BD4B	2017-07-06 01:59:00+03	33100.00
15BD6E	2017-07-16 04:52:00+03	50600.00
15BDED	2017-07-04 20:07:00+03	100000.00
15BE08	2017-07-24 11:30:00+03	43000.00
15BE0E	2017-07-10 08:21:00+03	44800.00
15BE12	2017-07-31 04:14:00+03	23600.00
15BE3A	2017-07-23 02:59:00+03	46200.00
15BE72	2017-08-13 18:42:00+03	23600.00
15BE77	2017-07-12 03:17:00+03	22400.00
15BF1F	2017-08-15 14:05:00+03	115400.00
15BFA9	2017-07-31 02:27:00+03	37500.00
15BFAD	2017-08-05 15:21:00+03	346900.00
15BFD8	2017-07-27 08:07:00+03	169300.00
15C07B	2017-07-28 07:54:00+03	246000.00
15C0D6	2017-07-22 09:01:00+03	131600.00
15C0DB	2017-07-12 01:20:00+03	30000.00
15C0FC	2017-07-23 16:06:00+03	61800.00
15C123	2017-07-16 19:49:00+03	43600.00
15C181	2017-07-29 12:47:00+03	22000.00
15C186	2017-07-30 15:07:00+03	39100.00
15C1FD	2017-08-04 22:42:00+03	112900.00
15C29A	2017-08-01 10:26:00+03	265700.00
15C2B8	2017-07-11 05:06:00+03	132800.00
15C2D1	2017-07-30 00:58:00+03	92600.00
15C392	2017-08-01 08:15:00+03	50700.00
15C3A9	2017-06-29 09:46:00+03	94000.00
15C41E	2017-07-12 13:05:00+03	116500.00
15C432	2017-07-09 17:30:00+03	71900.00
15C43F	2017-07-15 09:20:00+03	146400.00
15C495	2017-08-14 19:01:00+03	6300.00
15C49A	2017-08-06 20:31:00+03	69500.00
15C537	2017-07-20 23:49:00+03	45000.00
15C541	2017-07-12 11:41:00+03	28000.00
15C55C	2017-07-10 12:44:00+03	83200.00
15C58C	2017-07-23 03:08:00+03	46400.00
15C5BF	2017-07-14 22:12:00+03	28000.00
15C5CF	2017-07-06 02:34:00+03	3400.00
15C5D8	2017-08-14 09:23:00+03	13400.00
15C5EE	2017-07-10 08:52:00+03	85000.00
15C64E	2017-08-09 01:15:00+03	28800.00
15C654	2017-07-27 16:24:00+03	95600.00
15C68D	2017-07-19 07:57:00+03	33600.00
15C693	2017-07-22 06:39:00+03	112000.00
15C6E6	2017-08-04 14:50:00+03	92700.00
15C6EE	2017-07-26 17:04:00+03	67600.00
15C734	2017-07-21 06:53:00+03	17200.00
15C764	2017-07-10 22:53:00+03	46000.00
15C770	2017-08-07 18:39:00+03	28800.00
15C813	2017-07-26 07:33:00+03	25000.00
15C832	2017-07-30 14:49:00+03	38000.00
15C896	2017-08-12 17:01:00+03	41200.00
15C8F9	2017-07-28 19:31:00+03	10700.00
15C933	2017-08-08 09:42:00+03	56600.00
15C94F	2017-08-06 21:20:00+03	55000.00
15C9BE	2017-07-17 04:18:00+03	26000.00
15C9C8	2017-07-15 06:26:00+03	56600.00
15CA6B	2017-07-12 08:49:00+03	136600.00
15CB02	2017-08-11 18:26:00+03	26000.00
15CB67	2017-07-14 21:11:00+03	36200.00
15CBB9	2017-08-08 23:14:00+03	43000.00
15CBCD	2017-07-21 15:31:00+03	43400.00
15CBD6	2017-08-03 15:39:00+03	53200.00
15CC37	2017-07-13 03:07:00+03	265700.00
15CC3F	2017-08-01 22:25:00+03	12600.00
15CC8D	2017-07-28 09:17:00+03	92600.00
15CCC2	2017-08-07 15:38:00+03	73300.00
15CCE0	2017-07-26 22:06:00+03	28000.00
15CD3C	2017-07-05 21:48:00+03	44600.00
15CD41	2017-07-05 20:26:00+03	47200.00
15CD5A	2017-07-02 15:24:00+03	17000.00
15CDA7	2017-08-09 16:40:00+03	239100.00
15CDA8	2017-08-05 18:01:00+03	109600.00
15CDEF	2017-07-20 21:08:00+03	272300.00
15CE2F	2017-07-24 07:46:00+03	13600.00
15CE7F	2017-08-15 01:30:00+03	26000.00
15CF0C	2017-07-03 19:38:00+03	13400.00
15CF1D	2017-08-14 21:44:00+03	117200.00
15CF8F	2017-07-15 04:38:00+03	155500.00
15CFA7	2017-08-15 10:56:00+03	182100.00
15CFE3	2017-07-04 00:21:00+03	43500.00
15D012	2017-07-14 23:59:00+03	36200.00
15D045	2017-08-05 04:33:00+03	59600.00
15D06E	2017-08-01 10:04:00+03	104300.00
15D0CC	2017-08-01 14:56:00+03	65900.00
15D0CF	2017-07-18 04:05:00+03	44500.00
15D0D5	2017-08-03 12:17:00+03	12600.00
15D0DA	2017-07-16 16:50:00+03	257500.00
15D0E8	2017-07-07 08:59:00+03	62600.00
15D1C7	2017-07-16 11:19:00+03	42000.00
15D1FA	2017-07-18 06:27:00+03	125100.00
15D219	2017-08-12 03:46:00+03	26800.00
15D24B	2017-08-13 04:57:00+03	31200.00
15D26D	2017-07-08 21:49:00+03	32700.00
15D291	2017-07-12 04:21:00+03	27800.00
15D293	2017-07-11 19:50:00+03	137900.00
15D29D	2017-07-28 12:09:00+03	66000.00
15D2C3	2017-07-18 15:32:00+03	40800.00
15D31D	2017-08-09 06:43:00+03	135100.00
15D34B	2017-07-22 18:18:00+03	23600.00
15D38A	2017-07-18 06:53:00+03	8200.00
15D39E	2017-07-16 04:10:00+03	110500.00
15D3A4	2017-08-10 05:05:00+03	36500.00
15D431	2017-07-28 09:36:00+03	32800.00
15D4FF	2017-06-30 17:11:00+03	26200.00
15D527	2017-07-29 20:19:00+03	48500.00
15D54B	2017-08-11 10:56:00+03	312000.00
15D55A	2017-08-01 02:28:00+03	47900.00
15D59E	2017-07-05 12:27:00+03	13000.00
15D5F1	2017-07-21 20:55:00+03	182300.00
15D60F	2017-07-06 10:18:00+03	137700.00
15D62C	2017-07-10 22:41:00+03	139200.00
15D634	2017-08-09 21:55:00+03	137800.00
15D65A	2017-07-01 04:58:00+03	60400.00
15D6A9	2017-08-03 16:38:00+03	120600.00
15D6DE	2017-07-19 06:47:00+03	57400.00
15D8AC	2017-07-22 03:20:00+03	224000.00
15D8D9	2017-08-11 07:48:00+03	116400.00
15D956	2017-08-03 05:53:00+03	60300.00
15D959	2017-08-11 01:44:00+03	48800.00
15D99C	2017-08-03 06:12:00+03	26700.00
15DA4B	2017-08-13 17:13:00+03	88600.00
15DA98	2017-07-11 16:52:00+03	55800.00
15DAEC	2017-08-09 00:34:00+03	86300.00
15DB38	2017-08-15 13:55:00+03	110200.00
15DB3C	2017-07-04 14:23:00+03	31600.00
15DB71	2017-06-28 11:27:00+03	29800.00
15DB9C	2017-07-26 22:16:00+03	101200.00
15DBF5	2017-08-05 03:59:00+03	62600.00
15DC32	2017-07-20 08:19:00+03	393300.00
15DC40	2017-07-26 06:07:00+03	189800.00
15DD2D	2017-08-09 00:03:00+03	23200.00
15DDE6	2017-07-13 09:18:00+03	191300.00
15DDE9	2017-07-02 10:45:00+03	119500.00
15DDFF	2017-07-11 11:17:00+03	50200.00
15DE15	2017-08-10 04:46:00+03	132300.00
15DF0D	2017-07-30 02:32:00+03	48500.00
15DFE4	2017-07-29 19:58:00+03	58200.00
15E061	2017-07-30 14:47:00+03	73600.00
15E092	2017-08-07 16:44:00+03	26000.00
15E09C	2017-07-30 03:20:00+03	54800.00
15E0DF	2017-08-01 13:01:00+03	63000.00
15E11F	2017-07-29 18:12:00+03	26200.00
15E12E	2017-07-27 13:25:00+03	11000.00
15E1A7	2017-07-30 15:34:00+03	170500.00
15E1BF	2017-07-15 10:11:00+03	62800.00
15E1DE	2017-07-26 15:25:00+03	46000.00
15E26E	2017-07-09 00:10:00+03	86400.00
15E286	2017-08-15 12:43:00+03	12400.00
15E2C5	2017-08-08 19:24:00+03	46000.00
15E2E0	2017-08-05 10:17:00+03	212700.00
15E3BE	2017-07-30 20:58:00+03	164000.00
15E3E0	2017-07-30 14:15:00+03	50600.00
15E3FB	2017-07-24 03:32:00+03	40800.00
15E456	2017-07-09 23:03:00+03	68000.00
15E4CE	2017-07-18 20:00:00+03	111600.00
15E4D6	2017-08-07 15:48:00+03	120300.00
15E580	2017-07-15 09:12:00+03	6800.00
15E593	2017-07-26 11:07:00+03	50000.00
15E5F1	2017-07-06 19:02:00+03	25800.00
15E627	2017-07-14 04:25:00+03	23200.00
15E632	2017-07-20 14:56:00+03	67700.00
15E64B	2017-06-30 15:18:00+03	45200.00
15E6C0	2017-08-14 04:39:00+03	21400.00
15E6E2	2017-07-17 09:23:00+03	90800.00
15E744	2017-07-23 19:32:00+03	44000.00
15E7A9	2017-07-17 22:37:00+03	59200.00
15E841	2017-07-19 13:40:00+03	22000.00
15E843	2017-07-08 21:00:00+03	152500.00
15E8B2	2017-08-11 17:29:00+03	137600.00
15E951	2017-08-05 06:14:00+03	66600.00
15E999	2017-07-06 19:06:00+03	56000.00
15E9B2	2017-07-16 13:30:00+03	124400.00
15E9FC	2017-07-26 01:44:00+03	115400.00
15EA20	2017-07-15 08:18:00+03	35600.00
15EA37	2017-07-22 05:56:00+03	112000.00
15EA46	2017-07-14 15:13:00+03	369000.00
15EA85	2017-07-30 23:34:00+03	20500.00
15EAFD	2017-08-12 20:29:00+03	234700.00
15EB06	2017-08-11 12:03:00+03	56700.00
15EB19	2017-07-27 00:41:00+03	22000.00
15EBC3	2017-07-14 18:56:00+03	52000.00
15EC60	2017-07-04 02:55:00+03	40800.00
15ECAC	2017-08-10 01:05:00+03	28700.00
15ECBB	2017-08-02 21:25:00+03	37900.00
15ED31	2017-07-12 16:44:00+03	155600.00
15EDAE	2017-08-06 11:00:00+03	46000.00
15EDCA	2017-07-24 15:07:00+03	6900.00
15EE57	2017-07-17 06:23:00+03	19600.00
15EE92	2017-07-26 20:12:00+03	69000.00
15EFE2	2017-07-19 07:16:00+03	29800.00
15F024	2017-07-21 03:15:00+03	65900.00
15F053	2017-07-13 07:07:00+03	6300.00
15F055	2017-07-07 07:24:00+03	29600.00
15F083	2017-06-27 10:51:00+03	156000.00
15F0A8	2017-07-19 23:52:00+03	86800.00
15F14C	2017-08-11 10:42:00+03	112000.00
15F156	2017-08-04 08:17:00+03	28200.00
15F1EC	2017-07-09 16:02:00+03	28000.00
15F282	2017-07-16 12:23:00+03	65900.00
15F2DB	2017-07-12 12:26:00+03	48800.00
15F382	2017-07-01 06:30:00+03	22000.00
15F39C	2017-07-20 08:47:00+03	58400.00
15F3C9	2017-08-07 03:33:00+03	180100.00
15F415	2017-07-13 19:44:00+03	91600.00
15F44C	2017-08-13 20:12:00+03	131000.00
15F47A	2017-07-21 19:38:00+03	79600.00
15F518	2017-07-22 02:36:00+03	14400.00
15F53E	2017-08-14 16:15:00+03	132200.00
15F589	2017-07-20 10:51:00+03	199000.00
15F627	2017-08-04 16:31:00+03	101100.00
15F6D0	2017-08-06 20:17:00+03	14700.00
15F715	2017-07-22 08:22:00+03	24200.00
15F780	2017-07-14 12:35:00+03	27200.00
15F7BE	2017-07-22 13:36:00+03	27400.00
15F7D1	2017-07-28 23:01:00+03	32300.00
15F7D6	2017-07-20 07:29:00+03	28800.00
15F7F7	2017-07-27 05:13:00+03	55800.00
15F886	2017-07-17 04:31:00+03	28000.00
15F8B4	2017-07-17 06:00:00+03	86300.00
15F8F2	2017-07-24 20:24:00+03	24000.00
15F945	2017-07-23 04:34:00+03	55600.00
15F969	2017-08-03 23:14:00+03	17800.00
15F97D	2017-07-31 03:11:00+03	59300.00
15F9BD	2017-08-12 00:54:00+03	19600.00
15FA35	2017-07-29 16:15:00+03	28000.00
15FA40	2017-07-28 13:44:00+03	75300.00
15FA45	2017-07-07 11:53:00+03	67800.00
15FA51	2017-08-14 23:27:00+03	56000.00
15FA68	2017-08-13 16:13:00+03	77100.00
15FAB1	2017-08-10 14:19:00+03	87000.00
15FAB3	2017-07-20 22:32:00+03	26000.00
15FB62	2017-07-06 07:45:00+03	66600.00
15FB9B	2017-08-15 05:30:00+03	112000.00
15FC2E	2017-07-12 19:30:00+03	8000.00
15FC41	2017-08-13 07:29:00+03	47100.00
15FC79	2017-07-14 21:41:00+03	40100.00
15FC89	2017-07-11 19:55:00+03	240600.00
15FD15	2017-08-11 05:57:00+03	28800.00
15FD32	2017-07-02 18:13:00+03	79600.00
15FD49	2017-07-10 08:16:00+03	21800.00
15FDD6	2017-08-15 03:49:00+03	592900.00
15FDF9	2017-07-26 14:38:00+03	51800.00
15FE3E	2017-07-21 21:46:00+03	89700.00
15FE79	2017-07-23 22:23:00+03	91300.00
15FEF1	2017-06-28 21:44:00+03	198300.00
15FF62	2017-07-26 12:04:00+03	68400.00
15FF68	2017-08-01 04:57:00+03	49900.00
15FFB2	2017-08-10 23:30:00+03	117700.00
15FFD8	2017-07-16 21:27:00+03	77900.00
160001	2017-07-31 04:10:00+03	51200.00
160055	2017-07-05 04:40:00+03	31600.00
160065	2017-07-18 02:54:00+03	94700.00
160075	2017-07-27 00:43:00+03	28000.00
1600D6	2017-07-17 23:16:00+03	13600.00
1600E2	2017-07-11 09:43:00+03	36800.00
16012A	2017-08-05 19:14:00+03	40800.00
160136	2017-07-28 19:58:00+03	46400.00
160184	2017-07-14 21:01:00+03	27300.00
16023D	2017-07-18 05:10:00+03	36800.00
16025A	2017-08-14 22:44:00+03	38600.00
160289	2017-06-25 10:53:00+03	113700.00
16029B	2017-08-12 07:38:00+03	46700.00
160396	2017-07-09 19:05:00+03	37200.00
160413	2017-07-05 16:05:00+03	6700.00
160456	2017-08-01 18:40:00+03	55800.00
16052D	2017-07-10 00:35:00+03	47900.00
16055B	2017-07-30 17:54:00+03	37600.00
1605A3	2017-07-25 09:54:00+03	31400.00
16062C	2017-08-14 23:14:00+03	26600.00
160646	2017-08-14 23:19:00+03	14800.00
16064A	2017-07-30 03:33:00+03	88800.00
16066A	2017-06-30 16:48:00+03	40200.00
1606E2	2017-07-19 22:21:00+03	133200.00
1606F8	2017-08-12 16:54:00+03	65900.00
1606FA	2017-08-01 11:17:00+03	13700.00
160739	2017-08-15 14:38:00+03	25200.00
160746	2017-07-03 03:24:00+03	160700.00
160789	2017-08-10 14:17:00+03	71900.00
1607A7	2017-07-27 03:27:00+03	68800.00
1607D7	2017-07-13 23:08:00+03	202500.00
160807	2017-08-07 17:36:00+03	114700.00
160809	2017-08-07 20:00:00+03	15000.00
160869	2017-06-30 09:59:00+03	155600.00
16088A	2017-06-29 04:53:00+03	56000.00
1608E5	2017-07-27 06:51:00+03	83000.00
160969	2017-07-22 09:26:00+03	132800.00
1609B0	2017-07-04 11:06:00+03	8200.00
1609DB	2017-07-08 02:18:00+03	123000.00
1609DD	2017-07-18 16:20:00+03	6300.00
160A42	2017-07-02 11:58:00+03	90800.00
160A96	2017-07-12 02:27:00+03	23400.00
160A9F	2017-08-10 05:57:00+03	143600.00
160AA1	2017-07-29 02:50:00+03	32800.00
160BE3	2017-08-09 04:48:00+03	39500.00
160BE4	2017-07-23 04:31:00+03	266400.00
160C04	2017-07-05 12:43:00+03	43000.00
160C42	2017-07-15 17:45:00+03	134900.00
160C58	2017-07-03 04:51:00+03	64200.00
160CA8	2017-08-15 12:36:00+03	81300.00
160CDF	2017-08-12 11:33:00+03	32200.00
160D78	2017-08-10 07:15:00+03	60000.00
160D79	2017-07-20 19:12:00+03	59200.00
160D8D	2017-07-01 07:34:00+03	12600.00
160DB3	2017-07-03 13:15:00+03	23400.00
160DB5	2017-07-15 18:07:00+03	369000.00
160DEA	2017-06-30 12:45:00+03	40800.00
160E2B	2017-07-14 21:25:00+03	135600.00
160E39	2017-06-29 10:47:00+03	25600.00
160E3C	2017-07-19 20:26:00+03	26000.00
160E49	2017-08-07 07:24:00+03	201200.00
160E9C	2017-07-20 15:39:00+03	114800.00
160EA0	2017-07-15 01:45:00+03	168700.00
160EAB	2017-07-24 16:38:00+03	6700.00
160EF6	2017-08-08 16:43:00+03	57500.00
160F12	2017-07-25 08:04:00+03	56000.00
160F1C	2017-06-29 05:22:00+03	28000.00
160FC6	2017-07-29 16:05:00+03	145100.00
161003	2017-08-01 04:02:00+03	69000.00
1610B7	2017-08-01 20:27:00+03	26000.00
1610F5	2017-08-07 15:19:00+03	283700.00
16115C	2017-08-03 11:19:00+03	43200.00
161161	2017-07-21 04:54:00+03	87700.00
1611DB	2017-08-02 05:16:00+03	35600.00
16125F	2017-07-31 17:37:00+03	100000.00
1612A9	2017-07-29 16:04:00+03	25100.00
161331	2017-08-09 01:38:00+03	36200.00
1613AE	2017-07-08 13:08:00+03	37900.00
1613F9	2017-07-23 06:01:00+03	38800.00
161428	2017-08-09 17:52:00+03	52800.00
161464	2017-07-26 12:56:00+03	11600.00
161476	2017-08-12 07:35:00+03	283100.00
161498	2017-07-09 09:11:00+03	34000.00
16149B	2017-08-11 05:25:00+03	100600.00
1614CA	2017-07-24 08:37:00+03	6300.00
1614F8	2017-07-09 03:40:00+03	139400.00
161542	2017-08-06 11:04:00+03	168000.00
161570	2017-07-13 03:42:00+03	6700.00
16159A	2017-07-01 23:50:00+03	34600.00
1615BC	2017-07-24 03:36:00+03	89200.00
1615BD	2017-07-16 12:46:00+03	23600.00
161656	2017-07-24 05:35:00+03	246000.00
1616A9	2017-07-09 17:42:00+03	86600.00
1616CA	2017-07-10 16:56:00+03	71200.00
1616CC	2017-08-05 22:04:00+03	88600.00
1616CD	2017-08-10 20:18:00+03	100600.00
1616E6	2017-08-10 06:43:00+03	28000.00
16171C	2017-07-03 04:39:00+03	13600.00
161740	2017-07-10 14:08:00+03	129100.00
16176D	2017-07-10 02:06:00+03	70500.00
161781	2017-07-18 19:52:00+03	7200.00
16178A	2017-08-08 17:00:00+03	185600.00
16179A	2017-08-11 13:06:00+03	396800.00
16182B	2017-07-31 01:42:00+03	26000.00
161869	2017-08-08 14:43:00+03	38400.00
1618AB	2017-07-30 18:18:00+03	46400.00
1618C5	2017-08-04 04:07:00+03	56000.00
1618D5	2017-07-17 07:01:00+03	43500.00
16196D	2017-08-09 08:56:00+03	34800.00
16196E	2017-07-31 05:26:00+03	113700.00
16197B	2017-08-01 06:59:00+03	32700.00
1619A9	2017-07-28 07:15:00+03	57400.00
161A02	2017-07-26 04:08:00+03	269500.00
161A05	2017-08-15 02:15:00+03	47000.00
161A1D	2017-08-13 23:41:00+03	80200.00
161A27	2017-08-14 08:41:00+03	84000.00
161A34	2017-07-14 10:53:00+03	47600.00
161A50	2017-07-09 04:02:00+03	13800.00
161AB4	2017-08-02 05:06:00+03	25600.00
161ABA	2017-07-04 03:34:00+03	56000.00
161ABD	2017-07-30 19:14:00+03	47100.00
161B69	2017-08-06 02:25:00+03	34000.00
161BAA	2017-08-07 02:22:00+03	34000.00
161BCD	2017-08-12 09:52:00+03	56600.00
161C72	2017-07-22 07:58:00+03	28800.00
161CB0	2017-07-14 22:39:00+03	136600.00
161CE7	2017-07-26 21:09:00+03	28800.00
161D08	2017-07-31 19:09:00+03	69500.00
161DD3	2017-07-30 17:18:00+03	56100.00
161E18	2017-07-21 07:34:00+03	40800.00
161E71	2017-07-05 17:06:00+03	52400.00
161EA3	2017-07-15 19:30:00+03	40800.00
161EDA	2017-07-04 17:44:00+03	109200.00
161EF5	2017-07-01 21:11:00+03	79600.00
161F52	2017-08-01 03:52:00+03	199700.00
161FF0	2017-07-14 14:39:00+03	8400.00
16202F	2017-07-01 19:13:00+03	62800.00
1620B2	2017-08-05 16:13:00+03	81600.00
162133	2017-08-11 18:07:00+03	100600.00
162156	2017-07-30 06:37:00+03	105600.00
16215A	2017-08-02 12:01:00+03	54800.00
162174	2017-07-09 05:15:00+03	27800.00
1621D0	2017-07-09 04:14:00+03	100900.00
1621D8	2017-07-08 07:18:00+03	12600.00
16221D	2017-07-16 06:49:00+03	144900.00
16229F	2017-07-16 08:49:00+03	202100.00
162314	2017-07-11 23:03:00+03	63000.00
1625D8	2017-07-24 21:58:00+03	67600.00
1626CA	2017-07-30 07:08:00+03	102900.00
1626FC	2017-07-25 16:26:00+03	103500.00
16274A	2017-07-11 00:36:00+03	57700.00
162763	2017-07-07 07:15:00+03	61800.00
1627C3	2017-07-26 23:54:00+03	78800.00
1627D6	2017-08-13 17:07:00+03	114700.00
1627FA	2017-08-04 19:11:00+03	72400.00
162824	2017-07-13 02:38:00+03	66600.00
1628BA	2017-07-08 11:09:00+03	133100.00
1628F3	2017-07-24 11:54:00+03	41200.00
162929	2017-08-07 12:35:00+03	396500.00
16292D	2017-07-04 07:56:00+03	92000.00
162985	2017-07-11 01:57:00+03	48100.00
162993	2017-08-14 17:32:00+03	7300.00
162A58	2017-08-15 09:38:00+03	137800.00
162A8A	2017-08-04 18:38:00+03	133100.00
162A9D	2017-08-13 22:01:00+03	19600.00
162AEE	2017-06-30 19:23:00+03	38400.00
162B4D	2017-08-02 15:37:00+03	95200.00
162B89	2017-07-10 18:00:00+03	30900.00
162BB7	2017-07-10 08:46:00+03	34000.00
162BE2	2017-08-01 21:34:00+03	24300.00
162CCF	2017-07-26 01:01:00+03	183300.00
162D36	2017-07-18 03:12:00+03	54500.00
162E0A	2017-08-13 21:35:00+03	41200.00
162E21	2017-07-26 23:27:00+03	369000.00
162E2E	2017-08-04 08:54:00+03	56000.00
162EA3	2017-07-13 06:00:00+03	54800.00
162FA7	2017-08-10 11:10:00+03	139400.00
16302F	2017-07-19 08:36:00+03	42400.00
16316B	2017-08-02 02:23:00+03	399600.00
16323D	2017-07-15 16:33:00+03	57900.00
163246	2017-08-15 09:38:00+03	146600.00
163269	2017-08-02 05:02:00+03	60400.00
16327F	2017-08-03 12:06:00+03	122500.00
16328D	2017-08-12 06:48:00+03	50600.00
163357	2017-07-19 18:54:00+03	102100.00
1633AA	2017-07-15 05:53:00+03	123000.00
16343C	2017-07-08 03:45:00+03	131600.00
163449	2017-07-09 05:42:00+03	18800.00
163486	2017-08-07 14:22:00+03	23500.00
1634BF	2017-08-07 04:13:00+03	13600.00
1634C8	2017-07-06 11:30:00+03	98000.00
163532	2017-08-03 03:53:00+03	99500.00
163555	2017-07-08 14:19:00+03	27800.00
163582	2017-07-20 21:46:00+03	184300.00
1635C4	2017-07-30 14:02:00+03	112000.00
1635DB	2017-07-12 03:47:00+03	28700.00
16365D	2017-07-07 13:14:00+03	36000.00
163660	2017-08-12 10:54:00+03	24700.00
163661	2017-08-14 17:00:00+03	24000.00
16366C	2017-08-03 10:07:00+03	38600.00
163699	2017-07-12 00:57:00+03	28000.00
1636A8	2017-08-05 11:27:00+03	152900.00
16372F	2017-07-15 00:14:00+03	39500.00
163784	2017-07-06 05:30:00+03	85000.00
16379E	2017-07-29 18:34:00+03	14000.00
1637E1	2017-07-29 19:58:00+03	18000.00
16384C	2017-07-10 03:11:00+03	34600.00
1638E4	2017-08-12 14:06:00+03	24400.00
16391A	2017-08-08 16:22:00+03	153200.00
163928	2017-07-08 04:21:00+03	79200.00
163940	2017-07-07 17:18:00+03	28600.00
16398B	2017-07-10 13:54:00+03	43300.00
16398D	2017-08-07 16:55:00+03	19600.00
1639B3	2017-07-24 19:24:00+03	64700.00
163A17	2017-08-05 15:45:00+03	198400.00
163A66	2017-07-07 05:26:00+03	105600.00
163A69	2017-08-13 02:26:00+03	75600.00
163AB2	2017-07-29 04:51:00+03	113500.00
163B54	2017-07-22 18:29:00+03	29800.00
163BAF	2017-07-12 16:02:00+03	21800.00
163C22	2017-07-04 07:23:00+03	96200.00
163C28	2017-07-31 20:32:00+03	38600.00
163CD8	2017-08-15 07:18:00+03	48800.00
163CE4	2017-07-07 21:43:00+03	130200.00
163D69	2017-07-03 03:34:00+03	170700.00
163DE4	2017-07-02 00:34:00+03	64500.00
163DF5	2017-08-04 01:37:00+03	19600.00
163E02	2017-07-22 04:23:00+03	95900.00
163E29	2017-07-20 03:36:00+03	51600.00
163E43	2017-08-15 14:42:00+03	111700.00
163E70	2017-07-27 03:15:00+03	54800.00
163E74	2017-08-04 13:23:00+03	69900.00
163EA8	2017-07-05 23:14:00+03	73500.00
163EAC	2017-08-03 07:00:00+03	83900.00
163F23	2017-08-10 04:18:00+03	147700.00
163F4E	2017-07-23 23:07:00+03	34000.00
163FB3	2017-07-10 01:26:00+03	89700.00
163FE7	2017-07-05 13:45:00+03	64500.00
164007	2017-07-31 08:13:00+03	20000.00
164048	2017-08-10 14:32:00+03	40000.00
164073	2017-07-03 13:21:00+03	89600.00
164077	2017-07-21 18:47:00+03	231400.00
164121	2017-07-27 01:28:00+03	35000.00
164167	2017-08-08 21:52:00+03	27200.00
164174	2017-07-01 08:42:00+03	41600.00
16417F	2017-07-09 08:03:00+03	187600.00
1641A4	2017-07-19 01:06:00+03	57600.00
1641DF	2017-08-04 12:40:00+03	38800.00
164295	2017-07-05 04:41:00+03	260300.00
16431D	2017-08-01 04:11:00+03	44000.00
1643F8	2017-07-20 13:18:00+03	36200.00
164404	2017-07-28 03:58:00+03	26000.00
16449F	2017-07-15 19:49:00+03	34000.00
1644B9	2017-07-10 10:29:00+03	212000.00
1644D2	2017-07-20 04:36:00+03	35400.00
16450C	2017-07-06 08:19:00+03	134800.00
16451B	2017-07-24 11:51:00+03	81700.00
164585	2017-07-26 17:16:00+03	58400.00
1645B0	2017-08-02 08:18:00+03	20200.00
1645F1	2017-07-04 20:06:00+03	72800.00
164614	2017-07-26 04:05:00+03	22800.00
164619	2017-07-06 16:59:00+03	66000.00
164688	2017-07-11 15:13:00+03	57500.00
1646AD	2017-07-11 08:32:00+03	28800.00
1646C9	2017-07-16 04:18:00+03	133200.00
1646ED	2017-07-20 22:08:00+03	50800.00
164706	2017-06-29 18:36:00+03	317400.00
1647FA	2017-07-29 04:15:00+03	136800.00
164825	2017-07-17 06:23:00+03	291900.00
164841	2017-07-12 06:49:00+03	32800.00
164842	2017-07-19 00:23:00+03	214000.00
164855	2017-07-11 01:49:00+03	58600.00
1648CD	2017-07-17 02:13:00+03	31600.00
164977	2017-07-18 16:08:00+03	272300.00
16497C	2017-07-11 18:40:00+03	135000.00
164A12	2017-07-24 00:50:00+03	56100.00
164A5E	2017-08-12 05:19:00+03	7300.00
164A80	2017-07-26 09:20:00+03	248300.00
164A9E	2017-07-16 12:43:00+03	143100.00
164AA9	2017-08-06 11:30:00+03	42800.00
164B74	2017-07-02 01:40:00+03	88100.00
164BD5	2017-07-26 22:29:00+03	92000.00
164CC5	2017-07-16 20:33:00+03	9800.00
164D4A	2017-07-09 12:43:00+03	143300.00
164D70	2017-07-20 07:19:00+03	18900.00
164DA3	2017-07-13 11:38:00+03	47600.00
164DBF	2017-07-26 08:27:00+03	62600.00
164DE2	2017-07-09 10:13:00+03	27200.00
164DED	2017-07-31 07:25:00+03	266000.00
164E14	2017-07-22 03:57:00+03	146400.00
164E43	2017-07-29 22:35:00+03	46400.00
164E52	2017-06-26 16:53:00+03	62600.00
164E8B	2017-07-26 08:35:00+03	46300.00
164E97	2017-08-07 18:02:00+03	23200.00
164EB8	2017-08-11 19:04:00+03	73500.00
164EC4	2017-07-11 00:43:00+03	21800.00
164ED2	2017-07-29 22:16:00+03	85000.00
164ED4	2017-08-08 08:13:00+03	14000.00
164F01	2017-07-04 00:30:00+03	73600.00
164F02	2017-08-13 11:48:00+03	16400.00
164F46	2017-07-14 20:25:00+03	38900.00
164F4D	2017-07-19 16:14:00+03	59300.00
165050	2017-07-25 17:17:00+03	40400.00
16508A	2017-07-10 23:26:00+03	137700.00
1650D5	2017-07-07 19:21:00+03	28800.00
1650E7	2017-08-02 13:47:00+03	43500.00
165123	2017-07-21 11:00:00+03	23600.00
16524A	2017-07-02 17:41:00+03	23200.00
1652B0	2017-07-04 01:18:00+03	28300.00
1652CA	2017-07-09 11:09:00+03	82900.00
1652CE	2017-08-02 15:06:00+03	65300.00
16530F	2017-07-25 11:46:00+03	87400.00
16533C	2017-08-03 11:48:00+03	56000.00
16535C	2017-07-30 19:24:00+03	115600.00
16536F	2017-06-28 09:54:00+03	56000.00
1653D9	2017-07-22 04:32:00+03	73300.00
165424	2017-07-15 19:21:00+03	125600.00
165456	2017-06-30 17:40:00+03	27200.00
16546C	2017-07-10 17:57:00+03	35200.00
16546D	2017-07-23 09:57:00+03	122100.00
16547D	2017-08-10 00:19:00+03	34400.00
1654D0	2017-07-12 23:40:00+03	170100.00
1654FD	2017-07-18 04:35:00+03	123800.00
16558C	2017-07-02 04:59:00+03	46200.00
16559E	2017-07-11 21:10:00+03	37200.00
1655B5	2017-07-01 03:28:00+03	397700.00
1655DE	2017-07-08 00:00:00+03	93800.00
165641	2017-08-13 11:45:00+03	68400.00
16576E	2017-07-05 04:42:00+03	70800.00
1657ED	2017-07-21 00:28:00+03	111600.00
1658AC	2017-08-04 17:50:00+03	75200.00
1658BC	2017-07-21 19:50:00+03	38000.00
1658EC	2017-07-29 01:33:00+03	52900.00
165916	2017-07-12 10:21:00+03	71600.00
16591A	2017-08-09 07:01:00+03	226800.00
165927	2017-07-27 12:18:00+03	6000.00
1659BA	2017-08-12 23:25:00+03	85700.00
165A17	2017-07-30 11:15:00+03	124200.00
165A42	2017-07-12 00:58:00+03	29300.00
165AF0	2017-08-04 09:44:00+03	28700.00
165B0C	2017-07-09 20:57:00+03	131600.00
165B91	2017-07-07 23:48:00+03	99200.00
165BAD	2017-08-15 11:14:00+03	13300.00
165C05	2017-07-17 03:26:00+03	4000.00
165C09	2017-08-11 15:45:00+03	38800.00
165C28	2017-08-06 17:12:00+03	34000.00
165C76	2017-08-11 01:37:00+03	89600.00
165CEB	2017-08-12 21:49:00+03	73600.00
165CF7	2017-07-19 15:54:00+03	58200.00
165DC4	2017-08-02 04:28:00+03	297600.00
165E39	2017-07-10 05:41:00+03	68800.00
165E4D	2017-07-21 21:42:00+03	32400.00
165E84	2017-07-24 14:16:00+03	151200.00
165EE2	2017-07-10 14:47:00+03	28000.00
165EF9	2017-08-08 01:15:00+03	81700.00
165EFB	2017-07-02 05:28:00+03	123000.00
165F08	2017-07-08 05:48:00+03	77200.00
165F1D	2017-08-05 19:51:00+03	68400.00
165FB8	2017-08-15 05:35:00+03	28800.00
165FC5	2017-08-05 18:35:00+03	73300.00
165FE1	2017-07-08 02:34:00+03	147700.00
16601B	2017-07-16 21:52:00+03	66000.00
166033	2017-07-29 15:12:00+03	190000.00
16606A	2017-07-08 08:37:00+03	15400.00
166088	2017-07-12 10:41:00+03	25100.00
166106	2017-07-09 19:04:00+03	190400.00
166124	2017-07-10 08:43:00+03	49100.00
1661A6	2017-08-05 15:40:00+03	52900.00
1661AC	2017-08-02 18:10:00+03	48800.00
1661BC	2017-07-03 22:22:00+03	54500.00
1661E2	2017-07-05 21:42:00+03	59500.00
166202	2017-07-13 05:34:00+03	57700.00
16620E	2017-07-31 22:30:00+03	14400.00
166214	2017-07-03 20:23:00+03	55800.00
166274	2017-07-08 16:37:00+03	172700.00
1663A0	2017-08-06 20:44:00+03	29600.00
1663B2	2017-07-06 19:22:00+03	40600.00
166485	2017-07-23 18:32:00+03	90400.00
1664B0	2017-08-12 23:13:00+03	33700.00
1664E9	2017-08-07 14:46:00+03	37900.00
166504	2017-06-29 12:57:00+03	23200.00
16658E	2017-07-22 09:40:00+03	68800.00
1665A7	2017-07-01 16:53:00+03	56700.00
166693	2017-07-20 21:54:00+03	49600.00
166696	2017-07-11 05:49:00+03	56000.00
1666AA	2017-08-07 20:11:00+03	68000.00
1666D9	2017-07-10 05:50:00+03	21800.00
166763	2017-08-12 12:48:00+03	75600.00
16678B	2017-08-07 23:30:00+03	26800.00
166797	2017-07-29 17:43:00+03	131600.00
166844	2017-07-31 02:20:00+03	14800.00
166890	2017-08-05 03:59:00+03	28000.00
16689D	2017-07-17 15:22:00+03	133200.00
166910	2017-08-01 10:36:00+03	11600.00
166911	2017-08-13 18:20:00+03	44800.00
166938	2017-07-18 01:37:00+03	50200.00
16693A	2017-07-29 05:29:00+03	25800.00
1669B5	2017-07-19 04:27:00+03	17200.00
1669C6	2017-08-15 09:32:00+03	23600.00
166A6B	2017-08-11 07:54:00+03	60400.00
166AC7	2017-07-09 05:37:00+03	246000.00
166B34	2017-07-07 00:51:00+03	194300.00
166B8A	2017-08-09 07:01:00+03	103600.00
166C0F	2017-08-08 21:26:00+03	134700.00
166CF1	2017-07-20 14:24:00+03	117200.00
166D2D	2017-07-09 01:43:00+03	26000.00
166D38	2017-07-05 20:51:00+03	30200.00
166DAB	2017-08-11 07:41:00+03	38400.00
166DBB	2017-07-11 18:44:00+03	68400.00
166E10	2017-07-09 00:32:00+03	79000.00
166E1E	2017-07-10 07:22:00+03	95200.00
166E78	2017-06-30 11:34:00+03	96300.00
166EA3	2017-07-09 11:59:00+03	30200.00
166EE9	2017-07-27 05:36:00+03	61800.00
166F30	2017-07-23 00:31:00+03	59800.00
166F48	2017-08-03 03:49:00+03	19600.00
166F7E	2017-07-28 07:24:00+03	29200.00
166F96	2017-08-10 06:53:00+03	11000.00
166FAA	2017-07-03 09:59:00+03	61800.00
166FAF	2017-08-12 19:46:00+03	27200.00
166FBE	2017-07-22 03:22:00+03	62900.00
167001	2017-07-04 02:20:00+03	153200.00
167037	2017-07-02 05:51:00+03	266400.00
16709F	2017-07-04 20:00:00+03	83600.00
1670B4	2017-07-08 06:33:00+03	136800.00
1670CE	2017-08-04 13:46:00+03	355200.00
167129	2017-07-25 09:13:00+03	60800.00
16712A	2017-08-14 13:20:00+03	85000.00
167130	2017-08-03 18:00:00+03	118500.00
167197	2017-07-10 10:57:00+03	111600.00
1671A4	2017-07-30 07:39:00+03	15000.00
167286	2017-08-13 15:00:00+03	72200.00
16728F	2017-07-27 18:29:00+03	26000.00
1672B5	2017-08-10 20:48:00+03	26000.00
1672C2	2017-08-08 03:35:00+03	19800.00
167316	2017-07-20 19:21:00+03	39400.00
167341	2017-07-31 18:05:00+03	23100.00
167346	2017-07-12 21:27:00+03	123200.00
167353	2017-08-01 08:57:00+03	138500.00
16737E	2017-08-08 05:06:00+03	41800.00
1673CC	2017-07-16 02:12:00+03	67600.00
167429	2017-08-09 22:31:00+03	23200.00
16743A	2017-06-29 11:55:00+03	123000.00
167482	2017-07-26 18:16:00+03	396500.00
16751E	2017-07-24 13:02:00+03	68600.00
167551	2017-08-13 11:18:00+03	52000.00
167569	2017-08-09 15:28:00+03	16400.00
167577	2017-08-12 03:04:00+03	24400.00
1675C2	2017-07-27 00:36:00+03	14400.00
1675F2	2017-08-03 08:21:00+03	23900.00
167646	2017-07-12 00:13:00+03	28800.00
1676C8	2017-07-13 23:21:00+03	56900.00
1676CE	2017-07-09 23:56:00+03	57500.00
167739	2017-08-09 19:29:00+03	22000.00
167774	2017-07-05 12:57:00+03	20200.00
1677AB	2017-08-11 17:00:00+03	64400.00
1677D5	2017-07-06 06:35:00+03	25200.00
167881	2017-07-07 06:41:00+03	52700.00
167935	2017-07-14 04:03:00+03	65900.00
167958	2017-07-21 06:08:00+03	52700.00
167964	2017-08-11 17:15:00+03	48800.00
167AAE	2017-07-16 18:04:00+03	101200.00
167AAF	2017-07-21 10:22:00+03	6300.00
167ADA	2017-07-20 03:35:00+03	28600.00
167B22	2017-07-23 19:10:00+03	23400.00
167B34	2017-07-18 21:04:00+03	25400.00
167B54	2017-08-06 02:25:00+03	26700.00
167BB6	2017-07-08 20:22:00+03	136200.00
167BD9	2017-08-13 01:44:00+03	197000.00
167BF6	2017-07-21 17:03:00+03	88500.00
167C20	2017-07-02 16:16:00+03	26000.00
167C82	2017-07-09 09:39:00+03	55800.00
167CBD	2017-07-21 08:38:00+03	23200.00
167D02	2017-08-10 22:56:00+03	6000.00
167D55	2017-08-14 02:40:00+03	32800.00
167D6F	2017-07-13 09:50:00+03	28000.00
167D7D	2017-07-30 07:01:00+03	24400.00
167D84	2017-07-24 14:10:00+03	75600.00
167D96	2017-08-01 16:32:00+03	44800.00
167DCE	2017-07-19 09:10:00+03	46300.00
167E38	2017-07-12 17:23:00+03	70700.00
167E3E	2017-07-24 16:24:00+03	74800.00
167E4B	2017-07-25 18:59:00+03	29200.00
167EAF	2017-08-12 01:55:00+03	79000.00
167F06	2017-07-25 03:25:00+03	51900.00
167F25	2017-07-23 02:08:00+03	111600.00
167F39	2017-08-09 14:45:00+03	28800.00
167F58	2017-07-30 08:11:00+03	119600.00
167F59	2017-07-10 06:42:00+03	46000.00
167FDD	2017-08-06 05:27:00+03	77900.00
167FE2	2017-08-05 06:52:00+03	26800.00
167FEF	2017-07-17 15:32:00+03	46500.00
168019	2017-08-13 04:26:00+03	29800.00
1680A2	2017-08-13 15:46:00+03	21800.00
1680F2	2017-07-21 23:13:00+03	18800.00
168110	2017-08-08 15:43:00+03	44800.00
168181	2017-08-14 07:23:00+03	68400.00
16824A	2017-07-29 05:21:00+03	106700.00
1682D4	2017-07-09 13:03:00+03	163300.00
1682F5	2017-07-14 04:36:00+03	169900.00
168366	2017-07-08 16:30:00+03	154900.00
16836D	2017-07-15 23:11:00+03	31800.00
16836F	2017-07-30 23:16:00+03	22000.00
16839A	2017-08-15 15:37:00+03	75600.00
16839B	2017-07-11 01:26:00+03	14000.00
1683C4	2017-08-12 09:48:00+03	28000.00
1683FF	2017-07-17 20:36:00+03	136800.00
168424	2017-07-19 00:33:00+03	18600.00
16842C	2017-07-28 10:40:00+03	111600.00
16846A	2017-08-06 01:34:00+03	12600.00
16850D	2017-07-31 19:26:00+03	32200.00
168520	2017-07-24 01:33:00+03	21200.00
168532	2017-07-11 15:17:00+03	42700.00
168590	2017-07-25 11:08:00+03	20800.00
1685CC	2017-07-29 22:52:00+03	182300.00
1685E9	2017-08-03 14:37:00+03	182300.00
16863C	2017-07-08 20:35:00+03	128800.00
168670	2017-08-03 14:28:00+03	59800.00
168685	2017-07-21 11:50:00+03	79900.00
168686	2017-07-25 10:35:00+03	55800.00
168691	2017-07-13 10:07:00+03	32700.00
1686DD	2017-07-29 08:43:00+03	58000.00
1686E5	2017-07-24 11:10:00+03	29300.00
1686F1	2017-08-06 08:12:00+03	102700.00
16873B	2017-07-05 21:06:00+03	26000.00
168799	2017-08-08 22:06:00+03	28800.00
1687C3	2017-07-07 10:59:00+03	53600.00
1687EC	2017-07-17 23:20:00+03	59500.00
16885E	2017-07-16 00:21:00+03	44800.00
1688EC	2017-07-18 18:03:00+03	43600.00
168915	2017-07-23 23:48:00+03	136200.00
168950	2017-07-21 04:34:00+03	60900.00
168960	2017-08-14 15:56:00+03	28800.00
16897B	2017-08-07 03:57:00+03	123600.00
168998	2017-08-14 18:52:00+03	60400.00
1689F4	2017-08-07 22:24:00+03	58000.00
168A1A	2017-07-11 05:18:00+03	54800.00
168AC8	2017-07-19 07:05:00+03	13800.00
168B4E	2017-07-06 08:58:00+03	167400.00
168BB0	2017-07-29 15:58:00+03	155600.00
168BBE	2017-07-01 05:42:00+03	339800.00
168BF4	2017-07-20 04:10:00+03	90800.00
168C79	2017-07-27 21:08:00+03	32200.00
168C89	2017-07-14 06:38:00+03	31800.00
168CAB	2017-07-18 10:56:00+03	32800.00
168CCB	2017-07-23 01:07:00+03	42800.00
168CCC	2017-07-29 23:22:00+03	50600.00
168D1A	2017-07-20 04:21:00+03	131100.00
168D37	2017-08-08 05:01:00+03	27200.00
168D4E	2017-07-17 16:54:00+03	65200.00
168D66	2017-08-05 23:50:00+03	39200.00
168D72	2017-07-18 20:05:00+03	38600.00
168D8F	2017-07-27 16:21:00+03	26700.00
168DB4	2017-08-01 13:23:00+03	148200.00
168DFC	2017-07-12 04:47:00+03	57600.00
168E0A	2017-07-22 22:07:00+03	40800.00
168E2F	2017-07-08 08:18:00+03	181600.00
168E65	2017-07-21 19:24:00+03	58000.00
168F51	2017-07-28 03:13:00+03	67100.00
168F78	2017-07-14 18:20:00+03	58000.00
168F82	2017-08-13 03:24:00+03	6300.00
168FE6	2017-07-30 11:57:00+03	21800.00
169002	2017-08-05 17:21:00+03	103400.00
169028	2017-08-15 05:55:00+03	21300.00
169089	2017-07-16 22:17:00+03	35600.00
169108	2017-07-24 09:48:00+03	76800.00
169137	2017-08-04 15:34:00+03	28800.00
169151	2017-08-13 23:00:00+03	63500.00
16915E	2017-07-04 06:12:00+03	133100.00
169231	2017-07-18 15:23:00+03	29600.00
1692AA	2017-08-06 06:27:00+03	15000.00
169334	2017-08-11 07:21:00+03	182000.00
169336	2017-07-29 21:16:00+03	41200.00
16933B	2017-07-04 18:22:00+03	124200.00
169390	2017-08-13 12:46:00+03	131600.00
169394	2017-07-27 07:03:00+03	69500.00
169396	2017-08-03 10:44:00+03	26000.00
1693A7	2017-07-13 03:33:00+03	147700.00
1693CC	2017-07-15 02:17:00+03	23400.00
1693CF	2017-08-01 11:10:00+03	19600.00
16943F	2017-07-31 22:38:00+03	153900.00
169549	2017-08-08 03:05:00+03	30800.00
169554	2017-07-29 20:33:00+03	37100.00
169568	2017-08-15 16:34:00+03	52700.00
169590	2017-07-18 13:43:00+03	49400.00
16964E	2017-07-30 08:55:00+03	113000.00
169661	2017-08-09 10:49:00+03	56000.00
16967F	2017-08-05 00:34:00+03	398400.00
1696E2	2017-08-14 06:18:00+03	36200.00
16973F	2017-07-26 21:58:00+03	6300.00
169768	2017-07-07 13:11:00+03	36200.00
1697A1	2017-07-13 05:31:00+03	75300.00
1697BB	2017-07-18 14:38:00+03	78400.00
1697D5	2017-07-24 20:40:00+03	26000.00
1697DE	2017-07-24 21:22:00+03	65900.00
1697EB	2017-08-11 08:48:00+03	39800.00
16980D	2017-07-05 09:27:00+03	80000.00
169831	2017-07-04 01:10:00+03	117900.00
169845	2017-08-15 13:52:00+03	92600.00
169890	2017-08-10 05:01:00+03	38200.00
1698A6	2017-08-05 18:19:00+03	281500.00
1698E0	2017-07-16 12:06:00+03	32700.00
169929	2017-07-12 17:08:00+03	62900.00
16998F	2017-07-25 05:52:00+03	224000.00
169993	2017-08-14 09:40:00+03	516800.00
1699DA	2017-07-04 00:51:00+03	66600.00
169A50	2017-07-12 23:03:00+03	57400.00
169ACE	2017-08-10 15:32:00+03	8200.00
169BE1	2017-08-07 23:31:00+03	66700.00
169C3A	2017-07-03 17:07:00+03	134400.00
169C40	2017-08-14 06:19:00+03	36100.00
169C49	2017-08-01 11:32:00+03	31300.00
169C6A	2017-07-11 01:58:00+03	123000.00
169CA9	2017-07-14 22:32:00+03	23100.00
169D32	2017-08-01 03:00:00+03	72400.00
169D69	2017-07-25 12:27:00+03	33200.00
169D7F	2017-07-05 09:16:00+03	115800.00
169D88	2017-07-24 04:49:00+03	369000.00
169DDB	2017-07-13 14:37:00+03	94700.00
169DF5	2017-07-31 16:43:00+03	26800.00
169E73	2017-07-10 03:17:00+03	88500.00
169E9D	2017-08-05 04:16:00+03	41400.00
169EEC	2017-07-27 09:47:00+03	56000.00
169F01	2017-08-03 14:59:00+03	43300.00
169F1F	2017-07-08 10:33:00+03	88500.00
169F85	2017-06-29 00:44:00+03	248400.00
169F95	2017-08-07 06:40:00+03	48500.00
169F9C	2017-08-02 17:59:00+03	22600.00
169FAD	2017-06-29 15:27:00+03	27800.00
169FBD	2017-07-12 12:12:00+03	114400.00
16A051	2017-07-23 14:25:00+03	87700.00
16A070	2017-07-27 18:39:00+03	187900.00
16A071	2017-08-03 05:45:00+03	55800.00
16A07E	2017-06-30 06:53:00+03	19600.00
16A121	2017-08-07 20:09:00+03	25200.00
16A122	2017-07-10 09:07:00+03	140500.00
16A171	2017-07-04 22:26:00+03	65600.00
16A184	2017-07-02 02:01:00+03	124800.00
16A1AC	2017-07-17 04:25:00+03	40000.00
16A1B3	2017-07-12 17:50:00+03	23200.00
16A241	2017-07-14 16:19:00+03	71900.00
16A27E	2017-08-08 10:06:00+03	21500.00
16A292	2017-08-14 19:22:00+03	30800.00
16A345	2017-08-14 15:45:00+03	68100.00
16A349	2017-08-01 12:23:00+03	12400.00
16A35F	2017-08-03 21:33:00+03	277800.00
16A38F	2017-07-11 08:21:00+03	59700.00
16A3A0	2017-07-13 07:58:00+03	68100.00
16A3DA	2017-07-26 23:32:00+03	174600.00
16A496	2017-07-28 09:45:00+03	55000.00
16A4BA	2017-07-14 20:30:00+03	75600.00
16A522	2017-08-12 03:10:00+03	31800.00
16A523	2017-06-30 12:34:00+03	48900.00
16A542	2017-08-07 17:06:00+03	123000.00
16A54E	2017-07-13 17:41:00+03	28700.00
16A55A	2017-07-22 15:06:00+03	26700.00
16A567	2017-07-29 00:05:00+03	46200.00
16A59E	2017-07-08 13:15:00+03	28800.00
16A5A5	2017-07-13 02:05:00+03	112000.00
16A5EA	2017-07-18 17:34:00+03	23200.00
16A619	2017-07-01 07:33:00+03	12600.00
16A63D	2017-07-23 23:26:00+03	73500.00
16A686	2017-07-30 06:54:00+03	129200.00
16A6BA	2017-08-13 06:41:00+03	36200.00
16A753	2017-07-20 02:29:00+03	272400.00
16A780	2017-08-09 17:31:00+03	6300.00
16A7A0	2017-08-13 06:08:00+03	266400.00
16A822	2017-07-24 07:41:00+03	32800.00
16A848	2017-07-07 10:27:00+03	142700.00
16A8B6	2017-08-15 04:07:00+03	23600.00
16A8CD	2017-07-12 22:10:00+03	34000.00
16A8D3	2017-08-02 09:10:00+03	50100.00
16A8D5	2017-07-31 05:20:00+03	13400.00
16A909	2017-07-26 09:47:00+03	180800.00
16A942	2017-08-06 00:54:00+03	34400.00
16A981	2017-07-28 12:15:00+03	33100.00
16A99C	2017-08-10 19:07:00+03	169200.00
16A9A2	2017-07-03 07:27:00+03	32700.00
16A9C3	2017-08-11 12:23:00+03	119500.00
16AA0A	2017-08-11 08:04:00+03	37200.00
16AA2B	2017-08-09 22:35:00+03	36600.00
16AA2D	2017-07-25 14:40:00+03	83700.00
16AA59	2017-07-14 22:28:00+03	100300.00
16AAA6	2017-08-09 07:51:00+03	56600.00
16AAE7	2017-07-20 19:06:00+03	95600.00
16AAF4	2017-08-09 02:30:00+03	24700.00
16AB1B	2017-07-22 23:25:00+03	44800.00
16AB53	2017-07-06 06:25:00+03	31600.00
16ABA4	2017-07-17 23:28:00+03	49100.00
16ABA6	2017-08-07 09:50:00+03	45100.00
16AC2B	2017-07-28 07:54:00+03	95600.00
16ACB9	2017-08-08 15:38:00+03	108500.00
16AD01	2017-07-08 03:31:00+03	48300.00
16AD06	2017-08-07 11:14:00+03	98400.00
16AD69	2017-07-10 15:53:00+03	66000.00
16AE0B	2017-07-18 06:59:00+03	57200.00
16AE69	2017-07-23 23:47:00+03	145700.00
16AE81	2017-07-31 18:21:00+03	313800.00
16AE9E	2017-07-06 20:17:00+03	62600.00
16AEDC	2017-06-30 03:19:00+03	27300.00
16AF20	2017-07-15 14:06:00+03	6000.00
16AF30	2017-07-06 23:23:00+03	12600.00
16AF67	2017-08-07 06:15:00+03	23400.00
16AF7B	2017-07-17 04:18:00+03	50800.00
16AF7D	2017-07-04 19:50:00+03	135600.00
16AFB9	2017-08-10 12:37:00+03	97200.00
16AFE1	2017-07-27 18:44:00+03	94000.00
16AFF3	2017-07-03 08:41:00+03	66600.00
16B026	2017-07-08 23:18:00+03	32700.00
16B027	2017-07-31 06:15:00+03	23200.00
16B04A	2017-08-13 02:49:00+03	52000.00
16B04C	2017-07-03 02:46:00+03	20200.00
16B0F0	2017-08-07 00:44:00+03	147700.00
16B121	2017-07-25 08:52:00+03	27200.00
16B16E	2017-07-30 04:49:00+03	88600.00
16B17C	2017-07-11 18:01:00+03	72800.00
16B17E	2017-08-14 09:26:00+03	28800.00
16B1B2	2017-07-15 20:33:00+03	36200.00
16B20B	2017-07-02 11:19:00+03	67600.00
16B223	2017-07-07 03:22:00+03	49100.00
16B232	2017-07-10 17:31:00+03	36800.00
16B248	2017-08-12 09:16:00+03	36800.00
16B25D	2017-07-02 05:38:00+03	52100.00
16B25E	2017-07-16 09:27:00+03	21800.00
16B279	2017-07-08 07:01:00+03	113300.00
16B293	2017-08-10 05:42:00+03	265600.00
16B305	2017-07-27 02:05:00+03	67900.00
16B318	2017-07-31 07:00:00+03	71200.00
16B335	2017-07-12 01:15:00+03	271100.00
16B3E5	2017-08-08 05:41:00+03	52900.00
16B40F	2017-08-15 15:33:00+03	71200.00
16B419	2017-07-18 12:01:00+03	34000.00
16B42F	2017-08-07 03:13:00+03	26000.00
16B460	2017-08-08 21:18:00+03	37900.00
16B538	2017-07-14 13:41:00+03	135400.00
16B584	2017-07-21 18:50:00+03	56300.00
16B5BD	2017-08-01 08:18:00+03	99600.00
16B607	2017-08-01 03:14:00+03	369000.00
16B663	2017-07-29 22:44:00+03	26000.00
16B66D	2017-07-03 08:30:00+03	32800.00
16B674	2017-07-02 08:28:00+03	44800.00
16B694	2017-07-12 18:23:00+03	57500.00
16B6B0	2017-07-22 14:15:00+03	265600.00
16B6B6	2017-08-06 07:30:00+03	260300.00
16B7A7	2017-07-28 10:49:00+03	25600.00
16B8B3	2017-07-24 00:54:00+03	100600.00
16B8C6	2017-08-10 07:09:00+03	116400.00
16B907	2017-07-22 09:14:00+03	86500.00
16B91F	2017-07-07 22:14:00+03	29600.00
16B941	2017-07-12 04:23:00+03	65500.00
16B9D4	2017-07-31 14:00:00+03	12600.00
16BA1E	2017-08-08 07:48:00+03	69500.00
16BA40	2017-07-30 15:06:00+03	122700.00
16BA72	2017-08-02 23:16:00+03	92400.00
16BAA9	2017-07-27 04:26:00+03	14000.00
16BAF5	2017-07-20 01:51:00+03	68100.00
16BB07	2017-07-15 14:09:00+03	12000.00
16BB35	2017-07-29 09:33:00+03	31200.00
16BB5C	2017-08-11 04:01:00+03	31200.00
16BB8C	2017-06-30 14:27:00+03	102100.00
16BD2E	2017-08-12 18:52:00+03	32800.00
16BD90	2017-08-07 07:58:00+03	24700.00
16BDC7	2017-07-06 23:33:00+03	32800.00
16BDDE	2017-07-05 01:03:00+03	94900.00
16BE42	2017-07-28 11:59:00+03	28800.00
16BE9F	2017-07-05 18:46:00+03	68800.00
16BF71	2017-08-06 19:56:00+03	23600.00
16BF8F	2017-07-21 15:49:00+03	110500.00
16BF9E	2017-07-16 22:52:00+03	99300.00
16BFBB	2017-07-13 17:11:00+03	16400.00
16BFBE	2017-07-02 08:27:00+03	369000.00
16C09A	2017-07-29 22:15:00+03	119700.00
16C0AE	2017-08-15 13:49:00+03	40100.00
16C0F6	2017-07-28 10:33:00+03	44800.00
16C118	2017-07-25 07:17:00+03	91200.00
16C16F	2017-08-04 15:39:00+03	20000.00
16C1D2	2017-08-11 20:46:00+03	28000.00
16C1E5	2017-06-30 14:45:00+03	43500.00
16C201	2017-07-21 07:59:00+03	55800.00
16C20A	2017-07-20 17:41:00+03	28800.00
16C248	2017-08-12 12:15:00+03	37200.00
16C274	2017-07-22 16:32:00+03	199300.00
16C29E	2017-07-25 23:42:00+03	130300.00
16C2CF	2017-07-22 14:50:00+03	258400.00
16C2DC	2017-07-27 22:33:00+03	43400.00
16C3CE	2017-07-20 12:05:00+03	39600.00
16C41D	2017-07-12 05:20:00+03	123000.00
16C46D	2017-07-07 14:48:00+03	12200.00
16C514	2017-08-08 21:13:00+03	28000.00
16C536	2017-07-14 05:01:00+03	40100.00
16C58B	2017-08-05 22:25:00+03	58200.00
16C59A	2017-07-21 23:53:00+03	547000.00
16C5F9	2017-07-17 22:48:00+03	185600.00
16C609	2017-08-15 10:21:00+03	23400.00
16C629	2017-07-03 14:46:00+03	73500.00
16C66E	2017-07-24 08:55:00+03	114800.00
16C67C	2017-07-26 07:30:00+03	54800.00
16C6D9	2017-08-12 13:55:00+03	62000.00
16C710	2017-07-31 10:55:00+03	42800.00
16C743	2017-07-14 16:13:00+03	41600.00
16C752	2017-08-08 04:31:00+03	44800.00
16C763	2017-07-11 19:19:00+03	27400.00
16C78E	2017-08-13 08:58:00+03	102700.00
16C83B	2017-08-04 01:40:00+03	98300.00
16C84F	2017-07-18 06:26:00+03	96800.00
16C852	2017-08-15 02:04:00+03	28000.00
16C8DE	2017-08-11 04:44:00+03	56000.00
16C984	2017-08-05 11:06:00+03	76800.00
16C9A5	2017-07-06 09:58:00+03	23500.00
16C9FB	2017-07-24 17:43:00+03	61500.00
16C9FD	2017-08-14 11:31:00+03	201800.00
16CA2A	2017-07-04 16:42:00+03	39000.00
16CA34	2017-07-16 13:53:00+03	61800.00
16CA54	2017-07-29 18:19:00+03	46800.00
16CA75	2017-08-10 11:07:00+03	157100.00
16CA8E	2017-08-06 13:12:00+03	40800.00
16CAF3	2017-07-14 16:45:00+03	24400.00
16CB7D	2017-08-06 12:30:00+03	155600.00
16CBBE	2017-06-30 00:00:00+03	48800.00
16CBD2	2017-07-23 07:00:00+03	64800.00
16CBD6	2017-07-09 09:41:00+03	56600.00
16CBF7	2017-07-31 06:07:00+03	12400.00
16CBFB	2017-07-17 02:47:00+03	80900.00
16CC2E	2017-07-24 23:11:00+03	170700.00
16CC8A	2017-08-08 21:19:00+03	93400.00
16CD13	2017-07-29 05:13:00+03	96800.00
16CD2F	2017-07-06 15:13:00+03	53600.00
16CD30	2017-08-08 01:34:00+03	117500.00
16CD31	2017-07-21 10:35:00+03	56600.00
16CD94	2017-08-06 19:18:00+03	62600.00
16CD95	2017-08-12 09:18:00+03	62600.00
16CDA3	2017-07-18 05:19:00+03	43200.00
16CDC3	2017-08-01 21:48:00+03	6000.00
16CE8D	2017-07-22 22:12:00+03	57700.00
16CF2B	2017-07-04 18:29:00+03	6700.00
16CF33	2017-08-08 03:40:00+03	258400.00
16CF34	2017-07-07 00:58:00+03	75300.00
16CF75	2017-08-04 01:38:00+03	77900.00
16CF7F	2017-07-29 21:17:00+03	103800.00
16CFC3	2017-08-05 02:43:00+03	75000.00
16D02C	2017-08-05 13:10:00+03	14000.00
16D07C	2017-08-10 14:59:00+03	6300.00
16D0AB	2017-08-07 20:48:00+03	77900.00
16D0DD	2017-08-04 13:48:00+03	110500.00
16D0E4	2017-07-23 05:04:00+03	109600.00
16D128	2017-08-11 00:38:00+03	87200.00
16D176	2017-07-02 05:36:00+03	125200.00
16D1FC	2017-06-30 02:05:00+03	67000.00
16D1FF	2017-07-30 09:55:00+03	28000.00
16D21A	2017-07-03 21:26:00+03	55800.00
16D253	2017-07-31 01:34:00+03	50600.00
16D2B6	2017-08-07 15:01:00+03	289300.00
16D2E4	2017-07-29 12:55:00+03	63200.00
16D30A	2017-07-14 09:25:00+03	48700.00
16D31E	2017-07-16 15:33:00+03	56800.00
16D356	2017-08-11 01:06:00+03	369000.00
16D397	2017-07-07 23:09:00+03	44800.00
16D3D0	2017-07-09 13:20:00+03	112000.00
16D4D3	2017-07-10 13:24:00+03	50000.00
16D4E0	2017-07-12 07:28:00+03	80900.00
16D62A	2017-08-10 10:22:00+03	132800.00
16D630	2017-08-09 14:21:00+03	88100.00
16D646	2017-07-03 04:30:00+03	24800.00
16D648	2017-07-06 18:03:00+03	71600.00
16D65E	2017-07-13 03:59:00+03	40600.00
16D6EA	2017-07-26 13:23:00+03	28800.00
16D6FE	2017-08-02 23:39:00+03	75600.00
16D720	2017-07-06 23:03:00+03	123000.00
16D73E	2017-08-08 02:06:00+03	56900.00
16D78E	2017-08-09 06:30:00+03	70700.00
16D7FC	2017-07-09 19:59:00+03	57400.00
16D83B	2017-07-31 07:46:00+03	81500.00
16D8B9	2017-08-02 13:58:00+03	13300.00
16D8E4	2017-08-02 01:08:00+03	22000.00
16D8F3	2017-07-09 15:25:00+03	177200.00
16D8F9	2017-06-30 20:03:00+03	94700.00
16D91D	2017-07-31 04:40:00+03	83200.00
16D92E	2017-07-20 00:28:00+03	258700.00
16DA17	2017-07-29 02:46:00+03	246000.00
16DA25	2017-07-20 10:33:00+03	24200.00
16DA56	2017-07-07 06:30:00+03	65900.00
16DA75	2017-07-31 23:04:00+03	8400.00
16DA8B	2017-08-14 22:01:00+03	27200.00
16DB16	2017-08-11 03:08:00+03	31000.00
16DB1E	2017-08-04 21:20:00+03	187600.00
16DB6E	2017-08-08 13:28:00+03	168000.00
16DBCD	2017-08-10 08:27:00+03	55800.00
16DBFC	2017-08-11 23:02:00+03	26700.00
16DC9C	2017-07-08 08:32:00+03	59200.00
16DCA6	2017-08-13 01:37:00+03	52300.00
16DCAD	2017-08-01 22:48:00+03	123400.00
16DCEC	2017-06-30 22:12:00+03	30400.00
16DD7F	2017-08-09 21:16:00+03	197700.00
16DDB1	2017-07-05 06:59:00+03	27400.00
16DDC7	2017-07-14 06:16:00+03	101200.00
16DE20	2017-07-07 01:29:00+03	46400.00
16DE50	2017-07-03 10:41:00+03	47000.00
16DEA6	2017-08-03 07:56:00+03	174400.00
16DEEC	2017-07-30 15:58:00+03	72400.00
16DF0E	2017-08-03 23:08:00+03	39700.00
16DF1E	2017-08-08 14:49:00+03	179400.00
16DF5F	2017-07-28 16:01:00+03	7400.00
16DFC0	2017-07-28 21:49:00+03	56000.00
16E031	2017-07-15 16:26:00+03	89800.00
16E071	2017-08-11 01:32:00+03	21600.00
16E07F	2017-08-10 19:11:00+03	75600.00
16E0E3	2017-07-06 08:25:00+03	95200.00
16E0EA	2017-08-06 15:23:00+03	44000.00
16E0FF	2017-07-24 04:13:00+03	100600.00
16E120	2017-08-08 02:21:00+03	23200.00
16E12D	2017-07-11 07:11:00+03	56000.00
16E149	2017-08-13 12:01:00+03	280000.00
16E14A	2017-08-14 07:34:00+03	61800.00
16E163	2017-07-24 09:53:00+03	6700.00
16E1A0	2017-07-03 04:06:00+03	122300.00
16E1E3	2017-07-29 03:58:00+03	104800.00
16E1E7	2017-08-10 05:20:00+03	29600.00
16E20F	2017-07-05 01:40:00+03	37900.00
16E219	2017-07-08 18:54:00+03	75800.00
16E269	2017-07-16 09:50:00+03	55800.00
16E324	2017-07-27 05:27:00+03	73600.00
16E35D	2017-07-25 22:39:00+03	56000.00
16E365	2017-08-06 14:09:00+03	27800.00
16E374	2017-08-09 07:57:00+03	133200.00
16E410	2017-07-20 20:14:00+03	24400.00
16E420	2017-08-13 08:04:00+03	67000.00
16E475	2017-07-16 05:05:00+03	124200.00
16E4B6	2017-07-22 20:08:00+03	56200.00
16E528	2017-08-05 01:19:00+03	23200.00
16E53B	2017-07-15 20:49:00+03	8000.00
16E5BB	2017-08-03 04:21:00+03	86600.00
16E61C	2017-07-31 15:25:00+03	21200.00
16E640	2017-08-09 13:05:00+03	8000.00
16E6A1	2017-08-06 05:49:00+03	28000.00
16E709	2017-07-26 21:29:00+03	64700.00
16E722	2017-08-03 22:41:00+03	11800.00
16E738	2017-07-23 05:36:00+03	75700.00
16E7D1	2017-07-11 01:33:00+03	59800.00
16E865	2017-08-03 16:10:00+03	72700.00
16E8AF	2017-07-10 09:13:00+03	39600.00
16E8CA	2017-07-12 02:33:00+03	48500.00
16E902	2017-08-08 16:20:00+03	99200.00
16E92F	2017-07-15 09:59:00+03	128900.00
16E967	2017-08-01 07:37:00+03	112000.00
16E977	2017-08-15 10:56:00+03	29600.00
16E97F	2017-07-13 23:42:00+03	23600.00
16E98F	2017-07-19 12:09:00+03	21400.00
16E9C8	2017-08-01 05:35:00+03	85000.00
16E9E7	2017-07-05 14:17:00+03	13600.00
16EAD6	2017-08-09 08:47:00+03	40100.00
16EB12	2017-07-22 12:17:00+03	148400.00
16EB8A	2017-08-01 22:11:00+03	49500.00
16EBA4	2017-07-31 16:55:00+03	22200.00
16EBA7	2017-07-02 14:05:00+03	73600.00
16EC3F	2017-07-26 21:59:00+03	20400.00
16ECFC	2017-08-14 20:44:00+03	49100.00
16ED04	2017-07-30 17:30:00+03	12400.00
16ED28	2017-07-11 00:54:00+03	6600.00
16EDA7	2017-07-26 00:39:00+03	30000.00
16EDB7	2017-08-14 07:06:00+03	25200.00
16EE11	2017-07-17 04:38:00+03	37900.00
16EE3E	2017-07-20 17:38:00+03	56000.00
16EE81	2017-08-10 07:26:00+03	58400.00
16EEB4	2017-08-08 15:59:00+03	67200.00
16EF39	2017-08-13 19:26:00+03	39300.00
16EF80	2017-07-21 03:24:00+03	183300.00
16EF8C	2017-07-29 04:00:00+03	37900.00
16EFA4	2017-07-21 14:16:00+03	76600.00
16EFE3	2017-06-30 12:27:00+03	22000.00
16F007	2017-07-13 10:13:00+03	74800.00
16F031	2017-07-24 23:41:00+03	85700.00
16F033	2017-07-20 08:41:00+03	51900.00
16F04E	2017-07-09 01:56:00+03	14800.00
16F0BD	2017-08-10 02:46:00+03	61300.00
16F0C0	2017-07-24 18:44:00+03	25600.00
16F0EF	2017-07-06 12:03:00+03	27200.00
16F0FE	2017-07-08 06:25:00+03	47600.00
16F11C	2017-08-14 19:05:00+03	24400.00
16F12D	2017-08-10 01:07:00+03	58400.00
16F1DD	2017-07-23 03:01:00+03	26200.00
16F1E8	2017-07-24 19:14:00+03	168300.00
16F2C4	2017-07-20 05:08:00+03	27200.00
16F2E1	2017-07-26 20:39:00+03	126700.00
16F2EB	2017-08-01 22:59:00+03	40000.00
16F2F0	2017-06-29 14:01:00+03	37200.00
16F302	2017-07-01 09:52:00+03	198400.00
16F31F	2017-07-08 14:26:00+03	78600.00
16F326	2017-07-27 02:48:00+03	128900.00
16F34F	2017-07-27 08:37:00+03	16400.00
16F3AF	2017-07-20 16:01:00+03	27800.00
16F3CA	2017-08-10 09:15:00+03	93900.00
16F3DA	2017-08-11 16:27:00+03	23400.00
16F412	2017-07-05 03:16:00+03	66600.00
16F478	2017-07-23 00:00:00+03	52000.00
16F47D	2017-07-14 03:58:00+03	25200.00
16F4B3	2017-07-23 05:40:00+03	40800.00
16F524	2017-07-09 02:14:00+03	23200.00
16F542	2017-07-19 15:10:00+03	27200.00
16F5B4	2017-07-16 03:23:00+03	48800.00
16F5B9	2017-07-24 04:14:00+03	14800.00
16F641	2017-07-19 11:11:00+03	42700.00
16F667	2017-08-08 19:36:00+03	23200.00
16F6A6	2017-07-25 07:27:00+03	25600.00
16F75E	2017-07-07 21:29:00+03	42800.00
16F77A	2017-07-18 01:48:00+03	91600.00
16F832	2017-08-08 15:01:00+03	79200.00
16F869	2017-07-03 01:17:00+03	62600.00
16F961	2017-08-05 16:40:00+03	38600.00
16F9C7	2017-07-15 06:52:00+03	68400.00
16F9D6	2017-08-08 04:29:00+03	108200.00
16F9E4	2017-08-05 08:25:00+03	6700.00
16FA2F	2017-08-01 20:40:00+03	26000.00
16FAD9	2017-07-19 01:21:00+03	41800.00
16FADA	2017-07-14 02:20:00+03	184300.00
16FAF8	2017-08-04 22:56:00+03	13600.00
16FB08	2017-07-22 03:52:00+03	185500.00
16FB89	2017-07-01 15:51:00+03	23200.00
16FB9A	2017-07-05 12:51:00+03	47100.00
16FBAF	2017-08-06 22:03:00+03	12600.00
16FBD1	2017-07-23 21:35:00+03	113500.00
16FC5E	2017-07-19 14:51:00+03	64100.00
16FD73	2017-07-17 13:28:00+03	62600.00
16FDA6	2017-07-01 17:22:00+03	38200.00
16FDAC	2017-07-11 04:40:00+03	43800.00
16FDD0	2017-07-20 13:10:00+03	77900.00
16FE09	2017-07-12 22:30:00+03	14000.00
16FE17	2017-07-20 16:11:00+03	25400.00
16FE18	2017-07-28 23:07:00+03	26000.00
16FE58	2017-08-12 10:16:00+03	97800.00
16FE5A	2017-07-17 00:23:00+03	92700.00
16FE79	2017-07-23 03:22:00+03	28800.00
16FF16	2017-08-07 11:58:00+03	65600.00
16FF42	2017-07-29 19:35:00+03	23400.00
16FF57	2017-07-18 09:52:00+03	72200.00
170003	2017-07-18 12:07:00+03	137100.00
17002C	2017-07-17 15:06:00+03	98700.00
170055	2017-07-23 10:01:00+03	133900.00
170095	2017-07-29 05:38:00+03	54800.00
1700E7	2017-08-14 21:27:00+03	67200.00
17012C	2017-08-07 07:25:00+03	26800.00
1701B5	2017-07-09 21:38:00+03	272700.00
170236	2017-08-03 23:53:00+03	170400.00
1702B6	2017-08-04 02:17:00+03	69000.00
1702E8	2017-07-14 15:03:00+03	65900.00
17030F	2017-08-04 06:09:00+03	57500.00
170334	2017-08-14 14:10:00+03	150600.00
170338	2017-07-27 12:33:00+03	267500.00
17033C	2017-07-10 11:38:00+03	92200.00
170355	2017-07-15 12:39:00+03	541500.00
1703C3	2017-07-28 10:40:00+03	26700.00
1703DF	2017-08-04 18:59:00+03	121400.00
17042C	2017-07-13 11:55:00+03	46000.00
17046E	2017-07-11 14:57:00+03	45100.00
1704BC	2017-08-01 09:59:00+03	258400.00
170519	2017-07-06 14:18:00+03	34600.00
170566	2017-07-24 11:06:00+03	406100.00
17056A	2017-07-08 06:36:00+03	7200.00
17056F	2017-07-10 07:32:00+03	166700.00
170697	2017-07-10 03:50:00+03	93900.00
1706A3	2017-08-04 23:52:00+03	124200.00
170779	2017-08-12 06:56:00+03	35200.00
170808	2017-08-04 10:29:00+03	67600.00
170809	2017-07-21 18:43:00+03	65600.00
17080D	2017-08-09 22:39:00+03	84500.00
170834	2017-07-02 09:20:00+03	124200.00
17088C	2017-07-25 18:17:00+03	62600.00
1708F5	2017-08-13 13:56:00+03	33300.00
17092B	2017-07-27 23:39:00+03	55000.00
170A25	2017-07-08 10:46:00+03	12000.00
170A59	2017-08-04 04:34:00+03	43600.00
170A69	2017-07-06 01:29:00+03	52000.00
170A90	2017-08-12 11:53:00+03	36700.00
170B0E	2017-08-10 07:09:00+03	24400.00
170B32	2017-07-08 20:07:00+03	93900.00
170B38	2017-07-28 03:18:00+03	86800.00
170B81	2017-07-05 06:22:00+03	23600.00
170C02	2017-08-08 13:01:00+03	123200.00
170C0E	2017-07-27 08:31:00+03	74400.00
170CBC	2017-07-14 01:28:00+03	113000.00
170D19	2017-07-02 04:10:00+03	28000.00
170D43	2017-07-01 19:15:00+03	51900.00
170D6F	2017-08-03 14:09:00+03	102200.00
170DFC	2017-07-18 08:50:00+03	117500.00
170E1E	2017-08-12 12:03:00+03	24000.00
170E92	2017-07-08 09:57:00+03	29800.00
170EB2	2017-08-12 15:19:00+03	276900.00
170EB4	2017-07-25 14:10:00+03	44800.00
170F06	2017-07-31 23:04:00+03	25100.00
170F34	2017-07-09 16:09:00+03	134400.00
170F36	2017-07-29 16:33:00+03	47100.00
170F5C	2017-07-20 16:54:00+03	123000.00
170FA7	2017-07-02 23:58:00+03	58200.00
171030	2017-06-28 22:39:00+03	53100.00
1710F6	2017-07-27 16:48:00+03	343400.00
171148	2017-07-21 19:20:00+03	147000.00
1711EA	2017-08-13 07:12:00+03	289800.00
17120F	2017-08-02 15:57:00+03	21800.00
17126D	2017-06-30 11:08:00+03	30200.00
1712CA	2017-07-30 01:28:00+03	28000.00
1712E7	2017-08-08 13:42:00+03	80000.00
1712F4	2017-07-15 17:02:00+03	96800.00
1712FB	2017-08-15 15:48:00+03	72600.00
17132C	2017-08-04 08:09:00+03	271400.00
17132E	2017-07-09 18:25:00+03	86300.00
1713FE	2017-07-18 12:23:00+03	54600.00
171450	2017-07-03 13:44:00+03	40600.00
17147A	2017-07-31 02:00:00+03	113200.00
1714D0	2017-07-17 16:16:00+03	93900.00
171538	2017-08-13 16:12:00+03	119100.00
171592	2017-07-04 00:30:00+03	168000.00
1715A3	2017-07-29 16:47:00+03	19600.00
1715C6	2017-07-14 18:27:00+03	44000.00
1715E1	2017-07-25 01:53:00+03	133200.00
171605	2017-07-30 20:57:00+03	88600.00
171621	2017-07-05 11:30:00+03	40000.00
171671	2017-08-14 02:22:00+03	71900.00
171687	2017-08-12 21:40:00+03	31600.00
1716FB	2017-07-04 14:55:00+03	27200.00
17174B	2017-08-11 08:03:00+03	38400.00
1717AD	2017-08-02 22:19:00+03	167400.00
1717AF	2017-07-02 19:50:00+03	12000.00
1717B5	2017-07-05 20:41:00+03	144100.00
1717E6	2017-07-02 19:16:00+03	101200.00
171811	2017-08-07 19:47:00+03	64000.00
17181D	2017-07-06 15:53:00+03	23200.00
17183D	2017-07-31 10:30:00+03	88500.00
1718B1	2017-07-12 02:27:00+03	27200.00
1718BB	2017-07-14 14:20:00+03	49800.00
1718DC	2017-07-04 20:15:00+03	50400.00
1718EA	2017-07-22 02:06:00+03	57400.00
171925	2017-08-09 07:48:00+03	35600.00
17192B	2017-07-28 14:29:00+03	28800.00
17198F	2017-08-04 15:01:00+03	28800.00
1719AB	2017-07-26 18:42:00+03	100600.00
1719B7	2017-07-29 04:03:00+03	8000.00
1719E4	2017-07-10 20:40:00+03	95400.00
1719ED	2017-07-06 11:59:00+03	359200.00
171A20	2017-07-05 22:54:00+03	181800.00
171A4A	2017-06-26 15:36:00+03	19600.00
171A69	2017-08-03 08:18:00+03	141000.00
171AE7	2017-08-12 20:05:00+03	112000.00
171B3F	2017-07-02 07:39:00+03	14000.00
171BAF	2017-08-07 20:22:00+03	81200.00
171C5B	2017-08-12 02:40:00+03	67600.00
171C9C	2017-07-19 18:22:00+03	32200.00
171D3E	2017-07-30 21:01:00+03	22400.00
171DE5	2017-06-29 01:40:00+03	18400.00
171DEB	2017-08-13 19:18:00+03	27200.00
171EB2	2017-07-08 08:57:00+03	123000.00
171EE0	2017-08-10 07:02:00+03	51800.00
171FEF	2017-07-27 16:49:00+03	265700.00
171FF9	2017-07-28 13:08:00+03	223200.00
17203C	2017-08-11 23:21:00+03	21400.00
172044	2017-08-04 12:35:00+03	56000.00
172054	2017-07-17 04:22:00+03	60700.00
172067	2017-07-24 21:53:00+03	61800.00
172085	2017-08-13 06:53:00+03	53400.00
1720A4	2017-07-22 09:06:00+03	55800.00
1720AD	2017-08-08 13:52:00+03	60400.00
17211C	2017-07-25 05:06:00+03	274200.00
172207	2017-08-10 20:45:00+03	26500.00
1722B4	2017-08-10 12:40:00+03	34400.00
172363	2017-07-25 23:56:00+03	115900.00
17237C	2017-07-31 03:38:00+03	60700.00
17239B	2017-07-29 15:25:00+03	47100.00
1723B6	2017-08-01 13:36:00+03	37900.00
1723F5	2017-07-09 10:05:00+03	23200.00
172455	2017-08-02 10:01:00+03	28800.00
1724A2	2017-08-13 15:32:00+03	24500.00
172507	2017-07-16 02:17:00+03	64500.00
17250A	2017-08-09 05:58:00+03	398500.00
172560	2017-07-28 15:59:00+03	25400.00
172603	2017-08-09 17:49:00+03	143400.00
17262E	2017-07-21 21:57:00+03	106600.00
17273D	2017-07-07 05:54:00+03	26000.00
17278C	2017-07-11 02:20:00+03	135000.00
1727C4	2017-07-08 17:11:00+03	34000.00
1727ED	2017-07-21 04:24:00+03	13400.00
172812	2017-06-29 12:37:00+03	51900.00
172884	2017-07-14 02:39:00+03	469900.00
17289F	2017-07-05 11:22:00+03	87700.00
1728D5	2017-06-28 16:53:00+03	32800.00
1728E0	2017-07-12 05:13:00+03	153300.00
172929	2017-08-10 10:07:00+03	152200.00
17292A	2017-08-11 17:42:00+03	135200.00
172932	2017-07-22 14:50:00+03	37800.00
17298D	2017-08-06 10:06:00+03	23600.00
1729BF	2017-07-20 05:23:00+03	34000.00
1729CB	2017-08-04 20:17:00+03	135400.00
172A88	2017-08-14 06:11:00+03	185000.00
172A99	2017-07-22 18:45:00+03	28300.00
172B0D	2017-07-15 05:42:00+03	118600.00
172B15	2017-07-11 01:43:00+03	67600.00
172B68	2017-07-06 12:54:00+03	42600.00
172B7A	2017-07-27 16:45:00+03	56000.00
172BB1	2017-07-10 18:40:00+03	55800.00
172BB7	2017-07-06 05:41:00+03	38200.00
172BEA	2017-08-10 07:30:00+03	28000.00
172BEB	2017-07-13 14:27:00+03	31800.00
172C04	2017-08-07 03:03:00+03	52800.00
172C10	2017-08-03 07:56:00+03	73900.00
172C69	2017-08-05 07:38:00+03	143700.00
172C78	2017-08-12 03:18:00+03	38800.00
172C8B	2017-07-20 06:42:00+03	78300.00
172C93	2017-07-15 12:40:00+03	132500.00
172CC6	2017-07-13 18:43:00+03	48800.00
172D2A	2017-07-20 19:51:00+03	15100.00
172D5E	2017-07-22 16:31:00+03	292800.00
172D92	2017-07-14 10:32:00+03	100600.00
172D93	2017-07-16 13:57:00+03	38600.00
172E0E	2017-07-17 02:07:00+03	25600.00
172EAC	2017-07-31 09:17:00+03	62100.00
172F67	2017-08-13 11:05:00+03	42800.00
172FB8	2017-08-13 03:46:00+03	68800.00
17301A	2017-08-05 20:00:00+03	248300.00
17304B	2017-07-27 22:22:00+03	163500.00
1730DE	2017-08-01 22:21:00+03	15000.00
17311F	2017-07-18 23:32:00+03	38800.00
1731AF	2017-07-30 00:02:00+03	133200.00
1731E8	2017-06-22 05:46:00+03	70100.00
173203	2017-08-09 20:33:00+03	24800.00
17320B	2017-08-02 01:35:00+03	122500.00
1732A9	2017-07-29 16:40:00+03	85700.00
1732B1	2017-07-30 08:11:00+03	36200.00
173332	2017-07-13 19:10:00+03	75300.00
173375	2017-07-17 15:43:00+03	92400.00
173419	2017-08-09 21:09:00+03	102100.00
173472	2017-07-11 00:33:00+03	144400.00
173487	2017-07-17 13:29:00+03	36200.00
1734BD	2017-08-13 21:23:00+03	77200.00
173505	2017-07-04 20:40:00+03	314400.00
17355B	2017-07-21 18:11:00+03	68400.00
17359A	2017-07-17 11:41:00+03	65100.00
17359B	2017-07-25 20:35:00+03	44400.00
1735C7	2017-07-20 21:46:00+03	113200.00
173630	2017-08-01 12:10:00+03	17800.00
173661	2017-08-02 20:47:00+03	185600.00
17366B	2017-07-04 21:08:00+03	248400.00
17367F	2017-08-15 05:46:00+03	90200.00
173689	2017-08-13 20:47:00+03	125400.00
17369E	2017-08-08 08:11:00+03	23100.00
1736A7	2017-08-11 22:30:00+03	142400.00
17372E	2017-07-09 14:45:00+03	114800.00
173802	2017-07-13 18:50:00+03	89700.00
17380F	2017-07-04 02:05:00+03	60400.00
173894	2017-08-01 14:03:00+03	26000.00
1738DF	2017-07-30 18:35:00+03	42800.00
1738EC	2017-07-08 06:51:00+03	46800.00
173907	2017-07-06 23:13:00+03	131100.00
17390F	2017-07-17 16:04:00+03	91100.00
173945	2017-08-01 09:14:00+03	68100.00
173958	2017-07-07 03:17:00+03	67600.00
17395F	2017-07-07 00:02:00+03	26000.00
173989	2017-07-21 16:06:00+03	354400.00
1739A4	2017-07-23 15:17:00+03	151300.00
173A57	2017-07-11 16:34:00+03	26700.00
173A5D	2017-07-17 07:29:00+03	107800.00
173A7C	2017-08-03 02:37:00+03	34100.00
173AA2	2017-08-04 15:58:00+03	10800.00
173AF0	2017-08-03 21:04:00+03	141000.00
173AF4	2017-07-17 02:15:00+03	114700.00
173AFA	2017-07-18 03:21:00+03	22400.00
173B4E	2017-07-18 00:12:00+03	89600.00
173CCA	2017-08-11 23:00:00+03	28000.00
173CFC	2017-07-21 00:26:00+03	266400.00
173D3A	2017-07-19 11:02:00+03	35200.00
173D62	2017-07-24 20:16:00+03	56000.00
173D8C	2017-07-26 22:34:00+03	57600.00
173DAF	2017-07-07 23:20:00+03	23200.00
173DB1	2017-07-19 01:25:00+03	48800.00
173DFE	2017-08-04 16:17:00+03	158000.00
173E23	2017-07-28 02:35:00+03	43000.00
173E71	2017-07-06 20:06:00+03	38400.00
173E9F	2017-07-11 16:31:00+03	64700.00
173EA5	2017-07-18 19:53:00+03	46000.00
173EF1	2017-07-19 08:56:00+03	14800.00
173EF7	2017-06-26 05:44:00+03	26800.00
173EFA	2017-07-25 00:57:00+03	28000.00
173F22	2017-07-17 05:48:00+03	81700.00
173F39	2017-07-26 08:22:00+03	12600.00
173F48	2017-07-10 14:44:00+03	114800.00
173F4C	2017-07-27 23:11:00+03	40800.00
173FF2	2017-06-30 12:51:00+03	67600.00
174036	2017-07-05 08:49:00+03	28000.00
174063	2017-07-18 01:29:00+03	32800.00
174077	2017-07-11 23:31:00+03	12600.00
174088	2017-08-08 04:29:00+03	12600.00
174123	2017-07-23 05:02:00+03	102700.00
17418B	2017-07-20 07:19:00+03	21400.00
1741AB	2017-08-09 00:52:00+03	24400.00
1741EE	2017-07-02 00:41:00+03	284100.00
174277	2017-07-20 14:32:00+03	24400.00
1742DA	2017-07-15 20:29:00+03	26000.00
1742ED	2017-07-20 06:44:00+03	58800.00
174369	2017-08-03 20:59:00+03	88600.00
17437B	2017-07-18 12:57:00+03	24400.00
1743C2	2017-07-09 09:07:00+03	50400.00
1743F5	2017-07-12 17:50:00+03	115200.00
174401	2017-08-04 10:43:00+03	56100.00
17446E	2017-07-21 12:58:00+03	36700.00
17447C	2017-08-14 12:00:00+03	74900.00
17448B	2017-06-30 03:30:00+03	28000.00
1744FA	2017-07-05 21:41:00+03	123000.00
174551	2017-08-14 15:28:00+03	160800.00
17457D	2017-07-05 11:06:00+03	75600.00
1745D1	2017-07-25 21:08:00+03	82900.00
1745EC	2017-07-09 22:37:00+03	57400.00
17467B	2017-07-05 23:17:00+03	14400.00
1746BB	2017-07-15 01:35:00+03	94000.00
17474E	2017-06-29 06:11:00+03	23200.00
174766	2017-08-15 05:06:00+03	25800.00
174784	2017-07-03 02:55:00+03	174400.00
17478E	2017-07-24 23:57:00+03	172600.00
174792	2017-07-14 02:55:00+03	35800.00
1747E4	2017-08-11 07:52:00+03	59000.00
1747EA	2017-07-25 18:11:00+03	126300.00
174866	2017-08-13 02:30:00+03	16700.00
174902	2017-07-19 07:36:00+03	29600.00
174A17	2017-08-05 10:05:00+03	32800.00
174A70	2017-07-08 18:38:00+03	95200.00
174AAA	2017-08-10 23:28:00+03	88800.00
174B1A	2017-08-05 10:01:00+03	35200.00
174BEA	2017-07-24 18:20:00+03	61800.00
174BEF	2017-08-08 16:21:00+03	39300.00
174C44	2017-08-11 07:13:00+03	47000.00
174CC2	2017-07-09 03:34:00+03	135200.00
174D16	2017-07-31 14:35:00+03	27200.00
174DC2	2017-08-12 17:50:00+03	66000.00
174DD2	2017-07-23 16:36:00+03	134700.00
174DDF	2017-07-12 01:57:00+03	18600.00
174E07	2017-08-06 07:05:00+03	47200.00
174E4A	2017-07-29 22:49:00+03	29600.00
174E67	2017-07-14 05:43:00+03	94700.00
174EBB	2017-06-30 07:20:00+03	24800.00
174F23	2017-07-15 14:20:00+03	32800.00
174F53	2017-07-06 06:25:00+03	266400.00
174F75	2017-08-06 06:59:00+03	140900.00
174FE2	2017-08-03 05:22:00+03	40600.00
17508E	2017-07-04 02:13:00+03	52800.00
1750E4	2017-07-12 14:28:00+03	14000.00
1750ED	2017-07-09 10:59:00+03	128100.00
1750F3	2017-07-31 05:38:00+03	40800.00
175117	2017-07-04 01:41:00+03	161100.00
17512B	2017-08-02 18:04:00+03	32400.00
17517A	2017-08-09 01:09:00+03	91600.00
1751B0	2017-07-20 11:30:00+03	67600.00
175206	2017-07-24 00:09:00+03	35600.00
175213	2017-08-11 06:27:00+03	172100.00
17521A	2017-06-30 03:20:00+03	39400.00
175240	2017-07-12 19:03:00+03	72600.00
175256	2017-07-31 07:27:00+03	40800.00
175279	2017-07-08 14:55:00+03	53400.00
1752AF	2017-08-14 09:39:00+03	55800.00
1752E6	2017-07-12 06:22:00+03	10700.00
1752EF	2017-08-10 07:01:00+03	6800.00
17530A	2017-08-15 13:38:00+03	21400.00
175312	2017-07-25 19:39:00+03	23600.00
17533B	2017-07-20 09:09:00+03	147700.00
175344	2017-07-28 13:25:00+03	6300.00
17534D	2017-08-11 21:30:00+03	92400.00
175352	2017-08-12 02:56:00+03	57600.00
175359	2017-08-14 13:02:00+03	29600.00
17538F	2017-07-26 19:02:00+03	116000.00
175446	2017-08-14 03:09:00+03	48400.00
17548A	2017-07-12 23:16:00+03	59300.00
17549C	2017-07-09 05:57:00+03	30200.00
1754BE	2017-08-13 07:20:00+03	18000.00
175530	2017-07-21 04:33:00+03	120400.00
175537	2017-08-07 23:10:00+03	533800.00
175542	2017-07-07 19:53:00+03	24400.00
175560	2017-07-19 22:13:00+03	118000.00
17557D	2017-07-10 21:09:00+03	234500.00
1755A4	2017-07-10 06:53:00+03	46000.00
1755C0	2017-07-13 06:38:00+03	59000.00
1755C3	2017-07-06 15:28:00+03	8200.00
1755C4	2017-07-10 16:01:00+03	23200.00
17562E	2017-08-12 07:30:00+03	52900.00
175672	2017-07-07 04:57:00+03	47200.00
175764	2017-07-14 23:09:00+03	62900.00
17577B	2017-08-05 09:05:00+03	82900.00
175824	2017-07-18 19:04:00+03	122400.00
17582B	2017-07-07 18:17:00+03	133100.00
175832	2017-07-19 16:54:00+03	13600.00
175875	2017-07-14 18:45:00+03	51200.00
175A23	2017-07-01 12:53:00+03	92100.00
175A73	2017-07-15 13:02:00+03	23400.00
175A76	2017-08-09 02:02:00+03	66600.00
175A93	2017-08-09 13:37:00+03	43400.00
175A9A	2017-08-04 06:18:00+03	6700.00
175AD6	2017-07-18 22:13:00+03	35300.00
175ADC	2017-07-10 00:26:00+03	56000.00
175AFE	2017-07-23 16:34:00+03	246000.00
175B6D	2017-08-04 11:28:00+03	27400.00
175BB2	2017-07-25 08:06:00+03	341900.00
175BCA	2017-07-28 21:09:00+03	30300.00
175BD0	2017-07-16 09:52:00+03	86500.00
175BE4	2017-08-09 20:50:00+03	182300.00
175BF7	2017-07-23 05:16:00+03	40000.00
175C09	2017-07-11 16:26:00+03	38800.00
175C28	2017-07-19 09:44:00+03	60200.00
175C2E	2017-07-28 07:38:00+03	198400.00
175CBC	2017-07-10 06:15:00+03	23200.00
175D2B	2017-07-27 21:11:00+03	48800.00
175D37	2017-08-14 19:54:00+03	15100.00
175D46	2017-08-12 09:46:00+03	38800.00
175D8F	2017-08-01 13:34:00+03	139300.00
175E42	2017-07-30 08:59:00+03	23200.00
175F67	2017-07-12 12:51:00+03	20400.00
175F6D	2017-07-06 21:04:00+03	16400.00
176029	2017-07-14 19:45:00+03	92700.00
17603C	2017-08-09 12:17:00+03	6700.00
1760CD	2017-08-15 08:40:00+03	42500.00
1760D4	2017-07-15 00:08:00+03	144700.00
176114	2017-07-02 08:07:00+03	252200.00
1761C6	2017-07-29 00:15:00+03	99200.00
1761FB	2017-07-12 14:22:00+03	23900.00
17624B	2017-07-19 13:29:00+03	80700.00
17624F	2017-07-08 04:56:00+03	60400.00
176270	2017-07-31 06:08:00+03	69500.00
176294	2017-07-10 03:55:00+03	18000.00
1762EA	2017-07-28 19:04:00+03	304100.00
176349	2017-07-28 22:40:00+03	257600.00
1763D9	2017-08-13 22:06:00+03	57100.00
176403	2017-07-04 19:11:00+03	115700.00
17641C	2017-07-09 10:57:00+03	92100.00
176422	2017-07-17 23:07:00+03	23100.00
17644D	2017-07-12 21:51:00+03	80800.00
17646B	2017-08-03 21:32:00+03	254900.00
176473	2017-08-15 03:32:00+03	46400.00
1764B9	2017-07-25 17:12:00+03	40800.00
176529	2017-08-01 18:37:00+03	64700.00
17666B	2017-07-03 13:50:00+03	55800.00
176674	2017-08-08 00:45:00+03	75600.00
1766FA	2017-07-11 07:33:00+03	6700.00
176702	2017-07-13 13:11:00+03	50600.00
176755	2017-08-08 22:25:00+03	19600.00
176767	2017-08-03 07:03:00+03	21800.00
17676C	2017-07-06 12:07:00+03	59200.00
176794	2017-07-28 05:21:00+03	62500.00
1767EC	2017-08-07 01:23:00+03	49100.00
176826	2017-08-13 11:50:00+03	52900.00
176880	2017-08-10 16:58:00+03	75600.00
1769D9	2017-08-01 05:37:00+03	131600.00
1769DD	2017-08-13 17:21:00+03	65200.00
1769E5	2017-07-20 19:34:00+03	59800.00
176AA7	2017-07-28 23:46:00+03	23100.00
176B50	2017-08-08 10:48:00+03	380700.00
176B73	2017-06-27 22:57:00+03	119500.00
176BC8	2017-06-30 20:47:00+03	249100.00
176C93	2017-08-08 10:20:00+03	35300.00
176CF7	2017-07-30 08:20:00+03	67200.00
176D70	2017-07-25 16:06:00+03	121400.00
176DC8	2017-08-14 12:17:00+03	116500.00
176E55	2017-07-08 01:48:00+03	136700.00
176E5E	2017-08-13 16:09:00+03	27400.00
176EB0	2017-07-11 02:36:00+03	273800.00
176EE4	2017-07-05 23:24:00+03	53700.00
176F1A	2017-08-09 05:16:00+03	61800.00
176FC3	2017-07-06 21:44:00+03	14800.00
176FFE	2017-07-13 02:34:00+03	283100.00
177022	2017-07-03 12:02:00+03	34800.00
177023	2017-07-08 12:21:00+03	133100.00
177027	2017-08-05 17:37:00+03	70500.00
17704E	2017-07-07 15:29:00+03	22100.00
1770D1	2017-08-01 02:27:00+03	6000.00
1770F8	2017-06-28 04:51:00+03	57400.00
177107	2017-08-07 12:32:00+03	28800.00
177141	2017-07-07 15:28:00+03	78200.00
17722E	2017-07-28 11:56:00+03	25100.00
1772BD	2017-07-06 04:26:00+03	88200.00
1772BF	2017-07-29 18:48:00+03	6000.00
1772D0	2017-07-06 20:13:00+03	35600.00
1772F6	2017-07-05 03:09:00+03	40800.00
177320	2017-08-11 23:10:00+03	24000.00
177366	2017-07-17 02:16:00+03	133200.00
177369	2017-08-13 18:50:00+03	408500.00
177370	2017-08-01 19:19:00+03	118600.00
1773A2	2017-07-13 06:06:00+03	139200.00
1773AA	2017-07-27 20:04:00+03	76600.00
1773E2	2017-07-27 15:14:00+03	6000.00
17741B	2017-07-14 09:36:00+03	6400.00
17742A	2017-07-29 11:15:00+03	46200.00
1774BA	2017-07-13 01:56:00+03	271200.00
1774FB	2017-08-09 05:27:00+03	6700.00
17752B	2017-07-04 22:23:00+03	58600.00
177561	2017-07-03 23:04:00+03	178300.00
177576	2017-07-01 17:57:00+03	56500.00
17759F	2017-08-11 22:02:00+03	36500.00
1775A5	2017-08-02 23:34:00+03	23200.00
1775BD	2017-07-22 06:44:00+03	31400.00
1775D0	2017-07-09 07:14:00+03	28000.00
1775FD	2017-07-11 23:32:00+03	23600.00
177609	2017-08-03 10:10:00+03	217600.00
17761B	2017-07-09 08:57:00+03	62600.00
177620	2017-08-10 08:23:00+03	25600.00
17762B	2017-07-15 13:10:00+03	45200.00
177646	2017-07-29 05:45:00+03	55000.00
17767E	2017-07-06 01:56:00+03	16400.00
1776B3	2017-08-02 19:08:00+03	32800.00
1776D0	2017-07-10 20:24:00+03	63200.00
177716	2017-07-30 22:00:00+03	115300.00
177746	2017-08-14 04:00:00+03	202700.00
17775F	2017-07-23 03:24:00+03	28800.00
17777D	2017-08-03 16:41:00+03	254900.00
17780C	2017-08-14 06:29:00+03	56000.00
17783F	2017-07-11 11:15:00+03	23200.00
177846	2017-07-20 12:58:00+03	55800.00
17784A	2017-07-16 02:39:00+03	51900.00
17784B	2017-07-23 08:50:00+03	72800.00
17792E	2017-07-15 16:25:00+03	532800.00
177967	2017-08-14 04:22:00+03	68800.00
1779C1	2017-07-09 15:48:00+03	119600.00
1779D2	2017-06-27 01:48:00+03	96100.00
1779F6	2017-07-16 06:25:00+03	13000.00
177A6C	2017-07-24 10:43:00+03	24400.00
177A6D	2017-07-20 10:25:00+03	15000.00
177AAD	2017-08-11 06:42:00+03	40000.00
177AE9	2017-07-17 13:09:00+03	28000.00
177B04	2017-07-23 00:27:00+03	25600.00
177B09	2017-07-23 01:49:00+03	266400.00
177B20	2017-07-12 01:50:00+03	25800.00
177C31	2017-07-21 06:30:00+03	97800.00
177C6B	2017-07-12 11:55:00+03	36200.00
177CA1	2017-07-30 12:03:00+03	31400.00
177CAF	2017-07-29 21:44:00+03	82900.00
177CC2	2017-07-05 00:19:00+03	20800.00
177D0E	2017-07-11 01:57:00+03	103800.00
177D34	2017-08-06 02:49:00+03	128000.00
177D5F	2017-07-25 17:42:00+03	23500.00
177D68	2017-07-13 09:23:00+03	34600.00
177D6B	2017-07-01 04:43:00+03	15000.00
177E75	2017-07-22 07:27:00+03	229900.00
177E8F	2017-08-11 05:46:00+03	265600.00
177E93	2017-08-07 06:45:00+03	240800.00
177F2C	2017-07-19 07:05:00+03	26000.00
177F78	2017-07-05 16:49:00+03	71000.00
177FD1	2017-08-13 17:38:00+03	160100.00
177FDF	2017-07-28 12:54:00+03	88600.00
178001	2017-07-04 00:13:00+03	29200.00
178021	2017-08-08 23:27:00+03	43700.00
178080	2017-07-13 07:45:00+03	93400.00
178082	2017-08-08 14:08:00+03	66000.00
178093	2017-07-24 12:54:00+03	32700.00
17809C	2017-08-09 15:22:00+03	57400.00
17812F	2017-08-11 07:00:00+03	412400.00
178146	2017-07-09 23:26:00+03	24800.00
1781D6	2017-07-12 00:07:00+03	12400.00
1781E5	2017-07-06 08:27:00+03	47400.00
1781E6	2017-07-13 12:45:00+03	51000.00
1781F7	2017-07-07 18:59:00+03	12000.00
178233	2017-07-23 06:03:00+03	24800.00
1782A0	2017-07-14 18:59:00+03	520600.00
17836D	2017-07-12 06:44:00+03	38600.00
1783AC	2017-07-07 02:48:00+03	66000.00
178414	2017-07-30 09:06:00+03	73300.00
17848B	2017-06-26 00:28:00+03	67700.00
1784A3	2017-07-12 12:09:00+03	70600.00
1784E1	2017-07-05 23:18:00+03	55800.00
17850D	2017-07-17 00:00:00+03	55800.00
17852E	2017-08-13 15:59:00+03	174600.00
17858B	2017-07-29 09:36:00+03	42800.00
1785C5	2017-07-17 06:38:00+03	56000.00
17860B	2017-07-11 12:03:00+03	53800.00
178616	2017-08-07 00:15:00+03	77200.00
1786EB	2017-07-15 05:18:00+03	68100.00
1786FC	2017-08-04 17:29:00+03	53500.00
1787D6	2017-07-23 07:26:00+03	245500.00
1787F7	2017-07-30 02:13:00+03	46200.00
178812	2017-07-14 12:52:00+03	545200.00
178821	2017-08-08 22:41:00+03	46200.00
17886C	2017-07-03 23:48:00+03	46000.00
1788B5	2017-08-10 08:40:00+03	6700.00
1788E7	2017-07-05 19:45:00+03	50200.00
178966	2017-07-29 22:27:00+03	75300.00
1789CE	2017-07-28 00:17:00+03	261500.00
1789DD	2017-07-25 00:16:00+03	18600.00
178A44	2017-08-15 16:45:00+03	7400.00
178A6A	2017-08-10 17:23:00+03	44000.00
178AB2	2017-07-10 14:31:00+03	26000.00
178B6B	2017-08-06 17:42:00+03	102200.00
178B99	2017-08-12 00:07:00+03	21800.00
178C4C	2017-07-02 09:10:00+03	134400.00
178C6D	2017-08-12 14:40:00+03	188800.00
178C94	2017-07-04 21:55:00+03	105000.00
178CB8	2017-07-15 01:20:00+03	102100.00
178D2A	2017-07-12 18:30:00+03	246000.00
178D98	2017-08-12 02:05:00+03	46400.00
178DA7	2017-07-28 05:40:00+03	81500.00
178DCD	2017-07-15 20:13:00+03	672600.00
178DEA	2017-07-03 22:22:00+03	167400.00
178E2F	2017-07-23 12:53:00+03	113200.00
178E3F	2017-07-11 07:18:00+03	10800.00
178EEE	2017-07-27 14:27:00+03	72800.00
178F0F	2017-07-02 19:20:00+03	188900.00
178F29	2017-07-09 10:12:00+03	129600.00
178F79	2017-07-17 01:26:00+03	81700.00
178FAE	2017-08-10 18:13:00+03	62100.00
178FC4	2017-07-30 11:46:00+03	420200.00
17901D	2017-07-17 17:48:00+03	64800.00
179026	2017-07-12 19:30:00+03	131600.00
179067	2017-08-13 14:01:00+03	85000.00
17906C	2017-07-20 02:49:00+03	135400.00
1790FE	2017-07-25 21:55:00+03	92900.00
179136	2017-08-06 16:21:00+03	154600.00
179145	2017-07-15 21:18:00+03	160200.00
1791B0	2017-06-28 20:33:00+03	28000.00
1791C2	2017-07-22 16:00:00+03	28800.00
1791CB	2017-07-12 09:33:00+03	54700.00
179297	2017-07-31 01:26:00+03	31000.00
1792C3	2017-08-04 05:18:00+03	96800.00
1792D8	2017-08-10 11:47:00+03	28000.00
179378	2017-07-12 14:13:00+03	23600.00
179397	2017-07-08 12:10:00+03	36600.00
17942D	2017-07-25 18:12:00+03	123000.00
179448	2017-07-21 22:44:00+03	8400.00
17947D	2017-08-07 22:19:00+03	22000.00
17953D	2017-08-13 15:00:00+03	199600.00
17954B	2017-08-03 23:55:00+03	68800.00
17966F	2017-07-11 06:57:00+03	105400.00
1796DF	2017-07-30 16:16:00+03	136600.00
17970E	2017-08-07 21:01:00+03	135200.00
179719	2017-08-09 12:31:00+03	38400.00
17976D	2017-08-09 19:11:00+03	133100.00
179772	2017-07-07 22:54:00+03	447900.00
17978F	2017-07-11 05:17:00+03	28800.00
1797B8	2017-07-30 22:02:00+03	55800.00
1797DE	2017-08-12 07:16:00+03	51600.00
1797E5	2017-07-19 02:10:00+03	32800.00
1797FE	2017-08-11 11:36:00+03	57600.00
17983C	2017-07-17 06:02:00+03	28000.00
179851	2017-06-25 00:16:00+03	87200.00
179880	2017-07-24 19:17:00+03	91600.00
1798EB	2017-07-25 00:04:00+03	208600.00
1798F3	2017-07-02 11:21:00+03	29600.00
1798F9	2017-08-15 15:53:00+03	203300.00
179913	2017-07-15 12:55:00+03	55800.00
179952	2017-07-08 22:01:00+03	28000.00
17996C	2017-08-04 19:18:00+03	111600.00
1799A6	2017-07-31 02:08:00+03	112400.00
1799B1	2017-08-14 04:41:00+03	48800.00
179A40	2017-08-08 06:14:00+03	58200.00
179A66	2017-07-14 08:38:00+03	177600.00
179A89	2017-06-30 09:44:00+03	73500.00
179A9C	2017-07-03 19:42:00+03	139400.00
179AC0	2017-08-12 06:58:00+03	21800.00
179AF3	2017-08-08 19:36:00+03	78000.00
179B0C	2017-08-15 08:45:00+03	43700.00
179B0D	2017-07-08 10:55:00+03	34800.00
179B33	2017-07-26 15:31:00+03	88600.00
179B72	2017-08-09 17:03:00+03	138600.00
179B87	2017-07-14 19:05:00+03	77600.00
179BC6	2017-07-20 09:38:00+03	83300.00
179BF2	2017-07-09 06:48:00+03	56000.00
179C65	2017-07-13 10:02:00+03	147600.00
179C9C	2017-08-07 05:18:00+03	196800.00
179C9F	2017-07-10 02:43:00+03	123600.00
179CD9	2017-07-10 06:37:00+03	107400.00
179CE8	2017-07-19 14:03:00+03	48800.00
179CEB	2017-07-10 02:40:00+03	100200.00
179D8A	2017-08-10 08:16:00+03	107100.00
179DCF	2017-08-07 14:34:00+03	42400.00
179EEE	2017-07-22 04:49:00+03	57600.00
179F91	2017-07-11 22:41:00+03	66400.00
179FCF	2017-08-08 22:57:00+03	271500.00
179FF4	2017-07-15 03:50:00+03	111600.00
179FF9	2017-08-03 11:09:00+03	15400.00
17A01E	2017-07-04 08:00:00+03	64700.00
17A03D	2017-06-28 09:33:00+03	133100.00
17A245	2017-07-22 17:51:00+03	92100.00
17A292	2017-07-18 18:21:00+03	168000.00
17A2AC	2017-07-30 08:10:00+03	16400.00
17A2B0	2017-07-12 04:20:00+03	30400.00
17A321	2017-07-05 07:04:00+03	241300.00
17A36A	2017-08-04 18:04:00+03	101100.00
17A406	2017-07-21 23:44:00+03	281500.00
17A45B	2017-07-09 21:52:00+03	38800.00
17A4B8	2017-07-06 12:44:00+03	118600.00
17A4D2	2017-07-15 21:13:00+03	44800.00
17A4D4	2017-07-23 10:25:00+03	43100.00
17A503	2017-08-07 10:28:00+03	55800.00
17A51F	2017-08-03 12:06:00+03	147200.00
17A551	2017-07-01 12:40:00+03	74400.00
17A559	2017-07-18 00:29:00+03	114900.00
17A5A4	2017-08-10 06:08:00+03	51800.00
17A5B7	2017-07-25 20:35:00+03	62700.00
17A5E4	2017-07-25 19:28:00+03	23200.00
17A61A	2017-08-14 11:00:00+03	75600.00
17A6CC	2017-08-03 02:50:00+03	118700.00
17A6DA	2017-08-15 04:31:00+03	52800.00
17A6EA	2017-07-06 22:59:00+03	64300.00
17A736	2017-06-27 17:10:00+03	25400.00
17A763	2017-07-21 13:19:00+03	12600.00
17A779	2017-07-11 05:02:00+03	12000.00
17A78E	2017-07-24 13:34:00+03	34000.00
17A79E	2017-08-15 01:06:00+03	26700.00
17A7C9	2017-08-14 13:15:00+03	6600.00
17A7EE	2017-07-30 03:28:00+03	205000.00
17A7F8	2017-07-24 08:14:00+03	28800.00
17A843	2017-07-02 16:38:00+03	37900.00
17A8B1	2017-07-21 13:43:00+03	30400.00
17A8BD	2017-07-18 13:59:00+03	23400.00
17A8ED	2017-08-02 12:21:00+03	16400.00
17A90B	2017-07-21 20:26:00+03	51100.00
17A931	2017-07-29 19:27:00+03	51900.00
17A960	2017-07-27 10:59:00+03	109200.00
17A968	2017-08-05 03:28:00+03	36900.00
17A96A	2017-07-20 04:47:00+03	21400.00
17A9E3	2017-07-27 13:41:00+03	33100.00
17A9E4	2017-07-25 02:01:00+03	106200.00
17AA1B	2017-06-29 10:57:00+03	77600.00
17AA31	2017-08-05 13:32:00+03	20600.00
17AA57	2017-07-05 04:58:00+03	93900.00
17AABF	2017-07-23 01:24:00+03	66600.00
17AAFC	2017-07-16 23:01:00+03	99100.00
17AB51	2017-07-02 09:38:00+03	95600.00
17AB5E	2017-08-10 17:34:00+03	40200.00
17ABCD	2017-08-08 19:34:00+03	88500.00
17AC01	2017-07-11 21:30:00+03	23600.00
17AC12	2017-08-07 23:18:00+03	241300.00
17AC31	2017-07-22 03:54:00+03	19200.00
17AC62	2017-08-10 18:08:00+03	22000.00
17ACB5	2017-08-15 06:59:00+03	114500.00
17AD99	2017-07-27 11:47:00+03	34000.00
17ADBB	2017-07-02 07:25:00+03	65900.00
17ADDB	2017-07-10 06:11:00+03	28800.00
17ADF4	2017-07-21 02:57:00+03	32700.00
17AE42	2017-07-03 16:14:00+03	81300.00
17AE6F	2017-07-24 10:54:00+03	94700.00
17AEEB	2017-08-11 21:49:00+03	30000.00
17AEF5	2017-07-07 06:20:00+03	70400.00
17AF53	2017-07-13 00:44:00+03	21400.00
17AFFD	2017-07-21 04:27:00+03	22000.00
17B06A	2017-07-09 14:43:00+03	8000.00
17B096	2017-07-12 12:24:00+03	174800.00
17B11F	2017-07-18 02:24:00+03	70700.00
17B154	2017-08-12 12:04:00+03	14800.00
17B1AD	2017-07-11 18:05:00+03	19600.00
17B1C8	2017-07-19 12:10:00+03	23200.00
17B283	2017-08-02 17:31:00+03	135600.00
17B289	2017-07-27 11:21:00+03	43800.00
17B2DE	2017-07-17 10:30:00+03	56000.00
17B315	2017-07-10 15:07:00+03	254900.00
17B31F	2017-07-24 17:59:00+03	141200.00
17B38A	2017-07-12 17:02:00+03	57300.00
17B394	2017-08-09 04:35:00+03	28000.00
17B425	2017-08-11 06:47:00+03	188000.00
17B432	2017-08-14 15:06:00+03	99200.00
17B43E	2017-08-11 13:19:00+03	13000.00
17B47D	2017-08-14 17:41:00+03	26200.00
17B541	2017-06-28 03:46:00+03	285500.00
17B54C	2017-07-18 11:38:00+03	12600.00
17B55B	2017-07-22 12:20:00+03	28000.00
17B561	2017-07-09 03:54:00+03	14300.00
17B579	2017-07-07 05:08:00+03	38600.00
17B5F9	2017-07-06 04:07:00+03	46800.00
17B5FB	2017-08-13 11:22:00+03	21600.00
17B642	2017-07-05 05:40:00+03	12400.00
17B66D	2017-08-15 07:51:00+03	53200.00
17B69F	2017-08-08 16:52:00+03	114400.00
17B6B5	2017-07-04 08:25:00+03	81200.00
17B70F	2017-08-12 12:24:00+03	12300.00
17B716	2017-08-03 21:27:00+03	69500.00
17B7B7	2017-07-30 00:53:00+03	12600.00
17B845	2017-07-03 08:16:00+03	10100.00
17B8A6	2017-07-08 22:46:00+03	145100.00
17B8CF	2017-07-19 23:43:00+03	15000.00
17B90F	2017-07-28 18:23:00+03	10100.00
17B968	2017-07-23 00:54:00+03	32800.00
17B981	2017-07-11 20:48:00+03	48800.00
17B986	2017-07-30 18:09:00+03	59800.00
17BAAC	2017-08-10 05:44:00+03	20000.00
17BAB6	2017-07-31 12:46:00+03	398500.00
17BAD0	2017-07-04 05:48:00+03	26000.00
17BAF6	2017-07-14 22:00:00+03	123000.00
17BB6E	2017-07-28 14:46:00+03	58200.00
17BB82	2017-06-24 09:02:00+03	67900.00
17BBA1	2017-07-09 16:59:00+03	47600.00
17BBD6	2017-07-08 08:53:00+03	86600.00
17BBE3	2017-07-29 14:57:00+03	42400.00
17BC68	2017-08-04 10:30:00+03	54800.00
17BCBA	2017-07-15 18:33:00+03	34000.00
17BCE7	2017-08-01 01:16:00+03	46200.00
17BCEC	2017-07-29 05:24:00+03	40800.00
17BD15	2017-08-06 14:22:00+03	6800.00
17BD29	2017-07-07 16:22:00+03	139200.00
17BDE1	2017-08-04 16:19:00+03	18800.00
17BE37	2017-07-25 19:29:00+03	136200.00
17BE71	2017-08-06 21:05:00+03	67400.00
17BE86	2017-07-18 11:46:00+03	13400.00
17BEDD	2017-08-08 05:09:00+03	40000.00
17BF67	2017-07-09 22:49:00+03	15000.00
17BFEA	2017-07-15 08:23:00+03	6700.00
17C060	2017-08-03 06:12:00+03	28700.00
17C084	2017-07-15 21:55:00+03	38600.00
17C0E3	2017-07-15 20:28:00+03	25600.00
17C0F3	2017-07-18 09:52:00+03	67600.00
17C0F5	2017-07-27 07:51:00+03	22000.00
17C124	2017-07-18 17:19:00+03	19600.00
17C138	2017-08-13 05:54:00+03	134400.00
17C163	2017-08-10 16:14:00+03	22000.00
17C1A5	2017-08-08 05:40:00+03	36200.00
17C1AF	2017-06-29 06:23:00+03	34000.00
17C1C1	2017-08-05 14:21:00+03	236000.00
17C1E8	2017-08-15 06:20:00+03	28000.00
17C256	2017-07-18 09:51:00+03	56600.00
17C291	2017-07-13 08:24:00+03	63200.00
17C2AC	2017-07-16 18:48:00+03	35200.00
17C323	2017-06-28 17:03:00+03	73600.00
17C341	2017-06-29 23:50:00+03	41500.00
17C44A	2017-07-11 21:18:00+03	209000.00
17C4B3	2017-07-08 22:12:00+03	13500.00
17C4CF	2017-07-11 13:24:00+03	23400.00
17C4D6	2017-07-15 05:29:00+03	31600.00
17C4EF	2017-08-14 03:05:00+03	125700.00
17C528	2017-07-06 05:56:00+03	75300.00
17C543	2017-07-24 17:27:00+03	33100.00
17C564	2017-08-14 20:37:00+03	40000.00
17C576	2017-07-24 20:21:00+03	53600.00
17C5AF	2017-08-13 09:46:00+03	207000.00
17C5C0	2017-07-20 16:56:00+03	81700.00
17C5D4	2017-07-27 02:08:00+03	393800.00
17C5F5	2017-08-06 16:44:00+03	86500.00
17C615	2017-07-27 03:33:00+03	16400.00
17C63C	2017-07-12 00:07:00+03	46400.00
17C651	2017-07-20 14:11:00+03	51300.00
17C69D	2017-08-10 04:42:00+03	205600.00
17C6F8	2017-08-11 20:52:00+03	56000.00
17C701	2017-08-05 23:47:00+03	113200.00
17C74B	2017-08-05 15:57:00+03	42600.00
17C74E	2017-08-12 12:19:00+03	60700.00
17C769	2017-08-13 18:05:00+03	46400.00
17C830	2017-08-13 18:47:00+03	22000.00
17C8A3	2017-08-06 11:14:00+03	67100.00
17C92C	2017-06-28 23:43:00+03	31700.00
17C92D	2017-08-01 10:23:00+03	79800.00
17C977	2017-07-27 07:23:00+03	55800.00
17C981	2017-07-17 01:44:00+03	94600.00
17CA06	2017-08-08 17:26:00+03	59300.00
17CA0C	2017-07-28 08:41:00+03	40800.00
17CA32	2017-07-02 02:56:00+03	59000.00
17CA7B	2017-08-02 00:04:00+03	81600.00
17CABE	2017-07-14 15:45:00+03	22100.00
17CAD0	2017-08-07 08:31:00+03	23600.00
17CB19	2017-07-05 23:10:00+03	32900.00
17CB6F	2017-07-16 01:52:00+03	23600.00
17CB87	2017-07-30 01:50:00+03	40100.00
17CBA6	2017-07-23 07:55:00+03	38800.00
17CBFC	2017-08-08 01:17:00+03	77600.00
17CCB0	2017-08-04 18:30:00+03	167400.00
17CCB4	2017-08-11 06:24:00+03	31600.00
17CCB8	2017-07-12 05:21:00+03	29600.00
17CD07	2017-07-30 20:01:00+03	135400.00
17CD10	2017-08-05 11:19:00+03	659400.00
17CD47	2017-07-12 08:18:00+03	41100.00
17CD63	2017-07-14 09:53:00+03	135600.00
17CD81	2017-07-22 07:39:00+03	64300.00
17CDE0	2017-08-05 17:23:00+03	93400.00
17CE1C	2017-08-08 13:47:00+03	16400.00
17CE31	2017-07-01 06:25:00+03	52300.00
17CE32	2017-07-15 08:41:00+03	94000.00
17CE43	2017-07-15 05:26:00+03	257700.00
17CE48	2017-07-18 19:42:00+03	20500.00
17CE65	2017-07-14 23:27:00+03	69000.00
17CE7C	2017-08-09 20:23:00+03	42800.00
17CF39	2017-07-29 08:02:00+03	27900.00
17CF48	2017-07-28 10:38:00+03	73600.00
17CF90	2017-08-14 12:53:00+03	34000.00
17D0B0	2017-07-31 05:30:00+03	133200.00
17D0B2	2017-07-23 04:32:00+03	62600.00
17D0CB	2017-07-10 13:18:00+03	66600.00
17D13C	2017-07-14 03:53:00+03	49100.00
17D144	2017-08-03 18:36:00+03	27900.00
17D15C	2017-07-23 08:23:00+03	26600.00
17D172	2017-08-02 20:49:00+03	123900.00
17D17F	2017-07-24 16:15:00+03	23200.00
17D1CA	2017-07-11 03:22:00+03	56900.00
17D1D5	2017-07-28 03:09:00+03	23600.00
17D1F5	2017-07-29 18:17:00+03	46300.00
17D260	2017-07-09 19:09:00+03	95500.00
17D2A0	2017-08-09 10:31:00+03	174600.00
17D2C1	2017-08-10 15:31:00+03	156300.00
17D309	2017-07-06 20:36:00+03	155500.00
17D31C	2017-08-01 00:06:00+03	45500.00
17D34B	2017-07-05 14:03:00+03	234400.00
17D367	2017-08-14 12:03:00+03	24400.00
17D373	2017-07-07 16:11:00+03	132800.00
17D394	2017-08-14 04:15:00+03	66200.00
17D39B	2017-07-25 11:58:00+03	96100.00
17D39E	2017-07-11 11:56:00+03	48800.00
17D3C8	2017-07-09 13:51:00+03	54000.00
17D3C9	2017-07-19 16:45:00+03	13400.00
17D3DD	2017-07-12 10:43:00+03	24000.00
17D444	2017-07-17 02:10:00+03	48400.00
17D44E	2017-07-04 16:11:00+03	142400.00
17D468	2017-08-04 10:31:00+03	28800.00
17D47D	2017-07-07 22:16:00+03	66600.00
17D4A9	2017-07-10 09:33:00+03	54800.00
17D4D8	2017-07-15 15:50:00+03	12200.00
17D50B	2017-07-09 13:35:00+03	26800.00
17D521	2017-07-16 08:26:00+03	40000.00
17D559	2017-07-14 07:23:00+03	95600.00
17D580	2017-08-12 01:22:00+03	92600.00
17D594	2017-08-10 22:05:00+03	270700.00
17D5E0	2017-07-26 12:20:00+03	187600.00
17D60E	2017-07-12 01:08:00+03	56000.00
17D649	2017-07-20 23:30:00+03	6000.00
17D67D	2017-08-01 00:58:00+03	22000.00
17D721	2017-07-27 12:00:00+03	94700.00
17D75F	2017-07-28 22:42:00+03	26600.00
17D765	2017-07-09 18:03:00+03	27200.00
17D83D	2017-07-31 08:05:00+03	40800.00
17D85D	2017-08-07 22:05:00+03	23200.00
17D922	2017-08-13 00:02:00+03	45200.00
17D9E2	2017-07-31 13:42:00+03	38400.00
17DA2A	2017-08-11 11:49:00+03	7800.00
17DA50	2017-08-11 10:44:00+03	131100.00
17DA5B	2017-07-13 01:33:00+03	167400.00
17DA5E	2017-07-25 06:29:00+03	73600.00
17DA68	2017-07-27 22:59:00+03	261500.00
17DAF4	2017-07-21 16:04:00+03	79600.00
17DB32	2017-08-10 19:44:00+03	142900.00
17DB8B	2017-08-05 00:19:00+03	36900.00
17DB8F	2017-07-18 06:16:00+03	46400.00
17DBA0	2017-08-13 20:37:00+03	69900.00
17DBC7	2017-06-30 00:19:00+03	43900.00
17DC3B	2017-08-15 00:44:00+03	55800.00
17DC40	2017-08-14 14:04:00+03	28800.00
17DCD4	2017-07-24 01:39:00+03	28000.00
17DD17	2017-08-04 15:24:00+03	57600.00
17DD82	2017-07-15 21:56:00+03	45100.00
17DDAA	2017-07-10 16:10:00+03	24400.00
17DDC5	2017-08-12 22:53:00+03	191000.00
17DE3B	2017-07-21 02:36:00+03	135400.00
17DE5B	2017-07-31 07:49:00+03	24800.00
17DEBB	2017-08-10 14:30:00+03	31400.00
17DEF8	2017-07-06 11:32:00+03	29600.00
17DFC6	2017-07-02 20:07:00+03	47000.00
17DFF0	2017-07-14 09:14:00+03	21600.00
17E009	2017-07-25 18:48:00+03	84100.00
17E036	2017-07-26 16:05:00+03	55800.00
17E065	2017-07-11 14:08:00+03	24700.00
17E087	2017-08-13 14:42:00+03	52400.00
17E093	2017-07-03 17:15:00+03	25800.00
17E099	2017-07-24 04:47:00+03	390400.00
17E0A2	2017-08-11 17:42:00+03	65900.00
17E12E	2017-07-17 17:05:00+03	66600.00
17E1A8	2017-08-07 14:20:00+03	72400.00
17E1A9	2017-07-31 20:33:00+03	94000.00
17E1F0	2017-07-12 14:00:00+03	28000.00
17E1FC	2017-08-14 10:47:00+03	35700.00
17E20D	2017-08-11 22:14:00+03	36800.00
17E2D6	2017-08-03 17:29:00+03	28700.00
17E325	2017-08-02 16:56:00+03	68800.00
17E351	2017-08-13 18:26:00+03	55800.00
17E38F	2017-07-31 14:47:00+03	239100.00
17E40D	2017-06-27 15:32:00+03	62000.00
17E422	2017-07-26 08:21:00+03	36200.00
17E442	2017-07-24 18:40:00+03	56600.00
17E482	2017-08-04 19:08:00+03	28800.00
17E4C3	2017-08-14 13:35:00+03	92000.00
17E4D0	2017-08-10 16:12:00+03	13400.00
17E526	2017-07-19 00:35:00+03	60800.00
17E53E	2017-07-03 09:57:00+03	46400.00
17E546	2017-07-10 05:45:00+03	56000.00
17E54D	2017-08-03 16:58:00+03	114800.00
17E5E7	2017-07-26 16:40:00+03	41600.00
17E68E	2017-08-13 11:01:00+03	21400.00
17E6AE	2017-07-22 22:06:00+03	203000.00
17E6C3	2017-07-19 03:48:00+03	31100.00
17E760	2017-07-13 11:45:00+03	39800.00
17E77A	2017-07-04 04:27:00+03	52400.00
17E8CD	2017-07-07 08:31:00+03	31600.00
17E926	2017-07-24 00:47:00+03	54600.00
17E92D	2017-07-13 16:14:00+03	68100.00
17E938	2017-07-30 07:10:00+03	34000.00
17E998	2017-08-09 11:46:00+03	14000.00
17EA08	2017-07-20 23:30:00+03	59600.00
17EA13	2017-08-12 19:26:00+03	32100.00
17EA39	2017-07-21 05:47:00+03	31200.00
17EAB8	2017-08-11 10:05:00+03	26000.00
17EB3C	2017-07-01 18:32:00+03	61700.00
17EB91	2017-07-20 21:11:00+03	27300.00
17EB9A	2017-08-12 03:54:00+03	38400.00
17EBA2	2017-07-16 19:49:00+03	6000.00
17EBAF	2017-07-31 10:09:00+03	123000.00
17EBB5	2017-07-13 19:09:00+03	8800.00
17EBC6	2017-07-11 02:22:00+03	31600.00
17EBE0	2017-06-25 23:22:00+03	31400.00
17EBE3	2017-07-24 02:11:00+03	12600.00
17EC25	2017-08-14 02:20:00+03	92800.00
17EC66	2017-07-23 02:45:00+03	33600.00
17EC82	2017-07-19 06:57:00+03	149300.00
17ECC6	2017-07-16 17:00:00+03	136800.00
17ECFD	2017-08-11 07:15:00+03	39200.00
17ED25	2017-08-09 07:39:00+03	56000.00
17ED28	2017-08-05 20:17:00+03	49100.00
17ED5C	2017-07-23 07:35:00+03	46000.00
17ED8B	2017-07-26 09:14:00+03	70800.00
17ED8E	2017-07-05 23:09:00+03	136200.00
17EDDC	2017-08-09 10:57:00+03	61800.00
17EE16	2017-07-11 05:58:00+03	133000.00
17EE5E	2017-07-07 13:36:00+03	79800.00
17EEA1	2017-08-03 02:03:00+03	13600.00
17EEAE	2017-07-05 14:19:00+03	68100.00
17EF4F	2017-08-02 11:55:00+03	46400.00
17EF58	2017-08-03 18:38:00+03	46000.00
17EF8D	2017-07-16 22:27:00+03	99900.00
17EFBE	2017-08-06 06:36:00+03	65300.00
17F029	2017-08-15 16:37:00+03	54500.00
17F075	2017-07-11 10:37:00+03	55800.00
17F104	2017-08-08 12:39:00+03	89700.00
17F120	2017-07-23 10:49:00+03	37100.00
17F243	2017-08-09 17:01:00+03	94900.00
17F2BB	2017-07-19 14:46:00+03	18600.00
17F311	2017-08-01 20:43:00+03	56600.00
17F314	2017-07-27 13:53:00+03	16800.00
17F386	2017-07-02 04:22:00+03	55800.00
17F3EA	2017-06-26 10:28:00+03	58800.00
17F463	2017-08-02 13:42:00+03	19600.00
17F4B3	2017-07-26 03:31:00+03	54800.00
17F52F	2017-07-23 21:31:00+03	40400.00
17F553	2017-08-03 14:32:00+03	98700.00
17F58F	2017-07-14 14:20:00+03	46400.00
17F59E	2017-07-30 21:40:00+03	81600.00
17F608	2017-08-12 20:04:00+03	54400.00
17F610	2017-08-01 07:32:00+03	36500.00
17F634	2017-07-08 00:06:00+03	156300.00
17F64F	2017-08-09 07:35:00+03	66600.00
17F660	2017-08-03 23:50:00+03	103600.00
17F664	2017-07-20 18:14:00+03	43400.00
17F6A1	2017-07-14 02:56:00+03	135400.00
17F6B9	2017-08-14 07:22:00+03	28800.00
17F738	2017-07-12 02:51:00+03	266300.00
17F743	2017-07-20 01:24:00+03	70800.00
17F760	2017-07-16 22:58:00+03	266400.00
17F76C	2017-07-13 12:08:00+03	20200.00
17F7B9	2017-07-28 07:04:00+03	96800.00
17F7C4	2017-07-12 12:25:00+03	31200.00
17F81A	2017-07-13 16:30:00+03	97800.00
17F828	2017-08-04 10:31:00+03	28000.00
17F845	2017-07-23 07:01:00+03	13400.00
17F846	2017-07-15 23:28:00+03	25800.00
17F887	2017-07-02 01:27:00+03	73000.00
17F900	2017-06-27 13:05:00+03	48800.00
17F93A	2017-07-10 05:43:00+03	67600.00
17FA95	2017-08-05 02:34:00+03	46400.00
17FAAD	2017-08-06 14:45:00+03	73200.00
17FBC7	2017-07-23 21:53:00+03	62900.00
17FBD6	2017-07-26 22:08:00+03	70500.00
17FBEB	2017-07-07 16:26:00+03	86400.00
17FBF7	2017-07-05 02:16:00+03	24000.00
17FC40	2017-07-31 10:35:00+03	47500.00
17FD0B	2017-07-10 05:08:00+03	24300.00
17FD13	2017-07-27 06:56:00+03	124300.00
17FD1D	2017-07-26 03:55:00+03	48600.00
17FD6B	2017-07-05 18:26:00+03	23400.00
17FD84	2017-07-21 07:35:00+03	30800.00
17FD9B	2017-07-12 01:38:00+03	73500.00
17FDA0	2017-08-13 17:33:00+03	56000.00
17FE52	2017-08-13 16:50:00+03	167400.00
17FE53	2017-07-19 15:21:00+03	60300.00
17FE7E	2017-08-13 14:54:00+03	34000.00
17FF30	2017-08-04 08:26:00+03	406700.00
17FF5E	2017-07-10 05:32:00+03	58700.00
17FF80	2017-07-13 07:59:00+03	84500.00
17FFE6	2017-08-05 03:23:00+03	175200.00
180000	2017-07-04 17:52:00+03	87200.00
18002B	2017-07-01 20:28:00+03	224000.00
180064	2017-08-06 07:30:00+03	109800.00
18008D	2017-08-14 14:00:00+03	37000.00
180098	2017-07-29 15:00:00+03	32800.00
1800EC	2017-07-04 19:49:00+03	38600.00
180102	2017-07-14 07:41:00+03	26000.00
180107	2017-07-04 09:31:00+03	6700.00
180146	2017-07-31 23:06:00+03	50800.00
18016B	2017-07-09 06:06:00+03	90800.00
180178	2017-06-30 00:40:00+03	91500.00
180180	2017-08-11 19:38:00+03	12400.00
1801BE	2017-07-18 02:52:00+03	125200.00
18020B	2017-07-22 05:06:00+03	161800.00
18021D	2017-07-08 01:16:00+03	273400.00
1802B9	2017-08-05 05:17:00+03	185500.00
1802E1	2017-06-27 12:53:00+03	53300.00
180304	2017-06-29 12:16:00+03	66600.00
18033E	2017-07-21 13:23:00+03	28000.00
180348	2017-07-24 08:47:00+03	56100.00
180393	2017-07-28 20:48:00+03	46400.00
18039D	2017-07-16 13:45:00+03	133100.00
1803E9	2017-07-20 09:18:00+03	32200.00
1803EB	2017-08-08 03:19:00+03	36400.00
18041E	2017-07-14 06:15:00+03	120800.00
180422	2017-08-11 15:24:00+03	39900.00
18042B	2017-07-05 10:12:00+03	133200.00
18042E	2017-08-03 09:55:00+03	182300.00
18048B	2017-08-03 19:06:00+03	16000.00
1804BB	2017-06-30 10:48:00+03	45200.00
1804F7	2017-07-11 07:26:00+03	24400.00
180511	2017-08-06 10:31:00+03	21400.00
18055F	2017-07-13 13:55:00+03	46000.00
18056D	2017-07-05 22:43:00+03	69500.00
1805CE	2017-07-28 16:58:00+03	26000.00
1805F4	2017-07-21 23:02:00+03	154500.00
180639	2017-08-11 01:32:00+03	60400.00
180649	2017-08-02 22:20:00+03	277800.00
18065E	2017-07-18 04:49:00+03	76200.00
1806DD	2017-07-10 18:45:00+03	23400.00
180715	2017-08-04 19:57:00+03	55800.00
18078A	2017-07-18 00:01:00+03	200400.00
180843	2017-07-16 21:37:00+03	123000.00
180868	2017-08-03 21:59:00+03	14400.00
1808E6	2017-07-03 09:04:00+03	58400.00
18091E	2017-08-13 19:57:00+03	265600.00
180921	2017-07-24 01:40:00+03	173300.00
18094E	2017-07-30 13:45:00+03	57400.00
18096F	2017-07-13 07:14:00+03	42800.00
18098E	2017-07-25 05:11:00+03	187600.00
1809EA	2017-07-23 09:38:00+03	48800.00
1809FA	2017-06-30 17:28:00+03	53600.00
180A61	2017-07-22 01:35:00+03	155500.00
180ACA	2017-07-24 10:55:00+03	54400.00
180B0C	2017-07-28 05:57:00+03	46000.00
180B2F	2017-07-16 07:00:00+03	192400.00
180B8D	2017-07-01 04:08:00+03	13000.00
180B9C	2017-06-30 01:22:00+03	28300.00
180BDF	2017-07-26 10:01:00+03	34000.00
180C4A	2017-07-12 22:22:00+03	73400.00
180C95	2017-08-08 01:12:00+03	70700.00
180CA7	2017-07-24 20:54:00+03	122300.00
180CB6	2017-07-10 17:44:00+03	34000.00
180CF6	2017-07-02 19:44:00+03	29600.00
180CFD	2017-07-19 20:44:00+03	23400.00
180D06	2017-08-10 08:44:00+03	500100.00
180D31	2017-07-22 12:30:00+03	27400.00
180D36	2017-07-23 06:32:00+03	32800.00
180D60	2017-07-29 03:13:00+03	95200.00
180DC2	2017-08-02 06:56:00+03	28300.00
180E53	2017-08-11 05:22:00+03	26000.00
180E59	2017-08-14 04:18:00+03	31600.00
180EC9	2017-08-05 01:32:00+03	80000.00
180F3B	2017-08-13 22:33:00+03	43200.00
180F46	2017-07-11 23:49:00+03	70600.00
180F57	2017-07-29 05:06:00+03	73600.00
18104E	2017-07-24 01:41:00+03	24400.00
181061	2017-08-03 12:45:00+03	61500.00
181092	2017-08-03 13:28:00+03	62400.00
181106	2017-07-24 12:40:00+03	301800.00
18113D	2017-07-05 09:22:00+03	246000.00
181162	2017-08-13 11:04:00+03	39700.00
181164	2017-08-12 20:00:00+03	110500.00
181171	2017-08-15 02:06:00+03	89700.00
18118F	2017-07-19 18:08:00+03	46300.00
18119B	2017-08-14 13:40:00+03	59800.00
1811AB	2017-06-26 07:07:00+03	38600.00
1811E5	2017-07-23 00:20:00+03	135200.00
1811F2	2017-07-09 19:16:00+03	87000.00
18122F	2017-08-04 05:52:00+03	34400.00
18124E	2017-08-04 00:52:00+03	518000.00
18126E	2017-07-25 13:26:00+03	44600.00
18128F	2017-07-27 19:19:00+03	24600.00
1812C7	2017-07-20 12:27:00+03	30800.00
1813BC	2017-07-24 05:34:00+03	59800.00
1813C4	2017-07-11 06:01:00+03	46300.00
1813C8	2017-08-03 01:23:00+03	26200.00
1813E9	2017-08-08 10:01:00+03	88600.00
181423	2017-06-30 22:37:00+03	56000.00
181437	2017-07-17 12:43:00+03	16400.00
18144E	2017-08-05 01:54:00+03	24700.00
181469	2017-08-12 01:28:00+03	70800.00
1814BF	2017-08-02 17:53:00+03	269600.00
1814FB	2017-08-14 06:30:00+03	149300.00
181540	2017-07-28 02:11:00+03	13000.00
18154E	2017-07-10 05:50:00+03	515000.00
1815FF	2017-07-10 20:22:00+03	118400.00
181604	2017-08-09 14:01:00+03	59800.00
1816E0	2017-07-22 19:23:00+03	24400.00
18172D	2017-07-10 16:54:00+03	87000.00
18175B	2017-07-16 01:18:00+03	198800.00
18178F	2017-07-11 01:49:00+03	25000.00
1817BE	2017-08-04 18:27:00+03	78500.00
1817C0	2017-07-02 05:42:00+03	141600.00
1817FD	2017-07-09 09:09:00+03	23100.00
181823	2017-08-06 21:36:00+03	105600.00
18183F	2017-07-31 19:25:00+03	43400.00
181846	2017-08-06 13:04:00+03	31400.00
18187D	2017-07-24 01:52:00+03	24700.00
18187F	2017-08-08 22:02:00+03	85700.00
181893	2017-07-07 14:36:00+03	46400.00
18189D	2017-07-09 01:18:00+03	71700.00
1818B9	2017-07-08 19:43:00+03	31600.00
1818BB	2017-07-09 03:30:00+03	369000.00
1818C6	2017-07-23 20:44:00+03	18600.00
181914	2017-07-30 13:09:00+03	100200.00
181A13	2017-07-25 07:47:00+03	40000.00
181A52	2017-07-18 22:07:00+03	31400.00
181A56	2017-06-25 19:35:00+03	48800.00
181A5C	2017-07-31 21:34:00+03	190400.00
181A9A	2017-06-30 19:29:00+03	73600.00
181AC4	2017-08-14 16:04:00+03	13600.00
181AD1	2017-08-04 02:05:00+03	42000.00
181ADE	2017-07-07 06:36:00+03	112000.00
181B07	2017-07-12 07:09:00+03	53000.00
181B96	2017-07-18 11:04:00+03	135400.00
181BD2	2017-07-07 09:24:00+03	90800.00
181BF7	2017-07-29 17:35:00+03	51900.00
181C44	2017-07-01 11:44:00+03	157800.00
181C55	2017-07-07 10:05:00+03	76800.00
181C67	2017-07-13 12:39:00+03	109800.00
181C75	2017-08-08 20:37:00+03	139100.00
181CA8	2017-07-26 15:48:00+03	39800.00
181CB9	2017-07-17 08:34:00+03	13000.00
181CE5	2017-08-03 07:23:00+03	34200.00
181CF4	2017-07-25 20:57:00+03	420100.00
181D4C	2017-08-04 18:27:00+03	316400.00
181DC8	2017-08-05 09:45:00+03	6800.00
181DF5	2017-07-14 15:33:00+03	115800.00
181E30	2017-08-14 01:52:00+03	18400.00
181E64	2017-07-30 07:51:00+03	31600.00
181E68	2017-08-05 18:21:00+03	75700.00
181E6C	2017-07-11 15:55:00+03	92700.00
181EBF	2017-07-20 07:54:00+03	246000.00
181EFC	2017-07-19 19:39:00+03	53300.00
181F6D	2017-07-05 01:39:00+03	38000.00
181F7A	2017-07-28 20:22:00+03	47100.00
181FD9	2017-07-19 20:09:00+03	104600.00
181FE6	2017-07-08 12:10:00+03	83000.00
182009	2017-07-21 18:45:00+03	129200.00
182031	2017-08-09 21:08:00+03	59300.00
1820A1	2017-07-15 06:08:00+03	52700.00
1820B5	2017-08-08 01:46:00+03	24400.00
1820B6	2017-07-29 01:05:00+03	88400.00
1820D5	2017-08-12 20:51:00+03	78100.00
1820E1	2017-08-09 01:46:00+03	44700.00
182107	2017-07-03 08:00:00+03	29600.00
182155	2017-06-27 18:42:00+03	6000.00
182208	2017-07-26 01:00:00+03	52900.00
18222F	2017-08-09 01:37:00+03	96400.00
18225A	2017-07-24 08:28:00+03	26500.00
18225E	2017-07-22 06:02:00+03	48800.00
18229B	2017-07-21 16:08:00+03	44800.00
1822AD	2017-08-12 02:48:00+03	57700.00
1822B8	2017-08-13 10:50:00+03	20400.00
18230D	2017-08-10 06:00:00+03	93900.00
182385	2017-07-18 00:48:00+03	79800.00
182415	2017-07-02 00:26:00+03	36400.00
18243B	2017-07-13 05:54:00+03	532800.00
182465	2017-08-14 07:02:00+03	30200.00
1824B2	2017-08-14 11:11:00+03	75000.00
1824E2	2017-07-24 17:12:00+03	48700.00
182509	2017-07-22 17:46:00+03	52400.00
182566	2017-07-28 17:25:00+03	6700.00
182592	2017-08-01 11:16:00+03	42600.00
18259F	2017-08-01 12:16:00+03	55800.00
1825A2	2017-08-14 05:25:00+03	19600.00
1825AC	2017-07-19 04:09:00+03	63300.00
1825F6	2017-06-30 17:22:00+03	70500.00
182600	2017-07-04 03:43:00+03	34000.00
18260A	2017-07-08 14:00:00+03	49400.00
182623	2017-07-03 03:48:00+03	65400.00
18269F	2017-08-15 02:02:00+03	102200.00
1826A2	2017-07-15 08:58:00+03	33800.00
1827A2	2017-07-03 20:01:00+03	178800.00
1827A6	2017-08-06 03:29:00+03	26000.00
1827C3	2017-07-19 00:34:00+03	167400.00
1827CF	2017-06-30 21:19:00+03	23600.00
182830	2017-06-28 05:30:00+03	13200.00
18284E	2017-07-18 16:47:00+03	55800.00
182870	2017-07-25 23:57:00+03	393800.00
1828AB	2017-07-05 21:30:00+03	6800.00
182905	2017-07-08 09:20:00+03	89600.00
18291E	2017-07-26 12:47:00+03	27300.00
182941	2017-07-12 13:02:00+03	151200.00
182985	2017-08-11 04:24:00+03	133900.00
1829C7	2017-08-04 07:18:00+03	179200.00
1829E9	2017-07-15 03:32:00+03	53400.00
1829F9	2017-07-08 06:50:00+03	56000.00
182A4A	2017-08-14 15:57:00+03	56600.00
182AB6	2017-08-13 23:15:00+03	23400.00
182ADF	2017-07-14 06:15:00+03	39100.00
182B07	2017-08-05 20:41:00+03	23400.00
182B84	2017-08-11 00:59:00+03	23200.00
182BF2	2017-08-02 06:53:00+03	27800.00
182C00	2017-08-14 15:39:00+03	38800.00
182C0D	2017-07-19 16:18:00+03	51700.00
182CF2	2017-07-16 21:58:00+03	49100.00
182D08	2017-07-03 10:08:00+03	27900.00
182D18	2017-07-02 01:39:00+03	100600.00
182D42	2017-07-29 08:36:00+03	66600.00
182D52	2017-08-01 10:56:00+03	14000.00
182D6A	2017-07-11 20:08:00+03	27200.00
182D82	2017-08-13 13:34:00+03	89600.00
182D92	2017-07-23 00:03:00+03	13400.00
182DFE	2017-07-19 05:18:00+03	38600.00
182E0C	2017-07-10 13:22:00+03	11800.00
182E94	2017-08-03 17:24:00+03	87600.00
182E9D	2017-07-09 12:56:00+03	30200.00
182EA1	2017-07-26 16:56:00+03	55800.00
182ED9	2017-07-07 02:18:00+03	44000.00
182EFA	2017-07-29 20:08:00+03	44600.00
18307B	2017-07-10 23:08:00+03	37800.00
1830C4	2017-08-01 01:40:00+03	46300.00
183113	2017-07-19 07:33:00+03	125100.00
183145	2017-08-03 19:51:00+03	46400.00
18314F	2017-07-15 11:31:00+03	14000.00
1831DD	2017-08-15 13:52:00+03	45100.00
183223	2017-08-03 02:29:00+03	28300.00
18325A	2017-06-27 14:31:00+03	43100.00
1832A5	2017-07-27 01:47:00+03	252200.00
1832CA	2017-07-06 16:46:00+03	23200.00
183326	2017-08-15 04:08:00+03	75600.00
183375	2017-07-22 13:07:00+03	59100.00
1833B5	2017-07-08 08:41:00+03	54800.00
1833BF	2017-07-05 02:52:00+03	234900.00
1833EB	2017-08-05 13:02:00+03	27900.00
183465	2017-07-20 05:11:00+03	106800.00
1834A6	2017-08-05 19:51:00+03	23600.00
1834B6	2017-08-12 15:20:00+03	46000.00
1834EE	2017-07-28 01:27:00+03	14400.00
18350D	2017-08-09 23:28:00+03	19600.00
18350E	2017-08-14 04:54:00+03	105400.00
183510	2017-08-10 21:48:00+03	84100.00
183570	2017-07-06 16:17:00+03	65300.00
1835B4	2017-07-03 16:46:00+03	290500.00
1835CB	2017-07-27 13:22:00+03	147700.00
1835DF	2017-08-05 03:50:00+03	57500.00
1835FE	2017-08-03 20:07:00+03	28600.00
183621	2017-07-20 14:08:00+03	20400.00
183641	2017-07-04 06:20:00+03	260900.00
183666	2017-07-23 19:31:00+03	28000.00
1836A2	2017-07-25 20:29:00+03	67700.00
1836C7	2017-07-08 11:30:00+03	25600.00
183750	2017-07-27 22:14:00+03	36400.00
1837AE	2017-06-27 19:02:00+03	62000.00
1837D7	2017-07-17 22:24:00+03	57400.00
1837DC	2017-08-15 14:40:00+03	75800.00
1838DE	2017-07-21 23:16:00+03	99200.00
183906	2017-07-06 17:45:00+03	43600.00
183958	2017-08-01 14:39:00+03	126400.00
183996	2017-08-04 21:55:00+03	160100.00
18399C	2017-08-14 04:33:00+03	12600.00
1839B3	2017-07-29 06:19:00+03	97700.00
1839E4	2017-07-28 19:36:00+03	31400.00
183A65	2017-07-06 07:37:00+03	28300.00
183A76	2017-06-25 07:09:00+03	30000.00
183ACB	2017-07-09 07:44:00+03	30200.00
183ACC	2017-08-14 17:10:00+03	38400.00
183B01	2017-08-07 18:18:00+03	24400.00
183B2E	2017-07-11 00:48:00+03	98400.00
183B63	2017-08-07 21:59:00+03	43900.00
183B66	2017-07-18 01:45:00+03	50000.00
183B69	2017-07-24 05:56:00+03	11700.00
183B9F	2017-07-16 14:11:00+03	6300.00
183C23	2017-07-12 09:40:00+03	160200.00
183C2C	2017-07-16 11:58:00+03	28800.00
183C74	2017-07-02 20:53:00+03	62600.00
183CD6	2017-08-03 13:07:00+03	94700.00
183DCC	2017-07-30 22:52:00+03	69500.00
183E13	2017-07-23 19:09:00+03	44800.00
183E16	2017-07-24 17:55:00+03	24700.00
183EAD	2017-07-20 21:28:00+03	66800.00
183F2B	2017-08-08 15:27:00+03	37200.00
183F3F	2017-07-12 13:59:00+03	397500.00
183F6E	2017-08-10 18:21:00+03	141300.00
183FAD	2017-08-10 07:13:00+03	75600.00
183FE1	2017-07-07 07:47:00+03	21800.00
184013	2017-08-06 19:50:00+03	100600.00
18403C	2017-07-10 07:54:00+03	54000.00
18403E	2017-07-01 22:04:00+03	142400.00
184090	2017-08-01 23:44:00+03	26800.00
1840B0	2017-07-04 20:59:00+03	412800.00
184151	2017-07-23 10:15:00+03	289800.00
1841A5	2017-07-23 05:14:00+03	99600.00
1841AE	2017-07-26 06:40:00+03	32200.00
1841F9	2017-08-08 13:33:00+03	195600.00
184220	2017-07-18 08:44:00+03	168600.00
18428C	2017-08-05 09:07:00+03	17800.00
1842E1	2017-07-25 17:33:00+03	113600.00
1842E4	2017-07-18 10:49:00+03	248400.00
184354	2017-07-17 10:07:00+03	206200.00
184373	2017-07-06 07:59:00+03	21800.00
1843A4	2017-08-12 14:36:00+03	24400.00
1843B6	2017-08-02 15:14:00+03	6000.00
184402	2017-08-01 20:34:00+03	56000.00
18440F	2017-07-27 04:27:00+03	26000.00
184443	2017-08-01 15:32:00+03	37100.00
18447C	2017-08-12 01:13:00+03	68800.00
1844DE	2017-07-25 19:34:00+03	135300.00
184506	2017-07-29 06:39:00+03	6800.00
18452F	2017-08-12 02:11:00+03	283200.00
18453C	2017-08-07 13:30:00+03	289800.00
184586	2017-08-01 19:30:00+03	6300.00
18458D	2017-08-09 12:12:00+03	6300.00
1845B5	2017-08-05 09:09:00+03	15000.00
1845E4	2017-07-11 21:10:00+03	46800.00
1845F5	2017-07-10 19:56:00+03	27800.00
18461C	2017-08-10 11:22:00+03	50300.00
18467A	2017-08-03 19:02:00+03	24400.00
184695	2017-07-25 04:28:00+03	115200.00
1846AB	2017-08-04 06:52:00+03	32700.00
1846C1	2017-07-07 20:33:00+03	131100.00
1846C5	2017-08-11 19:47:00+03	131600.00
184719	2017-07-25 20:06:00+03	40000.00
184733	2017-07-29 23:37:00+03	29400.00
184755	2017-07-25 13:03:00+03	57600.00
184763	2017-07-16 11:24:00+03	56000.00
18477C	2017-07-10 11:07:00+03	19600.00
1847CF	2017-07-09 13:18:00+03	18800.00
1847E0	2017-07-11 04:42:00+03	30200.00
184845	2017-07-15 16:18:00+03	36800.00
1848D9	2017-07-10 10:28:00+03	12200.00
1848DC	2017-08-13 10:09:00+03	23200.00
184901	2017-07-13 00:51:00+03	152600.00
18496A	2017-08-09 18:10:00+03	134200.00
1849E0	2017-07-08 15:40:00+03	34700.00
184A19	2017-08-04 21:52:00+03	96800.00
184A20	2017-07-22 07:44:00+03	104600.00
184A89	2017-08-12 03:02:00+03	28800.00
184AF0	2017-06-30 19:50:00+03	55800.00
184B7E	2017-08-13 14:47:00+03	85800.00
184B8C	2017-07-10 14:19:00+03	248300.00
184BC4	2017-07-24 11:44:00+03	44800.00
184BCF	2017-07-18 15:59:00+03	52400.00
184BDF	2017-08-07 21:00:00+03	246000.00
184BE6	2017-07-21 06:12:00+03	199700.00
184C1A	2017-07-25 12:41:00+03	123000.00
184C3C	2017-07-31 05:15:00+03	171600.00
184C4B	2017-07-17 00:52:00+03	22000.00
184C66	2017-08-06 17:16:00+03	27700.00
184CA4	2017-08-03 10:06:00+03	49800.00
184CA9	2017-07-19 00:05:00+03	50600.00
184CF8	2017-08-13 08:47:00+03	28000.00
184D16	2017-07-10 10:10:00+03	20500.00
184D30	2017-07-05 21:36:00+03	135400.00
184DD5	2017-08-04 07:12:00+03	28300.00
184E18	2017-07-25 22:55:00+03	116800.00
184EB3	2017-07-11 07:37:00+03	14000.00
184EDA	2017-07-25 06:00:00+03	133200.00
184F0D	2017-08-04 15:43:00+03	136600.00
184F4E	2017-08-10 10:13:00+03	135600.00
184F54	2017-07-21 00:05:00+03	170100.00
184F8B	2017-08-07 03:44:00+03	128000.00
18505C	2017-08-03 05:18:00+03	58400.00
18506A	2017-08-02 05:46:00+03	136300.00
185084	2017-08-07 17:38:00+03	88500.00
185086	2017-08-06 05:25:00+03	76600.00
1850AD	2017-07-23 05:16:00+03	46300.00
1850BD	2017-07-02 18:45:00+03	68100.00
1851E9	2017-08-13 05:14:00+03	79600.00
1851EE	2017-08-13 04:48:00+03	119000.00
185208	2017-07-03 16:46:00+03	32800.00
185223	2017-07-18 03:34:00+03	203800.00
185239	2017-07-12 13:15:00+03	46000.00
18525A	2017-07-01 16:20:00+03	67200.00
1852DB	2017-08-04 20:40:00+03	26800.00
1852E1	2017-08-12 15:23:00+03	50600.00
1852F6	2017-08-04 10:59:00+03	6700.00
185308	2017-07-20 10:04:00+03	29600.00
185322	2017-07-06 01:17:00+03	49600.00
185323	2017-07-17 19:48:00+03	90000.00
18533E	2017-07-25 10:26:00+03	62900.00
18539A	2017-07-02 10:48:00+03	86800.00
1853EA	2017-08-05 09:53:00+03	46500.00
185431	2017-07-29 23:39:00+03	44000.00
185439	2017-08-08 17:05:00+03	23200.00
185449	2017-07-17 11:23:00+03	47000.00
1854A4	2017-08-08 16:45:00+03	126000.00
1854D6	2017-07-15 00:30:00+03	185700.00
18550D	2017-07-27 17:36:00+03	33800.00
18554C	2017-07-21 07:47:00+03	84800.00
185556	2017-07-07 03:48:00+03	24700.00
18556B	2017-08-04 14:36:00+03	111600.00
1855B8	2017-08-10 13:31:00+03	69000.00
185631	2017-08-04 07:58:00+03	43600.00
18564E	2017-07-20 03:54:00+03	58600.00
1856AE	2017-08-15 09:04:00+03	83100.00
1856F3	2017-08-07 00:12:00+03	11000.00
185714	2017-07-04 11:19:00+03	133200.00
185728	2017-08-01 19:26:00+03	70800.00
185753	2017-07-21 01:23:00+03	25400.00
18576A	2017-08-04 14:25:00+03	28000.00
185784	2017-08-06 05:12:00+03	232800.00
1857A4	2017-07-27 02:00:00+03	13700.00
18580A	2017-07-13 02:05:00+03	19800.00
185810	2017-07-20 13:21:00+03	155700.00
185823	2017-07-10 17:55:00+03	194200.00
185841	2017-07-22 07:25:00+03	61800.00
1858B4	2017-07-01 14:39:00+03	36200.00
1858D3	2017-07-06 07:32:00+03	18000.00
185946	2017-06-29 18:56:00+03	86600.00
185997	2017-07-26 15:29:00+03	133100.00
1859A2	2017-07-15 00:39:00+03	32800.00
185A08	2017-07-25 17:41:00+03	23900.00
185A3E	2017-07-05 13:31:00+03	27800.00
185A69	2017-08-05 01:13:00+03	54800.00
185AC1	2017-07-05 12:02:00+03	28000.00
185AE4	2017-08-04 22:02:00+03	11600.00
185AF5	2017-08-10 12:56:00+03	186000.00
185B25	2017-08-13 00:38:00+03	88100.00
185B7D	2017-07-13 16:14:00+03	113300.00
185BC7	2017-07-25 16:11:00+03	132200.00
185BD7	2017-06-29 06:12:00+03	72000.00
185BFA	2017-07-01 19:28:00+03	6300.00
185C41	2017-07-11 10:08:00+03	35300.00
185C55	2017-08-13 12:46:00+03	18000.00
185CB8	2017-07-11 13:55:00+03	467000.00
185CD3	2017-07-18 22:53:00+03	69500.00
185D34	2017-07-28 18:13:00+03	36200.00
185D79	2017-07-22 07:55:00+03	54800.00
185DEE	2017-07-16 13:39:00+03	28800.00
185DFA	2017-06-30 05:06:00+03	54800.00
185E41	2017-07-21 08:38:00+03	58600.00
185E44	2017-07-03 12:23:00+03	17800.00
185EC8	2017-07-29 07:18:00+03	133100.00
185EE2	2017-07-16 13:23:00+03	108900.00
185F84	2017-08-02 13:32:00+03	107000.00
185FDB	2017-07-18 07:36:00+03	24400.00
185FF5	2017-07-09 09:59:00+03	33800.00
186019	2017-07-29 06:44:00+03	66400.00
18607D	2017-07-04 16:48:00+03	28800.00
186088	2017-07-26 10:43:00+03	128800.00
1860A4	2017-07-21 02:16:00+03	24400.00
186106	2017-07-27 07:57:00+03	128800.00
18623B	2017-08-13 05:23:00+03	58800.00
186286	2017-07-26 02:04:00+03	6800.00
1862B8	2017-08-07 21:01:00+03	51900.00
1862EE	2017-07-23 09:08:00+03	58400.00
186303	2017-08-13 17:22:00+03	72400.00
186333	2017-07-28 23:00:00+03	105700.00
186334	2017-06-25 18:44:00+03	23600.00
186374	2017-08-13 00:00:00+03	83600.00
186380	2017-08-13 06:27:00+03	41400.00
1863B3	2017-07-11 18:40:00+03	133100.00
1863DD	2017-07-09 16:20:00+03	99200.00
186443	2017-08-14 18:56:00+03	137600.00
1864D4	2017-08-13 14:54:00+03	68300.00
1864D9	2017-08-06 06:38:00+03	40700.00
1864DB	2017-07-03 21:05:00+03	94100.00
1864F3	2017-08-12 08:09:00+03	143200.00
186589	2017-07-16 02:58:00+03	23600.00
186598	2017-07-15 05:59:00+03	45400.00
1865C3	2017-08-15 00:22:00+03	116300.00
186605	2017-08-10 11:48:00+03	37900.00
18662F	2017-07-29 16:46:00+03	50000.00
186638	2017-07-29 17:55:00+03	26800.00
18663B	2017-08-13 16:56:00+03	40400.00
18666A	2017-07-04 07:55:00+03	50400.00
18668C	2017-08-14 18:26:00+03	88900.00
186694	2017-07-04 06:23:00+03	28000.00
1866FD	2017-07-02 02:17:00+03	28000.00
186705	2017-06-28 23:12:00+03	39300.00
18673F	2017-07-01 03:59:00+03	46500.00
18674B	2017-07-23 10:00:00+03	67000.00
186753	2017-07-10 03:25:00+03	67200.00
186790	2017-07-31 15:38:00+03	43000.00
1867A9	2017-08-01 17:08:00+03	37900.00
1867F8	2017-08-06 14:48:00+03	56000.00
186865	2017-07-04 18:43:00+03	83000.00
1868B1	2017-07-02 11:22:00+03	115600.00
1868CC	2017-08-13 20:58:00+03	169900.00
186902	2017-08-09 13:19:00+03	97400.00
18691C	2017-07-18 14:23:00+03	162700.00
186935	2017-06-30 06:56:00+03	44000.00
186942	2017-06-28 01:41:00+03	42700.00
18694B	2017-08-10 11:48:00+03	55600.00
18696D	2017-07-13 16:18:00+03	52000.00
1869AA	2017-07-16 11:05:00+03	35600.00
186A35	2017-07-13 18:28:00+03	39000.00
186A4C	2017-07-27 12:28:00+03	82900.00
186B21	2017-08-08 05:33:00+03	18300.00
186B43	2017-07-04 23:38:00+03	282100.00
186B76	2017-08-05 14:55:00+03	70600.00
186BA7	2017-07-24 04:44:00+03	92000.00
186BC8	2017-07-30 22:31:00+03	45200.00
186BF5	2017-07-04 00:39:00+03	214400.00
186C0D	2017-07-14 11:07:00+03	69500.00
186CCD	2017-07-06 13:46:00+03	162700.00
186CF0	2017-07-16 22:56:00+03	136800.00
186D2A	2017-07-03 15:12:00+03	58000.00
186D9D	2017-07-13 19:17:00+03	57400.00
186DC4	2017-07-28 19:44:00+03	32800.00
186E6D	2017-07-18 18:11:00+03	36800.00
186E98	2017-07-04 21:07:00+03	135600.00
186ECD	2017-07-11 05:08:00+03	130400.00
186F29	2017-08-07 15:38:00+03	95700.00
186F97	2017-08-10 12:56:00+03	6700.00
186FC4	2017-08-10 18:42:00+03	408500.00
187014	2017-08-14 07:02:00+03	77900.00
187076	2017-07-09 12:18:00+03	92800.00
187089	2017-07-06 21:05:00+03	149400.00
18708C	2017-08-15 14:25:00+03	6300.00
1870AD	2017-07-19 18:42:00+03	8000.00
1870E9	2017-07-20 10:03:00+03	48800.00
187168	2017-08-08 16:56:00+03	26200.00
187174	2017-07-15 15:28:00+03	66800.00
187198	2017-07-07 05:12:00+03	58600.00
1871E4	2017-08-09 19:47:00+03	40800.00
187262	2017-07-07 03:17:00+03	147200.00
18729D	2017-07-05 18:26:00+03	143200.00
1872B3	2017-08-14 17:34:00+03	70700.00
1872CE	2017-07-31 19:12:00+03	74800.00
1872E2	2017-07-06 13:10:00+03	148200.00
187316	2017-07-14 14:42:00+03	47000.00
187346	2017-08-11 06:35:00+03	24800.00
18735E	2017-07-30 07:09:00+03	72300.00
1873BB	2017-08-15 12:50:00+03	89700.00
1873D7	2017-07-07 10:53:00+03	13400.00
18748D	2017-07-28 07:09:00+03	46400.00
1874B9	2017-08-09 23:41:00+03	59000.00
187510	2017-07-07 00:32:00+03	56600.00
18756D	2017-07-16 03:17:00+03	93300.00
18757B	2017-07-19 11:38:00+03	6600.00
1875E9	2017-07-23 20:30:00+03	50800.00
187624	2017-07-25 02:06:00+03	54600.00
18769F	2017-08-03 23:45:00+03	27900.00
1876A9	2017-08-01 11:01:00+03	33100.00
1876BE	2017-07-29 18:33:00+03	15000.00
18770E	2017-07-05 08:25:00+03	369000.00
187745	2017-07-09 00:37:00+03	44000.00
187767	2017-07-18 00:23:00+03	77200.00
18777A	2017-08-01 16:58:00+03	18300.00
18777B	2017-07-07 05:06:00+03	28000.00
187782	2017-07-02 17:58:00+03	29600.00
1877A5	2017-07-26 13:23:00+03	32700.00
1877A8	2017-07-11 09:52:00+03	125200.00
1877D2	2017-07-23 16:05:00+03	13000.00
1877D4	2017-08-09 09:41:00+03	39300.00
187804	2017-07-30 20:37:00+03	12600.00
187812	2017-08-10 08:20:00+03	232200.00
187870	2017-07-20 20:05:00+03	46900.00
18789F	2017-07-10 14:22:00+03	49800.00
1878A1	2017-08-10 07:52:00+03	40000.00
1878BF	2017-07-31 12:43:00+03	56200.00
1878FD	2017-07-10 20:35:00+03	291000.00
187905	2017-07-21 23:23:00+03	16400.00
18793A	2017-07-23 13:54:00+03	46000.00
187977	2017-06-27 22:46:00+03	234700.00
18799B	2017-07-07 09:28:00+03	90400.00
1879BC	2017-07-13 06:21:00+03	13400.00
187A07	2017-07-29 16:36:00+03	87000.00
187A79	2017-07-25 02:03:00+03	36200.00
187A7A	2017-08-05 18:39:00+03	168600.00
187AD2	2017-07-12 18:00:00+03	18600.00
187B05	2017-07-30 08:24:00+03	28800.00
187B07	2017-07-16 14:52:00+03	12400.00
187B1A	2017-07-25 03:08:00+03	131100.00
187BA5	2017-07-27 18:54:00+03	52000.00
187BA8	2017-07-14 04:39:00+03	32800.00
187C6E	2017-07-26 22:32:00+03	119600.00
187C85	2017-07-14 10:37:00+03	68900.00
187CE4	2017-07-16 17:14:00+03	66900.00
187CF4	2017-08-08 02:27:00+03	481800.00
187D2F	2017-07-29 04:05:00+03	73600.00
187D58	2017-07-25 21:35:00+03	63700.00
187D80	2017-08-10 01:36:00+03	14400.00
187D92	2017-07-16 10:50:00+03	50400.00
187DB4	2017-07-07 04:34:00+03	55400.00
187DC1	2017-07-24 15:42:00+03	67700.00
187E00	2017-07-17 11:11:00+03	154100.00
187E0E	2017-07-05 08:46:00+03	115900.00
187EAC	2017-08-05 20:23:00+03	131600.00
187EF9	2017-07-19 18:30:00+03	36200.00
187F26	2017-08-12 02:08:00+03	56000.00
187F70	2017-08-12 21:11:00+03	56600.00
187F92	2017-07-31 06:05:00+03	267000.00
187FDE	2017-07-12 21:57:00+03	70600.00
188009	2017-07-19 10:24:00+03	81300.00
188085	2017-07-18 04:02:00+03	16400.00
188151	2017-06-30 12:27:00+03	47400.00
188184	2017-08-08 05:42:00+03	123000.00
1881C2	2017-08-06 10:19:00+03	46400.00
1881F1	2017-07-23 03:44:00+03	58700.00
18820D	2017-08-02 21:48:00+03	14400.00
188226	2017-07-14 11:11:00+03	19800.00
1882A1	2017-08-01 02:08:00+03	66400.00
1882BA	2017-07-14 17:20:00+03	96300.00
1882EA	2017-08-01 18:00:00+03	70700.00
1882EE	2017-07-28 05:15:00+03	35200.00
188340	2017-07-30 19:11:00+03	128900.00
188359	2017-08-12 08:49:00+03	28300.00
18835D	2017-07-27 09:28:00+03	12600.00
1883F6	2017-07-18 15:48:00+03	96200.00
188406	2017-07-18 03:08:00+03	21200.00
188419	2017-08-13 01:12:00+03	193700.00
188447	2017-08-05 21:34:00+03	136200.00
18844E	2017-07-27 09:05:00+03	47000.00
1884F9	2017-08-09 04:58:00+03	36200.00
1884FA	2017-07-24 06:25:00+03	43200.00
18851D	2017-07-25 01:20:00+03	43800.00
18863B	2017-08-14 05:46:00+03	254900.00
18866A	2017-08-06 17:48:00+03	54600.00
1886B3	2017-07-20 18:43:00+03	41600.00
188717	2017-08-11 15:29:00+03	18600.00
188759	2017-07-13 19:39:00+03	369000.00
188769	2017-07-20 02:13:00+03	117200.00
1887AB	2017-07-15 04:52:00+03	27400.00
18881D	2017-07-02 08:07:00+03	17800.00
18889E	2017-08-06 09:35:00+03	62800.00
18891E	2017-07-01 16:34:00+03	136200.00
188952	2017-08-14 16:40:00+03	50500.00
188953	2017-07-27 12:38:00+03	76600.00
1889A1	2017-07-23 10:54:00+03	265700.00
188A25	2017-08-01 11:24:00+03	174200.00
188A46	2017-07-22 21:04:00+03	112000.00
188B08	2017-08-15 13:44:00+03	55700.00
188B73	2017-08-02 19:47:00+03	201200.00
188BF0	2017-07-03 08:18:00+03	27700.00
188C0A	2017-07-05 08:19:00+03	14000.00
188C13	2017-07-21 16:44:00+03	35200.00
188C38	2017-07-25 03:11:00+03	16400.00
188CAA	2017-07-23 05:27:00+03	29600.00
188D07	2017-07-08 02:07:00+03	77000.00
188D8C	2017-08-15 10:14:00+03	36400.00
188E2B	2017-06-29 15:41:00+03	120300.00
188E50	2017-08-11 11:19:00+03	119700.00
188E93	2017-08-09 01:35:00+03	11600.00
188F23	2017-07-25 12:35:00+03	65500.00
188F54	2017-08-04 07:21:00+03	73200.00
188F57	2017-08-02 02:58:00+03	202400.00
188F5C	2017-07-26 16:10:00+03	98200.00
188FAD	2017-07-21 19:47:00+03	399600.00
1890C6	2017-08-09 00:05:00+03	19400.00
1890EC	2017-07-15 21:05:00+03	246000.00
189123	2017-07-10 01:26:00+03	175700.00
18912D	2017-08-03 22:43:00+03	29200.00
189149	2017-07-13 02:05:00+03	91100.00
18914B	2017-07-30 04:05:00+03	98400.00
18915A	2017-07-12 00:48:00+03	42700.00
189171	2017-07-04 03:16:00+03	33100.00
189262	2017-06-30 13:05:00+03	44400.00
1892B0	2017-07-03 16:19:00+03	26100.00
1892C2	2017-08-11 00:22:00+03	55600.00
1892EA	2017-08-11 02:59:00+03	51700.00
1892EF	2017-07-09 15:56:00+03	14000.00
189322	2017-08-03 07:52:00+03	70700.00
189408	2017-08-09 02:51:00+03	85200.00
189430	2017-07-15 09:12:00+03	10700.00
189458	2017-07-10 03:39:00+03	59300.00
1894D6	2017-07-17 04:41:00+03	9800.00
189514	2017-08-08 08:28:00+03	40400.00
189578	2017-07-22 00:51:00+03	62600.00
1895C0	2017-07-29 11:03:00+03	54800.00
189632	2017-08-11 07:06:00+03	51800.00
189649	2017-08-03 23:56:00+03	596700.00
189665	2017-08-03 19:49:00+03	92400.00
189676	2017-08-06 22:39:00+03	27800.00
1896B0	2017-07-16 18:33:00+03	301800.00
1896B9	2017-08-13 07:10:00+03	42800.00
1896C9	2017-07-07 02:52:00+03	81300.00
1896CB	2017-07-20 18:20:00+03	131900.00
1896FB	2017-07-14 22:07:00+03	34000.00
1897D7	2017-08-15 12:28:00+03	26800.00
18981E	2017-08-02 23:09:00+03	46400.00
18986C	2017-08-14 12:22:00+03	57100.00
189890	2017-08-03 01:49:00+03	92100.00
1898E2	2017-07-08 15:29:00+03	31600.00
1898F2	2017-08-05 05:55:00+03	135600.00
189952	2017-07-08 02:55:00+03	10800.00
189A0F	2017-07-06 13:18:00+03	39200.00
189A14	2017-07-09 08:13:00+03	52300.00
189A81	2017-07-19 20:51:00+03	15900.00
189B39	2017-07-20 00:18:00+03	91100.00
189B60	2017-08-04 17:49:00+03	94700.00
189BAD	2017-07-17 05:58:00+03	28800.00
189C1A	2017-07-05 09:43:00+03	14400.00
189C4F	2017-08-07 09:12:00+03	45500.00
189C64	2017-08-08 23:24:00+03	63400.00
189CAA	2017-07-02 18:34:00+03	28000.00
189CD6	2017-07-08 01:03:00+03	6000.00
189CDF	2017-08-14 15:34:00+03	39200.00
189CE9	2017-08-05 07:02:00+03	89800.00
189D41	2017-07-29 17:17:00+03	123000.00
189D7E	2017-07-07 23:20:00+03	20800.00
189D9E	2017-08-03 17:22:00+03	88900.00
189DC3	2017-07-22 02:25:00+03	62600.00
189DCE	2017-07-17 03:06:00+03	46400.00
189E28	2017-07-07 00:15:00+03	29600.00
189E41	2017-08-02 04:35:00+03	63800.00
189E8B	2017-07-13 19:02:00+03	56600.00
189E8E	2017-07-04 18:34:00+03	106700.00
189F0E	2017-07-07 20:08:00+03	29600.00
189F12	2017-07-28 03:01:00+03	10600.00
189F1A	2017-07-24 14:21:00+03	72400.00
18A028	2017-08-04 17:04:00+03	51300.00
18A04A	2017-07-19 03:16:00+03	83000.00
18A04D	2017-07-27 03:45:00+03	41800.00
18A053	2017-07-06 14:37:00+03	136200.00
18A138	2017-07-10 10:22:00+03	83000.00
18A17E	2017-06-30 07:15:00+03	30000.00
18A1AC	2017-07-11 18:01:00+03	42200.00
18A1D6	2017-07-18 03:54:00+03	67400.00
18A231	2017-08-06 17:06:00+03	99300.00
18A23C	2017-07-13 12:09:00+03	124200.00
18A2E1	2017-07-16 21:36:00+03	21400.00
18A344	2017-07-12 04:09:00+03	34800.00
18A3E9	2017-07-04 12:47:00+03	300900.00
18A40C	2017-07-09 12:35:00+03	300900.00
18A493	2017-07-30 21:15:00+03	37600.00
18A534	2017-07-19 12:09:00+03	99200.00
18A5B9	2017-06-28 23:06:00+03	6700.00
18A63B	2017-07-20 11:08:00+03	6000.00
18A652	2017-07-27 02:10:00+03	266400.00
18A6CF	2017-07-22 09:20:00+03	37200.00
18A6ED	2017-07-23 21:05:00+03	66100.00
18A6EE	2017-08-04 21:02:00+03	56000.00
18A6F0	2017-07-10 10:03:00+03	89700.00
18A711	2017-08-03 14:00:00+03	26000.00
18A789	2017-08-03 04:59:00+03	54000.00
18A818	2017-07-06 20:22:00+03	26000.00
18A8B5	2017-08-10 16:19:00+03	58100.00
18A8D7	2017-07-01 08:29:00+03	46000.00
18A90C	2017-07-30 23:26:00+03	31600.00
18A91D	2017-07-10 00:52:00+03	131600.00
18A944	2017-08-04 07:00:00+03	87700.00
18A967	2017-07-30 18:01:00+03	152900.00
18A984	2017-08-13 05:39:00+03	396500.00
18A9A6	2017-07-01 07:27:00+03	32600.00
18A9E2	2017-07-11 21:53:00+03	59300.00
18A9FC	2017-07-16 21:08:00+03	25600.00
18AA1B	2017-07-19 20:51:00+03	76600.00
18AA1C	2017-07-05 10:39:00+03	27900.00
18AA40	2017-07-31 13:02:00+03	34600.00
18AA89	2017-07-01 13:31:00+03	41200.00
18AAA9	2017-07-12 23:16:00+03	18000.00
18AAC3	2017-07-09 15:11:00+03	92100.00
18AAE1	2017-08-11 07:06:00+03	129200.00
18AB4A	2017-07-09 01:38:00+03	69600.00
18AB4B	2017-07-16 10:26:00+03	383100.00
18AB4F	2017-07-25 11:45:00+03	73500.00
18ABD4	2017-07-16 16:15:00+03	36800.00
18ABD9	2017-07-20 23:54:00+03	53500.00
18AC2D	2017-08-06 18:04:00+03	273400.00
18AC93	2017-07-02 17:03:00+03	8000.00
18AD6B	2017-07-07 08:41:00+03	123000.00
18ADAA	2017-07-09 15:21:00+03	59800.00
18ADF7	2017-07-13 21:05:00+03	92800.00
18AE1B	2017-07-04 15:22:00+03	64200.00
18AE27	2017-07-19 03:16:00+03	28800.00
18AE36	2017-07-15 08:15:00+03	25600.00
18AE82	2017-08-09 21:14:00+03	50200.00
18AEA8	2017-08-01 23:41:00+03	61800.00
18AEE5	2017-08-12 16:46:00+03	38600.00
18AF01	2017-08-09 18:06:00+03	168000.00
18AF02	2017-07-27 02:32:00+03	24400.00
18AF43	2017-07-05 16:02:00+03	101200.00
18AF5A	2017-07-10 19:39:00+03	46400.00
18AFFE	2017-08-15 08:46:00+03	13400.00
18B012	2017-08-15 12:03:00+03	40000.00
18B0AC	2017-07-20 07:30:00+03	137100.00
18B0D7	2017-07-22 20:49:00+03	84300.00
18B0FA	2017-07-22 06:46:00+03	41200.00
18B0FD	2017-08-11 10:41:00+03	124200.00
18B10B	2017-07-25 20:32:00+03	29100.00
18B148	2017-07-11 14:27:00+03	24700.00
18B153	2017-07-30 11:02:00+03	31400.00
18B1A3	2017-08-15 10:20:00+03	86500.00
18B1B5	2017-07-11 15:58:00+03	29600.00
18B1BD	2017-07-14 10:56:00+03	26200.00
18B1D7	2017-07-07 14:10:00+03	57500.00
18B1E1	2017-07-23 18:05:00+03	68800.00
18B1F1	2017-07-13 17:29:00+03	24400.00
18B215	2017-07-31 06:58:00+03	83200.00
18B221	2017-07-19 18:38:00+03	26000.00
18B231	2017-07-31 17:11:00+03	90400.00
18B27B	2017-07-21 18:17:00+03	52400.00
18B2EB	2017-07-12 07:58:00+03	13400.00
18B2F8	2017-08-03 02:02:00+03	57600.00
18B302	2017-08-11 07:23:00+03	31100.00
18B36F	2017-07-23 20:50:00+03	97600.00
18B377	2017-07-15 08:05:00+03	66600.00
18B440	2017-07-30 14:27:00+03	40800.00
18B446	2017-08-09 08:05:00+03	65500.00
18B4ED	2017-07-06 15:44:00+03	27400.00
18B514	2017-08-13 08:54:00+03	184300.00
18B52B	2017-07-15 14:25:00+03	21800.00
18B579	2017-08-05 18:32:00+03	46200.00
18B580	2017-07-10 10:48:00+03	25600.00
18B59E	2017-07-01 02:10:00+03	21400.00
18B5BD	2017-07-18 09:51:00+03	47400.00
18B5E5	2017-07-25 19:44:00+03	124200.00
18B621	2017-08-15 06:29:00+03	28600.00
18B636	2017-07-06 12:35:00+03	86300.00
18B691	2017-07-22 08:36:00+03	111600.00
18B6A9	2017-08-11 14:04:00+03	75300.00
18B70C	2017-07-05 17:09:00+03	105000.00
18B7BF	2017-07-23 17:52:00+03	130400.00
18B7CB	2017-07-15 12:34:00+03	151200.00
18B82F	2017-07-15 11:25:00+03	37700.00
18B841	2017-08-12 20:43:00+03	132500.00
18B85F	2017-08-05 12:43:00+03	64600.00
18B868	2017-07-18 15:50:00+03	140900.00
18B895	2017-08-08 00:25:00+03	24400.00
18B8E3	2017-07-12 18:16:00+03	38800.00
18B8EA	2017-08-10 20:51:00+03	89600.00
18B948	2017-07-11 10:24:00+03	46000.00
18B961	2017-07-17 05:18:00+03	25200.00
18B9B0	2017-07-20 05:13:00+03	48800.00
18B9C7	2017-07-20 20:41:00+03	163800.00
18B9F0	2017-07-13 05:14:00+03	137600.00
18B9F9	2017-08-01 19:29:00+03	112300.00
18BA7D	2017-07-31 11:13:00+03	24700.00
18BA99	2017-08-01 06:57:00+03	65500.00
18BAC9	2017-07-19 03:34:00+03	73400.00
18BB1C	2017-07-27 22:09:00+03	30000.00
18BB35	2017-07-24 11:27:00+03	33100.00
18BC4C	2017-07-09 01:05:00+03	103500.00
18BC58	2017-07-18 02:21:00+03	70600.00
18BC8A	2017-06-30 10:05:00+03	89700.00
18BC93	2017-08-07 10:12:00+03	233500.00
18BCAD	2017-07-10 17:52:00+03	266400.00
18BCB5	2017-08-15 13:53:00+03	47500.00
18BD06	2017-08-05 19:14:00+03	48800.00
18BD0E	2017-08-13 22:04:00+03	98400.00
18BD5F	2017-08-08 02:49:00+03	28000.00
18BD85	2017-07-10 10:19:00+03	21400.00
18BD96	2017-07-27 06:18:00+03	69900.00
18BD9E	2017-07-23 22:29:00+03	48300.00
18BDDC	2017-08-04 14:20:00+03	39700.00
18BDDF	2017-08-12 10:37:00+03	16400.00
18BEDF	2017-07-31 16:00:00+03	11600.00
18BF0C	2017-07-10 22:05:00+03	114300.00
18BF25	2017-07-07 03:22:00+03	55800.00
18BF68	2017-07-20 17:19:00+03	6000.00
18BFC2	2017-08-02 17:54:00+03	6000.00
18BFE2	2017-07-14 11:23:00+03	58800.00
18C00A	2017-08-14 10:55:00+03	85000.00
18C027	2017-07-04 00:16:00+03	69500.00
18C039	2017-07-25 02:55:00+03	22000.00
18C060	2017-08-09 14:03:00+03	26000.00
18C09C	2017-06-29 22:27:00+03	178000.00
18C0E9	2017-08-04 15:05:00+03	93000.00
18C154	2017-07-06 06:15:00+03	44000.00
18C18D	2017-07-01 17:00:00+03	44900.00
18C1CD	2017-07-09 20:26:00+03	69500.00
18C1D5	2017-07-18 22:51:00+03	6200.00
18C1F0	2017-08-08 08:00:00+03	94200.00
18C24D	2017-07-22 12:28:00+03	21800.00
18C308	2017-07-24 23:15:00+03	8200.00
18C30C	2017-08-08 09:22:00+03	112000.00
18C3F6	2017-07-05 12:06:00+03	46400.00
18C3FD	2017-08-08 11:32:00+03	74800.00
18C43A	2017-07-13 22:19:00+03	55800.00
18C43B	2017-08-10 03:49:00+03	26000.00
18C48C	2017-07-28 15:22:00+03	26200.00
18C4D2	2017-08-09 09:07:00+03	116900.00
18C4D7	2017-07-11 06:03:00+03	60200.00
18C551	2017-07-10 00:26:00+03	131600.00
18C58A	2017-08-13 04:48:00+03	282600.00
18C610	2017-07-12 10:53:00+03	6700.00
18C6AC	2017-08-12 08:37:00+03	6300.00
18C70F	2017-07-28 17:43:00+03	37600.00
18C723	2017-07-06 20:10:00+03	246000.00
18C83F	2017-08-12 23:59:00+03	13000.00
18C8D3	2017-07-06 02:35:00+03	30200.00
18C8F5	2017-07-19 05:12:00+03	31400.00
18C917	2017-07-15 17:27:00+03	136200.00
18C941	2017-07-14 06:57:00+03	23900.00
18C956	2017-08-01 20:11:00+03	120600.00
18C992	2017-08-02 20:13:00+03	46400.00
18CA0A	2017-07-06 11:41:00+03	9300.00
18CA46	2017-08-13 15:35:00+03	36200.00
18CA70	2017-07-17 02:14:00+03	40200.00
18CAA6	2017-07-06 19:16:00+03	46000.00
18CAFB	2017-07-20 14:34:00+03	111600.00
18CB3D	2017-08-07 05:25:00+03	75300.00
18CB80	2017-07-12 17:32:00+03	67700.00
18CC23	2017-08-13 21:28:00+03	20200.00
18CCE5	2017-08-02 08:18:00+03	58700.00
18CCF4	2017-07-28 23:31:00+03	56000.00
18CCF5	2017-07-07 14:21:00+03	63000.00
18CCFD	2017-07-29 13:01:00+03	93900.00
18CD13	2017-08-04 16:56:00+03	538900.00
18CD4E	2017-07-08 12:45:00+03	132800.00
18CD8C	2017-07-22 01:18:00+03	43400.00
18CD90	2017-07-19 00:28:00+03	84100.00
18CD9C	2017-07-16 11:31:00+03	28000.00
18CDA5	2017-07-24 20:35:00+03	47200.00
18CE7F	2017-07-19 13:22:00+03	36400.00
18CED0	2017-08-08 06:00:00+03	54000.00
18CF4F	2017-07-17 06:46:00+03	20400.00
18CF63	2017-08-09 01:09:00+03	10700.00
18CFC8	2017-07-29 12:50:00+03	3400.00
18CFD7	2017-07-07 09:03:00+03	184000.00
18CFED	2017-08-01 20:08:00+03	81200.00
18CFF4	2017-08-03 20:03:00+03	44400.00
18D01D	2017-07-25 00:15:00+03	27900.00
18D091	2017-07-24 18:06:00+03	177200.00
18D092	2017-07-03 19:13:00+03	38500.00
18D0AE	2017-08-10 12:27:00+03	136500.00
18D0D1	2017-08-06 13:43:00+03	65900.00
18D0DA	2017-08-04 23:05:00+03	26000.00
18D0E0	2017-07-08 21:36:00+03	71200.00
18D0E4	2017-07-14 07:39:00+03	119100.00
18D0F2	2017-07-10 00:41:00+03	13700.00
18D114	2017-08-09 22:22:00+03	58600.00
18D128	2017-08-14 10:20:00+03	57200.00
18D160	2017-07-28 13:04:00+03	92800.00
18D216	2017-07-14 11:51:00+03	22600.00
18D298	2017-07-03 14:16:00+03	28800.00
18D299	2017-06-25 10:41:00+03	35700.00
18D2BB	2017-07-21 10:23:00+03	73600.00
18D311	2017-07-26 12:26:00+03	86800.00
18D34B	2017-07-27 11:16:00+03	82900.00
18D3C9	2017-07-04 10:44:00+03	70700.00
18D3D2	2017-07-22 21:56:00+03	89700.00
18D4FE	2017-06-29 23:54:00+03	93800.00
18D509	2017-07-15 14:59:00+03	246000.00
18D54E	2017-08-07 12:26:00+03	77000.00
18D5DA	2017-07-03 09:25:00+03	34000.00
18D668	2017-07-11 17:36:00+03	153300.00
18D672	2017-07-15 04:24:00+03	13200.00
18D6C8	2017-07-12 19:54:00+03	62700.00
18D6E2	2017-07-05 04:17:00+03	21800.00
18D858	2017-07-01 21:38:00+03	52800.00
18D876	2017-07-10 15:58:00+03	19600.00
18D8D0	2017-07-17 01:03:00+03	23200.00
18D8D8	2017-07-09 13:25:00+03	68900.00
18D8F5	2017-07-19 13:14:00+03	94000.00
18D943	2017-07-30 23:21:00+03	126700.00
18D961	2017-07-18 21:03:00+03	40000.00
18D9A8	2017-07-11 21:27:00+03	96200.00
18D9D2	2017-07-26 22:28:00+03	42800.00
18D9F3	2017-08-13 18:56:00+03	52000.00
18D9FE	2017-08-09 13:38:00+03	94700.00
18DA21	2017-07-19 23:38:00+03	67500.00
18DA29	2017-07-16 16:32:00+03	68800.00
18DA38	2017-07-30 04:23:00+03	30000.00
18DA5A	2017-08-04 20:15:00+03	26800.00
18DA81	2017-07-02 23:50:00+03	130900.00
18DAB4	2017-07-21 05:08:00+03	14000.00
18DB04	2017-07-09 02:32:00+03	49200.00
18DB8F	2017-08-12 14:11:00+03	96300.00
18DB97	2017-08-03 20:36:00+03	25800.00
18DC27	2017-07-19 08:01:00+03	104200.00
18DC69	2017-08-12 03:36:00+03	17600.00
18DCB6	2017-07-12 05:19:00+03	40000.00
18DCF0	2017-07-21 20:32:00+03	6800.00
18DD17	2017-08-06 21:46:00+03	106000.00
18DD27	2017-07-18 05:03:00+03	96800.00
18DD4B	2017-08-05 17:22:00+03	23400.00
18DD76	2017-08-10 13:10:00+03	27600.00
18DD9A	2017-07-10 15:11:00+03	27200.00
18DE18	2017-08-10 00:52:00+03	143200.00
18DEB3	2017-07-05 20:42:00+03	96300.00
18DEF6	2017-07-25 20:46:00+03	68400.00
18DF8D	2017-07-26 18:29:00+03	28000.00
18E0A6	2017-07-17 09:52:00+03	104500.00
18E18E	2017-07-10 03:59:00+03	19800.00
18E1C6	2017-08-13 12:27:00+03	7400.00
18E1CA	2017-08-14 12:29:00+03	28000.00
18E214	2017-07-21 04:34:00+03	88600.00
18E269	2017-07-10 09:36:00+03	46000.00
18E31B	2017-07-15 04:26:00+03	135600.00
18E3CA	2017-07-15 08:25:00+03	49400.00
18E43D	2017-07-03 19:57:00+03	54700.00
18E44D	2017-07-19 21:53:00+03	38400.00
18E479	2017-07-21 09:10:00+03	54800.00
18E4D7	2017-07-28 23:34:00+03	288600.00
18E4E5	2017-07-08 00:49:00+03	48500.00
18E4F7	2017-08-14 23:14:00+03	65000.00
18E50C	2017-08-01 22:58:00+03	56000.00
18E545	2017-07-15 18:37:00+03	85000.00
18E593	2017-07-13 08:26:00+03	142800.00
18E5B1	2017-07-30 14:25:00+03	28000.00
18E5E4	2017-08-05 05:13:00+03	28000.00
18E62A	2017-07-18 20:49:00+03	101200.00
18E685	2017-07-19 19:17:00+03	266400.00
18E6B1	2017-07-03 21:33:00+03	35600.00
18E6C7	2017-07-25 22:15:00+03	32800.00
18E701	2017-07-04 01:54:00+03	47200.00
18E72E	2017-08-11 06:20:00+03	55800.00
18E733	2017-07-18 01:41:00+03	37100.00
18E739	2017-07-30 17:54:00+03	58600.00
18E789	2017-07-28 04:45:00+03	70600.00
18E798	2017-08-14 04:13:00+03	76400.00
18E7CF	2017-07-16 20:08:00+03	92800.00
18E7EE	2017-07-11 17:13:00+03	51300.00
18E844	2017-07-11 02:37:00+03	66800.00
18E850	2017-07-12 08:03:00+03	32300.00
18E88D	2017-07-31 07:17:00+03	28000.00
18E8EF	2017-08-04 02:41:00+03	89200.00
18E971	2017-08-04 04:15:00+03	52700.00
18E9D3	2017-08-12 20:27:00+03	32500.00
18E9DD	2017-06-25 22:50:00+03	60800.00
18EA0F	2017-07-21 23:00:00+03	6700.00
18EA2B	2017-07-13 04:19:00+03	66600.00
18EA33	2017-07-08 07:19:00+03	142400.00
18EA99	2017-07-14 04:33:00+03	32700.00
18EA9B	2017-07-26 00:33:00+03	14000.00
18EAAD	2017-07-20 11:42:00+03	6000.00
18EAB9	2017-07-09 08:14:00+03	28000.00
18EB4F	2017-07-14 01:32:00+03	49700.00
18EB80	2017-08-12 10:57:00+03	128900.00
18EC11	2017-06-30 02:41:00+03	26800.00
18EC3E	2017-07-30 15:30:00+03	62800.00
18EC48	2017-08-12 13:38:00+03	69100.00
18EC6C	2017-07-04 10:18:00+03	131100.00
18ECE1	2017-07-26 10:53:00+03	124200.00
18ECFF	2017-08-06 03:08:00+03	13200.00
18ED63	2017-08-01 22:38:00+03	7400.00
18EDB3	2017-07-13 07:07:00+03	303100.00
18EDDE	2017-08-04 15:50:00+03	64600.00
18EDEF	2017-08-04 06:07:00+03	26000.00
18EDF0	2017-07-25 16:02:00+03	40800.00
18EDF6	2017-07-17 10:45:00+03	43000.00
18EE03	2017-07-20 21:17:00+03	102100.00
18EE11	2017-07-13 19:42:00+03	28000.00
18EE17	2017-08-08 06:20:00+03	36200.00
18EE35	2017-07-18 06:00:00+03	54800.00
18EE3B	2017-08-07 08:49:00+03	99700.00
18EE4D	2017-08-06 08:47:00+03	94700.00
18EE57	2017-07-27 22:22:00+03	55400.00
18EE87	2017-08-03 01:58:00+03	24000.00
18EECF	2017-08-12 01:28:00+03	37000.00
18EEFE	2017-08-13 14:58:00+03	22000.00
18EF22	2017-07-06 03:53:00+03	73600.00
18EF2B	2017-07-13 19:20:00+03	225900.00
18EF90	2017-07-19 18:15:00+03	38400.00
18F001	2017-07-11 11:11:00+03	21400.00
18F046	2017-07-01 04:46:00+03	70700.00
18F09F	2017-07-11 15:04:00+03	36200.00
18F0A4	2017-07-31 19:26:00+03	30900.00
18F0DE	2017-07-29 13:31:00+03	18400.00
18F0EF	2017-07-13 13:15:00+03	19800.00
18F139	2017-07-16 21:58:00+03	29600.00
18F1C8	2017-08-02 05:13:00+03	170500.00
18F20A	2017-08-14 06:32:00+03	61800.00
18F23A	2017-07-01 23:08:00+03	111600.00
18F2C2	2017-07-16 03:11:00+03	84900.00
18F2E2	2017-07-16 19:38:00+03	123000.00
18F395	2017-07-02 09:23:00+03	167400.00
18F3BB	2017-07-27 19:33:00+03	124200.00
18F3C4	2017-07-28 04:00:00+03	159800.00
18F3E4	2017-07-28 10:03:00+03	86800.00
18F3E6	2017-08-03 07:33:00+03	43500.00
18F424	2017-07-15 04:05:00+03	46400.00
18F445	2017-07-21 15:58:00+03	272300.00
18F50A	2017-07-27 14:13:00+03	19600.00
18F530	2017-07-25 14:03:00+03	40800.00
18F544	2017-08-02 18:26:00+03	46000.00
18F563	2017-07-08 04:51:00+03	99300.00
18F625	2017-07-11 18:01:00+03	68800.00
18F66D	2017-07-18 13:49:00+03	28000.00
18F735	2017-07-10 08:30:00+03	273000.00
18F73A	2017-07-15 03:39:00+03	58100.00
18F7D8	2017-07-03 22:21:00+03	51500.00
18F81A	2017-07-06 13:51:00+03	37200.00
18F828	2017-07-24 00:16:00+03	119600.00
18F82C	2017-07-11 01:17:00+03	16400.00
18F8A5	2017-07-21 05:09:00+03	96300.00
18F9E2	2017-07-18 10:28:00+03	65500.00
18FA7A	2017-07-25 01:08:00+03	55800.00
18FAA6	2017-08-02 06:31:00+03	29300.00
18FB46	2017-08-05 00:06:00+03	163600.00
18FB4C	2017-07-14 03:27:00+03	35700.00
18FB62	2017-07-12 09:33:00+03	277800.00
18FBAD	2017-07-10 00:08:00+03	26000.00
18FBB2	2017-08-13 03:15:00+03	116900.00
18FC74	2017-07-29 23:13:00+03	14400.00
18FCBE	2017-08-13 05:55:00+03	123000.00
18FCE1	2017-08-12 04:39:00+03	58900.00
18FCEF	2017-08-01 02:29:00+03	47500.00
18FDE4	2017-07-03 22:21:00+03	25400.00
18FE0B	2017-08-05 08:46:00+03	38800.00
18FE70	2017-07-31 13:05:00+03	151200.00
18FECE	2017-07-06 22:03:00+03	28000.00
18FF59	2017-08-08 00:23:00+03	23400.00
18FF6C	2017-07-22 16:04:00+03	26800.00
18FFBC	2017-07-05 05:11:00+03	23200.00
190017	2017-07-30 02:08:00+03	28000.00
19004E	2017-07-11 11:16:00+03	37900.00
190063	2017-08-07 01:16:00+03	112000.00
190124	2017-07-14 20:36:00+03	14000.00
190126	2017-08-02 17:03:00+03	22800.00
19013C	2017-07-20 13:23:00+03	23500.00
19013D	2017-07-31 01:12:00+03	40200.00
190159	2017-07-30 05:25:00+03	10600.00
19018D	2017-07-31 04:23:00+03	68400.00
1901BA	2017-07-18 10:47:00+03	41600.00
1901F3	2017-07-23 01:45:00+03	226200.00
19023E	2017-08-04 16:23:00+03	272400.00
190260	2017-07-20 07:29:00+03	6300.00
190293	2017-07-21 01:24:00+03	201400.00
1902A0	2017-07-20 02:37:00+03	37200.00
1902AE	2017-07-02 19:18:00+03	56900.00
1902C1	2017-08-12 07:22:00+03	34000.00
1902D4	2017-07-25 13:51:00+03	112000.00
19035E	2017-07-18 17:40:00+03	113200.00
190361	2017-07-05 01:05:00+03	67800.00
190378	2017-07-28 12:18:00+03	265700.00
1903AE	2017-07-15 16:08:00+03	65900.00
1903BA	2017-07-23 22:34:00+03	70700.00
1903D5	2017-07-16 17:30:00+03	38800.00
1903D9	2017-07-18 06:04:00+03	22600.00
1903E2	2017-07-11 14:33:00+03	56000.00
1903F1	2017-08-13 20:22:00+03	16400.00
1904A0	2017-07-02 17:54:00+03	258400.00
1904BF	2017-08-15 05:55:00+03	50800.00
1904C4	2017-08-02 16:11:00+03	66600.00
1904FE	2017-08-09 06:49:00+03	36400.00
190529	2017-07-01 12:18:00+03	34000.00
190544	2017-07-12 16:23:00+03	56900.00
190582	2017-07-23 01:03:00+03	29800.00
1905B5	2017-07-29 10:17:00+03	9800.00
19062F	2017-08-09 17:50:00+03	55800.00
19069D	2017-07-18 18:14:00+03	57800.00
190711	2017-07-17 17:46:00+03	147000.00
19077F	2017-06-28 22:25:00+03	46000.00
1907B6	2017-08-14 02:51:00+03	271200.00
190812	2017-07-13 13:38:00+03	175800.00
190818	2017-07-18 08:31:00+03	20200.00
19083E	2017-08-02 14:15:00+03	39200.00
19087E	2017-07-15 03:22:00+03	57500.00
190884	2017-08-02 02:54:00+03	189200.00
19091A	2017-07-08 09:20:00+03	11600.00
19095D	2017-07-22 07:03:00+03	56000.00
1909F8	2017-08-02 00:46:00+03	42400.00
1909FD	2017-08-06 07:31:00+03	37900.00
190A06	2017-07-26 09:21:00+03	56000.00
190A0F	2017-07-31 12:51:00+03	57600.00
190A5B	2017-07-01 07:46:00+03	67000.00
190A6B	2017-07-18 22:28:00+03	79400.00
190A94	2017-08-13 14:33:00+03	12000.00
190A96	2017-08-11 20:35:00+03	48500.00
190AF1	2017-08-09 14:58:00+03	21800.00
190AFA	2017-07-30 19:53:00+03	31400.00
190B1D	2017-08-12 12:22:00+03	36600.00
190B5D	2017-06-26 13:34:00+03	43100.00
190B9D	2017-07-07 05:41:00+03	73600.00
190BDF	2017-08-13 10:46:00+03	23200.00
190C29	2017-08-07 16:24:00+03	89800.00
190C65	2017-08-05 17:42:00+03	106200.00
190C6B	2017-07-02 23:07:00+03	85000.00
190C98	2017-08-05 14:24:00+03	12400.00
190CB6	2017-07-07 03:48:00+03	128600.00
190D62	2017-07-06 06:10:00+03	48400.00
190D66	2017-08-02 04:54:00+03	12400.00
190DE6	2017-08-06 14:46:00+03	68000.00
190E1C	2017-08-07 09:13:00+03	36200.00
190E2A	2017-07-26 12:08:00+03	21400.00
190E61	2017-07-08 01:05:00+03	20800.00
190E9E	2017-07-04 17:48:00+03	40800.00
190EC7	2017-08-05 11:44:00+03	21700.00
190EE9	2017-08-14 09:08:00+03	77100.00
190F17	2017-07-30 19:32:00+03	300900.00
190F27	2017-07-09 11:55:00+03	199400.00
190F3F	2017-08-07 22:07:00+03	51100.00
190F84	2017-07-11 04:18:00+03	46400.00
190FE9	2017-07-14 06:14:00+03	46000.00
190FF7	2017-07-11 20:52:00+03	23200.00
191083	2017-08-04 12:33:00+03	6000.00
1910A4	2017-07-04 13:57:00+03	146800.00
19115D	2017-08-08 06:50:00+03	51300.00
1911D6	2017-06-29 08:31:00+03	187600.00
19125D	2017-08-10 20:39:00+03	12600.00
191264	2017-07-27 00:20:00+03	6600.00
1912B3	2017-07-18 06:30:00+03	62600.00
1912E8	2017-08-08 08:56:00+03	54800.00
191313	2017-07-09 10:13:00+03	15100.00
191343	2017-07-25 08:48:00+03	41400.00
1913A5	2017-08-02 03:12:00+03	24400.00
1913B9	2017-08-13 17:21:00+03	24400.00
1913CD	2017-08-11 21:53:00+03	64800.00
191472	2017-07-12 08:31:00+03	199700.00
191566	2017-07-21 20:13:00+03	77200.00
191567	2017-07-21 08:35:00+03	34000.00
191575	2017-06-30 09:14:00+03	266300.00
191577	2017-07-14 09:36:00+03	386400.00
1915D1	2017-07-03 06:48:00+03	57800.00
1915E8	2017-07-09 10:32:00+03	16400.00
191637	2017-07-06 17:44:00+03	23600.00
19163E	2017-07-21 06:48:00+03	123000.00
191663	2017-08-10 07:11:00+03	54400.00
1916C6	2017-07-04 13:22:00+03	62000.00
1916E8	2017-07-24 08:06:00+03	212300.00
1916ED	2017-07-28 09:36:00+03	246000.00
19177E	2017-07-06 06:36:00+03	57400.00
19178C	2017-06-25 21:55:00+03	160200.00
191797	2017-07-09 13:02:00+03	304800.00
1917A8	2017-07-28 11:36:00+03	6900.00
1917F1	2017-08-03 07:53:00+03	37900.00
191828	2017-08-01 16:29:00+03	46200.00
19184E	2017-07-30 12:00:00+03	20000.00
191867	2017-07-14 01:05:00+03	116900.00
191878	2017-07-25 20:25:00+03	36800.00
1918D1	2017-07-13 06:51:00+03	26700.00
1918DF	2017-07-01 23:13:00+03	57300.00
19191E	2017-07-02 01:01:00+03	145300.00
191926	2017-07-29 16:15:00+03	44500.00
191941	2017-08-09 12:24:00+03	20200.00
1919B0	2017-07-22 05:52:00+03	26700.00
1919BB	2017-08-12 15:43:00+03	28800.00
1919E9	2017-08-02 15:51:00+03	28800.00
191A0D	2017-08-13 15:25:00+03	53800.00
191A92	2017-08-12 11:45:00+03	75300.00
191B0D	2017-08-14 13:02:00+03	306600.00
191B2A	2017-07-18 07:08:00+03	51300.00
191B30	2017-07-21 16:04:00+03	87400.00
191B44	2017-07-28 11:40:00+03	339300.00
191B98	2017-07-08 05:50:00+03	102100.00
191BCC	2017-07-13 16:36:00+03	88100.00
191C00	2017-07-04 23:25:00+03	25000.00
191C1E	2017-07-18 02:42:00+03	159100.00
191CA4	2017-07-27 14:30:00+03	26000.00
191CAA	2017-07-31 21:21:00+03	86800.00
191CD0	2017-07-23 05:10:00+03	39200.00
191D58	2017-07-08 00:23:00+03	28000.00
191D6C	2017-07-31 06:18:00+03	188300.00
191D79	2017-07-18 04:44:00+03	132800.00
191DA4	2017-08-13 07:28:00+03	406700.00
191DB8	2017-08-11 08:52:00+03	26000.00
191DBA	2017-08-10 07:14:00+03	14000.00
191DC4	2017-07-16 22:22:00+03	58900.00
191DEE	2017-07-29 06:33:00+03	16400.00
191E2F	2017-07-15 15:45:00+03	60200.00
191E4B	2017-07-21 21:40:00+03	29600.00
191E95	2017-07-27 00:19:00+03	26500.00
191EDB	2017-07-25 23:41:00+03	44000.00
191EEC	2017-07-20 13:54:00+03	61700.00
191F36	2017-07-08 08:28:00+03	98000.00
191F54	2017-07-14 22:11:00+03	383300.00
191FCC	2017-07-25 11:44:00+03	70700.00
192007	2017-07-21 12:13:00+03	26800.00
19201A	2017-08-08 04:04:00+03	393800.00
192049	2017-07-30 05:56:00+03	42800.00
192086	2017-08-09 23:08:00+03	55800.00
1920BA	2017-07-06 05:38:00+03	99900.00
1920BC	2017-07-28 15:37:00+03	12400.00
19214E	2017-08-09 22:22:00+03	89700.00
19215B	2017-08-01 11:32:00+03	37200.00
1921A7	2017-07-22 20:07:00+03	68800.00
1921B7	2017-08-15 01:42:00+03	40700.00
192226	2017-07-18 05:07:00+03	26200.00
19222B	2017-07-12 02:43:00+03	54900.00
19222E	2017-07-02 02:01:00+03	28000.00
192351	2017-07-07 07:33:00+03	28000.00
19237E	2017-07-08 16:52:00+03	36000.00
1923CC	2017-07-27 22:08:00+03	56000.00
1923E7	2017-07-23 00:55:00+03	55800.00
1924EF	2017-07-25 21:30:00+03	14000.00
19254D	2017-07-28 17:23:00+03	79200.00
19256B	2017-07-12 18:32:00+03	45200.00
1925B7	2017-07-16 05:02:00+03	27300.00
1925C6	2017-08-10 02:11:00+03	19600.00
192649	2017-07-13 15:43:00+03	48800.00
192657	2017-06-29 12:08:00+03	27700.00
192669	2017-08-09 23:58:00+03	26000.00
1926C4	2017-08-11 02:50:00+03	37000.00
192728	2017-07-17 17:06:00+03	46200.00
1927B7	2017-07-03 01:41:00+03	14400.00
1927D4	2017-08-07 01:57:00+03	135400.00
192870	2017-07-27 22:48:00+03	70200.00
1928CA	2017-07-21 04:23:00+03	61700.00
1928D0	2017-08-03 09:49:00+03	95600.00
192933	2017-07-14 04:35:00+03	70800.00
1929AD	2017-07-19 00:38:00+03	44600.00
192A12	2017-07-20 05:40:00+03	46000.00
192A43	2017-07-20 07:33:00+03	35600.00
192A60	2017-07-08 01:05:00+03	516800.00
192A6A	2017-08-03 16:42:00+03	67800.00
192AC8	2017-07-20 21:28:00+03	16400.00
192AEC	2017-08-15 15:46:00+03	179300.00
192BDA	2017-07-09 00:57:00+03	10700.00
192C4F	2017-07-21 16:47:00+03	67600.00
192C5E	2017-07-06 13:17:00+03	421700.00
192D7E	2017-07-30 13:30:00+03	369000.00
192D8D	2017-07-19 20:39:00+03	131100.00
192D92	2017-08-10 20:11:00+03	112000.00
192D9A	2017-07-08 19:12:00+03	14000.00
192DCE	2017-07-09 03:39:00+03	46000.00
192DE9	2017-08-14 05:19:00+03	16400.00
192E4C	2017-07-16 13:30:00+03	73500.00
192E56	2017-07-17 00:41:00+03	62100.00
192E5F	2017-07-08 03:16:00+03	152500.00
192E75	2017-07-25 13:56:00+03	204500.00
192E77	2017-06-30 08:59:00+03	31400.00
192E78	2017-07-09 14:25:00+03	43100.00
192EE9	2017-07-31 22:57:00+03	48800.00
192F5B	2017-08-14 17:30:00+03	201700.00
192F86	2017-08-13 08:24:00+03	32700.00
192FAE	2017-07-20 11:14:00+03	46300.00
192FCE	2017-07-19 12:18:00+03	26800.00
193031	2017-07-16 02:18:00+03	639600.00
1930E7	2017-07-17 18:09:00+03	47100.00
19310D	2017-07-13 19:29:00+03	75300.00
193184	2017-07-16 00:23:00+03	92100.00
1931B9	2017-08-06 21:53:00+03	37800.00
1931DB	2017-08-11 12:12:00+03	168000.00
1931E6	2017-07-30 14:58:00+03	77500.00
19326E	2017-07-09 23:20:00+03	76800.00
1932FB	2017-07-13 22:07:00+03	86500.00
193309	2017-07-02 09:32:00+03	26000.00
1933AA	2017-07-13 00:09:00+03	81900.00
1933C4	2017-07-22 07:31:00+03	47100.00
1933CA	2017-07-17 04:39:00+03	7200.00
1933FB	2017-07-14 18:29:00+03	67600.00
19347C	2017-07-11 18:31:00+03	78300.00
193566	2017-08-13 22:22:00+03	134900.00
19356B	2017-06-29 18:17:00+03	123000.00
193570	2017-07-20 15:54:00+03	166900.00
19359E	2017-07-08 02:25:00+03	93500.00
1935C1	2017-07-12 05:39:00+03	61200.00
19365F	2017-07-21 05:43:00+03	31000.00
19367D	2017-08-15 02:27:00+03	133100.00
193693	2017-06-29 23:49:00+03	6000.00
193700	2017-08-05 19:57:00+03	30200.00
193744	2017-08-12 21:06:00+03	76600.00
19375C	2017-07-01 06:07:00+03	37200.00
193774	2017-07-25 19:52:00+03	23200.00
1937B9	2017-08-13 18:49:00+03	94000.00
1937CC	2017-08-01 16:11:00+03	23600.00
1937E8	2017-07-17 10:17:00+03	29600.00
1937EB	2017-07-14 08:18:00+03	52700.00
19383A	2017-08-02 15:37:00+03	7400.00
1938B0	2017-08-12 12:06:00+03	103300.00
1938EB	2017-07-19 12:38:00+03	33300.00
193982	2017-07-14 21:34:00+03	66900.00
193993	2017-07-06 13:13:00+03	56000.00
193999	2017-07-03 16:56:00+03	147700.00
1939A1	2017-07-12 20:48:00+03	32800.00
1939B6	2017-08-02 20:52:00+03	6800.00
193A12	2017-07-28 06:41:00+03	320500.00
193A49	2017-07-14 13:38:00+03	55800.00
193A52	2017-07-20 06:34:00+03	53200.00
193AC5	2017-08-04 22:06:00+03	12600.00
193B2E	2017-07-26 00:01:00+03	135400.00
193B4A	2017-08-12 03:54:00+03	21500.00
193C33	2017-07-26 16:12:00+03	45000.00
193C69	2017-07-29 16:29:00+03	26200.00
193D07	2017-07-28 07:42:00+03	70500.00
193D21	2017-08-11 19:42:00+03	140400.00
193D4B	2017-07-12 23:47:00+03	94000.00
193D54	2017-08-08 18:35:00+03	34000.00
193D60	2017-07-06 07:47:00+03	78600.00
193D75	2017-06-30 01:53:00+03	43600.00
193DAA	2017-07-11 03:12:00+03	26000.00
193E1F	2017-07-10 15:23:00+03	149200.00
193E37	2017-07-03 09:25:00+03	19600.00
193EBB	2017-08-03 19:24:00+03	28800.00
193EC9	2017-08-01 23:10:00+03	162400.00
193F00	2017-08-05 08:12:00+03	57500.00
193F4D	2017-07-31 21:46:00+03	116000.00
194016	2017-07-27 13:56:00+03	48800.00
1941A2	2017-07-04 09:29:00+03	30800.00
1941AD	2017-07-14 20:19:00+03	37200.00
1941C2	2017-07-15 04:54:00+03	6700.00
1941F5	2017-07-18 13:31:00+03	26000.00
1942A6	2017-07-05 08:16:00+03	70600.00
194305	2017-08-10 12:41:00+03	93100.00
194439	2017-07-07 03:26:00+03	38800.00
194471	2017-08-06 20:59:00+03	58200.00
19448A	2017-07-03 05:01:00+03	44000.00
19448F	2017-07-27 02:30:00+03	18000.00
1944A0	2017-08-11 06:23:00+03	25800.00
1944E7	2017-07-29 03:45:00+03	10100.00
1944FA	2017-08-10 23:47:00+03	492000.00
194501	2017-08-10 13:57:00+03	73500.00
19453C	2017-08-01 05:51:00+03	132800.00
194562	2017-08-13 12:27:00+03	56600.00
1945A4	2017-08-11 15:28:00+03	240600.00
1945B3	2017-07-09 10:12:00+03	101900.00
194614	2017-07-04 04:46:00+03	29400.00
19461F	2017-07-15 06:40:00+03	52400.00
19462F	2017-07-28 09:44:00+03	95000.00
194675	2017-08-14 18:50:00+03	64900.00
194729	2017-07-30 23:14:00+03	7400.00
194744	2017-08-02 09:06:00+03	93700.00
19474D	2017-07-27 19:23:00+03	6000.00
194768	2017-07-21 00:00:00+03	123000.00
19476E	2017-08-05 12:19:00+03	40200.00
194789	2017-06-28 01:53:00+03	59000.00
1947B4	2017-07-08 15:00:00+03	13400.00
1947C9	2017-07-25 03:28:00+03	75100.00
1947E4	2017-06-30 08:50:00+03	85000.00
194811	2017-07-11 08:34:00+03	50200.00
194820	2017-07-19 07:37:00+03	46200.00
194835	2017-07-03 02:10:00+03	73300.00
19483D	2017-07-08 20:02:00+03	15000.00
19487F	2017-07-13 19:13:00+03	26700.00
19489A	2017-08-12 11:20:00+03	92800.00
19490F	2017-08-03 21:47:00+03	162700.00
19492D	2017-08-15 05:47:00+03	202600.00
19493B	2017-08-15 13:49:00+03	45200.00
194950	2017-07-31 02:54:00+03	52000.00
1949EE	2017-08-03 07:24:00+03	36200.00
1949FD	2017-07-09 14:16:00+03	132800.00
194A09	2017-07-12 22:00:00+03	39300.00
194A0B	2017-07-06 18:01:00+03	36200.00
194A14	2017-07-31 05:29:00+03	47400.00
194A2A	2017-08-07 01:59:00+03	44800.00
194A67	2017-07-08 18:34:00+03	39400.00
194A78	2017-07-23 21:01:00+03	136800.00
194A87	2017-08-07 05:59:00+03	170200.00
194B06	2017-07-16 21:09:00+03	189200.00
194DA3	2017-07-17 18:43:00+03	23200.00
194DB2	2017-08-09 22:11:00+03	48800.00
194DCA	2017-07-14 13:56:00+03	208100.00
194E01	2017-07-04 03:35:00+03	134600.00
194E2E	2017-08-01 18:54:00+03	128800.00
194E2F	2017-07-19 15:29:00+03	57400.00
194E48	2017-07-15 15:13:00+03	12600.00
194EB7	2017-08-11 05:05:00+03	41000.00
194ED3	2017-08-11 20:06:00+03	66600.00
194F34	2017-08-15 13:54:00+03	48800.00
194F8F	2017-08-11 04:56:00+03	36100.00
194FC0	2017-07-23 05:52:00+03	44600.00
195013	2017-08-03 08:51:00+03	23200.00
19504A	2017-08-12 18:54:00+03	30200.00
19519C	2017-07-21 20:38:00+03	63200.00
1951AA	2017-07-23 07:54:00+03	26000.00
1951F3	2017-07-17 04:38:00+03	111600.00
195218	2017-07-03 19:41:00+03	72400.00
19522D	2017-08-11 05:27:00+03	179400.00
195291	2017-07-29 22:34:00+03	123000.00
1952C8	2017-07-08 18:33:00+03	29100.00
1952EB	2017-07-12 10:28:00+03	86800.00
195322	2017-08-02 15:11:00+03	54100.00
195354	2017-08-10 12:34:00+03	23200.00
19535B	2017-07-25 13:48:00+03	58200.00
19538A	2017-07-25 11:49:00+03	31200.00
1953BF	2017-07-10 16:42:00+03	140100.00
195400	2017-08-13 12:23:00+03	31400.00
1954B7	2017-07-28 18:24:00+03	44000.00
1954E8	2017-07-27 01:41:00+03	56600.00
19556E	2017-07-22 13:07:00+03	41600.00
195587	2017-07-16 13:19:00+03	133200.00
195660	2017-07-01 20:09:00+03	103000.00
195791	2017-07-30 19:44:00+03	13600.00
1957B1	2017-07-28 14:50:00+03	23200.00
1957E7	2017-08-10 19:09:00+03	311200.00
195816	2017-07-31 01:48:00+03	28000.00
19587A	2017-07-11 11:17:00+03	25200.00
195911	2017-08-05 00:19:00+03	117400.00
19595D	2017-07-04 01:21:00+03	56000.00
195997	2017-08-02 09:10:00+03	58800.00
1959A7	2017-07-20 23:13:00+03	28800.00
1959AF	2017-08-06 18:04:00+03	65600.00
1959D4	2017-08-12 04:25:00+03	28800.00
1959E3	2017-07-16 19:44:00+03	23600.00
195A17	2017-08-05 19:29:00+03	58400.00
195A1C	2017-07-13 21:47:00+03	96800.00
195A79	2017-08-14 06:14:00+03	42600.00
195AF6	2017-07-14 14:19:00+03	46300.00
195B35	2017-07-01 04:37:00+03	113200.00
195B44	2017-08-07 06:17:00+03	55800.00
195B48	2017-07-13 14:33:00+03	114800.00
195B6F	2017-08-07 23:22:00+03	23200.00
195CA5	2017-08-11 08:40:00+03	58000.00
195CA8	2017-07-28 13:17:00+03	311200.00
195CD6	2017-07-18 05:57:00+03	75300.00
195CF5	2017-08-01 15:31:00+03	113800.00
195D13	2017-07-24 03:41:00+03	65100.00
195D36	2017-07-25 21:58:00+03	89000.00
195DF3	2017-07-06 12:07:00+03	44800.00
195E77	2017-07-28 19:24:00+03	63700.00
195EB5	2017-08-10 08:48:00+03	15400.00
195EB6	2017-08-09 15:11:00+03	28800.00
195F6D	2017-07-15 19:03:00+03	32700.00
195F76	2017-08-10 00:28:00+03	18500.00
195FA0	2017-06-28 23:59:00+03	55900.00
195FAE	2017-07-16 13:13:00+03	90400.00
195FC4	2017-07-07 10:48:00+03	48800.00
19604A	2017-07-13 16:41:00+03	189200.00
196088	2017-08-12 07:26:00+03	46400.00
196093	2017-07-27 21:05:00+03	14000.00
1960BE	2017-07-10 15:03:00+03	112000.00
19612E	2017-07-25 06:46:00+03	62100.00
196158	2017-07-04 08:37:00+03	60400.00
19616F	2017-07-13 22:34:00+03	45200.00
196187	2017-07-10 11:41:00+03	62000.00
1961F1	2017-07-15 10:56:00+03	18800.00
196237	2017-07-19 05:32:00+03	52100.00
196270	2017-06-30 15:33:00+03	36200.00
196312	2017-07-17 16:26:00+03	77900.00
196314	2017-08-10 23:23:00+03	140900.00
196340	2017-07-21 17:13:00+03	81700.00
196474	2017-07-23 22:50:00+03	137600.00
196480	2017-08-11 15:22:00+03	75600.00
1964C6	2017-08-10 03:01:00+03	34400.00
1964D3	2017-07-18 20:16:00+03	16000.00
19654B	2017-07-20 12:43:00+03	31100.00
196561	2017-08-06 02:50:00+03	11600.00
1965B4	2017-07-17 19:52:00+03	16400.00
196677	2017-07-27 19:57:00+03	51900.00
1966C5	2017-07-30 21:32:00+03	18800.00
1966FD	2017-07-17 08:50:00+03	53300.00
196722	2017-08-11 19:29:00+03	40100.00
196744	2017-08-02 20:05:00+03	75600.00
196751	2017-07-20 12:05:00+03	51600.00
1967D3	2017-07-12 11:07:00+03	40800.00
1967D6	2017-08-05 19:33:00+03	185600.00
1967D8	2017-08-11 03:05:00+03	12400.00
1967EB	2017-07-25 17:56:00+03	94400.00
19682C	2017-07-05 21:29:00+03	38800.00
19687F	2017-07-11 02:59:00+03	42600.00
19688A	2017-08-01 21:43:00+03	127900.00
1968DF	2017-08-06 12:31:00+03	46800.00
196932	2017-07-13 03:02:00+03	56100.00
196956	2017-07-16 23:09:00+03	24400.00
1969C9	2017-08-02 05:29:00+03	70700.00
196A11	2017-07-18 11:30:00+03	32800.00
196A18	2017-08-14 01:37:00+03	52400.00
196A1D	2017-07-22 20:49:00+03	46400.00
196A60	2017-07-24 18:17:00+03	16800.00
196A63	2017-08-14 19:35:00+03	115400.00
196A6A	2017-07-15 08:40:00+03	128400.00
196A8E	2017-07-28 11:23:00+03	64300.00
196AAB	2017-07-12 05:01:00+03	107400.00
196AC3	2017-08-01 17:34:00+03	135200.00
196AE1	2017-08-06 15:48:00+03	50900.00
196B13	2017-07-18 22:47:00+03	27200.00
196B36	2017-07-27 22:33:00+03	109700.00
196B41	2017-07-31 16:09:00+03	23400.00
196B54	2017-07-14 22:30:00+03	26800.00
196B8A	2017-08-14 16:37:00+03	81000.00
196BE5	2017-07-28 17:20:00+03	57500.00
196BFD	2017-08-12 16:35:00+03	96800.00
196C12	2017-07-22 16:29:00+03	15900.00
196C2E	2017-08-12 05:00:00+03	52000.00
196D30	2017-07-06 15:50:00+03	69000.00
196E8F	2017-07-15 22:18:00+03	99200.00
196EA5	2017-08-13 16:03:00+03	64700.00
196EF1	2017-07-19 19:35:00+03	167400.00
196F66	2017-07-16 16:34:00+03	72300.00
196F8E	2017-08-03 01:50:00+03	144300.00
196F91	2017-08-09 16:27:00+03	136500.00
197037	2017-07-25 06:22:00+03	69100.00
197056	2017-08-04 20:53:00+03	155300.00
197086	2017-08-03 13:05:00+03	174600.00
19709B	2017-07-28 07:31:00+03	35600.00
1970A9	2017-08-12 03:14:00+03	135400.00
1970D2	2017-07-03 07:15:00+03	46400.00
1970ED	2017-07-26 12:03:00+03	97000.00
19714B	2017-07-12 08:35:00+03	54500.00
197154	2017-07-13 17:17:00+03	54400.00
197163	2017-07-29 12:51:00+03	103900.00
19719E	2017-07-26 03:55:00+03	118700.00
1971EE	2017-07-12 05:02:00+03	75600.00
197237	2017-07-02 09:35:00+03	312900.00
197249	2017-08-04 13:25:00+03	155100.00
19725A	2017-07-19 03:40:00+03	24400.00
197268	2017-07-28 19:59:00+03	64700.00
197290	2017-07-13 14:35:00+03	128800.00
197293	2017-07-01 02:33:00+03	177600.00
197298	2017-07-26 08:23:00+03	48700.00
1972FE	2017-06-30 14:09:00+03	56000.00
1973DE	2017-07-11 02:59:00+03	101200.00
197438	2017-08-03 04:33:00+03	29600.00
19746E	2017-07-06 23:48:00+03	140800.00
1974D2	2017-07-27 05:58:00+03	32800.00
1974D8	2017-07-15 06:18:00+03	15000.00
1974E6	2017-07-02 13:38:00+03	69500.00
19754E	2017-08-07 14:09:00+03	133200.00
197589	2017-07-06 21:56:00+03	88500.00
1975F6	2017-07-08 05:52:00+03	65500.00
197609	2017-07-20 08:55:00+03	179400.00
19763C	2017-08-15 12:13:00+03	14400.00
19769D	2017-07-28 13:59:00+03	36900.00
1976FC	2017-07-14 03:04:00+03	70200.00
197842	2017-06-29 23:58:00+03	28700.00
19787D	2017-07-01 16:18:00+03	29200.00
1978AE	2017-07-13 09:14:00+03	39300.00
1978B7	2017-07-13 23:17:00+03	79500.00
1978C2	2017-08-15 12:27:00+03	43800.00
197900	2017-08-05 12:33:00+03	41300.00
197921	2017-08-04 10:08:00+03	418400.00
19794C	2017-07-13 05:57:00+03	27400.00
19794D	2017-08-03 03:46:00+03	39200.00
19796E	2017-08-03 18:51:00+03	151200.00
1979BE	2017-07-09 07:55:00+03	520600.00
197A38	2017-07-21 09:12:00+03	50800.00
197A4B	2017-08-12 10:48:00+03	34000.00
197A5D	2017-08-13 14:29:00+03	167500.00
197A67	2017-07-23 06:20:00+03	157200.00
197A6D	2017-08-09 04:41:00+03	138600.00
197AE7	2017-07-25 12:13:00+03	252200.00
197B2A	2017-07-20 14:21:00+03	19600.00
197C5E	2017-07-10 14:59:00+03	124200.00
197C7E	2017-07-30 09:15:00+03	28000.00
197C83	2017-08-05 03:18:00+03	203400.00
197D04	2017-07-28 00:56:00+03	38400.00
197D2A	2017-07-22 23:02:00+03	66600.00
197D93	2017-07-29 20:32:00+03	43600.00
197E23	2017-07-06 10:18:00+03	138000.00
197E34	2017-08-10 22:50:00+03	26000.00
197EA1	2017-07-27 02:10:00+03	12600.00
197ECD	2017-07-22 19:04:00+03	26700.00
197F11	2017-07-30 14:11:00+03	168000.00
197F28	2017-07-10 12:55:00+03	22000.00
197F68	2017-07-13 02:24:00+03	26000.00
197F6F	2017-08-03 06:29:00+03	34000.00
197F8A	2017-07-03 02:23:00+03	15000.00
197FFC	2017-07-06 02:22:00+03	20500.00
198011	2017-08-10 07:12:00+03	8400.00
198075	2017-08-01 19:44:00+03	141600.00
1980E6	2017-07-28 08:28:00+03	42700.00
19810C	2017-08-05 19:10:00+03	194100.00
198183	2017-07-30 10:03:00+03	84500.00
19835F	2017-07-30 20:47:00+03	11600.00
1983C9	2017-08-14 17:09:00+03	62600.00
198498	2017-07-22 02:15:00+03	98400.00
1984F6	2017-08-09 04:39:00+03	37900.00
198507	2017-08-12 23:38:00+03	73600.00
198537	2017-07-11 22:28:00+03	46400.00
19853B	2017-08-02 19:34:00+03	36900.00
19853C	2017-07-10 18:43:00+03	58800.00
19854A	2017-08-04 12:21:00+03	28700.00
1985C2	2017-07-04 19:31:00+03	29600.00
19863D	2017-08-02 14:05:00+03	24200.00
198699	2017-06-29 04:56:00+03	76600.00
1986A2	2017-08-13 02:37:00+03	110300.00
1986F8	2017-08-01 21:06:00+03	28000.00
198755	2017-07-09 18:03:00+03	55800.00
1987BF	2017-08-03 22:39:00+03	90800.00
19881A	2017-07-27 18:10:00+03	26700.00
198826	2017-07-05 17:48:00+03	63400.00
1988D2	2017-07-31 02:12:00+03	13700.00
198946	2017-06-30 08:28:00+03	24400.00
19898A	2017-08-15 15:17:00+03	24000.00
1989B4	2017-07-18 20:56:00+03	148300.00
1989D2	2017-07-11 14:58:00+03	106000.00
198A29	2017-07-21 02:18:00+03	75600.00
198A74	2017-07-28 11:29:00+03	383300.00
198AB1	2017-07-30 12:40:00+03	196400.00
198B1A	2017-07-25 08:40:00+03	120900.00
198B1F	2017-07-10 04:01:00+03	62800.00
198B33	2017-08-13 09:58:00+03	49100.00
198B64	2017-08-05 08:15:00+03	50800.00
198B80	2017-07-24 16:22:00+03	22000.00
198BB7	2017-07-14 15:25:00+03	56000.00
198CB3	2017-07-29 03:13:00+03	270700.00
198CC8	2017-07-22 05:51:00+03	185600.00
198CF1	2017-07-18 21:38:00+03	36800.00
198DDD	2017-08-05 09:58:00+03	28000.00
198E1D	2017-07-17 06:00:00+03	42800.00
198E3B	2017-07-22 03:38:00+03	22000.00
198EA2	2017-07-25 14:40:00+03	24800.00
198EA9	2017-07-27 19:17:00+03	154800.00
198EBA	2017-08-10 18:53:00+03	52900.00
198EF1	2017-07-10 01:12:00+03	125200.00
198EFC	2017-07-17 01:20:00+03	66800.00
198F1B	2017-07-11 08:03:00+03	49200.00
198F60	2017-07-22 14:07:00+03	31600.00
198F62	2017-08-09 15:47:00+03	67200.00
198F78	2017-07-31 18:56:00+03	198400.00
198FEC	2017-08-15 00:01:00+03	26700.00
19903B	2017-08-07 03:15:00+03	81700.00
199048	2017-07-05 05:47:00+03	45100.00
1990FC	2017-08-08 02:37:00+03	71900.00
1990FE	2017-07-16 18:40:00+03	23600.00
199175	2017-08-14 10:35:00+03	24400.00
199184	2017-07-01 15:35:00+03	29000.00
1991D0	2017-07-25 16:35:00+03	31100.00
1991DA	2017-08-14 00:55:00+03	56000.00
19921E	2017-08-12 21:33:00+03	74800.00
199262	2017-08-11 12:17:00+03	46400.00
199301	2017-07-07 11:26:00+03	492500.00
19933D	2017-07-23 16:21:00+03	163200.00
199357	2017-08-02 17:44:00+03	87900.00
199371	2017-07-29 12:22:00+03	46800.00
19939A	2017-07-11 09:17:00+03	14700.00
19939F	2017-07-22 10:37:00+03	75300.00
1993EE	2017-07-29 04:49:00+03	31400.00
1993F8	2017-08-10 08:37:00+03	23200.00
199408	2017-08-04 04:03:00+03	27900.00
199420	2017-08-01 12:10:00+03	58000.00
19944C	2017-07-30 20:27:00+03	57500.00
199466	2017-07-07 13:53:00+03	133200.00
1994E3	2017-07-30 04:49:00+03	30000.00
199533	2017-07-16 11:21:00+03	103900.00
19956F	2017-07-29 16:22:00+03	56000.00
199573	2017-08-15 16:38:00+03	42600.00
1995D0	2017-08-11 13:13:00+03	28600.00
1995F7	2017-08-08 10:41:00+03	75300.00
1996E8	2017-07-31 03:02:00+03	106300.00
19972B	2017-07-20 10:25:00+03	21600.00
199732	2017-07-30 12:43:00+03	73500.00
1997B2	2017-07-04 06:12:00+03	246000.00
1997D6	2017-08-08 23:01:00+03	21400.00
199808	2017-07-13 14:18:00+03	65800.00
199824	2017-08-14 15:36:00+03	14000.00
19988B	2017-07-19 00:03:00+03	35400.00
19989E	2017-07-13 17:19:00+03	290600.00
1998A4	2017-07-24 14:09:00+03	46200.00
1998A5	2017-07-02 23:22:00+03	20200.00
1998C7	2017-07-05 01:50:00+03	89200.00
19991B	2017-07-16 17:16:00+03	60300.00
199948	2017-08-15 00:18:00+03	84500.00
199952	2017-07-07 03:33:00+03	46400.00
199963	2017-07-19 23:21:00+03	43000.00
19996F	2017-07-27 12:29:00+03	8200.00
1999EE	2017-07-25 04:28:00+03	51400.00
199AE6	2017-08-04 18:55:00+03	73600.00
199AFC	2017-08-04 15:24:00+03	70600.00
199BAF	2017-07-05 17:55:00+03	123600.00
199BEB	2017-07-06 21:16:00+03	136000.00
199C77	2017-07-17 13:20:00+03	20400.00
199DA2	2017-08-11 11:38:00+03	66600.00
199E06	2017-07-06 17:17:00+03	28000.00
199E29	2017-08-10 06:08:00+03	168700.00
199E64	2017-08-07 18:00:00+03	12600.00
199E7D	2017-07-19 16:42:00+03	24400.00
199E99	2017-07-08 17:03:00+03	12600.00
199FA0	2017-08-05 16:03:00+03	26800.00
19A03B	2017-06-30 21:36:00+03	406100.00
19A0C2	2017-07-12 07:43:00+03	50200.00
19A12C	2017-07-30 18:20:00+03	56000.00
19A15B	2017-07-22 13:55:00+03	236700.00
19A1C8	2017-07-24 12:04:00+03	84000.00
19A216	2017-07-30 08:42:00+03	47100.00
19A2FF	2017-07-01 05:50:00+03	46000.00
19A43D	2017-07-20 02:18:00+03	120000.00
19A447	2017-08-13 01:59:00+03	58900.00
19A49E	2017-07-10 06:31:00+03	100000.00
19A4F9	2017-08-05 17:20:00+03	179700.00
19A4FD	2017-07-18 19:31:00+03	64800.00
19A51C	2017-07-20 21:26:00+03	396400.00
19A561	2017-07-16 22:46:00+03	55800.00
19A595	2017-07-26 15:27:00+03	54300.00
19A669	2017-07-12 05:33:00+03	32200.00
19A6F5	2017-07-15 15:48:00+03	19600.00
19A741	2017-07-01 22:05:00+03	159000.00
19A77B	2017-07-10 16:05:00+03	70800.00
19A7E3	2017-07-15 18:58:00+03	46200.00
19A86D	2017-08-12 22:54:00+03	195800.00
19A88F	2017-07-26 08:40:00+03	70700.00
19A8DE	2017-08-09 09:00:00+03	36900.00
19A9A7	2017-07-11 01:36:00+03	6000.00
19A9C6	2017-06-30 20:30:00+03	46500.00
19AA23	2017-08-06 10:37:00+03	25400.00
19AAB1	2017-08-08 13:20:00+03	68400.00
19AACC	2017-07-26 17:32:00+03	115100.00
19AAD1	2017-07-21 08:14:00+03	34000.00
19AAD9	2017-06-25 06:49:00+03	46400.00
19AB0A	2017-08-05 02:49:00+03	23600.00
19AB9A	2017-08-11 18:54:00+03	189200.00
19ABFD	2017-07-06 13:16:00+03	89600.00
19AC2E	2017-08-13 08:04:00+03	47200.00
19AC36	2017-08-05 12:48:00+03	100000.00
19AC40	2017-07-11 16:54:00+03	23200.00
19ACA1	2017-07-14 17:53:00+03	81600.00
19ACE9	2017-08-13 03:41:00+03	13600.00
19AD06	2017-07-06 02:44:00+03	24800.00
19AD79	2017-08-08 06:50:00+03	48900.00
19AE09	2017-07-16 16:28:00+03	118500.00
19AE47	2017-08-07 00:56:00+03	86800.00
19AE9C	2017-08-14 16:14:00+03	15100.00
19AF06	2017-08-06 07:11:00+03	26000.00
19AF48	2017-07-15 13:37:00+03	24600.00
19AF4C	2017-07-29 18:06:00+03	55600.00
19AF6B	2017-08-03 01:28:00+03	40000.00
19AF99	2017-07-31 09:39:00+03	28800.00
19AFAC	2017-08-10 00:06:00+03	205200.00
19AFEF	2017-07-27 01:29:00+03	136200.00
19B03A	2017-07-16 02:41:00+03	114300.00
19B053	2017-07-26 02:00:00+03	136200.00
19B065	2017-07-27 07:13:00+03	21400.00
19B068	2017-07-16 15:53:00+03	48300.00
19B077	2017-07-11 09:26:00+03	46400.00
19B14F	2017-07-10 21:23:00+03	20200.00
19B1C4	2017-08-15 04:25:00+03	19800.00
19B1DB	2017-07-05 20:41:00+03	46000.00
19B1F0	2017-08-03 22:39:00+03	26000.00
19B2A6	2017-07-27 13:50:00+03	106700.00
19B2CB	2017-08-13 12:07:00+03	54100.00
19B384	2017-07-20 01:31:00+03	96200.00
19B455	2017-08-01 16:51:00+03	123000.00
19B46D	2017-08-14 10:13:00+03	123000.00
19B493	2017-08-15 03:52:00+03	62600.00
19B4D2	2017-07-27 19:55:00+03	53200.00
19B57C	2017-07-25 00:00:00+03	84500.00
19B592	2017-08-03 07:59:00+03	56900.00
19B5B9	2017-07-22 20:58:00+03	154000.00
19B607	2017-07-19 01:04:00+03	120600.00
19B610	2017-07-18 01:42:00+03	32700.00
19B66A	2017-07-30 21:48:00+03	168000.00
19B6C3	2017-08-10 12:17:00+03	109600.00
19B6E3	2017-08-12 23:03:00+03	40600.00
19B732	2017-07-30 22:13:00+03	43200.00
19B775	2017-07-12 18:13:00+03	17800.00
19B7AE	2017-07-27 21:39:00+03	30600.00
19B7D7	2017-07-23 11:43:00+03	149300.00
19B7E6	2017-08-08 00:33:00+03	267400.00
19B81D	2017-08-10 02:05:00+03	81600.00
19B88B	2017-07-23 03:34:00+03	46400.00
19B895	2017-07-09 06:53:00+03	59300.00
19B89E	2017-07-09 23:10:00+03	112000.00
19B8B0	2017-08-11 10:34:00+03	39800.00
19B8BA	2017-07-21 14:56:00+03	60400.00
19B9DD	2017-07-05 22:36:00+03	55000.00
19B9DE	2017-07-27 03:50:00+03	136800.00
19BA1F	2017-07-02 00:33:00+03	32800.00
19BA35	2017-07-27 10:19:00+03	22000.00
19BA4A	2017-08-05 15:48:00+03	51300.00
19BA66	2017-07-15 21:53:00+03	46000.00
19BA6B	2017-08-07 16:22:00+03	46400.00
19BA86	2017-07-13 10:40:00+03	136200.00
19BB40	2017-07-18 01:59:00+03	173600.00
19BB67	2017-07-31 07:36:00+03	83300.00
19BB91	2017-08-11 12:19:00+03	156400.00
19BBE7	2017-07-04 11:43:00+03	23200.00
19BBFD	2017-08-01 16:16:00+03	24400.00
19BC8D	2017-08-04 05:11:00+03	193800.00
19BCB4	2017-08-14 17:30:00+03	246000.00
19BCCA	2017-08-12 20:58:00+03	67600.00
19BCFA	2017-07-18 01:58:00+03	51600.00
19BD19	2017-08-15 12:25:00+03	56000.00
19BD6F	2017-08-09 11:04:00+03	76600.00
19BD73	2017-07-18 03:26:00+03	132700.00
19BDC7	2017-08-10 06:38:00+03	224000.00
19BE0F	2017-07-16 10:29:00+03	81700.00
19BE12	2017-08-12 20:44:00+03	135600.00
19BE1F	2017-07-17 19:15:00+03	45500.00
19BEBE	2017-07-15 17:50:00+03	16400.00
19BF61	2017-08-13 16:07:00+03	43000.00
19BF9D	2017-07-25 10:22:00+03	148200.00
19BFCF	2017-08-01 19:48:00+03	177600.00
19C049	2017-08-12 04:33:00+03	89700.00
19C071	2017-07-16 15:21:00+03	89600.00
19C09D	2017-07-07 03:41:00+03	26000.00
19C0E3	2017-07-24 05:35:00+03	56100.00
19C0F1	2017-07-24 07:59:00+03	32800.00
19C12E	2017-07-30 15:07:00+03	42200.00
19C1E8	2017-07-07 22:02:00+03	32400.00
19C243	2017-07-28 07:48:00+03	94700.00
19C2C2	2017-08-08 07:43:00+03	6200.00
19C2D7	2017-08-10 08:43:00+03	92400.00
19C313	2017-07-28 06:13:00+03	185500.00
19C348	2017-07-09 06:29:00+03	23600.00
19C376	2017-07-23 18:14:00+03	155600.00
19C3C6	2017-08-04 22:40:00+03	15000.00
19C3D2	2017-08-02 16:13:00+03	243600.00
19C407	2017-07-15 09:21:00+03	64100.00
19C41F	2017-07-11 17:57:00+03	46400.00
19C43E	2017-08-09 06:09:00+03	91000.00
19C479	2017-07-17 17:58:00+03	111600.00
19C4BF	2017-07-13 21:34:00+03	6700.00
19C4C9	2017-07-09 18:12:00+03	70800.00
19C54F	2017-08-03 19:04:00+03	81700.00
19C566	2017-07-29 20:13:00+03	108600.00
19C5B0	2017-07-28 17:04:00+03	37900.00
19C642	2017-07-06 16:53:00+03	20200.00
19C6AD	2017-08-05 23:54:00+03	10800.00
19C77C	2017-08-13 21:25:00+03	43900.00
19C7B3	2017-08-14 04:45:00+03	70600.00
19C7C3	2017-07-11 16:43:00+03	166900.00
19C7DA	2017-08-10 23:57:00+03	42700.00
19C7FB	2017-08-05 00:36:00+03	152500.00
19C861	2017-07-25 03:17:00+03	54900.00
19C87A	2017-08-09 18:30:00+03	36200.00
19C87B	2017-07-03 23:46:00+03	25400.00
19C880	2017-07-08 14:36:00+03	135200.00
19C922	2017-07-21 18:01:00+03	26000.00
19C950	2017-07-07 03:45:00+03	59800.00
19C9DE	2017-07-21 21:13:00+03	6000.00
19C9EC	2017-07-29 08:19:00+03	90800.00
19CA08	2017-07-08 03:18:00+03	22200.00
19CA99	2017-07-28 21:04:00+03	46000.00
19CAE7	2017-08-12 15:00:00+03	8000.00
19CAEE	2017-08-08 17:25:00+03	265600.00
19CB25	2017-08-06 08:34:00+03	94000.00
19CB9E	2017-07-16 17:39:00+03	69000.00
19CBAA	2017-08-12 15:05:00+03	27800.00
19CBC3	2017-07-20 21:09:00+03	59800.00
19CBD2	2017-08-05 07:10:00+03	48200.00
19CD08	2017-08-14 10:29:00+03	24600.00
19CD40	2017-08-07 17:42:00+03	46400.00
19CD67	2017-08-03 20:28:00+03	38600.00
19CDCE	2017-08-07 10:56:00+03	59800.00
19CE2B	2017-08-01 08:28:00+03	46200.00
19CE7B	2017-07-24 20:01:00+03	55800.00
19CF0C	2017-08-01 19:52:00+03	70600.00
19CF62	2017-07-21 21:10:00+03	177800.00
19D018	2017-07-15 12:34:00+03	55800.00
19D027	2017-07-05 19:25:00+03	6800.00
19D044	2017-07-09 10:22:00+03	325500.00
19D077	2017-07-25 03:00:00+03	74400.00
19D078	2017-07-06 01:49:00+03	173600.00
19D089	2017-07-25 14:41:00+03	76800.00
19D0A1	2017-07-01 18:51:00+03	81800.00
19D0EE	2017-07-05 09:54:00+03	54800.00
19D0F5	2017-07-29 04:38:00+03	28000.00
19D0FA	2017-07-25 18:43:00+03	28000.00
19D0FF	2017-07-07 21:11:00+03	169600.00
19D106	2017-07-10 08:21:00+03	52000.00
19D149	2017-07-19 19:40:00+03	240500.00
19D17C	2017-08-04 18:36:00+03	85500.00
19D192	2017-08-08 13:33:00+03	6800.00
19D1F8	2017-08-10 03:18:00+03	23200.00
19D26D	2017-08-06 18:05:00+03	24700.00
19D279	2017-08-07 07:43:00+03	113800.00
19D2D5	2017-07-22 21:00:00+03	101200.00
19D30C	2017-07-01 22:36:00+03	67100.00
19D336	2017-08-11 22:00:00+03	46400.00
19D342	2017-07-27 13:27:00+03	171000.00
19D393	2017-08-05 05:52:00+03	67900.00
19D3B3	2017-08-10 07:33:00+03	41200.00
19D3B8	2017-08-02 10:47:00+03	28800.00
19D3DE	2017-08-15 15:01:00+03	13600.00
19D497	2017-07-18 04:09:00+03	7300.00
19D4F0	2017-07-11 16:47:00+03	136500.00
19D514	2017-08-12 17:07:00+03	13000.00
19D544	2017-07-13 20:55:00+03	56000.00
19D595	2017-07-07 02:14:00+03	102600.00
19D59B	2017-07-07 23:19:00+03	26000.00
19D5A8	2017-08-09 08:36:00+03	11600.00
19D5B5	2017-07-27 10:12:00+03	16400.00
19D6D0	2017-07-07 18:08:00+03	27200.00
19D6FE	2017-07-13 13:59:00+03	23200.00
19D711	2017-07-09 10:29:00+03	33000.00
19D722	2017-07-17 04:39:00+03	16400.00
19D7B3	2017-07-27 19:08:00+03	24400.00
19D7DF	2017-07-12 10:21:00+03	46000.00
19D8B4	2017-07-15 02:42:00+03	62700.00
19D8DF	2017-07-10 10:47:00+03	66000.00
19D8ED	2017-07-14 00:41:00+03	38600.00
19D935	2017-07-14 14:36:00+03	58600.00
19D93B	2017-08-03 02:57:00+03	135600.00
19D986	2017-08-15 13:32:00+03	13200.00
19D9B7	2017-08-02 01:19:00+03	65900.00
19D9BD	2017-07-23 05:15:00+03	38400.00
19D9F9	2017-07-03 00:01:00+03	133200.00
19DA93	2017-07-21 09:40:00+03	68300.00
19DADD	2017-08-14 02:41:00+03	114500.00
19DB24	2017-07-05 05:47:00+03	32800.00
19DB49	2017-07-13 04:57:00+03	65900.00
19DB4E	2017-07-28 12:47:00+03	49900.00
19DB52	2017-07-28 22:50:00+03	28800.00
19DB62	2017-07-12 22:36:00+03	28000.00
19DC5A	2017-07-16 15:16:00+03	112000.00
19DCAE	2017-07-07 22:53:00+03	28800.00
19DCC1	2017-07-31 00:10:00+03	316400.00
19DD20	2017-07-22 06:54:00+03	48800.00
19DD39	2017-07-04 08:43:00+03	28800.00
19DD3F	2017-07-17 11:51:00+03	36900.00
19DD8F	2017-08-10 11:29:00+03	6300.00
19DD90	2017-07-22 03:28:00+03	187600.00
19DDD6	2017-07-31 16:49:00+03	99500.00
19DEBB	2017-07-04 23:49:00+03	11700.00
19DF1B	2017-07-30 04:57:00+03	111600.00
19DF52	2017-07-11 01:18:00+03	137600.00
19DF84	2017-07-16 21:14:00+03	88600.00
19DF91	2017-07-24 23:18:00+03	83000.00
19DFAE	2017-08-01 16:37:00+03	284400.00
19DFC1	2017-07-20 15:10:00+03	71900.00
19DFE6	2017-08-14 03:39:00+03	92000.00
19DFF6	2017-07-27 04:23:00+03	68800.00
19E096	2017-07-26 00:25:00+03	131900.00
19E0AC	2017-08-15 11:19:00+03	41500.00
19E105	2017-07-13 22:01:00+03	134600.00
19E11D	2017-06-28 23:51:00+03	113700.00
19E1AE	2017-07-20 09:08:00+03	46800.00
19E1BF	2017-07-03 05:38:00+03	77000.00
19E20F	2017-07-24 17:12:00+03	24800.00
19E363	2017-07-05 15:18:00+03	40600.00
19E392	2017-07-02 05:12:00+03	22600.00
19E399	2017-07-19 03:40:00+03	210800.00
19E474	2017-08-15 12:41:00+03	43900.00
19E490	2017-07-04 13:34:00+03	36400.00
19E4E6	2017-07-04 18:08:00+03	54800.00
19E503	2017-07-11 05:09:00+03	40000.00
19E55F	2017-07-07 11:46:00+03	112000.00
19E584	2017-08-11 01:36:00+03	55600.00
19E5C2	2017-08-03 14:13:00+03	149400.00
19E5E4	2017-08-06 12:48:00+03	193700.00
19E64B	2017-07-13 13:33:00+03	56000.00
19E66A	2017-07-23 10:10:00+03	23200.00
19E681	2017-07-31 17:20:00+03	73500.00
19E6D5	2017-07-10 08:52:00+03	96800.00
19E6E5	2017-07-20 12:26:00+03	62600.00
19E70D	2017-08-05 04:32:00+03	62600.00
19E7E4	2017-08-07 22:17:00+03	21000.00
19E83F	2017-07-13 06:09:00+03	60400.00
19E960	2017-07-05 09:09:00+03	273000.00
19E967	2017-08-12 13:30:00+03	94800.00
19E98C	2017-07-03 22:13:00+03	47000.00
19EA1D	2017-07-20 02:22:00+03	7200.00
19EA7D	2017-07-03 18:36:00+03	26000.00
19EAD2	2017-06-28 16:39:00+03	21400.00
19EB28	2017-08-14 02:43:00+03	201800.00
19EB91	2017-08-06 15:12:00+03	135400.00
19EBBC	2017-07-27 17:28:00+03	55600.00
19EBC1	2017-08-12 05:01:00+03	11600.00
19EBFD	2017-07-31 03:53:00+03	188100.00
19EC09	2017-08-12 05:13:00+03	31100.00
19EC55	2017-07-06 09:39:00+03	6700.00
19EC6E	2017-08-02 03:21:00+03	75300.00
19EDCA	2017-08-14 16:36:00+03	105000.00
19EF22	2017-08-01 06:37:00+03	92900.00
19EF2B	2017-07-04 06:41:00+03	58000.00
19EF61	2017-07-25 11:07:00+03	147700.00
19EFDD	2017-08-01 10:17:00+03	68800.00
19EFE4	2017-07-29 23:30:00+03	22000.00
19F037	2017-07-26 02:56:00+03	106400.00
19F050	2017-08-02 09:39:00+03	44600.00
19F106	2017-07-20 18:26:00+03	13200.00
19F16E	2017-08-05 04:23:00+03	31400.00
19F174	2017-07-30 04:21:00+03	72400.00
19F1B4	2017-07-09 18:56:00+03	32700.00
19F248	2017-08-05 23:44:00+03	123000.00
19F2CC	2017-07-16 19:07:00+03	386300.00
19F2EC	2017-08-04 13:09:00+03	101200.00
19F2FC	2017-07-17 04:52:00+03	85400.00
19F32A	2017-07-21 15:21:00+03	36900.00
19F35E	2017-07-09 20:48:00+03	133600.00
19F361	2017-07-27 22:39:00+03	26000.00
19F3DF	2017-07-17 19:21:00+03	93600.00
19F40A	2017-07-05 12:25:00+03	25600.00
19F417	2017-08-06 08:24:00+03	24400.00
19F424	2017-07-22 10:03:00+03	57800.00
19F4BC	2017-07-27 04:48:00+03	28000.00
19F516	2017-07-29 17:36:00+03	393600.00
19F529	2017-08-02 19:06:00+03	142400.00
19F55C	2017-07-01 15:51:00+03	49400.00
19F591	2017-07-11 19:45:00+03	22000.00
19F5ED	2017-08-02 02:04:00+03	28800.00
19F69B	2017-08-06 00:24:00+03	30200.00
19F78C	2017-07-18 06:06:00+03	21400.00
19F7BB	2017-08-08 15:27:00+03	103500.00
19F7D2	2017-07-02 23:43:00+03	284400.00
19F814	2017-07-04 08:19:00+03	84100.00
19F824	2017-07-29 11:54:00+03	112000.00
19F853	2017-07-25 09:03:00+03	83000.00
19F85C	2017-08-06 07:40:00+03	50000.00
19F88D	2017-08-04 16:02:00+03	27900.00
19F8F5	2017-07-16 07:43:00+03	46500.00
19F918	2017-08-12 17:55:00+03	369000.00
19F927	2017-07-14 02:25:00+03	31900.00
19F93A	2017-08-02 23:51:00+03	26000.00
19F99C	2017-07-30 05:21:00+03	115700.00
19F9A0	2017-07-12 07:11:00+03	246000.00
19FAF4	2017-08-03 20:57:00+03	50800.00
19FB44	2017-07-08 01:56:00+03	410800.00
19FBB1	2017-08-01 15:45:00+03	23600.00
19FBE5	2017-07-06 11:06:00+03	83500.00
19FC0E	2017-08-05 02:02:00+03	33200.00
19FC47	2017-08-10 21:12:00+03	59200.00
19FC5C	2017-08-12 05:46:00+03	99700.00
19FD12	2017-07-31 16:43:00+03	170200.00
19FD49	2017-07-29 19:57:00+03	23100.00
19FD60	2017-08-14 08:02:00+03	79600.00
19FD61	2017-07-02 01:26:00+03	14000.00
19FD6C	2017-07-06 12:17:00+03	114800.00
19FE00	2017-08-09 00:18:00+03	19600.00
19FE2D	2017-07-08 09:55:00+03	40800.00
19FE38	2017-07-06 13:42:00+03	26700.00
19FE50	2017-08-13 16:15:00+03	57400.00
19FE54	2017-08-02 20:53:00+03	262600.00
19FE8A	2017-07-16 03:04:00+03	32800.00
19FEA1	2017-08-13 11:52:00+03	75300.00
19FF7C	2017-07-11 00:11:00+03	83000.00
19FF9C	2017-08-09 14:20:00+03	94000.00
19FFB4	2017-08-09 18:20:00+03	48700.00
19FFEA	2017-07-19 19:32:00+03	240500.00
1A004D	2017-08-05 11:57:00+03	96300.00
1A00C1	2017-07-21 20:06:00+03	40000.00
1A0151	2017-07-15 09:44:00+03	62100.00
1A0170	2017-07-30 07:16:00+03	49100.00
1A0216	2017-08-06 03:12:00+03	51900.00
1A0219	2017-07-22 00:10:00+03	64900.00
1A022D	2017-07-16 15:18:00+03	59800.00
1A024A	2017-07-30 14:58:00+03	185300.00
1A0256	2017-07-22 01:06:00+03	86300.00
1A027D	2017-07-22 13:02:00+03	67100.00
1A027E	2017-06-26 10:42:00+03	40200.00
1A02B3	2017-08-07 13:24:00+03	64100.00
1A02E6	2017-06-29 08:11:00+03	13600.00
1A0327	2017-07-18 01:28:00+03	20000.00
1A0355	2017-07-24 19:58:00+03	46700.00
1A0390	2017-06-29 10:37:00+03	226200.00
1A03A6	2017-08-03 22:45:00+03	28300.00
1A03CB	2017-07-16 05:55:00+03	92400.00
1A045A	2017-07-06 13:09:00+03	90400.00
1A0482	2017-08-15 02:10:00+03	13400.00
1A0513	2017-07-07 08:19:00+03	136200.00
1A0514	2017-07-03 02:21:00+03	271200.00
1A0552	2017-07-13 03:45:00+03	19800.00
1A0555	2017-07-15 14:02:00+03	36200.00
1A05A3	2017-08-10 18:00:00+03	43200.00
1A05D1	2017-07-25 03:24:00+03	10800.00
1A06E1	2017-07-02 09:24:00+03	25400.00
1A06F6	2017-07-16 05:40:00+03	273100.00
1A072C	2017-07-29 15:44:00+03	70800.00
1A072D	2017-08-12 12:54:00+03	38300.00
1A0789	2017-08-08 06:51:00+03	28000.00
1A079F	2017-08-15 00:55:00+03	26600.00
1A07F1	2017-08-15 13:18:00+03	24000.00
1A080F	2017-08-15 00:41:00+03	59200.00
1A08A9	2017-08-09 07:42:00+03	36200.00
1A08AC	2017-07-28 04:09:00+03	172600.00
1A08D3	2017-07-01 15:58:00+03	301800.00
1A08D6	2017-07-25 09:09:00+03	25400.00
1A08E0	2017-07-22 09:14:00+03	123000.00
1A0937	2017-07-21 00:20:00+03	53300.00
1A0991	2017-07-09 15:16:00+03	56600.00
1A09D4	2017-08-07 16:13:00+03	65900.00
1A09FF	2017-07-04 10:18:00+03	87400.00
1A0A1A	2017-07-18 04:32:00+03	153900.00
1A0A81	2017-07-11 23:18:00+03	54500.00
1A0A85	2017-07-12 07:58:00+03	34600.00
1A0AA4	2017-06-29 09:33:00+03	28800.00
1A0AEC	2017-07-08 16:49:00+03	261500.00
1A0B0B	2017-07-11 23:07:00+03	32400.00
1A0B11	2017-07-10 10:05:00+03	61100.00
1A0B17	2017-08-08 12:01:00+03	144400.00
1A0B52	2017-07-25 05:50:00+03	69000.00
1A0B70	2017-07-24 08:35:00+03	58200.00
1A0BD2	2017-07-08 16:11:00+03	47000.00
1A0BEE	2017-07-12 18:58:00+03	44000.00
1A0C7B	2017-07-28 07:06:00+03	116000.00
1A0C92	2017-07-08 17:12:00+03	6700.00
1A0CB3	2017-07-28 07:01:00+03	43800.00
1A0D16	2017-08-01 17:50:00+03	73600.00
1A0D8A	2017-08-05 04:24:00+03	34400.00
1A0D8C	2017-07-04 04:19:00+03	16800.00
1A0E67	2017-07-08 13:40:00+03	7400.00
1A0EB3	2017-07-11 20:11:00+03	85100.00
1A0EF3	2017-07-14 06:14:00+03	32700.00
1A0F0E	2017-07-25 13:56:00+03	81600.00
1A0F2E	2017-07-26 17:24:00+03	91100.00
1A0F33	2017-07-11 07:57:00+03	52900.00
1A0F84	2017-07-19 20:05:00+03	117700.00
1A0F93	2017-08-07 07:02:00+03	56000.00
1A0FA8	2017-07-08 14:16:00+03	75800.00
1A1000	2017-08-09 06:30:00+03	35300.00
1A101A	2017-07-31 14:45:00+03	131100.00
1A104B	2017-07-31 07:24:00+03	101800.00
1A1051	2017-07-03 12:30:00+03	66800.00
1A1086	2017-07-08 03:09:00+03	406100.00
1A10A6	2017-07-31 18:02:00+03	48100.00
1A111A	2017-07-26 19:20:00+03	322000.00
1A111D	2017-07-20 19:22:00+03	102600.00
1A1145	2017-07-26 02:18:00+03	119500.00
1A1156	2017-07-18 17:56:00+03	22000.00
1A1260	2017-08-05 11:12:00+03	101200.00
1A126E	2017-07-04 22:56:00+03	6800.00
1A1284	2017-07-04 14:50:00+03	70800.00
1A1406	2017-08-03 04:44:00+03	43900.00
1A140D	2017-07-08 15:33:00+03	25100.00
1A14E6	2017-07-28 09:06:00+03	75600.00
1A153A	2017-08-12 10:55:00+03	43100.00
1A154F	2017-08-05 09:04:00+03	44000.00
1A15D2	2017-07-16 07:37:00+03	25600.00
1A15EB	2017-07-29 22:58:00+03	77500.00
1A15FA	2017-07-10 11:29:00+03	40800.00
1A162D	2017-07-23 17:04:00+03	23200.00
1A1645	2017-07-12 22:57:00+03	37900.00
1A1651	2017-07-24 09:07:00+03	94000.00
1A165B	2017-07-20 07:41:00+03	89100.00
1A16B2	2017-08-09 00:54:00+03	67500.00
1A16F3	2017-08-05 22:10:00+03	39900.00
1A1759	2017-07-20 03:36:00+03	65600.00
1A176A	2017-07-31 19:28:00+03	114300.00
1A1776	2017-07-30 06:33:00+03	18700.00
1A1835	2017-07-19 15:50:00+03	131100.00
1A1897	2017-07-29 02:47:00+03	38800.00
1A18D2	2017-07-27 10:26:00+03	56000.00
1A18F2	2017-08-15 04:15:00+03	30200.00
1A1911	2017-06-27 21:36:00+03	284400.00
1A1926	2017-07-02 09:59:00+03	46500.00
1A1928	2017-08-11 02:00:00+03	115700.00
1A199E	2017-07-30 16:22:00+03	341900.00
1A19BA	2017-08-06 10:12:00+03	86600.00
1A19E6	2017-06-29 19:41:00+03	106800.00
1A19F5	2017-07-21 21:21:00+03	111600.00
1A1B86	2017-08-05 12:19:00+03	40800.00
1A1BD9	2017-07-24 13:40:00+03	99900.00
1A1BDF	2017-08-06 13:01:00+03	12400.00
1A1CB0	2017-08-03 21:24:00+03	19600.00
1A1D2F	2017-08-01 06:54:00+03	29600.00
1A1D51	2017-07-20 19:41:00+03	147700.00
1A1DCF	2017-08-01 19:36:00+03	73600.00
1A1DD1	2017-08-02 17:28:00+03	20000.00
1A1DF4	2017-07-02 04:48:00+03	78200.00
1A1E09	2017-07-15 04:55:00+03	26000.00
1A1E37	2017-07-01 03:35:00+03	94800.00
1A1EEC	2017-07-31 03:59:00+03	52400.00
1A1EF0	2017-07-05 08:22:00+03	444500.00
1A1F8E	2017-07-18 05:19:00+03	179400.00
1A1FB5	2017-07-26 21:06:00+03	91900.00
1A2027	2017-07-27 23:08:00+03	138600.00
1A2045	2017-07-04 08:27:00+03	32600.00
1A2057	2017-06-28 10:55:00+03	79600.00
1A2063	2017-07-15 02:28:00+03	43500.00
1A208F	2017-08-07 05:07:00+03	67200.00
1A20AF	2017-07-17 11:29:00+03	35200.00
1A20DA	2017-07-28 11:06:00+03	269600.00
1A2194	2017-07-21 20:09:00+03	40000.00
1A21F5	2017-08-11 08:35:00+03	125200.00
1A2258	2017-07-11 08:44:00+03	33000.00
1A2285	2017-07-27 10:04:00+03	56000.00
1A2307	2017-07-01 07:53:00+03	48800.00
1A2323	2017-08-08 17:16:00+03	66900.00
1A233F	2017-07-09 00:59:00+03	79900.00
1A235A	2017-07-31 01:27:00+03	46400.00
1A23C2	2017-07-03 17:25:00+03	44000.00
1A23D7	2017-07-19 18:11:00+03	20200.00
1A23F7	2017-08-10 08:14:00+03	46000.00
1A2412	2017-08-05 12:14:00+03	46800.00
1A244C	2017-08-14 07:14:00+03	26700.00
1A246C	2017-08-04 04:16:00+03	67600.00
1A2483	2017-07-10 00:53:00+03	62700.00
1A24A9	2017-08-08 10:16:00+03	52000.00
1A2521	2017-07-21 11:38:00+03	386300.00
1A2526	2017-08-15 03:32:00+03	12600.00
1A2551	2017-08-09 05:02:00+03	124200.00
1A256F	2017-07-15 07:54:00+03	136500.00
1A258B	2017-07-24 20:17:00+03	55800.00
1A25EA	2017-08-08 11:39:00+03	229000.00
1A2630	2017-08-12 15:30:00+03	87400.00
1A263B	2017-07-31 11:38:00+03	234200.00
1A2658	2017-07-06 01:19:00+03	44000.00
1A26EF	2017-07-07 00:46:00+03	125400.00
1A26F1	2017-07-06 00:24:00+03	54400.00
1A2726	2017-07-09 07:55:00+03	23600.00
1A2751	2017-07-09 00:58:00+03	28000.00
1A276A	2017-07-01 12:12:00+03	26700.00
1A2843	2017-07-20 12:39:00+03	98700.00
1A2901	2017-07-29 18:13:00+03	25800.00
1A2904	2017-07-08 02:06:00+03	84100.00
1A292E	2017-07-30 03:09:00+03	12600.00
1A2980	2017-07-16 18:51:00+03	542200.00
1A29D7	2017-08-09 09:49:00+03	81200.00
1A2A2A	2017-07-30 22:35:00+03	71900.00
1A2A70	2017-08-12 07:11:00+03	37000.00
1A2AA9	2017-07-21 19:18:00+03	111600.00
1A2B36	2017-07-02 19:03:00+03	76600.00
1A2B72	2017-07-16 10:05:00+03	23600.00
1A2B86	2017-07-19 21:03:00+03	48500.00
1A2B9C	2017-08-09 19:14:00+03	26000.00
1A2C2C	2017-07-17 20:55:00+03	83000.00
1A2C45	2017-08-07 03:04:00+03	50000.00
1A2C67	2017-07-16 15:55:00+03	115800.00
1A2C7E	2017-08-06 19:12:00+03	386300.00
1A2D63	2017-08-05 21:11:00+03	28800.00
1A2D6B	2017-07-06 02:20:00+03	68800.00
1A2DBA	2017-08-07 23:40:00+03	36200.00
1A2E09	2017-07-15 12:01:00+03	28000.00
1A2E42	2017-07-11 21:33:00+03	27900.00
1A2E55	2017-07-25 06:09:00+03	96300.00
1A2EE7	2017-07-22 17:49:00+03	133700.00
1A2EEC	2017-08-06 09:38:00+03	10700.00
1A2EFC	2017-07-14 05:39:00+03	25000.00
1A2F2E	2017-08-10 00:44:00+03	67600.00
1A2F64	2017-07-08 17:58:00+03	30000.00
1A2F96	2017-08-12 06:25:00+03	113600.00
1A303B	2017-07-09 00:17:00+03	215600.00
1A3052	2017-07-10 16:54:00+03	36400.00
1A30C6	2017-08-03 00:54:00+03	38800.00
1A30F4	2017-08-04 18:36:00+03	263200.00
1A3122	2017-07-01 01:54:00+03	28300.00
1A3133	2017-07-10 03:46:00+03	79900.00
1A3226	2017-07-20 18:01:00+03	10800.00
1A3246	2017-07-22 19:10:00+03	73200.00
1A326F	2017-07-07 01:05:00+03	68800.00
1A32F8	2017-08-03 18:39:00+03	50600.00
1A32FC	2017-07-27 17:06:00+03	46300.00
1A3347	2017-08-15 07:59:00+03	137600.00
1A3388	2017-08-10 13:07:00+03	31600.00
1A338F	2017-07-13 06:06:00+03	46400.00
1A33B0	2017-07-21 14:23:00+03	88600.00
1A33BF	2017-07-07 14:19:00+03	44800.00
1A345D	2017-07-20 15:33:00+03	14000.00
1A3486	2017-07-12 17:31:00+03	29600.00
1A34B4	2017-07-21 02:18:00+03	131100.00
1A351D	2017-08-07 17:46:00+03	216200.00
1A3541	2017-08-01 01:43:00+03	58800.00
1A358D	2017-07-09 18:24:00+03	331900.00
1A35A7	2017-07-10 16:41:00+03	154500.00
1A366D	2017-08-08 14:10:00+03	38900.00
1A371B	2017-07-26 17:35:00+03	23200.00
1A3736	2017-07-09 00:29:00+03	96800.00
1A3744	2017-07-02 09:22:00+03	19600.00
1A3767	2017-08-12 12:50:00+03	58400.00
1A37A1	2017-06-28 05:47:00+03	46300.00
1A37B1	2017-07-26 10:48:00+03	24800.00
1A3826	2017-07-08 16:52:00+03	134800.00
1A3899	2017-08-01 13:59:00+03	56000.00
1A3927	2017-08-05 18:08:00+03	13300.00
1A3999	2017-08-02 19:20:00+03	33600.00
1A39A9	2017-07-11 17:16:00+03	28000.00
1A39EF	2017-07-21 18:45:00+03	28800.00
1A3A6C	2017-07-23 11:53:00+03	135400.00
1A3A73	2017-07-18 02:58:00+03	26000.00
1A3A8C	2017-07-13 14:50:00+03	70200.00
1A3A8E	2017-08-10 18:02:00+03	27200.00
1A3A9C	2017-08-08 12:48:00+03	25800.00
1A3B1F	2017-08-15 00:40:00+03	43000.00
1A3BA3	2017-07-12 03:05:00+03	55800.00
1A3BD6	2017-07-16 21:33:00+03	27400.00
1A3BDE	2017-07-21 01:18:00+03	37900.00
1A3C9F	2017-07-24 09:53:00+03	173200.00
1A3CC8	2017-07-14 07:05:00+03	40800.00
1A3CD9	2017-07-26 11:08:00+03	25200.00
1A3D14	2017-07-13 18:23:00+03	117700.00
1A3D17	2017-08-09 19:17:00+03	98300.00
1A3DFC	2017-06-30 05:21:00+03	53000.00
1A3E0E	2017-07-23 02:43:00+03	189800.00
1A3E6D	2017-07-27 03:43:00+03	55800.00
1A3E9B	2017-07-03 07:06:00+03	44500.00
1A3ECC	2017-08-07 23:09:00+03	15000.00
1A3ED9	2017-07-07 00:37:00+03	154700.00
1A3F6A	2017-07-05 09:52:00+03	40000.00
1A3FCA	2017-07-28 17:04:00+03	67600.00
1A40A9	2017-06-28 14:29:00+03	56000.00
1A4121	2017-08-06 04:51:00+03	6000.00
1A41C4	2017-07-28 05:22:00+03	28000.00
1A420C	2017-07-10 07:37:00+03	75600.00
1A42E1	2017-07-17 23:35:00+03	26000.00
1A4319	2017-07-30 20:17:00+03	100600.00
1A437B	2017-07-07 12:36:00+03	28000.00
1A439E	2017-08-04 20:44:00+03	40800.00
1A4407	2017-08-12 17:04:00+03	38600.00
1A441A	2017-07-19 05:30:00+03	23600.00
1A4471	2017-08-03 00:01:00+03	13600.00
1A447E	2017-06-28 22:53:00+03	80000.00
1A448D	2017-07-18 13:23:00+03	54200.00
1A44C7	2017-08-05 15:12:00+03	23600.00
1A4627	2017-07-29 22:51:00+03	30400.00
1A4652	2017-07-01 22:54:00+03	55800.00
1A465D	2017-07-22 17:07:00+03	17800.00
1A471C	2017-07-06 18:59:00+03	35600.00
1A473A	2017-08-09 04:52:00+03	23900.00
1A47AC	2017-08-04 13:20:00+03	42800.00
1A47C0	2017-08-08 21:22:00+03	24000.00
1A47D6	2017-08-10 19:10:00+03	12600.00
1A47E7	2017-08-06 00:45:00+03	49100.00
1A4821	2017-07-26 23:09:00+03	28000.00
1A482D	2017-07-15 22:16:00+03	115700.00
1A4856	2017-07-25 11:54:00+03	156400.00
1A48B4	2017-07-04 14:43:00+03	22000.00
1A48C3	2017-07-26 02:21:00+03	28600.00
1A48D0	2017-07-12 08:35:00+03	28800.00
1A4909	2017-07-13 04:29:00+03	64700.00
1A49CA	2017-07-23 02:19:00+03	78700.00
1A49D0	2017-07-01 21:55:00+03	56000.00
1A49F3	2017-08-10 22:05:00+03	24000.00
1A4A46	2017-07-17 14:19:00+03	43400.00
1A4A54	2017-08-05 20:56:00+03	112000.00
1A4A7C	2017-08-01 02:13:00+03	21800.00
1A4B06	2017-07-28 03:34:00+03	30800.00
1A4B24	2017-08-04 08:18:00+03	73300.00
1A4B27	2017-07-02 07:14:00+03	66000.00
1A4BA8	2017-08-11 21:17:00+03	43600.00
1A4BAD	2017-07-06 01:11:00+03	92600.00
1A4BD4	2017-08-10 17:12:00+03	8200.00
1A4BE8	2017-07-05 23:39:00+03	41800.00
1A4C27	2017-08-15 00:18:00+03	40100.00
1A4CAB	2017-07-20 23:08:00+03	24400.00
1A4CC8	2017-07-02 17:59:00+03	26800.00
1A4CCA	2017-08-07 08:50:00+03	8200.00
1A4CD8	2017-07-07 12:11:00+03	106100.00
1A4D6B	2017-07-14 19:11:00+03	23600.00
1A4D7E	2017-07-11 15:58:00+03	79800.00
1A4E1B	2017-07-22 10:33:00+03	138600.00
1A4E3A	2017-07-20 19:30:00+03	21600.00
1A4E4D	2017-08-01 01:28:00+03	71900.00
1A4E82	2017-07-04 07:33:00+03	38200.00
1A4EB7	2017-07-08 23:16:00+03	54000.00
1A4F57	2017-07-23 03:41:00+03	13800.00
1A4F6E	2017-08-08 04:28:00+03	193900.00
1A4F98	2017-06-29 10:09:00+03	68800.00
1A4FA4	2017-08-11 14:24:00+03	48400.00
1A509E	2017-07-13 04:50:00+03	126500.00
1A50BA	2017-07-07 10:58:00+03	67600.00
1A50C5	2017-07-29 01:16:00+03	121400.00
1A50F5	2017-07-20 17:01:00+03	43100.00
1A5158	2017-07-07 09:31:00+03	42400.00
1A5192	2017-08-15 12:19:00+03	33400.00
1A5193	2017-08-11 05:46:00+03	46400.00
1A51C1	2017-07-21 06:30:00+03	23200.00
1A51CB	2017-08-06 17:52:00+03	18000.00
1A5201	2017-08-04 22:33:00+03	112000.00
1A5221	2017-07-19 00:24:00+03	40800.00
1A5239	2017-07-27 14:14:00+03	26000.00
1A5247	2017-07-30 03:50:00+03	28000.00
1A5284	2017-07-15 18:37:00+03	113700.00
1A52A9	2017-07-26 18:43:00+03	110300.00
1A52D8	2017-07-27 09:23:00+03	6900.00
1A52F5	2017-07-30 17:45:00+03	16400.00
1A52F9	2017-07-10 14:23:00+03	10800.00
1A531C	2017-08-02 17:23:00+03	290500.00
1A5392	2017-07-15 11:30:00+03	67200.00
1A53AF	2017-08-13 15:24:00+03	131100.00
1A5433	2017-07-13 10:55:00+03	22000.00
1A5450	2017-07-20 02:43:00+03	149300.00
1A5458	2017-07-19 22:14:00+03	137100.00
1A54E6	2017-07-16 21:54:00+03	166000.00
1A5530	2017-08-12 08:33:00+03	25100.00
1A5588	2017-07-15 02:31:00+03	10800.00
1A55DC	2017-08-10 08:57:00+03	43800.00
1A5664	2017-08-06 10:50:00+03	92800.00
1A566A	2017-08-07 14:39:00+03	155600.00
1A566B	2017-08-01 04:07:00+03	103900.00
1A569C	2017-07-27 04:39:00+03	12200.00
1A56E5	2017-08-15 06:28:00+03	48100.00
1A5748	2017-07-31 02:53:00+03	136800.00
1A5752	2017-07-09 08:25:00+03	39100.00
1A5774	2017-06-29 17:55:00+03	28800.00
1A5777	2017-07-23 08:46:00+03	23100.00
1A57BA	2017-07-08 12:50:00+03	16400.00
1A57D2	2017-06-30 19:10:00+03	57500.00
1A5814	2017-07-31 12:33:00+03	28000.00
1A581F	2017-08-06 09:32:00+03	111600.00
1A5859	2017-07-22 04:09:00+03	29800.00
1A58CA	2017-07-24 17:12:00+03	22000.00
1A59CA	2017-07-20 09:54:00+03	43900.00
1A5A34	2017-07-14 20:07:00+03	45500.00
1A5A39	2017-08-06 17:21:00+03	13400.00
1A5B48	2017-08-13 03:31:00+03	40600.00
1A5B4B	2017-08-10 13:47:00+03	216100.00
1A5C50	2017-07-24 02:57:00+03	192800.00
1A5C99	2017-07-03 07:53:00+03	46000.00
1A5D17	2017-07-29 08:25:00+03	23200.00
1A5D23	2017-08-14 12:34:00+03	234500.00
1A5D6C	2017-07-29 12:06:00+03	134400.00
1A5DC2	2017-08-14 18:47:00+03	49100.00
1A5E17	2017-07-08 22:04:00+03	27800.00
1A5E28	2017-08-05 07:41:00+03	42900.00
1A5E35	2017-08-06 18:08:00+03	258000.00
1A5EE7	2017-08-01 10:49:00+03	23500.00
1A5EF2	2017-07-08 20:31:00+03	47400.00
1A5EFE	2017-07-21 13:48:00+03	248300.00
1A5F33	2017-08-11 01:06:00+03	46200.00
1A5FC4	2017-07-12 04:51:00+03	128800.00
1A5FFC	2017-06-29 13:26:00+03	173600.00
1A6047	2017-08-12 15:53:00+03	128800.00
1A60A0	2017-08-10 07:32:00+03	65400.00
1A60D0	2017-07-11 14:37:00+03	14000.00
1A60DF	2017-08-08 08:43:00+03	31600.00
1A610E	2017-08-13 06:22:00+03	106900.00
1A612C	2017-07-31 13:35:00+03	83600.00
1A6153	2017-08-06 15:00:00+03	102600.00
1A61DC	2017-07-30 19:00:00+03	67600.00
1A6213	2017-07-09 15:29:00+03	81500.00
1A6221	2017-07-09 03:03:00+03	179400.00
1A6234	2017-07-08 09:53:00+03	108000.00
1A6285	2017-07-08 10:54:00+03	20600.00
1A629C	2017-08-03 10:22:00+03	52300.00
1A62F8	2017-07-06 16:08:00+03	58800.00
1A6311	2017-07-07 10:31:00+03	109000.00
1A63DA	2017-08-07 03:49:00+03	169600.00
1A64A8	2017-08-05 01:54:00+03	51300.00
1A64D2	2017-07-02 20:10:00+03	38800.00
1A64DA	2017-08-07 13:43:00+03	55800.00
1A64DE	2017-07-19 02:31:00+03	11700.00
1A659D	2017-07-21 15:49:00+03	67600.00
1A65C2	2017-07-13 16:22:00+03	44800.00
1A65FE	2017-07-04 09:25:00+03	62000.00
1A66EA	2017-07-21 14:58:00+03	48800.00
1A66F1	2017-07-05 22:21:00+03	6000.00
1A66FF	2017-07-26 18:44:00+03	136700.00
1A6738	2017-07-15 20:18:00+03	46200.00
1A6740	2017-07-29 22:26:00+03	28000.00
1A6778	2017-07-21 10:10:00+03	229900.00
1A6845	2017-07-17 02:05:00+03	69000.00
1A68AA	2017-07-31 23:04:00+03	186900.00
1A68EA	2017-07-11 00:44:00+03	51600.00
1A6937	2017-07-15 19:37:00+03	84100.00
1A6958	2017-07-11 13:22:00+03	246000.00
1A697C	2017-07-25 23:28:00+03	14000.00
1A698C	2017-08-12 03:44:00+03	56000.00
1A6A02	2017-07-30 21:54:00+03	293200.00
1A6A08	2017-07-17 12:06:00+03	23600.00
1A6A21	2017-07-12 01:14:00+03	54600.00
1A6A5A	2017-07-18 09:06:00+03	26700.00
1A6A8B	2017-08-01 15:47:00+03	45100.00
1A6AB1	2017-07-30 10:51:00+03	28800.00
1A6B29	2017-07-13 13:17:00+03	76400.00
1A6B3D	2017-07-23 20:34:00+03	91600.00
1A6BAB	2017-07-10 03:31:00+03	12200.00
1A6BAE	2017-07-17 03:16:00+03	45100.00
1A6BB3	2017-07-15 13:58:00+03	32200.00
1A6BF8	2017-07-28 09:46:00+03	46300.00
1A6C2E	2017-07-05 12:59:00+03	40800.00
1A6C56	2017-07-19 01:40:00+03	47100.00
1A6C88	2017-08-07 11:01:00+03	20200.00
1A6CB2	2017-07-20 16:48:00+03	45200.00
1A6CC6	2017-08-14 17:30:00+03	24400.00
1A6D38	2017-07-29 10:10:00+03	84500.00
1A6D66	2017-07-14 17:33:00+03	107700.00
1A6D79	2017-07-16 02:24:00+03	29600.00
1A6DAC	2017-08-11 13:11:00+03	13700.00
1A6E98	2017-08-03 15:26:00+03	57800.00
1A6F24	2017-08-15 08:21:00+03	28000.00
1A6F62	2017-06-28 13:20:00+03	51200.00
1A6F66	2017-07-19 00:59:00+03	27300.00
1A6FDA	2017-07-21 02:46:00+03	7400.00
1A70AB	2017-07-27 18:55:00+03	87100.00
1A70D4	2017-07-12 20:42:00+03	21500.00
1A7108	2017-07-16 10:44:00+03	26000.00
1A711A	2017-08-02 22:07:00+03	147900.00
1A714D	2017-08-03 03:48:00+03	130800.00
1A7164	2017-07-12 02:35:00+03	25400.00
1A71BD	2017-08-06 07:48:00+03	47400.00
1A71C4	2017-08-15 10:39:00+03	149200.00
1A71E5	2017-08-04 19:47:00+03	26000.00
1A71FF	2017-07-06 08:21:00+03	36200.00
1A7200	2017-07-30 14:44:00+03	66600.00
1A720C	2017-07-28 06:13:00+03	189200.00
1A725D	2017-07-24 15:28:00+03	65300.00
1A72E5	2017-07-14 18:47:00+03	94700.00
1A7320	2017-07-14 07:05:00+03	35600.00
1A7334	2017-08-10 06:58:00+03	21400.00
1A73AD	2017-07-06 01:01:00+03	216200.00
1A73F1	2017-07-24 20:15:00+03	185800.00
1A7407	2017-07-10 08:47:00+03	51600.00
1A740C	2017-07-26 09:34:00+03	67900.00
1A7413	2017-08-11 22:02:00+03	25200.00
1A748C	2017-07-21 05:50:00+03	24000.00
1A7492	2017-07-10 15:56:00+03	26800.00
1A74C0	2017-07-07 03:09:00+03	35600.00
1A74CD	2017-07-13 09:32:00+03	25100.00
1A74E5	2017-07-23 22:43:00+03	52000.00
1A750D	2017-07-12 16:49:00+03	24400.00
1A750E	2017-07-28 16:10:00+03	94000.00
1A751D	2017-08-15 17:09:00+03	27600.00
1A7579	2017-08-12 13:14:00+03	117200.00
1A7582	2017-08-05 22:02:00+03	136000.00
1A75B0	2017-07-10 22:38:00+03	266400.00
1A75B5	2017-08-11 17:11:00+03	41400.00
1A75C0	2017-07-20 19:05:00+03	10800.00
1A75DC	2017-07-19 02:55:00+03	46400.00
1A75DD	2017-08-04 13:46:00+03	277900.00
1A767C	2017-08-08 06:19:00+03	16800.00
1A7699	2017-07-02 11:29:00+03	25400.00
1A76BD	2017-08-05 17:20:00+03	26700.00
1A76ED	2017-07-31 00:27:00+03	6300.00
1A76FA	2017-08-12 14:23:00+03	48800.00
1A770B	2017-08-02 02:28:00+03	24400.00
1A77D1	2017-08-07 18:35:00+03	12400.00
1A7858	2017-07-31 07:22:00+03	49100.00
1A78C4	2017-07-15 04:55:00+03	56100.00
1A78E8	2017-07-12 12:40:00+03	26000.00
1A797B	2017-07-14 21:14:00+03	394400.00
1A7984	2017-08-04 07:29:00+03	16800.00
1A798A	2017-07-28 01:48:00+03	145800.00
1A799C	2017-08-14 09:25:00+03	31100.00
1A79DD	2017-07-05 21:11:00+03	46400.00
1A7AEA	2017-08-03 06:27:00+03	160700.00
1A7B0D	2017-07-09 17:21:00+03	55400.00
1A7B10	2017-07-13 17:54:00+03	97800.00
1A7B36	2017-08-15 15:18:00+03	179400.00
1A7BA8	2017-07-24 15:10:00+03	265600.00
1A7C12	2017-08-14 13:59:00+03	6700.00
1A7C1C	2017-07-13 08:11:00+03	52900.00
1A7C2F	2017-07-18 03:41:00+03	42800.00
1A7C38	2017-07-22 02:36:00+03	48800.00
1A7C77	2017-07-20 06:24:00+03	56600.00
1A7C81	2017-07-03 08:35:00+03	32800.00
1A7CAD	2017-08-11 22:33:00+03	133100.00
1A7CF8	2017-08-02 10:30:00+03	46300.00
1A7D12	2017-08-08 10:29:00+03	55800.00
1A7D37	2017-07-01 21:19:00+03	170100.00
1A7DAE	2017-08-05 11:32:00+03	42800.00
1A7DD4	2017-07-07 09:40:00+03	45000.00
1A7DDD	2017-07-31 10:29:00+03	185800.00
1A7DF2	2017-07-11 05:06:00+03	60700.00
1A7DFB	2017-07-06 00:04:00+03	90000.00
1A7E63	2017-07-19 07:55:00+03	243600.00
1A7EC7	2017-07-19 04:23:00+03	70700.00
1A7EEF	2017-08-09 11:02:00+03	57700.00
1A7F6C	2017-07-16 14:18:00+03	13400.00
1A7FC8	2017-07-18 03:17:00+03	135000.00
1A800D	2017-07-26 01:28:00+03	51900.00
1A8091	2017-08-08 16:03:00+03	39300.00
1A810D	2017-08-15 06:09:00+03	12200.00
1A8140	2017-07-07 18:17:00+03	113000.00
1A81FB	2017-08-06 11:59:00+03	14400.00
1A8219	2017-08-08 14:20:00+03	99700.00
1A8274	2017-08-04 13:56:00+03	37000.00
1A82D1	2017-08-07 06:47:00+03	44600.00
1A82D6	2017-08-07 08:06:00+03	93500.00
1A833B	2017-08-15 04:17:00+03	16400.00
1A837E	2017-08-12 21:16:00+03	30900.00
1A8386	2017-08-12 07:37:00+03	36000.00
1A83D3	2017-08-05 19:46:00+03	92800.00
1A83E2	2017-08-10 23:07:00+03	19600.00
1A84A1	2017-07-05 01:01:00+03	14400.00
1A84CE	2017-07-01 12:31:00+03	54000.00
1A8501	2017-06-30 18:03:00+03	84800.00
1A852D	2017-07-28 00:48:00+03	66800.00
1A8578	2017-08-04 21:49:00+03	131100.00
1A85C9	2017-07-03 23:46:00+03	67700.00
1A85CF	2017-07-26 14:39:00+03	236900.00
1A85D3	2017-07-11 21:50:00+03	24400.00
1A8682	2017-07-22 08:45:00+03	112000.00
1A86C7	2017-07-10 09:23:00+03	206400.00
1A871A	2017-08-09 14:58:00+03	80300.00
1A87FD	2017-07-15 09:34:00+03	106400.00
1A8800	2017-07-16 19:13:00+03	21800.00
1A8825	2017-07-26 03:02:00+03	266400.00
1A8851	2017-07-09 16:30:00+03	45200.00
1A8865	2017-08-02 04:14:00+03	23600.00
1A886E	2017-08-14 00:28:00+03	50000.00
1A889B	2017-07-25 19:04:00+03	217600.00
1A88B8	2017-08-01 07:37:00+03	24400.00
1A88C0	2017-08-01 05:19:00+03	56600.00
1A891A	2017-07-14 06:02:00+03	36200.00
1A8996	2017-07-28 20:58:00+03	51800.00
1A89CA	2017-08-09 08:49:00+03	85000.00
1A89CD	2017-08-11 14:32:00+03	49100.00
1A8A0C	2017-07-25 11:04:00+03	38600.00
1A8A36	2017-07-24 05:59:00+03	12000.00
1A8A6C	2017-07-04 04:39:00+03	55800.00
1A8A95	2017-08-08 16:54:00+03	23600.00
1A8AAE	2017-07-20 04:22:00+03	55600.00
1A8AC8	2017-06-29 15:20:00+03	23200.00
1A8B14	2017-07-08 15:10:00+03	10600.00
1A8B48	2017-08-02 09:30:00+03	6000.00
1A8B62	2017-07-04 05:11:00+03	61400.00
1A8BBB	2017-08-02 12:21:00+03	27200.00
1A8BC3	2017-08-01 07:42:00+03	132500.00
1A8C10	2017-07-14 21:40:00+03	87400.00
1A8C4E	2017-07-29 10:45:00+03	141600.00
1A8CE2	2017-08-14 08:48:00+03	99200.00
1A8D1A	2017-07-07 16:50:00+03	61900.00
1A8D8D	2017-07-31 10:19:00+03	28800.00
1A8DDB	2017-07-09 11:05:00+03	46400.00
1A8E38	2017-07-18 12:00:00+03	106300.00
1A8E8B	2017-07-14 10:56:00+03	168100.00
1A8E9D	2017-08-02 17:18:00+03	75600.00
1A8EA4	2017-06-28 12:46:00+03	106800.00
1A8EF0	2017-07-05 05:37:00+03	36400.00
1A8F75	2017-08-09 05:57:00+03	23200.00
1A9030	2017-08-09 00:56:00+03	24400.00
1A9061	2017-08-08 05:01:00+03	84700.00
1A90BE	2017-07-11 12:18:00+03	111600.00
1A90F7	2017-07-11 20:09:00+03	54400.00
1A9184	2017-07-11 04:13:00+03	38800.00
1A91BA	2017-07-19 14:36:00+03	38600.00
1A91C5	2017-07-07 13:31:00+03	87100.00
1A9227	2017-07-28 00:23:00+03	116700.00
1A9275	2017-07-18 06:10:00+03	39000.00
1A929A	2017-07-10 22:04:00+03	144000.00
1A92AA	2017-07-09 01:25:00+03	46400.00
1A92C2	2017-07-29 05:22:00+03	112000.00
1A92CF	2017-07-06 00:37:00+03	21000.00
1A9394	2017-07-07 16:54:00+03	95600.00
1A9426	2017-07-26 02:27:00+03	28000.00
1A9469	2017-06-29 19:16:00+03	36200.00
1A9522	2017-07-20 00:23:00+03	85700.00
1A956A	2017-08-15 05:40:00+03	312000.00
1A9592	2017-07-02 00:20:00+03	41800.00
1A95B2	2017-07-25 13:07:00+03	23200.00
1A95D2	2017-08-06 16:35:00+03	111700.00
1A9602	2017-07-20 02:30:00+03	71600.00
1A9613	2017-08-01 06:46:00+03	35200.00
1A967C	2017-08-12 06:42:00+03	271400.00
1A96B3	2017-07-31 09:15:00+03	37900.00
1A973E	2017-07-21 21:44:00+03	81300.00
1A9779	2017-08-05 12:14:00+03	39500.00
1A977C	2017-08-09 12:48:00+03	46400.00
1A97BC	2017-08-14 00:14:00+03	116500.00
1A97C6	2017-07-16 01:18:00+03	46000.00
1A97E3	2017-08-13 02:15:00+03	46400.00
1A9872	2017-07-22 13:12:00+03	21700.00
1A989F	2017-07-29 14:36:00+03	521800.00
1A98A0	2017-07-19 15:08:00+03	81000.00
1A98AE	2017-07-09 02:29:00+03	51800.00
1A98DC	2017-07-06 18:49:00+03	29600.00
1A98E4	2017-07-19 18:01:00+03	168000.00
1A98F2	2017-07-26 01:12:00+03	49000.00
1A9907	2017-07-25 23:37:00+03	62600.00
1A9979	2017-07-06 00:56:00+03	63200.00
1A9A2D	2017-07-21 08:58:00+03	132800.00
1A9A3B	2017-08-09 04:00:00+03	133200.00
1A9A62	2017-07-16 13:07:00+03	109700.00
1A9AF3	2017-07-26 08:27:00+03	68000.00
1A9B81	2017-07-12 17:24:00+03	14000.00
1A9BDF	2017-08-01 17:44:00+03	193700.00
1A9C0E	2017-07-17 08:07:00+03	27600.00
1A9C56	2017-08-09 16:27:00+03	23900.00
1A9C5D	2017-07-20 13:15:00+03	94000.00
1A9C88	2017-08-06 16:52:00+03	111900.00
1A9CBB	2017-07-02 05:37:00+03	58400.00
1A9CCD	2017-08-08 18:23:00+03	54100.00
1A9D24	2017-07-24 06:46:00+03	62700.00
1A9D75	2017-06-30 21:20:00+03	20200.00
1A9E54	2017-08-07 05:29:00+03	92900.00
1A9E6C	2017-07-14 18:55:00+03	23200.00
1A9E78	2017-07-11 22:34:00+03	140300.00
1A9E8F	2017-07-16 06:11:00+03	73300.00
1A9EBD	2017-08-06 06:44:00+03	27200.00
1A9EED	2017-07-27 04:11:00+03	75300.00
1A9F25	2017-07-08 00:22:00+03	65900.00
1A9F83	2017-07-04 10:43:00+03	89600.00
1A9FC6	2017-08-12 06:52:00+03	46400.00
1A9FCE	2017-08-06 00:23:00+03	136800.00
1A9FF2	2017-08-02 16:40:00+03	96100.00
1AA00E	2017-07-16 19:29:00+03	73300.00
1AA02F	2017-07-24 15:21:00+03	68100.00
1AA06C	2017-07-17 23:41:00+03	12600.00
1AA071	2017-08-02 13:37:00+03	67200.00
1AA0BD	2017-07-05 18:19:00+03	68800.00
1AA0D6	2017-07-23 01:54:00+03	31600.00
1AA167	2017-08-05 06:32:00+03	24600.00
1AA174	2017-08-03 09:17:00+03	47200.00
1AA189	2017-07-20 19:17:00+03	101200.00
1AA197	2017-07-18 12:42:00+03	43100.00
1AA217	2017-07-30 04:36:00+03	65500.00
1AA242	2017-08-09 05:56:00+03	26200.00
1AA29F	2017-07-07 20:03:00+03	28000.00
1AA2D5	2017-07-24 23:18:00+03	57600.00
1AA2F0	2017-07-31 10:34:00+03	181100.00
1AA307	2017-08-04 17:51:00+03	65400.00
1AA33D	2017-07-08 18:48:00+03	68100.00
1AA363	2017-08-01 09:56:00+03	23400.00
1AA37C	2017-07-22 14:49:00+03	150600.00
1AA3E2	2017-07-07 18:36:00+03	6300.00
1AA42A	2017-08-05 19:40:00+03	46200.00
1AA46E	2017-08-11 12:08:00+03	28800.00
1AA4DC	2017-07-15 19:20:00+03	115800.00
1AA57D	2017-07-12 19:51:00+03	39900.00
1AA5A4	2017-08-15 06:29:00+03	73600.00
1AA5BF	2017-07-04 07:52:00+03	118100.00
1AA5D6	2017-07-06 19:16:00+03	64500.00
1AA601	2017-07-18 00:04:00+03	44600.00
1AA688	2017-07-05 21:43:00+03	70000.00
1AA810	2017-08-02 20:44:00+03	92000.00
1AA8B7	2017-07-02 05:09:00+03	99700.00
1AA8BE	2017-07-06 02:46:00+03	24000.00
1AA8FE	2017-07-05 13:39:00+03	146800.00
1AA906	2017-08-10 01:28:00+03	94000.00
1AA95B	2017-07-15 22:02:00+03	56000.00
1AA988	2017-07-09 04:39:00+03	29400.00
1AA9CD	2017-08-14 11:43:00+03	56600.00
1AA9E1	2017-07-15 08:25:00+03	65900.00
1AAA03	2017-06-29 18:50:00+03	88400.00
1AAA48	2017-07-30 02:03:00+03	133200.00
1AAA77	2017-07-19 00:56:00+03	28000.00
1AAA7F	2017-08-12 02:10:00+03	47600.00
1AAA8D	2017-08-03 02:43:00+03	73300.00
1AAB47	2017-08-04 04:58:00+03	40200.00
1AAB5B	2017-07-19 22:31:00+03	53600.00
1AAB5F	2017-07-17 07:51:00+03	31400.00
1AABC5	2017-07-06 11:58:00+03	16400.00
1AABF4	2017-07-01 20:50:00+03	38800.00
1AACE5	2017-07-02 12:25:00+03	18100.00
1AACFD	2017-07-18 18:43:00+03	22000.00
1AAD66	2017-08-14 14:39:00+03	57500.00
1AADD8	2017-08-09 18:37:00+03	56000.00
1AADDA	2017-07-30 16:56:00+03	12600.00
1AAE4C	2017-07-28 08:50:00+03	135400.00
1AAE58	2017-07-28 05:06:00+03	101200.00
1AAEBA	2017-07-08 08:30:00+03	9200.00
1AAEC2	2017-07-20 22:13:00+03	81200.00
1AAEF8	2017-07-26 18:47:00+03	46300.00
1AAF0E	2017-07-30 15:41:00+03	57500.00
1AAF51	2017-08-11 05:41:00+03	22000.00
1AAF56	2017-07-25 13:57:00+03	48800.00
1AAF9A	2017-07-22 03:55:00+03	406700.00
1AAFA1	2017-07-11 06:19:00+03	23200.00
1AAFB6	2017-08-01 16:32:00+03	66600.00
1AAFED	2017-07-15 05:21:00+03	48800.00
1AB014	2017-07-28 11:49:00+03	71200.00
1AB04B	2017-06-27 19:36:00+03	354400.00
1AB099	2017-07-09 15:22:00+03	29600.00
1AB0E3	2017-07-12 09:36:00+03	209700.00
1AB10A	2017-07-05 13:17:00+03	16400.00
1AB15E	2017-07-26 15:03:00+03	66900.00
1AB19B	2017-08-12 22:12:00+03	12000.00
1AB1A2	2017-08-04 09:15:00+03	25800.00
1AB1BC	2017-08-02 13:49:00+03	24300.00
1AB1C4	2017-06-28 02:01:00+03	6300.00
1AB1DC	2017-07-13 08:14:00+03	57400.00
1AB213	2017-07-27 01:30:00+03	189100.00
1AB218	2017-07-30 03:26:00+03	33100.00
1AB242	2017-07-22 20:32:00+03	57600.00
1AB2DB	2017-06-29 05:06:00+03	11600.00
1AB2E9	2017-07-16 10:01:00+03	111600.00
1AB2F8	2017-07-09 07:03:00+03	25900.00
1AB313	2017-07-19 22:51:00+03	87100.00
1AB369	2017-07-31 05:42:00+03	20000.00
1AB36A	2017-07-28 04:59:00+03	126700.00
1AB37D	2017-07-08 04:12:00+03	133200.00
1AB37F	2017-08-06 06:16:00+03	48800.00
1AB394	2017-08-12 00:45:00+03	38600.00
1AB413	2017-07-29 15:59:00+03	46200.00
1AB458	2017-08-13 12:28:00+03	36800.00
1AB471	2017-08-07 14:17:00+03	121400.00
1AB49D	2017-07-18 17:28:00+03	136500.00
1AB4AF	2017-07-18 05:09:00+03	4400.00
1AB4E8	2017-07-23 02:33:00+03	149600.00
1AB4FD	2017-07-04 17:25:00+03	21800.00
1AB500	2017-07-05 07:17:00+03	20600.00
1AB59A	2017-07-05 12:42:00+03	11800.00
1AB5AE	2017-07-10 14:41:00+03	41200.00
1AB5F4	2017-07-04 11:50:00+03	49100.00
1AB668	2017-07-19 11:59:00+03	213200.00
1AB6F7	2017-08-13 03:18:00+03	265800.00
1AB758	2017-08-15 06:35:00+03	61400.00
1AB789	2017-07-25 14:46:00+03	14400.00
1AB7E8	2017-07-07 14:58:00+03	174000.00
1AB897	2017-06-30 10:02:00+03	39500.00
1AB8BA	2017-07-08 16:06:00+03	139500.00
1AB8D0	2017-07-31 03:00:00+03	25900.00
1AB940	2017-08-14 13:57:00+03	176500.00
1AB949	2017-07-22 10:39:00+03	14800.00
1AB952	2017-07-24 23:27:00+03	55800.00
1AB981	2017-08-05 23:36:00+03	34000.00
1AB984	2017-07-28 00:09:00+03	16000.00
1ABA54	2017-08-04 23:48:00+03	89700.00
1ABC22	2017-07-01 18:18:00+03	56000.00
1ABC29	2017-07-25 21:50:00+03	43600.00
1ABC32	2017-07-11 02:13:00+03	27900.00
1ABC70	2017-08-11 18:22:00+03	49500.00
1ABCF9	2017-07-11 01:59:00+03	42400.00
1ABD54	2017-08-04 16:54:00+03	40000.00
1ABD87	2017-07-27 02:55:00+03	100600.00
1ABD92	2017-07-16 16:06:00+03	26800.00
1ABDC8	2017-07-14 08:55:00+03	48400.00
1ABE59	2017-07-28 01:22:00+03	61800.00
1ABE84	2017-07-23 03:36:00+03	214000.00
1ABEB9	2017-06-29 14:59:00+03	57600.00
1ABEC7	2017-07-23 11:58:00+03	38400.00
1ABEEC	2017-07-29 02:20:00+03	77200.00
1ABEF5	2017-07-26 12:53:00+03	92100.00
1ABF63	2017-07-18 16:04:00+03	13400.00
1AC027	2017-06-30 14:10:00+03	38400.00
1AC087	2017-07-21 22:07:00+03	68800.00
1AC088	2017-07-24 08:21:00+03	21800.00
1AC094	2017-08-02 01:08:00+03	53600.00
1AC0D1	2017-07-28 02:06:00+03	57500.00
1AC108	2017-07-06 23:37:00+03	46400.00
1AC16D	2017-08-07 11:54:00+03	54800.00
1AC173	2017-06-29 13:06:00+03	36200.00
1AC17A	2017-07-03 14:37:00+03	27900.00
1AC1F3	2017-07-26 01:52:00+03	213200.00
1AC224	2017-07-31 13:37:00+03	337600.00
1AC26E	2017-07-03 07:45:00+03	118000.00
1AC2CB	2017-06-27 02:34:00+03	32800.00
1AC2FB	2017-07-02 03:42:00+03	73300.00
1AC386	2017-07-09 23:24:00+03	16400.00
1AC3D9	2017-07-06 05:14:00+03	112000.00
1AC3DE	2017-07-02 17:33:00+03	17800.00
1AC3E0	2017-07-26 05:54:00+03	42700.00
1AC447	2017-07-23 11:09:00+03	94000.00
1AC473	2017-07-19 13:17:00+03	10600.00
1AC50E	2017-07-15 22:17:00+03	62600.00
1AC525	2017-08-09 01:19:00+03	77200.00
1AC57D	2017-07-11 02:18:00+03	48400.00
1AC58D	2017-07-30 01:39:00+03	257500.00
1AC59B	2017-08-08 15:52:00+03	23200.00
1AC5C2	2017-07-31 09:14:00+03	184300.00
1AC5D7	2017-08-01 12:41:00+03	26800.00
1AC5F2	2017-07-17 13:11:00+03	37200.00
1AC652	2017-07-27 07:36:00+03	54800.00
1AC6C8	2017-08-08 16:32:00+03	58900.00
1AC744	2017-08-06 05:04:00+03	52300.00
1AC806	2017-08-11 08:26:00+03	119600.00
1AC81F	2017-07-12 04:12:00+03	131600.00
1AC834	2017-08-04 00:15:00+03	41900.00
1AC87A	2017-08-13 04:59:00+03	92700.00
1AC886	2017-07-16 12:28:00+03	52300.00
1AC914	2017-08-11 21:04:00+03	74800.00
1AC959	2017-07-28 10:44:00+03	55800.00
1AC963	2017-07-19 16:26:00+03	29400.00
1AC96E	2017-07-31 08:38:00+03	37900.00
1AC976	2017-08-11 14:06:00+03	69500.00
1AC980	2017-07-14 09:24:00+03	385600.00
1AC98F	2017-08-12 09:52:00+03	246000.00
1ACA12	2017-07-09 10:58:00+03	28000.00
1ACA1F	2017-07-28 03:14:00+03	47000.00
1ACAB3	2017-07-13 12:34:00+03	141700.00
1ACB04	2017-08-11 09:20:00+03	131100.00
1ACB54	2017-07-07 17:10:00+03	12600.00
1ACB89	2017-07-28 21:52:00+03	56600.00
1ACBE4	2017-08-13 18:34:00+03	48600.00
1ACBEB	2017-07-10 19:00:00+03	102100.00
1ACBF0	2017-07-22 07:25:00+03	288600.00
1ACC55	2017-08-13 12:23:00+03	132800.00
1ACCBF	2017-07-30 19:52:00+03	16800.00
1ACD07	2017-07-30 08:03:00+03	51100.00
1ACD10	2017-07-22 21:32:00+03	28000.00
1ACDC4	2017-07-06 04:37:00+03	40800.00
1ACE6C	2017-07-28 21:10:00+03	40000.00
1ACEB3	2017-08-05 05:42:00+03	55800.00
1ACEC0	2017-08-03 08:30:00+03	151200.00
1ACEE0	2017-08-08 05:01:00+03	31600.00
1ACEF8	2017-07-26 09:52:00+03	42400.00
1ACF11	2017-07-05 17:19:00+03	58800.00
1ACF22	2017-08-06 06:50:00+03	26000.00
1ACF2B	2017-08-04 03:18:00+03	28800.00
1ACF37	2017-07-06 18:44:00+03	56000.00
1ACF73	2017-08-04 00:51:00+03	32700.00
1ACFCB	2017-08-11 18:32:00+03	83000.00
1ACFD6	2017-06-30 20:02:00+03	56000.00
1ACFDB	2017-07-26 15:39:00+03	88600.00
1ACFF9	2017-07-25 07:47:00+03	64700.00
1AD00B	2017-07-30 07:45:00+03	58600.00
1AD0FF	2017-07-19 16:56:00+03	28800.00
1AD12F	2017-07-16 00:08:00+03	239300.00
1AD190	2017-07-01 13:53:00+03	16400.00
1AD1AA	2017-08-13 13:54:00+03	51900.00
1AD24A	2017-08-08 09:03:00+03	100600.00
1AD28B	2017-08-06 18:23:00+03	27800.00
1AD2C0	2017-07-05 10:05:00+03	14800.00
1AD308	2017-06-30 23:38:00+03	56600.00
1AD3ED	2017-07-14 05:47:00+03	50600.00
1AD4E9	2017-07-15 16:19:00+03	24800.00
1AD531	2017-07-23 17:08:00+03	86800.00
1AD57A	2017-07-31 11:01:00+03	19200.00
1AD5C7	2017-07-16 14:29:00+03	28000.00
1AD647	2017-08-13 23:17:00+03	189200.00
1AD649	2017-08-06 21:44:00+03	50400.00
1AD66F	2017-07-10 15:39:00+03	26000.00
1AD720	2017-07-09 18:33:00+03	80400.00
1AD739	2017-07-13 17:25:00+03	291000.00
1AD74E	2017-07-24 16:12:00+03	14400.00
1AD757	2017-06-30 11:45:00+03	48600.00
1AD76D	2017-07-14 12:46:00+03	44600.00
1AD78B	2017-07-02 23:40:00+03	88900.00
1AD7A3	2017-07-22 21:13:00+03	96800.00
1AD803	2017-07-14 02:44:00+03	28800.00
1AD82F	2017-07-03 03:33:00+03	31800.00
1AD924	2017-07-12 10:22:00+03	37200.00
1AD92E	2017-07-30 14:52:00+03	34200.00
1AD95A	2017-07-16 18:20:00+03	369000.00
1AD98A	2017-07-09 06:04:00+03	42400.00
1AD9BC	2017-07-22 15:17:00+03	12400.00
1AD9E3	2017-07-25 06:21:00+03	45800.00
1ADA1D	2017-07-28 08:39:00+03	58800.00
1ADA4A	2017-07-13 08:32:00+03	38800.00
1ADB0B	2017-07-16 04:17:00+03	67600.00
1ADB1E	2017-07-07 13:49:00+03	39300.00
1ADB43	2017-08-06 10:40:00+03	135400.00
1ADB6E	2017-08-15 02:12:00+03	59800.00
1ADB90	2017-08-11 11:13:00+03	135600.00
1ADBC5	2017-07-08 13:48:00+03	37100.00
1ADBF3	2017-07-17 08:07:00+03	492000.00
1ADC0F	2017-07-11 23:33:00+03	23200.00
1ADC12	2017-07-31 23:03:00+03	13600.00
1ADC15	2017-07-07 04:21:00+03	60400.00
1ADC2E	2017-07-01 04:59:00+03	112400.00
1ADC3D	2017-08-12 04:46:00+03	200400.00
1ADC5F	2017-07-20 23:43:00+03	50700.00
1ADCA4	2017-08-01 22:07:00+03	66600.00
1ADCAF	2017-07-17 10:40:00+03	223200.00
1ADCBA	2017-08-08 06:47:00+03	56000.00
1ADCEA	2017-07-27 04:03:00+03	112000.00
1ADE14	2017-07-21 08:53:00+03	14400.00
1ADE2B	2017-07-24 14:54:00+03	114800.00
1ADE84	2017-07-04 03:36:00+03	46200.00
1ADEA4	2017-07-19 19:40:00+03	20200.00
1ADF04	2017-07-05 19:38:00+03	28000.00
1ADF39	2017-07-09 09:04:00+03	18000.00
1ADF7A	2017-07-19 02:35:00+03	24400.00
1ADF9A	2017-07-19 18:12:00+03	116400.00
1AE052	2017-07-22 10:26:00+03	40000.00
1AE0A5	2017-07-21 19:04:00+03	46400.00
1AE153	2017-07-23 10:15:00+03	58600.00
1AE1F7	2017-07-17 09:39:00+03	28000.00
1AE222	2017-07-23 19:47:00+03	88900.00
1AE283	2017-06-30 20:17:00+03	26000.00
1AE2D0	2017-07-29 10:50:00+03	18700.00
1AE2DE	2017-08-04 18:44:00+03	95200.00
1AE356	2017-07-09 14:41:00+03	86500.00
1AE390	2017-07-19 20:52:00+03	26800.00
1AE39D	2017-07-24 23:34:00+03	26000.00
1AE3CB	2017-07-31 03:01:00+03	29600.00
1AE430	2017-07-14 00:42:00+03	36200.00
1AE45D	2017-07-22 14:03:00+03	50200.00
1AE489	2017-07-10 12:14:00+03	12800.00
1AE4AA	2017-07-25 14:35:00+03	47100.00
1AE4B1	2017-07-07 13:53:00+03	33300.00
1AE4DA	2017-07-21 19:04:00+03	65900.00
1AE502	2017-07-27 23:03:00+03	138900.00
1AE518	2017-07-06 09:06:00+03	22400.00
1AE58B	2017-07-27 02:34:00+03	133200.00
1AE663	2017-07-04 13:02:00+03	214900.00
1AE672	2017-07-01 22:46:00+03	188500.00
1AE6CD	2017-07-03 09:50:00+03	6800.00
1AE6D4	2017-07-13 09:02:00+03	24400.00
1AE703	2017-07-09 12:44:00+03	25400.00
1AE705	2017-07-09 03:41:00+03	56900.00
1AE71E	2017-07-13 06:12:00+03	202000.00
1AE74E	2017-07-09 07:11:00+03	23200.00
1AE7A0	2017-07-09 17:23:00+03	26200.00
1AE7AD	2017-07-18 13:31:00+03	61400.00
1AE7AE	2017-07-11 13:16:00+03	56000.00
1AE7FB	2017-07-11 11:14:00+03	55800.00
1AE823	2017-08-13 03:58:00+03	72800.00
1AE869	2017-06-29 13:39:00+03	59000.00
1AE87D	2017-08-11 08:20:00+03	134400.00
1AE8DF	2017-07-27 16:16:00+03	28000.00
1AE93C	2017-07-28 07:17:00+03	112000.00
1AE95D	2017-07-31 03:02:00+03	49300.00
1AE961	2017-08-01 23:00:00+03	66600.00
1AE9BA	2017-08-06 07:19:00+03	7400.00
1AE9BE	2017-07-23 09:38:00+03	670000.00
1AEA14	2017-08-10 07:29:00+03	28800.00
1AEA22	2017-08-04 14:31:00+03	67900.00
1AEA81	2017-07-27 04:42:00+03	157400.00
1AEA9C	2017-07-21 12:37:00+03	56000.00
1AEAB6	2017-07-30 08:13:00+03	87000.00
1AEB0F	2017-07-27 18:07:00+03	13400.00
1AEC3D	2017-08-13 08:24:00+03	23400.00
1AEC75	2017-08-10 13:11:00+03	21200.00
1AEC90	2017-08-14 20:13:00+03	58400.00
1AEC9F	2017-08-12 14:23:00+03	168200.00
1AECF4	2017-07-12 07:35:00+03	246000.00
1AED11	2017-07-14 19:26:00+03	47500.00
1AED26	2017-07-24 19:51:00+03	22600.00
1AEDB9	2017-07-10 10:49:00+03	47100.00
1AEDCD	2017-07-30 23:29:00+03	58800.00
1AEE6B	2017-08-08 14:40:00+03	28000.00
1AEE7D	2017-08-11 10:18:00+03	70400.00
1AEEBA	2017-08-06 14:02:00+03	55800.00
1AEEC8	2017-07-07 11:53:00+03	155600.00
1AEF61	2017-07-10 09:08:00+03	25600.00
1AEF98	2017-08-03 11:15:00+03	14000.00
1AEFB6	2017-07-15 22:10:00+03	42800.00
1AEFBC	2017-07-28 18:01:00+03	67200.00
1AEFDB	2017-07-24 14:04:00+03	46400.00
1AF01E	2017-08-08 21:26:00+03	46300.00
1AF042	2017-07-07 17:20:00+03	23400.00
1AF088	2017-08-07 14:22:00+03	75300.00
1AF0A5	2017-07-27 16:56:00+03	68400.00
1AF198	2017-08-05 17:37:00+03	27900.00
1AF1E9	2017-07-18 07:13:00+03	185700.00
1AF212	2017-07-13 05:04:00+03	111000.00
1AF226	2017-08-04 15:49:00+03	615000.00
1AF231	2017-07-16 06:12:00+03	55800.00
1AF239	2017-08-11 11:11:00+03	292600.00
1AF246	2017-07-03 21:09:00+03	393800.00
1AF279	2017-08-12 00:39:00+03	36200.00
1AF27C	2017-07-11 03:01:00+03	13400.00
1AF296	2017-07-31 07:58:00+03	69000.00
1AF2AA	2017-07-22 10:05:00+03	246000.00
1AF316	2017-07-31 12:37:00+03	59200.00
1AF342	2017-08-11 13:51:00+03	41200.00
1AF38A	2017-08-11 20:27:00+03	30600.00
1AF438	2017-08-01 16:23:00+03	35200.00
1AF46A	2017-07-24 11:39:00+03	29200.00
1AF497	2017-07-12 09:27:00+03	12600.00
1AF529	2017-08-12 07:18:00+03	231900.00
1AF540	2017-07-16 00:33:00+03	52800.00
1AF564	2017-07-21 10:34:00+03	196000.00
1AF594	2017-08-08 20:55:00+03	70600.00
1AF5E0	2017-07-23 07:01:00+03	266400.00
1AF5E5	2017-07-12 17:17:00+03	39800.00
1AF658	2017-08-15 01:53:00+03	29100.00
1AF662	2017-06-28 23:18:00+03	81700.00
1AF68D	2017-07-26 12:35:00+03	20100.00
1AF70C	2017-07-23 08:50:00+03	65500.00
1AF733	2017-07-09 04:02:00+03	44800.00
1AF7C0	2017-08-15 05:05:00+03	134600.00
1AF7C4	2017-07-15 09:28:00+03	54500.00
1AF814	2017-08-04 08:38:00+03	87000.00
1AF832	2017-07-12 22:24:00+03	61800.00
1AF845	2017-07-20 12:12:00+03	89600.00
1AF859	2017-07-10 17:01:00+03	496000.00
1AF862	2017-07-08 22:06:00+03	106100.00
1AF887	2017-07-06 03:22:00+03	306600.00
1AF8E6	2017-08-05 04:28:00+03	123000.00
1AF8E8	2017-07-06 21:18:00+03	19600.00
1AF935	2017-08-07 13:06:00+03	149300.00
1AF9A2	2017-07-17 04:51:00+03	34000.00
1AF9E8	2017-08-14 21:25:00+03	37200.00
1AF9FE	2017-07-16 00:42:00+03	21200.00
1AFA16	2017-08-04 19:12:00+03	62700.00
1AFA33	2017-07-15 15:56:00+03	182300.00
1AFA8D	2017-07-10 05:20:00+03	13400.00
1AFB6D	2017-08-10 23:56:00+03	37200.00
1AFBA7	2017-07-17 03:10:00+03	28000.00
1AFBD8	2017-07-28 04:09:00+03	112000.00
1AFBEB	2017-07-20 19:57:00+03	82700.00
1AFC18	2017-07-09 22:57:00+03	46200.00
1AFC3F	2017-08-01 22:22:00+03	85000.00
1AFC54	2017-08-13 12:37:00+03	104200.00
1AFCA8	2017-08-14 09:57:00+03	81700.00
1AFCBC	2017-08-10 02:37:00+03	80700.00
1AFCDA	2017-07-10 23:58:00+03	33800.00
1AFCDB	2017-08-05 16:48:00+03	114800.00
1AFD6C	2017-07-13 18:00:00+03	24400.00
1AFDB0	2017-08-07 14:26:00+03	38800.00
1AFDE1	2017-07-28 02:13:00+03	111100.00
1AFE1F	2017-07-01 14:29:00+03	111700.00
1AFE46	2017-08-01 18:35:00+03	13400.00
1AFEAF	2017-07-29 18:20:00+03	65500.00
1AFEF3	2017-08-03 23:00:00+03	8000.00
1AFF60	2017-07-10 04:21:00+03	28700.00
1AFF67	2017-08-04 12:29:00+03	289900.00
1AFF6D	2017-07-18 20:56:00+03	136200.00
1AFF73	2017-07-18 23:09:00+03	32800.00
1AFF98	2017-07-15 16:45:00+03	45200.00
1B00A6	2017-07-31 01:54:00+03	114000.00
1B00CC	2017-07-28 20:35:00+03	23200.00
1B012D	2017-08-01 21:51:00+03	67700.00
1B0197	2017-08-03 03:32:00+03	85600.00
1B01B5	2017-07-12 20:18:00+03	409100.00
1B0225	2017-07-07 13:50:00+03	84800.00
1B0293	2017-07-02 13:24:00+03	56600.00
1B02BC	2017-07-29 20:59:00+03	26800.00
1B02DA	2017-07-27 01:08:00+03	68800.00
1B02FF	2017-07-10 22:39:00+03	16400.00
1B036E	2017-08-09 10:39:00+03	15000.00
1B0508	2017-07-13 11:09:00+03	47700.00
1B052A	2017-08-04 22:59:00+03	56100.00
1B055C	2017-07-24 13:33:00+03	198600.00
1B0574	2017-07-27 23:06:00+03	43000.00
1B05D6	2017-08-11 15:37:00+03	72400.00
1B0621	2017-07-01 05:34:00+03	61800.00
1B0629	2017-07-09 15:14:00+03	213800.00
1B0657	2017-07-26 23:12:00+03	27200.00
1B0687	2017-08-14 10:35:00+03	130100.00
1B0690	2017-07-18 20:17:00+03	664200.00
1B06BC	2017-07-28 23:32:00+03	16400.00
1B06D8	2017-07-05 11:16:00+03	28000.00
1B06F5	2017-08-07 07:00:00+03	40000.00
1B0709	2017-08-12 13:11:00+03	61800.00
1B0742	2017-07-30 16:31:00+03	67600.00
1B0804	2017-08-13 01:52:00+03	86300.00
1B08AA	2017-07-16 17:16:00+03	147100.00
1B08B7	2017-07-22 03:49:00+03	95200.00
1B08D8	2017-08-09 06:54:00+03	41600.00
1B08DF	2017-08-14 09:12:00+03	21200.00
1B0924	2017-08-08 18:46:00+03	56600.00
1B0974	2017-07-05 19:42:00+03	6700.00
1B09DB	2017-07-30 16:59:00+03	127000.00
1B0B7D	2017-08-15 15:13:00+03	266400.00
1B0BE0	2017-07-11 14:03:00+03	108000.00
1B0BF2	2017-07-27 16:16:00+03	199700.00
1B0BFD	2017-06-28 02:25:00+03	47400.00
1B0C43	2017-08-08 15:36:00+03	32700.00
1B0C9C	2017-07-18 13:50:00+03	57500.00
1B0CEE	2017-07-15 22:07:00+03	31600.00
1B0D02	2017-07-28 07:34:00+03	13400.00
1B0D09	2017-07-31 02:27:00+03	80900.00
1B0D3C	2017-07-15 14:16:00+03	112000.00
1B0D5E	2017-07-17 06:29:00+03	6000.00
1B0D98	2017-07-10 15:51:00+03	155100.00
1B0D9D	2017-08-11 09:43:00+03	107800.00
1B0E3D	2017-07-13 00:56:00+03	29600.00
1B0E6F	2017-07-23 23:51:00+03	57800.00
1B0E8C	2017-07-28 03:04:00+03	31200.00
1B0E9E	2017-07-11 07:53:00+03	141600.00
1B0EC0	2017-07-13 18:41:00+03	32800.00
1B0EE8	2017-08-15 07:39:00+03	57400.00
1B0F00	2017-07-17 20:41:00+03	34800.00
1B0F53	2017-07-13 22:29:00+03	120900.00
1B1010	2017-07-02 00:42:00+03	33100.00
1B1094	2017-08-13 18:11:00+03	12000.00
1B10D6	2017-07-01 08:12:00+03	52400.00
1B1140	2017-07-10 21:48:00+03	43900.00
1B11A7	2017-07-16 04:14:00+03	65100.00
1B11F5	2017-07-14 14:34:00+03	56600.00
1B122E	2017-07-13 14:18:00+03	248400.00
1B129F	2017-08-07 07:05:00+03	30400.00
1B1303	2017-08-08 11:55:00+03	32200.00
1B1315	2017-07-27 08:22:00+03	17000.00
1B135E	2017-07-05 18:19:00+03	102100.00
1B136B	2017-07-13 04:52:00+03	23600.00
1B1401	2017-07-27 07:35:00+03	92800.00
1B1406	2017-08-12 13:27:00+03	12600.00
1B142F	2017-07-25 11:32:00+03	29800.00
1B1432	2017-07-15 16:08:00+03	24400.00
1B144E	2017-07-15 08:28:00+03	177200.00
1B1494	2017-06-27 07:44:00+03	16400.00
1B14F9	2017-06-30 18:53:00+03	128800.00
1B1507	2017-07-15 07:33:00+03	27200.00
1B154A	2017-08-10 10:26:00+03	49500.00
1B1595	2017-08-14 13:54:00+03	14000.00
1B15BE	2017-07-25 13:26:00+03	89600.00
1B15D5	2017-07-19 15:37:00+03	53600.00
1B15DF	2017-08-11 04:45:00+03	22100.00
1B1610	2017-07-19 18:07:00+03	128800.00
1B163C	2017-08-01 19:02:00+03	50600.00
1B1687	2017-08-12 17:30:00+03	15000.00
1B1731	2017-08-08 16:34:00+03	12000.00
1B1740	2017-07-13 17:32:00+03	103700.00
1B1747	2017-07-21 00:15:00+03	25600.00
1B1771	2017-07-17 14:28:00+03	22400.00
1B17DD	2017-08-15 10:26:00+03	265800.00
1B17E7	2017-07-16 16:44:00+03	173500.00
1B1809	2017-07-14 17:32:00+03	201800.00
1B185D	2017-08-05 04:45:00+03	56900.00
1B186A	2017-08-12 02:37:00+03	27400.00
1B1879	2017-08-09 19:44:00+03	93900.00
1B18A7	2017-07-16 00:52:00+03	6800.00
1B1930	2017-08-12 07:50:00+03	66600.00
1B19F5	2017-07-28 16:03:00+03	61800.00
1B1A1F	2017-08-01 11:22:00+03	11600.00
1B1A39	2017-07-17 01:58:00+03	14700.00
1B1A49	2017-07-26 00:11:00+03	6300.00
1B1A61	2017-07-18 07:11:00+03	13600.00
1B1A90	2017-07-14 07:38:00+03	24400.00
1B1B02	2017-08-05 04:40:00+03	52100.00
1B1B40	2017-08-03 16:20:00+03	46000.00
1B1B67	2017-06-29 08:47:00+03	14800.00
1B1BA5	2017-06-29 16:36:00+03	56000.00
1B1BB2	2017-07-21 23:38:00+03	148200.00
1B1BC8	2017-07-13 18:35:00+03	23200.00
1B1BFD	2017-08-08 17:39:00+03	112000.00
1B1C13	2017-07-30 17:36:00+03	16400.00
1B1C4A	2017-07-27 05:31:00+03	28800.00
1B1CC9	2017-08-06 01:47:00+03	106900.00
1B1D21	2017-08-10 12:58:00+03	20400.00
1B1D43	2017-08-12 04:50:00+03	331200.00
1B1D58	2017-07-02 01:28:00+03	56000.00
1B1D5B	2017-07-11 13:37:00+03	38600.00
1B1DEA	2017-07-01 13:51:00+03	28800.00
1B1DFC	2017-07-10 12:49:00+03	193500.00
1B1E04	2017-08-13 03:38:00+03	166000.00
1B1E31	2017-07-01 10:48:00+03	88000.00
1B1E59	2017-08-05 23:37:00+03	89200.00
1B1E69	2017-08-14 23:45:00+03	23600.00
1B1E89	2017-08-06 15:19:00+03	56000.00
1B1EE5	2017-07-11 14:33:00+03	153600.00
1B1EFC	2017-07-30 12:47:00+03	40600.00
1B1F1D	2017-08-15 14:26:00+03	32800.00
1B1F20	2017-08-13 19:38:00+03	97700.00
1B1F55	2017-07-17 23:26:00+03	54400.00
1B1F75	2017-08-02 14:25:00+03	212500.00
1B1FCC	2017-07-25 21:24:00+03	197200.00
1B200F	2017-07-12 20:53:00+03	172100.00
1B204D	2017-08-10 23:57:00+03	84000.00
1B207D	2017-07-11 14:03:00+03	111600.00
1B20A3	2017-08-02 23:04:00+03	24400.00
1B20C7	2017-08-12 06:39:00+03	15100.00
1B210A	2017-07-17 20:11:00+03	38200.00
1B210E	2017-07-10 05:47:00+03	166100.00
1B2124	2017-08-09 08:17:00+03	35700.00
1B2146	2017-07-23 02:56:00+03	199600.00
1B21E7	2017-07-31 04:46:00+03	23200.00
1B22E1	2017-07-03 06:57:00+03	26700.00
1B230C	2017-07-22 01:42:00+03	48500.00
1B231A	2017-08-11 12:06:00+03	86400.00
1B23AB	2017-07-12 18:01:00+03	11800.00
1B23AE	2017-07-20 23:14:00+03	200300.00
1B23B0	2017-07-28 09:43:00+03	57400.00
1B23E4	2017-08-06 00:44:00+03	188800.00
1B2448	2017-06-28 14:33:00+03	103600.00
1B246B	2017-08-03 06:16:00+03	92600.00
1B247C	2017-08-06 07:57:00+03	484400.00
1B2498	2017-07-12 00:54:00+03	23200.00
1B24A0	2017-07-18 22:59:00+03	54000.00
1B24C1	2017-07-15 10:46:00+03	40800.00
1B24C8	2017-08-10 11:16:00+03	37900.00
1B24DF	2017-07-21 23:19:00+03	58000.00
1B24EC	2017-07-17 22:24:00+03	28800.00
1B253E	2017-07-16 09:00:00+03	12200.00
1B254C	2017-08-14 09:50:00+03	42700.00
1B2566	2017-08-04 16:10:00+03	193600.00
1B25B0	2017-07-07 02:05:00+03	23600.00
1B2607	2017-07-09 15:25:00+03	24400.00
1B262C	2017-07-28 07:46:00+03	258400.00
1B264A	2017-08-04 09:37:00+03	35600.00
1B26B8	2017-07-14 00:30:00+03	31500.00
1B26C7	2017-07-08 06:39:00+03	24300.00
1B2739	2017-07-09 05:33:00+03	56000.00
1B2769	2017-08-10 10:12:00+03	59600.00
1B27CB	2017-08-13 07:02:00+03	214200.00
1B285D	2017-07-25 23:53:00+03	84800.00
1B28A3	2017-07-22 07:38:00+03	168000.00
1B28D0	2017-08-15 10:53:00+03	6700.00
1B2954	2017-08-05 17:55:00+03	23600.00
1B298E	2017-07-26 22:35:00+03	244800.00
1B2A11	2017-08-03 11:50:00+03	28800.00
1B2A1B	2017-08-11 06:39:00+03	100600.00
1B2A24	2017-08-07 12:21:00+03	38800.00
1B2A31	2017-07-07 10:34:00+03	23600.00
1B2A62	2017-07-09 21:43:00+03	23600.00
1B2A6E	2017-07-11 05:08:00+03	62600.00
1B2A7F	2017-07-30 02:16:00+03	92000.00
1B2AC3	2017-08-12 07:27:00+03	49500.00
1B2AE5	2017-06-30 17:21:00+03	138000.00
1B2AF6	2017-08-04 23:04:00+03	92700.00
1B2AFA	2017-08-03 10:58:00+03	40400.00
1B2B0C	2017-07-18 15:33:00+03	40600.00
1B2B1C	2017-07-25 20:53:00+03	136200.00
1B2B73	2017-07-09 13:26:00+03	11300.00
1B2B9C	2017-07-13 15:16:00+03	67600.00
1B2C43	2017-08-03 16:21:00+03	64500.00
1B2C4E	2017-07-17 14:51:00+03	119400.00
1B2C9C	2017-07-03 20:06:00+03	59800.00
1B2C9F	2017-08-05 23:37:00+03	98400.00
1B2DE5	2017-08-12 09:51:00+03	18800.00
1B2E2B	2017-08-05 03:22:00+03	81700.00
1B2E6D	2017-08-04 14:02:00+03	46000.00
1B2E87	2017-07-14 16:50:00+03	62600.00
1B2EAC	2017-07-19 18:01:00+03	85000.00
1B2EB2	2017-07-08 04:15:00+03	64200.00
1B2F50	2017-07-09 17:29:00+03	28000.00
1B2FB1	2017-07-02 05:38:00+03	21000.00
1B2FB5	2017-07-11 15:52:00+03	78100.00
1B2FFF	2017-07-23 16:29:00+03	53400.00
1B301B	2017-07-17 02:03:00+03	51900.00
1B304F	2017-07-18 17:00:00+03	36200.00
1B309E	2017-08-05 16:03:00+03	23600.00
1B30DB	2017-07-30 22:39:00+03	67800.00
1B30E4	2017-07-25 23:18:00+03	124200.00
1B3105	2017-08-04 23:25:00+03	99300.00
1B3137	2017-07-29 11:13:00+03	6000.00
1B314B	2017-07-14 12:04:00+03	58400.00
1B31A5	2017-08-06 16:42:00+03	6700.00
1B31CF	2017-08-04 17:37:00+03	23600.00
1B31FB	2017-08-08 07:40:00+03	144400.00
1B3248	2017-08-06 13:04:00+03	28000.00
1B3376	2017-08-08 16:58:00+03	78300.00
1B33A0	2017-07-17 19:58:00+03	25600.00
1B3417	2017-07-08 13:08:00+03	27200.00
1B344B	2017-08-09 22:53:00+03	73600.00
1B34DF	2017-08-03 15:03:00+03	146000.00
1B3532	2017-08-05 01:55:00+03	95600.00
1B3535	2017-07-10 02:12:00+03	201800.00
1B359B	2017-08-10 10:46:00+03	43500.00
1B35CA	2017-06-26 01:15:00+03	24400.00
1B35E3	2017-07-09 16:57:00+03	12600.00
1B362D	2017-07-04 19:52:00+03	25400.00
1B368F	2017-07-15 08:40:00+03	313100.00
1B36B6	2017-07-16 00:49:00+03	6300.00
1B36D4	2017-07-18 14:55:00+03	48800.00
1B36F2	2017-08-07 08:22:00+03	70600.00
1B3740	2017-08-04 09:17:00+03	36200.00
1B375A	2017-08-06 15:43:00+03	94700.00
1B3769	2017-08-04 15:32:00+03	37000.00
1B37D4	2017-07-08 14:12:00+03	37200.00
1B382C	2017-07-29 06:02:00+03	57500.00
1B3830	2017-07-28 14:29:00+03	49800.00
1B3867	2017-07-25 17:47:00+03	144400.00
1B3885	2017-07-09 03:37:00+03	23200.00
1B3893	2017-08-03 15:08:00+03	76600.00
1B38AA	2017-07-08 16:13:00+03	56100.00
1B38FC	2017-07-05 22:36:00+03	141200.00
1B3948	2017-07-11 23:14:00+03	57800.00
1B39B3	2017-07-31 19:39:00+03	37900.00
1B39C3	2017-07-17 12:33:00+03	56000.00
1B39CA	2017-08-09 23:02:00+03	52400.00
1B3A34	2017-07-19 10:12:00+03	51900.00
1B3A8F	2017-07-16 11:09:00+03	52300.00
1B3A9D	2017-08-15 11:06:00+03	133100.00
1B3AAF	2017-08-05 22:27:00+03	26800.00
1B3ACB	2017-07-04 09:20:00+03	27900.00
1B3AD4	2017-07-04 14:57:00+03	36200.00
1B3B2C	2017-07-08 16:24:00+03	74100.00
1B3B61	2017-07-29 06:19:00+03	26000.00
1B3BEF	2017-07-11 09:33:00+03	82900.00
1B3C34	2017-07-10 11:06:00+03	86400.00
1B3C3D	2017-07-11 23:15:00+03	135400.00
1B3C42	2017-08-08 21:07:00+03	168000.00
1B3DA1	2017-07-04 03:43:00+03	30000.00
1B3E07	2017-08-10 06:23:00+03	47400.00
1B3E15	2017-07-06 01:22:00+03	47400.00
1B3E55	2017-07-14 07:46:00+03	7800.00
1B3E61	2017-08-01 04:25:00+03	87000.00
1B3E9B	2017-08-07 06:09:00+03	101100.00
1B3EAB	2017-07-22 13:45:00+03	28000.00
1B3EB9	2017-07-24 02:05:00+03	29600.00
1B3ED9	2017-07-26 03:55:00+03	62000.00
1B4019	2017-07-13 17:30:00+03	36200.00
1B40BB	2017-06-29 16:43:00+03	199700.00
1B40F5	2017-07-31 17:10:00+03	117600.00
1B41D9	2017-07-07 22:34:00+03	65500.00
1B4253	2017-08-14 01:55:00+03	260900.00
1B425E	2017-07-18 02:29:00+03	26700.00
1B426D	2017-07-11 20:09:00+03	26000.00
1B4291	2017-08-01 04:22:00+03	55800.00
1B42BE	2017-07-02 05:40:00+03	173800.00
1B42DF	2017-07-18 13:16:00+03	43300.00
1B43DA	2017-07-12 22:37:00+03	16400.00
1B447D	2017-07-23 01:35:00+03	137600.00
1B4483	2017-07-04 00:44:00+03	24800.00
1B44BD	2017-07-10 11:47:00+03	6600.00
1B4500	2017-07-27 08:15:00+03	67900.00
1B45B0	2017-08-03 20:58:00+03	116000.00
1B45BD	2017-08-09 11:33:00+03	98400.00
1B45D3	2017-07-02 23:20:00+03	52000.00
1B4632	2017-07-03 07:38:00+03	180700.00
1B466F	2017-08-12 04:00:00+03	70200.00
1B468F	2017-08-01 21:39:00+03	62600.00
1B46AA	2017-07-07 17:33:00+03	94200.00
1B4764	2017-08-03 04:01:00+03	50600.00
1B478B	2017-07-03 04:17:00+03	112600.00
1B47A7	2017-08-07 06:36:00+03	224000.00
1B47DD	2017-07-19 19:11:00+03	166100.00
1B48AD	2017-07-02 06:13:00+03	14400.00
1B494A	2017-07-04 04:10:00+03	95300.00
1B4967	2017-07-09 11:23:00+03	23200.00
1B498A	2017-08-11 08:41:00+03	52000.00
1B499B	2017-06-29 21:06:00+03	64700.00
1B49E3	2017-08-01 13:08:00+03	9200.00
1B4A75	2017-06-29 08:17:00+03	66600.00
1B4B68	2017-07-09 02:58:00+03	55800.00
1B4BA8	2017-07-30 14:37:00+03	8200.00
1B4C55	2017-07-19 09:57:00+03	28000.00
1B4C6B	2017-07-27 07:19:00+03	12000.00
1B4D12	2017-08-10 23:13:00+03	21400.00
1B4E20	2017-08-07 02:53:00+03	133600.00
1B4E69	2017-07-26 00:56:00+03	89200.00
1B4E82	2017-08-12 18:09:00+03	43500.00
1B4EBA	2017-08-12 02:36:00+03	31600.00
1B4EF6	2017-07-04 09:46:00+03	59000.00
1B4F50	2017-07-16 08:25:00+03	114700.00
1B4FB2	2017-07-15 01:34:00+03	6600.00
1B4FB6	2017-07-03 12:11:00+03	56000.00
1B5096	2017-06-28 04:28:00+03	137900.00
1B50CB	2017-08-02 02:38:00+03	86600.00
1B50EE	2017-07-13 21:42:00+03	28800.00
1B50FD	2017-07-07 04:16:00+03	62600.00
1B510C	2017-08-06 19:19:00+03	40000.00
1B5130	2017-07-30 05:44:00+03	36200.00
1B514B	2017-06-30 19:36:00+03	111600.00
1B516C	2017-07-05 05:24:00+03	8000.00
1B5233	2017-07-07 00:20:00+03	33300.00
1B526D	2017-08-05 21:10:00+03	94900.00
1B528E	2017-07-11 22:56:00+03	28000.00
1B52DE	2017-08-05 01:34:00+03	28600.00
1B5360	2017-08-04 00:35:00+03	64500.00
1B53D3	2017-06-30 00:51:00+03	26000.00
1B5422	2017-07-27 02:32:00+03	34000.00
1B5437	2017-08-01 02:53:00+03	6000.00
1B54B4	2017-07-07 01:21:00+03	135400.00
1B54D7	2017-06-28 05:33:00+03	89700.00
1B5511	2017-08-08 23:00:00+03	8400.00
1B5544	2017-08-10 08:46:00+03	170700.00
1B55B9	2017-07-23 13:09:00+03	393800.00
1B55EE	2017-08-09 14:09:00+03	46200.00
1B5611	2017-07-02 16:52:00+03	4400.00
1B5647	2017-07-13 01:05:00+03	37100.00
1B565E	2017-07-01 07:21:00+03	45200.00
1B56E1	2017-07-06 17:14:00+03	56000.00
1B5712	2017-07-12 03:28:00+03	46400.00
1B5739	2017-07-12 18:22:00+03	89700.00
1B578F	2017-07-05 11:01:00+03	40200.00
1B57CA	2017-08-14 12:30:00+03	29800.00
1B57EB	2017-07-06 04:15:00+03	41200.00
1B57F2	2017-08-04 12:50:00+03	212800.00
1B5867	2017-08-10 10:31:00+03	114800.00
1B5896	2017-08-12 08:07:00+03	39500.00
1B5927	2017-08-14 02:03:00+03	123000.00
1B592E	2017-07-22 17:23:00+03	66600.00
1B594C	2017-08-07 09:00:00+03	155600.00
1B5962	2017-07-19 07:47:00+03	23200.00
1B59F2	2017-07-05 12:33:00+03	48100.00
1B59FA	2017-07-04 03:57:00+03	45000.00
1B59FD	2017-07-02 17:10:00+03	65500.00
1B5A0C	2017-08-12 17:05:00+03	239100.00
1B5A39	2017-07-07 05:34:00+03	209900.00
1B5A53	2017-08-02 13:09:00+03	34000.00
1B5AB9	2017-07-25 01:50:00+03	51600.00
1B5B13	2017-08-09 21:12:00+03	257500.00
1B5B22	2017-07-23 11:05:00+03	35600.00
1B5B3D	2017-07-07 08:29:00+03	53300.00
1B5BF7	2017-07-18 00:57:00+03	93700.00
1B5CAA	2017-07-13 08:15:00+03	16000.00
1B5CC6	2017-07-17 13:36:00+03	94100.00
1B5CE6	2017-07-25 23:02:00+03	25600.00
1B5DF1	2017-07-15 12:10:00+03	128800.00
1B5E05	2017-08-04 15:37:00+03	36200.00
1B5E20	2017-08-05 04:51:00+03	249100.00
1B5E7A	2017-08-08 10:24:00+03	170300.00
1B5EB6	2017-07-21 03:06:00+03	28800.00
1B5ED4	2017-07-05 14:34:00+03	57500.00
1B5EE8	2017-07-23 11:43:00+03	56000.00
1B5F0D	2017-07-12 21:33:00+03	92800.00
1B5F69	2017-07-11 00:30:00+03	64500.00
1B5F9D	2017-07-02 20:14:00+03	44600.00
1B5FDC	2017-08-02 22:37:00+03	81500.00
1B6003	2017-07-25 20:51:00+03	36200.00
1B6037	2017-08-05 02:30:00+03	23600.00
1B6056	2017-08-04 19:52:00+03	56600.00
1B60ED	2017-07-07 21:42:00+03	266200.00
1B60FA	2017-08-04 10:09:00+03	95200.00
1B6119	2017-07-30 14:26:00+03	30200.00
1B6165	2017-07-28 17:28:00+03	46400.00
1B6176	2017-07-26 18:16:00+03	56900.00
1B61B6	2017-07-02 14:59:00+03	46500.00
1B62E9	2017-08-01 23:18:00+03	25400.00
1B631D	2017-08-08 22:39:00+03	49900.00
1B6330	2017-07-25 02:43:00+03	63800.00
1B638E	2017-07-31 18:54:00+03	92000.00
1B63BB	2017-07-17 05:44:00+03	24700.00
1B6406	2017-07-20 20:26:00+03	48800.00
1B6460	2017-07-08 11:58:00+03	76400.00
1B646E	2017-07-29 16:42:00+03	100600.00
1B649E	2017-07-05 05:04:00+03	227500.00
1B64A1	2017-07-29 13:47:00+03	8000.00
1B653A	2017-08-02 19:53:00+03	75600.00
1B65AA	2017-07-10 17:17:00+03	51600.00
1B662F	2017-08-07 17:33:00+03	131100.00
1B664D	2017-08-06 11:45:00+03	93700.00
1B66F2	2017-08-06 16:26:00+03	29600.00
1B6734	2017-08-07 03:18:00+03	46900.00
1B6773	2017-07-03 23:26:00+03	31400.00
1B6789	2017-08-04 23:06:00+03	50600.00
1B67E4	2017-08-06 13:44:00+03	35700.00
1B685C	2017-07-14 21:19:00+03	304100.00
1B6872	2017-07-21 10:46:00+03	35200.00
1B688A	2017-07-21 06:06:00+03	25400.00
1B6898	2017-07-11 03:07:00+03	28800.00
1B689B	2017-08-11 15:40:00+03	58500.00
1B68B3	2017-07-12 11:09:00+03	28000.00
1B68B7	2017-08-11 12:01:00+03	67600.00
1B68D8	2017-07-13 03:29:00+03	61400.00
1B6904	2017-07-30 15:52:00+03	55800.00
1B690C	2017-07-02 03:19:00+03	40400.00
1B691B	2017-08-13 23:46:00+03	51800.00
1B6924	2017-07-06 05:55:00+03	55800.00
1B6950	2017-08-05 18:14:00+03	66000.00
1B69C9	2017-07-29 12:06:00+03	28000.00
1B6A1C	2017-07-31 14:52:00+03	16400.00
1B6A7E	2017-07-01 22:27:00+03	28000.00
1B6B35	2017-08-09 08:46:00+03	23200.00
1B6BAA	2017-07-25 11:12:00+03	60900.00
1B6BAD	2017-07-11 21:00:00+03	58400.00
1B6BAE	2017-07-13 14:43:00+03	67800.00
1B6BFA	2017-08-11 06:44:00+03	23200.00
1B6CFF	2017-08-15 02:41:00+03	61100.00
1B6D40	2017-07-10 07:46:00+03	49100.00
1B6DBF	2017-07-21 17:44:00+03	28000.00
1B6DCC	2017-08-03 09:29:00+03	40600.00
1B6E32	2017-08-14 00:31:00+03	87000.00
1B6E76	2017-07-10 15:33:00+03	105300.00
1B6E98	2017-06-29 03:51:00+03	67600.00
1B6EA5	2017-07-24 08:11:00+03	19600.00
1B6EF0	2017-07-26 06:22:00+03	97400.00
1B6EF8	2017-07-31 16:35:00+03	39400.00
1B6F1E	2017-07-02 02:14:00+03	167400.00
1B6F31	2017-08-15 08:37:00+03	64300.00
1B6F8B	2017-07-08 02:43:00+03	12000.00
1B7010	2017-07-07 19:09:00+03	64600.00
1B7042	2017-07-21 16:43:00+03	94000.00
1B704B	2017-08-11 14:35:00+03	29300.00
1B7084	2017-07-03 18:34:00+03	25100.00
1B70E4	2017-06-30 11:17:00+03	95900.00
1B712A	2017-07-11 05:25:00+03	55800.00
1B7176	2017-07-08 17:35:00+03	12000.00
1B7231	2017-07-05 14:18:00+03	6600.00
1B723E	2017-07-24 17:28:00+03	13400.00
1B7243	2017-08-14 21:21:00+03	44600.00
1B724F	2017-07-29 07:59:00+03	6600.00
1B7268	2017-08-06 21:43:00+03	28000.00
1B72C0	2017-07-02 18:15:00+03	137800.00
1B7306	2017-07-25 09:37:00+03	55800.00
1B7321	2017-07-23 03:56:00+03	393700.00
1B7382	2017-07-30 03:11:00+03	55800.00
1B7396	2017-07-12 16:53:00+03	25100.00
1B73AF	2017-07-19 18:46:00+03	56000.00
1B7402	2017-07-24 17:34:00+03	179300.00
1B7486	2017-07-19 17:57:00+03	64800.00
1B7541	2017-08-15 06:00:00+03	17200.00
1B7574	2017-08-07 19:26:00+03	92800.00
1B757D	2017-07-15 22:22:00+03	6800.00
1B7609	2017-07-02 17:22:00+03	41600.00
1B768A	2017-08-11 06:43:00+03	14000.00
1B76FB	2017-08-15 05:18:00+03	114800.00
1B7710	2017-08-14 21:40:00+03	129200.00
1B7716	2017-08-13 03:06:00+03	39300.00
1B77A9	2017-07-19 18:14:00+03	19800.00
1B78F0	2017-08-11 01:13:00+03	77600.00
1B79B1	2017-07-01 10:44:00+03	119400.00
1B79CB	2017-08-08 11:04:00+03	67400.00
1B79D8	2017-08-15 12:00:00+03	26800.00
1B79FC	2017-07-05 08:58:00+03	52300.00
1B7A3C	2017-07-06 05:28:00+03	43200.00
1B7A61	2017-07-23 15:42:00+03	51900.00
1B7A8E	2017-08-06 14:54:00+03	18000.00
1B7A94	2017-08-13 11:30:00+03	133300.00
1B7A9C	2017-08-09 10:57:00+03	55800.00
1B7ACF	2017-08-02 05:40:00+03	59200.00
1B7AFB	2017-07-26 04:41:00+03	40400.00
1B7B0F	2017-07-04 20:26:00+03	136200.00
1B7B57	2017-07-21 15:34:00+03	6700.00
1B7C11	2017-07-06 00:25:00+03	75800.00
1B7C44	2017-07-03 04:16:00+03	28800.00
1B7C62	2017-08-11 02:00:00+03	114600.00
1B7CE3	2017-08-08 22:13:00+03	50800.00
1B7CEF	2017-08-02 07:43:00+03	133200.00
1B7D52	2017-08-02 01:35:00+03	51900.00
1B7DD2	2017-08-01 15:26:00+03	33200.00
1B7DFD	2017-07-27 13:34:00+03	23400.00
1B7E1D	2017-08-13 07:00:00+03	75300.00
1B7E43	2017-08-13 11:05:00+03	36100.00
1B7E5F	2017-08-03 09:29:00+03	28000.00
1B7E88	2017-07-09 20:57:00+03	87400.00
1B7ED4	2017-07-01 03:49:00+03	75100.00
1B7F1F	2017-08-13 20:45:00+03	38400.00
1B7F4B	2017-08-06 15:53:00+03	35200.00
1B7F55	2017-07-19 23:04:00+03	29400.00
1B7F82	2017-07-17 02:16:00+03	29400.00
1B7FE1	2017-07-04 15:49:00+03	133200.00
1B801A	2017-07-20 09:35:00+03	54000.00
1B8041	2017-07-22 13:04:00+03	48400.00
1B8094	2017-07-07 19:11:00+03	615000.00
1B80E4	2017-08-06 10:42:00+03	248300.00
1B80E7	2017-07-10 19:54:00+03	26400.00
1B8125	2017-07-21 14:27:00+03	135400.00
1B8126	2017-07-04 23:31:00+03	54600.00
1B815F	2017-07-25 00:37:00+03	82900.00
1B816D	2017-08-10 07:56:00+03	53600.00
1B818A	2017-06-28 15:33:00+03	128800.00
1B81F4	2017-07-15 02:15:00+03	6000.00
1B8202	2017-07-22 04:54:00+03	32200.00
1B825A	2017-07-20 00:49:00+03	32700.00
1B8263	2017-07-20 01:25:00+03	84100.00
1B8287	2017-08-10 04:52:00+03	23200.00
1B82BF	2017-07-16 06:02:00+03	58200.00
1B82FE	2017-08-12 19:28:00+03	93900.00
1B832A	2017-07-02 02:29:00+03	30400.00
1B8332	2017-07-29 11:42:00+03	137600.00
1B835E	2017-07-15 02:36:00+03	81700.00
1B839D	2017-08-01 21:38:00+03	36400.00
1B8409	2017-08-08 04:52:00+03	36800.00
1B8498	2017-08-14 20:41:00+03	55500.00
1B84A0	2017-08-12 12:52:00+03	12600.00
1B850B	2017-07-23 23:37:00+03	31600.00
1B8529	2017-07-21 11:22:00+03	41500.00
1B8546	2017-08-07 12:45:00+03	84100.00
1B8606	2017-07-16 04:21:00+03	204700.00
1B8614	2017-07-12 00:08:00+03	425600.00
1B8640	2017-08-07 14:48:00+03	39300.00
1B868C	2017-07-10 23:35:00+03	36500.00
1B8693	2017-08-04 00:13:00+03	23200.00
1B86EC	2017-07-04 01:00:00+03	72400.00
1B8718	2017-06-29 10:39:00+03	36500.00
1B8745	2017-07-26 14:34:00+03	98600.00
1B8749	2017-08-12 10:06:00+03	253200.00
1B8753	2017-08-04 20:02:00+03	23200.00
1B87A9	2017-07-08 04:20:00+03	56000.00
1B87DD	2017-07-02 17:56:00+03	48300.00
1B87F9	2017-07-11 17:58:00+03	75300.00
1B87FB	2017-06-30 17:55:00+03	44000.00
1B8827	2017-07-02 10:42:00+03	102100.00
1B88FA	2017-07-28 14:11:00+03	39400.00
1B893C	2017-07-06 16:53:00+03	58600.00
1B8950	2017-08-10 15:33:00+03	46400.00
1B898E	2017-07-30 11:39:00+03	25600.00
1B8A0E	2017-07-09 05:21:00+03	68100.00
1B8A9F	2017-07-06 21:36:00+03	88600.00
1B8AC2	2017-08-15 01:38:00+03	12000.00
1B8B53	2017-07-07 07:21:00+03	23200.00
1B8C00	2017-08-05 17:37:00+03	36200.00
1B8C21	2017-07-28 02:52:00+03	52700.00
1B8C24	2017-08-13 18:59:00+03	56000.00
1B8CD4	2017-07-26 10:07:00+03	23600.00
1B8D31	2017-07-08 14:40:00+03	13600.00
1B8D47	2017-07-13 01:21:00+03	63300.00
1B8D59	2017-07-11 14:57:00+03	103300.00
1B8D7C	2017-07-15 21:33:00+03	54500.00
1B8D85	2017-08-15 03:43:00+03	74800.00
1B8E16	2017-07-06 18:49:00+03	13400.00
1B8ED6	2017-08-10 00:31:00+03	53300.00
1B8EDF	2017-07-20 15:51:00+03	36200.00
1B8F5C	2017-07-02 13:52:00+03	37900.00
1B8F6B	2017-07-08 05:26:00+03	56000.00
1B8F75	2017-07-11 21:27:00+03	32800.00
1B909D	2017-07-02 19:21:00+03	69100.00
1B90A0	2017-06-29 11:23:00+03	38800.00
1B9128	2017-07-11 09:58:00+03	123000.00
1B9172	2017-08-12 18:17:00+03	169600.00
1B918C	2017-07-19 21:03:00+03	31100.00
1B91A2	2017-08-03 05:40:00+03	55800.00
1B928A	2017-08-10 19:01:00+03	123000.00
1B9299	2017-07-18 12:03:00+03	56000.00
1B92A3	2017-08-12 23:36:00+03	40800.00
1B92C8	2017-06-30 23:51:00+03	51300.00
1B92E4	2017-07-07 03:11:00+03	78900.00
1B937F	2017-07-06 16:29:00+03	123700.00
1B93B7	2017-07-15 18:35:00+03	200200.00
1B93F9	2017-07-27 12:38:00+03	67700.00
1B93FD	2017-08-04 16:30:00+03	51900.00
1B9414	2017-07-21 05:57:00+03	198600.00
1B941E	2017-07-16 06:32:00+03	137100.00
1B9490	2017-07-26 07:31:00+03	31200.00
1B9493	2017-07-01 02:39:00+03	117800.00
1B953F	2017-07-26 23:11:00+03	12400.00
1B956D	2017-08-09 10:34:00+03	28000.00
1B9580	2017-06-29 00:57:00+03	8800.00
1B95E4	2017-07-11 06:00:00+03	68400.00
1B96A7	2017-08-14 06:58:00+03	100000.00
1B9719	2017-07-17 12:26:00+03	136600.00
1B971B	2017-06-29 11:52:00+03	177800.00
1B972A	2017-08-06 18:51:00+03	55800.00
1B975B	2017-07-24 09:29:00+03	17600.00
1B9770	2017-07-01 05:05:00+03	55800.00
1B9779	2017-07-02 05:14:00+03	75300.00
1B9848	2017-08-08 18:16:00+03	36800.00
1B984C	2017-07-07 20:55:00+03	59000.00
1B98C5	2017-08-09 04:54:00+03	83100.00
1B9903	2017-08-11 05:11:00+03	136800.00
1B9923	2017-07-03 02:24:00+03	40400.00
1B9939	2017-08-03 06:34:00+03	67200.00
1B9968	2017-07-03 19:07:00+03	43500.00
1B9A41	2017-07-11 21:10:00+03	42800.00
1B9A61	2017-08-05 13:42:00+03	188300.00
1B9B03	2017-07-28 20:12:00+03	86800.00
1B9BD8	2017-07-04 14:44:00+03	73200.00
1B9C12	2017-08-11 22:34:00+03	123000.00
1B9C42	2017-08-13 23:24:00+03	27900.00
1B9CA4	2017-07-02 11:45:00+03	31600.00
1B9D40	2017-07-26 22:35:00+03	219500.00
1B9D59	2017-08-04 14:05:00+03	64300.00
1B9E8C	2017-07-23 15:52:00+03	67600.00
1B9E9F	2017-07-18 18:28:00+03	167400.00
1B9EC6	2017-08-14 11:04:00+03	101700.00
1B9EE9	2017-07-22 23:44:00+03	6600.00
1B9EEE	2017-08-15 11:38:00+03	62700.00
1B9F07	2017-08-11 02:46:00+03	73300.00
1B9F52	2017-07-25 20:27:00+03	51900.00
1B9FF2	2017-07-19 12:04:00+03	113600.00
1BA007	2017-08-04 18:03:00+03	49300.00
1BA0B8	2017-07-07 01:03:00+03	166000.00
1BA0BB	2017-07-02 15:22:00+03	172600.00
1BA16F	2017-07-18 09:51:00+03	150600.00
1BA189	2017-07-12 02:17:00+03	89600.00
1BA197	2017-08-01 23:38:00+03	62600.00
1BA23F	2017-07-23 19:56:00+03	32400.00
1BA243	2017-07-05 17:36:00+03	76600.00
1BA2CA	2017-07-18 21:27:00+03	23600.00
1BA2F3	2017-07-18 14:20:00+03	33300.00
1BA307	2017-07-12 04:01:00+03	86600.00
1BA32C	2017-07-09 13:33:00+03	14000.00
1BA464	2017-07-16 21:12:00+03	51600.00
1BA47C	2017-07-07 09:16:00+03	405200.00
1BA49C	2017-07-12 20:34:00+03	91200.00
1BA4A8	2017-07-25 16:44:00+03	88300.00
1BA52D	2017-07-15 02:16:00+03	8000.00
1BA54A	2017-08-08 04:28:00+03	16800.00
1BA556	2017-07-03 03:12:00+03	92800.00
1BA573	2017-07-16 17:31:00+03	44500.00
1BA5BD	2017-07-23 08:14:00+03	6700.00
1BA5C0	2017-07-08 04:05:00+03	377100.00
1BA5D0	2017-08-15 14:24:00+03	42900.00
1BA5D1	2017-07-10 00:14:00+03	47800.00
1BA5EC	2017-07-04 14:19:00+03	46700.00
1BA5FC	2017-07-17 14:20:00+03	136600.00
1BA617	2017-08-02 08:29:00+03	137600.00
1BA625	2017-08-02 18:24:00+03	135600.00
1BA661	2017-07-20 00:35:00+03	21800.00
1BA692	2017-07-19 06:17:00+03	125200.00
1BA6BA	2017-07-04 01:43:00+03	45100.00
1BA6D8	2017-07-01 16:27:00+03	136600.00
1BA70E	2017-07-15 03:44:00+03	51000.00
1BA738	2017-08-10 23:20:00+03	37400.00
1BA786	2017-07-16 17:37:00+03	42700.00
1BA7C2	2017-07-27 12:33:00+03	41800.00
1BA7EA	2017-07-25 20:07:00+03	126300.00
1BA830	2017-07-05 16:38:00+03	123000.00
1BA835	2017-07-16 08:11:00+03	67600.00
1BA875	2017-08-07 01:06:00+03	31400.00
1BA8FE	2017-08-05 20:04:00+03	23900.00
1BA95A	2017-07-12 03:28:00+03	36200.00
1BA965	2017-07-19 20:41:00+03	22000.00
1BA986	2017-07-07 12:04:00+03	40900.00
1BAAAB	2017-07-27 08:21:00+03	73400.00
1BAAE4	2017-07-14 19:44:00+03	105600.00
1BAB16	2017-08-08 17:04:00+03	92000.00
1BAB1A	2017-07-15 08:59:00+03	43500.00
1BAC14	2017-08-07 22:54:00+03	264600.00
1BAC4E	2017-07-14 01:30:00+03	56000.00
1BAC54	2017-07-03 16:04:00+03	369000.00
1BAC55	2017-07-28 02:57:00+03	131100.00
1BACA8	2017-07-16 04:40:00+03	28800.00
1BAD1C	2017-08-12 10:55:00+03	61200.00
1BAD4A	2017-07-24 00:56:00+03	27800.00
1BADFB	2017-07-18 03:34:00+03	15000.00
1BAE20	2017-07-26 19:46:00+03	28800.00
1BAF57	2017-07-22 13:10:00+03	199300.00
1BAF88	2017-08-09 11:47:00+03	240600.00
1BAF90	2017-07-26 23:16:00+03	116500.00
1BAFDB	2017-07-04 01:28:00+03	72700.00
1BB03C	2017-08-09 23:58:00+03	31400.00
1BB0DF	2017-07-10 12:59:00+03	44600.00
1BB101	2017-08-15 08:44:00+03	246000.00
1BB15A	2017-08-10 01:37:00+03	55600.00
1BB1EF	2017-07-20 14:31:00+03	56000.00
1BB24F	2017-08-01 13:27:00+03	113200.00
1BB286	2017-07-26 02:24:00+03	92800.00
1BB29F	2017-08-03 17:32:00+03	381300.00
1BB379	2017-08-06 17:52:00+03	40000.00
1BB3ED	2017-07-30 08:25:00+03	89600.00
1BB43E	2017-07-12 01:31:00+03	199700.00
1BB46A	2017-07-31 06:46:00+03	16400.00
1BB49B	2017-07-09 13:09:00+03	43400.00
1BB4A7	2017-07-31 06:56:00+03	182700.00
1BB4C4	2017-08-01 07:43:00+03	36200.00
1BB4CD	2017-07-06 07:03:00+03	44800.00
1BB4E7	2017-08-02 18:40:00+03	6300.00
1BB503	2017-08-14 20:08:00+03	129000.00
1BB51C	2017-07-22 01:21:00+03	150500.00
1BB56E	2017-08-03 11:00:00+03	59800.00
1BB585	2017-07-12 21:32:00+03	54500.00
1BB5C1	2017-07-30 20:13:00+03	323800.00
1BB640	2017-07-14 12:12:00+03	101500.00
1BB654	2017-08-06 06:54:00+03	29400.00
1BB69D	2017-07-10 17:59:00+03	263200.00
1BB710	2017-08-06 00:45:00+03	28000.00
1BB75C	2017-07-31 11:07:00+03	49000.00
1BB774	2017-07-09 12:53:00+03	43400.00
1BB793	2017-06-30 13:43:00+03	12400.00
1BB83B	2017-06-22 01:52:00+03	123000.00
1BB869	2017-06-29 23:56:00+03	14800.00
1BB86C	2017-07-28 14:09:00+03	32800.00
1BB8A8	2017-07-08 09:45:00+03	615000.00
1BB931	2017-08-04 08:12:00+03	266200.00
1BB969	2017-07-07 08:15:00+03	67100.00
1BB995	2017-08-12 01:07:00+03	145300.00
1BB997	2017-07-09 04:47:00+03	6700.00
1BB9EB	2017-08-08 05:09:00+03	117800.00
1BBA46	2017-08-03 20:41:00+03	23200.00
1BBA49	2017-07-14 07:14:00+03	52800.00
1BBAD7	2017-07-16 04:50:00+03	86900.00
1BBB46	2017-07-29 10:52:00+03	40000.00
1BBB79	2017-07-21 23:32:00+03	302200.00
1BBBD2	2017-07-05 10:28:00+03	88600.00
1BBBFD	2017-07-30 04:38:00+03	76100.00
1BBC0A	2017-07-13 20:14:00+03	65900.00
1BBC22	2017-08-01 10:59:00+03	40800.00
1BBCD7	2017-08-15 13:20:00+03	23200.00
1BBDE4	2017-07-15 23:31:00+03	8200.00
1BBDE5	2017-08-03 08:43:00+03	39800.00
1BBE24	2017-07-18 16:49:00+03	18600.00
1BBE98	2017-07-27 12:58:00+03	30200.00
1BBED1	2017-08-14 03:49:00+03	28800.00
1BBF1B	2017-07-24 04:28:00+03	44600.00
1BBF4B	2017-08-07 06:08:00+03	26500.00
1BBFAE	2017-07-20 18:54:00+03	58600.00
1BBFBA	2017-07-03 02:41:00+03	66600.00
1BBFBD	2017-08-11 10:46:00+03	88100.00
1BBFC4	2017-07-07 06:01:00+03	111000.00
1BBFC9	2017-07-04 02:13:00+03	83000.00
1BC031	2017-07-09 13:39:00+03	25400.00
1BC05E	2017-08-08 12:08:00+03	23200.00
1BC0B9	2017-07-12 07:15:00+03	19600.00
1BC123	2017-07-24 11:52:00+03	156400.00
1BC12F	2017-08-12 01:44:00+03	132800.00
1BC154	2017-07-17 21:22:00+03	57600.00
1BC235	2017-08-09 11:26:00+03	36800.00
1BC292	2017-07-06 12:20:00+03	67200.00
1BC2BE	2017-07-30 08:48:00+03	104600.00
1BC2FE	2017-07-28 00:46:00+03	51300.00
1BC32C	2017-08-13 08:40:00+03	32700.00
1BC357	2017-07-17 13:46:00+03	24400.00
1BC3A9	2017-07-20 04:00:00+03	369000.00
1BC3AE	2017-07-13 22:42:00+03	67600.00
1BC43E	2017-07-11 18:20:00+03	158100.00
1BC45F	2017-07-09 20:48:00+03	149200.00
1BC4FF	2017-07-03 11:59:00+03	12600.00
1BC50E	2017-08-06 06:39:00+03	23200.00
1BC631	2017-06-29 21:23:00+03	28000.00
1BC63F	2017-07-21 01:51:00+03	47200.00
1BC67E	2017-07-15 01:54:00+03	6700.00
1BC6AA	2017-08-03 08:07:00+03	133100.00
1BC6B2	2017-07-25 13:33:00+03	194000.00
1BC6C6	2017-07-26 17:20:00+03	68800.00
1BC6FF	2017-07-24 11:43:00+03	13000.00
1BC728	2017-07-24 02:04:00+03	91600.00
1BC741	2017-07-10 00:48:00+03	29600.00
1BC786	2017-07-12 07:42:00+03	79800.00
1BC7C5	2017-08-06 03:54:00+03	33600.00
1BC7E3	2017-08-04 12:12:00+03	56900.00
1BC7FD	2017-08-14 15:45:00+03	12600.00
1BC8B2	2017-07-10 06:40:00+03	170600.00
1BC9B3	2017-07-04 04:01:00+03	22400.00
1BC9C4	2017-06-28 04:39:00+03	17800.00
1BC9C6	2017-08-10 23:59:00+03	55800.00
1BC9D4	2017-07-11 06:31:00+03	62700.00
1BC9DC	2017-07-13 09:30:00+03	47200.00
1BC9E9	2017-07-31 04:56:00+03	32200.00
1BCA49	2017-07-30 20:36:00+03	22000.00
1BCAA1	2017-07-26 07:21:00+03	479000.00
1BCACE	2017-07-28 08:54:00+03	28000.00
1BCAE5	2017-08-02 05:55:00+03	24400.00
1BCB23	2017-07-15 18:34:00+03	464400.00
1BCBA5	2017-08-05 11:44:00+03	260300.00
1BCBF4	2017-07-19 00:57:00+03	135100.00
1BCCCA	2017-08-14 07:26:00+03	13000.00
1BCCD7	2017-07-14 16:33:00+03	51900.00
1BCCE0	2017-07-19 10:13:00+03	86800.00
1BCCEB	2017-07-03 11:22:00+03	24700.00
1BCD15	2017-07-02 10:23:00+03	26000.00
1BCDA6	2017-07-19 00:35:00+03	109000.00
1BCE14	2017-08-08 07:39:00+03	40100.00
1BCE25	2017-07-11 22:48:00+03	119700.00
1BCEBB	2017-08-09 17:53:00+03	129200.00
1BCED7	2017-07-28 17:30:00+03	83300.00
1BCEE4	2017-07-10 18:19:00+03	51100.00
1BCF0F	2017-08-03 13:09:00+03	193600.00
1BCF13	2017-07-11 18:34:00+03	41400.00
1BCF1E	2017-08-07 18:20:00+03	59300.00
1BCF91	2017-08-05 10:41:00+03	515000.00
1BCFF0	2017-08-04 10:31:00+03	12400.00
1BD055	2017-08-03 08:36:00+03	26200.00
1BD071	2017-08-15 01:15:00+03	44800.00
1BD0AF	2017-07-21 03:55:00+03	272900.00
1BD0C9	2017-07-26 11:08:00+03	39600.00
1BD119	2017-07-07 08:12:00+03	81600.00
1BD164	2017-07-14 11:13:00+03	37200.00
1BD1C4	2017-08-15 06:40:00+03	56100.00
1BD1E3	2017-07-09 08:48:00+03	35200.00
1BD1F5	2017-07-30 17:15:00+03	23600.00
1BD1F7	2017-08-03 01:52:00+03	46200.00
1BD2C3	2017-08-01 04:00:00+03	115800.00
1BD2F9	2017-07-25 19:20:00+03	144400.00
1BD342	2017-07-01 11:27:00+03	51100.00
1BD344	2017-07-06 10:51:00+03	67200.00
1BD453	2017-07-14 13:13:00+03	111600.00
1BD4A0	2017-08-07 16:02:00+03	38000.00
1BD514	2017-07-17 15:38:00+03	30200.00
1BD51E	2017-08-10 21:10:00+03	28800.00
1BD548	2017-08-10 21:42:00+03	77600.00
1BD5B2	2017-07-13 05:30:00+03	70800.00
1BD5E6	2017-07-17 22:53:00+03	89100.00
1BD6DD	2017-06-30 16:07:00+03	38400.00
1BD6E1	2017-06-29 01:00:00+03	86300.00
1BD766	2017-08-10 09:21:00+03	24400.00
1BD784	2017-08-13 06:22:00+03	61800.00
1BD7A2	2017-07-15 06:34:00+03	28800.00
1BD7AB	2017-07-30 06:51:00+03	19600.00
1BD7D3	2017-07-21 00:21:00+03	198400.00
1BD815	2017-08-05 23:50:00+03	101200.00
1BD887	2017-08-01 19:54:00+03	111600.00
1BD907	2017-08-08 01:39:00+03	24700.00
1BD91A	2017-08-06 22:23:00+03	58600.00
1BD93F	2017-07-22 16:10:00+03	89000.00
1BD9FD	2017-07-09 21:08:00+03	36700.00
1BDA3D	2017-07-29 04:44:00+03	136700.00
1BDA43	2017-07-03 13:54:00+03	55800.00
1BDA83	2017-08-11 22:36:00+03	31600.00
1BDAE3	2017-07-22 21:33:00+03	114900.00
1BDB23	2017-07-26 20:08:00+03	72400.00
1BDB61	2017-07-06 23:32:00+03	77600.00
1BDB86	2017-07-14 12:23:00+03	68400.00
1BDBA2	2017-08-13 05:50:00+03	87200.00
1BDBC7	2017-08-11 11:54:00+03	83000.00
1BDBD5	2017-07-13 09:57:00+03	46000.00
1BDBDC	2017-07-19 19:01:00+03	46200.00
1BDC51	2017-07-16 13:58:00+03	54000.00
1BDC7B	2017-07-02 10:14:00+03	58200.00
1BDC81	2017-07-22 12:32:00+03	123200.00
1BDD09	2017-08-02 05:17:00+03	49200.00
1BDD1E	2017-08-05 04:53:00+03	65900.00
1BDD65	2017-07-07 06:01:00+03	28800.00
1BDDFF	2017-08-01 10:55:00+03	26200.00
1BDE70	2017-07-17 09:17:00+03	37900.00
1BDE8F	2017-08-02 08:48:00+03	47100.00
1BDF24	2017-08-03 22:43:00+03	68000.00
1BDF8A	2017-07-16 05:12:00+03	97800.00
1BDFF8	2017-08-05 07:21:00+03	102100.00
1BDFFC	2017-07-23 09:43:00+03	32900.00
1BE044	2017-07-26 09:39:00+03	37900.00
1BE090	2017-08-14 05:14:00+03	26000.00
1BE097	2017-07-01 14:31:00+03	145100.00
1BE0D4	2017-08-05 19:50:00+03	100900.00
1BE199	2017-08-14 23:30:00+03	58400.00
1BE206	2017-07-11 05:09:00+03	265800.00
1BE289	2017-07-09 15:20:00+03	16000.00
1BE2A9	2017-07-11 04:18:00+03	22100.00
1BE2BF	2017-07-29 12:10:00+03	26800.00
1BE2C6	2017-08-15 17:37:00+03	11800.00
1BE2C9	2017-07-25 18:52:00+03	64700.00
1BE383	2017-07-11 14:18:00+03	75800.00
1BE3A3	2017-08-05 04:51:00+03	77600.00
1BE461	2017-07-27 13:20:00+03	132800.00
1BE469	2017-07-05 17:36:00+03	48800.00
1BE472	2017-07-14 03:14:00+03	175200.00
1BE47A	2017-08-05 05:39:00+03	11600.00
1BE483	2017-08-12 03:37:00+03	16400.00
1BE484	2017-08-15 06:26:00+03	50000.00
1BE4EE	2017-07-22 14:08:00+03	68800.00
1BE549	2017-06-28 20:34:00+03	37900.00
1BE54D	2017-08-04 09:49:00+03	62800.00
1BE560	2017-07-20 06:47:00+03	67600.00
1BE57D	2017-07-16 06:12:00+03	80000.00
1BE580	2017-07-19 06:23:00+03	84800.00
1BE604	2017-07-24 07:11:00+03	6700.00
1BE651	2017-07-28 00:18:00+03	68800.00
1BE672	2017-08-15 15:22:00+03	129700.00
1BE692	2017-08-07 16:34:00+03	97800.00
1BE706	2017-08-04 19:17:00+03	65900.00
1BE729	2017-07-04 16:28:00+03	48900.00
1BE753	2017-07-08 07:46:00+03	65900.00
1BE803	2017-07-08 19:52:00+03	95700.00
1BE81A	2017-07-29 19:25:00+03	265600.00
1BE843	2017-08-05 13:31:00+03	81600.00
1BE844	2017-07-26 15:50:00+03	14400.00
1BE8DE	2017-07-11 21:35:00+03	52300.00
1BE95A	2017-08-09 11:31:00+03	48700.00
1BE9DA	2017-07-25 02:46:00+03	93700.00
1BEA60	2017-06-30 16:16:00+03	40800.00
1BEADA	2017-07-01 07:59:00+03	23200.00
1BEADF	2017-07-05 19:58:00+03	103600.00
1BEB1E	2017-08-07 19:55:00+03	25600.00
1BEBA5	2017-07-22 06:26:00+03	19600.00
1BEBCB	2017-08-06 16:50:00+03	25600.00
1BEBE1	2017-07-29 18:57:00+03	25200.00
1BEC9A	2017-07-27 16:41:00+03	246400.00
1BECD6	2017-07-03 14:44:00+03	22600.00
1BECEB	2017-08-03 21:15:00+03	57500.00
1BED03	2017-07-06 02:38:00+03	101200.00
1BED34	2017-07-24 03:48:00+03	13200.00
1BED52	2017-07-24 04:12:00+03	46200.00
1BED57	2017-07-04 22:57:00+03	38600.00
1BEE95	2017-08-14 13:40:00+03	99300.00
1BEE9B	2017-07-23 20:46:00+03	86600.00
1BEF46	2017-07-12 18:09:00+03	46300.00
1BEF6B	2017-07-01 11:40:00+03	140500.00
1BEF7A	2017-07-05 03:48:00+03	148700.00
1BEFB9	2017-07-05 04:19:00+03	57500.00
1BF00A	2017-08-08 10:17:00+03	67100.00
1BF011	2017-08-11 03:05:00+03	168700.00
1BF03B	2017-08-14 17:17:00+03	24400.00
1BF07D	2017-07-14 22:57:00+03	136500.00
1BF0F6	2017-07-26 08:56:00+03	79600.00
1BF12D	2017-07-26 03:19:00+03	92800.00
1BF156	2017-07-12 17:40:00+03	67600.00
1BF171	2017-08-04 15:01:00+03	46200.00
1BF1D0	2017-08-14 07:10:00+03	39800.00
1BF1E9	2017-07-18 08:42:00+03	77700.00
1BF1F9	2017-07-11 12:03:00+03	140400.00
1BF235	2017-07-22 13:35:00+03	24400.00
1BF291	2017-07-05 18:10:00+03	47000.00
1BF2CB	2017-08-15 01:02:00+03	128000.00
1BF2DB	2017-06-25 14:34:00+03	145200.00
1BF2F9	2017-08-02 00:49:00+03	125100.00
1BF36A	2017-07-03 08:12:00+03	24400.00
1BF3A3	2017-07-02 06:15:00+03	47000.00
1BF3E2	2017-08-15 14:48:00+03	31200.00
1BF408	2017-07-22 00:41:00+03	31600.00
1BF423	2017-07-19 06:26:00+03	25200.00
1BF44F	2017-06-30 12:45:00+03	38400.00
1BF613	2017-07-18 22:50:00+03	73600.00
1BF619	2017-07-12 17:40:00+03	193200.00
1BF648	2017-07-13 03:21:00+03	46500.00
1BF668	2017-08-13 11:14:00+03	88200.00
1BF683	2017-07-12 10:47:00+03	17800.00
1BF6C3	2017-07-22 10:00:00+03	73600.00
1BF6E8	2017-07-08 09:15:00+03	28700.00
1BF6F8	2017-07-18 17:06:00+03	32800.00
1BF738	2017-07-13 01:40:00+03	72600.00
1BF739	2017-07-20 16:30:00+03	37900.00
1BF74C	2017-07-03 20:08:00+03	46400.00
1BF7D1	2017-07-30 22:06:00+03	46200.00
1BF7F1	2017-06-29 12:41:00+03	120100.00
1BF868	2017-08-02 21:17:00+03	33000.00
1BF896	2017-08-10 00:33:00+03	6800.00
1BF8DD	2017-07-12 02:59:00+03	55700.00
1BF8F3	2017-07-14 04:33:00+03	290600.00
1BF8FA	2017-07-14 19:39:00+03	57500.00
1BF91A	2017-07-08 16:49:00+03	56000.00
1BF922	2017-07-24 09:04:00+03	65100.00
1BF950	2017-08-12 00:58:00+03	42500.00
1BF968	2017-08-01 13:42:00+03	38200.00
1BF9C3	2017-06-29 11:46:00+03	62800.00
1BF9C7	2017-08-10 01:28:00+03	81700.00
1BF9C9	2017-08-08 00:44:00+03	57300.00
1BF9EE	2017-07-17 09:20:00+03	135400.00
1BF9F1	2017-07-06 00:20:00+03	68900.00
1BFA02	2017-07-14 02:53:00+03	209800.00
1BFA38	2017-07-15 02:40:00+03	89600.00
1BFAA1	2017-07-08 04:37:00+03	94000.00
1BFAE0	2017-08-15 12:17:00+03	25200.00
1BFAF7	2017-07-29 08:05:00+03	93700.00
1BFB47	2017-07-01 07:15:00+03	85200.00
1BFB59	2017-07-12 15:01:00+03	102100.00
1BFBEE	2017-07-19 06:08:00+03	28800.00
1BFBFA	2017-07-26 20:26:00+03	20900.00
1BFC68	2017-06-29 08:54:00+03	85000.00
1BFCF9	2017-07-10 15:13:00+03	6000.00
1BFD46	2017-07-28 10:24:00+03	25900.00
1BFDA9	2017-07-17 11:19:00+03	99300.00
1BFDAF	2017-07-02 01:35:00+03	84500.00
1BFDF9	2017-07-04 04:28:00+03	20400.00
1BFE34	2017-07-14 19:09:00+03	46000.00
1BFE4D	2017-07-01 10:12:00+03	54500.00
1BFE5A	2017-07-14 04:44:00+03	102100.00
1BFE7A	2017-08-04 12:32:00+03	51300.00
1BFEA0	2017-07-30 22:15:00+03	136000.00
1BFECD	2017-07-24 07:09:00+03	246000.00
1BFF56	2017-07-17 04:20:00+03	12600.00
1BFF67	2017-08-02 16:19:00+03	81700.00
1BFF86	2017-07-21 03:36:00+03	68100.00
1BFFF3	2017-07-15 03:30:00+03	23200.00
1C002A	2017-07-08 05:44:00+03	139200.00
1C004B	2017-07-19 01:50:00+03	90400.00
1C00D4	2017-07-19 18:36:00+03	177200.00
1C0135	2017-07-30 15:34:00+03	23200.00
1C0183	2017-07-20 13:58:00+03	26000.00
1C01A6	2017-07-09 06:08:00+03	58800.00
1C0231	2017-07-21 19:23:00+03	20200.00
1C0353	2017-07-11 12:58:00+03	93400.00
1C039F	2017-07-19 12:25:00+03	55800.00
1C0427	2017-07-16 12:08:00+03	64600.00
1C042D	2017-07-07 10:54:00+03	6000.00
1C046C	2017-08-13 14:52:00+03	149300.00
1C04DB	2017-07-29 11:39:00+03	46400.00
1C0553	2017-08-08 00:33:00+03	55800.00
1C0572	2017-07-27 08:34:00+03	30400.00
1C05C8	2017-07-19 13:14:00+03	156600.00
1C05D7	2017-08-12 22:50:00+03	28000.00
1C0650	2017-08-15 15:31:00+03	59400.00
1C0676	2017-07-13 01:07:00+03	67400.00
1C06A2	2017-07-31 02:08:00+03	119700.00
1C06C3	2017-07-17 09:00:00+03	78600.00
1C0745	2017-07-30 04:15:00+03	133200.00
1C0756	2017-07-01 11:19:00+03	17600.00
1C076A	2017-08-06 08:18:00+03	29200.00
1C08C3	2017-08-14 14:03:00+03	78300.00
1C092B	2017-07-05 21:40:00+03	28000.00
1C09A3	2017-07-12 05:37:00+03	40800.00
1C09F7	2017-07-19 14:19:00+03	10800.00
1C0BB2	2017-08-13 17:41:00+03	67600.00
1C0C6D	2017-07-19 20:55:00+03	28800.00
1C0CD9	2017-07-27 00:12:00+03	56100.00
1C0D42	2017-08-10 03:44:00+03	36200.00
1C0D82	2017-08-15 02:24:00+03	149300.00
1C0DE8	2017-07-20 01:24:00+03	92800.00
1C0DFA	2017-08-14 03:10:00+03	272600.00
1C0E14	2017-07-21 10:05:00+03	6600.00
1C0E5A	2017-08-14 10:08:00+03	23600.00
1C0E5C	2017-07-22 02:14:00+03	139300.00
1C0E65	2017-06-30 07:16:00+03	131600.00
1C0ED7	2017-08-07 05:39:00+03	67700.00
1C0EE5	2017-07-05 01:05:00+03	31200.00
1C0EFE	2017-07-07 06:50:00+03	98300.00
1C0F34	2017-07-20 21:53:00+03	28800.00
1C0F6A	2017-06-29 21:16:00+03	116400.00
1C0FC4	2017-07-03 10:39:00+03	43200.00
1C0FC6	2017-08-01 03:35:00+03	108200.00
1C0FFC	2017-08-10 21:41:00+03	71400.00
1C105E	2017-07-06 13:17:00+03	50800.00
1C10BC	2017-07-10 12:25:00+03	92800.00
1C10F6	2017-08-12 10:46:00+03	26000.00
1C1120	2017-07-28 05:47:00+03	32200.00
1C1137	2017-07-07 21:14:00+03	13400.00
1C1148	2017-07-24 16:27:00+03	133200.00
1C117D	2017-08-09 09:32:00+03	52200.00
1C1199	2017-08-11 04:25:00+03	52300.00
1C11BB	2017-07-27 07:41:00+03	21400.00
1C11C7	2017-07-07 22:30:00+03	56000.00
1C1207	2017-08-05 04:39:00+03	63400.00
1C1223	2017-08-10 08:15:00+03	187600.00
1C123A	2017-07-25 14:20:00+03	41400.00
1C1277	2017-07-26 09:20:00+03	31000.00
1C12A0	2017-07-16 05:43:00+03	279800.00
1C12A2	2017-07-03 05:38:00+03	32900.00
1C12D7	2017-07-18 06:41:00+03	24400.00
1C12EA	2017-07-03 05:44:00+03	10600.00
1C13C6	2017-07-20 13:22:00+03	104600.00
1C13E6	2017-07-16 09:07:00+03	76300.00
1C13F2	2017-07-24 09:35:00+03	133200.00
1C1419	2017-07-26 00:28:00+03	116400.00
1C145C	2017-07-22 03:33:00+03	31400.00
1C1498	2017-07-14 00:15:00+03	65500.00
1C14DF	2017-08-07 23:48:00+03	131100.00
1C151E	2017-07-14 12:40:00+03	57700.00
1C1541	2017-08-09 09:23:00+03	59700.00
1C1570	2017-08-10 14:45:00+03	36700.00
1C1579	2017-08-14 12:32:00+03	27200.00
1C15D3	2017-07-04 01:33:00+03	57300.00
1C16D0	2017-08-13 09:33:00+03	170900.00
1C170E	2017-07-24 02:56:00+03	123200.00
1C1722	2017-07-26 09:48:00+03	16400.00
1C1733	2017-08-06 13:54:00+03	58900.00
1C1751	2017-08-12 12:41:00+03	101200.00
1C175F	2017-07-14 05:09:00+03	13400.00
1C1866	2017-08-05 14:26:00+03	135200.00
1C186D	2017-07-04 09:01:00+03	65000.00
1C1890	2017-08-10 03:28:00+03	46000.00
1C189F	2017-08-02 19:17:00+03	42800.00
1C18AA	2017-06-28 18:23:00+03	53700.00
1C1962	2017-07-29 18:23:00+03	52300.00
1C1980	2017-07-01 23:32:00+03	54000.00
1C198D	2017-08-06 15:33:00+03	20200.00
1C1991	2017-08-10 09:21:00+03	51800.00
1C1995	2017-07-25 05:56:00+03	18700.00
1C19A3	2017-07-18 10:21:00+03	33300.00
1C19B9	2017-07-25 07:13:00+03	62700.00
1C1A22	2017-07-27 14:00:00+03	77900.00
1C1A23	2017-08-12 17:19:00+03	112000.00
1C1A38	2017-08-14 08:23:00+03	53400.00
1C1A9F	2017-07-29 14:02:00+03	187900.00
1C1AB2	2017-07-03 14:00:00+03	30200.00
1C1AC7	2017-07-22 14:33:00+03	13400.00
1C1ADF	2017-08-05 07:20:00+03	99200.00
1C1B29	2017-08-04 01:24:00+03	39000.00
1C1B70	2017-07-23 10:32:00+03	36900.00
1C1B99	2017-07-21 05:31:00+03	290600.00
1C1BC7	2017-07-20 15:09:00+03	42900.00
1C1BD0	2017-06-26 00:08:00+03	124600.00
1C1C22	2017-08-12 14:44:00+03	8200.00
1C1D28	2017-08-08 18:05:00+03	25600.00
1C1D29	2017-08-13 17:40:00+03	48800.00
1C1D2D	2017-07-06 10:08:00+03	165000.00
1C1E56	2017-08-14 07:06:00+03	52400.00
1C1E63	2017-07-07 22:42:00+03	35600.00
1C1EA4	2017-07-05 05:15:00+03	18100.00
1C1EC4	2017-07-23 11:36:00+03	38400.00
1C1F05	2017-07-18 11:03:00+03	32800.00
1C1F2A	2017-07-14 11:13:00+03	67600.00
1C1F2E	2017-07-07 00:39:00+03	29200.00
1C1F30	2017-08-01 15:19:00+03	51600.00
1C1F35	2017-07-17 00:15:00+03	73500.00
1C1F5D	2017-07-06 01:59:00+03	38100.00
1C1F9A	2017-07-10 13:05:00+03	27300.00
1C1FA5	2017-08-07 18:45:00+03	37900.00
1C1FA8	2017-07-14 13:05:00+03	183300.00
1C1FAD	2017-07-05 20:07:00+03	57800.00
1C1FB7	2017-07-09 09:14:00+03	140500.00
1C1FC6	2017-07-26 04:57:00+03	23200.00
1C1FE4	2017-07-02 12:17:00+03	42600.00
1C1FEE	2017-07-18 23:03:00+03	57400.00
1C2009	2017-08-06 06:48:00+03	6300.00
1C2083	2017-07-08 00:30:00+03	72400.00
1C2087	2017-08-04 18:05:00+03	84500.00
1C20A2	2017-08-01 22:59:00+03	137400.00
1C20AB	2017-07-14 13:48:00+03	47000.00
1C20F5	2017-07-16 00:59:00+03	86200.00
1C2177	2017-07-14 00:18:00+03	44000.00
1C21E2	2017-08-15 14:59:00+03	24000.00
1C2254	2017-07-04 16:24:00+03	23400.00
1C2297	2017-07-09 22:56:00+03	236000.00
1C22B1	2017-07-08 07:26:00+03	67600.00
1C230C	2017-07-21 14:21:00+03	23600.00
1C23CA	2017-08-11 09:28:00+03	148200.00
1C2427	2017-08-06 09:24:00+03	73500.00
1C24B4	2017-07-08 04:11:00+03	100600.00
1C24E8	2017-08-07 15:28:00+03	99200.00
1C24E9	2017-08-05 04:08:00+03	62600.00
1C25B4	2017-07-04 18:52:00+03	46000.00
1C25D5	2017-07-02 03:00:00+03	133100.00
1C2656	2017-07-27 13:22:00+03	30200.00
1C2666	2017-08-04 04:53:00+03	43100.00
1C266A	2017-08-01 08:03:00+03	269400.00
1C267C	2017-07-12 12:33:00+03	121800.00
1C267F	2017-07-23 04:43:00+03	61500.00
1C26B2	2017-08-08 05:58:00+03	15100.00
1C26C6	2017-07-15 20:14:00+03	32700.00
1C26CF	2017-07-28 08:43:00+03	28000.00
1C2706	2017-08-10 12:47:00+03	26700.00
1C272F	2017-07-02 15:25:00+03	16400.00
1C2758	2017-07-11 14:28:00+03	22000.00
1C27C5	2017-07-05 08:01:00+03	43900.00
1C27ED	2017-07-04 19:47:00+03	91600.00
1C2816	2017-07-20 12:15:00+03	6300.00
1C2865	2017-07-02 04:51:00+03	63200.00
1C28B9	2017-07-10 07:48:00+03	55800.00
1C28F5	2017-07-26 10:05:00+03	29400.00
1C28F8	2017-07-30 20:22:00+03	24700.00
1C28FD	2017-08-08 16:59:00+03	106400.00
1C2935	2017-07-17 21:18:00+03	68300.00
1C2959	2017-07-25 13:39:00+03	89600.00
1C29C1	2017-07-21 21:47:00+03	95700.00
1C2A03	2017-07-04 06:21:00+03	41400.00
1C2B0A	2017-07-13 16:36:00+03	129700.00
1C2B38	2017-06-26 01:17:00+03	28700.00
1C2B69	2017-07-19 15:44:00+03	86400.00
1C2BA2	2017-07-01 04:21:00+03	22000.00
1C2C16	2017-07-09 16:06:00+03	83300.00
1C2C4C	2017-06-30 23:12:00+03	19600.00
1C2C5A	2017-07-13 08:58:00+03	15000.00
1C2CAB	2017-07-15 10:50:00+03	923200.00
1C2D13	2017-07-03 07:29:00+03	21600.00
1C2D1E	2017-08-13 13:19:00+03	11600.00
1C2D20	2017-08-11 06:02:00+03	117200.00
1C2D5D	2017-07-27 14:50:00+03	69700.00
1C2D60	2017-07-12 17:34:00+03	23200.00
1C2D66	2017-08-09 18:49:00+03	41600.00
1C2D89	2017-08-10 14:08:00+03	73900.00
1C2DA6	2017-07-21 03:29:00+03	181100.00
1C2DC0	2017-07-17 01:56:00+03	112400.00
1C2E0F	2017-08-07 21:47:00+03	26000.00
1C2E26	2017-07-21 00:42:00+03	85000.00
1C2E43	2017-07-10 22:18:00+03	75500.00
1C2E67	2017-07-09 09:59:00+03	172600.00
1C2F01	2017-07-24 12:26:00+03	46500.00
1C2F3A	2017-07-08 01:29:00+03	84100.00
1C2F9E	2017-08-15 07:37:00+03	99200.00
1C2FD2	2017-07-15 00:58:00+03	42800.00
1C2FD5	2017-08-03 03:46:00+03	179400.00
1C2FE2	2017-07-05 02:40:00+03	19600.00
1C2FE4	2017-07-08 21:52:00+03	23600.00
1C302B	2017-07-28 14:31:00+03	396300.00
1C3040	2017-08-13 22:49:00+03	30900.00
1C30E0	2017-07-30 14:41:00+03	187600.00
1C314F	2017-07-16 04:39:00+03	37700.00
1C3152	2017-08-02 11:52:00+03	23200.00
1C319C	2017-07-27 10:57:00+03	77800.00
1C31E9	2017-08-02 13:12:00+03	46900.00
1C31F5	2017-07-07 23:50:00+03	55600.00
1C31F8	2017-07-10 22:16:00+03	109600.00
1C3269	2017-07-24 02:15:00+03	80000.00
1C32D1	2017-07-17 00:54:00+03	31600.00
1C32E8	2017-07-15 18:57:00+03	46400.00
1C344A	2017-07-07 05:58:00+03	74200.00
1C3457	2017-08-11 14:32:00+03	118600.00
1C3575	2017-08-15 04:09:00+03	20300.00
1C35DC	2017-07-23 08:58:00+03	25600.00
1C364F	2017-08-11 06:17:00+03	23200.00
1C3658	2017-07-23 12:43:00+03	36400.00
1C3672	2017-08-02 14:34:00+03	31100.00
1C3688	2017-08-03 10:43:00+03	59800.00
1C3706	2017-07-01 11:27:00+03	272400.00
1C3741	2017-07-24 12:10:00+03	36000.00
1C3785	2017-07-27 11:21:00+03	50600.00
1C378C	2017-07-25 17:09:00+03	58800.00
1C37DA	2017-08-04 04:37:00+03	248500.00
1C37E4	2017-08-02 14:32:00+03	125200.00
1C38B6	2017-07-23 13:08:00+03	52600.00
1C38C9	2017-07-28 20:14:00+03	28000.00
1C38CB	2017-07-26 22:45:00+03	44000.00
1C398C	2017-07-12 20:03:00+03	123900.00
1C39D7	2017-08-04 03:06:00+03	270000.00
1C3A06	2017-08-10 07:59:00+03	63500.00
1C3B1A	2017-08-10 14:24:00+03	271200.00
1C3B33	2017-08-02 03:59:00+03	13400.00
1C3B97	2017-08-15 12:18:00+03	11700.00
1C3BCB	2017-07-05 17:23:00+03	45200.00
1C3BE5	2017-06-30 11:13:00+03	135400.00
1C3BF1	2017-07-18 20:17:00+03	154800.00
1C3C67	2017-08-03 20:00:00+03	27200.00
1C3CCF	2017-07-20 22:51:00+03	42400.00
1C3D48	2017-08-02 19:30:00+03	163400.00
1C3D93	2017-07-22 19:03:00+03	41200.00
1C3EBA	2017-08-14 06:38:00+03	316400.00
1C408A	2017-07-22 01:24:00+03	201600.00
1C4104	2017-07-15 03:07:00+03	45200.00
1C41BC	2017-08-06 08:47:00+03	56000.00
1C4211	2017-07-14 02:12:00+03	34600.00
1C4216	2017-08-12 04:32:00+03	6600.00
1C431B	2017-08-09 11:37:00+03	17800.00
1C4333	2017-08-10 16:39:00+03	43800.00
1C4393	2017-08-15 02:57:00+03	19800.00
1C43C1	2017-07-28 18:54:00+03	27200.00
1C43C6	2017-07-27 06:36:00+03	18900.00
1C43E9	2017-08-11 04:21:00+03	40000.00
1C4407	2017-08-14 20:09:00+03	97900.00
1C440F	2017-07-29 21:07:00+03	23200.00
1C4457	2017-08-13 08:13:00+03	37200.00
1C44B4	2017-07-26 09:01:00+03	102400.00
1C44D8	2017-07-21 01:09:00+03	31000.00
1C44D9	2017-08-05 19:59:00+03	75600.00
1C44E7	2017-07-05 06:58:00+03	108200.00
1C44EF	2017-08-08 06:35:00+03	46400.00
1C44F3	2017-07-06 05:07:00+03	173700.00
1C450F	2017-07-29 05:10:00+03	12400.00
1C457D	2017-08-12 12:56:00+03	36200.00
1C4584	2017-07-13 14:32:00+03	118900.00
1C4601	2017-07-23 08:19:00+03	67400.00
1C46C9	2017-07-26 17:53:00+03	35600.00
1C46D1	2017-07-02 09:32:00+03	23600.00
1C46D9	2017-07-14 12:35:00+03	23400.00
1C46FD	2017-07-26 20:12:00+03	31600.00
1C47DF	2017-08-15 16:36:00+03	173500.00
1C47E7	2017-08-01 07:31:00+03	61500.00
1C47F0	2017-08-15 07:49:00+03	25600.00
1C4849	2017-07-06 02:30:00+03	67100.00
1C487F	2017-07-09 14:33:00+03	63700.00
1C48F7	2017-07-13 08:06:00+03	11600.00
1C4996	2017-07-24 22:57:00+03	28000.00
1C4A11	2017-08-04 02:49:00+03	72400.00
1C4A23	2017-08-13 23:44:00+03	45200.00
1C4AB0	2017-07-07 20:12:00+03	51900.00
1C4B23	2017-07-07 17:24:00+03	126300.00
1C4C0F	2017-07-17 20:52:00+03	98400.00
1C4C3C	2017-07-16 06:39:00+03	169000.00
1C4C54	2017-07-24 21:19:00+03	103500.00
1C4C97	2017-07-19 11:48:00+03	49300.00
1C4CB7	2017-07-24 14:39:00+03	135400.00
1C4CF1	2017-07-15 02:48:00+03	41600.00
1C4D74	2017-07-11 11:25:00+03	82900.00
1C4DA7	2017-08-04 10:26:00+03	85000.00
1C4DC3	2017-08-03 19:53:00+03	12400.00
1C4E18	2017-07-23 16:49:00+03	28800.00
1C4E70	2017-08-04 13:21:00+03	189800.00
1C4E8B	2017-07-31 05:15:00+03	24000.00
1C4E8F	2017-07-14 22:16:00+03	133200.00
1C4E9F	2017-07-01 17:54:00+03	68400.00
1C4EBB	2017-07-07 06:38:00+03	97900.00
1C4F72	2017-07-11 09:18:00+03	6000.00
1C504F	2017-08-01 07:12:00+03	57100.00
1C5063	2017-08-14 12:46:00+03	99200.00
1C5082	2017-07-27 21:21:00+03	147200.00
1C5096	2017-06-30 15:25:00+03	189800.00
1C50E3	2017-07-05 12:16:00+03	172300.00
1C5105	2017-08-12 11:12:00+03	23100.00
1C511F	2017-08-13 23:17:00+03	80100.00
1C5149	2017-08-03 12:14:00+03	37100.00
1C5230	2017-07-27 08:13:00+03	393800.00
1C5337	2017-07-10 17:08:00+03	55800.00
1C5384	2017-07-29 01:07:00+03	29500.00
1C53C7	2017-08-13 11:31:00+03	26800.00
1C53F4	2017-08-03 09:10:00+03	274200.00
1C543F	2017-07-19 08:33:00+03	11700.00
1C5455	2017-07-08 19:25:00+03	24800.00
1C54A9	2017-07-01 01:32:00+03	100000.00
1C552D	2017-08-15 11:35:00+03	28000.00
1C556A	2017-08-05 00:59:00+03	27200.00
1C55B8	2017-07-10 00:50:00+03	50600.00
1C55E0	2017-08-11 13:18:00+03	99200.00
1C561C	2017-07-30 21:54:00+03	72300.00
1C5646	2017-08-10 14:25:00+03	96300.00
1C564E	2017-08-03 08:21:00+03	51900.00
1C5651	2017-08-13 10:34:00+03	147900.00
1C56CA	2017-07-11 00:14:00+03	28000.00
1C5745	2017-07-18 21:21:00+03	123000.00
1C5763	2017-07-13 02:19:00+03	67700.00
1C577D	2017-07-08 03:23:00+03	30200.00
1C5792	2017-08-13 02:32:00+03	19600.00
1C57F9	2017-08-13 04:36:00+03	351000.00
1C58C7	2017-07-05 10:07:00+03	12600.00
1C5994	2017-08-05 07:45:00+03	15700.00
1C5A22	2017-07-27 00:51:00+03	11800.00
1C5A2E	2017-07-08 14:48:00+03	73500.00
1C5A93	2017-08-06 10:00:00+03	538000.00
1C5A96	2017-08-08 02:57:00+03	116400.00
1C5AD3	2017-07-19 12:26:00+03	26000.00
1C5AD7	2017-08-09 22:32:00+03	60700.00
1C5AE5	2017-07-17 10:20:00+03	39800.00
1C5B2C	2017-08-08 17:29:00+03	109200.00
1C5B75	2017-07-22 09:09:00+03	28000.00
1C5B77	2017-08-09 04:55:00+03	56600.00
1C5C08	2017-07-21 21:36:00+03	98200.00
1C5C09	2017-07-29 15:31:00+03	6000.00
1C5C50	2017-07-10 10:32:00+03	92800.00
1C5C6A	2017-07-17 08:26:00+03	21800.00
1C5CA9	2017-07-21 16:08:00+03	55900.00
1C5CC0	2017-07-22 08:00:00+03	10600.00
1C5CEB	2017-07-18 02:51:00+03	81700.00
1C5CF4	2017-07-02 08:27:00+03	26400.00
1C5D32	2017-07-31 17:38:00+03	30000.00
1C5DA1	2017-07-30 16:42:00+03	24700.00
1C5DD1	2017-07-17 07:45:00+03	30200.00
1C5EBB	2017-07-13 08:09:00+03	25600.00
1C5EC9	2017-07-12 00:24:00+03	131800.00
1C5ECC	2017-08-02 21:57:00+03	44600.00
1C5FA5	2017-08-07 13:41:00+03	20000.00
1C5FD8	2017-08-12 05:14:00+03	266400.00
1C5FDC	2017-08-09 12:07:00+03	44000.00
1C6011	2017-08-14 13:42:00+03	66600.00
1C6064	2017-08-10 13:56:00+03	81700.00
1C60B7	2017-07-28 20:07:00+03	56000.00
1C6120	2017-06-26 10:27:00+03	54800.00
1C6124	2017-07-09 21:01:00+03	153900.00
1C6143	2017-07-11 03:59:00+03	81600.00
1C6176	2017-08-12 05:56:00+03	89100.00
1C61A5	2017-07-07 15:08:00+03	171100.00
1C61E3	2017-07-31 09:36:00+03	16000.00
1C61E9	2017-08-06 18:36:00+03	24700.00
1C61F1	2017-07-26 19:56:00+03	38800.00
1C6233	2017-07-31 09:35:00+03	23200.00
1C625F	2017-07-06 08:41:00+03	29600.00
1C626D	2017-07-18 05:04:00+03	67900.00
1C62B0	2017-07-25 19:43:00+03	62900.00
1C62DA	2017-07-11 03:26:00+03	57300.00
1C6326	2017-08-11 10:44:00+03	85500.00
1C6361	2017-08-14 09:10:00+03	34000.00
1C637C	2017-07-31 01:49:00+03	52700.00
1C639B	2017-07-25 15:59:00+03	85000.00
1C63CE	2017-07-05 23:16:00+03	23200.00
1C63E9	2017-08-15 14:40:00+03	228900.00
1C6424	2017-07-09 21:04:00+03	133200.00
1C6448	2017-08-15 00:37:00+03	67200.00
1C644E	2017-08-02 08:49:00+03	46400.00
1C64A1	2017-07-16 23:07:00+03	48800.00
1C653F	2017-07-08 05:14:00+03	32800.00
1C6550	2017-07-22 05:02:00+03	8000.00
1C65C1	2017-07-15 23:35:00+03	56000.00
1C65DC	2017-07-04 20:44:00+03	23400.00
1C65E8	2017-07-24 08:13:00+03	58400.00
1C6655	2017-08-10 00:25:00+03	153300.00
1C66D5	2017-08-02 13:35:00+03	56000.00
1C6707	2017-08-09 03:33:00+03	15000.00
1C6736	2017-08-08 19:55:00+03	58000.00
1C673C	2017-07-19 11:49:00+03	56000.00
1C675A	2017-07-28 16:59:00+03	68100.00
1C6898	2017-07-23 03:21:00+03	42800.00
1C6928	2017-07-03 00:24:00+03	182300.00
1C693A	2017-07-16 05:36:00+03	93900.00
1C6989	2017-08-05 21:47:00+03	56000.00
1C69A4	2017-07-30 20:50:00+03	102200.00
1C69A5	2017-07-11 17:18:00+03	56000.00
1C69E9	2017-07-16 07:09:00+03	26700.00
1C6A53	2017-08-05 16:50:00+03	152400.00
1C6A5C	2017-07-26 06:06:00+03	26000.00
1C6A77	2017-08-11 23:13:00+03	77900.00
1C6A7A	2017-07-12 13:05:00+03	44500.00
1C6A99	2017-06-29 19:12:00+03	154100.00
1C6AA8	2017-07-28 05:58:00+03	55800.00
1C6AD9	2017-08-14 05:54:00+03	75300.00
1C6C12	2017-07-26 13:13:00+03	81600.00
1C6C5A	2017-06-30 10:48:00+03	27200.00
1C6D7B	2017-07-29 08:29:00+03	69500.00
1C6DDA	2017-07-06 08:04:00+03	55800.00
1C6E30	2017-07-22 18:26:00+03	229800.00
1C6E48	2017-08-08 03:10:00+03	26700.00
1C6E57	2017-06-30 12:21:00+03	29600.00
1C6E99	2017-07-08 08:11:00+03	20400.00
1C6EDB	2017-07-27 06:42:00+03	25800.00
1C6F9A	2017-07-08 20:26:00+03	15800.00
1C6F9B	2017-07-14 17:47:00+03	21800.00
1C6FA8	2017-07-08 16:52:00+03	138000.00
1C7021	2017-08-02 15:19:00+03	81700.00
1C70C0	2017-08-02 19:27:00+03	84500.00
1C70D5	2017-07-05 06:51:00+03	14800.00
1C7103	2017-07-12 04:52:00+03	424700.00
1C7107	2017-07-15 06:37:00+03	49700.00
1C7179	2017-08-15 09:53:00+03	92800.00
1C7191	2017-08-10 15:22:00+03	18600.00
1C7192	2017-07-16 13:37:00+03	13700.00
1C71A1	2017-08-10 16:41:00+03	77700.00
1C71A9	2017-08-02 07:14:00+03	156000.00
1C71C3	2017-08-06 03:05:00+03	132200.00
1C71D1	2017-07-17 02:31:00+03	136600.00
1C71EC	2017-07-16 04:30:00+03	44800.00
1C7215	2017-08-15 17:49:00+03	257600.00
1C7252	2017-07-13 19:38:00+03	70200.00
1C7275	2017-07-23 08:04:00+03	246000.00
1C72BF	2017-07-08 16:09:00+03	139200.00
1C72E6	2017-07-30 21:17:00+03	122700.00
1C732D	2017-08-08 16:17:00+03	246000.00
1C73B2	2017-07-13 05:53:00+03	45000.00
1C73E6	2017-07-19 11:49:00+03	27200.00
1C74CD	2017-07-14 18:48:00+03	52800.00
1C74ED	2017-08-11 13:32:00+03	12000.00
1C74F2	2017-08-10 16:33:00+03	36900.00
1C7517	2017-07-28 08:14:00+03	46900.00
1C7543	2017-07-04 12:00:00+03	27200.00
1C7559	2017-08-01 08:35:00+03	42800.00
1C7576	2017-08-10 05:58:00+03	96300.00
1C75AF	2017-08-07 05:33:00+03	25400.00
1C75B9	2017-08-13 22:07:00+03	42700.00
1C760D	2017-08-11 13:47:00+03	58400.00
1C761F	2017-07-31 00:09:00+03	96200.00
1C763B	2017-08-15 01:16:00+03	44000.00
1C7679	2017-08-10 09:50:00+03	56000.00
1C76AA	2017-08-10 16:34:00+03	16400.00
1C7701	2017-08-11 04:27:00+03	289300.00
1C77BE	2017-08-04 10:38:00+03	56000.00
1C77D4	2017-07-25 08:51:00+03	50200.00
1C7806	2017-07-11 03:09:00+03	29100.00
1C783E	2017-07-10 08:38:00+03	125400.00
1C78E0	2017-06-29 23:08:00+03	37900.00
1C78FD	2017-07-10 18:50:00+03	64500.00
1C7953	2017-07-05 09:13:00+03	28000.00
1C79E0	2017-08-07 04:45:00+03	279800.00
1C7A32	2017-08-03 05:58:00+03	29600.00
1C7A54	2017-07-13 12:00:00+03	7400.00
1C7A5D	2017-08-12 17:05:00+03	36000.00
1C7A73	2017-07-26 20:17:00+03	48800.00
1C7A78	2017-07-29 03:02:00+03	133200.00
1C7A9F	2017-07-24 10:10:00+03	270800.00
1C7AAD	2017-08-11 07:26:00+03	120400.00
1C7ADA	2017-07-09 10:43:00+03	31400.00
1C7B2E	2017-08-10 06:17:00+03	17600.00
1C7BAD	2017-07-26 16:13:00+03	115200.00
1C7BE3	2017-08-14 06:09:00+03	70600.00
1C7C01	2017-07-30 20:35:00+03	58600.00
1C7CC1	2017-07-20 21:43:00+03	24400.00
1C7CD1	2017-07-18 09:12:00+03	246000.00
1C7CF8	2017-07-17 04:40:00+03	23200.00
1C7D34	2017-08-07 06:44:00+03	16400.00
1C7D98	2017-07-08 14:05:00+03	115900.00
1C7DF5	2017-06-30 09:45:00+03	48800.00
1C7E8C	2017-07-06 00:27:00+03	90400.00
1C7E8F	2017-07-21 22:20:00+03	136600.00
1C7EA9	2017-07-29 15:14:00+03	75800.00
1C7EC3	2017-07-21 08:54:00+03	369000.00
1C7ECA	2017-07-12 13:41:00+03	28800.00
1C7F31	2017-08-03 03:17:00+03	135400.00
1C7F86	2017-07-19 03:17:00+03	115600.00
1C8024	2017-07-21 06:55:00+03	7400.00
1C804A	2017-07-05 21:48:00+03	15400.00
1C8052	2017-08-06 18:18:00+03	75300.00
1C8080	2017-07-22 06:31:00+03	54000.00
1C80CF	2017-07-28 04:56:00+03	28000.00
1C80D6	2017-08-08 00:33:00+03	23600.00
1C814A	2017-07-23 13:04:00+03	88900.00
1C8162	2017-07-08 01:38:00+03	46400.00
1C81DA	2017-07-18 10:56:00+03	28800.00
1C8214	2017-07-28 23:15:00+03	32200.00
1C822A	2017-07-23 11:56:00+03	30200.00
1C82A4	2017-08-15 15:11:00+03	38600.00
1C82A9	2017-08-14 05:36:00+03	6700.00
1C82B9	2017-07-19 21:59:00+03	35700.00
1C82E6	2017-08-08 23:47:00+03	50600.00
1C83EB	2017-08-15 00:43:00+03	60000.00
1C84A6	2017-07-14 21:22:00+03	70700.00
1C84D8	2017-08-03 00:30:00+03	28800.00
1C84E7	2017-06-28 03:52:00+03	24000.00
1C8598	2017-07-02 11:26:00+03	43400.00
1C859B	2017-07-11 10:10:00+03	100600.00
1C85B6	2017-07-11 23:55:00+03	32800.00
1C85BA	2017-07-15 14:27:00+03	67200.00
1C85E2	2017-07-20 12:12:00+03	28000.00
1C8630	2017-07-20 05:40:00+03	79200.00
1C8695	2017-08-01 04:29:00+03	136200.00
1C86BD	2017-08-08 02:32:00+03	86500.00
1C8727	2017-07-23 20:28:00+03	43200.00
1C8757	2017-08-07 05:36:00+03	133200.00
1C880A	2017-08-09 19:09:00+03	56000.00
1C886E	2017-07-27 10:55:00+03	26500.00
1C88B3	2017-07-16 13:09:00+03	12000.00
1C88EB	2017-07-29 16:37:00+03	75300.00
1C8932	2017-08-14 14:17:00+03	37100.00
1C8946	2017-07-29 10:27:00+03	111600.00
1C899A	2017-07-31 21:22:00+03	28000.00
1C89A5	2017-08-09 21:13:00+03	68800.00
1C89BD	2017-07-19 09:58:00+03	28700.00
1C89DE	2017-08-10 01:46:00+03	181300.00
1C8A03	2017-07-16 21:17:00+03	47600.00
1C8A08	2017-07-22 09:43:00+03	246000.00
1C8A32	2017-08-08 22:43:00+03	48800.00
1C8A53	2017-07-31 17:34:00+03	114800.00
1C8A7F	2017-08-04 03:18:00+03	40200.00
1C8A9C	2017-07-29 02:05:00+03	46500.00
1C8AB9	2017-08-07 10:44:00+03	114800.00
1C8B1F	2017-07-16 04:09:00+03	65900.00
1C8B4C	2017-08-10 00:44:00+03	25200.00
1C8C14	2017-08-14 23:49:00+03	15000.00
1C8C52	2017-08-07 05:26:00+03	8400.00
1C8D44	2017-07-24 15:54:00+03	156600.00
1C8D90	2017-08-11 23:32:00+03	49200.00
1C8DA1	2017-07-07 08:00:00+03	42000.00
1C8DE9	2017-07-03 10:49:00+03	39800.00
1C8DFE	2017-07-02 20:38:00+03	112000.00
1C8E3B	2017-07-09 13:57:00+03	51600.00
1C8E45	2017-08-15 11:42:00+03	57600.00
1C8E54	2017-08-14 20:14:00+03	21400.00
1C8EC6	2017-08-07 00:25:00+03	57500.00
1C8EE2	2017-07-26 03:45:00+03	88900.00
1C8EE5	2017-06-29 04:43:00+03	223200.00
1C8EF7	2017-07-24 20:21:00+03	11600.00
1C8F24	2017-07-07 08:10:00+03	355200.00
1C8F46	2017-06-28 01:56:00+03	125200.00
1C8F64	2017-07-15 01:52:00+03	24400.00
1C8F7A	2017-07-31 14:37:00+03	23600.00
1C8F9A	2017-07-09 23:45:00+03	25900.00
1C8FE0	2017-07-07 04:01:00+03	25600.00
1C907A	2017-07-04 22:43:00+03	44000.00
1C90E3	2017-07-10 04:01:00+03	44000.00
1C9132	2017-07-17 15:46:00+03	70700.00
1C9143	2017-08-03 06:10:00+03	19600.00
1C9157	2017-07-09 10:55:00+03	304600.00
1C9178	2017-07-10 20:11:00+03	26800.00
1C9191	2017-07-22 14:26:00+03	40800.00
1C91A8	2017-08-14 22:32:00+03	62700.00
1C9279	2017-07-17 14:51:00+03	270000.00
1C937A	2017-08-05 11:44:00+03	6000.00
1C937B	2017-07-09 04:03:00+03	88800.00
1C937D	2017-08-07 03:41:00+03	56600.00
1C9390	2017-08-11 11:06:00+03	257500.00
1C93BD	2017-08-11 07:36:00+03	138000.00
1C93CE	2017-07-09 18:42:00+03	51900.00
1C9407	2017-07-31 13:46:00+03	27200.00
1C941B	2017-08-01 02:56:00+03	111600.00
1C94AD	2017-07-10 05:02:00+03	54800.00
1C94AE	2017-07-09 21:23:00+03	243600.00
1C94EE	2017-08-14 20:22:00+03	131600.00
1C94F0	2017-07-26 09:27:00+03	62400.00
1C9559	2017-08-03 10:25:00+03	13400.00
1C958B	2017-08-09 00:44:00+03	38800.00
1C95A6	2017-08-12 13:10:00+03	14400.00
1C9614	2017-07-10 14:48:00+03	23200.00
1C963D	2017-06-29 08:03:00+03	158000.00
1C9668	2017-07-12 05:57:00+03	43200.00
1C967C	2017-08-12 06:33:00+03	4000.00
1C96B1	2017-07-28 05:01:00+03	71900.00
1C96C6	2017-08-07 20:22:00+03	119600.00
1C977D	2017-08-15 04:38:00+03	15000.00
1C978A	2017-07-25 12:26:00+03	46400.00
1C9809	2017-08-08 18:45:00+03	80200.00
1C982D	2017-07-22 17:51:00+03	17800.00
1C9836	2017-07-08 14:09:00+03	33200.00
1C9842	2017-08-06 12:25:00+03	136200.00
1C9859	2017-07-09 09:03:00+03	52400.00
1C989E	2017-08-02 23:24:00+03	14000.00
1C98BC	2017-07-29 22:27:00+03	71300.00
1C99A1	2017-07-10 05:12:00+03	24000.00
1C99BB	2017-07-18 00:31:00+03	183300.00
1C9A37	2017-07-07 07:55:00+03	86200.00
1C9A5A	2017-07-17 12:43:00+03	26000.00
1C9A7B	2017-07-03 19:45:00+03	28800.00
1C9A80	2017-07-27 19:43:00+03	56100.00
1C9B73	2017-07-16 07:17:00+03	68000.00
1C9B8F	2017-07-14 03:08:00+03	85000.00
1C9BCC	2017-08-07 01:38:00+03	40800.00
1C9BEC	2017-07-23 08:03:00+03	13400.00
1C9C0F	2017-07-03 15:07:00+03	68100.00
1C9C31	2017-07-26 08:21:00+03	40100.00
1C9C4C	2017-07-27 23:36:00+03	30900.00
1C9C6B	2017-08-12 19:28:00+03	24400.00
1C9C71	2017-07-09 12:24:00+03	15000.00
1C9C91	2017-06-30 21:12:00+03	17600.00
1C9D0E	2017-07-20 19:01:00+03	44800.00
1C9D29	2017-06-29 10:13:00+03	103700.00
1C9D8A	2017-08-06 02:18:00+03	63800.00
1C9D8D	2017-07-06 00:16:00+03	203500.00
1C9D8E	2017-08-14 05:55:00+03	19600.00
1C9DCF	2017-07-18 11:46:00+03	31600.00
1C9DD4	2017-07-13 08:43:00+03	42800.00
1C9DE1	2017-07-09 08:09:00+03	136800.00
1C9E0E	2017-07-11 23:11:00+03	27200.00
1C9E1B	2017-07-29 23:39:00+03	28600.00
1C9E33	2017-07-15 22:27:00+03	58000.00
1C9E3D	2017-06-28 08:35:00+03	65500.00
1C9EA3	2017-08-04 13:31:00+03	43900.00
1C9ECA	2017-07-07 04:27:00+03	46300.00
1C9EE6	2017-07-26 05:46:00+03	13700.00
1C9F0F	2017-07-23 00:46:00+03	117200.00
1C9F14	2017-07-23 07:08:00+03	131100.00
1C9F7F	2017-08-15 12:15:00+03	123000.00
1C9F82	2017-06-29 08:01:00+03	31400.00
1C9F85	2017-08-09 07:21:00+03	32800.00
1C9FA9	2017-07-12 13:32:00+03	21800.00
1C9FD6	2017-07-07 23:06:00+03	85000.00
1CA0A0	2017-07-23 07:36:00+03	44000.00
1CA0A4	2017-07-27 14:13:00+03	170000.00
1CA0CE	2017-07-25 23:50:00+03	6800.00
1CA158	2017-08-09 20:04:00+03	108900.00
1CA1A7	2017-07-21 17:52:00+03	125200.00
1CA240	2017-07-09 11:53:00+03	20400.00
1CA271	2017-07-16 01:00:00+03	39800.00
1CA28C	2017-07-11 01:02:00+03	67200.00
1CA2AB	2017-07-25 12:49:00+03	65400.00
1CA2D4	2017-07-22 16:47:00+03	26800.00
1CA2E8	2017-07-17 13:11:00+03	62800.00
1CA332	2017-08-05 11:59:00+03	134600.00
1CA34B	2017-07-28 12:44:00+03	23600.00
1CA35A	2017-08-05 19:51:00+03	32700.00
1CA390	2017-08-10 16:45:00+03	270700.00
1CA416	2017-07-16 07:50:00+03	26000.00
1CA45C	2017-07-30 02:09:00+03	8200.00
1CA465	2017-08-05 05:40:00+03	52700.00
1CA468	2017-07-20 20:56:00+03	29400.00
1CA493	2017-07-11 22:52:00+03	40800.00
1CA4EE	2017-08-13 22:42:00+03	58600.00
1CA510	2017-07-15 10:58:00+03	47600.00
1CA55D	2017-07-23 23:51:00+03	36200.00
1CA587	2017-07-10 22:29:00+03	37700.00
1CA5C2	2017-08-10 08:57:00+03	54800.00
1CA60E	2017-08-09 05:07:00+03	24400.00
1CA65C	2017-07-14 18:37:00+03	6600.00
1CA6BE	2017-07-19 05:55:00+03	10700.00
1CA6F1	2017-08-02 15:53:00+03	22000.00
1CA72D	2017-07-16 21:56:00+03	118600.00
1CA870	2017-07-31 19:16:00+03	40400.00
1CA885	2017-08-07 03:56:00+03	260300.00
1CA8E2	2017-07-15 14:41:00+03	6000.00
1CA94C	2017-07-16 15:07:00+03	28000.00
1CA967	2017-08-14 17:59:00+03	93600.00
1CA96C	2017-07-06 03:08:00+03	44800.00
1CA9B4	2017-07-22 06:43:00+03	19800.00
1CAA1D	2017-07-05 19:56:00+03	37700.00
1CAAB4	2017-07-26 07:31:00+03	46400.00
1CAAE0	2017-07-21 08:02:00+03	29400.00
1CAB62	2017-07-28 04:56:00+03	304800.00
1CABB6	2017-07-13 21:49:00+03	6700.00
1CABE2	2017-07-18 14:45:00+03	23600.00
1CAC4A	2017-08-10 03:41:00+03	73500.00
1CAC5B	2017-07-09 05:34:00+03	417200.00
1CACC8	2017-07-13 05:39:00+03	26700.00
1CACD5	2017-06-28 01:42:00+03	66600.00
1CAD71	2017-08-05 13:41:00+03	29100.00
1CAD97	2017-07-31 02:50:00+03	23200.00
1CADEB	2017-08-14 23:37:00+03	173600.00
1CAE06	2017-07-19 04:10:00+03	45600.00
1CAE19	2017-08-12 14:16:00+03	68400.00
1CAEB4	2017-08-11 14:30:00+03	14000.00
1CAEBA	2017-08-11 10:23:00+03	123000.00
1CAF28	2017-07-13 17:11:00+03	116400.00
1CAF55	2017-07-04 00:08:00+03	54800.00
1CAF56	2017-08-05 10:24:00+03	122400.00
1CAFF3	2017-07-29 08:23:00+03	133200.00
1CAFFD	2017-07-17 09:19:00+03	133100.00
1CB005	2017-08-02 19:12:00+03	57300.00
1CB022	2017-07-30 20:31:00+03	59900.00
1CB02E	2017-08-05 10:12:00+03	24400.00
1CB04B	2017-06-26 08:02:00+03	92700.00
1CB05F	2017-07-10 08:12:00+03	23400.00
1CB0D1	2017-07-23 05:34:00+03	23400.00
1CB1A1	2017-08-02 19:10:00+03	43200.00
1CB1A2	2017-08-15 06:08:00+03	51600.00
1CB1AF	2017-07-23 17:53:00+03	56900.00
1CB1D0	2017-07-16 08:41:00+03	43200.00
1CB1F4	2017-08-15 07:49:00+03	139300.00
1CB238	2017-08-13 02:47:00+03	54800.00
1CB240	2017-07-11 23:55:00+03	414800.00
1CB2EE	2017-07-16 21:08:00+03	89200.00
1CB300	2017-08-11 09:37:00+03	48500.00
1CB35E	2017-07-07 17:00:00+03	75300.00
1CB3A7	2017-08-09 21:54:00+03	13400.00
1CB3B5	2017-07-09 00:10:00+03	50600.00
1CB3D2	2017-07-26 05:49:00+03	66000.00
1CB442	2017-07-12 21:47:00+03	58600.00
1CB467	2017-07-12 23:41:00+03	82900.00
1CB514	2017-08-04 05:41:00+03	184200.00
1CB51B	2017-08-15 17:14:00+03	114800.00
1CB553	2017-07-30 00:21:00+03	28300.00
1CB606	2017-08-14 06:04:00+03	43600.00
1CB608	2017-07-19 18:31:00+03	99300.00
1CB617	2017-08-10 12:42:00+03	24400.00
1CB63A	2017-08-04 01:47:00+03	65500.00
1CB645	2017-07-07 12:16:00+03	29600.00
1CB659	2017-07-24 10:57:00+03	14800.00
1CB6AA	2017-07-19 02:47:00+03	103500.00
1CB7FF	2017-07-05 15:28:00+03	29600.00
1CB875	2017-07-03 23:55:00+03	27800.00
1CB883	2017-07-07 10:49:00+03	28000.00
1CB8A5	2017-07-05 02:13:00+03	46900.00
1CB916	2017-08-13 04:19:00+03	81700.00
1CB947	2017-07-08 09:09:00+03	24800.00
1CB956	2017-07-17 21:02:00+03	6700.00
1CB97C	2017-08-09 14:08:00+03	133200.00
1CB991	2017-07-24 10:27:00+03	39200.00
1CB99C	2017-08-06 13:43:00+03	65400.00
1CB9B4	2017-07-22 21:21:00+03	46200.00
1CB9DA	2017-08-05 07:15:00+03	271100.00
1CBA02	2017-08-14 00:59:00+03	265600.00
1CBA0F	2017-07-04 15:00:00+03	26000.00
1CBA1E	2017-08-04 04:06:00+03	7400.00
1CBA68	2017-07-31 12:09:00+03	56100.00
1CBA6D	2017-07-08 10:07:00+03	55800.00
1CBAB0	2017-08-02 20:08:00+03	38600.00
1CBADA	2017-07-27 01:24:00+03	130800.00
1CBAF9	2017-07-26 10:29:00+03	59800.00
1CBB16	2017-06-30 01:04:00+03	39300.00
1CBB22	2017-07-12 11:55:00+03	30600.00
1CBB4B	2017-08-13 20:28:00+03	13200.00
1CBB51	2017-08-07 22:14:00+03	17600.00
1CBBF3	2017-07-14 15:37:00+03	189800.00
1CBC34	2017-07-24 09:27:00+03	21800.00
1CBC85	2017-07-08 03:56:00+03	52300.00
1CBC9C	2017-07-22 07:48:00+03	69000.00
1CBC9E	2017-07-05 20:25:00+03	88900.00
1CBCA6	2017-07-20 08:32:00+03	26000.00
1CBCB2	2017-08-06 10:25:00+03	269200.00
1CBCC4	2017-07-23 13:35:00+03	21600.00
1CBD4D	2017-08-02 04:19:00+03	99200.00
1CBD68	2017-07-13 21:50:00+03	68900.00
1CBD7D	2017-07-19 13:18:00+03	68000.00
1CBD8B	2017-06-29 08:33:00+03	43200.00
1CBDA3	2017-08-04 19:17:00+03	119700.00
1CBE02	2017-07-02 03:08:00+03	116000.00
1CBE28	2017-07-29 08:33:00+03	24400.00
1CBE63	2017-08-07 19:16:00+03	20400.00
1CBEA3	2017-07-30 06:41:00+03	71800.00
1CBEA5	2017-07-24 12:12:00+03	133200.00
1CBEC9	2017-08-03 11:18:00+03	25600.00
1CBED4	2017-08-13 12:45:00+03	65400.00
1CBEEB	2017-07-24 23:44:00+03	58200.00
1CBEEE	2017-08-07 07:22:00+03	28000.00
1CBF5C	2017-08-11 17:20:00+03	62700.00
1CBF77	2017-08-01 14:52:00+03	52300.00
1CBFB6	2017-07-22 17:29:00+03	90000.00
1CBFD8	2017-07-11 13:52:00+03	68800.00
1CC012	2017-08-12 16:54:00+03	135400.00
1CC016	2017-07-06 22:30:00+03	6000.00
1CC02E	2017-07-08 04:48:00+03	51600.00
1CC072	2017-07-28 04:48:00+03	25800.00
1CC07B	2017-07-05 10:49:00+03	13600.00
1CC0B5	2017-07-23 23:27:00+03	59200.00
1CC117	2017-07-14 03:22:00+03	50800.00
1CC13F	2017-07-19 08:06:00+03	48800.00
1CC154	2017-07-14 00:21:00+03	26000.00
1CC198	2017-07-12 15:37:00+03	237900.00
1CC1B2	2017-08-06 03:06:00+03	45200.00
1CC247	2017-07-04 11:24:00+03	46000.00
1CC249	2017-07-28 19:27:00+03	56900.00
1CC24D	2017-07-05 00:00:00+03	102100.00
1CC260	2017-07-20 07:24:00+03	25100.00
1CC271	2017-08-06 09:59:00+03	34700.00
1CC2FF	2017-07-05 17:51:00+03	295400.00
1CC307	2017-07-21 04:08:00+03	77200.00
1CC31B	2017-07-10 08:00:00+03	26800.00
1CC324	2017-07-23 08:57:00+03	28000.00
1CC333	2017-06-28 08:30:00+03	21500.00
1CC42B	2017-07-19 03:46:00+03	134400.00
1CC4A0	2017-08-15 14:49:00+03	49000.00
1CC4C8	2017-08-06 06:54:00+03	99200.00
1CC4D4	2017-07-18 15:18:00+03	76600.00
1CC502	2017-07-16 03:12:00+03	142000.00
1CC508	2017-07-26 20:50:00+03	64800.00
1CC529	2017-08-06 08:19:00+03	195800.00
1CC533	2017-07-13 02:59:00+03	51800.00
1CC53B	2017-08-07 04:04:00+03	56900.00
1CC543	2017-08-04 00:36:00+03	36800.00
1CC5AA	2017-07-09 03:42:00+03	56000.00
1CC5C1	2017-07-27 12:01:00+03	34000.00
1CC5C7	2017-08-12 06:00:00+03	73200.00
1CC629	2017-07-08 12:01:00+03	160200.00
1CC6B0	2017-07-29 02:44:00+03	59300.00
1CC6BB	2017-08-11 14:40:00+03	28800.00
1CC70A	2017-08-14 04:55:00+03	102700.00
1CC710	2017-07-18 22:07:00+03	53400.00
1CC718	2017-07-13 17:37:00+03	56000.00
1CC723	2017-07-08 01:52:00+03	54300.00
1CC785	2017-07-11 11:52:00+03	24200.00
1CC7C1	2017-07-04 17:08:00+03	55800.00
1CC7F2	2017-07-30 05:00:00+03	14400.00
1CC857	2017-07-26 09:22:00+03	322600.00
1CC889	2017-07-13 10:13:00+03	79800.00
1CC8C3	2017-08-05 08:39:00+03	78700.00
1CC983	2017-08-07 06:36:00+03	67400.00
1CC990	2017-07-12 16:47:00+03	17000.00
1CC99B	2017-08-01 13:47:00+03	48800.00
1CC9B8	2017-07-06 14:27:00+03	36800.00
1CCA60	2017-08-07 23:39:00+03	24400.00
1CCA86	2017-08-09 13:07:00+03	43900.00
1CCADF	2017-07-14 05:28:00+03	38800.00
1CCB69	2017-07-06 11:11:00+03	40800.00
1CCC00	2017-07-06 10:32:00+03	26000.00
1CCC1B	2017-07-09 13:02:00+03	115900.00
1CCC23	2017-08-12 21:46:00+03	242700.00
1CCC4A	2017-07-12 20:59:00+03	26000.00
1CCC69	2017-07-19 05:21:00+03	26800.00
1CCCC1	2017-07-30 04:50:00+03	16400.00
1CCCDF	2017-07-29 02:12:00+03	134400.00
1CCD1F	2017-07-11 12:37:00+03	66600.00
1CCD84	2017-08-06 11:13:00+03	32200.00
1CCDAB	2017-07-22 11:57:00+03	24700.00
1CCDD6	2017-07-09 17:19:00+03	57800.00
1CCDFF	2017-07-22 06:55:00+03	76600.00
1CCE01	2017-08-10 00:50:00+03	28800.00
1CCE82	2017-07-15 19:07:00+03	169900.00
1CCE8A	2017-08-10 17:50:00+03	80000.00
1CCED3	2017-07-26 16:07:00+03	149600.00
1CCEEC	2017-07-26 18:11:00+03	135600.00
1CCF08	2017-07-25 03:37:00+03	122400.00
1CCF49	2017-08-11 04:28:00+03	130400.00
1CCF96	2017-07-14 09:29:00+03	99200.00
1CCFBA	2017-07-27 06:32:00+03	92700.00
1CCFF8	2017-08-11 15:53:00+03	58900.00
1CD018	2017-07-23 11:56:00+03	122700.00
1CD035	2017-07-11 06:04:00+03	72700.00
1CD06C	2017-06-28 06:33:00+03	240600.00
1CD0E9	2017-07-08 15:03:00+03	189200.00
1CD130	2017-07-17 08:49:00+03	112000.00
1CD154	2017-07-08 02:50:00+03	40800.00
1CD17C	2017-07-19 13:51:00+03	192000.00
1CD1C2	2017-07-22 18:55:00+03	66000.00
1CD1CF	2017-07-21 20:30:00+03	157200.00
1CD202	2017-07-12 15:37:00+03	144700.00
1CD273	2017-08-13 14:59:00+03	39200.00
1CD2DC	2017-07-04 11:09:00+03	26800.00
1CD31F	2017-07-27 08:04:00+03	241300.00
1CD42A	2017-07-29 02:12:00+03	152400.00
1CD4A7	2017-07-22 02:36:00+03	14800.00
1CD4AA	2017-07-13 04:04:00+03	160400.00
1CD4B0	2017-07-16 08:41:00+03	36200.00
1CD4FC	2017-07-01 09:58:00+03	408500.00
1CD54B	2017-07-25 20:22:00+03	29400.00
1CD590	2017-08-04 18:19:00+03	23200.00
1CD5BA	2017-07-18 10:55:00+03	40800.00
1CD5D5	2017-08-06 09:48:00+03	93700.00
1CD64C	2017-07-20 11:48:00+03	95600.00
1CD667	2017-07-26 10:49:00+03	155600.00
1CD675	2017-08-07 01:51:00+03	56800.00
1CD6BA	2017-08-12 08:58:00+03	101200.00
1CD6BB	2017-07-03 12:59:00+03	19600.00
1CD6CE	2017-08-08 17:26:00+03	136500.00
1CD77F	2017-07-03 09:11:00+03	67000.00
1CD7D1	2017-07-05 21:43:00+03	115400.00
1CD819	2017-07-05 21:56:00+03	46400.00
1CD84D	2017-07-29 17:33:00+03	25600.00
1CD8CD	2017-08-14 19:27:00+03	29600.00
1CD92E	2017-07-06 03:53:00+03	20200.00
1CD990	2017-07-18 01:58:00+03	185000.00
1CD9C4	2017-08-12 17:11:00+03	15000.00
1CD9CE	2017-07-17 22:36:00+03	80100.00
1CD9EF	2017-07-01 13:49:00+03	28800.00
1CDA0F	2017-07-28 14:04:00+03	167400.00
1CDA2F	2017-08-12 10:01:00+03	142600.00
1CDA32	2017-07-28 09:52:00+03	47100.00
1CDAAD	2017-08-13 01:13:00+03	193500.00
1CDAEA	2017-07-09 04:37:00+03	46000.00
1CDB10	2017-08-01 00:46:00+03	55800.00
1CDB4B	2017-07-26 11:50:00+03	39100.00
1CDB81	2017-07-11 12:18:00+03	237800.00
1CDBB2	2017-07-07 10:14:00+03	60800.00
1CDBEB	2017-07-30 16:46:00+03	32200.00
1CDCEC	2017-07-17 06:12:00+03	111600.00
1CDD24	2017-07-05 06:57:00+03	56000.00
1CDE62	2017-06-26 03:27:00+03	43600.00
1CDEFC	2017-08-10 22:25:00+03	44800.00
1CDFDA	2017-07-13 11:25:00+03	54200.00
1CE01B	2017-07-06 12:52:00+03	24800.00
1CE069	2017-07-25 03:54:00+03	40600.00
1CE07B	2017-07-15 17:46:00+03	6300.00
1CE0B9	2017-07-27 02:15:00+03	23600.00
1CE10F	2017-06-25 22:06:00+03	97200.00
1CE16D	2017-07-09 03:14:00+03	28800.00
1CE22B	2017-07-30 17:10:00+03	24800.00
1CE253	2017-07-06 18:13:00+03	22000.00
1CE25E	2017-07-23 13:05:00+03	124200.00
1CE305	2017-07-17 08:00:00+03	36800.00
1CE34F	2017-08-05 11:19:00+03	64300.00
1CE386	2017-07-30 21:42:00+03	58800.00
1CE3AF	2017-07-07 15:33:00+03	37700.00
1CE46E	2017-07-12 06:36:00+03	136200.00
1CE479	2017-07-07 15:16:00+03	40000.00
1CE4BB	2017-07-22 01:20:00+03	123000.00
1CE62D	2017-07-26 13:21:00+03	21400.00
1CE692	2017-07-13 18:47:00+03	132800.00
1CE6EA	2017-07-23 21:32:00+03	46400.00
1CE746	2017-08-02 21:45:00+03	62600.00
1CE76E	2017-08-08 07:31:00+03	89700.00
1CE845	2017-07-01 14:57:00+03	128800.00
1CE848	2017-07-11 11:10:00+03	411700.00
1CE866	2017-07-21 12:51:00+03	398500.00
1CE87B	2017-07-08 09:29:00+03	265700.00
1CE88B	2017-08-14 15:39:00+03	116000.00
1CE92E	2017-07-16 06:54:00+03	133100.00
1CE998	2017-07-16 20:27:00+03	29600.00
1CE9B1	2017-07-22 23:45:00+03	166000.00
1CE9C9	2017-07-16 22:06:00+03	111600.00
1CEA4F	2017-07-29 16:31:00+03	189200.00
1CEA6D	2017-06-28 19:17:00+03	6600.00
1CEB29	2017-07-23 02:31:00+03	58000.00
1CEB43	2017-07-20 09:31:00+03	65900.00
1CEB8E	2017-07-12 06:20:00+03	55800.00
1CEC31	2017-08-01 14:35:00+03	42900.00
1CEC45	2017-08-03 21:42:00+03	67700.00
1CEC7D	2017-08-06 00:21:00+03	93900.00
1CEC84	2017-07-25 17:33:00+03	23200.00
1CECC1	2017-07-06 03:09:00+03	76600.00
1CECD7	2017-07-29 01:01:00+03	8800.00
1CED7C	2017-08-10 08:17:00+03	26500.00
1CED8B	2017-07-26 10:54:00+03	41800.00
1CED96	2017-08-11 08:51:00+03	152900.00
1CEDCF	2017-07-16 06:54:00+03	31000.00
1CEDD8	2017-08-11 14:09:00+03	147900.00
1CEE1B	2017-07-10 08:53:00+03	24300.00
1CEEB3	2017-07-26 08:53:00+03	62900.00
1CEEBC	2017-07-18 16:27:00+03	46400.00
1CEEE5	2017-07-16 15:11:00+03	21600.00
1CEF1E	2017-08-15 08:47:00+03	30200.00
1CEF80	2017-07-11 16:32:00+03	41800.00
1CF04A	2017-08-09 09:49:00+03	92900.00
1CF080	2017-07-24 09:39:00+03	71000.00
1CF0BB	2017-08-09 06:09:00+03	89600.00
1CF0C2	2017-07-31 20:35:00+03	27600.00
1CF0FA	2017-07-23 13:45:00+03	62600.00
1CF166	2017-06-30 07:25:00+03	24400.00
1CF1C4	2017-07-08 23:40:00+03	6800.00
1CF1C7	2017-08-10 15:20:00+03	40000.00
1CF1E2	2017-08-11 15:09:00+03	198300.00
1CF1F8	2017-07-17 23:33:00+03	341900.00
1CF1FA	2017-07-15 08:02:00+03	131400.00
1CF21E	2017-07-08 18:45:00+03	45100.00
1CF328	2017-07-12 21:18:00+03	6300.00
1CF32E	2017-07-23 07:17:00+03	46800.00
1CF398	2017-08-07 19:29:00+03	76600.00
1CF405	2017-07-19 15:46:00+03	125100.00
1CF447	2017-07-18 04:54:00+03	23200.00
1CF458	2017-07-24 06:00:00+03	67600.00
1CF463	2017-08-04 11:35:00+03	54700.00
1CF4BD	2017-07-31 11:52:00+03	27200.00
1CF4E6	2017-07-10 16:19:00+03	13600.00
1CF50D	2017-08-01 08:09:00+03	28000.00
1CF520	2017-08-13 20:08:00+03	64200.00
1CF534	2017-08-07 19:03:00+03	92800.00
1CF579	2017-07-27 11:36:00+03	46300.00
1CF60F	2017-08-06 15:45:00+03	14000.00
1CF69D	2017-08-03 21:50:00+03	64500.00
1CF6C8	2017-07-11 07:11:00+03	26000.00
1CF6D2	2017-07-04 10:09:00+03	27800.00
1CF6F7	2017-07-20 02:44:00+03	44600.00
1CF76B	2017-08-08 04:30:00+03	10800.00
1CF79A	2017-07-31 20:45:00+03	125200.00
1CF820	2017-07-20 06:04:00+03	137600.00
1CF837	2017-08-13 12:24:00+03	14800.00
1CF867	2017-07-02 08:24:00+03	189000.00
1CF87C	2017-07-21 14:43:00+03	20000.00
1CF88B	2017-07-06 20:24:00+03	23400.00
1CF8B0	2017-07-09 10:52:00+03	11600.00
1CF8BE	2017-07-04 06:41:00+03	11900.00
1CF8E4	2017-07-30 00:41:00+03	13400.00
1CF8F5	2017-08-11 03:05:00+03	26000.00
1CF916	2017-08-11 12:45:00+03	189800.00
1CF9AF	2017-06-29 11:05:00+03	22400.00
1CF9B3	2017-07-22 16:43:00+03	36200.00
1CF9F9	2017-07-04 11:11:00+03	16400.00
1CFA69	2017-07-15 15:14:00+03	133700.00
1CFA83	2017-07-17 04:01:00+03	100600.00
1CFAE1	2017-07-28 12:03:00+03	24400.00
1CFB23	2017-08-15 01:42:00+03	40800.00
1CFB30	2017-08-14 15:22:00+03	68400.00
1CFB41	2017-08-02 03:11:00+03	6000.00
1CFB8C	2017-06-29 10:54:00+03	57400.00
1CFBA6	2017-07-31 04:23:00+03	111600.00
1CFBE3	2017-07-14 15:41:00+03	12900.00
1CFC0D	2017-07-03 18:06:00+03	77000.00
1CFC5F	2017-07-11 09:44:00+03	26700.00
1CFC66	2017-07-03 20:35:00+03	289300.00
1CFCC0	2017-07-26 15:08:00+03	22600.00
1CFCEC	2017-08-06 15:39:00+03	257400.00
1CFD4D	2017-08-13 23:21:00+03	182300.00
1CFD52	2017-08-07 23:31:00+03	52200.00
1CFD7D	2017-08-14 07:15:00+03	86800.00
1CFD85	2017-08-11 05:02:00+03	25100.00
1CFDAC	2017-08-10 12:27:00+03	36200.00
1CFDC1	2017-07-14 17:01:00+03	28300.00
1CFE03	2017-07-27 04:31:00+03	56600.00
1CFE3C	2017-07-15 21:07:00+03	78200.00
1CFE6F	2017-07-20 23:47:00+03	21400.00
1CFECF	2017-07-13 23:04:00+03	12600.00
1CFF36	2017-07-11 01:29:00+03	38600.00
1CFF3E	2017-07-27 12:30:00+03	37900.00
1CFF4D	2017-08-06 23:54:00+03	55500.00
1CFF70	2017-07-25 06:57:00+03	62500.00
1CFFBE	2017-07-21 06:39:00+03	21200.00
1CFFD3	2017-07-17 05:14:00+03	23100.00
1D000B	2017-08-14 06:18:00+03	15000.00
1D003B	2017-07-11 21:22:00+03	28000.00
1D008F	2017-07-10 23:25:00+03	38400.00
1D013F	2017-08-05 09:52:00+03	85400.00
1D014F	2017-07-12 11:25:00+03	31400.00
1D0164	2017-07-13 09:47:00+03	58600.00
1D0184	2017-08-15 16:10:00+03	17600.00
1D019B	2017-07-21 23:12:00+03	131600.00
1D0208	2017-07-19 04:42:00+03	134400.00
1D0210	2017-07-01 11:30:00+03	31600.00
1D02E9	2017-06-28 10:23:00+03	7400.00
1D03BA	2017-07-17 20:25:00+03	124200.00
1D03D2	2017-07-05 08:30:00+03	28800.00
1D040A	2017-07-03 20:33:00+03	98700.00
1D048C	2017-08-09 04:29:00+03	56000.00
1D04A2	2017-08-11 19:34:00+03	62600.00
1D054C	2017-08-12 11:48:00+03	246000.00
1D05B3	2017-08-03 07:20:00+03	56000.00
1D05C9	2017-07-31 22:59:00+03	115600.00
1D05D1	2017-07-24 14:36:00+03	26600.00
1D0629	2017-08-02 06:36:00+03	9300.00
1D0658	2017-07-18 07:15:00+03	136100.00
1D0665	2017-07-21 02:12:00+03	23100.00
1D06B8	2017-07-05 21:02:00+03	40800.00
1D06D9	2017-07-09 11:04:00+03	115100.00
1D06ED	2017-08-13 17:18:00+03	45100.00
1D06F8	2017-07-24 11:20:00+03	38800.00
1D0795	2017-08-01 17:30:00+03	108000.00
1D0808	2017-08-12 07:11:00+03	52100.00
1D0837	2017-07-16 09:27:00+03	37900.00
1D08A4	2017-07-11 00:18:00+03	95300.00
1D0944	2017-07-01 03:57:00+03	74700.00
1D097A	2017-07-10 22:19:00+03	39600.00
1D09ED	2017-07-09 05:11:00+03	39100.00
1D0A26	2017-08-02 01:48:00+03	34400.00
1D0B49	2017-08-11 15:19:00+03	15000.00
1D0B4E	2017-07-07 09:28:00+03	56600.00
1D0B55	2017-07-14 04:59:00+03	56600.00
1D0B6F	2017-07-06 06:43:00+03	32800.00
1D0BBA	2017-07-31 03:51:00+03	75800.00
1D0BE4	2017-07-26 12:44:00+03	266400.00
1D0C2D	2017-08-05 20:25:00+03	64100.00
1D0C62	2017-07-25 07:55:00+03	66000.00
1D0CB6	2017-08-15 12:00:00+03	147000.00
1D0D33	2017-07-12 03:41:00+03	56100.00
1D0D56	2017-08-10 15:24:00+03	138600.00
1D0D73	2017-07-30 16:34:00+03	55800.00
1D0DCB	2017-07-20 07:05:00+03	202200.00
1D0E45	2017-07-03 00:28:00+03	56600.00
1D0E5A	2017-08-05 08:21:00+03	59800.00
1D0E70	2017-07-11 20:16:00+03	29600.00
1D0EB6	2017-08-11 05:47:00+03	133200.00
1D0EB8	2017-07-20 02:15:00+03	68400.00
1D0EDA	2017-08-01 23:34:00+03	10800.00
1D0F42	2017-08-04 11:09:00+03	44800.00
1D0F49	2017-08-04 20:44:00+03	51600.00
1D0FEA	2017-07-26 20:34:00+03	11600.00
1D101F	2017-08-08 19:14:00+03	132800.00
1D1022	2017-08-06 15:53:00+03	125200.00
1D1081	2017-07-06 22:29:00+03	113200.00
1D11EA	2017-07-06 09:01:00+03	13400.00
1D1219	2017-07-30 14:48:00+03	133200.00
1D1246	2017-07-30 22:04:00+03	23600.00
1D12A8	2017-07-18 22:10:00+03	99200.00
1D12C8	2017-08-09 05:04:00+03	8200.00
1D1306	2017-07-23 20:21:00+03	112000.00
1D1392	2017-07-09 15:05:00+03	27200.00
1D13AE	2017-07-03 20:31:00+03	25400.00
1D1447	2017-08-06 14:11:00+03	13400.00
1D14E3	2017-07-24 12:03:00+03	51900.00
1D153A	2017-08-11 10:27:00+03	103000.00
1D1546	2017-08-01 20:59:00+03	28000.00
1D155B	2017-08-02 20:53:00+03	38000.00
1D158A	2017-07-26 00:49:00+03	28800.00
1D15C8	2017-07-06 00:42:00+03	29600.00
1D15CC	2017-07-09 21:14:00+03	36200.00
1D1602	2017-07-12 11:49:00+03	208100.00
1D1613	2017-07-04 12:00:00+03	61500.00
1D16C0	2017-07-10 22:03:00+03	52000.00
1D16F8	2017-08-06 13:20:00+03	86500.00
1D1760	2017-07-28 16:02:00+03	85000.00
1D17A7	2017-08-12 14:54:00+03	87200.00
1D18B6	2017-07-31 05:53:00+03	43300.00
1D18B9	2017-07-01 22:37:00+03	51900.00
1D18F6	2017-07-28 07:14:00+03	114400.00
1D1925	2017-07-23 20:21:00+03	23600.00
1D198C	2017-07-17 11:42:00+03	39000.00
1D19AA	2017-06-30 19:24:00+03	135200.00
1D19F7	2017-07-25 10:26:00+03	34000.00
1D1A3D	2017-08-09 16:32:00+03	181000.00
1D1A51	2017-07-14 14:45:00+03	137100.00
1D1A7E	2017-08-03 10:39:00+03	82800.00
1D1A8A	2017-07-19 23:18:00+03	26600.00
1D1AA2	2017-07-30 22:39:00+03	31400.00
1D1AAD	2017-07-14 02:14:00+03	96800.00
1D1AC9	2017-07-21 01:58:00+03	51300.00
1D1B55	2017-07-24 12:03:00+03	12400.00
1D1B8B	2017-08-02 13:56:00+03	99200.00
1D1B95	2017-06-28 08:46:00+03	73100.00
1D1C53	2017-07-01 02:34:00+03	44500.00
1D1CAA	2017-08-11 17:22:00+03	154500.00
1D1D50	2017-07-16 13:57:00+03	21500.00
1D1D81	2017-08-07 14:45:00+03	60700.00
1D1DAE	2017-07-28 00:10:00+03	28000.00
1D1DE6	2017-07-18 05:32:00+03	28800.00
1D1E0B	2017-07-06 10:10:00+03	53400.00
1D1E36	2017-07-20 15:27:00+03	42700.00
1D1E3A	2017-08-02 00:52:00+03	8600.00
1D1EBA	2017-07-26 21:26:00+03	186900.00
1D1F26	2017-07-19 13:24:00+03	40000.00
1D1F84	2017-08-02 19:14:00+03	42800.00
1D1FCC	2017-07-27 09:14:00+03	46400.00
1D204F	2017-07-21 02:52:00+03	50000.00
1D205A	2017-06-30 06:45:00+03	13000.00
1D206E	2017-08-08 09:11:00+03	148200.00
1D2083	2017-07-15 20:09:00+03	50600.00
1D20B2	2017-08-07 01:32:00+03	118000.00
1D2102	2017-07-21 10:21:00+03	39800.00
1D210D	2017-07-18 16:13:00+03	6000.00
1D2110	2017-07-02 20:26:00+03	12000.00
1D2113	2017-07-07 04:52:00+03	81700.00
1D2137	2017-07-08 16:59:00+03	77600.00
1D2139	2017-07-18 04:22:00+03	15100.00
1D21BC	2017-08-11 09:11:00+03	273600.00
1D21E5	2017-08-13 01:29:00+03	57800.00
1D2231	2017-07-26 12:27:00+03	38000.00
1D22A4	2017-07-26 16:50:00+03	12600.00
1D22F3	2017-07-24 08:00:00+03	96600.00
1D2358	2017-07-30 10:06:00+03	246000.00
1D2390	2017-07-27 15:06:00+03	217600.00
1D23F5	2017-07-09 19:04:00+03	32800.00
1D2411	2017-08-04 13:08:00+03	79600.00
1D244F	2017-07-17 08:18:00+03	17500.00
1D2467	2017-07-03 22:18:00+03	85000.00
1D247A	2017-07-23 19:46:00+03	26000.00
1D24B0	2017-07-05 15:11:00+03	27800.00
1D252D	2017-07-20 14:34:00+03	32800.00
1D2550	2017-08-02 11:19:00+03	151200.00
1D2557	2017-07-11 10:19:00+03	25600.00
1D25B6	2017-07-28 11:51:00+03	47600.00
1D2712	2017-07-25 16:11:00+03	55800.00
1D2776	2017-07-21 20:55:00+03	67600.00
1D27FE	2017-07-30 14:43:00+03	92900.00
1D2853	2017-07-05 08:31:00+03	12000.00
1D286F	2017-07-16 13:39:00+03	133100.00
1D2897	2017-08-13 07:17:00+03	83300.00
1D28EE	2017-08-11 08:48:00+03	64700.00
1D2943	2017-08-10 12:15:00+03	19800.00
1D2958	2017-07-31 01:16:00+03	73600.00
1D2978	2017-07-11 09:00:00+03	99300.00
1D29B2	2017-08-15 14:38:00+03	131100.00
1D2A0E	2017-08-03 08:02:00+03	265600.00
1D2AD7	2017-07-21 13:38:00+03	46000.00
1D2AE6	2017-07-20 21:11:00+03	125500.00
1D2B35	2017-08-12 03:17:00+03	14400.00
1D2B51	2017-08-04 09:09:00+03	40200.00
1D2B8F	2017-07-13 04:28:00+03	67700.00
1D2BCA	2017-08-03 12:02:00+03	18000.00
1D2BF0	2017-08-04 11:47:00+03	26000.00
1D2BFF	2017-07-14 02:10:00+03	40600.00
1D2C21	2017-08-02 12:25:00+03	19600.00
1D2C22	2017-07-23 20:35:00+03	95200.00
1D2C62	2017-07-10 19:04:00+03	31600.00
1D2C9A	2017-07-25 18:22:00+03	67200.00
1D2CB9	2017-07-19 12:11:00+03	58600.00
1D2CC2	2017-08-06 16:55:00+03	155600.00
1D2D8A	2017-07-09 16:22:00+03	75600.00
1D2D8E	2017-07-07 23:59:00+03	62800.00
1D2DB3	2017-07-09 17:48:00+03	46500.00
1D2DF5	2017-08-13 18:41:00+03	28000.00
1D2DF8	2017-08-02 22:13:00+03	92100.00
1D2E94	2017-06-25 09:24:00+03	146300.00
1D2F0C	2017-08-03 15:15:00+03	28800.00
1D2F1F	2017-07-03 23:46:00+03	38800.00
1D2F30	2017-07-31 14:51:00+03	458700.00
1D2F94	2017-07-19 01:55:00+03	44000.00
1D2FB1	2017-08-03 12:10:00+03	184500.00
1D2FED	2017-07-24 00:12:00+03	81300.00
1D2FF8	2017-07-24 17:13:00+03	50600.00
1D3021	2017-06-29 08:28:00+03	38600.00
1D3028	2017-07-05 21:01:00+03	44800.00
1D3044	2017-08-06 11:55:00+03	32500.00
1D3052	2017-08-15 02:08:00+03	27200.00
1D3060	2017-07-12 03:15:00+03	28800.00
1D31BC	2017-08-14 21:11:00+03	12000.00
1D31C0	2017-07-30 10:54:00+03	37900.00
1D3282	2017-07-22 19:15:00+03	103200.00
1D32D5	2017-07-20 19:36:00+03	81300.00
1D3300	2017-06-30 13:55:00+03	9200.00
1D3312	2017-07-14 09:02:00+03	25600.00
1D3313	2017-07-22 09:07:00+03	24700.00
1D338E	2017-07-24 14:14:00+03	21400.00
1D33A6	2017-08-01 13:02:00+03	113200.00
1D33C6	2017-08-03 04:10:00+03	148800.00
1D33FD	2017-07-29 09:26:00+03	16400.00
1D3415	2017-07-17 08:31:00+03	135400.00
1D3436	2017-07-18 04:44:00+03	42800.00
1D3467	2017-07-06 22:29:00+03	31100.00
1D3490	2017-07-26 01:14:00+03	93900.00
1D3495	2017-07-19 00:05:00+03	32800.00
1D3497	2017-07-29 01:56:00+03	40700.00
1D355C	2017-08-02 11:28:00+03	19600.00
1D356A	2017-07-31 05:59:00+03	56000.00
1D35E6	2017-07-29 20:14:00+03	42800.00
1D366B	2017-07-28 14:06:00+03	131900.00
1D369A	2017-08-13 14:15:00+03	8200.00
1D370F	2017-07-16 17:30:00+03	147700.00
1D3721	2017-08-09 21:04:00+03	23200.00
1D374F	2017-08-08 19:29:00+03	29400.00
1D3775	2017-08-09 21:29:00+03	112600.00
1D37AC	2017-08-10 10:08:00+03	23400.00
1D3820	2017-07-09 23:47:00+03	10600.00
1D3878	2017-07-26 22:34:00+03	100600.00
1D38A0	2017-07-03 15:38:00+03	133700.00
1D38FB	2017-07-01 23:32:00+03	96200.00
1D390B	2017-07-20 21:02:00+03	79600.00
1D395D	2017-07-31 21:07:00+03	263100.00
1D396C	2017-07-30 02:12:00+03	52000.00
1D3A30	2017-08-06 22:29:00+03	67200.00
1D3B06	2017-07-17 17:33:00+03	57600.00
1D3B8D	2017-08-01 11:27:00+03	70600.00
1D3BFF	2017-07-09 17:04:00+03	92800.00
1D3C2A	2017-07-18 22:42:00+03	118900.00
1D3C40	2017-08-12 19:30:00+03	112400.00
1D3C52	2017-07-07 20:03:00+03	48200.00
1D3CAA	2017-07-17 11:23:00+03	123000.00
1D3CEA	2017-08-14 05:28:00+03	391000.00
1D3D66	2017-07-11 23:28:00+03	32800.00
1D3DDF	2017-07-07 08:47:00+03	6700.00
1D3E22	2017-08-13 19:02:00+03	73600.00
1D3E39	2017-07-31 22:48:00+03	172200.00
1D3EBC	2017-07-18 21:02:00+03	66600.00
1D3EC0	2017-08-08 20:29:00+03	51900.00
1D3ED2	2017-07-29 04:21:00+03	37300.00
1D3ED5	2017-07-04 09:48:00+03	70800.00
1D3F0C	2017-08-07 09:28:00+03	46000.00
1D3F3B	2017-07-11 21:31:00+03	28800.00
1D3F43	2017-08-10 16:36:00+03	92000.00
1D3F61	2017-08-01 11:33:00+03	26000.00
1D3F82	2017-07-18 17:13:00+03	265700.00
1D3FE8	2017-07-08 22:13:00+03	24000.00
1D404C	2017-07-11 23:04:00+03	67000.00
1D40CA	2017-07-12 13:15:00+03	92700.00
1D40E1	2017-07-11 11:47:00+03	95600.00
1D4117	2017-08-13 04:24:00+03	29500.00
1D415E	2017-07-15 07:33:00+03	15700.00
1D4198	2017-08-10 09:43:00+03	33000.00
1D4267	2017-08-04 01:07:00+03	225800.00
1D42B7	2017-07-29 17:12:00+03	26000.00
1D434C	2017-07-29 03:02:00+03	79000.00
1D4365	2017-07-18 00:04:00+03	50600.00
1D443B	2017-07-24 07:56:00+03	56000.00
1D4451	2017-07-08 20:34:00+03	67700.00
1D44B4	2017-07-11 07:32:00+03	28600.00
1D44D9	2017-07-16 16:53:00+03	6700.00
1D4501	2017-08-02 02:10:00+03	19600.00
1D4604	2017-07-10 21:18:00+03	92800.00
1D4644	2017-07-03 16:33:00+03	43600.00
1D468B	2017-07-10 01:14:00+03	51600.00
1D4693	2017-08-07 21:54:00+03	21600.00
1D46C0	2017-07-19 11:27:00+03	149200.00
1D46D7	2017-07-02 23:20:00+03	77600.00
1D46E5	2017-08-08 06:11:00+03	99700.00
1D4718	2017-07-30 21:21:00+03	40600.00
1D473B	2017-08-01 05:08:00+03	73500.00
1D47B1	2017-08-13 14:20:00+03	222800.00
1D47C5	2017-06-27 00:51:00+03	46300.00
1D47F5	2017-08-04 07:44:00+03	123000.00
1D481B	2017-08-01 16:50:00+03	24800.00
1D483C	2017-08-14 11:18:00+03	23400.00
1D4922	2017-07-08 05:06:00+03	22000.00
1D4959	2017-07-09 06:08:00+03	265600.00
1D498C	2017-08-10 23:27:00+03	55800.00
1D498F	2017-08-07 11:59:00+03	23600.00
1D49B4	2017-07-07 16:12:00+03	153200.00
1D4A16	2017-08-12 11:17:00+03	119400.00
1D4A30	2017-07-24 06:20:00+03	113300.00
1D4A31	2017-07-03 08:35:00+03	59000.00
1D4A8C	2017-07-06 04:24:00+03	23400.00
1D4B6F	2017-07-30 18:12:00+03	203000.00
1D4C0B	2017-07-14 21:18:00+03	75600.00
1D4C68	2017-07-30 05:40:00+03	244800.00
1D4CBA	2017-08-14 04:42:00+03	73300.00
1D4CBF	2017-07-23 14:48:00+03	69500.00
1D4D22	2017-08-15 07:25:00+03	175200.00
1D4D27	2017-08-10 04:28:00+03	32800.00
1D4D7A	2017-07-04 12:23:00+03	63200.00
1D4DAF	2017-08-09 21:37:00+03	20600.00
1D4DB5	2017-07-04 12:26:00+03	124400.00
1D4DD8	2017-08-02 16:58:00+03	16000.00
1D4DE7	2017-08-08 22:49:00+03	36200.00
1D4E54	2017-08-02 21:51:00+03	173900.00
1D4E84	2017-07-21 14:12:00+03	112000.00
1D4EDC	2017-08-13 08:51:00+03	113600.00
1D4F0A	2017-07-31 16:05:00+03	129200.00
1D4F14	2017-08-15 12:25:00+03	25000.00
1D4F82	2017-07-02 15:25:00+03	44000.00
1D4F9F	2017-07-03 11:50:00+03	29600.00
1D4FD4	2017-08-15 05:23:00+03	55000.00
1D4FF4	2017-07-25 00:18:00+03	35300.00
1D5015	2017-07-06 12:31:00+03	12300.00
1D5018	2017-07-27 22:06:00+03	62000.00
1D502A	2017-07-22 05:56:00+03	28000.00
1D5053	2017-06-28 15:56:00+03	59300.00
1D5123	2017-07-31 19:03:00+03	8000.00
1D518E	2017-07-01 23:17:00+03	59900.00
1D51F1	2017-07-28 16:11:00+03	112300.00
1D5246	2017-08-12 23:37:00+03	56000.00
1D5254	2017-08-14 13:36:00+03	26700.00
1D525F	2017-08-04 23:08:00+03	39300.00
1D5289	2017-07-13 06:03:00+03	114800.00
1D52AE	2017-08-08 05:25:00+03	282300.00
1D52CD	2017-08-13 21:28:00+03	42800.00
1D53B7	2017-07-14 21:03:00+03	65600.00
1D541C	2017-07-05 10:51:00+03	44800.00
1D5429	2017-07-10 03:29:00+03	399600.00
1D54FA	2017-07-16 01:00:00+03	111600.00
1D55EA	2017-08-01 09:45:00+03	42800.00
1D5647	2017-07-25 23:38:00+03	119800.00
1D5670	2017-07-13 10:51:00+03	18000.00
1D572C	2017-07-22 22:20:00+03	103000.00
1D5762	2017-07-21 03:08:00+03	69700.00
1D5838	2017-07-21 09:54:00+03	59800.00
1D5874	2017-08-14 07:57:00+03	123000.00
1D5926	2017-07-25 16:25:00+03	31400.00
1D5968	2017-08-07 15:26:00+03	61100.00
1D599A	2017-07-20 07:00:00+03	23400.00
1D59DA	2017-07-23 06:58:00+03	49100.00
1D5A54	2017-08-04 17:35:00+03	32800.00
1D5A67	2017-08-09 12:51:00+03	48800.00
1D5A85	2017-08-05 05:49:00+03	24700.00
1D5B37	2017-07-18 10:03:00+03	91200.00
1D5B66	2017-07-07 08:52:00+03	6700.00
1D5BBF	2017-06-30 06:44:00+03	40800.00
1D5BDD	2017-08-07 14:12:00+03	29500.00
1D5C2C	2017-08-03 02:50:00+03	64800.00
1D5C7C	2017-08-04 10:38:00+03	46000.00
1D5C93	2017-07-05 11:42:00+03	43900.00
1D5CB9	2017-08-11 01:40:00+03	59800.00
1D5CCA	2017-07-21 09:11:00+03	46300.00
1D5CF6	2017-07-15 04:59:00+03	67800.00
1D5D17	2017-08-02 11:17:00+03	47900.00
1D5DDF	2017-08-15 17:34:00+03	55800.00
1D5E11	2017-07-08 15:21:00+03	53300.00
1D5E97	2017-07-10 18:29:00+03	69200.00
1D5EDE	2017-08-13 12:36:00+03	54200.00
1D5EF4	2017-08-14 18:18:00+03	272400.00
1D5F57	2017-08-03 05:27:00+03	46000.00
1D5F61	2017-07-02 17:29:00+03	112000.00
1D5F75	2017-07-12 11:18:00+03	28000.00
1D5F8A	2017-08-14 22:58:00+03	67900.00
1D6013	2017-07-18 01:22:00+03	27300.00
1D6067	2017-07-05 11:48:00+03	22000.00
1D60B9	2017-07-27 14:53:00+03	122600.00
1D60E2	2017-07-17 07:27:00+03	14000.00
1D611C	2017-08-12 03:08:00+03	88400.00
1D6154	2017-07-04 11:27:00+03	59200.00
1D61B9	2017-07-24 05:25:00+03	31400.00
1D6295	2017-08-08 22:53:00+03	116400.00
1D62DC	2017-08-07 19:41:00+03	21400.00
1D62EB	2017-07-16 07:48:00+03	86300.00
1D6326	2017-07-10 20:00:00+03	223200.00
1D638D	2017-07-22 18:40:00+03	65000.00
1D63CC	2017-08-05 03:46:00+03	37900.00
1D63F7	2017-07-08 14:16:00+03	112000.00
1D644B	2017-07-05 11:47:00+03	109600.00
1D64CA	2017-07-08 10:45:00+03	26700.00
1D64D8	2017-07-10 10:47:00+03	27600.00
1D6520	2017-08-10 05:19:00+03	49200.00
1D6526	2017-07-17 01:17:00+03	76200.00
1D6538	2017-08-08 17:01:00+03	46000.00
1D654B	2017-08-11 04:42:00+03	56600.00
1D6558	2017-07-15 22:32:00+03	96800.00
1D6617	2017-08-03 19:04:00+03	13200.00
1D663D	2017-08-09 03:59:00+03	291100.00
1D6714	2017-07-22 10:32:00+03	56000.00
1D671A	2017-07-11 06:53:00+03	44800.00
1D673A	2017-07-11 20:00:00+03	133200.00
1D67C2	2017-07-14 10:57:00+03	58000.00
1D67CD	2017-08-04 19:57:00+03	16400.00
1D680C	2017-07-29 14:03:00+03	142000.00
1D682A	2017-08-11 18:52:00+03	23600.00
1D685B	2017-07-30 02:27:00+03	35300.00
1D687E	2017-07-29 01:51:00+03	51300.00
1D6891	2017-08-02 21:23:00+03	51900.00
1D68AE	2017-08-09 14:41:00+03	62200.00
1D68AF	2017-07-17 00:34:00+03	6300.00
1D6904	2017-07-05 05:52:00+03	58800.00
1D6961	2017-08-09 18:24:00+03	112000.00
1D697E	2017-08-09 22:50:00+03	168000.00
1D69D0	2017-07-06 22:42:00+03	49800.00
1D6A21	2017-08-01 12:04:00+03	28000.00
1D6A36	2017-07-28 15:42:00+03	49200.00
1D6A3F	2017-07-24 22:21:00+03	21400.00
1D6A70	2017-08-03 20:19:00+03	132800.00
1D6AC1	2017-07-30 21:43:00+03	28800.00
1D6AC2	2017-08-02 21:09:00+03	92900.00
1D6AD6	2017-07-10 06:55:00+03	271200.00
1D6B31	2017-07-14 15:57:00+03	311200.00
1D6C0C	2017-07-14 08:23:00+03	68800.00
1D6C64	2017-07-04 12:47:00+03	93700.00
1D6C67	2017-08-06 22:47:00+03	27200.00
1D6C8A	2017-07-29 16:27:00+03	46200.00
1D6CB5	2017-08-11 19:03:00+03	56900.00
1D6D34	2017-07-31 07:39:00+03	83000.00
1D6D64	2017-06-30 23:45:00+03	97600.00
1D6D75	2017-07-24 15:18:00+03	119800.00
1D6DF3	2017-07-09 00:32:00+03	37700.00
1D6E32	2017-08-14 04:15:00+03	55800.00
1D6E3A	2017-07-12 04:27:00+03	201200.00
1D6E65	2017-07-24 17:43:00+03	41600.00
1D6E81	2017-07-28 20:28:00+03	54800.00
1D6E95	2017-07-04 14:20:00+03	21000.00
1D6EBC	2017-07-24 11:26:00+03	86400.00
1D6ECE	2017-07-12 08:15:00+03	75300.00
1D6F2B	2017-08-01 11:36:00+03	59000.00
1D6F8C	2017-07-18 01:13:00+03	246000.00
1D6FC7	2017-07-16 19:06:00+03	39800.00
1D7040	2017-07-18 16:34:00+03	75300.00
1D7069	2017-07-15 08:18:00+03	77600.00
1D7075	2017-07-25 22:17:00+03	121200.00
1D70C5	2017-07-23 02:58:00+03	295400.00
1D70E0	2017-07-29 14:42:00+03	66600.00
1D70F4	2017-07-06 10:32:00+03	118600.00
1D713A	2017-07-21 00:40:00+03	12000.00
1D713D	2017-08-03 10:06:00+03	56000.00
1D7151	2017-07-04 01:33:00+03	58800.00
1D716E	2017-07-09 04:49:00+03	59200.00
1D7193	2017-08-05 15:47:00+03	79800.00
1D71A5	2017-08-01 08:18:00+03	303500.00
1D71D0	2017-08-12 16:44:00+03	16400.00
1D7288	2017-08-08 15:14:00+03	15000.00
1D7297	2017-07-19 15:48:00+03	40400.00
1D7303	2017-07-21 03:31:00+03	58000.00
1D731F	2017-07-23 02:40:00+03	18400.00
1D7326	2017-08-06 09:52:00+03	26000.00
1D7337	2017-07-30 00:57:00+03	386300.00
1D7351	2017-08-14 11:22:00+03	64800.00
1D735D	2017-07-23 02:58:00+03	54400.00
1D73A9	2017-07-26 14:21:00+03	82700.00
1D7401	2017-07-30 02:24:00+03	72400.00
1D7425	2017-07-26 08:27:00+03	173400.00
1D7438	2017-08-15 07:24:00+03	47400.00
1D743E	2017-07-12 17:54:00+03	12400.00
1D7444	2017-08-07 12:24:00+03	29800.00
1D7458	2017-08-02 00:40:00+03	99200.00
1D74A6	2017-08-12 02:37:00+03	19600.00
1D74A7	2017-07-05 18:30:00+03	60400.00
1D74D1	2017-07-30 12:56:00+03	36400.00
1D74D5	2017-07-22 04:33:00+03	90300.00
1D74E1	2017-07-16 20:17:00+03	31400.00
1D74F2	2017-07-29 15:20:00+03	27200.00
1D752E	2017-08-13 15:32:00+03	43500.00
1D75AF	2017-08-12 19:40:00+03	95200.00
1D760A	2017-06-30 07:56:00+03	92800.00
1D7612	2017-08-07 02:34:00+03	43700.00
1D766A	2017-07-27 13:42:00+03	121400.00
1D766D	2017-07-05 07:16:00+03	27600.00
1D76DD	2017-08-14 14:18:00+03	153200.00
1D76ED	2017-07-29 12:42:00+03	31100.00
1D76EE	2017-08-04 21:38:00+03	15000.00
1D777C	2017-07-18 07:46:00+03	22000.00
1D77E1	2017-07-20 14:43:00+03	57800.00
1D780B	2017-08-09 00:58:00+03	29400.00
1D7890	2017-07-04 11:56:00+03	134400.00
1D78C4	2017-08-12 03:08:00+03	21400.00
1D78CA	2017-07-27 07:11:00+03	13400.00
1D78DC	2017-08-06 20:47:00+03	16400.00
1D78FC	2017-07-11 23:53:00+03	112000.00
1D7902	2017-07-28 23:40:00+03	28000.00
1D7941	2017-07-12 10:31:00+03	30200.00
1D796E	2017-07-02 12:42:00+03	7200.00
1D79DF	2017-08-08 06:04:00+03	132800.00
1D7A5A	2017-08-11 02:44:00+03	153300.00
1D7B1A	2017-07-23 15:53:00+03	12600.00
1D7B2E	2017-07-29 10:47:00+03	135400.00
1D7B5F	2017-07-03 14:19:00+03	22600.00
1D7B81	2017-08-10 18:22:00+03	43900.00
1D7BBD	2017-08-14 16:04:00+03	12200.00
1D7BC7	2017-07-05 03:25:00+03	33300.00
1D7BE1	2017-07-13 12:03:00+03	29400.00
1D7BF8	2017-07-09 09:33:00+03	112000.00
1D7C08	2017-07-16 13:00:00+03	31200.00
1D7C93	2017-07-06 19:58:00+03	62700.00
1D7D37	2017-08-07 06:29:00+03	38400.00
1D7D56	2017-07-29 08:08:00+03	115700.00
1D7DA6	2017-07-22 12:47:00+03	25400.00
1D7DE8	2017-07-17 18:59:00+03	111600.00
1D7DF7	2017-07-25 20:19:00+03	111600.00
1D7F4B	2017-08-15 16:36:00+03	68000.00
1D7F93	2017-08-10 01:50:00+03	132800.00
1D7F97	2017-07-16 06:43:00+03	40400.00
1D8052	2017-07-31 20:12:00+03	181200.00
1D8104	2017-07-02 09:14:00+03	240600.00
1D8129	2017-08-14 07:15:00+03	64200.00
1D8134	2017-07-18 06:09:00+03	19400.00
1D81AA	2017-08-06 19:19:00+03	56000.00
1D81B2	2017-07-17 11:08:00+03	531400.00
1D81F1	2017-07-11 23:32:00+03	169000.00
1D823E	2017-07-09 01:52:00+03	12600.00
1D8323	2017-08-09 14:24:00+03	73600.00
1D8344	2017-07-08 17:37:00+03	43500.00
1D8380	2017-06-30 17:58:00+03	88600.00
1D838D	2017-08-04 19:56:00+03	66600.00
1D83E0	2017-07-21 14:30:00+03	16400.00
1D8407	2017-07-10 11:14:00+03	166900.00
1D8466	2017-07-14 04:47:00+03	56900.00
1D84CC	2017-08-02 01:43:00+03	23400.00
1D8512	2017-07-21 20:52:00+03	47100.00
1D856A	2017-08-10 08:47:00+03	52900.00
1D8631	2017-08-10 14:38:00+03	6700.00
1D864B	2017-08-07 15:38:00+03	40800.00
1D86C7	2017-07-02 01:07:00+03	108500.00
1D86E6	2017-07-31 07:02:00+03	63400.00
1D86E9	2017-08-01 14:20:00+03	80400.00
1D8730	2017-08-13 01:37:00+03	111600.00
1D8770	2017-07-15 12:05:00+03	429100.00
1D8799	2017-07-03 05:10:00+03	399600.00
1D87DA	2017-06-30 02:05:00+03	20000.00
1D883D	2017-07-31 00:06:00+03	45200.00
1D888C	2017-08-06 19:30:00+03	126700.00
1D88AB	2017-07-07 23:36:00+03	57500.00
1D88EE	2017-07-05 13:09:00+03	93700.00
1D8901	2017-07-11 09:46:00+03	115800.00
1D8956	2017-07-07 17:53:00+03	123000.00
1D89B3	2017-07-26 02:39:00+03	54500.00
1D89C4	2017-08-08 04:26:00+03	81200.00
1D89CB	2017-07-22 23:45:00+03	135400.00
1D89D2	2017-08-09 02:35:00+03	60400.00
1D89FB	2017-07-30 23:34:00+03	22400.00
1D8A15	2017-07-24 18:28:00+03	102100.00
1D8A38	2017-07-07 07:29:00+03	23200.00
1D8A53	2017-08-03 06:56:00+03	46000.00
1D8AA7	2017-07-28 01:20:00+03	48800.00
1D8B7E	2017-07-26 04:03:00+03	34000.00
1D8B95	2017-07-06 18:11:00+03	12100.00
1D8BAB	2017-08-13 13:05:00+03	31800.00
1D8BAD	2017-07-24 13:09:00+03	18000.00
1D8BE2	2017-07-07 00:56:00+03	28000.00
1D8C4D	2017-07-19 00:37:00+03	28300.00
1D8C76	2017-08-06 16:18:00+03	46900.00
1D8C85	2017-07-02 08:58:00+03	6000.00
1D8D61	2017-08-13 16:08:00+03	136500.00
1D8D64	2017-07-08 23:29:00+03	56600.00
1D8DC2	2017-07-10 23:51:00+03	25200.00
1D8DDC	2017-07-20 09:47:00+03	80000.00
1D8E3E	2017-07-09 11:13:00+03	41400.00
1D8E5D	2017-07-05 05:54:00+03	94700.00
1D8E63	2017-08-13 23:47:00+03	67200.00
1D8E6B	2017-08-07 02:42:00+03	9300.00
1D8E80	2017-08-14 05:53:00+03	67600.00
1D8EA2	2017-07-08 10:27:00+03	59200.00
1D8FAC	2017-07-07 13:00:00+03	13400.00
1D8FB8	2017-07-16 23:46:00+03	123000.00
1D900A	2017-07-12 22:59:00+03	66600.00
1D902D	2017-08-07 20:12:00+03	62400.00
1D907B	2017-07-31 01:23:00+03	129700.00
1D90AC	2017-07-02 09:18:00+03	56400.00
1D90AF	2017-07-31 13:26:00+03	113300.00
1D90BC	2017-07-22 17:19:00+03	16400.00
1D9108	2017-07-06 01:07:00+03	135600.00
1D9123	2017-07-11 00:13:00+03	111600.00
1D9196	2017-08-13 21:51:00+03	109400.00
1D91C5	2017-08-10 20:56:00+03	80900.00
1D91D3	2017-07-13 12:53:00+03	52900.00
1D921D	2017-07-04 09:31:00+03	119500.00
1D92B3	2017-07-16 00:39:00+03	40800.00
1D92F8	2017-07-26 18:09:00+03	6700.00
1D931B	2017-08-03 06:23:00+03	31400.00
1D9343	2017-07-26 16:42:00+03	111600.00
1D9346	2017-06-28 01:03:00+03	53100.00
1D936C	2017-08-01 12:14:00+03	31100.00
1D936D	2017-07-08 02:15:00+03	24300.00
1D9371	2017-08-12 10:33:00+03	59800.00
1D939E	2017-07-19 15:05:00+03	154500.00
1D9405	2017-08-13 11:15:00+03	13400.00
1D9419	2017-07-02 08:52:00+03	49500.00
1D9428	2017-07-21 12:53:00+03	93900.00
1D9435	2017-07-30 18:19:00+03	31100.00
1D9444	2017-07-18 19:26:00+03	17600.00
1D945F	2017-06-29 17:24:00+03	26000.00
1D9526	2017-08-01 22:23:00+03	147200.00
1D956C	2017-07-07 09:48:00+03	67600.00
1D9573	2017-07-24 06:14:00+03	26800.00
1D9582	2017-07-04 15:39:00+03	130700.00
1D959F	2017-07-21 01:36:00+03	105400.00
1D95AE	2017-07-10 20:54:00+03	249100.00
1D9603	2017-07-15 08:04:00+03	72400.00
1D9731	2017-07-07 18:36:00+03	190100.00
1D9746	2017-07-16 17:17:00+03	50800.00
1D975A	2017-07-02 09:58:00+03	55800.00
1D977D	2017-07-05 23:52:00+03	246000.00
1D9784	2017-07-13 02:46:00+03	18700.00
1D9791	2017-07-02 23:31:00+03	26800.00
1D9821	2017-07-26 06:36:00+03	132800.00
1D9841	2017-07-05 07:41:00+03	84500.00
1D98B1	2017-07-27 05:07:00+03	84100.00
1D98B6	2017-07-27 02:28:00+03	31800.00
1D98CC	2017-08-01 17:28:00+03	131600.00
1D98D2	2017-08-09 07:17:00+03	28000.00
1D98E6	2017-07-17 09:29:00+03	44500.00
1D9926	2017-07-03 00:26:00+03	232100.00
1D9929	2017-08-06 02:33:00+03	34000.00
1D9942	2017-06-30 21:40:00+03	42800.00
1D9992	2017-07-25 10:51:00+03	73400.00
1D9A71	2017-07-03 03:41:00+03	135400.00
1D9A8E	2017-07-06 19:25:00+03	54800.00
1D9AD0	2017-07-25 19:53:00+03	41800.00
1D9B26	2017-08-07 10:39:00+03	33200.00
1D9B5E	2017-08-02 01:49:00+03	56900.00
1D9B8C	2017-08-15 10:15:00+03	26000.00
1D9C46	2017-07-03 20:41:00+03	53300.00
1D9C58	2017-07-12 14:21:00+03	26200.00
1D9C89	2017-07-09 07:51:00+03	146600.00
1D9CD4	2017-07-16 06:13:00+03	108600.00
1D9CED	2017-07-15 11:54:00+03	87200.00
1D9D2B	2017-07-18 21:30:00+03	58200.00
1D9D63	2017-07-16 15:55:00+03	92800.00
1D9D6E	2017-07-01 13:32:00+03	59000.00
1D9DA1	2017-07-29 21:47:00+03	36200.00
1D9DEC	2017-07-29 10:02:00+03	57300.00
1D9DF9	2017-07-14 20:11:00+03	26000.00
1D9E3B	2017-07-16 05:01:00+03	61500.00
1D9E7E	2017-07-02 09:23:00+03	479000.00
1D9E90	2017-07-11 13:53:00+03	23200.00
1D9EE9	2017-08-10 03:39:00+03	69500.00
1D9F40	2017-07-23 05:40:00+03	56600.00
1D9F42	2017-07-21 05:15:00+03	39000.00
1D9F79	2017-07-06 10:46:00+03	63200.00
1D9F9E	2017-06-30 12:11:00+03	7800.00
1D9FA1	2017-07-20 23:50:00+03	439300.00
1DA008	2017-07-09 17:20:00+03	57800.00
1DA058	2017-07-06 21:42:00+03	31800.00
1DA060	2017-07-24 09:29:00+03	31100.00
1DA0D9	2017-07-11 22:09:00+03	17800.00
1DA0E7	2017-08-09 09:07:00+03	99300.00
1DA0F4	2017-07-04 23:04:00+03	65400.00
1DA10E	2017-07-31 04:57:00+03	119800.00
1DA265	2017-07-20 15:06:00+03	133100.00
1DA282	2017-07-26 02:54:00+03	103600.00
1DA2DA	2017-07-11 18:56:00+03	41600.00
1DA2DD	2017-08-12 02:26:00+03	67600.00
1DA325	2017-07-21 03:54:00+03	38300.00
1DA343	2017-07-21 19:41:00+03	28800.00
1DA35A	2017-07-26 13:33:00+03	94200.00
1DA3AD	2017-07-21 23:17:00+03	136200.00
1DA3F2	2017-06-27 13:25:00+03	54800.00
1DA421	2017-08-07 00:32:00+03	101100.00
1DA43C	2017-08-05 05:30:00+03	26000.00
1DA545	2017-07-08 04:16:00+03	553800.00
1DA5C0	2017-08-11 08:05:00+03	89200.00
1DA61D	2017-08-03 10:56:00+03	59200.00
1DA62E	2017-08-02 15:37:00+03	60400.00
1DA66D	2017-07-26 20:02:00+03	90100.00
1DA6EB	2017-07-28 18:03:00+03	143400.00
1DA716	2017-07-13 17:32:00+03	46300.00
1DA769	2017-07-18 14:45:00+03	12600.00
1DA776	2017-07-05 22:31:00+03	14000.00
1DA781	2017-07-13 07:48:00+03	57800.00
1DA7A2	2017-08-12 22:35:00+03	93400.00
1DA7C4	2017-07-22 05:13:00+03	29100.00
1DA848	2017-08-08 12:35:00+03	63500.00
1DA849	2017-07-14 04:49:00+03	27200.00
1DA85C	2017-07-13 21:39:00+03	67600.00
1DA8C3	2017-07-13 08:52:00+03	6000.00
1DA8C8	2017-07-08 06:15:00+03	34100.00
1DA8CA	2017-08-15 14:13:00+03	139300.00
1DA915	2017-08-12 07:21:00+03	136000.00
1DA91A	2017-08-11 06:42:00+03	28600.00
1DA95F	2017-07-14 15:23:00+03	53600.00
1DA999	2017-07-04 15:09:00+03	25800.00
1DA9A5	2017-07-22 23:12:00+03	224000.00
1DA9E7	2017-07-27 11:39:00+03	65900.00
1DAA1A	2017-08-07 19:43:00+03	43900.00
1DAA3B	2017-07-16 13:35:00+03	203300.00
1DAA47	2017-08-12 10:02:00+03	69000.00
1DAA8E	2017-07-30 04:06:00+03	114800.00
1DAAB5	2017-07-03 00:27:00+03	281500.00
1DAB02	2017-08-04 17:59:00+03	37200.00
1DAB26	2017-08-02 14:37:00+03	73600.00
1DAB3D	2017-07-23 05:42:00+03	399600.00
1DAC89	2017-08-04 15:08:00+03	123600.00
1DACE4	2017-07-19 06:22:00+03	43000.00
1DACFE	2017-08-10 19:52:00+03	12600.00
1DAD03	2017-07-12 17:27:00+03	65900.00
1DAD4B	2017-07-25 02:04:00+03	48800.00
1DAD96	2017-07-12 06:38:00+03	26800.00
1DADA0	2017-07-14 02:07:00+03	56400.00
1DADA9	2017-07-18 18:05:00+03	136500.00
1DADC2	2017-07-24 09:31:00+03	65500.00
1DAE12	2017-08-15 16:03:00+03	122200.00
1DAE1A	2017-08-07 14:05:00+03	39400.00
1DAE4C	2017-07-31 20:19:00+03	143100.00
1DAE8B	2017-08-02 08:50:00+03	68800.00
1DAE97	2017-07-15 02:57:00+03	132300.00
1DAED7	2017-07-31 15:48:00+03	40600.00
1DAEEE	2017-07-04 01:37:00+03	40800.00
1DAF76	2017-07-18 02:44:00+03	40600.00
1DAFDC	2017-06-29 02:18:00+03	57500.00
1DAFEA	2017-08-05 20:34:00+03	98400.00
1DB07F	2017-07-29 03:26:00+03	28800.00
1DB0A1	2017-07-09 08:18:00+03	47100.00
1DB0AC	2017-08-14 15:34:00+03	26700.00
1DB0FF	2017-07-06 22:56:00+03	46000.00
1DB14F	2017-08-03 06:24:00+03	52300.00
1DB1DB	2017-07-15 00:33:00+03	36400.00
1DB1DD	2017-08-13 11:13:00+03	132800.00
1DB22E	2017-08-06 02:17:00+03	17000.00
1DB297	2017-08-05 12:36:00+03	125000.00
1DB2B7	2017-07-21 04:36:00+03	66000.00
1DB2E8	2017-07-31 01:44:00+03	133100.00
1DB2EC	2017-07-04 23:37:00+03	87900.00
1DB38E	2017-07-06 04:47:00+03	23200.00
1DB3FB	2017-07-27 14:46:00+03	66600.00
1DB427	2017-07-13 17:41:00+03	56000.00
1DB454	2017-06-26 22:06:00+03	55800.00
1DB483	2017-07-30 11:30:00+03	20200.00
1DB4B5	2017-07-20 22:43:00+03	123000.00
1DB565	2017-07-29 06:44:00+03	199200.00
1DB581	2017-07-08 03:34:00+03	202800.00
1DB59A	2017-08-11 10:18:00+03	24700.00
1DB5B1	2017-07-23 17:18:00+03	198400.00
1DB5BE	2017-07-17 02:26:00+03	73500.00
1DB5C3	2017-08-07 19:21:00+03	81900.00
1DB5CA	2017-08-06 14:04:00+03	23600.00
1DB61C	2017-07-15 05:36:00+03	106200.00
1DB644	2017-07-11 02:28:00+03	78600.00
1DB67E	2017-07-02 19:04:00+03	68000.00
1DB698	2017-07-30 23:23:00+03	35500.00
1DB69B	2017-07-09 16:50:00+03	31400.00
1DB719	2017-07-13 10:39:00+03	19600.00
1DB744	2017-07-31 19:09:00+03	260300.00
1DB7F4	2017-07-27 13:24:00+03	246000.00
1DB8FF	2017-07-18 07:20:00+03	14300.00
1DB973	2017-07-27 03:32:00+03	67100.00
1DBA5F	2017-07-02 23:11:00+03	136600.00
1DBA60	2017-07-30 03:53:00+03	26900.00
1DBB10	2017-07-08 20:06:00+03	86300.00
1DBB30	2017-08-12 01:09:00+03	125300.00
1DBB45	2017-08-05 23:31:00+03	115800.00
1DBBA4	2017-07-17 04:30:00+03	66100.00
1DBC03	2017-07-05 18:03:00+03	72600.00
1DBC19	2017-07-27 11:59:00+03	14400.00
1DBC7C	2017-07-03 07:32:00+03	23200.00
1DBC8E	2017-07-03 02:08:00+03	61800.00
1DBC90	2017-08-04 20:09:00+03	23200.00
1DBC93	2017-08-08 05:06:00+03	135200.00
1DBCA9	2017-08-04 15:24:00+03	100500.00
1DBCDC	2017-07-07 06:33:00+03	99300.00
1DBCF9	2017-07-04 08:40:00+03	112000.00
1DBD02	2017-07-14 00:17:00+03	7400.00
1DBD09	2017-07-01 19:37:00+03	28800.00
1DBD0B	2017-08-07 20:53:00+03	14400.00
1DBD1D	2017-07-05 20:23:00+03	8000.00
1DBD3C	2017-08-07 14:33:00+03	73200.00
1DBDC5	2017-08-14 04:15:00+03	27200.00
1DBDD2	2017-07-19 23:35:00+03	66200.00
1DBDE4	2017-07-20 21:02:00+03	34000.00
1DBE94	2017-07-25 23:06:00+03	27300.00
1DBE9B	2017-07-03 02:34:00+03	46000.00
1DC04B	2017-08-09 07:20:00+03	38000.00
1DC107	2017-07-07 16:09:00+03	40100.00
1DC114	2017-07-29 10:42:00+03	23200.00
1DC164	2017-07-07 05:02:00+03	44000.00
1DC193	2017-07-06 12:02:00+03	23200.00
1DC256	2017-08-08 04:08:00+03	132000.00
1DC278	2017-07-01 04:05:00+03	66000.00
1DC2C2	2017-07-16 09:15:00+03	254900.00
1DC2FA	2017-08-15 15:54:00+03	14400.00
1DC3AD	2017-07-11 06:05:00+03	61100.00
1DC3EE	2017-07-30 23:36:00+03	58000.00
1DC413	2017-07-19 04:09:00+03	142400.00
1DC414	2017-08-09 03:57:00+03	52000.00
1DC426	2017-07-07 04:01:00+03	21200.00
1DC435	2017-07-20 05:36:00+03	6700.00
1DC44A	2017-08-04 06:29:00+03	13400.00
1DC4BF	2017-08-13 19:41:00+03	32700.00
1DC51A	2017-07-19 15:36:00+03	26000.00
1DC55C	2017-07-07 14:51:00+03	8400.00
1DC568	2017-06-27 01:58:00+03	16400.00
1DC570	2017-07-30 05:58:00+03	100600.00
1DC5B0	2017-07-15 20:17:00+03	140400.00
1DC5FC	2017-06-30 17:48:00+03	13400.00
1DC5FD	2017-07-13 18:02:00+03	105100.00
1DC670	2017-07-12 07:29:00+03	53300.00
1DC688	2017-08-09 06:05:00+03	36200.00
1DC698	2017-07-08 12:04:00+03	73600.00
1DC6AC	2017-07-27 09:24:00+03	123000.00
1DC74B	2017-07-31 22:38:00+03	27600.00
1DC7DA	2017-07-18 02:54:00+03	16400.00
1DC800	2017-08-07 10:36:00+03	34000.00
1DC88B	2017-08-06 15:03:00+03	56000.00
1DC968	2017-08-07 10:36:00+03	43500.00
1DC9A2	2017-07-03 17:54:00+03	83500.00
1DC9BC	2017-07-02 23:58:00+03	265800.00
1DC9C8	2017-07-16 13:34:00+03	57500.00
1DCA74	2017-07-06 10:21:00+03	51800.00
1DCA7B	2017-07-22 18:45:00+03	16000.00
1DCA9D	2017-07-13 14:03:00+03	131100.00
1DCAC4	2017-07-28 10:09:00+03	14000.00
1DCB18	2017-07-09 16:41:00+03	65000.00
1DCB51	2017-07-29 12:13:00+03	65000.00
1DCBB7	2017-07-15 08:54:00+03	92100.00
1DCBF4	2017-07-19 12:00:00+03	61800.00
1DCC2D	2017-07-19 12:40:00+03	21400.00
1DCC3C	2017-07-07 15:07:00+03	28800.00
1DCCC0	2017-07-01 03:09:00+03	25400.00
1DCD29	2017-08-04 22:53:00+03	126300.00
1DCD5D	2017-07-24 07:36:00+03	179300.00
1DCD89	2017-07-19 21:37:00+03	88600.00
1DCDF2	2017-07-20 01:43:00+03	111600.00
1DCE1E	2017-07-20 17:02:00+03	262300.00
1DCEFF	2017-07-16 11:43:00+03	135600.00
1DCF17	2017-07-09 18:38:00+03	24700.00
1DCF2F	2017-07-04 09:23:00+03	49200.00
1DCFA6	2017-07-11 22:58:00+03	37900.00
1DD0C8	2017-08-02 03:28:00+03	13400.00
1DD0CE	2017-08-09 15:30:00+03	128800.00
1DD0DB	2017-08-10 14:08:00+03	6700.00
1DD136	2017-08-07 11:32:00+03	55800.00
1DD142	2017-07-11 05:34:00+03	73300.00
1DD17B	2017-07-29 10:42:00+03	59200.00
1DD17C	2017-08-04 10:20:00+03	15800.00
1DD1BC	2017-07-20 05:52:00+03	125200.00
1DD209	2017-07-15 03:09:00+03	115100.00
1DD243	2017-07-29 01:00:00+03	52000.00
1DD2AD	2017-08-12 11:57:00+03	46400.00
1DD387	2017-08-07 19:10:00+03	56100.00
1DD3F8	2017-07-28 20:37:00+03	56000.00
1DD438	2017-08-11 01:34:00+03	45100.00
1DD442	2017-07-27 01:32:00+03	100600.00
1DD45F	2017-08-07 05:20:00+03	11600.00
1DD467	2017-07-17 00:20:00+03	116400.00
1DD4A9	2017-08-12 07:38:00+03	83000.00
1DD4E3	2017-07-10 07:02:00+03	529800.00
1DD510	2017-07-10 04:34:00+03	37200.00
1DD529	2017-08-08 16:11:00+03	52000.00
1DD56F	2017-07-24 20:35:00+03	23900.00
1DD573	2017-07-23 16:46:00+03	123000.00
1DD5B0	2017-07-01 02:59:00+03	272400.00
1DD632	2017-07-03 15:31:00+03	56000.00
1DD666	2017-07-07 17:41:00+03	157900.00
1DD6B6	2017-07-17 19:46:00+03	534300.00
1DD6D1	2017-07-06 00:21:00+03	67200.00
1DD6F2	2017-07-07 05:37:00+03	36800.00
1DD6F3	2017-07-28 22:27:00+03	77200.00
1DD7ED	2017-08-13 08:21:00+03	92900.00
1DD819	2017-07-29 07:23:00+03	39800.00
1DD827	2017-07-23 10:47:00+03	492000.00
1DD91A	2017-08-13 10:03:00+03	86600.00
1DD920	2017-08-07 13:53:00+03	46400.00
1DD9D7	2017-07-28 05:32:00+03	82600.00
1DDA12	2017-07-23 06:46:00+03	187600.00
1DDA1F	2017-08-06 09:52:00+03	52700.00
1DDA30	2017-07-03 17:48:00+03	136600.00
1DDA62	2017-06-26 05:15:00+03	406800.00
1DDAA6	2017-07-17 12:22:00+03	111400.00
1DDAD8	2017-07-03 20:52:00+03	40300.00
1DDADA	2017-07-10 16:04:00+03	77200.00
1DDADF	2017-07-19 00:49:00+03	46000.00
1DDB7F	2017-07-12 16:33:00+03	199700.00
1DDBC4	2017-07-16 18:18:00+03	166000.00
1DDBDE	2017-07-30 18:38:00+03	7400.00
1DDC96	2017-07-23 07:15:00+03	21800.00
1DDCC0	2017-08-06 15:59:00+03	108300.00
1DDCCE	2017-08-04 02:42:00+03	113200.00
1DDDC0	2017-07-30 00:59:00+03	38600.00
1DDE40	2017-08-02 21:10:00+03	189200.00
1DDE8D	2017-07-07 20:48:00+03	40800.00
1DDED6	2017-07-30 03:01:00+03	86400.00
1DDF79	2017-07-13 22:21:00+03	28800.00
1DDF89	2017-07-20 03:00:00+03	28000.00
1DDFB3	2017-08-07 16:06:00+03	138700.00
1DDFF3	2017-08-01 19:58:00+03	132800.00
1DDFF4	2017-08-07 20:41:00+03	12400.00
1DE000	2017-08-11 18:02:00+03	177200.00
1DE002	2017-07-04 00:46:00+03	44800.00
1DE058	2017-08-08 13:49:00+03	58400.00
1DE061	2017-07-20 10:23:00+03	92800.00
1DE06A	2017-08-01 11:02:00+03	26200.00
1DE127	2017-07-12 11:16:00+03	199700.00
1DE155	2017-07-17 23:35:00+03	46400.00
1DE193	2017-07-26 01:03:00+03	143200.00
1DE1E2	2017-07-30 20:35:00+03	35700.00
1DE1F0	2017-07-09 19:49:00+03	65400.00
1DE29D	2017-07-12 18:31:00+03	54800.00
1DE2C0	2017-08-06 06:54:00+03	64700.00
1DE2CB	2017-07-06 07:59:00+03	23400.00
1DE2DA	2017-07-11 02:46:00+03	15400.00
1DE2E3	2017-07-31 17:05:00+03	233100.00
1DE33E	2017-08-03 04:34:00+03	34000.00
1DE3B3	2017-07-23 10:48:00+03	92600.00
1DE3D5	2017-07-23 05:21:00+03	19600.00
1DE413	2017-08-01 22:18:00+03	266400.00
1DE44C	2017-08-07 19:26:00+03	62900.00
1DE496	2017-08-15 14:40:00+03	14000.00
1DE512	2017-07-19 22:36:00+03	94700.00
1DE534	2017-07-30 09:45:00+03	115400.00
1DE560	2017-08-15 01:01:00+03	6700.00
1DE56A	2017-08-09 17:04:00+03	35200.00
1DE57D	2017-08-02 00:14:00+03	46400.00
1DE5EC	2017-07-28 07:27:00+03	67600.00
1DE609	2017-07-19 12:15:00+03	53100.00
1DE60B	2017-06-30 06:49:00+03	123000.00
1DE6AF	2017-06-28 00:32:00+03	36200.00
1DE6B2	2017-07-15 12:36:00+03	28700.00
1DE743	2017-08-04 08:10:00+03	49500.00
1DE824	2017-08-05 21:18:00+03	134400.00
1DE941	2017-08-01 18:22:00+03	272600.00
1DE989	2017-07-25 07:57:00+03	59800.00
1DE9B6	2017-07-23 04:54:00+03	61500.00
1DE9BB	2017-07-20 13:35:00+03	35700.00
1DE9C6	2017-08-14 19:55:00+03	40600.00
1DEA5F	2017-07-07 09:29:00+03	382200.00
1DEA7E	2017-08-04 21:04:00+03	133100.00
1DEA82	2017-07-24 15:04:00+03	56000.00
1DEAB4	2017-07-09 13:51:00+03	130900.00
1DEADF	2017-07-18 07:11:00+03	52700.00
1DEAF4	2017-07-18 07:51:00+03	68800.00
1DEAFA	2017-07-16 11:05:00+03	146300.00
1DEB26	2017-08-13 04:31:00+03	6000.00
1DEB2D	2017-07-22 00:58:00+03	136200.00
1DEBC0	2017-07-03 13:37:00+03	41800.00
1DEBDF	2017-07-04 12:40:00+03	265800.00
1DEBE0	2017-07-29 16:15:00+03	35800.00
1DEC2D	2017-08-12 20:27:00+03	75300.00
1DEC4F	2017-08-08 00:29:00+03	47500.00
1DEC7B	2017-08-04 11:02:00+03	26000.00
1DED4C	2017-07-27 13:42:00+03	8000.00
1DED58	2017-07-24 23:34:00+03	105600.00
1DEE33	2017-07-05 19:09:00+03	64700.00
1DEEB0	2017-08-13 15:46:00+03	68800.00
1DEEF8	2017-07-17 03:35:00+03	48800.00
1DEF13	2017-07-26 05:34:00+03	87100.00
1DEF3D	2017-07-28 13:52:00+03	174800.00
1DEFDA	2017-07-10 21:19:00+03	15100.00
1DF003	2017-07-20 10:51:00+03	69000.00
1DF059	2017-07-16 20:31:00+03	24200.00
1DF062	2017-07-03 04:37:00+03	62700.00
1DF09B	2017-07-27 00:04:00+03	28800.00
1DF0A7	2017-07-02 18:04:00+03	13200.00
1DF108	2017-08-06 10:14:00+03	55800.00
1DF120	2017-08-14 02:06:00+03	11200.00
1DF13B	2017-08-07 10:52:00+03	60400.00
1DF171	2017-07-13 05:05:00+03	39300.00
1DF18D	2017-08-02 17:47:00+03	50200.00
1DF1B0	2017-08-05 22:39:00+03	123000.00
1DF1F9	2017-07-20 03:25:00+03	231200.00
1DF24D	2017-08-14 07:37:00+03	117300.00
1DF254	2017-07-03 16:17:00+03	47200.00
1DF27B	2017-08-06 09:23:00+03	87200.00
1DF28D	2017-07-17 21:40:00+03	406800.00
1DF2C7	2017-07-16 09:37:00+03	18600.00
1DF2F6	2017-07-09 23:37:00+03	23400.00
1DF35F	2017-07-10 13:28:00+03	18000.00
1DF382	2017-07-19 20:27:00+03	36200.00
1DF3B0	2017-08-07 08:02:00+03	22100.00
1DF42C	2017-08-01 20:22:00+03	258400.00
1DF42E	2017-07-23 17:16:00+03	40100.00
1DF42F	2017-07-15 01:50:00+03	40800.00
1DF49E	2017-07-17 05:14:00+03	25600.00
1DF4B7	2017-07-03 19:08:00+03	13200.00
1DF554	2017-08-05 09:41:00+03	62700.00
1DF56A	2017-07-27 06:41:00+03	101500.00
1DF57A	2017-08-04 22:07:00+03	22600.00
1DF5AD	2017-06-29 05:07:00+03	67700.00
1DF5CB	2017-08-08 19:00:00+03	98300.00
1DF5D3	2017-07-26 20:58:00+03	23600.00
1DF5D7	2017-08-07 03:17:00+03	97700.00
1DF605	2017-08-09 05:00:00+03	134400.00
1DF62B	2017-08-11 20:03:00+03	273000.00
1DF6BD	2017-08-03 23:28:00+03	77000.00
1DF6E7	2017-07-04 11:39:00+03	258500.00
1DF726	2017-07-08 19:08:00+03	24400.00
1DF74E	2017-08-08 11:14:00+03	35800.00
1DF75E	2017-07-28 15:37:00+03	83700.00
1DF90A	2017-07-16 06:15:00+03	161800.00
1DF917	2017-08-11 16:31:00+03	95200.00
1DF95A	2017-08-04 02:03:00+03	56600.00
1DF97B	2017-08-02 21:50:00+03	77000.00
1DFA48	2017-08-06 04:15:00+03	35700.00
1DFA4F	2017-07-03 15:41:00+03	73600.00
1DFAE2	2017-08-12 06:37:00+03	40600.00
1DFB7D	2017-07-26 05:46:00+03	262200.00
1DFB88	2017-07-27 08:40:00+03	132800.00
1DFB92	2017-07-03 02:25:00+03	66800.00
1DFBC7	2017-06-30 14:53:00+03	53600.00
1DFBD8	2017-07-08 00:37:00+03	424700.00
1DFC06	2017-07-26 14:08:00+03	49600.00
1DFC47	2017-07-17 02:06:00+03	25100.00
1DFC79	2017-08-05 10:56:00+03	47500.00
1DFC93	2017-07-20 23:38:00+03	56000.00
1DFCFA	2017-07-02 08:06:00+03	28800.00
1DFD0A	2017-08-12 21:03:00+03	51900.00
1DFD8B	2017-07-06 12:13:00+03	51600.00
1DFD9D	2017-07-08 06:57:00+03	99200.00
1DFDA9	2017-07-25 17:56:00+03	16400.00
1DFE17	2017-08-14 11:03:00+03	36400.00
1DFE60	2017-07-05 15:16:00+03	56000.00
1DFE7E	2017-08-06 19:39:00+03	65200.00
1DFEB5	2017-08-02 20:02:00+03	86500.00
1DFED1	2017-07-25 19:13:00+03	214900.00
1DFF82	2017-07-16 11:15:00+03	55800.00
1E00DF	2017-08-14 06:41:00+03	67400.00
1E00E4	2017-07-27 12:25:00+03	48500.00
1E00EE	2017-07-28 09:56:00+03	187600.00
1E010D	2017-07-07 22:03:00+03	20400.00
1E014C	2017-07-16 21:16:00+03	25000.00
1E014E	2017-08-05 03:33:00+03	81600.00
1E0152	2017-07-19 03:42:00+03	30000.00
1E01BF	2017-07-28 23:42:00+03	85000.00
1E01EB	2017-08-10 07:53:00+03	39800.00
1E0212	2017-07-24 22:16:00+03	67600.00
1E02DA	2017-08-06 11:40:00+03	520600.00
1E02E4	2017-08-04 18:17:00+03	89700.00
1E02F6	2017-07-31 16:23:00+03	277800.00
1E0300	2017-08-09 20:29:00+03	66600.00
1E0315	2017-07-10 22:19:00+03	620700.00
1E031E	2017-06-28 15:06:00+03	180800.00
1E032B	2017-08-03 05:39:00+03	40900.00
1E033D	2017-08-08 14:08:00+03	70600.00
1E03E8	2017-08-09 18:02:00+03	272300.00
1E042D	2017-07-25 06:56:00+03	6800.00
1E0438	2017-07-27 21:31:00+03	56000.00
1E04B6	2017-08-14 23:28:00+03	92800.00
1E0567	2017-07-11 00:12:00+03	48800.00
1E05A4	2017-06-30 04:41:00+03	55800.00
1E05D8	2017-07-15 19:55:00+03	17600.00
1E0655	2017-07-19 09:32:00+03	56000.00
1E065C	2017-07-10 06:49:00+03	26000.00
1E0666	2017-08-05 16:27:00+03	432600.00
1E0668	2017-07-07 17:23:00+03	48800.00
1E0679	2017-08-09 07:10:00+03	36800.00
1E06D0	2017-07-23 23:38:00+03	16400.00
1E06E9	2017-08-08 01:13:00+03	137600.00
1E0766	2017-07-18 20:32:00+03	6300.00
1E077A	2017-07-09 02:01:00+03	57600.00
1E077C	2017-07-14 23:43:00+03	13000.00
1E07CB	2017-07-14 05:38:00+03	168000.00
1E0818	2017-07-15 03:29:00+03	20700.00
1E0834	2017-07-08 13:34:00+03	8400.00
1E0895	2017-08-07 16:34:00+03	60400.00
1E0908	2017-07-16 04:20:00+03	136500.00
1E0975	2017-07-03 05:21:00+03	37600.00
1E098D	2017-07-13 12:30:00+03	73500.00
1E099D	2017-08-13 08:03:00+03	117600.00
1E09A5	2017-08-13 17:54:00+03	42800.00
1E09D7	2017-07-12 18:36:00+03	78100.00
1E09E3	2017-08-10 13:38:00+03	93900.00
1E09FB	2017-07-01 21:47:00+03	55600.00
1E0A2C	2017-08-03 17:07:00+03	153300.00
1E0A36	2017-07-26 12:37:00+03	22400.00
1E0A52	2017-07-05 22:01:00+03	46400.00
1E0A98	2017-07-16 04:00:00+03	20400.00
1E0AC1	2017-08-08 06:10:00+03	22000.00
1E0AC3	2017-07-28 12:36:00+03	52700.00
1E0BAE	2017-08-14 05:31:00+03	49500.00
1E0BB0	2017-07-18 22:06:00+03	148200.00
1E0CBB	2017-07-24 00:36:00+03	49400.00
1E0D52	2017-08-14 04:55:00+03	41000.00
1E0D8A	2017-07-22 21:51:00+03	141600.00
1E0DA0	2017-07-03 02:14:00+03	56000.00
1E0DE9	2017-07-11 05:12:00+03	56000.00
1E0E57	2017-07-27 03:00:00+03	40000.00
1E0E8E	2017-08-13 19:52:00+03	37700.00
1E0E91	2017-07-28 13:34:00+03	48800.00
1E0ED7	2017-08-05 01:44:00+03	21400.00
1E0F0E	2017-07-08 14:57:00+03	54000.00
1E0F64	2017-08-10 22:22:00+03	132800.00
1E0F8C	2017-08-09 03:22:00+03	398600.00
1E0F91	2017-07-17 18:24:00+03	78100.00
1E109A	2017-08-13 01:11:00+03	45200.00
1E10B2	2017-07-31 10:41:00+03	270800.00
1E111B	2017-08-03 01:03:00+03	44700.00
1E114C	2017-07-21 19:21:00+03	187500.00
1E119F	2017-07-31 10:11:00+03	95600.00
1E1216	2017-08-14 06:02:00+03	38600.00
1E125A	2017-07-16 15:12:00+03	42800.00
1E1266	2017-07-18 10:02:00+03	242400.00
1E12AC	2017-07-06 19:31:00+03	69900.00
1E12E6	2017-07-02 16:49:00+03	31200.00
1E12EF	2017-07-25 23:45:00+03	246000.00
1E12F0	2017-07-15 06:01:00+03	47900.00
1E1310	2017-08-11 19:28:00+03	14000.00
1E131C	2017-07-03 13:36:00+03	12600.00
1E134F	2017-07-04 11:45:00+03	92200.00
1E1377	2017-07-05 07:26:00+03	271100.00
1E1388	2017-08-12 03:25:00+03	46500.00
1E13AA	2017-07-16 18:38:00+03	123000.00
1E13C4	2017-07-06 20:56:00+03	7200.00
1E13C9	2017-08-05 03:08:00+03	56000.00
1E147D	2017-07-13 09:54:00+03	29400.00
1E1500	2017-07-09 01:00:00+03	92700.00
1E1518	2017-08-06 15:09:00+03	6700.00
1E152B	2017-08-09 16:41:00+03	26800.00
1E153C	2017-07-31 05:39:00+03	43800.00
1E155E	2017-07-07 19:29:00+03	131600.00
1E156D	2017-07-15 04:20:00+03	16400.00
1E1578	2017-07-08 20:47:00+03	30200.00
1E158A	2017-07-24 20:16:00+03	67700.00
1E159B	2017-08-02 18:41:00+03	28800.00
1E159C	2017-07-06 19:20:00+03	31400.00
1E15C6	2017-08-09 07:47:00+03	46200.00
1E1655	2017-08-09 15:37:00+03	369000.00
1E1660	2017-07-13 08:00:00+03	47100.00
1E1679	2017-08-03 02:55:00+03	97600.00
1E1691	2017-06-28 14:39:00+03	399700.00
1E16AC	2017-07-06 06:26:00+03	123700.00
1E16B7	2017-08-04 09:40:00+03	30000.00
1E16CE	2017-07-29 19:09:00+03	7400.00
1E16D5	2017-07-27 10:35:00+03	14800.00
1E16D7	2017-08-08 11:58:00+03	36200.00
1E16FD	2017-08-03 21:54:00+03	300400.00
1E170F	2017-08-11 21:02:00+03	85000.00
1E1762	2017-07-28 07:23:00+03	38800.00
1E1775	2017-08-08 23:30:00+03	86400.00
1E178D	2017-07-14 16:16:00+03	77600.00
1E179D	2017-08-02 11:31:00+03	40400.00
1E186C	2017-07-21 22:39:00+03	142800.00
1E1897	2017-07-03 17:44:00+03	103200.00
1E18EC	2017-07-21 13:07:00+03	112000.00
1E194D	2017-08-10 05:10:00+03	369000.00
1E19BE	2017-07-19 20:52:00+03	88000.00
1E19C8	2017-07-18 22:03:00+03	6000.00
1E1A03	2017-07-15 04:15:00+03	71500.00
1E1A26	2017-07-20 22:10:00+03	134400.00
1E1A39	2017-07-20 07:18:00+03	23600.00
1E1A46	2017-07-02 04:39:00+03	73200.00
1E1A83	2017-07-25 10:31:00+03	53400.00
1E1AC2	2017-07-27 11:11:00+03	62700.00
1E1B1D	2017-07-10 13:11:00+03	84500.00
1E1C1A	2017-07-30 02:04:00+03	60400.00
1E1C3E	2017-07-30 23:25:00+03	14800.00
1E1C93	2017-07-11 21:29:00+03	27200.00
1E1D45	2017-07-23 08:03:00+03	88800.00
1E1D62	2017-07-26 08:49:00+03	311100.00
1E1D9A	2017-07-21 18:55:00+03	53500.00
1E1DA0	2017-07-21 07:21:00+03	16400.00
1E1DE0	2017-08-08 12:19:00+03	31200.00
1E1E41	2017-08-11 15:04:00+03	156600.00
1E1EDE	2017-07-03 21:59:00+03	10800.00
1E1F56	2017-08-05 14:23:00+03	93900.00
1E1F98	2017-08-02 17:45:00+03	294000.00
1E1FC7	2017-08-10 14:00:00+03	278800.00
1E20EF	2017-07-29 05:25:00+03	46000.00
1E2139	2017-06-29 07:40:00+03	50000.00
1E2170	2017-07-27 00:57:00+03	24700.00
1E21AC	2017-07-18 23:17:00+03	19600.00
1E21B8	2017-08-11 12:39:00+03	40200.00
1E21C8	2017-07-30 12:13:00+03	66000.00
1E2211	2017-07-26 10:27:00+03	91700.00
1E2256	2017-07-05 14:12:00+03	48500.00
1E2283	2017-07-03 09:18:00+03	56600.00
1E22AC	2017-07-16 19:39:00+03	55900.00
1E22EB	2017-07-24 17:22:00+03	54400.00
1E22ED	2017-07-15 08:41:00+03	92400.00
1E23A9	2017-08-12 21:18:00+03	56000.00
1E23AB	2017-07-09 09:40:00+03	47000.00
1E23BA	2017-08-06 20:42:00+03	46000.00
1E23E0	2017-07-25 23:35:00+03	26000.00
1E244B	2017-07-24 09:38:00+03	42800.00
1E244D	2017-08-06 20:09:00+03	77200.00
1E2457	2017-07-24 16:00:00+03	21500.00
1E2459	2017-07-26 01:25:00+03	6000.00
1E24AD	2017-07-24 21:08:00+03	152200.00
1E24F5	2017-08-01 05:27:00+03	79600.00
1E252A	2017-07-22 21:52:00+03	86600.00
1E2569	2017-07-13 05:58:00+03	48100.00
1E256F	2017-08-05 13:53:00+03	9800.00
1E25B2	2017-07-16 10:56:00+03	64700.00
1E25CB	2017-07-24 15:33:00+03	96200.00
1E2632	2017-07-09 05:32:00+03	34000.00
1E2651	2017-07-13 15:58:00+03	62600.00
1E2669	2017-07-31 23:29:00+03	50000.00
1E2693	2017-08-09 05:18:00+03	301800.00
1E26A0	2017-07-11 14:03:00+03	40200.00
1E26B5	2017-07-19 21:11:00+03	96800.00
1E26C4	2017-07-12 20:17:00+03	192700.00
1E2736	2017-07-10 21:21:00+03	240500.00
1E275B	2017-08-13 20:37:00+03	28300.00
1E2775	2017-07-21 12:56:00+03	47000.00
1E279E	2017-07-19 04:31:00+03	38600.00
1E2899	2017-07-28 06:23:00+03	38800.00
1E289E	2017-08-07 19:00:00+03	105000.00
1E28C9	2017-07-08 05:02:00+03	8400.00
1E290B	2017-07-03 06:13:00+03	59100.00
1E292C	2017-07-19 23:14:00+03	73600.00
1E2961	2017-07-03 10:14:00+03	112000.00
1E2966	2017-07-07 03:42:00+03	36600.00
1E29EA	2017-07-17 15:00:00+03	26700.00
1E2A50	2017-07-09 12:59:00+03	27500.00
1E2B34	2017-07-12 05:53:00+03	34800.00
1E2B8A	2017-08-12 11:56:00+03	46300.00
1E2C19	2017-07-29 20:24:00+03	28000.00
1E2C70	2017-07-20 23:42:00+03	32700.00
1E2CCD	2017-07-07 22:23:00+03	31600.00
1E2CF0	2017-07-22 12:08:00+03	122800.00
1E2D3B	2017-08-14 01:45:00+03	106200.00
1E2DCC	2017-07-03 13:08:00+03	99300.00
1E2DEB	2017-08-06 08:04:00+03	131100.00
1E2E44	2017-08-13 13:53:00+03	121800.00
1E2E62	2017-07-21 20:28:00+03	32700.00
1E2E77	2017-08-04 02:50:00+03	23600.00
1E2ED1	2017-07-30 08:51:00+03	56600.00
1E2EDE	2017-07-27 20:42:00+03	31000.00
1E2F57	2017-07-22 20:18:00+03	136600.00
1E2F7C	2017-07-19 07:29:00+03	19600.00
1E2F8C	2017-07-15 19:14:00+03	43400.00
1E2FAE	2017-07-07 10:33:00+03	133200.00
1E300A	2017-07-19 03:55:00+03	7200.00
1E3026	2017-07-26 04:15:00+03	40600.00
1E3051	2017-07-31 10:18:00+03	37900.00
1E3056	2017-08-03 15:51:00+03	59200.00
1E3077	2017-07-23 12:09:00+03	132800.00
1E30C0	2017-07-21 03:11:00+03	150100.00
1E30C8	2017-07-31 03:36:00+03	46300.00
1E30F3	2017-07-22 13:51:00+03	13300.00
1E30F7	2017-07-09 09:53:00+03	77200.00
1E3114	2017-07-31 15:59:00+03	43700.00
1E316B	2017-07-07 23:49:00+03	252200.00
1E31A1	2017-07-21 05:22:00+03	156500.00
1E3202	2017-07-14 14:16:00+03	67200.00
1E32F0	2017-07-12 16:02:00+03	36400.00
1E3325	2017-07-04 08:00:00+03	20400.00
1E333E	2017-07-30 07:48:00+03	31600.00
1E3396	2017-07-18 08:43:00+03	133200.00
1E33CE	2017-08-08 06:53:00+03	195600.00
1E33FD	2017-07-10 02:57:00+03	35200.00
1E341C	2017-08-13 19:30:00+03	106900.00
1E3488	2017-07-02 03:39:00+03	23400.00
1E34AC	2017-08-10 05:26:00+03	10800.00
1E34C3	2017-07-15 19:06:00+03	140200.00
1E350C	2017-07-19 20:03:00+03	46400.00
1E356A	2017-08-11 20:26:00+03	44000.00
1E36B5	2017-07-30 00:29:00+03	168000.00
1E3709	2017-07-18 08:57:00+03	136800.00
1E3721	2017-07-01 01:17:00+03	104000.00
1E372F	2017-07-08 07:34:00+03	39200.00
1E374E	2017-07-06 19:22:00+03	41600.00
1E37F7	2017-07-16 18:27:00+03	70100.00
1E3816	2017-07-08 17:02:00+03	73300.00
1E3824	2017-07-05 15:02:00+03	163500.00
1E382F	2017-07-30 05:30:00+03	10600.00
1E3856	2017-07-06 21:16:00+03	39300.00
1E3884	2017-06-30 02:39:00+03	39900.00
1E38D8	2017-07-28 19:02:00+03	119500.00
1E392D	2017-07-07 08:46:00+03	532800.00
1E39D3	2017-07-15 06:59:00+03	19000.00
1E39ED	2017-08-07 02:02:00+03	22000.00
1E39F5	2017-07-01 06:15:00+03	6000.00
1E3A27	2017-07-07 12:36:00+03	38400.00
1E3A75	2017-07-27 06:40:00+03	36200.00
1E3A8E	2017-08-05 16:40:00+03	6800.00
1E3AAE	2017-07-09 09:55:00+03	91900.00
1E3B35	2017-07-31 18:14:00+03	41400.00
1E3C25	2017-07-13 02:05:00+03	46200.00
1E3C58	2017-08-05 08:19:00+03	174000.00
1E3C69	2017-07-20 05:17:00+03	29600.00
1E3C7A	2017-07-14 19:11:00+03	13600.00
1E3CA0	2017-07-06 14:17:00+03	28800.00
1E3CA1	2017-08-05 07:32:00+03	27600.00
1E3CD0	2017-07-31 14:38:00+03	159300.00
1E3D10	2017-07-26 05:34:00+03	28800.00
1E3D12	2017-07-30 19:03:00+03	92000.00
1E3D32	2017-07-30 02:54:00+03	98900.00
1E3D39	2017-07-24 11:43:00+03	26000.00
1E3D5B	2017-07-28 11:32:00+03	28000.00
1E3E3F	2017-07-13 20:02:00+03	28000.00
1E3E93	2017-08-05 00:47:00+03	70800.00
1E3EBF	2017-07-12 18:32:00+03	46400.00
1E3F09	2017-07-01 21:36:00+03	47000.00
1E3F0D	2017-07-04 03:35:00+03	28000.00
1E3F39	2017-07-17 01:44:00+03	411400.00
1E3F46	2017-08-14 00:57:00+03	32400.00
1E3F5C	2017-08-15 10:17:00+03	12400.00
1E3FC1	2017-07-16 18:24:00+03	99300.00
1E3FF5	2017-07-23 02:04:00+03	38600.00
1E413F	2017-08-12 03:40:00+03	28800.00
1E4167	2017-07-19 21:07:00+03	22000.00
1E41E6	2017-06-26 10:48:00+03	23200.00
1E41EC	2017-07-04 18:55:00+03	187600.00
1E422A	2017-07-14 05:53:00+03	38600.00
1E4235	2017-08-04 15:09:00+03	123000.00
1E4278	2017-07-27 09:41:00+03	83100.00
1E4284	2017-07-31 03:48:00+03	28000.00
1E4298	2017-07-16 17:01:00+03	12600.00
1E42C6	2017-07-03 09:55:00+03	81900.00
1E42D6	2017-07-08 14:21:00+03	86800.00
1E430F	2017-07-18 15:56:00+03	20200.00
1E432C	2017-07-15 11:53:00+03	169300.00
1E4330	2017-07-06 19:21:00+03	100000.00
1E43A0	2017-07-18 06:12:00+03	98300.00
1E43C4	2017-08-12 20:36:00+03	54000.00
1E43F0	2017-08-06 05:22:00+03	38800.00
1E4421	2017-07-28 23:00:00+03	133700.00
1E4436	2017-07-16 06:37:00+03	169800.00
1E447F	2017-07-09 23:23:00+03	21400.00
1E4493	2017-07-08 05:56:00+03	28800.00
1E4494	2017-07-05 01:32:00+03	29400.00
1E44BA	2017-08-08 18:38:00+03	259000.00
1E44DF	2017-08-03 22:00:00+03	246000.00
1E44EC	2017-08-06 00:06:00+03	28800.00
1E4525	2017-08-02 15:06:00+03	66900.00
1E457D	2017-07-29 16:04:00+03	172100.00
1E4617	2017-07-21 21:09:00+03	36200.00
1E4626	2017-07-18 18:48:00+03	12000.00
1E4673	2017-07-08 14:18:00+03	7200.00
1E467E	2017-06-29 07:00:00+03	67700.00
1E46B4	2017-08-05 16:26:00+03	28800.00
1E46B9	2017-08-05 06:40:00+03	22600.00
1E47B6	2017-07-04 02:12:00+03	72400.00
1E47C4	2017-07-04 23:42:00+03	88800.00
1E4820	2017-07-21 04:13:00+03	38600.00
1E485F	2017-08-11 03:11:00+03	378700.00
1E4899	2017-08-10 12:45:00+03	24000.00
1E48A9	2017-07-27 03:41:00+03	128600.00
1E48E0	2017-06-27 00:51:00+03	175300.00
1E48F4	2017-07-29 12:28:00+03	150100.00
1E491C	2017-08-09 09:51:00+03	44800.00
1E4921	2017-07-24 10:36:00+03	23200.00
1E494A	2017-07-31 17:17:00+03	219900.00
1E4975	2017-07-26 08:36:00+03	175300.00
1E4997	2017-07-13 23:15:00+03	46400.00
1E49CB	2017-07-26 06:06:00+03	30900.00
1E49CF	2017-07-18 16:27:00+03	12000.00
1E49E6	2017-08-11 07:26:00+03	81300.00
1E4A07	2017-08-13 03:33:00+03	325800.00
1E4AD7	2017-08-10 17:47:00+03	39000.00
1E4AF3	2017-07-06 18:26:00+03	123000.00
1E4BDF	2017-08-04 22:46:00+03	135300.00
1E4CC2	2017-07-03 14:53:00+03	16400.00
1E4CD0	2017-08-03 03:29:00+03	75800.00
1E4CD8	2017-08-10 08:39:00+03	31600.00
1E4CEA	2017-07-15 12:21:00+03	24400.00
1E4D39	2017-07-23 08:46:00+03	21400.00
1E4DAA	2017-07-23 12:55:00+03	46200.00
1E4DF8	2017-07-09 18:19:00+03	51200.00
1E4E19	2017-08-05 01:01:00+03	28800.00
1E4E79	2017-08-01 01:48:00+03	137600.00
1E4E9A	2017-07-03 10:18:00+03	185800.00
1E4F63	2017-07-20 19:52:00+03	112000.00
1E4F6C	2017-06-25 04:44:00+03	85000.00
1E4F72	2017-06-29 06:36:00+03	73300.00
1E4F75	2017-07-01 04:02:00+03	16400.00
1E504A	2017-07-08 07:53:00+03	28800.00
1E5058	2017-07-14 16:25:00+03	99200.00
1E5104	2017-07-10 17:00:00+03	51200.00
1E511A	2017-07-22 01:33:00+03	369000.00
1E5180	2017-08-15 13:55:00+03	13400.00
1E51C3	2017-07-24 20:37:00+03	162600.00
1E51C6	2017-07-08 10:19:00+03	224000.00
1E51E4	2017-07-04 04:46:00+03	66600.00
1E51FD	2017-07-21 23:58:00+03	12600.00
1E520E	2017-06-27 18:56:00+03	21800.00
1E5218	2017-07-22 22:00:00+03	26700.00
1E5232	2017-07-05 22:14:00+03	50000.00
1E5236	2017-07-12 01:10:00+03	16400.00
1E524F	2017-07-28 02:05:00+03	394400.00
1E534E	2017-07-25 04:01:00+03	76300.00
1E538F	2017-07-13 04:37:00+03	282100.00
1E5464	2017-07-31 13:00:00+03	119600.00
1E548C	2017-07-11 18:03:00+03	36800.00
1E54D2	2017-08-03 01:25:00+03	84100.00
1E54E4	2017-08-03 20:49:00+03	168000.00
1E55EC	2017-07-04 13:28:00+03	33400.00
1E55EF	2017-07-17 00:25:00+03	86800.00
1E55F4	2017-07-04 12:03:00+03	34000.00
1E5606	2017-07-29 21:02:00+03	56000.00
1E5655	2017-07-17 04:04:00+03	131100.00
1E566F	2017-07-28 08:01:00+03	56900.00
1E56AE	2017-07-26 05:04:00+03	45200.00
1E56B8	2017-07-01 18:16:00+03	25800.00
1E56BA	2017-07-17 18:14:00+03	12600.00
1E56C4	2017-08-09 07:31:00+03	39800.00
1E571F	2017-08-01 15:03:00+03	59100.00
1E57A0	2017-08-12 06:43:00+03	75600.00
1E589E	2017-08-08 02:46:00+03	29400.00
1E58C2	2017-08-02 12:23:00+03	23600.00
1E58DE	2017-07-29 09:54:00+03	209700.00
1E592B	2017-07-11 08:24:00+03	188200.00
1E5956	2017-08-14 11:48:00+03	65900.00
1E5977	2017-07-20 10:06:00+03	44800.00
1E5A13	2017-07-16 23:03:00+03	7200.00
1E5A1D	2017-08-08 16:07:00+03	56000.00
1E5A2F	2017-08-06 23:47:00+03	40800.00
1E5A76	2017-07-22 01:07:00+03	131600.00
1E5A8F	2017-07-11 22:37:00+03	29400.00
1E5AA6	2017-07-17 13:14:00+03	85700.00
1E5AEC	2017-08-10 20:04:00+03	152100.00
1E5B27	2017-07-27 22:21:00+03	369000.00
1E5B50	2017-08-12 14:52:00+03	40200.00
1E5B64	2017-07-16 04:34:00+03	42100.00
1E5B78	2017-07-22 05:11:00+03	28000.00
1E5BF4	2017-07-24 07:14:00+03	203000.00
1E5D40	2017-06-30 21:16:00+03	29800.00
1E5D59	2017-07-11 15:03:00+03	47600.00
1E5D89	2017-07-07 00:34:00+03	30200.00
1E5D98	2017-07-15 07:36:00+03	270000.00
1E5E5A	2017-07-17 13:29:00+03	23200.00
1E5E7C	2017-07-17 07:33:00+03	146000.00
1E5EBD	2017-08-11 21:30:00+03	40000.00
1E5ECC	2017-07-26 02:54:00+03	126600.00
1E5ED7	2017-07-23 00:12:00+03	123000.00
1E5F06	2017-08-15 10:13:00+03	43500.00
1E5F1B	2017-07-10 08:44:00+03	29800.00
1E5F50	2017-07-25 09:20:00+03	51300.00
1E5F51	2017-07-07 12:16:00+03	38800.00
1E5F6F	2017-07-05 09:44:00+03	135000.00
1E5FF0	2017-08-12 04:38:00+03	39500.00
1E6002	2017-07-20 20:18:00+03	59000.00
1E6012	2017-08-01 00:52:00+03	72800.00
1E6039	2017-07-18 00:05:00+03	84500.00
1E604A	2017-07-19 18:10:00+03	19800.00
1E6096	2017-07-20 03:09:00+03	35200.00
1E609D	2017-07-19 09:27:00+03	45200.00
1E60C3	2017-07-15 11:25:00+03	50000.00
1E612B	2017-07-22 03:53:00+03	32400.00
1E6152	2017-08-06 06:50:00+03	52000.00
1E6169	2017-07-25 23:39:00+03	32800.00
1E618E	2017-07-11 08:24:00+03	239400.00
1E620B	2017-07-14 22:47:00+03	92400.00
1E627F	2017-08-12 13:05:00+03	62000.00
1E628C	2017-08-04 22:24:00+03	76800.00
1E629F	2017-08-13 01:36:00+03	78300.00
1E6359	2017-07-22 05:40:00+03	116400.00
1E6362	2017-08-03 00:07:00+03	77200.00
1E6363	2017-08-07 19:30:00+03	58000.00
1E6396	2017-07-31 13:22:00+03	62400.00
1E63DB	2017-07-21 21:27:00+03	29800.00
1E63F5	2017-08-05 04:02:00+03	105400.00
1E6402	2017-07-10 02:51:00+03	48800.00
1E6430	2017-08-15 10:45:00+03	12700.00
1E6447	2017-07-30 23:44:00+03	136800.00
1E6450	2017-07-06 14:27:00+03	41400.00
1E6494	2017-08-03 08:04:00+03	35200.00
1E64D7	2017-08-06 08:33:00+03	89700.00
1E6545	2017-07-01 04:42:00+03	46400.00
1E6579	2017-07-12 17:29:00+03	223200.00
1E6633	2017-08-07 22:15:00+03	29200.00
1E663E	2017-08-02 03:11:00+03	126300.00
1E666C	2017-08-04 17:24:00+03	65200.00
1E6695	2017-08-08 06:28:00+03	272400.00
1E66F4	2017-07-22 20:01:00+03	21800.00
1E672A	2017-07-11 20:01:00+03	50800.00
1E673B	2017-07-22 12:03:00+03	42000.00
1E6741	2017-08-02 19:08:00+03	69000.00
1E6773	2017-07-07 22:42:00+03	62900.00
1E6778	2017-08-13 16:01:00+03	33300.00
1E67B0	2017-08-07 11:30:00+03	36200.00
1E67BD	2017-07-28 22:42:00+03	11600.00
1E67D8	2017-07-29 22:49:00+03	132800.00
1E67F0	2017-07-31 17:45:00+03	35800.00
1E681C	2017-06-30 21:58:00+03	85000.00
1E6842	2017-08-15 02:38:00+03	41500.00
1E689F	2017-08-03 00:55:00+03	24400.00
1E68A2	2017-08-09 23:05:00+03	28000.00
1E68B9	2017-08-11 04:59:00+03	27800.00
1E68EF	2017-08-08 19:22:00+03	41800.00
1E694D	2017-07-26 17:37:00+03	161200.00
1E6985	2017-07-08 13:10:00+03	83700.00
1E69DB	2017-07-18 21:35:00+03	117600.00
1E69F1	2017-07-05 05:43:00+03	40800.00
1E6A26	2017-07-25 04:10:00+03	65900.00
1E6A35	2017-06-30 15:31:00+03	28000.00
1E6A37	2017-08-14 14:48:00+03	46000.00
1E6AC3	2017-07-12 17:42:00+03	47500.00
1E6AD5	2017-07-20 21:03:00+03	184700.00
1E6B36	2017-08-13 23:09:00+03	148200.00
1E6B37	2017-07-04 03:47:00+03	117600.00
1E6B57	2017-07-21 04:58:00+03	28800.00
1E6B7F	2017-07-19 06:01:00+03	61500.00
1E6B85	2017-08-12 00:03:00+03	25100.00
1E6BEB	2017-07-06 15:09:00+03	56000.00
1E6BF7	2017-08-05 03:14:00+03	31000.00
1E6C00	2017-07-09 11:44:00+03	51600.00
1E6C3E	2017-07-20 08:01:00+03	332700.00
1E6C43	2017-08-08 21:41:00+03	45100.00
1E6C93	2017-07-11 02:28:00+03	12600.00
1E6CB5	2017-08-04 15:20:00+03	398300.00
1E6D0F	2017-08-10 22:21:00+03	81700.00
1E6D1B	2017-07-07 07:42:00+03	10800.00
1E6D2C	2017-08-07 02:20:00+03	114800.00
1E6D8A	2017-08-07 19:24:00+03	144400.00
1E6DE9	2017-08-12 13:02:00+03	113200.00
1E6E06	2017-08-07 04:07:00+03	61800.00
1E6E1A	2017-07-08 02:18:00+03	135400.00
1E6E27	2017-07-14 12:24:00+03	176800.00
1E6E40	2017-07-30 21:08:00+03	86800.00
1E6F39	2017-08-08 12:50:00+03	117200.00
1E6F77	2017-07-15 17:03:00+03	6700.00
1E6F9D	2017-08-08 23:37:00+03	8200.00
1E6FA2	2017-07-10 06:28:00+03	59800.00
1E6FAF	2017-07-12 12:50:00+03	24400.00
1E700A	2017-07-15 23:48:00+03	65900.00
1E7020	2017-07-20 16:22:00+03	119600.00
1E7021	2017-07-09 02:52:00+03	130400.00
1E70D0	2017-07-05 17:19:00+03	76600.00
1E7108	2017-07-26 03:11:00+03	68100.00
1E713F	2017-07-25 15:47:00+03	70200.00
1E7167	2017-07-30 00:15:00+03	46200.00
1E71A1	2017-07-20 13:50:00+03	32800.00
1E7205	2017-07-24 05:30:00+03	48800.00
1E7234	2017-07-22 18:16:00+03	67600.00
1E724D	2017-08-03 07:26:00+03	18300.00
1E7276	2017-08-03 13:50:00+03	49500.00
1E727B	2017-07-10 15:09:00+03	406800.00
1E72CD	2017-07-23 05:06:00+03	21000.00
1E72EC	2017-07-31 19:49:00+03	48800.00
1E72F2	2017-07-05 02:30:00+03	25800.00
1E7452	2017-07-02 04:31:00+03	262200.00
1E7454	2017-07-17 23:30:00+03	155600.00
1E7478	2017-06-30 00:07:00+03	20200.00
1E74BB	2017-07-21 18:48:00+03	65600.00
1E74C9	2017-08-03 07:04:00+03	51900.00
1E752C	2017-08-05 07:13:00+03	75600.00
1E752F	2017-08-04 02:38:00+03	54000.00
1E7594	2017-07-09 00:03:00+03	7400.00
1E7595	2017-07-28 12:22:00+03	28000.00
1E7599	2017-08-08 02:04:00+03	260900.00
1E75B7	2017-07-19 07:31:00+03	556700.00
1E75C8	2017-07-27 21:18:00+03	135000.00
1E75E1	2017-08-12 13:53:00+03	232100.00
1E7613	2017-08-02 01:35:00+03	13400.00
1E7649	2017-07-09 16:36:00+03	8200.00
1E767E	2017-07-08 07:51:00+03	59800.00
1E76BF	2017-08-04 22:16:00+03	69000.00
1E76CA	2017-07-01 01:02:00+03	46300.00
1E76FA	2017-08-01 21:02:00+03	41300.00
1E7701	2017-07-07 05:35:00+03	76800.00
1E7705	2017-06-30 08:25:00+03	24400.00
1E7807	2017-08-04 03:20:00+03	80400.00
1E7808	2017-08-09 11:26:00+03	23200.00
1E7818	2017-08-11 06:13:00+03	64800.00
1E7883	2017-07-10 03:23:00+03	64800.00
1E7932	2017-07-24 16:48:00+03	72400.00
1E799E	2017-07-25 15:22:00+03	39500.00
1E79F5	2017-06-25 18:15:00+03	16400.00
1E7A2F	2017-07-11 22:15:00+03	75300.00
1E7A3B	2017-07-01 07:25:00+03	70200.00
1E7A4B	2017-08-10 03:33:00+03	6000.00
1E7AA9	2017-06-30 14:03:00+03	56000.00
1E7B1A	2017-07-09 07:22:00+03	68100.00
1E7BAA	2017-07-18 19:55:00+03	66800.00
1E7BF5	2017-07-07 22:04:00+03	99700.00
1E7C58	2017-08-14 03:57:00+03	61500.00
1E7C7E	2017-07-15 12:24:00+03	297700.00
1E7C99	2017-07-13 12:42:00+03	311900.00
1E7CCE	2017-08-04 23:59:00+03	46300.00
1E7D68	2017-08-03 03:13:00+03	10800.00
1E7D74	2017-07-02 10:53:00+03	80700.00
1E7DC1	2017-07-09 17:19:00+03	146400.00
1E7DE3	2017-07-25 11:55:00+03	51600.00
1E7E2E	2017-07-11 04:47:00+03	131600.00
1E7E46	2017-07-04 04:55:00+03	95600.00
1E7E54	2017-07-25 20:10:00+03	136800.00
1E7EFE	2017-07-08 23:33:00+03	136200.00
1E7F16	2017-08-08 15:58:00+03	36200.00
1E7F34	2017-07-04 09:11:00+03	68100.00
1E7F67	2017-08-06 19:28:00+03	259000.00
1E7F9C	2017-06-29 12:25:00+03	22000.00
1E802D	2017-07-19 18:08:00+03	174300.00
1E807C	2017-07-31 16:42:00+03	73200.00
1E8128	2017-07-04 21:27:00+03	20100.00
1E812C	2017-07-27 23:18:00+03	40800.00
1E817A	2017-07-21 03:42:00+03	114800.00
1E818B	2017-08-06 00:19:00+03	96400.00
1E81BE	2017-08-02 18:02:00+03	28000.00
1E81EE	2017-07-22 01:50:00+03	25600.00
1E8247	2017-08-10 04:56:00+03	78600.00
1E825E	2017-07-20 20:17:00+03	87200.00
1E82A5	2017-07-16 15:07:00+03	128800.00
1E82AA	2017-07-25 21:09:00+03	26200.00
1E82DE	2017-07-11 17:17:00+03	31400.00
1E82E0	2017-08-13 08:00:00+03	56000.00
1E8350	2017-07-22 17:10:00+03	67600.00
1E8383	2017-07-15 18:23:00+03	67900.00
1E83EE	2017-08-12 19:59:00+03	12600.00
1E844A	2017-07-11 21:17:00+03	93000.00
1E847E	2017-07-08 11:08:00+03	27800.00
1E84C5	2017-07-29 14:34:00+03	28800.00
1E84DD	2017-08-09 17:38:00+03	12600.00
1E84E2	2017-07-03 04:41:00+03	56300.00
1E8528	2017-08-01 00:53:00+03	99200.00
1E8569	2017-07-11 06:01:00+03	75300.00
1E8579	2017-07-04 03:55:00+03	24400.00
1E860E	2017-07-30 08:15:00+03	103100.00
1E867E	2017-07-07 02:03:00+03	49100.00
1E8697	2017-08-09 15:00:00+03	62600.00
1E86D1	2017-07-01 02:09:00+03	123000.00
1E86DF	2017-08-08 01:39:00+03	81800.00
1E87BA	2017-08-06 18:37:00+03	169900.00
1E87DE	2017-08-13 21:20:00+03	240600.00
1E884F	2017-07-15 18:46:00+03	34000.00
1E88E3	2017-08-02 03:34:00+03	58200.00
1E8922	2017-08-03 03:19:00+03	43600.00
1E8959	2017-08-04 07:18:00+03	47500.00
1E8986	2017-08-12 07:55:00+03	26000.00
1E89A8	2017-07-03 16:28:00+03	48400.00
1E89BA	2017-07-30 05:32:00+03	29100.00
1E89FF	2017-08-12 09:13:00+03	78100.00
1E8A52	2017-08-05 01:33:00+03	131100.00
1E8A54	2017-07-05 16:50:00+03	68800.00
1E8AA1	2017-08-02 12:24:00+03	135600.00
1E8AB1	2017-07-14 16:07:00+03	93900.00
1E8AC5	2017-07-08 02:59:00+03	66600.00
1E8AEB	2017-07-26 07:02:00+03	85000.00
1E8AF7	2017-07-04 07:22:00+03	253300.00
1E8B45	2017-07-11 21:37:00+03	60000.00
1E8BA2	2017-07-28 14:05:00+03	65500.00
1E8C15	2017-07-07 18:44:00+03	44000.00
1E8C33	2017-08-14 16:00:00+03	114800.00
1E8C42	2017-07-20 12:21:00+03	393800.00
1E8C70	2017-07-19 06:20:00+03	108600.00
1E8CA6	2017-07-08 07:15:00+03	270600.00
1E8D22	2017-08-12 18:37:00+03	22000.00
1E8D55	2017-07-26 04:50:00+03	40900.00
1E8D60	2017-07-26 15:45:00+03	119500.00
1E8D84	2017-07-02 10:09:00+03	59100.00
1E8DA6	2017-07-31 09:03:00+03	25600.00
1E8DC4	2017-07-14 11:31:00+03	65500.00
1E8E22	2017-07-30 03:44:00+03	46700.00
1E8E37	2017-07-03 17:48:00+03	159800.00
1E8E73	2017-07-29 15:29:00+03	196800.00
1E8EA1	2017-07-19 22:11:00+03	14400.00
1E8EE3	2017-07-22 23:34:00+03	34100.00
1E8F8F	2017-07-24 23:12:00+03	55800.00
1E8FE9	2017-08-15 16:26:00+03	41200.00
1E908E	2017-07-24 17:35:00+03	21600.00
1E90B9	2017-07-04 16:46:00+03	111600.00
1E90E0	2017-07-17 07:08:00+03	16400.00
1E90E3	2017-07-06 17:53:00+03	94400.00
1E9138	2017-07-15 23:28:00+03	65000.00
1E9145	2017-07-30 02:30:00+03	62600.00
1E9163	2017-07-16 09:36:00+03	51900.00
1E9167	2017-08-03 05:40:00+03	135200.00
1E9178	2017-06-29 00:09:00+03	133200.00
1E91C1	2017-08-12 17:30:00+03	139600.00
1E91F6	2017-08-01 21:14:00+03	73300.00
1E9219	2017-08-11 05:34:00+03	12600.00
1E928C	2017-07-28 09:18:00+03	34700.00
1E9293	2017-07-06 03:02:00+03	26000.00
1E92B3	2017-07-31 17:12:00+03	6300.00
1E930A	2017-07-07 15:09:00+03	20400.00
1E9349	2017-08-11 16:43:00+03	283500.00
1E936A	2017-07-27 23:43:00+03	64500.00
1E9478	2017-07-10 08:20:00+03	45200.00
1E9486	2017-07-10 22:33:00+03	47200.00
1E94B1	2017-07-17 21:18:00+03	27200.00
1E94E8	2017-07-09 15:40:00+03	25100.00
1E95A9	2017-07-20 05:57:00+03	15700.00
1E95AE	2017-07-03 22:55:00+03	55800.00
1E95AF	2017-07-19 02:38:00+03	64900.00
1E962E	2017-07-16 17:30:00+03	81800.00
1E9690	2017-08-08 09:22:00+03	6800.00
1E96D0	2017-08-15 10:40:00+03	126400.00
1E9773	2017-07-12 04:43:00+03	25400.00
1E981A	2017-07-02 11:27:00+03	122500.00
1E9878	2017-07-25 06:45:00+03	13000.00
1E988A	2017-08-10 00:46:00+03	28800.00
1E98DE	2017-07-24 12:51:00+03	8400.00
1E993B	2017-07-13 01:27:00+03	52000.00
1E9948	2017-07-11 00:53:00+03	25200.00
1E99C7	2017-08-08 17:11:00+03	40000.00
1E99F4	2017-07-01 05:59:00+03	109200.00
1E9A01	2017-08-01 11:36:00+03	75800.00
1E9A1C	2017-07-12 14:18:00+03	92800.00
1E9A1E	2017-07-24 02:47:00+03	70700.00
1E9A5A	2017-08-10 21:50:00+03	88600.00
1E9AAB	2017-08-07 18:03:00+03	26000.00
1E9AC3	2017-08-14 02:20:00+03	53000.00
1E9AF4	2017-06-30 03:25:00+03	26000.00
1E9AF8	2017-08-12 00:29:00+03	65300.00
1E9B1B	2017-08-10 07:29:00+03	44600.00
1E9BA6	2017-07-09 15:29:00+03	40800.00
1E9BA7	2017-07-08 10:20:00+03	134400.00
1E9CAD	2017-07-21 15:40:00+03	66600.00
1E9CE5	2017-07-17 16:03:00+03	24400.00
1E9CF7	2017-08-10 00:27:00+03	62600.00
1E9D04	2017-07-25 13:07:00+03	82200.00
1E9D25	2017-07-06 01:29:00+03	52200.00
1E9D54	2017-07-29 18:34:00+03	65500.00
1E9D75	2017-08-02 14:30:00+03	55600.00
1E9D79	2017-07-02 16:27:00+03	28800.00
1E9D98	2017-06-29 12:33:00+03	12600.00
1E9DD8	2017-07-29 10:28:00+03	66600.00
1E9E0D	2017-07-10 02:51:00+03	21400.00
1E9E2B	2017-07-06 03:01:00+03	40800.00
1E9ED1	2017-07-08 09:08:00+03	38200.00
1E9ED8	2017-08-08 13:23:00+03	58400.00
1E9F30	2017-07-30 00:45:00+03	55800.00
1E9F98	2017-07-12 08:29:00+03	73400.00
1E9F9F	2017-08-07 11:12:00+03	65000.00
1E9FA6	2017-08-04 19:15:00+03	8000.00
1E9FD2	2017-06-27 17:34:00+03	170000.00
1E9FDB	2017-06-30 23:07:00+03	67200.00
1E9FE7	2017-07-27 13:04:00+03	58200.00
1E9FF8	2017-07-29 09:17:00+03	399600.00
1EA059	2017-07-08 12:15:00+03	66600.00
1EA05C	2017-07-12 20:24:00+03	71800.00
1EA073	2017-07-16 07:52:00+03	34800.00
1EA075	2017-08-07 01:14:00+03	56000.00
1EA0A2	2017-07-14 03:24:00+03	28800.00
1EA0C7	2017-07-20 15:11:00+03	14400.00
1EA0E9	2017-07-12 22:05:00+03	66000.00
1EA161	2017-07-04 14:22:00+03	66600.00
1EA18E	2017-07-11 06:15:00+03	240600.00
1EA1DB	2017-07-21 05:02:00+03	42800.00
1EA1EC	2017-07-05 08:01:00+03	154500.00
1EA224	2017-08-05 15:12:00+03	89600.00
1EA241	2017-08-08 06:51:00+03	35300.00
1EA2E6	2017-07-22 23:43:00+03	50600.00
1EA35D	2017-07-14 02:02:00+03	29600.00
1EA3C5	2017-07-16 21:29:00+03	28000.00
1EA3FA	2017-07-15 00:06:00+03	61500.00
1EA41A	2017-08-11 21:53:00+03	28000.00
1EA44F	2017-07-05 00:22:00+03	136000.00
1EA523	2017-07-16 15:09:00+03	56900.00
1EA52F	2017-07-26 07:25:00+03	55000.00
1EA548	2017-08-11 01:54:00+03	7400.00
1EA550	2017-07-29 15:07:00+03	529800.00
1EA56F	2017-08-09 01:25:00+03	28800.00
1EA58D	2017-07-27 20:47:00+03	188500.00
1EA615	2017-07-10 02:27:00+03	67200.00
1EA65F	2017-07-07 10:37:00+03	177200.00
1EA6BE	2017-07-15 13:37:00+03	66000.00
1EA6BF	2017-08-13 13:53:00+03	166100.00
1EA6CC	2017-07-29 19:13:00+03	246000.00
1EA727	2017-07-11 10:25:00+03	394400.00
1EA73E	2017-08-06 09:57:00+03	86300.00
1EA7B0	2017-07-30 07:51:00+03	19200.00
1EA804	2017-08-13 09:35:00+03	58200.00
1EA809	2017-06-30 08:21:00+03	6700.00
1EA82C	2017-07-09 18:38:00+03	61800.00
1EA83A	2017-07-10 08:04:00+03	41800.00
1EA847	2017-07-16 05:43:00+03	19600.00
1EA898	2017-07-03 16:04:00+03	20000.00
1EA8C9	2017-08-06 15:29:00+03	63400.00
1EA901	2017-07-03 17:57:00+03	427200.00
1EA914	2017-07-11 11:17:00+03	42700.00
1EA987	2017-07-07 04:57:00+03	70500.00
1EA989	2017-07-12 10:04:00+03	57400.00
1EA9A2	2017-07-17 13:56:00+03	65100.00
1EA9B8	2017-08-13 21:17:00+03	62400.00
1EA9C7	2017-07-15 13:43:00+03	12600.00
1EAA03	2017-07-14 21:09:00+03	174900.00
1EAA15	2017-07-19 15:36:00+03	25800.00
1EAB37	2017-08-11 02:03:00+03	43600.00
1EAC0A	2017-07-19 21:19:00+03	406700.00
1EAC17	2017-07-29 18:24:00+03	12400.00
1EAC6C	2017-07-10 06:06:00+03	16400.00
1EAC9F	2017-08-15 17:52:00+03	16400.00
1EACAE	2017-08-07 07:45:00+03	128800.00
1EACCA	2017-08-05 06:57:00+03	79600.00
1EAD6F	2017-08-04 13:42:00+03	179000.00
1EAE03	2017-07-16 05:53:00+03	106100.00
1EAE3B	2017-08-10 17:10:00+03	13000.00
1EAE50	2017-07-20 03:36:00+03	46000.00
1EAEA4	2017-07-02 19:06:00+03	271200.00
1EAEB6	2017-07-19 13:18:00+03	92700.00
1EAED1	2017-08-15 12:27:00+03	23200.00
1EAF06	2017-07-22 10:04:00+03	26000.00
1EAF08	2017-07-19 18:10:00+03	42800.00
1EAF13	2017-07-17 17:14:00+03	19600.00
1EAF24	2017-08-03 10:07:00+03	542200.00
1EAF3E	2017-07-03 22:28:00+03	47400.00
1EAF63	2017-07-31 04:51:00+03	75300.00
1EAF98	2017-07-17 07:20:00+03	20400.00
1EAFAD	2017-08-06 07:57:00+03	139300.00
1EB0AC	2017-06-29 23:08:00+03	27700.00
1EB0EA	2017-07-14 11:00:00+03	96300.00
1EB0FE	2017-07-30 05:19:00+03	47100.00
1EB117	2017-07-14 14:21:00+03	28800.00
1EB127	2017-07-19 19:08:00+03	48800.00
1EB12E	2017-08-07 12:45:00+03	35800.00
1EB1A9	2017-07-25 10:22:00+03	23200.00
1EB1D1	2017-07-09 04:40:00+03	333800.00
1EB1EA	2017-07-09 12:17:00+03	43200.00
1EB218	2017-07-29 09:05:00+03	28000.00
1EB21E	2017-07-28 15:28:00+03	58600.00
1EB23F	2017-07-17 01:05:00+03	25400.00
1EB26F	2017-08-13 03:25:00+03	93000.00
1EB29C	2017-08-13 00:34:00+03	56600.00
1EB2B3	2017-07-15 05:40:00+03	46400.00
1EB348	2017-07-11 19:48:00+03	31600.00
1EB351	2017-08-14 09:17:00+03	29400.00
1EB37E	2017-08-04 06:13:00+03	61800.00
1EB38D	2017-08-12 08:21:00+03	25600.00
1EB3A4	2017-07-04 13:36:00+03	52300.00
1EB3D1	2017-08-08 17:09:00+03	206700.00
1EB426	2017-08-15 04:52:00+03	67600.00
1EB4A1	2017-07-29 09:25:00+03	77900.00
1EB4B5	2017-08-10 00:15:00+03	132800.00
1EB4ED	2017-08-05 04:10:00+03	94700.00
1EB4F0	2017-07-25 12:53:00+03	45200.00
1EB599	2017-08-14 14:03:00+03	14000.00
1EB5BA	2017-08-02 18:47:00+03	28800.00
1EB5C1	2017-07-07 10:08:00+03	47100.00
1EB5D9	2017-08-02 22:26:00+03	75800.00
1EB64B	2017-08-12 21:34:00+03	37900.00
1EB68A	2017-08-15 07:23:00+03	13600.00
1EB696	2017-07-15 18:00:00+03	136200.00
1EB717	2017-07-23 18:34:00+03	6800.00
1EB718	2017-07-13 15:28:00+03	103500.00
1EB78C	2017-08-08 15:13:00+03	49600.00
1EB83E	2017-07-02 10:58:00+03	21800.00
1EB946	2017-07-19 10:26:00+03	45600.00
1EB976	2017-07-31 03:53:00+03	55800.00
1EB983	2017-08-07 17:34:00+03	12400.00
1EB9DE	2017-07-25 23:48:00+03	137600.00
1EB9E0	2017-07-16 18:33:00+03	26000.00
1EB9F2	2017-07-25 17:20:00+03	270800.00
1EBA71	2017-07-23 18:56:00+03	88400.00
1EBA73	2017-08-03 21:58:00+03	86600.00
1EBA77	2017-07-13 00:01:00+03	60400.00
1EBAE5	2017-07-31 05:48:00+03	22000.00
1EBB8D	2017-08-04 02:49:00+03	20400.00
1EBBB1	2017-07-14 22:58:00+03	35200.00
1EBC13	2017-07-30 02:02:00+03	42800.00
1EBCCC	2017-06-28 09:51:00+03	63800.00
1EBCF6	2017-08-05 15:54:00+03	61800.00
1EBDD5	2017-08-12 13:11:00+03	75300.00
1EBE43	2017-07-10 14:44:00+03	193000.00
1EBE9A	2017-08-12 02:53:00+03	142300.00
1EBEAB	2017-07-23 22:03:00+03	28000.00
1EBEC6	2017-07-28 00:41:00+03	17800.00
1EBF22	2017-07-03 23:53:00+03	199700.00
1EBF32	2017-07-26 14:36:00+03	18300.00
1EBF4C	2017-08-13 01:19:00+03	28000.00
1EBF4F	2017-07-04 05:23:00+03	10600.00
1EBF8D	2017-08-09 15:57:00+03	28000.00
1EC017	2017-07-22 19:25:00+03	90200.00
1EC04D	2017-07-29 02:44:00+03	152500.00
1EC067	2017-07-15 07:21:00+03	37900.00
1EC0A1	2017-08-09 17:27:00+03	71800.00
1EC118	2017-07-19 05:59:00+03	150200.00
1EC127	2017-07-22 23:00:00+03	16000.00
1EC143	2017-08-02 23:40:00+03	46400.00
1EC14D	2017-08-03 19:53:00+03	73500.00
1EC291	2017-07-26 08:49:00+03	25200.00
1EC2D0	2017-08-13 05:18:00+03	93700.00
1EC2D3	2017-08-06 15:22:00+03	19600.00
1EC300	2017-07-31 23:03:00+03	186900.00
1EC30C	2017-07-28 09:33:00+03	165800.00
1EC397	2017-08-09 03:48:00+03	117200.00
1EC3AA	2017-07-10 07:43:00+03	332900.00
1EC3D7	2017-08-01 20:08:00+03	85000.00
1EC3E4	2017-08-12 11:48:00+03	198400.00
1EC3EE	2017-07-03 00:31:00+03	88800.00
1EC437	2017-07-16 08:07:00+03	6000.00
1EC4E2	2017-07-08 23:17:00+03	80700.00
1EC4E9	2017-08-02 09:43:00+03	42700.00
1EC516	2017-07-06 00:49:00+03	48500.00
1EC53F	2017-07-10 13:33:00+03	26000.00
1EC544	2017-07-17 11:15:00+03	220800.00
1EC550	2017-07-29 00:09:00+03	30200.00
1EC553	2017-07-18 20:54:00+03	102100.00
1EC57F	2017-08-13 00:54:00+03	23200.00
1EC5D4	2017-07-22 00:46:00+03	135400.00
1EC602	2017-08-03 19:25:00+03	23200.00
1EC609	2017-07-11 07:24:00+03	37600.00
1EC614	2017-08-13 09:34:00+03	14400.00
1EC628	2017-08-04 09:39:00+03	39300.00
1EC64E	2017-07-09 19:50:00+03	23100.00
1EC661	2017-08-06 16:53:00+03	187800.00
1EC6D5	2017-08-10 10:52:00+03	58800.00
1EC77E	2017-07-04 15:54:00+03	3700.00
1EC79F	2017-07-10 21:42:00+03	23200.00
1EC84E	2017-07-11 13:57:00+03	48700.00
1EC887	2017-08-03 11:51:00+03	43100.00
1EC8A6	2017-08-04 13:44:00+03	26000.00
1EC8AC	2017-07-14 03:46:00+03	28000.00
1EC8C6	2017-06-28 03:04:00+03	14300.00
1EC979	2017-06-30 22:57:00+03	105600.00
1EC98C	2017-07-06 20:39:00+03	25600.00
1EC98F	2017-07-09 23:19:00+03	102200.00
1EC9C8	2017-07-27 14:48:00+03	147900.00
1EC9F8	2017-08-12 19:31:00+03	357900.00
1ECA24	2017-08-14 18:36:00+03	46400.00
1ECA26	2017-07-12 13:43:00+03	102800.00
1ECA3B	2017-07-17 00:00:00+03	32700.00
1ECA5B	2017-08-14 06:06:00+03	46400.00
1ECA87	2017-08-10 08:08:00+03	31600.00
1ECA8C	2017-08-06 23:21:00+03	14000.00
1ECAA9	2017-08-13 20:49:00+03	59300.00
1ECAB1	2017-08-06 21:23:00+03	69000.00
1ECAE3	2017-07-14 16:17:00+03	77600.00
1ECB00	2017-07-29 04:58:00+03	40100.00
1ECB0B	2017-07-22 18:14:00+03	29600.00
1ECB2C	2017-06-30 23:12:00+03	55800.00
1ECB45	2017-08-10 14:22:00+03	47700.00
1ECB4A	2017-07-07 05:56:00+03	96800.00
1ECBA3	2017-08-08 19:11:00+03	52000.00
1ECBCA	2017-07-04 19:44:00+03	28400.00
1ECBE3	2017-07-09 14:46:00+03	48400.00
1ECC0F	2017-07-14 01:25:00+03	115700.00
1ECC15	2017-07-12 07:19:00+03	55800.00
1ECC2E	2017-07-01 07:03:00+03	166100.00
1ECC79	2017-08-11 16:42:00+03	38600.00
1ECC7A	2017-07-23 08:24:00+03	21500.00
1ECCA4	2017-08-13 12:34:00+03	44800.00
1ECD00	2017-08-13 22:52:00+03	34800.00
1ECD50	2017-07-26 02:49:00+03	114500.00
1ECE0E	2017-08-14 12:58:00+03	30000.00
1ECE8F	2017-07-23 12:23:00+03	55800.00
1ECE92	2017-07-21 06:06:00+03	12000.00
1ECEE0	2017-07-10 08:55:00+03	66000.00
1ECF01	2017-07-20 11:31:00+03	101200.00
1ECFEF	2017-07-03 09:20:00+03	90800.00
1ED008	2017-08-11 22:19:00+03	559500.00
1ED033	2017-07-03 02:01:00+03	80700.00
1ED07F	2017-08-04 18:02:00+03	166900.00
1ED098	2017-07-17 02:23:00+03	16400.00
1ED09E	2017-07-17 16:05:00+03	23400.00
1ED0C6	2017-07-17 17:11:00+03	196000.00
1ED174	2017-07-17 07:58:00+03	58900.00
1ED179	2017-07-05 06:20:00+03	16400.00
1ED1C8	2017-08-11 21:37:00+03	20400.00
1ED1E5	2017-08-06 21:02:00+03	42900.00
1ED24B	2017-07-01 22:14:00+03	46200.00
1ED24E	2017-07-11 09:54:00+03	22600.00
1ED2AA	2017-07-02 18:16:00+03	174400.00
1ED2D6	2017-08-14 07:43:00+03	36800.00
1ED3F6	2017-08-08 22:16:00+03	85400.00
1ED40B	2017-08-05 14:50:00+03	89600.00
1ED4A2	2017-08-12 11:43:00+03	29800.00
1ED4B0	2017-07-31 03:40:00+03	38600.00
1ED541	2017-07-26 21:03:00+03	23200.00
1ED56F	2017-08-08 07:17:00+03	55800.00
1ED651	2017-07-26 10:42:00+03	6000.00
1ED652	2017-08-08 16:47:00+03	36200.00
1ED6B9	2017-07-07 01:06:00+03	36700.00
1ED70A	2017-07-06 19:18:00+03	32200.00
1ED78B	2017-07-27 16:33:00+03	59000.00
1ED7E5	2017-07-18 05:58:00+03	190400.00
1ED7FD	2017-07-11 02:09:00+03	105000.00
1ED991	2017-07-19 22:24:00+03	81200.00
1ED9AB	2017-08-11 21:32:00+03	236100.00
1ED9B0	2017-07-21 15:24:00+03	37200.00
1ED9D7	2017-08-01 03:13:00+03	75300.00
1EDA06	2017-07-09 10:00:00+03	124200.00
1EDA15	2017-07-18 15:51:00+03	69600.00
1EDA37	2017-08-10 13:12:00+03	85300.00
1EDA49	2017-08-10 23:56:00+03	220700.00
1EDB10	2017-06-26 02:16:00+03	31600.00
1EDB34	2017-08-05 01:39:00+03	51200.00
1EDB40	2017-08-08 09:56:00+03	129200.00
1EDB86	2017-08-04 09:19:00+03	84500.00
1EDB87	2017-07-04 16:46:00+03	68800.00
1EDB9F	2017-07-18 03:16:00+03	70500.00
1EDBA8	2017-08-04 15:11:00+03	69400.00
1EDBB8	2017-08-04 20:55:00+03	131600.00
1EDDA6	2017-07-18 20:10:00+03	146300.00
1EDDDD	2017-07-08 12:26:00+03	12400.00
1EDE14	2017-08-07 10:03:00+03	82300.00
1EDE1E	2017-08-10 23:01:00+03	146300.00
1EDEF3	2017-07-13 12:53:00+03	43900.00
1EDEF5	2017-08-05 21:03:00+03	8000.00
1EDF04	2017-08-13 02:30:00+03	85000.00
1EDF31	2017-07-20 06:24:00+03	143200.00
1EDF44	2017-07-07 04:10:00+03	29100.00
1EDF79	2017-07-05 09:09:00+03	56000.00
1EDFF7	2017-07-28 17:33:00+03	41600.00
1EE028	2017-08-05 16:18:00+03	246200.00
1EE052	2017-07-27 21:08:00+03	63200.00
1EE080	2017-08-12 08:44:00+03	154800.00
1EE0D9	2017-08-08 11:20:00+03	188400.00
1EE11E	2017-07-25 08:16:00+03	38400.00
1EE159	2017-07-14 00:09:00+03	190400.00
1EE194	2017-07-11 14:04:00+03	132800.00
1EE1E8	2017-07-08 15:10:00+03	6300.00
1EE21E	2017-08-08 02:55:00+03	46200.00
1EE239	2017-08-01 18:16:00+03	64800.00
1EE23C	2017-07-29 10:03:00+03	29600.00
1EE241	2017-07-21 04:07:00+03	15000.00
1EE249	2017-07-18 16:52:00+03	325500.00
1EE26A	2017-07-15 17:27:00+03	58000.00
1EE28A	2017-07-31 14:41:00+03	40100.00
1EE2A0	2017-07-13 11:43:00+03	26600.00
1EE358	2017-07-03 19:11:00+03	146100.00
1EE3D2	2017-07-28 08:23:00+03	75600.00
1EE422	2017-08-01 19:45:00+03	32800.00
1EE432	2017-08-03 08:33:00+03	87800.00
1EE459	2017-08-13 03:29:00+03	59900.00
1EE488	2017-07-21 04:27:00+03	77000.00
1EE4BC	2017-07-15 18:49:00+03	71800.00
1EE4BD	2017-07-05 23:24:00+03	26700.00
1EE4BE	2017-07-31 19:33:00+03	141600.00
1EE544	2017-08-07 00:00:00+03	83000.00
1EE56D	2017-08-01 09:24:00+03	34400.00
1EE5A6	2017-07-09 04:05:00+03	58700.00
1EE5C3	2017-08-15 03:29:00+03	134400.00
1EE5FC	2017-08-15 08:23:00+03	108600.00
1EE62F	2017-07-30 17:56:00+03	12600.00
1EE6A5	2017-08-01 16:00:00+03	23400.00
1EE72B	2017-07-06 08:54:00+03	8000.00
1EE775	2017-08-01 09:16:00+03	52000.00
1EE778	2017-07-25 00:52:00+03	65900.00
1EE7AF	2017-07-16 15:34:00+03	48100.00
1EE7DE	2017-07-26 07:59:00+03	67600.00
1EE826	2017-07-21 08:04:00+03	136000.00
1EE90E	2017-07-01 22:42:00+03	57500.00
1EE93C	2017-08-03 19:18:00+03	112000.00
1EE93F	2017-08-09 23:31:00+03	147500.00
1EE9B8	2017-07-23 09:13:00+03	40200.00
1EE9BB	2017-08-09 15:01:00+03	57500.00
1EE9F6	2017-08-04 23:30:00+03	6000.00
1EEA6E	2017-08-11 11:31:00+03	73600.00
1EEAA6	2017-07-02 11:32:00+03	60800.00
1EEAFC	2017-08-05 04:25:00+03	92800.00
1EEB88	2017-07-18 06:02:00+03	189200.00
1EEBC3	2017-07-09 19:49:00+03	56000.00
1EEBD7	2017-07-10 21:30:00+03	77900.00
1EEBD8	2017-07-03 06:38:00+03	332800.00
1EEBE5	2017-07-21 10:27:00+03	40000.00
1EEC3D	2017-07-31 10:37:00+03	45000.00
1EEC8D	2017-07-01 18:47:00+03	73800.00
1EED15	2017-07-24 05:25:00+03	30000.00
1EED69	2017-08-07 12:42:00+03	56600.00
1EEDD8	2017-07-15 23:45:00+03	37900.00
1EEDDD	2017-08-13 10:06:00+03	48100.00
1EEE14	2017-08-06 02:41:00+03	88400.00
1EEECE	2017-08-12 17:42:00+03	133200.00
1EEEFC	2017-08-07 19:37:00+03	13400.00
1EEF66	2017-07-18 22:48:00+03	21800.00
1EEF6B	2017-07-06 14:08:00+03	19200.00
1EEF8A	2017-08-15 16:27:00+03	14000.00
1EEFA4	2017-07-03 06:04:00+03	28800.00
1EEFF6	2017-07-17 02:12:00+03	135600.00
1EF009	2017-07-17 08:22:00+03	231800.00
1EF00F	2017-08-07 15:43:00+03	47500.00
1EF075	2017-08-03 07:54:00+03	116900.00
1EF09D	2017-07-12 11:46:00+03	54400.00
1EF0FC	2017-08-04 00:48:00+03	147100.00
1EF138	2017-07-21 03:32:00+03	23600.00
1EF141	2017-07-14 22:49:00+03	22000.00
1EF1F3	2017-07-15 16:07:00+03	12400.00
1EF1FD	2017-07-13 20:54:00+03	21800.00
1EF25F	2017-06-28 07:25:00+03	186900.00
1EF268	2017-07-04 02:03:00+03	23200.00
1EF283	2017-08-01 19:47:00+03	31600.00
1EF29F	2017-08-12 08:46:00+03	52000.00
1EF2DC	2017-07-27 22:15:00+03	14800.00
1EF2ED	2017-08-15 04:51:00+03	28800.00
1EF30C	2017-08-01 07:48:00+03	68300.00
1EF32E	2017-08-14 19:04:00+03	94200.00
1EF384	2017-07-05 02:30:00+03	66900.00
1EF3AE	2017-07-18 07:10:00+03	55800.00
1EF3B8	2017-07-24 12:12:00+03	28000.00
1EF406	2017-07-04 06:49:00+03	21800.00
1EF45A	2017-07-04 15:49:00+03	7300.00
1EF497	2017-07-23 18:08:00+03	147700.00
1EF4C7	2017-07-22 09:02:00+03	57800.00
1EF522	2017-08-01 14:19:00+03	76800.00
1EF529	2017-07-02 13:14:00+03	136200.00
1EF568	2017-07-11 04:10:00+03	24800.00
1EF56F	2017-07-06 05:41:00+03	56600.00
1EF59E	2017-08-06 03:03:00+03	6000.00
1EF5AB	2017-07-06 02:06:00+03	47000.00
1EF5C6	2017-08-04 22:18:00+03	99300.00
1EF5F8	2017-07-31 08:51:00+03	35800.00
1EF606	2017-07-30 11:55:00+03	46200.00
1EF696	2017-07-18 13:18:00+03	75200.00
1EF6BC	2017-08-10 03:39:00+03	59600.00
1EF6E4	2017-07-11 13:21:00+03	55600.00
1EF6E9	2017-08-14 17:19:00+03	59800.00
1EF711	2017-08-06 02:19:00+03	14400.00
1EF713	2017-07-01 21:40:00+03	32700.00
1EF72E	2017-08-14 03:07:00+03	28000.00
1EF793	2017-07-09 06:21:00+03	176800.00
1EF7FD	2017-07-18 12:49:00+03	138000.00
1EF821	2017-07-12 19:33:00+03	19800.00
1EF873	2017-07-15 06:50:00+03	135600.00
1EF8A6	2017-07-05 11:15:00+03	258400.00
1EF8D1	2017-07-12 21:41:00+03	246000.00
1EF8F1	2017-08-11 06:26:00+03	53600.00
1EF8F6	2017-07-05 17:12:00+03	37900.00
1EF946	2017-08-05 23:21:00+03	24400.00
1EF9B5	2017-07-31 12:39:00+03	69000.00
1EF9FE	2017-08-01 03:48:00+03	32200.00
1EFA33	2017-08-13 12:06:00+03	124200.00
1EFA59	2017-07-18 20:11:00+03	100600.00
1EFAAB	2017-08-07 07:48:00+03	133200.00
1EFB9A	2017-06-30 06:11:00+03	49800.00
1EFBB2	2017-07-14 08:55:00+03	53600.00
1EFC9F	2017-07-09 15:21:00+03	48800.00
1EFCCA	2017-08-05 22:45:00+03	85000.00
1EFCEB	2017-08-02 21:59:00+03	13000.00
1EFD49	2017-08-08 01:03:00+03	56000.00
1EFD64	2017-08-12 00:20:00+03	27800.00
1EFD86	2017-08-14 21:08:00+03	67200.00
1EFE08	2017-07-30 03:37:00+03	21400.00
1EFE5A	2017-07-12 16:59:00+03	75600.00
1EFE68	2017-08-11 19:52:00+03	185600.00
1EFE6A	2017-07-23 04:03:00+03	25000.00
1EFE74	2017-07-15 05:57:00+03	182300.00
1EFE91	2017-08-08 06:08:00+03	13200.00
1EFE92	2017-08-13 14:18:00+03	44000.00
1EFED0	2017-08-14 23:32:00+03	75600.00
1EFEF6	2017-07-23 00:56:00+03	52300.00
1EFF0E	2017-07-26 22:48:00+03	40000.00
1EFFE3	2017-07-03 13:19:00+03	24400.00
1EFFE4	2017-08-13 19:45:00+03	25000.00
1F003B	2017-07-16 21:04:00+03	72400.00
1F0057	2017-07-09 03:08:00+03	118100.00
1F008F	2017-07-07 20:36:00+03	67600.00
1F0099	2017-08-06 10:33:00+03	83700.00
1F010E	2017-08-03 01:29:00+03	62600.00
1F0152	2017-07-04 21:25:00+03	29600.00
1F0185	2017-08-11 18:50:00+03	51900.00
1F0199	2017-08-12 02:00:00+03	95600.00
1F0258	2017-08-06 06:45:00+03	23600.00
1F0265	2017-07-29 19:04:00+03	46400.00
1F029E	2017-07-27 10:03:00+03	183300.00
1F02CC	2017-08-05 05:34:00+03	172100.00
1F0319	2017-08-12 21:49:00+03	25400.00
1F031C	2017-07-24 00:39:00+03	136800.00
1F0330	2017-08-04 08:35:00+03	123000.00
1F0378	2017-08-09 20:09:00+03	112000.00
1F037A	2017-07-28 07:17:00+03	67600.00
1F03B4	2017-08-03 14:19:00+03	28400.00
1F03D1	2017-07-31 02:09:00+03	91800.00
1F0458	2017-07-19 19:10:00+03	119800.00
1F04C7	2017-08-10 21:07:00+03	35200.00
1F050B	2017-08-04 18:22:00+03	26000.00
1F0584	2017-08-01 09:40:00+03	38600.00
1F0645	2017-07-09 12:48:00+03	123600.00
1F073B	2017-07-08 13:41:00+03	40800.00
1F078D	2017-07-24 23:07:00+03	33100.00
1F081C	2017-07-08 19:20:00+03	130000.00
1F083B	2017-08-07 05:52:00+03	39000.00
1F0863	2017-08-08 01:28:00+03	16800.00
1F0871	2017-07-30 20:52:00+03	45200.00
1F0952	2017-07-30 14:02:00+03	186900.00
1F097B	2017-08-08 05:32:00+03	37900.00
1F097E	2017-07-17 14:56:00+03	19600.00
1F09AB	2017-07-22 23:21:00+03	55600.00
1F09B0	2017-07-14 00:56:00+03	32900.00
1F09F0	2017-07-30 17:25:00+03	57500.00
1F0A18	2017-07-23 08:14:00+03	65500.00
1F0A8D	2017-07-17 15:41:00+03	92800.00
1F0B86	2017-07-30 21:57:00+03	14400.00
1F0B9E	2017-07-12 14:29:00+03	35700.00
1F0BA8	2017-07-10 20:23:00+03	92000.00
1F0C58	2017-07-01 05:05:00+03	28000.00
1F0C64	2017-07-06 07:38:00+03	99600.00
1F0C71	2017-07-19 16:37:00+03	299600.00
1F0C72	2017-08-08 03:31:00+03	44000.00
1F0C96	2017-08-01 15:40:00+03	28800.00
1F0D25	2017-07-02 06:34:00+03	55800.00
1F0D69	2017-07-02 22:48:00+03	165100.00
1F0D7E	2017-07-06 19:06:00+03	30800.00
1F0D84	2017-07-22 02:53:00+03	6700.00
1F0D93	2017-08-06 15:40:00+03	123000.00
1F0E04	2017-06-30 16:34:00+03	23600.00
1F0E54	2017-08-14 14:55:00+03	241400.00
1F0E7B	2017-07-29 13:19:00+03	50000.00
1F0EAC	2017-07-12 04:48:00+03	6700.00
1F0F4E	2017-06-30 01:14:00+03	67600.00
1F0F5C	2017-07-19 01:00:00+03	148200.00
1F0F63	2017-08-08 16:06:00+03	122500.00
1F0FC3	2017-08-15 15:55:00+03	50800.00
1F0FD2	2017-07-08 10:34:00+03	69700.00
1F1016	2017-07-26 13:13:00+03	58200.00
1F101F	2017-07-04 18:46:00+03	78100.00
1F1064	2017-08-02 00:39:00+03	69000.00
1F107D	2017-07-05 11:16:00+03	13400.00
1F1099	2017-07-16 04:43:00+03	73600.00
1F10B6	2017-07-12 00:35:00+03	16400.00
1F10EF	2017-06-27 22:57:00+03	83800.00
1F11DE	2017-07-15 02:42:00+03	23200.00
1F1240	2017-07-05 11:45:00+03	98300.00
1F12D1	2017-07-21 05:12:00+03	19600.00
1F12F8	2017-08-12 19:11:00+03	169600.00
1F1319	2017-08-06 13:30:00+03	36200.00
1F131D	2017-07-15 04:12:00+03	92100.00
1F1375	2017-07-07 01:48:00+03	12600.00
1F1392	2017-07-02 09:51:00+03	17800.00
1F139C	2017-07-28 06:25:00+03	47000.00
1F13A6	2017-08-15 05:44:00+03	13200.00
1F13C3	2017-07-01 20:29:00+03	8200.00
1F143E	2017-07-24 07:06:00+03	75300.00
1F1459	2017-07-28 13:06:00+03	199700.00
1F1465	2017-08-14 17:09:00+03	111600.00
1F1499	2017-07-22 05:12:00+03	37900.00
1F14A9	2017-06-28 09:48:00+03	27200.00
1F14B9	2017-07-21 01:27:00+03	23400.00
1F15C4	2017-07-11 22:28:00+03	66400.00
1F15CC	2017-08-15 09:38:00+03	64800.00
1F164D	2017-07-28 15:02:00+03	14000.00
1F16FB	2017-06-30 09:02:00+03	44800.00
1F1712	2017-07-17 12:11:00+03	100500.00
1F173E	2017-07-09 14:08:00+03	23400.00
1F17D5	2017-07-15 17:14:00+03	24300.00
1F183D	2017-07-01 09:36:00+03	26200.00
1F188C	2017-06-28 22:26:00+03	35400.00
1F189C	2017-08-14 09:19:00+03	25600.00
1F18B2	2017-07-08 11:50:00+03	61800.00
1F18C3	2017-08-12 11:50:00+03	51900.00
1F1907	2017-07-26 13:14:00+03	124200.00
1F1944	2017-06-28 23:13:00+03	70700.00
1F19C8	2017-07-01 18:02:00+03	156300.00
1F1A0D	2017-07-04 01:02:00+03	35200.00
1F1A2A	2017-08-08 01:23:00+03	25400.00
1F1A56	2017-07-05 14:58:00+03	6800.00
1F1A8E	2017-07-10 05:49:00+03	112300.00
1F1AA7	2017-07-06 18:58:00+03	7400.00
1F1AC4	2017-07-05 02:58:00+03	24200.00
1F1AC7	2017-07-22 22:02:00+03	51900.00
1F1ADA	2017-08-11 00:30:00+03	155600.00
1F1C5E	2017-07-27 14:46:00+03	44000.00
1F1CF8	2017-07-04 23:09:00+03	86400.00
1F1D90	2017-07-13 06:19:00+03	92700.00
1F1DF4	2017-06-30 23:18:00+03	13600.00
1F1E88	2017-07-05 05:03:00+03	47400.00
1F1E9D	2017-07-24 03:28:00+03	55800.00
1F1EC9	2017-07-13 07:46:00+03	20600.00
1F1F26	2017-07-29 04:11:00+03	160000.00
1F1F4E	2017-08-14 04:31:00+03	35300.00
1F202B	2017-07-27 23:54:00+03	68100.00
1F208F	2017-08-12 06:44:00+03	27900.00
1F20AB	2017-07-18 15:12:00+03	42700.00
1F20AF	2017-07-24 09:28:00+03	100600.00
1F20CA	2017-08-09 11:57:00+03	67200.00
1F21EB	2017-07-17 23:53:00+03	26300.00
1F21FB	2017-07-18 19:30:00+03	36800.00
1F2207	2017-07-13 16:14:00+03	21400.00
1F2231	2017-08-13 06:26:00+03	62600.00
1F224A	2017-08-15 17:22:00+03	71900.00
1F2256	2017-07-10 21:35:00+03	199200.00
1F22E5	2017-07-04 13:49:00+03	31100.00
1F2319	2017-07-23 04:27:00+03	47600.00
1F2331	2017-07-27 13:56:00+03	38800.00
1F2334	2017-07-11 12:52:00+03	125400.00
1F2499	2017-07-31 17:47:00+03	39300.00
1F25AE	2017-08-04 09:06:00+03	57800.00
1F25C1	2017-07-27 05:06:00+03	75600.00
1F25EC	2017-08-03 05:05:00+03	68000.00
1F260C	2017-08-02 22:59:00+03	62700.00
1F2612	2017-07-23 10:16:00+03	20200.00
1F2654	2017-07-27 23:12:00+03	47600.00
1F26A0	2017-06-27 23:51:00+03	57500.00
1F26E7	2017-07-17 20:48:00+03	53200.00
1F26EA	2017-08-02 13:56:00+03	22600.00
1F27A5	2017-08-15 07:31:00+03	266500.00
1F27CB	2017-07-16 09:32:00+03	63300.00
1F27DA	2017-08-02 07:09:00+03	123000.00
1F27DD	2017-07-21 14:56:00+03	28800.00
1F27FF	2017-08-12 18:53:00+03	28300.00
1F287A	2017-07-14 05:01:00+03	202500.00
1F28F2	2017-08-09 09:20:00+03	110700.00
1F28FE	2017-08-01 15:04:00+03	30400.00
1F2927	2017-07-09 19:52:00+03	25000.00
1F2931	2017-08-08 03:43:00+03	99200.00
1F2940	2017-07-06 07:32:00+03	156000.00
1F295E	2017-07-09 17:22:00+03	33400.00
1F29BF	2017-07-15 20:55:00+03	62000.00
1F29C9	2017-07-27 14:44:00+03	302400.00
1F2A60	2017-08-10 18:44:00+03	69600.00
1F2AB9	2017-07-26 23:23:00+03	32200.00
1F2ACC	2017-07-14 00:05:00+03	56600.00
1F2AD9	2017-07-08 07:28:00+03	66600.00
1F2B57	2017-08-05 10:48:00+03	24000.00
1F2B9D	2017-07-27 22:58:00+03	46500.00
1F2BAC	2017-07-11 07:09:00+03	29600.00
1F2BCF	2017-07-17 08:46:00+03	57500.00
1F2BED	2017-07-11 05:32:00+03	85000.00
1F2C7E	2017-08-02 16:52:00+03	109600.00
1F2CDD	2017-07-05 14:43:00+03	72200.00
1F2D19	2017-07-22 19:40:00+03	51800.00
1F2D32	2017-08-03 01:58:00+03	269600.00
1F2D55	2017-07-14 15:25:00+03	12600.00
1F2D8C	2017-08-14 08:14:00+03	145100.00
1F2DA3	2017-08-15 11:19:00+03	25100.00
1F2DB8	2017-07-15 03:35:00+03	24800.00
1F2DF7	2017-07-31 16:52:00+03	205400.00
1F2E08	2017-08-12 10:46:00+03	21000.00
1F2E16	2017-07-31 11:41:00+03	40800.00
1F2E26	2017-08-13 23:40:00+03	16800.00
1F2E65	2017-07-20 06:02:00+03	134400.00
1F2EBA	2017-07-12 16:13:00+03	19600.00
1F2EBD	2017-07-17 06:51:00+03	54500.00
1F2EF5	2017-07-21 18:44:00+03	24800.00
1F2F3C	2017-07-04 18:33:00+03	40800.00
1F2F3F	2017-07-31 20:47:00+03	41300.00
1F2FB6	2017-07-16 04:16:00+03	24000.00
1F2FD8	2017-07-23 05:41:00+03	16400.00
1F2FEB	2017-07-07 17:00:00+03	357200.00
1F300A	2017-07-02 01:45:00+03	53400.00
1F3025	2017-07-23 11:25:00+03	25600.00
1F3083	2017-07-27 20:28:00+03	182300.00
1F3086	2017-07-27 16:26:00+03	369000.00
1F30BD	2017-07-27 07:05:00+03	42600.00
1F30EC	2017-07-26 07:40:00+03	65100.00
1F3244	2017-07-03 03:58:00+03	6700.00
1F3255	2017-07-21 11:13:00+03	147700.00
1F330E	2017-07-04 20:02:00+03	171100.00
1F3339	2017-07-07 11:05:00+03	177200.00
1F337A	2017-07-06 00:43:00+03	48800.00
1F3384	2017-08-04 23:55:00+03	56600.00
1F33FE	2017-07-12 08:56:00+03	70600.00
1F3411	2017-08-12 16:11:00+03	20400.00
1F3438	2017-08-03 04:45:00+03	53600.00
1F3441	2017-07-12 11:45:00+03	13200.00
1F3496	2017-08-01 15:57:00+03	84100.00
1F358D	2017-08-01 10:17:00+03	139400.00
1F3609	2017-07-19 12:26:00+03	26000.00
1F371E	2017-08-08 20:43:00+03	56000.00
1F3737	2017-08-15 10:15:00+03	31300.00
1F3773	2017-07-02 00:00:00+03	84300.00
1F377E	2017-08-14 23:12:00+03	118300.00
1F37D6	2017-07-29 10:34:00+03	26800.00
1F3847	2017-08-12 17:50:00+03	123000.00
1F3852	2017-08-09 21:32:00+03	23400.00
1F3884	2017-07-10 09:59:00+03	27900.00
1F38CF	2017-07-04 12:58:00+03	23900.00
1F38D9	2017-07-12 08:00:00+03	25600.00
1F3910	2017-07-05 01:48:00+03	36200.00
1F39FD	2017-07-03 01:58:00+03	35700.00
1F3A3A	2017-07-13 23:21:00+03	51600.00
1F3A4C	2017-08-06 10:57:00+03	187200.00
1F3B16	2017-08-13 02:34:00+03	23200.00
1F3BFE	2017-07-03 21:12:00+03	34000.00
1F3C82	2017-07-13 00:03:00+03	59800.00
1F3D23	2017-08-13 01:59:00+03	28800.00
1F3D3E	2017-07-14 12:24:00+03	133100.00
1F3D6A	2017-07-15 01:22:00+03	25000.00
1F3DC4	2017-08-06 02:04:00+03	47000.00
1F3DE5	2017-07-21 02:09:00+03	170000.00
1F3E91	2017-07-27 21:55:00+03	121400.00
1F3E94	2017-07-21 16:41:00+03	36800.00
1F3EA1	2017-07-03 05:44:00+03	55800.00
1F3F49	2017-07-09 23:27:00+03	39300.00
1F3FAA	2017-08-05 11:23:00+03	85000.00
1F4058	2017-08-11 10:13:00+03	135400.00
1F4074	2017-08-14 22:47:00+03	11700.00
1F4089	2017-08-15 00:34:00+03	95000.00
1F4093	2017-07-31 09:35:00+03	91600.00
1F4099	2017-07-03 13:52:00+03	47100.00
1F40F5	2017-08-15 01:51:00+03	40000.00
1F4148	2017-07-01 06:18:00+03	34000.00
1F41BA	2017-08-01 12:13:00+03	69900.00
1F4247	2017-08-06 06:34:00+03	125900.00
1F42F0	2017-06-27 09:31:00+03	92300.00
1F4364	2017-07-05 11:02:00+03	133100.00
1F4365	2017-07-29 20:19:00+03	57300.00
1F436F	2017-07-09 16:47:00+03	44300.00
1F4392	2017-08-07 08:35:00+03	26800.00
1F43A4	2017-07-11 20:57:00+03	11000.00
1F444A	2017-07-27 11:06:00+03	40100.00
1F4466	2017-07-06 11:21:00+03	60700.00
1F44B7	2017-08-03 23:40:00+03	32200.00
1F44F2	2017-07-23 15:29:00+03	302600.00
1F4509	2017-08-01 07:01:00+03	23200.00
1F451D	2017-08-01 20:41:00+03	48900.00
1F454A	2017-07-05 17:02:00+03	108600.00
1F4564	2017-07-21 05:18:00+03	35700.00
1F45CB	2017-07-17 03:09:00+03	271100.00
1F45F4	2017-08-10 22:22:00+03	21400.00
1F4603	2017-07-08 00:14:00+03	56600.00
1F467A	2017-08-10 20:19:00+03	28800.00
1F4693	2017-07-16 08:44:00+03	27000.00
1F46EF	2017-07-31 16:22:00+03	56900.00
1F47AF	2017-08-06 02:01:00+03	67400.00
1F47EF	2017-08-09 22:56:00+03	65200.00
1F47F1	2017-07-07 12:51:00+03	26600.00
1F487A	2017-07-23 04:33:00+03	9200.00
1F4883	2017-07-22 06:02:00+03	26400.00
1F48EE	2017-08-08 11:41:00+03	20200.00
1F49E3	2017-08-04 10:51:00+03	31200.00
1F4A25	2017-07-02 19:50:00+03	281800.00
1F4A3E	2017-07-29 00:26:00+03	532600.00
1F4A84	2017-08-15 05:17:00+03	101400.00
1F4AAF	2017-07-10 10:36:00+03	47000.00
1F4AED	2017-08-10 16:03:00+03	44600.00
1F4B48	2017-07-25 21:59:00+03	6000.00
1F4CE6	2017-07-24 13:56:00+03	19200.00
1F4CE9	2017-07-17 17:43:00+03	107000.00
1F4DA1	2017-07-08 01:57:00+03	54800.00
1F4DA5	2017-08-06 08:21:00+03	75600.00
1F4DB8	2017-08-09 16:10:00+03	48800.00
1F4DFE	2017-07-13 02:11:00+03	13400.00
1F4E80	2017-07-03 08:31:00+03	61500.00
1F4E99	2017-07-12 23:00:00+03	136600.00
1F4ECC	2017-08-02 19:10:00+03	39500.00
1F4EFE	2017-07-21 16:17:00+03	111600.00
1F4F22	2017-07-12 07:48:00+03	45100.00
1F4F3E	2017-07-13 15:25:00+03	47700.00
1F4FEA	2017-08-12 01:34:00+03	92100.00
1F5061	2017-08-04 22:36:00+03	61800.00
1F506F	2017-08-06 15:08:00+03	67600.00
1F50C9	2017-07-27 03:39:00+03	44800.00
1F50F0	2017-07-16 14:17:00+03	15100.00
1F50F7	2017-07-19 03:00:00+03	80300.00
1F5126	2017-08-05 06:26:00+03	81700.00
1F512A	2017-07-07 11:14:00+03	199200.00
1F5149	2017-07-19 11:39:00+03	85300.00
1F519F	2017-08-01 09:10:00+03	117600.00
1F51F0	2017-07-29 20:20:00+03	46000.00
1F5206	2017-07-10 03:28:00+03	68100.00
1F523C	2017-07-31 00:02:00+03	7400.00
1F524D	2017-07-26 02:31:00+03	8400.00
1F5273	2017-07-06 07:31:00+03	23200.00
1F52F4	2017-08-07 08:29:00+03	66300.00
1F5352	2017-07-07 22:23:00+03	14800.00
1F53A7	2017-07-10 06:28:00+03	56000.00
1F53D1	2017-07-31 21:28:00+03	32200.00
1F53DC	2017-08-14 09:51:00+03	46200.00
1F53DE	2017-07-04 17:16:00+03	55800.00
1F5444	2017-07-17 06:28:00+03	62600.00
1F5449	2017-07-12 05:57:00+03	44400.00
1F5459	2017-07-24 09:22:00+03	24400.00
1F5529	2017-07-31 03:21:00+03	56000.00
1F555D	2017-08-04 22:27:00+03	12000.00
1F5576	2017-07-11 09:31:00+03	229900.00
1F55B6	2017-07-28 17:17:00+03	30000.00
1F55CA	2017-07-12 12:40:00+03	116400.00
1F5623	2017-07-09 00:09:00+03	101400.00
1F5702	2017-08-11 16:58:00+03	19300.00
1F5706	2017-07-20 21:07:00+03	69000.00
1F5731	2017-08-03 06:59:00+03	28800.00
1F5746	2017-07-26 14:13:00+03	77200.00
1F5782	2017-08-06 08:36:00+03	25400.00
1F57A2	2017-08-12 18:45:00+03	38600.00
1F57F0	2017-08-02 04:33:00+03	21400.00
1F582B	2017-07-11 14:52:00+03	55800.00
1F583C	2017-08-11 04:43:00+03	258600.00
1F5872	2017-08-05 15:13:00+03	52800.00
1F5882	2017-07-10 11:26:00+03	27800.00
1F5888	2017-07-13 13:48:00+03	41800.00
1F58F7	2017-07-14 02:06:00+03	132800.00
1F5933	2017-07-13 01:16:00+03	23100.00
1F59B3	2017-08-10 15:43:00+03	28000.00
1F59F6	2017-07-19 23:00:00+03	28300.00
1F5A45	2017-07-02 08:53:00+03	43000.00
1F5A4F	2017-07-27 10:45:00+03	71400.00
1F5A5D	2017-07-21 16:06:00+03	24400.00
1F5A84	2017-07-03 18:55:00+03	113200.00
1F5AC6	2017-08-14 15:43:00+03	25200.00
1F5B20	2017-08-09 22:10:00+03	153300.00
1F5B3A	2017-07-15 15:27:00+03	89600.00
1F5B64	2017-07-03 15:31:00+03	56000.00
1F5BE8	2017-07-03 23:32:00+03	39300.00
1F5C38	2017-08-10 17:53:00+03	258300.00
1F5C4F	2017-07-24 04:02:00+03	75600.00
1F5C62	2017-07-21 17:21:00+03	39800.00
1F5CEC	2017-08-08 03:49:00+03	14700.00
1F5D0A	2017-08-02 23:14:00+03	54800.00
1F5D38	2017-07-08 07:15:00+03	25600.00
1F5DF6	2017-08-11 08:09:00+03	31100.00
1F5E2F	2017-07-01 14:10:00+03	25800.00
1F5E6A	2017-07-05 08:18:00+03	27200.00
1F5E73	2017-07-31 20:41:00+03	57600.00
1F5EA8	2017-07-26 02:21:00+03	115700.00
1F5ED7	2017-07-02 21:32:00+03	246000.00
1F5EE3	2017-08-12 08:00:00+03	21400.00
1F5F59	2017-07-02 00:49:00+03	246000.00
1F5F92	2017-06-29 18:20:00+03	30200.00
1F5FDB	2017-08-13 00:19:00+03	129800.00
1F6012	2017-08-10 00:57:00+03	84800.00
1F601D	2017-07-22 05:07:00+03	166000.00
1F6023	2017-08-08 01:06:00+03	23200.00
1F60D8	2017-07-27 15:17:00+03	134400.00
1F60F2	2017-07-28 18:44:00+03	8400.00
1F611B	2017-07-11 05:04:00+03	35600.00
1F611D	2017-07-03 23:43:00+03	55800.00
1F61A1	2017-07-23 10:27:00+03	123000.00
1F61C5	2017-07-05 16:36:00+03	136100.00
1F6242	2017-08-05 03:52:00+03	67100.00
1F6310	2017-08-12 07:24:00+03	47000.00
1F634B	2017-07-14 15:03:00+03	55800.00
1F6373	2017-07-06 17:50:00+03	85000.00
1F63AC	2017-08-07 09:27:00+03	73500.00
1F63B0	2017-08-13 10:16:00+03	125600.00
1F6415	2017-07-21 21:09:00+03	58900.00
1F641B	2017-07-02 02:41:00+03	31800.00
1F641E	2017-07-29 17:06:00+03	11600.00
1F6440	2017-08-12 10:44:00+03	64700.00
1F6441	2017-07-14 05:40:00+03	160700.00
1F64DC	2017-08-14 04:50:00+03	36000.00
1F652E	2017-07-31 07:14:00+03	124300.00
1F654B	2017-08-08 10:54:00+03	48400.00
1F6581	2017-08-13 07:07:00+03	14000.00
1F65BD	2017-08-13 03:03:00+03	40800.00
1F65C0	2017-08-11 17:35:00+03	55800.00
1F66CD	2017-07-15 01:34:00+03	24300.00
1F67A1	2017-07-02 00:46:00+03	86300.00
1F67CE	2017-08-02 17:52:00+03	65500.00
1F68B2	2017-07-21 03:41:00+03	55800.00
1F690E	2017-08-13 03:53:00+03	273500.00
1F6989	2017-06-26 20:49:00+03	64400.00
1F6A03	2017-07-24 22:10:00+03	31400.00
1F6A16	2017-08-07 17:45:00+03	57700.00
1F6A75	2017-07-02 21:59:00+03	62600.00
1F6AA2	2017-07-26 23:00:00+03	81600.00
1F6ADC	2017-07-29 03:37:00+03	51100.00
1F6AFA	2017-07-31 20:32:00+03	117600.00
1F6B32	2017-08-09 03:34:00+03	36200.00
1F6B9A	2017-08-13 17:25:00+03	135100.00
1F6BC2	2017-08-10 03:28:00+03	14000.00
1F6C17	2017-07-31 21:21:00+03	70600.00
1F6C6F	2017-07-09 13:19:00+03	52900.00
1F6CBF	2017-08-12 22:11:00+03	208200.00
1F6CD9	2017-08-06 07:47:00+03	177200.00
1F6D03	2017-07-14 03:30:00+03	74300.00
1F6D28	2017-07-27 14:28:00+03	31600.00
1F6DF4	2017-07-02 06:37:00+03	168000.00
1F6E19	2017-08-04 20:22:00+03	110400.00
1F6E42	2017-07-08 21:17:00+03	53400.00
1F6E7B	2017-07-10 17:21:00+03	56000.00
1F6EB0	2017-07-09 22:01:00+03	88800.00
1F6EED	2017-07-16 13:37:00+03	19800.00
1F6EF8	2017-07-11 21:07:00+03	6300.00
1F6F02	2017-08-13 07:55:00+03	40100.00
1F6F82	2017-08-02 15:06:00+03	131600.00
1F6F84	2017-07-26 19:46:00+03	28800.00
1F6F97	2017-07-12 18:05:00+03	27200.00
1F700C	2017-07-25 13:26:00+03	28800.00
1F701B	2017-07-27 11:00:00+03	80000.00
1F7064	2017-07-19 22:45:00+03	92100.00
1F70A7	2017-08-02 07:52:00+03	31400.00
1F70CF	2017-08-15 12:25:00+03	50800.00
1F7116	2017-07-03 06:34:00+03	81300.00
1F7152	2017-07-14 13:25:00+03	46400.00
1F71BD	2017-07-09 21:27:00+03	51900.00
1F71BF	2017-07-11 18:27:00+03	115700.00
1F71DD	2017-07-06 00:41:00+03	289300.00
1F71E2	2017-07-16 08:41:00+03	98400.00
1F723C	2017-07-27 02:01:00+03	408500.00
1F7242	2017-07-09 13:37:00+03	16400.00
1F7255	2017-07-11 11:46:00+03	67900.00
1F7286	2017-07-06 21:31:00+03	67400.00
1F7291	2017-08-15 05:50:00+03	51900.00
1F72AC	2017-07-15 13:54:00+03	26200.00
1F731B	2017-07-02 21:42:00+03	58800.00
1F7394	2017-07-25 06:18:00+03	28600.00
1F73BE	2017-07-13 21:58:00+03	26800.00
1F7449	2017-07-04 20:50:00+03	47000.00
1F74DA	2017-07-06 07:08:00+03	101200.00
1F7500	2017-07-02 19:53:00+03	34000.00
1F750C	2017-07-23 16:30:00+03	29600.00
1F7596	2017-07-24 19:46:00+03	65600.00
1F75CF	2017-07-15 12:59:00+03	92400.00
1F75D7	2017-07-21 18:27:00+03	88600.00
1F75F0	2017-07-29 02:34:00+03	54200.00
1F7629	2017-07-26 04:44:00+03	32600.00
1F7638	2017-08-08 14:24:00+03	85000.00
1F7643	2017-07-13 11:07:00+03	112000.00
1F7659	2017-07-08 21:47:00+03	58600.00
1F7670	2017-08-07 19:55:00+03	13700.00
1F767E	2017-07-28 02:13:00+03	55800.00
1F76A7	2017-07-28 17:26:00+03	6700.00
1F77C7	2017-08-09 07:39:00+03	48300.00
1F77D7	2017-08-05 03:36:00+03	48800.00
1F77DA	2017-08-09 10:35:00+03	29800.00
1F783A	2017-08-05 03:35:00+03	6700.00
1F7885	2017-07-20 07:51:00+03	24600.00
1F78A3	2017-07-18 00:36:00+03	90400.00
1F78FC	2017-07-09 15:43:00+03	92800.00
1F7A25	2017-08-13 13:20:00+03	265600.00
1F7A5E	2017-07-09 10:11:00+03	7300.00
1F7A84	2017-07-31 15:58:00+03	56100.00
1F7A8E	2017-07-25 04:43:00+03	56000.00
1F7AA3	2017-08-05 02:46:00+03	34300.00
1F7AAE	2017-07-02 02:07:00+03	37900.00
1F7AB3	2017-06-30 06:22:00+03	24400.00
1F7ADA	2017-07-23 14:18:00+03	60500.00
1F7ADF	2017-07-17 05:49:00+03	117900.00
1F7B1B	2017-07-16 22:44:00+03	135400.00
1F7B7F	2017-07-24 01:03:00+03	59300.00
1F7C0D	2017-07-25 18:43:00+03	62600.00
1F7C29	2017-07-14 05:28:00+03	24700.00
1F7CAB	2017-08-04 20:38:00+03	209200.00
1F7D1C	2017-07-09 16:42:00+03	25600.00
1F7E22	2017-07-18 00:41:00+03	7400.00
1F7EC4	2017-08-06 21:17:00+03	134800.00
1F7ED7	2017-08-07 01:23:00+03	25600.00
1F80CF	2017-07-24 09:17:00+03	55000.00
1F80DD	2017-08-07 12:52:00+03	23200.00
1F812C	2017-07-12 11:53:00+03	40200.00
1F813B	2017-08-08 13:03:00+03	114600.00
1F8144	2017-07-27 01:58:00+03	57500.00
1F8187	2017-07-24 15:30:00+03	53400.00
1F81CC	2017-07-08 01:17:00+03	7400.00
1F8266	2017-07-02 01:17:00+03	32200.00
1F8277	2017-07-27 02:53:00+03	186900.00
1F8280	2017-08-15 15:28:00+03	60400.00
1F82A5	2017-07-01 15:17:00+03	116900.00
1F8359	2017-08-04 21:01:00+03	87800.00
1F837C	2017-07-06 17:09:00+03	86500.00
1F8444	2017-08-12 13:19:00+03	88000.00
1F8487	2017-08-13 21:47:00+03	266400.00
1F84F2	2017-08-06 18:58:00+03	202000.00
1F8533	2017-08-08 11:21:00+03	139400.00
1F85E5	2017-07-22 13:06:00+03	28600.00
1F862D	2017-08-09 04:31:00+03	187600.00
1F8642	2017-08-03 20:06:00+03	83400.00
1F86AB	2017-07-20 17:08:00+03	28800.00
1F86FA	2017-07-09 23:40:00+03	84000.00
1F872D	2017-07-20 19:13:00+03	202100.00
1F8767	2017-07-11 20:46:00+03	114800.00
1F87D4	2017-07-20 17:00:00+03	37800.00
1F8890	2017-07-23 02:49:00+03	19600.00
1F88DE	2017-07-05 00:21:00+03	123000.00
1F88E3	2017-07-04 03:25:00+03	73200.00
1F88FD	2017-07-27 03:50:00+03	36200.00
1F892F	2017-07-28 23:06:00+03	58900.00
1F89F0	2017-07-09 00:13:00+03	23600.00
1F89FA	2017-08-12 12:19:00+03	118500.00
1F8A3A	2017-08-08 07:55:00+03	39300.00
1F8A44	2017-08-03 18:42:00+03	46200.00
1F8A7B	2017-06-27 17:02:00+03	101500.00
1F8AAC	2017-08-05 18:08:00+03	49600.00
1F8AFC	2017-07-15 08:00:00+03	119500.00
1F8B19	2017-08-03 18:13:00+03	182300.00
1F8B3F	2017-07-24 05:11:00+03	70700.00
1F8B7E	2017-07-29 22:55:00+03	32400.00
1F8BF5	2017-06-28 19:06:00+03	89700.00
1F8C0B	2017-07-06 19:44:00+03	24700.00
1F8C22	2017-07-20 23:19:00+03	11600.00
1F8C64	2017-07-21 22:27:00+03	6700.00
1F8CA0	2017-08-14 06:10:00+03	118700.00
1F8CFA	2017-07-23 01:58:00+03	69500.00
1F8D27	2017-07-04 05:21:00+03	100200.00
1F8D40	2017-07-16 17:58:00+03	142400.00
1F8D6A	2017-08-14 17:23:00+03	73000.00
1F8D81	2017-08-06 08:17:00+03	190400.00
1F8DA2	2017-08-04 13:13:00+03	56600.00
1F8DB8	2017-08-05 16:23:00+03	252200.00
1F8E83	2017-07-15 05:56:00+03	28000.00
1F8E8C	2017-07-15 20:58:00+03	223200.00
1F8FBC	2017-07-27 09:32:00+03	37200.00
1F8FD5	2017-07-27 04:41:00+03	101500.00
1F9062	2017-07-14 00:24:00+03	139300.00
1F90EE	2017-07-19 00:18:00+03	51900.00
1F90F0	2017-08-11 01:33:00+03	128800.00
1F91B5	2017-08-08 12:19:00+03	59200.00
1F91F8	2017-07-28 15:13:00+03	32800.00
1F9204	2017-07-13 02:18:00+03	56600.00
1F922C	2017-07-06 04:30:00+03	306200.00
1F9254	2017-07-10 22:09:00+03	291000.00
1F9274	2017-08-02 13:24:00+03	46400.00
1F9291	2017-07-18 09:01:00+03	111600.00
1F92BB	2017-07-21 11:28:00+03	25600.00
1F92D5	2017-07-18 01:07:00+03	189400.00
1F92FD	2017-08-15 16:29:00+03	49600.00
1F9361	2017-07-13 15:33:00+03	48800.00
1F9390	2017-07-18 18:18:00+03	652200.00
1F93C5	2017-07-06 19:50:00+03	196900.00
1F93EA	2017-07-27 13:15:00+03	43200.00
1F944A	2017-08-09 06:44:00+03	63200.00
1F9463	2017-07-23 19:16:00+03	68400.00
1F9477	2017-07-15 13:00:00+03	55800.00
1F9505	2017-08-03 02:09:00+03	23200.00
1F9539	2017-07-24 18:34:00+03	88800.00
1F95C2	2017-07-16 15:14:00+03	16400.00
1F95D1	2017-08-09 13:42:00+03	134400.00
1F95F8	2017-07-20 11:28:00+03	147700.00
1F9605	2017-08-13 19:16:00+03	162400.00
1F96B1	2017-07-20 15:29:00+03	19800.00
1F96E2	2017-06-28 07:19:00+03	59800.00
1F96E9	2017-07-18 09:16:00+03	208100.00
1F974A	2017-07-13 07:59:00+03	131100.00
1F978B	2017-08-11 12:52:00+03	8200.00
1F97AF	2017-07-04 06:29:00+03	66600.00
1F97F1	2017-08-04 19:32:00+03	124300.00
1F981C	2017-07-17 10:47:00+03	52100.00
1F984F	2017-07-09 03:29:00+03	118900.00
1F98AE	2017-07-15 23:20:00+03	32200.00
1F9926	2017-08-03 02:56:00+03	28800.00
1F992D	2017-07-15 12:08:00+03	103700.00
1F9983	2017-08-14 08:20:00+03	91800.00
1F998A	2017-07-20 20:45:00+03	36800.00
1F99BE	2017-07-31 00:15:00+03	72300.00
1F9A18	2017-08-13 16:07:00+03	229600.00
1F9A58	2017-07-18 18:10:00+03	259000.00
1F9A9D	2017-07-05 19:46:00+03	36800.00
1F9AA1	2017-08-12 15:47:00+03	27300.00
1F9AAF	2017-08-14 15:08:00+03	100000.00
1F9ACD	2017-07-10 09:28:00+03	96200.00
1F9ADC	2017-07-25 17:47:00+03	24400.00
1F9B06	2017-08-14 03:29:00+03	55800.00
1F9B31	2017-08-14 03:22:00+03	73100.00
1F9B9C	2017-08-09 04:17:00+03	198600.00
1F9BAC	2017-07-14 01:55:00+03	68800.00
1F9BC4	2017-07-26 04:05:00+03	65500.00
1F9BF1	2017-07-10 17:55:00+03	28000.00
1F9C09	2017-08-01 21:34:00+03	265600.00
1F9C5B	2017-06-24 19:54:00+03	87600.00
1F9C7E	2017-07-04 20:49:00+03	63400.00
1F9C81	2017-07-21 18:26:00+03	28800.00
1F9CA3	2017-08-12 23:32:00+03	27200.00
1F9D22	2017-07-23 07:28:00+03	39300.00
1F9DA8	2017-07-27 08:57:00+03	114800.00
1F9E02	2017-07-03 01:45:00+03	66600.00
1F9E15	2017-07-24 09:12:00+03	115400.00
1F9E7D	2017-07-25 09:25:00+03	28000.00
1F9F31	2017-08-06 07:58:00+03	101200.00
1F9F52	2017-08-10 17:09:00+03	56100.00
1F9FA7	2017-08-13 14:14:00+03	74000.00
1F9FD0	2017-08-04 00:20:00+03	56600.00
1FA05B	2017-07-23 08:01:00+03	28900.00
1FA08F	2017-08-03 02:35:00+03	164800.00
1FA0AC	2017-07-09 17:43:00+03	21400.00
1FA132	2017-07-11 09:28:00+03	44600.00
1FA14A	2017-07-25 10:37:00+03	60300.00
1FA166	2017-07-18 23:03:00+03	136200.00
1FA1F4	2017-08-05 12:01:00+03	52400.00
1FA201	2017-08-03 23:21:00+03	24400.00
1FA218	2017-07-03 12:02:00+03	39800.00
1FA2CC	2017-08-13 18:39:00+03	36400.00
1FA2E5	2017-07-23 23:17:00+03	13000.00
1FA330	2017-07-30 02:55:00+03	57400.00
1FA36C	2017-08-03 15:31:00+03	34000.00
1FA396	2017-08-05 12:12:00+03	86300.00
1FA3B2	2017-08-04 01:33:00+03	25200.00
1FA3EA	2017-08-05 16:00:00+03	56000.00
1FA488	2017-07-25 06:21:00+03	13400.00
1FA4F8	2017-07-26 22:09:00+03	207200.00
1FA52A	2017-07-23 12:24:00+03	40100.00
1FA58B	2017-08-14 07:33:00+03	189200.00
1FA5AF	2017-07-08 08:19:00+03	18100.00
1FA5E9	2017-08-05 15:47:00+03	95600.00
1FA5F9	2017-06-28 23:21:00+03	12400.00
1FA621	2017-07-12 15:26:00+03	28800.00
1FA6E0	2017-07-09 17:50:00+03	155600.00
1FA6F3	2017-08-13 04:19:00+03	8600.00
1FA6F9	2017-08-05 01:05:00+03	195900.00
1FA73B	2017-07-12 18:03:00+03	37900.00
1FA789	2017-07-06 19:02:00+03	184000.00
1FA7C2	2017-07-18 01:52:00+03	37900.00
1FA7F1	2017-07-06 00:08:00+03	140800.00
1FA81E	2017-07-11 12:48:00+03	25400.00
1FA885	2017-07-19 01:24:00+03	167400.00
1FA88A	2017-08-12 09:10:00+03	62000.00
1FA910	2017-07-24 08:54:00+03	36200.00
1FA98C	2017-08-02 15:35:00+03	90800.00
1FA9AC	2017-08-12 03:08:00+03	28800.00
1FA9CE	2017-08-10 17:01:00+03	27300.00
1FA9DD	2017-08-13 09:59:00+03	24400.00
1FA9FE	2017-07-24 13:26:00+03	61800.00
1FAA6C	2017-07-22 01:49:00+03	42100.00
1FAAA3	2017-07-17 22:05:00+03	38000.00
1FAAFF	2017-07-30 20:57:00+03	148200.00
1FAB00	2017-08-11 15:40:00+03	75300.00
1FAB1A	2017-07-09 16:05:00+03	125700.00
1FAB43	2017-07-05 20:02:00+03	92000.00
1FAB6A	2017-08-03 13:39:00+03	30800.00
1FAB75	2017-07-05 19:41:00+03	96300.00
1FABA7	2017-07-26 14:02:00+03	13800.00
1FAC20	2017-08-07 12:48:00+03	54800.00
1FAC32	2017-07-07 11:44:00+03	17800.00
1FAC4D	2017-07-24 16:54:00+03	6300.00
1FACBC	2017-07-15 22:24:00+03	24400.00
1FAD83	2017-07-06 17:13:00+03	91100.00
1FADC5	2017-07-17 03:00:00+03	6700.00
1FADE7	2017-07-16 12:07:00+03	94000.00
1FAE22	2017-07-13 00:30:00+03	112000.00
1FAE8C	2017-07-19 22:26:00+03	81400.00
1FAE98	2017-08-03 01:59:00+03	40800.00
1FAEA8	2017-07-20 13:42:00+03	150100.00
1FAEAD	2017-07-19 17:34:00+03	30000.00
1FAEEF	2017-08-03 12:19:00+03	39300.00
1FAF3F	2017-08-15 03:20:00+03	111600.00
1FAF4D	2017-07-10 09:58:00+03	100200.00
1FAF95	2017-08-08 21:18:00+03	96200.00
1FAFDC	2017-07-04 23:39:00+03	55800.00
1FAFE5	2017-08-03 17:48:00+03	67600.00
1FB02E	2017-07-19 12:41:00+03	248300.00
1FB070	2017-07-23 03:10:00+03	12200.00
1FB0A2	2017-08-10 21:25:00+03	123000.00
1FB11A	2017-07-02 05:22:00+03	21800.00
1FB128	2017-08-13 15:16:00+03	14400.00
1FB18F	2017-07-17 13:52:00+03	33300.00
1FB1E4	2017-07-06 00:08:00+03	6200.00
1FB1E6	2017-08-14 15:26:00+03	47100.00
1FB31E	2017-08-14 10:06:00+03	29500.00
1FB336	2017-07-19 20:27:00+03	66600.00
1FB33B	2017-08-12 13:14:00+03	45100.00
1FB3C2	2017-08-06 19:11:00+03	56000.00
1FB406	2017-07-16 14:27:00+03	14400.00
1FB4AF	2017-08-03 07:00:00+03	24200.00
1FB4CE	2017-07-29 11:44:00+03	92700.00
1FB5C5	2017-07-10 10:23:00+03	28000.00
1FB6C4	2017-07-11 23:54:00+03	28000.00
1FB74C	2017-07-07 20:42:00+03	6700.00
1FB761	2017-07-05 09:12:00+03	23200.00
1FB771	2017-07-17 05:41:00+03	12000.00
1FB78C	2017-07-15 06:49:00+03	24400.00
1FB86E	2017-08-15 12:42:00+03	118000.00
1FB8EF	2017-07-10 14:18:00+03	27200.00
1FB8F3	2017-07-05 05:11:00+03	62800.00
1FBA17	2017-07-23 02:21:00+03	132200.00
1FBAAE	2017-08-08 12:15:00+03	62900.00
1FBB11	2017-07-12 19:54:00+03	13400.00
1FBB5D	2017-07-05 17:52:00+03	6700.00
1FBB76	2017-07-08 04:15:00+03	39200.00
1FBBA0	2017-07-12 11:47:00+03	187800.00
1FBBA5	2017-07-11 10:52:00+03	36200.00
1FBC0B	2017-07-19 02:21:00+03	7200.00
1FBC67	2017-07-12 11:15:00+03	29600.00
1FBD59	2017-07-16 00:51:00+03	39800.00
1FBD79	2017-07-10 09:49:00+03	24000.00
1FBD87	2017-08-01 10:36:00+03	28700.00
1FBDC2	2017-07-05 18:46:00+03	71900.00
1FBE18	2017-08-10 07:36:00+03	136600.00
1FBE2C	2017-07-20 18:24:00+03	190400.00
1FBE36	2017-07-29 19:39:00+03	56600.00
1FBE41	2017-07-20 17:47:00+03	40800.00
1FBED5	2017-08-14 17:48:00+03	70600.00
1FBF21	2017-07-22 20:01:00+03	25200.00
1FBF7F	2017-07-21 19:34:00+03	428300.00
1FBF8C	2017-08-09 20:23:00+03	35900.00
1FBFD0	2017-07-14 10:15:00+03	40000.00
1FBFF7	2017-06-27 20:19:00+03	91500.00
1FC034	2017-07-14 14:29:00+03	181000.00
1FC03A	2017-08-13 23:28:00+03	82100.00
1FC04F	2017-07-28 23:41:00+03	24300.00
1FC13F	2017-08-12 13:45:00+03	105600.00
1FC16E	2017-07-15 00:22:00+03	144700.00
1FC1B8	2017-07-22 02:55:00+03	179500.00
1FC1E4	2017-08-07 23:32:00+03	129400.00
1FC20F	2017-07-30 15:06:00+03	61400.00
1FC239	2017-07-02 09:00:00+03	44000.00
1FC289	2017-07-23 06:02:00+03	277900.00
1FC2ED	2017-08-08 16:05:00+03	29600.00
1FC2F5	2017-07-15 14:36:00+03	71800.00
1FC302	2017-07-31 10:42:00+03	378700.00
1FC33E	2017-07-28 15:00:00+03	137800.00
1FC366	2017-07-30 04:01:00+03	81900.00
1FC387	2017-07-16 14:49:00+03	56000.00
1FC3CB	2017-07-22 11:47:00+03	47100.00
1FC429	2017-07-03 01:43:00+03	111600.00
1FC4C5	2017-07-03 03:27:00+03	56000.00
1FC4D7	2017-07-28 20:25:00+03	67600.00
1FC4E9	2017-07-25 22:49:00+03	51300.00
1FC4F0	2017-07-22 10:21:00+03	34000.00
1FC504	2017-07-20 17:31:00+03	103600.00
1FC52F	2017-07-03 08:59:00+03	64000.00
1FC594	2017-08-06 20:36:00+03	42800.00
1FC5EC	2017-08-12 01:40:00+03	8000.00
1FC601	2017-07-30 01:06:00+03	68000.00
1FC645	2017-07-11 07:36:00+03	60400.00
1FC6F7	2017-08-05 01:03:00+03	94700.00
1FC7CE	2017-08-12 06:00:00+03	36800.00
1FC7E2	2017-07-06 02:43:00+03	101200.00
1FC80D	2017-07-19 20:59:00+03	19600.00
1FC837	2017-07-17 15:57:00+03	24400.00
1FC8AB	2017-08-09 05:34:00+03	55800.00
1FC8B2	2017-08-01 01:28:00+03	8000.00
1FC9E4	2017-08-05 13:06:00+03	24400.00
1FC9E8	2017-07-11 00:26:00+03	135600.00
1FC9EE	2017-07-04 06:49:00+03	196800.00
1FCA57	2017-08-10 15:32:00+03	23200.00
1FCADB	2017-07-14 04:44:00+03	41800.00
1FCADC	2017-07-14 16:34:00+03	84300.00
1FCAF8	2017-07-18 02:20:00+03	111600.00
1FCB82	2017-08-05 12:13:00+03	120700.00
1FCBB9	2017-07-05 18:22:00+03	304800.00
1FCBE2	2017-07-09 21:41:00+03	58400.00
1FCC50	2017-07-21 17:38:00+03	86400.00
1FCC96	2017-07-11 13:28:00+03	134600.00
1FCCAF	2017-07-24 20:23:00+03	15900.00
1FCCC4	2017-07-09 12:25:00+03	67600.00
1FCD46	2017-07-28 14:03:00+03	21400.00
1FCD7C	2017-07-19 01:26:00+03	48800.00
1FCD93	2017-07-15 23:37:00+03	27400.00
1FCDBC	2017-08-02 12:34:00+03	210200.00
1FCDF1	2017-07-12 20:44:00+03	82900.00
1FCDF5	2017-08-14 06:04:00+03	15000.00
1FCE93	2017-07-01 14:17:00+03	152900.00
1FCE9A	2017-08-03 07:54:00+03	103900.00
1FCED5	2017-07-01 20:10:00+03	67600.00
1FCED7	2017-07-08 03:46:00+03	57300.00
1FCEE3	2017-07-07 00:57:00+03	63700.00
1FCF83	2017-07-15 02:07:00+03	140800.00
1FCFD6	2017-07-11 18:49:00+03	68000.00
1FCFF7	2017-08-08 10:48:00+03	30300.00
1FD01A	2017-07-01 06:29:00+03	20600.00
1FD069	2017-07-18 08:51:00+03	32200.00
1FD0E9	2017-07-05 19:16:00+03	87000.00
1FD0F6	2017-08-15 08:00:00+03	77500.00
1FD105	2017-07-22 06:39:00+03	31000.00
1FD11D	2017-08-12 07:24:00+03	55800.00
1FD127	2017-08-06 09:30:00+03	31200.00
1FD12D	2017-07-04 21:09:00+03	57400.00
1FD12E	2017-07-28 03:05:00+03	155600.00
1FD207	2017-07-29 10:43:00+03	65500.00
1FD20A	2017-07-21 17:39:00+03	92400.00
1FD216	2017-07-02 01:59:00+03	118600.00
1FD2AD	2017-07-20 09:46:00+03	52700.00
1FD2BD	2017-07-26 04:07:00+03	24000.00
1FD2F0	2017-07-08 05:36:00+03	269500.00
1FD2F8	2017-07-23 18:26:00+03	75500.00
1FD330	2017-07-02 18:20:00+03	44800.00
1FD34E	2017-08-07 08:45:00+03	99200.00
1FD37F	2017-08-13 04:31:00+03	51600.00
1FD3E8	2017-08-12 10:35:00+03	12100.00
1FD42B	2017-07-02 14:37:00+03	180000.00
1FD437	2017-07-16 17:21:00+03	31400.00
1FD4A3	2017-07-18 09:55:00+03	103800.00
1FD4C5	2017-07-20 18:29:00+03	113600.00
1FD4D4	2017-08-03 05:00:00+03	40800.00
1FD57C	2017-08-01 13:05:00+03	22400.00
1FD594	2017-07-24 05:18:00+03	290900.00
1FD5A8	2017-07-16 07:56:00+03	51800.00
1FD5B0	2017-07-26 08:04:00+03	23100.00
1FD5BC	2017-08-11 20:31:00+03	196700.00
1FD5C1	2017-08-12 12:59:00+03	94000.00
1FD5C2	2017-07-11 13:15:00+03	116400.00
1FD608	2017-07-11 21:49:00+03	144400.00
1FD622	2017-07-11 18:48:00+03	116400.00
1FD67B	2017-08-05 01:33:00+03	24200.00
1FD6A3	2017-08-06 10:14:00+03	294200.00
1FD6AC	2017-08-14 22:02:00+03	13300.00
1FD6BF	2017-07-06 05:07:00+03	283100.00
1FD6E2	2017-08-07 12:58:00+03	12600.00
1FD6E9	2017-08-15 08:57:00+03	148200.00
1FD714	2017-08-08 11:41:00+03	189500.00
1FD73D	2017-07-15 01:13:00+03	76600.00
1FD742	2017-07-07 02:57:00+03	25200.00
1FD74A	2017-08-05 19:18:00+03	26200.00
1FD74F	2017-07-30 23:37:00+03	41800.00
1FD834	2017-07-12 01:09:00+03	7400.00
1FD847	2017-08-04 14:47:00+03	67200.00
1FD8AC	2017-08-06 17:01:00+03	54600.00
1FD927	2017-07-01 12:19:00+03	65500.00
1FD932	2017-07-12 06:08:00+03	30000.00
1FD99F	2017-07-12 10:35:00+03	57600.00
1FDA34	2017-08-14 12:30:00+03	45100.00
1FDA41	2017-07-19 10:32:00+03	55800.00
1FDA42	2017-07-22 02:12:00+03	51800.00
1FDA7A	2017-08-08 10:38:00+03	98400.00
1FDA8C	2017-07-10 05:58:00+03	51900.00
1FDB3D	2017-07-10 19:36:00+03	112000.00
1FDB65	2017-07-03 04:27:00+03	193000.00
1FDC4C	2017-08-07 07:32:00+03	26800.00
1FDC8A	2017-07-21 11:20:00+03	246000.00
1FDC8D	2017-07-09 09:54:00+03	40000.00
1FDD23	2017-07-18 05:14:00+03	57600.00
1FDD5E	2017-07-16 09:17:00+03	135400.00
1FDD87	2017-07-03 07:44:00+03	74900.00
1FDDAF	2017-07-16 18:07:00+03	39300.00
1FDDDF	2017-08-05 02:41:00+03	112200.00
1FDDEB	2017-07-16 15:23:00+03	31800.00
1FDE3E	2017-07-25 14:30:00+03	7800.00
1FDE87	2017-07-18 00:20:00+03	24700.00
1FDE97	2017-08-06 21:04:00+03	254600.00
1FDE9B	2017-07-18 12:26:00+03	204700.00
1FDF85	2017-07-21 07:10:00+03	28000.00
1FE04A	2017-06-30 05:09:00+03	28800.00
1FE07D	2017-07-31 14:15:00+03	100600.00
1FE08E	2017-07-14 05:31:00+03	14400.00
1FE09C	2017-08-14 14:23:00+03	45200.00
1FE0F2	2017-08-15 13:23:00+03	131100.00
1FE166	2017-08-11 01:00:00+03	34600.00
1FE168	2017-07-26 05:51:00+03	21800.00
1FE172	2017-07-17 06:55:00+03	46500.00
1FE17D	2017-08-10 07:25:00+03	28700.00
1FE182	2017-08-14 12:25:00+03	86400.00
1FE1CD	2017-06-28 00:47:00+03	23200.00
1FE1DD	2017-07-05 19:20:00+03	66600.00
1FE1F1	2017-07-06 12:04:00+03	41200.00
1FE1F8	2017-08-06 06:15:00+03	13700.00
1FE206	2017-08-08 01:24:00+03	26000.00
1FE20B	2017-08-07 06:35:00+03	6700.00
1FE275	2017-07-22 18:49:00+03	48800.00
1FE28B	2017-08-03 17:07:00+03	64700.00
1FE2CB	2017-08-08 04:42:00+03	57600.00
1FE312	2017-08-01 04:21:00+03	47100.00
1FE372	2017-07-23 20:23:00+03	49100.00
1FE3DE	2017-07-14 05:33:00+03	28800.00
1FE3F1	2017-08-15 15:34:00+03	146300.00
1FE3F9	2017-07-28 12:41:00+03	65900.00
1FE408	2017-07-13 02:49:00+03	99200.00
1FE429	2017-08-02 02:15:00+03	34000.00
1FE4B0	2017-07-06 01:46:00+03	65500.00
1FE4B2	2017-07-05 07:16:00+03	39400.00
1FE5B9	2017-07-17 03:10:00+03	313800.00
1FE5C1	2017-08-05 10:53:00+03	51900.00
1FE5F6	2017-07-28 22:11:00+03	68800.00
1FE604	2017-07-27 17:16:00+03	46000.00
1FE617	2017-07-07 15:53:00+03	12600.00
1FE620	2017-07-06 21:17:00+03	31600.00
1FE62C	2017-08-03 04:11:00+03	20600.00
1FE664	2017-07-29 04:15:00+03	45200.00
1FE6B7	2017-07-20 00:06:00+03	61800.00
1FE6F5	2017-07-10 02:30:00+03	37900.00
1FE793	2017-07-14 01:22:00+03	38000.00
1FE7EF	2017-07-14 17:35:00+03	38600.00
1FE81B	2017-08-14 00:55:00+03	13400.00
1FE866	2017-07-10 17:43:00+03	47700.00
1FE8F6	2017-06-27 20:07:00+03	66600.00
1FE9BE	2017-07-29 12:29:00+03	94000.00
1FE9E9	2017-06-30 07:51:00+03	125300.00
1FE9FB	2017-07-19 05:37:00+03	51600.00
1FEA3C	2017-07-03 08:02:00+03	16400.00
1FEA69	2017-07-07 12:03:00+03	47200.00
1FEA74	2017-08-08 02:22:00+03	27400.00
1FEAF9	2017-08-06 09:14:00+03	31600.00
1FEB55	2017-07-08 06:34:00+03	272300.00
1FEB79	2017-07-31 00:30:00+03	27800.00
1FEB82	2017-07-26 08:12:00+03	31600.00
1FEBCC	2017-08-11 23:13:00+03	95200.00
1FEC3F	2017-07-04 07:10:00+03	47800.00
1FEC41	2017-07-25 04:52:00+03	56600.00
1FECC1	2017-07-22 08:26:00+03	29400.00
1FECE2	2017-07-16 05:25:00+03	40800.00
1FED21	2017-07-11 23:45:00+03	93900.00
1FED52	2017-08-07 07:33:00+03	56700.00
1FEDB1	2017-07-01 02:08:00+03	85000.00
1FEDB3	2017-07-01 06:21:00+03	103600.00
1FEDFA	2017-08-10 15:04:00+03	103600.00
1FEE09	2017-07-09 04:46:00+03	73300.00
1FEE71	2017-07-28 01:18:00+03	67500.00
1FEEA9	2017-08-06 23:02:00+03	33600.00
1FEECC	2017-07-28 17:22:00+03	85700.00
1FEF25	2017-08-01 05:19:00+03	37900.00
1FEF29	2017-07-23 00:17:00+03	16800.00
1FEF3A	2017-07-14 03:20:00+03	108900.00
1FEFA0	2017-07-13 15:38:00+03	6800.00
1FEFCA	2017-07-23 10:14:00+03	28000.00
1FEFDD	2017-08-06 21:02:00+03	65900.00
1FF00B	2017-07-28 21:21:00+03	31400.00
1FF01D	2017-07-21 23:16:00+03	124200.00
1FF026	2017-07-28 00:37:00+03	143600.00
1FF0A9	2017-08-06 00:44:00+03	300700.00
1FF0DD	2017-07-06 06:13:00+03	29400.00
1FF123	2017-07-23 19:35:00+03	87100.00
1FF129	2017-07-16 17:38:00+03	246000.00
1FF130	2017-07-14 14:41:00+03	92800.00
1FF1AE	2017-07-23 09:57:00+03	84500.00
1FF1B2	2017-07-29 22:55:00+03	319400.00
1FF1BC	2017-07-23 08:54:00+03	55800.00
1FF1D0	2017-07-22 13:21:00+03	27200.00
1FF1F9	2017-08-03 08:40:00+03	103800.00
1FF24F	2017-07-15 05:48:00+03	158500.00
1FF256	2017-07-13 14:27:00+03	89200.00
1FF25E	2017-08-02 05:18:00+03	49500.00
1FF275	2017-08-03 13:47:00+03	21400.00
1FF27C	2017-07-01 01:11:00+03	56600.00
1FF295	2017-07-16 19:03:00+03	44600.00
1FF36D	2017-07-20 05:12:00+03	8200.00
1FF390	2017-07-05 20:20:00+03	43500.00
1FF3AB	2017-07-03 12:51:00+03	54500.00
1FF3DA	2017-08-10 18:29:00+03	166900.00
1FF43E	2017-07-09 22:05:00+03	40000.00
1FF4D6	2017-07-29 12:10:00+03	40000.00
1FF51F	2017-07-13 04:15:00+03	64500.00
1FF529	2017-08-03 17:13:00+03	67000.00
1FF58E	2017-07-08 04:17:00+03	123000.00
1FF5A5	2017-07-25 10:43:00+03	57500.00
1FF5CA	2017-08-12 22:48:00+03	199400.00
1FF5FC	2017-07-15 10:11:00+03	258400.00
1FF6BE	2017-08-14 19:14:00+03	26500.00
1FF712	2017-07-14 21:40:00+03	111600.00
1FF718	2017-07-15 04:32:00+03	124200.00
1FF740	2017-07-19 10:55:00+03	218000.00
1FF751	2017-08-07 22:53:00+03	44500.00
1FF7B5	2017-08-05 21:08:00+03	12600.00
1FF7D0	2017-07-04 20:48:00+03	68100.00
1FF7DF	2017-08-05 22:48:00+03	85000.00
1FF7F7	2017-08-13 15:34:00+03	269300.00
1FF84B	2017-07-15 19:31:00+03	112000.00
1FF8D3	2017-07-28 11:43:00+03	148200.00
1FF8DE	2017-07-21 07:28:00+03	63000.00
1FF8F1	2017-07-09 06:16:00+03	89700.00
1FF8FB	2017-07-02 12:07:00+03	44400.00
1FF902	2017-07-22 09:17:00+03	133100.00
1FF952	2017-07-31 12:37:00+03	203000.00
1FF987	2017-08-06 15:09:00+03	24400.00
1FF995	2017-07-12 02:43:00+03	62600.00
1FF9AE	2017-07-20 07:04:00+03	27200.00
1FFA41	2017-07-18 17:16:00+03	45100.00
1FFA7B	2017-07-14 09:08:00+03	57600.00
1FFA7C	2017-07-25 16:11:00+03	55800.00
1FFA99	2017-07-12 04:08:00+03	20200.00
1FFABF	2017-08-13 03:16:00+03	57600.00
1FFB0F	2017-07-31 17:00:00+03	397100.00
1FFB85	2017-08-12 04:57:00+03	111600.00
1FFB87	2017-07-03 15:43:00+03	55300.00
1FFBA2	2017-07-02 15:07:00+03	32200.00
1FFBB6	2017-07-04 05:28:00+03	82700.00
1FFBDA	2017-07-24 10:09:00+03	146700.00
1FFC79	2017-08-10 19:49:00+03	24300.00
1FFCE0	2017-07-28 19:06:00+03	57400.00
1FFDB7	2017-07-11 11:37:00+03	48600.00
1FFE20	2017-07-09 19:49:00+03	61400.00
1FFE33	2017-06-28 13:11:00+03	226800.00
1FFEF1	2017-08-02 04:27:00+03	17000.00
1FFF09	2017-07-29 02:22:00+03	136500.00
1FFF3E	2017-07-07 08:23:00+03	39400.00
1FFF81	2017-07-03 00:49:00+03	81800.00
1FFF9B	2017-08-13 02:44:00+03	32400.00
1FFFD7	2017-08-08 01:58:00+03	27400.00
1FFFE6	2017-07-18 08:20:00+03	174200.00
200014	2017-07-22 06:29:00+03	41200.00
200048	2017-06-28 16:45:00+03	18600.00
20005C	2017-07-07 16:27:00+03	65500.00
200090	2017-08-01 01:47:00+03	75600.00
200193	2017-07-12 10:33:00+03	113600.00
2001A4	2017-07-12 14:27:00+03	59300.00
2001B3	2017-08-06 06:23:00+03	135600.00
2001B8	2017-08-10 22:42:00+03	266400.00
2001E0	2017-07-29 18:47:00+03	65400.00
200217	2017-06-28 08:22:00+03	128800.00
2002BD	2017-07-16 04:47:00+03	179600.00
2002C8	2017-08-12 02:49:00+03	51600.00
20035A	2017-07-26 13:41:00+03	62600.00
200367	2017-07-05 21:10:00+03	62600.00
2003C1	2017-07-05 18:12:00+03	6000.00
20041C	2017-07-24 15:49:00+03	100600.00
20043B	2017-07-24 00:20:00+03	81700.00
20046B	2017-08-09 11:27:00+03	80700.00
200478	2017-07-26 07:32:00+03	66800.00
2004CB	2017-07-09 04:19:00+03	35200.00
2005A6	2017-07-16 08:03:00+03	22000.00
2005D0	2017-07-26 12:08:00+03	36400.00
200612	2017-07-29 10:02:00+03	26700.00
200641	2017-07-25 09:51:00+03	37100.00
200665	2017-07-28 00:55:00+03	60400.00
200689	2017-07-08 09:20:00+03	16400.00
200695	2017-08-15 04:49:00+03	32800.00
2006C0	2017-07-15 07:13:00+03	29000.00
2006EF	2017-08-11 21:04:00+03	40800.00
200758	2017-08-11 15:21:00+03	59000.00
20075D	2017-06-30 04:15:00+03	40000.00
200773	2017-07-22 15:35:00+03	6700.00
20079C	2017-07-09 23:31:00+03	12600.00
200808	2017-08-04 09:59:00+03	265700.00
20084B	2017-07-25 07:58:00+03	135400.00
2008DF	2017-07-14 03:17:00+03	266400.00
20098F	2017-07-06 07:33:00+03	138000.00
20099A	2017-07-23 04:25:00+03	23200.00
2009B1	2017-08-12 07:13:00+03	47600.00
200A02	2017-08-08 20:04:00+03	46800.00
200AE9	2017-08-03 12:24:00+03	100600.00
200B2E	2017-07-02 21:11:00+03	89700.00
200BC3	2017-07-31 06:02:00+03	46400.00
200C83	2017-07-02 01:47:00+03	67600.00
200C93	2017-07-17 16:36:00+03	280800.00
200CAB	2017-07-27 03:26:00+03	28000.00
200CE8	2017-07-24 06:14:00+03	258700.00
200CF3	2017-08-12 13:14:00+03	123000.00
200D29	2017-07-01 13:00:00+03	13000.00
200D3E	2017-07-23 21:23:00+03	138800.00
200D55	2017-07-10 01:57:00+03	13200.00
200D63	2017-08-03 03:50:00+03	530800.00
200D83	2017-07-02 01:40:00+03	23200.00
200DF4	2017-07-09 07:43:00+03	20200.00
200E5D	2017-07-12 09:30:00+03	136400.00
200E71	2017-08-02 05:36:00+03	86400.00
200E76	2017-06-30 02:48:00+03	291000.00
200E8C	2017-08-07 17:05:00+03	64500.00
200EBE	2017-07-10 03:56:00+03	39200.00
200EE6	2017-07-29 04:54:00+03	31900.00
200FA9	2017-07-26 11:36:00+03	80200.00
200FFC	2017-07-23 17:31:00+03	179200.00
200FFD	2017-07-29 04:21:00+03	248300.00
20101B	2017-07-09 22:57:00+03	94200.00
2010FE	2017-07-30 15:17:00+03	266400.00
201122	2017-07-05 07:14:00+03	28800.00
201150	2017-08-10 17:38:00+03	56100.00
201182	2017-08-03 12:56:00+03	65900.00
201210	2017-06-30 17:05:00+03	43100.00
201222	2017-07-18 10:54:00+03	6700.00
201224	2017-07-15 08:13:00+03	32200.00
201268	2017-07-21 14:29:00+03	78800.00
2012C6	2017-07-17 21:56:00+03	26800.00
2012E0	2017-08-06 08:06:00+03	21400.00
2012E9	2017-07-22 08:31:00+03	136200.00
2012F9	2017-08-04 09:06:00+03	123000.00
201319	2017-07-15 14:58:00+03	28800.00
201352	2017-07-17 20:02:00+03	169200.00
201353	2017-07-26 07:17:00+03	28800.00
20136B	2017-07-02 10:47:00+03	134400.00
201372	2017-08-03 12:40:00+03	38300.00
20139B	2017-07-27 19:58:00+03	67100.00
20139C	2017-07-02 08:30:00+03	48800.00
2013CD	2017-07-26 02:17:00+03	29400.00
2013F6	2017-07-23 16:13:00+03	139300.00
201463	2017-07-02 15:57:00+03	202400.00
2014B3	2017-07-30 03:59:00+03	168000.00
2014B6	2017-07-03 12:57:00+03	132500.00
2014D0	2017-07-01 21:07:00+03	38500.00
201511	2017-08-01 16:45:00+03	118600.00
20152B	2017-07-29 08:07:00+03	81900.00
201534	2017-07-28 05:47:00+03	131100.00
20154B	2017-07-17 00:26:00+03	21800.00
201553	2017-07-15 17:30:00+03	29200.00
20156E	2017-08-03 06:19:00+03	54800.00
2015BE	2017-08-09 04:54:00+03	21400.00
2015F7	2017-08-14 04:09:00+03	26600.00
20162E	2017-08-08 14:57:00+03	67200.00
201659	2017-08-01 16:22:00+03	56000.00
2016EE	2017-08-07 08:31:00+03	27200.00
201718	2017-08-02 02:45:00+03	17200.00
201746	2017-07-24 12:13:00+03	84100.00
201768	2017-07-08 00:55:00+03	65900.00
201788	2017-07-02 16:18:00+03	46800.00
2017FD	2017-07-01 02:00:00+03	74400.00
201821	2017-07-05 21:45:00+03	4000.00
20184D	2017-08-10 15:25:00+03	282300.00
201860	2017-07-05 00:51:00+03	131100.00
2018FD	2017-07-24 12:52:00+03	77000.00
201912	2017-07-25 18:36:00+03	60400.00
2019D9	2017-07-10 15:53:00+03	41800.00
2019E6	2017-07-07 12:56:00+03	105800.00
2019E9	2017-07-22 19:37:00+03	22100.00
2019EF	2017-07-17 02:46:00+03	22000.00
2019F1	2017-08-06 10:05:00+03	40600.00
2019F6	2017-07-08 06:32:00+03	23200.00
201A2B	2017-07-17 23:02:00+03	134400.00
201AA3	2017-08-10 09:44:00+03	7200.00
201AF1	2017-07-27 12:05:00+03	55800.00
201B0B	2017-07-04 12:11:00+03	34000.00
201B28	2017-07-15 09:12:00+03	6000.00
201C27	2017-07-23 02:54:00+03	54500.00
201C5C	2017-07-18 17:47:00+03	73300.00
201CB0	2017-08-04 07:03:00+03	199800.00
201CCC	2017-08-06 08:35:00+03	31400.00
201CD5	2017-07-19 02:35:00+03	28000.00
201D1C	2017-07-20 22:40:00+03	6600.00
201DEA	2017-07-01 10:57:00+03	21800.00
201E02	2017-07-02 15:26:00+03	286600.00
201E30	2017-07-29 08:01:00+03	21600.00
201E9B	2017-07-04 14:34:00+03	101200.00
201EA2	2017-07-30 04:00:00+03	101200.00
201F0B	2017-07-24 21:12:00+03	55800.00
201F24	2017-07-26 07:40:00+03	72300.00
201F6B	2017-07-09 06:32:00+03	48800.00
201FB1	2017-07-31 03:14:00+03	114400.00
201FC4	2017-07-16 01:50:00+03	77200.00
20201C	2017-07-20 14:34:00+03	39800.00
202026	2017-08-03 00:23:00+03	246000.00
202081	2017-07-13 17:10:00+03	23600.00
202106	2017-07-30 19:44:00+03	149300.00
202111	2017-07-29 19:09:00+03	14000.00
202140	2017-07-15 10:34:00+03	43200.00
20218D	2017-07-14 20:46:00+03	57600.00
202195	2017-07-21 02:07:00+03	54500.00
2021E0	2017-07-18 10:15:00+03	108500.00
2022BE	2017-08-02 15:31:00+03	46200.00
2022D9	2017-08-03 08:38:00+03	43000.00
2022FF	2017-08-11 12:24:00+03	27400.00
20230A	2017-07-09 22:21:00+03	21000.00
2023EA	2017-07-06 12:42:00+03	73600.00
202432	2017-08-13 02:01:00+03	38600.00
202470	2017-08-10 22:17:00+03	65500.00
2024DD	2017-07-06 18:44:00+03	54000.00
20255C	2017-07-11 12:01:00+03	230000.00
20258E	2017-07-19 18:48:00+03	23200.00
2025A5	2017-08-05 20:46:00+03	31100.00
20260E	2017-07-26 23:12:00+03	94700.00
20261F	2017-07-07 23:26:00+03	118600.00
202646	2017-07-10 23:40:00+03	56600.00
2026B7	2017-07-20 08:04:00+03	58600.00
202700	2017-07-26 20:06:00+03	90200.00
20277A	2017-07-23 02:28:00+03	32800.00
2027A9	2017-07-12 03:19:00+03	37900.00
2027AB	2017-07-31 04:14:00+03	24400.00
202819	2017-08-15 05:06:00+03	10800.00
202839	2017-06-28 06:09:00+03	21400.00
202937	2017-07-06 19:22:00+03	36400.00
20296D	2017-07-10 04:52:00+03	31400.00
20299B	2017-07-22 21:44:00+03	44700.00
2029A9	2017-07-24 21:02:00+03	77900.00
202A4F	2017-07-03 09:33:00+03	6600.00
202A54	2017-07-12 13:54:00+03	92100.00
202A58	2017-07-24 14:23:00+03	37900.00
202A76	2017-07-07 09:22:00+03	56600.00
202BBA	2017-08-12 20:14:00+03	38600.00
202BD9	2017-07-21 18:59:00+03	26000.00
202C0C	2017-08-15 00:43:00+03	26000.00
202C21	2017-07-14 16:29:00+03	11600.00
202D02	2017-07-11 03:04:00+03	26800.00
202D2D	2017-07-22 04:17:00+03	85000.00
202D35	2017-07-07 14:17:00+03	12600.00
202D4A	2017-07-14 14:44:00+03	61800.00
202DAA	2017-07-27 17:29:00+03	31000.00
202DDE	2017-07-12 11:55:00+03	143400.00
202DEE	2017-07-02 09:04:00+03	24400.00
202E27	2017-07-28 10:28:00+03	75300.00
202FBB	2017-07-03 12:58:00+03	19800.00
203008	2017-08-15 04:27:00+03	28800.00
203011	2017-08-09 01:34:00+03	21200.00
20301F	2017-07-06 18:27:00+03	85200.00
203074	2017-08-10 08:33:00+03	50400.00
203080	2017-07-12 18:33:00+03	46000.00
203090	2017-07-08 21:03:00+03	89700.00
203129	2017-08-12 18:56:00+03	36600.00
203154	2017-08-15 11:13:00+03	89100.00
20318B	2017-07-29 14:05:00+03	13700.00
2031CC	2017-07-18 06:55:00+03	48300.00
20320B	2017-07-14 19:39:00+03	141500.00
2032C4	2017-07-08 19:06:00+03	75600.00
2032E4	2017-08-02 22:52:00+03	36200.00
203300	2017-07-19 00:51:00+03	77100.00
20330B	2017-07-28 07:40:00+03	787100.00
203340	2017-08-14 18:46:00+03	28800.00
203363	2017-08-08 13:55:00+03	8000.00
2033B1	2017-06-29 17:41:00+03	123000.00
2033B6	2017-08-10 21:57:00+03	103500.00
203411	2017-07-30 19:44:00+03	128800.00
20342A	2017-07-14 01:47:00+03	36200.00
203475	2017-07-07 15:04:00+03	79600.00
2034A2	2017-08-15 06:11:00+03	24000.00
2034C6	2017-07-31 11:37:00+03	11800.00
203538	2017-07-10 16:30:00+03	43200.00
2035A4	2017-08-09 21:13:00+03	30700.00
2035DF	2017-08-13 01:22:00+03	47700.00
203698	2017-07-01 12:44:00+03	49800.00
2036A0	2017-07-04 06:25:00+03	53500.00
203713	2017-07-13 11:56:00+03	13300.00
203779	2017-07-24 13:02:00+03	42700.00
203819	2017-07-15 16:26:00+03	36200.00
20381F	2017-08-02 08:18:00+03	40000.00
203892	2017-07-16 22:48:00+03	128800.00
2038CE	2017-07-09 20:25:00+03	199800.00
2038E8	2017-07-13 04:37:00+03	107200.00
2038F1	2017-07-01 07:11:00+03	68400.00
203900	2017-07-01 11:29:00+03	81300.00
203935	2017-08-08 07:54:00+03	26000.00
203970	2017-07-20 14:57:00+03	28800.00
2039A7	2017-08-12 05:47:00+03	61300.00
203A1C	2017-07-06 23:05:00+03	272300.00
203A27	2017-08-07 01:40:00+03	36200.00
203A4F	2017-08-03 05:22:00+03	29100.00
203A94	2017-07-18 00:25:00+03	57400.00
203A9A	2017-07-06 00:13:00+03	32200.00
203AAA	2017-07-30 12:58:00+03	152500.00
203ABD	2017-07-28 03:02:00+03	117200.00
203B1A	2017-07-14 05:33:00+03	48800.00
203B53	2017-07-31 09:57:00+03	11000.00
203B92	2017-07-19 14:27:00+03	55800.00
203BC6	2017-07-10 07:06:00+03	12400.00
203BEC	2017-07-19 01:25:00+03	40800.00
203C94	2017-08-03 14:18:00+03	76600.00
203CB5	2017-08-15 07:24:00+03	14400.00
203CDC	2017-07-03 11:12:00+03	78600.00
203CE5	2017-08-09 22:33:00+03	179400.00
203D0C	2017-07-24 03:14:00+03	97900.00
203DD5	2017-08-14 20:07:00+03	6200.00
203ECC	2017-08-13 02:04:00+03	52000.00
203EEA	2017-08-11 19:51:00+03	18600.00
203F19	2017-08-04 04:21:00+03	12400.00
203F63	2017-08-03 23:56:00+03	7300.00
203F82	2017-06-26 17:00:00+03	620800.00
203FB0	2017-07-31 01:55:00+03	62700.00
203FE5	2017-08-12 08:37:00+03	75300.00
2040C7	2017-07-19 18:46:00+03	56000.00
2040CC	2017-07-28 01:36:00+03	38800.00
2040DA	2017-08-14 07:47:00+03	57600.00
2040EC	2017-07-09 04:56:00+03	78100.00
20425A	2017-07-18 22:10:00+03	101800.00
204285	2017-08-04 08:09:00+03	10800.00
204323	2017-07-23 12:42:00+03	100700.00
20438B	2017-07-02 05:07:00+03	103000.00
2043FD	2017-08-15 09:54:00+03	58800.00
20441F	2017-08-11 09:51:00+03	141600.00
204433	2017-07-16 20:21:00+03	46800.00
204459	2017-07-19 09:12:00+03	46700.00
2044A4	2017-07-27 05:52:00+03	80000.00
204504	2017-07-20 12:31:00+03	28000.00
204509	2017-07-09 20:23:00+03	89600.00
2045AC	2017-07-22 14:05:00+03	187600.00
2045F6	2017-07-31 00:20:00+03	11700.00
204601	2017-07-16 03:06:00+03	23600.00
204640	2017-08-08 15:34:00+03	14400.00
204695	2017-08-07 04:47:00+03	12600.00
2046D7	2017-08-11 11:34:00+03	113100.00
2046F2	2017-07-05 15:32:00+03	26000.00
2047AA	2017-07-13 00:53:00+03	135200.00
2047C0	2017-07-04 14:24:00+03	16400.00
2047E1	2017-07-20 13:48:00+03	68100.00
2047F8	2017-07-28 06:17:00+03	111200.00
20484C	2017-07-06 22:31:00+03	145300.00
2048AB	2017-08-15 12:21:00+03	21800.00
2048D3	2017-07-02 02:13:00+03	13600.00
2048F8	2017-07-29 18:46:00+03	40900.00
204923	2017-07-24 12:20:00+03	56000.00
204981	2017-07-21 22:38:00+03	81600.00
2049DF	2017-07-09 13:45:00+03	12600.00
204A01	2017-07-11 02:43:00+03	24800.00
204A0B	2017-07-19 17:01:00+03	131900.00
204A16	2017-07-16 21:46:00+03	16400.00
204A1A	2017-07-26 19:18:00+03	16400.00
204A5D	2017-07-15 17:46:00+03	234000.00
204ACD	2017-07-16 04:21:00+03	141400.00
204AF4	2017-08-10 01:37:00+03	20200.00
204AFB	2017-08-10 00:05:00+03	96800.00
204AFD	2017-07-29 22:22:00+03	100600.00
204B29	2017-08-07 23:28:00+03	29100.00
204B4F	2017-06-30 04:32:00+03	27800.00
204BA1	2017-07-27 07:51:00+03	47400.00
204BA8	2017-07-02 17:44:00+03	14400.00
204BAC	2017-07-02 17:12:00+03	155600.00
204BED	2017-07-29 05:21:00+03	24700.00
204C4F	2017-08-09 14:23:00+03	62800.00
204C65	2017-08-12 17:06:00+03	39800.00
204CA3	2017-07-20 21:27:00+03	26000.00
204D36	2017-08-04 00:46:00+03	58200.00
204DAF	2017-08-06 18:35:00+03	26700.00
204DD2	2017-08-02 01:05:00+03	24400.00
204DEC	2017-07-21 23:40:00+03	31000.00
204E02	2017-07-21 14:05:00+03	56000.00
204E5D	2017-07-11 19:07:00+03	39700.00
204E70	2017-07-13 21:33:00+03	78200.00
204E74	2017-08-01 18:37:00+03	106400.00
204ED4	2017-07-05 03:54:00+03	67800.00
204F3B	2017-08-10 23:41:00+03	48500.00
204F47	2017-07-14 14:20:00+03	25200.00
204F55	2017-07-16 11:20:00+03	35600.00
204F66	2017-07-15 07:48:00+03	22400.00
204F90	2017-08-12 20:57:00+03	70500.00
204FB1	2017-08-06 00:37:00+03	65900.00
204FB7	2017-07-23 20:05:00+03	54100.00
204FE0	2017-07-21 16:50:00+03	135600.00
205055	2017-07-07 01:39:00+03	42400.00
2050F7	2017-08-14 11:42:00+03	170200.00
205108	2017-08-04 01:55:00+03	49800.00
20510C	2017-07-18 22:55:00+03	170200.00
205136	2017-07-30 18:13:00+03	57600.00
205193	2017-08-02 09:32:00+03	99600.00
2051CB	2017-08-14 13:29:00+03	273000.00
2051DD	2017-07-09 06:05:00+03	57300.00
20524E	2017-07-29 15:56:00+03	85000.00
2052E2	2017-07-29 19:21:00+03	152900.00
2052EE	2017-07-02 23:36:00+03	84500.00
2052EF	2017-07-11 02:06:00+03	37200.00
2052F5	2017-07-14 17:20:00+03	119500.00
205363	2017-07-12 09:25:00+03	33200.00
205428	2017-07-30 14:41:00+03	75600.00
20542B	2017-07-20 18:10:00+03	135200.00
20543E	2017-07-28 05:02:00+03	199700.00
205446	2017-07-06 19:47:00+03	38800.00
2054CC	2017-08-02 03:03:00+03	23600.00
205502	2017-07-18 07:17:00+03	75300.00
205573	2017-07-09 12:02:00+03	47100.00
2055C0	2017-08-04 03:52:00+03	162200.00
205607	2017-08-13 09:16:00+03	92000.00
205699	2017-08-07 03:36:00+03	152500.00
20569E	2017-08-04 22:52:00+03	45200.00
2056B6	2017-07-20 08:44:00+03	23100.00
2056D8	2017-08-06 17:14:00+03	40600.00
2056DD	2017-08-03 07:47:00+03	23200.00
2056DE	2017-08-06 00:32:00+03	123000.00
2056F2	2017-08-13 09:18:00+03	91600.00
20573F	2017-07-28 09:05:00+03	69500.00
2057CF	2017-07-03 15:20:00+03	168000.00
2057E7	2017-07-09 20:18:00+03	111600.00
205824	2017-06-29 02:38:00+03	6700.00
205830	2017-08-01 13:37:00+03	248300.00
20585E	2017-07-15 22:46:00+03	28800.00
2058D5	2017-07-23 04:49:00+03	133200.00
20590B	2017-07-20 00:07:00+03	272700.00
205923	2017-06-30 11:18:00+03	32800.00
2059DC	2017-07-02 03:25:00+03	42700.00
2059FF	2017-08-05 13:01:00+03	47000.00
205A0B	2017-07-27 17:47:00+03	224000.00
205A0C	2017-08-08 18:01:00+03	39800.00
205A18	2017-07-21 14:10:00+03	175800.00
205A49	2017-08-02 01:25:00+03	65500.00
205AE2	2017-07-05 12:38:00+03	6600.00
205B92	2017-08-15 03:43:00+03	81300.00
205BA1	2017-07-03 04:14:00+03	54600.00
205BEB	2017-07-13 20:59:00+03	87300.00
205C02	2017-07-08 12:03:00+03	189400.00
205C2C	2017-07-04 12:17:00+03	25400.00
205C76	2017-08-12 07:26:00+03	57300.00
205CEE	2017-07-26 06:01:00+03	48500.00
205D04	2017-07-15 15:28:00+03	6200.00
205D1A	2017-07-05 16:30:00+03	19600.00
205D23	2017-08-09 16:42:00+03	8000.00
205D68	2017-07-23 13:23:00+03	24400.00
205D7E	2017-07-05 22:19:00+03	39400.00
205D7F	2017-07-23 04:06:00+03	101200.00
205E29	2017-07-30 23:51:00+03	71800.00
205E5C	2017-07-26 10:24:00+03	58900.00
205E5E	2017-07-21 02:47:00+03	92000.00
205ECA	2017-07-03 09:02:00+03	69500.00
205ED0	2017-08-02 15:33:00+03	38400.00
205F25	2017-07-07 22:31:00+03	112600.00
205F5E	2017-07-05 22:04:00+03	22000.00
205F60	2017-08-15 13:05:00+03	43600.00
205F89	2017-07-27 03:42:00+03	14400.00
205FE9	2017-07-14 19:49:00+03	50600.00
206056	2017-07-10 21:10:00+03	304100.00
206095	2017-08-13 09:11:00+03	48100.00
2060DC	2017-08-15 00:02:00+03	13600.00
2060ED	2017-07-12 18:54:00+03	43600.00
20610D	2017-07-21 05:45:00+03	12600.00
20612D	2017-08-05 05:49:00+03	66600.00
20615E	2017-07-08 11:46:00+03	86300.00
20619F	2017-07-20 03:10:00+03	278200.00
206209	2017-08-09 22:25:00+03	19600.00
206227	2017-07-30 02:08:00+03	57400.00
206234	2017-07-04 20:32:00+03	50000.00
206282	2017-07-10 15:51:00+03	40100.00
206287	2017-07-19 12:47:00+03	135400.00
2062D3	2017-07-04 19:08:00+03	27300.00
206323	2017-07-16 00:39:00+03	21400.00
206382	2017-08-09 00:41:00+03	38800.00
206390	2017-07-13 03:06:00+03	25200.00
2063E5	2017-07-13 19:28:00+03	28700.00
2063F0	2017-07-28 09:41:00+03	187600.00
2063FC	2017-08-04 16:16:00+03	243700.00
206428	2017-07-22 02:51:00+03	50400.00
206456	2017-07-04 06:25:00+03	56100.00
206484	2017-07-04 07:10:00+03	189800.00
2064FE	2017-07-28 01:35:00+03	278400.00
206520	2017-07-04 17:18:00+03	23600.00
206575	2017-07-12 02:04:00+03	50000.00
2065D1	2017-07-06 10:08:00+03	49200.00
20661C	2017-07-26 19:33:00+03	246000.00
20665D	2017-08-04 05:57:00+03	212800.00
206677	2017-07-11 06:23:00+03	114400.00
20669B	2017-07-28 07:01:00+03	27700.00
2066EF	2017-07-14 11:43:00+03	9200.00
206718	2017-08-14 14:06:00+03	36100.00
20674A	2017-07-16 10:15:00+03	56200.00
20674F	2017-08-05 03:03:00+03	229600.00
206766	2017-07-05 21:09:00+03	117600.00
2067D8	2017-07-16 17:21:00+03	118600.00
2067FA	2017-08-02 13:29:00+03	59200.00
20681A	2017-06-30 15:11:00+03	25700.00
206865	2017-07-28 05:56:00+03	93400.00
20690E	2017-07-09 06:03:00+03	51600.00
20696A	2017-07-07 17:25:00+03	102100.00
206979	2017-07-16 23:17:00+03	70600.00
20699E	2017-07-21 19:19:00+03	26000.00
206A07	2017-07-28 07:13:00+03	86600.00
206A15	2017-07-04 18:45:00+03	31200.00
206AB2	2017-08-14 08:52:00+03	412300.00
206ABC	2017-07-22 20:39:00+03	31400.00
206AF7	2017-08-03 06:19:00+03	14000.00
206B1E	2017-08-02 04:41:00+03	12400.00
206B1F	2017-07-08 21:29:00+03	35400.00
206B2B	2017-07-28 09:43:00+03	386300.00
206BA7	2017-08-05 23:20:00+03	19600.00
206BFC	2017-07-14 09:05:00+03	70800.00
206C1A	2017-07-03 16:48:00+03	24400.00
206C6E	2017-07-28 05:09:00+03	42800.00
206D91	2017-08-11 15:41:00+03	116900.00
206DC3	2017-07-15 11:16:00+03	122000.00
206DE8	2017-07-06 07:35:00+03	94000.00
206ECF	2017-08-03 04:25:00+03	92200.00
206ED3	2017-08-11 23:04:00+03	136500.00
206EE9	2017-08-15 11:43:00+03	74800.00
206F30	2017-07-06 09:45:00+03	24400.00
206FAE	2017-07-12 03:26:00+03	105000.00
206FB8	2017-07-12 10:14:00+03	32400.00
206FD9	2017-07-13 23:24:00+03	26000.00
20701B	2017-07-23 15:55:00+03	24700.00
20708C	2017-07-11 12:57:00+03	58400.00
20708E	2017-07-06 11:18:00+03	47200.00
207111	2017-08-02 03:20:00+03	38600.00
20713E	2017-07-10 01:41:00+03	81700.00
20716C	2017-07-30 19:31:00+03	67700.00
207189	2017-07-01 21:53:00+03	26000.00
2071BB	2017-08-12 21:30:00+03	8400.00
2071C6	2017-08-03 17:27:00+03	56000.00
2071CA	2017-07-10 15:29:00+03	70500.00
2071F5	2017-08-12 08:31:00+03	90000.00
207241	2017-07-21 18:02:00+03	59200.00
20727E	2017-07-08 04:10:00+03	16400.00
2072AA	2017-08-09 03:54:00+03	91200.00
2072E0	2017-08-12 10:38:00+03	155600.00
2072EC	2017-07-17 05:15:00+03	97600.00
207303	2017-08-11 23:49:00+03	76800.00
207327	2017-08-03 05:55:00+03	135000.00
207336	2017-08-14 18:05:00+03	55100.00
20743D	2017-07-25 21:11:00+03	64600.00
207443	2017-07-29 17:27:00+03	13400.00
2074B2	2017-08-14 20:29:00+03	677800.00
207528	2017-07-24 04:59:00+03	69100.00
2075A8	2017-07-18 23:50:00+03	21200.00
207664	2017-07-27 22:48:00+03	37400.00
207672	2017-07-21 06:44:00+03	184500.00
2076B4	2017-07-07 05:03:00+03	140900.00
2076C7	2017-08-04 19:25:00+03	103000.00
2076DC	2017-07-22 05:11:00+03	8400.00
2076EA	2017-08-12 22:30:00+03	6800.00
207718	2017-08-09 02:16:00+03	52000.00
207778	2017-08-01 10:37:00+03	397700.00
20777E	2017-07-04 12:42:00+03	56200.00
207788	2017-07-15 19:51:00+03	16400.00
2077B1	2017-07-10 07:35:00+03	19800.00
207853	2017-07-04 02:52:00+03	23400.00
207879	2017-07-06 00:07:00+03	117200.00
207881	2017-07-26 12:39:00+03	24700.00
2078EA	2017-07-17 08:20:00+03	13400.00
2078F7	2017-08-12 05:28:00+03	50700.00
207942	2017-07-05 05:36:00+03	22000.00
20795F	2017-07-18 21:08:00+03	89700.00
207997	2017-08-10 20:54:00+03	44900.00
207A03	2017-07-03 22:42:00+03	88800.00
207A89	2017-07-07 20:30:00+03	51600.00
207AD8	2017-07-07 07:20:00+03	44300.00
207AFA	2017-07-07 16:20:00+03	28000.00
207B13	2017-08-13 04:47:00+03	67000.00
207B9C	2017-08-01 00:34:00+03	77000.00
207C19	2017-07-20 11:12:00+03	265700.00
207C63	2017-08-01 13:31:00+03	166000.00
207C69	2017-07-31 10:09:00+03	102300.00
207CA3	2017-08-14 17:44:00+03	55800.00
207E2A	2017-08-12 05:32:00+03	81800.00
207E46	2017-07-29 08:36:00+03	134400.00
207E6F	2017-07-20 19:50:00+03	109600.00
207E79	2017-07-09 13:28:00+03	46000.00
207EFF	2017-08-05 16:57:00+03	213200.00
207F2F	2017-07-15 10:20:00+03	136200.00
207F53	2017-08-04 08:04:00+03	28800.00
207FD7	2017-07-22 20:27:00+03	26700.00
208086	2017-08-07 01:26:00+03	23200.00
20808F	2017-07-02 09:46:00+03	72800.00
2080AC	2017-06-30 08:43:00+03	97900.00
208144	2017-08-07 09:35:00+03	51900.00
20815D	2017-07-25 19:41:00+03	38300.00
20816B	2017-07-21 09:10:00+03	13800.00
208196	2017-07-03 03:23:00+03	47000.00
20821E	2017-08-01 01:20:00+03	51300.00
208249	2017-07-19 18:13:00+03	50600.00
20824C	2017-08-15 13:44:00+03	40100.00
208253	2017-08-03 15:33:00+03	27300.00
2082C1	2017-07-04 05:55:00+03	64800.00
2082FB	2017-07-19 17:57:00+03	44700.00
208374	2017-08-04 03:17:00+03	114700.00
208386	2017-08-04 15:00:00+03	141900.00
208392	2017-07-02 05:32:00+03	57500.00
2083ED	2017-07-12 23:28:00+03	98000.00
20849F	2017-07-16 14:13:00+03	24800.00
2084F2	2017-07-15 20:25:00+03	37900.00
20855E	2017-07-03 17:37:00+03	73100.00
208578	2017-07-04 00:59:00+03	34000.00
208598	2017-07-22 18:42:00+03	31400.00
2085B9	2017-07-31 19:40:00+03	139300.00
20861D	2017-07-22 09:34:00+03	155600.00
208654	2017-07-02 01:30:00+03	68100.00
208700	2017-08-03 12:20:00+03	45200.00
208711	2017-08-02 09:54:00+03	131100.00
20873F	2017-07-25 02:55:00+03	123000.00
208752	2017-08-13 08:28:00+03	51900.00
20878E	2017-08-08 17:20:00+03	41600.00
208795	2017-07-07 17:50:00+03	73400.00
20879C	2017-07-12 19:18:00+03	35200.00
20883C	2017-07-31 12:44:00+03	131600.00
20884F	2017-08-05 13:29:00+03	270700.00
208866	2017-07-18 06:27:00+03	27300.00
20888D	2017-07-11 07:20:00+03	202400.00
2088F9	2017-07-06 15:16:00+03	70700.00
20893B	2017-08-01 07:23:00+03	77700.00
208974	2017-07-26 15:02:00+03	38600.00
2089EA	2017-07-28 01:32:00+03	63900.00
208A84	2017-07-03 00:34:00+03	62700.00
208AC1	2017-08-15 17:25:00+03	14000.00
208AE2	2017-07-27 11:34:00+03	199200.00
208AF1	2017-08-01 02:29:00+03	84500.00
208B12	2017-07-16 09:09:00+03	55800.00
208B66	2017-07-14 06:08:00+03	14000.00
208B86	2017-08-12 00:11:00+03	63500.00
208C26	2017-08-06 10:36:00+03	188200.00
208C29	2017-08-06 06:10:00+03	100600.00
208C63	2017-08-08 13:01:00+03	35700.00
208C6E	2017-07-09 13:56:00+03	98000.00
208CAE	2017-08-01 07:49:00+03	64500.00
208D4A	2017-07-16 18:00:00+03	27400.00
208D65	2017-07-01 01:00:00+03	46400.00
208D6B	2017-07-15 16:59:00+03	56000.00
208D86	2017-07-29 16:56:00+03	127300.00
208E1B	2017-07-24 00:52:00+03	50800.00
208E8E	2017-07-15 20:55:00+03	26000.00
208EEB	2017-07-03 11:26:00+03	20200.00
208EEC	2017-07-08 22:28:00+03	36600.00
208F30	2017-08-15 04:50:00+03	63700.00
208F52	2017-07-17 11:01:00+03	43500.00
208FA4	2017-07-16 21:13:00+03	23600.00
20908D	2017-08-01 10:11:00+03	89700.00
20912C	2017-08-06 06:48:00+03	26700.00
20918E	2017-08-06 05:22:00+03	59800.00
2091B2	2017-08-05 23:45:00+03	52700.00
2091E6	2017-08-14 17:46:00+03	37900.00
209288	2017-07-05 14:57:00+03	48800.00
2092A2	2017-07-04 09:13:00+03	43800.00
2092E3	2017-07-21 16:21:00+03	28000.00
20934C	2017-07-21 05:50:00+03	129900.00
2093AF	2017-07-13 20:50:00+03	48800.00
2093B1	2017-07-27 02:39:00+03	22600.00
2093C9	2017-08-04 20:41:00+03	46400.00
2094BE	2017-07-29 05:33:00+03	22400.00
20950B	2017-08-13 02:12:00+03	55800.00
209522	2017-07-13 15:47:00+03	28000.00
209649	2017-07-08 07:34:00+03	112400.00
20968E	2017-07-09 21:31:00+03	111600.00
2096CF	2017-08-01 13:02:00+03	515100.00
2096D4	2017-07-23 18:43:00+03	68300.00
2097C2	2017-08-11 16:41:00+03	111600.00
2097D7	2017-07-19 11:42:00+03	96200.00
2097FD	2017-08-11 10:50:00+03	13600.00
209812	2017-07-19 19:50:00+03	55800.00
20982B	2017-07-23 07:30:00+03	118900.00
209839	2017-07-17 13:47:00+03	94700.00
209870	2017-08-04 15:24:00+03	23600.00
209973	2017-07-31 08:21:00+03	49600.00
209980	2017-08-10 16:51:00+03	24800.00
209981	2017-08-11 02:57:00+03	97400.00
209988	2017-07-01 15:03:00+03	135400.00
2099BF	2017-08-09 18:37:00+03	66600.00
2099D8	2017-08-01 23:29:00+03	166900.00
2099E1	2017-07-19 02:23:00+03	116800.00
209A5F	2017-07-16 17:06:00+03	46400.00
209A8B	2017-08-05 03:41:00+03	177600.00
209A92	2017-07-22 03:37:00+03	59000.00
209B0F	2017-08-11 10:24:00+03	28000.00
209B31	2017-07-07 03:48:00+03	65200.00
209B83	2017-08-15 10:32:00+03	33100.00
209B9F	2017-08-07 08:55:00+03	52700.00
209BB4	2017-07-06 19:17:00+03	6700.00
209BBC	2017-07-21 04:54:00+03	167500.00
209C1A	2017-07-28 11:48:00+03	16400.00
209C98	2017-07-20 11:43:00+03	40400.00
209CD3	2017-08-08 14:58:00+03	118600.00
209CDC	2017-08-06 16:12:00+03	52000.00
209D13	2017-07-10 16:22:00+03	191900.00
209D15	2017-07-14 13:20:00+03	23400.00
209D43	2017-07-30 07:53:00+03	56000.00
209D83	2017-07-11 21:21:00+03	125200.00
209E08	2017-07-10 00:27:00+03	61800.00
209E0E	2017-06-29 08:51:00+03	94000.00
209E2B	2017-08-08 09:56:00+03	38600.00
209EE3	2017-07-16 13:08:00+03	15900.00
209F5C	2017-08-10 08:48:00+03	55800.00
209F62	2017-07-10 04:30:00+03	23400.00
209FB2	2017-08-14 01:57:00+03	148800.00
20A029	2017-07-16 01:35:00+03	123000.00
20A056	2017-08-10 03:18:00+03	55600.00
20A0A2	2017-08-14 12:32:00+03	67700.00
20A0C2	2017-07-27 09:41:00+03	21400.00
20A0E3	2017-08-09 09:43:00+03	55800.00
20A0F6	2017-07-26 06:36:00+03	24400.00
20A18B	2017-07-29 17:42:00+03	69500.00
20A195	2017-07-22 14:43:00+03	54800.00
20A251	2017-07-12 18:32:00+03	246000.00
20A295	2017-07-24 14:26:00+03	99300.00
20A2C6	2017-07-05 15:21:00+03	40800.00
20A329	2017-08-08 14:31:00+03	135600.00
20A367	2017-07-20 23:23:00+03	138500.00
20A402	2017-07-25 21:58:00+03	19600.00
20A41F	2017-08-10 04:22:00+03	55600.00
20A449	2017-07-05 11:57:00+03	152200.00
20A48D	2017-07-19 18:19:00+03	59800.00
20A4AA	2017-07-23 01:49:00+03	96200.00
20A544	2017-07-27 20:47:00+03	6900.00
20A5B7	2017-08-03 17:30:00+03	26000.00
20A638	2017-07-10 10:56:00+03	73200.00
20A648	2017-08-05 03:37:00+03	80800.00
20A663	2017-08-05 09:46:00+03	124200.00
20A665	2017-08-02 04:52:00+03	50400.00
20A729	2017-08-15 14:55:00+03	68400.00
20A7B9	2017-07-29 08:44:00+03	70700.00
20A7CA	2017-08-14 20:36:00+03	19900.00
20A7ED	2017-08-11 13:00:00+03	66400.00
20A89B	2017-07-20 03:24:00+03	142900.00
20A8A8	2017-08-13 10:20:00+03	37700.00
20A8EF	2017-07-30 07:50:00+03	83200.00
20A909	2017-07-30 00:02:00+03	400900.00
20A945	2017-07-28 14:30:00+03	39800.00
20A953	2017-07-25 14:38:00+03	53400.00
20A9F9	2017-07-23 14:14:00+03	67600.00
20AA36	2017-07-06 11:46:00+03	21400.00
20AAB9	2017-07-19 14:14:00+03	65900.00
20AADF	2017-07-06 03:14:00+03	84100.00
20AB74	2017-07-30 14:21:00+03	16400.00
20AC85	2017-08-08 16:26:00+03	377400.00
20ACAD	2017-07-22 00:06:00+03	57600.00
20ACD3	2017-08-04 06:01:00+03	18000.00
20AD03	2017-07-26 22:01:00+03	187900.00
20AD2C	2017-07-08 17:56:00+03	28800.00
20AD4E	2017-06-30 20:06:00+03	23200.00
20AD53	2017-07-08 16:13:00+03	122800.00
20AD96	2017-08-12 16:40:00+03	303500.00
20ADCB	2017-07-26 06:48:00+03	28800.00
20AE1C	2017-07-11 03:39:00+03	228400.00
20AE3D	2017-08-09 15:43:00+03	6300.00
20AE59	2017-08-01 20:08:00+03	24800.00
20AE7E	2017-07-19 14:30:00+03	12400.00
20AEDC	2017-07-24 17:37:00+03	27900.00
20AEED	2017-07-16 01:50:00+03	27200.00
20AF52	2017-07-17 20:18:00+03	81700.00
20AF68	2017-08-12 18:55:00+03	34000.00
20AF85	2017-08-09 01:59:00+03	24400.00
20AF93	2017-07-08 05:43:00+03	224000.00
20AF9E	2017-08-10 20:37:00+03	174900.00
20AFA4	2017-07-31 18:56:00+03	189800.00
20AFC9	2017-08-13 10:31:00+03	29600.00
20AFFF	2017-07-26 10:23:00+03	140500.00
20B026	2017-08-12 18:57:00+03	90400.00
20B033	2017-07-15 02:18:00+03	56000.00
20B06E	2017-07-26 14:20:00+03	23400.00
20B0A2	2017-07-18 20:46:00+03	71600.00
20B0C7	2017-07-23 17:56:00+03	114600.00
20B104	2017-08-14 04:18:00+03	59200.00
20B15F	2017-08-14 12:18:00+03	185400.00
20B164	2017-07-05 03:34:00+03	35200.00
20B18E	2017-07-07 01:48:00+03	73600.00
20B1BA	2017-07-02 18:13:00+03	39500.00
20B258	2017-07-10 21:51:00+03	56600.00
20B317	2017-07-06 19:20:00+03	155700.00
20B329	2017-07-11 17:48:00+03	51300.00
20B360	2017-08-15 09:20:00+03	28000.00
20B37C	2017-07-01 01:31:00+03	23200.00
20B392	2017-07-11 20:23:00+03	49700.00
20B3A5	2017-08-02 06:35:00+03	257600.00
20B455	2017-08-08 08:21:00+03	73500.00
20B482	2017-07-07 01:36:00+03	100000.00
20B493	2017-07-26 15:44:00+03	46000.00
20B4B9	2017-07-23 18:02:00+03	37900.00
20B4F9	2017-08-02 05:26:00+03	43200.00
20B508	2017-07-05 15:42:00+03	67200.00
20B556	2017-07-29 03:36:00+03	56100.00
20B558	2017-08-03 12:05:00+03	43400.00
20B574	2017-08-14 20:19:00+03	271100.00
20B5B3	2017-08-03 22:12:00+03	7400.00
20B617	2017-07-21 12:20:00+03	112000.00
20B61C	2017-07-28 23:37:00+03	134900.00
20B673	2017-07-09 20:41:00+03	45200.00
20B6AE	2017-07-24 21:08:00+03	92400.00
20B6D4	2017-07-09 23:35:00+03	59300.00
20B75A	2017-07-28 17:20:00+03	37900.00
20B7BB	2017-07-13 21:52:00+03	58400.00
20B897	2017-07-22 01:38:00+03	46800.00
20B904	2017-07-07 15:32:00+03	185300.00
20B90A	2017-07-09 14:39:00+03	65800.00
20B9C0	2017-08-07 05:49:00+03	28600.00
20B9D0	2017-07-21 00:43:00+03	24400.00
20BA21	2017-08-12 18:11:00+03	13400.00
20BA41	2017-07-21 20:40:00+03	101200.00
20BA7A	2017-07-04 10:32:00+03	26000.00
20BAD6	2017-08-09 08:35:00+03	112000.00
20BAEE	2017-07-29 07:33:00+03	46400.00
20BB68	2017-08-09 07:54:00+03	44600.00
20BB69	2017-07-07 20:21:00+03	361600.00
20BBFB	2017-07-25 17:51:00+03	12400.00
20BC5C	2017-08-03 00:57:00+03	42900.00
20BD3B	2017-07-15 10:14:00+03	59800.00
20BD89	2017-07-17 04:24:00+03	78800.00
20BDBA	2017-07-21 00:01:00+03	22600.00
20BDD9	2017-08-10 17:49:00+03	70500.00
20BDE1	2017-08-14 14:46:00+03	67700.00
20BE31	2017-07-22 17:33:00+03	94000.00
20BE67	2017-07-13 21:35:00+03	123600.00
20BE71	2017-07-28 08:43:00+03	64400.00
20BE72	2017-07-23 21:10:00+03	61800.00
20BE8C	2017-07-18 13:01:00+03	55800.00
20BE9B	2017-07-29 17:40:00+03	24700.00
20BEDB	2017-08-02 00:02:00+03	133200.00
20BEEE	2017-07-12 08:44:00+03	20200.00
20BF06	2017-07-15 07:25:00+03	23200.00
20BF30	2017-08-15 02:53:00+03	92100.00
20BF9D	2017-07-10 17:57:00+03	23200.00
20BFFF	2017-07-25 11:56:00+03	56600.00
20C043	2017-07-23 13:52:00+03	193700.00
20C077	2017-07-12 23:32:00+03	8000.00
20C092	2017-08-03 12:48:00+03	135400.00
20C10C	2017-07-01 12:28:00+03	46000.00
20C10E	2017-07-25 23:47:00+03	143600.00
20C10F	2017-07-28 07:01:00+03	136200.00
20C131	2017-07-19 16:28:00+03	173500.00
20C15D	2017-07-07 08:13:00+03	6000.00
20C1C4	2017-07-08 09:14:00+03	53600.00
20C291	2017-07-23 14:07:00+03	25400.00
20C299	2017-08-07 15:18:00+03	19600.00
20C321	2017-08-13 12:56:00+03	27800.00
20C373	2017-07-15 03:26:00+03	6300.00
20C3C0	2017-08-02 12:48:00+03	58000.00
20C41B	2017-07-09 17:28:00+03	96500.00
20C420	2017-07-13 21:53:00+03	31100.00
20C491	2017-08-04 05:19:00+03	6200.00
20C4B4	2017-06-26 05:14:00+03	246000.00
20C4C3	2017-08-10 05:27:00+03	56600.00
20C4F3	2017-08-09 21:04:00+03	92000.00
20C50F	2017-07-17 17:43:00+03	57400.00
20C534	2017-08-15 03:02:00+03	270800.00
20C575	2017-08-01 08:14:00+03	176300.00
20C5A3	2017-08-11 08:08:00+03	57500.00
20C5AB	2017-08-14 16:27:00+03	64700.00
20C5DD	2017-07-06 05:38:00+03	201800.00
20C623	2017-08-11 05:40:00+03	47000.00
20C641	2017-07-06 06:39:00+03	47200.00
20C6FF	2017-07-03 15:55:00+03	167400.00
20C773	2017-07-06 07:52:00+03	3700.00
20C7BB	2017-08-04 05:45:00+03	57300.00
20C7C9	2017-07-17 20:59:00+03	14300.00
20C7E1	2017-07-31 11:36:00+03	28200.00
20C87E	2017-07-04 08:21:00+03	36800.00
20C954	2017-07-03 04:00:00+03	22000.00
20C9E4	2017-07-09 04:12:00+03	192700.00
20CAF8	2017-06-30 01:26:00+03	28000.00
20CB79	2017-07-24 16:31:00+03	46200.00
20CBD2	2017-08-01 03:48:00+03	91200.00
20CBE6	2017-08-03 13:05:00+03	117200.00
20CC6E	2017-07-14 18:56:00+03	90400.00
20CD0B	2017-08-10 08:29:00+03	81300.00
20CD6E	2017-07-26 10:30:00+03	67600.00
20CDEC	2017-07-13 16:11:00+03	44500.00
20CE03	2017-08-04 03:53:00+03	104000.00
20CE32	2017-07-16 13:43:00+03	14800.00
20CE33	2017-07-07 04:33:00+03	221000.00
20CE54	2017-07-20 05:16:00+03	14000.00
20CE60	2017-07-10 21:20:00+03	12600.00
20CF2B	2017-08-09 09:31:00+03	24400.00
20CF44	2017-07-11 01:17:00+03	119400.00
20CF5D	2017-07-22 11:04:00+03	52000.00
20CFBA	2017-08-03 01:39:00+03	192400.00
20D004	2017-07-25 16:00:00+03	28000.00
20D00C	2017-07-20 21:12:00+03	81500.00
20D093	2017-08-04 05:49:00+03	23200.00
20D0CB	2017-07-15 23:15:00+03	59300.00
20D0F6	2017-07-25 18:37:00+03	50600.00
20D103	2017-07-28 16:01:00+03	266000.00
20D169	2017-08-08 11:29:00+03	14800.00
20D174	2017-08-06 11:40:00+03	105600.00
20D181	2017-08-10 15:17:00+03	142200.00
20D255	2017-06-29 23:40:00+03	78400.00
20D25E	2017-08-15 10:31:00+03	18000.00
20D274	2017-06-30 10:04:00+03	56000.00
20D354	2017-07-12 22:51:00+03	110300.00
20D387	2017-08-08 17:57:00+03	24400.00
20D389	2017-07-13 05:46:00+03	16400.00
20D3A8	2017-08-14 14:26:00+03	123000.00
20D3AD	2017-07-28 14:21:00+03	64700.00
20D40C	2017-07-09 10:54:00+03	41200.00
20D415	2017-08-07 21:44:00+03	177200.00
20D479	2017-07-17 08:40:00+03	39200.00
20D509	2017-08-13 07:16:00+03	39800.00
20D54D	2017-07-17 18:15:00+03	56000.00
20D55B	2017-07-30 19:55:00+03	46400.00
20D567	2017-06-28 06:00:00+03	23200.00
20D5A1	2017-06-30 19:17:00+03	26000.00
20D5E9	2017-07-27 14:18:00+03	27200.00
20D65C	2017-07-11 16:23:00+03	25200.00
20D69F	2017-07-09 15:22:00+03	66600.00
20D6B6	2017-07-23 08:26:00+03	31800.00
20D6D6	2017-07-21 01:09:00+03	22400.00
20D6DE	2017-07-21 16:08:00+03	45900.00
20D721	2017-08-12 16:04:00+03	41800.00
20D722	2017-07-08 16:08:00+03	32100.00
20D78D	2017-07-06 02:16:00+03	45300.00
20D7F3	2017-07-11 18:48:00+03	135400.00
20D81D	2017-07-06 10:36:00+03	12600.00
20D8E4	2017-07-05 08:46:00+03	94100.00
20D9BC	2017-07-28 08:23:00+03	26000.00
20DA6B	2017-07-20 17:39:00+03	46400.00
20DA83	2017-07-03 03:51:00+03	22200.00
20DB22	2017-07-10 22:59:00+03	99300.00
20DB7F	2017-07-20 10:53:00+03	80700.00
20DBAC	2017-08-01 07:06:00+03	26200.00
20DBAF	2017-08-08 20:01:00+03	85200.00
20DBCF	2017-08-15 15:07:00+03	36200.00
20DBE4	2017-07-15 19:31:00+03	89600.00
20DCA1	2017-08-01 20:22:00+03	90700.00
20DCE0	2017-08-05 22:26:00+03	43900.00
20DDB6	2017-07-28 23:06:00+03	12600.00
20DE10	2017-08-10 11:03:00+03	67000.00
20DE3B	2017-07-12 17:36:00+03	73500.00
20DE8E	2017-07-01 06:19:00+03	66600.00
20DEE2	2017-07-04 12:14:00+03	67600.00
20DF54	2017-07-08 03:53:00+03	25100.00
20DF60	2017-07-13 22:43:00+03	9200.00
20DF65	2017-07-11 01:17:00+03	27900.00
20DF69	2017-07-17 14:21:00+03	95900.00
20DF94	2017-08-15 01:17:00+03	25200.00
20DFC5	2017-07-18 15:54:00+03	170100.00
20DFE6	2017-08-06 11:31:00+03	112000.00
20E04B	2017-08-15 13:40:00+03	75300.00
20E05C	2017-07-18 16:24:00+03	266500.00
20E073	2017-07-04 10:05:00+03	12600.00
20E0C2	2017-08-07 22:20:00+03	399600.00
20E18B	2017-07-09 02:42:00+03	11600.00
20E1BB	2017-07-03 22:21:00+03	28800.00
20E243	2017-07-21 12:04:00+03	62600.00
20E2DC	2017-07-27 02:27:00+03	260300.00
20E2FE	2017-07-31 15:18:00+03	13600.00
20E333	2017-08-01 12:01:00+03	46800.00
20E367	2017-07-27 20:18:00+03	116100.00
20E370	2017-08-15 06:04:00+03	23200.00
20E3A5	2017-07-02 18:25:00+03	68300.00
20E45D	2017-07-11 11:08:00+03	32800.00
20E4D5	2017-07-31 05:21:00+03	25600.00
20E57C	2017-07-19 06:15:00+03	56000.00
20E5C4	2017-07-07 22:09:00+03	67300.00
20E5EC	2017-07-15 10:20:00+03	28000.00
20E613	2017-08-08 21:48:00+03	265600.00
20E615	2017-08-09 17:01:00+03	22000.00
20E659	2017-07-16 20:06:00+03	155600.00
20E6BE	2017-07-04 13:33:00+03	71900.00
20E6E7	2017-08-09 09:11:00+03	58600.00
20E710	2017-07-16 01:14:00+03	89700.00
20E77E	2017-07-22 20:00:00+03	85700.00
20E78D	2017-08-02 18:14:00+03	37900.00
20E7B8	2017-08-13 05:29:00+03	113700.00
20E7BA	2017-06-30 03:35:00+03	87300.00
20E7F0	2017-07-13 14:31:00+03	27200.00
20E879	2017-07-14 20:27:00+03	75300.00
20E963	2017-07-15 15:53:00+03	12100.00
20E967	2017-08-03 02:10:00+03	66100.00
20E9B0	2017-08-01 16:37:00+03	28800.00
20E9C3	2017-07-10 20:48:00+03	29400.00
20EA0E	2017-07-01 22:11:00+03	406700.00
20EA3A	2017-08-14 08:19:00+03	43000.00
20EA80	2017-08-01 20:54:00+03	28000.00
20EB0A	2017-08-12 10:29:00+03	108700.00
20EB14	2017-08-15 13:35:00+03	59800.00
20EC0E	2017-07-02 00:43:00+03	23600.00
20EC34	2017-07-02 18:04:00+03	99500.00
20EC74	2017-08-13 07:41:00+03	284300.00
20EC8E	2017-07-18 01:24:00+03	51600.00
20EC99	2017-07-04 02:26:00+03	135400.00
20ECE0	2017-07-09 09:02:00+03	31400.00
20ED3F	2017-07-11 17:49:00+03	117600.00
20ED68	2017-08-06 15:02:00+03	67200.00
20ED7A	2017-08-14 19:48:00+03	13400.00
20EDCF	2017-07-07 23:43:00+03	69500.00
20EDD6	2017-07-12 12:52:00+03	59400.00
20EDDB	2017-07-06 03:53:00+03	39400.00
20EE69	2017-08-04 23:05:00+03	58900.00
20EE6A	2017-08-08 16:49:00+03	8200.00
20EEA9	2017-07-29 21:19:00+03	26000.00
20EEAE	2017-07-09 22:56:00+03	50800.00
20EEE4	2017-07-24 19:51:00+03	131900.00
20EF18	2017-07-09 03:03:00+03	23600.00
20EFEE	2017-08-11 03:47:00+03	13400.00
20F027	2017-07-22 07:45:00+03	36200.00
20F0AE	2017-08-04 16:55:00+03	271400.00
20F0C5	2017-08-14 17:35:00+03	61500.00
20F10C	2017-07-08 08:30:00+03	75600.00
20F171	2017-07-30 02:01:00+03	87200.00
20F1AD	2017-07-20 05:36:00+03	124300.00
20F1CC	2017-07-15 01:11:00+03	136800.00
20F1E1	2017-07-31 23:18:00+03	45100.00
20F1F4	2017-07-11 01:21:00+03	131600.00
20F1FF	2017-08-01 23:16:00+03	43900.00
20F22D	2017-07-20 08:59:00+03	68900.00
20F238	2017-07-15 22:41:00+03	11600.00
20F239	2017-07-25 08:59:00+03	202600.00
20F269	2017-08-11 05:57:00+03	258400.00
20F2E8	2017-08-08 09:05:00+03	54600.00
20F2F5	2017-07-30 17:41:00+03	28000.00
20F30D	2017-08-09 02:43:00+03	46300.00
20F36B	2017-07-23 09:23:00+03	23400.00
20F396	2017-07-14 01:45:00+03	56000.00
20F39B	2017-07-04 01:50:00+03	73900.00
20F3BA	2017-07-18 10:59:00+03	30400.00
20F3CA	2017-07-17 01:24:00+03	84100.00
20F423	2017-08-05 16:48:00+03	47400.00
20F48D	2017-07-28 16:30:00+03	27600.00
20F4A8	2017-08-01 23:03:00+03	22200.00
20F4D2	2017-07-16 08:36:00+03	38800.00
20F545	2017-07-14 18:51:00+03	21400.00
20F5E0	2017-08-11 10:44:00+03	202400.00
20F63A	2017-07-13 10:08:00+03	17200.00
20F6C4	2017-08-04 16:46:00+03	23900.00
20F6E1	2017-07-14 15:39:00+03	56000.00
20F734	2017-07-12 19:59:00+03	81000.00
20F784	2017-08-09 13:42:00+03	32700.00
20F7C3	2017-07-15 22:21:00+03	13200.00
20F7CA	2017-07-29 06:23:00+03	29400.00
20F7FC	2017-07-13 20:34:00+03	191200.00
20F840	2017-08-11 17:59:00+03	51600.00
20F895	2017-08-06 06:13:00+03	266400.00
20F8C3	2017-07-13 18:08:00+03	279800.00
20F95B	2017-07-25 09:46:00+03	369000.00
20F9CA	2017-07-18 16:47:00+03	21800.00
20FA0E	2017-07-24 16:44:00+03	37600.00
20FAF1	2017-08-03 20:53:00+03	403600.00
20FAFD	2017-08-05 08:20:00+03	86300.00
20FB6F	2017-07-07 08:19:00+03	246000.00
20FBF5	2017-08-15 09:34:00+03	69600.00
20FC3B	2017-08-07 13:06:00+03	52500.00
20FC41	2017-07-10 09:58:00+03	58000.00
20FD6D	2017-06-27 14:14:00+03	15400.00
20FDEA	2017-06-28 20:20:00+03	170700.00
20FE1A	2017-07-31 18:34:00+03	56900.00
20FEEE	2017-07-22 03:43:00+03	29400.00
20FF6F	2017-08-10 20:24:00+03	11600.00
20FF75	2017-07-06 15:45:00+03	79000.00
20FF81	2017-07-22 11:29:00+03	28800.00
20FFEC	2017-06-29 17:20:00+03	28000.00
210076	2017-07-30 13:50:00+03	57700.00
2100B0	2017-08-03 09:37:00+03	53600.00
2100C0	2017-07-04 04:40:00+03	46000.00
2100E4	2017-07-16 05:10:00+03	114400.00
2100F4	2017-07-17 20:55:00+03	136800.00
210131	2017-08-03 23:33:00+03	135400.00
2101A3	2017-07-07 02:43:00+03	25100.00
2101DF	2017-08-15 04:28:00+03	56000.00
21021B	2017-08-03 09:58:00+03	56000.00
21021F	2017-08-13 19:48:00+03	92600.00
210221	2017-08-12 16:13:00+03	100000.00
210222	2017-07-03 22:11:00+03	3400.00
210238	2017-08-03 06:07:00+03	38400.00
210244	2017-08-14 09:44:00+03	82900.00
210258	2017-07-05 21:10:00+03	56000.00
210275	2017-08-15 13:10:00+03	20900.00
2102B2	2017-07-08 08:16:00+03	31400.00
2102B4	2017-07-05 10:56:00+03	42700.00
2102CA	2017-07-14 21:17:00+03	6700.00
210346	2017-07-03 01:01:00+03	21200.00
2103B6	2017-08-07 17:26:00+03	19600.00
2103C1	2017-07-17 13:02:00+03	53300.00
210432	2017-07-26 02:14:00+03	136800.00
2104A6	2017-08-03 21:36:00+03	44000.00
2104EE	2017-07-06 08:24:00+03	49600.00
2104F5	2017-07-04 22:55:00+03	26800.00
210541	2017-07-27 09:47:00+03	294000.00
21057C	2017-07-08 12:39:00+03	20100.00
21059A	2017-07-10 18:50:00+03	95000.00
2105B3	2017-07-01 16:30:00+03	101700.00
2105E6	2017-07-03 11:43:00+03	56000.00
210638	2017-08-14 19:41:00+03	125400.00
2106EC	2017-07-19 07:32:00+03	58000.00
210741	2017-07-09 10:00:00+03	25400.00
21076A	2017-08-10 20:55:00+03	54400.00
210804	2017-07-14 11:19:00+03	27200.00
21080D	2017-07-17 10:36:00+03	38200.00
210813	2017-07-08 03:19:00+03	74200.00
210875	2017-07-19 17:18:00+03	6600.00
210878	2017-08-10 07:30:00+03	8000.00
210889	2017-07-17 18:18:00+03	134400.00
210890	2017-07-14 22:40:00+03	36200.00
2108CA	2017-07-22 02:45:00+03	166000.00
210972	2017-08-04 20:15:00+03	64800.00
210974	2017-08-02 15:24:00+03	414700.00
210980	2017-07-28 00:37:00+03	28600.00
210A4D	2017-07-09 04:07:00+03	6000.00
210A54	2017-07-26 21:34:00+03	26000.00
210A70	2017-07-28 04:00:00+03	36900.00
210AF2	2017-07-26 15:18:00+03	41600.00
210B66	2017-07-26 21:41:00+03	36200.00
210B7B	2017-08-11 08:35:00+03	56000.00
210BA3	2017-07-12 06:49:00+03	89100.00
210BB8	2017-07-19 07:48:00+03	21400.00
210BFF	2017-07-28 03:42:00+03	28800.00
210C1E	2017-08-13 09:23:00+03	15000.00
210C5C	2017-08-10 18:58:00+03	272300.00
210C83	2017-07-17 05:34:00+03	25700.00
210CB2	2017-07-14 22:33:00+03	85000.00
210CB4	2017-07-14 02:03:00+03	14400.00
210CB6	2017-07-04 09:37:00+03	55800.00
210D54	2017-07-18 15:53:00+03	10800.00
210DEB	2017-07-13 15:15:00+03	116500.00
210E5E	2017-08-04 05:36:00+03	8000.00
210E8F	2017-08-12 19:09:00+03	47000.00
210E97	2017-07-30 17:00:00+03	31400.00
210F04	2017-07-10 11:52:00+03	68100.00
210FCE	2017-07-16 14:36:00+03	281500.00
210FF7	2017-07-10 18:02:00+03	69900.00
211016	2017-07-10 07:23:00+03	26800.00
21101F	2017-08-13 13:35:00+03	14000.00
21102C	2017-07-11 12:35:00+03	93900.00
21103C	2017-07-15 09:53:00+03	16400.00
2110C2	2017-07-19 08:29:00+03	67600.00
211104	2017-07-27 13:34:00+03	21400.00
211138	2017-06-30 02:43:00+03	23200.00
21114F	2017-08-11 12:28:00+03	593300.00
211168	2017-08-09 12:43:00+03	26000.00
2111BB	2017-07-10 07:05:00+03	46700.00
2111BE	2017-08-07 10:52:00+03	112600.00
211219	2017-08-14 17:38:00+03	67100.00
21127F	2017-07-13 00:29:00+03	139400.00
211291	2017-07-08 14:27:00+03	53700.00
211301	2017-07-10 14:59:00+03	180200.00
211367	2017-07-17 00:02:00+03	15000.00
2113F6	2017-07-06 10:09:00+03	226400.00
211421	2017-07-20 01:59:00+03	129200.00
211433	2017-07-15 00:14:00+03	58800.00
21144F	2017-07-21 19:27:00+03	59000.00
2114B8	2017-07-18 04:42:00+03	133100.00
21159D	2017-07-19 06:54:00+03	25800.00
2115DC	2017-08-04 17:21:00+03	11600.00
211612	2017-08-05 11:43:00+03	181100.00
211662	2017-07-29 06:09:00+03	22000.00
2116DE	2017-07-13 10:49:00+03	185000.00
211703	2017-08-15 17:44:00+03	443000.00
211720	2017-08-14 15:40:00+03	37200.00
211796	2017-08-06 03:38:00+03	393000.00
2117FF	2017-08-08 19:03:00+03	146300.00
211817	2017-07-03 20:46:00+03	32800.00
21181B	2017-08-14 03:14:00+03	77900.00
211847	2017-07-24 13:16:00+03	125200.00
211874	2017-08-01 22:35:00+03	184300.00
2118F3	2017-07-05 09:52:00+03	47100.00
211945	2017-07-10 00:22:00+03	75300.00
211985	2017-08-08 00:18:00+03	492700.00
2119ED	2017-07-05 09:16:00+03	21400.00
2119F7	2017-07-03 00:49:00+03	155600.00
211AF2	2017-08-11 12:50:00+03	140100.00
211B07	2017-07-18 05:17:00+03	125000.00
211B0A	2017-08-01 19:40:00+03	28000.00
211B18	2017-08-11 13:48:00+03	6000.00
211B26	2017-08-10 11:18:00+03	12600.00
211B82	2017-07-15 23:43:00+03	92800.00
211B9A	2017-07-19 02:03:00+03	28000.00
211BC7	2017-08-14 21:53:00+03	92000.00
211BC9	2017-07-02 18:00:00+03	52100.00
211BEE	2017-08-12 12:54:00+03	138000.00
211C27	2017-07-01 19:30:00+03	63200.00
211C2E	2017-07-17 09:09:00+03	93900.00
211C9D	2017-08-12 02:35:00+03	25100.00
211CA7	2017-07-29 07:42:00+03	14400.00
211CBA	2017-08-04 08:22:00+03	81700.00
211D34	2017-08-13 16:32:00+03	21200.00
211D66	2017-06-30 02:14:00+03	81900.00
211E21	2017-07-16 05:46:00+03	92800.00
211E53	2017-07-19 15:54:00+03	78100.00
211EA6	2017-07-15 23:16:00+03	37700.00
211EC8	2017-08-04 22:36:00+03	39500.00
211EF0	2017-07-25 13:57:00+03	6700.00
211F1A	2017-08-11 18:39:00+03	159800.00
211F30	2017-07-15 08:56:00+03	123000.00
211F49	2017-08-09 06:42:00+03	155600.00
211FA6	2017-07-11 16:47:00+03	21400.00
211FC6	2017-08-10 19:26:00+03	31900.00
212002	2017-07-09 10:01:00+03	45600.00
212056	2017-07-14 13:23:00+03	16400.00
21209E	2017-07-06 13:55:00+03	20000.00
2120D4	2017-07-18 06:09:00+03	31900.00
21210B	2017-08-13 14:44:00+03	6700.00
212116	2017-07-04 23:43:00+03	58100.00
212131	2017-07-13 04:50:00+03	169900.00
212149	2017-07-21 11:04:00+03	35300.00
212157	2017-07-09 06:51:00+03	763400.00
212213	2017-08-04 04:00:00+03	49900.00
212219	2017-07-20 07:54:00+03	137100.00
2122C8	2017-08-06 09:54:00+03	11200.00
2122D9	2017-07-21 22:33:00+03	46500.00
2122FE	2017-07-10 20:22:00+03	92700.00
212308	2017-08-02 02:39:00+03	53600.00
21238F	2017-07-18 05:11:00+03	66600.00
2123BC	2017-07-20 00:36:00+03	84100.00
2123CC	2017-07-09 12:16:00+03	136800.00
212402	2017-08-14 16:02:00+03	39100.00
212455	2017-07-29 16:51:00+03	149100.00
21245D	2017-08-10 10:56:00+03	101200.00
212473	2017-07-15 04:55:00+03	139400.00
212481	2017-08-09 07:09:00+03	37700.00
212547	2017-08-14 21:10:00+03	119500.00
212559	2017-07-15 17:22:00+03	56000.00
21256C	2017-07-06 22:00:00+03	57800.00
212586	2017-08-14 08:06:00+03	52000.00
212591	2017-08-15 03:11:00+03	51600.00
2125C6	2017-07-30 10:56:00+03	26700.00
2125E5	2017-08-11 00:12:00+03	139200.00
2125E9	2017-07-17 03:38:00+03	26000.00
212627	2017-08-08 05:31:00+03	28000.00
212638	2017-07-28 16:01:00+03	45400.00
2126EE	2017-08-08 06:37:00+03	129700.00
212703	2017-07-13 13:47:00+03	55100.00
212731	2017-07-25 05:28:00+03	75600.00
2127C0	2017-07-25 10:37:00+03	42100.00
21280E	2017-07-12 21:56:00+03	53300.00
212846	2017-07-20 08:48:00+03	133200.00
21284B	2017-08-08 18:58:00+03	233800.00
21287B	2017-07-01 01:42:00+03	46400.00
21288C	2017-07-16 17:14:00+03	6000.00
2128DD	2017-08-01 15:30:00+03	69000.00
21294E	2017-07-20 22:04:00+03	246000.00
21295C	2017-07-25 19:53:00+03	85000.00
2129BD	2017-08-01 06:31:00+03	12600.00
212A8C	2017-07-14 17:57:00+03	38500.00
212AA3	2017-07-30 06:11:00+03	65900.00
212AAB	2017-07-07 21:30:00+03	24400.00
212AF9	2017-07-21 21:41:00+03	229900.00
212B27	2017-08-14 16:41:00+03	27200.00
212B2F	2017-07-08 10:35:00+03	99200.00
212B4D	2017-07-07 05:13:00+03	70600.00
212B64	2017-08-04 22:29:00+03	102700.00
212B66	2017-07-30 03:35:00+03	58600.00
212B68	2017-07-25 19:03:00+03	57800.00
212BAE	2017-08-05 01:38:00+03	25600.00
212BB7	2017-08-05 07:38:00+03	24400.00
212C06	2017-06-29 16:54:00+03	32800.00
212C0F	2017-08-15 17:11:00+03	46000.00
212C51	2017-07-24 14:51:00+03	46700.00
212CDC	2017-07-26 02:23:00+03	179300.00
212CEB	2017-08-14 08:53:00+03	12600.00
212D66	2017-07-02 13:27:00+03	68100.00
212DE7	2017-07-20 21:01:00+03	12600.00
212E1E	2017-07-24 15:38:00+03	44600.00
212E7D	2017-07-25 02:16:00+03	38600.00
212E9E	2017-06-29 00:48:00+03	61800.00
212EC9	2017-08-13 04:19:00+03	18400.00
212F74	2017-08-07 17:27:00+03	103200.00
212FF1	2017-07-07 23:04:00+03	6700.00
213029	2017-08-11 22:16:00+03	80100.00
21307B	2017-08-01 18:57:00+03	61800.00
2130A4	2017-08-11 16:36:00+03	54000.00
2130B0	2017-07-06 09:02:00+03	31000.00
2130D2	2017-08-05 10:04:00+03	112000.00
21310C	2017-07-11 01:17:00+03	6300.00
21310D	2017-08-08 00:01:00+03	23900.00
213111	2017-08-03 19:38:00+03	212500.00
213118	2017-07-01 00:20:00+03	47800.00
213131	2017-07-08 08:10:00+03	43900.00
213181	2017-07-31 15:35:00+03	26000.00
213197	2017-07-10 05:41:00+03	173200.00
2131AF	2017-07-22 22:36:00+03	47200.00
2131DE	2017-07-06 22:26:00+03	124200.00
21325D	2017-07-07 04:29:00+03	59800.00
213292	2017-07-06 10:09:00+03	23100.00
2132AF	2017-07-16 23:17:00+03	112600.00
2132D3	2017-08-01 11:11:00+03	40000.00
2132E7	2017-07-21 04:24:00+03	190400.00
2132EF	2017-07-23 07:48:00+03	26000.00
213341	2017-07-03 03:18:00+03	20200.00
21336E	2017-07-30 00:12:00+03	37900.00
213377	2017-07-05 18:32:00+03	80900.00
21338A	2017-07-29 06:16:00+03	79600.00
213395	2017-07-02 23:48:00+03	34800.00
2133F8	2017-07-16 04:06:00+03	101500.00
213425	2017-07-11 21:15:00+03	8200.00
213478	2017-07-13 22:07:00+03	84400.00
2134EC	2017-07-23 22:38:00+03	46200.00
2134FB	2017-08-14 13:40:00+03	58900.00
2134FE	2017-08-03 01:47:00+03	81600.00
213507	2017-07-21 10:49:00+03	28900.00
21353C	2017-08-14 20:09:00+03	46400.00
213548	2017-07-19 17:04:00+03	46000.00
2135BE	2017-08-05 06:11:00+03	190400.00
2135D4	2017-08-10 18:07:00+03	284700.00
2135DD	2017-07-06 05:11:00+03	135600.00
2135EA	2017-07-06 14:11:00+03	81500.00
2135F7	2017-06-26 03:21:00+03	26800.00
21367B	2017-08-05 21:50:00+03	35300.00
21367C	2017-07-17 10:27:00+03	115400.00
2136C4	2017-07-25 06:28:00+03	13800.00
21372C	2017-07-10 17:01:00+03	26800.00
2137E9	2017-07-21 15:44:00+03	24400.00
21381D	2017-07-03 17:45:00+03	372500.00
213840	2017-08-03 11:51:00+03	55600.00
2138AE	2017-07-18 11:04:00+03	117600.00
2138C5	2017-08-03 03:04:00+03	58200.00
213907	2017-07-06 07:07:00+03	37200.00
21394C	2017-08-15 12:28:00+03	50000.00
213977	2017-07-12 08:41:00+03	106500.00
2139B2	2017-07-25 22:20:00+03	32900.00
2139DE	2017-07-15 06:17:00+03	14800.00
213A01	2017-07-22 13:11:00+03	42800.00
213A0D	2017-07-13 03:16:00+03	28800.00
213A66	2017-07-14 07:58:00+03	38200.00
213A89	2017-07-22 01:11:00+03	128600.00
213AC7	2017-07-08 08:27:00+03	135400.00
213AEC	2017-07-22 11:03:00+03	168000.00
213B0C	2017-08-12 08:23:00+03	40700.00
213B51	2017-08-08 04:06:00+03	14000.00
213B93	2017-08-02 08:32:00+03	29600.00
213BC1	2017-08-09 12:15:00+03	38600.00
213BD4	2017-07-24 22:05:00+03	14000.00
213BE0	2017-07-28 20:43:00+03	47400.00
213C1E	2017-07-23 23:34:00+03	32200.00
213C53	2017-07-31 21:36:00+03	68400.00
213CC7	2017-07-22 01:40:00+03	21000.00
213CE4	2017-08-02 02:09:00+03	160700.00
213D60	2017-07-11 12:54:00+03	42700.00
213E22	2017-07-12 00:03:00+03	36600.00
213E37	2017-07-05 09:31:00+03	266400.00
213E69	2017-07-06 23:50:00+03	38800.00
213ED3	2017-08-11 01:16:00+03	28800.00
213EF2	2017-07-21 11:26:00+03	70700.00
213F99	2017-07-24 14:47:00+03	8000.00
213FD1	2017-08-13 10:11:00+03	135600.00
213FF7	2017-07-06 01:59:00+03	36800.00
214011	2017-07-26 08:18:00+03	10600.00
214047	2017-08-02 20:01:00+03	74300.00
214066	2017-08-07 02:54:00+03	86800.00
21406F	2017-07-15 23:13:00+03	24200.00
214076	2017-07-16 01:42:00+03	46400.00
21407B	2017-07-19 13:25:00+03	7400.00
2140CA	2017-07-28 00:08:00+03	124200.00
2140D8	2017-08-13 04:36:00+03	66400.00
214159	2017-07-17 21:26:00+03	30100.00
214190	2017-07-12 02:02:00+03	28600.00
2141A7	2017-07-12 02:24:00+03	43800.00
2141FF	2017-07-09 11:58:00+03	84500.00
214201	2017-07-10 09:04:00+03	81700.00
21423C	2017-07-12 13:04:00+03	36200.00
21428F	2017-07-15 13:39:00+03	133200.00
214296	2017-08-12 20:09:00+03	56000.00
214298	2017-07-19 10:51:00+03	38600.00
2142C9	2017-07-29 14:32:00+03	91200.00
2142DF	2017-07-26 01:46:00+03	260300.00
2142F5	2017-07-04 10:04:00+03	59300.00
2143F7	2017-08-11 22:39:00+03	25600.00
214415	2017-07-04 04:42:00+03	20000.00
21442F	2017-08-12 12:28:00+03	257900.00
21444B	2017-07-18 04:04:00+03	71100.00
214456	2017-07-13 23:12:00+03	67600.00
2144A0	2017-07-12 10:03:00+03	70800.00
2144BB	2017-08-09 18:32:00+03	39200.00
2144BE	2017-07-07 21:08:00+03	135000.00
2144DE	2017-07-18 08:43:00+03	16400.00
214521	2017-07-14 03:55:00+03	415000.00
214526	2017-07-12 04:43:00+03	27200.00
214583	2017-06-29 22:25:00+03	69100.00
214588	2017-06-30 03:38:00+03	114800.00
21459E	2017-07-20 09:48:00+03	281500.00
214660	2017-07-03 14:14:00+03	66500.00
214661	2017-07-27 09:33:00+03	100000.00
214665	2017-07-05 15:42:00+03	173200.00
214671	2017-08-01 23:59:00+03	13700.00
2146FC	2017-07-16 17:56:00+03	18600.00
21472C	2017-08-03 01:08:00+03	78300.00
21472F	2017-08-02 00:41:00+03	91200.00
214738	2017-08-11 15:41:00+03	113800.00
21473C	2017-07-17 18:23:00+03	29200.00
214773	2017-07-21 02:50:00+03	47100.00
214776	2017-07-08 07:36:00+03	20200.00
21477D	2017-07-06 11:25:00+03	34100.00
21477F	2017-06-28 19:07:00+03	55800.00
2147ED	2017-07-29 23:52:00+03	21600.00
214867	2017-08-12 17:10:00+03	585700.00
21493E	2017-07-22 07:05:00+03	53700.00
21497A	2017-07-22 22:52:00+03	32200.00
2149B9	2017-08-06 12:02:00+03	19600.00
2149F7	2017-07-01 16:49:00+03	27800.00
214A10	2017-07-08 03:22:00+03	182700.00
214A57	2017-08-09 07:10:00+03	26000.00
214A5B	2017-08-06 08:40:00+03	28800.00
214AC2	2017-08-04 02:46:00+03	48300.00
214B11	2017-08-15 13:58:00+03	20500.00
214B41	2017-07-14 02:03:00+03	8200.00
214B64	2017-07-21 20:28:00+03	25600.00
214B8E	2017-08-15 00:10:00+03	39900.00
214BD8	2017-07-10 03:05:00+03	25600.00
214BF1	2017-08-03 21:08:00+03	286100.00
214CA2	2017-08-04 08:45:00+03	26700.00
214CB0	2017-07-07 23:47:00+03	39500.00
214D0B	2017-07-02 07:42:00+03	69500.00
214D1A	2017-07-16 16:10:00+03	31000.00
214D37	2017-07-27 22:06:00+03	81900.00
214DA6	2017-07-15 13:53:00+03	26000.00
214DF2	2017-08-14 18:25:00+03	26000.00
214E97	2017-07-03 08:21:00+03	95200.00
214E9F	2017-08-04 19:40:00+03	285000.00
214F9E	2017-08-12 21:25:00+03	58800.00
214FA9	2017-07-04 05:14:00+03	35600.00
214FC9	2017-07-05 20:24:00+03	136500.00
214FD2	2017-07-22 04:30:00+03	33100.00
214FDB	2017-08-12 08:20:00+03	61800.00
215048	2017-07-04 12:04:00+03	8400.00
21507E	2017-07-27 10:03:00+03	14000.00
215080	2017-07-19 06:58:00+03	47500.00
2150D5	2017-07-20 17:33:00+03	51800.00
21513A	2017-07-15 05:53:00+03	23600.00
215146	2017-08-04 09:59:00+03	25900.00
215171	2017-08-15 17:28:00+03	46400.00
215173	2017-07-08 22:33:00+03	80000.00
215189	2017-07-31 12:53:00+03	213200.00
2151A1	2017-08-12 23:17:00+03	111600.00
2151CF	2017-08-14 13:24:00+03	249100.00
215210	2017-08-02 02:12:00+03	91200.00
215234	2017-08-07 06:20:00+03	22000.00
21524A	2017-08-03 16:01:00+03	21200.00
2152B1	2017-07-18 22:26:00+03	42400.00
215300	2017-07-13 11:33:00+03	87400.00
215327	2017-08-14 17:25:00+03	89800.00
215364	2017-07-12 22:01:00+03	96900.00
21537C	2017-08-08 08:40:00+03	20600.00
215391	2017-07-22 02:08:00+03	124200.00
2153B2	2017-07-31 07:13:00+03	46400.00
2153EF	2017-07-27 16:22:00+03	75300.00
2153FA	2017-08-12 22:09:00+03	48800.00
21540B	2017-07-21 07:37:00+03	23600.00
21542D	2017-07-12 21:14:00+03	280600.00
21542E	2017-06-29 05:20:00+03	58500.00
215458	2017-07-13 03:42:00+03	58200.00
215490	2017-08-04 00:19:00+03	96800.00
2154B0	2017-07-20 13:38:00+03	58200.00
2154B6	2017-08-11 04:24:00+03	13400.00
2154B9	2017-07-23 02:53:00+03	82900.00
215545	2017-08-02 13:52:00+03	123000.00
2155E8	2017-07-22 00:42:00+03	131100.00
21560D	2017-08-14 13:31:00+03	71900.00
21562C	2017-08-03 14:45:00+03	264000.00
215655	2017-07-18 05:41:00+03	130400.00
21565E	2017-08-02 18:18:00+03	65900.00
21566D	2017-07-04 18:26:00+03	134600.00
21568D	2017-07-26 12:06:00+03	123000.00
21569A	2017-07-08 12:30:00+03	59200.00
215715	2017-08-14 13:16:00+03	111600.00
21572E	2017-08-09 14:09:00+03	6700.00
215763	2017-07-22 16:14:00+03	71900.00
2157C4	2017-07-16 20:35:00+03	40300.00
215827	2017-07-02 14:05:00+03	168000.00
215855	2017-07-30 05:15:00+03	70800.00
2158A6	2017-07-14 18:25:00+03	21800.00
2158D0	2017-08-06 22:32:00+03	69500.00
2158D8	2017-06-27 12:41:00+03	246000.00
2158F7	2017-07-26 09:41:00+03	233800.00
21590F	2017-08-04 15:16:00+03	66600.00
215988	2017-07-19 13:56:00+03	39300.00
21599F	2017-07-29 07:35:00+03	22600.00
2159AA	2017-07-19 14:01:00+03	127300.00
2159B7	2017-07-25 23:54:00+03	58000.00
215A79	2017-08-14 03:53:00+03	86800.00
215AA6	2017-07-24 05:39:00+03	29200.00
215B18	2017-07-09 06:20:00+03	19600.00
215B2E	2017-08-11 11:33:00+03	8000.00
215B8D	2017-07-03 20:15:00+03	47200.00
215B9F	2017-07-09 07:00:00+03	20400.00
215BA2	2017-06-29 19:43:00+03	64600.00
215BE1	2017-08-07 12:51:00+03	89600.00
215C0D	2017-07-11 09:10:00+03	15400.00
215C7D	2017-07-25 03:27:00+03	6300.00
215C98	2017-07-22 04:16:00+03	73400.00
215CC9	2017-08-07 00:52:00+03	54400.00
215D05	2017-07-23 18:49:00+03	111600.00
215D5F	2017-08-02 22:06:00+03	97400.00
215D65	2017-07-20 21:25:00+03	92100.00
215DFA	2017-07-04 06:58:00+03	102100.00
215DFD	2017-08-10 00:50:00+03	46300.00
215E46	2017-07-18 01:29:00+03	31000.00
215E6D	2017-07-18 18:36:00+03	26000.00
215F5A	2017-07-10 23:44:00+03	86400.00
215F91	2017-07-19 02:25:00+03	14400.00
215FDB	2017-07-14 04:25:00+03	47200.00
216004	2017-07-13 15:06:00+03	47000.00
216045	2017-07-31 00:51:00+03	38800.00
216056	2017-08-06 15:51:00+03	19300.00
21606A	2017-08-02 19:34:00+03	398500.00
21609C	2017-07-26 01:32:00+03	15900.00
2160C5	2017-08-09 15:39:00+03	28800.00
2160D8	2017-07-22 19:41:00+03	40800.00
2160FF	2017-07-13 20:53:00+03	67600.00
21612C	2017-07-11 02:56:00+03	375000.00
216132	2017-07-29 21:19:00+03	58000.00
216163	2017-08-05 18:05:00+03	442800.00
21616A	2017-07-09 04:15:00+03	115800.00
216180	2017-07-08 02:25:00+03	14800.00
2161AF	2017-07-25 15:27:00+03	79600.00
2161D7	2017-07-09 06:23:00+03	58400.00
21629D	2017-07-24 00:37:00+03	21400.00
2162A9	2017-08-08 00:25:00+03	198300.00
2162D4	2017-07-10 14:16:00+03	45200.00
21633E	2017-07-15 14:17:00+03	62700.00
216373	2017-07-05 09:45:00+03	75300.00
21637C	2017-07-07 17:43:00+03	13200.00
216383	2017-07-03 06:48:00+03	47100.00
216385	2017-07-15 04:22:00+03	14000.00
2163E8	2017-07-16 20:57:00+03	67700.00
216435	2017-06-30 23:31:00+03	44700.00
216436	2017-07-30 00:31:00+03	167400.00
216485	2017-06-30 15:07:00+03	56600.00
2164AA	2017-08-10 18:14:00+03	269600.00
2164B2	2017-07-10 08:54:00+03	15800.00
2164DA	2017-08-02 12:53:00+03	56000.00
2164E3	2017-07-10 22:42:00+03	88900.00
216502	2017-07-25 02:40:00+03	16400.00
216528	2017-07-16 19:21:00+03	70100.00
21659B	2017-08-14 16:12:00+03	24400.00
21659C	2017-07-25 15:20:00+03	28000.00
2165CE	2017-07-10 05:32:00+03	25400.00
21660B	2017-07-23 05:21:00+03	35700.00
2166A0	2017-06-28 03:29:00+03	28800.00
2166BE	2017-07-26 15:14:00+03	155600.00
21672E	2017-07-25 01:33:00+03	24400.00
21677C	2017-07-15 13:34:00+03	52000.00
2167BE	2017-07-01 03:41:00+03	76600.00
216856	2017-08-08 16:29:00+03	68100.00
216898	2017-07-17 13:43:00+03	32600.00
2169D0	2017-07-17 17:22:00+03	42800.00
216A0E	2017-07-16 11:53:00+03	43900.00
216A34	2017-08-14 00:27:00+03	118000.00
216AE9	2017-07-10 15:19:00+03	89600.00
216C10	2017-07-11 23:03:00+03	56600.00
216CAB	2017-08-01 05:41:00+03	114500.00
216D06	2017-07-07 02:27:00+03	65500.00
216D11	2017-08-07 13:22:00+03	56200.00
216D17	2017-08-04 15:20:00+03	12000.00
216D23	2017-07-03 13:07:00+03	23200.00
216D28	2017-08-01 20:13:00+03	52000.00
216D73	2017-07-11 22:22:00+03	67600.00
216D8A	2017-08-05 03:13:00+03	40800.00
216DA7	2017-07-10 02:49:00+03	6200.00
216DBD	2017-08-03 15:13:00+03	398400.00
216DF1	2017-07-27 14:43:00+03	47600.00
216E1B	2017-08-05 08:59:00+03	37200.00
216E49	2017-07-25 02:59:00+03	95200.00
216E5F	2017-07-31 23:11:00+03	3400.00
216E88	2017-08-12 07:12:00+03	15400.00
216FA6	2017-07-10 07:58:00+03	50000.00
216FD1	2017-07-27 14:04:00+03	201200.00
216FF9	2017-07-03 08:01:00+03	67600.00
217036	2017-07-11 12:59:00+03	226200.00
217059	2017-07-30 19:58:00+03	57400.00
21706A	2017-08-08 07:11:00+03	56600.00
2170FB	2017-07-09 04:32:00+03	48500.00
217125	2017-07-30 11:37:00+03	23200.00
217130	2017-07-19 13:25:00+03	169900.00
217137	2017-07-26 02:40:00+03	58400.00
21718A	2017-08-11 08:50:00+03	46200.00
2171E6	2017-07-12 04:43:00+03	54800.00
21727F	2017-07-30 08:54:00+03	103800.00
217328	2017-07-30 02:01:00+03	49300.00
217329	2017-07-01 00:30:00+03	38600.00
21732D	2017-08-14 23:13:00+03	197600.00
217378	2017-07-19 16:47:00+03	14000.00
21737D	2017-07-18 11:11:00+03	235900.00
217442	2017-08-05 13:21:00+03	10800.00
2174B8	2017-08-03 19:10:00+03	92600.00
217509	2017-08-07 22:15:00+03	69500.00
217512	2017-07-16 10:19:00+03	31400.00
2175AF	2017-08-03 08:48:00+03	28800.00
217603	2017-07-24 05:27:00+03	14800.00
217634	2017-08-15 08:23:00+03	61800.00
217665	2017-08-04 02:00:00+03	50000.00
2176C7	2017-07-22 11:14:00+03	27300.00
217759	2017-07-24 06:56:00+03	98000.00
217768	2017-08-03 12:39:00+03	22000.00
21776D	2017-08-06 18:04:00+03	155600.00
21778C	2017-07-21 10:13:00+03	130900.00
2177BF	2017-07-17 04:09:00+03	54500.00
2177C2	2017-07-23 16:15:00+03	132800.00
2177E8	2017-07-28 17:29:00+03	273000.00
2177F5	2017-07-11 04:39:00+03	70700.00
21784B	2017-08-02 01:09:00+03	13700.00
2178A0	2017-08-08 20:23:00+03	134200.00
2178CE	2017-08-02 01:46:00+03	29600.00
2178E1	2017-06-29 22:22:00+03	78000.00
2178EF	2017-07-04 03:17:00+03	43700.00
2178F3	2017-08-13 06:06:00+03	340100.00
21796C	2017-07-10 10:25:00+03	93700.00
21797E	2017-07-12 19:46:00+03	666000.00
217A0F	2017-07-28 02:19:00+03	85000.00
217A18	2017-08-13 01:34:00+03	50000.00
217A68	2017-07-29 09:33:00+03	56000.00
217A9C	2017-07-17 16:31:00+03	85700.00
217AD0	2017-08-14 07:09:00+03	11800.00
217B0E	2017-07-28 09:05:00+03	28800.00
217B32	2017-07-03 04:03:00+03	70800.00
217BD1	2017-07-03 09:59:00+03	13400.00
217CC7	2017-07-11 03:55:00+03	265700.00
217CE0	2017-07-09 02:27:00+03	21400.00
217D20	2017-07-23 17:24:00+03	193100.00
217D30	2017-07-24 16:11:00+03	48800.00
217DED	2017-07-07 04:41:00+03	37700.00
217E1A	2017-08-01 09:58:00+03	73400.00
217E37	2017-08-15 07:20:00+03	95600.00
217E98	2017-07-31 21:08:00+03	19600.00
217F37	2017-08-15 14:29:00+03	27300.00
217F3F	2017-07-03 21:10:00+03	52000.00
217F62	2017-08-15 13:07:00+03	53500.00
217F67	2017-07-22 17:06:00+03	80500.00
217F9D	2017-07-22 13:25:00+03	108200.00
217FCD	2017-07-23 04:32:00+03	22000.00
217FF5	2017-08-04 11:59:00+03	64600.00
218065	2017-07-19 22:54:00+03	110000.00
2180E8	2017-07-17 17:46:00+03	91300.00
2180F4	2017-08-13 07:17:00+03	25400.00
218107	2017-08-04 19:42:00+03	12000.00
21812B	2017-07-12 06:33:00+03	52100.00
218137	2017-08-01 20:04:00+03	21200.00
218153	2017-07-05 23:04:00+03	59600.00
2181D2	2017-07-29 03:56:00+03	301800.00
21828C	2017-07-31 05:32:00+03	53300.00
2182C3	2017-08-12 11:23:00+03	124300.00
2182E3	2017-07-06 16:34:00+03	28000.00
218329	2017-07-31 00:17:00+03	97900.00
21836D	2017-07-17 17:02:00+03	23100.00
2183C2	2017-08-01 22:34:00+03	90000.00
2183E6	2017-08-02 22:46:00+03	31400.00
218441	2017-07-04 10:00:00+03	58800.00
218453	2017-07-13 21:23:00+03	28000.00
218457	2017-07-11 04:02:00+03	7400.00
218487	2017-08-11 13:36:00+03	10600.00
2184FF	2017-07-12 10:35:00+03	28000.00
218538	2017-07-30 09:17:00+03	57400.00
218541	2017-08-12 01:44:00+03	23200.00
218582	2017-07-12 00:14:00+03	75500.00
2185FA	2017-07-07 04:48:00+03	10600.00
21864B	2017-07-29 03:17:00+03	31600.00
2186C3	2017-08-04 20:52:00+03	100600.00
2186FC	2017-07-17 05:14:00+03	35600.00
21875F	2017-08-02 19:01:00+03	26600.00
218781	2017-07-27 18:02:00+03	10800.00
218792	2017-08-08 19:46:00+03	20400.00
218797	2017-07-25 04:03:00+03	81300.00
2187ED	2017-07-30 05:53:00+03	232800.00
218814	2017-08-03 11:07:00+03	57400.00
218825	2017-08-10 14:41:00+03	168000.00
21885E	2017-08-10 08:30:00+03	71900.00
21887A	2017-07-06 22:52:00+03	44800.00
2188A5	2017-08-03 08:04:00+03	46200.00
2188B9	2017-07-03 17:11:00+03	107100.00
218A0D	2017-07-25 03:17:00+03	68700.00
218A10	2017-07-13 13:01:00+03	12600.00
218A75	2017-08-05 03:06:00+03	15000.00
218AB9	2017-08-10 09:03:00+03	13200.00
218AE0	2017-07-23 04:21:00+03	12600.00
218B04	2017-07-16 01:18:00+03	12400.00
218B53	2017-07-13 14:29:00+03	50600.00
218B75	2017-07-15 05:46:00+03	55800.00
218C46	2017-07-21 13:40:00+03	144700.00
218CB8	2017-07-21 13:41:00+03	66600.00
218CEA	2017-08-13 18:30:00+03	40000.00
218D12	2017-07-19 12:59:00+03	6800.00
218D1C	2017-08-08 20:34:00+03	79000.00
218D2C	2017-08-13 03:53:00+03	58200.00
218D64	2017-07-23 00:27:00+03	16400.00
218D9C	2017-07-16 17:56:00+03	38200.00
218DCB	2017-07-02 01:24:00+03	35700.00
218E61	2017-07-12 09:03:00+03	46000.00
218ED5	2017-07-24 00:31:00+03	32800.00
218EE3	2017-07-21 05:45:00+03	95200.00
218F13	2017-07-15 20:08:00+03	99200.00
218F48	2017-08-04 05:59:00+03	23200.00
218FA4	2017-08-13 05:26:00+03	12800.00
218FB8	2017-08-13 10:56:00+03	14400.00
219044	2017-08-11 19:28:00+03	103500.00
2190E1	2017-08-07 15:39:00+03	28000.00
2190E4	2017-07-09 20:51:00+03	8400.00
219116	2017-07-11 04:19:00+03	12600.00
21912C	2017-07-16 23:32:00+03	246000.00
21914F	2017-07-27 04:33:00+03	34000.00
2191C1	2017-07-16 15:20:00+03	68400.00
2191C6	2017-08-01 22:38:00+03	32100.00
21925B	2017-08-07 17:20:00+03	46400.00
21929B	2017-07-31 17:19:00+03	252200.00
21929C	2017-08-13 22:35:00+03	62200.00
2192AB	2017-07-16 11:25:00+03	28300.00
2192D8	2017-08-15 10:49:00+03	75300.00
2192FE	2017-07-02 09:58:00+03	96300.00
219387	2017-06-30 06:44:00+03	49800.00
2193D4	2017-08-12 05:37:00+03	335100.00
2193D7	2017-08-07 12:50:00+03	36200.00
2193D9	2017-07-20 07:35:00+03	40800.00
219411	2017-07-01 01:12:00+03	65900.00
219439	2017-08-10 00:49:00+03	40400.00
219479	2017-07-28 21:33:00+03	70600.00
219489	2017-07-15 07:20:00+03	55800.00
2194A8	2017-08-11 02:08:00+03	189200.00
2194AB	2017-07-04 23:47:00+03	13600.00
21957E	2017-07-09 01:24:00+03	26000.00
219623	2017-07-05 01:03:00+03	149300.00
219683	2017-08-05 05:07:00+03	32900.00
2196E0	2017-07-07 14:51:00+03	20200.00
2196EA	2017-07-17 11:38:00+03	26800.00
21971A	2017-07-18 12:53:00+03	96100.00
219723	2017-08-15 08:22:00+03	40100.00
219751	2017-08-15 13:25:00+03	47400.00
219786	2017-07-17 04:07:00+03	14400.00
2197C9	2017-08-03 02:35:00+03	202100.00
2197F3	2017-07-20 11:01:00+03	148200.00
219803	2017-07-07 12:02:00+03	14800.00
21981F	2017-07-18 10:25:00+03	47400.00
219848	2017-07-11 07:46:00+03	13400.00
21986A	2017-07-19 10:20:00+03	22000.00
219920	2017-07-14 00:01:00+03	9200.00
219922	2017-08-11 23:40:00+03	40800.00
2199CE	2017-07-26 09:18:00+03	25800.00
2199DB	2017-08-06 08:29:00+03	135000.00
219A0E	2017-07-28 16:52:00+03	13400.00
219A1C	2017-07-16 19:32:00+03	15100.00
219A32	2017-07-19 04:54:00+03	45000.00
219A85	2017-07-29 14:33:00+03	55800.00
219A96	2017-08-11 01:48:00+03	62400.00
219A9A	2017-08-10 12:05:00+03	60400.00
219AE9	2017-06-28 20:47:00+03	33100.00
219B03	2017-07-02 11:40:00+03	100300.00
219B75	2017-07-06 19:37:00+03	37000.00
219BE9	2017-07-04 08:36:00+03	56000.00
219BEA	2017-07-05 20:20:00+03	43900.00
219BF1	2017-07-17 12:01:00+03	39200.00
219BF4	2017-06-28 14:14:00+03	56000.00
219C3C	2017-07-09 21:51:00+03	50900.00
219C7C	2017-08-11 21:41:00+03	54800.00
219D25	2017-07-08 18:35:00+03	46400.00
219D2E	2017-08-02 16:47:00+03	150700.00
219D38	2017-07-25 09:28:00+03	52800.00
219D41	2017-07-26 19:56:00+03	45200.00
219D82	2017-08-13 23:09:00+03	11300.00
219DBB	2017-07-19 22:27:00+03	22200.00
219DD3	2017-07-29 15:26:00+03	328600.00
219DE0	2017-07-25 11:21:00+03	28000.00
219E67	2017-07-28 06:35:00+03	22000.00
219EBF	2017-07-02 03:33:00+03	34400.00
219ECF	2017-07-23 06:33:00+03	43100.00
219F01	2017-08-15 17:43:00+03	83300.00
219F89	2017-07-27 06:44:00+03	77400.00
219FAB	2017-07-18 06:29:00+03	21800.00
219FDE	2017-07-25 07:05:00+03	39400.00
21A079	2017-07-05 07:53:00+03	73400.00
21A099	2017-07-27 00:19:00+03	48800.00
21A0E6	2017-07-26 14:45:00+03	21400.00
21A143	2017-06-30 05:46:00+03	51200.00
21A1CF	2017-07-29 18:30:00+03	92000.00
21A204	2017-07-21 04:38:00+03	51900.00
21A210	2017-08-07 05:34:00+03	23600.00
21A233	2017-07-07 23:24:00+03	412300.00
21A291	2017-08-15 10:12:00+03	23200.00
21A2D7	2017-07-20 00:46:00+03	23600.00
21A35F	2017-07-25 03:02:00+03	46300.00
21A484	2017-08-05 00:45:00+03	62600.00
21A4FA	2017-07-04 13:44:00+03	162400.00
21A500	2017-08-07 01:07:00+03	88600.00
21A504	2017-07-03 01:06:00+03	31100.00
21A588	2017-07-03 15:38:00+03	47200.00
21A5D7	2017-08-11 15:58:00+03	23600.00
21A5E3	2017-08-07 05:46:00+03	81600.00
21A627	2017-07-19 07:00:00+03	38800.00
21A62D	2017-07-22 02:54:00+03	39600.00
21A6B0	2017-07-05 20:44:00+03	14800.00
21A722	2017-07-30 02:57:00+03	85000.00
21A743	2017-07-03 10:59:00+03	128400.00
21A7E2	2017-07-24 23:05:00+03	26800.00
21A81E	2017-07-01 13:40:00+03	73600.00
21A85F	2017-06-27 06:48:00+03	48200.00
21A944	2017-07-16 01:33:00+03	99300.00
21A9D3	2017-07-08 03:09:00+03	47100.00
21AA01	2017-07-18 09:55:00+03	105600.00
21AA03	2017-07-23 21:00:00+03	62100.00
21AA33	2017-07-11 05:15:00+03	28000.00
21AA5F	2017-08-08 18:31:00+03	13400.00
21AA61	2017-07-19 14:47:00+03	136800.00
21AA76	2017-08-06 01:43:00+03	122500.00
21AA7F	2017-07-09 03:14:00+03	28800.00
21AAAD	2017-07-30 02:44:00+03	59300.00
21AAD0	2017-06-30 09:18:00+03	26800.00
21AAF4	2017-08-01 16:48:00+03	15400.00
21AB03	2017-07-30 05:43:00+03	59000.00
21AB56	2017-07-17 09:37:00+03	172100.00
21AB97	2017-07-20 08:23:00+03	85000.00
21AC35	2017-07-21 02:23:00+03	52000.00
21ACDA	2017-08-14 22:02:00+03	38400.00
21AD68	2017-08-13 04:55:00+03	12600.00
21AD6B	2017-07-10 19:54:00+03	19600.00
21ADBD	2017-08-03 05:22:00+03	8400.00
21ADD2	2017-08-10 01:30:00+03	8000.00
21ADED	2017-07-02 12:21:00+03	81700.00
21AE3B	2017-07-10 17:02:00+03	87200.00
21AE65	2017-07-26 19:06:00+03	19600.00
21AE6E	2017-07-12 02:29:00+03	25600.00
21AEBC	2017-07-03 09:32:00+03	92000.00
21AEE9	2017-07-03 09:11:00+03	67100.00
21AF01	2017-07-12 03:31:00+03	162200.00
21AF25	2017-07-06 15:37:00+03	24400.00
21AF2A	2017-08-14 20:00:00+03	19600.00
21AF44	2017-07-03 13:34:00+03	84800.00
21AF46	2017-07-23 06:45:00+03	27000.00
21AF82	2017-07-03 18:25:00+03	56000.00
21AF98	2017-07-28 20:19:00+03	22000.00
21B039	2017-07-10 13:43:00+03	231400.00
21B083	2017-07-24 12:20:00+03	34100.00
21B099	2017-08-03 10:35:00+03	37200.00
21B131	2017-07-19 20:02:00+03	132800.00
21B159	2017-08-14 06:20:00+03	13400.00
21B17D	2017-07-15 01:08:00+03	31800.00
21B231	2017-08-04 21:41:00+03	399600.00
21B2B5	2017-07-10 13:39:00+03	31700.00
21B323	2017-07-14 19:54:00+03	115800.00
21B36C	2017-07-30 07:00:00+03	156000.00
21B37F	2017-08-14 12:18:00+03	92800.00
21B3AF	2017-08-02 14:38:00+03	118000.00
21B427	2017-07-11 22:49:00+03	56000.00
21B430	2017-07-07 10:05:00+03	81600.00
21B440	2017-07-21 08:53:00+03	111600.00
21B44D	2017-07-16 08:30:00+03	89600.00
21B455	2017-07-05 21:09:00+03	40000.00
21B481	2017-07-22 02:47:00+03	165700.00
21B496	2017-08-13 15:41:00+03	220700.00
21B4CE	2017-08-09 10:30:00+03	6600.00
21B4F4	2017-07-16 20:33:00+03	25200.00
21B516	2017-07-22 15:40:00+03	212100.00
21B547	2017-07-05 23:44:00+03	38600.00
21B565	2017-08-04 16:13:00+03	28800.00
21B588	2017-07-14 03:25:00+03	13400.00
21B59E	2017-08-05 00:10:00+03	62800.00
21B5B8	2017-07-13 13:30:00+03	174200.00
21B5BD	2017-08-12 10:02:00+03	49700.00
21B779	2017-07-03 06:55:00+03	406100.00
21B818	2017-06-26 07:20:00+03	57600.00
21B8A0	2017-08-02 05:42:00+03	24400.00
21B931	2017-07-13 13:49:00+03	15100.00
21B984	2017-07-24 03:58:00+03	248400.00
21B998	2017-07-14 21:23:00+03	19600.00
21BA68	2017-08-10 13:02:00+03	57600.00
21BA8B	2017-08-07 17:45:00+03	86600.00
21BAD4	2017-07-22 01:35:00+03	64700.00
21BB62	2017-07-18 05:21:00+03	75600.00
21BB6C	2017-08-03 06:22:00+03	30900.00
21BBCC	2017-08-10 03:39:00+03	98400.00
21BBF1	2017-07-22 13:55:00+03	62600.00
21BCAE	2017-07-10 07:15:00+03	61800.00
21BCBD	2017-07-18 13:30:00+03	125400.00
21BCC6	2017-06-30 08:06:00+03	21400.00
21BCD5	2017-08-12 05:14:00+03	22300.00
21BD05	2017-08-01 05:32:00+03	293400.00
21BD85	2017-07-21 18:47:00+03	13000.00
21BDAC	2017-08-10 10:28:00+03	19600.00
21BDD3	2017-08-08 18:21:00+03	246000.00
21BDE2	2017-07-16 12:48:00+03	140900.00
21BE46	2017-07-11 01:31:00+03	167300.00
21BE7E	2017-07-09 17:54:00+03	6700.00
21BEB0	2017-07-27 16:42:00+03	199100.00
21BF46	2017-08-13 21:00:00+03	56100.00
21BF60	2017-08-09 12:15:00+03	146500.00
21BF70	2017-07-24 06:57:00+03	30000.00
21BF92	2017-07-02 01:18:00+03	24500.00
21BF9B	2017-07-22 23:05:00+03	46300.00
21BFBA	2017-07-07 06:49:00+03	56700.00
21C00C	2017-07-21 18:26:00+03	229300.00
21C017	2017-08-01 12:34:00+03	28000.00
21C03E	2017-07-27 08:03:00+03	54000.00
21C125	2017-07-19 09:55:00+03	34600.00
21C140	2017-07-29 01:12:00+03	32200.00
21C1BE	2017-08-15 01:52:00+03	126100.00
21C1F4	2017-08-13 23:56:00+03	137700.00
21C272	2017-08-04 05:32:00+03	98200.00
21C274	2017-08-02 10:59:00+03	59900.00
21C28D	2017-07-23 20:25:00+03	38400.00
21C2F5	2017-07-06 21:31:00+03	19600.00
21C2FD	2017-07-20 06:22:00+03	157100.00
21C32D	2017-08-06 15:02:00+03	37800.00
21C345	2017-07-02 14:55:00+03	90400.00
21C352	2017-08-07 07:53:00+03	243600.00
21C354	2017-08-06 22:50:00+03	25400.00
21C36F	2017-07-19 20:58:00+03	37500.00
21C37F	2017-08-04 06:17:00+03	36000.00
21C3B3	2017-08-06 18:10:00+03	119600.00
21C3C2	2017-07-26 02:10:00+03	40400.00
21C3CB	2017-07-12 04:27:00+03	254900.00
21C3DB	2017-07-21 12:43:00+03	14800.00
21C47B	2017-07-19 23:02:00+03	86400.00
21C4BC	2017-08-14 02:14:00+03	49800.00
21C548	2017-07-24 05:08:00+03	24400.00
21C5BC	2017-07-19 19:32:00+03	63500.00
21C5FA	2017-07-25 05:31:00+03	21800.00
21C603	2017-07-18 02:19:00+03	57400.00
21C60D	2017-08-06 00:53:00+03	69700.00
21C612	2017-07-28 07:40:00+03	85000.00
21C619	2017-07-01 21:47:00+03	88800.00
21C659	2017-07-30 16:24:00+03	90800.00
21C6DF	2017-08-06 12:41:00+03	125000.00
21C7B5	2017-08-03 04:56:00+03	27400.00
21C7BD	2017-07-01 06:40:00+03	111600.00
21C7F1	2017-08-04 04:53:00+03	20200.00
21C7F8	2017-07-23 13:28:00+03	56000.00
21C8CF	2017-07-20 16:11:00+03	128600.00
21C8FE	2017-07-22 07:19:00+03	130400.00
21C930	2017-08-04 06:27:00+03	198400.00
21C937	2017-07-03 05:17:00+03	40000.00
21C98F	2017-07-17 12:51:00+03	75800.00
21C9A1	2017-07-26 07:25:00+03	114700.00
21C9A4	2017-07-29 16:29:00+03	44600.00
21CA11	2017-07-30 21:52:00+03	24400.00
21CAB8	2017-07-01 03:59:00+03	58600.00
21CAF2	2017-07-26 20:32:00+03	62800.00
21CB38	2017-08-05 18:03:00+03	58600.00
21CBA7	2017-07-03 18:42:00+03	20600.00
21CBBA	2017-07-06 16:38:00+03	70100.00
21CC23	2017-07-17 00:28:00+03	57600.00
21CC5E	2017-07-02 00:57:00+03	187600.00
21CC93	2017-07-16 21:07:00+03	85000.00
21CC9B	2017-08-15 17:51:00+03	114700.00
21CCEE	2017-07-30 14:21:00+03	112300.00
21CD9A	2017-07-24 04:09:00+03	40400.00
21CDA9	2017-07-05 19:55:00+03	8200.00
21CDBC	2017-08-05 13:08:00+03	38400.00
21CDC9	2017-07-29 11:49:00+03	106900.00
21CDCF	2017-07-09 14:00:00+03	46000.00
21CE04	2017-07-29 02:23:00+03	26600.00
21CE88	2017-07-31 13:26:00+03	131100.00
21CF10	2017-07-22 10:22:00+03	17800.00
21CF31	2017-07-20 19:59:00+03	69500.00
21CF71	2017-08-04 14:38:00+03	50800.00
21CF85	2017-08-11 07:21:00+03	42000.00
21CFA1	2017-07-30 09:57:00+03	13400.00
21CFF4	2017-07-25 20:53:00+03	12600.00
21D023	2017-08-06 23:29:00+03	26000.00
21D07C	2017-08-15 01:41:00+03	65500.00
21D0B9	2017-07-08 02:19:00+03	27800.00
21D0CB	2017-07-14 07:16:00+03	31100.00
21D0D4	2017-07-18 03:45:00+03	26800.00
21D1B3	2017-08-05 05:30:00+03	38600.00
21D22E	2017-07-15 16:11:00+03	136200.00
21D269	2017-07-10 07:21:00+03	36800.00
21D2C7	2017-07-05 08:24:00+03	422900.00
21D306	2017-07-03 02:56:00+03	22600.00
21D326	2017-08-14 16:35:00+03	78600.00
21D391	2017-07-25 12:53:00+03	13600.00
21D3FA	2017-07-31 21:46:00+03	272300.00
21D436	2017-08-04 04:11:00+03	68800.00
21D470	2017-08-09 00:05:00+03	39400.00
21D4A6	2017-07-09 00:03:00+03	418400.00
21D507	2017-07-24 04:45:00+03	123000.00
21D512	2017-07-22 21:16:00+03	129700.00
21D58B	2017-07-25 10:17:00+03	56600.00
21D604	2017-07-24 23:17:00+03	265800.00
21D622	2017-07-08 14:09:00+03	46000.00
21D679	2017-07-20 08:26:00+03	24400.00
21D6AA	2017-08-12 20:45:00+03	54800.00
21D767	2017-07-16 04:04:00+03	27200.00
21D78A	2017-07-07 01:13:00+03	13600.00
21D7D6	2017-07-26 01:17:00+03	53000.00
21D828	2017-07-24 21:37:00+03	48800.00
21D84A	2017-07-14 06:25:00+03	46000.00
21D87C	2017-08-08 13:43:00+03	123000.00
21D89F	2017-07-20 02:35:00+03	28800.00
21D8A8	2017-08-14 05:43:00+03	123000.00
21D8B9	2017-08-04 17:30:00+03	20400.00
21D8D0	2017-07-19 23:31:00+03	37700.00
21D962	2017-07-16 11:54:00+03	67600.00
21D97B	2017-07-27 14:08:00+03	72300.00
21D9B0	2017-07-21 23:24:00+03	14000.00
21DA34	2017-07-20 22:40:00+03	24000.00
21DA37	2017-07-02 02:09:00+03	21800.00
21DA6D	2017-08-06 00:53:00+03	24400.00
21DA88	2017-08-01 05:43:00+03	72800.00
21DAA6	2017-07-10 16:55:00+03	28800.00
21DAB3	2017-07-15 15:18:00+03	73100.00
21DABD	2017-07-10 19:16:00+03	68600.00
21DACD	2017-07-24 12:03:00+03	46400.00
21DB0B	2017-07-20 04:25:00+03	15100.00
21DB35	2017-08-02 08:52:00+03	139300.00
21DB62	2017-07-11 12:33:00+03	20200.00
21DBA7	2017-08-03 19:23:00+03	76300.00
21DBBF	2017-07-12 14:48:00+03	136200.00
21DBD1	2017-08-12 01:42:00+03	132200.00
21DBD6	2017-08-07 09:29:00+03	24400.00
21DBF4	2017-07-09 21:37:00+03	92000.00
21DC37	2017-07-31 17:07:00+03	57400.00
21DC63	2017-07-25 22:46:00+03	64600.00
21DCBD	2017-07-31 20:09:00+03	57300.00
21DCC3	2017-08-04 19:01:00+03	48800.00
21DCD3	2017-07-10 09:53:00+03	170000.00
21DD9D	2017-07-22 13:12:00+03	23900.00
21DDA8	2017-07-22 13:29:00+03	42600.00
21DDFE	2017-08-01 13:27:00+03	46400.00
21DE1C	2017-07-14 14:50:00+03	126300.00
21DE36	2017-07-21 02:02:00+03	23200.00
21DEBC	2017-07-14 08:15:00+03	59200.00
21DECB	2017-07-08 16:49:00+03	46800.00
21DEE8	2017-07-20 13:25:00+03	16400.00
21DF8E	2017-07-06 23:03:00+03	136000.00
21DFA4	2017-07-20 19:57:00+03	60400.00
21DFB4	2017-07-17 01:59:00+03	92400.00
21DFDF	2017-07-05 14:37:00+03	14400.00
21DFE2	2017-07-28 11:57:00+03	270800.00
21DFF5	2017-07-18 09:19:00+03	22000.00
21E06E	2017-07-20 23:47:00+03	246000.00
21E077	2017-07-12 16:36:00+03	119700.00
21E097	2017-07-03 05:11:00+03	131600.00
21E0A3	2017-07-31 10:10:00+03	54800.00
21E1CE	2017-08-06 18:39:00+03	147500.00
21E208	2017-07-09 03:06:00+03	128800.00
21E2E8	2017-07-04 17:46:00+03	6700.00
21E30A	2017-08-04 21:10:00+03	23200.00
21E345	2017-07-22 06:36:00+03	27900.00
21E34A	2017-06-28 01:01:00+03	50800.00
21E38C	2017-07-16 14:43:00+03	67600.00
21E43D	2017-07-31 09:51:00+03	25600.00
21E475	2017-07-10 23:49:00+03	81600.00
21E4C3	2017-07-28 02:11:00+03	18600.00
21E530	2017-08-07 21:14:00+03	85400.00
21E552	2017-07-05 23:26:00+03	66600.00
21E595	2017-08-11 06:57:00+03	154500.00
21E5F4	2017-07-13 17:55:00+03	24400.00
21E611	2017-08-15 18:00:00+03	16400.00
21E63E	2017-07-18 01:15:00+03	45200.00
21E647	2017-07-16 09:34:00+03	125000.00
21E699	2017-07-14 14:29:00+03	135400.00
21E6C7	2017-07-28 08:51:00+03	54800.00
21E6E7	2017-07-16 02:37:00+03	87200.00
21E71F	2017-07-10 12:59:00+03	50100.00
21E72C	2017-07-11 18:22:00+03	31600.00
21E7CF	2017-07-30 03:34:00+03	23400.00
21E7DA	2017-07-09 02:07:00+03	60200.00
21E864	2017-08-13 07:19:00+03	119700.00
21E873	2017-07-03 22:44:00+03	42000.00
21E885	2017-07-19 22:36:00+03	399600.00
21E8CA	2017-07-07 11:13:00+03	180000.00
21E8FA	2017-07-23 23:14:00+03	152500.00
21E9A2	2017-08-14 02:09:00+03	46400.00
21EA2C	2017-07-07 07:50:00+03	42700.00
21EA47	2017-07-30 10:15:00+03	28000.00
21EA86	2017-08-05 23:20:00+03	39500.00
21EAC9	2017-07-29 04:06:00+03	19600.00
21EAF3	2017-07-10 15:44:00+03	27200.00
21EAF6	2017-07-15 09:12:00+03	219900.00
21EB51	2017-08-03 16:20:00+03	128800.00
21EB76	2017-08-03 08:17:00+03	136200.00
21EBB6	2017-07-21 09:40:00+03	52300.00
21ECD0	2017-07-24 12:30:00+03	12600.00
21ECDA	2017-07-28 07:44:00+03	258400.00
21ED5A	2017-07-17 23:59:00+03	92800.00
21ED61	2017-08-09 06:02:00+03	43000.00
21EDBD	2017-07-05 18:44:00+03	50100.00
21EE49	2017-07-22 11:06:00+03	31400.00
21EF35	2017-07-28 18:12:00+03	89700.00
21EF4D	2017-07-15 07:38:00+03	61800.00
21EF81	2017-08-13 10:36:00+03	135000.00
21EFAA	2017-07-05 02:50:00+03	21400.00
21EFB8	2017-07-03 12:14:00+03	81600.00
21EFD7	2017-07-29 02:47:00+03	56000.00
21F03B	2017-07-21 05:27:00+03	47000.00
21F047	2017-07-30 05:58:00+03	52900.00
21F0E9	2017-08-05 11:01:00+03	23200.00
21F0F6	2017-07-20 15:26:00+03	105100.00
21F165	2017-07-08 20:07:00+03	136400.00
21F176	2017-08-13 15:45:00+03	49200.00
21F1AC	2017-08-07 01:15:00+03	25100.00
21F245	2017-07-07 00:21:00+03	68800.00
21F2B4	2017-07-30 21:27:00+03	68800.00
21F30D	2017-08-09 06:49:00+03	24800.00
21F314	2017-07-02 13:02:00+03	207000.00
21F32C	2017-07-27 21:56:00+03	61800.00
21F344	2017-07-19 03:47:00+03	47200.00
21F3E1	2017-07-16 17:20:00+03	119300.00
21F402	2017-07-04 22:58:00+03	22000.00
21F454	2017-07-11 23:30:00+03	75600.00
21F462	2017-07-23 23:54:00+03	174400.00
21F485	2017-07-19 05:32:00+03	113200.00
21F512	2017-07-28 02:20:00+03	43300.00
21F52B	2017-07-20 04:14:00+03	29400.00
21F543	2017-08-06 11:43:00+03	48800.00
21F5A5	2017-08-09 05:24:00+03	246000.00
21F5A8	2017-07-05 09:37:00+03	125400.00
21F5CB	2017-08-08 15:43:00+03	13400.00
21F5D9	2017-07-29 00:01:00+03	119500.00
21F682	2017-07-14 13:12:00+03	34000.00
21F73B	2017-07-05 23:16:00+03	32400.00
21F77E	2017-07-09 10:12:00+03	123000.00
21F783	2017-07-14 22:30:00+03	91200.00
21F86B	2017-07-08 19:38:00+03	40800.00
21F873	2017-08-09 04:00:00+03	52300.00
21F96C	2017-08-05 19:22:00+03	36100.00
21F9A6	2017-07-06 10:56:00+03	28000.00
21F9BE	2017-07-12 22:20:00+03	170500.00
21F9E0	2017-07-10 09:58:00+03	129700.00
21F9E4	2017-07-13 05:56:00+03	34000.00
21F9E7	2017-07-18 00:37:00+03	386300.00
21FA7A	2017-08-12 19:18:00+03	12600.00
21FAC2	2017-07-06 06:19:00+03	179200.00
21FAE9	2017-07-31 20:15:00+03	18400.00
21FB19	2017-08-02 17:48:00+03	135400.00
21FB57	2017-07-27 23:20:00+03	37900.00
21FB5A	2017-07-29 17:30:00+03	40000.00
21FB6F	2017-07-02 23:31:00+03	117600.00
21FC2F	2017-08-11 03:22:00+03	99300.00
21FC5D	2017-07-20 10:57:00+03	30300.00
21FC9C	2017-07-31 20:26:00+03	53400.00
21FD25	2017-06-26 09:01:00+03	46400.00
21FD86	2017-08-03 06:57:00+03	34300.00
21FDB3	2017-07-26 08:19:00+03	62600.00
21FDD0	2017-08-09 04:48:00+03	54800.00
21FE14	2017-08-04 05:40:00+03	20700.00
21FE26	2017-08-08 22:36:00+03	37900.00
21FE45	2017-08-07 21:57:00+03	182200.00
21FEC2	2017-07-09 13:41:00+03	163800.00
21FEC3	2017-08-14 17:05:00+03	98300.00
21FEDD	2017-08-15 04:36:00+03	51500.00
21FEE0	2017-07-05 05:50:00+03	118500.00
21FEE6	2017-08-02 11:20:00+03	55800.00
21FF4A	2017-07-19 04:57:00+03	14800.00
21FF60	2017-07-21 07:42:00+03	177200.00
21FF6E	2017-07-31 17:50:00+03	45000.00
21FF7A	2017-07-11 02:16:00+03	59100.00
21FFCD	2017-07-18 22:53:00+03	47100.00
21FFE2	2017-07-13 14:01:00+03	270700.00
21FFFE	2017-07-15 13:29:00+03	132800.00
220079	2017-08-15 09:08:00+03	92800.00
220081	2017-07-04 02:35:00+03	56000.00
2200EF	2017-07-26 04:50:00+03	246000.00
220210	2017-08-11 22:27:00+03	40400.00
22026A	2017-08-14 15:39:00+03	30200.00
22028A	2017-07-03 08:08:00+03	28000.00
22029E	2017-08-09 20:51:00+03	105600.00
220341	2017-07-19 14:50:00+03	20200.00
220343	2017-07-27 05:01:00+03	7300.00
220381	2017-07-09 21:10:00+03	132800.00
220408	2017-07-09 16:38:00+03	187600.00
22048B	2017-07-02 22:07:00+03	97900.00
2204C3	2017-07-15 21:21:00+03	28800.00
220540	2017-07-11 14:34:00+03	136200.00
22055B	2017-07-18 01:04:00+03	22400.00
22058B	2017-07-27 10:14:00+03	19600.00
2205C9	2017-07-16 21:43:00+03	52800.00
2205E6	2017-07-20 23:59:00+03	56000.00
22061D	2017-08-13 18:58:00+03	46400.00
22061E	2017-08-11 17:00:00+03	112600.00
22063C	2017-07-15 06:23:00+03	15000.00
22063E	2017-08-13 23:55:00+03	135300.00
220671	2017-08-13 17:39:00+03	57800.00
2206D7	2017-07-10 08:11:00+03	32800.00
2206DC	2017-08-04 19:29:00+03	64400.00
22073C	2017-07-27 23:46:00+03	26600.00
22074A	2017-07-27 17:47:00+03	28800.00
22075C	2017-07-11 11:19:00+03	100600.00
2207BF	2017-07-09 08:41:00+03	12600.00
22090D	2017-07-14 10:25:00+03	54400.00
22090F	2017-07-16 21:30:00+03	66600.00
220934	2017-08-08 14:44:00+03	135400.00
22093F	2017-07-20 14:39:00+03	91500.00
220954	2017-07-11 21:26:00+03	83600.00
22097B	2017-08-14 05:22:00+03	103100.00
2209A6	2017-07-02 11:12:00+03	23100.00
2209B6	2017-08-09 19:31:00+03	40800.00
220A47	2017-08-14 14:48:00+03	42400.00
220A68	2017-08-11 00:39:00+03	26000.00
220ADE	2017-08-15 03:03:00+03	95900.00
220AF1	2017-07-14 13:58:00+03	43600.00
220B24	2017-08-10 16:52:00+03	42800.00
220B75	2017-07-13 01:24:00+03	88600.00
220C05	2017-07-09 06:15:00+03	89600.00
220C40	2017-07-30 12:35:00+03	189800.00
220C47	2017-07-17 08:34:00+03	78600.00
220C5E	2017-08-03 18:52:00+03	55600.00
220C72	2017-07-31 13:35:00+03	28000.00
220CE3	2017-07-20 00:12:00+03	19800.00
220CF0	2017-07-06 03:13:00+03	24400.00
220DAD	2017-07-06 18:54:00+03	115800.00
220DB0	2017-07-29 14:38:00+03	27300.00
220DC6	2017-07-12 16:00:00+03	21000.00
220DCB	2017-08-10 05:32:00+03	23200.00
220E01	2017-07-11 06:16:00+03	56000.00
220E14	2017-08-05 14:02:00+03	16400.00
220EA9	2017-07-03 10:01:00+03	40400.00
220EBC	2017-07-14 22:24:00+03	15000.00
220ECA	2017-07-04 02:45:00+03	28800.00
220EEC	2017-08-06 18:05:00+03	46000.00
220EF1	2017-08-06 21:10:00+03	89600.00
220F53	2017-07-14 12:53:00+03	283700.00
220FB8	2017-07-26 04:50:00+03	47000.00
220FC0	2017-07-30 07:55:00+03	61900.00
22100B	2017-07-24 15:38:00+03	53400.00
22100C	2017-08-14 05:43:00+03	52700.00
221061	2017-07-20 04:19:00+03	128800.00
221077	2017-08-06 03:41:00+03	111600.00
2210A2	2017-07-19 23:31:00+03	42800.00
2210B0	2017-08-09 11:46:00+03	28800.00
22110E	2017-07-24 21:58:00+03	42800.00
221122	2017-07-26 02:50:00+03	173000.00
221125	2017-07-20 02:45:00+03	175300.00
221218	2017-06-30 16:42:00+03	19800.00
22121F	2017-08-03 03:34:00+03	204200.00
221226	2017-06-30 01:40:00+03	97500.00
2212D7	2017-08-13 16:21:00+03	65500.00
221318	2017-08-02 19:13:00+03	56000.00
22131B	2017-08-02 06:21:00+03	46200.00
22131E	2017-08-10 02:14:00+03	23100.00
221326	2017-07-09 00:36:00+03	106900.00
2213EB	2017-07-27 15:38:00+03	135600.00
2213ED	2017-07-26 01:35:00+03	95200.00
22143B	2017-07-26 01:38:00+03	135400.00
221458	2017-07-09 10:04:00+03	198600.00
2214AE	2017-08-02 23:35:00+03	19600.00
221519	2017-08-09 05:25:00+03	57400.00
221597	2017-07-25 23:10:00+03	6700.00
2215B2	2017-07-12 08:53:00+03	26000.00
221622	2017-07-27 10:44:00+03	37700.00
221680	2017-07-15 04:32:00+03	135600.00
221692	2017-07-18 08:29:00+03	95200.00
221697	2017-07-11 08:05:00+03	49800.00
2216B0	2017-07-02 16:47:00+03	75600.00
22173F	2017-07-14 20:47:00+03	143000.00
221764	2017-07-16 03:03:00+03	85600.00
2217BE	2017-07-22 22:39:00+03	265700.00
2217E4	2017-06-30 22:22:00+03	28000.00
22181A	2017-08-08 22:31:00+03	128600.00
221845	2017-07-01 09:47:00+03	48400.00
221851	2017-07-17 15:05:00+03	138600.00
2218D0	2017-08-04 22:49:00+03	26000.00
2218E8	2017-07-09 03:20:00+03	56600.00
2218E9	2017-08-09 20:16:00+03	6700.00
22195D	2017-07-22 01:13:00+03	76300.00
221984	2017-06-29 19:30:00+03	52400.00
2219A8	2017-07-25 10:34:00+03	260300.00
2219D0	2017-07-18 10:38:00+03	29400.00
2219E0	2017-07-19 22:02:00+03	48700.00
221A09	2017-08-07 07:16:00+03	46400.00
221A19	2017-07-06 17:21:00+03	66000.00
221A4B	2017-07-07 21:57:00+03	95100.00
221A69	2017-08-04 10:02:00+03	51900.00
221A97	2017-07-14 02:33:00+03	18700.00
221A9E	2017-08-13 08:55:00+03	35500.00
221AF1	2017-07-10 17:10:00+03	98000.00
221AF8	2017-08-02 04:05:00+03	40400.00
221B1F	2017-07-06 12:25:00+03	86500.00
221B2E	2017-07-08 15:48:00+03	31600.00
221B32	2017-07-10 15:07:00+03	45400.00
221B9C	2017-07-10 05:18:00+03	23600.00
221B9F	2017-07-12 14:35:00+03	26000.00
221C03	2017-08-07 07:27:00+03	111600.00
221C1C	2017-07-06 04:09:00+03	35800.00
221C24	2017-07-05 03:45:00+03	38400.00
221C30	2017-07-07 13:56:00+03	116200.00
221CBB	2017-08-11 22:46:00+03	51800.00
221CC8	2017-07-17 06:31:00+03	6800.00
221CD6	2017-07-04 15:29:00+03	47100.00
221D0E	2017-07-29 05:55:00+03	72400.00
221D33	2017-08-05 01:14:00+03	98300.00
221D4B	2017-07-16 08:12:00+03	16400.00
221D8D	2017-07-02 02:20:00+03	26000.00
221E30	2017-07-30 04:49:00+03	252200.00
221E7E	2017-07-31 03:38:00+03	170700.00
221E8E	2017-08-09 18:35:00+03	67700.00
221ECC	2017-07-08 16:58:00+03	53400.00
221F71	2017-07-17 15:09:00+03	368900.00
221F77	2017-07-26 23:23:00+03	22000.00
221F83	2017-08-01 19:01:00+03	27700.00
221FB7	2017-07-12 06:05:00+03	43200.00
222045	2017-08-15 14:32:00+03	61700.00
222094	2017-07-13 02:41:00+03	50600.00
2220A1	2017-08-04 19:23:00+03	41400.00
2220A6	2017-08-15 04:26:00+03	70600.00
22212C	2017-07-07 22:01:00+03	48700.00
222147	2017-07-02 16:29:00+03	70700.00
22214F	2017-07-23 16:14:00+03	51900.00
222182	2017-07-03 20:34:00+03	187600.00
2221AA	2017-07-22 10:34:00+03	62600.00
222234	2017-07-13 06:26:00+03	38000.00
22229B	2017-08-07 09:10:00+03	108700.00
2222B5	2017-07-06 14:27:00+03	72400.00
2222C6	2017-08-08 23:29:00+03	45100.00
222356	2017-07-26 10:33:00+03	111600.00
222391	2017-07-04 21:02:00+03	168700.00
222395	2017-07-04 12:01:00+03	32200.00
222490	2017-07-29 03:14:00+03	136500.00
222501	2017-08-15 03:50:00+03	81700.00
22259E	2017-07-17 00:46:00+03	8400.00
2225C2	2017-07-12 20:47:00+03	59000.00
2225E1	2017-07-29 06:21:00+03	103200.00
222618	2017-07-05 18:18:00+03	146000.00
222650	2017-08-04 06:38:00+03	56000.00
222669	2017-07-16 14:31:00+03	30800.00
22267B	2017-07-29 00:16:00+03	73500.00
2226E4	2017-07-04 23:51:00+03	102100.00
222715	2017-07-18 21:35:00+03	23200.00
222757	2017-07-31 07:21:00+03	56600.00
222777	2017-07-03 08:17:00+03	66600.00
222783	2017-07-23 20:03:00+03	52300.00
2227AC	2017-07-10 07:36:00+03	114300.00
2227B4	2017-08-03 00:45:00+03	271100.00
2227DE	2017-08-15 05:46:00+03	101800.00
22280E	2017-07-10 21:38:00+03	71200.00
222814	2017-07-11 11:52:00+03	31600.00
2228C1	2017-07-25 20:09:00+03	48800.00
222921	2017-07-14 12:51:00+03	118300.00
2229EC	2017-07-28 05:51:00+03	16400.00
2229EF	2017-08-05 05:27:00+03	62100.00
2229F9	2017-08-10 09:33:00+03	48800.00
222A1B	2017-07-16 22:49:00+03	79800.00
222A60	2017-08-08 17:33:00+03	56000.00
222ABA	2017-08-09 01:59:00+03	51900.00
222B6C	2017-08-14 04:05:00+03	96300.00
222BBD	2017-07-04 08:14:00+03	6700.00
222BFD	2017-07-09 18:49:00+03	83600.00
222CEB	2017-07-15 12:51:00+03	231400.00
222DD3	2017-07-04 02:45:00+03	98300.00
222E13	2017-08-15 16:46:00+03	26000.00
222E15	2017-07-13 11:05:00+03	57200.00
222E81	2017-07-20 22:41:00+03	28800.00
222EC8	2017-07-24 23:06:00+03	28800.00
222EDA	2017-07-10 04:17:00+03	18400.00
222F03	2017-07-16 20:23:00+03	56000.00
222F39	2017-07-21 04:52:00+03	177600.00
222FB2	2017-07-06 13:27:00+03	52000.00
222FBE	2017-08-04 09:04:00+03	22600.00
223024	2017-07-06 14:39:00+03	83100.00
22303E	2017-07-16 07:43:00+03	13400.00
223076	2017-07-17 11:02:00+03	46800.00
223109	2017-07-08 17:31:00+03	22600.00
22310F	2017-07-09 11:46:00+03	232400.00
223110	2017-07-26 00:15:00+03	65900.00
22311B	2017-07-25 10:23:00+03	265600.00
22311E	2017-08-04 15:31:00+03	265700.00
22317E	2017-08-08 23:29:00+03	21600.00
2231E9	2017-08-05 11:54:00+03	27200.00
223214	2017-08-10 02:21:00+03	100200.00
22322A	2017-07-08 21:07:00+03	84100.00
223261	2017-08-09 15:55:00+03	111700.00
22329A	2017-07-02 15:28:00+03	29400.00
22331C	2017-07-23 03:08:00+03	20400.00
223320	2017-07-11 19:01:00+03	21400.00
223396	2017-07-19 17:17:00+03	480700.00
2233A4	2017-07-19 07:10:00+03	44000.00
2233A6	2017-08-04 03:28:00+03	73600.00
2233E6	2017-08-04 09:23:00+03	116800.00
2233F1	2017-07-15 17:50:00+03	155600.00
22340F	2017-07-11 16:53:00+03	27800.00
223470	2017-08-07 04:22:00+03	14000.00
223526	2017-07-10 23:03:00+03	6700.00
223528	2017-07-12 23:05:00+03	226800.00
223552	2017-07-16 00:56:00+03	116900.00
223571	2017-07-09 12:44:00+03	187600.00
22357F	2017-08-03 11:44:00+03	66600.00
2235D3	2017-08-04 15:04:00+03	268600.00
22363A	2017-07-19 11:43:00+03	135400.00
223653	2017-07-31 16:19:00+03	120800.00
2236E8	2017-08-01 03:11:00+03	59300.00
2236F7	2017-07-30 22:32:00+03	18000.00
223843	2017-07-12 13:26:00+03	36200.00
22393A	2017-08-02 18:16:00+03	110300.00
223947	2017-07-03 12:49:00+03	61800.00
223970	2017-07-06 10:15:00+03	65100.00
223981	2017-07-18 19:25:00+03	86400.00
2239DC	2017-07-28 23:16:00+03	79800.00
223A30	2017-07-11 23:27:00+03	76800.00
223ABE	2017-07-05 08:06:00+03	13600.00
223B32	2017-07-26 02:47:00+03	284400.00
223C24	2017-07-11 03:05:00+03	36200.00
223C32	2017-07-08 21:42:00+03	147700.00
223C91	2017-07-27 12:34:00+03	174600.00
223C95	2017-08-03 09:45:00+03	43300.00
223D8E	2017-08-06 13:29:00+03	29600.00
223DCC	2017-07-07 13:29:00+03	59300.00
223DF8	2017-07-04 02:44:00+03	12600.00
223E06	2017-07-22 19:12:00+03	67600.00
223E16	2017-06-29 21:14:00+03	109600.00
223E63	2017-08-13 07:12:00+03	178800.00
223F30	2017-07-30 11:02:00+03	342100.00
223F80	2017-07-13 18:14:00+03	101200.00
223FBE	2017-08-10 19:52:00+03	46400.00
223FEB	2017-07-24 13:24:00+03	47400.00
223FF1	2017-07-16 19:55:00+03	37900.00
22400D	2017-07-04 23:07:00+03	23200.00
224028	2017-08-04 10:28:00+03	23600.00
22403A	2017-08-11 00:29:00+03	168000.00
224101	2017-07-11 02:19:00+03	8200.00
224149	2017-07-14 10:43:00+03	71600.00
22417A	2017-08-01 21:19:00+03	492000.00
2241CB	2017-07-08 12:42:00+03	100600.00
2241D4	2017-07-28 15:48:00+03	58000.00
2241E7	2017-07-18 16:15:00+03	7900.00
2241F1	2017-08-04 17:08:00+03	31400.00
224202	2017-07-30 01:33:00+03	25600.00
224215	2017-07-30 23:50:00+03	64300.00
2242F0	2017-07-17 09:39:00+03	120900.00
2243BF	2017-07-13 16:39:00+03	231400.00
224417	2017-07-10 17:47:00+03	62000.00
224479	2017-07-31 21:23:00+03	6300.00
2244C3	2017-06-30 11:35:00+03	27400.00
22453D	2017-08-03 09:33:00+03	103200.00
224545	2017-07-08 15:04:00+03	50600.00
2245B2	2017-08-14 13:29:00+03	92900.00
22467A	2017-08-05 00:50:00+03	99200.00
2246FF	2017-07-21 05:12:00+03	135600.00
22472F	2017-08-07 08:10:00+03	46200.00
224831	2017-07-28 14:24:00+03	291200.00
22485B	2017-07-27 06:03:00+03	6800.00
2248F1	2017-07-18 21:59:00+03	52000.00
224925	2017-07-10 09:17:00+03	40000.00
224926	2017-06-26 10:00:00+03	100300.00
224935	2017-08-06 01:19:00+03	179500.00
224938	2017-07-03 18:31:00+03	9800.00
224961	2017-07-04 09:08:00+03	56900.00
224983	2017-07-06 02:48:00+03	109600.00
2249CF	2017-08-11 17:36:00+03	61800.00
2249E5	2017-08-01 18:11:00+03	56000.00
224A20	2017-08-15 12:01:00+03	12000.00
224A2D	2017-07-29 01:46:00+03	67000.00
224A3D	2017-08-11 02:57:00+03	46400.00
224A7E	2017-07-14 20:15:00+03	61800.00
224AA3	2017-07-09 02:06:00+03	28800.00
224AC3	2017-08-01 23:17:00+03	492000.00
224ADF	2017-08-09 07:59:00+03	21800.00
224B0D	2017-08-05 01:46:00+03	28000.00
224B17	2017-07-21 22:02:00+03	8000.00
224C41	2017-07-25 19:44:00+03	99700.00
224C49	2017-08-12 13:49:00+03	58800.00
224C76	2017-08-08 02:14:00+03	59400.00
224CB3	2017-07-20 17:06:00+03	61800.00
224CB4	2017-07-24 08:27:00+03	37500.00
224D38	2017-08-10 17:22:00+03	119500.00
224D8A	2017-08-03 20:30:00+03	40000.00
224E02	2017-07-18 10:13:00+03	6000.00
224E64	2017-07-19 14:28:00+03	199700.00
224E7D	2017-08-07 16:33:00+03	25600.00
224E7F	2017-07-19 23:41:00+03	67200.00
224EAC	2017-07-23 08:54:00+03	26200.00
224EB7	2017-07-30 23:01:00+03	28800.00
224F00	2017-07-31 23:10:00+03	24000.00
224F2E	2017-07-17 06:18:00+03	117700.00
22503C	2017-07-17 22:31:00+03	154500.00
22506C	2017-07-18 07:41:00+03	46400.00
225072	2017-07-27 10:19:00+03	27200.00
225078	2017-07-20 19:21:00+03	67000.00
225097	2017-07-12 09:03:00+03	170200.00
2250C7	2017-08-13 16:17:00+03	139200.00
22511B	2017-07-29 21:54:00+03	103400.00
22513D	2017-08-01 11:17:00+03	56000.00
225191	2017-07-01 02:44:00+03	136800.00
2251D1	2017-08-12 19:14:00+03	35300.00
225235	2017-06-30 13:10:00+03	42800.00
2253E2	2017-08-13 12:03:00+03	270800.00
22542C	2017-07-12 13:13:00+03	102100.00
22542D	2017-08-12 05:22:00+03	23600.00
22542F	2017-08-02 05:15:00+03	67200.00
225450	2017-08-01 02:04:00+03	48600.00
225576	2017-07-25 19:48:00+03	23100.00
22558A	2017-07-09 07:01:00+03	29600.00
22559C	2017-07-25 14:31:00+03	16400.00
2255AB	2017-07-14 09:21:00+03	135400.00
22562D	2017-07-12 06:05:00+03	132800.00
22568A	2017-07-24 03:12:00+03	129200.00
22571B	2017-08-07 16:57:00+03	33000.00
22572E	2017-07-16 18:07:00+03	64800.00
225734	2017-07-18 04:23:00+03	42000.00
225750	2017-08-09 18:39:00+03	79300.00
225764	2017-07-22 02:57:00+03	84300.00
225775	2017-08-09 20:31:00+03	41300.00
22577A	2017-08-01 21:35:00+03	29400.00
225786	2017-07-17 17:24:00+03	167900.00
2257B1	2017-07-08 15:33:00+03	102100.00
225817	2017-08-05 20:16:00+03	60400.00
2258C3	2017-07-26 19:40:00+03	21400.00
225903	2017-07-05 12:17:00+03	24400.00
225910	2017-07-01 06:32:00+03	85400.00
225956	2017-07-26 17:45:00+03	192700.00
225981	2017-08-10 00:17:00+03	28000.00
2259D9	2017-07-30 06:07:00+03	147400.00
225A95	2017-07-03 07:43:00+03	25100.00
225A98	2017-08-05 08:44:00+03	47200.00
225AD1	2017-07-04 08:58:00+03	57500.00
225B66	2017-08-14 23:10:00+03	19600.00
225B6F	2017-07-31 00:03:00+03	21800.00
225BC9	2017-06-30 13:04:00+03	43100.00
225C7E	2017-07-02 10:18:00+03	33300.00
225CB5	2017-07-27 09:07:00+03	38600.00
225CDB	2017-08-14 22:21:00+03	64500.00
225CDE	2017-08-11 19:20:00+03	122000.00
225CF3	2017-07-20 06:55:00+03	603600.00
225CF4	2017-06-28 09:45:00+03	46300.00
225D05	2017-07-15 23:25:00+03	21200.00
225D11	2017-08-11 00:21:00+03	174000.00
225D1F	2017-08-03 05:45:00+03	84100.00
225D22	2017-08-10 20:51:00+03	56000.00
225DBC	2017-07-12 04:11:00+03	147000.00
225E03	2017-08-10 10:28:00+03	43800.00
225E51	2017-07-10 03:57:00+03	25900.00
225E78	2017-07-29 09:43:00+03	44800.00
225E9E	2017-07-22 10:04:00+03	11700.00
225EBB	2017-07-11 14:32:00+03	23200.00
225EC1	2017-07-22 00:51:00+03	57400.00
225F02	2017-08-05 17:38:00+03	45200.00
225F1E	2017-07-07 20:26:00+03	54800.00
225F35	2017-08-07 10:35:00+03	63400.00
225F63	2017-08-05 08:37:00+03	20400.00
225FA4	2017-07-22 06:53:00+03	265700.00
225FD0	2017-08-04 09:02:00+03	44000.00
225FF8	2017-07-30 14:32:00+03	89600.00
226004	2017-07-23 17:55:00+03	173600.00
226007	2017-07-23 15:26:00+03	62800.00
226047	2017-07-20 06:53:00+03	31900.00
22605B	2017-07-04 11:48:00+03	6700.00
22607A	2017-07-11 15:07:00+03	81700.00
226103	2017-07-15 01:13:00+03	199700.00
22615C	2017-07-03 18:40:00+03	36200.00
22616D	2017-08-08 18:21:00+03	23400.00
22617A	2017-07-28 19:04:00+03	80700.00
2261B7	2017-07-14 10:39:00+03	49800.00
226216	2017-07-12 06:50:00+03	124900.00
22625C	2017-08-11 21:08:00+03	38400.00
226275	2017-08-02 12:54:00+03	36200.00
226282	2017-07-18 20:35:00+03	76200.00
22629C	2017-07-08 05:46:00+03	390400.00
2262DB	2017-07-03 11:25:00+03	77000.00
2262EA	2017-08-09 03:51:00+03	100200.00
2262F2	2017-07-30 06:22:00+03	6800.00
226306	2017-08-06 03:26:00+03	67600.00
226356	2017-07-12 13:28:00+03	43100.00
22637F	2017-07-11 01:58:00+03	6700.00
226387	2017-07-03 14:14:00+03	68400.00
226388	2017-07-13 08:58:00+03	48800.00
226461	2017-07-01 17:34:00+03	108500.00
226476	2017-07-07 01:48:00+03	22600.00
226478	2017-08-01 13:41:00+03	26000.00
22650A	2017-07-11 16:48:00+03	45200.00
22650E	2017-07-10 02:07:00+03	14800.00
226561	2017-07-11 14:18:00+03	59800.00
2265F0	2017-07-17 12:25:00+03	492000.00
2265FB	2017-08-06 19:57:00+03	60400.00
22664C	2017-07-01 18:00:00+03	13000.00
226661	2017-07-06 15:51:00+03	112000.00
226672	2017-07-28 18:45:00+03	54500.00
226677	2017-08-12 05:14:00+03	46400.00
2266A5	2017-08-11 18:34:00+03	36200.00
2266B6	2017-07-03 11:51:00+03	49600.00
2266BA	2017-08-06 19:28:00+03	70700.00
2266CC	2017-07-20 11:31:00+03	37100.00
226783	2017-07-24 21:57:00+03	16400.00
22679F	2017-07-24 13:59:00+03	26000.00
2267A2	2017-07-20 03:54:00+03	84000.00
22681D	2017-07-30 19:47:00+03	17600.00
22681E	2017-07-18 11:12:00+03	28300.00
226862	2017-08-03 07:01:00+03	8400.00
2268C8	2017-07-13 15:54:00+03	11000.00
22693B	2017-07-16 10:24:00+03	55800.00
2269A1	2017-07-11 02:09:00+03	46300.00
2269A5	2017-08-05 01:21:00+03	16400.00
226A47	2017-08-06 22:27:00+03	48800.00
226A5F	2017-07-16 16:09:00+03	41800.00
226A61	2017-07-13 14:32:00+03	14400.00
226A92	2017-07-06 21:11:00+03	98400.00
226B27	2017-07-21 04:18:00+03	64800.00
226BAA	2017-08-14 18:23:00+03	13800.00
226BF8	2017-08-07 14:56:00+03	123400.00
226C08	2017-07-26 15:11:00+03	23600.00
226C35	2017-07-05 02:14:00+03	41200.00
226C6E	2017-07-26 05:32:00+03	45400.00
226C80	2017-08-10 21:59:00+03	69600.00
226D06	2017-07-27 17:30:00+03	70700.00
226DAD	2017-07-17 15:22:00+03	71600.00
226EE1	2017-07-15 21:54:00+03	95000.00
226F21	2017-07-14 20:23:00+03	168000.00
226F6C	2017-06-26 07:48:00+03	51600.00
226FE7	2017-08-08 12:37:00+03	90400.00
227008	2017-07-04 07:08:00+03	31300.00
227054	2017-07-01 10:00:00+03	43100.00
227057	2017-07-11 12:06:00+03	25600.00
2270BB	2017-07-12 18:07:00+03	255600.00
22717C	2017-07-12 04:59:00+03	399600.00
22721A	2017-07-27 09:16:00+03	30800.00
22722A	2017-07-17 02:18:00+03	24400.00
2272A2	2017-07-06 13:47:00+03	127900.00
2272AA	2017-07-31 01:40:00+03	66600.00
2272C2	2017-08-09 18:39:00+03	31600.00
2272D0	2017-07-16 15:18:00+03	162600.00
227358	2017-07-05 03:49:00+03	32700.00
2273B3	2017-07-24 04:02:00+03	86300.00
2273F8	2017-07-13 11:31:00+03	133200.00
227435	2017-07-11 20:08:00+03	13800.00
227451	2017-08-01 19:04:00+03	6800.00
227543	2017-07-11 19:11:00+03	39300.00
22754A	2017-07-04 03:18:00+03	69600.00
2276C3	2017-07-27 16:19:00+03	150300.00
2276D1	2017-08-09 12:35:00+03	166100.00
2276DA	2017-06-30 02:38:00+03	77500.00
2276E0	2017-08-15 03:16:00+03	112600.00
2276E7	2017-08-11 20:03:00+03	136800.00
22771B	2017-07-07 22:49:00+03	134400.00
22775F	2017-07-21 14:08:00+03	39800.00
227825	2017-08-07 22:28:00+03	67500.00
227844	2017-07-30 02:22:00+03	48900.00
227867	2017-08-07 18:09:00+03	110600.00
227890	2017-07-31 21:32:00+03	116800.00
2278D2	2017-08-07 01:06:00+03	6000.00
22794D	2017-07-25 06:10:00+03	53700.00
227998	2017-07-17 16:24:00+03	182300.00
2279AB	2017-07-30 01:35:00+03	80200.00
2279AF	2017-07-19 19:33:00+03	54400.00
2279E7	2017-07-11 11:52:00+03	23400.00
2279F3	2017-08-12 01:56:00+03	101500.00
227A1D	2017-07-05 07:02:00+03	101200.00
227B1B	2017-08-02 07:06:00+03	81600.00
227BD0	2017-07-07 11:21:00+03	24400.00
227BEC	2017-07-20 15:00:00+03	56600.00
227C70	2017-07-03 04:41:00+03	75300.00
227C80	2017-07-19 03:35:00+03	48800.00
227CB6	2017-07-10 06:25:00+03	67600.00
227CD7	2017-08-08 00:06:00+03	56000.00
227D1F	2017-08-06 22:41:00+03	153300.00
227D30	2017-08-02 16:35:00+03	40100.00
227D46	2017-07-16 18:57:00+03	87300.00
227E1C	2017-07-25 21:21:00+03	10800.00
227E27	2017-07-30 15:28:00+03	27800.00
227E2F	2017-07-19 19:33:00+03	26000.00
227E4F	2017-07-25 16:38:00+03	140900.00
227E79	2017-07-11 12:00:00+03	92800.00
227E93	2017-08-12 08:55:00+03	110300.00
227E9A	2017-08-03 14:21:00+03	101200.00
227F4E	2017-07-21 02:55:00+03	57500.00
227F56	2017-07-03 22:21:00+03	35200.00
227F84	2017-08-03 00:23:00+03	26700.00
22801C	2017-07-16 18:15:00+03	125200.00
228035	2017-07-22 00:33:00+03	40200.00
228066	2017-08-09 00:19:00+03	266300.00
228074	2017-08-03 04:36:00+03	266400.00
22807D	2017-07-20 23:51:00+03	46300.00
2280C4	2017-08-01 11:51:00+03	214400.00
2280DC	2017-07-22 07:03:00+03	26200.00
228132	2017-08-14 09:26:00+03	65900.00
228147	2017-07-05 20:03:00+03	31400.00
228179	2017-08-10 13:18:00+03	153900.00
22818A	2017-07-09 05:11:00+03	55800.00
2281FA	2017-07-08 14:54:00+03	38800.00
22820E	2017-07-21 10:46:00+03	99000.00
228235	2017-07-04 03:24:00+03	49100.00
228262	2017-08-04 09:29:00+03	47100.00
228296	2017-08-15 10:59:00+03	16400.00
2282A6	2017-08-11 02:04:00+03	6000.00
2282C0	2017-07-04 04:29:00+03	96300.00
2282D0	2017-07-21 15:14:00+03	101200.00
22831E	2017-07-27 12:10:00+03	69500.00
228390	2017-07-27 19:56:00+03	14000.00
2283A7	2017-08-01 06:57:00+03	28000.00
2283FC	2017-08-12 17:37:00+03	49600.00
22840F	2017-07-12 16:33:00+03	43200.00
22848C	2017-07-26 05:13:00+03	31600.00
22849D	2017-08-11 11:44:00+03	11600.00
2284A5	2017-07-30 19:47:00+03	73600.00
2284C6	2017-07-03 17:46:00+03	40000.00
2284CE	2017-08-10 16:48:00+03	29600.00
2284E3	2017-08-03 12:56:00+03	22000.00
2284EC	2017-07-19 10:28:00+03	52000.00
2284F1	2017-07-14 03:34:00+03	137600.00
228530	2017-07-08 03:26:00+03	152500.00
228585	2017-08-14 21:30:00+03	42800.00
228586	2017-08-02 18:47:00+03	189200.00
2285DE	2017-07-08 16:15:00+03	89700.00
2285F1	2017-07-01 10:10:00+03	84300.00
22865F	2017-07-03 19:11:00+03	57300.00
2286AE	2017-08-06 13:13:00+03	88600.00
22879C	2017-07-12 16:31:00+03	65500.00
2287BE	2017-08-02 19:58:00+03	34000.00
228937	2017-08-14 10:27:00+03	36000.00
228945	2017-08-11 02:47:00+03	26000.00
22895F	2017-07-10 07:14:00+03	6700.00
2289CF	2017-07-08 15:05:00+03	40600.00
228A32	2017-07-28 08:54:00+03	28000.00
228AEA	2017-07-10 01:48:00+03	23400.00
228B0C	2017-08-13 02:35:00+03	12400.00
228B8B	2017-08-11 15:07:00+03	254900.00
228BD0	2017-07-21 04:52:00+03	69000.00
228BE0	2017-07-30 02:27:00+03	16400.00
228BE4	2017-07-14 14:44:00+03	28000.00
228BEC	2017-07-11 05:27:00+03	22600.00
228D08	2017-07-10 22:06:00+03	258400.00
228D4C	2017-07-31 07:32:00+03	12600.00
228E21	2017-07-26 05:39:00+03	129000.00
228E28	2017-08-03 01:04:00+03	148200.00
228F25	2017-06-29 06:17:00+03	92200.00
228F83	2017-08-10 13:45:00+03	56000.00
228FB4	2017-08-05 17:20:00+03	114800.00
228FC5	2017-08-14 04:54:00+03	70700.00
228FD9	2017-07-12 04:13:00+03	57500.00
229032	2017-07-28 20:30:00+03	55800.00
229036	2017-08-04 18:17:00+03	128800.00
229055	2017-08-01 08:19:00+03	21400.00
22912E	2017-08-11 19:09:00+03	62500.00
22914F	2017-07-26 02:07:00+03	67200.00
229165	2017-08-04 14:29:00+03	64100.00
22918E	2017-08-02 10:57:00+03	56000.00
229192	2017-08-02 00:55:00+03	28000.00
2291E2	2017-07-20 13:05:00+03	21800.00
229218	2017-08-09 00:27:00+03	114800.00
2292A9	2017-07-07 12:22:00+03	26000.00
2292F1	2017-07-14 15:47:00+03	102300.00
22930D	2017-08-10 00:39:00+03	56200.00
22932F	2017-07-21 08:43:00+03	16800.00
229362	2017-07-05 18:25:00+03	89600.00
22936E	2017-06-28 20:14:00+03	7200.00
2293CE	2017-06-30 18:49:00+03	55600.00
2293E9	2017-07-24 03:08:00+03	58600.00
22944D	2017-07-16 05:17:00+03	115700.00
2294B3	2017-07-16 10:29:00+03	31600.00
2294E4	2017-08-12 03:58:00+03	23200.00
229599	2017-07-05 22:06:00+03	16800.00
2295C2	2017-08-09 23:05:00+03	231900.00
2295CA	2017-07-18 18:37:00+03	112000.00
2295EA	2017-07-15 08:57:00+03	56600.00
22962E	2017-07-10 13:59:00+03	10600.00
22966E	2017-08-05 23:44:00+03	23200.00
22967C	2017-07-16 03:20:00+03	78100.00
2296B2	2017-07-31 15:13:00+03	91600.00
2296EE	2017-07-15 13:09:00+03	47100.00
229706	2017-08-06 09:12:00+03	13200.00
229749	2017-08-02 16:51:00+03	173900.00
229784	2017-08-10 03:53:00+03	68100.00
2297E4	2017-07-25 08:11:00+03	100900.00
22980B	2017-07-02 00:35:00+03	10600.00
2298B8	2017-08-15 17:45:00+03	61800.00
2298FD	2017-07-18 17:54:00+03	45100.00
2299B1	2017-07-10 00:55:00+03	46400.00
229A08	2017-07-28 09:53:00+03	26000.00
229A64	2017-08-05 01:05:00+03	78300.00
229AA8	2017-07-26 17:37:00+03	111600.00
229AE7	2017-07-13 19:11:00+03	56000.00
229AFC	2017-07-18 03:11:00+03	167800.00
229B2E	2017-07-24 20:33:00+03	86300.00
229B43	2017-07-17 06:05:00+03	23200.00
229B5A	2017-08-09 01:36:00+03	92000.00
229B93	2017-07-15 19:49:00+03	266400.00
229BF6	2017-08-09 05:41:00+03	68800.00
229C3D	2017-07-12 05:26:00+03	28800.00
229CB5	2017-07-07 14:35:00+03	44500.00
229CBB	2017-08-04 10:33:00+03	105000.00
229CCA	2017-07-17 15:00:00+03	65500.00
229CFA	2017-07-10 14:11:00+03	246000.00
229D41	2017-07-23 12:14:00+03	97900.00
229D4F	2017-07-31 07:44:00+03	53600.00
229D55	2017-08-06 02:27:00+03	62900.00
229DF7	2017-08-07 05:10:00+03	26000.00
229E15	2017-07-22 05:24:00+03	121800.00
229E64	2017-07-27 08:52:00+03	61200.00
229F2B	2017-07-23 11:05:00+03	26800.00
229F4F	2017-08-02 21:41:00+03	75000.00
229F58	2017-07-06 23:16:00+03	88900.00
229F6C	2017-08-03 09:50:00+03	28900.00
229F74	2017-07-28 04:03:00+03	133700.00
229F8F	2017-07-30 07:46:00+03	65900.00
229F9D	2017-07-28 23:13:00+03	67200.00
229FBB	2017-07-26 18:26:00+03	96800.00
229FCB	2017-07-10 11:44:00+03	36600.00
229FFA	2017-08-08 19:48:00+03	87700.00
22A02F	2017-08-09 19:54:00+03	23400.00
22A12D	2017-07-29 05:22:00+03	38800.00
22A155	2017-07-09 23:08:00+03	54400.00
22A1A8	2017-07-20 04:10:00+03	396000.00
22A1C3	2017-07-11 01:35:00+03	115100.00
22A1DE	2017-08-10 00:10:00+03	270800.00
22A1DF	2017-07-19 09:58:00+03	101000.00
22A1F1	2017-08-04 12:59:00+03	14400.00
22A23D	2017-07-02 16:19:00+03	13400.00
22A2A0	2017-07-12 17:07:00+03	64700.00
22A2DB	2017-07-02 22:42:00+03	58800.00
22A2E8	2017-07-31 06:42:00+03	133200.00
22A30F	2017-07-02 03:09:00+03	55400.00
22A330	2017-07-19 07:53:00+03	46000.00
22A377	2017-07-03 11:00:00+03	85700.00
22A3A0	2017-07-06 23:09:00+03	56000.00
22A3B0	2017-07-02 06:54:00+03	23200.00
22A3E8	2017-07-23 07:57:00+03	531300.00
22A3FB	2017-07-11 08:55:00+03	64700.00
22A4DB	2017-07-04 13:15:00+03	52800.00
22A515	2017-07-07 02:29:00+03	273600.00
22A542	2017-08-03 16:23:00+03	85700.00
22A59E	2017-07-03 19:58:00+03	133100.00
22A5B7	2017-07-26 12:42:00+03	14800.00
22A5D6	2017-07-09 05:09:00+03	59900.00
22A60B	2017-07-02 08:14:00+03	16400.00
22A60D	2017-07-17 13:38:00+03	61900.00
22A60E	2017-08-12 21:56:00+03	169300.00
22A628	2017-06-27 08:20:00+03	130900.00
22A641	2017-08-03 20:43:00+03	58900.00
22A6BA	2017-07-23 04:14:00+03	19600.00
22A6F7	2017-08-08 18:52:00+03	67200.00
22A720	2017-07-09 03:23:00+03	81600.00
22A734	2017-07-21 01:28:00+03	34000.00
22A73D	2017-08-07 13:11:00+03	72400.00
22A74A	2017-07-05 14:26:00+03	96500.00
22A77A	2017-07-31 06:00:00+03	16400.00
22A7CC	2017-07-04 11:05:00+03	41800.00
22A83D	2017-07-02 04:34:00+03	24400.00
22A852	2017-07-28 09:57:00+03	13400.00
22A8A0	2017-07-19 19:51:00+03	35200.00
22A8CE	2017-07-12 05:04:00+03	98300.00
22A90F	2017-07-23 16:27:00+03	203600.00
22A952	2017-07-06 11:04:00+03	114300.00
22A999	2017-07-10 13:04:00+03	44800.00
22A9A8	2017-07-29 18:55:00+03	125200.00
22A9CC	2017-07-20 22:04:00+03	26000.00
22A9EE	2017-07-08 11:39:00+03	21200.00
22AA11	2017-07-25 03:37:00+03	21800.00
22AABE	2017-07-15 12:05:00+03	46000.00
22AB8C	2017-08-05 11:18:00+03	19300.00
22ABCC	2017-07-18 03:27:00+03	28800.00
22ABF1	2017-07-18 09:46:00+03	309300.00
22AC42	2017-07-24 10:28:00+03	132800.00
22AC6D	2017-06-29 06:59:00+03	112000.00
22AD20	2017-07-22 05:16:00+03	26800.00
22AD48	2017-08-02 09:04:00+03	12600.00
22AD65	2017-07-15 17:35:00+03	46200.00
22AD7B	2017-07-11 07:09:00+03	78200.00
22AD8B	2017-07-27 01:58:00+03	21200.00
22ADCA	2017-07-29 14:56:00+03	112400.00
22ADE3	2017-07-31 02:59:00+03	28800.00
22AE30	2017-08-14 20:25:00+03	91100.00
22AE40	2017-08-14 18:06:00+03	52700.00
22AE48	2017-07-07 01:42:00+03	64700.00
22AEB5	2017-08-15 16:36:00+03	13900.00
22AF4E	2017-07-24 22:16:00+03	75300.00
22AF8A	2017-07-09 16:39:00+03	77200.00
22AFBD	2017-07-07 13:45:00+03	101100.00
22AFDF	2017-07-29 22:47:00+03	399600.00
22AFEE	2017-07-28 03:08:00+03	289800.00
22AFF1	2017-07-20 10:54:00+03	135400.00
22AFF9	2017-07-06 20:16:00+03	167900.00
22AFFD	2017-07-17 20:28:00+03	89600.00
22B01E	2017-07-09 23:14:00+03	52100.00
22B03D	2017-07-29 17:55:00+03	93200.00
22B054	2017-07-16 18:21:00+03	238300.00
22B080	2017-07-19 21:52:00+03	66400.00
22B082	2017-06-30 21:22:00+03	306200.00
22B093	2017-08-09 08:14:00+03	135200.00
22B0A5	2017-07-09 10:22:00+03	60400.00
22B0AC	2017-07-21 12:48:00+03	40000.00
22B10C	2017-08-12 10:29:00+03	100600.00
22B1F3	2017-07-22 19:30:00+03	176400.00
22B240	2017-07-26 15:29:00+03	21800.00
22B241	2017-08-01 17:18:00+03	26000.00
22B29C	2017-07-18 02:21:00+03	112000.00
22B2BA	2017-07-16 03:15:00+03	40900.00
22B2CE	2017-07-29 14:02:00+03	156200.00
22B309	2017-07-01 20:11:00+03	206800.00
22B35C	2017-07-21 00:55:00+03	123000.00
22B35D	2017-07-10 09:20:00+03	52800.00
22B38B	2017-07-21 11:05:00+03	78000.00
22B409	2017-07-04 23:26:00+03	51900.00
22B43B	2017-08-11 17:31:00+03	24400.00
22B4B8	2017-07-12 20:56:00+03	16400.00
22B4C6	2017-06-30 06:05:00+03	21200.00
22B4FD	2017-07-24 17:15:00+03	27600.00
22B521	2017-07-19 09:23:00+03	14000.00
22B59F	2017-07-28 10:34:00+03	68100.00
22B5CE	2017-07-05 22:48:00+03	123000.00
22B5D9	2017-06-29 11:42:00+03	97900.00
22B60E	2017-07-05 03:26:00+03	81200.00
22B61D	2017-06-23 02:35:00+03	111800.00
22B62D	2017-07-23 06:11:00+03	112600.00
22B6DF	2017-07-26 18:49:00+03	53400.00
22B6F5	2017-07-03 20:12:00+03	101500.00
22B707	2017-07-22 10:15:00+03	118100.00
22B729	2017-07-15 08:36:00+03	48800.00
22B765	2017-08-02 13:32:00+03	172200.00
22B778	2017-07-06 11:14:00+03	57500.00
22B79C	2017-07-21 23:35:00+03	20100.00
22B7AE	2017-08-04 03:45:00+03	437100.00
22B7BC	2017-07-10 06:36:00+03	83400.00
22B800	2017-07-01 08:56:00+03	96200.00
22B80D	2017-07-11 21:21:00+03	7400.00
22B826	2017-07-14 10:48:00+03	10800.00
22B866	2017-08-05 12:46:00+03	45200.00
22B869	2017-08-06 23:53:00+03	46200.00
22B8B5	2017-08-06 10:24:00+03	48100.00
22B947	2017-08-03 13:43:00+03	6700.00
22B995	2017-07-12 11:03:00+03	46400.00
22BA10	2017-07-01 12:43:00+03	23600.00
22BA12	2017-08-09 22:48:00+03	46300.00
22BB07	2017-07-27 07:15:00+03	88600.00
22BB2D	2017-08-05 21:47:00+03	67600.00
22BB7D	2017-08-08 22:55:00+03	323800.00
22BB8B	2017-08-02 16:44:00+03	28800.00
22BBC4	2017-07-31 20:45:00+03	24400.00
22BC75	2017-08-10 07:17:00+03	271100.00
22BC76	2017-08-03 13:21:00+03	112000.00
22BC7F	2017-07-22 01:50:00+03	125400.00
22BCB4	2017-07-29 19:01:00+03	125400.00
22BCBF	2017-07-15 04:51:00+03	44600.00
22BD4C	2017-08-14 18:42:00+03	65400.00
22BD67	2017-08-02 20:18:00+03	112000.00
22BD7F	2017-08-09 10:28:00+03	81200.00
22BD86	2017-07-03 00:36:00+03	137800.00
22BDB4	2017-08-03 22:15:00+03	8400.00
22BDBB	2017-07-23 12:53:00+03	66600.00
22BDC1	2017-07-14 10:03:00+03	123000.00
22BDC2	2017-08-01 19:39:00+03	211800.00
22BDE1	2017-07-23 14:39:00+03	30000.00
22BE21	2017-07-28 19:15:00+03	66000.00
22BE67	2017-07-24 14:29:00+03	25100.00
22BE7A	2017-08-14 11:35:00+03	15000.00
22BF06	2017-07-07 15:27:00+03	26000.00
22BFA7	2017-08-14 05:49:00+03	45100.00
22C02F	2017-07-10 03:57:00+03	28000.00
22C03F	2017-07-19 05:25:00+03	111600.00
22C062	2017-07-11 15:21:00+03	26600.00
22C07F	2017-08-10 11:17:00+03	66600.00
22C0BA	2017-07-01 12:22:00+03	109800.00
22C13F	2017-07-25 09:28:00+03	52000.00
22C185	2017-07-08 12:33:00+03	123000.00
22C1B0	2017-08-12 00:24:00+03	26200.00
22C209	2017-07-17 01:50:00+03	27200.00
22C2C4	2017-07-02 13:26:00+03	70200.00
22C3EB	2017-07-29 11:09:00+03	135600.00
22C431	2017-07-17 00:42:00+03	22000.00
22C451	2017-07-15 18:29:00+03	64800.00
22C49E	2017-07-27 05:30:00+03	174500.00
22C55C	2017-07-11 04:29:00+03	12600.00
22C5A9	2017-08-01 07:20:00+03	100600.00
22C5C2	2017-07-09 06:28:00+03	7800.00
22C672	2017-07-15 21:31:00+03	22000.00
22C6D2	2017-07-02 21:51:00+03	15400.00
22C6DD	2017-07-20 18:22:00+03	74800.00
22C6E2	2017-07-07 09:32:00+03	52700.00
22C725	2017-07-15 18:52:00+03	193200.00
22C79D	2017-06-29 08:56:00+03	88500.00
22C7C3	2017-07-09 03:04:00+03	13200.00
22C7C6	2017-06-30 07:33:00+03	28600.00
22C7DD	2017-07-14 12:51:00+03	40800.00
22C84B	2017-07-11 01:48:00+03	69500.00
22C8E1	2017-08-02 18:05:00+03	20200.00
22C8FE	2017-08-04 21:53:00+03	62000.00
22C95A	2017-07-17 17:59:00+03	54800.00
22C9A6	2017-07-18 07:59:00+03	92800.00
22C9B7	2017-07-26 19:52:00+03	25800.00
22C9C4	2017-07-10 21:41:00+03	168000.00
22C9CD	2017-07-25 15:20:00+03	58200.00
22C9FD	2017-07-08 13:58:00+03	115100.00
22CA10	2017-06-29 11:22:00+03	23100.00
22CA2C	2017-08-13 15:24:00+03	54500.00
22CA47	2017-07-28 17:38:00+03	14400.00
22CACA	2017-08-01 22:15:00+03	380800.00
22CB0D	2017-07-24 23:05:00+03	111700.00
22CB6E	2017-08-12 21:43:00+03	266400.00
22CB77	2017-08-05 07:33:00+03	117600.00
22CB85	2017-08-02 16:42:00+03	178000.00
22CC2E	2017-07-15 21:54:00+03	125400.00
22CC36	2017-08-08 13:15:00+03	16400.00
22CC99	2017-07-20 06:11:00+03	51300.00
22CCAE	2017-07-09 13:42:00+03	23400.00
22CCB2	2017-07-02 17:52:00+03	133200.00
22CCDC	2017-08-01 00:14:00+03	150800.00
22CD54	2017-07-24 08:32:00+03	73300.00
22CD57	2017-07-17 01:24:00+03	133100.00
22CD61	2017-08-08 08:51:00+03	59300.00
22CE64	2017-07-06 23:19:00+03	89700.00
22CED3	2017-07-21 16:05:00+03	48700.00
22CEE3	2017-07-26 08:58:00+03	68800.00
22CF96	2017-08-03 17:35:00+03	27300.00
22D04D	2017-08-07 14:41:00+03	6000.00
22D057	2017-08-01 23:39:00+03	111600.00
22D0B5	2017-08-01 23:00:00+03	45200.00
22D0B9	2017-08-14 12:21:00+03	83000.00
22D0E9	2017-08-06 15:50:00+03	19600.00
22D199	2017-07-18 00:34:00+03	26000.00
22D1C8	2017-08-02 03:04:00+03	56600.00
22D1D9	2017-07-24 18:03:00+03	26000.00
22D1F4	2017-08-08 17:16:00+03	28800.00
22D20C	2017-07-08 20:35:00+03	81200.00
22D243	2017-08-12 13:45:00+03	48400.00
22D272	2017-07-22 13:29:00+03	39800.00
22D298	2017-07-18 05:47:00+03	34000.00
22D2AF	2017-07-13 11:35:00+03	155600.00
22D2CB	2017-07-24 21:19:00+03	60800.00
22D325	2017-07-14 16:57:00+03	56900.00
22D32A	2017-07-09 06:07:00+03	40800.00
22D332	2017-08-11 06:57:00+03	93800.00
22D3DF	2017-08-03 19:56:00+03	23600.00
22D3E6	2017-08-07 06:31:00+03	141200.00
22D4A4	2017-07-08 08:01:00+03	8400.00
22D509	2017-08-13 00:37:00+03	23200.00
22D50B	2017-07-08 09:11:00+03	64500.00
22D51B	2017-08-08 13:10:00+03	99200.00
22D565	2017-08-07 20:04:00+03	40800.00
22D577	2017-08-15 03:53:00+03	21400.00
22D59B	2017-07-19 08:55:00+03	44700.00
22D5A6	2017-07-12 02:55:00+03	189100.00
22D627	2017-08-11 04:52:00+03	49600.00
22D651	2017-07-31 13:16:00+03	199700.00
22D669	2017-07-25 20:38:00+03	133200.00
22D670	2017-07-18 10:46:00+03	46400.00
22D689	2017-06-29 03:38:00+03	86600.00
22D703	2017-08-02 22:35:00+03	56000.00
22D75D	2017-08-03 19:08:00+03	98400.00
22D76C	2017-07-19 15:54:00+03	17200.00
22D77A	2017-08-09 08:59:00+03	46500.00
22D7BC	2017-08-12 05:51:00+03	26800.00
22D893	2017-07-06 13:55:00+03	38400.00
22D896	2017-07-22 18:45:00+03	35200.00
22D8DE	2017-07-29 22:47:00+03	39300.00
22D92E	2017-07-24 19:47:00+03	87400.00
22D950	2017-07-22 10:29:00+03	77200.00
22D960	2017-07-13 07:21:00+03	19600.00
22D961	2017-07-10 17:34:00+03	176800.00
22D963	2017-08-14 12:35:00+03	27900.00
22D97F	2017-07-16 02:22:00+03	37500.00
22D9BC	2017-07-17 03:08:00+03	42600.00
22D9D5	2017-08-03 10:37:00+03	124000.00
22D9E3	2017-07-13 16:18:00+03	43500.00
22D9EA	2017-08-11 23:28:00+03	76600.00
22D9EC	2017-07-16 09:31:00+03	160200.00
22DA5F	2017-08-07 18:54:00+03	22000.00
22DB51	2017-08-06 06:16:00+03	123000.00
22DB56	2017-06-30 21:20:00+03	47100.00
22DB62	2017-07-26 12:04:00+03	133600.00
22DBE4	2017-08-11 02:27:00+03	54000.00
22DBF3	2017-07-16 01:58:00+03	55800.00
22DBF5	2017-08-03 06:26:00+03	173500.00
22DC35	2017-07-07 09:01:00+03	123200.00
22DCAA	2017-08-08 15:02:00+03	117000.00
22DCE8	2017-07-23 08:29:00+03	119500.00
22DD3D	2017-07-19 18:26:00+03	11600.00
22DD48	2017-08-06 22:37:00+03	32900.00
22DD54	2017-07-15 04:55:00+03	132500.00
22DD70	2017-08-13 20:26:00+03	299200.00
22DD77	2017-07-21 15:53:00+03	214900.00
22DD7C	2017-07-06 07:05:00+03	87200.00
22DD8E	2017-08-10 15:35:00+03	95300.00
22DDCE	2017-07-27 06:46:00+03	58500.00
22DE1D	2017-07-25 00:45:00+03	75600.00
22DE42	2017-07-11 09:57:00+03	60600.00
22DE9F	2017-07-19 16:06:00+03	94200.00
22DF2D	2017-07-14 01:08:00+03	63200.00
22DF3F	2017-07-17 15:04:00+03	68800.00
22DF98	2017-08-14 04:33:00+03	71900.00
22DFA2	2017-07-09 02:55:00+03	139200.00
22DFA3	2017-07-14 18:41:00+03	45500.00
22DFE9	2017-07-06 02:42:00+03	119300.00
22E16C	2017-07-25 12:14:00+03	23600.00
22E19A	2017-07-18 02:25:00+03	28000.00
22E1B1	2017-08-02 18:35:00+03	14400.00
22E1BC	2017-08-13 23:55:00+03	110500.00
22E1CA	2017-07-16 20:17:00+03	147800.00
22E1D0	2017-07-07 04:21:00+03	73600.00
22E1D5	2017-08-07 14:41:00+03	450300.00
22E204	2017-08-07 05:58:00+03	28000.00
22E214	2017-07-21 02:38:00+03	25400.00
22E22A	2017-07-27 18:22:00+03	114800.00
22E247	2017-08-12 15:40:00+03	123000.00
22E2B8	2017-07-12 19:19:00+03	55800.00
22E319	2017-07-28 18:12:00+03	13400.00
22E3C9	2017-08-05 11:54:00+03	26000.00
22E3CB	2017-08-04 05:29:00+03	22000.00
22E3FA	2017-07-15 22:11:00+03	76400.00
22E502	2017-07-08 02:50:00+03	102800.00
22E57D	2017-07-03 20:37:00+03	89600.00
22E5A2	2017-07-31 21:22:00+03	63700.00
22E5CB	2017-08-11 14:36:00+03	46200.00
22E5D7	2017-06-30 22:39:00+03	34800.00
22E60E	2017-08-06 23:35:00+03	55800.00
22E611	2017-07-31 01:20:00+03	12600.00
22E61A	2017-07-24 14:34:00+03	29600.00
22E643	2017-07-20 03:46:00+03	17800.00
22E66D	2017-08-04 03:09:00+03	75300.00
22E697	2017-08-11 00:56:00+03	14400.00
22E75D	2017-07-18 03:20:00+03	70700.00
22E768	2017-08-14 03:20:00+03	206400.00
22E773	2017-08-07 13:49:00+03	31600.00
22E790	2017-08-06 15:41:00+03	49800.00
22E7EA	2017-07-23 13:47:00+03	116700.00
22E820	2017-07-23 19:03:00+03	21800.00
22E8BC	2017-07-16 11:15:00+03	34000.00
22E8CE	2017-08-07 01:00:00+03	67900.00
22E970	2017-08-09 22:44:00+03	101200.00
22E9A0	2017-08-06 02:55:00+03	43100.00
22E9A2	2017-08-06 10:47:00+03	32700.00
22E9A3	2017-07-16 06:26:00+03	67500.00
22E9B9	2017-07-27 10:03:00+03	21400.00
22EB2E	2017-08-10 03:52:00+03	47000.00
22EB41	2017-07-24 05:46:00+03	47400.00
22EB4B	2017-08-07 11:55:00+03	109800.00
22EBA4	2017-07-15 05:43:00+03	258400.00
22EBE8	2017-07-29 21:54:00+03	37200.00
22EC26	2017-07-04 08:11:00+03	49100.00
22EC4A	2017-08-06 23:45:00+03	67200.00
22EC9D	2017-08-05 19:26:00+03	60900.00
22ECA1	2017-08-07 10:39:00+03	29600.00
22ECA8	2017-07-12 00:56:00+03	85000.00
22ECB2	2017-08-15 13:24:00+03	141300.00
22ECBA	2017-07-01 20:00:00+03	28800.00
22ED2F	2017-06-27 01:27:00+03	55800.00
22ED87	2017-08-03 07:05:00+03	62600.00
22EDB2	2017-07-26 12:39:00+03	35600.00
22EE34	2017-07-17 08:33:00+03	82900.00
22EE4B	2017-07-13 18:32:00+03	40600.00
22EE57	2017-07-14 22:02:00+03	46400.00
22EE5F	2017-07-19 07:54:00+03	21400.00
22EE68	2017-07-23 07:30:00+03	28000.00
22EEA7	2017-07-21 22:18:00+03	98400.00
22EEB3	2017-07-07 07:33:00+03	79900.00
22EEED	2017-06-28 23:31:00+03	23200.00
22EF97	2017-07-14 21:53:00+03	31400.00
22EFEE	2017-08-06 16:00:00+03	64800.00
22EFEF	2017-07-31 02:58:00+03	110500.00
22F0AB	2017-08-09 13:47:00+03	32100.00
22F0D0	2017-08-11 14:02:00+03	119500.00
22F15F	2017-07-18 02:57:00+03	37200.00
22F1F3	2017-08-04 20:25:00+03	35200.00
22F256	2017-07-06 00:49:00+03	143900.00
22F262	2017-07-12 06:31:00+03	40400.00
22F32E	2017-07-14 10:01:00+03	136800.00
22F39A	2017-08-09 23:29:00+03	92800.00
22F3B1	2017-07-08 17:23:00+03	57800.00
22F3D6	2017-08-01 22:24:00+03	73500.00
22F416	2017-07-12 19:36:00+03	34000.00
22F460	2017-08-09 04:55:00+03	12600.00
22F475	2017-07-12 09:00:00+03	108000.00
22F47C	2017-08-03 07:19:00+03	10700.00
22F48C	2017-07-15 15:28:00+03	88500.00
22F4BA	2017-08-02 22:43:00+03	27900.00
22F51F	2017-07-06 21:27:00+03	38800.00
22F547	2017-07-19 17:21:00+03	56900.00
22F581	2017-08-09 13:20:00+03	28000.00
22F5B1	2017-08-08 14:20:00+03	46200.00
22F638	2017-08-02 10:34:00+03	130900.00
22F6D4	2017-07-06 17:39:00+03	85700.00
22F727	2017-08-13 22:47:00+03	21500.00
22F750	2017-08-08 21:41:00+03	666900.00
22F77D	2017-07-15 14:12:00+03	6700.00
22F780	2017-07-10 09:56:00+03	48500.00
22F781	2017-07-05 09:40:00+03	58900.00
22F78E	2017-07-18 19:54:00+03	28800.00
22F832	2017-07-10 17:13:00+03	99300.00
22F88E	2017-08-05 15:13:00+03	72400.00
22F8FE	2017-08-06 03:52:00+03	100500.00
22F906	2017-07-24 12:35:00+03	56000.00
22F948	2017-07-11 11:09:00+03	14000.00
22F962	2017-07-27 11:41:00+03	65900.00
22F96A	2017-07-02 16:42:00+03	171700.00
22F97F	2017-07-23 14:37:00+03	56000.00
22FA7B	2017-07-01 01:15:00+03	82700.00
22FA7C	2017-07-04 22:47:00+03	54500.00
22FA88	2017-07-22 03:38:00+03	133200.00
22FA91	2017-07-17 14:26:00+03	66600.00
22FAB9	2017-07-13 12:31:00+03	6000.00
22FB31	2017-07-19 19:41:00+03	26000.00
22FB4B	2017-08-08 18:09:00+03	286600.00
22FB9F	2017-08-14 21:56:00+03	12000.00
22FBD6	2017-08-07 13:01:00+03	90800.00
22FBF4	2017-08-05 08:45:00+03	45100.00
22FC1A	2017-07-14 19:27:00+03	100200.00
22FCC5	2017-08-10 16:56:00+03	20200.00
22FD86	2017-07-19 00:39:00+03	28400.00
22FD9E	2017-07-27 18:35:00+03	248500.00
22FDD3	2017-08-14 19:40:00+03	136200.00
22FE6F	2017-07-16 00:53:00+03	3700.00
22FE81	2017-08-02 15:52:00+03	46200.00
22FE8D	2017-07-01 03:31:00+03	24400.00
22FF87	2017-08-03 11:36:00+03	69500.00
22FFB4	2017-08-02 20:21:00+03	20400.00
22FFDF	2017-07-31 14:46:00+03	44000.00
230064	2017-07-06 02:11:00+03	135400.00
230068	2017-08-10 20:26:00+03	8200.00
230077	2017-07-21 09:54:00+03	56000.00
2300CE	2017-07-28 14:49:00+03	44000.00
2300E8	2017-07-04 00:04:00+03	32200.00
230163	2017-07-25 15:07:00+03	8600.00
230165	2017-07-23 04:26:00+03	58800.00
23016E	2017-07-22 05:30:00+03	26700.00
2301BE	2017-07-12 08:06:00+03	332000.00
2301E9	2017-08-02 14:21:00+03	48800.00
23025A	2017-07-12 02:38:00+03	65900.00
230286	2017-07-06 02:43:00+03	31600.00
2302B4	2017-08-14 03:32:00+03	51600.00
2302E5	2017-07-23 11:38:00+03	89700.00
230341	2017-07-05 12:47:00+03	137200.00
230352	2017-07-25 14:54:00+03	155600.00
230376	2017-07-28 23:07:00+03	74800.00
230395	2017-06-29 10:12:00+03	36200.00
2303AC	2017-07-17 22:53:00+03	123600.00
2303F6	2017-08-09 13:49:00+03	14000.00
230405	2017-07-01 22:23:00+03	21400.00
23041B	2017-08-05 03:18:00+03	131100.00
23041C	2017-07-24 03:24:00+03	41200.00
230466	2017-08-14 01:33:00+03	50600.00
23049C	2017-08-04 17:41:00+03	112000.00
2304AC	2017-07-23 22:59:00+03	38800.00
2304C9	2017-07-21 00:06:00+03	36800.00
23056E	2017-07-02 03:18:00+03	37200.00
2305F4	2017-07-16 01:02:00+03	14400.00
230608	2017-08-13 03:10:00+03	16800.00
2306C8	2017-08-05 21:19:00+03	357400.00
2306EF	2017-08-02 00:38:00+03	69500.00
2307BB	2017-07-10 17:20:00+03	47500.00
2307F7	2017-07-14 05:44:00+03	67700.00
23085F	2017-07-13 16:04:00+03	218000.00
2308D5	2017-07-29 08:05:00+03	73300.00
230935	2017-08-04 03:23:00+03	668900.00
230949	2017-08-08 14:14:00+03	126500.00
230964	2017-08-07 23:45:00+03	46200.00
230967	2017-07-30 22:40:00+03	15600.00
23098A	2017-08-08 18:01:00+03	30000.00
23099B	2017-07-16 01:56:00+03	75600.00
2309C2	2017-07-12 07:09:00+03	67600.00
230A5C	2017-08-03 04:13:00+03	58000.00
230A78	2017-07-19 09:39:00+03	78300.00
230AA6	2017-07-08 12:48:00+03	170800.00
230B72	2017-07-27 11:28:00+03	99200.00
230BA8	2017-07-20 20:18:00+03	40800.00
230BAB	2017-08-10 03:17:00+03	189200.00
230C02	2017-07-20 02:31:00+03	135200.00
230C24	2017-08-14 09:16:00+03	89700.00
230C2E	2017-08-05 17:59:00+03	177200.00
230C8E	2017-08-11 19:11:00+03	160400.00
230CE9	2017-07-07 13:33:00+03	64700.00
230D31	2017-07-26 05:05:00+03	47100.00
230D5C	2017-08-07 06:09:00+03	56000.00
230D5F	2017-07-28 23:14:00+03	40100.00
230D87	2017-07-20 19:05:00+03	27200.00
230DAC	2017-08-15 10:54:00+03	6600.00
230E28	2017-07-17 00:15:00+03	36400.00
230EAC	2017-07-16 20:59:00+03	62700.00
230F10	2017-07-23 20:54:00+03	35800.00
230F40	2017-07-13 23:19:00+03	107200.00
230FDE	2017-07-20 18:05:00+03	21800.00
230FF4	2017-08-12 02:35:00+03	133200.00
231003	2017-07-05 13:52:00+03	91100.00
23101F	2017-07-17 13:11:00+03	50200.00
23102E	2017-07-11 04:21:00+03	123000.00
23106B	2017-08-06 01:34:00+03	65900.00
231115	2017-07-14 02:44:00+03	45200.00
231157	2017-07-17 09:01:00+03	93900.00
2311B5	2017-07-24 18:55:00+03	47000.00
2311D7	2017-07-21 07:53:00+03	185700.00
2311EA	2017-06-30 19:18:00+03	216400.00
231205	2017-08-01 15:13:00+03	132100.00
231248	2017-08-03 01:52:00+03	213600.00
23124F	2017-07-30 21:48:00+03	103500.00
231283	2017-07-27 14:25:00+03	52300.00
23129F	2017-07-28 05:59:00+03	106400.00
2312D4	2017-08-04 20:35:00+03	95600.00
231327	2017-07-20 23:47:00+03	136800.00
2314E6	2017-08-05 19:31:00+03	21400.00
231582	2017-07-28 06:25:00+03	21400.00
2315AB	2017-07-04 13:27:00+03	38400.00
2315D2	2017-07-24 23:56:00+03	67400.00
231620	2017-08-10 10:41:00+03	55000.00
23166E	2017-07-10 19:16:00+03	39300.00
2316C8	2017-08-05 13:13:00+03	39300.00
2316CA	2017-07-15 13:45:00+03	121800.00
23170C	2017-07-24 22:15:00+03	43800.00
231773	2017-07-08 22:16:00+03	57600.00
231775	2017-07-30 03:06:00+03	86500.00
23179E	2017-08-12 07:05:00+03	89700.00
2317CD	2017-06-30 12:05:00+03	199700.00
231800	2017-08-14 05:48:00+03	26700.00
23181C	2017-07-26 15:27:00+03	16400.00
231839	2017-08-02 21:06:00+03	53600.00
2318D3	2017-07-05 11:12:00+03	46000.00
2318F3	2017-07-09 08:01:00+03	21400.00
23193E	2017-06-26 20:46:00+03	81800.00
2319F1	2017-07-19 15:03:00+03	28800.00
231A57	2017-07-17 09:04:00+03	43500.00
231A5A	2017-08-08 10:19:00+03	130000.00
231B3E	2017-07-07 04:11:00+03	142400.00
231BC8	2017-07-12 06:36:00+03	55800.00
231C1A	2017-07-14 00:07:00+03	135400.00
231C5E	2017-07-11 06:22:00+03	6300.00
231D0C	2017-07-06 02:22:00+03	133200.00
231D60	2017-07-18 07:30:00+03	31000.00
231E34	2017-08-11 04:58:00+03	439600.00
231E58	2017-08-13 00:57:00+03	110500.00
231EC5	2017-08-01 16:41:00+03	12000.00
231F0E	2017-08-12 22:13:00+03	32800.00
231F1B	2017-07-10 07:24:00+03	140400.00
231F43	2017-07-26 00:10:00+03	43600.00
231F4C	2017-07-14 01:30:00+03	76200.00
231F61	2017-07-03 04:01:00+03	38800.00
231FA5	2017-07-27 08:24:00+03	98800.00
231FD5	2017-08-14 07:09:00+03	46300.00
23200C	2017-08-13 05:39:00+03	12000.00
2320C7	2017-07-17 07:54:00+03	13800.00
23212B	2017-07-06 11:32:00+03	70800.00
232193	2017-08-05 08:30:00+03	27800.00
2321AD	2017-07-12 15:04:00+03	109500.00
23225D	2017-07-21 19:35:00+03	12400.00
232260	2017-07-29 22:43:00+03	77600.00
232264	2017-08-13 22:40:00+03	67800.00
232277	2017-07-17 05:46:00+03	46400.00
232287	2017-07-16 08:38:00+03	677800.00
2322B6	2017-07-10 04:56:00+03	89800.00
2322D9	2017-08-11 04:54:00+03	136100.00
232371	2017-07-05 13:19:00+03	55800.00
232372	2017-08-03 23:29:00+03	12600.00
2323B7	2017-06-29 06:26:00+03	64800.00
232495	2017-07-31 14:11:00+03	44000.00
2324FA	2017-07-30 03:32:00+03	30400.00
23250D	2017-08-01 12:39:00+03	65300.00
232515	2017-07-27 16:27:00+03	6300.00
23255F	2017-07-31 11:53:00+03	258400.00
2325A7	2017-08-10 13:35:00+03	67100.00
2325CF	2017-08-11 14:49:00+03	26000.00
23260B	2017-08-08 08:35:00+03	42800.00
232618	2017-06-30 19:12:00+03	59800.00
23264A	2017-07-07 18:35:00+03	23400.00
232687	2017-08-09 21:48:00+03	11000.00
23268A	2017-07-14 05:49:00+03	399600.00
232695	2017-07-21 03:20:00+03	15000.00
2326B4	2017-07-11 15:09:00+03	46400.00
2326B6	2017-07-20 10:02:00+03	29600.00
2326CE	2017-07-04 12:36:00+03	62800.00
2326E9	2017-07-24 16:02:00+03	155600.00
23270B	2017-07-26 17:11:00+03	116000.00
23270D	2017-08-08 10:14:00+03	6700.00
232769	2017-08-12 23:27:00+03	6700.00
232788	2017-07-19 03:34:00+03	6200.00
2327D8	2017-08-03 15:48:00+03	15100.00
232844	2017-07-22 19:42:00+03	108900.00
232854	2017-07-25 19:21:00+03	40600.00
232923	2017-07-20 08:45:00+03	73600.00
232930	2017-07-06 06:30:00+03	28000.00
23294F	2017-07-26 09:28:00+03	37200.00
232955	2017-07-19 02:03:00+03	334700.00
23298D	2017-07-10 16:01:00+03	187600.00
2329C6	2017-07-08 18:13:00+03	51900.00
232A10	2017-07-27 03:47:00+03	156500.00
232A50	2017-08-05 17:25:00+03	226200.00
232A5C	2017-08-06 23:37:00+03	31600.00
232A85	2017-07-01 02:41:00+03	37900.00
232A94	2017-07-17 16:31:00+03	42400.00
232AC0	2017-08-09 07:16:00+03	28000.00
232AC4	2017-07-04 13:04:00+03	16300.00
232ADB	2017-07-18 11:14:00+03	46000.00
232AE7	2017-08-13 12:35:00+03	18000.00
232BB2	2017-07-06 17:25:00+03	16400.00
232BC9	2017-07-02 15:28:00+03	67000.00
232BF9	2017-07-07 09:43:00+03	99700.00
232C04	2017-08-02 13:37:00+03	270800.00
232C25	2017-08-03 19:58:00+03	95200.00
232C29	2017-07-12 06:51:00+03	42700.00
232C75	2017-07-20 08:19:00+03	14800.00
232C9B	2017-07-30 18:12:00+03	8400.00
232C9E	2017-07-27 03:27:00+03	45400.00
232CA9	2017-07-10 19:01:00+03	28000.00
232D7C	2017-07-31 11:55:00+03	36400.00
232DB9	2017-07-30 12:19:00+03	265800.00
232DD3	2017-07-16 11:03:00+03	44000.00
232E4C	2017-08-04 10:45:00+03	39500.00
232E7A	2017-07-03 12:18:00+03	39500.00
232E9D	2017-07-14 11:39:00+03	233800.00
232F75	2017-07-10 15:34:00+03	30200.00
232F7D	2017-06-30 11:51:00+03	6000.00
232F85	2017-07-31 16:50:00+03	17200.00
232F9C	2017-07-05 21:02:00+03	86400.00
232FC3	2017-07-11 22:21:00+03	22000.00
232FFA	2017-07-18 00:36:00+03	80700.00
233007	2017-08-03 21:07:00+03	97900.00
23300B	2017-08-15 04:12:00+03	92400.00
233012	2017-07-05 07:34:00+03	47200.00
233019	2017-07-25 12:09:00+03	67900.00
23301A	2017-07-05 18:12:00+03	93600.00
233053	2017-08-10 05:55:00+03	133200.00
23308F	2017-07-07 23:16:00+03	67600.00
2330CC	2017-07-29 02:18:00+03	28700.00
2330EE	2017-08-14 03:02:00+03	46400.00
2330EF	2017-08-13 11:46:00+03	31300.00
233157	2017-07-28 04:25:00+03	58200.00
23318E	2017-08-06 12:05:00+03	36500.00
2331C2	2017-07-17 11:46:00+03	30400.00
2331C9	2017-07-31 04:14:00+03	28000.00
2331D1	2017-08-09 11:10:00+03	83100.00
233224	2017-07-21 07:13:00+03	85600.00
23324C	2017-08-12 16:08:00+03	20400.00
2332F8	2017-07-07 08:10:00+03	73600.00
233305	2017-07-27 20:42:00+03	51900.00
233350	2017-07-30 01:32:00+03	81600.00
233361	2017-07-17 00:32:00+03	15400.00
23336C	2017-07-03 15:58:00+03	24700.00
23338A	2017-07-03 09:06:00+03	26000.00
23342A	2017-07-05 07:53:00+03	238600.00
233442	2017-07-05 13:08:00+03	44600.00
233449	2017-07-25 03:00:00+03	6700.00
2334AB	2017-07-03 08:02:00+03	65900.00
2334EC	2017-07-26 03:05:00+03	62700.00
2334F9	2017-07-14 05:56:00+03	53300.00
2334FC	2017-07-09 15:37:00+03	88600.00
233526	2017-07-02 11:50:00+03	76800.00
23352A	2017-07-28 21:02:00+03	77200.00
233535	2017-08-11 07:40:00+03	34000.00
23354C	2017-07-02 22:32:00+03	23200.00
2335F1	2017-07-31 00:03:00+03	28800.00
2335FD	2017-08-06 20:40:00+03	87100.00
233624	2017-08-05 09:36:00+03	38600.00
233638	2017-07-07 13:08:00+03	23600.00
233656	2017-08-10 08:44:00+03	27200.00
23369F	2017-08-12 06:26:00+03	38800.00
2336B9	2017-07-17 15:09:00+03	76300.00
233703	2017-07-02 10:47:00+03	26700.00
233716	2017-07-24 10:11:00+03	479700.00
233717	2017-07-11 11:22:00+03	60400.00
233780	2017-07-20 09:29:00+03	271400.00
233789	2017-08-09 08:47:00+03	137800.00
2337C3	2017-08-02 19:31:00+03	8000.00
233816	2017-07-17 04:34:00+03	152900.00
2338CE	2017-08-10 19:06:00+03	76600.00
233910	2017-07-05 23:13:00+03	68100.00
23394D	2017-08-14 19:39:00+03	44000.00
2339B9	2017-07-23 20:53:00+03	23200.00
2339E5	2017-07-09 07:07:00+03	47200.00
2339EB	2017-07-14 04:29:00+03	187600.00
233A9E	2017-08-13 23:32:00+03	62300.00
233AA4	2017-07-13 07:30:00+03	37900.00
233B13	2017-07-28 14:46:00+03	124200.00
233B26	2017-08-08 11:25:00+03	105000.00
233B96	2017-07-28 11:11:00+03	21200.00
233B9B	2017-07-13 23:30:00+03	85000.00
233BA3	2017-07-08 21:27:00+03	406600.00
233BEE	2017-08-08 00:05:00+03	97000.00
233D09	2017-07-03 16:26:00+03	134600.00
233D50	2017-08-08 02:41:00+03	226200.00
233D59	2017-08-09 14:44:00+03	185300.00
233D7F	2017-07-03 19:00:00+03	241400.00
233E78	2017-07-11 18:55:00+03	27200.00
233EBB	2017-08-06 07:30:00+03	57500.00
233EC6	2017-08-07 20:19:00+03	231300.00
233ECB	2017-08-10 02:02:00+03	274000.00
233ED2	2017-07-21 01:56:00+03	213800.00
233ED6	2017-08-15 03:49:00+03	21600.00
233F16	2017-07-24 23:39:00+03	48700.00
233F68	2017-08-02 19:01:00+03	16400.00
233FFD	2017-08-01 18:19:00+03	15100.00
234050	2017-07-01 12:38:00+03	38600.00
234084	2017-08-02 09:51:00+03	15000.00
2340EB	2017-07-20 16:07:00+03	93400.00
234111	2017-07-12 02:14:00+03	96300.00
2341F4	2017-07-24 19:22:00+03	65900.00
234278	2017-08-08 10:46:00+03	100600.00
23430F	2017-08-01 15:33:00+03	39200.00
23431C	2017-08-08 18:48:00+03	16800.00
234320	2017-08-03 07:51:00+03	27300.00
23432E	2017-07-15 14:38:00+03	140900.00
23437C	2017-07-23 23:11:00+03	33800.00
2343A2	2017-07-28 04:11:00+03	64300.00
234428	2017-07-30 15:06:00+03	66600.00
23446A	2017-08-11 07:33:00+03	32700.00
234471	2017-08-10 23:47:00+03	44500.00
2344FD	2017-08-09 07:46:00+03	46400.00
2345AE	2017-06-29 03:29:00+03	36200.00
2345C7	2017-07-15 07:16:00+03	26000.00
2345DE	2017-07-08 21:03:00+03	33400.00
234611	2017-06-30 23:09:00+03	61900.00
234664	2017-07-19 09:46:00+03	27200.00
234680	2017-07-20 05:15:00+03	27800.00
2346B5	2017-08-05 11:06:00+03	58600.00
234717	2017-08-14 22:46:00+03	30400.00
23472B	2017-06-30 08:11:00+03	88900.00
23473C	2017-08-14 09:57:00+03	100000.00
234758	2017-07-28 17:30:00+03	6000.00
2347F4	2017-08-13 01:43:00+03	59800.00
234831	2017-07-26 05:40:00+03	6700.00
234836	2017-08-12 14:06:00+03	18800.00
234875	2017-07-11 21:34:00+03	25900.00
234888	2017-08-11 16:19:00+03	109600.00
2348A5	2017-06-30 15:11:00+03	70600.00
2348DF	2017-07-29 10:06:00+03	29600.00
234917	2017-07-16 18:27:00+03	132800.00
234952	2017-07-04 02:24:00+03	111600.00
23497A	2017-07-18 23:46:00+03	24800.00
234983	2017-07-19 13:50:00+03	57400.00
2349A0	2017-08-12 10:37:00+03	146700.00
2349A1	2017-07-16 21:29:00+03	7400.00
234A11	2017-08-08 12:17:00+03	66000.00
234A58	2017-06-27 17:44:00+03	38200.00
234ADC	2017-07-19 12:37:00+03	31200.00
234BBB	2017-07-23 05:52:00+03	56000.00
234C4D	2017-07-19 19:23:00+03	14800.00
234C6B	2017-07-22 20:49:00+03	14000.00
234C6D	2017-08-12 16:52:00+03	20400.00
234C77	2017-07-10 12:11:00+03	94000.00
234D69	2017-07-14 14:59:00+03	27900.00
234D74	2017-07-15 07:27:00+03	21600.00
234D85	2017-07-11 09:45:00+03	147700.00
234DCE	2017-07-22 10:13:00+03	21600.00
234DE9	2017-07-23 06:15:00+03	30200.00
234EA2	2017-07-03 20:28:00+03	100600.00
234EDA	2017-07-29 08:56:00+03	56600.00
234F45	2017-07-24 09:30:00+03	14400.00
234F5D	2017-07-31 22:28:00+03	56300.00
234F9C	2017-07-13 08:32:00+03	36000.00
234FA0	2017-08-08 15:53:00+03	54800.00
234FA2	2017-07-21 12:40:00+03	43200.00
234FAA	2017-08-13 19:53:00+03	25800.00
234FDB	2017-06-28 03:07:00+03	21400.00
234FF5	2017-07-17 10:21:00+03	62700.00
235012	2017-08-14 03:57:00+03	112600.00
235017	2017-07-19 04:24:00+03	89700.00
23502C	2017-08-13 03:37:00+03	271400.00
2350FD	2017-07-29 16:33:00+03	86200.00
235103	2017-07-26 01:44:00+03	110200.00
23511D	2017-08-06 02:48:00+03	32800.00
235146	2017-07-17 11:53:00+03	117500.00
235159	2017-07-23 07:17:00+03	26000.00
23523F	2017-07-26 10:33:00+03	201200.00
235263	2017-07-08 15:59:00+03	33300.00
2352F8	2017-08-15 11:56:00+03	79600.00
2352FF	2017-08-13 21:16:00+03	123000.00
23536C	2017-07-23 22:36:00+03	111600.00
235386	2017-08-07 10:44:00+03	31600.00
23539C	2017-06-30 20:16:00+03	166900.00
2353CE	2017-07-11 08:18:00+03	92400.00
2353D1	2017-07-22 18:39:00+03	40000.00
235404	2017-07-18 12:40:00+03	84100.00
235409	2017-07-30 22:31:00+03	496700.00
23543C	2017-08-01 12:54:00+03	25800.00
235493	2017-07-05 13:25:00+03	185800.00
2354A5	2017-07-22 07:35:00+03	100600.00
2354D6	2017-07-20 23:50:00+03	13400.00
2355EE	2017-07-29 08:50:00+03	202400.00
23561E	2017-07-22 13:44:00+03	32800.00
235661	2017-07-31 22:42:00+03	16400.00
235679	2017-08-01 00:54:00+03	46800.00
235799	2017-07-06 09:15:00+03	62700.00
2357A8	2017-07-07 07:59:00+03	39300.00
235872	2017-07-23 05:37:00+03	21400.00
235884	2017-08-06 12:44:00+03	246000.00
2358B5	2017-07-11 13:28:00+03	24400.00
2358EF	2017-08-03 17:28:00+03	211000.00
235958	2017-07-09 06:10:00+03	66000.00
2359A8	2017-07-25 11:21:00+03	50600.00
2359B7	2017-07-06 21:52:00+03	58600.00
235A00	2017-07-08 14:20:00+03	114400.00
235A31	2017-07-29 06:40:00+03	55800.00
235A34	2017-07-20 12:40:00+03	167500.00
235A50	2017-08-12 07:52:00+03	103500.00
235A56	2017-07-30 02:28:00+03	63800.00
235A7B	2017-08-05 17:06:00+03	103500.00
235ADF	2017-08-04 00:53:00+03	79300.00
235B41	2017-07-20 10:44:00+03	114400.00
235BFF	2017-07-20 19:27:00+03	18800.00
235C16	2017-08-11 19:06:00+03	89600.00
235C87	2017-07-10 03:06:00+03	21800.00
235CDA	2017-07-22 02:07:00+03	59200.00
235CF0	2017-08-02 03:47:00+03	12000.00
235CFB	2017-08-13 18:05:00+03	42000.00
235D27	2017-07-24 03:04:00+03	23400.00
235D4B	2017-07-12 19:32:00+03	56000.00
235D8E	2017-07-18 14:22:00+03	76300.00
235D97	2017-07-07 10:28:00+03	28000.00
235DA6	2017-07-28 07:14:00+03	16400.00
235DC0	2017-08-14 09:05:00+03	26800.00
235E10	2017-08-12 18:02:00+03	37700.00
235E1A	2017-08-09 07:00:00+03	112000.00
235E1C	2017-07-18 01:42:00+03	37800.00
235E2C	2017-07-17 07:36:00+03	12600.00
235E2D	2017-07-05 19:03:00+03	25600.00
235E6F	2017-07-02 02:25:00+03	18000.00
235E98	2017-08-14 22:36:00+03	173000.00
235EFC	2017-07-27 23:06:00+03	217600.00
235F60	2017-07-30 21:33:00+03	14400.00
235F7A	2017-07-27 07:28:00+03	12000.00
235F91	2017-07-30 16:00:00+03	110300.00
235FB4	2017-07-23 00:25:00+03	16400.00
23601C	2017-07-28 00:12:00+03	28800.00
236028	2017-08-09 19:20:00+03	325500.00
23602B	2017-08-07 22:02:00+03	14000.00
23604C	2017-08-13 07:44:00+03	34000.00
23608C	2017-07-17 22:23:00+03	187600.00
23608E	2017-06-28 13:06:00+03	23400.00
236090	2017-08-13 04:12:00+03	132800.00
2360CE	2017-08-02 12:15:00+03	398500.00
2360E8	2017-07-24 15:27:00+03	78700.00
2361C4	2017-07-28 06:25:00+03	265600.00
236219	2017-07-13 09:00:00+03	56600.00
236233	2017-07-18 01:15:00+03	7300.00
236245	2017-08-14 09:19:00+03	108500.00
236255	2017-08-12 18:14:00+03	62100.00
23628E	2017-08-05 12:42:00+03	92900.00
2362E3	2017-07-18 21:19:00+03	96400.00
2362F8	2017-07-06 14:19:00+03	80700.00
236315	2017-08-14 02:28:00+03	15400.00
2363A9	2017-08-06 00:11:00+03	73500.00
236412	2017-08-12 08:40:00+03	26300.00
236425	2017-08-09 18:44:00+03	42400.00
236459	2017-07-11 19:58:00+03	42800.00
236480	2017-08-14 05:21:00+03	64700.00
23649E	2017-08-12 04:29:00+03	26200.00
2364BC	2017-07-11 10:12:00+03	99200.00
236533	2017-08-09 05:03:00+03	137600.00
236534	2017-07-02 20:48:00+03	179600.00
23653E	2017-07-20 00:19:00+03	46400.00
2365DE	2017-07-16 22:21:00+03	47600.00
23665E	2017-08-10 11:14:00+03	20400.00
2366AA	2017-07-25 04:03:00+03	76800.00
2366CA	2017-07-31 14:46:00+03	101100.00
236725	2017-07-08 19:40:00+03	85000.00
23672D	2017-06-29 12:12:00+03	10600.00
23673F	2017-07-19 03:59:00+03	65600.00
236796	2017-08-02 08:14:00+03	23200.00
2367A9	2017-08-02 14:39:00+03	23200.00
2367B0	2017-08-05 03:46:00+03	47200.00
2367B9	2017-07-07 17:39:00+03	116700.00
2367D8	2017-07-22 06:47:00+03	77200.00
2367FA	2017-07-12 22:52:00+03	89600.00
2367FF	2017-08-08 07:20:00+03	143300.00
236809	2017-08-15 04:26:00+03	94000.00
23683E	2017-07-06 19:42:00+03	118700.00
236866	2017-07-16 18:43:00+03	38600.00
236890	2017-07-10 12:31:00+03	46400.00
2368CF	2017-07-31 09:57:00+03	49500.00
2369F6	2017-07-08 05:38:00+03	23400.00
236A1F	2017-08-11 14:38:00+03	43900.00
236A36	2017-07-03 09:16:00+03	202300.00
236ADD	2017-08-06 02:19:00+03	42800.00
236B5D	2017-08-11 19:59:00+03	125600.00
236B5F	2017-07-28 10:31:00+03	123000.00
236BCF	2017-08-09 00:07:00+03	64200.00
236BF1	2017-08-13 18:58:00+03	134600.00
236BF6	2017-07-24 19:52:00+03	23400.00
236C03	2017-07-08 18:44:00+03	34600.00
236C38	2017-08-12 22:12:00+03	46400.00
236C76	2017-08-06 11:53:00+03	88500.00
236C94	2017-08-13 04:22:00+03	23600.00
236CA3	2017-07-15 14:18:00+03	131600.00
236CE2	2017-08-10 21:06:00+03	131600.00
236D04	2017-07-21 21:35:00+03	86300.00
236D0F	2017-08-04 03:27:00+03	21800.00
236D31	2017-08-06 07:14:00+03	55800.00
236D42	2017-08-10 11:59:00+03	72800.00
236D9C	2017-07-10 16:29:00+03	49100.00
236DAA	2017-07-05 14:43:00+03	58900.00
236DB9	2017-07-11 00:16:00+03	296400.00
236DCA	2017-08-04 06:14:00+03	52300.00
236E36	2017-07-22 09:38:00+03	57800.00
236E5C	2017-07-06 15:20:00+03	11300.00
236E6A	2017-08-14 19:46:00+03	40000.00
236E96	2017-08-06 17:00:00+03	73600.00
236ED7	2017-07-17 21:08:00+03	67200.00
236F0F	2017-07-27 23:12:00+03	96000.00
237020	2017-08-05 08:44:00+03	135400.00
23706D	2017-08-01 01:57:00+03	59300.00
237138	2017-08-09 21:34:00+03	52900.00
2371E7	2017-07-23 11:32:00+03	6000.00
237233	2017-07-02 06:53:00+03	313100.00
23723E	2017-07-02 22:22:00+03	6000.00
237247	2017-08-05 05:57:00+03	50600.00
237248	2017-07-19 21:47:00+03	157900.00
23725C	2017-07-03 14:50:00+03	75200.00
237263	2017-06-30 22:38:00+03	28000.00
237267	2017-07-07 22:53:00+03	46000.00
2372BF	2017-07-09 04:15:00+03	45200.00
237371	2017-08-03 19:08:00+03	13400.00
237377	2017-07-13 14:55:00+03	34000.00
23740F	2017-08-03 09:23:00+03	10800.00
23750D	2017-08-14 14:07:00+03	33300.00
237538	2017-08-04 23:34:00+03	6300.00
237559	2017-08-03 19:14:00+03	40800.00
2375C6	2017-07-15 16:07:00+03	57800.00
2375E0	2017-08-14 18:05:00+03	115800.00
237647	2017-07-29 00:18:00+03	265600.00
23764B	2017-07-19 18:50:00+03	147900.00
2376C7	2017-08-03 15:44:00+03	168000.00
2376D0	2017-08-11 11:19:00+03	116800.00
237761	2017-08-06 18:23:00+03	133700.00
23776F	2017-07-03 05:09:00+03	83700.00
237784	2017-07-25 12:04:00+03	34000.00
2377E0	2017-07-26 09:06:00+03	32800.00
2377E3	2017-08-05 00:17:00+03	30200.00
237833	2017-07-11 14:51:00+03	42600.00
23785F	2017-07-03 06:42:00+03	86600.00
23789F	2017-07-03 15:20:00+03	87900.00
23792F	2017-07-06 03:52:00+03	444000.00
237970	2017-08-07 00:42:00+03	28000.00
237996	2017-07-20 23:45:00+03	133100.00
237A1C	2017-08-13 23:53:00+03	140900.00
237A65	2017-07-14 09:04:00+03	135400.00
237AAD	2017-08-06 16:12:00+03	87100.00
237B22	2017-08-08 04:18:00+03	244100.00
237B50	2017-07-02 09:31:00+03	123000.00
237B83	2017-08-05 10:17:00+03	20200.00
237BA9	2017-08-01 13:29:00+03	16400.00
237BC6	2017-08-12 10:32:00+03	89200.00
237C54	2017-07-28 18:48:00+03	136200.00
237C6F	2017-07-27 09:01:00+03	22000.00
237C73	2017-07-03 07:23:00+03	76200.00
237CA4	2017-08-12 05:18:00+03	132800.00
237CAE	2017-08-14 04:29:00+03	99200.00
237CB4	2017-08-09 23:59:00+03	35200.00
237CDE	2017-07-05 16:17:00+03	313000.00
237D51	2017-07-07 09:14:00+03	134000.00
237D6B	2017-07-04 06:49:00+03	124200.00
237D87	2017-07-18 03:25:00+03	42400.00
237E48	2017-08-07 01:22:00+03	56000.00
237E4D	2017-07-18 00:24:00+03	40400.00
237E73	2017-07-19 08:31:00+03	17800.00
237E9A	2017-08-01 15:44:00+03	28800.00
237ED0	2017-08-10 02:34:00+03	509100.00
237EDA	2017-08-03 19:56:00+03	48800.00
237F30	2017-07-19 12:01:00+03	55800.00
237F33	2017-08-04 05:25:00+03	61400.00
237F53	2017-08-07 23:22:00+03	13700.00
237F76	2017-07-30 21:14:00+03	28200.00
237F7F	2017-07-29 19:08:00+03	44000.00
237FA3	2017-07-24 16:58:00+03	48300.00
237FC6	2017-07-18 11:27:00+03	213200.00
237FEB	2017-08-06 01:09:00+03	52000.00
23803A	2017-07-23 18:21:00+03	28800.00
238044	2017-07-03 20:59:00+03	88400.00
238046	2017-08-05 16:19:00+03	68800.00
2380D0	2017-07-14 20:56:00+03	14000.00
2380FF	2017-07-15 05:18:00+03	562400.00
2381C5	2017-07-28 10:42:00+03	159200.00
2381E4	2017-07-26 05:59:00+03	40800.00
2381F7	2017-08-14 14:51:00+03	74000.00
23821C	2017-07-05 16:02:00+03	55800.00
23823D	2017-07-23 18:37:00+03	111600.00
2382A2	2017-07-21 02:04:00+03	285600.00
2382A7	2017-08-09 13:12:00+03	31800.00
2382CB	2017-08-14 13:48:00+03	270800.00
2382DB	2017-07-30 06:57:00+03	30400.00
238389	2017-07-03 10:51:00+03	58600.00
2383A7	2017-08-11 10:00:00+03	28000.00
23841D	2017-07-13 01:05:00+03	26700.00
2384C6	2017-07-01 02:36:00+03	107500.00
2385A7	2017-07-13 11:34:00+03	101200.00
2385B9	2017-07-06 07:20:00+03	47000.00
23860C	2017-07-12 06:33:00+03	8200.00
238614	2017-07-21 03:12:00+03	81900.00
238692	2017-07-17 11:50:00+03	168700.00
2386CD	2017-07-12 13:08:00+03	239300.00
238713	2017-07-17 14:39:00+03	37800.00
23874A	2017-07-18 00:32:00+03	55800.00
238878	2017-07-14 16:00:00+03	135000.00
238901	2017-08-02 13:17:00+03	54700.00
23891C	2017-07-09 19:14:00+03	28800.00
238937	2017-06-29 18:30:00+03	26800.00
238954	2017-07-08 12:12:00+03	92800.00
238956	2017-07-08 04:30:00+03	23200.00
2389B2	2017-07-02 08:19:00+03	64800.00
238A02	2017-07-02 23:56:00+03	56100.00
238A2B	2017-07-19 13:19:00+03	160700.00
238A66	2017-08-04 10:35:00+03	42800.00
238A67	2017-07-28 22:17:00+03	26000.00
238A80	2017-08-12 00:33:00+03	67200.00
238AEB	2017-08-12 21:45:00+03	90400.00
238B1C	2017-07-14 09:46:00+03	75300.00
238B2A	2017-07-24 21:59:00+03	86400.00
238B7A	2017-08-01 05:51:00+03	35600.00
238BA8	2017-07-12 08:11:00+03	113200.00
238BB1	2017-07-07 15:46:00+03	70500.00
238BF5	2017-07-14 17:15:00+03	64700.00
238C05	2017-07-11 12:41:00+03	177300.00
238C3C	2017-08-15 11:10:00+03	84100.00
238C4E	2017-07-26 17:32:00+03	38700.00
238C69	2017-07-23 17:28:00+03	14400.00
238CA3	2017-08-12 02:40:00+03	56900.00
238CB1	2017-07-13 12:21:00+03	67900.00
238D14	2017-07-07 02:20:00+03	38000.00
238D3E	2017-07-07 03:38:00+03	20900.00
238D91	2017-07-25 07:50:00+03	93900.00
238DA2	2017-07-28 03:14:00+03	25000.00
238E29	2017-07-13 22:06:00+03	23100.00
238E7F	2017-07-30 08:41:00+03	39000.00
238EAB	2017-07-13 04:52:00+03	24800.00
238EF9	2017-07-29 09:22:00+03	7400.00
238F01	2017-07-14 04:50:00+03	37100.00
238F1A	2017-07-20 19:29:00+03	79900.00
238FA7	2017-07-07 08:23:00+03	200500.00
239023	2017-07-22 08:03:00+03	39200.00
2390A0	2017-07-23 11:43:00+03	51600.00
2390D4	2017-08-08 18:33:00+03	67200.00
2390D9	2017-08-10 05:13:00+03	26600.00
239143	2017-07-15 04:40:00+03	138700.00
239179	2017-08-04 14:45:00+03	62600.00
239183	2017-07-10 04:35:00+03	375200.00
2391E6	2017-07-18 01:33:00+03	143800.00
2391E9	2017-07-21 10:44:00+03	26000.00
2391FC	2017-07-18 11:17:00+03	116800.00
239249	2017-08-05 14:27:00+03	202600.00
239259	2017-08-12 08:08:00+03	56000.00
239305	2017-07-30 14:21:00+03	37900.00
23932B	2017-08-12 12:11:00+03	135300.00
239337	2017-07-15 17:17:00+03	24800.00
239360	2017-08-14 22:27:00+03	202800.00
2393A8	2017-08-15 13:41:00+03	83000.00
2393CA	2017-07-22 21:34:00+03	46800.00
239439	2017-08-13 03:09:00+03	28000.00
239458	2017-07-10 05:34:00+03	45200.00
23949A	2017-07-18 07:46:00+03	95600.00
2394A4	2017-08-10 05:40:00+03	18900.00
239554	2017-08-10 00:39:00+03	80000.00
23960F	2017-08-10 17:07:00+03	184300.00
239636	2017-07-09 00:44:00+03	39800.00
23964E	2017-07-13 20:47:00+03	27400.00
2396AF	2017-07-13 02:01:00+03	14000.00
2396E5	2017-08-11 20:49:00+03	32800.00
2396E6	2017-07-24 07:16:00+03	272400.00
23973D	2017-07-01 14:08:00+03	54800.00
239758	2017-08-01 03:01:00+03	85000.00
2397B2	2017-08-06 20:44:00+03	50600.00
2397BB	2017-08-06 22:12:00+03	13600.00
239801	2017-07-23 16:13:00+03	44800.00
23983D	2017-08-10 16:18:00+03	53100.00
239853	2017-08-15 05:07:00+03	26800.00
23987C	2017-07-12 19:59:00+03	162300.00
2398B8	2017-08-11 06:00:00+03	70600.00
2398C4	2017-07-05 19:06:00+03	6000.00
2398EF	2017-07-06 15:37:00+03	43400.00
239A95	2017-08-15 06:15:00+03	26000.00
239ADC	2017-07-06 20:03:00+03	47100.00
239AE6	2017-07-11 11:36:00+03	170000.00
239AFB	2017-07-29 20:29:00+03	91600.00
239B5B	2017-07-14 18:28:00+03	32800.00
239B5D	2017-07-29 18:21:00+03	174000.00
239B63	2017-07-31 12:47:00+03	24400.00
239BA7	2017-07-11 03:02:00+03	46800.00
239BD5	2017-07-03 07:28:00+03	46400.00
239BF4	2017-07-09 16:16:00+03	137100.00
239C03	2017-07-29 02:55:00+03	178800.00
239C17	2017-07-31 00:59:00+03	81600.00
239CF9	2017-07-12 14:11:00+03	25200.00
239D02	2017-07-08 19:12:00+03	61800.00
239D08	2017-07-28 21:38:00+03	24400.00
239D6F	2017-07-26 22:01:00+03	64800.00
239D71	2017-07-29 06:47:00+03	50800.00
239DE2	2017-06-28 15:08:00+03	18800.00
239DFE	2017-07-14 07:59:00+03	14000.00
239E23	2017-07-22 09:00:00+03	31600.00
239E91	2017-07-28 04:39:00+03	48400.00
239EDC	2017-07-13 09:55:00+03	49600.00
239EDD	2017-07-07 15:53:00+03	60400.00
239EE9	2017-08-14 21:18:00+03	98400.00
239EF8	2017-07-26 00:44:00+03	56000.00
239F7A	2017-08-05 19:12:00+03	39500.00
239FF1	2017-07-25 11:07:00+03	97900.00
239FF6	2017-07-28 23:51:00+03	57400.00
239FF9	2017-08-11 02:18:00+03	23200.00
23A044	2017-07-30 11:09:00+03	16400.00
23A07D	2017-06-29 12:54:00+03	68400.00
23A09F	2017-08-05 20:35:00+03	311500.00
23A0B3	2017-08-10 10:24:00+03	42900.00
23A0EF	2017-07-27 00:46:00+03	12300.00
23A1AE	2017-07-13 22:58:00+03	30000.00
23A1D7	2017-08-09 10:19:00+03	56000.00
23A222	2017-07-24 04:55:00+03	56000.00
23A267	2017-07-21 12:06:00+03	62700.00
23A3CA	2017-08-06 14:57:00+03	182300.00
23A3DF	2017-07-24 09:12:00+03	48800.00
23A3E6	2017-08-09 02:47:00+03	58400.00
23A3F1	2017-08-09 08:19:00+03	42700.00
23A44C	2017-07-29 12:19:00+03	12600.00
23A464	2017-07-25 15:22:00+03	266400.00
23A4A1	2017-07-01 03:38:00+03	56000.00
23A4F9	2017-07-26 15:02:00+03	135400.00
23A506	2017-07-09 03:32:00+03	23600.00
23A54C	2017-07-06 09:31:00+03	62700.00
23A555	2017-08-13 08:14:00+03	32800.00
23A562	2017-08-05 06:02:00+03	16400.00
23A58C	2017-07-21 02:11:00+03	81600.00
23A5C3	2017-07-08 15:59:00+03	66200.00
23A5D9	2017-07-09 01:44:00+03	51200.00
23A6B2	2017-07-13 20:20:00+03	14000.00
23A6DE	2017-07-26 14:46:00+03	52100.00
23A732	2017-07-28 08:23:00+03	96800.00
23A7C6	2017-07-16 17:52:00+03	14000.00
23A7F7	2017-07-09 09:26:00+03	21800.00
23A856	2017-08-14 21:45:00+03	56000.00
23A874	2017-07-05 05:27:00+03	24800.00
23A8D8	2017-07-28 03:32:00+03	69900.00
23A929	2017-07-17 12:32:00+03	28000.00
23A945	2017-07-05 18:57:00+03	37200.00
23A989	2017-07-07 02:31:00+03	76400.00
23A990	2017-07-14 18:44:00+03	66000.00
23AA1C	2017-07-10 23:30:00+03	8200.00
23AA21	2017-08-13 05:21:00+03	53200.00
23AA47	2017-07-29 17:16:00+03	147200.00
23AA5B	2017-07-12 21:33:00+03	131100.00
23AA77	2017-08-15 16:54:00+03	43200.00
23AAD4	2017-07-23 20:47:00+03	44600.00
23AAD5	2017-07-06 09:55:00+03	93700.00
23AB52	2017-07-23 20:16:00+03	37100.00
23ABA2	2017-07-18 11:29:00+03	72400.00
23ABCD	2017-07-24 15:49:00+03	55800.00
23ABD5	2017-07-11 18:34:00+03	23600.00
23AC48	2017-08-01 16:13:00+03	8000.00
23AC4B	2017-07-30 00:41:00+03	70800.00
23AC79	2017-07-27 21:36:00+03	26000.00
23AC7C	2017-08-08 00:59:00+03	375200.00
23AD7F	2017-07-15 14:22:00+03	25200.00
23AD88	2017-08-14 00:20:00+03	31200.00
23AD99	2017-07-28 09:02:00+03	266400.00
23ADD5	2017-07-15 13:21:00+03	70700.00
23AE18	2017-07-28 22:53:00+03	61500.00
23AE7F	2017-07-27 03:03:00+03	29400.00
23AE89	2017-07-13 04:46:00+03	26000.00
23AF70	2017-08-02 19:54:00+03	36200.00
23AF91	2017-07-15 07:01:00+03	179700.00
23AFD3	2017-07-17 20:42:00+03	22200.00
23B00E	2017-08-12 12:24:00+03	26800.00
23B054	2017-08-13 19:46:00+03	6000.00
23B09E	2017-07-30 21:37:00+03	65000.00
23B10A	2017-07-16 22:56:00+03	18400.00
23B13C	2017-08-14 02:45:00+03	60700.00
23B1A8	2017-07-05 09:28:00+03	28000.00
23B1BF	2017-07-17 20:57:00+03	68400.00
23B2C1	2017-07-10 10:20:00+03	43100.00
23B2E1	2017-08-03 07:45:00+03	28800.00
23B2F1	2017-07-24 16:42:00+03	166000.00
23B309	2017-07-08 03:01:00+03	167900.00
23B30D	2017-07-12 23:24:00+03	75600.00
23B30E	2017-08-10 04:00:00+03	37600.00
23B395	2017-08-13 15:46:00+03	28000.00
23B3CC	2017-07-01 20:44:00+03	28700.00
23B3E1	2017-07-01 23:30:00+03	14000.00
23B434	2017-07-06 07:38:00+03	25400.00
23B49E	2017-08-14 04:05:00+03	23600.00
23B4BC	2017-07-07 04:44:00+03	71900.00
23B4F7	2017-08-07 08:41:00+03	33600.00
23B4FA	2017-07-03 01:26:00+03	134000.00
23B502	2017-07-08 21:03:00+03	52000.00
23B5A0	2017-07-14 20:29:00+03	70900.00
23B5B3	2017-07-11 23:38:00+03	56000.00
23B631	2017-06-30 16:23:00+03	90600.00
23B639	2017-07-05 10:54:00+03	56600.00
23B660	2017-08-03 00:00:00+03	75700.00
23B66E	2017-07-23 01:29:00+03	115200.00
23B6C6	2017-08-10 23:54:00+03	56600.00
23B756	2017-08-04 17:37:00+03	16400.00
23B783	2017-07-19 04:11:00+03	29400.00
23B7B3	2017-08-05 11:35:00+03	70800.00
23B826	2017-07-07 08:12:00+03	57600.00
23B972	2017-08-13 18:11:00+03	141000.00
23B99B	2017-07-30 16:54:00+03	26000.00
23BA54	2017-08-01 21:05:00+03	61800.00
23BAA2	2017-08-03 06:11:00+03	129700.00
23BAA3	2017-08-05 07:14:00+03	53200.00
23BAD6	2017-07-22 14:29:00+03	217600.00
23BB30	2017-07-14 15:58:00+03	53700.00
23BB55	2017-08-13 22:23:00+03	99200.00
23BB7A	2017-07-09 19:26:00+03	59600.00
23BBAD	2017-07-22 00:49:00+03	65500.00
23BBD0	2017-07-19 13:53:00+03	666000.00
23BBE0	2017-07-25 13:27:00+03	7400.00
23BC48	2017-07-11 20:47:00+03	92100.00
23BCAD	2017-07-18 21:44:00+03	50100.00
23BCCB	2017-08-04 20:24:00+03	189200.00
23BD4B	2017-08-12 00:30:00+03	38800.00
23BD55	2017-08-13 21:26:00+03	396700.00
23BDAD	2017-07-27 13:46:00+03	56600.00
23BDBD	2017-07-30 12:16:00+03	25200.00
23BDC2	2017-07-12 10:12:00+03	79900.00
23BDD4	2017-07-08 12:10:00+03	27200.00
23BDE6	2017-08-09 12:33:00+03	28800.00
23BDFB	2017-07-25 19:13:00+03	13400.00
23BE2D	2017-07-20 15:18:00+03	220500.00
23BE35	2017-07-11 21:15:00+03	7400.00
23BE39	2017-07-17 11:32:00+03	37200.00
23BE81	2017-07-25 22:56:00+03	99700.00
23BE8E	2017-07-17 11:33:00+03	71900.00
23BEDE	2017-08-07 03:26:00+03	86300.00
23BF28	2017-07-31 04:40:00+03	28800.00
23BF55	2017-07-25 10:19:00+03	79300.00
23BF88	2017-07-09 09:12:00+03	35600.00
23C006	2017-07-09 13:51:00+03	118500.00
23C065	2017-07-09 19:33:00+03	219500.00
23C085	2017-08-10 13:04:00+03	49000.00
23C0AF	2017-07-28 15:15:00+03	43200.00
23C0B2	2017-08-06 14:53:00+03	27000.00
23C0C6	2017-07-14 19:05:00+03	405200.00
23C10A	2017-07-10 23:41:00+03	56000.00
23C132	2017-08-02 13:45:00+03	205600.00
23C1C7	2017-08-05 21:09:00+03	20400.00
23C1FE	2017-08-11 21:38:00+03	76600.00
23C24F	2017-08-11 01:51:00+03	11800.00
23C2D0	2017-08-04 14:14:00+03	52000.00
23C3BA	2017-07-01 01:41:00+03	27800.00
23C3BD	2017-07-14 15:07:00+03	64700.00
23C3CE	2017-07-08 02:58:00+03	24400.00
23C3D2	2017-07-17 21:55:00+03	81700.00
23C3EA	2017-07-04 08:06:00+03	162400.00
23C448	2017-07-30 10:06:00+03	28000.00
23C45A	2017-08-02 09:20:00+03	13400.00
23C478	2017-08-13 04:32:00+03	102700.00
23C47B	2017-07-25 10:13:00+03	40200.00
23C4B8	2017-07-06 11:53:00+03	58600.00
23C4D6	2017-07-16 02:25:00+03	70700.00
23C53C	2017-08-14 15:13:00+03	24500.00
23C562	2017-08-01 00:28:00+03	23200.00
23C5AD	2017-07-15 12:38:00+03	69500.00
23C621	2017-08-02 01:55:00+03	33100.00
23C632	2017-07-24 10:49:00+03	27200.00
23C654	2017-07-06 15:27:00+03	179400.00
23C712	2017-08-13 07:29:00+03	38600.00
23C760	2017-07-24 03:08:00+03	111600.00
23C778	2017-07-06 07:41:00+03	83600.00
23C77D	2017-08-07 19:59:00+03	7400.00
23C7D3	2017-07-28 05:10:00+03	17600.00
23C7FC	2017-07-14 02:38:00+03	133200.00
23C893	2017-07-20 21:48:00+03	11700.00
23C8C1	2017-07-03 00:38:00+03	427600.00
23C8E6	2017-07-19 21:38:00+03	133100.00
23C92B	2017-08-07 06:06:00+03	12400.00
23C975	2017-08-13 23:13:00+03	89700.00
23C99C	2017-06-28 23:02:00+03	241300.00
23C9C7	2017-08-01 14:52:00+03	28000.00
23C9D6	2017-07-30 01:54:00+03	23600.00
23C9EE	2017-07-03 08:34:00+03	111600.00
23C9F2	2017-08-10 04:41:00+03	14000.00
23CA38	2017-07-30 14:51:00+03	16800.00
23CA61	2017-07-24 23:15:00+03	14400.00
23CA6C	2017-07-16 09:08:00+03	25800.00
23CB06	2017-08-12 06:22:00+03	86400.00
23CB24	2017-07-24 22:08:00+03	41200.00
23CB3A	2017-07-03 10:48:00+03	106900.00
23CB6D	2017-07-08 17:09:00+03	23200.00
23CB72	2017-07-03 21:29:00+03	136200.00
23CB7D	2017-07-06 17:31:00+03	161400.00
23CB88	2017-07-12 16:43:00+03	124200.00
23CC2D	2017-07-11 00:14:00+03	19600.00
23CC66	2017-08-02 18:28:00+03	186900.00
23CC90	2017-07-27 23:32:00+03	135400.00
23CDC5	2017-07-15 06:10:00+03	81300.00
23CDE1	2017-08-05 18:22:00+03	178800.00
23CDEA	2017-08-10 23:47:00+03	111600.00
23CE0E	2017-07-22 22:27:00+03	136800.00
23CE9F	2017-08-11 03:27:00+03	12600.00
23CEA0	2017-08-15 07:36:00+03	128800.00
23CEB3	2017-07-13 02:27:00+03	22000.00
23CF33	2017-07-23 15:24:00+03	101200.00
23CF78	2017-07-07 13:41:00+03	55800.00
23CFB7	2017-07-20 10:05:00+03	89700.00
23CFCC	2017-07-04 11:32:00+03	54800.00
23CFD0	2017-08-03 19:55:00+03	76800.00
23CFDF	2017-07-03 04:40:00+03	101200.00
23D006	2017-07-02 14:38:00+03	36900.00
23D00B	2017-07-07 04:04:00+03	135200.00
23D0B2	2017-07-14 13:15:00+03	13400.00
23D0FD	2017-07-14 13:36:00+03	46000.00
23D16E	2017-08-07 02:04:00+03	51600.00
23D174	2017-07-24 06:56:00+03	32800.00
23D176	2017-07-22 10:18:00+03	95000.00
23D17C	2017-08-04 01:48:00+03	28000.00
23D1B3	2017-07-01 11:47:00+03	10800.00
23D1F8	2017-08-07 05:26:00+03	24200.00
23D220	2017-07-12 19:52:00+03	76800.00
23D265	2017-07-12 12:11:00+03	26700.00
23D2BB	2017-07-11 19:35:00+03	56000.00
23D331	2017-08-11 05:27:00+03	160100.00
23D334	2017-07-15 08:55:00+03	155600.00
23D344	2017-08-08 01:53:00+03	32000.00
23D3A9	2017-07-22 17:08:00+03	40800.00
23D425	2017-07-04 19:23:00+03	75300.00
23D461	2017-07-22 13:00:00+03	137600.00
23D4BB	2017-07-08 18:32:00+03	496600.00
23D4E9	2017-08-13 10:21:00+03	56000.00
23D57A	2017-07-25 07:18:00+03	72200.00
23D57F	2017-08-08 19:04:00+03	51000.00
23D5B2	2017-06-30 01:58:00+03	77900.00
23D5C3	2017-08-09 04:29:00+03	174800.00
23D606	2017-08-10 12:57:00+03	135200.00
23D614	2017-07-12 11:06:00+03	40000.00
23D632	2017-08-06 09:39:00+03	19600.00
23D655	2017-07-21 21:26:00+03	146600.00
23D68E	2017-08-02 16:58:00+03	47700.00
23D6B2	2017-07-08 04:55:00+03	21800.00
23D6F5	2017-08-04 16:07:00+03	185800.00
23D6F9	2017-08-13 01:35:00+03	149600.00
23D735	2017-08-13 04:07:00+03	54500.00
23D7C7	2017-07-03 04:45:00+03	79900.00
23D868	2017-08-09 23:58:00+03	52700.00
23D88D	2017-07-27 15:51:00+03	16400.00
23D8AE	2017-07-05 00:45:00+03	146200.00
23D8B6	2017-07-04 21:47:00+03	44000.00
23D8D2	2017-07-23 13:26:00+03	83500.00
23D8EA	2017-07-27 05:50:00+03	119700.00
23D8EC	2017-07-19 16:37:00+03	40600.00
23D8ED	2017-06-30 05:07:00+03	89200.00
23D905	2017-08-02 15:37:00+03	58400.00
23D944	2017-08-13 02:48:00+03	28300.00
23D94D	2017-07-07 23:20:00+03	83000.00
23D969	2017-08-09 19:41:00+03	12600.00
23D9EA	2017-07-29 12:35:00+03	43200.00
23DA7E	2017-08-06 18:10:00+03	26000.00
23DA93	2017-07-11 16:38:00+03	62600.00
23DAB3	2017-08-10 11:51:00+03	21800.00
23DAE1	2017-08-01 13:31:00+03	23200.00
23DAF8	2017-07-05 11:47:00+03	74200.00
23DAF9	2017-07-24 17:44:00+03	136000.00
23DB7E	2017-08-09 04:59:00+03	369000.00
23DB85	2017-07-15 17:05:00+03	14000.00
23DB9F	2017-07-09 10:17:00+03	24400.00
23DBA0	2017-07-11 20:27:00+03	33600.00
23DBDC	2017-07-18 07:17:00+03	46400.00
23DBDF	2017-07-05 14:03:00+03	25400.00
23DC5E	2017-07-10 13:21:00+03	187600.00
23DD2A	2017-08-09 04:20:00+03	92400.00
23DD4B	2017-07-02 04:21:00+03	40800.00
23DDC0	2017-07-16 13:53:00+03	59800.00
23DDD4	2017-07-24 09:37:00+03	28800.00
23DE1A	2017-08-06 04:25:00+03	15000.00
23DE26	2017-07-31 08:22:00+03	29800.00
23DE30	2017-07-31 05:22:00+03	62100.00
23DEC8	2017-07-20 06:53:00+03	133100.00
23DF46	2017-07-09 06:16:00+03	66600.00
23DFF9	2017-08-02 10:33:00+03	372400.00
23E045	2017-07-05 06:44:00+03	21800.00
23E08E	2017-07-04 01:35:00+03	88900.00
23E0D7	2017-07-07 17:04:00+03	21500.00
23E0F9	2017-06-30 20:22:00+03	219300.00
23E10C	2017-08-01 07:27:00+03	123000.00
23E10F	2017-08-08 05:38:00+03	57500.00
23E12B	2017-07-30 21:02:00+03	22000.00
23E182	2017-08-10 16:40:00+03	22000.00
23E19E	2017-08-14 02:22:00+03	36200.00
23E1F6	2017-07-20 03:48:00+03	174600.00
23E209	2017-08-06 09:58:00+03	60400.00
23E2F0	2017-07-11 23:11:00+03	46300.00
23E2FC	2017-08-02 19:15:00+03	21800.00
23E32B	2017-07-31 14:59:00+03	18000.00
23E3EC	2017-07-14 01:15:00+03	199700.00
23E40F	2017-08-12 03:46:00+03	49400.00
23E423	2017-08-08 14:20:00+03	33300.00
23E501	2017-08-04 02:48:00+03	55800.00
23E509	2017-07-21 18:47:00+03	13700.00
23E50C	2017-08-08 03:52:00+03	14300.00
23E555	2017-08-03 12:38:00+03	27200.00
23E5CE	2017-07-11 18:00:00+03	26800.00
23E609	2017-08-05 15:08:00+03	31200.00
23E66A	2017-07-14 18:28:00+03	112100.00
23E680	2017-08-04 04:49:00+03	6700.00
23E6E6	2017-07-24 05:28:00+03	265700.00
23E790	2017-07-14 03:30:00+03	23200.00
23E7B1	2017-08-13 02:11:00+03	29600.00
23E82B	2017-07-18 22:49:00+03	8400.00
23E841	2017-07-07 19:52:00+03	48400.00
23E864	2017-07-13 07:19:00+03	25400.00
23E877	2017-07-13 20:51:00+03	113700.00
23E886	2017-08-06 11:54:00+03	21800.00
23E8E8	2017-07-31 18:56:00+03	276500.00
23E903	2017-07-13 02:48:00+03	28000.00
23E907	2017-07-16 09:28:00+03	112000.00
23E952	2017-07-23 13:11:00+03	135600.00
23E95C	2017-08-13 14:42:00+03	13400.00
23E9A8	2017-07-18 20:43:00+03	167400.00
23EA05	2017-08-07 14:28:00+03	25600.00
23EA14	2017-08-05 10:48:00+03	7400.00
23EA1D	2017-08-01 22:43:00+03	58400.00
23EA52	2017-07-13 16:40:00+03	246000.00
23EA95	2017-07-29 15:28:00+03	177800.00
23EAA5	2017-07-04 09:07:00+03	34800.00
23EB11	2017-07-21 16:35:00+03	113300.00
23EB43	2017-07-01 16:32:00+03	56000.00
23EB7E	2017-07-02 07:11:00+03	123000.00
23EB8D	2017-07-18 19:03:00+03	21400.00
23EBBF	2017-07-07 20:37:00+03	99200.00
23EC21	2017-08-02 16:52:00+03	47400.00
23EC24	2017-08-11 05:02:00+03	76300.00
23EC40	2017-07-28 15:24:00+03	174300.00
23EC47	2017-08-13 22:04:00+03	65100.00
23EC55	2017-08-07 10:47:00+03	56000.00
23EC67	2017-08-05 09:40:00+03	54000.00
23EC72	2017-08-14 03:03:00+03	30200.00
23EC97	2017-08-13 04:02:00+03	56000.00
23ECF7	2017-08-11 07:01:00+03	156600.00
23ED34	2017-06-30 10:53:00+03	124200.00
23ED80	2017-07-10 05:25:00+03	40300.00
23EDA2	2017-07-24 21:53:00+03	38400.00
23EDDE	2017-07-02 02:00:00+03	58600.00
23EDF0	2017-07-19 04:47:00+03	22000.00
23EDF7	2017-08-07 16:38:00+03	112000.00
23EDFE	2017-07-24 07:44:00+03	40800.00
23EE0C	2017-07-08 17:39:00+03	69500.00
23EE79	2017-08-01 03:29:00+03	27900.00
23EECC	2017-06-30 06:45:00+03	38200.00
23EF9D	2017-07-04 13:06:00+03	139100.00
23EFB3	2017-07-11 00:54:00+03	132800.00
23F02A	2017-07-31 10:43:00+03	115900.00
23F036	2017-07-29 11:37:00+03	11600.00
23F0D0	2017-07-07 19:51:00+03	37400.00
23F0DD	2017-07-03 01:37:00+03	62100.00
23F15C	2017-07-28 18:40:00+03	50600.00
23F15E	2017-07-21 18:49:00+03	70100.00
23F1EA	2017-08-06 06:07:00+03	31600.00
23F213	2017-07-07 10:58:00+03	125800.00
23F237	2017-08-13 17:43:00+03	135600.00
23F26A	2017-08-05 05:58:00+03	158400.00
23F26D	2017-07-21 18:35:00+03	13700.00
23F2B5	2017-07-24 21:29:00+03	14400.00
23F2F1	2017-07-03 14:02:00+03	95000.00
23F34A	2017-08-02 12:15:00+03	65500.00
23F376	2017-07-04 14:58:00+03	560700.00
23F43B	2017-08-06 21:39:00+03	56600.00
23F47E	2017-07-03 20:16:00+03	131600.00
23F4BA	2017-07-02 21:43:00+03	114600.00
23F4E8	2017-07-21 19:02:00+03	26000.00
23F516	2017-08-06 08:51:00+03	670900.00
23F535	2017-07-05 16:06:00+03	55800.00
23F5A6	2017-07-28 20:48:00+03	50000.00
23F5AA	2017-07-23 11:48:00+03	25600.00
23F5BF	2017-07-23 04:33:00+03	131100.00
23F5CC	2017-08-12 05:48:00+03	48800.00
23F5D7	2017-08-15 04:43:00+03	6700.00
23F5FE	2017-07-29 17:01:00+03	6300.00
23F606	2017-08-05 15:40:00+03	42700.00
23F608	2017-07-04 08:20:00+03	88800.00
23F610	2017-07-10 03:00:00+03	27700.00
23F616	2017-07-12 20:57:00+03	127200.00
23F642	2017-08-03 16:48:00+03	28800.00
23F65A	2017-07-28 04:35:00+03	46300.00
23F6ED	2017-08-02 21:03:00+03	9000.00
23F76E	2017-07-09 17:16:00+03	139500.00
23F78C	2017-07-29 13:26:00+03	40800.00
23F7F2	2017-08-07 13:31:00+03	15400.00
23F843	2017-08-08 15:25:00+03	26000.00
23F876	2017-07-05 02:52:00+03	47200.00
23F880	2017-07-28 02:47:00+03	140300.00
23F88D	2017-07-21 03:53:00+03	19600.00
23F8DD	2017-07-20 09:01:00+03	258400.00
23F8E3	2017-08-03 00:37:00+03	24400.00
23F8EB	2017-07-31 17:53:00+03	62000.00
23F902	2017-08-04 07:44:00+03	191900.00
23F916	2017-07-28 18:39:00+03	38800.00
23F993	2017-07-16 21:15:00+03	57500.00
23FA10	2017-08-13 16:46:00+03	35400.00
23FB21	2017-07-03 07:21:00+03	55800.00
23FB29	2017-07-20 00:55:00+03	84500.00
23FB80	2017-08-04 19:47:00+03	23100.00
23FB8D	2017-08-06 05:35:00+03	23600.00
23FC3A	2017-08-05 05:13:00+03	26000.00
23FC8C	2017-08-05 22:10:00+03	20200.00
23FCA0	2017-07-27 20:07:00+03	62000.00
23FCB8	2017-07-06 12:12:00+03	135200.00
23FCBF	2017-07-08 13:26:00+03	27800.00
23FD23	2017-07-24 15:15:00+03	51300.00
23FD50	2017-07-17 23:31:00+03	47100.00
23FD61	2017-07-31 23:06:00+03	6000.00
23FD6E	2017-07-25 05:39:00+03	21800.00
23FD79	2017-07-25 20:36:00+03	81600.00
23FD99	2017-07-17 13:52:00+03	50000.00
23FDB7	2017-07-20 11:02:00+03	44000.00
23FE0E	2017-08-12 12:44:00+03	14000.00
23FE0F	2017-08-12 04:32:00+03	159200.00
23FE11	2017-07-04 19:55:00+03	35600.00
23FE33	2017-08-01 11:39:00+03	23600.00
23FE64	2017-07-19 23:32:00+03	67600.00
23FE9A	2017-07-22 21:57:00+03	53600.00
23FEA3	2017-08-02 12:35:00+03	57400.00
23FED1	2017-07-08 18:07:00+03	33100.00
23FED5	2017-08-05 19:57:00+03	43600.00
23FED7	2017-07-18 08:34:00+03	25400.00
23FF24	2017-07-26 10:40:00+03	65400.00
23FFA7	2017-08-13 21:02:00+03	49300.00
240067	2017-07-26 03:33:00+03	28000.00
24006C	2017-08-14 00:54:00+03	90400.00
240076	2017-07-29 09:50:00+03	65900.00
24011F	2017-07-29 08:02:00+03	30900.00
240133	2017-07-18 22:27:00+03	27200.00
240139	2017-07-12 10:39:00+03	25200.00
24014D	2017-07-26 12:34:00+03	43200.00
240174	2017-07-24 13:03:00+03	57300.00
2401F9	2017-07-21 07:03:00+03	58700.00
24020D	2017-07-12 15:24:00+03	72300.00
240227	2017-07-16 18:20:00+03	85000.00
240267	2017-08-06 03:16:00+03	93400.00
240282	2017-07-19 02:01:00+03	54000.00
2402B0	2017-07-17 15:55:00+03	75300.00
2402E5	2017-08-03 12:26:00+03	46200.00
24034B	2017-07-30 13:53:00+03	124800.00
2403D2	2017-07-28 11:21:00+03	224000.00
2403F9	2017-07-21 21:13:00+03	123000.00
24041E	2017-07-06 13:06:00+03	196400.00
24042C	2017-07-18 19:58:00+03	46400.00
240462	2017-07-14 18:18:00+03	224000.00
240518	2017-07-15 14:56:00+03	6000.00
240542	2017-07-15 06:00:00+03	12400.00
240585	2017-08-13 13:06:00+03	13400.00
2406A3	2017-08-06 16:24:00+03	112600.00
2406BA	2017-07-19 11:44:00+03	74000.00
2406D4	2017-08-01 05:43:00+03	76600.00
2406E8	2017-07-13 11:56:00+03	15000.00
240719	2017-08-11 11:26:00+03	37000.00
24072C	2017-08-13 12:46:00+03	97900.00
240733	2017-07-01 19:08:00+03	18600.00
24077D	2017-07-12 21:56:00+03	6700.00
2407B1	2017-07-12 15:55:00+03	208200.00
2407F9	2017-07-04 14:41:00+03	6000.00
2408AC	2017-07-07 17:43:00+03	46300.00
240909	2017-08-08 04:52:00+03	14000.00
240923	2017-08-05 03:30:00+03	95000.00
24093E	2017-07-20 14:15:00+03	67600.00
2409C8	2017-08-12 05:51:00+03	52000.00
2409D2	2017-07-03 01:02:00+03	66600.00
240A45	2017-07-03 09:07:00+03	67600.00
240AA8	2017-08-14 06:02:00+03	59300.00
240ABE	2017-08-14 00:37:00+03	56000.00
240AF9	2017-08-11 12:20:00+03	12000.00
240B4D	2017-07-24 08:23:00+03	55800.00
240BB4	2017-07-13 04:48:00+03	25600.00
240BC3	2017-07-31 11:30:00+03	124800.00
240BD0	2017-08-14 07:55:00+03	23600.00
240BE1	2017-08-10 04:11:00+03	133100.00
240BF3	2017-08-12 22:06:00+03	62000.00
240BFA	2017-07-16 12:07:00+03	123600.00
240C1F	2017-07-14 15:14:00+03	45100.00
240C98	2017-08-08 13:41:00+03	31200.00
240D6F	2017-08-15 02:44:00+03	99200.00
240D78	2017-07-17 05:25:00+03	27200.00
240DAE	2017-08-04 01:07:00+03	77900.00
240DB6	2017-07-28 14:51:00+03	86600.00
240DC0	2017-08-13 22:35:00+03	13600.00
240EA6	2017-07-20 00:46:00+03	39300.00
240ED2	2017-08-14 23:14:00+03	99200.00
240EF5	2017-07-10 00:02:00+03	101900.00
240F05	2017-07-16 18:01:00+03	146800.00
240F1A	2017-08-08 04:57:00+03	110500.00
240F38	2017-07-17 06:06:00+03	40400.00
240F3D	2017-08-01 21:14:00+03	10800.00
240FA9	2017-08-06 14:50:00+03	61600.00
240FC7	2017-08-05 16:34:00+03	14400.00
240FF5	2017-07-10 14:55:00+03	44800.00
24100E	2017-08-15 07:46:00+03	15400.00
2410B3	2017-08-04 10:47:00+03	23200.00
2410E0	2017-07-14 10:49:00+03	23400.00
241104	2017-07-16 08:39:00+03	31600.00
241112	2017-07-31 13:22:00+03	65300.00
24111F	2017-07-15 12:11:00+03	36900.00
241189	2017-07-30 12:50:00+03	20000.00
2411AF	2017-07-19 17:01:00+03	196100.00
24123C	2017-08-15 16:31:00+03	142400.00
24127B	2017-07-10 11:06:00+03	125400.00
24128B	2017-07-24 20:11:00+03	43000.00
2412A8	2017-07-15 20:42:00+03	30000.00
2412AD	2017-08-14 05:35:00+03	130400.00
24138C	2017-07-07 09:44:00+03	53100.00
241492	2017-07-23 16:55:00+03	58800.00
24149C	2017-07-16 06:53:00+03	152500.00
2414D9	2017-06-28 17:49:00+03	45400.00
2414DB	2017-07-25 05:57:00+03	92900.00
241550	2017-07-10 13:53:00+03	111600.00
241573	2017-07-30 14:44:00+03	178800.00
24158E	2017-07-11 13:31:00+03	148200.00
241590	2017-08-12 06:41:00+03	23200.00
241617	2017-07-02 20:46:00+03	23200.00
241686	2017-07-29 08:05:00+03	55800.00
24168A	2017-07-30 22:09:00+03	123000.00
24170C	2017-07-19 23:28:00+03	26000.00
24178F	2017-07-11 20:56:00+03	30200.00
2417CD	2017-08-12 02:40:00+03	46400.00
241850	2017-07-18 08:56:00+03	59000.00
24187F	2017-07-09 17:31:00+03	60000.00
2418E2	2017-07-23 03:40:00+03	44000.00
24192C	2017-07-24 00:19:00+03	39200.00
24197B	2017-07-26 01:01:00+03	25400.00
2419DB	2017-07-21 23:44:00+03	28800.00
2419E2	2017-07-05 14:06:00+03	73500.00
241A36	2017-07-11 00:04:00+03	27300.00
241A63	2017-07-03 05:57:00+03	492000.00
241AF9	2017-08-11 00:57:00+03	115400.00
241B0E	2017-07-14 09:26:00+03	88000.00
241B55	2017-07-15 03:15:00+03	125400.00
241B80	2017-08-13 19:04:00+03	67600.00
241BC4	2017-08-11 23:58:00+03	12600.00
241BD4	2017-07-07 14:06:00+03	16400.00
241C02	2017-07-24 16:59:00+03	30000.00
241C1D	2017-07-05 18:32:00+03	133200.00
241C40	2017-08-06 11:16:00+03	31400.00
241C5F	2017-07-27 12:32:00+03	55800.00
241C80	2017-07-31 23:39:00+03	117200.00
241CB0	2017-08-10 01:35:00+03	33100.00
241CBD	2017-07-26 13:18:00+03	16400.00
241D7A	2017-08-11 19:26:00+03	27400.00
241DC0	2017-08-07 21:15:00+03	46000.00
241E32	2017-07-22 00:34:00+03	26600.00
241E50	2017-07-12 21:45:00+03	6700.00
241E6E	2017-08-05 06:33:00+03	532800.00
241EBB	2017-07-21 23:04:00+03	198400.00
241EDF	2017-08-01 11:41:00+03	40800.00
241EE1	2017-07-22 16:45:00+03	56000.00
241F07	2017-08-01 05:25:00+03	71600.00
241F1F	2017-07-07 18:36:00+03	96300.00
241F36	2017-07-05 21:53:00+03	14000.00
241F96	2017-08-08 09:26:00+03	179400.00
241FFE	2017-07-04 22:41:00+03	18600.00
242006	2017-07-25 04:00:00+03	157100.00
24200B	2017-07-13 18:34:00+03	123000.00
24200C	2017-08-13 14:42:00+03	49500.00
242035	2017-06-30 16:31:00+03	136800.00
242069	2017-07-17 00:37:00+03	40800.00
242074	2017-07-20 08:47:00+03	39500.00
2420CB	2017-08-07 17:51:00+03	495400.00
24213E	2017-08-10 07:09:00+03	66000.00
2421B3	2017-07-24 02:34:00+03	48800.00
2421DB	2017-08-07 02:26:00+03	89600.00
2421FE	2017-07-31 07:23:00+03	70800.00
24222B	2017-07-09 07:22:00+03	6700.00
24227B	2017-07-15 12:24:00+03	115600.00
24230D	2017-07-17 06:11:00+03	6800.00
242317	2017-08-04 16:58:00+03	27400.00
24232F	2017-07-19 08:51:00+03	28000.00
24233C	2017-07-10 21:53:00+03	6700.00
24233F	2017-07-20 03:36:00+03	6800.00
24234F	2017-08-02 07:30:00+03	48600.00
2423F5	2017-07-17 07:45:00+03	39200.00
2423F7	2017-08-02 23:00:00+03	244600.00
242416	2017-07-11 10:05:00+03	128800.00
24246A	2017-07-07 18:39:00+03	28000.00
242478	2017-08-05 05:46:00+03	7400.00
24247A	2017-08-15 03:22:00+03	364600.00
24247B	2017-08-07 06:36:00+03	25400.00
242484	2017-07-19 01:16:00+03	83000.00
24249F	2017-08-04 21:16:00+03	30200.00
2424CD	2017-07-05 01:34:00+03	137900.00
2424F4	2017-07-02 22:57:00+03	18000.00
242515	2017-08-06 18:41:00+03	12700.00
242544	2017-07-04 11:53:00+03	135600.00
242567	2017-07-14 11:18:00+03	410800.00
24257B	2017-08-06 20:41:00+03	23200.00
242580	2017-07-18 10:17:00+03	23100.00
2426A2	2017-08-15 16:13:00+03	8400.00
2426DA	2017-08-08 14:52:00+03	85000.00
2426EA	2017-08-07 15:35:00+03	86300.00
24276D	2017-07-17 13:13:00+03	322600.00
242799	2017-07-13 00:33:00+03	39600.00
2427FB	2017-07-11 05:38:00+03	21400.00
242861	2017-07-05 11:19:00+03	25100.00
2428D0	2017-06-29 01:27:00+03	52000.00
242907	2017-08-05 07:54:00+03	53500.00
242948	2017-08-07 16:04:00+03	28800.00
242996	2017-07-27 23:31:00+03	28000.00
2429C1	2017-07-26 23:47:00+03	22600.00
2429EC	2017-06-30 18:04:00+03	9000.00
242A7F	2017-08-12 11:20:00+03	29400.00
242ADF	2017-07-10 15:14:00+03	123000.00
242B64	2017-07-07 18:12:00+03	56000.00
242BFE	2017-07-17 07:02:00+03	101500.00
242C1F	2017-08-14 20:01:00+03	38600.00
242CC3	2017-06-28 23:41:00+03	39300.00
242D17	2017-07-04 12:45:00+03	139400.00
242D26	2017-08-11 04:01:00+03	63500.00
242D40	2017-08-14 20:16:00+03	14000.00
242D5D	2017-08-13 00:29:00+03	86300.00
242DAD	2017-07-24 08:28:00+03	112000.00
242DAF	2017-07-19 06:56:00+03	9800.00
242DC9	2017-07-03 23:04:00+03	133200.00
242DD4	2017-07-24 05:39:00+03	81900.00
242E02	2017-07-18 01:10:00+03	43600.00
242E05	2017-07-26 21:16:00+03	70800.00
242E2C	2017-07-28 23:56:00+03	44800.00
242EBE	2017-07-27 16:09:00+03	107700.00
242EC9	2017-07-27 10:43:00+03	23200.00
242ED0	2017-07-15 18:51:00+03	270000.00
242EF7	2017-07-27 15:12:00+03	39800.00
242F19	2017-08-12 12:04:00+03	67200.00
242F61	2017-07-26 02:36:00+03	28000.00
243015	2017-08-08 11:08:00+03	21200.00
243050	2017-07-19 22:13:00+03	40000.00
2430B3	2017-07-26 01:15:00+03	93400.00
2430F8	2017-07-29 07:18:00+03	26100.00
2431A4	2017-08-13 15:30:00+03	24300.00
2431AC	2017-07-10 09:35:00+03	78300.00
243237	2017-08-15 09:45:00+03	38600.00
24325E	2017-07-29 07:56:00+03	23200.00
2432C2	2017-07-02 03:47:00+03	15800.00
2432C6	2017-07-02 09:55:00+03	14000.00
243314	2017-08-13 19:04:00+03	21200.00
24334A	2017-07-31 18:49:00+03	101200.00
24339B	2017-08-10 13:46:00+03	53400.00
2433A1	2017-07-26 09:22:00+03	37200.00
24343F	2017-07-27 03:18:00+03	108700.00
243480	2017-07-05 22:15:00+03	174600.00
24348E	2017-06-30 16:07:00+03	246000.00
2434C5	2017-07-16 05:02:00+03	81300.00
24352C	2017-07-09 11:23:00+03	24000.00
2435C5	2017-07-04 18:59:00+03	79200.00
243602	2017-07-09 17:26:00+03	96400.00
2436B2	2017-07-25 15:26:00+03	143000.00
24372A	2017-07-22 17:16:00+03	58400.00
243753	2017-07-03 06:07:00+03	46800.00
2437C2	2017-07-02 12:58:00+03	14000.00
243834	2017-08-06 12:04:00+03	55800.00
243857	2017-07-19 09:41:00+03	27900.00
243881	2017-07-01 18:27:00+03	201200.00
24388F	2017-07-17 17:37:00+03	23200.00
2438AE	2017-08-15 09:07:00+03	26700.00
2438C2	2017-07-21 23:53:00+03	95300.00
2438E6	2017-07-08 04:26:00+03	116400.00
24390E	2017-07-05 17:19:00+03	135200.00
243920	2017-07-16 06:22:00+03	54400.00
243923	2017-07-05 22:49:00+03	67600.00
243959	2017-08-04 18:18:00+03	70600.00
243978	2017-07-03 02:02:00+03	146200.00
243AF3	2017-08-12 15:51:00+03	32800.00
243B21	2017-07-27 04:02:00+03	99200.00
243B27	2017-08-11 04:14:00+03	67700.00
243B2C	2017-08-13 10:33:00+03	36800.00
243B75	2017-07-11 22:51:00+03	29300.00
243BB0	2017-08-13 07:36:00+03	532800.00
243BB3	2017-08-14 11:08:00+03	36000.00
243C19	2017-07-07 18:01:00+03	72300.00
243C2B	2017-08-15 06:32:00+03	22000.00
243C3B	2017-07-22 23:20:00+03	37900.00
243CC8	2017-08-12 15:49:00+03	27800.00
243D0A	2017-08-10 07:32:00+03	50700.00
243D4D	2017-07-04 15:05:00+03	36900.00
243D7A	2017-08-10 07:55:00+03	56000.00
243DE8	2017-07-25 03:55:00+03	104600.00
243DEE	2017-07-03 23:22:00+03	257500.00
243E07	2017-07-15 03:52:00+03	247900.00
243E5D	2017-07-15 16:17:00+03	75300.00
243E75	2017-07-29 02:12:00+03	143400.00
243F56	2017-08-04 08:55:00+03	14000.00
243F63	2017-08-12 19:48:00+03	25400.00
243F68	2017-07-10 09:50:00+03	81700.00
243FD2	2017-08-04 23:05:00+03	69500.00
243FD8	2017-07-05 16:19:00+03	13400.00
244011	2017-07-14 14:43:00+03	110200.00
24403B	2017-07-14 08:58:00+03	155600.00
244092	2017-08-08 14:31:00+03	28800.00
24409E	2017-07-29 12:33:00+03	11700.00
2440DD	2017-07-12 02:00:00+03	539400.00
24412D	2017-07-08 14:25:00+03	23600.00
244139	2017-07-13 22:00:00+03	60400.00
24414A	2017-07-12 06:33:00+03	87000.00
244215	2017-07-31 16:37:00+03	25600.00
24427D	2017-07-13 11:02:00+03	205400.00
244364	2017-07-19 00:22:00+03	37200.00
2443A6	2017-07-08 05:05:00+03	40100.00
244411	2017-07-31 23:06:00+03	39600.00
244437	2017-07-19 09:51:00+03	54500.00
244445	2017-07-02 05:43:00+03	51300.00
244448	2017-07-28 00:11:00+03	112000.00
2444C9	2017-07-06 01:24:00+03	56000.00
2444F6	2017-07-04 10:20:00+03	27300.00
24454F	2017-08-11 21:44:00+03	37200.00
244568	2017-08-01 12:51:00+03	59300.00
24457E	2017-08-08 00:20:00+03	13400.00
2445B5	2017-07-30 08:54:00+03	36900.00
2445C6	2017-08-14 07:46:00+03	47400.00
244641	2017-06-30 11:48:00+03	213200.00
24465E	2017-07-28 05:14:00+03	32700.00
2446AB	2017-08-12 16:55:00+03	18800.00
2446C1	2017-07-21 14:29:00+03	74800.00
2446EB	2017-07-21 15:49:00+03	50000.00
2446ED	2017-07-12 19:34:00+03	60400.00
2446FD	2017-07-13 00:36:00+03	15000.00
244713	2017-07-05 00:48:00+03	103300.00
24473B	2017-07-10 04:15:00+03	168000.00
24474C	2017-08-06 08:42:00+03	28800.00
244769	2017-07-20 02:41:00+03	46400.00
244779	2017-07-22 11:30:00+03	46300.00
24477C	2017-07-06 10:28:00+03	189100.00
244782	2017-08-12 10:43:00+03	54300.00
2447F4	2017-07-07 13:19:00+03	47100.00
244806	2017-07-18 15:39:00+03	25600.00
244828	2017-07-17 03:49:00+03	132800.00
24482C	2017-07-09 12:10:00+03	92100.00
24484D	2017-07-24 09:43:00+03	111600.00
244869	2017-08-13 14:36:00+03	220700.00
24487B	2017-07-17 15:37:00+03	27800.00
2448B3	2017-08-01 19:34:00+03	69500.00
2448C4	2017-07-03 01:36:00+03	50000.00
244930	2017-07-19 04:54:00+03	45400.00
244977	2017-07-07 21:52:00+03	651900.00
2449B2	2017-07-24 23:48:00+03	30700.00
2449E6	2017-07-06 03:37:00+03	74400.00
244A01	2017-07-12 02:46:00+03	73500.00
244A73	2017-07-06 05:12:00+03	75900.00
244A94	2017-08-11 19:07:00+03	16000.00
244AD6	2017-08-12 08:48:00+03	189800.00
244AF7	2017-07-07 23:01:00+03	72200.00
244BFB	2017-07-12 17:31:00+03	18800.00
244C1D	2017-07-03 07:16:00+03	70700.00
244CA5	2017-07-16 19:09:00+03	28800.00
244CBF	2017-07-14 06:48:00+03	20100.00
244CF7	2017-07-02 11:55:00+03	167400.00
244D00	2017-08-10 19:17:00+03	8200.00
244D46	2017-08-02 08:31:00+03	57400.00
244E1E	2017-08-01 20:24:00+03	51900.00
244E27	2017-07-20 20:41:00+03	14000.00
244E85	2017-08-09 15:01:00+03	115900.00
244F07	2017-07-22 11:16:00+03	47000.00
244F79	2017-07-22 05:40:00+03	9200.00
244FCB	2017-07-20 12:17:00+03	28800.00
244FD0	2017-07-07 15:27:00+03	151200.00
244FE0	2017-06-30 12:48:00+03	28800.00
244FF0	2017-08-02 10:36:00+03	12200.00
245098	2017-07-25 21:20:00+03	67600.00
2450A4	2017-08-03 18:12:00+03	49800.00
2450B0	2017-08-05 01:34:00+03	75600.00
24516E	2017-07-16 04:09:00+03	66600.00
245192	2017-07-24 16:39:00+03	252200.00
24519E	2017-07-06 09:21:00+03	56600.00
2451BC	2017-07-30 00:16:00+03	33000.00
2451D7	2017-07-10 10:24:00+03	81300.00
245283	2017-08-04 04:08:00+03	92800.00
245295	2017-07-17 14:07:00+03	83000.00
2452D8	2017-07-21 13:01:00+03	184300.00
245330	2017-07-17 08:09:00+03	63200.00
24539D	2017-07-18 17:06:00+03	68800.00
2453B7	2017-08-12 21:49:00+03	133200.00
24548F	2017-07-16 20:32:00+03	44800.00
2454E0	2017-08-04 23:58:00+03	136500.00
245535	2017-07-30 09:36:00+03	46400.00
245596	2017-07-19 15:55:00+03	56000.00
245602	2017-08-02 23:21:00+03	193600.00
245603	2017-07-27 03:15:00+03	111600.00
24561B	2017-08-02 15:20:00+03	56900.00
245645	2017-07-04 12:50:00+03	246000.00
2456DA	2017-07-03 17:09:00+03	15400.00
245742	2017-08-10 09:30:00+03	136800.00
245768	2017-07-30 08:05:00+03	67000.00
2457B2	2017-07-05 17:02:00+03	53400.00
2457D2	2017-08-11 18:04:00+03	75300.00
245814	2017-08-14 07:19:00+03	399600.00
245816	2017-07-06 12:07:00+03	100600.00
245827	2017-08-10 02:50:00+03	50300.00
24586F	2017-08-11 01:58:00+03	75300.00
2458A3	2017-07-05 15:57:00+03	103500.00
2458C1	2017-07-20 22:06:00+03	10700.00
2458FB	2017-07-07 10:23:00+03	29300.00
24595F	2017-07-11 16:32:00+03	76600.00
245961	2017-08-12 10:17:00+03	32100.00
24596D	2017-08-09 20:37:00+03	144700.00
2459C4	2017-08-11 12:40:00+03	40400.00
2459F7	2017-08-03 11:50:00+03	181600.00
245A04	2017-07-28 19:06:00+03	37800.00
245A74	2017-07-27 14:37:00+03	6000.00
245AC9	2017-08-13 06:24:00+03	28800.00
245AEE	2017-07-27 01:31:00+03	242600.00
245B0D	2017-07-27 21:05:00+03	12400.00
245B21	2017-07-27 10:09:00+03	56000.00
245B5D	2017-08-07 13:45:00+03	10600.00
245B64	2017-07-20 20:22:00+03	155600.00
245B83	2017-08-04 08:49:00+03	23200.00
245BFB	2017-08-05 05:46:00+03	6000.00
245C22	2017-06-29 19:27:00+03	20600.00
245CDA	2017-07-06 21:32:00+03	14000.00
245D0D	2017-07-18 19:46:00+03	164600.00
245D34	2017-07-21 06:22:00+03	73900.00
245D76	2017-07-05 10:25:00+03	55800.00
245DFF	2017-08-10 05:56:00+03	63200.00
245E2E	2017-08-15 05:03:00+03	29400.00
245E32	2017-07-04 10:40:00+03	25500.00
245E40	2017-08-01 23:30:00+03	44800.00
245EB4	2017-07-16 04:52:00+03	224000.00
245EC0	2017-07-12 04:11:00+03	133200.00
245ED7	2017-07-24 16:21:00+03	105000.00
245F4C	2017-08-04 09:40:00+03	28700.00
245FE4	2017-07-20 06:04:00+03	26800.00
246017	2017-07-19 21:20:00+03	164600.00
246081	2017-07-31 13:07:00+03	87200.00
2460A2	2017-07-28 05:09:00+03	69500.00
2461A9	2017-07-26 08:20:00+03	121400.00
2461F0	2017-07-22 10:19:00+03	28000.00
24627D	2017-07-19 11:40:00+03	83000.00
24628F	2017-08-04 16:24:00+03	137100.00
2462F8	2017-08-05 04:57:00+03	24800.00
24631E	2017-07-27 13:33:00+03	10800.00
246330	2017-07-19 18:37:00+03	28800.00
246417	2017-07-08 15:03:00+03	175800.00
246445	2017-07-22 21:29:00+03	10700.00
2464C9	2017-07-15 03:17:00+03	10800.00
2464ED	2017-08-14 15:26:00+03	15700.00
24650A	2017-08-12 20:11:00+03	39500.00
246524	2017-07-23 16:01:00+03	25400.00
24652D	2017-07-04 08:46:00+03	173900.00
24654B	2017-07-20 06:35:00+03	67600.00
2465B4	2017-07-17 01:34:00+03	85000.00
2465DC	2017-07-31 13:27:00+03	26700.00
24663A	2017-07-26 13:30:00+03	56000.00
24669C	2017-07-29 10:40:00+03	75300.00
24670A	2017-08-12 04:21:00+03	53300.00
24672A	2017-07-26 08:07:00+03	6000.00
246762	2017-07-09 05:02:00+03	79900.00
246786	2017-08-14 02:50:00+03	111000.00
246794	2017-08-09 06:59:00+03	10800.00
24683B	2017-07-22 09:38:00+03	23200.00
24683E	2017-06-29 10:23:00+03	67600.00
2468A0	2017-07-10 23:00:00+03	193100.00
2468B6	2017-07-25 10:39:00+03	61800.00
2468C3	2017-07-27 19:38:00+03	56000.00
246936	2017-08-03 02:47:00+03	67200.00
246946	2017-07-21 13:06:00+03	37900.00
246987	2017-08-05 00:44:00+03	56000.00
246996	2017-07-25 19:10:00+03	73100.00
246A1C	2017-07-04 07:46:00+03	160800.00
246A23	2017-08-03 01:06:00+03	13400.00
246A75	2017-07-12 05:04:00+03	44000.00
246A8B	2017-07-02 02:29:00+03	66100.00
246A9F	2017-07-21 04:48:00+03	114800.00
246AF8	2017-07-05 18:51:00+03	16400.00
246B8E	2017-07-28 07:40:00+03	28800.00
246C51	2017-07-06 11:37:00+03	39500.00
246CC1	2017-07-03 11:05:00+03	31400.00
246D24	2017-07-10 03:44:00+03	34000.00
246DB7	2017-08-12 14:01:00+03	75600.00
246DE8	2017-07-28 09:38:00+03	16400.00
246E5B	2017-08-14 04:23:00+03	21800.00
246E68	2017-07-23 05:42:00+03	6700.00
246EBE	2017-07-09 18:35:00+03	85700.00
246F4E	2017-07-04 19:56:00+03	38600.00
246F6F	2017-07-25 05:07:00+03	40600.00
246FAD	2017-07-12 12:29:00+03	56000.00
246FE5	2017-08-03 17:14:00+03	202100.00
24707D	2017-06-30 05:13:00+03	47400.00
2470BB	2017-07-28 10:49:00+03	244600.00
2470C3	2017-07-15 09:47:00+03	42600.00
2471E8	2017-08-08 15:09:00+03	118600.00
2473CD	2017-07-03 09:57:00+03	135200.00
247432	2017-08-02 17:21:00+03	123000.00
247440	2017-08-14 20:55:00+03	13000.00
247456	2017-07-16 19:06:00+03	92800.00
247481	2017-07-06 03:31:00+03	44800.00
2474A3	2017-07-02 05:55:00+03	90800.00
2474D0	2017-07-26 08:17:00+03	13600.00
247596	2017-08-11 11:56:00+03	107500.00
247598	2017-08-01 09:19:00+03	46000.00
2475DE	2017-08-07 20:40:00+03	147100.00
247626	2017-07-07 15:36:00+03	95500.00
247637	2017-07-04 02:17:00+03	144700.00
247660	2017-07-25 09:31:00+03	112600.00
2476DA	2017-08-08 02:19:00+03	51900.00
247864	2017-07-22 05:11:00+03	202100.00
247882	2017-08-08 03:48:00+03	44600.00
2478F8	2017-07-20 07:04:00+03	3400.00
247900	2017-07-10 08:24:00+03	92700.00
247918	2017-07-22 03:52:00+03	34000.00
247992	2017-07-25 04:55:00+03	117100.00
2479F9	2017-07-08 11:09:00+03	56000.00
247AC9	2017-07-16 12:23:00+03	56600.00
247ACC	2017-08-06 09:35:00+03	86900.00
247AD5	2017-07-17 11:28:00+03	15800.00
247B44	2017-08-03 16:37:00+03	277000.00
247C01	2017-08-15 09:16:00+03	26000.00
247C07	2017-07-03 12:37:00+03	23600.00
247C5D	2017-08-11 15:12:00+03	68700.00
247CC2	2017-07-15 23:25:00+03	10600.00
247D13	2017-07-18 03:59:00+03	69500.00
247D28	2017-07-12 19:32:00+03	271200.00
247D86	2017-07-21 21:22:00+03	23400.00
247DAA	2017-08-08 16:30:00+03	93900.00
247DB5	2017-07-01 22:15:00+03	23600.00
247DFB	2017-08-05 08:52:00+03	111600.00
247E61	2017-08-09 00:51:00+03	70600.00
247F8C	2017-08-07 02:21:00+03	35800.00
247F90	2017-08-02 09:48:00+03	139300.00
248010	2017-07-03 17:43:00+03	80500.00
2480A4	2017-07-24 06:05:00+03	112000.00
2480A7	2017-07-22 12:27:00+03	40100.00
2480BD	2017-07-26 04:36:00+03	186900.00
2480D9	2017-07-14 05:14:00+03	43900.00
2480E2	2017-08-03 16:14:00+03	177200.00
248104	2017-07-23 09:53:00+03	46300.00
248106	2017-07-08 01:11:00+03	93900.00
24811A	2017-07-11 01:38:00+03	187900.00
24817B	2017-08-10 02:26:00+03	32200.00
248196	2017-08-08 12:49:00+03	18000.00
2481A3	2017-08-06 16:43:00+03	83000.00
2481A4	2017-07-11 11:54:00+03	40800.00
2481D1	2017-07-21 14:53:00+03	71600.00
2481D4	2017-07-17 02:24:00+03	54400.00
2481E3	2017-07-09 04:26:00+03	13200.00
248248	2017-07-21 18:48:00+03	41600.00
24824D	2017-07-17 15:04:00+03	56000.00
248263	2017-07-21 17:09:00+03	21800.00
248271	2017-07-14 10:41:00+03	20400.00
2482A3	2017-07-26 05:25:00+03	34000.00
2482C1	2017-08-14 23:32:00+03	85700.00
2482D8	2017-08-15 15:03:00+03	183100.00
24832B	2017-07-04 12:09:00+03	35600.00
248359	2017-07-02 21:34:00+03	47400.00
24835E	2017-07-13 00:02:00+03	14000.00
248366	2017-07-07 14:55:00+03	246000.00
248392	2017-08-08 07:03:00+03	37800.00
248395	2017-08-05 20:36:00+03	40600.00
2483B4	2017-07-29 21:11:00+03	211100.00
248418	2017-06-30 03:34:00+03	14400.00
248433	2017-07-08 03:25:00+03	92600.00
24844C	2017-07-22 06:17:00+03	135400.00
248491	2017-08-09 06:26:00+03	56000.00
2484BD	2017-07-08 13:24:00+03	139300.00
24865D	2017-08-03 01:33:00+03	24700.00
2486E8	2017-06-30 03:40:00+03	28800.00
24873C	2017-08-09 10:53:00+03	27300.00
248770	2017-08-06 12:24:00+03	54800.00
2487F1	2017-07-09 13:41:00+03	25100.00
24887F	2017-07-08 15:17:00+03	44600.00
248893	2017-07-11 04:35:00+03	37900.00
2488C9	2017-08-12 08:57:00+03	46000.00
2488E0	2017-07-09 00:02:00+03	246000.00
2488FE	2017-07-21 07:55:00+03	78500.00
24892C	2017-08-09 04:59:00+03	75600.00
248996	2017-07-14 22:28:00+03	168000.00
2489D8	2017-07-25 22:05:00+03	19800.00
248A38	2017-07-11 04:08:00+03	38800.00
248AFD	2017-08-09 12:38:00+03	54300.00
248B9E	2017-08-15 03:24:00+03	148200.00
248BAB	2017-07-05 20:22:00+03	12400.00
248BC0	2017-07-13 21:00:00+03	19600.00
248C04	2017-08-02 07:29:00+03	62600.00
248C26	2017-08-12 21:40:00+03	86100.00
248C79	2017-07-20 13:51:00+03	66600.00
248CA9	2017-07-31 05:36:00+03	14800.00
248CCA	2017-07-16 22:49:00+03	39300.00
248D5C	2017-08-10 06:33:00+03	141300.00
248D6D	2017-07-31 10:05:00+03	38800.00
248DE3	2017-07-04 16:36:00+03	58600.00
248E2F	2017-07-19 17:30:00+03	47000.00
248E77	2017-08-05 21:22:00+03	56600.00
248E97	2017-07-02 23:10:00+03	16400.00
248F27	2017-07-16 09:39:00+03	24800.00
248F64	2017-07-18 07:18:00+03	25600.00
248F66	2017-07-10 06:23:00+03	65600.00
248FB0	2017-08-15 00:00:00+03	56000.00
24900D	2017-07-19 03:52:00+03	84900.00
249025	2017-07-19 19:35:00+03	173500.00
24904F	2017-08-01 01:41:00+03	182400.00
2490CA	2017-08-12 02:46:00+03	40800.00
2490CF	2017-07-06 11:09:00+03	261500.00
249133	2017-08-06 00:53:00+03	35800.00
249149	2017-08-03 04:02:00+03	24400.00
24915A	2017-08-07 19:37:00+03	18800.00
249168	2017-07-28 20:35:00+03	87000.00
24918F	2017-07-18 13:00:00+03	73600.00
2491D5	2017-07-20 01:44:00+03	21800.00
2491ED	2017-07-10 05:43:00+03	135400.00
24926B	2017-07-14 22:18:00+03	64700.00
2492A4	2017-07-23 04:17:00+03	65900.00
249326	2017-07-23 00:59:00+03	50600.00
249393	2017-08-15 09:01:00+03	71400.00
2493A8	2017-07-03 13:09:00+03	46400.00
2493BC	2017-07-08 17:33:00+03	84200.00
2493D5	2017-08-12 04:11:00+03	89600.00
2493ED	2017-07-12 21:29:00+03	38600.00
249404	2017-07-27 21:08:00+03	137600.00
24940A	2017-08-12 14:51:00+03	67700.00
249419	2017-07-27 22:27:00+03	104600.00
249469	2017-07-11 03:20:00+03	26000.00
249474	2017-07-26 01:34:00+03	6000.00
24957E	2017-07-29 22:46:00+03	89800.00
249591	2017-08-14 15:55:00+03	198400.00
249597	2017-07-06 12:46:00+03	372500.00
2495B7	2017-07-12 21:20:00+03	43600.00
2495C2	2017-07-31 18:32:00+03	30200.00
2495C4	2017-08-03 18:16:00+03	73900.00
2495DF	2017-07-16 08:36:00+03	24400.00
2495EC	2017-07-18 07:25:00+03	26800.00
2495FA	2017-07-17 11:52:00+03	46000.00
24960D	2017-08-15 13:51:00+03	28800.00
24969F	2017-06-26 07:51:00+03	132800.00
2497D5	2017-08-02 11:24:00+03	12600.00
2497FF	2017-07-22 20:22:00+03	12600.00
249846	2017-07-26 08:46:00+03	36500.00
249851	2017-08-15 10:00:00+03	65900.00
24985F	2017-07-03 20:56:00+03	13400.00
249885	2017-07-22 21:33:00+03	54500.00
249896	2017-07-05 05:23:00+03	25400.00
2498DD	2017-07-10 03:37:00+03	16400.00
249904	2017-08-05 17:46:00+03	123000.00
249907	2017-07-05 01:49:00+03	19600.00
249928	2017-07-30 03:12:00+03	46400.00
249942	2017-07-31 11:43:00+03	51900.00
249950	2017-08-13 03:19:00+03	27200.00
2499AA	2017-08-12 01:00:00+03	56000.00
249A49	2017-07-17 12:31:00+03	531400.00
249A62	2017-08-07 02:17:00+03	92800.00
249A93	2017-08-08 01:06:00+03	51900.00
249AC3	2017-07-21 20:35:00+03	99300.00
249B08	2017-07-02 19:19:00+03	273600.00
249B6B	2017-07-24 11:48:00+03	6000.00
249B72	2017-07-21 18:36:00+03	90400.00
249B94	2017-08-07 19:03:00+03	113000.00
249BE0	2017-08-02 17:41:00+03	58200.00
249BF6	2017-08-05 06:37:00+03	539400.00
249C0E	2017-07-15 04:25:00+03	29600.00
249C1B	2017-07-06 12:27:00+03	28000.00
249D2D	2017-07-17 10:41:00+03	20000.00
249D77	2017-07-21 22:55:00+03	24600.00
249DD9	2017-07-05 03:29:00+03	72400.00
249DF6	2017-07-22 02:49:00+03	56000.00
249E08	2017-07-29 05:47:00+03	217600.00
249E23	2017-06-28 14:12:00+03	131100.00
249EB6	2017-07-21 19:46:00+03	39300.00
249F14	2017-08-11 17:36:00+03	58600.00
249F1B	2017-08-03 00:30:00+03	31600.00
249F39	2017-08-15 03:41:00+03	75300.00
249F68	2017-08-14 14:14:00+03	25400.00
249F6B	2017-08-10 18:46:00+03	131100.00
249F79	2017-07-27 03:58:00+03	12600.00
249FA8	2017-07-24 21:05:00+03	43500.00
249FCB	2017-08-02 12:31:00+03	75300.00
249FD2	2017-06-29 02:30:00+03	40800.00
24A06C	2017-07-07 09:28:00+03	53700.00
24A0CB	2017-07-25 10:44:00+03	52000.00
24A135	2017-08-12 20:45:00+03	35300.00
24A15D	2017-08-08 16:54:00+03	21800.00
24A248	2017-08-10 18:54:00+03	18600.00
24A279	2017-08-15 05:03:00+03	23400.00
24A29C	2017-08-09 09:52:00+03	64700.00
24A2A5	2017-08-03 09:52:00+03	105600.00
24A2C2	2017-08-14 00:33:00+03	89600.00
24A31B	2017-07-31 03:18:00+03	104000.00
24A38A	2017-07-30 07:37:00+03	26000.00
24A398	2017-07-06 13:01:00+03	103500.00
24A3AC	2017-08-12 18:58:00+03	94000.00
24A3C7	2017-07-08 18:13:00+03	132800.00
24A3DD	2017-07-26 17:22:00+03	37900.00
24A43C	2017-08-12 17:07:00+03	199200.00
24A452	2017-08-07 02:55:00+03	90400.00
24A4C6	2017-08-07 04:09:00+03	50600.00
24A4D0	2017-08-04 21:26:00+03	92800.00
24A4DB	2017-08-08 03:27:00+03	48800.00
24A4E4	2017-08-03 15:22:00+03	52000.00
24A513	2017-08-07 13:58:00+03	6700.00
24A560	2017-07-27 08:47:00+03	35600.00
24A5A6	2017-08-01 02:53:00+03	27000.00
24A5CC	2017-08-02 19:30:00+03	134000.00
24A5E5	2017-08-15 14:16:00+03	76800.00
24A5E7	2017-07-28 19:32:00+03	187800.00
24A663	2017-07-25 04:07:00+03	55800.00
24A6BC	2017-08-07 22:05:00+03	33200.00
24A70D	2017-07-18 16:19:00+03	59800.00
24A740	2017-07-20 19:43:00+03	28000.00
24A795	2017-07-30 05:24:00+03	8800.00
24A79C	2017-07-12 03:25:00+03	116000.00
24A811	2017-07-16 23:37:00+03	112300.00
24A8C2	2017-07-26 23:47:00+03	66000.00
24A8CC	2017-08-05 06:58:00+03	59000.00
24A8FC	2017-07-27 02:41:00+03	53600.00
24A93C	2017-07-11 02:57:00+03	32800.00
24AA79	2017-07-08 10:32:00+03	26700.00
24AA9B	2017-08-08 03:01:00+03	12000.00
24AB07	2017-08-03 18:20:00+03	28800.00
24AB16	2017-07-14 22:10:00+03	114800.00
24AB41	2017-07-29 18:37:00+03	135200.00
24ABBB	2017-08-06 08:57:00+03	96300.00
24AC61	2017-07-27 11:13:00+03	45200.00
24AC6A	2017-08-12 17:43:00+03	15400.00
24AD21	2017-08-03 04:42:00+03	87200.00
24AD55	2017-07-25 05:58:00+03	664200.00
24AD81	2017-08-03 00:11:00+03	106400.00
24ADD3	2017-07-17 09:19:00+03	80900.00
24AE4C	2017-07-23 05:47:00+03	23200.00
24AE57	2017-07-26 09:36:00+03	7200.00
24AE71	2017-07-28 11:20:00+03	58800.00
24AEDB	2017-08-09 14:35:00+03	67600.00
24AEF2	2017-07-26 08:23:00+03	85600.00
24AF70	2017-07-19 11:20:00+03	128600.00
24AF7F	2017-07-13 18:07:00+03	136500.00
24AFD9	2017-08-12 19:49:00+03	28400.00
24B050	2017-08-15 03:59:00+03	99200.00
24B0BB	2017-07-17 12:47:00+03	55800.00
24B109	2017-07-10 17:46:00+03	27900.00
24B118	2017-07-29 00:54:00+03	24400.00
24B142	2017-08-08 02:55:00+03	115200.00
24B193	2017-07-28 13:23:00+03	28800.00
24B254	2017-07-22 19:00:00+03	273000.00
24B300	2017-07-10 14:56:00+03	55800.00
24B31D	2017-08-06 05:04:00+03	23400.00
24B388	2017-08-06 12:11:00+03	370900.00
24B3A3	2017-07-09 04:03:00+03	62600.00
24B422	2017-07-03 09:46:00+03	34800.00
24B483	2017-07-21 05:20:00+03	62000.00
24B4B8	2017-07-19 09:52:00+03	16400.00
24B4EA	2017-07-26 00:34:00+03	65500.00
24B56D	2017-07-20 07:34:00+03	96300.00
24B570	2017-07-28 04:31:00+03	21800.00
24B5DE	2017-07-29 13:37:00+03	139900.00
24B63F	2017-07-24 03:14:00+03	67600.00
24B6EE	2017-07-25 16:56:00+03	47200.00
24B72F	2017-08-15 17:51:00+03	74300.00
24B760	2017-07-10 13:52:00+03	8200.00
24B7B3	2017-08-15 14:58:00+03	56600.00
24B7CE	2017-07-29 08:20:00+03	46400.00
24B7D0	2017-07-21 14:37:00+03	82000.00
24B7DC	2017-07-22 19:27:00+03	179500.00
24B842	2017-08-01 16:09:00+03	25400.00
24B84D	2017-07-18 03:55:00+03	131100.00
24B887	2017-06-30 20:02:00+03	106100.00
24B8BE	2017-07-07 15:34:00+03	112000.00
24B8C9	2017-07-14 04:53:00+03	116800.00
24B90A	2017-08-02 17:46:00+03	248300.00
24B92D	2017-07-01 15:01:00+03	13400.00
24B9C3	2017-07-02 01:34:00+03	40800.00
24BA6D	2017-07-12 11:06:00+03	48800.00
24BAB0	2017-07-02 23:44:00+03	20400.00
24BAB5	2017-07-22 03:57:00+03	71200.00
24BAF0	2017-07-17 02:52:00+03	57500.00
24BB2C	2017-08-04 10:01:00+03	68800.00
24BB4D	2017-07-04 11:31:00+03	13800.00
24BC21	2017-07-18 18:04:00+03	56000.00
24BC40	2017-07-13 05:11:00+03	18600.00
24BC9A	2017-07-23 19:31:00+03	64100.00
24BC9F	2017-07-14 23:30:00+03	67600.00
24BCA3	2017-07-13 10:34:00+03	69000.00
24BCA4	2017-07-25 13:13:00+03	19600.00
24BCBC	2017-08-12 16:10:00+03	12600.00
24BCE2	2017-07-07 00:20:00+03	6300.00
24BCF6	2017-07-25 18:01:00+03	54800.00
24BD00	2017-07-05 05:57:00+03	102600.00
24BD43	2017-06-30 16:44:00+03	38800.00
24BD53	2017-08-09 08:03:00+03	45200.00
24BD91	2017-07-19 09:00:00+03	25200.00
24BE57	2017-08-03 06:29:00+03	8200.00
24BE7D	2017-08-10 18:51:00+03	12600.00
24BF19	2017-07-10 12:34:00+03	65500.00
24BF92	2017-08-04 22:06:00+03	28800.00
24C047	2017-07-22 14:11:00+03	21200.00
24C0AD	2017-08-15 16:10:00+03	177200.00
24C0E5	2017-07-17 18:34:00+03	25100.00
24C153	2017-08-07 08:36:00+03	36200.00
24C156	2017-08-05 02:08:00+03	69500.00
24C224	2017-08-10 09:32:00+03	67800.00
24C29D	2017-07-20 09:25:00+03	93400.00
24C2BA	2017-07-25 06:41:00+03	134600.00
24C311	2017-07-24 13:18:00+03	20500.00
24C318	2017-07-03 17:09:00+03	26800.00
24C32A	2017-08-06 15:04:00+03	44000.00
24C34F	2017-07-15 09:48:00+03	29400.00
24C365	2017-08-11 02:17:00+03	67200.00
24C376	2017-08-08 11:45:00+03	277800.00
24C3B8	2017-06-30 01:23:00+03	56200.00
24C3D1	2017-08-09 10:58:00+03	38600.00
24C3F0	2017-07-23 17:17:00+03	88400.00
24C434	2017-07-16 15:05:00+03	93400.00
24C470	2017-08-02 03:16:00+03	11600.00
24C4B9	2017-08-10 13:09:00+03	133100.00
24C4BF	2017-08-04 15:02:00+03	143200.00
24C4FA	2017-07-22 02:10:00+03	19600.00
24C4FD	2017-07-08 12:07:00+03	53600.00
24C5C2	2017-07-23 18:17:00+03	52000.00
24C5FA	2017-07-30 10:35:00+03	67700.00
24C63A	2017-07-11 11:37:00+03	51600.00
24C7A6	2017-07-27 22:06:00+03	234700.00
24C7DC	2017-07-08 01:54:00+03	32700.00
24C7E8	2017-07-30 16:35:00+03	71600.00
24C81A	2017-08-14 06:44:00+03	46400.00
24C84E	2017-08-04 10:03:00+03	40000.00
24C8F0	2017-07-14 11:33:00+03	24300.00
24C911	2017-08-02 15:56:00+03	56000.00
24C930	2017-07-16 16:59:00+03	23600.00
24C94E	2017-08-10 04:43:00+03	26000.00
24C989	2017-07-28 20:08:00+03	92000.00
24C9A7	2017-08-15 07:44:00+03	539400.00
24CA20	2017-07-29 12:12:00+03	132800.00
24CA5B	2017-07-04 23:59:00+03	46000.00
24CA6F	2017-07-23 15:57:00+03	117900.00
24CA97	2017-07-12 15:03:00+03	56900.00
24CA98	2017-08-01 01:39:00+03	25400.00
24CAA9	2017-07-16 14:35:00+03	23200.00
24CC14	2017-07-14 22:55:00+03	36200.00
24CC1C	2017-07-19 17:57:00+03	44700.00
24CCA8	2017-07-14 11:57:00+03	23600.00
24CCB0	2017-08-15 07:02:00+03	26800.00
24CCC2	2017-07-31 17:26:00+03	54800.00
24CD82	2017-08-03 08:22:00+03	133100.00
24CDA5	2017-07-08 08:17:00+03	12600.00
24CDB0	2017-07-24 16:08:00+03	129600.00
24CE14	2017-07-31 14:55:00+03	102000.00
24CE60	2017-07-02 15:25:00+03	64300.00
24CECE	2017-08-09 06:06:00+03	355200.00
24CF61	2017-06-30 02:59:00+03	56800.00
24CF79	2017-08-06 10:13:00+03	34200.00
24CFA3	2017-07-05 16:07:00+03	86600.00
24CFA7	2017-07-26 15:13:00+03	90400.00
24D05A	2017-07-09 21:55:00+03	23200.00
24D08E	2017-07-27 16:26:00+03	28800.00
24D098	2017-07-31 18:46:00+03	125200.00
24D107	2017-08-12 10:35:00+03	6300.00
24D175	2017-07-11 11:17:00+03	55800.00
24D1F0	2017-08-06 21:08:00+03	12600.00
24D203	2017-06-28 04:22:00+03	55800.00
24D29A	2017-07-07 12:53:00+03	10700.00
24D29B	2017-07-21 09:56:00+03	45200.00
24D343	2017-07-24 05:02:00+03	51900.00
24D349	2017-08-14 22:11:00+03	32800.00
24D44A	2017-07-11 09:17:00+03	75300.00
24D44F	2017-07-28 16:11:00+03	38400.00
24D47E	2017-07-28 02:42:00+03	96300.00
24D48A	2017-07-15 11:28:00+03	160700.00
24D4BF	2017-07-28 12:09:00+03	142400.00
24D4C1	2017-08-09 16:52:00+03	77600.00
24D56C	2017-07-25 22:57:00+03	28800.00
24D5AD	2017-07-08 05:01:00+03	23400.00
24D5C7	2017-07-08 20:30:00+03	224000.00
24D6A6	2017-08-03 15:40:00+03	16800.00
24D6C1	2017-07-07 10:19:00+03	199200.00
24D754	2017-07-03 16:21:00+03	46000.00
24D7A1	2017-07-17 08:19:00+03	12000.00
24D7D0	2017-07-18 23:06:00+03	47000.00
24D7D2	2017-08-13 22:23:00+03	88500.00
24D7F1	2017-07-12 01:29:00+03	97500.00
24D7F2	2017-08-12 21:50:00+03	26000.00
24D804	2017-07-02 01:24:00+03	51800.00
24D810	2017-08-10 19:00:00+03	141400.00
24D827	2017-08-07 17:36:00+03	82900.00
24D849	2017-08-13 18:09:00+03	91700.00
24D88C	2017-08-07 11:10:00+03	14000.00
24D8DD	2017-07-12 11:17:00+03	14400.00
24D989	2017-08-08 02:34:00+03	8400.00
24DA51	2017-08-15 05:48:00+03	6000.00
24DA65	2017-08-02 21:22:00+03	22600.00
24DA79	2017-06-28 11:53:00+03	131600.00
24DA81	2017-08-11 04:15:00+03	65100.00
24DADA	2017-08-02 05:46:00+03	30300.00
24DB77	2017-07-20 10:35:00+03	111600.00
24DC04	2017-08-12 00:29:00+03	94000.00
24DC6A	2017-07-18 11:29:00+03	15400.00
24DC8F	2017-08-04 03:21:00+03	53800.00
24DC9D	2017-07-15 18:25:00+03	26700.00
24DCA0	2017-07-18 17:08:00+03	54500.00
24DCA5	2017-07-26 05:30:00+03	32800.00
24DCD2	2017-07-07 21:34:00+03	40800.00
24DCDB	2017-08-07 22:34:00+03	29600.00
24DCF0	2017-07-24 16:59:00+03	95500.00
24DD10	2017-07-03 09:47:00+03	74300.00
24DD71	2017-07-20 04:13:00+03	70700.00
24DDA4	2017-07-14 00:51:00+03	46500.00
24DDBA	2017-08-02 10:54:00+03	6000.00
24DDDB	2017-07-22 04:52:00+03	85700.00
24DDE4	2017-07-12 22:30:00+03	34600.00
24DE3B	2017-07-30 18:43:00+03	160800.00
24DE49	2017-08-05 06:41:00+03	3700.00
24DE4B	2017-07-25 22:57:00+03	36200.00
24DE5E	2017-08-01 18:58:00+03	386300.00
24DE63	2017-07-13 07:21:00+03	48800.00
24DE8B	2017-08-03 02:00:00+03	49600.00
24DEDC	2017-07-20 19:00:00+03	47200.00
24DEF1	2017-07-15 04:18:00+03	20500.00
24DEF5	2017-08-12 17:25:00+03	49200.00
24DF13	2017-07-23 10:58:00+03	56000.00
24DF27	2017-07-24 06:01:00+03	59800.00
24DF3A	2017-07-28 15:23:00+03	31400.00
24DF71	2017-08-11 16:39:00+03	21000.00
24E01D	2017-08-01 22:53:00+03	23400.00
24E020	2017-07-31 10:49:00+03	8000.00
24E062	2017-07-05 16:56:00+03	46400.00
24E06D	2017-08-07 12:08:00+03	40400.00
24E084	2017-08-15 06:04:00+03	81300.00
24E0B7	2017-07-28 12:12:00+03	30800.00
24E10E	2017-07-07 14:05:00+03	30000.00
24E111	2017-08-02 12:41:00+03	99300.00
24E1DC	2017-07-09 16:10:00+03	260900.00
24E266	2017-08-10 15:29:00+03	69000.00
24E2E8	2017-07-22 17:25:00+03	53000.00
24E3D0	2017-08-10 15:13:00+03	129200.00
24E42E	2017-07-10 04:38:00+03	52500.00
24E442	2017-07-14 10:46:00+03	39500.00
24E44C	2017-07-14 22:00:00+03	52000.00
24E5B7	2017-07-17 22:29:00+03	137100.00
24E5CF	2017-07-17 16:06:00+03	28800.00
24E5D8	2017-07-15 02:33:00+03	89600.00
24E613	2017-08-09 15:52:00+03	26800.00
24E61D	2017-07-23 17:52:00+03	73900.00
24E6C9	2017-07-24 01:40:00+03	56100.00
24E6E8	2017-07-07 13:27:00+03	12400.00
24E6F7	2017-07-19 21:52:00+03	28000.00
24E6F9	2017-07-16 10:30:00+03	37900.00
24E701	2017-08-04 21:23:00+03	119300.00
24E71D	2017-08-10 22:39:00+03	42100.00
24E745	2017-08-11 12:33:00+03	687000.00
24E746	2017-07-06 20:33:00+03	16400.00
24E769	2017-07-08 21:13:00+03	47100.00
24E786	2017-07-21 12:32:00+03	37700.00
24E7DD	2017-07-23 09:21:00+03	15900.00
24E83A	2017-07-28 01:26:00+03	38800.00
24E8B0	2017-08-08 00:20:00+03	72600.00
24E8CA	2017-07-02 22:38:00+03	96800.00
24E931	2017-07-10 12:53:00+03	117600.00
24E9B3	2017-07-05 13:46:00+03	46300.00
24E9F6	2017-08-05 20:27:00+03	40000.00
24EA0C	2017-07-14 13:12:00+03	38600.00
24EA1B	2017-07-31 05:04:00+03	52200.00
24EA8D	2017-08-13 02:32:00+03	75300.00
24EACF	2017-07-30 19:47:00+03	56000.00
24EB01	2017-08-07 09:15:00+03	28800.00
24EB6E	2017-07-31 02:22:00+03	57400.00
24EB77	2017-07-18 00:35:00+03	165500.00
24EC01	2017-06-25 03:57:00+03	56600.00
24EC1A	2017-08-15 15:13:00+03	52900.00
24EC4B	2017-07-14 23:24:00+03	35200.00
24EC60	2017-08-10 01:19:00+03	85000.00
24EC87	2017-08-05 19:30:00+03	179400.00
24EC8F	2017-07-16 16:05:00+03	17200.00
24EC98	2017-07-10 09:48:00+03	86800.00
24ECA1	2017-07-15 05:51:00+03	169600.00
24ECAA	2017-07-28 05:10:00+03	83600.00
24ECC3	2017-07-31 08:36:00+03	131600.00
24ECEB	2017-07-30 15:41:00+03	57600.00
24ED26	2017-07-10 09:29:00+03	43200.00
24ED2D	2017-07-26 05:42:00+03	70500.00
24EDC5	2017-07-16 14:37:00+03	92800.00
24EE14	2017-07-25 06:50:00+03	47100.00
24EE20	2017-08-10 05:55:00+03	25600.00
24EE42	2017-07-25 04:44:00+03	6700.00
24EF01	2017-08-06 12:17:00+03	44000.00
24EF26	2017-08-02 10:35:00+03	56000.00
24EF62	2017-08-11 21:28:00+03	80000.00
24F019	2017-07-30 00:05:00+03	75300.00
24F09A	2017-07-31 09:43:00+03	23200.00
24F117	2017-07-13 23:23:00+03	16400.00
24F156	2017-08-05 15:46:00+03	56000.00
24F16D	2017-07-04 17:48:00+03	51600.00
24F1AF	2017-07-14 03:38:00+03	28800.00
24F1EA	2017-08-10 11:11:00+03	124200.00
24F224	2017-07-21 22:23:00+03	28800.00
24F236	2017-07-28 09:49:00+03	58000.00
24F266	2017-08-11 11:46:00+03	93900.00
24F2E1	2017-07-24 03:04:00+03	169300.00
24F312	2017-08-02 20:23:00+03	13400.00
24F366	2017-08-15 04:30:00+03	155600.00
24F367	2017-07-01 02:44:00+03	22000.00
24F37D	2017-07-15 16:40:00+03	227200.00
24F37E	2017-07-09 11:59:00+03	69100.00
24F42E	2017-07-21 07:29:00+03	91000.00
24F477	2017-08-11 20:41:00+03	236700.00
24F4AB	2017-07-28 20:56:00+03	56600.00
24F4AC	2017-07-24 21:39:00+03	16400.00
24F545	2017-07-09 00:44:00+03	29400.00
24F563	2017-07-25 13:32:00+03	136800.00
24F5D9	2017-07-16 01:58:00+03	14400.00
24F646	2017-08-15 15:13:00+03	131100.00
24F66B	2017-07-10 05:52:00+03	77000.00
24F66F	2017-08-14 16:40:00+03	66700.00
24F721	2017-06-30 06:28:00+03	25400.00
24F757	2017-08-15 13:32:00+03	93500.00
24F88B	2017-07-11 01:33:00+03	46300.00
24F89D	2017-07-29 02:35:00+03	128800.00
24F8AA	2017-07-01 20:17:00+03	14100.00
24F8D5	2017-06-30 12:43:00+03	67200.00
24F8D7	2017-08-12 14:54:00+03	26000.00
24F8E7	2017-07-08 05:39:00+03	52700.00
24F93E	2017-07-12 07:07:00+03	53400.00
24F989	2017-08-12 01:55:00+03	32900.00
24FA02	2017-07-07 11:28:00+03	58400.00
24FA57	2017-08-15 08:50:00+03	36700.00
24FABE	2017-07-20 00:04:00+03	104200.00
24FACD	2017-08-14 08:35:00+03	28000.00
24FB5C	2017-07-04 15:02:00+03	39800.00
24FB66	2017-08-05 10:28:00+03	46300.00
24FBB7	2017-08-04 01:45:00+03	53600.00
24FBEB	2017-07-02 20:22:00+03	19600.00
24FC36	2017-07-23 20:19:00+03	671000.00
24FC4D	2017-08-11 11:10:00+03	21400.00
24FC77	2017-08-03 17:20:00+03	22000.00
24FC82	2017-07-06 03:47:00+03	52600.00
24FCAD	2017-08-13 17:01:00+03	47100.00
24FCD4	2017-08-06 21:13:00+03	107400.00
24FCD7	2017-06-29 16:37:00+03	26800.00
24FCEE	2017-07-29 23:50:00+03	77000.00
24FD55	2017-08-05 16:52:00+03	27200.00
24FD6F	2017-07-10 20:04:00+03	33100.00
24FD7A	2017-07-13 16:05:00+03	130900.00
24FD92	2017-07-18 19:19:00+03	108000.00
24FE1D	2017-07-18 16:36:00+03	246000.00
24FE6A	2017-08-06 10:20:00+03	141700.00
24FF13	2017-08-07 11:45:00+03	93500.00
24FF61	2017-07-08 19:06:00+03	26000.00
24FFA5	2017-07-16 01:32:00+03	184500.00
250000	2017-07-20 17:06:00+03	620800.00
250021	2017-07-04 09:08:00+03	67000.00
250026	2017-08-01 11:02:00+03	270800.00
250120	2017-07-05 10:58:00+03	82200.00
25014B	2017-07-10 01:10:00+03	22100.00
25014D	2017-07-15 01:23:00+03	47000.00
2501A3	2017-07-22 06:23:00+03	271100.00
250205	2017-07-31 18:44:00+03	28800.00
250255	2017-07-31 05:29:00+03	99200.00
25026F	2017-08-08 17:22:00+03	64400.00
250279	2017-08-13 18:18:00+03	35600.00
2502C9	2017-07-25 23:59:00+03	75600.00
250310	2017-08-11 21:54:00+03	56000.00
250386	2017-07-28 08:54:00+03	38200.00
25039A	2017-07-25 02:13:00+03	51600.00
25041C	2017-08-10 03:57:00+03	13600.00
2504DA	2017-07-30 02:54:00+03	78600.00
25059B	2017-07-02 00:23:00+03	26200.00
2505B5	2017-07-30 14:45:00+03	34600.00
25062E	2017-08-10 14:21:00+03	26800.00
25070C	2017-07-01 07:04:00+03	58900.00
250723	2017-08-04 15:12:00+03	51600.00
250760	2017-07-01 02:45:00+03	39300.00
2507C6	2017-07-03 00:05:00+03	128800.00
25083C	2017-07-29 09:41:00+03	111600.00
250891	2017-07-09 16:30:00+03	28800.00
2508BC	2017-08-01 11:17:00+03	44000.00
2508BF	2017-07-10 09:38:00+03	39800.00
2508C0	2017-07-27 12:18:00+03	26800.00
2508C6	2017-07-17 04:33:00+03	53600.00
2508C8	2017-07-10 14:10:00+03	168000.00
2508D8	2017-07-05 11:47:00+03	56600.00
25094F	2017-08-05 03:15:00+03	28800.00
2509E1	2017-07-21 11:57:00+03	56000.00
250A09	2017-08-09 21:23:00+03	6700.00
250A6F	2017-07-16 16:28:00+03	113200.00
250AF1	2017-08-08 01:28:00+03	44500.00
250B1F	2017-08-07 00:33:00+03	112000.00
250B4C	2017-08-07 16:17:00+03	56000.00
250B5F	2017-07-09 16:43:00+03	265700.00
250B76	2017-07-10 00:53:00+03	84800.00
250BA9	2017-07-21 12:54:00+03	46400.00
250BB6	2017-08-06 04:10:00+03	28800.00
250BE3	2017-08-11 07:23:00+03	46000.00
250C20	2017-08-02 03:38:00+03	35200.00
250C29	2017-07-30 22:42:00+03	56000.00
250C38	2017-08-03 14:45:00+03	27800.00
250D63	2017-07-05 02:05:00+03	18600.00
250D7B	2017-08-10 11:49:00+03	6700.00
250D82	2017-07-13 15:57:00+03	92900.00
250EC6	2017-08-06 12:29:00+03	60800.00
250ED8	2017-07-24 04:06:00+03	29600.00
250EEA	2017-08-12 20:22:00+03	30900.00
250FAF	2017-08-01 13:06:00+03	17800.00
250FE1	2017-08-09 19:45:00+03	86300.00
250FEC	2017-07-01 22:38:00+03	40800.00
250FF0	2017-07-09 06:56:00+03	56000.00
251008	2017-07-10 22:36:00+03	7400.00
2510C2	2017-07-06 19:43:00+03	99200.00
2511A6	2017-07-26 20:11:00+03	46400.00
2512A2	2017-07-30 18:42:00+03	30000.00
2512CF	2017-07-06 10:54:00+03	42800.00
2512D4	2017-07-27 20:58:00+03	58600.00
251356	2017-07-08 12:26:00+03	23400.00
2513FF	2017-08-11 18:21:00+03	43000.00
251424	2017-08-03 15:01:00+03	29600.00
25143D	2017-07-05 08:40:00+03	78300.00
25148B	2017-07-14 14:07:00+03	90400.00
2514CD	2017-08-07 09:13:00+03	64800.00
2514ED	2017-07-15 05:09:00+03	46000.00
25153A	2017-07-23 17:20:00+03	65000.00
25155B	2017-08-05 03:54:00+03	73500.00
25155C	2017-07-07 12:49:00+03	36400.00
2515A1	2017-07-26 10:52:00+03	26000.00
2515CA	2017-07-14 15:39:00+03	46300.00
251601	2017-08-12 19:29:00+03	8400.00
25161C	2017-08-10 22:20:00+03	60400.00
251623	2017-07-28 10:32:00+03	19800.00
251632	2017-08-10 13:41:00+03	99300.00
25166E	2017-08-13 08:20:00+03	73300.00
2516FF	2017-08-15 12:48:00+03	12600.00
251749	2017-07-01 04:58:00+03	170000.00
251753	2017-07-31 16:11:00+03	107400.00
251758	2017-08-03 15:03:00+03	66000.00
25175E	2017-08-01 23:42:00+03	149100.00
25176C	2017-07-11 20:23:00+03	51600.00
251794	2017-07-06 17:18:00+03	21000.00
2517E3	2017-06-29 01:59:00+03	27800.00
251867	2017-07-12 00:39:00+03	12600.00
2518CD	2017-07-08 01:52:00+03	132800.00
2518EA	2017-08-15 06:17:00+03	50700.00
2519A2	2017-08-04 23:04:00+03	36800.00
2519EC	2017-07-26 00:23:00+03	26400.00
2519FF	2017-08-10 00:40:00+03	124200.00
251A05	2017-08-11 13:55:00+03	75300.00
251A31	2017-07-17 10:01:00+03	99300.00
251A61	2017-08-01 11:37:00+03	81900.00
251B1F	2017-07-25 22:50:00+03	123000.00
251B3C	2017-07-28 02:53:00+03	79000.00
251B85	2017-07-05 23:00:00+03	46300.00
251C7C	2017-08-13 11:54:00+03	6800.00
251CA5	2017-07-16 02:54:00+03	30800.00
251D1C	2017-07-07 01:51:00+03	46400.00
251D77	2017-07-21 07:53:00+03	99300.00
251D7F	2017-07-24 21:43:00+03	46200.00
251D91	2017-07-27 09:35:00+03	43600.00
251DA3	2017-07-17 12:14:00+03	44100.00
251DA5	2017-07-28 20:42:00+03	58000.00
251DA9	2017-07-18 12:52:00+03	68000.00
251DC8	2017-07-13 04:17:00+03	46700.00
251DE7	2017-06-29 03:00:00+03	117800.00
251DFA	2017-07-23 04:37:00+03	111600.00
251E50	2017-07-12 11:37:00+03	36000.00
251EA1	2017-08-02 09:04:00+03	13400.00
251ED5	2017-08-09 11:06:00+03	24400.00
251F1E	2017-07-15 11:47:00+03	58800.00
251F3C	2017-08-14 17:13:00+03	26800.00
251F4B	2017-07-12 13:09:00+03	246000.00
251FAD	2017-07-28 11:04:00+03	20600.00
251FD1	2017-08-07 21:51:00+03	55800.00
252062	2017-07-19 07:15:00+03	104900.00
2520B2	2017-07-28 05:28:00+03	33300.00
2520F5	2017-08-13 18:05:00+03	16800.00
252113	2017-07-04 17:22:00+03	32800.00
252130	2017-07-16 00:44:00+03	56000.00
25213A	2017-07-13 16:46:00+03	56000.00
25213E	2017-08-04 23:22:00+03	23600.00
2521BD	2017-07-27 16:24:00+03	38400.00
2521ED	2017-08-09 20:34:00+03	51900.00
252223	2017-07-29 20:52:00+03	228700.00
25224C	2017-07-04 09:51:00+03	38600.00
25228B	2017-08-02 18:21:00+03	150600.00
252395	2017-08-09 23:27:00+03	107500.00
2523D9	2017-08-07 13:57:00+03	12400.00
2524A9	2017-07-14 16:25:00+03	189200.00
2524B6	2017-08-01 01:45:00+03	32200.00
2524CB	2017-07-06 01:24:00+03	246000.00
2524EA	2017-08-01 17:06:00+03	27800.00
25251F	2017-07-05 23:36:00+03	55600.00
25258A	2017-07-25 06:32:00+03	102100.00
2525AF	2017-07-25 11:28:00+03	78800.00
2525DF	2017-07-07 21:55:00+03	91200.00
2525EE	2017-08-12 20:32:00+03	66000.00
2526AA	2017-07-25 21:54:00+03	56600.00
25270D	2017-07-07 21:44:00+03	100600.00
25272D	2017-07-27 03:39:00+03	37900.00
252746	2017-07-30 16:02:00+03	66600.00
252777	2017-07-14 01:53:00+03	28000.00
25278C	2017-08-02 11:07:00+03	79600.00
2527AB	2017-07-18 22:25:00+03	36200.00
2527F6	2017-07-14 15:03:00+03	112000.00
252832	2017-07-28 07:38:00+03	46300.00
252847	2017-07-07 14:14:00+03	252200.00
25285A	2017-08-08 08:00:00+03	34000.00
252886	2017-06-26 03:47:00+03	88500.00
252892	2017-08-05 01:36:00+03	135400.00
25299E	2017-07-01 08:39:00+03	57400.00
2529BD	2017-08-13 10:24:00+03	89700.00
2529C3	2017-08-08 04:16:00+03	92800.00
252A20	2017-07-28 22:43:00+03	189200.00
252B8F	2017-07-22 23:01:00+03	88500.00
252BA4	2017-07-19 20:32:00+03	135200.00
252BF8	2017-07-18 16:06:00+03	95200.00
252C26	2017-07-28 01:31:00+03	49100.00
252C5E	2017-08-01 08:10:00+03	46200.00
252C90	2017-07-26 15:23:00+03	24200.00
252D04	2017-07-10 21:45:00+03	34100.00
252D62	2017-08-04 11:54:00+03	37900.00
252D8D	2017-07-16 18:05:00+03	21400.00
252E44	2017-07-06 13:54:00+03	26000.00
252E4A	2017-07-06 09:16:00+03	112000.00
252E52	2017-07-17 16:08:00+03	202400.00
252E5A	2017-07-30 11:42:00+03	36200.00
252E5B	2017-07-09 16:06:00+03	123000.00
252EBA	2017-08-03 01:40:00+03	56000.00
252F1A	2017-08-08 12:40:00+03	76600.00
252F3E	2017-07-05 02:56:00+03	27200.00
252F57	2017-07-23 05:20:00+03	13600.00
252FB1	2017-07-20 16:20:00+03	68800.00
252FF6	2017-07-13 10:50:00+03	91100.00
253037	2017-07-30 21:54:00+03	40800.00
25306E	2017-07-31 16:36:00+03	133100.00
253084	2017-07-19 11:11:00+03	55800.00
2530D1	2017-08-08 08:55:00+03	31100.00
253103	2017-07-23 06:15:00+03	43900.00
25316C	2017-07-17 11:01:00+03	73200.00
25319F	2017-07-16 01:58:00+03	60500.00
2531C0	2017-08-09 03:56:00+03	26000.00
253263	2017-08-02 15:41:00+03	48800.00
253264	2017-07-20 12:43:00+03	47200.00
25328B	2017-07-02 11:31:00+03	155600.00
2532CB	2017-08-13 18:43:00+03	55600.00
2532CE	2017-07-09 18:11:00+03	60400.00
2532DD	2017-07-02 14:58:00+03	21800.00
2532F3	2017-08-07 08:32:00+03	45200.00
25330F	2017-07-07 02:20:00+03	56000.00
253315	2017-08-07 15:42:00+03	55800.00
253347	2017-07-26 08:58:00+03	38200.00
25336E	2017-07-20 07:28:00+03	88600.00
2533A3	2017-08-05 05:36:00+03	70700.00
2533DB	2017-07-10 12:02:00+03	57600.00
25340F	2017-08-15 05:18:00+03	32800.00
25341B	2017-07-15 10:35:00+03	47800.00
253421	2017-07-30 10:21:00+03	27800.00
25348D	2017-08-05 12:46:00+03	52900.00
253508	2017-07-05 10:31:00+03	149300.00
25352F	2017-07-03 05:57:00+03	25400.00
25354D	2017-07-01 17:55:00+03	20600.00
253559	2017-07-04 10:02:00+03	64600.00
25357C	2017-08-15 00:58:00+03	89000.00
2535E8	2017-08-13 11:21:00+03	38800.00
2537CD	2017-07-18 07:40:00+03	29400.00
2537E0	2017-08-14 19:18:00+03	67600.00
25382C	2017-07-31 02:55:00+03	133200.00
253845	2017-08-04 00:43:00+03	28000.00
253876	2017-08-10 19:19:00+03	43900.00
2538A3	2017-07-07 03:33:00+03	48800.00
2538D4	2017-07-02 21:07:00+03	6700.00
2538F6	2017-07-23 00:36:00+03	14800.00
253924	2017-07-03 15:51:00+03	136800.00
2539B6	2017-06-29 06:54:00+03	33300.00
2539D0	2017-08-13 08:31:00+03	79600.00
253A3E	2017-07-11 09:38:00+03	92900.00
253B00	2017-08-06 20:23:00+03	28400.00
253B38	2017-08-06 08:56:00+03	66000.00
253B9D	2017-08-07 13:55:00+03	32800.00
253BA7	2017-07-15 02:44:00+03	26000.00
253BCD	2017-07-08 23:32:00+03	138000.00
253C2B	2017-08-09 14:41:00+03	28000.00
253C3F	2017-07-11 07:37:00+03	133200.00
253C5B	2017-07-19 08:44:00+03	46000.00
253C74	2017-07-07 17:47:00+03	166900.00
253CF4	2017-08-10 22:48:00+03	96100.00
253D1F	2017-07-19 15:09:00+03	43600.00
253D23	2017-07-17 10:06:00+03	124200.00
253D36	2017-07-25 17:14:00+03	85000.00
253D91	2017-07-07 12:51:00+03	13400.00
253D9A	2017-07-23 08:05:00+03	115600.00
253E1B	2017-07-30 00:36:00+03	43600.00
253E90	2017-07-29 17:47:00+03	232800.00
253E9B	2017-07-17 02:15:00+03	114800.00
253EE7	2017-08-04 02:49:00+03	28800.00
253EFC	2017-07-28 02:23:00+03	246000.00
253F05	2017-07-06 20:29:00+03	66600.00
253F6D	2017-07-12 18:20:00+03	75300.00
253F75	2017-07-25 04:56:00+03	57600.00
253F86	2017-08-12 06:30:00+03	123000.00
253FBC	2017-07-22 11:08:00+03	55800.00
253FD0	2017-07-25 18:45:00+03	49100.00
254005	2017-07-30 02:48:00+03	56600.00
254007	2017-08-13 22:59:00+03	75600.00
25401A	2017-08-08 01:41:00+03	6300.00
25405E	2017-07-07 08:15:00+03	205000.00
254074	2017-07-30 09:54:00+03	41800.00
2540C5	2017-08-05 20:51:00+03	40800.00
2540E7	2017-08-06 07:14:00+03	24400.00
2540FD	2017-07-25 01:16:00+03	48800.00
25410A	2017-08-05 04:00:00+03	179300.00
254169	2017-07-06 05:29:00+03	62600.00
25419D	2017-07-08 17:58:00+03	62600.00
2542B5	2017-06-30 07:22:00+03	11800.00
254331	2017-07-12 17:07:00+03	44400.00
254335	2017-07-10 18:05:00+03	71900.00
254382	2017-07-19 01:43:00+03	55000.00
25438A	2017-07-11 16:12:00+03	205600.00
2543B3	2017-07-29 13:22:00+03	179200.00
254407	2017-08-12 12:13:00+03	36900.00
254431	2017-07-12 23:50:00+03	36200.00
254461	2017-08-02 22:31:00+03	57400.00
2544D9	2017-08-15 00:40:00+03	109800.00
2544DA	2017-07-31 11:52:00+03	100600.00
25459A	2017-07-30 03:00:00+03	32800.00
25463F	2017-07-15 18:16:00+03	57500.00
254689	2017-07-17 16:05:00+03	15400.00
2546F3	2017-07-21 11:40:00+03	44500.00
254703	2017-08-10 22:56:00+03	50600.00
25471D	2017-07-30 21:23:00+03	58400.00
254774	2017-08-14 20:42:00+03	25100.00
254778	2017-07-10 13:03:00+03	43000.00
254791	2017-08-11 15:37:00+03	108700.00
25482D	2017-07-11 11:11:00+03	39000.00
254837	2017-07-25 10:39:00+03	86800.00
254857	2017-07-28 15:30:00+03	96800.00
254862	2017-08-07 16:32:00+03	18800.00
254878	2017-07-27 08:42:00+03	422700.00
2548C8	2017-06-30 18:50:00+03	55800.00
2548D1	2017-07-05 01:35:00+03	14400.00
254911	2017-08-05 21:19:00+03	277000.00
254920	2017-08-13 02:44:00+03	31400.00
25493C	2017-07-03 08:42:00+03	12600.00
254995	2017-08-14 20:33:00+03	74400.00
2549C5	2017-07-14 23:39:00+03	65900.00
2549D7	2017-07-31 22:39:00+03	272300.00
254A21	2017-08-03 13:55:00+03	46200.00
254A33	2017-07-04 12:20:00+03	58400.00
254A83	2017-08-05 17:43:00+03	234300.00
254AF3	2017-08-09 04:50:00+03	21400.00
254B38	2017-07-31 03:39:00+03	55800.00
254B5F	2017-08-08 09:59:00+03	100000.00
254C9B	2017-08-06 21:19:00+03	38800.00
254CA5	2017-06-30 21:01:00+03	22000.00
254CA6	2017-07-08 16:06:00+03	132800.00
254CCF	2017-07-17 20:28:00+03	88800.00
254DD7	2017-07-05 00:19:00+03	71900.00
254E40	2017-08-05 14:35:00+03	31600.00
254E5C	2017-07-18 08:01:00+03	23900.00
254E7F	2017-07-15 19:00:00+03	27200.00
254E9E	2017-07-25 04:59:00+03	55800.00
254EC4	2017-08-15 05:28:00+03	36800.00
254EDA	2017-08-01 12:00:00+03	55800.00
254EDC	2017-08-15 06:26:00+03	12000.00
254EE5	2017-08-13 14:29:00+03	124400.00
254EF4	2017-07-14 19:52:00+03	55800.00
254F20	2017-07-02 08:17:00+03	38600.00
254F2D	2017-07-27 16:56:00+03	47200.00
254F32	2017-08-13 19:22:00+03	86300.00
254FAC	2017-08-10 04:51:00+03	30400.00
254FC5	2017-07-16 21:15:00+03	57800.00
255074	2017-07-29 17:42:00+03	30200.00
2550B2	2017-08-04 05:33:00+03	56100.00
2550B6	2017-07-05 12:42:00+03	47400.00
25510A	2017-07-28 09:16:00+03	207400.00
255161	2017-07-17 11:17:00+03	98400.00
25520B	2017-07-11 16:57:00+03	75800.00
25520E	2017-07-16 06:37:00+03	81200.00
255237	2017-07-10 00:24:00+03	57600.00
255241	2017-08-05 19:25:00+03	123000.00
2552C1	2017-08-12 09:31:00+03	87800.00
255378	2017-08-15 17:15:00+03	57400.00
255393	2017-06-29 08:03:00+03	147100.00
2553EF	2017-07-04 07:46:00+03	92000.00
2553F8	2017-08-10 01:16:00+03	55800.00
255440	2017-07-16 15:10:00+03	111600.00
255448	2017-07-15 12:59:00+03	189200.00
255481	2017-07-23 16:15:00+03	59200.00
255514	2017-08-08 14:17:00+03	136600.00
255547	2017-08-08 05:26:00+03	180100.00
255554	2017-07-18 13:41:00+03	58600.00
255556	2017-07-22 03:36:00+03	56000.00
2555AF	2017-07-24 10:04:00+03	60500.00
25564E	2017-07-12 03:18:00+03	90400.00
255661	2017-08-06 03:57:00+03	67600.00
255670	2017-07-27 00:20:00+03	377400.00
255751	2017-07-04 01:27:00+03	31600.00
255789	2017-07-11 07:36:00+03	50100.00
25578A	2017-08-09 22:47:00+03	55800.00
2557D5	2017-06-30 13:36:00+03	11700.00
2557FD	2017-07-14 04:28:00+03	131100.00
255813	2017-08-10 07:42:00+03	10600.00
25582F	2017-08-03 17:12:00+03	40000.00
255966	2017-07-11 16:47:00+03	35800.00
255987	2017-07-16 00:06:00+03	47600.00
2559BD	2017-07-18 16:19:00+03	26200.00
255A31	2017-07-31 07:19:00+03	273600.00
255A44	2017-07-04 06:29:00+03	49000.00
255A8F	2017-07-13 20:08:00+03	53900.00
255AA7	2017-07-16 09:57:00+03	271200.00
255AEE	2017-07-23 19:50:00+03	18400.00
255AEF	2017-07-18 01:48:00+03	20200.00
255B2E	2017-07-18 19:46:00+03	88800.00
255B5F	2017-08-09 03:56:00+03	23200.00
255BB0	2017-08-10 01:43:00+03	14000.00
255BD3	2017-08-15 07:22:00+03	48800.00
255BE7	2017-08-02 13:42:00+03	32800.00
255C10	2017-06-28 16:14:00+03	48800.00
255C1B	2017-07-23 10:08:00+03	32700.00
255C7D	2017-08-09 07:28:00+03	22000.00
255C9A	2017-07-02 23:47:00+03	14400.00
255D01	2017-07-06 01:51:00+03	63700.00
255D21	2017-07-01 22:40:00+03	27800.00
255D3F	2017-07-10 06:43:00+03	14400.00
255D5E	2017-08-14 03:40:00+03	62700.00
255E2C	2017-07-31 02:47:00+03	61500.00
255E3B	2017-08-10 16:33:00+03	20400.00
255E50	2017-07-03 23:52:00+03	67800.00
255ECC	2017-08-08 08:01:00+03	188100.00
255EE5	2017-07-14 15:54:00+03	66600.00
255EF4	2017-08-13 13:26:00+03	21800.00
255F9F	2017-08-08 13:29:00+03	35400.00
25600C	2017-07-03 06:09:00+03	73200.00
256026	2017-07-21 00:08:00+03	91500.00
256064	2017-07-11 07:14:00+03	49900.00
2560A5	2017-07-03 10:10:00+03	163800.00
2560DA	2017-07-31 12:00:00+03	52000.00
256123	2017-08-03 15:10:00+03	26400.00
25613A	2017-07-16 16:18:00+03	28000.00
2561BE	2017-07-31 16:29:00+03	38400.00
256229	2017-08-06 12:45:00+03	45200.00
256231	2017-07-17 02:39:00+03	142400.00
256292	2017-07-06 17:53:00+03	13600.00
2562FF	2017-07-13 04:41:00+03	25100.00
2563B3	2017-08-11 23:58:00+03	65500.00
256400	2017-07-07 20:56:00+03	55600.00
256409	2017-07-10 13:31:00+03	27200.00
256464	2017-08-09 01:33:00+03	124200.00
256472	2017-07-14 09:28:00+03	99200.00
25656B	2017-07-17 20:47:00+03	108500.00
2565B3	2017-08-09 18:38:00+03	27300.00
2565E7	2017-08-03 13:31:00+03	6300.00
256634	2017-07-11 08:52:00+03	83000.00
2566D4	2017-06-23 05:17:00+03	64700.00
25676B	2017-07-14 00:32:00+03	57800.00
25676C	2017-07-02 16:49:00+03	18000.00
25677C	2017-07-17 02:34:00+03	48800.00
25679E	2017-07-19 02:27:00+03	188100.00
2567B7	2017-07-02 03:39:00+03	29600.00
2567CB	2017-07-19 10:34:00+03	66800.00
2567F3	2017-08-01 04:56:00+03	9300.00
2567F7	2017-08-09 17:43:00+03	14000.00
2567FD	2017-07-25 18:42:00+03	131100.00
256817	2017-07-20 15:32:00+03	720600.00
25687A	2017-07-27 13:22:00+03	56000.00
256908	2017-08-14 11:32:00+03	398500.00
256955	2017-08-15 04:15:00+03	20400.00
25695B	2017-07-11 02:34:00+03	25000.00
256965	2017-07-04 21:18:00+03	92000.00
256980	2017-07-15 03:03:00+03	37500.00
2569B0	2017-08-04 06:46:00+03	74300.00
256ABE	2017-07-21 18:43:00+03	10700.00
256B47	2017-07-05 12:06:00+03	269200.00
256B48	2017-08-11 12:47:00+03	137600.00
256B72	2017-07-20 22:07:00+03	67900.00
256B7E	2017-07-26 05:29:00+03	112000.00
256BD6	2017-07-22 09:25:00+03	113800.00
256BDA	2017-07-12 15:36:00+03	399600.00
256BEA	2017-08-10 13:59:00+03	40000.00
256BEC	2017-07-05 09:19:00+03	14000.00
256BEF	2017-07-21 06:49:00+03	83100.00
256BFD	2017-08-12 08:43:00+03	27200.00
256C31	2017-07-03 16:04:00+03	21800.00
256C35	2017-08-15 15:13:00+03	28900.00
256C38	2017-08-12 13:03:00+03	44800.00
256C59	2017-08-07 14:16:00+03	168000.00
256C92	2017-08-11 13:01:00+03	21400.00
256CBF	2017-08-02 06:50:00+03	126000.00
256CCA	2017-07-04 05:01:00+03	87900.00
256CD0	2017-07-21 16:07:00+03	6800.00
256D7E	2017-08-09 04:29:00+03	34000.00
256D96	2017-07-24 08:06:00+03	21600.00
256DEC	2017-08-11 19:22:00+03	81300.00
256DFA	2017-08-03 23:48:00+03	15400.00
256E3C	2017-07-29 16:23:00+03	45200.00
256E7F	2017-08-02 15:38:00+03	21800.00
256E84	2017-07-01 20:02:00+03	32200.00
256E87	2017-08-15 13:22:00+03	58000.00
256F3D	2017-07-28 08:16:00+03	31000.00
256F70	2017-08-13 05:50:00+03	51900.00
256FD8	2017-08-08 10:48:00+03	89600.00
257041	2017-07-26 00:46:00+03	71700.00
25710E	2017-07-13 06:04:00+03	132500.00
257126	2017-07-10 17:48:00+03	32700.00
25713E	2017-06-29 15:33:00+03	52700.00
257187	2017-07-26 00:34:00+03	23400.00
2571B4	2017-08-01 16:34:00+03	224000.00
2571C7	2017-08-01 16:52:00+03	69000.00
25723A	2017-07-14 22:02:00+03	62600.00
257254	2017-07-29 18:37:00+03	58000.00
257258	2017-07-15 03:54:00+03	96800.00
25727B	2017-07-08 02:25:00+03	28800.00
257292	2017-08-08 17:54:00+03	28000.00
257317	2017-08-11 00:15:00+03	65600.00
2573CB	2017-07-14 13:40:00+03	78700.00
2573E3	2017-08-03 09:49:00+03	29600.00
25745C	2017-07-20 11:16:00+03	116400.00
257494	2017-07-22 18:22:00+03	97600.00
257497	2017-08-12 17:11:00+03	16800.00
2574B5	2017-07-23 22:43:00+03	28800.00
2574E1	2017-08-05 00:22:00+03	19600.00
2575D5	2017-08-03 07:06:00+03	46000.00
257606	2017-07-02 18:31:00+03	532800.00
257625	2017-07-30 01:33:00+03	135400.00
257648	2017-07-08 01:01:00+03	69100.00
257656	2017-07-12 13:18:00+03	172600.00
257667	2017-07-13 10:38:00+03	173500.00
257681	2017-07-14 16:54:00+03	81300.00
2576DC	2017-06-27 03:02:00+03	56600.00
2576E2	2017-07-17 10:01:00+03	23600.00
257725	2017-08-06 11:39:00+03	43000.00
25779D	2017-07-09 20:17:00+03	182100.00
257808	2017-07-20 20:05:00+03	25700.00
25782D	2017-06-30 11:33:00+03	87000.00
257853	2017-07-17 15:24:00+03	22000.00
25788D	2017-07-12 05:01:00+03	69700.00
25789A	2017-07-17 16:16:00+03	13300.00
25789F	2017-07-14 11:11:00+03	19600.00
2578CC	2017-07-04 01:11:00+03	147200.00
2578ED	2017-07-28 09:10:00+03	46400.00
25795F	2017-08-06 07:50:00+03	29600.00
257961	2017-07-26 13:01:00+03	88500.00
257980	2017-07-12 11:32:00+03	57600.00
2579CA	2017-08-01 14:43:00+03	24800.00
257AF5	2017-08-12 20:56:00+03	52800.00
257B58	2017-07-08 03:59:00+03	6800.00
257B7D	2017-07-14 03:19:00+03	210900.00
257B9B	2017-08-06 18:51:00+03	65900.00
257BAD	2017-07-14 08:04:00+03	102100.00
257BB2	2017-08-10 13:28:00+03	136800.00
257C1E	2017-08-01 19:39:00+03	301800.00
257C3C	2017-07-04 12:41:00+03	35800.00
257C8F	2017-07-15 12:28:00+03	133200.00
257CD8	2017-07-25 11:21:00+03	189200.00
257D91	2017-08-01 10:50:00+03	198600.00
257DB3	2017-07-20 11:09:00+03	95400.00
257DCA	2017-07-05 12:19:00+03	7400.00
257DE2	2017-07-08 10:27:00+03	31000.00
257DE3	2017-07-10 13:33:00+03	14800.00
257E09	2017-07-13 01:20:00+03	227800.00
257E3F	2017-08-13 14:48:00+03	46200.00
257EC2	2017-07-26 16:05:00+03	281800.00
257F06	2017-07-02 22:40:00+03	144000.00
257F0F	2017-07-14 17:26:00+03	104500.00
257FBF	2017-07-22 11:52:00+03	25700.00
258070	2017-08-09 03:31:00+03	24400.00
258151	2017-08-15 02:43:00+03	199700.00
25815B	2017-07-09 08:31:00+03	119500.00
25816A	2017-08-02 19:46:00+03	265600.00
258172	2017-07-30 12:23:00+03	91500.00
2581CD	2017-08-08 19:38:00+03	189500.00
2581D5	2017-07-21 10:53:00+03	19600.00
25822C	2017-07-08 23:13:00+03	27300.00
2582AD	2017-08-04 14:01:00+03	22200.00
2582B5	2017-07-09 11:39:00+03	37200.00
2582F4	2017-07-24 12:39:00+03	40000.00
2582FD	2017-07-08 00:15:00+03	109000.00
258319	2017-08-05 11:23:00+03	28000.00
258321	2017-07-30 09:17:00+03	58400.00
258392	2017-08-14 08:55:00+03	81200.00
258401	2017-08-10 01:00:00+03	13400.00
25841B	2017-07-31 22:38:00+03	31100.00
2584E3	2017-07-13 20:56:00+03	84000.00
258513	2017-07-17 10:41:00+03	92800.00
258524	2017-07-17 01:25:00+03	36200.00
258558	2017-07-10 08:19:00+03	13600.00
25857F	2017-08-02 23:46:00+03	56100.00
258582	2017-07-18 15:54:00+03	56000.00
258606	2017-07-12 00:51:00+03	49200.00
25863F	2017-07-26 04:19:00+03	34600.00
2586C8	2017-07-29 02:25:00+03	48800.00
2586E2	2017-07-20 17:30:00+03	6600.00
2586F5	2017-07-16 09:15:00+03	7400.00
25870F	2017-07-22 00:20:00+03	57800.00
258786	2017-08-12 16:26:00+03	198900.00
2587A8	2017-08-12 16:47:00+03	92800.00
2587FD	2017-07-13 09:44:00+03	68400.00
258825	2017-07-31 00:50:00+03	56000.00
25882A	2017-08-04 02:49:00+03	23600.00
2588A5	2017-07-05 02:08:00+03	65900.00
258988	2017-08-11 21:51:00+03	48800.00
258A71	2017-08-01 14:35:00+03	78600.00
258A7E	2017-07-17 08:49:00+03	36200.00
258A9F	2017-08-10 21:54:00+03	27800.00
258AD5	2017-07-05 16:54:00+03	34000.00
258B42	2017-08-02 23:14:00+03	67200.00
258B4C	2017-08-15 14:38:00+03	70800.00
258B58	2017-07-11 07:43:00+03	15100.00
258C39	2017-06-30 21:53:00+03	6800.00
258C84	2017-07-05 09:13:00+03	88600.00
258CE4	2017-08-10 23:04:00+03	24400.00
258D08	2017-07-11 06:40:00+03	155600.00
258D2C	2017-07-19 18:42:00+03	72400.00
258DD8	2017-07-17 04:19:00+03	88600.00
258E02	2017-08-03 23:25:00+03	26000.00
258E18	2017-07-11 06:18:00+03	67900.00
258E93	2017-06-28 06:42:00+03	68000.00
258EA4	2017-07-08 12:28:00+03	223200.00
258EB9	2017-07-23 09:47:00+03	83000.00
258F04	2017-07-18 18:59:00+03	130100.00
258F20	2017-07-24 18:10:00+03	19600.00
258F94	2017-07-17 12:00:00+03	24700.00
258FA9	2017-07-07 18:49:00+03	131600.00
258FC1	2017-07-06 16:26:00+03	144400.00
258FC2	2017-07-27 18:01:00+03	112000.00
258FD6	2017-07-30 13:16:00+03	48100.00
259034	2017-08-02 08:14:00+03	96300.00
259049	2017-08-08 01:52:00+03	69100.00
25906A	2017-08-08 02:06:00+03	10700.00
25908C	2017-08-03 01:12:00+03	36900.00
2590DA	2017-07-05 04:44:00+03	65500.00
25910D	2017-08-06 22:52:00+03	133100.00
259144	2017-07-22 13:54:00+03	100900.00
259149	2017-07-03 17:00:00+03	46200.00
25916F	2017-07-13 05:31:00+03	40800.00
2591A1	2017-08-10 04:08:00+03	277000.00
2591B7	2017-07-14 23:08:00+03	58600.00
2591FF	2017-07-09 11:05:00+03	6000.00
25926E	2017-07-13 17:07:00+03	79800.00
259281	2017-07-29 23:56:00+03	24400.00
2592DE	2017-07-23 16:57:00+03	96800.00
2592ED	2017-08-06 09:33:00+03	109000.00
2592F6	2017-07-04 21:29:00+03	97800.00
2592FA	2017-07-10 06:37:00+03	48800.00
259306	2017-07-08 09:26:00+03	11600.00
259320	2017-07-17 08:54:00+03	64100.00
259384	2017-08-13 21:24:00+03	87200.00
2593AC	2017-07-22 23:01:00+03	12600.00
2593C7	2017-07-06 17:05:00+03	69400.00
259470	2017-07-26 06:37:00+03	93000.00
259495	2017-08-02 08:25:00+03	34000.00
2594CE	2017-07-21 11:43:00+03	80100.00
259527	2017-07-21 22:57:00+03	58900.00
25953E	2017-07-06 18:15:00+03	38300.00
2595B7	2017-07-22 00:18:00+03	99200.00
2595BC	2017-08-07 17:30:00+03	59200.00
2595DB	2017-08-12 22:55:00+03	65500.00
259697	2017-07-23 21:51:00+03	137100.00
2596D3	2017-07-03 04:31:00+03	103500.00
25972D	2017-07-06 17:50:00+03	46000.00
25972E	2017-07-26 21:25:00+03	38800.00
25977F	2017-07-22 12:28:00+03	127300.00
2597CC	2017-07-06 09:27:00+03	47200.00
2597D8	2017-07-07 02:53:00+03	123000.00
2597F5	2017-07-20 02:46:00+03	12600.00
259914	2017-08-11 12:10:00+03	136600.00
259948	2017-07-19 16:29:00+03	66400.00
25994C	2017-07-21 22:08:00+03	40800.00
25995C	2017-08-12 20:08:00+03	49600.00
259981	2017-07-02 21:01:00+03	12200.00
259988	2017-07-06 14:14:00+03	45200.00
259990	2017-07-11 22:46:00+03	8000.00
2599B7	2017-08-12 12:03:00+03	54800.00
2599D3	2017-07-28 18:13:00+03	44800.00
2599D9	2017-07-06 01:06:00+03	46800.00
259A13	2017-07-19 22:02:00+03	73500.00
259AC2	2017-07-15 14:46:00+03	91600.00
259B8F	2017-08-12 22:54:00+03	13400.00
259BC3	2017-07-10 00:50:00+03	17200.00
259C08	2017-08-05 10:05:00+03	119700.00
259C0F	2017-08-11 19:28:00+03	18000.00
259C79	2017-07-19 00:56:00+03	27300.00
259CB9	2017-07-30 23:03:00+03	28800.00
259CBE	2017-07-05 22:01:00+03	143100.00
259CCE	2017-08-13 23:26:00+03	173500.00
259CF5	2017-07-28 08:34:00+03	94000.00
259D88	2017-07-14 09:44:00+03	40600.00
259E10	2017-07-20 03:29:00+03	57400.00
259E4E	2017-07-19 19:02:00+03	23200.00
259EC7	2017-08-12 18:03:00+03	131100.00
259F6B	2017-08-08 12:55:00+03	24600.00
259FC9	2017-07-04 00:34:00+03	46800.00
259FD0	2017-08-14 21:59:00+03	21800.00
25A0AC	2017-08-05 07:39:00+03	62600.00
25A0EC	2017-06-30 17:31:00+03	41400.00
25A109	2017-07-28 11:35:00+03	103500.00
25A10E	2017-07-25 01:24:00+03	66000.00
25A1BE	2017-07-31 00:40:00+03	109900.00
25A1C6	2017-07-15 10:28:00+03	27700.00
25A1E3	2017-07-29 03:44:00+03	46700.00
25A1E6	2017-07-26 22:38:00+03	86400.00
25A201	2017-07-07 22:11:00+03	56600.00
25A21F	2017-07-08 20:17:00+03	77200.00
25A23D	2017-07-05 06:18:00+03	26000.00
25A252	2017-07-07 14:07:00+03	50600.00
25A2AB	2017-07-27 22:02:00+03	19600.00
25A3B5	2017-08-15 07:04:00+03	192900.00
25A3E2	2017-06-30 14:01:00+03	65200.00
25A40D	2017-08-09 08:34:00+03	78100.00
25A4A5	2017-07-24 09:46:00+03	44600.00
25A4AC	2017-07-26 04:35:00+03	8400.00
25A4D1	2017-07-10 11:53:00+03	67200.00
25A56C	2017-07-29 09:32:00+03	100600.00
25A593	2017-08-13 22:48:00+03	6700.00
25A5C0	2017-07-03 04:19:00+03	14000.00
25A60C	2017-07-10 18:13:00+03	153300.00
25A627	2017-07-04 14:52:00+03	123600.00
25A651	2017-06-28 00:57:00+03	17800.00
25A69B	2017-06-30 22:05:00+03	90000.00
25A76B	2017-07-21 16:14:00+03	29600.00
25A7BC	2017-07-29 21:29:00+03	33600.00
25A885	2017-07-30 12:15:00+03	9200.00
25A88C	2017-07-03 22:41:00+03	47100.00
25A900	2017-07-26 01:34:00+03	20400.00
25A92B	2017-07-17 10:39:00+03	28800.00
25A9CC	2017-08-09 00:03:00+03	243600.00
25A9DB	2017-08-14 01:33:00+03	19000.00
25AA01	2017-07-11 11:11:00+03	23800.00
25AA2D	2017-08-12 14:08:00+03	30600.00
25AA77	2017-06-29 17:39:00+03	37900.00
25AA8A	2017-07-08 17:52:00+03	20800.00
25AAF7	2017-07-24 19:41:00+03	70100.00
25AB9F	2017-07-30 12:15:00+03	56600.00
25ABE7	2017-07-20 19:09:00+03	240600.00
25ABED	2017-07-09 15:43:00+03	62600.00
25AC0A	2017-08-10 21:41:00+03	28000.00
25AC54	2017-07-02 07:32:00+03	170000.00
25AC80	2017-08-07 14:37:00+03	38400.00
25AC95	2017-08-10 01:43:00+03	61500.00
25AC97	2017-08-01 02:16:00+03	31400.00
25AC9B	2017-08-09 20:33:00+03	23200.00
25AD42	2017-06-29 13:27:00+03	48500.00
25AD78	2017-07-29 02:37:00+03	55800.00
25ADAC	2017-07-29 14:07:00+03	137600.00
25AE37	2017-08-09 12:24:00+03	14400.00
25AE4D	2017-07-25 04:35:00+03	131100.00
25AE6F	2017-07-03 14:39:00+03	26000.00
25AEF1	2017-08-14 17:18:00+03	27200.00
25AF19	2017-07-01 19:24:00+03	70700.00
25AF4E	2017-07-04 20:46:00+03	133100.00
25AF97	2017-07-26 13:24:00+03	69900.00
25AF99	2017-07-31 12:37:00+03	24800.00
25AFA0	2017-07-29 10:11:00+03	32800.00
25AFB9	2017-07-06 14:44:00+03	47200.00
25B002	2017-08-05 08:28:00+03	109600.00
25B032	2017-08-11 22:18:00+03	135400.00
25B040	2017-07-12 13:48:00+03	80000.00
25B0BF	2017-08-05 08:11:00+03	289800.00
25B0DE	2017-07-16 09:02:00+03	42600.00
25B0E3	2017-07-22 20:16:00+03	65900.00
25B0E7	2017-07-31 03:48:00+03	115100.00
25B0F4	2017-07-23 21:58:00+03	24400.00
25B104	2017-08-11 11:57:00+03	37900.00
25B12C	2017-07-14 12:16:00+03	31400.00
25B1C6	2017-07-08 23:33:00+03	27300.00
25B1EC	2017-07-29 03:29:00+03	64100.00
25B1F4	2017-07-23 20:21:00+03	100600.00
25B206	2017-08-09 19:02:00+03	32700.00
25B262	2017-07-13 18:29:00+03	79000.00
25B26E	2017-07-14 00:43:00+03	28000.00
25B31B	2017-08-08 10:58:00+03	26800.00
25B328	2017-07-28 10:10:00+03	21800.00
25B3B0	2017-07-04 10:49:00+03	124300.00
25B44B	2017-08-06 18:28:00+03	12000.00
25B451	2017-08-11 11:14:00+03	101200.00
25B464	2017-07-02 04:47:00+03	12600.00
25B485	2017-06-26 05:55:00+03	339900.00
25B4A2	2017-07-14 11:56:00+03	6400.00
25B565	2017-07-19 16:20:00+03	18700.00
25B592	2017-08-10 00:52:00+03	53300.00
25B597	2017-07-19 09:21:00+03	57800.00
25B649	2017-08-03 18:17:00+03	47000.00
25B6C1	2017-07-31 22:55:00+03	68100.00
25B70A	2017-07-29 19:29:00+03	170500.00
25B752	2017-07-16 13:52:00+03	272900.00
25B76A	2017-07-21 00:49:00+03	56000.00
25B77A	2017-08-07 08:32:00+03	31200.00
25B805	2017-07-10 06:28:00+03	28000.00
25B831	2017-07-06 18:19:00+03	22000.00
25B834	2017-07-13 13:22:00+03	114300.00
25B848	2017-08-04 06:35:00+03	47400.00
25B84C	2017-07-09 21:47:00+03	96300.00
25B994	2017-07-07 02:17:00+03	47100.00
25B9C5	2017-08-15 07:14:00+03	43200.00
25B9C9	2017-07-28 19:38:00+03	398500.00
25B9EC	2017-08-05 16:05:00+03	127200.00
25BA3D	2017-08-01 19:12:00+03	88600.00
25BAA8	2017-07-15 11:51:00+03	56600.00
25BACA	2017-07-15 21:50:00+03	12600.00
25BAD4	2017-06-26 16:22:00+03	28000.00
25BB22	2017-07-17 06:12:00+03	20000.00
25BB33	2017-07-05 05:00:00+03	46400.00
25BB48	2017-07-05 01:30:00+03	51900.00
25BBDF	2017-08-02 18:58:00+03	50800.00
25BCEC	2017-08-14 07:07:00+03	26000.00
25BD32	2017-07-10 01:40:00+03	37500.00
25BE3E	2017-08-05 13:48:00+03	155500.00
25BEC3	2017-07-30 12:43:00+03	60800.00
25BEDE	2017-07-02 23:41:00+03	14400.00
25BF27	2017-08-08 08:16:00+03	406700.00
25BF56	2017-07-14 17:46:00+03	33300.00
25BFBF	2017-08-08 13:52:00+03	28800.00
25C038	2017-07-28 20:07:00+03	77900.00
25C03C	2017-07-28 04:39:00+03	23200.00
25C0D0	2017-07-24 21:19:00+03	248500.00
25C1C7	2017-08-05 13:21:00+03	14400.00
25C23E	2017-08-05 23:39:00+03	77900.00
25C25D	2017-07-24 23:27:00+03	86300.00
25C2F2	2017-07-26 06:51:00+03	81700.00
25C2F8	2017-08-02 04:48:00+03	26000.00
25C303	2017-07-06 14:33:00+03	32200.00
25C31C	2017-07-22 11:58:00+03	28600.00
25C347	2017-07-05 00:06:00+03	182600.00
25C34B	2017-08-10 03:54:00+03	114300.00
25C360	2017-08-15 00:36:00+03	23200.00
25C37F	2017-07-29 19:30:00+03	123000.00
25C414	2017-07-11 12:39:00+03	182100.00
25C42C	2017-07-06 05:52:00+03	12400.00
25C588	2017-07-23 22:45:00+03	112000.00
25C5C7	2017-07-12 17:22:00+03	39200.00
25C5DE	2017-08-15 00:10:00+03	59700.00
25C633	2017-08-09 15:10:00+03	86600.00
25C675	2017-07-01 08:33:00+03	68800.00
25C6F8	2017-07-21 11:12:00+03	68700.00
25C754	2017-07-29 09:40:00+03	160700.00
25C759	2017-08-12 18:34:00+03	26000.00
25C79B	2017-07-07 13:33:00+03	167400.00
25C7BC	2017-07-13 16:52:00+03	7200.00
25C7F5	2017-08-01 20:22:00+03	37900.00
25C8B2	2017-07-28 22:46:00+03	176800.00
25C910	2017-07-19 01:08:00+03	146600.00
25C9CA	2017-07-11 23:11:00+03	67800.00
25CA78	2017-07-25 13:11:00+03	9200.00
25CB3E	2017-08-15 04:53:00+03	186800.00
25CB82	2017-07-11 03:37:00+03	28000.00
25CB95	2017-08-05 17:53:00+03	48800.00
25CBA8	2017-07-08 03:24:00+03	36200.00
25CBC8	2017-07-13 21:30:00+03	80000.00
25CCDD	2017-08-15 00:06:00+03	12400.00
25CCFB	2017-07-12 16:14:00+03	38200.00
25CD12	2017-08-01 16:18:00+03	58000.00
25CD86	2017-07-11 09:17:00+03	54800.00
25CDDE	2017-07-12 03:16:00+03	27200.00
25CE07	2017-07-24 14:06:00+03	46200.00
25CE41	2017-08-14 11:37:00+03	20200.00
25CE97	2017-07-05 07:02:00+03	90800.00
25CEA0	2017-08-01 13:42:00+03	53300.00
25CF16	2017-07-11 03:15:00+03	25400.00
25CF41	2017-08-07 13:07:00+03	28200.00
25CF5D	2017-07-27 00:47:00+03	26600.00
25CF76	2017-07-16 08:03:00+03	22000.00
25CFB0	2017-07-28 03:18:00+03	28000.00
25CFCA	2017-06-30 17:27:00+03	23600.00
25CFDB	2017-07-22 06:37:00+03	48700.00
25CFDD	2017-07-21 03:51:00+03	217600.00
25CFFE	2017-07-28 12:54:00+03	81700.00
25D00B	2017-07-25 21:55:00+03	89600.00
25D023	2017-07-01 10:28:00+03	95700.00
25D053	2017-07-14 10:47:00+03	56600.00
25D057	2017-08-01 17:10:00+03	62600.00
25D0F4	2017-08-08 14:19:00+03	93700.00
25D11B	2017-07-23 02:50:00+03	55600.00
25D123	2017-07-02 08:37:00+03	40000.00
25D233	2017-08-02 19:16:00+03	67000.00
25D292	2017-07-21 10:48:00+03	28000.00
25D2C9	2017-07-18 19:27:00+03	41900.00
25D3E4	2017-08-01 14:29:00+03	56100.00
25D501	2017-08-06 13:40:00+03	21800.00
25D52B	2017-07-31 17:42:00+03	227600.00
25D537	2017-07-20 00:07:00+03	290900.00
25D53C	2017-08-15 03:33:00+03	38800.00
25D544	2017-07-06 17:29:00+03	42800.00
25D5E3	2017-07-18 06:49:00+03	57600.00
25D60A	2017-06-27 08:08:00+03	56900.00
25D716	2017-08-13 12:18:00+03	23200.00
25D71E	2017-07-04 13:33:00+03	56000.00
25D780	2017-08-02 10:34:00+03	56600.00
25D78B	2017-08-09 20:33:00+03	107000.00
25D7D7	2017-07-25 00:50:00+03	32000.00
25D8B2	2017-07-06 08:55:00+03	109600.00
25D8BD	2017-08-06 02:49:00+03	56200.00
25D8CE	2017-08-12 00:42:00+03	6800.00
25D8F2	2017-08-02 01:47:00+03	26700.00
25D903	2017-07-15 20:40:00+03	23600.00
25D943	2017-07-20 00:09:00+03	8000.00
25D988	2017-07-29 06:29:00+03	30400.00
25DA25	2017-07-14 03:57:00+03	58400.00
25DAB0	2017-08-14 07:31:00+03	74900.00
25DAF8	2017-07-10 04:59:00+03	29600.00
25DB27	2017-07-30 08:45:00+03	65900.00
25DB3A	2017-08-15 08:34:00+03	160700.00
25DBC8	2017-08-08 02:58:00+03	37700.00
25DC4F	2017-07-11 15:17:00+03	95600.00
25DC83	2017-08-05 16:50:00+03	26800.00
25DCE3	2017-08-13 03:10:00+03	94900.00
25DCF7	2017-07-21 09:21:00+03	116800.00
25DD0E	2017-07-07 16:55:00+03	133100.00
25DD85	2017-07-19 12:22:00+03	161000.00
25DE19	2017-07-02 18:29:00+03	185000.00
25DE64	2017-07-10 04:31:00+03	131100.00
25DE7D	2017-07-28 23:43:00+03	19600.00
25DEC9	2017-08-02 16:53:00+03	27200.00
25DF03	2017-08-11 16:40:00+03	22400.00
25DFB1	2017-07-12 12:40:00+03	56600.00
25DFF5	2017-08-15 13:40:00+03	6200.00
25E07C	2017-07-29 13:40:00+03	132800.00
25E081	2017-07-02 14:14:00+03	30700.00
25E0FC	2017-08-13 23:58:00+03	99200.00
25E159	2017-07-21 08:08:00+03	34000.00
25E213	2017-08-13 09:19:00+03	23200.00
25E21F	2017-08-05 23:34:00+03	23600.00
25E223	2017-08-05 06:43:00+03	65500.00
25E237	2017-07-04 11:59:00+03	260300.00
25E248	2017-07-15 22:20:00+03	591600.00
25E294	2017-07-24 09:21:00+03	48800.00
25E29C	2017-07-29 02:51:00+03	43200.00
25E2E9	2017-07-06 15:38:00+03	123000.00
25E346	2017-07-11 08:16:00+03	31700.00
25E351	2017-07-06 08:19:00+03	123000.00
25E382	2017-07-15 08:56:00+03	46000.00
25E3A9	2017-07-15 17:06:00+03	62400.00
25E3B5	2017-07-04 22:48:00+03	23900.00
25E3F8	2017-08-07 14:38:00+03	88800.00
25E422	2017-07-29 21:16:00+03	40600.00
25E42B	2017-07-27 08:51:00+03	164400.00
25E43C	2017-07-22 20:21:00+03	19500.00
25E4B4	2017-08-02 01:24:00+03	36200.00
25E4C8	2017-07-19 23:57:00+03	6000.00
25E506	2017-07-05 04:05:00+03	7400.00
25E516	2017-07-19 16:36:00+03	57400.00
25E538	2017-07-14 03:13:00+03	37900.00
25E55A	2017-07-04 12:37:00+03	70700.00
25E5AF	2017-07-21 19:03:00+03	12600.00
25E60B	2017-08-04 10:02:00+03	46800.00
25E6BA	2017-07-20 07:14:00+03	68400.00
25E6EE	2017-07-06 09:27:00+03	13400.00
25E702	2017-07-04 06:21:00+03	57700.00
25E722	2017-07-10 07:59:00+03	66600.00
25E77C	2017-07-01 00:25:00+03	31900.00
25E790	2017-07-12 23:53:00+03	178800.00
25E7DB	2017-07-05 22:05:00+03	405200.00
25E7F3	2017-08-08 10:08:00+03	53600.00
25E80E	2017-07-23 07:21:00+03	27800.00
25E811	2017-08-12 05:16:00+03	36100.00
25E831	2017-07-28 21:27:00+03	41200.00
25E83F	2017-08-07 13:42:00+03	92100.00
25E8AB	2017-07-06 23:01:00+03	84100.00
25E8B6	2017-08-01 10:54:00+03	265700.00
25E8F8	2017-06-30 13:49:00+03	57800.00
25E908	2017-07-30 08:53:00+03	9300.00
25E928	2017-07-14 11:51:00+03	239700.00
25E930	2017-07-14 17:07:00+03	17600.00
25E94D	2017-08-10 18:12:00+03	79000.00
25E9A6	2017-07-10 10:42:00+03	46200.00
25EACD	2017-07-09 13:41:00+03	39100.00
25EAE8	2017-07-03 23:34:00+03	175200.00
25EB0C	2017-08-10 23:13:00+03	556700.00
25EB36	2017-07-02 20:41:00+03	66600.00
25EB4B	2017-08-14 17:13:00+03	137600.00
25EBAF	2017-07-17 00:28:00+03	46800.00
25EBD3	2017-08-04 13:08:00+03	59300.00
25EBEA	2017-07-07 15:51:00+03	211000.00
25EC8E	2017-08-07 11:08:00+03	75600.00
25ECD4	2017-08-08 07:49:00+03	108000.00
25ED6A	2017-07-31 00:38:00+03	47000.00
25EDC5	2017-08-05 18:42:00+03	93700.00
25EDDA	2017-07-11 11:12:00+03	28800.00
25EDDF	2017-08-11 05:52:00+03	14400.00
25EDE1	2017-08-05 11:42:00+03	23400.00
25EE16	2017-07-14 18:19:00+03	134900.00
25EE43	2017-07-14 04:42:00+03	125000.00
25EE4E	2017-07-20 14:36:00+03	30800.00
25EE54	2017-07-06 01:48:00+03	59100.00
25EEE2	2017-07-20 08:07:00+03	96200.00
25EEEF	2017-07-18 13:13:00+03	271400.00
25EEFD	2017-07-04 00:27:00+03	189200.00
25EF35	2017-07-02 10:28:00+03	67200.00
25EF40	2017-07-18 09:03:00+03	123000.00
25EF59	2017-08-07 03:56:00+03	169900.00
25EF74	2017-07-08 03:00:00+03	47200.00
25EFC4	2017-07-31 07:41:00+03	48800.00
25F010	2017-08-05 09:47:00+03	101500.00
25F060	2017-08-13 04:30:00+03	73500.00
25F0CA	2017-07-14 14:17:00+03	155500.00
25F188	2017-07-28 01:34:00+03	59200.00
25F24A	2017-07-24 14:03:00+03	40800.00
25F2C2	2017-07-21 23:57:00+03	43900.00
25F2CE	2017-07-22 16:14:00+03	10700.00
25F2FE	2017-07-22 22:32:00+03	35200.00
25F318	2017-07-20 16:25:00+03	56100.00
25F343	2017-07-30 02:41:00+03	86600.00
25F359	2017-08-09 12:06:00+03	10800.00
25F37D	2017-08-10 04:55:00+03	156000.00
25F3D0	2017-08-03 21:11:00+03	93900.00
25F461	2017-07-21 22:53:00+03	44500.00
25F4A6	2017-07-12 07:26:00+03	153300.00
25F515	2017-07-12 08:48:00+03	20800.00
25F51B	2017-07-24 06:53:00+03	73500.00
25F526	2017-07-09 18:40:00+03	9300.00
25F59D	2017-08-08 06:41:00+03	97800.00
25F5B9	2017-07-09 10:56:00+03	46800.00
25F629	2017-08-13 20:34:00+03	99200.00
25F655	2017-07-08 09:43:00+03	16800.00
25F666	2017-07-14 11:08:00+03	40400.00
25F679	2017-07-02 08:09:00+03	29400.00
25F68B	2017-08-06 12:00:00+03	126000.00
25F69E	2017-08-06 17:42:00+03	105600.00
25F70F	2017-07-11 22:10:00+03	15100.00
25F78B	2017-08-02 14:19:00+03	136600.00
25F7EF	2017-08-12 05:41:00+03	289800.00
25F811	2017-07-27 03:37:00+03	15800.00
25F823	2017-07-25 02:33:00+03	55800.00
25F824	2017-07-12 20:16:00+03	393800.00
25F8BC	2017-07-31 05:03:00+03	121800.00
25F914	2017-07-06 08:05:00+03	12600.00
25F93F	2017-07-13 07:44:00+03	189800.00
25F946	2017-08-05 21:48:00+03	19600.00
25F94C	2017-07-10 14:56:00+03	87200.00
25F9F4	2017-06-28 06:51:00+03	102100.00
25F9FA	2017-07-17 04:49:00+03	90400.00
25FA0D	2017-08-05 19:03:00+03	163300.00
25FA74	2017-07-05 16:02:00+03	62600.00
25FA93	2017-07-09 20:42:00+03	86500.00
25FAE1	2017-07-17 13:11:00+03	24400.00
25FAF4	2017-07-06 03:41:00+03	95700.00
25FB75	2017-07-17 21:04:00+03	50000.00
25FBC8	2017-08-13 07:41:00+03	42700.00
25FBED	2017-07-08 12:14:00+03	12100.00
25FC03	2017-07-23 13:14:00+03	26700.00
25FC83	2017-07-07 14:15:00+03	12600.00
25FC87	2017-08-07 22:26:00+03	199700.00
25FD01	2017-07-22 19:19:00+03	92600.00
25FD02	2017-08-13 10:59:00+03	56000.00
25FD41	2017-07-08 21:36:00+03	110500.00
25FD66	2017-08-14 00:30:00+03	37900.00
25FD7C	2017-08-15 05:15:00+03	66000.00
25FE7F	2017-07-12 04:07:00+03	106100.00
25FEC2	2017-07-28 23:25:00+03	58000.00
25FF08	2017-07-26 08:21:00+03	119800.00
25FF0B	2017-08-08 23:10:00+03	31600.00
25FF1A	2017-07-11 17:41:00+03	14800.00
25FF40	2017-07-30 19:30:00+03	61500.00
25FF55	2017-08-15 07:30:00+03	56100.00
25FFB7	2017-07-09 04:22:00+03	94000.00
25FFBA	2017-07-13 19:33:00+03	266400.00
260002	2017-07-24 02:16:00+03	33300.00
26000E	2017-08-04 23:07:00+03	34100.00
26003A	2017-07-12 11:27:00+03	58700.00
26003E	2017-08-08 22:14:00+03	28000.00
26005E	2017-07-27 08:22:00+03	57400.00
2600A5	2017-07-21 17:49:00+03	75600.00
2600A8	2017-06-28 09:10:00+03	50000.00
2601E7	2017-07-12 14:49:00+03	26800.00
260241	2017-08-09 14:12:00+03	179300.00
2602B6	2017-07-20 06:23:00+03	25400.00
2602C3	2017-08-08 22:41:00+03	138400.00
260316	2017-07-01 20:43:00+03	31700.00
260326	2017-08-08 12:50:00+03	207200.00
260333	2017-08-02 10:02:00+03	7200.00
260346	2017-07-25 14:31:00+03	29800.00
260395	2017-07-30 23:16:00+03	13400.00
260418	2017-08-07 01:04:00+03	22000.00
26043D	2017-08-12 20:18:00+03	64700.00
260440	2017-07-12 10:32:00+03	39300.00
26046B	2017-07-09 12:46:00+03	132800.00
260497	2017-08-07 08:47:00+03	93900.00
260500	2017-07-31 07:11:00+03	127300.00
260555	2017-07-07 00:17:00+03	27400.00
26059D	2017-07-31 03:30:00+03	79900.00
2605E6	2017-07-31 03:06:00+03	237700.00
26064E	2017-07-02 10:51:00+03	115700.00
260694	2017-07-08 22:31:00+03	260300.00
260696	2017-07-08 04:41:00+03	11800.00
26069C	2017-08-12 22:59:00+03	25600.00
2606A0	2017-08-06 16:37:00+03	20600.00
260706	2017-07-13 12:37:00+03	261500.00
2607AE	2017-08-02 05:23:00+03	35700.00
26087A	2017-07-18 04:52:00+03	23900.00
26089F	2017-07-12 15:46:00+03	152900.00
26091F	2017-07-31 09:39:00+03	31600.00
260988	2017-08-05 14:10:00+03	170000.00
26099C	2017-06-29 08:10:00+03	56100.00
2609BF	2017-08-13 11:36:00+03	23600.00
260A37	2017-07-28 20:07:00+03	102100.00
260A57	2017-08-02 00:18:00+03	51200.00
260B00	2017-08-05 17:47:00+03	112000.00
260B25	2017-07-22 13:55:00+03	743500.00
260B85	2017-07-08 18:11:00+03	67200.00
260C2D	2017-07-06 00:41:00+03	28000.00
260C39	2017-07-10 12:14:00+03	89800.00
260C9E	2017-07-18 13:30:00+03	8200.00
260CBD	2017-07-03 15:29:00+03	47200.00
260CC0	2017-07-25 15:59:00+03	96800.00
260CDB	2017-07-20 03:50:00+03	81900.00
260CDD	2017-08-11 15:06:00+03	30800.00
260D61	2017-07-21 20:53:00+03	149000.00
260D77	2017-07-18 20:25:00+03	95600.00
260DF5	2017-07-06 09:27:00+03	25200.00
260E38	2017-07-02 03:21:00+03	59800.00
260F32	2017-08-14 03:35:00+03	13400.00
260F58	2017-07-28 16:46:00+03	133100.00
261037	2017-08-14 08:41:00+03	62900.00
2610A4	2017-08-14 22:10:00+03	135000.00
2610D8	2017-07-08 10:27:00+03	40000.00
261142	2017-07-08 21:47:00+03	23200.00
26115A	2017-07-20 13:49:00+03	24200.00
2611CC	2017-07-08 15:38:00+03	55500.00
261226	2017-07-10 00:49:00+03	168000.00
26123E	2017-07-13 13:37:00+03	81500.00
2612C4	2017-08-12 22:48:00+03	168700.00
2612D4	2017-08-13 20:14:00+03	38600.00
261358	2017-07-22 22:29:00+03	6700.00
26137E	2017-06-29 17:35:00+03	124400.00
2613B4	2017-08-06 15:52:00+03	42600.00
26140A	2017-07-13 13:03:00+03	131100.00
26141A	2017-07-28 14:50:00+03	69100.00
261452	2017-07-01 17:57:00+03	50000.00
26148B	2017-07-28 11:13:00+03	29200.00
2614B7	2017-08-15 04:43:00+03	45200.00
261525	2017-08-14 12:12:00+03	32800.00
261530	2017-06-29 20:26:00+03	11800.00
261543	2017-07-16 03:40:00+03	38800.00
2615D4	2017-07-20 20:18:00+03	40600.00
2615E0	2017-08-09 12:07:00+03	44100.00
261616	2017-07-31 06:35:00+03	78600.00
261651	2017-07-04 18:24:00+03	31600.00
261660	2017-07-26 13:55:00+03	33600.00
261665	2017-08-02 05:36:00+03	118500.00
2616A2	2017-07-11 00:07:00+03	72200.00
2616EB	2017-08-14 16:20:00+03	14800.00
261725	2017-07-08 10:58:00+03	69700.00
2617B0	2017-08-09 01:04:00+03	28800.00
2617BF	2017-07-03 23:49:00+03	19600.00
26183A	2017-07-21 00:24:00+03	108500.00
26199C	2017-07-06 08:01:00+03	72300.00
2619BC	2017-07-21 01:36:00+03	19600.00
261A0D	2017-07-17 20:19:00+03	95200.00
261A22	2017-08-08 19:05:00+03	123600.00
261A5B	2017-08-01 19:01:00+03	57500.00
261B1D	2017-08-04 01:47:00+03	25100.00
261B3C	2017-07-09 01:37:00+03	157200.00
261B80	2017-07-30 04:15:00+03	99300.00
261C3F	2017-07-22 21:49:00+03	26000.00
261CFE	2017-08-13 18:49:00+03	24200.00
261D2A	2017-08-10 16:15:00+03	47400.00
261DA1	2017-08-03 21:54:00+03	23200.00
261DA5	2017-08-07 13:44:00+03	58200.00
261DE2	2017-08-14 07:38:00+03	67200.00
261E32	2017-07-05 21:57:00+03	56200.00
261E6C	2017-07-18 19:23:00+03	56000.00
261F04	2017-07-29 01:44:00+03	32700.00
261F2D	2017-07-28 09:22:00+03	103500.00
261F6C	2017-08-09 20:45:00+03	62000.00
26203C	2017-08-14 23:34:00+03	26300.00
26204B	2017-07-09 15:56:00+03	32200.00
262071	2017-08-06 13:23:00+03	32800.00
262081	2017-07-20 07:49:00+03	24800.00
26213F	2017-08-14 17:00:00+03	118100.00
26215C	2017-07-25 13:14:00+03	67200.00
262167	2017-07-23 12:20:00+03	271100.00
2621AC	2017-08-07 02:38:00+03	46900.00
2621B7	2017-07-19 18:24:00+03	73200.00
262203	2017-08-06 19:13:00+03	177600.00
262216	2017-07-25 12:57:00+03	58000.00
262219	2017-08-07 09:53:00+03	102000.00
26222D	2017-07-04 23:30:00+03	15800.00
2622C7	2017-07-22 22:22:00+03	164600.00
2623C8	2017-07-10 19:56:00+03	174600.00
262451	2017-07-28 17:38:00+03	6700.00
262498	2017-07-18 14:57:00+03	117600.00
2624C3	2017-07-15 13:58:00+03	257600.00
2624CB	2017-08-14 11:44:00+03	12000.00
2624CD	2017-08-15 09:43:00+03	89600.00
2624F3	2017-07-14 21:41:00+03	19800.00
262560	2017-08-14 19:12:00+03	168000.00
262596	2017-07-04 11:55:00+03	23100.00
262598	2017-07-19 15:23:00+03	74000.00
26259F	2017-07-14 22:50:00+03	23900.00
2625A0	2017-08-15 05:31:00+03	68000.00
2625E7	2017-07-17 09:09:00+03	48800.00
262644	2017-08-05 06:14:00+03	112000.00
262651	2017-08-09 21:59:00+03	57500.00
2626AB	2017-08-07 19:31:00+03	32800.00
2626AD	2017-07-29 04:16:00+03	26800.00
2626CA	2017-07-05 06:03:00+03	54500.00
26273C	2017-08-09 12:33:00+03	59000.00
26276B	2017-07-03 03:03:00+03	13200.00
262785	2017-08-09 20:53:00+03	12600.00
262805	2017-08-12 04:03:00+03	39200.00
262864	2017-07-12 10:58:00+03	44600.00
2628B1	2017-07-23 10:05:00+03	229400.00
2628FF	2017-07-30 01:29:00+03	19600.00
262907	2017-08-01 18:32:00+03	27800.00
262948	2017-07-11 04:20:00+03	24400.00
26296F	2017-07-05 15:30:00+03	38800.00
2629CF	2017-07-24 10:38:00+03	39800.00
2629E7	2017-07-29 11:23:00+03	6300.00
2629E9	2017-07-30 21:24:00+03	85000.00
2629EE	2017-07-05 18:09:00+03	54000.00
262A03	2017-08-06 01:07:00+03	218000.00
262A37	2017-08-04 02:58:00+03	153300.00
262A65	2017-07-25 13:13:00+03	59400.00
262A95	2017-08-02 20:29:00+03	57800.00
262AA7	2017-08-12 17:22:00+03	146300.00
262AB5	2017-08-06 17:06:00+03	6000.00
262ACA	2017-08-06 20:19:00+03	47000.00
262AD0	2017-08-15 04:00:00+03	115200.00
262B09	2017-07-13 15:14:00+03	99200.00
262B31	2017-07-15 09:23:00+03	54800.00
262B4A	2017-07-11 22:15:00+03	6000.00
262B69	2017-07-24 07:46:00+03	39800.00
262BA8	2017-08-08 18:49:00+03	24600.00
262BD9	2017-07-05 13:55:00+03	45500.00
262BF4	2017-08-12 15:03:00+03	70400.00
262C5B	2017-07-07 23:34:00+03	15000.00
262C96	2017-07-07 18:34:00+03	60400.00
262D38	2017-08-02 19:28:00+03	73400.00
262D84	2017-07-02 00:55:00+03	112000.00
262D93	2017-06-29 17:00:00+03	58800.00
262DBC	2017-08-15 07:57:00+03	98300.00
262DD7	2017-07-10 14:48:00+03	38800.00
262DEB	2017-06-29 10:59:00+03	141400.00
262E3D	2017-08-06 16:44:00+03	57400.00
262E4F	2017-07-11 17:30:00+03	381400.00
262E55	2017-07-24 23:31:00+03	6700.00
262E6E	2017-07-22 11:45:00+03	29300.00
262EE7	2017-08-06 04:12:00+03	147700.00
262F1A	2017-08-04 04:24:00+03	62700.00
262F57	2017-07-30 14:24:00+03	68000.00
262F69	2017-06-28 21:38:00+03	148200.00
262F9D	2017-07-30 12:04:00+03	193200.00
262FA4	2017-07-20 10:13:00+03	99600.00
262FD4	2017-07-21 14:17:00+03	67900.00
262FE7	2017-08-13 06:42:00+03	63500.00
26302A	2017-07-11 16:48:00+03	36900.00
2630D0	2017-08-15 11:23:00+03	28800.00
2630D6	2017-08-06 05:00:00+03	193800.00
263103	2017-08-04 02:49:00+03	62000.00
26311E	2017-08-13 14:03:00+03	76600.00
263124	2017-07-01 06:00:00+03	28000.00
26312B	2017-08-06 05:56:00+03	200500.00
26318D	2017-07-08 07:40:00+03	28000.00
263191	2017-08-09 08:37:00+03	35200.00
263257	2017-08-13 04:49:00+03	13400.00
2632B5	2017-07-08 02:33:00+03	56600.00
2632C3	2017-08-13 01:09:00+03	32100.00
263316	2017-08-07 03:50:00+03	6700.00
263398	2017-07-24 15:00:00+03	49600.00
2633A6	2017-08-05 18:09:00+03	58600.00
2633DC	2017-07-20 13:33:00+03	92400.00
2633F8	2017-07-16 07:22:00+03	56000.00
26340F	2017-08-06 12:38:00+03	59000.00
26350D	2017-07-13 00:46:00+03	17200.00
26351B	2017-07-10 12:04:00+03	137100.00
263522	2017-07-02 04:08:00+03	27200.00
263537	2017-07-20 03:15:00+03	16400.00
263593	2017-07-07 14:07:00+03	95200.00
2635A5	2017-07-11 11:36:00+03	62600.00
263608	2017-07-06 06:17:00+03	161200.00
263636	2017-08-04 18:52:00+03	40800.00
26367C	2017-06-29 06:53:00+03	47400.00
2636B9	2017-08-08 16:19:00+03	80300.00
2636F9	2017-07-13 02:29:00+03	271200.00
26372B	2017-07-28 23:07:00+03	8400.00
263789	2017-07-02 07:28:00+03	92400.00
26381A	2017-07-09 01:29:00+03	86500.00
263866	2017-08-13 18:05:00+03	117700.00
26388B	2017-07-01 10:02:00+03	128800.00
2638D9	2017-07-17 12:50:00+03	160700.00
263921	2017-07-25 02:23:00+03	123000.00
263981	2017-07-29 05:08:00+03	55800.00
26398B	2017-08-07 02:47:00+03	23200.00
2639C8	2017-07-17 05:13:00+03	123200.00
2639DF	2017-07-15 14:32:00+03	176800.00
2639EC	2017-08-01 09:29:00+03	28800.00
263A0A	2017-07-25 06:34:00+03	9800.00
263A44	2017-07-22 10:38:00+03	28000.00
263A68	2017-07-27 08:12:00+03	57500.00
263AFB	2017-07-29 08:59:00+03	137600.00
263AFC	2017-07-25 13:39:00+03	112000.00
263B08	2017-08-06 15:06:00+03	54400.00
263B76	2017-07-24 22:47:00+03	46400.00
263BBC	2017-06-29 13:34:00+03	29000.00
263BC3	2017-07-27 16:52:00+03	24700.00
263BD5	2017-08-07 10:12:00+03	62700.00
263BFA	2017-08-09 04:52:00+03	72200.00
263C63	2017-07-14 14:29:00+03	25100.00
263C8F	2017-08-09 19:24:00+03	14400.00
263C96	2017-07-14 12:38:00+03	20000.00
263D65	2017-07-18 22:44:00+03	73500.00
263D8A	2017-07-30 03:59:00+03	25200.00
263D8D	2017-07-25 00:07:00+03	30600.00
263D9E	2017-07-24 02:54:00+03	20200.00
263DF8	2017-07-10 19:03:00+03	39200.00
263E49	2017-07-15 12:20:00+03	105600.00
263E4D	2017-07-16 06:00:00+03	155200.00
263E56	2017-07-01 20:07:00+03	35600.00
263ECE	2017-06-29 18:43:00+03	20200.00
263EDE	2017-08-07 00:34:00+03	32800.00
263F0D	2017-07-30 11:33:00+03	16800.00
263FFF	2017-07-25 08:39:00+03	23200.00
264022	2017-08-11 08:48:00+03	6700.00
264027	2017-07-01 17:05:00+03	59800.00
264070	2017-07-11 09:46:00+03	135000.00
264072	2017-07-24 06:28:00+03	6600.00
264079	2017-07-05 12:19:00+03	64500.00
2640A9	2017-07-07 08:45:00+03	46000.00
264198	2017-07-01 15:20:00+03	44800.00
2641CF	2017-07-22 11:43:00+03	24200.00
264284	2017-07-29 08:34:00+03	34100.00
2642BB	2017-08-11 12:00:00+03	13000.00
2642BD	2017-08-12 05:22:00+03	246000.00
2642E2	2017-08-02 12:16:00+03	10800.00
264355	2017-07-28 07:09:00+03	70600.00
264395	2017-07-20 09:51:00+03	28000.00
26443A	2017-08-07 14:59:00+03	243600.00
26446B	2017-07-30 23:57:00+03	115600.00
264475	2017-07-09 09:28:00+03	398500.00
26447B	2017-08-15 13:38:00+03	46400.00
2644B5	2017-07-02 07:17:00+03	18000.00
26454E	2017-07-16 00:56:00+03	400600.00
264554	2017-08-04 07:51:00+03	143800.00
264577	2017-08-07 14:06:00+03	6800.00
264637	2017-07-22 05:02:00+03	26000.00
26465B	2017-07-23 03:20:00+03	531400.00
26467A	2017-08-08 05:40:00+03	46800.00
264696	2017-07-19 14:24:00+03	9800.00
264722	2017-07-28 15:24:00+03	103000.00
264746	2017-07-04 07:35:00+03	138000.00
264787	2017-07-10 08:51:00+03	51600.00
2647E2	2017-07-29 00:24:00+03	213200.00
26483B	2017-07-15 13:24:00+03	127300.00
2648DA	2017-07-06 09:47:00+03	42800.00
26491F	2017-08-05 23:06:00+03	156100.00
264931	2017-07-23 11:22:00+03	6800.00
26493A	2017-07-03 16:04:00+03	203100.00
2649AA	2017-07-14 23:16:00+03	32800.00
2649AB	2017-07-14 09:41:00+03	87900.00
2649BD	2017-07-31 03:22:00+03	43200.00
2649D0	2017-07-17 20:20:00+03	265700.00
2649F6	2017-07-11 06:17:00+03	25000.00
264A30	2017-07-29 22:41:00+03	27200.00
264AB9	2017-07-25 08:07:00+03	37200.00
264AC5	2017-08-01 09:26:00+03	15000.00
264C29	2017-07-31 15:10:00+03	54400.00
264C9C	2017-07-02 10:22:00+03	27600.00
264CA3	2017-07-07 05:53:00+03	133200.00
264D0B	2017-07-31 03:08:00+03	115700.00
264DE8	2017-07-26 16:58:00+03	229300.00
264DF1	2017-08-06 16:07:00+03	199700.00
264E92	2017-08-10 07:55:00+03	56600.00
264ECC	2017-07-26 16:30:00+03	186900.00
264EEB	2017-08-06 11:32:00+03	38600.00
264F87	2017-08-04 17:52:00+03	126700.00
264F99	2017-07-22 20:33:00+03	6000.00
264FD7	2017-06-26 16:21:00+03	113900.00
265014	2017-06-30 06:03:00+03	98400.00
265044	2017-07-19 16:47:00+03	133200.00
26504F	2017-07-10 07:23:00+03	34100.00
26508E	2017-07-15 10:55:00+03	25400.00
26509A	2017-08-09 00:39:00+03	23600.00
2650E1	2017-08-11 14:43:00+03	28800.00
265103	2017-07-25 18:55:00+03	13700.00
265148	2017-07-10 21:34:00+03	71800.00
2651A4	2017-07-28 12:40:00+03	128800.00
265281	2017-08-12 09:00:00+03	121700.00
2652D4	2017-08-09 06:08:00+03	66800.00
265314	2017-07-18 23:57:00+03	145200.00
26537C	2017-07-29 01:15:00+03	192900.00
2653B0	2017-07-09 16:18:00+03	66400.00
2653D5	2017-07-25 19:30:00+03	189200.00
26541B	2017-07-28 14:53:00+03	36800.00
265456	2017-07-05 12:21:00+03	47000.00
265462	2017-07-21 01:16:00+03	43600.00
265465	2017-07-19 05:06:00+03	95700.00
26548D	2017-07-01 03:36:00+03	136800.00
2655A0	2017-07-01 12:33:00+03	56100.00
265748	2017-07-17 09:26:00+03	42800.00
2657A3	2017-07-16 19:59:00+03	46800.00
2657A4	2017-08-06 18:32:00+03	83700.00
2657A9	2017-08-02 00:54:00+03	28800.00
2657D9	2017-08-15 08:42:00+03	56000.00
2657E4	2017-08-14 19:55:00+03	99300.00
2657E6	2017-07-09 02:35:00+03	54600.00
265888	2017-07-04 01:37:00+03	141700.00
2658BC	2017-08-14 09:54:00+03	68800.00
2658D4	2017-06-26 13:25:00+03	23600.00
265923	2017-07-29 12:30:00+03	91700.00
265962	2017-08-08 09:31:00+03	6300.00
265A89	2017-07-19 17:06:00+03	13400.00
265AD4	2017-07-08 19:17:00+03	410200.00
265B0A	2017-07-03 15:41:00+03	111600.00
265C0A	2017-08-10 16:08:00+03	15000.00
265C11	2017-06-26 16:40:00+03	293900.00
265CB5	2017-08-11 19:32:00+03	22100.00
265CE9	2017-07-02 16:09:00+03	73300.00
265D29	2017-07-13 14:02:00+03	36200.00
265DD7	2017-07-09 18:33:00+03	47200.00
265DD8	2017-08-11 04:12:00+03	28700.00
265DF8	2017-07-07 05:56:00+03	38600.00
265E1C	2017-08-13 08:28:00+03	46400.00
265E21	2017-08-03 17:54:00+03	27800.00
265E58	2017-08-02 16:47:00+03	118800.00
265EC0	2017-08-02 21:22:00+03	18000.00
265EE8	2017-07-24 14:23:00+03	7400.00
265F88	2017-07-29 05:29:00+03	54800.00
265FAF	2017-08-14 16:09:00+03	133200.00
265FDC	2017-08-05 11:50:00+03	50000.00
265FE1	2017-07-14 01:08:00+03	93900.00
266006	2017-07-28 04:07:00+03	75300.00
26603D	2017-07-23 02:22:00+03	23200.00
266045	2017-07-05 02:57:00+03	101900.00
266046	2017-07-22 10:48:00+03	34800.00
2660F8	2017-07-26 21:10:00+03	398500.00
266156	2017-07-09 13:40:00+03	61600.00
2661B6	2017-07-13 18:10:00+03	199600.00
2661C8	2017-08-13 09:53:00+03	56100.00
26628C	2017-07-24 14:34:00+03	21800.00
2662BD	2017-08-11 10:31:00+03	66600.00
2662DE	2017-07-10 14:05:00+03	28800.00
266377	2017-07-10 10:43:00+03	61600.00
2663CB	2017-07-31 01:24:00+03	53400.00
2663E7	2017-07-18 07:11:00+03	23600.00
266473	2017-08-01 23:57:00+03	55800.00
266501	2017-07-11 00:43:00+03	242700.00
266552	2017-08-03 23:02:00+03	42800.00
2665D9	2017-07-27 22:37:00+03	21600.00
266605	2017-08-04 01:02:00+03	23600.00
266627	2017-08-10 06:34:00+03	114800.00
266698	2017-07-23 15:13:00+03	59200.00
2666A4	2017-07-04 18:59:00+03	85000.00
2666C7	2017-07-26 04:10:00+03	28800.00
2666F7	2017-07-23 13:25:00+03	50900.00
266722	2017-07-01 18:38:00+03	29000.00
266739	2017-07-03 20:05:00+03	51600.00
2667D5	2017-07-26 12:18:00+03	128800.00
26680D	2017-08-08 09:38:00+03	170300.00
26681C	2017-08-11 09:58:00+03	81800.00
26681D	2017-08-05 04:22:00+03	248400.00
26682B	2017-08-01 08:09:00+03	6000.00
266850	2017-07-08 23:04:00+03	156100.00
266881	2017-08-13 08:24:00+03	40700.00
2668A5	2017-07-15 00:47:00+03	66600.00
2668A6	2017-06-29 08:25:00+03	62800.00
26694F	2017-08-04 20:00:00+03	123600.00
26698D	2017-08-02 19:27:00+03	55800.00
2669AA	2017-08-06 16:11:00+03	14000.00
2669D2	2017-07-08 17:42:00+03	57600.00
266A06	2017-08-14 14:35:00+03	40300.00
266A15	2017-07-31 18:46:00+03	133200.00
266A21	2017-07-08 16:04:00+03	40800.00
266A2E	2017-07-12 22:33:00+03	37100.00
266A66	2017-07-18 12:40:00+03	92800.00
266A8A	2017-07-12 23:48:00+03	37900.00
266AA2	2017-08-15 04:17:00+03	47500.00
266ACA	2017-08-07 01:27:00+03	55800.00
266AD6	2017-07-20 09:11:00+03	21800.00
266B38	2017-07-04 02:24:00+03	68800.00
266BCB	2017-07-12 03:29:00+03	97900.00
266BD0	2017-07-16 09:08:00+03	63800.00
266BD4	2017-07-18 18:54:00+03	201200.00
266BE3	2017-07-16 21:12:00+03	56000.00
266BF9	2017-07-02 14:30:00+03	56600.00
266BFD	2017-08-13 03:58:00+03	65300.00
266C2B	2017-07-27 16:39:00+03	133200.00
266C55	2017-07-04 11:27:00+03	141600.00
266C7E	2017-08-05 16:05:00+03	56600.00
266C88	2017-07-07 13:39:00+03	36200.00
266D0F	2017-07-08 14:27:00+03	52000.00
266D14	2017-08-08 13:25:00+03	102100.00
266D25	2017-07-03 16:33:00+03	16400.00
266D27	2017-07-25 18:15:00+03	36700.00
266D39	2017-07-01 02:49:00+03	20200.00
266D55	2017-07-20 22:10:00+03	56600.00
266DB0	2017-08-13 00:57:00+03	103500.00
266E40	2017-07-21 18:58:00+03	56000.00
266E7E	2017-07-03 02:32:00+03	153200.00
266E99	2017-08-15 14:03:00+03	234400.00
266EAA	2017-07-24 22:48:00+03	53400.00
266F4D	2017-07-15 07:33:00+03	10600.00
266F58	2017-08-15 07:36:00+03	120200.00
266FE9	2017-07-21 11:50:00+03	58600.00
267036	2017-08-07 07:25:00+03	40200.00
267056	2017-07-08 12:43:00+03	14400.00
267093	2017-07-26 14:57:00+03	32300.00
2670B1	2017-07-30 18:40:00+03	57600.00
2670C7	2017-07-25 12:48:00+03	25600.00
26710D	2017-08-07 18:02:00+03	38000.00
2672A5	2017-07-07 09:16:00+03	92100.00
2672B1	2017-07-27 13:50:00+03	67500.00
2672C5	2017-08-13 15:01:00+03	73500.00
267312	2017-08-15 16:21:00+03	61500.00
2673CB	2017-07-04 06:04:00+03	515100.00
267458	2017-07-22 01:13:00+03	63200.00
2674C6	2017-08-04 23:11:00+03	48300.00
2674EE	2017-07-09 20:31:00+03	27200.00
26751B	2017-07-29 12:14:00+03	138900.00
267538	2017-07-29 15:05:00+03	10800.00
267539	2017-08-05 19:52:00+03	75500.00
267589	2017-07-25 11:32:00+03	56000.00
2675B4	2017-07-06 05:44:00+03	48800.00
2675CB	2017-08-03 15:28:00+03	6800.00
267615	2017-07-07 05:29:00+03	25400.00
267645	2017-07-04 11:01:00+03	84100.00
26764B	2017-07-11 04:01:00+03	133800.00
267656	2017-08-13 05:20:00+03	11000.00
267775	2017-07-30 13:07:00+03	15000.00
2677AB	2017-07-09 17:23:00+03	73500.00
2677BD	2017-08-10 14:23:00+03	290800.00
267801	2017-08-06 03:22:00+03	31600.00
26780F	2017-07-30 05:00:00+03	154800.00
26782D	2017-07-28 21:54:00+03	47200.00
267868	2017-08-13 19:43:00+03	26000.00
2678C7	2017-07-28 05:42:00+03	14800.00
2678D3	2017-07-19 20:15:00+03	52000.00
267953	2017-07-27 14:12:00+03	31400.00
26797B	2017-07-19 20:49:00+03	66000.00
267993	2017-07-27 15:46:00+03	59000.00
2679EA	2017-07-19 18:45:00+03	30400.00
267A36	2017-07-06 14:20:00+03	172100.00
267AC4	2017-07-26 22:55:00+03	52100.00
267B03	2017-07-11 18:55:00+03	40800.00
267B1C	2017-08-15 13:05:00+03	123000.00
267B3D	2017-07-20 10:55:00+03	28800.00
267BA9	2017-07-31 12:31:00+03	31400.00
267BB2	2017-08-03 23:51:00+03	51600.00
267BB8	2017-08-10 16:10:00+03	43300.00
267BEA	2017-08-06 14:11:00+03	46400.00
267C19	2017-07-20 04:27:00+03	29400.00
267D06	2017-06-26 23:25:00+03	36900.00
267D2F	2017-07-13 11:26:00+03	57600.00
267D81	2017-07-30 07:30:00+03	93700.00
267DC3	2017-08-06 05:21:00+03	48900.00
267DDF	2017-07-22 11:30:00+03	24600.00
267E19	2017-08-15 02:53:00+03	111600.00
267E5A	2017-08-14 08:21:00+03	25100.00
267EA3	2017-08-06 21:50:00+03	47000.00
267F1D	2017-08-12 01:28:00+03	62600.00
267FD2	2017-07-06 04:40:00+03	72400.00
267FE0	2017-07-25 05:11:00+03	82000.00
26801D	2017-08-13 06:04:00+03	28800.00
2680CB	2017-07-09 16:06:00+03	28000.00
2680E6	2017-07-06 08:49:00+03	103800.00
26810B	2017-08-08 11:49:00+03	23200.00
268115	2017-07-28 10:03:00+03	40800.00
26813D	2017-07-27 03:46:00+03	21800.00
2681AB	2017-07-14 10:53:00+03	133200.00
2681D6	2017-08-10 23:24:00+03	56000.00
2681EE	2017-07-08 04:44:00+03	59000.00
268205	2017-08-01 08:35:00+03	440600.00
26825C	2017-08-13 21:45:00+03	62700.00
26827C	2017-07-14 09:42:00+03	232200.00
2683B9	2017-07-31 17:00:00+03	62700.00
268484	2017-07-17 16:24:00+03	55000.00
26849E	2017-06-30 00:53:00+03	86800.00
268507	2017-07-25 05:06:00+03	69000.00
268514	2017-08-03 10:50:00+03	65000.00
2685AD	2017-07-21 01:31:00+03	69900.00
2685B6	2017-07-11 23:43:00+03	60700.00
2685F7	2017-07-20 01:57:00+03	94400.00
268622	2017-08-09 09:40:00+03	39800.00
268662	2017-07-11 09:22:00+03	100600.00
2686A8	2017-07-13 06:12:00+03	56000.00
2687B6	2017-06-30 13:42:00+03	14000.00
2687C5	2017-07-09 11:05:00+03	101200.00
26881E	2017-07-28 10:51:00+03	131300.00
268822	2017-08-06 17:33:00+03	36200.00
268882	2017-07-07 04:00:00+03	29600.00
2688B5	2017-07-18 00:46:00+03	101500.00
2688CD	2017-08-03 06:16:00+03	93500.00
2688E4	2017-08-08 05:50:00+03	158600.00
26892A	2017-08-13 00:55:00+03	56600.00
26893C	2017-08-09 18:02:00+03	8200.00
26895A	2017-07-10 06:52:00+03	34700.00
2689CF	2017-07-29 12:34:00+03	28000.00
268A63	2017-07-02 20:14:00+03	154500.00
268A8B	2017-08-14 10:43:00+03	22000.00
268A99	2017-07-29 14:16:00+03	16000.00
268AA4	2017-07-04 06:36:00+03	27000.00
268AD2	2017-07-19 14:51:00+03	24400.00
268B0C	2017-07-29 00:10:00+03	53600.00
268B25	2017-07-26 08:33:00+03	25600.00
268B82	2017-08-15 13:39:00+03	13200.00
268BB8	2017-08-12 17:35:00+03	26800.00
268C1D	2017-08-02 02:36:00+03	134400.00
268C20	2017-08-02 08:03:00+03	14000.00
268C30	2017-07-31 00:40:00+03	123600.00
268C47	2017-07-13 22:57:00+03	29400.00
268C5A	2017-07-31 01:34:00+03	24300.00
268CA3	2017-07-07 14:38:00+03	56900.00
268D03	2017-07-08 00:13:00+03	147700.00
268D2A	2017-08-14 07:04:00+03	137900.00
268D45	2017-07-04 09:44:00+03	83300.00
268D62	2017-08-06 12:46:00+03	281500.00
268D78	2017-08-04 11:38:00+03	22100.00
268D8B	2017-07-25 10:17:00+03	206400.00
268E22	2017-07-12 20:35:00+03	27200.00
268E80	2017-07-05 06:19:00+03	16800.00
268EAE	2017-08-08 13:56:00+03	58000.00
268F66	2017-08-02 19:10:00+03	40000.00
268FC5	2017-07-17 21:25:00+03	27400.00
26905B	2017-07-27 08:11:00+03	75300.00
269062	2017-07-30 17:27:00+03	73300.00
2690A2	2017-07-04 10:33:00+03	56900.00
26910D	2017-08-06 13:24:00+03	28000.00
269138	2017-08-06 18:35:00+03	21400.00
269158	2017-08-06 04:48:00+03	43300.00
269166	2017-07-30 02:08:00+03	132700.00
26917C	2017-07-25 14:57:00+03	131100.00
2691AC	2017-06-28 14:24:00+03	28000.00
269236	2017-07-18 08:48:00+03	273000.00
269278	2017-06-30 05:56:00+03	47200.00
26927D	2017-07-07 00:12:00+03	24400.00
2692C2	2017-07-24 10:50:00+03	23200.00
26930C	2017-08-05 14:12:00+03	22400.00
269339	2017-07-19 17:37:00+03	521200.00
269341	2017-07-24 03:03:00+03	243700.00
269350	2017-07-12 00:46:00+03	23400.00
26939A	2017-08-05 04:01:00+03	23200.00
2693E7	2017-07-02 01:18:00+03	4000.00
269437	2017-07-17 09:20:00+03	12600.00
26948A	2017-07-08 00:48:00+03	40800.00
2694B5	2017-07-06 05:51:00+03	130000.00
2694C9	2017-07-31 01:42:00+03	64300.00
2694E6	2017-07-24 01:29:00+03	85000.00
269504	2017-08-14 12:08:00+03	481100.00
269512	2017-07-11 19:23:00+03	52600.00
269611	2017-07-12 16:00:00+03	66600.00
269655	2017-07-23 03:24:00+03	9000.00
269694	2017-07-24 22:03:00+03	45100.00
26969C	2017-08-08 10:13:00+03	46900.00
2696A6	2017-07-14 15:47:00+03	246000.00
2696BE	2017-08-06 08:31:00+03	35800.00
2696F0	2017-08-02 08:11:00+03	52900.00
26974D	2017-07-07 08:04:00+03	116400.00
269769	2017-08-06 07:12:00+03	87100.00
2697D0	2017-08-09 04:45:00+03	59800.00
2697EB	2017-07-18 11:30:00+03	58600.00
269812	2017-07-19 04:41:00+03	135000.00
269839	2017-07-31 00:54:00+03	23600.00
26985C	2017-08-15 00:09:00+03	249000.00
2698C2	2017-07-06 02:46:00+03	118800.00
26991E	2017-08-05 17:58:00+03	19600.00
269936	2017-07-12 15:23:00+03	78300.00
269A93	2017-07-18 18:31:00+03	24000.00
269A9F	2017-08-03 05:31:00+03	186900.00
269ABA	2017-07-20 20:21:00+03	28000.00
269B11	2017-08-10 02:10:00+03	78100.00
269B3D	2017-07-25 04:56:00+03	29200.00
269B43	2017-07-17 08:26:00+03	40300.00
269B53	2017-08-05 11:13:00+03	32800.00
269B5D	2017-07-22 22:11:00+03	77000.00
269B69	2017-07-05 14:05:00+03	67600.00
269B89	2017-07-17 01:39:00+03	34000.00
269BFB	2017-08-11 13:06:00+03	21800.00
269C18	2017-07-19 07:10:00+03	28000.00
269C33	2017-07-02 22:26:00+03	18800.00
269C53	2017-07-30 22:15:00+03	56900.00
269C6F	2017-08-15 07:39:00+03	58700.00
269C76	2017-07-09 04:19:00+03	39800.00
269CDC	2017-07-18 01:48:00+03	92800.00
269CE0	2017-07-29 09:18:00+03	68100.00
269CEA	2017-07-09 07:32:00+03	70700.00
269D7A	2017-07-29 09:48:00+03	27900.00
269D85	2017-08-03 14:03:00+03	455900.00
269D8B	2017-07-10 20:30:00+03	26800.00
269DB1	2017-07-04 15:18:00+03	18000.00
269DDC	2017-08-06 18:47:00+03	46900.00
269E45	2017-07-13 21:50:00+03	132800.00
269EEC	2017-07-15 00:34:00+03	32400.00
269F20	2017-07-31 09:15:00+03	15400.00
269F2B	2017-07-09 04:45:00+03	6300.00
269F8F	2017-08-14 16:25:00+03	46400.00
269FC4	2017-07-12 08:07:00+03	64600.00
269FCE	2017-07-18 23:51:00+03	92900.00
269FD0	2017-08-02 06:18:00+03	34000.00
269FEF	2017-07-16 07:47:00+03	232800.00
26A00A	2017-08-07 11:49:00+03	93900.00
26A02D	2017-08-06 23:16:00+03	398500.00
26A044	2017-07-28 05:13:00+03	75300.00
26A10E	2017-06-28 07:21:00+03	92400.00
26A112	2017-08-06 19:14:00+03	24400.00
26A131	2017-07-13 13:24:00+03	124200.00
26A16D	2017-07-19 20:38:00+03	135400.00
26A1DB	2017-07-16 11:10:00+03	111400.00
26A1E7	2017-07-21 03:28:00+03	39700.00
26A203	2017-07-17 23:19:00+03	286700.00
26A267	2017-08-08 02:37:00+03	205400.00
26A2D4	2017-07-06 09:20:00+03	238300.00
26A2DD	2017-07-29 19:23:00+03	85000.00
26A2ED	2017-07-26 13:55:00+03	123000.00
26A317	2017-08-09 19:33:00+03	101200.00
26A328	2017-08-02 20:31:00+03	19800.00
26A3C9	2017-07-06 12:14:00+03	37900.00
26A3CD	2017-08-11 11:20:00+03	77600.00
26A3F1	2017-08-09 11:22:00+03	27900.00
26A43C	2017-07-05 15:06:00+03	13400.00
26A4A5	2017-07-03 04:53:00+03	21800.00
26A4C2	2017-07-20 16:19:00+03	26000.00
26A4DA	2017-08-02 21:59:00+03	182300.00
26A4E1	2017-07-10 00:32:00+03	18600.00
26A51E	2017-08-05 20:48:00+03	54400.00
26A536	2017-08-05 13:20:00+03	123000.00
26A59C	2017-07-24 08:32:00+03	92900.00
26A5E8	2017-07-18 23:26:00+03	102100.00
26A669	2017-08-13 18:25:00+03	257500.00
26A69B	2017-07-11 03:02:00+03	258000.00
26A6BA	2017-07-29 12:52:00+03	68600.00
26A6E3	2017-07-30 05:34:00+03	138000.00
26A710	2017-07-02 13:46:00+03	111600.00
26A727	2017-07-21 03:54:00+03	100700.00
26A768	2017-07-29 23:53:00+03	88600.00
26A7BB	2017-08-15 01:17:00+03	19600.00
26A7E2	2017-07-08 16:04:00+03	119600.00
26A848	2017-07-26 18:58:00+03	26800.00
26A84D	2017-07-12 08:28:00+03	112000.00
26A87E	2017-07-09 17:08:00+03	20600.00
26A888	2017-07-06 20:01:00+03	258000.00
26A8D7	2017-06-30 00:44:00+03	72000.00
26A902	2017-07-15 11:17:00+03	57500.00
26A942	2017-07-08 00:56:00+03	47000.00
26AA10	2017-08-09 15:35:00+03	726600.00
26AA82	2017-07-26 05:36:00+03	113300.00
26AACA	2017-07-08 02:38:00+03	21200.00
26AB42	2017-08-04 18:30:00+03	129400.00
26AB5B	2017-07-16 04:15:00+03	179400.00
26AB98	2017-07-01 17:58:00+03	29500.00
26ABCB	2017-07-06 03:30:00+03	84500.00
26ABE3	2017-08-11 12:08:00+03	123000.00
26AC7F	2017-07-24 02:04:00+03	83000.00
26ACEC	2017-07-10 04:38:00+03	270400.00
26ACF0	2017-06-29 04:08:00+03	106900.00
26AD72	2017-07-26 21:41:00+03	111600.00
26AE20	2017-07-07 17:13:00+03	266400.00
26AE77	2017-07-19 20:38:00+03	65500.00
26AEAD	2017-08-05 19:00:00+03	58200.00
26AF25	2017-08-05 23:03:00+03	43100.00
26AF2D	2017-08-13 03:58:00+03	141600.00
26AF55	2017-08-08 15:00:00+03	54800.00
26AF63	2017-07-06 18:53:00+03	25400.00
26AF65	2017-08-15 16:51:00+03	103000.00
26AF89	2017-07-10 22:16:00+03	30900.00
26AF9A	2017-08-15 16:31:00+03	53600.00
26B00B	2017-08-02 12:58:00+03	31400.00
26B027	2017-06-26 10:06:00+03	50900.00
26B034	2017-08-06 16:21:00+03	135200.00
26B059	2017-07-11 15:48:00+03	40800.00
26B06E	2017-08-12 15:49:00+03	87900.00
26B0CF	2017-08-11 02:10:00+03	28800.00
26B0FA	2017-07-29 23:32:00+03	100600.00
26B14D	2017-07-20 21:42:00+03	28000.00
26B17F	2017-08-09 18:08:00+03	45200.00
26B1B8	2017-07-23 22:42:00+03	23200.00
26B1C6	2017-08-14 18:08:00+03	37200.00
26B1E0	2017-08-03 07:08:00+03	75000.00
26B257	2017-08-03 20:12:00+03	28000.00
26B28A	2017-08-07 03:15:00+03	12400.00
26B2B3	2017-08-12 16:08:00+03	68400.00
26B2D0	2017-07-10 03:46:00+03	17800.00
26B2DD	2017-07-26 21:51:00+03	42800.00
26B2EC	2017-08-05 18:01:00+03	6700.00
26B2F1	2017-08-01 13:47:00+03	55800.00
26B30F	2017-07-20 14:25:00+03	31400.00
26B333	2017-06-29 04:53:00+03	45100.00
26B347	2017-08-15 06:41:00+03	43200.00
26B3C7	2017-07-31 22:16:00+03	16400.00
26B3CC	2017-07-31 08:48:00+03	49100.00
26B47D	2017-07-15 23:01:00+03	46400.00
26B4B2	2017-08-04 20:35:00+03	271100.00
26B505	2017-07-03 07:15:00+03	31600.00
26B510	2017-07-24 06:07:00+03	103200.00
26B540	2017-08-02 23:42:00+03	49700.00
26B54E	2017-07-25 10:01:00+03	6300.00
26B5EF	2017-08-01 11:44:00+03	131600.00
26B5F6	2017-07-22 23:26:00+03	40800.00
26B650	2017-07-02 16:00:00+03	24700.00
26B652	2017-07-14 03:47:00+03	56600.00
26B671	2017-07-21 21:13:00+03	66100.00
26B699	2017-07-30 13:08:00+03	28800.00
26B69D	2017-06-26 14:19:00+03	37600.00
26B6B9	2017-07-05 22:14:00+03	56000.00
26B6C3	2017-08-02 00:52:00+03	25100.00
26B6DE	2017-07-01 20:16:00+03	258400.00
26B701	2017-08-05 10:22:00+03	26000.00
26B731	2017-07-05 05:15:00+03	92900.00
26B772	2017-08-11 22:17:00+03	59800.00
26B7E1	2017-07-21 14:28:00+03	25200.00
26B819	2017-08-13 04:15:00+03	36200.00
26B854	2017-07-04 07:18:00+03	116400.00
26B8F4	2017-08-10 17:51:00+03	24600.00
26B94B	2017-07-07 16:55:00+03	36800.00
26B9F4	2017-07-23 00:23:00+03	156500.00
26BA0F	2017-07-04 11:31:00+03	119900.00
26BA1D	2017-08-10 05:44:00+03	27200.00
26BA41	2017-07-15 08:18:00+03	24400.00
26BA8B	2017-08-14 01:52:00+03	47000.00
26BADB	2017-08-11 14:27:00+03	20000.00
26BAFF	2017-07-26 06:38:00+03	22000.00
26BB01	2017-07-10 06:29:00+03	6700.00
26BB10	2017-07-21 06:01:00+03	99700.00
26BB35	2017-07-21 23:29:00+03	23400.00
26BB76	2017-08-10 20:30:00+03	78800.00
26BB9D	2017-07-25 18:28:00+03	68400.00
26BBB0	2017-07-19 10:54:00+03	57800.00
26BBF8	2017-07-31 18:38:00+03	54800.00
26BC08	2017-08-12 11:30:00+03	60400.00
26BC84	2017-07-20 20:27:00+03	289300.00
26BC91	2017-07-26 10:18:00+03	46700.00
26BCAB	2017-08-11 07:22:00+03	153600.00
26BCD8	2017-08-10 18:26:00+03	54800.00
26BCEA	2017-07-02 05:36:00+03	66600.00
26BD13	2017-07-12 03:34:00+03	13000.00
26BDC6	2017-08-10 08:18:00+03	56000.00
26BE08	2017-08-04 00:43:00+03	76200.00
26BE2F	2017-08-10 05:47:00+03	21200.00
26BE3A	2017-08-06 16:04:00+03	16800.00
26BE62	2017-08-03 15:12:00+03	40000.00
26BEB8	2017-08-08 13:47:00+03	180600.00
26BF11	2017-07-04 09:37:00+03	34200.00
26BF73	2017-07-08 22:58:00+03	28800.00
26BFB7	2017-08-15 13:41:00+03	112000.00
26C014	2017-08-08 18:32:00+03	65100.00
26C01D	2017-07-23 14:50:00+03	28000.00
26C087	2017-07-24 00:28:00+03	70200.00
26C0EF	2017-07-05 04:45:00+03	124200.00
26C112	2017-07-14 23:58:00+03	42800.00
26C117	2017-07-22 08:58:00+03	67700.00
26C143	2017-07-11 17:10:00+03	219500.00
26C1C0	2017-07-09 02:11:00+03	23400.00
26C23B	2017-07-26 21:22:00+03	27800.00
26C355	2017-07-22 18:31:00+03	46000.00
26C35B	2017-07-16 18:52:00+03	12200.00
26C3E1	2017-08-07 23:53:00+03	62800.00
26C43C	2017-07-19 06:14:00+03	35200.00
26C4F4	2017-08-05 07:08:00+03	62000.00
26C4F5	2017-07-17 16:47:00+03	143200.00
26C4FA	2017-08-14 17:15:00+03	40100.00
26C53F	2017-07-28 08:31:00+03	69500.00
26C5C8	2017-08-03 16:56:00+03	240600.00
26C5DD	2017-07-26 08:59:00+03	91100.00
26C602	2017-08-04 04:21:00+03	246000.00
26C609	2017-08-06 22:13:00+03	106400.00
26C64D	2017-07-04 21:15:00+03	58100.00
26C6EC	2017-07-05 19:53:00+03	125400.00
26C827	2017-07-14 15:39:00+03	45200.00
26C86D	2017-07-05 05:53:00+03	28000.00
26C890	2017-07-12 14:44:00+03	111600.00
26C8BC	2017-08-11 09:11:00+03	68800.00
26C8F0	2017-07-03 17:27:00+03	64700.00
26C8F3	2017-07-01 19:29:00+03	28000.00
26C8FF	2017-07-28 08:56:00+03	111600.00
26C92C	2017-08-02 03:46:00+03	204000.00
26CA3F	2017-07-14 10:40:00+03	89700.00
26CA8C	2017-07-08 03:24:00+03	133100.00
26CAA6	2017-07-22 22:19:00+03	260300.00
26CB17	2017-07-04 16:22:00+03	57400.00
26CB96	2017-07-09 17:07:00+03	62700.00
26CBAD	2017-08-05 18:06:00+03	195800.00
26CBB5	2017-07-04 02:33:00+03	50700.00
26CBCE	2017-08-07 18:35:00+03	39300.00
26CBD1	2017-07-06 09:36:00+03	75300.00
26CC03	2017-07-19 21:50:00+03	14000.00
26CC2B	2017-08-08 18:35:00+03	14000.00
26CC3B	2017-07-11 19:39:00+03	202300.00
26CC60	2017-07-12 03:04:00+03	133200.00
26CC8B	2017-07-17 11:43:00+03	35600.00
26CCE3	2017-07-23 07:22:00+03	12000.00
26CCFC	2017-07-06 10:54:00+03	14800.00
26CD2D	2017-07-05 05:02:00+03	89700.00
26CD8E	2017-07-05 12:50:00+03	39200.00
26CDA6	2017-07-19 02:08:00+03	121800.00
26CE27	2017-08-14 14:40:00+03	12600.00
26CE3F	2017-07-09 12:50:00+03	46400.00
26CEAA	2017-06-27 11:50:00+03	53600.00
26CF2A	2017-08-07 04:51:00+03	62900.00
26CF5C	2017-07-21 20:54:00+03	20500.00
26CF6A	2017-08-10 03:30:00+03	27400.00
26CFA5	2017-07-26 21:12:00+03	84900.00
26CFBF	2017-08-07 16:28:00+03	53300.00
26CFD3	2017-07-03 08:21:00+03	88900.00
26CFF2	2017-08-05 21:24:00+03	116700.00
26D029	2017-07-31 00:11:00+03	393000.00
26D03A	2017-07-28 14:58:00+03	45200.00
26D0AE	2017-07-15 17:26:00+03	135600.00
26D0C9	2017-08-15 16:20:00+03	187600.00
26D10C	2017-07-27 10:50:00+03	27900.00
26D14B	2017-07-25 03:59:00+03	43100.00
26D210	2017-07-22 20:52:00+03	50200.00
26D214	2017-08-15 05:16:00+03	27200.00
26D237	2017-07-21 01:14:00+03	20900.00
26D28A	2017-07-11 11:09:00+03	44600.00
26D28E	2017-07-13 04:59:00+03	159500.00
26D2CD	2017-08-06 22:43:00+03	47600.00
26D34D	2017-06-30 02:52:00+03	17000.00
26D37E	2017-07-04 06:16:00+03	26000.00
26D3BA	2017-08-14 22:20:00+03	406700.00
26D3CC	2017-07-07 11:47:00+03	29400.00
26D45B	2017-07-09 07:03:00+03	46800.00
26D482	2017-08-11 19:50:00+03	38800.00
26D4F8	2017-07-09 09:06:00+03	132800.00
26D504	2017-08-09 04:05:00+03	92800.00
26D557	2017-08-04 04:03:00+03	126700.00
26D569	2017-07-04 08:12:00+03	67600.00
26D574	2017-08-04 23:02:00+03	18000.00
26D5DE	2017-07-06 17:41:00+03	101200.00
26D5E8	2017-07-04 21:23:00+03	38200.00
26D602	2017-08-06 19:20:00+03	54300.00
26D603	2017-07-09 22:07:00+03	58200.00
26D60E	2017-07-25 05:08:00+03	76900.00
26D60F	2017-07-03 00:36:00+03	36500.00
26D64B	2017-07-04 06:30:00+03	112600.00
26D6C2	2017-07-27 01:40:00+03	21000.00
26D713	2017-08-08 13:32:00+03	62000.00
26D71C	2017-07-12 03:51:00+03	7400.00
26D781	2017-08-09 22:23:00+03	23600.00
26D798	2017-07-25 09:01:00+03	16400.00
26D7D4	2017-07-20 11:48:00+03	68800.00
26D81F	2017-07-23 16:01:00+03	58400.00
26D89B	2017-07-13 19:07:00+03	75300.00
26D8B7	2017-08-15 06:01:00+03	70800.00
26D8CF	2017-07-13 20:09:00+03	246000.00
26D8E7	2017-07-08 07:33:00+03	6000.00
26D97E	2017-07-27 04:59:00+03	81800.00
26D98E	2017-07-18 00:57:00+03	59300.00
26D9D7	2017-07-07 04:10:00+03	31900.00
26DA93	2017-08-01 09:55:00+03	147200.00
26DAA8	2017-07-21 09:37:00+03	24800.00
26DABB	2017-07-05 10:44:00+03	44700.00
26DC41	2017-08-15 16:41:00+03	149000.00
26DD1F	2017-07-31 16:01:00+03	123000.00
26DD23	2017-08-07 10:58:00+03	125200.00
26DD3B	2017-07-09 20:30:00+03	191000.00
26DDA1	2017-07-03 12:33:00+03	22000.00
26DDAA	2017-08-11 07:07:00+03	26000.00
26DDC1	2017-07-23 02:29:00+03	25400.00
26DDFE	2017-07-16 03:57:00+03	59400.00
26DF1F	2017-07-27 23:26:00+03	85000.00
26DF59	2017-08-02 18:00:00+03	6700.00
26DF66	2017-07-29 05:06:00+03	32800.00
26DF71	2017-07-04 00:10:00+03	228900.00
26E03A	2017-08-15 15:26:00+03	27200.00
26E063	2017-07-31 23:23:00+03	38400.00
26E170	2017-08-10 19:17:00+03	55800.00
26E18F	2017-07-11 09:15:00+03	75600.00
26E1A0	2017-07-18 02:52:00+03	99300.00
26E1BA	2017-07-11 18:39:00+03	113700.00
26E1E0	2017-07-04 21:57:00+03	153900.00
26E1F9	2017-07-27 18:32:00+03	48400.00
26E1FF	2017-08-15 00:27:00+03	46700.00
26E211	2017-08-01 12:07:00+03	224000.00
26E22F	2017-07-09 17:59:00+03	92900.00
26E23D	2017-06-30 02:00:00+03	191400.00
26E27D	2017-06-30 18:15:00+03	24400.00
26E2C0	2017-07-26 10:27:00+03	515100.00
26E2ED	2017-07-29 21:28:00+03	123600.00
26E333	2017-07-09 01:30:00+03	58000.00
26E33B	2017-07-28 01:08:00+03	12400.00
26E38E	2017-07-24 09:39:00+03	19600.00
26E3F1	2017-07-18 14:36:00+03	13600.00
26E400	2017-07-05 14:41:00+03	40800.00
26E49E	2017-07-16 00:41:00+03	54800.00
26E4DB	2017-07-15 05:48:00+03	125700.00
26E51D	2017-07-23 14:00:00+03	101600.00
26E534	2017-08-02 17:19:00+03	40400.00
26E53A	2017-07-24 10:42:00+03	78300.00
26E544	2017-08-05 15:13:00+03	10800.00
26E5A8	2017-07-27 05:44:00+03	55800.00
26E5BA	2017-07-03 02:11:00+03	57400.00
26E5CC	2017-07-21 21:53:00+03	9800.00
26E708	2017-07-08 09:06:00+03	60700.00
26E737	2017-07-03 14:05:00+03	37900.00
26E97F	2017-07-27 17:10:00+03	62600.00
26EA07	2017-08-08 19:03:00+03	12400.00
26EAB9	2017-07-18 21:29:00+03	14400.00
26EAD8	2017-07-26 04:48:00+03	135400.00
26EBA4	2017-07-30 16:48:00+03	70600.00
26EBD4	2017-08-03 06:45:00+03	14000.00
26EC09	2017-07-07 09:02:00+03	12600.00
26EC50	2017-06-28 15:23:00+03	18000.00
26EC6B	2017-07-25 21:01:00+03	56600.00
26ECA9	2017-08-12 21:21:00+03	89600.00
26ECC9	2017-07-21 22:15:00+03	23400.00
26ECCB	2017-07-30 07:36:00+03	24400.00
26ED86	2017-07-20 14:51:00+03	11700.00
26EDA5	2017-08-06 04:08:00+03	138600.00
26EDB9	2017-07-26 10:34:00+03	21800.00
26EDC2	2017-07-09 15:13:00+03	30200.00
26EE2B	2017-08-11 01:03:00+03	105600.00
26EE2C	2017-07-01 23:50:00+03	75300.00
26EE4B	2017-08-04 10:52:00+03	101700.00
26EE4F	2017-07-26 14:00:00+03	11000.00
26EF28	2017-08-07 03:11:00+03	174900.00
26EF58	2017-08-08 06:41:00+03	16400.00
26EF77	2017-08-12 02:57:00+03	46400.00
26F020	2017-07-15 11:31:00+03	36200.00
26F03E	2017-08-12 15:37:00+03	35500.00
26F078	2017-06-27 02:30:00+03	120800.00
26F0B5	2017-07-20 18:13:00+03	48800.00
26F0B6	2017-08-01 18:42:00+03	153300.00
26F11C	2017-07-17 22:13:00+03	248500.00
26F143	2017-07-23 05:08:00+03	70700.00
26F1C5	2017-08-02 16:19:00+03	26000.00
26F252	2017-07-24 08:27:00+03	6800.00
26F2A1	2017-07-09 06:45:00+03	73600.00
26F2CE	2017-07-16 18:31:00+03	16400.00
26F327	2017-08-12 23:38:00+03	177200.00
26F393	2017-07-08 09:22:00+03	13600.00
26F3DC	2017-07-20 05:00:00+03	34000.00
26F430	2017-07-13 04:04:00+03	55600.00
26F447	2017-08-08 01:22:00+03	198400.00
26F44B	2017-07-04 11:31:00+03	10600.00
26F44E	2017-07-20 02:26:00+03	57700.00
26F47B	2017-07-16 15:06:00+03	51900.00
26F4B8	2017-07-25 16:31:00+03	174800.00
26F4EE	2017-08-01 08:17:00+03	48800.00
26F516	2017-07-19 23:44:00+03	75500.00
26F528	2017-08-09 02:15:00+03	498200.00
26F59F	2017-07-07 19:16:00+03	116900.00
26F5D2	2017-07-24 19:39:00+03	24400.00
26F5D9	2017-08-08 15:59:00+03	84100.00
26F5DA	2017-07-10 07:33:00+03	93900.00
26F604	2017-07-07 11:28:00+03	101900.00
26F62D	2017-07-25 05:48:00+03	65500.00
26F747	2017-07-08 20:35:00+03	58600.00
26F79B	2017-07-09 07:42:00+03	36000.00
26F7D4	2017-06-29 19:11:00+03	103000.00
26F7D5	2017-07-29 02:12:00+03	81700.00
26F80B	2017-07-13 09:13:00+03	294500.00
26F834	2017-08-15 15:49:00+03	56600.00
26F889	2017-08-13 14:31:00+03	52800.00
26F8C3	2017-07-01 15:24:00+03	162600.00
26F8F9	2017-07-30 14:01:00+03	22200.00
26F987	2017-08-08 14:49:00+03	50200.00
26F991	2017-07-26 18:03:00+03	68100.00
26F992	2017-07-17 06:27:00+03	154900.00
26F9FB	2017-08-08 03:52:00+03	56600.00
26F9FD	2017-08-02 22:34:00+03	145100.00
26FA01	2017-07-06 00:13:00+03	123000.00
26FA60	2017-07-22 06:24:00+03	26800.00
26FA63	2017-08-08 21:55:00+03	272300.00
26FB28	2017-08-10 16:37:00+03	189100.00
26FB68	2017-06-30 21:51:00+03	109800.00
26FBBA	2017-07-13 02:23:00+03	52300.00
26FC38	2017-07-08 08:57:00+03	28000.00
26FC7D	2017-08-01 01:20:00+03	123000.00
26FCA9	2017-08-13 21:28:00+03	55800.00
26FCDD	2017-08-12 19:19:00+03	27200.00
26FD7A	2017-08-11 21:57:00+03	15000.00
26FD82	2017-07-21 14:38:00+03	123000.00
26FD8C	2017-08-03 19:11:00+03	93700.00
26FDD9	2017-07-01 22:51:00+03	47000.00
26FDDD	2017-08-10 03:30:00+03	66900.00
26FDEF	2017-08-05 03:14:00+03	369000.00
26FE0E	2017-06-28 05:37:00+03	26600.00
26FE3A	2017-08-12 17:05:00+03	49100.00
26FE49	2017-08-14 09:44:00+03	15900.00
26FE4A	2017-08-03 18:15:00+03	8200.00
26FE72	2017-07-31 12:32:00+03	79900.00
26FEB6	2017-07-30 13:46:00+03	28800.00
26FF06	2017-08-14 23:48:00+03	56900.00
26FF23	2017-08-06 04:42:00+03	58600.00
26FF28	2017-07-31 18:18:00+03	58400.00
26FF40	2017-07-17 01:34:00+03	169600.00
26FF8E	2017-07-24 22:08:00+03	19600.00
26FFA5	2017-07-10 19:11:00+03	33200.00
2700C6	2017-07-29 07:10:00+03	32200.00
270167	2017-07-06 19:32:00+03	135600.00
27019C	2017-08-11 12:14:00+03	30300.00
2701C0	2017-07-10 22:28:00+03	46500.00
2701C1	2017-07-27 22:04:00+03	58600.00
2701DD	2017-07-18 06:11:00+03	87400.00
2701FC	2017-08-07 20:27:00+03	38400.00
270220	2017-07-19 12:59:00+03	168200.00
270224	2017-07-22 15:08:00+03	71600.00
270230	2017-07-05 22:41:00+03	117600.00
270270	2017-07-09 12:56:00+03	38600.00
270284	2017-06-28 20:53:00+03	6200.00
2702B9	2017-08-15 07:10:00+03	55700.00
270340	2017-07-28 04:09:00+03	12400.00
270355	2017-07-22 10:42:00+03	42600.00
270356	2017-08-11 16:23:00+03	253300.00
270380	2017-08-12 08:08:00+03	47400.00
270385	2017-08-11 10:45:00+03	67600.00
27039F	2017-07-09 14:54:00+03	76300.00
2703D3	2017-08-11 04:38:00+03	21600.00
27041E	2017-07-01 08:23:00+03	32800.00
27042D	2017-08-11 12:08:00+03	132800.00
270452	2017-08-04 02:41:00+03	30200.00
270467	2017-07-09 16:02:00+03	166900.00
2704A6	2017-08-12 13:47:00+03	119800.00
2704C6	2017-07-22 01:25:00+03	46400.00
2704D2	2017-07-23 00:16:00+03	153200.00
2704E2	2017-08-12 00:10:00+03	91500.00
270564	2017-07-24 07:32:00+03	14000.00
270566	2017-07-03 23:11:00+03	23600.00
2705EA	2017-07-20 05:14:00+03	40900.00
270613	2017-07-16 02:16:00+03	25900.00
27061F	2017-07-09 13:50:00+03	26300.00
270635	2017-07-24 22:05:00+03	92800.00
27066D	2017-07-31 14:46:00+03	201200.00
270681	2017-07-25 10:45:00+03	74400.00
2706ED	2017-07-10 19:00:00+03	12600.00
270754	2017-08-15 12:09:00+03	32300.00
270756	2017-08-10 01:42:00+03	102300.00
2707A5	2017-08-07 13:36:00+03	531300.00
270886	2017-06-29 14:21:00+03	12600.00
2708C0	2017-08-11 22:54:00+03	37700.00
270912	2017-08-01 15:53:00+03	170000.00
270926	2017-07-03 19:10:00+03	56000.00
270944	2017-07-11 01:58:00+03	73900.00
270962	2017-07-04 18:53:00+03	68900.00
27098E	2017-08-12 22:59:00+03	77600.00
2709F6	2017-07-07 23:52:00+03	112000.00
270A75	2017-07-13 00:33:00+03	100900.00
270A77	2017-08-14 20:30:00+03	396500.00
270AA5	2017-07-17 22:01:00+03	56000.00
270B15	2017-07-05 10:28:00+03	88600.00
270B35	2017-08-10 11:46:00+03	30400.00
270B3E	2017-08-13 11:53:00+03	46000.00
270B4B	2017-07-18 01:21:00+03	60000.00
270B56	2017-08-11 04:28:00+03	56000.00
270B7C	2017-07-09 21:34:00+03	105000.00
270C1F	2017-08-15 02:58:00+03	36000.00
270C60	2017-07-05 04:26:00+03	132800.00
270CB6	2017-08-13 15:07:00+03	88100.00
270CC5	2017-07-27 12:37:00+03	116400.00
270D2D	2017-08-03 01:35:00+03	283100.00
270DCB	2017-07-23 21:35:00+03	271100.00
270E38	2017-08-08 19:53:00+03	95000.00
270E53	2017-08-13 16:43:00+03	62000.00
270F61	2017-07-16 04:00:00+03	198400.00
270FA8	2017-07-09 22:09:00+03	40700.00
270FB8	2017-07-16 03:06:00+03	155100.00
271021	2017-07-29 12:17:00+03	52800.00
271107	2017-07-15 07:23:00+03	65300.00
271155	2017-08-02 13:14:00+03	45200.00
27118E	2017-07-24 00:51:00+03	171100.00
2711B6	2017-07-05 07:21:00+03	55600.00
2711D2	2017-07-18 21:44:00+03	146300.00
2711E5	2017-08-10 03:36:00+03	26500.00
2711F8	2017-08-15 14:10:00+03	129700.00
271257	2017-07-19 15:29:00+03	7400.00
27126A	2017-07-16 11:30:00+03	26000.00
2712A4	2017-08-02 04:18:00+03	35700.00
271311	2017-07-06 21:07:00+03	242700.00
271331	2017-07-28 04:23:00+03	83600.00
27133B	2017-07-07 16:58:00+03	249100.00
27136F	2017-08-06 15:34:00+03	25800.00
2713C3	2017-07-16 23:03:00+03	44600.00
271405	2017-08-09 06:29:00+03	14300.00
27142D	2017-07-18 20:12:00+03	52300.00
271479	2017-07-11 09:30:00+03	59000.00
2714D7	2017-07-08 18:06:00+03	26600.00
2714E5	2017-07-16 02:20:00+03	79000.00
271522	2017-08-14 05:48:00+03	24400.00
271547	2017-08-10 20:24:00+03	23200.00
2715A7	2017-07-21 18:32:00+03	30200.00
2715FD	2017-07-22 04:40:00+03	7400.00
271612	2017-08-13 23:15:00+03	6700.00
27164E	2017-07-02 19:57:00+03	12000.00
27165A	2017-08-06 09:45:00+03	113800.00
2716C2	2017-07-04 12:19:00+03	36000.00
2716F1	2017-07-10 16:16:00+03	81300.00
2717BB	2017-07-18 02:18:00+03	58800.00
27182B	2017-08-04 10:13:00+03	10200.00
271865	2017-07-05 11:20:00+03	32400.00
27190B	2017-07-23 13:12:00+03	44000.00
27191D	2017-07-10 01:15:00+03	28000.00
271930	2017-08-08 06:16:00+03	118100.00
271936	2017-07-04 12:32:00+03	75300.00
27194E	2017-08-08 11:59:00+03	189200.00
27195A	2017-07-02 05:26:00+03	147500.00
2719BA	2017-07-15 23:15:00+03	62200.00
2719D9	2017-07-29 14:00:00+03	25000.00
2719E9	2017-07-29 05:49:00+03	32700.00
2719F5	2017-07-08 21:05:00+03	67600.00
271A2E	2017-08-12 23:17:00+03	16800.00
271A61	2017-07-20 22:18:00+03	196900.00
271A88	2017-08-08 12:41:00+03	111000.00
271AE0	2017-07-12 00:58:00+03	49800.00
271B0D	2017-08-02 15:01:00+03	42000.00
271B5B	2017-07-13 14:19:00+03	16400.00
271B5E	2017-07-18 21:28:00+03	65400.00
271B97	2017-08-08 05:10:00+03	62600.00
271C46	2017-08-11 23:47:00+03	43600.00
271C84	2017-07-08 16:10:00+03	10700.00
271C90	2017-08-03 02:13:00+03	31200.00
271C91	2017-08-03 08:58:00+03	23200.00
271CC0	2017-07-18 07:49:00+03	6800.00
271DAE	2017-07-16 20:54:00+03	30000.00
271E3F	2017-07-13 11:46:00+03	56100.00
271E4A	2017-07-10 13:55:00+03	16400.00
271E93	2017-08-12 08:08:00+03	6700.00
271EB1	2017-08-07 00:13:00+03	69600.00
271EF7	2017-06-30 19:47:00+03	44700.00
271F5C	2017-07-22 10:26:00+03	23200.00
271FA0	2017-07-17 14:35:00+03	93900.00
271FCF	2017-08-10 17:56:00+03	6700.00
271FF9	2017-07-18 04:46:00+03	63700.00
272099	2017-08-02 21:13:00+03	23200.00
2720A4	2017-08-07 14:58:00+03	48500.00
2720B7	2017-08-13 03:15:00+03	100200.00
272105	2017-07-16 14:49:00+03	16400.00
272125	2017-07-17 23:55:00+03	38600.00
272129	2017-08-15 16:53:00+03	113900.00
27212A	2017-07-20 18:25:00+03	90000.00
27212F	2017-07-21 23:44:00+03	78800.00
272158	2017-07-13 03:58:00+03	16400.00
272172	2017-07-15 22:54:00+03	257500.00
2721BA	2017-07-21 08:45:00+03	34100.00
2721D6	2017-07-25 00:24:00+03	91200.00
272204	2017-07-11 06:55:00+03	24300.00
272246	2017-07-08 22:00:00+03	24800.00
27226A	2017-07-22 13:48:00+03	135200.00
27227D	2017-08-12 16:58:00+03	40000.00
2722A9	2017-08-01 16:02:00+03	13400.00
2722EA	2017-07-26 00:27:00+03	29600.00
2722F3	2017-08-15 09:06:00+03	135200.00
27236D	2017-07-30 01:58:00+03	15400.00
272448	2017-07-08 17:48:00+03	69000.00
27244C	2017-08-05 12:50:00+03	72300.00
27246F	2017-08-06 15:30:00+03	88600.00
272479	2017-07-29 03:36:00+03	26000.00
2724C3	2017-07-26 08:34:00+03	56000.00
2725B6	2017-08-04 07:43:00+03	136500.00
2725E1	2017-06-30 13:01:00+03	270800.00
2725FA	2017-07-18 02:02:00+03	258400.00
272648	2017-08-09 02:28:00+03	57500.00
272726	2017-07-21 16:40:00+03	28800.00
272731	2017-07-07 05:46:00+03	23200.00
272790	2017-07-31 21:04:00+03	97600.00
272809	2017-07-26 06:11:00+03	83200.00
272812	2017-07-07 11:09:00+03	46400.00
27281D	2017-08-08 05:11:00+03	28000.00
27282F	2017-07-28 02:41:00+03	52000.00
2728BB	2017-07-30 15:39:00+03	36000.00
2728D5	2017-08-06 12:57:00+03	252200.00
2729C6	2017-07-28 18:40:00+03	46000.00
2729EB	2017-07-01 15:45:00+03	33600.00
272A2F	2017-07-12 15:40:00+03	39300.00
272A3D	2017-07-29 16:40:00+03	115100.00
272A6B	2017-07-18 05:32:00+03	28000.00
272A82	2017-08-11 02:40:00+03	58000.00
272AA9	2017-07-10 09:16:00+03	45200.00
272B0A	2017-07-11 06:21:00+03	88000.00
272B5E	2017-07-31 03:29:00+03	34800.00
272B62	2017-07-10 14:22:00+03	135400.00
272BE5	2017-08-01 17:08:00+03	77000.00
272C6D	2017-08-07 06:14:00+03	34600.00
272D12	2017-08-07 14:04:00+03	168000.00
272D28	2017-08-06 19:39:00+03	131100.00
272D41	2017-07-11 23:48:00+03	92100.00
272DF8	2017-08-13 17:52:00+03	56000.00
272E20	2017-07-02 08:14:00+03	12600.00
272E35	2017-08-09 08:15:00+03	48800.00
272E58	2017-07-08 03:50:00+03	25000.00
272E82	2017-07-08 00:48:00+03	28000.00
272E89	2017-08-03 04:54:00+03	266400.00
272EBC	2017-07-04 16:04:00+03	129700.00
272ED5	2017-08-14 04:48:00+03	13400.00
272F18	2017-07-18 18:28:00+03	62600.00
272F3F	2017-08-10 13:21:00+03	87200.00
272F62	2017-08-01 18:41:00+03	43500.00
272FED	2017-08-15 05:42:00+03	57200.00
272FFB	2017-08-04 07:58:00+03	56000.00
273004	2017-07-11 00:14:00+03	59400.00
2730EC	2017-08-03 17:00:00+03	81400.00
273114	2017-08-07 05:51:00+03	35600.00
27317E	2017-07-30 08:34:00+03	83100.00
2731CB	2017-08-03 09:39:00+03	186900.00
27321F	2017-07-09 21:57:00+03	80900.00
273256	2017-08-06 07:05:00+03	136800.00
2732AC	2017-07-31 20:26:00+03	50800.00
2732B8	2017-07-23 03:40:00+03	58800.00
27334A	2017-08-07 17:04:00+03	12200.00
273399	2017-08-14 12:31:00+03	19900.00
2733AC	2017-07-29 22:42:00+03	23200.00
2733D9	2017-07-05 01:32:00+03	81200.00
273431	2017-07-04 05:01:00+03	286600.00
273475	2017-07-26 16:32:00+03	36800.00
2734AA	2017-07-09 01:57:00+03	30600.00
273505	2017-08-10 21:05:00+03	24400.00
273517	2017-07-11 13:48:00+03	98200.00
273527	2017-07-27 20:34:00+03	32800.00
273550	2017-08-12 09:41:00+03	20700.00
27356E	2017-07-09 03:34:00+03	60400.00
2735D6	2017-07-06 21:04:00+03	23900.00
273654	2017-07-04 12:59:00+03	24700.00
273671	2017-08-09 11:11:00+03	89700.00
2736B7	2017-08-14 22:28:00+03	55800.00
2736BA	2017-07-19 01:41:00+03	25600.00
2736D6	2017-07-31 07:34:00+03	28000.00
2736E0	2017-07-26 19:09:00+03	46200.00
2736F3	2017-07-31 16:47:00+03	284400.00
273713	2017-07-10 14:03:00+03	34000.00
273751	2017-08-02 08:52:00+03	16400.00
27375E	2017-07-27 17:11:00+03	58400.00
273763	2017-07-21 01:20:00+03	46400.00
273783	2017-07-01 23:01:00+03	26700.00
2737D0	2017-07-20 04:11:00+03	92800.00
273882	2017-07-07 18:00:00+03	137100.00
2738BB	2017-08-05 23:35:00+03	41400.00
2738BF	2017-08-12 04:04:00+03	53600.00
2738C8	2017-08-10 09:28:00+03	47000.00
2738DA	2017-07-31 19:08:00+03	26200.00
2738F0	2017-08-06 14:50:00+03	123000.00
27398D	2017-07-01 20:46:00+03	26600.00
2739E3	2017-07-31 09:31:00+03	38200.00
273AFA	2017-08-04 08:23:00+03	88500.00
273B17	2017-07-15 13:02:00+03	13600.00
273B8A	2017-07-22 21:16:00+03	29600.00
273CCC	2017-08-13 01:06:00+03	14400.00
273CED	2017-07-18 17:24:00+03	91500.00
273CF7	2017-07-30 15:48:00+03	102100.00
273D1D	2017-07-02 10:27:00+03	43600.00
273D2A	2017-07-03 17:56:00+03	89600.00
273D63	2017-07-16 15:55:00+03	114400.00
273DBD	2017-08-09 06:19:00+03	30200.00
273E07	2017-08-10 11:52:00+03	137600.00
273E0E	2017-08-14 23:56:00+03	68900.00
273EB9	2017-08-06 11:58:00+03	26000.00
273F02	2017-07-08 04:48:00+03	103500.00
273FC7	2017-08-13 23:01:00+03	177200.00
274050	2017-07-10 20:51:00+03	15800.00
274051	2017-08-02 01:05:00+03	27800.00
27405C	2017-08-06 15:43:00+03	202100.00
2740EF	2017-08-09 12:34:00+03	12600.00
274165	2017-07-31 04:13:00+03	53400.00
27419A	2017-06-30 23:18:00+03	23200.00
2741EA	2017-07-22 13:35:00+03	169600.00
27427E	2017-07-21 13:10:00+03	67600.00
274292	2017-07-22 04:05:00+03	37900.00
2742F5	2017-07-04 20:06:00+03	7200.00
2743C6	2017-07-01 10:49:00+03	46200.00
274426	2017-08-05 23:44:00+03	423900.00
274438	2017-07-30 13:37:00+03	88200.00
27446A	2017-08-14 20:28:00+03	80100.00
274523	2017-07-28 20:18:00+03	94000.00
2745E1	2017-06-30 06:15:00+03	143100.00
2746AA	2017-08-06 05:47:00+03	58600.00
2746B2	2017-08-13 21:12:00+03	56000.00
2746D1	2017-07-30 18:09:00+03	111600.00
2746EC	2017-08-14 19:58:00+03	68800.00
27477C	2017-07-14 19:03:00+03	30400.00
2747A8	2017-08-12 12:16:00+03	155600.00
2747D4	2017-07-27 16:12:00+03	62600.00
274842	2017-07-24 22:42:00+03	116900.00
274845	2017-07-25 11:31:00+03	67600.00
274899	2017-08-03 12:48:00+03	48800.00
274993	2017-07-12 17:35:00+03	19600.00
2749D9	2017-07-21 20:22:00+03	6000.00
274A1B	2017-07-30 08:11:00+03	46000.00
274A28	2017-07-21 18:41:00+03	22000.00
274AC4	2017-08-03 14:47:00+03	30900.00
274AD6	2017-07-17 05:46:00+03	141600.00
274B0F	2017-07-27 03:24:00+03	129200.00
274B3E	2017-08-01 03:08:00+03	21800.00
274B50	2017-08-09 11:50:00+03	16400.00
274B89	2017-07-30 01:33:00+03	23200.00
274BFE	2017-08-11 14:26:00+03	73600.00
274C4B	2017-07-29 18:02:00+03	68400.00
274CA6	2017-07-27 13:30:00+03	266400.00
274D7A	2017-08-10 03:40:00+03	26000.00
274DF3	2017-08-12 11:39:00+03	147100.00
274DF4	2017-07-17 07:05:00+03	38600.00
274E84	2017-08-02 09:44:00+03	42800.00
274EAD	2017-08-03 00:51:00+03	127200.00
274F21	2017-07-27 01:20:00+03	96300.00
274F8A	2017-07-10 17:50:00+03	113300.00
274FC0	2017-08-12 16:26:00+03	101100.00
274FC9	2017-07-05 20:55:00+03	123000.00
275037	2017-07-26 13:56:00+03	56000.00
275157	2017-07-30 12:01:00+03	53200.00
275159	2017-08-13 05:18:00+03	34400.00
2751AD	2017-07-10 13:12:00+03	137600.00
27520E	2017-07-30 00:21:00+03	191200.00
275260	2017-07-19 19:50:00+03	54500.00
275261	2017-07-21 04:51:00+03	83300.00
275302	2017-07-07 06:13:00+03	24200.00
2753D3	2017-08-04 10:08:00+03	139800.00
275479	2017-07-27 03:59:00+03	29600.00
275486	2017-07-20 12:21:00+03	85000.00
275497	2017-07-21 11:39:00+03	53300.00
275498	2017-07-02 17:46:00+03	105600.00
2754E1	2017-08-01 12:06:00+03	33100.00
2754E5	2017-08-04 22:31:00+03	31600.00
27552E	2017-07-24 08:47:00+03	55800.00
275581	2017-07-29 22:58:00+03	125200.00
2755F6	2017-07-19 10:03:00+03	44800.00
27565A	2017-07-26 20:23:00+03	392700.00
275680	2017-08-01 10:57:00+03	6700.00
275685	2017-08-05 16:40:00+03	67600.00
275713	2017-07-29 15:25:00+03	61800.00
275757	2017-07-24 06:15:00+03	16400.00
275818	2017-07-22 19:04:00+03	28300.00
27582F	2017-07-28 12:32:00+03	55800.00
275854	2017-07-31 18:26:00+03	303500.00
27588F	2017-08-15 13:29:00+03	23600.00
2758E9	2017-07-22 14:42:00+03	57400.00
27593B	2017-07-31 04:31:00+03	83300.00
27594F	2017-08-07 06:19:00+03	28800.00
275959	2017-07-26 13:55:00+03	26000.00
27595F	2017-07-11 00:15:00+03	13000.00
27597D	2017-08-08 10:01:00+03	56600.00
27599C	2017-08-03 20:42:00+03	403600.00
2759B2	2017-07-10 16:53:00+03	13400.00
2759D3	2017-07-10 15:55:00+03	496600.00
275A31	2017-07-14 14:20:00+03	28700.00
275B1A	2017-06-27 19:27:00+03	116500.00
275B1B	2017-07-17 14:35:00+03	106400.00
275B1C	2017-08-11 05:31:00+03	66000.00
275B3C	2017-07-23 01:32:00+03	48300.00
275B7B	2017-07-09 00:31:00+03	54800.00
275C3B	2017-07-04 07:56:00+03	10800.00
275C93	2017-08-02 23:43:00+03	92000.00
275C9C	2017-07-06 23:40:00+03	69500.00
275CCA	2017-07-30 12:21:00+03	32800.00
275D18	2017-07-20 00:57:00+03	6000.00
275D55	2017-07-21 08:57:00+03	26800.00
275DB4	2017-08-05 16:28:00+03	47000.00
275DBD	2017-07-26 17:36:00+03	27200.00
275DC2	2017-08-05 02:53:00+03	167400.00
275DCF	2017-07-05 22:09:00+03	28800.00
275E0C	2017-07-05 06:47:00+03	101100.00
275E4A	2017-08-01 19:52:00+03	66200.00
275E75	2017-07-21 01:31:00+03	34200.00
275E99	2017-07-08 22:08:00+03	6000.00
275F0C	2017-08-10 18:51:00+03	12400.00
275F26	2017-07-30 10:41:00+03	68800.00
276029	2017-07-17 18:19:00+03	55800.00
276264	2017-07-29 11:23:00+03	22000.00
27627F	2017-08-15 14:38:00+03	36800.00
2762AE	2017-07-09 10:00:00+03	77400.00
2762E2	2017-08-11 06:16:00+03	199800.00
27639D	2017-07-18 13:19:00+03	84400.00
27646B	2017-07-12 19:06:00+03	14400.00
2764BD	2017-07-28 21:32:00+03	136600.00
2764DC	2017-07-23 14:19:00+03	25800.00
2764E3	2017-07-20 17:33:00+03	37200.00
276539	2017-07-18 22:15:00+03	55800.00
276579	2017-08-12 04:29:00+03	135400.00
276588	2017-07-05 12:13:00+03	111600.00
276595	2017-08-04 05:15:00+03	92600.00
2765BF	2017-07-24 01:01:00+03	21000.00
2765E0	2017-08-02 23:06:00+03	91800.00
27663A	2017-06-29 18:48:00+03	151400.00
276650	2017-06-30 06:37:00+03	35400.00
2766F2	2017-07-11 11:48:00+03	156300.00
276715	2017-08-01 18:44:00+03	48800.00
27673E	2017-06-29 23:58:00+03	22600.00
276775	2017-07-04 09:28:00+03	40800.00
2767F0	2017-08-13 23:43:00+03	52800.00
2768B7	2017-07-09 11:05:00+03	23400.00
2768F9	2017-07-06 04:05:00+03	26800.00
276953	2017-07-02 07:06:00+03	64100.00
27696A	2017-08-08 21:39:00+03	64800.00
27698B	2017-08-04 10:52:00+03	820100.00
2769DE	2017-07-12 04:38:00+03	66000.00
2769E5	2017-07-31 06:30:00+03	24800.00
276A29	2017-07-12 16:37:00+03	223200.00
276A2C	2017-07-13 13:23:00+03	541400.00
276A53	2017-07-20 01:09:00+03	20200.00
276A6F	2017-08-11 05:20:00+03	95800.00
276A71	2017-07-13 04:48:00+03	18000.00
276ABB	2017-08-04 06:16:00+03	96800.00
276C4A	2017-08-11 20:26:00+03	64600.00
276D2E	2017-08-09 00:54:00+03	25100.00
276D58	2017-07-18 09:06:00+03	90600.00
276D9D	2017-07-20 06:06:00+03	56900.00
276DDD	2017-07-08 20:38:00+03	11800.00
276E0A	2017-08-01 02:06:00+03	55800.00
276E74	2017-08-01 22:23:00+03	21800.00
276EDD	2017-07-22 13:53:00+03	135600.00
276F14	2017-08-06 02:30:00+03	147500.00
276FD7	2017-07-25 17:09:00+03	26700.00
277017	2017-07-14 17:10:00+03	23600.00
277045	2017-08-13 17:43:00+03	43000.00
277072	2017-08-12 18:12:00+03	71900.00
2770BA	2017-08-14 09:52:00+03	57200.00
2770BB	2017-07-04 11:06:00+03	111600.00
2770E8	2017-07-13 12:40:00+03	148800.00
277101	2017-08-14 10:32:00+03	43900.00
277105	2017-07-20 10:43:00+03	106400.00
277197	2017-07-18 05:26:00+03	101800.00
277205	2017-08-06 20:09:00+03	128800.00
277210	2017-07-02 07:34:00+03	55800.00
27724E	2017-07-20 06:53:00+03	392200.00
277284	2017-07-04 01:09:00+03	22000.00
277295	2017-07-08 13:08:00+03	25600.00
277363	2017-07-25 21:22:00+03	104800.00
27736A	2017-08-04 11:51:00+03	10800.00
277400	2017-08-12 18:34:00+03	24000.00
277416	2017-08-02 19:16:00+03	6600.00
277467	2017-08-11 18:08:00+03	406100.00
2775D0	2017-07-06 18:40:00+03	24400.00
27760C	2017-08-04 05:10:00+03	57600.00
277611	2017-07-06 19:05:00+03	9300.00
27769F	2017-07-18 07:35:00+03	70600.00
2776F0	2017-07-18 09:37:00+03	62700.00
2776FA	2017-08-08 18:57:00+03	56600.00
277709	2017-08-05 23:15:00+03	32700.00
277732	2017-07-05 08:13:00+03	23200.00
277747	2017-07-31 09:33:00+03	83700.00
277828	2017-07-03 10:23:00+03	40800.00
27786D	2017-07-18 00:37:00+03	58600.00
27789D	2017-07-12 21:42:00+03	37600.00
2778F3	2017-07-19 02:08:00+03	67400.00
277916	2017-08-15 06:40:00+03	40800.00
277925	2017-08-13 06:46:00+03	168000.00
27798B	2017-07-31 14:29:00+03	19600.00
277A1F	2017-08-06 10:09:00+03	63200.00
277A55	2017-07-27 20:46:00+03	7400.00
277A6E	2017-07-17 06:20:00+03	141100.00
277A91	2017-08-08 06:47:00+03	54800.00
277B01	2017-07-12 23:37:00+03	146000.00
277B17	2017-07-23 02:11:00+03	12400.00
277B63	2017-08-10 02:06:00+03	47000.00
277BC6	2017-08-02 03:19:00+03	14400.00
277C68	2017-07-11 02:02:00+03	8200.00
277D44	2017-07-11 14:49:00+03	44800.00
277DAB	2017-07-11 16:38:00+03	66000.00
277DDE	2017-07-07 16:12:00+03	52800.00
277DF2	2017-08-02 13:29:00+03	21600.00
277DF9	2017-07-23 18:26:00+03	62600.00
277ECC	2017-08-01 18:40:00+03	40800.00
277ED9	2017-08-10 06:41:00+03	13400.00
277F29	2017-08-09 08:10:00+03	100200.00
2780AE	2017-07-25 00:50:00+03	27400.00
2780B7	2017-07-12 19:17:00+03	56100.00
2780EB	2017-08-14 09:08:00+03	23100.00
27818C	2017-07-30 02:36:00+03	21400.00
27819A	2017-07-10 02:41:00+03	47000.00
27819D	2017-08-02 10:52:00+03	30800.00
2781A0	2017-07-05 06:08:00+03	51900.00
2781A5	2017-07-16 04:39:00+03	55800.00
27820C	2017-08-14 21:17:00+03	93300.00
278217	2017-07-23 15:29:00+03	21800.00
278246	2017-07-31 08:28:00+03	136000.00
278261	2017-07-20 03:19:00+03	39200.00
2782F9	2017-07-07 20:34:00+03	74300.00
278360	2017-07-02 16:09:00+03	65400.00
2783BC	2017-07-18 18:51:00+03	155600.00
2783D2	2017-07-24 05:04:00+03	26200.00
2783EA	2017-08-09 21:24:00+03	177900.00
278414	2017-08-06 16:23:00+03	23200.00
2784A2	2017-07-23 07:35:00+03	47100.00
2784B8	2017-07-26 00:40:00+03	66000.00
278580	2017-06-26 05:58:00+03	66200.00
27859B	2017-08-15 02:26:00+03	19600.00
2785BA	2017-07-17 09:59:00+03	43500.00
2785D5	2017-08-14 04:46:00+03	23200.00
278605	2017-07-23 07:33:00+03	14000.00
278607	2017-06-27 15:03:00+03	28000.00
278654	2017-08-13 16:14:00+03	11000.00
2786A7	2017-07-17 08:40:00+03	146400.00
278759	2017-07-01 00:58:00+03	78700.00
278796	2017-07-17 04:29:00+03	135400.00
2787C0	2017-07-31 23:53:00+03	148200.00
2787D6	2017-08-14 14:25:00+03	30200.00
278818	2017-07-21 20:02:00+03	76600.00
278835	2017-07-03 22:11:00+03	56000.00
27884E	2017-07-25 20:08:00+03	316000.00
278857	2017-08-12 00:16:00+03	51900.00
2788B2	2017-07-04 15:01:00+03	188800.00
278962	2017-07-19 00:51:00+03	27200.00
278986	2017-07-23 03:18:00+03	293900.00
2789B5	2017-08-07 11:25:00+03	31600.00
278A16	2017-07-28 19:32:00+03	22600.00
278A34	2017-07-20 06:35:00+03	53100.00
278AD2	2017-08-11 17:23:00+03	79600.00
278B2E	2017-07-17 04:12:00+03	13600.00
278B60	2017-07-02 08:54:00+03	61400.00
278BC9	2017-08-11 22:38:00+03	177200.00
278C1A	2017-07-19 03:15:00+03	411000.00
278C4C	2017-07-09 17:43:00+03	59800.00
278C50	2017-07-18 11:19:00+03	35700.00
278C6F	2017-07-16 21:27:00+03	181200.00
278C82	2017-07-05 15:55:00+03	6700.00
278C8C	2017-07-19 21:56:00+03	265600.00
278CB0	2017-07-28 23:46:00+03	70800.00
278CBB	2017-07-07 11:38:00+03	6800.00
278D01	2017-08-09 04:30:00+03	118500.00
278D42	2017-07-09 18:07:00+03	132800.00
278DFB	2017-08-06 01:41:00+03	30900.00
278E61	2017-07-16 14:25:00+03	123000.00
278E6E	2017-08-14 04:45:00+03	49900.00
278E97	2017-07-21 17:27:00+03	258000.00
278EB7	2017-08-15 17:05:00+03	15100.00
278F49	2017-07-09 11:08:00+03	20200.00
278F5E	2017-07-07 10:42:00+03	30200.00
278F61	2017-07-15 04:33:00+03	31400.00
278FEB	2017-08-08 01:07:00+03	38800.00
278FFE	2017-07-11 00:38:00+03	23200.00
27900F	2017-07-28 15:16:00+03	33600.00
279016	2017-07-24 14:46:00+03	6700.00
279087	2017-07-13 01:09:00+03	135600.00
2790C6	2017-07-05 17:22:00+03	28800.00
2790D6	2017-08-09 03:14:00+03	51200.00
2790F4	2017-07-22 10:47:00+03	41600.00
2790F8	2017-08-09 02:52:00+03	58400.00
27915A	2017-07-02 21:45:00+03	174400.00
279169	2017-07-23 18:06:00+03	50900.00
279174	2017-07-12 11:50:00+03	56000.00
27919F	2017-07-14 02:31:00+03	32700.00
279215	2017-07-03 22:30:00+03	75600.00
279228	2017-07-10 20:57:00+03	172300.00
279238	2017-07-14 15:38:00+03	101200.00
279254	2017-07-25 16:01:00+03	68100.00
27926F	2017-07-04 07:28:00+03	55600.00
2793AD	2017-07-25 03:42:00+03	156300.00
27940F	2017-07-07 15:45:00+03	43900.00
279422	2017-07-01 22:06:00+03	20400.00
279446	2017-07-31 12:22:00+03	62600.00
27948F	2017-06-28 20:53:00+03	69500.00
27949A	2017-07-12 18:38:00+03	66300.00
2794AB	2017-07-15 10:08:00+03	24400.00
27958E	2017-08-03 18:36:00+03	18300.00
2795EE	2017-07-12 02:33:00+03	80700.00
2795F9	2017-07-02 19:03:00+03	34000.00
279615	2017-06-30 13:09:00+03	55800.00
279620	2017-07-06 20:55:00+03	131800.00
279644	2017-08-02 04:16:00+03	70700.00
279650	2017-08-11 03:38:00+03	87100.00
27966B	2017-07-17 03:33:00+03	55800.00
279672	2017-08-15 06:15:00+03	23200.00
279674	2017-07-18 11:03:00+03	51900.00
27967A	2017-07-21 17:05:00+03	139500.00
279681	2017-08-12 18:14:00+03	136300.00
279690	2017-07-11 02:54:00+03	21800.00
2796C1	2017-08-14 09:08:00+03	111600.00
27974E	2017-08-08 23:29:00+03	43400.00
279765	2017-08-09 20:07:00+03	55500.00
279820	2017-08-09 04:01:00+03	21800.00
279824	2017-08-12 12:34:00+03	131600.00
279897	2017-07-24 11:31:00+03	21400.00
279904	2017-07-16 23:58:00+03	40300.00
2799D6	2017-07-11 19:32:00+03	350200.00
2799E8	2017-07-23 21:26:00+03	56600.00
279A49	2017-07-13 02:19:00+03	14000.00
279A53	2017-08-03 03:25:00+03	112700.00
279A9E	2017-07-14 23:50:00+03	21400.00
279AB2	2017-07-28 00:00:00+03	289100.00
279AFB	2017-08-05 04:16:00+03	31200.00
279B8B	2017-07-12 18:15:00+03	55500.00
279BE0	2017-07-17 10:02:00+03	56000.00
279C02	2017-07-29 21:04:00+03	23200.00
279C1C	2017-08-11 12:10:00+03	17800.00
279C61	2017-07-16 00:07:00+03	26700.00
279C68	2017-08-03 18:53:00+03	55800.00
279CB3	2017-08-13 17:12:00+03	122800.00
279CD8	2017-07-28 01:50:00+03	44000.00
279D0A	2017-08-06 01:42:00+03	23200.00
279D2F	2017-08-12 13:19:00+03	133100.00
279D32	2017-07-18 05:05:00+03	248300.00
279D46	2017-07-19 02:26:00+03	66600.00
279D5E	2017-07-28 14:31:00+03	21200.00
279D87	2017-07-14 16:39:00+03	93700.00
279DB4	2017-07-23 06:20:00+03	32700.00
279DBC	2017-07-10 06:16:00+03	271100.00
279E25	2017-07-20 12:47:00+03	209900.00
279E5C	2017-07-01 06:44:00+03	112000.00
279E80	2017-07-22 00:21:00+03	28000.00
279F0C	2017-06-30 02:41:00+03	80000.00
279F10	2017-07-24 23:52:00+03	12000.00
279F96	2017-07-16 11:57:00+03	92200.00
279FBA	2017-07-24 08:05:00+03	97600.00
27A02A	2017-08-05 02:22:00+03	133100.00
27A062	2017-07-03 08:26:00+03	68800.00
27A086	2017-07-07 21:30:00+03	23200.00
27A0AF	2017-08-08 09:55:00+03	134400.00
27A150	2017-07-30 18:07:00+03	26000.00
27A166	2017-07-30 16:41:00+03	73300.00
27A1E6	2017-07-16 06:44:00+03	25400.00
27A1E9	2017-06-29 06:07:00+03	100000.00
27A1EA	2017-07-31 12:20:00+03	56000.00
27A216	2017-08-09 00:22:00+03	31800.00
27A435	2017-07-09 11:37:00+03	28700.00
27A454	2017-08-05 16:17:00+03	36400.00
27A4DE	2017-08-05 11:18:00+03	11600.00
27A525	2017-07-10 15:23:00+03	14800.00
27A53B	2017-08-06 12:48:00+03	139400.00
27A555	2017-07-27 00:05:00+03	25000.00
27A5B7	2017-08-14 09:38:00+03	132800.00
27A5F8	2017-07-08 06:27:00+03	61500.00
27A604	2017-07-05 19:41:00+03	173200.00
27A638	2017-07-17 20:59:00+03	191000.00
27A65F	2017-08-09 23:42:00+03	76400.00
27A66A	2017-08-10 13:52:00+03	65900.00
27A66D	2017-08-08 08:50:00+03	91700.00
27A68C	2017-08-13 02:39:00+03	184300.00
27A722	2017-07-28 04:16:00+03	35600.00
27A739	2017-08-01 22:55:00+03	198800.00
27A76B	2017-08-02 14:55:00+03	86800.00
27A795	2017-07-08 01:20:00+03	27200.00
27A7B8	2017-07-27 11:52:00+03	145200.00
27A7D4	2017-07-26 20:06:00+03	26800.00
27A828	2017-07-21 07:43:00+03	178300.00
27A854	2017-07-31 06:01:00+03	22400.00
27A89E	2017-08-14 11:21:00+03	72200.00
27A90D	2017-08-12 04:41:00+03	136800.00
27A920	2017-07-02 00:43:00+03	23400.00
27A937	2017-07-28 08:31:00+03	24400.00
27A98A	2017-07-04 23:44:00+03	6000.00
27A9D9	2017-07-25 00:47:00+03	92400.00
27AA0C	2017-08-12 09:32:00+03	21400.00
27AA1E	2017-07-05 12:48:00+03	92700.00
27AA2E	2017-07-16 03:56:00+03	76600.00
27AA55	2017-07-29 00:55:00+03	56900.00
27AA5E	2017-08-03 17:32:00+03	26700.00
27AA87	2017-07-16 07:01:00+03	67200.00
27AA8F	2017-08-08 23:58:00+03	43000.00
27AA9F	2017-07-19 22:50:00+03	197700.00
27AAFC	2017-07-11 22:37:00+03	28000.00
27AB2D	2017-08-01 06:46:00+03	24400.00
27AB93	2017-07-16 15:24:00+03	28800.00
27AC0B	2017-07-30 04:07:00+03	53300.00
27ACB8	2017-07-09 22:27:00+03	56600.00
27ACC9	2017-08-15 14:03:00+03	29600.00
27ACD3	2017-07-12 12:29:00+03	51300.00
27AD03	2017-07-28 19:07:00+03	39200.00
27AD36	2017-07-10 08:38:00+03	61800.00
27AE54	2017-07-19 23:52:00+03	138000.00
27AE83	2017-07-16 23:31:00+03	144400.00
27AEB2	2017-07-26 08:06:00+03	51600.00
27AEB6	2017-08-08 19:47:00+03	34400.00
27AEB9	2017-07-31 04:54:00+03	112000.00
27AEEC	2017-07-12 04:09:00+03	26000.00
27AEF9	2017-07-23 19:56:00+03	330200.00
27AF0D	2017-08-15 09:46:00+03	13400.00
27AF1C	2017-07-29 03:21:00+03	42700.00
27AF73	2017-07-06 16:10:00+03	11000.00
27AFAF	2017-06-29 03:15:00+03	187600.00
27AFEC	2017-07-18 15:25:00+03	199700.00
27B046	2017-08-14 15:54:00+03	23600.00
27B07B	2017-07-26 07:41:00+03	56900.00
27B0A7	2017-07-03 04:35:00+03	46400.00
27B0B8	2017-07-14 11:03:00+03	135400.00
27B0C1	2017-07-17 22:38:00+03	38800.00
27B0EB	2017-08-13 10:40:00+03	147700.00
27B1C0	2017-07-13 14:56:00+03	22000.00
27B1CE	2017-07-18 01:28:00+03	100600.00
27B21B	2017-07-17 19:23:00+03	59300.00
27B2A4	2017-08-09 16:53:00+03	24400.00
27B31C	2017-07-23 00:24:00+03	57300.00
27B32E	2017-07-07 20:25:00+03	16400.00
27B3BF	2017-07-23 06:53:00+03	72300.00
27B3D2	2017-08-04 15:59:00+03	286100.00
27B411	2017-08-15 06:11:00+03	75300.00
27B422	2017-08-09 13:20:00+03	25000.00
27B435	2017-07-06 13:08:00+03	60300.00
27B448	2017-06-29 23:27:00+03	44600.00
27B44D	2017-07-13 09:07:00+03	27200.00
27B492	2017-07-06 18:56:00+03	48200.00
27B589	2017-07-16 06:42:00+03	202000.00
27B591	2017-07-25 07:43:00+03	241300.00
27B612	2017-07-03 12:28:00+03	55800.00
27B616	2017-08-03 08:27:00+03	60800.00
27B62F	2017-08-10 22:05:00+03	36200.00
27B65E	2017-07-06 18:28:00+03	68700.00
27B670	2017-06-26 09:19:00+03	44700.00
27B673	2017-07-25 19:59:00+03	303100.00
27B6AB	2017-08-06 00:33:00+03	84500.00
27B6D8	2017-08-15 16:54:00+03	128800.00
27B762	2017-08-11 04:35:00+03	45100.00
27B881	2017-07-21 10:47:00+03	75600.00
27B8CC	2017-07-13 03:26:00+03	116100.00
27B928	2017-08-14 16:21:00+03	40400.00
27B943	2017-07-11 16:51:00+03	48500.00
27B957	2017-07-13 11:25:00+03	54800.00
27B975	2017-07-12 20:29:00+03	23600.00
27B98D	2017-07-25 19:12:00+03	81700.00
27BAB0	2017-07-10 13:11:00+03	135600.00
27BB3D	2017-08-09 20:07:00+03	147200.00
27BB44	2017-08-10 10:41:00+03	47500.00
27BBEA	2017-08-13 01:14:00+03	266400.00
27BC4D	2017-07-15 05:11:00+03	58400.00
27BCA0	2017-07-13 17:22:00+03	16800.00
27BCE0	2017-07-18 06:50:00+03	70700.00
27BCE5	2017-08-05 11:05:00+03	151200.00
27BD01	2017-08-02 14:13:00+03	131100.00
27BD18	2017-07-18 11:35:00+03	40800.00
27BD25	2017-07-18 22:39:00+03	28600.00
27BD29	2017-08-10 20:24:00+03	36200.00
27BD48	2017-07-01 22:34:00+03	23600.00
27BD56	2017-08-10 12:43:00+03	93700.00
27BD5E	2017-08-07 23:42:00+03	54300.00
27BDCF	2017-06-30 08:48:00+03	40200.00
27BE93	2017-07-18 23:04:00+03	89200.00
27BF1C	2017-07-23 13:00:00+03	236000.00
27BF77	2017-08-04 15:17:00+03	50700.00
27BFE4	2017-07-14 17:50:00+03	69600.00
27BFF9	2017-08-12 21:16:00+03	70800.00
27C068	2017-08-07 07:57:00+03	26000.00
27C0DB	2017-07-12 22:28:00+03	49600.00
27C100	2017-07-12 15:11:00+03	28800.00
27C129	2017-08-15 02:24:00+03	33000.00
27C13C	2017-08-13 03:09:00+03	19800.00
27C17C	2017-07-04 14:55:00+03	73300.00
27C1F4	2017-07-12 05:02:00+03	27400.00
27C219	2017-07-16 17:34:00+03	194000.00
27C23C	2017-07-29 11:08:00+03	20000.00
27C256	2017-07-23 16:07:00+03	10600.00
27C257	2017-07-15 17:11:00+03	43200.00
27C269	2017-07-18 00:55:00+03	56000.00
27C2F0	2017-08-02 01:48:00+03	44700.00
27C320	2017-08-01 02:19:00+03	46400.00
27C33A	2017-08-05 07:09:00+03	567600.00
27C36C	2017-07-11 19:20:00+03	55600.00
27C412	2017-08-07 09:18:00+03	6800.00
27C443	2017-08-03 14:32:00+03	14000.00
27C449	2017-08-01 10:08:00+03	26000.00
27C4CC	2017-08-01 18:46:00+03	68000.00
27C524	2017-08-09 10:09:00+03	57500.00
27C543	2017-08-09 20:50:00+03	298000.00
27C557	2017-08-08 04:10:00+03	62600.00
27C5CC	2017-07-25 21:16:00+03	40000.00
27C5E7	2017-08-12 07:49:00+03	133200.00
27C634	2017-07-06 19:24:00+03	26000.00
27C64D	2017-07-19 03:30:00+03	44700.00
27C6CF	2017-07-15 19:44:00+03	406000.00
27C733	2017-07-16 07:39:00+03	85000.00
27C7CB	2017-07-17 03:44:00+03	28000.00
27C7EF	2017-08-13 03:33:00+03	135400.00
27C7FA	2017-08-08 04:01:00+03	52000.00
27C907	2017-07-04 11:56:00+03	40300.00
27C970	2017-08-08 19:16:00+03	46400.00
27C9D2	2017-07-04 01:50:00+03	25500.00
27C9DA	2017-08-02 15:53:00+03	39600.00
27C9E7	2017-07-01 16:37:00+03	46000.00
27CA05	2017-07-06 23:41:00+03	46000.00
27CA4B	2017-07-21 07:00:00+03	98400.00
27CABE	2017-08-12 08:24:00+03	12600.00
27CACD	2017-08-07 02:47:00+03	39400.00
27CAEA	2017-07-26 16:36:00+03	77900.00
27CBDD	2017-07-13 20:59:00+03	246000.00
27CC34	2017-07-18 05:06:00+03	25000.00
27CC38	2017-07-16 12:14:00+03	264600.00
27CC72	2017-08-02 20:10:00+03	189800.00
27CCB8	2017-08-12 23:20:00+03	66600.00
27CCD9	2017-06-30 06:22:00+03	135400.00
27CCF6	2017-08-10 01:45:00+03	24400.00
27CD19	2017-07-30 14:23:00+03	12200.00
27CD1F	2017-08-06 23:39:00+03	38800.00
27CE1A	2017-08-09 06:20:00+03	112000.00
27CE6D	2017-07-27 04:17:00+03	39500.00
27CEEE	2017-07-26 17:45:00+03	10600.00
27CF2F	2017-08-09 02:14:00+03	258400.00
27CF49	2017-08-08 23:55:00+03	65200.00
27CF64	2017-07-20 17:28:00+03	92900.00
27CFA3	2017-08-09 14:01:00+03	252700.00
27CFF2	2017-06-30 11:21:00+03	38800.00
27D05B	2017-07-15 15:22:00+03	29200.00
27D0D6	2017-07-29 23:40:00+03	36000.00
27D10B	2017-07-01 17:05:00+03	29600.00
27D13E	2017-07-31 09:11:00+03	176800.00
27D156	2017-06-30 15:47:00+03	57600.00
27D15B	2017-07-28 02:30:00+03	38400.00
27D16F	2017-07-07 00:18:00+03	35600.00
27D17E	2017-08-08 08:13:00+03	36900.00
27D1A1	2017-07-25 16:31:00+03	27400.00
27D1C1	2017-08-10 13:08:00+03	192700.00
27D1F2	2017-08-10 19:19:00+03	98400.00
27D208	2017-08-08 21:06:00+03	21400.00
27D212	2017-07-28 19:59:00+03	119700.00
27D222	2017-08-01 03:39:00+03	529100.00
27D253	2017-07-03 05:00:00+03	102100.00
27D25C	2017-08-01 09:10:00+03	174400.00
27D29F	2017-08-09 19:25:00+03	70600.00
27D2F9	2017-07-05 13:45:00+03	16800.00
27D33C	2017-07-11 00:53:00+03	65500.00
27D402	2017-07-04 17:12:00+03	112000.00
27D41F	2017-07-17 12:09:00+03	18600.00
27D432	2017-07-04 09:42:00+03	73500.00
27D43F	2017-08-09 22:51:00+03	37200.00
27D488	2017-08-07 10:32:00+03	74300.00
27D4BB	2017-07-04 05:14:00+03	31600.00
27D4CE	2017-07-10 16:24:00+03	82400.00
27D522	2017-07-04 22:37:00+03	257500.00
27D5F2	2017-08-03 15:09:00+03	56600.00
27D607	2017-07-09 19:06:00+03	68000.00
27D656	2017-07-14 02:59:00+03	25600.00
27D6E2	2017-08-04 08:28:00+03	89700.00
27D766	2017-07-11 15:21:00+03	106100.00
27D79E	2017-07-12 13:07:00+03	222000.00
27D7AF	2017-07-16 12:10:00+03	6300.00
27D7C7	2017-07-04 08:06:00+03	156300.00
27D7DF	2017-08-04 01:26:00+03	278400.00
27D80C	2017-07-03 23:52:00+03	189700.00
27D83B	2017-07-28 05:31:00+03	20200.00
27D9B1	2017-06-30 10:48:00+03	7400.00
27D9B7	2017-08-09 14:39:00+03	273000.00
27DAE0	2017-06-27 16:42:00+03	24400.00
27DB3F	2017-08-07 03:36:00+03	63200.00
27DBF7	2017-07-03 18:40:00+03	83200.00
27DBF8	2017-06-29 20:11:00+03	47200.00
27DC01	2017-07-10 17:05:00+03	46700.00
27DC0A	2017-07-11 20:34:00+03	18500.00
27DC57	2017-07-12 17:35:00+03	84500.00
27DCA8	2017-07-30 17:52:00+03	13400.00
27DCAB	2017-07-21 13:19:00+03	248300.00
27DCE0	2017-07-02 07:27:00+03	257600.00
27DCE2	2017-07-16 23:34:00+03	38800.00
27DD0F	2017-07-31 02:42:00+03	22400.00
27DD1C	2017-08-08 13:08:00+03	94000.00
27DD6E	2017-07-25 08:23:00+03	102100.00
27DD87	2017-08-13 01:50:00+03	36200.00
27DDD0	2017-08-05 03:17:00+03	61500.00
27DDF6	2017-07-03 03:24:00+03	157200.00
27DE02	2017-08-13 00:49:00+03	369000.00
27DE43	2017-07-19 01:52:00+03	47700.00
27DE46	2017-08-07 06:19:00+03	28800.00
27DE47	2017-07-16 14:07:00+03	165000.00
27DE7B	2017-07-25 23:25:00+03	70700.00
27DEB0	2017-07-04 21:32:00+03	29800.00
27DEE5	2017-07-30 23:38:00+03	42600.00
27DEF0	2017-07-15 01:31:00+03	98200.00
27DF20	2017-07-08 22:03:00+03	12400.00
27DF3D	2017-08-05 07:15:00+03	14000.00
27DF55	2017-07-25 16:26:00+03	86300.00
27DF80	2017-08-14 12:24:00+03	77900.00
27DF81	2017-07-13 15:26:00+03	29600.00
27DFA3	2017-07-15 01:40:00+03	31400.00
27DFE5	2017-08-04 20:38:00+03	28000.00
27E05E	2017-07-31 03:44:00+03	55800.00
27E08C	2017-07-20 10:48:00+03	170500.00
27E0A3	2017-08-09 13:59:00+03	23100.00
27E0D1	2017-07-22 19:10:00+03	71900.00
27E0D4	2017-08-08 19:35:00+03	31000.00
27E153	2017-07-09 01:24:00+03	182300.00
27E172	2017-07-22 06:33:00+03	58200.00
27E198	2017-07-25 18:17:00+03	18300.00
27E1A2	2017-07-30 20:55:00+03	107300.00
27E28C	2017-08-02 01:44:00+03	37100.00
27E316	2017-08-08 03:02:00+03	40400.00
27E341	2017-07-21 21:43:00+03	44000.00
27E371	2017-08-05 22:44:00+03	28000.00
27E375	2017-07-01 07:40:00+03	77200.00
27E39E	2017-07-26 09:11:00+03	111600.00
27E47F	2017-08-06 00:19:00+03	16000.00
27E488	2017-07-11 08:25:00+03	20200.00
27E525	2017-07-25 00:27:00+03	12600.00
27E57F	2017-08-13 16:09:00+03	141600.00
27E593	2017-07-18 01:29:00+03	241300.00
27E63B	2017-08-07 18:35:00+03	93900.00
27E64D	2017-08-02 09:00:00+03	13200.00
27E686	2017-07-19 07:21:00+03	56000.00
27E6C5	2017-08-12 01:25:00+03	28000.00
27E713	2017-08-08 15:08:00+03	219700.00
27E784	2017-07-24 21:57:00+03	68100.00
27E799	2017-08-02 17:59:00+03	135400.00
27E7D4	2017-07-27 14:21:00+03	132800.00
27E835	2017-07-03 12:20:00+03	40800.00
27E83D	2017-07-09 09:41:00+03	28300.00
27E841	2017-07-03 12:49:00+03	24400.00
27E876	2017-07-29 19:02:00+03	10100.00
27E8D9	2017-08-02 16:12:00+03	28800.00
27E9CD	2017-08-12 20:35:00+03	56900.00
27EA54	2017-08-11 13:23:00+03	62900.00
27EA62	2017-08-11 23:00:00+03	55800.00
27EA74	2017-07-22 19:14:00+03	43100.00
27EA83	2017-07-08 07:21:00+03	46200.00
27EADD	2017-08-13 13:01:00+03	51300.00
27EB28	2017-08-09 09:30:00+03	92000.00
27EB6D	2017-07-06 19:16:00+03	69900.00
27EB85	2017-07-12 14:42:00+03	146300.00
27EBBF	2017-07-14 07:36:00+03	26500.00
27EC3C	2017-07-09 05:55:00+03	39300.00
27EC49	2017-07-17 17:19:00+03	28000.00
27EC4A	2017-08-02 15:08:00+03	14000.00
27EC54	2017-07-03 16:01:00+03	39400.00
27ECD6	2017-08-07 02:36:00+03	47500.00
27ED50	2017-07-03 17:53:00+03	15200.00
27ED54	2017-07-01 07:43:00+03	278300.00
27ED59	2017-08-14 05:48:00+03	57400.00
27ED6D	2017-07-13 19:18:00+03	392200.00
27EE00	2017-07-20 20:04:00+03	59800.00
27EF2C	2017-07-04 15:35:00+03	28000.00
27EF2D	2017-07-24 16:54:00+03	25200.00
27EF35	2017-08-04 14:29:00+03	111600.00
27EF8B	2017-07-27 04:57:00+03	106200.00
27F012	2017-08-06 01:57:00+03	37600.00
27F015	2017-07-11 13:01:00+03	14000.00
27F06E	2017-08-12 18:56:00+03	88900.00
27F0C4	2017-08-05 09:27:00+03	63700.00
27F0EE	2017-08-13 07:41:00+03	73300.00
27F159	2017-08-08 05:39:00+03	177200.00
27F15C	2017-07-24 19:19:00+03	38300.00
27F18F	2017-07-14 00:37:00+03	50600.00
27F1C1	2017-07-26 14:13:00+03	461700.00
27F1D3	2017-07-07 15:25:00+03	82900.00
27F1F4	2017-08-13 10:02:00+03	37200.00
27F1F6	2017-06-30 07:49:00+03	28000.00
27F200	2017-07-10 07:27:00+03	10800.00
27F201	2017-08-05 18:38:00+03	12600.00
27F269	2017-06-30 11:22:00+03	21400.00
27F2A4	2017-07-26 16:39:00+03	185600.00
27F2F6	2017-07-03 20:27:00+03	33200.00
27F3B5	2017-07-16 06:50:00+03	20200.00
27F3F3	2017-08-12 02:59:00+03	54500.00
27F40B	2017-07-26 03:17:00+03	73800.00
27F45F	2017-07-18 18:12:00+03	167400.00
27F460	2017-07-12 17:13:00+03	176600.00
27F475	2017-08-08 05:47:00+03	60600.00
27F4B8	2017-07-11 22:59:00+03	19600.00
27F4CB	2017-08-13 02:14:00+03	45100.00
27F513	2017-08-13 14:17:00+03	57400.00
27F55D	2017-07-07 19:31:00+03	103200.00
27F597	2017-07-30 21:59:00+03	133200.00
27F5C5	2017-07-19 14:52:00+03	105700.00
27F5F7	2017-07-26 16:42:00+03	6700.00
27F611	2017-06-29 21:30:00+03	198400.00
27F66D	2017-07-19 16:12:00+03	29600.00
27F6D0	2017-07-06 19:50:00+03	35600.00
27F7BC	2017-07-09 09:28:00+03	81700.00
27F7C1	2017-07-22 10:59:00+03	59000.00
27F7DE	2017-07-25 01:41:00+03	62400.00
27F7EB	2017-08-03 01:28:00+03	27200.00
27F836	2017-08-06 13:38:00+03	109200.00
27F893	2017-07-09 04:39:00+03	82700.00
27F903	2017-08-07 16:37:00+03	24800.00
27F926	2017-07-11 14:19:00+03	103100.00
27F935	2017-07-02 03:39:00+03	56000.00
27F971	2017-07-11 03:30:00+03	50800.00
27F9F1	2017-07-23 14:03:00+03	64600.00
27F9FB	2017-07-04 02:24:00+03	32800.00
27FA07	2017-08-11 09:41:00+03	43600.00
27FA3A	2017-08-06 19:07:00+03	28700.00
27FA60	2017-08-12 14:37:00+03	142400.00
27FAD8	2017-08-11 20:36:00+03	224000.00
27FB33	2017-08-06 12:24:00+03	53300.00
27FB42	2017-07-30 05:58:00+03	91500.00
27FB96	2017-07-10 21:25:00+03	398500.00
27FBE2	2017-07-07 03:41:00+03	116900.00
27FC1B	2017-07-07 19:03:00+03	150600.00
27FC47	2017-08-03 06:12:00+03	111600.00
27FC51	2017-07-18 11:46:00+03	26800.00
27FCC3	2017-08-12 11:58:00+03	43900.00
27FCD4	2017-08-09 13:02:00+03	15800.00
27FD0E	2017-07-16 14:09:00+03	32800.00
27FD0F	2017-07-11 08:13:00+03	59800.00
27FD3E	2017-07-14 11:43:00+03	26700.00
27FD5F	2017-07-13 09:24:00+03	173500.00
27FD6D	2017-08-08 00:34:00+03	58700.00
27FDD7	2017-08-03 01:59:00+03	46000.00
27FEF8	2017-08-09 16:39:00+03	6800.00
27FFB3	2017-08-04 08:31:00+03	47000.00
27FFE4	2017-08-03 12:03:00+03	48900.00
27FFF5	2017-07-27 13:18:00+03	81300.00
27FFF8	2017-06-27 15:56:00+03	58400.00
28003B	2017-08-01 08:58:00+03	40400.00
280059	2017-07-07 09:16:00+03	66600.00
2800B5	2017-08-14 22:36:00+03	156300.00
280159	2017-07-17 17:45:00+03	37200.00
280178	2017-07-18 18:01:00+03	14400.00
2802EB	2017-08-11 03:38:00+03	142400.00
28031E	2017-08-06 14:53:00+03	12600.00
28036D	2017-08-14 14:52:00+03	26700.00
2803B1	2017-08-14 07:47:00+03	171400.00
2803B8	2017-07-05 16:33:00+03	248300.00
2803EA	2017-07-16 05:56:00+03	31600.00
280463	2017-08-06 02:10:00+03	45000.00
2804CD	2017-07-21 18:38:00+03	59000.00
2804E8	2017-07-07 02:16:00+03	91600.00
2804F0	2017-07-07 09:00:00+03	129200.00
280503	2017-07-14 09:06:00+03	38000.00
280504	2017-07-28 11:42:00+03	248300.00
280524	2017-07-13 14:31:00+03	185600.00
28056A	2017-08-09 14:45:00+03	36200.00
28056F	2017-07-03 00:52:00+03	52000.00
2805BD	2017-08-09 07:15:00+03	56000.00
2805E1	2017-08-14 15:08:00+03	73500.00
2806E5	2017-07-28 02:41:00+03	265600.00
28074D	2017-07-17 14:05:00+03	37700.00
280784	2017-07-19 19:40:00+03	99000.00
28079E	2017-08-05 19:53:00+03	26700.00
2807B8	2017-08-09 12:22:00+03	50000.00
2807C2	2017-07-22 12:15:00+03	59800.00
280813	2017-07-22 21:21:00+03	92800.00
280847	2017-07-31 15:51:00+03	36200.00
2808E0	2017-07-11 13:16:00+03	46400.00
28093C	2017-07-20 16:40:00+03	42800.00
28095A	2017-08-01 22:18:00+03	133100.00
28096E	2017-07-26 11:08:00+03	39500.00
280979	2017-07-29 17:51:00+03	64400.00
2809DE	2017-07-11 19:03:00+03	69400.00
2809E3	2017-07-12 05:10:00+03	22600.00
280A21	2017-07-10 23:39:00+03	18000.00
280B18	2017-08-01 15:45:00+03	19600.00
280B23	2017-07-26 20:41:00+03	28000.00
280B2F	2017-07-10 20:44:00+03	36200.00
280B32	2017-07-15 14:29:00+03	177200.00
280BD1	2017-07-25 04:25:00+03	64300.00
280BD9	2017-07-23 06:26:00+03	375200.00
280C1E	2017-08-03 10:38:00+03	54800.00
280C80	2017-06-30 15:33:00+03	13000.00
280C88	2017-07-06 20:57:00+03	28600.00
280CDB	2017-08-13 19:27:00+03	26400.00
280D19	2017-07-06 01:41:00+03	12000.00
280D39	2017-07-13 18:36:00+03	144300.00
280D81	2017-07-08 03:05:00+03	29600.00
280D9E	2017-07-10 00:24:00+03	66600.00
280DB6	2017-07-03 17:08:00+03	664200.00
280E0D	2017-07-20 16:32:00+03	13400.00
280E19	2017-07-16 23:32:00+03	7400.00
280E50	2017-07-09 07:09:00+03	20000.00
280E6B	2017-08-14 19:54:00+03	13400.00
280EFC	2017-07-05 10:09:00+03	37200.00
280F25	2017-07-20 11:12:00+03	46400.00
280F57	2017-07-04 15:55:00+03	46200.00
280FD3	2017-08-05 21:40:00+03	232800.00
281022	2017-07-14 19:00:00+03	16400.00
281047	2017-07-13 04:50:00+03	58000.00
28105B	2017-07-05 16:11:00+03	73500.00
281083	2017-07-05 11:32:00+03	312900.00
28119D	2017-07-07 16:05:00+03	69500.00
281270	2017-07-12 23:50:00+03	13200.00
28134C	2017-07-10 10:58:00+03	6000.00
281397	2017-08-12 18:43:00+03	32400.00
2813F0	2017-08-11 18:33:00+03	159500.00
281434	2017-08-02 23:59:00+03	84500.00
281444	2017-07-13 07:04:00+03	130200.00
28144C	2017-07-20 08:07:00+03	52000.00
2814D9	2017-08-12 18:36:00+03	37600.00
281564	2017-07-26 04:32:00+03	44900.00
2815E4	2017-07-15 21:33:00+03	81800.00
2815E9	2017-08-15 16:59:00+03	104300.00
28161C	2017-07-11 23:37:00+03	32900.00
281638	2017-07-09 17:06:00+03	6600.00
2816A5	2017-07-22 11:32:00+03	105100.00
2816B9	2017-07-31 21:42:00+03	135400.00
28170B	2017-07-03 00:47:00+03	92900.00
281756	2017-07-18 23:05:00+03	59800.00
281798	2017-07-11 01:56:00+03	47400.00
2817DE	2017-07-15 19:14:00+03	84500.00
2817E9	2017-07-06 16:47:00+03	75700.00
28183A	2017-07-25 01:57:00+03	412900.00
281859	2017-08-14 05:45:00+03	98700.00
281874	2017-07-30 21:35:00+03	46200.00
2819BD	2017-08-01 10:56:00+03	28600.00
2819CE	2017-07-07 03:25:00+03	56000.00
281A3F	2017-08-09 21:33:00+03	80000.00
281A7A	2017-07-28 19:49:00+03	36200.00
281AFD	2017-07-29 13:52:00+03	36400.00
281B12	2017-08-11 22:40:00+03	28800.00
281B1E	2017-08-06 03:18:00+03	51900.00
281B2F	2017-07-28 21:47:00+03	27800.00
281B93	2017-07-26 03:35:00+03	6000.00
281BB8	2017-07-22 23:54:00+03	26000.00
281BBD	2017-08-14 00:58:00+03	25100.00
281BD1	2017-07-11 00:12:00+03	101500.00
281BF1	2017-07-15 16:49:00+03	46400.00
281C2D	2017-07-14 10:50:00+03	135400.00
281C57	2017-08-03 17:04:00+03	25000.00
281C73	2017-08-02 08:30:00+03	56000.00
281C86	2017-08-08 04:38:00+03	63700.00
281CDB	2017-07-20 15:08:00+03	6000.00
281D74	2017-07-07 14:00:00+03	21200.00
281DAC	2017-08-15 14:12:00+03	240600.00
281DE3	2017-07-30 20:40:00+03	66600.00
281E38	2017-07-23 07:36:00+03	23200.00
281E3E	2017-07-29 18:21:00+03	136600.00
281E9F	2017-07-08 01:23:00+03	369000.00
281EA4	2017-07-22 16:00:00+03	57300.00
281EB8	2017-07-18 17:53:00+03	89700.00
281EE0	2017-07-30 22:36:00+03	55800.00
281F73	2017-07-07 15:48:00+03	12400.00
281F76	2017-07-26 00:56:00+03	199700.00
281F92	2017-08-03 00:45:00+03	16400.00
281FA8	2017-07-03 15:24:00+03	44100.00
281FC7	2017-07-28 02:20:00+03	61800.00
281FC9	2017-07-07 22:19:00+03	111600.00
281FCA	2017-07-21 17:08:00+03	133200.00
281FE1	2017-07-30 15:18:00+03	261500.00
282004	2017-07-14 02:58:00+03	50100.00
282068	2017-07-16 10:08:00+03	28800.00
282094	2017-07-24 07:29:00+03	23600.00
2820B7	2017-08-08 05:54:00+03	23200.00
2820D5	2017-08-11 15:07:00+03	199700.00
2820D9	2017-07-04 11:22:00+03	26000.00
2820E8	2017-08-14 08:36:00+03	68400.00
28217C	2017-07-01 10:59:00+03	49800.00
28218D	2017-07-21 23:54:00+03	26800.00
282204	2017-08-08 00:01:00+03	44500.00
28220A	2017-07-12 08:12:00+03	68400.00
2822AB	2017-08-11 11:53:00+03	52900.00
2822BF	2017-07-17 03:10:00+03	28000.00
28237D	2017-07-31 07:32:00+03	85000.00
282396	2017-07-26 08:30:00+03	294000.00
282446	2017-07-09 14:27:00+03	68800.00
2824EA	2017-08-10 05:18:00+03	369000.00
2825BC	2017-07-18 21:57:00+03	223700.00
282679	2017-07-05 11:59:00+03	206400.00
282697	2017-07-04 19:49:00+03	40000.00
282713	2017-07-29 04:02:00+03	32400.00
28272D	2017-07-27 15:25:00+03	210200.00
2827A0	2017-08-06 07:07:00+03	186100.00
2827B1	2017-07-12 23:37:00+03	103600.00
28280A	2017-08-08 17:34:00+03	76100.00
28284B	2017-08-03 17:48:00+03	36200.00
28287A	2017-07-24 06:59:00+03	32700.00
2828F9	2017-07-12 10:09:00+03	99900.00
282912	2017-07-21 14:29:00+03	42200.00
282917	2017-08-15 00:46:00+03	67200.00
282988	2017-08-01 09:08:00+03	28800.00
2829B6	2017-07-06 16:26:00+03	42700.00
282A46	2017-07-27 20:06:00+03	95200.00
282AA4	2017-08-12 21:24:00+03	76600.00
282AAD	2017-07-12 08:25:00+03	6700.00
282ADE	2017-08-10 23:09:00+03	61800.00
282B06	2017-08-12 01:49:00+03	31600.00
282B3D	2017-07-22 19:17:00+03	93400.00
282B8E	2017-07-21 19:35:00+03	102500.00
282BA0	2017-07-25 23:59:00+03	26800.00
282BD4	2017-07-17 03:00:00+03	59200.00
282BDA	2017-07-29 14:13:00+03	191000.00
282C63	2017-08-12 19:41:00+03	15700.00
282C9E	2017-07-09 04:14:00+03	134400.00
282CB5	2017-08-07 20:27:00+03	60600.00
282CD8	2017-07-25 09:00:00+03	28000.00
282CEF	2017-07-08 20:10:00+03	132800.00
282D30	2017-08-11 10:25:00+03	48200.00
282DAB	2017-07-28 04:15:00+03	138900.00
282EA4	2017-07-03 22:35:00+03	133100.00
282EA7	2017-07-11 20:16:00+03	27400.00
282EB2	2017-07-08 17:10:00+03	14400.00
282F4C	2017-07-30 23:56:00+03	56000.00
282F7B	2017-07-22 05:08:00+03	73300.00
282F96	2017-08-05 19:06:00+03	27200.00
282FA6	2017-06-29 17:04:00+03	26000.00
282FC4	2017-07-25 23:08:00+03	21800.00
283006	2017-08-08 20:11:00+03	30200.00
28301F	2017-06-25 04:37:00+03	31400.00
283077	2017-07-30 22:36:00+03	135600.00
2830C1	2017-07-20 02:43:00+03	28800.00
2830D2	2017-07-19 13:46:00+03	135400.00
2830FB	2017-07-21 09:11:00+03	31000.00
283100	2017-07-20 07:37:00+03	56000.00
2831FC	2017-07-28 05:29:00+03	38200.00
283235	2017-07-27 01:17:00+03	11600.00
28328C	2017-07-09 01:56:00+03	6300.00
2832DE	2017-07-04 16:36:00+03	124200.00
28336A	2017-07-21 00:21:00+03	134400.00
283375	2017-07-09 09:26:00+03	14000.00
2833A2	2017-07-20 13:08:00+03	51500.00
2833A4	2017-07-21 06:55:00+03	139800.00
2833D9	2017-08-04 05:11:00+03	84100.00
283407	2017-07-27 18:53:00+03	28000.00
283451	2017-07-28 07:17:00+03	23200.00
28348E	2017-08-03 13:54:00+03	149600.00
28351F	2017-07-22 09:48:00+03	66100.00
28352D	2017-08-12 09:12:00+03	47800.00
283545	2017-08-05 21:17:00+03	58600.00
283552	2017-08-04 04:15:00+03	143100.00
283563	2017-08-01 07:18:00+03	136400.00
28358A	2017-07-09 00:15:00+03	40000.00
283598	2017-07-05 14:04:00+03	441500.00
2835AA	2017-08-11 15:46:00+03	89700.00
2835D9	2017-07-29 05:21:00+03	26000.00
283642	2017-07-05 07:37:00+03	79900.00
283655	2017-08-14 14:07:00+03	177500.00
2837E2	2017-08-04 19:06:00+03	201200.00
28381B	2017-07-10 22:29:00+03	70600.00
28383E	2017-07-19 00:12:00+03	93900.00
283846	2017-08-07 10:18:00+03	103100.00
28384D	2017-08-09 05:52:00+03	19600.00
28386C	2017-07-02 04:01:00+03	136800.00
28386D	2017-07-28 01:17:00+03	88900.00
283885	2017-07-10 09:44:00+03	246000.00
2838E6	2017-07-02 02:08:00+03	498200.00
283915	2017-07-27 13:05:00+03	96800.00
2839A5	2017-07-11 05:26:00+03	35700.00
2839D1	2017-08-03 12:48:00+03	123000.00
283A36	2017-07-29 14:18:00+03	69700.00
283A58	2017-08-03 17:21:00+03	56600.00
283ABA	2017-07-24 20:34:00+03	47000.00
283B0C	2017-07-29 15:04:00+03	16400.00
283B1E	2017-08-15 10:35:00+03	82700.00
283B67	2017-08-03 23:18:00+03	189200.00
283BF2	2017-07-05 10:06:00+03	46300.00
283C6C	2017-07-04 16:25:00+03	199700.00
283C76	2017-08-07 19:31:00+03	6000.00
283D10	2017-08-09 13:58:00+03	96200.00
283D41	2017-07-23 10:31:00+03	258300.00
283D9F	2017-07-23 20:08:00+03	56600.00
283DFB	2017-08-14 13:53:00+03	28000.00
283E03	2017-07-16 23:49:00+03	10800.00
283E1A	2017-07-23 11:29:00+03	14400.00
283E43	2017-07-18 03:26:00+03	66600.00
283E77	2017-08-06 04:52:00+03	88000.00
283EEB	2017-08-07 18:55:00+03	10800.00
283F38	2017-07-18 08:43:00+03	28800.00
283F56	2017-07-31 06:16:00+03	84500.00
283FD5	2017-07-18 20:16:00+03	42700.00
283FE0	2017-08-15 06:28:00+03	124200.00
28401F	2017-07-10 02:14:00+03	122300.00
28405A	2017-07-06 06:18:00+03	99900.00
28405F	2017-08-08 01:51:00+03	59100.00
284087	2017-07-07 05:09:00+03	39100.00
2840DB	2017-08-06 08:16:00+03	57500.00
2840E0	2017-07-02 11:08:00+03	28800.00
2840F3	2017-08-13 11:53:00+03	46400.00
2840FA	2017-07-14 16:46:00+03	27300.00
284104	2017-07-05 04:35:00+03	8000.00
28410B	2017-08-10 05:16:00+03	28800.00
28410D	2017-08-03 10:30:00+03	113200.00
284116	2017-08-05 19:13:00+03	28000.00
284138	2017-08-15 11:50:00+03	31200.00
28416B	2017-07-22 23:24:00+03	67800.00
28419C	2017-07-24 20:44:00+03	54600.00
28419F	2017-07-11 19:50:00+03	83000.00
2842AF	2017-07-17 20:25:00+03	153200.00
2842FF	2017-08-03 02:54:00+03	22000.00
284303	2017-08-10 11:49:00+03	94500.00
28433B	2017-07-24 06:34:00+03	114400.00
2843AD	2017-07-31 17:47:00+03	71700.00
2843B6	2017-07-13 11:04:00+03	38800.00
2843C5	2017-07-21 08:48:00+03	4000.00
2844F9	2017-07-03 03:41:00+03	46400.00
284536	2017-08-08 23:23:00+03	36200.00
28458B	2017-07-04 03:15:00+03	92400.00
2845A4	2017-07-26 17:38:00+03	13400.00
2845D5	2017-08-12 07:21:00+03	59200.00
2845E7	2017-07-12 15:03:00+03	369000.00
2846A6	2017-07-25 03:20:00+03	173500.00
2846AD	2017-07-08 14:14:00+03	57500.00
284714	2017-07-08 17:49:00+03	168000.00
284785	2017-07-15 03:24:00+03	67000.00
284795	2017-07-17 08:41:00+03	58000.00
284797	2017-07-07 23:53:00+03	179000.00
2847A0	2017-07-28 01:30:00+03	27200.00
2847A3	2017-07-08 14:02:00+03	12600.00
2847B0	2017-07-15 08:53:00+03	24400.00
28489F	2017-07-12 22:19:00+03	52000.00
2848A1	2017-07-06 11:23:00+03	136800.00
2848E5	2017-07-19 00:10:00+03	46500.00
28499A	2017-07-26 10:57:00+03	31600.00
2849A2	2017-07-20 21:52:00+03	184200.00
2849BB	2017-07-08 12:50:00+03	66600.00
2849D0	2017-08-04 23:17:00+03	50400.00
284A0F	2017-07-07 16:23:00+03	133200.00
284A53	2017-08-01 07:41:00+03	89700.00
284A74	2017-07-13 09:45:00+03	88500.00
284A8F	2017-07-19 15:49:00+03	43200.00
284B15	2017-07-29 03:04:00+03	22000.00
284B2B	2017-08-11 06:15:00+03	31600.00
284B88	2017-07-08 00:37:00+03	51900.00
284C4B	2017-08-09 13:07:00+03	131800.00
284C53	2017-08-11 12:56:00+03	241300.00
284C68	2017-07-10 02:40:00+03	52700.00
284C97	2017-07-21 13:30:00+03	301800.00
284CDE	2017-07-19 02:25:00+03	156600.00
284D0B	2017-07-31 21:15:00+03	100000.00
284D2D	2017-08-07 16:36:00+03	335400.00
284D58	2017-08-02 10:05:00+03	174600.00
284D8A	2017-08-04 17:07:00+03	36200.00
284DA4	2017-08-14 20:41:00+03	25100.00
284DCE	2017-07-04 15:56:00+03	57700.00
284E8A	2017-07-31 17:53:00+03	55800.00
284E8F	2017-07-25 12:21:00+03	90800.00
284EA0	2017-07-07 16:35:00+03	73200.00
284EC9	2017-08-05 08:47:00+03	25200.00
284ED7	2017-07-02 01:36:00+03	91100.00
284F24	2017-08-03 01:18:00+03	67900.00
284F41	2017-07-09 18:58:00+03	69000.00
284F95	2017-07-05 22:09:00+03	94200.00
285046	2017-08-13 07:33:00+03	73300.00
28506D	2017-07-10 15:59:00+03	44700.00
2850B2	2017-07-29 22:31:00+03	85000.00
28514D	2017-07-29 03:41:00+03	70400.00
28519A	2017-07-13 05:15:00+03	28000.00
28523C	2017-07-04 17:32:00+03	94100.00
285247	2017-07-18 12:14:00+03	42400.00
28526C	2017-07-12 20:10:00+03	61400.00
285278	2017-07-28 11:41:00+03	20400.00
28529C	2017-07-05 17:02:00+03	186200.00
28529F	2017-07-28 09:24:00+03	118800.00
2852AB	2017-07-06 17:43:00+03	51900.00
2852B4	2017-08-02 02:24:00+03	62600.00
2852E6	2017-07-15 03:07:00+03	47600.00
2852F5	2017-07-16 03:29:00+03	36000.00
285387	2017-08-14 17:44:00+03	46400.00
285390	2017-07-22 17:04:00+03	56000.00
285467	2017-08-14 19:11:00+03	18300.00
285488	2017-08-02 11:06:00+03	44800.00
2854B2	2017-08-02 09:12:00+03	43200.00
2854BB	2017-07-26 18:39:00+03	20000.00
2854D7	2017-08-02 13:34:00+03	12600.00
285510	2017-07-15 03:24:00+03	111600.00
285555	2017-08-03 03:51:00+03	52900.00
285604	2017-07-27 08:55:00+03	32800.00
285672	2017-08-03 03:52:00+03	133200.00
285683	2017-07-31 19:05:00+03	43500.00
2856EC	2017-08-12 15:41:00+03	8200.00
285770	2017-08-09 00:46:00+03	65900.00
285771	2017-07-24 07:41:00+03	23200.00
2857CF	2017-07-07 18:26:00+03	28800.00
285809	2017-08-14 16:14:00+03	69500.00
285828	2017-08-02 07:23:00+03	6000.00
28587D	2017-07-04 01:34:00+03	6800.00
285893	2017-07-23 11:37:00+03	410800.00
2858DC	2017-07-02 19:43:00+03	41400.00
2858DE	2017-07-31 10:01:00+03	52700.00
2858FD	2017-07-25 08:18:00+03	12600.00
2859C4	2017-07-05 13:56:00+03	175500.00
2859EB	2017-08-15 00:00:00+03	59100.00
2859F5	2017-08-04 14:46:00+03	46300.00
2859FA	2017-07-13 00:31:00+03	76400.00
285A1A	2017-07-12 13:34:00+03	13800.00
285A42	2017-07-11 16:19:00+03	40000.00
285A44	2017-07-27 05:10:00+03	243600.00
285A64	2017-07-30 02:01:00+03	69500.00
285A9D	2017-07-15 03:34:00+03	32800.00
285AD9	2017-07-07 17:41:00+03	179400.00
285AED	2017-08-01 12:49:00+03	56600.00
285B09	2017-07-24 01:29:00+03	26700.00
285B55	2017-07-13 16:43:00+03	27800.00
285B62	2017-08-10 21:30:00+03	16400.00
285B7E	2017-07-02 01:50:00+03	89600.00
285BC5	2017-07-16 14:02:00+03	6200.00
285D40	2017-07-22 13:42:00+03	40800.00
285D60	2017-08-05 02:55:00+03	24400.00
285D64	2017-07-09 22:49:00+03	28300.00
285D9F	2017-08-04 14:47:00+03	48100.00
285DC7	2017-07-13 00:17:00+03	52000.00
285E25	2017-07-24 20:58:00+03	133700.00
285E54	2017-08-14 17:59:00+03	131600.00
285E8D	2017-07-10 09:44:00+03	71000.00
285F12	2017-07-16 15:19:00+03	125400.00
285F5F	2017-07-14 09:54:00+03	61800.00
285F64	2017-07-26 22:39:00+03	52100.00
285F6D	2017-08-10 19:36:00+03	68300.00
285F89	2017-08-09 01:43:00+03	37900.00
285FA9	2017-07-20 22:49:00+03	10800.00
285FEF	2017-07-09 18:50:00+03	53600.00
28601C	2017-08-07 13:06:00+03	48800.00
28604D	2017-07-16 02:02:00+03	82700.00
28608E	2017-07-11 15:09:00+03	112000.00
2860C8	2017-07-23 02:04:00+03	29300.00
28613A	2017-07-29 12:27:00+03	42400.00
286153	2017-08-09 01:18:00+03	61800.00
286185	2017-08-14 23:43:00+03	40800.00
2861B1	2017-08-11 03:48:00+03	16400.00
2862DC	2017-08-08 01:50:00+03	38500.00
28631E	2017-07-27 13:58:00+03	89600.00
28635E	2017-07-16 00:17:00+03	108500.00
286379	2017-07-13 19:56:00+03	49800.00
286385	2017-08-09 08:23:00+03	83000.00
28638C	2017-08-09 16:04:00+03	286600.00
286392	2017-07-30 03:50:00+03	55800.00
2863AE	2017-07-11 00:28:00+03	27800.00
2863BC	2017-08-08 08:50:00+03	81700.00
2863D4	2017-08-10 16:11:00+03	62000.00
2863EC	2017-08-04 00:24:00+03	111600.00
286428	2017-07-08 17:28:00+03	40800.00
286429	2017-07-17 14:11:00+03	137900.00
28642D	2017-07-05 09:34:00+03	23400.00
286479	2017-07-26 02:10:00+03	266400.00
2864B6	2017-07-09 17:33:00+03	35200.00
2864B7	2017-07-25 18:27:00+03	99200.00
2864DD	2017-07-10 17:44:00+03	133200.00
2864E3	2017-07-28 21:05:00+03	25600.00
2864E9	2017-07-05 22:57:00+03	56600.00
286518	2017-08-01 05:26:00+03	43200.00
286519	2017-07-15 13:27:00+03	39800.00
2865B4	2017-07-28 06:08:00+03	43500.00
2865B8	2017-07-08 22:29:00+03	14800.00
286670	2017-07-09 04:36:00+03	24400.00
286693	2017-07-22 02:31:00+03	50600.00
2866B5	2017-08-09 11:45:00+03	28800.00
2866D7	2017-07-05 19:48:00+03	68400.00
286717	2017-07-17 00:14:00+03	23600.00
28676C	2017-08-15 10:48:00+03	24400.00
286779	2017-07-31 10:20:00+03	132800.00
2867CC	2017-07-21 03:39:00+03	73600.00
2867DD	2017-06-30 06:55:00+03	38600.00
28683A	2017-08-13 02:17:00+03	50900.00
28686A	2017-08-14 12:07:00+03	89700.00
2868A8	2017-07-15 10:08:00+03	31400.00
286944	2017-08-11 18:17:00+03	159000.00
286949	2017-08-01 21:26:00+03	89100.00
2869B0	2017-08-13 11:20:00+03	43100.00
2869CF	2017-07-22 22:30:00+03	6300.00
286A21	2017-08-05 18:41:00+03	56000.00
286A3F	2017-07-13 01:16:00+03	146600.00
286A90	2017-08-05 19:18:00+03	24400.00
286AE7	2017-07-28 16:58:00+03	81300.00
286B4C	2017-08-10 01:19:00+03	369000.00
286B4E	2017-07-28 20:16:00+03	32800.00
286B89	2017-07-11 18:50:00+03	66000.00
286B92	2017-07-26 21:58:00+03	21800.00
286B9A	2017-06-28 04:15:00+03	135000.00
286BAA	2017-07-08 16:44:00+03	157100.00
286BC1	2017-08-13 21:44:00+03	42000.00
286BEC	2017-08-02 18:46:00+03	43600.00
286C9D	2017-08-11 17:17:00+03	67600.00
286CC8	2017-08-09 12:12:00+03	46400.00
286D36	2017-07-02 18:26:00+03	101200.00
286D92	2017-06-28 20:51:00+03	134400.00
286DB5	2017-08-09 02:02:00+03	386400.00
286E87	2017-08-10 07:32:00+03	176600.00
286ECC	2017-07-04 13:00:00+03	6300.00
286EEF	2017-08-13 16:55:00+03	113700.00
286EF2	2017-07-03 19:10:00+03	278400.00
286F26	2017-07-02 00:12:00+03	57500.00
286F49	2017-07-19 17:50:00+03	132700.00
286FA2	2017-08-11 08:02:00+03	24600.00
286FA9	2017-07-09 18:52:00+03	26700.00
286FC7	2017-07-25 21:31:00+03	278100.00
286FD8	2017-07-21 23:10:00+03	131100.00
28702B	2017-07-07 03:52:00+03	44000.00
2870B1	2017-08-05 08:47:00+03	150600.00
2870C5	2017-08-05 01:49:00+03	78300.00
2870CC	2017-07-17 15:48:00+03	102100.00
2870D1	2017-08-10 23:35:00+03	55800.00
287122	2017-07-14 03:25:00+03	59800.00
2871B3	2017-07-23 22:51:00+03	135400.00
287265	2017-07-11 11:09:00+03	22400.00
2872E1	2017-07-30 02:32:00+03	166100.00
287302	2017-07-17 15:02:00+03	40800.00
287320	2017-08-02 08:15:00+03	38600.00
287323	2017-07-24 06:30:00+03	84000.00
287333	2017-07-12 18:31:00+03	123000.00
28733F	2017-07-18 14:18:00+03	28800.00
287365	2017-07-02 06:27:00+03	65900.00
28736F	2017-07-25 00:49:00+03	65900.00
28738B	2017-07-12 15:42:00+03	51600.00
2873A1	2017-07-22 01:41:00+03	42600.00
2873A6	2017-07-30 23:22:00+03	44600.00
2873D6	2017-07-29 08:10:00+03	26000.00
2873EC	2017-08-14 19:19:00+03	134800.00
287487	2017-07-07 00:27:00+03	285000.00
28748D	2017-07-30 17:20:00+03	26800.00
287491	2017-06-30 00:24:00+03	73300.00
2874CC	2017-07-22 21:44:00+03	23600.00
28756C	2017-08-15 07:19:00+03	57500.00
287592	2017-08-07 03:15:00+03	28000.00
28759D	2017-08-04 04:35:00+03	43900.00
2875AD	2017-07-06 21:03:00+03	56000.00
2875B9	2017-07-26 03:11:00+03	65000.00
2875BE	2017-07-07 18:52:00+03	141600.00
2875BF	2017-07-13 18:54:00+03	59800.00
2875E0	2017-07-23 21:11:00+03	36800.00
287622	2017-07-10 22:35:00+03	106700.00
287655	2017-07-27 10:44:00+03	56000.00
287681	2017-07-17 01:18:00+03	87200.00
28768B	2017-08-04 18:59:00+03	56000.00
2876E3	2017-07-13 13:32:00+03	23200.00
287707	2017-08-06 10:14:00+03	66600.00
28772A	2017-07-16 22:56:00+03	81200.00
2877A2	2017-07-13 09:48:00+03	55800.00
2877E0	2017-07-25 21:26:00+03	160700.00
2877F2	2017-07-16 06:11:00+03	240600.00
28780D	2017-07-15 07:28:00+03	28000.00
287856	2017-07-05 17:59:00+03	271100.00
28793D	2017-07-05 07:23:00+03	91300.00
287972	2017-07-08 02:55:00+03	13600.00
287982	2017-08-11 05:11:00+03	136200.00
2879A3	2017-07-13 12:47:00+03	32800.00
2879D4	2017-07-17 06:18:00+03	135400.00
287A03	2017-07-25 03:44:00+03	136300.00
287A8A	2017-07-21 13:13:00+03	199200.00
287B87	2017-08-12 14:18:00+03	201200.00
287BC9	2017-07-25 00:41:00+03	28000.00
287C44	2017-07-20 19:18:00+03	74800.00
287C79	2017-07-03 17:14:00+03	60400.00
287CAD	2017-08-10 19:30:00+03	83200.00
287D00	2017-08-06 06:12:00+03	24700.00
287D1F	2017-08-14 15:19:00+03	27800.00
287D6E	2017-07-04 04:05:00+03	28800.00
287DB6	2017-07-30 04:18:00+03	6300.00
287DF7	2017-07-30 07:02:00+03	123000.00
287F21	2017-07-21 16:58:00+03	29600.00
287F3F	2017-07-12 17:02:00+03	6300.00
287F73	2017-08-10 11:25:00+03	281400.00
287F7F	2017-07-11 14:21:00+03	31400.00
287FB7	2017-06-30 17:17:00+03	47600.00
287FD2	2017-07-19 04:21:00+03	272400.00
288098	2017-07-14 22:34:00+03	372500.00
28809A	2017-08-11 17:43:00+03	133100.00
2880AD	2017-07-21 02:21:00+03	81900.00
2881B2	2017-07-15 08:11:00+03	46400.00
2881CE	2017-07-29 15:34:00+03	34000.00
288258	2017-07-02 00:53:00+03	23600.00
28826B	2017-07-31 12:38:00+03	33400.00
2883EA	2017-07-20 04:45:00+03	313400.00
2883F4	2017-07-13 21:46:00+03	67600.00
288476	2017-07-02 12:14:00+03	93600.00
2884D2	2017-07-19 00:28:00+03	24600.00
2884D9	2017-07-02 14:53:00+03	23200.00
288559	2017-06-29 21:11:00+03	312000.00
2885AC	2017-08-08 11:26:00+03	120800.00
288656	2017-07-26 10:09:00+03	25400.00
28866E	2017-08-11 15:26:00+03	18000.00
2886A1	2017-07-06 08:45:00+03	33400.00
2887EA	2017-08-07 12:29:00+03	61800.00
28880E	2017-08-08 04:11:00+03	109600.00
28885D	2017-07-11 16:20:00+03	22000.00
2888BA	2017-08-08 14:56:00+03	66600.00
288957	2017-08-07 01:21:00+03	48800.00
2889CC	2017-07-14 04:39:00+03	40100.00
2889E6	2017-07-11 12:52:00+03	13400.00
2889F5	2017-08-04 23:35:00+03	23200.00
288AC1	2017-07-10 22:28:00+03	29300.00
288ADF	2017-07-26 06:44:00+03	246000.00
288B22	2017-07-21 23:37:00+03	55800.00
288BC3	2017-07-02 16:38:00+03	283100.00
288BE0	2017-08-10 05:09:00+03	30200.00
288C21	2017-07-06 12:18:00+03	39800.00
288C6D	2017-08-09 09:34:00+03	281900.00
288C7F	2017-08-05 21:12:00+03	47000.00
288CB7	2017-08-13 21:59:00+03	89600.00
288D11	2017-07-19 21:24:00+03	15000.00
288D47	2017-08-15 04:44:00+03	48700.00
288D78	2017-07-26 11:44:00+03	14000.00
288DD5	2017-07-12 15:57:00+03	26800.00
288DEB	2017-07-17 06:51:00+03	179300.00
288E6D	2017-07-14 21:37:00+03	20000.00
288E9F	2017-07-16 03:08:00+03	38400.00
288EA3	2017-07-08 02:45:00+03	23600.00
288F25	2017-08-13 10:20:00+03	92700.00
288F44	2017-07-12 01:09:00+03	25100.00
288F6F	2017-08-10 01:32:00+03	86300.00
288F74	2017-08-05 14:09:00+03	31600.00
288F92	2017-07-29 21:10:00+03	94000.00
288FCF	2017-07-06 13:32:00+03	31400.00
28903B	2017-07-05 17:18:00+03	81600.00
2890F2	2017-07-07 03:04:00+03	92800.00
289176	2017-07-04 02:22:00+03	182300.00
289195	2017-08-08 04:29:00+03	24400.00
2891DA	2017-07-21 23:07:00+03	86500.00
2891FF	2017-07-15 15:26:00+03	199800.00
28927E	2017-07-09 00:00:00+03	100000.00
2892F6	2017-07-09 20:20:00+03	98400.00
2892FB	2017-07-18 18:53:00+03	67200.00
28931F	2017-07-15 12:29:00+03	249100.00
2893C8	2017-08-04 15:09:00+03	21400.00
289428	2017-08-05 10:36:00+03	194000.00
28942B	2017-07-26 08:47:00+03	13400.00
289513	2017-08-12 03:39:00+03	8000.00
28953A	2017-08-04 09:46:00+03	103800.00
289545	2017-08-11 13:21:00+03	266400.00
289562	2017-07-22 18:40:00+03	15000.00
289569	2017-07-26 00:11:00+03	24400.00
289637	2017-07-15 21:51:00+03	26000.00
289646	2017-07-05 08:42:00+03	21400.00
28965C	2017-07-14 20:38:00+03	81600.00
2896AA	2017-07-12 04:44:00+03	80300.00
2896C6	2017-07-26 13:58:00+03	270800.00
2896D7	2017-07-31 19:03:00+03	119500.00
2897B7	2017-07-11 11:43:00+03	56900.00
289834	2017-07-25 13:41:00+03	32200.00
289845	2017-07-24 20:03:00+03	156500.00
289895	2017-07-01 03:52:00+03	147000.00
2898A7	2017-07-17 06:39:00+03	12600.00
2898D3	2017-08-06 16:15:00+03	58100.00
2898FC	2017-07-30 02:59:00+03	109300.00
289952	2017-07-31 06:58:00+03	36000.00
289959	2017-07-20 07:09:00+03	139500.00
289966	2017-07-24 18:10:00+03	6300.00
289995	2017-07-23 06:57:00+03	23200.00
2899CD	2017-08-08 04:12:00+03	24400.00
289A50	2017-07-21 00:48:00+03	51200.00
289A59	2017-07-29 14:49:00+03	157200.00
289A8A	2017-07-26 21:02:00+03	87200.00
289AA1	2017-08-15 13:08:00+03	205500.00
289AA2	2017-08-15 08:17:00+03	70800.00
289AAC	2017-07-25 02:24:00+03	56000.00
289AD7	2017-07-30 08:14:00+03	28000.00
289AE5	2017-07-14 19:21:00+03	95200.00
289B05	2017-08-10 13:30:00+03	33100.00
289C0B	2017-08-11 23:34:00+03	73900.00
289C1E	2017-07-11 14:20:00+03	66000.00
289C67	2017-07-07 15:14:00+03	296600.00
289CAF	2017-07-19 08:11:00+03	53400.00
289D04	2017-08-05 15:43:00+03	156500.00
289E13	2017-07-30 17:20:00+03	16400.00
289E17	2017-08-05 17:06:00+03	393800.00
289E23	2017-08-12 21:54:00+03	85900.00
289F29	2017-07-05 13:56:00+03	81700.00
289F35	2017-07-11 02:59:00+03	40000.00
289F74	2017-07-19 21:47:00+03	13600.00
28A02A	2017-08-15 08:23:00+03	4100.00
28A073	2017-07-18 14:53:00+03	26000.00
28A0BD	2017-07-25 07:26:00+03	56000.00
28A0C7	2017-07-28 19:50:00+03	14800.00
28A0E0	2017-07-17 14:02:00+03	21000.00
28A104	2017-07-25 02:15:00+03	28800.00
28A166	2017-07-21 23:04:00+03	15100.00
28A18F	2017-08-11 17:01:00+03	20000.00
28A1C5	2017-07-09 09:22:00+03	179400.00
28A1EA	2017-07-17 15:57:00+03	37900.00
28A29D	2017-07-18 15:34:00+03	52100.00
28A2A8	2017-07-11 06:58:00+03	61200.00
28A2AC	2017-07-11 17:53:00+03	76600.00
28A2D4	2017-08-11 09:09:00+03	12600.00
28A2F7	2017-07-23 06:06:00+03	30200.00
28A33E	2017-07-07 03:19:00+03	59800.00
28A3A7	2017-07-07 04:27:00+03	135600.00
28A3B3	2017-07-21 00:32:00+03	116400.00
28A3C0	2017-07-05 12:24:00+03	35600.00
28A3D1	2017-08-12 08:14:00+03	53600.00
28A3D9	2017-07-02 17:50:00+03	129200.00
28A446	2017-08-13 00:45:00+03	40600.00
28A46F	2017-07-07 00:35:00+03	16400.00
28A48F	2017-07-24 07:15:00+03	177200.00
28A4B4	2017-06-30 23:12:00+03	266400.00
28A58C	2017-07-27 11:16:00+03	69400.00
28A610	2017-07-18 07:06:00+03	46200.00
28A666	2017-07-07 01:06:00+03	28000.00
28A66D	2017-08-03 02:31:00+03	25100.00
28A689	2017-07-24 05:19:00+03	83900.00
28A74A	2017-07-08 18:33:00+03	52000.00
28A793	2017-07-10 15:06:00+03	66600.00
28A7A8	2017-07-28 13:28:00+03	133200.00
28A7EF	2017-08-10 20:27:00+03	66600.00
28A853	2017-07-14 18:51:00+03	100600.00
28A85F	2017-08-05 14:00:00+03	17800.00
28A87F	2017-07-25 04:39:00+03	74800.00
28A891	2017-07-21 02:35:00+03	88400.00
28A898	2017-07-14 12:13:00+03	103500.00
28A8C2	2017-07-19 11:50:00+03	76300.00
28A977	2017-07-24 12:08:00+03	105000.00
28A9C6	2017-07-22 02:54:00+03	85700.00
28A9C8	2017-08-14 22:31:00+03	42800.00
28A9D6	2017-07-29 19:12:00+03	6700.00
28A9DE	2017-08-06 00:03:00+03	134700.00
28AA0D	2017-08-01 18:07:00+03	6800.00
28AA14	2017-07-22 00:19:00+03	41400.00
28AA27	2017-07-17 12:43:00+03	59300.00
28AA90	2017-08-05 22:41:00+03	139700.00
28AABA	2017-08-13 08:21:00+03	31200.00
28AB83	2017-07-12 01:58:00+03	47500.00
28ABFC	2017-08-06 10:11:00+03	48800.00
28AC42	2017-07-22 11:30:00+03	106100.00
28AC4D	2017-08-11 18:30:00+03	135100.00
28AC98	2017-07-07 17:55:00+03	56000.00
28ACBE	2017-08-04 15:12:00+03	309600.00
28ACD5	2017-07-23 20:56:00+03	81600.00
28AD00	2017-07-26 15:13:00+03	58400.00
28AD0E	2017-07-09 10:00:00+03	55800.00
28ADF2	2017-07-15 12:45:00+03	39200.00
28AEA1	2017-08-04 11:36:00+03	92800.00
28AEA5	2017-07-19 21:53:00+03	41800.00
28AED2	2017-07-11 16:32:00+03	36600.00
28AED5	2017-08-15 08:22:00+03	44400.00
28AEF3	2017-07-16 04:09:00+03	8200.00
28AF4F	2017-07-31 07:25:00+03	85000.00
28AF83	2017-07-13 01:24:00+03	68400.00
28AFC9	2017-07-04 02:21:00+03	123000.00
28B058	2017-08-11 19:21:00+03	51100.00
28B183	2017-07-27 11:16:00+03	29200.00
28B1CD	2017-07-06 20:41:00+03	94000.00
28B216	2017-07-28 10:02:00+03	167400.00
28B2A9	2017-08-06 15:46:00+03	103500.00
28B2CC	2017-07-11 13:59:00+03	76800.00
28B2FF	2017-08-07 15:44:00+03	53600.00
28B366	2017-07-20 09:31:00+03	78100.00
28B44B	2017-08-10 06:23:00+03	46900.00
28B464	2017-08-01 10:40:00+03	33100.00
28B48F	2017-07-01 07:03:00+03	30400.00
28B4AA	2017-07-30 01:10:00+03	32800.00
28B4C5	2017-07-25 01:21:00+03	27800.00
28B4D8	2017-08-07 06:17:00+03	18000.00
28B4DA	2017-07-10 16:47:00+03	31600.00
28B553	2017-07-13 09:05:00+03	12400.00
28B564	2017-08-15 00:05:00+03	12000.00
28B5BD	2017-08-13 23:37:00+03	66200.00
28B5C6	2017-06-29 09:07:00+03	27900.00
28B5D4	2017-08-09 14:31:00+03	32800.00
28B64E	2017-08-14 19:59:00+03	398500.00
28B698	2017-06-30 15:03:00+03	28800.00
28B69F	2017-07-20 13:16:00+03	216300.00
28B6CA	2017-07-29 06:37:00+03	229400.00
28B705	2017-07-12 18:37:00+03	135300.00
28B70A	2017-07-25 18:29:00+03	49100.00
28B71B	2017-08-06 02:26:00+03	26000.00
28B842	2017-07-08 12:39:00+03	208200.00
28B86A	2017-07-25 09:31:00+03	46400.00
28B88F	2017-07-07 15:05:00+03	135400.00
28B894	2017-08-02 20:50:00+03	39200.00
28B8B6	2017-08-12 06:03:00+03	38800.00
28B8D3	2017-07-31 01:30:00+03	67600.00
28B915	2017-08-13 18:24:00+03	111400.00
28B986	2017-07-10 05:49:00+03	117000.00
28B99A	2017-08-15 14:22:00+03	23200.00
28B9A6	2017-07-12 23:51:00+03	98100.00
28B9BA	2017-08-13 22:17:00+03	135200.00
28B9D9	2017-08-12 20:16:00+03	47500.00
28BA3E	2017-07-12 04:16:00+03	398500.00
28BAAD	2017-08-13 15:23:00+03	55800.00
28BAC3	2017-08-14 14:46:00+03	59000.00
28BAC8	2017-08-11 15:37:00+03	161400.00
28BB1E	2017-07-21 08:51:00+03	133100.00
28BB43	2017-07-27 15:08:00+03	27800.00
28BB97	2017-08-01 12:12:00+03	67200.00
28BBF4	2017-08-15 06:22:00+03	73300.00
28BC01	2017-08-10 13:59:00+03	13700.00
28BC0A	2017-07-17 16:36:00+03	29600.00
28BC26	2017-07-30 01:41:00+03	48800.00
28BC68	2017-08-01 23:06:00+03	56000.00
28BC8D	2017-08-12 04:27:00+03	16400.00
28BCA3	2017-08-04 23:22:00+03	62600.00
28BD47	2017-06-29 09:50:00+03	113700.00
28BD63	2017-07-31 09:21:00+03	58800.00
28BD8D	2017-07-20 00:26:00+03	213200.00
28BD99	2017-08-09 16:14:00+03	40000.00
28BDBD	2017-07-10 22:51:00+03	44500.00
28BDC2	2017-07-21 10:22:00+03	26000.00
28BDFC	2017-07-19 03:03:00+03	32700.00
28BE0B	2017-08-02 22:21:00+03	100600.00
28BED3	2017-08-06 12:02:00+03	12600.00
28BED8	2017-07-05 21:54:00+03	86000.00
28BED9	2017-07-15 07:30:00+03	20400.00
28BF0C	2017-07-09 06:39:00+03	133200.00
28BFA0	2017-07-01 11:43:00+03	75300.00
28BFAC	2017-08-15 03:54:00+03	28800.00
28BFE5	2017-07-16 16:34:00+03	81700.00
28BFEC	2017-07-08 23:59:00+03	65100.00
28BFFD	2017-07-08 01:57:00+03	12600.00
28C00F	2017-07-12 05:41:00+03	14400.00
28C097	2017-08-12 05:28:00+03	55800.00
28C121	2017-08-06 22:35:00+03	46800.00
28C12A	2017-08-02 12:39:00+03	196800.00
28C12F	2017-07-30 21:34:00+03	56000.00
28C1FC	2017-07-31 05:42:00+03	27200.00
28C23E	2017-07-15 17:29:00+03	34000.00
28C26A	2017-07-21 20:05:00+03	59300.00
28C2A1	2017-07-20 16:57:00+03	49400.00
28C2C3	2017-08-11 09:38:00+03	105000.00
28C2E8	2017-07-12 20:31:00+03	73500.00
28C31E	2017-08-13 01:51:00+03	91200.00
28C367	2017-07-27 01:40:00+03	22000.00
28C3C5	2017-07-01 09:45:00+03	13400.00
28C408	2017-07-23 07:24:00+03	6300.00
28C417	2017-07-31 18:23:00+03	205400.00
28C4AB	2017-08-02 16:24:00+03	47400.00
28C4AE	2017-07-22 15:17:00+03	24400.00
28C531	2017-08-08 08:05:00+03	89600.00
28C5CC	2017-07-28 22:51:00+03	37500.00
28C5F9	2017-07-08 07:56:00+03	46500.00
28C633	2017-07-05 04:36:00+03	47100.00
28C659	2017-07-24 03:22:00+03	166000.00
28C74C	2017-08-08 15:37:00+03	77500.00
28C7B6	2017-07-31 03:46:00+03	146600.00
28C7E5	2017-08-03 21:15:00+03	101100.00
28C7FF	2017-08-01 03:48:00+03	92800.00
28C807	2017-07-09 14:41:00+03	70600.00
28C810	2017-08-09 06:47:00+03	78300.00
28C814	2017-07-26 05:08:00+03	210900.00
28C83E	2017-08-13 18:40:00+03	72200.00
28C855	2017-07-07 18:51:00+03	58400.00
28C88B	2017-08-13 19:21:00+03	52300.00
28C897	2017-08-10 20:01:00+03	100600.00
28C8A5	2017-08-03 11:55:00+03	56000.00
28C8B6	2017-07-10 18:45:00+03	74900.00
28C8E8	2017-08-11 12:32:00+03	54700.00
28C909	2017-08-13 14:24:00+03	375200.00
28CA45	2017-07-25 01:23:00+03	56200.00
28CAA3	2017-08-02 04:15:00+03	66600.00
28CAA4	2017-08-05 16:38:00+03	52100.00
28CAB0	2017-07-19 12:03:00+03	111600.00
28CB0E	2017-07-22 10:40:00+03	132800.00
28CB56	2017-07-24 23:40:00+03	82000.00
28CB70	2017-07-04 16:30:00+03	117200.00
28CBA1	2017-08-07 13:36:00+03	61500.00
28CC28	2017-08-06 10:37:00+03	46800.00
28CC61	2017-08-01 14:19:00+03	57600.00
28CCB6	2017-08-08 08:39:00+03	96800.00
28CCF3	2017-07-26 07:07:00+03	32200.00
28CD16	2017-08-10 00:24:00+03	123000.00
28CD2C	2017-08-12 13:12:00+03	12600.00
28CDAF	2017-07-28 00:27:00+03	47200.00
28CDBA	2017-08-01 16:03:00+03	14400.00
28CDC0	2017-07-11 09:29:00+03	24200.00
28CDCA	2017-06-25 23:51:00+03	47200.00
28CDDF	2017-07-02 22:03:00+03	55800.00
28CE26	2017-07-26 01:09:00+03	13400.00
28CE30	2017-07-26 15:21:00+03	112000.00
28CE3B	2017-07-24 04:33:00+03	372500.00
28CEA6	2017-07-11 20:42:00+03	47700.00
28CED8	2017-07-11 22:17:00+03	266200.00
28CF2A	2017-07-23 19:07:00+03	53400.00
28CF44	2017-07-31 12:10:00+03	114900.00
28CF6D	2017-08-06 11:28:00+03	17200.00
28CF81	2017-07-29 17:23:00+03	61800.00
28D00E	2017-08-05 11:05:00+03	56000.00
28D014	2017-07-02 09:54:00+03	133200.00
28D227	2017-08-15 09:53:00+03	109600.00
28D253	2017-07-02 04:44:00+03	54400.00
28D28F	2017-07-03 09:27:00+03	46800.00
28D2CA	2017-07-14 10:25:00+03	190400.00
28D2EA	2017-07-28 06:39:00+03	40000.00
28D30E	2017-07-08 11:21:00+03	64300.00
28D362	2017-07-16 03:25:00+03	103500.00
28D497	2017-08-08 14:38:00+03	97900.00
28D4A7	2017-07-11 10:34:00+03	20200.00
28D4D9	2017-08-04 10:51:00+03	55800.00
28D4F6	2017-07-16 11:49:00+03	117600.00
28D524	2017-07-16 11:45:00+03	31600.00
28D545	2017-07-28 15:42:00+03	64600.00
28D54B	2017-07-04 07:44:00+03	12600.00
28D5A2	2017-07-05 13:05:00+03	266400.00
28D5AA	2017-07-07 13:38:00+03	31600.00
28D5C4	2017-07-26 13:41:00+03	31600.00
28D60C	2017-07-29 06:51:00+03	7400.00
28D648	2017-08-04 02:24:00+03	111800.00
28D661	2017-07-03 23:46:00+03	22000.00
28D672	2017-07-19 12:38:00+03	64200.00
28D6B3	2017-06-29 16:24:00+03	27200.00
28D6C0	2017-08-12 17:38:00+03	40800.00
28D6D5	2017-07-19 23:01:00+03	58400.00
28D6DF	2017-08-07 21:44:00+03	111600.00
28D736	2017-07-19 05:25:00+03	62600.00
28D786	2017-07-08 12:44:00+03	20200.00
28D7EC	2017-07-19 13:28:00+03	13600.00
28D85B	2017-08-14 21:19:00+03	26800.00
28D8A0	2017-08-09 16:18:00+03	95100.00
28D8A9	2017-07-06 21:15:00+03	150600.00
28D9D2	2017-08-01 22:25:00+03	384000.00
28D9F2	2017-07-02 08:42:00+03	160200.00
28DA14	2017-07-04 19:12:00+03	13400.00
28DA37	2017-07-02 13:24:00+03	30000.00
28DA40	2017-07-08 08:09:00+03	12600.00
28DA62	2017-08-12 17:21:00+03	89600.00
28DA88	2017-07-24 11:13:00+03	130400.00
28DAA8	2017-08-02 06:23:00+03	113800.00
28DAD1	2017-07-28 02:12:00+03	6800.00
28DAEC	2017-08-13 23:17:00+03	40100.00
28DB76	2017-07-18 16:05:00+03	77200.00
28DB77	2017-08-09 07:16:00+03	132800.00
28DB8A	2017-07-10 17:28:00+03	23600.00
28DB8B	2017-07-12 15:18:00+03	19600.00
28DB8C	2017-07-23 00:47:00+03	40900.00
28DBD1	2017-08-15 13:26:00+03	43200.00
28DC17	2017-08-12 22:00:00+03	23200.00
28DC26	2017-07-19 03:15:00+03	28000.00
28DC3E	2017-06-30 19:07:00+03	16400.00
28DCB6	2017-06-30 11:49:00+03	38600.00
28DD1A	2017-07-19 23:53:00+03	56000.00
28DE0E	2017-07-15 03:14:00+03	62800.00
28DE18	2017-07-05 21:57:00+03	133200.00
28DE1E	2017-07-22 21:17:00+03	60300.00
28DED4	2017-07-10 10:48:00+03	125100.00
28DF50	2017-07-13 11:53:00+03	23400.00
28DFD2	2017-07-12 12:13:00+03	47000.00
28DFE9	2017-07-22 04:12:00+03	29600.00
28E04A	2017-07-09 03:30:00+03	344600.00
28E106	2017-07-17 05:58:00+03	166000.00
28E126	2017-08-10 09:32:00+03	19600.00
28E154	2017-06-27 20:34:00+03	75600.00
28E16B	2017-07-27 12:53:00+03	50000.00
28E172	2017-07-09 02:31:00+03	26000.00
28E189	2017-07-13 07:47:00+03	170000.00
28E195	2017-07-31 03:16:00+03	77000.00
28E1BF	2017-08-04 15:40:00+03	28800.00
28E387	2017-07-15 09:42:00+03	73900.00
28E3B0	2017-07-07 19:42:00+03	44000.00
28E3B9	2017-07-05 11:58:00+03	28000.00
28E3C5	2017-08-01 09:38:00+03	26000.00
28E450	2017-08-02 01:58:00+03	58800.00
28E48A	2017-07-09 03:41:00+03	135200.00
28E49E	2017-06-27 00:24:00+03	21800.00
28E4A8	2017-08-13 22:19:00+03	56600.00
28E5AD	2017-08-11 09:58:00+03	13300.00
28E606	2017-07-18 07:13:00+03	24400.00
28E67D	2017-08-11 03:21:00+03	71900.00
28E6CD	2017-08-10 11:55:00+03	384800.00
28E6F1	2017-08-11 03:15:00+03	136200.00
28E733	2017-08-15 03:45:00+03	122100.00
28E76C	2017-07-06 05:28:00+03	225800.00
28E7C9	2017-08-10 16:42:00+03	54000.00
28E7DC	2017-08-01 07:20:00+03	44600.00
28E7FF	2017-07-13 06:29:00+03	118600.00
28E8A8	2017-08-09 11:15:00+03	172800.00
28E8FB	2017-07-02 21:02:00+03	43500.00
28E90E	2017-07-01 03:09:00+03	42700.00
28E967	2017-08-09 20:29:00+03	36000.00
28E9B4	2017-07-30 11:14:00+03	111600.00
28EA29	2017-07-31 20:41:00+03	43600.00
28EA32	2017-06-25 12:07:00+03	173200.00
28EA5D	2017-08-14 15:08:00+03	46400.00
28EAB4	2017-07-19 06:33:00+03	136800.00
28EAD3	2017-07-29 08:39:00+03	6000.00
28EB8C	2017-08-07 20:03:00+03	15300.00
28EBC0	2017-07-23 09:56:00+03	28000.00
28EBE9	2017-08-05 23:34:00+03	66600.00
28EC10	2017-07-28 15:36:00+03	100000.00
28EC1B	2017-08-11 02:30:00+03	46000.00
28EC8C	2017-08-01 07:43:00+03	23600.00
28ECA9	2017-08-14 09:01:00+03	128800.00
28EDE2	2017-07-30 01:28:00+03	39800.00
28EE26	2017-07-31 20:51:00+03	73600.00
28EE3E	2017-08-13 08:16:00+03	257600.00
28EE59	2017-07-31 13:56:00+03	21600.00
28EEB1	2017-08-06 01:50:00+03	84300.00
28EF13	2017-07-25 18:39:00+03	187800.00
28EF3D	2017-07-27 18:52:00+03	96800.00
28EFE9	2017-07-13 21:45:00+03	44000.00
28F01F	2017-07-13 22:29:00+03	43600.00
28F032	2017-07-20 20:24:00+03	135600.00
28F068	2017-08-07 01:13:00+03	64700.00
28F0F7	2017-08-07 20:00:00+03	17200.00
28F16D	2017-08-03 20:24:00+03	28700.00
28F172	2017-07-18 09:06:00+03	68800.00
28F17F	2017-07-15 21:12:00+03	70600.00
28F1BD	2017-07-19 03:14:00+03	71200.00
28F1C3	2017-07-13 18:17:00+03	74800.00
28F1CB	2017-08-12 07:18:00+03	128800.00
28F1FE	2017-07-29 01:35:00+03	30700.00
28F210	2017-07-24 11:52:00+03	55800.00
28F21B	2017-07-07 14:14:00+03	28300.00
28F27A	2017-08-06 13:47:00+03	75300.00
28F28B	2017-07-06 05:24:00+03	14400.00
28F2FB	2017-08-01 04:50:00+03	35200.00
28F2FF	2017-07-27 01:15:00+03	42400.00
28F315	2017-07-05 07:25:00+03	61800.00
28F358	2017-07-11 20:31:00+03	160100.00
28F3C2	2017-07-03 21:57:00+03	249100.00
28F3EC	2017-07-10 16:04:00+03	136200.00
28F401	2017-07-07 02:12:00+03	53600.00
28F421	2017-08-11 06:39:00+03	14000.00
28F425	2017-08-02 15:54:00+03	43200.00
28F487	2017-08-08 08:52:00+03	245200.00
28F4A3	2017-07-03 06:22:00+03	31200.00
28F4EF	2017-08-10 10:22:00+03	68400.00
28F5D0	2017-08-09 03:00:00+03	33000.00
28F654	2017-06-28 14:15:00+03	62000.00
28F659	2017-07-25 23:02:00+03	71900.00
28F65C	2017-07-11 22:13:00+03	37800.00
28F660	2017-08-12 03:48:00+03	48500.00
28F6A0	2017-07-26 10:41:00+03	135400.00
28F736	2017-07-28 04:59:00+03	93000.00
28F78F	2017-07-27 22:04:00+03	7200.00
28F7AD	2017-07-30 08:22:00+03	124300.00
28F82E	2017-07-24 14:51:00+03	53500.00
28F846	2017-08-14 16:44:00+03	26200.00
28F857	2017-07-08 06:53:00+03	354200.00
28F8C1	2017-07-15 15:22:00+03	50600.00
28F97B	2017-07-18 12:43:00+03	396500.00
28F97D	2017-07-28 13:18:00+03	28700.00
28F988	2017-07-25 19:38:00+03	130900.00
28F9A9	2017-08-15 03:03:00+03	23600.00
28F9DF	2017-07-30 23:55:00+03	63000.00
28FA13	2017-07-10 17:42:00+03	135600.00
28FA15	2017-08-15 10:44:00+03	37100.00
28FA56	2017-07-07 00:39:00+03	449500.00
28FA99	2017-07-17 07:51:00+03	7400.00
28FAE2	2017-07-28 09:20:00+03	31600.00
28FB23	2017-08-11 18:21:00+03	193200.00
28FB50	2017-08-12 05:49:00+03	182300.00
28FB9C	2017-07-14 17:23:00+03	98200.00
28FC0C	2017-07-09 00:16:00+03	162600.00
28FC64	2017-07-06 07:59:00+03	121800.00
28FC8A	2017-07-14 14:10:00+03	266400.00
28FCD8	2017-07-06 22:40:00+03	92100.00
28FCE7	2017-08-08 05:56:00+03	36900.00
28FD0F	2017-07-07 12:30:00+03	167400.00
28FD11	2017-08-10 21:59:00+03	198400.00
28FD27	2017-07-21 14:56:00+03	24400.00
28FD2C	2017-08-12 00:56:00+03	119500.00
28FD30	2017-07-12 08:10:00+03	266400.00
28FDB7	2017-08-05 16:41:00+03	73300.00
28FDBC	2017-07-22 18:05:00+03	28000.00
28FE44	2017-08-05 13:14:00+03	66000.00
28FE59	2017-08-12 00:31:00+03	52000.00
28FE82	2017-08-12 17:23:00+03	137600.00
28FE83	2017-08-10 18:11:00+03	36200.00
28FE9F	2017-07-19 20:39:00+03	15700.00
28FEDD	2017-08-03 12:33:00+03	186900.00
28FF0E	2017-06-27 07:10:00+03	56000.00
28FF47	2017-07-30 07:06:00+03	67600.00
28FF9A	2017-08-02 19:34:00+03	16400.00
290013	2017-07-11 03:11:00+03	46400.00
290041	2017-07-19 21:46:00+03	33300.00
29005D	2017-08-12 21:30:00+03	54400.00
290093	2017-07-06 16:38:00+03	36800.00
290103	2017-07-13 21:35:00+03	57600.00
290114	2017-08-11 08:18:00+03	59000.00
29011A	2017-07-08 01:45:00+03	79900.00
290131	2017-07-14 17:16:00+03	6700.00
2901CF	2017-08-02 18:20:00+03	58000.00
2901DC	2017-07-09 07:52:00+03	223700.00
2901E1	2017-07-15 01:19:00+03	163100.00
290203	2017-07-21 22:59:00+03	92900.00
290214	2017-07-03 20:58:00+03	6200.00
290291	2017-06-29 17:12:00+03	30400.00
2902B8	2017-07-12 12:32:00+03	118100.00
2902F5	2017-07-03 20:02:00+03	56800.00
290307	2017-08-13 18:58:00+03	26700.00
290324	2017-07-13 21:20:00+03	16400.00
29032D	2017-07-31 13:00:00+03	172500.00
290340	2017-08-01 03:35:00+03	155600.00
290347	2017-08-09 05:07:00+03	88000.00
2904AE	2017-08-08 21:14:00+03	8000.00
2904E3	2017-08-04 00:31:00+03	24000.00
2904E5	2017-07-17 21:27:00+03	9300.00
29050E	2017-07-09 09:57:00+03	26000.00
290537	2017-08-05 21:59:00+03	116400.00
290550	2017-07-09 14:33:00+03	66600.00
290557	2017-06-29 07:21:00+03	133200.00
2905E6	2017-08-12 12:09:00+03	35800.00
290604	2017-07-06 23:54:00+03	96600.00
29060F	2017-07-18 06:29:00+03	10800.00
290632	2017-08-07 19:15:00+03	38800.00
290687	2017-07-13 16:11:00+03	79000.00
29068A	2017-07-03 21:12:00+03	55800.00
29069E	2017-07-21 04:51:00+03	70700.00
2906F1	2017-08-11 21:27:00+03	40900.00
290706	2017-08-10 17:18:00+03	98300.00
29073D	2017-07-01 19:22:00+03	38600.00
290741	2017-07-05 02:58:00+03	28800.00
2907A4	2017-07-21 02:47:00+03	36800.00
2907B1	2017-08-13 04:07:00+03	139800.00
2907F3	2017-07-07 19:43:00+03	125400.00
29080D	2017-07-14 17:40:00+03	62600.00
290840	2017-07-06 01:15:00+03	24600.00
29085D	2017-07-18 01:00:00+03	64400.00
290888	2017-07-09 05:50:00+03	123000.00
2908E5	2017-07-27 16:02:00+03	73600.00
2908EE	2017-07-11 13:33:00+03	66600.00
290904	2017-07-10 09:26:00+03	62800.00
290913	2017-08-07 16:45:00+03	195800.00
290951	2017-08-03 20:31:00+03	38400.00
2909B2	2017-07-14 16:36:00+03	46400.00
2909DB	2017-07-17 04:16:00+03	29600.00
2909E0	2017-08-13 17:26:00+03	179500.00
2909E4	2017-06-27 20:17:00+03	298800.00
290A00	2017-07-22 16:36:00+03	51900.00
290A4E	2017-08-14 03:08:00+03	28800.00
290A6D	2017-07-16 17:08:00+03	70200.00
290AA2	2017-07-09 23:44:00+03	32000.00
290AD3	2017-07-15 04:36:00+03	26800.00
290AD6	2017-07-08 22:27:00+03	67600.00
290B65	2017-07-14 22:46:00+03	88000.00
290B8A	2017-07-14 08:01:00+03	24700.00
290B94	2017-08-01 04:25:00+03	163600.00
290BAD	2017-08-12 07:19:00+03	272400.00
290C1D	2017-08-05 17:53:00+03	40600.00
290C82	2017-07-07 12:15:00+03	69500.00
290C92	2017-07-03 18:30:00+03	38800.00
290D7D	2017-07-10 09:28:00+03	43700.00
290DEF	2017-07-08 16:19:00+03	49600.00
290EC2	2017-07-04 05:48:00+03	19200.00
290EEB	2017-07-08 00:55:00+03	60600.00
290F4C	2017-07-01 08:01:00+03	21200.00
290F50	2017-08-06 16:54:00+03	154500.00
290FD1	2017-08-12 01:22:00+03	61700.00
29104A	2017-07-07 04:44:00+03	121200.00
29105F	2017-07-21 14:35:00+03	28000.00
29107B	2017-08-04 10:48:00+03	38000.00
2910C5	2017-08-10 12:32:00+03	22000.00
2910D7	2017-07-17 12:54:00+03	54400.00
29115A	2017-07-15 19:57:00+03	47000.00
29122C	2017-07-13 00:13:00+03	18600.00
291230	2017-07-30 12:41:00+03	53700.00
291260	2017-07-25 21:17:00+03	56100.00
291295	2017-08-05 15:28:00+03	86800.00
29130B	2017-07-26 03:17:00+03	73300.00
291321	2017-07-14 11:56:00+03	78300.00
291323	2017-07-17 18:58:00+03	57500.00
2913A3	2017-07-08 11:20:00+03	70900.00
291430	2017-07-22 23:56:00+03	88400.00
291443	2017-08-12 09:29:00+03	28000.00
29146B	2017-07-16 05:20:00+03	28000.00
29147D	2017-06-30 03:44:00+03	56000.00
29154F	2017-07-08 17:45:00+03	26800.00
2915C1	2017-08-15 11:41:00+03	86300.00
2915EE	2017-07-31 09:14:00+03	56000.00
2915F7	2017-08-08 09:33:00+03	40000.00
29164C	2017-07-23 09:59:00+03	25600.00
291693	2017-07-29 08:21:00+03	75300.00
2916C1	2017-07-16 20:47:00+03	56500.00
2917E2	2017-08-11 23:55:00+03	24500.00
291803	2017-07-18 02:45:00+03	43000.00
29182D	2017-07-01 20:12:00+03	18600.00
291835	2017-08-04 09:07:00+03	94000.00
291839	2017-08-11 18:42:00+03	124200.00
291841	2017-07-29 03:14:00+03	23200.00
2918D7	2017-08-10 12:17:00+03	195500.00
29192A	2017-08-15 08:23:00+03	34100.00
291945	2017-07-11 00:50:00+03	30200.00
29197A	2017-07-15 13:09:00+03	26000.00
291980	2017-08-03 21:39:00+03	79000.00
2919BE	2017-07-18 20:12:00+03	23600.00
2919DB	2017-07-19 01:01:00+03	173600.00
2919FE	2017-07-28 07:19:00+03	62600.00
291A08	2017-07-31 21:56:00+03	63400.00
291A0B	2017-07-21 01:26:00+03	372600.00
291A0C	2017-07-07 13:12:00+03	28600.00
291A7E	2017-07-22 15:36:00+03	38800.00
291A9A	2017-08-12 16:48:00+03	56000.00
291AD7	2017-08-08 17:17:00+03	16400.00
291AFB	2017-08-10 06:17:00+03	57400.00
291B0C	2017-07-23 15:34:00+03	23600.00
291B1B	2017-07-15 08:24:00+03	86500.00
291BAD	2017-07-08 03:47:00+03	65900.00
291BE1	2017-06-30 05:43:00+03	135000.00
291BF3	2017-08-09 21:00:00+03	6300.00
291CB0	2017-07-29 14:42:00+03	357600.00
291D3D	2017-08-05 16:07:00+03	81600.00
291D43	2017-07-21 23:09:00+03	144400.00
291D56	2017-08-01 06:15:00+03	42800.00
291D93	2017-08-02 23:44:00+03	37900.00
291D99	2017-07-30 00:00:00+03	62600.00
291D9B	2017-08-03 18:12:00+03	169900.00
291DF9	2017-07-04 18:53:00+03	66800.00
291E19	2017-07-21 03:08:00+03	37600.00
291EB6	2017-07-22 05:05:00+03	36200.00
291EBB	2017-08-05 17:32:00+03	134400.00
291EC4	2017-07-08 21:18:00+03	43800.00
291F5B	2017-07-30 22:45:00+03	116700.00
292018	2017-08-08 23:40:00+03	68400.00
2920BD	2017-07-02 14:41:00+03	252200.00
29218A	2017-07-07 16:58:00+03	101100.00
2922D4	2017-07-08 01:16:00+03	184300.00
2922F1	2017-07-19 06:20:00+03	58700.00
292319	2017-08-04 20:20:00+03	30200.00
29234D	2017-07-25 03:04:00+03	14000.00
292354	2017-07-27 16:29:00+03	124200.00
292364	2017-07-03 09:59:00+03	273000.00
2923BE	2017-07-13 20:31:00+03	30200.00
292487	2017-08-04 00:43:00+03	29400.00
29248C	2017-07-01 23:31:00+03	75300.00
2925AD	2017-08-02 06:56:00+03	25200.00
2925D3	2017-07-05 10:44:00+03	38800.00
2925EA	2017-07-20 17:16:00+03	88100.00
2925F5	2017-07-22 02:01:00+03	75500.00
29262C	2017-08-09 19:08:00+03	43200.00
29265E	2017-07-01 11:43:00+03	20200.00
292667	2017-08-05 01:01:00+03	56600.00
2926AD	2017-08-14 16:24:00+03	62600.00
2926B0	2017-07-24 14:38:00+03	23200.00
2926CE	2017-07-05 04:39:00+03	81900.00
2926D4	2017-08-03 09:10:00+03	39400.00
2926DC	2017-07-06 17:40:00+03	88600.00
29270A	2017-07-22 15:20:00+03	332800.00
29271A	2017-08-05 01:16:00+03	27800.00
292726	2017-07-29 16:29:00+03	128000.00
29273B	2017-07-13 13:18:00+03	12600.00
292754	2017-07-13 12:17:00+03	6200.00
292757	2017-08-13 15:29:00+03	43600.00
29279A	2017-07-21 15:20:00+03	133100.00
29283A	2017-08-07 00:47:00+03	73600.00
292865	2017-07-30 00:37:00+03	8200.00
292901	2017-07-04 23:02:00+03	61500.00
29297C	2017-08-09 12:00:00+03	31600.00
29298A	2017-08-13 17:49:00+03	48800.00
2929D4	2017-07-30 18:37:00+03	67000.00
292A3C	2017-07-31 19:47:00+03	58600.00
292A57	2017-07-11 07:20:00+03	369000.00
292A9F	2017-07-21 13:11:00+03	20400.00
292ACD	2017-07-27 23:57:00+03	75600.00
292AD8	2017-07-11 14:00:00+03	122600.00
292AE0	2017-07-12 23:15:00+03	67900.00
292AF1	2017-07-07 21:29:00+03	32800.00
292AFD	2017-07-15 06:52:00+03	219100.00
292B0D	2017-08-14 13:38:00+03	48000.00
292B21	2017-08-01 07:25:00+03	32800.00
292B2D	2017-07-11 09:56:00+03	121700.00
292B42	2017-08-09 01:52:00+03	193600.00
292B44	2017-07-12 02:17:00+03	92600.00
292B9A	2017-07-30 22:39:00+03	83700.00
292BA6	2017-07-27 00:12:00+03	258400.00
292C13	2017-08-05 23:29:00+03	131600.00
292C72	2017-07-10 00:31:00+03	95600.00
292DAA	2017-07-26 22:57:00+03	219300.00
292DBA	2017-07-29 06:01:00+03	58800.00
292E3C	2017-07-22 12:20:00+03	48800.00
292E44	2017-07-24 07:38:00+03	28000.00
292EFE	2017-08-08 04:15:00+03	50000.00
293002	2017-08-05 10:59:00+03	27900.00
29302C	2017-08-12 05:20:00+03	8200.00
293058	2017-07-07 19:42:00+03	13400.00
293126	2017-08-08 02:19:00+03	313200.00
293184	2017-07-21 18:18:00+03	47400.00
293190	2017-07-18 04:53:00+03	21400.00
2931AE	2017-08-15 10:55:00+03	265700.00
293276	2017-08-05 02:43:00+03	29100.00
2932F3	2017-08-14 23:28:00+03	115100.00
29331C	2017-07-30 19:48:00+03	182700.00
293338	2017-07-05 12:32:00+03	52300.00
29336C	2017-07-06 23:18:00+03	11700.00
29338A	2017-07-30 10:51:00+03	70700.00
2933BF	2017-08-08 06:51:00+03	150100.00
293463	2017-07-22 08:59:00+03	209900.00
293499	2017-07-01 15:14:00+03	57100.00
29349E	2017-07-28 01:45:00+03	107300.00
2934D1	2017-08-04 07:47:00+03	19600.00
29351F	2017-07-01 01:19:00+03	70700.00
293569	2017-07-08 06:58:00+03	62000.00
29357D	2017-07-20 05:12:00+03	46000.00
293586	2017-08-09 23:14:00+03	57700.00
2935C3	2017-07-28 15:30:00+03	47000.00
29369A	2017-07-05 20:56:00+03	36200.00
2936B6	2017-07-17 21:33:00+03	62600.00
2936D1	2017-06-30 19:34:00+03	131100.00
2936F2	2017-07-17 19:27:00+03	75300.00
2936FC	2017-07-24 14:39:00+03	8200.00
2937D5	2017-08-08 00:20:00+03	23600.00
293852	2017-07-15 15:58:00+03	113700.00
293879	2017-08-10 19:38:00+03	86400.00
2938C5	2017-07-06 05:56:00+03	80900.00
2938C8	2017-08-01 06:59:00+03	32800.00
2938E8	2017-07-27 18:52:00+03	28800.00
2938E9	2017-08-02 15:28:00+03	94200.00
29395F	2017-07-26 12:53:00+03	147500.00
29399C	2017-07-08 22:33:00+03	74600.00
2939C6	2017-07-21 13:30:00+03	85500.00
293A32	2017-08-14 04:25:00+03	23200.00
293A76	2017-07-09 03:46:00+03	56600.00
293ABE	2017-08-08 10:23:00+03	64700.00
293B08	2017-07-29 09:46:00+03	28000.00
293B12	2017-07-07 07:44:00+03	31400.00
293B2E	2017-06-24 19:59:00+03	23200.00
293B6E	2017-07-28 17:07:00+03	13200.00
293C14	2017-07-20 00:13:00+03	25700.00
293C31	2017-08-07 09:28:00+03	31600.00
293C3B	2017-07-25 20:30:00+03	92800.00
293C54	2017-08-10 12:26:00+03	168000.00
293C90	2017-07-10 18:27:00+03	70800.00
293C94	2017-07-22 02:45:00+03	72600.00
293CD9	2017-07-28 05:21:00+03	6000.00
293D30	2017-08-14 07:12:00+03	26200.00
293DE7	2017-07-09 22:03:00+03	66600.00
293DFC	2017-08-04 23:51:00+03	19600.00
293E9F	2017-08-08 21:28:00+03	56000.00
293EBA	2017-08-12 05:03:00+03	133700.00
293EE9	2017-07-12 17:05:00+03	16400.00
293FDC	2017-08-10 22:36:00+03	49900.00
29404B	2017-08-07 21:41:00+03	12600.00
294071	2017-08-06 22:27:00+03	47400.00
294079	2017-07-10 17:15:00+03	13600.00
294084	2017-07-20 13:48:00+03	133200.00
29408B	2017-07-15 22:01:00+03	41800.00
294178	2017-08-14 04:24:00+03	45500.00
294189	2017-07-26 01:45:00+03	65500.00
294212	2017-08-08 08:13:00+03	25200.00
294257	2017-07-25 06:10:00+03	10800.00
294274	2017-07-19 04:10:00+03	35200.00
294285	2017-08-01 22:27:00+03	155300.00
29428C	2017-07-10 15:42:00+03	177100.00
2942DF	2017-07-22 00:01:00+03	29400.00
294347	2017-08-10 18:29:00+03	64400.00
2943B7	2017-08-11 21:08:00+03	55800.00
294425	2017-07-08 17:48:00+03	48800.00
294433	2017-08-13 16:37:00+03	20600.00
29446F	2017-07-31 10:09:00+03	55800.00
29448D	2017-08-03 12:29:00+03	26800.00
2944AC	2017-08-02 23:25:00+03	36000.00
29452D	2017-07-19 21:39:00+03	36200.00
29453D	2017-07-05 03:38:00+03	67100.00
29456B	2017-07-28 03:47:00+03	366600.00
294582	2017-07-26 11:20:00+03	51900.00
2945E5	2017-07-04 20:17:00+03	64800.00
29463B	2017-07-13 22:26:00+03	36200.00
29467E	2017-07-14 04:25:00+03	23200.00
294683	2017-07-20 17:51:00+03	131100.00
294693	2017-08-12 03:47:00+03	127200.00
2946F7	2017-07-22 22:40:00+03	77000.00
29473C	2017-08-12 05:54:00+03	40600.00
29478B	2017-08-12 18:00:00+03	254900.00
29478D	2017-07-28 04:22:00+03	31100.00
294816	2017-07-20 23:08:00+03	64500.00
294823	2017-08-01 19:18:00+03	103500.00
29483C	2017-07-12 01:27:00+03	111600.00
294872	2017-07-16 12:04:00+03	85000.00
294916	2017-08-08 19:19:00+03	198400.00
29491D	2017-07-04 21:48:00+03	190400.00
29498B	2017-07-27 23:32:00+03	36200.00
294A05	2017-07-21 08:03:00+03	54800.00
294A47	2017-07-15 00:43:00+03	65800.00
294A4C	2017-07-19 07:35:00+03	47400.00
294A83	2017-08-02 16:43:00+03	88600.00
294A9B	2017-07-06 16:12:00+03	135400.00
294AE9	2017-07-10 20:21:00+03	58200.00
294BA7	2017-06-29 14:54:00+03	56000.00
294C52	2017-06-29 22:55:00+03	25200.00
294C62	2017-08-13 18:11:00+03	39400.00
294C8F	2017-07-17 18:56:00+03	12400.00
294CA3	2017-07-06 10:43:00+03	10600.00
294CDB	2017-08-08 06:37:00+03	13200.00
294D2E	2017-07-30 18:40:00+03	152900.00
294D68	2017-07-13 08:25:00+03	31700.00
294DA1	2017-08-03 13:21:00+03	440700.00
294DB5	2017-08-14 11:52:00+03	112000.00
294DDA	2017-08-03 16:54:00+03	57600.00
294DEF	2017-08-04 05:57:00+03	135400.00
294DF3	2017-07-30 14:15:00+03	111600.00
294E01	2017-07-19 13:50:00+03	38800.00
294E51	2017-08-09 15:19:00+03	86600.00
294E99	2017-07-11 08:33:00+03	85000.00
294ED3	2017-08-09 10:18:00+03	123700.00
294F77	2017-08-05 23:44:00+03	66600.00
294FF1	2017-08-11 23:59:00+03	25100.00
2950EC	2017-07-27 07:24:00+03	147100.00
2950F4	2017-07-08 09:04:00+03	43400.00
295138	2017-07-24 03:29:00+03	84100.00
295189	2017-07-25 05:04:00+03	56000.00
2951A1	2017-07-31 03:41:00+03	336400.00
295207	2017-07-25 19:02:00+03	399600.00
29521D	2017-07-07 06:56:00+03	56100.00
295223	2017-07-04 01:48:00+03	72600.00
295283	2017-08-06 12:23:00+03	6000.00
2952E4	2017-07-27 12:56:00+03	57700.00
2952FA	2017-07-15 21:05:00+03	75600.00
29538E	2017-07-24 19:51:00+03	281700.00
29539B	2017-08-03 03:14:00+03	119600.00
2953A4	2017-07-10 05:12:00+03	25600.00
29547A	2017-07-30 10:31:00+03	23600.00
2954BF	2017-07-31 09:46:00+03	37700.00
2956AB	2017-07-16 03:39:00+03	44500.00
2956DB	2017-07-24 08:13:00+03	29200.00
295722	2017-08-15 06:03:00+03	24000.00
29577D	2017-08-08 12:10:00+03	26700.00
295786	2017-08-15 16:51:00+03	386300.00
2957A0	2017-07-23 17:53:00+03	89300.00
2957A1	2017-08-05 07:44:00+03	229300.00
29580E	2017-07-14 22:28:00+03	33100.00
295861	2017-07-03 10:12:00+03	22000.00
295867	2017-07-07 12:13:00+03	146300.00
29587C	2017-08-06 13:29:00+03	51000.00
2958C0	2017-07-23 13:47:00+03	38800.00
29596B	2017-07-08 00:41:00+03	21400.00
29596C	2017-07-14 17:21:00+03	48800.00
295970	2017-08-11 13:52:00+03	26700.00
295978	2017-08-11 08:43:00+03	73100.00
295997	2017-07-19 19:01:00+03	78600.00
2959FF	2017-08-03 02:19:00+03	136200.00
295A45	2017-07-10 02:04:00+03	46000.00
295A7B	2017-08-01 14:13:00+03	6700.00
295A8F	2017-07-11 20:09:00+03	53000.00
295A9E	2017-07-13 10:59:00+03	23200.00
295ABB	2017-07-17 23:35:00+03	22200.00
295BEB	2017-07-23 15:13:00+03	23200.00
295C03	2017-08-05 06:43:00+03	57400.00
295CE3	2017-07-11 05:24:00+03	13600.00
295CF6	2017-07-20 12:52:00+03	23200.00
295D06	2017-07-14 03:34:00+03	142400.00
295D27	2017-07-02 01:30:00+03	49600.00
295D3C	2017-07-23 22:59:00+03	20000.00
295D4A	2017-07-14 21:36:00+03	26000.00
295D4F	2017-07-10 01:26:00+03	57500.00
295DAA	2017-07-04 04:40:00+03	6800.00
295DE1	2017-07-15 19:58:00+03	187600.00
295E36	2017-08-07 22:47:00+03	25400.00
295ED7	2017-08-02 06:07:00+03	75300.00
295EDE	2017-08-14 02:06:00+03	14400.00
295EE6	2017-07-12 10:59:00+03	95700.00
295F5A	2017-07-02 12:06:00+03	66600.00
295F70	2017-07-11 00:50:00+03	31200.00
295F9C	2017-07-13 07:02:00+03	67900.00
296007	2017-08-11 11:37:00+03	36800.00
296098	2017-07-25 17:28:00+03	101200.00
29609E	2017-08-09 19:40:00+03	131600.00
2960AC	2017-07-23 19:22:00+03	43200.00
2960C5	2017-07-29 20:38:00+03	155300.00
296175	2017-07-12 15:14:00+03	23900.00
296176	2017-07-22 00:30:00+03	132800.00
296180	2017-07-21 18:29:00+03	71400.00
296246	2017-08-07 12:38:00+03	85700.00
29626F	2017-08-03 23:43:00+03	33200.00
296293	2017-07-27 02:27:00+03	91600.00
296337	2017-08-08 12:43:00+03	13400.00
2963AF	2017-07-19 04:56:00+03	139400.00
2963C9	2017-07-29 23:01:00+03	61900.00
2963F7	2017-08-06 13:53:00+03	45200.00
296445	2017-07-05 22:28:00+03	295400.00
296481	2017-07-29 07:00:00+03	128800.00
29649D	2017-07-21 09:01:00+03	6700.00
2964C2	2017-07-31 21:21:00+03	67700.00
296506	2017-07-08 12:39:00+03	66600.00
2965F4	2017-07-27 01:23:00+03	4000.00
2965FC	2017-08-05 02:00:00+03	6900.00
296628	2017-08-13 09:35:00+03	25600.00
296636	2017-08-12 22:09:00+03	22100.00
29664F	2017-07-05 11:09:00+03	101700.00
2966E8	2017-07-25 06:11:00+03	48800.00
29679D	2017-07-28 15:02:00+03	111600.00
2967AB	2017-08-05 20:44:00+03	26000.00
2967D6	2017-08-10 07:24:00+03	28000.00
296832	2017-07-17 18:46:00+03	106400.00
296870	2017-07-11 19:22:00+03	198400.00
296881	2017-07-09 23:24:00+03	28000.00
296896	2017-07-17 08:55:00+03	7300.00
2968C0	2017-07-11 07:19:00+03	55800.00
2968C8	2017-07-21 01:06:00+03	7800.00
296967	2017-07-24 00:14:00+03	45000.00
29696F	2017-07-19 19:03:00+03	62900.00
296988	2017-07-07 16:32:00+03	25200.00
2969A0	2017-08-06 14:03:00+03	38600.00
2969D0	2017-08-15 01:27:00+03	28800.00
296A61	2017-07-21 04:08:00+03	6800.00
296AC8	2017-07-31 10:34:00+03	20800.00
296B0A	2017-07-28 02:22:00+03	40100.00
296B3E	2017-07-21 09:26:00+03	30200.00
296B69	2017-07-14 09:08:00+03	20000.00
296BC8	2017-07-30 00:06:00+03	20800.00
296BD8	2017-06-30 14:32:00+03	14000.00
296BF5	2017-08-08 20:41:00+03	65200.00
296CD6	2017-08-13 07:46:00+03	87900.00
296D29	2017-08-09 09:51:00+03	155600.00
296D8F	2017-07-18 21:34:00+03	396500.00
296DC3	2017-07-11 14:55:00+03	12000.00
296DE4	2017-08-12 00:34:00+03	272300.00
296E57	2017-08-12 05:58:00+03	101400.00
296E6F	2017-07-21 22:19:00+03	58600.00
296ECB	2017-08-02 06:22:00+03	12400.00
296F1A	2017-07-11 18:37:00+03	26000.00
296F7D	2017-07-06 08:37:00+03	39400.00
296F92	2017-07-20 00:40:00+03	61500.00
297054	2017-07-28 08:56:00+03	24200.00
29709C	2017-07-14 15:18:00+03	129700.00
297100	2017-07-26 22:36:00+03	12000.00
297116	2017-07-12 21:01:00+03	243600.00
29717F	2017-07-16 07:55:00+03	85000.00
297199	2017-07-13 01:55:00+03	39500.00
297211	2017-07-26 23:11:00+03	49800.00
29722F	2017-08-14 19:36:00+03	178800.00
297234	2017-07-20 06:54:00+03	49100.00
29729B	2017-07-12 07:20:00+03	134700.00
2972B2	2017-08-13 17:13:00+03	92100.00
2972FA	2017-07-03 12:55:00+03	28800.00
2972FC	2017-08-07 11:13:00+03	54800.00
297316	2017-07-03 15:42:00+03	56600.00
297332	2017-08-13 00:54:00+03	142700.00
29733D	2017-07-19 09:06:00+03	95900.00
297371	2017-07-17 21:22:00+03	25400.00
2973DB	2017-07-27 16:51:00+03	284400.00
2973E3	2017-07-02 10:24:00+03	99200.00
297415	2017-08-02 07:07:00+03	140100.00
297510	2017-07-16 09:27:00+03	93600.00
29755A	2017-07-26 17:42:00+03	10800.00
297560	2017-07-14 07:56:00+03	37900.00
2975D4	2017-06-30 21:14:00+03	70800.00
2976B7	2017-07-10 04:55:00+03	23200.00
297709	2017-07-10 20:17:00+03	93400.00
29775F	2017-07-04 18:00:00+03	85000.00
297785	2017-06-28 11:02:00+03	84700.00
297788	2017-06-29 06:14:00+03	32200.00
2977A5	2017-07-01 02:51:00+03	12000.00
2977A9	2017-08-12 19:13:00+03	21800.00
2977C8	2017-07-27 13:16:00+03	64200.00
297842	2017-08-12 18:30:00+03	42000.00
297843	2017-08-10 23:54:00+03	135600.00
2978B1	2017-08-08 15:57:00+03	47200.00
2978BE	2017-07-18 13:09:00+03	55800.00
2978DD	2017-08-01 20:58:00+03	31600.00
297925	2017-08-05 12:18:00+03	168000.00
297932	2017-07-03 05:41:00+03	266300.00
2979A4	2017-07-26 09:00:00+03	62600.00
2979A9	2017-08-02 18:00:00+03	14400.00
2979B6	2017-07-16 11:15:00+03	116000.00
297A74	2017-07-15 22:39:00+03	40800.00
297AB0	2017-07-18 19:44:00+03	56000.00
297AC0	2017-07-03 04:35:00+03	48800.00
297AD4	2017-08-14 03:36:00+03	40000.00
297B1A	2017-07-03 22:57:00+03	151200.00
297B41	2017-07-28 12:50:00+03	15000.00
297B97	2017-07-30 10:31:00+03	22000.00
297BCB	2017-08-13 20:30:00+03	132800.00
297BD6	2017-07-10 14:40:00+03	159400.00
297BE2	2017-07-12 06:36:00+03	52700.00
297C91	2017-08-13 12:43:00+03	59400.00
297CA9	2017-08-14 13:35:00+03	99700.00
297D36	2017-08-01 06:43:00+03	56000.00
297DCC	2017-07-10 18:22:00+03	40100.00
297E21	2017-07-09 19:28:00+03	31400.00
297E31	2017-08-11 05:56:00+03	6000.00
297E38	2017-07-19 22:35:00+03	20500.00
297E8E	2017-07-28 04:22:00+03	13400.00
297E97	2017-07-22 02:03:00+03	39400.00
297F51	2017-07-28 13:56:00+03	25200.00
297F65	2017-07-08 14:36:00+03	23400.00
297F76	2017-07-09 01:52:00+03	146900.00
297FA0	2017-07-20 21:11:00+03	206200.00
297FC5	2017-08-05 23:13:00+03	68100.00
297FCE	2017-08-11 23:21:00+03	34600.00
297FE1	2017-07-06 06:52:00+03	54400.00
29807C	2017-07-11 21:29:00+03	75200.00
2980A8	2017-08-02 01:06:00+03	120900.00
2980E1	2017-07-20 08:55:00+03	23600.00
2980FE	2017-07-23 18:52:00+03	210200.00
29812B	2017-08-13 00:07:00+03	282800.00
298172	2017-07-22 07:45:00+03	189200.00
298176	2017-07-19 02:52:00+03	266000.00
2981F6	2017-07-23 06:24:00+03	201200.00
298242	2017-07-03 23:02:00+03	37900.00
29826C	2017-07-07 14:56:00+03	75600.00
298280	2017-08-05 12:21:00+03	100600.00
2982DC	2017-08-11 05:05:00+03	84500.00
298303	2017-07-07 22:10:00+03	32800.00
298348	2017-08-06 07:19:00+03	27300.00
298397	2017-07-12 09:09:00+03	56000.00
298404	2017-08-08 16:52:00+03	67600.00
298563	2017-07-31 22:32:00+03	122400.00
2985B6	2017-08-05 05:15:00+03	55600.00
2985C7	2017-07-15 09:00:00+03	50400.00
2985DB	2017-07-05 17:06:00+03	13200.00
2985E5	2017-08-15 16:37:00+03	55800.00
298628	2017-08-11 19:02:00+03	172100.00
298696	2017-07-20 01:02:00+03	21400.00
2986E4	2017-07-15 01:31:00+03	248500.00
298715	2017-07-23 21:49:00+03	92300.00
298747	2017-07-07 18:01:00+03	43600.00
298763	2017-07-15 03:57:00+03	51300.00
2987CF	2017-08-01 05:27:00+03	36200.00
298802	2017-07-03 13:22:00+03	56000.00
29884E	2017-07-26 04:10:00+03	42800.00
29891A	2017-07-23 07:20:00+03	153200.00
298925	2017-08-09 04:13:00+03	102100.00
298945	2017-07-11 00:58:00+03	246000.00
298981	2017-07-29 16:42:00+03	36000.00
298A73	2017-08-12 12:01:00+03	22600.00
298A8A	2017-07-20 07:09:00+03	46300.00
298AF1	2017-08-06 05:56:00+03	278400.00
298B2E	2017-07-23 00:32:00+03	37100.00
298B83	2017-07-10 06:54:00+03	75300.00
298B8D	2017-07-10 13:16:00+03	24400.00
298BCF	2017-07-18 04:50:00+03	13400.00
298C29	2017-07-12 00:46:00+03	24400.00
298C2C	2017-07-11 07:59:00+03	119400.00
298CDB	2017-07-13 10:55:00+03	38400.00
298CE3	2017-07-12 20:08:00+03	111600.00
298D1F	2017-07-03 09:16:00+03	61800.00
298DC8	2017-07-27 18:33:00+03	46300.00
298DCB	2017-08-15 11:31:00+03	13000.00
298DD5	2017-08-08 04:31:00+03	49200.00
298DF4	2017-08-05 22:41:00+03	101100.00
298E74	2017-06-30 21:15:00+03	271200.00
298F7A	2017-07-23 20:25:00+03	21800.00
298F92	2017-07-17 20:31:00+03	56100.00
298FA6	2017-07-28 18:46:00+03	100400.00
298FD0	2017-08-10 08:04:00+03	119500.00
298FE9	2017-07-10 20:30:00+03	26200.00
299006	2017-08-01 20:19:00+03	68400.00
29904F	2017-07-09 04:05:00+03	112600.00
29907D	2017-08-02 19:40:00+03	56000.00
299080	2017-08-04 14:31:00+03	117600.00
299090	2017-07-21 17:56:00+03	55800.00
299108	2017-07-18 19:49:00+03	6300.00
29913E	2017-07-08 17:01:00+03	86600.00
299148	2017-08-11 18:41:00+03	40400.00
299151	2017-07-10 01:47:00+03	25900.00
299193	2017-07-24 12:05:00+03	29600.00
2991AB	2017-08-06 14:06:00+03	62700.00
2991B3	2017-08-03 21:23:00+03	23600.00
299206	2017-07-22 20:58:00+03	51200.00
29924C	2017-08-11 21:15:00+03	44500.00
299282	2017-07-21 18:31:00+03	59300.00
29928B	2017-07-03 00:22:00+03	44100.00
299309	2017-08-09 13:18:00+03	135600.00
299324	2017-08-02 01:50:00+03	248400.00
299327	2017-07-24 05:25:00+03	139200.00
29934B	2017-07-11 20:42:00+03	28000.00
29934C	2017-08-09 23:40:00+03	39200.00
2993B4	2017-07-26 06:25:00+03	155600.00
29940D	2017-08-14 08:23:00+03	84500.00
299417	2017-08-15 07:03:00+03	77000.00
299434	2017-08-10 23:36:00+03	20400.00
299464	2017-08-08 12:53:00+03	55800.00
2994C0	2017-07-13 10:54:00+03	168000.00
2994E5	2017-07-04 01:01:00+03	86800.00
299599	2017-08-05 09:51:00+03	82700.00
2995BC	2017-07-24 01:55:00+03	28800.00
2995E1	2017-07-31 00:10:00+03	101200.00
299609	2017-07-29 03:27:00+03	48800.00
299648	2017-07-28 09:36:00+03	96800.00
29964B	2017-07-12 23:32:00+03	62000.00
299666	2017-07-30 23:56:00+03	65000.00
299668	2017-08-04 03:55:00+03	8000.00
299692	2017-07-15 21:51:00+03	83700.00
2996C4	2017-07-12 03:40:00+03	35200.00
299714	2017-07-04 01:43:00+03	44000.00
29972A	2017-08-10 07:05:00+03	64800.00
299747	2017-07-12 10:30:00+03	62000.00
299753	2017-07-23 12:44:00+03	410500.00
299762	2017-07-08 01:51:00+03	47000.00
299784	2017-06-29 16:01:00+03	46400.00
2997AE	2017-07-11 10:30:00+03	32200.00
2997B9	2017-08-13 05:10:00+03	406600.00
2997E8	2017-07-25 14:51:00+03	69400.00
299842	2017-07-22 18:03:00+03	69900.00
299851	2017-08-02 01:17:00+03	111600.00
2998F2	2017-08-15 06:29:00+03	40600.00
299906	2017-07-14 21:21:00+03	24400.00
299924	2017-07-13 00:17:00+03	18300.00
299945	2017-06-30 02:19:00+03	277400.00
299B09	2017-07-31 02:30:00+03	22000.00
299B1B	2017-08-06 08:50:00+03	65400.00
299B1C	2017-07-13 02:08:00+03	24400.00
299B49	2017-07-15 11:10:00+03	36900.00
299B7A	2017-07-07 17:48:00+03	28000.00
299B9F	2017-08-08 04:44:00+03	193600.00
299BAB	2017-07-21 15:46:00+03	139800.00
299BB2	2017-07-30 22:07:00+03	16400.00
299BE6	2017-07-28 22:44:00+03	24300.00
299C5B	2017-07-15 16:02:00+03	31600.00
299CA1	2017-08-01 07:21:00+03	67600.00
299CA6	2017-08-01 08:55:00+03	28000.00
299D4E	2017-07-13 05:11:00+03	19800.00
299EE7	2017-07-23 11:42:00+03	26700.00
299F0D	2017-08-01 04:53:00+03	23400.00
299F80	2017-07-11 20:19:00+03	258400.00
299FB4	2017-08-10 06:32:00+03	8400.00
299FCC	2017-07-18 01:02:00+03	59800.00
299FD6	2017-08-02 06:53:00+03	28000.00
299FDA	2017-07-04 12:43:00+03	16800.00
299FE1	2017-07-30 14:41:00+03	8000.00
29A03B	2017-08-14 21:22:00+03	40400.00
29A04F	2017-07-04 17:14:00+03	56200.00
29A0BB	2017-08-02 06:34:00+03	30400.00
29A0DA	2017-07-12 03:19:00+03	65900.00
29A0EA	2017-07-15 23:12:00+03	10800.00
29A180	2017-07-24 01:31:00+03	21200.00
29A1AC	2017-07-21 06:09:00+03	69600.00
29A2FF	2017-08-13 21:09:00+03	55600.00
29A375	2017-08-12 18:28:00+03	167400.00
29A392	2017-08-08 18:49:00+03	34000.00
29A3B0	2017-08-12 06:34:00+03	81600.00
29A3D9	2017-08-14 01:58:00+03	131100.00
29A457	2017-08-05 01:32:00+03	31400.00
29A491	2017-08-04 07:25:00+03	19600.00
29A503	2017-08-15 01:56:00+03	55000.00
29A530	2017-07-26 15:01:00+03	46500.00
29A596	2017-07-24 14:39:00+03	25700.00
29A5EE	2017-08-13 16:02:00+03	394400.00
29A623	2017-07-02 06:20:00+03	55800.00
29A64E	2017-08-01 21:11:00+03	29600.00
29A6A5	2017-08-14 09:03:00+03	12600.00
29A6B3	2017-07-28 01:10:00+03	124400.00
29A6DC	2017-08-12 18:31:00+03	99300.00
29A702	2017-08-08 07:27:00+03	6000.00
29A722	2017-07-05 06:05:00+03	49800.00
29A7CE	2017-08-01 14:33:00+03	375200.00
29A7F8	2017-07-09 23:24:00+03	25600.00
29A824	2017-08-14 15:42:00+03	188000.00
29A892	2017-07-30 04:53:00+03	56600.00
29A898	2017-08-12 03:36:00+03	52000.00
29A8C3	2017-07-29 12:21:00+03	213800.00
29A8D2	2017-08-04 23:20:00+03	64800.00
29AA49	2017-08-08 02:14:00+03	220200.00
29AA4E	2017-08-05 23:33:00+03	56000.00
29AA62	2017-07-29 21:27:00+03	20200.00
29AAF3	2017-08-12 19:55:00+03	76600.00
29AB1C	2017-07-29 02:58:00+03	23200.00
29ABBE	2017-07-09 18:35:00+03	28000.00
29ABE5	2017-08-03 08:00:00+03	89400.00
29AC35	2017-07-27 12:21:00+03	77700.00
29ACD3	2017-07-22 19:01:00+03	91600.00
29ACE4	2017-07-26 05:47:00+03	54500.00
29AD7D	2017-07-07 23:03:00+03	86600.00
29AE19	2017-07-12 04:13:00+03	254600.00
29AE1E	2017-07-10 16:05:00+03	36400.00
29AE9C	2017-07-14 10:13:00+03	21400.00
29AEE1	2017-07-06 03:23:00+03	52900.00
29AEF0	2017-08-14 19:31:00+03	52000.00
29AF6A	2017-07-30 11:30:00+03	25600.00
29AFD0	2017-07-03 22:34:00+03	116900.00
29AFD6	2017-07-16 13:30:00+03	44800.00
29B087	2017-08-12 13:35:00+03	46000.00
29B0E2	2017-07-27 07:42:00+03	73500.00
29B0EB	2017-08-07 07:08:00+03	55800.00
29B0EC	2017-07-30 14:09:00+03	39400.00
29B14A	2017-07-24 08:54:00+03	249200.00
29B14E	2017-08-10 06:48:00+03	98300.00
29B18D	2017-07-03 20:05:00+03	88900.00
29B1B1	2017-08-07 13:41:00+03	15800.00
29B22B	2017-07-26 19:55:00+03	40800.00
29B24C	2017-07-29 12:56:00+03	108900.00
29B25D	2017-07-15 06:33:00+03	52800.00
29B35F	2017-07-12 18:50:00+03	43600.00
29B3C4	2017-07-29 10:14:00+03	384800.00
29B403	2017-07-21 07:12:00+03	68800.00
29B42D	2017-07-22 17:02:00+03	218800.00
29B430	2017-08-02 21:20:00+03	11600.00
29B482	2017-08-06 15:55:00+03	23600.00
29B4B3	2017-07-18 23:58:00+03	29400.00
29B4C2	2017-07-04 07:08:00+03	56100.00
29B4D9	2017-07-17 02:27:00+03	139000.00
29B4F9	2017-08-09 08:15:00+03	67400.00
29B4FC	2017-07-24 08:37:00+03	25600.00
29B505	2017-07-18 16:34:00+03	55800.00
29B536	2017-08-02 04:30:00+03	131600.00
29B541	2017-07-28 02:37:00+03	75300.00
29B57B	2017-07-25 18:07:00+03	15000.00
29B5B3	2017-07-25 05:29:00+03	86600.00
29B5CA	2017-07-22 00:36:00+03	39600.00
29B62B	2017-07-02 06:28:00+03	43600.00
29B648	2017-07-28 14:46:00+03	133200.00
29B66D	2017-07-09 02:20:00+03	20200.00
29B677	2017-07-24 13:46:00+03	64500.00
29B71F	2017-06-29 07:16:00+03	35700.00
29B820	2017-07-27 15:58:00+03	112600.00
29B904	2017-07-06 02:04:00+03	103000.00
29B914	2017-07-05 17:15:00+03	26200.00
29B95D	2017-07-08 03:22:00+03	92800.00
29B965	2017-07-25 17:13:00+03	67600.00
29B9A7	2017-08-11 02:27:00+03	74800.00
29B9B2	2017-07-22 17:10:00+03	87600.00
29B9E5	2017-08-14 04:20:00+03	28200.00
29B9E8	2017-07-13 01:53:00+03	133200.00
29B9F8	2017-08-08 11:01:00+03	43600.00
29BA4B	2017-07-02 07:47:00+03	193100.00
29BA9F	2017-07-24 04:59:00+03	85000.00
29BAF2	2017-08-14 15:16:00+03	28300.00
29BAF5	2017-07-22 08:19:00+03	236700.00
29BB7C	2017-07-17 17:17:00+03	29400.00
29BB8A	2017-07-18 18:32:00+03	62900.00
29BB94	2017-07-12 08:48:00+03	175300.00
29BC3F	2017-07-26 06:47:00+03	149200.00
29BCDF	2017-07-25 20:38:00+03	56600.00
29BCFF	2017-07-30 21:47:00+03	67100.00
29BDBD	2017-07-27 13:57:00+03	13600.00
29BE38	2017-07-10 12:42:00+03	160700.00
29BEE3	2017-07-06 15:31:00+03	66600.00
29BEFF	2017-07-20 03:56:00+03	55800.00
29BF4C	2017-07-15 20:58:00+03	64300.00
29BF4E	2017-07-17 04:22:00+03	56000.00
29BF82	2017-07-26 22:17:00+03	97800.00
29BFA6	2017-08-06 10:14:00+03	45200.00
29BFC1	2017-07-19 15:42:00+03	51600.00
29BFD6	2017-07-29 15:52:00+03	224500.00
29C015	2017-07-10 17:10:00+03	24800.00
29C0B4	2017-07-11 20:01:00+03	155000.00
29C0BD	2017-07-18 13:51:00+03	38400.00
29C0C1	2017-07-31 17:14:00+03	95700.00
29C122	2017-08-08 01:19:00+03	27200.00
29C183	2017-07-26 00:52:00+03	19600.00
29C1C2	2017-07-16 15:22:00+03	162600.00
29C1FB	2017-08-05 08:39:00+03	32600.00
29C1FF	2017-08-04 20:20:00+03	155600.00
29C211	2017-07-29 22:10:00+03	29600.00
29C218	2017-07-07 10:02:00+03	58800.00
29C25D	2017-08-10 00:57:00+03	59800.00
29C293	2017-07-26 05:41:00+03	20400.00
29C2EB	2017-07-08 14:34:00+03	80900.00
29C3D1	2017-08-01 05:47:00+03	40800.00
29C3EA	2017-08-08 11:08:00+03	23200.00
29C3FF	2017-07-24 05:00:00+03	26000.00
29C415	2017-07-19 20:47:00+03	88000.00
29C42D	2017-07-02 07:05:00+03	99700.00
29C43E	2017-08-06 13:00:00+03	46500.00
29C4FA	2017-07-25 07:28:00+03	40000.00
29C53D	2017-07-20 20:37:00+03	26600.00
29C5E3	2017-08-14 19:19:00+03	16400.00
29C658	2017-07-08 19:28:00+03	75600.00
29C665	2017-07-04 09:31:00+03	103400.00
29C68E	2017-06-29 20:13:00+03	72200.00
29C720	2017-07-17 15:19:00+03	17000.00
29C7BE	2017-08-09 18:37:00+03	49500.00
29C7F5	2017-08-02 02:46:00+03	31600.00
29C88B	2017-08-12 19:32:00+03	85700.00
29C8BE	2017-08-15 16:12:00+03	79200.00
29C90C	2017-07-30 18:51:00+03	405200.00
29C97C	2017-07-20 01:23:00+03	64700.00
29C99C	2017-07-19 09:23:00+03	44000.00
29C9B6	2017-07-19 12:31:00+03	179500.00
29C9F9	2017-07-08 18:36:00+03	96800.00
29CAC3	2017-07-18 19:34:00+03	45200.00
29CAE4	2017-07-31 18:40:00+03	75600.00
29CAEF	2017-07-05 18:31:00+03	25600.00
29CB08	2017-07-25 02:26:00+03	283100.00
29CB83	2017-08-15 05:05:00+03	32200.00
29CBAB	2017-08-08 14:23:00+03	57600.00
29CBD4	2017-08-15 17:58:00+03	48100.00
29CC1D	2017-08-08 05:37:00+03	57100.00
29CC5A	2017-07-01 01:02:00+03	46800.00
29CC86	2017-07-12 19:53:00+03	65200.00
29CCCD	2017-07-25 05:13:00+03	29400.00
29CDA4	2017-07-08 01:08:00+03	70600.00
29CE6C	2017-08-09 13:05:00+03	28700.00
29CEE1	2017-07-30 02:50:00+03	84300.00
29CEED	2017-08-13 02:51:00+03	23200.00
29CF16	2017-07-30 15:31:00+03	27200.00
29CF2C	2017-07-12 14:37:00+03	51000.00
29CF39	2017-08-14 09:50:00+03	29900.00
29CF40	2017-07-01 12:23:00+03	38400.00
29CF9D	2017-07-20 11:55:00+03	28800.00
29D00E	2017-07-27 01:30:00+03	15800.00
29D040	2017-08-06 10:29:00+03	24400.00
29D094	2017-08-11 21:46:00+03	22800.00
29D139	2017-07-13 14:30:00+03	24400.00
29D1C0	2017-07-17 06:26:00+03	121800.00
29D1C5	2017-07-21 06:14:00+03	6800.00
29D225	2017-08-07 10:49:00+03	50600.00
29D278	2017-07-27 11:06:00+03	31900.00
29D310	2017-07-14 09:57:00+03	7400.00
29D32D	2017-08-08 16:15:00+03	24400.00
29D359	2017-07-28 18:41:00+03	114800.00
29D385	2017-07-18 20:50:00+03	25100.00
29D3AA	2017-07-21 16:04:00+03	42400.00
29D3C2	2017-07-17 02:25:00+03	102800.00
29D406	2017-07-25 01:58:00+03	59800.00
29D407	2017-08-03 03:01:00+03	50800.00
29D413	2017-07-19 00:07:00+03	26000.00
29D449	2017-07-20 00:10:00+03	75600.00
29D46B	2017-07-09 19:04:00+03	55800.00
29D476	2017-07-12 15:53:00+03	73600.00
29D488	2017-07-06 16:46:00+03	28800.00
29D4DF	2017-07-30 14:10:00+03	177200.00
29D4EB	2017-07-02 03:31:00+03	55800.00
29D59F	2017-08-14 10:27:00+03	32800.00
29D662	2017-07-09 20:33:00+03	32700.00
29D6F5	2017-08-06 09:54:00+03	190400.00
29D782	2017-08-10 22:23:00+03	6800.00
29D796	2017-08-04 16:51:00+03	151200.00
29D7C8	2017-07-11 03:50:00+03	31600.00
29D7F4	2017-07-17 19:37:00+03	36200.00
29D851	2017-08-15 13:09:00+03	14400.00
29D857	2017-07-11 01:52:00+03	39200.00
29D85B	2017-07-27 21:56:00+03	95900.00
29D8F8	2017-08-08 23:55:00+03	23600.00
29D94A	2017-08-15 11:58:00+03	115100.00
29D970	2017-07-12 08:24:00+03	16400.00
29D9B0	2017-08-04 14:51:00+03	137600.00
29D9D0	2017-07-03 20:33:00+03	72300.00
29D9D9	2017-08-07 14:50:00+03	406600.00
29DA06	2017-08-01 15:42:00+03	146100.00
29DA5A	2017-07-12 13:23:00+03	12400.00
29DB1F	2017-06-30 06:48:00+03	170500.00
29DB24	2017-07-29 06:08:00+03	26000.00
29DB95	2017-08-12 09:42:00+03	6000.00
29DC1C	2017-06-30 13:01:00+03	77000.00
29DC38	2017-08-15 12:51:00+03	12200.00
29DC8B	2017-08-12 08:52:00+03	81900.00
29DCC8	2017-07-21 17:29:00+03	199700.00
29DD41	2017-07-24 14:47:00+03	47200.00
29DD64	2017-07-24 15:59:00+03	43200.00
29DD74	2017-07-24 17:38:00+03	88100.00
29DE16	2017-08-08 20:13:00+03	49500.00
29DE1A	2017-07-23 21:41:00+03	125400.00
29DE73	2017-07-06 16:36:00+03	58000.00
29DEE1	2017-07-15 10:21:00+03	14800.00
29DF63	2017-07-03 06:42:00+03	28800.00
29DF85	2017-07-16 14:34:00+03	36400.00
29DFBD	2017-08-15 05:55:00+03	37900.00
29DFCB	2017-07-26 12:02:00+03	48800.00
29DFF0	2017-08-11 14:28:00+03	8200.00
29E045	2017-07-27 19:50:00+03	43400.00
29E071	2017-07-12 14:44:00+03	31600.00
29E082	2017-07-28 12:47:00+03	107400.00
29E0E0	2017-08-08 14:40:00+03	68800.00
29E0F3	2017-07-20 04:22:00+03	87900.00
29E10A	2017-07-09 04:05:00+03	51600.00
29E125	2017-08-01 10:09:00+03	48100.00
29E174	2017-07-11 10:47:00+03	28000.00
29E17D	2017-07-28 18:25:00+03	58900.00
29E180	2017-07-12 12:24:00+03	63700.00
29E19D	2017-08-13 09:41:00+03	46000.00
29E225	2017-07-27 16:35:00+03	12000.00
29E277	2017-07-17 05:35:00+03	12000.00
29E2A2	2017-07-05 20:18:00+03	237600.00
29E2C1	2017-07-10 16:01:00+03	78600.00
29E307	2017-08-13 15:47:00+03	24400.00
29E30B	2017-08-01 10:17:00+03	71900.00
29E34C	2017-08-02 05:25:00+03	240500.00
29E3A9	2017-08-02 20:07:00+03	84000.00
29E402	2017-08-12 11:49:00+03	59700.00
29E41B	2017-08-10 03:56:00+03	66600.00
29E46C	2017-08-13 11:45:00+03	35600.00
29E499	2017-07-28 08:28:00+03	51600.00
29E546	2017-07-28 02:57:00+03	30400.00
29E54B	2017-08-10 22:19:00+03	12000.00
29E572	2017-08-12 14:33:00+03	43200.00
29E575	2017-07-05 18:48:00+03	68000.00
29E58E	2017-07-24 16:49:00+03	284400.00
29E59E	2017-07-20 08:41:00+03	56100.00
29E660	2017-07-24 07:46:00+03	112600.00
29E6D8	2017-07-05 18:22:00+03	26200.00
29E727	2017-07-11 15:01:00+03	64600.00
29E793	2017-07-19 08:47:00+03	137700.00
29E7F9	2017-08-03 08:18:00+03	26700.00
29E81B	2017-07-23 16:15:00+03	48800.00
29E870	2017-07-23 19:36:00+03	25400.00
29E891	2017-07-09 05:00:00+03	28000.00
29E94A	2017-07-07 09:18:00+03	139400.00
29E95C	2017-07-29 03:49:00+03	38200.00
29E9E0	2017-07-31 23:18:00+03	40400.00
29EA04	2017-07-08 17:30:00+03	28800.00
29EA5D	2017-07-16 01:21:00+03	56000.00
29EA68	2017-07-14 06:11:00+03	8000.00
29EAEF	2017-07-31 00:34:00+03	11700.00
29EB25	2017-07-09 02:12:00+03	102100.00
29EBFD	2017-07-18 16:56:00+03	55800.00
29EC29	2017-07-06 20:17:00+03	8200.00
29EC39	2017-08-15 02:09:00+03	35200.00
29EC5C	2017-07-17 03:38:00+03	102100.00
29ECCF	2017-06-30 16:01:00+03	14000.00
29ED01	2017-07-11 20:34:00+03	23600.00
29ED20	2017-07-18 13:22:00+03	85200.00
29ED21	2017-07-14 11:17:00+03	122100.00
29EDBE	2017-07-10 19:43:00+03	99700.00
29EDE7	2017-07-28 20:33:00+03	11800.00
29EE25	2017-06-30 13:58:00+03	113200.00
29EE47	2017-07-11 19:21:00+03	70800.00
29EF37	2017-07-19 20:40:00+03	109000.00
29EF60	2017-08-12 20:15:00+03	12600.00
29EF79	2017-06-30 12:17:00+03	15400.00
29EF7A	2017-07-15 00:22:00+03	28000.00
29EFC0	2017-07-17 05:02:00+03	125200.00
29EFCE	2017-07-20 03:56:00+03	12000.00
29EFDC	2017-07-10 00:22:00+03	94700.00
29F126	2017-08-10 10:03:00+03	146000.00
29F137	2017-07-05 05:57:00+03	111400.00
29F13C	2017-07-09 02:43:00+03	20800.00
29F229	2017-08-02 10:52:00+03	57700.00
29F30F	2017-07-05 05:03:00+03	77000.00
29F310	2017-07-14 20:16:00+03	56000.00
29F313	2017-08-11 06:10:00+03	225800.00
29F373	2017-07-05 04:56:00+03	15800.00
29F3B5	2017-06-29 08:21:00+03	26800.00
29F3D1	2017-07-16 23:47:00+03	26800.00
29F3E3	2017-08-03 07:29:00+03	12200.00
29F3F6	2017-08-09 08:53:00+03	28800.00
29F443	2017-08-11 04:20:00+03	123000.00
29F4BA	2017-08-04 09:10:00+03	84100.00
29F4C2	2017-07-27 08:47:00+03	32800.00
29F517	2017-08-05 04:30:00+03	101200.00
29F560	2017-06-30 00:29:00+03	52300.00
29F582	2017-07-29 14:27:00+03	266400.00
29F58B	2017-07-24 21:04:00+03	202200.00
29F61D	2017-08-06 15:06:00+03	73600.00
29F629	2017-08-08 12:55:00+03	45100.00
29F638	2017-07-26 02:10:00+03	235400.00
29F6C8	2017-07-23 01:27:00+03	57600.00
29F6D0	2017-07-07 06:27:00+03	64000.00
29F6D2	2017-07-22 02:12:00+03	123000.00
29F713	2017-07-31 21:39:00+03	46400.00
29F721	2017-07-05 06:25:00+03	37100.00
29F726	2017-08-11 02:10:00+03	100600.00
29F752	2017-07-14 20:28:00+03	26700.00
29F820	2017-06-30 05:32:00+03	16400.00
29F866	2017-08-11 14:06:00+03	62600.00
29F89D	2017-07-04 15:08:00+03	24700.00
29F8B9	2017-06-29 18:33:00+03	20200.00
29F93B	2017-07-29 14:41:00+03	294200.00
29F954	2017-08-13 14:42:00+03	42800.00
29F998	2017-07-24 06:09:00+03	43300.00
29F9A7	2017-07-31 06:40:00+03	49100.00
29F9BB	2017-07-16 05:53:00+03	139600.00
29F9D4	2017-08-10 22:01:00+03	28000.00
29FAD8	2017-07-22 17:19:00+03	25000.00
29FAEB	2017-08-01 14:13:00+03	269200.00
29FB1F	2017-07-08 10:12:00+03	46300.00
29FB41	2017-07-24 14:32:00+03	77500.00
29FB47	2017-07-11 20:31:00+03	124200.00
29FB60	2017-06-28 00:57:00+03	23600.00
29FBC5	2017-07-15 05:43:00+03	12600.00
29FBC9	2017-08-01 17:40:00+03	142400.00
29FBCA	2017-07-31 03:39:00+03	133600.00
29FBCE	2017-07-27 08:35:00+03	114600.00
29FCA4	2017-08-11 15:48:00+03	13400.00
29FCAE	2017-07-01 13:18:00+03	12600.00
29FCB5	2017-07-20 19:19:00+03	67200.00
29FCD8	2017-07-08 09:35:00+03	369000.00
29FD06	2017-07-14 04:14:00+03	56000.00
29FD6D	2017-07-31 12:28:00+03	30700.00
29FE13	2017-07-20 01:27:00+03	55400.00
29FE77	2017-07-07 07:30:00+03	58900.00
29FE7C	2017-07-04 08:37:00+03	73300.00
29FE9B	2017-07-31 22:37:00+03	55800.00
29FEC5	2017-07-23 20:27:00+03	20600.00
29FEF7	2017-07-16 04:30:00+03	35700.00
29FF30	2017-07-02 03:37:00+03	6700.00
29FF53	2017-07-17 09:14:00+03	53700.00
29FFE7	2017-07-01 18:42:00+03	92700.00
2A006C	2017-07-16 23:58:00+03	44000.00
2A00B9	2017-08-11 03:56:00+03	52300.00
2A00F3	2017-07-01 16:22:00+03	136200.00
2A0107	2017-07-31 15:18:00+03	32700.00
2A0111	2017-06-30 11:46:00+03	56000.00
2A0190	2017-07-29 03:52:00+03	12600.00
2A01A0	2017-07-09 19:12:00+03	57800.00
2A01BB	2017-07-12 17:46:00+03	92600.00
2A0206	2017-08-06 11:07:00+03	14400.00
2A0281	2017-07-08 11:18:00+03	83000.00
2A028D	2017-07-23 23:09:00+03	23400.00
2A0292	2017-07-08 04:26:00+03	46300.00
2A02E3	2017-07-26 21:06:00+03	62600.00
2A031F	2017-07-04 12:40:00+03	46000.00
2A0337	2017-07-04 20:49:00+03	61400.00
2A0363	2017-07-06 18:33:00+03	135200.00
2A03A1	2017-07-25 11:00:00+03	70800.00
2A0408	2017-07-17 01:09:00+03	58200.00
2A040B	2017-07-18 07:38:00+03	92600.00
2A041C	2017-08-06 04:52:00+03	56200.00
2A042F	2017-07-26 02:00:00+03	88400.00
2A047A	2017-07-20 03:59:00+03	83700.00
2A0488	2017-08-12 01:55:00+03	28300.00
2A048B	2017-07-13 20:09:00+03	82900.00
2A04B9	2017-08-07 21:34:00+03	32200.00
2A0508	2017-07-12 22:56:00+03	115400.00
2A052D	2017-07-31 11:09:00+03	46000.00
2A0596	2017-07-30 02:18:00+03	38600.00
2A05D6	2017-07-30 08:15:00+03	45200.00
2A05EA	2017-07-13 02:40:00+03	116000.00
2A0695	2017-07-07 12:26:00+03	25600.00
2A06B8	2017-08-12 14:31:00+03	125400.00
2A0708	2017-08-11 14:58:00+03	6700.00
2A0724	2017-07-22 17:33:00+03	8400.00
2A0770	2017-07-27 16:23:00+03	23200.00
2A077A	2017-07-26 18:18:00+03	76600.00
2A07F0	2017-07-19 07:09:00+03	185300.00
2A0849	2017-08-14 09:41:00+03	14400.00
2A0878	2017-07-21 05:53:00+03	35600.00
2A089B	2017-07-29 18:36:00+03	46400.00
2A08DF	2017-07-30 17:39:00+03	56000.00
2A08FD	2017-07-08 07:26:00+03	172100.00
2A0973	2017-08-10 23:30:00+03	89700.00
2A0A61	2017-07-05 08:28:00+03	283500.00
2A0AF1	2017-08-13 17:35:00+03	27800.00
2A0AFA	2017-08-10 10:31:00+03	38400.00
2A0AFF	2017-08-05 13:26:00+03	92900.00
2A0B1D	2017-08-01 21:39:00+03	420500.00
2A0B29	2017-07-10 17:40:00+03	102300.00
2A0B89	2017-08-14 17:20:00+03	102100.00
2A0BA1	2017-07-18 12:18:00+03	111900.00
2A0BA5	2017-07-03 20:11:00+03	30200.00
2A0C55	2017-07-10 16:41:00+03	40800.00
2A0C57	2017-07-03 07:28:00+03	652800.00
2A0C66	2017-08-04 19:50:00+03	69500.00
2A0C81	2017-07-22 08:22:00+03	72400.00
2A0CF8	2017-08-08 14:48:00+03	89700.00
2A0D09	2017-07-10 16:40:00+03	12400.00
2A0D22	2017-06-30 11:40:00+03	26000.00
2A0D6C	2017-08-03 02:23:00+03	66600.00
2A0E4B	2017-08-15 14:47:00+03	52700.00
2A0E4E	2017-08-02 13:37:00+03	231300.00
2A0EEE	2017-08-08 04:01:00+03	100000.00
2A0F06	2017-08-04 05:23:00+03	155600.00
2A0F66	2017-07-29 19:48:00+03	81600.00
2A0FC7	2017-07-09 03:01:00+03	54800.00
2A0FD8	2017-07-15 03:03:00+03	23900.00
2A0FE7	2017-07-20 11:17:00+03	45100.00
2A100C	2017-08-03 02:30:00+03	30800.00
2A1047	2017-07-12 12:30:00+03	35600.00
2A10C2	2017-07-06 03:14:00+03	52700.00
2A1134	2017-06-25 03:41:00+03	64400.00
2A118B	2017-07-23 17:18:00+03	75600.00
2A11C8	2017-08-14 06:32:00+03	228300.00
2A120C	2017-07-25 17:21:00+03	7200.00
2A1223	2017-07-09 10:58:00+03	205600.00
2A1350	2017-07-13 09:43:00+03	123900.00
2A1371	2017-08-14 20:51:00+03	25100.00
2A137B	2017-08-02 14:56:00+03	175300.00
2A13CF	2017-07-18 03:02:00+03	98800.00
2A1407	2017-07-27 01:25:00+03	45400.00
2A142A	2017-07-16 07:23:00+03	180400.00
2A147B	2017-08-06 08:47:00+03	39500.00
2A1526	2017-08-13 13:14:00+03	61800.00
2A1551	2017-07-21 13:52:00+03	6000.00
2A155C	2017-07-25 15:41:00+03	77800.00
2A1581	2017-08-01 17:41:00+03	6800.00
2A15A7	2017-08-06 04:48:00+03	114400.00
2A15E7	2017-07-08 03:30:00+03	56000.00
2A1645	2017-08-06 13:59:00+03	106100.00
2A1654	2017-07-15 10:36:00+03	97900.00
2A1687	2017-07-13 16:13:00+03	40000.00
2A16C3	2017-07-03 11:52:00+03	26100.00
2A1786	2017-08-09 11:57:00+03	24300.00
2A17C9	2017-08-02 08:29:00+03	46200.00
2A1843	2017-07-18 11:30:00+03	136600.00
2A1856	2017-07-26 06:05:00+03	54000.00
2A1862	2017-08-14 20:42:00+03	28000.00
2A1884	2017-07-02 14:29:00+03	28800.00
2A1912	2017-07-16 16:50:00+03	49200.00
2A192C	2017-07-18 19:44:00+03	92700.00
2A193E	2017-07-07 19:43:00+03	113200.00
2A197D	2017-07-15 11:47:00+03	17600.00
2A1A02	2017-07-29 06:46:00+03	187600.00
2A1AC3	2017-08-05 00:52:00+03	110000.00
2A1B19	2017-07-21 15:38:00+03	48100.00
2A1B1D	2017-07-05 21:02:00+03	56600.00
2A1B20	2017-07-16 14:26:00+03	25100.00
2A1B4B	2017-07-09 00:07:00+03	26000.00
2A1B5E	2017-07-14 11:45:00+03	84100.00
2A1B6E	2017-07-15 17:07:00+03	135400.00
2A1B9F	2017-08-15 14:26:00+03	54500.00
2A1BC4	2017-07-31 04:51:00+03	48800.00
2A1C0F	2017-07-28 00:17:00+03	28800.00
2A1C30	2017-07-05 11:33:00+03	112000.00
2A1CAA	2017-07-21 03:46:00+03	156500.00
2A1CD7	2017-07-22 03:49:00+03	84800.00
2A1D1F	2017-08-11 16:25:00+03	73300.00
2A1DA5	2017-08-14 05:21:00+03	8400.00
2A1DA8	2017-07-25 01:30:00+03	69600.00
2A1DD3	2017-06-28 04:52:00+03	71000.00
2A1DE6	2017-08-05 21:00:00+03	10800.00
2A1E63	2017-07-11 13:58:00+03	40200.00
2A1ED9	2017-08-13 14:04:00+03	56000.00
2A1F2A	2017-08-11 18:13:00+03	26000.00
2A1F37	2017-07-06 12:21:00+03	23600.00
2A1F88	2017-07-05 00:19:00+03	65100.00
2A1FA8	2017-07-21 23:36:00+03	36200.00
2A1FD6	2017-06-24 05:23:00+03	28800.00
2A1FF5	2017-07-28 18:20:00+03	23200.00
2A203F	2017-07-24 13:36:00+03	48700.00
2A20C6	2017-08-14 21:54:00+03	51000.00
2A20C7	2017-06-29 15:05:00+03	117200.00
2A2156	2017-08-12 00:22:00+03	112000.00
2A21AB	2017-07-21 06:55:00+03	41900.00
2A21C2	2017-08-02 22:19:00+03	37900.00
2A2219	2017-07-30 17:20:00+03	22000.00
2A227B	2017-08-06 06:14:00+03	73300.00
2A22B2	2017-06-29 17:07:00+03	47700.00
2A22C5	2017-07-06 01:04:00+03	14400.00
2A22DC	2017-08-06 19:07:00+03	25800.00
2A2300	2017-07-27 00:38:00+03	111600.00
2A231F	2017-07-18 10:00:00+03	123600.00
2A23C7	2017-08-06 18:16:00+03	23600.00
2A23EE	2017-07-23 21:47:00+03	68800.00
2A23FD	2017-07-04 17:46:00+03	265700.00
2A2536	2017-07-10 06:47:00+03	394400.00
2A254D	2017-07-19 10:53:00+03	62000.00
2A2573	2017-08-02 14:13:00+03	70600.00
2A25FF	2017-08-11 04:29:00+03	10800.00
2A2625	2017-07-03 03:34:00+03	117200.00
2A263E	2017-07-30 11:38:00+03	104200.00
2A2680	2017-07-11 07:49:00+03	134200.00
2A26A3	2017-07-27 08:49:00+03	6600.00
2A26B6	2017-07-23 19:11:00+03	28000.00
2A2701	2017-08-02 06:38:00+03	111600.00
2A276C	2017-08-13 09:36:00+03	81600.00
2A27AD	2017-08-13 17:19:00+03	20400.00
2A283B	2017-08-14 04:10:00+03	61800.00
2A2852	2017-07-05 12:39:00+03	70700.00
2A2865	2017-08-03 21:41:00+03	122800.00
2A2874	2017-07-22 14:56:00+03	38600.00
2A28D5	2017-07-14 00:38:00+03	24400.00
2A29D4	2017-08-09 01:20:00+03	74800.00
2A2A13	2017-07-07 19:04:00+03	28600.00
2A2A42	2017-07-23 15:55:00+03	133200.00
2A2A7F	2017-08-12 15:57:00+03	15400.00
2A2A9E	2017-07-19 05:50:00+03	13400.00
2A2AB4	2017-07-26 04:46:00+03	62600.00
2A2B18	2017-07-25 15:26:00+03	20200.00
2A2B7D	2017-07-28 16:27:00+03	135600.00
2A2B7F	2017-07-22 06:40:00+03	26600.00
2A2B83	2017-07-18 19:39:00+03	62100.00
2A2BAD	2017-07-10 11:26:00+03	170800.00
2A2C13	2017-08-12 01:21:00+03	24200.00
2A2C36	2017-07-03 23:47:00+03	290600.00
2A2C38	2017-08-10 13:29:00+03	369000.00
2A2CA2	2017-07-07 14:24:00+03	108100.00
2A2CB4	2017-08-14 09:15:00+03	75300.00
2A2D17	2017-07-23 03:05:00+03	193600.00
2A2D4B	2017-08-14 02:17:00+03	29000.00
2A2D9A	2017-08-05 13:03:00+03	215200.00
2A2E1F	2017-07-29 12:22:00+03	104200.00
2A2EEA	2017-07-16 03:46:00+03	18600.00
2A2F2E	2017-07-16 21:45:00+03	29600.00
2A2F67	2017-07-22 14:04:00+03	53700.00
2A3093	2017-07-19 06:29:00+03	65900.00
2A30FF	2017-08-14 17:53:00+03	28300.00
2A3100	2017-07-29 12:23:00+03	64300.00
2A3114	2017-08-07 01:54:00+03	427400.00
2A3126	2017-07-24 18:30:00+03	131100.00
2A3132	2017-07-21 02:22:00+03	69000.00
2A3145	2017-07-03 19:19:00+03	46000.00
2A31C3	2017-07-22 12:03:00+03	14400.00
2A3225	2017-07-21 02:39:00+03	62600.00
2A3236	2017-07-02 02:22:00+03	102800.00
2A32EF	2017-07-12 16:16:00+03	22600.00
2A32FF	2017-07-21 08:30:00+03	24400.00
2A337A	2017-08-10 00:19:00+03	100600.00
2A3380	2017-08-02 14:08:00+03	56000.00
2A33B8	2017-07-22 08:53:00+03	133100.00
2A33E9	2017-07-17 19:27:00+03	172700.00
2A3402	2017-07-19 15:27:00+03	86500.00
2A343E	2017-07-11 07:16:00+03	19800.00
2A34B2	2017-07-16 05:43:00+03	136800.00
2A34FA	2017-07-28 19:22:00+03	306500.00
2A3500	2017-07-22 16:44:00+03	22400.00
2A3552	2017-07-01 07:46:00+03	92800.00
2A35B1	2017-07-10 19:06:00+03	37900.00
2A35D8	2017-07-10 16:12:00+03	71400.00
2A3606	2017-07-22 06:52:00+03	36900.00
2A3648	2017-07-12 17:22:00+03	57500.00
2A364E	2017-07-26 21:16:00+03	37900.00
2A3658	2017-08-01 10:16:00+03	40800.00
2A365F	2017-08-11 04:50:00+03	44500.00
2A3690	2017-08-09 23:05:00+03	33300.00
2A36C8	2017-07-20 18:14:00+03	173500.00
2A370A	2017-07-09 05:05:00+03	132300.00
2A3749	2017-08-10 22:51:00+03	40400.00
2A37E5	2017-07-11 00:33:00+03	258400.00
2A38FC	2017-07-11 05:12:00+03	119500.00
2A3910	2017-08-15 12:44:00+03	95400.00
2A392A	2017-07-20 16:25:00+03	72200.00
2A3932	2017-08-12 06:32:00+03	43100.00
2A3991	2017-07-02 18:57:00+03	14800.00
2A3A1B	2017-07-29 07:02:00+03	28000.00
2A3A2B	2017-08-08 12:34:00+03	56600.00
2A3A3C	2017-08-08 16:38:00+03	36800.00
2A3A4B	2017-07-16 03:45:00+03	30800.00
2A3A81	2017-07-09 06:33:00+03	92800.00
2A3AB6	2017-08-11 23:25:00+03	265600.00
2A3AE9	2017-07-11 08:57:00+03	21200.00
2A3B05	2017-08-15 15:26:00+03	8400.00
2A3B07	2017-07-29 23:39:00+03	29600.00
2A3B75	2017-08-03 22:35:00+03	131100.00
2A3B89	2017-07-16 04:57:00+03	12200.00
2A3BCE	2017-08-01 13:37:00+03	26000.00
2A3BD1	2017-07-17 03:27:00+03	38400.00
2A3BFA	2017-07-18 00:29:00+03	52300.00
2A3C1F	2017-07-13 11:06:00+03	58000.00
2A3C81	2017-07-13 17:39:00+03	101200.00
2A3C85	2017-08-02 13:55:00+03	30200.00
2A3CC6	2017-08-10 20:11:00+03	46000.00
2A3CD2	2017-07-29 16:15:00+03	28800.00
2A3CF5	2017-08-01 06:55:00+03	94000.00
2A3D69	2017-07-08 06:59:00+03	73000.00
2A3D81	2017-07-23 11:58:00+03	46000.00
2A3D8B	2017-08-02 16:19:00+03	153300.00
2A3DDF	2017-08-07 01:26:00+03	48100.00
2A3E0E	2017-08-10 14:55:00+03	46400.00
2A3E3F	2017-07-10 08:21:00+03	36200.00
2A3E9A	2017-07-26 10:35:00+03	92900.00
2A3EC0	2017-07-16 23:42:00+03	25400.00
2A3EC4	2017-07-19 01:36:00+03	24400.00
2A3EC7	2017-07-07 01:56:00+03	68800.00
2A3EEA	2017-08-02 17:40:00+03	42700.00
2A3F0A	2017-07-24 14:49:00+03	160500.00
2A3F38	2017-08-01 03:56:00+03	39200.00
2A3F5C	2017-07-27 04:30:00+03	16400.00
2A3FA5	2017-07-04 19:51:00+03	45400.00
2A407C	2017-07-14 15:02:00+03	246000.00
2A40EA	2017-08-05 01:22:00+03	155600.00
2A40EB	2017-08-10 20:37:00+03	25100.00
2A411B	2017-07-29 07:09:00+03	129200.00
2A414C	2017-07-16 00:26:00+03	40600.00
2A4191	2017-08-10 21:56:00+03	28000.00
2A4198	2017-07-07 21:44:00+03	223200.00
2A41AB	2017-07-04 23:31:00+03	184200.00
2A41B5	2017-07-19 14:39:00+03	23200.00
2A41E4	2017-07-03 00:00:00+03	33100.00
2A421C	2017-07-22 12:07:00+03	123000.00
2A421F	2017-08-05 12:51:00+03	99400.00
2A4234	2017-07-01 11:40:00+03	41400.00
2A42D3	2017-08-13 13:33:00+03	77400.00
2A42E6	2017-07-09 20:22:00+03	50800.00
2A42FE	2017-08-09 21:34:00+03	134400.00
2A4331	2017-06-30 05:09:00+03	23200.00
2A433E	2017-07-26 02:34:00+03	76300.00
2A4398	2017-07-08 09:30:00+03	133200.00
2A43CF	2017-07-12 00:33:00+03	24600.00
2A442C	2017-07-03 11:36:00+03	27400.00
2A444A	2017-07-21 16:44:00+03	67400.00
2A444F	2017-07-20 11:57:00+03	6000.00
2A4456	2017-06-30 07:56:00+03	406700.00
2A4494	2017-07-12 19:19:00+03	55900.00
2A44FB	2017-08-11 17:09:00+03	31400.00
2A4511	2017-07-29 19:01:00+03	31600.00
2A4514	2017-07-12 21:25:00+03	13400.00
2A4518	2017-08-11 19:01:00+03	58800.00
2A455B	2017-07-25 14:49:00+03	244000.00
2A4599	2017-07-30 09:37:00+03	123000.00
2A45B0	2017-07-31 01:31:00+03	26800.00
2A45F1	2017-07-12 08:36:00+03	40100.00
2A461F	2017-07-05 11:27:00+03	137600.00
2A46FD	2017-08-05 20:21:00+03	57600.00
2A46FF	2017-07-06 14:19:00+03	4000.00
2A4742	2017-07-15 10:51:00+03	266300.00
2A4792	2017-08-08 08:47:00+03	21600.00
2A47D5	2017-07-02 01:59:00+03	39600.00
2A47FC	2017-08-01 00:32:00+03	131600.00
2A4823	2017-08-13 14:45:00+03	54500.00
2A4836	2017-07-27 02:02:00+03	26600.00
2A487A	2017-07-16 09:35:00+03	133200.00
2A48B5	2017-07-27 23:42:00+03	49600.00
2A48C7	2017-08-04 02:17:00+03	28000.00
2A48C9	2017-08-08 08:13:00+03	20400.00
2A48CC	2017-06-29 05:28:00+03	30000.00
2A4909	2017-07-07 11:39:00+03	111600.00
2A4A01	2017-07-03 01:47:00+03	28800.00
2A4A28	2017-08-13 05:09:00+03	167200.00
2A4ABA	2017-07-20 00:26:00+03	62600.00
2A4ADE	2017-07-10 14:32:00+03	55800.00
2A4BAD	2017-07-12 03:28:00+03	55600.00
2A4C1B	2017-07-24 05:28:00+03	34000.00
2A4C5E	2017-07-30 12:37:00+03	358800.00
2A4C94	2017-07-04 07:34:00+03	54500.00
2A4CA5	2017-07-28 21:40:00+03	52700.00
2A4CBD	2017-07-27 16:22:00+03	82900.00
2A4CBE	2017-08-04 01:27:00+03	26000.00
2A4D14	2017-07-17 16:02:00+03	24400.00
2A4D3F	2017-07-30 21:37:00+03	44800.00
2A4D54	2017-07-06 14:55:00+03	28600.00
2A4DC7	2017-08-10 12:06:00+03	65900.00
2A4DEB	2017-07-13 20:01:00+03	16400.00
2A4E1D	2017-07-02 10:11:00+03	21600.00
2A4E97	2017-07-30 18:55:00+03	36200.00
2A4EC8	2017-07-13 10:54:00+03	67100.00
2A4ECE	2017-08-10 18:54:00+03	286600.00
2A4EE4	2017-07-09 02:11:00+03	391600.00
2A4EFF	2017-07-28 04:22:00+03	34000.00
2A4F17	2017-08-06 16:46:00+03	31600.00
2A4F2B	2017-07-22 13:55:00+03	31200.00
2A4F2F	2017-08-12 16:43:00+03	70800.00
2A4F94	2017-07-27 12:46:00+03	46800.00
2A5007	2017-07-31 16:35:00+03	54800.00
2A50A5	2017-08-01 09:25:00+03	66000.00
2A5104	2017-07-27 20:43:00+03	28000.00
2A5122	2017-08-14 15:28:00+03	24400.00
2A5126	2017-08-07 02:45:00+03	28000.00
2A5163	2017-07-11 22:42:00+03	34200.00
2A5181	2017-08-14 08:02:00+03	11000.00
2A51DB	2017-07-13 00:44:00+03	68700.00
2A51E7	2017-07-10 06:41:00+03	65500.00
2A5200	2017-08-15 13:35:00+03	6600.00
2A522F	2017-08-02 08:35:00+03	60600.00
2A52E2	2017-07-21 19:02:00+03	40200.00
2A531E	2017-08-09 00:38:00+03	70200.00
2A5356	2017-07-09 08:39:00+03	402400.00
2A53D8	2017-08-07 04:10:00+03	37200.00
2A5436	2017-07-08 14:02:00+03	66600.00
2A54B0	2017-07-02 11:28:00+03	30700.00
2A5578	2017-07-26 00:01:00+03	170300.00
2A5624	2017-08-05 01:49:00+03	78200.00
2A5746	2017-08-09 02:10:00+03	50100.00
2A57E4	2017-08-09 18:31:00+03	137700.00
2A5805	2017-08-10 05:44:00+03	52800.00
2A5846	2017-07-26 22:53:00+03	101200.00
2A5856	2017-07-05 09:00:00+03	92000.00
2A58F3	2017-08-08 19:46:00+03	8000.00
2A594F	2017-07-21 19:05:00+03	135600.00
2A5955	2017-07-20 15:19:00+03	64400.00
2A5969	2017-07-18 00:25:00+03	135400.00
2A598B	2017-07-26 17:54:00+03	46400.00
2A59CF	2017-07-29 13:59:00+03	56000.00
2A59FB	2017-07-18 02:06:00+03	103500.00
2A5A03	2017-07-03 10:33:00+03	70700.00
2A5A84	2017-07-15 11:00:00+03	41200.00
2A5A98	2017-07-13 07:00:00+03	24400.00
2A5AAB	2017-07-03 23:42:00+03	46400.00
2A5B30	2017-07-25 11:58:00+03	6000.00
2A5BA3	2017-08-06 22:42:00+03	14000.00
2A5BB8	2017-07-05 06:11:00+03	92700.00
2A5BC7	2017-08-11 18:18:00+03	28000.00
2A5C1B	2017-07-31 13:00:00+03	45200.00
2A5C1F	2017-07-10 20:31:00+03	532800.00
2A5C7F	2017-08-07 22:02:00+03	189200.00
2A5CC4	2017-08-04 06:02:00+03	30200.00
2A5D6C	2017-07-09 11:52:00+03	66000.00
2A5DB8	2017-07-16 18:10:00+03	47000.00
2A5E03	2017-08-10 08:36:00+03	28000.00
2A5E10	2017-08-06 15:13:00+03	134000.00
2A5E17	2017-08-05 23:28:00+03	55800.00
2A5E34	2017-07-08 13:51:00+03	144600.00
2A5E8D	2017-08-01 13:18:00+03	81300.00
2A5EA9	2017-08-05 14:36:00+03	20400.00
2A5EAE	2017-07-29 10:06:00+03	47700.00
2A5EBD	2017-07-10 19:18:00+03	59000.00
2A5F46	2017-07-31 22:38:00+03	85000.00
2A5F91	2017-07-17 02:20:00+03	61800.00
2A5FAC	2017-07-17 00:44:00+03	6000.00
2A6003	2017-08-08 14:46:00+03	29400.00
2A602A	2017-07-21 09:03:00+03	93500.00
2A6065	2017-08-14 23:34:00+03	96800.00
2A6066	2017-08-09 22:15:00+03	23600.00
2A6070	2017-07-06 21:20:00+03	44000.00
2A61C5	2017-08-05 12:24:00+03	88600.00
2A61D8	2017-08-12 07:10:00+03	21800.00
2A61DA	2017-07-09 16:04:00+03	79600.00
2A624E	2017-07-30 15:59:00+03	31800.00
2A6278	2017-07-03 07:18:00+03	6600.00
2A62A7	2017-07-09 06:42:00+03	123000.00
2A62FF	2017-07-06 11:07:00+03	129200.00
2A634F	2017-08-12 23:12:00+03	78800.00
2A6456	2017-08-05 05:02:00+03	61800.00
2A6480	2017-07-23 16:09:00+03	163900.00
2A65A2	2017-08-11 13:29:00+03	39800.00
2A65AE	2017-07-09 02:32:00+03	14800.00
2A65BD	2017-07-01 14:12:00+03	58800.00
2A65C2	2017-07-21 00:35:00+03	62600.00
2A6686	2017-08-01 12:59:00+03	67400.00
2A6695	2017-08-01 19:22:00+03	26000.00
2A677A	2017-07-02 04:38:00+03	14000.00
2A67B8	2017-08-10 06:33:00+03	22000.00
2A683B	2017-08-05 00:07:00+03	59800.00
2A6854	2017-07-11 14:58:00+03	13400.00
2A6876	2017-08-12 03:29:00+03	67600.00
2A68C6	2017-07-29 10:06:00+03	95600.00
2A6916	2017-07-22 19:57:00+03	15400.00
2A6969	2017-08-09 03:12:00+03	16400.00
2A6A2D	2017-08-01 13:30:00+03	25600.00
2A6A9F	2017-07-06 14:43:00+03	14400.00
2A6AB1	2017-08-02 18:12:00+03	20200.00
2A6B53	2017-07-28 18:08:00+03	8400.00
2A6B54	2017-07-14 00:05:00+03	59200.00
2A6B60	2017-07-15 05:09:00+03	94800.00
2A6B6F	2017-07-27 10:48:00+03	10600.00
2A6B90	2017-07-05 14:28:00+03	27200.00
2A6C7F	2017-07-08 18:27:00+03	51300.00
2A6C94	2017-07-19 16:27:00+03	65600.00
2A6CFC	2017-07-28 10:48:00+03	44800.00
2A6D05	2017-07-13 03:08:00+03	147100.00
2A6D0F	2017-07-16 03:22:00+03	64700.00
2A6D49	2017-07-30 21:04:00+03	77100.00
2A6D56	2017-07-20 12:08:00+03	39900.00
2A6D6C	2017-07-29 18:34:00+03	16400.00
2A6DD5	2017-07-07 23:21:00+03	94900.00
2A6E0A	2017-08-10 08:30:00+03	100000.00
2A6E20	2017-07-07 23:06:00+03	69600.00
2A6E3B	2017-07-14 15:45:00+03	529700.00
2A6F06	2017-08-15 01:15:00+03	53100.00
2A6F28	2017-07-28 16:58:00+03	12200.00
2A6F78	2017-07-05 18:43:00+03	142400.00
2A6FA9	2017-07-31 10:06:00+03	124200.00
2A6FC5	2017-07-06 08:44:00+03	33300.00
2A6FEF	2017-07-15 05:13:00+03	37600.00
2A7004	2017-07-04 05:23:00+03	73200.00
2A701C	2017-07-02 02:27:00+03	56100.00
2A7049	2017-07-06 23:44:00+03	428900.00
2A70B3	2017-07-14 04:53:00+03	65400.00
2A70F5	2017-07-12 16:08:00+03	124300.00
2A70F8	2017-08-08 00:23:00+03	19000.00
2A711D	2017-07-16 21:21:00+03	27500.00
2A7164	2017-08-11 20:07:00+03	8200.00
2A7176	2017-07-14 14:30:00+03	26000.00
2A71D6	2017-07-30 18:06:00+03	57600.00
2A721E	2017-07-23 09:23:00+03	55800.00
2A7226	2017-08-13 09:05:00+03	43000.00
2A7295	2017-07-08 08:04:00+03	64600.00
2A72C4	2017-08-07 20:06:00+03	55800.00
2A72CE	2017-07-29 21:40:00+03	135600.00
2A72D7	2017-08-03 13:06:00+03	6800.00
2A72FC	2017-08-07 23:12:00+03	24800.00
2A730A	2017-08-03 20:07:00+03	232800.00
2A7312	2017-08-15 15:34:00+03	75000.00
2A736D	2017-07-15 16:33:00+03	6300.00
2A73A1	2017-07-04 09:01:00+03	46200.00
2A74D2	2017-08-03 21:15:00+03	67000.00
2A74D7	2017-07-31 10:35:00+03	14000.00
2A7512	2017-08-15 09:53:00+03	133200.00
2A7548	2017-08-04 03:28:00+03	52700.00
2A75E3	2017-08-01 16:50:00+03	159100.00
2A75FC	2017-07-26 07:36:00+03	12600.00
2A7638	2017-07-04 02:53:00+03	44500.00
2A7649	2017-07-29 13:20:00+03	220100.00
2A7657	2017-07-14 10:16:00+03	19600.00
2A765E	2017-07-10 07:27:00+03	103000.00
2A76AE	2017-07-22 17:15:00+03	58600.00
2A76B3	2017-06-30 21:45:00+03	25600.00
2A773E	2017-07-19 05:37:00+03	27200.00
2A7775	2017-07-29 17:00:00+03	148100.00
2A7783	2017-07-09 20:16:00+03	24400.00
2A77B5	2017-08-08 05:39:00+03	189800.00
2A782D	2017-08-04 23:12:00+03	12600.00
2A7838	2017-07-11 17:49:00+03	199700.00
2A78AF	2017-07-25 07:59:00+03	60400.00
2A7945	2017-07-21 14:43:00+03	14400.00
2A7947	2017-07-07 14:16:00+03	54700.00
2A7981	2017-07-16 17:53:00+03	26000.00
2A7A44	2017-07-19 17:02:00+03	36200.00
2A7A82	2017-08-01 18:45:00+03	8000.00
2A7AA7	2017-08-09 19:48:00+03	119800.00
2A7B0C	2017-07-06 06:46:00+03	26500.00
2A7B0D	2017-07-27 02:13:00+03	266400.00
2A7B1B	2017-08-02 01:36:00+03	108900.00
2A7B4E	2017-07-07 09:32:00+03	258400.00
2A7B67	2017-08-07 20:40:00+03	96200.00
2A7C9B	2017-07-01 20:18:00+03	56900.00
2A7C9D	2017-08-12 00:48:00+03	289800.00
2A7CB0	2017-07-05 21:15:00+03	154400.00
2A7CD2	2017-07-10 19:24:00+03	59200.00
2A7CF0	2017-07-23 11:15:00+03	33600.00
2A7D1B	2017-07-31 14:44:00+03	93900.00
2A7D79	2017-08-02 06:04:00+03	100000.00
2A7D9A	2017-08-04 00:09:00+03	43900.00
2A7DC6	2017-07-20 19:33:00+03	39400.00
2A7DDA	2017-07-30 21:09:00+03	19600.00
2A7DEC	2017-07-23 16:24:00+03	6800.00
2A7E06	2017-07-28 07:50:00+03	38400.00
2A7EC1	2017-08-15 12:12:00+03	114800.00
2A7F03	2017-08-09 20:55:00+03	60600.00
2A7F0D	2017-07-17 01:18:00+03	174900.00
2A7F26	2017-07-06 02:04:00+03	57600.00
2A7F2E	2017-07-19 00:21:00+03	240600.00
2A7F9B	2017-08-11 00:09:00+03	23200.00
2A7FCB	2017-08-04 14:33:00+03	129700.00
2A8035	2017-07-31 23:10:00+03	173500.00
2A8057	2017-08-03 14:33:00+03	85000.00
2A805F	2017-08-15 00:10:00+03	305800.00
2A80FB	2017-08-11 14:32:00+03	67200.00
2A810A	2017-08-05 03:32:00+03	67600.00
2A81C6	2017-07-11 04:36:00+03	18800.00
2A81EA	2017-07-30 05:34:00+03	133100.00
2A8222	2017-08-05 05:18:00+03	160200.00
2A8237	2017-07-21 05:44:00+03	27600.00
2A8246	2017-07-26 07:51:00+03	46400.00
2A827A	2017-07-10 02:01:00+03	147700.00
2A828C	2017-07-20 03:55:00+03	64600.00
2A8331	2017-08-13 10:22:00+03	7200.00
2A8354	2017-07-15 10:07:00+03	58400.00
2A835C	2017-07-12 17:30:00+03	140100.00
2A838F	2017-07-02 22:15:00+03	80500.00
2A8394	2017-08-11 02:19:00+03	84500.00
2A83CA	2017-08-05 09:41:00+03	68800.00
2A8447	2017-07-20 19:27:00+03	40000.00
2A84C4	2017-07-14 09:18:00+03	43200.00
2A84FB	2017-08-13 18:21:00+03	29600.00
2A85F4	2017-07-18 13:36:00+03	24800.00
2A862F	2017-08-06 02:05:00+03	46400.00
2A8663	2017-08-13 06:39:00+03	123000.00
2A8672	2017-07-09 19:31:00+03	90000.00
2A86E6	2017-07-25 12:50:00+03	87200.00
2A86ED	2017-08-10 22:18:00+03	41800.00
2A873B	2017-07-22 02:21:00+03	29600.00
2A873D	2017-07-18 16:46:00+03	123000.00
2A876B	2017-07-03 15:07:00+03	16400.00
2A876E	2017-08-14 04:28:00+03	139100.00
2A876F	2017-08-12 23:24:00+03	68400.00
2A87B8	2017-07-19 16:15:00+03	118700.00
2A87BF	2017-08-05 07:15:00+03	67700.00
2A87DC	2017-07-21 13:36:00+03	291000.00
2A8801	2017-08-05 18:13:00+03	168000.00
2A882E	2017-07-19 13:19:00+03	10700.00
2A8871	2017-07-11 11:41:00+03	39800.00
2A8883	2017-07-17 13:27:00+03	24400.00
2A888F	2017-07-17 22:24:00+03	40100.00
2A88E5	2017-07-17 21:26:00+03	72500.00
2A8924	2017-07-19 19:40:00+03	46800.00
2A8947	2017-08-08 02:21:00+03	92400.00
2A895C	2017-07-11 00:25:00+03	26700.00
2A8967	2017-08-08 21:43:00+03	46400.00
2A896B	2017-07-28 23:00:00+03	89200.00
2A89B0	2017-08-02 15:40:00+03	39800.00
2A89C8	2017-08-04 18:25:00+03	16400.00
2A89DE	2017-07-18 06:08:00+03	21800.00
2A89F4	2017-07-22 09:12:00+03	28800.00
2A8A13	2017-07-09 03:45:00+03	27800.00
2A8A21	2017-07-13 03:06:00+03	23900.00
2A8A22	2017-08-11 20:49:00+03	100600.00
2A8A75	2017-07-02 18:12:00+03	239000.00
2A8AA6	2017-08-15 01:30:00+03	62300.00
2A8AB4	2017-07-26 04:34:00+03	66000.00
2A8AFE	2017-07-08 05:21:00+03	197300.00
2A8B20	2017-07-18 22:09:00+03	26700.00
2A8B55	2017-08-06 10:05:00+03	39800.00
2A8B8A	2017-07-08 07:04:00+03	40000.00
2A8BA4	2017-07-21 09:32:00+03	168000.00
2A8C14	2017-08-05 00:10:00+03	112000.00
2A8CAB	2017-07-31 00:29:00+03	28800.00
2A8CD9	2017-08-09 12:26:00+03	28000.00
2A8D9F	2017-07-12 08:14:00+03	28800.00
2A8DD5	2017-07-30 18:07:00+03	387400.00
2A8DEB	2017-07-28 11:56:00+03	58800.00
2A8E75	2017-08-08 04:15:00+03	154500.00
2A8EDF	2017-07-20 15:47:00+03	102900.00
2A8F2C	2017-07-18 14:11:00+03	85500.00
2A8FF8	2017-07-10 07:27:00+03	67000.00
2A90A0	2017-07-28 08:02:00+03	26000.00
2A90FD	2017-07-16 17:08:00+03	162400.00
2A91B8	2017-08-02 08:20:00+03	89200.00
2A91BF	2017-08-11 21:53:00+03	131600.00
2A91FE	2017-08-13 07:31:00+03	28800.00
2A922B	2017-07-16 05:59:00+03	64500.00
2A922C	2017-08-05 06:59:00+03	89600.00
2A9241	2017-08-01 00:25:00+03	28600.00
2A924D	2017-07-30 04:42:00+03	24400.00
2A9276	2017-07-04 08:33:00+03	100200.00
2A932C	2017-07-08 11:09:00+03	83200.00
2A9348	2017-08-12 19:44:00+03	38200.00
2A9394	2017-07-28 18:42:00+03	38400.00
2A93A1	2017-07-06 11:57:00+03	59800.00
2A93A9	2017-07-13 20:32:00+03	98300.00
2A93DE	2017-07-20 05:25:00+03	50800.00
2A93FF	2017-07-05 10:33:00+03	124200.00
2A9442	2017-08-11 13:13:00+03	238000.00
2A9483	2017-07-31 14:46:00+03	20200.00
2A94C1	2017-07-11 09:25:00+03	40000.00
2A94C3	2017-07-20 03:52:00+03	266400.00
2A94F0	2017-07-11 11:20:00+03	46000.00
2A9567	2017-07-16 08:55:00+03	17000.00
2A961E	2017-07-02 04:39:00+03	27400.00
2A96A4	2017-07-22 14:44:00+03	50600.00
2A971E	2017-07-02 07:34:00+03	65900.00
2A9723	2017-07-08 16:22:00+03	86300.00
2A9729	2017-06-28 13:19:00+03	155100.00
2A972A	2017-07-09 13:30:00+03	100000.00
2A9760	2017-07-15 13:45:00+03	30200.00
2A97B6	2017-07-03 14:01:00+03	158800.00
2A9847	2017-07-13 17:43:00+03	56600.00
2A9868	2017-07-13 07:38:00+03	133300.00
2A9881	2017-07-18 03:54:00+03	38600.00
2A98C3	2017-08-02 20:11:00+03	68100.00
2A98C9	2017-07-30 13:58:00+03	39200.00
2A9956	2017-08-10 12:22:00+03	251500.00
2A999E	2017-07-14 18:18:00+03	136100.00
2A999F	2017-07-27 09:49:00+03	141100.00
2A9A94	2017-08-06 12:26:00+03	85000.00
2A9ABE	2017-07-01 04:48:00+03	47000.00
2A9AC8	2017-07-02 15:53:00+03	47100.00
2A9ACF	2017-07-23 11:42:00+03	22600.00
2A9ADD	2017-07-23 21:52:00+03	131600.00
2A9B15	2017-07-30 02:56:00+03	111600.00
2A9B80	2017-07-05 18:56:00+03	35200.00
2A9BEE	2017-08-06 11:43:00+03	37900.00
2A9C0E	2017-07-28 09:30:00+03	123600.00
2A9C75	2017-07-17 15:34:00+03	123000.00
2A9CF4	2017-07-15 02:54:00+03	38400.00
2A9D37	2017-07-07 21:37:00+03	38800.00
2A9D3B	2017-08-02 09:49:00+03	189200.00
2A9DA5	2017-08-11 02:12:00+03	89700.00
2A9DB3	2017-07-20 07:54:00+03	29600.00
2A9E03	2017-07-03 21:05:00+03	62800.00
2A9E1D	2017-07-09 16:08:00+03	16400.00
2A9E2F	2017-07-28 12:20:00+03	59800.00
2A9F0D	2017-07-05 02:49:00+03	13700.00
2A9F22	2017-07-30 20:19:00+03	135000.00
2A9F5B	2017-07-06 10:04:00+03	6300.00
2A9FE1	2017-08-04 02:29:00+03	18900.00
2A9FEA	2017-07-06 21:47:00+03	21800.00
2AA00F	2017-07-14 22:24:00+03	8400.00
2AA020	2017-06-29 17:27:00+03	79000.00
2AA05D	2017-07-04 15:43:00+03	16400.00
2AA08D	2017-07-07 17:18:00+03	38800.00
2AA128	2017-08-01 07:17:00+03	56000.00
2AA150	2017-07-20 10:59:00+03	41200.00
2AA1AE	2017-08-12 17:08:00+03	58600.00
2AA1B8	2017-07-22 19:23:00+03	13700.00
2AA1C6	2017-08-10 05:10:00+03	20200.00
2AA1D1	2017-07-25 02:54:00+03	13400.00
2AA1E4	2017-07-14 17:06:00+03	16800.00
2AA1E8	2017-07-08 17:19:00+03	21000.00
2AA216	2017-07-16 08:23:00+03	44000.00
2AA22A	2017-07-13 07:21:00+03	73600.00
2AA279	2017-07-30 13:52:00+03	9800.00
2AA2B0	2017-07-20 20:58:00+03	176500.00
2AA306	2017-08-07 01:53:00+03	114800.00
2AA331	2017-08-09 10:37:00+03	43000.00
2AA33C	2017-07-21 06:18:00+03	111600.00
2AA346	2017-08-12 04:00:00+03	42800.00
2AA356	2017-08-13 11:50:00+03	38600.00
2AA3E1	2017-08-08 21:53:00+03	31600.00
2AA412	2017-07-03 01:14:00+03	99200.00
2AA437	2017-07-05 11:36:00+03	99200.00
2AA43A	2017-07-14 03:44:00+03	369000.00
2AA456	2017-08-07 03:58:00+03	43400.00
2AA45B	2017-07-07 04:13:00+03	168000.00
2AA46A	2017-07-16 13:27:00+03	660600.00
2AA481	2017-07-23 08:52:00+03	221000.00
2AA497	2017-07-17 17:09:00+03	6000.00
2AA4DB	2017-06-30 15:26:00+03	167400.00
2AA5C4	2017-07-03 20:24:00+03	399600.00
2AA5CB	2017-07-11 17:23:00+03	62700.00
2AA671	2017-07-12 17:05:00+03	143100.00
2AA691	2017-07-02 18:41:00+03	123000.00
2AA6A4	2017-07-04 17:49:00+03	44000.00
2AA6B3	2017-07-21 23:53:00+03	40800.00
2AA6C6	2017-07-19 20:58:00+03	67600.00
2AA750	2017-07-03 15:04:00+03	31100.00
2AA761	2017-07-15 16:56:00+03	115700.00
2AA7A4	2017-07-14 20:40:00+03	54800.00
2AA7B4	2017-08-04 08:04:00+03	26800.00
2AA7CA	2017-08-01 00:46:00+03	21200.00
2AA8C2	2017-07-08 06:39:00+03	81600.00
2AA8FC	2017-07-30 13:01:00+03	86900.00
2AA942	2017-07-27 19:02:00+03	167500.00
2AAA18	2017-07-01 15:07:00+03	23200.00
2AAA3A	2017-07-20 15:19:00+03	60700.00
2AAA6A	2017-08-05 00:49:00+03	60400.00
2AAAED	2017-07-15 12:48:00+03	114800.00
2AAAF5	2017-07-14 08:21:00+03	25400.00
2AAB34	2017-07-26 07:27:00+03	296100.00
2AAB44	2017-07-28 19:29:00+03	54000.00
2AAC15	2017-08-12 07:30:00+03	31200.00
2AAC2E	2017-07-13 04:37:00+03	38600.00
2AAC96	2017-07-05 17:36:00+03	7400.00
2AACC9	2017-07-02 23:00:00+03	8200.00
2AACF6	2017-07-09 06:06:00+03	11800.00
2AAD18	2017-07-14 03:58:00+03	68200.00
2AAD34	2017-08-09 03:52:00+03	103900.00
2AADB0	2017-08-03 01:23:00+03	69500.00
2AADB7	2017-06-30 16:07:00+03	75300.00
2AADCD	2017-08-06 12:49:00+03	52100.00
2AAE0E	2017-08-15 05:51:00+03	17700.00
2AAE15	2017-07-19 08:46:00+03	21800.00
2AAE21	2017-08-02 09:42:00+03	181600.00
2AAE25	2017-07-24 15:02:00+03	12000.00
2AAE2D	2017-07-30 06:26:00+03	49800.00
2AAE32	2017-07-08 12:30:00+03	23200.00
2AAE9E	2017-07-17 03:54:00+03	50600.00
2AAEC1	2017-07-01 08:19:00+03	135400.00
2AAEC2	2017-07-10 03:03:00+03	132800.00
2AAF06	2017-07-09 20:05:00+03	28000.00
2AAF30	2017-08-03 20:22:00+03	34000.00
2AAF3D	2017-07-31 20:22:00+03	8000.00
2AB0B6	2017-07-31 21:31:00+03	29600.00
2AB139	2017-08-09 09:26:00+03	47000.00
2AB258	2017-07-23 06:42:00+03	49600.00
2AB285	2017-08-01 03:44:00+03	36200.00
2AB2C3	2017-07-16 02:46:00+03	91200.00
2AB2F6	2017-07-09 23:22:00+03	6700.00
2AB356	2017-08-15 15:14:00+03	6000.00
2AB368	2017-07-06 20:51:00+03	24700.00
2AB3CF	2017-07-13 01:58:00+03	43200.00
2AB3F4	2017-08-14 20:32:00+03	36000.00
2AB480	2017-08-13 18:32:00+03	25800.00
2AB4BF	2017-08-09 16:38:00+03	47100.00
2AB4E6	2017-08-07 01:20:00+03	49800.00
2AB522	2017-07-25 20:55:00+03	133100.00
2AB548	2017-08-05 18:48:00+03	6000.00
2AB598	2017-08-15 02:55:00+03	29800.00
2AB6C2	2017-07-22 02:12:00+03	72800.00
2AB715	2017-07-31 17:05:00+03	88600.00
2AB7BA	2017-07-15 16:13:00+03	56600.00
2AB82E	2017-07-31 13:39:00+03	59700.00
2AB8B2	2017-07-04 08:03:00+03	91100.00
2AB8E9	2017-07-14 20:12:00+03	246000.00
2AB948	2017-07-30 01:03:00+03	118000.00
2AB957	2017-08-06 22:59:00+03	28800.00
2AB977	2017-07-24 04:50:00+03	26000.00
2AB9D1	2017-07-29 05:17:00+03	28800.00
2ABA18	2017-07-07 11:10:00+03	12000.00
2ABA41	2017-07-31 15:03:00+03	46200.00
2ABA55	2017-08-07 00:58:00+03	56200.00
2ABA9D	2017-07-21 13:13:00+03	54800.00
2ABAEC	2017-07-11 16:17:00+03	40800.00
2ABB2B	2017-07-21 08:48:00+03	56000.00
2ABB46	2017-07-27 10:30:00+03	31900.00
2ABB54	2017-08-03 07:32:00+03	26000.00
2ABBAE	2017-08-13 00:50:00+03	40000.00
2ABBBB	2017-08-01 21:56:00+03	91500.00
2ABBE1	2017-08-03 08:34:00+03	42800.00
2ABC66	2017-08-02 22:19:00+03	38800.00
2ABCAA	2017-08-12 11:53:00+03	406700.00
2ABCD6	2017-07-30 13:58:00+03	135200.00
2ABD0D	2017-07-18 09:52:00+03	19600.00
2ABD65	2017-08-01 14:22:00+03	46000.00
2ABD85	2017-07-05 16:39:00+03	105000.00
2ABDB0	2017-08-03 14:42:00+03	28800.00
2ABE00	2017-08-13 21:20:00+03	46200.00
2ABE06	2017-07-26 13:18:00+03	17800.00
2ABE1F	2017-07-18 10:50:00+03	54500.00
2ABE7E	2017-08-10 19:33:00+03	28800.00
2ABE8D	2017-07-11 21:47:00+03	11000.00
2ABF7E	2017-08-04 09:18:00+03	39300.00
2ABF81	2017-08-07 13:15:00+03	44800.00
2ABF9E	2017-07-10 12:32:00+03	92700.00
2ABFA2	2017-07-26 01:33:00+03	18700.00
2AC0C3	2017-07-24 21:58:00+03	44000.00
2AC0E8	2017-07-12 00:57:00+03	61500.00
2AC100	2017-07-06 05:55:00+03	40800.00
2AC104	2017-07-09 16:16:00+03	31900.00
2AC108	2017-08-10 00:39:00+03	123000.00
2AC162	2017-07-08 01:09:00+03	71900.00
2AC23E	2017-07-19 08:12:00+03	99200.00
2AC25E	2017-07-01 09:19:00+03	137100.00
2AC27E	2017-07-07 16:50:00+03	48100.00
2AC366	2017-07-08 23:49:00+03	135400.00
2AC383	2017-07-23 18:34:00+03	81300.00
2AC401	2017-07-07 21:24:00+03	128800.00
2AC40F	2017-08-11 21:32:00+03	78300.00
2AC43C	2017-07-26 08:49:00+03	62700.00
2AC496	2017-07-08 11:57:00+03	14000.00
2AC4B1	2017-07-12 08:41:00+03	39700.00
2AC4BA	2017-07-26 19:48:00+03	24800.00
2AC4C0	2017-08-01 16:00:00+03	34000.00
2AC4D0	2017-07-22 16:29:00+03	66600.00
2AC4F2	2017-07-19 00:37:00+03	26700.00
2AC4FD	2017-07-08 21:38:00+03	46400.00
2AC534	2017-07-17 00:45:00+03	129200.00
2AC540	2017-07-19 22:47:00+03	38600.00
2AC55C	2017-07-26 04:24:00+03	32800.00
2AC570	2017-08-07 18:21:00+03	58000.00
2AC594	2017-08-04 11:37:00+03	14700.00
2AC5D4	2017-07-06 12:38:00+03	152500.00
2AC5F7	2017-08-13 02:46:00+03	25800.00
2AC61B	2017-07-04 08:58:00+03	75600.00
2AC623	2017-08-10 19:17:00+03	43900.00
2AC65A	2017-08-07 06:28:00+03	135400.00
2AC704	2017-08-09 18:47:00+03	124200.00
2AC71F	2017-08-11 15:31:00+03	108300.00
2AC736	2017-07-06 10:02:00+03	57500.00
2AC752	2017-07-19 06:21:00+03	12600.00
2AC755	2017-07-19 03:54:00+03	8200.00
2AC7E6	2017-08-12 18:19:00+03	26800.00
2AC831	2017-08-15 15:08:00+03	81800.00
2AC8CE	2017-07-16 12:33:00+03	123700.00
2AC931	2017-08-15 00:05:00+03	56000.00
2AC953	2017-07-11 09:33:00+03	20400.00
2AC9AF	2017-07-08 21:29:00+03	29100.00
2AC9BC	2017-08-15 03:39:00+03	36900.00
2AC9E8	2017-08-04 03:25:00+03	148200.00
2ACA4E	2017-07-07 21:31:00+03	14000.00
2ACA67	2017-08-13 01:16:00+03	17200.00
2ACA6A	2017-07-23 08:58:00+03	26400.00
2ACA76	2017-08-14 07:49:00+03	49500.00
2ACA94	2017-08-06 09:01:00+03	265700.00
2ACAAB	2017-07-17 14:16:00+03	246000.00
2ACAF2	2017-07-29 09:02:00+03	55800.00
2ACB40	2017-07-20 14:45:00+03	49800.00
2ACB67	2017-07-05 22:06:00+03	102100.00
2ACB6D	2017-07-19 06:09:00+03	26000.00
2ACBA2	2017-07-25 16:10:00+03	30000.00
2ACBA4	2017-07-19 12:40:00+03	31000.00
2ACCC7	2017-07-12 20:09:00+03	177200.00
2ACCD3	2017-07-15 20:01:00+03	103500.00
2ACCFB	2017-07-05 16:11:00+03	55800.00
2ACD2E	2017-07-16 02:26:00+03	100900.00
2ACD52	2017-07-23 05:45:00+03	54000.00
2ACDB3	2017-07-14 12:45:00+03	398600.00
2ACDFD	2017-07-01 10:05:00+03	21400.00
2ACE26	2017-07-02 09:54:00+03	114300.00
2ACE39	2017-08-14 09:11:00+03	32800.00
2ACE63	2017-07-12 06:59:00+03	60800.00
2ACE6D	2017-08-04 07:24:00+03	270000.00
2ACE6F	2017-07-21 04:05:00+03	112000.00
2ACEB0	2017-08-01 05:59:00+03	52700.00
2ACEC3	2017-07-16 06:48:00+03	14400.00
2ACEE2	2017-07-26 21:11:00+03	26800.00
2ACF49	2017-07-07 20:09:00+03	11900.00
2ACFE1	2017-07-09 21:05:00+03	6000.00
2AD055	2017-07-12 23:12:00+03	55800.00
2AD195	2017-07-15 20:38:00+03	28800.00
2AD20E	2017-08-10 18:37:00+03	75700.00
2AD210	2017-07-28 06:02:00+03	87000.00
2AD276	2017-07-15 09:13:00+03	57400.00
2AD2B6	2017-08-13 04:23:00+03	67400.00
2AD2BA	2017-08-10 05:08:00+03	21400.00
2AD2C4	2017-07-07 03:17:00+03	92900.00
2AD2C9	2017-07-24 09:24:00+03	184300.00
2AD353	2017-07-28 16:13:00+03	37800.00
2AD39B	2017-08-13 21:06:00+03	52000.00
2AD3FC	2017-07-03 13:31:00+03	64500.00
2AD4A1	2017-08-14 21:55:00+03	88800.00
2AD4BA	2017-08-07 03:56:00+03	24800.00
2AD4BC	2017-08-09 08:55:00+03	28800.00
2AD53F	2017-08-02 17:22:00+03	13800.00
2AD5AC	2017-07-28 14:14:00+03	26000.00
2AD60B	2017-07-11 03:33:00+03	135400.00
2AD672	2017-07-10 20:21:00+03	70400.00
2AD774	2017-08-13 21:46:00+03	255600.00
2AD777	2017-07-08 17:23:00+03	177600.00
2AD7EF	2017-08-02 00:33:00+03	57500.00
2AD85D	2017-07-19 13:43:00+03	102600.00
2AD896	2017-07-06 08:52:00+03	37900.00
2AD8A5	2017-07-10 13:50:00+03	40800.00
2AD96E	2017-07-18 00:07:00+03	79900.00
2AD9A0	2017-08-13 10:17:00+03	54800.00
2AD9A6	2017-07-26 15:21:00+03	110500.00
2AD9E7	2017-06-29 23:54:00+03	56000.00
2AD9F3	2017-08-12 09:28:00+03	272400.00
2ADA43	2017-07-24 13:15:00+03	398500.00
2ADA9E	2017-07-30 18:00:00+03	28800.00
2ADAD4	2017-08-03 21:17:00+03	24400.00
2ADAD7	2017-08-15 02:38:00+03	47400.00
2ADAF7	2017-07-08 07:58:00+03	103800.00
2ADB56	2017-07-10 21:00:00+03	162900.00
2ADB94	2017-07-26 05:31:00+03	133200.00
2ADBE2	2017-07-23 22:26:00+03	193600.00
2ADC1D	2017-07-05 04:54:00+03	21000.00
2ADC95	2017-07-13 01:59:00+03	28000.00
2ADCEC	2017-07-17 01:04:00+03	189800.00
2ADCFD	2017-08-14 10:10:00+03	7400.00
2ADD1D	2017-06-28 23:02:00+03	23200.00
2ADD40	2017-07-21 21:07:00+03	34200.00
2ADD41	2017-07-05 01:37:00+03	26000.00
2ADD66	2017-07-18 14:02:00+03	132200.00
2ADDAF	2017-08-07 03:09:00+03	65500.00
2ADE0E	2017-08-13 06:16:00+03	69500.00
2ADE18	2017-07-25 02:22:00+03	14000.00
2ADEBE	2017-08-05 16:35:00+03	26000.00
2ADF0C	2017-07-24 13:10:00+03	6700.00
2ADF66	2017-08-02 09:55:00+03	16800.00
2ADFB2	2017-08-08 10:50:00+03	62900.00
2ADFE5	2017-07-29 08:26:00+03	65600.00
2AE00D	2017-07-30 07:51:00+03	27300.00
2AE01E	2017-07-28 05:50:00+03	68800.00
2AE03F	2017-08-11 10:44:00+03	30000.00
2AE041	2017-08-02 03:42:00+03	44600.00
2AE0A0	2017-06-27 17:24:00+03	13200.00
2AE0AF	2017-07-20 20:24:00+03	53800.00
2AE0B5	2017-07-27 18:09:00+03	462000.00
2AE0D6	2017-07-21 06:04:00+03	36200.00
2AE0E3	2017-08-06 20:25:00+03	161800.00
2AE143	2017-08-02 06:01:00+03	40800.00
2AE1A4	2017-07-29 22:17:00+03	13000.00
2AE1CE	2017-07-29 03:22:00+03	17800.00
2AE1E9	2017-07-22 22:13:00+03	53600.00
2AE266	2017-08-03 21:46:00+03	67600.00
2AE2BD	2017-07-26 18:10:00+03	6600.00
2AE2DB	2017-07-20 19:42:00+03	20200.00
2AE2FD	2017-08-14 00:43:00+03	131900.00
2AE330	2017-08-14 07:09:00+03	57300.00
2AE3B8	2017-07-16 10:01:00+03	51900.00
2AE3DA	2017-07-23 21:21:00+03	130700.00
2AE403	2017-08-04 00:10:00+03	50700.00
2AE409	2017-07-19 03:52:00+03	29800.00
2AE439	2017-08-14 02:08:00+03	55800.00
2AE450	2017-07-10 23:41:00+03	25100.00
2AE4AC	2017-07-12 14:31:00+03	37900.00
2AE57F	2017-07-23 03:09:00+03	60200.00
2AE598	2017-07-13 12:04:00+03	31600.00
2AE5A8	2017-07-09 17:23:00+03	54800.00
2AE5B0	2017-07-26 22:46:00+03	26800.00
2AE694	2017-07-09 12:35:00+03	36000.00
2AE6A0	2017-07-08 16:47:00+03	31700.00
2AE6A2	2017-08-08 02:34:00+03	25600.00
2AE6BA	2017-08-09 17:52:00+03	26700.00
2AE788	2017-07-11 20:52:00+03	136800.00
2AE78F	2017-07-16 09:03:00+03	50800.00
2AE7B9	2017-07-04 23:24:00+03	92800.00
2AE7E8	2017-08-02 23:53:00+03	40000.00
2AE800	2017-08-06 05:01:00+03	16400.00
2AE83C	2017-07-02 00:07:00+03	163400.00
2AE8CD	2017-08-15 01:01:00+03	46300.00
2AE8FD	2017-08-10 18:44:00+03	13300.00
2AE93B	2017-08-14 03:55:00+03	34800.00
2AE93D	2017-08-15 14:24:00+03	133100.00
2AE96C	2017-08-03 13:35:00+03	155600.00
2AE980	2017-07-10 01:02:00+03	66000.00
2AE99F	2017-07-01 04:02:00+03	133100.00
2AE9BB	2017-06-29 14:30:00+03	170200.00
2AE9F2	2017-07-04 08:43:00+03	58000.00
2AEA06	2017-06-30 21:33:00+03	135600.00
2AEAB0	2017-07-17 03:56:00+03	26800.00
2AEAC8	2017-07-14 05:14:00+03	46800.00
2AEB0D	2017-07-29 17:42:00+03	14000.00
2AEB31	2017-07-26 17:53:00+03	23400.00
2AEB75	2017-08-12 09:03:00+03	38600.00
2AEBAB	2017-07-02 09:24:00+03	46800.00
2AEBD3	2017-07-20 03:32:00+03	6000.00
2AEBF0	2017-07-15 15:09:00+03	23600.00
2AECE7	2017-07-12 14:26:00+03	270800.00
2AECEF	2017-08-13 13:31:00+03	21000.00
2AED21	2017-07-21 07:30:00+03	46300.00
2AED29	2017-07-15 08:14:00+03	67600.00
2AED9A	2017-07-26 19:48:00+03	60100.00
2AEDA4	2017-07-21 10:02:00+03	58800.00
2AEDAA	2017-07-09 23:48:00+03	50000.00
2AEE68	2017-08-13 23:50:00+03	91200.00
2AEE6C	2017-08-03 17:40:00+03	23200.00
2AEE7B	2017-07-18 17:17:00+03	57700.00
2AEE7E	2017-08-02 02:37:00+03	124200.00
2AEE97	2017-07-19 02:16:00+03	92400.00
2AEE9C	2017-06-28 22:34:00+03	92900.00
2AEEA1	2017-07-01 16:38:00+03	56000.00
2AEEE4	2017-07-07 14:27:00+03	85500.00
2AEEE9	2017-07-19 10:18:00+03	87700.00
2AEF18	2017-07-20 02:47:00+03	30200.00
2AEF22	2017-07-25 18:14:00+03	75400.00
2AEF5C	2017-07-02 22:38:00+03	26700.00
2AEF97	2017-08-15 10:42:00+03	45100.00
2AF022	2017-07-03 07:00:00+03	11700.00
2AF031	2017-07-18 14:32:00+03	12600.00
2AF0AA	2017-08-12 21:56:00+03	42000.00
2AF0CA	2017-08-01 14:07:00+03	88500.00
2AF10E	2017-08-09 20:34:00+03	35600.00
2AF14B	2017-07-07 16:17:00+03	111000.00
2AF22F	2017-08-10 20:22:00+03	15000.00
2AF272	2017-07-12 08:37:00+03	22000.00
2AF318	2017-07-25 17:18:00+03	10800.00
2AF328	2017-07-28 22:40:00+03	23600.00
2AF355	2017-08-06 02:12:00+03	47400.00
2AF3C1	2017-07-20 11:29:00+03	54800.00
2AF412	2017-07-31 01:48:00+03	81600.00
2AF42A	2017-07-27 14:16:00+03	74400.00
2AF42D	2017-08-12 05:05:00+03	87900.00
2AF440	2017-07-26 01:15:00+03	32800.00
2AF443	2017-08-01 13:12:00+03	284400.00
2AF462	2017-07-16 01:22:00+03	13400.00
2AF4DD	2017-08-14 13:21:00+03	112000.00
2AF511	2017-08-13 18:18:00+03	266400.00
2AF560	2017-07-15 02:30:00+03	46000.00
2AF5AA	2017-07-11 16:05:00+03	26300.00
2AF5D3	2017-07-14 03:33:00+03	15000.00
2AF64E	2017-08-11 20:05:00+03	665200.00
2AF682	2017-07-09 22:55:00+03	23400.00
2AF6D9	2017-07-06 12:20:00+03	17200.00
2AF728	2017-08-12 14:06:00+03	75300.00
2AF761	2017-07-19 02:34:00+03	56600.00
2AF768	2017-08-08 19:26:00+03	35200.00
2AF7A6	2017-07-13 03:26:00+03	47700.00
2AF873	2017-08-11 14:36:00+03	28800.00
2AF8D0	2017-07-30 13:53:00+03	56600.00
2AF998	2017-07-25 00:16:00+03	266500.00
2AFA69	2017-08-10 15:49:00+03	23200.00
2AFAC5	2017-07-03 11:04:00+03	916000.00
2AFAD2	2017-07-13 15:17:00+03	55800.00
2AFB1C	2017-07-12 14:22:00+03	31600.00
2AFB36	2017-08-15 18:00:00+03	21400.00
2AFB3A	2017-08-12 14:05:00+03	51600.00
2AFB49	2017-08-07 18:48:00+03	77000.00
2AFC67	2017-08-13 22:47:00+03	28300.00
2AFC8F	2017-07-27 19:33:00+03	56000.00
2AFCC6	2017-07-18 19:43:00+03	45500.00
2AFD10	2017-07-27 18:33:00+03	46000.00
2AFD3C	2017-07-08 10:48:00+03	42800.00
2AFD75	2017-08-11 21:41:00+03	89700.00
2AFDBA	2017-08-07 18:12:00+03	23600.00
2AFDF0	2017-07-14 04:40:00+03	35600.00
2AFE3F	2017-08-12 04:57:00+03	92700.00
2AFE48	2017-07-05 17:11:00+03	42000.00
2AFE83	2017-06-30 00:27:00+03	72000.00
2AFE96	2017-07-27 17:31:00+03	38800.00
2AFEAB	2017-07-28 10:49:00+03	136200.00
2AFED9	2017-06-30 08:14:00+03	112000.00
2AFF25	2017-07-07 22:19:00+03	48800.00
2AFF76	2017-07-28 14:30:00+03	72200.00
2AFF97	2017-07-17 09:29:00+03	56000.00
2AFFAD	2017-08-02 04:23:00+03	51900.00
2AFFE7	2017-07-30 05:48:00+03	77200.00
2B0033	2017-08-14 21:46:00+03	11800.00
2B005B	2017-08-10 13:12:00+03	40000.00
2B007A	2017-07-30 17:03:00+03	92000.00
2B0087	2017-07-22 06:25:00+03	55800.00
2B00A7	2017-07-12 02:31:00+03	23900.00
2B00B6	2017-08-09 14:57:00+03	38400.00
2B0112	2017-07-18 10:05:00+03	70300.00
2B0132	2017-08-15 03:43:00+03	45200.00
2B016A	2017-07-09 00:03:00+03	198300.00
2B0195	2017-07-31 21:55:00+03	47700.00
2B01CE	2017-08-06 02:43:00+03	58000.00
2B020F	2017-08-09 14:31:00+03	15000.00
2B0298	2017-07-25 14:12:00+03	70800.00
2B02AA	2017-07-27 15:27:00+03	56900.00
2B0394	2017-07-25 04:21:00+03	124000.00
2B03C5	2017-07-19 07:18:00+03	47200.00
2B0443	2017-08-11 16:52:00+03	122400.00
2B0448	2017-07-14 06:16:00+03	21400.00
2B04D7	2017-07-08 08:12:00+03	14000.00
2B04FA	2017-07-13 04:39:00+03	113800.00
2B050D	2017-06-29 09:40:00+03	80000.00
2B050E	2017-06-26 19:59:00+03	31100.00
2B05CE	2017-07-19 06:03:00+03	6700.00
2B05FB	2017-07-04 14:28:00+03	43500.00
2B05FC	2017-07-14 12:16:00+03	153400.00
2B0616	2017-07-23 18:39:00+03	58200.00
2B0633	2017-07-25 06:46:00+03	38800.00
2B067E	2017-08-15 08:51:00+03	22000.00
2B0791	2017-07-25 13:38:00+03	131100.00
2B07CC	2017-08-02 17:12:00+03	265700.00
2B086C	2017-08-11 14:02:00+03	132800.00
2B08E1	2017-07-04 07:38:00+03	144700.00
2B090E	2017-07-21 09:18:00+03	133200.00
2B097F	2017-08-11 14:26:00+03	47100.00
2B09E6	2017-07-18 14:44:00+03	73400.00
2B0A1B	2017-07-25 17:31:00+03	46400.00
2B0A26	2017-07-11 13:40:00+03	117600.00
2B0A5F	2017-07-18 12:00:00+03	75100.00
2B0A84	2017-08-09 10:46:00+03	481800.00
2B0BB1	2017-07-03 08:42:00+03	12400.00
2B0BD0	2017-08-14 22:14:00+03	179400.00
2B0BDB	2017-08-13 12:16:00+03	26500.00
2B0CDE	2017-07-09 04:10:00+03	58400.00
2B0D2F	2017-07-18 22:24:00+03	6000.00
2B0D44	2017-07-23 11:12:00+03	39100.00
2B0DE1	2017-08-15 08:48:00+03	492000.00
2B0E5D	2017-07-26 02:51:00+03	13600.00
2B0E75	2017-07-31 03:45:00+03	11600.00
2B0E89	2017-07-06 18:04:00+03	26800.00
2B0EB9	2017-07-07 14:46:00+03	28800.00
2B0ED3	2017-08-09 14:28:00+03	39300.00
2B0F71	2017-08-08 22:39:00+03	128800.00
2B0FF7	2017-07-22 18:20:00+03	94000.00
2B1032	2017-07-21 09:47:00+03	57300.00
2B10B7	2017-08-09 00:53:00+03	89700.00
2B117E	2017-07-20 15:12:00+03	56200.00
2B1187	2017-07-18 15:21:00+03	21400.00
2B11AB	2017-07-25 11:52:00+03	32700.00
2B11CF	2017-07-03 13:13:00+03	26000.00
2B11EC	2017-07-05 23:28:00+03	61800.00
2B1255	2017-07-25 09:47:00+03	34000.00
2B134A	2017-07-24 03:58:00+03	100900.00
2B1393	2017-07-04 06:54:00+03	122000.00
2B1399	2017-08-08 19:11:00+03	55800.00
2B13C2	2017-07-06 06:26:00+03	52800.00
2B144D	2017-07-12 19:56:00+03	50100.00
2B145C	2017-07-16 14:06:00+03	136200.00
2B14A1	2017-07-10 01:59:00+03	55800.00
2B14AF	2017-08-10 15:43:00+03	38400.00
2B1572	2017-07-19 08:01:00+03	134400.00
2B15A1	2017-07-02 18:11:00+03	36700.00
2B1691	2017-07-28 15:19:00+03	28000.00
2B16C5	2017-07-12 22:29:00+03	31600.00
2B171E	2017-08-03 08:16:00+03	37100.00
2B1727	2017-07-29 22:43:00+03	11000.00
2B1748	2017-08-02 01:50:00+03	68400.00
2B178A	2017-07-05 01:56:00+03	115000.00
2B1806	2017-06-30 21:57:00+03	27900.00
2B1849	2017-07-08 07:49:00+03	12400.00
2B186F	2017-08-15 00:47:00+03	66600.00
2B18CD	2017-07-28 14:07:00+03	8200.00
2B194D	2017-07-23 10:20:00+03	86300.00
2B195C	2017-07-27 03:25:00+03	84100.00
2B19CA	2017-08-05 01:43:00+03	25600.00
2B1A48	2017-07-22 23:59:00+03	64700.00
2B1A8E	2017-07-11 11:15:00+03	26000.00
2B1B51	2017-07-03 21:08:00+03	169300.00
2B1BA8	2017-07-20 08:01:00+03	73600.00
2B1C37	2017-07-21 09:08:00+03	56900.00
2B1C41	2017-08-13 04:59:00+03	42700.00
2B1C5F	2017-08-08 14:26:00+03	27200.00
2B1C64	2017-08-11 18:37:00+03	68800.00
2B1CC0	2017-08-03 21:58:00+03	148200.00
2B1D56	2017-08-06 10:33:00+03	54500.00
2B1DB4	2017-07-23 16:50:00+03	91200.00
2B1DDF	2017-08-06 00:44:00+03	248300.00
2B1DEA	2017-07-31 20:21:00+03	32900.00
2B1DFC	2017-08-04 12:59:00+03	49900.00
2B1E22	2017-07-12 20:54:00+03	35400.00
2B1E6C	2017-07-27 15:43:00+03	108900.00
2B1E8E	2017-08-07 12:02:00+03	44400.00
2B1EB8	2017-08-07 13:17:00+03	64800.00
2B1EFC	2017-07-04 21:18:00+03	111600.00
2B1F05	2017-07-26 22:00:00+03	40900.00
2B1F12	2017-07-15 02:31:00+03	58200.00
2B1F2E	2017-07-30 17:59:00+03	19000.00
2B1F78	2017-08-07 19:20:00+03	92800.00
2B1F79	2017-07-28 05:59:00+03	8000.00
2B1F9A	2017-07-28 21:14:00+03	89600.00
2B1F9B	2017-07-28 17:30:00+03	86300.00
2B1FE1	2017-07-12 20:16:00+03	211600.00
2B20AE	2017-08-07 09:57:00+03	12400.00
2B20C1	2017-07-05 10:46:00+03	196800.00
2B20DE	2017-06-28 11:05:00+03	130400.00
2B2132	2017-08-12 20:57:00+03	92100.00
2B21E7	2017-07-19 06:31:00+03	43600.00
2B2219	2017-07-11 13:57:00+03	70200.00
2B2290	2017-07-16 04:18:00+03	53400.00
2B229A	2017-08-07 02:12:00+03	116900.00
2B22F8	2017-08-11 12:47:00+03	56000.00
2B238D	2017-08-04 22:27:00+03	58600.00
2B239B	2017-08-12 01:31:00+03	61300.00
2B239E	2017-08-04 10:31:00+03	6300.00
2B23D2	2017-07-21 13:23:00+03	105100.00
2B23EA	2017-08-03 17:23:00+03	6700.00
2B2410	2017-07-07 04:50:00+03	61800.00
2B2475	2017-07-26 02:52:00+03	83300.00
2B249D	2017-07-26 19:28:00+03	69000.00
2B256B	2017-07-10 12:25:00+03	29600.00
2B25FD	2017-06-28 17:33:00+03	47000.00
2B2623	2017-07-02 21:57:00+03	103100.00
2B262B	2017-08-10 20:43:00+03	14800.00
2B2637	2017-07-02 01:20:00+03	29400.00
2B268D	2017-06-30 02:53:00+03	52000.00
2B26F1	2017-07-02 07:08:00+03	57500.00
2B2700	2017-08-05 00:54:00+03	19600.00
2B2718	2017-08-14 17:05:00+03	236800.00
2B275E	2017-07-20 07:56:00+03	152900.00
2B2765	2017-07-07 13:21:00+03	78700.00
2B27DF	2017-08-07 08:50:00+03	59200.00
2B27E8	2017-07-19 12:09:00+03	48800.00
2B2830	2017-07-31 05:53:00+03	139100.00
2B29B8	2017-07-03 21:37:00+03	38600.00
2B29DA	2017-07-04 03:31:00+03	56600.00
2B2ADF	2017-07-13 05:21:00+03	46500.00
2B2C4B	2017-07-05 22:05:00+03	56600.00
2B2C67	2017-08-15 15:07:00+03	119600.00
2B2CDC	2017-07-13 15:49:00+03	8800.00
2B2E72	2017-08-01 23:01:00+03	31600.00
2B2E75	2017-07-23 22:34:00+03	60400.00
2B2E87	2017-08-09 12:57:00+03	30400.00
2B2E98	2017-07-08 02:16:00+03	23600.00
2B2ED4	2017-07-22 12:06:00+03	12600.00
2B2F38	2017-08-08 13:06:00+03	6000.00
2B2F9F	2017-08-05 03:40:00+03	45200.00
2B2FC0	2017-07-29 20:50:00+03	124300.00
2B3005	2017-07-26 21:21:00+03	28000.00
2B30DB	2017-07-15 09:43:00+03	55800.00
2B3115	2017-07-11 16:14:00+03	26000.00
2B312D	2017-08-08 17:13:00+03	266400.00
2B3133	2017-08-07 01:21:00+03	484200.00
2B3145	2017-08-06 07:01:00+03	100600.00
2B3184	2017-08-14 22:16:00+03	34000.00
2B31A9	2017-08-06 18:10:00+03	67100.00
2B31C2	2017-07-18 15:01:00+03	24000.00
2B31D2	2017-08-05 23:02:00+03	26000.00
2B3207	2017-08-01 02:15:00+03	86300.00
2B323C	2017-07-12 21:41:00+03	31600.00
2B323D	2017-08-13 03:46:00+03	28800.00
2B3241	2017-08-03 19:44:00+03	37200.00
2B3260	2017-07-02 08:55:00+03	31400.00
2B3267	2017-07-21 07:24:00+03	108100.00
2B3319	2017-08-11 02:23:00+03	69500.00
2B331C	2017-07-04 21:18:00+03	249000.00
2B3342	2017-07-07 22:26:00+03	23600.00
2B3361	2017-07-03 09:15:00+03	56000.00
2B336B	2017-08-13 05:56:00+03	23900.00
2B338F	2017-07-14 02:58:00+03	155600.00
2B33FA	2017-07-08 20:22:00+03	30200.00
2B3401	2017-07-28 22:47:00+03	26400.00
2B343A	2017-08-01 01:33:00+03	145100.00
2B3461	2017-07-09 00:50:00+03	102100.00
2B3489	2017-07-01 21:17:00+03	47600.00
2B34AA	2017-08-06 17:03:00+03	91500.00
2B34C1	2017-07-04 10:04:00+03	46000.00
2B3536	2017-07-13 00:46:00+03	69500.00
2B356D	2017-07-11 10:11:00+03	23600.00
2B358F	2017-08-03 03:54:00+03	77500.00
2B35E1	2017-06-29 05:23:00+03	67800.00
2B35FA	2017-07-29 20:53:00+03	111600.00
2B362B	2017-08-11 21:43:00+03	28800.00
2B363F	2017-08-03 06:10:00+03	31400.00
2B3664	2017-07-18 20:40:00+03	28000.00
2B370C	2017-07-11 20:46:00+03	28000.00
2B3760	2017-08-01 23:04:00+03	77600.00
2B3816	2017-08-15 02:12:00+03	146900.00
2B3861	2017-08-01 22:22:00+03	55800.00
2B3865	2017-07-20 07:44:00+03	42400.00
2B388C	2017-08-03 21:43:00+03	28000.00
2B3892	2017-07-04 09:51:00+03	76200.00
2B38B0	2017-07-01 11:01:00+03	42000.00
2B38D1	2017-07-19 11:51:00+03	12600.00
2B38F3	2017-07-04 08:00:00+03	19600.00
2B3976	2017-07-09 15:29:00+03	369000.00
2B39BE	2017-08-14 01:34:00+03	56900.00
2B39C5	2017-07-21 11:57:00+03	119600.00
2B39D6	2017-07-06 09:09:00+03	22000.00
2B3A04	2017-07-27 21:51:00+03	70100.00
2B3AD2	2017-07-03 12:18:00+03	56000.00
2B3AE8	2017-08-03 10:31:00+03	59100.00
2B3B6E	2017-08-09 12:57:00+03	75300.00
2B3B72	2017-08-06 11:25:00+03	100600.00
2B3B78	2017-07-28 06:23:00+03	6600.00
2B3B8A	2017-07-11 08:52:00+03	111600.00
2B3BC0	2017-07-09 06:38:00+03	379000.00
2B3BDF	2017-07-27 04:42:00+03	16400.00
2B3C31	2017-08-05 17:01:00+03	53600.00
2B3C8A	2017-08-09 09:23:00+03	57500.00
2B3D39	2017-08-03 05:21:00+03	166100.00
2B3D6E	2017-07-11 08:53:00+03	49600.00
2B3DE8	2017-08-02 10:34:00+03	112000.00
2B3E56	2017-08-11 19:55:00+03	39800.00
2B3ECC	2017-07-14 10:29:00+03	28000.00
2B3EDD	2017-07-10 22:36:00+03	57300.00
2B3F0A	2017-07-24 15:07:00+03	116100.00
2B3F8E	2017-07-08 21:30:00+03	92400.00
2B3F97	2017-08-14 14:08:00+03	46500.00
2B3F9A	2017-08-08 13:46:00+03	68400.00
2B3FDA	2017-08-01 20:35:00+03	135800.00
2B4021	2017-08-02 06:30:00+03	23400.00
2B4033	2017-08-09 02:29:00+03	85000.00
2B40CB	2017-08-05 08:24:00+03	58800.00
2B4101	2017-08-14 06:58:00+03	25400.00
2B4193	2017-08-06 06:57:00+03	71900.00
2B420C	2017-08-06 00:49:00+03	28800.00
2B4266	2017-08-04 21:01:00+03	58800.00
2B42BF	2017-07-24 16:02:00+03	56000.00
2B42F8	2017-07-27 14:37:00+03	95200.00
2B4319	2017-07-07 05:01:00+03	52900.00
2B4352	2017-07-24 11:06:00+03	84400.00
2B437B	2017-07-27 18:34:00+03	17800.00
2B439F	2017-06-30 12:11:00+03	13200.00
2B441C	2017-07-20 23:55:00+03	86800.00
2B4468	2017-07-03 06:10:00+03	123000.00
2B4487	2017-07-08 15:17:00+03	101500.00
2B44B3	2017-07-22 22:24:00+03	53300.00
2B44B7	2017-08-05 15:14:00+03	47200.00
2B44E1	2017-08-09 10:53:00+03	69500.00
2B4562	2017-08-08 13:18:00+03	169900.00
2B45E7	2017-07-03 13:51:00+03	159000.00
2B462D	2017-07-30 19:36:00+03	78100.00
2B4641	2017-07-29 00:28:00+03	31700.00
2B4696	2017-08-12 17:38:00+03	38000.00
2B46D7	2017-07-18 11:05:00+03	56000.00
2B4759	2017-08-01 23:35:00+03	47100.00
2B4761	2017-08-13 22:45:00+03	137700.00
2B4767	2017-07-18 06:36:00+03	58600.00
2B4778	2017-07-30 00:29:00+03	64100.00
2B478A	2017-08-12 10:56:00+03	73500.00
2B47BE	2017-07-03 19:40:00+03	47100.00
2B47D4	2017-08-08 10:00:00+03	32700.00
2B47E1	2017-07-20 10:29:00+03	228700.00
2B4882	2017-07-05 15:16:00+03	189600.00
2B4887	2017-07-05 23:45:00+03	23200.00
2B492D	2017-07-24 05:35:00+03	68200.00
2B49B7	2017-08-08 06:56:00+03	22000.00
2B4AC1	2017-08-04 01:31:00+03	139100.00
2B4B3A	2017-07-13 20:17:00+03	93900.00
2B4B9D	2017-08-03 13:29:00+03	36200.00
2B4BB5	2017-08-03 18:30:00+03	54500.00
2B4BE0	2017-07-24 01:07:00+03	15000.00
2B4BFC	2017-08-02 21:13:00+03	66600.00
2B4CB2	2017-07-26 22:30:00+03	76900.00
2B4CEE	2017-07-23 03:24:00+03	61000.00
2B4D2B	2017-07-09 11:45:00+03	64800.00
2B4D5F	2017-07-15 06:40:00+03	49800.00
2B4DC6	2017-08-06 20:06:00+03	117800.00
2B4E24	2017-07-06 05:15:00+03	112000.00
2B4E7C	2017-07-09 16:27:00+03	283100.00
2B4EDE	2017-07-25 20:49:00+03	23400.00
2B4EDF	2017-07-25 14:32:00+03	167400.00
2B4FDD	2017-07-03 05:55:00+03	6000.00
2B4FDE	2017-07-25 14:25:00+03	14000.00
2B5073	2017-08-15 05:19:00+03	28000.00
2B508B	2017-07-30 22:12:00+03	56000.00
2B50A5	2017-08-02 19:18:00+03	28000.00
2B50DB	2017-08-03 11:20:00+03	21800.00
2B5106	2017-08-02 14:52:00+03	56900.00
2B51B1	2017-07-13 09:33:00+03	30200.00
2B5221	2017-07-28 00:36:00+03	23600.00
2B5323	2017-07-20 09:45:00+03	58600.00
2B532C	2017-07-16 18:07:00+03	159100.00
2B5336	2017-07-05 14:25:00+03	75600.00
2B540F	2017-08-01 00:31:00+03	52800.00
2B5434	2017-07-17 17:12:00+03	239100.00
2B548F	2017-07-28 23:42:00+03	34000.00
2B54AC	2017-07-16 23:52:00+03	277900.00
2B54D8	2017-07-20 21:27:00+03	173300.00
2B557D	2017-07-22 23:34:00+03	409100.00
2B5594	2017-08-10 18:44:00+03	21800.00
2B5616	2017-07-10 05:58:00+03	75300.00
2B5673	2017-07-27 03:47:00+03	37900.00
2B567F	2017-08-06 04:26:00+03	37200.00
2B5692	2017-07-11 16:19:00+03	87700.00
2B56E8	2017-07-13 05:42:00+03	65300.00
2B5734	2017-07-22 05:51:00+03	58600.00
2B574D	2017-08-13 11:12:00+03	206700.00
2B57EF	2017-07-19 00:23:00+03	57500.00
2B5844	2017-08-08 20:08:00+03	12200.00
2B5853	2017-08-04 10:21:00+03	40800.00
2B5898	2017-07-24 20:47:00+03	58600.00
2B58A0	2017-07-14 10:33:00+03	44800.00
2B58A3	2017-07-14 23:49:00+03	60400.00
2B58E1	2017-08-08 20:28:00+03	14000.00
2B592D	2017-07-27 03:57:00+03	27600.00
2B5992	2017-07-15 16:15:00+03	52300.00
2B59F3	2017-07-12 12:18:00+03	233800.00
2B5A1A	2017-08-07 17:00:00+03	112000.00
2B5ABB	2017-08-14 01:58:00+03	14000.00
2B5ADA	2017-07-17 12:38:00+03	62800.00
2B5B36	2017-06-29 02:58:00+03	147700.00
2B5B3D	2017-07-22 06:24:00+03	39200.00
2B5B4E	2017-07-21 01:25:00+03	63200.00
2B5B58	2017-07-25 10:51:00+03	40700.00
2B5B62	2017-07-19 07:05:00+03	46200.00
2B5BC9	2017-08-05 02:42:00+03	133200.00
2B5BE2	2017-08-07 11:31:00+03	91500.00
2B5BED	2017-07-14 17:03:00+03	92000.00
2B5C05	2017-07-06 20:40:00+03	198500.00
2B5C0B	2017-08-08 00:41:00+03	89600.00
2B5C42	2017-07-21 14:40:00+03	75300.00
2B5C84	2017-07-16 02:22:00+03	40800.00
2B5CB6	2017-07-23 04:04:00+03	54000.00
2B5CEE	2017-07-24 15:22:00+03	539400.00
2B5D12	2017-08-02 23:14:00+03	133200.00
2B5D19	2017-07-23 11:02:00+03	12600.00
2B5D5C	2017-08-03 15:02:00+03	32800.00
2B5D6C	2017-07-01 06:19:00+03	60200.00
2B5DA8	2017-07-12 03:29:00+03	13600.00
2B5DD5	2017-07-05 04:00:00+03	64200.00
2B5E2F	2017-08-11 04:27:00+03	60400.00
2B5E5A	2017-08-13 14:43:00+03	25200.00
2B5E69	2017-07-06 06:25:00+03	34000.00
2B5E6C	2017-07-19 05:57:00+03	16400.00
2B5E74	2017-07-18 20:44:00+03	62600.00
2B5EBC	2017-07-26 14:33:00+03	70700.00
2B5F4F	2017-07-21 23:07:00+03	135400.00
2B5F51	2017-06-30 23:13:00+03	54500.00
2B5FD3	2017-07-23 06:25:00+03	28800.00
2B6014	2017-07-11 03:47:00+03	101200.00
2B6024	2017-07-27 06:25:00+03	42800.00
2B6050	2017-08-07 07:42:00+03	103800.00
2B6058	2017-07-16 11:28:00+03	62000.00
2B60A7	2017-07-27 07:05:00+03	92600.00
2B60F6	2017-07-11 03:03:00+03	62200.00
2B611F	2017-07-26 16:05:00+03	128800.00
2B6180	2017-07-31 04:51:00+03	38600.00
2B61DA	2017-08-07 03:22:00+03	78100.00
2B6228	2017-07-30 21:00:00+03	53300.00
2B622D	2017-08-08 23:37:00+03	48500.00
2B6237	2017-08-02 03:34:00+03	265800.00
2B6266	2017-07-09 15:05:00+03	195600.00
2B6278	2017-08-04 09:16:00+03	26200.00
2B627B	2017-07-25 13:24:00+03	23600.00
2B627C	2017-07-09 06:27:00+03	67600.00
2B62B4	2017-07-25 09:36:00+03	20500.00
2B62D0	2017-08-15 15:31:00+03	54500.00
2B62F2	2017-07-13 12:12:00+03	87800.00
2B62F9	2017-07-24 00:50:00+03	529100.00
2B62FE	2017-07-31 13:10:00+03	23600.00
2B632F	2017-08-07 18:56:00+03	46400.00
2B642D	2017-07-14 17:23:00+03	324600.00
2B6450	2017-07-26 12:53:00+03	49200.00
2B6455	2017-07-10 10:38:00+03	6600.00
2B649E	2017-07-20 00:30:00+03	66600.00
2B64E7	2017-07-25 03:32:00+03	44000.00
2B652C	2017-07-06 20:53:00+03	62600.00
2B656A	2017-07-01 22:32:00+03	225200.00
2B658D	2017-08-12 11:14:00+03	38000.00
2B6596	2017-07-23 05:13:00+03	28800.00
2B6613	2017-08-11 06:48:00+03	13700.00
2B6659	2017-07-23 08:36:00+03	208300.00
2B6688	2017-07-12 12:06:00+03	77700.00
2B6781	2017-07-13 13:24:00+03	117600.00
2B687B	2017-07-02 01:39:00+03	154800.00
2B689D	2017-07-07 23:28:00+03	25900.00
2B68A6	2017-08-14 07:24:00+03	23600.00
2B68C2	2017-07-09 07:06:00+03	144400.00
2B68FA	2017-07-18 06:44:00+03	131600.00
2B6937	2017-07-26 13:33:00+03	193600.00
2B69CC	2017-07-15 10:23:00+03	95300.00
2B69F1	2017-08-15 16:34:00+03	70400.00
2B6A24	2017-07-15 22:17:00+03	248300.00
2B6AAF	2017-08-15 12:14:00+03	97100.00
2B6AC3	2017-07-20 02:11:00+03	100600.00
2B6AD6	2017-07-21 14:19:00+03	6700.00
2B6B27	2017-08-09 16:00:00+03	52300.00
2B6B32	2017-07-24 02:52:00+03	166000.00
2B6BB0	2017-08-15 11:15:00+03	46400.00
2B6C37	2017-08-01 00:13:00+03	37900.00
2B6CA4	2017-07-07 02:51:00+03	44500.00
2B6CEA	2017-07-30 23:10:00+03	56000.00
2B6CF1	2017-06-28 04:00:00+03	46000.00
2B6DBC	2017-07-22 23:05:00+03	30700.00
2B6DD6	2017-07-02 06:04:00+03	87100.00
2B6E1E	2017-08-04 19:28:00+03	14400.00
2B6E3B	2017-07-08 06:12:00+03	67500.00
2B6E47	2017-07-22 08:58:00+03	133100.00
2B6E69	2017-08-09 13:29:00+03	39800.00
2B6E85	2017-08-04 18:00:00+03	153300.00
2B6E8F	2017-08-10 14:15:00+03	70600.00
2B6EB0	2017-07-12 16:23:00+03	42700.00
2B6EC3	2017-08-10 13:19:00+03	298400.00
2B6ECF	2017-07-13 16:24:00+03	46200.00
2B6F37	2017-07-03 05:07:00+03	47100.00
2B6FCF	2017-07-09 09:32:00+03	44600.00
2B6FDD	2017-07-19 05:02:00+03	101700.00
2B6FFD	2017-08-11 06:10:00+03	73300.00
2B7086	2017-07-01 15:15:00+03	78800.00
2B708C	2017-08-04 09:41:00+03	114700.00
2B7112	2017-07-27 15:46:00+03	46000.00
2B711C	2017-06-29 00:36:00+03	134700.00
2B7124	2017-07-31 16:00:00+03	6000.00
2B7155	2017-07-07 02:49:00+03	58000.00
2B7258	2017-08-11 14:09:00+03	93900.00
2B72E9	2017-07-20 00:26:00+03	25900.00
2B72EE	2017-07-11 07:51:00+03	386000.00
2B7320	2017-07-29 00:37:00+03	25400.00
2B737F	2017-07-26 05:18:00+03	86500.00
2B7399	2017-07-02 08:31:00+03	153300.00
2B73DE	2017-08-01 04:34:00+03	32800.00
2B7427	2017-07-14 17:44:00+03	542300.00
2B747B	2017-07-10 01:46:00+03	51900.00
2B74A3	2017-07-11 06:40:00+03	79000.00
2B7517	2017-08-07 01:11:00+03	40800.00
2B75A4	2017-07-30 09:58:00+03	110500.00
2B75B9	2017-07-08 22:32:00+03	113300.00
2B75C5	2017-07-31 05:24:00+03	89600.00
2B7628	2017-07-18 05:25:00+03	46300.00
2B7633	2017-08-07 07:20:00+03	55800.00
2B7643	2017-07-08 00:46:00+03	48400.00
2B7655	2017-08-03 02:46:00+03	148800.00
2B767B	2017-07-18 15:01:00+03	291700.00
2B7735	2017-08-07 20:47:00+03	86800.00
2B773A	2017-07-14 10:45:00+03	47100.00
2B7788	2017-06-28 17:47:00+03	26600.00
2B77C3	2017-07-30 14:15:00+03	23200.00
2B77D9	2017-08-07 07:53:00+03	130100.00
2B7842	2017-07-16 21:53:00+03	399600.00
2B7857	2017-08-14 08:11:00+03	47200.00
2B7869	2017-07-25 23:24:00+03	28700.00
2B786E	2017-07-21 07:50:00+03	156300.00
2B78D6	2017-08-01 18:05:00+03	135600.00
2B78DA	2017-07-01 02:15:00+03	101200.00
2B78DD	2017-07-21 20:26:00+03	160200.00
2B78F0	2017-07-24 04:49:00+03	236900.00
2B7936	2017-08-11 19:39:00+03	55800.00
2B793D	2017-07-24 23:04:00+03	28800.00
2B79AA	2017-07-25 07:08:00+03	229900.00
2B7A17	2017-08-06 05:24:00+03	29400.00
2B7A2C	2017-07-14 19:41:00+03	28800.00
2B7A3F	2017-07-22 01:22:00+03	147600.00
2B7A65	2017-07-15 09:51:00+03	54000.00
2B7A66	2017-07-16 06:05:00+03	52300.00
2B7AE9	2017-08-14 02:10:00+03	33100.00
2B7BF3	2017-08-11 20:18:00+03	12000.00
2B7C2F	2017-07-24 12:22:00+03	283500.00
2B7C55	2017-07-02 23:27:00+03	224200.00
2B7C5F	2017-08-10 06:30:00+03	76100.00
2B7C75	2017-08-04 10:08:00+03	86300.00
2B7C99	2017-08-14 12:50:00+03	17000.00
2B7CC1	2017-07-15 08:37:00+03	102000.00
2B7D29	2017-08-07 11:25:00+03	44800.00
2B7D5B	2017-08-02 16:52:00+03	187600.00
2B7D91	2017-06-26 08:09:00+03	166100.00
2B7D95	2017-08-14 13:06:00+03	22000.00
2B7DD9	2017-08-05 02:59:00+03	134400.00
2B7E02	2017-07-07 15:20:00+03	86800.00
2B7E25	2017-08-10 13:46:00+03	35200.00
2B7E52	2017-07-16 03:07:00+03	106700.00
2B7EA1	2017-08-06 10:47:00+03	40600.00
2B7F03	2017-07-21 04:26:00+03	30200.00
2B7F09	2017-07-06 15:56:00+03	26000.00
2B7F1F	2017-08-01 05:44:00+03	36200.00
2B7F2D	2017-08-13 06:13:00+03	93700.00
2B7F2E	2017-07-13 08:49:00+03	45100.00
2B7F35	2017-07-07 17:53:00+03	44800.00
2B7F57	2017-07-14 15:20:00+03	25200.00
2B7F9F	2017-08-12 21:00:00+03	111600.00
2B8000	2017-07-29 11:11:00+03	25400.00
2B8026	2017-07-21 14:39:00+03	46300.00
2B80EF	2017-08-13 08:18:00+03	36000.00
2B8172	2017-07-22 22:52:00+03	498200.00
2B817F	2017-07-21 21:20:00+03	13400.00
2B81B7	2017-08-10 02:52:00+03	47100.00
2B81BF	2017-08-13 15:43:00+03	52000.00
2B81D3	2017-07-25 05:16:00+03	31400.00
2B81FF	2017-08-11 15:45:00+03	28000.00
2B820B	2017-08-14 07:07:00+03	89600.00
2B8257	2017-08-14 08:40:00+03	159800.00
2B82CE	2017-07-27 20:45:00+03	179900.00
2B82CF	2017-07-16 19:21:00+03	13400.00
2B82F7	2017-08-11 11:36:00+03	50000.00
2B832B	2017-07-20 11:51:00+03	23400.00
2B83FE	2017-07-13 03:54:00+03	10800.00
2B844D	2017-06-30 04:19:00+03	188500.00
2B847D	2017-08-13 21:36:00+03	169900.00
2B84DA	2017-07-24 23:09:00+03	14800.00
2B8503	2017-07-12 03:01:00+03	21400.00
2B8534	2017-07-29 23:19:00+03	44000.00
2B8583	2017-07-15 08:38:00+03	177600.00
2B8584	2017-07-24 09:00:00+03	56600.00
2B8592	2017-08-04 09:04:00+03	40600.00
2B85C9	2017-08-03 11:32:00+03	93200.00
2B85F1	2017-07-26 08:25:00+03	74400.00
2B869A	2017-07-04 17:06:00+03	63200.00
2B873E	2017-08-03 22:53:00+03	260900.00
2B8763	2017-08-04 06:47:00+03	57800.00
2B8764	2017-07-15 14:23:00+03	294200.00
2B878D	2017-07-28 21:48:00+03	29600.00
2B879A	2017-07-25 01:43:00+03	246000.00
2B87AA	2017-07-13 13:15:00+03	10700.00
2B87B4	2017-08-14 08:23:00+03	133700.00
2B87B6	2017-07-03 12:21:00+03	66200.00
2B87D7	2017-07-27 01:48:00+03	10600.00
2B8877	2017-07-16 07:33:00+03	21200.00
2B888A	2017-08-03 05:21:00+03	278400.00
2B88D0	2017-07-01 10:53:00+03	303500.00
2B8918	2017-07-16 01:50:00+03	28000.00
2B894F	2017-07-17 04:53:00+03	205000.00
2B8984	2017-07-29 17:22:00+03	147700.00
2B8994	2017-07-14 08:32:00+03	22100.00
2B89BA	2017-07-13 08:47:00+03	57600.00
2B89FA	2017-07-21 13:47:00+03	21400.00
2B8A08	2017-08-11 15:46:00+03	85200.00
2B8A40	2017-07-14 01:50:00+03	127900.00
2B8A61	2017-07-18 13:24:00+03	45400.00
2B8A86	2017-07-12 23:26:00+03	52800.00
2B8B66	2017-07-26 16:57:00+03	45200.00
2B8B6E	2017-07-07 04:57:00+03	29200.00
2B8B73	2017-08-09 17:12:00+03	28000.00
2B8B75	2017-08-11 13:32:00+03	39300.00
2B8B8C	2017-07-26 15:01:00+03	28800.00
2B8C77	2017-07-14 16:48:00+03	169900.00
2B8CC9	2017-08-14 01:15:00+03	103800.00
2B8CCB	2017-07-14 20:17:00+03	57500.00
2B8D1E	2017-07-24 15:47:00+03	8400.00
2B8D3E	2017-07-28 13:16:00+03	39400.00
2B8D4F	2017-07-09 07:53:00+03	39300.00
2B8DAD	2017-06-27 03:29:00+03	71600.00
2B8DB4	2017-07-07 09:09:00+03	130300.00
2B8DCF	2017-08-08 05:25:00+03	133700.00
2B8E07	2017-08-02 07:00:00+03	173500.00
2B8E12	2017-06-28 05:37:00+03	112800.00
2B8F0A	2017-07-13 19:48:00+03	156600.00
2B8F23	2017-08-08 20:06:00+03	48800.00
2B8FDB	2017-07-03 11:59:00+03	27200.00
2B9053	2017-07-15 02:02:00+03	13400.00
2B90A9	2017-07-29 10:09:00+03	43000.00
2B90B3	2017-07-09 23:38:00+03	28000.00
2B9135	2017-07-24 04:25:00+03	68100.00
2B916E	2017-08-04 08:34:00+03	84000.00
2B918F	2017-07-03 00:02:00+03	56900.00
2B919D	2017-07-21 18:17:00+03	91700.00
2B91FE	2017-07-15 00:53:00+03	46400.00
2B924B	2017-08-02 14:05:00+03	56000.00
2B924F	2017-08-07 03:54:00+03	31100.00
2B925B	2017-07-26 04:39:00+03	89600.00
2B9305	2017-07-17 07:36:00+03	243700.00
2B930F	2017-07-25 00:41:00+03	141300.00
2B9324	2017-07-13 10:01:00+03	135400.00
2B9336	2017-07-18 21:38:00+03	49800.00
2B9362	2017-07-08 15:24:00+03	49400.00
2B9365	2017-07-04 09:32:00+03	38600.00
2B9377	2017-07-20 20:31:00+03	246000.00
2B937D	2017-08-09 17:02:00+03	54800.00
2B93C4	2017-08-09 14:17:00+03	63500.00
2B9443	2017-08-01 10:27:00+03	59800.00
2B9525	2017-07-21 23:55:00+03	24800.00
2B9580	2017-07-26 00:19:00+03	84100.00
2B95D9	2017-07-06 23:03:00+03	122400.00
2B95DA	2017-07-13 23:01:00+03	65500.00
2B9690	2017-08-04 08:30:00+03	175300.00
2B96E5	2017-07-23 09:20:00+03	55800.00
2B970C	2017-08-03 04:02:00+03	91000.00
2B973C	2017-07-22 04:04:00+03	94700.00
2B97A4	2017-08-10 12:57:00+03	47200.00
2B97D2	2017-08-14 02:25:00+03	13400.00
2B97E7	2017-07-06 21:34:00+03	22000.00
2B97E9	2017-07-11 19:38:00+03	48800.00
2B9811	2017-08-05 12:22:00+03	43100.00
2B981E	2017-08-10 03:21:00+03	81600.00
2B983A	2017-08-09 09:15:00+03	8200.00
2B987C	2017-08-10 03:27:00+03	25600.00
2B9899	2017-08-04 14:07:00+03	66100.00
2B98A2	2017-07-04 12:37:00+03	12600.00
2B98A8	2017-08-11 06:51:00+03	55800.00
2B98C3	2017-07-16 10:57:00+03	156300.00
2B98CF	2017-07-15 16:42:00+03	123000.00
2B9901	2017-07-05 07:32:00+03	61500.00
2B994E	2017-07-19 11:15:00+03	116600.00
2B9969	2017-07-11 21:10:00+03	16400.00
2B99F6	2017-07-09 13:00:00+03	45100.00
2B9A47	2017-08-02 20:08:00+03	28000.00
2B9A8F	2017-07-18 12:50:00+03	24500.00
2B9AB4	2017-07-26 18:05:00+03	114700.00
2B9ACF	2017-07-29 22:52:00+03	369000.00
2B9ADF	2017-08-09 16:34:00+03	99200.00
2B9B2A	2017-07-06 09:05:00+03	67800.00
2B9B49	2017-06-29 23:53:00+03	177800.00
2B9B80	2017-08-05 20:28:00+03	185400.00
2B9BF2	2017-08-14 11:21:00+03	266400.00
2B9C64	2017-07-26 04:23:00+03	24400.00
2B9C87	2017-07-14 14:57:00+03	29600.00
2B9C9B	2017-06-29 06:26:00+03	91000.00
2B9CE7	2017-07-28 18:10:00+03	53100.00
2B9D21	2017-07-12 16:41:00+03	68600.00
2B9D5F	2017-07-29 03:41:00+03	36800.00
2B9D61	2017-08-12 06:45:00+03	199000.00
2B9D7C	2017-08-05 20:47:00+03	70800.00
2B9DA2	2017-07-16 12:10:00+03	36200.00
2B9DF4	2017-07-31 19:37:00+03	23600.00
2B9E26	2017-08-06 12:27:00+03	11100.00
2B9EDB	2017-07-06 03:04:00+03	95600.00
2B9EF5	2017-07-22 12:11:00+03	46400.00
2B9F6F	2017-07-05 21:31:00+03	190400.00
2B9F87	2017-07-21 22:27:00+03	25900.00
2B9FB5	2017-08-13 16:54:00+03	83200.00
2B9FC9	2017-07-29 09:44:00+03	12400.00
2BA020	2017-08-14 19:47:00+03	234700.00
2BA058	2017-08-08 08:29:00+03	132800.00
2BA103	2017-08-10 18:52:00+03	65900.00
2BA22F	2017-07-13 09:56:00+03	47200.00
2BA255	2017-08-12 10:13:00+03	19600.00
2BA2AC	2017-07-10 16:40:00+03	398500.00
2BA2B4	2017-07-13 13:37:00+03	265800.00
2BA2E2	2017-08-03 02:14:00+03	73200.00
2BA36E	2017-08-03 15:21:00+03	65800.00
2BA3BE	2017-08-05 23:18:00+03	41200.00
2BA41E	2017-07-17 12:11:00+03	16400.00
2BA46C	2017-08-09 16:53:00+03	80800.00
2BA480	2017-07-31 03:11:00+03	25900.00
2BA489	2017-07-22 15:39:00+03	479000.00
2BA491	2017-08-09 15:02:00+03	89700.00
2BA513	2017-07-14 04:43:00+03	54800.00
2BA51D	2017-08-15 15:08:00+03	42500.00
2BA545	2017-08-03 13:58:00+03	68100.00
2BA606	2017-08-05 03:34:00+03	16800.00
2BA632	2017-07-22 17:53:00+03	187900.00
2BA655	2017-08-11 05:17:00+03	32800.00
2BA6A0	2017-07-10 12:03:00+03	58600.00
2BA6CD	2017-07-20 18:55:00+03	28000.00
2BA6E1	2017-07-22 05:45:00+03	172100.00
2BA71B	2017-08-14 17:14:00+03	35100.00
2BA7A1	2017-08-14 04:32:00+03	59300.00
2BA7AF	2017-07-17 07:37:00+03	80800.00
2BA7B3	2017-07-29 19:55:00+03	136200.00
2BA7BC	2017-07-08 09:10:00+03	94000.00
2BA818	2017-08-11 12:54:00+03	58400.00
2BA887	2017-08-10 01:14:00+03	16400.00
2BA918	2017-07-12 13:36:00+03	56000.00
2BA93C	2017-07-12 23:21:00+03	62200.00
2BA982	2017-08-09 16:53:00+03	39300.00
2BAA17	2017-08-08 14:24:00+03	47100.00
2BAA2F	2017-07-04 03:34:00+03	15000.00
2BAA6E	2017-08-08 16:45:00+03	62000.00
2BAA87	2017-07-22 17:32:00+03	280900.00
2BAAAE	2017-07-05 08:12:00+03	109400.00
2BAB0C	2017-08-15 15:04:00+03	7400.00
2BAB4E	2017-07-25 20:02:00+03	39500.00
2BAB52	2017-07-25 19:48:00+03	75300.00
2BAB58	2017-08-13 08:32:00+03	67200.00
2BAB9B	2017-06-27 10:38:00+03	19600.00
2BABAC	2017-07-05 12:31:00+03	46200.00
2BABDB	2017-07-01 03:22:00+03	72200.00
2BAC04	2017-08-13 06:26:00+03	49600.00
2BACC8	2017-07-19 22:19:00+03	47400.00
2BACD0	2017-07-30 13:21:00+03	95700.00
2BACD3	2017-08-04 16:52:00+03	26800.00
2BAD73	2017-07-30 00:17:00+03	23600.00
2BAE3F	2017-08-13 13:48:00+03	24400.00
2BAE4A	2017-07-28 00:13:00+03	186200.00
2BAE6A	2017-08-02 10:05:00+03	246000.00
2BAE94	2017-07-05 03:03:00+03	55800.00
2BAF2A	2017-07-14 14:58:00+03	12600.00
2BAF3C	2017-07-14 06:38:00+03	112000.00
2BAF68	2017-07-23 06:58:00+03	6800.00
2BAF74	2017-08-07 06:12:00+03	28000.00
2BAF8A	2017-07-24 22:34:00+03	41400.00
2BAFB5	2017-07-02 02:36:00+03	19600.00
2BB0AB	2017-08-12 22:40:00+03	51200.00
2BB0CB	2017-07-19 08:59:00+03	27400.00
2BB0F7	2017-08-02 03:30:00+03	55800.00
2BB156	2017-07-10 06:37:00+03	34000.00
2BB16C	2017-07-30 07:39:00+03	52000.00
2BB173	2017-08-03 01:45:00+03	246000.00
2BB17F	2017-07-27 10:06:00+03	6300.00
2BB1CA	2017-07-24 01:49:00+03	56900.00
2BB1D2	2017-08-01 16:11:00+03	56900.00
2BB1D5	2017-07-10 23:03:00+03	43200.00
2BB201	2017-07-13 06:10:00+03	37200.00
2BB252	2017-07-17 03:07:00+03	28000.00
2BB258	2017-07-12 09:11:00+03	46000.00
2BB260	2017-08-12 21:08:00+03	54400.00
2BB2A8	2017-07-17 23:45:00+03	40000.00
2BB2D4	2017-07-16 10:04:00+03	381400.00
2BB36D	2017-07-12 00:43:00+03	98400.00
2BB37B	2017-07-19 14:34:00+03	70800.00
2BB384	2017-08-14 17:59:00+03	23200.00
2BB3A4	2017-07-13 05:00:00+03	81700.00
2BB3DB	2017-07-01 21:53:00+03	23600.00
2BB44B	2017-07-16 23:56:00+03	13600.00
2BB4E6	2017-07-31 04:15:00+03	131100.00
2BB4EA	2017-07-24 16:11:00+03	90800.00
2BB525	2017-07-26 15:09:00+03	47400.00
2BB595	2017-08-09 11:02:00+03	62700.00
2BB59B	2017-08-02 06:43:00+03	26000.00
2BB59C	2017-08-10 17:41:00+03	93700.00
2BB5EF	2017-07-11 17:07:00+03	258400.00
2BB625	2017-08-07 04:09:00+03	43600.00
2BB65D	2017-08-03 07:49:00+03	14800.00
2BB77B	2017-07-07 09:17:00+03	34000.00
2BB7B1	2017-07-10 08:08:00+03	19800.00
2BB809	2017-07-20 11:56:00+03	53300.00
2BB834	2017-08-05 07:21:00+03	58800.00
2BB848	2017-07-29 01:29:00+03	34000.00
2BB8B6	2017-07-25 12:27:00+03	70600.00
2BBA19	2017-07-30 01:22:00+03	48700.00
2BBA28	2017-07-12 00:28:00+03	31000.00
2BBA38	2017-08-10 11:34:00+03	58200.00
2BBA66	2017-07-21 14:29:00+03	9800.00
2BBA80	2017-07-17 20:07:00+03	55800.00
2BBAFB	2017-07-26 06:37:00+03	55800.00
2BBB6C	2017-06-30 02:02:00+03	26000.00
2BBBB3	2017-07-21 18:16:00+03	32900.00
2BBBEE	2017-07-28 03:43:00+03	369000.00
2BBC51	2017-08-09 03:06:00+03	13800.00
2BBC84	2017-08-01 19:03:00+03	21800.00
2BBCAD	2017-07-12 10:41:00+03	59100.00
2BBCBA	2017-08-07 13:54:00+03	141600.00
2BBD06	2017-07-20 20:16:00+03	48500.00
2BBD1B	2017-07-19 22:24:00+03	38200.00
2BBD63	2017-07-26 04:22:00+03	48400.00
2BBD8B	2017-07-19 15:58:00+03	37900.00
2BBDF2	2017-07-18 18:53:00+03	42400.00
2BBE1B	2017-07-23 10:10:00+03	25100.00
2BBE91	2017-07-22 02:29:00+03	66600.00
2BBEA6	2017-08-01 08:47:00+03	79600.00
2BBECA	2017-08-11 06:19:00+03	406700.00
2BBF30	2017-07-16 11:12:00+03	28800.00
2BBF85	2017-07-14 19:13:00+03	22200.00
2BC038	2017-07-14 20:19:00+03	54800.00
2BC069	2017-07-06 23:22:00+03	108200.00
2BC088	2017-07-26 09:38:00+03	19600.00
2BC0D1	2017-08-04 17:05:00+03	202300.00
2BC0E7	2017-07-03 00:48:00+03	46800.00
2BC13C	2017-07-26 12:55:00+03	80100.00
2BC1AA	2017-07-15 14:35:00+03	149300.00
2BC1FB	2017-07-21 21:13:00+03	253200.00
2BC200	2017-07-27 07:51:00+03	58600.00
2BC21A	2017-07-21 19:20:00+03	13400.00
2BC232	2017-08-09 08:05:00+03	58600.00
2BC266	2017-06-30 17:00:00+03	112600.00
2BC2D3	2017-07-30 02:21:00+03	19600.00
2BC30F	2017-07-27 05:00:00+03	22300.00
2BC33A	2017-08-12 07:39:00+03	24600.00
2BC386	2017-07-26 11:29:00+03	13400.00
2BC3A9	2017-08-12 23:35:00+03	31900.00
2BC3C8	2017-07-15 04:14:00+03	244100.00
2BC45C	2017-08-03 00:37:00+03	35300.00
2BC49E	2017-08-04 01:28:00+03	146300.00
2BC4C6	2017-07-28 01:07:00+03	248500.00
2BC4FA	2017-07-15 00:17:00+03	16400.00
2BC57F	2017-07-26 11:45:00+03	246000.00
2BC580	2017-07-17 02:23:00+03	66000.00
2BC58D	2017-07-16 22:35:00+03	58600.00
2BC5F0	2017-07-26 22:06:00+03	102200.00
2BC62B	2017-07-29 20:37:00+03	35200.00
2BC708	2017-08-08 03:40:00+03	46700.00
2BC72A	2017-08-07 14:06:00+03	6700.00
2BC749	2017-08-12 07:55:00+03	26000.00
2BC752	2017-07-21 05:27:00+03	44800.00
2BC75E	2017-07-31 01:37:00+03	51900.00
2BC7FD	2017-07-16 17:36:00+03	114700.00
2BC83E	2017-07-17 03:40:00+03	75600.00
2BC853	2017-07-17 09:18:00+03	27300.00
2BC85C	2017-07-08 07:51:00+03	69700.00
2BC886	2017-07-06 05:33:00+03	34600.00
2BC8CF	2017-08-09 23:21:00+03	7400.00
2BC8D3	2017-07-07 03:46:00+03	40800.00
2BC8DF	2017-07-26 16:30:00+03	100600.00
2BC8F7	2017-07-23 11:53:00+03	132000.00
2BC9C9	2017-08-04 04:13:00+03	32200.00
2BC9D4	2017-07-27 14:42:00+03	65500.00
2BCAA1	2017-07-31 06:51:00+03	62700.00
2BCAC8	2017-07-09 19:40:00+03	13400.00
2BCB42	2017-08-12 21:02:00+03	101200.00
2BCB7B	2017-07-07 00:09:00+03	95600.00
2BCBE4	2017-06-29 19:20:00+03	106300.00
2BCC6D	2017-08-07 04:21:00+03	135400.00
2BCC7E	2017-06-29 07:37:00+03	396800.00
2BCD70	2017-07-02 04:12:00+03	92800.00
2BCD74	2017-06-30 00:00:00+03	68800.00
2BCDCF	2017-07-17 06:34:00+03	75200.00
2BCDDA	2017-08-02 11:46:00+03	14800.00
2BCDE5	2017-07-05 09:02:00+03	227000.00
2BCE30	2017-08-09 04:09:00+03	36200.00
2BCED2	2017-07-24 19:51:00+03	77400.00
2BCF44	2017-06-29 16:25:00+03	68400.00
2BCF9A	2017-08-08 01:21:00+03	21800.00
2BCFA5	2017-07-25 14:13:00+03	396400.00
2BD065	2017-07-24 05:34:00+03	173900.00
2BD07C	2017-07-05 20:06:00+03	24400.00
2BD086	2017-07-09 05:21:00+03	112000.00
2BD0B9	2017-08-13 23:08:00+03	23600.00
2BD0EB	2017-07-12 16:29:00+03	70000.00
2BD198	2017-08-10 15:55:00+03	91800.00
2BD20F	2017-07-11 03:59:00+03	173400.00
2BD234	2017-07-07 05:05:00+03	115800.00
2BD245	2017-07-23 00:25:00+03	137100.00
2BD2D7	2017-07-29 00:33:00+03	54400.00
2BD30B	2017-07-27 21:27:00+03	14000.00
2BD343	2017-07-26 07:03:00+03	131600.00
2BD353	2017-07-16 04:29:00+03	96800.00
2BD377	2017-08-06 08:52:00+03	73600.00
2BD3A1	2017-08-15 16:28:00+03	6000.00
2BD3AB	2017-07-03 10:44:00+03	46400.00
2BD3AC	2017-07-30 13:04:00+03	69500.00
2BD3D0	2017-07-11 08:14:00+03	112000.00
2BD3E0	2017-08-14 01:21:00+03	13400.00
2BD414	2017-08-11 02:22:00+03	39300.00
2BD437	2017-08-06 12:18:00+03	50000.00
2BD441	2017-06-30 23:11:00+03	78200.00
2BD48A	2017-08-02 15:31:00+03	20200.00
2BD49B	2017-07-16 03:26:00+03	251400.00
2BD5F1	2017-07-09 11:48:00+03	56000.00
2BD5F9	2017-07-16 14:47:00+03	23200.00
2BD612	2017-07-30 02:42:00+03	216600.00
2BD615	2017-07-18 11:14:00+03	29600.00
2BD633	2017-07-22 19:35:00+03	16400.00
2BD67B	2017-08-01 07:39:00+03	64500.00
2BD6C5	2017-08-02 14:21:00+03	50000.00
2BD6C8	2017-08-01 08:27:00+03	32800.00
2BD6E9	2017-07-21 07:42:00+03	33300.00
2BD6EE	2017-07-03 16:21:00+03	27800.00
2BD712	2017-08-06 05:14:00+03	121500.00
2BD718	2017-07-12 21:15:00+03	116000.00
2BD736	2017-08-08 07:19:00+03	166000.00
2BD76A	2017-07-16 22:04:00+03	117000.00
2BD77B	2017-07-02 22:53:00+03	55800.00
2BD77D	2017-07-23 08:05:00+03	22000.00
2BD79C	2017-07-14 03:52:00+03	57400.00
2BD830	2017-07-29 16:10:00+03	22000.00
2BD853	2017-08-05 08:27:00+03	26100.00
2BD868	2017-07-08 22:12:00+03	15800.00
2BD919	2017-07-11 17:04:00+03	96300.00
2BD952	2017-07-04 07:51:00+03	69700.00
2BD99C	2017-08-08 19:24:00+03	113800.00
2BD9A5	2017-07-29 13:19:00+03	40800.00
2BD9B3	2017-07-24 13:19:00+03	27200.00
2BD9CA	2017-07-28 15:22:00+03	10800.00
2BD9CD	2017-08-06 20:36:00+03	24000.00
2BDA36	2017-07-23 15:19:00+03	58400.00
2BDA53	2017-08-08 03:06:00+03	13200.00
2BDA66	2017-08-10 14:34:00+03	14800.00
2BDA7F	2017-08-03 14:42:00+03	15400.00
2BDB33	2017-08-14 04:37:00+03	169900.00
2BDB98	2017-07-04 17:47:00+03	246000.00
2BDBD2	2017-08-08 06:19:00+03	7400.00
2BDC2A	2017-08-07 00:56:00+03	47200.00
2BDC55	2017-07-08 10:15:00+03	68100.00
2BDC70	2017-08-15 15:50:00+03	73600.00
2BDC77	2017-07-27 21:42:00+03	23200.00
2BDD30	2017-07-09 22:35:00+03	58800.00
2BDD37	2017-08-12 12:52:00+03	36800.00
2BDD44	2017-07-11 16:16:00+03	136200.00
2BDD5B	2017-08-14 09:44:00+03	19600.00
2BDD60	2017-07-09 06:24:00+03	81300.00
2BDDD1	2017-07-30 22:12:00+03	24400.00
2BDDF7	2017-07-09 03:40:00+03	59300.00
2BDE06	2017-07-12 12:06:00+03	66600.00
2BDE23	2017-08-12 00:10:00+03	30000.00
2BDE30	2017-08-13 15:35:00+03	44800.00
2BDE3E	2017-07-24 18:53:00+03	26600.00
2BDE43	2017-08-12 16:39:00+03	66600.00
2BDE5D	2017-07-02 21:36:00+03	23200.00
2BDF23	2017-07-12 13:04:00+03	10700.00
2BDF43	2017-08-13 11:37:00+03	24000.00
2BDF77	2017-08-11 20:13:00+03	94800.00
2BDFD1	2017-08-11 21:07:00+03	128800.00
2BDFD4	2017-07-30 21:05:00+03	55800.00
2BDFE9	2017-07-09 11:17:00+03	56000.00
2BE02F	2017-08-13 08:47:00+03	34200.00
2BE0A1	2017-08-03 22:12:00+03	62700.00
2BE0A2	2017-07-22 00:54:00+03	23200.00
2BE0F7	2017-07-03 01:40:00+03	49800.00
2BE184	2017-07-23 22:25:00+03	202800.00
2BE206	2017-08-14 12:52:00+03	46400.00
2BE21B	2017-08-04 21:33:00+03	6800.00
2BE220	2017-07-07 21:47:00+03	29300.00
2BE234	2017-07-21 03:34:00+03	34400.00
2BE281	2017-07-16 02:35:00+03	6400.00
2BE292	2017-08-01 21:10:00+03	64700.00
2BE2F8	2017-07-04 01:25:00+03	16400.00
2BE384	2017-08-10 10:30:00+03	94400.00
2BE3DC	2017-08-06 17:22:00+03	70700.00
2BE3F0	2017-07-17 01:32:00+03	57500.00
2BE483	2017-07-16 12:06:00+03	24200.00
2BE49F	2017-08-14 15:29:00+03	105100.00
2BE4AE	2017-07-07 21:04:00+03	12400.00
2BE4B1	2017-07-02 11:07:00+03	49500.00
2BE4B5	2017-07-16 15:00:00+03	69500.00
2BE546	2017-07-11 18:17:00+03	26900.00
2BE58B	2017-08-03 13:02:00+03	11600.00
2BE595	2017-07-19 06:06:00+03	11600.00
2BE5B9	2017-07-25 16:07:00+03	36200.00
2BE5D3	2017-08-13 10:24:00+03	12600.00
2BE5ED	2017-07-17 18:28:00+03	57500.00
2BE5F1	2017-08-07 21:28:00+03	20500.00
2BE65E	2017-08-07 15:37:00+03	16400.00
2BE690	2017-07-23 16:56:00+03	46000.00
2BE6AA	2017-08-15 11:02:00+03	42300.00
2BE6AB	2017-08-08 02:33:00+03	111600.00
2BE6C7	2017-08-03 04:03:00+03	181100.00
2BE727	2017-08-08 18:32:00+03	26000.00
2BE7FC	2017-07-21 08:21:00+03	58800.00
2BE842	2017-07-16 15:18:00+03	61500.00
2BE849	2017-07-30 14:20:00+03	224000.00
2BE84F	2017-07-24 17:35:00+03	91500.00
2BE878	2017-07-21 22:38:00+03	29200.00
2BE886	2017-07-15 06:01:00+03	15400.00
2BE8A7	2017-07-28 14:16:00+03	23600.00
2BE8C0	2017-07-29 17:11:00+03	43100.00
2BE915	2017-07-27 06:14:00+03	131100.00
2BE969	2017-07-14 09:28:00+03	23200.00
2BEA1B	2017-07-05 11:41:00+03	22000.00
2BEA5B	2017-08-14 23:25:00+03	13400.00
2BEA61	2017-07-12 01:34:00+03	123000.00
2BEB19	2017-07-25 00:46:00+03	58800.00
2BEB89	2017-07-04 02:22:00+03	27200.00
2BEBE6	2017-07-26 02:41:00+03	23200.00
2BEC05	2017-07-06 06:17:00+03	22000.00
2BEC49	2017-08-15 14:05:00+03	38300.00
2BEC64	2017-08-01 17:06:00+03	109600.00
2BEC73	2017-06-27 08:59:00+03	67900.00
2BED59	2017-07-18 20:14:00+03	40800.00
2BED6A	2017-07-31 07:37:00+03	290500.00
2BED93	2017-07-12 06:31:00+03	57300.00
2BEDB4	2017-08-14 23:28:00+03	40800.00
2BEDE2	2017-07-12 01:30:00+03	16400.00
2BEDFD	2017-07-01 09:57:00+03	33800.00
2BEE12	2017-07-05 04:25:00+03	75200.00
2BEE18	2017-07-17 12:57:00+03	139100.00
2BEE35	2017-08-05 08:19:00+03	94900.00
2BEE96	2017-07-31 08:27:00+03	25900.00
2BEEA3	2017-07-14 13:48:00+03	39400.00
2BEED3	2017-08-15 12:46:00+03	71200.00
2BEEEB	2017-07-13 21:16:00+03	67600.00
2BEEFC	2017-08-02 14:20:00+03	199300.00
2BEF52	2017-08-09 18:09:00+03	262200.00
2BEFB7	2017-08-12 10:30:00+03	11600.00
2BF018	2017-07-13 12:07:00+03	193200.00
2BF06A	2017-08-08 08:06:00+03	103600.00
2BF092	2017-08-14 13:53:00+03	34200.00
2BF0EC	2017-07-17 04:30:00+03	83500.00
2BF0F5	2017-07-13 01:35:00+03	24300.00
2BF150	2017-08-12 09:52:00+03	58200.00
2BF15F	2017-07-03 21:08:00+03	58200.00
2BF165	2017-08-02 01:14:00+03	36800.00
2BF19D	2017-08-15 16:40:00+03	187900.00
2BF1E1	2017-07-08 07:49:00+03	21200.00
2BF1FE	2017-08-15 05:40:00+03	80400.00
2BF216	2017-08-15 17:31:00+03	6300.00
2BF228	2017-07-22 18:08:00+03	128800.00
2BF24E	2017-07-31 12:23:00+03	43000.00
2BF254	2017-07-07 21:47:00+03	393800.00
2BF277	2017-07-21 10:19:00+03	148800.00
2BF283	2017-08-04 15:52:00+03	58600.00
2BF293	2017-07-09 16:04:00+03	60400.00
2BF2C0	2017-07-01 05:06:00+03	24300.00
2BF2F0	2017-07-16 04:48:00+03	99200.00
2BF303	2017-08-12 05:22:00+03	93900.00
2BF382	2017-08-02 17:13:00+03	24200.00
2BF388	2017-08-10 19:57:00+03	83200.00
2BF39A	2017-07-16 17:55:00+03	128800.00
2BF3F0	2017-08-02 07:04:00+03	135400.00
2BF3F3	2017-08-09 17:31:00+03	81900.00
2BF47C	2017-08-03 11:16:00+03	22600.00
2BF4A6	2017-07-03 17:04:00+03	129600.00
2BF51B	2017-08-04 03:23:00+03	99700.00
2BF530	2017-08-08 12:22:00+03	27800.00
2BF54C	2017-08-11 16:50:00+03	419100.00
2BF589	2017-06-26 18:13:00+03	62700.00
2BF5B5	2017-07-04 14:28:00+03	56000.00
2BF5CE	2017-07-23 04:24:00+03	68600.00
2BF603	2017-07-16 19:26:00+03	86800.00
2BF636	2017-07-11 15:10:00+03	54800.00
2BF64A	2017-08-04 03:39:00+03	56000.00
2BF6AE	2017-07-27 10:08:00+03	46200.00
2BF6E0	2017-07-24 23:37:00+03	22000.00
2BF74F	2017-07-04 16:53:00+03	37700.00
2BF7EA	2017-08-09 20:13:00+03	43700.00
2BF828	2017-07-26 10:25:00+03	135100.00
2BF853	2017-07-06 04:05:00+03	7200.00
2BF86F	2017-07-19 17:12:00+03	56000.00
2BF872	2017-07-23 10:42:00+03	23600.00
2BF882	2017-07-11 19:43:00+03	24400.00
2BF8C9	2017-07-20 09:56:00+03	23600.00
2BF96C	2017-07-24 14:14:00+03	93900.00
2BF989	2017-07-19 22:40:00+03	70000.00
2BF99A	2017-07-03 17:51:00+03	29600.00
2BF9C8	2017-07-03 09:39:00+03	266500.00
2BF9D9	2017-08-05 00:51:00+03	44000.00
2BFA1F	2017-08-03 21:50:00+03	70700.00
2BFA41	2017-08-14 03:07:00+03	69100.00
2BFA44	2017-07-12 03:06:00+03	56000.00
2BFAA9	2017-08-04 21:09:00+03	192700.00
2BFAEF	2017-07-07 15:32:00+03	33100.00
2BFB19	2017-07-15 08:37:00+03	133100.00
2BFB56	2017-07-05 09:10:00+03	60800.00
2BFB8A	2017-08-12 09:53:00+03	29100.00
2BFBBC	2017-07-07 13:48:00+03	56600.00
2BFBED	2017-08-01 17:52:00+03	174800.00
2BFC02	2017-07-05 18:33:00+03	91600.00
2BFC09	2017-07-31 05:38:00+03	56100.00
2BFC62	2017-08-07 17:00:00+03	70700.00
2BFCD6	2017-07-29 13:26:00+03	44800.00
2BFCD7	2017-07-20 23:17:00+03	28800.00
2BFCE3	2017-07-02 06:38:00+03	56000.00
2BFCF9	2017-07-13 16:59:00+03	58800.00
2BFD35	2017-08-02 16:52:00+03	399600.00
2BFD52	2017-07-13 09:48:00+03	67100.00
2BFDA2	2017-07-28 05:52:00+03	44000.00
2BFDBE	2017-07-17 18:55:00+03	30200.00
2BFE1A	2017-07-13 05:14:00+03	69200.00
2BFE20	2017-08-07 07:55:00+03	116400.00
2BFEDE	2017-07-30 10:17:00+03	58400.00
2BFF01	2017-07-07 06:33:00+03	70600.00
2BFF10	2017-07-07 16:02:00+03	38300.00
2BFFEF	2017-08-12 05:49:00+03	72300.00
2BFFF5	2017-08-14 18:28:00+03	266200.00
2C0015	2017-07-02 22:24:00+03	36500.00
2C001E	2017-08-03 06:27:00+03	54800.00
2C0040	2017-07-31 06:12:00+03	96800.00
2C005E	2017-08-11 16:28:00+03	17800.00
2C0064	2017-08-11 05:08:00+03	90800.00
2C0067	2017-08-12 07:35:00+03	75100.00
2C00D2	2017-07-10 21:05:00+03	219700.00
2C0100	2017-07-22 22:09:00+03	41400.00
2C0162	2017-07-24 12:14:00+03	526800.00
2C016B	2017-08-07 04:31:00+03	29600.00
2C01E1	2017-07-14 00:34:00+03	26100.00
2C0227	2017-08-12 20:17:00+03	42900.00
2C026D	2017-08-13 13:18:00+03	6700.00
2C0341	2017-07-04 10:01:00+03	67600.00
2C0369	2017-07-26 23:08:00+03	40400.00
2C0436	2017-07-28 05:37:00+03	91600.00
2C0438	2017-07-14 02:57:00+03	22000.00
2C046F	2017-08-02 11:08:00+03	72400.00
2C0490	2017-08-05 06:36:00+03	92600.00
2C04C2	2017-08-08 05:47:00+03	49400.00
2C0519	2017-07-01 23:45:00+03	8200.00
2C0532	2017-07-02 06:54:00+03	50400.00
2C0588	2017-07-23 20:24:00+03	42400.00
2C059E	2017-08-11 09:34:00+03	101200.00
2C05DA	2017-08-15 08:51:00+03	64700.00
2C05F7	2017-07-11 13:50:00+03	96300.00
2C0633	2017-07-26 03:07:00+03	11700.00
2C06C2	2017-08-02 23:40:00+03	47400.00
2C0719	2017-07-10 06:01:00+03	112000.00
2C0814	2017-07-24 17:14:00+03	92800.00
2C081F	2017-07-01 23:42:00+03	29100.00
2C0832	2017-07-08 05:25:00+03	69200.00
2C083B	2017-07-04 13:52:00+03	46200.00
2C0842	2017-07-30 09:42:00+03	89700.00
2C089C	2017-07-04 22:41:00+03	66600.00
2C0964	2017-07-26 00:58:00+03	44200.00
2C09AE	2017-08-04 19:53:00+03	123700.00
2C09F2	2017-06-26 06:16:00+03	53300.00
2C0A84	2017-07-26 23:58:00+03	26700.00
2C0AEF	2017-08-15 16:44:00+03	24000.00
2C0B4F	2017-07-27 19:12:00+03	114800.00
2C0BA3	2017-08-12 06:16:00+03	12400.00
2C0BBB	2017-08-09 09:11:00+03	92000.00
2C0C1B	2017-08-14 04:07:00+03	94800.00
2C0C44	2017-08-13 07:49:00+03	82900.00
2C0C53	2017-07-19 10:51:00+03	58800.00
2C0C76	2017-07-17 09:16:00+03	20000.00
2C0C9A	2017-08-09 07:24:00+03	23600.00
2C0D30	2017-07-28 03:23:00+03	53700.00
2C0DA6	2017-07-06 06:46:00+03	40100.00
2C0DE9	2017-07-05 09:10:00+03	65600.00
2C0DEF	2017-07-11 05:18:00+03	94000.00
2C0E13	2017-07-28 20:04:00+03	72000.00
2C0E1A	2017-08-11 18:47:00+03	15400.00
2C0E78	2017-08-06 14:26:00+03	47700.00
2C0F29	2017-08-15 14:04:00+03	6700.00
2C0F55	2017-07-01 06:07:00+03	68900.00
2C0FCA	2017-08-15 09:36:00+03	25800.00
2C105C	2017-08-13 19:16:00+03	37900.00
2C1090	2017-08-03 06:32:00+03	111600.00
2C10D5	2017-07-26 18:33:00+03	156300.00
2C10EB	2017-07-28 02:50:00+03	49300.00
2C1142	2017-07-18 17:36:00+03	47200.00
2C11BC	2017-08-02 14:33:00+03	46400.00
2C11D3	2017-07-26 20:23:00+03	23200.00
2C11EE	2017-08-08 17:27:00+03	19800.00
2C1201	2017-07-11 23:50:00+03	47500.00
2C1213	2017-08-07 08:20:00+03	24400.00
2C1233	2017-07-30 22:25:00+03	44800.00
2C124A	2017-08-05 14:17:00+03	56000.00
2C1250	2017-08-01 15:44:00+03	11700.00
2C1251	2017-07-19 18:44:00+03	531400.00
2C12A9	2017-07-27 04:32:00+03	56600.00
2C12C1	2017-07-03 20:35:00+03	94000.00
2C12FC	2017-07-22 07:32:00+03	152500.00
2C135A	2017-08-01 13:21:00+03	62100.00
2C1381	2017-07-13 10:09:00+03	42700.00
2C13D7	2017-07-25 13:36:00+03	38400.00
2C1400	2017-08-10 15:42:00+03	33600.00
2C141D	2017-07-14 00:32:00+03	182000.00
2C1436	2017-07-11 16:38:00+03	23400.00
2C143D	2017-07-15 11:50:00+03	55800.00
2C1441	2017-07-16 15:06:00+03	38800.00
2C144A	2017-08-09 19:41:00+03	26000.00
2C1470	2017-07-17 21:26:00+03	16400.00
2C147F	2017-07-17 20:14:00+03	112000.00
2C1496	2017-08-14 22:08:00+03	16800.00
2C14E8	2017-08-09 13:50:00+03	96100.00
2C1555	2017-08-09 20:51:00+03	218000.00
2C1574	2017-07-13 13:50:00+03	28800.00
2C1579	2017-08-03 05:08:00+03	123600.00
2C158C	2017-07-20 15:54:00+03	37200.00
2C1626	2017-08-14 05:54:00+03	36000.00
2C1643	2017-08-05 07:58:00+03	54800.00
2C1666	2017-07-02 08:11:00+03	68400.00
2C169D	2017-07-31 14:10:00+03	46400.00
2C16EF	2017-07-19 09:39:00+03	50600.00
2C17BF	2017-08-06 16:28:00+03	24400.00
2C17FE	2017-08-14 12:19:00+03	7300.00
2C185C	2017-07-02 05:43:00+03	40800.00
2C1870	2017-08-03 04:11:00+03	46400.00
2C188B	2017-07-02 03:56:00+03	60400.00
2C18AE	2017-08-07 11:01:00+03	61800.00
2C192F	2017-08-04 18:34:00+03	20400.00
2C1937	2017-07-29 02:29:00+03	160200.00
2C198A	2017-07-23 20:03:00+03	25900.00
2C19B8	2017-07-25 16:39:00+03	16000.00
2C19E9	2017-07-14 14:27:00+03	265700.00
2C1A07	2017-07-24 07:32:00+03	28000.00
2C1A0C	2017-07-24 04:13:00+03	25600.00
2C1A15	2017-07-15 16:21:00+03	43100.00
2C1A41	2017-07-07 07:09:00+03	31600.00
2C1A75	2017-07-10 09:50:00+03	24800.00
2C1AAB	2017-07-22 10:08:00+03	44800.00
2C1AB2	2017-07-20 20:41:00+03	76600.00
2C1AF4	2017-07-27 03:49:00+03	92800.00
2C1B82	2017-07-16 13:56:00+03	23600.00
2C1B93	2017-07-26 09:56:00+03	20400.00
2C1BD5	2017-07-16 21:24:00+03	13400.00
2C1BEF	2017-08-07 09:24:00+03	27700.00
2C1C93	2017-07-07 22:37:00+03	43200.00
2C1CE4	2017-08-03 07:34:00+03	124300.00
2C1CFA	2017-07-29 05:46:00+03	36400.00
2C1D34	2017-08-09 05:40:00+03	65900.00
2C1DFC	2017-08-10 17:08:00+03	179300.00
2C1E01	2017-07-18 18:13:00+03	100600.00
2C1E69	2017-07-08 15:05:00+03	65800.00
2C1EA0	2017-08-15 16:36:00+03	46800.00
2C1EA7	2017-07-05 20:15:00+03	27300.00
2C1F5A	2017-07-28 02:34:00+03	32400.00
2C2030	2017-07-27 15:45:00+03	86500.00
2C2081	2017-08-02 22:26:00+03	13600.00
2C20FC	2017-07-28 01:54:00+03	56000.00
2C210E	2017-08-04 05:35:00+03	131100.00
2C2111	2017-07-16 05:24:00+03	31600.00
2C215E	2017-07-31 05:09:00+03	145300.00
2C2180	2017-07-09 12:38:00+03	228700.00
2C2199	2017-08-12 15:38:00+03	42600.00
2C219F	2017-08-11 22:18:00+03	41800.00
2C224E	2017-08-01 08:28:00+03	120100.00
2C2261	2017-07-15 22:05:00+03	19600.00
2C2282	2017-07-29 16:49:00+03	239000.00
2C2295	2017-08-08 17:20:00+03	45200.00
2C22D6	2017-08-12 20:18:00+03	106400.00
2C231C	2017-08-13 22:38:00+03	44800.00
2C233E	2017-07-10 04:03:00+03	51300.00
2C236F	2017-08-07 01:36:00+03	40400.00
2C2389	2017-07-11 14:22:00+03	38800.00
2C24F4	2017-07-23 21:42:00+03	96300.00
2C2507	2017-08-07 16:27:00+03	46400.00
2C250F	2017-07-12 21:57:00+03	84000.00
2C251D	2017-07-26 01:39:00+03	55800.00
2C2525	2017-08-10 00:11:00+03	136200.00
2C2547	2017-07-01 06:03:00+03	34100.00
2C256F	2017-07-21 00:46:00+03	13400.00
2C259D	2017-08-08 01:57:00+03	22200.00
2C25EE	2017-07-19 14:02:00+03	153200.00
2C2636	2017-07-07 07:48:00+03	66200.00
2C265F	2017-08-06 12:24:00+03	43200.00
2C2695	2017-07-15 18:09:00+03	54800.00
2C26AD	2017-07-09 15:36:00+03	32700.00
2C2705	2017-07-22 11:18:00+03	123000.00
2C2718	2017-08-04 12:49:00+03	188000.00
2C273B	2017-07-26 02:56:00+03	68800.00
2C275E	2017-07-20 19:45:00+03	21800.00
2C2792	2017-07-23 13:49:00+03	88000.00
2C27EA	2017-07-27 04:01:00+03	80000.00
2C28C8	2017-07-15 19:18:00+03	61700.00
2C28E5	2017-07-14 13:37:00+03	68400.00
2C2926	2017-07-22 08:15:00+03	70600.00
2C2951	2017-08-14 00:52:00+03	133100.00
2C299E	2017-07-22 10:30:00+03	111600.00
2C29E2	2017-07-03 17:08:00+03	38300.00
2C2A17	2017-08-08 15:43:00+03	12600.00
2C2A58	2017-07-11 03:46:00+03	21400.00
2C2AB4	2017-07-21 08:41:00+03	28300.00
2C2AC0	2017-08-05 21:53:00+03	266200.00
2C2AE0	2017-07-08 01:07:00+03	57800.00
2C2AF0	2017-08-07 07:59:00+03	41600.00
2C2B15	2017-07-15 17:33:00+03	197000.00
2C2B8B	2017-07-04 01:51:00+03	18600.00
2C2BC2	2017-07-04 18:28:00+03	133200.00
2C2BED	2017-08-12 23:53:00+03	169900.00
2C2C5E	2017-07-18 06:51:00+03	66600.00
2C2C7E	2017-07-08 19:30:00+03	38600.00
2C2CAF	2017-07-26 10:21:00+03	92800.00
2C2D23	2017-07-21 05:16:00+03	26000.00
2C2D43	2017-07-20 04:56:00+03	12000.00
2C2D90	2017-07-10 13:34:00+03	168300.00
2C2DD1	2017-07-17 02:10:00+03	101200.00
2C2DE0	2017-07-20 01:40:00+03	45200.00
2C2E33	2017-07-09 19:01:00+03	72600.00
2C2EC3	2017-07-29 14:00:00+03	14400.00
2C2ED9	2017-07-15 04:05:00+03	56600.00
2C2F40	2017-08-05 01:25:00+03	20200.00
2C2F6F	2017-07-31 15:06:00+03	41200.00
2C2FEC	2017-08-02 16:34:00+03	6300.00
2C3062	2017-07-19 15:53:00+03	6700.00
2C3082	2017-07-27 06:48:00+03	70700.00
2C3092	2017-08-15 05:54:00+03	20200.00
2C30A2	2017-08-07 22:43:00+03	179400.00
2C3123	2017-08-04 21:09:00+03	43000.00
2C3150	2017-08-01 14:06:00+03	106400.00
2C31B8	2017-07-13 01:54:00+03	31400.00
2C31D2	2017-08-03 09:01:00+03	13300.00
2C326A	2017-08-05 00:12:00+03	32200.00
2C32A1	2017-07-18 10:14:00+03	36600.00
2C32A2	2017-07-14 09:30:00+03	62900.00
2C32D2	2017-07-03 04:10:00+03	28000.00
2C32DD	2017-07-14 09:50:00+03	31000.00
2C32E2	2017-07-11 18:01:00+03	68100.00
2C3332	2017-07-17 00:49:00+03	8200.00
2C3369	2017-07-18 12:35:00+03	83000.00
2C3416	2017-07-15 19:00:00+03	73500.00
2C3490	2017-08-12 18:09:00+03	56600.00
2C34A0	2017-07-05 11:28:00+03	52700.00
2C34A7	2017-07-22 00:28:00+03	44500.00
2C350E	2017-07-13 02:30:00+03	31700.00
2C3555	2017-07-16 16:20:00+03	8000.00
2C355B	2017-07-11 00:18:00+03	6700.00
2C358A	2017-08-03 04:38:00+03	58600.00
2C3596	2017-07-12 06:49:00+03	30700.00
2C35C1	2017-08-04 01:51:00+03	44600.00
2C360F	2017-07-30 17:41:00+03	62600.00
2C36CE	2017-07-06 18:31:00+03	89700.00
2C36F0	2017-07-05 18:13:00+03	27800.00
2C373A	2017-07-31 03:06:00+03	40800.00
2C37BE	2017-08-06 17:53:00+03	69000.00
2C37EE	2017-08-14 04:52:00+03	15000.00
2C38B0	2017-08-02 08:54:00+03	21800.00
2C39BF	2017-08-10 04:31:00+03	109400.00
2C3AE1	2017-06-28 14:53:00+03	12600.00
2C3AE4	2017-07-10 03:21:00+03	111600.00
2C3AFE	2017-07-19 09:28:00+03	16400.00
2C3B6B	2017-07-14 18:35:00+03	24400.00
2C3BB9	2017-07-18 08:29:00+03	78500.00
2C3BC4	2017-07-21 00:43:00+03	56000.00
2C3C30	2017-07-07 23:20:00+03	115600.00
2C3C45	2017-07-28 11:28:00+03	44100.00
2C3C8A	2017-08-05 04:49:00+03	23600.00
2C3D73	2017-08-13 21:12:00+03	126500.00
2C3DA1	2017-08-04 18:44:00+03	135400.00
2C3DEB	2017-07-24 03:32:00+03	56600.00
2C3DF0	2017-07-17 07:59:00+03	64700.00
2C3E17	2017-07-03 10:55:00+03	39800.00
2C3E5F	2017-08-06 16:08:00+03	85700.00
2C3E89	2017-07-17 03:49:00+03	28000.00
2C3EDF	2017-08-10 23:49:00+03	23100.00
2C3F11	2017-08-11 19:48:00+03	23200.00
2C3FE4	2017-08-11 19:57:00+03	199700.00
2C3FFA	2017-07-17 01:45:00+03	86300.00
2C4035	2017-07-03 11:01:00+03	38800.00
2C4055	2017-07-09 06:55:00+03	133200.00
2C4068	2017-07-17 09:28:00+03	561800.00
2C4098	2017-08-06 17:14:00+03	31900.00
2C40CC	2017-08-11 13:38:00+03	184500.00
2C418F	2017-06-28 10:10:00+03	57400.00
2C41DD	2017-06-30 01:19:00+03	47400.00
2C41EF	2017-07-26 08:04:00+03	95600.00
2C41FF	2017-08-06 05:48:00+03	40000.00
2C4209	2017-07-16 10:13:00+03	102100.00
2C4263	2017-07-21 16:00:00+03	43600.00
2C439D	2017-07-12 20:55:00+03	29600.00
2C43C3	2017-07-29 07:27:00+03	41900.00
2C4408	2017-08-05 10:03:00+03	396200.00
2C4421	2017-07-05 04:03:00+03	20800.00
2C446E	2017-08-06 12:46:00+03	186900.00
2C44AF	2017-07-18 09:15:00+03	196400.00
2C451D	2017-08-02 17:12:00+03	198900.00
2C4567	2017-08-08 10:30:00+03	83000.00
2C45CC	2017-07-07 01:54:00+03	16400.00
2C45D9	2017-07-18 19:04:00+03	9800.00
2C4645	2017-07-06 13:21:00+03	55800.00
2C471F	2017-08-07 07:45:00+03	44600.00
2C4733	2017-07-17 07:21:00+03	128800.00
2C4750	2017-07-28 09:22:00+03	96300.00
2C475F	2017-08-10 07:09:00+03	21400.00
2C47E8	2017-08-05 13:14:00+03	60700.00
2C47F1	2017-07-13 07:06:00+03	26000.00
2C47F5	2017-07-01 16:06:00+03	38400.00
2C483B	2017-07-25 07:53:00+03	34100.00
2C48D9	2017-08-05 23:51:00+03	8200.00
2C48FB	2017-08-01 22:10:00+03	67700.00
2C4910	2017-07-09 07:09:00+03	201800.00
2C4927	2017-08-12 02:03:00+03	38200.00
2C4971	2017-07-26 06:47:00+03	28000.00
2C497D	2017-07-31 20:43:00+03	78700.00
2C4994	2017-08-15 09:03:00+03	64800.00
2C49EF	2017-07-16 23:03:00+03	25800.00
2C4A17	2017-08-05 12:44:00+03	27600.00
2C4A59	2017-08-04 21:52:00+03	33100.00
2C4A75	2017-08-14 07:17:00+03	114300.00
2C4A82	2017-07-11 02:08:00+03	23600.00
2C4AB7	2017-06-25 17:48:00+03	26000.00
2C4B37	2017-08-01 10:23:00+03	69400.00
2C4B8C	2017-07-05 10:45:00+03	141600.00
2C4BA6	2017-08-01 16:33:00+03	54400.00
2C4BA8	2017-07-29 08:21:00+03	118700.00
2C4CD7	2017-08-10 16:31:00+03	52100.00
2C4CDA	2017-07-18 14:45:00+03	28000.00
2C4D00	2017-08-12 01:10:00+03	109200.00
2C4D0C	2017-08-04 16:38:00+03	217100.00
2C4DAB	2017-07-27 15:33:00+03	57800.00
2C4DC9	2017-07-02 00:00:00+03	25800.00
2C4DED	2017-08-14 23:38:00+03	38500.00
2C4E01	2017-07-20 18:57:00+03	24000.00
2C4E29	2017-07-21 01:08:00+03	52000.00
2C4E3E	2017-07-28 20:30:00+03	103400.00
2C4E46	2017-07-21 14:22:00+03	28800.00
2C4E5D	2017-07-23 00:28:00+03	65600.00
2C4EAF	2017-07-21 11:18:00+03	68800.00
2C4EFC	2017-07-17 20:28:00+03	48800.00
2C4F61	2017-08-07 20:57:00+03	94300.00
2C4F6F	2017-08-09 16:20:00+03	131100.00
2C4FA4	2017-07-30 04:48:00+03	87100.00
2C5018	2017-06-28 11:01:00+03	279000.00
2C501F	2017-07-12 11:56:00+03	167200.00
2C502B	2017-08-08 03:36:00+03	113200.00
2C5047	2017-08-15 08:53:00+03	155600.00
2C507E	2017-06-28 15:25:00+03	38600.00
2C50B8	2017-07-14 11:13:00+03	199700.00
2C5223	2017-08-04 11:21:00+03	111700.00
2C525D	2017-07-20 12:53:00+03	115100.00
2C526C	2017-07-28 17:28:00+03	34000.00
2C5305	2017-07-26 11:38:00+03	236700.00
2C5333	2017-07-10 04:43:00+03	40000.00
2C5375	2017-08-01 20:43:00+03	31200.00
2C5395	2017-07-17 18:50:00+03	46000.00
2C53D8	2017-07-20 17:37:00+03	32100.00
2C5401	2017-07-24 11:45:00+03	38800.00
2C5418	2017-08-05 15:43:00+03	24400.00
2C541F	2017-08-04 12:31:00+03	138000.00
2C5440	2017-07-15 00:20:00+03	79600.00
2C546E	2017-07-17 06:04:00+03	53200.00
2C54EA	2017-07-14 22:44:00+03	134400.00
2C5570	2017-08-10 10:15:00+03	6800.00
2C569E	2017-07-01 03:27:00+03	22400.00
2C56AF	2017-07-10 20:08:00+03	151200.00
2C5704	2017-08-15 10:14:00+03	111600.00
2C5742	2017-07-29 10:24:00+03	70700.00
2C577E	2017-08-03 20:11:00+03	26800.00
2C57A5	2017-08-12 05:14:00+03	16400.00
2C57AD	2017-06-29 20:58:00+03	61800.00
2C5803	2017-07-06 03:20:00+03	43200.00
2C5809	2017-07-07 13:38:00+03	258400.00
2C5839	2017-08-04 00:40:00+03	63200.00
2C58DF	2017-07-07 20:57:00+03	106900.00
2C595C	2017-07-30 05:27:00+03	77000.00
2C59B4	2017-08-07 19:50:00+03	295400.00
2C59ED	2017-07-12 21:04:00+03	102300.00
2C59FA	2017-07-01 17:08:00+03	35700.00
2C5A0C	2017-08-10 11:50:00+03	168000.00
2C5A87	2017-08-14 00:42:00+03	106800.00
2C5A92	2017-08-07 04:28:00+03	22000.00
2C5B3C	2017-08-01 17:47:00+03	111600.00
2C5B9B	2017-08-07 02:51:00+03	114800.00
2C5C07	2017-06-30 12:39:00+03	26900.00
2C5C0B	2017-07-27 07:53:00+03	31000.00
2C5C1F	2017-07-18 10:11:00+03	59800.00
2C5C41	2017-07-19 10:29:00+03	21000.00
2C5C43	2017-07-18 13:30:00+03	42800.00
2C5CAE	2017-07-06 19:08:00+03	394400.00
2C5D58	2017-06-30 15:38:00+03	19600.00
2C5DC2	2017-08-06 12:02:00+03	58400.00
2C5DD9	2017-07-24 14:19:00+03	121700.00
2C5E04	2017-07-09 20:05:00+03	114900.00
2C5E1E	2017-08-05 14:00:00+03	56000.00
2C5E74	2017-07-11 16:16:00+03	149300.00
2C5E76	2017-08-10 19:17:00+03	22000.00
2C5E87	2017-07-07 06:01:00+03	34000.00
2C5ECA	2017-07-23 04:18:00+03	21500.00
2C5ED8	2017-07-25 01:31:00+03	260300.00
2C5F1F	2017-07-20 14:35:00+03	7400.00
2C5F33	2017-08-09 10:12:00+03	136200.00
2C5F36	2017-07-03 16:05:00+03	88800.00
2C604D	2017-07-18 03:28:00+03	31600.00
2C606C	2017-08-09 21:22:00+03	65900.00
2C60A7	2017-07-10 03:48:00+03	44800.00
2C6113	2017-08-08 18:14:00+03	115100.00
2C6125	2017-06-27 16:09:00+03	57600.00
2C6161	2017-08-02 14:17:00+03	10800.00
2C61CE	2017-07-01 17:12:00+03	56000.00
2C61D9	2017-07-28 14:32:00+03	76600.00
2C61E6	2017-07-08 17:28:00+03	136200.00
2C6239	2017-07-06 07:08:00+03	189800.00
2C6241	2017-07-04 00:58:00+03	77900.00
2C6272	2017-07-22 13:42:00+03	136200.00
2C6282	2017-07-28 06:32:00+03	69500.00
2C62C1	2017-07-15 22:09:00+03	125200.00
2C62E0	2017-08-01 15:21:00+03	223200.00
2C637C	2017-07-03 14:52:00+03	178800.00
2C63E8	2017-07-16 07:38:00+03	6000.00
2C6475	2017-08-08 23:24:00+03	165500.00
2C647D	2017-07-29 06:00:00+03	167500.00
2C6481	2017-07-28 10:53:00+03	147700.00
2C648F	2017-08-15 04:48:00+03	35500.00
2C6496	2017-08-01 20:26:00+03	22000.00
2C6499	2017-07-26 04:12:00+03	28800.00
2C64E8	2017-07-30 14:21:00+03	21500.00
2C6560	2017-08-05 04:30:00+03	92000.00
2C6577	2017-07-06 03:29:00+03	50800.00
2C65C6	2017-07-18 22:34:00+03	112000.00
2C65D5	2017-07-27 02:18:00+03	61400.00
2C6638	2017-07-12 13:09:00+03	58200.00
2C6641	2017-07-26 07:23:00+03	265800.00
2C667B	2017-07-10 23:50:00+03	19800.00
2C6708	2017-07-19 17:12:00+03	38400.00
2C67D1	2017-08-02 23:32:00+03	78300.00
2C685E	2017-07-16 16:07:00+03	8000.00
2C6891	2017-08-05 05:34:00+03	40000.00
2C68EC	2017-07-31 23:08:00+03	70800.00
2C68FC	2017-07-26 12:35:00+03	44000.00
2C6911	2017-07-15 14:16:00+03	56900.00
2C691C	2017-07-06 08:16:00+03	88500.00
2C694A	2017-08-02 21:22:00+03	166000.00
2C6977	2017-07-26 19:49:00+03	40800.00
2C69AE	2017-07-17 07:44:00+03	26000.00
2C69CC	2017-07-19 19:45:00+03	25400.00
2C69D5	2017-08-14 05:49:00+03	60400.00
2C6A21	2017-08-01 15:00:00+03	20800.00
2C6A22	2017-07-14 02:39:00+03	111600.00
2C6A42	2017-07-05 10:02:00+03	48800.00
2C6A5D	2017-07-09 05:15:00+03	77200.00
2C6B5B	2017-08-13 00:35:00+03	23200.00
2C6B60	2017-07-16 06:13:00+03	492000.00
2C6B72	2017-07-27 04:17:00+03	50700.00
2C6B7F	2017-07-05 11:37:00+03	53200.00
2C6B97	2017-07-16 05:02:00+03	46200.00
2C6BCD	2017-07-30 01:19:00+03	172100.00
2C6BCE	2017-07-29 08:22:00+03	6000.00
2C6BFF	2017-07-24 23:52:00+03	86800.00
2C6C42	2017-08-09 03:34:00+03	146600.00
2C6C6A	2017-08-10 00:19:00+03	136200.00
2C6CEB	2017-06-30 18:52:00+03	56900.00
2C6D30	2017-08-01 16:10:00+03	48800.00
2C6D3B	2017-08-08 00:54:00+03	46300.00
2C6D57	2017-07-07 13:50:00+03	40800.00
2C6DAC	2017-08-04 12:02:00+03	81700.00
2C6DE6	2017-08-15 12:39:00+03	73200.00
2C6E03	2017-08-04 21:57:00+03	21800.00
2C6E4C	2017-07-11 05:30:00+03	129600.00
2C6E61	2017-08-01 16:31:00+03	6700.00
2C6F2F	2017-08-08 00:08:00+03	80000.00
2C6F42	2017-08-10 05:43:00+03	270800.00
2C6F5B	2017-07-09 16:40:00+03	54800.00
2C6F6A	2017-07-17 11:11:00+03	11800.00
2C6F9A	2017-07-19 01:29:00+03	21800.00
2C6FBA	2017-08-11 17:33:00+03	236900.00
2C709F	2017-08-13 03:12:00+03	13400.00
2C70BC	2017-07-22 13:22:00+03	258400.00
2C713D	2017-07-13 05:27:00+03	65800.00
2C718F	2017-07-11 18:23:00+03	86300.00
2C71B8	2017-08-09 12:52:00+03	66600.00
2C7201	2017-08-01 12:58:00+03	189800.00
2C7208	2017-07-03 14:53:00+03	40800.00
2C720A	2017-07-10 22:12:00+03	101800.00
2C723B	2017-07-17 00:31:00+03	51900.00
2C724E	2017-07-06 17:10:00+03	19600.00
2C7258	2017-07-28 15:22:00+03	146300.00
2C7269	2017-08-02 01:56:00+03	21800.00
2C7283	2017-08-10 17:24:00+03	48600.00
2C72A6	2017-08-12 10:40:00+03	24000.00
2C732B	2017-07-02 10:46:00+03	23100.00
2C7363	2017-07-17 06:22:00+03	86800.00
2C7397	2017-07-16 07:24:00+03	45200.00
2C73AA	2017-07-28 16:18:00+03	47800.00
2C73CD	2017-07-23 09:48:00+03	89600.00
2C73ED	2017-07-22 09:09:00+03	73500.00
2C741A	2017-08-08 19:40:00+03	41300.00
2C7444	2017-08-14 17:32:00+03	21600.00
2C746A	2017-07-31 16:32:00+03	118700.00
2C7495	2017-08-05 10:04:00+03	76200.00
2C74E3	2017-07-09 00:16:00+03	46200.00
2C7505	2017-08-10 05:26:00+03	115400.00
2C752E	2017-08-15 05:58:00+03	274000.00
2C7549	2017-08-08 06:38:00+03	79900.00
2C7594	2017-07-06 05:13:00+03	39100.00
2C75BC	2017-07-13 04:42:00+03	56000.00
2C75C1	2017-08-05 19:24:00+03	114900.00
2C7624	2017-07-23 18:06:00+03	147900.00
2C76D4	2017-08-05 09:33:00+03	50000.00
2C76E6	2017-07-29 22:48:00+03	99200.00
2C7706	2017-07-28 03:15:00+03	14400.00
2C7729	2017-07-16 01:34:00+03	50600.00
2C7746	2017-08-12 08:18:00+03	31100.00
2C7771	2017-07-18 01:27:00+03	25700.00
2C77EA	2017-07-10 09:18:00+03	68600.00
2C7863	2017-07-16 23:15:00+03	138900.00
2C787A	2017-07-13 09:51:00+03	58400.00
2C7890	2017-07-25 08:23:00+03	364000.00
2C78AD	2017-07-07 12:37:00+03	20400.00
2C78B8	2017-07-05 13:54:00+03	76800.00
2C790F	2017-07-01 09:31:00+03	52000.00
2C7944	2017-08-05 18:38:00+03	135400.00
2C7963	2017-07-19 06:08:00+03	7200.00
2C79A7	2017-08-08 18:03:00+03	47200.00
2C7A2A	2017-07-04 08:01:00+03	65200.00
2C7A46	2017-07-21 16:06:00+03	60400.00
2C7A48	2017-07-13 11:41:00+03	190100.00
2C7B1B	2017-07-18 21:02:00+03	246000.00
2C7B40	2017-07-25 09:35:00+03	85000.00
2C7B7C	2017-07-28 01:17:00+03	239900.00
2C7C24	2017-08-14 12:03:00+03	49700.00
2C7C37	2017-07-02 15:42:00+03	58200.00
2C7CCD	2017-07-31 20:16:00+03	27200.00
2C7D00	2017-07-05 21:04:00+03	21800.00
2C7D1C	2017-07-21 05:10:00+03	25000.00
2C7D4D	2017-08-05 06:32:00+03	85700.00
2C7D73	2017-07-16 23:26:00+03	92100.00
2C7DE9	2017-06-26 19:22:00+03	24400.00
2C7E06	2017-08-05 22:49:00+03	57700.00
2C7E2F	2017-08-11 11:33:00+03	44800.00
2C7E66	2017-07-16 10:15:00+03	22000.00
2C7EB9	2017-08-02 06:52:00+03	30400.00
2C7F21	2017-07-04 12:57:00+03	62800.00
2C7F6B	2017-08-06 14:40:00+03	55600.00
2C7F6C	2017-07-06 18:40:00+03	36200.00
2C7F87	2017-06-27 02:42:00+03	46200.00
2C7FA2	2017-08-06 23:20:00+03	45100.00
2C7FDA	2017-08-04 00:08:00+03	202400.00
2C8064	2017-07-04 01:33:00+03	75100.00
2C806F	2017-07-29 14:28:00+03	58200.00
2C8075	2017-08-14 14:48:00+03	23400.00
2C80A2	2017-07-12 10:49:00+03	61500.00
2C80B9	2017-08-13 19:40:00+03	375200.00
2C80C2	2017-07-01 20:59:00+03	101200.00
2C80E5	2017-08-12 06:40:00+03	26300.00
2C810D	2017-07-14 00:08:00+03	181100.00
2C81A3	2017-07-18 02:35:00+03	215500.00
2C8203	2017-08-13 00:19:00+03	33400.00
2C8249	2017-07-09 03:49:00+03	68800.00
2C824E	2017-08-11 21:11:00+03	199200.00
2C8286	2017-08-05 04:16:00+03	46300.00
2C82AE	2017-07-05 12:35:00+03	54500.00
2C8318	2017-07-13 15:59:00+03	265800.00
2C8326	2017-08-11 01:52:00+03	97800.00
2C83D6	2017-07-19 05:37:00+03	38800.00
2C83FB	2017-07-31 10:50:00+03	55800.00
2C8410	2017-07-29 03:36:00+03	80000.00
2C8436	2017-07-16 11:59:00+03	38600.00
2C84E6	2017-07-22 18:11:00+03	40400.00
2C855D	2017-07-31 00:39:00+03	168000.00
2C857C	2017-07-21 05:52:00+03	92000.00
2C858D	2017-07-18 14:36:00+03	144400.00
2C85E2	2017-07-09 04:17:00+03	56000.00
2C85F5	2017-08-09 03:59:00+03	14800.00
2C8604	2017-07-16 16:39:00+03	47200.00
2C8620	2017-08-13 02:11:00+03	18000.00
2C8672	2017-06-27 18:52:00+03	15400.00
2C869A	2017-08-05 16:33:00+03	86400.00
2C86AD	2017-07-13 15:37:00+03	127300.00
2C86C5	2017-08-11 22:54:00+03	56000.00
2C86EC	2017-07-13 11:58:00+03	111600.00
2C871E	2017-07-31 09:44:00+03	94000.00
2C872F	2017-08-09 23:02:00+03	64800.00
2C876C	2017-08-02 19:13:00+03	54500.00
2C8775	2017-07-18 05:40:00+03	56000.00
2C8785	2017-07-10 20:25:00+03	36200.00
2C8808	2017-08-14 07:23:00+03	34000.00
2C880B	2017-07-08 09:15:00+03	57500.00
2C8825	2017-08-02 23:10:00+03	223200.00
2C8919	2017-07-08 15:17:00+03	51800.00
2C8920	2017-08-03 16:43:00+03	28000.00
2C893C	2017-06-29 08:11:00+03	23200.00
2C89E8	2017-08-03 02:16:00+03	128600.00
2C89F6	2017-07-21 00:33:00+03	687000.00
2C89FA	2017-07-16 10:19:00+03	88200.00
2C8A15	2017-07-02 12:06:00+03	270200.00
2C8AA4	2017-07-15 13:43:00+03	123000.00
2C8AD0	2017-07-09 19:08:00+03	101800.00
2C8AD4	2017-07-06 07:13:00+03	135200.00
2C8AE0	2017-07-25 12:24:00+03	135600.00
2C8AE6	2017-07-13 08:03:00+03	56000.00
2C8B0D	2017-07-27 03:23:00+03	13200.00
2C8B47	2017-07-29 18:59:00+03	116400.00
2C8B77	2017-07-21 20:42:00+03	56000.00
2C8C4F	2017-07-13 13:21:00+03	76600.00
2C8C67	2017-08-12 17:23:00+03	28000.00
2C8C73	2017-07-05 10:09:00+03	45500.00
2C8CA9	2017-08-03 04:06:00+03	64600.00
2C8CD7	2017-07-28 21:56:00+03	56000.00
2C8D0C	2017-07-23 09:18:00+03	67200.00
2C8D83	2017-07-15 18:06:00+03	66700.00
2C8DC0	2017-08-02 11:26:00+03	90400.00
2C8E3E	2017-07-03 15:29:00+03	23100.00
2C8E56	2017-07-02 20:03:00+03	114700.00
2C8E7B	2017-07-03 14:43:00+03	496200.00
2C8ED9	2017-08-13 02:07:00+03	44000.00
2C8EDE	2017-07-22 09:56:00+03	47000.00
2C8F54	2017-08-09 16:39:00+03	18400.00
2C8FEE	2017-07-31 19:30:00+03	15400.00
2C9049	2017-07-30 21:05:00+03	375200.00
2C905D	2017-08-03 05:50:00+03	123000.00
2C906D	2017-08-15 07:30:00+03	133200.00
2C9091	2017-07-27 01:53:00+03	38300.00
2C9127	2017-07-02 07:01:00+03	20600.00
2C9132	2017-06-29 23:50:00+03	48800.00
2C9135	2017-08-13 08:13:00+03	42000.00
2C9204	2017-08-09 13:19:00+03	7400.00
2C9212	2017-07-17 18:39:00+03	10600.00
2C924A	2017-08-02 00:04:00+03	71100.00
2C9274	2017-07-14 19:14:00+03	16400.00
2C92B8	2017-07-19 19:22:00+03	398900.00
2C9320	2017-07-21 18:43:00+03	6600.00
2C9325	2017-06-28 03:13:00+03	64300.00
2C9531	2017-08-05 00:11:00+03	27200.00
2C9585	2017-07-30 00:54:00+03	12000.00
2C95A4	2017-07-31 07:14:00+03	26200.00
2C95A9	2017-08-15 17:52:00+03	44100.00
2C95C8	2017-07-24 20:56:00+03	6000.00
2C95CF	2017-07-20 15:23:00+03	6700.00
2C9664	2017-07-30 19:39:00+03	58600.00
2C9669	2017-08-13 18:34:00+03	32000.00
2C96EB	2017-07-04 07:43:00+03	50000.00
2C9728	2017-08-10 05:23:00+03	156500.00
2C9799	2017-07-16 08:25:00+03	58000.00
2C97A5	2017-07-13 05:53:00+03	21800.00
2C97F7	2017-08-03 07:36:00+03	123000.00
2C986E	2017-07-13 20:16:00+03	75800.00
2C98B7	2017-06-29 19:14:00+03	53400.00
2C9917	2017-07-22 01:36:00+03	29600.00
2C991F	2017-07-02 20:35:00+03	123700.00
2C9921	2017-07-26 21:01:00+03	158500.00
2C992C	2017-08-13 19:04:00+03	29500.00
2C995F	2017-07-18 13:26:00+03	8000.00
2C99E7	2017-08-14 01:28:00+03	246000.00
2C99EC	2017-07-16 18:12:00+03	42800.00
2C9A1C	2017-07-03 03:08:00+03	167400.00
2C9A81	2017-08-08 09:52:00+03	393000.00
2C9AB5	2017-08-03 05:54:00+03	492000.00
2C9B95	2017-08-12 10:11:00+03	32200.00
2C9BEE	2017-07-15 11:07:00+03	55800.00
2C9C0A	2017-07-05 23:30:00+03	95200.00
2C9C38	2017-08-07 15:32:00+03	136600.00
2C9CB0	2017-07-26 17:19:00+03	24800.00
2C9CB3	2017-07-06 23:01:00+03	19600.00
2C9CDE	2017-08-07 00:44:00+03	45200.00
2C9CE2	2017-08-09 23:39:00+03	212800.00
2C9D39	2017-08-04 23:36:00+03	38600.00
2C9D48	2017-07-02 21:14:00+03	111700.00
2C9D5F	2017-07-04 16:38:00+03	36000.00
2C9DEF	2017-07-01 03:58:00+03	6600.00
2C9E2B	2017-07-11 05:58:00+03	94300.00
2C9E3C	2017-08-01 16:18:00+03	62200.00
2C9E81	2017-08-01 15:18:00+03	43300.00
2C9E99	2017-08-01 10:44:00+03	198400.00
2C9E9F	2017-06-30 06:26:00+03	47000.00
2C9EAE	2017-07-23 18:30:00+03	28800.00
2C9EBC	2017-07-15 15:36:00+03	70800.00
2C9F3A	2017-07-14 14:14:00+03	32700.00
2C9F53	2017-07-26 09:52:00+03	73900.00
2C9FC7	2017-07-23 10:51:00+03	37400.00
2C9FFC	2017-07-19 09:22:00+03	36200.00
2CA010	2017-07-15 18:19:00+03	288200.00
2CA020	2017-07-07 00:42:00+03	134900.00
2CA037	2017-07-14 06:42:00+03	57600.00
2CA084	2017-07-03 03:08:00+03	199200.00
2CA10D	2017-08-15 12:12:00+03	56900.00
2CA123	2017-08-01 06:15:00+03	57600.00
2CA147	2017-07-09 02:10:00+03	179300.00
2CA162	2017-08-04 10:58:00+03	67800.00
2CA1B0	2017-07-25 23:27:00+03	35300.00
2CA1C4	2017-07-29 21:08:00+03	76800.00
2CA1F1	2017-08-15 10:10:00+03	37800.00
2CA202	2017-07-02 21:04:00+03	137100.00
2CA220	2017-08-01 22:00:00+03	92800.00
2CA233	2017-08-15 06:32:00+03	25100.00
2CA27C	2017-08-14 17:56:00+03	29200.00
2CA2A4	2017-07-11 03:55:00+03	28800.00
2CA30F	2017-08-08 23:15:00+03	56900.00
2CA354	2017-08-05 11:25:00+03	34000.00
2CA376	2017-07-28 21:26:00+03	413400.00
2CA43A	2017-07-20 08:28:00+03	104400.00
2CA444	2017-07-20 02:22:00+03	28800.00
2CA4C4	2017-07-31 05:40:00+03	8200.00
2CA504	2017-08-07 20:33:00+03	13600.00
2CA54E	2017-08-14 21:15:00+03	24800.00
2CA61C	2017-07-22 10:04:00+03	56100.00
2CA647	2017-08-10 03:55:00+03	112000.00
2CA657	2017-06-28 15:14:00+03	20200.00
2CA69F	2017-07-30 13:50:00+03	47000.00
2CA6AB	2017-07-27 03:01:00+03	12400.00
2CA6B4	2017-07-14 01:19:00+03	17200.00
2CA6B7	2017-08-11 19:27:00+03	21800.00
2CA6EF	2017-08-03 07:55:00+03	23100.00
2CA752	2017-07-02 05:29:00+03	66600.00
2CA761	2017-07-29 19:54:00+03	197000.00
2CA7D1	2017-08-05 06:51:00+03	47400.00
2CA7E1	2017-07-27 21:16:00+03	67600.00
2CA7E2	2017-08-13 16:37:00+03	85000.00
2CA84E	2017-07-31 09:12:00+03	14000.00
2CA8AE	2017-07-04 16:00:00+03	23600.00
2CA8CA	2017-07-04 16:34:00+03	64700.00
2CA8EE	2017-08-02 22:25:00+03	48800.00
2CA971	2017-06-30 11:58:00+03	12600.00
2CA9BB	2017-07-09 17:50:00+03	123000.00
2CAA68	2017-07-02 06:47:00+03	24800.00
2CAA8B	2017-07-25 09:15:00+03	85000.00
2CAA9E	2017-08-11 22:41:00+03	133100.00
2CAAA6	2017-08-10 11:34:00+03	74800.00
2CAAC3	2017-07-04 07:32:00+03	189200.00
2CAB57	2017-07-14 11:45:00+03	15000.00
2CABEE	2017-07-15 18:20:00+03	21800.00
2CABFA	2017-07-08 07:37:00+03	40800.00
2CAC3B	2017-08-06 11:44:00+03	43900.00
2CAC51	2017-07-27 21:19:00+03	43100.00
2CAC7B	2017-07-26 16:40:00+03	57400.00
2CAC99	2017-07-30 03:14:00+03	264600.00
2CACCE	2017-08-03 07:35:00+03	169000.00
2CAD01	2017-07-04 23:10:00+03	179200.00
2CAD7A	2017-07-16 02:42:00+03	21800.00
2CAD91	2017-07-07 01:11:00+03	9300.00
2CADE3	2017-07-29 04:18:00+03	135600.00
2CAE14	2017-08-11 06:12:00+03	21800.00
2CAE17	2017-07-17 00:41:00+03	129600.00
2CAE19	2017-07-20 18:32:00+03	28800.00
2CAE60	2017-07-23 17:39:00+03	19600.00
2CAF13	2017-07-27 08:14:00+03	23600.00
2CAF5D	2017-07-18 14:31:00+03	139100.00
2CAFB1	2017-08-06 23:12:00+03	136800.00
2CB0D4	2017-08-01 07:44:00+03	31000.00
2CB1BE	2017-07-14 07:02:00+03	111700.00
2CB21D	2017-08-08 23:00:00+03	52000.00
2CB2A0	2017-08-11 07:52:00+03	103100.00
2CB30D	2017-07-03 22:41:00+03	86800.00
2CB318	2017-07-11 23:58:00+03	188700.00
2CB429	2017-07-26 20:05:00+03	26200.00
2CB456	2017-08-15 08:29:00+03	133200.00
2CB469	2017-07-26 02:11:00+03	246000.00
2CB47D	2017-08-05 03:45:00+03	56000.00
2CB521	2017-08-08 12:47:00+03	55800.00
2CB528	2017-07-26 06:13:00+03	73600.00
2CB53F	2017-07-13 03:00:00+03	151000.00
2CB560	2017-07-23 01:25:00+03	42700.00
2CB567	2017-07-27 18:48:00+03	28000.00
2CB589	2017-07-10 00:51:00+03	14400.00
2CB5C4	2017-07-05 02:34:00+03	26000.00
2CB6A7	2017-08-10 00:18:00+03	160400.00
2CB7F7	2017-08-11 03:03:00+03	29600.00
2CB800	2017-08-11 19:34:00+03	54000.00
2CB821	2017-07-12 18:08:00+03	23200.00
2CB8B0	2017-07-19 16:48:00+03	9800.00
2CB8D5	2017-07-26 20:08:00+03	23200.00
2CB945	2017-07-19 08:53:00+03	122300.00
2CB970	2017-08-10 04:53:00+03	37100.00
2CB9F4	2017-07-21 18:53:00+03	25800.00
2CBA64	2017-07-30 15:02:00+03	257600.00
2CBAB4	2017-08-13 09:37:00+03	16800.00
2CBAE6	2017-07-30 01:46:00+03	87300.00
2CBB43	2017-08-13 02:02:00+03	169300.00
2CBB8D	2017-07-05 18:46:00+03	50400.00
2CBBB2	2017-08-10 16:47:00+03	184100.00
2CBBC6	2017-07-16 08:34:00+03	120000.00
2CBBC9	2017-07-27 21:22:00+03	70000.00
2CBBD7	2017-07-24 13:52:00+03	57200.00
2CBBDD	2017-07-28 08:04:00+03	92800.00
2CBC59	2017-08-05 10:38:00+03	81900.00
2CBC6A	2017-08-13 07:27:00+03	252200.00
2CBC8D	2017-08-10 20:27:00+03	92000.00
2CBCCC	2017-07-05 04:22:00+03	6000.00
2CBD48	2017-08-14 14:31:00+03	23100.00
2CBDBD	2017-08-01 14:32:00+03	28800.00
2CBDE6	2017-07-04 21:33:00+03	78300.00
2CBE34	2017-08-11 02:28:00+03	92800.00
2CBE6C	2017-08-13 00:47:00+03	23200.00
2CBE78	2017-07-19 19:24:00+03	53200.00
2CBE98	2017-07-10 13:30:00+03	57600.00
2CBEA8	2017-07-06 12:49:00+03	49800.00
2CBECF	2017-07-31 10:06:00+03	168000.00
2CBEEB	2017-08-06 04:17:00+03	59300.00
2CBF10	2017-08-05 08:53:00+03	80600.00
2CBF47	2017-08-13 22:30:00+03	86400.00
2CBF4F	2017-06-25 09:48:00+03	20400.00
2CBFB0	2017-07-30 15:38:00+03	94000.00
2CBFC9	2017-08-05 02:18:00+03	62600.00
2CC002	2017-08-01 19:47:00+03	15700.00
2CC047	2017-08-04 03:07:00+03	73600.00
2CC049	2017-07-14 04:58:00+03	11100.00
2CC0D9	2017-07-21 03:31:00+03	24400.00
2CC199	2017-08-13 17:02:00+03	138000.00
2CC1BC	2017-07-12 15:45:00+03	61800.00
2CC206	2017-08-14 03:08:00+03	35700.00
2CC26D	2017-07-04 17:30:00+03	8400.00
2CC272	2017-08-11 13:44:00+03	24400.00
2CC27E	2017-08-03 20:39:00+03	111000.00
2CC292	2017-07-10 20:24:00+03	88100.00
2CC2D5	2017-07-15 00:03:00+03	48400.00
2CC2ED	2017-07-25 23:06:00+03	181200.00
2CC2FF	2017-08-10 06:44:00+03	9200.00
2CC306	2017-07-04 12:29:00+03	56000.00
2CC314	2017-07-18 20:36:00+03	75300.00
2CC332	2017-08-12 05:32:00+03	38800.00
2CC3D0	2017-08-05 19:44:00+03	133200.00
2CC3E7	2017-08-01 00:08:00+03	92800.00
2CC40F	2017-08-03 05:20:00+03	134800.00
2CC428	2017-08-06 14:50:00+03	7400.00
2CC4E2	2017-07-19 03:09:00+03	133200.00
2CC504	2017-07-23 09:28:00+03	62100.00
2CC515	2017-08-12 22:37:00+03	58800.00
2CC534	2017-07-13 17:29:00+03	26800.00
2CC537	2017-07-19 13:39:00+03	375200.00
2CC5EA	2017-07-06 22:02:00+03	64600.00
2CC600	2017-07-27 02:03:00+03	100600.00
2CC610	2017-08-02 19:35:00+03	103000.00
2CC63E	2017-07-30 18:16:00+03	50600.00
2CC650	2017-07-14 06:11:00+03	64700.00
2CC757	2017-07-30 22:13:00+03	20400.00
2CC78D	2017-07-06 04:22:00+03	23600.00
2CC7B4	2017-07-10 16:27:00+03	82600.00
2CC7D3	2017-07-09 19:53:00+03	27800.00
2CC83A	2017-07-16 03:45:00+03	42600.00
2CC879	2017-07-27 06:19:00+03	99200.00
2CC8FE	2017-07-23 14:02:00+03	37700.00
2CC951	2017-07-08 16:55:00+03	38800.00
2CC965	2017-07-30 21:20:00+03	128800.00
2CC96A	2017-07-28 04:45:00+03	42600.00
2CC9B1	2017-07-03 17:39:00+03	90800.00
2CCA43	2017-07-10 05:11:00+03	53200.00
2CCA95	2017-08-06 09:17:00+03	257500.00
2CCAAB	2017-07-30 22:24:00+03	68400.00
2CCB2D	2017-07-14 15:03:00+03	12400.00
2CCB31	2017-08-01 03:56:00+03	50800.00
2CCB6B	2017-07-08 18:27:00+03	8200.00
2CCB8B	2017-07-21 05:37:00+03	47100.00
2CCBA3	2017-07-14 07:50:00+03	76600.00
2CCBE2	2017-08-01 08:57:00+03	34000.00
2CCBF1	2017-07-14 17:56:00+03	73500.00
2CCC25	2017-08-12 21:16:00+03	201300.00
2CCCD7	2017-08-09 09:46:00+03	35300.00
2CCCF8	2017-08-12 19:30:00+03	61700.00
2CCCFF	2017-07-25 18:30:00+03	18900.00
2CCD0E	2017-07-15 03:57:00+03	24200.00
2CCD81	2017-07-03 18:19:00+03	7400.00
2CCE1D	2017-07-01 17:02:00+03	111600.00
2CCE28	2017-07-21 19:38:00+03	46200.00
2CCE3D	2017-07-09 18:17:00+03	127400.00
2CCEA5	2017-07-20 04:34:00+03	120800.00
2CCED6	2017-08-10 21:09:00+03	173500.00
2CCEE9	2017-08-11 11:12:00+03	85000.00
2CCF0F	2017-07-14 03:16:00+03	111600.00
2CCF4E	2017-07-13 11:09:00+03	48800.00
2CCF81	2017-07-25 09:03:00+03	55800.00
2CCFAB	2017-07-23 10:25:00+03	234500.00
2CD047	2017-07-25 21:33:00+03	8200.00
2CD0F6	2017-07-08 09:16:00+03	41400.00
2CD100	2017-08-02 16:19:00+03	83500.00
2CD11D	2017-07-25 09:29:00+03	81600.00
2CD169	2017-07-02 05:20:00+03	6800.00
2CD1B7	2017-07-25 04:27:00+03	33200.00
2CD1C3	2017-07-03 08:21:00+03	56000.00
2CD254	2017-08-10 23:09:00+03	54800.00
2CD286	2017-07-04 09:01:00+03	112000.00
2CD2EC	2017-08-11 10:37:00+03	38400.00
2CD31F	2017-07-26 08:06:00+03	24400.00
2CD339	2017-07-28 17:35:00+03	86800.00
2CD366	2017-07-25 11:33:00+03	70100.00
2CD36A	2017-07-11 13:40:00+03	21600.00
2CD3E9	2017-07-10 09:02:00+03	265700.00
2CD41B	2017-08-07 17:57:00+03	272300.00
2CD432	2017-07-09 18:06:00+03	67900.00
2CD455	2017-06-27 17:15:00+03	46200.00
2CD45F	2017-07-30 16:52:00+03	166900.00
2CD4C5	2017-08-14 02:32:00+03	189800.00
2CD4E0	2017-08-15 02:14:00+03	74800.00
2CD504	2017-07-12 08:24:00+03	14000.00
2CD5DC	2017-07-27 07:20:00+03	52300.00
2CD62A	2017-07-24 02:18:00+03	88100.00
2CD645	2017-08-11 17:47:00+03	55800.00
2CD697	2017-07-04 23:13:00+03	30200.00
2CD69B	2017-07-25 20:18:00+03	62600.00
2CD703	2017-07-20 01:37:00+03	36500.00
2CD721	2017-07-30 03:08:00+03	15100.00
2CD735	2017-07-12 19:56:00+03	155600.00
2CD740	2017-08-06 23:36:00+03	36800.00
2CD761	2017-07-04 18:10:00+03	63200.00
2CD783	2017-07-24 19:10:00+03	47700.00
2CD7B3	2017-08-10 19:29:00+03	52700.00
2CD848	2017-07-18 01:35:00+03	19800.00
2CD867	2017-07-11 13:35:00+03	77900.00
2CD890	2017-08-10 21:15:00+03	28800.00
2CD895	2017-08-14 10:45:00+03	272400.00
2CD89E	2017-08-13 17:39:00+03	6000.00
2CD8D9	2017-07-26 01:55:00+03	57500.00
2CD91D	2017-07-29 13:09:00+03	24400.00
2CD936	2017-07-15 16:06:00+03	102100.00
2CD95D	2017-08-09 02:33:00+03	29600.00
2CD9DC	2017-07-25 15:23:00+03	27800.00
2CD9E7	2017-07-26 23:25:00+03	52600.00
2CDA41	2017-07-16 06:39:00+03	14400.00
2CDAD5	2017-08-09 03:45:00+03	108800.00
2CDB4E	2017-07-08 01:57:00+03	29000.00
2CDB63	2017-07-28 11:11:00+03	65600.00
2CDB93	2017-08-06 00:00:00+03	143000.00
2CDC00	2017-07-03 08:25:00+03	39100.00
2CDC0A	2017-07-25 08:10:00+03	20200.00
2CDC14	2017-07-20 03:13:00+03	11800.00
2CDC8E	2017-07-24 23:53:00+03	148200.00
2CDD14	2017-07-20 15:25:00+03	52100.00
2CDD66	2017-08-07 07:55:00+03	56900.00
2CDDAF	2017-08-02 01:44:00+03	80300.00
2CDDFE	2017-07-06 16:22:00+03	43200.00
2CDE14	2017-08-12 01:51:00+03	47400.00
2CDE9F	2017-07-09 02:04:00+03	57600.00
2CDECC	2017-06-29 10:31:00+03	39500.00
2CDF58	2017-07-08 20:57:00+03	132800.00
2CDF63	2017-07-09 21:37:00+03	271400.00
2CDFAF	2017-07-30 12:11:00+03	92600.00
2CDFC0	2017-07-23 15:49:00+03	69600.00
2CE07A	2017-07-18 15:09:00+03	31700.00
2CE0C6	2017-07-31 15:29:00+03	149100.00
2CE0E7	2017-07-17 10:59:00+03	225300.00
2CE12D	2017-08-12 15:53:00+03	29800.00
2CE141	2017-07-25 16:54:00+03	28800.00
2CE1A5	2017-07-02 04:34:00+03	85500.00
2CE229	2017-06-29 22:28:00+03	189800.00
2CE24B	2017-07-07 10:22:00+03	43200.00
2CE270	2017-07-15 11:44:00+03	193600.00
2CE273	2017-08-02 09:53:00+03	166000.00
2CE28E	2017-08-07 06:11:00+03	65100.00
2CE2DF	2017-07-05 03:18:00+03	339300.00
2CE30D	2017-07-23 07:19:00+03	59800.00
2CE311	2017-07-27 21:44:00+03	81600.00
2CE448	2017-07-16 09:32:00+03	31600.00
2CE469	2017-07-10 07:31:00+03	69000.00
2CE4A3	2017-08-02 01:38:00+03	25800.00
2CE4A7	2017-07-07 06:22:00+03	61800.00
2CE4BC	2017-07-30 11:54:00+03	26200.00
2CE4C5	2017-07-14 04:09:00+03	78600.00
2CE4F4	2017-07-21 02:01:00+03	113800.00
2CE530	2017-08-07 16:34:00+03	174600.00
2CE551	2017-08-08 01:33:00+03	185500.00
2CE56D	2017-07-09 07:37:00+03	123000.00
2CE5F5	2017-07-06 02:06:00+03	26200.00
2CE616	2017-07-08 21:35:00+03	73200.00
2CE6AA	2017-08-09 01:29:00+03	23200.00
2CE739	2017-07-08 13:43:00+03	34100.00
2CE781	2017-07-06 11:27:00+03	50800.00
2CE794	2017-07-24 06:27:00+03	15800.00
2CE7B7	2017-07-08 00:50:00+03	89200.00
2CE838	2017-07-04 14:47:00+03	369000.00
2CE83D	2017-08-12 10:24:00+03	30200.00
2CE849	2017-07-18 03:00:00+03	136100.00
2CE879	2017-08-05 16:26:00+03	13600.00
2CE8C8	2017-07-25 06:45:00+03	28000.00
2CE905	2017-08-10 01:01:00+03	95200.00
2CE944	2017-08-13 21:56:00+03	252200.00
2CE94C	2017-07-11 16:27:00+03	28800.00
2CE953	2017-07-20 15:01:00+03	56000.00
2CE96E	2017-08-07 05:10:00+03	17800.00
2CEA09	2017-08-03 12:49:00+03	44800.00
2CEA1D	2017-08-13 06:09:00+03	27200.00
2CEA87	2017-07-12 14:44:00+03	105000.00
2CEAEE	2017-08-12 17:19:00+03	64400.00
2CEAFB	2017-07-10 14:48:00+03	6200.00
2CEB0B	2017-07-04 22:09:00+03	205000.00
2CEB18	2017-07-18 20:22:00+03	8200.00
2CEC94	2017-08-11 13:51:00+03	46000.00
2CEC99	2017-07-19 23:24:00+03	12600.00
2CECE9	2017-08-09 20:13:00+03	21400.00
2CED12	2017-07-07 11:45:00+03	147000.00
2CED26	2017-07-17 06:54:00+03	54400.00
2CED83	2017-07-22 19:34:00+03	86800.00
2CED85	2017-07-22 17:43:00+03	58800.00
2CEDB2	2017-08-01 07:48:00+03	48000.00
2CEDF0	2017-07-31 14:53:00+03	25900.00
2CEE0D	2017-08-13 15:33:00+03	26000.00
2CEEA1	2017-08-07 01:38:00+03	55800.00
2CEF10	2017-07-28 22:10:00+03	255100.00
2CEF2F	2017-07-18 16:13:00+03	35800.00
2CEF3F	2017-07-08 00:47:00+03	129400.00
2CF000	2017-07-02 13:34:00+03	21400.00
2CF02B	2017-07-21 11:18:00+03	88600.00
2CF040	2017-08-06 13:54:00+03	125200.00
2CF04B	2017-08-15 16:28:00+03	29100.00
2CF119	2017-08-12 09:03:00+03	179400.00
2CF11C	2017-07-13 00:04:00+03	59400.00
2CF134	2017-07-31 16:28:00+03	33400.00
2CF190	2017-07-07 23:34:00+03	48500.00
2CF1AC	2017-07-22 11:48:00+03	24400.00
2CF207	2017-07-08 04:42:00+03	43200.00
2CF266	2017-07-04 04:00:00+03	113800.00
2CF268	2017-06-24 01:52:00+03	96800.00
2CF26B	2017-07-25 05:51:00+03	21800.00
2CF30F	2017-07-30 23:04:00+03	32800.00
2CF372	2017-08-14 07:35:00+03	73600.00
2CF44C	2017-08-12 09:00:00+03	77200.00
2CF451	2017-07-25 11:37:00+03	265700.00
2CF4AC	2017-08-05 22:02:00+03	369000.00
2CF59A	2017-07-07 01:41:00+03	37600.00
2CF59F	2017-07-21 09:49:00+03	25100.00
2CF5AF	2017-08-11 15:06:00+03	12600.00
2CF608	2017-07-26 19:56:00+03	51900.00
2CF618	2017-07-26 11:42:00+03	24000.00
2CF64C	2017-06-28 16:18:00+03	99300.00
2CF6D8	2017-07-26 10:20:00+03	95600.00
2CF6EB	2017-08-03 11:37:00+03	8200.00
2CF755	2017-07-25 15:54:00+03	34000.00
2CF75E	2017-07-20 16:22:00+03	8200.00
2CF795	2017-07-28 20:13:00+03	133200.00
2CF7D2	2017-07-15 10:48:00+03	66600.00
2CF7D8	2017-07-30 16:04:00+03	6300.00
2CF7DB	2017-07-25 02:38:00+03	29600.00
2CF812	2017-07-31 02:34:00+03	11700.00
2CF870	2017-08-05 22:10:00+03	52600.00
2CF917	2017-07-08 04:21:00+03	184300.00
2CF931	2017-07-23 12:55:00+03	477500.00
2CF94D	2017-08-12 13:19:00+03	66600.00
2CF970	2017-07-19 04:23:00+03	139500.00
2CF9AB	2017-08-07 14:42:00+03	6000.00
2CFA12	2017-08-09 07:23:00+03	29600.00
2CFA58	2017-08-07 23:33:00+03	29600.00
2CFA7F	2017-08-12 12:48:00+03	33300.00
2CFA88	2017-07-24 09:46:00+03	30300.00
2CFA9E	2017-07-31 22:21:00+03	201200.00
2CFB47	2017-07-15 03:46:00+03	12600.00
2CFB60	2017-07-26 07:13:00+03	201200.00
2CFB71	2017-07-14 20:30:00+03	36200.00
2CFC07	2017-07-18 06:47:00+03	36900.00
2CFC5C	2017-07-19 23:59:00+03	23400.00
2CFC75	2017-08-14 09:17:00+03	77000.00
2CFC7E	2017-07-26 00:33:00+03	26000.00
2CFCD0	2017-07-31 18:14:00+03	22600.00
2CFCE1	2017-07-31 17:30:00+03	48500.00
2CFD46	2017-07-04 05:03:00+03	22000.00
2CFD4A	2017-07-30 06:52:00+03	142400.00
2CFDAE	2017-07-31 17:45:00+03	64600.00
2CFDC1	2017-08-01 16:05:00+03	25000.00
2CFE12	2017-07-21 08:29:00+03	58900.00
2CFE38	2017-07-13 19:27:00+03	116300.00
2CFE6E	2017-07-05 23:18:00+03	199700.00
2CFE7B	2017-08-05 16:18:00+03	55800.00
2CFEDC	2017-08-01 14:11:00+03	170000.00
2CFF87	2017-07-29 16:28:00+03	56000.00
2CFFD2	2017-08-01 08:17:00+03	67600.00
2D0026	2017-08-15 10:46:00+03	40800.00
2D0047	2017-07-07 10:22:00+03	153000.00
2D0054	2017-07-05 13:20:00+03	94400.00
2D007E	2017-07-11 09:18:00+03	86400.00
2D0127	2017-08-14 02:11:00+03	71200.00
2D018D	2017-07-24 09:50:00+03	110000.00
2D01AC	2017-08-09 02:38:00+03	59200.00
2D01B2	2017-08-13 22:23:00+03	198600.00
2D0205	2017-08-02 15:14:00+03	72400.00
2D0271	2017-07-19 07:10:00+03	49100.00
2D02B6	2017-07-14 23:30:00+03	163600.00
2D02D7	2017-07-25 18:14:00+03	24400.00
2D032F	2017-08-09 08:59:00+03	18600.00
2D0399	2017-08-13 13:16:00+03	62000.00
2D042E	2017-07-16 11:36:00+03	119700.00
2D0462	2017-07-19 00:04:00+03	79900.00
2D04C1	2017-08-14 01:33:00+03	92800.00
2D0597	2017-08-06 17:28:00+03	30000.00
2D0662	2017-07-18 04:26:00+03	16000.00
2D06F0	2017-07-04 22:50:00+03	85000.00
2D0708	2017-07-22 21:04:00+03	16400.00
2D0710	2017-07-25 18:52:00+03	28800.00
2D0745	2017-07-28 15:13:00+03	114700.00
2D07FC	2017-07-27 04:00:00+03	62600.00
2D0898	2017-08-11 15:52:00+03	23200.00
2D08B2	2017-07-15 21:40:00+03	127300.00
2D08BB	2017-07-13 09:37:00+03	55800.00
2D0980	2017-08-06 14:13:00+03	26000.00
2D09AC	2017-08-03 09:10:00+03	150600.00
2D09B7	2017-07-16 11:47:00+03	33000.00
2D0A40	2017-07-30 01:23:00+03	46300.00
2D0A4E	2017-07-17 08:52:00+03	15900.00
2D0A9C	2017-08-03 07:12:00+03	41200.00
2D0AFF	2017-07-25 08:29:00+03	124200.00
2D0BA2	2017-07-08 23:32:00+03	13400.00
2D0C2F	2017-07-13 15:13:00+03	20400.00
2D0C31	2017-07-29 09:27:00+03	43400.00
2D0C80	2017-07-12 06:32:00+03	82900.00
2D0D6D	2017-07-21 14:57:00+03	88500.00
2D0D7C	2017-08-04 19:09:00+03	111700.00
2D0DB1	2017-08-13 07:23:00+03	240900.00
2D0DD5	2017-08-06 20:57:00+03	14400.00
2D0E19	2017-07-28 23:48:00+03	102700.00
2D0E50	2017-07-17 20:46:00+03	19800.00
2D0E82	2017-07-19 05:52:00+03	147700.00
2D0EE9	2017-08-09 10:23:00+03	133100.00
2D0F7D	2017-08-10 13:36:00+03	36200.00
2D0FB6	2017-08-05 16:03:00+03	73500.00
2D0FC4	2017-08-13 12:12:00+03	44000.00
2D0FDD	2017-08-02 09:43:00+03	26600.00
2D100C	2017-08-09 20:43:00+03	23400.00
2D1092	2017-08-14 07:10:00+03	81700.00
2D10C5	2017-07-31 19:15:00+03	47400.00
2D10CC	2017-07-12 15:30:00+03	20200.00
2D10F4	2017-07-09 02:22:00+03	51600.00
2D10FA	2017-07-27 01:43:00+03	56000.00
2D113F	2017-08-03 16:31:00+03	246000.00
2D11A3	2017-07-01 20:28:00+03	27300.00
2D123C	2017-08-06 03:42:00+03	31600.00
2D123F	2017-08-07 09:38:00+03	23200.00
2D124B	2017-07-07 06:38:00+03	30200.00
2D1274	2017-07-11 21:49:00+03	65600.00
2D12BF	2017-07-28 03:24:00+03	26000.00
2D12D0	2017-07-23 07:40:00+03	26800.00
2D12DE	2017-08-09 00:33:00+03	75300.00
2D1304	2017-07-24 12:51:00+03	97900.00
2D1384	2017-07-25 08:20:00+03	163400.00
2D1395	2017-08-05 14:06:00+03	54800.00
2D13BE	2017-07-22 13:05:00+03	135400.00
2D1400	2017-08-05 11:24:00+03	56000.00
2D140D	2017-07-21 07:44:00+03	115700.00
2D1454	2017-08-01 15:35:00+03	34600.00
2D1466	2017-07-28 14:25:00+03	38800.00
2D14A8	2017-08-07 10:55:00+03	56200.00
2D14C0	2017-07-23 07:41:00+03	26700.00
2D152E	2017-08-02 05:55:00+03	7400.00
2D155B	2017-07-11 22:33:00+03	24400.00
2D157C	2017-08-02 14:01:00+03	32700.00
2D1598	2017-08-13 19:15:00+03	152100.00
2D15AF	2017-07-28 14:25:00+03	64700.00
2D15E6	2017-07-09 20:59:00+03	46000.00
2D164A	2017-08-08 04:38:00+03	44500.00
2D168D	2017-08-03 08:50:00+03	25900.00
2D174A	2017-07-10 03:52:00+03	28600.00
2D1751	2017-08-05 03:18:00+03	24200.00
2D175F	2017-07-20 01:33:00+03	327100.00
2D179F	2017-07-05 15:44:00+03	23200.00
2D17C7	2017-07-21 08:50:00+03	94000.00
2D17D4	2017-08-09 05:46:00+03	66000.00
2D1806	2017-08-05 00:54:00+03	12600.00
2D182D	2017-07-14 23:42:00+03	49800.00
2D184E	2017-07-23 22:28:00+03	21400.00
2D18AD	2017-08-01 09:25:00+03	119600.00
2D190F	2017-07-30 13:06:00+03	26700.00
2D192C	2017-07-18 20:30:00+03	23600.00
2D1942	2017-07-04 04:17:00+03	113700.00
2D19D1	2017-07-25 14:26:00+03	56600.00
2D1A35	2017-08-02 00:59:00+03	205600.00
2D1A82	2017-07-25 08:37:00+03	28800.00
2D1A94	2017-07-28 22:07:00+03	10600.00
2D1AED	2017-08-07 11:33:00+03	40800.00
2D1B5E	2017-08-14 12:13:00+03	24800.00
2D1BAA	2017-08-11 08:05:00+03	12600.00
2D1CE9	2017-07-07 05:13:00+03	87300.00
2D1D43	2017-07-07 12:08:00+03	316700.00
2D1D4E	2017-07-05 17:12:00+03	130400.00
2D1D74	2017-07-12 20:25:00+03	153300.00
2D1D9F	2017-07-27 15:37:00+03	138500.00
2D1DD8	2017-08-06 16:48:00+03	50600.00
2D1E02	2017-07-26 00:07:00+03	34000.00
2D1E14	2017-07-13 15:43:00+03	58400.00
2D1E75	2017-07-26 00:11:00+03	102100.00
2D1EBB	2017-07-18 19:18:00+03	102100.00
2D1EDF	2017-07-19 14:46:00+03	58800.00
2D1EEC	2017-08-06 07:53:00+03	11800.00
2D1F05	2017-07-17 12:35:00+03	18600.00
2D1F0C	2017-07-23 13:11:00+03	43900.00
2D1F50	2017-07-21 00:04:00+03	44000.00
2D1F5F	2017-07-27 00:20:00+03	89600.00
2D1F76	2017-08-02 08:33:00+03	51600.00
2D1F85	2017-08-14 04:43:00+03	62900.00
2D1FBC	2017-08-08 03:05:00+03	37100.00
2D1FC0	2017-07-29 12:59:00+03	26800.00
2D1FCD	2017-07-24 01:27:00+03	79100.00
2D2030	2017-07-29 02:23:00+03	19600.00
2D2051	2017-08-02 19:49:00+03	16400.00
2D2079	2017-07-10 18:09:00+03	321600.00
2D2087	2017-07-24 13:38:00+03	85000.00
2D20BA	2017-07-06 01:32:00+03	271200.00
2D20C8	2017-07-04 20:51:00+03	24200.00
2D2121	2017-07-22 20:08:00+03	26400.00
2D2153	2017-08-01 18:42:00+03	110500.00
2D21E1	2017-07-09 11:30:00+03	65500.00
2D2201	2017-07-11 12:16:00+03	75600.00
2D221A	2017-07-30 23:53:00+03	6300.00
2D2293	2017-08-15 04:17:00+03	42800.00
2D22F1	2017-07-12 10:00:00+03	21400.00
2D2314	2017-07-11 12:20:00+03	70100.00
2D231B	2017-08-11 05:31:00+03	56300.00
2D235A	2017-08-03 09:09:00+03	58200.00
2D238D	2017-07-24 00:41:00+03	50600.00
2D23D5	2017-07-12 23:01:00+03	136200.00
2D23EF	2017-07-21 12:54:00+03	57600.00
2D2425	2017-07-19 14:47:00+03	50000.00
2D245D	2017-08-11 13:35:00+03	28800.00
2D24F8	2017-07-29 20:52:00+03	136400.00
2D252C	2017-08-12 10:55:00+03	53100.00
2D2548	2017-07-06 07:34:00+03	55800.00
2D2550	2017-08-11 09:02:00+03	36400.00
2D260D	2017-07-12 00:56:00+03	123000.00
2D260E	2017-07-08 15:30:00+03	36200.00
2D2610	2017-07-30 10:08:00+03	88900.00
2D2627	2017-07-27 07:28:00+03	73900.00
2D262E	2017-07-04 03:05:00+03	99200.00
2D2644	2017-08-13 01:33:00+03	34000.00
2D2669	2017-07-13 22:55:00+03	28800.00
2D2690	2017-07-08 06:44:00+03	19600.00
2D26A7	2017-07-15 14:01:00+03	50800.00
2D26F2	2017-07-22 09:15:00+03	172100.00
2D273B	2017-07-03 05:47:00+03	64100.00
2D2757	2017-07-26 15:05:00+03	43200.00
2D2840	2017-08-02 05:56:00+03	123000.00
2D2865	2017-07-05 21:17:00+03	98400.00
2D289A	2017-08-13 01:28:00+03	46800.00
2D28C5	2017-08-05 10:39:00+03	70500.00
2D28ED	2017-08-04 22:15:00+03	95500.00
2D291B	2017-07-21 14:39:00+03	38400.00
2D2944	2017-07-29 00:52:00+03	9200.00
2D2994	2017-07-10 22:14:00+03	85600.00
2D2996	2017-07-25 08:28:00+03	67100.00
2D2AE0	2017-07-27 22:33:00+03	40100.00
2D2B01	2017-07-18 19:23:00+03	112200.00
2D2B1F	2017-07-22 05:57:00+03	40000.00
2D2C16	2017-08-12 01:24:00+03	46400.00
2D2C66	2017-07-23 03:12:00+03	14800.00
2D2C71	2017-07-16 13:12:00+03	28800.00
2D2C93	2017-08-06 17:36:00+03	56800.00
2D2CB4	2017-07-08 08:56:00+03	13400.00
2D2D1D	2017-08-15 00:56:00+03	87100.00
2D2D2A	2017-08-11 17:43:00+03	296400.00
2D2D5D	2017-07-08 06:55:00+03	116400.00
2D2D78	2017-08-07 04:48:00+03	53100.00
2D2E0C	2017-07-29 07:47:00+03	50800.00
2D2E22	2017-07-01 10:58:00+03	11000.00
2D2E55	2017-07-26 14:16:00+03	60800.00
2D2EF4	2017-08-03 20:16:00+03	100600.00
2D2F26	2017-07-17 08:34:00+03	139300.00
2D2FC0	2017-07-29 06:28:00+03	210000.00
2D2FD4	2017-07-09 14:14:00+03	15900.00
2D2FE6	2017-08-03 21:41:00+03	26000.00
2D3019	2017-08-07 03:42:00+03	32700.00
2D3049	2017-07-23 20:43:00+03	23200.00
2D30A0	2017-06-30 12:25:00+03	43600.00
2D3143	2017-07-18 06:16:00+03	47400.00
2D3146	2017-08-03 22:15:00+03	130900.00
2D3148	2017-07-28 09:04:00+03	70600.00
2D3155	2017-07-29 20:52:00+03	70800.00
2D318F	2017-07-11 04:11:00+03	17200.00
2D31C9	2017-08-09 06:40:00+03	22000.00
2D321A	2017-07-09 05:48:00+03	36800.00
2D3231	2017-07-10 01:11:00+03	56000.00
2D327A	2017-07-31 02:19:00+03	47100.00
2D32E5	2017-06-29 18:43:00+03	47400.00
2D3323	2017-07-25 04:27:00+03	33400.00
2D3344	2017-07-03 09:56:00+03	56000.00
2D337B	2017-08-07 14:06:00+03	157700.00
2D33F8	2017-07-20 08:21:00+03	266400.00
2D33FE	2017-07-11 04:54:00+03	44000.00
2D340F	2017-08-06 13:39:00+03	14800.00
2D34AF	2017-07-02 14:13:00+03	92600.00
2D34B9	2017-07-19 10:19:00+03	97200.00
2D34F0	2017-07-18 04:52:00+03	88500.00
2D356F	2017-08-08 19:31:00+03	56000.00
2D3599	2017-08-10 14:51:00+03	154500.00
2D3678	2017-07-07 13:25:00+03	172500.00
2D367E	2017-08-15 04:48:00+03	66100.00
2D3733	2017-08-06 12:47:00+03	94200.00
2D3742	2017-07-13 21:14:00+03	33000.00
2D374B	2017-08-14 21:13:00+03	93900.00
2D378C	2017-07-09 12:59:00+03	56000.00
2D37BD	2017-07-30 09:05:00+03	20200.00
2D37C5	2017-07-21 05:02:00+03	57600.00
2D37DC	2017-07-03 21:52:00+03	48800.00
2D3815	2017-08-08 15:44:00+03	6000.00
2D384B	2017-08-04 00:13:00+03	16400.00
2D393F	2017-07-20 21:47:00+03	131100.00
2D39EE	2017-08-02 05:57:00+03	136500.00
2D3AF7	2017-07-02 10:47:00+03	124200.00
2D3B5B	2017-08-07 18:45:00+03	12200.00
2D3B96	2017-07-21 04:53:00+03	36000.00
2D3BB8	2017-07-02 19:38:00+03	55800.00
2D3BE8	2017-07-29 00:21:00+03	50200.00
2D3BED	2017-08-11 01:13:00+03	32700.00
2D3C41	2017-07-14 14:31:00+03	34400.00
2D3C44	2017-08-02 19:48:00+03	22100.00
2D3C82	2017-07-14 07:50:00+03	81900.00
2D3CC1	2017-07-14 13:49:00+03	38500.00
2D3CF8	2017-07-06 11:38:00+03	131600.00
2D3D15	2017-07-02 06:16:00+03	101100.00
2D3D27	2017-07-27 21:35:00+03	14000.00
2D3D33	2017-07-31 23:02:00+03	42800.00
2D3D51	2017-07-14 03:27:00+03	93700.00
2D3D96	2017-08-14 05:30:00+03	36700.00
2D3DA3	2017-08-07 13:27:00+03	142400.00
2D3DB9	2017-08-12 09:24:00+03	19600.00
2D3DF3	2017-08-01 21:37:00+03	38600.00
2D3E97	2017-08-04 02:01:00+03	110500.00
2D3EEB	2017-07-20 23:39:00+03	52000.00
2D3F76	2017-08-09 12:14:00+03	399600.00
2D3F80	2017-08-08 05:47:00+03	59200.00
2D3FC6	2017-07-03 01:27:00+03	6800.00
2D3FD1	2017-07-28 10:16:00+03	12600.00
2D3FF4	2017-07-17 19:32:00+03	85400.00
2D4006	2017-08-07 14:45:00+03	151300.00
2D407B	2017-07-31 08:09:00+03	46000.00
2D4089	2017-08-03 10:27:00+03	112000.00
2D408B	2017-08-06 12:50:00+03	22000.00
2D41C3	2017-07-25 19:18:00+03	51800.00
2D4205	2017-08-02 19:15:00+03	88200.00
2D420C	2017-07-05 14:46:00+03	50000.00
2D4228	2017-07-08 20:53:00+03	202100.00
2D4242	2017-08-07 18:55:00+03	65600.00
2D42F8	2017-08-09 20:30:00+03	28800.00
2D436C	2017-07-25 14:13:00+03	69000.00
2D4449	2017-07-26 14:23:00+03	37100.00
2D445E	2017-08-13 03:46:00+03	56100.00
2D4467	2017-07-10 14:16:00+03	25800.00
2D4478	2017-07-25 11:44:00+03	8400.00
2D44B7	2017-08-07 03:07:00+03	39300.00
2D4543	2017-07-13 15:42:00+03	12000.00
2D45C6	2017-08-06 01:45:00+03	29600.00
2D45CA	2017-07-14 16:39:00+03	68800.00
2D4623	2017-08-08 03:39:00+03	48800.00
2D46B7	2017-07-07 14:36:00+03	170000.00
2D4741	2017-07-13 03:03:00+03	26000.00
2D477D	2017-08-09 18:09:00+03	41300.00
2D47C5	2017-06-28 13:56:00+03	32700.00
2D47D0	2017-08-01 03:28:00+03	59200.00
2D4822	2017-07-23 02:00:00+03	66600.00
2D4928	2017-06-29 03:58:00+03	92400.00
2D493B	2017-07-09 18:25:00+03	173500.00
2D49A9	2017-07-07 04:09:00+03	8000.00
2D49C4	2017-08-08 08:23:00+03	8200.00
2D49C9	2017-08-05 16:37:00+03	28000.00
2D49F3	2017-08-02 17:51:00+03	56000.00
2D4A59	2017-07-30 02:07:00+03	31400.00
2D4A66	2017-07-05 21:08:00+03	32800.00
2D4ADB	2017-06-30 05:27:00+03	43500.00
2D4B1C	2017-07-29 22:56:00+03	47300.00
2D4B9A	2017-07-20 23:23:00+03	31600.00
2D4BB5	2017-08-10 08:33:00+03	62900.00
2D4BDF	2017-07-03 12:48:00+03	68800.00
2D4C2C	2017-08-12 02:37:00+03	28300.00
2D4C32	2017-08-05 22:05:00+03	59800.00
2D4CC8	2017-07-01 15:34:00+03	106400.00
2D4CCB	2017-07-09 23:39:00+03	56600.00
2D4CD1	2017-07-01 02:17:00+03	47400.00
2D4CF4	2017-07-06 14:38:00+03	40000.00
2D4CFA	2017-07-08 15:39:00+03	16400.00
2D4D04	2017-07-18 05:59:00+03	47500.00
2D4D05	2017-07-30 08:22:00+03	66600.00
2D4D2A	2017-07-28 07:16:00+03	28000.00
2D4D4E	2017-07-23 14:44:00+03	56000.00
2D4D55	2017-07-19 17:43:00+03	73600.00
2D4D5E	2017-08-03 17:26:00+03	23400.00
2D4DB5	2017-07-26 09:09:00+03	76600.00
2D4DD8	2017-07-29 16:53:00+03	89700.00
2D4EB8	2017-07-08 07:45:00+03	52900.00
2D4EF0	2017-07-10 01:00:00+03	67700.00
2D4EF3	2017-07-14 02:08:00+03	46400.00
2D4F13	2017-07-30 13:24:00+03	57400.00
2D4F61	2017-07-31 18:56:00+03	31600.00
2D4F8E	2017-07-27 15:12:00+03	34000.00
2D5004	2017-08-04 07:39:00+03	20200.00
2D500C	2017-08-01 01:18:00+03	188700.00
2D505D	2017-08-02 09:30:00+03	27900.00
2D509A	2017-07-03 00:18:00+03	55800.00
2D5150	2017-08-06 03:43:00+03	60300.00
2D5155	2017-07-07 17:23:00+03	133200.00
2D5190	2017-07-07 02:48:00+03	123200.00
2D51AB	2017-07-05 11:04:00+03	77900.00
2D51DC	2017-08-14 13:50:00+03	12600.00
2D5206	2017-07-16 11:28:00+03	146800.00
2D524F	2017-08-02 15:11:00+03	205000.00
2D52C9	2017-08-07 11:16:00+03	166100.00
2D52F1	2017-07-15 09:05:00+03	103900.00
2D5302	2017-08-14 08:02:00+03	70800.00
2D5386	2017-07-18 20:46:00+03	67200.00
2D5391	2017-08-11 04:26:00+03	73400.00
2D53C4	2017-07-14 00:29:00+03	51900.00
2D53D5	2017-08-06 03:53:00+03	23600.00
2D540D	2017-08-08 20:55:00+03	44800.00
2D541A	2017-07-13 19:05:00+03	89600.00
2D5420	2017-08-11 15:35:00+03	81300.00
2D548F	2017-08-13 10:55:00+03	108700.00
2D54E0	2017-07-21 20:45:00+03	133700.00
2D5526	2017-07-14 02:04:00+03	70600.00
2D5549	2017-07-15 21:08:00+03	94800.00
2D55E7	2017-08-02 04:50:00+03	13000.00
2D561B	2017-07-20 23:44:00+03	49100.00
2D5685	2017-08-11 11:40:00+03	50600.00
2D56DF	2017-07-18 16:11:00+03	123000.00
2D5753	2017-07-25 17:51:00+03	8000.00
2D579A	2017-06-30 21:05:00+03	134100.00
2D5815	2017-08-05 23:29:00+03	38900.00
2D5879	2017-07-05 11:46:00+03	67500.00
2D589A	2017-07-20 20:44:00+03	8000.00
2D5923	2017-06-30 02:30:00+03	30000.00
2D595E	2017-07-17 06:07:00+03	8200.00
2D5961	2017-08-11 13:02:00+03	69500.00
2D59B0	2017-07-30 04:15:00+03	23200.00
2D59CC	2017-06-29 14:19:00+03	68400.00
2D5A25	2017-07-01 04:10:00+03	51800.00
2D5A72	2017-07-09 01:36:00+03	39300.00
2D5AA6	2017-07-17 11:58:00+03	8200.00
2D5B0B	2017-08-12 12:15:00+03	31600.00
2D5B51	2017-08-14 17:25:00+03	48800.00
2D5B5F	2017-08-03 20:57:00+03	6700.00
2D5B66	2017-07-25 07:01:00+03	14800.00
2D5BC3	2017-08-12 13:00:00+03	24400.00
2D5C04	2017-08-08 16:24:00+03	35200.00
2D5D1A	2017-07-18 20:48:00+03	185300.00
2D5D85	2017-07-17 04:38:00+03	20200.00
2D5E06	2017-07-15 03:39:00+03	62800.00
2D5E65	2017-08-03 02:55:00+03	246000.00
2D5E77	2017-08-01 18:13:00+03	135400.00
2D5EF2	2017-07-14 19:21:00+03	293900.00
2D5F03	2017-08-12 04:16:00+03	45100.00
2D5F37	2017-07-04 16:23:00+03	49000.00
2D5F3A	2017-07-06 18:25:00+03	26000.00
2D5F78	2017-07-26 01:26:00+03	26000.00
2D6000	2017-08-06 09:14:00+03	186900.00
2D6032	2017-08-15 02:53:00+03	29400.00
2D6080	2017-08-01 15:59:00+03	52000.00
2D60C0	2017-07-06 05:16:00+03	97600.00
2D6179	2017-08-09 18:03:00+03	18000.00
2D61B0	2017-07-25 08:43:00+03	36800.00
2D61F8	2017-07-15 13:55:00+03	148700.00
2D6231	2017-08-09 17:21:00+03	44800.00
2D625F	2017-07-09 10:32:00+03	23200.00
2D6329	2017-07-01 07:50:00+03	81600.00
2D632D	2017-07-29 04:58:00+03	148200.00
2D633F	2017-07-26 05:57:00+03	131100.00
2D63A2	2017-06-27 19:30:00+03	88900.00
2D63B0	2017-07-15 03:40:00+03	47400.00
2D63EC	2017-07-07 17:11:00+03	26500.00
2D6406	2017-07-17 08:23:00+03	135600.00
2D647F	2017-07-09 11:22:00+03	22000.00
2D64E1	2017-07-12 12:10:00+03	26800.00
2D64E3	2017-08-09 05:06:00+03	48600.00
2D6503	2017-08-07 15:16:00+03	19600.00
2D6525	2017-08-02 13:27:00+03	49500.00
2D65D5	2017-07-24 10:20:00+03	99300.00
2D65E1	2017-08-10 06:53:00+03	140900.00
2D666C	2017-07-24 03:08:00+03	43100.00
2D66F0	2017-07-21 05:29:00+03	45200.00
2D6708	2017-08-07 14:00:00+03	23200.00
2D675B	2017-07-12 16:24:00+03	138400.00
2D67E5	2017-07-23 01:19:00+03	55800.00
2D6805	2017-08-12 09:48:00+03	38800.00
2D6819	2017-08-07 12:19:00+03	59400.00
2D6826	2017-07-23 11:29:00+03	48800.00
2D6894	2017-07-16 17:37:00+03	49400.00
2D68F2	2017-07-18 12:56:00+03	101200.00
2D694D	2017-07-24 08:53:00+03	43400.00
2D6964	2017-08-13 12:13:00+03	12600.00
2D6A09	2017-08-15 01:42:00+03	32700.00
2D6A9B	2017-08-11 08:50:00+03	28000.00
2D6AA3	2017-07-31 14:36:00+03	8000.00
2D6AE8	2017-07-13 13:00:00+03	29300.00
2D6AEA	2017-07-12 01:43:00+03	13200.00
2D6B12	2017-07-16 06:36:00+03	124600.00
2D6B2F	2017-07-01 06:32:00+03	396500.00
2D6B6A	2017-08-13 23:18:00+03	338400.00
2D6B6E	2017-08-14 20:36:00+03	86300.00
2D6B84	2017-07-12 18:56:00+03	170000.00
2D6BD4	2017-07-31 06:20:00+03	35600.00
2D6BFC	2017-07-18 18:55:00+03	66600.00
2D6C13	2017-08-12 06:45:00+03	186600.00
2D6CCA	2017-07-11 06:25:00+03	38400.00
2D6D90	2017-08-03 04:25:00+03	190400.00
2D6DF6	2017-08-04 05:33:00+03	23200.00
2D6E19	2017-07-19 16:39:00+03	68800.00
2D6E70	2017-07-29 16:04:00+03	55600.00
2D6EC2	2017-08-02 06:40:00+03	31600.00
2D6EF2	2017-07-22 05:24:00+03	13000.00
2D6F25	2017-07-09 03:09:00+03	354400.00
2D6F3E	2017-08-07 07:36:00+03	25600.00
2D6F49	2017-08-01 13:11:00+03	176400.00
2D6F7D	2017-07-18 18:15:00+03	7400.00
2D6FBB	2017-08-12 19:41:00+03	269500.00
2D6FFC	2017-07-24 03:39:00+03	123000.00
2D7029	2017-07-21 20:25:00+03	132800.00
2D7042	2017-08-06 15:54:00+03	13600.00
2D70D4	2017-07-22 08:00:00+03	46300.00
2D7130	2017-08-06 05:19:00+03	88100.00
2D71E9	2017-07-04 03:36:00+03	159200.00
2D7297	2017-07-17 19:57:00+03	66600.00
2D72A9	2017-07-28 08:47:00+03	133200.00
2D736B	2017-07-19 11:19:00+03	125100.00
2D7470	2017-08-05 02:12:00+03	104600.00
2D7485	2017-07-14 09:58:00+03	37200.00
2D749D	2017-07-11 02:54:00+03	14400.00
2D7502	2017-07-27 02:57:00+03	246000.00
2D7513	2017-08-04 01:55:00+03	90600.00
2D75B6	2017-07-26 08:32:00+03	7400.00
2D75CE	2017-07-05 21:15:00+03	148200.00
2D75DE	2017-08-12 02:55:00+03	123300.00
2D75EE	2017-07-03 16:42:00+03	96300.00
2D75F6	2017-08-09 05:07:00+03	87200.00
2D7632	2017-06-30 10:24:00+03	57300.00
2D7664	2017-07-23 16:50:00+03	87700.00
2D76B1	2017-07-22 06:20:00+03	102600.00
2D7717	2017-07-17 00:07:00+03	16400.00
2D7723	2017-08-10 09:59:00+03	48400.00
2D7825	2017-07-06 01:58:00+03	19600.00
2D7853	2017-07-17 01:47:00+03	156500.00
2D7897	2017-08-07 02:03:00+03	16000.00
2D78B3	2017-08-07 12:46:00+03	54000.00
2D78C4	2017-07-07 12:49:00+03	21600.00
2D790F	2017-07-21 15:49:00+03	28800.00
2D7931	2017-07-11 11:01:00+03	52400.00
2D7987	2017-06-30 16:26:00+03	82600.00
2D7996	2017-08-02 20:33:00+03	38600.00
2D799D	2017-07-10 13:16:00+03	170200.00
2D79ED	2017-07-31 13:11:00+03	36900.00
2D7A29	2017-08-14 23:06:00+03	79600.00
2D7A6B	2017-07-21 18:04:00+03	131100.00
2D7A93	2017-07-09 17:51:00+03	155600.00
2D7A9F	2017-07-03 19:17:00+03	116000.00
2D7B50	2017-08-02 16:48:00+03	54300.00
2D7BE2	2017-07-21 20:08:00+03	23600.00
2D7BF6	2017-08-04 23:31:00+03	70800.00
2D7C3F	2017-08-12 10:02:00+03	102200.00
2D7C4E	2017-08-08 00:35:00+03	65500.00
2D7C9B	2017-08-08 13:59:00+03	85400.00
2D7CBA	2017-07-12 14:33:00+03	53400.00
2D7CE3	2017-07-01 13:35:00+03	28000.00
2D7D57	2017-08-12 05:17:00+03	159800.00
2D7D6E	2017-08-04 14:11:00+03	48800.00
2D7DA0	2017-07-09 11:11:00+03	91100.00
2D7DAA	2017-08-14 00:52:00+03	90400.00
2D7DD3	2017-06-29 09:32:00+03	56000.00
2D7DE7	2017-07-30 01:53:00+03	66300.00
2D7DFC	2017-06-30 09:29:00+03	63700.00
2D7E1C	2017-07-27 08:52:00+03	69500.00
2D7E2E	2017-08-02 21:12:00+03	26000.00
2D7E59	2017-07-28 20:46:00+03	13400.00
2D7EF5	2017-07-20 01:29:00+03	12600.00
2D7F88	2017-07-29 23:16:00+03	23200.00
2D7FA6	2017-07-25 21:50:00+03	185300.00
2D7FED	2017-08-04 03:55:00+03	170200.00
2D807D	2017-07-12 21:15:00+03	100000.00
2D8093	2017-07-19 12:58:00+03	11800.00
2D8135	2017-07-03 04:18:00+03	12600.00
2D8150	2017-07-11 00:15:00+03	132800.00
2D815C	2017-07-19 13:49:00+03	66600.00
2D8174	2017-07-22 11:22:00+03	55800.00
2D817A	2017-07-26 09:49:00+03	20000.00
2D8182	2017-08-05 13:16:00+03	55800.00
2D8184	2017-08-03 13:59:00+03	28800.00
2D81D3	2017-06-29 16:01:00+03	382200.00
2D81FE	2017-07-28 00:28:00+03	46300.00
2D8255	2017-07-19 03:11:00+03	123900.00
2D82CE	2017-07-16 11:15:00+03	25000.00
2D8322	2017-08-06 07:45:00+03	44800.00
2D832C	2017-07-31 20:24:00+03	69900.00
2D8374	2017-07-22 02:00:00+03	13700.00
2D83AF	2017-08-03 11:39:00+03	6700.00
2D83B5	2017-08-15 08:26:00+03	54000.00
2D83B6	2017-07-29 23:34:00+03	83900.00
2D8456	2017-08-13 12:15:00+03	131100.00
2D8462	2017-07-14 17:09:00+03	23200.00
2D84E3	2017-08-06 14:18:00+03	17800.00
2D8519	2017-08-08 17:47:00+03	15100.00
2D8558	2017-08-04 16:44:00+03	52800.00
2D85C4	2017-08-15 02:32:00+03	22600.00
2D85FE	2017-08-03 18:33:00+03	40200.00
2D861C	2017-08-07 06:38:00+03	26000.00
2D8639	2017-07-17 12:38:00+03	31600.00
2D8680	2017-07-17 10:54:00+03	52300.00
2D8681	2017-07-11 23:40:00+03	6700.00
2D868E	2017-08-10 20:09:00+03	124300.00
2D86A5	2017-07-06 00:44:00+03	34000.00
2D86CA	2017-08-15 08:52:00+03	91800.00
2D8772	2017-07-13 17:16:00+03	11600.00
2D877C	2017-07-18 07:38:00+03	54500.00
2D8788	2017-08-06 11:15:00+03	29600.00
2D87D9	2017-07-07 16:22:00+03	94400.00
2D891A	2017-07-21 02:12:00+03	6300.00
2D8A08	2017-07-24 15:00:00+03	66600.00
2D8A5F	2017-08-09 01:35:00+03	89600.00
2D8AE6	2017-07-27 15:12:00+03	19800.00
2D8B01	2017-07-25 08:35:00+03	23600.00
2D8B1D	2017-08-03 04:30:00+03	119300.00
2D8B24	2017-07-02 02:46:00+03	40400.00
2D8B93	2017-08-08 03:00:00+03	80800.00
2D8BBC	2017-07-05 18:04:00+03	23600.00
2D8BC1	2017-08-04 23:06:00+03	107800.00
2D8C22	2017-07-28 00:25:00+03	72000.00
2D8CAC	2017-08-03 05:54:00+03	52000.00
2D8CC3	2017-07-23 16:27:00+03	119500.00
2D8CD9	2017-08-02 00:48:00+03	13600.00
2D8D73	2017-08-09 02:02:00+03	7400.00
2D8DBE	2017-07-27 06:23:00+03	115000.00
2D8DE9	2017-07-18 03:34:00+03	56000.00
2D8E06	2017-08-11 00:28:00+03	59800.00
2D8E0D	2017-07-01 14:38:00+03	8800.00
2D8E11	2017-07-30 11:50:00+03	11300.00
2D8E1B	2017-07-14 06:48:00+03	410200.00
2D8E30	2017-07-27 19:45:00+03	59400.00
2D8E6D	2017-07-16 17:10:00+03	68800.00
2D8ECB	2017-07-30 19:18:00+03	29600.00
2D8F79	2017-07-01 14:32:00+03	45400.00
2D8FBC	2017-07-26 08:01:00+03	369700.00
2D8FE2	2017-08-04 15:40:00+03	28800.00
2D9035	2017-07-09 21:17:00+03	28000.00
2D90E2	2017-07-01 21:58:00+03	74300.00
2D9123	2017-07-06 11:14:00+03	49100.00
2D9159	2017-07-13 22:38:00+03	266400.00
2D9160	2017-07-03 08:17:00+03	23800.00
2D91BB	2017-08-12 00:59:00+03	23100.00
2D91C7	2017-07-06 03:48:00+03	37700.00
2D922E	2017-07-06 14:33:00+03	143000.00
2D9274	2017-07-09 20:01:00+03	69600.00
2D92C8	2017-07-23 13:40:00+03	26000.00
2D92D9	2017-07-26 13:26:00+03	75600.00
2D92FA	2017-08-14 18:14:00+03	22000.00
2D9396	2017-07-24 05:17:00+03	99300.00
2D9538	2017-08-08 21:38:00+03	65000.00
2D9611	2017-07-23 04:22:00+03	23200.00
2D962B	2017-08-13 06:06:00+03	61600.00
2D9632	2017-08-11 19:26:00+03	46400.00
2D965D	2017-07-30 14:06:00+03	63200.00
2D967F	2017-07-19 10:16:00+03	28000.00
2D9692	2017-07-19 21:17:00+03	26000.00
2D969C	2017-06-28 08:02:00+03	88600.00
2D96C5	2017-08-13 04:52:00+03	248400.00
2D96FF	2017-08-13 07:27:00+03	26500.00
2D973A	2017-07-16 09:29:00+03	179300.00
2D974A	2017-08-01 04:46:00+03	6700.00
2D9780	2017-07-16 12:21:00+03	60600.00
2D9782	2017-07-01 12:10:00+03	6300.00
2D97A2	2017-07-27 12:54:00+03	118800.00
2D97D3	2017-07-16 17:30:00+03	47200.00
2D985E	2017-07-20 14:32:00+03	246000.00
2D98A6	2017-08-12 07:08:00+03	111600.00
2D9994	2017-07-07 07:38:00+03	26000.00
2D99DA	2017-08-10 22:19:00+03	106900.00
2D9A11	2017-07-29 23:18:00+03	47500.00
2D9A32	2017-07-10 13:17:00+03	37700.00
2D9A49	2017-07-03 17:19:00+03	147900.00
2D9AC5	2017-08-04 23:18:00+03	92200.00
2D9AC6	2017-08-15 14:28:00+03	154500.00
2D9AE5	2017-07-16 12:24:00+03	16000.00
2D9B86	2017-07-11 17:33:00+03	8000.00
2D9C4E	2017-08-05 11:51:00+03	26400.00
2D9C8F	2017-07-29 03:45:00+03	43400.00
2D9C99	2017-07-12 21:32:00+03	100200.00
2D9CD3	2017-08-08 15:05:00+03	38200.00
2D9D1B	2017-07-15 16:18:00+03	66600.00
2D9D46	2017-07-08 17:09:00+03	37200.00
2D9D5C	2017-07-30 08:37:00+03	75800.00
2D9D77	2017-08-07 08:17:00+03	89700.00
2D9DB4	2017-07-23 21:32:00+03	115500.00
2D9E0E	2017-07-08 17:55:00+03	43200.00
2D9E8C	2017-07-18 20:08:00+03	101200.00
2D9EA2	2017-08-01 20:56:00+03	131100.00
2D9EE6	2017-07-15 05:55:00+03	172100.00
2D9F5C	2017-07-29 05:45:00+03	64900.00
2D9FE4	2017-07-19 07:25:00+03	258000.00
2DA015	2017-08-08 03:21:00+03	75600.00
2DA046	2017-07-21 12:05:00+03	68800.00
2DA085	2017-08-09 07:38:00+03	86300.00
2DA0B7	2017-07-23 15:34:00+03	39600.00
2DA187	2017-07-24 00:58:00+03	26600.00
2DA19D	2017-08-05 05:21:00+03	91300.00
2DA201	2017-07-13 03:41:00+03	85000.00
2DA21D	2017-07-22 22:58:00+03	86800.00
2DA273	2017-07-06 04:59:00+03	56000.00
2DA276	2017-08-04 06:41:00+03	56000.00
2DA29F	2017-08-09 16:56:00+03	55800.00
2DA2E1	2017-07-20 01:14:00+03	17800.00
2DA431	2017-08-15 02:43:00+03	26000.00
2DA469	2017-07-07 01:10:00+03	26000.00
2DA47A	2017-07-13 19:41:00+03	19800.00
2DA489	2017-07-01 12:15:00+03	19600.00
2DA4BF	2017-08-01 08:11:00+03	266200.00
2DA4D0	2017-08-04 13:43:00+03	24400.00
2DA564	2017-08-04 08:53:00+03	27800.00
2DA58A	2017-08-05 12:37:00+03	406800.00
2DA590	2017-08-13 21:14:00+03	38400.00
2DA5A1	2017-07-04 22:28:00+03	25400.00
2DA5AC	2017-07-03 04:39:00+03	58200.00
2DA6A3	2017-07-31 18:32:00+03	32700.00
2DA6B6	2017-08-12 19:31:00+03	26800.00
2DA71A	2017-07-08 19:44:00+03	16800.00
2DA841	2017-07-02 12:09:00+03	115800.00
2DA8F8	2017-08-14 05:01:00+03	14800.00
2DA957	2017-07-30 06:42:00+03	42900.00
2DA9E7	2017-07-30 18:10:00+03	97900.00
2DAA41	2017-07-07 20:27:00+03	10100.00
2DAAB9	2017-07-20 05:00:00+03	24300.00
2DAAF7	2017-07-06 05:02:00+03	31000.00
2DAB28	2017-07-19 09:23:00+03	29600.00
2DAB35	2017-07-03 19:32:00+03	50000.00
2DAB6C	2017-08-02 04:00:00+03	65500.00
2DAB9D	2017-07-08 18:51:00+03	86300.00
2DABC4	2017-07-03 19:23:00+03	53300.00
2DAC12	2017-08-11 01:09:00+03	116400.00
2DAC1D	2017-07-17 20:45:00+03	56000.00
2DAC3D	2017-07-16 22:13:00+03	29800.00
2DAC5D	2017-07-27 00:40:00+03	54800.00
2DAC72	2017-07-03 17:13:00+03	408500.00
2DACBF	2017-07-01 06:35:00+03	37600.00
2DACDF	2017-07-18 16:41:00+03	115900.00
2DACFB	2017-06-30 05:13:00+03	27400.00
2DACFE	2017-07-14 06:18:00+03	406700.00
2DAD49	2017-07-16 05:35:00+03	270700.00
2DAD88	2017-07-30 03:50:00+03	131600.00
2DADAB	2017-07-06 07:41:00+03	95300.00
2DADE1	2017-07-16 20:42:00+03	46400.00
2DADED	2017-07-04 19:50:00+03	246100.00
2DAE47	2017-07-11 17:14:00+03	30000.00
2DAE54	2017-07-11 15:35:00+03	24400.00
2DAE7B	2017-07-17 23:37:00+03	189200.00
2DAEFC	2017-08-10 04:06:00+03	86600.00
2DAF20	2017-07-23 16:07:00+03	123400.00
2DAFC2	2017-07-21 22:16:00+03	32800.00
2DAFE0	2017-07-17 07:48:00+03	89600.00
2DB020	2017-07-26 15:58:00+03	28000.00
2DB044	2017-07-06 11:15:00+03	12600.00
2DB05F	2017-07-02 01:43:00+03	75700.00
2DB0FB	2017-07-02 21:15:00+03	62700.00
2DB10B	2017-07-28 19:23:00+03	58200.00
2DB1A4	2017-07-16 06:04:00+03	100600.00
2DB1B5	2017-08-13 18:16:00+03	50100.00
2DB211	2017-08-09 05:07:00+03	119800.00
2DB271	2017-08-05 01:01:00+03	68100.00
2DB28C	2017-07-04 20:48:00+03	12600.00
2DB2B6	2017-07-15 23:15:00+03	131600.00
2DB2C0	2017-08-07 12:17:00+03	27200.00
2DB2C3	2017-07-23 13:24:00+03	16000.00
2DB373	2017-07-08 12:43:00+03	64500.00
2DB37F	2017-07-27 18:39:00+03	79600.00
2DB3B0	2017-07-18 16:49:00+03	45000.00
2DB47F	2017-08-02 19:42:00+03	90800.00
2DB4BB	2017-07-16 03:23:00+03	132800.00
2DB502	2017-07-18 15:47:00+03	23400.00
2DB51C	2017-08-12 23:42:00+03	193700.00
2DB569	2017-07-21 20:28:00+03	54300.00
2DB589	2017-07-09 06:57:00+03	81600.00
2DB5A8	2017-07-18 04:55:00+03	48400.00
2DB661	2017-07-21 17:32:00+03	37900.00
2DB66F	2017-07-07 19:43:00+03	79600.00
2DB69C	2017-07-14 11:36:00+03	16400.00
2DB6A7	2017-07-24 12:15:00+03	143100.00
2DB6D2	2017-07-05 03:27:00+03	60400.00
2DB6D9	2017-07-09 04:55:00+03	207100.00
2DB6F5	2017-08-13 00:49:00+03	55400.00
2DB734	2017-07-11 18:27:00+03	26000.00
2DB7A1	2017-07-29 20:30:00+03	271100.00
2DB7B9	2017-07-16 19:10:00+03	24500.00
2DB7BC	2017-07-10 02:06:00+03	51800.00
2DB7DF	2017-07-27 05:25:00+03	23400.00
2DB826	2017-08-13 20:05:00+03	206400.00
2DB8BC	2017-07-06 13:48:00+03	12400.00
2DB999	2017-07-25 23:58:00+03	33600.00
2DB9E1	2017-07-26 03:18:00+03	24400.00
2DBA08	2017-07-17 19:26:00+03	22000.00
2DBA11	2017-08-11 02:11:00+03	20800.00
2DBA18	2017-07-13 15:10:00+03	55800.00
2DBB32	2017-08-12 03:19:00+03	30400.00
2DBBA8	2017-08-05 23:02:00+03	124300.00
2DBC35	2017-08-06 21:52:00+03	24400.00
2DBC38	2017-07-04 02:41:00+03	133200.00
2DBC3B	2017-07-16 13:54:00+03	18000.00
2DBCCB	2017-07-26 20:23:00+03	47400.00
2DBD1A	2017-08-10 15:15:00+03	29800.00
2DBD1D	2017-08-01 12:12:00+03	21800.00
2DBD6E	2017-07-30 08:26:00+03	363100.00
2DBD97	2017-08-04 20:09:00+03	88100.00
2DBDFC	2017-07-06 03:50:00+03	99300.00
2DBE16	2017-07-07 02:30:00+03	50000.00
2DBE25	2017-07-04 00:14:00+03	85000.00
2DBE76	2017-07-12 20:10:00+03	66600.00
2DBE97	2017-07-31 02:43:00+03	78700.00
2DBEEB	2017-08-08 02:20:00+03	43800.00
2DBEF0	2017-08-05 21:25:00+03	39100.00
2DBF0B	2017-07-06 07:07:00+03	40400.00
2DBFA2	2017-07-22 03:48:00+03	76600.00
2DBFF8	2017-08-06 00:27:00+03	38600.00
2DC010	2017-08-15 13:34:00+03	31700.00
2DC01B	2017-07-05 22:50:00+03	25200.00
2DC022	2017-08-01 13:47:00+03	188200.00
2DC081	2017-08-11 14:20:00+03	22100.00
2DC08D	2017-08-10 01:19:00+03	56100.00
2DC0C0	2017-08-13 08:24:00+03	225000.00
2DC0DD	2017-07-17 13:28:00+03	36800.00
2DC135	2017-07-10 05:54:00+03	27800.00
2DC136	2017-08-09 10:25:00+03	260300.00
2DC1A9	2017-07-26 05:44:00+03	6600.00
2DC288	2017-07-10 05:50:00+03	270800.00
2DC290	2017-07-26 17:19:00+03	20600.00
2DC2EF	2017-08-09 18:59:00+03	28800.00
2DC36B	2017-07-25 02:11:00+03	38200.00
2DC539	2017-07-04 09:44:00+03	118600.00
2DC586	2017-07-31 17:27:00+03	23200.00
2DC58F	2017-07-05 05:43:00+03	54600.00
2DC593	2017-08-14 12:26:00+03	145300.00
2DC5F2	2017-07-25 19:30:00+03	136200.00
2DC678	2017-08-15 08:17:00+03	79800.00
2DC69D	2017-07-09 08:07:00+03	113700.00
2DC6A4	2017-07-12 05:08:00+03	59200.00
2DC6BE	2017-07-07 15:41:00+03	340000.00
2DC6BF	2017-07-26 10:54:00+03	15000.00
2DC6D2	2017-07-30 13:47:00+03	93700.00
2DC70C	2017-07-16 15:48:00+03	42800.00
2DC725	2017-07-17 17:26:00+03	48200.00
2DC759	2017-08-01 22:05:00+03	52400.00
2DC79C	2017-07-29 20:57:00+03	38800.00
2DC7E6	2017-08-07 08:31:00+03	234600.00
2DC803	2017-07-31 12:30:00+03	22000.00
2DC828	2017-07-27 07:02:00+03	33600.00
2DC8AD	2017-07-04 12:29:00+03	24500.00
2DC8EF	2017-07-11 12:48:00+03	23400.00
2DC91D	2017-07-04 10:24:00+03	187600.00
2DC929	2017-07-30 04:12:00+03	73800.00
2DC931	2017-08-04 21:30:00+03	114500.00
2DC99E	2017-07-21 08:33:00+03	72000.00
2DCA19	2017-07-28 17:15:00+03	94000.00
2DCA1F	2017-07-29 05:42:00+03	83600.00
2DCA32	2017-08-07 09:03:00+03	114800.00
2DCA55	2017-07-07 07:36:00+03	7400.00
2DCA5E	2017-07-25 15:41:00+03	59300.00
2DCA64	2017-07-18 17:56:00+03	13000.00
2DCA6E	2017-07-07 07:59:00+03	40400.00
2DCAD8	2017-07-03 02:49:00+03	92100.00
2DCB0F	2017-07-15 14:31:00+03	29600.00
2DCB43	2017-07-19 21:53:00+03	39500.00
2DCB54	2017-08-08 12:45:00+03	47000.00
2DCBDC	2017-07-20 02:12:00+03	36900.00
2DCBED	2017-07-02 20:05:00+03	169000.00
2DCC15	2017-07-03 14:07:00+03	199700.00
2DCD35	2017-08-06 16:57:00+03	246000.00
2DCD36	2017-07-23 00:13:00+03	28800.00
2DCD3B	2017-08-10 18:14:00+03	58200.00
2DCD88	2017-08-03 11:06:00+03	47100.00
2DCDD4	2017-08-13 04:32:00+03	43600.00
2DCE1A	2017-08-12 21:38:00+03	116900.00
2DCE25	2017-07-22 01:06:00+03	58600.00
2DCE74	2017-07-15 10:08:00+03	44700.00
2DCED3	2017-07-03 17:33:00+03	66600.00
2DCF3D	2017-07-23 02:55:00+03	36800.00
2DCF3F	2017-07-27 19:07:00+03	28000.00
2DCFDE	2017-08-06 05:20:00+03	30200.00
2DCFE0	2017-07-03 09:13:00+03	66600.00
2DD036	2017-08-13 08:41:00+03	23900.00
2DD06F	2017-08-13 05:11:00+03	146300.00
2DD070	2017-07-23 04:48:00+03	176500.00
2DD073	2017-07-23 20:46:00+03	399600.00
2DD184	2017-07-06 05:12:00+03	49800.00
2DD1DE	2017-08-15 07:17:00+03	36700.00
2DD232	2017-08-05 22:56:00+03	113000.00
2DD2A3	2017-08-10 06:31:00+03	89700.00
2DD355	2017-07-04 20:18:00+03	6800.00
2DD37B	2017-08-03 15:58:00+03	48900.00
2DD3F7	2017-08-14 19:28:00+03	7400.00
2DD3FA	2017-08-02 13:44:00+03	418500.00
2DD530	2017-07-25 13:30:00+03	111600.00
2DD54A	2017-07-14 22:39:00+03	92900.00
2DD55B	2017-07-18 06:10:00+03	76400.00
2DD562	2017-08-07 17:23:00+03	19600.00
2DD5D3	2017-07-09 06:57:00+03	34000.00
2DD61E	2017-07-20 14:21:00+03	48800.00
2DD678	2017-07-16 16:34:00+03	135200.00
2DD679	2017-07-10 20:38:00+03	49900.00
2DD6D9	2017-07-15 15:47:00+03	26000.00
2DD6DF	2017-07-22 14:10:00+03	102000.00
2DD7AB	2017-08-07 09:52:00+03	272300.00
2DD7F6	2017-08-08 06:26:00+03	88600.00
2DD805	2017-07-23 18:58:00+03	36200.00
2DD871	2017-07-07 14:18:00+03	50300.00
2DD8E9	2017-06-30 01:34:00+03	58800.00
2DD968	2017-07-31 06:44:00+03	13400.00
2DDA0C	2017-07-16 09:45:00+03	54500.00
2DDA1D	2017-07-10 22:25:00+03	121400.00
2DDA85	2017-07-05 09:17:00+03	44500.00
2DDAE3	2017-08-07 00:56:00+03	73200.00
2DDB0D	2017-08-04 14:08:00+03	56600.00
2DDB6A	2017-07-17 09:32:00+03	113600.00
2DDB6B	2017-06-30 14:37:00+03	25600.00
2DDB92	2017-07-18 16:37:00+03	16400.00
2DDBFF	2017-08-02 12:24:00+03	132800.00
2DDC2F	2017-08-08 17:17:00+03	39200.00
2DDC65	2017-08-01 06:45:00+03	46400.00
2DDCC4	2017-07-14 12:23:00+03	25600.00
2DDD4B	2017-07-24 09:53:00+03	289100.00
2DDDA3	2017-08-14 22:54:00+03	202200.00
2DDE10	2017-07-15 03:57:00+03	43000.00
2DDEF2	2017-08-09 19:17:00+03	56000.00
2DDF21	2017-08-04 21:35:00+03	133200.00
2DDF2A	2017-07-30 17:18:00+03	14000.00
2DDF9B	2017-07-16 17:43:00+03	7200.00
2DDFC5	2017-07-26 10:11:00+03	24400.00
2DDFE9	2017-07-09 05:24:00+03	49300.00
2DDFFB	2017-07-16 00:43:00+03	40200.00
2DE003	2017-07-09 02:10:00+03	22600.00
2DE034	2017-07-06 17:27:00+03	94000.00
2DE09B	2017-08-11 16:19:00+03	43200.00
2DE0B6	2017-07-02 19:31:00+03	6700.00
2DE0C3	2017-07-11 09:05:00+03	38600.00
2DE172	2017-08-13 14:49:00+03	272400.00
2DE17A	2017-07-19 10:08:00+03	13400.00
2DE182	2017-07-28 19:04:00+03	24400.00
2DE184	2017-07-25 22:04:00+03	58600.00
2DE1B2	2017-07-02 08:12:00+03	168700.00
2DE259	2017-07-21 00:54:00+03	86300.00
2DE286	2017-07-06 18:39:00+03	16800.00
2DE2CB	2017-06-28 05:13:00+03	148200.00
2DE33C	2017-07-06 03:19:00+03	229300.00
2DE3C5	2017-07-02 11:55:00+03	88700.00
2DE3F2	2017-07-24 06:49:00+03	6000.00
2DE3F4	2017-08-07 22:53:00+03	100900.00
2DE3F9	2017-08-02 09:20:00+03	23100.00
2DE46C	2017-07-13 22:49:00+03	17200.00
2DE474	2017-08-14 18:09:00+03	90400.00
2DE57C	2017-07-23 10:35:00+03	7400.00
2DE596	2017-07-11 23:35:00+03	161400.00
2DE5BF	2017-07-06 20:11:00+03	93000.00
2DE5F9	2017-08-07 23:14:00+03	25100.00
2DE5FF	2017-08-01 02:55:00+03	46000.00
2DE63C	2017-06-26 10:15:00+03	25400.00
2DE67D	2017-07-11 02:39:00+03	56000.00
2DE6A4	2017-07-08 08:28:00+03	321900.00
2DE75D	2017-08-14 22:53:00+03	27200.00
2DE78F	2017-07-25 13:07:00+03	44600.00
2DE827	2017-07-18 22:03:00+03	54900.00
2DE856	2017-07-10 21:36:00+03	54800.00
2DE874	2017-07-21 10:06:00+03	33600.00
2DE8EC	2017-07-11 22:29:00+03	67000.00
2DE8FF	2017-07-19 10:08:00+03	38600.00
2DE916	2017-08-14 05:04:00+03	31600.00
2DE92F	2017-07-03 01:02:00+03	26000.00
2DE938	2017-08-09 22:44:00+03	101200.00
2DE975	2017-07-17 02:34:00+03	23400.00
2DE9A7	2017-07-14 17:16:00+03	37900.00
2DEA5B	2017-08-11 13:56:00+03	46400.00
2DEA5F	2017-07-29 16:51:00+03	25100.00
2DEAA8	2017-08-03 02:58:00+03	89600.00
2DEAB2	2017-07-30 19:02:00+03	6400.00
2DEBAB	2017-08-14 23:06:00+03	103500.00
2DEBD6	2017-07-13 02:10:00+03	88600.00
2DEC22	2017-08-03 13:36:00+03	27200.00
2DEC3D	2017-08-09 02:31:00+03	14000.00
2DEC7C	2017-07-18 03:45:00+03	135400.00
2DEC8F	2017-07-22 00:42:00+03	27600.00
2DECB3	2017-08-06 23:45:00+03	67600.00
2DECF2	2017-07-25 21:02:00+03	12400.00
2DECF6	2017-08-14 16:57:00+03	23200.00
2DED02	2017-07-06 01:27:00+03	29100.00
2DED6A	2017-07-24 13:51:00+03	83200.00
2DED82	2017-07-21 18:16:00+03	6300.00
2DEDD8	2017-06-30 09:31:00+03	36800.00
2DEE03	2017-07-09 02:56:00+03	58200.00
2DEE0B	2017-07-20 21:10:00+03	12000.00
2DEE7E	2017-07-01 04:28:00+03	28000.00
2DEE95	2017-08-07 20:48:00+03	62600.00
2DEE96	2017-07-25 05:25:00+03	88200.00
2DEE9C	2017-07-18 20:21:00+03	51900.00
2DEEA2	2017-08-11 11:59:00+03	62000.00
2DEECC	2017-07-15 15:22:00+03	108500.00
2DEF0E	2017-07-14 02:57:00+03	57700.00
2DEF3E	2017-08-11 03:54:00+03	26000.00
2DEF5C	2017-07-11 23:57:00+03	138900.00
2DEF65	2017-07-08 11:40:00+03	111600.00
2DEFAF	2017-08-14 05:59:00+03	68100.00
2DEFC5	2017-08-01 22:24:00+03	34400.00
2DEFFE	2017-07-18 03:21:00+03	119500.00
2DF05D	2017-06-30 01:26:00+03	28800.00
2DF17A	2017-07-29 20:54:00+03	111600.00
2DF1B8	2017-07-03 00:17:00+03	56600.00
2DF268	2017-08-14 20:19:00+03	12000.00
2DF2F9	2017-08-11 12:54:00+03	19800.00
2DF31D	2017-06-26 13:55:00+03	153900.00
2DF374	2017-07-18 15:14:00+03	202800.00
2DF419	2017-07-09 23:25:00+03	179400.00
2DF41F	2017-08-12 22:30:00+03	67600.00
2DF488	2017-07-16 16:13:00+03	52000.00
2DF4C4	2017-08-15 17:18:00+03	102000.00
2DF50B	2017-07-18 06:24:00+03	14400.00
2DF517	2017-08-09 05:13:00+03	283100.00
2DF530	2017-07-22 05:48:00+03	11800.00
2DF55D	2017-07-09 19:32:00+03	43000.00
2DF58B	2017-07-08 08:52:00+03	24800.00
2DF61A	2017-08-14 12:40:00+03	58000.00
2DF633	2017-07-25 09:35:00+03	51200.00
2DF637	2017-07-11 09:23:00+03	54500.00
2DF64A	2017-07-14 04:16:00+03	18600.00
2DF64C	2017-07-16 20:01:00+03	103000.00
2DF727	2017-08-07 11:02:00+03	255600.00
2DF729	2017-07-24 01:13:00+03	29200.00
2DF744	2017-07-17 13:51:00+03	14400.00
2DF75D	2017-08-11 19:09:00+03	11100.00
2DF79E	2017-07-18 07:27:00+03	66600.00
2DF7D2	2017-08-07 21:36:00+03	46400.00
2DF802	2017-06-30 14:26:00+03	45100.00
2DF807	2017-07-12 08:34:00+03	11600.00
2DF893	2017-07-01 13:09:00+03	85600.00
2DF8E5	2017-07-05 20:26:00+03	103000.00
2DF8E9	2017-07-09 09:54:00+03	58400.00
2DF963	2017-08-04 08:57:00+03	17000.00
2DF999	2017-07-18 21:49:00+03	282000.00
2DF9EF	2017-07-12 08:01:00+03	147700.00
2DFA07	2017-08-14 02:01:00+03	79900.00
2DFA68	2017-07-16 16:25:00+03	155600.00
2DFA9A	2017-07-10 13:44:00+03	72600.00
2DFAE1	2017-07-10 15:01:00+03	32800.00
2DFB1E	2017-07-11 14:19:00+03	37700.00
2DFB3C	2017-07-08 06:45:00+03	62700.00
2DFBF4	2017-07-15 11:27:00+03	14400.00
2DFBFC	2017-07-16 14:20:00+03	56600.00
2DFC77	2017-07-21 20:52:00+03	30000.00
2DFC98	2017-07-08 04:46:00+03	20400.00
2DFCD5	2017-08-12 20:11:00+03	86300.00
2DFCD7	2017-08-04 14:00:00+03	91600.00
2DFCDA	2017-08-05 05:51:00+03	131100.00
2DFCDB	2017-08-10 04:29:00+03	90800.00
2DFD11	2017-08-15 16:09:00+03	40800.00
2DFD84	2017-08-11 09:14:00+03	47200.00
2DFD97	2017-07-27 03:01:00+03	98700.00
2DFDC6	2017-07-16 05:06:00+03	12400.00
2DFDCD	2017-07-14 15:49:00+03	97100.00
2DFE23	2017-08-01 02:31:00+03	344500.00
2DFEDE	2017-06-26 13:48:00+03	57700.00
2DFF82	2017-08-09 19:41:00+03	59800.00
2DFF85	2017-07-31 18:49:00+03	49600.00
2DFFBC	2017-07-11 23:43:00+03	24200.00
2DFFC3	2017-07-15 04:11:00+03	61800.00
2DFFE8	2017-08-01 23:04:00+03	151200.00
2DFFF5	2017-07-17 19:05:00+03	28600.00
2E001D	2017-07-12 05:10:00+03	30000.00
2E0026	2017-07-23 06:55:00+03	55800.00
2E002B	2017-07-10 07:27:00+03	47000.00
2E0062	2017-07-16 14:49:00+03	46400.00
2E0096	2017-07-27 15:27:00+03	129700.00
2E0167	2017-08-10 18:10:00+03	9200.00
2E0188	2017-08-08 02:17:00+03	28800.00
2E01DB	2017-07-03 20:24:00+03	49200.00
2E020D	2017-08-04 19:29:00+03	97600.00
2E02A3	2017-08-05 14:27:00+03	297100.00
2E02BA	2017-08-09 01:30:00+03	265700.00
2E02C7	2017-07-05 03:31:00+03	21400.00
2E02CC	2017-08-09 23:50:00+03	35900.00
2E0349	2017-07-19 18:18:00+03	55800.00
2E038D	2017-07-30 22:03:00+03	104600.00
2E03C3	2017-08-12 10:58:00+03	63400.00
2E03C6	2017-08-06 07:04:00+03	80100.00
2E0405	2017-08-07 00:05:00+03	11800.00
2E0449	2017-08-11 02:40:00+03	92100.00
2E0463	2017-07-20 12:16:00+03	25600.00
2E055A	2017-07-27 06:34:00+03	56600.00
2E057F	2017-07-24 13:10:00+03	144000.00
2E05A5	2017-07-16 03:54:00+03	56000.00
2E05A8	2017-07-04 11:50:00+03	93400.00
2E05E3	2017-07-16 08:28:00+03	112000.00
2E065D	2017-07-14 07:59:00+03	28600.00
2E066D	2017-07-09 20:18:00+03	62600.00
2E06A2	2017-07-21 00:41:00+03	17200.00
2E075E	2017-07-19 05:51:00+03	65900.00
2E07B7	2017-07-06 10:43:00+03	136200.00
2E07EC	2017-08-15 05:59:00+03	21800.00
2E0816	2017-07-18 12:25:00+03	134400.00
2E0828	2017-07-10 19:31:00+03	77900.00
2E0850	2017-08-03 22:17:00+03	38800.00
2E0864	2017-07-11 12:35:00+03	40800.00
2E08AB	2017-07-19 21:16:00+03	79500.00
2E08CF	2017-08-15 02:04:00+03	62500.00
2E0937	2017-07-03 14:32:00+03	26000.00
2E0956	2017-07-02 03:34:00+03	25600.00
2E09ED	2017-08-05 18:49:00+03	271300.00
2E0A06	2017-07-28 04:05:00+03	85600.00
2E0A1D	2017-08-10 09:43:00+03	12400.00
2E0A4A	2017-07-28 08:18:00+03	14000.00
2E0B22	2017-07-01 22:49:00+03	44600.00
2E0B32	2017-07-06 07:39:00+03	21400.00
2E0B65	2017-08-15 05:08:00+03	20500.00
2E0B8D	2017-07-09 14:59:00+03	124200.00
2E0BB2	2017-08-15 04:35:00+03	66800.00
2E0BCC	2017-06-27 08:47:00+03	56000.00
2E0BD2	2017-08-14 09:28:00+03	13400.00
2E0BDE	2017-08-01 21:34:00+03	20000.00
2E0BE1	2017-07-11 09:45:00+03	83600.00
2E0C1C	2017-07-30 16:17:00+03	99300.00
2E0C32	2017-07-09 22:32:00+03	220900.00
2E0C67	2017-07-22 02:22:00+03	13300.00
2E0C71	2017-07-16 01:01:00+03	46000.00
2E0CB2	2017-08-01 21:09:00+03	108700.00
2E0D05	2017-07-10 09:05:00+03	75100.00
2E0DA8	2017-07-02 23:48:00+03	54000.00
2E0DCB	2017-08-09 05:22:00+03	321100.00
2E0E2C	2017-07-05 07:51:00+03	75300.00
2E0F69	2017-07-10 04:41:00+03	25800.00
2E0FBC	2017-07-28 02:35:00+03	66600.00
2E0FC1	2017-08-11 08:45:00+03	70800.00
2E1008	2017-07-15 22:24:00+03	83000.00
2E106B	2017-07-23 07:13:00+03	66000.00
2E1137	2017-07-27 22:01:00+03	47000.00
2E119B	2017-07-01 12:04:00+03	26400.00
2E11AB	2017-07-28 02:52:00+03	230000.00
2E11D0	2017-07-03 15:40:00+03	20200.00
2E11E5	2017-08-01 17:34:00+03	6000.00
2E1238	2017-07-15 06:31:00+03	46400.00
2E124B	2017-07-17 23:42:00+03	26800.00
2E12ED	2017-08-06 14:48:00+03	59800.00
2E12F0	2017-08-05 00:28:00+03	128800.00
2E136F	2017-07-18 23:02:00+03	58600.00
2E13A0	2017-07-06 11:13:00+03	136000.00
2E1426	2017-08-15 11:37:00+03	28800.00
2E1453	2017-07-07 05:57:00+03	39500.00
2E145B	2017-08-11 17:08:00+03	6700.00
2E149B	2017-08-10 01:13:00+03	29600.00
2E149C	2017-07-15 00:30:00+03	53100.00
2E14A7	2017-07-23 03:56:00+03	24800.00
2E1516	2017-07-08 21:37:00+03	21800.00
2E1538	2017-07-24 04:54:00+03	132800.00
2E1601	2017-07-08 12:05:00+03	62600.00
2E166E	2017-08-09 12:07:00+03	56900.00
2E1680	2017-07-26 21:14:00+03	28200.00
2E16BA	2017-08-14 21:29:00+03	246000.00
2E16D7	2017-08-14 22:13:00+03	88100.00
2E172B	2017-08-10 06:16:00+03	12600.00
2E175C	2017-08-10 16:51:00+03	53600.00
2E177B	2017-07-16 07:21:00+03	14700.00
2E194D	2017-07-19 15:18:00+03	37800.00
2E1963	2017-08-07 10:24:00+03	52900.00
2E196C	2017-07-24 02:21:00+03	25600.00
2E1984	2017-07-26 05:48:00+03	54800.00
2E1986	2017-07-21 00:41:00+03	109600.00
2E198C	2017-08-12 07:11:00+03	25800.00
2E19CF	2017-06-28 20:50:00+03	55500.00
2E1A24	2017-08-12 12:40:00+03	55500.00
2E1A7D	2017-07-28 07:27:00+03	20600.00
2E1ABD	2017-07-17 06:01:00+03	72400.00
2E1ADF	2017-07-26 06:23:00+03	59600.00
2E1AE2	2017-07-20 18:00:00+03	6000.00
2E1B44	2017-08-11 11:18:00+03	48900.00
2E1B68	2017-07-29 21:45:00+03	40000.00
2E1B7D	2017-07-16 11:07:00+03	28000.00
2E1BFD	2017-08-08 02:31:00+03	63600.00
2E1CE2	2017-07-26 12:38:00+03	47000.00
2E1D5D	2017-07-10 11:40:00+03	88900.00
2E1D65	2017-07-05 23:26:00+03	46400.00
2E1DE4	2017-07-12 23:41:00+03	65800.00
2E1E34	2017-07-10 15:46:00+03	38400.00
2E1EA4	2017-07-10 14:22:00+03	92000.00
2E1EA5	2017-07-07 04:45:00+03	50600.00
2E1EE0	2017-07-14 04:18:00+03	46800.00
2E1F30	2017-07-03 01:26:00+03	36200.00
2E1FC2	2017-07-06 07:46:00+03	21600.00
2E2010	2017-07-31 03:47:00+03	96200.00
2E2031	2017-08-14 16:42:00+03	66600.00
2E2046	2017-07-03 09:00:00+03	26000.00
2E2056	2017-07-09 15:15:00+03	25800.00
2E208B	2017-08-13 02:35:00+03	14800.00
2E20C0	2017-07-19 07:18:00+03	109000.00
2E2106	2017-08-09 20:26:00+03	83000.00
2E2146	2017-07-24 10:17:00+03	142400.00
2E2184	2017-07-18 15:34:00+03	246000.00
2E221A	2017-07-18 02:34:00+03	13400.00
2E2239	2017-07-14 09:53:00+03	42800.00
2E2283	2017-07-11 16:45:00+03	49900.00
2E22E3	2017-07-26 13:03:00+03	77200.00
2E22F9	2017-07-02 08:38:00+03	63200.00
2E2312	2017-07-19 06:28:00+03	86600.00
2E2313	2017-07-25 23:56:00+03	26800.00
2E231A	2017-07-31 23:26:00+03	99100.00
2E23D4	2017-07-21 19:04:00+03	16400.00
2E250F	2017-07-28 20:58:00+03	46400.00
2E257E	2017-07-30 17:12:00+03	15400.00
2E259E	2017-07-16 04:39:00+03	34000.00
2E2643	2017-07-12 12:27:00+03	96800.00
2E2687	2017-07-13 10:16:00+03	85600.00
2E2692	2017-08-13 15:49:00+03	47000.00
2E26E3	2017-08-09 04:34:00+03	21600.00
2E26FF	2017-08-13 08:43:00+03	53300.00
2E2710	2017-08-04 00:48:00+03	303100.00
2E2720	2017-07-10 10:46:00+03	23200.00
2E2726	2017-07-24 15:36:00+03	189200.00
2E273C	2017-07-10 06:28:00+03	53600.00
2E2756	2017-07-09 13:41:00+03	29600.00
2E275D	2017-07-10 11:50:00+03	32700.00
2E277F	2017-07-25 11:00:00+03	25600.00
2E27A7	2017-08-15 15:36:00+03	70300.00
2E27B2	2017-07-22 09:22:00+03	85000.00
2E280A	2017-08-02 04:25:00+03	56700.00
2E2813	2017-07-19 21:52:00+03	328500.00
2E2821	2017-07-06 04:31:00+03	272400.00
2E286B	2017-08-09 14:44:00+03	78100.00
2E2967	2017-07-18 12:51:00+03	16000.00
2E29A0	2017-07-18 15:05:00+03	18000.00
2E29DC	2017-07-07 09:31:00+03	32700.00
2E29F3	2017-07-26 17:42:00+03	27200.00
2E29F7	2017-07-13 23:09:00+03	84400.00
2E2A5E	2017-07-14 06:28:00+03	167900.00
2E2A6E	2017-07-16 02:34:00+03	50600.00
2E2AA8	2017-08-04 14:30:00+03	112000.00
2E2AAC	2017-07-17 01:03:00+03	113700.00
2E2AE7	2017-08-04 11:33:00+03	56600.00
2E2B81	2017-08-07 04:33:00+03	7800.00
2E2B93	2017-08-06 04:29:00+03	91000.00
2E2BF4	2017-07-07 07:32:00+03	98300.00
2E2C05	2017-08-12 18:32:00+03	46000.00
2E2C77	2017-08-12 17:42:00+03	14400.00
2E2C7A	2017-08-01 19:18:00+03	23600.00
2E2CF2	2017-07-08 07:16:00+03	82100.00
2E2D6B	2017-07-07 03:56:00+03	24400.00
2E2DD1	2017-07-23 09:40:00+03	40300.00
2E2DF2	2017-08-05 11:55:00+03	50000.00
2E2E49	2017-07-30 13:58:00+03	27800.00
2E2EC4	2017-07-12 06:47:00+03	28000.00
2E2ED0	2017-08-07 07:16:00+03	13400.00
2E2FDA	2017-08-14 00:37:00+03	15100.00
2E302C	2017-08-07 17:33:00+03	20200.00
2E3055	2017-07-08 03:29:00+03	73500.00
2E30B8	2017-08-02 04:25:00+03	75300.00
2E310A	2017-07-17 11:20:00+03	84000.00
2E3138	2017-07-29 11:27:00+03	123000.00
2E3177	2017-08-13 08:10:00+03	115700.00
2E3194	2017-07-12 18:10:00+03	71900.00
2E31B2	2017-07-14 08:29:00+03	45200.00
2E31B6	2017-07-31 10:17:00+03	111900.00
2E31C6	2017-07-09 13:11:00+03	6600.00
2E3206	2017-08-05 13:36:00+03	82200.00
2E3250	2017-08-10 08:16:00+03	14000.00
2E3254	2017-08-07 17:57:00+03	206800.00
2E3289	2017-07-16 12:14:00+03	184200.00
2E3297	2017-07-29 23:41:00+03	160400.00
2E32A3	2017-07-31 01:39:00+03	45200.00
2E32AB	2017-07-07 04:01:00+03	71800.00
2E32F4	2017-07-06 17:55:00+03	22000.00
2E3324	2017-07-05 18:52:00+03	273800.00
2E33AC	2017-07-06 19:20:00+03	22000.00
2E3416	2017-07-25 08:29:00+03	87700.00
2E3423	2017-08-01 04:44:00+03	46400.00
2E34AB	2017-08-12 04:39:00+03	14800.00
2E356C	2017-08-15 04:57:00+03	143300.00
2E3574	2017-07-08 01:20:00+03	8400.00
2E357D	2017-06-29 12:42:00+03	58400.00
2E359A	2017-07-25 09:58:00+03	26000.00
2E35AC	2017-07-23 13:13:00+03	6900.00
2E35DC	2017-07-27 07:09:00+03	48300.00
2E3629	2017-07-31 00:21:00+03	89700.00
2E36AB	2017-08-06 07:39:00+03	7300.00
2E36C1	2017-08-06 23:33:00+03	58000.00
2E376E	2017-07-31 09:41:00+03	44000.00
2E3783	2017-07-29 00:55:00+03	9200.00
2E37B0	2017-07-15 04:52:00+03	47100.00
2E37D2	2017-08-15 13:51:00+03	6700.00
2E3815	2017-08-11 23:31:00+03	48800.00
2E38DA	2017-07-05 07:48:00+03	40900.00
2E3971	2017-07-10 20:24:00+03	15800.00
2E39D9	2017-07-24 19:04:00+03	164800.00
2E3A0E	2017-07-11 05:49:00+03	28300.00
2E3B5A	2017-07-18 00:41:00+03	75100.00
2E3B87	2017-07-01 20:42:00+03	71900.00
2E3BAC	2017-08-13 15:32:00+03	34400.00
2E3C00	2017-07-18 19:34:00+03	9800.00
2E3C1B	2017-07-29 11:40:00+03	38400.00
2E3C2F	2017-08-04 11:56:00+03	24600.00
2E3C34	2017-07-10 22:19:00+03	365400.00
2E3CCC	2017-07-30 04:10:00+03	30700.00
2E3D33	2017-07-04 18:38:00+03	109600.00
2E3D6A	2017-08-14 01:10:00+03	28800.00
2E3D72	2017-07-16 05:29:00+03	242700.00
2E3D82	2017-07-16 01:48:00+03	79600.00
2E3D9A	2017-06-28 18:59:00+03	24300.00
2E3DDD	2017-08-06 19:53:00+03	195800.00
2E3E4A	2017-06-29 22:11:00+03	125000.00
2E3F41	2017-08-07 04:51:00+03	123000.00
2E3F82	2017-07-06 08:37:00+03	67400.00
2E40B7	2017-07-13 05:17:00+03	124200.00
2E4114	2017-07-24 20:29:00+03	189200.00
2E4158	2017-07-06 06:50:00+03	135600.00
2E41FA	2017-07-01 03:59:00+03	13400.00
2E4235	2017-08-14 10:06:00+03	184300.00
2E426B	2017-07-04 07:42:00+03	53000.00
2E42B4	2017-07-02 09:19:00+03	133200.00
2E42E3	2017-08-09 09:35:00+03	6000.00
2E4330	2017-07-17 13:10:00+03	34000.00
2E4335	2017-08-09 00:57:00+03	55800.00
2E43A0	2017-07-23 15:07:00+03	55800.00
2E43DF	2017-08-02 20:57:00+03	12600.00
2E43FB	2017-08-10 16:15:00+03	83000.00
2E444B	2017-07-22 06:54:00+03	14000.00
2E4515	2017-07-24 02:17:00+03	44200.00
2E451F	2017-07-12 14:18:00+03	84500.00
2E4555	2017-07-30 08:19:00+03	101500.00
2E4562	2017-08-04 08:54:00+03	57600.00
2E4629	2017-08-08 22:08:00+03	15700.00
2E4728	2017-07-05 12:13:00+03	48900.00
2E4750	2017-07-18 10:03:00+03	92000.00
2E47BE	2017-07-23 07:20:00+03	44000.00
2E47C5	2017-07-07 19:03:00+03	397500.00
2E47EE	2017-06-30 09:14:00+03	9300.00
2E4800	2017-08-07 03:31:00+03	38400.00
2E4972	2017-07-21 03:33:00+03	28800.00
2E49D8	2017-07-25 20:33:00+03	56600.00
2E4A5D	2017-07-13 11:10:00+03	22100.00
2E4A6D	2017-07-28 21:00:00+03	412300.00
2E4AB3	2017-07-11 10:03:00+03	14800.00
2E4AD6	2017-07-06 16:46:00+03	72800.00
2E4AEB	2017-07-28 05:55:00+03	68100.00
2E4B97	2017-08-02 22:27:00+03	270700.00
2E4BAF	2017-08-02 21:06:00+03	8200.00
2E4BE6	2017-07-15 14:26:00+03	170200.00
2E4C00	2017-08-04 22:39:00+03	92600.00
2E4C4B	2017-08-11 21:07:00+03	46400.00
2E4C8E	2017-07-10 09:18:00+03	68800.00
2E4D4A	2017-08-09 03:26:00+03	81600.00
2E4E2E	2017-08-06 01:13:00+03	46800.00
2E4E45	2017-08-07 04:50:00+03	30200.00
2E4E55	2017-07-22 03:56:00+03	48800.00
2E4E8E	2017-08-14 07:14:00+03	37600.00
2E4F3D	2017-07-12 16:40:00+03	56600.00
2E4F4A	2017-07-20 00:40:00+03	396400.00
2E4F82	2017-07-06 04:02:00+03	99200.00
2E4F97	2017-07-10 00:02:00+03	111600.00
2E4FC1	2017-07-25 12:00:00+03	49200.00
2E4FCE	2017-07-09 05:36:00+03	46400.00
2E5016	2017-07-26 04:08:00+03	22000.00
2E5018	2017-07-08 21:13:00+03	93900.00
2E5030	2017-07-07 08:00:00+03	118500.00
2E5037	2017-08-13 08:40:00+03	47100.00
2E5083	2017-07-10 12:25:00+03	36200.00
2E50A3	2017-07-19 12:35:00+03	148200.00
2E5101	2017-07-24 20:52:00+03	66400.00
2E513C	2017-07-22 13:45:00+03	24400.00
2E5143	2017-07-13 14:36:00+03	56600.00
2E5187	2017-07-23 17:08:00+03	56900.00
2E5193	2017-08-12 20:47:00+03	51800.00
2E51F1	2017-07-28 00:07:00+03	40000.00
2E5229	2017-08-09 14:48:00+03	193700.00
2E5258	2017-06-27 21:07:00+03	23600.00
2E5265	2017-07-27 03:18:00+03	28300.00
2E52AB	2017-07-13 13:36:00+03	67600.00
2E52C9	2017-07-31 16:20:00+03	39800.00
2E52F1	2017-07-30 15:02:00+03	13600.00
2E52FD	2017-07-10 03:18:00+03	117000.00
2E532A	2017-07-10 21:39:00+03	39200.00
2E532C	2017-07-01 16:44:00+03	47000.00
2E5370	2017-07-11 01:14:00+03	40800.00
2E5373	2017-08-09 18:05:00+03	119500.00
2E53B0	2017-06-30 18:22:00+03	28000.00
2E5402	2017-08-08 11:50:00+03	332200.00
2E5407	2017-08-11 04:20:00+03	49100.00
2E5415	2017-08-05 03:05:00+03	44800.00
2E5499	2017-06-28 22:25:00+03	19000.00
2E54B6	2017-06-30 18:17:00+03	28000.00
2E54B7	2017-08-02 11:08:00+03	14800.00
2E54C0	2017-07-29 02:43:00+03	21800.00
2E54DC	2017-07-29 22:02:00+03	12600.00
2E5521	2017-07-16 00:09:00+03	52000.00
2E552A	2017-07-01 04:40:00+03	16400.00
2E552D	2017-07-28 06:34:00+03	29600.00
2E5552	2017-06-25 02:37:00+03	66600.00
2E559E	2017-07-04 06:33:00+03	72600.00
2E55EE	2017-07-03 15:06:00+03	87000.00
2E55FA	2017-07-06 02:36:00+03	28000.00
2E5636	2017-07-09 01:58:00+03	25800.00
2E56A4	2017-07-10 04:16:00+03	130100.00
2E56C2	2017-07-28 14:31:00+03	47200.00
2E575E	2017-08-11 03:05:00+03	12600.00
2E5774	2017-07-14 17:02:00+03	248300.00
2E57A1	2017-08-04 02:45:00+03	12400.00
2E57A8	2017-08-12 03:05:00+03	56000.00
2E57D0	2017-07-22 23:17:00+03	28000.00
2E581D	2017-07-27 23:48:00+03	113700.00
2E585F	2017-07-16 05:10:00+03	120100.00
2E5873	2017-08-02 11:03:00+03	227200.00
2E58CC	2017-08-15 15:15:00+03	62000.00
2E591B	2017-07-16 00:14:00+03	273600.00
2E5934	2017-07-26 17:34:00+03	31600.00
2E5965	2017-08-12 18:06:00+03	138600.00
2E5991	2017-08-05 16:19:00+03	81800.00
2E59C9	2017-07-25 20:12:00+03	252200.00
2E59D8	2017-07-05 05:39:00+03	107900.00
2E5A05	2017-08-06 18:00:00+03	168000.00
2E5A2F	2017-07-28 11:56:00+03	47400.00
2E5A38	2017-07-27 20:08:00+03	138100.00
2E5A57	2017-07-24 14:38:00+03	27900.00
2E5ACB	2017-07-06 07:12:00+03	57600.00
2E5AD2	2017-07-27 22:38:00+03	86500.00
2E5B0E	2017-07-23 10:54:00+03	113300.00
2E5B73	2017-07-17 08:29:00+03	62100.00
2E5BC0	2017-07-31 06:09:00+03	53400.00
2E5BCF	2017-07-30 17:29:00+03	24600.00
2E5C5F	2017-08-15 14:00:00+03	131100.00
2E5CA0	2017-07-07 10:13:00+03	139400.00
2E5D36	2017-07-04 05:57:00+03	6600.00
2E5D56	2017-08-04 20:38:00+03	133100.00
2E5D62	2017-08-12 03:03:00+03	28000.00
2E5D7B	2017-08-10 13:53:00+03	125400.00
2E5DE1	2017-08-08 18:05:00+03	91500.00
2E5F69	2017-07-30 17:31:00+03	53600.00
2E5F8C	2017-08-06 21:59:00+03	75600.00
2E5FE5	2017-07-10 05:49:00+03	16000.00
2E5FF6	2017-08-06 17:25:00+03	56000.00
2E612D	2017-08-09 14:00:00+03	55800.00
2E6153	2017-07-31 23:42:00+03	6800.00
2E615B	2017-08-07 00:19:00+03	48500.00
2E618D	2017-08-11 20:56:00+03	28000.00
2E6191	2017-07-21 09:39:00+03	73400.00
2E61D3	2017-08-01 04:54:00+03	56600.00
2E61DC	2017-08-04 14:45:00+03	135400.00
2E62E9	2017-07-05 18:25:00+03	28000.00
2E634D	2017-07-08 14:15:00+03	32800.00
2E635C	2017-07-09 15:37:00+03	48800.00
2E635E	2017-07-16 07:26:00+03	41200.00
2E63CF	2017-07-22 21:18:00+03	48800.00
2E64B8	2017-08-10 19:58:00+03	34000.00
2E656F	2017-07-03 15:46:00+03	173600.00
2E6591	2017-08-11 18:37:00+03	96800.00
2E6690	2017-07-21 23:39:00+03	41300.00
2E66D3	2017-07-30 21:13:00+03	27800.00
2E6763	2017-08-13 00:26:00+03	66600.00
2E67B0	2017-08-09 15:02:00+03	136000.00
2E6831	2017-08-09 22:44:00+03	35200.00
2E686B	2017-07-04 20:08:00+03	234800.00
2E68DD	2017-07-16 17:54:00+03	28000.00
2E6910	2017-07-29 09:43:00+03	40000.00
2E6929	2017-08-15 03:59:00+03	66400.00
2E699A	2017-07-31 16:42:00+03	29600.00
2E6A21	2017-08-07 03:13:00+03	147600.00
2E6A2B	2017-08-08 04:00:00+03	119800.00
2E6A9D	2017-08-03 22:51:00+03	59300.00
2E6B96	2017-07-12 13:31:00+03	81600.00
2E6BDF	2017-07-23 02:46:00+03	114800.00
2E6BE8	2017-07-10 03:24:00+03	131900.00
2E6C08	2017-08-15 10:26:00+03	75000.00
2E6C17	2017-08-06 15:08:00+03	56900.00
2E6C4E	2017-08-01 22:24:00+03	59200.00
2E6C65	2017-08-08 11:33:00+03	21400.00
2E6CAF	2017-08-09 10:50:00+03	85000.00
2E6CC5	2017-08-01 07:56:00+03	48700.00
2E6CD4	2017-07-16 03:28:00+03	22000.00
2E6D7E	2017-07-23 10:27:00+03	61500.00
2E6D89	2017-07-02 01:41:00+03	57800.00
2E6DBD	2017-07-21 06:25:00+03	6300.00
2E6E32	2017-07-13 11:02:00+03	23400.00
2E6E39	2017-08-09 03:12:00+03	133200.00
2E6EE4	2017-07-17 07:25:00+03	34200.00
2E6F2D	2017-07-14 03:13:00+03	67100.00
2E6FAA	2017-07-11 17:07:00+03	131100.00
2E707A	2017-07-11 00:20:00+03	27400.00
2E7081	2017-08-08 04:50:00+03	193600.00
2E709E	2017-08-06 18:28:00+03	65900.00
2E70C7	2017-07-29 12:09:00+03	56100.00
2E70D2	2017-07-30 09:36:00+03	70500.00
2E713D	2017-06-30 17:44:00+03	90400.00
2E714D	2017-08-07 18:00:00+03	34000.00
2E7172	2017-08-14 04:43:00+03	70800.00
2E7179	2017-08-13 19:02:00+03	45200.00
2E717D	2017-07-17 19:33:00+03	28800.00
2E71F4	2017-07-27 03:22:00+03	30200.00
2E722D	2017-08-09 08:23:00+03	54800.00
2E7270	2017-08-12 12:05:00+03	129700.00
2E7370	2017-08-11 18:27:00+03	98200.00
2E73A8	2017-08-13 19:30:00+03	39800.00
2E73B5	2017-07-19 04:33:00+03	38400.00
2E73F5	2017-07-16 22:20:00+03	144400.00
2E747D	2017-08-11 16:08:00+03	22000.00
2E74A1	2017-07-22 07:20:00+03	28800.00
2E75A6	2017-07-17 10:06:00+03	31600.00
2E75B4	2017-07-17 16:58:00+03	112000.00
2E75CC	2017-07-16 10:32:00+03	28000.00
2E75DE	2017-07-05 12:42:00+03	167400.00
2E75F5	2017-07-23 03:03:00+03	64700.00
2E7667	2017-07-17 09:45:00+03	58900.00
2E7679	2017-08-04 19:56:00+03	55700.00
2E771E	2017-07-04 02:15:00+03	26800.00
2E7731	2017-07-25 00:08:00+03	248400.00
2E7752	2017-07-17 01:58:00+03	26000.00
2E7755	2017-08-09 18:28:00+03	89600.00
2E77DE	2017-07-06 15:03:00+03	40000.00
2E781D	2017-07-08 19:47:00+03	72800.00
2E786E	2017-08-06 05:59:00+03	257500.00
2E78C6	2017-07-07 01:14:00+03	133200.00
2E7922	2017-08-07 00:56:00+03	13400.00
2E795A	2017-07-18 09:06:00+03	56900.00
2E7985	2017-07-18 04:59:00+03	59800.00
2E7A52	2017-08-01 23:18:00+03	27200.00
2E7A6D	2017-07-26 10:17:00+03	25900.00
2E7A7D	2017-07-22 21:55:00+03	114300.00
2E7B0C	2017-07-14 04:24:00+03	70400.00
2E7B0D	2017-07-12 11:46:00+03	49600.00
2E7B1C	2017-07-04 17:37:00+03	38400.00
2E7B85	2017-08-10 05:05:00+03	48500.00
2E7B89	2017-07-11 10:48:00+03	117500.00
2E7C0A	2017-07-16 17:50:00+03	86800.00
2E7C1B	2017-07-28 06:56:00+03	27200.00
2E7C25	2017-07-04 14:15:00+03	40000.00
2E7C36	2017-08-09 22:40:00+03	43200.00
2E7CD9	2017-08-02 10:57:00+03	58400.00
2E7D7D	2017-08-05 09:42:00+03	28000.00
2E7D88	2017-07-08 09:24:00+03	58400.00
2E7D8D	2017-07-31 23:19:00+03	15000.00
2E7DF8	2017-07-29 09:10:00+03	13600.00
2E7E16	2017-07-13 21:20:00+03	46200.00
2E7E18	2017-07-21 04:43:00+03	84100.00
2E7E2E	2017-07-28 12:42:00+03	23200.00
2E7E60	2017-08-07 00:35:00+03	265200.00
2E7E90	2017-07-27 03:02:00+03	59800.00
2E7EDE	2017-08-12 23:41:00+03	71200.00
2E7F06	2017-07-09 13:03:00+03	53600.00
2E7F14	2017-08-08 15:00:00+03	382500.00
2E7FA9	2017-07-03 03:57:00+03	67700.00
2E7FDF	2017-07-14 03:33:00+03	23200.00
2E8003	2017-07-28 22:16:00+03	75600.00
2E801E	2017-07-25 11:30:00+03	106900.00
2E803A	2017-06-29 04:34:00+03	14000.00
2E808F	2017-08-04 11:45:00+03	16400.00
2E811A	2017-07-19 16:15:00+03	112600.00
2E8137	2017-07-27 06:09:00+03	291600.00
2E8190	2017-08-14 07:36:00+03	55800.00
2E819F	2017-06-30 10:10:00+03	101100.00
2E81B6	2017-07-17 19:46:00+03	84000.00
2E8266	2017-08-05 22:09:00+03	174800.00
2E8351	2017-07-14 00:04:00+03	66600.00
2E8352	2017-07-26 16:06:00+03	57600.00
2E835C	2017-07-15 13:18:00+03	120700.00
2E8367	2017-08-09 19:33:00+03	6000.00
2E8374	2017-08-07 13:33:00+03	162400.00
2E839A	2017-07-10 05:15:00+03	32500.00
2E83A0	2017-08-01 02:54:00+03	153600.00
2E83A5	2017-07-12 08:04:00+03	6000.00
2E83BD	2017-08-09 02:49:00+03	19600.00
2E83C8	2017-07-16 00:00:00+03	40800.00
2E841B	2017-07-06 05:32:00+03	66600.00
2E8474	2017-07-06 02:33:00+03	26700.00
2E84CD	2017-08-02 08:54:00+03	6700.00
2E84E3	2017-07-29 06:50:00+03	77400.00
2E857F	2017-07-20 20:58:00+03	14400.00
2E859A	2017-08-11 19:45:00+03	6600.00
2E85B4	2017-07-30 06:44:00+03	42700.00
2E85DB	2017-08-08 03:26:00+03	46400.00
2E8643	2017-07-06 02:47:00+03	111600.00
2E864D	2017-07-29 03:20:00+03	9800.00
2E8655	2017-07-24 11:37:00+03	20400.00
2E872F	2017-07-28 12:04:00+03	26200.00
2E8759	2017-07-15 14:53:00+03	34000.00
2E8825	2017-07-15 09:08:00+03	23200.00
2E88EC	2017-07-09 12:33:00+03	21400.00
2E8913	2017-07-04 04:10:00+03	47800.00
2E8931	2017-07-14 07:06:00+03	133200.00
2E8941	2017-08-01 16:12:00+03	23200.00
2E8983	2017-08-07 09:18:00+03	49300.00
2E8A18	2017-07-26 12:45:00+03	9800.00
2E8AA8	2017-07-09 11:11:00+03	146300.00
2E8AFB	2017-07-20 19:59:00+03	133200.00
2E8B37	2017-08-12 21:50:00+03	246000.00
2E8B4E	2017-07-26 23:40:00+03	118000.00
2E8B6C	2017-07-18 20:09:00+03	50700.00
2E8B9E	2017-08-02 15:16:00+03	100700.00
2E8BB4	2017-08-12 01:47:00+03	41200.00
2E8BB5	2017-07-03 09:04:00+03	70600.00
2E8C12	2017-08-14 07:05:00+03	40600.00
2E8C7F	2017-07-31 15:56:00+03	57600.00
2E8C9C	2017-08-14 17:23:00+03	21600.00
2E8CC5	2017-07-04 23:59:00+03	11700.00
2E8CC8	2017-07-17 06:52:00+03	28800.00
2E8CDF	2017-07-31 00:18:00+03	44500.00
2E8CE1	2017-07-29 15:28:00+03	180000.00
2E8CF3	2017-08-09 13:51:00+03	32800.00
2E8CF7	2017-07-20 21:02:00+03	131100.00
2E8CFD	2017-06-26 02:02:00+03	55800.00
2E8D2F	2017-08-03 05:55:00+03	24800.00
2E8D33	2017-08-05 18:13:00+03	40800.00
2E8D74	2017-07-26 19:39:00+03	23200.00
2E8D8B	2017-08-14 03:02:00+03	58700.00
2E8D8C	2017-07-25 06:55:00+03	403300.00
2E8DA8	2017-08-09 01:00:00+03	44000.00
2E8DEA	2017-07-02 04:57:00+03	69000.00
2E8E88	2017-07-06 08:58:00+03	15100.00
2E8EA0	2017-07-20 05:01:00+03	52700.00
2E8FFC	2017-07-26 12:06:00+03	56000.00
2E904B	2017-08-02 20:16:00+03	123000.00
2E9061	2017-08-15 14:36:00+03	95800.00
2E90C4	2017-08-11 16:33:00+03	38400.00
2E90DF	2017-07-31 07:48:00+03	24400.00
2E914B	2017-07-13 06:29:00+03	106400.00
2E9179	2017-06-30 17:35:00+03	46300.00
2E919F	2017-08-09 14:37:00+03	62000.00
2E91AB	2017-07-21 22:36:00+03	18600.00
2E91D0	2017-07-08 11:25:00+03	199200.00
2E91DA	2017-07-23 21:33:00+03	36100.00
2E91DD	2017-07-02 10:31:00+03	28800.00
2E91E6	2017-08-10 04:18:00+03	6000.00
2E91EB	2017-07-19 15:50:00+03	355200.00
2E92C6	2017-08-14 09:05:00+03	72200.00
2E9338	2017-07-10 06:54:00+03	260900.00
2E93C5	2017-07-03 19:19:00+03	16400.00
2E942A	2017-07-10 10:13:00+03	40000.00
2E944C	2017-08-12 19:41:00+03	123900.00
2E9459	2017-07-18 00:06:00+03	33300.00
2E948A	2017-07-23 13:30:00+03	29600.00
2E94E1	2017-07-08 02:46:00+03	124200.00
2E94FC	2017-08-05 03:50:00+03	24800.00
2E957F	2017-07-31 05:37:00+03	278600.00
2E95CE	2017-08-06 20:35:00+03	137100.00
2E963B	2017-06-29 17:57:00+03	40000.00
2E963E	2017-08-07 21:38:00+03	49800.00
2E964A	2017-07-09 08:19:00+03	342400.00
2E96AE	2017-07-14 20:26:00+03	26000.00
2E9728	2017-07-09 12:19:00+03	54500.00
2E9776	2017-08-08 13:43:00+03	53400.00
2E97AD	2017-07-22 10:47:00+03	64400.00
2E9815	2017-08-15 07:59:00+03	74400.00
2E9833	2017-07-02 05:04:00+03	43200.00
2E984C	2017-08-12 02:56:00+03	62100.00
2E98FE	2017-07-11 06:17:00+03	112200.00
2E9911	2017-07-22 15:10:00+03	122300.00
2E992A	2017-07-15 02:29:00+03	49800.00
2E9946	2017-07-27 17:03:00+03	50600.00
2E9A52	2017-07-04 12:49:00+03	31400.00
2E9A80	2017-08-15 15:48:00+03	13400.00
2E9AB2	2017-08-15 04:45:00+03	37200.00
2E9AB8	2017-08-11 15:31:00+03	99000.00
2E9AC8	2017-08-01 05:57:00+03	23200.00
2E9B3A	2017-08-10 19:41:00+03	16400.00
2E9B58	2017-07-05 20:54:00+03	105600.00
2E9B75	2017-07-06 07:07:00+03	85700.00
2E9BCD	2017-07-15 19:54:00+03	7400.00
2E9BFD	2017-08-01 14:18:00+03	31600.00
2E9BFF	2017-08-14 02:14:00+03	68800.00
2E9C41	2017-08-06 16:51:00+03	32400.00
2E9C80	2017-07-30 06:43:00+03	167700.00
2E9D59	2017-06-30 13:23:00+03	78500.00
2E9DAF	2017-07-16 10:08:00+03	17200.00
2E9DCA	2017-08-14 23:09:00+03	145300.00
2E9DEF	2017-07-14 10:57:00+03	8400.00
2E9E7D	2017-07-18 10:57:00+03	116900.00
2E9E83	2017-07-15 16:42:00+03	56000.00
2E9EC2	2017-08-10 09:52:00+03	16800.00
2E9F3B	2017-07-04 17:57:00+03	72400.00
2E9F6C	2017-06-30 12:06:00+03	32800.00
2E9F7A	2017-07-28 08:32:00+03	57500.00
2EA007	2017-08-02 00:28:00+03	138000.00
2EA07E	2017-08-05 18:45:00+03	29600.00
2EA0A4	2017-07-20 00:01:00+03	302700.00
2EA0BD	2017-06-29 08:03:00+03	102800.00
2EA15B	2017-08-12 13:50:00+03	134800.00
2EA174	2017-07-06 12:53:00+03	6000.00
2EA1E2	2017-07-07 00:31:00+03	12400.00
2EA1E8	2017-07-16 15:00:00+03	89600.00
2EA20C	2017-07-11 18:15:00+03	63500.00
2EA24D	2017-07-17 12:18:00+03	75000.00
2EA264	2017-08-04 16:54:00+03	50300.00
2EA273	2017-08-11 07:28:00+03	11600.00
2EA2E9	2017-07-01 23:46:00+03	12600.00
2EA316	2017-07-03 21:35:00+03	246000.00
2EA35E	2017-07-17 23:08:00+03	46400.00
2EA399	2017-07-06 01:08:00+03	53800.00
2EA3D3	2017-08-10 12:22:00+03	182300.00
2EA3F8	2017-08-09 05:00:00+03	11600.00
2EA442	2017-07-10 10:56:00+03	28000.00
2EA44D	2017-08-09 23:12:00+03	82000.00
2EA460	2017-07-10 03:44:00+03	31400.00
2EA488	2017-07-04 01:15:00+03	44000.00
2EA4A2	2017-07-25 12:36:00+03	56100.00
2EA4E8	2017-07-19 23:27:00+03	16400.00
2EA51E	2017-07-17 04:36:00+03	89700.00
2EA545	2017-07-16 22:54:00+03	75600.00
2EA5B1	2017-08-12 03:34:00+03	60400.00
2EA5C0	2017-08-01 05:12:00+03	10700.00
2EA634	2017-07-19 16:49:00+03	121400.00
2EA685	2017-08-07 01:51:00+03	46400.00
2EA763	2017-07-30 01:28:00+03	64100.00
2EA770	2017-07-26 08:27:00+03	47100.00
2EA7CD	2017-07-26 07:45:00+03	55800.00
2EA803	2017-07-13 02:39:00+03	57500.00
2EA86E	2017-07-15 17:24:00+03	50600.00
2EA87C	2017-07-31 16:01:00+03	132800.00
2EA8C9	2017-07-09 07:00:00+03	28000.00
2EA8F2	2017-07-17 16:35:00+03	36200.00
2EA935	2017-07-12 16:44:00+03	23400.00
2EA9B0	2017-07-05 00:55:00+03	123700.00
2EA9D6	2017-08-06 21:49:00+03	32200.00
2EA9DB	2017-07-21 17:07:00+03	78100.00
2EA9E6	2017-07-19 22:20:00+03	21800.00
2EA9FE	2017-07-07 08:56:00+03	45200.00
2EAA0B	2017-08-13 07:04:00+03	42600.00
2EAA2A	2017-08-15 11:46:00+03	196100.00
2EAA35	2017-07-09 14:13:00+03	29600.00
2EAA3A	2017-07-20 01:41:00+03	136800.00
2EAA3B	2017-07-03 21:20:00+03	26000.00
2EAA48	2017-07-08 10:06:00+03	102100.00
2EAA51	2017-08-15 04:41:00+03	25100.00
2EAA82	2017-07-11 21:35:00+03	19600.00
2EAAD8	2017-07-12 17:25:00+03	278600.00
2EAB27	2017-08-06 02:14:00+03	131100.00
2EAB6E	2017-08-09 19:45:00+03	137000.00
2EAB8B	2017-07-21 20:38:00+03	88200.00
2EAB9A	2017-08-09 13:03:00+03	263900.00
2EAC25	2017-07-23 00:51:00+03	6200.00
2EACC2	2017-08-12 00:56:00+03	293900.00
2EACD9	2017-07-19 03:59:00+03	81600.00
2EAD12	2017-08-13 21:34:00+03	103700.00
2EAD42	2017-08-11 19:16:00+03	135600.00
2EAD56	2017-08-01 19:16:00+03	35300.00
2EAD71	2017-07-05 14:44:00+03	59800.00
2EAD74	2017-07-08 09:34:00+03	127200.00
2EAE28	2017-07-20 19:06:00+03	30200.00
2EAEAF	2017-08-06 19:16:00+03	105000.00
2EAEB1	2017-08-13 13:07:00+03	62000.00
2EAFCC	2017-07-25 21:13:00+03	103800.00
2EB024	2017-08-15 09:09:00+03	26700.00
2EB02E	2017-07-18 14:51:00+03	177400.00
2EB06D	2017-07-13 04:17:00+03	57400.00
2EB320	2017-07-11 13:01:00+03	24400.00
2EB374	2017-07-21 00:59:00+03	137600.00
2EB408	2017-07-05 01:42:00+03	49800.00
2EB4C1	2017-07-23 04:00:00+03	70700.00
2EB4E4	2017-07-29 05:16:00+03	79600.00
2EB5B0	2017-07-29 07:46:00+03	111600.00
2EB636	2017-08-14 02:31:00+03	26200.00
2EB64D	2017-07-19 21:57:00+03	59800.00
2EB65B	2017-07-02 08:00:00+03	143000.00
2EB717	2017-07-19 00:20:00+03	199700.00
2EB7A1	2017-07-10 19:31:00+03	15900.00
2EB7D9	2017-08-08 12:07:00+03	28000.00
2EB7F3	2017-07-23 11:06:00+03	56000.00
2EB828	2017-06-26 21:23:00+03	26000.00
2EB834	2017-07-02 06:41:00+03	136800.00
2EB862	2017-07-29 15:16:00+03	68000.00
2EB87C	2017-07-18 18:41:00+03	26700.00
2EB898	2017-07-10 19:17:00+03	123000.00
2EB921	2017-07-10 20:25:00+03	51200.00
2EB995	2017-06-29 17:30:00+03	15900.00
2EB9CC	2017-08-14 20:54:00+03	59800.00
2EBA1B	2017-07-02 13:15:00+03	106100.00
2EBA1E	2017-07-13 03:23:00+03	268400.00
2EBA40	2017-07-23 05:19:00+03	117700.00
2EBA55	2017-08-15 12:09:00+03	73900.00
2EBAAD	2017-08-04 02:47:00+03	231900.00
2EBB0F	2017-07-08 09:24:00+03	56100.00
2EBC0D	2017-07-12 11:42:00+03	67600.00
2EBC27	2017-07-14 08:56:00+03	52600.00
2EBC30	2017-08-15 01:26:00+03	68800.00
2EBC3D	2017-07-05 12:56:00+03	14700.00
2EBC40	2017-07-27 07:29:00+03	108600.00
2EBC54	2017-08-14 11:35:00+03	29600.00
2EBD03	2017-08-03 05:52:00+03	46300.00
2EBD68	2017-07-13 17:08:00+03	92900.00
2EBD7E	2017-07-28 02:53:00+03	260300.00
2EBDA6	2017-07-19 09:05:00+03	337400.00
2EBDBE	2017-07-19 11:30:00+03	169000.00
2EBDFB	2017-08-01 10:04:00+03	26600.00
2EBE32	2017-08-06 05:27:00+03	38600.00
2EBF03	2017-07-29 18:08:00+03	21400.00
2EBFE8	2017-07-24 01:39:00+03	66600.00
2EBFF8	2017-07-12 18:05:00+03	89700.00
2EC01F	2017-07-02 06:34:00+03	24400.00
2EC040	2017-07-26 03:34:00+03	265600.00
2EC083	2017-07-19 13:49:00+03	18600.00
2EC0AB	2017-07-03 07:02:00+03	100600.00
2EC0C3	2017-07-03 21:50:00+03	6700.00
2EC0C8	2017-07-08 11:21:00+03	46300.00
2EC0E8	2017-07-27 18:27:00+03	92100.00
2EC0FC	2017-08-14 12:55:00+03	68900.00
2EC117	2017-08-03 02:58:00+03	57600.00
2EC136	2017-07-07 18:41:00+03	62800.00
2EC149	2017-08-09 07:42:00+03	57500.00
2EC17A	2017-08-11 19:42:00+03	260900.00
2EC1DD	2017-07-29 14:09:00+03	27600.00
2EC209	2017-08-04 04:03:00+03	202500.00
2EC2C8	2017-07-16 05:51:00+03	254800.00
2EC2F0	2017-07-10 14:21:00+03	100000.00
2EC31B	2017-08-14 10:45:00+03	27000.00
2EC323	2017-07-13 06:07:00+03	25600.00
2EC338	2017-07-05 10:41:00+03	6000.00
2EC364	2017-07-09 11:44:00+03	28800.00
2EC3EF	2017-07-17 14:36:00+03	121400.00
2EC414	2017-07-08 19:53:00+03	89700.00
2EC494	2017-07-03 20:44:00+03	39400.00
2EC4D4	2017-07-24 11:34:00+03	126400.00
2EC50B	2017-07-15 14:55:00+03	28000.00
2EC52E	2017-08-08 05:28:00+03	34000.00
2EC53B	2017-07-10 05:12:00+03	34700.00
2EC541	2017-08-06 02:59:00+03	266400.00
2EC543	2017-07-10 08:17:00+03	413400.00
2EC604	2017-07-20 09:26:00+03	134400.00
2EC60D	2017-07-04 13:04:00+03	28800.00
2EC61C	2017-07-28 10:00:00+03	55800.00
2EC639	2017-08-08 23:15:00+03	113700.00
2EC66A	2017-07-28 23:56:00+03	20600.00
2EC68A	2017-08-05 00:09:00+03	35600.00
2EC6D6	2017-08-11 18:30:00+03	25900.00
2EC6DA	2017-07-12 13:42:00+03	66600.00
2EC6F9	2017-07-04 06:05:00+03	139000.00
2EC769	2017-07-23 07:54:00+03	22000.00
2EC774	2017-07-12 07:15:00+03	60700.00
2EC7F8	2017-07-23 02:22:00+03	34000.00
2EC809	2017-07-05 22:25:00+03	133700.00
2EC851	2017-07-18 10:05:00+03	38400.00
2EC88E	2017-08-08 03:49:00+03	167400.00
2EC8AD	2017-07-29 04:55:00+03	14000.00
2EC8B0	2017-07-25 09:17:00+03	31600.00
2EC8F8	2017-07-31 22:52:00+03	169900.00
2EC930	2017-07-12 07:08:00+03	74400.00
2EC96F	2017-07-14 13:23:00+03	24600.00
2EC987	2017-07-19 11:36:00+03	46400.00
2EC9C2	2017-08-13 09:01:00+03	112000.00
2ECA1F	2017-08-13 02:05:00+03	44800.00
2ECA21	2017-07-14 18:20:00+03	36800.00
2ECA98	2017-07-12 00:03:00+03	91800.00
2ECAE4	2017-08-03 16:41:00+03	79600.00
2ECAFA	2017-07-06 23:13:00+03	270700.00
2ECB0D	2017-08-07 19:44:00+03	28000.00
2ECB2B	2017-07-19 11:56:00+03	136800.00
2ECB74	2017-08-03 18:45:00+03	43600.00
2ECBC9	2017-07-19 09:10:00+03	75300.00
2ECBD4	2017-08-13 19:08:00+03	55800.00
2ECC00	2017-07-12 19:48:00+03	65900.00
2ECC81	2017-08-11 14:33:00+03	47400.00
2ECD48	2017-08-14 00:52:00+03	14800.00
2ECD8D	2017-07-15 09:21:00+03	86600.00
2ECD97	2017-07-26 16:33:00+03	53800.00
2ECE2A	2017-07-07 00:43:00+03	52300.00
2ECE94	2017-07-27 05:08:00+03	272300.00
2ECEE7	2017-07-16 10:33:00+03	21800.00
2ECEED	2017-07-02 05:36:00+03	18800.00
2ECF1D	2017-07-10 19:22:00+03	103300.00
2ECF94	2017-08-10 08:52:00+03	51100.00
2ECFEA	2017-08-15 13:39:00+03	8200.00
2ED01E	2017-07-12 17:39:00+03	89600.00
2ED0A3	2017-07-02 17:42:00+03	81900.00
2ED181	2017-08-15 02:41:00+03	21000.00
2ED198	2017-08-05 00:44:00+03	55800.00
2ED1C1	2017-07-23 12:13:00+03	65900.00
2ED1F3	2017-07-23 11:18:00+03	36200.00
2ED1FB	2017-07-29 04:29:00+03	102600.00
2ED20F	2017-07-27 09:41:00+03	27200.00
2ED230	2017-08-10 12:06:00+03	7400.00
2ED335	2017-07-24 09:58:00+03	240600.00
2ED350	2017-07-18 13:59:00+03	65900.00
2ED35D	2017-07-12 20:27:00+03	23200.00
2ED38A	2017-07-31 21:20:00+03	45500.00
2ED3BD	2017-07-14 21:13:00+03	123000.00
2ED3C7	2017-07-11 20:33:00+03	82400.00
2ED3D8	2017-07-20 20:52:00+03	153300.00
2ED44E	2017-08-12 11:59:00+03	181000.00
2ED461	2017-08-13 20:55:00+03	24700.00
2ED476	2017-08-08 07:40:00+03	125400.00
2ED48D	2017-07-08 12:56:00+03	68800.00
2ED497	2017-07-24 02:44:00+03	135400.00
2ED521	2017-07-18 23:29:00+03	131100.00
2ED546	2017-08-05 23:34:00+03	182300.00
2ED59C	2017-08-11 14:54:00+03	61900.00
2ED603	2017-08-15 06:08:00+03	161600.00
2ED641	2017-08-13 21:42:00+03	146400.00
2ED652	2017-07-14 00:50:00+03	80700.00
2ED65E	2017-07-30 18:39:00+03	384600.00
2ED681	2017-07-19 10:08:00+03	10600.00
2ED6B3	2017-07-15 10:02:00+03	23600.00
2ED6CE	2017-08-14 18:00:00+03	270500.00
2ED6E0	2017-07-01 03:55:00+03	123000.00
2ED6FB	2017-07-18 16:17:00+03	68900.00
2ED72A	2017-07-05 10:02:00+03	42600.00
2ED76D	2017-08-12 23:45:00+03	277800.00
2ED76E	2017-07-14 06:04:00+03	39200.00
2ED778	2017-07-19 04:00:00+03	115800.00
2ED7D5	2017-07-22 10:24:00+03	26800.00
2ED813	2017-08-15 00:16:00+03	89700.00
2ED86C	2017-08-14 07:07:00+03	113300.00
2ED88A	2017-07-12 23:34:00+03	54500.00
2ED895	2017-06-26 03:46:00+03	8600.00
2ED8DC	2017-08-06 09:19:00+03	26000.00
2ED8E7	2017-07-07 09:13:00+03	56000.00
2ED90A	2017-08-13 16:05:00+03	26800.00
2ED92F	2017-06-30 19:41:00+03	99200.00
2ED935	2017-07-31 23:15:00+03	38600.00
2ED942	2017-07-06 06:13:00+03	42800.00
2ED95B	2017-07-09 00:45:00+03	52100.00
2ED96B	2017-07-24 11:30:00+03	56000.00
2ED9AC	2017-07-28 08:49:00+03	16400.00
2ED9C3	2017-08-15 03:52:00+03	67500.00
2ED9CB	2017-07-22 19:00:00+03	40800.00
2ED9F5	2017-08-14 09:31:00+03	395000.00
2ED9F6	2017-07-18 00:11:00+03	58600.00
2EDA07	2017-08-09 08:20:00+03	76800.00
2EDA30	2017-08-09 06:11:00+03	21400.00
2EDA43	2017-07-08 00:31:00+03	65500.00
2EDA5B	2017-07-14 10:19:00+03	42000.00
2EDAAB	2017-08-04 20:12:00+03	139200.00
2EDB02	2017-07-16 13:33:00+03	56200.00
2EDB04	2017-07-04 17:04:00+03	48500.00
2EDB5B	2017-07-01 19:05:00+03	135400.00
2EDB83	2017-08-15 09:43:00+03	14000.00
2EDBBC	2017-07-01 14:33:00+03	25000.00
2EDC54	2017-08-14 13:07:00+03	26000.00
2EDC7C	2017-07-16 17:33:00+03	29200.00
2EDC8C	2017-08-07 15:37:00+03	46700.00
2EDCCC	2017-07-24 06:15:00+03	38600.00
2EDCEC	2017-07-31 05:54:00+03	13600.00
2EDD35	2017-08-08 08:37:00+03	119500.00
2EDD77	2017-07-07 09:54:00+03	88400.00
2EDD82	2017-07-16 14:29:00+03	86800.00
2EDDEA	2017-07-09 01:58:00+03	31100.00
2EDE07	2017-07-16 15:56:00+03	55800.00
2EDE35	2017-08-01 07:15:00+03	81300.00
2EDE45	2017-07-27 12:08:00+03	119400.00
2EDEAE	2017-08-08 23:59:00+03	23400.00
2EDEEA	2017-08-06 00:35:00+03	112000.00
2EDF11	2017-07-09 21:56:00+03	147300.00
2EDF3C	2017-07-22 05:02:00+03	6000.00
2EDF6D	2017-07-12 12:27:00+03	196800.00
2EDF72	2017-08-12 06:53:00+03	75200.00
2EDF98	2017-08-10 00:32:00+03	135000.00
2EDFE1	2017-08-14 17:55:00+03	25000.00
2EDFE4	2017-07-18 00:22:00+03	48800.00
2EE1AD	2017-07-14 07:38:00+03	103600.00
2EE1B4	2017-07-07 17:22:00+03	107000.00
2EE1D9	2017-07-30 14:14:00+03	21400.00
2EE2A6	2017-07-28 01:54:00+03	88200.00
2EE2AD	2017-08-15 02:26:00+03	113300.00
2EE2C3	2017-07-15 13:45:00+03	98400.00
2EE343	2017-07-19 00:03:00+03	168600.00
2EE369	2017-08-09 10:21:00+03	132800.00
2EE375	2017-07-19 13:42:00+03	56000.00
2EE3CA	2017-07-25 11:36:00+03	117800.00
2EE3F5	2017-07-07 11:20:00+03	63800.00
2EE461	2017-07-28 00:20:00+03	28800.00
2EE467	2017-08-12 09:11:00+03	531400.00
2EE46F	2017-08-03 00:29:00+03	131100.00
2EE478	2017-07-31 03:18:00+03	161600.00
2EE48C	2017-07-17 14:50:00+03	64600.00
2EE4AD	2017-08-10 08:14:00+03	113600.00
2EE4C2	2017-08-07 17:05:00+03	22000.00
2EE4E8	2017-07-19 14:21:00+03	135600.00
2EE4F6	2017-07-27 08:59:00+03	29600.00
2EE510	2017-07-30 06:39:00+03	26000.00
2EE51E	2017-08-15 07:27:00+03	14400.00
2EE53F	2017-07-27 18:26:00+03	12600.00
2EE56F	2017-07-15 12:49:00+03	32200.00
2EE583	2017-07-03 09:15:00+03	55600.00
2EE5E5	2017-07-16 03:33:00+03	246000.00
2EE5FE	2017-07-21 12:17:00+03	25600.00
2EE608	2017-07-25 13:20:00+03	67200.00
2EE641	2017-07-06 11:57:00+03	38400.00
2EE656	2017-08-02 19:35:00+03	28000.00
2EE661	2017-08-01 03:58:00+03	77900.00
2EE6C6	2017-07-05 05:32:00+03	39200.00
2EE73A	2017-08-12 00:01:00+03	13700.00
2EE73F	2017-07-09 21:59:00+03	28800.00
2EE7D3	2017-07-25 13:00:00+03	27900.00
2EE7EB	2017-07-18 02:07:00+03	43200.00
2EE811	2017-06-29 11:41:00+03	13400.00
2EE85C	2017-08-07 10:50:00+03	70700.00
2EE86E	2017-07-17 12:16:00+03	94000.00
2EE907	2017-07-07 11:32:00+03	40000.00
2EE93E	2017-08-11 07:17:00+03	99200.00
2EE987	2017-08-10 18:41:00+03	87000.00
2EE9AC	2017-08-12 02:44:00+03	17000.00
2EEABA	2017-07-09 18:56:00+03	70800.00
2EEB28	2017-08-03 18:02:00+03	24400.00
2EEB45	2017-06-27 19:29:00+03	179200.00
2EEB5F	2017-08-04 13:11:00+03	85000.00
2EEB6D	2017-07-31 15:57:00+03	173500.00
2EEB7B	2017-07-20 07:47:00+03	86800.00
2EEBB2	2017-07-23 13:13:00+03	75300.00
2EEBE1	2017-08-04 14:29:00+03	34000.00
2EEC2A	2017-07-15 06:37:00+03	101200.00
2EEC4B	2017-08-07 10:16:00+03	35200.00
2EECD3	2017-08-07 17:36:00+03	94000.00
2EED0A	2017-07-03 02:16:00+03	67200.00
2EEDD6	2017-07-14 04:43:00+03	103500.00
2EEE47	2017-07-25 10:52:00+03	29400.00
2EEE50	2017-07-03 06:19:00+03	43600.00
2EEE70	2017-07-08 01:19:00+03	28800.00
2EEEC1	2017-07-06 00:14:00+03	57500.00
2EEEE0	2017-08-05 07:28:00+03	65900.00
2EEEF7	2017-08-13 06:02:00+03	25100.00
2EEF15	2017-07-30 21:05:00+03	28800.00
2EF039	2017-07-24 11:51:00+03	25400.00
2EF070	2017-08-07 19:37:00+03	101900.00
2EF0B0	2017-08-09 06:09:00+03	82500.00
2EF0C5	2017-08-02 03:19:00+03	49700.00
2EF0DE	2017-07-10 11:52:00+03	56000.00
2EF14E	2017-08-03 01:30:00+03	68400.00
2EF23F	2017-07-28 12:29:00+03	22400.00
2EF253	2017-07-22 20:08:00+03	46300.00
2EF291	2017-07-28 10:09:00+03	136800.00
2EF295	2017-08-12 07:41:00+03	46200.00
2EF2F7	2017-07-13 15:15:00+03	23200.00
2EF32E	2017-08-07 20:13:00+03	242700.00
2EF456	2017-07-15 22:37:00+03	62000.00
2EF49F	2017-08-11 01:01:00+03	91100.00
2EF514	2017-07-11 07:04:00+03	31600.00
2EF51A	2017-07-21 03:04:00+03	52700.00
2EF52A	2017-08-03 09:16:00+03	96300.00
2EF56F	2017-07-15 15:38:00+03	39400.00
2EF5F4	2017-07-21 01:59:00+03	35200.00
2EF6BD	2017-07-22 14:03:00+03	136200.00
2EF6C6	2017-08-06 07:32:00+03	58200.00
2EF70B	2017-08-04 22:41:00+03	35200.00
2EF70E	2017-07-18 00:31:00+03	52300.00
2EF728	2017-07-19 01:50:00+03	123000.00
2EF80E	2017-08-12 12:47:00+03	44600.00
2EF833	2017-07-24 20:51:00+03	15700.00
2EF857	2017-08-05 19:55:00+03	29600.00
2EF8E0	2017-07-17 22:25:00+03	135600.00
2EF8F5	2017-07-17 03:48:00+03	119700.00
2EF99A	2017-07-06 05:12:00+03	42700.00
2EF9AE	2017-07-06 02:50:00+03	32800.00
2EF9F4	2017-08-11 21:06:00+03	10600.00
2EFA2B	2017-07-29 07:19:00+03	119500.00
2EFA54	2017-07-13 13:21:00+03	196000.00
2EFA5C	2017-08-12 19:07:00+03	63500.00
2EFA87	2017-07-26 21:46:00+03	38800.00
2EFAF2	2017-08-04 04:17:00+03	28000.00
2EFB25	2017-07-26 12:40:00+03	269200.00
2EFB71	2017-08-05 16:10:00+03	492000.00
2EFB7B	2017-07-27 15:40:00+03	184300.00
2EFBFF	2017-06-23 08:33:00+03	68800.00
2EFC46	2017-07-31 08:03:00+03	21800.00
2EFC5D	2017-07-05 13:22:00+03	31400.00
2EFCED	2017-08-09 06:13:00+03	117500.00
2EFD2C	2017-07-08 15:03:00+03	64200.00
2EFD9C	2017-07-30 09:36:00+03	42700.00
2EFE2F	2017-07-07 20:09:00+03	95700.00
2EFE45	2017-07-19 18:15:00+03	48800.00
2EFE5A	2017-07-20 05:48:00+03	66000.00
2EFE8E	2017-08-12 04:09:00+03	89700.00
2EFEED	2017-08-03 20:32:00+03	79800.00
2EFF47	2017-07-18 01:34:00+03	93400.00
2EFFA7	2017-07-30 22:54:00+03	12400.00
2EFFAB	2017-07-28 13:04:00+03	9300.00
2EFFBD	2017-07-29 22:39:00+03	28800.00
2F000A	2017-07-06 12:01:00+03	301800.00
2F000F	2017-08-01 07:14:00+03	12600.00
2F0081	2017-08-09 22:08:00+03	119600.00
2F00BD	2017-07-02 20:17:00+03	34000.00
2F00EA	2017-08-04 17:35:00+03	135600.00
2F0124	2017-07-11 15:53:00+03	135400.00
2F013F	2017-08-02 08:50:00+03	39200.00
2F014C	2017-08-03 02:50:00+03	43600.00
2F019E	2017-07-06 05:11:00+03	61500.00
2F01B5	2017-07-22 23:42:00+03	21400.00
2F024D	2017-07-23 10:39:00+03	11800.00
2F02BD	2017-08-10 21:35:00+03	62000.00
2F0316	2017-08-12 06:11:00+03	53200.00
2F0320	2017-08-15 09:42:00+03	31100.00
2F0377	2017-08-07 19:11:00+03	96800.00
2F038F	2017-07-31 15:11:00+03	26000.00
2F039F	2017-07-09 17:17:00+03	28800.00
2F03D8	2017-08-14 21:37:00+03	36200.00
2F03EE	2017-07-01 12:52:00+03	67600.00
2F0437	2017-08-09 16:28:00+03	56000.00
2F048F	2017-07-17 19:08:00+03	250800.00
2F050C	2017-07-03 05:22:00+03	134400.00
2F05E4	2017-07-03 14:42:00+03	103500.00
2F05F0	2017-07-15 00:16:00+03	9800.00
2F0604	2017-08-09 07:01:00+03	52700.00
2F0655	2017-07-12 17:47:00+03	62600.00
2F0674	2017-08-08 21:26:00+03	13600.00
2F0684	2017-07-03 14:29:00+03	136200.00
2F069D	2017-07-24 23:55:00+03	110600.00
2F06AD	2017-08-06 18:16:00+03	67900.00
2F073A	2017-08-12 12:13:00+03	133100.00
2F082E	2017-07-03 13:46:00+03	25600.00
2F0842	2017-08-12 07:12:00+03	57800.00
2F08A1	2017-07-04 23:32:00+03	308100.00
2F08DF	2017-07-20 23:04:00+03	14400.00
2F08EF	2017-07-08 12:26:00+03	23100.00
2F08FA	2017-07-01 14:15:00+03	43200.00
2F09E4	2017-07-05 04:21:00+03	130900.00
2F0A06	2017-07-21 23:03:00+03	30800.00
2F0A5A	2017-07-30 06:32:00+03	89700.00
2F0ABF	2017-08-08 10:44:00+03	148200.00
2F0ACF	2017-07-13 07:06:00+03	51600.00
2F0ADA	2017-07-05 15:11:00+03	131600.00
2F0B6A	2017-07-12 04:35:00+03	195600.00
2F0B7D	2017-07-25 09:16:00+03	32700.00
2F0BD2	2017-08-04 04:00:00+03	24000.00
2F0C11	2017-07-28 01:50:00+03	299900.00
2F0C23	2017-07-19 17:54:00+03	14800.00
2F0C66	2017-07-17 16:02:00+03	70600.00
2F0CB1	2017-08-01 21:01:00+03	92600.00
2F0CC0	2017-07-03 17:32:00+03	28800.00
2F0CC8	2017-08-05 22:29:00+03	185800.00
2F0CE3	2017-07-06 11:41:00+03	48900.00
2F0D07	2017-07-02 22:30:00+03	53600.00
2F0D14	2017-07-26 19:00:00+03	26000.00
2F0D5E	2017-08-14 16:05:00+03	39300.00
2F0D72	2017-07-04 23:07:00+03	25200.00
2F0DCC	2017-07-09 02:42:00+03	40600.00
2F0DF2	2017-07-27 07:52:00+03	57500.00
2F0E72	2017-08-13 06:17:00+03	24700.00
2F0E9B	2017-08-09 07:14:00+03	13200.00
2F0EA6	2017-07-04 12:21:00+03	56000.00
2F0EC2	2017-08-11 03:08:00+03	393000.00
2F0EC6	2017-07-30 12:02:00+03	347100.00
2F0F20	2017-08-10 20:01:00+03	136200.00
2F0F78	2017-08-08 14:25:00+03	14300.00
2F0F9C	2017-07-11 15:54:00+03	55800.00
2F1016	2017-07-16 05:24:00+03	23200.00
2F1031	2017-07-14 04:48:00+03	45200.00
2F1050	2017-08-15 16:12:00+03	79900.00
2F109F	2017-07-23 15:13:00+03	81300.00
2F1115	2017-07-10 10:25:00+03	39300.00
2F114E	2017-07-15 04:05:00+03	40000.00
2F116D	2017-07-22 23:04:00+03	30200.00
2F11AA	2017-07-13 14:45:00+03	70800.00
2F11DF	2017-08-05 05:32:00+03	39800.00
2F11EA	2017-07-15 15:46:00+03	34400.00
2F11F9	2017-08-09 05:25:00+03	46400.00
2F1215	2017-08-13 14:32:00+03	189200.00
2F129B	2017-06-27 05:41:00+03	99300.00
2F12A1	2017-07-31 22:28:00+03	54800.00
2F12C1	2017-07-12 08:04:00+03	26400.00
2F1343	2017-06-29 08:41:00+03	41600.00
2F1379	2017-08-14 16:36:00+03	20800.00
2F13C3	2017-08-05 05:21:00+03	23200.00
2F1445	2017-07-26 07:12:00+03	69600.00
2F1458	2017-08-11 08:08:00+03	48800.00
2F1459	2017-07-31 22:37:00+03	37900.00
2F146D	2017-07-07 08:21:00+03	28000.00
2F14AB	2017-07-21 04:01:00+03	24000.00
2F14BC	2017-07-19 08:20:00+03	233800.00
2F14DB	2017-07-12 18:51:00+03	98400.00
2F14E5	2017-07-27 22:18:00+03	332800.00
2F153F	2017-08-11 19:32:00+03	99200.00
2F1560	2017-07-24 10:08:00+03	29600.00
2F15BF	2017-07-13 11:19:00+03	46300.00
2F1642	2017-08-10 17:40:00+03	35200.00
2F166E	2017-07-28 14:55:00+03	60400.00
2F1700	2017-07-25 04:08:00+03	123000.00
2F1702	2017-07-10 19:19:00+03	62700.00
2F1734	2017-07-11 04:04:00+03	34000.00
2F1822	2017-07-13 23:32:00+03	335400.00
2F182F	2017-08-04 04:55:00+03	291000.00
2F1836	2017-07-05 09:33:00+03	32800.00
2F189B	2017-08-13 20:58:00+03	14400.00
2F18A8	2017-07-06 22:21:00+03	46400.00
2F18B6	2017-08-15 06:10:00+03	19800.00
2F18BF	2017-07-05 12:56:00+03	123600.00
2F18C6	2017-08-14 17:16:00+03	28900.00
2F18CE	2017-08-05 18:17:00+03	258400.00
2F18E5	2017-07-23 11:34:00+03	72400.00
2F18E8	2017-07-29 07:05:00+03	107000.00
2F18F4	2017-07-04 23:00:00+03	118600.00
2F1973	2017-08-15 00:23:00+03	50200.00
2F19AA	2017-07-31 13:58:00+03	44800.00
2F19C0	2017-07-21 22:13:00+03	14400.00
2F19C3	2017-07-31 18:58:00+03	30200.00
2F19D5	2017-08-01 02:02:00+03	16400.00
2F19F7	2017-07-31 04:03:00+03	64800.00
2F1A3A	2017-07-10 00:58:00+03	69200.00
2F1A8C	2017-08-12 16:57:00+03	131800.00
2F1ADA	2017-07-03 21:25:00+03	77700.00
2F1B87	2017-08-14 02:15:00+03	28300.00
2F1BB8	2017-08-13 10:58:00+03	252200.00
2F1BC4	2017-08-14 04:58:00+03	26800.00
2F1BF6	2017-07-09 09:45:00+03	31100.00
2F1C4F	2017-08-12 04:10:00+03	37900.00
2F1CA2	2017-07-12 02:53:00+03	147700.00
2F1CD2	2017-07-08 13:12:00+03	54500.00
2F1CEC	2017-07-13 15:32:00+03	6700.00
2F1CFE	2017-07-22 21:17:00+03	95400.00
2F1D3A	2017-07-12 08:40:00+03	43500.00
2F1D6F	2017-08-02 21:18:00+03	271100.00
2F1D80	2017-08-10 11:58:00+03	128700.00
2F1D95	2017-08-02 12:19:00+03	28800.00
2F1E82	2017-07-02 13:53:00+03	95200.00
2F1EB2	2017-07-26 17:35:00+03	53300.00
2F1EB8	2017-07-22 04:09:00+03	302400.00
2F1F24	2017-08-02 06:30:00+03	10700.00
2F1F33	2017-08-03 15:16:00+03	112000.00
2F1F72	2017-07-02 23:26:00+03	134400.00
2F1FBF	2017-07-06 14:04:00+03	68100.00
2F20DC	2017-07-03 00:41:00+03	6000.00
2F2117	2017-07-28 01:58:00+03	24300.00
2F2130	2017-07-06 19:38:00+03	45200.00
2F2184	2017-07-13 21:22:00+03	45200.00
2F21EB	2017-08-03 06:12:00+03	37700.00
2F2226	2017-07-13 10:40:00+03	326100.00
2F2280	2017-08-13 04:48:00+03	23600.00
2F2281	2017-07-05 13:42:00+03	15200.00
2F22B7	2017-08-05 02:35:00+03	17600.00
2F22F9	2017-08-15 03:32:00+03	62400.00
2F235A	2017-08-13 13:46:00+03	26200.00
2F2411	2017-07-09 09:12:00+03	105600.00
2F243C	2017-07-06 12:43:00+03	26000.00
2F2473	2017-08-06 03:13:00+03	58600.00
2F2483	2017-08-14 01:53:00+03	14400.00
2F24A1	2017-07-29 19:02:00+03	27200.00
2F24D5	2017-08-14 13:50:00+03	45200.00
2F24F2	2017-08-06 15:13:00+03	270800.00
2F2589	2017-07-14 07:32:00+03	118700.00
2F2636	2017-07-08 11:00:00+03	112000.00
2F2662	2017-07-14 08:44:00+03	69500.00
2F267A	2017-07-13 07:49:00+03	125000.00
2F271A	2017-07-24 03:40:00+03	51200.00
2F2782	2017-07-07 20:05:00+03	25800.00
2F27B5	2017-08-10 16:45:00+03	12600.00
2F27BD	2017-07-04 11:43:00+03	141100.00
2F281B	2017-08-13 13:20:00+03	26000.00
2F28AB	2017-08-09 19:14:00+03	53400.00
2F290E	2017-08-11 19:22:00+03	89700.00
2F295D	2017-07-12 22:19:00+03	358800.00
2F296F	2017-07-12 16:34:00+03	67700.00
2F2A13	2017-08-12 07:09:00+03	16400.00
2F2A5F	2017-07-04 06:21:00+03	46200.00
2F2AE1	2017-06-30 10:07:00+03	131100.00
2F2AF8	2017-07-17 06:46:00+03	14800.00
2F2B0C	2017-07-22 04:29:00+03	72800.00
2F2B52	2017-08-14 23:21:00+03	20400.00
2F2B78	2017-07-13 11:33:00+03	6700.00
2F2BB2	2017-07-13 02:43:00+03	28800.00
2F2C08	2017-07-04 11:05:00+03	244200.00
2F2CA2	2017-07-29 22:37:00+03	60700.00
2F2CCB	2017-08-03 16:00:00+03	206800.00
2F2CD6	2017-08-04 02:05:00+03	184300.00
2F2D45	2017-08-12 14:42:00+03	133200.00
2F2D4E	2017-07-11 09:49:00+03	38400.00
2F2D63	2017-07-04 16:49:00+03	13400.00
2F2D81	2017-07-18 06:05:00+03	15800.00
2F2DC3	2017-07-24 02:41:00+03	78200.00
2F2DC7	2017-07-15 18:57:00+03	135400.00
2F2DCB	2017-07-15 10:55:00+03	147700.00
2F2EAD	2017-07-26 12:15:00+03	29800.00
2F2EEA	2017-08-09 19:13:00+03	28000.00
2F2EEB	2017-08-09 18:13:00+03	18600.00
2F2F2A	2017-07-05 15:12:00+03	26700.00
2F2F48	2017-08-05 13:36:00+03	145300.00
2F2FA3	2017-07-20 12:13:00+03	169000.00
2F2FAF	2017-07-21 15:03:00+03	125400.00
2F2FEF	2017-07-20 23:27:00+03	21600.00
2F3000	2017-07-10 01:40:00+03	16800.00
2F3042	2017-07-02 08:43:00+03	38600.00
2F30F4	2017-08-14 06:45:00+03	85700.00
2F3187	2017-07-04 01:30:00+03	46400.00
2F31DF	2017-07-29 03:36:00+03	114800.00
2F3263	2017-07-15 01:55:00+03	66600.00
2F33D3	2017-06-29 12:31:00+03	172000.00
2F342D	2017-07-23 10:34:00+03	56100.00
2F34A9	2017-07-12 22:18:00+03	119700.00
2F34C2	2017-07-28 17:01:00+03	29200.00
2F34C8	2017-07-21 01:41:00+03	15900.00
2F34CC	2017-07-17 11:18:00+03	61200.00
2F34E4	2017-07-24 16:26:00+03	106900.00
2F3526	2017-07-04 05:11:00+03	58800.00
2F355D	2017-08-01 06:48:00+03	19600.00
2F360E	2017-07-07 00:20:00+03	123000.00
2F3629	2017-07-19 12:27:00+03	52000.00
2F368B	2017-07-18 00:27:00+03	27200.00
2F3698	2017-07-27 13:41:00+03	129200.00
2F36AB	2017-07-03 05:55:00+03	25600.00
2F36F4	2017-08-02 11:41:00+03	56000.00
2F374F	2017-08-07 09:16:00+03	156500.00
2F37E1	2017-07-10 17:41:00+03	10800.00
2F3808	2017-07-22 15:51:00+03	143400.00
2F3810	2017-08-13 04:52:00+03	44600.00
2F3828	2017-07-09 14:21:00+03	24400.00
2F38DD	2017-08-15 09:00:00+03	68100.00
2F390C	2017-07-14 16:41:00+03	47000.00
2F391C	2017-08-11 08:15:00+03	405000.00
2F392D	2017-07-30 04:39:00+03	9800.00
2F393A	2017-07-20 16:04:00+03	263100.00
2F3944	2017-08-05 09:26:00+03	72800.00
2F3953	2017-08-05 05:42:00+03	7400.00
2F3978	2017-07-12 21:32:00+03	88000.00
2F3982	2017-08-12 21:18:00+03	197400.00
2F3986	2017-07-30 16:44:00+03	14000.00
2F39EB	2017-07-07 00:08:00+03	39400.00
2F39EC	2017-08-06 04:51:00+03	56600.00
2F3A02	2017-07-06 11:59:00+03	69900.00
2F3A25	2017-08-07 16:20:00+03	103200.00
2F3A5F	2017-08-02 06:17:00+03	266200.00
2F3A6B	2017-07-05 06:07:00+03	166900.00
2F3AF9	2017-07-28 19:04:00+03	135200.00
2F3B19	2017-07-28 02:29:00+03	35200.00
2F3C2F	2017-08-05 14:23:00+03	119500.00
2F3C48	2017-07-09 03:55:00+03	131100.00
2F3D18	2017-07-02 22:15:00+03	64900.00
2F3D63	2017-08-11 08:34:00+03	37100.00
2F3DF8	2017-08-12 16:30:00+03	114900.00
2F3E09	2017-07-29 17:31:00+03	95700.00
2F3E4B	2017-08-13 23:27:00+03	49200.00
2F3E62	2017-07-31 18:11:00+03	73900.00
2F3F2D	2017-07-22 08:31:00+03	17600.00
2F3F37	2017-07-06 03:26:00+03	36200.00
2F3F41	2017-07-28 00:00:00+03	207200.00
2F3F4B	2017-08-05 00:43:00+03	65900.00
2F3F52	2017-08-14 04:22:00+03	28000.00
2F3FC2	2017-08-13 00:27:00+03	54100.00
2F3FEC	2017-08-15 02:11:00+03	86400.00
2F4045	2017-07-12 08:02:00+03	26700.00
2F4062	2017-07-04 13:25:00+03	15000.00
2F40E6	2017-07-27 23:05:00+03	14800.00
2F4181	2017-07-19 22:44:00+03	89700.00
2F429D	2017-07-15 15:08:00+03	20600.00
2F42B8	2017-07-28 21:04:00+03	111600.00
2F42BB	2017-07-20 15:21:00+03	39600.00
2F42E6	2017-07-28 13:51:00+03	258400.00
2F4305	2017-07-02 22:55:00+03	75600.00
2F437F	2017-07-27 01:01:00+03	30200.00
2F43C0	2017-07-27 03:13:00+03	35300.00
2F445E	2017-07-18 15:18:00+03	62900.00
2F4478	2017-07-15 12:44:00+03	31000.00
2F4496	2017-08-02 23:58:00+03	66400.00
2F452C	2017-08-01 22:07:00+03	89700.00
2F4556	2017-08-13 13:21:00+03	56000.00
2F457F	2017-06-26 04:42:00+03	90000.00
2F461E	2017-08-07 15:52:00+03	96800.00
2F462D	2017-06-30 11:18:00+03	6700.00
2F4631	2017-08-02 17:24:00+03	11600.00
2F46E5	2017-08-06 13:13:00+03	226200.00
2F4712	2017-08-07 11:25:00+03	16400.00
2F4726	2017-07-01 10:23:00+03	55500.00
2F4737	2017-08-14 16:36:00+03	57700.00
2F4797	2017-07-18 12:50:00+03	31400.00
2F47D9	2017-07-10 03:11:00+03	111600.00
2F48D0	2017-07-03 06:40:00+03	23600.00
2F49B8	2017-07-18 06:14:00+03	124200.00
2F4B91	2017-07-27 14:36:00+03	46000.00
2F4BB0	2017-08-15 09:19:00+03	56000.00
2F4BE0	2017-07-06 08:34:00+03	23400.00
2F4BE7	2017-08-01 21:13:00+03	11800.00
2F4BF4	2017-07-06 15:45:00+03	26000.00
2F4C2B	2017-06-30 11:08:00+03	56000.00
2F4C2C	2017-07-23 10:36:00+03	123000.00
2F4C79	2017-07-28 11:22:00+03	187800.00
2F4D36	2017-08-04 08:00:00+03	58600.00
2F4D96	2017-08-03 09:47:00+03	31600.00
2F4D9C	2017-07-16 00:31:00+03	46200.00
2F4E17	2017-08-08 16:01:00+03	22000.00
2F4E94	2017-07-21 03:17:00+03	47600.00
2F4ED1	2017-06-25 09:31:00+03	26000.00
2F4F15	2017-07-25 21:37:00+03	46800.00
2F4F9F	2017-07-11 12:16:00+03	113200.00
2F4FFB	2017-07-08 23:31:00+03	46300.00
2F5012	2017-08-03 17:46:00+03	25400.00
2F503E	2017-08-08 18:13:00+03	33300.00
2F50DE	2017-07-17 00:09:00+03	21800.00
2F5147	2017-07-28 10:21:00+03	174400.00
2F5158	2017-08-08 03:13:00+03	29600.00
2F517F	2017-08-10 19:37:00+03	56600.00
2F51D6	2017-08-12 21:22:00+03	26800.00
2F5273	2017-07-16 04:50:00+03	58600.00
2F52B6	2017-07-07 02:21:00+03	28800.00
2F5324	2017-07-13 22:17:00+03	116400.00
2F5331	2017-07-11 07:55:00+03	195800.00
2F538E	2017-07-09 07:45:00+03	16800.00
2F53D0	2017-08-12 06:58:00+03	23800.00
2F540D	2017-07-01 08:43:00+03	46700.00
2F5422	2017-07-05 01:06:00+03	64300.00
2F5430	2017-07-27 14:53:00+03	25600.00
2F5474	2017-07-26 06:23:00+03	52700.00
2F548F	2017-06-28 18:57:00+03	125200.00
2F54EB	2017-07-20 14:05:00+03	57500.00
2F5588	2017-07-05 15:38:00+03	122000.00
2F572A	2017-08-12 07:56:00+03	99200.00
2F5736	2017-07-11 15:59:00+03	77900.00
2F5755	2017-08-12 01:47:00+03	93500.00
2F57E2	2017-07-16 01:56:00+03	6800.00
2F5810	2017-07-31 19:52:00+03	75300.00
2F581A	2017-07-04 02:00:00+03	9800.00
2F583B	2017-08-09 02:03:00+03	6300.00
2F58ED	2017-07-30 09:50:00+03	66000.00
2F591F	2017-08-03 06:54:00+03	37200.00
2F594E	2017-07-12 18:06:00+03	26800.00
2F5969	2017-07-18 18:50:00+03	140900.00
2F5A24	2017-07-04 23:31:00+03	21200.00
2F5A58	2017-07-02 19:31:00+03	41100.00
2F5AE3	2017-08-14 15:25:00+03	81300.00
2F5B48	2017-07-22 14:26:00+03	155600.00
2F5B4E	2017-07-21 01:05:00+03	85700.00
2F5B5A	2017-07-06 17:11:00+03	43600.00
2F5C38	2017-08-14 15:15:00+03	19600.00
2F5CA9	2017-07-08 12:06:00+03	134400.00
2F5CD4	2017-07-23 19:46:00+03	56000.00
2F5CE1	2017-07-05 18:11:00+03	28800.00
2F5D18	2017-07-25 05:11:00+03	20600.00
2F5D23	2017-07-13 03:20:00+03	254600.00
2F5D63	2017-07-15 05:41:00+03	84000.00
2F5DD6	2017-07-29 14:16:00+03	14000.00
2F5DE8	2017-08-13 17:58:00+03	65200.00
2F5E47	2017-08-03 05:00:00+03	29400.00
2F5E6E	2017-08-12 23:36:00+03	26000.00
2F5E89	2017-07-25 01:16:00+03	126200.00
2F5F07	2017-08-06 03:07:00+03	13300.00
2F5F4A	2017-08-05 23:44:00+03	28000.00
2F5F96	2017-08-10 01:50:00+03	23600.00
2F6011	2017-08-01 05:09:00+03	55800.00
2F602D	2017-07-03 13:44:00+03	21800.00
2F6032	2017-07-19 22:57:00+03	65900.00
2F606F	2017-07-26 11:41:00+03	24400.00
2F60A4	2017-08-12 23:50:00+03	229900.00
2F60B1	2017-07-07 14:50:00+03	61800.00
2F6105	2017-07-16 05:04:00+03	199700.00
2F6164	2017-08-05 15:24:00+03	131100.00
2F619E	2017-08-15 13:01:00+03	41200.00
2F61D6	2017-08-06 17:08:00+03	48200.00
2F61DA	2017-08-10 07:30:00+03	71100.00
2F61E2	2017-08-12 16:13:00+03	34000.00
2F622D	2017-07-28 02:42:00+03	14000.00
2F6262	2017-07-20 03:06:00+03	135600.00
2F62CA	2017-08-15 03:58:00+03	67200.00
2F62CC	2017-07-08 10:24:00+03	46200.00
2F62D5	2017-07-25 11:58:00+03	51900.00
2F62DD	2017-08-05 21:29:00+03	45200.00
2F62FD	2017-07-08 21:08:00+03	55800.00
2F6320	2017-08-11 04:46:00+03	48700.00
2F6330	2017-07-30 18:14:00+03	89700.00
2F6358	2017-08-15 15:20:00+03	20200.00
2F63B3	2017-08-06 22:37:00+03	197700.00
2F63C9	2017-08-10 02:29:00+03	47600.00
2F6502	2017-07-01 01:12:00+03	72400.00
2F6539	2017-08-03 13:17:00+03	16400.00
2F656B	2017-08-02 22:18:00+03	22400.00
2F66A1	2017-08-10 07:17:00+03	23600.00
2F66B3	2017-08-15 08:27:00+03	20400.00
2F66D8	2017-08-11 18:27:00+03	55800.00
2F673E	2017-07-16 18:52:00+03	50200.00
2F675F	2017-07-13 23:29:00+03	48800.00
2F67B3	2017-08-03 13:41:00+03	306200.00
2F6833	2017-07-09 13:03:00+03	394000.00
2F6848	2017-08-07 20:48:00+03	19600.00
2F6880	2017-08-11 13:28:00+03	26700.00
2F6889	2017-07-03 23:58:00+03	55800.00
2F689D	2017-06-30 13:00:00+03	103600.00
2F68AD	2017-08-08 13:37:00+03	116400.00
2F68CC	2017-08-07 22:41:00+03	45100.00
2F6934	2017-07-30 05:34:00+03	86400.00
2F696A	2017-08-10 15:29:00+03	20200.00
2F6A7D	2017-07-18 06:27:00+03	12600.00
2F6B07	2017-08-02 04:37:00+03	42700.00
2F6B0B	2017-08-10 08:40:00+03	187800.00
2F6B36	2017-07-07 14:28:00+03	41600.00
2F6BDE	2017-07-12 13:27:00+03	48800.00
2F6BF3	2017-07-25 01:49:00+03	13600.00
2F6C17	2017-08-15 10:59:00+03	225500.00
2F6C65	2017-08-10 00:54:00+03	30000.00
2F6C6E	2017-07-11 21:28:00+03	29600.00
2F6CC6	2017-07-16 12:37:00+03	67600.00
2F6CE1	2017-07-03 21:54:00+03	36100.00
2F6D0D	2017-08-09 10:02:00+03	30200.00
2F6D1B	2017-07-14 16:38:00+03	24800.00
2F6D29	2017-07-03 16:46:00+03	123000.00
2F6D51	2017-07-29 01:32:00+03	111700.00
2F6D61	2017-07-13 12:43:00+03	49600.00
2F6D7B	2017-07-05 07:29:00+03	259000.00
2F6D97	2017-07-28 02:22:00+03	94900.00
2F6DCD	2017-07-19 18:45:00+03	85800.00
2F6DDB	2017-08-08 14:58:00+03	56000.00
2F6E03	2017-07-24 00:01:00+03	23600.00
2F6E33	2017-07-18 06:28:00+03	30700.00
2F6E47	2017-08-01 16:11:00+03	8200.00
2F6E95	2017-08-08 02:10:00+03	85000.00
2F6EC4	2017-08-12 17:51:00+03	51900.00
2F6ED2	2017-08-02 18:35:00+03	123000.00
2F6F1F	2017-07-11 09:27:00+03	25600.00
2F6F48	2017-07-29 21:47:00+03	44000.00
2F6F59	2017-07-07 23:23:00+03	69200.00
2F6F72	2017-08-13 20:28:00+03	28800.00
2F6F9F	2017-07-20 03:21:00+03	112000.00
2F6FC3	2017-07-29 16:18:00+03	8000.00
2F6FDF	2017-08-08 02:40:00+03	56000.00
2F7050	2017-08-13 23:47:00+03	16400.00
2F70D8	2017-08-03 05:27:00+03	78000.00
2F71AF	2017-07-19 13:15:00+03	68800.00
2F723A	2017-08-11 03:18:00+03	156400.00
2F723B	2017-07-08 12:51:00+03	77200.00
2F7287	2017-08-10 19:57:00+03	98400.00
2F72B2	2017-07-05 08:50:00+03	26800.00
2F72CC	2017-08-03 00:08:00+03	40800.00
2F72FC	2017-07-24 12:31:00+03	31400.00
2F7344	2017-08-12 01:36:00+03	28800.00
2F739D	2017-07-28 00:54:00+03	56600.00
2F7428	2017-07-05 21:55:00+03	68800.00
2F748F	2017-07-06 20:10:00+03	6000.00
2F74C8	2017-07-29 11:11:00+03	119600.00
2F751F	2017-08-13 23:21:00+03	65400.00
2F7570	2017-07-15 00:57:00+03	62000.00
2F7589	2017-07-11 21:56:00+03	28000.00
2F7600	2017-07-21 02:13:00+03	116700.00
2F7688	2017-08-14 19:08:00+03	136000.00
2F76C4	2017-07-24 09:55:00+03	28800.00
2F77A0	2017-07-22 13:39:00+03	22000.00
2F77B9	2017-07-12 10:50:00+03	25600.00
2F77C0	2017-07-02 00:40:00+03	40800.00
2F77CC	2017-07-12 22:47:00+03	62700.00
2F7804	2017-08-03 19:53:00+03	59300.00
2F7835	2017-08-11 06:35:00+03	126400.00
2F78A1	2017-08-10 22:38:00+03	203000.00
2F78EF	2017-07-15 06:42:00+03	28800.00
2F7905	2017-07-25 12:29:00+03	38400.00
2F7949	2017-07-26 11:23:00+03	49400.00
2F794B	2017-07-04 07:01:00+03	128800.00
2F7967	2017-07-24 03:31:00+03	272000.00
2F7A0B	2017-08-14 13:07:00+03	37600.00
2F7A4A	2017-07-04 20:15:00+03	123000.00
2F7ADC	2017-08-02 20:36:00+03	19600.00
2F7AE6	2017-07-13 21:47:00+03	23600.00
2F7B51	2017-07-20 10:03:00+03	9800.00
2F7BB0	2017-08-07 11:48:00+03	182500.00
2F7C08	2017-07-16 03:43:00+03	146300.00
2F7CB3	2017-08-03 10:21:00+03	284200.00
2F7CBB	2017-07-08 04:32:00+03	92800.00
2F7CE0	2017-07-09 09:50:00+03	202300.00
2F7D02	2017-07-11 14:53:00+03	38400.00
2F7D11	2017-07-09 03:42:00+03	118100.00
2F7D73	2017-07-02 12:24:00+03	58600.00
2F7DB4	2017-08-08 11:19:00+03	32800.00
2F7DB6	2017-06-30 13:19:00+03	28000.00
2F7E06	2017-07-24 21:52:00+03	16400.00
2F7E2E	2017-08-11 20:51:00+03	32800.00
2F7E4D	2017-07-19 06:43:00+03	68100.00
2F7E50	2017-07-28 05:56:00+03	57600.00
2F7E62	2017-08-10 14:09:00+03	56600.00
2F7E82	2017-08-15 12:22:00+03	77000.00
2F7F20	2017-07-20 03:22:00+03	114200.00
2F7F24	2017-08-10 22:14:00+03	32700.00
2F7F41	2017-08-14 17:09:00+03	120700.00
2F7F4C	2017-08-07 11:08:00+03	90800.00
2F7F85	2017-07-07 17:23:00+03	92400.00
2F7FF2	2017-08-12 07:04:00+03	43200.00
2F8017	2017-08-11 08:08:00+03	35200.00
2F801F	2017-08-12 18:27:00+03	25000.00
2F8094	2017-07-17 03:13:00+03	16400.00
2F809D	2017-07-04 22:52:00+03	43600.00
2F80B9	2017-07-23 17:27:00+03	31200.00
2F80F1	2017-07-05 03:47:00+03	46900.00
2F81E0	2017-08-11 03:13:00+03	58800.00
2F81F2	2017-07-11 03:07:00+03	38600.00
2F8203	2017-08-07 10:24:00+03	26000.00
2F8213	2017-06-26 16:10:00+03	36800.00
2F8240	2017-08-11 03:21:00+03	118700.00
2F82AA	2017-07-22 08:01:00+03	12600.00
2F82E3	2017-08-10 10:55:00+03	126700.00
2F8301	2017-08-11 07:36:00+03	67600.00
2F8415	2017-07-14 23:45:00+03	25000.00
2F8453	2017-07-12 22:23:00+03	14400.00
2F84BC	2017-07-27 18:30:00+03	204200.00
2F8545	2017-07-21 12:53:00+03	40000.00
2F8557	2017-07-01 23:59:00+03	186900.00
2F85F2	2017-07-05 03:04:00+03	112000.00
2F8663	2017-07-14 04:56:00+03	47500.00
2F86C2	2017-07-08 06:10:00+03	21800.00
2F8731	2017-08-15 13:19:00+03	100600.00
2F87B6	2017-07-15 00:31:00+03	91200.00
2F87DE	2017-07-18 14:11:00+03	76600.00
2F87F5	2017-08-12 07:41:00+03	26200.00
2F880B	2017-08-15 05:10:00+03	13400.00
2F8848	2017-07-29 22:56:00+03	42800.00
2F8898	2017-07-25 03:07:00+03	191200.00
2F8899	2017-07-28 18:53:00+03	7400.00
2F897B	2017-08-01 12:38:00+03	23200.00
2F89AB	2017-07-30 08:59:00+03	70400.00
2F89DC	2017-08-08 17:53:00+03	65500.00
2F8A17	2017-07-24 03:39:00+03	56000.00
2F8A6D	2017-07-01 13:49:00+03	40000.00
2F8AB5	2017-07-11 02:49:00+03	100600.00
2F8ABA	2017-07-13 05:09:00+03	100600.00
2F8B17	2017-07-19 05:42:00+03	32700.00
2F8B62	2017-07-04 05:00:00+03	23200.00
2F8B7D	2017-07-20 00:02:00+03	114400.00
2F8BA7	2017-07-05 00:15:00+03	25200.00
2F8C14	2017-08-02 11:22:00+03	28000.00
2F8C1F	2017-07-23 02:40:00+03	66600.00
2F8C4B	2017-07-28 18:52:00+03	65900.00
2F8C5E	2017-07-20 22:14:00+03	52300.00
2F8C69	2017-07-05 00:49:00+03	28000.00
2F8CAC	2017-07-14 13:17:00+03	58900.00
2F8CD7	2017-07-28 04:51:00+03	57500.00
2F8D09	2017-07-01 11:04:00+03	91800.00
2F8D45	2017-08-11 19:21:00+03	53800.00
2F8D62	2017-08-02 20:53:00+03	46500.00
2F8DD1	2017-07-24 14:45:00+03	179500.00
2F8DD3	2017-07-12 11:28:00+03	37800.00
2F8DD9	2017-08-11 14:14:00+03	95300.00
2F8E48	2017-07-10 10:20:00+03	56000.00
2F8E83	2017-08-03 19:29:00+03	47700.00
2F8E84	2017-08-02 00:10:00+03	257600.00
2F8E85	2017-07-18 14:35:00+03	36200.00
2F8E8A	2017-07-08 06:46:00+03	103200.00
2F8EA7	2017-07-12 04:22:00+03	52400.00
2F8EEE	2017-07-16 05:38:00+03	34400.00
2F8EFF	2017-07-10 01:02:00+03	105600.00
2F8F1F	2017-07-11 17:08:00+03	165600.00
2F8F5F	2017-08-14 23:45:00+03	153300.00
2F8F7C	2017-08-09 19:00:00+03	100100.00
2F8FE1	2017-08-15 00:29:00+03	70700.00
2F9018	2017-07-04 18:59:00+03	46000.00
2F90CA	2017-07-17 22:14:00+03	81600.00
2F9108	2017-07-20 22:02:00+03	200300.00
2F9138	2017-07-09 09:36:00+03	115400.00
2F9338	2017-07-28 20:49:00+03	69400.00
2F9361	2017-07-07 19:43:00+03	92800.00
2F9397	2017-07-08 06:21:00+03	231900.00
2F93C8	2017-07-25 05:46:00+03	28000.00
2F93D9	2017-08-07 07:37:00+03	184300.00
2F93F8	2017-06-30 03:40:00+03	54000.00
2F9443	2017-07-25 16:05:00+03	167400.00
2F9484	2017-07-31 21:49:00+03	53500.00
2F94C3	2017-07-24 04:44:00+03	75300.00
2F957F	2017-08-08 22:03:00+03	28800.00
2F95DE	2017-06-27 03:33:00+03	83300.00
2F964D	2017-07-09 16:49:00+03	40400.00
2F9663	2017-08-08 07:03:00+03	46000.00
2F9669	2017-07-28 12:39:00+03	68400.00
2F9677	2017-07-28 16:37:00+03	56600.00
2F96E6	2017-07-11 21:44:00+03	66600.00
2F972A	2017-07-18 03:42:00+03	51900.00
2F97A3	2017-07-15 07:53:00+03	95100.00
2F97DB	2017-07-19 02:16:00+03	97800.00
2F988D	2017-07-26 12:04:00+03	34100.00
2F9891	2017-08-10 02:39:00+03	28800.00
2F98FB	2017-07-09 04:10:00+03	51900.00
2F998B	2017-07-20 21:56:00+03	92400.00
2F99C3	2017-08-15 00:17:00+03	77900.00
2F99C6	2017-08-08 09:12:00+03	21400.00
2F99F4	2017-08-09 09:59:00+03	40600.00
2F99FC	2017-07-01 17:20:00+03	49800.00
2F9B37	2017-08-05 08:10:00+03	246000.00
2F9B4A	2017-08-10 09:39:00+03	48800.00
2F9B6E	2017-07-29 15:43:00+03	28800.00
2F9BC9	2017-07-06 10:29:00+03	62800.00
2F9C08	2017-07-08 03:11:00+03	92800.00
2F9C28	2017-07-21 04:36:00+03	56000.00
2F9C77	2017-07-18 15:16:00+03	123900.00
2F9CE1	2017-07-16 05:54:00+03	27000.00
2F9D31	2017-07-26 18:54:00+03	65500.00
2F9D70	2017-08-08 09:48:00+03	14400.00
2F9DE6	2017-08-14 14:15:00+03	73900.00
2F9E1E	2017-07-18 10:23:00+03	46700.00
2F9E3E	2017-08-11 02:55:00+03	13400.00
2F9EE2	2017-07-26 06:15:00+03	128500.00
2F9F37	2017-07-20 08:09:00+03	59800.00
2F9F42	2017-07-30 15:00:00+03	61800.00
2F9F99	2017-07-02 01:57:00+03	299600.00
2F9FA9	2017-07-22 20:19:00+03	40400.00
2F9FD4	2017-07-09 10:38:00+03	100600.00
2F9FED	2017-07-04 21:11:00+03	51900.00
2FA041	2017-08-05 23:10:00+03	105100.00
2FA12E	2017-07-22 23:50:00+03	25000.00
2FA189	2017-07-17 07:13:00+03	16400.00
2FA1B9	2017-07-10 12:12:00+03	31100.00
2FA1D3	2017-07-16 21:15:00+03	100600.00
2FA2FA	2017-07-15 17:55:00+03	22600.00
2FA346	2017-08-08 15:04:00+03	83100.00
2FA35A	2017-07-23 12:43:00+03	26000.00
2FA379	2017-07-25 01:18:00+03	23600.00
2FA37B	2017-07-22 15:57:00+03	68400.00
2FA39D	2017-08-09 07:33:00+03	276900.00
2FA4B6	2017-07-19 15:50:00+03	14000.00
2FA4D7	2017-08-14 21:40:00+03	18000.00
2FA5AB	2017-07-28 20:19:00+03	83400.00
2FA62F	2017-07-15 05:19:00+03	30200.00
2FA631	2017-08-02 00:23:00+03	37200.00
2FA63A	2017-08-03 15:49:00+03	265600.00
2FA688	2017-07-17 00:39:00+03	57800.00
2FA6D8	2017-07-08 21:28:00+03	123000.00
2FA708	2017-07-21 07:12:00+03	81300.00
2FA738	2017-07-07 14:08:00+03	91600.00
2FA74A	2017-07-21 00:13:00+03	39800.00
2FA780	2017-08-02 09:06:00+03	59900.00
2FA794	2017-08-09 16:02:00+03	265700.00
2FA7B4	2017-07-21 20:50:00+03	26600.00
2FA7C6	2017-07-27 08:08:00+03	24400.00
2FA7F7	2017-08-05 22:30:00+03	108200.00
2FA803	2017-07-07 22:03:00+03	157500.00
2FA808	2017-08-02 00:11:00+03	19600.00
2FA829	2017-08-14 22:08:00+03	65600.00
2FA85B	2017-07-03 02:56:00+03	56000.00
2FA868	2017-08-13 21:54:00+03	138000.00
2FA870	2017-08-08 01:31:00+03	93500.00
2FA876	2017-07-07 18:15:00+03	116800.00
2FA888	2017-07-02 20:51:00+03	69500.00
2FA8E2	2017-07-07 02:11:00+03	112000.00
2FA9CD	2017-08-12 00:42:00+03	30200.00
2FA9D0	2017-07-03 01:55:00+03	88100.00
2FA9D1	2017-07-18 21:40:00+03	64800.00
2FAA3B	2017-07-07 15:32:00+03	28800.00
2FAA6C	2017-08-10 17:26:00+03	23600.00
2FAA8B	2017-07-10 01:21:00+03	131100.00
2FAAB1	2017-07-07 23:50:00+03	155300.00
2FAAB5	2017-08-09 22:39:00+03	125400.00
2FAAC6	2017-07-13 10:20:00+03	19600.00
2FAADB	2017-07-18 13:21:00+03	25600.00
2FAB41	2017-08-05 04:55:00+03	46400.00
2FAB5B	2017-07-08 16:32:00+03	196100.00
2FAB74	2017-07-10 11:47:00+03	28800.00
2FABA2	2017-07-15 09:35:00+03	65100.00
2FABC8	2017-07-13 09:45:00+03	13400.00
2FAC0D	2017-07-20 16:07:00+03	44600.00
2FAC1F	2017-08-14 21:02:00+03	84500.00
2FAC42	2017-07-31 20:55:00+03	55800.00
2FAC4F	2017-07-23 17:08:00+03	62600.00
2FAC9B	2017-07-10 13:39:00+03	7900.00
2FACCB	2017-08-13 12:50:00+03	39200.00
2FACDC	2017-08-05 12:31:00+03	37100.00
2FAD00	2017-08-13 19:48:00+03	246000.00
2FAD10	2017-08-01 20:26:00+03	19500.00
2FAD2A	2017-08-14 06:08:00+03	22000.00
2FAD51	2017-07-04 22:23:00+03	26000.00
2FADA7	2017-07-02 02:36:00+03	46300.00
2FAE0F	2017-08-05 09:53:00+03	13400.00
2FAE23	2017-08-10 12:56:00+03	37900.00
2FAE67	2017-07-10 15:41:00+03	86600.00
2FAE72	2017-08-06 00:33:00+03	108500.00
2FAE93	2017-07-21 16:46:00+03	47400.00
2FAE98	2017-07-06 21:54:00+03	87100.00
2FAED8	2017-08-03 20:37:00+03	15700.00
2FAF09	2017-07-28 22:41:00+03	123000.00
2FAF11	2017-07-20 21:36:00+03	147400.00
2FAF58	2017-08-13 20:16:00+03	52000.00
2FAF6A	2017-08-11 20:14:00+03	44800.00
2FAF8A	2017-07-17 07:44:00+03	44200.00
2FB034	2017-08-12 19:54:00+03	292200.00
2FB055	2017-08-04 15:31:00+03	10800.00
2FB058	2017-08-03 16:02:00+03	154100.00
2FB08F	2017-07-24 19:38:00+03	18600.00
2FB0DD	2017-07-11 14:16:00+03	24400.00
2FB0ED	2017-07-30 16:43:00+03	45200.00
2FB0F5	2017-07-11 11:40:00+03	115700.00
2FB166	2017-08-09 22:52:00+03	23400.00
2FB17D	2017-07-18 10:07:00+03	34800.00
2FB188	2017-07-14 00:42:00+03	40400.00
2FB1EB	2017-07-25 12:51:00+03	39600.00
2FB1F7	2017-07-04 19:51:00+03	15600.00
2FB260	2017-08-03 12:05:00+03	41600.00
2FB274	2017-08-11 03:32:00+03	21400.00
2FB2A4	2017-08-08 06:10:00+03	30200.00
2FB2F6	2017-07-30 00:10:00+03	170700.00
2FB322	2017-07-07 19:48:00+03	77900.00
2FB353	2017-07-27 21:39:00+03	51600.00
2FB368	2017-07-22 23:46:00+03	6000.00
2FB390	2017-07-05 06:47:00+03	82900.00
2FB3FA	2017-08-11 16:13:00+03	69000.00
2FB41E	2017-07-08 01:58:00+03	81500.00
2FB44C	2017-08-13 20:20:00+03	27200.00
2FB46A	2017-08-12 01:50:00+03	100600.00
2FB474	2017-08-06 16:33:00+03	22100.00
2FB503	2017-08-14 03:06:00+03	26000.00
2FB528	2017-07-20 20:34:00+03	75300.00
2FB554	2017-06-29 10:49:00+03	208100.00
2FB592	2017-08-04 02:44:00+03	180800.00
2FB596	2017-07-21 09:03:00+03	158500.00
2FB5B0	2017-08-04 11:20:00+03	123000.00
2FB5EC	2017-08-07 07:13:00+03	28000.00
2FB674	2017-07-19 14:08:00+03	38400.00
2FB6F8	2017-07-27 08:40:00+03	36200.00
2FB742	2017-07-14 00:49:00+03	55800.00
2FB7F3	2017-07-15 00:12:00+03	106900.00
2FB80E	2017-08-06 10:09:00+03	131000.00
2FB833	2017-07-07 01:33:00+03	92800.00
2FB834	2017-07-24 17:05:00+03	137100.00
2FB842	2017-07-01 15:44:00+03	6000.00
2FB8E2	2017-08-12 21:10:00+03	145300.00
2FB92A	2017-07-28 09:38:00+03	70700.00
2FB957	2017-08-02 12:55:00+03	118600.00
2FB959	2017-06-30 04:37:00+03	28300.00
2FB99B	2017-08-08 03:43:00+03	57500.00
2FB9E0	2017-08-01 23:36:00+03	100600.00
2FBA02	2017-07-06 09:00:00+03	32200.00
2FBA05	2017-07-11 07:11:00+03	124200.00
2FBA28	2017-07-27 18:20:00+03	38200.00
2FBA3A	2017-08-03 05:16:00+03	255600.00
2FBA66	2017-07-27 03:14:00+03	168000.00
2FBA70	2017-07-22 05:36:00+03	7200.00
2FBA85	2017-07-16 13:34:00+03	28800.00
2FBA8A	2017-07-29 16:34:00+03	145200.00
2FBA92	2017-07-16 04:48:00+03	58400.00
2FBAB5	2017-07-31 09:19:00+03	44600.00
2FBAF2	2017-08-10 17:49:00+03	24400.00
2FBB19	2017-08-08 15:08:00+03	57800.00
2FBB53	2017-08-03 22:15:00+03	100600.00
2FBB8F	2017-08-01 20:57:00+03	136800.00
2FBCAA	2017-07-16 12:19:00+03	23400.00
2FBCC4	2017-07-31 05:36:00+03	89600.00
2FBCC7	2017-08-11 00:48:00+03	34000.00
2FBCDD	2017-08-09 08:36:00+03	30200.00
2FBD0A	2017-08-04 13:58:00+03	12400.00
2FBD26	2017-08-08 03:29:00+03	66600.00
2FBD2B	2017-08-02 23:11:00+03	34000.00
2FBD2D	2017-07-10 03:35:00+03	43400.00
2FBD79	2017-07-09 01:29:00+03	47000.00
2FBD84	2017-07-26 06:37:00+03	29600.00
2FBDE1	2017-08-02 05:45:00+03	133200.00
2FBE42	2017-07-26 05:18:00+03	103500.00
2FBE9B	2017-08-14 09:39:00+03	49700.00
2FBF47	2017-07-23 12:47:00+03	18600.00
2FBF7D	2017-07-12 22:07:00+03	23200.00
2FC159	2017-08-04 15:37:00+03	35300.00
2FC160	2017-07-18 01:28:00+03	29200.00
2FC17A	2017-07-20 18:55:00+03	16400.00
2FC1C3	2017-07-22 00:16:00+03	56700.00
2FC1F0	2017-08-05 12:08:00+03	31100.00
2FC201	2017-07-04 14:37:00+03	155600.00
2FC21F	2017-07-17 13:54:00+03	23200.00
2FC23F	2017-08-05 20:31:00+03	85000.00
2FC264	2017-08-11 15:48:00+03	158100.00
2FC286	2017-07-26 22:15:00+03	55800.00
2FC376	2017-07-17 20:06:00+03	86600.00
2FC3D1	2017-06-29 01:25:00+03	113200.00
2FC41C	2017-07-13 02:29:00+03	6800.00
2FC439	2017-08-08 06:34:00+03	103800.00
2FC499	2017-07-22 13:39:00+03	133200.00
2FC4AE	2017-08-15 04:03:00+03	120100.00
2FC507	2017-07-31 16:52:00+03	62700.00
2FC55D	2017-07-27 22:40:00+03	28800.00
2FC565	2017-07-01 10:57:00+03	6000.00
2FC581	2017-07-09 02:46:00+03	53300.00
2FC59D	2017-07-12 10:02:00+03	27000.00
2FC5A2	2017-07-03 14:54:00+03	87900.00
2FC5C5	2017-07-25 09:31:00+03	224000.00
2FC5CF	2017-07-30 11:17:00+03	6800.00
2FC5D2	2017-07-08 05:40:00+03	228900.00
2FC5EC	2017-08-03 23:22:00+03	24400.00
2FC602	2017-07-16 22:50:00+03	26700.00
2FC646	2017-07-11 09:47:00+03	94000.00
2FC719	2017-07-24 06:18:00+03	68000.00
2FC726	2017-08-05 21:59:00+03	54000.00
2FC75C	2017-07-12 17:33:00+03	42800.00
2FC761	2017-07-22 23:18:00+03	56000.00
2FC79F	2017-08-11 03:25:00+03	73300.00
2FC807	2017-07-15 11:59:00+03	71200.00
2FC8FB	2017-07-10 07:17:00+03	24400.00
2FC906	2017-07-25 15:33:00+03	133200.00
2FC982	2017-07-22 17:46:00+03	41400.00
2FC9B2	2017-07-16 09:42:00+03	6700.00
2FCA04	2017-07-02 05:15:00+03	217600.00
2FCA92	2017-06-28 22:02:00+03	23200.00
2FCA9C	2017-07-27 22:18:00+03	16400.00
2FCACD	2017-08-12 14:20:00+03	267800.00
2FCADD	2017-07-07 15:40:00+03	55800.00
2FCAE4	2017-07-02 21:19:00+03	46000.00
2FCB2A	2017-08-01 04:30:00+03	7400.00
2FCB59	2017-08-12 13:47:00+03	81600.00
2FCB5A	2017-07-10 05:49:00+03	34400.00
2FCB66	2017-08-11 15:39:00+03	93900.00
2FCBA0	2017-07-26 04:56:00+03	68800.00
2FCC10	2017-07-11 04:57:00+03	32800.00
2FCC43	2017-07-26 22:02:00+03	65600.00
2FCD1C	2017-07-10 20:07:00+03	65400.00
2FCD7A	2017-08-03 22:15:00+03	114800.00
2FCD92	2017-06-27 16:40:00+03	98400.00
2FCE51	2017-08-04 09:15:00+03	21800.00
2FCE5A	2017-08-11 08:29:00+03	174000.00
2FCE8A	2017-07-28 13:03:00+03	26000.00
2FCEC3	2017-07-06 23:15:00+03	31600.00
2FCFE0	2017-07-14 08:12:00+03	13400.00
2FD01C	2017-07-10 01:23:00+03	111700.00
2FD151	2017-08-04 05:08:00+03	56000.00
2FD171	2017-08-14 12:21:00+03	85000.00
2FD1B9	2017-07-04 16:16:00+03	7400.00
2FD1FD	2017-07-05 09:30:00+03	12600.00
2FD21A	2017-07-20 10:52:00+03	49100.00
2FD23F	2017-07-27 04:41:00+03	94300.00
2FD273	2017-08-13 18:58:00+03	532800.00
2FD2CC	2017-08-13 15:15:00+03	136200.00
2FD2E5	2017-07-06 19:35:00+03	799200.00
2FD311	2017-07-27 00:10:00+03	106600.00
2FD333	2017-07-03 23:15:00+03	68000.00
2FD351	2017-07-10 09:59:00+03	118000.00
2FD356	2017-08-13 20:01:00+03	62600.00
2FD365	2017-07-24 01:58:00+03	113000.00
2FD3AB	2017-07-07 02:20:00+03	43600.00
2FD468	2017-07-25 19:48:00+03	23200.00
2FD46F	2017-08-03 03:37:00+03	47000.00
2FD485	2017-07-10 16:43:00+03	29400.00
2FD492	2017-07-05 22:20:00+03	61700.00
2FD49C	2017-08-08 00:55:00+03	52000.00
2FD507	2017-07-14 10:57:00+03	88600.00
2FD518	2017-08-13 13:27:00+03	58000.00
2FD520	2017-08-06 06:02:00+03	101200.00
2FD522	2017-07-12 23:52:00+03	6700.00
2FD532	2017-08-05 14:10:00+03	14000.00
2FD644	2017-07-10 16:14:00+03	23200.00
2FD6B0	2017-08-02 16:47:00+03	102100.00
2FD727	2017-07-12 15:33:00+03	387300.00
2FD731	2017-07-07 02:51:00+03	246000.00
2FD756	2017-07-25 09:43:00+03	46400.00
2FD775	2017-07-26 06:09:00+03	29500.00
2FD777	2017-08-09 15:50:00+03	13800.00
2FD780	2017-07-06 19:29:00+03	88400.00
2FD7DB	2017-08-11 06:49:00+03	56000.00
2FD7EB	2017-08-13 18:15:00+03	84500.00
2FD91E	2017-07-14 14:08:00+03	81700.00
2FD9A9	2017-07-30 08:59:00+03	46400.00
2FD9C6	2017-07-18 14:36:00+03	286500.00
2FD9E6	2017-07-24 00:51:00+03	112000.00
2FDA45	2017-07-05 22:38:00+03	69000.00
2FDA6B	2017-08-05 02:35:00+03	260300.00
2FDB38	2017-07-12 07:50:00+03	28800.00
2FDB76	2017-08-14 22:45:00+03	36600.00
2FDB83	2017-07-31 01:18:00+03	8200.00
2FDB95	2017-07-30 10:10:00+03	24000.00
2FDBD3	2017-07-07 16:23:00+03	28800.00
2FDC26	2017-08-10 06:31:00+03	6300.00
2FDC3D	2017-07-30 21:56:00+03	16400.00
2FDC45	2017-07-28 06:39:00+03	142400.00
2FDC4D	2017-08-10 12:46:00+03	65300.00
2FDC72	2017-08-10 23:12:00+03	54800.00
2FDC9B	2017-08-13 10:13:00+03	266400.00
2FDCA4	2017-07-18 08:51:00+03	46800.00
2FDCAC	2017-07-08 04:44:00+03	43000.00
2FDCC0	2017-08-06 00:16:00+03	47400.00
2FDCD9	2017-07-31 01:08:00+03	28800.00
2FDCE6	2017-08-08 00:23:00+03	67600.00
2FDD10	2017-07-11 10:21:00+03	21000.00
2FDD51	2017-07-17 19:43:00+03	26000.00
2FDDD3	2017-07-05 00:19:00+03	16400.00
2FDDF9	2017-07-25 15:16:00+03	58900.00
2FDE32	2017-07-28 20:01:00+03	66600.00
2FDE8F	2017-08-01 19:21:00+03	51900.00
2FDE99	2017-08-04 07:56:00+03	187800.00
2FDED4	2017-08-09 17:41:00+03	28800.00
2FDEF3	2017-07-08 18:09:00+03	50600.00
2FDF2A	2017-07-31 20:11:00+03	77000.00
2FE017	2017-08-10 17:54:00+03	46000.00
2FE031	2017-07-11 04:32:00+03	198600.00
2FE08F	2017-07-15 13:25:00+03	40800.00
2FE0AE	2017-07-12 17:05:00+03	29800.00
2FE0BD	2017-08-07 23:35:00+03	40200.00
2FE0EC	2017-07-23 16:59:00+03	38200.00
2FE113	2017-08-09 12:54:00+03	86600.00
2FE11F	2017-07-22 11:11:00+03	21400.00
2FE168	2017-07-25 13:40:00+03	173900.00
2FE179	2017-07-19 09:23:00+03	58700.00
2FE1C0	2017-07-21 23:44:00+03	28800.00
2FE1D8	2017-07-31 13:02:00+03	246000.00
2FE1D9	2017-07-25 10:49:00+03	155300.00
2FE22B	2017-08-13 22:35:00+03	135400.00
2FE230	2017-07-22 07:24:00+03	29800.00
2FE25F	2017-08-08 08:13:00+03	25400.00
2FE262	2017-08-02 06:57:00+03	66000.00
2FE2B5	2017-08-08 10:37:00+03	86400.00
2FE2CA	2017-08-02 00:07:00+03	75600.00
2FE306	2017-07-06 20:48:00+03	27800.00
2FE308	2017-07-18 12:04:00+03	46400.00
2FE309	2017-07-05 21:26:00+03	205600.00
2FE30D	2017-07-24 19:28:00+03	24400.00
2FE391	2017-06-30 04:17:00+03	24400.00
2FE3A5	2017-07-22 15:21:00+03	8200.00
2FE3F3	2017-07-05 23:49:00+03	43600.00
2FE471	2017-08-12 17:28:00+03	265700.00
2FE477	2017-07-14 13:27:00+03	28800.00
2FE4B1	2017-08-01 00:15:00+03	378700.00
2FE4CF	2017-07-09 18:49:00+03	58400.00
2FE530	2017-07-22 22:16:00+03	62600.00
2FE5A3	2017-08-08 17:39:00+03	168000.00
2FE5BD	2017-08-02 14:08:00+03	23200.00
2FE5C7	2017-08-10 17:08:00+03	53700.00
2FE605	2017-07-23 06:39:00+03	57800.00
2FE60E	2017-07-22 00:38:00+03	64600.00
2FE631	2017-07-16 14:29:00+03	53100.00
2FE648	2017-07-11 14:27:00+03	44600.00
2FE65C	2017-08-15 09:02:00+03	23200.00
2FE673	2017-07-31 23:56:00+03	86800.00
2FE68F	2017-07-27 02:11:00+03	57800.00
2FE6BA	2017-08-01 00:22:00+03	69600.00
2FE6CA	2017-07-10 02:46:00+03	16400.00
2FE6D0	2017-07-21 01:55:00+03	36200.00
2FE6FF	2017-08-10 18:15:00+03	99300.00
2FE712	2017-08-04 16:18:00+03	32700.00
2FE71C	2017-07-30 16:35:00+03	113600.00
2FE71D	2017-07-18 19:07:00+03	47200.00
2FE726	2017-07-03 09:46:00+03	54500.00
2FE752	2017-07-18 01:45:00+03	55800.00
2FE793	2017-07-17 07:34:00+03	56200.00
2FE7D6	2017-07-07 05:47:00+03	43500.00
2FE7DD	2017-08-14 08:49:00+03	111600.00
2FE804	2017-07-21 10:06:00+03	47000.00
2FE822	2017-07-12 19:31:00+03	40000.00
2FE84E	2017-07-12 12:53:00+03	70600.00
2FE85E	2017-07-11 01:45:00+03	12000.00
2FE87E	2017-07-19 17:39:00+03	265700.00
2FE8AB	2017-07-03 11:34:00+03	105600.00
2FE8B5	2017-08-15 11:30:00+03	50600.00
2FE8BF	2017-07-16 18:32:00+03	35400.00
2FE90A	2017-07-29 22:30:00+03	90200.00
2FE90B	2017-08-01 23:07:00+03	39200.00
2FE940	2017-07-25 20:34:00+03	32800.00
2FE9A2	2017-07-17 12:19:00+03	46200.00
2FE9AA	2017-07-15 23:11:00+03	29600.00
2FE9C2	2017-08-15 06:02:00+03	23200.00
2FE9C8	2017-07-08 18:48:00+03	70800.00
2FEA41	2017-07-18 04:25:00+03	23200.00
2FEA5B	2017-07-17 05:14:00+03	82600.00
2FEA81	2017-07-03 12:07:00+03	135200.00
2FEAC6	2017-07-17 03:39:00+03	50600.00
2FEAEC	2017-07-09 14:13:00+03	117600.00
2FEB40	2017-08-12 16:28:00+03	23400.00
2FEB82	2017-08-07 23:33:00+03	46000.00
2FEBA9	2017-07-31 06:17:00+03	28800.00
2FEBE2	2017-08-15 02:33:00+03	56600.00
2FEBF8	2017-07-30 10:02:00+03	119500.00
2FEC0D	2017-08-10 18:12:00+03	28000.00
2FEC4C	2017-07-04 20:49:00+03	44000.00
2FED31	2017-07-14 01:53:00+03	94800.00
2FED67	2017-08-10 20:41:00+03	47100.00
2FED6F	2017-08-02 09:31:00+03	53500.00
2FEDDC	2017-08-02 03:10:00+03	28800.00
2FEDF5	2017-08-07 01:46:00+03	58000.00
2FEE26	2017-07-03 04:17:00+03	25000.00
2FEE99	2017-06-30 15:48:00+03	28000.00
2FEED6	2017-08-14 21:10:00+03	21800.00
2FEED8	2017-07-01 09:08:00+03	406700.00
2FEEF9	2017-07-15 00:52:00+03	44000.00
2FEF1B	2017-07-12 11:59:00+03	16400.00
2FEF3B	2017-07-10 00:09:00+03	246000.00
2FEF62	2017-07-19 16:23:00+03	23200.00
2FEF6B	2017-08-10 15:22:00+03	54100.00
2FEF71	2017-08-04 14:13:00+03	233100.00
2FF077	2017-07-18 07:44:00+03	135600.00
2FF096	2017-08-02 00:05:00+03	68100.00
2FF0A3	2017-07-16 12:46:00+03	27900.00
2FF0FF	2017-08-09 22:25:00+03	92800.00
2FF1CD	2017-07-10 03:37:00+03	44000.00
2FF224	2017-08-12 19:04:00+03	35300.00
2FF30D	2017-07-17 20:56:00+03	25800.00
2FF35A	2017-07-27 07:07:00+03	74400.00
2FF3CE	2017-08-12 23:11:00+03	134400.00
2FF4D9	2017-07-08 21:39:00+03	102300.00
2FF543	2017-07-23 12:00:00+03	48800.00
2FF583	2017-06-29 03:44:00+03	23600.00
2FF5CF	2017-08-02 11:22:00+03	14000.00
2FF5EF	2017-08-03 01:27:00+03	137600.00
2FF60F	2017-08-15 00:43:00+03	52400.00
2FF63C	2017-07-13 14:09:00+03	25100.00
2FF6A0	2017-07-04 22:43:00+03	6000.00
2FF6C8	2017-08-12 08:38:00+03	18000.00
2FF6DF	2017-08-06 07:30:00+03	102000.00
2FF7D7	2017-07-11 08:19:00+03	33300.00
2FF7F0	2017-07-19 05:54:00+03	62100.00
2FF813	2017-08-08 17:45:00+03	23200.00
2FF8AB	2017-08-11 20:03:00+03	94000.00
2FF8D2	2017-07-11 08:07:00+03	81300.00
2FF8E4	2017-07-14 22:31:00+03	14000.00
2FFA17	2017-07-08 12:25:00+03	86800.00
2FFA3B	2017-07-25 15:23:00+03	29400.00
2FFA3D	2017-08-13 10:34:00+03	36500.00
2FFAC0	2017-07-25 10:12:00+03	37200.00
2FFAC7	2017-07-11 08:59:00+03	30600.00
2FFACB	2017-07-01 14:18:00+03	43900.00
2FFAFA	2017-08-09 04:07:00+03	35600.00
2FFB03	2017-08-05 17:54:00+03	47500.00
2FFB50	2017-08-01 23:31:00+03	29600.00
2FFB5B	2017-08-05 11:41:00+03	40800.00
2FFBCC	2017-07-11 12:51:00+03	96300.00
2FFC32	2017-07-03 00:53:00+03	111600.00
2FFC47	2017-08-14 06:03:00+03	41300.00
2FFC90	2017-07-08 20:47:00+03	79900.00
2FFCA0	2017-07-15 15:19:00+03	57400.00
2FFCA1	2017-08-15 02:23:00+03	53300.00
2FFCC8	2017-08-01 07:48:00+03	67200.00
2FFCDD	2017-07-27 02:20:00+03	64700.00
2FFD17	2017-07-12 10:08:00+03	232800.00
2FFD4A	2017-07-07 01:35:00+03	28800.00
2FFE12	2017-07-30 19:33:00+03	71900.00
2FFE8B	2017-08-09 13:35:00+03	56000.00
2FFEA3	2017-08-02 02:54:00+03	14400.00
2FFEAD	2017-07-04 11:53:00+03	51900.00
2FFED7	2017-07-20 15:38:00+03	68400.00
2FFEF8	2017-06-30 03:15:00+03	22400.00
2FFF0F	2017-07-24 18:50:00+03	399200.00
2FFF29	2017-07-31 02:55:00+03	63800.00
2FFF7E	2017-07-09 23:11:00+03	52800.00
2FFF91	2017-08-04 00:14:00+03	135400.00
300009	2017-08-03 04:41:00+03	56000.00
3000B5	2017-07-29 14:04:00+03	88000.00
3000C5	2017-08-02 22:20:00+03	30700.00
3000DC	2017-07-30 06:49:00+03	54000.00
3000E9	2017-07-11 05:21:00+03	27800.00
30013D	2017-08-15 01:44:00+03	26700.00
3001F0	2017-07-23 05:10:00+03	51200.00
300283	2017-07-21 08:11:00+03	8200.00
300319	2017-07-04 20:03:00+03	115700.00
300392	2017-08-14 19:38:00+03	199200.00
300397	2017-07-04 07:57:00+03	50600.00
3003E1	2017-07-13 08:16:00+03	92800.00
300408	2017-07-17 04:35:00+03	110300.00
300490	2017-08-06 20:30:00+03	48800.00
3004A2	2017-07-10 12:48:00+03	83000.00
3004C1	2017-08-04 07:40:00+03	93000.00
3004C2	2017-07-19 15:47:00+03	89600.00
3005D6	2017-08-10 03:35:00+03	8000.00
3005E5	2017-08-07 02:33:00+03	135600.00
300688	2017-08-02 21:46:00+03	96400.00
30068C	2017-08-14 05:35:00+03	12000.00
3006E1	2017-08-01 18:20:00+03	372600.00
3006F3	2017-07-04 12:02:00+03	67100.00
300732	2017-08-15 09:55:00+03	59600.00
30077B	2017-07-15 15:21:00+03	144300.00
3007C8	2017-07-10 03:22:00+03	116400.00
300843	2017-08-13 11:30:00+03	40600.00
3008A3	2017-08-14 01:04:00+03	18600.00
3008C0	2017-07-29 16:36:00+03	31000.00
3008E4	2017-07-07 22:58:00+03	59800.00
30097F	2017-07-12 12:16:00+03	27200.00
3009D3	2017-07-28 01:59:00+03	244600.00
300A18	2017-08-11 16:48:00+03	80000.00
300A4C	2017-07-06 05:10:00+03	62600.00
300A4E	2017-07-23 05:50:00+03	135400.00
300AE8	2017-07-02 20:52:00+03	49400.00
300AF5	2017-07-11 14:41:00+03	64700.00
300B13	2017-08-03 13:52:00+03	169600.00
300B42	2017-07-21 20:22:00+03	38600.00
300B53	2017-07-28 07:38:00+03	77200.00
300C09	2017-07-28 02:44:00+03	12400.00
300C3F	2017-07-19 02:49:00+03	55800.00
300C5E	2017-07-18 04:43:00+03	88300.00
300CF1	2017-08-04 22:46:00+03	131100.00
300DAC	2017-08-03 15:15:00+03	21000.00
300DD7	2017-07-22 16:33:00+03	73600.00
300E0E	2017-07-30 11:10:00+03	55800.00
300E56	2017-08-14 03:35:00+03	100600.00
300E74	2017-07-15 05:15:00+03	26000.00
300F0E	2017-07-25 05:30:00+03	52000.00
300F1F	2017-08-11 18:39:00+03	59200.00
300F4D	2017-08-04 20:53:00+03	69400.00
300F89	2017-07-11 10:05:00+03	31600.00
30102E	2017-08-14 23:28:00+03	140900.00
30103C	2017-07-13 12:23:00+03	119500.00
301081	2017-08-06 18:23:00+03	123000.00
301135	2017-08-03 10:05:00+03	12000.00
3011C6	2017-07-25 04:43:00+03	52300.00
3011D4	2017-08-02 07:27:00+03	125600.00
3011F9	2017-07-07 12:30:00+03	132800.00
30123F	2017-07-28 11:35:00+03	101200.00
30124B	2017-08-06 22:16:00+03	59400.00
301288	2017-07-30 17:04:00+03	64800.00
301316	2017-07-30 09:16:00+03	13600.00
301319	2017-07-31 06:22:00+03	24400.00
3013A8	2017-07-09 16:42:00+03	33800.00
3013B5	2017-07-16 04:42:00+03	136200.00
3013C0	2017-07-15 16:19:00+03	246000.00
3013D1	2017-08-05 15:12:00+03	113200.00
3013D6	2017-07-11 07:23:00+03	266400.00
301472	2017-07-22 18:26:00+03	41600.00
3014B7	2017-07-13 06:31:00+03	55800.00
3014E1	2017-08-04 09:43:00+03	44000.00
3015A9	2017-08-08 11:06:00+03	79900.00
3015DA	2017-07-24 19:55:00+03	48800.00
3015EE	2017-07-17 00:06:00+03	56000.00
301619	2017-08-15 13:22:00+03	46700.00
301657	2017-07-25 20:16:00+03	167400.00
301674	2017-08-11 07:41:00+03	273000.00
3016C6	2017-07-10 12:35:00+03	112000.00
301745	2017-07-18 13:18:00+03	35200.00
30176F	2017-07-13 00:25:00+03	162400.00
3017A4	2017-07-12 23:59:00+03	57200.00
3017BC	2017-07-03 19:17:00+03	303500.00
3017E9	2017-07-01 10:07:00+03	6200.00
301886	2017-07-17 20:04:00+03	32800.00
301898	2017-08-08 00:56:00+03	297300.00
3018D9	2017-07-12 10:31:00+03	43600.00
3018FE	2017-07-07 15:42:00+03	62600.00
301918	2017-07-14 19:42:00+03	149300.00
301981	2017-07-15 18:20:00+03	12600.00
3019CE	2017-08-09 04:15:00+03	99300.00
301A12	2017-07-03 10:40:00+03	54400.00
301A16	2017-07-10 09:55:00+03	78800.00
301A34	2017-07-12 09:58:00+03	46000.00
301A53	2017-07-10 13:47:00+03	26600.00
301A55	2017-07-03 09:46:00+03	116400.00
301A9D	2017-07-16 07:16:00+03	135600.00
301ADA	2017-07-28 08:46:00+03	46400.00
301ADC	2017-08-05 23:57:00+03	93900.00
301B8E	2017-08-01 00:34:00+03	70700.00
301BE4	2017-08-06 21:29:00+03	16400.00
301C1C	2017-08-14 23:33:00+03	64700.00
301C67	2017-07-30 06:30:00+03	207000.00
301CF1	2017-08-13 17:40:00+03	20800.00
301D30	2017-07-29 14:44:00+03	136200.00
301D6D	2017-07-23 21:51:00+03	47400.00
301D76	2017-07-26 21:27:00+03	98400.00
301DA1	2017-08-13 18:07:00+03	205000.00
301DFE	2017-07-12 16:24:00+03	29400.00
301EFD	2017-07-12 04:06:00+03	46400.00
301F1A	2017-07-19 17:41:00+03	11000.00
301F25	2017-07-13 06:04:00+03	23600.00
301F68	2017-07-13 11:49:00+03	27400.00
301F71	2017-08-08 12:39:00+03	103200.00
302003	2017-08-14 22:17:00+03	105600.00
30204B	2017-07-11 12:30:00+03	80700.00
302066	2017-08-09 03:21:00+03	48900.00
302095	2017-07-24 14:57:00+03	12200.00
30209C	2017-07-03 06:59:00+03	89600.00
3020BA	2017-07-22 23:24:00+03	55800.00
3020C2	2017-07-21 01:55:00+03	7300.00
3020CE	2017-07-14 05:30:00+03	59200.00
3020D8	2017-08-14 01:22:00+03	28000.00
3020EE	2017-07-01 15:07:00+03	280000.00
302147	2017-08-03 06:41:00+03	21800.00
3021DA	2017-07-28 09:48:00+03	34600.00
302216	2017-07-16 08:33:00+03	167400.00
302282	2017-07-01 04:09:00+03	65300.00
302288	2017-07-09 18:39:00+03	47600.00
3022A6	2017-08-07 05:37:00+03	85000.00
30233D	2017-08-07 05:08:00+03	64100.00
30235D	2017-07-26 13:55:00+03	122800.00
30236A	2017-07-08 09:59:00+03	113200.00
3023D3	2017-08-04 01:13:00+03	29600.00
3023EE	2017-08-08 11:22:00+03	52300.00
3023F2	2017-07-09 17:10:00+03	47100.00
302451	2017-07-19 21:41:00+03	24400.00
3024DC	2017-07-11 04:33:00+03	47500.00
3024E6	2017-08-09 20:33:00+03	48500.00
302538	2017-07-09 22:38:00+03	60400.00
302540	2017-06-28 14:29:00+03	9800.00
3025A3	2017-07-10 20:40:00+03	58800.00
3025A8	2017-08-07 21:16:00+03	34700.00
3025F4	2017-08-02 15:46:00+03	191200.00
30264F	2017-07-12 16:26:00+03	170500.00
302685	2017-08-04 14:18:00+03	353100.00
3026A1	2017-07-13 10:02:00+03	56600.00
3026AE	2017-07-10 15:21:00+03	15800.00
3026C2	2017-06-27 09:08:00+03	101200.00
3026C8	2017-08-04 00:18:00+03	71100.00
3026E5	2017-07-12 22:57:00+03	271200.00
30271B	2017-08-03 06:33:00+03	83400.00
30272B	2017-07-05 02:12:00+03	57200.00
302771	2017-08-11 01:49:00+03	46000.00
302773	2017-07-28 06:11:00+03	181100.00
3027B0	2017-07-31 16:54:00+03	92800.00
3027C3	2017-08-13 07:13:00+03	42800.00
3027C6	2017-07-01 13:49:00+03	68100.00
3027C9	2017-07-02 23:41:00+03	24800.00
3028C0	2017-07-25 10:40:00+03	12600.00
3028EF	2017-08-07 13:52:00+03	92400.00
3029AB	2017-07-03 06:17:00+03	53300.00
3029E3	2017-08-05 14:40:00+03	36200.00
302A27	2017-07-15 15:32:00+03	68100.00
302A4B	2017-07-19 18:17:00+03	53200.00
302A65	2017-07-24 10:23:00+03	6700.00
302AC8	2017-08-15 13:14:00+03	115100.00
302B22	2017-08-13 00:56:00+03	111600.00
302B41	2017-07-30 15:06:00+03	516000.00
302B51	2017-08-07 11:06:00+03	52600.00
302B66	2017-07-15 05:57:00+03	99300.00
302B78	2017-08-12 16:41:00+03	110500.00
302B79	2017-08-14 08:48:00+03	82900.00
302B8D	2017-08-08 14:17:00+03	62600.00
302BC1	2017-07-16 12:47:00+03	26800.00
302C12	2017-07-24 04:03:00+03	76100.00
302CA0	2017-07-10 10:26:00+03	6700.00
302CD1	2017-07-17 18:44:00+03	148200.00
302D26	2017-08-14 06:54:00+03	28000.00
302D72	2017-07-22 11:05:00+03	21000.00
302DEC	2017-08-03 23:13:00+03	31600.00
302DFE	2017-07-14 14:35:00+03	61400.00
302E09	2017-07-11 14:39:00+03	135600.00
302E5A	2017-07-13 17:08:00+03	28000.00
302E73	2017-07-31 15:05:00+03	60400.00
302EF7	2017-08-05 09:07:00+03	26000.00
302EF9	2017-07-19 09:54:00+03	313800.00
302F36	2017-08-13 01:51:00+03	28000.00
302F66	2017-07-21 14:49:00+03	89700.00
302F90	2017-07-25 23:17:00+03	246000.00
302FF6	2017-08-07 03:35:00+03	141400.00
303006	2017-08-10 16:33:00+03	34000.00
303055	2017-07-04 04:44:00+03	134700.00
303063	2017-08-03 11:34:00+03	44000.00
3030AE	2017-07-21 23:07:00+03	28800.00
3030D2	2017-07-25 19:08:00+03	67000.00
30310F	2017-07-19 11:07:00+03	56000.00
30322F	2017-07-13 09:05:00+03	147600.00
303293	2017-08-03 06:34:00+03	79200.00
30329E	2017-08-15 14:46:00+03	88900.00
303334	2017-08-08 12:41:00+03	119400.00
303350	2017-08-02 18:02:00+03	119600.00
3033A8	2017-08-02 05:16:00+03	75300.00
3033E4	2017-07-10 08:59:00+03	70200.00
303440	2017-08-15 02:04:00+03	53200.00
303476	2017-07-09 04:35:00+03	121400.00
303488	2017-07-31 13:12:00+03	54800.00
30349A	2017-07-05 22:40:00+03	198400.00
3034E8	2017-08-01 19:38:00+03	62400.00
303503	2017-08-13 10:04:00+03	15800.00
303533	2017-06-28 15:45:00+03	40600.00
30357B	2017-07-19 16:06:00+03	46000.00
303588	2017-08-08 20:57:00+03	114800.00
3035BD	2017-07-29 14:26:00+03	119600.00
3035E8	2017-07-03 09:23:00+03	67600.00
30363C	2017-08-07 22:41:00+03	50100.00
3036D4	2017-07-14 08:37:00+03	69500.00
3036F2	2017-08-04 16:34:00+03	64800.00
3037EB	2017-07-29 19:52:00+03	13400.00
303859	2017-08-04 12:17:00+03	26000.00
30386C	2017-08-12 19:49:00+03	61800.00
303881	2017-07-01 05:05:00+03	55800.00
303889	2017-07-18 10:33:00+03	189200.00
3038D2	2017-07-01 22:16:00+03	192700.00
3038F5	2017-07-05 12:01:00+03	26000.00
303900	2017-07-10 13:52:00+03	33600.00
30390A	2017-07-20 14:39:00+03	46000.00
30391A	2017-07-28 18:06:00+03	24400.00
303929	2017-08-14 00:47:00+03	132800.00
303941	2017-07-12 03:39:00+03	272300.00
303981	2017-07-06 06:24:00+03	14400.00
303989	2017-07-26 01:08:00+03	46400.00
303A21	2017-08-04 06:50:00+03	119700.00
303A42	2017-08-02 19:23:00+03	43500.00
303A5E	2017-07-09 05:24:00+03	6000.00
303A6D	2017-07-15 01:53:00+03	131100.00
303A94	2017-07-20 16:23:00+03	136800.00
303A9F	2017-07-05 23:08:00+03	43600.00
303ABD	2017-08-07 21:31:00+03	207300.00
303AD8	2017-07-13 02:21:00+03	167400.00
303AEA	2017-07-17 19:27:00+03	28800.00
303B06	2017-07-19 10:06:00+03	273000.00
303B38	2017-07-22 19:37:00+03	6200.00
303B9C	2017-07-27 13:40:00+03	23200.00
303BA9	2017-07-21 00:24:00+03	156400.00
303BDA	2017-07-05 20:13:00+03	8000.00
303BE1	2017-08-08 21:09:00+03	52000.00
303C49	2017-07-09 09:09:00+03	26700.00
303C54	2017-07-29 10:02:00+03	30000.00
303C65	2017-07-23 02:18:00+03	12600.00
303CDC	2017-07-15 07:32:00+03	261500.00
303D31	2017-07-14 02:47:00+03	31600.00
303D6B	2017-08-05 03:53:00+03	272400.00
303DB2	2017-07-16 19:50:00+03	62000.00
303E3B	2017-07-10 11:04:00+03	44800.00
303E93	2017-08-12 01:56:00+03	23600.00
303EA0	2017-08-11 04:26:00+03	43200.00
303EAE	2017-07-11 06:33:00+03	94800.00
303EB3	2017-08-07 21:49:00+03	58000.00
303EEA	2017-07-30 12:03:00+03	80400.00
303EF5	2017-07-22 09:55:00+03	23400.00
303F6F	2017-07-25 10:15:00+03	123000.00
303FEC	2017-07-30 14:41:00+03	50700.00
303FEE	2017-08-05 16:23:00+03	47400.00
303FF3	2017-07-01 17:52:00+03	79800.00
30403A	2017-06-26 06:21:00+03	27200.00
30409B	2017-07-07 22:01:00+03	51900.00
30419A	2017-07-22 03:06:00+03	56600.00
3041A2	2017-07-09 08:16:00+03	65400.00
3041B0	2017-07-06 12:07:00+03	167200.00
304266	2017-07-24 16:06:00+03	47400.00
3042E3	2017-08-05 03:03:00+03	27200.00
304305	2017-07-03 00:22:00+03	174900.00
304338	2017-08-10 17:41:00+03	51800.00
304345	2017-08-08 05:40:00+03	64700.00
304361	2017-07-03 18:23:00+03	85700.00
304377	2017-07-11 00:10:00+03	14000.00
3043BA	2017-07-21 05:20:00+03	250800.00
304400	2017-08-02 19:40:00+03	135600.00
304425	2017-07-09 11:39:00+03	43600.00
3044E8	2017-08-14 06:18:00+03	206700.00
304526	2017-06-28 15:28:00+03	47500.00
304545	2017-08-13 19:37:00+03	12600.00
3045E3	2017-07-27 13:20:00+03	46400.00
304622	2017-07-08 08:47:00+03	64500.00
30468A	2017-08-10 13:17:00+03	88900.00
304699	2017-08-07 19:07:00+03	153300.00
3046B1	2017-07-11 13:21:00+03	152900.00
3046BF	2017-08-08 04:23:00+03	153300.00
3046C1	2017-07-16 05:39:00+03	135400.00
3046E8	2017-07-20 12:31:00+03	117700.00
304729	2017-08-06 02:19:00+03	111600.00
304732	2017-08-15 16:46:00+03	37700.00
30475E	2017-07-05 14:03:00+03	23600.00
304779	2017-07-01 14:20:00+03	66600.00
304798	2017-08-08 04:22:00+03	155600.00
3047C0	2017-07-02 15:34:00+03	50800.00
3047DA	2017-07-31 07:07:00+03	181600.00
304849	2017-07-13 10:28:00+03	26800.00
304873	2017-07-07 01:09:00+03	29200.00
3048D9	2017-07-12 09:59:00+03	22000.00
30498F	2017-08-15 13:30:00+03	102000.00
304A05	2017-07-02 03:50:00+03	94200.00
304B69	2017-08-11 05:37:00+03	76800.00
304B75	2017-07-14 08:10:00+03	59200.00
304C43	2017-07-25 12:45:00+03	39200.00
304C77	2017-07-28 07:47:00+03	44100.00
304C8D	2017-07-02 10:49:00+03	32800.00
304CF0	2017-08-10 22:11:00+03	271400.00
304D0E	2017-07-21 08:45:00+03	62100.00
304D13	2017-07-16 00:41:00+03	55800.00
304D41	2017-07-24 08:57:00+03	112000.00
304E9F	2017-07-20 14:44:00+03	95600.00
304F18	2017-08-14 09:01:00+03	48500.00
304F65	2017-07-10 12:15:00+03	28600.00
304FE4	2017-07-05 02:07:00+03	73400.00
305003	2017-07-06 22:48:00+03	87100.00
305004	2017-07-17 10:48:00+03	28000.00
305013	2017-07-13 08:58:00+03	339900.00
305027	2017-07-22 04:08:00+03	29600.00
305052	2017-07-28 21:19:00+03	78200.00
305082	2017-07-31 06:05:00+03	166100.00
30508F	2017-08-02 13:01:00+03	108900.00
3050B2	2017-08-10 12:14:00+03	116800.00
3050F0	2017-08-10 16:49:00+03	51600.00
30511C	2017-07-31 20:45:00+03	246000.00
30518E	2017-07-23 01:28:00+03	14400.00
305209	2017-07-11 23:08:00+03	169200.00
30523E	2017-07-08 20:57:00+03	102100.00
305251	2017-07-07 23:24:00+03	44800.00
305277	2017-07-11 21:53:00+03	59300.00
3052A8	2017-08-08 02:52:00+03	135400.00
3052BA	2017-08-11 04:21:00+03	188900.00
3052C0	2017-08-05 17:24:00+03	26800.00
3052FD	2017-07-01 16:11:00+03	184100.00
305333	2017-06-29 07:24:00+03	406200.00
30533B	2017-08-01 06:22:00+03	29600.00
305382	2017-08-05 14:23:00+03	51800.00
3053F0	2017-08-15 09:02:00+03	38600.00
30542C	2017-07-15 20:41:00+03	18000.00
30542E	2017-07-04 17:29:00+03	28800.00
3054F7	2017-07-14 07:18:00+03	34000.00
30557E	2017-08-12 14:50:00+03	57700.00
3055A7	2017-08-07 02:23:00+03	37100.00
3055DB	2017-07-14 11:23:00+03	28800.00
3055DD	2017-07-12 03:07:00+03	77900.00
3055F6	2017-08-06 00:01:00+03	46200.00
305641	2017-07-30 19:25:00+03	46700.00
305655	2017-08-12 21:52:00+03	39500.00
3056A5	2017-07-25 04:47:00+03	25800.00
305704	2017-07-11 11:23:00+03	28000.00
305716	2017-08-15 15:55:00+03	142300.00
30574F	2017-07-05 13:56:00+03	21000.00
30576E	2017-08-03 03:20:00+03	57800.00
30577C	2017-08-11 19:40:00+03	79700.00
3057B4	2017-08-12 13:24:00+03	28000.00
30589B	2017-08-15 03:06:00+03	89700.00
3058B1	2017-08-05 00:01:00+03	69600.00
3058ED	2017-08-01 22:33:00+03	11600.00
305915	2017-07-01 20:39:00+03	55400.00
3059D2	2017-07-03 21:09:00+03	73000.00
305A22	2017-07-29 02:41:00+03	29400.00
305A28	2017-07-27 16:20:00+03	203400.00
305A4B	2017-07-13 13:10:00+03	271100.00
305A5D	2017-07-15 11:45:00+03	37800.00
305A80	2017-06-29 03:02:00+03	33800.00
305AA3	2017-07-06 00:26:00+03	39800.00
305ADF	2017-07-19 23:19:00+03	43400.00
305B1C	2017-07-05 06:03:00+03	79000.00
305B43	2017-07-25 00:05:00+03	34000.00
305BD0	2017-07-19 10:34:00+03	89700.00
305C05	2017-07-14 10:57:00+03	133100.00
305C34	2017-07-11 14:27:00+03	56000.00
305CF5	2017-07-26 09:40:00+03	32800.00
305D21	2017-07-17 16:14:00+03	72600.00
305D38	2017-07-05 16:23:00+03	27200.00
305D73	2017-07-10 22:22:00+03	37000.00
305DBA	2017-08-03 04:48:00+03	65100.00
305DBC	2017-08-03 09:20:00+03	66700.00
305DC2	2017-07-22 15:45:00+03	13200.00
305E11	2017-07-07 14:12:00+03	92400.00
305E3E	2017-08-11 14:15:00+03	61900.00
305E69	2017-08-12 10:33:00+03	133900.00
305E86	2017-07-23 00:35:00+03	28800.00
305E8D	2017-07-27 12:37:00+03	187600.00
305ECC	2017-07-25 13:51:00+03	75300.00
305ECE	2017-07-28 10:33:00+03	160000.00
305ECF	2017-07-24 15:03:00+03	112000.00
305EE5	2017-07-25 01:07:00+03	27200.00
305EF6	2017-07-05 17:54:00+03	46700.00
305F29	2017-08-11 13:17:00+03	134400.00
305F3B	2017-07-14 05:17:00+03	46200.00
305F77	2017-08-14 03:47:00+03	119300.00
305F87	2017-08-07 11:50:00+03	42700.00
305FAD	2017-07-17 10:37:00+03	87200.00
305FED	2017-07-17 18:25:00+03	35200.00
306002	2017-07-21 02:28:00+03	58600.00
306040	2017-08-08 20:18:00+03	99300.00
306066	2017-07-03 15:56:00+03	24400.00
3060C4	2017-08-09 20:43:00+03	46400.00
3060C6	2017-08-04 16:06:00+03	8200.00
3060E1	2017-07-15 07:40:00+03	79800.00
30614C	2017-07-03 02:54:00+03	65500.00
30614D	2017-08-13 08:58:00+03	46400.00
306179	2017-08-11 04:13:00+03	28000.00
30617E	2017-07-17 11:16:00+03	48300.00
306193	2017-08-08 09:10:00+03	6700.00
3061AF	2017-07-16 00:00:00+03	40600.00
3061B5	2017-08-13 14:23:00+03	24400.00
306235	2017-07-30 09:51:00+03	38800.00
306295	2017-08-07 03:52:00+03	246000.00
306386	2017-08-13 04:55:00+03	25800.00
30639D	2017-07-01 02:25:00+03	167900.00
3063D7	2017-08-09 04:51:00+03	137400.00
3063EA	2017-08-14 17:30:00+03	65300.00
306411	2017-08-03 23:26:00+03	56000.00
306422	2017-08-02 12:00:00+03	44000.00
306432	2017-08-11 10:10:00+03	179500.00
30644A	2017-07-18 13:49:00+03	54500.00
306471	2017-08-05 08:59:00+03	369000.00
30649D	2017-08-12 00:08:00+03	40000.00
3064D1	2017-07-24 04:09:00+03	71300.00
306594	2017-07-18 01:12:00+03	56000.00
3065C9	2017-08-08 03:39:00+03	83300.00
3065F9	2017-07-10 14:47:00+03	115800.00
30661C	2017-06-29 06:41:00+03	55800.00
306650	2017-07-27 06:56:00+03	55800.00
306655	2017-07-27 19:51:00+03	22000.00
306694	2017-07-02 10:04:00+03	16400.00
30669E	2017-08-14 00:06:00+03	56100.00
306715	2017-07-13 03:05:00+03	240600.00
306769	2017-07-31 08:02:00+03	101200.00
3067AA	2017-07-27 00:24:00+03	29200.00
306894	2017-07-26 21:48:00+03	57500.00
30689E	2017-06-30 18:47:00+03	65200.00
3068A0	2017-07-15 19:07:00+03	86600.00
3068B9	2017-07-19 21:45:00+03	47200.00
3068DE	2017-07-14 18:40:00+03	17600.00
306910	2017-08-05 00:03:00+03	30200.00
3069DB	2017-07-11 14:56:00+03	35700.00
3069F3	2017-07-24 15:06:00+03	12400.00
306A29	2017-07-16 05:55:00+03	106400.00
306A2C	2017-07-05 10:19:00+03	103200.00
306A41	2017-07-22 15:32:00+03	23600.00
306A7B	2017-07-20 16:59:00+03	154800.00
306A85	2017-07-07 20:54:00+03	69600.00
306AB4	2017-07-01 03:51:00+03	57600.00
306AC9	2017-08-12 07:36:00+03	29100.00
306B60	2017-07-05 00:12:00+03	62400.00
306BAF	2017-07-27 22:24:00+03	98600.00
306BD9	2017-08-15 03:13:00+03	97700.00
306C55	2017-07-06 02:07:00+03	131100.00
306C7D	2017-08-04 18:58:00+03	58600.00
306C96	2017-07-13 00:23:00+03	29600.00
306CC2	2017-07-10 05:52:00+03	46000.00
306CE7	2017-08-14 13:18:00+03	12000.00
306D2A	2017-07-21 21:24:00+03	86400.00
306D35	2017-07-12 13:25:00+03	96000.00
306D41	2017-07-02 15:41:00+03	96900.00
306DF8	2017-07-17 21:24:00+03	48800.00
306E39	2017-08-06 07:34:00+03	31200.00
306E40	2017-07-29 14:24:00+03	23600.00
306E6C	2017-08-03 00:25:00+03	134400.00
306F25	2017-08-09 03:24:00+03	37900.00
306F48	2017-07-12 22:21:00+03	38500.00
306FBB	2017-08-01 10:55:00+03	74800.00
306FD5	2017-08-03 20:29:00+03	53400.00
306FDB	2017-07-24 03:59:00+03	43100.00
307014	2017-08-09 03:08:00+03	82300.00
30701C	2017-07-04 04:17:00+03	7400.00
30702A	2017-07-27 08:40:00+03	57800.00
30705E	2017-07-04 05:08:00+03	44000.00
30708A	2017-07-20 15:34:00+03	56000.00
3070A8	2017-07-16 20:27:00+03	70600.00
3070B7	2017-07-07 20:27:00+03	57800.00
3070CF	2017-08-14 13:22:00+03	54400.00
3070D7	2017-07-10 11:31:00+03	18000.00
307163	2017-07-21 08:23:00+03	60400.00
3071E8	2017-08-10 19:33:00+03	94300.00
307233	2017-08-03 21:13:00+03	13600.00
307266	2017-07-25 14:30:00+03	92700.00
307269	2017-08-08 17:56:00+03	14000.00
3072A9	2017-08-09 16:28:00+03	45500.00
3072BB	2017-08-09 19:15:00+03	56900.00
3072BD	2017-07-16 18:40:00+03	123900.00
3072D9	2017-08-04 08:21:00+03	45100.00
3072DB	2017-08-11 13:48:00+03	77200.00
307364	2017-07-12 19:53:00+03	25000.00
3073A0	2017-07-30 21:42:00+03	43900.00
3073EB	2017-08-07 14:50:00+03	65900.00
3073FA	2017-08-10 23:17:00+03	29200.00
307401	2017-08-03 12:54:00+03	55800.00
30742F	2017-07-26 10:15:00+03	27200.00
307449	2017-08-06 11:36:00+03	176500.00
307452	2017-08-02 08:06:00+03	51600.00
3074A0	2017-07-04 13:33:00+03	33000.00
307505	2017-07-20 08:26:00+03	56800.00
307568	2017-07-30 19:27:00+03	141100.00
3075BC	2017-07-26 19:35:00+03	58600.00
3075F9	2017-07-20 21:47:00+03	25600.00
30761D	2017-08-08 09:06:00+03	36200.00
307656	2017-08-08 12:44:00+03	40000.00
307699	2017-07-21 10:22:00+03	23200.00
3076DC	2017-07-23 21:03:00+03	57800.00
307749	2017-07-21 12:28:00+03	37000.00
307754	2017-07-01 11:56:00+03	34000.00
30784E	2017-08-13 16:14:00+03	22000.00
307860	2017-06-29 11:54:00+03	48800.00
307889	2017-07-04 14:22:00+03	31600.00
3078C6	2017-08-03 00:21:00+03	72200.00
30792D	2017-07-16 23:48:00+03	65200.00
307936	2017-07-09 10:51:00+03	56000.00
30793D	2017-07-14 13:39:00+03	26000.00
3079CF	2017-07-27 07:16:00+03	66300.00
3079F2	2017-08-09 22:29:00+03	62400.00
307A8C	2017-08-09 05:39:00+03	119600.00
307A92	2017-07-27 17:21:00+03	25600.00
307AEE	2017-08-07 17:42:00+03	6000.00
307AF5	2017-07-21 16:06:00+03	24400.00
307B26	2017-07-04 04:25:00+03	135200.00
307BB7	2017-07-10 01:57:00+03	46400.00
307BBC	2017-07-22 02:13:00+03	8000.00
307BDC	2017-07-27 18:09:00+03	21400.00
307BF2	2017-07-12 16:03:00+03	55800.00
307C20	2017-07-07 02:41:00+03	206400.00
307C4D	2017-07-12 11:53:00+03	60700.00
307CF2	2017-07-26 10:36:00+03	43500.00
307D46	2017-07-09 16:44:00+03	70700.00
307D58	2017-08-01 16:44:00+03	14000.00
307D5E	2017-08-04 16:53:00+03	59200.00
307DF4	2017-08-10 15:46:00+03	137400.00
307E2D	2017-07-09 14:57:00+03	14600.00
307E49	2017-07-31 04:37:00+03	139500.00
307E59	2017-07-12 20:53:00+03	58000.00
307E79	2017-07-18 10:29:00+03	56000.00
307ED0	2017-08-03 15:02:00+03	27200.00
307ED2	2017-07-06 11:41:00+03	135400.00
307EFB	2017-07-11 20:06:00+03	492000.00
307F02	2017-07-27 03:24:00+03	82900.00
307F09	2017-07-20 16:55:00+03	156000.00
307F38	2017-07-10 09:20:00+03	23200.00
307FB7	2017-07-30 10:22:00+03	14700.00
307FEE	2017-07-12 14:09:00+03	24400.00
308019	2017-07-25 00:20:00+03	36100.00
308097	2017-08-13 10:12:00+03	67100.00
3080CA	2017-08-12 17:21:00+03	70700.00
308116	2017-07-20 22:33:00+03	58000.00
308170	2017-07-06 10:10:00+03	14000.00
308192	2017-06-29 11:29:00+03	193500.00
3081AC	2017-07-24 06:05:00+03	66000.00
3081AF	2017-07-08 10:12:00+03	42400.00
308292	2017-07-08 01:56:00+03	77900.00
3082CC	2017-08-07 15:45:00+03	246000.00
308309	2017-07-29 18:14:00+03	283700.00
308317	2017-08-06 04:46:00+03	369000.00
308349	2017-07-15 19:53:00+03	27900.00
30836C	2017-06-29 20:38:00+03	27200.00
3083C5	2017-08-12 20:09:00+03	55800.00
3083DE	2017-07-09 09:24:00+03	188000.00
30841E	2017-08-15 07:39:00+03	27700.00
308422	2017-08-06 04:42:00+03	50600.00
30845D	2017-08-06 07:45:00+03	88600.00
308482	2017-08-08 22:44:00+03	23400.00
3084F3	2017-07-14 20:02:00+03	47500.00
308533	2017-08-15 07:06:00+03	52000.00
3085B0	2017-07-24 15:48:00+03	507100.00
3085C1	2017-08-08 15:53:00+03	68800.00
3085E4	2017-07-30 06:20:00+03	26000.00
308618	2017-07-31 21:17:00+03	44500.00
308682	2017-07-09 06:40:00+03	46300.00
30869B	2017-07-15 13:58:00+03	70000.00
3086C0	2017-07-09 13:56:00+03	69500.00
3086D4	2017-08-14 07:43:00+03	27200.00
30874A	2017-08-13 10:30:00+03	55800.00
3087F3	2017-07-18 10:49:00+03	118900.00
30882D	2017-07-09 20:36:00+03	155600.00
3088EB	2017-07-05 05:30:00+03	40900.00
30892B	2017-08-12 11:34:00+03	99300.00
3089A2	2017-06-30 15:53:00+03	16800.00
308A4A	2017-08-13 15:59:00+03	43200.00
308A4E	2017-07-15 05:42:00+03	148200.00
308A64	2017-08-09 15:17:00+03	82200.00
308AD8	2017-07-30 15:22:00+03	62700.00
308AF0	2017-06-28 17:29:00+03	68400.00
308BA0	2017-07-09 01:30:00+03	56000.00
308BDC	2017-08-03 10:40:00+03	66000.00
308C13	2017-08-08 19:04:00+03	44500.00
308C26	2017-07-29 19:07:00+03	46800.00
308C30	2017-07-07 14:25:00+03	271100.00
308C37	2017-08-02 07:07:00+03	43900.00
308C47	2017-07-05 18:20:00+03	54300.00
308CFC	2017-07-27 22:57:00+03	24800.00
308D0D	2017-07-26 07:37:00+03	85000.00
308D6B	2017-08-12 12:51:00+03	18600.00
308D86	2017-07-25 16:22:00+03	46200.00
308DC3	2017-08-14 04:29:00+03	50100.00
308DDB	2017-08-07 08:27:00+03	155600.00
308E5C	2017-07-05 02:54:00+03	64400.00
308EC6	2017-07-13 00:04:00+03	39200.00
308F25	2017-07-08 13:49:00+03	67000.00
308F2E	2017-07-02 23:27:00+03	50000.00
309053	2017-07-31 09:38:00+03	23900.00
3090F1	2017-08-02 20:33:00+03	129700.00
30912F	2017-07-03 09:27:00+03	40200.00
30913A	2017-07-22 10:21:00+03	100600.00
309142	2017-07-02 18:24:00+03	52000.00
309145	2017-07-22 20:54:00+03	184900.00
3091EF	2017-08-04 08:56:00+03	116400.00
309229	2017-07-25 06:52:00+03	50300.00
30925E	2017-08-10 20:17:00+03	70700.00
309341	2017-07-20 18:14:00+03	21000.00
309393	2017-07-17 09:25:00+03	50300.00
309398	2017-07-24 17:51:00+03	32400.00
309400	2017-08-01 20:49:00+03	27200.00
309401	2017-08-15 15:42:00+03	28000.00
30941B	2017-08-15 01:40:00+03	36000.00
309462	2017-07-11 16:39:00+03	25000.00
30949A	2017-07-10 03:46:00+03	44600.00
309530	2017-08-05 02:39:00+03	23200.00
309541	2017-08-14 07:39:00+03	89200.00
309558	2017-07-31 16:45:00+03	114500.00
30959D	2017-07-23 17:33:00+03	8200.00
3095A1	2017-08-07 16:16:00+03	304200.00
309618	2017-07-19 13:54:00+03	86800.00
309651	2017-08-11 20:25:00+03	89700.00
309679	2017-07-27 13:20:00+03	68100.00
309741	2017-07-15 01:59:00+03	19200.00
309751	2017-07-17 18:30:00+03	56000.00
30975A	2017-07-13 08:16:00+03	23600.00
30978B	2017-07-26 23:32:00+03	31700.00
3097B2	2017-08-10 07:18:00+03	13400.00
309833	2017-07-28 12:23:00+03	67200.00
30984C	2017-07-06 02:05:00+03	28400.00
309875	2017-08-12 07:55:00+03	136800.00
3098BB	2017-07-13 09:40:00+03	66600.00
3098DD	2017-07-27 01:21:00+03	110500.00
30995D	2017-08-14 23:52:00+03	369000.00
30997E	2017-07-14 02:37:00+03	52700.00
309988	2017-08-01 12:32:00+03	57600.00
30999F	2017-07-23 14:51:00+03	21800.00
309A52	2017-07-27 07:31:00+03	101200.00
309A74	2017-08-05 05:00:00+03	25400.00
309B0D	2017-07-09 23:35:00+03	21400.00
309B48	2017-07-09 13:43:00+03	123000.00
309B53	2017-07-07 11:51:00+03	25000.00
309B95	2017-07-08 14:43:00+03	405000.00
309BB3	2017-07-02 17:39:00+03	30200.00
309BF4	2017-06-26 06:25:00+03	22000.00
309C41	2017-07-15 21:31:00+03	56000.00
309C45	2017-07-27 16:47:00+03	72300.00
309C4F	2017-07-10 22:57:00+03	75500.00
309C51	2017-07-03 02:49:00+03	23400.00
309C6C	2017-07-30 12:35:00+03	68600.00
309CA4	2017-08-08 14:19:00+03	46400.00
309CC2	2017-07-12 13:13:00+03	139200.00
309D69	2017-07-09 14:46:00+03	278400.00
309D6F	2017-07-21 18:33:00+03	45400.00
309D86	2017-07-25 19:52:00+03	111700.00
309DC2	2017-07-10 08:46:00+03	90800.00
309DD2	2017-08-06 02:38:00+03	55800.00
309E77	2017-08-14 16:05:00+03	52800.00
309EB5	2017-07-30 21:49:00+03	492200.00
309EEA	2017-08-13 18:01:00+03	21400.00
309F03	2017-07-04 13:24:00+03	204500.00
309F19	2017-08-14 19:36:00+03	48800.00
309F71	2017-08-13 19:59:00+03	23200.00
309F75	2017-08-01 19:31:00+03	12600.00
309F97	2017-07-14 07:31:00+03	67700.00
30A096	2017-07-24 19:06:00+03	23400.00
30A0D6	2017-08-11 12:52:00+03	66000.00
30A115	2017-08-07 14:39:00+03	67200.00
30A149	2017-07-28 22:42:00+03	30200.00
30A14E	2017-06-29 19:09:00+03	204700.00
30A157	2017-07-24 17:44:00+03	91600.00
30A185	2017-07-21 12:42:00+03	18000.00
30A1FC	2017-07-17 02:09:00+03	169600.00
30A24D	2017-07-29 05:34:00+03	81600.00
30A298	2017-07-11 00:51:00+03	39300.00
30A2AE	2017-08-13 22:15:00+03	87100.00
30A2DB	2017-08-13 02:02:00+03	8400.00
30A2E3	2017-07-14 14:16:00+03	71000.00
30A2F0	2017-07-20 14:21:00+03	46500.00
30A2F4	2017-08-08 09:07:00+03	28800.00
30A327	2017-07-23 09:16:00+03	61800.00
30A32E	2017-07-06 13:48:00+03	28000.00
30A39E	2017-08-13 11:56:00+03	52100.00
30A3A6	2017-08-12 05:21:00+03	73500.00
30A401	2017-07-08 14:04:00+03	66800.00
30A404	2017-08-10 20:57:00+03	86600.00
30A4AF	2017-07-19 13:54:00+03	56000.00
30A558	2017-08-08 21:34:00+03	169600.00
30A56F	2017-07-25 23:26:00+03	48100.00
30A599	2017-07-23 22:04:00+03	172100.00
30A5AE	2017-07-29 06:47:00+03	45200.00
30A62B	2017-07-28 14:26:00+03	26000.00
30A639	2017-07-17 02:01:00+03	62600.00
30A676	2017-07-18 22:30:00+03	126500.00
30A697	2017-08-01 23:07:00+03	135300.00
30A69C	2017-07-04 05:58:00+03	258400.00
30A77C	2017-08-05 16:30:00+03	105100.00
30A841	2017-07-08 05:57:00+03	202400.00
30A851	2017-08-14 21:14:00+03	40700.00
30A86C	2017-07-18 21:40:00+03	136800.00
30A873	2017-07-23 15:30:00+03	28000.00
30A87A	2017-07-20 11:51:00+03	119600.00
30A93A	2017-08-05 20:56:00+03	12000.00
30A940	2017-08-14 06:11:00+03	56000.00
30A99D	2017-08-08 17:28:00+03	39700.00
30A99E	2017-08-09 01:54:00+03	96800.00
30A9DB	2017-07-15 19:48:00+03	224000.00
30A9DF	2017-07-20 20:48:00+03	135400.00
30AA11	2017-08-15 14:00:00+03	47000.00
30AA16	2017-08-04 22:23:00+03	31600.00
30AA2B	2017-08-14 00:06:00+03	63300.00
30AA79	2017-07-06 03:16:00+03	44000.00
30AB14	2017-08-11 17:33:00+03	68800.00
30AB74	2017-07-01 08:35:00+03	54800.00
30AB7B	2017-07-08 16:51:00+03	25600.00
30AB8D	2017-08-02 23:23:00+03	139700.00
30ABA2	2017-07-28 09:44:00+03	3700.00
30AC1C	2017-08-13 11:59:00+03	28800.00
30AC9B	2017-07-09 22:43:00+03	31900.00
30ACAD	2017-07-17 15:51:00+03	46200.00
30AD2D	2017-07-18 14:47:00+03	25800.00
30AD30	2017-08-07 20:25:00+03	52000.00
30AD9A	2017-08-02 09:58:00+03	27200.00
30ADD3	2017-08-10 03:54:00+03	231200.00
30ADE4	2017-08-05 22:36:00+03	16400.00
30AE25	2017-07-01 13:02:00+03	167500.00
30AE85	2017-07-14 23:42:00+03	131100.00
30AE88	2017-07-10 07:54:00+03	87400.00
30AEAD	2017-07-09 21:48:00+03	75600.00
30AEDB	2017-07-18 17:29:00+03	270800.00
30AEF2	2017-08-08 14:58:00+03	38800.00
30AF12	2017-07-20 03:50:00+03	21400.00
30AF32	2017-08-10 22:41:00+03	23200.00
30AF41	2017-07-05 12:53:00+03	47800.00
30AF85	2017-07-01 01:06:00+03	84800.00
30B02A	2017-07-23 06:30:00+03	46400.00
30B09C	2017-07-04 20:28:00+03	88800.00
30B0BC	2017-08-14 13:03:00+03	101600.00
30B125	2017-08-12 20:54:00+03	36800.00
30B129	2017-07-07 12:49:00+03	33300.00
30B1DE	2017-07-16 05:43:00+03	113200.00
30B258	2017-07-20 01:27:00+03	112600.00
30B2D1	2017-07-19 13:26:00+03	84800.00
30B355	2017-07-16 16:27:00+03	186900.00
30B38E	2017-06-28 15:34:00+03	55800.00
30B3EF	2017-08-01 09:44:00+03	111600.00
30B438	2017-07-17 22:21:00+03	53100.00
30B44B	2017-06-30 10:08:00+03	92900.00
30B44F	2017-08-01 17:58:00+03	12200.00
30B4C4	2017-07-18 01:40:00+03	42800.00
30B4F0	2017-08-13 00:10:00+03	54500.00
30B56A	2017-07-25 05:35:00+03	124200.00
30B5C3	2017-08-12 22:21:00+03	34000.00
30B612	2017-07-09 05:59:00+03	406200.00
30B6C3	2017-07-16 02:14:00+03	26800.00
30B70B	2017-07-15 02:48:00+03	7200.00
30B70F	2017-07-04 07:46:00+03	97400.00
30B72B	2017-08-10 18:45:00+03	50000.00
30B757	2017-07-05 05:21:00+03	11600.00
30B787	2017-07-08 15:55:00+03	24400.00
30B808	2017-07-11 20:46:00+03	62600.00
30B87B	2017-07-02 09:32:00+03	61800.00
30B89C	2017-07-09 10:33:00+03	46400.00
30B8CA	2017-07-10 09:43:00+03	59800.00
30B8E1	2017-07-28 20:04:00+03	73600.00
30B8E9	2017-07-20 14:23:00+03	32800.00
30B92E	2017-07-05 10:33:00+03	6700.00
30B965	2017-07-30 02:34:00+03	73200.00
30BA33	2017-08-15 13:21:00+03	36200.00
30BA83	2017-07-23 05:21:00+03	27200.00
30BAD2	2017-08-04 11:47:00+03	51600.00
30BAD8	2017-08-02 06:05:00+03	23800.00
30BB3C	2017-07-05 18:26:00+03	121100.00
30BB77	2017-08-07 23:40:00+03	52000.00
30BB78	2017-08-10 19:23:00+03	46400.00
30BC67	2017-06-28 03:59:00+03	90400.00
30BCB5	2017-08-07 00:43:00+03	46800.00
30BCCC	2017-07-03 14:39:00+03	10800.00
30BD5B	2017-07-14 19:34:00+03	15900.00
30BD62	2017-07-10 05:16:00+03	24400.00
30BDC6	2017-07-29 17:19:00+03	30900.00
30BDCF	2017-08-05 14:31:00+03	72300.00
30BDF1	2017-07-31 00:57:00+03	42000.00
30BDFC	2017-07-03 14:05:00+03	65600.00
30BE1F	2017-07-04 13:44:00+03	7400.00
30BE39	2017-07-31 13:09:00+03	40800.00
30BEB4	2017-07-13 01:33:00+03	61800.00
30BEF0	2017-07-05 19:32:00+03	169300.00
30BEF1	2017-07-15 11:36:00+03	54000.00
30BF72	2017-07-12 22:30:00+03	75600.00
30BFD7	2017-07-11 03:38:00+03	105000.00
30C01A	2017-07-19 19:31:00+03	203000.00
30C026	2017-07-19 21:49:00+03	180000.00
30C0AD	2017-08-14 18:22:00+03	117200.00
30C0D3	2017-07-30 07:04:00+03	64500.00
30C16A	2017-07-27 17:20:00+03	189800.00
30C1C3	2017-08-06 19:21:00+03	43400.00
30C1CF	2017-08-10 09:08:00+03	143100.00
30C1D5	2017-08-12 07:38:00+03	66600.00
30C291	2017-07-27 18:08:00+03	85000.00
30C2D8	2017-07-22 13:12:00+03	32800.00
30C30B	2017-08-09 23:50:00+03	32800.00
30C385	2017-07-09 03:13:00+03	26200.00
30C38C	2017-08-14 23:05:00+03	32200.00
30C397	2017-07-12 04:27:00+03	19600.00
30C42D	2017-08-06 10:56:00+03	27400.00
30C451	2017-07-27 17:42:00+03	54500.00
30C47A	2017-07-25 02:02:00+03	51900.00
30C528	2017-07-10 16:10:00+03	12600.00
30C535	2017-08-13 17:47:00+03	35200.00
30C54D	2017-07-24 08:12:00+03	190100.00
30C56D	2017-07-06 14:58:00+03	118600.00
30C5FC	2017-08-12 10:43:00+03	81600.00
30C5FF	2017-07-14 01:50:00+03	167400.00
30C626	2017-07-10 22:46:00+03	137800.00
30C66F	2017-08-15 04:54:00+03	21600.00
30C671	2017-07-23 01:27:00+03	28800.00
30C6D0	2017-08-04 23:04:00+03	21400.00
30C705	2017-07-11 11:33:00+03	12300.00
30C720	2017-07-12 16:29:00+03	23200.00
30C72B	2017-07-27 17:05:00+03	23200.00
30C746	2017-07-26 18:10:00+03	68900.00
30C7BC	2017-07-17 02:47:00+03	54800.00
30C7D6	2017-08-02 11:42:00+03	48800.00
30C7FD	2017-07-18 15:31:00+03	56000.00
30C84D	2017-07-14 03:10:00+03	211100.00
30C855	2017-08-13 05:52:00+03	56600.00
30C897	2017-07-24 14:23:00+03	136800.00
30C8BC	2017-07-28 01:47:00+03	52400.00
30C8E5	2017-07-19 05:35:00+03	469900.00
30C91B	2017-07-25 19:37:00+03	137700.00
30C920	2017-07-01 07:18:00+03	139300.00
30C971	2017-08-03 13:13:00+03	83200.00
30CA45	2017-07-25 14:47:00+03	28000.00
30CA8F	2017-08-02 21:57:00+03	83900.00
30CADE	2017-07-12 06:36:00+03	39300.00
30CB57	2017-07-06 21:08:00+03	51900.00
30CB75	2017-08-02 00:17:00+03	73600.00
30CB81	2017-07-29 18:25:00+03	51600.00
30CBA7	2017-07-08 04:04:00+03	28700.00
30CC4C	2017-08-14 22:53:00+03	170900.00
30CD4D	2017-07-21 05:12:00+03	29400.00
30CD79	2017-07-14 14:20:00+03	48800.00
30CDA0	2017-08-04 05:11:00+03	198800.00
30CDF8	2017-07-13 10:13:00+03	111600.00
30CDFB	2017-07-07 10:10:00+03	35200.00
30CE48	2017-07-22 17:27:00+03	23600.00
30CE5E	2017-08-15 13:08:00+03	95700.00
30CE7A	2017-08-06 07:32:00+03	106100.00
30CE85	2017-08-06 23:53:00+03	34700.00
30CEC4	2017-07-27 20:36:00+03	84100.00
30CED1	2017-08-05 04:21:00+03	33600.00
30CF8A	2017-07-27 04:40:00+03	141600.00
30CF90	2017-07-28 18:37:00+03	87200.00
30D005	2017-07-01 10:22:00+03	23200.00
30D017	2017-07-22 21:39:00+03	80200.00
30D035	2017-07-04 05:45:00+03	114700.00
30D064	2017-08-15 10:41:00+03	201800.00
30D06F	2017-08-14 01:52:00+03	26800.00
30D07E	2017-08-12 10:36:00+03	156900.00
30D09D	2017-08-01 19:10:00+03	12400.00
30D137	2017-07-18 16:13:00+03	40000.00
30D155	2017-07-09 16:16:00+03	10800.00
30D191	2017-08-13 07:35:00+03	13400.00
30D1B1	2017-07-04 22:41:00+03	258400.00
30D209	2017-08-09 11:39:00+03	37200.00
30D212	2017-07-11 13:02:00+03	109400.00
30D2BD	2017-07-26 20:03:00+03	110300.00
30D318	2017-07-29 00:07:00+03	138600.00
30D362	2017-08-11 23:07:00+03	126300.00
30D367	2017-07-06 00:48:00+03	44000.00
30D36E	2017-08-02 13:57:00+03	92800.00
30D495	2017-07-08 20:31:00+03	173500.00
30D49A	2017-08-15 01:28:00+03	13400.00
30D4D3	2017-07-19 08:07:00+03	269500.00
30D4FE	2017-07-10 11:22:00+03	44800.00
30D4FF	2017-07-17 15:54:00+03	386200.00
30D512	2017-08-06 21:04:00+03	64700.00
30D521	2017-07-08 09:03:00+03	220500.00
30D55B	2017-07-12 00:42:00+03	56600.00
30D56E	2017-07-07 06:29:00+03	68600.00
30D584	2017-07-20 13:13:00+03	38400.00
30D5E0	2017-07-29 17:04:00+03	26100.00
30D601	2017-07-27 05:45:00+03	132800.00
30D61B	2017-08-04 18:03:00+03	266400.00
30D650	2017-07-11 16:46:00+03	62000.00
30D66B	2017-07-17 10:27:00+03	236100.00
30D6FF	2017-07-17 19:31:00+03	22600.00
30D717	2017-07-24 15:38:00+03	86400.00
30D71F	2017-07-25 13:11:00+03	39400.00
30D84F	2017-07-04 12:42:00+03	55800.00
30D888	2017-08-11 20:25:00+03	112000.00
30D8B9	2017-07-23 02:19:00+03	75600.00
30D8E1	2017-08-01 06:17:00+03	23200.00
30D8F8	2017-08-09 10:36:00+03	46400.00
30D925	2017-07-10 11:31:00+03	42700.00
30D928	2017-07-16 01:20:00+03	83700.00
30D9BB	2017-08-01 01:23:00+03	54800.00
30D9EE	2017-08-09 09:39:00+03	16800.00
30DAC3	2017-07-28 01:29:00+03	105600.00
30DAD0	2017-07-06 07:17:00+03	86800.00
30DAE4	2017-07-27 07:08:00+03	46300.00
30DAF9	2017-06-28 17:48:00+03	72400.00
30DB27	2017-07-17 15:51:00+03	20000.00
30DB5B	2017-08-09 02:59:00+03	57600.00
30DB81	2017-08-12 01:40:00+03	16400.00
30DBB1	2017-07-27 13:30:00+03	60600.00
30DBB9	2017-07-14 12:23:00+03	70700.00
30DC00	2017-08-11 03:28:00+03	131600.00
30DC08	2017-07-08 08:32:00+03	46400.00
30DC0F	2017-08-11 15:54:00+03	41400.00
30DC19	2017-08-07 05:56:00+03	44800.00
30DC36	2017-08-03 22:45:00+03	47500.00
30DC81	2017-07-22 11:05:00+03	47800.00
30DCBA	2017-07-02 04:35:00+03	266400.00
30DCC1	2017-07-10 16:43:00+03	166000.00
30DD18	2017-08-14 02:12:00+03	67400.00
30DD31	2017-07-13 17:12:00+03	131800.00
30DD37	2017-08-11 23:50:00+03	272500.00
30DD63	2017-08-14 08:47:00+03	29200.00
30DD66	2017-08-11 16:58:00+03	54800.00
30DE06	2017-07-11 01:52:00+03	12600.00
30DE46	2017-08-12 22:24:00+03	28800.00
30DE9E	2017-07-15 14:44:00+03	95200.00
30DEA6	2017-08-11 21:01:00+03	11800.00
30DEAA	2017-08-13 09:46:00+03	34400.00
30DF4D	2017-08-05 05:43:00+03	47400.00
30DF55	2017-07-04 09:02:00+03	82400.00
30DF57	2017-07-29 12:49:00+03	58000.00
30DFA9	2017-08-04 16:20:00+03	85200.00
30DFBA	2017-07-06 02:21:00+03	92400.00
30DFC0	2017-08-11 13:53:00+03	128600.00
30E106	2017-06-22 22:25:00+03	212500.00
30E131	2017-08-11 07:00:00+03	58600.00
30E1AB	2017-06-30 08:25:00+03	133200.00
30E1CA	2017-08-03 14:34:00+03	48800.00
30E243	2017-07-25 17:42:00+03	15000.00
30E255	2017-07-17 10:32:00+03	28800.00
30E267	2017-07-28 21:25:00+03	27300.00
30E270	2017-07-01 08:49:00+03	70400.00
30E2C7	2017-07-25 04:55:00+03	66800.00
30E30C	2017-08-07 23:19:00+03	30800.00
30E3B4	2017-07-27 20:30:00+03	83000.00
30E3C3	2017-08-13 15:46:00+03	37600.00
30E3D5	2017-07-17 12:10:00+03	38600.00
30E42D	2017-08-06 18:04:00+03	76400.00
30E45A	2017-08-09 01:31:00+03	149100.00
30E46C	2017-07-11 10:59:00+03	38600.00
30E625	2017-07-08 13:23:00+03	124000.00
30E68D	2017-07-17 09:47:00+03	25200.00
30E6B4	2017-07-21 14:26:00+03	64900.00
30E730	2017-07-06 12:58:00+03	67600.00
30E76E	2017-07-18 22:34:00+03	76600.00
30E7E8	2017-07-08 08:50:00+03	67000.00
30E80A	2017-07-01 07:33:00+03	147700.00
30E870	2017-07-29 04:49:00+03	55800.00
30E8DD	2017-08-11 02:06:00+03	37900.00
30E901	2017-07-24 14:20:00+03	68100.00
30E904	2017-08-05 18:01:00+03	22000.00
30E907	2017-07-17 16:15:00+03	69500.00
30E923	2017-06-30 01:00:00+03	78300.00
30E984	2017-08-06 19:23:00+03	103700.00
30E9B5	2017-07-01 12:11:00+03	23200.00
30EA72	2017-08-15 05:12:00+03	46400.00
30EAE9	2017-07-27 23:53:00+03	61800.00
30EAFF	2017-08-05 04:50:00+03	124000.00
30EB4F	2017-07-10 17:55:00+03	29800.00
30EB70	2017-07-27 21:08:00+03	23200.00
30EB7C	2017-07-31 15:41:00+03	36200.00
30EBB5	2017-08-06 01:46:00+03	13400.00
30EBC8	2017-07-26 01:06:00+03	32900.00
30EBF3	2017-07-12 20:54:00+03	57500.00
30EC49	2017-08-11 08:58:00+03	53800.00
30EC96	2017-06-29 13:30:00+03	60400.00
30EC9C	2017-08-01 08:01:00+03	38000.00
30ECB1	2017-07-28 23:54:00+03	103500.00
30EDD7	2017-07-16 20:16:00+03	18600.00
30EE07	2017-07-05 16:05:00+03	177200.00
30EE44	2017-07-16 00:43:00+03	108500.00
30EEC6	2017-08-08 10:45:00+03	93600.00
30EED1	2017-07-09 13:49:00+03	41200.00
30EEEE	2017-07-22 02:03:00+03	23200.00
30EF02	2017-07-26 15:52:00+03	92900.00
30EF03	2017-08-04 00:41:00+03	54500.00
30EF32	2017-07-05 17:27:00+03	72200.00
30EF3C	2017-06-30 13:49:00+03	8000.00
30EF80	2017-07-10 07:39:00+03	44400.00
30F04F	2017-07-06 18:01:00+03	85800.00
30F067	2017-08-13 11:26:00+03	32200.00
30F09F	2017-08-04 02:04:00+03	77400.00
30F0F2	2017-07-25 07:16:00+03	136500.00
30F179	2017-07-05 12:09:00+03	79300.00
30F1AD	2017-07-03 09:33:00+03	133800.00
30F1CC	2017-08-11 15:30:00+03	66600.00
30F1D0	2017-08-07 21:36:00+03	18600.00
30F1DA	2017-08-04 19:27:00+03	46300.00
30F1FD	2017-07-03 11:21:00+03	91800.00
30F20A	2017-08-12 20:59:00+03	38600.00
30F3A4	2017-08-15 14:44:00+03	44500.00
30F3AD	2017-07-04 01:15:00+03	21500.00
30F3B5	2017-07-30 15:38:00+03	119400.00
30F44E	2017-07-09 22:32:00+03	43100.00
30F4BE	2017-07-10 15:29:00+03	18000.00
30F573	2017-07-23 05:15:00+03	142300.00
30F5A3	2017-07-14 00:53:00+03	66600.00
30F5E1	2017-07-17 15:45:00+03	68800.00
30F628	2017-07-13 18:06:00+03	26000.00
30F6BF	2017-07-28 06:15:00+03	37600.00
30F6D2	2017-07-21 05:01:00+03	27800.00
30F6EA	2017-07-16 04:25:00+03	99200.00
30F773	2017-08-11 21:01:00+03	13200.00
30F778	2017-08-04 02:47:00+03	69100.00
30F78F	2017-08-14 14:48:00+03	79800.00
30F80C	2017-07-07 08:21:00+03	24800.00
30F847	2017-07-11 13:26:00+03	12800.00
30F859	2017-07-07 23:41:00+03	20000.00
30F8C9	2017-07-29 23:22:00+03	25400.00
30F8D4	2017-08-07 02:39:00+03	32400.00
30F8D7	2017-07-05 09:41:00+03	24700.00
30F8DD	2017-07-26 00:56:00+03	6700.00
30F8DE	2017-08-13 16:05:00+03	46200.00
30F98D	2017-08-11 06:43:00+03	87700.00
30F9A2	2017-07-09 02:16:00+03	37900.00
30F9F7	2017-07-01 11:19:00+03	6800.00
30FA7A	2017-07-28 16:36:00+03	35800.00
30FAEA	2017-08-02 08:52:00+03	68000.00
30FAEB	2017-07-08 08:14:00+03	36200.00
30FB59	2017-07-10 12:39:00+03	46300.00
30FBE0	2017-07-28 20:19:00+03	167400.00
30FC37	2017-07-11 13:58:00+03	126500.00
30FC81	2017-08-01 00:24:00+03	19600.00
30FC84	2017-07-08 22:07:00+03	47200.00
30FCD4	2017-07-19 08:54:00+03	20700.00
30FD02	2017-08-01 05:48:00+03	25400.00
30FE54	2017-07-15 04:50:00+03	51900.00
30FE83	2017-08-07 20:34:00+03	132800.00
30FEEC	2017-07-17 08:49:00+03	38600.00
30FEFE	2017-08-09 07:34:00+03	26000.00
30FFA1	2017-07-24 23:48:00+03	147700.00
30FFB9	2017-07-23 18:11:00+03	85700.00
31004C	2017-08-14 20:38:00+03	49100.00
3100B1	2017-08-02 08:09:00+03	15200.00
3100B5	2017-07-14 06:22:00+03	12600.00
3100BE	2017-08-11 21:24:00+03	28000.00
3100C7	2017-08-14 01:25:00+03	113200.00
3100FD	2017-07-24 20:55:00+03	36800.00
310118	2017-07-15 22:54:00+03	68000.00
31016F	2017-08-08 10:14:00+03	129000.00
310184	2017-08-15 10:41:00+03	24400.00
310222	2017-07-28 20:18:00+03	37900.00
310269	2017-08-02 18:56:00+03	39500.00
3102BC	2017-08-08 20:32:00+03	52400.00
3102D1	2017-07-26 13:26:00+03	10600.00
31034A	2017-07-23 03:19:00+03	173400.00
310350	2017-07-20 02:19:00+03	181600.00
31037E	2017-07-15 17:13:00+03	51900.00
3103A4	2017-08-13 11:00:00+03	14400.00
3103DD	2017-08-08 17:27:00+03	134400.00
31040A	2017-07-14 15:44:00+03	183300.00
310456	2017-07-29 12:30:00+03	21400.00
3104E9	2017-07-14 14:11:00+03	28800.00
310517	2017-07-13 14:23:00+03	40800.00
310543	2017-07-07 20:42:00+03	46300.00
3105C9	2017-08-07 23:00:00+03	59300.00
3105FF	2017-07-24 14:09:00+03	30700.00
31061D	2017-08-13 18:42:00+03	136200.00
310623	2017-07-30 20:41:00+03	186100.00
310775	2017-07-24 06:25:00+03	87000.00
31077B	2017-07-25 09:29:00+03	73500.00
31077C	2017-07-18 02:08:00+03	96800.00
310793	2017-07-07 04:30:00+03	119000.00
3107C6	2017-07-15 04:30:00+03	228800.00
3107CA	2017-07-18 15:56:00+03	75100.00
3107D7	2017-08-04 17:48:00+03	48800.00
310842	2017-07-06 14:31:00+03	57600.00
3108D7	2017-08-01 11:37:00+03	25600.00
310914	2017-08-09 11:37:00+03	55300.00
310929	2017-07-01 14:05:00+03	40800.00
3109EA	2017-08-01 04:55:00+03	24700.00
310A1D	2017-07-11 19:14:00+03	123700.00
310A7D	2017-07-20 05:28:00+03	46400.00
310ABD	2017-08-08 07:24:00+03	92600.00
310BFA	2017-08-15 14:44:00+03	146300.00
310C05	2017-07-03 05:35:00+03	31600.00
310C60	2017-08-12 09:33:00+03	248400.00
310C99	2017-07-03 11:48:00+03	456100.00
310CD0	2017-07-11 05:40:00+03	30200.00
310CF3	2017-07-12 02:24:00+03	44600.00
310D04	2017-08-13 02:11:00+03	36200.00
310D65	2017-07-25 06:58:00+03	67600.00
310D66	2017-07-27 09:05:00+03	185500.00
310D71	2017-07-09 22:37:00+03	31900.00
310DD8	2017-08-11 11:48:00+03	43900.00
310E1C	2017-07-12 12:28:00+03	47400.00
310E33	2017-07-31 09:20:00+03	48700.00
310E78	2017-08-13 10:45:00+03	23600.00
310E96	2017-08-09 04:46:00+03	91700.00
310EC4	2017-08-14 00:02:00+03	129700.00
310ED0	2017-07-04 09:01:00+03	69000.00
310EF4	2017-07-01 23:58:00+03	21400.00
310F30	2017-08-04 02:32:00+03	24400.00
310F4A	2017-07-14 11:56:00+03	13600.00
31101C	2017-08-14 11:53:00+03	192500.00
311092	2017-07-22 08:15:00+03	11800.00
3110A7	2017-07-04 17:50:00+03	190400.00
3110A8	2017-08-09 05:08:00+03	12600.00
3110CE	2017-08-02 02:45:00+03	57800.00
3110D8	2017-07-27 06:53:00+03	56100.00
311158	2017-08-13 01:27:00+03	37200.00
3111CD	2017-08-11 14:38:00+03	38800.00
31125D	2017-07-30 22:56:00+03	173600.00
311273	2017-08-06 11:12:00+03	71800.00
3112F8	2017-08-12 14:44:00+03	85000.00
31132D	2017-07-12 06:56:00+03	40200.00
311337	2017-07-17 17:34:00+03	78400.00
31134A	2017-07-14 06:53:00+03	42000.00
311366	2017-07-17 09:26:00+03	27200.00
3113B5	2017-08-10 01:55:00+03	78300.00
3113EB	2017-08-08 23:24:00+03	12600.00
31142E	2017-07-21 22:43:00+03	62100.00
3114BB	2017-07-06 18:42:00+03	56000.00
3114DB	2017-07-10 14:19:00+03	16800.00
31152C	2017-07-11 02:47:00+03	30200.00
31153D	2017-08-06 14:17:00+03	137600.00
31153E	2017-08-12 08:20:00+03	70600.00
31154F	2017-07-18 02:13:00+03	123000.00
311586	2017-07-24 15:44:00+03	112000.00
3115DA	2017-07-13 05:31:00+03	24400.00
311606	2017-07-19 10:02:00+03	100000.00
31160F	2017-08-12 08:27:00+03	28300.00
3116A7	2017-08-07 03:32:00+03	10800.00
311748	2017-07-25 01:01:00+03	67600.00
311777	2017-07-22 11:04:00+03	54800.00
311793	2017-08-08 05:12:00+03	25400.00
311840	2017-07-10 07:48:00+03	71100.00
3118CD	2017-07-03 11:24:00+03	48800.00
3118D1	2017-07-07 11:19:00+03	85000.00
311958	2017-07-26 06:29:00+03	92700.00
311984	2017-08-15 10:30:00+03	85000.00
3119D7	2017-07-30 15:34:00+03	58600.00
3119FA	2017-08-15 03:41:00+03	11700.00
311A5C	2017-07-24 01:37:00+03	54100.00
311B53	2017-08-09 13:11:00+03	81500.00
311B67	2017-08-02 01:52:00+03	135300.00
311BC2	2017-07-02 06:04:00+03	93900.00
311BF1	2017-08-13 22:44:00+03	406700.00
311C0A	2017-07-01 13:24:00+03	45100.00
311C21	2017-08-05 23:32:00+03	42400.00
311C69	2017-07-31 08:32:00+03	85700.00
311CB2	2017-07-07 05:30:00+03	231800.00
311D37	2017-08-02 04:01:00+03	346100.00
311D60	2017-08-14 23:05:00+03	30400.00
311D6C	2017-07-12 05:49:00+03	20100.00
311DC0	2017-07-14 10:25:00+03	113200.00
311DC4	2017-07-13 03:05:00+03	313200.00
311E3C	2017-07-27 02:32:00+03	86000.00
311EC5	2017-07-18 22:54:00+03	40000.00
311EEB	2017-08-11 04:18:00+03	23600.00
311EF2	2017-07-07 08:06:00+03	297000.00
311F26	2017-08-07 09:55:00+03	106400.00
311F4E	2017-07-26 04:29:00+03	78000.00
311F5D	2017-07-25 01:27:00+03	285900.00
311F7A	2017-07-16 21:55:00+03	65500.00
311F80	2017-08-04 04:39:00+03	61400.00
312012	2017-07-16 22:16:00+03	89800.00
31203C	2017-08-09 17:52:00+03	31000.00
31207E	2017-08-08 10:06:00+03	25600.00
3120EB	2017-08-13 10:36:00+03	14000.00
312135	2017-07-20 15:40:00+03	28600.00
3122B4	2017-07-23 18:23:00+03	12800.00
3122DD	2017-07-12 01:13:00+03	31600.00
3122E7	2017-07-05 22:35:00+03	101600.00
312337	2017-07-24 01:09:00+03	21000.00
312374	2017-07-23 05:59:00+03	103500.00
3123B8	2017-07-13 13:23:00+03	91200.00
3123D2	2017-07-14 02:20:00+03	43200.00
3123DB	2017-07-23 23:29:00+03	49600.00
312464	2017-07-31 00:12:00+03	14400.00
312474	2017-08-09 09:41:00+03	169300.00
31248C	2017-07-11 23:43:00+03	36200.00
3124D5	2017-08-01 09:01:00+03	51300.00
3124E5	2017-07-07 11:40:00+03	46200.00
31250D	2017-08-04 11:54:00+03	49400.00
312514	2017-07-29 07:39:00+03	40000.00
312540	2017-08-12 10:44:00+03	64700.00
312568	2017-08-08 10:31:00+03	67600.00
3125AF	2017-08-03 05:52:00+03	55900.00
3125EF	2017-07-05 07:01:00+03	85000.00
312648	2017-08-05 05:27:00+03	22600.00
312713	2017-07-30 03:11:00+03	13400.00
312768	2017-07-20 10:16:00+03	55800.00
31276C	2017-08-14 21:17:00+03	25800.00
312775	2017-07-09 02:52:00+03	94700.00
3127D2	2017-07-09 17:33:00+03	130400.00
312847	2017-08-12 01:07:00+03	23400.00
3128E6	2017-07-28 17:36:00+03	123000.00
31290E	2017-08-06 02:43:00+03	32700.00
3129A1	2017-08-13 02:57:00+03	85500.00
312A21	2017-08-14 20:25:00+03	53500.00
312AFA	2017-08-09 11:46:00+03	46500.00
312B0A	2017-07-06 12:17:00+03	64500.00
312B32	2017-07-22 04:37:00+03	174900.00
312CA3	2017-07-07 08:24:00+03	44800.00
312CC7	2017-07-12 04:39:00+03	21400.00
312CF2	2017-08-02 20:43:00+03	22400.00
312D8C	2017-07-18 08:38:00+03	136600.00
312D99	2017-07-11 02:50:00+03	29000.00
312E6B	2017-07-24 21:36:00+03	22000.00
312E7B	2017-07-25 18:04:00+03	26800.00
312EA7	2017-07-22 08:29:00+03	48300.00
312EAD	2017-07-09 19:12:00+03	15800.00
312ECD	2017-07-28 01:42:00+03	123000.00
312EE2	2017-07-27 18:45:00+03	44000.00
312EEE	2017-08-14 14:31:00+03	272300.00
312F20	2017-07-30 04:16:00+03	92800.00
312F61	2017-07-11 10:48:00+03	35600.00
312F8B	2017-07-31 22:03:00+03	64700.00
313011	2017-07-17 11:16:00+03	135400.00
313020	2017-07-17 04:24:00+03	57600.00
313048	2017-07-17 02:46:00+03	54800.00
313051	2017-07-03 07:06:00+03	89200.00
313076	2017-07-24 06:17:00+03	54800.00
3130B5	2017-08-04 13:34:00+03	115700.00
3130DE	2017-07-31 17:31:00+03	116800.00
3130F7	2017-07-04 06:57:00+03	67900.00
313141	2017-07-23 11:11:00+03	177200.00
31318D	2017-08-10 18:30:00+03	87800.00
31318E	2017-08-10 08:09:00+03	29600.00
313197	2017-07-25 20:42:00+03	79400.00
3131A5	2017-07-21 00:37:00+03	55800.00
3132BA	2017-07-04 20:24:00+03	43900.00
313331	2017-08-11 15:22:00+03	194200.00
313339	2017-07-08 18:18:00+03	144300.00
31344C	2017-07-20 20:37:00+03	271100.00
31346C	2017-07-17 16:54:00+03	48800.00
313480	2017-08-09 02:10:00+03	56300.00
3134AF	2017-07-20 07:48:00+03	133200.00
313507	2017-08-15 15:01:00+03	31200.00
3135A6	2017-07-11 16:33:00+03	20800.00
3135ED	2017-07-22 11:17:00+03	122700.00
3135F4	2017-07-22 23:17:00+03	26700.00
3135F7	2017-08-11 23:27:00+03	46400.00
31360C	2017-07-22 09:25:00+03	43400.00
313635	2017-07-09 06:57:00+03	13400.00
313652	2017-08-01 12:34:00+03	28800.00
31365A	2017-07-16 08:24:00+03	140900.00
31367D	2017-08-15 04:42:00+03	294200.00
3136B7	2017-07-11 21:35:00+03	33200.00
31370E	2017-07-28 13:24:00+03	6300.00
313735	2017-07-13 06:16:00+03	32800.00
3137A9	2017-07-04 23:20:00+03	56000.00
3137B0	2017-07-21 09:39:00+03	135000.00
3137C8	2017-08-11 20:14:00+03	92000.00
3137FB	2017-08-14 05:22:00+03	166100.00
313813	2017-07-30 20:34:00+03	65500.00
313816	2017-07-30 01:35:00+03	124400.00
313834	2017-08-10 17:54:00+03	100600.00
31394B	2017-07-31 16:19:00+03	16400.00
313952	2017-07-21 16:05:00+03	173500.00
3139F8	2017-08-13 04:45:00+03	56000.00
313A1D	2017-07-10 13:10:00+03	20000.00
313A3B	2017-07-14 15:24:00+03	167400.00
313AB8	2017-07-08 18:40:00+03	49100.00
313B26	2017-07-23 14:25:00+03	12600.00
313B8B	2017-07-09 00:52:00+03	34400.00
313BB0	2017-07-30 12:30:00+03	136800.00
313BFE	2017-06-30 14:19:00+03	46800.00
313C1F	2017-07-21 06:33:00+03	393800.00
313C29	2017-07-20 02:45:00+03	28800.00
313C6E	2017-07-26 04:36:00+03	26600.00
313CCF	2017-07-08 23:53:00+03	6900.00
313CDD	2017-08-03 17:26:00+03	72400.00
313CE4	2017-07-29 16:52:00+03	34000.00
313CE7	2017-07-25 15:22:00+03	52000.00
313D1D	2017-07-06 02:15:00+03	72600.00
313D1E	2017-08-11 15:48:00+03	95200.00
313D58	2017-08-14 07:31:00+03	396500.00
313E0C	2017-07-06 06:24:00+03	27200.00
313E66	2017-07-18 05:17:00+03	56000.00
313F7A	2017-07-10 00:25:00+03	26000.00
313FD8	2017-08-13 19:52:00+03	47500.00
313FD9	2017-07-05 23:50:00+03	154400.00
313FF6	2017-08-11 21:16:00+03	87700.00
31400C	2017-07-30 20:15:00+03	20200.00
31401A	2017-08-05 00:45:00+03	24400.00
31402C	2017-06-30 14:59:00+03	69500.00
314102	2017-06-30 04:18:00+03	278400.00
31418F	2017-07-20 11:15:00+03	43000.00
3141E3	2017-07-09 13:33:00+03	114500.00
31420B	2017-07-09 06:34:00+03	92600.00
314262	2017-07-24 08:31:00+03	167400.00
314373	2017-07-26 19:12:00+03	70600.00
3143BF	2017-08-01 21:12:00+03	80100.00
3143CC	2017-07-04 19:40:00+03	28800.00
31441A	2017-07-03 17:17:00+03	68800.00
3144D2	2017-08-07 22:06:00+03	28800.00
314505	2017-07-21 09:56:00+03	124200.00
314509	2017-08-02 15:10:00+03	96200.00
31453D	2017-08-14 15:58:00+03	13400.00
31454C	2017-08-07 21:15:00+03	38800.00
314569	2017-08-12 06:19:00+03	62100.00
314579	2017-08-13 16:24:00+03	162300.00
31457C	2017-08-03 00:39:00+03	25200.00
3145F8	2017-07-26 21:49:00+03	96800.00
314657	2017-08-05 19:30:00+03	89600.00
31466A	2017-07-08 19:11:00+03	406100.00
314676	2017-08-13 22:30:00+03	169900.00
31467D	2017-07-28 17:23:00+03	199700.00
3146B6	2017-07-08 06:27:00+03	23200.00
3146DC	2017-07-08 07:32:00+03	26000.00
3146EC	2017-07-23 19:00:00+03	23600.00
3146F2	2017-07-05 04:44:00+03	135400.00
31470C	2017-08-13 11:20:00+03	46200.00
314723	2017-08-14 18:17:00+03	101200.00
31476E	2017-07-30 21:20:00+03	26600.00
3147CD	2017-08-14 04:11:00+03	48200.00
314904	2017-07-12 22:50:00+03	34600.00
31490F	2017-08-05 05:49:00+03	28700.00
314912	2017-07-20 10:11:00+03	27200.00
31491F	2017-08-13 16:20:00+03	56600.00
314973	2017-08-01 07:40:00+03	112000.00
3149B0	2017-07-11 12:14:00+03	10700.00
3149BF	2017-07-06 21:22:00+03	40100.00
3149E2	2017-07-12 03:16:00+03	13000.00
314AF0	2017-07-18 15:02:00+03	49800.00
314B2A	2017-08-04 10:55:00+03	265200.00
314B31	2017-07-15 02:14:00+03	55800.00
314B80	2017-08-14 10:12:00+03	115700.00
314B81	2017-06-30 02:40:00+03	109400.00
314BAA	2017-07-26 23:09:00+03	68800.00
314BB9	2017-07-17 04:57:00+03	173400.00
314BC7	2017-07-27 00:09:00+03	75300.00
314C0A	2017-07-26 10:53:00+03	117600.00
314C38	2017-07-27 04:28:00+03	100600.00
314C5B	2017-07-24 15:12:00+03	32800.00
314C8F	2017-08-11 05:16:00+03	286100.00
314CD2	2017-07-28 20:08:00+03	17200.00
314CF3	2017-07-05 17:41:00+03	89200.00
314D0B	2017-07-14 13:13:00+03	260300.00
314D33	2017-07-08 11:47:00+03	27800.00
314D64	2017-08-07 12:36:00+03	46800.00
314D6F	2017-08-08 06:49:00+03	67200.00
314D99	2017-07-18 14:51:00+03	73100.00
314E11	2017-08-14 13:44:00+03	40600.00
314E14	2017-07-21 13:42:00+03	74400.00
314E40	2017-08-08 05:25:00+03	23200.00
314EA3	2017-08-15 15:13:00+03	10800.00
314EA8	2017-07-26 21:28:00+03	6700.00
314EB5	2017-07-09 00:09:00+03	115600.00
314EF9	2017-07-29 12:06:00+03	46200.00
314F09	2017-07-16 17:13:00+03	26200.00
314F42	2017-08-06 03:10:00+03	29400.00
314F4C	2017-08-13 08:15:00+03	25400.00
314F4F	2017-07-08 21:03:00+03	14400.00
314FA2	2017-07-21 03:20:00+03	62800.00
314FD2	2017-07-15 01:41:00+03	98400.00
314FFB	2017-07-13 16:21:00+03	135600.00
315043	2017-08-09 22:15:00+03	33100.00
315070	2017-07-12 12:24:00+03	306200.00
3150A3	2017-07-22 07:31:00+03	16400.00
31510E	2017-08-07 05:38:00+03	80700.00
315116	2017-07-03 05:13:00+03	49400.00
315117	2017-08-09 04:32:00+03	184300.00
3151F6	2017-07-16 01:08:00+03	22000.00
31525B	2017-07-23 11:54:00+03	8600.00
315293	2017-07-17 12:52:00+03	339300.00
315336	2017-07-25 17:28:00+03	122800.00
3153FA	2017-08-14 03:14:00+03	66600.00
315436	2017-08-11 20:32:00+03	47200.00
315488	2017-08-08 05:02:00+03	114400.00
315500	2017-07-08 00:40:00+03	21800.00
315546	2017-08-06 11:56:00+03	47100.00
315594	2017-07-09 21:34:00+03	14400.00
3155F5	2017-08-15 02:39:00+03	62600.00
315648	2017-08-09 11:00:00+03	23200.00
31568E	2017-08-15 00:33:00+03	155600.00
31568F	2017-07-04 12:10:00+03	55000.00
3156FB	2017-07-24 20:09:00+03	28000.00
3156FF	2017-07-11 01:08:00+03	79200.00
315709	2017-07-19 02:05:00+03	57900.00
315724	2017-07-12 03:15:00+03	73000.00
31573B	2017-08-05 23:37:00+03	39200.00
315815	2017-07-27 19:08:00+03	76800.00
315824	2017-07-10 12:50:00+03	26800.00
315874	2017-07-09 14:48:00+03	39800.00
3158A6	2017-08-09 02:44:00+03	22000.00
3158D4	2017-08-10 14:53:00+03	14000.00
3158E6	2017-07-10 07:36:00+03	4000.00
3159B3	2017-07-26 00:37:00+03	68400.00
3159FD	2017-07-05 23:25:00+03	16400.00
315A79	2017-07-27 21:44:00+03	174600.00
315A84	2017-07-20 05:42:00+03	52000.00
315AA4	2017-07-13 04:56:00+03	29600.00
315C90	2017-07-01 11:22:00+03	133200.00
315C9C	2017-07-25 14:54:00+03	125100.00
315CB0	2017-07-24 02:54:00+03	31400.00
315CC4	2017-08-09 01:41:00+03	286100.00
315CE9	2017-07-12 23:40:00+03	135200.00
315D23	2017-07-21 04:58:00+03	73500.00
315D65	2017-07-19 07:57:00+03	7400.00
315D6F	2017-08-05 15:05:00+03	289800.00
315D78	2017-08-15 07:18:00+03	56600.00
315DC1	2017-07-20 04:44:00+03	58100.00
315DD8	2017-07-25 05:43:00+03	62600.00
315DFA	2017-07-12 03:10:00+03	29200.00
315E4A	2017-08-07 05:25:00+03	135600.00
315E58	2017-07-15 12:20:00+03	47500.00
315E95	2017-07-29 20:17:00+03	9300.00
315F07	2017-07-14 01:18:00+03	26000.00
315F30	2017-07-25 19:47:00+03	24400.00
315F5C	2017-07-11 06:44:00+03	115600.00
315F8A	2017-08-09 00:53:00+03	56600.00
316011	2017-07-11 18:24:00+03	22600.00
316020	2017-07-20 06:21:00+03	150500.00
316041	2017-07-06 02:46:00+03	66400.00
3160AA	2017-08-10 00:32:00+03	28800.00
3160C8	2017-07-21 21:36:00+03	39400.00
31610E	2017-07-16 05:56:00+03	35700.00
31626B	2017-08-15 10:21:00+03	38200.00
316288	2017-07-25 00:55:00+03	200700.00
316290	2017-08-06 08:20:00+03	62600.00
316292	2017-08-10 05:23:00+03	128800.00
31629B	2017-07-25 19:46:00+03	31800.00
3162A9	2017-07-09 01:29:00+03	31400.00
3162AB	2017-08-05 07:43:00+03	398500.00
3162DE	2017-07-06 03:51:00+03	134400.00
3162F5	2017-07-16 17:41:00+03	26000.00
3163A3	2017-07-21 07:08:00+03	52000.00
3163B0	2017-07-08 09:28:00+03	77900.00
316437	2017-07-11 19:32:00+03	67600.00
316438	2017-07-20 12:14:00+03	17000.00
3164A2	2017-07-12 10:04:00+03	32200.00
3164FC	2017-07-20 00:41:00+03	56000.00
316511	2017-07-19 20:22:00+03	29400.00
316514	2017-07-22 00:40:00+03	29600.00
316528	2017-08-04 17:03:00+03	6300.00
316535	2017-07-20 22:18:00+03	59200.00
3165E8	2017-07-16 09:37:00+03	6000.00
31665E	2017-07-06 18:42:00+03	87200.00
316662	2017-08-13 02:36:00+03	39300.00
316750	2017-08-08 09:38:00+03	72400.00
31676A	2017-06-30 21:13:00+03	46300.00
31676E	2017-07-22 10:45:00+03	29400.00
31680A	2017-07-29 18:06:00+03	26000.00
316847	2017-07-12 02:04:00+03	61800.00
316850	2017-07-22 20:05:00+03	132800.00
31686A	2017-07-24 08:21:00+03	16400.00
3168C5	2017-07-28 18:08:00+03	54500.00
316904	2017-07-12 00:01:00+03	28000.00
316941	2017-08-09 08:40:00+03	36200.00
316973	2017-08-04 13:22:00+03	67800.00
316979	2017-07-28 15:55:00+03	135400.00
3169AA	2017-08-11 01:18:00+03	25800.00
316A3E	2017-07-18 11:44:00+03	46400.00
316A5D	2017-07-19 05:48:00+03	50000.00
316A80	2017-08-13 12:36:00+03	24400.00
316AC5	2017-08-14 15:16:00+03	13400.00
316AE6	2017-07-15 19:54:00+03	20200.00
316AFC	2017-08-14 00:22:00+03	58200.00
316B6D	2017-08-09 13:02:00+03	62000.00
316CC5	2017-06-26 17:58:00+03	72400.00
316CF0	2017-07-18 18:37:00+03	190100.00
316D05	2017-07-13 19:11:00+03	124200.00
316D64	2017-08-11 00:06:00+03	48300.00
316DB2	2017-07-08 11:11:00+03	139200.00
316DBA	2017-07-16 17:10:00+03	69600.00
316DD6	2017-08-13 18:54:00+03	80400.00
316DF2	2017-08-05 19:25:00+03	79900.00
316DFD	2017-08-11 15:39:00+03	67300.00
316E06	2017-07-10 15:18:00+03	27800.00
316E25	2017-07-14 14:02:00+03	33100.00
316E5E	2017-07-19 17:35:00+03	26000.00
316E63	2017-07-03 20:21:00+03	37900.00
316ED6	2017-07-31 19:28:00+03	277900.00
316EFB	2017-07-25 11:31:00+03	283100.00
316F03	2017-07-30 02:13:00+03	43800.00
316FAC	2017-08-10 05:38:00+03	260900.00
316FF2	2017-08-13 02:08:00+03	45100.00
31707C	2017-07-30 18:44:00+03	19600.00
3170BF	2017-07-20 00:50:00+03	112000.00
317119	2017-08-09 01:03:00+03	54300.00
31712D	2017-07-07 00:36:00+03	68800.00
317175	2017-07-13 12:06:00+03	55800.00
317179	2017-07-27 09:50:00+03	24400.00
31717A	2017-07-03 09:54:00+03	60200.00
3171A2	2017-07-03 00:25:00+03	122000.00
3171BA	2017-07-06 07:41:00+03	104200.00
3171BE	2017-08-04 16:09:00+03	103000.00
317202	2017-07-06 06:18:00+03	26800.00
31720C	2017-07-12 02:24:00+03	68100.00
31723B	2017-07-09 00:02:00+03	39800.00
317290	2017-07-02 00:44:00+03	38400.00
3172AB	2017-08-06 02:52:00+03	48400.00
31733C	2017-07-13 07:45:00+03	39200.00
317385	2017-07-31 04:14:00+03	38400.00
31738A	2017-07-17 19:33:00+03	8200.00
3173A8	2017-07-13 23:32:00+03	67600.00
3173B6	2017-07-17 05:14:00+03	53700.00
31744E	2017-08-07 22:11:00+03	22000.00
31747D	2017-07-15 18:52:00+03	50300.00
317496	2017-07-14 05:26:00+03	112000.00
31753C	2017-07-01 18:18:00+03	38800.00
317576	2017-06-29 11:22:00+03	56900.00
317583	2017-07-09 23:13:00+03	131600.00
3175D3	2017-08-14 13:17:00+03	59300.00
3175FF	2017-07-28 16:42:00+03	223200.00
317628	2017-07-19 18:59:00+03	270000.00
31768A	2017-07-14 18:37:00+03	85000.00
3176AD	2017-07-18 05:33:00+03	254200.00
3176B1	2017-07-11 21:03:00+03	119500.00
317771	2017-08-15 03:58:00+03	47400.00
317790	2017-07-04 17:54:00+03	36600.00
3177FE	2017-07-23 07:43:00+03	199200.00
317845	2017-07-16 13:17:00+03	57500.00
31787B	2017-08-08 18:29:00+03	40600.00
3178EE	2017-07-03 02:18:00+03	25000.00
3178F6	2017-07-15 09:11:00+03	396500.00
31791A	2017-07-10 15:23:00+03	166100.00
317931	2017-08-15 17:31:00+03	32200.00
317941	2017-07-13 20:45:00+03	55800.00
317A35	2017-07-03 20:28:00+03	56000.00
317A5B	2017-08-02 22:01:00+03	17200.00
317A6C	2017-06-28 00:03:00+03	14000.00
317AD7	2017-07-18 14:23:00+03	135400.00
317AFC	2017-08-10 15:48:00+03	69500.00
317B0F	2017-07-20 23:59:00+03	68000.00
317B58	2017-08-14 01:25:00+03	21400.00
317B8A	2017-08-02 05:18:00+03	24600.00
317BC0	2017-07-04 04:28:00+03	11300.00
317BC9	2017-07-30 07:31:00+03	28700.00
317C36	2017-07-07 09:14:00+03	59800.00
317CB6	2017-08-04 11:41:00+03	31400.00
317CB7	2017-08-01 17:37:00+03	20400.00
317CBF	2017-08-05 10:04:00+03	12400.00
317D05	2017-08-06 06:01:00+03	135600.00
317D0C	2017-08-09 02:46:00+03	85700.00
317DB3	2017-07-18 20:13:00+03	87300.00
317DCF	2017-07-21 14:22:00+03	81800.00
317DD4	2017-06-29 06:44:00+03	84000.00
317E1F	2017-07-27 11:21:00+03	26200.00
317E7F	2017-08-06 05:08:00+03	23200.00
317E86	2017-06-29 23:28:00+03	52400.00
317EEC	2017-08-07 18:17:00+03	82900.00
317F3A	2017-07-13 03:14:00+03	33100.00
317F8A	2017-08-13 00:14:00+03	66600.00
318070	2017-07-06 04:14:00+03	69600.00
318090	2017-08-09 08:49:00+03	67400.00
3180B4	2017-07-15 21:25:00+03	51900.00
318164	2017-07-11 03:28:00+03	39200.00
31816A	2017-08-14 14:41:00+03	92800.00
31819B	2017-07-20 12:36:00+03	31400.00
3181A1	2017-07-11 23:10:00+03	162400.00
3181EF	2017-07-31 22:43:00+03	58600.00
31827A	2017-07-30 11:39:00+03	23200.00
3182B1	2017-07-07 20:28:00+03	10800.00
3182F7	2017-07-25 17:52:00+03	111600.00
31831B	2017-08-15 14:07:00+03	15000.00
31832C	2017-07-12 20:07:00+03	27600.00
318376	2017-07-13 13:37:00+03	484700.00
3183AE	2017-07-22 02:30:00+03	23200.00
3183DE	2017-07-01 13:03:00+03	27700.00
31844E	2017-08-14 03:08:00+03	45200.00
318493	2017-07-31 16:16:00+03	51400.00
31849F	2017-08-13 22:23:00+03	32800.00
3184E7	2017-07-30 13:55:00+03	3400.00
3185C2	2017-07-29 22:36:00+03	21800.00
318640	2017-07-07 07:00:00+03	50800.00
318652	2017-08-13 16:37:00+03	240600.00
318655	2017-08-11 21:50:00+03	123200.00
318670	2017-08-04 12:37:00+03	246200.00
3186FC	2017-08-07 16:25:00+03	72300.00
3187BD	2017-08-02 09:13:00+03	131600.00
318829	2017-07-03 05:41:00+03	40000.00
3188D1	2017-07-30 12:24:00+03	99300.00
318912	2017-07-31 23:59:00+03	47000.00
318925	2017-08-06 02:38:00+03	100600.00
318931	2017-07-21 23:34:00+03	16400.00
318952	2017-07-17 12:22:00+03	23200.00
318959	2017-07-22 06:29:00+03	26800.00
31895F	2017-08-14 22:51:00+03	55800.00
31896B	2017-08-05 01:19:00+03	20600.00
31898F	2017-07-21 19:48:00+03	56000.00
3189A1	2017-07-13 21:20:00+03	36800.00
318A58	2017-07-20 22:03:00+03	85400.00
318A6F	2017-07-14 18:04:00+03	20400.00
318AB5	2017-08-02 09:25:00+03	68800.00
318AFB	2017-07-28 19:25:00+03	36600.00
318B2A	2017-07-10 23:24:00+03	29100.00
318B48	2017-07-27 19:56:00+03	35500.00
318BA0	2017-07-24 14:00:00+03	23200.00
318C31	2017-08-12 16:16:00+03	44700.00
318C3B	2017-07-06 04:10:00+03	74900.00
318C74	2017-07-05 11:54:00+03	50800.00
318C85	2017-08-09 15:47:00+03	31600.00
318CA3	2017-07-23 06:21:00+03	166100.00
318CF0	2017-07-27 12:21:00+03	31100.00
318D08	2017-07-25 06:16:00+03	35600.00
318D16	2017-07-16 05:08:00+03	81500.00
318D4A	2017-07-06 12:00:00+03	32200.00
318D70	2017-08-03 07:06:00+03	93700.00
318D81	2017-07-17 20:47:00+03	245500.00
318D8B	2017-07-31 10:55:00+03	46400.00
318DC8	2017-07-05 12:02:00+03	151200.00
318E41	2017-07-27 19:36:00+03	20400.00
318E80	2017-07-10 13:14:00+03	99300.00
318EB6	2017-08-03 22:30:00+03	37800.00
318F4E	2017-08-11 00:32:00+03	167200.00
318F53	2017-08-09 17:32:00+03	43900.00
318F64	2017-07-13 21:55:00+03	92800.00
318F65	2017-07-18 07:47:00+03	51900.00
318F9D	2017-07-16 07:53:00+03	66600.00
318FCF	2017-07-11 07:53:00+03	16400.00
318FDA	2017-08-14 07:26:00+03	312300.00
318FDD	2017-07-21 13:43:00+03	112000.00
318FED	2017-07-19 19:51:00+03	31700.00
319037	2017-08-08 07:36:00+03	177200.00
319067	2017-07-27 16:56:00+03	43100.00
31908F	2017-08-12 02:29:00+03	393800.00
3190DA	2017-07-18 13:11:00+03	57500.00
319113	2017-07-24 16:52:00+03	148700.00
319174	2017-07-28 08:45:00+03	26000.00
3191AE	2017-07-31 00:26:00+03	13200.00
319208	2017-07-09 20:15:00+03	12600.00
319222	2017-08-02 16:26:00+03	22000.00
319254	2017-08-12 07:24:00+03	23200.00
3192AC	2017-08-13 08:15:00+03	26200.00
3192D0	2017-07-05 01:42:00+03	48800.00
31934E	2017-07-11 15:49:00+03	141600.00
319354	2017-08-05 14:23:00+03	67100.00
3193A6	2017-07-11 02:33:00+03	64900.00
319418	2017-07-19 21:33:00+03	239400.00
31941D	2017-08-04 08:00:00+03	76300.00
31948A	2017-08-10 07:00:00+03	65900.00
31948C	2017-08-03 13:32:00+03	193700.00
319490	2017-07-23 20:18:00+03	169300.00
31949D	2017-07-15 14:28:00+03	62600.00
3194D8	2017-07-14 23:19:00+03	51300.00
31952F	2017-07-23 18:14:00+03	113800.00
319536	2017-07-07 20:19:00+03	113200.00
31955A	2017-08-14 08:12:00+03	6000.00
319621	2017-08-14 01:35:00+03	260300.00
319647	2017-07-22 13:21:00+03	57800.00
3196C0	2017-07-06 22:40:00+03	90200.00
3196C9	2017-08-08 07:41:00+03	69500.00
3196D7	2017-08-05 16:39:00+03	37200.00
319788	2017-08-01 17:50:00+03	174500.00
31979D	2017-07-17 07:05:00+03	84000.00
319817	2017-07-02 20:05:00+03	12600.00
319821	2017-08-14 17:06:00+03	12600.00
319827	2017-07-19 22:40:00+03	45100.00
3198E1	2017-07-15 02:00:00+03	34600.00
319916	2017-07-26 13:57:00+03	78300.00
31991C	2017-07-07 23:39:00+03	29600.00
3199B0	2017-08-14 02:11:00+03	77200.00
3199B8	2017-07-28 02:19:00+03	190700.00
3199DE	2017-08-08 19:15:00+03	84300.00
319A04	2017-07-27 03:22:00+03	148800.00
319A36	2017-08-08 21:33:00+03	52000.00
319A40	2017-07-14 15:59:00+03	52000.00
319A9C	2017-08-11 07:03:00+03	47500.00
319AA3	2017-07-06 17:24:00+03	193600.00
319AF2	2017-08-14 04:08:00+03	43200.00
319B03	2017-07-03 22:04:00+03	17800.00
319B17	2017-07-24 15:07:00+03	43600.00
319B61	2017-07-10 18:42:00+03	94700.00
319B7E	2017-08-01 09:11:00+03	61500.00
319B9A	2017-07-14 01:43:00+03	46000.00
319BDF	2017-08-15 09:10:00+03	120700.00
319C06	2017-08-07 15:30:00+03	55800.00
319C0F	2017-07-24 23:20:00+03	26400.00
319C1C	2017-07-11 06:52:00+03	55800.00
319C37	2017-07-20 04:59:00+03	40200.00
319CD3	2017-08-06 07:26:00+03	28000.00
319D17	2017-07-16 03:17:00+03	429000.00
319DAA	2017-07-30 13:13:00+03	30200.00
319DAF	2017-07-05 05:07:00+03	285300.00
319E18	2017-07-12 20:46:00+03	56600.00
319E23	2017-06-30 11:12:00+03	13600.00
319E24	2017-07-04 15:39:00+03	55800.00
319E47	2017-07-06 16:35:00+03	58900.00
319E96	2017-07-09 22:05:00+03	43500.00
319ECA	2017-07-21 16:41:00+03	248300.00
319ECC	2017-08-02 06:02:00+03	24200.00
319F17	2017-07-23 02:04:00+03	135100.00
319F3B	2017-07-05 07:37:00+03	199600.00
319F67	2017-08-06 18:24:00+03	28300.00
319F6C	2017-07-31 14:31:00+03	26800.00
319F71	2017-08-06 06:38:00+03	105600.00
319F7B	2017-07-31 23:12:00+03	28800.00
319FCF	2017-07-14 05:22:00+03	496600.00
31A0C7	2017-08-12 05:28:00+03	13400.00
31A155	2017-08-10 06:51:00+03	29200.00
31A164	2017-07-15 14:16:00+03	112000.00
31A269	2017-08-06 01:40:00+03	28800.00
31A2E9	2017-07-27 16:04:00+03	119600.00
31A2EF	2017-07-30 20:04:00+03	45200.00
31A32A	2017-07-13 19:07:00+03	209900.00
31A32B	2017-07-08 03:16:00+03	18600.00
31A345	2017-07-16 07:27:00+03	93700.00
31A366	2017-07-25 08:45:00+03	22100.00
31A36E	2017-07-24 12:05:00+03	92800.00
31A376	2017-08-02 19:44:00+03	51800.00
31A390	2017-07-09 07:30:00+03	31200.00
31A411	2017-07-07 17:07:00+03	62600.00
31A50D	2017-07-28 09:00:00+03	43500.00
31A581	2017-07-22 03:12:00+03	23200.00
31A5F7	2017-07-18 02:17:00+03	67200.00
31A5FF	2017-07-10 18:34:00+03	37200.00
31A687	2017-08-09 14:00:00+03	60700.00
31A6CA	2017-08-08 03:33:00+03	23400.00
31A73C	2017-08-02 02:43:00+03	24400.00
31A797	2017-07-18 19:54:00+03	44600.00
31A854	2017-07-29 20:55:00+03	26000.00
31A861	2017-07-05 07:23:00+03	73600.00
31A92E	2017-07-28 17:30:00+03	112000.00
31A994	2017-08-14 16:26:00+03	58800.00
31A9DB	2017-08-02 19:01:00+03	21800.00
31AA97	2017-06-29 03:25:00+03	99900.00
31AAC3	2017-07-29 04:14:00+03	24400.00
31AB0E	2017-07-05 21:47:00+03	48800.00
31AB14	2017-07-04 12:52:00+03	164400.00
31AB6A	2017-08-09 20:23:00+03	13800.00
31AB88	2017-07-10 01:11:00+03	96800.00
31AC12	2017-06-28 23:10:00+03	26700.00
31ACA2	2017-07-17 16:29:00+03	21400.00
31AD4F	2017-07-08 22:19:00+03	25100.00
31AD6F	2017-07-18 12:42:00+03	160200.00
31AD7E	2017-07-03 16:42:00+03	24700.00
31ADBA	2017-07-20 10:23:00+03	32800.00
31ADD5	2017-07-11 08:19:00+03	52000.00
31AE78	2017-07-23 19:49:00+03	48300.00
31AEA8	2017-06-30 05:42:00+03	65500.00
31AED3	2017-08-04 18:57:00+03	52900.00
31AED9	2017-08-13 00:31:00+03	47400.00
31AEFB	2017-08-07 14:05:00+03	22000.00
31AF1E	2017-07-12 09:27:00+03	20200.00
31AF43	2017-07-11 22:41:00+03	56900.00
31AF5D	2017-07-15 08:16:00+03	49400.00
31AF8F	2017-07-05 06:47:00+03	12200.00
31B092	2017-07-01 18:23:00+03	92800.00
31B105	2017-07-19 19:13:00+03	56000.00
31B110	2017-07-28 23:40:00+03	46000.00
31B1C5	2017-07-26 14:47:00+03	105000.00
31B267	2017-07-09 15:42:00+03	32200.00
31B281	2017-07-30 22:02:00+03	13800.00
31B288	2017-07-27 15:46:00+03	24800.00
31B2CB	2017-07-31 22:40:00+03	12600.00
31B305	2017-08-12 13:46:00+03	369000.00
31B47F	2017-08-13 22:54:00+03	77900.00
31B4CA	2017-07-03 04:18:00+03	199600.00
31B50E	2017-07-31 10:13:00+03	35800.00
31B567	2017-08-01 16:20:00+03	77200.00
31B587	2017-08-04 03:45:00+03	184300.00
31B595	2017-07-06 15:57:00+03	67600.00
31B5B4	2017-07-28 05:14:00+03	81300.00
31B5C9	2017-07-19 03:41:00+03	232300.00
31B5DA	2017-07-09 05:42:00+03	116400.00
31B5E8	2017-07-04 16:59:00+03	48500.00
31B627	2017-08-05 14:59:00+03	25600.00
31B69F	2017-08-14 05:27:00+03	112000.00
31B6AF	2017-07-05 04:41:00+03	43000.00
31B6B1	2017-08-11 03:38:00+03	16400.00
31B6EC	2017-08-11 14:25:00+03	26000.00
31B6ED	2017-08-15 04:48:00+03	24700.00
31B713	2017-07-22 18:29:00+03	34800.00
31B7C0	2017-07-28 01:28:00+03	193700.00
31B7E6	2017-07-05 07:20:00+03	20200.00
31B7F6	2017-07-22 11:35:00+03	32800.00
31B805	2017-07-27 23:07:00+03	28800.00
31B809	2017-08-14 17:46:00+03	19800.00
31B818	2017-07-03 11:04:00+03	84100.00
31B821	2017-07-24 17:04:00+03	58800.00
31B872	2017-08-11 18:31:00+03	63900.00
31B8C7	2017-07-21 03:24:00+03	23200.00
31B8CA	2017-07-08 16:47:00+03	57600.00
31B8F8	2017-07-16 18:47:00+03	17200.00
31B98C	2017-08-10 13:48:00+03	97700.00
31B9E3	2017-07-18 09:34:00+03	8400.00
31BA5C	2017-07-23 12:48:00+03	46400.00
31BA70	2017-07-12 12:01:00+03	24400.00
31BABF	2017-08-15 15:26:00+03	12600.00
31BAD9	2017-07-18 11:47:00+03	57800.00
31BAF7	2017-07-12 09:00:00+03	27300.00
31BB55	2017-08-01 07:03:00+03	104700.00
31BBA5	2017-07-12 06:20:00+03	100600.00
31BBF7	2017-07-04 11:42:00+03	26800.00
31BBFE	2017-07-11 16:07:00+03	36400.00
31BC0D	2017-07-23 00:26:00+03	19800.00
31BC30	2017-07-01 02:05:00+03	28800.00
31BC71	2017-08-14 11:08:00+03	23200.00
31BCF0	2017-08-06 04:20:00+03	62600.00
31BCF5	2017-08-09 10:26:00+03	46700.00
31BD3F	2017-08-12 15:08:00+03	220200.00
31BE45	2017-08-15 05:10:00+03	56000.00
31BE6B	2017-08-12 20:10:00+03	48400.00
31BE81	2017-08-02 15:31:00+03	44800.00
31BE87	2017-07-30 12:29:00+03	153300.00
31BEB5	2017-07-13 20:16:00+03	22000.00
31BEE4	2017-08-06 15:43:00+03	121100.00
31BF1D	2017-07-30 12:13:00+03	66800.00
31BF28	2017-07-07 00:32:00+03	192800.00
31BF6E	2017-06-27 07:23:00+03	47200.00
31BF82	2017-07-04 06:05:00+03	19200.00
31BF87	2017-08-05 14:52:00+03	51400.00
31BF98	2017-07-09 16:01:00+03	57600.00
31BFA5	2017-08-05 14:16:00+03	40000.00
31BFCB	2017-07-01 07:43:00+03	35300.00
31C070	2017-07-29 15:13:00+03	46300.00
31C0C3	2017-08-02 21:04:00+03	14000.00
31C0D3	2017-07-16 04:49:00+03	44600.00
31C10F	2017-07-07 15:17:00+03	62300.00
31C131	2017-07-12 01:52:00+03	52800.00
31C194	2017-07-19 01:44:00+03	56000.00
31C1B0	2017-07-09 14:33:00+03	38400.00
31C1D9	2017-07-29 15:33:00+03	125400.00
31C20A	2017-08-02 04:37:00+03	70800.00
31C219	2017-07-13 06:48:00+03	93900.00
31C282	2017-08-08 22:13:00+03	52900.00
31C2ED	2017-07-30 01:07:00+03	28800.00
31C34E	2017-07-13 22:04:00+03	136200.00
31C3A2	2017-08-10 15:40:00+03	18000.00
31C3B8	2017-08-01 06:51:00+03	14400.00
31C3C3	2017-07-03 10:05:00+03	55800.00
31C3C9	2017-08-08 18:38:00+03	96400.00
31C3ED	2017-08-06 22:45:00+03	136300.00
31C414	2017-07-19 15:42:00+03	73500.00
31C41D	2017-07-13 05:07:00+03	149300.00
31C46F	2017-07-12 05:56:00+03	51900.00
31C476	2017-07-22 03:05:00+03	29600.00
31C4ED	2017-06-30 21:44:00+03	40300.00
31C55D	2017-08-15 15:41:00+03	6700.00
31C5C8	2017-08-11 15:49:00+03	68000.00
31C5DE	2017-07-17 15:26:00+03	32800.00
31C5F3	2017-07-20 08:22:00+03	69500.00
31C6CB	2017-07-01 07:13:00+03	67700.00
31C6DA	2017-07-13 23:30:00+03	123600.00
31C6F7	2017-07-26 13:48:00+03	65600.00
31C70D	2017-07-21 13:13:00+03	83900.00
31C736	2017-07-13 09:37:00+03	46000.00
31C766	2017-07-05 22:21:00+03	36000.00
31C7B6	2017-06-30 09:43:00+03	50600.00
31C7CA	2017-08-06 08:58:00+03	23600.00
31C7F9	2017-07-03 08:00:00+03	60400.00
31C820	2017-07-26 18:22:00+03	97800.00
31C840	2017-07-23 02:49:00+03	116000.00
31C84E	2017-07-12 08:01:00+03	17800.00
31C953	2017-07-17 12:29:00+03	55800.00
31C988	2017-08-04 04:48:00+03	56100.00
31C98C	2017-07-29 14:50:00+03	67100.00
31C9E7	2017-07-27 15:09:00+03	51900.00
31C9F0	2017-07-30 08:10:00+03	123000.00
31CA05	2017-07-28 11:02:00+03	105600.00
31CA17	2017-07-10 23:26:00+03	125200.00
31CA80	2017-07-23 00:43:00+03	35600.00
31CAA5	2017-07-02 20:10:00+03	81200.00
31CAFA	2017-08-14 13:23:00+03	46400.00
31CB9B	2017-08-09 20:46:00+03	103100.00
31CB9D	2017-07-26 02:34:00+03	46400.00
31CBAF	2017-07-29 18:48:00+03	85000.00
31CBC5	2017-07-13 05:04:00+03	342400.00
31CBD3	2017-07-13 04:03:00+03	56000.00
31CBFB	2017-08-07 12:03:00+03	56600.00
31CC18	2017-07-06 19:03:00+03	46000.00
31CC1D	2017-08-12 07:07:00+03	45100.00
31CC3D	2017-07-25 05:00:00+03	102100.00
31CC9E	2017-07-07 18:40:00+03	57800.00
31CCD3	2017-07-25 09:42:00+03	85000.00
31CCD5	2017-07-11 16:35:00+03	80900.00
31CD2D	2017-07-25 12:12:00+03	13400.00
31CD72	2017-07-29 00:01:00+03	89200.00
31CDC1	2017-07-11 21:41:00+03	36900.00
31CE2A	2017-07-07 10:23:00+03	79900.00
31CE3C	2017-08-10 07:37:00+03	123000.00
31CEA9	2017-08-06 06:40:00+03	40800.00
31CEFA	2017-07-14 18:29:00+03	47000.00
31CF2E	2017-08-14 17:22:00+03	28000.00
31CF46	2017-08-03 18:36:00+03	59100.00
31CF6B	2017-08-07 12:49:00+03	48800.00
31CF6D	2017-08-03 09:05:00+03	98000.00
31CF7A	2017-07-18 18:40:00+03	13400.00
31CF8C	2017-07-19 17:28:00+03	85000.00
31CFCA	2017-07-24 18:56:00+03	25600.00
31CFE1	2017-08-04 00:56:00+03	18300.00
31D054	2017-08-13 22:04:00+03	99200.00
31D0EB	2017-07-23 00:31:00+03	28000.00
31D128	2017-08-05 00:51:00+03	81600.00
31D163	2017-07-31 16:45:00+03	40800.00
31D192	2017-07-31 00:45:00+03	85000.00
31D1A2	2017-07-11 20:49:00+03	84100.00
31D26E	2017-08-08 02:37:00+03	28000.00
31D272	2017-07-07 14:43:00+03	31700.00
31D29C	2017-08-14 20:25:00+03	56000.00
31D2AA	2017-07-06 09:57:00+03	137600.00
31D2D2	2017-07-06 13:59:00+03	82900.00
31D342	2017-07-21 22:38:00+03	31100.00
31D363	2017-07-29 09:09:00+03	205000.00
31D374	2017-07-31 16:41:00+03	26000.00
31D3A8	2017-07-24 12:36:00+03	23200.00
31D3BE	2017-08-03 21:36:00+03	90600.00
31D3CA	2017-07-28 21:40:00+03	136200.00
31D47B	2017-08-05 17:30:00+03	44800.00
31D4DA	2017-08-14 08:01:00+03	56600.00
31D4DC	2017-08-04 15:55:00+03	56000.00
31D557	2017-07-11 03:38:00+03	62600.00
31D58C	2017-07-12 16:58:00+03	168000.00
31D5D7	2017-08-12 09:23:00+03	19800.00
31D684	2017-07-23 14:25:00+03	36800.00
31D695	2017-07-11 11:50:00+03	43200.00
31D6D9	2017-08-01 13:51:00+03	67400.00
31D6E6	2017-08-06 08:18:00+03	111600.00
31D717	2017-07-20 06:16:00+03	16400.00
31D721	2017-07-05 09:36:00+03	177200.00
31D732	2017-07-25 17:36:00+03	41800.00
31D782	2017-07-30 00:00:00+03	114600.00
31D797	2017-07-28 06:29:00+03	67100.00
31D79F	2017-07-20 15:53:00+03	301800.00
31D7D0	2017-08-07 10:30:00+03	62600.00
31D7DE	2017-08-09 23:49:00+03	369000.00
31D889	2017-08-12 03:34:00+03	88400.00
31D890	2017-07-23 05:02:00+03	22600.00
31D8AE	2017-07-01 05:33:00+03	114600.00
31D8F5	2017-07-07 10:12:00+03	28800.00
31D90D	2017-07-06 14:32:00+03	18600.00
31D935	2017-07-15 00:21:00+03	52700.00
31D9B6	2017-08-08 21:07:00+03	31600.00
31D9FB	2017-07-14 20:10:00+03	23600.00
31D9FC	2017-06-29 22:08:00+03	53200.00
31DA0A	2017-07-04 08:33:00+03	52300.00
31DA34	2017-08-12 21:28:00+03	96100.00
31DA7C	2017-08-04 23:01:00+03	73500.00
31DAA2	2017-07-23 15:32:00+03	31600.00
31DAC6	2017-07-31 04:37:00+03	55800.00
31DC10	2017-07-13 20:32:00+03	260300.00
31DC27	2017-08-09 20:49:00+03	131900.00
31DC5B	2017-08-11 13:15:00+03	81300.00
31DCCF	2017-08-02 02:05:00+03	14000.00
31DD1B	2017-08-12 18:38:00+03	57300.00
31DD36	2017-07-28 07:18:00+03	89400.00
31DD78	2017-07-04 08:30:00+03	177600.00
31DDF0	2017-08-08 02:47:00+03	31400.00
31DE37	2017-08-01 14:25:00+03	53500.00
31DE46	2017-07-16 16:30:00+03	47100.00
31DE86	2017-08-03 02:21:00+03	69200.00
31DE9C	2017-08-08 01:18:00+03	38400.00
31DECC	2017-08-15 02:04:00+03	62900.00
31DED7	2017-08-06 14:25:00+03	224000.00
31DF6B	2017-07-23 11:29:00+03	15800.00
31DF98	2017-08-07 01:44:00+03	64800.00
31DFCF	2017-08-10 21:33:00+03	47000.00
31DFD4	2017-07-01 01:24:00+03	35400.00
31E02D	2017-07-03 22:15:00+03	114400.00
31E04F	2017-07-29 01:20:00+03	61800.00
31E05C	2017-08-10 15:31:00+03	24300.00
31E0F3	2017-07-24 16:28:00+03	52000.00
31E175	2017-08-02 21:42:00+03	74000.00
31E269	2017-07-17 08:10:00+03	35600.00
31E286	2017-07-01 06:06:00+03	135100.00
31E290	2017-07-04 00:04:00+03	24800.00
31E321	2017-08-11 11:34:00+03	436900.00
31E344	2017-07-21 19:51:00+03	96800.00
31E345	2017-06-29 07:14:00+03	182300.00
31E378	2017-07-25 16:25:00+03	168000.00
31E397	2017-06-29 12:57:00+03	53300.00
31E3DC	2017-07-29 00:39:00+03	81300.00
31E4AF	2017-07-28 10:18:00+03	133100.00
31E4BC	2017-07-27 02:38:00+03	125400.00
31E4C1	2017-08-10 22:12:00+03	36200.00
31E4E1	2017-08-15 16:18:00+03	11700.00
31E524	2017-07-22 21:07:00+03	50800.00
31E550	2017-08-11 21:30:00+03	57600.00
31E5C0	2017-07-29 00:13:00+03	20400.00
31E5DB	2017-07-23 17:34:00+03	195800.00
31E5DF	2017-07-16 19:35:00+03	31400.00
31E61A	2017-08-05 00:06:00+03	21600.00
31E66E	2017-07-22 12:16:00+03	30000.00
31E681	2017-08-06 19:41:00+03	6600.00
31E691	2017-07-15 12:56:00+03	37900.00
31E6D8	2017-07-16 12:16:00+03	73600.00
31E6DC	2017-07-10 06:35:00+03	32700.00
31E71F	2017-07-20 03:36:00+03	10800.00
31E730	2017-07-07 11:34:00+03	59300.00
31E750	2017-07-17 20:37:00+03	179400.00
31E752	2017-07-27 06:51:00+03	27900.00
31E77B	2017-07-09 13:22:00+03	31600.00
31E7BC	2017-07-12 15:07:00+03	56600.00
31E83C	2017-07-21 10:35:00+03	187600.00
31E8AA	2017-07-23 21:07:00+03	92000.00
31E90C	2017-07-21 10:33:00+03	37100.00
31E946	2017-07-18 20:26:00+03	28000.00
31E94D	2017-07-05 16:40:00+03	22000.00
31EA04	2017-07-11 22:31:00+03	21000.00
31EA21	2017-07-20 20:11:00+03	68500.00
31EA29	2017-08-11 02:18:00+03	59800.00
31EA60	2017-07-01 00:35:00+03	49600.00
31EAC1	2017-08-02 15:24:00+03	126900.00
31EB3A	2017-07-04 20:28:00+03	40600.00
31EBBE	2017-07-29 20:48:00+03	75500.00
31EBD2	2017-08-07 17:33:00+03	81600.00
31EC02	2017-07-06 07:13:00+03	43200.00
31EC39	2017-07-09 12:19:00+03	20000.00
31EC4A	2017-07-03 05:03:00+03	37900.00
31EC80	2017-07-11 06:10:00+03	26800.00
31ECA9	2017-07-23 06:56:00+03	12200.00
31ED15	2017-08-04 21:12:00+03	86000.00
31EDC9	2017-07-05 12:36:00+03	169300.00
31EDEF	2017-06-27 13:49:00+03	39600.00
31EE4A	2017-07-08 19:16:00+03	31600.00
31EE64	2017-06-30 20:23:00+03	25900.00
31EE77	2017-07-20 02:15:00+03	57800.00
31EF4E	2017-08-06 05:50:00+03	73500.00
31EF75	2017-07-19 23:21:00+03	25200.00
31EFDB	2017-07-16 12:15:00+03	123000.00
31EFDD	2017-08-09 23:44:00+03	83000.00
31F001	2017-08-02 23:27:00+03	13400.00
31F059	2017-07-26 04:29:00+03	6300.00
31F093	2017-07-19 18:07:00+03	54400.00
31F0B7	2017-08-11 16:06:00+03	49300.00
31F0B8	2017-06-30 01:46:00+03	25600.00
31F0DE	2017-08-10 07:56:00+03	25200.00
31F0EE	2017-07-10 10:13:00+03	133200.00
31F11E	2017-07-23 20:28:00+03	125100.00
31F127	2017-07-09 20:41:00+03	44800.00
31F183	2017-07-13 04:44:00+03	186900.00
31F1F0	2017-07-08 02:20:00+03	29800.00
31F252	2017-08-01 16:58:00+03	73300.00
31F262	2017-08-04 18:39:00+03	47100.00
31F284	2017-06-29 22:02:00+03	31400.00
31F2A6	2017-07-19 11:27:00+03	46300.00
31F2AF	2017-07-05 02:28:00+03	66600.00
31F31A	2017-07-23 21:30:00+03	18500.00
31F35B	2017-07-02 00:37:00+03	57800.00
31F3B3	2017-07-14 23:07:00+03	26000.00
31F3E8	2017-08-07 02:30:00+03	72300.00
31F3F7	2017-07-13 09:36:00+03	28800.00
31F463	2017-07-12 13:49:00+03	65900.00
31F46C	2017-07-13 06:18:00+03	70800.00
31F48B	2017-07-29 03:16:00+03	12000.00
31F4CC	2017-08-02 23:45:00+03	26800.00
31F4DA	2017-08-12 12:55:00+03	49800.00
31F4EE	2017-08-02 22:26:00+03	175300.00
31F587	2017-07-13 05:21:00+03	134700.00
31F5ED	2017-07-26 09:39:00+03	112000.00
31F612	2017-08-03 23:32:00+03	42700.00
31F627	2017-08-13 16:39:00+03	40800.00
31F632	2017-07-03 14:11:00+03	32200.00
31F638	2017-07-03 19:59:00+03	21400.00
31F64E	2017-08-04 09:46:00+03	32800.00
31F695	2017-07-08 12:41:00+03	55800.00
31F6F2	2017-07-17 17:30:00+03	55400.00
31F753	2017-08-06 05:40:00+03	173900.00
31F78C	2017-08-01 22:59:00+03	14000.00
31F7D9	2017-07-30 10:01:00+03	135400.00
31F7EF	2017-08-14 22:36:00+03	25400.00
31F7F3	2017-08-02 07:40:00+03	65600.00
31F80C	2017-07-31 07:15:00+03	44600.00
31F81F	2017-07-26 05:53:00+03	27200.00
31F82A	2017-08-15 03:04:00+03	15000.00
31F908	2017-07-31 02:18:00+03	51200.00
31F96E	2017-07-29 01:00:00+03	111600.00
31F99C	2017-07-09 05:10:00+03	10800.00
31FA00	2017-07-01 03:51:00+03	21800.00
31FA27	2017-07-15 03:05:00+03	12600.00
31FA48	2017-08-03 12:25:00+03	42800.00
31FAA5	2017-08-08 12:17:00+03	35800.00
31FAB6	2017-07-23 13:11:00+03	56000.00
31FAD1	2017-07-19 14:52:00+03	51800.00
31FAE2	2017-07-02 07:58:00+03	62600.00
31FAE9	2017-07-21 15:53:00+03	592200.00
31FAEF	2017-07-18 09:07:00+03	40000.00
31FB2E	2017-07-17 18:46:00+03	58400.00
31FBBF	2017-07-23 22:39:00+03	270700.00
31FC42	2017-07-10 08:14:00+03	31200.00
31FC4A	2017-07-11 10:23:00+03	112100.00
31FC60	2017-08-09 23:08:00+03	70800.00
31FD0F	2017-07-27 12:01:00+03	271100.00
31FD83	2017-07-22 16:05:00+03	6700.00
31FDC5	2017-07-06 00:36:00+03	12400.00
31FE17	2017-07-08 07:21:00+03	6600.00
31FE60	2017-07-02 19:02:00+03	185500.00
31FE84	2017-07-16 02:55:00+03	55800.00
31FE9B	2017-08-12 14:21:00+03	54200.00
31FEB2	2017-07-02 02:20:00+03	85000.00
31FF97	2017-07-08 04:24:00+03	120100.00
31FFCD	2017-07-07 03:12:00+03	98800.00
31FFDE	2017-08-01 05:33:00+03	21400.00
32004F	2017-07-13 14:38:00+03	67200.00
320068	2017-08-14 01:31:00+03	46400.00
320071	2017-07-08 06:46:00+03	75600.00
32012F	2017-08-14 18:58:00+03	40000.00
320163	2017-08-01 06:23:00+03	160200.00
32016C	2017-07-25 21:57:00+03	27800.00
3201C8	2017-07-03 21:02:00+03	129700.00
3201EF	2017-08-02 09:52:00+03	56000.00
320215	2017-07-10 23:33:00+03	99200.00
32024B	2017-07-17 07:21:00+03	15400.00
3202CB	2017-08-01 18:10:00+03	84700.00
3202CD	2017-07-22 06:53:00+03	248400.00
3202F8	2017-08-11 19:07:00+03	45000.00
32031E	2017-08-08 05:36:00+03	39800.00
320324	2017-08-14 12:22:00+03	35300.00
32034E	2017-07-21 01:26:00+03	133200.00
320357	2017-07-28 00:09:00+03	41600.00
320391	2017-07-13 07:05:00+03	36800.00
3203CD	2017-07-11 10:56:00+03	29600.00
3203D7	2017-07-08 00:38:00+03	22200.00
3203DE	2017-07-20 13:48:00+03	45200.00
3203F2	2017-07-20 05:32:00+03	169900.00
3203F5	2017-07-02 03:30:00+03	52400.00
320439	2017-08-14 05:08:00+03	270700.00
32044E	2017-08-13 21:00:00+03	43600.00
320452	2017-07-20 20:55:00+03	115100.00
3204F2	2017-08-01 19:26:00+03	6400.00
32050A	2017-06-29 21:14:00+03	515000.00
32050D	2017-07-22 21:20:00+03	95200.00
320586	2017-07-30 18:06:00+03	71200.00
32058F	2017-07-25 19:28:00+03	59800.00
320591	2017-08-05 08:16:00+03	40600.00
320595	2017-07-20 02:30:00+03	59900.00
3205FC	2017-08-06 19:54:00+03	114200.00
32061B	2017-08-08 18:31:00+03	78700.00
320633	2017-08-01 21:42:00+03	67000.00
320638	2017-08-14 01:19:00+03	84200.00
320674	2017-08-15 13:14:00+03	85500.00
320681	2017-07-18 19:46:00+03	51500.00
320695	2017-07-10 06:24:00+03	66600.00
320769	2017-07-29 05:39:00+03	76600.00
32076A	2017-07-25 18:35:00+03	24400.00
320793	2017-08-03 02:04:00+03	23900.00
3207C9	2017-07-04 18:16:00+03	33600.00
320847	2017-06-30 01:07:00+03	28000.00
32086E	2017-07-03 16:47:00+03	22000.00
320969	2017-07-22 06:00:00+03	57500.00
32096E	2017-07-10 19:11:00+03	24800.00
3209CD	2017-07-16 06:15:00+03	88200.00
320A82	2017-07-07 03:27:00+03	24800.00
320A92	2017-06-29 02:07:00+03	6000.00
320A9D	2017-07-28 06:23:00+03	68900.00
320AAF	2017-08-01 17:00:00+03	48700.00
320AFF	2017-08-10 23:11:00+03	70100.00
320BE6	2017-07-29 23:50:00+03	58400.00
320BF8	2017-07-09 11:38:00+03	12600.00
320C00	2017-08-02 02:50:00+03	45200.00
320C21	2017-07-17 02:04:00+03	48700.00
320C52	2017-07-28 19:58:00+03	182300.00
320C68	2017-07-03 00:55:00+03	73300.00
320C7F	2017-07-12 13:59:00+03	306500.00
320CB0	2017-07-26 11:55:00+03	8400.00
320CE5	2017-08-07 01:08:00+03	61800.00
320D06	2017-07-25 01:33:00+03	43900.00
320D22	2017-07-21 12:36:00+03	242700.00
320D36	2017-07-11 05:11:00+03	34000.00
320DDE	2017-07-15 11:53:00+03	110300.00
320EBB	2017-08-08 19:01:00+03	56900.00
320EED	2017-07-11 02:39:00+03	69700.00
320F32	2017-08-12 18:58:00+03	13400.00
320F46	2017-07-20 16:11:00+03	213200.00
320F58	2017-07-05 16:19:00+03	199600.00
320F73	2017-08-08 13:45:00+03	28000.00
32104B	2017-07-29 05:30:00+03	68800.00
321071	2017-08-07 14:20:00+03	75300.00
3210DE	2017-08-05 05:18:00+03	28000.00
3210F0	2017-07-24 21:56:00+03	105900.00
3211A9	2017-07-05 06:48:00+03	59800.00
3211CF	2017-07-26 13:18:00+03	235700.00
321247	2017-06-29 16:16:00+03	56600.00
32129D	2017-08-09 21:48:00+03	66600.00
3212B5	2017-07-23 20:02:00+03	77200.00
3212E9	2017-06-29 18:47:00+03	26700.00
32133D	2017-07-27 17:23:00+03	43000.00
321374	2017-07-22 05:50:00+03	46000.00
3213AE	2017-07-29 22:57:00+03	117600.00
3213DB	2017-07-14 20:07:00+03	24400.00
3213FB	2017-08-04 01:36:00+03	135200.00
321475	2017-07-29 20:01:00+03	83700.00
321497	2017-07-05 05:50:00+03	137000.00
3214B9	2017-07-27 17:09:00+03	223200.00
3214C8	2017-07-14 10:18:00+03	51300.00
321519	2017-07-27 15:46:00+03	68800.00
32154B	2017-08-15 07:02:00+03	147900.00
321587	2017-07-14 16:14:00+03	33600.00
32159C	2017-08-05 10:54:00+03	20400.00
3215E2	2017-08-04 15:22:00+03	142400.00
321615	2017-07-28 09:01:00+03	116900.00
321640	2017-07-18 20:15:00+03	28800.00
3216A6	2017-08-11 06:12:00+03	38600.00
3216DA	2017-07-31 20:27:00+03	185000.00
321708	2017-08-13 21:39:00+03	27200.00
32178F	2017-08-08 18:15:00+03	24400.00
321819	2017-07-25 06:34:00+03	24700.00
321876	2017-07-12 21:46:00+03	65900.00
321888	2017-07-06 16:37:00+03	516000.00
321918	2017-07-30 18:43:00+03	44700.00
321965	2017-08-10 15:47:00+03	99600.00
32199D	2017-07-29 21:56:00+03	40100.00
3219F3	2017-08-13 18:07:00+03	76600.00
321A04	2017-07-25 08:41:00+03	11800.00
321A0A	2017-07-06 17:17:00+03	270700.00
321A49	2017-06-30 13:36:00+03	41600.00
321AB1	2017-07-27 18:57:00+03	22100.00
321AE1	2017-07-19 15:32:00+03	176600.00
321B0D	2017-08-04 17:01:00+03	10800.00
321B2C	2017-07-24 12:33:00+03	20800.00
321B48	2017-07-21 22:48:00+03	113200.00
321BBE	2017-07-11 15:32:00+03	57300.00
321C32	2017-07-05 10:27:00+03	135000.00
321CBA	2017-08-06 05:13:00+03	10700.00
321CBD	2017-07-05 10:37:00+03	282300.00
321D23	2017-07-03 13:56:00+03	92900.00
321D2C	2017-08-10 02:31:00+03	59800.00
321D58	2017-07-10 20:19:00+03	70400.00
321DF3	2017-07-31 02:29:00+03	86600.00
321E19	2017-07-08 07:11:00+03	52900.00
322043	2017-07-22 23:58:00+03	50000.00
322090	2017-06-30 19:31:00+03	126300.00
3220C2	2017-08-11 05:39:00+03	67600.00
3220EA	2017-06-25 19:12:00+03	34800.00
3221F3	2017-07-19 20:44:00+03	13800.00
322255	2017-06-28 05:53:00+03	18000.00
322290	2017-08-14 17:08:00+03	123000.00
3222A0	2017-07-08 16:43:00+03	80000.00
3222B1	2017-07-09 18:29:00+03	72300.00
32231B	2017-07-05 09:34:00+03	32700.00
322332	2017-08-12 19:55:00+03	52700.00
3223AF	2017-07-17 02:24:00+03	64100.00
3223EC	2017-07-08 03:25:00+03	25800.00
3223EE	2017-07-06 06:22:00+03	29600.00
322402	2017-08-11 07:06:00+03	306800.00
322452	2017-08-06 10:35:00+03	75300.00
32245C	2017-07-10 03:22:00+03	122000.00
322482	2017-07-11 18:31:00+03	57300.00
32259B	2017-07-31 07:02:00+03	29600.00
3225AC	2017-07-13 12:07:00+03	147900.00
32260A	2017-08-14 19:46:00+03	131100.00
322619	2017-08-14 03:47:00+03	56600.00
322624	2017-08-15 10:30:00+03	246000.00
322667	2017-08-10 22:09:00+03	13700.00
3226AE	2017-07-27 18:08:00+03	99700.00
3226DF	2017-07-07 05:13:00+03	16800.00
3226E3	2017-08-06 15:39:00+03	58000.00
322718	2017-08-09 08:12:00+03	136500.00
32275B	2017-07-25 03:02:00+03	67600.00
322770	2017-07-16 10:27:00+03	165000.00
322784	2017-07-06 14:29:00+03	124300.00
3227B7	2017-07-06 14:00:00+03	121800.00
3227BA	2017-08-10 16:18:00+03	356400.00
322807	2017-06-29 21:28:00+03	43900.00
32281E	2017-07-26 16:47:00+03	24400.00
322905	2017-08-11 03:04:00+03	260300.00
322940	2017-08-06 16:19:00+03	547600.00
32297B	2017-08-12 03:59:00+03	56600.00
32299A	2017-07-06 02:28:00+03	71100.00
3229BC	2017-07-25 06:22:00+03	19600.00
3229E8	2017-07-07 15:45:00+03	80200.00
3229EB	2017-08-10 20:07:00+03	23200.00
3229F0	2017-08-05 22:46:00+03	49200.00
322A42	2017-08-03 04:20:00+03	58400.00
322A6C	2017-08-11 04:16:00+03	39200.00
322A79	2017-06-25 19:45:00+03	118400.00
322A8C	2017-07-04 21:45:00+03	16400.00
322AA6	2017-07-11 20:51:00+03	28800.00
322ADB	2017-08-04 20:01:00+03	25400.00
322B25	2017-08-08 13:24:00+03	165900.00
322C8A	2017-07-28 03:12:00+03	25400.00
322CB2	2017-07-25 02:30:00+03	88800.00
322CC4	2017-08-07 02:10:00+03	64800.00
322CF7	2017-07-18 05:53:00+03	23600.00
322D05	2017-07-19 02:25:00+03	36000.00
322D14	2017-06-30 01:07:00+03	49300.00
322D24	2017-08-14 01:08:00+03	23200.00
322D90	2017-07-27 01:00:00+03	43000.00
322DA2	2017-07-19 14:46:00+03	114800.00
322DA4	2017-08-09 17:32:00+03	55500.00
322E1E	2017-07-13 10:31:00+03	84300.00
322E8F	2017-07-17 17:11:00+03	12600.00
322ECD	2017-07-15 17:20:00+03	108000.00
322ECE	2017-08-04 13:53:00+03	51500.00
322F24	2017-07-09 20:49:00+03	46200.00
322F59	2017-06-28 06:09:00+03	55800.00
322FC5	2017-07-05 21:21:00+03	117600.00
323003	2017-07-24 09:04:00+03	49100.00
323034	2017-08-01 00:40:00+03	40000.00
3230AA	2017-07-11 13:42:00+03	73900.00
3230AB	2017-08-10 20:12:00+03	55800.00
32319C	2017-07-09 23:39:00+03	56000.00
3231C1	2017-08-01 05:51:00+03	132800.00
3231CA	2017-08-10 13:56:00+03	84000.00
3231D0	2017-06-28 12:49:00+03	24800.00
32330F	2017-08-07 09:44:00+03	23200.00
323324	2017-07-30 22:44:00+03	47500.00
323342	2017-07-30 15:03:00+03	13600.00
323367	2017-08-08 04:18:00+03	6600.00
3233C9	2017-07-21 10:42:00+03	260900.00
323422	2017-07-20 21:42:00+03	59800.00
323424	2017-07-05 21:25:00+03	89700.00
323520	2017-06-29 13:24:00+03	369000.00
32353D	2017-08-12 05:44:00+03	65900.00
3235F8	2017-07-12 18:22:00+03	26800.00
32362C	2017-07-07 02:01:00+03	118500.00
323630	2017-07-30 14:12:00+03	117600.00
3236BE	2017-08-05 09:58:00+03	61800.00
3237FA	2017-07-27 06:18:00+03	68700.00
3238C1	2017-08-01 17:15:00+03	47400.00
3238DE	2017-07-25 00:17:00+03	62600.00
3238FB	2017-07-25 23:15:00+03	116000.00
323906	2017-07-19 09:15:00+03	115600.00
323984	2017-08-04 21:02:00+03	47700.00
323994	2017-07-19 19:40:00+03	4000.00
3239B1	2017-07-23 05:48:00+03	55800.00
3239B4	2017-07-17 08:58:00+03	65500.00
3239DA	2017-07-25 01:33:00+03	28000.00
3239DE	2017-08-12 05:30:00+03	90400.00
323A31	2017-07-27 21:18:00+03	29400.00
323A51	2017-08-15 00:48:00+03	85500.00
323AA9	2017-07-20 20:45:00+03	43200.00
323AB5	2017-07-22 07:55:00+03	52000.00
323AF8	2017-07-06 07:21:00+03	365600.00
323AFB	2017-08-10 17:29:00+03	19600.00
323B74	2017-07-05 20:13:00+03	21800.00
323BCD	2017-08-02 06:14:00+03	43500.00
323BCF	2017-07-28 23:35:00+03	145700.00
323BF9	2017-07-09 07:14:00+03	26000.00
323C0E	2017-06-26 01:14:00+03	192400.00
323C13	2017-07-17 04:13:00+03	16400.00
323C29	2017-07-30 18:08:00+03	64800.00
323C2E	2017-07-13 17:00:00+03	54400.00
323C30	2017-07-08 17:40:00+03	155600.00
323C6A	2017-07-21 14:03:00+03	92800.00
323C92	2017-08-13 06:16:00+03	105600.00
323CD2	2017-06-28 01:05:00+03	28000.00
323CE9	2017-08-12 00:50:00+03	97900.00
323D58	2017-07-13 17:38:00+03	26800.00
323D99	2017-07-30 11:55:00+03	167200.00
323DA7	2017-07-23 04:34:00+03	59200.00
323DAA	2017-07-12 05:44:00+03	40000.00
323E7B	2017-07-21 14:12:00+03	67100.00
323EA6	2017-06-29 11:36:00+03	13200.00
323EF3	2017-08-10 17:47:00+03	14900.00
323F33	2017-07-03 18:50:00+03	30900.00
323FC8	2017-08-12 17:10:00+03	144400.00
323FE8	2017-07-30 06:28:00+03	111600.00
32403A	2017-08-15 08:46:00+03	244100.00
324068	2017-08-10 15:09:00+03	49100.00
324169	2017-07-11 11:30:00+03	12600.00
32425C	2017-07-26 09:30:00+03	266400.00
3242A2	2017-08-06 00:39:00+03	59800.00
3242CB	2017-07-25 16:12:00+03	196000.00
3242E2	2017-08-08 11:28:00+03	81600.00
3242ED	2017-07-30 07:24:00+03	32800.00
324301	2017-08-02 00:20:00+03	185600.00
324385	2017-08-01 10:59:00+03	258400.00
3243A5	2017-07-05 17:33:00+03	135600.00
3243DA	2017-07-16 12:28:00+03	126400.00
32441D	2017-07-05 17:58:00+03	54000.00
32443D	2017-07-09 13:55:00+03	14000.00
32443E	2017-07-08 11:42:00+03	24800.00
3244A8	2017-08-14 22:45:00+03	59400.00
3244BF	2017-08-13 04:55:00+03	37900.00
32452F	2017-07-07 20:43:00+03	24400.00
324540	2017-08-07 03:30:00+03	119600.00
324546	2017-07-30 15:53:00+03	136700.00
3245FE	2017-08-09 09:00:00+03	99200.00
324644	2017-07-08 16:25:00+03	30200.00
324673	2017-07-22 16:35:00+03	28800.00
32467D	2017-07-23 01:08:00+03	67600.00
32468C	2017-07-10 21:50:00+03	33800.00
324692	2017-07-09 08:15:00+03	52400.00
324698	2017-08-04 06:20:00+03	68800.00
32469F	2017-07-07 04:16:00+03	162900.00
3247B0	2017-08-12 00:56:00+03	43900.00
324831	2017-08-04 06:49:00+03	31600.00
324846	2017-07-09 22:45:00+03	36200.00
324879	2017-07-30 01:30:00+03	84500.00
324917	2017-07-16 22:15:00+03	31600.00
324935	2017-08-09 10:01:00+03	28800.00
3249D9	2017-07-04 17:13:00+03	14000.00
3249DE	2017-07-12 11:25:00+03	46000.00
3249E1	2017-07-06 08:14:00+03	40100.00
324AA0	2017-07-08 19:30:00+03	72200.00
324B12	2017-08-13 16:57:00+03	25200.00
324B8A	2017-08-11 18:54:00+03	66600.00
324BBE	2017-08-07 11:14:00+03	55800.00
324C9B	2017-08-14 07:17:00+03	53100.00
324CAD	2017-07-21 21:52:00+03	94500.00
324CC0	2017-07-29 13:45:00+03	66600.00
324CDF	2017-07-16 06:27:00+03	59600.00
324D12	2017-07-31 03:19:00+03	78800.00
324D1E	2017-07-26 03:31:00+03	51300.00
324DBC	2017-07-09 04:57:00+03	84500.00
324DD2	2017-07-07 18:22:00+03	154500.00
324DDE	2017-07-29 14:31:00+03	55500.00
324E4F	2017-08-14 05:47:00+03	47500.00
324E95	2017-07-07 18:23:00+03	128800.00
324EB3	2017-07-09 02:19:00+03	22000.00
324EC2	2017-07-21 08:38:00+03	201800.00
324F12	2017-07-01 00:23:00+03	56000.00
324F1F	2017-07-26 06:33:00+03	43900.00
324F33	2017-07-01 16:55:00+03	38400.00
324F64	2017-07-28 22:46:00+03	56000.00
324F99	2017-08-14 13:20:00+03	28300.00
32502A	2017-08-13 12:30:00+03	27200.00
32505D	2017-08-07 13:55:00+03	36200.00
3250A3	2017-07-06 18:48:00+03	36800.00
3250A6	2017-07-12 15:10:00+03	48500.00
3250A7	2017-07-05 03:08:00+03	71000.00
3250D9	2017-07-03 23:10:00+03	23200.00
325100	2017-07-09 03:22:00+03	23200.00
32516B	2017-07-24 05:05:00+03	56600.00
3251EB	2017-07-23 08:16:00+03	25100.00
3251EE	2017-07-09 01:50:00+03	54500.00
3251FA	2017-08-08 16:54:00+03	16400.00
3251FE	2017-08-14 15:37:00+03	94700.00
325223	2017-07-20 22:18:00+03	77000.00
325232	2017-07-22 04:02:00+03	55800.00
325252	2017-07-23 08:00:00+03	6700.00
325287	2017-07-24 13:09:00+03	23100.00
3252D7	2017-07-01 05:16:00+03	96400.00
325386	2017-07-24 00:59:00+03	49900.00
325396	2017-06-28 03:24:00+03	116800.00
3253C9	2017-07-29 21:34:00+03	13300.00
3253F0	2017-08-05 23:31:00+03	7400.00
32540F	2017-07-02 06:55:00+03	87000.00
325440	2017-07-22 08:18:00+03	73200.00
325468	2017-07-15 03:16:00+03	26000.00
3254A4	2017-07-24 17:12:00+03	184200.00
3254D3	2017-08-02 04:10:00+03	93700.00
3254DB	2017-08-03 03:03:00+03	199200.00
325569	2017-07-31 11:01:00+03	136800.00
32556D	2017-07-28 01:36:00+03	89600.00
32559B	2017-07-23 18:38:00+03	28600.00
3255AE	2017-08-11 10:53:00+03	112600.00
3255CB	2017-07-06 09:39:00+03	31600.00
325619	2017-07-18 19:48:00+03	275900.00
32562A	2017-07-31 20:04:00+03	54400.00
325668	2017-07-27 05:21:00+03	21400.00
32567E	2017-08-09 19:45:00+03	47200.00
3256BC	2017-07-22 15:34:00+03	88400.00
32570C	2017-07-25 00:35:00+03	36700.00
32570D	2017-08-08 18:12:00+03	57800.00
32573D	2017-08-08 21:22:00+03	12600.00
32576A	2017-08-14 08:48:00+03	115800.00
3257CE	2017-08-08 09:33:00+03	119500.00
3257DA	2017-07-28 22:28:00+03	75300.00
3257E6	2017-07-20 13:28:00+03	67600.00
325856	2017-07-03 12:50:00+03	19600.00
32585F	2017-07-13 02:37:00+03	124000.00
325868	2017-08-05 05:12:00+03	99200.00
32589F	2017-07-22 07:17:00+03	122800.00
3258AA	2017-07-11 00:27:00+03	75300.00
3258EC	2017-07-28 11:19:00+03	100700.00
3258ED	2017-07-20 16:00:00+03	45100.00
325998	2017-07-12 12:05:00+03	56000.00
3259A7	2017-08-04 07:20:00+03	263000.00
3259AE	2017-08-04 06:21:00+03	27800.00
3259EF	2017-08-14 18:12:00+03	31400.00
325A85	2017-07-12 20:23:00+03	48300.00
325A88	2017-07-12 00:55:00+03	28000.00
325A93	2017-07-27 19:19:00+03	23200.00
325AD7	2017-08-14 21:25:00+03	114400.00
325B0C	2017-07-03 22:06:00+03	40800.00
325B7B	2017-07-31 12:19:00+03	133200.00
325BBE	2017-08-10 04:35:00+03	70100.00
325BF8	2017-07-26 13:00:00+03	111000.00
325C0C	2017-08-07 12:32:00+03	102000.00
325C30	2017-07-18 08:12:00+03	43800.00
325C3E	2017-06-27 04:06:00+03	48400.00
325C71	2017-07-07 05:50:00+03	138000.00
325CA6	2017-07-07 21:27:00+03	46200.00
325CAC	2017-08-06 01:25:00+03	38600.00
325D06	2017-08-03 01:20:00+03	114800.00
325D5E	2017-07-22 05:15:00+03	32700.00
325DA0	2017-07-11 02:42:00+03	103800.00
325DC2	2017-07-09 02:23:00+03	123000.00
325E24	2017-07-15 01:31:00+03	51900.00
325E51	2017-07-27 03:40:00+03	112000.00
325E65	2017-07-19 08:02:00+03	61500.00
325EAC	2017-07-04 23:18:00+03	6300.00
325EDB	2017-08-10 00:17:00+03	43100.00
325EE2	2017-07-29 20:27:00+03	61900.00
325F55	2017-07-04 11:01:00+03	23400.00
32601A	2017-07-22 20:33:00+03	22200.00
326029	2017-07-27 04:49:00+03	114200.00
32604D	2017-07-19 11:25:00+03	23200.00
3260BA	2017-07-06 10:00:00+03	94300.00
3261D7	2017-07-11 19:07:00+03	36200.00
3261DA	2017-07-07 23:23:00+03	7200.00
32620D	2017-07-22 14:43:00+03	55800.00
326213	2017-07-17 22:37:00+03	47100.00
326227	2017-08-09 08:15:00+03	134400.00
3262DC	2017-07-15 16:31:00+03	85000.00
326314	2017-08-12 17:11:00+03	76800.00
326318	2017-07-07 12:37:00+03	40200.00
326368	2017-07-09 05:06:00+03	23200.00
326391	2017-08-14 16:03:00+03	91900.00
32639B	2017-07-13 14:22:00+03	81600.00
3263CA	2017-07-14 05:25:00+03	111600.00
32641D	2017-08-14 14:16:00+03	58000.00
326460	2017-07-23 10:49:00+03	114300.00
3264D2	2017-07-27 07:53:00+03	53700.00
3264E4	2017-07-16 09:53:00+03	32500.00
32654C	2017-07-16 12:47:00+03	43100.00
3265B4	2017-08-13 10:26:00+03	62600.00
326605	2017-07-10 11:39:00+03	26000.00
326697	2017-08-13 02:37:00+03	145100.00
326723	2017-07-02 08:02:00+03	32800.00
32674E	2017-08-11 10:00:00+03	26000.00
32677A	2017-07-22 22:58:00+03	8200.00
326785	2017-08-05 21:27:00+03	21800.00
32678C	2017-07-05 08:46:00+03	85000.00
3267A9	2017-07-31 07:47:00+03	28000.00
3267C3	2017-07-24 21:21:00+03	44800.00
3267D7	2017-07-23 23:27:00+03	118500.00
3267D9	2017-07-09 06:06:00+03	25400.00
3267DF	2017-07-21 08:25:00+03	51300.00
32680C	2017-08-02 00:52:00+03	134400.00
326814	2017-08-02 03:20:00+03	97700.00
326859	2017-07-17 06:01:00+03	78800.00
3268C4	2017-07-14 08:17:00+03	74000.00
326945	2017-08-09 00:24:00+03	9800.00
3269C8	2017-08-08 08:00:00+03	90400.00
326A43	2017-07-21 13:47:00+03	99200.00
326A6C	2017-07-28 11:23:00+03	26700.00
326A81	2017-07-13 10:30:00+03	398500.00
326A95	2017-08-01 10:43:00+03	167400.00
326AA2	2017-07-29 01:54:00+03	39800.00
326AB9	2017-08-08 06:04:00+03	39700.00
326AD6	2017-07-16 18:50:00+03	22000.00
326B0E	2017-07-21 00:42:00+03	54800.00
326B16	2017-08-09 19:44:00+03	12600.00
326B2F	2017-07-04 23:31:00+03	83100.00
326B50	2017-08-09 04:52:00+03	56000.00
326B81	2017-07-24 04:28:00+03	26000.00
326B93	2017-08-09 02:33:00+03	54400.00
326BCE	2017-07-04 14:46:00+03	103500.00
326C11	2017-07-29 05:09:00+03	226200.00
326C6A	2017-07-09 04:04:00+03	493300.00
326D10	2017-07-30 16:07:00+03	138900.00
326D25	2017-08-02 09:12:00+03	46400.00
326D8E	2017-07-24 19:02:00+03	19800.00
326E10	2017-08-05 05:55:00+03	42000.00
326E20	2017-07-16 04:27:00+03	48800.00
326F08	2017-08-05 05:08:00+03	137600.00
326F50	2017-08-03 22:29:00+03	48800.00
326F80	2017-07-09 05:42:00+03	69000.00
326F8C	2017-08-07 07:43:00+03	49800.00
326F98	2017-07-07 11:22:00+03	123000.00
326F9C	2017-07-26 08:54:00+03	183100.00
326FAD	2017-07-17 04:53:00+03	25400.00
326FAF	2017-07-15 15:16:00+03	46000.00
327004	2017-08-13 07:39:00+03	258400.00
327060	2017-08-06 22:25:00+03	62400.00
327068	2017-07-26 17:13:00+03	48800.00
32715B	2017-07-13 11:53:00+03	21200.00
327182	2017-07-12 03:35:00+03	60400.00
3271A9	2017-08-03 02:24:00+03	57500.00
3271DC	2017-07-29 20:03:00+03	123900.00
327211	2017-07-17 05:54:00+03	28800.00
327215	2017-07-03 17:39:00+03	48800.00
32723A	2017-07-30 17:15:00+03	59800.00
32727A	2017-07-05 01:35:00+03	48800.00
3272D6	2017-07-12 11:37:00+03	260900.00
327321	2017-08-05 07:12:00+03	55600.00
327333	2017-08-12 07:12:00+03	122500.00
327350	2017-08-14 06:48:00+03	14000.00
327409	2017-08-08 22:03:00+03	30000.00
3274A2	2017-08-04 04:31:00+03	54100.00
327540	2017-07-18 08:40:00+03	21200.00
32754D	2017-07-14 02:24:00+03	66600.00
327552	2017-07-15 12:54:00+03	26200.00
32755C	2017-07-06 21:09:00+03	12200.00
3275A7	2017-07-15 18:29:00+03	39500.00
3275B4	2017-07-13 00:16:00+03	199700.00
3275BB	2017-08-10 08:16:00+03	136200.00
32760F	2017-07-21 09:39:00+03	59800.00
32762B	2017-08-13 17:08:00+03	21800.00
32770E	2017-07-22 00:30:00+03	40800.00
32772E	2017-07-25 08:04:00+03	112000.00
32778C	2017-08-07 22:50:00+03	46400.00
3277C1	2017-08-09 21:07:00+03	23200.00
3277CC	2017-07-11 04:50:00+03	103000.00
3277EC	2017-08-11 17:45:00+03	70700.00
32780A	2017-08-03 01:37:00+03	135600.00
327817	2017-07-12 13:36:00+03	81200.00
32781D	2017-07-19 06:00:00+03	8000.00
327823	2017-07-04 00:43:00+03	56000.00
327897	2017-07-04 11:30:00+03	28000.00
3278A5	2017-08-01 14:52:00+03	559500.00
3278D2	2017-07-14 11:22:00+03	58900.00
3278D8	2017-07-19 04:17:00+03	23100.00
3278E7	2017-07-28 08:19:00+03	39200.00
3278E9	2017-07-01 03:40:00+03	23600.00
3278F1	2017-07-07 22:13:00+03	54100.00
3278F2	2017-07-13 04:56:00+03	87300.00
327971	2017-07-27 17:49:00+03	26700.00
32798D	2017-07-12 05:41:00+03	369000.00
327998	2017-07-29 04:05:00+03	42800.00
3279A0	2017-08-09 14:00:00+03	78600.00
3279F2	2017-08-10 20:21:00+03	136200.00
3279F6	2017-08-12 08:33:00+03	137700.00
327A1B	2017-08-14 12:57:00+03	23200.00
327A4C	2017-07-07 14:04:00+03	13400.00
327A5B	2017-07-10 22:37:00+03	21400.00
327A81	2017-08-14 01:24:00+03	88500.00
327A91	2017-07-31 18:10:00+03	16400.00
327ACA	2017-07-20 00:19:00+03	369000.00
327ACD	2017-08-05 01:36:00+03	24400.00
327AD9	2017-07-22 08:55:00+03	56000.00
327B0F	2017-08-14 15:08:00+03	54300.00
327B2C	2017-07-18 20:21:00+03	136600.00
327B2E	2017-08-10 05:27:00+03	115600.00
327B98	2017-08-05 05:17:00+03	123000.00
327BA0	2017-07-11 23:43:00+03	102100.00
327BAA	2017-07-22 07:04:00+03	62300.00
327BBB	2017-07-24 04:13:00+03	52800.00
327BC1	2017-07-05 12:22:00+03	144700.00
327C1A	2017-07-13 06:06:00+03	32700.00
327C4A	2017-07-07 01:55:00+03	73500.00
327CF9	2017-07-20 14:06:00+03	198300.00
327D4F	2017-07-05 10:43:00+03	24800.00
327D7F	2017-08-07 16:57:00+03	99200.00
327E16	2017-07-24 23:55:00+03	28000.00
327E19	2017-07-24 07:03:00+03	82900.00
327E23	2017-08-09 03:54:00+03	44000.00
327EAB	2017-07-13 05:26:00+03	64500.00
327F0F	2017-07-22 01:50:00+03	33100.00
327F2B	2017-07-05 14:09:00+03	28000.00
327F31	2017-07-13 20:06:00+03	8400.00
327F9C	2017-07-22 02:23:00+03	21200.00
327FDA	2017-08-03 12:01:00+03	28600.00
327FE6	2017-08-13 20:35:00+03	130800.00
327FF0	2017-07-30 08:57:00+03	69100.00
328041	2017-07-05 20:50:00+03	6300.00
328075	2017-08-11 13:20:00+03	28000.00
32814C	2017-07-05 16:36:00+03	73900.00
32819F	2017-08-07 02:32:00+03	20000.00
3281AE	2017-07-26 11:36:00+03	25400.00
3281E9	2017-07-07 21:34:00+03	103900.00
328279	2017-08-04 22:30:00+03	137800.00
3282DA	2017-07-27 14:59:00+03	12000.00
32835B	2017-07-13 18:47:00+03	133400.00
3283AD	2017-08-04 00:24:00+03	148700.00
3283BF	2017-07-20 13:12:00+03	73600.00
3283C7	2017-07-21 11:15:00+03	6000.00
32842F	2017-08-08 09:30:00+03	39200.00
328460	2017-08-04 23:27:00+03	193700.00
328488	2017-07-09 09:27:00+03	49400.00
3284A6	2017-07-28 17:30:00+03	106400.00
328507	2017-08-06 16:25:00+03	47000.00
328522	2017-07-25 21:40:00+03	175300.00
328534	2017-08-14 10:03:00+03	66600.00
328571	2017-07-29 18:19:00+03	52400.00
32863A	2017-07-17 07:32:00+03	23900.00
3286B4	2017-07-02 05:13:00+03	97600.00
3286F8	2017-08-08 02:08:00+03	63000.00
32878C	2017-07-03 20:39:00+03	39100.00
328795	2017-08-05 14:59:00+03	56000.00
3287D1	2017-07-30 04:20:00+03	47000.00
3287EE	2017-07-29 05:21:00+03	6000.00
328855	2017-08-03 19:26:00+03	29400.00
328891	2017-07-23 10:38:00+03	75300.00
32889A	2017-08-04 05:19:00+03	147700.00
3288AC	2017-07-04 16:13:00+03	272000.00
3288F1	2017-08-15 11:09:00+03	47700.00
328979	2017-08-08 06:19:00+03	56600.00
3289D5	2017-08-13 10:47:00+03	66600.00
3289FA	2017-07-26 07:48:00+03	492000.00
328A33	2017-07-17 12:05:00+03	22000.00
328A5C	2017-07-03 23:49:00+03	265600.00
328AD6	2017-08-08 17:15:00+03	38300.00
328B5D	2017-07-16 07:15:00+03	56000.00
328BA2	2017-07-16 20:47:00+03	75600.00
328BC4	2017-07-20 14:57:00+03	18600.00
328BF5	2017-08-03 05:00:00+03	332200.00
328BF7	2017-07-19 17:10:00+03	81300.00
328C0F	2017-07-14 08:42:00+03	30000.00
328C2D	2017-07-26 13:27:00+03	16400.00
328C55	2017-07-19 10:05:00+03	42600.00
328C97	2017-07-27 19:01:00+03	135400.00
328CA0	2017-07-13 18:09:00+03	243700.00
328CF4	2017-07-17 20:00:00+03	48800.00
328D26	2017-08-03 19:31:00+03	542200.00
328D31	2017-08-15 04:57:00+03	48000.00
328DD9	2017-07-16 13:29:00+03	28300.00
328E13	2017-07-18 20:13:00+03	83400.00
328E75	2017-07-07 08:00:00+03	85000.00
328E97	2017-08-06 19:57:00+03	52000.00
328E99	2017-07-08 03:30:00+03	135400.00
328EC4	2017-08-03 08:59:00+03	19600.00
328ECE	2017-07-22 18:20:00+03	92800.00
328EF9	2017-07-24 17:48:00+03	81000.00
328F0F	2017-07-21 20:43:00+03	169900.00
328F5F	2017-07-08 18:15:00+03	42400.00
328F6D	2017-07-20 23:21:00+03	34400.00
328FB3	2017-06-25 20:50:00+03	57500.00
328FD1	2017-07-17 02:20:00+03	23200.00
32905F	2017-07-26 00:56:00+03	26000.00
3290E3	2017-08-11 20:51:00+03	44000.00
329122	2017-07-24 16:33:00+03	51300.00
3291A8	2017-08-13 02:19:00+03	49800.00
329232	2017-07-24 14:41:00+03	56000.00
329261	2017-08-08 13:17:00+03	73600.00
329271	2017-08-06 10:46:00+03	35200.00
3292E1	2017-08-09 02:32:00+03	250600.00
3292EA	2017-07-11 07:59:00+03	26200.00
329308	2017-08-09 02:49:00+03	90800.00
329310	2017-06-28 04:49:00+03	23200.00
329340	2017-07-26 08:38:00+03	249200.00
32935C	2017-08-15 00:39:00+03	24400.00
329433	2017-07-27 18:23:00+03	41200.00
32943D	2017-08-11 05:05:00+03	48100.00
329440	2017-08-07 01:40:00+03	34000.00
329452	2017-06-27 23:55:00+03	41400.00
3294F7	2017-07-27 18:10:00+03	36200.00
3294FE	2017-07-31 10:10:00+03	139200.00
32950F	2017-07-17 03:36:00+03	54800.00
329534	2017-07-27 23:22:00+03	42800.00
32954C	2017-07-05 12:51:00+03	76900.00
32955C	2017-08-07 03:53:00+03	56000.00
329578	2017-07-28 17:12:00+03	153300.00
3295A9	2017-08-01 10:14:00+03	56100.00
329601	2017-08-15 02:16:00+03	88200.00
329636	2017-08-05 04:27:00+03	21400.00
32966F	2017-07-10 03:21:00+03	22000.00
3296AF	2017-07-24 14:00:00+03	90400.00
3296EB	2017-08-06 21:09:00+03	58700.00
329711	2017-08-05 18:22:00+03	101500.00
329768	2017-08-11 00:03:00+03	52900.00
329797	2017-07-31 09:08:00+03	116700.00
3297EA	2017-07-23 09:46:00+03	57600.00
3297F8	2017-08-10 11:00:00+03	33100.00
3298C0	2017-07-31 00:08:00+03	130900.00
3298CC	2017-07-23 06:12:00+03	32200.00
329923	2017-07-03 00:42:00+03	8200.00
32992C	2017-08-12 08:42:00+03	41400.00
32995F	2017-07-06 00:55:00+03	73600.00
329978	2017-07-16 18:28:00+03	32800.00
329AC5	2017-08-06 15:06:00+03	23200.00
329ADF	2017-08-06 08:34:00+03	42100.00
329BA7	2017-08-08 05:42:00+03	38600.00
329BD2	2017-07-15 12:55:00+03	78900.00
329BE3	2017-07-29 12:56:00+03	122800.00
329BEE	2017-08-13 19:40:00+03	269300.00
329C2A	2017-07-19 23:00:00+03	7400.00
329C5A	2017-07-06 23:54:00+03	106400.00
329C5E	2017-07-07 12:25:00+03	91800.00
329C7D	2017-07-19 12:35:00+03	123000.00
329D9B	2017-07-04 02:56:00+03	62600.00
329DAD	2017-07-05 23:58:00+03	111700.00
329E6E	2017-07-02 05:44:00+03	258400.00
329E8B	2017-08-03 22:08:00+03	123000.00
329EB0	2017-07-28 06:23:00+03	124200.00
329ED3	2017-07-09 08:47:00+03	56600.00
329F07	2017-07-20 13:44:00+03	78500.00
329F32	2017-07-03 03:06:00+03	20600.00
329F36	2017-07-24 00:34:00+03	68800.00
32A001	2017-07-24 08:12:00+03	38000.00
32A0A0	2017-06-26 22:35:00+03	67200.00
32A0CA	2017-08-10 05:47:00+03	18600.00
32A17F	2017-07-26 12:37:00+03	29200.00
32A191	2017-07-28 09:41:00+03	26800.00
32A196	2017-08-03 04:29:00+03	12600.00
32A1E5	2017-07-12 21:45:00+03	65700.00
32A239	2017-07-07 07:37:00+03	32800.00
32A318	2017-08-07 06:59:00+03	113200.00
32A31A	2017-07-12 00:40:00+03	56000.00
32A322	2017-08-14 07:31:00+03	14400.00
32A345	2017-07-13 09:48:00+03	133200.00
32A38D	2017-08-08 19:47:00+03	105600.00
32A3EB	2017-07-24 16:20:00+03	313100.00
32A3EF	2017-08-05 16:41:00+03	114600.00
32A416	2017-07-31 10:54:00+03	102100.00
32A43D	2017-07-28 22:38:00+03	71200.00
32A442	2017-08-13 23:07:00+03	25600.00
32A472	2017-07-14 10:54:00+03	19300.00
32A567	2017-07-30 22:33:00+03	80400.00
32A677	2017-07-24 14:22:00+03	60700.00
32A68D	2017-07-26 07:10:00+03	32400.00
32A6D6	2017-07-26 20:04:00+03	182300.00
32A77D	2017-08-09 01:22:00+03	6000.00
32A82C	2017-08-05 02:44:00+03	25800.00
32A845	2017-07-03 22:16:00+03	46000.00
32A85B	2017-07-11 13:22:00+03	108900.00
32A88B	2017-07-14 09:01:00+03	46400.00
32A891	2017-07-13 11:20:00+03	16400.00
32A8A1	2017-07-07 18:29:00+03	51000.00
32A8ED	2017-06-30 11:56:00+03	35400.00
32A91E	2017-07-25 03:10:00+03	6800.00
32A923	2017-08-07 10:29:00+03	50300.00
32AA4D	2017-07-28 05:04:00+03	12400.00
32AA7E	2017-07-10 12:12:00+03	19600.00
32AA8F	2017-07-17 09:41:00+03	248400.00
32AAED	2017-07-04 12:11:00+03	48400.00
32AB3C	2017-08-08 03:00:00+03	129500.00
32ABA8	2017-07-05 07:08:00+03	13700.00
32AC28	2017-07-15 00:17:00+03	58700.00
32AD20	2017-07-17 09:33:00+03	25900.00
32AD32	2017-07-26 02:53:00+03	25400.00
32AD5F	2017-07-27 17:54:00+03	148200.00
32ADD5	2017-07-24 05:34:00+03	117200.00
32ADF1	2017-08-11 04:27:00+03	62600.00
32AE23	2017-07-02 05:31:00+03	15400.00
32AE49	2017-08-05 22:50:00+03	28000.00
32AE73	2017-07-07 10:51:00+03	37900.00
32AEA9	2017-08-13 21:36:00+03	38400.00
32AEED	2017-07-03 17:34:00+03	136200.00
32AEF3	2017-08-11 05:49:00+03	82900.00
32AF20	2017-08-02 02:26:00+03	107300.00
32AF21	2017-07-23 17:04:00+03	56600.00
32AF55	2017-07-30 15:23:00+03	62100.00
32AF84	2017-07-19 09:44:00+03	102300.00
32AF91	2017-07-30 17:02:00+03	34600.00
32B05B	2017-08-15 00:53:00+03	158700.00
32B0BB	2017-07-06 06:33:00+03	56000.00
32B176	2017-07-31 12:25:00+03	84000.00
32B233	2017-07-05 20:18:00+03	43200.00
32B2C0	2017-07-13 10:32:00+03	67900.00
32B2CF	2017-07-11 23:13:00+03	87000.00
32B2E8	2017-07-06 00:03:00+03	26000.00
32B2F3	2017-07-23 07:05:00+03	33200.00
32B301	2017-08-04 18:44:00+03	43600.00
32B308	2017-07-21 23:00:00+03	6000.00
32B30C	2017-07-20 05:04:00+03	57400.00
32B31E	2017-08-11 00:36:00+03	40800.00
32B325	2017-08-02 17:30:00+03	40000.00
32B39A	2017-07-02 07:38:00+03	100600.00
32B3EB	2017-08-02 08:40:00+03	23100.00
32B40B	2017-07-10 10:56:00+03	28800.00
32B41B	2017-07-29 02:30:00+03	47100.00
32B450	2017-08-02 01:58:00+03	67600.00
32B45A	2017-06-25 16:41:00+03	187800.00
32B491	2017-08-15 17:32:00+03	52000.00
32B4B5	2017-08-14 18:42:00+03	39300.00
32B4D5	2017-08-02 03:02:00+03	173400.00
32B521	2017-08-03 09:25:00+03	197100.00
32B528	2017-07-18 11:00:00+03	53600.00
32B65B	2017-08-11 14:00:00+03	236700.00
32B687	2017-07-10 23:33:00+03	130200.00
32B6C6	2017-08-10 07:31:00+03	21000.00
32B705	2017-07-23 12:48:00+03	70500.00
32B765	2017-08-14 02:48:00+03	94700.00
32B7C4	2017-07-19 23:46:00+03	20400.00
32B7EB	2017-07-21 10:31:00+03	28800.00
32B83E	2017-07-15 23:45:00+03	123000.00
32B87A	2017-07-18 01:05:00+03	24400.00
32B8B0	2017-08-14 06:41:00+03	107000.00
32B983	2017-07-22 06:36:00+03	92800.00
32B994	2017-07-06 16:59:00+03	16400.00
32B9E0	2017-08-15 12:53:00+03	62700.00
32B9FB	2017-08-05 07:04:00+03	84500.00
32BA31	2017-08-01 23:24:00+03	99200.00
32BA4C	2017-07-30 22:57:00+03	40600.00
32BAB9	2017-07-25 09:03:00+03	104900.00
32BB1F	2017-08-14 12:34:00+03	92800.00
32BB41	2017-07-12 06:30:00+03	70400.00
32BC4E	2017-07-12 15:42:00+03	40800.00
32BC7F	2017-07-28 00:38:00+03	21400.00
32BC88	2017-07-08 23:05:00+03	17800.00
32BCDD	2017-07-14 05:30:00+03	40400.00
32BCF4	2017-07-21 23:06:00+03	18700.00
32BCFB	2017-07-12 09:09:00+03	174200.00
32BD0A	2017-08-12 00:56:00+03	92700.00
32BDA4	2017-08-12 21:42:00+03	78500.00
32BDBA	2017-07-10 18:50:00+03	232800.00
32BDC6	2017-07-29 12:02:00+03	115800.00
32BDDF	2017-08-12 12:11:00+03	27000.00
32BDE4	2017-07-28 01:19:00+03	71900.00
32BE0C	2017-07-03 04:09:00+03	21600.00
32BE34	2017-08-09 22:28:00+03	17600.00
32BEC5	2017-08-02 23:55:00+03	37900.00
32BEED	2017-08-01 03:22:00+03	62000.00
32BF03	2017-07-15 19:38:00+03	136800.00
32BF75	2017-07-09 18:43:00+03	25200.00
32BFC2	2017-07-04 07:15:00+03	26700.00
32BFC9	2017-07-20 15:22:00+03	11600.00
32C0DE	2017-08-06 08:03:00+03	246000.00
32C0E0	2017-07-06 04:14:00+03	63200.00
32C0E1	2017-06-30 21:35:00+03	21500.00
32C148	2017-07-12 22:26:00+03	48800.00
32C1D7	2017-07-17 10:39:00+03	137100.00
32C1DE	2017-08-11 15:31:00+03	7400.00
32C1EB	2017-07-12 02:00:00+03	70900.00
32C202	2017-07-26 21:25:00+03	23200.00
32C230	2017-07-30 21:47:00+03	120700.00
32C3F9	2017-07-26 00:14:00+03	26700.00
32C40D	2017-08-02 02:56:00+03	187600.00
32C48E	2017-07-30 21:16:00+03	246000.00
32C4B6	2017-07-27 05:19:00+03	6700.00
32C510	2017-07-10 14:52:00+03	36000.00
32C52C	2017-07-18 15:00:00+03	112000.00
32C59C	2017-07-29 12:20:00+03	90800.00
32C5AE	2017-07-03 10:34:00+03	25600.00
32C61C	2017-07-25 05:08:00+03	112000.00
32C648	2017-08-11 16:44:00+03	56600.00
32C6AC	2017-07-22 16:03:00+03	112000.00
32C6CB	2017-07-15 23:11:00+03	28000.00
32C707	2017-07-09 22:00:00+03	30900.00
32C736	2017-07-16 08:05:00+03	26500.00
32C768	2017-08-09 03:33:00+03	259000.00
32C773	2017-08-06 01:49:00+03	24800.00
32C7B5	2017-07-29 10:54:00+03	66000.00
32C7C6	2017-08-14 15:12:00+03	46400.00
32C7EC	2017-07-23 18:52:00+03	48500.00
32C82F	2017-08-01 15:16:00+03	133200.00
32C8AB	2017-08-08 04:16:00+03	94000.00
32C8F6	2017-07-19 07:20:00+03	59000.00
32C971	2017-08-03 22:27:00+03	35200.00
32C9B8	2017-07-06 13:46:00+03	79000.00
32C9CC	2017-08-04 17:44:00+03	28000.00
32C9FB	2017-07-17 07:18:00+03	20200.00
32CA21	2017-08-05 20:21:00+03	224000.00
32CA63	2017-07-10 02:30:00+03	18600.00
32CA7C	2017-07-29 20:42:00+03	50800.00
32CA7F	2017-08-06 00:19:00+03	59000.00
32CB2E	2017-07-16 13:02:00+03	59200.00
32CB53	2017-07-29 03:45:00+03	135400.00
32CBBE	2017-07-13 20:32:00+03	38200.00
32CC70	2017-08-10 01:39:00+03	73300.00
32CCB7	2017-07-30 01:20:00+03	49500.00
32CD55	2017-08-08 05:14:00+03	13600.00
32CD7B	2017-07-22 11:20:00+03	55800.00
32CD84	2017-07-23 06:15:00+03	39400.00
32CD8D	2017-07-21 14:12:00+03	25400.00
32CDBA	2017-07-12 00:32:00+03	12600.00
32CE34	2017-07-23 21:21:00+03	28000.00
32CE61	2017-07-17 20:51:00+03	20100.00
32CF4A	2017-07-11 02:19:00+03	89600.00
32CF89	2017-07-30 19:55:00+03	171000.00
32CF91	2017-07-02 19:10:00+03	26800.00
32CF93	2017-08-14 13:37:00+03	141600.00
32CFFD	2017-07-07 15:51:00+03	155600.00
32D06B	2017-07-29 20:04:00+03	8000.00
32D074	2017-07-25 08:33:00+03	21800.00
32D087	2017-08-12 01:57:00+03	25200.00
32D10C	2017-07-12 21:07:00+03	270000.00
32D16D	2017-07-09 06:32:00+03	38700.00
32D1B0	2017-07-01 04:48:00+03	44600.00
32D1E2	2017-08-11 05:06:00+03	20000.00
32D1FA	2017-07-03 16:11:00+03	83000.00
32D2AE	2017-07-29 08:22:00+03	234600.00
32D3ED	2017-07-14 18:13:00+03	22400.00
32D46A	2017-08-09 11:32:00+03	45200.00
32D4E2	2017-06-30 05:38:00+03	77600.00
32D4F4	2017-07-26 05:21:00+03	12600.00
32D52B	2017-08-09 11:48:00+03	15100.00
32D543	2017-07-12 22:10:00+03	57400.00
32D555	2017-08-01 09:57:00+03	57300.00
32D581	2017-07-18 10:31:00+03	44000.00
32D5F4	2017-07-07 07:23:00+03	28000.00
32D633	2017-07-10 18:00:00+03	245500.00
32D698	2017-08-05 17:02:00+03	27900.00
32D718	2017-07-26 08:08:00+03	29600.00
32D786	2017-08-15 06:26:00+03	32500.00
32D7A6	2017-07-29 17:52:00+03	174900.00
32D805	2017-08-08 04:25:00+03	76200.00
32D81D	2017-07-13 02:46:00+03	44000.00
32D965	2017-07-23 10:54:00+03	25200.00
32D986	2017-08-08 01:29:00+03	166100.00
32D9EF	2017-08-14 22:13:00+03	199200.00
32DA64	2017-07-20 10:40:00+03	49800.00
32DAB5	2017-07-20 23:22:00+03	118500.00
32DB6A	2017-08-08 12:47:00+03	12400.00
32DBDD	2017-07-27 12:34:00+03	69500.00
32DC5F	2017-07-27 19:24:00+03	28000.00
32DC81	2017-06-28 12:19:00+03	23400.00
32DC9A	2017-08-06 06:37:00+03	27200.00
32DCE8	2017-07-31 07:39:00+03	40800.00
32DD03	2017-07-29 14:06:00+03	23200.00
32DD75	2017-07-08 08:57:00+03	23200.00
32DE7A	2017-07-02 22:02:00+03	26800.00
32DE88	2017-07-26 22:41:00+03	28000.00
32DEB3	2017-07-25 01:14:00+03	46800.00
32DED4	2017-07-27 15:04:00+03	99300.00
32DF12	2017-07-17 14:13:00+03	124200.00
32DF73	2017-08-14 20:05:00+03	7300.00
32DF7D	2017-07-02 19:02:00+03	110300.00
32E07A	2017-08-06 09:34:00+03	55800.00
32E092	2017-08-09 14:04:00+03	28000.00
32E11D	2017-07-03 02:32:00+03	123000.00
32E147	2017-07-07 12:38:00+03	47400.00
32E169	2017-07-17 16:04:00+03	27500.00
32E16F	2017-07-09 23:19:00+03	109000.00
32E1CC	2017-07-24 19:22:00+03	73300.00
32E1F1	2017-08-10 02:22:00+03	69500.00
32E22F	2017-07-30 18:50:00+03	47400.00
32E332	2017-08-02 11:58:00+03	30200.00
32E341	2017-07-05 20:41:00+03	31200.00
32E359	2017-08-04 00:54:00+03	6800.00
32E408	2017-08-05 04:53:00+03	40800.00
32E4C6	2017-08-09 01:35:00+03	185000.00
32E589	2017-08-05 14:14:00+03	66000.00
32E597	2017-07-18 18:10:00+03	87100.00
32E598	2017-08-10 10:11:00+03	202100.00
32E5EA	2017-08-01 16:03:00+03	21400.00
32E5F6	2017-08-06 02:56:00+03	13300.00
32E630	2017-07-21 17:34:00+03	67900.00
32E685	2017-08-08 09:41:00+03	125500.00
32E693	2017-07-02 00:17:00+03	67100.00
32E6CA	2017-07-05 02:43:00+03	55800.00
32E6E6	2017-07-21 23:52:00+03	124200.00
32E6F6	2017-08-12 18:58:00+03	156500.00
32E70D	2017-08-02 10:24:00+03	46400.00
32E718	2017-07-30 12:54:00+03	28000.00
32E779	2017-07-22 00:00:00+03	123000.00
32E821	2017-08-01 16:18:00+03	139100.00
32E826	2017-07-15 11:00:00+03	83300.00
32E831	2017-07-31 18:26:00+03	8400.00
32E87E	2017-07-21 00:51:00+03	43500.00
32E938	2017-07-27 11:11:00+03	37200.00
32E9DD	2017-07-18 02:54:00+03	34000.00
32E9FD	2017-07-07 21:45:00+03	132800.00
32EA24	2017-08-09 23:03:00+03	16400.00
32EA61	2017-07-13 12:17:00+03	24400.00
32EA64	2017-08-02 23:32:00+03	16400.00
32EAE5	2017-07-08 10:03:00+03	28000.00
32EBF7	2017-07-10 23:11:00+03	88100.00
32EC67	2017-07-26 18:41:00+03	80600.00
32ED11	2017-07-26 15:46:00+03	6700.00
32ED5D	2017-07-11 07:56:00+03	142400.00
32ED71	2017-08-14 19:54:00+03	127200.00
32ED96	2017-07-08 22:49:00+03	242700.00
32EDEB	2017-07-29 16:44:00+03	92000.00
32EE2E	2017-07-15 16:13:00+03	80600.00
32EED2	2017-07-14 14:21:00+03	84500.00
32EED9	2017-08-14 08:57:00+03	166200.00
32EFA7	2017-08-06 16:44:00+03	28800.00
32EFED	2017-07-27 12:13:00+03	288800.00
32F03F	2017-07-27 17:39:00+03	48100.00
32F0BE	2017-07-30 09:34:00+03	188200.00
32F0C0	2017-07-08 10:43:00+03	64700.00
32F152	2017-08-01 19:38:00+03	21400.00
32F18B	2017-08-12 13:24:00+03	272300.00
32F18F	2017-08-11 20:44:00+03	135200.00
32F25C	2017-08-15 04:36:00+03	178500.00
32F2A9	2017-08-02 07:56:00+03	78500.00
32F339	2017-08-02 22:05:00+03	22600.00
32F35E	2017-07-14 05:27:00+03	86800.00
32F400	2017-07-16 10:09:00+03	71200.00
32F412	2017-08-10 10:37:00+03	24400.00
32F414	2017-08-08 05:13:00+03	13400.00
32F440	2017-07-16 11:12:00+03	246000.00
32F45A	2017-08-14 13:10:00+03	32800.00
32F475	2017-07-16 09:29:00+03	42800.00
32F4C9	2017-08-14 05:58:00+03	62900.00
32F524	2017-07-08 15:41:00+03	31600.00
32F5C0	2017-07-24 23:17:00+03	24400.00
32F670	2017-08-06 18:16:00+03	64400.00
32F74B	2017-07-27 00:40:00+03	76600.00
32F776	2017-08-01 07:23:00+03	79000.00
32F7E2	2017-07-14 06:34:00+03	86600.00
32F80D	2017-07-25 05:15:00+03	124600.00
32F839	2017-07-27 05:50:00+03	224000.00
32F859	2017-07-04 05:06:00+03	16400.00
32F894	2017-08-03 01:41:00+03	26000.00
32F8FD	2017-07-17 18:42:00+03	25400.00
32F96B	2017-07-23 13:30:00+03	238500.00
32F97C	2017-07-18 10:38:00+03	82900.00
32F9A2	2017-07-30 21:08:00+03	7400.00
32F9DB	2017-07-13 01:52:00+03	6000.00
32F9F8	2017-08-14 07:36:00+03	40400.00
32FAC6	2017-08-15 17:46:00+03	160700.00
32FADB	2017-07-28 16:53:00+03	112600.00
32FB0D	2017-07-03 06:09:00+03	198600.00
32FB17	2017-07-04 12:13:00+03	42700.00
32FB32	2017-08-08 17:05:00+03	122000.00
32FB6E	2017-08-10 19:12:00+03	25800.00
32FB80	2017-08-08 12:44:00+03	46000.00
32FB9E	2017-07-22 15:27:00+03	6800.00
32FBA6	2017-07-01 16:42:00+03	28800.00
32FBC4	2017-07-28 05:38:00+03	32400.00
32FC0E	2017-06-30 23:09:00+03	135600.00
32FC1C	2017-08-03 20:31:00+03	80900.00
32FC25	2017-08-04 12:28:00+03	28800.00
32FC27	2017-08-04 09:53:00+03	166100.00
32FDA6	2017-07-15 08:34:00+03	46200.00
32FE68	2017-06-28 14:45:00+03	70800.00
32FE78	2017-07-17 07:13:00+03	270800.00
32FEC2	2017-07-28 05:57:00+03	88900.00
32FF27	2017-07-26 20:21:00+03	69500.00
32FF3B	2017-07-04 20:59:00+03	26000.00
32FF56	2017-07-25 10:24:00+03	123900.00
32FFD5	2017-07-19 06:01:00+03	59200.00
32FFD7	2017-08-04 08:08:00+03	199700.00
32FFD8	2017-07-31 02:06:00+03	69500.00
32FFFF	2017-08-08 21:58:00+03	36200.00
330038	2017-07-26 14:26:00+03	29600.00
330069	2017-07-18 17:11:00+03	73500.00
3300BF	2017-07-05 12:04:00+03	92000.00
3301D8	2017-07-04 12:20:00+03	81600.00
3303FE	2017-07-24 15:29:00+03	66600.00
330407	2017-08-10 13:19:00+03	101200.00
330443	2017-07-03 11:01:00+03	38600.00
330455	2017-08-04 21:20:00+03	14800.00
330494	2017-08-02 02:57:00+03	69000.00
330495	2017-07-20 10:23:00+03	16800.00
3305BB	2017-08-13 14:10:00+03	102100.00
3305DD	2017-07-11 15:56:00+03	188000.00
330703	2017-07-22 05:01:00+03	37600.00
33071F	2017-07-01 13:45:00+03	26800.00
330741	2017-08-09 17:47:00+03	73900.00
330781	2017-07-26 10:51:00+03	23200.00
330794	2017-07-15 13:38:00+03	57400.00
330813	2017-08-07 00:44:00+03	101200.00
330820	2017-08-09 16:52:00+03	47500.00
330841	2017-07-08 09:34:00+03	25800.00
3308B9	2017-08-15 09:34:00+03	99800.00
330978	2017-07-29 07:12:00+03	70700.00
3309C9	2017-08-09 16:26:00+03	73100.00
3309EA	2017-08-10 22:20:00+03	160200.00
330A25	2017-07-18 08:24:00+03	70500.00
330A83	2017-07-12 21:38:00+03	246000.00
330AE4	2017-07-18 20:12:00+03	147700.00
330B0C	2017-07-03 05:25:00+03	65500.00
330B56	2017-07-20 14:20:00+03	144400.00
330B5F	2017-07-27 04:43:00+03	24400.00
330B79	2017-07-07 12:36:00+03	218500.00
330BA0	2017-08-08 23:34:00+03	34700.00
330C27	2017-08-04 02:16:00+03	52000.00
330C7B	2017-07-26 08:17:00+03	56800.00
330C84	2017-08-15 04:34:00+03	316100.00
330CAC	2017-08-07 02:33:00+03	61800.00
330CEE	2017-07-31 11:51:00+03	24600.00
330CF5	2017-07-28 20:35:00+03	18800.00
330E04	2017-08-02 23:27:00+03	18000.00
330E07	2017-07-22 02:22:00+03	8200.00
330E30	2017-07-21 03:06:00+03	58600.00
330E4C	2017-07-11 11:13:00+03	79900.00
330EA2	2017-07-04 14:34:00+03	81700.00
330F33	2017-07-19 12:57:00+03	56600.00
330F78	2017-07-22 08:48:00+03	54100.00
330F83	2017-07-17 19:30:00+03	14300.00
330F89	2017-07-29 07:12:00+03	64800.00
330F9D	2017-07-21 16:30:00+03	46000.00
330FBC	2017-07-17 05:24:00+03	37500.00
3310A5	2017-07-12 04:23:00+03	39300.00
3310B3	2017-07-25 15:45:00+03	55800.00
3310C1	2017-07-06 23:43:00+03	147000.00
331134	2017-07-30 08:36:00+03	139400.00
331170	2017-08-01 13:36:00+03	89600.00
33119A	2017-07-25 20:25:00+03	174400.00
331217	2017-07-12 19:55:00+03	16400.00
33122B	2017-08-05 06:10:00+03	6000.00
331284	2017-08-14 18:14:00+03	29800.00
33128C	2017-08-05 11:30:00+03	85200.00
331314	2017-08-14 04:06:00+03	10500.00
331374	2017-07-04 22:00:00+03	55800.00
331395	2017-07-20 13:06:00+03	58600.00
3313B6	2017-08-10 02:00:00+03	26800.00
3313FA	2017-06-29 11:28:00+03	113200.00
331433	2017-07-14 23:02:00+03	24800.00
3314AD	2017-08-03 12:37:00+03	26800.00
331501	2017-08-13 06:54:00+03	14000.00
331544	2017-08-02 06:31:00+03	13400.00
331572	2017-07-14 16:22:00+03	136200.00
331575	2017-07-04 02:11:00+03	89700.00
3315B3	2017-07-03 08:12:00+03	16400.00
3315BC	2017-07-15 23:38:00+03	147100.00
3315DC	2017-07-03 15:18:00+03	121500.00
33165C	2017-07-26 14:03:00+03	166900.00
331688	2017-07-12 15:15:00+03	46400.00
331739	2017-07-26 02:51:00+03	28000.00
331791	2017-07-16 03:39:00+03	58800.00
3317C3	2017-07-07 08:56:00+03	31900.00
3317F5	2017-08-13 17:41:00+03	36200.00
33187E	2017-07-28 05:04:00+03	75300.00
331959	2017-07-17 23:36:00+03	56000.00
33195E	2017-07-02 16:09:00+03	55000.00
3319B3	2017-08-04 23:26:00+03	60200.00
331A33	2017-07-12 22:49:00+03	91600.00
331AF6	2017-07-31 14:47:00+03	62700.00
331B6E	2017-07-25 10:25:00+03	36800.00
331B87	2017-07-07 13:42:00+03	21400.00
331BDB	2017-07-11 07:37:00+03	30200.00
331BDD	2017-07-18 00:20:00+03	423500.00
331BF8	2017-07-25 06:49:00+03	14800.00
331C02	2017-07-24 05:57:00+03	67500.00
331CAC	2017-07-30 04:50:00+03	60400.00
331CBE	2017-08-05 22:19:00+03	16400.00
331CE9	2017-07-06 16:23:00+03	14400.00
331D25	2017-08-04 09:13:00+03	48800.00
331D40	2017-08-14 18:32:00+03	28000.00
331DA4	2017-07-17 15:33:00+03	19600.00
331DAE	2017-07-05 01:10:00+03	92700.00
331DBC	2017-07-18 17:42:00+03	59800.00
331DC8	2017-07-03 16:59:00+03	26600.00
331E2D	2017-07-29 22:27:00+03	138600.00
331F06	2017-08-06 04:51:00+03	66600.00
331F7E	2017-07-20 21:44:00+03	135400.00
331F99	2017-07-14 00:26:00+03	37800.00
331FEF	2017-07-28 22:37:00+03	26000.00
331FF1	2017-07-29 04:25:00+03	48800.00
332007	2017-08-06 19:25:00+03	41700.00
332074	2017-08-12 02:07:00+03	210900.00
3320BF	2017-07-22 02:38:00+03	28800.00
332146	2017-08-07 16:46:00+03	116400.00
332192	2017-08-13 03:14:00+03	12000.00
3321A3	2017-08-14 03:52:00+03	35200.00
3321DD	2017-08-15 02:04:00+03	134400.00
332286	2017-07-31 03:54:00+03	202400.00
332314	2017-07-29 18:45:00+03	40300.00
332392	2017-08-15 11:21:00+03	206800.00
33239C	2017-07-22 12:00:00+03	105600.00
3323F6	2017-08-10 01:07:00+03	86800.00
33242D	2017-07-13 03:20:00+03	38600.00
33242E	2017-08-13 08:19:00+03	56000.00
332466	2017-07-19 17:46:00+03	184300.00
33248B	2017-07-19 05:43:00+03	57200.00
3324CE	2017-07-10 13:48:00+03	26700.00
332510	2017-07-13 22:38:00+03	137400.00
332545	2017-08-02 04:19:00+03	70300.00
33256A	2017-07-17 00:48:00+03	22000.00
332587	2017-08-08 09:44:00+03	52000.00
3325DF	2017-07-24 17:33:00+03	62900.00
3325FD	2017-07-30 02:43:00+03	143600.00
33269C	2017-07-12 02:32:00+03	299600.00
3326C3	2017-07-09 14:37:00+03	106900.00
3326DB	2017-08-14 08:26:00+03	163500.00
332710	2017-07-19 22:52:00+03	79600.00
332719	2017-07-10 15:33:00+03	24400.00
332791	2017-07-31 21:55:00+03	94000.00
332794	2017-07-15 07:58:00+03	36200.00
33279D	2017-08-05 21:21:00+03	64400.00
3327D2	2017-08-10 04:49:00+03	66000.00
3327DD	2017-08-09 13:41:00+03	46000.00
3327E2	2017-07-18 23:14:00+03	54400.00
3327E7	2017-07-22 04:12:00+03	69500.00
332807	2017-07-19 05:36:00+03	77600.00
33284A	2017-07-10 12:11:00+03	131100.00
33285D	2017-07-17 14:28:00+03	113700.00
332876	2017-08-09 05:22:00+03	144300.00
33291E	2017-08-13 13:59:00+03	46500.00
332972	2017-07-22 09:14:00+03	47000.00
33298D	2017-07-02 00:28:00+03	68000.00
3329AA	2017-07-10 18:42:00+03	265700.00
3329BC	2017-06-30 06:46:00+03	58200.00
3329ED	2017-08-08 01:52:00+03	11600.00
332A8F	2017-07-26 18:08:00+03	26000.00
332ABC	2017-07-18 18:15:00+03	135600.00
332AE9	2017-07-14 19:40:00+03	99700.00
332BB7	2017-07-31 17:54:00+03	34000.00
332BFD	2017-07-01 05:59:00+03	39300.00
332C15	2017-08-08 00:56:00+03	181000.00
332C7E	2017-08-08 04:24:00+03	56000.00
332D30	2017-06-28 03:08:00+03	23200.00
332D44	2017-08-09 02:45:00+03	133700.00
332D45	2017-08-01 02:09:00+03	114300.00
332D53	2017-07-13 10:02:00+03	71900.00
332D79	2017-07-05 18:20:00+03	49200.00
332D87	2017-07-24 11:10:00+03	63400.00
332D99	2017-07-20 07:36:00+03	49700.00
332D9F	2017-07-11 21:11:00+03	56600.00
332DA9	2017-07-20 11:51:00+03	51900.00
332E73	2017-08-09 14:35:00+03	58600.00
332EC4	2017-07-31 03:14:00+03	57600.00
332EC7	2017-07-06 10:52:00+03	92000.00
332ED6	2017-07-19 10:27:00+03	56000.00
332EE6	2017-07-10 09:58:00+03	46000.00
332EF6	2017-08-04 13:16:00+03	135600.00
332F17	2017-08-13 01:58:00+03	22400.00
332F5E	2017-07-16 11:21:00+03	37200.00
332FAD	2017-07-08 00:32:00+03	30600.00
333037	2017-07-24 16:56:00+03	156500.00
333074	2017-07-22 05:36:00+03	56000.00
3330AA	2017-07-19 08:48:00+03	16400.00
3331E4	2017-07-17 11:15:00+03	44000.00
3331FF	2017-07-25 12:32:00+03	128800.00
333291	2017-07-01 07:04:00+03	132800.00
333301	2017-07-25 20:26:00+03	21800.00
33331D	2017-07-05 12:07:00+03	31400.00
333372	2017-07-19 06:44:00+03	46300.00
333390	2017-07-14 07:04:00+03	44800.00
333391	2017-07-11 16:01:00+03	66600.00
3333A2	2017-06-30 14:45:00+03	492000.00
3333D0	2017-07-26 09:00:00+03	92000.00
3333D3	2017-07-09 15:14:00+03	46000.00
3333EA	2017-08-02 13:47:00+03	93400.00
333405	2017-07-07 04:26:00+03	47800.00
333458	2017-07-13 08:27:00+03	9800.00
333480	2017-08-13 23:26:00+03	99200.00
3334CA	2017-07-06 11:17:00+03	78300.00
333511	2017-08-11 17:23:00+03	103500.00
333543	2017-08-05 17:33:00+03	22000.00
33355B	2017-07-19 00:45:00+03	66300.00
3335B8	2017-07-14 04:46:00+03	266400.00
3335C6	2017-08-05 18:33:00+03	265600.00
333635	2017-07-18 17:29:00+03	73200.00
333647	2017-07-17 21:21:00+03	113200.00
333661	2017-08-13 06:34:00+03	112000.00
3336AA	2017-07-07 13:59:00+03	112000.00
33376E	2017-07-29 02:22:00+03	106100.00
333852	2017-08-12 06:54:00+03	82000.00
333857	2017-07-23 21:00:00+03	16400.00
33386C	2017-07-14 03:28:00+03	63200.00
33389D	2017-07-06 23:43:00+03	16400.00
333A11	2017-07-31 02:17:00+03	45200.00
333A40	2017-07-05 13:11:00+03	23200.00
333A75	2017-07-24 10:53:00+03	52800.00
333AC6	2017-07-23 05:35:00+03	140300.00
333AD8	2017-08-05 15:46:00+03	137100.00
333AFD	2017-06-30 20:25:00+03	46300.00
333B25	2017-08-11 12:59:00+03	20400.00
333BC7	2017-08-10 09:19:00+03	67400.00
333C15	2017-08-11 06:32:00+03	131800.00
333C39	2017-07-13 13:08:00+03	115100.00
333C4C	2017-08-09 23:51:00+03	62800.00
333C81	2017-07-27 12:17:00+03	40600.00
333C8F	2017-07-21 05:26:00+03	64700.00
333CCB	2017-08-07 05:49:00+03	116700.00
333CFA	2017-07-27 05:46:00+03	137100.00
333D3D	2017-07-31 17:09:00+03	37900.00
333D44	2017-07-22 05:13:00+03	23200.00
333DA1	2017-07-18 22:38:00+03	47400.00
333DC7	2017-07-01 05:53:00+03	134400.00
333E27	2017-07-04 08:54:00+03	46400.00
333E2E	2017-08-08 10:11:00+03	28600.00
333EEF	2017-07-14 15:24:00+03	71300.00
333EFD	2017-07-04 21:14:00+03	51200.00
333F68	2017-07-19 11:54:00+03	25800.00
333FA1	2017-08-14 21:30:00+03	73300.00
333FA4	2017-07-29 00:24:00+03	16400.00
333FB4	2017-08-13 03:09:00+03	111600.00
333FE3	2017-07-10 19:29:00+03	12000.00
334025	2017-07-15 12:41:00+03	23600.00
33403A	2017-07-24 18:22:00+03	246000.00
334101	2017-07-30 11:42:00+03	80000.00
334111	2017-08-08 18:50:00+03	71200.00
334244	2017-08-08 16:49:00+03	24800.00
334287	2017-07-14 07:19:00+03	6000.00
334292	2017-08-04 23:18:00+03	270500.00
33429E	2017-07-04 21:23:00+03	53400.00
334310	2017-07-05 05:58:00+03	48700.00
33435E	2017-08-08 05:53:00+03	101700.00
334390	2017-07-23 21:47:00+03	30900.00
3343E6	2017-08-12 00:19:00+03	14800.00
3343F3	2017-07-19 17:16:00+03	199200.00
3344BA	2017-08-12 05:48:00+03	27400.00
33451F	2017-07-15 03:20:00+03	75600.00
334525	2017-07-15 11:22:00+03	303100.00
334560	2017-07-11 15:34:00+03	29400.00
334568	2017-07-28 18:29:00+03	46000.00
334576	2017-08-10 14:54:00+03	68800.00
3346B8	2017-07-29 15:18:00+03	46400.00
33475C	2017-07-13 19:27:00+03	160800.00
334793	2017-07-12 17:29:00+03	44800.00
3347A4	2017-07-07 09:59:00+03	22000.00
3347E0	2017-07-14 00:26:00+03	89600.00
334814	2017-07-14 21:38:00+03	145400.00
334856	2017-08-12 16:58:00+03	19600.00
334864	2017-07-16 08:47:00+03	35200.00
33489F	2017-07-28 07:10:00+03	66400.00
3348B4	2017-07-11 01:33:00+03	95200.00
334900	2017-08-01 15:55:00+03	23200.00
33496A	2017-07-21 10:28:00+03	86600.00
33498F	2017-07-24 07:40:00+03	104600.00
334991	2017-07-13 20:59:00+03	266200.00
3349CE	2017-07-31 14:38:00+03	21400.00
334A45	2017-08-04 16:20:00+03	64700.00
334AAA	2017-07-26 20:21:00+03	111600.00
334AAB	2017-07-16 07:31:00+03	42700.00
334ABE	2017-07-14 10:20:00+03	56100.00
334AF4	2017-08-04 10:54:00+03	246000.00
334B2F	2017-07-13 14:31:00+03	41600.00
334B55	2017-08-15 06:18:00+03	131100.00
334C54	2017-07-10 12:19:00+03	284400.00
334C56	2017-07-01 03:11:00+03	61800.00
334D7D	2017-07-12 02:16:00+03	18800.00
334D88	2017-08-14 17:14:00+03	85000.00
334D95	2017-08-03 07:52:00+03	128800.00
334DB6	2017-08-12 01:48:00+03	32700.00
334E28	2017-07-06 00:47:00+03	55800.00
334E2C	2017-07-03 12:01:00+03	136000.00
334E56	2017-06-29 03:04:00+03	61800.00
334EEF	2017-07-29 09:52:00+03	136200.00
334FB2	2017-08-10 06:33:00+03	154300.00
334FFD	2017-07-06 09:01:00+03	32700.00
335015	2017-07-06 01:50:00+03	147000.00
335054	2017-08-09 20:34:00+03	123000.00
335072	2017-08-09 05:20:00+03	97000.00
335082	2017-06-27 04:04:00+03	24000.00
3350F9	2017-07-14 21:55:00+03	242100.00
335112	2017-07-15 13:56:00+03	216400.00
3351B7	2017-07-19 08:49:00+03	122300.00
3351D5	2017-08-13 14:56:00+03	48800.00
3351E3	2017-07-03 03:23:00+03	48800.00
33524C	2017-07-07 00:38:00+03	101200.00
33525E	2017-07-08 20:09:00+03	153300.00
33528C	2017-07-18 15:11:00+03	56000.00
3352C2	2017-07-28 16:59:00+03	111600.00
3352FD	2017-07-14 16:42:00+03	136200.00
33537E	2017-07-02 11:05:00+03	414400.00
3353DC	2017-08-15 11:42:00+03	12600.00
3353F2	2017-06-30 19:37:00+03	52300.00
335445	2017-08-09 20:21:00+03	28800.00
335498	2017-07-18 18:37:00+03	79000.00
33549D	2017-06-28 12:14:00+03	19000.00
3354C1	2017-08-05 07:50:00+03	12000.00
3354E1	2017-07-02 06:48:00+03	91600.00
3354EF	2017-07-27 05:20:00+03	31600.00
33550C	2017-07-28 08:41:00+03	24400.00
335553	2017-06-28 04:42:00+03	579600.00
3356AA	2017-07-24 22:02:00+03	28000.00
33570C	2017-07-23 21:48:00+03	28000.00
335733	2017-07-13 14:12:00+03	99200.00
3357D7	2017-08-05 05:31:00+03	41800.00
33581F	2017-06-29 19:06:00+03	58900.00
33586E	2017-08-03 00:29:00+03	46300.00
33588D	2017-07-14 17:24:00+03	77500.00
3358E6	2017-08-06 16:05:00+03	100200.00
33593C	2017-07-12 01:35:00+03	154800.00
335953	2017-07-14 00:50:00+03	58600.00
33595E	2017-08-08 04:09:00+03	132800.00
335994	2017-07-30 21:29:00+03	56000.00
335A3E	2017-07-12 11:48:00+03	169000.00
335A62	2017-07-26 14:19:00+03	68800.00
335B13	2017-07-06 10:29:00+03	57400.00
335B5A	2017-08-09 04:42:00+03	115600.00
335B5C	2017-08-07 07:22:00+03	126200.00
335B8D	2017-07-02 12:37:00+03	87300.00
335BEA	2017-07-11 17:43:00+03	16400.00
335C22	2017-08-14 22:03:00+03	18400.00
335C55	2017-08-01 21:16:00+03	73100.00
335C8B	2017-07-10 05:42:00+03	46200.00
335C8D	2017-08-09 03:26:00+03	140900.00
335CA6	2017-07-27 14:45:00+03	23200.00
335CD6	2017-08-13 06:50:00+03	103600.00
335CE8	2017-07-25 06:17:00+03	124200.00
335D14	2017-07-21 02:07:00+03	170700.00
335D3A	2017-07-27 21:09:00+03	41800.00
335D87	2017-08-06 02:04:00+03	20400.00
335DE5	2017-07-29 13:39:00+03	73100.00
335E6F	2017-07-07 03:07:00+03	54800.00
335F3B	2017-08-08 22:56:00+03	33100.00
335F4B	2017-07-25 09:19:00+03	23400.00
335F5A	2017-07-21 13:43:00+03	133200.00
335F5F	2017-07-21 05:26:00+03	20200.00
335F68	2017-07-07 03:35:00+03	13800.00
335FA5	2017-07-30 09:26:00+03	189000.00
335FAB	2017-08-05 01:02:00+03	496700.00
335FF2	2017-07-02 22:57:00+03	14700.00
33600A	2017-08-05 00:15:00+03	78400.00
33608E	2017-07-14 17:58:00+03	25400.00
336139	2017-08-09 10:04:00+03	301800.00
336161	2017-07-25 08:35:00+03	93900.00
3361A6	2017-07-31 10:15:00+03	54000.00
3361CE	2017-07-23 21:12:00+03	94700.00
3361D2	2017-08-05 05:36:00+03	115800.00
33628F	2017-07-24 21:27:00+03	25800.00
3362D7	2017-08-12 09:18:00+03	84100.00
336314	2017-07-14 19:37:00+03	84500.00
336395	2017-07-31 10:11:00+03	111600.00
3363D8	2017-08-01 03:30:00+03	21200.00
3363FB	2017-07-19 18:27:00+03	190900.00
336401	2017-07-05 03:44:00+03	6000.00
33641F	2017-08-10 23:55:00+03	69000.00
336484	2017-08-02 15:03:00+03	47200.00
336488	2017-07-17 08:50:00+03	70600.00
3364D4	2017-07-14 22:11:00+03	53300.00
3364ED	2017-07-18 12:25:00+03	24400.00
3364F4	2017-08-13 02:49:00+03	43900.00
336558	2017-07-15 19:40:00+03	193700.00
3365C0	2017-08-11 10:36:00+03	90000.00
336678	2017-08-15 02:23:00+03	67200.00
3366FD	2017-07-16 07:24:00+03	99700.00
33670C	2017-07-06 00:19:00+03	133200.00
336735	2017-06-30 13:28:00+03	12600.00
336753	2017-07-07 22:27:00+03	101200.00
33678F	2017-07-27 19:13:00+03	40000.00
3367BB	2017-07-18 22:17:00+03	79600.00
3367CA	2017-08-04 13:20:00+03	9200.00
3367DA	2017-08-05 22:39:00+03	90000.00
33680E	2017-07-14 15:50:00+03	11800.00
336811	2017-07-15 14:05:00+03	52900.00
336820	2017-06-30 22:52:00+03	188000.00
336839	2017-07-10 20:27:00+03	26000.00
336952	2017-08-01 00:36:00+03	58400.00
3369E3	2017-07-24 09:15:00+03	55800.00
336A24	2017-07-18 03:34:00+03	278600.00
336A29	2017-08-02 02:30:00+03	122500.00
336A37	2017-08-09 05:03:00+03	31400.00
336B02	2017-08-02 02:31:00+03	265600.00
336B63	2017-07-07 23:33:00+03	133200.00
336B90	2017-07-07 06:23:00+03	23400.00
336B9E	2017-07-05 20:30:00+03	64700.00
336BBB	2017-08-03 17:46:00+03	46200.00
336C0E	2017-07-29 14:14:00+03	56900.00
336C6A	2017-07-23 00:54:00+03	89200.00
336CB5	2017-07-02 00:34:00+03	175300.00
336CBF	2017-07-16 00:45:00+03	92800.00
336CF1	2017-07-02 10:38:00+03	47900.00
336D0F	2017-07-27 16:32:00+03	47200.00
336DA4	2017-06-30 03:03:00+03	21600.00
336E14	2017-08-12 23:30:00+03	28800.00
336E40	2017-08-08 21:03:00+03	92900.00
336E43	2017-07-15 21:36:00+03	92000.00
336E7B	2017-07-13 05:12:00+03	10600.00
336EA9	2017-07-06 09:25:00+03	93500.00
336ECA	2017-07-17 10:25:00+03	28800.00
336EEF	2017-07-26 12:58:00+03	58100.00
33700B	2017-07-06 04:25:00+03	57400.00
337014	2017-08-01 01:59:00+03	248300.00
337065	2017-07-21 03:20:00+03	73300.00
337082	2017-08-01 03:45:00+03	16400.00
3370BE	2017-07-28 12:53:00+03	92800.00
337155	2017-07-02 17:37:00+03	90600.00
337222	2017-07-01 22:26:00+03	184300.00
337275	2017-07-09 07:41:00+03	219300.00
3372FE	2017-08-11 21:42:00+03	84100.00
3372FF	2017-08-10 05:18:00+03	45100.00
33731E	2017-07-02 09:21:00+03	81600.00
337367	2017-08-07 04:42:00+03	54300.00
33738D	2017-08-10 10:49:00+03	65500.00
3373D8	2017-07-14 14:36:00+03	39800.00
3373E1	2017-07-12 21:39:00+03	93900.00
3373F0	2017-07-18 03:19:00+03	120700.00
337400	2017-07-13 08:51:00+03	16400.00
33741C	2017-08-13 09:23:00+03	25800.00
337433	2017-07-06 06:17:00+03	55800.00
337456	2017-08-07 01:40:00+03	67200.00
337465	2017-07-10 19:26:00+03	62700.00
337474	2017-07-06 17:27:00+03	28000.00
337484	2017-06-30 10:56:00+03	117600.00
337489	2017-07-14 18:39:00+03	83300.00
337493	2017-07-30 18:14:00+03	289300.00
33749E	2017-07-04 14:47:00+03	189200.00
3374BF	2017-08-11 13:44:00+03	12200.00
33756D	2017-08-13 18:28:00+03	135700.00
3375E8	2017-08-14 16:36:00+03	107000.00
33762E	2017-08-09 16:39:00+03	301800.00
3376AE	2017-06-30 10:07:00+03	196800.00
3376C6	2017-07-01 12:54:00+03	26800.00
3376ED	2017-07-25 02:10:00+03	31600.00
33778C	2017-07-09 21:03:00+03	46300.00
337857	2017-07-17 03:56:00+03	40800.00
3378B9	2017-07-22 08:39:00+03	26500.00
3378BA	2017-07-12 12:56:00+03	25600.00
3378EE	2017-07-20 06:22:00+03	131600.00
337938	2017-07-23 02:13:00+03	133200.00
337956	2017-07-14 15:05:00+03	28000.00
3379B2	2017-07-04 00:11:00+03	69000.00
3379BC	2017-08-02 04:04:00+03	39800.00
3379C8	2017-07-15 21:58:00+03	29800.00
337A3C	2017-07-04 11:25:00+03	50900.00
337A47	2017-08-12 02:42:00+03	27200.00
337A61	2017-08-04 22:42:00+03	42800.00
337A68	2017-07-18 03:54:00+03	92400.00
337A7E	2017-07-29 12:36:00+03	28000.00
337A89	2017-08-11 12:40:00+03	40000.00
337AE7	2017-07-09 04:20:00+03	37100.00
337B0A	2017-08-02 03:04:00+03	16400.00
337B2C	2017-07-16 07:54:00+03	40400.00
337BDA	2017-08-01 17:23:00+03	89000.00
337BFF	2017-07-05 19:40:00+03	22000.00
337C73	2017-07-26 20:26:00+03	161800.00
337C7D	2017-08-08 18:36:00+03	167500.00
337D03	2017-08-13 18:36:00+03	75600.00
337D62	2017-08-05 03:39:00+03	38200.00
337D92	2017-08-12 07:39:00+03	96800.00
337E83	2017-08-12 03:43:00+03	34400.00
337E93	2017-07-30 10:33:00+03	46400.00
337EDE	2017-07-07 15:28:00+03	47400.00
337F82	2017-07-22 07:29:00+03	83100.00
338001	2017-07-29 00:03:00+03	282300.00
33804C	2017-07-23 17:43:00+03	129200.00
33805B	2017-08-14 02:34:00+03	108000.00
338063	2017-08-05 11:43:00+03	32700.00
338108	2017-07-17 00:13:00+03	54500.00
33810C	2017-07-26 16:52:00+03	199600.00
33811A	2017-07-03 16:53:00+03	496600.00
338158	2017-07-08 03:42:00+03	64400.00
33816C	2017-08-10 17:54:00+03	65900.00
3381AE	2017-07-06 22:22:00+03	43000.00
3381B5	2017-07-15 02:33:00+03	212600.00
33820A	2017-07-13 03:37:00+03	86400.00
33821C	2017-07-07 04:24:00+03	52000.00
338393	2017-07-08 23:33:00+03	73200.00
3383B2	2017-08-02 11:54:00+03	38400.00
3383F9	2017-07-24 00:32:00+03	132800.00
338447	2017-07-04 12:06:00+03	27200.00
33849A	2017-07-29 00:19:00+03	40800.00
3384F1	2017-08-02 01:28:00+03	88900.00
338510	2017-07-10 17:46:00+03	246000.00
33851B	2017-08-04 04:39:00+03	76600.00
338529	2017-08-14 14:29:00+03	24300.00
33859D	2017-08-10 11:35:00+03	119500.00
33863C	2017-08-11 03:15:00+03	8000.00
3386EF	2017-08-04 19:54:00+03	33600.00
338720	2017-07-13 00:17:00+03	26000.00
338737	2017-07-02 19:12:00+03	193200.00
3387CF	2017-08-02 23:42:00+03	115800.00
338839	2017-08-09 07:28:00+03	23400.00
338848	2017-08-10 23:10:00+03	494700.00
338872	2017-07-26 23:42:00+03	67600.00
3388AD	2017-07-12 03:02:00+03	47600.00
3388BF	2017-07-06 11:25:00+03	125000.00
3388CC	2017-07-24 04:12:00+03	53700.00
33893A	2017-08-02 18:37:00+03	56000.00
3389C1	2017-08-08 01:01:00+03	6800.00
3389F7	2017-07-10 06:29:00+03	179300.00
338A21	2017-07-20 20:10:00+03	28800.00
338A6B	2017-07-04 19:48:00+03	62600.00
338A81	2017-07-12 14:26:00+03	51800.00
338B11	2017-07-15 04:50:00+03	134000.00
338B27	2017-08-13 02:48:00+03	27800.00
338B7B	2017-07-31 09:02:00+03	67600.00
338BFE	2017-07-26 18:02:00+03	24800.00
338C0B	2017-08-09 09:21:00+03	44800.00
338C0E	2017-07-09 12:05:00+03	43600.00
338C28	2017-07-20 04:50:00+03	28800.00
338C6B	2017-07-24 06:42:00+03	169900.00
338CB1	2017-08-05 01:39:00+03	21200.00
338CB5	2017-07-01 13:54:00+03	69500.00
338CE5	2017-07-25 21:17:00+03	15800.00
338D58	2017-07-18 19:02:00+03	145100.00
338DEA	2017-08-01 21:16:00+03	30000.00
338E0B	2017-07-06 21:57:00+03	68000.00
338E46	2017-08-04 19:46:00+03	67600.00
338EB2	2017-07-05 17:36:00+03	148200.00
338EC9	2017-08-09 00:49:00+03	40700.00
338EED	2017-07-27 00:05:00+03	22000.00
339000	2017-08-02 03:49:00+03	29200.00
33902F	2017-07-20 19:07:00+03	63400.00
33903E	2017-07-07 06:00:00+03	24400.00
33905A	2017-07-16 20:23:00+03	98400.00
339068	2017-07-31 20:14:00+03	125200.00
339102	2017-08-08 11:06:00+03	139800.00
339162	2017-07-27 12:58:00+03	102100.00
3391A5	2017-07-08 07:51:00+03	64700.00
3391EF	2017-07-29 14:27:00+03	75300.00
339264	2017-07-17 21:49:00+03	160200.00
33930F	2017-08-12 13:44:00+03	173900.00
33936A	2017-08-01 14:49:00+03	46400.00
3393AE	2017-08-15 13:55:00+03	16400.00
3393B4	2017-08-11 11:07:00+03	77800.00
3393BF	2017-07-06 21:55:00+03	46000.00
339411	2017-07-24 06:54:00+03	81600.00
339418	2017-08-03 22:59:00+03	18600.00
33947E	2017-08-15 18:00:00+03	102100.00
3394A3	2017-07-31 22:11:00+03	28800.00
33952D	2017-08-14 17:53:00+03	11000.00
3395DD	2017-07-31 23:06:00+03	43000.00
33960B	2017-08-11 01:55:00+03	105000.00
3396A5	2017-07-15 18:07:00+03	18900.00
3396EE	2017-07-21 06:13:00+03	75600.00
33971B	2017-07-03 22:38:00+03	73600.00
339738	2017-08-15 00:06:00+03	83600.00
33974A	2017-07-10 10:43:00+03	40900.00
3397E4	2017-07-05 01:22:00+03	28000.00
33980D	2017-07-11 07:38:00+03	56000.00
3398C5	2017-08-07 00:50:00+03	73000.00
33994C	2017-08-09 02:30:00+03	85000.00
3399A2	2017-07-01 06:05:00+03	41400.00
3399AE	2017-07-06 01:37:00+03	31600.00
3399F9	2017-08-15 08:23:00+03	18600.00
339A65	2017-07-20 22:10:00+03	29600.00
339A81	2017-07-30 02:56:00+03	28000.00
339A93	2017-07-13 02:23:00+03	129600.00
339A9F	2017-08-01 21:41:00+03	32400.00
339AE9	2017-07-21 12:39:00+03	136200.00
339AF3	2017-07-04 13:34:00+03	57300.00
339B0F	2017-08-03 18:04:00+03	56000.00
339B62	2017-08-11 13:33:00+03	40300.00
339BC4	2017-08-12 05:36:00+03	23600.00
339C51	2017-07-08 20:17:00+03	54400.00
339C70	2017-07-11 15:02:00+03	111600.00
339CAB	2017-08-03 04:05:00+03	47000.00
339CB2	2017-07-15 14:41:00+03	52000.00
339D1C	2017-07-24 12:21:00+03	67700.00
339D36	2017-08-15 01:23:00+03	75300.00
339D74	2017-08-04 18:28:00+03	35500.00
339DB0	2017-08-13 00:47:00+03	44000.00
339DB5	2017-07-24 00:23:00+03	100600.00
339DBE	2017-07-03 09:57:00+03	13400.00
339DCD	2017-07-12 19:33:00+03	24400.00
339E21	2017-07-28 15:43:00+03	57400.00
339E2D	2017-08-12 01:20:00+03	98400.00
339E4D	2017-08-07 05:28:00+03	32700.00
339EFC	2017-07-01 07:47:00+03	56600.00
339F67	2017-07-16 09:05:00+03	24700.00
339F85	2017-08-04 03:59:00+03	14000.00
339F86	2017-07-27 20:35:00+03	73500.00
339F9D	2017-08-13 04:33:00+03	75600.00
339FE9	2017-07-22 14:51:00+03	55800.00
339FED	2017-07-24 18:05:00+03	99300.00
33A061	2017-08-12 17:04:00+03	42800.00
33A096	2017-07-14 14:08:00+03	58800.00
33A110	2017-07-25 12:40:00+03	77900.00
33A11A	2017-07-21 06:46:00+03	28000.00
33A15E	2017-08-03 12:46:00+03	48900.00
33A168	2017-06-30 16:07:00+03	147100.00
33A1A5	2017-08-13 07:21:00+03	56600.00
33A1D6	2017-07-21 19:14:00+03	62600.00
33A25C	2017-07-15 14:40:00+03	43500.00
33A270	2017-08-03 15:09:00+03	23100.00
33A2A1	2017-06-30 14:29:00+03	79300.00
33A2B3	2017-07-19 16:10:00+03	18500.00
33A2E9	2017-07-12 11:15:00+03	98100.00
33A2EE	2017-07-28 12:36:00+03	99300.00
33A345	2017-08-15 10:43:00+03	246000.00
33A36B	2017-08-11 18:34:00+03	55800.00
33A38B	2017-08-06 08:01:00+03	12400.00
33A3A0	2017-08-02 16:16:00+03	39500.00
33A3D3	2017-08-08 09:44:00+03	54000.00
33A409	2017-07-31 13:58:00+03	39100.00
33A44E	2017-07-20 18:01:00+03	65200.00
33A457	2017-07-31 13:12:00+03	12600.00
33A4AC	2017-07-25 20:10:00+03	70700.00
33A4BD	2017-07-24 00:23:00+03	32200.00
33A504	2017-07-13 18:50:00+03	139200.00
33A517	2017-07-09 21:32:00+03	89700.00
33A587	2017-07-31 14:56:00+03	46000.00
33A5C1	2017-08-02 08:11:00+03	101500.00
33A61E	2017-08-13 02:16:00+03	45100.00
33A698	2017-07-08 19:16:00+03	86500.00
33A701	2017-07-23 01:22:00+03	44000.00
33A791	2017-07-15 14:19:00+03	62700.00
33A7A3	2017-07-21 08:28:00+03	172600.00
33A7EA	2017-07-20 00:11:00+03	57400.00
33A836	2017-07-16 02:06:00+03	194400.00
33A858	2017-07-20 04:21:00+03	94700.00
33A86C	2017-07-29 01:40:00+03	297300.00
33A874	2017-07-24 10:47:00+03	46700.00
33A877	2017-07-16 11:07:00+03	13600.00
33A927	2017-07-20 07:41:00+03	77600.00
33A986	2017-08-07 18:34:00+03	81800.00
33A9A5	2017-07-18 06:18:00+03	38400.00
33AA5E	2017-07-21 11:22:00+03	47000.00
33AB3C	2017-07-21 11:17:00+03	14000.00
33AC1E	2017-07-22 20:55:00+03	393800.00
33AC24	2017-08-09 15:34:00+03	131600.00
33AC2D	2017-07-03 14:25:00+03	14400.00
33AC4B	2017-08-11 08:26:00+03	39800.00
33AC51	2017-08-14 02:28:00+03	23600.00
33AC76	2017-07-17 03:42:00+03	47100.00
33ACBB	2017-08-06 23:15:00+03	47200.00
33AD2B	2017-07-20 05:18:00+03	29400.00
33AD30	2017-07-30 08:21:00+03	92800.00
33AD59	2017-07-13 16:54:00+03	41900.00
33ADD0	2017-07-05 05:28:00+03	32700.00
33ADD8	2017-07-15 21:10:00+03	75600.00
33ADE7	2017-07-28 10:54:00+03	31500.00
33ADEB	2017-08-12 20:02:00+03	24600.00
33ADF9	2017-07-18 06:57:00+03	24300.00
33AE01	2017-07-13 14:57:00+03	57500.00
33AE7D	2017-08-08 07:03:00+03	31400.00
33AEB6	2017-08-12 17:05:00+03	57600.00
33AED8	2017-08-04 00:59:00+03	100600.00
33AF20	2017-07-30 21:55:00+03	59800.00
33AFCA	2017-08-15 16:16:00+03	40000.00
33B0F4	2017-08-02 15:12:00+03	111600.00
33B119	2017-08-06 01:06:00+03	99300.00
33B12D	2017-07-03 02:01:00+03	93000.00
33B150	2017-07-24 16:43:00+03	61600.00
33B158	2017-08-13 16:50:00+03	128800.00
33B1C3	2017-07-28 18:04:00+03	84900.00
33B251	2017-07-10 11:04:00+03	34000.00
33B26A	2017-07-27 06:44:00+03	28800.00
33B2A3	2017-08-03 19:18:00+03	175200.00
33B3AA	2017-08-05 18:23:00+03	56000.00
33B3E0	2017-07-18 16:59:00+03	231900.00
33B446	2017-08-14 19:36:00+03	18800.00
33B4B3	2017-07-28 19:36:00+03	6000.00
33B4B7	2017-07-09 22:06:00+03	101700.00
33B506	2017-08-11 00:35:00+03	24700.00
33B54F	2017-07-22 05:09:00+03	48800.00
33B55A	2017-08-15 06:11:00+03	246000.00
33B579	2017-08-05 07:12:00+03	49800.00
33B5E6	2017-08-14 18:04:00+03	123000.00
33B617	2017-07-18 04:30:00+03	25400.00
33B670	2017-07-25 08:26:00+03	55800.00
33B775	2017-08-15 03:10:00+03	248400.00
33B7B6	2017-07-12 08:18:00+03	21400.00
33B844	2017-07-20 21:21:00+03	46400.00
33B87C	2017-08-12 21:05:00+03	46400.00
33B882	2017-08-11 11:13:00+03	48800.00
33B894	2017-08-13 20:51:00+03	59900.00
33B8DE	2017-07-29 08:42:00+03	12600.00
33B8E3	2017-07-31 07:54:00+03	23600.00
33B923	2017-08-05 00:50:00+03	97100.00
33B987	2017-08-02 03:34:00+03	27900.00
33B9D4	2017-08-14 02:50:00+03	56600.00
33B9E3	2017-06-28 01:34:00+03	60900.00
33B9F6	2017-07-26 21:56:00+03	69100.00
33BA1D	2017-07-15 15:15:00+03	26200.00
33BA2F	2017-07-27 17:04:00+03	20200.00
33BA32	2017-07-08 16:57:00+03	51900.00
33BB2A	2017-07-17 16:25:00+03	43600.00
33BB46	2017-07-08 13:15:00+03	25400.00
33BB4D	2017-07-19 20:54:00+03	92700.00
33BBB3	2017-08-04 15:22:00+03	143100.00
33BCB9	2017-08-10 23:54:00+03	62600.00
33BCDB	2017-07-14 21:42:00+03	46400.00
33BD75	2017-07-29 00:42:00+03	23400.00
33BDB4	2017-08-08 20:27:00+03	66400.00
33BE90	2017-07-22 12:42:00+03	80000.00
33BEA3	2017-07-05 14:04:00+03	27800.00
33BED7	2017-08-07 20:20:00+03	51600.00
33BF07	2017-07-29 11:50:00+03	141600.00
33BF21	2017-07-25 10:21:00+03	62000.00
33BFA0	2017-07-19 07:45:00+03	45500.00
33BFE1	2017-07-26 01:26:00+03	20000.00
33BFF5	2017-07-16 07:54:00+03	62800.00
33C003	2017-07-07 07:56:00+03	70700.00
33C067	2017-07-01 01:23:00+03	246000.00
33C074	2017-07-29 11:32:00+03	8400.00
33C0C1	2017-07-10 11:37:00+03	266400.00
33C0E9	2017-08-07 19:56:00+03	25200.00
33C16E	2017-07-26 03:29:00+03	77200.00
33C188	2017-07-09 05:12:00+03	73200.00
33C21D	2017-07-19 17:28:00+03	112600.00
33C25A	2017-07-26 11:29:00+03	100600.00
33C2A2	2017-07-06 21:07:00+03	35300.00
33C30E	2017-07-12 17:18:00+03	556200.00
33C347	2017-07-20 04:06:00+03	55800.00
33C36F	2017-07-16 08:53:00+03	141100.00
33C3B3	2017-07-05 21:42:00+03	61700.00
33C3DC	2017-08-14 22:41:00+03	56900.00
33C3F3	2017-08-05 08:19:00+03	37100.00
33C409	2017-07-09 20:02:00+03	40800.00
33C425	2017-07-30 01:33:00+03	26900.00
33C43A	2017-07-19 17:03:00+03	75300.00
33C4E0	2017-07-06 09:33:00+03	68400.00
33C4E9	2017-08-01 13:08:00+03	111600.00
33C517	2017-07-01 19:32:00+03	23200.00
33C524	2017-08-13 14:07:00+03	28800.00
33C52D	2017-07-02 10:17:00+03	92400.00
33C563	2017-08-07 19:38:00+03	24400.00
33C5D1	2017-07-08 09:34:00+03	70000.00
33C5E6	2017-08-10 02:46:00+03	27200.00
33C611	2017-07-07 23:57:00+03	52000.00
33C629	2017-08-11 01:47:00+03	46300.00
33C682	2017-07-05 11:48:00+03	85000.00
33C6D4	2017-08-09 19:51:00+03	63200.00
33C721	2017-07-13 03:24:00+03	6800.00
33C72A	2017-08-01 12:30:00+03	27900.00
33C778	2017-07-13 14:25:00+03	18000.00
33C7C4	2017-07-02 15:52:00+03	26700.00
33C7DF	2017-08-14 07:55:00+03	12400.00
33C7F8	2017-07-26 08:47:00+03	62800.00
33C81E	2017-07-22 00:10:00+03	67600.00
33C8AC	2017-07-10 08:12:00+03	98400.00
33C8B4	2017-07-12 04:44:00+03	37600.00
33C924	2017-07-04 22:09:00+03	136200.00
33C944	2017-07-11 06:07:00+03	64200.00
33C9E2	2017-08-14 12:16:00+03	22600.00
33C9F5	2017-07-25 13:16:00+03	14400.00
33C9F6	2017-07-30 19:58:00+03	95600.00
33CA0E	2017-08-07 05:35:00+03	67800.00
33CA20	2017-08-02 17:39:00+03	27000.00
33CAD7	2017-07-30 22:17:00+03	71600.00
33CB06	2017-08-13 11:37:00+03	15800.00
33CB20	2017-07-01 16:42:00+03	67000.00
33CB3F	2017-07-16 15:24:00+03	56600.00
33CB5B	2017-07-07 04:41:00+03	26000.00
33CB75	2017-08-06 02:11:00+03	20200.00
33CB7E	2017-07-05 07:41:00+03	70700.00
33CC54	2017-08-10 02:26:00+03	21800.00
33CC56	2017-08-02 19:33:00+03	49800.00
33CCFA	2017-08-06 13:52:00+03	23600.00
33CD57	2017-08-03 11:13:00+03	97700.00
33CD7D	2017-07-05 00:00:00+03	86600.00
33CDFF	2017-07-21 02:00:00+03	96800.00
33CEE6	2017-07-30 09:48:00+03	123900.00
33CEF0	2017-08-14 02:25:00+03	62200.00
33CF06	2017-08-09 08:36:00+03	105000.00
33CF67	2017-08-07 03:50:00+03	39800.00
33CFAF	2017-07-17 11:36:00+03	115900.00
33CFC9	2017-07-26 18:35:00+03	70600.00
33CFE1	2017-07-22 20:20:00+03	19000.00
33D09E	2017-07-28 22:22:00+03	36200.00
33D118	2017-08-06 18:02:00+03	26000.00
33D167	2017-07-06 00:44:00+03	55000.00
33D1C2	2017-07-24 00:29:00+03	51900.00
33D1EC	2017-07-01 06:16:00+03	16400.00
33D20F	2017-07-12 23:06:00+03	59800.00
33D2CA	2017-07-23 19:41:00+03	15000.00
33D2E4	2017-07-31 13:25:00+03	38400.00
33D368	2017-07-25 13:10:00+03	64800.00
33D463	2017-08-04 02:06:00+03	387400.00
33D483	2017-07-14 09:05:00+03	144000.00
33D485	2017-08-08 16:30:00+03	52700.00
33D49F	2017-07-26 10:17:00+03	62700.00
33D4FB	2017-07-26 06:51:00+03	6700.00
33D573	2017-07-17 20:33:00+03	62700.00
33D594	2017-08-14 23:17:00+03	46500.00
33D5A1	2017-07-22 20:12:00+03	13200.00
33D61A	2017-08-09 12:26:00+03	52000.00
33D636	2017-08-05 03:44:00+03	68800.00
33D649	2017-07-05 13:20:00+03	87100.00
33D65D	2017-08-04 18:53:00+03	26900.00
33D6CD	2017-07-08 20:11:00+03	62800.00
33D701	2017-07-19 20:53:00+03	23200.00
33D71D	2017-07-14 10:45:00+03	16400.00
33D7D6	2017-07-25 09:20:00+03	118100.00
33D881	2017-07-16 21:36:00+03	44800.00
33D89B	2017-07-16 17:38:00+03	130900.00
33D930	2017-08-13 07:54:00+03	44400.00
33D97E	2017-07-12 14:07:00+03	36200.00
33D9D2	2017-07-29 12:31:00+03	269000.00
33D9F5	2017-07-04 13:24:00+03	7400.00
33DA78	2017-07-26 21:34:00+03	32400.00
33DA79	2017-08-14 09:53:00+03	56200.00
33DAB8	2017-08-01 14:04:00+03	129600.00
33DAE5	2017-06-22 01:29:00+03	57500.00
33DB86	2017-07-27 09:32:00+03	101900.00
33DBA5	2017-07-12 23:26:00+03	89700.00
33DBAB	2017-08-04 21:57:00+03	40800.00
33DBB4	2017-07-29 14:24:00+03	199600.00
33DBCD	2017-07-24 17:46:00+03	106400.00
33DC68	2017-08-07 05:44:00+03	68400.00
33DD40	2017-08-10 01:51:00+03	136500.00
33DD45	2017-07-30 09:10:00+03	51100.00
33DD4E	2017-07-23 22:32:00+03	57600.00
33DD59	2017-07-06 01:29:00+03	56900.00
33DDEE	2017-07-16 10:44:00+03	23600.00
33DE88	2017-07-11 23:45:00+03	56000.00
33DEC0	2017-07-20 19:32:00+03	406100.00
33DEE5	2017-08-13 03:23:00+03	54500.00
33DEF3	2017-07-23 22:36:00+03	24700.00
33DF48	2017-07-12 03:11:00+03	20600.00
33DF55	2017-08-10 14:45:00+03	88500.00
33DF6A	2017-07-22 05:35:00+03	249200.00
33DF80	2017-06-29 22:36:00+03	76800.00
33DF89	2017-07-11 06:02:00+03	43800.00
33DFEF	2017-07-29 00:40:00+03	23200.00
33E00A	2017-08-07 17:42:00+03	99200.00
33E0EE	2017-08-10 20:59:00+03	42000.00
33E19A	2017-07-11 23:34:00+03	47000.00
33E237	2017-08-03 07:36:00+03	49500.00
33E25A	2017-08-11 01:54:00+03	26000.00
33E27D	2017-07-29 10:59:00+03	60700.00
33E2C3	2017-08-02 23:15:00+03	136000.00
33E323	2017-07-18 03:11:00+03	129200.00
33E345	2017-07-22 04:44:00+03	502900.00
33E35F	2017-06-30 07:58:00+03	173500.00
33E40A	2017-07-01 02:37:00+03	99200.00
33E40B	2017-07-10 05:44:00+03	8000.00
33E446	2017-07-25 19:34:00+03	52000.00
33E44F	2017-08-02 16:43:00+03	62000.00
33E470	2017-08-14 11:41:00+03	116100.00
33E483	2017-08-07 01:57:00+03	10800.00
33E4AB	2017-07-25 01:45:00+03	26000.00
33E4B5	2017-08-05 18:08:00+03	70800.00
33E595	2017-07-15 06:09:00+03	16400.00
33E5DC	2017-07-06 10:04:00+03	28000.00
33E60E	2017-07-22 03:26:00+03	47300.00
33E614	2017-07-02 15:24:00+03	131200.00
33E617	2017-07-08 00:49:00+03	27600.00
33E623	2017-07-25 21:31:00+03	116400.00
33E676	2017-08-08 04:19:00+03	28800.00
33E737	2017-08-12 15:30:00+03	51800.00
33E799	2017-07-05 09:36:00+03	34000.00
33E7A8	2017-08-14 08:51:00+03	40600.00
33E821	2017-07-07 11:43:00+03	99300.00
33E825	2017-06-29 04:48:00+03	289400.00
33E83F	2017-08-08 02:36:00+03	47000.00
33E866	2017-08-09 02:54:00+03	28800.00
33E86B	2017-07-03 03:29:00+03	56000.00
33E880	2017-07-05 13:08:00+03	112000.00
33E8B0	2017-08-15 04:32:00+03	383000.00
33E8D3	2017-07-10 09:47:00+03	16400.00
33E905	2017-07-26 02:26:00+03	128800.00
33E90B	2017-08-10 11:46:00+03	85800.00
33E92A	2017-08-14 09:51:00+03	18900.00
33E95E	2017-07-27 21:25:00+03	69400.00
33E9B0	2017-07-28 22:02:00+03	26000.00
33E9D5	2017-08-05 12:31:00+03	22400.00
33EA17	2017-07-22 18:51:00+03	36200.00
33EA6D	2017-07-21 03:51:00+03	75600.00
33EA83	2017-07-19 20:27:00+03	71900.00
33EAE5	2017-07-27 16:27:00+03	28800.00
33EB47	2017-07-20 17:22:00+03	22000.00
33EBB1	2017-07-07 13:54:00+03	96100.00
33EC34	2017-08-12 22:00:00+03	46400.00
33EC3C	2017-07-19 14:10:00+03	28000.00
33EC42	2017-07-23 15:09:00+03	135600.00
33EC82	2017-08-05 20:53:00+03	43900.00
33EC97	2017-08-14 00:45:00+03	286100.00
33ECF8	2017-07-23 13:26:00+03	66100.00
33ECFA	2017-08-04 01:54:00+03	128800.00
33ED11	2017-07-17 05:53:00+03	69500.00
33ED31	2017-08-10 05:03:00+03	29600.00
33ED7A	2017-07-29 08:44:00+03	92900.00
33ED7B	2017-07-25 03:03:00+03	149200.00
33EDEB	2017-07-27 04:56:00+03	103000.00
33EE1C	2017-07-16 20:17:00+03	27300.00
33EE30	2017-07-02 17:03:00+03	13400.00
33EE4D	2017-07-31 15:27:00+03	34000.00
33EE51	2017-08-13 06:06:00+03	83100.00
33EEBB	2017-07-31 04:00:00+03	184100.00
33EEC0	2017-07-27 15:23:00+03	67400.00
33EECF	2017-07-22 00:56:00+03	27500.00
33EF39	2017-08-07 00:19:00+03	148700.00
33EF81	2017-07-24 04:28:00+03	66500.00
33EFB2	2017-07-23 17:59:00+03	44000.00
33EFF3	2017-07-28 14:00:00+03	34000.00
33F001	2017-07-03 19:38:00+03	73500.00
33F002	2017-07-11 05:25:00+03	43700.00
33F10B	2017-07-12 13:06:00+03	65000.00
33F192	2017-07-11 09:22:00+03	111600.00
33F1B1	2017-07-26 09:04:00+03	26600.00
33F1BC	2017-08-02 00:45:00+03	107400.00
33F248	2017-07-16 02:25:00+03	52000.00
33F27B	2017-07-31 01:25:00+03	45000.00
33F284	2017-08-11 18:43:00+03	99200.00
33F38D	2017-07-20 00:22:00+03	88000.00
33F3BB	2017-08-06 04:57:00+03	92900.00
33F3BD	2017-08-08 01:50:00+03	90600.00
33F3E4	2017-08-04 23:28:00+03	27200.00
33F421	2017-07-13 15:48:00+03	29600.00
33F4A4	2017-08-09 07:19:00+03	56000.00
33F4AD	2017-08-13 19:56:00+03	50100.00
33F4F1	2017-07-07 18:59:00+03	112000.00
33F51F	2017-08-08 21:17:00+03	132800.00
33F545	2017-06-27 09:49:00+03	64500.00
33F563	2017-08-05 17:37:00+03	24000.00
33F567	2017-08-03 03:33:00+03	95700.00
33F573	2017-07-09 11:03:00+03	67800.00
33F5A5	2017-07-06 16:57:00+03	26800.00
33F5B2	2017-07-06 23:31:00+03	32900.00
33F5BF	2017-08-14 04:46:00+03	184300.00
33F5E4	2017-07-06 02:04:00+03	91200.00
33F5F7	2017-07-08 18:05:00+03	92100.00
33F688	2017-07-19 12:00:00+03	22000.00
33F6CA	2017-08-12 17:04:00+03	58800.00
33F719	2017-08-14 09:51:00+03	48000.00
33F732	2017-08-02 09:08:00+03	55800.00
33F745	2017-07-12 14:32:00+03	66600.00
33F797	2017-07-07 18:44:00+03	46200.00
33F809	2017-07-12 10:57:00+03	16400.00
33F8CA	2017-06-29 12:48:00+03	58600.00
33F9BC	2017-08-13 12:10:00+03	15400.00
33FA2B	2017-07-08 02:33:00+03	413400.00
33FA43	2017-08-11 12:27:00+03	13200.00
33FA85	2017-07-19 15:48:00+03	173900.00
33FB21	2017-08-11 11:27:00+03	118100.00
33FB36	2017-08-13 05:06:00+03	202700.00
33FB54	2017-07-29 00:33:00+03	100600.00
33FB6A	2017-08-04 03:09:00+03	65600.00
33FB6E	2017-07-06 19:51:00+03	42700.00
33FBA7	2017-08-13 23:33:00+03	106900.00
33FBD0	2017-07-04 20:10:00+03	159800.00
33FBF3	2017-07-30 13:20:00+03	28300.00
33FC71	2017-07-18 20:20:00+03	56000.00
33FC91	2017-07-23 17:44:00+03	26000.00
33FC95	2017-08-15 11:51:00+03	26000.00
33FCD2	2017-08-11 07:21:00+03	76300.00
33FD5E	2017-08-10 19:31:00+03	265700.00
33FD6D	2017-07-13 14:33:00+03	271400.00
33FE47	2017-08-12 14:06:00+03	43500.00
33FE81	2017-08-02 13:48:00+03	28800.00
33FEB8	2017-07-09 22:22:00+03	12400.00
33FEE7	2017-07-14 07:21:00+03	46400.00
33FEEA	2017-07-28 02:04:00+03	259000.00
33FF02	2017-07-28 10:04:00+03	61800.00
33FF06	2017-07-09 08:56:00+03	38600.00
33FF29	2017-07-01 21:43:00+03	48400.00
33FF35	2017-07-03 16:43:00+03	209900.00
33FF5B	2017-07-17 14:01:00+03	32800.00
33FFA8	2017-08-02 02:23:00+03	34000.00
340004	2017-07-23 18:11:00+03	38800.00
340008	2017-07-02 17:28:00+03	248300.00
34005F	2017-08-10 19:09:00+03	39200.00
340069	2017-08-01 07:08:00+03	28800.00
3400A3	2017-07-10 22:26:00+03	12000.00
3400E6	2017-07-23 02:53:00+03	14800.00
340123	2017-07-05 22:26:00+03	89600.00
340137	2017-07-10 19:32:00+03	46800.00
34014D	2017-08-08 03:55:00+03	93900.00
340153	2017-08-01 23:36:00+03	40800.00
340244	2017-08-01 09:50:00+03	111600.00
340265	2017-07-12 04:36:00+03	46400.00
3402C6	2017-07-18 07:24:00+03	13400.00
3403A0	2017-06-27 01:10:00+03	122700.00
3403B8	2017-07-09 21:47:00+03	26200.00
3403E5	2017-07-11 11:18:00+03	59800.00
3403FE	2017-07-06 16:52:00+03	100600.00
3404F4	2017-07-17 08:42:00+03	64700.00
34050D	2017-07-23 04:26:00+03	8200.00
34050E	2017-07-22 08:34:00+03	164700.00
3405AA	2017-07-06 02:21:00+03	76600.00
3405EC	2017-08-08 04:38:00+03	75800.00
340629	2017-07-05 21:57:00+03	23200.00
34069E	2017-07-18 10:30:00+03	52000.00
3406A2	2017-08-11 13:42:00+03	81600.00
340780	2017-07-22 14:14:00+03	53600.00
340788	2017-08-14 23:28:00+03	43200.00
3407BC	2017-08-12 16:18:00+03	270200.00
34084F	2017-08-11 04:16:00+03	22400.00
340946	2017-07-28 03:09:00+03	20200.00
340974	2017-07-09 07:51:00+03	46200.00
3409B7	2017-08-03 05:51:00+03	168000.00
340A5A	2017-07-02 18:29:00+03	82900.00
340A97	2017-07-30 05:33:00+03	193100.00
340ADC	2017-06-25 04:59:00+03	162700.00
340B08	2017-07-06 23:40:00+03	135200.00
340B82	2017-07-10 17:29:00+03	19800.00
340C63	2017-07-18 15:03:00+03	31000.00
340D30	2017-07-09 22:53:00+03	66200.00
340D37	2017-08-08 20:12:00+03	115600.00
340E38	2017-07-05 04:31:00+03	55800.00
340E48	2017-06-28 22:15:00+03	111600.00
340E59	2017-08-13 08:44:00+03	23200.00
340E7C	2017-08-13 00:54:00+03	7200.00
340E95	2017-06-30 13:50:00+03	75600.00
340EC1	2017-08-08 18:53:00+03	51600.00
340EC8	2017-08-11 00:35:00+03	28800.00
340EEC	2017-07-13 13:09:00+03	24400.00
340F34	2017-08-02 22:09:00+03	61800.00
340F3D	2017-07-11 06:25:00+03	21800.00
340F3E	2017-07-25 17:53:00+03	65200.00
340F4E	2017-07-16 17:14:00+03	38600.00
340F67	2017-07-05 20:20:00+03	27800.00
340FA6	2017-08-12 16:39:00+03	112000.00
340FC0	2017-07-13 07:37:00+03	28000.00
340FC3	2017-08-02 15:22:00+03	14000.00
341011	2017-07-27 12:13:00+03	137100.00
34109D	2017-07-23 16:33:00+03	70600.00
3410FF	2017-08-04 09:26:00+03	65900.00
341155	2017-08-05 01:18:00+03	85200.00
34119F	2017-07-02 13:37:00+03	26800.00
3411D6	2017-07-12 05:12:00+03	81600.00
341235	2017-08-06 08:23:00+03	11600.00
341299	2017-07-10 01:25:00+03	73100.00
3412F5	2017-06-28 22:07:00+03	54400.00
3412FB	2017-08-10 13:21:00+03	132800.00
341318	2017-08-12 02:32:00+03	153100.00
341324	2017-07-06 06:16:00+03	16400.00
341420	2017-07-23 02:21:00+03	84100.00
34144D	2017-07-07 16:40:00+03	56000.00
341451	2017-07-17 22:31:00+03	83000.00
34153E	2017-07-23 18:53:00+03	169900.00
3415BA	2017-07-19 23:00:00+03	21200.00
3415CC	2017-08-02 07:50:00+03	51200.00
34160D	2017-07-23 02:27:00+03	36800.00
34163B	2017-08-10 21:42:00+03	23600.00
34165D	2017-08-04 07:39:00+03	154600.00
34167F	2017-07-05 11:53:00+03	98400.00
341696	2017-07-19 17:28:00+03	29400.00
3416BE	2017-07-14 00:01:00+03	61100.00
341730	2017-08-11 12:06:00+03	123000.00
34173B	2017-07-07 20:00:00+03	123000.00
34177B	2017-07-05 13:54:00+03	326200.00
3417AF	2017-08-12 20:11:00+03	24400.00
3417B5	2017-08-04 05:32:00+03	31600.00
3417B6	2017-08-07 16:39:00+03	48500.00
3417B8	2017-07-14 18:27:00+03	58600.00
34180A	2017-08-10 05:46:00+03	62400.00
34183B	2017-08-06 04:50:00+03	45100.00
341843	2017-07-30 01:08:00+03	94500.00
341891	2017-07-18 14:51:00+03	52800.00
3418C5	2017-07-22 23:38:00+03	66800.00
3418FF	2017-07-02 19:59:00+03	13400.00
341931	2017-07-08 19:36:00+03	64800.00
3419D3	2017-07-05 16:42:00+03	15000.00
3419DD	2017-07-16 17:25:00+03	56600.00
3419DE	2017-08-01 17:37:00+03	60900.00
341A23	2017-07-15 02:47:00+03	145600.00
341A2C	2017-08-04 09:37:00+03	24000.00
341A4A	2017-07-05 19:39:00+03	23200.00
341A57	2017-08-09 04:39:00+03	13600.00
341AAD	2017-07-24 00:49:00+03	47100.00
341AF6	2017-08-11 09:23:00+03	23200.00
341B74	2017-07-21 19:32:00+03	42000.00
341BF9	2017-07-15 14:28:00+03	100600.00
341C2F	2017-07-03 15:32:00+03	136200.00
341C5A	2017-07-09 09:15:00+03	95000.00
341C5F	2017-07-10 05:52:00+03	52100.00
341C95	2017-08-07 06:01:00+03	96800.00
341D13	2017-08-08 02:48:00+03	25200.00
341E34	2017-07-05 13:18:00+03	45500.00
341E40	2017-08-13 16:44:00+03	71600.00
341E4C	2017-07-06 19:52:00+03	11800.00
341E6D	2017-07-25 11:11:00+03	19600.00
341E90	2017-07-25 22:22:00+03	16400.00
341E9B	2017-07-15 19:26:00+03	54500.00
341EF1	2017-07-03 23:19:00+03	64800.00
341F05	2017-07-24 22:14:00+03	56000.00
342010	2017-06-27 05:10:00+03	140000.00
342024	2017-07-29 21:19:00+03	28800.00
342050	2017-06-30 07:39:00+03	144000.00
34209C	2017-07-07 13:20:00+03	91800.00
34209D	2017-07-12 22:43:00+03	170000.00
3420A0	2017-07-14 05:09:00+03	64200.00
3420D3	2017-08-14 19:23:00+03	128300.00
3420E7	2017-07-21 17:11:00+03	289900.00
342158	2017-07-14 10:43:00+03	10800.00
342169	2017-07-19 05:23:00+03	28800.00
3421A1	2017-08-13 12:08:00+03	56000.00
342204	2017-08-14 05:23:00+03	123000.00
342207	2017-08-14 14:57:00+03	28000.00
342229	2017-08-01 12:31:00+03	63200.00
34222F	2017-07-25 07:24:00+03	34700.00
34226C	2017-07-25 06:19:00+03	43900.00
342311	2017-08-15 07:52:00+03	35800.00
3423CE	2017-08-05 01:05:00+03	58200.00
3423EF	2017-08-04 18:32:00+03	156300.00
34251D	2017-07-04 15:27:00+03	134400.00
342528	2017-08-14 07:18:00+03	75600.00
342556	2017-08-13 09:01:00+03	31000.00
34257D	2017-08-13 16:06:00+03	34800.00
3425A4	2017-07-18 12:09:00+03	98200.00
3425A5	2017-07-24 05:47:00+03	95600.00
3425E2	2017-08-14 06:05:00+03	14400.00
3425FA	2017-07-05 23:30:00+03	57600.00
342618	2017-08-11 18:29:00+03	67900.00
34265B	2017-08-02 16:38:00+03	47400.00
34266A	2017-08-01 10:21:00+03	88100.00
342689	2017-07-24 04:04:00+03	28000.00
34268E	2017-08-09 18:06:00+03	40800.00
3426B6	2017-07-20 19:56:00+03	265700.00
3426C6	2017-08-09 22:36:00+03	75300.00
3426D1	2017-07-07 09:56:00+03	57800.00
342725	2017-07-21 10:04:00+03	28000.00
342732	2017-08-11 04:48:00+03	21400.00
342738	2017-07-29 02:04:00+03	170600.00
3427E6	2017-07-07 01:31:00+03	26000.00
342827	2017-07-24 04:34:00+03	43000.00
342844	2017-07-21 08:29:00+03	20200.00
342856	2017-07-16 11:08:00+03	81600.00
34287A	2017-07-17 17:07:00+03	50000.00
3428D0	2017-08-02 03:03:00+03	56000.00
342956	2017-07-29 02:36:00+03	124300.00
34295A	2017-07-25 03:51:00+03	89700.00
342991	2017-07-12 07:53:00+03	17200.00
3429C8	2017-07-14 17:06:00+03	56100.00
3429EA	2017-07-19 20:44:00+03	274700.00
3429F6	2017-07-13 18:31:00+03	14000.00
342A7E	2017-07-28 05:17:00+03	99200.00
342A9D	2017-07-20 00:15:00+03	40100.00
342AD9	2017-07-25 02:26:00+03	148700.00
342B0D	2017-07-14 19:41:00+03	81700.00
342B29	2017-07-19 04:24:00+03	332800.00
342B59	2017-08-12 00:53:00+03	61800.00
342B92	2017-08-10 20:45:00+03	381800.00
342BD2	2017-07-21 02:16:00+03	36200.00
342C24	2017-07-03 01:14:00+03	68100.00
342C58	2017-07-17 16:24:00+03	217300.00
342CA7	2017-07-28 10:08:00+03	16400.00
342CC2	2017-08-14 22:11:00+03	292300.00
342D1F	2017-07-26 09:00:00+03	37900.00
342D29	2017-07-19 07:14:00+03	51900.00
342D33	2017-08-01 00:26:00+03	22200.00
342D46	2017-07-03 09:16:00+03	181600.00
342DBB	2017-07-12 03:06:00+03	23600.00
342E04	2017-07-03 20:57:00+03	615000.00
342E12	2017-08-07 11:10:00+03	71100.00
342E4B	2017-08-10 19:40:00+03	20400.00
342F2F	2017-07-21 21:54:00+03	70400.00
342FBC	2017-08-01 10:25:00+03	45100.00
342FF4	2017-08-13 12:20:00+03	48000.00
343036	2017-08-12 19:31:00+03	46800.00
343062	2017-07-01 22:14:00+03	114700.00
343133	2017-08-04 12:55:00+03	49500.00
34314D	2017-07-08 23:23:00+03	26000.00
343182	2017-07-20 17:00:00+03	35200.00
3431AC	2017-07-13 04:25:00+03	111600.00
343214	2017-08-01 01:22:00+03	44000.00
343250	2017-07-29 11:34:00+03	105600.00
34326D	2017-08-04 03:56:00+03	56000.00
343289	2017-07-09 11:37:00+03	19600.00
34331A	2017-07-06 02:12:00+03	62600.00
34339D	2017-08-06 18:41:00+03	102400.00
34342C	2017-07-16 05:12:00+03	61800.00
343437	2017-07-31 11:47:00+03	79900.00
34345B	2017-07-22 18:33:00+03	124800.00
34347B	2017-07-26 18:25:00+03	12600.00
34347E	2017-07-06 15:16:00+03	77000.00
3434AA	2017-08-04 10:00:00+03	37900.00
3434CB	2017-07-25 01:53:00+03	45100.00
343555	2017-07-31 05:57:00+03	28000.00
34362B	2017-07-28 08:11:00+03	103500.00
343643	2017-07-07 23:42:00+03	52600.00
34368D	2017-08-01 21:38:00+03	30000.00
3436D6	2017-06-29 02:08:00+03	57600.00
343733	2017-07-04 17:49:00+03	74400.00
343764	2017-08-15 16:30:00+03	90800.00
343779	2017-08-06 14:38:00+03	46200.00
3437C0	2017-06-30 19:03:00+03	24600.00
34381C	2017-07-19 02:17:00+03	77000.00
343863	2017-08-09 09:12:00+03	46000.00
3438C4	2017-06-28 03:20:00+03	11600.00
343901	2017-07-06 16:59:00+03	45200.00
343936	2017-08-14 09:44:00+03	170600.00
34399D	2017-07-19 19:27:00+03	16400.00
3439B4	2017-08-13 23:57:00+03	45000.00
343A37	2017-07-20 09:07:00+03	133200.00
343A64	2017-07-18 16:56:00+03	37200.00
343ABC	2017-08-07 12:31:00+03	23200.00
343AE6	2017-07-08 03:31:00+03	75300.00
343B0A	2017-07-06 21:43:00+03	28000.00
343BA1	2017-08-08 23:24:00+03	65900.00
343BE0	2017-07-07 21:05:00+03	115700.00
343C71	2017-07-13 04:21:00+03	27400.00
343CA3	2017-07-29 12:25:00+03	68000.00
343CCD	2017-07-17 09:21:00+03	25100.00
343D07	2017-08-01 07:02:00+03	47600.00
343D0F	2017-07-08 17:23:00+03	86600.00
343D14	2017-07-23 23:15:00+03	369000.00
343D4E	2017-07-19 07:01:00+03	95700.00
343D78	2017-08-04 00:10:00+03	27400.00
343D7E	2017-07-17 04:43:00+03	37900.00
343D9D	2017-07-16 23:36:00+03	26200.00
343DE3	2017-08-04 11:16:00+03	24400.00
343DF7	2017-08-02 19:03:00+03	167400.00
343E57	2017-07-08 05:49:00+03	28000.00
343F2B	2017-07-15 07:50:00+03	147100.00
343F51	2017-07-09 20:31:00+03	47600.00
343F7E	2017-07-16 20:18:00+03	46400.00
343FAD	2017-08-06 13:55:00+03	42800.00
343FDF	2017-07-06 13:48:00+03	32800.00
34406C	2017-08-01 21:58:00+03	69700.00
344092	2017-07-31 06:56:00+03	46000.00
3440B2	2017-07-14 22:46:00+03	46200.00
3440C7	2017-07-01 22:50:00+03	40600.00
3440F1	2017-08-02 15:19:00+03	174300.00
344190	2017-07-04 14:51:00+03	516800.00
3441F4	2017-08-10 16:21:00+03	56000.00
34422F	2017-08-01 10:39:00+03	21400.00
344253	2017-07-29 18:47:00+03	35200.00
34429E	2017-08-10 04:07:00+03	29800.00
3442C3	2017-07-30 17:54:00+03	52000.00
34436B	2017-07-16 12:58:00+03	32700.00
344373	2017-07-13 16:44:00+03	24400.00
34437B	2017-07-17 17:34:00+03	28800.00
3443A5	2017-07-16 06:28:00+03	133100.00
3443BD	2017-07-16 15:27:00+03	64700.00
344420	2017-08-14 20:24:00+03	35800.00
344439	2017-07-24 10:05:00+03	136000.00
344443	2017-08-10 23:18:00+03	189800.00
344456	2017-08-10 17:53:00+03	41600.00
34447D	2017-07-16 05:28:00+03	40800.00
34449D	2017-07-30 12:41:00+03	12600.00
34449E	2017-07-07 01:23:00+03	10800.00
3444D5	2017-08-03 07:42:00+03	19800.00
3444FE	2017-07-03 00:41:00+03	18800.00
34452F	2017-07-26 08:04:00+03	40800.00
344545	2017-06-28 23:48:00+03	76900.00
3445FF	2017-06-29 22:06:00+03	26800.00
34463E	2017-07-27 23:52:00+03	26800.00
3446EE	2017-07-26 04:08:00+03	23200.00
344707	2017-07-28 11:19:00+03	189200.00
344708	2017-07-12 02:25:00+03	48800.00
34475E	2017-08-15 16:32:00+03	81400.00
34489E	2017-07-25 23:17:00+03	59800.00
3448ED	2017-08-07 07:59:00+03	6600.00
3448FA	2017-07-09 15:01:00+03	58800.00
344956	2017-07-19 06:13:00+03	40400.00
3449B0	2017-07-20 12:20:00+03	31400.00
3449CA	2017-07-11 09:26:00+03	218800.00
3449E3	2017-07-12 02:28:00+03	124200.00
344A0E	2017-07-15 02:14:00+03	46800.00
344A37	2017-07-30 01:16:00+03	62600.00
344A62	2017-07-27 16:19:00+03	30000.00
344A78	2017-07-10 23:14:00+03	84800.00
344A87	2017-08-13 02:41:00+03	39400.00
344AFD	2017-08-09 03:17:00+03	155200.00
344B0A	2017-07-08 08:28:00+03	36400.00
344B2B	2017-08-11 14:15:00+03	56600.00
344B8F	2017-07-26 12:20:00+03	28000.00
344BC0	2017-07-11 07:25:00+03	113200.00
344C39	2017-07-02 09:28:00+03	65900.00
344C3B	2017-07-18 20:52:00+03	23400.00
344CE8	2017-07-22 08:31:00+03	56600.00
344D2C	2017-08-11 01:12:00+03	85000.00
344DD1	2017-08-12 01:17:00+03	111600.00
344DE7	2017-07-17 12:19:00+03	55800.00
344EBC	2017-07-15 11:14:00+03	31700.00
344EF4	2017-08-05 02:05:00+03	60700.00
344F18	2017-08-01 14:43:00+03	14700.00
344F61	2017-07-16 23:24:00+03	91100.00
344F70	2017-07-30 22:30:00+03	257600.00
344FBF	2017-08-06 17:08:00+03	73500.00
344FE1	2017-08-05 06:30:00+03	11600.00
345092	2017-08-13 08:45:00+03	131100.00
3450A7	2017-07-05 15:23:00+03	30200.00
3450B9	2017-08-05 00:30:00+03	267400.00
3450DB	2017-07-27 22:32:00+03	132800.00
345103	2017-07-01 20:37:00+03	297000.00
34510F	2017-07-26 02:45:00+03	399300.00
345129	2017-07-11 05:11:00+03	66600.00
34513F	2017-07-04 09:58:00+03	112600.00
345179	2017-08-13 12:37:00+03	32800.00
3451E8	2017-08-01 10:02:00+03	115900.00
3451ED	2017-08-06 22:11:00+03	24400.00
34523A	2017-07-08 11:45:00+03	21800.00
345265	2017-07-05 14:51:00+03	64800.00
34528B	2017-07-05 17:19:00+03	111600.00
345302	2017-07-19 05:47:00+03	110500.00
345351	2017-07-26 16:44:00+03	269500.00
34535F	2017-07-21 06:00:00+03	24700.00
3453BF	2017-08-06 11:27:00+03	37100.00
3453D1	2017-07-28 03:50:00+03	75200.00
345487	2017-08-08 07:35:00+03	18000.00
34555B	2017-08-08 07:57:00+03	72200.00
345599	2017-07-06 12:28:00+03	99200.00
3455CD	2017-07-26 23:40:00+03	35700.00
345632	2017-07-30 16:30:00+03	28800.00
3456A7	2017-07-21 21:19:00+03	123200.00
3456B6	2017-08-10 06:28:00+03	369000.00
3456BC	2017-07-04 00:28:00+03	86300.00
3456BD	2017-07-07 13:57:00+03	61800.00
34574A	2017-08-05 23:54:00+03	117600.00
345750	2017-08-01 16:40:00+03	40400.00
3457BF	2017-06-29 02:32:00+03	270800.00
3457F1	2017-07-05 22:53:00+03	37900.00
3458A6	2017-07-22 15:20:00+03	62100.00
3458CA	2017-07-02 05:41:00+03	66000.00
3459DE	2017-07-12 09:18:00+03	78200.00
345A44	2017-07-28 03:50:00+03	79600.00
345A66	2017-07-26 02:13:00+03	20400.00
345A92	2017-08-14 19:08:00+03	42800.00
345A95	2017-07-06 05:52:00+03	69100.00
345AD1	2017-07-31 01:02:00+03	48700.00
345B1C	2017-07-13 19:25:00+03	47200.00
345B2A	2017-07-23 19:58:00+03	186000.00
345B5B	2017-07-03 01:51:00+03	147000.00
345BA6	2017-08-15 03:55:00+03	110500.00
345BFB	2017-07-01 05:09:00+03	110500.00
345C2E	2017-06-30 03:27:00+03	12000.00
345C56	2017-07-22 17:53:00+03	31600.00
345CD1	2017-08-05 19:25:00+03	113200.00
345D08	2017-07-17 17:06:00+03	59800.00
345D50	2017-08-05 12:27:00+03	14400.00
345E6D	2017-08-15 14:10:00+03	102800.00
345E7E	2017-08-03 16:09:00+03	67600.00
345E95	2017-07-29 07:12:00+03	14400.00
345E98	2017-08-01 00:36:00+03	57600.00
345EAA	2017-08-02 14:05:00+03	47700.00
345EC1	2017-07-21 10:05:00+03	64400.00
345F24	2017-08-01 18:06:00+03	101100.00
345F2E	2017-07-07 08:43:00+03	185600.00
34601F	2017-08-13 07:21:00+03	36200.00
3460A1	2017-07-31 00:03:00+03	338000.00
3460D0	2017-07-28 04:43:00+03	114700.00
346148	2017-08-07 06:14:00+03	133100.00
346180	2017-08-14 10:39:00+03	121400.00
346228	2017-08-05 08:05:00+03	46400.00
34626B	2017-07-07 12:55:00+03	158000.00
34629B	2017-08-15 15:55:00+03	24400.00
3462A3	2017-07-17 02:04:00+03	33300.00
34630E	2017-07-20 16:53:00+03	31900.00
3463A4	2017-08-09 22:57:00+03	88200.00
3463AE	2017-07-24 16:47:00+03	246000.00
3463CC	2017-07-20 02:30:00+03	56900.00
3463DE	2017-07-26 19:23:00+03	32700.00
346470	2017-08-04 06:17:00+03	28000.00
346471	2017-07-22 07:31:00+03	67400.00
346493	2017-07-01 04:00:00+03	31100.00
3464EB	2017-07-07 16:56:00+03	24400.00
346573	2017-07-05 23:43:00+03	100200.00
346578	2017-08-03 11:52:00+03	193300.00
34660E	2017-07-28 11:06:00+03	86300.00
34661B	2017-07-25 19:47:00+03	122500.00
346641	2017-07-19 22:37:00+03	58400.00
34665A	2017-07-27 00:23:00+03	27200.00
346671	2017-07-02 16:41:00+03	92800.00
3466F5	2017-08-09 17:15:00+03	122200.00
346710	2017-08-08 03:30:00+03	23400.00
346779	2017-07-18 09:57:00+03	35300.00
3467F6	2017-07-16 03:13:00+03	26000.00
34680E	2017-08-10 11:03:00+03	26800.00
346929	2017-07-16 18:06:00+03	47100.00
34699C	2017-07-22 05:53:00+03	55800.00
3469AD	2017-07-06 09:22:00+03	67300.00
3469E0	2017-07-09 17:03:00+03	61500.00
346A44	2017-08-15 06:00:00+03	36000.00
346A6B	2017-07-23 05:53:00+03	133200.00
346A82	2017-08-03 04:37:00+03	10800.00
346AA1	2017-07-07 04:59:00+03	42000.00
346AD3	2017-07-15 02:22:00+03	135400.00
346AD6	2017-07-28 14:59:00+03	51800.00
346B2D	2017-07-02 11:46:00+03	32700.00
346BA0	2017-07-23 18:43:00+03	390400.00
346BBB	2017-07-04 03:25:00+03	119600.00
346BDF	2017-08-03 10:51:00+03	58200.00
346BF7	2017-07-17 18:18:00+03	131100.00
346C00	2017-08-10 18:10:00+03	37100.00
346C0A	2017-07-12 18:49:00+03	56000.00
346CEE	2017-07-03 17:25:00+03	62000.00
346D04	2017-07-04 03:51:00+03	52000.00
346DE5	2017-07-26 10:04:00+03	45800.00
346ECF	2017-07-15 07:42:00+03	23600.00
346F01	2017-08-13 02:15:00+03	173200.00
346F2B	2017-07-27 01:40:00+03	29100.00
346F2C	2017-08-04 06:39:00+03	55400.00
346F67	2017-07-17 22:20:00+03	37900.00
346F6D	2017-08-08 15:16:00+03	62600.00
346F78	2017-06-30 10:23:00+03	58800.00
346FA4	2017-07-04 03:10:00+03	28800.00
346FB0	2017-07-29 17:18:00+03	101100.00
346FB9	2017-07-28 11:24:00+03	260300.00
347008	2017-08-10 23:26:00+03	239700.00
347036	2017-08-14 18:27:00+03	19600.00
34704A	2017-08-05 10:48:00+03	56000.00
347067	2017-08-15 08:41:00+03	48800.00
347184	2017-07-10 15:32:00+03	260900.00
3471A2	2017-07-05 15:49:00+03	38600.00
347291	2017-08-13 10:08:00+03	22000.00
3472AF	2017-07-15 12:06:00+03	66000.00
3472C7	2017-07-09 19:12:00+03	68800.00
3472CC	2017-08-06 04:57:00+03	56000.00
347324	2017-07-16 06:57:00+03	187600.00
3473BF	2017-08-02 02:54:00+03	20800.00
3473C8	2017-08-12 07:01:00+03	140900.00
3473CC	2017-08-08 23:09:00+03	10800.00
3473D4	2017-07-15 04:52:00+03	75300.00
34742B	2017-07-15 16:45:00+03	30800.00
34748F	2017-08-07 15:53:00+03	131600.00
3474A4	2017-08-02 17:40:00+03	23200.00
3474C8	2017-07-18 12:14:00+03	112000.00
3474FA	2017-08-10 17:29:00+03	13400.00
347544	2017-07-02 01:29:00+03	70200.00
34756A	2017-07-04 09:38:00+03	105600.00
34758C	2017-08-15 04:49:00+03	153800.00
3475A1	2017-07-09 20:54:00+03	36800.00
3475E2	2017-07-26 01:38:00+03	84100.00
3475EF	2017-07-28 04:09:00+03	54800.00
3475F6	2017-07-18 07:27:00+03	31600.00
347662	2017-07-20 15:36:00+03	123000.00
34768C	2017-08-02 13:14:00+03	52700.00
3476B6	2017-07-14 14:51:00+03	134400.00
3476E0	2017-07-17 00:14:00+03	21800.00
347716	2017-08-09 03:11:00+03	112000.00
3477C6	2017-08-07 21:07:00+03	179200.00
3477D3	2017-08-04 03:54:00+03	17600.00
3477D8	2017-07-30 18:26:00+03	54800.00
3477E2	2017-07-03 09:11:00+03	18800.00
34782B	2017-07-27 02:43:00+03	204200.00
34786F	2017-07-19 12:43:00+03	32800.00
3478B7	2017-07-01 14:59:00+03	169200.00
3478F3	2017-08-01 19:39:00+03	65400.00
347906	2017-07-13 19:28:00+03	62700.00
347976	2017-07-14 10:20:00+03	54800.00
3479AF	2017-07-04 22:37:00+03	58600.00
3479DE	2017-08-11 02:13:00+03	23200.00
3479F8	2017-08-03 21:28:00+03	21400.00
347A28	2017-08-04 16:20:00+03	44000.00
347A3E	2017-07-22 18:27:00+03	135000.00
347BD3	2017-07-14 01:47:00+03	55400.00
347BD7	2017-06-27 13:10:00+03	33300.00
347C4F	2017-07-11 19:31:00+03	77000.00
347C91	2017-08-06 13:12:00+03	62600.00
347CEA	2017-08-04 22:03:00+03	194700.00
347D16	2017-07-07 06:22:00+03	84100.00
347DC6	2017-07-13 11:49:00+03	59800.00
347E77	2017-08-12 21:00:00+03	12600.00
347EA5	2017-07-13 08:26:00+03	311900.00
347EB5	2017-08-11 13:35:00+03	139100.00
347F6D	2017-07-23 16:36:00+03	14800.00
347F7E	2017-08-06 21:43:00+03	64400.00
347FEE	2017-07-04 00:12:00+03	56000.00
348001	2017-08-01 16:46:00+03	147100.00
34801E	2017-07-04 04:06:00+03	145000.00
34806C	2017-07-09 04:49:00+03	114700.00
348073	2017-08-11 01:38:00+03	123000.00
34808A	2017-07-01 17:32:00+03	281200.00
348098	2017-07-07 03:15:00+03	155600.00
348099	2017-07-07 03:09:00+03	100600.00
3480BE	2017-07-20 00:54:00+03	41600.00
3480DB	2017-07-14 09:20:00+03	38800.00
3480FD	2017-08-06 22:34:00+03	133200.00
348145	2017-08-13 20:37:00+03	57600.00
3481C5	2017-07-28 22:37:00+03	40800.00
34820E	2017-07-29 06:30:00+03	26800.00
348269	2017-08-15 12:47:00+03	286100.00
3482C8	2017-07-24 11:35:00+03	66000.00
3482E3	2017-08-15 01:20:00+03	48000.00
34831A	2017-07-28 09:46:00+03	48800.00
3483A2	2017-08-05 21:03:00+03	95500.00
3483AB	2017-08-02 15:34:00+03	181100.00
3483B2	2017-07-05 04:31:00+03	32800.00
3483B6	2017-08-04 02:02:00+03	54100.00
348412	2017-07-14 03:25:00+03	56000.00
3484CE	2017-07-28 02:38:00+03	136100.00
348531	2017-08-12 22:09:00+03	176000.00
348536	2017-08-01 08:34:00+03	394400.00
34853A	2017-08-09 16:20:00+03	108200.00
348545	2017-07-29 18:36:00+03	38600.00
348550	2017-07-20 22:35:00+03	28000.00
34855E	2017-07-12 04:46:00+03	47100.00
34857C	2017-08-09 15:06:00+03	61800.00
348589	2017-08-04 20:40:00+03	196600.00
348596	2017-08-02 07:18:00+03	28800.00
3485FD	2017-07-01 05:19:00+03	38800.00
34869E	2017-07-19 22:46:00+03	31400.00
3486CA	2017-08-05 10:55:00+03	6700.00
3486F0	2017-07-26 19:23:00+03	127100.00
34874B	2017-07-17 05:05:00+03	84100.00
348772	2017-07-20 22:46:00+03	43200.00
3487BF	2017-07-09 03:48:00+03	29600.00
3487CA	2017-07-30 05:13:00+03	170600.00
3487DF	2017-07-23 19:52:00+03	81900.00
348820	2017-07-13 22:57:00+03	103900.00
34884B	2017-08-09 05:17:00+03	54400.00
348854	2017-08-06 22:25:00+03	265700.00
3488A3	2017-08-10 11:44:00+03	12000.00
3488CE	2017-07-22 15:19:00+03	38800.00
3488E3	2017-08-14 02:22:00+03	63700.00
34890A	2017-08-02 17:49:00+03	47100.00
348917	2017-07-16 02:08:00+03	282300.00
34892E	2017-08-09 16:50:00+03	56000.00
348935	2017-06-29 05:08:00+03	135200.00
34895A	2017-06-26 23:56:00+03	123700.00
3489D3	2017-07-22 10:42:00+03	56000.00
3489E6	2017-07-08 16:59:00+03	73500.00
3489FA	2017-08-03 07:44:00+03	32800.00
348A10	2017-07-17 09:10:00+03	62600.00
348A5E	2017-08-04 04:04:00+03	124200.00
348A62	2017-08-04 03:11:00+03	36200.00
348A9C	2017-07-15 13:17:00+03	44300.00
348ACC	2017-08-14 11:22:00+03	137600.00
348AFA	2017-08-01 08:54:00+03	110100.00
348B6D	2017-07-05 21:32:00+03	265700.00
348BD8	2017-08-05 23:11:00+03	55800.00
348C07	2017-07-28 05:36:00+03	36200.00
348C16	2017-07-02 12:00:00+03	36800.00
348C17	2017-07-16 00:27:00+03	199700.00
348C84	2017-08-06 22:55:00+03	214700.00
348CE2	2017-08-02 09:58:00+03	265800.00
348D5E	2017-07-16 14:15:00+03	100600.00
348DA1	2017-06-28 06:06:00+03	32400.00
348E3D	2017-08-15 04:44:00+03	420500.00
348E8D	2017-08-03 13:42:00+03	30400.00
348EDB	2017-07-21 13:03:00+03	135400.00
348F11	2017-07-26 14:56:00+03	43500.00
348F48	2017-08-04 07:57:00+03	51900.00
348F51	2017-07-08 19:27:00+03	75300.00
348F5F	2017-07-08 15:14:00+03	28000.00
348F6A	2017-07-30 04:07:00+03	286100.00
348F73	2017-07-17 11:12:00+03	393600.00
348FCA	2017-07-04 08:28:00+03	62100.00
349021	2017-07-26 06:57:00+03	68000.00
349027	2017-07-01 00:48:00+03	42900.00
349044	2017-07-20 14:35:00+03	113300.00
34905F	2017-07-09 21:25:00+03	8600.00
3490A0	2017-07-25 11:07:00+03	135600.00
3490B1	2017-07-14 17:36:00+03	26700.00
3490D4	2017-07-09 01:01:00+03	12900.00
3490FC	2017-07-06 14:59:00+03	15000.00
349106	2017-07-15 11:28:00+03	132800.00
34910D	2017-07-05 09:36:00+03	135400.00
349177	2017-07-18 11:53:00+03	27400.00
34919D	2017-07-22 00:42:00+03	46000.00
34921D	2017-08-06 00:51:00+03	14000.00
34925B	2017-07-06 05:57:00+03	21400.00
349266	2017-08-15 07:18:00+03	64000.00
3492A8	2017-08-09 13:38:00+03	75500.00
3492CB	2017-07-19 00:01:00+03	13400.00
349304	2017-07-11 11:58:00+03	52900.00
349309	2017-07-02 09:45:00+03	150600.00
349365	2017-07-05 00:59:00+03	235700.00
349375	2017-08-12 23:34:00+03	58600.00
3493C8	2017-08-06 02:13:00+03	81700.00
3493D1	2017-07-21 07:16:00+03	172700.00
349418	2017-07-13 19:24:00+03	149300.00
349445	2017-08-05 09:44:00+03	32800.00
349453	2017-08-07 05:43:00+03	39300.00
349461	2017-08-10 15:57:00+03	24800.00
349489	2017-07-20 04:53:00+03	36800.00
34956F	2017-07-08 02:14:00+03	56000.00
3495BB	2017-08-09 00:06:00+03	32500.00
3495C8	2017-08-09 10:51:00+03	47000.00
3495D3	2017-07-03 15:27:00+03	65900.00
3495D8	2017-07-11 07:45:00+03	76600.00
349604	2017-07-07 08:25:00+03	99200.00
349620	2017-07-18 11:45:00+03	168700.00
34965E	2017-07-30 06:36:00+03	42100.00
34967C	2017-08-06 17:40:00+03	111600.00
349692	2017-07-25 03:48:00+03	56600.00
3496D9	2017-07-19 06:56:00+03	44700.00
349724	2017-07-25 11:26:00+03	55800.00
3497E7	2017-08-11 13:54:00+03	26800.00
3497EC	2017-06-30 02:31:00+03	31600.00
3497F3	2017-08-13 17:19:00+03	67200.00
349814	2017-08-03 13:52:00+03	13400.00
349873	2017-08-09 14:33:00+03	99200.00
349880	2017-08-07 14:41:00+03	36200.00
3498A8	2017-07-01 08:03:00+03	50100.00
3498DE	2017-07-09 23:55:00+03	40800.00
349904	2017-07-28 17:40:00+03	56000.00
34991A	2017-07-30 16:15:00+03	64800.00
3499B9	2017-06-29 11:01:00+03	124200.00
349A3D	2017-08-11 06:19:00+03	243600.00
349B0D	2017-08-13 05:20:00+03	34000.00
349B7E	2017-07-29 09:37:00+03	56000.00
349B90	2017-07-04 05:15:00+03	65900.00
349BB0	2017-07-15 20:53:00+03	168000.00
349BBA	2017-07-04 00:47:00+03	166000.00
349BC0	2017-08-14 13:43:00+03	13400.00
349BED	2017-08-12 03:13:00+03	46400.00
349BFA	2017-08-04 08:52:00+03	31600.00
349BFD	2017-08-05 06:38:00+03	23900.00
349C23	2017-07-29 08:20:00+03	81600.00
349C29	2017-08-14 04:24:00+03	13700.00
349C44	2017-07-20 21:41:00+03	19600.00
349C5A	2017-07-24 13:59:00+03	266400.00
349D2D	2017-07-30 14:36:00+03	86000.00
349D42	2017-07-23 03:17:00+03	53300.00
349DE2	2017-08-09 22:09:00+03	32400.00
349DF7	2017-07-16 05:56:00+03	57800.00
349E20	2017-07-27 12:47:00+03	7300.00
349E22	2017-07-13 17:23:00+03	61800.00
349ECA	2017-07-28 21:43:00+03	103800.00
349EE0	2017-07-22 14:47:00+03	11600.00
349EF5	2017-07-28 23:13:00+03	133600.00
349F86	2017-07-24 16:43:00+03	115600.00
349FD9	2017-08-14 15:10:00+03	73200.00
349FDA	2017-07-27 17:26:00+03	57400.00
349FF5	2017-07-01 19:42:00+03	82900.00
34A002	2017-07-08 02:25:00+03	91600.00
34A097	2017-07-06 03:06:00+03	28800.00
34A0C1	2017-07-27 21:44:00+03	13400.00
34A153	2017-07-27 08:59:00+03	23400.00
34A19E	2017-07-06 16:53:00+03	118500.00
34A232	2017-08-13 04:06:00+03	42700.00
34A315	2017-07-26 13:50:00+03	24300.00
34A32B	2017-07-09 13:12:00+03	266400.00
34A35D	2017-07-28 12:24:00+03	20500.00
34A370	2017-07-28 05:02:00+03	51900.00
34A3B3	2017-07-15 16:25:00+03	260300.00
34A433	2017-08-15 15:04:00+03	284400.00
34A476	2017-07-23 05:26:00+03	62600.00
34A48F	2017-08-14 15:55:00+03	28800.00
34A497	2017-07-01 11:27:00+03	43200.00
34A4CA	2017-07-28 15:43:00+03	87000.00
34A4F2	2017-07-21 15:59:00+03	103200.00
34A520	2017-07-08 12:34:00+03	46800.00
34A582	2017-07-28 02:22:00+03	26800.00
34A5A6	2017-08-02 02:56:00+03	166900.00
34A625	2017-08-11 06:01:00+03	44000.00
34A637	2017-07-07 08:01:00+03	13400.00
34A642	2017-07-25 20:32:00+03	61800.00
34A648	2017-08-14 20:29:00+03	106900.00
34A696	2017-08-12 21:25:00+03	57800.00
34A6A1	2017-07-09 17:17:00+03	68800.00
34A6C2	2017-08-10 07:58:00+03	65900.00
34A6DD	2017-08-15 11:40:00+03	37200.00
34A6FE	2017-07-15 23:59:00+03	52300.00
34A744	2017-08-01 22:29:00+03	10800.00
34A769	2017-08-06 09:05:00+03	271100.00
34A808	2017-07-15 18:48:00+03	38800.00
34A819	2017-07-06 08:44:00+03	43100.00
34A83C	2017-07-31 16:22:00+03	84300.00
34A83F	2017-07-23 11:47:00+03	133200.00
34A877	2017-08-05 08:17:00+03	30200.00
34A8A1	2017-07-05 15:58:00+03	76400.00
34A920	2017-07-22 09:05:00+03	58000.00
34A983	2017-07-14 20:15:00+03	192700.00
34A99F	2017-07-31 16:25:00+03	40000.00
34A9AC	2017-07-31 03:50:00+03	69500.00
34A9CD	2017-07-04 17:16:00+03	123000.00
34A9D6	2017-08-13 19:35:00+03	69600.00
34AA84	2017-07-20 12:39:00+03	16800.00
34AABB	2017-07-12 13:14:00+03	28000.00
34AAF2	2017-06-30 08:27:00+03	61900.00
34AB0D	2017-08-08 15:50:00+03	24400.00
34AB2A	2017-07-18 11:13:00+03	142400.00
34AB55	2017-08-01 12:02:00+03	76600.00
34AB68	2017-07-06 10:08:00+03	56600.00
34AB92	2017-08-11 10:55:00+03	56600.00
34ABE5	2017-07-01 20:23:00+03	77200.00
34AC31	2017-07-25 22:20:00+03	135600.00
34AC6F	2017-07-16 05:40:00+03	64100.00
34AD42	2017-07-20 21:21:00+03	52700.00
34ADC0	2017-07-13 08:42:00+03	14400.00
34ADE4	2017-07-25 12:10:00+03	61800.00
34ADF6	2017-06-28 08:16:00+03	135600.00
34AE2D	2017-07-23 00:51:00+03	108600.00
34AE91	2017-07-14 08:47:00+03	88600.00
34AEC4	2017-07-15 05:06:00+03	46400.00
34AF6C	2017-08-15 01:13:00+03	78700.00
34AF73	2017-07-18 00:00:00+03	38600.00
34AFAC	2017-07-12 11:54:00+03	266500.00
34B0C2	2017-07-13 08:09:00+03	119500.00
34B138	2017-08-03 11:45:00+03	56000.00
34B19F	2017-07-08 07:45:00+03	36000.00
34B1BB	2017-07-30 22:51:00+03	42900.00
34B1C4	2017-07-16 15:49:00+03	58600.00
34B1DD	2017-07-15 09:48:00+03	26600.00
34B1EC	2017-08-07 00:58:00+03	28000.00
34B231	2017-08-03 16:05:00+03	6000.00
34B26A	2017-07-21 05:20:00+03	28700.00
34B279	2017-07-18 08:53:00+03	55800.00
34B2DD	2017-08-05 20:39:00+03	193700.00
34B32E	2017-08-12 08:15:00+03	148200.00
34B377	2017-07-10 11:49:00+03	23100.00
34B3E3	2017-07-07 12:21:00+03	8800.00
34B43E	2017-08-11 12:21:00+03	25200.00
34B440	2017-07-10 11:15:00+03	89500.00
34B498	2017-08-02 05:44:00+03	24800.00
34B4BF	2017-07-12 08:16:00+03	116700.00
34B4EA	2017-08-07 21:44:00+03	15700.00
34B525	2017-08-02 05:37:00+03	25400.00
34B55B	2017-07-04 02:18:00+03	35200.00
34B566	2017-07-26 21:36:00+03	22000.00
34B595	2017-08-06 22:02:00+03	54800.00
34B5C2	2017-07-27 12:56:00+03	119600.00
34B5FA	2017-07-26 22:38:00+03	58400.00
34B73C	2017-08-10 12:28:00+03	85400.00
34B751	2017-08-08 22:56:00+03	78700.00
34B76B	2017-08-13 07:00:00+03	36000.00
34B786	2017-07-19 09:49:00+03	107300.00
34B7FE	2017-07-07 08:41:00+03	189000.00
34B809	2017-07-04 18:41:00+03	24600.00
34B83C	2017-08-07 23:40:00+03	32700.00
34B85F	2017-07-30 06:02:00+03	55800.00
34B86A	2017-07-25 04:26:00+03	6000.00
34B914	2017-07-26 23:08:00+03	26200.00
34B915	2017-07-04 17:26:00+03	70600.00
34B91E	2017-07-27 17:08:00+03	66000.00
34B9AD	2017-08-01 15:17:00+03	89600.00
34B9E7	2017-07-14 11:12:00+03	90400.00
34B9F4	2017-07-13 11:19:00+03	56000.00
34BA06	2017-07-25 19:18:00+03	56600.00
34BA24	2017-07-14 17:05:00+03	107400.00
34BA39	2017-08-08 02:21:00+03	23200.00
34BA46	2017-07-07 11:17:00+03	75300.00
34BAB3	2017-07-02 02:07:00+03	56000.00
34BACE	2017-08-09 15:10:00+03	85000.00
34BAE6	2017-07-11 03:02:00+03	45200.00
34BAE9	2017-08-06 15:01:00+03	28000.00
34BAF7	2017-07-07 15:59:00+03	86800.00
34BB65	2017-07-11 11:05:00+03	67400.00
34BB66	2017-07-10 04:58:00+03	13400.00
34BBCD	2017-08-10 14:36:00+03	99200.00
34BBCF	2017-08-04 10:43:00+03	15000.00
34BC29	2017-08-15 05:04:00+03	51600.00
34BC62	2017-08-07 20:58:00+03	34100.00
34BC6D	2017-08-05 17:55:00+03	118000.00
34BCAF	2017-07-15 09:58:00+03	99700.00
34BCB1	2017-08-04 22:15:00+03	14000.00
34BCB6	2017-07-15 19:25:00+03	49200.00
34BCDC	2017-07-27 03:36:00+03	28800.00
34BCE3	2017-08-05 18:25:00+03	25400.00
34BCF9	2017-08-12 21:12:00+03	30200.00
34BD75	2017-07-25 14:14:00+03	6000.00
34BD91	2017-08-10 09:58:00+03	13400.00
34BDA3	2017-07-26 08:23:00+03	214100.00
34BDE5	2017-08-11 02:59:00+03	184300.00
34BE4E	2017-08-05 05:38:00+03	33400.00
34BE4F	2017-07-21 16:19:00+03	67800.00
34BE75	2017-07-18 15:26:00+03	124200.00
34BEA0	2017-07-13 08:43:00+03	62600.00
34BED6	2017-07-09 09:47:00+03	13600.00
34BF2B	2017-08-12 04:54:00+03	63200.00
34BF36	2017-07-01 01:48:00+03	13400.00
34BF51	2017-08-14 04:43:00+03	39800.00
34BF82	2017-07-05 09:57:00+03	29600.00
34BF9E	2017-07-29 10:22:00+03	54900.00
34BFCE	2017-08-01 11:17:00+03	56000.00
34BFDD	2017-08-14 22:40:00+03	21000.00
34C002	2017-07-08 01:38:00+03	103200.00
34C065	2017-07-20 01:00:00+03	23400.00
34C0AF	2017-07-09 12:18:00+03	12200.00
34C0E5	2017-07-26 21:35:00+03	89600.00
34C133	2017-07-03 10:30:00+03	37200.00
34C135	2017-08-06 01:11:00+03	214900.00
34C16B	2017-08-02 07:24:00+03	40000.00
34C210	2017-07-25 06:47:00+03	31400.00
34C21C	2017-07-17 02:56:00+03	16400.00
34C250	2017-08-10 23:15:00+03	46400.00
34C285	2017-07-02 12:23:00+03	53600.00
34C307	2017-08-01 05:09:00+03	145100.00
34C32A	2017-07-11 16:53:00+03	85000.00
34C3A1	2017-07-03 22:16:00+03	9800.00
34C3B2	2017-07-14 08:23:00+03	47200.00
34C3C1	2017-07-15 05:27:00+03	131100.00
34C3F2	2017-07-26 02:35:00+03	155000.00
34C429	2017-07-23 07:38:00+03	27300.00
34C42C	2017-07-10 05:31:00+03	32800.00
34C454	2017-08-09 05:00:00+03	56000.00
34C466	2017-07-24 18:51:00+03	12400.00
34C4AE	2017-07-24 05:25:00+03	135000.00
34C574	2017-08-05 17:34:00+03	37600.00
34C636	2017-08-02 00:01:00+03	291000.00
34C644	2017-08-08 18:14:00+03	265700.00
34C66D	2017-07-23 19:02:00+03	7400.00
34C6DF	2017-07-09 16:51:00+03	12000.00
34C6FF	2017-08-07 02:09:00+03	124200.00
34C71D	2017-08-10 10:43:00+03	151300.00
34C71E	2017-07-23 11:07:00+03	89700.00
34C75F	2017-08-11 01:44:00+03	55500.00
34C7D5	2017-07-31 14:00:00+03	89700.00
34C819	2017-07-23 01:04:00+03	56000.00
34C856	2017-07-12 23:45:00+03	27600.00
34C87C	2017-07-12 00:53:00+03	27700.00
34C93D	2017-08-01 08:30:00+03	70700.00
34C962	2017-07-05 23:00:00+03	20200.00
34C963	2017-07-11 10:42:00+03	177200.00
34C9F4	2017-07-20 14:33:00+03	43400.00
34C9F9	2017-07-27 16:56:00+03	87100.00
34CA79	2017-07-25 21:57:00+03	14400.00
34CA90	2017-07-24 16:46:00+03	12600.00
34CAC9	2017-08-01 10:23:00+03	72200.00
34CB38	2017-07-17 18:33:00+03	23200.00
34CB7A	2017-08-12 06:46:00+03	26000.00
34CBB5	2017-07-29 14:01:00+03	136500.00
34CBEA	2017-07-31 01:10:00+03	40800.00
34CBFB	2017-08-05 13:40:00+03	101200.00
34CC30	2017-07-06 09:07:00+03	70700.00
34CCE5	2017-08-15 05:07:00+03	18500.00
34CD82	2017-08-03 01:55:00+03	78600.00
34CDAA	2017-08-10 11:28:00+03	26400.00
34CDD2	2017-08-01 08:42:00+03	24400.00
34CE20	2017-08-04 12:36:00+03	53300.00
34CE50	2017-07-14 07:07:00+03	51200.00
34CE51	2017-07-20 21:28:00+03	111300.00
34CE7B	2017-07-09 17:54:00+03	124300.00
34CEB1	2017-07-11 15:06:00+03	28800.00
34CEB3	2017-07-20 00:12:00+03	129000.00
34CEDB	2017-07-25 13:24:00+03	128000.00
34CEE6	2017-07-24 04:14:00+03	56300.00
34CEE9	2017-07-05 01:17:00+03	22000.00
34CF6B	2017-07-13 07:41:00+03	29200.00
34D019	2017-08-10 04:02:00+03	141600.00
34D024	2017-08-10 09:26:00+03	121400.00
34D0DD	2017-07-19 10:02:00+03	59000.00
34D192	2017-08-04 04:51:00+03	12600.00
34D1A7	2017-07-30 11:03:00+03	21400.00
34D1D8	2017-07-26 14:56:00+03	123600.00
34D23B	2017-08-12 21:38:00+03	23600.00
34D24A	2017-07-20 21:30:00+03	29100.00
34D373	2017-07-07 10:32:00+03	57600.00
34D380	2017-08-04 13:34:00+03	44500.00
34D440	2017-07-20 20:22:00+03	42900.00
34D444	2017-07-09 12:59:00+03	70500.00
34D472	2017-07-21 20:20:00+03	57600.00
34D54F	2017-07-28 19:25:00+03	33200.00
34D5CC	2017-07-20 05:08:00+03	61800.00
34D5D4	2017-07-07 21:41:00+03	223400.00
34D5F0	2017-06-27 07:03:00+03	20400.00
34D63D	2017-07-21 04:50:00+03	44600.00
34D649	2017-07-30 20:22:00+03	102100.00
34D672	2017-07-06 12:35:00+03	31200.00
34D728	2017-07-17 03:28:00+03	42700.00
34D735	2017-07-05 22:13:00+03	26000.00
34D79B	2017-07-13 21:13:00+03	27600.00
34D7B4	2017-08-13 12:00:00+03	12000.00
34D7FE	2017-08-01 12:02:00+03	133100.00
34D860	2017-07-09 21:22:00+03	65500.00
34D883	2017-07-06 18:44:00+03	42800.00
34D940	2017-07-08 07:11:00+03	17600.00
34D94B	2017-07-05 10:34:00+03	37500.00
34D963	2017-07-30 13:53:00+03	49100.00
34DA7A	2017-07-21 08:44:00+03	105000.00
34DAAD	2017-07-03 21:45:00+03	42400.00
34DAB9	2017-07-03 19:32:00+03	48500.00
34DAE8	2017-07-02 23:25:00+03	46000.00
34DB4B	2017-07-15 16:30:00+03	13400.00
34DB6C	2017-07-09 15:18:00+03	130400.00
34DD08	2017-07-08 04:24:00+03	55800.00
34DD27	2017-07-07 06:33:00+03	13700.00
34DD73	2017-08-04 08:21:00+03	47800.00
34DD78	2017-08-07 10:33:00+03	37700.00
34DD8D	2017-08-14 08:33:00+03	13400.00
34DD94	2017-08-02 16:55:00+03	56000.00
34DDC1	2017-07-09 11:43:00+03	135000.00
34DDD2	2017-08-05 10:40:00+03	30400.00
34DDEB	2017-08-09 12:10:00+03	6700.00
34DDF3	2017-08-01 04:40:00+03	73600.00
34DE23	2017-07-29 01:01:00+03	20600.00
34DE52	2017-07-26 23:18:00+03	41200.00
34DE72	2017-07-18 09:09:00+03	25600.00
34DE8C	2017-07-10 03:27:00+03	25600.00
34DEAB	2017-08-02 09:53:00+03	135200.00
34DEDD	2017-08-02 12:07:00+03	196800.00
34DF40	2017-07-17 22:26:00+03	23100.00
34DF6F	2017-08-13 11:29:00+03	47300.00
34DF7D	2017-07-13 12:49:00+03	96100.00
34DFFA	2017-08-13 03:35:00+03	46000.00
34E094	2017-07-09 05:39:00+03	35600.00
34E0DB	2017-07-02 12:39:00+03	26700.00
34E123	2017-07-12 23:55:00+03	17200.00
34E1F6	2017-07-24 22:17:00+03	12000.00
34E2AC	2017-07-29 01:05:00+03	18600.00
34E302	2017-08-15 17:47:00+03	43900.00
34E38C	2017-07-30 05:40:00+03	135600.00
34E3AE	2017-07-22 18:58:00+03	47200.00
34E3B2	2017-07-23 08:04:00+03	56000.00
34E3CB	2017-08-10 07:32:00+03	49300.00
34E3F8	2017-07-02 11:29:00+03	97900.00
34E423	2017-08-12 09:22:00+03	28000.00
34E456	2017-07-05 14:27:00+03	120900.00
34E45F	2017-07-13 05:02:00+03	80300.00
34E47C	2017-08-05 18:33:00+03	56000.00
34E492	2017-07-14 15:22:00+03	58800.00
34E519	2017-08-12 03:29:00+03	113600.00
34E5A8	2017-07-25 20:05:00+03	103800.00
34E5C3	2017-07-27 13:02:00+03	28000.00
34E611	2017-07-10 09:01:00+03	12000.00
34E69C	2017-07-21 18:56:00+03	36800.00
34E6BE	2017-07-16 17:56:00+03	117500.00
34E6FC	2017-07-03 16:57:00+03	270200.00
34E787	2017-07-24 11:58:00+03	47200.00
34E849	2017-07-03 15:15:00+03	199800.00
34E8AC	2017-07-10 18:10:00+03	29400.00
34E93D	2017-08-02 00:35:00+03	53600.00
34E949	2017-07-07 10:40:00+03	47000.00
34E974	2017-08-14 14:22:00+03	270800.00
34E995	2017-08-03 17:53:00+03	212000.00
34EAA9	2017-07-20 13:13:00+03	46200.00
34EB58	2017-08-10 18:14:00+03	26200.00
34EB5B	2017-08-04 15:21:00+03	40000.00
34EB9C	2017-07-26 16:09:00+03	99700.00
34EC0C	2017-07-28 15:40:00+03	94000.00
34EC65	2017-08-01 23:31:00+03	44700.00
34ED8B	2017-08-12 02:35:00+03	40800.00
34EE0D	2017-08-13 15:54:00+03	47200.00
34EE33	2017-08-15 12:38:00+03	50000.00
34EE5A	2017-08-03 18:33:00+03	26000.00
34EE78	2017-06-29 03:07:00+03	77900.00
34EF06	2017-07-30 07:32:00+03	77000.00
34EF4D	2017-08-10 08:04:00+03	61900.00
34EF94	2017-07-14 06:36:00+03	93400.00
34EFA2	2017-07-25 04:31:00+03	46400.00
34EFA6	2017-07-20 18:10:00+03	89600.00
34F057	2017-08-15 12:20:00+03	73200.00
34F0FC	2017-07-01 09:28:00+03	46800.00
34F111	2017-07-13 23:13:00+03	32800.00
34F165	2017-07-23 02:44:00+03	40800.00
34F18E	2017-08-13 22:44:00+03	109200.00
34F1CE	2017-07-05 02:39:00+03	47700.00
34F229	2017-07-18 04:43:00+03	28800.00
34F249	2017-07-28 14:21:00+03	260300.00
34F25E	2017-08-03 07:44:00+03	46300.00
34F288	2017-07-28 20:58:00+03	88600.00
34F2AC	2017-08-12 01:47:00+03	88800.00
34F30A	2017-07-28 17:16:00+03	454500.00
34F45D	2017-07-05 15:38:00+03	46000.00
34F471	2017-07-18 02:06:00+03	92000.00
34F4AA	2017-07-31 18:27:00+03	96300.00
34F4F1	2017-08-01 12:49:00+03	81600.00
34F5A5	2017-07-10 06:23:00+03	38800.00
34F5F4	2017-07-19 17:26:00+03	21400.00
34F62C	2017-08-13 17:22:00+03	211000.00
34F65D	2017-07-17 23:04:00+03	13200.00
34F695	2017-08-08 02:42:00+03	49800.00
34F6F8	2017-07-26 02:46:00+03	135300.00
34F70C	2017-07-20 00:04:00+03	58900.00
34F744	2017-07-15 19:17:00+03	16400.00
34F765	2017-08-05 22:26:00+03	152900.00
34F76F	2017-07-09 12:08:00+03	227000.00
34F7AE	2017-07-20 10:56:00+03	89600.00
34F7F0	2017-08-13 11:41:00+03	116600.00
34F848	2017-07-26 05:09:00+03	128800.00
34F84C	2017-08-04 22:07:00+03	91200.00
34F877	2017-07-19 19:43:00+03	66100.00
34F8D0	2017-07-18 11:53:00+03	47600.00
34F94F	2017-08-08 21:08:00+03	148200.00
34F95D	2017-08-03 09:32:00+03	10700.00
34F966	2017-07-19 00:06:00+03	123700.00
34F998	2017-07-03 00:13:00+03	134600.00
34F9D7	2017-07-10 12:16:00+03	111700.00
34FA2B	2017-08-03 02:37:00+03	12600.00
34FA2D	2017-07-04 08:18:00+03	87400.00
34FA60	2017-07-08 23:30:00+03	227800.00
34FA69	2017-07-15 22:01:00+03	8200.00
34FA74	2017-07-13 16:00:00+03	137600.00
34FA94	2017-08-03 13:19:00+03	40800.00
34FAAF	2017-07-23 20:45:00+03	23200.00
34FAF5	2017-07-10 08:31:00+03	83600.00
34FB21	2017-07-25 06:40:00+03	54400.00
34FB83	2017-08-09 12:40:00+03	45200.00
34FBA9	2017-07-18 04:57:00+03	136500.00
34FCAF	2017-07-13 01:31:00+03	170700.00
34FCDA	2017-07-02 03:36:00+03	155600.00
34FD37	2017-07-22 12:43:00+03	8400.00
34FD41	2017-07-12 05:54:00+03	31400.00
34FD61	2017-07-26 06:07:00+03	43000.00
34FDA4	2017-06-29 07:06:00+03	6300.00
34FDFF	2017-07-21 14:36:00+03	105400.00
34FE19	2017-07-24 03:02:00+03	56000.00
34FE20	2017-08-07 18:48:00+03	45100.00
34FEEA	2017-07-21 01:48:00+03	23400.00
34FF20	2017-07-09 01:18:00+03	48500.00
34FF98	2017-07-16 11:31:00+03	57800.00
34FFF3	2017-07-20 06:47:00+03	99200.00
34FFFB	2017-07-28 06:40:00+03	25100.00
350021	2017-08-11 11:38:00+03	82900.00
350043	2017-07-16 06:03:00+03	19600.00
3500D9	2017-08-03 06:27:00+03	43600.00
350183	2017-07-22 08:44:00+03	122300.00
3501AF	2017-07-11 13:19:00+03	66000.00
3501B9	2017-08-15 07:07:00+03	25800.00
350208	2017-07-15 09:03:00+03	54000.00
35023C	2017-07-27 12:53:00+03	56000.00
35024B	2017-08-12 19:16:00+03	264000.00
350265	2017-07-05 07:20:00+03	179100.00
350271	2017-07-11 09:06:00+03	50600.00
350308	2017-07-03 00:58:00+03	75600.00
350384	2017-07-11 13:28:00+03	150300.00
3503C4	2017-08-12 03:04:00+03	55600.00
350407	2017-08-15 07:34:00+03	56000.00
350411	2017-08-10 22:34:00+03	29800.00
350460	2017-07-14 07:07:00+03	23200.00
350473	2017-07-30 01:39:00+03	28600.00
3504D3	2017-07-04 17:43:00+03	13700.00
3504E0	2017-07-24 12:04:00+03	136800.00
3504F8	2017-07-23 20:25:00+03	55800.00
35054E	2017-07-10 00:52:00+03	13700.00
350610	2017-07-18 00:16:00+03	31600.00
350617	2017-08-05 07:36:00+03	50600.00
350647	2017-07-05 02:07:00+03	93700.00
3506AB	2017-08-02 23:28:00+03	75600.00
3506AC	2017-08-01 09:59:00+03	297600.00
3506B1	2017-07-04 05:16:00+03	67600.00
350741	2017-07-17 13:34:00+03	43200.00
350747	2017-08-14 05:48:00+03	12600.00
350768	2017-07-25 12:02:00+03	28000.00
35079C	2017-07-19 07:05:00+03	27200.00
3507D6	2017-08-02 01:05:00+03	97600.00
350863	2017-07-11 14:08:00+03	123000.00
3508C0	2017-08-09 05:46:00+03	28000.00
350913	2017-08-01 23:40:00+03	60400.00
3509CD	2017-08-14 20:18:00+03	59000.00
350A15	2017-08-14 00:48:00+03	24400.00
350A42	2017-08-03 09:26:00+03	356000.00
350B3C	2017-07-04 17:59:00+03	165100.00
350B5D	2017-08-11 15:44:00+03	17000.00
350BBA	2017-08-02 16:35:00+03	67700.00
350BC8	2017-07-11 08:59:00+03	26000.00
350BCB	2017-07-01 06:18:00+03	37100.00
350BDD	2017-07-28 09:20:00+03	24700.00
350BDE	2017-07-26 13:26:00+03	147800.00
350BE4	2017-07-13 21:17:00+03	88900.00
350BF4	2017-07-01 16:49:00+03	96800.00
350C50	2017-07-07 08:27:00+03	36800.00
350CD0	2017-08-10 14:39:00+03	136600.00
350D38	2017-08-05 18:00:00+03	46000.00
350D44	2017-07-10 08:00:00+03	134600.00
350DF7	2017-08-05 23:32:00+03	26000.00
350E1D	2017-07-19 00:36:00+03	246000.00
350E2F	2017-08-06 02:43:00+03	34600.00
350EC4	2017-08-14 09:02:00+03	238200.00
350F27	2017-07-26 12:18:00+03	260900.00
350F56	2017-07-26 16:12:00+03	36200.00
350F59	2017-07-17 17:43:00+03	115700.00
350F62	2017-07-23 23:16:00+03	52300.00
350F9F	2017-08-04 21:43:00+03	82900.00
350FCB	2017-07-02 23:51:00+03	46000.00
350FD1	2017-07-20 22:24:00+03	46000.00
351036	2017-07-28 00:19:00+03	122000.00
351053	2017-08-11 02:45:00+03	113600.00
351075	2017-07-24 17:49:00+03	56000.00
35107B	2017-07-02 20:48:00+03	382200.00
351087	2017-08-02 07:06:00+03	128800.00
351122	2017-07-23 20:24:00+03	131100.00
351170	2017-07-11 14:58:00+03	86800.00
351190	2017-08-13 15:38:00+03	201800.00
3511D6	2017-07-02 16:06:00+03	88800.00
3511ED	2017-08-03 11:05:00+03	28000.00
35122B	2017-08-01 21:06:00+03	64900.00
35123A	2017-07-09 10:33:00+03	13800.00
351273	2017-07-21 20:32:00+03	174400.00
3512A6	2017-07-14 06:25:00+03	73500.00
3512AB	2017-07-04 10:17:00+03	66000.00
3512D6	2017-06-30 20:23:00+03	8200.00
3512EA	2017-07-26 23:39:00+03	43100.00
35131F	2017-08-15 05:58:00+03	182300.00
351361	2017-08-14 14:52:00+03	65900.00
351372	2017-08-03 01:12:00+03	23600.00
3513CE	2017-08-07 07:13:00+03	46800.00
3513DD	2017-07-06 17:16:00+03	8000.00
3513F7	2017-07-29 12:41:00+03	6000.00
351408	2017-07-08 12:37:00+03	234700.00
35153D	2017-07-27 15:51:00+03	50600.00
351581	2017-06-30 20:04:00+03	50800.00
3516E2	2017-08-07 03:04:00+03	26000.00
3516FE	2017-08-02 08:27:00+03	55800.00
351720	2017-07-25 06:56:00+03	78300.00
35173D	2017-07-05 21:31:00+03	7200.00
3517A7	2017-08-11 09:32:00+03	99200.00
3517D9	2017-08-03 23:49:00+03	23600.00
3517EA	2017-07-06 15:17:00+03	58800.00
35182F	2017-07-15 17:07:00+03	50000.00
351844	2017-07-22 02:06:00+03	46400.00
351859	2017-08-12 02:10:00+03	37400.00
35185B	2017-08-02 02:43:00+03	189200.00
35197B	2017-07-30 02:36:00+03	84800.00
3519A7	2017-07-26 22:34:00+03	123000.00
3519DC	2017-08-05 08:54:00+03	32800.00
3519F1	2017-08-12 23:08:00+03	189800.00
351A3A	2017-08-11 21:19:00+03	14400.00
351A81	2017-08-01 08:07:00+03	29600.00
351A9D	2017-08-13 04:57:00+03	23200.00
351A9F	2017-07-22 17:42:00+03	70700.00
351B07	2017-07-23 06:29:00+03	93800.00
351B61	2017-07-30 10:45:00+03	169600.00
351B7A	2017-07-12 02:19:00+03	97500.00
351C1E	2017-07-16 11:17:00+03	24400.00
351CB2	2017-07-24 01:36:00+03	65500.00
351CEF	2017-08-12 02:11:00+03	118000.00
351D25	2017-08-03 09:05:00+03	43600.00
351D3D	2017-07-03 07:49:00+03	70700.00
351D57	2017-07-07 13:15:00+03	6600.00
351D6C	2017-08-05 11:25:00+03	28800.00
351D88	2017-07-07 19:59:00+03	46400.00
351DBD	2017-07-26 07:11:00+03	303600.00
351DE4	2017-07-02 19:56:00+03	43800.00
351DF9	2017-07-08 14:05:00+03	26600.00
351E52	2017-08-09 09:22:00+03	6000.00
351E69	2017-07-10 17:52:00+03	58400.00
351EB0	2017-07-27 17:07:00+03	73300.00
351EB8	2017-08-06 02:09:00+03	40600.00
351ED8	2017-07-31 03:21:00+03	469600.00
351EFE	2017-08-07 19:44:00+03	48300.00
351F8A	2017-07-31 22:07:00+03	47400.00
351FDF	2017-08-12 11:35:00+03	38500.00
35202B	2017-07-12 12:53:00+03	20400.00
352093	2017-08-04 12:10:00+03	111700.00
3521A0	2017-08-01 09:32:00+03	56100.00
3521B4	2017-07-11 15:00:00+03	56900.00
3521CF	2017-07-03 04:25:00+03	51900.00
3521F8	2017-07-23 23:50:00+03	103200.00
352266	2017-08-03 14:32:00+03	149900.00
352278	2017-07-28 04:04:00+03	44800.00
35228D	2017-07-15 09:17:00+03	229900.00
3522BD	2017-07-11 01:55:00+03	24400.00
3522C0	2017-06-26 21:32:00+03	34400.00
3522D0	2017-07-22 15:03:00+03	75700.00
35230A	2017-07-17 01:46:00+03	6700.00
352364	2017-08-08 17:07:00+03	106200.00
352370	2017-07-18 01:59:00+03	10600.00
352384	2017-07-23 09:05:00+03	92100.00
352460	2017-07-16 20:17:00+03	28000.00
3524F6	2017-07-16 11:21:00+03	28800.00
35252B	2017-07-16 11:13:00+03	123000.00
35256A	2017-07-08 13:28:00+03	76600.00
352582	2017-08-04 16:16:00+03	21400.00
352613	2017-08-10 02:43:00+03	46400.00
352638	2017-08-12 03:05:00+03	204300.00
35264A	2017-07-26 16:57:00+03	260300.00
352673	2017-07-28 08:55:00+03	68800.00
3526A1	2017-07-22 14:25:00+03	56000.00
3526D5	2017-07-20 11:32:00+03	170000.00
3526EF	2017-07-13 07:45:00+03	68800.00
35274D	2017-08-08 18:27:00+03	43200.00
3527F0	2017-07-25 06:55:00+03	28000.00
35281F	2017-07-20 04:54:00+03	39800.00
35283B	2017-08-02 00:46:00+03	28200.00
352865	2017-08-07 04:14:00+03	189000.00
3528E1	2017-08-04 12:30:00+03	271200.00
352931	2017-08-04 02:11:00+03	133100.00
3529EC	2017-08-10 22:51:00+03	207200.00
352A6C	2017-07-09 18:14:00+03	6800.00
352A8F	2017-07-19 20:35:00+03	59800.00
352AA1	2017-07-31 11:12:00+03	188000.00
352AAE	2017-08-11 21:08:00+03	118700.00
352AD3	2017-07-17 04:24:00+03	33300.00
352B0D	2017-08-07 06:55:00+03	58000.00
352B6C	2017-08-12 00:07:00+03	28800.00
352BDA	2017-07-16 14:34:00+03	77900.00
352C61	2017-07-12 19:09:00+03	73600.00
352C6D	2017-07-25 18:59:00+03	32800.00
352C86	2017-06-27 03:24:00+03	24400.00
352C97	2017-08-02 05:04:00+03	46300.00
352CBA	2017-07-16 10:54:00+03	44400.00
352CE9	2017-08-13 03:49:00+03	13400.00
352D43	2017-07-22 08:37:00+03	244100.00
352D7A	2017-08-04 20:24:00+03	13700.00
352D92	2017-08-05 04:09:00+03	14800.00
352D98	2017-08-13 08:52:00+03	46400.00
352DAA	2017-08-14 05:48:00+03	38600.00
352DDE	2017-06-29 14:19:00+03	51900.00
352E45	2017-07-10 16:37:00+03	157100.00
352E5E	2017-07-01 13:46:00+03	29100.00
352EC5	2017-08-01 21:12:00+03	58900.00
352F8C	2017-08-10 08:36:00+03	32900.00
352F97	2017-07-27 23:30:00+03	120900.00
352FF3	2017-07-21 16:35:00+03	113300.00
353061	2017-07-30 16:47:00+03	84000.00
3530BF	2017-07-04 13:04:00+03	36200.00
3530E8	2017-08-01 15:42:00+03	40200.00
3531DC	2017-08-06 08:16:00+03	12600.00
3532CE	2017-07-05 10:43:00+03	47200.00
353301	2017-07-13 03:14:00+03	52300.00
3533EB	2017-07-23 20:41:00+03	67700.00
35341A	2017-07-15 22:20:00+03	280000.00
353477	2017-07-11 12:07:00+03	14400.00
35347D	2017-07-07 03:02:00+03	30200.00
3534B7	2017-07-26 15:50:00+03	22600.00
3534D9	2017-07-27 10:17:00+03	88600.00
3534DD	2017-07-21 10:14:00+03	56000.00
353553	2017-07-29 08:41:00+03	59700.00
353578	2017-08-06 19:42:00+03	44800.00
35358D	2017-08-05 01:57:00+03	116400.00
3535C3	2017-07-05 12:10:00+03	38800.00
3535C8	2017-07-19 22:01:00+03	92700.00
353689	2017-07-14 04:34:00+03	72000.00
3536D8	2017-07-09 10:08:00+03	265700.00
35374A	2017-07-03 19:23:00+03	39000.00
353780	2017-07-26 06:11:00+03	134000.00
353782	2017-07-25 14:06:00+03	243100.00
3537E8	2017-07-11 00:53:00+03	117500.00
3537EF	2017-07-15 14:56:00+03	23400.00
353838	2017-07-22 03:36:00+03	39300.00
353851	2017-07-27 15:46:00+03	66600.00
353915	2017-07-27 21:47:00+03	23400.00
353932	2017-07-11 13:31:00+03	111600.00
353955	2017-07-03 21:53:00+03	105000.00
35396E	2017-07-08 13:57:00+03	17200.00
353990	2017-08-15 07:41:00+03	282000.00
3539B9	2017-07-16 11:54:00+03	55900.00
353A7C	2017-08-05 06:42:00+03	108200.00
353AAC	2017-07-30 09:01:00+03	116400.00
353B0D	2017-07-21 08:59:00+03	25100.00
353B59	2017-07-20 01:34:00+03	56000.00
353B6F	2017-08-05 10:55:00+03	50000.00
353B97	2017-08-07 09:38:00+03	102800.00
353B9C	2017-06-27 11:16:00+03	55800.00
353BAD	2017-08-11 12:46:00+03	46000.00
353BD9	2017-07-22 07:37:00+03	185800.00
353C40	2017-07-25 09:31:00+03	46800.00
353C54	2017-07-15 22:39:00+03	43600.00
353C83	2017-08-03 00:24:00+03	65000.00
353CBA	2017-08-12 21:30:00+03	24400.00
353CCC	2017-07-03 00:47:00+03	83000.00
353CD5	2017-07-27 21:43:00+03	92900.00
353D1F	2017-07-29 17:21:00+03	14400.00
353D9D	2017-06-30 17:27:00+03	20600.00
353DA2	2017-07-20 09:19:00+03	85600.00
353DA5	2017-07-13 16:19:00+03	167900.00
353DE0	2017-07-29 02:29:00+03	46300.00
353E07	2017-07-23 12:12:00+03	187900.00
353E98	2017-07-27 05:42:00+03	6000.00
353E9D	2017-07-16 10:14:00+03	99800.00
353F0C	2017-07-20 05:53:00+03	185300.00
353F18	2017-06-29 19:00:00+03	76800.00
353F23	2017-07-20 10:36:00+03	111600.00
353F25	2017-08-14 07:36:00+03	52000.00
353F39	2017-08-09 05:44:00+03	36800.00
353F7A	2017-08-14 16:34:00+03	77000.00
353F93	2017-07-26 16:28:00+03	8000.00
353F9C	2017-08-09 19:34:00+03	234100.00
353FA5	2017-07-13 08:46:00+03	266400.00
353FA8	2017-07-26 22:03:00+03	24300.00
353FF7	2017-07-29 13:02:00+03	56600.00
35402D	2017-08-09 14:24:00+03	286100.00
3540FB	2017-08-03 21:36:00+03	27000.00
354109	2017-07-11 11:45:00+03	67400.00
354114	2017-08-15 09:33:00+03	199700.00
3541CD	2017-06-30 00:38:00+03	108100.00
35427D	2017-07-03 07:03:00+03	90900.00
3542BA	2017-07-27 10:48:00+03	44400.00
3542DC	2017-08-07 11:36:00+03	119900.00
3542E4	2017-08-14 19:30:00+03	64000.00
3542F7	2017-07-26 10:02:00+03	23600.00
3542FC	2017-08-07 19:51:00+03	12600.00
354329	2017-07-01 14:08:00+03	98400.00
3543F6	2017-08-09 20:38:00+03	369000.00
3544C7	2017-08-09 08:30:00+03	87900.00
354509	2017-08-03 04:21:00+03	7400.00
35452C	2017-08-04 02:27:00+03	26600.00
354572	2017-08-11 00:47:00+03	56000.00
354587	2017-08-07 15:41:00+03	189800.00
35458A	2017-07-15 11:38:00+03	160700.00
35458B	2017-08-08 13:31:00+03	6700.00
3545DD	2017-06-29 19:38:00+03	176600.00
3545EE	2017-07-05 08:34:00+03	69500.00
354612	2017-07-25 00:05:00+03	85600.00
354697	2017-07-08 21:46:00+03	10600.00
3548E9	2017-08-08 16:56:00+03	21400.00
3548EE	2017-07-06 13:48:00+03	12600.00
354919	2017-07-07 07:24:00+03	36200.00
35493A	2017-07-16 13:01:00+03	134400.00
354992	2017-07-13 21:23:00+03	36800.00
3549AC	2017-07-15 04:13:00+03	22000.00
3549BF	2017-07-12 06:45:00+03	103900.00
3549E3	2017-08-05 10:55:00+03	187800.00
354A7F	2017-08-12 04:07:00+03	6700.00
354A83	2017-08-05 00:36:00+03	86800.00
354BC6	2017-07-21 07:33:00+03	116000.00
354BD5	2017-07-16 06:56:00+03	326100.00
354BE2	2017-07-12 11:17:00+03	6700.00
354C09	2017-07-13 01:56:00+03	138500.00
354C9B	2017-07-04 04:17:00+03	13600.00
354CDF	2017-07-25 04:29:00+03	174000.00
354CE9	2017-07-08 20:41:00+03	37900.00
354D52	2017-07-12 03:09:00+03	45200.00
354D82	2017-08-01 18:23:00+03	153200.00
354DB1	2017-08-02 14:45:00+03	27900.00
354DDA	2017-07-15 13:30:00+03	56000.00
354E38	2017-07-25 20:01:00+03	131000.00
354E8A	2017-08-13 21:27:00+03	11600.00
354EA7	2017-08-11 18:19:00+03	67700.00
354EE3	2017-08-10 16:42:00+03	24200.00
354EEC	2017-08-07 05:35:00+03	92000.00
354F6A	2017-07-06 22:54:00+03	6700.00
354FFC	2017-07-23 21:59:00+03	56900.00
3550C3	2017-08-08 19:59:00+03	8600.00
35513B	2017-08-12 01:25:00+03	177200.00
35513D	2017-07-29 04:53:00+03	83700.00
3551B2	2017-08-09 04:08:00+03	29600.00
3551D2	2017-08-08 05:05:00+03	120900.00
355210	2017-07-12 06:15:00+03	265700.00
355271	2017-08-06 19:10:00+03	36800.00
3552C5	2017-07-18 22:26:00+03	85000.00
3552E1	2017-08-09 05:02:00+03	37900.00
355320	2017-07-02 20:31:00+03	57400.00
35532C	2017-07-08 10:22:00+03	33400.00
35532F	2017-07-25 11:39:00+03	145200.00
3553AA	2017-07-21 16:18:00+03	266400.00
3553FD	2017-08-05 12:51:00+03	70600.00
355456	2017-07-25 10:16:00+03	23400.00
355458	2017-07-11 02:52:00+03	31100.00
3554C8	2017-07-04 10:31:00+03	64800.00
355503	2017-08-07 12:58:00+03	30800.00
35552A	2017-07-24 21:01:00+03	53600.00
355597	2017-07-24 12:17:00+03	38400.00
3555B6	2017-07-01 00:33:00+03	44800.00
35569B	2017-08-01 12:03:00+03	84300.00
3556E0	2017-08-06 11:07:00+03	177500.00
3556E4	2017-07-03 20:14:00+03	59300.00
355731	2017-08-06 15:15:00+03	43900.00
355778	2017-07-02 13:56:00+03	402400.00
3557F3	2017-07-14 01:49:00+03	30400.00
3557F6	2017-08-13 04:16:00+03	26700.00
355848	2017-07-12 22:50:00+03	88600.00
355878	2017-07-13 16:34:00+03	28000.00
3558F9	2017-07-26 20:45:00+03	50600.00
355964	2017-07-22 22:56:00+03	124000.00
355972	2017-08-08 05:41:00+03	94000.00
355983	2017-07-13 09:29:00+03	75600.00
3559CF	2017-08-15 15:12:00+03	139400.00
355A31	2017-07-08 19:48:00+03	36800.00
355AA4	2017-07-25 18:26:00+03	111600.00
355B25	2017-07-15 22:46:00+03	61400.00
355B43	2017-07-16 17:07:00+03	64100.00
355B54	2017-07-18 21:43:00+03	35700.00
355B55	2017-07-30 15:32:00+03	12000.00
355B62	2017-07-17 06:29:00+03	111500.00
355B79	2017-07-31 08:31:00+03	189200.00
355B99	2017-08-12 04:35:00+03	35200.00
355BAE	2017-07-25 17:35:00+03	12400.00
355BD8	2017-07-16 13:24:00+03	28000.00
355BFF	2017-07-28 09:05:00+03	39500.00
355C08	2017-07-20 09:04:00+03	341000.00
355CDC	2017-07-02 04:37:00+03	16400.00
355D41	2017-07-02 09:31:00+03	69500.00
355D59	2017-07-16 12:49:00+03	420500.00
355D88	2017-07-03 06:57:00+03	62100.00
355DB1	2017-08-14 17:15:00+03	18600.00
355E5E	2017-07-28 11:39:00+03	42800.00
355EAF	2017-08-02 18:58:00+03	15000.00
355ED1	2017-08-14 14:15:00+03	9200.00
355F0D	2017-07-07 09:09:00+03	67400.00
355F69	2017-07-02 21:52:00+03	76600.00
355F80	2017-08-01 00:46:00+03	28000.00
355F86	2017-07-11 15:09:00+03	99300.00
355FCE	2017-08-05 23:27:00+03	101200.00
355FF7	2017-07-27 14:05:00+03	107400.00
35603A	2017-07-24 09:31:00+03	99200.00
356080	2017-07-10 10:08:00+03	30200.00
3560A8	2017-07-03 01:21:00+03	94800.00
3560B5	2017-07-07 03:29:00+03	43100.00
3560B7	2017-07-02 05:34:00+03	19100.00
3560F8	2017-07-08 07:21:00+03	67600.00
35612D	2017-07-17 13:10:00+03	49600.00
3561DA	2017-07-18 07:15:00+03	57500.00
356241	2017-07-13 18:04:00+03	24700.00
35625B	2017-07-06 17:49:00+03	11200.00
356287	2017-07-03 07:20:00+03	58400.00
3562AC	2017-07-19 01:21:00+03	53300.00
356326	2017-07-10 19:28:00+03	251100.00
35637D	2017-08-06 01:54:00+03	33200.00
3563A5	2017-07-25 01:00:00+03	62000.00
3563B9	2017-07-20 10:19:00+03	265800.00
3563C1	2017-07-25 15:16:00+03	24400.00
3563F7	2017-07-30 21:49:00+03	122500.00
356470	2017-07-18 23:36:00+03	23200.00
35647D	2017-07-16 07:43:00+03	39300.00
35648C	2017-07-11 16:44:00+03	94700.00
3564F3	2017-07-25 09:09:00+03	82900.00
35651B	2017-07-20 14:26:00+03	73600.00
356647	2017-07-30 15:17:00+03	173900.00
3566E7	2017-08-02 14:41:00+03	52400.00
3566F3	2017-07-24 18:46:00+03	111600.00
35676F	2017-07-16 11:07:00+03	114800.00
3567CC	2017-08-07 17:09:00+03	21800.00
3567D1	2017-08-03 15:26:00+03	58800.00
35682F	2017-07-04 20:01:00+03	28000.00
35684C	2017-08-03 06:10:00+03	22000.00
356874	2017-07-20 21:05:00+03	96800.00
356922	2017-07-08 09:12:00+03	73900.00
356955	2017-08-12 03:33:00+03	23200.00
356ADA	2017-07-29 21:03:00+03	59400.00
356AF5	2017-07-03 15:16:00+03	54300.00
356B14	2017-07-29 04:00:00+03	111600.00
356B6B	2017-07-14 03:50:00+03	46000.00
356B7A	2017-08-06 10:38:00+03	23600.00
356B9A	2017-07-06 22:17:00+03	104900.00
356BE7	2017-07-11 03:15:00+03	101200.00
356C46	2017-08-06 06:16:00+03	72200.00
356C52	2017-07-14 15:08:00+03	76600.00
356C62	2017-08-03 17:21:00+03	67000.00
356C72	2017-07-09 22:54:00+03	43200.00
356C75	2017-07-28 01:02:00+03	261600.00
356CEA	2017-07-26 06:05:00+03	47200.00
356D08	2017-08-10 20:34:00+03	31900.00
356DF7	2017-08-04 17:14:00+03	67900.00
356E48	2017-08-12 14:22:00+03	55500.00
356EE5	2017-08-09 23:15:00+03	78600.00
356EF6	2017-08-12 18:56:00+03	48800.00
356FB1	2017-07-19 01:04:00+03	58600.00
356FBE	2017-08-02 17:35:00+03	227900.00
357056	2017-07-21 10:03:00+03	58000.00
357063	2017-08-11 01:35:00+03	114400.00
357084	2017-08-15 14:35:00+03	22000.00
3570E0	2017-07-22 05:55:00+03	84500.00
35717A	2017-07-11 18:35:00+03	140900.00
3571FA	2017-07-28 03:06:00+03	284700.00
35720C	2017-08-13 07:14:00+03	150600.00
35727A	2017-07-13 07:59:00+03	40800.00
357288	2017-07-29 22:27:00+03	13600.00
3572CD	2017-07-04 13:53:00+03	28000.00
3572E0	2017-07-25 21:32:00+03	52900.00
357322	2017-07-27 21:58:00+03	46000.00
35734C	2017-07-01 22:19:00+03	32200.00
35738C	2017-08-08 20:01:00+03	42600.00
35746C	2017-08-11 10:47:00+03	21800.00
35746F	2017-08-07 04:27:00+03	89800.00
35747F	2017-07-09 21:04:00+03	23400.00
357495	2017-07-18 00:46:00+03	23200.00
357524	2017-07-12 10:51:00+03	25600.00
35754A	2017-07-17 02:42:00+03	23200.00
357562	2017-07-15 16:33:00+03	52700.00
3575DE	2017-07-09 19:12:00+03	23200.00
357647	2017-08-07 14:02:00+03	35600.00
357706	2017-07-15 05:48:00+03	82600.00
357738	2017-08-07 02:24:00+03	52000.00
357770	2017-06-30 18:48:00+03	20600.00
357784	2017-07-28 18:46:00+03	24400.00
35779C	2017-07-31 22:58:00+03	19900.00
35779E	2017-07-09 04:41:00+03	42000.00
3577D2	2017-08-14 19:08:00+03	47400.00
3577DE	2017-08-06 05:44:00+03	25800.00
35786B	2017-06-25 15:38:00+03	83200.00
35792F	2017-08-12 11:28:00+03	39500.00
357938	2017-08-14 12:01:00+03	88900.00
357950	2017-08-06 15:28:00+03	11000.00
357975	2017-08-03 15:22:00+03	16400.00
357977	2017-07-07 13:31:00+03	43400.00
357981	2017-07-24 09:20:00+03	529200.00
357982	2017-08-04 17:18:00+03	51900.00
357A0D	2017-07-04 22:29:00+03	28000.00
357A27	2017-07-20 20:39:00+03	32200.00
357A2B	2017-07-10 19:53:00+03	55800.00
357A3A	2017-07-26 21:58:00+03	265600.00
357A6B	2017-08-10 06:47:00+03	44800.00
357A84	2017-07-12 23:03:00+03	100000.00
357A90	2017-07-26 00:50:00+03	29400.00
357A9B	2017-07-20 19:36:00+03	22000.00
357B85	2017-07-30 17:48:00+03	121400.00
357B8C	2017-07-06 05:36:00+03	134700.00
357BA1	2017-07-30 19:52:00+03	90800.00
357BDC	2017-08-13 17:49:00+03	19600.00
357BE8	2017-08-14 15:07:00+03	163400.00
357C3C	2017-08-09 03:18:00+03	43600.00
357C4D	2017-08-14 16:16:00+03	16400.00
357C7B	2017-07-09 15:53:00+03	90200.00
357CE7	2017-07-08 15:23:00+03	56600.00
357CFB	2017-07-22 21:40:00+03	133900.00
357D88	2017-08-10 07:39:00+03	56000.00
357DC0	2017-08-06 11:09:00+03	59300.00
357DC2	2017-07-22 01:57:00+03	18000.00
357DCA	2017-08-12 04:48:00+03	10600.00
357E24	2017-08-13 07:14:00+03	67200.00
357EA4	2017-08-07 18:45:00+03	21200.00
357ECE	2017-08-09 12:45:00+03	143400.00
357EE5	2017-08-14 06:53:00+03	67400.00
357EF1	2017-08-10 01:05:00+03	44000.00
357EFE	2017-07-18 07:12:00+03	80300.00
357F46	2017-08-09 05:05:00+03	87100.00
357F51	2017-08-06 01:53:00+03	59400.00
357F7B	2017-07-12 11:18:00+03	255000.00
357FCC	2017-07-23 10:05:00+03	70700.00
357FE9	2017-07-01 22:56:00+03	81700.00
357FF0	2017-07-03 22:09:00+03	59800.00
358037	2017-08-04 00:25:00+03	13400.00
358088	2017-08-02 13:40:00+03	37600.00
35808C	2017-07-31 13:18:00+03	56000.00
3580F7	2017-07-09 19:09:00+03	21600.00
358183	2017-07-25 10:38:00+03	46000.00
358203	2017-08-06 16:01:00+03	62600.00
35826E	2017-07-16 20:59:00+03	28000.00
358291	2017-07-23 16:53:00+03	102000.00
3582A1	2017-07-12 10:38:00+03	65900.00
3582C7	2017-08-14 10:04:00+03	284400.00
358310	2017-07-12 14:11:00+03	38400.00
35834E	2017-08-08 09:29:00+03	25000.00
35838E	2017-07-13 11:06:00+03	33800.00
3583C6	2017-07-12 04:03:00+03	56600.00
3583E7	2017-07-25 07:30:00+03	25900.00
3583F2	2017-07-11 12:28:00+03	48800.00
35842A	2017-08-07 06:06:00+03	57800.00
35843B	2017-07-06 05:01:00+03	25400.00
358473	2017-07-19 07:00:00+03	27400.00
3584C2	2017-07-27 16:07:00+03	47500.00
3584D8	2017-07-30 16:22:00+03	56000.00
3584EE	2017-08-14 05:05:00+03	49100.00
358502	2017-08-13 10:47:00+03	397100.00
3585CC	2017-07-21 02:59:00+03	101200.00
35866C	2017-08-15 08:24:00+03	123000.00
3586AD	2017-08-04 16:37:00+03	30000.00
3586E0	2017-07-29 16:10:00+03	12600.00
358754	2017-07-05 19:43:00+03	48700.00
3587CA	2017-07-10 03:54:00+03	13800.00
3587F1	2017-08-10 17:34:00+03	254900.00
3587FA	2017-07-20 12:15:00+03	53400.00
35890B	2017-08-06 00:45:00+03	311200.00
358916	2017-07-21 23:16:00+03	246000.00
35892E	2017-08-05 09:11:00+03	36900.00
35897E	2017-07-23 23:02:00+03	55500.00
358A29	2017-08-11 05:52:00+03	260900.00
358A78	2017-07-05 18:24:00+03	38800.00
358A7B	2017-07-29 13:12:00+03	119700.00
358AA1	2017-07-27 12:19:00+03	13400.00
358AB4	2017-07-21 11:09:00+03	41400.00
358AF8	2017-08-10 20:46:00+03	67700.00
358BE2	2017-08-01 01:26:00+03	46000.00
358C02	2017-07-28 16:36:00+03	55500.00
358C15	2017-08-10 13:53:00+03	62600.00
358C20	2017-08-10 18:06:00+03	269400.00
358C62	2017-07-01 11:21:00+03	62100.00
358C72	2017-07-13 08:01:00+03	65600.00
358CA0	2017-08-05 02:39:00+03	154800.00
358CAE	2017-08-08 07:08:00+03	12600.00
358CDF	2017-07-19 13:16:00+03	115100.00
358D3B	2017-08-08 05:17:00+03	47100.00
358D92	2017-07-25 19:31:00+03	73200.00
358D9D	2017-07-07 17:15:00+03	50600.00
358DA5	2017-08-12 15:32:00+03	179600.00
358DE8	2017-08-09 05:38:00+03	86600.00
358DF1	2017-07-09 03:05:00+03	55800.00
358E43	2017-08-08 05:49:00+03	92700.00
358E91	2017-08-04 00:41:00+03	22000.00
358EC6	2017-07-21 14:33:00+03	88000.00
358F09	2017-06-30 10:15:00+03	52700.00
358F63	2017-07-08 02:09:00+03	94000.00
35901B	2017-07-07 10:59:00+03	187600.00
359020	2017-08-13 01:16:00+03	23200.00
35904D	2017-07-30 19:49:00+03	266400.00
35906B	2017-07-23 21:31:00+03	105000.00
3590B8	2017-07-05 07:00:00+03	22000.00
3590C1	2017-08-06 23:02:00+03	36900.00
359147	2017-07-18 15:13:00+03	187600.00
359183	2017-07-12 05:33:00+03	68000.00
3591AA	2017-07-28 03:35:00+03	119800.00
3591B7	2017-07-18 00:27:00+03	65100.00
359225	2017-06-30 17:04:00+03	111600.00
359238	2017-07-18 19:26:00+03	144700.00
359273	2017-07-10 18:03:00+03	56600.00
35929E	2017-07-11 08:50:00+03	28000.00
359303	2017-08-12 05:21:00+03	140500.00
359318	2017-08-02 03:59:00+03	51300.00
359330	2017-08-12 14:33:00+03	29400.00
359340	2017-07-27 00:02:00+03	44600.00
359358	2017-06-26 16:07:00+03	15700.00
359374	2017-07-09 16:04:00+03	61400.00
3593A0	2017-07-05 08:28:00+03	78200.00
3593A2	2017-07-03 01:30:00+03	38500.00
3593D0	2017-07-05 06:05:00+03	23200.00
35940F	2017-06-26 15:15:00+03	55400.00
359432	2017-08-13 19:29:00+03	24400.00
35946F	2017-08-15 02:48:00+03	31300.00
359487	2017-07-02 06:50:00+03	29400.00
3594BF	2017-07-08 15:48:00+03	24000.00
3594CE	2017-07-30 07:32:00+03	54000.00
3594DF	2017-07-21 20:08:00+03	69400.00
3594F1	2017-08-10 01:07:00+03	55800.00
359535	2017-08-11 14:38:00+03	24600.00
35954B	2017-08-11 01:03:00+03	129200.00
359586	2017-07-09 23:23:00+03	32800.00
35958B	2017-07-10 03:40:00+03	211000.00
3595AE	2017-07-28 02:56:00+03	117600.00
3595D5	2017-07-07 20:55:00+03	73500.00
3595DE	2017-07-05 10:11:00+03	257600.00
359620	2017-07-23 06:13:00+03	8600.00
35964E	2017-08-01 14:28:00+03	46200.00
359696	2017-07-17 20:54:00+03	31200.00
35969C	2017-07-05 08:40:00+03	13400.00
3596BA	2017-08-13 09:04:00+03	79200.00
3596F3	2017-08-06 13:38:00+03	68200.00
35978E	2017-08-14 21:06:00+03	109600.00
3597C6	2017-07-01 11:18:00+03	75500.00
3597F5	2017-07-14 02:14:00+03	51900.00
359816	2017-07-07 11:25:00+03	36200.00
359860	2017-08-08 12:45:00+03	16400.00
359869	2017-07-24 02:35:00+03	119400.00
3598C7	2017-08-11 07:31:00+03	60400.00
35999E	2017-07-18 08:52:00+03	25600.00
3599AF	2017-07-08 21:43:00+03	32600.00
3599C5	2017-07-27 15:33:00+03	20400.00
359A13	2017-07-30 14:30:00+03	49100.00
359A58	2017-07-14 23:37:00+03	41200.00
359A59	2017-07-22 13:50:00+03	23600.00
359A79	2017-07-02 21:37:00+03	15400.00
359AA0	2017-07-21 18:31:00+03	43200.00
359AAB	2017-07-28 01:55:00+03	41600.00
359AC9	2017-07-14 15:28:00+03	23400.00
359B3E	2017-08-05 23:10:00+03	41600.00
359B68	2017-08-10 23:39:00+03	224000.00
359BA3	2017-08-14 06:21:00+03	13400.00
359BCD	2017-07-26 02:14:00+03	138200.00
359BEB	2017-07-14 10:54:00+03	83700.00
359D26	2017-06-30 13:12:00+03	56000.00
359D80	2017-08-02 05:26:00+03	57400.00
359DC2	2017-07-27 17:24:00+03	21400.00
359E57	2017-07-03 21:43:00+03	32800.00
359EF1	2017-07-19 00:04:00+03	75600.00
359F0E	2017-07-19 18:31:00+03	66600.00
359F16	2017-07-11 03:31:00+03	30800.00
359FCA	2017-07-03 20:46:00+03	110300.00
35A01A	2017-08-08 18:20:00+03	95700.00
35A034	2017-07-23 04:09:00+03	20200.00
35A051	2017-08-08 15:11:00+03	13600.00
35A0AE	2017-07-27 00:28:00+03	24400.00
35A0F6	2017-07-31 19:58:00+03	86400.00
35A186	2017-08-15 00:28:00+03	6000.00
35A1D6	2017-07-04 11:46:00+03	56000.00
35A1F3	2017-08-10 00:15:00+03	32400.00
35A22F	2017-08-12 12:55:00+03	95600.00
35A230	2017-07-17 14:54:00+03	174200.00
35A33D	2017-06-30 04:55:00+03	189200.00
35A35B	2017-07-04 22:35:00+03	117900.00
35A3A5	2017-08-04 07:11:00+03	53300.00
35A3A8	2017-07-25 03:22:00+03	29600.00
35A3D6	2017-07-25 05:07:00+03	157600.00
35A40A	2017-07-27 22:23:00+03	44700.00
35A40F	2017-08-13 17:38:00+03	6300.00
35A433	2017-07-01 07:46:00+03	27900.00
35A437	2017-08-02 16:08:00+03	114700.00
35A553	2017-08-12 09:31:00+03	248400.00
35A5F1	2017-07-20 03:04:00+03	94400.00
35A667	2017-07-30 13:41:00+03	14000.00
35A6F4	2017-07-31 04:32:00+03	86500.00
35A706	2017-08-03 14:03:00+03	99200.00
35A756	2017-07-10 13:16:00+03	114800.00
35A768	2017-07-15 06:24:00+03	65600.00
35A7D4	2017-08-14 08:03:00+03	46300.00
35A85D	2017-06-25 22:46:00+03	44800.00
35A861	2017-07-25 16:05:00+03	36900.00
35AA0B	2017-07-10 08:18:00+03	39200.00
35AA60	2017-07-02 16:07:00+03	17200.00
35AA66	2017-08-04 10:43:00+03	21200.00
35AC03	2017-07-06 01:01:00+03	33100.00
35AC31	2017-07-30 10:27:00+03	26000.00
35AC84	2017-07-08 11:03:00+03	143600.00
35AC9F	2017-07-26 06:55:00+03	130400.00
35AD29	2017-07-17 03:56:00+03	65500.00
35AD37	2017-07-13 22:11:00+03	65900.00
35AD3A	2017-08-15 09:35:00+03	36200.00
35AE5F	2017-07-08 11:05:00+03	27800.00
35AEA4	2017-08-13 18:46:00+03	53000.00
35AEDC	2017-07-31 03:17:00+03	122800.00
35AEE1	2017-07-11 11:24:00+03	56000.00
35AF4E	2017-07-23 05:13:00+03	6700.00
35AF68	2017-07-22 11:23:00+03	123000.00
35AF8C	2017-07-09 13:54:00+03	139700.00
35AFE6	2017-07-09 04:37:00+03	46400.00
35AFFB	2017-07-06 04:00:00+03	49100.00
35B00C	2017-07-09 18:19:00+03	14000.00
35B029	2017-07-07 08:41:00+03	72800.00
35B035	2017-07-26 12:41:00+03	92000.00
35B062	2017-08-08 01:07:00+03	46400.00
35B077	2017-07-21 10:17:00+03	54800.00
35B0DA	2017-07-12 06:57:00+03	23600.00
35B0ED	2017-07-18 15:46:00+03	7200.00
35B160	2017-06-28 01:50:00+03	93900.00
35B1A2	2017-07-05 18:01:00+03	57600.00
35B1AF	2017-08-03 19:28:00+03	32900.00
35B20D	2017-08-05 21:19:00+03	99800.00
35B236	2017-07-12 20:41:00+03	38400.00
35B252	2017-08-07 14:13:00+03	137600.00
35B273	2017-07-28 12:31:00+03	77700.00
35B28C	2017-08-14 00:46:00+03	104200.00
35B331	2017-08-10 05:20:00+03	87800.00
35B346	2017-08-14 05:38:00+03	48500.00
35B38A	2017-07-12 17:45:00+03	202300.00
35B3AC	2017-08-04 01:23:00+03	46400.00
35B3AD	2017-07-25 01:11:00+03	45200.00
35B3D2	2017-08-11 17:21:00+03	62000.00
35B3D9	2017-07-16 22:51:00+03	31400.00
35B3F2	2017-08-03 05:57:00+03	24800.00
35B406	2017-07-24 12:36:00+03	40600.00
35B4E2	2017-07-21 22:05:00+03	51000.00
35B582	2017-07-04 17:08:00+03	28800.00
35B58A	2017-07-06 04:09:00+03	112000.00
35B58C	2017-07-26 19:54:00+03	283100.00
35B5AF	2017-07-29 05:34:00+03	29600.00
35B5EE	2017-08-08 13:16:00+03	28000.00
35B5FA	2017-07-04 23:36:00+03	380800.00
35B634	2017-07-11 16:40:00+03	20400.00
35B683	2017-07-25 09:40:00+03	25800.00
35B686	2017-08-01 06:39:00+03	196000.00
35B6DE	2017-08-05 20:33:00+03	12600.00
35B72B	2017-07-11 05:13:00+03	7400.00
35B7AC	2017-07-10 20:52:00+03	6700.00
35B7D4	2017-07-05 08:29:00+03	58900.00
35B7EB	2017-08-09 17:57:00+03	27400.00
35B863	2017-07-05 22:14:00+03	31400.00
35B879	2017-08-11 12:45:00+03	65500.00
35B88F	2017-07-05 13:53:00+03	14000.00
35B89D	2017-08-06 05:11:00+03	27200.00
35B97C	2017-08-05 04:52:00+03	31400.00
35B993	2017-08-02 17:26:00+03	38500.00
35B999	2017-07-04 07:59:00+03	77800.00
35B9B8	2017-07-21 15:53:00+03	52900.00
35B9C5	2017-07-01 13:51:00+03	94000.00
35B9D7	2017-08-03 18:11:00+03	70800.00
35BA06	2017-08-13 23:22:00+03	130300.00
35BA1C	2017-07-27 13:14:00+03	56000.00
35BA4A	2017-07-23 01:04:00+03	185600.00
35BA55	2017-08-03 22:17:00+03	23200.00
35BA5A	2017-07-08 05:31:00+03	95200.00
35BA9A	2017-07-18 00:40:00+03	46300.00
35BB09	2017-08-04 07:28:00+03	53300.00
35BB1D	2017-06-29 01:54:00+03	64500.00
35BB87	2017-07-31 15:17:00+03	64300.00
35BBA6	2017-07-25 01:22:00+03	91700.00
35BBE6	2017-07-06 02:33:00+03	117600.00
35BC1C	2017-07-14 06:55:00+03	260300.00
35BC21	2017-07-17 13:36:00+03	24700.00
35BC52	2017-08-10 10:19:00+03	372500.00
35BC8A	2017-07-19 19:03:00+03	22000.00
35BCA9	2017-07-05 02:25:00+03	28000.00
35BD1A	2017-07-29 13:14:00+03	138600.00
35BD50	2017-08-08 00:25:00+03	43700.00
35BD6C	2017-08-11 23:38:00+03	46500.00
35BDDC	2017-08-01 10:46:00+03	66600.00
35BE1F	2017-07-24 20:30:00+03	170200.00
35BE6C	2017-07-26 01:33:00+03	170500.00
35BEA4	2017-07-16 14:21:00+03	62100.00
35BECF	2017-07-14 02:11:00+03	86400.00
35BEE8	2017-07-28 21:22:00+03	19800.00
35BEFE	2017-08-10 13:30:00+03	118200.00
35BF4C	2017-07-22 11:21:00+03	189800.00
35BF55	2017-08-03 23:59:00+03	6700.00
35BF75	2017-07-16 10:01:00+03	30100.00
35BFA3	2017-07-14 20:38:00+03	36400.00
35BFFB	2017-07-28 21:05:00+03	19800.00
35C05A	2017-08-09 08:30:00+03	68800.00
35C073	2017-08-10 07:07:00+03	53800.00
35C080	2017-07-06 06:32:00+03	12600.00
35C0E9	2017-08-02 23:58:00+03	62500.00
35C0F6	2017-07-02 11:13:00+03	72600.00
35C11F	2017-08-12 04:11:00+03	56000.00
35C148	2017-07-11 21:53:00+03	100000.00
35C154	2017-07-01 18:28:00+03	23400.00
35C164	2017-07-08 21:02:00+03	46000.00
35C17E	2017-07-30 14:03:00+03	30000.00
35C193	2017-07-17 15:36:00+03	64700.00
35C1DC	2017-07-25 15:00:00+03	44600.00
35C318	2017-07-13 23:24:00+03	63600.00
35C31E	2017-07-30 21:03:00+03	29600.00
35C3F7	2017-08-06 04:08:00+03	34200.00
35C4AA	2017-07-12 00:45:00+03	40000.00
35C4D3	2017-07-08 01:16:00+03	73600.00
35C52E	2017-08-15 08:32:00+03	56900.00
35C590	2017-08-14 13:17:00+03	40400.00
35C5D0	2017-06-27 12:37:00+03	16400.00
35C5D4	2017-07-31 03:00:00+03	101200.00
35C5D9	2017-07-21 12:51:00+03	66000.00
35C5EB	2017-07-26 01:37:00+03	190400.00
35C61C	2017-07-07 04:36:00+03	185300.00
35C665	2017-08-05 02:28:00+03	805800.00
35C66F	2017-07-27 20:08:00+03	14000.00
35C6D0	2017-07-24 09:08:00+03	6800.00
35C6E1	2017-06-28 19:25:00+03	56900.00
35C70A	2017-07-09 21:27:00+03	11600.00
35C792	2017-07-29 01:04:00+03	14400.00
35C7AC	2017-08-15 05:14:00+03	54500.00
35C7CC	2017-07-26 06:57:00+03	56000.00
35C90B	2017-08-07 07:55:00+03	26000.00
35C933	2017-08-04 11:30:00+03	88900.00
35C945	2017-07-14 02:44:00+03	56000.00
35C94C	2017-07-15 05:48:00+03	6000.00
35C951	2017-07-25 04:53:00+03	50400.00
35C9A5	2017-07-21 02:16:00+03	46300.00
35C9D3	2017-07-23 18:43:00+03	131600.00
35C9F6	2017-08-07 11:46:00+03	83000.00
35CA0E	2017-07-16 04:16:00+03	48800.00
35CA36	2017-08-08 22:58:00+03	60400.00
35CA4D	2017-08-02 16:59:00+03	55800.00
35CAA8	2017-07-28 03:45:00+03	23200.00
35CB48	2017-07-27 23:11:00+03	93900.00
35CBF7	2017-08-01 16:30:00+03	66600.00
35CC23	2017-07-16 08:18:00+03	6700.00
35CCF2	2017-07-29 09:00:00+03	136600.00
35CD64	2017-07-28 17:17:00+03	6200.00
35CD73	2017-08-15 14:03:00+03	63200.00
35CD9E	2017-07-11 19:47:00+03	79300.00
35CDDA	2017-08-13 03:48:00+03	42600.00
35CEB2	2017-08-05 01:48:00+03	57100.00
35CEC1	2017-08-03 04:07:00+03	46400.00
35CEC4	2017-08-01 20:20:00+03	149900.00
35CF05	2017-07-14 14:40:00+03	43600.00
35CF88	2017-08-10 06:31:00+03	29600.00
35CFA8	2017-08-05 05:33:00+03	539400.00
35CFDD	2017-07-15 00:26:00+03	47100.00
35D03F	2017-07-25 11:01:00+03	133700.00
35D05D	2017-07-10 13:35:00+03	13300.00
35D074	2017-07-10 01:25:00+03	59400.00
35D0C1	2017-08-07 15:35:00+03	39500.00
35D0D9	2017-07-17 17:39:00+03	60400.00
35D0E1	2017-08-04 05:15:00+03	56000.00
35D160	2017-07-15 14:06:00+03	24000.00
35D18D	2017-07-31 03:46:00+03	246000.00
35D1F0	2017-08-10 00:25:00+03	167400.00
35D21C	2017-06-29 02:21:00+03	44600.00
35D246	2017-08-15 13:59:00+03	80900.00
35D27A	2017-07-23 13:13:00+03	13600.00
35D27F	2017-08-10 12:41:00+03	141600.00
35D29D	2017-07-06 14:46:00+03	36200.00
35D2D3	2017-07-27 03:33:00+03	14000.00
35D309	2017-07-23 18:12:00+03	133200.00
35D30C	2017-07-05 14:36:00+03	58600.00
35D326	2017-07-30 03:53:00+03	50800.00
35D32F	2017-08-11 16:34:00+03	64700.00
35D363	2017-07-22 06:30:00+03	40800.00
35D3D0	2017-08-02 19:55:00+03	115200.00
35D3DC	2017-08-11 13:49:00+03	49800.00
35D455	2017-08-01 02:42:00+03	96200.00
35D530	2017-08-09 23:38:00+03	43000.00
35D5E6	2017-07-10 13:32:00+03	53500.00
35D5F5	2017-07-26 14:05:00+03	44600.00
35D5FD	2017-07-27 12:07:00+03	56600.00
35D604	2017-07-28 22:45:00+03	57100.00
35D670	2017-07-11 19:06:00+03	92900.00
35D69F	2017-07-19 18:30:00+03	60700.00
35D6E6	2017-07-17 10:08:00+03	26100.00
35D786	2017-07-21 02:03:00+03	123000.00
35D7F0	2017-07-14 19:01:00+03	198400.00
35D820	2017-07-09 19:26:00+03	54800.00
35D823	2017-07-13 10:55:00+03	68800.00
35D865	2017-07-21 10:52:00+03	79900.00
35D88C	2017-07-16 13:56:00+03	64000.00
35D8C6	2017-06-30 03:14:00+03	147700.00
35D8F1	2017-07-19 05:11:00+03	55800.00
35D8F5	2017-07-31 02:00:00+03	24600.00
35D915	2017-08-11 01:28:00+03	133100.00
35D93A	2017-08-05 03:34:00+03	179400.00
35DA4D	2017-07-07 04:03:00+03	55800.00
35DA82	2017-08-06 18:09:00+03	16400.00
35DACC	2017-08-10 00:18:00+03	302400.00
35DAE9	2017-07-19 04:37:00+03	24400.00
35DB34	2017-08-12 20:17:00+03	47000.00
35DB6A	2017-07-26 09:13:00+03	39800.00
35DC1B	2017-08-04 05:26:00+03	62600.00
35DC38	2017-07-05 10:47:00+03	199200.00
35DC75	2017-07-17 21:18:00+03	14800.00
35DC93	2017-07-28 13:01:00+03	26200.00
35DCAB	2017-07-26 11:48:00+03	46000.00
35DCEB	2017-08-06 00:39:00+03	123000.00
35DD75	2017-07-30 12:34:00+03	111900.00
35DDC0	2017-08-10 23:08:00+03	112000.00
35DDE4	2017-08-07 19:02:00+03	8000.00
35DDE8	2017-06-26 14:50:00+03	29400.00
35DDEF	2017-07-19 07:39:00+03	58400.00
35DE61	2017-08-04 15:46:00+03	249000.00
35DE9C	2017-07-08 15:27:00+03	10800.00
35DEF3	2017-07-17 01:54:00+03	41600.00
35DF09	2017-08-02 05:15:00+03	23200.00
35DFA3	2017-07-29 00:31:00+03	65400.00
35E03F	2017-07-23 15:37:00+03	111600.00
35E05A	2017-08-10 12:16:00+03	34100.00
35E05E	2017-07-15 10:25:00+03	28000.00
35E066	2017-08-10 19:08:00+03	75000.00
35E098	2017-07-06 06:06:00+03	172300.00
35E0B5	2017-08-07 22:11:00+03	27200.00
35E0EF	2017-07-28 12:57:00+03	39800.00
35E16F	2017-07-06 21:24:00+03	59200.00
35E198	2017-07-05 11:22:00+03	87400.00
35E23E	2017-06-28 04:59:00+03	132800.00
35E27B	2017-07-15 13:49:00+03	48800.00
35E27E	2017-07-22 04:56:00+03	31700.00
35E298	2017-07-12 14:03:00+03	71100.00
35E2BF	2017-07-18 01:30:00+03	95200.00
35E30B	2017-07-21 02:29:00+03	83200.00
35E329	2017-07-11 12:01:00+03	185300.00
35E390	2017-07-18 12:57:00+03	86800.00
35E3CE	2017-07-25 00:58:00+03	18300.00
35E3FD	2017-07-26 08:25:00+03	12600.00
35E408	2017-08-05 06:04:00+03	27200.00
35E42F	2017-08-10 05:10:00+03	139400.00
35E54A	2017-08-01 02:26:00+03	56000.00
35E550	2017-07-09 16:11:00+03	166100.00
35E565	2017-06-28 21:18:00+03	119800.00
35E568	2017-07-31 15:57:00+03	28800.00
35E59F	2017-06-30 02:44:00+03	64800.00
35E5E1	2017-07-20 09:36:00+03	24400.00
35E620	2017-08-10 10:48:00+03	107400.00
35E667	2017-07-23 13:13:00+03	56000.00
35E6CD	2017-07-22 00:53:00+03	87000.00
35E7A6	2017-08-08 22:45:00+03	38600.00
35E7D8	2017-07-18 01:36:00+03	66600.00
35E7E1	2017-07-08 08:16:00+03	52300.00
35E829	2017-08-09 09:33:00+03	60400.00
35E880	2017-07-09 00:06:00+03	23600.00
35E883	2017-08-08 21:35:00+03	12600.00
35E88E	2017-07-15 04:32:00+03	29500.00
35E89E	2017-06-27 16:16:00+03	192000.00
35E8A3	2017-08-09 01:05:00+03	22000.00
35E8BE	2017-07-30 18:41:00+03	21400.00
35E8E6	2017-08-12 20:42:00+03	105800.00
35E90D	2017-07-04 07:45:00+03	6000.00
35E95D	2017-07-03 22:43:00+03	139200.00
35E969	2017-08-01 07:48:00+03	46400.00
35E972	2017-06-29 12:15:00+03	20400.00
35E97A	2017-07-27 22:07:00+03	26800.00
35E980	2017-08-06 21:51:00+03	24400.00
35EA0D	2017-08-08 12:53:00+03	23200.00
35EA17	2017-07-26 02:53:00+03	254900.00
35EA61	2017-07-03 08:09:00+03	46000.00
35EA97	2017-08-05 19:55:00+03	28800.00
35EA98	2017-07-21 15:17:00+03	18800.00
35EB3B	2017-07-01 02:29:00+03	92100.00
35EB3D	2017-07-22 04:23:00+03	177600.00
35EB3E	2017-07-05 12:16:00+03	79400.00
35EB47	2017-07-09 01:03:00+03	100600.00
35EB69	2017-07-11 12:07:00+03	71600.00
35EBA3	2017-07-31 18:06:00+03	35300.00
35EBBB	2017-08-12 04:11:00+03	46400.00
35EBCA	2017-07-14 03:12:00+03	38400.00
35EBD1	2017-07-19 14:36:00+03	87000.00
35EBF2	2017-08-02 06:41:00+03	111600.00
35EC00	2017-07-04 14:04:00+03	80800.00
35EC48	2017-08-08 14:12:00+03	67000.00
35EC63	2017-08-09 09:10:00+03	15000.00
35ECA6	2017-08-14 22:58:00+03	36000.00
35ECFD	2017-06-30 12:03:00+03	11300.00
35EDE3	2017-07-21 08:54:00+03	40800.00
35EE8C	2017-07-20 17:18:00+03	53900.00
35EEAF	2017-08-07 16:14:00+03	56000.00
35EF3E	2017-07-17 07:10:00+03	53300.00
35EF42	2017-07-01 17:54:00+03	23600.00
35EF7D	2017-08-01 03:04:00+03	48500.00
35EF92	2017-07-24 01:30:00+03	47400.00
35EFDB	2017-07-13 03:56:00+03	68800.00
35EFF0	2017-07-18 10:58:00+03	23400.00
35EFF6	2017-07-27 08:08:00+03	125200.00
35F090	2017-07-28 11:21:00+03	64900.00
35F106	2017-07-16 03:44:00+03	56000.00
35F158	2017-08-09 14:18:00+03	75300.00
35F160	2017-07-14 12:12:00+03	47000.00
35F243	2017-07-04 15:48:00+03	90000.00
35F272	2017-07-27 05:05:00+03	86800.00
35F286	2017-08-07 07:34:00+03	187600.00
35F2F3	2017-08-11 06:50:00+03	258000.00
35F3B6	2017-07-09 12:56:00+03	13600.00
35F3EF	2017-07-05 09:33:00+03	200300.00
35F450	2017-07-08 23:27:00+03	76600.00
35F45B	2017-07-16 11:34:00+03	57600.00
35F462	2017-07-24 17:49:00+03	117200.00
35F476	2017-07-27 18:42:00+03	77000.00
35F4D8	2017-07-13 21:28:00+03	51900.00
35F4EB	2017-08-11 09:10:00+03	37000.00
35F501	2017-07-26 22:06:00+03	266400.00
35F518	2017-07-19 00:00:00+03	36800.00
35F550	2017-07-29 07:38:00+03	54500.00
35F557	2017-08-14 18:24:00+03	43200.00
35F5B8	2017-07-04 03:12:00+03	10800.00
35F5DE	2017-07-09 22:44:00+03	65500.00
35F5F1	2017-08-01 22:15:00+03	28000.00
35F616	2017-07-06 08:44:00+03	44500.00
35F64B	2017-08-08 07:37:00+03	47000.00
35F65E	2017-07-23 22:24:00+03	16800.00
35F6B8	2017-07-05 03:21:00+03	26000.00
35F6CF	2017-08-09 10:10:00+03	174900.00
35F7FE	2017-07-27 12:12:00+03	46400.00
35F837	2017-07-24 13:19:00+03	28700.00
35F85F	2017-07-06 17:19:00+03	37900.00
35F931	2017-07-23 23:54:00+03	38700.00
35F97A	2017-07-30 16:36:00+03	116900.00
35F9BB	2017-08-09 06:23:00+03	19600.00
35FA73	2017-07-16 09:21:00+03	68000.00
35FAF4	2017-07-02 11:00:00+03	52900.00
35FBAC	2017-07-23 22:04:00+03	121400.00
35FBAE	2017-08-14 18:20:00+03	46400.00
35FBB1	2017-08-05 12:19:00+03	26700.00
35FBBA	2017-08-02 21:03:00+03	258000.00
35FC4A	2017-07-26 06:53:00+03	110300.00
35FC61	2017-06-30 21:10:00+03	135200.00
35FD07	2017-08-04 10:57:00+03	103500.00
35FD0E	2017-07-26 19:16:00+03	7200.00
35FD19	2017-06-29 07:16:00+03	23200.00
35FD72	2017-07-30 09:23:00+03	27200.00
35FD83	2017-07-01 08:58:00+03	12400.00
35FDED	2017-07-28 02:41:00+03	369000.00
35FE45	2017-08-09 15:59:00+03	8200.00
35FE5B	2017-07-21 17:53:00+03	38600.00
35FE7B	2017-07-04 23:47:00+03	229900.00
35FEAC	2017-08-08 05:52:00+03	44800.00
35FECF	2017-08-06 12:38:00+03	43600.00
35FF04	2017-08-13 09:42:00+03	95200.00
35FF32	2017-08-14 16:41:00+03	38800.00
36009B	2017-08-12 12:34:00+03	78600.00
3600F7	2017-08-10 00:50:00+03	55800.00
360103	2017-07-17 00:36:00+03	8200.00
360139	2017-07-11 18:53:00+03	25100.00
36016F	2017-08-11 18:23:00+03	14000.00
360178	2017-07-04 10:57:00+03	89700.00
360250	2017-07-26 12:09:00+03	20200.00
36025D	2017-07-27 17:28:00+03	25600.00
360289	2017-08-13 06:22:00+03	50300.00
3602E0	2017-07-05 18:03:00+03	40800.00
3603BA	2017-07-10 23:26:00+03	29600.00
3603F2	2017-08-01 14:55:00+03	269600.00
36047D	2017-07-21 12:00:00+03	45800.00
360536	2017-08-01 09:29:00+03	258400.00
3605EA	2017-07-27 05:48:00+03	40000.00
3605FC	2017-08-01 20:19:00+03	146000.00
360601	2017-07-13 06:37:00+03	98400.00
360675	2017-08-03 22:42:00+03	51900.00
360689	2017-08-04 03:53:00+03	36200.00
3606EE	2017-07-07 15:54:00+03	139400.00
360730	2017-07-12 10:39:00+03	55800.00
36073B	2017-07-24 01:59:00+03	89600.00
360844	2017-08-08 23:10:00+03	259500.00
360878	2017-07-13 23:14:00+03	30200.00
360896	2017-07-23 21:59:00+03	61500.00
3608E4	2017-07-30 02:53:00+03	257600.00
3608EA	2017-08-09 22:30:00+03	46400.00
360925	2017-07-17 15:36:00+03	124200.00
360951	2017-08-09 12:21:00+03	13700.00
36096C	2017-08-04 03:20:00+03	17000.00
3609AC	2017-07-12 03:24:00+03	45000.00
360A74	2017-07-14 00:45:00+03	33100.00
360A91	2017-06-24 09:49:00+03	50400.00
360AD4	2017-07-08 05:15:00+03	85600.00
360AE8	2017-08-03 08:28:00+03	52400.00
360B8E	2017-08-01 01:21:00+03	148200.00
360B9B	2017-08-03 23:19:00+03	46300.00
360BEF	2017-08-02 20:41:00+03	49600.00
360C06	2017-07-02 05:13:00+03	46400.00
360C5A	2017-06-29 22:33:00+03	28000.00
360C6F	2017-07-27 23:07:00+03	36400.00
360CE0	2017-07-16 02:04:00+03	85000.00
360CF4	2017-07-07 14:52:00+03	26400.00
360D6F	2017-07-05 18:30:00+03	88600.00
360E2E	2017-07-22 21:29:00+03	6800.00
360EC6	2017-08-10 14:10:00+03	42800.00
360F49	2017-07-14 20:47:00+03	80700.00
360F4F	2017-08-03 01:47:00+03	43600.00
360FE4	2017-08-05 15:43:00+03	24600.00
361074	2017-07-12 04:26:00+03	12600.00
36108F	2017-08-07 08:27:00+03	39300.00
3610C9	2017-08-05 05:43:00+03	248300.00
3610D8	2017-07-17 00:44:00+03	36900.00
361101	2017-08-10 04:03:00+03	62600.00
36115F	2017-07-25 16:58:00+03	37400.00
361170	2017-08-08 21:49:00+03	25200.00
361173	2017-08-04 15:39:00+03	58200.00
3611DE	2017-08-11 05:12:00+03	52300.00
36129A	2017-07-04 03:37:00+03	21400.00
36133B	2017-07-02 12:45:00+03	105000.00
361356	2017-07-17 13:57:00+03	112600.00
361365	2017-07-21 12:21:00+03	56000.00
36137E	2017-08-12 21:20:00+03	35800.00
3613E8	2017-06-30 19:20:00+03	92400.00
361450	2017-07-03 21:11:00+03	97600.00
361461	2017-08-10 21:58:00+03	75600.00
36146D	2017-07-17 11:26:00+03	139400.00
36147B	2017-08-03 14:50:00+03	266400.00
361491	2017-08-11 11:43:00+03	420600.00
3614C4	2017-08-04 20:52:00+03	47000.00
3614E4	2017-07-26 14:42:00+03	30200.00
3614EA	2017-07-24 03:33:00+03	32800.00
361509	2017-07-16 07:32:00+03	112000.00
361517	2017-07-01 02:57:00+03	53500.00
361563	2017-07-25 02:34:00+03	57400.00
36157B	2017-08-15 13:41:00+03	38800.00
361598	2017-07-09 22:55:00+03	135600.00
3615BB	2017-08-13 20:44:00+03	81500.00
3615CB	2017-07-22 12:06:00+03	11000.00
3615CD	2017-07-05 00:04:00+03	311200.00
3615F1	2017-07-10 16:59:00+03	147800.00
36163C	2017-07-02 18:35:00+03	38400.00
36165E	2017-07-17 22:36:00+03	58000.00
361708	2017-07-07 08:52:00+03	40400.00
3617CA	2017-08-05 01:56:00+03	54100.00
36180A	2017-08-13 16:54:00+03	31600.00
361845	2017-07-12 23:25:00+03	9200.00
361890	2017-07-28 11:58:00+03	59800.00
36189A	2017-07-08 12:00:00+03	97100.00
3618B4	2017-08-07 07:26:00+03	135400.00
361905	2017-06-30 16:38:00+03	39200.00
36192E	2017-07-16 16:03:00+03	66800.00
361934	2017-07-23 07:20:00+03	91100.00
3619D5	2017-07-11 20:56:00+03	65500.00
3619F4	2017-08-02 06:28:00+03	110700.00
361A10	2017-08-03 04:35:00+03	16400.00
361A39	2017-07-10 11:46:00+03	122000.00
361ADC	2017-07-18 08:47:00+03	43500.00
361AF6	2017-08-15 11:28:00+03	23600.00
361BA5	2017-08-11 02:48:00+03	40600.00
361C04	2017-07-22 22:20:00+03	18600.00
361C0E	2017-07-11 22:14:00+03	80400.00
361C96	2017-07-25 11:05:00+03	37600.00
361D0F	2017-07-20 20:23:00+03	26000.00
361D2D	2017-08-08 02:05:00+03	59600.00
361D3B	2017-07-22 02:55:00+03	28000.00
361DA8	2017-08-10 19:26:00+03	75300.00
361E5C	2017-08-12 00:06:00+03	43200.00
361E89	2017-08-15 08:35:00+03	50800.00
361EA2	2017-07-06 05:48:00+03	112600.00
361F1E	2017-08-14 16:03:00+03	18600.00
361F6F	2017-07-24 20:59:00+03	44000.00
361F91	2017-07-11 23:55:00+03	28700.00
361FBF	2017-07-03 02:24:00+03	147200.00
361FC3	2017-08-01 13:59:00+03	57500.00
362009	2017-08-09 15:42:00+03	69600.00
36202E	2017-07-08 08:08:00+03	67600.00
36203A	2017-07-28 08:15:00+03	102400.00
36203E	2017-07-11 03:15:00+03	59800.00
362067	2017-07-06 06:08:00+03	15000.00
36209D	2017-07-10 14:30:00+03	51800.00
3620DE	2017-06-26 02:12:00+03	143100.00
36215B	2017-07-22 09:22:00+03	26000.00
36217F	2017-07-31 11:50:00+03	74800.00
3621D1	2017-07-28 14:15:00+03	117200.00
3621EA	2017-07-27 05:40:00+03	69900.00
36222A	2017-08-08 19:01:00+03	60000.00
362289	2017-08-09 01:14:00+03	23200.00
3622D7	2017-07-05 06:32:00+03	111600.00
3622EC	2017-08-10 05:48:00+03	42800.00
3623AC	2017-07-06 05:35:00+03	71600.00
3623FE	2017-07-08 07:25:00+03	18800.00
362418	2017-08-14 15:22:00+03	46400.00
36242D	2017-07-03 12:48:00+03	25600.00
36242F	2017-07-28 10:21:00+03	19600.00
362453	2017-08-01 11:51:00+03	56000.00
362472	2017-08-07 19:30:00+03	41600.00
362484	2017-07-03 05:34:00+03	66600.00
3624CE	2017-08-02 20:14:00+03	375200.00
362506	2017-07-29 12:21:00+03	27200.00
36250C	2017-06-30 04:41:00+03	13200.00
362512	2017-08-12 17:52:00+03	149300.00
362550	2017-07-17 07:30:00+03	56000.00
362553	2017-08-03 07:04:00+03	47000.00
36258F	2017-07-05 08:52:00+03	54300.00
3625AE	2017-08-09 16:21:00+03	20200.00
362604	2017-08-07 09:11:00+03	54400.00
362613	2017-08-08 10:01:00+03	26200.00
36261F	2017-07-31 10:59:00+03	20200.00
36266C	2017-08-09 23:31:00+03	66000.00
362674	2017-08-12 07:57:00+03	105800.00
362678	2017-08-05 08:06:00+03	410200.00
362688	2017-08-02 17:05:00+03	55800.00
362693	2017-07-18 02:16:00+03	23200.00
362706	2017-07-16 12:52:00+03	108900.00
362748	2017-07-06 00:28:00+03	84100.00
362778	2017-08-09 05:37:00+03	58600.00
3627A6	2017-08-14 04:33:00+03	113800.00
3627F1	2017-08-06 08:30:00+03	37700.00
362808	2017-08-09 20:50:00+03	73300.00
362827	2017-07-04 15:43:00+03	189400.00
362866	2017-07-25 07:21:00+03	28000.00
36288D	2017-07-26 22:17:00+03	32900.00
36299E	2017-07-17 05:12:00+03	11000.00
3629A1	2017-07-24 08:46:00+03	6000.00
3629AE	2017-07-20 15:24:00+03	38700.00
3629D0	2017-07-10 14:28:00+03	17800.00
3629DA	2017-08-13 02:44:00+03	66600.00
3629ED	2017-08-12 02:49:00+03	90400.00
362A38	2017-07-12 19:38:00+03	6600.00
362A4B	2017-07-07 03:10:00+03	56000.00
362A63	2017-07-06 11:20:00+03	14400.00
362A84	2017-08-04 10:08:00+03	133100.00
362A9C	2017-07-05 05:45:00+03	71100.00
362A9D	2017-08-09 11:12:00+03	103900.00
362ADE	2017-07-19 15:01:00+03	75100.00
362AEB	2017-08-11 22:37:00+03	45500.00
362B59	2017-07-08 08:53:00+03	49400.00
362BA9	2017-08-04 06:32:00+03	64700.00
362BAB	2017-07-16 00:46:00+03	123000.00
362BEB	2017-07-04 02:38:00+03	30200.00
362BF2	2017-07-09 01:34:00+03	64500.00
362C14	2017-07-10 17:49:00+03	136800.00
362C2B	2017-08-15 07:12:00+03	66600.00
362C4B	2017-07-09 04:50:00+03	73300.00
362C5A	2017-08-15 17:10:00+03	46000.00
362C62	2017-07-09 08:21:00+03	75300.00
362C67	2017-08-03 23:14:00+03	84000.00
362CA9	2017-07-23 13:13:00+03	133200.00
362CF1	2017-08-06 07:23:00+03	64600.00
362D5F	2017-07-05 17:09:00+03	29400.00
362D6D	2017-07-30 09:09:00+03	133200.00
362D81	2017-08-04 23:17:00+03	136200.00
362D8E	2017-08-11 20:17:00+03	153300.00
362EB2	2017-08-14 01:53:00+03	49700.00
362EE5	2017-08-04 01:55:00+03	12600.00
362F67	2017-08-01 20:07:00+03	63200.00
362F9C	2017-07-28 01:08:00+03	11600.00
362FBB	2017-07-30 15:56:00+03	6000.00
362FFD	2017-07-24 22:53:00+03	93000.00
363010	2017-07-09 08:02:00+03	79600.00
3630F2	2017-07-11 08:36:00+03	136800.00
3630F7	2017-07-19 01:45:00+03	113200.00
36312A	2017-08-09 23:34:00+03	46400.00
3631BD	2017-07-28 05:59:00+03	179400.00
363233	2017-08-01 08:19:00+03	173900.00
363246	2017-07-04 23:48:00+03	167400.00
36324A	2017-07-29 00:23:00+03	14400.00
363252	2017-08-07 06:29:00+03	132800.00
36329B	2017-08-10 15:21:00+03	77600.00
3632FC	2017-08-14 10:09:00+03	50100.00
363353	2017-07-06 09:49:00+03	11600.00
3633F9	2017-08-08 22:36:00+03	30800.00
363442	2017-07-16 21:47:00+03	254600.00
3634B0	2017-07-28 14:21:00+03	21200.00
363507	2017-07-05 03:06:00+03	12400.00
363555	2017-07-14 15:22:00+03	66600.00
363574	2017-07-04 18:16:00+03	6700.00
3635D8	2017-07-31 13:49:00+03	277800.00
3635DB	2017-07-10 01:27:00+03	14800.00
3635EF	2017-08-13 01:18:00+03	33500.00
363614	2017-08-12 03:36:00+03	50600.00
36364A	2017-07-02 11:43:00+03	28000.00
36368C	2017-07-28 11:42:00+03	81900.00
3636C1	2017-08-01 08:39:00+03	164400.00
3636C5	2017-07-16 19:48:00+03	135400.00
3636D5	2017-07-27 01:24:00+03	36600.00
363798	2017-07-23 23:40:00+03	20100.00
3637B3	2017-07-01 15:09:00+03	68400.00
3637BF	2017-07-10 21:46:00+03	59800.00
363818	2017-07-13 04:31:00+03	16800.00
363882	2017-07-27 08:30:00+03	46400.00
363899	2017-08-09 17:05:00+03	40800.00
3638B1	2017-07-05 09:16:00+03	48800.00
3638D5	2017-08-11 17:57:00+03	212200.00
3639CA	2017-07-14 07:25:00+03	29600.00
3639FE	2017-07-13 06:07:00+03	23200.00
363A10	2017-07-31 04:03:00+03	22000.00
363A24	2017-07-18 07:08:00+03	99200.00
363A3D	2017-08-12 03:36:00+03	17300.00
363AC3	2017-07-18 04:53:00+03	95200.00
363AF2	2017-07-05 07:10:00+03	20500.00
363AFE	2017-08-15 13:54:00+03	7200.00
363B66	2017-08-05 03:03:00+03	46400.00
363BD3	2017-07-20 06:54:00+03	27800.00
363BFC	2017-07-05 09:56:00+03	99700.00
363C00	2017-08-10 15:01:00+03	148200.00
363C24	2017-07-14 04:57:00+03	120900.00
363C5C	2017-07-21 02:44:00+03	95600.00
363D41	2017-08-07 14:27:00+03	65600.00
363D89	2017-08-04 03:05:00+03	42800.00
363DC5	2017-08-06 01:43:00+03	87900.00
363DF0	2017-08-14 23:06:00+03	26800.00
363E34	2017-07-18 14:37:00+03	23600.00
363E43	2017-08-11 08:16:00+03	34800.00
363E69	2017-08-12 20:07:00+03	28800.00
363E6A	2017-07-19 07:20:00+03	129700.00
363E7C	2017-07-13 14:10:00+03	20400.00
363EB2	2017-08-09 14:54:00+03	39400.00
363EC6	2017-08-06 13:53:00+03	27200.00
363EEA	2017-07-23 16:41:00+03	31600.00
363F71	2017-08-05 18:46:00+03	185800.00
363F84	2017-06-30 07:34:00+03	73100.00
363FE7	2017-07-19 04:32:00+03	46400.00
363FEA	2017-07-22 08:39:00+03	369000.00
363FF0	2017-08-07 15:50:00+03	67600.00
364044	2017-07-07 19:40:00+03	16400.00
36405F	2017-08-03 07:42:00+03	130400.00
36409F	2017-07-29 02:49:00+03	61800.00
364174	2017-07-21 23:55:00+03	29400.00
3641D0	2017-07-08 05:18:00+03	104600.00
36426B	2017-07-11 07:39:00+03	409700.00
3642FC	2017-06-28 20:55:00+03	21200.00
36430F	2017-07-03 21:19:00+03	65500.00
364334	2017-08-09 04:14:00+03	12400.00
364447	2017-07-13 20:37:00+03	69800.00
364456	2017-08-12 01:11:00+03	99000.00
364461	2017-07-04 11:32:00+03	23400.00
364469	2017-08-03 02:10:00+03	24400.00
3644EE	2017-07-06 07:17:00+03	66000.00
364520	2017-08-06 20:27:00+03	100600.00
364522	2017-08-11 11:27:00+03	31800.00
36453F	2017-07-21 22:46:00+03	55800.00
364580	2017-07-26 00:39:00+03	37900.00
3645E7	2017-07-25 16:28:00+03	26000.00
36460A	2017-07-28 12:25:00+03	55600.00
36469B	2017-07-12 21:57:00+03	24600.00
3646DF	2017-07-31 07:29:00+03	62600.00
3646F9	2017-08-01 11:43:00+03	159800.00
364756	2017-08-11 03:32:00+03	40000.00
3647B4	2017-07-19 07:20:00+03	26000.00
3647BD	2017-07-06 22:54:00+03	230500.00
3647FA	2017-07-11 20:02:00+03	56900.00
364830	2017-07-28 12:48:00+03	48400.00
364890	2017-07-10 18:05:00+03	23200.00
3648AC	2017-08-10 21:48:00+03	135200.00
3648B6	2017-07-08 09:39:00+03	35800.00
3648BD	2017-07-25 02:39:00+03	50100.00
3648C8	2017-07-14 20:56:00+03	24800.00
3648F7	2017-08-15 06:56:00+03	166100.00
364965	2017-07-23 17:04:00+03	36800.00
3649AF	2017-07-07 08:16:00+03	27300.00
3649B0	2017-08-13 21:48:00+03	156300.00
3649C5	2017-07-10 16:42:00+03	291000.00
3649DE	2017-07-18 08:32:00+03	92800.00
3649FF	2017-07-25 01:53:00+03	112000.00
364A2A	2017-08-11 06:28:00+03	93900.00
364AB9	2017-07-09 12:39:00+03	198400.00
364AEE	2017-07-29 20:50:00+03	37200.00
364AEF	2017-08-06 00:10:00+03	136200.00
364B03	2017-07-25 18:20:00+03	67700.00
364B7B	2017-07-29 15:34:00+03	134400.00
364B94	2017-06-30 22:48:00+03	273400.00
364C1C	2017-08-15 07:41:00+03	38800.00
364C44	2017-08-02 01:17:00+03	34000.00
364C9F	2017-07-31 05:14:00+03	102100.00
364D03	2017-07-16 04:34:00+03	19000.00
364D2A	2017-07-10 04:31:00+03	28600.00
364E12	2017-07-27 23:20:00+03	114700.00
364E4E	2017-08-08 03:50:00+03	38800.00
364E5C	2017-07-11 02:23:00+03	86600.00
364E63	2017-07-08 16:11:00+03	57400.00
364EE5	2017-08-01 20:03:00+03	85000.00
364F39	2017-07-03 12:03:00+03	28700.00
364F91	2017-08-15 11:36:00+03	74200.00
364FA8	2017-07-06 11:40:00+03	20600.00
364FAB	2017-07-13 18:45:00+03	12600.00
364FAC	2017-07-01 12:58:00+03	101200.00
364FF8	2017-07-13 14:16:00+03	48800.00
365004	2017-07-11 23:49:00+03	42000.00
36506C	2017-07-16 11:04:00+03	64400.00
365077	2017-08-01 13:55:00+03	38600.00
3650AF	2017-07-05 20:56:00+03	17200.00
36516E	2017-07-30 02:33:00+03	40800.00
3651A7	2017-07-25 21:55:00+03	54800.00
3651C9	2017-07-11 17:53:00+03	6600.00
3651EF	2017-07-02 16:14:00+03	666000.00
36526D	2017-07-01 17:11:00+03	26200.00
36537D	2017-07-13 08:59:00+03	81700.00
3653C6	2017-07-31 23:56:00+03	75300.00
36542E	2017-07-17 19:17:00+03	57800.00
36544F	2017-08-12 12:58:00+03	16400.00
365494	2017-07-01 05:24:00+03	261500.00
3654AB	2017-08-10 08:52:00+03	86400.00
3654DA	2017-08-13 05:06:00+03	76200.00
365590	2017-07-13 16:53:00+03	64700.00
3655C1	2017-08-13 01:19:00+03	219400.00
3655EB	2017-07-25 21:26:00+03	61800.00
365612	2017-06-30 15:51:00+03	147600.00
36562A	2017-07-08 00:25:00+03	75600.00
36565C	2017-07-20 17:28:00+03	381800.00
365691	2017-08-09 14:17:00+03	64600.00
36569F	2017-07-03 23:57:00+03	44700.00
3656C3	2017-08-12 11:42:00+03	133200.00
365700	2017-08-11 12:13:00+03	82600.00
36572A	2017-08-03 05:13:00+03	22000.00
36576E	2017-07-03 22:19:00+03	24600.00
365791	2017-08-07 09:50:00+03	23600.00
3657A9	2017-08-13 20:28:00+03	46700.00
3658B8	2017-08-08 00:13:00+03	46400.00
3658C7	2017-07-29 09:24:00+03	141600.00
365919	2017-08-15 06:00:00+03	182000.00
365947	2017-07-24 08:30:00+03	25600.00
365981	2017-07-04 01:22:00+03	34000.00
365A80	2017-07-04 21:05:00+03	88900.00
365A84	2017-07-07 15:21:00+03	14000.00
365AF9	2017-08-14 07:20:00+03	115400.00
365B2A	2017-07-16 04:48:00+03	75800.00
365BC0	2017-07-22 14:51:00+03	22200.00
365C4C	2017-07-20 04:26:00+03	79600.00
365C85	2017-08-13 15:32:00+03	7200.00
365C86	2017-06-28 22:30:00+03	54500.00
365CA8	2017-08-11 02:22:00+03	167700.00
365CC9	2017-08-03 00:49:00+03	58400.00
365CF0	2017-07-17 22:28:00+03	60400.00
365CF6	2017-07-16 23:37:00+03	61800.00
365D52	2017-07-03 07:30:00+03	26700.00
365D85	2017-07-01 07:48:00+03	56600.00
365D8C	2017-08-14 17:20:00+03	37800.00
365DD6	2017-07-25 10:32:00+03	20800.00
365DED	2017-07-16 02:55:00+03	27800.00
365E08	2017-07-30 21:04:00+03	41400.00
365E38	2017-07-23 20:03:00+03	52800.00
365ED9	2017-08-14 17:07:00+03	46800.00
365F00	2017-07-22 15:19:00+03	138600.00
365F50	2017-08-05 22:56:00+03	31400.00
365F54	2017-08-10 16:18:00+03	135400.00
365F9B	2017-07-27 22:20:00+03	32700.00
365F9F	2017-08-07 06:21:00+03	134700.00
365FB9	2017-07-21 12:00:00+03	23600.00
365FC7	2017-07-23 09:13:00+03	167400.00
365FD1	2017-07-19 05:00:00+03	24300.00
366047	2017-08-04 14:22:00+03	28000.00
36606F	2017-08-02 18:45:00+03	93700.00
3660D5	2017-07-30 18:45:00+03	58600.00
3660DB	2017-08-02 11:57:00+03	94200.00
36614C	2017-08-15 05:19:00+03	30200.00
366150	2017-07-12 05:01:00+03	89600.00
366159	2017-07-17 18:23:00+03	74000.00
366176	2017-08-06 03:33:00+03	32800.00
366185	2017-07-25 20:27:00+03	20200.00
3661A6	2017-07-30 01:35:00+03	96400.00
3661F4	2017-07-17 23:24:00+03	61500.00
366246	2017-07-25 10:58:00+03	254900.00
366266	2017-07-10 00:41:00+03	47000.00
366268	2017-08-11 12:00:00+03	16400.00
366301	2017-07-11 16:34:00+03	46400.00
36631B	2017-08-15 02:08:00+03	270800.00
366324	2017-07-21 12:27:00+03	496600.00
366332	2017-08-08 12:45:00+03	240600.00
36633C	2017-06-27 23:58:00+03	30800.00
3663B0	2017-08-07 01:20:00+03	126400.00
3663EC	2017-08-13 15:08:00+03	32800.00
366409	2017-07-23 16:59:00+03	36200.00
36642C	2017-07-10 10:48:00+03	81700.00
366466	2017-07-14 12:46:00+03	19600.00
3664A5	2017-08-14 11:35:00+03	6000.00
3664EF	2017-07-31 04:55:00+03	46900.00
366523	2017-08-15 05:07:00+03	36700.00
36666B	2017-08-08 00:10:00+03	22800.00
366681	2017-07-21 13:07:00+03	28800.00
366696	2017-08-09 18:37:00+03	199700.00
3666B4	2017-07-29 13:47:00+03	29600.00
3666BF	2017-07-06 05:39:00+03	73400.00
3666F4	2017-07-08 18:32:00+03	31400.00
36674E	2017-08-13 19:19:00+03	27800.00
366775	2017-08-11 02:37:00+03	92000.00
366787	2017-08-05 01:37:00+03	31100.00
3667B9	2017-07-28 16:43:00+03	40400.00
3667CF	2017-08-08 19:02:00+03	149300.00
3667DC	2017-08-10 17:49:00+03	61800.00
366808	2017-07-16 19:32:00+03	12000.00
36681B	2017-07-11 08:38:00+03	43200.00
36681F	2017-07-20 10:54:00+03	139400.00
366863	2017-08-13 13:29:00+03	296400.00
36687B	2017-08-08 15:27:00+03	90000.00
3668C4	2017-08-09 00:29:00+03	18400.00
36692F	2017-08-10 09:50:00+03	113300.00
366947	2017-07-31 01:32:00+03	192700.00
36694A	2017-07-07 05:02:00+03	28800.00
36694F	2017-06-27 08:17:00+03	55000.00
36695F	2017-07-14 16:57:00+03	131600.00
3669A3	2017-07-10 05:32:00+03	167400.00
3669EE	2017-08-06 10:07:00+03	13600.00
3669F4	2017-07-31 20:13:00+03	88900.00
366A5B	2017-07-23 18:21:00+03	299200.00
366B11	2017-08-12 16:19:00+03	166900.00
366C3B	2017-07-08 09:35:00+03	14400.00
366C4B	2017-07-28 22:58:00+03	134700.00
366C50	2017-08-01 15:48:00+03	96200.00
366C60	2017-08-11 10:02:00+03	83000.00
366D4B	2017-08-14 17:42:00+03	23200.00
366D68	2017-08-02 19:12:00+03	50600.00
366D69	2017-07-31 00:03:00+03	20800.00
366D85	2017-08-12 10:03:00+03	29800.00
366D89	2017-07-24 21:55:00+03	31400.00
366DFA	2017-07-05 13:54:00+03	15000.00
366E18	2017-08-06 10:46:00+03	21800.00
366E43	2017-07-04 21:33:00+03	63500.00
366EAD	2017-07-29 01:07:00+03	70200.00
366EE2	2017-07-27 22:26:00+03	46000.00
366F02	2017-08-01 00:07:00+03	68800.00
366F56	2017-07-22 09:50:00+03	46300.00
366FAD	2017-07-24 14:17:00+03	6000.00
366FD7	2017-07-02 23:02:00+03	6700.00
36701A	2017-08-15 13:49:00+03	99200.00
367055	2017-08-05 00:54:00+03	22000.00
3670F8	2017-08-03 16:31:00+03	6800.00
367155	2017-07-01 16:51:00+03	42800.00
3671F7	2017-07-15 21:05:00+03	69500.00
36729F	2017-08-06 10:08:00+03	28800.00
3672A8	2017-07-15 01:05:00+03	147700.00
367385	2017-07-09 10:17:00+03	156100.00
3673E0	2017-07-30 21:47:00+03	52000.00
36740E	2017-07-07 09:50:00+03	57600.00
367464	2017-08-13 20:11:00+03	29000.00
36748E	2017-08-07 07:26:00+03	57800.00
367492	2017-08-10 18:22:00+03	46400.00
3674BA	2017-07-14 02:06:00+03	25800.00
3674C3	2017-08-09 04:38:00+03	37900.00
3674E1	2017-06-29 02:49:00+03	69600.00
367508	2017-07-24 09:55:00+03	32800.00
367553	2017-07-25 02:05:00+03	92400.00
367569	2017-07-13 02:16:00+03	116900.00
367590	2017-07-16 12:58:00+03	58600.00
3675A2	2017-08-07 18:24:00+03	198400.00
3675C6	2017-08-15 00:38:00+03	34000.00
3675D5	2017-07-08 12:27:00+03	26800.00
3675DC	2017-07-04 10:17:00+03	20900.00
3675E1	2017-07-02 06:37:00+03	39300.00
367631	2017-07-23 12:11:00+03	12600.00
36764C	2017-08-08 09:10:00+03	11800.00
367674	2017-07-27 16:14:00+03	56000.00
36769B	2017-08-06 15:48:00+03	38400.00
36772A	2017-07-23 01:31:00+03	66600.00
367767	2017-07-23 19:18:00+03	73500.00
367780	2017-07-14 07:08:00+03	42700.00
36779D	2017-07-11 04:28:00+03	100700.00
3677ED	2017-07-31 12:26:00+03	89600.00
36781B	2017-07-08 08:28:00+03	98400.00
367826	2017-08-06 23:52:00+03	46400.00
36787D	2017-07-12 19:52:00+03	84300.00
3679C3	2017-08-13 19:11:00+03	63400.00
367A4B	2017-07-09 10:44:00+03	27200.00
367A50	2017-08-04 20:28:00+03	189200.00
367AF7	2017-08-11 05:38:00+03	40800.00
367B06	2017-07-02 23:00:00+03	37200.00
367B7B	2017-07-13 17:42:00+03	27200.00
367BA0	2017-07-25 05:11:00+03	29400.00
367BF9	2017-07-29 19:15:00+03	28000.00
367C34	2017-07-29 01:57:00+03	18000.00
367C61	2017-07-02 00:43:00+03	69800.00
367D0D	2017-07-19 07:19:00+03	53700.00
367D20	2017-08-02 04:19:00+03	105100.00
367D8B	2017-07-24 05:29:00+03	24800.00
367D99	2017-07-09 08:58:00+03	35600.00
367DB5	2017-07-16 04:06:00+03	49500.00
367DED	2017-08-03 00:22:00+03	61800.00
367ED8	2017-07-16 06:19:00+03	21400.00
367F18	2017-08-10 00:05:00+03	7400.00
367F25	2017-07-25 11:32:00+03	9200.00
367F46	2017-07-02 09:20:00+03	211100.00
367F6E	2017-08-03 18:14:00+03	106400.00
367F84	2017-08-15 14:12:00+03	43400.00
367FBD	2017-06-30 16:34:00+03	116000.00
367FDF	2017-07-26 08:45:00+03	77600.00
367FE8	2017-07-08 00:52:00+03	53100.00
36801C	2017-08-13 04:09:00+03	130400.00
368080	2017-08-01 04:05:00+03	51600.00
3680AF	2017-07-31 09:09:00+03	246000.00
3680B1	2017-07-31 22:48:00+03	313800.00
3680C1	2017-07-11 02:27:00+03	99300.00
3680EC	2017-08-09 14:01:00+03	77900.00
368131	2017-08-07 16:59:00+03	26700.00
368136	2017-08-01 19:43:00+03	99300.00
3681BB	2017-08-12 11:11:00+03	106200.00
368250	2017-07-30 14:41:00+03	138000.00
368286	2017-06-28 23:07:00+03	55600.00
36829B	2017-08-07 02:18:00+03	163200.00
3682A8	2017-08-13 04:12:00+03	29500.00
3682FA	2017-07-09 19:51:00+03	16800.00
36833C	2017-07-04 03:19:00+03	50600.00
3683B1	2017-08-02 01:08:00+03	28000.00
3683C5	2017-07-24 17:53:00+03	134400.00
3683DD	2017-07-30 23:52:00+03	13400.00
3683F0	2017-08-09 21:07:00+03	35700.00
3684EE	2017-06-27 08:03:00+03	126900.00
36851E	2017-07-26 14:45:00+03	69000.00
36856F	2017-07-25 14:33:00+03	12400.00
3685C7	2017-07-14 07:09:00+03	88100.00
368613	2017-08-09 07:20:00+03	108200.00
36862F	2017-07-26 22:58:00+03	68400.00
368630	2017-07-08 11:34:00+03	270800.00
368645	2017-08-06 14:19:00+03	24400.00
368692	2017-06-28 23:43:00+03	45200.00
368694	2017-07-02 06:44:00+03	139300.00
3686B6	2017-08-07 05:47:00+03	68000.00
3686DE	2017-07-05 18:22:00+03	23400.00
368728	2017-08-07 00:34:00+03	43000.00
36872A	2017-07-18 04:27:00+03	149200.00
368775	2017-08-10 18:56:00+03	46300.00
3687BB	2017-08-14 11:55:00+03	22000.00
3687F7	2017-07-31 01:02:00+03	166300.00
3688E4	2017-07-16 02:37:00+03	13400.00
3688FD	2017-07-07 04:51:00+03	76400.00
368901	2017-07-24 14:58:00+03	25800.00
36890D	2017-08-08 01:24:00+03	12600.00
368915	2017-07-24 08:12:00+03	96400.00
36892B	2017-08-07 04:25:00+03	26000.00
3689C9	2017-07-04 04:32:00+03	19000.00
368AC5	2017-06-30 08:36:00+03	109600.00
368AD1	2017-07-05 00:12:00+03	85000.00
368B57	2017-08-12 06:18:00+03	23200.00
368B73	2017-08-07 22:30:00+03	75300.00
368B89	2017-07-31 17:09:00+03	187800.00
368B9C	2017-08-03 12:26:00+03	246000.00
368D2B	2017-08-01 19:03:00+03	23200.00
368D40	2017-08-07 22:59:00+03	124200.00
368D4C	2017-08-13 13:50:00+03	114800.00
368E05	2017-07-14 21:49:00+03	37500.00
368E79	2017-08-15 08:11:00+03	28800.00
368ED5	2017-07-02 10:49:00+03	99200.00
368F02	2017-07-31 14:21:00+03	271400.00
368F0F	2017-07-15 06:27:00+03	4000.00
368F36	2017-08-03 07:20:00+03	19600.00
368F42	2017-07-16 20:09:00+03	118700.00
368F88	2017-07-18 10:49:00+03	56600.00
368FA4	2017-07-26 04:16:00+03	47600.00
368FF5	2017-07-20 15:09:00+03	32700.00
36902B	2017-07-31 02:57:00+03	155300.00
3690AB	2017-08-04 02:39:00+03	134400.00
3690D7	2017-08-06 05:53:00+03	135000.00
369207	2017-07-29 03:09:00+03	45000.00
36920E	2017-07-10 16:43:00+03	46800.00
369214	2017-06-30 21:10:00+03	233700.00
36925B	2017-08-12 12:21:00+03	168000.00
369273	2017-08-09 10:24:00+03	108600.00
369275	2017-07-18 17:52:00+03	18400.00
3692C4	2017-07-25 19:01:00+03	98400.00
3692C5	2017-07-07 16:28:00+03	50600.00
369313	2017-07-25 10:29:00+03	53500.00
369358	2017-07-15 15:59:00+03	52700.00
36941E	2017-07-14 06:00:00+03	51600.00
369437	2017-07-22 15:26:00+03	70100.00
3694D8	2017-07-31 06:33:00+03	134700.00
3694F2	2017-07-14 12:08:00+03	111600.00
369514	2017-08-06 13:04:00+03	66000.00
3695A6	2017-07-24 18:00:00+03	24400.00
3695B0	2017-08-05 23:11:00+03	22000.00
3695B3	2017-07-04 20:34:00+03	58900.00
369642	2017-08-07 13:11:00+03	26000.00
369654	2017-08-02 07:21:00+03	43200.00
3696D5	2017-07-23 18:54:00+03	75300.00
3697F4	2017-07-02 03:21:00+03	31400.00
369860	2017-07-31 11:11:00+03	84100.00
36987A	2017-08-03 04:55:00+03	18000.00
36989A	2017-07-04 13:48:00+03	193200.00
369906	2017-08-05 08:42:00+03	26000.00
369942	2017-07-29 18:10:00+03	44800.00
3699AC	2017-07-30 10:06:00+03	195000.00
3699B0	2017-07-07 13:14:00+03	81700.00
3699BE	2017-07-15 05:02:00+03	99200.00
369A47	2017-07-20 04:28:00+03	113300.00
369A87	2017-07-05 14:40:00+03	6000.00
369AD6	2017-07-15 12:19:00+03	44500.00
369B27	2017-07-07 04:07:00+03	47000.00
369B37	2017-07-14 09:53:00+03	10800.00
369B7D	2017-07-04 00:33:00+03	6300.00
369B91	2017-07-22 09:26:00+03	49600.00
369C17	2017-07-16 02:40:00+03	23200.00
369C1C	2017-07-31 03:18:00+03	35200.00
369C5A	2017-07-05 10:47:00+03	28700.00
369C8A	2017-07-22 19:00:00+03	55400.00
369CFD	2017-08-10 01:34:00+03	6300.00
369D00	2017-08-14 01:59:00+03	14000.00
369D44	2017-08-07 11:56:00+03	91100.00
369D69	2017-08-06 23:26:00+03	166100.00
369D9B	2017-08-11 06:54:00+03	399600.00
369E2D	2017-07-19 07:47:00+03	25000.00
369E9B	2017-08-03 16:59:00+03	27200.00
369F0B	2017-07-17 19:08:00+03	91800.00
369F1C	2017-07-27 07:20:00+03	134600.00
369F1E	2017-07-15 14:42:00+03	119500.00
369F81	2017-08-01 21:46:00+03	31100.00
369F9B	2017-08-02 07:37:00+03	6700.00
369FEA	2017-07-25 22:37:00+03	73400.00
369FF5	2017-08-13 11:12:00+03	199700.00
369FF7	2017-07-16 05:33:00+03	98400.00
36A095	2017-08-03 12:27:00+03	123600.00
36A0CA	2017-08-03 10:49:00+03	26800.00
36A127	2017-08-06 15:59:00+03	22600.00
36A14C	2017-07-10 01:00:00+03	8200.00
36A18B	2017-08-15 00:02:00+03	27900.00
36A1C8	2017-08-15 15:21:00+03	62800.00
36A1DE	2017-07-14 01:28:00+03	22000.00
36A259	2017-07-12 12:56:00+03	38000.00
36A26F	2017-07-19 11:01:00+03	6000.00
36A2AA	2017-08-01 23:36:00+03	173900.00
36A2B7	2017-07-23 07:03:00+03	821600.00
36A2D5	2017-08-05 02:21:00+03	35700.00
36A2FF	2017-07-04 13:38:00+03	24700.00
36A321	2017-07-16 06:14:00+03	57500.00
36A330	2017-07-13 03:55:00+03	12000.00
36A3D4	2017-08-15 14:30:00+03	372500.00
36A3F9	2017-08-09 21:02:00+03	58600.00
36A49A	2017-08-04 06:20:00+03	12600.00
36A4AD	2017-08-01 16:20:00+03	10800.00
36A4C7	2017-08-10 22:56:00+03	60400.00
36A5B1	2017-07-13 05:13:00+03	269900.00
36A5F1	2017-07-16 01:22:00+03	246000.00
36A5FF	2017-08-06 04:07:00+03	411200.00
36A66C	2017-07-28 08:23:00+03	56000.00
36A6AA	2017-07-08 09:18:00+03	46000.00
36A70C	2017-07-16 15:04:00+03	39800.00
36A777	2017-07-08 18:28:00+03	32200.00
36A78E	2017-07-12 12:27:00+03	55800.00
36A797	2017-08-08 12:54:00+03	36200.00
36A799	2017-07-17 01:03:00+03	20000.00
36A7CA	2017-07-19 23:45:00+03	112000.00
36A8A4	2017-06-29 01:36:00+03	56100.00
36A981	2017-07-18 00:31:00+03	16400.00
36A9C9	2017-08-02 09:31:00+03	31000.00
36A9EC	2017-08-08 06:02:00+03	58200.00
36A9FD	2017-08-07 06:23:00+03	48300.00
36AA7A	2017-07-17 18:19:00+03	6200.00
36AA83	2017-08-07 06:07:00+03	75700.00
36AA92	2017-07-02 20:32:00+03	43200.00
36AA99	2017-07-01 06:27:00+03	119000.00
36AACD	2017-08-02 06:53:00+03	148500.00
36AAE8	2017-07-20 08:29:00+03	133200.00
36AAFD	2017-07-25 16:36:00+03	12600.00
36AB3E	2017-07-30 04:11:00+03	59800.00
36AB55	2017-07-06 16:38:00+03	123000.00
36ABE0	2017-07-29 20:28:00+03	31400.00
36AC43	2017-08-10 07:26:00+03	13500.00
36AC4E	2017-07-01 17:23:00+03	52000.00
36AC60	2017-07-07 09:53:00+03	70200.00
36ACBF	2017-07-28 05:20:00+03	75600.00
36AD03	2017-07-31 21:55:00+03	57600.00
36AD15	2017-08-03 17:59:00+03	21400.00
36AD25	2017-07-19 18:09:00+03	85000.00
36AD6B	2017-07-03 05:30:00+03	39200.00
36AD78	2017-08-03 11:29:00+03	101100.00
36AD9D	2017-07-19 03:28:00+03	116400.00
36AD9F	2017-08-09 23:09:00+03	46000.00
36ADCE	2017-07-08 19:48:00+03	46400.00
36ADF2	2017-07-08 15:55:00+03	14000.00
36AE5C	2017-08-01 22:48:00+03	173900.00
36AE99	2017-08-01 14:54:00+03	164400.00
36AEFC	2017-07-07 23:13:00+03	51300.00
36AF5A	2017-07-13 13:48:00+03	103900.00
36AFB6	2017-07-05 05:10:00+03	47100.00
36B00B	2017-08-03 17:26:00+03	55800.00
36B02C	2017-08-11 08:55:00+03	23200.00
36B02D	2017-08-08 13:55:00+03	151400.00
36B0D9	2017-06-28 02:46:00+03	326200.00
36B0F0	2017-08-08 02:25:00+03	40000.00
36B112	2017-08-03 22:47:00+03	27800.00
36B1D5	2017-08-01 07:46:00+03	520600.00
36B21C	2017-08-07 06:05:00+03	66400.00
36B26B	2017-07-18 08:48:00+03	30800.00
36B286	2017-07-19 21:18:00+03	106700.00
36B291	2017-07-07 03:54:00+03	34000.00
36B2B2	2017-07-24 20:16:00+03	56600.00
36B2C9	2017-06-29 12:32:00+03	16000.00
36B2D7	2017-07-10 07:35:00+03	14400.00
36B301	2017-07-22 11:11:00+03	129500.00
36B39C	2017-07-30 19:38:00+03	12600.00
36B3AF	2017-07-17 18:27:00+03	26000.00
36B3D0	2017-07-05 21:26:00+03	98400.00
36B41F	2017-07-25 23:38:00+03	406700.00
36B46D	2017-07-19 18:12:00+03	90800.00
36B49B	2017-08-03 00:53:00+03	28000.00
36B4A0	2017-07-21 06:26:00+03	26000.00
36B4B9	2017-07-07 00:48:00+03	15200.00
36B4D7	2017-06-29 06:11:00+03	25200.00
36B4EF	2017-07-17 08:18:00+03	265600.00
36B551	2017-07-10 06:12:00+03	51900.00
36B5A7	2017-08-02 05:04:00+03	8400.00
36B5BE	2017-07-26 15:53:00+03	31900.00
36B631	2017-07-21 22:43:00+03	57400.00
36B676	2017-07-12 13:07:00+03	37900.00
36B685	2017-08-04 07:35:00+03	157900.00
36B689	2017-07-29 06:56:00+03	7300.00
36B6AF	2017-06-29 21:09:00+03	23400.00
36B6B9	2017-08-05 12:41:00+03	23200.00
36B6F4	2017-07-16 10:55:00+03	83000.00
36B72E	2017-08-02 17:49:00+03	265600.00
36B735	2017-08-08 14:52:00+03	36200.00
36B79E	2017-07-16 22:19:00+03	135200.00
36B7CF	2017-07-30 12:18:00+03	202400.00
36B844	2017-07-26 23:02:00+03	45200.00
36B853	2017-08-02 06:23:00+03	111600.00
36B87B	2017-07-20 03:34:00+03	203000.00
36B88B	2017-07-19 23:58:00+03	185500.00
36B890	2017-07-07 20:40:00+03	105600.00
36B8A4	2017-07-27 12:13:00+03	141600.00
36B8B2	2017-08-13 04:19:00+03	26700.00
36B90A	2017-07-08 06:49:00+03	24800.00
36B984	2017-07-10 16:31:00+03	26000.00
36B993	2017-07-11 05:12:00+03	41800.00
36B9B5	2017-07-19 15:21:00+03	117200.00
36B9B8	2017-08-11 11:22:00+03	26000.00
36B9EA	2017-07-05 06:25:00+03	25200.00
36BA18	2017-08-03 00:12:00+03	23600.00
36BA53	2017-08-01 19:15:00+03	69400.00
36BA75	2017-07-03 11:21:00+03	23600.00
36BAA3	2017-07-30 12:00:00+03	63200.00
36BAE2	2017-08-03 09:39:00+03	196700.00
36BAE5	2017-07-19 17:16:00+03	246000.00
36BB64	2017-07-16 01:53:00+03	111600.00
36BBDE	2017-07-22 17:48:00+03	67200.00
36BBE0	2017-07-14 04:24:00+03	43000.00
36BC25	2017-06-26 07:29:00+03	36600.00
36BC76	2017-08-08 13:29:00+03	72200.00
36BC89	2017-07-10 14:33:00+03	95600.00
36BCAB	2017-08-14 09:13:00+03	24400.00
36BCD4	2017-07-17 03:58:00+03	11600.00
36BD0D	2017-07-13 05:31:00+03	23600.00
36BD25	2017-07-21 16:33:00+03	119300.00
36BD7A	2017-07-27 08:49:00+03	177200.00
36BD7D	2017-07-31 11:10:00+03	73600.00
36BD80	2017-07-04 21:16:00+03	80600.00
36BD88	2017-07-03 20:19:00+03	85000.00
36BD89	2017-08-10 01:08:00+03	40800.00
36BD92	2017-07-17 21:22:00+03	32700.00
36BDD0	2017-07-25 12:29:00+03	3700.00
36BDE6	2017-07-03 13:59:00+03	56200.00
36BDEA	2017-07-07 09:19:00+03	146900.00
36BE7E	2017-07-18 17:32:00+03	258400.00
36BE7F	2017-07-18 03:11:00+03	241300.00
36BEA0	2017-07-28 16:38:00+03	104600.00
36BEA4	2017-07-24 15:13:00+03	70400.00
36BEAB	2017-07-21 02:56:00+03	77900.00
36BF25	2017-07-17 00:18:00+03	6700.00
36BF28	2017-07-16 13:54:00+03	273000.00
36BF41	2017-08-07 15:40:00+03	77000.00
36BF66	2017-07-19 11:57:00+03	6700.00
36BF7B	2017-08-04 00:09:00+03	94000.00
36BF86	2017-07-09 00:32:00+03	131100.00
36BF8E	2017-07-22 03:27:00+03	272400.00
36BFB8	2017-08-12 17:07:00+03	172600.00
36BFED	2017-08-04 02:39:00+03	103100.00
36BFF2	2017-07-19 04:19:00+03	33400.00
36C034	2017-07-15 23:59:00+03	128800.00
36C05A	2017-06-29 08:16:00+03	47000.00
36C0BA	2017-08-01 05:00:00+03	351900.00
36C0D4	2017-07-02 19:42:00+03	115900.00
36C0D6	2017-07-19 07:25:00+03	68400.00
36C0D9	2017-07-06 17:06:00+03	23200.00
36C103	2017-08-09 12:23:00+03	301800.00
36C10F	2017-07-12 03:51:00+03	28800.00
36C120	2017-07-19 01:28:00+03	42400.00
36C157	2017-07-02 04:53:00+03	51600.00
36C15C	2017-08-01 12:25:00+03	62300.00
36C178	2017-07-29 11:48:00+03	31400.00
36C18B	2017-07-15 02:14:00+03	56000.00
36C20A	2017-07-10 17:03:00+03	55800.00
36C20B	2017-07-21 12:12:00+03	103600.00
36C224	2017-08-06 23:06:00+03	246000.00
36C275	2017-07-30 23:54:00+03	38400.00
36C2AC	2017-08-07 16:43:00+03	199700.00
36C392	2017-07-31 13:50:00+03	111600.00
36C3A7	2017-06-27 20:44:00+03	46700.00
36C3E7	2017-07-11 20:38:00+03	25400.00
36C3EE	2017-08-04 10:39:00+03	14800.00
36C40D	2017-08-12 07:47:00+03	43200.00
36C4CF	2017-08-03 18:36:00+03	49200.00
36C513	2017-07-10 04:25:00+03	56000.00
36C536	2017-07-20 01:08:00+03	44800.00
36C5AB	2017-07-16 19:59:00+03	48800.00
36C5BA	2017-07-07 04:30:00+03	20200.00
36C5C5	2017-08-14 02:52:00+03	91000.00
36C5E0	2017-08-15 00:24:00+03	30800.00
36C710	2017-07-27 13:35:00+03	60400.00
36C747	2017-07-04 01:36:00+03	56100.00
36C766	2017-06-30 04:41:00+03	10800.00
36C775	2017-08-15 01:31:00+03	6300.00
36C7AA	2017-07-02 18:42:00+03	43600.00
36C7C7	2017-07-31 18:04:00+03	12400.00
36C7EC	2017-08-05 09:39:00+03	189200.00
36C82B	2017-07-25 08:39:00+03	64900.00
36C831	2017-08-04 07:22:00+03	47200.00
36C868	2017-07-21 15:22:00+03	275200.00
36C8BB	2017-07-04 07:28:00+03	6000.00
36C913	2017-08-08 21:25:00+03	13400.00
36C9A9	2017-07-22 13:51:00+03	90000.00
36C9D6	2017-07-05 17:29:00+03	75600.00
36CA3D	2017-07-06 04:13:00+03	28000.00
36CA71	2017-07-10 05:40:00+03	31400.00
36CA90	2017-07-25 22:57:00+03	71900.00
36CB1D	2017-08-06 15:53:00+03	28800.00
36CB70	2017-07-04 16:31:00+03	166100.00
36CB76	2017-07-29 03:55:00+03	23200.00
36CB8A	2017-07-05 04:25:00+03	27300.00
36CB93	2017-07-02 03:51:00+03	66000.00
36CBE8	2017-08-08 01:20:00+03	31200.00
36CC2A	2017-07-10 16:43:00+03	28800.00
36CC7D	2017-08-13 12:55:00+03	101100.00
36CCA0	2017-07-20 09:46:00+03	396200.00
36CCEA	2017-07-19 22:00:00+03	60900.00
36CD17	2017-07-16 20:05:00+03	66600.00
36CD5F	2017-07-27 19:20:00+03	27200.00
36CD82	2017-07-22 10:39:00+03	104100.00
36CDF5	2017-07-06 16:29:00+03	98000.00
36CE1D	2017-07-07 20:28:00+03	25400.00
36CE2D	2017-08-08 03:05:00+03	186900.00
36CE47	2017-08-08 19:09:00+03	38500.00
36CE63	2017-07-23 14:07:00+03	192400.00
36CE8F	2017-07-10 12:04:00+03	115900.00
36CF66	2017-07-29 10:02:00+03	111600.00
36CF67	2017-07-05 02:56:00+03	85000.00
36CF80	2017-08-03 23:51:00+03	28000.00
36CFB3	2017-07-13 08:13:00+03	85000.00
36CFB9	2017-07-23 18:52:00+03	126300.00
36CFC2	2017-07-16 22:15:00+03	24800.00
36CFEC	2017-08-05 03:52:00+03	77200.00
36D03F	2017-07-05 19:53:00+03	86400.00
36D044	2017-08-12 17:44:00+03	46200.00
36D06B	2017-07-19 19:47:00+03	60400.00
36D0E1	2017-08-14 10:51:00+03	89600.00
36D103	2017-07-25 14:33:00+03	184500.00
36D14D	2017-08-04 09:44:00+03	14400.00
36D152	2017-07-11 12:48:00+03	199200.00
36D15D	2017-07-12 07:24:00+03	106400.00
36D22A	2017-08-14 16:38:00+03	40800.00
36D2F5	2017-08-14 15:45:00+03	101100.00
36D316	2017-07-10 16:50:00+03	40800.00
36D331	2017-07-17 01:43:00+03	6700.00
36D379	2017-07-10 22:19:00+03	99300.00
36D445	2017-07-05 23:48:00+03	220700.00
36D48E	2017-08-02 07:48:00+03	56000.00
36D4A8	2017-07-11 08:50:00+03	19600.00
36D4DB	2017-07-14 13:46:00+03	162700.00
36D4DC	2017-08-10 04:21:00+03	55800.00
36D535	2017-07-10 06:54:00+03	75300.00
36D576	2017-07-22 07:50:00+03	34600.00
36D580	2017-07-20 16:23:00+03	15800.00
36D5FB	2017-08-11 21:00:00+03	23200.00
36D60B	2017-08-08 00:26:00+03	29600.00
36D639	2017-07-31 07:20:00+03	129700.00
36D6DE	2017-07-03 18:26:00+03	46400.00
36D6E9	2017-07-13 21:37:00+03	46900.00
36D706	2017-07-16 23:31:00+03	92600.00
36D744	2017-08-08 23:05:00+03	34600.00
36D746	2017-07-23 09:36:00+03	75300.00
36D748	2017-07-21 14:29:00+03	185300.00
36D7BC	2017-07-30 09:59:00+03	23400.00
36D82A	2017-07-05 01:01:00+03	26400.00
36D84E	2017-07-11 01:01:00+03	170200.00
36D8D9	2017-08-14 12:10:00+03	112600.00
36D92E	2017-08-07 03:28:00+03	28300.00
36D938	2017-08-03 09:32:00+03	54800.00
36D9E7	2017-06-30 20:16:00+03	76000.00
36DA50	2017-06-30 22:20:00+03	99200.00
36DAF4	2017-08-04 01:34:00+03	59800.00
36DBBF	2017-07-20 10:10:00+03	186900.00
36DC25	2017-07-15 18:30:00+03	19800.00
36DC57	2017-08-14 12:08:00+03	12000.00
36DC63	2017-07-26 08:20:00+03	169900.00
36DC7A	2017-07-28 03:34:00+03	30200.00
36DC83	2017-07-23 16:31:00+03	36800.00
36DD04	2017-08-12 02:12:00+03	29200.00
36DD07	2017-07-07 22:09:00+03	39200.00
36DD53	2017-07-13 14:38:00+03	101200.00
36DD56	2017-07-03 12:01:00+03	56000.00
36DE4D	2017-07-27 18:52:00+03	155600.00
36DEA9	2017-08-03 17:15:00+03	135000.00
36DECE	2017-07-03 22:18:00+03	80000.00
36DEE3	2017-08-08 17:48:00+03	17600.00
36DEEB	2017-08-13 13:28:00+03	86300.00
36DF5D	2017-08-13 11:50:00+03	114400.00
36DF63	2017-08-08 15:50:00+03	28400.00
36DF69	2017-08-12 17:26:00+03	154100.00
36DF6C	2017-07-02 04:43:00+03	29400.00
36DF7A	2017-07-26 15:53:00+03	28800.00
36DFD2	2017-07-20 18:35:00+03	12400.00
36E013	2017-07-08 08:58:00+03	47500.00
36E016	2017-07-19 12:38:00+03	265600.00
36E03D	2017-08-15 09:44:00+03	39400.00
36E0E9	2017-07-01 11:48:00+03	167400.00
36E103	2017-07-26 06:01:00+03	55800.00
36E1A2	2017-07-19 22:03:00+03	20400.00
36E25B	2017-07-08 19:57:00+03	97000.00
36E2BF	2017-07-26 22:25:00+03	244500.00
36E324	2017-07-15 15:00:00+03	32000.00
36E32F	2017-07-13 13:00:00+03	26000.00
36E360	2017-08-14 20:24:00+03	77200.00
36E37A	2017-08-09 20:46:00+03	29600.00
36E388	2017-08-03 21:27:00+03	369000.00
36E38F	2017-08-02 06:51:00+03	57700.00
36E3CC	2017-07-28 03:44:00+03	27800.00
36E46D	2017-07-19 01:22:00+03	89700.00
36E53B	2017-07-08 20:21:00+03	179400.00
36E558	2017-07-04 04:46:00+03	131400.00
36E582	2017-07-18 16:37:00+03	290600.00
36E5CD	2017-07-07 03:45:00+03	155600.00
36E636	2017-07-24 22:47:00+03	132800.00
36E6D7	2017-07-15 16:19:00+03	110500.00
36E6FC	2017-08-03 19:20:00+03	21800.00
36E72F	2017-07-16 11:34:00+03	118100.00
36E744	2017-07-26 18:35:00+03	24200.00
36E751	2017-07-01 13:21:00+03	57400.00
36E75B	2017-07-12 06:23:00+03	24400.00
36E76E	2017-08-07 03:15:00+03	109600.00
36E7AE	2017-07-01 16:06:00+03	105000.00
36E7D2	2017-07-27 04:24:00+03	23200.00
36E83A	2017-07-23 12:14:00+03	6700.00
36E865	2017-07-17 23:49:00+03	32700.00
36E86B	2017-07-10 13:19:00+03	16400.00
36E927	2017-07-07 01:25:00+03	92400.00
36E937	2017-07-31 19:52:00+03	21000.00
36E96A	2017-07-12 20:01:00+03	115000.00
36E99E	2017-08-07 22:49:00+03	92800.00
36EA36	2017-07-21 05:08:00+03	29400.00
36EA95	2017-08-04 13:08:00+03	28000.00
36EA98	2017-07-12 04:03:00+03	29600.00
36EAE4	2017-07-06 09:37:00+03	48000.00
36EB51	2017-07-20 03:31:00+03	235700.00
36EB86	2017-07-04 21:00:00+03	75200.00
36EBDC	2017-08-11 02:50:00+03	357600.00
36EC49	2017-07-08 11:45:00+03	50000.00
36EC74	2017-07-07 01:11:00+03	109800.00
36ECE1	2017-07-24 13:31:00+03	167900.00
36ED07	2017-08-05 19:02:00+03	26000.00
36ED11	2017-08-08 16:30:00+03	167400.00
36ED34	2017-07-24 06:52:00+03	55800.00
36EDC5	2017-07-08 13:13:00+03	56000.00
36EE15	2017-08-06 13:30:00+03	14000.00
36EE34	2017-07-27 13:58:00+03	56000.00
36EEA4	2017-08-09 07:43:00+03	57600.00
36EED0	2017-07-25 05:12:00+03	21200.00
36EEEA	2017-08-03 22:50:00+03	106400.00
36EF09	2017-08-08 23:25:00+03	64100.00
36EF9B	2017-07-16 11:28:00+03	57500.00
36EFA1	2017-08-05 20:38:00+03	111700.00
36EFBF	2017-08-12 18:39:00+03	19600.00
36EFCA	2017-07-01 15:30:00+03	36200.00
36F019	2017-07-11 14:44:00+03	86400.00
36F03A	2017-07-16 08:37:00+03	56000.00
36F19D	2017-07-11 07:29:00+03	85000.00
36F249	2017-08-03 02:09:00+03	23200.00
36F2B5	2017-08-15 07:58:00+03	72400.00
36F2E2	2017-07-02 09:59:00+03	25100.00
36F307	2017-07-03 21:12:00+03	260900.00
36F31F	2017-07-11 23:22:00+03	25900.00
36F35E	2017-07-27 02:00:00+03	120100.00
36F362	2017-07-13 11:51:00+03	54500.00
36F372	2017-07-09 17:59:00+03	201200.00
36F374	2017-07-28 10:25:00+03	12900.00
36F3D8	2017-08-10 19:02:00+03	31000.00
36F418	2017-08-12 20:18:00+03	35600.00
36F4DE	2017-07-25 17:28:00+03	26000.00
36F4EF	2017-07-09 01:07:00+03	23400.00
36F51D	2017-07-07 09:34:00+03	63800.00
36F566	2017-07-22 13:41:00+03	52700.00
36F5A6	2017-07-02 13:01:00+03	28000.00
36F63B	2017-07-03 19:45:00+03	135600.00
36F692	2017-08-14 21:50:00+03	62600.00
36F6A4	2017-08-11 02:35:00+03	27400.00
36F6C3	2017-07-17 03:15:00+03	542200.00
36F7D8	2017-07-07 22:44:00+03	47800.00
36F812	2017-07-12 12:34:00+03	51900.00
36F82F	2017-07-22 17:49:00+03	250400.00
36F833	2017-07-30 04:14:00+03	60400.00
36F882	2017-07-11 09:17:00+03	277800.00
36F970	2017-08-13 09:48:00+03	59200.00
36F9B1	2017-06-30 11:29:00+03	61800.00
36F9BB	2017-07-13 15:57:00+03	26000.00
36F9C1	2017-07-12 19:46:00+03	187600.00
36F9C8	2017-07-18 18:14:00+03	309200.00
36F9DB	2017-07-17 00:55:00+03	49800.00
36F9F4	2017-07-29 03:07:00+03	9300.00
36F9F7	2017-07-22 01:34:00+03	46400.00
36FA1B	2017-07-25 05:15:00+03	46000.00
36FA24	2017-08-09 20:56:00+03	168000.00
36FA34	2017-07-22 19:12:00+03	43400.00
36FA4A	2017-07-21 00:44:00+03	193700.00
36FA7C	2017-07-03 10:20:00+03	15400.00
36FA89	2017-07-17 13:51:00+03	36800.00
36FAEA	2017-07-21 16:51:00+03	14000.00
36FB2E	2017-08-02 02:43:00+03	12000.00
36FB3E	2017-07-04 15:39:00+03	101700.00
36FB4D	2017-07-16 11:16:00+03	78900.00
36FBC8	2017-07-01 21:51:00+03	8600.00
36FC81	2017-07-10 13:47:00+03	39200.00
36FCAB	2017-07-13 01:20:00+03	15900.00
36FCB4	2017-07-31 18:26:00+03	35600.00
36FCF8	2017-08-08 14:25:00+03	44000.00
36FD1B	2017-08-01 03:50:00+03	75600.00
36FD38	2017-07-28 09:52:00+03	62600.00
36FD6F	2017-07-20 00:17:00+03	46800.00
36FDD6	2017-07-24 11:56:00+03	35700.00
36FDF4	2017-06-29 02:38:00+03	133100.00
36FE98	2017-06-30 02:14:00+03	23600.00
36FF41	2017-07-13 03:54:00+03	27200.00
36FF66	2017-08-07 16:43:00+03	14000.00
36FF94	2017-07-13 12:57:00+03	55600.00
36FFE2	2017-07-13 19:39:00+03	8400.00
36FFF0	2017-07-29 02:09:00+03	24400.00
37004A	2017-07-19 17:03:00+03	29200.00
370060	2017-07-20 08:47:00+03	80900.00
370063	2017-07-05 13:43:00+03	28300.00
370088	2017-08-05 12:31:00+03	86600.00
370122	2017-07-21 02:04:00+03	56300.00
37017C	2017-07-11 11:47:00+03	15000.00
3701C7	2017-07-05 04:25:00+03	23100.00
370281	2017-08-15 14:19:00+03	192700.00
37028E	2017-08-04 22:54:00+03	100600.00
3702C8	2017-07-02 04:36:00+03	85400.00
370300	2017-07-26 11:17:00+03	22100.00
370359	2017-07-15 07:05:00+03	12400.00
37039D	2017-08-05 03:51:00+03	38400.00
370410	2017-07-25 18:43:00+03	26000.00
370497	2017-07-04 22:00:00+03	57600.00
37053E	2017-08-02 02:52:00+03	21800.00
370560	2017-07-12 10:22:00+03	24400.00
370598	2017-08-13 07:12:00+03	21400.00
3705AA	2017-08-06 18:47:00+03	94800.00
370601	2017-07-14 08:12:00+03	57200.00
370653	2017-07-31 17:21:00+03	22600.00
3706A7	2017-08-11 20:35:00+03	26700.00
370732	2017-07-15 22:57:00+03	15000.00
37074C	2017-08-08 10:25:00+03	177200.00
370750	2017-07-30 12:09:00+03	71600.00
37078A	2017-07-14 21:27:00+03	24000.00
3707AB	2017-08-11 08:24:00+03	100000.00
3707C2	2017-07-03 18:33:00+03	198600.00
3707D2	2017-08-09 15:04:00+03	76600.00
3707FE	2017-07-11 22:03:00+03	49100.00
37083C	2017-07-24 09:35:00+03	46200.00
370853	2017-06-26 10:31:00+03	44800.00
370882	2017-07-29 14:59:00+03	69800.00
37091D	2017-07-02 10:53:00+03	55800.00
37097E	2017-08-02 23:30:00+03	24400.00
37099C	2017-07-01 16:35:00+03	75200.00
3709A7	2017-06-28 15:06:00+03	60300.00
370A56	2017-08-03 15:04:00+03	206200.00
370ACF	2017-07-10 14:48:00+03	59100.00
370B13	2017-07-26 01:26:00+03	67600.00
370B53	2017-08-08 01:17:00+03	81600.00
370B7C	2017-07-10 10:58:00+03	62700.00
370BB3	2017-07-28 21:51:00+03	27200.00
370BE7	2017-07-02 14:49:00+03	119700.00
370BE8	2017-07-08 07:38:00+03	91500.00
370BF1	2017-08-12 07:31:00+03	99200.00
370C50	2017-07-20 00:23:00+03	47800.00
370C67	2017-08-04 02:06:00+03	56000.00
370CE3	2017-07-05 06:33:00+03	372500.00
370D23	2017-07-22 06:53:00+03	54800.00
370D37	2017-08-06 13:23:00+03	136800.00
370D59	2017-07-25 02:56:00+03	150600.00
370D78	2017-07-09 12:58:00+03	37400.00
370DBC	2017-07-20 14:50:00+03	47200.00
370E21	2017-07-13 09:54:00+03	7200.00
370E22	2017-08-15 09:11:00+03	28800.00
370E2B	2017-08-01 22:10:00+03	78300.00
370E68	2017-07-16 06:17:00+03	125200.00
370EE3	2017-08-02 21:57:00+03	44700.00
370F2D	2017-07-10 07:05:00+03	28800.00
370F5C	2017-07-14 07:46:00+03	46400.00
370F7A	2017-07-12 10:12:00+03	265600.00
371019	2017-06-29 12:02:00+03	6000.00
371046	2017-08-05 04:26:00+03	169900.00
371092	2017-08-02 23:08:00+03	35200.00
371099	2017-07-12 03:32:00+03	136200.00
3710B9	2017-07-19 12:21:00+03	112100.00
37114C	2017-07-14 08:08:00+03	77000.00
3711D1	2017-07-08 14:44:00+03	61200.00
37120D	2017-07-25 13:46:00+03	428400.00
371221	2017-07-13 04:57:00+03	21400.00
371228	2017-08-07 15:59:00+03	61800.00
371235	2017-07-08 16:57:00+03	28800.00
3712AF	2017-07-08 22:36:00+03	201800.00
3712C3	2017-07-26 04:40:00+03	168000.00
3712DA	2017-08-12 17:29:00+03	66600.00
37135E	2017-07-28 07:20:00+03	94000.00
371395	2017-08-15 01:58:00+03	90800.00
3713D0	2017-08-14 15:01:00+03	40600.00
3714D0	2017-07-04 03:17:00+03	113200.00
371549	2017-07-22 14:32:00+03	56000.00
3715B4	2017-07-24 23:47:00+03	27200.00
371606	2017-07-10 13:41:00+03	75600.00
371645	2017-08-07 15:32:00+03	25400.00
371668	2017-07-12 16:13:00+03	23600.00
371779	2017-07-05 01:53:00+03	38600.00
3717E9	2017-07-25 17:09:00+03	326100.00
3717F4	2017-07-14 16:05:00+03	58600.00
37182C	2017-08-10 02:33:00+03	55800.00
37184A	2017-07-11 11:30:00+03	100600.00
371852	2017-08-07 01:39:00+03	27200.00
3718A1	2017-07-10 12:25:00+03	81300.00
3718D2	2017-08-13 01:19:00+03	29300.00
371910	2017-07-26 21:32:00+03	109600.00
371937	2017-07-20 16:28:00+03	67400.00
3719B6	2017-07-08 03:28:00+03	57700.00
371A3D	2017-07-19 16:46:00+03	283500.00
371A4E	2017-08-08 12:11:00+03	67400.00
371AE1	2017-07-27 14:30:00+03	24400.00
371B34	2017-07-21 18:10:00+03	25400.00
371B58	2017-07-18 14:50:00+03	37900.00
371B9D	2017-08-04 23:52:00+03	24000.00
371BE2	2017-07-24 03:30:00+03	27900.00
371BE5	2017-07-13 09:50:00+03	176900.00
371C98	2017-08-07 20:20:00+03	43600.00
371CB9	2017-07-26 10:13:00+03	34000.00
371CF0	2017-07-29 08:27:00+03	39800.00
371D3E	2017-08-10 15:33:00+03	132800.00
371D4D	2017-08-04 16:00:00+03	74400.00
371DD0	2017-07-28 22:13:00+03	72200.00
371DD3	2017-07-01 23:13:00+03	51900.00
371DEA	2017-07-09 03:57:00+03	29600.00
371E44	2017-07-21 08:54:00+03	67600.00
371E55	2017-08-12 20:28:00+03	73300.00
371E74	2017-08-13 17:17:00+03	36800.00
371EEC	2017-07-10 13:18:00+03	38400.00
371F14	2017-07-18 09:15:00+03	37700.00
371F5C	2017-08-11 22:10:00+03	130400.00
371FDE	2017-07-11 02:01:00+03	21500.00
372003	2017-07-05 08:20:00+03	28300.00
372085	2017-07-15 14:07:00+03	51500.00
372088	2017-08-10 07:18:00+03	37900.00
3720A0	2017-08-06 23:14:00+03	23200.00
3720B5	2017-07-13 12:37:00+03	43600.00
3720E4	2017-08-07 21:31:00+03	20000.00
3720F7	2017-08-09 22:50:00+03	231800.00
3720FC	2017-07-29 17:51:00+03	79900.00
372104	2017-07-14 02:31:00+03	38800.00
37212C	2017-08-06 04:00:00+03	24700.00
37214F	2017-08-04 11:02:00+03	46400.00
372169	2017-08-12 12:25:00+03	73600.00
372189	2017-07-15 00:28:00+03	67200.00
3721F2	2017-08-02 20:22:00+03	71200.00
37223E	2017-08-13 02:21:00+03	258700.00
372270	2017-07-22 08:29:00+03	65900.00
372292	2017-07-03 19:32:00+03	92600.00
3722C1	2017-08-04 16:45:00+03	180200.00
3722DA	2017-07-20 23:36:00+03	57500.00
372309	2017-07-11 07:28:00+03	55900.00
372310	2017-07-03 10:15:00+03	34000.00
37232D	2017-08-05 04:50:00+03	19600.00
372344	2017-08-05 13:41:00+03	76600.00
3723FF	2017-07-31 16:27:00+03	18700.00
372419	2017-07-20 16:24:00+03	79900.00
37242A	2017-08-04 01:04:00+03	198400.00
372462	2017-07-28 03:46:00+03	114200.00
372472	2017-07-10 06:13:00+03	65900.00
372499	2017-08-10 06:52:00+03	8200.00
3724CF	2017-07-08 09:05:00+03	153800.00
3724E1	2017-07-10 02:08:00+03	275200.00
3724F7	2017-06-25 06:58:00+03	56000.00
37251C	2017-07-09 03:12:00+03	29400.00
372619	2017-08-14 01:08:00+03	28000.00
37266F	2017-08-11 00:39:00+03	133100.00
3726AD	2017-07-04 12:23:00+03	47400.00
3726D4	2017-07-03 08:18:00+03	64800.00
372747	2017-07-26 09:07:00+03	13700.00
372774	2017-08-03 11:53:00+03	184300.00
3727D6	2017-07-17 09:43:00+03	32700.00
3728B8	2017-07-25 08:16:00+03	47600.00
372930	2017-07-27 16:14:00+03	160400.00
372940	2017-07-12 13:40:00+03	84500.00
372942	2017-07-18 18:00:00+03	28000.00
372A48	2017-07-15 22:36:00+03	114700.00
372A71	2017-08-05 07:26:00+03	257500.00
372A9A	2017-07-19 12:24:00+03	539400.00
372B7D	2017-07-09 17:19:00+03	6700.00
372BC0	2017-07-23 17:22:00+03	27200.00
372C7D	2017-07-22 18:55:00+03	79900.00
372C8C	2017-07-01 11:49:00+03	64700.00
372CDF	2017-08-13 11:06:00+03	28000.00
372D59	2017-07-01 01:48:00+03	69600.00
372DC7	2017-08-06 06:54:00+03	61800.00
372DF6	2017-07-10 01:12:00+03	14000.00
372EC0	2017-07-10 04:45:00+03	131100.00
372EC9	2017-07-16 09:41:00+03	99200.00
372ECD	2017-07-06 07:45:00+03	25000.00
372ED5	2017-07-15 17:26:00+03	38400.00
372EFF	2017-07-05 07:18:00+03	52400.00
372F1F	2017-07-26 02:00:00+03	161400.00
372F45	2017-07-22 15:55:00+03	24800.00
372F7A	2017-08-14 06:35:00+03	6000.00
372F9F	2017-07-04 19:57:00+03	14000.00
372FF3	2017-07-04 18:53:00+03	12400.00
373021	2017-07-24 23:20:00+03	35200.00
373022	2017-07-02 09:01:00+03	6300.00
37302D	2017-08-05 20:07:00+03	26000.00
3731FF	2017-07-18 08:52:00+03	28000.00
373228	2017-07-21 08:15:00+03	32800.00
373285	2017-08-10 09:17:00+03	46800.00
3732B6	2017-08-04 17:30:00+03	33300.00
3732C3	2017-08-13 00:58:00+03	88600.00
3732E6	2017-07-08 19:39:00+03	4000.00
3732EB	2017-07-04 03:44:00+03	257500.00
373321	2017-08-02 13:05:00+03	28000.00
3733A5	2017-08-06 11:22:00+03	377400.00
373418	2017-07-08 05:52:00+03	112000.00
3734C7	2017-07-09 06:02:00+03	26000.00
373506	2017-07-07 12:10:00+03	272100.00
37353D	2017-07-23 00:53:00+03	28800.00
373544	2017-07-15 08:48:00+03	21400.00
373570	2017-07-15 19:47:00+03	35800.00
3735B3	2017-08-13 21:36:00+03	193700.00
3735DE	2017-07-22 20:24:00+03	76300.00
3735FC	2017-08-04 10:41:00+03	55800.00
37361B	2017-08-11 13:19:00+03	87700.00
37362E	2017-07-26 12:50:00+03	26800.00
373640	2017-07-01 23:25:00+03	28800.00
3736B4	2017-07-19 05:40:00+03	260300.00
373712	2017-08-14 18:49:00+03	16000.00
3737A9	2017-08-11 11:01:00+03	13400.00
3737F1	2017-07-26 21:22:00+03	55800.00
37383C	2017-08-14 16:18:00+03	185300.00
3738B7	2017-08-10 11:49:00+03	129200.00
3738E3	2017-07-22 21:29:00+03	60700.00
37395C	2017-07-18 04:09:00+03	27900.00
373998	2017-07-10 00:04:00+03	70700.00
3739D1	2017-07-30 10:12:00+03	66300.00
3739E0	2017-08-12 07:52:00+03	48800.00
3739E6	2017-07-29 19:44:00+03	49800.00
373B1C	2017-07-20 21:27:00+03	23200.00
373B4C	2017-08-05 17:23:00+03	87000.00
373B72	2017-08-14 19:27:00+03	50800.00
373BAA	2017-08-09 04:50:00+03	68800.00
373BD2	2017-07-08 07:33:00+03	45100.00
373D5C	2017-08-12 04:26:00+03	12600.00
373DAE	2017-08-09 07:29:00+03	14400.00
373E59	2017-07-31 17:41:00+03	48500.00
373E5E	2017-07-25 11:51:00+03	8200.00
373E6F	2017-07-12 05:04:00+03	11300.00
373E9C	2017-06-26 19:41:00+03	271100.00
373EE4	2017-07-08 01:00:00+03	29200.00
373EEA	2017-07-13 23:14:00+03	67400.00
373F1A	2017-07-06 16:48:00+03	46400.00
373F5A	2017-08-10 02:54:00+03	92100.00
373FAC	2017-07-31 18:55:00+03	145300.00
37405D	2017-07-31 00:15:00+03	65500.00
374064	2017-07-19 05:21:00+03	229400.00
374066	2017-07-29 03:26:00+03	41300.00
3740C9	2017-08-04 19:25:00+03	55800.00
3740CF	2017-08-08 09:08:00+03	56000.00
374105	2017-08-13 11:40:00+03	50600.00
37413C	2017-07-28 14:11:00+03	49100.00
374162	2017-08-09 17:49:00+03	20400.00
37416F	2017-08-13 23:52:00+03	55800.00
37429E	2017-07-23 19:47:00+03	23400.00
3742D8	2017-07-22 16:53:00+03	77000.00
374315	2017-07-03 04:03:00+03	73600.00
374318	2017-06-30 16:32:00+03	266400.00
37437D	2017-08-14 19:52:00+03	111600.00
3743FC	2017-08-02 10:16:00+03	38400.00
374415	2017-07-10 10:52:00+03	21400.00
374422	2017-06-29 10:39:00+03	84000.00
3744A5	2017-07-09 08:46:00+03	40000.00
374580	2017-07-05 02:22:00+03	141300.00
374583	2017-08-03 23:18:00+03	89600.00
3745A9	2017-07-17 04:16:00+03	62600.00
3745AB	2017-07-03 04:17:00+03	111600.00
374619	2017-07-01 00:18:00+03	23200.00
374697	2017-07-13 13:03:00+03	84100.00
374728	2017-07-10 18:14:00+03	68100.00
374729	2017-08-07 12:25:00+03	42600.00
37472C	2017-08-03 19:52:00+03	21800.00
37473E	2017-06-30 20:51:00+03	13000.00
374758	2017-08-09 06:05:00+03	44300.00
3747A2	2017-07-12 06:12:00+03	55000.00
3747C9	2017-07-14 21:29:00+03	47600.00
3747CB	2017-07-30 08:19:00+03	27300.00
374828	2017-08-06 12:40:00+03	40800.00
374838	2017-08-14 10:19:00+03	28800.00
374845	2017-07-23 22:08:00+03	72800.00
374877	2017-07-25 10:13:00+03	26000.00
37487B	2017-07-23 17:05:00+03	102100.00
3748E8	2017-07-15 07:17:00+03	10600.00
3748EF	2017-08-15 17:08:00+03	37900.00
374992	2017-08-14 10:30:00+03	75300.00
37499B	2017-07-09 05:06:00+03	25200.00
3749DC	2017-07-14 16:43:00+03	112200.00
374AD2	2017-06-30 15:15:00+03	171800.00
374B07	2017-07-15 00:53:00+03	48500.00
374C8B	2017-08-04 11:28:00+03	6900.00
374D04	2017-08-13 14:11:00+03	38400.00
374EF4	2017-07-26 22:55:00+03	26600.00
374F10	2017-07-08 18:02:00+03	56200.00
374F19	2017-07-22 21:26:00+03	26000.00
374F54	2017-07-01 21:42:00+03	26000.00
374F71	2017-08-02 18:42:00+03	89000.00
374F95	2017-07-23 20:42:00+03	53800.00
374FC7	2017-08-11 15:18:00+03	8000.00
375026	2017-07-11 16:16:00+03	146800.00
375029	2017-07-23 16:24:00+03	12600.00
37504C	2017-07-10 06:05:00+03	123000.00
375056	2017-07-16 20:45:00+03	40800.00
3750B5	2017-07-14 12:32:00+03	12400.00
3750EB	2017-07-05 21:57:00+03	12100.00
3751C9	2017-08-10 00:06:00+03	134700.00
3751E9	2017-07-08 17:23:00+03	35200.00
375267	2017-07-12 20:57:00+03	26000.00
37526E	2017-08-14 06:33:00+03	27300.00
37529E	2017-07-22 23:40:00+03	70100.00
3752F1	2017-07-10 16:27:00+03	148200.00
375365	2017-08-03 19:26:00+03	57800.00
3753CB	2017-08-08 00:43:00+03	58700.00
3753E6	2017-07-20 03:56:00+03	95200.00
375469	2017-08-07 14:47:00+03	21800.00
3755A9	2017-08-07 22:38:00+03	398500.00
3755B2	2017-07-26 11:14:00+03	126200.00
3755EC	2017-07-10 00:08:00+03	55800.00
375640	2017-08-02 15:39:00+03	131100.00
375682	2017-07-05 20:17:00+03	149300.00
375708	2017-07-11 06:17:00+03	12600.00
375711	2017-07-15 14:35:00+03	37900.00
37575A	2017-08-11 08:19:00+03	12400.00
37576C	2017-07-20 09:57:00+03	20200.00
375798	2017-07-14 00:39:00+03	39800.00
37583F	2017-06-30 22:55:00+03	30200.00
3758EB	2017-08-01 04:05:00+03	6300.00
3758FA	2017-07-27 18:49:00+03	30200.00
375902	2017-08-09 16:47:00+03	40600.00
375914	2017-08-14 17:37:00+03	56000.00
375939	2017-07-16 22:31:00+03	19600.00
375958	2017-07-30 20:12:00+03	18600.00
375965	2017-07-05 01:26:00+03	46800.00
37596E	2017-07-13 16:19:00+03	61800.00
375984	2017-07-09 03:15:00+03	26300.00
3759B0	2017-07-18 09:56:00+03	56000.00
3759D4	2017-08-13 01:31:00+03	37400.00
3759FC	2017-07-06 09:05:00+03	84000.00
375A23	2017-08-07 02:10:00+03	26700.00
375AA4	2017-07-13 10:37:00+03	50200.00
375ACA	2017-07-22 02:51:00+03	146300.00
375B20	2017-07-20 05:04:00+03	67000.00
375BA3	2017-07-16 02:03:00+03	26700.00
375BBF	2017-08-15 17:41:00+03	9200.00
375BC4	2017-08-08 06:59:00+03	111900.00
375BD0	2017-08-12 17:57:00+03	39600.00
375BDD	2017-08-01 19:35:00+03	50700.00
375BF5	2017-08-11 03:27:00+03	37900.00
375BFF	2017-07-22 23:04:00+03	90800.00
375C0D	2017-07-28 16:06:00+03	55800.00
375C2F	2017-07-10 17:15:00+03	72400.00
375C3A	2017-07-15 08:55:00+03	56000.00
375C49	2017-07-04 05:20:00+03	68800.00
375C7C	2017-08-07 06:58:00+03	23600.00
375CBF	2017-08-08 23:49:00+03	233800.00
375CE8	2017-07-12 15:03:00+03	56000.00
375CED	2017-07-02 23:00:00+03	66600.00
375D24	2017-07-15 21:37:00+03	84100.00
375D9D	2017-07-25 21:55:00+03	57800.00
375DAB	2017-07-04 22:50:00+03	36700.00
375DE4	2017-07-09 08:00:00+03	493200.00
375DF1	2017-07-16 14:05:00+03	315200.00
375E02	2017-07-04 11:30:00+03	72400.00
375E32	2017-08-11 16:41:00+03	50400.00
375E88	2017-07-23 18:20:00+03	22000.00
375E8D	2017-07-30 04:23:00+03	19600.00
375EA7	2017-07-03 11:24:00+03	44700.00
375EC0	2017-07-30 15:38:00+03	260300.00
375EC4	2017-07-12 06:07:00+03	46200.00
375F38	2017-08-05 17:29:00+03	123000.00
375FA9	2017-07-02 12:09:00+03	122800.00
376036	2017-07-25 11:36:00+03	25400.00
376071	2017-07-10 04:35:00+03	29600.00
376075	2017-07-17 04:43:00+03	59400.00
376092	2017-06-25 18:03:00+03	57800.00
3760B0	2017-07-30 16:53:00+03	46400.00
3760D6	2017-07-16 10:00:00+03	25100.00
376166	2017-07-09 13:36:00+03	46000.00
37620E	2017-07-26 07:12:00+03	143700.00
3762AA	2017-07-06 05:31:00+03	58800.00
37635E	2017-07-12 22:54:00+03	54800.00
376393	2017-07-23 03:42:00+03	100600.00
376395	2017-07-04 11:31:00+03	30200.00
376453	2017-07-02 22:34:00+03	135600.00
376524	2017-08-06 11:53:00+03	73500.00
37658F	2017-08-01 21:50:00+03	49900.00
376590	2017-07-12 18:10:00+03	111600.00
376606	2017-07-15 20:24:00+03	55800.00
3766A9	2017-08-02 13:33:00+03	20000.00
37671E	2017-08-15 14:23:00+03	46000.00
3767C6	2017-07-14 15:20:00+03	83000.00
376801	2017-07-08 02:18:00+03	28000.00
376876	2017-08-15 04:43:00+03	20200.00
376880	2017-08-11 00:46:00+03	30100.00
37691C	2017-07-06 05:06:00+03	26000.00
376939	2017-08-07 04:31:00+03	174400.00
376A01	2017-07-22 16:12:00+03	21400.00
376A3C	2017-07-26 01:18:00+03	93000.00
376A42	2017-07-20 13:22:00+03	30900.00
376B80	2017-08-05 19:12:00+03	54600.00
376BBC	2017-08-05 13:10:00+03	69200.00
376BD7	2017-08-14 17:34:00+03	112000.00
376C49	2017-07-13 08:52:00+03	10800.00
376C4D	2017-07-18 05:37:00+03	70700.00
376C82	2017-07-12 02:30:00+03	81700.00
376CF7	2017-07-11 11:59:00+03	132900.00
376D2C	2017-07-01 06:17:00+03	25800.00
376DB1	2017-07-15 11:04:00+03	56000.00
376DF7	2017-07-20 18:13:00+03	70600.00
376E42	2017-07-19 02:22:00+03	14000.00
376E4D	2017-08-03 05:58:00+03	46400.00
376E95	2017-07-05 01:37:00+03	27800.00
376EE4	2017-07-14 05:46:00+03	67600.00
376F00	2017-06-28 20:26:00+03	23200.00
376F60	2017-08-15 15:48:00+03	76900.00
376F67	2017-07-16 22:27:00+03	386300.00
376FCE	2017-07-12 08:55:00+03	36200.00
376FE7	2017-07-25 22:26:00+03	55000.00
376FF2	2017-08-06 17:06:00+03	52000.00
37706D	2017-07-12 08:41:00+03	258400.00
377074	2017-07-05 00:21:00+03	137300.00
377079	2017-07-28 18:07:00+03	13000.00
3770A6	2017-06-27 04:41:00+03	20400.00
3770CE	2017-07-08 13:13:00+03	21400.00
377122	2017-07-07 09:57:00+03	38600.00
377151	2017-07-31 13:43:00+03	56000.00
3771AF	2017-07-02 07:40:00+03	88100.00
3771B2	2017-07-04 16:09:00+03	309500.00
3771CC	2017-07-30 02:38:00+03	90800.00
377213	2017-07-08 13:04:00+03	26800.00
377246	2017-07-05 15:21:00+03	93900.00
377306	2017-07-10 13:57:00+03	67600.00
37735F	2017-07-30 13:09:00+03	47100.00
3773B0	2017-07-06 20:31:00+03	213200.00
3773BC	2017-07-13 01:47:00+03	23200.00
37748F	2017-07-05 18:11:00+03	40600.00
3774DA	2017-06-30 10:50:00+03	45200.00
3774F1	2017-07-29 07:33:00+03	46500.00
37750F	2017-07-17 04:38:00+03	132800.00
37756E	2017-07-04 06:42:00+03	22600.00
377608	2017-07-04 19:17:00+03	8400.00
3776A7	2017-07-03 06:03:00+03	47000.00
3776C4	2017-08-10 05:34:00+03	73300.00
37770D	2017-07-03 23:03:00+03	38800.00
377725	2017-08-07 23:31:00+03	16400.00
377743	2017-07-25 08:42:00+03	91300.00
377793	2017-08-09 12:05:00+03	40400.00
3777F4	2017-07-30 08:53:00+03	70700.00
37786A	2017-08-04 11:11:00+03	27900.00
3778A1	2017-07-18 01:18:00+03	22600.00
3778F4	2017-07-06 10:06:00+03	68800.00
3778F7	2017-08-02 01:32:00+03	19600.00
3778FE	2017-07-15 04:46:00+03	105600.00
377911	2017-08-06 09:59:00+03	60900.00
37791D	2017-07-12 00:21:00+03	175300.00
377982	2017-07-27 12:11:00+03	60200.00
3779A4	2017-07-13 21:45:00+03	53700.00
3779C5	2017-07-12 21:31:00+03	48500.00
3779D4	2017-08-13 20:07:00+03	6000.00
377A19	2017-07-28 02:11:00+03	56000.00
377A34	2017-07-30 12:26:00+03	10100.00
377A9D	2017-07-30 03:43:00+03	40100.00
377AC3	2017-08-14 18:57:00+03	112600.00
377AFB	2017-08-03 00:36:00+03	63200.00
377B30	2017-07-22 06:10:00+03	28000.00
377B39	2017-07-23 20:25:00+03	147500.00
377B3A	2017-07-18 20:19:00+03	100600.00
377B56	2017-07-03 20:13:00+03	31400.00
377B9D	2017-07-28 18:16:00+03	492000.00
377BC4	2017-07-19 00:34:00+03	83300.00
377C0E	2017-08-03 17:39:00+03	22000.00
377C3B	2017-08-05 16:19:00+03	194200.00
377C3F	2017-08-08 17:42:00+03	34000.00
377C83	2017-07-12 09:30:00+03	72400.00
377CA7	2017-07-27 09:45:00+03	75600.00
377CE8	2017-08-13 15:03:00+03	12600.00
377CFC	2017-07-14 12:03:00+03	69600.00
377D3C	2017-07-13 02:52:00+03	187600.00
377D88	2017-07-27 04:00:00+03	82900.00
377DD5	2017-07-05 13:57:00+03	78600.00
377E12	2017-08-05 03:54:00+03	190400.00
377E21	2017-07-22 00:35:00+03	50600.00
377E22	2017-08-05 03:50:00+03	18100.00
377E5A	2017-07-11 22:32:00+03	141800.00
377EC4	2017-08-09 00:48:00+03	27200.00
377F6B	2017-07-09 19:16:00+03	56600.00
377FE7	2017-08-02 16:26:00+03	70700.00
378048	2017-08-06 06:47:00+03	81300.00
378073	2017-08-08 23:22:00+03	16400.00
378092	2017-08-09 22:09:00+03	92800.00
378095	2017-08-02 09:45:00+03	65500.00
3780F2	2017-07-26 17:36:00+03	21400.00
37816D	2017-07-20 23:39:00+03	46800.00
37816F	2017-07-30 09:48:00+03	35300.00
378199	2017-08-08 09:32:00+03	25100.00
37822D	2017-07-14 13:06:00+03	54400.00
378231	2017-07-14 01:23:00+03	43100.00
378288	2017-07-13 00:04:00+03	64400.00
3782D9	2017-08-03 12:04:00+03	37900.00
37831F	2017-08-09 05:53:00+03	36200.00
378345	2017-07-25 22:25:00+03	131100.00
378381	2017-08-12 18:21:00+03	162600.00
3783D6	2017-08-03 21:27:00+03	52700.00
37844B	2017-08-01 19:51:00+03	142400.00
3784EC	2017-08-01 16:46:00+03	57700.00
3784FC	2017-07-12 16:41:00+03	12400.00
378516	2017-07-07 02:48:00+03	47500.00
378581	2017-07-03 21:33:00+03	92800.00
378595	2017-07-23 14:51:00+03	186900.00
3785D5	2017-07-16 21:16:00+03	114800.00
378610	2017-08-03 07:03:00+03	17800.00
3786A2	2017-08-12 14:30:00+03	6400.00
378713	2017-07-05 08:12:00+03	16800.00
378749	2017-08-07 02:00:00+03	28000.00
3787CE	2017-07-16 18:00:00+03	133200.00
3787D0	2017-07-28 16:47:00+03	97200.00
3787D2	2017-07-07 09:09:00+03	31400.00
378817	2017-07-15 10:42:00+03	56600.00
37884F	2017-07-13 13:32:00+03	241300.00
378865	2017-08-15 08:42:00+03	22400.00
3788AF	2017-07-23 05:51:00+03	64800.00
37891D	2017-07-23 06:08:00+03	8400.00
37893E	2017-07-03 03:12:00+03	179400.00
37894D	2017-08-09 08:47:00+03	88800.00
37895B	2017-08-14 12:52:00+03	53600.00
3789C8	2017-08-05 13:53:00+03	38600.00
378A0A	2017-08-04 10:17:00+03	65000.00
378A49	2017-07-27 13:23:00+03	86100.00
378A52	2017-07-31 20:52:00+03	133100.00
378A95	2017-07-09 02:39:00+03	65900.00
378AEC	2017-08-13 03:17:00+03	27300.00
378B4C	2017-07-21 13:22:00+03	24400.00
378B5B	2017-07-20 19:36:00+03	65100.00
378C62	2017-08-05 10:28:00+03	105100.00
378D6F	2017-07-25 00:08:00+03	36000.00
378D83	2017-07-27 23:19:00+03	51400.00
378DD4	2017-07-28 09:13:00+03	246000.00
378DDE	2017-08-01 08:03:00+03	7300.00
378E15	2017-07-05 17:22:00+03	13600.00
378E67	2017-08-10 00:30:00+03	6200.00
378E6E	2017-07-10 06:35:00+03	24400.00
378E85	2017-07-29 08:11:00+03	56900.00
378ECD	2017-07-13 17:03:00+03	199600.00
378F4B	2017-07-09 04:23:00+03	56000.00
378F57	2017-07-08 00:57:00+03	100600.00
378F79	2017-08-08 20:20:00+03	272300.00
378FA2	2017-07-30 13:26:00+03	141200.00
37901F	2017-07-18 15:15:00+03	16800.00
379026	2017-07-18 06:28:00+03	46300.00
379038	2017-07-13 03:21:00+03	202400.00
379084	2017-07-14 17:17:00+03	89700.00
3790AB	2017-07-16 07:05:00+03	136200.00
3790E3	2017-08-13 11:47:00+03	42800.00
37912D	2017-08-04 20:59:00+03	92900.00
379132	2017-07-16 00:38:00+03	111600.00
379176	2017-07-11 07:48:00+03	18300.00
379178	2017-08-09 08:27:00+03	48800.00
379184	2017-07-22 11:39:00+03	28300.00
3791BD	2017-06-28 07:28:00+03	92800.00
37921A	2017-07-26 05:25:00+03	38600.00
37922C	2017-08-05 18:41:00+03	39800.00
37923F	2017-07-02 13:42:00+03	112000.00
37924C	2017-06-30 15:32:00+03	147700.00
379266	2017-07-24 14:06:00+03	104600.00
379299	2017-08-13 15:52:00+03	12600.00
37931B	2017-08-12 01:29:00+03	52900.00
379321	2017-07-18 22:12:00+03	34000.00
379333	2017-08-14 07:24:00+03	109200.00
379345	2017-07-13 04:55:00+03	123900.00
379359	2017-07-08 01:54:00+03	113000.00
379365	2017-07-23 03:00:00+03	34000.00
379386	2017-07-08 02:39:00+03	36200.00
3793A0	2017-07-27 19:48:00+03	88800.00
3793B5	2017-07-22 22:20:00+03	102100.00
37944E	2017-07-10 05:49:00+03	91500.00
37954A	2017-07-04 12:40:00+03	16400.00
379556	2017-07-13 04:39:00+03	369000.00
37958C	2017-08-04 14:53:00+03	51900.00
379595	2017-08-03 01:41:00+03	177600.00
379596	2017-07-09 12:00:00+03	12600.00
3795B5	2017-07-23 06:40:00+03	28000.00
379623	2017-06-29 21:28:00+03	11700.00
379664	2017-07-01 17:11:00+03	134600.00
3796A1	2017-07-15 01:26:00+03	65900.00
37973D	2017-07-23 02:05:00+03	67200.00
379766	2017-07-13 09:44:00+03	65200.00
3797A6	2017-08-11 00:29:00+03	95300.00
379837	2017-07-27 22:54:00+03	114500.00
379849	2017-07-07 22:06:00+03	76600.00
37987F	2017-08-04 14:27:00+03	329200.00
3798C9	2017-08-14 18:38:00+03	92900.00
3798EE	2017-07-13 14:51:00+03	8400.00
379935	2017-06-30 19:32:00+03	30000.00
37999C	2017-07-27 17:28:00+03	72400.00
3799CE	2017-08-13 03:35:00+03	152700.00
3799DA	2017-07-16 13:54:00+03	52100.00
379A07	2017-08-14 04:44:00+03	46200.00
379A09	2017-07-17 03:41:00+03	55600.00
379A52	2017-08-12 21:04:00+03	57600.00
379A96	2017-08-15 06:36:00+03	12000.00
379ABF	2017-07-25 17:23:00+03	90800.00
379B0E	2017-08-02 07:46:00+03	86800.00
379B66	2017-07-06 15:25:00+03	44600.00
379BF2	2017-07-12 12:05:00+03	61500.00
379BFE	2017-08-11 20:32:00+03	25000.00
379C00	2017-07-24 05:36:00+03	46800.00
379C22	2017-07-11 09:49:00+03	59800.00
379C26	2017-07-11 22:53:00+03	24400.00
379C3B	2017-08-05 19:10:00+03	40600.00
379C4A	2017-07-22 09:02:00+03	8400.00
379CAB	2017-08-12 21:24:00+03	272300.00
379CF2	2017-07-27 07:37:00+03	23200.00
379CFD	2017-07-27 12:20:00+03	24400.00
379D77	2017-07-15 23:52:00+03	288600.00
379DBB	2017-07-07 11:21:00+03	39800.00
379F3A	2017-07-30 19:19:00+03	100600.00
379F4B	2017-08-07 05:38:00+03	6700.00
379FBF	2017-07-25 10:21:00+03	90300.00
37A05E	2017-07-24 00:30:00+03	127100.00
37A063	2017-07-02 17:12:00+03	399600.00
37A19F	2017-07-13 03:45:00+03	75200.00
37A1D1	2017-07-18 21:42:00+03	133200.00
37A1E9	2017-07-31 08:01:00+03	23400.00
37A232	2017-07-07 05:55:00+03	119500.00
37A25D	2017-07-16 04:42:00+03	136700.00
37A282	2017-08-12 04:45:00+03	31100.00
37A2AF	2017-08-04 20:56:00+03	43000.00
37A30D	2017-07-16 12:30:00+03	61100.00
37A3AD	2017-08-06 14:18:00+03	23600.00
37A3C5	2017-07-06 13:13:00+03	26000.00
37A3CE	2017-07-30 23:47:00+03	62600.00
37A49B	2017-07-28 10:51:00+03	85400.00
37A4D3	2017-08-01 00:46:00+03	53400.00
37A548	2017-08-08 20:57:00+03	245000.00
37A561	2017-07-27 19:00:00+03	18000.00
37A661	2017-07-26 06:57:00+03	28800.00
37A6A6	2017-07-26 12:53:00+03	13400.00
37A6ED	2017-07-08 15:21:00+03	39300.00
37A705	2017-07-30 21:10:00+03	40100.00
37A70C	2017-08-01 00:28:00+03	65500.00
37A749	2017-07-06 01:28:00+03	75600.00
37A7A2	2017-07-28 14:01:00+03	112600.00
37A7D7	2017-07-05 03:25:00+03	37200.00
37A812	2017-07-16 18:24:00+03	168000.00
37A900	2017-08-02 14:04:00+03	24400.00
37A94B	2017-07-07 23:10:00+03	22000.00
37A94C	2017-07-19 05:34:00+03	21400.00
37A99D	2017-08-10 11:44:00+03	134400.00
37A9D1	2017-07-26 22:08:00+03	99200.00
37AA0F	2017-07-08 19:38:00+03	75600.00
37AA13	2017-07-13 07:09:00+03	6800.00
37AA42	2017-07-30 04:46:00+03	42800.00
37AA4E	2017-08-03 16:45:00+03	46000.00
37AAB4	2017-07-15 15:48:00+03	40600.00
37AB08	2017-07-22 01:33:00+03	55100.00
37AB71	2017-07-03 05:52:00+03	46200.00
37ABEC	2017-07-07 00:49:00+03	64800.00
37AD46	2017-08-07 14:38:00+03	278600.00
37ADA9	2017-08-10 00:34:00+03	171000.00
37ADE4	2017-07-13 22:36:00+03	54400.00
37AE2C	2017-08-05 18:49:00+03	64700.00
37AE5C	2017-08-10 20:56:00+03	170200.00
37AE7A	2017-07-15 19:43:00+03	72200.00
37AEE4	2017-07-30 12:36:00+03	311200.00
37AF01	2017-07-05 21:02:00+03	29600.00
37AF03	2017-07-16 12:08:00+03	26800.00
37AF12	2017-06-30 11:21:00+03	28000.00
37AF32	2017-08-04 23:41:00+03	23600.00
37AF46	2017-07-02 20:46:00+03	112000.00
37AFA6	2017-07-01 19:24:00+03	246000.00
37B026	2017-06-27 21:12:00+03	15400.00
37B084	2017-07-23 04:25:00+03	26600.00
37B0EB	2017-06-27 21:30:00+03	101200.00
37B184	2017-08-08 01:48:00+03	372600.00
37B1E3	2017-07-27 19:33:00+03	114300.00
37B1E5	2017-07-17 17:40:00+03	76100.00
37B1EC	2017-07-20 13:34:00+03	64300.00
37B297	2017-08-02 01:14:00+03	153100.00
37B2A7	2017-07-06 15:09:00+03	23200.00
37B2EA	2017-07-22 22:46:00+03	201200.00
37B301	2017-08-12 02:55:00+03	286600.00
37B3A3	2017-07-19 02:35:00+03	30400.00
37B3A6	2017-08-02 07:56:00+03	91800.00
37B3EA	2017-07-18 22:20:00+03	28300.00
37B44A	2017-07-02 21:56:00+03	46300.00
37B455	2017-07-14 03:47:00+03	98100.00
37B4DF	2017-07-24 21:05:00+03	28800.00
37B4F5	2017-07-25 00:12:00+03	80000.00
37B540	2017-07-25 10:09:00+03	58900.00
37B553	2017-08-12 20:45:00+03	87000.00
37B562	2017-07-31 06:28:00+03	116400.00
37B572	2017-08-02 16:55:00+03	20600.00
37B573	2017-07-15 15:27:00+03	36000.00
37B578	2017-07-27 13:19:00+03	66800.00
37B5DC	2017-07-24 04:20:00+03	36200.00
37B615	2017-08-12 07:17:00+03	23600.00
37B647	2017-08-12 05:22:00+03	70500.00
37B650	2017-07-16 02:05:00+03	23200.00
37B687	2017-07-13 19:50:00+03	75600.00
37B69D	2017-07-30 22:00:00+03	28000.00
37B6FF	2017-07-08 14:35:00+03	123000.00
37B82F	2017-08-01 01:49:00+03	167400.00
37B837	2017-07-14 22:27:00+03	30200.00
37B861	2017-07-30 09:28:00+03	52800.00
37B872	2017-07-11 08:03:00+03	7400.00
37B884	2017-08-08 22:33:00+03	182200.00
37B8A4	2017-07-07 23:41:00+03	21400.00
37B8CD	2017-07-02 04:58:00+03	20400.00
37B91A	2017-07-26 09:49:00+03	257600.00
37B94D	2017-07-27 08:39:00+03	61500.00
37B99B	2017-07-07 14:06:00+03	25600.00
37B9FF	2017-07-25 23:25:00+03	131100.00
37BA6C	2017-08-10 09:52:00+03	67000.00
37BA76	2017-07-18 22:54:00+03	230000.00
37BA88	2017-06-28 05:41:00+03	38600.00
37BAE1	2017-08-08 16:13:00+03	40800.00
37BAE3	2017-08-12 20:43:00+03	116800.00
37BB15	2017-07-03 02:22:00+03	69600.00
37BB39	2017-07-13 02:13:00+03	58600.00
37BBC1	2017-06-25 14:24:00+03	134400.00
37BBC2	2017-08-02 17:24:00+03	29500.00
37BBE8	2017-07-24 03:44:00+03	19600.00
37BC1A	2017-07-30 07:49:00+03	48500.00
37BC39	2017-08-13 00:14:00+03	271200.00
37BC3E	2017-08-07 17:00:00+03	75600.00
37BCC9	2017-07-19 04:04:00+03	60200.00
37BCED	2017-07-02 04:50:00+03	13800.00
37BD36	2017-07-15 15:36:00+03	35200.00
37BD48	2017-07-20 04:28:00+03	48700.00
37BDA0	2017-08-08 16:54:00+03	26000.00
37BE61	2017-08-14 22:52:00+03	27900.00
37BEC4	2017-06-24 21:44:00+03	26800.00
37BEC5	2017-08-03 01:54:00+03	89700.00
37BEDC	2017-08-08 11:31:00+03	135600.00
37BF15	2017-07-21 15:17:00+03	136800.00
37BF63	2017-07-26 02:41:00+03	49400.00
37BF6D	2017-08-02 13:43:00+03	136800.00
37BFAF	2017-07-23 21:01:00+03	62100.00
37BFB7	2017-07-02 23:36:00+03	87400.00
37BFE4	2017-08-12 12:03:00+03	67900.00
37C019	2017-07-20 10:08:00+03	42000.00
37C034	2017-08-14 23:36:00+03	76300.00
37C17D	2017-08-12 16:04:00+03	266400.00
37C196	2017-08-14 22:32:00+03	65300.00
37C20B	2017-07-30 09:05:00+03	99700.00
37C2AD	2017-07-15 02:08:00+03	28000.00
37C2BB	2017-07-29 12:36:00+03	72300.00
37C2DC	2017-08-15 13:10:00+03	27400.00
37C338	2017-07-24 22:07:00+03	103400.00
37C34B	2017-07-11 15:16:00+03	14800.00
37C421	2017-07-01 11:25:00+03	396600.00
37C43B	2017-07-07 11:03:00+03	36200.00
37C4A7	2017-07-21 05:33:00+03	195900.00
37C4C6	2017-07-29 04:26:00+03	134400.00
37C4D9	2017-07-04 08:40:00+03	38200.00
37C4DA	2017-07-17 03:23:00+03	23200.00
37C50C	2017-08-15 08:47:00+03	25200.00
37C519	2017-08-07 10:51:00+03	113000.00
37C52A	2017-08-14 16:49:00+03	13400.00
37C59D	2017-07-23 11:17:00+03	46000.00
37C5C0	2017-07-02 06:50:00+03	23600.00
37C5F3	2017-07-31 20:53:00+03	16400.00
37C637	2017-08-14 18:50:00+03	46400.00
37C668	2017-07-10 12:28:00+03	23600.00
37C692	2017-07-21 20:32:00+03	44000.00
37C772	2017-07-26 06:07:00+03	77200.00
37C7C0	2017-07-17 01:30:00+03	49200.00
37C7CF	2017-06-30 03:39:00+03	6200.00
37C7EA	2017-07-22 10:27:00+03	67900.00
37C849	2017-07-12 02:29:00+03	128600.00
37C883	2017-07-14 06:42:00+03	36200.00
37C894	2017-07-27 16:26:00+03	6700.00
37C9AF	2017-08-09 04:50:00+03	126300.00
37C9C0	2017-07-01 21:09:00+03	32800.00
37C9D7	2017-07-05 03:41:00+03	114100.00
37C9DC	2017-07-01 13:30:00+03	128000.00
37C9E9	2017-08-04 05:29:00+03	96300.00
37CA15	2017-07-20 11:01:00+03	131600.00
37CA52	2017-08-02 03:56:00+03	81900.00
37CB84	2017-07-25 16:45:00+03	46400.00
37CC59	2017-08-10 18:00:00+03	6700.00
37CC71	2017-08-04 13:19:00+03	234100.00
37CC7B	2017-08-02 12:19:00+03	26000.00
37CCA4	2017-08-10 08:57:00+03	53000.00
37CD13	2017-08-10 06:25:00+03	93600.00
37CD32	2017-07-10 15:34:00+03	159800.00
37CD82	2017-07-05 08:19:00+03	348100.00
37CDC2	2017-07-27 03:11:00+03	7400.00
37CDD8	2017-07-19 13:14:00+03	14400.00
37CE1D	2017-08-13 06:43:00+03	48800.00
37CE21	2017-07-20 00:15:00+03	31600.00
37CE4B	2017-07-26 08:53:00+03	83000.00
37CEB6	2017-08-13 19:36:00+03	23200.00
37CF2F	2017-07-30 01:02:00+03	46400.00
37CFAC	2017-07-31 11:37:00+03	27300.00
37CFD5	2017-08-04 17:02:00+03	283700.00
37CFDA	2017-07-09 18:38:00+03	49200.00
37CFF8	2017-07-05 16:22:00+03	28800.00
37D047	2017-08-01 01:28:00+03	17800.00
37D049	2017-07-31 18:37:00+03	55800.00
37D057	2017-07-16 05:07:00+03	29800.00
37D072	2017-08-03 05:54:00+03	73300.00
37D0D3	2017-07-20 09:19:00+03	112000.00
37D102	2017-07-14 09:14:00+03	55800.00
37D126	2017-07-10 13:43:00+03	136800.00
37D128	2017-07-10 15:49:00+03	168000.00
37D146	2017-07-15 10:32:00+03	246000.00
37D1A7	2017-07-16 16:41:00+03	24800.00
37D1C2	2017-07-14 00:23:00+03	47100.00
37D2CF	2017-07-15 07:01:00+03	65000.00
37D321	2017-07-05 11:58:00+03	46500.00
37D32D	2017-06-30 16:03:00+03	6000.00
37D330	2017-07-09 05:27:00+03	62400.00
37D39F	2017-08-05 17:40:00+03	83100.00
37D3AB	2017-08-02 23:03:00+03	40800.00
37D3B5	2017-06-29 22:24:00+03	124200.00
37D432	2017-06-27 16:59:00+03	118000.00
37D45A	2017-08-10 09:05:00+03	14800.00
37D45C	2017-07-05 15:38:00+03	99800.00
37D468	2017-08-03 14:37:00+03	25100.00
37D4C1	2017-08-05 16:51:00+03	18900.00
37D4ED	2017-08-11 12:26:00+03	61300.00
37D521	2017-07-26 12:22:00+03	70100.00
37D553	2017-08-11 08:14:00+03	27200.00
37D5B7	2017-07-31 19:16:00+03	95000.00
37D61F	2017-07-13 21:41:00+03	44800.00
37D63E	2017-07-03 08:23:00+03	100200.00
37D65E	2017-07-21 12:14:00+03	131100.00
37D67C	2017-07-09 23:22:00+03	92400.00
37D6A1	2017-07-12 15:19:00+03	116400.00
37D72B	2017-07-13 17:46:00+03	24400.00
37D73B	2017-07-26 16:15:00+03	50000.00
37D7AF	2017-07-02 05:50:00+03	81300.00
37D80B	2017-07-17 16:52:00+03	43200.00
37D843	2017-08-01 16:27:00+03	28000.00
37D865	2017-06-30 11:12:00+03	20500.00
37D8B6	2017-07-25 18:23:00+03	240500.00
37D91E	2017-08-07 22:10:00+03	85000.00
37D923	2017-07-29 04:54:00+03	62600.00
37D92A	2017-08-01 05:16:00+03	73400.00
37D934	2017-07-23 12:07:00+03	73600.00
37DA0D	2017-08-06 15:46:00+03	32800.00
37DA77	2017-07-05 12:29:00+03	169900.00
37DBBE	2017-07-11 07:19:00+03	44000.00
37DBD5	2017-07-23 11:56:00+03	12600.00
37DC0B	2017-08-10 14:58:00+03	193300.00
37DC2D	2017-07-30 01:30:00+03	67700.00
37DC35	2017-08-02 08:22:00+03	71600.00
37DCCE	2017-07-06 09:44:00+03	95700.00
37DCF2	2017-08-07 06:43:00+03	204500.00
37DDF8	2017-08-11 21:14:00+03	113700.00
37DDF9	2017-08-14 07:44:00+03	102300.00
37DDFA	2017-07-01 11:50:00+03	26000.00
37DDFC	2017-07-19 01:32:00+03	32800.00
37DF77	2017-08-04 22:32:00+03	14400.00
37DF93	2017-08-07 02:44:00+03	100600.00
37DFA6	2017-07-27 03:43:00+03	6000.00
37DFC1	2017-07-04 06:47:00+03	47200.00
37DFF6	2017-07-06 17:49:00+03	78800.00
37DFFB	2017-08-10 16:34:00+03	79600.00
37E020	2017-08-15 06:44:00+03	294400.00
37E063	2017-07-18 07:26:00+03	114400.00
37E095	2017-07-08 19:49:00+03	49200.00
37E09D	2017-08-05 18:48:00+03	51200.00
37E112	2017-07-24 06:09:00+03	42800.00
37E15E	2017-07-10 01:30:00+03	60400.00
37E181	2017-07-29 00:18:00+03	88300.00
37E1CB	2017-07-25 06:48:00+03	98200.00
37E1FF	2017-07-19 20:00:00+03	258400.00
37E20B	2017-07-10 01:55:00+03	28000.00
37E2B6	2017-08-03 07:50:00+03	117600.00
37E30A	2017-08-13 18:46:00+03	40300.00
37E38B	2017-07-07 10:03:00+03	14000.00
37E38E	2017-07-08 03:40:00+03	46200.00
37E42C	2017-07-18 23:47:00+03	122000.00
37E464	2017-08-10 03:57:00+03	6800.00
37E531	2017-06-28 15:26:00+03	58200.00
37E541	2017-08-12 05:06:00+03	34100.00
37E54F	2017-07-13 13:33:00+03	41400.00
37E55E	2017-08-02 20:49:00+03	11200.00
37E57C	2017-07-17 06:47:00+03	9800.00
37E59F	2017-08-13 06:13:00+03	94200.00
37E5B8	2017-07-20 06:05:00+03	7400.00
37E5EA	2017-07-31 08:53:00+03	67600.00
37E5EB	2017-08-13 04:26:00+03	111600.00
37E620	2017-07-28 21:30:00+03	166100.00
37E644	2017-07-04 20:34:00+03	34000.00
37E645	2017-07-25 07:41:00+03	156500.00
37E65E	2017-08-10 17:30:00+03	51300.00
37E694	2017-08-05 03:03:00+03	210200.00
37E6AE	2017-08-14 12:45:00+03	133200.00
37E6C2	2017-07-15 04:35:00+03	122700.00
37E887	2017-08-15 05:49:00+03	64400.00
37E88A	2017-08-05 16:54:00+03	46400.00
37E8AE	2017-08-12 01:32:00+03	40000.00
37E8F3	2017-07-09 08:02:00+03	54800.00
37E92E	2017-07-01 11:36:00+03	66800.00
37E985	2017-08-07 01:37:00+03	12600.00
37E999	2017-07-10 14:52:00+03	86400.00
37E9BA	2017-07-16 10:49:00+03	47400.00
37EA55	2017-08-11 16:54:00+03	147700.00
37EAD4	2017-07-28 06:35:00+03	23200.00
37EB68	2017-08-08 04:22:00+03	29600.00
37EB6F	2017-07-19 06:17:00+03	290500.00
37EC01	2017-07-11 22:44:00+03	15000.00
37EC36	2017-07-07 07:36:00+03	242400.00
37EC46	2017-07-30 16:44:00+03	133100.00
37EC65	2017-07-17 12:23:00+03	75600.00
37EC7B	2017-07-25 17:50:00+03	26000.00
37ECBC	2017-07-14 14:16:00+03	34000.00
37ED0A	2017-07-05 18:22:00+03	131600.00
37ED1C	2017-07-17 22:50:00+03	269200.00
37ED52	2017-07-03 14:03:00+03	65400.00
37ED9B	2017-07-14 11:10:00+03	133200.00
37EDB4	2017-08-08 12:54:00+03	24400.00
37EE29	2017-08-07 20:09:00+03	46800.00
37EF47	2017-07-19 02:39:00+03	150600.00
37EF9E	2017-08-01 01:06:00+03	399600.00
37EFD8	2017-07-05 13:24:00+03	6000.00
37EFF1	2017-07-05 15:48:00+03	82900.00
37F050	2017-07-08 04:33:00+03	16400.00
37F06C	2017-07-16 11:09:00+03	483400.00
37F086	2017-07-16 19:25:00+03	33400.00
37F1E4	2017-07-30 22:03:00+03	75300.00
37F233	2017-07-18 05:59:00+03	30400.00
37F23C	2017-08-14 21:34:00+03	72400.00
37F256	2017-08-10 17:40:00+03	53600.00
37F272	2017-07-10 06:35:00+03	88900.00
37F27F	2017-07-04 09:02:00+03	6000.00
37F2DA	2017-07-07 09:32:00+03	29600.00
37F35D	2017-08-09 10:02:00+03	25300.00
37F3C0	2017-07-16 00:32:00+03	49800.00
37F3EA	2017-07-03 10:19:00+03	97900.00
37F3F0	2017-07-10 19:41:00+03	271100.00
37F44C	2017-07-17 06:13:00+03	42800.00
37F4DD	2017-07-22 01:32:00+03	41200.00
37F53B	2017-08-03 21:32:00+03	27200.00
37F563	2017-07-06 13:54:00+03	23600.00
37F5E9	2017-08-02 04:53:00+03	420500.00
37F5F3	2017-08-15 05:34:00+03	67700.00
37F5F4	2017-08-02 10:22:00+03	51300.00
37F669	2017-07-13 18:40:00+03	53000.00
37F66B	2017-08-01 06:23:00+03	58000.00
37F674	2017-07-08 22:10:00+03	7400.00
37F68D	2017-07-16 08:38:00+03	36800.00
37F78C	2017-08-13 14:37:00+03	46400.00
37F7F5	2017-07-23 13:13:00+03	112000.00
37F841	2017-08-13 15:23:00+03	48800.00
37F87D	2017-07-08 01:03:00+03	79300.00
37F8CF	2017-08-05 05:12:00+03	133100.00
37F93D	2017-08-12 13:27:00+03	119500.00
37F94E	2017-07-01 11:40:00+03	46500.00
37F971	2017-08-13 17:46:00+03	85600.00
37FA53	2017-07-15 17:13:00+03	6700.00
37FA63	2017-08-01 03:49:00+03	98300.00
37FAEF	2017-07-31 23:25:00+03	92000.00
37FB15	2017-07-24 17:52:00+03	49400.00
37FB31	2017-07-09 09:10:00+03	26700.00
37FBEF	2017-07-19 22:27:00+03	21500.00
37FCCC	2017-06-28 17:39:00+03	46000.00
37FD2C	2017-07-03 04:04:00+03	149100.00
37FD63	2017-07-05 04:27:00+03	22000.00
37FD7D	2017-08-12 16:04:00+03	39800.00
37FD98	2017-08-11 02:02:00+03	128600.00
37FD9C	2017-07-03 11:03:00+03	26000.00
37FDAF	2017-08-05 14:55:00+03	81600.00
37FDC3	2017-08-09 01:14:00+03	13400.00
37FDF8	2017-07-21 20:42:00+03	112600.00
37FE13	2017-07-28 23:24:00+03	34000.00
37FE21	2017-07-24 02:21:00+03	269200.00
37FF04	2017-07-08 17:44:00+03	155600.00
37FF0F	2017-07-22 21:09:00+03	111700.00
37FF7B	2017-07-09 19:20:00+03	20400.00
37FFE9	2017-07-20 11:45:00+03	43200.00
3800A1	2017-07-18 16:43:00+03	36700.00
3800BF	2017-07-23 21:05:00+03	258400.00
380101	2017-07-07 05:06:00+03	110200.00
38011F	2017-07-05 04:42:00+03	288700.00
38018A	2017-07-20 04:27:00+03	61800.00
3801B8	2017-07-27 14:52:00+03	182200.00
3801C3	2017-08-13 00:31:00+03	65100.00
3801F6	2017-08-07 18:52:00+03	26800.00
38020C	2017-07-26 22:36:00+03	12000.00
380244	2017-07-04 04:22:00+03	147000.00
380250	2017-07-19 18:55:00+03	38800.00
38029C	2017-08-07 11:54:00+03	38600.00
3802D0	2017-06-29 17:29:00+03	246000.00
380312	2017-07-17 23:44:00+03	135600.00
38035F	2017-07-29 08:01:00+03	6400.00
380386	2017-08-06 20:06:00+03	136200.00
380398	2017-07-17 16:13:00+03	111600.00
38039A	2017-08-04 05:22:00+03	301800.00
380419	2017-08-09 23:53:00+03	142900.00
380453	2017-07-08 10:10:00+03	26800.00
380462	2017-08-02 22:45:00+03	52000.00
38048D	2017-07-07 01:26:00+03	120900.00
3804B8	2017-07-20 16:40:00+03	81200.00
380500	2017-07-06 08:26:00+03	19500.00
380559	2017-06-29 16:36:00+03	264600.00
38058D	2017-06-27 02:18:00+03	32700.00
38058F	2017-07-23 18:07:00+03	29400.00
380593	2017-08-13 22:00:00+03	116000.00
3805C0	2017-07-01 17:22:00+03	48100.00
3805D6	2017-07-02 18:33:00+03	135400.00
38063E	2017-08-12 21:45:00+03	31600.00
380644	2017-07-12 19:56:00+03	66000.00
38068C	2017-08-09 23:10:00+03	393700.00
3806A8	2017-07-08 21:25:00+03	32700.00
3806DC	2017-07-13 11:32:00+03	64700.00
380703	2017-07-11 00:30:00+03	100600.00
38074E	2017-08-09 10:16:00+03	7800.00
38076A	2017-07-02 10:26:00+03	56100.00
3807A6	2017-07-20 20:48:00+03	39400.00
3807C0	2017-07-12 02:49:00+03	91900.00
3807C7	2017-08-05 18:10:00+03	27200.00
3807C8	2017-07-31 13:04:00+03	67200.00
380805	2017-08-15 01:27:00+03	6000.00
38083E	2017-07-14 04:25:00+03	15000.00
3808F3	2017-08-14 08:05:00+03	14400.00
38095A	2017-07-16 04:34:00+03	123000.00
3809EF	2017-07-14 15:39:00+03	24400.00
380A1D	2017-07-26 15:38:00+03	14800.00
380A24	2017-07-28 04:56:00+03	184400.00
380A27	2017-07-25 12:53:00+03	44200.00
380A86	2017-07-02 21:39:00+03	68000.00
380AA0	2017-07-10 01:26:00+03	25400.00
380ACE	2017-07-14 10:01:00+03	27200.00
380B0C	2017-08-06 20:35:00+03	77200.00
380B0F	2017-07-09 05:52:00+03	111600.00
380B4D	2017-07-26 18:37:00+03	190400.00
380B53	2017-07-17 13:51:00+03	26800.00
380B68	2017-07-15 08:31:00+03	85000.00
380BC3	2017-07-20 21:42:00+03	283100.00
380BD1	2017-07-07 21:01:00+03	34000.00
380BF1	2017-07-20 23:50:00+03	48400.00
380C8F	2017-07-29 12:20:00+03	136800.00
380CBF	2017-07-06 21:25:00+03	29000.00
380D2D	2017-08-02 11:31:00+03	96300.00
380DA5	2017-07-21 09:05:00+03	68800.00
380DB3	2017-07-13 11:12:00+03	20200.00
380DF5	2017-08-03 13:42:00+03	20500.00
380E11	2017-08-13 13:54:00+03	20400.00
380ED5	2017-07-24 12:17:00+03	13200.00
380F22	2017-08-06 14:30:00+03	67100.00
380F36	2017-07-05 06:46:00+03	14400.00
380F60	2017-07-12 02:23:00+03	42600.00
380F86	2017-08-10 01:41:00+03	41800.00
380F99	2017-08-04 13:14:00+03	13400.00
380FC2	2017-07-24 21:04:00+03	103800.00
380FD6	2017-07-21 23:56:00+03	60400.00
380FDF	2017-07-02 10:29:00+03	38600.00
380FE2	2017-08-06 21:56:00+03	75600.00
381015	2017-07-05 00:53:00+03	47200.00
38101D	2017-07-26 13:16:00+03	46400.00
381073	2017-06-26 12:36:00+03	22000.00
3810A9	2017-07-29 02:48:00+03	131100.00
3810C0	2017-07-19 09:05:00+03	64200.00
3810C5	2017-08-05 13:04:00+03	62600.00
381119	2017-07-25 10:07:00+03	105000.00
381163	2017-08-15 11:26:00+03	39300.00
3811D7	2017-07-25 13:01:00+03	14000.00
381256	2017-07-28 01:09:00+03	135600.00
38126B	2017-07-09 22:28:00+03	11600.00
381317	2017-08-11 07:14:00+03	46400.00
381396	2017-07-06 15:54:00+03	103500.00
3813AA	2017-07-21 11:50:00+03	140900.00
3813FB	2017-07-23 02:47:00+03	44800.00
38140D	2017-06-26 12:35:00+03	166900.00
381423	2017-07-09 13:56:00+03	59300.00
38145A	2017-08-06 03:11:00+03	133100.00
38145F	2017-07-10 11:36:00+03	46400.00
38146D	2017-07-27 04:26:00+03	26000.00
381482	2017-07-06 15:28:00+03	6000.00
3814C5	2017-06-29 06:33:00+03	135400.00
38150C	2017-07-04 01:46:00+03	16400.00
38153B	2017-08-06 08:24:00+03	24600.00
38158D	2017-07-11 15:00:00+03	88400.00
3815C6	2017-08-11 01:29:00+03	123000.00
3815CF	2017-07-25 11:16:00+03	13600.00
3815E0	2017-07-22 21:25:00+03	77000.00
381618	2017-08-03 01:44:00+03	28800.00
3816A1	2017-07-04 22:55:00+03	136200.00
3816A4	2017-07-30 02:45:00+03	114700.00
381704	2017-07-14 03:45:00+03	233400.00
381760	2017-07-09 11:20:00+03	67900.00
3817E2	2017-07-27 21:54:00+03	51900.00
3817E5	2017-08-13 23:55:00+03	80000.00
381810	2017-08-10 12:58:00+03	94700.00
381816	2017-07-30 12:24:00+03	23200.00
381850	2017-07-05 02:05:00+03	23200.00
3818C6	2017-07-08 12:32:00+03	61600.00
381924	2017-07-08 22:57:00+03	134400.00
381952	2017-08-05 10:05:00+03	10800.00
3819AC	2017-07-22 06:04:00+03	28800.00
381A55	2017-07-23 14:42:00+03	6000.00
381A6E	2017-07-12 08:09:00+03	37200.00
381B09	2017-07-22 14:25:00+03	111600.00
381B18	2017-08-05 18:22:00+03	80200.00
381B3D	2017-07-08 19:06:00+03	49600.00
381B74	2017-07-20 01:09:00+03	112000.00
381B8B	2017-08-01 06:48:00+03	190200.00
381BAA	2017-07-07 09:18:00+03	37500.00
381C38	2017-07-10 01:16:00+03	125400.00
381CBC	2017-07-28 09:05:00+03	6600.00
381D32	2017-07-31 15:33:00+03	49800.00
381DA5	2017-07-08 18:16:00+03	23200.00
381DCF	2017-06-30 00:00:00+03	90300.00
381E07	2017-08-02 22:15:00+03	36400.00
381E69	2017-07-16 12:57:00+03	34600.00
381EF4	2017-07-26 16:48:00+03	47500.00
381F16	2017-07-23 00:30:00+03	31600.00
381F2B	2017-07-21 20:30:00+03	40000.00
381F81	2017-08-13 22:18:00+03	46400.00
381F87	2017-07-21 10:45:00+03	27200.00
381FB4	2017-07-24 22:21:00+03	73500.00
381FFC	2017-08-13 13:02:00+03	20200.00
38200E	2017-08-02 19:14:00+03	61800.00
382095	2017-07-09 21:03:00+03	146000.00
38214E	2017-06-30 15:37:00+03	67200.00
382174	2017-06-25 08:13:00+03	115900.00
38222E	2017-08-06 06:40:00+03	58800.00
38228B	2017-07-21 09:23:00+03	53100.00
382363	2017-07-25 03:09:00+03	13800.00
3823FE	2017-07-17 08:00:00+03	24800.00
382421	2017-08-04 07:29:00+03	79900.00
38243B	2017-07-27 15:51:00+03	40000.00
38243D	2017-07-19 23:45:00+03	8000.00
382598	2017-07-16 16:26:00+03	606900.00
382661	2017-08-14 18:01:00+03	12600.00
38266A	2017-08-05 09:29:00+03	29100.00
38268C	2017-08-11 15:34:00+03	26000.00
38269A	2017-08-15 12:50:00+03	135600.00
3826AC	2017-07-08 19:16:00+03	273000.00
3826D0	2017-07-07 21:52:00+03	29600.00
3826D9	2017-07-26 12:36:00+03	136800.00
38275E	2017-08-10 17:54:00+03	132800.00
3827CE	2017-08-01 22:28:00+03	177200.00
3827DD	2017-07-17 16:55:00+03	60400.00
3827E3	2017-08-08 11:54:00+03	89900.00
382827	2017-07-18 05:42:00+03	20200.00
382843	2017-07-30 11:31:00+03	44600.00
382847	2017-08-01 01:58:00+03	30200.00
382881	2017-07-25 19:48:00+03	40100.00
3828D5	2017-08-09 23:32:00+03	59200.00
3828ED	2017-07-29 04:26:00+03	29600.00
3828FC	2017-08-12 04:08:00+03	83100.00
382902	2017-08-07 02:55:00+03	155300.00
38290A	2017-07-09 01:42:00+03	108500.00
382933	2017-07-03 22:56:00+03	309500.00
382937	2017-07-12 08:36:00+03	145300.00
382993	2017-07-15 00:52:00+03	81900.00
3829F7	2017-08-10 14:40:00+03	26800.00
382A0D	2017-07-04 05:11:00+03	28800.00
382AE1	2017-07-08 19:21:00+03	50600.00
382B40	2017-07-15 21:37:00+03	38600.00
382B53	2017-07-26 12:21:00+03	23200.00
382BA1	2017-07-15 00:58:00+03	125000.00
382BA9	2017-07-22 16:07:00+03	24400.00
382BE1	2017-07-24 21:49:00+03	440900.00
382BE5	2017-07-15 10:43:00+03	160400.00
382C2F	2017-07-09 03:36:00+03	40800.00
382CE6	2017-07-31 16:25:00+03	103400.00
382CE9	2017-06-30 16:31:00+03	6800.00
382CF1	2017-07-08 08:24:00+03	26700.00
382D62	2017-07-30 02:36:00+03	56000.00
382D83	2017-08-01 14:06:00+03	99200.00
382E2E	2017-07-17 20:06:00+03	30200.00
382E97	2017-07-14 18:24:00+03	94700.00
382EC3	2017-08-08 07:42:00+03	36100.00
382F96	2017-07-09 03:25:00+03	6000.00
382FB8	2017-07-20 14:58:00+03	24800.00
383122	2017-07-17 17:11:00+03	98400.00
3831FC	2017-07-04 09:38:00+03	16400.00
383232	2017-07-29 12:49:00+03	369000.00
38324A	2017-08-03 02:34:00+03	194800.00
383275	2017-07-31 21:18:00+03	51900.00
3832B0	2017-07-23 04:53:00+03	112000.00
383303	2017-08-06 22:57:00+03	162000.00
38333C	2017-07-24 22:55:00+03	23600.00
383375	2017-07-06 06:24:00+03	66400.00
38337F	2017-07-12 12:13:00+03	28000.00
38338D	2017-08-05 01:12:00+03	21500.00
3833A7	2017-08-05 07:20:00+03	35200.00
3833CF	2017-07-25 07:30:00+03	58600.00
3833EE	2017-07-09 17:53:00+03	46300.00
383404	2017-08-01 18:44:00+03	43200.00
383410	2017-07-10 05:01:00+03	77900.00
383464	2017-07-05 09:40:00+03	30000.00
383496	2017-07-19 09:52:00+03	30000.00
3834A9	2017-08-03 19:22:00+03	39200.00
3834B3	2017-07-29 17:56:00+03	144400.00
3834BE	2017-08-08 19:51:00+03	16400.00
3834C3	2017-07-05 06:40:00+03	103900.00
3834FC	2017-07-28 01:20:00+03	198900.00
383552	2017-07-27 03:01:00+03	25000.00
383563	2017-07-24 23:28:00+03	99300.00
3835A5	2017-07-18 21:12:00+03	56000.00
38365E	2017-08-05 16:47:00+03	54600.00
38369D	2017-08-13 03:40:00+03	26000.00
3836A3	2017-07-30 08:24:00+03	23400.00
3836F5	2017-07-29 15:12:00+03	134600.00
383719	2017-07-03 02:50:00+03	266400.00
38371B	2017-07-16 00:32:00+03	154000.00
383736	2017-07-03 11:39:00+03	56600.00
383758	2017-07-10 10:50:00+03	135000.00
38375C	2017-08-11 23:33:00+03	223000.00
383796	2017-07-17 15:36:00+03	27200.00
383797	2017-07-27 13:46:00+03	156500.00
38379E	2017-08-04 05:21:00+03	42100.00
3837E9	2017-06-30 10:55:00+03	201600.00
383809	2017-07-26 22:18:00+03	24400.00
383810	2017-07-15 03:15:00+03	7400.00
383816	2017-08-05 05:18:00+03	66600.00
383872	2017-07-17 16:09:00+03	8200.00
38388C	2017-07-05 01:02:00+03	68800.00
383895	2017-07-22 15:59:00+03	27200.00
3838A7	2017-08-09 18:58:00+03	134000.00
3838B0	2017-08-11 08:57:00+03	134200.00
3838DB	2017-08-05 18:29:00+03	33300.00
3838FA	2017-08-11 13:04:00+03	18000.00
38391D	2017-07-11 02:59:00+03	86800.00
38393E	2017-07-25 03:32:00+03	90800.00
38394C	2017-07-13 07:21:00+03	23600.00
383987	2017-07-13 03:09:00+03	97700.00
3839AE	2017-08-14 06:15:00+03	67200.00
383A04	2017-07-25 17:36:00+03	24200.00
383A65	2017-08-08 03:00:00+03	61600.00
383A77	2017-07-21 22:38:00+03	223200.00
383A87	2017-07-04 07:26:00+03	38200.00
383AC7	2017-07-08 17:01:00+03	97600.00
383AEB	2017-07-15 13:40:00+03	101100.00
383AEE	2017-07-16 23:13:00+03	24400.00
383AF9	2017-07-26 11:22:00+03	133200.00
383B69	2017-08-03 08:10:00+03	168000.00
383C27	2017-07-02 11:41:00+03	56000.00
383CDC	2017-07-11 22:11:00+03	99800.00
383D5F	2017-07-17 14:13:00+03	120000.00
383E42	2017-08-14 19:19:00+03	77600.00
383E4D	2017-07-21 20:27:00+03	56000.00
383E5F	2017-07-24 08:43:00+03	38700.00
383E89	2017-08-14 13:57:00+03	42000.00
383F41	2017-08-05 03:58:00+03	56000.00
383F9F	2017-07-09 15:22:00+03	55900.00
383FE4	2017-08-02 05:13:00+03	44600.00
383FFF	2017-07-09 20:04:00+03	177200.00
384003	2017-07-08 10:47:00+03	81700.00
38407C	2017-08-14 08:00:00+03	11000.00
3840ED	2017-07-26 07:52:00+03	99200.00
38410B	2017-08-13 09:38:00+03	91100.00
38411C	2017-07-13 16:01:00+03	193600.00
38412F	2017-07-26 22:57:00+03	50800.00
38413F	2017-07-24 10:59:00+03	83000.00
384154	2017-07-23 07:42:00+03	14900.00
38418D	2017-08-09 01:34:00+03	66600.00
3841DB	2017-06-29 06:43:00+03	92000.00
384244	2017-08-11 20:43:00+03	88600.00
3842F9	2017-07-12 12:42:00+03	6700.00
384301	2017-08-13 14:10:00+03	56000.00
384309	2017-08-07 06:39:00+03	67000.00
384319	2017-07-31 21:13:00+03	36200.00
3843F5	2017-07-22 15:00:00+03	13000.00
384451	2017-08-10 21:25:00+03	41200.00
3844A7	2017-07-24 03:27:00+03	90000.00
384574	2017-08-15 11:34:00+03	156600.00
384583	2017-07-06 10:00:00+03	134400.00
3845BA	2017-07-10 20:07:00+03	23200.00
384615	2017-08-11 07:43:00+03	14800.00
384622	2017-08-15 10:08:00+03	41400.00
3846D8	2017-07-07 03:39:00+03	22600.00
38470E	2017-07-24 18:01:00+03	188900.00
38471F	2017-07-29 04:12:00+03	21400.00
384727	2017-08-02 14:08:00+03	7400.00
38476B	2017-07-07 10:03:00+03	26200.00
384776	2017-07-07 07:39:00+03	27000.00
384795	2017-06-27 02:00:00+03	18900.00
3847BB	2017-08-07 11:25:00+03	20200.00
384898	2017-07-06 05:40:00+03	89200.00
384965	2017-07-05 22:51:00+03	29600.00
38496B	2017-07-11 07:31:00+03	86500.00
384993	2017-08-12 03:53:00+03	207400.00
384A02	2017-08-06 02:07:00+03	291000.00
384A1D	2017-07-12 23:06:00+03	54800.00
384A92	2017-07-05 17:49:00+03	29600.00
384ADA	2017-08-05 08:31:00+03	46800.00
384AE4	2017-07-10 07:03:00+03	44700.00
384BAC	2017-08-10 06:48:00+03	78200.00
384BB7	2017-07-06 23:47:00+03	130300.00
384BDC	2017-08-09 20:12:00+03	393000.00
384C8F	2017-07-12 12:05:00+03	6700.00
384CED	2017-07-13 12:37:00+03	119500.00
384CF1	2017-07-09 04:47:00+03	31400.00
384CF9	2017-07-26 13:45:00+03	16400.00
384D2A	2017-07-13 17:55:00+03	87000.00
384D6E	2017-08-08 16:27:00+03	55800.00
384D88	2017-08-09 20:59:00+03	97100.00
384D9D	2017-07-10 02:01:00+03	39500.00
384DED	2017-08-09 18:59:00+03	103500.00
384E5D	2017-07-20 20:03:00+03	27900.00
384ED4	2017-08-02 23:26:00+03	166900.00
384F3E	2017-07-03 00:13:00+03	123000.00
384F68	2017-07-31 11:26:00+03	73500.00
384FA7	2017-08-14 06:38:00+03	26000.00
38505B	2017-08-04 15:18:00+03	72200.00
385138	2017-08-15 14:33:00+03	58400.00
3851C1	2017-07-21 04:51:00+03	56000.00
3851CA	2017-07-02 21:05:00+03	215600.00
3851EB	2017-07-14 21:31:00+03	52800.00
38521B	2017-08-14 09:58:00+03	4000.00
38524D	2017-07-14 19:54:00+03	163600.00
38536E	2017-07-07 04:54:00+03	163600.00
3853DC	2017-07-21 01:42:00+03	55500.00
3853E4	2017-08-11 02:48:00+03	27200.00
385409	2017-08-04 05:53:00+03	25600.00
38540A	2017-07-08 18:38:00+03	258000.00
38541D	2017-08-02 05:22:00+03	24400.00
385458	2017-07-17 20:28:00+03	78300.00
3854E3	2017-07-25 17:56:00+03	39800.00
38557A	2017-07-01 06:54:00+03	70400.00
38557E	2017-07-28 19:17:00+03	28000.00
3855BA	2017-07-26 23:01:00+03	43600.00
385601	2017-07-09 21:35:00+03	21400.00
385661	2017-07-26 08:30:00+03	273200.00
38566E	2017-07-24 04:25:00+03	98800.00
385687	2017-07-30 05:43:00+03	243600.00
38568B	2017-06-30 03:04:00+03	42800.00
38569A	2017-07-15 18:17:00+03	80200.00
3856A8	2017-08-02 06:57:00+03	67600.00
3856AA	2017-08-03 22:55:00+03	24200.00
3856B9	2017-07-03 07:40:00+03	39300.00
385700	2017-07-09 04:14:00+03	99200.00
385715	2017-07-27 10:55:00+03	35600.00
3857AD	2017-07-22 03:39:00+03	56100.00
385836	2017-07-23 21:40:00+03	55800.00
38586C	2017-07-23 12:10:00+03	56000.00
3858A6	2017-07-09 22:02:00+03	99200.00
3858CC	2017-07-10 12:26:00+03	69500.00
38592D	2017-07-14 10:41:00+03	210200.00
385A60	2017-07-12 14:54:00+03	46900.00
385A7C	2017-07-16 21:22:00+03	64200.00
385AB0	2017-07-05 21:29:00+03	101200.00
385ADA	2017-07-09 11:26:00+03	95100.00
385B07	2017-08-05 01:09:00+03	56000.00
385B0E	2017-07-31 19:02:00+03	26800.00
385B3D	2017-08-06 14:19:00+03	28000.00
385BB3	2017-07-24 07:32:00+03	12200.00
385C22	2017-07-10 21:13:00+03	136800.00
385C72	2017-08-12 08:25:00+03	65900.00
385C73	2017-08-08 10:33:00+03	65100.00
385C7D	2017-07-15 12:23:00+03	6300.00
385C88	2017-07-09 18:30:00+03	53600.00
385C8B	2017-08-03 21:16:00+03	45600.00
385CEE	2017-06-29 07:01:00+03	170500.00
385D36	2017-07-14 11:28:00+03	112000.00
385D7F	2017-07-11 10:26:00+03	231900.00
385D9D	2017-07-10 15:19:00+03	87900.00
385DBC	2017-08-09 02:19:00+03	113800.00
385E2F	2017-08-05 02:15:00+03	52000.00
385E79	2017-07-10 04:50:00+03	12200.00
385F34	2017-07-23 23:39:00+03	30200.00
385F5D	2017-07-26 17:41:00+03	18800.00
385F9E	2017-06-30 22:05:00+03	56000.00
386024	2017-07-13 14:08:00+03	61800.00
38602F	2017-07-27 01:32:00+03	6700.00
386088	2017-07-16 09:52:00+03	16400.00
3860B4	2017-08-01 20:45:00+03	190300.00
3860CB	2017-07-27 15:11:00+03	40800.00
38612C	2017-07-13 01:08:00+03	70500.00
38615E	2017-07-23 22:53:00+03	92800.00
38617B	2017-08-02 04:14:00+03	50000.00
38617E	2017-07-07 16:57:00+03	22000.00
38619D	2017-07-11 07:14:00+03	67800.00
38621A	2017-08-12 07:36:00+03	38000.00
38622B	2017-08-08 21:17:00+03	37700.00
3862B8	2017-07-05 14:25:00+03	9800.00
3862BB	2017-07-11 23:11:00+03	38800.00
3862E4	2017-07-21 01:16:00+03	84100.00
386300	2017-08-11 20:02:00+03	37200.00
386301	2017-07-19 12:48:00+03	60400.00
386344	2017-06-29 18:58:00+03	62000.00
3863AD	2017-07-21 02:13:00+03	75300.00
3863B3	2017-07-21 07:25:00+03	44800.00
3863E9	2017-08-11 17:19:00+03	56600.00
386418	2017-07-09 04:28:00+03	60400.00
386433	2017-07-17 19:17:00+03	38000.00
3864A9	2017-07-31 21:41:00+03	78700.00
386518	2017-08-10 18:02:00+03	173300.00
386523	2017-07-01 13:31:00+03	116800.00
3865A9	2017-07-04 23:42:00+03	66600.00
3865E1	2017-07-20 09:50:00+03	73300.00
386618	2017-07-25 16:09:00+03	272300.00
38662A	2017-07-30 18:55:00+03	162200.00
38665A	2017-08-03 20:07:00+03	67600.00
38675C	2017-07-03 01:27:00+03	25400.00
386776	2017-07-18 05:05:00+03	31400.00
38679F	2017-07-01 06:03:00+03	26200.00
3867E1	2017-07-12 09:09:00+03	6700.00
386842	2017-07-24 09:28:00+03	92400.00
3868D8	2017-07-25 05:05:00+03	111600.00
3868EC	2017-07-10 19:01:00+03	23600.00
386940	2017-07-17 17:36:00+03	73500.00
386971	2017-07-18 12:07:00+03	27200.00
3869A1	2017-07-23 21:45:00+03	49500.00
386A08	2017-07-06 01:47:00+03	26200.00
386A30	2017-07-04 14:34:00+03	22000.00
386A52	2017-08-12 19:09:00+03	27200.00
386A76	2017-07-14 22:06:00+03	63200.00
386B1B	2017-08-12 13:18:00+03	132800.00
386B23	2017-07-04 04:08:00+03	67100.00
386BE6	2017-08-06 03:01:00+03	54000.00
386BE9	2017-07-14 15:09:00+03	74700.00
386BF3	2017-07-18 06:54:00+03	453100.00
386BFD	2017-08-09 17:34:00+03	13400.00
386CC4	2017-07-21 18:51:00+03	174900.00
386D36	2017-07-22 00:56:00+03	41800.00
386D3E	2017-08-14 14:37:00+03	111600.00
386DC9	2017-07-18 22:08:00+03	54500.00
386DD3	2017-07-31 05:27:00+03	205600.00
386DF0	2017-07-22 02:08:00+03	56000.00
386E06	2017-07-01 19:54:00+03	38600.00
386E17	2017-08-12 00:47:00+03	155600.00
386E29	2017-08-13 01:06:00+03	45000.00
386E3F	2017-08-10 13:41:00+03	74400.00
386E5F	2017-07-27 18:38:00+03	37400.00
386EB1	2017-07-12 09:24:00+03	78300.00
386EC8	2017-07-08 18:40:00+03	140900.00
386EEF	2017-08-01 12:38:00+03	16400.00
386F4C	2017-08-01 11:01:00+03	54400.00
386FD4	2017-08-10 10:28:00+03	46000.00
38702D	2017-06-27 08:07:00+03	19600.00
38708A	2017-07-06 14:50:00+03	51600.00
3870C3	2017-07-30 19:48:00+03	93000.00
3871B2	2017-08-11 15:16:00+03	7200.00
3871C7	2017-07-31 00:49:00+03	144400.00
3871F9	2017-07-19 11:13:00+03	116800.00
3871FA	2017-07-10 20:28:00+03	53300.00
387248	2017-07-31 00:34:00+03	44600.00
387284	2017-07-06 00:23:00+03	75200.00
3872FE	2017-07-25 21:06:00+03	12600.00
387313	2017-07-19 00:42:00+03	31200.00
387321	2017-07-30 07:04:00+03	260900.00
387327	2017-07-06 12:34:00+03	37100.00
38734F	2017-06-30 05:44:00+03	39800.00
3873C6	2017-07-11 05:55:00+03	48800.00
3873F4	2017-08-07 13:55:00+03	32400.00
3873F7	2017-07-24 23:13:00+03	21800.00
387425	2017-07-13 08:15:00+03	54300.00
387463	2017-07-07 18:18:00+03	55800.00
387469	2017-07-18 00:06:00+03	547000.00
3875F5	2017-07-23 07:41:00+03	125200.00
387652	2017-08-12 23:12:00+03	30200.00
38765B	2017-07-29 02:27:00+03	27800.00
387673	2017-07-14 08:10:00+03	12400.00
3876CF	2017-07-02 18:35:00+03	32400.00
3876ED	2017-08-01 18:20:00+03	19600.00
38775C	2017-07-16 17:21:00+03	57100.00
387829	2017-08-06 14:31:00+03	50600.00
3878DC	2017-07-07 00:15:00+03	41300.00
3878F0	2017-08-01 01:48:00+03	93000.00
387900	2017-07-06 01:41:00+03	26700.00
38792A	2017-07-19 12:40:00+03	46000.00
387990	2017-07-13 23:20:00+03	59600.00
3879DC	2017-08-13 05:52:00+03	18000.00
3879DD	2017-07-13 21:53:00+03	17800.00
387B01	2017-08-13 13:59:00+03	26000.00
387B2E	2017-08-07 01:37:00+03	77200.00
387B4B	2017-07-30 13:20:00+03	155600.00
387C0A	2017-08-09 20:11:00+03	63300.00
387D93	2017-07-13 09:11:00+03	21800.00
387DB2	2017-07-14 17:44:00+03	8600.00
387E39	2017-07-02 00:59:00+03	23400.00
387E6C	2017-07-17 20:24:00+03	75300.00
387EAD	2017-07-02 20:59:00+03	189800.00
387EB5	2017-08-11 02:27:00+03	16400.00
387EF3	2017-08-07 00:13:00+03	40800.00
387F72	2017-08-06 17:48:00+03	59600.00
387F89	2017-08-01 22:26:00+03	8200.00
387FB5	2017-07-26 08:18:00+03	265700.00
387FEF	2017-08-08 09:05:00+03	29000.00
38800C	2017-07-09 06:09:00+03	49900.00
38805B	2017-08-14 12:59:00+03	65600.00
38806B	2017-07-29 00:10:00+03	16400.00
3880FE	2017-07-16 11:12:00+03	143900.00
388120	2017-08-09 03:26:00+03	26000.00
3881A6	2017-07-19 12:39:00+03	19600.00
3881C6	2017-07-18 12:39:00+03	89600.00
3881D5	2017-08-05 03:08:00+03	12600.00
388271	2017-07-09 05:00:00+03	23600.00
3882A3	2017-07-04 02:43:00+03	125200.00
3882C5	2017-07-06 23:07:00+03	31600.00
3882F5	2017-08-04 11:42:00+03	46800.00
388339	2017-08-13 13:28:00+03	24600.00
38834F	2017-07-05 11:10:00+03	118100.00
3883F3	2017-07-05 11:44:00+03	27400.00
3883F8	2017-08-15 13:31:00+03	62700.00
388416	2017-07-15 18:33:00+03	23600.00
388417	2017-07-07 06:27:00+03	78000.00
388445	2017-07-15 22:49:00+03	12400.00
388494	2017-08-09 10:16:00+03	8200.00
3884A7	2017-07-19 03:32:00+03	77400.00
3884C6	2017-08-13 00:27:00+03	13400.00
388521	2017-08-13 16:31:00+03	58200.00
388597	2017-06-30 17:23:00+03	28000.00
3885AC	2017-07-10 14:15:00+03	67400.00
388612	2017-07-02 18:43:00+03	25100.00
388667	2017-08-07 01:43:00+03	75600.00
3886C5	2017-08-13 08:18:00+03	43200.00
3886EA	2017-08-09 09:55:00+03	184500.00
388772	2017-07-26 20:28:00+03	58800.00
3887C1	2017-07-24 11:32:00+03	26200.00
3887C3	2017-08-08 17:04:00+03	48400.00
3887F4	2017-07-14 08:18:00+03	46400.00
38888F	2017-08-15 13:45:00+03	70700.00
3888B5	2017-07-20 13:25:00+03	271200.00
3888D0	2017-07-16 21:10:00+03	65300.00
388953	2017-07-31 20:00:00+03	27300.00
388989	2017-08-02 12:36:00+03	6300.00
3889AA	2017-07-08 14:38:00+03	67200.00
3889C2	2017-07-06 20:56:00+03	171200.00
3889C3	2017-07-17 21:20:00+03	35700.00
388A92	2017-08-03 06:36:00+03	31600.00
388AAD	2017-07-18 23:58:00+03	92900.00
388AB0	2017-08-07 06:03:00+03	44000.00
388BF0	2017-08-03 21:34:00+03	28000.00
388BFC	2017-07-12 00:51:00+03	35500.00
388C97	2017-08-13 09:13:00+03	17200.00
388CE3	2017-07-15 20:44:00+03	199600.00
388CF8	2017-07-13 19:52:00+03	23400.00
388D0C	2017-07-16 10:26:00+03	46800.00
388D15	2017-08-15 14:53:00+03	223200.00
388D2F	2017-08-08 16:06:00+03	23600.00
388D6A	2017-07-31 21:23:00+03	80500.00
388D8C	2017-07-25 21:12:00+03	113600.00
388D8F	2017-07-16 16:19:00+03	135200.00
388DE7	2017-07-12 04:02:00+03	28000.00
388DF3	2017-07-22 01:18:00+03	70600.00
388E45	2017-07-03 00:27:00+03	28000.00
388E77	2017-07-11 04:52:00+03	84100.00
388EBD	2017-07-07 04:47:00+03	133200.00
388ECC	2017-07-31 23:46:00+03	114800.00
388EFF	2017-07-09 13:40:00+03	48800.00
388F4C	2017-07-31 20:39:00+03	81300.00
388F58	2017-07-13 00:59:00+03	63200.00
388F7D	2017-07-20 04:09:00+03	57400.00
388F7F	2017-08-08 09:22:00+03	50800.00
388FB1	2017-07-23 14:36:00+03	29600.00
388FC8	2017-07-10 20:09:00+03	75200.00
389017	2017-08-13 01:25:00+03	135200.00
389018	2017-08-06 18:10:00+03	26800.00
389022	2017-07-10 04:55:00+03	206400.00
389065	2017-07-09 09:29:00+03	162500.00
389092	2017-07-04 11:55:00+03	70700.00
389106	2017-07-15 03:08:00+03	146300.00
38910C	2017-08-01 00:43:00+03	21200.00
38919B	2017-08-08 18:20:00+03	81600.00
3891B1	2017-08-14 16:47:00+03	28800.00
3891CD	2017-07-12 08:43:00+03	51300.00
3891E7	2017-07-10 04:18:00+03	28000.00
389235	2017-07-29 20:00:00+03	117500.00
389250	2017-07-22 23:02:00+03	24400.00
389307	2017-07-15 04:43:00+03	89700.00
389311	2017-07-23 19:03:00+03	67200.00
389320	2017-08-12 10:58:00+03	98400.00
389342	2017-07-23 17:23:00+03	91100.00
389370	2017-07-22 14:47:00+03	44800.00
389394	2017-08-10 04:41:00+03	116000.00
3893A8	2017-08-08 21:35:00+03	206700.00
3893D1	2017-07-10 18:15:00+03	137100.00
3893D6	2017-07-01 04:18:00+03	47200.00
3893D9	2017-07-26 14:46:00+03	57500.00
3893F3	2017-06-29 13:16:00+03	28800.00
3893F4	2017-07-15 17:40:00+03	10700.00
389403	2017-07-28 03:46:00+03	66600.00
389460	2017-07-27 00:34:00+03	88600.00
38948A	2017-07-25 23:30:00+03	66600.00
3894BE	2017-08-08 02:31:00+03	43200.00
389504	2017-08-02 10:30:00+03	23200.00
389549	2017-08-01 16:30:00+03	11600.00
389592	2017-07-27 00:05:00+03	6900.00
3895CE	2017-07-24 13:51:00+03	56100.00
38962F	2017-08-09 13:21:00+03	64000.00
389661	2017-08-09 18:45:00+03	24400.00
389690	2017-07-02 11:40:00+03	62600.00
3896AB	2017-07-16 20:31:00+03	95900.00
3896B2	2017-07-02 13:20:00+03	195900.00
3896DC	2017-07-15 17:09:00+03	70600.00
38973E	2017-08-07 07:34:00+03	147100.00
389813	2017-07-25 10:22:00+03	42700.00
38981B	2017-07-05 06:16:00+03	113300.00
38983B	2017-08-02 14:42:00+03	264600.00
389874	2017-07-07 00:42:00+03	19600.00
389876	2017-07-14 01:59:00+03	73600.00
3898A9	2017-08-12 16:59:00+03	100000.00
3898BE	2017-07-07 05:27:00+03	50600.00
38996C	2017-07-31 22:16:00+03	75600.00
3899E3	2017-07-28 13:36:00+03	20400.00
389A5C	2017-07-14 20:34:00+03	14000.00
389AA1	2017-08-03 14:17:00+03	49000.00
389AC9	2017-08-07 21:46:00+03	6700.00
389B03	2017-07-23 00:34:00+03	11600.00
389B29	2017-08-04 09:15:00+03	164400.00
389B78	2017-07-13 02:34:00+03	28800.00
389BE0	2017-08-14 04:57:00+03	10700.00
389BF3	2017-08-11 08:41:00+03	27800.00
389C04	2017-07-05 23:29:00+03	123600.00
389C42	2017-07-11 15:38:00+03	27800.00
389CEF	2017-07-20 09:58:00+03	26000.00
389D28	2017-08-07 21:51:00+03	44800.00
389D9A	2017-07-11 19:20:00+03	132800.00
389DB5	2017-08-06 05:23:00+03	240600.00
389E17	2017-08-09 16:35:00+03	46200.00
389E26	2017-07-19 12:39:00+03	243300.00
389E62	2017-07-10 18:55:00+03	99900.00
389E66	2017-07-30 23:06:00+03	280000.00
389E67	2017-08-09 17:03:00+03	174900.00
389E8F	2017-07-10 02:29:00+03	397700.00
389F0B	2017-07-24 19:14:00+03	26000.00
389F70	2017-07-20 12:41:00+03	46200.00
389F86	2017-08-05 14:31:00+03	68100.00
389FA1	2017-08-04 08:39:00+03	38200.00
389FEE	2017-08-11 03:40:00+03	6700.00
38A009	2017-07-23 13:03:00+03	97900.00
38A066	2017-07-15 07:17:00+03	6800.00
38A0B0	2017-08-04 21:47:00+03	30200.00
38A0B4	2017-08-15 13:39:00+03	56000.00
38A0F7	2017-07-23 18:41:00+03	51800.00
38A1BA	2017-08-15 03:01:00+03	42800.00
38A1CF	2017-08-11 16:39:00+03	27900.00
38A224	2017-07-17 06:20:00+03	75300.00
38A2C9	2017-07-10 11:14:00+03	179600.00
38A2FE	2017-07-09 11:12:00+03	56000.00
38A32C	2017-07-17 20:15:00+03	54100.00
38A377	2017-08-10 23:58:00+03	92800.00
38A423	2017-08-09 20:34:00+03	68100.00
38A445	2017-07-04 18:54:00+03	137100.00
38A480	2017-08-11 15:32:00+03	86800.00
38A4BD	2017-07-19 08:30:00+03	491600.00
38A59D	2017-07-15 16:11:00+03	11600.00
38A5D0	2017-08-02 18:06:00+03	52000.00
38A5F3	2017-07-19 03:15:00+03	42000.00
38A650	2017-07-22 07:03:00+03	80800.00
38A662	2017-07-17 06:22:00+03	53600.00
38A66D	2017-07-05 21:13:00+03	35400.00
38A68B	2017-07-09 13:59:00+03	187800.00
38A69B	2017-08-12 03:21:00+03	40800.00
38A6D1	2017-07-12 20:38:00+03	97000.00
38A6D7	2017-08-01 14:33:00+03	19600.00
38A737	2017-08-04 17:39:00+03	108000.00
38A7F6	2017-07-10 08:30:00+03	358900.00
38A815	2017-07-17 05:56:00+03	136800.00
38A8D6	2017-07-22 23:52:00+03	46400.00
38A8F2	2017-07-21 08:35:00+03	100600.00
38A907	2017-08-12 11:14:00+03	31600.00
38A91C	2017-07-29 01:31:00+03	52800.00
38A94C	2017-07-06 20:36:00+03	6300.00
38A9CC	2017-07-05 06:15:00+03	60400.00
38A9D6	2017-08-02 01:05:00+03	111400.00
38A9F1	2017-07-21 01:15:00+03	28800.00
38AA32	2017-06-28 02:27:00+03	219300.00
38AA4C	2017-06-30 03:11:00+03	136200.00
38AB22	2017-07-29 16:23:00+03	51600.00
38AB6F	2017-07-26 07:55:00+03	76900.00
38ABD1	2017-08-11 04:24:00+03	51900.00
38AC33	2017-07-24 00:51:00+03	43000.00
38AC4D	2017-08-01 03:55:00+03	32800.00
38ACBD	2017-07-03 23:18:00+03	255600.00
38ACF5	2017-07-25 11:47:00+03	69500.00
38AD61	2017-07-12 02:14:00+03	44000.00
38ADA7	2017-08-12 07:38:00+03	40800.00
38ADAB	2017-07-09 15:01:00+03	42400.00
38ADCB	2017-07-06 03:26:00+03	254900.00
38ADD1	2017-08-08 12:30:00+03	105600.00
38AE06	2017-07-26 09:35:00+03	36900.00
38AEAC	2017-08-13 16:01:00+03	60700.00
38AEBB	2017-08-11 01:55:00+03	47000.00
38AF40	2017-08-14 07:58:00+03	115400.00
38AF5F	2017-07-30 19:16:00+03	123000.00
38AF75	2017-06-30 00:22:00+03	12400.00
38AF86	2017-08-06 00:54:00+03	273000.00
38AF87	2017-08-06 13:58:00+03	41600.00
38AF8B	2017-07-11 10:01:00+03	53300.00
38AFA6	2017-08-02 22:10:00+03	39800.00
38B03B	2017-08-14 08:42:00+03	65100.00
38B0D1	2017-08-09 18:39:00+03	86400.00
38B131	2017-06-30 10:55:00+03	11800.00
38B136	2017-08-10 17:47:00+03	150200.00
38B13A	2017-07-03 17:18:00+03	100000.00
38B205	2017-07-14 05:08:00+03	13400.00
38B24E	2017-07-29 06:38:00+03	51900.00
38B2A3	2017-08-13 08:39:00+03	223200.00
38B2D1	2017-07-20 07:09:00+03	26700.00
38B334	2017-08-12 09:10:00+03	38400.00
38B362	2017-08-13 14:39:00+03	68000.00
38B3C5	2017-07-03 16:39:00+03	185500.00
38B3F1	2017-08-08 19:29:00+03	136800.00
38B3F3	2017-07-21 01:12:00+03	132800.00
38B40B	2017-07-10 10:08:00+03	70500.00
38B414	2017-07-18 16:39:00+03	260300.00
38B41C	2017-07-08 21:31:00+03	210900.00
38B489	2017-07-31 19:25:00+03	198600.00
38B4A1	2017-07-07 09:24:00+03	59200.00
38B4CA	2017-08-04 19:46:00+03	406800.00
38B50E	2017-08-05 01:22:00+03	75600.00
38B543	2017-07-13 10:39:00+03	56000.00
38B552	2017-07-15 02:00:00+03	94200.00
38B56A	2017-08-11 23:04:00+03	13000.00
38B5AF	2017-08-10 18:17:00+03	71200.00
38B5CE	2017-07-10 23:48:00+03	50600.00
38B630	2017-08-06 05:01:00+03	6000.00
38B663	2017-07-19 02:52:00+03	92900.00
38B677	2017-07-24 02:04:00+03	59200.00
38B6C1	2017-08-10 08:46:00+03	51600.00
38B6C2	2017-08-07 10:35:00+03	182300.00
38B6C5	2017-08-05 20:22:00+03	187600.00
38B6DA	2017-08-05 17:53:00+03	52000.00
38B75D	2017-08-14 07:48:00+03	385000.00
38B78C	2017-08-12 22:25:00+03	83800.00
38B7A1	2017-07-27 10:15:00+03	89700.00
38B7D4	2017-07-09 22:05:00+03	40400.00
38B7F9	2017-07-13 13:40:00+03	532800.00
38B836	2017-08-10 06:43:00+03	132800.00
38B877	2017-08-13 13:36:00+03	49400.00
38B8B0	2017-08-04 14:53:00+03	66600.00
38B8B7	2017-07-03 13:57:00+03	26000.00
38B91A	2017-07-20 05:10:00+03	166100.00
38B91B	2017-07-16 18:27:00+03	135400.00
38B942	2017-07-26 12:38:00+03	25600.00
38B95A	2017-07-29 12:01:00+03	57400.00
38B978	2017-07-26 15:29:00+03	43200.00
38B990	2017-07-31 14:41:00+03	21400.00
38B994	2017-07-31 11:39:00+03	31600.00
38B9EA	2017-07-11 08:47:00+03	42800.00
38BA2C	2017-07-08 13:59:00+03	46000.00
38BA2E	2017-08-15 03:29:00+03	167400.00
38BA86	2017-07-15 01:45:00+03	56000.00
38BAEE	2017-07-31 13:28:00+03	28000.00
38BB0C	2017-07-03 06:00:00+03	26000.00
38BB42	2017-07-07 03:38:00+03	75600.00
38BB8B	2017-07-23 20:20:00+03	103800.00
38BBAF	2017-07-10 20:32:00+03	96200.00
38BBEB	2017-08-11 03:09:00+03	69600.00
38BC50	2017-07-12 14:25:00+03	94800.00
38BC85	2017-07-07 19:53:00+03	31600.00
38BCD6	2017-07-14 20:35:00+03	16400.00
38BD0E	2017-08-12 20:38:00+03	22400.00
38BD21	2017-08-04 06:28:00+03	73400.00
38BD46	2017-08-10 18:35:00+03	43000.00
38BD80	2017-07-10 21:46:00+03	57600.00
38BDB5	2017-07-28 01:59:00+03	136600.00
38BDDC	2017-08-07 01:46:00+03	24700.00
38BE04	2017-08-03 19:11:00+03	86400.00
38BECF	2017-07-09 22:40:00+03	39200.00
38BEE7	2017-07-23 09:07:00+03	253200.00
38BF2C	2017-07-15 11:01:00+03	24400.00
38BFF4	2017-07-22 00:39:00+03	28000.00
38C01E	2017-08-10 04:19:00+03	259000.00
38C099	2017-08-08 22:55:00+03	63200.00
38C0E1	2017-07-12 05:31:00+03	60900.00
38C0F4	2017-07-30 04:46:00+03	56000.00
38C155	2017-07-13 19:48:00+03	58400.00
38C179	2017-08-12 08:32:00+03	41800.00
38C1DA	2017-07-09 01:13:00+03	195900.00
38C237	2017-07-02 13:34:00+03	38600.00
38C2A2	2017-08-01 09:02:00+03	22000.00
38C311	2017-07-19 18:39:00+03	28000.00
38C38B	2017-07-10 20:46:00+03	57400.00
38C3B0	2017-08-12 03:05:00+03	65500.00
38C46F	2017-07-05 08:08:00+03	94700.00
38C4A1	2017-08-15 04:17:00+03	160800.00
38C4F9	2017-08-12 00:42:00+03	38400.00
38C503	2017-07-16 23:31:00+03	23600.00
38C50E	2017-08-03 11:41:00+03	36800.00
38C530	2017-08-01 01:33:00+03	44700.00
38C551	2017-07-10 18:48:00+03	42800.00
38C552	2017-08-03 21:33:00+03	112000.00
38C56C	2017-07-10 00:40:00+03	47400.00
38C5A3	2017-07-04 08:14:00+03	26700.00
38C63D	2017-07-29 09:49:00+03	57600.00
38C646	2017-08-04 01:39:00+03	34000.00
38C655	2017-07-23 03:29:00+03	48500.00
38C672	2017-07-24 17:17:00+03	6000.00
38C6DB	2017-07-19 19:16:00+03	83700.00
38C743	2017-08-04 20:38:00+03	21600.00
38C747	2017-06-30 04:09:00+03	169900.00
38C785	2017-08-08 15:48:00+03	103400.00
38C7F1	2017-07-18 15:00:00+03	132800.00
38C871	2017-08-15 01:39:00+03	30000.00
38C8C1	2017-08-01 06:38:00+03	32200.00
38C8F1	2017-08-14 12:48:00+03	27800.00
38C8FD	2017-08-15 14:19:00+03	22000.00
38C902	2017-07-27 14:36:00+03	131100.00
38C9A3	2017-08-08 03:23:00+03	411700.00
38C9C2	2017-07-07 00:49:00+03	19600.00
38C9ED	2017-08-11 01:15:00+03	95100.00
38CA1E	2017-07-16 15:49:00+03	6000.00
38CB2B	2017-07-21 02:48:00+03	22000.00
38CB56	2017-08-02 13:26:00+03	78400.00
38CB6B	2017-06-29 19:30:00+03	7900.00
38CB81	2017-07-08 05:04:00+03	134800.00
38CBA9	2017-07-17 02:45:00+03	149300.00
38CBC6	2017-08-14 20:03:00+03	55600.00
38CC32	2017-08-03 10:13:00+03	123000.00
38CC4F	2017-07-19 07:43:00+03	128800.00
38CC81	2017-07-12 11:13:00+03	56600.00
38CCB4	2017-07-13 17:43:00+03	13000.00
38CD17	2017-08-09 07:44:00+03	86300.00
38CD1E	2017-07-31 21:16:00+03	48800.00
38CDA9	2017-07-02 15:33:00+03	12400.00
38CDCB	2017-07-26 08:05:00+03	214900.00
38CDDC	2017-07-11 05:35:00+03	51100.00
38CE4E	2017-08-04 05:22:00+03	289900.00
38CEA6	2017-07-07 06:28:00+03	68400.00
38CECD	2017-08-04 14:33:00+03	112000.00
38CEEE	2017-07-01 07:21:00+03	67600.00
38CFB5	2017-07-25 21:35:00+03	67200.00
38CFBA	2017-08-04 16:25:00+03	160000.00
38D00B	2017-08-11 11:58:00+03	87000.00
38D021	2017-07-14 03:11:00+03	16400.00
38D052	2017-08-06 21:28:00+03	37700.00
38D129	2017-08-09 03:39:00+03	80700.00
38D16D	2017-08-02 00:45:00+03	49600.00
38D1F7	2017-07-06 05:38:00+03	92800.00
38D297	2017-08-08 04:03:00+03	21800.00
38D2B9	2017-07-15 02:38:00+03	124400.00
38D2D1	2017-07-05 23:47:00+03	81700.00
38D2E3	2017-07-09 21:51:00+03	24200.00
38D2FF	2017-07-19 08:04:00+03	67000.00
38D377	2017-07-30 10:21:00+03	435800.00
38D418	2017-07-29 11:10:00+03	68700.00
38D4B4	2017-08-02 05:40:00+03	141600.00
38D4BF	2017-07-15 03:29:00+03	45500.00
38D573	2017-07-18 21:16:00+03	46000.00
38D5C6	2017-07-07 06:07:00+03	69700.00
38D623	2017-07-08 18:47:00+03	93500.00
38D647	2017-08-02 13:51:00+03	58600.00
38D655	2017-07-06 19:17:00+03	111600.00
38D681	2017-07-19 01:11:00+03	37200.00
38D719	2017-07-06 09:14:00+03	196800.00
38D72C	2017-06-30 11:13:00+03	32700.00
38D751	2017-07-13 13:30:00+03	139400.00
38D76C	2017-07-29 04:58:00+03	139300.00
38D773	2017-08-15 14:53:00+03	32200.00
38D786	2017-07-23 04:17:00+03	25400.00
38D7B3	2017-07-25 06:53:00+03	40200.00
38D7D1	2017-07-12 10:35:00+03	44500.00
38D7EB	2017-08-11 15:22:00+03	36000.00
38D80B	2017-07-06 14:41:00+03	7400.00
38D8B8	2017-08-15 13:49:00+03	86400.00
38D922	2017-07-29 19:56:00+03	18000.00
38D9DA	2017-08-13 06:00:00+03	70900.00
38D9E9	2017-07-18 03:09:00+03	246000.00
38DA0F	2017-07-26 18:16:00+03	6000.00
38DA45	2017-07-10 20:09:00+03	65900.00
38DA6C	2017-08-09 19:23:00+03	37600.00
38DA7C	2017-07-07 20:27:00+03	133200.00
38DAA6	2017-08-07 10:00:00+03	53300.00
38DAE0	2017-07-24 17:19:00+03	23400.00
38DB93	2017-07-17 20:13:00+03	21500.00
38DBA5	2017-07-07 12:51:00+03	24600.00
38DBF4	2017-07-04 02:56:00+03	92600.00
38DC3C	2017-07-14 11:11:00+03	48800.00
38DC8C	2017-07-30 20:25:00+03	53400.00
38DC9F	2017-08-03 15:26:00+03	67600.00
38DCC3	2017-07-16 01:42:00+03	135600.00
38DDB0	2017-07-23 06:12:00+03	99700.00
38DDD9	2017-08-06 22:12:00+03	139300.00
38DE08	2017-08-07 18:30:00+03	69200.00
38DE1F	2017-07-12 21:50:00+03	23400.00
38DE2A	2017-07-11 06:16:00+03	52400.00
38DE96	2017-07-15 03:05:00+03	26000.00
38DED3	2017-07-28 18:27:00+03	99700.00
38DEE8	2017-08-14 23:52:00+03	81300.00
38DF20	2017-07-06 14:45:00+03	260900.00
38DF26	2017-07-25 03:52:00+03	25000.00
38DFA0	2017-07-05 14:22:00+03	276000.00
38E047	2017-08-02 11:09:00+03	28800.00
38E09B	2017-07-10 19:05:00+03	148200.00
38E0EC	2017-07-29 14:10:00+03	182300.00
38E0FC	2017-07-27 01:30:00+03	47100.00
38E1B3	2017-06-27 08:05:00+03	68100.00
38E1FF	2017-08-01 02:06:00+03	67600.00
38E2E7	2017-07-25 06:54:00+03	273400.00
38E315	2017-08-02 05:16:00+03	73500.00
38E330	2017-07-22 23:50:00+03	201200.00
38E376	2017-08-10 09:41:00+03	23900.00
38E38E	2017-07-30 08:35:00+03	150600.00
38E399	2017-07-23 08:16:00+03	64100.00
38E467	2017-07-13 10:22:00+03	286100.00
38E48E	2017-08-10 15:14:00+03	55800.00
38E492	2017-07-31 23:50:00+03	64800.00
38E54A	2017-07-16 09:48:00+03	75600.00
38E556	2017-07-21 19:00:00+03	57500.00
38E55C	2017-08-15 08:00:00+03	84500.00
38E5A8	2017-07-05 11:16:00+03	75000.00
38E5D2	2017-07-14 16:54:00+03	148100.00
38E608	2017-07-13 03:57:00+03	10100.00
38E640	2017-07-19 10:39:00+03	241300.00
38E64B	2017-07-12 14:34:00+03	229900.00
38E659	2017-08-13 00:39:00+03	46800.00
38E69F	2017-07-14 05:02:00+03	52000.00
38E6C0	2017-07-10 02:10:00+03	16400.00
38E6C3	2017-07-09 09:13:00+03	18500.00
38E70D	2017-07-03 14:41:00+03	61200.00
38E711	2017-08-14 16:50:00+03	22000.00
38E72D	2017-07-15 04:10:00+03	21400.00
38E76E	2017-07-04 05:35:00+03	56000.00
38E8C9	2017-07-13 08:01:00+03	62800.00
38E90D	2017-07-13 00:01:00+03	268000.00
38E929	2017-07-19 00:40:00+03	30700.00
38E933	2017-07-31 12:43:00+03	66600.00
38E98D	2017-08-04 06:22:00+03	313800.00
38E9AB	2017-07-12 15:05:00+03	46400.00
38E9BF	2017-07-06 21:43:00+03	73500.00
38E9EE	2017-08-12 23:09:00+03	20600.00
38E9F1	2017-07-28 11:54:00+03	227300.00
38EA41	2017-07-04 23:00:00+03	26000.00
38EA6B	2017-07-29 01:08:00+03	28000.00
38EA8A	2017-08-09 15:41:00+03	43500.00
38EAB3	2017-07-14 12:27:00+03	65500.00
38EAB5	2017-08-11 15:55:00+03	55800.00
38EABA	2017-08-15 04:45:00+03	85600.00
38EAE8	2017-07-08 19:25:00+03	111600.00
38EAFC	2017-07-10 18:33:00+03	10800.00
38EB35	2017-07-17 20:43:00+03	68800.00
38EB42	2017-08-06 20:35:00+03	58200.00
38EB8B	2017-07-22 20:56:00+03	61500.00
38EBA4	2017-07-26 06:49:00+03	15000.00
38EBBC	2017-07-10 07:42:00+03	26100.00
38EC6C	2017-07-12 01:04:00+03	36800.00
38EC90	2017-07-06 05:26:00+03	30200.00
38ECCC	2017-06-30 06:14:00+03	67600.00
38ED41	2017-07-18 07:26:00+03	116400.00
38EE43	2017-07-09 05:54:00+03	48300.00
38EE46	2017-08-05 07:21:00+03	56100.00
38EE8D	2017-07-20 10:40:00+03	112000.00
38EF9F	2017-08-09 07:21:00+03	120100.00
38EFA6	2017-08-06 22:47:00+03	10700.00
38EFAB	2017-08-10 20:17:00+03	89600.00
38F013	2017-07-23 12:57:00+03	19800.00
38F056	2017-07-08 16:25:00+03	126100.00
38F0E2	2017-07-31 08:23:00+03	28600.00
38F116	2017-07-13 18:17:00+03	24400.00
38F133	2017-07-31 05:56:00+03	11600.00
38F1E1	2017-08-11 00:16:00+03	48800.00
38F21C	2017-07-06 21:40:00+03	111600.00
38F247	2017-07-17 06:54:00+03	6000.00
38F25F	2017-07-18 09:36:00+03	19800.00
38F294	2017-07-29 17:02:00+03	405200.00
38F2E8	2017-07-09 00:49:00+03	26000.00
38F325	2017-07-22 17:05:00+03	95900.00
38F377	2017-07-22 02:01:00+03	18900.00
38F378	2017-08-01 18:16:00+03	67200.00
38F382	2017-08-01 19:14:00+03	16400.00
38F392	2017-07-17 05:20:00+03	48800.00
38F3D1	2017-08-11 04:07:00+03	95200.00
38F3D6	2017-07-19 00:03:00+03	13700.00
38F460	2017-07-18 08:33:00+03	61900.00
38F4B4	2017-08-01 23:42:00+03	32200.00
38F4D6	2017-08-14 09:53:00+03	39300.00
38F4DC	2017-07-02 07:44:00+03	28000.00
38F53A	2017-08-02 00:36:00+03	34600.00
38F5BE	2017-07-15 04:39:00+03	72000.00
38F618	2017-07-15 19:30:00+03	101200.00
38F686	2017-07-27 16:30:00+03	39800.00
38F725	2017-07-21 00:26:00+03	72400.00
38F76D	2017-08-05 16:33:00+03	44000.00
38F7D3	2017-07-13 12:07:00+03	201200.00
38F838	2017-07-22 00:27:00+03	25600.00
38F879	2017-07-13 12:18:00+03	119900.00
38F885	2017-07-27 08:25:00+03	137600.00
38F8A9	2017-07-29 08:04:00+03	150600.00
38F8BD	2017-08-11 02:51:00+03	113600.00
38F909	2017-07-16 19:33:00+03	14400.00
38F924	2017-08-11 06:50:00+03	78300.00
38F9E1	2017-07-17 17:06:00+03	132800.00
38FA4A	2017-07-19 23:54:00+03	61800.00
38FAAE	2017-07-21 06:39:00+03	46000.00
38FB20	2017-08-12 00:09:00+03	47100.00
38FB4C	2017-07-21 03:37:00+03	34400.00
38FB82	2017-07-27 09:10:00+03	56000.00
38FB8A	2017-07-26 13:26:00+03	6800.00
38FBF6	2017-07-26 17:28:00+03	279800.00
38FBFC	2017-08-13 02:14:00+03	65500.00
38FC05	2017-07-07 16:03:00+03	46400.00
38FC0F	2017-08-02 00:50:00+03	43200.00
38FC2E	2017-08-13 06:59:00+03	266400.00
38FC3E	2017-08-13 03:48:00+03	39300.00
38FCF3	2017-07-12 17:19:00+03	56900.00
38FD00	2017-07-06 19:51:00+03	186900.00
38FD81	2017-06-30 12:08:00+03	20100.00
38FD90	2017-07-31 10:08:00+03	112000.00
38FE1F	2017-08-06 02:10:00+03	28800.00
38FE5A	2017-08-14 02:07:00+03	135400.00
38FEFC	2017-07-08 05:51:00+03	27900.00
38FF3D	2017-07-17 12:07:00+03	66600.00
38FF46	2017-07-06 11:01:00+03	27200.00
38FF77	2017-07-09 17:53:00+03	113200.00
38FFA4	2017-07-03 11:19:00+03	24400.00
390024	2017-07-15 23:01:00+03	56900.00
39012A	2017-07-08 08:46:00+03	28000.00
39016E	2017-07-29 13:59:00+03	194700.00
390198	2017-08-07 06:24:00+03	24300.00
3901AE	2017-07-03 14:10:00+03	200500.00
3901DC	2017-07-17 23:47:00+03	55800.00
3901F8	2017-08-11 18:38:00+03	66600.00
3903EA	2017-07-25 05:24:00+03	62700.00
390414	2017-08-05 14:11:00+03	56000.00
39041F	2017-07-19 06:46:00+03	133200.00
3904AC	2017-07-11 10:09:00+03	56000.00
3904DF	2017-06-29 03:41:00+03	54200.00
3904F1	2017-07-09 06:07:00+03	45000.00
390504	2017-08-07 00:29:00+03	96200.00
39052C	2017-07-04 08:40:00+03	7300.00
39053B	2017-07-28 05:10:00+03	92400.00
39054E	2017-08-01 14:48:00+03	66000.00
390559	2017-07-27 21:51:00+03	29600.00
3905D1	2017-07-29 23:03:00+03	68100.00
3905E6	2017-06-24 18:02:00+03	14400.00
3905EB	2017-08-03 14:27:00+03	6700.00
390645	2017-07-08 23:00:00+03	94200.00
39064C	2017-07-19 20:19:00+03	113200.00
390666	2017-07-28 01:47:00+03	124300.00
39068C	2017-07-04 00:01:00+03	40200.00
3906A6	2017-07-31 15:00:00+03	47000.00
3906C1	2017-08-01 09:03:00+03	26800.00
390705	2017-07-30 13:53:00+03	169600.00
39075B	2017-07-05 23:36:00+03	46800.00
39079F	2017-08-08 03:54:00+03	26800.00
3907BE	2017-08-13 20:46:00+03	7400.00
3907F3	2017-07-18 13:03:00+03	75300.00
390843	2017-07-03 14:22:00+03	125400.00
390869	2017-08-09 08:24:00+03	136000.00
39087D	2017-08-06 05:07:00+03	62600.00
3908A6	2017-07-07 03:30:00+03	32200.00
3908DF	2017-07-30 10:07:00+03	96200.00
390910	2017-07-20 00:08:00+03	23400.00
390935	2017-07-21 04:07:00+03	32400.00
39097E	2017-08-08 09:54:00+03	101200.00
390983	2017-07-04 09:22:00+03	46400.00
39098B	2017-08-13 21:55:00+03	6700.00
3909C2	2017-07-29 18:39:00+03	11600.00
3909EE	2017-08-14 09:00:00+03	46700.00
390A0A	2017-08-02 12:42:00+03	184100.00
390A69	2017-07-02 10:16:00+03	95600.00
390A9F	2017-07-19 08:46:00+03	92800.00
390AA4	2017-07-06 11:44:00+03	56000.00
390AC4	2017-07-17 18:33:00+03	282300.00
390AE8	2017-07-11 08:10:00+03	30000.00
390B79	2017-08-09 10:29:00+03	203400.00
390BC8	2017-07-01 11:29:00+03	47600.00
390C58	2017-08-15 07:22:00+03	28800.00
390C5A	2017-07-14 09:02:00+03	6800.00
390CC5	2017-08-03 18:32:00+03	37600.00
390CEC	2017-08-12 18:35:00+03	135400.00
390CFE	2017-07-31 21:56:00+03	30200.00
390D07	2017-07-08 10:54:00+03	131600.00
390D76	2017-07-20 22:52:00+03	190300.00
390D90	2017-08-05 19:31:00+03	399300.00
390DB0	2017-07-19 09:25:00+03	83600.00
390DFC	2017-07-10 23:08:00+03	100000.00
390E71	2017-07-29 19:25:00+03	29400.00
390E78	2017-07-31 23:28:00+03	84500.00
390ED5	2017-08-11 12:57:00+03	40000.00
390F35	2017-08-05 18:47:00+03	116800.00
391001	2017-08-15 11:45:00+03	57600.00
39106D	2017-07-24 17:14:00+03	52000.00
391072	2017-07-21 23:27:00+03	54500.00
3910F9	2017-08-14 01:09:00+03	57500.00
391108	2017-07-16 08:19:00+03	48500.00
391131	2017-07-23 11:20:00+03	218800.00
391154	2017-07-15 15:07:00+03	17800.00
3911BD	2017-07-24 03:29:00+03	150600.00
3911FD	2017-08-14 06:25:00+03	15800.00
39124E	2017-07-02 18:09:00+03	49600.00
3912CD	2017-07-01 13:23:00+03	48800.00
3912D2	2017-08-08 03:54:00+03	66900.00
391315	2017-07-17 14:55:00+03	67400.00
3913C8	2017-07-12 16:04:00+03	112400.00
3913E1	2017-08-04 07:28:00+03	189100.00
391489	2017-07-18 18:34:00+03	30200.00
391493	2017-08-15 13:32:00+03	13000.00
3914C7	2017-08-15 01:32:00+03	156500.00
391522	2017-07-14 22:16:00+03	34000.00
3915B1	2017-08-14 09:02:00+03	22000.00
3915EB	2017-07-07 18:43:00+03	99200.00
391608	2017-08-02 01:55:00+03	12400.00
391609	2017-07-07 04:08:00+03	40200.00
391731	2017-08-15 01:40:00+03	26000.00
391779	2017-08-08 04:12:00+03	38800.00
3917C5	2017-07-10 21:54:00+03	13600.00
3917E9	2017-07-17 16:08:00+03	49200.00
391841	2017-08-11 03:53:00+03	28800.00
39184F	2017-07-12 22:19:00+03	166000.00
39186F	2017-07-16 12:11:00+03	113700.00
3918CD	2017-08-11 05:30:00+03	24800.00
391984	2017-08-04 16:41:00+03	168300.00
3919D7	2017-07-10 22:22:00+03	143600.00
3919DD	2017-07-21 23:38:00+03	17600.00
3919EA	2017-08-03 08:18:00+03	103200.00
391ACF	2017-07-01 23:37:00+03	30400.00
391AF3	2017-07-05 01:53:00+03	71200.00
391AF9	2017-07-10 12:47:00+03	106100.00
391B8A	2017-06-28 10:40:00+03	46700.00
391BDF	2017-07-16 18:58:00+03	31400.00
391C3E	2017-07-07 19:49:00+03	25800.00
391C8B	2017-07-31 00:20:00+03	38800.00
391C90	2017-07-18 20:54:00+03	56900.00
391D25	2017-08-11 10:13:00+03	35200.00
391D7B	2017-07-13 20:22:00+03	25000.00
391DE7	2017-08-11 20:14:00+03	26000.00
391E9B	2017-07-14 16:40:00+03	257500.00
391F01	2017-08-13 08:43:00+03	60700.00
391F02	2017-06-30 14:02:00+03	176400.00
391F16	2017-07-21 18:47:00+03	78000.00
391F7B	2017-07-12 17:49:00+03	20000.00
39202D	2017-07-16 02:06:00+03	117100.00
392065	2017-08-03 07:23:00+03	42800.00
392083	2017-08-01 11:56:00+03	58000.00
3920D0	2017-07-25 22:24:00+03	187400.00
3920ED	2017-07-19 20:27:00+03	111600.00
392122	2017-07-07 19:28:00+03	59200.00
392185	2017-07-18 08:31:00+03	20200.00
3921FF	2017-07-19 09:41:00+03	167300.00
392223	2017-07-15 04:07:00+03	57800.00
392254	2017-07-24 01:41:00+03	38800.00
3922D5	2017-07-15 04:59:00+03	119700.00
3922E3	2017-07-07 19:11:00+03	123000.00
39232C	2017-08-02 22:50:00+03	6800.00
3923E9	2017-07-15 01:44:00+03	88600.00
392433	2017-07-15 03:48:00+03	87100.00
39243D	2017-08-09 12:41:00+03	23900.00
392478	2017-08-01 18:32:00+03	86600.00
3924A8	2017-08-02 05:01:00+03	12000.00
3924D9	2017-07-13 01:44:00+03	112000.00
39254B	2017-08-15 03:08:00+03	147600.00
392563	2017-07-16 17:33:00+03	222400.00
392587	2017-08-10 19:59:00+03	97900.00
3925BF	2017-08-12 10:57:00+03	28000.00
39261F	2017-07-25 09:30:00+03	13400.00
392649	2017-08-09 11:14:00+03	28800.00
3926AA	2017-08-08 10:26:00+03	86300.00
3926AE	2017-08-05 10:19:00+03	54800.00
39270A	2017-07-19 15:49:00+03	28000.00
392723	2017-07-23 03:51:00+03	77000.00
392782	2017-07-31 16:48:00+03	6900.00
3927A0	2017-08-14 00:18:00+03	99500.00
3927B4	2017-07-08 06:51:00+03	21400.00
392821	2017-07-16 06:44:00+03	136800.00
39282F	2017-07-16 10:00:00+03	20600.00
39284A	2017-08-08 17:41:00+03	139000.00
392856	2017-07-29 18:46:00+03	115400.00
392897	2017-07-20 10:04:00+03	31100.00
3928BE	2017-08-07 10:41:00+03	81700.00
3929BE	2017-07-01 03:07:00+03	87000.00
3929E9	2017-08-11 20:51:00+03	21800.00
392AD7	2017-07-28 06:05:00+03	43500.00
392B2A	2017-07-23 20:16:00+03	38600.00
392B94	2017-07-09 19:20:00+03	10800.00
392BDF	2017-07-29 22:44:00+03	19600.00
392BF5	2017-07-31 18:18:00+03	68800.00
392C9B	2017-07-11 08:50:00+03	273000.00
392CA5	2017-07-18 03:08:00+03	8200.00
392CBE	2017-07-04 15:28:00+03	26700.00
392CEB	2017-08-12 20:28:00+03	31600.00
392D09	2017-07-13 03:48:00+03	71400.00
392D0A	2017-08-07 17:45:00+03	19600.00
392D12	2017-07-18 20:50:00+03	56100.00
392D35	2017-08-14 05:50:00+03	78800.00
392DB6	2017-07-20 18:06:00+03	69900.00
392E4D	2017-07-06 19:56:00+03	23200.00
392EB9	2017-07-05 18:30:00+03	99500.00
392EE2	2017-08-01 14:23:00+03	46400.00
392F19	2017-08-05 17:11:00+03	198400.00
392F46	2017-07-27 21:38:00+03	24000.00
392F69	2017-08-13 06:35:00+03	48400.00
392F75	2017-07-26 19:25:00+03	29600.00
392F88	2017-07-12 07:14:00+03	46400.00
392FAF	2017-08-06 09:46:00+03	47100.00
392FF3	2017-08-04 22:19:00+03	20200.00
393040	2017-08-04 17:24:00+03	75300.00
393085	2017-08-06 15:03:00+03	88600.00
3930E3	2017-07-16 03:49:00+03	100600.00
39310B	2017-07-23 13:21:00+03	181100.00
39313C	2017-07-28 12:52:00+03	21800.00
393148	2017-08-09 17:07:00+03	26100.00
393245	2017-08-15 04:31:00+03	10800.00
3932DE	2017-07-29 17:36:00+03	63800.00
3932EE	2017-07-18 03:36:00+03	52000.00
3932F3	2017-08-09 15:44:00+03	38600.00
3932F7	2017-07-24 23:46:00+03	92600.00
39336D	2017-07-02 12:33:00+03	114800.00
3933C5	2017-08-11 19:03:00+03	136800.00
3933F2	2017-08-08 10:13:00+03	169900.00
393406	2017-08-12 00:04:00+03	20200.00
393476	2017-07-01 06:38:00+03	170000.00
393497	2017-07-21 00:34:00+03	28000.00
3934A6	2017-07-16 04:39:00+03	159000.00
393528	2017-08-07 22:41:00+03	75200.00
393541	2017-08-11 06:20:00+03	202400.00
39355A	2017-07-19 00:20:00+03	26600.00
39358A	2017-07-17 05:58:00+03	101200.00
393598	2017-07-27 06:15:00+03	64700.00
3935E0	2017-07-27 19:39:00+03	56000.00
393623	2017-07-20 06:34:00+03	123000.00
3936CB	2017-07-05 05:53:00+03	135600.00
39374E	2017-07-03 12:35:00+03	42600.00
3937C3	2017-07-18 08:36:00+03	135600.00
3937D9	2017-08-01 22:54:00+03	61200.00
39381F	2017-07-21 09:14:00+03	13400.00
393820	2017-07-08 04:35:00+03	66600.00
393840	2017-07-29 12:30:00+03	115900.00
393943	2017-07-26 16:37:00+03	28300.00
393951	2017-06-29 17:31:00+03	198300.00
393976	2017-07-22 14:55:00+03	52300.00
3939A1	2017-07-05 06:42:00+03	67700.00
393A3D	2017-07-27 03:59:00+03	118100.00
393AA3	2017-08-02 14:48:00+03	30200.00
393AC1	2017-07-01 16:18:00+03	16400.00
393B8B	2017-07-22 21:28:00+03	26800.00
393BC2	2017-08-04 20:22:00+03	46400.00
393C31	2017-07-06 13:16:00+03	170000.00
393CC1	2017-08-12 05:14:00+03	134800.00
393CEE	2017-07-05 10:20:00+03	49600.00
393CFE	2017-08-11 08:24:00+03	16400.00
393D72	2017-07-24 15:39:00+03	28000.00
393D84	2017-07-04 22:49:00+03	138100.00
393D9E	2017-06-29 01:09:00+03	25600.00
393DB2	2017-08-02 11:40:00+03	48400.00
393DE5	2017-08-11 05:26:00+03	44000.00
393DF4	2017-08-02 17:16:00+03	57100.00
393E36	2017-07-29 00:44:00+03	65400.00
394002	2017-07-01 19:51:00+03	18300.00
39409B	2017-08-09 13:48:00+03	257500.00
3940D5	2017-07-12 07:58:00+03	63400.00
3940DD	2017-08-01 07:08:00+03	132600.00
3940EC	2017-07-15 05:07:00+03	47400.00
394195	2017-08-07 23:55:00+03	42700.00
394198	2017-06-29 08:50:00+03	44600.00
3941BA	2017-08-12 11:06:00+03	57600.00
394246	2017-08-05 20:14:00+03	28000.00
394248	2017-08-04 17:16:00+03	37900.00
394254	2017-08-03 16:49:00+03	172100.00
3942C6	2017-07-26 02:47:00+03	11600.00
394373	2017-07-21 14:38:00+03	71000.00
39443F	2017-07-27 11:43:00+03	293700.00
3944A5	2017-08-06 03:37:00+03	23200.00
394509	2017-08-10 03:46:00+03	181600.00
39451B	2017-07-06 02:56:00+03	24400.00
394528	2017-08-03 04:48:00+03	92700.00
39457B	2017-07-03 01:03:00+03	112000.00
3945A9	2017-07-20 09:08:00+03	111600.00
3945AA	2017-08-03 11:06:00+03	98200.00
3945B8	2017-08-11 18:26:00+03	31600.00
3945CF	2017-07-27 09:54:00+03	28000.00
394623	2017-07-27 14:43:00+03	64600.00
39462F	2017-08-01 14:53:00+03	56200.00
3946E9	2017-07-11 20:19:00+03	35800.00
394797	2017-08-05 00:37:00+03	91300.00
3947C7	2017-08-07 19:11:00+03	147700.00
39480B	2017-08-15 00:17:00+03	14400.00
394824	2017-07-14 04:36:00+03	29600.00
394859	2017-07-19 14:13:00+03	25200.00
3948E7	2017-07-04 22:29:00+03	99700.00
394927	2017-08-03 21:10:00+03	14000.00
3949D1	2017-07-09 19:45:00+03	31400.00
3949D6	2017-07-22 03:54:00+03	21400.00
394A39	2017-08-11 08:01:00+03	194800.00
394A6E	2017-08-14 04:28:00+03	7400.00
394AD1	2017-08-10 08:35:00+03	125200.00
394AF3	2017-08-07 11:00:00+03	21800.00
394B00	2017-07-28 12:14:00+03	75600.00
394B38	2017-07-13 01:57:00+03	72300.00
394B41	2017-07-22 23:14:00+03	67600.00
394B5C	2017-08-07 16:02:00+03	28000.00
394B83	2017-07-15 00:37:00+03	123000.00
394BB7	2017-08-10 03:41:00+03	24300.00
394BD8	2017-07-18 12:38:00+03	70700.00
394BEB	2017-07-04 16:54:00+03	40300.00
394C9D	2017-07-14 07:57:00+03	49500.00
394CDB	2017-08-03 13:08:00+03	58000.00
394D32	2017-08-01 01:41:00+03	21800.00
394D75	2017-07-04 05:03:00+03	39200.00
394D7B	2017-07-30 15:07:00+03	81200.00
394DF3	2017-07-03 11:06:00+03	43600.00
394E83	2017-07-31 17:10:00+03	42000.00
394EAF	2017-08-15 13:20:00+03	205200.00
394EC1	2017-08-15 05:06:00+03	28400.00
394ECB	2017-07-21 04:45:00+03	61800.00
394F74	2017-07-28 13:38:00+03	175900.00
395009	2017-08-15 14:18:00+03	75300.00
395114	2017-07-05 00:10:00+03	122700.00
395115	2017-07-21 16:30:00+03	46000.00
3951B7	2017-08-11 15:19:00+03	47200.00
3951DB	2017-07-18 19:37:00+03	270200.00
395228	2017-07-19 01:54:00+03	23200.00
395293	2017-08-09 05:17:00+03	7400.00
39531A	2017-07-01 15:07:00+03	123000.00
3953A4	2017-07-05 04:41:00+03	10800.00
39543A	2017-08-09 21:29:00+03	46000.00
3954C1	2017-08-05 13:49:00+03	125500.00
395513	2017-08-12 02:12:00+03	8400.00
395519	2017-08-10 10:10:00+03	99200.00
395531	2017-08-12 17:12:00+03	26000.00
3955F6	2017-07-06 02:44:00+03	68800.00
39564D	2017-07-28 03:14:00+03	6800.00
39566A	2017-08-14 08:50:00+03	38200.00
39567F	2017-08-09 13:41:00+03	289800.00
3956CC	2017-08-10 12:38:00+03	12700.00
395702	2017-07-23 18:30:00+03	134800.00
395769	2017-07-19 22:38:00+03	37900.00
3957A6	2017-08-14 01:45:00+03	32800.00
3957D1	2017-07-30 19:57:00+03	89600.00
395800	2017-07-12 11:43:00+03	16400.00
395825	2017-07-23 07:31:00+03	45200.00
39582D	2017-07-10 04:45:00+03	9200.00
395898	2017-07-24 03:39:00+03	43400.00
39591B	2017-08-01 20:43:00+03	128800.00
395A06	2017-08-04 07:01:00+03	36800.00
395A45	2017-07-10 22:25:00+03	18800.00
395A6A	2017-07-29 20:06:00+03	193300.00
395A81	2017-08-06 15:37:00+03	31100.00
395AD4	2017-08-13 15:00:00+03	26700.00
395B03	2017-07-07 15:04:00+03	111600.00
395B5A	2017-07-08 13:11:00+03	148300.00
395B64	2017-08-07 04:54:00+03	24000.00
395B66	2017-08-06 23:05:00+03	26200.00
395B91	2017-08-08 03:33:00+03	13000.00
395B96	2017-06-30 08:25:00+03	134600.00
395BAC	2017-08-12 00:44:00+03	28200.00
395BAE	2017-08-09 04:04:00+03	260900.00
395C24	2017-08-10 02:34:00+03	102000.00
395C3C	2017-07-25 18:46:00+03	97100.00
395C6F	2017-08-12 04:53:00+03	78600.00
395C89	2017-08-11 18:56:00+03	46400.00
395CC3	2017-07-11 19:06:00+03	43800.00
395CDC	2017-08-14 11:39:00+03	24400.00
395D18	2017-08-07 18:44:00+03	115900.00
395D49	2017-08-01 03:46:00+03	140900.00
395D7F	2017-07-20 15:45:00+03	29800.00
395DDF	2017-08-02 14:21:00+03	265700.00
395DE6	2017-07-21 11:29:00+03	214900.00
395DF6	2017-08-09 19:12:00+03	133200.00
395E18	2017-08-13 02:48:00+03	23200.00
395EAE	2017-08-13 14:21:00+03	13400.00
395EAF	2017-08-09 04:25:00+03	13200.00
395F5F	2017-07-03 18:09:00+03	123900.00
395FCC	2017-08-02 22:47:00+03	278700.00
395FF6	2017-08-04 04:55:00+03	60200.00
396011	2017-08-01 07:12:00+03	369000.00
396018	2017-07-08 17:40:00+03	40000.00
396047	2017-08-05 14:42:00+03	99200.00
39606F	2017-08-12 15:04:00+03	92000.00
39610E	2017-07-23 01:27:00+03	68400.00
396176	2017-07-17 20:53:00+03	56000.00
39617B	2017-08-09 00:47:00+03	47400.00
3961F2	2017-08-01 18:58:00+03	153600.00
39623B	2017-08-05 08:41:00+03	66600.00
396276	2017-07-16 08:40:00+03	59800.00
396283	2017-08-04 12:07:00+03	257500.00
3962B9	2017-08-01 18:10:00+03	35300.00
3962BD	2017-08-13 21:32:00+03	40300.00
396351	2017-07-25 13:41:00+03	166700.00
3963D4	2017-07-13 08:24:00+03	79900.00
3963EA	2017-08-06 08:48:00+03	175200.00
3963FF	2017-07-09 02:48:00+03	49900.00
396461	2017-08-13 01:48:00+03	38400.00
396519	2017-07-09 15:27:00+03	88800.00
39653D	2017-08-15 08:09:00+03	8200.00
396583	2017-07-11 08:52:00+03	48100.00
3965F4	2017-07-14 16:32:00+03	100600.00
396606	2017-07-06 17:32:00+03	117900.00
3966A0	2017-08-10 17:56:00+03	21000.00
396702	2017-07-05 00:35:00+03	46400.00
396706	2017-07-15 14:55:00+03	135600.00
39672F	2017-07-07 13:21:00+03	44600.00
39679C	2017-07-13 10:35:00+03	19800.00
3967A9	2017-07-23 07:52:00+03	39600.00
3967D5	2017-07-18 23:55:00+03	71600.00
3967ED	2017-07-11 20:24:00+03	19600.00
3967FC	2017-07-19 00:40:00+03	133200.00
39682D	2017-07-05 13:10:00+03	96800.00
39682E	2017-07-28 04:21:00+03	46400.00
39687B	2017-08-13 09:05:00+03	102100.00
39691A	2017-08-05 19:00:00+03	58200.00
396962	2017-08-06 22:00:00+03	363600.00
39697B	2017-08-02 12:21:00+03	16400.00
3969D6	2017-08-01 07:25:00+03	62000.00
3969FF	2017-08-06 07:30:00+03	42800.00
396A2B	2017-07-31 03:42:00+03	12000.00
396AA4	2017-07-18 02:38:00+03	38400.00
396B34	2017-08-13 18:24:00+03	26200.00
396BB2	2017-07-20 14:52:00+03	28700.00
396C3E	2017-08-06 07:14:00+03	114200.00
396C62	2017-07-14 08:44:00+03	12600.00
396C83	2017-07-30 08:31:00+03	38800.00
396C85	2017-08-08 04:14:00+03	44800.00
396CC3	2017-07-03 13:47:00+03	15000.00
396D1B	2017-07-19 01:37:00+03	32200.00
396D43	2017-08-04 08:34:00+03	32900.00
396D6C	2017-08-08 10:50:00+03	40300.00
396DAE	2017-07-11 19:48:00+03	69400.00
396DE5	2017-08-01 23:10:00+03	11300.00
396E65	2017-07-12 09:14:00+03	50600.00
396E6F	2017-07-03 08:03:00+03	47900.00
396EDC	2017-07-31 11:21:00+03	12400.00
396F0F	2017-08-03 04:44:00+03	50600.00
396F29	2017-07-17 13:04:00+03	67000.00
396F54	2017-07-11 13:26:00+03	56600.00
396F87	2017-08-07 10:59:00+03	26400.00
396FDF	2017-08-10 06:05:00+03	11600.00
396FE0	2017-07-02 01:27:00+03	21400.00
39700A	2017-07-18 22:10:00+03	54800.00
3970A1	2017-08-10 07:50:00+03	289800.00
3970A9	2017-07-15 11:54:00+03	81800.00
3970B7	2017-07-10 05:18:00+03	24800.00
3970D4	2017-08-03 19:10:00+03	187600.00
3970E3	2017-06-29 08:08:00+03	19300.00
39718E	2017-07-14 05:02:00+03	103500.00
3971A8	2017-08-06 05:16:00+03	116400.00
3971E5	2017-08-04 09:49:00+03	110700.00
397301	2017-07-21 22:38:00+03	26700.00
39739A	2017-07-23 07:01:00+03	18300.00
397404	2017-07-01 10:33:00+03	40800.00
3974DB	2017-07-28 13:26:00+03	63200.00
397503	2017-07-10 14:09:00+03	16400.00
397504	2017-07-09 23:37:00+03	135200.00
397517	2017-07-12 08:53:00+03	82200.00
3975E9	2017-07-29 02:59:00+03	135400.00
39762F	2017-08-14 19:06:00+03	271200.00
3976CD	2017-07-30 17:26:00+03	28000.00
3976F7	2017-07-24 16:40:00+03	142400.00
397702	2017-07-21 10:20:00+03	136200.00
3977A2	2017-07-09 02:17:00+03	115900.00
3977E7	2017-07-28 18:32:00+03	84500.00
397828	2017-08-13 04:30:00+03	50000.00
39792A	2017-08-11 12:44:00+03	116400.00
39799A	2017-07-23 16:37:00+03	41200.00
397A3D	2017-07-13 21:54:00+03	33300.00
397AB1	2017-07-03 18:26:00+03	189800.00
397B04	2017-07-20 05:47:00+03	43000.00
397B0E	2017-08-11 15:01:00+03	28800.00
397C30	2017-08-12 17:49:00+03	8200.00
397C3C	2017-07-04 03:54:00+03	91100.00
397CA0	2017-07-09 01:53:00+03	56000.00
397CBD	2017-07-18 08:00:00+03	25900.00
397CC5	2017-07-18 18:43:00+03	44800.00
397CE2	2017-08-11 18:48:00+03	68100.00
397CED	2017-07-23 02:34:00+03	57500.00
397D11	2017-08-09 02:26:00+03	20200.00
397D17	2017-07-19 08:16:00+03	93700.00
397D32	2017-07-29 14:41:00+03	99300.00
397DB7	2017-07-23 16:09:00+03	50000.00
397DC6	2017-07-28 17:00:00+03	81700.00
397E76	2017-07-06 17:02:00+03	28000.00
397EAA	2017-08-15 06:19:00+03	19600.00
397EE2	2017-08-08 15:53:00+03	14400.00
397F26	2017-07-14 05:37:00+03	39300.00
397FA1	2017-08-01 22:44:00+03	46400.00
397FB0	2017-07-17 06:17:00+03	119500.00
397FDC	2017-06-29 13:50:00+03	156500.00
39808D	2017-07-23 16:30:00+03	135400.00
398259	2017-08-08 12:31:00+03	72200.00
39828E	2017-07-24 17:38:00+03	91900.00
398339	2017-07-02 21:06:00+03	64300.00
398340	2017-07-16 05:16:00+03	75600.00
39834C	2017-08-02 16:25:00+03	29600.00
3983F9	2017-07-13 00:22:00+03	56000.00
39842B	2017-08-01 01:14:00+03	496600.00
398451	2017-07-25 06:11:00+03	40800.00
39846D	2017-08-11 23:19:00+03	126900.00
39848A	2017-08-01 06:10:00+03	46400.00
39848B	2017-07-10 19:29:00+03	72400.00
3984B9	2017-07-21 19:23:00+03	92800.00
398508	2017-08-02 21:45:00+03	23200.00
39856B	2017-07-10 22:01:00+03	98200.00
39857B	2017-08-03 23:14:00+03	199700.00
398583	2017-07-05 01:15:00+03	28000.00
398585	2017-07-05 08:04:00+03	54200.00
398663	2017-08-02 00:18:00+03	101200.00
3986C4	2017-08-01 12:17:00+03	72400.00
39870F	2017-07-24 00:47:00+03	52700.00
39875E	2017-07-08 07:30:00+03	56000.00
3987B9	2017-07-23 19:10:00+03	18600.00
3987C2	2017-07-19 21:21:00+03	52700.00
3987EE	2017-08-12 23:29:00+03	184300.00
398877	2017-07-24 07:59:00+03	177200.00
3988E5	2017-08-07 00:20:00+03	156300.00
3988FB	2017-07-28 06:26:00+03	28000.00
3989DE	2017-07-04 06:39:00+03	23200.00
398A15	2017-07-10 05:47:00+03	24000.00
398A27	2017-08-04 18:25:00+03	103400.00
398A3C	2017-07-12 18:47:00+03	105100.00
398ACD	2017-08-07 23:29:00+03	51900.00
398AFA	2017-08-11 02:49:00+03	130300.00
398B1F	2017-07-27 14:48:00+03	75600.00
398B5F	2017-08-12 09:10:00+03	354400.00
398BD8	2017-07-31 05:38:00+03	28000.00
398CD5	2017-07-27 01:42:00+03	50600.00
398D15	2017-07-22 07:58:00+03	75300.00
398D56	2017-07-05 01:48:00+03	42700.00
398D95	2017-08-10 16:31:00+03	187600.00
398DB1	2017-06-30 06:10:00+03	26000.00
398DB9	2017-07-27 08:55:00+03	28000.00
398DE9	2017-07-11 18:54:00+03	54500.00
398EA1	2017-07-28 01:01:00+03	17200.00
398ED7	2017-08-08 07:31:00+03	15900.00
398EEA	2017-07-26 13:43:00+03	246000.00
398EF1	2017-07-25 17:17:00+03	139500.00
398FF7	2017-08-02 14:20:00+03	69100.00
399046	2017-06-29 11:04:00+03	27800.00
399089	2017-08-08 21:13:00+03	201800.00
3990D2	2017-07-24 20:52:00+03	62800.00
3990E4	2017-07-07 07:29:00+03	46000.00
39910E	2017-07-03 10:58:00+03	92800.00
399191	2017-08-11 03:47:00+03	55800.00
39919D	2017-07-27 18:41:00+03	28000.00
3991D3	2017-08-06 16:51:00+03	11000.00
3991EA	2017-08-15 01:20:00+03	87100.00
399223	2017-07-09 18:03:00+03	133200.00
399226	2017-08-07 19:46:00+03	75800.00
399274	2017-07-20 14:48:00+03	68000.00
3992CE	2017-08-04 19:44:00+03	29400.00
399304	2017-06-29 10:28:00+03	45200.00
399341	2017-07-22 02:47:00+03	40200.00
399343	2017-07-18 06:05:00+03	242600.00
399375	2017-08-09 00:04:00+03	18800.00
3993A9	2017-07-25 22:51:00+03	22100.00
39941C	2017-07-22 19:23:00+03	265700.00
399477	2017-07-26 02:58:00+03	27300.00
399487	2017-07-09 19:01:00+03	6300.00
39951C	2017-07-21 00:30:00+03	54000.00
39955F	2017-07-08 18:16:00+03	91200.00
3995D2	2017-08-06 20:17:00+03	43500.00
39963E	2017-07-16 08:35:00+03	39200.00
39969D	2017-07-29 12:01:00+03	14400.00
3996CD	2017-08-10 11:55:00+03	398400.00
399718	2017-07-06 02:26:00+03	198400.00
39974F	2017-07-09 14:37:00+03	25100.00
3997B0	2017-07-14 06:31:00+03	23200.00
399804	2017-08-11 17:02:00+03	64500.00
399813	2017-08-07 12:45:00+03	43600.00
399860	2017-07-15 11:41:00+03	56900.00
399864	2017-07-12 23:25:00+03	188300.00
39988F	2017-08-12 09:13:00+03	119500.00
3998A7	2017-07-18 10:30:00+03	136600.00
399968	2017-07-16 05:20:00+03	56000.00
3999E7	2017-07-26 17:33:00+03	76800.00
399A16	2017-08-08 05:46:00+03	56000.00
399A42	2017-07-27 19:49:00+03	61800.00
399A87	2017-08-13 23:23:00+03	27900.00
399A8F	2017-07-19 03:08:00+03	24000.00
399AE0	2017-08-13 14:23:00+03	64000.00
399AF3	2017-07-18 12:04:00+03	55800.00
399B08	2017-08-09 04:09:00+03	669500.00
399B3D	2017-08-04 00:28:00+03	89600.00
399B8B	2017-07-01 00:52:00+03	404600.00
399BF7	2017-07-03 13:48:00+03	66000.00
399C65	2017-07-25 23:42:00+03	6700.00
399CA5	2017-07-29 17:13:00+03	23600.00
399CEC	2017-07-23 06:03:00+03	25200.00
399D93	2017-08-05 07:42:00+03	166100.00
399DE8	2017-07-06 06:19:00+03	58900.00
399E06	2017-07-04 23:39:00+03	135600.00
399E18	2017-07-21 12:44:00+03	18600.00
399EBB	2017-07-19 23:29:00+03	28000.00
399ECA	2017-07-19 22:25:00+03	55800.00
399F21	2017-06-27 15:33:00+03	83000.00
399F6E	2017-07-24 19:47:00+03	112000.00
39A00A	2017-07-20 06:06:00+03	206800.00
39A049	2017-08-07 02:19:00+03	93700.00
39A0FD	2017-08-07 18:15:00+03	30900.00
39A0FE	2017-08-14 07:11:00+03	16000.00
39A113	2017-08-11 11:05:00+03	47700.00
39A11B	2017-07-11 16:12:00+03	67200.00
39A187	2017-07-24 01:37:00+03	40800.00
39A20A	2017-07-08 11:40:00+03	192400.00
39A21B	2017-07-20 21:45:00+03	117600.00
39A24D	2017-07-27 02:11:00+03	71800.00
39A2A1	2017-07-28 17:45:00+03	6700.00
39A2CB	2017-08-11 14:39:00+03	23200.00
39A307	2017-08-01 16:31:00+03	101200.00
39A31E	2017-07-11 06:23:00+03	72400.00
39A330	2017-07-06 20:33:00+03	123600.00
39A374	2017-06-29 15:00:00+03	135400.00
39A3BA	2017-07-09 21:20:00+03	186900.00
39A45D	2017-08-12 06:02:00+03	81500.00
39A45E	2017-07-22 09:36:00+03	112600.00
39A478	2017-08-09 00:54:00+03	92800.00
39A4A4	2017-08-01 23:46:00+03	41500.00
39A4D6	2017-07-18 20:01:00+03	62600.00
39A5A0	2017-08-04 18:45:00+03	28800.00
39A5A8	2017-08-13 21:38:00+03	121400.00
39A696	2017-07-19 07:04:00+03	40000.00
39A713	2017-07-25 00:29:00+03	92800.00
39A724	2017-07-16 20:13:00+03	14400.00
39A7C6	2017-07-26 11:14:00+03	26000.00
39A81D	2017-07-19 15:04:00+03	28000.00
39A859	2017-07-27 09:40:00+03	115800.00
39A896	2017-07-11 12:19:00+03	91100.00
39A89F	2017-07-22 13:56:00+03	25600.00
39A8A5	2017-07-07 21:23:00+03	32200.00
39A8B9	2017-07-05 03:45:00+03	24800.00
39A8C2	2017-07-22 20:18:00+03	70600.00
39A8C6	2017-07-02 09:35:00+03	281500.00
39A8C7	2017-07-03 22:36:00+03	246000.00
39A96B	2017-08-11 00:24:00+03	18600.00
39A98E	2017-07-24 06:05:00+03	32800.00
39A9B1	2017-07-16 03:02:00+03	34600.00
39A9B6	2017-07-01 17:14:00+03	59400.00
39A9EA	2017-08-02 03:25:00+03	10800.00
39AA48	2017-07-14 04:22:00+03	74900.00
39AA82	2017-07-26 16:05:00+03	92000.00
39AA8F	2017-07-16 12:44:00+03	46400.00
39AAB9	2017-08-08 03:34:00+03	142600.00
39AACA	2017-07-16 10:25:00+03	100600.00
39AAE6	2017-06-30 07:28:00+03	46300.00
39AB00	2017-07-24 20:40:00+03	26600.00
39AB4B	2017-08-10 09:08:00+03	106000.00
39AB75	2017-07-09 11:11:00+03	23200.00
39AB90	2017-07-04 21:17:00+03	102700.00
39AB94	2017-07-18 09:34:00+03	89700.00
39ABB9	2017-07-08 02:35:00+03	99200.00
39ABF7	2017-08-10 10:45:00+03	40800.00
39AC02	2017-07-07 01:30:00+03	47100.00
39AC0B	2017-07-30 17:49:00+03	100700.00
39AC6E	2017-07-19 14:53:00+03	147200.00
39ACCD	2017-08-03 18:06:00+03	95100.00
39AD0F	2017-08-13 21:00:00+03	56600.00
39AD4C	2017-08-11 02:34:00+03	374700.00
39AD4F	2017-07-17 11:22:00+03	57800.00
39AD6B	2017-07-14 11:28:00+03	56000.00
39AD80	2017-08-15 15:27:00+03	110200.00
39ADAA	2017-08-13 02:04:00+03	85000.00
39ADF2	2017-08-08 08:23:00+03	249300.00
39AE04	2017-08-06 15:26:00+03	25400.00
39AE2A	2017-08-06 11:08:00+03	8200.00
39AE61	2017-08-11 04:07:00+03	146300.00
39AED0	2017-07-03 01:52:00+03	196000.00
39AF7C	2017-08-04 18:36:00+03	86600.00
39AFAA	2017-07-12 00:02:00+03	51200.00
39AFB4	2017-07-20 17:50:00+03	294000.00
39B050	2017-07-16 13:02:00+03	113000.00
39B090	2017-07-13 03:17:00+03	27600.00
39B092	2017-07-11 09:06:00+03	99200.00
39B094	2017-08-13 12:19:00+03	19800.00
39B0C8	2017-08-11 10:23:00+03	23100.00
39B0E8	2017-07-23 00:06:00+03	21400.00
39B12B	2017-07-23 22:35:00+03	46000.00
39B15B	2017-07-18 20:56:00+03	119500.00
39B187	2017-07-22 05:27:00+03	14400.00
39B1B1	2017-07-03 16:56:00+03	36400.00
39B1B2	2017-07-06 19:57:00+03	109800.00
39B1B8	2017-08-13 17:07:00+03	31800.00
39B215	2017-07-30 23:16:00+03	42800.00
39B255	2017-08-06 18:44:00+03	241400.00
39B296	2017-07-20 22:09:00+03	73200.00
39B2B8	2017-07-18 04:02:00+03	47000.00
39B315	2017-07-09 04:39:00+03	29600.00
39B3CE	2017-07-10 06:41:00+03	38800.00
39B3D5	2017-07-21 22:44:00+03	55800.00
39B3F1	2017-08-13 11:36:00+03	47100.00
39B3FE	2017-08-11 07:03:00+03	532800.00
39B464	2017-07-04 16:24:00+03	17800.00
39B46A	2017-08-08 22:21:00+03	29600.00
39B4AF	2017-07-15 00:17:00+03	258300.00
39B4C3	2017-08-02 02:57:00+03	35200.00
39B4C7	2017-07-20 23:57:00+03	42500.00
39B4CB	2017-07-05 03:13:00+03	76600.00
39B50A	2017-07-08 12:57:00+03	40800.00
39B528	2017-07-28 23:56:00+03	38400.00
39B52D	2017-07-20 22:51:00+03	21400.00
39B543	2017-07-21 23:50:00+03	117600.00
39B569	2017-07-02 09:59:00+03	40300.00
39B5E5	2017-07-07 02:41:00+03	86400.00
39B5E8	2017-07-29 13:08:00+03	58200.00
39B5EB	2017-07-31 10:38:00+03	139500.00
39B604	2017-08-07 05:29:00+03	54100.00
39B674	2017-08-14 16:37:00+03	79900.00
39B6B0	2017-08-03 15:22:00+03	57400.00
39B6BD	2017-07-14 11:28:00+03	58600.00
39B6FD	2017-07-21 23:57:00+03	28000.00
39B708	2017-08-13 23:47:00+03	14400.00
39B76C	2017-08-10 12:32:00+03	24000.00
39B76F	2017-07-07 21:43:00+03	99200.00
39B7DC	2017-08-11 08:07:00+03	155100.00
39B806	2017-07-26 02:28:00+03	35200.00
39B8F8	2017-07-09 09:46:00+03	56900.00
39B962	2017-08-02 05:45:00+03	14000.00
39B98F	2017-07-06 21:49:00+03	24800.00
39B9AD	2017-07-21 04:34:00+03	22600.00
39BA54	2017-07-09 22:27:00+03	31600.00
39BA81	2017-07-09 04:08:00+03	64600.00
39BAD7	2017-07-23 03:01:00+03	198400.00
39BBC6	2017-07-09 04:21:00+03	36200.00
39BC46	2017-07-07 09:58:00+03	47000.00
39BC63	2017-07-23 14:30:00+03	28000.00
39BF07	2017-07-21 07:24:00+03	23400.00
39BF5A	2017-07-12 14:19:00+03	32800.00
39C02C	2017-07-06 03:46:00+03	143200.00
39C078	2017-08-04 05:09:00+03	28000.00
39C0AD	2017-07-21 22:00:00+03	85700.00
39C0C4	2017-08-07 14:08:00+03	75800.00
39C10D	2017-07-15 17:15:00+03	28000.00
39C134	2017-08-03 10:37:00+03	27900.00
39C179	2017-06-29 00:46:00+03	30900.00
39C21D	2017-07-15 10:17:00+03	66600.00
39C28A	2017-07-28 01:27:00+03	31800.00
39C296	2017-07-18 07:45:00+03	7400.00
39C2EE	2017-07-22 01:14:00+03	16400.00
39C35E	2017-07-21 01:12:00+03	31600.00
39C363	2017-07-30 20:24:00+03	47700.00
39C3CE	2017-08-14 04:19:00+03	12600.00
39C469	2017-07-12 15:57:00+03	67600.00
39C4DC	2017-08-06 06:04:00+03	28000.00
39C538	2017-07-08 01:25:00+03	66000.00
39C553	2017-07-04 23:06:00+03	529200.00
39C583	2017-08-11 11:30:00+03	111600.00
39C5C3	2017-07-23 02:56:00+03	7400.00
39C604	2017-08-04 23:29:00+03	46000.00
39C636	2017-07-30 22:33:00+03	101500.00
39C647	2017-07-19 17:54:00+03	56900.00
39C670	2017-07-23 08:23:00+03	43200.00
39C68D	2017-07-27 21:21:00+03	27200.00
39C6A4	2017-07-16 13:08:00+03	6600.00
39C726	2017-08-11 02:43:00+03	8200.00
39C73B	2017-07-29 02:17:00+03	18800.00
39C796	2017-07-05 03:40:00+03	70800.00
39C7E2	2017-07-21 00:58:00+03	13300.00
39C82F	2017-07-24 23:35:00+03	93900.00
39C84C	2017-08-07 00:15:00+03	37900.00
39C896	2017-07-29 09:47:00+03	46500.00
39C89B	2017-06-25 09:56:00+03	40400.00
39C8B1	2017-08-14 03:24:00+03	24700.00
39C8E8	2017-07-01 12:56:00+03	32800.00
39C93E	2017-07-20 06:54:00+03	75600.00
39C9EB	2017-07-01 01:36:00+03	31600.00
39CA06	2017-08-02 19:59:00+03	113600.00
39CAAA	2017-07-12 19:01:00+03	56100.00
39CB55	2017-07-07 19:07:00+03	22100.00
39CB7A	2017-07-09 15:19:00+03	92600.00
39CB7B	2017-08-10 10:52:00+03	386300.00
39CBAB	2017-08-04 11:15:00+03	66600.00
39CBD1	2017-08-12 21:31:00+03	77600.00
39CBED	2017-07-29 07:38:00+03	28700.00
39CC15	2017-08-08 11:16:00+03	115800.00
39CC16	2017-07-18 15:51:00+03	25600.00
39CC6A	2017-07-03 23:45:00+03	23600.00
39CC90	2017-07-18 08:24:00+03	132800.00
39CC91	2017-07-10 10:07:00+03	28000.00
39CCA6	2017-08-09 17:22:00+03	207000.00
39CCC0	2017-08-01 04:47:00+03	246000.00
39CD81	2017-07-14 22:40:00+03	28700.00
39CD83	2017-07-01 19:45:00+03	6900.00
39CDC4	2017-07-03 00:03:00+03	31100.00
39CDD4	2017-07-05 00:46:00+03	40400.00
39CDF3	2017-07-12 01:14:00+03	56000.00
39CDFB	2017-06-26 14:45:00+03	16400.00
39CE04	2017-07-10 02:04:00+03	368000.00
39CE22	2017-08-09 20:02:00+03	39300.00
39CE42	2017-07-30 14:47:00+03	40600.00
39CE5E	2017-07-08 16:23:00+03	49800.00
39CE93	2017-07-11 15:21:00+03	16400.00
39CEBC	2017-07-15 03:41:00+03	38400.00
39CEC8	2017-07-30 23:49:00+03	44600.00
39CED7	2017-07-06 13:01:00+03	117200.00
39CF65	2017-08-13 16:22:00+03	51300.00
39CF97	2017-08-04 10:03:00+03	85000.00
39CFCD	2017-06-28 20:38:00+03	11600.00
39D085	2017-08-08 23:03:00+03	169600.00
39D094	2017-07-06 05:49:00+03	23200.00
39D0D3	2017-07-21 19:12:00+03	286600.00
39D1BC	2017-07-29 18:01:00+03	63700.00
39D223	2017-07-11 12:42:00+03	37200.00
39D232	2017-07-15 02:59:00+03	28800.00
39D238	2017-07-08 00:24:00+03	30900.00
39D270	2017-07-22 09:28:00+03	21800.00
39D2BA	2017-07-20 05:29:00+03	12900.00
39D2C1	2017-08-07 18:22:00+03	16000.00
39D2E1	2017-07-15 03:34:00+03	67200.00
39D32B	2017-08-10 00:19:00+03	13200.00
39D347	2017-08-04 11:48:00+03	55800.00
39D35A	2017-07-05 02:56:00+03	28000.00
39D399	2017-08-06 13:21:00+03	408500.00
39D3BB	2017-08-11 13:18:00+03	58800.00
39D3C1	2017-07-12 18:03:00+03	126600.00
39D400	2017-07-04 18:48:00+03	38800.00
39D425	2017-08-15 05:12:00+03	53600.00
39D477	2017-07-28 02:55:00+03	28300.00
39D493	2017-07-12 09:59:00+03	56000.00
39D495	2017-08-14 23:23:00+03	30200.00
39D497	2017-07-15 16:51:00+03	56600.00
39D564	2017-07-18 07:20:00+03	53200.00
39D5BE	2017-08-13 16:12:00+03	28000.00
39D5DD	2017-07-21 09:57:00+03	59800.00
39D61A	2017-08-06 11:08:00+03	25600.00
39D683	2017-08-05 08:18:00+03	52000.00
39D6EA	2017-07-21 00:20:00+03	54000.00
39D84E	2017-08-10 09:36:00+03	12600.00
39D84F	2017-07-28 07:34:00+03	46400.00
39D8B8	2017-08-14 02:51:00+03	296200.00
39D8D8	2017-07-23 05:34:00+03	28800.00
39D99B	2017-07-14 23:53:00+03	73300.00
39DA85	2017-07-12 07:28:00+03	25400.00
39DB07	2017-07-01 15:12:00+03	84100.00
39DB16	2017-08-04 05:37:00+03	40800.00
39DB24	2017-08-08 06:34:00+03	56600.00
39DCD3	2017-07-01 22:52:00+03	38400.00
39DD8A	2017-07-28 03:01:00+03	134400.00
39DEA4	2017-07-07 02:51:00+03	28800.00
39DF0D	2017-07-14 20:44:00+03	89100.00
39DF2B	2017-08-08 22:54:00+03	8400.00
39DFA9	2017-08-07 19:01:00+03	31400.00
39DFAC	2017-08-15 00:32:00+03	96300.00
39E0F3	2017-08-14 02:25:00+03	40000.00
39E120	2017-08-04 07:46:00+03	75300.00
39E171	2017-08-10 10:33:00+03	58000.00
39E196	2017-08-08 14:39:00+03	102100.00
39E1D1	2017-07-06 00:13:00+03	96200.00
39E21B	2017-07-11 10:43:00+03	56000.00
39E221	2017-07-04 08:24:00+03	59200.00
39E234	2017-07-26 01:28:00+03	52300.00
39E24F	2017-07-11 21:11:00+03	103500.00
39E268	2017-08-02 13:49:00+03	12400.00
39E2FA	2017-08-08 20:34:00+03	60400.00
39E336	2017-08-11 15:50:00+03	109000.00
39E353	2017-08-09 00:03:00+03	46200.00
39E35C	2017-07-31 09:32:00+03	57500.00
39E383	2017-07-23 16:31:00+03	36400.00
39E3CC	2017-07-10 16:36:00+03	135600.00
39E3DB	2017-07-06 17:58:00+03	36900.00
39E431	2017-08-03 02:49:00+03	46200.00
39E485	2017-07-30 10:33:00+03	86400.00
39E4A5	2017-08-10 16:29:00+03	56000.00
39E52B	2017-07-29 02:34:00+03	29500.00
39E585	2017-07-25 01:58:00+03	92800.00
39E59A	2017-07-30 18:26:00+03	193700.00
39E5AB	2017-08-04 15:29:00+03	198600.00
39E5D3	2017-07-06 23:31:00+03	67400.00
39E694	2017-08-10 21:44:00+03	389600.00
39E69E	2017-07-09 10:45:00+03	29000.00
39E733	2017-07-23 15:02:00+03	111600.00
39E792	2017-08-01 19:03:00+03	136500.00
39E81B	2017-07-30 17:11:00+03	31600.00
39E852	2017-08-14 03:45:00+03	94200.00
39E85E	2017-07-09 04:58:00+03	123000.00
39E8C8	2017-08-12 23:10:00+03	14000.00
39E943	2017-07-08 10:45:00+03	55800.00
39E95D	2017-08-09 13:39:00+03	189200.00
39E999	2017-07-02 03:23:00+03	27800.00
39E9A2	2017-07-26 19:07:00+03	50700.00
39E9B1	2017-08-01 05:19:00+03	34000.00
39EA33	2017-07-19 08:51:00+03	86800.00
39EA4B	2017-07-05 08:49:00+03	47200.00
39EAE2	2017-08-09 09:51:00+03	50600.00
39EB0D	2017-07-17 10:51:00+03	83000.00
39EB71	2017-07-07 20:55:00+03	26600.00
39EB8B	2017-08-12 05:05:00+03	53400.00
39EBA0	2017-07-24 22:39:00+03	19600.00
39EBA9	2017-07-13 15:33:00+03	55800.00
39EBC4	2017-07-09 11:58:00+03	289500.00
39EBDE	2017-08-14 00:24:00+03	210800.00
39EC17	2017-08-09 00:57:00+03	6300.00
39EC44	2017-08-11 04:23:00+03	37700.00
39EC64	2017-06-30 17:28:00+03	45200.00
39EC79	2017-07-24 16:03:00+03	25100.00
39ED29	2017-08-13 16:26:00+03	192500.00
39ED5B	2017-07-18 15:26:00+03	492000.00
39ED88	2017-07-17 08:48:00+03	40100.00
39EDB8	2017-07-23 03:22:00+03	369000.00
39EE03	2017-07-16 22:16:00+03	49200.00
39EE3C	2017-08-08 19:51:00+03	18600.00
39EE59	2017-07-23 20:47:00+03	355600.00
39EEE0	2017-07-01 08:39:00+03	24400.00
39EF9C	2017-07-12 04:40:00+03	26800.00
39EFC5	2017-07-03 14:16:00+03	191200.00
39EFE0	2017-07-08 23:03:00+03	15400.00
39F01E	2017-07-29 21:37:00+03	55800.00
39F031	2017-08-01 07:35:00+03	113700.00
39F045	2017-07-28 19:03:00+03	134400.00
39F0BE	2017-07-27 17:32:00+03	13400.00
39F0CB	2017-07-12 22:27:00+03	70800.00
39F109	2017-07-08 14:45:00+03	28800.00
39F12A	2017-07-20 07:46:00+03	165800.00
39F17E	2017-08-06 06:55:00+03	47100.00
39F1DF	2017-07-17 18:41:00+03	29600.00
39F243	2017-08-01 20:36:00+03	12600.00
39F252	2017-07-03 09:51:00+03	67200.00
39F265	2017-07-06 20:05:00+03	78800.00
39F27A	2017-07-01 12:23:00+03	43800.00
39F28A	2017-07-23 02:04:00+03	30900.00
39F2AA	2017-07-30 10:03:00+03	34000.00
39F316	2017-07-18 21:16:00+03	54800.00
39F35A	2017-08-01 12:42:00+03	46000.00
39F3E5	2017-08-05 16:36:00+03	77000.00
39F3F6	2017-07-09 22:11:00+03	40400.00
39F4D6	2017-08-14 22:21:00+03	13400.00
39F50E	2017-07-29 08:53:00+03	141400.00
39F5C3	2017-08-02 05:08:00+03	69000.00
39F5E3	2017-07-27 11:04:00+03	59000.00
39F5E5	2017-07-27 21:45:00+03	172700.00
39F635	2017-07-12 14:25:00+03	112400.00
39F644	2017-08-04 11:54:00+03	136300.00
39F66C	2017-07-19 18:10:00+03	30000.00
39F67B	2017-07-05 05:17:00+03	43100.00
39F688	2017-07-03 11:49:00+03	52800.00
39F68C	2017-07-05 01:51:00+03	123000.00
39F6AA	2017-07-31 12:55:00+03	105000.00
39F6F6	2017-06-29 05:10:00+03	49100.00
39F718	2017-08-13 13:36:00+03	24200.00
39F739	2017-08-10 19:58:00+03	252200.00
39F784	2017-07-05 19:29:00+03	57600.00
39F84E	2017-07-30 16:19:00+03	99200.00
39F875	2017-07-19 23:30:00+03	58700.00
39F918	2017-08-07 23:56:00+03	26000.00
39F98D	2017-07-06 01:47:00+03	47200.00
39F999	2017-07-12 00:04:00+03	26600.00
39F9BD	2017-07-14 12:03:00+03	46000.00
39F9C5	2017-07-05 20:15:00+03	31100.00
39FAA8	2017-08-12 01:18:00+03	47200.00
39FAE2	2017-07-11 17:58:00+03	22600.00
39FB78	2017-08-14 21:30:00+03	6300.00
39FBC1	2017-08-06 15:21:00+03	44600.00
39FC4B	2017-08-03 00:03:00+03	21800.00
39FC71	2017-07-28 04:36:00+03	27300.00
39FC80	2017-07-21 03:37:00+03	18300.00
39FD37	2017-08-03 23:03:00+03	173500.00
39FD66	2017-07-24 14:02:00+03	22100.00
39FD6D	2017-08-05 18:00:00+03	13700.00
39FD7A	2017-07-12 10:05:00+03	23200.00
39FDB4	2017-07-30 18:11:00+03	61800.00
39FDBD	2017-08-03 11:35:00+03	133200.00
39FDD6	2017-08-02 21:37:00+03	120100.00
39FE3D	2017-08-10 21:10:00+03	142400.00
39FE55	2017-08-08 11:23:00+03	42800.00
39FE5A	2017-08-03 22:59:00+03	28000.00
39FE94	2017-07-26 06:25:00+03	56000.00
39FF22	2017-07-03 13:42:00+03	57400.00
39FF63	2017-07-14 18:44:00+03	115600.00
39FF8F	2017-07-24 07:11:00+03	66200.00
39FF93	2017-07-19 20:25:00+03	38800.00
3A009F	2017-08-15 06:53:00+03	396500.00
3A00D4	2017-07-11 17:32:00+03	185000.00
3A00E4	2017-08-13 06:44:00+03	92800.00
3A00E7	2017-07-10 07:25:00+03	18800.00
3A017A	2017-07-02 15:18:00+03	28000.00
3A0196	2017-06-28 06:30:00+03	45000.00
3A019E	2017-07-07 18:38:00+03	75600.00
3A01E8	2017-07-09 23:52:00+03	265800.00
3A020D	2017-07-26 15:21:00+03	6000.00
3A0219	2017-07-11 11:22:00+03	59300.00
3A024F	2017-08-11 13:59:00+03	23400.00
3A0319	2017-07-25 03:35:00+03	32200.00
3A0354	2017-07-06 11:19:00+03	79300.00
3A0356	2017-07-26 10:30:00+03	47900.00
3A0361	2017-07-10 11:38:00+03	195800.00
3A03AD	2017-07-03 08:39:00+03	131100.00
3A03AE	2017-07-18 20:50:00+03	67200.00
3A0420	2017-08-03 20:31:00+03	90600.00
3A043B	2017-07-06 08:21:00+03	259100.00
3A047F	2017-07-16 03:20:00+03	62100.00
3A05A6	2017-08-15 06:30:00+03	42800.00
3A0607	2017-07-30 07:16:00+03	153900.00
3A060D	2017-07-22 13:48:00+03	46800.00
3A0695	2017-07-15 17:18:00+03	64500.00
3A06BF	2017-07-05 18:08:00+03	21800.00
3A0708	2017-06-28 20:18:00+03	117600.00
3A075C	2017-07-03 16:43:00+03	55800.00
3A0776	2017-07-23 01:38:00+03	26400.00
3A0789	2017-07-11 11:43:00+03	6800.00
3A0838	2017-08-15 11:47:00+03	51900.00
3A0845	2017-07-20 10:11:00+03	29800.00
3A085A	2017-07-27 02:58:00+03	54000.00
3A089B	2017-08-11 09:08:00+03	61900.00
3A08C9	2017-08-05 09:25:00+03	173500.00
3A08E2	2017-07-23 01:10:00+03	138000.00
3A08FF	2017-08-10 12:29:00+03	201200.00
3A0913	2017-07-23 13:01:00+03	54500.00
3A0935	2017-06-26 16:10:00+03	13800.00
3A097B	2017-08-03 20:38:00+03	42800.00
3A0A2D	2017-07-18 14:24:00+03	58400.00
3A0A76	2017-07-02 00:51:00+03	151800.00
3A0A85	2017-07-26 06:32:00+03	64200.00
3A0B1F	2017-07-12 22:31:00+03	85000.00
3A0B54	2017-08-07 04:52:00+03	80300.00
3A0B80	2017-07-03 21:28:00+03	67600.00
3A0BC0	2017-07-30 04:13:00+03	35600.00
3A0BDD	2017-07-15 02:17:00+03	28800.00
3A0C1C	2017-07-18 10:38:00+03	20200.00
3A0C58	2017-07-26 20:00:00+03	88800.00
3A0CE9	2017-07-22 20:36:00+03	16000.00
3A0CF0	2017-07-18 22:01:00+03	42800.00
3A0DBC	2017-07-18 18:24:00+03	98400.00
3A0DDA	2017-07-16 03:33:00+03	13200.00
3A0E39	2017-08-03 19:45:00+03	92600.00
3A0EB0	2017-07-10 00:37:00+03	48800.00
3A0ECD	2017-08-05 23:28:00+03	24500.00
3A0F1E	2017-07-01 15:10:00+03	35200.00
3A0F21	2017-08-03 05:09:00+03	283700.00
3A0F47	2017-07-01 09:18:00+03	23400.00
3A0F6E	2017-07-06 17:40:00+03	46400.00
3A1002	2017-07-18 18:58:00+03	133100.00
3A1007	2017-07-17 16:55:00+03	98400.00
3A100F	2017-07-29 08:49:00+03	44600.00
3A1020	2017-08-01 02:46:00+03	26000.00
3A1059	2017-07-04 14:23:00+03	34100.00
3A106A	2017-07-29 09:48:00+03	6800.00
3A1086	2017-07-23 05:52:00+03	74800.00
3A10B7	2017-07-06 17:47:00+03	46000.00
3A1102	2017-07-28 21:53:00+03	89600.00
3A1135	2017-07-14 17:22:00+03	67800.00
3A1163	2017-08-11 22:35:00+03	379000.00
3A116B	2017-07-24 17:08:00+03	189200.00
3A11A5	2017-06-29 04:12:00+03	28800.00
3A11CD	2017-07-25 07:01:00+03	60400.00
3A11E8	2017-08-07 16:52:00+03	246000.00
3A1213	2017-07-15 12:55:00+03	47500.00
3A1227	2017-08-15 08:23:00+03	61600.00
3A1266	2017-08-13 22:11:00+03	13400.00
3A1287	2017-07-11 06:23:00+03	24400.00
3A12A3	2017-08-13 09:57:00+03	135600.00
3A12C0	2017-08-08 19:37:00+03	180600.00
3A12F5	2017-08-12 00:10:00+03	246000.00
3A1374	2017-08-07 11:24:00+03	86600.00
3A13A0	2017-08-02 04:47:00+03	58800.00
3A13A3	2017-08-01 02:19:00+03	45200.00
3A13B6	2017-07-16 20:23:00+03	46400.00
3A13DC	2017-08-05 05:57:00+03	56000.00
3A13DF	2017-07-07 21:34:00+03	47000.00
3A1439	2017-07-29 14:01:00+03	61800.00
3A1446	2017-07-26 07:08:00+03	24000.00
3A1458	2017-07-08 19:54:00+03	13600.00
3A149F	2017-08-10 09:23:00+03	26000.00
3A14AF	2017-08-05 19:40:00+03	50000.00
3A14B5	2017-08-06 15:45:00+03	14000.00
3A14C7	2017-06-28 00:27:00+03	47000.00
3A14EE	2017-07-08 02:27:00+03	92600.00
3A150A	2017-08-02 18:31:00+03	199700.00
3A159C	2017-07-07 05:38:00+03	154800.00
3A15CA	2017-08-07 21:55:00+03	36200.00
3A15D1	2017-08-02 00:30:00+03	7400.00
3A15E5	2017-07-06 20:10:00+03	44800.00
3A15F1	2017-07-21 04:16:00+03	92600.00
3A15F8	2017-06-30 22:34:00+03	38800.00
3A160F	2017-08-05 09:32:00+03	65900.00
3A1620	2017-08-07 12:45:00+03	46000.00
3A1630	2017-07-04 00:34:00+03	35800.00
3A1634	2017-07-29 02:59:00+03	13400.00
3A1639	2017-07-11 08:43:00+03	26200.00
3A1658	2017-08-12 23:22:00+03	47600.00
3A16BB	2017-07-26 21:21:00+03	16000.00
3A170D	2017-06-30 15:43:00+03	283000.00
3A1737	2017-08-07 08:21:00+03	114900.00
3A1777	2017-07-18 10:36:00+03	67600.00
3A17B7	2017-07-14 12:32:00+03	26000.00
3A17F6	2017-07-21 11:22:00+03	14400.00
3A185C	2017-07-16 08:34:00+03	532800.00
3A188E	2017-08-14 03:59:00+03	103700.00
3A18FC	2017-08-03 17:39:00+03	188500.00
3A1946	2017-08-11 20:43:00+03	90400.00
3A195E	2017-07-08 03:01:00+03	384400.00
3A196A	2017-08-09 19:10:00+03	55800.00
3A19B2	2017-07-16 06:05:00+03	19600.00
3A19BB	2017-08-12 17:05:00+03	40200.00
3A1A4D	2017-07-21 02:39:00+03	58200.00
3A1A54	2017-08-07 02:00:00+03	73300.00
3A1ABA	2017-08-06 19:05:00+03	15100.00
3A1BCA	2017-07-21 03:58:00+03	54500.00
3A1C91	2017-08-12 23:38:00+03	166900.00
3A1CD0	2017-07-19 23:10:00+03	40000.00
3A1D26	2017-07-15 09:32:00+03	386200.00
3A1D43	2017-07-15 05:19:00+03	28600.00
3A1D63	2017-08-03 05:00:00+03	56000.00
3A1D6D	2017-07-19 05:48:00+03	266400.00
3A1E01	2017-08-07 20:30:00+03	236000.00
3A1E10	2017-08-04 12:34:00+03	23400.00
3A1E26	2017-08-14 06:11:00+03	27300.00
3A1E98	2017-07-27 03:41:00+03	11000.00
3A1F02	2017-08-11 00:32:00+03	28800.00
3A1F56	2017-07-15 10:07:00+03	28000.00
3A1FEC	2017-07-09 23:50:00+03	145300.00
3A2048	2017-08-11 00:13:00+03	20000.00
3A2054	2017-07-19 10:30:00+03	66600.00
3A2076	2017-08-03 07:34:00+03	189800.00
3A20CD	2017-08-08 06:36:00+03	12600.00
3A20E4	2017-07-15 04:57:00+03	14000.00
3A20E8	2017-07-14 08:27:00+03	30200.00
3A20EB	2017-08-06 04:08:00+03	26000.00
3A2127	2017-07-12 22:25:00+03	22200.00
3A212D	2017-07-14 06:32:00+03	26700.00
3A2151	2017-07-03 05:13:00+03	78600.00
3A21A4	2017-07-03 09:27:00+03	63200.00
3A2226	2017-08-10 18:39:00+03	42800.00
3A2227	2017-07-23 14:56:00+03	26100.00
3A228A	2017-07-15 08:12:00+03	64700.00
3A22B4	2017-08-01 05:47:00+03	46800.00
3A23D4	2017-07-05 21:58:00+03	78300.00
3A2439	2017-07-30 02:12:00+03	28000.00
3A2457	2017-08-06 06:06:00+03	31900.00
3A24D9	2017-07-18 08:04:00+03	179400.00
3A24DB	2017-07-18 12:57:00+03	79600.00
3A24EB	2017-08-04 11:02:00+03	28000.00
3A24EE	2017-08-14 06:25:00+03	92700.00
3A2507	2017-06-29 23:13:00+03	14000.00
3A256E	2017-08-03 23:11:00+03	43800.00
3A25A6	2017-07-24 15:57:00+03	46000.00
3A25B6	2017-07-24 11:46:00+03	50600.00
3A25D6	2017-08-15 05:03:00+03	260300.00
3A260D	2017-07-31 01:58:00+03	131600.00
3A261D	2017-08-02 20:12:00+03	75300.00
3A26C3	2017-08-15 08:42:00+03	199700.00
3A26DC	2017-07-17 09:24:00+03	30400.00
3A2700	2017-07-11 21:55:00+03	38800.00
3A272F	2017-08-13 13:34:00+03	19600.00
3A2763	2017-07-10 08:01:00+03	7200.00
3A2846	2017-07-13 21:01:00+03	65900.00
3A28A4	2017-07-05 08:39:00+03	7800.00
3A28A5	2017-07-29 17:54:00+03	64600.00
3A28E9	2017-07-13 17:03:00+03	42000.00
3A28FA	2017-07-31 08:04:00+03	58200.00
3A2901	2017-07-27 04:48:00+03	38600.00
3A2940	2017-07-31 17:39:00+03	96800.00
3A2991	2017-08-06 07:22:00+03	23400.00
3A29A4	2017-08-08 16:57:00+03	95600.00
3A2A40	2017-07-17 21:11:00+03	246000.00
3A2A4D	2017-07-10 00:48:00+03	132800.00
3A2A4E	2017-07-09 16:54:00+03	15400.00
3A2AA7	2017-07-09 07:32:00+03	69100.00
3A2ACA	2017-07-28 07:47:00+03	132800.00
3A2AE8	2017-08-06 19:03:00+03	6700.00
3A2B1B	2017-07-30 11:28:00+03	14700.00
3A2B3D	2017-08-01 20:39:00+03	14100.00
3A2B4B	2017-07-21 12:24:00+03	92400.00
3A2BC0	2017-07-19 11:32:00+03	91200.00
3A2BE7	2017-07-14 15:56:00+03	32800.00
3A2C0E	2017-07-12 17:22:00+03	55800.00
3A2C60	2017-07-03 03:12:00+03	108300.00
3A2C77	2017-08-09 01:47:00+03	22000.00
3A2CB5	2017-07-03 01:17:00+03	97700.00
3A2D55	2017-07-21 04:08:00+03	84000.00
3A2D99	2017-06-30 20:44:00+03	41600.00
3A2DF4	2017-07-11 19:04:00+03	19600.00
3A2DFB	2017-08-08 19:01:00+03	67600.00
3A2E98	2017-07-20 22:41:00+03	79600.00
3A2ECA	2017-07-10 15:54:00+03	28000.00
3A2F1A	2017-07-15 04:42:00+03	185500.00
3A2F60	2017-07-27 14:33:00+03	64800.00
3A2F98	2017-07-22 18:55:00+03	28800.00
3A2FA6	2017-07-17 19:48:00+03	12000.00
3A3042	2017-07-24 07:37:00+03	12000.00
3A30D3	2017-07-18 03:00:00+03	56600.00
3A30E5	2017-07-10 21:30:00+03	128800.00
3A312F	2017-07-25 08:00:00+03	21800.00
3A318E	2017-06-27 01:30:00+03	79800.00
3A31A0	2017-07-27 03:31:00+03	29600.00
3A31B3	2017-08-12 04:13:00+03	85700.00
3A31D9	2017-08-14 00:09:00+03	103700.00
3A31DB	2017-07-09 05:00:00+03	30400.00
3A32A3	2017-07-25 14:50:00+03	91300.00
3A32A5	2017-07-14 22:21:00+03	75600.00
3A32B9	2017-07-05 16:23:00+03	23200.00
3A3382	2017-07-15 04:13:00+03	10800.00
3A3385	2017-07-26 18:08:00+03	12400.00
3A33A6	2017-07-03 08:27:00+03	92400.00
3A3407	2017-07-20 02:06:00+03	22000.00
3A3472	2017-07-08 20:43:00+03	26000.00
3A3494	2017-07-10 19:29:00+03	61800.00
3A3495	2017-07-22 22:39:00+03	31900.00
3A3589	2017-07-31 18:48:00+03	52000.00
3A35C3	2017-07-16 05:07:00+03	52300.00
3A35DC	2017-08-14 19:45:00+03	12700.00
3A3601	2017-07-19 23:21:00+03	188100.00
3A3647	2017-08-12 17:20:00+03	84500.00
3A3650	2017-07-15 09:20:00+03	26000.00
3A367B	2017-08-14 08:02:00+03	24400.00
3A36A1	2017-07-18 06:54:00+03	14400.00
3A374E	2017-07-28 04:09:00+03	46400.00
3A3762	2017-07-15 13:31:00+03	25200.00
3A3789	2017-07-19 22:43:00+03	40600.00
3A37BC	2017-07-07 14:19:00+03	73400.00
3A3804	2017-07-29 13:43:00+03	174600.00
3A381E	2017-07-15 23:16:00+03	26000.00
3A3859	2017-07-31 04:27:00+03	32700.00
3A385E	2017-08-04 19:40:00+03	27200.00
3A3862	2017-07-28 12:53:00+03	119500.00
3A39D7	2017-07-06 12:20:00+03	369000.00
3A39E4	2017-06-30 23:04:00+03	85000.00
3A3A00	2017-07-17 16:19:00+03	26000.00
3A3A32	2017-07-19 10:37:00+03	47400.00
3A3A47	2017-07-21 13:20:00+03	70700.00
3A3B08	2017-07-16 22:22:00+03	28000.00
3A3BE9	2017-08-04 08:45:00+03	68800.00
3A3C2E	2017-08-03 22:02:00+03	246000.00
3A3C35	2017-08-11 03:49:00+03	72800.00
3A3C38	2017-07-15 19:44:00+03	32800.00
3A3CDB	2017-07-29 12:56:00+03	28000.00
3A3D0C	2017-07-10 15:48:00+03	28000.00
3A3D89	2017-07-02 21:31:00+03	82900.00
3A3D94	2017-07-28 19:04:00+03	57500.00
3A3DEC	2017-07-26 18:25:00+03	87300.00
3A3DF1	2017-08-08 22:17:00+03	55800.00
3A3E74	2017-07-04 00:29:00+03	65800.00
3A3E77	2017-07-06 19:27:00+03	136800.00
3A3EA1	2017-08-03 13:14:00+03	44800.00
3A3EB9	2017-07-26 13:13:00+03	185000.00
3A3EE4	2017-07-10 22:38:00+03	24400.00
3A3F7D	2017-07-17 01:04:00+03	22000.00
3A3FB3	2017-07-18 21:35:00+03	29600.00
3A3FCA	2017-07-22 08:04:00+03	266200.00
3A3FCF	2017-08-06 01:16:00+03	56100.00
3A4044	2017-07-31 22:23:00+03	405000.00
3A405A	2017-07-15 00:46:00+03	92000.00
3A406D	2017-08-11 09:16:00+03	21800.00
3A40D4	2017-08-05 00:23:00+03	24400.00
3A414A	2017-08-14 02:12:00+03	133700.00
3A41D6	2017-07-09 07:30:00+03	63200.00
3A42E7	2017-07-23 14:41:00+03	8200.00
3A4334	2017-07-31 01:36:00+03	46400.00
3A436D	2017-08-10 05:16:00+03	36200.00
3A444B	2017-07-15 12:54:00+03	58000.00
3A4466	2017-08-13 06:19:00+03	93900.00
3A44B9	2017-07-01 21:02:00+03	52000.00
3A44EB	2017-07-29 14:41:00+03	32400.00
3A44F4	2017-07-30 11:19:00+03	182000.00
3A44FD	2017-08-15 12:07:00+03	36200.00
3A4517	2017-08-09 03:10:00+03	27200.00
3A458F	2017-07-21 00:47:00+03	203500.00
3A4617	2017-07-17 02:53:00+03	37900.00
3A462F	2017-07-18 10:52:00+03	28800.00
3A4658	2017-08-11 13:59:00+03	135400.00
3A466D	2017-07-07 13:44:00+03	13200.00
3A46DC	2017-07-22 04:50:00+03	31600.00
3A46EB	2017-07-06 09:08:00+03	55800.00
3A4752	2017-07-30 16:37:00+03	60400.00
3A47A1	2017-08-04 21:34:00+03	57600.00
3A47B9	2017-08-10 21:28:00+03	42800.00
3A47BD	2017-07-25 18:20:00+03	133200.00
3A4887	2017-07-30 16:36:00+03	47100.00
3A48A0	2017-07-07 21:12:00+03	187600.00
3A48EA	2017-07-23 06:24:00+03	43900.00
3A4920	2017-07-16 21:03:00+03	34000.00
3A496C	2017-07-03 03:12:00+03	27800.00
3A49A2	2017-07-10 18:43:00+03	61800.00
3A4A04	2017-07-22 15:40:00+03	73500.00
3A4A4C	2017-07-08 02:39:00+03	25000.00
3A4A86	2017-07-09 20:16:00+03	83000.00
3A4A8C	2017-08-12 15:40:00+03	42800.00
3A4AD7	2017-08-09 17:52:00+03	39500.00
3A4AEE	2017-07-13 13:28:00+03	272700.00
3A4AF1	2017-08-12 11:45:00+03	28000.00
3A4B44	2017-08-07 12:48:00+03	45000.00
3A4BA5	2017-07-06 20:21:00+03	24400.00
3A4BFE	2017-07-10 09:03:00+03	86800.00
3A4C28	2017-07-03 14:12:00+03	100700.00
3A4D02	2017-08-13 05:29:00+03	81600.00
3A4D25	2017-07-22 07:25:00+03	28800.00
3A4DF8	2017-08-01 11:09:00+03	24400.00
3A4E1A	2017-07-24 22:13:00+03	35300.00
3A4E37	2017-08-10 15:31:00+03	19600.00
3A4E9A	2017-08-04 09:05:00+03	152400.00
3A4EC5	2017-08-08 15:32:00+03	37900.00
3A4ED1	2017-08-04 15:17:00+03	23600.00
3A4EE2	2017-08-04 10:29:00+03	60700.00
3A4EEA	2017-07-19 12:57:00+03	31600.00
3A4F21	2017-08-02 05:07:00+03	28000.00
3A4F26	2017-07-25 17:42:00+03	91900.00
3A4F37	2017-07-24 05:19:00+03	56600.00
3A4F4D	2017-06-28 09:50:00+03	56000.00
3A4FA7	2017-07-05 21:51:00+03	292300.00
3A4FBC	2017-08-07 10:52:00+03	84500.00
3A4FE2	2017-07-27 09:20:00+03	28000.00
3A5021	2017-08-08 04:59:00+03	54000.00
3A5030	2017-07-26 02:57:00+03	27400.00
3A50AE	2017-08-08 01:54:00+03	386300.00
3A50C1	2017-07-22 03:47:00+03	76100.00
3A50DD	2017-08-03 15:31:00+03	29200.00
3A516B	2017-08-14 01:52:00+03	35200.00
3A518E	2017-07-04 21:01:00+03	134200.00
3A5217	2017-07-22 07:56:00+03	58600.00
3A5219	2017-07-12 12:27:00+03	27400.00
3A523B	2017-07-20 04:29:00+03	68400.00
3A52D1	2017-07-13 19:45:00+03	31600.00
3A530F	2017-07-20 01:29:00+03	66600.00
3A531B	2017-08-05 04:20:00+03	20600.00
3A53BF	2017-08-14 00:29:00+03	21400.00
3A53C5	2017-07-31 01:29:00+03	38600.00
3A53E7	2017-08-02 18:59:00+03	28000.00
3A543C	2017-08-10 11:51:00+03	59800.00
3A54A2	2017-07-22 18:09:00+03	17600.00
3A551F	2017-07-13 22:31:00+03	39100.00
3A555C	2017-07-26 23:09:00+03	13200.00
3A5564	2017-08-02 00:33:00+03	30600.00
3A5596	2017-08-06 12:28:00+03	98400.00
3A55F4	2017-08-12 10:18:00+03	134400.00
3A5617	2017-08-05 03:15:00+03	16400.00
3A563E	2017-07-16 16:40:00+03	47400.00
3A5645	2017-07-07 17:24:00+03	28000.00
3A5689	2017-07-28 14:28:00+03	26000.00
3A5692	2017-07-23 20:36:00+03	82200.00
3A569F	2017-07-17 15:50:00+03	46000.00
3A56E6	2017-07-10 22:43:00+03	63200.00
3A5715	2017-07-29 14:06:00+03	12200.00
3A5720	2017-08-03 05:33:00+03	25000.00
3A572F	2017-08-14 14:03:00+03	23600.00
3A5756	2017-07-09 07:36:00+03	29400.00
3A57FC	2017-07-27 10:07:00+03	36200.00
3A5826	2017-07-14 21:10:00+03	266400.00
3A5876	2017-08-13 22:52:00+03	46500.00
3A58F8	2017-07-06 09:32:00+03	55800.00
3A5988	2017-08-13 18:46:00+03	51900.00
3A5A4B	2017-08-11 19:13:00+03	27200.00
3A5ADC	2017-07-31 05:54:00+03	67600.00
3A5B03	2017-06-29 02:57:00+03	41600.00
3A5BA9	2017-07-30 07:17:00+03	39200.00
3A5BBC	2017-07-07 04:34:00+03	117700.00
3A5C41	2017-07-26 06:50:00+03	125200.00
3A5C7A	2017-07-01 23:41:00+03	44000.00
3A5CAD	2017-07-18 03:56:00+03	36200.00
3A5CE5	2017-07-02 06:53:00+03	53600.00
3A5CFB	2017-08-10 00:08:00+03	26000.00
3A5D15	2017-07-23 18:26:00+03	55800.00
3A5D6A	2017-08-10 14:21:00+03	56600.00
3A5D86	2017-07-08 19:33:00+03	70700.00
3A5D8A	2017-07-13 18:04:00+03	89400.00
3A5DC0	2017-07-27 21:23:00+03	31900.00
3A5E0A	2017-07-01 11:46:00+03	39400.00
3A5E38	2017-07-10 09:11:00+03	81200.00
3A5E6F	2017-07-29 15:47:00+03	33600.00
3A5EB6	2017-07-02 20:06:00+03	25100.00
3A5F0A	2017-07-28 17:53:00+03	46000.00
3A5F16	2017-08-15 09:03:00+03	496600.00
3A5F49	2017-08-02 02:45:00+03	25800.00
3A5F68	2017-08-13 17:02:00+03	54500.00
3A5F7A	2017-08-07 17:24:00+03	40600.00
3A602B	2017-07-24 19:45:00+03	47200.00
3A6038	2017-08-15 15:13:00+03	12400.00
3A6096	2017-07-07 01:01:00+03	81700.00
3A60AC	2017-07-21 12:07:00+03	393600.00
3A60B8	2017-07-21 08:21:00+03	111600.00
3A60F9	2017-07-14 06:06:00+03	75300.00
3A61DB	2017-08-15 16:25:00+03	43000.00
3A61F2	2017-08-10 09:16:00+03	68800.00
3A624B	2017-07-03 11:00:00+03	54800.00
3A6269	2017-08-03 02:19:00+03	168000.00
3A6270	2017-07-31 18:16:00+03	128800.00
3A62AF	2017-06-29 10:57:00+03	89600.00
3A62C0	2017-07-07 21:08:00+03	136800.00
3A62EA	2017-08-07 13:29:00+03	28000.00
3A6318	2017-08-07 00:15:00+03	146600.00
3A6328	2017-07-06 06:21:00+03	53100.00
3A6357	2017-07-12 11:39:00+03	38700.00
3A6387	2017-08-11 04:52:00+03	42400.00
3A638C	2017-08-13 07:36:00+03	103200.00
3A63A4	2017-07-29 13:45:00+03	167400.00
3A63B0	2017-07-21 09:37:00+03	6000.00
3A6421	2017-08-04 16:48:00+03	258400.00
3A6555	2017-08-09 23:24:00+03	191000.00
3A657D	2017-08-04 16:29:00+03	113000.00
3A65A7	2017-07-24 00:49:00+03	8400.00
3A6633	2017-07-22 09:56:00+03	14000.00
3A663E	2017-07-22 13:43:00+03	28000.00
3A6644	2017-07-19 11:28:00+03	32100.00
3A6664	2017-08-13 13:30:00+03	21000.00
3A6691	2017-07-14 21:53:00+03	28300.00
3A6736	2017-07-20 23:42:00+03	59300.00
3A674F	2017-07-07 13:32:00+03	88100.00
3A6785	2017-07-17 15:15:00+03	94400.00
3A6788	2017-07-05 09:28:00+03	46200.00
3A67C6	2017-07-29 19:42:00+03	56600.00
3A6813	2017-08-04 18:29:00+03	170500.00
3A690B	2017-07-11 06:40:00+03	148200.00
3A693B	2017-07-17 01:38:00+03	133200.00
3A694C	2017-07-19 10:39:00+03	23200.00
3A695B	2017-08-06 04:11:00+03	8000.00
3A6986	2017-07-01 18:29:00+03	18100.00
3A699D	2017-07-23 04:02:00+03	64600.00
3A69A2	2017-08-05 16:07:00+03	42800.00
3A69CA	2017-07-26 15:13:00+03	354400.00
3A6A45	2017-07-02 23:16:00+03	20500.00
3A6B21	2017-07-06 10:30:00+03	93700.00
3A6B40	2017-07-09 18:05:00+03	8000.00
3A6B5C	2017-08-03 16:55:00+03	265700.00
3A6B79	2017-07-19 04:44:00+03	30200.00
3A6BCC	2017-07-06 23:46:00+03	70500.00
3A6C64	2017-07-11 02:19:00+03	14400.00
3A6CCD	2017-07-08 13:24:00+03	81600.00
3A6CD9	2017-07-02 08:25:00+03	306600.00
3A6DCC	2017-07-10 00:06:00+03	31400.00
3A6E1B	2017-08-06 07:15:00+03	26700.00
3A6E1E	2017-07-14 03:36:00+03	102700.00
3A6E5E	2017-07-23 03:39:00+03	23200.00
3A6E73	2017-06-29 06:42:00+03	128800.00
3A6E81	2017-08-04 15:44:00+03	76600.00
3A6EF1	2017-08-12 06:45:00+03	49600.00
3A6F73	2017-07-07 05:30:00+03	89700.00
3A6F87	2017-07-02 15:32:00+03	39800.00
3A6F8D	2017-07-20 07:09:00+03	46300.00
3A7017	2017-07-20 02:21:00+03	13200.00
3A703C	2017-08-01 04:14:00+03	116500.00
3A704B	2017-08-01 05:13:00+03	28800.00
3A7129	2017-07-16 15:47:00+03	55800.00
3A71CD	2017-07-31 09:08:00+03	99200.00
3A723D	2017-07-27 21:27:00+03	89100.00
3A7251	2017-07-11 00:07:00+03	117200.00
3A726A	2017-08-09 13:34:00+03	64800.00
3A729E	2017-07-05 15:52:00+03	12600.00
3A72E9	2017-07-15 12:11:00+03	368900.00
3A730E	2017-08-12 02:08:00+03	58000.00
3A7312	2017-07-25 04:26:00+03	64400.00
3A7331	2017-08-03 10:24:00+03	100600.00
3A735C	2017-08-09 17:00:00+03	100600.00
3A7369	2017-08-14 02:54:00+03	40100.00
3A7396	2017-08-12 15:17:00+03	29600.00
3A73BB	2017-07-31 01:12:00+03	185400.00
3A73C6	2017-07-25 21:00:00+03	124200.00
3A7403	2017-08-09 22:18:00+03	56000.00
3A740C	2017-08-08 02:15:00+03	90800.00
3A741F	2017-07-04 09:34:00+03	31600.00
3A7422	2017-08-14 06:59:00+03	39400.00
3A743D	2017-07-07 09:40:00+03	135000.00
3A7452	2017-07-15 20:31:00+03	48500.00
3A7481	2017-08-08 10:04:00+03	53700.00
3A7495	2017-07-15 07:50:00+03	132900.00
3A753A	2017-07-19 09:34:00+03	131900.00
3A75AD	2017-07-18 19:37:00+03	60700.00
3A75CB	2017-07-18 07:47:00+03	99600.00
3A75FE	2017-08-10 03:25:00+03	76600.00
3A762C	2017-08-09 02:29:00+03	28800.00
3A764B	2017-07-10 09:06:00+03	82800.00
3A7667	2017-07-05 05:54:00+03	159200.00
3A76EA	2017-07-07 11:56:00+03	46200.00
3A770A	2017-08-06 11:27:00+03	89600.00
3A7752	2017-08-08 06:51:00+03	32000.00
3A778F	2017-07-13 00:26:00+03	45200.00
3A77A8	2017-07-19 01:22:00+03	27600.00
3A77B2	2017-08-12 12:28:00+03	270400.00
3A77BA	2017-07-30 01:49:00+03	25200.00
3A77F7	2017-07-11 10:29:00+03	19600.00
3A7826	2017-07-27 04:36:00+03	112000.00
3A786D	2017-08-03 08:52:00+03	39200.00
3A78C8	2017-07-30 22:07:00+03	23200.00
3A798E	2017-07-01 07:54:00+03	123600.00
3A7990	2017-08-02 21:30:00+03	83600.00
3A799A	2017-07-09 06:28:00+03	57600.00
3A7A18	2017-07-28 03:03:00+03	36200.00
3A7A28	2017-07-21 11:24:00+03	83700.00
3A7AA8	2017-07-11 11:08:00+03	26000.00
3A7ACB	2017-07-10 14:03:00+03	158500.00
3A7AED	2017-07-13 05:01:00+03	32800.00
3A7B03	2017-07-01 03:20:00+03	136800.00
3A7B05	2017-08-11 13:22:00+03	25800.00
3A7B10	2017-08-07 13:11:00+03	108500.00
3A7B6B	2017-07-22 04:14:00+03	57400.00
3A7BE5	2017-07-25 01:32:00+03	31600.00
3A7BFD	2017-07-21 00:52:00+03	35700.00
3A7D09	2017-07-19 17:02:00+03	136800.00
3A7D74	2017-08-06 05:53:00+03	89200.00
3A7D97	2017-07-22 07:48:00+03	14000.00
3A7DAA	2017-08-14 20:05:00+03	145300.00
3A7DAB	2017-08-09 19:41:00+03	67200.00
3A7DB6	2017-08-05 14:50:00+03	26300.00
3A7E14	2017-08-02 10:46:00+03	87000.00
3A7E2B	2017-08-05 08:57:00+03	23200.00
3A7E4A	2017-07-24 21:44:00+03	29600.00
3A7E60	2017-08-07 07:59:00+03	111600.00
3A7E6B	2017-07-14 13:15:00+03	93900.00
3A7E7D	2017-08-04 02:56:00+03	48800.00
3A7E85	2017-07-29 05:19:00+03	29100.00
3A7F3F	2017-08-04 22:16:00+03	26600.00
3A7F56	2017-07-18 07:27:00+03	14000.00
3A7F57	2017-07-25 16:00:00+03	112000.00
3A7F64	2017-06-30 20:12:00+03	84100.00
3A7F82	2017-07-17 22:00:00+03	62600.00
3A7FA1	2017-07-05 16:22:00+03	56000.00
3A8003	2017-07-30 23:25:00+03	29100.00
3A8074	2017-07-29 03:49:00+03	73200.00
3A80A6	2017-07-25 16:58:00+03	48400.00
3A80B5	2017-08-05 14:13:00+03	34000.00
3A8177	2017-07-26 01:35:00+03	39500.00
3A8178	2017-07-18 19:08:00+03	109800.00
3A819E	2017-07-01 21:25:00+03	53600.00
3A81DD	2017-07-11 23:22:00+03	62600.00
3A8232	2017-08-07 03:01:00+03	127600.00
3A8247	2017-08-12 03:35:00+03	28000.00
3A8280	2017-08-14 15:31:00+03	39800.00
3A8292	2017-07-27 14:24:00+03	27200.00
3A82B2	2017-07-22 03:16:00+03	23200.00
3A82E2	2017-08-05 19:44:00+03	66000.00
3A8373	2017-08-14 07:13:00+03	27200.00
3A837F	2017-07-13 19:33:00+03	101200.00
3A838D	2017-08-10 00:11:00+03	12600.00
3A83FF	2017-07-22 23:18:00+03	23400.00
3A840E	2017-07-24 04:19:00+03	38600.00
3A841F	2017-07-12 05:26:00+03	138500.00
3A8430	2017-07-28 04:47:00+03	55800.00
3A8450	2017-07-18 12:56:00+03	738000.00
3A8457	2017-08-09 17:01:00+03	38800.00
3A84D8	2017-07-11 07:21:00+03	265400.00
3A84F6	2017-08-03 02:10:00+03	27600.00
3A8532	2017-07-26 14:33:00+03	11800.00
3A8548	2017-07-24 14:53:00+03	46200.00
3A8577	2017-07-24 13:24:00+03	132800.00
3A85EA	2017-08-15 07:20:00+03	31200.00
3A861A	2017-06-30 09:34:00+03	46200.00
3A8627	2017-07-14 14:22:00+03	26000.00
3A862F	2017-07-10 12:47:00+03	48600.00
3A865A	2017-07-12 07:33:00+03	12600.00
3A8664	2017-07-28 04:35:00+03	139400.00
3A8759	2017-07-11 19:02:00+03	67600.00
3A8770	2017-07-15 21:31:00+03	20800.00
3A87C6	2017-07-30 23:59:00+03	46400.00
3A88A6	2017-08-14 08:26:00+03	66600.00
3A88EF	2017-07-10 01:10:00+03	73300.00
3A890B	2017-07-26 20:30:00+03	13000.00
3A892D	2017-08-15 15:59:00+03	38600.00
3A89B8	2017-08-12 12:22:00+03	76400.00
3A8A35	2017-07-14 10:54:00+03	28000.00
3A8A5B	2017-07-23 20:59:00+03	56000.00
3A8A6D	2017-07-05 11:22:00+03	270700.00
3A8AF8	2017-07-25 10:49:00+03	38600.00
3A8B0E	2017-08-11 09:38:00+03	189900.00
3A8B4E	2017-08-02 00:38:00+03	176100.00
3A8B5E	2017-06-29 12:19:00+03	153300.00
3A8B7F	2017-07-03 03:05:00+03	49500.00
3A8BCF	2017-08-14 09:49:00+03	54500.00
3A8C2D	2017-07-03 10:11:00+03	35600.00
3A8C33	2017-07-16 01:02:00+03	28000.00
3A8C5C	2017-07-16 18:06:00+03	166000.00
3A8DD5	2017-07-08 14:41:00+03	42800.00
3A8DDA	2017-06-27 14:00:00+03	28000.00
3A8E34	2017-08-11 07:12:00+03	193900.00
3A8EB0	2017-08-04 15:39:00+03	35700.00
3A8F1D	2017-07-02 07:32:00+03	74900.00
3A8FA6	2017-07-10 07:50:00+03	136200.00
3A8FC6	2017-08-03 16:52:00+03	84000.00
3A8FDB	2017-07-22 06:38:00+03	28000.00
3A8FE8	2017-07-06 08:39:00+03	61800.00
3A9018	2017-08-12 22:22:00+03	23200.00
3A9038	2017-07-15 20:59:00+03	38400.00
3A9050	2017-07-12 23:41:00+03	101100.00
3A913B	2017-07-09 13:17:00+03	24500.00
3A9227	2017-06-27 13:16:00+03	28000.00
3A92AD	2017-08-06 14:49:00+03	224000.00
3A92BA	2017-07-19 23:49:00+03	54000.00
3A92BB	2017-07-17 09:22:00+03	31400.00
3A92CB	2017-08-09 12:46:00+03	106000.00
3A9391	2017-07-28 01:37:00+03	103800.00
3A9481	2017-07-25 05:42:00+03	120300.00
3A9498	2017-07-04 17:36:00+03	26800.00
3A94A5	2017-07-06 13:06:00+03	37100.00
3A94CB	2017-08-08 06:57:00+03	46200.00
3A94CC	2017-07-31 18:27:00+03	202000.00
3A9551	2017-06-30 19:24:00+03	49900.00
3A95E2	2017-07-06 07:43:00+03	52600.00
3A9609	2017-08-12 11:08:00+03	102100.00
3A967E	2017-07-19 05:17:00+03	48400.00
3A96A8	2017-07-29 00:13:00+03	78600.00
3A96E2	2017-07-08 20:17:00+03	56000.00
3A9781	2017-07-22 02:09:00+03	136500.00
3A9808	2017-07-08 12:03:00+03	68000.00
3A9823	2017-06-28 21:39:00+03	13600.00
3A985C	2017-07-04 02:50:00+03	271200.00
3A9871	2017-07-11 03:57:00+03	32800.00
3A98D8	2017-07-22 01:32:00+03	43200.00
3A9932	2017-07-13 22:46:00+03	90600.00
3A995E	2017-07-19 03:43:00+03	44600.00
3A996A	2017-08-07 16:42:00+03	174900.00
3A99D3	2017-07-27 00:53:00+03	406200.00
3A99DC	2017-07-14 13:13:00+03	103800.00
3A99F7	2017-07-20 11:35:00+03	75300.00
3A9A2A	2017-07-26 01:35:00+03	25600.00
3A9ABC	2017-07-15 13:36:00+03	24300.00
3A9ACB	2017-08-13 22:25:00+03	12000.00
3A9AF3	2017-08-13 09:21:00+03	132800.00
3A9B50	2017-08-08 12:47:00+03	27800.00
3A9B6B	2017-07-02 18:10:00+03	70800.00
3A9B6F	2017-07-04 15:18:00+03	58900.00
3A9BF0	2017-07-15 07:11:00+03	134400.00
3A9CB1	2017-08-02 00:00:00+03	28800.00
3A9CC5	2017-07-01 15:20:00+03	34600.00
3A9D82	2017-07-29 04:44:00+03	39200.00
3A9E0F	2017-07-09 16:43:00+03	61800.00
3A9E6C	2017-07-22 00:29:00+03	26500.00
3A9E77	2017-07-01 03:04:00+03	114800.00
3A9E8E	2017-07-08 01:54:00+03	271200.00
3A9EDF	2017-07-03 12:47:00+03	20200.00
3A9EEA	2017-07-03 08:17:00+03	25600.00
3A9F3D	2017-08-05 09:16:00+03	55800.00
3A9F7D	2017-07-08 14:02:00+03	73300.00
3A9FE0	2017-07-12 14:33:00+03	142300.00
3AA048	2017-08-11 20:57:00+03	492000.00
3AA083	2017-08-13 09:45:00+03	178800.00
3AA09E	2017-07-09 22:14:00+03	48800.00
3AA0A3	2017-07-08 05:32:00+03	16400.00
3AA151	2017-08-15 00:26:00+03	56600.00
3AA1AF	2017-08-07 07:42:00+03	187600.00
3AA234	2017-07-23 23:05:00+03	266400.00
3AA2DA	2017-07-12 07:59:00+03	28000.00
3AA2F2	2017-07-27 07:40:00+03	114500.00
3AA302	2017-08-03 07:37:00+03	42400.00
3AA348	2017-07-14 19:02:00+03	58900.00
3AA361	2017-08-10 21:51:00+03	88600.00
3AA37B	2017-07-17 03:49:00+03	48800.00
3AA40C	2017-08-01 12:08:00+03	69600.00
3AA45B	2017-07-05 21:15:00+03	30000.00
3AA49F	2017-07-05 12:46:00+03	6300.00
3AA4C5	2017-08-01 12:52:00+03	56600.00
3AA573	2017-07-28 19:57:00+03	98400.00
3AA58E	2017-07-07 12:29:00+03	25400.00
3AA5B7	2017-07-14 18:38:00+03	124000.00
3AA5BA	2017-07-19 10:47:00+03	203600.00
3AA672	2017-07-13 23:59:00+03	386300.00
3AA67D	2017-07-11 10:37:00+03	35600.00
3AA6C9	2017-07-23 21:01:00+03	28300.00
3AA6FE	2017-07-12 04:50:00+03	101500.00
3AA701	2017-07-22 13:47:00+03	156500.00
3AA762	2017-08-10 21:27:00+03	81900.00
3AA7D8	2017-07-27 15:17:00+03	80200.00
3AA883	2017-08-09 10:50:00+03	45200.00
3AA8ED	2017-08-04 06:43:00+03	86600.00
3AA8FE	2017-07-29 23:06:00+03	25100.00
3AA900	2017-07-01 19:46:00+03	28800.00
3AA918	2017-07-10 22:48:00+03	75300.00
3AA997	2017-07-29 00:59:00+03	37100.00
3AAA4B	2017-07-15 19:13:00+03	28000.00
3AAA9E	2017-07-22 19:47:00+03	156600.00
3AAAFF	2017-08-14 18:24:00+03	50600.00
3AAB12	2017-07-23 03:40:00+03	156500.00
3AAB43	2017-07-22 16:09:00+03	130000.00
3AABAD	2017-07-25 00:05:00+03	34000.00
3AAC3A	2017-08-06 02:00:00+03	101400.00
3AAC78	2017-08-09 23:32:00+03	70800.00
3AACC0	2017-07-19 00:37:00+03	13800.00
3AACE1	2017-08-01 03:56:00+03	58100.00
3AACF9	2017-07-22 15:56:00+03	40100.00
3AAD17	2017-07-30 21:43:00+03	117200.00
3AAE29	2017-08-07 02:07:00+03	133700.00
3AAEC1	2017-07-08 02:06:00+03	184600.00
3AAF73	2017-07-15 15:46:00+03	12600.00
3AAF80	2017-07-04 19:17:00+03	37100.00
3AAF92	2017-07-13 23:55:00+03	193500.00
3AAF93	2017-06-30 23:30:00+03	150700.00
3AAFDF	2017-07-17 15:08:00+03	29400.00
3AB04E	2017-08-02 02:48:00+03	89700.00
3AB076	2017-07-22 22:45:00+03	49100.00
3AB0D3	2017-08-02 19:56:00+03	48800.00
3AB108	2017-07-24 18:50:00+03	83600.00
3AB116	2017-07-17 21:56:00+03	65900.00
3AB15F	2017-08-06 11:10:00+03	772500.00
3AB1E8	2017-07-11 21:15:00+03	492000.00
3AB1E9	2017-08-04 15:07:00+03	47400.00
3AB1EA	2017-07-25 08:49:00+03	31000.00
3AB221	2017-08-13 09:33:00+03	78000.00
3AB23F	2017-07-19 14:54:00+03	112000.00
3AB240	2017-07-28 10:14:00+03	25600.00
3AB30C	2017-07-16 21:00:00+03	6800.00
3AB327	2017-07-05 15:10:00+03	173500.00
3AB35F	2017-07-01 20:13:00+03	133100.00
3AB395	2017-08-06 10:27:00+03	64800.00
3AB3A6	2017-07-23 22:13:00+03	70700.00
3AB3B0	2017-07-14 02:45:00+03	272300.00
3AB3C7	2017-08-03 18:45:00+03	55800.00
3AB3C8	2017-07-25 02:33:00+03	16400.00
3AB401	2017-07-30 06:22:00+03	85000.00
3AB409	2017-06-30 01:20:00+03	30200.00
3AB48D	2017-08-15 04:12:00+03	59800.00
3AB48F	2017-07-29 17:12:00+03	66000.00
3AB496	2017-08-10 18:43:00+03	125200.00
3AB4C6	2017-08-11 04:39:00+03	150700.00
3AB5BF	2017-07-30 02:23:00+03	87700.00
3AB60D	2017-08-15 02:55:00+03	25200.00
3AB695	2017-07-17 14:29:00+03	77200.00
3AB701	2017-07-22 13:55:00+03	99200.00
3AB710	2017-08-07 14:59:00+03	75300.00
3AB714	2017-08-08 14:02:00+03	78100.00
3AB79C	2017-07-20 01:26:00+03	6300.00
3AB79E	2017-07-28 16:31:00+03	8400.00
3AB7D4	2017-07-24 22:32:00+03	39500.00
3AB81A	2017-07-31 22:06:00+03	48800.00
3AB8C3	2017-07-20 08:59:00+03	26000.00
3AB8DC	2017-07-16 16:31:00+03	59800.00
3AB8ED	2017-07-19 20:28:00+03	49100.00
3AB907	2017-08-10 15:12:00+03	17200.00
3AB923	2017-07-22 08:15:00+03	62600.00
3AB970	2017-08-15 08:41:00+03	266400.00
3ABA17	2017-08-10 05:28:00+03	142000.00
3ABA1B	2017-07-15 20:39:00+03	62600.00
3ABA2F	2017-08-09 19:31:00+03	240600.00
3ABAA6	2017-08-06 18:59:00+03	47000.00
3ABABA	2017-07-14 00:33:00+03	47200.00
3ABAC7	2017-07-17 07:50:00+03	92800.00
3ABB37	2017-07-12 17:48:00+03	150600.00
3ABC75	2017-07-24 18:12:00+03	72300.00
3ABCC4	2017-08-02 05:45:00+03	90800.00
3ABCFF	2017-08-11 22:15:00+03	101100.00
3ABD08	2017-07-07 14:59:00+03	27300.00
3ABD69	2017-08-15 12:09:00+03	116400.00
3ABDCA	2017-07-27 02:37:00+03	25600.00
3ABDDB	2017-08-02 20:35:00+03	60400.00
3ABE5C	2017-08-03 20:18:00+03	11800.00
3ABE99	2017-07-30 13:26:00+03	175700.00
3ABED7	2017-07-22 00:11:00+03	182300.00
3ABF03	2017-08-09 15:10:00+03	229900.00
3ABF4D	2017-08-15 05:37:00+03	78300.00
3ABFD1	2017-07-26 22:14:00+03	16400.00
3AC004	2017-07-14 08:30:00+03	29600.00
3AC021	2017-08-09 06:49:00+03	36200.00
3AC043	2017-07-12 18:05:00+03	36800.00
3AC05A	2017-08-04 23:36:00+03	13000.00
3AC0A7	2017-08-09 13:10:00+03	73100.00
3AC0D1	2017-08-08 00:30:00+03	33600.00
3AC0E6	2017-07-12 06:49:00+03	81700.00
3AC0FB	2017-06-30 07:25:00+03	78200.00
3AC131	2017-07-31 01:06:00+03	1087100.00
3AC153	2017-07-14 11:44:00+03	62600.00
3AC160	2017-08-08 16:51:00+03	51200.00
3AC1A3	2017-08-01 13:47:00+03	6000.00
3AC1BA	2017-08-15 14:58:00+03	32400.00
3AC21B	2017-07-28 23:25:00+03	13400.00
3AC297	2017-07-29 01:37:00+03	76800.00
3AC2B8	2017-08-13 07:44:00+03	29600.00
3AC2FF	2017-08-10 04:13:00+03	176400.00
3AC328	2017-08-04 03:08:00+03	56000.00
3AC386	2017-08-02 02:58:00+03	32700.00
3AC38A	2017-07-21 11:07:00+03	26700.00
3AC4C7	2017-08-05 22:38:00+03	29600.00
3AC53D	2017-08-12 05:07:00+03	185800.00
3AC56F	2017-07-08 03:49:00+03	28000.00
3AC5C9	2017-07-20 11:00:00+03	149300.00
3AC5CC	2017-07-05 20:21:00+03	23200.00
3AC5D8	2017-08-02 17:15:00+03	96300.00
3AC5DD	2017-07-23 18:35:00+03	119600.00
3AC5DE	2017-07-04 17:42:00+03	292300.00
3AC623	2017-08-01 22:50:00+03	73900.00
3AC635	2017-08-14 08:34:00+03	43900.00
3AC67B	2017-08-15 07:53:00+03	68600.00
3AC6A6	2017-07-23 10:24:00+03	94000.00
3AC6D4	2017-08-11 21:43:00+03	55600.00
3AC702	2017-08-15 12:05:00+03	56000.00
3AC727	2017-07-10 20:22:00+03	31600.00
3AC758	2017-07-10 09:17:00+03	75600.00
3AC7AC	2017-07-17 19:46:00+03	65500.00
3AC89A	2017-07-27 06:39:00+03	39400.00
3AC929	2017-08-04 06:08:00+03	42800.00
3AC9AB	2017-07-26 22:19:00+03	35200.00
3ACA04	2017-08-08 03:02:00+03	89600.00
3ACA31	2017-07-13 13:21:00+03	136000.00
3ACA37	2017-07-02 05:45:00+03	28000.00
3ACA3D	2017-07-10 13:40:00+03	57600.00
3ACAA4	2017-08-11 04:15:00+03	21500.00
3ACAC3	2017-08-06 22:19:00+03	40900.00
3ACADD	2017-07-19 19:31:00+03	50200.00
3ACAEE	2017-07-18 23:06:00+03	6700.00
3ACB27	2017-07-28 09:57:00+03	40200.00
3ACB2E	2017-08-02 21:10:00+03	12600.00
3ACB45	2017-07-24 06:20:00+03	152400.00
3ACB4E	2017-07-19 07:33:00+03	32800.00
3ACBBA	2017-07-26 00:47:00+03	60400.00
3ACBF7	2017-08-08 04:02:00+03	73600.00
3ACC21	2017-07-25 01:19:00+03	28000.00
3ACC6B	2017-08-12 05:16:00+03	23600.00
3ACD29	2017-07-22 06:09:00+03	112000.00
3ACD8B	2017-08-09 13:07:00+03	83200.00
3ACDAE	2017-08-10 16:51:00+03	23400.00
3ACDDB	2017-08-15 08:02:00+03	164600.00
3ACDF0	2017-08-15 02:33:00+03	66600.00
3ACE04	2017-07-13 20:37:00+03	55000.00
3ACE8A	2017-07-18 13:14:00+03	24400.00
3ACEDC	2017-08-13 17:25:00+03	42800.00
3ACF08	2017-08-08 12:25:00+03	79900.00
3AD035	2017-07-17 10:51:00+03	90000.00
3AD049	2017-07-29 01:24:00+03	49800.00
3AD066	2017-07-06 00:40:00+03	48800.00
3AD067	2017-07-29 13:09:00+03	36200.00
3AD06E	2017-07-14 01:48:00+03	38200.00
3AD08C	2017-07-21 02:06:00+03	12000.00
3AD109	2017-06-30 04:09:00+03	21000.00
3AD114	2017-07-10 04:03:00+03	58400.00
3AD152	2017-07-30 11:48:00+03	18000.00
3AD15D	2017-08-06 02:04:00+03	101200.00
3AD168	2017-07-12 07:12:00+03	81700.00
3AD17F	2017-07-06 09:02:00+03	283100.00
3AD1C3	2017-07-24 02:32:00+03	166900.00
3AD1F3	2017-07-12 19:21:00+03	56000.00
3AD20B	2017-07-22 20:44:00+03	93000.00
3AD249	2017-08-10 01:38:00+03	60000.00
3AD26A	2017-06-30 14:32:00+03	10600.00
3AD2F7	2017-07-19 20:48:00+03	29600.00
3AD30B	2017-08-02 14:43:00+03	103500.00
3AD344	2017-07-09 23:24:00+03	23200.00
3AD34E	2017-08-11 19:50:00+03	40400.00
3AD37C	2017-07-08 06:42:00+03	14000.00
3AD399	2017-07-03 05:11:00+03	60400.00
3AD3DA	2017-08-07 21:04:00+03	84000.00
3AD4A5	2017-07-08 08:57:00+03	249100.00
3AD4BE	2017-07-22 11:09:00+03	14400.00
3AD4C3	2017-07-30 20:50:00+03	15400.00
3AD4DB	2017-07-16 18:58:00+03	168000.00
3AD52A	2017-07-27 13:31:00+03	46000.00
3AD54E	2017-07-05 11:10:00+03	27200.00
3AD59D	2017-07-18 17:49:00+03	75600.00
3AD5FD	2017-08-07 08:09:00+03	87100.00
3AD61D	2017-08-08 16:39:00+03	20000.00
3AD637	2017-07-26 09:33:00+03	34000.00
3AD64E	2017-08-09 08:37:00+03	8000.00
3AD6F4	2017-07-23 21:38:00+03	78600.00
3AD70A	2017-07-07 16:53:00+03	67600.00
3AD724	2017-08-15 09:25:00+03	85000.00
3AD766	2017-08-07 04:00:00+03	135400.00
3AD7B8	2017-07-31 01:51:00+03	81200.00
3AD7BC	2017-07-28 09:00:00+03	135300.00
3AD7EE	2017-07-30 14:22:00+03	126400.00
3AD83F	2017-08-13 09:07:00+03	120600.00
3AD96E	2017-07-08 20:13:00+03	18500.00
3ADA1F	2017-07-17 15:15:00+03	246000.00
3ADA32	2017-07-30 08:18:00+03	80900.00
3ADA39	2017-07-06 19:28:00+03	265700.00
3ADA40	2017-07-04 09:33:00+03	123000.00
3ADAB1	2017-07-23 06:22:00+03	88800.00
3ADAEC	2017-07-16 03:53:00+03	36200.00
3ADC4A	2017-08-08 17:17:00+03	36000.00
3ADC51	2017-07-09 02:21:00+03	77000.00
3ADC7B	2017-08-02 19:39:00+03	6700.00
3ADD18	2017-07-23 18:11:00+03	57500.00
3ADD4D	2017-07-27 20:52:00+03	39800.00
3ADD50	2017-07-19 07:57:00+03	57500.00
3ADD77	2017-08-11 03:15:00+03	62800.00
3ADD7E	2017-08-07 10:21:00+03	37200.00
3ADD8B	2017-07-14 18:52:00+03	12400.00
3ADDD1	2017-08-15 08:25:00+03	31400.00
3ADDF2	2017-08-11 18:19:00+03	112600.00
3ADE1C	2017-07-26 20:44:00+03	15400.00
3ADE33	2017-07-16 02:36:00+03	33100.00
3ADE3B	2017-07-19 11:23:00+03	28000.00
3ADE61	2017-07-03 19:58:00+03	61900.00
3ADE65	2017-07-16 23:18:00+03	8800.00
3ADEFA	2017-08-12 10:50:00+03	28800.00
3ADEFD	2017-08-15 17:17:00+03	23200.00
3ADF03	2017-07-10 10:38:00+03	6800.00
3ADF1D	2017-07-05 05:16:00+03	62600.00
3ADF25	2017-07-11 16:54:00+03	135600.00
3ADF4A	2017-08-14 17:03:00+03	57400.00
3ADF68	2017-07-19 12:06:00+03	116900.00
3ADF82	2017-08-06 10:49:00+03	76800.00
3ADF83	2017-08-14 09:19:00+03	70800.00
3ADFA8	2017-08-04 12:59:00+03	32400.00
3ADFBF	2017-07-12 07:08:00+03	39300.00
3ADFE0	2017-07-29 16:08:00+03	14800.00
3ADFEA	2017-07-02 02:42:00+03	103600.00
3ADFFD	2017-07-22 18:02:00+03	28800.00
3AE050	2017-08-14 17:06:00+03	31200.00
3AE0A4	2017-07-27 14:34:00+03	22100.00
3AE0BC	2017-07-01 08:10:00+03	39500.00
3AE0D0	2017-08-08 03:03:00+03	40800.00
3AE13E	2017-07-24 08:52:00+03	88100.00
3AE159	2017-07-11 20:36:00+03	25900.00
3AE163	2017-08-10 05:04:00+03	88400.00
3AE18A	2017-07-03 00:10:00+03	184200.00
3AE1C1	2017-07-09 06:02:00+03	39400.00
3AE206	2017-07-16 02:57:00+03	25000.00
3AE208	2017-08-12 02:55:00+03	67700.00
3AE28B	2017-07-14 13:25:00+03	174400.00
3AE32D	2017-08-08 13:25:00+03	535800.00
3AE384	2017-07-08 09:06:00+03	45200.00
3AE407	2017-07-22 10:55:00+03	26000.00
3AE493	2017-07-11 16:36:00+03	26200.00
3AE4B8	2017-07-10 10:00:00+03	23600.00
3AE574	2017-08-13 12:54:00+03	24000.00
3AE58A	2017-07-21 03:35:00+03	23600.00
3AE60A	2017-07-12 02:20:00+03	64800.00
3AE63D	2017-07-11 21:05:00+03	48800.00
3AE661	2017-07-03 09:35:00+03	40300.00
3AE680	2017-07-19 00:27:00+03	63800.00
3AE6E0	2017-07-04 15:06:00+03	36500.00
3AE817	2017-08-15 05:01:00+03	45200.00
3AE83E	2017-08-12 16:28:00+03	112400.00
3AE84A	2017-07-24 04:43:00+03	186900.00
3AE8CE	2017-08-13 12:34:00+03	24400.00
3AE8ED	2017-08-04 07:51:00+03	25200.00
3AE951	2017-07-21 15:16:00+03	32800.00
3AE99A	2017-08-06 23:17:00+03	112000.00
3AEA0F	2017-07-21 00:46:00+03	31100.00
3AEA29	2017-08-03 15:52:00+03	43600.00
3AEA5B	2017-07-28 07:23:00+03	64200.00
3AEA73	2017-07-21 02:59:00+03	37900.00
3AEA7B	2017-07-28 09:12:00+03	23400.00
3AEA7E	2017-07-06 11:49:00+03	48800.00
3AEA80	2017-07-19 14:51:00+03	49200.00
3AEAA4	2017-07-04 23:37:00+03	136000.00
3AEAF4	2017-07-29 02:30:00+03	85100.00
3AEB61	2017-07-03 12:45:00+03	88400.00
3AEBA4	2017-08-15 09:51:00+03	69500.00
3AEBC9	2017-08-06 08:37:00+03	18600.00
3AEC02	2017-07-13 23:28:00+03	58900.00
3AEC11	2017-07-23 01:19:00+03	14000.00
3AEC46	2017-08-07 05:12:00+03	331600.00
3AEC95	2017-08-07 03:17:00+03	28000.00
3AECB4	2017-07-31 04:02:00+03	38400.00
3AED0A	2017-07-03 21:17:00+03	113300.00
3AED5D	2017-08-12 20:16:00+03	25600.00
3AED84	2017-07-19 15:47:00+03	162400.00
3AEDBF	2017-07-07 18:32:00+03	6000.00
3AEE0E	2017-08-15 17:04:00+03	282600.00
3AEE52	2017-08-13 23:35:00+03	82900.00
3AEE76	2017-07-13 06:26:00+03	57600.00
3AEEE2	2017-07-10 20:59:00+03	41400.00
3AEF13	2017-07-03 18:11:00+03	53700.00
3AEF25	2017-07-13 03:17:00+03	105600.00
3AEFA7	2017-07-19 00:25:00+03	24400.00
3AF003	2017-08-15 09:24:00+03	246000.00
3AF063	2017-07-07 07:48:00+03	67200.00
3AF099	2017-06-30 22:40:00+03	48800.00
3AF0A7	2017-08-08 06:28:00+03	177200.00
3AF0C6	2017-07-09 23:29:00+03	182000.00
3AF0FD	2017-08-07 17:24:00+03	83000.00
3AF213	2017-08-14 12:48:00+03	46700.00
3AF278	2017-07-16 16:10:00+03	29600.00
3AF2BB	2017-08-14 16:49:00+03	115100.00
3AF2CE	2017-07-18 23:14:00+03	23200.00
3AF3BC	2017-07-30 22:27:00+03	28000.00
3AF458	2017-07-03 22:41:00+03	246000.00
3AF477	2017-08-08 01:27:00+03	46400.00
3AF4B3	2017-07-27 23:46:00+03	69500.00
3AF569	2017-07-14 08:13:00+03	21200.00
3AF5E6	2017-07-06 19:47:00+03	50800.00
3AF5F8	2017-07-18 15:38:00+03	28800.00
3AF65B	2017-08-09 14:05:00+03	13400.00
3AF681	2017-08-14 16:04:00+03	272400.00
3AF691	2017-07-09 02:35:00+03	78100.00
3AF6A3	2017-08-03 14:00:00+03	20500.00
3AF75C	2017-08-02 08:13:00+03	66600.00
3AF80E	2017-08-01 13:00:00+03	20800.00
3AF81F	2017-07-26 20:58:00+03	54500.00
3AF822	2017-07-10 19:48:00+03	24800.00
3AF885	2017-07-01 06:58:00+03	62900.00
3AF922	2017-08-06 02:04:00+03	160300.00
3AF946	2017-08-02 04:09:00+03	25600.00
3AF950	2017-07-17 22:01:00+03	16400.00
3AF99E	2017-08-08 10:02:00+03	27200.00
3AFA03	2017-07-24 01:45:00+03	85000.00
3AFA30	2017-08-10 00:51:00+03	315600.00
3AFA3C	2017-07-15 03:59:00+03	12400.00
3AFA97	2017-08-08 12:57:00+03	301800.00
3AFA9D	2017-07-11 00:21:00+03	6300.00
3AFAB8	2017-07-06 01:58:00+03	139400.00
3AFAD0	2017-08-04 13:58:00+03	81600.00
3AFAF6	2017-08-10 08:49:00+03	28800.00
3AFB1A	2017-07-09 00:58:00+03	69600.00
3AFB79	2017-08-10 15:10:00+03	31200.00
3AFC26	2017-07-30 01:34:00+03	112000.00
3AFC33	2017-07-03 12:48:00+03	372500.00
3AFC4A	2017-08-12 00:42:00+03	131800.00
3AFCAF	2017-07-22 14:14:00+03	97800.00
3AFD47	2017-07-11 10:50:00+03	59300.00
3AFDBF	2017-07-28 02:53:00+03	96300.00
3AFE43	2017-08-01 23:49:00+03	66600.00
3AFE5C	2017-07-08 12:46:00+03	406100.00
3AFE9A	2017-07-14 13:43:00+03	6700.00
3AFEB1	2017-08-13 16:02:00+03	107900.00
3AFEE4	2017-08-08 22:36:00+03	46000.00
3AFF07	2017-07-25 07:29:00+03	35600.00
3AFF37	2017-07-02 22:19:00+03	46500.00
3AFF78	2017-07-19 06:16:00+03	144700.00
3B0007	2017-08-11 15:31:00+03	118800.00
3B001F	2017-07-23 16:46:00+03	36200.00
3B007B	2017-07-01 18:19:00+03	44000.00
3B00C2	2017-06-28 02:37:00+03	46400.00
3B00D9	2017-08-09 01:41:00+03	67800.00
3B01B7	2017-07-15 08:08:00+03	62300.00
3B01D8	2017-07-04 08:18:00+03	56000.00
3B023D	2017-08-15 15:16:00+03	7400.00
3B025A	2017-07-25 12:48:00+03	45200.00
3B02C9	2017-07-30 22:18:00+03	61800.00
3B02F3	2017-07-18 01:57:00+03	65500.00
3B0309	2017-08-05 09:07:00+03	131900.00
3B0351	2017-08-06 12:33:00+03	126000.00
3B0391	2017-07-28 14:07:00+03	20400.00
3B03AA	2017-08-01 19:54:00+03	136200.00
3B042A	2017-08-13 23:47:00+03	38600.00
3B0459	2017-07-09 01:50:00+03	27200.00
3B0476	2017-08-01 11:02:00+03	127300.00
3B04A7	2017-07-23 22:43:00+03	43000.00
3B04DD	2017-07-29 02:18:00+03	69500.00
3B050A	2017-07-29 06:14:00+03	139900.00
3B0535	2017-08-14 03:44:00+03	100600.00
3B05A1	2017-06-24 10:48:00+03	22000.00
3B0660	2017-08-12 22:30:00+03	56000.00
3B06E2	2017-07-07 07:05:00+03	92000.00
3B06EF	2017-07-22 00:05:00+03	10800.00
3B0702	2017-07-09 15:53:00+03	15900.00
3B0706	2017-07-05 08:21:00+03	91500.00
3B071D	2017-08-01 08:08:00+03	107500.00
3B079F	2017-08-05 17:14:00+03	173600.00
3B07A1	2017-08-12 17:42:00+03	23200.00
3B07EB	2017-07-31 01:33:00+03	112000.00
3B0850	2017-08-12 07:04:00+03	261000.00
3B08B1	2017-07-02 12:29:00+03	246000.00
3B08C0	2017-07-06 03:22:00+03	155500.00
3B08C3	2017-08-03 11:11:00+03	24400.00
3B08FE	2017-07-18 23:19:00+03	201200.00
3B095C	2017-08-02 02:24:00+03	71200.00
3B09D6	2017-07-07 18:57:00+03	13400.00
3B0A10	2017-07-27 15:06:00+03	18000.00
3B0A46	2017-07-21 10:43:00+03	24400.00
3B0A57	2017-07-09 22:54:00+03	15700.00
3B0A61	2017-07-30 20:42:00+03	480600.00
3B0A6A	2017-08-15 04:44:00+03	13400.00
3B0A9C	2017-07-22 20:15:00+03	95200.00
3B0AA9	2017-07-29 14:37:00+03	30900.00
3B0AD6	2017-07-11 14:31:00+03	48800.00
3B0AD9	2017-07-26 19:20:00+03	26000.00
3B0B40	2017-07-24 16:13:00+03	136800.00
3B0B53	2017-07-06 20:36:00+03	92800.00
3B0B80	2017-06-28 05:34:00+03	12600.00
3B0B9E	2017-08-11 14:53:00+03	66600.00
3B0BB0	2017-08-11 03:22:00+03	94900.00
3B0BCC	2017-07-11 16:33:00+03	111600.00
3B0BDF	2017-07-18 17:17:00+03	39400.00
3B0C97	2017-07-20 18:44:00+03	103500.00
3B0CB2	2017-07-08 02:12:00+03	91100.00
3B0CD3	2017-06-30 03:42:00+03	37600.00
3B0D40	2017-06-30 20:54:00+03	90400.00
3B0D5A	2017-07-16 13:34:00+03	23400.00
3B0D7B	2017-07-02 17:55:00+03	75600.00
3B0D7C	2017-08-10 21:15:00+03	46000.00
3B0D80	2017-07-15 13:06:00+03	101400.00
3B0D9A	2017-08-08 09:34:00+03	28000.00
3B0DA7	2017-07-14 20:08:00+03	269200.00
3B0DD1	2017-08-13 23:07:00+03	51900.00
3B0E70	2017-07-15 12:05:00+03	53600.00
3B0EE3	2017-07-14 14:10:00+03	40100.00
3B0F2D	2017-07-23 13:37:00+03	27900.00
3B0F6B	2017-07-12 07:31:00+03	93900.00
3B0FA5	2017-07-01 23:59:00+03	69500.00
3B0FFD	2017-07-24 08:35:00+03	52000.00
3B1029	2017-08-14 11:31:00+03	30900.00
3B105C	2017-08-12 19:01:00+03	86600.00
3B1090	2017-07-31 14:49:00+03	44600.00
3B1166	2017-08-02 22:40:00+03	270800.00
3B116D	2017-08-04 00:26:00+03	12400.00
3B117B	2017-07-10 03:41:00+03	21400.00
3B127F	2017-07-19 16:55:00+03	112000.00
3B12B4	2017-08-04 01:00:00+03	52000.00
3B1309	2017-07-23 12:56:00+03	12400.00
3B136E	2017-07-11 23:20:00+03	71200.00
3B139F	2017-07-24 15:02:00+03	25200.00
3B142E	2017-07-27 21:54:00+03	50700.00
3B143B	2017-07-26 17:21:00+03	32800.00
3B1442	2017-06-30 15:29:00+03	38400.00
3B1481	2017-06-30 00:21:00+03	184300.00
3B161E	2017-08-04 15:36:00+03	81200.00
3B1658	2017-07-02 16:04:00+03	45100.00
3B16B8	2017-07-04 04:33:00+03	75300.00
3B1707	2017-07-20 05:45:00+03	29600.00
3B171D	2017-07-21 06:19:00+03	12400.00
3B1731	2017-07-09 21:04:00+03	129200.00
3B1745	2017-07-07 05:32:00+03	19600.00
3B1748	2017-07-11 04:09:00+03	48300.00
3B1791	2017-08-06 00:21:00+03	77000.00
3B179E	2017-08-03 03:47:00+03	48800.00
3B17C2	2017-07-16 06:45:00+03	88100.00
3B17D0	2017-08-09 19:07:00+03	35300.00
3B181F	2017-08-11 12:40:00+03	123000.00
3B182B	2017-07-07 06:31:00+03	16400.00
3B18F7	2017-08-13 11:45:00+03	65900.00
3B1926	2017-07-16 14:02:00+03	29600.00
3B199F	2017-08-12 11:55:00+03	260300.00
3B1A0B	2017-07-10 02:13:00+03	200400.00
3B1A8D	2017-07-16 00:03:00+03	48400.00
3B1AA2	2017-07-08 21:08:00+03	128900.00
3B1ACB	2017-07-18 16:05:00+03	106900.00
3B1B2F	2017-08-08 06:38:00+03	21400.00
3B1B60	2017-07-10 06:14:00+03	58800.00
3B1C2E	2017-08-05 02:08:00+03	155600.00
3B1C76	2017-07-31 13:06:00+03	103400.00
3B1CDF	2017-07-08 22:58:00+03	46800.00
3B1CF6	2017-07-26 15:47:00+03	56000.00
3B1D2D	2017-08-12 01:14:00+03	24400.00
3B1D3A	2017-07-30 18:00:00+03	37900.00
3B1D74	2017-07-06 16:46:00+03	40800.00
3B1DAA	2017-07-01 09:58:00+03	207200.00
3B1DB4	2017-07-24 02:44:00+03	100600.00
3B1DFA	2017-08-04 06:00:00+03	48700.00
3B1E55	2017-07-11 19:03:00+03	530400.00
3B1E91	2017-06-30 09:21:00+03	46400.00
3B1E92	2017-07-28 13:19:00+03	48800.00
3B1F0A	2017-08-12 12:47:00+03	37000.00
3B2073	2017-08-07 12:25:00+03	67900.00
3B2097	2017-07-31 21:34:00+03	92800.00
3B210A	2017-07-08 19:40:00+03	28000.00
3B2143	2017-07-16 06:16:00+03	129200.00
3B214B	2017-07-03 05:44:00+03	55800.00
3B2152	2017-07-14 10:26:00+03	32800.00
3B2238	2017-08-11 14:20:00+03	40800.00
3B22E3	2017-07-04 23:22:00+03	65900.00
3B2354	2017-07-25 19:40:00+03	30100.00
3B2439	2017-08-10 21:27:00+03	20000.00
3B2440	2017-08-15 09:25:00+03	139400.00
3B24AC	2017-07-24 14:25:00+03	64200.00
3B2519	2017-07-26 21:15:00+03	11600.00
3B2525	2017-06-28 07:17:00+03	113000.00
3B254C	2017-07-03 01:43:00+03	205900.00
3B2599	2017-07-26 00:30:00+03	22000.00
3B25A4	2017-08-10 10:29:00+03	83500.00
3B25AD	2017-08-09 21:04:00+03	89800.00
3B25DA	2017-07-17 15:34:00+03	44000.00
3B2602	2017-07-13 08:29:00+03	73300.00
3B260B	2017-07-25 00:39:00+03	36400.00
3B26DE	2017-06-25 18:41:00+03	76900.00
3B2721	2017-07-03 03:20:00+03	59800.00
3B2722	2017-07-23 23:30:00+03	266400.00
3B2770	2017-07-21 08:33:00+03	136200.00
3B2781	2017-08-05 08:29:00+03	14000.00
3B27DE	2017-07-20 08:51:00+03	40800.00
3B27FD	2017-07-15 12:42:00+03	78200.00
3B28AA	2017-07-12 04:04:00+03	141600.00
3B292B	2017-08-04 18:25:00+03	193100.00
3B297B	2017-08-05 15:45:00+03	25200.00
3B29D8	2017-07-15 17:38:00+03	46400.00
3B2A47	2017-07-26 23:47:00+03	125200.00
3B2A70	2017-07-16 03:01:00+03	93000.00
3B2A87	2017-07-05 01:47:00+03	28800.00
3B2A95	2017-07-30 12:55:00+03	59800.00
3B2ACC	2017-07-25 20:19:00+03	23400.00
3B2B7F	2017-07-22 13:03:00+03	14400.00
3B2BB2	2017-07-05 12:10:00+03	47700.00
3B2BB7	2017-08-06 22:24:00+03	27800.00
3B2BCD	2017-07-21 13:25:00+03	26000.00
3B2C01	2017-07-30 21:57:00+03	133200.00
3B2C05	2017-08-01 06:27:00+03	67000.00
3B2C15	2017-08-10 22:45:00+03	58400.00
3B2C3D	2017-07-15 12:05:00+03	266400.00
3B2D7A	2017-08-12 09:27:00+03	36200.00
3B2DA9	2017-07-17 06:35:00+03	20000.00
3B2DC4	2017-07-08 23:34:00+03	88600.00
3B2DDA	2017-07-12 11:05:00+03	58600.00
3B2E09	2017-07-24 04:36:00+03	44600.00
3B2F09	2017-07-09 05:22:00+03	136800.00
3B2F6C	2017-07-04 19:18:00+03	92800.00
3B2F7A	2017-07-16 18:24:00+03	28000.00
3B2FB2	2017-08-09 17:39:00+03	8000.00
3B2FE0	2017-07-06 06:37:00+03	51900.00
3B30EE	2017-07-04 20:01:00+03	81600.00
3B3120	2017-07-18 10:55:00+03	31600.00
3B3123	2017-07-07 21:30:00+03	58800.00
3B3149	2017-07-12 20:40:00+03	44600.00
3B3175	2017-07-22 12:25:00+03	16400.00
3B31B6	2017-07-26 13:15:00+03	231200.00
3B3276	2017-08-05 15:07:00+03	81600.00
3B32B4	2017-08-02 13:17:00+03	40000.00
3B3308	2017-08-05 12:16:00+03	92800.00
3B3346	2017-07-15 18:16:00+03	25900.00
3B3386	2017-07-26 01:22:00+03	85000.00
3B33DB	2017-08-04 00:07:00+03	42800.00
3B3461	2017-08-03 13:09:00+03	38800.00
3B3497	2017-07-21 05:34:00+03	39300.00
3B34A2	2017-08-04 20:39:00+03	50800.00
3B34AD	2017-08-12 01:48:00+03	21800.00
3B34C6	2017-07-20 13:17:00+03	28000.00
3B34CF	2017-08-10 15:14:00+03	24300.00
3B34F0	2017-08-10 21:10:00+03	37900.00
3B34FD	2017-07-25 19:55:00+03	38200.00
3B3534	2017-07-23 16:08:00+03	21400.00
3B3574	2017-08-12 17:02:00+03	67800.00
3B35A8	2017-07-22 06:02:00+03	13400.00
3B35AD	2017-08-07 18:40:00+03	12600.00
3B35B4	2017-07-04 13:11:00+03	136800.00
3B35EA	2017-07-15 04:56:00+03	171900.00
3B35F9	2017-07-25 00:23:00+03	259000.00
3B36FC	2017-06-29 03:49:00+03	6000.00
3B3708	2017-07-29 07:41:00+03	181600.00
3B370E	2017-07-21 09:44:00+03	37700.00
3B3797	2017-08-13 05:59:00+03	66000.00
3B3842	2017-07-11 09:37:00+03	26000.00
3B38C7	2017-08-07 09:47:00+03	40800.00
3B38EB	2017-08-08 01:22:00+03	148200.00
3B3937	2017-07-06 22:25:00+03	122500.00
3B3952	2017-08-01 04:51:00+03	46800.00
3B3A1E	2017-07-07 11:14:00+03	92700.00
3B3AFF	2017-07-09 01:45:00+03	46800.00
3B3B20	2017-07-26 18:32:00+03	129600.00
3B3B72	2017-08-05 05:51:00+03	124200.00
3B3B87	2017-07-20 12:22:00+03	55800.00
3B3BCE	2017-07-02 20:43:00+03	52800.00
3B3BD7	2017-08-05 18:36:00+03	71800.00
3B3BE1	2017-07-03 04:15:00+03	88900.00
3B3BFC	2017-07-07 14:45:00+03	76400.00
3B3C03	2017-07-03 11:38:00+03	36200.00
3B3D41	2017-07-07 02:45:00+03	248300.00
3B3DA3	2017-07-19 08:01:00+03	6000.00
3B3DAA	2017-08-13 07:57:00+03	6800.00
3B3DB3	2017-07-06 15:13:00+03	67100.00
3B3E64	2017-07-10 08:31:00+03	17000.00
3B3E70	2017-07-24 13:04:00+03	181400.00
3B3F07	2017-08-03 10:53:00+03	43800.00
3B3F6D	2017-07-31 15:25:00+03	67800.00
3B3FAB	2017-08-01 16:57:00+03	180000.00
3B403C	2017-07-11 06:27:00+03	96400.00
3B40CF	2017-07-22 00:35:00+03	198600.00
3B40DA	2017-07-23 07:45:00+03	92200.00
3B4106	2017-07-23 05:42:00+03	47600.00
3B4278	2017-08-10 17:38:00+03	25600.00
3B43AA	2017-07-16 16:38:00+03	52300.00
3B43AB	2017-07-02 05:22:00+03	266400.00
3B43C1	2017-08-03 13:20:00+03	129600.00
3B4416	2017-07-06 13:15:00+03	47500.00
3B4424	2017-08-07 20:21:00+03	25600.00
3B44E2	2017-07-11 11:00:00+03	136800.00
3B4505	2017-07-15 11:26:00+03	59000.00
3B455F	2017-07-04 21:57:00+03	43200.00
3B45A9	2017-07-23 02:44:00+03	20000.00
3B45D5	2017-08-05 03:30:00+03	643800.00
3B45F0	2017-07-13 16:20:00+03	56900.00
3B466E	2017-07-08 06:33:00+03	46200.00
3B471D	2017-07-09 13:33:00+03	155600.00
3B4721	2017-07-31 18:34:00+03	28000.00
3B4746	2017-07-31 23:23:00+03	27900.00
3B4781	2017-07-24 18:29:00+03	289800.00
3B478B	2017-07-28 03:24:00+03	114800.00
3B4794	2017-08-12 19:00:00+03	59800.00
3B481C	2017-07-14 10:00:00+03	61900.00
3B4850	2017-07-18 12:11:00+03	18800.00
3B485F	2017-08-07 06:20:00+03	60600.00
3B48BF	2017-07-13 02:00:00+03	34000.00
3B4916	2017-07-30 16:21:00+03	28300.00
3B4978	2017-08-11 16:00:00+03	43100.00
3B497D	2017-08-11 11:19:00+03	28800.00
3B498C	2017-07-17 10:01:00+03	59300.00
3B49F9	2017-07-19 08:57:00+03	29200.00
3B4A0D	2017-07-12 21:34:00+03	61200.00
3B4A38	2017-07-29 06:55:00+03	85700.00
3B4A59	2017-07-05 22:49:00+03	18100.00
3B4A70	2017-08-02 13:23:00+03	30300.00
3B4B76	2017-07-27 11:04:00+03	15900.00
3B4B98	2017-08-09 11:09:00+03	81800.00
3B4C24	2017-07-26 14:24:00+03	132800.00
3B4C37	2017-08-12 17:00:00+03	38000.00
3B4C5A	2017-07-16 07:06:00+03	26800.00
3B4C63	2017-08-11 23:56:00+03	66600.00
3B4C7F	2017-08-10 05:43:00+03	266400.00
3B4CA9	2017-08-09 14:23:00+03	99200.00
3B4CB7	2017-06-28 16:20:00+03	187600.00
3B4CC9	2017-08-10 15:24:00+03	73400.00
3B4D06	2017-07-09 08:14:00+03	29400.00
3B4D2B	2017-07-16 11:45:00+03	6700.00
3B4D43	2017-08-13 08:34:00+03	26000.00
3B4D58	2017-07-08 16:13:00+03	56000.00
3B4D5C	2017-08-15 09:30:00+03	26800.00
3B4D82	2017-07-08 17:41:00+03	229300.00
3B4D8A	2017-07-20 07:40:00+03	23200.00
3B4DCB	2017-07-21 10:48:00+03	25100.00
3B4DDA	2017-08-04 02:39:00+03	170000.00
3B4E14	2017-08-11 19:50:00+03	246000.00
3B4E46	2017-07-23 17:18:00+03	42800.00
3B4EAF	2017-07-10 11:17:00+03	6800.00
3B4EB6	2017-08-10 13:08:00+03	123000.00
3B4EEF	2017-08-10 21:01:00+03	26400.00
3B4FEF	2017-06-28 20:23:00+03	149100.00
3B501A	2017-07-25 01:55:00+03	35600.00
3B5028	2017-08-09 07:43:00+03	35600.00
3B506C	2017-08-08 18:36:00+03	66800.00
3B510A	2017-07-02 08:48:00+03	14400.00
3B512E	2017-07-12 00:33:00+03	55800.00
3B515B	2017-07-28 23:57:00+03	56600.00
3B51A0	2017-07-17 23:20:00+03	6700.00
3B51B4	2017-07-24 22:28:00+03	10100.00
3B51BD	2017-07-06 04:30:00+03	106200.00
3B51FE	2017-07-18 03:48:00+03	12400.00
3B5213	2017-08-02 05:43:00+03	55800.00
3B5263	2017-07-26 17:19:00+03	109600.00
3B52AB	2017-08-03 16:58:00+03	50400.00
3B52B2	2017-08-08 11:15:00+03	56100.00
3B52D0	2017-07-21 21:12:00+03	87700.00
3B52D3	2017-07-30 05:25:00+03	117000.00
3B5325	2017-07-31 20:51:00+03	29400.00
3B5350	2017-07-29 00:44:00+03	469400.00
3B5371	2017-07-30 13:44:00+03	12400.00
3B5378	2017-08-10 21:02:00+03	34200.00
3B53AC	2017-07-27 08:43:00+03	56100.00
3B5466	2017-08-03 12:04:00+03	166100.00
3B54B0	2017-07-13 22:58:00+03	62100.00
3B54BB	2017-07-05 17:08:00+03	1204500.00
3B54F0	2017-07-09 16:09:00+03	22000.00
3B54F4	2017-07-30 00:05:00+03	65400.00
3B552D	2017-07-02 14:22:00+03	54800.00
3B55C1	2017-07-18 03:45:00+03	268400.00
3B55C7	2017-08-10 20:21:00+03	273600.00
3B5637	2017-08-07 21:54:00+03	34400.00
3B5693	2017-08-08 16:43:00+03	96600.00
3B56C3	2017-07-14 05:09:00+03	6700.00
3B56D0	2017-07-22 02:12:00+03	25600.00
3B5746	2017-07-31 11:34:00+03	155600.00
3B575D	2017-08-12 14:52:00+03	58400.00
3B576A	2017-07-17 00:23:00+03	206800.00
3B57C2	2017-07-11 13:02:00+03	28000.00
3B5854	2017-08-03 18:09:00+03	46400.00
3B58DE	2017-07-18 11:48:00+03	14000.00
3B5922	2017-07-15 12:37:00+03	70700.00
3B5948	2017-08-12 09:23:00+03	46000.00
3B59E4	2017-07-21 12:50:00+03	148200.00
3B5A29	2017-08-06 12:04:00+03	105000.00
3B5A35	2017-08-07 15:33:00+03	48800.00
3B5A4D	2017-07-29 22:56:00+03	71600.00
3B5A53	2017-07-03 21:33:00+03	120800.00
3B5A96	2017-06-28 04:09:00+03	40000.00
3B5AC9	2017-07-06 06:44:00+03	28800.00
3B5ADB	2017-08-02 20:25:00+03	26000.00
3B5B07	2017-08-05 08:41:00+03	21600.00
3B5B0C	2017-08-02 15:15:00+03	266400.00
3B5B4F	2017-07-06 17:43:00+03	101200.00
3B5B71	2017-07-29 14:18:00+03	132800.00
3B5B79	2017-07-03 23:06:00+03	33200.00
3B5D56	2017-08-11 06:51:00+03	27900.00
3B5DB5	2017-07-25 18:54:00+03	28800.00
3B5DDE	2017-07-25 03:45:00+03	60400.00
3B5E14	2017-08-03 16:34:00+03	266200.00
3B5E21	2017-07-17 08:10:00+03	23400.00
3B5E4F	2017-08-08 03:05:00+03	66800.00
3B5E88	2017-07-02 16:04:00+03	64500.00
3B5EC8	2017-07-05 15:21:00+03	78200.00
3B5EDF	2017-07-31 12:52:00+03	83600.00
3B5F59	2017-07-27 01:08:00+03	34000.00
3B5F9B	2017-08-02 09:24:00+03	175300.00
3B5FE5	2017-08-12 03:27:00+03	54400.00
3B604D	2017-08-14 02:36:00+03	36000.00
3B60BE	2017-07-24 05:25:00+03	38400.00
3B60CA	2017-07-20 08:27:00+03	40800.00
3B60DC	2017-08-02 12:01:00+03	55800.00
3B60EC	2017-07-06 18:55:00+03	27400.00
3B60EF	2017-07-28 05:02:00+03	26700.00
3B612C	2017-07-19 17:59:00+03	18900.00
3B61C9	2017-08-13 09:12:00+03	118500.00
3B61F6	2017-07-03 16:55:00+03	58000.00
3B61F8	2017-08-08 07:12:00+03	8200.00
3B621C	2017-08-11 16:29:00+03	43400.00
3B62D1	2017-08-01 12:15:00+03	43900.00
3B6314	2017-07-16 08:39:00+03	107400.00
3B6342	2017-07-08 07:51:00+03	30200.00
3B635E	2017-08-04 03:17:00+03	28000.00
3B6361	2017-07-15 03:16:00+03	47100.00
3B63AF	2017-08-08 03:29:00+03	30200.00
3B6416	2017-08-02 08:52:00+03	46400.00
3B645A	2017-07-30 13:08:00+03	34000.00
3B64B4	2017-07-14 06:45:00+03	135400.00
3B6541	2017-08-06 12:42:00+03	50600.00
3B6663	2017-08-04 08:55:00+03	187600.00
3B668F	2017-07-16 12:11:00+03	40800.00
3B66D6	2017-08-05 12:54:00+03	100200.00
3B66DA	2017-08-05 19:57:00+03	93900.00
3B66FC	2017-08-02 16:35:00+03	8200.00
3B6707	2017-06-29 19:33:00+03	26700.00
3B6819	2017-08-02 00:28:00+03	63500.00
3B681C	2017-08-08 03:38:00+03	26200.00
3B684A	2017-06-30 09:10:00+03	43900.00
3B6870	2017-08-04 08:09:00+03	33100.00
3B68BC	2017-08-11 12:19:00+03	72000.00
3B68ED	2017-07-24 07:28:00+03	6000.00
3B6901	2017-07-08 06:59:00+03	36400.00
3B6953	2017-07-18 10:11:00+03	19600.00
3B69C9	2017-08-09 21:53:00+03	116300.00
3B69D3	2017-07-04 01:15:00+03	75300.00
3B69DE	2017-07-15 23:21:00+03	339900.00
3B6A1C	2017-08-09 06:55:00+03	29400.00
3B6A34	2017-07-24 03:11:00+03	133200.00
3B6A39	2017-07-09 21:17:00+03	24400.00
3B6AA1	2017-08-07 05:02:00+03	107200.00
3B6AE7	2017-07-24 15:45:00+03	103000.00
3B6B16	2017-08-12 16:13:00+03	136200.00
3B6B63	2017-08-07 22:24:00+03	76600.00
3B6B76	2017-08-12 11:05:00+03	97000.00
3B6BE2	2017-07-02 13:34:00+03	100600.00
3B6C05	2017-07-15 10:14:00+03	17600.00
3B6C3C	2017-07-25 00:34:00+03	39100.00
3B6CEA	2017-08-10 22:04:00+03	43200.00
3B6D2A	2017-08-02 15:09:00+03	28800.00
3B6D58	2017-08-08 05:14:00+03	175000.00
3B6D89	2017-07-07 15:47:00+03	46400.00
3B6D8E	2017-07-31 08:29:00+03	88300.00
3B6D93	2017-07-19 02:51:00+03	240600.00
3B6DCC	2017-07-27 08:12:00+03	28000.00
3B6DE5	2017-06-30 21:33:00+03	86800.00
3B6DEC	2017-07-05 12:06:00+03	398500.00
3B6F20	2017-07-02 10:58:00+03	29100.00
3B6F55	2017-07-27 21:27:00+03	134400.00
3B6F6B	2017-08-15 07:00:00+03	27200.00
3B6F78	2017-07-31 22:26:00+03	65600.00
3B7007	2017-08-01 21:24:00+03	73600.00
3B700D	2017-07-24 14:10:00+03	28000.00
3B703F	2017-07-26 13:57:00+03	35900.00
3B70AB	2017-08-02 23:52:00+03	72300.00
3B70C9	2017-08-15 08:22:00+03	270700.00
3B70EC	2017-07-10 06:16:00+03	16400.00
3B7102	2017-07-17 02:10:00+03	14000.00
3B7179	2017-08-15 14:14:00+03	32800.00
3B717C	2017-07-28 11:21:00+03	90600.00
3B721B	2017-07-20 13:42:00+03	23200.00
3B7220	2017-07-31 16:07:00+03	202000.00
3B7224	2017-07-08 09:51:00+03	178800.00
3B7299	2017-08-07 06:16:00+03	20600.00
3B732B	2017-08-06 06:55:00+03	55800.00
3B7345	2017-06-30 20:45:00+03	23400.00
3B734B	2017-06-29 11:24:00+03	22100.00
3B7371	2017-07-07 08:17:00+03	24700.00
3B7392	2017-07-16 10:16:00+03	191000.00
3B7396	2017-07-03 20:16:00+03	7200.00
3B7399	2017-07-04 23:14:00+03	73500.00
3B73A8	2017-07-30 11:27:00+03	96200.00
3B73AF	2017-07-13 04:35:00+03	64900.00
3B73B1	2017-06-30 20:57:00+03	45200.00
3B7468	2017-07-26 01:18:00+03	14800.00
3B746B	2017-07-16 13:32:00+03	29600.00
3B7488	2017-07-19 14:31:00+03	25100.00
3B749A	2017-07-01 04:56:00+03	20400.00
3B74C0	2017-07-21 12:34:00+03	160200.00
3B7578	2017-07-28 12:49:00+03	22600.00
3B75A2	2017-07-09 13:05:00+03	246000.00
3B7652	2017-07-21 00:50:00+03	26800.00
3B769B	2017-07-16 14:38:00+03	25600.00
3B76A5	2017-07-09 08:30:00+03	64700.00
3B76A6	2017-07-02 18:48:00+03	28000.00
3B7753	2017-07-04 06:31:00+03	199200.00
3B775D	2017-07-26 17:34:00+03	8400.00
3B789F	2017-08-11 14:01:00+03	32900.00
3B78FF	2017-08-10 22:50:00+03	112000.00
3B7920	2017-08-13 17:57:00+03	62600.00
3B79B7	2017-07-11 00:25:00+03	7400.00
3B7A01	2017-07-28 03:36:00+03	24200.00
3B7A2B	2017-07-08 21:13:00+03	26000.00
3B7A60	2017-07-01 18:54:00+03	83000.00
3B7A89	2017-08-04 03:43:00+03	113200.00
3B7AA8	2017-07-12 06:13:00+03	125200.00
3B7AC0	2017-07-13 05:18:00+03	433300.00
3B7ACF	2017-07-12 03:22:00+03	66800.00
3B7AE8	2017-08-02 11:56:00+03	44000.00
3B7B02	2017-08-10 02:03:00+03	27600.00
3B7BDA	2017-08-14 00:50:00+03	89000.00
3B7BE5	2017-07-20 13:17:00+03	43500.00
3B7C09	2017-07-21 18:58:00+03	124100.00
3B7D95	2017-07-24 15:33:00+03	91100.00
3B7E41	2017-07-19 03:57:00+03	43800.00
3B7E6B	2017-07-27 13:49:00+03	126300.00
3B7ED3	2017-08-13 12:21:00+03	111600.00
3B7EF9	2017-07-09 00:15:00+03	213200.00
3B7F22	2017-07-02 13:23:00+03	34000.00
3B7F4E	2017-07-13 19:58:00+03	152400.00
3B7F51	2017-08-03 06:05:00+03	48700.00
3B7F66	2017-07-06 22:49:00+03	27200.00
3B7F7F	2017-07-14 15:57:00+03	47100.00
3B7F8C	2017-08-13 23:55:00+03	92700.00
3B7FEF	2017-07-21 00:09:00+03	6000.00
3B800E	2017-07-05 00:22:00+03	121700.00
3B8065	2017-08-04 14:51:00+03	40000.00
3B8071	2017-08-03 10:22:00+03	28000.00
3B8098	2017-08-10 00:51:00+03	86300.00
3B809D	2017-07-31 04:06:00+03	29100.00
3B80BC	2017-08-06 22:19:00+03	88000.00
3B812C	2017-08-11 01:21:00+03	88100.00
3B8130	2017-07-25 18:20:00+03	56000.00
3B8135	2017-08-13 07:20:00+03	14000.00
3B829F	2017-07-10 14:30:00+03	73000.00
3B8326	2017-06-29 23:29:00+03	133100.00
3B836C	2017-07-01 17:05:00+03	134700.00
3B83AB	2017-08-11 20:59:00+03	72600.00
3B83DC	2017-07-15 09:15:00+03	201200.00
3B84E4	2017-08-03 21:28:00+03	286100.00
3B8597	2017-07-24 03:38:00+03	37900.00
3B85B9	2017-07-19 02:41:00+03	49100.00
3B86EA	2017-07-26 12:34:00+03	65900.00
3B878B	2017-07-16 18:02:00+03	48500.00
3B87BC	2017-08-08 15:16:00+03	26800.00
3B87DC	2017-07-30 23:22:00+03	46200.00
3B87E8	2017-07-12 18:18:00+03	27800.00
3B8832	2017-07-27 12:44:00+03	24400.00
3B8846	2017-07-16 07:21:00+03	53600.00
3B8869	2017-07-01 16:04:00+03	24000.00
3B8879	2017-08-13 07:03:00+03	67600.00
3B88D3	2017-07-11 00:20:00+03	70000.00
3B8959	2017-07-04 05:35:00+03	246000.00
3B89CE	2017-08-04 06:27:00+03	152500.00
3B8A1B	2017-07-02 12:13:00+03	46000.00
3B8A1C	2017-08-13 19:10:00+03	26200.00
3B8A32	2017-08-04 16:51:00+03	33100.00
3B8A40	2017-08-08 14:51:00+03	69400.00
3B8AC2	2017-07-13 06:13:00+03	14000.00
3B8AD1	2017-08-06 07:06:00+03	168200.00
3B8B1F	2017-07-11 18:31:00+03	168000.00
3B8C20	2017-07-07 07:48:00+03	12600.00
3B8C84	2017-07-10 17:22:00+03	46300.00
3B8CA5	2017-07-04 21:37:00+03	17600.00
3B8CC5	2017-08-08 06:23:00+03	16400.00
3B8D1F	2017-07-03 04:34:00+03	53500.00
3B8D27	2017-07-24 12:30:00+03	84200.00
3B8D5E	2017-08-12 06:04:00+03	28000.00
3B8D6D	2017-08-10 07:58:00+03	6700.00
3B8D7C	2017-07-18 18:04:00+03	16400.00
3B8D97	2017-07-25 11:25:00+03	26200.00
3B8E1A	2017-07-12 06:00:00+03	28000.00
3B8E3F	2017-08-10 00:49:00+03	16400.00
3B8E4D	2017-07-10 10:30:00+03	37900.00
3B8E57	2017-07-25 08:09:00+03	134000.00
3B8EDE	2017-07-21 13:28:00+03	77900.00
3B8F09	2017-07-03 17:16:00+03	28800.00
3B8F47	2017-07-13 19:30:00+03	38400.00
3B8F49	2017-08-09 21:27:00+03	75300.00
3B8F53	2017-07-11 20:08:00+03	47200.00
3B8FB0	2017-07-16 14:22:00+03	77000.00
3B9009	2017-07-05 18:01:00+03	177500.00
3B9051	2017-07-23 09:02:00+03	56000.00
3B906B	2017-08-15 11:13:00+03	93900.00
3B906D	2017-07-16 01:43:00+03	37900.00
3B9087	2017-08-01 10:01:00+03	30000.00
3B909E	2017-07-03 18:44:00+03	50600.00
3B915D	2017-07-30 00:02:00+03	14400.00
3B918F	2017-07-14 05:11:00+03	90200.00
3B919B	2017-08-01 00:49:00+03	10600.00
3B9201	2017-07-18 13:48:00+03	24000.00
3B925D	2017-08-12 11:40:00+03	24400.00
3B9275	2017-07-10 08:32:00+03	186900.00
3B92AB	2017-08-01 05:24:00+03	31600.00
3B92F3	2017-06-26 08:04:00+03	13700.00
3B9335	2017-07-11 23:26:00+03	35600.00
3B9359	2017-08-09 08:12:00+03	94400.00
3B93CA	2017-07-11 18:37:00+03	46200.00
3B9403	2017-07-21 17:17:00+03	36200.00
3B9406	2017-07-31 21:15:00+03	56000.00
3B94A8	2017-07-25 23:14:00+03	46400.00
3B955C	2017-07-16 13:50:00+03	13400.00
3B955F	2017-08-10 23:18:00+03	52900.00
3B9572	2017-07-12 16:46:00+03	135600.00
3B958D	2017-07-08 20:38:00+03	290600.00
3B9593	2017-08-07 07:36:00+03	133100.00
3B95A6	2017-07-25 16:17:00+03	239400.00
3B95D3	2017-08-12 13:12:00+03	67600.00
3B95F2	2017-08-09 01:16:00+03	226200.00
3B9610	2017-07-05 22:39:00+03	29600.00
3B9612	2017-07-26 16:29:00+03	32700.00
3B9644	2017-07-03 16:00:00+03	194800.00
3B965C	2017-07-20 03:19:00+03	39800.00
3B965E	2017-06-28 11:42:00+03	20000.00
3B9681	2017-08-12 13:10:00+03	7400.00
3B969D	2017-07-03 02:20:00+03	92900.00
3B96B1	2017-07-07 20:13:00+03	40800.00
3B96E8	2017-07-31 04:50:00+03	34000.00
3B96F1	2017-07-23 23:42:00+03	31600.00
3B9740	2017-07-03 20:27:00+03	73500.00
3B9741	2017-07-03 04:23:00+03	139300.00
3B979D	2017-07-30 20:22:00+03	408500.00
3B9807	2017-07-30 17:29:00+03	18000.00
3B985B	2017-08-03 16:36:00+03	25900.00
3B989A	2017-08-13 03:48:00+03	46000.00
3B98D4	2017-07-05 16:12:00+03	23200.00
3B991C	2017-08-07 19:32:00+03	56600.00
3B99CE	2017-07-14 12:20:00+03	111600.00
3B9A0A	2017-07-27 16:49:00+03	114800.00
3B9A54	2017-07-07 18:32:00+03	28000.00
3B9A63	2017-07-24 01:55:00+03	46200.00
3B9A79	2017-07-19 04:23:00+03	73300.00
3B9AF0	2017-07-26 17:32:00+03	26000.00
3B9B07	2017-07-24 13:40:00+03	28000.00
3B9B1F	2017-06-28 19:57:00+03	124000.00
3B9B68	2017-07-15 20:10:00+03	120700.00
3B9B98	2017-08-06 00:27:00+03	15800.00
3B9C42	2017-07-17 15:53:00+03	40800.00
3B9CBD	2017-07-02 16:05:00+03	14400.00
3B9CC0	2017-07-20 11:51:00+03	23200.00
3B9CDB	2017-07-17 14:46:00+03	131100.00
3B9CE0	2017-07-23 15:45:00+03	28700.00
3B9CE1	2017-08-09 11:41:00+03	26000.00
3B9D55	2017-07-14 22:10:00+03	65300.00
3B9D91	2017-07-16 19:18:00+03	16400.00
3B9D97	2017-07-24 00:45:00+03	32800.00
3B9E67	2017-07-08 20:24:00+03	99200.00
3B9EF7	2017-08-11 20:13:00+03	23200.00
3B9F51	2017-07-21 02:57:00+03	23200.00
3B9F56	2017-07-17 00:16:00+03	20400.00
3B9F86	2017-08-04 02:27:00+03	55800.00
3B9FD3	2017-07-23 22:04:00+03	117600.00
3B9FF0	2017-08-09 01:23:00+03	23600.00
3BA00C	2017-08-14 16:30:00+03	28800.00
3BA033	2017-07-29 07:33:00+03	38800.00
3BA0B7	2017-07-24 13:52:00+03	28000.00
3BA0D7	2017-08-06 18:33:00+03	18000.00
3BA0F0	2017-08-08 04:44:00+03	56600.00
3BA11C	2017-07-04 07:29:00+03	280000.00
3BA170	2017-07-30 09:59:00+03	33100.00
3BA1C1	2017-07-23 20:21:00+03	46400.00
3BA217	2017-08-11 12:40:00+03	53300.00
3BA260	2017-07-25 20:22:00+03	38600.00
3BA295	2017-07-19 14:10:00+03	38400.00
3BA37A	2017-07-21 22:11:00+03	84000.00
3BA388	2017-07-06 08:07:00+03	123200.00
3BA45D	2017-08-10 17:29:00+03	139400.00
3BA4B5	2017-08-13 08:53:00+03	147700.00
3BA4C9	2017-07-15 14:51:00+03	25000.00
3BA5A9	2017-07-15 16:49:00+03	24400.00
3BA5CE	2017-08-13 18:26:00+03	73200.00
3BA615	2017-08-06 03:14:00+03	92400.00
3BA646	2017-07-18 17:07:00+03	378400.00
3BA657	2017-07-25 22:54:00+03	99600.00
3BA71B	2017-08-04 01:36:00+03	174400.00
3BA742	2017-07-30 04:35:00+03	259100.00
3BA8B4	2017-08-11 10:08:00+03	111600.00
3BA8EA	2017-07-02 05:16:00+03	29600.00
3BA92C	2017-07-30 12:55:00+03	147700.00
3BA97F	2017-08-15 09:33:00+03	202600.00
3BA981	2017-08-13 21:57:00+03	62600.00
3BA984	2017-07-05 03:47:00+03	16400.00
3BA9B7	2017-07-16 16:11:00+03	25600.00
3BA9C1	2017-07-31 04:58:00+03	37200.00
3BA9E0	2017-07-01 11:43:00+03	28000.00
3BAA76	2017-08-07 19:54:00+03	53100.00
3BAA7C	2017-07-20 12:13:00+03	54000.00
3BAA95	2017-07-21 16:29:00+03	34000.00
3BAA97	2017-07-19 02:27:00+03	37900.00
3BAAF3	2017-08-11 01:49:00+03	62700.00
3BAB25	2017-08-11 00:05:00+03	26700.00
3BABD0	2017-07-09 08:03:00+03	56000.00
3BAC17	2017-07-04 08:53:00+03	202400.00
3BAC27	2017-08-03 19:40:00+03	24200.00
3BAC65	2017-07-19 00:38:00+03	51300.00
3BACD0	2017-07-31 09:40:00+03	175800.00
3BAD12	2017-07-31 16:51:00+03	265800.00
3BAD5F	2017-07-13 00:03:00+03	24000.00
3BAD63	2017-07-12 07:56:00+03	60900.00
3BAD74	2017-08-15 07:53:00+03	28000.00
3BAD75	2017-07-30 10:22:00+03	135400.00
3BAD8F	2017-07-29 16:51:00+03	39500.00
3BAD92	2017-08-05 17:24:00+03	39500.00
3BAD9A	2017-08-09 12:26:00+03	29600.00
3BADD9	2017-08-11 12:09:00+03	15000.00
3BADE3	2017-07-18 00:10:00+03	46000.00
3BAEFE	2017-07-20 17:44:00+03	88900.00
3BAF42	2017-08-13 15:33:00+03	38800.00
3BAFC5	2017-07-19 21:26:00+03	28800.00
3BB01F	2017-07-25 12:58:00+03	77100.00
3BB033	2017-07-08 09:12:00+03	47500.00
3BB148	2017-07-20 13:07:00+03	21400.00
3BB17F	2017-07-30 12:57:00+03	58900.00
3BB212	2017-08-06 21:42:00+03	133100.00
3BB23B	2017-07-08 15:55:00+03	46400.00
3BB24E	2017-07-13 08:47:00+03	23100.00
3BB27A	2017-07-05 21:08:00+03	56000.00
3BB27C	2017-08-10 00:51:00+03	98400.00
3BB2DE	2017-08-04 08:42:00+03	41200.00
3BB2EA	2017-08-12 08:29:00+03	123000.00
3BB31F	2017-07-05 10:10:00+03	141100.00
3BB33C	2017-07-05 16:14:00+03	86100.00
3BB35A	2017-07-31 19:04:00+03	58200.00
3BB37B	2017-07-08 15:04:00+03	20600.00
3BB3FC	2017-07-18 23:15:00+03	81700.00
3BB419	2017-07-26 06:55:00+03	66600.00
3BB446	2017-07-27 02:14:00+03	37700.00
3BB479	2017-08-13 15:15:00+03	54000.00
3BB4AA	2017-07-09 03:52:00+03	123000.00
3BB4AE	2017-08-08 10:02:00+03	92800.00
3BB55C	2017-08-10 22:23:00+03	294200.00
3BB57A	2017-08-11 16:58:00+03	26000.00
3BB58C	2017-07-10 13:53:00+03	85000.00
3BB5D0	2017-07-20 11:34:00+03	27800.00
3BB60E	2017-07-06 06:00:00+03	11600.00
3BB625	2017-08-08 04:07:00+03	75300.00
3BB66D	2017-08-13 01:31:00+03	87100.00
3BB67A	2017-07-06 18:44:00+03	23200.00
3BB6B2	2017-07-23 09:18:00+03	135400.00
3BB6B4	2017-07-08 00:29:00+03	27200.00
3BB6CC	2017-08-04 22:32:00+03	47400.00
3BB729	2017-08-08 07:22:00+03	246000.00
3BB75A	2017-07-15 04:57:00+03	169800.00
3BB76F	2017-07-08 02:07:00+03	23200.00
3BB7C1	2017-07-18 08:28:00+03	19600.00
3BB7D6	2017-07-12 13:39:00+03	92800.00
3BB801	2017-07-10 19:21:00+03	88100.00
3BB802	2017-08-05 14:07:00+03	28000.00
3BB827	2017-07-10 19:35:00+03	56000.00
3BB830	2017-07-17 22:32:00+03	28000.00
3BB882	2017-07-12 01:54:00+03	6300.00
3BB8C5	2017-08-13 16:16:00+03	128300.00
3BB8D6	2017-08-05 13:23:00+03	52000.00
3BB8E9	2017-07-12 23:39:00+03	44500.00
3BB907	2017-07-28 22:44:00+03	23200.00
3BB961	2017-08-11 12:06:00+03	75300.00
3BB972	2017-07-08 00:58:00+03	155600.00
3BB9CF	2017-07-21 00:08:00+03	32700.00
3BBA0D	2017-07-08 05:30:00+03	205000.00
3BBA25	2017-07-01 15:14:00+03	6300.00
3BBAF2	2017-07-03 10:00:00+03	39800.00
3BBB87	2017-07-25 05:27:00+03	27600.00
3BBC3E	2017-07-26 20:26:00+03	84500.00
3BBC68	2017-08-09 18:53:00+03	89600.00
3BBC6B	2017-07-11 12:15:00+03	55800.00
3BBCC9	2017-08-12 11:23:00+03	46000.00
3BBCCC	2017-08-03 09:52:00+03	62600.00
3BBCD1	2017-08-07 03:04:00+03	8000.00
3BBCE5	2017-07-23 08:30:00+03	268400.00
3BBCE7	2017-07-05 17:16:00+03	48800.00
3BBCED	2017-07-06 01:33:00+03	88500.00
3BBCF6	2017-08-09 14:49:00+03	19800.00
3BBD27	2017-08-02 10:13:00+03	31400.00
3BBD48	2017-07-18 06:03:00+03	55800.00
3BBD65	2017-07-28 02:18:00+03	65500.00
3BBD84	2017-07-25 06:56:00+03	66100.00
3BBE00	2017-08-05 07:35:00+03	65900.00
3BBE02	2017-08-15 08:31:00+03	39800.00
3BBE23	2017-07-06 08:03:00+03	34800.00
3BBF7A	2017-07-12 12:48:00+03	200700.00
3BBF7C	2017-07-20 17:45:00+03	79800.00
3BBF89	2017-07-26 23:14:00+03	34000.00
3BBF8E	2017-07-01 22:26:00+03	64500.00
3BBFFA	2017-07-14 06:28:00+03	56600.00
3BC176	2017-07-03 14:29:00+03	93900.00
3BC1E8	2017-07-19 08:06:00+03	46400.00
3BC21B	2017-07-17 18:08:00+03	78000.00
3BC224	2017-06-30 01:57:00+03	43500.00
3BC26A	2017-08-08 19:16:00+03	73600.00
3BC2C6	2017-07-29 19:13:00+03	17000.00
3BC315	2017-08-13 10:50:00+03	327200.00
3BC33D	2017-07-27 08:13:00+03	131600.00
3BC38E	2017-07-02 23:07:00+03	42800.00
3BC3A3	2017-07-16 21:52:00+03	23200.00
3BC403	2017-08-12 04:51:00+03	35300.00
3BC45D	2017-07-23 05:48:00+03	33300.00
3BC46E	2017-07-10 16:29:00+03	34000.00
3BC486	2017-07-30 06:41:00+03	59400.00
3BC4BB	2017-08-12 23:52:00+03	132800.00
3BC4D8	2017-07-24 15:10:00+03	38400.00
3BC4DB	2017-07-28 21:32:00+03	57600.00
3BC4EB	2017-07-22 14:13:00+03	50000.00
3BC507	2017-07-05 20:49:00+03	6800.00
3BC599	2017-08-12 18:05:00+03	102100.00
3BC5E3	2017-07-13 07:22:00+03	11600.00
3BC5F4	2017-07-31 12:15:00+03	13400.00
3BC62E	2017-08-02 04:27:00+03	26800.00
3BC62F	2017-07-28 00:30:00+03	135400.00
3BC6B6	2017-07-22 10:38:00+03	22000.00
3BC6D5	2017-07-27 04:28:00+03	58000.00
3BC6F0	2017-07-22 19:27:00+03	36200.00
3BC6F9	2017-08-15 15:39:00+03	12600.00
3BC779	2017-07-21 05:56:00+03	105100.00
3BC77E	2017-07-25 11:41:00+03	104200.00
3BC806	2017-08-15 07:05:00+03	93900.00
3BC859	2017-07-05 18:56:00+03	64700.00
3BC8A6	2017-08-05 10:43:00+03	246000.00
3BC8F9	2017-08-08 18:08:00+03	40600.00
3BC90D	2017-07-06 20:57:00+03	135600.00
3BC91C	2017-07-01 11:55:00+03	25000.00
3BC946	2017-07-23 04:13:00+03	136200.00
3BC95B	2017-06-29 22:19:00+03	56600.00
3BCA57	2017-08-10 07:29:00+03	290600.00
3BCA7E	2017-07-23 20:59:00+03	28000.00
3BCBB1	2017-07-24 15:10:00+03	32800.00
3BCBBE	2017-08-08 08:03:00+03	72300.00
3BCBEC	2017-08-10 15:52:00+03	26700.00
3BCC3B	2017-08-06 03:05:00+03	67500.00
3BCC80	2017-08-08 15:02:00+03	474800.00
3BCC9A	2017-07-05 10:15:00+03	201200.00
3BCCB0	2017-07-29 10:17:00+03	28000.00
3BCCC6	2017-07-10 07:36:00+03	131100.00
3BCCF4	2017-07-25 22:08:00+03	139200.00
3BCDBE	2017-08-10 01:43:00+03	37000.00
3BCDDF	2017-08-12 07:17:00+03	19000.00
3BCE0F	2017-08-02 01:58:00+03	67700.00
3BCE81	2017-07-24 15:48:00+03	51600.00
3BCE96	2017-07-06 04:05:00+03	3700.00
3BCEC8	2017-07-11 03:17:00+03	57500.00
3BCF04	2017-08-11 10:58:00+03	32700.00
3BCF14	2017-07-16 07:59:00+03	16400.00
3BCF57	2017-07-18 07:19:00+03	62000.00
3BCFE3	2017-07-16 00:30:00+03	27300.00
3BD016	2017-07-15 00:51:00+03	22600.00
3BD02F	2017-08-03 06:02:00+03	117200.00
3BD04C	2017-07-05 11:43:00+03	46000.00
3BD051	2017-08-15 04:11:00+03	26700.00
3BD064	2017-08-04 12:38:00+03	40100.00
3BD0F1	2017-07-25 10:06:00+03	279500.00
3BD123	2017-07-14 16:49:00+03	13000.00
3BD1B1	2017-07-10 06:50:00+03	27900.00
3BD1F8	2017-07-27 16:11:00+03	27800.00
3BD210	2017-08-12 10:47:00+03	29200.00
3BD222	2017-07-19 16:41:00+03	73400.00
3BD249	2017-06-28 10:38:00+03	56100.00
3BD27B	2017-08-06 15:24:00+03	18000.00
3BD286	2017-07-18 21:36:00+03	75600.00
3BD294	2017-07-26 19:07:00+03	28800.00
3BD29F	2017-07-23 14:16:00+03	99200.00
3BD2FF	2017-07-05 10:52:00+03	23400.00
3BD301	2017-07-20 11:19:00+03	147700.00
3BD3C0	2017-08-13 10:17:00+03	43700.00
3BD3FD	2017-07-23 11:55:00+03	111600.00
3BD41F	2017-07-11 23:43:00+03	75300.00
3BD462	2017-08-14 13:57:00+03	32200.00
3BD4A5	2017-08-12 02:10:00+03	26000.00
3BD4C2	2017-07-18 16:05:00+03	47600.00
3BD4CE	2017-07-12 15:51:00+03	111600.00
3BD4D0	2017-06-25 02:34:00+03	26600.00
3BD4D6	2017-08-02 22:38:00+03	134400.00
3BD536	2017-07-17 23:24:00+03	111600.00
3BD53D	2017-07-14 11:16:00+03	13000.00
3BD54B	2017-08-04 23:02:00+03	45200.00
3BD5B8	2017-08-04 05:40:00+03	28800.00
3BD5BC	2017-07-01 22:02:00+03	280500.00
3BD5BD	2017-07-05 23:59:00+03	137100.00
3BD5DE	2017-07-27 13:11:00+03	492000.00
3BD621	2017-07-22 14:09:00+03	23400.00
3BD667	2017-08-13 02:34:00+03	24000.00
3BD680	2017-08-06 07:43:00+03	21800.00
3BD6CC	2017-07-19 09:39:00+03	42400.00
3BD751	2017-07-08 13:56:00+03	172600.00
3BD752	2017-08-04 18:58:00+03	22400.00
3BD788	2017-07-23 03:03:00+03	6300.00
3BD84B	2017-07-15 22:24:00+03	29600.00
3BD876	2017-07-01 04:10:00+03	67700.00
3BD92E	2017-07-25 20:43:00+03	84100.00
3BD9F4	2017-07-07 05:23:00+03	57700.00
3BDA0B	2017-07-17 01:34:00+03	112000.00
3BDA6F	2017-07-22 09:23:00+03	24400.00
3BDA74	2017-07-05 03:08:00+03	12600.00
3BDAB5	2017-07-14 02:32:00+03	55800.00
3BDAEA	2017-07-03 08:11:00+03	301300.00
3BDB82	2017-07-22 11:41:00+03	40300.00
3BDBD5	2017-08-06 17:14:00+03	157200.00
3BDBFF	2017-07-07 16:31:00+03	76100.00
3BDC3D	2017-07-20 06:27:00+03	10800.00
3BDCF7	2017-07-24 01:18:00+03	44800.00
3BDD12	2017-06-30 16:46:00+03	8400.00
3BDD24	2017-07-05 01:34:00+03	132800.00
3BDDBF	2017-07-04 02:52:00+03	43000.00
3BDE36	2017-07-09 08:59:00+03	86500.00
3BDE65	2017-07-13 19:49:00+03	55800.00
3BDE76	2017-07-22 06:25:00+03	89600.00
3BDEA9	2017-07-31 10:19:00+03	118500.00
3BDEBA	2017-08-06 06:50:00+03	135200.00
3BDEC0	2017-07-30 20:47:00+03	141700.00
3BDF4B	2017-08-10 00:14:00+03	271100.00
3BDF58	2017-07-23 08:33:00+03	24400.00
3BE03D	2017-07-05 04:45:00+03	135300.00
3BE051	2017-07-06 06:19:00+03	66600.00
3BE08B	2017-08-11 08:41:00+03	71600.00
3BE0CA	2017-07-31 13:31:00+03	23600.00
3BE128	2017-07-08 06:54:00+03	100600.00
3BE12B	2017-07-06 23:09:00+03	36100.00
3BE220	2017-08-12 07:17:00+03	28800.00
3BE237	2017-07-13 07:38:00+03	230400.00
3BE335	2017-07-27 05:13:00+03	114700.00
3BE348	2017-08-14 19:15:00+03	84000.00
3BE34B	2017-07-25 09:54:00+03	112000.00
3BE383	2017-07-20 21:19:00+03	12600.00
3BE386	2017-07-06 19:50:00+03	3700.00
3BE38A	2017-08-13 05:25:00+03	60700.00
3BE3D7	2017-08-11 13:40:00+03	6700.00
3BE3DD	2017-07-02 18:33:00+03	67800.00
3BE451	2017-07-28 09:57:00+03	25000.00
3BE4A7	2017-07-05 04:53:00+03	65000.00
3BE634	2017-07-28 08:08:00+03	72800.00
3BE639	2017-07-19 06:39:00+03	175200.00
3BE649	2017-07-28 09:55:00+03	47400.00
3BE676	2017-08-13 20:21:00+03	58200.00
3BE6C9	2017-07-15 13:09:00+03	24800.00
3BE706	2017-07-29 19:16:00+03	56000.00
3BE773	2017-07-15 06:33:00+03	50800.00
3BE794	2017-08-09 15:23:00+03	52000.00
3BE7AB	2017-07-19 12:34:00+03	40400.00
3BE7C3	2017-07-05 11:50:00+03	150600.00
3BE7C4	2017-07-19 02:44:00+03	44600.00
3BE829	2017-07-29 07:27:00+03	25600.00
3BE839	2017-07-27 04:16:00+03	21800.00
3BE862	2017-07-10 13:15:00+03	21800.00
3BE864	2017-08-04 21:31:00+03	65900.00
3BE88B	2017-08-01 15:00:00+03	28000.00
3BE8B7	2017-07-27 16:15:00+03	14400.00
3BE970	2017-07-05 07:03:00+03	68700.00
3BE9BB	2017-07-02 07:56:00+03	185000.00
3BE9D4	2017-07-10 06:13:00+03	46000.00
3BEA0D	2017-07-08 15:23:00+03	12400.00
3BEA19	2017-07-26 08:42:00+03	88400.00
3BEA60	2017-07-02 04:13:00+03	101500.00
3BEA69	2017-07-22 09:34:00+03	423300.00
3BEA75	2017-07-04 12:13:00+03	122000.00
3BEA9F	2017-07-01 04:28:00+03	58000.00
3BEAE4	2017-07-17 16:02:00+03	18000.00
3BEB10	2017-07-30 01:03:00+03	147700.00
3BEB56	2017-07-19 12:28:00+03	54800.00
3BEBB9	2017-07-10 18:44:00+03	6800.00
3BEBE3	2017-07-07 07:03:00+03	101500.00
3BEC07	2017-07-09 22:41:00+03	99600.00
3BEC08	2017-08-07 18:56:00+03	28000.00
3BECCD	2017-07-01 00:34:00+03	123000.00
3BEDA0	2017-07-01 13:16:00+03	42400.00
3BEE09	2017-07-22 22:04:00+03	28700.00
3BEE14	2017-07-21 06:07:00+03	66600.00
3BEE22	2017-08-14 14:19:00+03	26500.00
3BEE41	2017-07-06 11:21:00+03	24800.00
3BEEC0	2017-08-07 10:15:00+03	58600.00
3BEED0	2017-08-12 08:16:00+03	50800.00
3BEF08	2017-07-31 06:33:00+03	75300.00
3BEF1E	2017-08-01 15:37:00+03	83600.00
3BEF21	2017-08-09 13:36:00+03	23200.00
3BEF68	2017-06-29 04:48:00+03	26100.00
3BEF71	2017-07-23 18:56:00+03	397700.00
3BEFD0	2017-08-14 23:19:00+03	24000.00
3BF001	2017-08-03 12:20:00+03	32700.00
3BF00D	2017-08-04 13:24:00+03	28000.00
3BF048	2017-07-14 01:49:00+03	54300.00
3BF06A	2017-08-02 13:20:00+03	187600.00
3BF0CA	2017-07-17 17:51:00+03	90600.00
3BF0CD	2017-08-01 11:42:00+03	32200.00
3BF12E	2017-07-26 06:24:00+03	24200.00
3BF137	2017-07-11 06:43:00+03	135400.00
3BF13B	2017-07-06 21:31:00+03	6700.00
3BF164	2017-08-08 21:47:00+03	134900.00
3BF180	2017-08-05 01:14:00+03	46300.00
3BF193	2017-07-03 04:18:00+03	24400.00
3BF1B6	2017-07-07 08:21:00+03	35600.00
3BF23E	2017-07-28 23:53:00+03	95200.00
3BF3BE	2017-08-01 05:31:00+03	40600.00
3BF40F	2017-07-03 01:54:00+03	124200.00
3BF458	2017-07-31 04:24:00+03	73600.00
3BF474	2017-07-09 11:19:00+03	162700.00
3BF4B2	2017-07-10 11:21:00+03	39200.00
3BF4EB	2017-08-03 11:21:00+03	173600.00
3BF52F	2017-07-24 02:00:00+03	96200.00
3BF546	2017-08-06 13:20:00+03	58600.00
3BF61D	2017-08-02 01:49:00+03	114700.00
3BF644	2017-08-12 02:03:00+03	55800.00
3BF6C3	2017-07-26 16:33:00+03	70700.00
3BF6CB	2017-07-03 05:34:00+03	55800.00
3BF6F4	2017-07-17 22:18:00+03	13400.00
3BF737	2017-07-19 12:17:00+03	24400.00
3BF74C	2017-07-26 04:10:00+03	181600.00
3BF792	2017-07-14 13:59:00+03	46200.00
3BF7FC	2017-07-07 20:50:00+03	38400.00
3BF85F	2017-08-07 21:33:00+03	166000.00
3BF897	2017-07-27 12:58:00+03	19500.00
3BF8D1	2017-07-17 17:01:00+03	30200.00
3BF8DA	2017-07-25 05:02:00+03	29600.00
3BF905	2017-08-13 07:23:00+03	223200.00
3BF923	2017-08-15 14:09:00+03	32700.00
3BF92C	2017-07-30 19:40:00+03	77500.00
3BF95A	2017-07-18 01:46:00+03	11800.00
3BF97C	2017-06-29 13:16:00+03	246000.00
3BFA62	2017-07-14 19:24:00+03	283700.00
3BFA7C	2017-07-21 03:35:00+03	26000.00
3BFAB1	2017-07-26 00:38:00+03	47500.00
3BFAB3	2017-07-05 08:10:00+03	76800.00
3BFB3B	2017-07-23 05:47:00+03	38800.00
3BFBCA	2017-07-27 22:20:00+03	101000.00
3BFBF4	2017-07-13 01:14:00+03	57400.00
3BFC37	2017-08-14 18:02:00+03	28300.00
3BFD02	2017-07-15 03:30:00+03	131600.00
3BFD54	2017-07-19 00:02:00+03	156000.00
3BFDAE	2017-07-22 14:35:00+03	118400.00
3BFDB8	2017-07-15 09:04:00+03	57800.00
3BFDF9	2017-07-28 19:20:00+03	62100.00
3BFE09	2017-08-12 14:43:00+03	72600.00
3BFE22	2017-08-09 17:37:00+03	68800.00
3BFE32	2017-07-11 22:11:00+03	7400.00
3BFE3A	2017-08-04 13:50:00+03	38600.00
3BFEA9	2017-07-02 22:50:00+03	35600.00
3BFEB7	2017-07-02 10:19:00+03	19600.00
3BFF0A	2017-07-30 20:25:00+03	15000.00
3BFFD3	2017-07-16 15:06:00+03	31900.00
3BFFE3	2017-07-02 04:50:00+03	12000.00
3BFFE4	2017-07-28 07:56:00+03	246000.00
3BFFF9	2017-08-05 08:55:00+03	23600.00
3BFFFA	2017-08-06 20:22:00+03	21500.00
3C005C	2017-08-05 16:20:00+03	137600.00
3C00D3	2017-07-13 13:18:00+03	58400.00
3C00F5	2017-08-10 08:29:00+03	89700.00
3C0160	2017-08-07 14:01:00+03	63200.00
3C01B9	2017-08-05 16:54:00+03	33300.00
3C01CB	2017-07-14 04:36:00+03	23400.00
3C0240	2017-07-31 17:51:00+03	40700.00
3C0258	2017-08-10 10:14:00+03	260300.00
3C0270	2017-07-26 21:35:00+03	33000.00
3C0287	2017-07-31 03:07:00+03	26200.00
3C02A2	2017-08-14 06:05:00+03	52300.00
3C02EA	2017-07-30 09:44:00+03	96500.00
3C02FA	2017-07-09 23:11:00+03	13400.00
3C0308	2017-07-08 08:12:00+03	27900.00
3C0378	2017-07-19 18:46:00+03	44800.00
3C03B4	2017-07-08 14:24:00+03	89600.00
3C03CE	2017-08-10 07:12:00+03	20600.00
3C0458	2017-08-04 20:42:00+03	55800.00
3C0489	2017-08-01 09:30:00+03	47500.00
3C0490	2017-07-11 18:59:00+03	77600.00
3C04C1	2017-08-03 20:28:00+03	78300.00
3C04DD	2017-07-06 22:49:00+03	43000.00
3C04F6	2017-07-16 21:24:00+03	252200.00
3C050C	2017-07-10 12:42:00+03	12600.00
3C0526	2017-07-08 07:22:00+03	198800.00
3C052A	2017-07-24 12:21:00+03	14400.00
3C059C	2017-07-04 06:08:00+03	41300.00
3C05D0	2017-08-15 05:52:00+03	410500.00
3C05EE	2017-08-15 17:42:00+03	133200.00
3C064D	2017-08-06 18:42:00+03	75600.00
3C06C9	2017-07-17 09:52:00+03	167400.00
3C06E1	2017-08-11 08:16:00+03	72400.00
3C0708	2017-07-28 19:27:00+03	86300.00
3C073C	2017-07-20 11:10:00+03	52700.00
3C07A7	2017-06-30 15:07:00+03	167400.00
3C07B3	2017-07-22 18:33:00+03	46400.00
3C07C3	2017-08-06 00:49:00+03	99200.00
3C07E6	2017-08-04 16:26:00+03	23600.00
3C0839	2017-07-16 16:14:00+03	44000.00
3C0854	2017-08-11 04:02:00+03	117900.00
3C0867	2017-07-11 08:53:00+03	43000.00
3C0880	2017-07-18 04:59:00+03	87800.00
3C0887	2017-08-13 09:51:00+03	23600.00
3C0917	2017-07-26 09:16:00+03	38600.00
3C0981	2017-08-08 00:36:00+03	52100.00
3C09BC	2017-08-09 05:11:00+03	199100.00
3C0A00	2017-08-08 22:46:00+03	123000.00
3C0A1F	2017-07-28 14:08:00+03	45100.00
3C0A37	2017-07-01 07:57:00+03	174400.00
3C0A5B	2017-07-20 20:20:00+03	43200.00
3C0AEE	2017-07-11 06:59:00+03	45200.00
3C0BC9	2017-07-04 15:53:00+03	56000.00
3C0BD0	2017-08-06 04:07:00+03	30000.00
3C0BDF	2017-07-21 10:51:00+03	369000.00
3C0BEC	2017-08-03 20:51:00+03	22400.00
3C0BF7	2017-07-19 10:40:00+03	200500.00
3C0C54	2017-08-05 11:10:00+03	48800.00
3C0CD0	2017-07-10 19:56:00+03	93900.00
3C0CD3	2017-07-10 02:37:00+03	168000.00
3C0CD8	2017-07-31 12:01:00+03	156700.00
3C0CDA	2017-07-22 05:33:00+03	139200.00
3C0CE4	2017-07-30 12:07:00+03	83000.00
3C0D24	2017-08-06 21:17:00+03	34000.00
3C0E2C	2017-07-23 03:43:00+03	160200.00
3C0E31	2017-08-10 05:27:00+03	21600.00
3C0EBC	2017-08-06 01:00:00+03	40800.00
3C0EFF	2017-07-23 00:55:00+03	44000.00
3C0F38	2017-07-30 23:24:00+03	124200.00
3C0F4E	2017-07-24 20:45:00+03	75300.00
3C0F60	2017-07-19 08:20:00+03	70500.00
3C0FF2	2017-07-07 15:17:00+03	96800.00
3C1020	2017-07-06 03:07:00+03	146400.00
3C1022	2017-07-19 12:03:00+03	30200.00
3C1032	2017-07-23 19:09:00+03	283100.00
3C103D	2017-08-02 11:16:00+03	23600.00
3C1079	2017-07-06 15:47:00+03	73400.00
3C1093	2017-08-04 08:07:00+03	54800.00
3C10B8	2017-07-30 20:15:00+03	34800.00
3C1101	2017-07-08 15:59:00+03	285900.00
3C113D	2017-08-07 14:04:00+03	49800.00
3C11C9	2017-08-08 10:26:00+03	134700.00
3C11EF	2017-07-22 01:41:00+03	69500.00
3C123C	2017-07-30 18:33:00+03	28800.00
3C1264	2017-08-11 15:05:00+03	23200.00
3C127F	2017-07-16 09:31:00+03	64800.00
3C1281	2017-08-08 19:40:00+03	54000.00
3C12A3	2017-07-26 20:56:00+03	72600.00
3C12F1	2017-07-19 06:27:00+03	97200.00
3C12F2	2017-06-30 19:05:00+03	42700.00
3C1381	2017-07-13 21:20:00+03	24400.00
3C1394	2017-07-07 04:00:00+03	122300.00
3C1396	2017-08-13 19:27:00+03	42400.00
3C1398	2017-08-04 17:15:00+03	135200.00
3C13F2	2017-07-04 17:26:00+03	92800.00
3C1481	2017-08-11 11:08:00+03	48100.00
3C14DA	2017-07-13 20:04:00+03	83000.00
3C1516	2017-07-15 18:57:00+03	116000.00
3C1553	2017-07-03 19:03:00+03	99300.00
3C156E	2017-07-27 04:22:00+03	104000.00
3C15B9	2017-07-23 02:24:00+03	87000.00
3C1666	2017-07-22 16:39:00+03	25200.00
3C1672	2017-08-02 19:18:00+03	123000.00
3C167A	2017-07-07 07:02:00+03	31200.00
3C1689	2017-07-20 09:29:00+03	50600.00
3C16A2	2017-07-22 05:03:00+03	37200.00
3C16DB	2017-07-24 11:36:00+03	13400.00
3C170F	2017-08-07 13:49:00+03	13000.00
3C171B	2017-07-08 12:05:00+03	65900.00
3C1732	2017-07-07 17:06:00+03	77900.00
3C1763	2017-08-05 01:39:00+03	62800.00
3C17B4	2017-07-11 10:19:00+03	26000.00
3C17E0	2017-07-03 11:40:00+03	116700.00
3C1802	2017-07-26 01:30:00+03	38600.00
3C1808	2017-07-24 03:12:00+03	51900.00
3C1815	2017-07-02 16:32:00+03	46400.00
3C1835	2017-08-07 05:09:00+03	217600.00
3C183F	2017-07-03 13:56:00+03	24400.00
3C1877	2017-08-07 11:47:00+03	99200.00
3C188B	2017-07-07 14:23:00+03	60400.00
3C1893	2017-07-22 02:08:00+03	76400.00
3C18AE	2017-07-31 12:04:00+03	65500.00
3C1939	2017-07-30 15:17:00+03	114300.00
3C196F	2017-08-09 19:18:00+03	13400.00
3C197B	2017-07-06 15:03:00+03	40800.00
3C19A0	2017-08-09 21:23:00+03	75000.00
3C1A3F	2017-07-19 05:32:00+03	68000.00
3C1A56	2017-07-22 02:24:00+03	15400.00
3C1A89	2017-07-10 08:43:00+03	26800.00
3C1AD9	2017-07-24 13:37:00+03	79000.00
3C1BBC	2017-07-12 00:19:00+03	30200.00
3C1C16	2017-08-04 04:50:00+03	43600.00
3C1CA9	2017-08-13 12:48:00+03	115600.00
3C1D63	2017-08-09 02:49:00+03	44400.00
3C1D8D	2017-07-30 12:18:00+03	22000.00
3C1DDA	2017-07-16 04:17:00+03	85200.00
3C1F15	2017-07-29 15:44:00+03	28800.00
3C1F56	2017-07-05 11:42:00+03	18600.00
3C1F84	2017-08-09 00:33:00+03	83900.00
3C1F99	2017-07-17 17:42:00+03	20500.00
3C1FB7	2017-07-30 15:33:00+03	48400.00
3C1FDC	2017-08-13 12:25:00+03	93500.00
3C2056	2017-08-01 06:15:00+03	101800.00
3C2085	2017-07-11 15:57:00+03	89200.00
3C208E	2017-07-05 18:15:00+03	38200.00
3C209B	2017-07-22 21:03:00+03	16400.00
3C20D1	2017-07-07 22:58:00+03	73600.00
3C20E2	2017-07-05 01:05:00+03	47000.00
3C20F2	2017-07-20 06:25:00+03	97900.00
3C2109	2017-08-14 14:01:00+03	55800.00
3C214F	2017-07-04 03:58:00+03	67600.00
3C2188	2017-08-02 00:48:00+03	13000.00
3C21E2	2017-08-02 08:36:00+03	289500.00
3C2292	2017-07-20 14:34:00+03	109600.00
3C22C2	2017-07-18 00:31:00+03	56000.00
3C22DF	2017-08-01 07:01:00+03	40000.00
3C234B	2017-08-05 15:02:00+03	30100.00
3C2356	2017-08-12 01:22:00+03	54800.00
3C240A	2017-07-10 21:17:00+03	94300.00
3C240D	2017-07-14 11:38:00+03	46000.00
3C2421	2017-07-07 17:25:00+03	87000.00
3C2490	2017-07-13 11:34:00+03	46400.00
3C24E3	2017-07-17 18:14:00+03	46200.00
3C24E5	2017-07-12 06:10:00+03	29800.00
3C250C	2017-08-04 20:09:00+03	86300.00
3C2512	2017-08-02 02:20:00+03	8200.00
3C2543	2017-07-27 16:58:00+03	14000.00
3C255F	2017-07-31 22:01:00+03	64800.00
3C257C	2017-08-10 12:40:00+03	25800.00
3C25A3	2017-07-06 18:04:00+03	6700.00
3C25CF	2017-07-26 03:32:00+03	44400.00
3C25E0	2017-07-24 06:31:00+03	92000.00
3C25E4	2017-07-19 06:09:00+03	131600.00
3C26A1	2017-07-19 06:04:00+03	57600.00
3C26A2	2017-07-31 20:16:00+03	52100.00
3C27B9	2017-07-21 04:12:00+03	114800.00
3C27D3	2017-08-02 12:40:00+03	51900.00
3C281A	2017-07-08 13:19:00+03	27300.00
3C2875	2017-06-30 07:35:00+03	55800.00
3C2896	2017-08-05 15:07:00+03	19600.00
3C28AE	2017-08-10 10:35:00+03	67600.00
3C28C2	2017-07-17 19:31:00+03	100600.00
3C28CF	2017-07-09 19:06:00+03	28000.00
3C293C	2017-07-01 17:55:00+03	52300.00
3C293D	2017-07-02 08:33:00+03	28000.00
3C2956	2017-07-28 01:27:00+03	59700.00
3C2A07	2017-08-15 07:50:00+03	66000.00
3C2A28	2017-08-01 05:25:00+03	170200.00
3C2A80	2017-08-05 20:30:00+03	75300.00
3C2AA5	2017-07-23 22:30:00+03	36200.00
3C2AAD	2017-08-09 16:12:00+03	40800.00
3C2B05	2017-07-06 12:57:00+03	61500.00
3C2B0A	2017-07-20 03:19:00+03	65300.00
3C2B45	2017-08-12 03:02:00+03	31600.00
3C2B9C	2017-08-09 08:09:00+03	52000.00
3C2BC4	2017-07-24 03:58:00+03	141800.00
3C2C7E	2017-07-26 20:11:00+03	75800.00
3C2CD8	2017-07-24 08:37:00+03	266400.00
3C2CE8	2017-07-21 13:51:00+03	248400.00
3C2D05	2017-06-28 20:37:00+03	300700.00
3C2D8B	2017-07-21 03:25:00+03	149400.00
3C2DB8	2017-07-29 20:08:00+03	40800.00
3C2DB9	2017-07-12 02:15:00+03	47100.00
3C2E66	2017-08-04 18:35:00+03	62700.00
3C2EC0	2017-07-09 08:01:00+03	61400.00
3C2EC6	2017-07-01 22:47:00+03	26800.00
3C2EFF	2017-08-02 17:50:00+03	167400.00
3C2F15	2017-07-20 22:21:00+03	112600.00
3C2F2C	2017-08-14 22:19:00+03	67900.00
3C2F52	2017-07-18 06:55:00+03	103500.00
3C2F6C	2017-07-07 03:19:00+03	248400.00
3C2F8F	2017-07-20 02:37:00+03	59400.00
3C2FBA	2017-07-13 11:16:00+03	112100.00
3C2FD8	2017-08-01 06:06:00+03	20200.00
3C3043	2017-08-07 00:37:00+03	55600.00
3C3064	2017-08-14 19:08:00+03	56000.00
3C30A1	2017-08-14 01:45:00+03	13200.00
3C3101	2017-07-16 17:01:00+03	187600.00
3C3106	2017-07-03 15:49:00+03	77900.00
3C317A	2017-08-15 07:15:00+03	51600.00
3C324F	2017-07-12 08:48:00+03	23200.00
3C3272	2017-07-18 00:48:00+03	73200.00
3C32FF	2017-08-14 10:09:00+03	28000.00
3C331D	2017-08-06 16:26:00+03	10800.00
3C3377	2017-07-20 05:13:00+03	64300.00
3C337C	2017-07-18 02:24:00+03	15900.00
3C33E1	2017-08-11 04:57:00+03	87100.00
3C344D	2017-07-10 08:43:00+03	29600.00
3C3468	2017-08-15 04:15:00+03	28700.00
3C3490	2017-08-15 14:03:00+03	14000.00
3C34A3	2017-08-14 01:59:00+03	32800.00
3C34B2	2017-07-24 00:13:00+03	26000.00
3C3524	2017-07-05 02:00:00+03	26800.00
3C3583	2017-07-12 18:25:00+03	23200.00
3C3596	2017-08-15 06:12:00+03	42400.00
3C3652	2017-07-23 01:48:00+03	16400.00
3C3676	2017-07-31 13:31:00+03	43200.00
3C36A1	2017-06-29 17:43:00+03	40600.00
3C36C2	2017-07-22 15:33:00+03	51900.00
3C3737	2017-08-15 15:28:00+03	69600.00
3C374A	2017-07-18 00:23:00+03	25800.00
3C375F	2017-08-02 05:45:00+03	136200.00
3C3774	2017-07-10 20:11:00+03	25900.00
3C37DB	2017-07-28 08:19:00+03	24800.00
3C37DF	2017-08-13 11:39:00+03	56000.00
3C37E6	2017-08-03 21:18:00+03	26500.00
3C382C	2017-08-10 10:26:00+03	61800.00
3C3868	2017-07-30 12:06:00+03	88500.00
3C3883	2017-08-15 17:09:00+03	115100.00
3C3921	2017-08-11 10:04:00+03	61800.00
3C3971	2017-07-07 22:18:00+03	46800.00
3C39FB	2017-07-16 10:18:00+03	12600.00
3C3ADD	2017-07-17 06:01:00+03	36400.00
3C3AE8	2017-08-02 18:08:00+03	84100.00
3C3BDF	2017-07-04 21:18:00+03	13600.00
3C3C53	2017-07-25 22:38:00+03	6000.00
3C3C60	2017-06-30 10:47:00+03	48400.00
3C3C74	2017-07-16 05:00:00+03	84000.00
3C3C82	2017-07-16 15:07:00+03	27200.00
3C3C87	2017-08-01 08:47:00+03	93100.00
3C3C9F	2017-08-05 02:44:00+03	84500.00
3C3CAD	2017-08-11 19:46:00+03	28800.00
3C3CC5	2017-08-05 16:26:00+03	73600.00
3C3CEE	2017-07-26 01:41:00+03	100200.00
3C3D57	2017-07-30 14:39:00+03	73600.00
3C3DF2	2017-07-02 00:52:00+03	111600.00
3C3DFA	2017-07-02 06:07:00+03	88600.00
3C3E0D	2017-07-30 07:25:00+03	134200.00
3C3E97	2017-07-06 08:36:00+03	32800.00
3C3EF6	2017-07-30 00:17:00+03	62000.00
3C3F20	2017-07-31 08:41:00+03	28800.00
3C4008	2017-07-07 22:56:00+03	112000.00
3C4053	2017-08-08 12:36:00+03	86600.00
3C405C	2017-07-31 05:40:00+03	152500.00
3C40BC	2017-08-13 16:58:00+03	168700.00
3C40E6	2017-07-20 16:56:00+03	43300.00
3C40EF	2017-08-15 08:26:00+03	111600.00
3C4107	2017-07-19 03:28:00+03	16400.00
3C413B	2017-07-12 22:23:00+03	47400.00
3C4171	2017-07-17 06:32:00+03	28800.00
3C417F	2017-07-31 17:39:00+03	99900.00
3C41F2	2017-08-08 11:32:00+03	9800.00
3C421C	2017-08-11 05:55:00+03	105500.00
3C4279	2017-07-31 13:47:00+03	65900.00
3C42A1	2017-07-29 08:03:00+03	26800.00
3C42A3	2017-07-08 05:48:00+03	79400.00
3C42BF	2017-07-11 04:32:00+03	105600.00
3C42D8	2017-07-20 04:32:00+03	372500.00
3C42FE	2017-07-17 17:14:00+03	81700.00
3C43F9	2017-08-01 20:41:00+03	30200.00
3C440E	2017-08-09 04:23:00+03	66600.00
3C44F9	2017-07-15 19:44:00+03	248300.00
3C44FA	2017-08-06 15:14:00+03	51900.00
3C454C	2017-07-04 13:47:00+03	56600.00
3C45D4	2017-07-22 08:44:00+03	53300.00
3C45EC	2017-07-26 12:07:00+03	49100.00
3C4658	2017-08-05 00:20:00+03	199700.00
3C4679	2017-07-23 09:24:00+03	99300.00
3C4693	2017-07-19 00:33:00+03	137000.00
3C475E	2017-07-29 16:22:00+03	31600.00
3C47CF	2017-08-01 09:47:00+03	43200.00
3C47DB	2017-08-05 12:52:00+03	213200.00
3C4826	2017-08-07 00:26:00+03	53600.00
3C4849	2017-08-01 05:21:00+03	28800.00
3C4855	2017-07-25 08:11:00+03	21400.00
3C48A5	2017-08-03 15:49:00+03	265700.00
3C48C5	2017-08-04 22:56:00+03	260300.00
3C4938	2017-07-17 16:37:00+03	55800.00
3C4959	2017-08-06 13:02:00+03	23600.00
3C4A3B	2017-08-02 09:47:00+03	24400.00
3C4A52	2017-07-11 15:59:00+03	46400.00
3C4A61	2017-08-03 09:53:00+03	92000.00
3C4ABE	2017-07-23 20:51:00+03	121400.00
3C4B11	2017-07-27 11:08:00+03	23400.00
3C4B24	2017-07-24 01:56:00+03	20000.00
3C4B28	2017-07-11 21:21:00+03	42900.00
3C4B86	2017-07-24 11:04:00+03	28800.00
3C4B8F	2017-07-07 14:11:00+03	178800.00
3C4B9C	2017-08-14 20:30:00+03	13000.00
3C4BAF	2017-08-13 18:45:00+03	30000.00
3C4BF7	2017-08-14 17:50:00+03	272400.00
3C4C7A	2017-08-04 20:03:00+03	26000.00
3C4CBC	2017-07-09 07:18:00+03	52000.00
3C4CC8	2017-07-02 20:50:00+03	58000.00
3C4CEE	2017-07-03 13:58:00+03	50000.00
3C4D62	2017-06-30 22:55:00+03	199200.00
3C4D6A	2017-08-02 07:06:00+03	26000.00
3C4D79	2017-07-06 02:09:00+03	26800.00
3C4D90	2017-07-19 21:16:00+03	32400.00
3C4DD2	2017-07-09 10:07:00+03	167500.00
3C4DE6	2017-08-01 18:50:00+03	28800.00
3C4E64	2017-08-04 17:53:00+03	73300.00
3C4E94	2017-08-13 00:55:00+03	153200.00
3C4ED8	2017-07-05 06:53:00+03	39300.00
3C4F49	2017-07-09 10:37:00+03	21400.00
3C5011	2017-08-13 10:39:00+03	190400.00
3C501F	2017-08-01 06:54:00+03	86800.00
3C508A	2017-08-02 19:57:00+03	32700.00
3C50B3	2017-07-29 22:13:00+03	185600.00
3C5107	2017-08-08 22:39:00+03	24000.00
3C5136	2017-08-11 14:22:00+03	49100.00
3C513D	2017-07-20 05:26:00+03	92800.00
3C514A	2017-08-02 16:35:00+03	19800.00
3C5196	2017-07-26 13:44:00+03	147900.00
3C51C3	2017-07-11 11:18:00+03	86400.00
3C5225	2017-08-07 23:31:00+03	46400.00
3C5228	2017-07-13 00:51:00+03	25000.00
3C52BA	2017-07-12 21:42:00+03	54500.00
3C5399	2017-08-03 16:40:00+03	58000.00
3C53BA	2017-07-09 15:19:00+03	153200.00
3C53C3	2017-08-06 05:24:00+03	184300.00
3C53F4	2017-07-23 00:13:00+03	55500.00
3C541D	2017-07-12 03:45:00+03	21800.00
3C542D	2017-07-30 20:03:00+03	100600.00
3C5437	2017-07-07 11:15:00+03	57600.00
3C54A7	2017-08-05 21:10:00+03	7400.00
3C5589	2017-06-30 21:23:00+03	136300.00
3C55B1	2017-07-01 15:50:00+03	28000.00
3C55D3	2017-08-10 02:06:00+03	30200.00
3C5619	2017-07-26 18:16:00+03	78300.00
3C5621	2017-07-03 07:33:00+03	56000.00
3C5663	2017-07-05 17:29:00+03	265700.00
3C566E	2017-08-14 11:56:00+03	25700.00
3C5670	2017-08-02 05:59:00+03	298600.00
3C5694	2017-07-12 09:52:00+03	23200.00
3C56BC	2017-07-29 14:11:00+03	63000.00
3C56FA	2017-07-14 16:54:00+03	11600.00
3C5827	2017-07-22 06:01:00+03	398600.00
3C5844	2017-08-07 09:23:00+03	95200.00
3C58C8	2017-08-01 11:39:00+03	115800.00
3C58D1	2017-07-11 08:54:00+03	83200.00
3C591F	2017-08-05 16:11:00+03	93000.00
3C5A83	2017-08-14 06:22:00+03	31900.00
3C5AE2	2017-07-13 11:46:00+03	21800.00
3C5B6F	2017-07-24 20:49:00+03	192500.00
3C5BA7	2017-07-23 02:06:00+03	108300.00
3C5BA8	2017-07-18 12:00:00+03	36200.00
3C5BF3	2017-07-16 15:46:00+03	24700.00
3C5CAA	2017-08-04 07:34:00+03	9300.00
3C5D0B	2017-07-09 23:00:00+03	51000.00
3C5D56	2017-07-08 20:23:00+03	230000.00
3C5DEF	2017-07-15 08:00:00+03	13200.00
3C5DF9	2017-07-12 07:09:00+03	342400.00
3C5E15	2017-07-30 22:19:00+03	100900.00
3C5E63	2017-07-16 21:24:00+03	83000.00
3C5E83	2017-07-18 02:38:00+03	118200.00
3C5E91	2017-07-14 23:01:00+03	123000.00
3C5E97	2017-08-02 19:01:00+03	44000.00
3C5F15	2017-07-18 02:17:00+03	51200.00
3C5F2C	2017-07-24 01:00:00+03	49800.00
3C5F5E	2017-07-28 10:40:00+03	41200.00
3C5F6C	2017-07-24 16:11:00+03	214900.00
3C5FAD	2017-07-19 21:36:00+03	199700.00
3C5FC6	2017-08-10 07:45:00+03	195800.00
3C60AB	2017-07-03 07:52:00+03	11700.00
3C60B9	2017-07-12 18:32:00+03	52400.00
3C60BB	2017-07-30 23:34:00+03	139500.00
3C60BC	2017-08-14 11:16:00+03	90700.00
3C60C9	2017-07-17 14:19:00+03	283100.00
3C610C	2017-07-26 14:34:00+03	56000.00
3C618F	2017-07-12 13:52:00+03	28000.00
3C6195	2017-07-23 05:22:00+03	39200.00
3C619F	2017-08-03 13:17:00+03	44600.00
3C61FF	2017-07-01 17:54:00+03	61500.00
3C6211	2017-08-05 02:24:00+03	25600.00
3C622D	2017-07-14 01:26:00+03	40100.00
3C6256	2017-07-23 00:59:00+03	188600.00
3C6265	2017-08-08 09:40:00+03	265600.00
3C62B8	2017-07-03 05:35:00+03	155600.00
3C62B9	2017-08-03 08:41:00+03	132500.00
3C62CC	2017-07-21 20:41:00+03	52000.00
3C635D	2017-07-01 18:54:00+03	248300.00
3C63A2	2017-07-11 18:52:00+03	92000.00
3C63C5	2017-08-12 07:34:00+03	14000.00
3C63FD	2017-07-07 14:11:00+03	133200.00
3C64A9	2017-07-07 04:17:00+03	83000.00
3C64B3	2017-07-15 06:15:00+03	45200.00
3C64C6	2017-08-03 05:26:00+03	19600.00
3C64E7	2017-07-16 11:28:00+03	44000.00
3C6542	2017-07-12 07:33:00+03	48800.00
3C6585	2017-08-13 11:00:00+03	125100.00
3C6590	2017-07-21 21:10:00+03	223200.00
3C659C	2017-07-19 18:06:00+03	26800.00
3C65CC	2017-08-06 10:44:00+03	38600.00
3C65E9	2017-07-13 07:04:00+03	135200.00
3C667E	2017-07-03 12:36:00+03	96200.00
3C66C9	2017-08-11 02:47:00+03	32800.00
3C6713	2017-07-14 17:48:00+03	181400.00
3C6744	2017-07-19 23:50:00+03	44800.00
3C6753	2017-06-30 06:57:00+03	123000.00
3C67F6	2017-07-26 13:37:00+03	29600.00
3C67F9	2017-07-19 02:56:00+03	29600.00
3C6880	2017-08-09 16:28:00+03	55800.00
3C690B	2017-07-21 20:56:00+03	193700.00
3C690C	2017-08-14 23:39:00+03	123300.00
3C6985	2017-08-14 09:19:00+03	65900.00
3C69BD	2017-06-29 06:16:00+03	21200.00
3C69D8	2017-08-13 05:26:00+03	54000.00
3C6A12	2017-07-13 01:36:00+03	25200.00
3C6A18	2017-07-04 22:31:00+03	40000.00
3C6A5E	2017-07-31 21:42:00+03	32900.00
3C6AB5	2017-07-25 16:08:00+03	127000.00
3C6AD3	2017-07-15 08:55:00+03	202400.00
3C6AF4	2017-07-24 07:48:00+03	89700.00
3C6B11	2017-08-11 00:27:00+03	95600.00
3C6B27	2017-06-27 07:12:00+03	11600.00
3C6BFA	2017-07-24 09:26:00+03	57400.00
3C6C14	2017-08-11 07:45:00+03	147800.00
3C6C3D	2017-07-30 04:41:00+03	67600.00
3C6CA5	2017-07-28 01:52:00+03	64500.00
3C6CCE	2017-08-15 10:30:00+03	104000.00
3C6CFC	2017-07-02 00:38:00+03	68400.00
3C6D14	2017-07-06 03:26:00+03	24800.00
3C6D15	2017-08-12 00:27:00+03	118900.00
3C6D1A	2017-08-07 08:37:00+03	28000.00
3C6D23	2017-07-28 19:48:00+03	25200.00
3C6D4E	2017-07-14 10:51:00+03	258400.00
3C6D7D	2017-08-03 18:51:00+03	41200.00
3C6D7E	2017-08-06 18:49:00+03	117200.00
3C6DF0	2017-08-04 14:22:00+03	59800.00
3C6E3D	2017-08-10 19:51:00+03	40800.00
3C6E4C	2017-08-12 03:50:00+03	23200.00
3C6F2F	2017-07-05 09:00:00+03	102700.00
3C6F3A	2017-07-05 06:26:00+03	189900.00
3C7047	2017-07-04 17:39:00+03	31600.00
3C7058	2017-07-23 11:07:00+03	144400.00
3C70A2	2017-08-07 15:06:00+03	37600.00
3C70E4	2017-07-04 14:22:00+03	85000.00
3C711D	2017-07-06 16:08:00+03	32100.00
3C717B	2017-07-10 20:00:00+03	68800.00
3C71F8	2017-07-28 08:48:00+03	166100.00
3C71FC	2017-08-05 16:15:00+03	132800.00
3C720B	2017-06-26 11:45:00+03	111700.00
3C72DA	2017-07-20 15:51:00+03	73300.00
3C72F8	2017-07-29 19:07:00+03	56800.00
3C7337	2017-07-30 10:19:00+03	14400.00
3C7352	2017-08-02 06:33:00+03	28800.00
3C7380	2017-08-07 12:32:00+03	36700.00
3C738C	2017-08-04 04:35:00+03	135000.00
3C7420	2017-08-13 22:59:00+03	31100.00
3C7443	2017-07-21 21:59:00+03	62800.00
3C74C4	2017-07-10 20:18:00+03	88100.00
3C74FA	2017-08-08 19:10:00+03	28700.00
3C7505	2017-08-11 17:14:00+03	28000.00
3C7517	2017-07-13 19:01:00+03	189200.00
3C751F	2017-07-29 09:30:00+03	162600.00
3C752A	2017-07-05 14:07:00+03	68000.00
3C75B4	2017-06-30 10:50:00+03	135600.00
3C75D6	2017-06-29 09:16:00+03	96800.00
3C7605	2017-08-14 23:22:00+03	40400.00
3C76BD	2017-07-13 04:53:00+03	67200.00
3C76C3	2017-07-26 17:37:00+03	195800.00
3C7708	2017-08-11 09:56:00+03	40600.00
3C775F	2017-08-08 08:32:00+03	109200.00
3C779C	2017-07-04 10:52:00+03	65800.00
3C77D5	2017-07-23 05:24:00+03	6000.00
3C7898	2017-08-06 02:39:00+03	31600.00
3C7963	2017-07-30 19:34:00+03	117600.00
3C7976	2017-08-12 15:01:00+03	99200.00
3C797B	2017-06-28 23:33:00+03	69500.00
3C7998	2017-08-08 06:10:00+03	137800.00
3C79B3	2017-08-10 13:19:00+03	70400.00
3C7A4C	2017-08-09 09:49:00+03	165500.00
3C7A5C	2017-06-30 21:39:00+03	37500.00
3C7A6A	2017-07-15 23:47:00+03	28800.00
3C7AC0	2017-08-14 07:36:00+03	8000.00
3C7B2D	2017-08-01 00:02:00+03	56000.00
3C7B31	2017-08-15 17:00:00+03	6000.00
3C7B6A	2017-07-22 01:19:00+03	21200.00
3C7BC9	2017-07-07 09:09:00+03	16400.00
3C7C57	2017-08-07 00:25:00+03	6400.00
3C7CA2	2017-08-09 07:35:00+03	83400.00
3C7CE2	2017-07-31 08:17:00+03	40000.00
3C7D41	2017-07-23 20:50:00+03	7200.00
3C7D51	2017-07-18 15:38:00+03	10800.00
3C7DDB	2017-07-17 12:19:00+03	26000.00
3C7DDC	2017-07-20 16:33:00+03	92900.00
3C7DE0	2017-07-31 12:33:00+03	99200.00
3C7E01	2017-07-16 05:15:00+03	20500.00
3C7EC1	2017-07-17 09:45:00+03	22000.00
3C7F04	2017-07-27 10:23:00+03	102800.00
3C7F8D	2017-08-05 21:14:00+03	56000.00
3C801F	2017-07-11 13:39:00+03	112000.00
3C8045	2017-07-05 13:19:00+03	100600.00
3C804F	2017-08-01 19:52:00+03	112200.00
3C809A	2017-08-07 09:30:00+03	90000.00
3C80C6	2017-08-10 21:46:00+03	87200.00
3C810A	2017-06-28 05:45:00+03	76600.00
3C8121	2017-08-14 11:13:00+03	99200.00
3C8157	2017-08-07 10:18:00+03	34000.00
3C816E	2017-08-14 11:04:00+03	32800.00
3C8193	2017-07-08 23:35:00+03	30000.00
3C81AE	2017-08-03 13:33:00+03	100000.00
3C823D	2017-07-21 06:16:00+03	74300.00
3C8274	2017-08-13 01:05:00+03	31600.00
3C827F	2017-07-05 20:42:00+03	16400.00
3C828F	2017-08-08 21:27:00+03	21400.00
3C82A5	2017-07-10 12:13:00+03	142400.00
3C82D0	2017-07-14 07:28:00+03	40600.00
3C8366	2017-07-31 04:09:00+03	73000.00
3C8398	2017-08-13 09:03:00+03	170000.00
3C839F	2017-08-14 01:31:00+03	89600.00
3C83EF	2017-08-01 21:33:00+03	72400.00
3C83FE	2017-08-11 17:56:00+03	188000.00
3C8465	2017-08-09 01:47:00+03	118000.00
3C8479	2017-07-23 09:28:00+03	84200.00
3C84CB	2017-07-28 15:35:00+03	271200.00
3C84EC	2017-07-16 18:29:00+03	23200.00
3C84F7	2017-08-06 17:04:00+03	15400.00
3C851E	2017-07-13 11:35:00+03	37200.00
3C8522	2017-08-15 13:26:00+03	32400.00
3C8567	2017-08-12 13:24:00+03	45400.00
3C8572	2017-07-17 01:16:00+03	52000.00
3C85DE	2017-08-10 16:11:00+03	28000.00
3C85F1	2017-08-02 14:54:00+03	44700.00
3C860F	2017-07-16 23:49:00+03	57500.00
3C8641	2017-07-11 18:57:00+03	75600.00
3C86C4	2017-07-07 06:26:00+03	32300.00
3C86CD	2017-07-28 10:44:00+03	105200.00
3C86CF	2017-07-17 09:46:00+03	95600.00
3C875B	2017-07-09 03:21:00+03	135600.00
3C8836	2017-08-13 11:39:00+03	57600.00
3C8894	2017-08-08 12:32:00+03	26800.00
3C88A4	2017-08-01 10:23:00+03	46900.00
3C88E6	2017-08-14 09:20:00+03	42600.00
3C8902	2017-08-07 00:13:00+03	53600.00
3C891B	2017-08-07 13:51:00+03	31200.00
3C89A9	2017-07-06 07:31:00+03	23200.00
3C89DB	2017-07-08 08:18:00+03	7300.00
3C89E2	2017-08-12 08:19:00+03	67400.00
3C8A92	2017-06-30 16:55:00+03	24400.00
3C8AD4	2017-08-06 17:44:00+03	52700.00
3C8B2D	2017-08-01 16:20:00+03	57600.00
3C8B3A	2017-08-10 07:11:00+03	28800.00
3C8B3B	2017-08-12 05:08:00+03	118800.00
3C8B46	2017-07-12 11:09:00+03	38800.00
3C8B80	2017-07-21 07:05:00+03	19600.00
3C8CDB	2017-07-12 19:22:00+03	46200.00
3C8D19	2017-07-13 15:35:00+03	96200.00
3C8D48	2017-06-30 11:45:00+03	28800.00
3C8D50	2017-08-06 16:11:00+03	56000.00
3C8D58	2017-07-06 04:19:00+03	286100.00
3C8D61	2017-07-08 04:22:00+03	27900.00
3C8D85	2017-07-30 10:47:00+03	29200.00
3C8DA1	2017-07-11 09:10:00+03	100000.00
3C8E84	2017-07-12 19:30:00+03	25800.00
3C8EA1	2017-07-21 16:06:00+03	112200.00
3C8EDA	2017-07-11 21:26:00+03	28800.00
3C8EE2	2017-07-19 21:02:00+03	94000.00
3C8F43	2017-07-15 22:42:00+03	532800.00
3C8F64	2017-08-13 16:17:00+03	23200.00
3C8F77	2017-07-03 05:55:00+03	88800.00
3C8F91	2017-07-13 15:49:00+03	97900.00
3C9072	2017-08-13 23:40:00+03	25900.00
3C9095	2017-07-03 00:47:00+03	28900.00
3C90B1	2017-08-02 08:06:00+03	68800.00
3C9104	2017-08-05 05:36:00+03	82900.00
3C9160	2017-07-16 08:18:00+03	48300.00
3C9193	2017-08-15 12:28:00+03	542300.00
3C9206	2017-07-31 13:26:00+03	306200.00
3C92B9	2017-07-09 17:12:00+03	123000.00
3C92C6	2017-08-03 16:20:00+03	56100.00
3C930F	2017-07-20 23:34:00+03	248500.00
3C9321	2017-07-19 04:27:00+03	112000.00
3C9322	2017-07-31 22:04:00+03	23900.00
3C9333	2017-08-01 13:59:00+03	40300.00
3C938D	2017-07-22 16:33:00+03	48500.00
3C939D	2017-07-11 00:16:00+03	56100.00
3C93F2	2017-07-07 22:21:00+03	26500.00
3C9405	2017-07-02 17:23:00+03	51600.00
3C9463	2017-07-03 17:43:00+03	102100.00
3C94C7	2017-07-17 07:51:00+03	23600.00
3C94F1	2017-07-05 01:46:00+03	111700.00
3C950D	2017-08-03 01:21:00+03	104400.00
3C9596	2017-07-03 14:15:00+03	16000.00
3C9632	2017-07-29 13:59:00+03	23400.00
3C9649	2017-07-14 05:49:00+03	119800.00
3C964D	2017-07-25 11:52:00+03	56100.00
3C9712	2017-07-03 17:22:00+03	7400.00
3C9773	2017-07-15 09:39:00+03	86400.00
3C9811	2017-07-11 16:33:00+03	59400.00
3C9827	2017-07-25 10:27:00+03	39200.00
3C98A2	2017-07-11 17:21:00+03	13700.00
3C98CA	2017-08-11 06:02:00+03	27200.00
3C990D	2017-08-12 19:25:00+03	56900.00
3C995A	2017-07-18 23:55:00+03	17000.00
3C9973	2017-07-03 09:48:00+03	37900.00
3C9990	2017-07-01 15:03:00+03	60400.00
3C999F	2017-07-07 05:24:00+03	56000.00
3C99F6	2017-07-20 20:23:00+03	61800.00
3C9A07	2017-06-30 13:39:00+03	28800.00
3C9B5B	2017-07-18 17:35:00+03	50400.00
3C9BC0	2017-08-11 06:43:00+03	263200.00
3C9BF5	2017-07-21 13:29:00+03	26000.00
3C9C60	2017-08-07 12:30:00+03	33100.00
3C9C7B	2017-08-08 08:58:00+03	114500.00
3C9CD4	2017-07-03 11:36:00+03	73600.00
3C9CFC	2017-07-12 17:04:00+03	14800.00
3C9D1B	2017-07-05 03:18:00+03	67900.00
3C9D3E	2017-07-16 09:17:00+03	92100.00
3C9D74	2017-07-10 16:06:00+03	84900.00
3C9DBD	2017-07-05 00:59:00+03	44800.00
3C9DD3	2017-07-12 08:53:00+03	46300.00
3C9DE8	2017-08-14 15:12:00+03	21800.00
3C9E29	2017-08-01 19:22:00+03	99500.00
3C9E9B	2017-07-26 18:59:00+03	29600.00
3C9E9C	2017-08-07 17:54:00+03	65000.00
3C9EB2	2017-07-02 20:51:00+03	53200.00
3C9EC1	2017-07-22 17:16:00+03	136800.00
3C9EC6	2017-08-04 09:15:00+03	244200.00
3C9F33	2017-07-16 14:31:00+03	70700.00
3CA0CD	2017-07-28 19:02:00+03	103500.00
3CA0D4	2017-07-10 02:38:00+03	26200.00
3CA106	2017-08-02 13:11:00+03	99300.00
3CA173	2017-07-15 12:32:00+03	77000.00
3CA1D6	2017-08-08 10:32:00+03	100600.00
3CA1FC	2017-07-09 07:58:00+03	45400.00
3CA20B	2017-07-23 17:43:00+03	36000.00
3CA29A	2017-07-11 01:34:00+03	173600.00
3CA2AD	2017-07-04 23:05:00+03	49200.00
3CA305	2017-08-13 14:54:00+03	26000.00
3CA311	2017-07-03 05:50:00+03	56100.00
3CA31B	2017-07-02 22:18:00+03	14700.00
3CA346	2017-07-12 20:19:00+03	57400.00
3CA366	2017-07-14 18:12:00+03	42800.00
3CA3AA	2017-07-05 02:21:00+03	69700.00
3CA3BD	2017-08-15 12:03:00+03	43200.00
3CA426	2017-07-17 06:07:00+03	65900.00
3CA49B	2017-07-15 01:50:00+03	136000.00
3CA4AE	2017-06-28 10:39:00+03	40000.00
3CA4EA	2017-07-11 11:12:00+03	134400.00
3CA515	2017-07-17 21:51:00+03	61500.00
3CA545	2017-07-09 05:20:00+03	133100.00
3CA5C4	2017-07-08 03:04:00+03	109600.00
3CA5ED	2017-08-06 12:28:00+03	42400.00
3CA64F	2017-07-16 09:04:00+03	40800.00
3CA669	2017-08-02 12:32:00+03	67400.00
3CA69B	2017-08-07 01:26:00+03	102500.00
3CA6DA	2017-07-12 05:09:00+03	22000.00
3CA746	2017-08-04 23:12:00+03	21800.00
3CA787	2017-08-05 14:17:00+03	6700.00
3CA795	2017-07-23 04:57:00+03	6300.00
3CA838	2017-07-09 22:58:00+03	246000.00
3CA84E	2017-07-04 17:28:00+03	34000.00
3CA8CC	2017-07-04 01:58:00+03	33100.00
3CA8D5	2017-07-09 00:59:00+03	16400.00
3CA908	2017-07-07 09:22:00+03	100600.00
3CA915	2017-07-30 19:35:00+03	289800.00
3CA927	2017-07-19 14:55:00+03	26800.00
3CA968	2017-08-02 22:21:00+03	148200.00
3CA98F	2017-07-13 17:01:00+03	46400.00
3CA9B9	2017-08-14 23:53:00+03	136200.00
3CA9CD	2017-08-10 12:15:00+03	34000.00
3CAA12	2017-07-22 23:46:00+03	37300.00
3CAA1B	2017-08-07 11:57:00+03	4100.00
3CAA42	2017-07-12 23:49:00+03	37200.00
3CAA57	2017-07-15 05:02:00+03	99500.00
3CAA5C	2017-08-08 11:51:00+03	106400.00
3CAA69	2017-08-03 00:24:00+03	54800.00
3CAA77	2017-08-10 11:13:00+03	23200.00
3CAAA4	2017-08-12 12:46:00+03	21800.00
3CAAB3	2017-07-08 01:56:00+03	12400.00
3CAAF1	2017-07-30 15:25:00+03	113200.00
3CAB50	2017-07-28 04:01:00+03	66000.00
3CAB84	2017-07-15 09:57:00+03	94900.00
3CAB9E	2017-07-05 05:59:00+03	95600.00
3CAC4E	2017-07-26 10:31:00+03	19800.00
3CACA6	2017-07-16 08:08:00+03	30700.00
3CACB0	2017-07-12 08:13:00+03	49200.00
3CACE3	2017-08-07 06:57:00+03	34200.00
3CAD2A	2017-07-05 00:25:00+03	16400.00
3CAD8D	2017-07-08 15:41:00+03	399600.00
3CADD7	2017-08-06 06:11:00+03	55300.00
3CAE2A	2017-07-09 09:50:00+03	30000.00
3CAE4B	2017-08-13 23:53:00+03	95600.00
3CAE94	2017-08-02 03:19:00+03	81200.00
3CAEE9	2017-07-16 01:20:00+03	31600.00
3CAFFD	2017-07-08 17:34:00+03	12400.00
3CB021	2017-08-06 18:52:00+03	97600.00
3CB053	2017-07-15 10:38:00+03	103200.00
3CB054	2017-07-08 22:00:00+03	46300.00
3CB0AA	2017-07-03 18:37:00+03	76100.00
3CB0F1	2017-08-08 01:03:00+03	64700.00
3CB1CA	2017-07-05 22:33:00+03	28000.00
3CB240	2017-07-27 02:50:00+03	6700.00
3CB298	2017-07-07 06:30:00+03	31600.00
3CB29C	2017-07-26 10:15:00+03	27200.00
3CB2EE	2017-07-20 04:26:00+03	82900.00
3CB393	2017-07-22 04:41:00+03	89700.00
3CB40C	2017-06-30 18:20:00+03	172100.00
3CB430	2017-07-07 09:35:00+03	52000.00
3CB470	2017-08-13 18:28:00+03	56900.00
3CB4BA	2017-07-13 15:23:00+03	85700.00
3CB540	2017-07-27 16:23:00+03	15800.00
3CB5D4	2017-08-12 17:19:00+03	37200.00
3CB641	2017-07-15 12:53:00+03	11600.00
3CB673	2017-07-05 07:44:00+03	153300.00
3CB681	2017-07-10 13:27:00+03	56000.00
3CB68B	2017-07-31 06:46:00+03	6700.00
3CB696	2017-08-05 08:53:00+03	24000.00
3CB701	2017-06-27 05:23:00+03	48800.00
3CB72D	2017-08-01 13:48:00+03	21800.00
3CB732	2017-07-01 10:45:00+03	23200.00
3CB788	2017-08-01 00:53:00+03	8000.00
3CB7BB	2017-07-07 21:44:00+03	136800.00
3CB7CD	2017-08-10 21:02:00+03	52000.00
3CB840	2017-08-07 11:12:00+03	28800.00
3CB85C	2017-08-12 11:29:00+03	78000.00
3CB8A1	2017-07-21 09:23:00+03	87100.00
3CB8CB	2017-07-07 22:09:00+03	42400.00
3CB900	2017-07-06 19:05:00+03	22000.00
3CB918	2017-08-03 10:21:00+03	66600.00
3CB950	2017-08-11 14:15:00+03	191200.00
3CB960	2017-07-09 04:50:00+03	42800.00
3CB980	2017-07-13 18:52:00+03	135000.00
3CB98D	2017-07-03 16:58:00+03	38400.00
3CB9AC	2017-07-20 04:52:00+03	113200.00
3CB9E1	2017-07-04 14:32:00+03	67800.00
3CBA5A	2017-07-21 05:07:00+03	165100.00
3CBAC4	2017-07-03 14:53:00+03	21200.00
3CBB1F	2017-08-12 10:01:00+03	57300.00
3CBB44	2017-08-14 07:01:00+03	27200.00
3CBB5B	2017-08-14 20:28:00+03	31400.00
3CBBEF	2017-08-08 18:41:00+03	94800.00
3CBC7A	2017-08-09 01:54:00+03	44000.00
3CBC87	2017-06-29 08:54:00+03	56000.00
3CBD4F	2017-07-26 16:34:00+03	70600.00
3CBD85	2017-07-01 03:49:00+03	92000.00
3CBDBA	2017-06-28 09:25:00+03	25400.00
3CBE23	2017-08-03 03:16:00+03	20000.00
3CBE3C	2017-07-26 11:32:00+03	265600.00
3CBE77	2017-07-17 03:40:00+03	15000.00
3CBED9	2017-07-12 04:42:00+03	119500.00
3CBF17	2017-07-12 10:19:00+03	68400.00
3CBF2B	2017-08-01 11:48:00+03	58600.00
3CBF63	2017-07-23 07:16:00+03	179500.00
3CBF6F	2017-07-05 04:41:00+03	50600.00
3CBF8A	2017-06-30 18:17:00+03	39200.00
3CBFD2	2017-08-14 01:36:00+03	189200.00
3CBFE3	2017-08-14 18:00:00+03	94700.00
3CC05F	2017-07-09 13:02:00+03	83000.00
3CC087	2017-07-13 21:36:00+03	65600.00
3CC153	2017-07-13 05:21:00+03	61800.00
3CC1A9	2017-07-30 20:00:00+03	246000.00
3CC1C4	2017-08-11 19:41:00+03	98400.00
3CC1CA	2017-07-31 01:05:00+03	47200.00
3CC1FA	2017-07-27 23:29:00+03	17200.00
3CC220	2017-08-12 07:37:00+03	52400.00
3CC27F	2017-08-13 21:01:00+03	36700.00
3CC2BD	2017-07-13 15:52:00+03	57800.00
3CC2E7	2017-07-05 05:53:00+03	28000.00
3CC367	2017-07-07 21:08:00+03	131600.00
3CC3A5	2017-08-13 13:07:00+03	23600.00
3CC3D3	2017-07-06 02:17:00+03	34000.00
3CC3EC	2017-08-10 11:57:00+03	64400.00
3CC3F4	2017-07-12 05:51:00+03	25600.00
3CC447	2017-08-15 11:21:00+03	124200.00
3CC47C	2017-08-07 13:22:00+03	93100.00
3CC49B	2017-07-20 14:36:00+03	71800.00
3CC4B0	2017-08-13 01:47:00+03	147700.00
3CC4B2	2017-07-18 06:59:00+03	99300.00
3CC4E0	2017-08-14 03:58:00+03	126300.00
3CC50F	2017-08-13 19:46:00+03	166100.00
3CC51E	2017-07-15 13:50:00+03	27900.00
3CC581	2017-07-18 11:15:00+03	56000.00
3CC5D0	2017-08-05 20:02:00+03	23600.00
3CC5E0	2017-07-19 15:06:00+03	387400.00
3CC5F2	2017-07-20 02:04:00+03	65800.00
3CC65C	2017-07-25 01:54:00+03	49100.00
3CC67D	2017-07-19 21:10:00+03	360900.00
3CC67E	2017-07-05 07:22:00+03	12600.00
3CC68B	2017-07-03 15:55:00+03	38800.00
3CC69F	2017-07-31 01:23:00+03	23200.00
3CC6B8	2017-07-10 11:49:00+03	124200.00
3CC6B9	2017-07-22 15:53:00+03	26800.00
3CC6FA	2017-07-01 13:17:00+03	28800.00
3CC6FB	2017-07-06 01:00:00+03	67100.00
3CC725	2017-07-25 09:24:00+03	14000.00
3CC731	2017-08-15 16:37:00+03	22900.00
3CC770	2017-07-03 15:20:00+03	21800.00
3CC79F	2017-08-09 19:40:00+03	174400.00
3CC7AF	2017-07-10 07:09:00+03	42600.00
3CC7FE	2017-07-25 03:22:00+03	20200.00
3CC824	2017-07-23 04:26:00+03	32200.00
3CC86B	2017-07-09 23:31:00+03	134700.00
3CC886	2017-07-17 09:59:00+03	130400.00
3CC8A0	2017-07-25 23:08:00+03	393800.00
3CC8E0	2017-08-04 09:16:00+03	26200.00
3CC982	2017-07-12 06:24:00+03	40800.00
3CC985	2017-06-30 08:31:00+03	13400.00
3CC989	2017-08-04 15:28:00+03	56000.00
3CC99C	2017-07-14 16:26:00+03	53700.00
3CC9C2	2017-07-22 14:22:00+03	43700.00
3CCA0B	2017-07-20 04:40:00+03	46000.00
3CCA0F	2017-07-20 17:50:00+03	85000.00
3CCA14	2017-08-11 22:33:00+03	14000.00
3CCA1B	2017-07-09 09:37:00+03	48700.00
3CCA1F	2017-08-09 01:42:00+03	52400.00
3CCADE	2017-07-09 06:30:00+03	19600.00
3CCAE1	2017-07-31 05:29:00+03	66400.00
3CCB2D	2017-07-28 04:04:00+03	101200.00
3CCB4C	2017-07-30 22:24:00+03	72400.00
3CCB71	2017-07-12 12:01:00+03	139800.00
3CCB9C	2017-07-22 07:52:00+03	153000.00
3CCBAA	2017-08-12 05:28:00+03	56000.00
3CCBD4	2017-08-13 18:47:00+03	43000.00
3CCBDE	2017-07-15 11:54:00+03	21800.00
3CCC3F	2017-08-09 00:27:00+03	27200.00
3CCCC8	2017-07-27 15:09:00+03	54000.00
3CCD12	2017-07-02 23:46:00+03	64800.00
3CCD6A	2017-08-10 06:12:00+03	25200.00
3CCD76	2017-08-06 06:03:00+03	87800.00
3CCD86	2017-07-18 04:08:00+03	51900.00
3CCDDA	2017-07-06 16:44:00+03	54800.00
3CCDF8	2017-08-10 18:03:00+03	28000.00
3CCDFF	2017-08-15 07:15:00+03	29600.00
3CCE24	2017-07-07 23:33:00+03	100300.00
3CCE38	2017-08-07 20:32:00+03	14800.00
3CCE3F	2017-07-28 18:37:00+03	27200.00
3CCE52	2017-06-29 10:46:00+03	25600.00
3CCF21	2017-07-18 08:03:00+03	288600.00
3CCF2F	2017-07-31 09:45:00+03	65900.00
3CCF56	2017-07-03 03:09:00+03	13400.00
3CCF5E	2017-07-18 05:18:00+03	290500.00
3CCF67	2017-07-01 06:11:00+03	76900.00
3CCF79	2017-07-04 04:52:00+03	36800.00
3CCF95	2017-07-19 06:31:00+03	88100.00
3CCF9D	2017-08-07 15:39:00+03	87700.00
3CCFD6	2017-08-09 01:36:00+03	270800.00
3CCFFF	2017-08-12 09:49:00+03	156500.00
3CD018	2017-07-18 00:50:00+03	72800.00
3CD02F	2017-06-29 22:58:00+03	117200.00
3CD04B	2017-07-07 11:58:00+03	96200.00
3CD07B	2017-07-23 23:31:00+03	61800.00
3CD0B2	2017-07-12 16:13:00+03	92400.00
3CD0C1	2017-07-29 19:50:00+03	26800.00
3CD0DC	2017-07-24 19:47:00+03	198400.00
3CD0E2	2017-07-10 23:27:00+03	112600.00
3CD0F3	2017-07-07 10:16:00+03	28000.00
3CD15A	2017-07-29 09:22:00+03	48200.00
3CD1BF	2017-08-12 08:03:00+03	13600.00
3CD1CC	2017-07-15 11:02:00+03	79800.00
3CD245	2017-07-31 03:30:00+03	92600.00
3CD2C2	2017-07-29 21:33:00+03	10100.00
3CD2C7	2017-07-23 00:27:00+03	116000.00
3CD329	2017-07-01 05:38:00+03	55800.00
3CD348	2017-07-02 19:03:00+03	120400.00
3CD3A2	2017-08-11 08:09:00+03	38600.00
3CD3B0	2017-08-14 13:07:00+03	51900.00
3CD3F0	2017-07-19 18:22:00+03	44800.00
3CD43B	2017-07-27 01:47:00+03	46300.00
3CD4B2	2017-07-23 23:06:00+03	80200.00
3CD4EE	2017-08-14 13:04:00+03	23100.00
3CD560	2017-08-13 14:04:00+03	27200.00
3CD586	2017-06-24 15:03:00+03	28800.00
3CD5C5	2017-08-14 17:13:00+03	47400.00
3CD630	2017-07-18 13:24:00+03	24400.00
3CD652	2017-07-27 05:11:00+03	8000.00
3CD654	2017-07-10 13:02:00+03	142400.00
3CD67D	2017-08-08 07:39:00+03	252200.00
3CD689	2017-06-26 20:14:00+03	45100.00
3CD6FF	2017-07-30 05:05:00+03	45400.00
3CD727	2017-07-09 23:00:00+03	260300.00
3CD739	2017-07-07 04:30:00+03	25600.00
3CD75E	2017-07-02 05:24:00+03	95100.00
3CD7D6	2017-08-02 21:06:00+03	52000.00
3CD7F3	2017-07-18 20:45:00+03	97800.00
3CD8E8	2017-07-22 01:09:00+03	56600.00
3CD8F8	2017-08-08 10:17:00+03	266400.00
3CD940	2017-08-08 14:06:00+03	52100.00
3CDA2F	2017-07-30 01:57:00+03	73500.00
3CDA4C	2017-07-28 01:26:00+03	21800.00
3CDAA3	2017-08-13 08:17:00+03	56000.00
3CDAE5	2017-07-31 11:40:00+03	52300.00
3CDB22	2017-07-22 09:50:00+03	70900.00
3CDB36	2017-07-21 00:38:00+03	148200.00
3CDB95	2017-07-15 03:59:00+03	23400.00
3CDBA4	2017-07-23 05:38:00+03	16800.00
3CDC7A	2017-07-08 08:14:00+03	58800.00
3CDCB5	2017-08-04 05:41:00+03	133200.00
3CDCD5	2017-07-21 14:00:00+03	86300.00
3CDD39	2017-07-07 08:13:00+03	73200.00
3CDD49	2017-08-13 03:37:00+03	24300.00
3CDD76	2017-08-06 03:04:00+03	61800.00
3CDDB5	2017-08-08 19:32:00+03	12600.00
3CDDF2	2017-07-19 18:13:00+03	86500.00
3CDE18	2017-07-11 21:12:00+03	23200.00
3CDE27	2017-07-29 07:30:00+03	6700.00
3CDE65	2017-08-04 11:20:00+03	73100.00
3CDE94	2017-07-14 14:48:00+03	112600.00
3CDECC	2017-08-05 20:25:00+03	213400.00
3CDEF6	2017-08-07 06:58:00+03	48800.00
3CDF29	2017-08-15 07:30:00+03	102300.00
3CDF9A	2017-07-06 02:30:00+03	67700.00
3CDF9F	2017-07-28 08:16:00+03	68800.00
3CE00A	2017-08-03 06:21:00+03	56100.00
3CE033	2017-07-07 00:54:00+03	89700.00
3CE06B	2017-07-01 11:33:00+03	104800.00
3CE090	2017-07-20 14:30:00+03	19600.00
3CE096	2017-07-23 19:54:00+03	91100.00
3CE097	2017-07-14 05:21:00+03	66600.00
3CE0D0	2017-08-03 22:02:00+03	27000.00
3CE1A5	2017-07-13 05:54:00+03	300700.00
3CE20E	2017-07-31 13:12:00+03	12600.00
3CE257	2017-07-11 16:18:00+03	26000.00
3CE25B	2017-07-26 04:39:00+03	27200.00
3CE2AF	2017-07-10 17:47:00+03	106400.00
3CE2B5	2017-07-28 02:47:00+03	20200.00
3CE2F8	2017-07-03 01:24:00+03	24800.00
3CE3A8	2017-07-19 07:42:00+03	44100.00
3CE3AD	2017-07-14 13:56:00+03	57600.00
3CE438	2017-07-28 01:50:00+03	96800.00
3CE44B	2017-07-31 12:02:00+03	25400.00
3CE4D0	2017-08-14 18:33:00+03	30800.00
3CE594	2017-07-20 03:46:00+03	34400.00
3CE5B2	2017-08-13 14:37:00+03	189200.00
3CE5E7	2017-08-02 15:13:00+03	44800.00
3CE618	2017-08-03 02:44:00+03	57400.00
3CE651	2017-07-20 13:24:00+03	99200.00
3CE679	2017-08-09 20:34:00+03	85000.00
3CE67E	2017-07-28 11:45:00+03	107700.00
3CE6F2	2017-08-07 04:24:00+03	28300.00
3CE741	2017-08-07 09:13:00+03	99200.00
3CE7FB	2017-07-18 01:53:00+03	43200.00
3CE822	2017-07-02 09:58:00+03	85200.00
3CE885	2017-07-25 06:31:00+03	30900.00
3CE892	2017-08-09 11:46:00+03	39900.00
3CE8AC	2017-07-25 03:38:00+03	62800.00
3CE8F7	2017-08-15 17:14:00+03	6800.00
3CE906	2017-07-06 01:57:00+03	28300.00
3CE90D	2017-07-13 09:58:00+03	23600.00
3CE91A	2017-06-28 07:18:00+03	398500.00
3CE930	2017-07-16 01:53:00+03	51900.00
3CE99C	2017-07-26 15:11:00+03	142400.00
3CE9A3	2017-08-01 13:23:00+03	7800.00
3CE9C8	2017-08-14 02:35:00+03	160000.00
3CEA0E	2017-08-11 21:04:00+03	64800.00
3CEA2A	2017-08-02 23:56:00+03	67900.00
3CEB3E	2017-07-13 00:32:00+03	47800.00
3CEB84	2017-07-18 23:37:00+03	28800.00
3CEC10	2017-07-30 11:11:00+03	37900.00
3CEC2F	2017-07-21 21:20:00+03	100600.00
3CECE6	2017-08-12 13:16:00+03	86600.00
3CECEA	2017-08-10 06:40:00+03	47200.00
3CED9A	2017-07-24 19:05:00+03	83700.00
3CED9F	2017-08-15 13:04:00+03	14800.00
3CEDEE	2017-07-27 03:32:00+03	56000.00
3CEE4A	2017-08-15 05:44:00+03	43600.00
3CEE68	2017-08-07 14:53:00+03	233700.00
3CEE72	2017-07-19 23:38:00+03	120900.00
3CEE8A	2017-08-14 16:11:00+03	6600.00
3CEEAF	2017-08-08 00:50:00+03	58100.00
3CEF0F	2017-08-10 10:27:00+03	6600.00
3CEF3E	2017-07-07 00:40:00+03	266400.00
3CEF44	2017-08-12 09:10:00+03	107500.00
3CEF9E	2017-08-09 08:24:00+03	12400.00
3CEFCB	2017-07-11 03:08:00+03	39300.00
3CF091	2017-08-06 15:43:00+03	93800.00
3CF093	2017-07-16 01:16:00+03	8400.00
3CF0F2	2017-08-13 07:10:00+03	51900.00
3CF122	2017-08-11 21:25:00+03	38500.00
3CF141	2017-07-12 15:36:00+03	59000.00
3CF161	2017-07-11 07:53:00+03	38200.00
3CF16A	2017-08-04 12:40:00+03	20000.00
3CF1AC	2017-07-10 18:52:00+03	26600.00
3CF25E	2017-08-11 12:08:00+03	124100.00
3CF32D	2017-07-23 19:42:00+03	51300.00
3CF33E	2017-08-05 15:00:00+03	169300.00
3CF369	2017-07-20 13:32:00+03	76800.00
3CF408	2017-08-01 05:21:00+03	30800.00
3CF441	2017-07-19 01:47:00+03	56100.00
3CF47B	2017-07-14 11:27:00+03	6000.00
3CF49D	2017-07-16 18:28:00+03	61800.00
3CF4A8	2017-08-08 00:35:00+03	405200.00
3CF4E5	2017-07-04 12:16:00+03	69600.00
3CF522	2017-07-15 05:35:00+03	85700.00
3CF575	2017-07-10 17:40:00+03	36200.00
3CF5CC	2017-08-15 17:05:00+03	26700.00
3CF60F	2017-08-03 21:57:00+03	34600.00
3CF69B	2017-07-10 07:49:00+03	23600.00
3CF6DA	2017-08-13 03:59:00+03	53300.00
3CF731	2017-07-10 18:07:00+03	44600.00
3CF7C9	2017-07-28 04:14:00+03	15100.00
3CF80F	2017-07-08 10:33:00+03	533800.00
3CF834	2017-07-20 21:08:00+03	28800.00
3CF83B	2017-07-13 21:29:00+03	69100.00
3CF879	2017-07-14 22:22:00+03	220100.00
3CF8CA	2017-07-30 14:01:00+03	91000.00
3CF8FB	2017-07-08 19:13:00+03	28700.00
3CF91D	2017-07-11 00:43:00+03	63800.00
3CF98D	2017-08-04 00:22:00+03	116800.00
3CF998	2017-08-10 13:47:00+03	56000.00
3CF9A2	2017-08-12 19:18:00+03	284400.00
3CF9B2	2017-07-12 00:49:00+03	64100.00
3CF9B6	2017-07-17 08:25:00+03	21000.00
3CF9E9	2017-07-11 13:25:00+03	31900.00
3CF9FA	2017-07-23 02:32:00+03	135000.00
3CFA11	2017-07-18 00:10:00+03	92800.00
3CFA7A	2017-07-03 16:19:00+03	140800.00
3CFAC8	2017-08-07 22:32:00+03	290400.00
3CFAD7	2017-08-02 22:07:00+03	382000.00
3CFAE2	2017-08-03 11:52:00+03	29200.00
3CFB3C	2017-07-18 23:54:00+03	45400.00
3CFBBB	2017-06-28 13:00:00+03	73600.00
3CFCD5	2017-08-06 11:44:00+03	95600.00
3CFCD7	2017-08-15 03:05:00+03	144300.00
3CFCDD	2017-07-20 09:19:00+03	80900.00
3CFD42	2017-08-02 03:23:00+03	57500.00
3CFDE2	2017-07-07 01:27:00+03	144400.00
3CFE7D	2017-08-11 06:03:00+03	45400.00
3CFE7F	2017-07-05 11:13:00+03	28800.00
3CFEA2	2017-07-12 05:36:00+03	54800.00
3CFED5	2017-07-12 10:53:00+03	135600.00
3CFF21	2017-07-26 12:35:00+03	23200.00
3CFF50	2017-08-02 01:09:00+03	19600.00
3CFFDD	2017-08-01 12:41:00+03	21400.00
3D0129	2017-07-22 01:16:00+03	61900.00
3D014D	2017-06-29 18:40:00+03	21500.00
3D01C1	2017-07-26 01:32:00+03	137100.00
3D0251	2017-07-02 04:31:00+03	46500.00
3D026D	2017-07-09 13:37:00+03	28000.00
3D0279	2017-07-07 15:29:00+03	53300.00
3D0329	2017-08-02 16:47:00+03	23400.00
3D046D	2017-08-05 14:16:00+03	59100.00
3D0473	2017-08-13 03:33:00+03	254600.00
3D0482	2017-08-12 12:49:00+03	55800.00
3D0499	2017-07-28 18:40:00+03	50000.00
3D04AE	2017-08-02 17:12:00+03	46000.00
3D04C2	2017-07-03 13:17:00+03	199700.00
3D04DB	2017-07-10 07:59:00+03	46700.00
3D04E2	2017-08-08 23:07:00+03	17200.00
3D050D	2017-07-29 15:00:00+03	243600.00
3D056B	2017-07-10 08:10:00+03	126400.00
3D05AA	2017-08-14 01:34:00+03	18000.00
3D05B6	2017-07-17 00:26:00+03	58400.00
3D05C0	2017-08-12 00:52:00+03	39400.00
3D05D9	2017-08-07 01:11:00+03	37700.00
3D0616	2017-08-14 07:17:00+03	28000.00
3D0619	2017-08-11 03:13:00+03	60900.00
3D0645	2017-08-12 22:48:00+03	92400.00
3D0691	2017-07-24 21:43:00+03	13600.00
3D06A8	2017-07-29 16:58:00+03	68100.00
3D06B7	2017-07-06 04:10:00+03	93800.00
3D06C5	2017-07-23 09:29:00+03	23400.00
3D06CB	2017-07-30 00:46:00+03	23600.00
3D06F9	2017-07-14 23:59:00+03	622000.00
3D070E	2017-07-22 09:31:00+03	36200.00
3D0740	2017-07-02 01:46:00+03	7400.00
3D07CC	2017-08-04 12:10:00+03	134100.00
3D07E1	2017-07-28 02:39:00+03	45200.00
3D0874	2017-08-01 10:48:00+03	55800.00
3D0898	2017-07-17 23:49:00+03	39200.00
3D0899	2017-07-08 23:55:00+03	22000.00
3D0934	2017-08-14 20:47:00+03	137800.00
3D0958	2017-08-11 13:23:00+03	67400.00
3D097C	2017-07-27 23:52:00+03	37200.00
3D0982	2017-07-04 09:05:00+03	67400.00
3D09A0	2017-07-05 00:19:00+03	39000.00
3D09A9	2017-07-18 23:49:00+03	136800.00
3D09AF	2017-07-14 23:53:00+03	25600.00
3D09F7	2017-08-01 17:58:00+03	274200.00
3D0A00	2017-07-29 11:15:00+03	12600.00
3D0A21	2017-07-12 04:08:00+03	22000.00
3D0A28	2017-08-09 19:46:00+03	199700.00
3D0AB5	2017-07-07 05:37:00+03	139800.00
3D0B02	2017-07-08 08:50:00+03	88900.00
3D0B52	2017-08-07 11:18:00+03	155600.00
3D0C3B	2017-08-15 08:49:00+03	123000.00
3D0D7E	2017-08-14 09:23:00+03	18800.00
3D0D80	2017-07-28 14:01:00+03	24400.00
3D0DA2	2017-08-09 11:42:00+03	157200.00
3D0DAF	2017-07-27 08:14:00+03	67700.00
3D0DE3	2017-07-01 07:10:00+03	121400.00
3D0E3A	2017-08-09 12:46:00+03	75300.00
3D0E67	2017-07-18 17:26:00+03	38400.00
3D0E6E	2017-08-01 12:55:00+03	46300.00
3D0EAD	2017-08-13 02:48:00+03	29600.00
3D0F3D	2017-08-04 00:25:00+03	56000.00
3D0F60	2017-07-26 18:37:00+03	12000.00
3D0F82	2017-08-15 00:45:00+03	117100.00
3D0F96	2017-08-01 01:20:00+03	37700.00
3D0FAD	2017-08-08 11:07:00+03	36200.00
3D0FB3	2017-08-14 14:06:00+03	66700.00
3D104B	2017-08-01 13:35:00+03	120600.00
3D10BF	2017-07-23 08:33:00+03	53600.00
3D10EB	2017-08-01 15:02:00+03	52300.00
3D1140	2017-07-07 03:37:00+03	62800.00
3D118A	2017-07-11 18:31:00+03	75200.00
3D1223	2017-07-13 22:34:00+03	369000.00
3D1229	2017-07-24 13:58:00+03	26700.00
3D1247	2017-07-22 21:14:00+03	22600.00
3D1254	2017-08-04 01:53:00+03	133200.00
3D129C	2017-08-07 21:39:00+03	84300.00
3D12EA	2017-08-14 15:29:00+03	174400.00
3D1314	2017-07-17 22:31:00+03	28800.00
3D1365	2017-07-22 19:53:00+03	56100.00
3D13AF	2017-07-30 15:22:00+03	26300.00
3D13BD	2017-07-29 11:03:00+03	43000.00
3D13D6	2017-07-16 23:54:00+03	118100.00
3D13E2	2017-08-06 00:23:00+03	26200.00
3D1437	2017-08-12 00:20:00+03	7200.00
3D146D	2017-08-05 15:21:00+03	48800.00
3D148E	2017-07-26 01:22:00+03	131600.00
3D14B2	2017-07-04 18:39:00+03	48800.00
3D14B4	2017-07-28 11:56:00+03	46700.00
3D14DF	2017-08-07 08:04:00+03	14800.00
3D1569	2017-07-14 18:35:00+03	37300.00
3D157F	2017-07-21 19:50:00+03	94200.00
3D1599	2017-07-25 12:21:00+03	182100.00
3D15A5	2017-08-13 15:48:00+03	42600.00
3D15EF	2017-07-09 19:41:00+03	77200.00
3D161C	2017-08-06 20:53:00+03	16400.00
3D1626	2017-08-09 18:08:00+03	527000.00
3D166E	2017-07-02 15:30:00+03	112000.00
3D174F	2017-08-03 16:43:00+03	257600.00
3D17F3	2017-07-19 13:27:00+03	24400.00
3D17F6	2017-07-25 08:42:00+03	135600.00
3D17F8	2017-07-28 01:44:00+03	39500.00
3D1812	2017-07-13 11:34:00+03	55800.00
3D1816	2017-07-29 19:57:00+03	47100.00
3D186F	2017-07-21 07:30:00+03	42800.00
3D1891	2017-07-19 02:35:00+03	41400.00
3D190A	2017-07-17 21:16:00+03	32700.00
3D1911	2017-08-06 18:25:00+03	32800.00
3D1937	2017-07-29 22:08:00+03	21400.00
3D196D	2017-07-05 13:59:00+03	43200.00
3D1993	2017-07-25 08:00:00+03	51200.00
3D19E0	2017-07-23 15:21:00+03	97800.00
3D19F9	2017-07-03 17:15:00+03	70600.00
3D1A09	2017-08-11 02:54:00+03	73100.00
3D1A12	2017-08-09 08:06:00+03	38400.00
3D1A2D	2017-08-10 00:14:00+03	28800.00
3D1A3C	2017-07-30 09:05:00+03	14000.00
3D1A58	2017-07-29 22:08:00+03	28800.00
3D1A63	2017-07-30 13:36:00+03	279800.00
3D1A7E	2017-07-11 06:25:00+03	28800.00
3D1AEF	2017-08-01 12:30:00+03	224000.00
3D1AF0	2017-07-22 04:23:00+03	59800.00
3D1B22	2017-08-01 20:27:00+03	57500.00
3D1BD4	2017-07-07 14:25:00+03	14000.00
3D1C12	2017-08-03 04:53:00+03	48400.00
3D1C73	2017-08-01 15:44:00+03	80800.00
3D1C86	2017-08-04 22:03:00+03	58800.00
3D1CAA	2017-07-03 19:07:00+03	19600.00
3D1CC2	2017-07-15 00:07:00+03	14000.00
3D1CE0	2017-08-15 13:29:00+03	86800.00
3D1CE1	2017-07-23 11:14:00+03	56600.00
3D1DD7	2017-07-22 23:34:00+03	11800.00
3D1E12	2017-07-07 22:55:00+03	37900.00
3D1E46	2017-07-06 21:00:00+03	20200.00
3D1E8C	2017-08-05 20:48:00+03	49100.00
3D1EA9	2017-07-19 03:12:00+03	124200.00
3D1EEE	2017-07-23 10:35:00+03	270700.00
3D1F22	2017-08-11 07:01:00+03	85000.00
3D1F2D	2017-07-22 20:56:00+03	30400.00
3D1F4A	2017-07-04 12:54:00+03	12400.00
3D1F4C	2017-07-28 18:09:00+03	28000.00
3D1F54	2017-08-12 10:42:00+03	21400.00
3D1F83	2017-07-27 22:11:00+03	71100.00
3D2002	2017-07-23 23:42:00+03	26000.00
3D2005	2017-08-14 20:53:00+03	6000.00
3D2019	2017-08-12 12:55:00+03	6300.00
3D202F	2017-07-13 02:21:00+03	74900.00
3D2075	2017-08-14 01:23:00+03	108100.00
3D208B	2017-08-08 18:51:00+03	55800.00
3D2097	2017-07-13 22:33:00+03	20800.00
3D20A7	2017-07-10 01:21:00+03	131600.00
3D20AC	2017-08-01 13:59:00+03	92100.00
3D20D3	2017-07-24 16:40:00+03	57600.00
3D2161	2017-07-23 15:11:00+03	24400.00
3D217A	2017-08-05 16:05:00+03	55800.00
3D220C	2017-07-06 12:43:00+03	13400.00
3D2244	2017-08-09 18:22:00+03	73500.00
3D2276	2017-06-30 09:33:00+03	46700.00
3D23A2	2017-07-13 05:24:00+03	49800.00
3D23D1	2017-08-07 14:35:00+03	28800.00
3D2400	2017-08-10 18:11:00+03	38400.00
3D2406	2017-08-05 07:44:00+03	67400.00
3D2407	2017-08-09 08:11:00+03	47900.00
3D2446	2017-08-01 10:28:00+03	84100.00
3D247F	2017-08-15 08:42:00+03	26700.00
3D24E1	2017-07-05 03:12:00+03	28700.00
3D24F7	2017-07-23 14:09:00+03	135000.00
3D2509	2017-07-19 06:57:00+03	47100.00
3D2525	2017-07-13 21:02:00+03	67400.00
3D2531	2017-08-08 21:11:00+03	6000.00
3D2684	2017-08-10 00:02:00+03	114500.00
3D2717	2017-07-03 08:43:00+03	317800.00
3D2786	2017-07-16 21:54:00+03	41800.00
3D27E5	2017-08-02 12:35:00+03	46200.00
3D27F4	2017-08-10 19:38:00+03	260900.00
3D27FA	2017-07-10 19:26:00+03	30200.00
3D2809	2017-08-10 18:25:00+03	56600.00
3D2814	2017-07-01 16:12:00+03	21400.00
3D282B	2017-07-28 15:17:00+03	31600.00
3D290E	2017-07-29 05:57:00+03	149200.00
3D2934	2017-06-27 22:52:00+03	101100.00
3D2939	2017-08-05 23:19:00+03	16400.00
3D2960	2017-07-30 10:25:00+03	155400.00
3D29A3	2017-07-13 20:24:00+03	257600.00
3D29AB	2017-07-24 18:35:00+03	15800.00
3D29B4	2017-08-13 08:10:00+03	62100.00
3D29E9	2017-07-26 06:22:00+03	118500.00
3D2A1F	2017-07-14 02:48:00+03	56600.00
3D2A2E	2017-08-11 01:32:00+03	151000.00
3D2A3F	2017-07-07 18:55:00+03	165000.00
3D2A91	2017-08-08 07:55:00+03	43500.00
3D2AF7	2017-08-10 03:43:00+03	28000.00
3D2B07	2017-08-11 08:13:00+03	54100.00
3D2B13	2017-06-30 15:17:00+03	47200.00
3D2B2E	2017-07-22 21:36:00+03	23200.00
3D2B3A	2017-08-13 06:52:00+03	44700.00
3D2B3D	2017-08-04 20:36:00+03	92800.00
3D2B4A	2017-07-09 21:06:00+03	19600.00
3D2BC1	2017-07-30 00:27:00+03	6000.00
3D2C08	2017-07-06 10:33:00+03	59800.00
3D2CFD	2017-07-08 23:11:00+03	56100.00
3D2D48	2017-07-13 07:40:00+03	44000.00
3D2D81	2017-08-03 01:23:00+03	54300.00
3D2D86	2017-08-12 17:58:00+03	56200.00
3D2DA6	2017-08-05 22:24:00+03	52300.00
3D2DB4	2017-07-26 09:18:00+03	111600.00
3D2DB9	2017-07-20 19:38:00+03	32700.00
3D2DC3	2017-08-12 23:46:00+03	14000.00
3D2DCC	2017-08-06 20:21:00+03	67200.00
3D2DE3	2017-07-26 20:18:00+03	96800.00
3D2E3A	2017-07-05 14:17:00+03	199500.00
3D2EE2	2017-08-08 03:39:00+03	46300.00
3D2FE0	2017-07-31 00:54:00+03	44600.00
3D3063	2017-07-10 10:04:00+03	36600.00
3D3089	2017-07-19 10:06:00+03	23400.00
3D30BB	2017-07-07 02:52:00+03	55800.00
3D30C4	2017-07-16 09:25:00+03	35900.00
3D30C9	2017-08-14 15:11:00+03	10800.00
3D310A	2017-06-28 15:09:00+03	55800.00
3D3126	2017-08-13 00:34:00+03	332200.00
3D3133	2017-07-21 12:07:00+03	47000.00
3D3166	2017-07-28 05:31:00+03	64400.00
3D31AF	2017-06-30 13:54:00+03	46200.00
3D31D4	2017-07-13 22:53:00+03	246000.00
3D3235	2017-07-09 03:21:00+03	73600.00
3D32DF	2017-08-03 07:33:00+03	112000.00
3D3335	2017-07-20 13:30:00+03	8200.00
3D3383	2017-07-17 15:31:00+03	46500.00
3D3433	2017-07-18 06:01:00+03	44500.00
3D34C2	2017-07-10 14:51:00+03	13600.00
3D3685	2017-08-06 00:33:00+03	24800.00
3D369D	2017-08-13 03:25:00+03	92900.00
3D36C5	2017-07-26 16:47:00+03	46400.00
3D36C6	2017-07-21 04:32:00+03	67100.00
3D36E7	2017-07-30 20:26:00+03	56100.00
3D376A	2017-08-12 16:40:00+03	31400.00
3D376D	2017-07-07 21:26:00+03	20600.00
3D37C8	2017-08-11 01:19:00+03	28300.00
3D37CD	2017-08-03 07:42:00+03	56000.00
3D3854	2017-07-23 10:57:00+03	24400.00
3D388E	2017-07-19 03:37:00+03	22000.00
3D38A3	2017-08-09 04:34:00+03	131800.00
3D38EB	2017-07-13 11:11:00+03	20600.00
3D3905	2017-08-12 17:10:00+03	109200.00
3D3912	2017-07-03 00:10:00+03	135400.00
3D3915	2017-07-10 08:42:00+03	23200.00
3D39F5	2017-07-27 23:45:00+03	7300.00
3D3A0A	2017-08-06 16:57:00+03	11700.00
3D3A44	2017-07-04 21:04:00+03	52200.00
3D3A54	2017-08-01 00:23:00+03	78800.00
3D3A56	2017-08-02 07:37:00+03	36200.00
3D3A8C	2017-07-17 18:36:00+03	174200.00
3D3AB0	2017-07-02 17:06:00+03	26000.00
3D3ABB	2017-08-03 14:55:00+03	67200.00
3D3B00	2017-07-26 05:14:00+03	19600.00
3D3B09	2017-06-29 00:30:00+03	12400.00
3D3B6B	2017-07-15 19:04:00+03	12600.00
3D3C07	2017-07-01 00:03:00+03	30900.00
3D3C14	2017-08-15 12:36:00+03	14800.00
3D3C90	2017-07-21 04:35:00+03	46400.00
3D3C9A	2017-08-10 23:48:00+03	93000.00
3D3CD6	2017-08-12 18:28:00+03	23200.00
3D3D55	2017-07-03 17:22:00+03	13200.00
3D3D8B	2017-07-16 21:30:00+03	91100.00
3D3DB4	2017-08-12 07:52:00+03	102100.00
3D3DEF	2017-08-06 05:30:00+03	67800.00
3D3E03	2017-08-13 15:13:00+03	125400.00
3D3E0E	2017-07-16 03:35:00+03	135000.00
3D3E45	2017-07-10 10:44:00+03	6600.00
3D3E77	2017-07-31 15:47:00+03	56000.00
3D3E93	2017-07-06 01:54:00+03	354200.00
3D3EB4	2017-08-13 17:53:00+03	86300.00
3D3F33	2017-07-18 18:37:00+03	362800.00
3D3F4B	2017-07-04 02:43:00+03	38400.00
3D3FA2	2017-07-30 02:24:00+03	204700.00
3D3FA6	2017-08-11 16:58:00+03	17600.00
3D3FE2	2017-07-21 19:37:00+03	49300.00
3D3FF4	2017-08-12 09:18:00+03	399600.00
3D4031	2017-07-01 22:46:00+03	28800.00
3D4042	2017-07-13 07:19:00+03	193200.00
3D4065	2017-07-03 22:30:00+03	50100.00
3D40C2	2017-07-26 17:42:00+03	13400.00
3D410E	2017-07-30 19:40:00+03	13700.00
3D423E	2017-08-13 03:29:00+03	56000.00
3D4254	2017-08-06 17:40:00+03	13600.00
3D42D7	2017-07-13 07:15:00+03	86800.00
3D42F4	2017-07-23 14:14:00+03	28000.00
3D4379	2017-08-11 20:06:00+03	155600.00
3D43D5	2017-08-13 07:46:00+03	67200.00
3D43E5	2017-07-17 10:08:00+03	46000.00
3D43F2	2017-07-30 05:13:00+03	12200.00
3D43F7	2017-08-10 04:47:00+03	48500.00
3D440D	2017-07-13 12:23:00+03	290100.00
3D4489	2017-07-11 17:38:00+03	114300.00
3D449D	2017-07-26 20:36:00+03	26900.00
3D44BC	2017-07-06 10:59:00+03	66900.00
3D44FB	2017-08-13 00:06:00+03	75600.00
3D450A	2017-07-01 08:56:00+03	21800.00
3D4562	2017-07-14 21:54:00+03	174200.00
3D4590	2017-07-14 07:47:00+03	101200.00
3D45EF	2017-08-10 00:54:00+03	43900.00
3D4659	2017-08-04 02:36:00+03	39600.00
3D46E8	2017-07-01 19:28:00+03	135000.00
3D46F9	2017-07-30 22:19:00+03	75600.00
3D47E9	2017-07-11 09:47:00+03	8000.00
3D4804	2017-08-04 09:55:00+03	34000.00
3D480D	2017-07-24 04:40:00+03	265600.00
3D484B	2017-07-30 18:56:00+03	73400.00
3D4882	2017-07-14 20:41:00+03	191700.00
3D4886	2017-07-21 09:03:00+03	174400.00
3D4904	2017-07-18 05:08:00+03	46400.00
3D4907	2017-07-29 02:26:00+03	136500.00
3D4955	2017-08-04 00:28:00+03	13400.00
3D49C5	2017-07-03 02:36:00+03	191700.00
3D49F6	2017-07-09 11:15:00+03	26700.00
3D4A17	2017-07-21 02:44:00+03	75600.00
3D4A4D	2017-08-06 18:39:00+03	40600.00
3D4A74	2017-07-20 17:19:00+03	20200.00
3D4A7D	2017-07-01 04:36:00+03	26000.00
3D4AC2	2017-07-05 06:42:00+03	8200.00
3D4B33	2017-07-11 06:06:00+03	32900.00
3D4B5F	2017-07-14 12:21:00+03	84400.00
3D4B9B	2017-08-12 02:17:00+03	171000.00
3D4BB6	2017-07-29 22:53:00+03	273400.00
3D4BDC	2017-07-23 21:08:00+03	56200.00
3D4C0C	2017-08-11 18:45:00+03	28000.00
3D4CAB	2017-08-08 22:46:00+03	32800.00
3D4CB2	2017-07-28 20:51:00+03	101800.00
3D4D05	2017-07-17 07:23:00+03	44000.00
3D4D6B	2017-08-04 12:24:00+03	34000.00
3D4D9D	2017-07-08 00:22:00+03	45200.00
3D4DAC	2017-07-17 00:53:00+03	119700.00
3D4E40	2017-08-10 04:30:00+03	51800.00
3D4E51	2017-07-18 11:58:00+03	24400.00
3D4E77	2017-07-02 02:01:00+03	14000.00
3D4E79	2017-07-20 20:22:00+03	16400.00
3D4EFA	2017-08-02 19:46:00+03	27200.00
3D4F74	2017-08-09 06:14:00+03	46400.00
3D4F85	2017-07-07 16:07:00+03	38800.00
3D5089	2017-07-07 09:33:00+03	63200.00
3D5119	2017-07-20 21:11:00+03	186100.00
3D513B	2017-07-20 09:38:00+03	31600.00
3D5141	2017-07-03 17:19:00+03	43200.00
3D517C	2017-07-20 22:06:00+03	202400.00
3D51E6	2017-07-31 03:29:00+03	124700.00
3D5250	2017-08-10 23:27:00+03	47100.00
3D5270	2017-07-30 02:13:00+03	26000.00
3D52D4	2017-07-07 20:42:00+03	248300.00
3D52D9	2017-08-04 23:13:00+03	156400.00
3D52F3	2017-08-13 07:24:00+03	125400.00
3D5327	2017-08-07 05:26:00+03	21800.00
3D532B	2017-07-16 22:04:00+03	51900.00
3D5331	2017-07-05 23:54:00+03	6700.00
3D5369	2017-08-11 06:12:00+03	97900.00
3D53CE	2017-07-23 14:39:00+03	39200.00
3D53FA	2017-07-30 19:30:00+03	133200.00
3D54B8	2017-06-30 00:31:00+03	6000.00
3D54C1	2017-07-14 17:15:00+03	69400.00
3D54EF	2017-08-08 23:39:00+03	12400.00
3D54F4	2017-08-11 12:40:00+03	27900.00
3D5529	2017-08-14 11:05:00+03	114600.00
3D553A	2017-08-04 04:44:00+03	88900.00
3D553B	2017-08-11 18:22:00+03	12700.00
3D5598	2017-06-30 00:49:00+03	68800.00
3D55B5	2017-08-14 06:17:00+03	46300.00
3D56B9	2017-07-07 11:19:00+03	75600.00
3D56BB	2017-07-29 14:17:00+03	246000.00
3D56E6	2017-07-21 16:50:00+03	56600.00
3D56F6	2017-07-31 06:08:00+03	6700.00
3D5715	2017-07-08 02:23:00+03	6700.00
3D5781	2017-07-24 21:35:00+03	126300.00
3D57C8	2017-07-08 16:29:00+03	26700.00
3D59F0	2017-07-24 00:50:00+03	54500.00
3D5A11	2017-08-08 10:00:00+03	344700.00
3D5A39	2017-07-07 22:44:00+03	16000.00
3D5A4C	2017-07-02 23:03:00+03	55600.00
3D5A99	2017-07-24 21:21:00+03	57600.00
3D5A9A	2017-07-16 02:46:00+03	140700.00
3D5ACB	2017-07-26 16:03:00+03	399600.00
3D5AF9	2017-08-10 18:26:00+03	206400.00
3D5B16	2017-07-29 09:45:00+03	26800.00
3D5B2A	2017-07-14 08:17:00+03	38400.00
3D5B2D	2017-07-18 07:42:00+03	166900.00
3D5B32	2017-08-06 04:19:00+03	56000.00
3D5B97	2017-08-11 04:38:00+03	405000.00
3D5C14	2017-07-10 19:43:00+03	68800.00
3D5C17	2017-07-23 18:43:00+03	112400.00
3D5C19	2017-07-11 08:29:00+03	57800.00
3D5C31	2017-08-03 08:36:00+03	89700.00
3D5C80	2017-07-27 01:42:00+03	23200.00
3D5CBC	2017-08-13 09:21:00+03	73500.00
3D5D31	2017-08-09 23:23:00+03	12600.00
3D5D9C	2017-07-22 00:48:00+03	91100.00
3D5DB8	2017-07-08 17:13:00+03	56000.00
3D5DBD	2017-07-29 03:06:00+03	6700.00
3D5E01	2017-06-29 03:58:00+03	77200.00
3D5E14	2017-07-06 17:59:00+03	185600.00
3D5E39	2017-07-07 07:19:00+03	28000.00
3D5FA2	2017-07-07 12:29:00+03	55800.00
3D5FDB	2017-07-30 14:30:00+03	147100.00
3D5FEA	2017-07-14 09:31:00+03	43900.00
3D600C	2017-07-20 14:00:00+03	44700.00
3D60AB	2017-07-29 16:21:00+03	23200.00
3D60AD	2017-07-24 16:45:00+03	40700.00
3D613E	2017-07-30 13:52:00+03	115600.00
3D619E	2017-07-10 14:52:00+03	111600.00
3D61AC	2017-07-12 09:45:00+03	97800.00
3D61AF	2017-08-14 14:30:00+03	92800.00
3D61CC	2017-07-23 11:36:00+03	68000.00
3D61D3	2017-07-23 07:26:00+03	123000.00
3D620C	2017-08-12 01:22:00+03	211500.00
3D622F	2017-07-14 20:40:00+03	28000.00
3D6235	2017-08-05 00:02:00+03	56000.00
3D62B9	2017-07-03 16:34:00+03	14400.00
3D6305	2017-07-23 18:45:00+03	59300.00
3D63C3	2017-07-18 21:09:00+03	41200.00
3D63E7	2017-07-21 12:20:00+03	49800.00
3D6433	2017-08-14 16:11:00+03	78300.00
3D6462	2017-07-22 09:02:00+03	46800.00
3D647D	2017-08-13 13:33:00+03	31200.00
3D64CD	2017-07-16 11:26:00+03	260900.00
3D6513	2017-07-26 22:26:00+03	193100.00
3D6563	2017-08-15 10:15:00+03	35700.00
3D65C9	2017-07-19 20:08:00+03	173600.00
3D65D3	2017-07-15 03:35:00+03	38800.00
3D65DA	2017-07-20 13:03:00+03	67900.00
3D65DE	2017-07-24 07:02:00+03	62700.00
3D65FC	2017-07-20 23:41:00+03	176800.00
3D660A	2017-07-31 03:15:00+03	37900.00
3D6679	2017-08-03 09:30:00+03	93900.00
3D6697	2017-07-18 16:51:00+03	86300.00
3D66A8	2017-07-19 06:30:00+03	23200.00
3D66F7	2017-08-12 11:33:00+03	29600.00
3D66FB	2017-07-19 13:38:00+03	93900.00
3D674C	2017-07-23 23:58:00+03	46000.00
3D6762	2017-07-20 05:21:00+03	12400.00
3D6770	2017-07-19 21:06:00+03	30900.00
3D67FA	2017-07-05 06:46:00+03	24400.00
3D687A	2017-08-11 18:08:00+03	99200.00
3D68BB	2017-07-30 21:38:00+03	140900.00
3D68D6	2017-07-19 07:30:00+03	75600.00
3D68D9	2017-07-21 13:41:00+03	46000.00
3D68F7	2017-07-23 21:53:00+03	34200.00
3D6905	2017-07-18 23:09:00+03	137600.00
3D691E	2017-06-29 15:22:00+03	103900.00
3D6935	2017-07-18 11:25:00+03	23400.00
3D6950	2017-08-05 04:35:00+03	23600.00
3D69E9	2017-07-24 07:14:00+03	16400.00
3D6A5B	2017-08-06 23:09:00+03	236700.00
3D6A61	2017-07-27 11:10:00+03	399600.00
3D6A96	2017-07-07 07:49:00+03	22000.00
3D6AD0	2017-08-05 14:16:00+03	150600.00
3D6B25	2017-08-01 17:09:00+03	50200.00
3D6B3D	2017-07-15 14:21:00+03	46800.00
3D6B4D	2017-08-14 14:44:00+03	115000.00
3D6B65	2017-07-03 21:23:00+03	73300.00
3D6B70	2017-07-16 08:38:00+03	23500.00
3D6B9D	2017-07-06 03:09:00+03	87700.00
3D6BD9	2017-08-10 22:39:00+03	46000.00
3D6BDC	2017-07-04 20:19:00+03	56000.00
3D6C09	2017-07-11 15:09:00+03	101200.00
3D6C4C	2017-08-10 10:39:00+03	99500.00
3D6C88	2017-08-02 15:32:00+03	43300.00
3D6CBF	2017-08-05 00:57:00+03	8600.00
3D6D38	2017-07-10 07:32:00+03	20200.00
3D6D51	2017-07-27 02:04:00+03	20200.00
3D6D57	2017-08-07 10:53:00+03	203000.00
3D6D5D	2017-08-09 09:15:00+03	53300.00
3D6D85	2017-08-04 01:56:00+03	111600.00
3D6D88	2017-07-11 04:15:00+03	52000.00
3D6DA5	2017-08-14 15:32:00+03	112200.00
3D6DD2	2017-07-06 18:39:00+03	28800.00
3D6EC4	2017-07-02 10:55:00+03	188000.00
3D6F16	2017-07-22 13:07:00+03	100700.00
3D6F1E	2017-07-08 18:01:00+03	30800.00
3D6F9F	2017-07-12 04:01:00+03	26600.00
3D7001	2017-07-05 01:16:00+03	271100.00
3D7057	2017-08-07 03:46:00+03	135400.00
3D70CE	2017-08-07 10:48:00+03	12400.00
3D70E4	2017-08-03 23:09:00+03	32200.00
3D70F1	2017-08-01 01:46:00+03	18000.00
3D712D	2017-07-04 03:28:00+03	46400.00
3D7151	2017-07-22 12:11:00+03	125000.00
3D715E	2017-07-20 12:25:00+03	47100.00
3D716D	2017-08-05 06:12:00+03	81700.00
3D71A5	2017-07-10 17:19:00+03	85000.00
3D71B7	2017-07-06 15:17:00+03	60400.00
3D7323	2017-07-08 07:28:00+03	13400.00
3D7353	2017-07-04 09:38:00+03	67600.00
3D739E	2017-07-15 15:50:00+03	40000.00
3D73A0	2017-08-01 05:38:00+03	131600.00
3D73A1	2017-08-01 06:25:00+03	66600.00
3D7415	2017-08-12 08:33:00+03	87800.00
3D7417	2017-08-15 04:42:00+03	72600.00
3D743B	2017-07-25 20:14:00+03	61500.00
3D7449	2017-07-15 08:12:00+03	34000.00
3D7463	2017-07-04 16:55:00+03	46200.00
3D7479	2017-07-25 13:37:00+03	378400.00
3D7485	2017-07-21 12:04:00+03	172100.00
3D7516	2017-07-01 09:26:00+03	98400.00
3D752D	2017-07-14 23:20:00+03	48200.00
3D7565	2017-08-10 02:42:00+03	60400.00
3D7592	2017-07-27 13:40:00+03	71400.00
3D75E5	2017-07-25 17:02:00+03	37900.00
3D76AB	2017-07-19 20:31:00+03	135400.00
3D77EF	2017-07-14 04:25:00+03	50800.00
3D77FB	2017-07-29 23:55:00+03	59900.00
3D7879	2017-07-21 05:48:00+03	41600.00
3D787A	2017-07-08 01:54:00+03	134400.00
3D7922	2017-07-26 22:23:00+03	50800.00
3D792F	2017-07-06 08:37:00+03	67600.00
3D794C	2017-06-30 02:46:00+03	92400.00
3D79D9	2017-07-26 21:32:00+03	41500.00
3D7A16	2017-07-23 20:59:00+03	6300.00
3D7A1E	2017-08-07 11:01:00+03	14800.00
3D7A2A	2017-07-21 10:28:00+03	137600.00
3D7A74	2017-08-08 02:56:00+03	13400.00
3D7AB9	2017-08-11 02:17:00+03	112000.00
3D7AD3	2017-06-30 03:34:00+03	16400.00
3D7AE4	2017-08-01 04:49:00+03	49900.00
3D7B0F	2017-07-21 14:12:00+03	35600.00
3D7B40	2017-07-26 08:05:00+03	136200.00
3D7B5C	2017-08-08 15:09:00+03	23600.00
3D7BAF	2017-07-04 12:18:00+03	81700.00
3D7D85	2017-07-19 18:47:00+03	70700.00
3D7D8F	2017-07-15 12:57:00+03	8400.00
3D7D92	2017-07-19 03:33:00+03	70600.00
3D7DA9	2017-08-11 10:08:00+03	26000.00
3D7E20	2017-07-06 02:22:00+03	58600.00
3D7E29	2017-08-01 14:24:00+03	29600.00
3D7E43	2017-07-26 23:13:00+03	22000.00
3D7EA4	2017-07-17 07:06:00+03	37200.00
3D7F1D	2017-08-02 02:51:00+03	26800.00
3D7F6B	2017-07-11 22:45:00+03	22000.00
3D7FA9	2017-07-14 23:49:00+03	14400.00
3D7FC3	2017-08-11 17:16:00+03	147700.00
3D8014	2017-08-04 12:29:00+03	37900.00
3D80C7	2017-07-21 09:58:00+03	46300.00
3D80D4	2017-08-06 01:52:00+03	136600.00
3D8140	2017-08-06 19:01:00+03	29600.00
3D8180	2017-07-05 12:13:00+03	44800.00
3D81AD	2017-08-02 20:53:00+03	45100.00
3D81C5	2017-07-18 12:13:00+03	36100.00
3D81F6	2017-07-16 03:33:00+03	111600.00
3D8222	2017-08-14 06:04:00+03	25600.00
3D822D	2017-08-09 09:15:00+03	29600.00
3D8298	2017-07-29 09:48:00+03	43600.00
3D82A5	2017-07-18 16:20:00+03	36200.00
3D8306	2017-07-14 04:27:00+03	112000.00
3D832E	2017-07-04 13:56:00+03	206100.00
3D8356	2017-08-02 19:45:00+03	85700.00
3D8358	2017-08-04 15:26:00+03	96100.00
3D8371	2017-08-04 06:24:00+03	207300.00
3D83A0	2017-08-14 06:04:00+03	133200.00
3D8482	2017-08-14 07:42:00+03	369000.00
3D8487	2017-07-09 12:47:00+03	47200.00
3D84B6	2017-07-27 02:35:00+03	71900.00
3D8523	2017-08-12 12:54:00+03	8000.00
3D855E	2017-08-13 23:32:00+03	47600.00
3D85AF	2017-07-19 05:31:00+03	48800.00
3D8627	2017-08-01 05:08:00+03	112000.00
3D8662	2017-08-10 08:45:00+03	74400.00
3D8791	2017-08-04 04:45:00+03	39600.00
3D8792	2017-08-14 22:48:00+03	49100.00
3D879C	2017-07-04 07:27:00+03	31200.00
3D87BF	2017-07-15 03:35:00+03	19600.00
3D8816	2017-08-12 06:49:00+03	87400.00
3D8844	2017-07-17 02:54:00+03	79600.00
3D884F	2017-07-21 08:37:00+03	560000.00
3D8873	2017-08-15 11:58:00+03	14400.00
3D88B5	2017-07-09 23:53:00+03	46000.00
3D88B8	2017-07-31 01:25:00+03	21800.00
3D88BD	2017-07-23 22:15:00+03	24400.00
3D88E5	2017-07-23 18:07:00+03	64700.00
3D8936	2017-07-29 18:42:00+03	47200.00
3D896C	2017-07-22 18:30:00+03	73500.00
3D8998	2017-08-03 20:12:00+03	84100.00
3D89AB	2017-07-01 15:57:00+03	56100.00
3D89E5	2017-08-15 00:52:00+03	35900.00
3D89F9	2017-06-29 15:10:00+03	119600.00
3D8A08	2017-08-12 11:56:00+03	13400.00
3D8A27	2017-07-27 17:47:00+03	62600.00
3D8AB2	2017-07-16 02:45:00+03	284300.00
3D8B5C	2017-07-19 06:57:00+03	39400.00
3D8B6A	2017-07-03 09:45:00+03	166700.00
3D8BEF	2017-07-05 04:48:00+03	136200.00
3D8BF9	2017-08-08 01:11:00+03	80000.00
3D8C38	2017-08-01 09:44:00+03	23200.00
3D8D44	2017-07-26 16:19:00+03	32800.00
3D8D5C	2017-07-29 22:41:00+03	168000.00
3D8D9A	2017-08-13 04:54:00+03	189800.00
3D8E27	2017-07-17 12:24:00+03	106200.00
3D8E3D	2017-08-14 15:17:00+03	209200.00
3D8EDF	2017-08-10 01:10:00+03	67900.00
3D8F2B	2017-07-19 14:22:00+03	142300.00
3D8F42	2017-07-31 12:08:00+03	42800.00
3D8F50	2017-08-06 08:14:00+03	71800.00
3D8F82	2017-08-02 14:37:00+03	68100.00
3D8F8F	2017-07-03 19:58:00+03	102300.00
3D8FB3	2017-07-26 02:39:00+03	67200.00
3D8FC5	2017-07-17 18:01:00+03	103500.00
3D8FCF	2017-08-11 04:59:00+03	70700.00
3D8FDA	2017-08-07 17:01:00+03	118800.00
3D905A	2017-07-14 12:58:00+03	43600.00
3D906E	2017-07-23 19:55:00+03	151800.00
3D90C4	2017-07-24 16:31:00+03	44600.00
3D90E9	2017-07-27 14:19:00+03	92800.00
3D90F0	2017-07-01 12:04:00+03	112000.00
3D9103	2017-07-18 19:27:00+03	66400.00
3D911C	2017-07-09 14:23:00+03	112000.00
3D9126	2017-06-27 09:04:00+03	24800.00
3D917C	2017-08-15 09:30:00+03	103900.00
3D9187	2017-07-29 10:52:00+03	270700.00
3D918D	2017-07-16 13:42:00+03	24400.00
3D91D1	2017-07-18 12:57:00+03	28800.00
3D92BC	2017-07-23 20:01:00+03	79000.00
3D92BE	2017-07-20 16:50:00+03	64700.00
3D933C	2017-08-10 17:30:00+03	23200.00
3D9388	2017-07-09 22:42:00+03	28800.00
3D93AB	2017-08-08 07:22:00+03	225200.00
3D9442	2017-08-04 10:27:00+03	24400.00
3D948F	2017-08-04 10:01:00+03	58800.00
3D94CC	2017-07-15 09:25:00+03	173400.00
3D950B	2017-07-19 20:12:00+03	26000.00
3D9513	2017-07-11 08:34:00+03	260300.00
3D9514	2017-08-04 13:54:00+03	25800.00
3D9517	2017-07-04 18:42:00+03	61800.00
3D9541	2017-08-13 09:56:00+03	150600.00
3D9584	2017-07-15 22:35:00+03	167400.00
3D959D	2017-07-26 09:14:00+03	30200.00
3D95A0	2017-07-09 04:15:00+03	52100.00
3D9607	2017-07-13 17:13:00+03	88500.00
3D9629	2017-06-30 19:08:00+03	13400.00
3D9695	2017-08-02 05:00:00+03	125700.00
3D96AF	2017-08-15 11:44:00+03	56000.00
3D9733	2017-08-03 14:30:00+03	31100.00
3D9768	2017-07-06 10:35:00+03	75300.00
3D9783	2017-08-02 05:19:00+03	88000.00
3D97DF	2017-07-31 04:17:00+03	193700.00
3D9804	2017-08-09 20:07:00+03	32200.00
3D9846	2017-07-17 00:43:00+03	120400.00
3D988D	2017-08-04 18:51:00+03	127300.00
3D98B3	2017-07-22 13:20:00+03	58900.00
3D98E4	2017-08-13 07:53:00+03	24000.00
3D990E	2017-08-04 06:40:00+03	11700.00
3D995E	2017-08-11 02:43:00+03	44600.00
3D997D	2017-08-01 23:57:00+03	23200.00
3D99B5	2017-07-20 10:44:00+03	59300.00
3D99F3	2017-07-10 12:07:00+03	27200.00
3D9A44	2017-08-08 21:36:00+03	55800.00
3D9A66	2017-07-17 20:15:00+03	38800.00
3D9A9E	2017-07-09 08:24:00+03	199700.00
3D9AAB	2017-07-17 08:02:00+03	176400.00
3D9B03	2017-08-05 05:27:00+03	28700.00
3D9B13	2017-07-31 04:04:00+03	81700.00
3D9B42	2017-07-30 00:39:00+03	135400.00
3D9B50	2017-07-19 03:08:00+03	111600.00
3D9B6D	2017-08-07 19:54:00+03	23200.00
3D9BA9	2017-08-09 13:33:00+03	135600.00
3D9BE8	2017-08-05 17:08:00+03	131100.00
3D9C41	2017-07-24 03:58:00+03	6700.00
3D9CB5	2017-07-29 01:50:00+03	62600.00
3D9D0C	2017-06-30 01:54:00+03	47200.00
3D9D48	2017-07-04 10:58:00+03	28000.00
3D9D71	2017-07-22 16:00:00+03	112000.00
3D9DBD	2017-07-27 09:31:00+03	13200.00
3D9ECB	2017-08-06 10:37:00+03	136200.00
3D9EF1	2017-08-12 18:56:00+03	53300.00
3D9EF2	2017-07-20 04:02:00+03	58600.00
3D9EF6	2017-07-04 12:51:00+03	22000.00
3D9F17	2017-07-11 20:24:00+03	26400.00
3D9F48	2017-07-13 17:40:00+03	99200.00
3D9F74	2017-08-09 02:45:00+03	27200.00
3DA014	2017-08-08 11:33:00+03	240600.00
3DA020	2017-08-01 19:37:00+03	86800.00
3DA089	2017-08-10 11:32:00+03	15900.00
3DA0B9	2017-08-07 22:21:00+03	246000.00
3DA0CB	2017-08-15 09:40:00+03	13500.00
3DA0D5	2017-07-25 23:23:00+03	36900.00
3DA14C	2017-07-18 04:29:00+03	68300.00
3DA163	2017-07-20 23:32:00+03	14800.00
3DA2DD	2017-08-08 14:03:00+03	13300.00
3DA30C	2017-07-10 16:27:00+03	46000.00
3DA329	2017-08-15 10:49:00+03	27200.00
3DA335	2017-07-01 04:57:00+03	32800.00
3DA423	2017-08-14 01:46:00+03	142400.00
3DA456	2017-08-05 10:59:00+03	168000.00
3DA4A7	2017-08-10 04:40:00+03	23200.00
3DA4AA	2017-07-25 15:40:00+03	114700.00
3DA4C3	2017-07-19 06:34:00+03	64800.00
3DA4D8	2017-07-28 09:01:00+03	59800.00
3DA4EB	2017-07-31 08:59:00+03	282100.00
3DA519	2017-07-19 02:48:00+03	56000.00
3DA591	2017-07-14 02:22:00+03	79600.00
3DA5B8	2017-07-26 03:34:00+03	413400.00
3DA624	2017-07-23 13:30:00+03	25600.00
3DA633	2017-07-19 22:15:00+03	26000.00
3DA699	2017-07-16 12:29:00+03	54000.00
3DA6F9	2017-07-09 15:46:00+03	89700.00
3DA71E	2017-08-04 22:17:00+03	23600.00
3DA72C	2017-08-10 11:51:00+03	28000.00
3DA783	2017-07-04 04:13:00+03	29600.00
3DA7EB	2017-06-27 13:02:00+03	187600.00
3DA80A	2017-08-15 01:42:00+03	46200.00
3DA8BC	2017-08-15 06:49:00+03	48800.00
3DA8E2	2017-08-13 05:00:00+03	68400.00
3DA949	2017-08-01 23:42:00+03	266200.00
3DAA65	2017-07-11 00:13:00+03	25600.00
3DAB0C	2017-07-18 09:23:00+03	58600.00
3DAB1B	2017-07-18 14:24:00+03	34400.00
3DAB35	2017-07-22 18:45:00+03	59200.00
3DAB8A	2017-07-26 05:49:00+03	36200.00
3DABA4	2017-08-09 16:35:00+03	86000.00
3DABFE	2017-07-23 05:42:00+03	260300.00
3DAC25	2017-07-09 17:02:00+03	28000.00
3DAC36	2017-08-05 10:05:00+03	50000.00
3DAC63	2017-07-11 00:37:00+03	28800.00
3DAC6C	2017-07-28 17:53:00+03	25400.00
3DACFA	2017-08-06 12:15:00+03	16400.00
3DACFC	2017-07-13 16:05:00+03	133100.00
3DAD0F	2017-07-30 17:07:00+03	111600.00
3DAD3E	2017-07-31 15:58:00+03	173200.00
3DAD5B	2017-07-02 09:42:00+03	198600.00
3DADF6	2017-07-28 09:07:00+03	15400.00
3DAE29	2017-06-30 07:28:00+03	62600.00
3DAE48	2017-08-02 00:59:00+03	111600.00
3DAE64	2017-08-03 20:06:00+03	112600.00
3DAE70	2017-08-01 10:31:00+03	84000.00
3DAE82	2017-08-14 21:25:00+03	13600.00
3DAE92	2017-08-08 08:01:00+03	137400.00
3DAEB1	2017-07-02 22:42:00+03	149200.00
3DAF09	2017-07-30 14:04:00+03	258700.00
3DAF35	2017-07-13 23:19:00+03	36200.00
3DAF87	2017-07-24 12:50:00+03	51900.00
3DAFF9	2017-07-14 09:50:00+03	38600.00
3DB04D	2017-07-27 23:48:00+03	29100.00
3DB04E	2017-08-08 02:29:00+03	31600.00
3DB076	2017-08-14 10:17:00+03	149600.00
3DB11E	2017-08-06 14:15:00+03	51000.00
3DB14B	2017-08-07 02:38:00+03	133100.00
3DB161	2017-08-02 08:04:00+03	270800.00
3DB175	2017-07-17 03:13:00+03	54400.00
3DB1CE	2017-07-14 23:15:00+03	26000.00
3DB1EF	2017-07-25 16:37:00+03	250600.00
3DB215	2017-07-28 13:21:00+03	52900.00
3DB237	2017-07-30 01:30:00+03	78900.00
3DB23D	2017-07-26 21:12:00+03	86800.00
3DB25D	2017-07-25 12:28:00+03	31600.00
3DB2B1	2017-07-06 05:33:00+03	26800.00
3DB2DD	2017-08-03 20:30:00+03	50600.00
3DB315	2017-07-13 10:44:00+03	123000.00
3DB31C	2017-07-07 01:40:00+03	99300.00
3DB346	2017-08-09 00:02:00+03	233800.00
3DB3BE	2017-07-09 19:48:00+03	55800.00
3DB3D7	2017-08-06 09:50:00+03	26200.00
3DB3D8	2017-07-04 08:36:00+03	28800.00
3DB446	2017-08-09 18:14:00+03	40300.00
3DB456	2017-08-13 11:40:00+03	92900.00
3DB4D9	2017-07-13 23:08:00+03	112200.00
3DB4ED	2017-07-28 07:20:00+03	55800.00
3DB513	2017-08-14 18:18:00+03	46400.00
3DB58F	2017-07-05 15:13:00+03	137800.00
3DB59F	2017-07-31 04:22:00+03	12600.00
3DB5B2	2017-06-30 15:41:00+03	51000.00
3DB5B7	2017-07-10 03:02:00+03	28000.00
3DB5EA	2017-07-23 08:53:00+03	98400.00
3DB615	2017-08-08 22:00:00+03	27900.00
3DB62B	2017-07-20 06:31:00+03	24400.00
3DB64E	2017-08-01 23:23:00+03	39800.00
3DB713	2017-06-28 06:43:00+03	51300.00
3DB753	2017-07-02 11:18:00+03	185600.00
3DB754	2017-07-06 15:59:00+03	39800.00
3DB759	2017-07-27 06:25:00+03	70600.00
3DB769	2017-07-25 07:44:00+03	56900.00
3DB7B1	2017-07-03 15:17:00+03	138300.00
3DB92C	2017-08-09 23:52:00+03	12600.00
3DB978	2017-08-05 08:52:00+03	51900.00
3DB992	2017-07-17 14:10:00+03	36200.00
3DBA6F	2017-07-10 04:16:00+03	133200.00
3DBA71	2017-07-05 22:19:00+03	46700.00
3DBAEC	2017-08-01 19:02:00+03	64700.00
3DBB19	2017-07-20 11:04:00+03	4100.00
3DBB21	2017-07-04 14:10:00+03	27400.00
3DBB75	2017-07-03 18:57:00+03	51900.00
3DBB9E	2017-08-12 20:46:00+03	22000.00
3DBBC5	2017-07-13 00:36:00+03	58800.00
3DBBE0	2017-08-02 13:22:00+03	39200.00
3DBC2D	2017-08-15 06:19:00+03	18100.00
3DBC67	2017-07-07 20:14:00+03	32800.00
3DBCD5	2017-07-31 16:26:00+03	16400.00
3DBCFE	2017-07-31 20:41:00+03	89700.00
3DBD00	2017-07-13 23:00:00+03	101200.00
3DBD78	2017-07-01 18:49:00+03	66600.00
3DBD96	2017-07-17 17:08:00+03	57400.00
3DBDCB	2017-08-11 17:59:00+03	52000.00
3DBDDC	2017-08-01 16:43:00+03	6800.00
3DBE5F	2017-08-01 17:31:00+03	131100.00
3DBE82	2017-08-13 10:34:00+03	72700.00
3DBE91	2017-08-03 11:46:00+03	153300.00
3DBE9D	2017-07-06 10:55:00+03	30000.00
3DBF92	2017-07-13 22:54:00+03	66200.00
3DBFCE	2017-07-02 07:20:00+03	101200.00
3DC069	2017-07-04 17:29:00+03	53800.00
3DC077	2017-07-05 17:16:00+03	40400.00
3DC084	2017-08-10 05:28:00+03	37600.00
3DC086	2017-07-22 21:20:00+03	108000.00
3DC09C	2017-07-29 03:15:00+03	185800.00
3DC0AB	2017-07-25 13:54:00+03	125200.00
3DC0B5	2017-07-20 23:53:00+03	36400.00
3DC0CA	2017-07-30 22:57:00+03	23600.00
3DC0D9	2017-07-10 02:33:00+03	19600.00
3DC0EA	2017-07-30 07:05:00+03	247400.00
3DC149	2017-07-03 16:37:00+03	86600.00
3DC15F	2017-07-20 12:35:00+03	122000.00
3DC173	2017-08-06 03:40:00+03	103700.00
3DC17F	2017-08-08 07:41:00+03	14000.00
3DC1A8	2017-08-05 17:19:00+03	55800.00
3DC295	2017-07-23 11:44:00+03	12600.00
3DC2AD	2017-07-26 08:51:00+03	78700.00
3DC2AF	2017-07-18 13:35:00+03	65900.00
3DC2C9	2017-08-12 11:13:00+03	61800.00
3DC317	2017-07-26 14:19:00+03	32700.00
3DC319	2017-07-30 16:14:00+03	42800.00
3DC360	2017-08-07 20:49:00+03	65300.00
3DC379	2017-07-23 21:19:00+03	46000.00
3DC3D6	2017-07-20 10:09:00+03	32700.00
3DC3EF	2017-08-11 09:27:00+03	6600.00
3DC479	2017-07-08 05:01:00+03	110000.00
3DC482	2017-07-04 02:07:00+03	143100.00
3DC4A0	2017-07-23 10:15:00+03	40800.00
3DC4A2	2017-07-25 18:29:00+03	123600.00
3DC4AA	2017-07-14 21:46:00+03	185600.00
3DC4C5	2017-07-07 02:55:00+03	11600.00
3DC550	2017-07-10 13:16:00+03	10800.00
3DC646	2017-07-09 12:41:00+03	48700.00
3DC64A	2017-07-29 09:48:00+03	167500.00
3DC677	2017-07-10 13:56:00+03	30800.00
3DC68B	2017-06-29 09:31:00+03	22000.00
3DC6AF	2017-07-29 21:12:00+03	84500.00
3DC6D0	2017-07-24 05:04:00+03	62800.00
3DC7B4	2017-07-18 12:51:00+03	24600.00
3DC7FE	2017-07-20 04:57:00+03	86300.00
3DC803	2017-08-14 18:07:00+03	96000.00
3DC81B	2017-08-06 21:39:00+03	58400.00
3DC82F	2017-08-01 02:24:00+03	28000.00
3DC885	2017-08-10 15:04:00+03	21400.00
3DC8B9	2017-07-24 04:29:00+03	59700.00
3DC8CA	2017-08-14 07:04:00+03	120300.00
3DC8E9	2017-08-15 14:05:00+03	308900.00
3DC957	2017-08-13 21:20:00+03	96600.00
3DCA1F	2017-07-16 09:55:00+03	43200.00
3DCA77	2017-08-03 16:40:00+03	55800.00
3DCAD2	2017-08-07 04:03:00+03	45600.00
3DCB09	2017-08-02 14:07:00+03	46000.00
3DCB11	2017-08-14 15:06:00+03	40100.00
3DCB3D	2017-07-27 21:31:00+03	51900.00
3DCB5B	2017-08-10 00:11:00+03	16000.00
3DCB78	2017-07-04 04:13:00+03	55800.00
3DCBB9	2017-08-04 20:37:00+03	6300.00
3DCC0D	2017-08-02 23:44:00+03	55000.00
3DCC1A	2017-07-02 21:25:00+03	44600.00
3DCC7B	2017-07-13 00:44:00+03	77500.00
3DCCC8	2017-07-23 01:59:00+03	155600.00
3DCD39	2017-08-12 18:35:00+03	150000.00
3DCD5F	2017-07-07 14:12:00+03	15800.00
3DCDC8	2017-07-17 05:17:00+03	83000.00
3DCE18	2017-08-06 16:33:00+03	37900.00
3DCE88	2017-08-09 19:36:00+03	77100.00
3DCF1C	2017-08-15 00:42:00+03	34000.00
3DCF3A	2017-08-03 01:00:00+03	25600.00
3DCF5F	2017-08-04 20:29:00+03	9300.00
3DCFBF	2017-07-18 21:36:00+03	47100.00
3DD071	2017-07-21 00:49:00+03	24200.00
3DD089	2017-07-15 02:35:00+03	123000.00
3DD094	2017-08-04 14:16:00+03	44500.00
3DD125	2017-08-06 05:53:00+03	13400.00
3DD161	2017-08-03 15:09:00+03	46000.00
3DD187	2017-07-14 19:49:00+03	24400.00
3DD1F0	2017-08-11 09:59:00+03	15100.00
3DD202	2017-08-05 21:15:00+03	187600.00
3DD262	2017-08-10 10:23:00+03	42800.00
3DD279	2017-07-12 03:42:00+03	32200.00
3DD2CC	2017-08-04 04:43:00+03	47700.00
3DD2EC	2017-08-15 02:17:00+03	81200.00
3DD46B	2017-07-29 12:47:00+03	124300.00
3DD4D0	2017-07-03 22:36:00+03	54800.00
3DD50D	2017-07-15 10:08:00+03	52000.00
3DD523	2017-08-11 15:28:00+03	84300.00
3DD52F	2017-07-12 07:50:00+03	55800.00
3DD534	2017-07-16 01:08:00+03	77900.00
3DD54A	2017-08-14 12:11:00+03	65900.00
3DD561	2017-07-02 08:51:00+03	103500.00
3DD573	2017-07-19 06:53:00+03	20000.00
3DD57F	2017-07-23 07:45:00+03	114400.00
3DD583	2017-07-05 15:39:00+03	123000.00
3DD5A0	2017-08-03 20:20:00+03	27300.00
3DD5E7	2017-07-28 19:56:00+03	6700.00
3DD5F6	2017-07-30 07:26:00+03	169000.00
3DD646	2017-08-11 12:36:00+03	50600.00
3DD65D	2017-07-11 07:33:00+03	43100.00
3DD675	2017-07-26 05:51:00+03	123000.00
3DD679	2017-08-09 23:56:00+03	56600.00
3DD68C	2017-07-27 10:31:00+03	65300.00
3DD6B6	2017-07-31 06:40:00+03	39800.00
3DD6CE	2017-08-12 04:00:00+03	75600.00
3DD6E6	2017-07-10 03:41:00+03	89600.00
3DD709	2017-07-19 05:44:00+03	23400.00
3DD719	2017-07-29 20:25:00+03	55500.00
3DD73B	2017-08-08 22:09:00+03	603600.00
3DD756	2017-07-27 00:52:00+03	54800.00
3DD786	2017-07-26 05:09:00+03	58900.00
3DD840	2017-07-07 07:46:00+03	288300.00
3DD89E	2017-08-04 03:33:00+03	10800.00
3DD8D7	2017-07-16 16:56:00+03	11600.00
3DD8FB	2017-07-17 12:21:00+03	48800.00
3DD8FC	2017-08-07 23:58:00+03	22600.00
3DD93D	2017-07-27 10:20:00+03	8000.00
3DD994	2017-07-12 10:41:00+03	101200.00
3DD999	2017-08-09 22:16:00+03	18600.00
3DD9BA	2017-07-30 10:08:00+03	56000.00
3DDA22	2017-07-06 06:36:00+03	25600.00
3DDA43	2017-08-10 18:28:00+03	46400.00
3DDA4D	2017-07-13 07:16:00+03	28000.00
3DDAB1	2017-07-13 09:48:00+03	57000.00
3DDAFD	2017-07-29 17:23:00+03	274200.00
3DDB40	2017-07-06 08:56:00+03	20400.00
3DDB4E	2017-07-07 15:57:00+03	32800.00
3DDB5F	2017-07-29 09:59:00+03	46400.00
3DDB62	2017-08-02 12:32:00+03	155600.00
3DDBC1	2017-07-21 03:29:00+03	149100.00
3DDBD2	2017-07-17 21:25:00+03	6700.00
3DDC75	2017-07-16 22:03:00+03	49100.00
3DDC85	2017-08-04 00:09:00+03	88900.00
3DDCC6	2017-08-14 21:50:00+03	87000.00
3DDCFE	2017-07-04 07:52:00+03	54400.00
3DDD18	2017-07-14 20:22:00+03	30000.00
3DDD43	2017-08-11 02:06:00+03	32800.00
3DDD59	2017-08-03 04:07:00+03	112000.00
3DDD7A	2017-07-25 20:42:00+03	100500.00
3DDD90	2017-06-28 15:51:00+03	40000.00
3DDDA0	2017-07-05 20:20:00+03	135000.00
3DDDAF	2017-07-30 13:53:00+03	13600.00
3DDDB1	2017-08-13 06:39:00+03	65900.00
3DDDBB	2017-07-31 06:08:00+03	24800.00
3DDDEA	2017-08-01 10:23:00+03	112000.00
3DDE62	2017-07-30 07:27:00+03	38600.00
3DDF6F	2017-07-31 08:33:00+03	124200.00
3DDF79	2017-07-21 16:07:00+03	39500.00
3DDFD5	2017-07-07 03:18:00+03	24000.00
3DE007	2017-08-15 13:53:00+03	112000.00
3DE065	2017-08-07 10:04:00+03	28000.00
3DE0DF	2017-07-23 18:13:00+03	69500.00
3DE13C	2017-07-03 09:37:00+03	123000.00
3DE1BD	2017-07-10 07:35:00+03	42800.00
3DE1E6	2017-08-02 07:01:00+03	75600.00
3DE226	2017-07-15 20:42:00+03	127600.00
3DE23D	2017-07-07 15:08:00+03	42800.00
3DE26D	2017-08-15 14:00:00+03	81300.00
3DE285	2017-08-10 07:55:00+03	58800.00
3DE2D3	2017-08-04 23:54:00+03	46200.00
3DE2D8	2017-08-11 08:52:00+03	101800.00
3DE30B	2017-07-10 08:30:00+03	67800.00
3DE40F	2017-07-25 19:47:00+03	29600.00
3DE452	2017-08-13 07:07:00+03	54000.00
3DE47C	2017-08-13 18:12:00+03	98400.00
3DE49A	2017-08-03 21:29:00+03	21800.00
3DE4BE	2017-08-12 13:02:00+03	117200.00
3DE5BA	2017-08-09 02:56:00+03	39200.00
3DE64F	2017-08-15 03:27:00+03	29400.00
3DE6B0	2017-08-15 12:17:00+03	55800.00
3DE6FE	2017-07-07 19:53:00+03	27800.00
3DE701	2017-07-27 09:15:00+03	222800.00
3DE73E	2017-07-19 03:28:00+03	27300.00
3DE7BB	2017-08-12 20:12:00+03	34000.00
3DE7C6	2017-07-13 15:00:00+03	62600.00
3DE7CF	2017-08-12 10:49:00+03	26500.00
3DE837	2017-07-07 03:21:00+03	49400.00
3DE893	2017-08-11 06:59:00+03	44000.00
3DE8B3	2017-08-15 07:04:00+03	130400.00
3DE8BF	2017-07-05 08:38:00+03	70900.00
3DE8CB	2017-07-26 16:44:00+03	246000.00
3DE97B	2017-08-15 13:10:00+03	40800.00
3DE982	2017-08-12 16:09:00+03	64100.00
3DE9A1	2017-07-07 13:28:00+03	28000.00
3DE9DC	2017-08-05 12:18:00+03	154500.00
3DE9E4	2017-08-11 19:35:00+03	36400.00
3DEA20	2017-07-03 09:36:00+03	92700.00
3DEA3E	2017-07-15 00:36:00+03	31600.00
3DEA77	2017-07-19 19:10:00+03	355900.00
3DEAD4	2017-08-11 02:37:00+03	81700.00
3DEB05	2017-07-13 03:34:00+03	77600.00
3DEB20	2017-08-01 06:16:00+03	54000.00
3DEBBA	2017-07-09 21:14:00+03	24400.00
3DEC13	2017-08-03 18:10:00+03	23400.00
3DEC3A	2017-07-21 13:27:00+03	139200.00
3DEC40	2017-07-30 18:16:00+03	32800.00
3DEC4F	2017-07-14 14:29:00+03	32800.00
3DEC64	2017-08-02 03:35:00+03	57600.00
3DEC96	2017-07-08 07:11:00+03	50800.00
3DECF6	2017-07-01 20:43:00+03	47100.00
3DED5B	2017-07-17 20:15:00+03	257500.00
3DED7B	2017-07-12 03:15:00+03	31600.00
3DED93	2017-08-09 06:16:00+03	89600.00
3DEDF3	2017-07-14 23:31:00+03	37200.00
3DEDFC	2017-07-12 08:05:00+03	173100.00
3DEE6B	2017-07-30 15:35:00+03	62600.00
3DEE92	2017-07-22 19:13:00+03	28300.00
3DEF06	2017-08-15 09:41:00+03	40100.00
3DEF61	2017-07-18 21:29:00+03	35600.00
3DEF88	2017-07-09 13:29:00+03	136300.00
3DEF90	2017-07-30 22:44:00+03	84300.00
3DF012	2017-08-01 10:22:00+03	92800.00
3DF025	2017-07-18 14:10:00+03	194000.00
3DF031	2017-08-06 02:22:00+03	86600.00
3DF06F	2017-07-16 02:38:00+03	14000.00
3DF099	2017-07-28 21:38:00+03	54000.00
3DF0A0	2017-08-03 03:40:00+03	14800.00
3DF0AD	2017-08-13 12:41:00+03	16400.00
3DF0E5	2017-08-09 05:17:00+03	26000.00
3DF0F8	2017-08-12 01:25:00+03	56000.00
3DF114	2017-07-05 12:36:00+03	6000.00
3DF136	2017-07-22 06:55:00+03	30200.00
3DF17C	2017-07-08 00:14:00+03	96300.00
3DF18D	2017-07-06 23:59:00+03	20200.00
3DF1B8	2017-06-28 12:30:00+03	136500.00
3DF249	2017-07-21 09:47:00+03	26000.00
3DF253	2017-07-07 04:36:00+03	111600.00
3DF2B4	2017-07-04 09:02:00+03	96200.00
3DF2FA	2017-07-16 22:12:00+03	28800.00
3DF32E	2017-07-09 12:00:00+03	83300.00
3DF359	2017-08-09 22:36:00+03	58600.00
3DF372	2017-07-01 01:44:00+03	33100.00
3DF3A4	2017-08-03 15:38:00+03	42800.00
3DF428	2017-08-10 02:32:00+03	21800.00
3DF440	2017-07-30 23:41:00+03	43500.00
3DF499	2017-08-03 17:15:00+03	56000.00
3DF4AC	2017-07-19 23:45:00+03	37900.00
3DF584	2017-07-22 01:46:00+03	199400.00
3DF6FD	2017-07-10 17:22:00+03	56900.00
3DF720	2017-07-30 07:08:00+03	19600.00
3DF790	2017-07-14 16:19:00+03	48500.00
3DF7AA	2017-08-14 10:42:00+03	81600.00
3DF7E1	2017-07-29 14:41:00+03	65900.00
3DF7E2	2017-08-09 23:24:00+03	64800.00
3DF7EB	2017-07-22 04:44:00+03	40100.00
3DF807	2017-08-10 22:29:00+03	62900.00
3DF81A	2017-07-21 16:58:00+03	56600.00
3DF83A	2017-07-24 16:30:00+03	30000.00
3DF859	2017-08-01 05:58:00+03	75600.00
3DF8B7	2017-08-10 18:29:00+03	25100.00
3DF90C	2017-08-10 08:13:00+03	135400.00
3DF9FF	2017-07-26 19:11:00+03	37900.00
3DFA08	2017-08-11 08:15:00+03	115700.00
3DFA0E	2017-08-12 11:11:00+03	10800.00
3DFA6C	2017-08-04 14:03:00+03	273300.00
3DFB4E	2017-08-03 12:28:00+03	56200.00
3DFBB1	2017-08-05 02:57:00+03	70600.00
3DFBB5	2017-07-21 20:10:00+03	419400.00
3DFBC2	2017-07-09 17:58:00+03	12400.00
3DFBF8	2017-07-03 15:59:00+03	45200.00
3DFC7F	2017-07-09 18:44:00+03	145100.00
3DFCB8	2017-07-01 09:05:00+03	25600.00
3DFD02	2017-06-29 04:31:00+03	29600.00
3DFD3A	2017-07-20 06:23:00+03	59300.00
3DFD3C	2017-08-08 02:28:00+03	28700.00
3DFDBF	2017-08-13 04:13:00+03	283100.00
3DFDFF	2017-07-17 05:58:00+03	197600.00
3DFE03	2017-07-15 18:12:00+03	20200.00
3DFE83	2017-08-11 10:24:00+03	13000.00
3DFE8E	2017-07-12 04:43:00+03	64400.00
3DFEC8	2017-07-15 02:27:00+03	155600.00
3DFF13	2017-07-29 08:07:00+03	27200.00
3E009D	2017-08-07 06:59:00+03	123600.00
3E00AC	2017-07-13 04:35:00+03	67000.00
3E00E8	2017-07-19 22:46:00+03	85700.00
3E00EF	2017-08-12 20:39:00+03	38500.00
3E00F0	2017-07-23 20:10:00+03	59800.00
3E0137	2017-07-06 00:01:00+03	28000.00
3E0193	2017-08-15 00:31:00+03	229900.00
3E0199	2017-06-30 23:07:00+03	72300.00
3E01AB	2017-08-01 04:44:00+03	56600.00
3E01AE	2017-07-20 15:35:00+03	56000.00
3E01EF	2017-08-09 14:23:00+03	27200.00
3E01FA	2017-07-21 23:07:00+03	105700.00
3E0216	2017-07-19 09:01:00+03	211000.00
3E0218	2017-07-27 12:19:00+03	94800.00
3E0256	2017-08-03 03:51:00+03	117100.00
3E0290	2017-07-15 01:49:00+03	40400.00
3E029D	2017-07-31 02:52:00+03	27200.00
3E02E0	2017-07-12 05:29:00+03	95700.00
3E02FC	2017-07-16 06:14:00+03	58000.00
3E0358	2017-08-15 07:04:00+03	75200.00
3E03E7	2017-07-06 07:16:00+03	24400.00
3E040C	2017-07-21 00:02:00+03	20400.00
3E0428	2017-07-26 02:37:00+03	65300.00
3E04ED	2017-07-17 14:25:00+03	63400.00
3E05BC	2017-07-17 18:32:00+03	69500.00
3E05C4	2017-07-14 19:02:00+03	28000.00
3E05D5	2017-06-27 20:47:00+03	58400.00
3E0616	2017-07-11 02:58:00+03	16400.00
3E0627	2017-07-27 08:38:00+03	117200.00
3E067F	2017-07-23 11:36:00+03	166100.00
3E071B	2017-08-01 00:43:00+03	7400.00
3E071D	2017-07-29 13:33:00+03	46300.00
3E073F	2017-07-09 22:29:00+03	67600.00
3E078C	2017-08-08 03:24:00+03	174800.00
3E07D2	2017-07-09 11:07:00+03	54400.00
3E07D7	2017-07-11 18:01:00+03	14000.00
3E07FF	2017-07-04 02:02:00+03	52000.00
3E0806	2017-08-05 14:59:00+03	26000.00
3E081F	2017-08-13 19:48:00+03	117500.00
3E0829	2017-07-23 02:31:00+03	23200.00
3E085A	2017-07-07 16:18:00+03	135600.00
3E08BC	2017-08-13 12:40:00+03	62100.00
3E0974	2017-08-08 14:46:00+03	50600.00
3E09A2	2017-07-04 00:03:00+03	112000.00
3E09BE	2017-08-13 13:44:00+03	73100.00
3E09CB	2017-07-16 07:58:00+03	85000.00
3E09D8	2017-07-20 11:23:00+03	172400.00
3E09F7	2017-07-21 23:43:00+03	229300.00
3E0A41	2017-07-13 05:54:00+03	19600.00
3E0A49	2017-07-15 22:13:00+03	28800.00
3E0A7E	2017-07-24 05:10:00+03	8200.00
3E0AA8	2017-07-18 18:58:00+03	46500.00
3E0B72	2017-07-23 07:48:00+03	35200.00
3E0B9C	2017-07-26 13:28:00+03	120400.00
3E0BCA	2017-07-06 19:29:00+03	69500.00
3E0BD5	2017-07-30 19:25:00+03	92800.00
3E0BDC	2017-07-20 03:06:00+03	102100.00
3E0C0C	2017-08-01 01:27:00+03	88200.00
3E0C1E	2017-07-15 20:34:00+03	123000.00
3E0C26	2017-08-02 06:46:00+03	28800.00
3E0C28	2017-08-12 19:28:00+03	19600.00
3E0C36	2017-08-03 18:40:00+03	29800.00
3E0C5B	2017-07-22 21:35:00+03	134200.00
3E0CA3	2017-08-09 04:23:00+03	135600.00
3E0CC9	2017-08-14 05:45:00+03	16400.00
3E0CE5	2017-07-11 08:32:00+03	93900.00
3E0D36	2017-08-10 02:34:00+03	56600.00
3E0E12	2017-08-13 06:17:00+03	258000.00
3E0E96	2017-07-26 04:34:00+03	13600.00
3E0EAC	2017-07-29 05:04:00+03	72400.00
3E0F01	2017-07-12 18:09:00+03	27800.00
3E0F45	2017-08-01 18:40:00+03	72800.00
3E0F7C	2017-08-14 13:39:00+03	29800.00
3E0FD5	2017-07-15 09:55:00+03	235200.00
3E0FEA	2017-08-01 14:07:00+03	66800.00
3E0FFC	2017-07-14 06:05:00+03	112000.00
3E1052	2017-07-02 15:38:00+03	46400.00
3E1103	2017-08-13 16:44:00+03	369000.00
3E111D	2017-07-23 08:27:00+03	44000.00
3E1186	2017-08-01 08:08:00+03	147100.00
3E11D2	2017-07-08 11:16:00+03	96300.00
3E1205	2017-07-31 20:16:00+03	26000.00
3E120C	2017-07-08 15:11:00+03	40600.00
3E1222	2017-08-15 09:30:00+03	118400.00
3E122F	2017-07-22 20:42:00+03	115900.00
3E1232	2017-07-08 21:43:00+03	59800.00
3E1256	2017-08-13 23:29:00+03	8200.00
3E125B	2017-07-11 00:37:00+03	240600.00
3E1312	2017-07-16 20:04:00+03	35600.00
3E1336	2017-07-11 15:44:00+03	87500.00
3E1349	2017-08-15 17:34:00+03	23200.00
3E13BB	2017-07-15 02:57:00+03	29600.00
3E1423	2017-07-20 15:07:00+03	542200.00
3E1434	2017-08-03 10:13:00+03	57400.00
3E1488	2017-06-30 05:46:00+03	20900.00
3E14C3	2017-07-31 15:59:00+03	266400.00
3E150E	2017-08-04 08:40:00+03	31400.00
3E15BC	2017-07-23 16:22:00+03	26000.00
3E161A	2017-07-16 20:12:00+03	24400.00
3E161D	2017-08-05 01:43:00+03	38600.00
3E16A2	2017-07-02 09:21:00+03	103000.00
3E16E9	2017-08-01 04:21:00+03	133100.00
3E1749	2017-07-29 20:52:00+03	33600.00
3E17EF	2017-08-11 17:29:00+03	64800.00
3E1886	2017-07-24 21:36:00+03	56000.00
3E1988	2017-07-04 04:39:00+03	15400.00
3E198B	2017-07-20 20:46:00+03	107500.00
3E19BC	2017-08-11 21:19:00+03	258400.00
3E19CD	2017-08-08 14:20:00+03	15000.00
3E19E8	2017-08-14 05:54:00+03	23200.00
3E1A5B	2017-07-11 11:22:00+03	24400.00
3E1AD8	2017-07-12 15:33:00+03	7200.00
3E1AF9	2017-08-01 12:20:00+03	41200.00
3E1B15	2017-07-25 11:49:00+03	112600.00
3E1B2E	2017-08-09 18:21:00+03	46000.00
3E1B56	2017-07-12 02:48:00+03	56000.00
3E1B58	2017-07-19 03:51:00+03	38400.00
3E1B74	2017-06-26 05:28:00+03	66600.00
3E1BA1	2017-07-22 15:51:00+03	330500.00
3E1BB7	2017-08-06 10:19:00+03	68000.00
3E1BCF	2017-07-18 06:20:00+03	124200.00
3E1BE0	2017-08-06 08:23:00+03	7400.00
3E1BF3	2017-07-02 22:33:00+03	19800.00
3E1BFF	2017-07-01 08:30:00+03	23200.00
3E1C8A	2017-07-27 18:17:00+03	21400.00
3E1CBD	2017-07-10 18:34:00+03	62700.00
3E1CE8	2017-07-09 02:38:00+03	23200.00
3E1D29	2017-07-04 14:47:00+03	58700.00
3E1D44	2017-08-11 17:52:00+03	115900.00
3E1D4F	2017-08-02 00:26:00+03	100300.00
3E1D55	2017-07-27 07:03:00+03	238700.00
3E1D70	2017-07-02 11:57:00+03	47000.00
3E1DC1	2017-08-03 22:08:00+03	28000.00
3E1DC4	2017-07-19 16:08:00+03	99200.00
3E1DE4	2017-08-07 13:00:00+03	57600.00
3E1E1C	2017-07-24 07:41:00+03	97700.00
3E1E3B	2017-07-24 07:07:00+03	24300.00
3E1E42	2017-07-12 01:03:00+03	70200.00
3E1E4C	2017-08-05 18:36:00+03	64700.00
3E1E6D	2017-07-23 22:15:00+03	79300.00
3E1E7C	2017-07-03 20:37:00+03	112000.00
3E1EA2	2017-07-02 06:07:00+03	59200.00
3E1EB9	2017-07-18 01:51:00+03	127300.00
3E1F18	2017-07-31 16:02:00+03	187800.00
3E1FBE	2017-07-07 09:11:00+03	56600.00
3E1FDE	2017-08-01 06:29:00+03	136200.00
3E1FEF	2017-08-12 10:46:00+03	21000.00
3E2010	2017-07-18 07:23:00+03	11000.00
3E201E	2017-08-11 17:40:00+03	68200.00
3E2087	2017-08-02 19:24:00+03	33600.00
3E209A	2017-07-13 20:47:00+03	4000.00
3E2139	2017-07-03 05:19:00+03	54300.00
3E21BC	2017-07-26 12:37:00+03	677700.00
3E21D7	2017-07-08 05:45:00+03	45600.00
3E229A	2017-07-22 20:23:00+03	185300.00
3E22F3	2017-07-12 13:31:00+03	542200.00
3E231A	2017-07-09 14:11:00+03	24600.00
3E2333	2017-07-23 06:07:00+03	51800.00
3E237C	2017-07-02 12:18:00+03	198600.00
3E239F	2017-07-12 03:59:00+03	56000.00
3E23C7	2017-08-01 06:01:00+03	55800.00
3E23E4	2017-07-03 12:36:00+03	11300.00
3E242A	2017-07-15 02:53:00+03	56100.00
3E244B	2017-07-20 06:42:00+03	19200.00
3E249F	2017-07-04 17:37:00+03	73600.00
3E2517	2017-08-03 02:52:00+03	89700.00
3E251C	2017-07-27 09:59:00+03	136100.00
3E254E	2017-07-14 05:18:00+03	18000.00
3E255B	2017-08-02 20:55:00+03	207200.00
3E2562	2017-08-13 09:05:00+03	56800.00
3E25C9	2017-07-26 23:34:00+03	3400.00
3E263A	2017-08-04 11:45:00+03	31600.00
3E2642	2017-08-13 23:54:00+03	147800.00
3E265B	2017-07-15 14:00:00+03	38400.00
3E2667	2017-07-18 23:41:00+03	55800.00
3E2689	2017-08-03 19:10:00+03	26000.00
3E26F6	2017-08-03 14:20:00+03	6700.00
3E2791	2017-07-13 16:15:00+03	114800.00
3E286F	2017-08-04 10:13:00+03	155600.00
3E28DF	2017-07-24 01:18:00+03	43600.00
3E2909	2017-07-09 01:26:00+03	75600.00
3E294C	2017-07-08 18:36:00+03	81500.00
3E298E	2017-08-07 04:43:00+03	62900.00
3E29F1	2017-07-09 17:35:00+03	18000.00
3E29F7	2017-07-25 07:08:00+03	387400.00
3E29F9	2017-07-16 09:23:00+03	52400.00
3E2A26	2017-08-04 20:22:00+03	83200.00
3E2A27	2017-06-30 21:57:00+03	265600.00
3E2A43	2017-07-16 10:59:00+03	112000.00
3E2A6E	2017-08-08 22:42:00+03	357600.00
3E2ABB	2017-07-25 12:03:00+03	75200.00
3E2AC6	2017-07-17 21:26:00+03	22600.00
3E2ADE	2017-07-14 14:44:00+03	84000.00
3E2B1F	2017-08-06 13:06:00+03	55800.00
3E2B2E	2017-08-04 18:43:00+03	199700.00
3E2B7F	2017-08-13 00:49:00+03	218200.00
3E2BDF	2017-07-19 11:13:00+03	35700.00
3E2C0A	2017-07-29 04:54:00+03	99200.00
3E2C14	2017-08-10 17:37:00+03	44700.00
3E2C1F	2017-08-08 04:18:00+03	66600.00
3E2C7D	2017-08-02 17:45:00+03	40000.00
3E2CA1	2017-07-23 14:03:00+03	46400.00
3E2D2F	2017-07-13 06:00:00+03	36200.00
3E2D6F	2017-06-30 23:02:00+03	213200.00
3E2D88	2017-07-17 02:27:00+03	41200.00
3E2D89	2017-08-12 19:20:00+03	26000.00
3E2E17	2017-07-28 09:10:00+03	36600.00
3E2E25	2017-07-22 15:24:00+03	37900.00
3E2E38	2017-07-06 01:54:00+03	60400.00
3E2EF8	2017-07-20 13:59:00+03	28800.00
3E2F66	2017-07-22 23:49:00+03	173200.00
3E2F87	2017-08-07 23:23:00+03	93700.00
3E2FCC	2017-07-06 02:11:00+03	75600.00
3E3031	2017-07-31 03:07:00+03	27600.00
3E303C	2017-07-21 02:22:00+03	37200.00
3E3068	2017-07-24 19:37:00+03	6700.00
3E308D	2017-08-08 23:04:00+03	23200.00
3E30FC	2017-07-14 08:12:00+03	34000.00
3E318F	2017-07-16 09:16:00+03	99300.00
3E32A9	2017-08-09 15:07:00+03	71900.00
3E32AA	2017-07-09 02:23:00+03	23600.00
3E3329	2017-07-21 04:06:00+03	16400.00
3E332F	2017-08-11 21:16:00+03	78600.00
3E333D	2017-07-07 16:49:00+03	33300.00
3E33AA	2017-07-21 07:55:00+03	36000.00
3E3422	2017-07-23 13:51:00+03	75300.00
3E346A	2017-08-07 19:26:00+03	40600.00
3E3473	2017-07-18 13:06:00+03	135200.00
3E34B1	2017-07-23 16:08:00+03	83000.00
3E3504	2017-07-06 01:12:00+03	31600.00
3E3540	2017-07-14 12:32:00+03	32700.00
3E3554	2017-07-22 10:10:00+03	31300.00
3E357B	2017-07-13 03:22:00+03	398500.00
3E3583	2017-08-06 20:25:00+03	57800.00
3E35B6	2017-08-13 21:01:00+03	43900.00
3E35BE	2017-08-04 15:57:00+03	99200.00
3E35C3	2017-08-10 22:52:00+03	65900.00
3E367D	2017-08-13 08:10:00+03	16400.00
3E36B7	2017-07-15 18:09:00+03	6000.00
3E36DD	2017-08-06 09:22:00+03	52000.00
3E36E0	2017-07-12 19:39:00+03	101200.00
3E3747	2017-07-21 17:46:00+03	258400.00
3E3775	2017-07-25 03:54:00+03	178800.00
3E37BD	2017-07-14 13:31:00+03	119800.00
3E37F3	2017-08-12 22:05:00+03	28000.00
3E37FC	2017-08-13 14:03:00+03	69900.00
3E384C	2017-08-08 15:04:00+03	83400.00
3E3850	2017-07-29 09:45:00+03	47000.00
3E385F	2017-07-04 22:21:00+03	132800.00
3E3891	2017-07-21 02:52:00+03	16400.00
3E38E5	2017-07-06 10:21:00+03	113200.00
3E38FA	2017-07-15 04:38:00+03	30800.00
3E39F4	2017-07-10 01:31:00+03	270800.00
3E3A0C	2017-07-11 16:57:00+03	24300.00
3E3A14	2017-06-30 06:03:00+03	96200.00
3E3A50	2017-07-14 15:32:00+03	40300.00
3E3A65	2017-08-04 11:06:00+03	89600.00
3E3B27	2017-07-29 08:23:00+03	38700.00
3E3B60	2017-07-28 03:19:00+03	16400.00
3E3BBE	2017-08-11 21:53:00+03	46300.00
3E3C35	2017-07-08 13:28:00+03	40400.00
3E3D40	2017-07-22 01:49:00+03	128400.00
3E3D58	2017-07-31 01:20:00+03	28800.00
3E3E73	2017-07-10 06:25:00+03	23200.00
3E3E99	2017-08-07 14:35:00+03	84300.00
3E3E9E	2017-07-20 20:55:00+03	40000.00
3E3EF7	2017-07-22 17:31:00+03	14000.00
3E3F2A	2017-07-07 13:03:00+03	6000.00
3E3F86	2017-07-26 23:34:00+03	21200.00
3E3FAF	2017-06-30 00:43:00+03	73300.00
3E404A	2017-07-20 00:09:00+03	24600.00
3E40C3	2017-07-29 00:22:00+03	48800.00
3E40CD	2017-07-23 18:22:00+03	23600.00
3E412F	2017-07-12 23:07:00+03	67600.00
3E4138	2017-07-19 09:41:00+03	14000.00
3E4141	2017-07-06 05:51:00+03	108900.00
3E4143	2017-07-13 00:48:00+03	61800.00
3E419A	2017-07-28 07:41:00+03	43200.00
3E41C2	2017-07-07 07:51:00+03	61800.00
3E41D3	2017-08-10 09:24:00+03	47000.00
3E41DC	2017-07-25 10:02:00+03	56000.00
3E41E0	2017-07-05 20:13:00+03	64900.00
3E42B9	2017-08-13 06:25:00+03	139400.00
3E42C2	2017-07-06 10:29:00+03	152900.00
3E42FD	2017-07-27 07:08:00+03	35600.00
3E430E	2017-07-24 12:00:00+03	56600.00
3E4332	2017-07-29 15:07:00+03	173900.00
3E433A	2017-08-07 14:00:00+03	34100.00
3E4390	2017-07-20 18:24:00+03	185600.00
3E43B1	2017-08-11 08:17:00+03	93400.00
3E43DE	2017-08-02 10:07:00+03	37900.00
3E442A	2017-07-30 14:02:00+03	52800.00
3E445A	2017-08-06 12:08:00+03	31600.00
3E445E	2017-07-16 12:30:00+03	21000.00
3E4461	2017-06-30 13:02:00+03	43000.00
3E449B	2017-08-14 05:26:00+03	67300.00
3E4520	2017-07-09 22:01:00+03	24500.00
3E4535	2017-08-09 19:38:00+03	86500.00
3E45AF	2017-08-02 20:00:00+03	55800.00
3E4649	2017-08-08 05:15:00+03	16400.00
3E46D2	2017-07-11 12:57:00+03	56000.00
3E473C	2017-07-27 13:46:00+03	104200.00
3E475C	2017-08-04 11:51:00+03	64700.00
3E47B9	2017-08-14 21:01:00+03	43900.00
3E47D9	2017-07-29 02:28:00+03	63700.00
3E485F	2017-08-14 08:58:00+03	28000.00
3E487D	2017-07-14 11:45:00+03	28000.00
3E4895	2017-07-31 18:47:00+03	17200.00
3E48C1	2017-08-06 18:36:00+03	31600.00
3E48C5	2017-07-22 06:44:00+03	290500.00
3E48C8	2017-07-21 08:23:00+03	44200.00
3E4937	2017-08-05 17:22:00+03	65500.00
3E4953	2017-07-18 02:39:00+03	67900.00
3E4964	2017-08-14 21:35:00+03	136500.00
3E498E	2017-08-13 19:55:00+03	30600.00
3E4A04	2017-08-14 13:35:00+03	37700.00
3E4A19	2017-07-30 00:55:00+03	201400.00
3E4A81	2017-07-20 15:15:00+03	203100.00
3E4A82	2017-07-13 16:40:00+03	46400.00
3E4A8E	2017-08-09 05:17:00+03	30400.00
3E4B33	2017-07-15 06:32:00+03	23400.00
3E4B3C	2017-08-05 23:51:00+03	56900.00
3E4B4C	2017-07-16 04:44:00+03	143100.00
3E4B5F	2017-06-30 18:08:00+03	266400.00
3E4B60	2017-07-22 19:59:00+03	28800.00
3E4BA0	2017-08-05 13:33:00+03	13400.00
3E4C08	2017-08-03 23:56:00+03	13400.00
3E4C23	2017-07-13 21:40:00+03	23400.00
3E4CAA	2017-07-07 03:54:00+03	195300.00
3E4E1C	2017-07-03 04:44:00+03	51900.00
3E4E1E	2017-08-15 01:08:00+03	25100.00
3E4E5C	2017-06-28 18:34:00+03	83000.00
3E4EA1	2017-07-26 06:28:00+03	40600.00
3E4F4B	2017-07-22 18:04:00+03	56000.00
3E4FFF	2017-07-07 09:24:00+03	271200.00
3E5003	2017-08-03 13:28:00+03	14400.00
3E50A7	2017-07-19 06:07:00+03	46200.00
3E50AD	2017-07-31 11:54:00+03	28000.00
3E50DB	2017-08-14 18:20:00+03	103900.00
3E50E5	2017-07-05 16:01:00+03	136200.00
3E5118	2017-08-02 14:58:00+03	29400.00
3E5129	2017-07-22 15:36:00+03	58200.00
3E5157	2017-07-03 15:03:00+03	28800.00
3E51C3	2017-07-10 23:24:00+03	78600.00
3E51D8	2017-07-26 16:06:00+03	58200.00
3E521C	2017-07-24 11:21:00+03	81900.00
3E52D7	2017-08-13 06:04:00+03	12600.00
3E5309	2017-07-18 15:26:00+03	76900.00
3E530F	2017-07-15 11:40:00+03	265700.00
3E531A	2017-07-26 18:43:00+03	36000.00
3E5332	2017-07-30 17:53:00+03	286700.00
3E5339	2017-08-04 11:21:00+03	111600.00
3E53BD	2017-07-07 00:31:00+03	199300.00
3E53F6	2017-07-09 23:58:00+03	28800.00
3E5407	2017-07-31 05:03:00+03	40000.00
3E543E	2017-07-23 02:36:00+03	103500.00
3E544F	2017-08-05 13:55:00+03	14000.00
3E5482	2017-08-11 06:13:00+03	55800.00
3E54E4	2017-08-13 09:48:00+03	244800.00
3E54EB	2017-08-04 16:05:00+03	47400.00
3E555F	2017-07-07 07:35:00+03	25000.00
3E556C	2017-07-23 10:34:00+03	97000.00
3E55EA	2017-07-29 14:53:00+03	73200.00
3E55FA	2017-08-07 21:59:00+03	60000.00
3E5633	2017-08-01 11:54:00+03	48400.00
3E5636	2017-08-14 00:55:00+03	283100.00
3E564E	2017-08-02 11:29:00+03	248300.00
3E5659	2017-07-26 16:16:00+03	40800.00
3E5686	2017-08-13 08:24:00+03	20600.00
3E568F	2017-07-10 03:15:00+03	12400.00
3E5696	2017-07-21 07:51:00+03	20600.00
3E56A2	2017-08-13 17:08:00+03	116400.00
3E56B4	2017-07-24 15:37:00+03	86800.00
3E56BD	2017-07-29 05:38:00+03	95200.00
3E56D2	2017-07-05 15:59:00+03	19600.00
3E572A	2017-07-15 04:12:00+03	83700.00
3E574B	2017-07-01 22:59:00+03	80400.00
3E5764	2017-08-05 12:15:00+03	56600.00
3E5774	2017-08-02 20:01:00+03	86600.00
3E57AC	2017-07-07 08:02:00+03	70400.00
3E57DC	2017-07-22 23:58:00+03	133100.00
3E582B	2017-07-12 11:59:00+03	43900.00
3E5852	2017-07-01 19:33:00+03	93900.00
3E5864	2017-07-16 22:13:00+03	27200.00
3E586E	2017-07-02 22:59:00+03	117800.00
3E589D	2017-07-22 14:26:00+03	103800.00
3E58AD	2017-07-09 02:48:00+03	79800.00
3E590D	2017-07-18 23:17:00+03	25400.00
3E5919	2017-07-12 05:10:00+03	73200.00
3E5929	2017-07-30 19:29:00+03	26700.00
3E595F	2017-06-26 09:36:00+03	312900.00
3E5997	2017-07-16 10:27:00+03	35800.00
3E59BB	2017-07-08 16:03:00+03	116400.00
3E59F6	2017-07-15 05:46:00+03	22000.00
3E5A4C	2017-07-28 10:29:00+03	62100.00
3E5A82	2017-08-06 07:59:00+03	42400.00
3E5ACD	2017-07-11 00:58:00+03	114700.00
3E5B18	2017-07-28 18:30:00+03	42600.00
3E5B4D	2017-08-14 02:31:00+03	28800.00
3E5B7F	2017-07-07 11:51:00+03	56000.00
3E5B9B	2017-08-03 05:19:00+03	29100.00
3E5C52	2017-07-22 04:27:00+03	38200.00
3E5CCA	2017-07-06 23:24:00+03	258400.00
3E5CFE	2017-06-29 11:49:00+03	56600.00
3E5D25	2017-08-13 02:01:00+03	24400.00
3E5D77	2017-07-16 02:09:00+03	45200.00
3E5E02	2017-08-10 20:17:00+03	58000.00
3E5E19	2017-07-03 03:42:00+03	24700.00
3E5E1F	2017-07-24 11:25:00+03	55800.00
3E5E5C	2017-08-04 14:36:00+03	36200.00
3E5E73	2017-08-12 10:42:00+03	67200.00
3E5EA5	2017-07-24 05:09:00+03	35800.00
3E5EA7	2017-08-13 03:49:00+03	62000.00
3E5EE9	2017-07-19 08:53:00+03	62600.00
3E5F35	2017-07-20 09:18:00+03	39300.00
3E5F4C	2017-07-05 09:12:00+03	51900.00
3E5FEF	2017-08-02 04:53:00+03	265600.00
3E6022	2017-07-05 21:00:00+03	6700.00
3E6038	2017-08-11 13:49:00+03	62000.00
3E6080	2017-07-06 05:21:00+03	120400.00
3E6081	2017-08-07 21:19:00+03	168000.00
3E60C8	2017-07-14 01:13:00+03	58000.00
3E6151	2017-07-30 21:31:00+03	140300.00
3E6221	2017-08-03 10:22:00+03	43900.00
3E6243	2017-07-06 11:57:00+03	117000.00
3E6270	2017-07-07 08:32:00+03	34600.00
3E6280	2017-07-11 02:41:00+03	47400.00
3E62FF	2017-08-09 18:42:00+03	57300.00
3E6325	2017-07-14 16:33:00+03	21400.00
3E638E	2017-08-09 09:57:00+03	34000.00
3E6397	2017-07-10 13:20:00+03	40800.00
3E643A	2017-07-02 11:26:00+03	52000.00
3E644D	2017-08-05 16:03:00+03	27800.00
3E645F	2017-08-15 00:14:00+03	75700.00
3E649A	2017-07-25 21:44:00+03	54000.00
3E652C	2017-07-10 12:14:00+03	14000.00
3E662E	2017-07-30 23:52:00+03	26000.00
3E6644	2017-07-30 20:31:00+03	163600.00
3E664C	2017-08-05 14:47:00+03	113700.00
3E6661	2017-08-01 22:07:00+03	155600.00
3E6666	2017-07-18 14:29:00+03	26000.00
3E669E	2017-08-10 17:27:00+03	43900.00
3E66CB	2017-08-03 23:18:00+03	69200.00
3E6731	2017-08-10 17:23:00+03	10600.00
3E6746	2017-07-26 19:46:00+03	24400.00
3E677D	2017-07-12 00:48:00+03	90400.00
3E67BD	2017-08-13 14:29:00+03	48500.00
3E6828	2017-07-11 04:31:00+03	56100.00
3E6839	2017-07-04 03:39:00+03	16400.00
3E690E	2017-07-05 05:16:00+03	19000.00
3E691B	2017-08-12 21:18:00+03	204700.00
3E692E	2017-07-31 16:43:00+03	21800.00
3E6990	2017-07-25 19:59:00+03	23600.00
3E6A03	2017-07-29 09:46:00+03	250600.00
3E6A99	2017-08-03 01:53:00+03	22000.00
3E6AB9	2017-07-04 03:33:00+03	96800.00
3E6AC6	2017-07-18 02:53:00+03	95200.00
3E6ACF	2017-07-29 15:32:00+03	16600.00
3E6ADA	2017-08-14 06:44:00+03	46300.00
3E6ADC	2017-08-05 18:03:00+03	95700.00
3E6B16	2017-07-29 22:05:00+03	59200.00
3E6BFA	2017-07-26 07:03:00+03	81800.00
3E6C3E	2017-08-08 14:00:00+03	24700.00
3E6C4B	2017-08-15 04:12:00+03	25600.00
3E6C5C	2017-08-12 14:39:00+03	7400.00
3E6D0A	2017-07-11 01:34:00+03	19600.00
3E6DAC	2017-08-14 22:01:00+03	123500.00
3E6DCC	2017-07-17 00:17:00+03	6700.00
3E6DE5	2017-08-02 01:10:00+03	111600.00
3E6E67	2017-07-07 13:47:00+03	28800.00
3E6E94	2017-07-17 01:28:00+03	135400.00
3E6EE8	2017-07-23 14:12:00+03	89700.00
3E6F06	2017-07-23 07:05:00+03	32800.00
3E6F7F	2017-07-28 00:25:00+03	93400.00
3E6FF6	2017-07-20 19:01:00+03	26000.00
3E7021	2017-07-14 12:02:00+03	148800.00
3E7047	2017-08-07 01:04:00+03	24400.00
3E7052	2017-07-08 00:14:00+03	266400.00
3E705D	2017-07-24 17:15:00+03	29200.00
3E70C2	2017-08-14 14:49:00+03	44000.00
3E7104	2017-07-07 08:53:00+03	44000.00
3E716B	2017-08-05 02:43:00+03	30200.00
3E7185	2017-07-15 00:48:00+03	35600.00
3E71A0	2017-08-10 12:54:00+03	123000.00
3E71A3	2017-06-27 04:33:00+03	59000.00
3E71BA	2017-07-08 02:04:00+03	128300.00
3E71BE	2017-07-21 05:32:00+03	47400.00
3E720F	2017-07-19 04:09:00+03	176800.00
3E7224	2017-08-07 07:25:00+03	31400.00
3E7250	2017-07-25 15:31:00+03	47400.00
3E7256	2017-07-26 19:23:00+03	182300.00
3E72AE	2017-07-08 10:24:00+03	13200.00
3E72B5	2017-08-08 20:02:00+03	31600.00
3E72B8	2017-08-10 23:46:00+03	137400.00
3E7300	2017-07-30 04:27:00+03	40100.00
3E7387	2017-07-26 05:59:00+03	61400.00
3E73C3	2017-07-01 14:48:00+03	66600.00
3E7424	2017-07-29 14:47:00+03	57500.00
3E74D4	2017-07-21 07:44:00+03	38600.00
3E74E2	2017-08-10 11:21:00+03	66600.00
3E7595	2017-07-21 14:41:00+03	20400.00
3E762E	2017-07-30 23:29:00+03	37900.00
3E7632	2017-07-27 22:56:00+03	204200.00
3E7643	2017-07-11 12:15:00+03	72200.00
3E7666	2017-07-15 05:41:00+03	49600.00
3E7684	2017-07-02 14:18:00+03	46300.00
3E76A3	2017-07-09 06:55:00+03	56000.00
3E772F	2017-06-28 06:51:00+03	132800.00
3E777A	2017-08-09 11:43:00+03	136000.00
3E7823	2017-07-03 06:59:00+03	36200.00
3E788C	2017-07-27 21:14:00+03	29600.00
3E795D	2017-07-20 19:44:00+03	37100.00
3E7980	2017-08-12 20:30:00+03	42400.00
3E79A3	2017-07-06 12:39:00+03	51600.00
3E7A5E	2017-07-30 23:58:00+03	151300.00
3E7A61	2017-07-31 06:35:00+03	182000.00
3E7A8F	2017-07-03 14:11:00+03	67700.00
3E7ABA	2017-07-25 05:58:00+03	43200.00
3E7ABB	2017-07-27 19:55:00+03	35600.00
3E7B17	2017-08-15 17:43:00+03	36000.00
3E7B1C	2017-07-19 08:50:00+03	44000.00
3E7B68	2017-07-24 17:00:00+03	32200.00
3E7B8C	2017-08-14 14:50:00+03	56300.00
3E7B90	2017-07-16 20:51:00+03	229300.00
3E7BB0	2017-07-16 04:32:00+03	62600.00
3E7BBD	2017-07-19 21:42:00+03	46400.00
3E7BE0	2017-07-05 14:06:00+03	37100.00
3E7BF9	2017-07-28 09:59:00+03	56000.00
3E7C13	2017-07-29 21:29:00+03	25200.00
3E7C63	2017-07-23 13:48:00+03	95000.00
3E7CC7	2017-06-28 12:19:00+03	59300.00
3E7D28	2017-07-31 11:37:00+03	150600.00
3E7DAB	2017-07-14 20:49:00+03	6000.00
3E7DBC	2017-07-17 18:19:00+03	28000.00
3E7DBF	2017-08-08 17:32:00+03	28000.00
3E7E8D	2017-07-06 15:02:00+03	72400.00
3E7EF9	2017-07-03 13:40:00+03	47400.00
3E7F15	2017-07-24 16:16:00+03	75300.00
3E7FA2	2017-08-10 04:54:00+03	106900.00
3E7FAB	2017-07-08 21:27:00+03	85000.00
3E7FC2	2017-07-11 16:51:00+03	35800.00
3E7FC7	2017-07-08 11:44:00+03	97700.00
3E7FEE	2017-07-15 08:03:00+03	56900.00
3E801F	2017-07-30 02:46:00+03	188000.00
3E8042	2017-08-03 19:23:00+03	141600.00
3E8069	2017-07-10 07:35:00+03	69900.00
3E8083	2017-07-21 19:41:00+03	103800.00
3E80A0	2017-07-17 12:44:00+03	34000.00
3E80CC	2017-07-08 22:50:00+03	142400.00
3E80DE	2017-07-12 21:44:00+03	115600.00
3E8179	2017-08-07 02:40:00+03	21600.00
3E817E	2017-08-06 11:50:00+03	56600.00
3E81B8	2017-07-06 20:59:00+03	28800.00
3E81E4	2017-07-02 03:13:00+03	28000.00
3E81E9	2017-08-05 16:59:00+03	16400.00
3E81F7	2017-07-15 12:26:00+03	55600.00
3E821A	2017-08-08 07:11:00+03	22600.00
3E821E	2017-08-08 23:46:00+03	269400.00
3E821F	2017-07-07 19:45:00+03	6700.00
3E8224	2017-07-14 21:46:00+03	32700.00
3E825D	2017-07-25 04:45:00+03	48500.00
3E8269	2017-07-06 21:57:00+03	61800.00
3E8278	2017-07-08 08:56:00+03	61200.00
3E829C	2017-07-13 19:15:00+03	51900.00
3E831A	2017-07-06 22:23:00+03	49300.00
3E834D	2017-08-09 13:33:00+03	399600.00
3E8352	2017-07-23 17:50:00+03	66600.00
3E8354	2017-08-15 06:51:00+03	83100.00
3E83D7	2017-07-06 23:45:00+03	86300.00
3E83F9	2017-08-09 05:00:00+03	125200.00
3E8418	2017-08-03 04:50:00+03	69500.00
3E8494	2017-08-14 00:57:00+03	24400.00
3E8498	2017-07-30 22:10:00+03	98400.00
3E84BC	2017-08-06 04:21:00+03	65000.00
3E84C3	2017-08-02 11:19:00+03	26800.00
3E8515	2017-08-05 13:28:00+03	92800.00
3E855A	2017-07-05 07:23:00+03	136600.00
3E85AD	2017-08-13 04:32:00+03	61600.00
3E85DC	2017-07-22 03:41:00+03	46300.00
3E85F9	2017-07-16 02:33:00+03	55800.00
3E85FF	2017-08-11 20:06:00+03	39200.00
3E8684	2017-07-31 05:47:00+03	6000.00
3E86C9	2017-07-11 01:51:00+03	27200.00
3E86EA	2017-08-01 04:49:00+03	28000.00
3E8719	2017-07-07 09:33:00+03	6800.00
3E875C	2017-07-25 03:36:00+03	134400.00
3E8764	2017-07-08 16:00:00+03	25600.00
3E87CC	2017-08-07 13:25:00+03	196000.00
3E87CD	2017-07-26 03:02:00+03	24400.00
3E8842	2017-08-13 21:13:00+03	54000.00
3E8860	2017-07-22 14:16:00+03	47000.00
3E88DC	2017-07-17 09:48:00+03	170300.00
3E89A6	2017-07-18 18:33:00+03	118000.00
3E89AA	2017-07-14 06:19:00+03	46400.00
3E89E8	2017-07-30 19:49:00+03	133200.00
3E8B59	2017-07-13 06:47:00+03	28000.00
3E8B6A	2017-07-08 06:09:00+03	80400.00
3E8BED	2017-07-03 15:50:00+03	111600.00
3E8C1D	2017-07-09 13:38:00+03	25800.00
3E8C72	2017-07-07 15:36:00+03	49500.00
3E8C82	2017-07-22 12:53:00+03	37100.00
3E8C96	2017-07-02 04:53:00+03	134700.00
3E8CAE	2017-07-09 04:50:00+03	173600.00
3E8CE6	2017-07-14 12:40:00+03	74400.00
3E8CF7	2017-07-04 01:11:00+03	24000.00
3E8CFC	2017-07-19 00:30:00+03	63200.00
3E8D0D	2017-07-21 07:37:00+03	24400.00
3E8D39	2017-07-27 11:03:00+03	181000.00
3E8D40	2017-07-20 09:12:00+03	37700.00
3E8D5E	2017-07-16 10:36:00+03	46000.00
3E8DBB	2017-06-30 16:11:00+03	28800.00
3E8E08	2017-07-21 03:40:00+03	12400.00
3E8E8B	2017-07-13 08:25:00+03	291500.00
3E8EB7	2017-08-06 10:12:00+03	20400.00
3E8EBA	2017-07-30 07:48:00+03	81700.00
3E8F30	2017-07-26 03:30:00+03	48100.00
3E8F51	2017-07-20 17:02:00+03	14700.00
3E8F59	2017-07-22 07:33:00+03	406100.00
3E8F88	2017-07-29 08:27:00+03	155500.00
3E8FCA	2017-07-16 18:16:00+03	14800.00
3E9036	2017-07-10 10:06:00+03	40000.00
3E9042	2017-07-26 05:34:00+03	333600.00
3E90A3	2017-07-27 23:39:00+03	84500.00
3E9108	2017-08-09 06:36:00+03	147200.00
3E9128	2017-07-10 14:30:00+03	55800.00
3E9228	2017-07-08 15:20:00+03	124200.00
3E92B1	2017-08-13 06:20:00+03	26800.00
3E931C	2017-08-12 12:25:00+03	43200.00
3E9329	2017-08-01 23:13:00+03	11300.00
3E936E	2017-07-15 11:31:00+03	56000.00
3E9402	2017-07-08 03:36:00+03	40800.00
3E94A2	2017-07-26 18:12:00+03	81700.00
3E9550	2017-07-04 01:42:00+03	43700.00
3E9558	2017-07-05 12:31:00+03	26700.00
3E9596	2017-07-28 06:34:00+03	13600.00
3E95B7	2017-08-13 00:31:00+03	245400.00
3E95FB	2017-07-21 01:44:00+03	30400.00
3E9602	2017-07-16 07:04:00+03	28800.00
3E97AD	2017-08-02 01:33:00+03	80000.00
3E97CC	2017-08-13 14:06:00+03	62400.00
3E9805	2017-07-01 10:47:00+03	114800.00
3E9834	2017-08-05 00:02:00+03	96400.00
3E9886	2017-07-03 23:01:00+03	26200.00
3E98AD	2017-08-06 12:17:00+03	25200.00
3E98EE	2017-08-14 20:54:00+03	23400.00
3E996B	2017-07-15 11:27:00+03	87400.00
3E996F	2017-07-24 17:34:00+03	46400.00
3E9A26	2017-07-04 02:51:00+03	57300.00
3E9A59	2017-08-10 07:44:00+03	16400.00
3E9A93	2017-07-23 19:57:00+03	34400.00
3E9ABA	2017-07-21 17:19:00+03	57800.00
3E9AFD	2017-07-09 23:50:00+03	83400.00
3E9BDE	2017-07-23 14:51:00+03	149000.00
3E9BE5	2017-07-22 12:37:00+03	113200.00
3E9C51	2017-07-30 01:32:00+03	98400.00
3E9C58	2017-08-08 13:43:00+03	111600.00
3E9C67	2017-08-14 11:44:00+03	46000.00
3E9C6F	2017-07-04 23:49:00+03	79300.00
3E9C87	2017-07-14 06:22:00+03	206400.00
3E9CE7	2017-08-03 12:43:00+03	12600.00
3E9D66	2017-07-16 08:53:00+03	121400.00
3E9D71	2017-08-06 08:19:00+03	265200.00
3E9D78	2017-07-26 22:12:00+03	61800.00
3E9D82	2017-07-22 06:58:00+03	147700.00
3E9E0C	2017-08-11 00:11:00+03	66600.00
3E9E1F	2017-08-04 15:26:00+03	114800.00
3E9E4B	2017-08-03 11:30:00+03	59200.00
3E9E6A	2017-07-03 06:16:00+03	99200.00
3E9EB4	2017-07-29 09:36:00+03	85700.00
3E9EDC	2017-07-11 11:16:00+03	40100.00
3E9F2D	2017-07-10 05:17:00+03	64600.00
3E9FCE	2017-06-30 13:53:00+03	83000.00
3E9FDE	2017-08-08 14:10:00+03	66600.00
3EA04E	2017-08-05 12:52:00+03	72400.00
3EA0B4	2017-08-15 01:02:00+03	21400.00
3EA185	2017-07-25 23:44:00+03	56700.00
3EA1B2	2017-07-10 14:10:00+03	48800.00
3EA1BC	2017-08-01 10:39:00+03	65900.00
3EA1D4	2017-08-11 10:46:00+03	199000.00
3EA1E7	2017-07-18 13:40:00+03	36200.00
3EA1F1	2017-08-14 09:32:00+03	161400.00
3EA207	2017-07-25 06:15:00+03	332700.00
3EA25E	2017-07-05 19:07:00+03	72400.00
3EA279	2017-08-05 15:43:00+03	28000.00
3EA29E	2017-07-30 12:41:00+03	90800.00
3EA352	2017-07-28 16:42:00+03	164700.00
3EA357	2017-07-12 04:10:00+03	306200.00
3EA36E	2017-07-24 11:28:00+03	193400.00
3EA374	2017-07-23 14:27:00+03	20600.00
3EA4DC	2017-07-11 22:57:00+03	102100.00
3EA561	2017-08-02 07:18:00+03	136200.00
3EA59A	2017-07-09 06:30:00+03	265600.00
3EA5D2	2017-07-18 00:09:00+03	149500.00
3EA62B	2017-07-04 17:37:00+03	125400.00
3EA655	2017-08-03 02:22:00+03	37200.00
3EA66C	2017-08-09 06:33:00+03	70600.00
3EA67D	2017-07-28 18:37:00+03	28000.00
3EA689	2017-08-02 21:44:00+03	196100.00
3EA695	2017-06-30 01:39:00+03	406700.00
3EA6C7	2017-07-21 10:03:00+03	257500.00
3EA7DD	2017-07-27 02:13:00+03	45500.00
3EA7E6	2017-08-01 17:58:00+03	28000.00
3EA815	2017-08-15 01:18:00+03	81300.00
3EA830	2017-07-27 02:41:00+03	61800.00
3EA856	2017-08-11 17:41:00+03	65400.00
3EA899	2017-08-01 18:25:00+03	89200.00
3EA8B0	2017-07-26 14:24:00+03	32700.00
3EA916	2017-06-30 05:32:00+03	43600.00
3EAA20	2017-07-09 13:33:00+03	47500.00
3EAA32	2017-07-26 06:39:00+03	63200.00
3EAA36	2017-07-16 03:17:00+03	76300.00
3EAAAB	2017-08-02 09:03:00+03	23900.00
3EAAD0	2017-07-15 21:18:00+03	195600.00
3EAB05	2017-07-20 18:34:00+03	125200.00
3EAB56	2017-07-08 04:51:00+03	53000.00
3EAB90	2017-07-15 07:28:00+03	42800.00
3EABC7	2017-07-24 16:14:00+03	84100.00
3EAC13	2017-08-10 08:42:00+03	55800.00
3EAC37	2017-07-10 14:52:00+03	26000.00
3EAC41	2017-08-12 08:09:00+03	38500.00
3EACAC	2017-07-17 07:35:00+03	271100.00
3EACAE	2017-08-01 23:23:00+03	147500.00
3EACC8	2017-08-13 09:48:00+03	62900.00
3EACD0	2017-07-11 13:58:00+03	23200.00
3EACFA	2017-07-13 21:03:00+03	46900.00
3EAD57	2017-08-02 20:22:00+03	135400.00
3EADE7	2017-07-01 09:23:00+03	31600.00
3EAE17	2017-07-11 20:32:00+03	18000.00
3EAED0	2017-08-14 14:33:00+03	16400.00
3EAF4E	2017-07-27 13:12:00+03	111600.00
3EAF6D	2017-07-21 04:07:00+03	37900.00
3EAF8A	2017-07-16 12:02:00+03	43500.00
3EAFB1	2017-07-25 12:11:00+03	67500.00
3EB026	2017-07-08 17:32:00+03	27200.00
3EB02F	2017-07-10 23:43:00+03	14000.00
3EB050	2017-08-12 20:17:00+03	46800.00
3EB137	2017-07-11 23:28:00+03	105100.00
3EB142	2017-08-02 19:29:00+03	36700.00
3EB261	2017-07-12 06:17:00+03	62900.00
3EB291	2017-07-23 05:37:00+03	114500.00
3EB2A8	2017-07-09 05:55:00+03	50000.00
3EB2FD	2017-08-05 08:43:00+03	53600.00
3EB30F	2017-07-05 17:06:00+03	26000.00
3EB36B	2017-07-14 01:27:00+03	36200.00
3EB396	2017-08-06 21:19:00+03	67900.00
3EB3F0	2017-08-08 16:30:00+03	185600.00
3EB406	2017-08-07 13:27:00+03	84500.00
3EB415	2017-07-28 02:40:00+03	46400.00
3EB49C	2017-07-10 06:40:00+03	28000.00
3EB4B1	2017-07-20 16:53:00+03	68800.00
3EB4DB	2017-07-26 22:11:00+03	65900.00
3EB4F5	2017-07-31 19:30:00+03	230700.00
3EB552	2017-07-06 14:43:00+03	271100.00
3EB570	2017-08-03 11:18:00+03	148200.00
3EB57A	2017-07-12 09:43:00+03	81600.00
3EB5BE	2017-07-16 01:48:00+03	8400.00
3EB5D2	2017-07-08 09:37:00+03	29100.00
3EB5D3	2017-07-25 14:25:00+03	65900.00
3EB600	2017-07-21 13:29:00+03	46400.00
3EB620	2017-07-11 17:29:00+03	24400.00
3EB639	2017-08-11 17:20:00+03	110300.00
3EB644	2017-07-22 20:32:00+03	28000.00
3EB67C	2017-07-04 12:05:00+03	123000.00
3EB686	2017-08-13 16:36:00+03	53700.00
3EB6F5	2017-08-12 08:35:00+03	14400.00
3EB700	2017-07-04 04:40:00+03	57800.00
3EB70F	2017-08-05 19:48:00+03	15900.00
3EB75A	2017-07-16 23:31:00+03	12600.00
3EB770	2017-08-11 16:25:00+03	85500.00
3EB7CB	2017-07-27 14:43:00+03	26000.00
3EB7E1	2017-07-23 13:05:00+03	131100.00
3EB81B	2017-07-21 16:10:00+03	46000.00
3EB847	2017-07-13 03:21:00+03	15800.00
3EB868	2017-08-11 08:51:00+03	82900.00
3EB86E	2017-08-13 00:56:00+03	77200.00
3EB890	2017-07-07 20:57:00+03	100300.00
3EB8D9	2017-07-09 06:45:00+03	12600.00
3EB8FC	2017-08-15 07:31:00+03	44000.00
3EBA04	2017-07-02 23:06:00+03	58400.00
3EBA12	2017-07-13 00:49:00+03	102100.00
3EBA3A	2017-07-09 16:32:00+03	26200.00
3EBA74	2017-07-28 16:53:00+03	41900.00
3EBB28	2017-08-13 11:22:00+03	34300.00
3EBBB7	2017-07-24 04:34:00+03	99200.00
3EBBFD	2017-07-03 03:28:00+03	55800.00
3EBD0C	2017-08-01 15:35:00+03	116500.00
3EBD48	2017-08-02 09:30:00+03	213800.00
3EBE4B	2017-08-10 11:20:00+03	75600.00
3EBE66	2017-07-08 22:39:00+03	84100.00
3EBE98	2017-08-06 02:41:00+03	7400.00
3EBE9C	2017-08-14 03:35:00+03	38800.00
3EBECA	2017-08-07 09:11:00+03	25200.00
3EBEDB	2017-08-05 03:32:00+03	13800.00
3EBEE6	2017-07-14 14:40:00+03	46200.00
3EBF51	2017-08-11 07:22:00+03	57500.00
3EBFB0	2017-07-28 20:47:00+03	16400.00
3EC05B	2017-07-04 14:15:00+03	6700.00
3EC06D	2017-08-15 08:25:00+03	25600.00
3EC083	2017-07-17 12:36:00+03	44600.00
3EC092	2017-07-06 19:56:00+03	20400.00
3EC0A3	2017-07-31 07:11:00+03	28200.00
3EC0EB	2017-07-26 18:44:00+03	27200.00
3EC1C8	2017-07-05 13:38:00+03	103000.00
3EC1E9	2017-07-22 01:08:00+03	118500.00
3EC215	2017-08-01 21:30:00+03	46400.00
3EC233	2017-07-01 05:27:00+03	46000.00
3EC258	2017-07-03 02:40:00+03	238900.00
3EC264	2017-07-12 16:29:00+03	25800.00
3EC26C	2017-08-15 10:27:00+03	93000.00
3EC2BF	2017-07-21 11:26:00+03	26000.00
3EC37C	2017-07-20 21:20:00+03	28800.00
3EC393	2017-07-09 22:48:00+03	12400.00
3EC3D5	2017-08-12 05:42:00+03	14000.00
3EC42A	2017-07-16 20:23:00+03	56500.00
3EC50B	2017-07-12 03:39:00+03	119600.00
3EC52A	2017-07-07 12:01:00+03	56100.00
3EC52C	2017-07-08 15:01:00+03	58400.00
3EC564	2017-07-23 02:20:00+03	398500.00
3EC5C8	2017-07-14 06:01:00+03	52900.00
3EC66B	2017-07-20 18:21:00+03	49900.00
3EC67A	2017-08-02 19:55:00+03	13400.00
3EC688	2017-07-26 18:12:00+03	25200.00
3EC6D4	2017-07-11 16:16:00+03	22200.00
3EC6FA	2017-07-04 00:23:00+03	85000.00
3EC6FC	2017-07-13 15:47:00+03	71000.00
3EC79A	2017-07-16 13:31:00+03	13100.00
3EC7A5	2017-06-29 20:07:00+03	97600.00
3EC7EE	2017-07-31 08:30:00+03	14400.00
3EC852	2017-07-29 17:38:00+03	68400.00
3EC85A	2017-08-15 01:28:00+03	31100.00
3EC8D7	2017-07-09 17:13:00+03	25400.00
3EC8ED	2017-07-21 00:24:00+03	96800.00
3EC914	2017-07-30 08:07:00+03	92800.00
3EC992	2017-08-14 01:02:00+03	56000.00
3EC9B1	2017-07-08 03:11:00+03	28800.00
3ECA28	2017-08-06 14:36:00+03	155600.00
3ECA31	2017-07-05 22:05:00+03	28000.00
3ECA50	2017-07-01 09:34:00+03	37900.00
3ECA6C	2017-07-24 23:47:00+03	24400.00
3ECA85	2017-07-02 10:31:00+03	29800.00
3ECAC7	2017-07-09 08:27:00+03	56000.00
3ECB2B	2017-08-11 13:53:00+03	520600.00
3ECB7C	2017-07-30 09:58:00+03	89600.00
3ECBAB	2017-07-04 18:35:00+03	62600.00
3ECD3A	2017-08-15 03:54:00+03	37700.00
3ECD83	2017-07-25 09:15:00+03	242900.00
3ECD94	2017-07-17 14:17:00+03	99200.00
3ECDC4	2017-07-13 22:43:00+03	123000.00
3ECDE2	2017-07-18 08:27:00+03	55800.00
3ECE09	2017-08-02 18:35:00+03	21600.00
3ECE0B	2017-07-04 14:12:00+03	87200.00
3ECE13	2017-07-26 20:25:00+03	286100.00
3ECE1E	2017-08-07 10:42:00+03	25000.00
3ECECE	2017-07-01 16:39:00+03	229900.00
3ECEF3	2017-07-25 15:42:00+03	225900.00
3ECF9E	2017-07-04 22:11:00+03	112600.00
3ECFCD	2017-07-10 02:02:00+03	61800.00
3ECFEA	2017-08-01 13:06:00+03	266400.00
3ED054	2017-07-22 20:11:00+03	46200.00
3ED080	2017-07-29 10:33:00+03	292900.00
3ED0D5	2017-07-21 04:04:00+03	99000.00
3ED136	2017-08-08 22:11:00+03	515900.00
3ED18E	2017-07-28 22:46:00+03	26000.00
3ED204	2017-08-02 22:37:00+03	232300.00
3ED38F	2017-08-05 17:40:00+03	28000.00
3ED396	2017-08-09 06:09:00+03	133100.00
3ED415	2017-08-14 00:29:00+03	239100.00
3ED42F	2017-06-28 06:03:00+03	38600.00
3ED485	2017-07-21 11:33:00+03	231800.00
3ED491	2017-07-27 00:36:00+03	270700.00
3ED4D4	2017-08-11 07:19:00+03	272400.00
3ED536	2017-08-01 08:19:00+03	43200.00
3ED571	2017-07-04 10:24:00+03	137000.00
3ED5D0	2017-07-16 02:40:00+03	8000.00
3ED5EA	2017-07-18 03:10:00+03	30000.00
3ED620	2017-07-23 15:23:00+03	6000.00
3ED642	2017-08-14 07:57:00+03	67200.00
3ED68E	2017-06-30 04:23:00+03	75300.00
3ED6CC	2017-07-29 16:09:00+03	92700.00
3ED6F5	2017-07-17 15:38:00+03	27900.00
3ED701	2017-07-03 12:58:00+03	8200.00
3ED724	2017-06-28 14:43:00+03	133900.00
3ED729	2017-08-14 23:20:00+03	56000.00
3ED762	2017-07-16 09:04:00+03	65900.00
3ED7A8	2017-07-01 12:03:00+03	56000.00
3ED7B8	2017-07-14 19:14:00+03	51600.00
3ED7DC	2017-08-11 05:44:00+03	24800.00
3ED7E5	2017-08-07 20:35:00+03	111600.00
3ED7F8	2017-08-09 02:12:00+03	78000.00
3ED851	2017-07-11 04:40:00+03	46500.00
3ED8A3	2017-07-16 09:35:00+03	13400.00
3ED8B6	2017-07-06 01:03:00+03	147700.00
3ED931	2017-07-05 20:41:00+03	25600.00
3ED961	2017-07-10 00:29:00+03	94800.00
3ED97F	2017-06-28 17:39:00+03	46800.00
3ED98B	2017-07-07 11:30:00+03	24400.00
3ED98E	2017-07-15 21:37:00+03	6700.00
3EDAB5	2017-08-03 07:36:00+03	29300.00
3EDAD3	2017-07-14 17:59:00+03	54800.00
3EDAD4	2017-07-19 05:01:00+03	88800.00
3EDAE4	2017-08-03 14:27:00+03	139200.00
3EDC19	2017-07-15 21:03:00+03	63700.00
3EDC24	2017-07-16 08:22:00+03	38800.00
3EDC62	2017-08-08 08:21:00+03	23900.00
3EDC7B	2017-07-05 20:24:00+03	179300.00
3EDCB6	2017-07-29 22:18:00+03	31600.00
3EDCD1	2017-07-23 21:56:00+03	31400.00
3EDD30	2017-08-10 11:04:00+03	292200.00
3EDD6D	2017-08-04 15:35:00+03	66600.00
3EDD7F	2017-08-07 10:31:00+03	107400.00
3EDDB1	2017-07-09 09:30:00+03	444500.00
3EDDD9	2017-08-06 19:36:00+03	65500.00
3EDEB9	2017-08-13 23:34:00+03	40800.00
3EDECC	2017-07-15 04:22:00+03	95300.00
3EE112	2017-06-30 22:14:00+03	123000.00
3EE115	2017-08-07 18:02:00+03	119700.00
3EE12F	2017-07-14 04:18:00+03	28000.00
3EE153	2017-07-18 08:35:00+03	23200.00
3EE15F	2017-07-17 21:45:00+03	105000.00
3EE178	2017-07-06 18:11:00+03	84000.00
3EE195	2017-07-18 13:46:00+03	147100.00
3EE1A5	2017-07-30 06:17:00+03	62100.00
3EE23C	2017-07-16 10:33:00+03	36200.00
3EE267	2017-07-22 04:15:00+03	61500.00
3EE2A7	2017-08-13 06:33:00+03	70800.00
3EE306	2017-07-23 08:45:00+03	54800.00
3EE3D2	2017-07-12 20:48:00+03	156300.00
3EE3D3	2017-07-24 13:57:00+03	96800.00
3EE44F	2017-07-22 21:01:00+03	63600.00
3EE4C3	2017-07-23 18:26:00+03	65600.00
3EE4D5	2017-07-07 12:22:00+03	46400.00
3EE523	2017-07-26 05:59:00+03	37900.00
3EE566	2017-08-14 08:28:00+03	74400.00
3EE586	2017-07-17 13:47:00+03	131600.00
3EE5E4	2017-07-06 10:24:00+03	37900.00
3EE601	2017-07-03 00:32:00+03	77000.00
3EE625	2017-07-12 14:06:00+03	224000.00
3EE655	2017-08-05 21:44:00+03	111700.00
3EE67E	2017-08-07 00:35:00+03	134400.00
3EE6F5	2017-07-10 18:01:00+03	68000.00
3EE6F8	2017-08-11 08:02:00+03	26200.00
3EE6FC	2017-07-06 15:18:00+03	65900.00
3EE777	2017-07-30 01:22:00+03	26800.00
3EE7B6	2017-07-09 22:13:00+03	198300.00
3EE7E8	2017-08-15 00:25:00+03	32200.00
3EE7FF	2017-07-30 17:38:00+03	24400.00
3EE838	2017-08-04 18:16:00+03	18000.00
3EE83C	2017-07-12 10:51:00+03	58700.00
3EE849	2017-07-06 01:10:00+03	17200.00
3EE88D	2017-07-31 00:58:00+03	52300.00
3EE8B1	2017-07-22 05:15:00+03	93700.00
3EE8B3	2017-07-16 05:17:00+03	91600.00
3EE8B4	2017-08-09 05:56:00+03	42800.00
3EE8BC	2017-07-20 21:24:00+03	94000.00
3EE90C	2017-07-24 21:46:00+03	311200.00
3EE912	2017-08-03 00:59:00+03	79200.00
3EE94C	2017-07-25 03:19:00+03	30200.00
3EE9F2	2017-08-09 10:31:00+03	15900.00
3EEA1D	2017-07-17 04:32:00+03	75300.00
3EEA2E	2017-07-30 15:43:00+03	211500.00
3EEA39	2017-08-08 18:22:00+03	125100.00
3EEA58	2017-08-02 22:23:00+03	100600.00
3EEA97	2017-07-21 16:32:00+03	56000.00
3EEA9C	2017-07-24 01:42:00+03	93900.00
3EEAAE	2017-07-27 12:08:00+03	81600.00
3EEAC4	2017-07-09 21:53:00+03	36000.00
3EEACB	2017-06-29 06:51:00+03	12000.00
3EEBB3	2017-07-27 05:21:00+03	116900.00
3EEBD4	2017-06-29 09:54:00+03	40400.00
3EEC17	2017-07-21 14:16:00+03	28800.00
3EEC43	2017-06-30 03:35:00+03	26700.00
3EEC54	2017-07-07 16:09:00+03	65100.00
3EEC57	2017-08-14 03:43:00+03	31000.00
3EECA1	2017-07-05 04:25:00+03	22000.00
3EECC0	2017-08-11 07:51:00+03	68900.00
3EED88	2017-08-07 09:44:00+03	36200.00
3EEDA1	2017-07-09 20:53:00+03	28000.00
3EEE03	2017-07-02 11:27:00+03	136200.00
3EEE22	2017-07-31 03:43:00+03	44000.00
3EEECB	2017-07-02 14:00:00+03	30200.00
3EEEEE	2017-07-24 14:31:00+03	30000.00
3EEF0C	2017-07-07 10:11:00+03	75600.00
3EEF31	2017-07-18 01:30:00+03	103800.00
3EEF84	2017-07-28 01:54:00+03	101200.00
3EEF89	2017-08-09 20:47:00+03	281500.00
3EEF9B	2017-08-09 20:50:00+03	106800.00
3EF003	2017-07-11 05:24:00+03	36600.00
3EF042	2017-07-15 18:59:00+03	48300.00
3EF09F	2017-08-14 16:16:00+03	52300.00
3EF0A8	2017-07-23 01:11:00+03	36400.00
3EF0B8	2017-08-09 18:15:00+03	258400.00
3EF0C6	2017-07-08 02:53:00+03	15100.00
3EF0D8	2017-07-07 19:57:00+03	34200.00
3EF0EA	2017-07-25 22:52:00+03	62100.00
3EF178	2017-07-10 05:06:00+03	98400.00
3EF1A6	2017-07-09 20:04:00+03	25600.00
3EF1E5	2017-08-08 00:43:00+03	31600.00
3EF209	2017-07-01 17:44:00+03	24400.00
3EF242	2017-07-30 06:51:00+03	26000.00
3EF249	2017-07-11 08:41:00+03	48800.00
3EF273	2017-07-10 10:05:00+03	43200.00
3EF275	2017-07-29 23:07:00+03	6800.00
3EF2CD	2017-07-04 10:22:00+03	39200.00
3EF3EE	2017-07-20 07:24:00+03	75600.00
3EF409	2017-07-17 18:48:00+03	13600.00
3EF417	2017-07-22 06:08:00+03	89600.00
3EF425	2017-07-15 17:22:00+03	44000.00
3EF443	2017-07-19 08:48:00+03	71200.00
3EF45C	2017-07-10 01:04:00+03	133100.00
3EF464	2017-08-03 05:16:00+03	110500.00
3EF4ED	2017-08-03 20:38:00+03	56000.00
3EF515	2017-07-23 12:42:00+03	54800.00
3EF5F0	2017-07-06 02:46:00+03	133100.00
3EF681	2017-07-29 19:30:00+03	26700.00
3EF6D6	2017-07-03 01:38:00+03	46400.00
3EF7BB	2017-08-07 09:01:00+03	150600.00
3EF7DD	2017-07-10 08:20:00+03	116900.00
3EF7F0	2017-07-09 03:31:00+03	11800.00
3EF817	2017-07-05 21:12:00+03	22000.00
3EF827	2017-07-06 15:53:00+03	56600.00
3EF900	2017-08-01 17:31:00+03	111600.00
3EF96D	2017-08-03 03:54:00+03	19600.00
3EF9A6	2017-08-14 11:04:00+03	57400.00
3EF9A8	2017-07-13 22:59:00+03	238900.00
3EF9AE	2017-07-13 15:26:00+03	229900.00
3EF9B9	2017-07-21 07:21:00+03	271100.00
3EFA3A	2017-08-01 12:00:00+03	72200.00
3EFA55	2017-07-16 23:35:00+03	46400.00
3EFA59	2017-07-27 00:25:00+03	32700.00
3EFA78	2017-07-22 21:45:00+03	57800.00
3EFA9A	2017-08-06 08:26:00+03	32800.00
3EFAA4	2017-08-09 11:22:00+03	31200.00
3EFAB5	2017-07-14 17:27:00+03	25400.00
3EFAC6	2017-07-28 18:06:00+03	55800.00
3EFAF3	2017-07-22 00:51:00+03	246000.00
3EFB24	2017-07-09 08:40:00+03	66600.00
3EFBA6	2017-07-10 04:51:00+03	46000.00
3EFBCA	2017-07-13 09:32:00+03	231400.00
3EFBFE	2017-08-01 00:26:00+03	193600.00
3EFC38	2017-07-09 05:46:00+03	10600.00
3EFCA1	2017-07-27 01:59:00+03	53600.00
3EFCAF	2017-07-10 03:46:00+03	17200.00
3EFD49	2017-07-20 11:35:00+03	65800.00
3EFE05	2017-07-08 05:02:00+03	31900.00
3EFE28	2017-08-05 06:55:00+03	52000.00
3EFE37	2017-07-03 15:57:00+03	56000.00
3EFE59	2017-08-04 05:06:00+03	100600.00
3EFF29	2017-08-12 20:58:00+03	138600.00
3EFFB3	2017-08-09 12:33:00+03	44500.00
3EFFB9	2017-08-14 06:55:00+03	18600.00
3EFFCA	2017-07-09 20:37:00+03	6800.00
3EFFDA	2017-07-23 00:13:00+03	8400.00
3F0018	2017-07-31 08:23:00+03	28000.00
3F0030	2017-06-30 07:58:00+03	150600.00
3F0047	2017-08-11 15:25:00+03	58600.00
3F004D	2017-08-03 17:59:00+03	96300.00
3F008E	2017-07-06 13:39:00+03	32800.00
3F0096	2017-07-16 12:17:00+03	54800.00
3F014C	2017-08-08 23:09:00+03	90700.00
3F014D	2017-08-03 10:37:00+03	128800.00
3F0153	2017-07-09 05:55:00+03	136000.00
3F018A	2017-07-07 12:00:00+03	52700.00
3F020D	2017-08-02 08:55:00+03	177600.00
3F0281	2017-07-10 02:19:00+03	32800.00
3F0291	2017-07-26 18:36:00+03	45100.00
3F02A0	2017-07-21 12:24:00+03	29600.00
3F02C0	2017-08-08 10:58:00+03	98700.00
3F0316	2017-07-12 04:13:00+03	6600.00
3F033B	2017-08-10 09:43:00+03	46000.00
3F0373	2017-07-23 17:55:00+03	31600.00
3F0384	2017-08-01 19:28:00+03	135600.00
3F03DC	2017-07-16 19:42:00+03	201200.00
3F043C	2017-08-02 20:56:00+03	40700.00
3F0481	2017-07-29 15:21:00+03	149100.00
3F04C6	2017-07-07 13:18:00+03	56600.00
3F04EE	2017-07-06 09:16:00+03	11700.00
3F05E2	2017-07-05 07:47:00+03	67700.00
3F062F	2017-07-28 20:37:00+03	56000.00
3F0654	2017-07-06 10:34:00+03	28000.00
3F066B	2017-08-13 13:24:00+03	38400.00
3F0698	2017-07-26 08:47:00+03	26000.00
3F06A7	2017-08-14 02:16:00+03	202600.00
3F06AB	2017-08-10 01:51:00+03	25600.00
3F06DF	2017-07-22 21:39:00+03	21500.00
3F0705	2017-07-03 08:02:00+03	39800.00
3F07F5	2017-07-09 18:16:00+03	46200.00
3F0844	2017-08-12 03:02:00+03	56000.00
3F0969	2017-08-11 17:51:00+03	12000.00
3F096C	2017-07-03 17:51:00+03	23200.00
3F09AD	2017-08-02 02:41:00+03	49600.00
3F09ED	2017-07-09 20:41:00+03	23400.00
3F0A14	2017-07-12 07:20:00+03	28800.00
3F0AA2	2017-07-13 09:40:00+03	116000.00
3F0B13	2017-08-09 00:59:00+03	6000.00
3F0B22	2017-08-07 21:15:00+03	8400.00
3F0B2A	2017-07-26 11:21:00+03	136800.00
3F0B2B	2017-08-03 19:26:00+03	187600.00
3F0B87	2017-07-16 04:04:00+03	136200.00
3F0BB3	2017-08-04 19:11:00+03	24700.00
3F0BEE	2017-08-03 08:54:00+03	22100.00
3F0C47	2017-07-04 00:20:00+03	68800.00
3F0C64	2017-07-04 09:50:00+03	28000.00
3F0D99	2017-07-06 19:20:00+03	26700.00
3F0DA5	2017-07-24 08:35:00+03	15000.00
3F0DE9	2017-07-02 00:21:00+03	31600.00
3F0E11	2017-07-21 21:13:00+03	26000.00
3F0E20	2017-07-10 14:59:00+03	18300.00
3F0EB8	2017-07-10 22:26:00+03	12200.00
3F0EFA	2017-08-03 22:53:00+03	20400.00
3F0EFE	2017-08-04 01:51:00+03	131600.00
3F0F3C	2017-08-01 11:45:00+03	140300.00
3F0F54	2017-07-25 21:45:00+03	40400.00
3F0F5E	2017-07-24 19:17:00+03	15100.00
3F0FA1	2017-07-22 08:14:00+03	21400.00
3F0FAF	2017-07-25 01:03:00+03	27200.00
3F1072	2017-07-11 11:12:00+03	26700.00
3F112F	2017-07-08 05:28:00+03	101200.00
3F1144	2017-07-04 13:48:00+03	31600.00
3F114D	2017-08-04 11:21:00+03	13800.00
3F1159	2017-08-04 02:06:00+03	52000.00
3F11B8	2017-07-30 23:04:00+03	49100.00
3F11D2	2017-08-10 00:24:00+03	73500.00
3F12FA	2017-07-05 15:39:00+03	155100.00
3F1369	2017-07-30 13:41:00+03	97200.00
3F1472	2017-08-15 15:33:00+03	85700.00
3F14AE	2017-08-01 00:45:00+03	46000.00
3F14C6	2017-07-06 22:55:00+03	117200.00
3F1507	2017-08-03 14:44:00+03	6000.00
3F1517	2017-08-09 21:02:00+03	46000.00
3F155E	2017-08-11 15:43:00+03	6600.00
3F156A	2017-07-01 13:42:00+03	25100.00
3F157E	2017-07-11 19:32:00+03	23600.00
3F1589	2017-07-05 20:44:00+03	104600.00
3F15CE	2017-08-13 01:32:00+03	124200.00
3F15FB	2017-07-06 21:11:00+03	101100.00
3F16A5	2017-08-14 09:58:00+03	81700.00
3F16A8	2017-07-27 23:16:00+03	7400.00
3F1707	2017-07-26 05:53:00+03	199600.00
3F170F	2017-06-30 01:13:00+03	137400.00
3F1743	2017-07-20 16:09:00+03	43000.00
3F17B6	2017-07-29 02:14:00+03	97400.00
3F17DA	2017-07-28 16:53:00+03	39200.00
3F17DB	2017-07-15 01:10:00+03	93800.00
3F17E9	2017-08-06 22:11:00+03	24400.00
3F1892	2017-07-02 21:21:00+03	14000.00
3F18F6	2017-08-06 13:30:00+03	246000.00
3F1916	2017-08-05 03:54:00+03	25400.00
3F196A	2017-06-30 15:55:00+03	81900.00
3F198F	2017-07-29 02:15:00+03	47800.00
3F19AA	2017-07-22 23:01:00+03	215500.00
3F19D2	2017-08-03 04:18:00+03	46000.00
3F19DB	2017-07-31 16:05:00+03	71400.00
3F1A62	2017-07-26 08:30:00+03	31400.00
3F1AAF	2017-07-03 18:45:00+03	46000.00
3F1AE0	2017-07-27 14:52:00+03	30200.00
3F1B4E	2017-08-11 23:47:00+03	286100.00
3F1BD0	2017-07-04 03:35:00+03	10800.00
3F1BDC	2017-08-08 14:20:00+03	46000.00
3F1BE5	2017-08-03 20:51:00+03	90000.00
3F1BEE	2017-07-03 14:21:00+03	7800.00
3F1BFE	2017-08-14 13:04:00+03	26800.00
3F1C74	2017-08-11 03:05:00+03	105100.00
3F1C8A	2017-08-08 09:25:00+03	111700.00
3F1D26	2017-07-17 01:42:00+03	93900.00
3F1D91	2017-07-07 22:17:00+03	21400.00
3F1DF6	2017-08-03 21:56:00+03	91200.00
3F1E38	2017-07-19 11:40:00+03	43200.00
3F1E3D	2017-07-15 11:58:00+03	491600.00
3F1E9A	2017-07-21 14:14:00+03	46200.00
3F1EF3	2017-07-02 20:31:00+03	105100.00
3F1EFB	2017-07-27 14:10:00+03	363000.00
3F1F0B	2017-08-08 11:44:00+03	19600.00
3F1F39	2017-08-01 07:59:00+03	56900.00
3F1F44	2017-08-14 22:01:00+03	135400.00
3F1F54	2017-08-04 08:31:00+03	65500.00
3F1FB5	2017-07-14 01:32:00+03	59000.00
3F2048	2017-07-27 13:30:00+03	38400.00
3F2063	2017-07-26 01:20:00+03	298400.00
3F2076	2017-08-15 17:50:00+03	56000.00
3F2090	2017-07-19 14:51:00+03	53700.00
3F209F	2017-08-05 05:30:00+03	104600.00
3F2116	2017-08-04 10:36:00+03	88000.00
3F21E7	2017-07-09 04:53:00+03	199200.00
3F2214	2017-08-02 19:16:00+03	26000.00
3F2288	2017-07-14 02:12:00+03	22400.00
3F2296	2017-07-28 02:07:00+03	28600.00
3F22CB	2017-07-19 09:35:00+03	147000.00
3F22E5	2017-07-23 03:43:00+03	14000.00
3F2306	2017-07-07 17:31:00+03	62600.00
3F234C	2017-07-05 01:32:00+03	172600.00
3F238E	2017-06-30 23:03:00+03	119500.00
3F2392	2017-08-15 08:48:00+03	28000.00
3F23A2	2017-07-18 11:32:00+03	20100.00
3F23A7	2017-08-12 20:38:00+03	136800.00
3F2433	2017-08-11 01:44:00+03	60400.00
3F247B	2017-07-01 06:00:00+03	85700.00
3F24A5	2017-08-05 13:40:00+03	46200.00
3F24E5	2017-08-13 05:38:00+03	24800.00
3F24F0	2017-08-14 20:03:00+03	53600.00
3F24F8	2017-07-09 23:38:00+03	28800.00
3F256B	2017-07-03 12:14:00+03	37100.00
3F257D	2017-07-21 00:14:00+03	59200.00
3F25A8	2017-08-04 00:57:00+03	28000.00
3F2629	2017-07-13 22:38:00+03	32700.00
3F2635	2017-07-23 00:05:00+03	260900.00
3F265B	2017-07-17 11:40:00+03	127800.00
3F273F	2017-08-07 00:33:00+03	55800.00
3F2767	2017-07-30 21:06:00+03	140200.00
3F27AD	2017-07-10 19:32:00+03	103100.00
3F27D2	2017-07-10 23:52:00+03	24400.00
3F27F7	2017-08-04 22:13:00+03	111600.00
3F2813	2017-07-27 04:06:00+03	27800.00
3F281E	2017-07-28 06:00:00+03	32900.00
3F2844	2017-07-24 01:52:00+03	102100.00
3F285A	2017-07-29 03:54:00+03	12600.00
3F289C	2017-07-21 00:36:00+03	150600.00
3F2922	2017-07-12 15:09:00+03	146300.00
3F29D9	2017-07-06 12:52:00+03	16400.00
3F29E1	2017-07-06 12:27:00+03	54000.00
3F2A1D	2017-08-09 16:18:00+03	21600.00
3F2A30	2017-08-07 17:46:00+03	24400.00
3F2A61	2017-07-08 15:52:00+03	100000.00
3F2AB3	2017-07-09 11:28:00+03	39300.00
3F2B16	2017-08-14 16:48:00+03	17300.00
3F2B82	2017-07-28 20:39:00+03	71900.00
3F2B88	2017-07-19 13:27:00+03	45200.00
3F2BAC	2017-07-05 22:22:00+03	32800.00
3F2C91	2017-07-29 22:52:00+03	62000.00
3F2CA8	2017-06-29 02:09:00+03	25200.00
3F2D4B	2017-07-21 14:19:00+03	47200.00
3F2D4F	2017-07-03 20:03:00+03	22000.00
3F2DA2	2017-08-08 23:50:00+03	23900.00
3F2DAA	2017-07-12 15:55:00+03	114800.00
3F2E1F	2017-07-24 00:44:00+03	32800.00
3F2E75	2017-08-11 17:21:00+03	32200.00
3F2EDA	2017-07-23 07:10:00+03	26000.00
3F2EFA	2017-07-03 23:39:00+03	6300.00
3F2F2A	2017-08-08 07:48:00+03	40800.00
3F2F71	2017-07-25 13:37:00+03	129200.00
3F3056	2017-07-09 03:43:00+03	57400.00
3F306F	2017-08-03 23:58:00+03	92800.00
3F3093	2017-07-11 13:32:00+03	58200.00
3F3094	2017-07-04 18:04:00+03	56100.00
3F30CA	2017-07-23 08:53:00+03	266400.00
3F3114	2017-08-11 15:47:00+03	40000.00
3F331E	2017-08-03 22:25:00+03	227200.00
3F3365	2017-07-01 08:38:00+03	13400.00
3F3394	2017-08-15 00:31:00+03	52000.00
3F33B4	2017-08-04 22:10:00+03	50600.00
3F342F	2017-07-16 07:09:00+03	21400.00
3F3492	2017-07-26 19:10:00+03	408500.00
3F351E	2017-06-28 01:57:00+03	6700.00
3F35BB	2017-07-17 22:43:00+03	69500.00
3F35EA	2017-07-05 17:04:00+03	123000.00
3F3665	2017-08-07 11:44:00+03	20000.00
3F3678	2017-08-01 21:35:00+03	73500.00
3F3688	2017-07-10 00:13:00+03	37900.00
3F36D7	2017-08-05 04:04:00+03	187800.00
3F3724	2017-08-11 09:13:00+03	8200.00
3F373B	2017-07-07 14:37:00+03	73200.00
3F3750	2017-07-06 04:44:00+03	29400.00
3F3754	2017-08-05 14:52:00+03	29600.00
3F3757	2017-07-04 20:40:00+03	103500.00
3F3769	2017-07-28 23:57:00+03	282100.00
3F3794	2017-07-19 08:38:00+03	190000.00
3F379F	2017-08-04 17:02:00+03	42700.00
3F37C6	2017-07-22 23:51:00+03	133100.00
3F380E	2017-07-04 08:14:00+03	40800.00
3F3859	2017-07-11 14:54:00+03	67900.00
3F385F	2017-07-15 07:07:00+03	122000.00
3F3867	2017-07-10 21:48:00+03	196400.00
3F38D7	2017-08-12 11:30:00+03	89600.00
3F393C	2017-08-06 00:11:00+03	27800.00
3F3949	2017-06-27 17:58:00+03	51900.00
3F394B	2017-08-13 20:49:00+03	53600.00
3F3963	2017-07-01 12:57:00+03	56000.00
3F3974	2017-08-09 01:56:00+03	22000.00
3F3977	2017-07-21 09:05:00+03	128900.00
3F399B	2017-07-29 10:19:00+03	11000.00
3F39C2	2017-08-09 02:30:00+03	30000.00
3F39F1	2017-08-03 12:45:00+03	85600.00
3F39FE	2017-07-03 13:16:00+03	27200.00
3F3A3E	2017-07-30 12:55:00+03	73300.00
3F3A51	2017-08-12 00:25:00+03	85500.00
3F3AD8	2017-07-21 05:36:00+03	167400.00
3F3AE2	2017-08-02 13:51:00+03	55800.00
3F3B3C	2017-07-24 08:26:00+03	27200.00
3F3B9F	2017-07-10 13:45:00+03	75600.00
3F3BBF	2017-08-02 17:42:00+03	26200.00
3F3C8F	2017-08-12 09:50:00+03	104300.00
3F3D1F	2017-08-09 13:52:00+03	71500.00
3F3D27	2017-07-16 02:55:00+03	277000.00
3F3DD5	2017-07-13 00:36:00+03	36100.00
3F3DE1	2017-07-11 03:44:00+03	40600.00
3F3DEA	2017-08-06 19:44:00+03	28000.00
3F3E0E	2017-07-14 06:56:00+03	26800.00
3F3E5E	2017-08-04 16:35:00+03	55400.00
3F3E75	2017-08-13 16:31:00+03	25100.00
3F3EBD	2017-07-20 18:36:00+03	211200.00
3F3EF9	2017-08-05 16:07:00+03	173900.00
3F3F15	2017-07-17 17:43:00+03	97500.00
3F3FAE	2017-06-28 02:46:00+03	46400.00
3F3FB3	2017-07-12 18:11:00+03	65600.00
3F3FF6	2017-08-05 00:09:00+03	35300.00
3F4064	2017-08-10 11:34:00+03	39500.00
3F406F	2017-07-13 02:58:00+03	98000.00
3F40EF	2017-07-24 01:19:00+03	46400.00
3F4118	2017-08-05 11:21:00+03	240600.00
3F4173	2017-07-22 13:44:00+03	68200.00
3F41E6	2017-08-13 08:34:00+03	46400.00
3F423F	2017-08-08 22:15:00+03	12000.00
3F428C	2017-07-30 01:43:00+03	39800.00
3F42A8	2017-08-12 00:10:00+03	27200.00
3F4333	2017-08-06 00:32:00+03	248400.00
3F435B	2017-07-07 08:52:00+03	68400.00
3F4361	2017-07-23 07:25:00+03	204200.00
3F4366	2017-07-29 22:01:00+03	23400.00
3F43D1	2017-08-12 16:11:00+03	28800.00
3F43F0	2017-07-25 00:47:00+03	36200.00
3F4451	2017-07-11 13:31:00+03	24600.00
3F4482	2017-07-26 21:37:00+03	92800.00
3F4581	2017-07-17 01:09:00+03	412900.00
3F45B5	2017-08-15 05:37:00+03	7500.00
3F45D5	2017-07-02 05:51:00+03	65400.00
3F45DF	2017-08-13 09:33:00+03	32800.00
3F4602	2017-07-27 06:10:00+03	27200.00
3F4605	2017-07-20 17:14:00+03	57600.00
3F463F	2017-08-11 03:15:00+03	36400.00
3F4648	2017-07-31 08:13:00+03	136200.00
3F4700	2017-08-11 20:28:00+03	23400.00
3F4701	2017-08-08 01:24:00+03	28000.00
3F47C5	2017-07-15 01:00:00+03	60400.00
3F47CA	2017-07-13 19:19:00+03	39200.00
3F47D9	2017-08-06 09:09:00+03	58200.00
3F4824	2017-07-30 23:33:00+03	56600.00
3F4866	2017-07-25 17:26:00+03	16800.00
3F48F8	2017-07-30 10:49:00+03	121800.00
3F4908	2017-08-08 07:11:00+03	48500.00
3F4945	2017-08-09 23:21:00+03	56000.00
3F4958	2017-07-02 21:21:00+03	16400.00
3F4986	2017-07-24 02:51:00+03	6300.00
3F49B8	2017-08-15 08:05:00+03	187700.00
3F4A4D	2017-08-09 12:22:00+03	16400.00
3F4A6F	2017-07-12 03:07:00+03	57600.00
3F4A87	2017-08-05 15:03:00+03	35200.00
3F4A8A	2017-08-02 18:07:00+03	89700.00
3F4A94	2017-07-08 06:40:00+03	72400.00
3F4ADB	2017-08-11 23:38:00+03	57500.00
3F4B35	2017-07-22 23:16:00+03	43600.00
3F4B7F	2017-08-13 13:27:00+03	40600.00
3F4BA8	2017-07-13 18:12:00+03	141700.00
3F4C05	2017-07-22 17:32:00+03	68400.00
3F4C78	2017-08-12 06:41:00+03	83700.00
3F4C84	2017-07-28 18:38:00+03	23600.00
3F4CA1	2017-08-14 08:16:00+03	175900.00
3F4CCB	2017-07-12 01:25:00+03	57700.00
3F4CD9	2017-08-11 21:42:00+03	134300.00
3F4CDE	2017-07-17 16:06:00+03	75300.00
3F4CE9	2017-07-13 01:53:00+03	12600.00
3F4D3A	2017-07-16 17:31:00+03	16000.00
3F4D71	2017-07-14 10:13:00+03	85000.00
3F4D77	2017-07-12 05:18:00+03	70600.00
3F4DA3	2017-07-25 01:57:00+03	76300.00
3F4DE5	2017-07-23 18:07:00+03	56000.00
3F4EE5	2017-08-12 05:35:00+03	15700.00
3F4FA3	2017-08-11 04:58:00+03	49100.00
3F4FD5	2017-07-27 06:58:00+03	28800.00
3F5096	2017-07-12 06:53:00+03	34000.00
3F50CF	2017-08-08 18:28:00+03	114300.00
3F50DE	2017-07-03 18:51:00+03	39500.00
3F50E2	2017-07-09 18:37:00+03	24800.00
3F50EF	2017-07-17 03:38:00+03	11600.00
3F511B	2017-08-13 06:21:00+03	38800.00
3F515C	2017-07-16 08:14:00+03	71700.00
3F5168	2017-07-06 17:06:00+03	26200.00
3F5192	2017-07-28 21:28:00+03	26000.00
3F51B4	2017-08-09 08:22:00+03	26000.00
3F5227	2017-07-09 19:23:00+03	68800.00
3F522A	2017-07-14 18:14:00+03	46400.00
3F5244	2017-07-29 00:55:00+03	62800.00
3F52B3	2017-07-14 00:23:00+03	14000.00
3F532E	2017-08-08 08:48:00+03	235400.00
3F5360	2017-07-18 11:32:00+03	169600.00
3F5363	2017-08-15 06:30:00+03	129800.00
3F53B1	2017-07-05 06:21:00+03	39800.00
3F53CC	2017-06-26 15:59:00+03	49800.00
3F53DD	2017-07-16 06:58:00+03	51300.00
3F546C	2017-07-02 05:36:00+03	99200.00
3F5492	2017-07-03 01:43:00+03	7400.00
3F54B7	2017-07-29 04:20:00+03	334800.00
3F5536	2017-08-08 20:41:00+03	271200.00
3F555D	2017-07-20 11:23:00+03	24600.00
3F557E	2017-07-14 17:33:00+03	28800.00
3F55A1	2017-07-25 14:52:00+03	108500.00
3F5605	2017-08-07 21:28:00+03	412300.00
3F566D	2017-08-12 22:51:00+03	26000.00
3F56D4	2017-07-16 15:03:00+03	158500.00
3F5705	2017-07-11 09:23:00+03	44100.00
3F5740	2017-07-28 03:03:00+03	55700.00
3F575C	2017-07-18 17:14:00+03	444500.00
3F575E	2017-07-10 10:15:00+03	41400.00
3F577E	2017-07-12 13:38:00+03	14000.00
3F57A1	2017-07-11 00:26:00+03	9800.00
3F57A7	2017-08-09 12:39:00+03	16700.00
3F586A	2017-07-12 13:57:00+03	81300.00
3F58A8	2017-07-12 22:13:00+03	53600.00
3F58F6	2017-07-23 14:05:00+03	351900.00
3F5962	2017-07-14 05:44:00+03	200800.00
3F59AA	2017-07-09 15:41:00+03	27200.00
3F59FC	2017-07-06 22:04:00+03	11300.00
3F5A14	2017-07-13 04:15:00+03	56000.00
3F5A1C	2017-08-04 15:23:00+03	23600.00
3F5A9A	2017-07-10 23:25:00+03	31400.00
3F5AAF	2017-07-03 21:24:00+03	23600.00
3F5B6D	2017-07-17 17:46:00+03	61800.00
3F5BF8	2017-08-11 16:38:00+03	58900.00
3F5CA4	2017-07-20 15:54:00+03	27300.00
3F5CAB	2017-07-22 17:49:00+03	42400.00
3F5CC9	2017-08-01 19:30:00+03	20400.00
3F5D03	2017-07-12 09:24:00+03	6300.00
3F5D87	2017-08-07 01:01:00+03	59300.00
3F5D99	2017-07-09 15:34:00+03	67400.00
3F5DEB	2017-07-18 04:40:00+03	60900.00
3F5E50	2017-07-17 15:30:00+03	55800.00
3F5EC7	2017-07-28 14:11:00+03	189800.00
3F5F1A	2017-07-18 18:19:00+03	146300.00
3F5F1D	2017-08-13 00:49:00+03	22600.00
3F5F6E	2017-08-07 10:54:00+03	54800.00
3F5F73	2017-07-23 21:05:00+03	189000.00
3F5F7C	2017-07-06 09:11:00+03	155600.00
3F5F95	2017-07-21 12:33:00+03	57800.00
3F6089	2017-07-22 18:11:00+03	18600.00
3F608D	2017-07-05 14:47:00+03	85000.00
3F60C8	2017-07-22 01:33:00+03	69600.00
3F6199	2017-07-12 15:46:00+03	67200.00
3F61D9	2017-07-05 19:33:00+03	23200.00
3F6209	2017-08-03 08:33:00+03	16400.00
3F624E	2017-08-04 14:39:00+03	23400.00
3F62CD	2017-07-20 10:11:00+03	19600.00
3F62D5	2017-08-14 23:55:00+03	75600.00
3F62E3	2017-07-23 14:13:00+03	62600.00
3F62E6	2017-07-13 14:59:00+03	73200.00
3F631D	2017-08-05 18:58:00+03	211100.00
3F635F	2017-07-05 08:42:00+03	69500.00
3F63C6	2017-07-23 19:40:00+03	170200.00
3F63E4	2017-07-05 10:17:00+03	42800.00
3F6420	2017-08-03 03:20:00+03	137100.00
3F646A	2017-07-08 23:05:00+03	60400.00
3F647E	2017-06-30 05:13:00+03	137600.00
3F64AE	2017-07-19 18:20:00+03	38600.00
3F64EA	2017-08-13 19:27:00+03	258400.00
3F655F	2017-06-26 13:50:00+03	270800.00
3F668D	2017-07-31 08:55:00+03	14800.00
3F6704	2017-07-11 04:23:00+03	37200.00
3F6722	2017-06-28 05:49:00+03	59000.00
3F6736	2017-07-25 05:54:00+03	21200.00
3F675B	2017-07-06 21:09:00+03	24400.00
3F67B6	2017-07-11 17:48:00+03	188900.00
3F67B7	2017-08-07 09:53:00+03	12600.00
3F67BA	2017-08-13 08:51:00+03	65400.00
3F680E	2017-07-09 10:48:00+03	133200.00
3F6837	2017-07-28 15:04:00+03	36600.00
3F6887	2017-08-12 15:24:00+03	76800.00
3F689A	2017-07-14 00:12:00+03	37800.00
3F68A3	2017-08-03 17:27:00+03	39800.00
3F690D	2017-07-29 01:33:00+03	69500.00
3F692B	2017-07-27 21:42:00+03	42100.00
3F698E	2017-08-03 05:28:00+03	23200.00
3F69CC	2017-07-25 06:05:00+03	12600.00
3F6A3E	2017-07-05 15:46:00+03	49100.00
3F6A44	2017-07-10 18:14:00+03	49100.00
3F6ADF	2017-08-02 20:52:00+03	13200.00
3F6B84	2017-07-06 04:44:00+03	68100.00
3F6BF2	2017-07-01 18:11:00+03	75600.00
3F6C35	2017-08-12 02:59:00+03	23200.00
3F6C45	2017-07-25 08:41:00+03	185600.00
3F6C55	2017-06-30 03:24:00+03	176500.00
3F6C58	2017-07-30 19:02:00+03	10700.00
3F6C7E	2017-07-06 09:15:00+03	59300.00
3F6CC6	2017-08-04 14:44:00+03	26600.00
3F6CDA	2017-07-07 09:17:00+03	271200.00
3F6CEC	2017-07-01 11:03:00+03	128700.00
3F6D8E	2017-08-15 04:37:00+03	52000.00
3F6E43	2017-07-14 20:28:00+03	54000.00
3F6E65	2017-07-31 05:55:00+03	132800.00
3F6E6A	2017-07-27 22:58:00+03	62600.00
3F6E88	2017-07-07 10:01:00+03	31400.00
3F6EA1	2017-08-02 14:46:00+03	48100.00
3F6F23	2017-08-10 18:54:00+03	49200.00
3F6F44	2017-07-05 10:26:00+03	45100.00
3F7000	2017-07-28 23:23:00+03	48800.00
3F709D	2017-08-04 21:16:00+03	213200.00
3F711B	2017-08-02 14:27:00+03	16400.00
3F7132	2017-07-12 03:57:00+03	6000.00
3F7159	2017-07-12 13:32:00+03	39500.00
3F715C	2017-08-08 05:51:00+03	58700.00
3F7182	2017-08-08 05:59:00+03	46400.00
3F7184	2017-08-08 18:42:00+03	30200.00
3F7196	2017-08-08 07:52:00+03	132800.00
3F71BE	2017-07-04 22:19:00+03	75300.00
3F71E2	2017-07-02 21:24:00+03	6200.00
3F71EB	2017-08-15 13:14:00+03	25400.00
3F7202	2017-08-07 02:36:00+03	22000.00
3F7204	2017-08-14 11:58:00+03	101600.00
3F7229	2017-08-15 11:42:00+03	83000.00
3F7258	2017-07-29 16:21:00+03	88600.00
3F726D	2017-07-08 23:07:00+03	28800.00
3F72DC	2017-08-12 15:18:00+03	20200.00
3F730A	2017-08-13 07:06:00+03	28800.00
3F7320	2017-07-12 06:58:00+03	20400.00
3F7349	2017-07-17 20:40:00+03	76800.00
3F73AC	2017-07-20 07:56:00+03	26000.00
3F73B3	2017-07-17 03:43:00+03	40800.00
3F73E2	2017-08-14 23:58:00+03	79900.00
3F73F6	2017-07-09 22:06:00+03	14800.00
3F7425	2017-07-23 19:27:00+03	168000.00
3F7450	2017-08-14 10:21:00+03	100400.00
3F7461	2017-07-17 18:49:00+03	72400.00
3F74D0	2017-08-04 14:10:00+03	93900.00
3F74DC	2017-08-12 05:30:00+03	26000.00
3F7557	2017-07-17 19:36:00+03	23600.00
3F75EA	2017-07-19 08:33:00+03	177700.00
3F7686	2017-07-21 00:28:00+03	263200.00
3F780C	2017-07-07 03:24:00+03	14400.00
3F7857	2017-08-11 00:34:00+03	265700.00
3F786D	2017-07-02 20:10:00+03	55800.00
3F7891	2017-07-29 22:38:00+03	21800.00
3F78A2	2017-08-14 15:07:00+03	243600.00
3F78EA	2017-08-14 11:21:00+03	50800.00
3F791E	2017-07-16 20:29:00+03	67900.00
3F79DC	2017-08-15 06:37:00+03	27600.00
3F79F8	2017-08-03 16:30:00+03	182000.00
3F7A2A	2017-08-02 14:22:00+03	101200.00
3F7A38	2017-07-22 20:21:00+03	98600.00
3F7A46	2017-08-02 12:15:00+03	106800.00
3F7A5C	2017-07-13 19:16:00+03	171900.00
3F7AA5	2017-07-05 13:25:00+03	47400.00
3F7AB0	2017-07-18 02:06:00+03	32400.00
3F7AB3	2017-07-03 16:04:00+03	58600.00
3F7B0E	2017-07-19 16:39:00+03	88800.00
3F7B12	2017-07-21 08:27:00+03	136200.00
3F7B78	2017-08-11 16:06:00+03	28000.00
3F7BFA	2017-08-14 15:25:00+03	94200.00
3F7C0D	2017-07-29 12:17:00+03	40100.00
3F7C48	2017-08-12 19:18:00+03	51900.00
3F7C5E	2017-07-28 12:23:00+03	159500.00
3F7C70	2017-07-31 19:42:00+03	3700.00
3F7D47	2017-07-18 02:26:00+03	58000.00
3F7D52	2017-08-02 18:21:00+03	117600.00
3F7D88	2017-07-14 11:13:00+03	28800.00
3F7E3A	2017-07-31 07:04:00+03	8000.00
3F7E74	2017-07-19 04:38:00+03	79900.00
3F7ECF	2017-07-24 12:44:00+03	30200.00
3F7ED0	2017-08-14 03:29:00+03	12000.00
3F7F59	2017-07-19 22:49:00+03	13700.00
3F7F5D	2017-07-16 07:27:00+03	67200.00
3F7FDF	2017-07-22 06:00:00+03	130800.00
3F7FF5	2017-07-07 17:33:00+03	73200.00
3F802E	2017-07-19 15:19:00+03	13600.00
3F8162	2017-08-14 17:11:00+03	127300.00
3F81E6	2017-07-04 16:11:00+03	181600.00
3F81EB	2017-08-05 23:56:00+03	131800.00
3F81F1	2017-07-13 22:58:00+03	28800.00
3F81FA	2017-07-10 22:11:00+03	39400.00
3F81FC	2017-08-09 11:26:00+03	63700.00
3F8261	2017-08-02 22:24:00+03	35600.00
3F8284	2017-07-26 03:20:00+03	252200.00
3F82B9	2017-07-08 12:57:00+03	62900.00
3F82CB	2017-08-05 02:45:00+03	136200.00
3F8323	2017-07-26 19:51:00+03	274600.00
3F8376	2017-07-31 15:37:00+03	125200.00
3F83A1	2017-07-06 04:36:00+03	53600.00
3F8434	2017-08-05 02:50:00+03	135300.00
3F8456	2017-07-05 14:56:00+03	58900.00
3F84A1	2017-08-13 20:32:00+03	7400.00
3F84B5	2017-08-12 14:31:00+03	166000.00
3F84E8	2017-07-25 20:29:00+03	51900.00
3F851A	2017-08-14 02:10:00+03	265700.00
3F8523	2017-07-10 13:36:00+03	25100.00
3F852B	2017-07-05 20:04:00+03	36200.00
3F852E	2017-08-02 04:04:00+03	81300.00
3F8538	2017-08-14 15:29:00+03	22000.00
3F8586	2017-07-15 13:33:00+03	23200.00
3F8597	2017-07-13 15:40:00+03	20400.00
3F85A2	2017-08-15 14:00:00+03	145100.00
3F85B8	2017-07-29 19:42:00+03	32800.00
3F85CD	2017-07-12 04:26:00+03	38600.00
3F85D1	2017-08-05 16:28:00+03	42800.00
3F85F0	2017-08-03 10:35:00+03	89700.00
3F862F	2017-07-23 19:08:00+03	44800.00
3F8679	2017-07-14 23:10:00+03	23600.00
3F86D0	2017-07-21 19:41:00+03	49800.00
3F86F0	2017-07-04 18:52:00+03	258400.00
3F86F7	2017-07-05 09:24:00+03	89600.00
3F8709	2017-07-23 02:05:00+03	28800.00
3F8745	2017-08-10 07:23:00+03	134400.00
3F8774	2017-07-12 00:39:00+03	177600.00
3F877D	2017-07-22 10:28:00+03	182000.00
3F87AB	2017-07-02 14:42:00+03	6000.00
3F87BB	2017-07-17 04:10:00+03	81600.00
3F8802	2017-07-11 16:18:00+03	11800.00
3F88E8	2017-08-15 12:50:00+03	109200.00
3F893D	2017-08-05 09:28:00+03	53400.00
3F895D	2017-08-08 01:23:00+03	271200.00
3F897B	2017-07-20 01:03:00+03	52700.00
3F898C	2017-07-12 16:25:00+03	23200.00
3F89BC	2017-08-11 21:20:00+03	36800.00
3F8A7B	2017-08-07 08:52:00+03	38800.00
3F8A8A	2017-07-02 11:58:00+03	32800.00
3F8B95	2017-07-21 11:03:00+03	62900.00
3F8BC5	2017-07-28 15:46:00+03	117600.00
3F8C3E	2017-07-28 04:24:00+03	99700.00
3F8C43	2017-07-12 01:05:00+03	37600.00
3F8C75	2017-07-06 11:31:00+03	48800.00
3F8CDA	2017-08-09 01:46:00+03	20100.00
3F8D10	2017-08-10 12:32:00+03	44800.00
3F8D3A	2017-06-28 21:30:00+03	114300.00
3F8DC0	2017-08-10 19:37:00+03	64800.00
3F8DDB	2017-07-30 04:59:00+03	36400.00
3F8DE1	2017-07-13 02:33:00+03	51000.00
3F8E21	2017-07-19 01:05:00+03	62800.00
3F8E32	2017-08-05 19:53:00+03	52600.00
3F8E7F	2017-07-24 12:04:00+03	66000.00
3F8E87	2017-07-13 22:28:00+03	32400.00
3F8EBE	2017-06-30 16:50:00+03	92400.00
3F8F46	2017-07-22 16:49:00+03	64800.00
3F8FAB	2017-07-25 00:51:00+03	101200.00
3F901D	2017-07-03 19:30:00+03	87000.00
3F9031	2017-08-14 04:32:00+03	66000.00
3F90AC	2017-08-10 21:46:00+03	100600.00
3F90AF	2017-08-07 09:26:00+03	79000.00
3F9110	2017-07-03 17:38:00+03	35300.00
3F9171	2017-07-07 20:11:00+03	30800.00
3F91C0	2017-07-02 17:10:00+03	111600.00
3F923B	2017-07-02 22:00:00+03	56600.00
3F923E	2017-07-29 04:08:00+03	44800.00
3F929B	2017-07-09 13:47:00+03	405000.00
3F9320	2017-07-25 04:31:00+03	27900.00
3F9334	2017-07-04 04:37:00+03	192400.00
3F9389	2017-07-21 03:00:00+03	34600.00
3F938E	2017-07-11 01:04:00+03	32700.00
3F93DE	2017-07-31 15:57:00+03	99300.00
3F93E3	2017-08-15 09:43:00+03	198300.00
3F940D	2017-07-02 06:58:00+03	13200.00
3F9418	2017-07-06 05:06:00+03	130200.00
3F94AA	2017-08-14 06:44:00+03	28000.00
3F94CE	2017-07-20 19:27:00+03	56000.00
3F94E8	2017-07-05 22:25:00+03	16800.00
3F9524	2017-08-10 23:00:00+03	22000.00
3F957D	2017-07-10 18:19:00+03	34000.00
3F958B	2017-07-17 11:22:00+03	102000.00
3F95F2	2017-07-15 05:07:00+03	32700.00
3F9608	2017-07-10 04:09:00+03	12600.00
3F961D	2017-08-04 17:32:00+03	43800.00
3F9660	2017-07-26 21:33:00+03	86100.00
3F96BD	2017-07-18 16:19:00+03	12600.00
3F9760	2017-07-02 04:25:00+03	62600.00
3F9777	2017-08-07 09:21:00+03	199600.00
3F9784	2017-08-13 06:14:00+03	120400.00
3F9826	2017-07-30 12:54:00+03	25600.00
3F9841	2017-07-05 18:14:00+03	66600.00
3F9844	2017-07-14 21:17:00+03	21400.00
3F987D	2017-07-29 13:40:00+03	188500.00
3F98A1	2017-07-06 07:11:00+03	44000.00
3F98C9	2017-07-30 16:09:00+03	31400.00
3F9932	2017-08-15 01:27:00+03	27900.00
3F9937	2017-08-10 05:37:00+03	38800.00
3F996D	2017-07-26 19:16:00+03	270700.00
3F998C	2017-07-02 04:01:00+03	58600.00
3F9994	2017-07-18 08:55:00+03	111600.00
3F99A9	2017-08-14 08:04:00+03	81300.00
3F9A08	2017-07-08 12:52:00+03	96100.00
3F9A23	2017-08-08 01:21:00+03	46400.00
3F9A3F	2017-08-11 05:18:00+03	187800.00
3F9A63	2017-06-30 02:01:00+03	56600.00
3F9ABA	2017-08-05 19:47:00+03	76600.00
3F9B2D	2017-07-24 04:34:00+03	43200.00
3F9B37	2017-06-28 03:09:00+03	23200.00
3F9B4E	2017-07-26 17:58:00+03	148800.00
3F9BEC	2017-07-22 12:41:00+03	399600.00
3F9C02	2017-07-21 16:11:00+03	67400.00
3F9C0F	2017-08-02 22:00:00+03	96300.00
3F9DA2	2017-07-26 22:00:00+03	88600.00
3F9DD0	2017-07-19 04:01:00+03	85000.00
3F9E0B	2017-07-13 05:56:00+03	46400.00
3F9E13	2017-08-03 09:52:00+03	32400.00
3F9E67	2017-08-02 14:55:00+03	6700.00
3F9E77	2017-08-02 10:02:00+03	24400.00
3F9E9A	2017-08-08 14:22:00+03	25800.00
3F9EE9	2017-07-19 08:27:00+03	55600.00
3F9F17	2017-08-09 18:23:00+03	24400.00
3F9F8F	2017-08-09 16:15:00+03	14400.00
3F9FA4	2017-07-19 15:25:00+03	58000.00
3F9FA8	2017-07-13 02:24:00+03	43100.00
3F9FBC	2017-07-14 09:55:00+03	24800.00
3F9FC8	2017-07-27 20:05:00+03	179300.00
3F9FE3	2017-08-11 12:03:00+03	69500.00
3F9FEB	2017-08-07 17:06:00+03	32800.00
3F9FFF	2017-07-13 16:27:00+03	75300.00
3FA005	2017-08-13 04:26:00+03	37700.00
3FA11A	2017-07-11 02:32:00+03	88800.00
3FA12D	2017-07-14 13:46:00+03	75200.00
3FA198	2017-07-06 00:57:00+03	24400.00
3FA1BE	2017-08-02 19:06:00+03	25600.00
3FA1C5	2017-08-11 11:33:00+03	74900.00
3FA1CA	2017-06-29 00:30:00+03	119600.00
3FA1ED	2017-07-12 18:57:00+03	306200.00
3FA1FE	2017-07-06 22:26:00+03	30800.00
3FA2B2	2017-07-17 20:39:00+03	67200.00
3FA333	2017-08-05 05:14:00+03	46400.00
3FA388	2017-08-10 17:19:00+03	129200.00
3FA3A9	2017-08-07 16:59:00+03	58900.00
3FA3BC	2017-08-15 15:03:00+03	62900.00
3FA3F0	2017-08-11 01:08:00+03	46400.00
3FA3F4	2017-07-30 01:13:00+03	43600.00
3FA40F	2017-07-30 10:33:00+03	48800.00
3FA472	2017-07-18 14:28:00+03	80000.00
3FA477	2017-08-01 06:20:00+03	44800.00
3FA503	2017-07-07 06:56:00+03	46300.00
3FA50E	2017-08-14 02:44:00+03	129200.00
3FA514	2017-08-05 21:38:00+03	35600.00
3FA540	2017-08-07 03:13:00+03	26200.00
3FA56B	2017-08-14 00:01:00+03	24800.00
3FA5C1	2017-07-25 23:22:00+03	175600.00
3FA664	2017-07-18 22:54:00+03	80300.00
3FA67C	2017-07-12 16:34:00+03	136200.00
3FA697	2017-08-15 11:59:00+03	125700.00
3FA6C7	2017-07-02 05:52:00+03	78600.00
3FA6DF	2017-08-15 05:05:00+03	45600.00
3FA75E	2017-08-02 01:12:00+03	109900.00
3FA778	2017-07-02 22:09:00+03	43500.00
3FA7E1	2017-07-13 01:01:00+03	88100.00
3FA80E	2017-07-25 07:37:00+03	123000.00
3FA82D	2017-07-30 04:13:00+03	31000.00
3FA82E	2017-08-14 20:30:00+03	80400.00
3FA867	2017-08-05 13:06:00+03	20200.00
3FA87A	2017-07-02 12:46:00+03	38800.00
3FA8D3	2017-07-09 00:13:00+03	87400.00
3FA8E2	2017-08-15 07:38:00+03	31600.00
3FA91F	2017-07-28 11:37:00+03	76400.00
3FA936	2017-08-11 20:30:00+03	35600.00
3FA93A	2017-08-02 16:28:00+03	8200.00
3FA966	2017-08-05 14:28:00+03	12000.00
3FA9A0	2017-07-05 13:12:00+03	57400.00
3FAB15	2017-07-23 18:49:00+03	40100.00
3FAB70	2017-07-17 00:42:00+03	54500.00
3FAB90	2017-08-15 01:44:00+03	27800.00
3FABCD	2017-07-13 22:10:00+03	26000.00
3FABD2	2017-08-02 07:14:00+03	36200.00
3FAC49	2017-07-15 02:33:00+03	46400.00
3FAC4B	2017-07-10 02:12:00+03	283500.00
3FACDD	2017-08-14 20:14:00+03	115900.00
3FAD41	2017-07-09 12:14:00+03	102700.00
3FADC3	2017-07-13 17:55:00+03	47400.00
3FAE06	2017-07-24 10:52:00+03	94000.00
3FAE81	2017-07-16 12:19:00+03	363400.00
3FAEBC	2017-08-01 06:02:00+03	56600.00
3FAEE4	2017-08-14 22:54:00+03	81500.00
3FAFFB	2017-07-10 08:53:00+03	27300.00
3FB00E	2017-07-04 22:17:00+03	30200.00
3FB0AB	2017-08-02 00:17:00+03	87000.00
3FB0AC	2017-07-24 12:42:00+03	92800.00
3FB0AF	2017-07-09 17:56:00+03	28000.00
3FB0EE	2017-07-09 05:21:00+03	137100.00
3FB13A	2017-06-28 22:46:00+03	84100.00
3FB194	2017-08-08 04:21:00+03	38800.00
3FB1AD	2017-07-31 20:50:00+03	13400.00
3FB1D9	2017-08-06 02:37:00+03	23200.00
3FB1FC	2017-07-24 01:01:00+03	36200.00
3FB27F	2017-08-04 04:40:00+03	74800.00
3FB2F5	2017-08-11 01:38:00+03	129000.00
3FB32C	2017-07-18 12:17:00+03	66600.00
3FB34B	2017-07-18 12:32:00+03	147100.00
3FB35D	2017-08-10 08:08:00+03	160200.00
3FB38E	2017-07-26 22:08:00+03	106400.00
3FB390	2017-08-08 20:05:00+03	83700.00
3FB3CF	2017-08-08 12:52:00+03	38600.00
3FB3DB	2017-08-13 01:20:00+03	92400.00
3FB44B	2017-07-14 17:24:00+03	30400.00
3FB452	2017-07-19 05:28:00+03	14400.00
3FB454	2017-07-27 09:01:00+03	85000.00
3FB459	2017-08-14 19:03:00+03	100600.00
3FB485	2017-08-02 11:18:00+03	55600.00
3FB49C	2017-07-15 05:27:00+03	21400.00
3FB506	2017-07-22 14:18:00+03	55800.00
3FB531	2017-08-07 01:52:00+03	55800.00
3FB5BB	2017-08-05 11:19:00+03	56000.00
3FB5C5	2017-08-07 11:40:00+03	113700.00
3FB625	2017-07-05 09:43:00+03	59300.00
3FB635	2017-07-02 15:47:00+03	70600.00
3FB70E	2017-07-27 22:50:00+03	47000.00
3FB79C	2017-07-02 13:56:00+03	68100.00
3FB7A2	2017-07-03 09:36:00+03	131600.00
3FB7D3	2017-08-08 11:57:00+03	11700.00
3FB7EA	2017-07-12 22:56:00+03	87000.00
3FB897	2017-08-06 03:46:00+03	270600.00
3FB8D3	2017-07-03 04:53:00+03	369000.00
3FB8E8	2017-07-25 18:11:00+03	6700.00
3FB8EB	2017-07-19 11:58:00+03	31800.00
3FB8EC	2017-08-01 23:39:00+03	265600.00
3FB8F5	2017-07-25 19:14:00+03	40100.00
3FB95E	2017-07-06 22:27:00+03	112000.00
3FB9D4	2017-08-12 23:05:00+03	59800.00
3FB9D7	2017-07-13 20:28:00+03	28000.00
3FB9D9	2017-08-15 07:30:00+03	128800.00
3FB9EC	2017-07-04 05:56:00+03	20200.00
3FB9F4	2017-08-07 16:09:00+03	25400.00
3FBA09	2017-07-02 20:18:00+03	28800.00
3FBA17	2017-07-24 21:05:00+03	41400.00
3FBA21	2017-07-09 21:55:00+03	21400.00
3FBA84	2017-07-01 16:04:00+03	21800.00
3FBAB9	2017-07-23 09:58:00+03	67700.00
3FBB50	2017-07-17 08:52:00+03	112000.00
3FBBD4	2017-07-22 23:50:00+03	68100.00
3FBC71	2017-07-09 02:35:00+03	260300.00
3FBCAB	2017-08-10 14:28:00+03	128800.00
3FBCBD	2017-07-27 23:23:00+03	99300.00
3FBCDB	2017-07-18 02:28:00+03	22000.00
3FBCED	2017-07-17 18:50:00+03	124200.00
3FBDB0	2017-07-07 07:51:00+03	36200.00
3FBDB2	2017-07-23 03:51:00+03	86600.00
3FBE47	2017-07-20 18:24:00+03	27200.00
3FBF1D	2017-08-13 06:21:00+03	10700.00
3FBF48	2017-07-17 19:45:00+03	26200.00
3FBF8F	2017-08-02 12:05:00+03	57300.00
3FBF9A	2017-07-14 21:51:00+03	57800.00
3FBFB9	2017-07-09 22:04:00+03	133200.00
3FBFD0	2017-08-04 14:07:00+03	6700.00
3FBFDB	2017-07-19 14:20:00+03	134900.00
3FC13C	2017-08-14 08:54:00+03	43600.00
3FC153	2017-07-03 02:18:00+03	270700.00
3FC168	2017-07-13 02:09:00+03	28000.00
3FC16B	2017-07-18 00:44:00+03	46000.00
3FC181	2017-07-28 19:09:00+03	47000.00
3FC191	2017-06-26 22:37:00+03	6700.00
3FC197	2017-07-08 13:47:00+03	67100.00
3FC1C6	2017-07-05 14:57:00+03	26000.00
3FC1CE	2017-08-10 17:55:00+03	68800.00
3FC228	2017-08-10 07:26:00+03	398500.00
3FC2A3	2017-07-03 04:04:00+03	46800.00
3FC30A	2017-06-28 08:09:00+03	120800.00
3FC376	2017-08-08 12:43:00+03	62000.00
3FC378	2017-07-10 18:42:00+03	12600.00
3FC3FB	2017-08-03 04:05:00+03	31400.00
3FC3FC	2017-07-21 18:08:00+03	39500.00
3FC425	2017-07-04 15:02:00+03	260700.00
3FC43B	2017-07-05 23:56:00+03	92400.00
3FC49C	2017-08-06 13:39:00+03	27900.00
3FC4A8	2017-07-10 10:41:00+03	199700.00
3FC504	2017-07-03 18:46:00+03	68800.00
3FC5B2	2017-07-06 10:48:00+03	30200.00
3FC630	2017-07-01 01:47:00+03	87200.00
3FC668	2017-06-27 10:29:00+03	109400.00
3FC69E	2017-07-14 01:15:00+03	83200.00
3FC6A7	2017-08-06 16:35:00+03	13800.00
3FC6C5	2017-06-26 23:55:00+03	68800.00
3FC6DF	2017-07-12 14:53:00+03	111600.00
3FC714	2017-07-21 04:35:00+03	266100.00
3FC7A5	2017-07-16 01:31:00+03	72300.00
3FC7C8	2017-07-30 14:14:00+03	25600.00
3FC7E3	2017-07-20 09:15:00+03	52900.00
3FC7F5	2017-07-22 03:08:00+03	34600.00
3FC82C	2017-07-14 20:21:00+03	26000.00
3FC918	2017-07-22 19:04:00+03	22000.00
3FC9C8	2017-06-28 01:00:00+03	25600.00
3FC9DE	2017-08-12 22:52:00+03	58800.00
3FCA58	2017-07-21 06:34:00+03	39200.00
3FCA61	2017-07-16 20:28:00+03	68100.00
3FCA6C	2017-07-14 02:14:00+03	119500.00
3FCA9B	2017-07-24 03:18:00+03	18800.00
3FCAFF	2017-07-27 03:36:00+03	136500.00
3FCB1F	2017-07-01 12:49:00+03	36200.00
3FCB75	2017-08-02 09:52:00+03	7300.00
3FCC41	2017-08-08 00:21:00+03	48700.00
3FCDF3	2017-08-12 05:37:00+03	54800.00
3FCE95	2017-07-21 16:47:00+03	23600.00
3FCECC	2017-08-10 14:45:00+03	85000.00
3FCEDB	2017-07-10 03:16:00+03	265400.00
3FCF1A	2017-07-15 07:50:00+03	67100.00
3FCFCE	2017-08-09 09:40:00+03	126700.00
3FCFFC	2017-08-14 13:21:00+03	70800.00
3FD053	2017-07-22 18:49:00+03	71500.00
3FD0F8	2017-08-12 08:36:00+03	111600.00
3FD111	2017-08-05 17:09:00+03	286700.00
3FD1A7	2017-07-06 20:36:00+03	56000.00
3FD1F0	2017-08-10 11:23:00+03	26700.00
3FD205	2017-08-04 19:15:00+03	66600.00
3FD218	2017-07-29 08:36:00+03	85000.00
3FD26D	2017-07-16 23:45:00+03	40400.00
3FD2B1	2017-07-02 22:50:00+03	46200.00
3FD303	2017-08-02 19:34:00+03	25600.00
3FD322	2017-08-10 16:36:00+03	54600.00
3FD32E	2017-07-15 06:07:00+03	28000.00
3FD3A4	2017-07-29 13:28:00+03	92000.00
3FD3CF	2017-07-20 07:37:00+03	38800.00
3FD3E9	2017-07-27 05:29:00+03	36200.00
3FD4BC	2017-07-11 11:10:00+03	6300.00
3FD506	2017-08-04 06:05:00+03	17800.00
3FD516	2017-08-14 06:56:00+03	36200.00
3FD52D	2017-07-21 02:23:00+03	62600.00
3FD534	2017-07-14 12:05:00+03	67000.00
3FD543	2017-07-22 13:14:00+03	134600.00
3FD5EB	2017-08-15 07:12:00+03	51800.00
3FD604	2017-07-27 14:15:00+03	54800.00
3FD658	2017-07-24 07:05:00+03	54500.00
3FD6E9	2017-07-07 04:56:00+03	69900.00
3FD715	2017-07-05 03:12:00+03	10700.00
3FD730	2017-07-19 09:59:00+03	113000.00
3FD74B	2017-08-02 12:40:00+03	112000.00
3FD76D	2017-08-15 05:00:00+03	46400.00
3FD7AA	2017-08-13 20:31:00+03	40800.00
3FD8A0	2017-08-13 07:13:00+03	92400.00
3FD945	2017-07-02 20:00:00+03	58700.00
3FD9D4	2017-07-13 04:34:00+03	23900.00
3FDA15	2017-07-09 21:46:00+03	48800.00
3FDA5F	2017-08-11 17:56:00+03	81300.00
3FDB7D	2017-07-24 04:13:00+03	86500.00
3FDB96	2017-07-24 21:01:00+03	46000.00
3FDC15	2017-06-24 08:31:00+03	49300.00
3FDC1C	2017-07-22 04:36:00+03	46400.00
3FDCAA	2017-07-26 02:36:00+03	14400.00
3FDCC8	2017-07-25 21:24:00+03	85700.00
3FDCF9	2017-08-10 08:53:00+03	113700.00
3FDD1E	2017-07-17 22:05:00+03	37900.00
3FDD27	2017-07-18 19:28:00+03	11200.00
3FDD5B	2017-08-08 21:44:00+03	24800.00
3FDDF3	2017-07-29 23:12:00+03	199700.00
3FDE09	2017-07-08 21:40:00+03	79600.00
3FDEBA	2017-07-12 16:59:00+03	321900.00
3FDEC5	2017-07-23 07:35:00+03	28800.00
3FDF30	2017-08-01 17:16:00+03	68800.00
3FDF3E	2017-08-10 10:32:00+03	34400.00
3FDF6B	2017-08-10 03:40:00+03	26000.00
3FDF6D	2017-06-25 00:56:00+03	46400.00
3FDFA3	2017-08-11 13:44:00+03	82700.00
3FE03F	2017-07-04 19:37:00+03	47200.00
3FE04B	2017-07-16 19:40:00+03	13300.00
3FE088	2017-07-10 17:40:00+03	136200.00
3FE0AD	2017-08-12 08:43:00+03	103800.00
3FE0AF	2017-07-14 19:02:00+03	78300.00
3FE0DC	2017-07-05 20:39:00+03	246000.00
3FE103	2017-07-02 06:30:00+03	66400.00
3FE112	2017-07-13 06:41:00+03	30800.00
3FE11C	2017-08-07 00:33:00+03	224000.00
3FE137	2017-07-12 13:49:00+03	273000.00
3FE1C2	2017-07-08 18:27:00+03	202400.00
3FE24B	2017-07-21 15:57:00+03	120400.00
3FE298	2017-06-30 23:48:00+03	34000.00
3FE2D7	2017-08-13 12:45:00+03	70800.00
3FE2EB	2017-08-15 15:11:00+03	166100.00
3FE2EC	2017-07-09 11:49:00+03	88700.00
3FE355	2017-08-04 21:30:00+03	123000.00
3FE37A	2017-07-07 09:25:00+03	52400.00
3FE38C	2017-08-07 04:59:00+03	199700.00
3FE3AA	2017-07-07 11:58:00+03	13600.00
3FE3B3	2017-08-03 11:10:00+03	168000.00
3FE3D6	2017-07-05 13:43:00+03	47700.00
3FE3DC	2017-07-04 11:08:00+03	40800.00
3FE3E7	2017-07-30 20:59:00+03	48800.00
3FE3EE	2017-07-12 06:06:00+03	56600.00
3FE46A	2017-07-09 20:31:00+03	27900.00
3FE4B4	2017-07-03 14:18:00+03	177800.00
3FE530	2017-07-05 15:59:00+03	103800.00
3FE53F	2017-07-11 07:47:00+03	14400.00
3FE541	2017-08-13 16:22:00+03	43900.00
3FE5E2	2017-08-14 04:48:00+03	99300.00
3FE651	2017-08-03 09:00:00+03	27200.00
3FE669	2017-07-30 11:57:00+03	73500.00
3FE6BA	2017-06-29 11:54:00+03	119600.00
3FE77C	2017-07-14 08:19:00+03	7400.00
3FE790	2017-08-14 19:33:00+03	47100.00
3FE829	2017-08-12 04:26:00+03	24400.00
3FE87D	2017-08-06 21:20:00+03	246000.00
3FE8D1	2017-08-04 08:32:00+03	46700.00
3FE8E6	2017-07-27 10:38:00+03	13400.00
3FE955	2017-08-06 22:32:00+03	270800.00
3FE980	2017-07-15 19:42:00+03	36200.00
3FE9FF	2017-07-28 12:07:00+03	26500.00
3FEA22	2017-08-14 17:37:00+03	65900.00
3FEA27	2017-07-29 02:55:00+03	68800.00
3FEA2C	2017-07-11 22:08:00+03	92800.00
3FEAF0	2017-07-08 12:05:00+03	113300.00
3FEB55	2017-08-09 17:15:00+03	123000.00
3FEBA8	2017-08-10 06:40:00+03	12200.00
3FEBD3	2017-07-14 10:40:00+03	36900.00
3FEBDB	2017-07-20 04:10:00+03	132800.00
3FEBE1	2017-08-11 16:50:00+03	62600.00
3FEC03	2017-08-05 04:53:00+03	57600.00
3FEC0A	2017-07-14 03:15:00+03	399300.00
3FEC26	2017-08-12 11:36:00+03	46300.00
3FED11	2017-07-21 05:00:00+03	71200.00
3FED86	2017-07-18 23:25:00+03	24400.00
3FEDDE	2017-07-03 06:03:00+03	133300.00
3FEDE2	2017-08-11 20:13:00+03	59700.00
3FEEA9	2017-08-02 21:23:00+03	28000.00
3FEEB2	2017-07-13 23:28:00+03	59000.00
3FEEC5	2017-07-29 18:00:00+03	92700.00
3FEF7E	2017-07-14 20:41:00+03	85200.00
3FEFF4	2017-07-02 00:03:00+03	6800.00
3FF0D9	2017-08-15 04:16:00+03	14000.00
3FF17B	2017-08-11 21:20:00+03	15400.00
3FF196	2017-07-10 10:04:00+03	89600.00
3FF1BA	2017-07-08 07:36:00+03	20200.00
3FF1F3	2017-07-26 16:43:00+03	260300.00
3FF211	2017-08-14 22:47:00+03	23400.00
3FF281	2017-07-11 21:25:00+03	111600.00
3FF292	2017-08-08 07:56:00+03	42800.00
3FF29F	2017-08-10 14:04:00+03	85000.00
3FF2E7	2017-07-15 01:38:00+03	23200.00
3FF2F2	2017-07-06 11:13:00+03	14400.00
3FF2FA	2017-07-20 12:35:00+03	6000.00
3FF348	2017-08-06 13:01:00+03	184500.00
3FF361	2017-06-28 20:08:00+03	225300.00
3FF3A8	2017-07-30 20:25:00+03	87200.00
3FF409	2017-08-11 05:25:00+03	85700.00
3FF451	2017-07-29 10:38:00+03	24000.00
3FF474	2017-08-11 21:28:00+03	26000.00
3FF4A4	2017-07-16 10:38:00+03	67700.00
3FF4D7	2017-07-25 18:57:00+03	81700.00
3FF4FA	2017-07-12 17:52:00+03	25100.00
3FF54F	2017-07-26 11:45:00+03	188000.00
3FF55C	2017-08-08 21:10:00+03	155500.00
3FF564	2017-07-09 12:23:00+03	12600.00
3FF5BB	2017-07-11 07:14:00+03	271700.00
3FF605	2017-08-06 07:24:00+03	103800.00
3FF64B	2017-08-13 03:58:00+03	11800.00
3FF684	2017-07-19 18:08:00+03	11600.00
3FF6AD	2017-07-25 08:12:00+03	204700.00
3FF725	2017-07-10 18:02:00+03	87100.00
3FF738	2017-07-27 19:59:00+03	47000.00
3FF7BE	2017-07-20 08:40:00+03	6700.00
3FF86F	2017-08-07 13:24:00+03	357600.00
3FF870	2017-07-31 04:08:00+03	145900.00
3FF962	2017-07-23 17:27:00+03	138000.00
3FF967	2017-07-24 07:10:00+03	83200.00
3FF9B6	2017-08-02 04:09:00+03	58600.00
3FF9BA	2017-07-04 23:34:00+03	21000.00
3FF9C2	2017-08-08 05:32:00+03	50400.00
3FF9DA	2017-08-03 21:25:00+03	20800.00
3FFA85	2017-08-08 02:38:00+03	28800.00
3FFAE4	2017-07-12 23:42:00+03	23200.00
3FFAF9	2017-07-06 21:29:00+03	35200.00
3FFB60	2017-08-01 02:43:00+03	55800.00
3FFBFE	2017-07-27 02:07:00+03	81600.00
3FFC72	2017-07-30 13:15:00+03	128800.00
3FFCCA	2017-07-19 09:00:00+03	60000.00
3FFD4B	2017-08-01 03:00:00+03	37900.00
3FFDB9	2017-08-09 09:41:00+03	54600.00
3FFE12	2017-08-02 11:57:00+03	98300.00
3FFE5F	2017-07-26 15:54:00+03	30200.00
3FFE73	2017-08-15 04:26:00+03	42500.00
3FFEA1	2017-08-10 03:32:00+03	8000.00
400006	2017-07-11 07:04:00+03	6700.00
400012	2017-07-05 19:24:00+03	14000.00
400042	2017-08-13 03:50:00+03	67200.00
4000D5	2017-08-04 23:17:00+03	50800.00
40011A	2017-07-19 01:59:00+03	75600.00
400132	2017-07-01 11:18:00+03	247200.00
400144	2017-07-15 08:12:00+03	44800.00
400175	2017-08-02 10:34:00+03	56600.00
40019A	2017-07-04 11:09:00+03	369000.00
4001CF	2017-07-11 19:15:00+03	56600.00
4001DC	2017-07-06 21:39:00+03	57600.00
400210	2017-07-02 10:55:00+03	56600.00
40021C	2017-07-04 09:07:00+03	67500.00
400290	2017-06-29 19:16:00+03	356400.00
400292	2017-07-30 11:55:00+03	56100.00
400376	2017-07-29 20:52:00+03	46300.00
40038D	2017-07-24 04:01:00+03	31100.00
4003A5	2017-08-09 13:05:00+03	161300.00
4003FD	2017-08-03 20:35:00+03	25600.00
400402	2017-07-22 15:43:00+03	36200.00
40042F	2017-07-16 12:22:00+03	23200.00
4004E1	2017-07-06 14:36:00+03	7400.00
4004F8	2017-08-10 08:08:00+03	14400.00
400502	2017-07-09 21:00:00+03	61800.00
40051B	2017-08-01 18:59:00+03	257400.00
40056A	2017-07-29 22:37:00+03	64100.00
400598	2017-08-01 17:27:00+03	166100.00
400601	2017-08-07 14:33:00+03	34000.00
400665	2017-08-09 23:30:00+03	40600.00
400670	2017-08-09 16:40:00+03	95500.00
400684	2017-07-24 08:14:00+03	40800.00
400708	2017-07-31 23:17:00+03	66200.00
40071E	2017-07-11 04:28:00+03	79600.00
400736	2017-08-07 09:32:00+03	90800.00
4007F1	2017-07-27 09:31:00+03	56900.00
400818	2017-07-17 20:12:00+03	185500.00
4008BD	2017-07-15 08:37:00+03	185000.00
4008CD	2017-07-20 08:42:00+03	54000.00
4008F5	2017-07-09 05:16:00+03	211100.00
4009B2	2017-07-17 17:51:00+03	85000.00
400A03	2017-08-09 03:03:00+03	67800.00
400A0E	2017-08-15 13:22:00+03	32700.00
400A2A	2017-06-26 22:20:00+03	82200.00
400A69	2017-07-13 11:38:00+03	24800.00
400AC9	2017-08-10 07:32:00+03	78100.00
400AF1	2017-07-21 04:53:00+03	96800.00
400B5A	2017-07-25 13:53:00+03	67900.00
400B5C	2017-07-18 00:54:00+03	19800.00
400B60	2017-07-04 10:47:00+03	92400.00
400C46	2017-06-30 07:55:00+03	21800.00
400C50	2017-07-27 04:48:00+03	13400.00
400C65	2017-07-25 18:23:00+03	28700.00
400CC9	2017-07-27 11:44:00+03	168000.00
400D19	2017-08-11 21:50:00+03	119400.00
400D28	2017-08-13 05:36:00+03	232800.00
400D67	2017-08-06 09:42:00+03	31200.00
400DBB	2017-08-08 14:27:00+03	36500.00
400E05	2017-07-27 23:14:00+03	110700.00
400E12	2017-07-07 01:52:00+03	29400.00
400E60	2017-08-09 11:47:00+03	86300.00
400E7D	2017-07-11 04:18:00+03	229400.00
400EBD	2017-06-30 15:21:00+03	252400.00
400EBF	2017-07-20 10:52:00+03	519600.00
400F2B	2017-08-03 17:18:00+03	56000.00
400F62	2017-07-18 08:06:00+03	137400.00
400FBC	2017-08-11 15:26:00+03	86400.00
4010B2	2017-08-14 19:27:00+03	13400.00
4010D3	2017-07-16 20:38:00+03	48800.00
4010F9	2017-07-12 16:43:00+03	45100.00
4010FC	2017-07-27 23:27:00+03	73400.00
40111A	2017-07-16 17:00:00+03	19600.00
40111C	2017-07-24 05:05:00+03	38600.00
401133	2017-08-03 13:43:00+03	67200.00
401140	2017-07-05 04:54:00+03	108500.00
401156	2017-07-29 09:12:00+03	86600.00
401174	2017-08-04 11:42:00+03	27900.00
40118A	2017-07-31 15:29:00+03	46800.00
40119E	2017-07-03 00:39:00+03	61900.00
4011B5	2017-07-07 08:22:00+03	209600.00
4011E6	2017-07-06 23:50:00+03	24600.00
401254	2017-07-05 12:53:00+03	79900.00
401257	2017-08-13 07:10:00+03	134700.00
401292	2017-08-15 03:52:00+03	32700.00
401304	2017-07-11 13:59:00+03	200000.00
401309	2017-08-06 22:26:00+03	33300.00
401311	2017-06-30 04:29:00+03	28800.00
401331	2017-08-09 13:15:00+03	30300.00
401378	2017-07-08 09:05:00+03	27900.00
4013A2	2017-07-14 07:06:00+03	68800.00
40142A	2017-07-26 22:55:00+03	53400.00
401468	2017-08-13 22:35:00+03	50900.00
401493	2017-08-02 13:06:00+03	17600.00
4014A8	2017-08-14 08:24:00+03	46200.00
401517	2017-08-03 02:44:00+03	47000.00
40160E	2017-07-08 21:22:00+03	46000.00
401669	2017-07-24 22:13:00+03	113200.00
40167D	2017-07-10 05:26:00+03	125900.00
401697	2017-08-06 01:57:00+03	400000.00
4016E6	2017-07-16 18:33:00+03	86600.00
40172E	2017-07-29 09:50:00+03	13200.00
401751	2017-07-12 18:13:00+03	56000.00
401786	2017-07-10 17:11:00+03	68800.00
40179E	2017-07-15 01:22:00+03	21800.00
4017AE	2017-06-29 17:04:00+03	22000.00
4017ED	2017-08-01 23:19:00+03	19600.00
401809	2017-08-11 03:50:00+03	187600.00
401858	2017-08-08 16:41:00+03	20200.00
401883	2017-08-07 05:47:00+03	13000.00
401900	2017-07-05 03:52:00+03	65600.00
40193C	2017-07-24 00:06:00+03	104800.00
401967	2017-07-08 07:56:00+03	208100.00
4019BF	2017-07-20 03:41:00+03	13400.00
4019D2	2017-07-24 19:05:00+03	47400.00
401A01	2017-07-14 09:58:00+03	42700.00
401A16	2017-07-29 11:54:00+03	56000.00
401A9B	2017-07-26 09:58:00+03	46400.00
401AEE	2017-07-11 13:40:00+03	23200.00
401AFB	2017-07-29 13:18:00+03	66600.00
401B03	2017-07-11 14:40:00+03	87600.00
401B35	2017-08-05 10:36:00+03	244800.00
401B36	2017-08-10 05:46:00+03	54000.00
401B83	2017-08-03 01:11:00+03	248300.00
401BDB	2017-08-11 02:09:00+03	24000.00
401BDF	2017-08-10 10:12:00+03	55500.00
401BF6	2017-07-14 19:02:00+03	265800.00
401C31	2017-07-11 09:56:00+03	56000.00
401C7C	2017-07-12 02:00:00+03	25200.00
401D34	2017-08-01 09:39:00+03	23400.00
401D61	2017-07-26 10:04:00+03	40900.00
401DCE	2017-08-14 18:39:00+03	23600.00
401DDC	2017-07-19 22:05:00+03	32900.00
401DEF	2017-08-10 17:51:00+03	78500.00
401E2C	2017-07-12 03:40:00+03	190200.00
401EAE	2017-06-28 11:43:00+03	25000.00
401F05	2017-07-28 21:30:00+03	51300.00
401F0F	2017-08-12 18:01:00+03	49500.00
401F1E	2017-08-09 23:34:00+03	17600.00
401F2F	2017-07-25 09:20:00+03	133700.00
401F62	2017-07-23 11:21:00+03	31600.00
401FD4	2017-07-20 02:14:00+03	120400.00
40200B	2017-08-09 13:06:00+03	313400.00
402034	2017-08-12 17:48:00+03	32800.00
4020E4	2017-07-29 06:48:00+03	75100.00
4020FE	2017-07-27 16:27:00+03	25800.00
40210A	2017-07-26 18:32:00+03	123600.00
40210F	2017-07-07 01:43:00+03	54800.00
40216C	2017-07-22 21:29:00+03	43600.00
4021C0	2017-08-03 10:34:00+03	65800.00
4021DD	2017-07-20 05:27:00+03	162700.00
4021FE	2017-08-03 12:41:00+03	14800.00
4022C6	2017-07-15 08:36:00+03	6000.00
4022DC	2017-08-14 16:28:00+03	24700.00
402304	2017-07-14 11:38:00+03	196400.00
402360	2017-07-06 05:57:00+03	103500.00
4023C8	2017-08-07 01:20:00+03	155000.00
4023F8	2017-08-03 13:50:00+03	67200.00
40242D	2017-07-25 15:07:00+03	87100.00
402455	2017-07-15 08:28:00+03	89600.00
402460	2017-07-02 07:11:00+03	102100.00
402480	2017-08-07 04:51:00+03	68100.00
4024CE	2017-07-14 04:43:00+03	28800.00
4024D1	2017-07-04 03:24:00+03	81700.00
4024F0	2017-07-25 23:03:00+03	88600.00
402511	2017-08-02 11:13:00+03	270700.00
40253A	2017-07-14 23:56:00+03	188000.00
402594	2017-07-22 06:50:00+03	83000.00
4025DC	2017-07-26 10:34:00+03	266400.00
4025DD	2017-07-19 08:54:00+03	186900.00
402603	2017-07-22 17:59:00+03	92800.00
402604	2017-07-04 02:43:00+03	56200.00
402650	2017-07-06 23:31:00+03	12400.00
402657	2017-07-11 18:33:00+03	26300.00
402661	2017-08-08 07:50:00+03	68000.00
402695	2017-07-14 06:53:00+03	78600.00
402727	2017-07-06 13:29:00+03	13600.00
40276B	2017-07-21 21:07:00+03	397700.00
4028D3	2017-07-22 07:42:00+03	406100.00
4028F9	2017-07-07 05:33:00+03	136200.00
402922	2017-08-08 18:21:00+03	16400.00
40294C	2017-07-30 01:35:00+03	35500.00
402952	2017-08-11 14:58:00+03	77900.00
402998	2017-07-06 15:37:00+03	46400.00
402A6A	2017-07-19 15:40:00+03	135400.00
402A79	2017-08-06 19:46:00+03	57600.00
402B0B	2017-07-06 09:57:00+03	65900.00
402B56	2017-07-24 16:23:00+03	369000.00
402B89	2017-08-05 11:24:00+03	135400.00
402BA7	2017-07-03 08:54:00+03	46000.00
402C42	2017-08-02 21:04:00+03	57600.00
402CA7	2017-07-13 19:26:00+03	67200.00
402CFA	2017-08-01 09:51:00+03	28000.00
402D2E	2017-07-23 21:15:00+03	12400.00
402D85	2017-06-30 23:31:00+03	16400.00
402E17	2017-08-12 04:50:00+03	22100.00
402E1E	2017-07-31 06:26:00+03	121600.00
402EF0	2017-08-10 00:34:00+03	22000.00
402EFD	2017-08-14 22:44:00+03	14000.00
402F1E	2017-08-06 00:49:00+03	72400.00
402F44	2017-07-26 11:55:00+03	105600.00
402F55	2017-07-25 09:28:00+03	29600.00
402F57	2017-06-30 11:19:00+03	26700.00
402F7F	2017-07-30 11:42:00+03	88500.00
402FB4	2017-08-08 02:45:00+03	35600.00
402FEF	2017-07-11 15:12:00+03	28800.00
403055	2017-07-11 08:09:00+03	51900.00
403070	2017-08-04 16:01:00+03	21400.00
403075	2017-07-14 06:30:00+03	255600.00
4030DF	2017-08-01 01:53:00+03	26000.00
4031F1	2017-08-01 21:09:00+03	83500.00
40324D	2017-07-31 10:29:00+03	46800.00
403250	2017-08-07 10:29:00+03	89600.00
403295	2017-07-02 20:37:00+03	48800.00
403321	2017-07-21 19:50:00+03	35600.00
403347	2017-07-20 20:20:00+03	118900.00
4033CD	2017-07-09 07:29:00+03	56600.00
403423	2017-08-11 17:21:00+03	99200.00
4034B8	2017-08-10 17:16:00+03	56600.00
4034D9	2017-07-22 20:10:00+03	65000.00
4034F6	2017-07-25 17:54:00+03	59000.00
403563	2017-07-09 07:31:00+03	24200.00
403589	2017-07-14 07:54:00+03	78000.00
4035B9	2017-08-01 06:25:00+03	63200.00
4035FD	2017-08-13 21:18:00+03	65900.00
403632	2017-07-10 03:31:00+03	35600.00
4036B5	2017-07-29 08:36:00+03	6000.00
4036BF	2017-08-06 12:45:00+03	386300.00
4036F6	2017-07-05 21:43:00+03	32700.00
4036FA	2017-08-09 13:25:00+03	102100.00
403716	2017-07-16 23:37:00+03	48800.00
40373A	2017-07-14 22:48:00+03	13400.00
40374F	2017-07-27 10:52:00+03	88100.00
40377A	2017-07-08 12:58:00+03	80200.00
403788	2017-07-09 12:07:00+03	73600.00
40378F	2017-07-12 04:25:00+03	96800.00
4037E0	2017-08-12 01:22:00+03	60400.00
4037EA	2017-07-10 01:12:00+03	21200.00
40383B	2017-08-13 21:10:00+03	8400.00
403921	2017-08-15 13:11:00+03	74000.00
403980	2017-07-22 06:34:00+03	14400.00
4039D9	2017-07-07 22:57:00+03	32200.00
403A0F	2017-08-07 19:15:00+03	81600.00
403A28	2017-07-02 20:18:00+03	35600.00
403A36	2017-08-10 17:05:00+03	56600.00
403A4A	2017-08-12 15:42:00+03	553200.00
403A50	2017-07-07 06:23:00+03	339900.00
403A82	2017-07-08 23:26:00+03	59200.00
403ABD	2017-08-05 17:55:00+03	6000.00
403AF6	2017-07-18 20:20:00+03	99300.00
403B1B	2017-08-10 19:19:00+03	120800.00
403B25	2017-08-10 20:11:00+03	40800.00
403B2A	2017-07-27 07:54:00+03	19600.00
403B3E	2017-07-13 18:14:00+03	25600.00
403B43	2017-08-06 02:54:00+03	40800.00
403B62	2017-06-30 12:02:00+03	28000.00
403BAF	2017-08-06 00:35:00+03	113200.00
403C3D	2017-07-30 18:41:00+03	65500.00
403CD5	2017-07-11 17:42:00+03	64200.00
403CE9	2017-08-15 04:30:00+03	81700.00
403D55	2017-07-25 16:44:00+03	15100.00
403D67	2017-07-12 20:57:00+03	21600.00
403E0A	2017-08-05 12:54:00+03	46400.00
403E24	2017-08-04 14:12:00+03	85000.00
403E42	2017-07-05 07:40:00+03	23200.00
403E5A	2017-08-03 14:12:00+03	139400.00
403E6B	2017-07-24 07:49:00+03	31700.00
403ED9	2017-08-11 08:41:00+03	29000.00
403EEF	2017-07-25 09:18:00+03	23200.00
403FC4	2017-08-12 05:50:00+03	29400.00
404016	2017-08-02 21:26:00+03	34400.00
404030	2017-08-13 22:00:00+03	40400.00
40404D	2017-08-01 00:17:00+03	18000.00
404094	2017-07-06 23:34:00+03	52900.00
4040A6	2017-08-09 05:15:00+03	125200.00
4040B8	2017-07-18 22:57:00+03	61500.00
404160	2017-08-11 07:45:00+03	28000.00
404168	2017-07-22 07:52:00+03	28000.00
40416C	2017-07-01 19:38:00+03	398500.00
4041F6	2017-08-07 19:28:00+03	94800.00
40426F	2017-07-15 08:12:00+03	111600.00
404275	2017-08-06 11:46:00+03	26200.00
4042C7	2017-08-13 21:45:00+03	103200.00
404351	2017-07-19 15:38:00+03	43200.00
40436B	2017-08-10 20:30:00+03	72400.00
404440	2017-07-14 23:51:00+03	85000.00
404444	2017-08-06 06:19:00+03	113500.00
40447A	2017-07-31 18:13:00+03	118500.00
4044A9	2017-08-15 16:31:00+03	56200.00
4044B4	2017-07-05 02:09:00+03	51900.00
404521	2017-07-27 17:36:00+03	27300.00
404522	2017-08-08 10:53:00+03	111600.00
40456D	2017-08-08 07:24:00+03	14800.00
40461E	2017-07-16 19:24:00+03	135400.00
404626	2017-07-09 21:02:00+03	82200.00
4046E0	2017-08-15 05:10:00+03	28000.00
40470F	2017-07-16 00:22:00+03	87700.00
404753	2017-08-09 23:03:00+03	57600.00
404770	2017-08-03 15:05:00+03	26200.00
4047C4	2017-07-12 11:23:00+03	85000.00
40484C	2017-07-04 23:00:00+03	60200.00
4048DD	2017-08-15 02:21:00+03	48800.00
404908	2017-08-13 19:28:00+03	91000.00
404913	2017-07-07 16:11:00+03	79300.00
4049BE	2017-07-24 07:56:00+03	47100.00
404A6D	2017-08-09 12:00:00+03	67700.00
404A7C	2017-07-09 01:57:00+03	46400.00
404AA3	2017-07-19 09:31:00+03	177200.00
404ACA	2017-08-14 22:10:00+03	66600.00
404B27	2017-08-07 19:36:00+03	23200.00
404B41	2017-07-09 09:16:00+03	25600.00
404B5F	2017-07-29 14:44:00+03	23200.00
404BCA	2017-08-11 21:35:00+03	169900.00
404BF1	2017-08-09 08:08:00+03	56200.00
404C63	2017-08-14 00:33:00+03	26000.00
404C88	2017-07-26 02:50:00+03	75300.00
404C8D	2017-07-18 17:41:00+03	185600.00
404CDB	2017-07-27 17:39:00+03	81300.00
404CDE	2017-08-04 12:05:00+03	87400.00
404CE1	2017-07-18 15:54:00+03	68100.00
404CF5	2017-08-06 07:07:00+03	24000.00
404D36	2017-07-21 15:10:00+03	77500.00
404D4E	2017-07-11 13:14:00+03	116400.00
404DE1	2017-08-13 22:29:00+03	258400.00
404E34	2017-08-02 03:49:00+03	85000.00
404E3B	2017-07-28 03:43:00+03	187800.00
404E45	2017-07-09 19:12:00+03	4000.00
404E61	2017-06-29 18:56:00+03	172100.00
404F4D	2017-07-18 08:53:00+03	17800.00
404F9D	2017-07-17 19:16:00+03	249300.00
404FEF	2017-08-12 06:50:00+03	25100.00
40503B	2017-08-02 17:09:00+03	16400.00
4050A1	2017-07-30 12:58:00+03	18100.00
4050F0	2017-07-04 08:23:00+03	39800.00
4050FF	2017-07-08 07:38:00+03	55600.00
4051B3	2017-07-24 00:21:00+03	26000.00
4051BE	2017-08-03 12:17:00+03	96300.00
405246	2017-07-20 03:54:00+03	23600.00
40525D	2017-07-23 20:12:00+03	81700.00
405278	2017-08-13 01:36:00+03	270700.00
40530F	2017-07-28 17:20:00+03	34000.00
40533E	2017-07-02 01:21:00+03	39200.00
405359	2017-07-22 02:33:00+03	44800.00
40536A	2017-06-27 13:50:00+03	50600.00
4053B3	2017-08-09 04:19:00+03	45100.00
4053D8	2017-08-03 00:45:00+03	21600.00
405425	2017-07-12 02:23:00+03	50600.00
40542F	2017-07-02 11:13:00+03	95200.00
405447	2017-08-13 04:37:00+03	38400.00
405485	2017-08-01 20:48:00+03	399600.00
4054BD	2017-08-09 13:52:00+03	128800.00
4054DE	2017-07-27 04:47:00+03	27800.00
4054F7	2017-08-10 13:07:00+03	88400.00
4054FD	2017-07-15 18:51:00+03	152400.00
405533	2017-07-08 17:24:00+03	138000.00
405588	2017-08-14 09:16:00+03	111600.00
405590	2017-08-14 18:53:00+03	67300.00
4055BF	2017-08-03 01:21:00+03	112000.00
4055F2	2017-07-31 06:37:00+03	96300.00
4056A9	2017-07-04 09:10:00+03	133100.00
405725	2017-07-14 04:02:00+03	23200.00
40575B	2017-08-15 04:31:00+03	51600.00
405804	2017-08-09 07:50:00+03	52000.00
405807	2017-07-01 02:01:00+03	60400.00
405835	2017-06-29 05:44:00+03	42700.00
40586A	2017-07-21 13:31:00+03	31800.00
405870	2017-07-11 07:07:00+03	40200.00
4058DF	2017-07-31 11:52:00+03	62900.00
4058E0	2017-07-31 06:38:00+03	518000.00
4058EE	2017-08-02 08:14:00+03	85700.00
405922	2017-08-04 01:53:00+03	73300.00
405940	2017-07-30 08:43:00+03	24000.00
405992	2017-07-16 01:24:00+03	66600.00
405999	2017-07-18 12:19:00+03	66000.00
4059DC	2017-07-10 06:40:00+03	29600.00
405A27	2017-08-02 07:13:00+03	44800.00
405A3C	2017-08-14 02:11:00+03	133100.00
405A79	2017-07-30 04:56:00+03	38800.00
405B0B	2017-07-04 22:47:00+03	94800.00
405B36	2017-07-21 15:05:00+03	37700.00
405B68	2017-07-06 17:04:00+03	58600.00
405B73	2017-07-10 02:10:00+03	38600.00
405B8B	2017-07-11 18:02:00+03	103200.00
405BE4	2017-08-05 02:19:00+03	136200.00
405C24	2017-07-08 01:45:00+03	138800.00
405C35	2017-07-11 17:44:00+03	40800.00
405C49	2017-08-02 02:43:00+03	30200.00
405C6C	2017-08-04 08:25:00+03	52900.00
405CA5	2017-07-29 00:08:00+03	115400.00
405CD4	2017-07-31 15:29:00+03	8200.00
405CFE	2017-07-28 22:01:00+03	25400.00
405D34	2017-08-07 05:00:00+03	68800.00
405D3F	2017-07-24 17:34:00+03	52300.00
405DAD	2017-07-05 00:54:00+03	72200.00
405E6C	2017-07-17 04:36:00+03	100600.00
405E8A	2017-08-09 14:25:00+03	103500.00
405EF3	2017-07-11 10:27:00+03	132800.00
405EF7	2017-07-30 15:27:00+03	516800.00
40601E	2017-07-07 10:05:00+03	12000.00
40604C	2017-07-15 17:44:00+03	56000.00
40617B	2017-08-13 06:20:00+03	69000.00
4061C2	2017-08-08 18:02:00+03	185000.00
4061D0	2017-06-29 07:58:00+03	25800.00
406211	2017-08-07 12:19:00+03	26000.00
40625A	2017-07-03 06:26:00+03	52400.00
40625E	2017-07-28 00:37:00+03	90700.00
406270	2017-07-31 21:55:00+03	56000.00
4062AE	2017-07-04 08:28:00+03	67200.00
4062C9	2017-07-11 09:38:00+03	16400.00
4062E9	2017-08-04 09:36:00+03	61800.00
40630C	2017-08-08 12:46:00+03	240600.00
406394	2017-07-28 09:13:00+03	266400.00
4063C3	2017-07-29 12:43:00+03	173900.00
4063C4	2017-07-14 07:37:00+03	60400.00
406433	2017-08-15 17:43:00+03	145200.00
40645A	2017-07-11 13:40:00+03	93900.00
40646B	2017-07-25 18:51:00+03	123600.00
40647E	2017-07-01 10:09:00+03	56900.00
406480	2017-07-16 17:10:00+03	36800.00
40649A	2017-07-16 23:02:00+03	68800.00
4064B6	2017-08-02 08:11:00+03	28800.00
4064C3	2017-08-03 03:40:00+03	51300.00
4064DC	2017-07-10 09:52:00+03	27800.00
406630	2017-07-27 10:05:00+03	75300.00
40663B	2017-07-07 16:59:00+03	169900.00
4066AF	2017-08-09 00:47:00+03	105000.00
4066BB	2017-07-23 06:13:00+03	132800.00
4066FB	2017-07-16 08:48:00+03	51900.00
4067B6	2017-07-18 00:29:00+03	77000.00
4067DE	2017-08-09 16:55:00+03	53500.00
4068CD	2017-07-19 07:24:00+03	20200.00
4068F0	2017-07-05 14:40:00+03	54800.00
4068FA	2017-08-08 20:57:00+03	273400.00
406919	2017-08-15 07:08:00+03	60400.00
406994	2017-07-28 11:04:00+03	36400.00
406A07	2017-07-07 15:37:00+03	147700.00
406A3C	2017-08-13 09:28:00+03	31000.00
406A42	2017-08-04 00:53:00+03	15000.00
406A5C	2017-07-10 01:17:00+03	53600.00
406A87	2017-07-03 13:14:00+03	27200.00
406A8F	2017-07-25 05:02:00+03	64800.00
406AAF	2017-07-16 02:00:00+03	47100.00
406AFC	2017-08-14 23:03:00+03	149800.00
406B15	2017-07-24 12:12:00+03	71900.00
406B21	2017-07-25 12:48:00+03	37200.00
406B29	2017-07-05 05:01:00+03	76300.00
406BC2	2017-08-13 11:52:00+03	57700.00
406BF0	2017-08-13 14:11:00+03	102000.00
406C28	2017-07-01 14:25:00+03	19600.00
406C48	2017-07-13 09:26:00+03	48300.00
406C5C	2017-08-13 17:30:00+03	7400.00
406C69	2017-08-01 00:39:00+03	142400.00
406CB5	2017-07-28 16:42:00+03	54000.00
406D0F	2017-06-30 01:37:00+03	45200.00
406D6E	2017-06-28 11:10:00+03	112600.00
406D84	2017-07-02 05:37:00+03	38500.00
406DC4	2017-07-28 08:54:00+03	66600.00
406E01	2017-07-03 06:28:00+03	94000.00
406E3F	2017-08-06 22:34:00+03	72200.00
406E76	2017-07-13 05:26:00+03	17000.00
406E88	2017-07-06 22:35:00+03	23600.00
406E94	2017-07-09 10:23:00+03	55800.00
406EF8	2017-07-19 03:37:00+03	62900.00
406F3F	2017-08-12 15:48:00+03	6700.00
406F60	2017-08-13 17:35:00+03	47200.00
406F9D	2017-07-07 12:00:00+03	102300.00
406FDC	2017-07-03 05:49:00+03	254900.00
406FF4	2017-07-07 18:08:00+03	6800.00
407035	2017-08-08 18:50:00+03	25800.00
407047	2017-08-01 17:10:00+03	14800.00
407055	2017-07-04 12:03:00+03	85700.00
407083	2017-07-19 15:17:00+03	31600.00
4070C1	2017-08-06 07:17:00+03	100300.00
407118	2017-08-01 22:18:00+03	119500.00
40712D	2017-07-16 08:21:00+03	181400.00
407137	2017-08-07 12:31:00+03	55800.00
40716E	2017-07-25 09:47:00+03	219300.00
40718D	2017-07-13 23:31:00+03	46300.00
4071A1	2017-07-18 08:17:00+03	22000.00
4071B4	2017-06-28 13:35:00+03	123000.00
4071C0	2017-07-31 01:28:00+03	108200.00
4071E0	2017-08-06 09:57:00+03	20400.00
40720D	2017-07-15 18:14:00+03	37900.00
40722C	2017-07-30 13:44:00+03	69500.00
40727D	2017-07-07 06:47:00+03	22000.00
407285	2017-07-28 05:40:00+03	36600.00
407295	2017-08-01 06:02:00+03	65000.00
4072DA	2017-08-05 10:43:00+03	27800.00
407326	2017-07-10 06:14:00+03	33000.00
40744F	2017-07-19 22:21:00+03	23600.00
40746B	2017-08-10 14:24:00+03	46800.00
4074CC	2017-07-28 08:32:00+03	75600.00
4074DE	2017-07-31 19:02:00+03	7400.00
4074DF	2017-07-03 13:51:00+03	21000.00
4074FC	2017-07-04 22:22:00+03	47500.00
40751C	2017-08-13 04:30:00+03	47900.00
40752F	2017-07-30 22:32:00+03	265800.00
40753B	2017-07-11 18:31:00+03	53600.00
407575	2017-08-12 03:45:00+03	56000.00
40761E	2017-08-12 12:24:00+03	59300.00
407715	2017-07-01 16:52:00+03	48700.00
407728	2017-07-21 13:28:00+03	186500.00
407735	2017-07-18 11:55:00+03	135200.00
40773D	2017-08-11 18:11:00+03	6700.00
4077E6	2017-07-17 07:20:00+03	46500.00
4077FB	2017-07-12 02:52:00+03	36200.00
40787A	2017-08-09 13:43:00+03	270000.00
40787E	2017-08-01 14:10:00+03	406200.00
4078D7	2017-07-06 23:16:00+03	23200.00
40793C	2017-07-08 00:05:00+03	444600.00
4079F7	2017-08-11 13:01:00+03	55800.00
4079FE	2017-08-11 19:32:00+03	27400.00
407A47	2017-07-12 19:48:00+03	14000.00
407A63	2017-08-12 11:03:00+03	28000.00
407A85	2017-08-12 11:06:00+03	56000.00
407A9E	2017-07-05 10:49:00+03	28000.00
407B46	2017-07-17 03:23:00+03	150600.00
407B7C	2017-08-03 18:42:00+03	26000.00
407B7D	2017-07-23 11:54:00+03	51900.00
407BE0	2017-07-29 18:28:00+03	46000.00
407BEF	2017-07-03 13:52:00+03	119600.00
407C27	2017-08-13 19:46:00+03	23600.00
407C58	2017-07-23 06:02:00+03	14400.00
407CF9	2017-07-13 15:29:00+03	65900.00
407D13	2017-08-06 01:57:00+03	23200.00
407D68	2017-07-21 14:19:00+03	133100.00
407D76	2017-07-21 23:44:00+03	95900.00
407DB6	2017-08-04 22:24:00+03	33300.00
407DEF	2017-08-14 11:46:00+03	38400.00
407E62	2017-07-14 16:07:00+03	185300.00
407ECC	2017-08-14 05:02:00+03	79600.00
407F03	2017-08-10 23:09:00+03	135600.00
407F1E	2017-07-14 02:33:00+03	16400.00
407F24	2017-07-13 10:09:00+03	16400.00
407F49	2017-07-13 16:52:00+03	16600.00
407F59	2017-07-06 05:10:00+03	201800.00
407FDD	2017-07-31 04:05:00+03	20200.00
40805F	2017-07-14 16:50:00+03	100600.00
408149	2017-07-22 05:07:00+03	114700.00
408158	2017-08-10 20:30:00+03	37100.00
40815E	2017-07-21 12:29:00+03	37900.00
40818D	2017-07-16 16:29:00+03	25000.00
4081D3	2017-07-02 21:54:00+03	129400.00
4081E3	2017-07-27 00:52:00+03	66600.00
4081FA	2017-07-25 09:48:00+03	37900.00
40820A	2017-07-28 10:41:00+03	68800.00
40822D	2017-08-15 03:11:00+03	60300.00
408230	2017-07-25 16:55:00+03	119400.00
4082A4	2017-07-16 12:07:00+03	36200.00
408329	2017-07-15 14:32:00+03	75500.00
408344	2017-07-03 19:43:00+03	54200.00
4083CA	2017-07-10 01:55:00+03	406700.00
4083F4	2017-08-12 14:20:00+03	169000.00
408429	2017-07-12 04:34:00+03	24000.00
4084D9	2017-07-26 06:16:00+03	28000.00
408516	2017-06-27 08:09:00+03	37200.00
40854D	2017-08-04 15:09:00+03	397300.00
4085AB	2017-08-06 23:06:00+03	36200.00
4085B8	2017-07-11 20:17:00+03	112000.00
4085D1	2017-08-03 20:37:00+03	58900.00
408613	2017-07-21 15:57:00+03	83000.00
408617	2017-07-11 00:29:00+03	31400.00
408644	2017-07-05 05:44:00+03	111600.00
408716	2017-07-14 20:25:00+03	56000.00
408756	2017-07-11 07:53:00+03	114800.00
40876D	2017-08-06 02:48:00+03	43200.00
408801	2017-07-11 10:32:00+03	263900.00
40882D	2017-07-04 06:44:00+03	52200.00
408838	2017-07-05 16:17:00+03	26700.00
408865	2017-07-30 03:07:00+03	51900.00
4088B3	2017-07-07 17:49:00+03	27300.00
4088F0	2017-07-26 05:26:00+03	16400.00
408908	2017-07-06 15:37:00+03	136300.00
4089EE	2017-08-14 18:32:00+03	135400.00
408A5E	2017-08-02 21:14:00+03	597300.00
408A80	2017-08-14 04:43:00+03	165500.00
408A9D	2017-08-03 17:13:00+03	12400.00
408AB3	2017-08-04 05:57:00+03	38600.00
408AB9	2017-07-03 18:26:00+03	189200.00
408AC8	2017-08-09 08:28:00+03	42800.00
408AEF	2017-07-20 03:56:00+03	40000.00
408B01	2017-07-02 20:38:00+03	90400.00
408C20	2017-08-13 04:14:00+03	49600.00
408C2F	2017-08-08 01:07:00+03	48800.00
408C4C	2017-07-30 12:51:00+03	101600.00
408CC5	2017-08-05 01:16:00+03	88900.00
408CF2	2017-08-01 17:38:00+03	103200.00
408D01	2017-07-07 16:05:00+03	34400.00
408D12	2017-07-18 16:18:00+03	46900.00
408D13	2017-07-13 12:41:00+03	89700.00
408D32	2017-08-05 08:24:00+03	81900.00
408D60	2017-07-04 11:12:00+03	190400.00
408D9D	2017-07-05 07:20:00+03	246000.00
408DD6	2017-07-11 21:36:00+03	81000.00
408E2A	2017-07-10 16:17:00+03	65900.00
408E43	2017-06-30 16:12:00+03	79700.00
408E9C	2017-08-03 19:26:00+03	30200.00
408EA4	2017-07-19 05:07:00+03	92400.00
408EAE	2017-07-18 12:44:00+03	26800.00
408F77	2017-08-13 13:59:00+03	28000.00
408FAB	2017-07-31 20:47:00+03	338900.00
409032	2017-07-17 09:51:00+03	18000.00
40903F	2017-08-11 20:30:00+03	58800.00
40912E	2017-07-25 17:19:00+03	26700.00
40914A	2017-08-11 07:52:00+03	92000.00
409155	2017-08-09 15:14:00+03	103500.00
409162	2017-08-03 17:12:00+03	111600.00
409183	2017-08-05 15:53:00+03	30900.00
40919A	2017-07-28 12:22:00+03	55800.00
409236	2017-07-20 14:13:00+03	29600.00
409249	2017-07-07 09:30:00+03	109800.00
40925E	2017-07-08 04:33:00+03	179200.00
409261	2017-07-09 13:13:00+03	23400.00
40926C	2017-08-13 02:14:00+03	136800.00
40926F	2017-08-05 18:17:00+03	46400.00
4092C7	2017-07-20 19:00:00+03	178800.00
409319	2017-08-03 18:34:00+03	78200.00
40934A	2017-07-21 07:35:00+03	199600.00
409361	2017-07-31 15:05:00+03	85000.00
4093FD	2017-07-13 19:00:00+03	70700.00
409442	2017-07-19 13:04:00+03	111600.00
40946D	2017-07-29 12:38:00+03	158300.00
40946F	2017-07-27 13:43:00+03	12000.00
40948F	2017-08-01 16:11:00+03	23200.00
4094DC	2017-07-01 13:58:00+03	77000.00
4094E8	2017-07-21 02:15:00+03	23600.00
40952E	2017-08-01 14:20:00+03	67000.00
409536	2017-07-23 20:41:00+03	68000.00
409550	2017-08-09 22:24:00+03	132800.00
40962C	2017-08-13 00:37:00+03	37100.00
40967C	2017-07-06 07:06:00+03	23600.00
40968B	2017-07-29 11:36:00+03	83700.00
4096AD	2017-07-18 05:46:00+03	52300.00
4096BF	2017-07-23 12:27:00+03	58800.00
4096E8	2017-07-12 22:53:00+03	372500.00
40972D	2017-07-08 03:18:00+03	24400.00
40974A	2017-08-05 18:10:00+03	28800.00
40974E	2017-08-04 08:01:00+03	13700.00
409770	2017-07-06 12:20:00+03	202200.00
4097B3	2017-07-11 23:40:00+03	132800.00
4097DC	2017-07-22 10:52:00+03	98200.00
409800	2017-07-10 23:52:00+03	6700.00
40982C	2017-07-04 10:26:00+03	46200.00
409906	2017-08-12 09:38:00+03	36800.00
409907	2017-06-30 21:50:00+03	108000.00
409909	2017-07-18 17:38:00+03	132800.00
409997	2017-07-05 19:13:00+03	108000.00
409A3D	2017-08-11 06:22:00+03	52800.00
409A41	2017-07-21 10:42:00+03	15000.00
409A42	2017-06-29 18:21:00+03	24200.00
409A5B	2017-07-15 18:55:00+03	24600.00
409A9B	2017-07-09 16:23:00+03	156600.00
409AC9	2017-07-14 10:06:00+03	58200.00
409AF8	2017-07-15 21:30:00+03	61500.00
409B62	2017-07-25 05:41:00+03	44800.00
409B75	2017-07-24 06:58:00+03	108500.00
409BB1	2017-07-10 12:58:00+03	29600.00
409BF5	2017-07-24 10:57:00+03	88700.00
409C06	2017-07-20 10:28:00+03	59800.00
409C34	2017-08-02 06:02:00+03	62700.00
409C58	2017-07-21 00:19:00+03	65500.00
409CA2	2017-07-08 02:41:00+03	26800.00
409D12	2017-06-30 01:51:00+03	27200.00
409D19	2017-07-06 01:12:00+03	48500.00
409D52	2017-08-09 20:53:00+03	114300.00
409D55	2017-07-12 22:52:00+03	28000.00
409DE3	2017-08-07 17:06:00+03	91800.00
409E2C	2017-07-25 10:27:00+03	93900.00
409E33	2017-07-02 02:12:00+03	24500.00
409E63	2017-06-30 06:15:00+03	63200.00
409E8E	2017-06-30 12:27:00+03	111600.00
409EB8	2017-07-14 16:08:00+03	16800.00
409EC7	2017-07-15 18:08:00+03	56200.00
409F24	2017-08-12 20:06:00+03	257500.00
409F35	2017-07-14 23:27:00+03	57500.00
409F68	2017-07-23 00:12:00+03	369000.00
409F9F	2017-07-15 17:34:00+03	193200.00
40A02B	2017-07-13 22:59:00+03	28000.00
40A0E8	2017-07-20 07:58:00+03	64000.00
40A105	2017-07-19 13:27:00+03	26000.00
40A141	2017-08-09 09:28:00+03	71200.00
40A1C9	2017-07-26 22:54:00+03	75800.00
40A234	2017-07-10 00:33:00+03	30200.00
40A271	2017-07-06 06:38:00+03	25400.00
40A293	2017-07-19 07:45:00+03	208300.00
40A3B9	2017-08-10 19:44:00+03	123000.00
40A3C5	2017-07-21 10:56:00+03	24800.00
40A3CD	2017-07-11 04:41:00+03	92800.00
40A40D	2017-08-01 02:05:00+03	85700.00
40A40E	2017-07-17 15:56:00+03	226900.00
40A49A	2017-08-08 13:18:00+03	67000.00
40A4A1	2017-08-10 15:13:00+03	140900.00
40A4AD	2017-07-25 12:25:00+03	26000.00
40A4B2	2017-07-07 07:59:00+03	42400.00
40A506	2017-08-13 23:16:00+03	76600.00
40A555	2017-07-10 16:31:00+03	210000.00
40A56A	2017-08-07 17:34:00+03	29600.00
40A60B	2017-07-07 11:10:00+03	46400.00
40A657	2017-07-24 03:48:00+03	52700.00
40A65A	2017-08-15 14:03:00+03	191400.00
40A691	2017-08-02 04:02:00+03	291200.00
40A751	2017-07-22 19:07:00+03	136200.00
40A764	2017-08-02 11:29:00+03	6600.00
40A78E	2017-07-22 21:21:00+03	20400.00
40A7AE	2017-08-12 06:29:00+03	52700.00
40A7E4	2017-08-13 07:47:00+03	24000.00
40A7EE	2017-07-01 00:10:00+03	47600.00
40A7FD	2017-07-31 16:29:00+03	61600.00
40A801	2017-06-27 18:19:00+03	67100.00
40A890	2017-08-13 10:59:00+03	10800.00
40A91F	2017-08-09 11:30:00+03	27800.00
40A9AD	2017-07-23 11:26:00+03	166000.00
40A9E3	2017-08-11 04:23:00+03	109000.00
40AAAB	2017-07-07 20:02:00+03	28000.00
40AADD	2017-07-11 04:10:00+03	39200.00
40AB35	2017-07-28 21:24:00+03	68000.00
40ABB5	2017-07-25 13:31:00+03	64200.00
40AC07	2017-07-08 17:20:00+03	258400.00
40AC25	2017-07-01 04:08:00+03	25000.00
40AC9C	2017-07-11 07:13:00+03	131600.00
40ACA0	2017-07-18 20:59:00+03	128500.00
40ACCB	2017-07-26 07:36:00+03	51000.00
40AD2C	2017-07-07 18:40:00+03	93600.00
40ADA0	2017-07-06 02:59:00+03	91000.00
40ADAF	2017-07-22 20:37:00+03	376000.00
40AE67	2017-07-05 14:40:00+03	34000.00
40AEB2	2017-07-24 17:16:00+03	210200.00
40AEEB	2017-07-31 05:51:00+03	15000.00
40AFBC	2017-07-04 22:42:00+03	12000.00
40AFE0	2017-08-15 06:31:00+03	32700.00
40AFEC	2017-08-11 08:29:00+03	31600.00
40B013	2017-07-07 12:56:00+03	99200.00
40B041	2017-07-31 17:51:00+03	75600.00
40B075	2017-07-27 13:02:00+03	87400.00
40B0D9	2017-08-06 07:28:00+03	258400.00
40B0E7	2017-08-02 17:33:00+03	104200.00
40B104	2017-07-31 06:03:00+03	21800.00
40B10C	2017-07-20 02:40:00+03	58700.00
40B112	2017-07-05 23:47:00+03	56000.00
40B144	2017-08-09 18:45:00+03	233700.00
40B1A3	2017-07-13 22:09:00+03	161600.00
40B226	2017-06-29 02:53:00+03	62200.00
40B25E	2017-07-07 02:46:00+03	62000.00
40B2DD	2017-08-01 20:38:00+03	89600.00
40B2EE	2017-08-05 10:54:00+03	38800.00
40B33E	2017-07-09 07:17:00+03	257500.00
40B35B	2017-07-17 11:56:00+03	54800.00
40B374	2017-08-04 11:22:00+03	248300.00
40B449	2017-08-10 09:09:00+03	86300.00
40B466	2017-08-02 04:59:00+03	21400.00
40B487	2017-07-18 09:55:00+03	111600.00
40B4B9	2017-08-03 22:29:00+03	26000.00
40B4CC	2017-07-26 22:42:00+03	250600.00
40B51F	2017-07-16 00:26:00+03	91100.00
40B56D	2017-07-27 07:51:00+03	136200.00
40B671	2017-08-14 11:13:00+03	13200.00
40B68E	2017-07-16 14:22:00+03	27200.00
40B6C9	2017-08-09 02:13:00+03	79700.00
40B74A	2017-07-19 00:41:00+03	144300.00
40B761	2017-08-04 22:36:00+03	124600.00
40B762	2017-07-05 21:22:00+03	37700.00
40B766	2017-08-10 08:25:00+03	23600.00
40B786	2017-08-02 03:15:00+03	46500.00
40B79D	2017-07-13 15:00:00+03	40800.00
40B7C1	2017-07-14 18:54:00+03	102100.00
40B7EB	2017-08-15 03:39:00+03	54000.00
40B866	2017-08-02 01:16:00+03	177200.00
40B885	2017-07-06 04:28:00+03	54000.00
40B90A	2017-06-29 09:10:00+03	68300.00
40B936	2017-08-07 05:26:00+03	123000.00
40B9C1	2017-07-03 07:07:00+03	166900.00
40BA04	2017-07-18 12:50:00+03	6600.00
40BA22	2017-07-07 19:42:00+03	117600.00
40BA6F	2017-07-16 22:56:00+03	62600.00
40BACA	2017-07-28 23:31:00+03	20200.00
40BC47	2017-07-09 14:47:00+03	48700.00
40BC8D	2017-07-29 08:00:00+03	133100.00
40BC9C	2017-07-07 08:13:00+03	65900.00
40BDA3	2017-07-19 21:09:00+03	23400.00
40BDB5	2017-07-28 07:22:00+03	114800.00
40BE7D	2017-08-13 02:23:00+03	81300.00
40BE8F	2017-07-11 04:41:00+03	135600.00
40BF8D	2017-08-03 22:02:00+03	24300.00
40BFC0	2017-07-25 20:14:00+03	78300.00
40BFDF	2017-07-19 01:01:00+03	54000.00
40C07B	2017-07-16 02:16:00+03	103700.00
40C0AB	2017-07-27 22:15:00+03	10800.00
40C149	2017-07-24 07:58:00+03	62600.00
40C16E	2017-07-27 10:45:00+03	8000.00
40C1A8	2017-08-15 17:26:00+03	27800.00
40C1D2	2017-07-22 01:23:00+03	97700.00
40C1D8	2017-08-11 15:00:00+03	57700.00
40C1F9	2017-08-02 10:10:00+03	266200.00
40C213	2017-08-14 12:10:00+03	202500.00
40C22C	2017-08-07 06:34:00+03	62600.00
40C23F	2017-07-29 02:44:00+03	91100.00
40C243	2017-08-08 17:09:00+03	36200.00
40C273	2017-08-07 04:56:00+03	47100.00
40C2F0	2017-07-22 00:55:00+03	6000.00
40C306	2017-08-12 09:27:00+03	21800.00
40C325	2017-07-06 07:20:00+03	13400.00
40C341	2017-07-24 03:00:00+03	28800.00
40C352	2017-07-03 23:43:00+03	135400.00
40C36A	2017-08-08 05:40:00+03	29600.00
40C431	2017-07-08 09:54:00+03	108600.00
40C50D	2017-07-06 16:31:00+03	49600.00
40C527	2017-08-11 07:29:00+03	66200.00
40C577	2017-07-02 09:31:00+03	156500.00
40C58C	2017-07-25 01:58:00+03	28000.00
40C637	2017-08-01 18:13:00+03	29400.00
40C664	2017-07-31 18:39:00+03	56600.00
40C666	2017-07-05 12:57:00+03	290500.00
40C6BA	2017-07-27 19:35:00+03	61600.00
40C6E2	2017-07-23 17:54:00+03	18600.00
40C703	2017-07-04 19:01:00+03	96800.00
40C7B5	2017-06-30 06:01:00+03	93900.00
40C870	2017-07-23 07:32:00+03	28800.00
40C8AF	2017-07-15 12:02:00+03	46000.00
40C914	2017-07-18 22:55:00+03	103400.00
40C91F	2017-07-11 07:29:00+03	28800.00
40C961	2017-08-13 00:32:00+03	177600.00
40C973	2017-07-22 04:22:00+03	23200.00
40C99B	2017-08-14 00:27:00+03	38400.00
40C9CC	2017-07-30 09:30:00+03	38000.00
40C9F4	2017-07-21 01:45:00+03	13200.00
40CA10	2017-08-14 11:36:00+03	62600.00
40CA98	2017-07-26 12:01:00+03	131100.00
40CABE	2017-07-14 10:25:00+03	123000.00
40CB24	2017-07-18 18:59:00+03	123000.00
40CB51	2017-08-06 05:01:00+03	19200.00
40CB57	2017-07-12 04:18:00+03	27200.00
40CB76	2017-07-24 17:02:00+03	16800.00
40CB9E	2017-08-08 21:17:00+03	22000.00
40CBC2	2017-07-24 10:43:00+03	72300.00
40CBFB	2017-08-03 16:49:00+03	123000.00
40CC1D	2017-07-02 12:56:00+03	69500.00
40CC70	2017-07-11 08:26:00+03	135000.00
40CCA9	2017-07-23 18:48:00+03	58400.00
40CCAE	2017-06-29 19:52:00+03	6000.00
40CCE8	2017-07-31 10:24:00+03	13400.00
40CD08	2017-07-21 20:46:00+03	89600.00
40CD0A	2017-07-09 13:49:00+03	67700.00
40CDAC	2017-07-21 18:56:00+03	172700.00
40CDDF	2017-07-16 21:49:00+03	57600.00
40CDEE	2017-08-13 10:27:00+03	80200.00
40CE6D	2017-07-23 16:57:00+03	65900.00
40CEA9	2017-07-28 13:19:00+03	139700.00
40CEAC	2017-07-07 19:36:00+03	48100.00
40CEE4	2017-07-01 12:37:00+03	64400.00
40CF38	2017-07-28 16:26:00+03	73200.00
40CF97	2017-07-24 00:32:00+03	25800.00
40D09F	2017-08-09 18:13:00+03	28900.00
40D0A1	2017-08-03 09:52:00+03	41400.00
40D0DF	2017-07-14 04:11:00+03	80900.00
40D159	2017-07-10 02:25:00+03	335800.00
40D20F	2017-07-17 02:08:00+03	108600.00
40D286	2017-08-15 08:49:00+03	57600.00
40D28A	2017-07-21 09:23:00+03	82000.00
40D2CA	2017-08-08 16:10:00+03	59200.00
40D2E9	2017-08-10 21:38:00+03	37600.00
40D2EC	2017-07-14 07:21:00+03	73100.00
40D31E	2017-08-02 04:45:00+03	3800.00
40D34D	2017-07-20 14:49:00+03	41600.00
40D390	2017-06-30 00:26:00+03	23200.00
40D3CF	2017-08-14 07:32:00+03	6700.00
40D432	2017-08-14 02:09:00+03	85700.00
40D493	2017-07-03 23:30:00+03	25400.00
40D4DB	2017-08-13 17:41:00+03	71900.00
40D565	2017-07-26 23:52:00+03	38400.00
40D5A4	2017-07-16 11:30:00+03	54800.00
40D5E4	2017-07-31 20:20:00+03	23200.00
40D622	2017-08-11 08:28:00+03	76800.00
40D62A	2017-07-28 12:35:00+03	69600.00
40D661	2017-07-20 06:49:00+03	55800.00
40D6A5	2017-07-31 09:23:00+03	26700.00
40D6D2	2017-06-26 22:08:00+03	31600.00
40D6E1	2017-08-08 02:47:00+03	123600.00
40D6F7	2017-07-23 21:51:00+03	31400.00
40D700	2017-07-28 21:50:00+03	60400.00
40D718	2017-07-05 11:20:00+03	23200.00
40D71B	2017-08-08 08:53:00+03	133200.00
40D799	2017-07-16 15:05:00+03	38000.00
40D79E	2017-07-03 05:38:00+03	50600.00
40D7AA	2017-07-09 23:28:00+03	56000.00
40D82E	2017-07-18 22:21:00+03	59800.00
40D834	2017-07-29 00:48:00+03	47800.00
40D885	2017-07-08 01:05:00+03	57600.00
40D8F0	2017-07-15 17:39:00+03	135400.00
40D8F3	2017-07-29 09:00:00+03	47200.00
40D92E	2017-07-03 23:37:00+03	116900.00
40D951	2017-07-15 23:02:00+03	55800.00
40D953	2017-07-08 05:58:00+03	98600.00
40D99F	2017-08-09 01:21:00+03	38400.00
40DA2D	2017-07-18 08:38:00+03	149400.00
40DAEC	2017-07-22 11:32:00+03	46200.00
40DB1F	2017-07-03 08:44:00+03	28600.00
40DB51	2017-07-20 00:24:00+03	57800.00
40DB60	2017-07-12 06:05:00+03	56100.00
40DB8A	2017-07-07 01:41:00+03	177200.00
40DBE2	2017-07-19 04:52:00+03	66200.00
40DBF8	2017-07-24 02:11:00+03	31600.00
40DBFE	2017-07-30 15:11:00+03	13600.00
40DC0D	2017-07-18 14:08:00+03	66600.00
40DC10	2017-07-02 20:30:00+03	39600.00
40DC19	2017-07-21 14:18:00+03	11600.00
40DC1B	2017-07-21 08:46:00+03	59300.00
40DC2F	2017-08-01 17:41:00+03	23600.00
40DC5D	2017-07-06 09:02:00+03	40800.00
40DC91	2017-07-05 23:09:00+03	96100.00
40DCA2	2017-08-09 13:59:00+03	60800.00
40DD1F	2017-07-30 16:04:00+03	147100.00
40DD2C	2017-08-11 21:33:00+03	59400.00
40DD5F	2017-07-23 07:51:00+03	89600.00
40DD72	2017-08-01 05:32:00+03	112000.00
40DD75	2017-08-08 14:11:00+03	148200.00
40DDC7	2017-07-24 11:18:00+03	88600.00
40DDEF	2017-07-10 17:08:00+03	75100.00
40DDFE	2017-07-08 08:53:00+03	24400.00
40DE12	2017-07-16 19:07:00+03	60400.00
40DE1B	2017-07-05 01:01:00+03	53600.00
40DE2F	2017-07-15 12:17:00+03	133100.00
40DE3D	2017-07-19 19:26:00+03	23200.00
40DE63	2017-07-27 20:22:00+03	67600.00
40DF35	2017-07-26 03:25:00+03	54800.00
40DF4F	2017-07-15 05:51:00+03	24400.00
40E029	2017-07-04 00:47:00+03	26200.00
40E036	2017-08-01 22:49:00+03	21600.00
40E053	2017-07-07 00:18:00+03	25100.00
40E0AB	2017-08-09 10:57:00+03	133100.00
40E0AD	2017-07-10 03:08:00+03	48900.00
40E0C1	2017-08-12 14:21:00+03	62700.00
40E0C6	2017-07-25 09:44:00+03	136000.00
40E0D3	2017-07-28 07:38:00+03	117200.00
40E0DB	2017-07-14 22:00:00+03	34200.00
40E0E9	2017-08-06 17:07:00+03	91500.00
40E0EE	2017-08-07 17:47:00+03	79000.00
40E13A	2017-07-04 11:32:00+03	62600.00
40E177	2017-07-15 16:40:00+03	205600.00
40E1C3	2017-07-26 15:06:00+03	32800.00
40E1C7	2017-08-01 21:29:00+03	6000.00
40E266	2017-07-26 18:59:00+03	46400.00
40E31B	2017-08-11 16:30:00+03	138500.00
40E35B	2017-07-19 13:20:00+03	125200.00
40E40E	2017-08-07 14:25:00+03	38400.00
40E425	2017-07-12 09:35:00+03	56200.00
40E452	2017-08-10 14:29:00+03	27300.00
40E4DD	2017-07-06 03:47:00+03	54500.00
40E4EF	2017-07-23 16:27:00+03	37900.00
40E4F5	2017-07-24 05:39:00+03	173900.00
40E567	2017-07-28 14:35:00+03	27200.00
40E603	2017-08-14 18:24:00+03	149600.00
40E60B	2017-07-23 08:20:00+03	26000.00
40E6B9	2017-08-13 19:41:00+03	50800.00
40E6DE	2017-07-11 03:36:00+03	15000.00
40E79E	2017-07-01 21:21:00+03	56000.00
40E822	2017-08-06 13:17:00+03	49800.00
40E85F	2017-07-04 17:57:00+03	88500.00
40E8AE	2017-07-23 22:38:00+03	54400.00
40E8C3	2017-07-11 11:05:00+03	406200.00
40E93B	2017-07-17 21:56:00+03	54800.00
40E957	2017-07-10 07:35:00+03	137600.00
40E9BE	2017-08-15 17:52:00+03	56600.00
40E9F2	2017-07-28 16:32:00+03	117300.00
40EA05	2017-08-03 02:56:00+03	51800.00
40EA27	2017-07-09 07:24:00+03	89600.00
40EA3C	2017-07-27 15:01:00+03	42000.00
40EA42	2017-07-24 02:48:00+03	49100.00
40EA4D	2017-08-11 07:22:00+03	23100.00
40EAF5	2017-07-08 08:57:00+03	31000.00
40EB07	2017-07-06 18:26:00+03	27200.00
40EB5F	2017-07-30 19:40:00+03	54400.00
40EB64	2017-07-05 05:29:00+03	79200.00
40EB97	2017-07-25 08:46:00+03	269000.00
40EBB9	2017-07-25 20:06:00+03	38800.00
40EBC9	2017-08-14 07:42:00+03	25400.00
40EC3E	2017-08-09 10:22:00+03	92400.00
40EC81	2017-07-18 20:05:00+03	124200.00
40ECAA	2017-07-24 22:53:00+03	81300.00
40ED34	2017-07-12 16:58:00+03	94700.00
40ED5E	2017-08-14 21:27:00+03	60400.00
40ED75	2017-07-12 00:52:00+03	246000.00
40EDB0	2017-07-20 05:29:00+03	91200.00
40EEA6	2017-07-03 02:37:00+03	136800.00
40EED4	2017-07-13 09:02:00+03	125100.00
40EF2C	2017-07-21 00:23:00+03	70700.00
40EFAF	2017-07-22 16:40:00+03	7400.00
40EFFE	2017-07-21 09:15:00+03	55800.00
40F028	2017-07-03 10:33:00+03	23200.00
40F041	2017-07-18 07:12:00+03	119600.00
40F04B	2017-07-20 18:47:00+03	87000.00
40F05A	2017-08-09 03:19:00+03	187600.00
40F0C8	2017-07-25 16:15:00+03	26200.00
40F0EA	2017-08-14 13:19:00+03	170500.00
40F110	2017-07-12 00:11:00+03	10600.00
40F139	2017-07-24 06:36:00+03	62800.00
40F255	2017-07-24 02:12:00+03	40000.00
40F280	2017-08-11 20:29:00+03	100600.00
40F29E	2017-07-02 01:38:00+03	23600.00
40F354	2017-07-21 16:55:00+03	70700.00
40F381	2017-07-23 13:52:00+03	64800.00
40F3A5	2017-08-11 01:51:00+03	139500.00
40F542	2017-07-12 15:04:00+03	53600.00
40F5E7	2017-08-07 22:44:00+03	76200.00
40F611	2017-07-31 00:08:00+03	37900.00
40F622	2017-07-08 00:06:00+03	27700.00
40F672	2017-08-08 03:23:00+03	65400.00
40F6B4	2017-06-26 07:17:00+03	116400.00
40F6C4	2017-07-15 02:48:00+03	30000.00
40F6D4	2017-07-22 02:12:00+03	428900.00
40F729	2017-08-02 06:31:00+03	55800.00
40F7FA	2017-07-13 15:05:00+03	78900.00
40F86E	2017-08-10 08:05:00+03	51600.00
40F8A8	2017-07-07 19:24:00+03	18700.00
40F8BD	2017-08-12 18:30:00+03	40800.00
40F8C3	2017-06-30 13:46:00+03	28000.00
40F8DE	2017-08-03 00:16:00+03	73000.00
40F98A	2017-08-02 12:43:00+03	6000.00
40F9F8	2017-08-07 05:27:00+03	62000.00
40F9FE	2017-07-02 17:50:00+03	78600.00
40FA2E	2017-08-12 01:19:00+03	73300.00
40FA6C	2017-07-22 07:27:00+03	11800.00
40FAC4	2017-07-05 20:49:00+03	28000.00
40FB6A	2017-07-20 04:33:00+03	67200.00
40FB6D	2017-07-12 14:01:00+03	28800.00
40FB87	2017-07-08 08:38:00+03	70800.00
40FBEA	2017-07-03 21:57:00+03	119500.00
40FC45	2017-07-09 07:34:00+03	19600.00
40FC65	2017-07-26 10:09:00+03	25400.00
40FC88	2017-07-01 02:20:00+03	16400.00
40FCA4	2017-08-11 23:52:00+03	70200.00
40FCAE	2017-07-19 07:59:00+03	135400.00
40FE8B	2017-06-30 02:52:00+03	8400.00
40FEB4	2017-08-06 04:42:00+03	56900.00
40FED0	2017-07-10 14:42:00+03	16400.00
40FF55	2017-08-09 12:34:00+03	199700.00
40FF57	2017-08-01 00:29:00+03	96800.00
40FFAF	2017-07-26 12:08:00+03	21400.00
40FFF7	2017-07-30 04:10:00+03	55800.00
410002	2017-07-14 14:24:00+03	66700.00
410091	2017-07-31 05:47:00+03	36400.00
410097	2017-07-16 18:35:00+03	8600.00
410099	2017-08-10 15:24:00+03	37200.00
41009E	2017-07-16 21:11:00+03	44100.00
410107	2017-08-04 06:28:00+03	255600.00
4101CB	2017-07-22 14:09:00+03	286100.00
4102A1	2017-08-11 23:16:00+03	46400.00
4102C3	2017-07-23 11:10:00+03	93900.00
4102D8	2017-07-30 00:35:00+03	36200.00
4102D9	2017-07-28 17:37:00+03	26000.00
4102EA	2017-07-16 14:16:00+03	27200.00
41036F	2017-07-16 21:59:00+03	88600.00
410371	2017-07-04 07:40:00+03	100600.00
41039E	2017-07-27 04:26:00+03	135600.00
4103AD	2017-07-20 08:40:00+03	22000.00
4103D0	2017-08-15 04:18:00+03	243500.00
4103D8	2017-07-21 05:20:00+03	39300.00
4103FC	2017-07-26 11:25:00+03	24400.00
41042F	2017-07-08 02:37:00+03	229900.00
410486	2017-07-18 14:48:00+03	92700.00
4104B8	2017-08-15 08:02:00+03	67700.00
41052E	2017-07-10 17:08:00+03	16400.00
4105D1	2017-08-15 03:09:00+03	62000.00
41060C	2017-08-02 09:55:00+03	42800.00
41061F	2017-07-04 19:25:00+03	33100.00
410643	2017-08-01 10:03:00+03	25100.00
41068E	2017-08-05 12:36:00+03	64000.00
4106BC	2017-07-11 09:16:00+03	397100.00
4106E7	2017-08-14 07:35:00+03	32800.00
41077C	2017-08-08 02:52:00+03	57200.00
4107B7	2017-08-02 23:49:00+03	167400.00
4108CA	2017-07-20 07:38:00+03	158500.00
4108CB	2017-07-07 15:24:00+03	60400.00
4108D8	2017-08-15 10:20:00+03	271100.00
4108E6	2017-08-15 16:18:00+03	17300.00
4108F3	2017-07-28 06:25:00+03	53800.00
41091A	2017-07-27 01:21:00+03	128800.00
41099B	2017-08-09 12:16:00+03	14400.00
4109DE	2017-08-03 02:34:00+03	18500.00
4109FD	2017-07-05 16:59:00+03	56000.00
410A1B	2017-07-05 15:48:00+03	56600.00
410A9C	2017-07-12 11:55:00+03	140000.00
410AEB	2017-07-09 11:44:00+03	52100.00
410B19	2017-07-12 16:15:00+03	73300.00
410B42	2017-08-06 20:48:00+03	105000.00
410B77	2017-07-15 14:53:00+03	14300.00
410B99	2017-07-31 23:38:00+03	12400.00
410BA7	2017-08-08 09:05:00+03	46000.00
410BAF	2017-08-06 05:14:00+03	29600.00
410C51	2017-07-14 16:27:00+03	171700.00
410C71	2017-08-13 21:29:00+03	28800.00
410C97	2017-08-12 18:25:00+03	393800.00
410CB5	2017-07-31 16:57:00+03	93900.00
410CD9	2017-07-19 17:31:00+03	14000.00
410D2D	2017-07-20 14:16:00+03	112400.00
410D5E	2017-08-12 05:22:00+03	68100.00
410D5F	2017-07-01 00:40:00+03	15800.00
410D81	2017-06-28 16:07:00+03	174400.00
410D88	2017-07-05 10:40:00+03	55300.00
410DB8	2017-07-31 21:20:00+03	32200.00
410DC0	2017-07-28 20:39:00+03	43200.00
410DD7	2017-08-10 22:37:00+03	28000.00
410DFF	2017-07-04 21:50:00+03	133200.00
410E15	2017-07-16 12:06:00+03	13400.00
410E28	2017-08-13 02:40:00+03	13400.00
410E53	2017-06-28 01:26:00+03	23200.00
410E5B	2017-08-08 15:12:00+03	62800.00
410E81	2017-07-23 14:56:00+03	191700.00
410F06	2017-07-14 12:08:00+03	34000.00
410F6A	2017-08-11 23:11:00+03	112600.00
410F9A	2017-08-12 06:03:00+03	66000.00
410FB6	2017-06-30 15:25:00+03	94600.00
410FCA	2017-07-19 21:56:00+03	23600.00
411006	2017-06-29 15:08:00+03	114800.00
41104E	2017-07-16 08:10:00+03	40000.00
4110EE	2017-07-09 08:47:00+03	12600.00
411139	2017-08-08 14:19:00+03	24600.00
411163	2017-07-27 23:37:00+03	50600.00
411164	2017-07-08 22:06:00+03	187800.00
4112CD	2017-08-05 02:06:00+03	26200.00
4112E0	2017-07-28 02:19:00+03	31400.00
411354	2017-07-09 09:23:00+03	85000.00
411360	2017-07-29 14:13:00+03	201200.00
4113B8	2017-07-09 07:29:00+03	65200.00
4113CB	2017-07-20 05:20:00+03	65800.00
4113E4	2017-08-01 12:14:00+03	92800.00
4113EB	2017-06-30 06:43:00+03	139800.00
4113F2	2017-08-14 16:11:00+03	75600.00
4113FB	2017-07-29 17:42:00+03	21400.00
411405	2017-07-05 07:34:00+03	59800.00
411422	2017-07-30 17:28:00+03	19600.00
4114C3	2017-07-18 12:13:00+03	54800.00
4114DD	2017-07-22 21:24:00+03	61800.00
411522	2017-08-07 10:48:00+03	86600.00
41152A	2017-08-13 20:21:00+03	28700.00
411575	2017-07-17 01:14:00+03	20400.00
4115D3	2017-08-05 05:23:00+03	124300.00
4115E7	2017-07-22 13:23:00+03	94000.00
41160A	2017-07-04 09:32:00+03	14400.00
4116D5	2017-07-11 19:43:00+03	32700.00
4116EE	2017-08-06 08:42:00+03	13400.00
41172E	2017-07-25 03:59:00+03	39300.00
411784	2017-08-06 23:22:00+03	23200.00
4117F9	2017-07-24 09:02:00+03	201200.00
4117FE	2017-07-04 16:36:00+03	112000.00
41181F	2017-07-12 17:43:00+03	31200.00
411888	2017-07-01 14:29:00+03	73600.00
4118D0	2017-07-08 23:50:00+03	80300.00
41194D	2017-08-02 05:36:00+03	28800.00
41197F	2017-08-14 12:57:00+03	15800.00
4119A9	2017-07-01 07:58:00+03	45100.00
4119BF	2017-07-06 00:39:00+03	25100.00
411AD2	2017-07-26 17:37:00+03	49400.00
411B51	2017-08-07 16:05:00+03	20800.00
411BB5	2017-07-18 02:21:00+03	68800.00
411BB7	2017-07-24 03:37:00+03	399600.00
411BD2	2017-07-17 20:50:00+03	23600.00
411BEC	2017-07-01 18:36:00+03	65500.00
411C76	2017-07-12 03:27:00+03	18000.00
411D06	2017-08-10 17:44:00+03	49500.00
411D36	2017-07-12 06:11:00+03	24400.00
411D56	2017-08-12 07:13:00+03	19600.00
411DE6	2017-07-11 03:06:00+03	24600.00
411E0F	2017-07-06 23:42:00+03	6000.00
411E31	2017-07-17 08:06:00+03	59800.00
411E4B	2017-06-30 19:20:00+03	66400.00
411E57	2017-07-24 13:12:00+03	66600.00
411EBC	2017-07-12 16:35:00+03	28800.00
411EF4	2017-07-09 08:49:00+03	229500.00
411F10	2017-08-04 12:24:00+03	114800.00
411F5B	2017-08-10 00:46:00+03	153200.00
411F62	2017-07-10 06:51:00+03	21200.00
411F96	2017-08-13 11:27:00+03	300700.00
411FA9	2017-07-28 11:37:00+03	19600.00
411FC9	2017-07-24 02:40:00+03	64400.00
411FCC	2017-07-21 03:19:00+03	23200.00
411FED	2017-07-14 21:31:00+03	42800.00
411FF1	2017-07-11 05:09:00+03	152500.00
411FFD	2017-07-06 17:58:00+03	42800.00
412088	2017-08-03 13:24:00+03	56600.00
41209A	2017-07-24 08:24:00+03	66000.00
4120F7	2017-08-14 12:38:00+03	18300.00
41216B	2017-07-21 22:34:00+03	260300.00
41219C	2017-08-10 10:08:00+03	126200.00
4121E7	2017-07-15 20:57:00+03	67400.00
412257	2017-07-11 00:51:00+03	24000.00
412278	2017-07-28 23:40:00+03	77600.00
4122A3	2017-08-15 01:35:00+03	22100.00
4122F1	2017-07-15 19:49:00+03	56000.00
41231D	2017-08-14 21:27:00+03	23900.00
412325	2017-07-11 06:22:00+03	24200.00
4123A6	2017-07-16 12:54:00+03	123000.00
412437	2017-08-14 00:04:00+03	91800.00
412445	2017-07-02 04:24:00+03	133100.00
41247F	2017-07-10 18:36:00+03	37900.00
412486	2017-08-13 10:16:00+03	26000.00
4124AF	2017-08-09 21:21:00+03	91100.00
4124CE	2017-08-06 05:32:00+03	82200.00
4124DE	2017-07-28 12:57:00+03	369000.00
412504	2017-07-02 16:05:00+03	188900.00
412506	2017-07-07 20:48:00+03	234900.00
41255B	2017-07-07 15:37:00+03	57600.00
412571	2017-07-11 03:47:00+03	34000.00
412604	2017-07-07 16:24:00+03	23200.00
41262A	2017-07-04 20:58:00+03	542300.00
412740	2017-08-02 12:04:00+03	71100.00
412756	2017-08-07 07:11:00+03	30400.00
412765	2017-07-25 22:24:00+03	66600.00
412766	2017-08-13 03:19:00+03	332800.00
412796	2017-07-10 22:56:00+03	35700.00
4127A6	2017-07-13 17:49:00+03	35600.00
412868	2017-07-03 09:04:00+03	72400.00
41287C	2017-08-07 06:43:00+03	46400.00
4128BC	2017-07-27 04:33:00+03	148200.00
4128E3	2017-07-25 14:04:00+03	19600.00
412922	2017-07-05 13:47:00+03	92800.00
4129D2	2017-07-31 15:15:00+03	185700.00
4129E1	2017-07-25 04:31:00+03	160800.00
412A32	2017-08-11 10:02:00+03	7200.00
412AC2	2017-08-06 21:35:00+03	75600.00
412B74	2017-07-25 10:22:00+03	248500.00
412B79	2017-08-13 13:22:00+03	26800.00
412B7C	2017-07-16 09:43:00+03	387400.00
412B8C	2017-07-30 12:07:00+03	35400.00
412BA3	2017-08-07 08:21:00+03	240600.00
412C18	2017-07-15 13:52:00+03	53600.00
412C1D	2017-07-17 02:14:00+03	496700.00
412C3C	2017-08-14 10:37:00+03	23200.00
412C6D	2017-07-11 19:02:00+03	21400.00
412CDF	2017-07-27 18:23:00+03	56900.00
412D23	2017-08-12 22:53:00+03	34000.00
412D41	2017-08-07 21:53:00+03	119300.00
412D67	2017-08-03 02:37:00+03	59200.00
412DBB	2017-08-04 16:05:00+03	72300.00
412DC2	2017-07-25 03:28:00+03	66600.00
412DF1	2017-07-27 07:55:00+03	39800.00
412E47	2017-07-08 11:25:00+03	26700.00
412E53	2017-07-14 15:57:00+03	11600.00
412E88	2017-08-05 20:00:00+03	94000.00
412E90	2017-07-09 22:28:00+03	43500.00
412E9C	2017-08-09 03:09:00+03	20600.00
412EC5	2017-08-01 08:37:00+03	111600.00
412F0A	2017-08-02 20:08:00+03	48800.00
412F6A	2017-07-09 06:07:00+03	130800.00
412F8A	2017-08-13 07:34:00+03	67600.00
412FB1	2017-08-12 19:29:00+03	143100.00
412FDE	2017-08-08 12:02:00+03	83000.00
413027	2017-07-03 15:49:00+03	73400.00
413049	2017-08-02 05:07:00+03	143300.00
4130CA	2017-07-26 16:32:00+03	22000.00
413110	2017-07-31 10:28:00+03	67000.00
4131EA	2017-07-26 10:30:00+03	28000.00
413209	2017-07-27 23:00:00+03	58400.00
413214	2017-08-03 21:12:00+03	31600.00
413215	2017-07-18 23:44:00+03	13300.00
413218	2017-07-05 03:16:00+03	29600.00
41321B	2017-08-13 20:34:00+03	177200.00
413233	2017-08-09 12:04:00+03	21400.00
41323A	2017-07-15 23:04:00+03	46000.00
413245	2017-08-10 16:04:00+03	112000.00
413255	2017-07-26 15:35:00+03	88900.00
413261	2017-07-22 16:52:00+03	89600.00
4132E0	2017-08-13 18:37:00+03	38400.00
41337E	2017-07-17 04:42:00+03	56000.00
413385	2017-07-30 01:34:00+03	56000.00
413391	2017-07-27 08:40:00+03	36200.00
4133BE	2017-07-28 07:44:00+03	67700.00
4133DF	2017-06-30 10:14:00+03	28800.00
4133E1	2017-08-09 04:19:00+03	199700.00
413429	2017-07-17 17:32:00+03	225200.00
41344B	2017-07-11 12:55:00+03	32700.00
413476	2017-08-09 01:41:00+03	38600.00
4134E8	2017-08-09 20:18:00+03	25800.00
413506	2017-07-10 23:31:00+03	55800.00
413508	2017-07-26 17:45:00+03	47100.00
4135E7	2017-08-11 23:36:00+03	57600.00
4135EB	2017-07-29 19:37:00+03	406100.00
413614	2017-08-06 22:25:00+03	21800.00
41362B	2017-06-30 15:30:00+03	19600.00
41364C	2017-07-05 02:41:00+03	136200.00
41371E	2017-08-11 07:29:00+03	173200.00
41372A	2017-07-17 15:05:00+03	6000.00
413754	2017-07-22 05:07:00+03	6300.00
4137A4	2017-07-20 22:32:00+03	6700.00
4137B7	2017-08-02 23:09:00+03	60700.00
4137DC	2017-08-03 04:45:00+03	136200.00
4137F2	2017-08-12 23:27:00+03	75600.00
413818	2017-07-19 18:45:00+03	68100.00
413835	2017-07-03 11:39:00+03	10700.00
41387F	2017-06-26 03:47:00+03	135600.00
41388D	2017-08-07 17:37:00+03	25000.00
4138AC	2017-08-14 17:46:00+03	13200.00
4138B6	2017-07-19 07:40:00+03	149100.00
413925	2017-07-24 03:24:00+03	16400.00
41393B	2017-08-14 08:50:00+03	45400.00
413946	2017-07-25 09:22:00+03	38000.00
41396E	2017-07-09 17:51:00+03	52300.00
413973	2017-08-12 21:24:00+03	147900.00
4139D1	2017-07-31 14:09:00+03	156300.00
413A00	2017-07-03 02:11:00+03	266400.00
413A59	2017-08-08 01:26:00+03	78100.00
413A7D	2017-07-03 23:16:00+03	58900.00
413AA9	2017-07-26 05:18:00+03	21200.00
413AC9	2017-08-03 22:46:00+03	11600.00
413B19	2017-08-01 05:36:00+03	138600.00
413B48	2017-08-10 19:52:00+03	22000.00
413BDC	2017-07-06 18:29:00+03	178800.00
413C80	2017-08-02 19:37:00+03	92000.00
413D08	2017-07-26 08:17:00+03	134400.00
413DCD	2017-08-05 08:51:00+03	15000.00
413DFD	2017-08-06 11:57:00+03	26000.00
413E62	2017-07-04 13:33:00+03	405200.00
413E71	2017-08-01 21:10:00+03	39300.00
413EA3	2017-07-25 02:52:00+03	54800.00
413F19	2017-07-20 13:14:00+03	398500.00
413F4A	2017-08-12 13:36:00+03	66100.00
413F5E	2017-07-22 22:40:00+03	21400.00
41403D	2017-06-29 00:49:00+03	34000.00
414072	2017-07-10 07:18:00+03	114800.00
41407D	2017-07-27 12:14:00+03	37100.00
414084	2017-08-11 00:12:00+03	136000.00
41408B	2017-07-04 02:16:00+03	14000.00
4140C9	2017-07-14 17:39:00+03	30200.00
4140D9	2017-08-02 01:29:00+03	23200.00
41415A	2017-07-08 03:23:00+03	168000.00
4141A0	2017-07-02 08:11:00+03	72400.00
41420E	2017-07-27 21:03:00+03	69400.00
414288	2017-08-07 16:00:00+03	35300.00
4142B3	2017-07-18 13:28:00+03	32200.00
4142DB	2017-07-05 06:30:00+03	39300.00
41431D	2017-07-20 14:37:00+03	382000.00
414388	2017-07-24 05:35:00+03	118900.00
4143AB	2017-08-10 14:03:00+03	23100.00
4143BA	2017-07-07 02:15:00+03	56600.00
4143BF	2017-07-11 03:56:00+03	23200.00
4143D5	2017-07-10 11:33:00+03	56000.00
4143DC	2017-08-09 17:00:00+03	65400.00
4143F4	2017-07-27 05:03:00+03	48800.00
414427	2017-08-08 06:17:00+03	16400.00
414452	2017-07-23 10:29:00+03	11600.00
41446E	2017-07-17 19:04:00+03	66000.00
41446F	2017-07-15 21:56:00+03	99200.00
41447E	2017-07-17 01:34:00+03	390400.00
4144B7	2017-07-01 01:21:00+03	67600.00
4144CE	2017-08-13 14:49:00+03	149100.00
4144CF	2017-07-25 20:22:00+03	14000.00
41453C	2017-08-02 04:54:00+03	56000.00
414592	2017-07-22 01:13:00+03	89000.00
4145B3	2017-07-19 20:45:00+03	26000.00
41466E	2017-08-06 16:29:00+03	169300.00
41466F	2017-07-23 17:06:00+03	67600.00
41467A	2017-07-14 02:02:00+03	81100.00
414684	2017-07-05 15:47:00+03	136600.00
4146FC	2017-07-26 06:15:00+03	114300.00
41470D	2017-07-07 17:22:00+03	13600.00
414770	2017-07-16 03:07:00+03	42800.00
4147C2	2017-08-10 06:49:00+03	369000.00
4147D1	2017-07-31 05:18:00+03	136800.00
414821	2017-07-19 22:16:00+03	23200.00
414853	2017-07-05 19:59:00+03	65200.00
414888	2017-08-09 02:19:00+03	58400.00
41489F	2017-08-13 15:09:00+03	67200.00
4149AC	2017-07-15 07:48:00+03	13200.00
4149CB	2017-07-17 21:33:00+03	13700.00
4149D7	2017-08-06 13:26:00+03	393800.00
4149DA	2017-08-08 08:49:00+03	84500.00
4149DC	2017-08-11 21:43:00+03	56000.00
414A1D	2017-07-11 21:44:00+03	32700.00
414A29	2017-07-07 07:48:00+03	366400.00
414AD1	2017-07-08 18:26:00+03	68800.00
414B1B	2017-07-14 06:02:00+03	6800.00
414C0D	2017-07-18 19:02:00+03	12400.00
414C16	2017-07-21 15:30:00+03	111600.00
414C40	2017-07-30 02:54:00+03	82900.00
414C8B	2017-07-02 12:20:00+03	61800.00
414CCE	2017-07-18 21:54:00+03	84800.00
414D10	2017-07-20 21:43:00+03	165800.00
414D23	2017-07-24 20:37:00+03	59800.00
414D70	2017-08-09 08:21:00+03	30400.00
414D91	2017-07-26 17:28:00+03	129700.00
414D9A	2017-08-14 02:38:00+03	29600.00
414DB4	2017-07-31 10:35:00+03	82200.00
414E02	2017-07-07 04:35:00+03	81300.00
414E67	2017-07-12 15:35:00+03	44000.00
414EDC	2017-08-07 12:18:00+03	22000.00
414EE0	2017-07-28 07:07:00+03	133200.00
414EF2	2017-08-11 05:07:00+03	16400.00
414F98	2017-08-13 00:33:00+03	76000.00
414FC9	2017-08-03 15:44:00+03	221800.00
415006	2017-08-03 14:33:00+03	16800.00
415019	2017-07-02 14:38:00+03	68800.00
415024	2017-07-19 17:42:00+03	311900.00
4150A8	2017-07-16 15:55:00+03	38800.00
415157	2017-08-02 23:37:00+03	56000.00
4151B6	2017-07-06 00:28:00+03	54800.00
415251	2017-08-05 23:55:00+03	42800.00
415286	2017-07-07 19:53:00+03	92000.00
415290	2017-07-10 09:50:00+03	62900.00
4152C8	2017-07-02 19:00:00+03	51300.00
4152CA	2017-08-08 18:05:00+03	34000.00
41535F	2017-07-08 00:36:00+03	26000.00
415383	2017-07-06 05:30:00+03	54800.00
4153B0	2017-07-24 04:39:00+03	90100.00
4153CA	2017-08-02 05:36:00+03	103500.00
415435	2017-07-03 19:21:00+03	9200.00
41546B	2017-07-02 06:44:00+03	75500.00
415540	2017-07-08 09:30:00+03	40800.00
41555E	2017-08-01 20:29:00+03	67600.00
415570	2017-07-14 14:24:00+03	61600.00
415640	2017-07-11 08:07:00+03	39200.00
41564D	2017-08-03 10:54:00+03	66600.00
4156C6	2017-07-01 00:56:00+03	25400.00
4156DE	2017-07-10 01:02:00+03	75600.00
415814	2017-08-08 16:54:00+03	136200.00
415886	2017-08-09 12:43:00+03	165800.00
415916	2017-08-03 07:24:00+03	28000.00
415930	2017-07-21 06:53:00+03	70200.00
415985	2017-08-04 06:49:00+03	71900.00
4159F0	2017-07-29 04:33:00+03	6600.00
415A54	2017-07-02 07:10:00+03	189200.00
415AEC	2017-07-19 03:43:00+03	56000.00
415C02	2017-07-08 07:51:00+03	56000.00
415C10	2017-08-04 22:32:00+03	100600.00
415CDF	2017-07-12 04:54:00+03	55800.00
415D47	2017-07-28 19:47:00+03	39200.00
415D74	2017-08-01 05:57:00+03	134600.00
415D83	2017-07-29 14:08:00+03	26700.00
415E05	2017-07-07 22:40:00+03	11600.00
415E7E	2017-07-11 19:04:00+03	73300.00
415F71	2017-07-02 17:17:00+03	136100.00
416096	2017-07-06 10:58:00+03	19600.00
4160A5	2017-08-05 14:11:00+03	35600.00
416150	2017-07-11 23:06:00+03	46000.00
41616D	2017-07-07 05:41:00+03	37200.00
41617E	2017-07-23 18:17:00+03	37500.00
416259	2017-07-15 08:10:00+03	35600.00
416268	2017-07-05 06:09:00+03	55800.00
4162AF	2017-07-18 03:51:00+03	28300.00
4162B5	2017-08-06 20:30:00+03	19600.00
4162CF	2017-08-04 22:59:00+03	85000.00
416320	2017-07-07 13:04:00+03	26000.00
416400	2017-07-18 07:56:00+03	20200.00
41640A	2017-07-12 07:01:00+03	21800.00
416460	2017-07-22 08:58:00+03	137400.00
4164CE	2017-08-09 00:49:00+03	8400.00
4164F3	2017-07-08 21:01:00+03	55100.00
41652E	2017-07-09 03:46:00+03	51600.00
416537	2017-07-01 17:11:00+03	20500.00
416544	2017-07-04 18:02:00+03	136100.00
416579	2017-07-07 01:29:00+03	56000.00
4165A5	2017-08-15 03:18:00+03	56600.00
4165AA	2017-07-07 01:25:00+03	105100.00
4165B3	2017-07-26 19:31:00+03	26700.00
416615	2017-07-05 06:26:00+03	103500.00
41662A	2017-07-21 13:01:00+03	172100.00
416638	2017-08-02 13:32:00+03	86100.00
416644	2017-07-07 04:42:00+03	10600.00
4166BE	2017-07-02 01:09:00+03	133200.00
4166C7	2017-08-13 15:09:00+03	102100.00
4166C8	2017-07-10 23:08:00+03	52000.00
4166DA	2017-07-06 17:12:00+03	90400.00
41675C	2017-07-28 18:12:00+03	46400.00
416784	2017-07-16 03:28:00+03	332400.00
4167A5	2017-08-07 20:55:00+03	91500.00
4167D5	2017-08-01 17:27:00+03	68800.00
4167D6	2017-07-20 16:59:00+03	49900.00
41681E	2017-08-15 16:52:00+03	28000.00
416856	2017-07-23 11:53:00+03	87800.00
416915	2017-07-01 10:37:00+03	53600.00
416935	2017-07-21 04:23:00+03	56600.00
41696B	2017-07-26 04:12:00+03	89700.00
416976	2017-07-21 20:16:00+03	61800.00
4169B3	2017-06-30 11:32:00+03	31400.00
4169C1	2017-08-07 23:43:00+03	8400.00
416A0A	2017-07-30 03:31:00+03	38600.00
416A0E	2017-07-18 11:57:00+03	418800.00
416A23	2017-07-09 10:34:00+03	96800.00
416A77	2017-08-15 03:24:00+03	28800.00
416A95	2017-07-14 01:57:00+03	258400.00
416B71	2017-07-18 05:01:00+03	28000.00
416B72	2017-07-11 19:00:00+03	31600.00
416D26	2017-08-11 19:54:00+03	41800.00
416D28	2017-07-02 19:57:00+03	6800.00
416D42	2017-08-10 11:02:00+03	101200.00
416DA2	2017-07-23 08:45:00+03	28700.00
416DB8	2017-07-18 03:17:00+03	25600.00
416E2C	2017-07-05 08:29:00+03	108600.00
416E74	2017-07-24 05:37:00+03	6000.00
416E7A	2017-08-01 03:05:00+03	87200.00
416ED6	2017-07-14 02:34:00+03	28000.00
416EEA	2017-07-13 09:19:00+03	51900.00
416FFD	2017-08-07 18:16:00+03	123000.00
417053	2017-08-13 12:51:00+03	48200.00
4170B5	2017-08-08 10:24:00+03	306500.00
4170C6	2017-08-13 21:57:00+03	17200.00
4170E3	2017-08-03 00:33:00+03	62600.00
41710A	2017-08-02 12:48:00+03	123000.00
417130	2017-07-11 14:34:00+03	36200.00
417159	2017-07-12 16:58:00+03	25800.00
4171F0	2017-07-16 22:07:00+03	48800.00
417220	2017-08-08 19:11:00+03	54800.00
4172FA	2017-07-13 05:44:00+03	25900.00
41732E	2017-08-06 01:43:00+03	246000.00
417371	2017-08-09 20:59:00+03	13200.00
4173A3	2017-08-07 18:48:00+03	99200.00
41742D	2017-08-11 21:01:00+03	45500.00
41742E	2017-07-24 15:12:00+03	103300.00
41744D	2017-08-11 19:30:00+03	40000.00
4174F5	2017-07-30 01:30:00+03	278400.00
417510	2017-08-02 00:16:00+03	26800.00
417518	2017-08-13 20:35:00+03	56100.00
41752F	2017-06-29 06:04:00+03	6800.00
417570	2017-08-14 07:20:00+03	48800.00
417582	2017-07-06 16:16:00+03	40800.00
41766F	2017-07-08 14:36:00+03	332700.00
41768E	2017-08-06 05:38:00+03	19600.00
4176F4	2017-08-08 18:10:00+03	78300.00
417764	2017-07-26 15:42:00+03	123000.00
41779F	2017-07-11 11:58:00+03	114700.00
41782A	2017-07-20 04:35:00+03	52700.00
417855	2017-07-15 00:16:00+03	51900.00
417864	2017-06-28 20:39:00+03	102300.00
41789E	2017-07-15 07:02:00+03	41600.00
4178C4	2017-07-28 10:16:00+03	134400.00
4178E2	2017-08-06 13:30:00+03	212100.00
417942	2017-08-03 20:24:00+03	23200.00
417948	2017-07-17 06:30:00+03	45200.00
4179BF	2017-07-14 11:38:00+03	201200.00
417A1F	2017-07-31 07:11:00+03	24400.00
417A30	2017-07-26 02:50:00+03	56000.00
417A54	2017-07-03 09:16:00+03	69100.00
417AB8	2017-07-20 14:30:00+03	6800.00
417AC2	2017-07-29 10:54:00+03	13200.00
417ACB	2017-08-11 13:37:00+03	38400.00
417AD2	2017-07-02 19:05:00+03	63000.00
417B12	2017-07-22 23:01:00+03	56000.00
417B19	2017-08-09 05:23:00+03	164600.00
417BD5	2017-07-07 08:56:00+03	68400.00
417BEE	2017-07-14 08:23:00+03	11700.00
417BF8	2017-08-09 11:58:00+03	34000.00
417BFE	2017-08-12 03:38:00+03	16400.00
417C1C	2017-06-28 06:31:00+03	175300.00
417C1F	2017-07-12 21:09:00+03	67600.00
417C59	2017-08-10 04:19:00+03	73300.00
417C93	2017-08-10 19:36:00+03	55800.00
417CD3	2017-07-10 18:03:00+03	38600.00
417CEA	2017-08-10 18:27:00+03	19600.00
417CEE	2017-08-01 12:20:00+03	13800.00
417DE6	2017-07-05 13:15:00+03	73500.00
417E0A	2017-07-10 02:34:00+03	229900.00
417E0B	2017-07-04 04:54:00+03	87100.00
417E28	2017-08-15 00:24:00+03	32800.00
417E47	2017-06-29 21:00:00+03	68000.00
417E92	2017-07-11 16:31:00+03	111700.00
417E96	2017-08-15 16:13:00+03	40600.00
417EA9	2017-07-09 21:10:00+03	118400.00
417EB4	2017-08-14 17:52:00+03	65600.00
417F8A	2017-07-05 20:08:00+03	28800.00
417FF3	2017-07-07 16:08:00+03	34700.00
418059	2017-08-07 23:30:00+03	46200.00
41805E	2017-08-02 17:24:00+03	23200.00
418076	2017-08-04 12:40:00+03	48800.00
41808A	2017-07-03 21:30:00+03	46300.00
4180A3	2017-08-02 10:41:00+03	18600.00
4180B3	2017-07-15 04:47:00+03	23400.00
418154	2017-08-12 10:53:00+03	56000.00
418174	2017-07-20 11:30:00+03	178100.00
41820A	2017-07-20 00:44:00+03	123000.00
418241	2017-07-17 16:19:00+03	116400.00
4182C0	2017-08-03 00:16:00+03	7200.00
4182F6	2017-07-18 08:56:00+03	199600.00
418303	2017-06-30 21:26:00+03	47200.00
418319	2017-08-11 07:04:00+03	13200.00
418343	2017-07-04 16:16:00+03	6800.00
4183A1	2017-07-25 19:54:00+03	24400.00
4183AA	2017-08-08 14:34:00+03	65600.00
4183B5	2017-07-22 20:38:00+03	270800.00
4183D5	2017-07-05 05:07:00+03	25200.00
4183ED	2017-07-05 07:41:00+03	56900.00
4183EF	2017-07-18 23:09:00+03	40800.00
418426	2017-07-25 14:24:00+03	24800.00
41844A	2017-08-12 12:41:00+03	115700.00
418459	2017-07-26 08:01:00+03	67500.00
418476	2017-08-06 17:48:00+03	128800.00
4184BB	2017-08-13 17:59:00+03	6000.00
41852B	2017-07-19 11:45:00+03	232100.00
41854F	2017-07-21 02:10:00+03	26000.00
418582	2017-07-15 08:05:00+03	26000.00
418591	2017-08-14 00:35:00+03	20200.00
418610	2017-07-26 17:02:00+03	76800.00
418639	2017-08-02 01:25:00+03	85000.00
4186A8	2017-07-27 22:19:00+03	26000.00
4186AF	2017-08-11 11:45:00+03	18600.00
4186C9	2017-07-12 13:57:00+03	26300.00
41876C	2017-08-14 11:38:00+03	23200.00
418821	2017-08-12 14:02:00+03	13400.00
418936	2017-07-13 11:17:00+03	176800.00
418A01	2017-07-12 14:04:00+03	14000.00
418A12	2017-07-10 03:46:00+03	188000.00
418A3B	2017-08-15 13:02:00+03	6700.00
418A4F	2017-08-15 01:33:00+03	59800.00
418A88	2017-08-11 09:36:00+03	65900.00
418AED	2017-08-07 06:07:00+03	114500.00
418B24	2017-07-11 23:36:00+03	164900.00
418B3C	2017-08-04 07:30:00+03	96800.00
418C03	2017-07-25 02:48:00+03	62700.00
418C28	2017-06-28 18:12:00+03	20400.00
418C2C	2017-08-12 06:33:00+03	87600.00
418C6D	2017-07-11 00:59:00+03	57600.00
418CAB	2017-07-17 23:52:00+03	92700.00
418CD8	2017-07-08 10:56:00+03	79600.00
418CEF	2017-08-06 23:56:00+03	26700.00
418D0A	2017-08-09 14:03:00+03	93700.00
418D12	2017-07-08 05:02:00+03	56000.00
418DCA	2017-08-05 16:39:00+03	28600.00
418E27	2017-07-18 13:24:00+03	52100.00
418E33	2017-07-10 13:18:00+03	47100.00
418E43	2017-07-09 18:28:00+03	150400.00
418E67	2017-07-01 00:22:00+03	233800.00
418EA8	2017-08-03 10:42:00+03	74300.00
419020	2017-08-12 02:51:00+03	68100.00
419043	2017-08-14 21:14:00+03	396500.00
419090	2017-08-06 20:29:00+03	99700.00
41909D	2017-08-13 19:20:00+03	6700.00
41915A	2017-08-01 06:24:00+03	553600.00
4191AC	2017-08-11 18:32:00+03	58600.00
4191AF	2017-08-01 06:11:00+03	34000.00
4191B2	2017-07-20 00:04:00+03	52300.00
4191D2	2017-07-22 10:05:00+03	38800.00
4191DA	2017-07-13 16:49:00+03	46400.00
4191F8	2017-08-02 01:14:00+03	23200.00
419202	2017-08-13 04:39:00+03	33100.00
419218	2017-08-14 01:14:00+03	224000.00
4192DB	2017-08-03 10:35:00+03	6600.00
419314	2017-07-19 01:09:00+03	31800.00
419327	2017-07-13 04:56:00+03	66000.00
419349	2017-07-02 05:22:00+03	11700.00
419394	2017-07-02 06:02:00+03	81900.00
4193FE	2017-08-07 23:04:00+03	40800.00
41941E	2017-07-27 18:25:00+03	32800.00
419448	2017-08-04 11:28:00+03	21400.00
41947F	2017-07-14 11:45:00+03	257600.00
4194AD	2017-07-13 11:27:00+03	161100.00
4194D0	2017-08-07 08:50:00+03	23600.00
4194DD	2017-07-19 02:35:00+03	88600.00
41962F	2017-07-14 05:17:00+03	15800.00
41963A	2017-08-09 18:55:00+03	112100.00
419724	2017-07-17 09:24:00+03	80300.00
419736	2017-07-03 01:45:00+03	266400.00
41975D	2017-08-13 08:31:00+03	61500.00
419783	2017-07-24 07:22:00+03	127500.00
419795	2017-08-14 05:23:00+03	55800.00
419864	2017-08-11 02:15:00+03	46800.00
419892	2017-08-10 01:30:00+03	56000.00
41990B	2017-07-09 16:25:00+03	6600.00
41991C	2017-07-18 12:49:00+03	48000.00
4199C5	2017-08-14 02:48:00+03	76100.00
4199CA	2017-07-07 03:54:00+03	93700.00
419A06	2017-07-09 19:22:00+03	75600.00
419A20	2017-07-01 06:09:00+03	111600.00
419A79	2017-08-05 16:38:00+03	28000.00
419AC9	2017-07-20 21:58:00+03	3700.00
419AFC	2017-07-17 18:30:00+03	40100.00
419B0A	2017-07-13 07:31:00+03	75900.00
419B44	2017-07-14 11:22:00+03	58600.00
419B65	2017-08-10 00:33:00+03	8000.00
419B66	2017-07-14 21:04:00+03	98400.00
419B82	2017-07-09 02:58:00+03	28000.00
419C8F	2017-07-01 21:25:00+03	111600.00
419CAA	2017-07-21 13:59:00+03	46700.00
419CB2	2017-07-14 08:04:00+03	6700.00
419CFB	2017-08-12 19:13:00+03	53600.00
419D58	2017-07-19 13:16:00+03	35500.00
419D63	2017-07-11 22:33:00+03	21400.00
419D74	2017-07-06 18:36:00+03	68000.00
419DA2	2017-07-14 17:22:00+03	28000.00
419DCF	2017-08-13 19:25:00+03	73000.00
419DDE	2017-07-05 18:39:00+03	56000.00
419DFB	2017-07-17 02:04:00+03	132800.00
419E04	2017-07-22 06:47:00+03	77500.00
419E1B	2017-07-08 15:43:00+03	193600.00
419E1E	2017-07-10 06:55:00+03	168000.00
419E27	2017-08-06 10:07:00+03	26200.00
419E42	2017-07-14 15:53:00+03	220800.00
419E50	2017-07-31 10:13:00+03	63500.00
419E52	2017-06-27 09:57:00+03	246000.00
419ED8	2017-07-18 12:03:00+03	81000.00
419F2C	2017-07-04 17:27:00+03	49100.00
419FA2	2017-08-09 11:44:00+03	38400.00
41A00C	2017-08-01 18:26:00+03	57800.00
41A078	2017-07-15 00:49:00+03	23600.00
41A107	2017-08-12 14:48:00+03	32700.00
41A147	2017-08-13 11:09:00+03	23200.00
41A19C	2017-07-09 15:45:00+03	55000.00
41A1B5	2017-07-30 21:54:00+03	13000.00
41A1C4	2017-08-08 11:07:00+03	28000.00
41A251	2017-07-17 02:21:00+03	43800.00
41A259	2017-08-12 17:28:00+03	256900.00
41A275	2017-08-10 17:00:00+03	31600.00
41A2CF	2017-07-13 06:46:00+03	50200.00
41A31C	2017-08-02 04:23:00+03	54300.00
41A37B	2017-07-23 03:03:00+03	32800.00
41A397	2017-07-31 13:47:00+03	133200.00
41A3D1	2017-08-09 03:10:00+03	28000.00
41A3F6	2017-07-15 12:13:00+03	68800.00
41A4A8	2017-07-10 00:14:00+03	67200.00
41A637	2017-06-28 09:26:00+03	30400.00
41A638	2017-07-24 18:38:00+03	55800.00
41A647	2017-07-02 03:37:00+03	13700.00
41A672	2017-07-25 15:11:00+03	86600.00
41A689	2017-07-31 11:37:00+03	250000.00
41A766	2017-07-16 03:22:00+03	651900.00
41A794	2017-08-05 15:26:00+03	14000.00
41A7D5	2017-07-27 12:56:00+03	80200.00
41A7DE	2017-07-14 13:05:00+03	23600.00
41A815	2017-07-31 02:46:00+03	26000.00
41A85C	2017-07-18 08:06:00+03	37200.00
41A8B6	2017-07-24 22:05:00+03	54000.00
41A8EB	2017-07-25 01:13:00+03	40600.00
41A946	2017-08-14 20:32:00+03	16400.00
41A9BA	2017-07-07 05:28:00+03	24700.00
41A9C6	2017-08-09 10:09:00+03	22600.00
41AA04	2017-07-22 14:05:00+03	14000.00
41AA37	2017-07-25 23:30:00+03	192400.00
41AA54	2017-07-23 13:49:00+03	187600.00
41AA8D	2017-08-06 01:15:00+03	18600.00
41AAF7	2017-07-04 21:52:00+03	43200.00
41AB19	2017-07-27 11:17:00+03	100600.00
41AB59	2017-08-04 03:10:00+03	68000.00
41ABDF	2017-08-15 07:35:00+03	112600.00
41AC25	2017-07-17 11:49:00+03	85000.00
41ACC5	2017-07-03 17:08:00+03	18800.00
41AD05	2017-07-30 23:53:00+03	9800.00
41AD0F	2017-08-11 11:38:00+03	75300.00
41AD27	2017-08-07 03:29:00+03	112100.00
41AD2F	2017-07-21 10:29:00+03	90400.00
41ADAC	2017-07-09 03:51:00+03	54500.00
41ADE7	2017-08-15 10:59:00+03	35400.00
41AE10	2017-07-28 14:18:00+03	25400.00
41AE15	2017-07-29 21:40:00+03	15500.00
41AE4D	2017-07-04 23:19:00+03	52600.00
41AEF7	2017-07-16 01:44:00+03	132800.00
41AF59	2017-07-25 05:10:00+03	272300.00
41B005	2017-08-15 08:10:00+03	16400.00
41B034	2017-07-18 12:54:00+03	102600.00
41B08D	2017-07-09 17:18:00+03	28300.00
41B0D9	2017-08-09 19:52:00+03	246000.00
41B18E	2017-07-19 00:45:00+03	68100.00
41B196	2017-08-12 06:08:00+03	46400.00
41B1B7	2017-07-16 08:52:00+03	16400.00
41B1BA	2017-07-16 11:25:00+03	192700.00
41B1C3	2017-08-01 09:28:00+03	61000.00
41B204	2017-07-16 19:17:00+03	122500.00
41B233	2017-08-02 07:12:00+03	31600.00
41B244	2017-07-30 01:15:00+03	65900.00
41B293	2017-07-18 23:24:00+03	290600.00
41B299	2017-07-28 23:16:00+03	32800.00
41B30A	2017-08-01 09:45:00+03	4000.00
41B320	2017-08-14 16:48:00+03	103900.00
41B36D	2017-06-30 04:29:00+03	111600.00
41B3C9	2017-08-04 10:57:00+03	46700.00
41B4A4	2017-07-10 23:11:00+03	12600.00
41B57C	2017-07-30 20:07:00+03	88600.00
41B641	2017-07-02 08:04:00+03	46400.00
41B64A	2017-07-02 09:51:00+03	14400.00
41B65B	2017-07-07 02:21:00+03	52300.00
41B6C8	2017-08-10 15:54:00+03	16400.00
41B6DC	2017-06-30 07:29:00+03	67600.00
41B717	2017-07-16 13:05:00+03	55800.00
41B719	2017-07-06 22:19:00+03	57700.00
41B747	2017-08-14 18:22:00+03	38100.00
41B887	2017-07-08 12:18:00+03	44000.00
41B899	2017-08-04 05:28:00+03	95200.00
41B909	2017-08-07 15:20:00+03	44700.00
41B917	2017-07-23 15:05:00+03	205200.00
41B92F	2017-07-22 06:38:00+03	187800.00
41B940	2017-08-06 02:59:00+03	135400.00
41B98D	2017-06-29 20:04:00+03	56000.00
41B9C1	2017-07-11 01:09:00+03	53600.00
41B9ED	2017-07-25 20:12:00+03	32800.00
41BA7E	2017-07-23 13:01:00+03	20200.00
41BAF0	2017-08-11 14:09:00+03	95900.00
41BAFE	2017-08-15 09:53:00+03	80200.00
41BBAF	2017-08-15 08:00:00+03	13000.00
41BC23	2017-07-03 23:40:00+03	45200.00
41BCF5	2017-08-07 14:03:00+03	56000.00
41BD6E	2017-07-31 13:10:00+03	131000.00
41BD86	2017-08-01 04:54:00+03	77500.00
41BDA3	2017-07-12 00:06:00+03	51900.00
41BDB1	2017-08-03 19:37:00+03	3400.00
41BDBC	2017-08-06 20:22:00+03	25600.00
41BDC5	2017-07-24 20:08:00+03	12400.00
41BDCD	2017-07-12 03:48:00+03	52000.00
41BDD0	2017-07-23 10:19:00+03	79700.00
41BEA9	2017-06-28 08:53:00+03	28000.00
41BEF5	2017-07-23 04:35:00+03	21800.00
41BFCD	2017-07-09 03:49:00+03	65400.00
41BFEA	2017-08-02 07:53:00+03	35800.00
41BFF6	2017-07-12 19:46:00+03	26800.00
41C085	2017-08-10 03:05:00+03	50000.00
41C0CB	2017-07-05 06:19:00+03	23200.00
41C0D9	2017-07-30 14:29:00+03	15900.00
41C117	2017-07-13 14:12:00+03	55600.00
41C123	2017-08-01 21:43:00+03	27200.00
41C128	2017-08-06 17:58:00+03	118600.00
41C165	2017-08-09 18:58:00+03	68800.00
41C324	2017-07-30 19:57:00+03	29100.00
41C348	2017-07-12 10:47:00+03	24400.00
41C360	2017-08-01 08:02:00+03	28200.00
41C3D8	2017-07-26 11:25:00+03	75300.00
41C453	2017-08-01 15:52:00+03	82400.00
41C456	2017-07-02 09:07:00+03	72800.00
41C522	2017-07-04 22:56:00+03	136200.00
41C52F	2017-08-04 15:25:00+03	21400.00
41C536	2017-07-04 21:49:00+03	140900.00
41C547	2017-07-30 06:16:00+03	55800.00
41C54B	2017-07-29 18:36:00+03	182300.00
41C5DD	2017-07-05 14:21:00+03	81600.00
41C5EF	2017-07-21 10:16:00+03	23200.00
41C684	2017-08-03 11:59:00+03	39500.00
41C69D	2017-07-01 22:42:00+03	37900.00
41C6BF	2017-06-30 16:38:00+03	62100.00
41C725	2017-08-06 00:33:00+03	46300.00
41C750	2017-07-18 00:36:00+03	28800.00
41C758	2017-07-31 07:17:00+03	26000.00
41C790	2017-07-08 19:04:00+03	81700.00
41C79C	2017-07-15 11:58:00+03	458600.00
41C835	2017-08-07 08:11:00+03	72200.00
41C83B	2017-07-24 06:52:00+03	46300.00
41C841	2017-08-08 03:11:00+03	133200.00
41C87A	2017-08-13 08:09:00+03	40300.00
41C8A1	2017-07-05 22:31:00+03	113700.00
41C959	2017-07-16 17:01:00+03	515000.00
41CA23	2017-07-04 02:27:00+03	77000.00
41CA3C	2017-07-10 13:35:00+03	67200.00
41CA9C	2017-07-28 18:33:00+03	30200.00
41CAFA	2017-07-15 09:13:00+03	38600.00
41CB12	2017-07-06 21:04:00+03	50800.00
41CBC4	2017-07-31 09:10:00+03	24400.00
41CBE2	2017-07-16 18:49:00+03	142400.00
41CC0D	2017-08-11 05:10:00+03	39200.00
41CC3D	2017-08-15 13:23:00+03	246000.00
41CC59	2017-07-13 00:05:00+03	48800.00
41CC7B	2017-07-11 04:05:00+03	31400.00
41CC80	2017-06-30 06:00:00+03	11700.00
41CCB0	2017-07-19 15:03:00+03	35200.00
41CCBC	2017-07-31 13:38:00+03	23600.00
41CCD2	2017-07-12 08:15:00+03	14000.00
41CD61	2017-07-25 00:16:00+03	51600.00
41CDBF	2017-08-13 21:55:00+03	28000.00
41CDF3	2017-07-28 18:38:00+03	28600.00
41CE7D	2017-08-04 18:43:00+03	117600.00
41CEB2	2017-08-15 12:40:00+03	56900.00
41CED3	2017-07-20 19:50:00+03	34000.00
41CEF4	2017-07-30 21:47:00+03	39600.00
41CF22	2017-08-08 20:46:00+03	58600.00
41CF5A	2017-08-14 22:13:00+03	62600.00
41D0E0	2017-07-14 12:32:00+03	38800.00
41D102	2017-08-06 10:10:00+03	13200.00
41D11A	2017-08-07 20:42:00+03	89700.00
41D125	2017-07-26 16:31:00+03	100600.00
41D158	2017-07-21 19:31:00+03	20200.00
41D17A	2017-07-25 11:35:00+03	16400.00
41D1C2	2017-08-01 12:10:00+03	398300.00
41D1CD	2017-07-19 19:23:00+03	88400.00
41D229	2017-08-07 23:06:00+03	18600.00
41D233	2017-06-26 03:27:00+03	99300.00
41D29D	2017-07-09 00:21:00+03	25800.00
41D2A2	2017-08-14 05:38:00+03	91100.00
41D319	2017-07-10 11:27:00+03	113600.00
41D358	2017-08-05 06:03:00+03	101000.00
41D3AE	2017-07-04 08:25:00+03	52700.00
41D465	2017-07-07 13:56:00+03	132000.00
41D522	2017-07-20 06:57:00+03	52300.00
41D539	2017-08-04 11:14:00+03	143500.00
41D555	2017-08-10 18:03:00+03	89700.00
41D56C	2017-07-12 09:27:00+03	69600.00
41D571	2017-07-01 06:11:00+03	24800.00
41D5AF	2017-07-28 01:13:00+03	55000.00
41D5CB	2017-07-01 09:53:00+03	266400.00
41D5D9	2017-08-10 16:25:00+03	39200.00
41D5FA	2017-07-23 01:42:00+03	44400.00
41D5FC	2017-07-18 17:54:00+03	133100.00
41D64B	2017-07-17 18:18:00+03	96300.00
41D694	2017-08-04 09:36:00+03	28800.00
41D6C6	2017-07-30 15:00:00+03	56000.00
41D6CC	2017-08-14 03:03:00+03	91600.00
41D6E1	2017-07-20 07:14:00+03	202300.00
41D786	2017-07-19 13:23:00+03	202400.00
41D78C	2017-06-30 08:38:00+03	56000.00
41D7A0	2017-07-03 18:17:00+03	132700.00
41D7B6	2017-08-14 01:03:00+03	73300.00
41D808	2017-07-21 15:16:00+03	28800.00
41D80B	2017-07-22 01:26:00+03	89700.00
41D827	2017-07-13 04:41:00+03	62800.00
41D835	2017-08-01 12:19:00+03	56000.00
41D854	2017-07-02 06:58:00+03	26000.00
41D8AD	2017-08-09 18:55:00+03	160700.00
41D8C1	2017-08-02 20:15:00+03	7200.00
41D9BF	2017-07-24 14:16:00+03	47000.00
41D9CB	2017-07-18 12:33:00+03	74400.00
41D9DE	2017-08-13 09:17:00+03	73900.00
41DA2D	2017-07-07 13:43:00+03	68800.00
41DA4E	2017-07-11 04:10:00+03	57600.00
41DA76	2017-07-01 21:51:00+03	38000.00
41DA7B	2017-07-11 23:26:00+03	13400.00
41DAD9	2017-07-07 07:01:00+03	101800.00
41DADF	2017-07-14 13:00:00+03	61500.00
41DAF3	2017-08-04 02:07:00+03	47100.00
41DB49	2017-07-06 20:40:00+03	13400.00
41DB73	2017-08-01 11:25:00+03	56100.00
41DB9C	2017-07-04 08:25:00+03	25400.00
41DC01	2017-08-05 06:33:00+03	76800.00
41DC0B	2017-07-28 13:13:00+03	42400.00
41DC3C	2017-07-17 21:53:00+03	99700.00
41DC6D	2017-08-07 07:54:00+03	14800.00
41DC7F	2017-07-25 16:03:00+03	28800.00
41DC85	2017-08-11 18:35:00+03	266400.00
41DD0D	2017-08-05 03:15:00+03	23400.00
41DD22	2017-07-02 03:32:00+03	66600.00
41DD76	2017-08-15 11:23:00+03	26000.00
41DDDD	2017-07-06 02:45:00+03	11000.00
41DE08	2017-07-12 05:48:00+03	36600.00
41DE51	2017-07-17 10:09:00+03	21800.00
41DE84	2017-07-22 23:47:00+03	130400.00
41DE8D	2017-08-12 20:26:00+03	147500.00
41DEA2	2017-07-07 04:50:00+03	64300.00
41DED4	2017-07-07 14:34:00+03	55600.00
41DF39	2017-07-17 06:12:00+03	231900.00
41DFD8	2017-07-19 10:49:00+03	103000.00
41E0DE	2017-07-16 23:56:00+03	243300.00
41E102	2017-07-15 23:33:00+03	78300.00
41E127	2017-07-08 09:16:00+03	6000.00
41E180	2017-07-29 18:12:00+03	293200.00
41E1A5	2017-07-29 05:02:00+03	70800.00
41E1AF	2017-08-13 15:46:00+03	38800.00
41E1CC	2017-07-11 21:41:00+03	36400.00
41E1DB	2017-07-14 18:05:00+03	28000.00
41E215	2017-07-17 01:01:00+03	133100.00
41E22E	2017-07-07 22:26:00+03	13600.00
41E293	2017-08-08 17:01:00+03	114800.00
41E2C5	2017-07-30 19:15:00+03	74700.00
41E2F8	2017-07-08 16:39:00+03	19200.00
41E33B	2017-06-28 10:22:00+03	40600.00
41E36A	2017-07-06 03:39:00+03	182500.00
41E374	2017-07-27 04:39:00+03	103500.00
41E4E9	2017-08-13 19:20:00+03	26700.00
41E532	2017-07-07 17:47:00+03	34200.00
41E57A	2017-07-31 06:40:00+03	57400.00
41E5E6	2017-07-12 06:01:00+03	173100.00
41E609	2017-07-30 08:29:00+03	18600.00
41E62D	2017-08-11 06:22:00+03	266300.00
41E63B	2017-08-08 22:14:00+03	64400.00
41E6C6	2017-08-10 02:25:00+03	30200.00
41E6CD	2017-08-13 13:24:00+03	166100.00
41E70F	2017-08-13 21:48:00+03	125600.00
41E74C	2017-07-01 21:31:00+03	57800.00
41E771	2017-07-07 03:20:00+03	55800.00
41E79B	2017-08-13 15:23:00+03	29900.00
41E7E3	2017-08-07 13:51:00+03	81700.00
41E7E9	2017-08-09 10:29:00+03	219300.00
41E867	2017-07-16 09:02:00+03	98400.00
41E86C	2017-07-03 04:21:00+03	7200.00
41E91E	2017-08-09 12:34:00+03	128800.00
41E93C	2017-08-07 22:47:00+03	62000.00
41E975	2017-07-28 20:41:00+03	30800.00
41E97D	2017-08-14 03:42:00+03	30900.00
41E9D9	2017-08-03 21:38:00+03	181500.00
41EA3E	2017-07-15 15:58:00+03	123000.00
41EA5F	2017-07-17 15:32:00+03	109200.00
41EA74	2017-07-09 05:35:00+03	81600.00
41EA92	2017-07-31 03:51:00+03	42700.00
41EA9F	2017-08-08 19:23:00+03	8000.00
41EB0D	2017-08-11 09:10:00+03	73200.00
41EB15	2017-07-15 08:32:00+03	25000.00
41EB4D	2017-07-08 17:10:00+03	28800.00
41EB91	2017-07-11 07:37:00+03	85000.00
41EC09	2017-07-12 14:05:00+03	118100.00
41EC66	2017-08-06 02:04:00+03	23200.00
41EC89	2017-07-31 15:21:00+03	21400.00
41ECCC	2017-07-24 11:08:00+03	102100.00
41ECF2	2017-08-08 18:58:00+03	42800.00
41ED10	2017-08-14 02:18:00+03	40000.00
41ED28	2017-07-16 15:14:00+03	46300.00
41ED53	2017-07-04 14:47:00+03	40900.00
41ED56	2017-07-19 00:05:00+03	399600.00
41ED5E	2017-07-12 09:54:00+03	28000.00
41ED72	2017-07-21 12:00:00+03	12600.00
41ED7E	2017-07-25 05:12:00+03	18700.00
41ED84	2017-07-04 21:19:00+03	123000.00
41EDAD	2017-08-13 22:39:00+03	50600.00
41EDD7	2017-07-16 06:01:00+03	12600.00
41EDE7	2017-08-15 17:52:00+03	787100.00
41EE0D	2017-08-13 02:33:00+03	48400.00
41EE35	2017-08-11 20:57:00+03	92900.00
41EE58	2017-08-12 12:24:00+03	36900.00
41EF18	2017-08-14 10:53:00+03	113600.00
41EF38	2017-07-23 12:06:00+03	67100.00
41EFB1	2017-08-02 11:42:00+03	49200.00
41EFCD	2017-07-28 19:23:00+03	68400.00
41F067	2017-07-29 15:27:00+03	27200.00
41F135	2017-07-16 03:29:00+03	258400.00
41F199	2017-07-04 13:25:00+03	156300.00
41F1C2	2017-07-17 07:50:00+03	13600.00
41F246	2017-07-28 11:34:00+03	56000.00
41F279	2017-08-01 09:41:00+03	25400.00
41F27A	2017-08-06 16:04:00+03	136600.00
41F283	2017-07-18 02:20:00+03	68800.00
41F2C1	2017-06-29 16:52:00+03	102700.00
41F324	2017-08-03 08:38:00+03	56600.00
41F345	2017-07-21 09:27:00+03	30200.00
41F376	2017-07-05 07:34:00+03	10800.00
41F3CC	2017-08-11 07:10:00+03	27300.00
41F4A8	2017-07-22 16:43:00+03	93600.00
41F563	2017-08-08 12:07:00+03	46700.00
41F57E	2017-08-07 03:13:00+03	47100.00
41F5E7	2017-08-06 07:50:00+03	149100.00
41F5F5	2017-07-05 17:55:00+03	31600.00
41F5FA	2017-07-12 03:10:00+03	29600.00
41F632	2017-07-31 11:25:00+03	89600.00
41F659	2017-08-05 14:27:00+03	47400.00
41F67E	2017-07-04 11:21:00+03	36200.00
41F688	2017-08-08 17:13:00+03	66000.00
41F705	2017-07-10 13:07:00+03	111600.00
41F732	2017-06-29 23:52:00+03	137800.00
41F74A	2017-07-20 06:15:00+03	275000.00
41F76A	2017-07-29 12:41:00+03	32700.00
41F7C4	2017-07-08 21:12:00+03	56600.00
41F7D0	2017-07-04 23:20:00+03	46000.00
41F7D2	2017-08-01 21:59:00+03	62900.00
41F811	2017-07-20 23:22:00+03	44600.00
41F818	2017-08-01 04:14:00+03	83700.00
41F85A	2017-07-17 07:22:00+03	262500.00
41F87D	2017-07-16 18:03:00+03	56000.00
41F89C	2017-08-08 23:01:00+03	81500.00
41F8BE	2017-07-01 13:15:00+03	30400.00
41F8C1	2017-07-25 18:45:00+03	6000.00
41F8D4	2017-08-01 04:30:00+03	246000.00
41F8D9	2017-07-13 00:10:00+03	36800.00
41F909	2017-07-15 20:49:00+03	57700.00
41F937	2017-08-14 08:12:00+03	445200.00
41F97D	2017-08-12 00:05:00+03	26000.00
41F988	2017-07-15 03:46:00+03	73500.00
41F9B7	2017-07-20 20:53:00+03	120700.00
41F9CA	2017-07-24 00:25:00+03	92800.00
41F9D3	2017-08-11 08:39:00+03	118000.00
41FA52	2017-07-14 05:45:00+03	46400.00
41FA75	2017-08-04 10:05:00+03	234200.00
41FADC	2017-08-04 15:58:00+03	86600.00
41FADF	2017-07-15 02:39:00+03	68000.00
41FB23	2017-07-06 18:29:00+03	61800.00
41FB64	2017-07-22 11:09:00+03	22400.00
41FB77	2017-07-16 18:02:00+03	43000.00
41FBAB	2017-08-08 17:00:00+03	26700.00
41FBC9	2017-06-29 06:34:00+03	95200.00
41FBFC	2017-07-25 18:34:00+03	26000.00
41FC52	2017-08-11 19:54:00+03	55800.00
41FC86	2017-07-29 22:37:00+03	658600.00
41FCE1	2017-08-04 02:29:00+03	92800.00
41FCE2	2017-07-31 10:43:00+03	100600.00
41FD3F	2017-07-02 03:01:00+03	76400.00
41FD51	2017-06-30 06:58:00+03	35300.00
41FDE9	2017-07-30 07:09:00+03	12600.00
41FE40	2017-08-06 21:08:00+03	47600.00
41FEDF	2017-08-04 00:28:00+03	14000.00
41FF00	2017-07-07 02:49:00+03	43200.00
41FF47	2017-07-17 00:55:00+03	151500.00
42000D	2017-07-17 20:18:00+03	146600.00
42003B	2017-08-15 12:51:00+03	214500.00
42003F	2017-08-15 10:32:00+03	111600.00
42010F	2017-07-13 08:01:00+03	189800.00
420140	2017-08-13 05:49:00+03	93000.00
420147	2017-07-13 11:47:00+03	143300.00
42026A	2017-07-02 16:38:00+03	398500.00
42026E	2017-08-12 23:30:00+03	81600.00
42029B	2017-07-28 12:08:00+03	70100.00
420304	2017-08-01 13:35:00+03	10800.00
42030A	2017-07-29 15:14:00+03	96200.00
42031B	2017-07-10 18:06:00+03	78600.00
420320	2017-08-07 11:39:00+03	46400.00
420348	2017-08-10 03:37:00+03	7400.00
420373	2017-07-28 02:27:00+03	66000.00
420383	2017-08-06 03:33:00+03	46000.00
4203A3	2017-07-20 03:27:00+03	169900.00
4203E4	2017-07-06 09:50:00+03	40400.00
42040A	2017-08-02 10:15:00+03	61800.00
420484	2017-07-04 05:27:00+03	31700.00
4204B9	2017-07-28 19:53:00+03	92400.00
4204C3	2017-07-27 18:20:00+03	46200.00
420556	2017-08-11 03:04:00+03	36600.00
420583	2017-07-10 16:50:00+03	216500.00
42059D	2017-07-15 08:25:00+03	37800.00
420605	2017-07-30 18:01:00+03	57400.00
420611	2017-07-17 13:08:00+03	65100.00
420615	2017-07-13 18:50:00+03	133100.00
420622	2017-07-17 12:02:00+03	71600.00
420647	2017-07-01 12:03:00+03	40000.00
420680	2017-07-05 11:37:00+03	38000.00
420692	2017-07-23 00:12:00+03	81300.00
4206A0	2017-06-27 08:47:00+03	135600.00
4206DC	2017-08-10 00:29:00+03	28000.00
420770	2017-07-28 08:46:00+03	112000.00
420789	2017-08-08 09:07:00+03	54500.00
42082B	2017-07-01 00:44:00+03	24400.00
42083B	2017-07-01 11:53:00+03	38600.00
420851	2017-07-27 19:37:00+03	59000.00
420886	2017-07-27 01:44:00+03	124200.00
4208F0	2017-07-23 01:25:00+03	23600.00
4208F1	2017-07-15 12:12:00+03	224000.00
420935	2017-07-13 22:57:00+03	67000.00
42096B	2017-08-09 21:42:00+03	49200.00
420994	2017-07-14 06:42:00+03	46800.00
4209AF	2017-07-22 17:11:00+03	133200.00
4209EF	2017-08-03 03:34:00+03	246000.00
420A08	2017-07-10 11:04:00+03	26000.00
420A3C	2017-07-18 19:56:00+03	60900.00
420A3D	2017-06-29 07:29:00+03	12600.00
420A5C	2017-08-01 08:54:00+03	72400.00
420A8F	2017-08-12 09:42:00+03	45900.00
420A96	2017-06-30 19:34:00+03	20400.00
420AB8	2017-07-29 10:04:00+03	64800.00
420AC4	2017-07-05 06:09:00+03	40000.00
420B81	2017-07-22 09:22:00+03	76900.00
420BB3	2017-08-15 08:59:00+03	46400.00
420BC1	2017-07-31 13:56:00+03	24600.00
420BC4	2017-07-28 15:18:00+03	59800.00
420BD9	2017-07-08 18:49:00+03	22000.00
420BDB	2017-07-25 12:08:00+03	58000.00
420C2A	2017-07-08 10:51:00+03	28000.00
420C32	2017-08-12 07:06:00+03	115700.00
420C33	2017-08-10 20:27:00+03	56600.00
420C62	2017-08-14 16:42:00+03	38800.00
420CC9	2017-07-16 17:02:00+03	45400.00
420D1D	2017-07-09 13:03:00+03	28000.00
420D3E	2017-08-03 01:37:00+03	155600.00
420D66	2017-07-25 10:50:00+03	56300.00
420E68	2017-07-05 07:28:00+03	50800.00
420EB4	2017-07-05 22:15:00+03	35600.00
420EB8	2017-08-08 09:58:00+03	66300.00
420F06	2017-07-05 03:19:00+03	15000.00
420F33	2017-08-08 17:20:00+03	43200.00
420F48	2017-06-27 21:19:00+03	45400.00
420F6D	2017-08-11 00:33:00+03	61800.00
420F89	2017-07-30 08:37:00+03	25600.00
420FDE	2017-08-15 11:34:00+03	33800.00
420FE6	2017-08-11 16:32:00+03	27900.00
420FFF	2017-06-30 17:17:00+03	42800.00
421011	2017-08-13 00:40:00+03	136200.00
421028	2017-08-11 20:12:00+03	90700.00
421030	2017-07-21 20:34:00+03	28000.00
421064	2017-07-20 00:38:00+03	14400.00
421083	2017-07-04 06:34:00+03	20800.00
4210AD	2017-06-28 09:01:00+03	53100.00
4210B0	2017-07-23 12:02:00+03	131600.00
4211AD	2017-07-12 08:47:00+03	67900.00
4211FA	2017-07-20 10:32:00+03	258000.00
421215	2017-07-09 22:17:00+03	99300.00
421248	2017-07-17 17:53:00+03	258400.00
421254	2017-08-12 11:24:00+03	85700.00
4212C5	2017-07-08 15:25:00+03	13400.00
4212FA	2017-07-29 12:25:00+03	67400.00
421308	2017-07-08 02:14:00+03	56000.00
421369	2017-07-21 02:56:00+03	31600.00
421377	2017-07-13 21:15:00+03	45200.00
4213E5	2017-08-13 10:36:00+03	48500.00
42140D	2017-08-11 15:11:00+03	179800.00
421448	2017-07-23 20:41:00+03	8200.00
421494	2017-07-23 05:33:00+03	58600.00
42164F	2017-08-05 10:35:00+03	258400.00
421680	2017-07-05 15:46:00+03	94900.00
42168E	2017-07-26 01:14:00+03	32700.00
421692	2017-07-14 12:05:00+03	43600.00
4217A0	2017-08-09 06:59:00+03	116400.00
4217CD	2017-08-08 13:50:00+03	31600.00
42184F	2017-07-13 06:11:00+03	30000.00
421862	2017-07-13 02:31:00+03	57500.00
4218FD	2017-08-15 10:09:00+03	40800.00
421901	2017-08-12 07:07:00+03	20000.00
4219E4	2017-07-09 07:06:00+03	179500.00
4219ED	2017-07-14 07:00:00+03	58600.00
4219FA	2017-08-12 18:47:00+03	69500.00
421A29	2017-07-12 12:57:00+03	68800.00
421A71	2017-07-12 14:01:00+03	57100.00
421A9E	2017-07-14 15:41:00+03	65900.00
421AAD	2017-08-10 23:12:00+03	112000.00
421AF2	2017-08-03 13:32:00+03	14000.00
421B71	2017-08-09 21:33:00+03	131600.00
421B7E	2017-07-10 07:08:00+03	300700.00
421BC3	2017-07-21 16:44:00+03	47100.00
421BEA	2017-07-30 08:52:00+03	26000.00
421BEB	2017-07-21 21:33:00+03	90000.00
421C54	2017-08-01 15:40:00+03	64500.00
421CB2	2017-08-13 19:57:00+03	440900.00
421D33	2017-07-30 20:26:00+03	73200.00
421D9C	2017-08-13 00:04:00+03	38400.00
421E48	2017-07-21 07:02:00+03	40200.00
421E65	2017-07-12 17:04:00+03	6300.00
421E6B	2017-07-30 18:41:00+03	14400.00
421E72	2017-07-05 07:27:00+03	75300.00
421EB7	2017-08-06 01:53:00+03	89200.00
421EDE	2017-08-07 10:44:00+03	16400.00
421F00	2017-07-18 10:16:00+03	30900.00
421F41	2017-07-25 17:33:00+03	32800.00
421F58	2017-07-12 22:40:00+03	62800.00
422055	2017-07-11 13:10:00+03	14800.00
422068	2017-08-11 16:09:00+03	14000.00
42207C	2017-07-22 14:14:00+03	54400.00
4220AA	2017-08-10 19:36:00+03	44800.00
4220F7	2017-08-15 17:14:00+03	151200.00
422103	2017-07-14 11:08:00+03	260900.00
422156	2017-08-14 09:55:00+03	242700.00
4221FC	2017-08-08 00:22:00+03	66600.00
422212	2017-08-09 08:26:00+03	35600.00
422224	2017-08-11 11:15:00+03	87200.00
422248	2017-08-03 08:19:00+03	40000.00
42226C	2017-08-14 15:42:00+03	26700.00
4222C3	2017-07-10 19:23:00+03	74800.00
4222CE	2017-08-11 23:23:00+03	112000.00
4222E5	2017-08-15 03:27:00+03	70200.00
42231B	2017-07-16 15:48:00+03	49400.00
422329	2017-07-01 04:36:00+03	108000.00
422389	2017-07-15 06:06:00+03	149800.00
422397	2017-07-10 23:13:00+03	70400.00
4223B5	2017-07-21 08:50:00+03	55800.00
422425	2017-08-11 00:17:00+03	35200.00
42242D	2017-08-07 22:45:00+03	56000.00
42244E	2017-08-13 19:51:00+03	60400.00
4224A0	2017-07-27 03:36:00+03	46700.00
4224D0	2017-08-15 15:46:00+03	114500.00
4224D5	2017-07-18 14:43:00+03	70700.00
422508	2017-08-03 09:44:00+03	28000.00
422578	2017-07-11 05:14:00+03	213200.00
4225B9	2017-07-25 09:10:00+03	113300.00
4226BB	2017-07-17 05:49:00+03	411700.00
422700	2017-08-08 21:21:00+03	210200.00
422705	2017-07-09 02:49:00+03	12800.00
422735	2017-06-29 17:18:00+03	27200.00
422736	2017-07-06 17:05:00+03	133100.00
4227B1	2017-07-14 10:33:00+03	37600.00
4227F8	2017-08-09 03:48:00+03	7200.00
4227FA	2017-07-07 21:09:00+03	29600.00
422846	2017-07-30 16:52:00+03	46800.00
422864	2017-07-29 13:56:00+03	57600.00
422898	2017-08-07 00:45:00+03	542300.00
4228D9	2017-08-11 03:18:00+03	289800.00
4228EE	2017-07-06 21:33:00+03	417600.00
4228F2	2017-07-14 12:40:00+03	73200.00
42290D	2017-08-01 03:03:00+03	99900.00
4229EE	2017-07-14 17:02:00+03	51200.00
422A42	2017-07-21 23:10:00+03	14800.00
422A49	2017-07-30 04:21:00+03	27400.00
422ADC	2017-06-26 15:43:00+03	29600.00
422ADF	2017-08-11 10:46:00+03	12000.00
422B4B	2017-07-11 16:07:00+03	114800.00
422C46	2017-07-15 21:48:00+03	186900.00
422C69	2017-07-10 05:53:00+03	266400.00
422CCA	2017-07-09 11:40:00+03	41200.00
422CF2	2017-08-08 17:02:00+03	138300.00
422CF5	2017-07-16 03:41:00+03	47000.00
422D3C	2017-07-04 12:56:00+03	16400.00
422D5A	2017-07-30 02:24:00+03	46200.00
422DA4	2017-07-27 10:00:00+03	67600.00
422DA6	2017-08-05 01:12:00+03	23600.00
422E2D	2017-07-12 11:31:00+03	50700.00
422E3A	2017-07-13 14:43:00+03	12400.00
422E53	2017-08-15 00:12:00+03	65900.00
422E8A	2017-08-12 22:29:00+03	23200.00
422E8C	2017-07-09 14:43:00+03	77600.00
422E96	2017-08-10 08:19:00+03	147700.00
422ED9	2017-07-03 01:33:00+03	24600.00
422EF5	2017-08-08 13:04:00+03	109600.00
422F0F	2017-07-31 17:47:00+03	123000.00
422F52	2017-08-07 13:37:00+03	223200.00
422F74	2017-08-06 21:10:00+03	72400.00
42301D	2017-08-12 15:02:00+03	89700.00
4231B2	2017-08-08 13:27:00+03	26000.00
423226	2017-08-01 12:50:00+03	94000.00
423265	2017-07-13 23:11:00+03	62700.00
423298	2017-07-04 09:47:00+03	56100.00
4232B2	2017-07-09 22:55:00+03	46400.00
423334	2017-08-07 12:29:00+03	182300.00
423392	2017-08-15 00:42:00+03	135400.00
42340A	2017-07-11 15:51:00+03	24800.00
423438	2017-08-10 15:28:00+03	26800.00
423489	2017-07-31 14:37:00+03	61400.00
4234A8	2017-08-13 01:09:00+03	46300.00
4234B2	2017-08-02 12:30:00+03	36200.00
4234EF	2017-07-25 08:02:00+03	46800.00
42350C	2017-08-14 10:46:00+03	36600.00
423524	2017-07-05 09:40:00+03	168000.00
42352F	2017-08-15 06:42:00+03	122300.00
4235AC	2017-07-23 23:16:00+03	48400.00
4235D4	2017-07-03 15:36:00+03	114400.00
423658	2017-07-29 05:44:00+03	55800.00
42367F	2017-07-30 02:53:00+03	40000.00
4236B8	2017-07-03 23:40:00+03	25000.00
4236E7	2017-07-03 19:24:00+03	40000.00
423743	2017-08-09 11:34:00+03	46400.00
423751	2017-08-04 03:59:00+03	90800.00
42377F	2017-08-12 19:53:00+03	14000.00
4237D6	2017-08-04 16:13:00+03	36200.00
4237FD	2017-06-27 19:10:00+03	40000.00
42380F	2017-07-07 05:48:00+03	47000.00
423844	2017-07-15 07:58:00+03	35700.00
423857	2017-07-16 05:53:00+03	38400.00
423909	2017-07-28 15:52:00+03	144000.00
42390D	2017-07-07 04:14:00+03	81600.00
423915	2017-07-22 16:09:00+03	86300.00
423945	2017-08-12 07:16:00+03	42600.00
423960	2017-07-13 15:37:00+03	23200.00
423969	2017-08-08 14:56:00+03	26000.00
423975	2017-07-24 13:48:00+03	39400.00
4239CD	2017-07-06 14:30:00+03	57500.00
4239EE	2017-07-05 16:27:00+03	42800.00
4239FF	2017-08-06 08:27:00+03	28000.00
423A4F	2017-07-14 10:58:00+03	92900.00
423AFC	2017-07-30 14:54:00+03	27800.00
423B5C	2017-07-02 02:16:00+03	273300.00
423B9B	2017-07-20 02:43:00+03	12600.00
423BA2	2017-08-04 00:23:00+03	25000.00
423BB7	2017-07-27 07:30:00+03	27300.00
423BCF	2017-07-25 15:34:00+03	103900.00
423CD9	2017-07-24 20:26:00+03	98200.00
423D3B	2017-08-10 21:43:00+03	55800.00
423D6D	2017-07-13 19:02:00+03	47400.00
423D83	2017-07-10 02:33:00+03	89700.00
423DD7	2017-07-09 10:39:00+03	84100.00
423DF1	2017-07-15 22:52:00+03	23200.00
423E11	2017-07-25 07:14:00+03	100600.00
423E8B	2017-06-28 11:15:00+03	35600.00
423EA0	2017-08-01 20:41:00+03	51900.00
423F08	2017-07-30 00:37:00+03	31800.00
423F30	2017-08-04 10:25:00+03	52600.00
423F49	2017-08-15 07:22:00+03	15000.00
423F76	2017-08-07 22:07:00+03	56900.00
423FB7	2017-08-03 13:32:00+03	38800.00
423FCC	2017-07-06 08:22:00+03	178000.00
423FD4	2017-07-02 16:01:00+03	61700.00
423FF8	2017-07-31 15:02:00+03	14400.00
424006	2017-08-04 23:32:00+03	56600.00
42400F	2017-07-27 12:31:00+03	99300.00
424052	2017-07-18 07:53:00+03	8400.00
424086	2017-08-01 05:56:00+03	53600.00
42415F	2017-07-04 13:02:00+03	12600.00
42416A	2017-07-12 20:15:00+03	56000.00
42419A	2017-07-29 02:18:00+03	51600.00
42423A	2017-08-14 01:08:00+03	207200.00
424277	2017-07-18 05:59:00+03	145200.00
42427B	2017-08-13 15:25:00+03	135300.00
424288	2017-07-01 08:24:00+03	135000.00
4242B9	2017-07-09 18:10:00+03	45200.00
424350	2017-08-10 05:21:00+03	27200.00
42437A	2017-07-17 00:03:00+03	91800.00
4243A9	2017-07-18 15:45:00+03	46700.00
4243BE	2017-07-20 05:57:00+03	28800.00
4243F9	2017-07-25 05:10:00+03	56600.00
424434	2017-07-21 11:34:00+03	60800.00
424464	2017-08-12 07:15:00+03	276900.00
424484	2017-08-15 09:43:00+03	18900.00
4244EE	2017-07-06 19:30:00+03	55800.00
4244FF	2017-07-14 20:47:00+03	198600.00
42454A	2017-07-15 00:38:00+03	114800.00
424584	2017-08-09 06:42:00+03	59000.00
4245D6	2017-08-03 03:49:00+03	92800.00
424611	2017-08-03 22:57:00+03	83000.00
42466A	2017-08-08 17:32:00+03	40800.00
424676	2017-08-02 22:01:00+03	64000.00
4246A2	2017-08-15 17:52:00+03	54000.00
4246E9	2017-08-06 02:35:00+03	10700.00
4246F0	2017-06-23 23:20:00+03	46000.00
4247AD	2017-07-08 06:26:00+03	21200.00
4247B1	2017-07-11 06:42:00+03	12000.00
424842	2017-08-10 23:07:00+03	75100.00
424877	2017-08-09 13:43:00+03	181200.00
42488A	2017-07-11 20:25:00+03	71600.00
424896	2017-08-12 10:00:00+03	28800.00
4248F1	2017-07-20 22:53:00+03	74400.00
4248F5	2017-07-13 17:01:00+03	53400.00
4248F9	2017-07-03 19:20:00+03	36200.00
4248FB	2017-06-29 20:38:00+03	25400.00
424914	2017-07-09 22:02:00+03	92900.00
42498B	2017-07-08 00:04:00+03	17600.00
424A5B	2017-07-08 08:33:00+03	135400.00
424A68	2017-07-12 14:47:00+03	8400.00
424ADC	2017-07-29 13:25:00+03	82900.00
424B19	2017-08-06 21:57:00+03	75600.00
424B1C	2017-07-27 00:08:00+03	85800.00
424B48	2017-08-08 16:31:00+03	21600.00
424B6F	2017-08-07 00:01:00+03	26000.00
424BC9	2017-07-18 18:39:00+03	14000.00
424C07	2017-08-02 14:26:00+03	23600.00
424C2C	2017-08-11 11:29:00+03	189400.00
424C3F	2017-07-17 04:08:00+03	177200.00
424C44	2017-08-12 07:41:00+03	39800.00
424C4B	2017-07-24 11:49:00+03	240600.00
424C69	2017-07-28 11:39:00+03	65800.00
424CD9	2017-07-10 13:40:00+03	28000.00
424D5F	2017-08-03 12:37:00+03	43600.00
424D86	2017-07-04 19:08:00+03	37900.00
424E3F	2017-07-03 07:13:00+03	76400.00
424F2E	2017-07-09 04:45:00+03	25400.00
424F3D	2017-07-09 03:24:00+03	11800.00
424F66	2017-06-27 20:50:00+03	16800.00
424F71	2017-07-30 06:10:00+03	31000.00
424FE1	2017-07-10 05:30:00+03	6700.00
424FF7	2017-07-21 14:30:00+03	80300.00
425000	2017-08-05 16:27:00+03	44600.00
425021	2017-08-04 01:10:00+03	48700.00
425067	2017-07-06 15:08:00+03	56000.00
4250C4	2017-08-10 23:30:00+03	12400.00
425174	2017-07-06 10:50:00+03	31600.00
425225	2017-08-13 17:47:00+03	37500.00
425241	2017-08-13 17:58:00+03	55800.00
425250	2017-07-11 14:08:00+03	48400.00
4252B6	2017-07-20 21:03:00+03	36200.00
42530E	2017-07-07 08:10:00+03	6000.00
42531E	2017-08-08 20:51:00+03	31400.00
42533C	2017-08-08 03:59:00+03	10600.00
425355	2017-08-07 04:13:00+03	82900.00
42537D	2017-07-17 22:55:00+03	43600.00
4253E1	2017-07-04 01:35:00+03	36200.00
425417	2017-07-23 19:02:00+03	56600.00
425490	2017-08-08 21:05:00+03	58600.00
4254C1	2017-08-04 03:30:00+03	51900.00
42558E	2017-07-28 12:47:00+03	77200.00
4255B8	2017-07-16 16:16:00+03	55800.00
4255F8	2017-07-19 18:28:00+03	28200.00
425636	2017-07-30 12:50:00+03	40200.00
425638	2017-07-15 12:37:00+03	66600.00
4256EF	2017-08-03 15:22:00+03	62000.00
425717	2017-08-02 03:59:00+03	90600.00
42574E	2017-07-19 10:38:00+03	300400.00
425776	2017-08-10 09:27:00+03	14000.00
425786	2017-07-15 16:12:00+03	36600.00
4257B6	2017-07-30 04:01:00+03	56000.00
4257B7	2017-07-25 00:35:00+03	31200.00
4257C0	2017-06-30 13:18:00+03	65500.00
425819	2017-07-31 11:30:00+03	65100.00
4258B8	2017-07-28 07:24:00+03	540000.00
4258D8	2017-07-11 15:14:00+03	58400.00
4258E3	2017-07-09 06:53:00+03	28000.00
425A08	2017-07-16 05:10:00+03	67200.00
425A50	2017-08-13 06:33:00+03	103000.00
425A58	2017-07-27 01:30:00+03	58800.00
425A74	2017-07-18 23:54:00+03	27900.00
425A8C	2017-07-25 13:02:00+03	270700.00
425AC5	2017-07-14 21:37:00+03	258000.00
425ADA	2017-07-18 20:58:00+03	98300.00
425AF5	2017-08-02 02:42:00+03	24700.00
425B45	2017-08-09 01:26:00+03	118900.00
425B6B	2017-07-27 23:10:00+03	270000.00
425BBE	2017-08-01 16:15:00+03	37500.00
425BD0	2017-07-04 00:50:00+03	55800.00
425C0D	2017-08-04 15:02:00+03	10800.00
425C25	2017-07-14 22:13:00+03	55800.00
425C77	2017-08-12 11:37:00+03	34600.00
425CBC	2017-08-15 08:03:00+03	12600.00
425CD3	2017-07-16 14:10:00+03	111600.00
425CD6	2017-07-26 16:18:00+03	15800.00
425D2D	2017-07-29 20:48:00+03	58000.00
425D72	2017-08-01 21:15:00+03	37600.00
425D90	2017-07-06 20:05:00+03	128800.00
425DAA	2017-07-01 19:42:00+03	167400.00
425E3E	2017-07-15 20:51:00+03	80000.00
425F53	2017-07-31 08:54:00+03	68000.00
425F65	2017-08-06 04:59:00+03	77000.00
425FCC	2017-07-10 09:23:00+03	23200.00
426033	2017-08-15 05:54:00+03	32800.00
42604D	2017-07-11 03:50:00+03	70800.00
42605E	2017-08-02 00:17:00+03	50800.00
42609E	2017-08-05 14:04:00+03	6700.00
4260B8	2017-08-14 09:10:00+03	98700.00
4260C9	2017-08-10 22:53:00+03	26000.00
4260FD	2017-08-06 15:58:00+03	57600.00
426119	2017-08-08 17:31:00+03	56000.00
426167	2017-07-23 13:07:00+03	333800.00
426168	2017-07-23 02:17:00+03	88600.00
4261C5	2017-08-05 17:51:00+03	64100.00
426220	2017-07-23 00:08:00+03	54400.00
42628E	2017-07-07 12:34:00+03	20200.00
4262E1	2017-07-01 20:11:00+03	27200.00
4262E4	2017-07-10 22:48:00+03	10700.00
42630C	2017-07-23 06:43:00+03	189800.00
426312	2017-07-20 21:41:00+03	246000.00
42631F	2017-08-08 06:56:00+03	55600.00
426331	2017-07-10 22:24:00+03	193600.00
426360	2017-07-07 07:23:00+03	32700.00
42637D	2017-07-26 23:45:00+03	67400.00
4263A4	2017-08-11 11:03:00+03	39800.00
426438	2017-07-12 15:32:00+03	92700.00
426460	2017-07-21 22:47:00+03	73300.00
426462	2017-07-18 10:09:00+03	29600.00
42650B	2017-07-08 05:25:00+03	240600.00
42653E	2017-07-02 20:02:00+03	120800.00
42659E	2017-07-11 16:08:00+03	15800.00
4265B0	2017-08-04 02:58:00+03	162700.00
4265DA	2017-08-12 07:32:00+03	112000.00
426690	2017-07-04 10:03:00+03	59800.00
4266E5	2017-07-13 12:55:00+03	13400.00
426723	2017-08-11 03:20:00+03	34600.00
4267CF	2017-07-03 22:37:00+03	75600.00
4267FB	2017-07-09 14:45:00+03	83600.00
426821	2017-07-24 00:43:00+03	66400.00
4268B0	2017-08-11 23:10:00+03	113700.00
426935	2017-07-07 02:14:00+03	55800.00
426983	2017-08-06 09:39:00+03	68800.00
426A02	2017-08-02 20:54:00+03	147100.00
426A18	2017-07-06 16:34:00+03	16400.00
426A29	2017-07-26 22:28:00+03	132800.00
426A89	2017-07-04 18:36:00+03	24400.00
426AC4	2017-07-10 16:03:00+03	70800.00
426B11	2017-07-28 10:52:00+03	36800.00
426B4C	2017-07-30 18:36:00+03	113000.00
426BE1	2017-08-06 23:16:00+03	282100.00
426BF2	2017-07-23 04:51:00+03	69100.00
426C3B	2017-07-09 21:00:00+03	28000.00
426C42	2017-07-03 20:38:00+03	32800.00
426C4D	2017-07-29 08:48:00+03	272300.00
426C68	2017-07-16 17:56:00+03	84100.00
426C79	2017-07-30 20:08:00+03	56000.00
426CDA	2017-08-13 15:48:00+03	46400.00
426DB5	2017-08-06 00:21:00+03	56000.00
426E73	2017-08-12 06:46:00+03	260700.00
426E9E	2017-07-03 09:46:00+03	85400.00
426F3A	2017-07-13 21:51:00+03	229400.00
426F4B	2017-07-13 03:24:00+03	19100.00
426FAE	2017-08-15 03:51:00+03	13800.00
426FB3	2017-07-13 21:05:00+03	26000.00
42702B	2017-08-08 04:14:00+03	67600.00
427066	2017-07-10 21:51:00+03	56900.00
427089	2017-07-21 05:02:00+03	20400.00
4270BC	2017-08-13 20:31:00+03	58800.00
427100	2017-07-27 10:00:00+03	24400.00
42711C	2017-07-27 23:08:00+03	87100.00
42719E	2017-07-07 23:12:00+03	48800.00
4271B4	2017-08-12 08:06:00+03	76600.00
4271D2	2017-07-03 13:31:00+03	64400.00
4272EF	2017-08-12 10:51:00+03	12600.00
4272F4	2017-08-14 18:39:00+03	15800.00
42731A	2017-07-28 18:54:00+03	41200.00
427361	2017-07-03 06:04:00+03	84500.00
427377	2017-07-19 00:26:00+03	55800.00
4273B9	2017-08-14 22:24:00+03	651000.00
427415	2017-06-30 11:06:00+03	75200.00
42747B	2017-07-19 15:12:00+03	7400.00
42748E	2017-08-11 03:40:00+03	94000.00
4274D7	2017-08-11 22:09:00+03	124200.00
427517	2017-07-09 03:41:00+03	51600.00
42751C	2017-07-22 12:05:00+03	170600.00
4275E9	2017-08-06 05:17:00+03	6700.00
427653	2017-07-21 10:55:00+03	68800.00
427748	2017-07-06 03:17:00+03	46700.00
42776D	2017-07-09 11:08:00+03	65000.00
42777E	2017-07-01 15:22:00+03	24400.00
4277DA	2017-07-29 20:39:00+03	74800.00
4277FC	2017-07-04 05:50:00+03	33500.00
42783A	2017-07-13 07:08:00+03	44600.00
427843	2017-07-26 02:22:00+03	24000.00
427880	2017-07-29 01:30:00+03	69500.00
4278C5	2017-07-09 01:39:00+03	22600.00
4278F5	2017-07-25 06:22:00+03	69600.00
4279A0	2017-08-07 18:01:00+03	12600.00
4279B2	2017-08-14 22:46:00+03	201800.00
4279E3	2017-08-08 03:40:00+03	26000.00
427A19	2017-07-04 14:09:00+03	23600.00
427AF9	2017-06-29 10:15:00+03	61800.00
427B07	2017-07-20 10:16:00+03	42600.00
427B19	2017-08-08 18:42:00+03	152500.00
427B5E	2017-08-05 09:29:00+03	249000.00
427B9C	2017-08-12 23:42:00+03	24700.00
427BA6	2017-07-04 03:49:00+03	55800.00
427BF6	2017-08-06 00:53:00+03	49100.00
427C61	2017-07-19 19:52:00+03	16400.00
427C8C	2017-07-02 07:15:00+03	56200.00
427CFD	2017-08-01 17:06:00+03	132800.00
427DAA	2017-07-27 21:15:00+03	24800.00
427DB1	2017-08-11 09:59:00+03	52400.00
427DE7	2017-06-29 01:07:00+03	29600.00
427E05	2017-07-14 06:38:00+03	20400.00
427E50	2017-07-16 02:43:00+03	29600.00
427E9E	2017-07-11 00:48:00+03	86300.00
427EE7	2017-08-02 06:58:00+03	47200.00
427EEE	2017-07-10 15:04:00+03	196000.00
427F05	2017-07-08 17:00:00+03	28000.00
427F4F	2017-08-03 11:31:00+03	23200.00
427F64	2017-07-24 14:26:00+03	167900.00
427F8B	2017-07-16 00:27:00+03	14000.00
427FB7	2017-07-03 19:08:00+03	42900.00
428011	2017-08-03 14:43:00+03	58800.00
42808E	2017-08-14 20:41:00+03	106900.00
4280E2	2017-07-27 03:59:00+03	12400.00
428124	2017-08-13 03:36:00+03	53800.00
428134	2017-07-30 03:32:00+03	24700.00
42819F	2017-07-06 14:24:00+03	30200.00
4281BF	2017-07-31 04:17:00+03	29600.00
4281FB	2017-07-27 17:03:00+03	31100.00
428234	2017-07-27 10:20:00+03	56900.00
428289	2017-07-30 15:43:00+03	28000.00
4282C6	2017-07-12 14:19:00+03	20000.00
42831E	2017-08-08 10:17:00+03	47200.00
428327	2017-07-01 13:25:00+03	35700.00
428340	2017-07-03 16:20:00+03	22000.00
4283C3	2017-07-29 23:30:00+03	55800.00
4283EB	2017-07-24 23:39:00+03	61800.00
428411	2017-07-20 21:10:00+03	77200.00
428414	2017-08-14 07:26:00+03	112600.00
428424	2017-07-11 00:32:00+03	70800.00
428462	2017-08-08 03:21:00+03	93900.00
42846B	2017-08-07 12:51:00+03	6300.00
428485	2017-07-06 23:35:00+03	102600.00
4284D4	2017-07-15 04:47:00+03	179300.00
4284FF	2017-07-31 03:01:00+03	31600.00
42850E	2017-08-07 02:06:00+03	135400.00
428534	2017-08-13 14:44:00+03	94200.00
428569	2017-07-19 13:03:00+03	293700.00
4285EC	2017-07-30 08:32:00+03	29600.00
4285F0	2017-08-12 19:12:00+03	55800.00
42860E	2017-08-12 02:46:00+03	50600.00
42867A	2017-07-02 19:57:00+03	15000.00
428714	2017-07-08 08:04:00+03	95000.00
428800	2017-07-31 21:04:00+03	87000.00
428815	2017-07-16 00:55:00+03	25400.00
428857	2017-07-06 15:50:00+03	56000.00
42885E	2017-07-06 07:19:00+03	78200.00
428875	2017-07-09 06:47:00+03	620800.00
4288E0	2017-07-03 12:24:00+03	189800.00
4288E5	2017-07-28 17:13:00+03	358400.00
4288FE	2017-08-15 06:19:00+03	65000.00
42891C	2017-07-01 19:04:00+03	90100.00
428983	2017-07-09 22:09:00+03	105600.00
42898F	2017-07-20 17:39:00+03	136500.00
4289E0	2017-08-14 18:06:00+03	31800.00
4289F7	2017-07-14 10:53:00+03	28000.00
428A13	2017-06-30 20:57:00+03	124200.00
428AA1	2017-07-05 20:11:00+03	54200.00
428AAB	2017-07-23 05:08:00+03	234300.00
428B37	2017-07-07 13:45:00+03	136800.00
428B94	2017-08-08 16:55:00+03	81500.00
428BF5	2017-07-06 16:40:00+03	14000.00
428C54	2017-07-24 07:09:00+03	24000.00
428CB8	2017-07-12 19:57:00+03	23200.00
428CDD	2017-07-21 20:10:00+03	24000.00
428D66	2017-07-10 11:09:00+03	254900.00
428DAB	2017-07-03 11:25:00+03	62700.00
428E7F	2017-08-12 22:53:00+03	13200.00
428EAC	2017-07-30 23:12:00+03	55800.00
428EBD	2017-07-10 10:01:00+03	23900.00
428ECE	2017-07-14 18:47:00+03	37100.00
428EF1	2017-07-06 19:31:00+03	55800.00
428F03	2017-06-30 22:55:00+03	54500.00
428F73	2017-07-03 20:40:00+03	31000.00
428FFA	2017-07-24 05:01:00+03	23500.00
429000	2017-07-26 05:07:00+03	25600.00
429007	2017-07-27 03:58:00+03	26800.00
429009	2017-07-18 20:03:00+03	124300.00
42909F	2017-06-28 02:14:00+03	89000.00
42917A	2017-07-14 00:44:00+03	70500.00
4291BF	2017-07-24 18:56:00+03	12600.00
4291FE	2017-07-11 06:34:00+03	20400.00
429218	2017-07-26 13:16:00+03	24400.00
42921B	2017-07-22 12:22:00+03	66600.00
429248	2017-08-07 03:01:00+03	30400.00
429249	2017-08-14 12:22:00+03	22100.00
42925C	2017-07-31 02:39:00+03	53600.00
4292AE	2017-07-07 21:55:00+03	23600.00
429340	2017-08-11 22:56:00+03	81700.00
4293FD	2017-08-01 22:59:00+03	29600.00
42943C	2017-06-28 23:52:00+03	33200.00
42947D	2017-07-05 15:00:00+03	62500.00
4294BB	2017-08-07 19:28:00+03	42400.00
4294CD	2017-07-06 01:30:00+03	94700.00
429562	2017-07-25 13:04:00+03	35200.00
429584	2017-08-10 22:17:00+03	169900.00
4295B6	2017-07-30 01:04:00+03	37900.00
42962B	2017-07-14 18:24:00+03	59800.00
42967A	2017-08-01 01:18:00+03	99200.00
4296E7	2017-07-17 05:27:00+03	56000.00
429706	2017-07-14 00:24:00+03	25600.00
429733	2017-07-05 18:33:00+03	62600.00
429770	2017-07-28 21:21:00+03	24800.00
4297EC	2017-08-03 08:25:00+03	8000.00
4297FD	2017-07-25 01:27:00+03	51200.00
429811	2017-07-11 05:27:00+03	11000.00
429825	2017-08-06 09:14:00+03	39100.00
429849	2017-07-11 23:10:00+03	70400.00
42985F	2017-08-11 19:00:00+03	66000.00
4298A5	2017-08-12 12:39:00+03	6000.00
4298E4	2017-07-10 07:16:00+03	92800.00
4299D9	2017-08-03 06:47:00+03	79200.00
4299FD	2017-07-12 12:13:00+03	101200.00
429A5B	2017-07-28 12:19:00+03	26000.00
429A8A	2017-07-30 16:44:00+03	27800.00
429A8B	2017-08-02 18:20:00+03	117900.00
429B95	2017-06-28 08:19:00+03	6700.00
429BC6	2017-08-13 21:51:00+03	124100.00
429C25	2017-07-17 08:19:00+03	14800.00
429C29	2017-07-07 15:04:00+03	57300.00
429C98	2017-07-22 01:41:00+03	369000.00
429D9D	2017-08-03 13:28:00+03	72300.00
429DA2	2017-07-24 12:09:00+03	26000.00
429DA8	2017-08-04 12:57:00+03	59000.00
429DF1	2017-07-02 10:33:00+03	15400.00
429DFA	2017-07-10 07:28:00+03	13400.00
429E2C	2017-07-14 02:46:00+03	31400.00
429E83	2017-07-10 21:24:00+03	26800.00
429E9B	2017-07-28 04:37:00+03	135000.00
429EA2	2017-07-22 23:37:00+03	66600.00
429ECA	2017-08-13 03:44:00+03	412400.00
429EE4	2017-07-17 10:50:00+03	39500.00
429F14	2017-08-07 08:00:00+03	188000.00
429F79	2017-07-26 08:52:00+03	12100.00
429F8C	2017-08-03 16:12:00+03	58900.00
429F8E	2017-08-14 18:50:00+03	65500.00
429FA2	2017-07-18 21:07:00+03	27200.00
429FBE	2017-07-01 13:07:00+03	70800.00
42A048	2017-08-03 12:55:00+03	57700.00
42A057	2017-07-05 16:17:00+03	92400.00
42A065	2017-07-31 10:27:00+03	53900.00
42A110	2017-07-22 20:23:00+03	119600.00
42A11A	2017-07-02 20:41:00+03	89100.00
42A159	2017-07-07 16:30:00+03	27200.00
42A18F	2017-07-01 06:38:00+03	73000.00
42A1E3	2017-07-19 21:59:00+03	62800.00
42A1F8	2017-07-06 12:57:00+03	55800.00
42A22B	2017-07-26 00:47:00+03	13000.00
42A263	2017-07-22 03:10:00+03	28800.00
42A266	2017-06-29 09:27:00+03	18000.00
42A283	2017-07-29 11:31:00+03	92900.00
42A2A5	2017-07-31 06:26:00+03	56000.00
42A2A7	2017-07-25 09:28:00+03	74400.00
42A2AC	2017-08-15 06:39:00+03	26000.00
42A315	2017-07-07 00:41:00+03	102200.00
42A31B	2017-07-04 10:04:00+03	18800.00
42A390	2017-08-10 21:56:00+03	21400.00
42A391	2017-08-09 01:38:00+03	45200.00
42A484	2017-07-02 05:34:00+03	23600.00
42A49B	2017-08-09 14:57:00+03	30000.00
42A4A0	2017-07-08 15:27:00+03	77200.00
42A4DA	2017-08-04 14:40:00+03	26400.00
42A532	2017-07-30 08:24:00+03	56000.00
42A53C	2017-08-11 21:30:00+03	55800.00
42A541	2017-07-30 06:54:00+03	6700.00
42A55F	2017-07-07 17:07:00+03	6000.00
42A567	2017-07-28 12:39:00+03	66400.00
42A5CF	2017-07-17 09:48:00+03	55800.00
42A607	2017-07-25 17:02:00+03	6000.00
42A61C	2017-07-11 15:53:00+03	26500.00
42A639	2017-07-18 10:48:00+03	273600.00
42A63C	2017-07-20 22:13:00+03	68400.00
42A652	2017-08-14 10:59:00+03	135400.00
42A6C1	2017-08-03 11:24:00+03	52300.00
42A6E5	2017-08-01 20:03:00+03	139500.00
42A6F5	2017-08-09 13:15:00+03	135300.00
42A713	2017-07-07 04:10:00+03	73500.00
42A799	2017-07-19 14:24:00+03	16800.00
42A7A0	2017-08-12 11:28:00+03	179300.00
42A7B0	2017-07-20 23:15:00+03	67600.00
42A7D8	2017-08-09 00:26:00+03	21800.00
42A828	2017-07-04 12:03:00+03	87100.00
42A836	2017-08-10 08:04:00+03	13400.00
42A915	2017-07-04 12:28:00+03	6000.00
42A943	2017-07-13 10:16:00+03	61800.00
42A9AF	2017-08-14 21:04:00+03	189200.00
42A9F6	2017-06-30 14:17:00+03	528600.00
42AA01	2017-08-15 15:11:00+03	46500.00
42AA54	2017-08-04 02:02:00+03	26000.00
42AA6E	2017-07-02 18:48:00+03	47500.00
42AA82	2017-07-19 11:20:00+03	89200.00
42AAAF	2017-07-28 10:56:00+03	43200.00
42AABB	2017-07-21 00:07:00+03	108200.00
42AB12	2017-08-10 03:19:00+03	112600.00
42AB43	2017-08-05 02:48:00+03	65900.00
42AB54	2017-08-02 02:44:00+03	67600.00
42AB7F	2017-07-19 23:30:00+03	48800.00
42ABDC	2017-08-01 15:26:00+03	134700.00
42ABDF	2017-08-13 04:01:00+03	266400.00
42AC1D	2017-08-02 14:09:00+03	64400.00
42AC9F	2017-08-03 09:21:00+03	56000.00
42ACC1	2017-07-31 09:38:00+03	108600.00
42AD10	2017-07-06 17:06:00+03	59800.00
42AD1E	2017-07-20 23:58:00+03	133200.00
42AD3C	2017-06-28 23:04:00+03	155600.00
42AD9A	2017-07-11 04:01:00+03	24400.00
42AD9B	2017-08-10 17:02:00+03	26600.00
42ADC6	2017-08-05 11:56:00+03	75300.00
42ADD5	2017-08-14 13:15:00+03	26000.00
42AE59	2017-07-06 04:41:00+03	92000.00
42AE81	2017-07-24 03:14:00+03	46700.00
42AF43	2017-07-17 19:47:00+03	31000.00
42AF6C	2017-08-11 02:02:00+03	270000.00
42AFF1	2017-07-24 04:34:00+03	44000.00
42AFF6	2017-08-13 09:20:00+03	74000.00
42B032	2017-07-21 19:58:00+03	7200.00
42B0A6	2017-08-12 20:57:00+03	87200.00
42B110	2017-07-08 15:25:00+03	25800.00
42B181	2017-07-18 16:12:00+03	72200.00
42B1EF	2017-07-28 14:02:00+03	43600.00
42B1F7	2017-08-08 21:33:00+03	281500.00
42B200	2017-07-05 08:55:00+03	23400.00
42B248	2017-07-27 19:41:00+03	23200.00
42B264	2017-07-06 14:03:00+03	27200.00
42B274	2017-07-25 10:07:00+03	44400.00
42B275	2017-07-11 13:57:00+03	38800.00
42B2FA	2017-07-17 12:41:00+03	79700.00
42B301	2017-08-10 09:24:00+03	260700.00
42B340	2017-07-09 23:15:00+03	56000.00
42B3C0	2017-07-19 02:53:00+03	143100.00
42B3EB	2017-07-18 02:33:00+03	56000.00
42B404	2017-07-27 17:17:00+03	25800.00
42B46B	2017-07-10 17:41:00+03	103700.00
42B499	2017-07-03 04:35:00+03	46000.00
42B4A8	2017-07-11 17:32:00+03	75300.00
42B536	2017-07-07 16:57:00+03	339900.00
42B55E	2017-08-10 14:16:00+03	396500.00
42B5D5	2017-07-25 14:40:00+03	97900.00
42B64E	2017-07-24 03:52:00+03	131100.00
42B65C	2017-08-06 19:31:00+03	7400.00
42B68F	2017-07-06 02:49:00+03	56000.00
42B6B4	2017-07-17 07:29:00+03	103500.00
42B6E6	2017-07-17 22:17:00+03	146600.00
42B726	2017-07-15 12:51:00+03	14700.00
42B73B	2017-08-14 22:07:00+03	43300.00
42B741	2017-07-25 11:29:00+03	369000.00
42B74E	2017-07-21 14:30:00+03	17800.00
42B7F1	2017-08-07 02:38:00+03	44800.00
42B806	2017-06-29 02:43:00+03	50600.00
42B80E	2017-07-12 00:25:00+03	38800.00
42B83B	2017-07-03 23:50:00+03	532800.00
42B845	2017-08-09 17:35:00+03	23200.00
42B874	2017-07-04 10:52:00+03	57600.00
42B8F6	2017-07-04 10:31:00+03	22000.00
42B948	2017-07-06 22:41:00+03	52000.00
42B962	2017-08-15 16:16:00+03	55800.00
42B9B2	2017-07-17 13:05:00+03	65900.00
42B9BF	2017-07-22 23:37:00+03	48700.00
42B9D7	2017-07-26 01:30:00+03	31600.00
42B9E8	2017-07-11 20:44:00+03	189800.00
42BA06	2017-07-03 01:35:00+03	47000.00
42BA2B	2017-08-06 16:46:00+03	13400.00
42BA47	2017-08-13 04:44:00+03	26000.00
42BACD	2017-07-09 06:41:00+03	6800.00
42BAD4	2017-08-15 00:06:00+03	55800.00
42BB3B	2017-08-15 06:18:00+03	101900.00
42BB53	2017-07-23 12:01:00+03	135600.00
42BB60	2017-08-05 11:52:00+03	148300.00
42BBB2	2017-08-05 01:19:00+03	97900.00
42BBB3	2017-07-17 19:48:00+03	62000.00
42BBC7	2017-07-05 23:07:00+03	84100.00
42BBED	2017-08-10 12:49:00+03	28300.00
42BBF0	2017-07-25 18:25:00+03	43400.00
42BC21	2017-07-18 20:59:00+03	246000.00
42BC2B	2017-07-28 00:24:00+03	44600.00
42BC65	2017-08-11 13:38:00+03	75500.00
42BC7B	2017-08-04 06:56:00+03	42400.00
42BC7F	2017-07-28 08:19:00+03	37900.00
42BC82	2017-07-08 21:38:00+03	195600.00
42BCDA	2017-08-04 09:30:00+03	12400.00
42BD03	2017-07-02 20:46:00+03	152500.00
42BD33	2017-08-10 03:52:00+03	55800.00
42BD62	2017-08-13 11:51:00+03	135400.00
42BE12	2017-07-01 01:33:00+03	34000.00
42BE20	2017-06-30 14:00:00+03	27800.00
42BE3D	2017-07-11 19:07:00+03	74000.00
42BE7E	2017-07-14 07:37:00+03	36400.00
42BE87	2017-07-30 10:32:00+03	129400.00
42BE8B	2017-07-02 03:22:00+03	81600.00
42BF04	2017-07-26 01:58:00+03	14800.00
42BF90	2017-08-13 13:18:00+03	49700.00
42C006	2017-07-05 05:28:00+03	47400.00
42C08F	2017-07-05 02:55:00+03	56000.00
42C096	2017-07-26 04:58:00+03	27700.00
42C0A2	2017-07-23 13:24:00+03	266400.00
42C0F6	2017-07-29 17:04:00+03	110500.00
42C111	2017-08-01 12:59:00+03	66600.00
42C128	2017-08-10 14:10:00+03	36200.00
42C175	2017-08-04 05:28:00+03	15000.00
42C1B4	2017-08-15 13:44:00+03	162400.00
42C1C7	2017-08-09 00:51:00+03	170800.00
42C1E5	2017-07-11 02:07:00+03	38400.00
42C1EF	2017-07-31 05:25:00+03	14400.00
42C21D	2017-07-10 00:44:00+03	58400.00
42C222	2017-07-08 08:12:00+03	12600.00
42C264	2017-07-16 01:49:00+03	139700.00
42C281	2017-07-23 21:21:00+03	56000.00
42C2B9	2017-06-30 00:49:00+03	48100.00
42C2F8	2017-08-13 02:01:00+03	174400.00
42C346	2017-07-18 02:45:00+03	23200.00
42C3AB	2017-08-10 03:19:00+03	112000.00
42C3E5	2017-06-29 15:39:00+03	56600.00
42C434	2017-08-07 13:29:00+03	155600.00
42C436	2017-07-26 00:00:00+03	260900.00
42C438	2017-07-05 01:16:00+03	179300.00
42C493	2017-07-28 09:43:00+03	177200.00
42C4BF	2017-07-25 08:45:00+03	32700.00
42C4FC	2017-07-23 12:56:00+03	56000.00
42C4FF	2017-07-11 08:38:00+03	13200.00
42C50C	2017-07-26 06:52:00+03	20000.00
42C553	2017-08-02 12:13:00+03	270700.00
42C5DC	2017-08-07 18:03:00+03	22900.00
42C5FE	2017-07-05 23:01:00+03	28800.00
42C626	2017-07-01 11:48:00+03	54800.00
42C708	2017-07-21 06:47:00+03	318200.00
42C715	2017-08-10 16:58:00+03	12600.00
42C770	2017-07-04 02:33:00+03	24400.00
42C78C	2017-08-07 23:52:00+03	298500.00
42C7BE	2017-07-30 10:40:00+03	61800.00
42C7C3	2017-07-29 06:31:00+03	51600.00
42C83B	2017-07-06 03:54:00+03	276200.00
42C882	2017-07-12 02:41:00+03	280600.00
42C895	2017-08-14 18:43:00+03	13400.00
42C90B	2017-07-13 04:59:00+03	303100.00
42C90D	2017-07-20 02:14:00+03	56900.00
42C914	2017-08-08 17:34:00+03	28000.00
42C920	2017-08-07 01:21:00+03	62200.00
42C984	2017-07-24 04:20:00+03	67200.00
42C992	2017-07-26 21:50:00+03	212200.00
42C9F7	2017-08-03 09:54:00+03	13200.00
42CA3B	2017-08-03 14:12:00+03	18000.00
42CAEA	2017-07-16 09:54:00+03	67200.00
42CB2E	2017-08-13 07:06:00+03	72200.00
42CB41	2017-07-19 05:10:00+03	38600.00
42CB8E	2017-07-25 16:17:00+03	111600.00
42CC16	2017-07-06 18:32:00+03	68000.00
42CC2F	2017-08-13 08:02:00+03	87000.00
42CC5A	2017-07-19 09:15:00+03	265700.00
42CCCF	2017-07-03 21:39:00+03	56100.00
42CD32	2017-07-02 22:37:00+03	57800.00
42CD71	2017-07-15 20:45:00+03	6800.00
42CD7C	2017-08-05 06:03:00+03	37900.00
42CE59	2017-07-16 04:55:00+03	266300.00
42CED5	2017-07-23 14:49:00+03	56200.00
42CF35	2017-08-06 08:19:00+03	57600.00
42CF98	2017-07-25 23:37:00+03	63300.00
42CFF6	2017-07-10 20:34:00+03	64800.00
42CFFD	2017-07-09 03:23:00+03	13300.00
42D005	2017-07-26 10:22:00+03	37700.00
42D013	2017-07-10 09:13:00+03	6000.00
42D04D	2017-07-19 08:36:00+03	44000.00
42D0AD	2017-07-18 20:22:00+03	19600.00
42D143	2017-07-10 22:50:00+03	101600.00
42D164	2017-08-11 11:45:00+03	93900.00
42D2CE	2017-07-04 02:48:00+03	50300.00
42D309	2017-08-03 14:22:00+03	117600.00
42D336	2017-08-02 18:52:00+03	33600.00
42D34F	2017-07-18 05:38:00+03	40800.00
42D376	2017-07-04 05:37:00+03	20600.00
42D38A	2017-08-07 19:02:00+03	84500.00
42D3A7	2017-07-22 00:33:00+03	55800.00
42D451	2017-07-27 12:57:00+03	60400.00
42D4C3	2017-07-25 22:37:00+03	258400.00
42D57B	2017-07-12 09:37:00+03	46300.00
42D605	2017-08-10 09:18:00+03	73100.00
42D60F	2017-08-03 17:16:00+03	71200.00
42D689	2017-07-31 13:35:00+03	64200.00
42D6C9	2017-07-24 22:40:00+03	111700.00
42D7D5	2017-07-18 01:19:00+03	28800.00
42D7EE	2017-08-11 01:55:00+03	94000.00
42D868	2017-08-10 16:15:00+03	133200.00
42D900	2017-08-11 06:55:00+03	133200.00
42D906	2017-08-11 14:19:00+03	105600.00
42D95E	2017-08-01 12:10:00+03	133200.00
42D986	2017-07-18 00:43:00+03	3400.00
42DA3E	2017-07-14 17:10:00+03	84200.00
42DA67	2017-08-01 19:29:00+03	51300.00
42DA79	2017-06-24 22:42:00+03	31000.00
42DAB3	2017-07-31 10:26:00+03	45000.00
42DAF2	2017-08-03 07:01:00+03	23200.00
42DB15	2017-08-09 10:21:00+03	49600.00
42DBCB	2017-08-12 02:06:00+03	60000.00
42DBD1	2017-07-28 06:51:00+03	73600.00
42DC06	2017-07-12 07:14:00+03	23900.00
42DC0C	2017-07-06 04:05:00+03	191400.00
42DC27	2017-07-22 02:40:00+03	185600.00
42DCB1	2017-08-07 21:54:00+03	16400.00
42DD24	2017-08-09 18:53:00+03	6000.00
42DD92	2017-08-11 08:46:00+03	28800.00
42DDC5	2017-08-14 16:40:00+03	96800.00
42DDEA	2017-08-12 16:40:00+03	56000.00
42DE6D	2017-08-03 21:24:00+03	95200.00
42DEA0	2017-07-12 15:27:00+03	13400.00
42DFF8	2017-07-26 19:41:00+03	54400.00
42E008	2017-07-20 22:33:00+03	102100.00
42E075	2017-08-12 01:41:00+03	531400.00
42E0A2	2017-07-10 11:58:00+03	46400.00
42E0B4	2017-08-09 21:30:00+03	246000.00
42E0DF	2017-07-27 01:42:00+03	6300.00
42E0EC	2017-08-02 13:14:00+03	101900.00
42E16A	2017-08-02 20:36:00+03	54800.00
42E210	2017-08-14 18:01:00+03	61500.00
42E247	2017-07-27 07:32:00+03	65400.00
42E30E	2017-07-08 18:47:00+03	26000.00
42E360	2017-07-01 03:22:00+03	75300.00
42E36F	2017-08-07 02:51:00+03	44600.00
42E3A4	2017-08-11 08:04:00+03	16400.00
42E3A7	2017-08-09 04:29:00+03	22000.00
42E3ED	2017-07-08 23:50:00+03	37900.00
42E45A	2017-07-22 01:26:00+03	128400.00
42E462	2017-07-30 01:40:00+03	70700.00
42E53A	2017-07-16 19:21:00+03	42800.00
42E562	2017-08-11 21:56:00+03	29400.00
42E56F	2017-07-15 16:50:00+03	28800.00
42E5C2	2017-07-28 11:51:00+03	39000.00
42E66A	2017-07-31 01:52:00+03	54000.00
42E6A2	2017-08-13 03:23:00+03	101200.00
42E6B3	2017-07-23 10:20:00+03	43200.00
42E6CD	2017-08-08 18:58:00+03	53600.00
42E6CE	2017-08-02 08:29:00+03	88000.00
42E6F8	2017-08-02 21:40:00+03	91300.00
42E746	2017-07-19 21:59:00+03	16400.00
42E806	2017-08-11 15:13:00+03	393800.00
42E841	2017-07-15 00:25:00+03	27200.00
42E8AB	2017-07-25 02:49:00+03	193200.00
42E8F4	2017-07-06 23:52:00+03	170000.00
42E91A	2017-07-27 08:54:00+03	27400.00
42E92F	2017-08-05 09:35:00+03	84000.00
42E94B	2017-07-03 15:19:00+03	23500.00
42EA2A	2017-07-26 09:58:00+03	28000.00
42EABA	2017-08-11 04:29:00+03	69400.00
42EAC0	2017-07-03 16:52:00+03	381400.00
42EB56	2017-08-14 20:48:00+03	67400.00
42EB65	2017-07-11 11:27:00+03	19600.00
42EBAF	2017-07-21 19:43:00+03	17000.00
42EBE0	2017-08-07 17:38:00+03	187200.00
42EBF0	2017-07-21 16:49:00+03	156700.00
42EC03	2017-07-20 14:04:00+03	111600.00
42EC2A	2017-07-05 11:42:00+03	24800.00
42EC34	2017-07-19 09:51:00+03	67200.00
42EC86	2017-07-29 17:31:00+03	42800.00
42ECA2	2017-06-27 23:50:00+03	64500.00
42ECFA	2017-08-08 19:01:00+03	70700.00
42EDA1	2017-08-14 06:06:00+03	139300.00
42EDA9	2017-07-24 21:01:00+03	54100.00
42EEC8	2017-07-13 10:10:00+03	37700.00
42EF1C	2017-07-29 07:20:00+03	24400.00
42EF22	2017-07-21 04:22:00+03	56000.00
42EFCF	2017-07-24 09:11:00+03	62800.00
42F024	2017-08-02 08:15:00+03	241400.00
42F090	2017-08-03 05:13:00+03	38800.00
42F0B0	2017-08-12 07:03:00+03	56000.00
42F0EA	2017-08-12 22:11:00+03	47400.00
42F1A0	2017-08-04 12:20:00+03	38600.00
42F1FD	2017-07-29 15:24:00+03	40300.00
42F28D	2017-07-02 07:20:00+03	41200.00
42F290	2017-07-16 12:59:00+03	62100.00
42F2B0	2017-08-13 19:23:00+03	81300.00
42F394	2017-08-12 22:24:00+03	58400.00
42F3BC	2017-07-20 21:34:00+03	202400.00
42F3F4	2017-07-07 13:15:00+03	48800.00
42F432	2017-08-09 18:49:00+03	21800.00
42F473	2017-07-18 03:04:00+03	112000.00
42F4AB	2017-08-04 15:26:00+03	14400.00
42F4B4	2017-07-30 05:05:00+03	27200.00
42F4F5	2017-07-30 10:17:00+03	34100.00
42F4FA	2017-07-26 14:24:00+03	16400.00
42F4FC	2017-08-02 09:38:00+03	138700.00
42F537	2017-08-04 16:22:00+03	27700.00
42F58F	2017-07-08 20:33:00+03	36200.00
42F5CF	2017-07-04 01:05:00+03	40400.00
42F5F7	2017-07-08 21:45:00+03	14300.00
42F6E7	2017-07-17 08:45:00+03	109600.00
42F706	2017-08-08 21:54:00+03	56600.00
42F75F	2017-08-05 23:41:00+03	182300.00
42F7E4	2017-07-18 16:51:00+03	101200.00
42F851	2017-08-01 19:10:00+03	24400.00
42F891	2017-08-06 19:11:00+03	12400.00
42F8F4	2017-07-01 22:39:00+03	21800.00
42F925	2017-07-16 15:16:00+03	35200.00
42F956	2017-07-30 09:33:00+03	369000.00
42F97B	2017-07-14 18:29:00+03	38600.00
42F993	2017-07-22 18:02:00+03	124200.00
42F9E6	2017-06-28 03:01:00+03	44800.00
42FA07	2017-08-10 19:31:00+03	99200.00
42FA09	2017-07-25 20:11:00+03	50000.00
42FA3D	2017-07-23 01:27:00+03	80000.00
42FA4E	2017-07-28 21:51:00+03	47500.00
42FAA6	2017-07-30 06:50:00+03	132000.00
42FAB7	2017-07-30 03:57:00+03	46000.00
42FABB	2017-08-13 20:05:00+03	44000.00
42FB42	2017-07-29 23:24:00+03	20400.00
42FB5A	2017-06-30 08:34:00+03	136600.00
42FB94	2017-07-10 21:11:00+03	43100.00
42FBC6	2017-07-29 22:07:00+03	29800.00
42FBEC	2017-07-01 09:46:00+03	162700.00
42FCA5	2017-07-23 02:32:00+03	43600.00
42FCB9	2017-07-15 15:48:00+03	59800.00
42FCC0	2017-07-04 03:39:00+03	38000.00
42FD5B	2017-08-01 08:39:00+03	30200.00
42FDD6	2017-07-30 06:47:00+03	60400.00
42FDD7	2017-08-13 15:17:00+03	279000.00
42FEF2	2017-08-12 11:59:00+03	60400.00
42FF11	2017-08-06 19:52:00+03	339800.00
42FF42	2017-07-17 19:45:00+03	166200.00
42FF77	2017-07-14 11:46:00+03	96200.00
42FFAD	2017-08-14 11:03:00+03	396200.00
43000F	2017-07-29 23:34:00+03	248400.00
43005D	2017-08-02 17:41:00+03	56000.00
430065	2017-07-27 18:21:00+03	23200.00
43007C	2017-07-09 15:53:00+03	12600.00
43008B	2017-07-03 21:33:00+03	75300.00
4300DD	2017-07-27 14:03:00+03	66600.00
43017F	2017-08-05 09:27:00+03	97700.00
430192	2017-07-20 02:04:00+03	139800.00
430193	2017-07-27 17:22:00+03	21800.00
4301B9	2017-07-03 21:26:00+03	46400.00
43027D	2017-08-01 23:08:00+03	6000.00
43029F	2017-07-29 06:50:00+03	54000.00
4302AF	2017-07-12 10:05:00+03	27400.00
4303F6	2017-08-04 01:21:00+03	72400.00
430448	2017-08-12 07:40:00+03	23200.00
4304C1	2017-08-08 06:28:00+03	57600.00
4305B5	2017-08-02 21:44:00+03	62000.00
43061B	2017-08-02 09:42:00+03	6400.00
43063A	2017-08-02 01:30:00+03	92000.00
43067F	2017-07-07 17:02:00+03	398500.00
4306E5	2017-08-11 10:47:00+03	205600.00
4306EE	2017-07-23 22:51:00+03	69500.00
430787	2017-07-27 17:03:00+03	38800.00
43078E	2017-08-12 14:20:00+03	57700.00
4307AC	2017-06-26 08:56:00+03	28000.00
430819	2017-07-29 19:38:00+03	44600.00
43089B	2017-07-03 05:18:00+03	38600.00
4308EB	2017-08-14 16:25:00+03	46400.00
4309E3	2017-07-11 02:32:00+03	500100.00
4309FD	2017-06-30 07:29:00+03	375200.00
430A52	2017-07-23 20:51:00+03	28000.00
430AA5	2017-07-25 14:20:00+03	26000.00
430B0D	2017-07-31 03:59:00+03	86500.00
430B6E	2017-07-30 00:17:00+03	43000.00
430B74	2017-07-09 11:00:00+03	47800.00
430B8A	2017-07-07 23:34:00+03	135400.00
430B9E	2017-08-05 21:59:00+03	515100.00
430BC0	2017-07-13 08:17:00+03	83000.00
430BC9	2017-08-04 09:42:00+03	279200.00
430BF8	2017-07-02 11:07:00+03	58800.00
430CD4	2017-07-30 00:28:00+03	48800.00
430CDA	2017-07-12 02:25:00+03	116800.00
430D17	2017-07-09 10:48:00+03	64700.00
430D23	2017-07-21 09:26:00+03	185800.00
430DCA	2017-08-12 09:18:00+03	52400.00
430DE4	2017-07-10 18:23:00+03	201200.00
430E02	2017-07-13 19:53:00+03	75800.00
430E14	2017-07-08 00:18:00+03	7400.00
430E28	2017-07-16 02:18:00+03	147200.00
430E4C	2017-07-12 03:35:00+03	46300.00
430E51	2017-07-23 20:44:00+03	23200.00
430E80	2017-07-20 22:41:00+03	21800.00
430E9E	2017-07-16 17:33:00+03	52400.00
430E9F	2017-08-03 12:22:00+03	47600.00
430F24	2017-06-27 18:28:00+03	42100.00
430FDC	2017-08-09 12:21:00+03	24400.00
430FE8	2017-06-28 18:58:00+03	206300.00
430FE9	2017-06-27 07:08:00+03	68100.00
43100B	2017-08-12 20:52:00+03	113200.00
431011	2017-07-31 04:52:00+03	283100.00
43101D	2017-08-03 10:10:00+03	92700.00
43105E	2017-08-02 02:28:00+03	6000.00
4310F7	2017-07-31 19:07:00+03	43200.00
43113B	2017-07-13 01:47:00+03	133200.00
43116F	2017-08-02 01:48:00+03	52900.00
4311BB	2017-07-08 03:31:00+03	113200.00
431213	2017-07-08 11:54:00+03	22000.00
431247	2017-07-27 03:40:00+03	6000.00
431252	2017-08-03 22:02:00+03	32800.00
43127B	2017-07-07 04:06:00+03	26000.00
4312DC	2017-07-23 00:21:00+03	55800.00
43130F	2017-07-28 21:09:00+03	92800.00
431333	2017-07-11 02:57:00+03	167500.00
431353	2017-08-08 15:42:00+03	74400.00
431408	2017-07-16 20:16:00+03	23900.00
43141A	2017-08-14 05:04:00+03	209000.00
4314A3	2017-07-27 12:39:00+03	13700.00
4314EB	2017-07-13 01:24:00+03	542300.00
4314F5	2017-07-27 10:31:00+03	24800.00
43156F	2017-07-09 05:04:00+03	23400.00
431593	2017-08-14 10:34:00+03	325500.00
43163E	2017-07-16 16:01:00+03	66600.00
43166A	2017-07-22 04:07:00+03	93900.00
4316B0	2017-08-09 10:06:00+03	29400.00
4316FC	2017-07-09 14:33:00+03	111600.00
431764	2017-07-21 05:31:00+03	185300.00
431848	2017-07-26 19:15:00+03	92000.00
43189D	2017-07-02 17:04:00+03	124200.00
4318FF	2017-08-13 21:06:00+03	46400.00
4319DF	2017-07-18 19:54:00+03	273400.00
4319FE	2017-07-24 01:57:00+03	55700.00
431A39	2017-06-29 14:39:00+03	115900.00
431A5B	2017-07-20 23:41:00+03	40800.00
431AB0	2017-07-10 23:49:00+03	53300.00
431ABC	2017-08-07 14:08:00+03	51800.00
431AFF	2017-08-12 04:48:00+03	56000.00
431B50	2017-07-15 06:54:00+03	51900.00
431B5F	2017-08-08 13:17:00+03	13600.00
431B6F	2017-07-26 18:11:00+03	119400.00
431B75	2017-07-20 00:59:00+03	246000.00
431BDB	2017-07-20 16:49:00+03	6300.00
431CEC	2017-07-05 21:14:00+03	206400.00
431DA7	2017-08-13 13:36:00+03	195700.00
431DF1	2017-07-18 09:51:00+03	29200.00
431E3B	2017-07-23 16:49:00+03	27200.00
431E69	2017-07-24 14:36:00+03	130000.00
431E7A	2017-07-17 22:52:00+03	149300.00
431EA0	2017-07-31 19:10:00+03	26800.00
431EAA	2017-07-20 05:30:00+03	63500.00
431EEA	2017-07-18 10:12:00+03	201800.00
43208D	2017-08-01 17:11:00+03	68800.00
4320B9	2017-08-02 13:04:00+03	46400.00
4320BC	2017-07-14 09:33:00+03	12400.00
4320CD	2017-08-07 16:04:00+03	66600.00
432127	2017-07-01 09:01:00+03	144300.00
432162	2017-07-08 02:21:00+03	101800.00
432193	2017-07-02 16:34:00+03	95200.00
4321C1	2017-07-24 04:26:00+03	38500.00
4321DD	2017-07-22 09:28:00+03	16400.00
43224E	2017-07-08 00:19:00+03	85000.00
4323C8	2017-08-14 04:20:00+03	42600.00
432425	2017-08-01 12:22:00+03	23200.00
432488	2017-07-08 06:25:00+03	81900.00
432529	2017-07-31 04:01:00+03	6900.00
43252B	2017-07-19 07:26:00+03	14400.00
43252D	2017-08-08 03:29:00+03	38400.00
43254D	2017-07-07 09:15:00+03	254900.00
432598	2017-08-04 15:29:00+03	73600.00
43259A	2017-07-23 07:27:00+03	47400.00
4325C5	2017-07-21 01:11:00+03	22000.00
432638	2017-07-14 21:27:00+03	111600.00
432648	2017-07-23 08:18:00+03	10600.00
4326A9	2017-07-27 15:07:00+03	24400.00
432708	2017-07-07 02:47:00+03	6700.00
432718	2017-07-10 09:45:00+03	36000.00
432771	2017-07-21 17:10:00+03	24000.00
4327A9	2017-07-13 14:20:00+03	199600.00
4327AC	2017-08-07 18:58:00+03	61800.00
4327C7	2017-07-10 23:24:00+03	46400.00
43282F	2017-07-21 16:41:00+03	95200.00
432878	2017-08-08 06:38:00+03	22400.00
4328C3	2017-07-05 00:53:00+03	26800.00
43294A	2017-08-01 20:39:00+03	36900.00
4329B4	2017-07-11 15:22:00+03	87700.00
4329F1	2017-07-13 05:30:00+03	52900.00
432A53	2017-08-05 09:43:00+03	27200.00
432A6D	2017-08-06 02:00:00+03	21800.00
432A7D	2017-08-06 11:48:00+03	112000.00
432B19	2017-07-25 00:32:00+03	25000.00
432B48	2017-08-12 13:24:00+03	24400.00
432B81	2017-07-21 17:52:00+03	82900.00
432BEC	2017-08-14 22:20:00+03	35600.00
432C38	2017-07-26 19:06:00+03	94000.00
432C4D	2017-07-14 21:30:00+03	11700.00
432C5A	2017-07-09 18:29:00+03	25400.00
432C8B	2017-08-06 18:18:00+03	158200.00
432CFD	2017-07-04 23:14:00+03	393700.00
432D0A	2017-07-31 15:24:00+03	42600.00
432D16	2017-08-02 20:36:00+03	92000.00
432D3F	2017-07-27 05:46:00+03	23600.00
432D57	2017-07-21 05:06:00+03	50000.00
432D6E	2017-07-07 17:11:00+03	35600.00
432E36	2017-07-13 21:38:00+03	45500.00
432E37	2017-08-08 10:16:00+03	40600.00
432E3F	2017-08-07 17:24:00+03	61500.00
432EB6	2017-07-02 09:30:00+03	40900.00
432F33	2017-08-04 20:47:00+03	152800.00
432F88	2017-07-02 16:29:00+03	9200.00
432FA8	2017-07-13 14:24:00+03	28000.00
432FB1	2017-07-02 14:56:00+03	47000.00
432FC2	2017-07-13 05:16:00+03	70700.00
432FD4	2017-07-07 14:24:00+03	136400.00
43305D	2017-08-04 09:39:00+03	10100.00
43307A	2017-07-03 12:27:00+03	154500.00
4330B1	2017-08-11 22:35:00+03	43200.00
433165	2017-08-03 04:10:00+03	23200.00
433170	2017-08-13 07:39:00+03	234900.00
433197	2017-07-05 11:38:00+03	60200.00
4331AF	2017-07-30 04:51:00+03	16400.00
433239	2017-08-12 22:03:00+03	48800.00
433246	2017-07-02 15:55:00+03	98200.00
4332CD	2017-07-28 09:38:00+03	46900.00
4332D9	2017-07-21 08:47:00+03	8200.00
4332DC	2017-08-07 05:23:00+03	145000.00
4332F8	2017-07-26 02:57:00+03	132800.00
43336D	2017-07-29 13:58:00+03	26000.00
433378	2017-07-18 18:37:00+03	132800.00
433403	2017-08-10 02:22:00+03	6800.00
433445	2017-08-05 18:55:00+03	266400.00
433451	2017-07-15 03:22:00+03	28000.00
433452	2017-07-07 19:53:00+03	57200.00
4334BB	2017-08-05 11:05:00+03	69500.00
4335E4	2017-07-23 14:25:00+03	92800.00
433713	2017-08-15 17:28:00+03	202300.00
433720	2017-07-13 16:45:00+03	14400.00
433776	2017-07-05 09:47:00+03	27400.00
43377F	2017-08-05 21:32:00+03	181400.00
433780	2017-07-08 12:42:00+03	22000.00
4337AA	2017-08-05 04:28:00+03	70600.00
43380F	2017-07-21 05:55:00+03	24400.00
433818	2017-08-04 14:50:00+03	156300.00
433840	2017-07-21 08:23:00+03	22600.00
43384E	2017-07-19 05:33:00+03	76900.00
433855	2017-08-10 19:18:00+03	119600.00
4338C0	2017-07-20 12:17:00+03	133200.00
433989	2017-06-29 13:45:00+03	136800.00
4339B7	2017-08-11 02:21:00+03	413500.00
433A5E	2017-07-06 17:34:00+03	106200.00
433A89	2017-08-14 08:03:00+03	50000.00
433AC2	2017-08-01 01:56:00+03	173100.00
433AD3	2017-08-06 05:25:00+03	28800.00
433B55	2017-08-03 18:25:00+03	37900.00
433BB6	2017-07-25 11:19:00+03	113200.00
433BF6	2017-07-24 04:35:00+03	115900.00
433C33	2017-08-14 06:06:00+03	28400.00
433C3D	2017-07-24 06:01:00+03	92000.00
433CAD	2017-08-02 23:09:00+03	170000.00
433D1F	2017-07-13 14:32:00+03	91600.00
433DBF	2017-08-09 23:26:00+03	56100.00
433DD1	2017-07-29 08:10:00+03	32800.00
433DF3	2017-07-27 11:30:00+03	85000.00
433E2D	2017-08-14 23:48:00+03	50100.00
433E72	2017-07-11 06:10:00+03	29600.00
433EA3	2017-08-08 18:07:00+03	14000.00
433EE7	2017-07-10 02:06:00+03	447400.00
433F60	2017-08-14 23:22:00+03	43900.00
434004	2017-08-15 09:28:00+03	133200.00
434066	2017-07-31 04:34:00+03	372600.00
43408A	2017-07-02 22:01:00+03	26000.00
43408D	2017-07-03 11:58:00+03	81500.00
434091	2017-08-14 10:13:00+03	321500.00
4340C2	2017-07-14 06:55:00+03	65000.00
4340CD	2017-08-03 23:42:00+03	39600.00
4340DC	2017-07-27 07:08:00+03	20200.00
43423A	2017-08-08 13:49:00+03	28800.00
434274	2017-07-28 17:08:00+03	44600.00
4342AB	2017-07-29 20:15:00+03	99900.00
4342B3	2017-07-30 01:29:00+03	266400.00
4342C0	2017-07-02 09:24:00+03	46400.00
43434A	2017-08-04 20:05:00+03	136200.00
434402	2017-08-13 06:07:00+03	28800.00
434504	2017-08-14 21:26:00+03	136200.00
43450A	2017-07-09 20:45:00+03	40400.00
434521	2017-08-01 10:18:00+03	57400.00
434538	2017-08-08 17:51:00+03	135400.00
434580	2017-07-13 05:11:00+03	75300.00
434595	2017-08-09 03:23:00+03	61700.00
4345E1	2017-07-29 14:44:00+03	509700.00
43461D	2017-07-13 01:17:00+03	99200.00
434622	2017-08-06 04:54:00+03	129600.00
434638	2017-08-13 08:37:00+03	135400.00
434677	2017-08-15 05:49:00+03	10800.00
4346AC	2017-08-05 00:06:00+03	8200.00
43479A	2017-08-07 05:45:00+03	28000.00
4347F7	2017-07-19 14:42:00+03	20000.00
434808	2017-07-17 02:09:00+03	139500.00
43483F	2017-08-14 21:40:00+03	78700.00
43489A	2017-07-17 21:37:00+03	99300.00
4348C3	2017-08-01 02:40:00+03	74800.00
4348F1	2017-07-14 06:11:00+03	201200.00
434911	2017-07-07 17:15:00+03	43500.00
4349DD	2017-07-10 12:55:00+03	289800.00
434ADC	2017-07-11 22:01:00+03	75300.00
434AF0	2017-08-05 07:10:00+03	57800.00
434B54	2017-08-15 02:56:00+03	49900.00
434B56	2017-08-01 09:23:00+03	23200.00
434B9C	2017-07-24 10:04:00+03	132800.00
434D22	2017-07-29 11:27:00+03	292500.00
434D39	2017-07-04 08:06:00+03	17000.00
434DDB	2017-07-26 21:34:00+03	7200.00
434E02	2017-07-24 01:42:00+03	6700.00
434E45	2017-07-25 07:08:00+03	48800.00
434E4A	2017-08-01 03:34:00+03	48300.00
434E6A	2017-08-07 13:45:00+03	123600.00
434E72	2017-08-09 10:29:00+03	56000.00
434ED7	2017-08-04 12:10:00+03	30200.00
434EDE	2017-07-10 01:02:00+03	173200.00
434F49	2017-08-12 00:17:00+03	29100.00
434F7C	2017-07-07 02:30:00+03	84700.00
434F85	2017-07-11 01:34:00+03	260200.00
434FC3	2017-08-14 20:11:00+03	124200.00
434FE9	2017-08-11 22:58:00+03	202100.00
43501D	2017-08-08 17:36:00+03	36500.00
435075	2017-07-10 12:55:00+03	44100.00
4350BA	2017-08-02 05:26:00+03	128800.00
435113	2017-07-18 21:02:00+03	52000.00
43511F	2017-08-03 12:29:00+03	57500.00
435141	2017-08-04 13:10:00+03	82900.00
4351BB	2017-08-09 18:10:00+03	24200.00
4351DD	2017-07-10 16:12:00+03	14400.00
435259	2017-08-05 17:40:00+03	87200.00
435264	2017-08-01 14:11:00+03	133200.00
4352C3	2017-08-06 19:20:00+03	136200.00
4352D5	2017-07-07 15:11:00+03	144700.00
4352EF	2017-08-14 01:33:00+03	90000.00
435357	2017-08-14 13:57:00+03	53700.00
435407	2017-07-10 10:57:00+03	8000.00
435409	2017-08-12 08:37:00+03	23200.00
43542E	2017-07-20 22:31:00+03	311100.00
4354AE	2017-08-13 18:32:00+03	20000.00
4354C2	2017-07-09 13:32:00+03	90800.00
4354CF	2017-07-22 15:47:00+03	270700.00
4354F2	2017-07-15 15:39:00+03	75600.00
435542	2017-07-26 05:34:00+03	47100.00
43559B	2017-08-02 00:07:00+03	106100.00
43568B	2017-08-03 15:21:00+03	62000.00
4356B9	2017-08-12 08:08:00+03	45600.00
4356C3	2017-07-14 11:25:00+03	43900.00
4356EB	2017-07-10 03:35:00+03	19600.00
435727	2017-08-06 18:20:00+03	23200.00
435753	2017-08-08 12:19:00+03	23500.00
435783	2017-07-08 09:01:00+03	94000.00
43583A	2017-07-07 20:31:00+03	131600.00
435892	2017-08-10 17:25:00+03	69100.00
435899	2017-07-14 23:39:00+03	23600.00
4358E8	2017-07-27 09:22:00+03	38600.00
4358FD	2017-08-04 09:29:00+03	40000.00
435924	2017-07-31 03:40:00+03	10300.00
43593B	2017-06-29 08:39:00+03	24400.00
43598E	2017-08-10 09:29:00+03	56000.00
435990	2017-07-29 21:10:00+03	52700.00
43599B	2017-07-15 03:03:00+03	25600.00
43599D	2017-07-16 17:48:00+03	28000.00
4359E4	2017-07-18 17:00:00+03	136200.00
4359FA	2017-07-30 14:38:00+03	41200.00
435A0A	2017-08-13 02:35:00+03	139100.00
435A3F	2017-07-09 09:07:00+03	22000.00
435A7C	2017-08-09 23:19:00+03	25400.00
435A98	2017-07-06 00:33:00+03	42800.00
435AD8	2017-08-08 16:36:00+03	26200.00
435AF1	2017-07-20 22:44:00+03	36400.00
435B21	2017-07-09 05:25:00+03	44800.00
435B67	2017-07-16 10:12:00+03	46000.00
435B90	2017-07-23 16:18:00+03	129000.00
435BD1	2017-08-09 00:40:00+03	81300.00
435BD2	2017-07-17 15:31:00+03	42800.00
435BE4	2017-08-07 16:59:00+03	156100.00
435C63	2017-07-16 05:49:00+03	14000.00
435C8C	2017-07-22 14:22:00+03	18600.00
435CFF	2017-07-09 03:35:00+03	40000.00
435D1F	2017-07-01 14:37:00+03	54800.00
435D29	2017-07-04 08:42:00+03	21800.00
435D87	2017-07-14 06:49:00+03	99200.00
435D99	2017-07-08 07:08:00+03	38600.00
435DC6	2017-07-08 04:28:00+03	92800.00
435EAB	2017-08-05 23:12:00+03	47000.00
435EDE	2017-06-27 14:44:00+03	50800.00
435EE2	2017-07-24 20:49:00+03	66600.00
435EE5	2017-07-05 03:34:00+03	17000.00
435FBE	2017-07-12 11:08:00+03	6300.00
436043	2017-06-30 18:08:00+03	67400.00
4360AA	2017-08-11 08:07:00+03	28000.00
4360C6	2017-08-15 04:41:00+03	105000.00
4360C9	2017-08-01 04:29:00+03	44000.00
43616B	2017-07-13 02:34:00+03	71200.00
43619A	2017-08-14 02:16:00+03	68800.00
4361B7	2017-07-11 06:05:00+03	113700.00
4361D1	2017-08-01 19:49:00+03	43200.00
4361D3	2017-07-14 20:05:00+03	34000.00
4361E6	2017-07-20 01:31:00+03	61600.00
436205	2017-08-07 02:44:00+03	58800.00
436222	2017-07-12 15:33:00+03	123000.00
43624F	2017-07-01 12:52:00+03	69700.00
436282	2017-07-11 01:10:00+03	311200.00
43630E	2017-08-02 19:30:00+03	26700.00
43633F	2017-08-13 07:11:00+03	99200.00
436341	2017-07-26 09:34:00+03	27400.00
436350	2017-07-03 12:53:00+03	46400.00
43635D	2017-08-14 04:50:00+03	66600.00
43636C	2017-07-18 05:19:00+03	104000.00
4363CA	2017-08-12 07:50:00+03	138000.00
436424	2017-08-09 05:09:00+03	105100.00
436437	2017-07-08 06:54:00+03	14800.00
436476	2017-07-07 13:31:00+03	58800.00
43647C	2017-08-06 21:16:00+03	29600.00
43648E	2017-07-23 13:46:00+03	384900.00
4364CF	2017-07-15 11:17:00+03	28000.00
4364D3	2017-08-02 16:15:00+03	56600.00
4364F4	2017-06-26 09:05:00+03	73100.00
436515	2017-07-10 21:13:00+03	130400.00
43651F	2017-07-22 15:55:00+03	260900.00
436566	2017-07-13 14:48:00+03	28000.00
4365B1	2017-07-25 05:52:00+03	20500.00
4365C9	2017-07-17 12:31:00+03	266100.00
4365E1	2017-07-14 16:09:00+03	6300.00
436665	2017-07-23 10:32:00+03	99200.00
436717	2017-07-09 15:58:00+03	83600.00
4367BC	2017-06-29 06:13:00+03	43100.00
4367F0	2017-08-13 06:37:00+03	49500.00
436818	2017-07-14 22:19:00+03	119700.00
4368AA	2017-06-29 18:01:00+03	95600.00
436900	2017-07-19 01:23:00+03	85400.00
436918	2017-07-17 02:23:00+03	111600.00
436943	2017-07-04 16:55:00+03	58600.00
43694C	2017-07-05 19:37:00+03	248500.00
43698B	2017-07-20 10:02:00+03	38400.00
4369FB	2017-07-31 21:39:00+03	24800.00
436A0F	2017-07-28 20:08:00+03	90000.00
436A34	2017-07-22 00:20:00+03	202600.00
436AD4	2017-08-06 13:54:00+03	11700.00
436B06	2017-08-15 11:16:00+03	18000.00
436B86	2017-07-25 07:49:00+03	198400.00
436BF8	2017-07-16 06:56:00+03	91900.00
436C26	2017-07-19 10:58:00+03	266400.00
436C72	2017-07-13 06:28:00+03	26800.00
436CA4	2017-07-01 14:09:00+03	92800.00
436CBA	2017-07-17 14:34:00+03	31400.00
436D54	2017-08-11 02:46:00+03	59400.00
436D6B	2017-07-06 12:02:00+03	212800.00
436D8A	2017-08-05 20:06:00+03	19600.00
436DBD	2017-07-06 16:19:00+03	78900.00
436E17	2017-08-09 13:52:00+03	266200.00
436E29	2017-08-06 01:33:00+03	93400.00
436E35	2017-07-05 07:33:00+03	58400.00
436E91	2017-07-14 06:18:00+03	66600.00
436F8E	2017-08-03 21:57:00+03	131100.00
437009	2017-07-01 19:09:00+03	50800.00
437030	2017-07-11 07:08:00+03	92900.00
43703D	2017-08-13 11:46:00+03	11600.00
437042	2017-07-14 14:00:00+03	75600.00
437086	2017-07-21 13:39:00+03	43900.00
4370BB	2017-07-17 11:59:00+03	147100.00
4370EA	2017-08-10 19:01:00+03	123000.00
437196	2017-08-09 12:23:00+03	35700.00
437210	2017-07-07 07:22:00+03	88000.00
4372C2	2017-07-15 18:59:00+03	28000.00
4372EB	2017-07-21 08:40:00+03	100600.00
43730F	2017-07-08 04:33:00+03	87800.00
43731A	2017-07-11 15:02:00+03	23600.00
437341	2017-07-24 15:41:00+03	142400.00
437349	2017-07-14 09:34:00+03	187600.00
437395	2017-08-14 02:34:00+03	58400.00
4373EC	2017-07-09 12:59:00+03	46400.00
437425	2017-07-28 16:32:00+03	56100.00
4374EF	2017-08-01 09:27:00+03	46000.00
4375E0	2017-08-03 22:54:00+03	56600.00
43765D	2017-08-05 22:40:00+03	26800.00
437671	2017-08-11 13:20:00+03	54600.00
4376BF	2017-08-03 20:00:00+03	10600.00
4376E3	2017-08-05 17:43:00+03	47400.00
4376E6	2017-07-15 15:15:00+03	123000.00
43773B	2017-08-13 10:49:00+03	39400.00
437744	2017-07-26 10:11:00+03	63500.00
4377DB	2017-07-09 09:30:00+03	27900.00
43780F	2017-07-08 07:32:00+03	31600.00
43781A	2017-08-12 03:41:00+03	55800.00
43781B	2017-08-04 08:45:00+03	242200.00
43787C	2017-08-02 09:46:00+03	26000.00
4378DF	2017-08-02 09:31:00+03	13200.00
4378E4	2017-08-08 00:53:00+03	25100.00
437941	2017-07-30 12:50:00+03	95200.00
437942	2017-07-22 02:30:00+03	10800.00
43799D	2017-08-08 20:07:00+03	114800.00
4379BC	2017-07-08 07:13:00+03	35300.00
4379DB	2017-07-18 23:40:00+03	77400.00
437A32	2017-08-11 13:37:00+03	53300.00
437A8B	2017-07-13 18:22:00+03	27200.00
437A90	2017-08-05 03:11:00+03	47100.00
437AD1	2017-07-29 10:15:00+03	173200.00
437B59	2017-07-28 15:19:00+03	23200.00
437B62	2017-08-05 20:59:00+03	73600.00
437C0B	2017-08-09 02:12:00+03	72200.00
437C27	2017-07-21 20:46:00+03	15000.00
437C3B	2017-07-15 19:08:00+03	301800.00
437C3C	2017-08-02 15:48:00+03	23600.00
437C56	2017-07-02 15:23:00+03	120000.00
437C71	2017-07-26 12:13:00+03	41600.00
437C89	2017-07-17 15:42:00+03	30700.00
437CAB	2017-08-12 21:11:00+03	37700.00
437CD4	2017-08-01 18:05:00+03	103500.00
437CE5	2017-07-02 20:44:00+03	83700.00
437CFA	2017-08-12 19:26:00+03	55800.00
437D0F	2017-07-16 16:21:00+03	23200.00
437D21	2017-07-24 03:11:00+03	32800.00
437D75	2017-07-11 16:03:00+03	235700.00
437DDF	2017-06-27 16:15:00+03	40300.00
437E7A	2017-07-30 12:14:00+03	62600.00
437EC3	2017-08-02 00:31:00+03	112100.00
437F5A	2017-07-26 04:17:00+03	306600.00
437F96	2017-07-16 10:25:00+03	217600.00
437FC2	2017-07-03 10:00:00+03	226800.00
438012	2017-07-12 00:31:00+03	24800.00
43807C	2017-07-20 12:17:00+03	72300.00
43808E	2017-08-01 06:32:00+03	144400.00
4380D9	2017-07-22 21:46:00+03	51900.00
4380F8	2017-07-20 23:11:00+03	29200.00
438155	2017-08-13 13:34:00+03	57600.00
4381D1	2017-07-22 09:41:00+03	42400.00
43821A	2017-08-09 06:52:00+03	59200.00
438263	2017-07-31 13:16:00+03	123000.00
438283	2017-08-15 15:55:00+03	29900.00
438285	2017-07-07 21:42:00+03	53300.00
4382AE	2017-08-04 15:40:00+03	371700.00
4383CA	2017-07-31 04:03:00+03	24400.00
4383D4	2017-07-02 08:30:00+03	48500.00
4383D6	2017-07-07 00:45:00+03	73000.00
438464	2017-07-30 23:53:00+03	14400.00
43850D	2017-06-29 01:16:00+03	44800.00
43853F	2017-07-11 11:50:00+03	70700.00
438564	2017-07-26 13:01:00+03	40800.00
438585	2017-07-27 11:31:00+03	536000.00
4385B4	2017-08-03 13:01:00+03	28800.00
4386B3	2017-07-06 02:22:00+03	31400.00
4386C8	2017-07-28 00:08:00+03	69100.00
438777	2017-07-14 16:59:00+03	29600.00
43887D	2017-07-11 22:33:00+03	26000.00
43889B	2017-07-13 15:29:00+03	20400.00
438906	2017-07-08 17:42:00+03	250600.00
438945	2017-07-29 08:26:00+03	63400.00
43895F	2017-07-06 07:17:00+03	68400.00
4389FA	2017-08-02 15:12:00+03	8200.00
438A12	2017-08-14 11:47:00+03	67900.00
438AE7	2017-07-30 17:43:00+03	11700.00
438AEB	2017-07-13 16:56:00+03	75200.00
438B3E	2017-07-27 07:04:00+03	125600.00
438B40	2017-07-29 11:30:00+03	25600.00
438B6A	2017-07-25 13:44:00+03	36000.00
438BA3	2017-08-03 13:43:00+03	126500.00
438BAD	2017-07-29 23:07:00+03	67200.00
438BAE	2017-08-04 22:16:00+03	155400.00
438C37	2017-07-31 08:25:00+03	260300.00
438C58	2017-07-19 16:21:00+03	49200.00
438D01	2017-07-03 02:22:00+03	40400.00
438D3E	2017-07-30 09:20:00+03	135400.00
438D7C	2017-08-06 10:07:00+03	144300.00
438E81	2017-08-12 06:45:00+03	273000.00
438E86	2017-07-04 08:53:00+03	28600.00
438F0B	2017-07-26 11:31:00+03	36200.00
438F42	2017-08-03 11:25:00+03	112000.00
438F9C	2017-07-01 09:31:00+03	151800.00
438FD4	2017-08-08 22:49:00+03	13400.00
43901C	2017-08-15 14:31:00+03	48500.00
43902D	2017-07-16 11:54:00+03	22600.00
439085	2017-07-18 11:23:00+03	11600.00
4390A2	2017-07-13 07:16:00+03	28800.00
4390C9	2017-08-07 13:53:00+03	26800.00
4390ED	2017-07-08 10:17:00+03	32700.00
439196	2017-08-09 10:48:00+03	24700.00
4391FD	2017-08-14 07:51:00+03	57600.00
439230	2017-08-09 20:39:00+03	77200.00
43926D	2017-07-05 20:08:00+03	46700.00
439295	2017-08-13 18:45:00+03	28800.00
43935D	2017-07-07 20:28:00+03	37800.00
439399	2017-07-22 05:21:00+03	8400.00
43939B	2017-07-22 13:15:00+03	598400.00
4393A1	2017-08-02 20:36:00+03	75600.00
43940A	2017-07-25 20:55:00+03	36800.00
43948D	2017-07-04 01:22:00+03	52100.00
4394B7	2017-07-31 05:36:00+03	49800.00
4394DD	2017-08-11 16:22:00+03	87000.00
439514	2017-07-29 16:14:00+03	189800.00
439547	2017-07-13 11:14:00+03	18600.00
439591	2017-08-03 05:05:00+03	4000.00
4395DD	2017-07-21 04:28:00+03	78300.00
4395F5	2017-07-05 05:04:00+03	129600.00
43962A	2017-08-08 20:42:00+03	55800.00
439669	2017-07-07 02:13:00+03	59200.00
43966D	2017-07-13 04:41:00+03	85000.00
439700	2017-07-02 08:12:00+03	47000.00
439743	2017-07-21 17:04:00+03	117600.00
439745	2017-07-28 18:57:00+03	13600.00
439768	2017-08-01 20:45:00+03	81700.00
4397A0	2017-07-05 05:22:00+03	28000.00
4397D2	2017-08-06 14:29:00+03	73600.00
439830	2017-08-12 22:45:00+03	57300.00
439857	2017-07-18 13:54:00+03	193500.00
4398E8	2017-07-21 03:01:00+03	135600.00
439925	2017-08-08 20:57:00+03	86800.00
439957	2017-07-23 07:37:00+03	43100.00
4399A8	2017-07-13 17:09:00+03	75300.00
4399B9	2017-07-21 03:21:00+03	168000.00
4399CB	2017-07-21 14:39:00+03	56000.00
4399D5	2017-07-02 10:46:00+03	40400.00
439A00	2017-08-12 09:25:00+03	115600.00
439A61	2017-08-12 21:25:00+03	84000.00
439B47	2017-07-05 22:50:00+03	70800.00
439B65	2017-08-01 22:55:00+03	75800.00
439B86	2017-07-15 14:41:00+03	51300.00
439B90	2017-08-10 22:23:00+03	99200.00
439B9B	2017-06-30 09:46:00+03	18700.00
439BCF	2017-07-21 07:56:00+03	108500.00
439BF0	2017-08-09 11:19:00+03	207200.00
439C9E	2017-08-03 15:46:00+03	56000.00
439CA1	2017-07-12 03:16:00+03	6700.00
439D75	2017-08-10 00:11:00+03	26000.00
439D81	2017-08-10 21:59:00+03	28800.00
439D8F	2017-07-12 04:14:00+03	10600.00
439D95	2017-08-06 18:13:00+03	72400.00
439DCD	2017-07-18 22:33:00+03	24600.00
439E24	2017-07-08 19:24:00+03	119500.00
439E59	2017-07-12 16:11:00+03	81000.00
439F90	2017-07-10 06:40:00+03	13400.00
43A00A	2017-08-03 06:55:00+03	66800.00
43A01C	2017-07-14 07:46:00+03	26700.00
43A03C	2017-08-11 18:19:00+03	37200.00
43A055	2017-08-15 15:32:00+03	62000.00
43A0D6	2017-07-04 17:31:00+03	56800.00
43A0EF	2017-08-07 11:07:00+03	92400.00
43A0F7	2017-08-08 13:09:00+03	41600.00
43A10A	2017-08-02 00:23:00+03	55800.00
43A1C5	2017-07-17 10:26:00+03	27200.00
43A27F	2017-08-14 16:30:00+03	114700.00
43A2C3	2017-07-01 06:13:00+03	57500.00
43A325	2017-07-08 10:30:00+03	57600.00
43A355	2017-07-29 06:40:00+03	29400.00
43A389	2017-08-01 05:43:00+03	6000.00
43A3EF	2017-08-02 23:03:00+03	64700.00
43A422	2017-08-03 22:49:00+03	24700.00
43A42E	2017-07-31 19:04:00+03	60700.00
43A436	2017-07-28 05:46:00+03	48300.00
43A446	2017-07-16 10:35:00+03	29600.00
43A46C	2017-07-11 03:49:00+03	173400.00
43A4AD	2017-07-05 23:41:00+03	65100.00
43A4BC	2017-08-03 22:33:00+03	56000.00
43A542	2017-07-22 02:24:00+03	14700.00
43A543	2017-08-06 06:53:00+03	24400.00
43A5AF	2017-08-14 00:21:00+03	48700.00
43A5B0	2017-07-19 13:05:00+03	138900.00
43A5F5	2017-08-03 22:16:00+03	42800.00
43A61F	2017-07-28 07:17:00+03	16800.00
43A63C	2017-07-31 15:52:00+03	272300.00
43A66B	2017-08-06 21:29:00+03	20400.00
43A6F1	2017-07-30 11:41:00+03	79200.00
43A710	2017-07-22 07:15:00+03	56600.00
43A765	2017-08-07 20:37:00+03	66000.00
43A7A9	2017-08-06 23:37:00+03	39500.00
43A835	2017-07-04 02:18:00+03	10700.00
43A864	2017-07-04 11:40:00+03	39800.00
43A888	2017-07-06 06:58:00+03	213000.00
43A903	2017-07-21 03:11:00+03	21200.00
43A92A	2017-07-19 09:50:00+03	60400.00
43A962	2017-07-21 06:00:00+03	28300.00
43A98E	2017-08-04 14:25:00+03	43500.00
43A990	2017-06-30 20:43:00+03	76600.00
43A9E7	2017-07-08 16:01:00+03	134400.00
43AA63	2017-08-06 01:58:00+03	56900.00
43AA91	2017-08-04 06:09:00+03	22000.00
43AAF2	2017-07-14 12:08:00+03	31600.00
43AB19	2017-08-04 20:28:00+03	112000.00
43AB4D	2017-08-08 07:22:00+03	66100.00
43AB51	2017-06-29 03:53:00+03	26600.00
43AC28	2017-08-02 12:43:00+03	64800.00
43AC9D	2017-07-06 21:31:00+03	28800.00
43ACF8	2017-07-24 05:35:00+03	75600.00
43ACFE	2017-08-11 23:42:00+03	94700.00
43AD02	2017-08-02 00:43:00+03	63300.00
43ADEA	2017-07-13 20:55:00+03	50600.00
43ADFF	2017-07-21 20:12:00+03	133100.00
43AE05	2017-07-23 08:15:00+03	393800.00
43AE30	2017-07-22 07:20:00+03	193200.00
43AE5F	2017-07-11 18:12:00+03	25400.00
43AE7F	2017-08-13 13:14:00+03	47400.00
43AE8A	2017-08-06 17:09:00+03	164000.00
43AED4	2017-08-14 09:46:00+03	29900.00
43AEF8	2017-08-04 15:37:00+03	87200.00
43AF06	2017-07-28 12:54:00+03	135400.00
43AF7F	2017-07-18 12:30:00+03	111600.00
43AF80	2017-07-06 21:56:00+03	18000.00
43B054	2017-07-20 03:48:00+03	40800.00
43B070	2017-08-10 09:19:00+03	86800.00
43B083	2017-06-25 05:47:00+03	43600.00
43B0E8	2017-08-12 04:49:00+03	57800.00
43B0F8	2017-08-07 02:23:00+03	56600.00
43B167	2017-07-12 00:09:00+03	68000.00
43B18B	2017-08-06 10:49:00+03	83400.00
43B22F	2017-08-13 14:56:00+03	25200.00
43B252	2017-08-04 20:01:00+03	27400.00
43B2EE	2017-07-08 14:31:00+03	6000.00
43B306	2017-08-01 20:59:00+03	68100.00
43B31B	2017-07-07 12:11:00+03	32800.00
43B35D	2017-07-26 08:41:00+03	114800.00
43B396	2017-07-12 21:21:00+03	46700.00
43B429	2017-07-24 21:29:00+03	8200.00
43B439	2017-08-14 22:40:00+03	56000.00
43B453	2017-07-22 00:40:00+03	25100.00
43B464	2017-07-30 10:14:00+03	56000.00
43B46B	2017-07-12 03:32:00+03	56000.00
43B47D	2017-07-15 04:20:00+03	101200.00
43B47E	2017-08-14 19:13:00+03	71400.00
43B4D8	2017-08-15 03:41:00+03	114800.00
43B521	2017-08-05 22:24:00+03	24000.00
43B595	2017-07-03 23:12:00+03	20600.00
43B5CA	2017-07-28 13:43:00+03	77900.00
43B5EC	2017-07-29 23:09:00+03	46800.00
43B5F1	2017-08-07 15:04:00+03	136200.00
43B619	2017-08-01 08:14:00+03	55800.00
43B627	2017-07-13 10:56:00+03	179400.00
43B64E	2017-08-12 12:23:00+03	299900.00
43B6CB	2017-07-04 21:29:00+03	92100.00
43B6CD	2017-07-18 14:11:00+03	133200.00
43B711	2017-08-07 15:09:00+03	139300.00
43B739	2017-08-11 06:09:00+03	45200.00
43B747	2017-07-29 22:15:00+03	81300.00
43B76A	2017-08-10 16:01:00+03	27800.00
43B7F1	2017-08-07 07:37:00+03	148200.00
43B807	2017-08-10 06:56:00+03	81600.00
43B844	2017-07-09 10:22:00+03	38600.00
43B885	2017-07-22 11:10:00+03	73200.00
43B8B0	2017-07-27 00:03:00+03	43000.00
43B99F	2017-07-08 18:33:00+03	58000.00
43BA8E	2017-07-02 06:30:00+03	46400.00
43BB46	2017-07-09 15:03:00+03	46800.00
43BB49	2017-08-14 21:37:00+03	45200.00
43BB61	2017-07-23 14:35:00+03	16400.00
43BB76	2017-08-07 00:25:00+03	22400.00
43BB82	2017-08-05 23:14:00+03	85400.00
43BBA1	2017-07-09 06:24:00+03	50000.00
43BBCD	2017-08-12 05:33:00+03	65600.00
43BBD6	2017-07-10 20:28:00+03	53600.00
43BC03	2017-07-20 15:49:00+03	136200.00
43BC44	2017-07-22 17:22:00+03	10700.00
43BC85	2017-08-09 14:25:00+03	23600.00
43BDC4	2017-08-13 15:37:00+03	159700.00
43BE19	2017-07-18 06:59:00+03	78300.00
43BE62	2017-07-16 23:22:00+03	84100.00
43BE7B	2017-08-10 20:12:00+03	109200.00
43BEE4	2017-07-21 08:16:00+03	65500.00
43BEFD	2017-08-05 03:57:00+03	23200.00
43BF3A	2017-07-31 04:45:00+03	43100.00
43BF4B	2017-07-28 16:52:00+03	54000.00
43BFB0	2017-07-31 16:27:00+03	37000.00
43C001	2017-07-05 08:03:00+03	32800.00
43C043	2017-07-23 18:53:00+03	66300.00
43C073	2017-07-11 14:38:00+03	66600.00
43C089	2017-07-09 02:34:00+03	62100.00
43C08D	2017-08-11 10:13:00+03	85000.00
43C0A9	2017-07-26 01:30:00+03	25100.00
43C0BD	2017-07-13 01:50:00+03	52000.00
43C0D5	2017-07-21 20:55:00+03	40900.00
43C0ED	2017-07-02 04:10:00+03	8400.00
43C134	2017-07-16 07:41:00+03	46200.00
43C177	2017-07-14 23:59:00+03	278400.00
43C186	2017-08-08 14:15:00+03	30000.00
43C26F	2017-06-29 02:31:00+03	17000.00
43C2B8	2017-07-10 05:40:00+03	34000.00
43C321	2017-07-22 01:27:00+03	538800.00
43C331	2017-08-06 22:24:00+03	36800.00
43C381	2017-07-15 06:57:00+03	78200.00
43C42C	2017-07-08 05:29:00+03	24400.00
43C4E3	2017-07-19 20:52:00+03	102800.00
43C4EF	2017-08-03 10:37:00+03	23600.00
43C513	2017-07-27 21:06:00+03	68000.00
43C56B	2017-07-16 06:36:00+03	179200.00
43C5D4	2017-07-29 04:05:00+03	60700.00
43C65A	2017-08-14 15:13:00+03	91900.00
43C6A8	2017-07-15 16:33:00+03	28000.00
43C725	2017-07-20 21:16:00+03	13600.00
43C728	2017-08-09 18:01:00+03	22600.00
43C73C	2017-08-04 08:17:00+03	41200.00
43C750	2017-08-10 04:11:00+03	10800.00
43C77F	2017-07-15 06:18:00+03	86800.00
43C787	2017-07-12 04:29:00+03	16400.00
43C78D	2017-07-23 15:20:00+03	171100.00
43C7A4	2017-08-08 08:21:00+03	89700.00
43C826	2017-07-14 07:50:00+03	37800.00
43C82F	2017-08-10 07:58:00+03	22600.00
43C87D	2017-08-09 08:23:00+03	77600.00
43C8B8	2017-08-01 19:02:00+03	26800.00
43C8ED	2017-08-14 23:00:00+03	27200.00
43C92C	2017-08-11 08:16:00+03	24400.00
43C93F	2017-07-18 18:59:00+03	111600.00
43CA19	2017-08-07 00:13:00+03	65900.00
43CA2A	2017-07-07 18:39:00+03	72300.00
43CA52	2017-08-07 14:07:00+03	51600.00
43CA63	2017-08-08 05:05:00+03	12600.00
43CA9E	2017-08-14 06:44:00+03	6000.00
43CAA0	2017-07-20 04:15:00+03	67100.00
43CACF	2017-07-26 10:14:00+03	36400.00
43CAD1	2017-08-01 03:19:00+03	23600.00
43CAEC	2017-08-01 16:39:00+03	18600.00
43CAF1	2017-07-17 01:33:00+03	39500.00
43CB2D	2017-08-03 16:40:00+03	28000.00
43CB2F	2017-08-08 16:30:00+03	64700.00
43CB39	2017-07-29 03:08:00+03	71200.00
43CBBE	2017-07-19 20:31:00+03	123000.00
43CBCB	2017-08-09 17:08:00+03	46000.00
43CBE5	2017-07-17 19:11:00+03	50800.00
43CC1A	2017-08-15 17:47:00+03	15100.00
43CC61	2017-07-28 10:00:00+03	54400.00
43CC84	2017-07-01 05:49:00+03	50600.00
43CCFA	2017-07-09 15:03:00+03	79900.00
43CD13	2017-08-13 23:10:00+03	67200.00
43CD6C	2017-08-11 09:00:00+03	406700.00
43CDC5	2017-08-10 02:13:00+03	8000.00
43CDD8	2017-07-01 06:56:00+03	6300.00
43CDF4	2017-07-26 05:36:00+03	17800.00
43CE12	2017-07-19 12:42:00+03	11600.00
43CE3E	2017-08-08 07:04:00+03	86600.00
43CE99	2017-08-07 08:54:00+03	32900.00
43CF4C	2017-07-22 09:01:00+03	27200.00
43CF77	2017-07-04 06:44:00+03	192500.00
43CF7C	2017-07-05 07:15:00+03	44500.00
43CF81	2017-07-04 01:08:00+03	26000.00
43D037	2017-07-24 12:51:00+03	67800.00
43D03F	2017-07-27 11:59:00+03	24800.00
43D053	2017-08-04 10:50:00+03	56500.00
43D0A2	2017-07-12 22:16:00+03	49500.00
43D110	2017-08-02 07:25:00+03	102100.00
43D15A	2017-08-14 04:17:00+03	85000.00
43D189	2017-07-13 18:49:00+03	6700.00
43D18F	2017-07-11 16:37:00+03	27200.00
43D214	2017-07-29 05:08:00+03	87100.00
43D22E	2017-07-26 12:58:00+03	83000.00
43D25B	2017-07-12 06:11:00+03	258400.00
43D2A2	2017-07-11 21:24:00+03	199300.00
43D340	2017-07-08 08:28:00+03	26500.00
43D376	2017-07-11 15:18:00+03	65900.00
43D3EE	2017-07-21 03:04:00+03	224000.00
43D3FA	2017-07-23 10:23:00+03	27200.00
43D406	2017-07-18 12:24:00+03	55800.00
43D47D	2017-07-29 09:02:00+03	252200.00
43D5AF	2017-08-11 23:04:00+03	135400.00
43D5BC	2017-08-08 20:13:00+03	47600.00
43D5D1	2017-07-02 05:39:00+03	21800.00
43D61F	2017-07-15 13:29:00+03	130400.00
43D626	2017-08-12 12:21:00+03	77200.00
43D665	2017-08-07 09:18:00+03	58000.00
43D692	2017-07-05 03:18:00+03	59800.00
43D6C6	2017-07-12 11:58:00+03	28200.00
43D6DC	2017-08-05 12:12:00+03	81200.00
43D73E	2017-08-01 15:16:00+03	86400.00
43D748	2017-07-04 13:58:00+03	117600.00
43D777	2017-08-07 07:25:00+03	62900.00
43D7AC	2017-07-24 10:46:00+03	198400.00
43D7B2	2017-07-28 23:47:00+03	46000.00
43D80D	2017-07-22 12:20:00+03	13400.00
43D816	2017-07-29 06:55:00+03	33100.00
43D83A	2017-08-08 12:52:00+03	93900.00
43D866	2017-08-09 05:43:00+03	207300.00
43D8EB	2017-06-29 05:35:00+03	280600.00
43D8F2	2017-07-19 05:38:00+03	149600.00
43D8F8	2017-07-12 13:01:00+03	125300.00
43D928	2017-07-23 11:05:00+03	235400.00
43D97A	2017-08-07 21:21:00+03	36200.00
43D996	2017-08-08 07:16:00+03	49600.00
43D9C7	2017-07-17 13:51:00+03	144500.00
43D9E1	2017-08-13 06:39:00+03	47700.00
43DA2C	2017-07-06 11:50:00+03	24200.00
43DA65	2017-06-28 05:34:00+03	6800.00
43DABA	2017-08-10 17:12:00+03	199200.00
43DAF0	2017-07-24 06:29:00+03	19800.00
43DB14	2017-07-31 07:43:00+03	26000.00
43DB57	2017-08-08 08:37:00+03	114500.00
43DB92	2017-08-01 00:36:00+03	55800.00
43DB95	2017-07-06 21:22:00+03	48800.00
43DBCF	2017-07-08 18:18:00+03	23200.00
43DC4B	2017-08-12 06:07:00+03	55600.00
43DD5C	2017-07-21 13:42:00+03	47000.00
43DDB6	2017-07-17 07:19:00+03	26600.00
43DDF5	2017-08-07 19:28:00+03	27200.00
43DDFA	2017-07-22 15:12:00+03	78600.00
43DE3B	2017-08-08 03:52:00+03	128800.00
43DE40	2017-08-08 14:17:00+03	44300.00
43DE89	2017-07-27 23:58:00+03	76400.00
43DE9A	2017-08-12 00:56:00+03	92600.00
43DEEA	2017-07-23 14:50:00+03	23200.00
43DEF4	2017-07-02 14:01:00+03	126300.00
43DF09	2017-08-11 09:20:00+03	52900.00
43DF56	2017-07-19 22:34:00+03	44000.00
43DF89	2017-08-15 11:18:00+03	33500.00
43DF8D	2017-07-13 01:25:00+03	119600.00
43DFA1	2017-08-09 00:36:00+03	65200.00
43DFDE	2017-08-06 12:22:00+03	169600.00
43E00A	2017-07-19 20:22:00+03	170200.00
43E00F	2017-08-03 11:51:00+03	92000.00
43E018	2017-08-08 17:37:00+03	35400.00
43E071	2017-07-13 16:37:00+03	23400.00
43E07C	2017-08-03 05:56:00+03	58800.00
43E0C9	2017-07-14 08:05:00+03	133200.00
43E0CE	2017-07-14 05:22:00+03	76600.00
43E0CF	2017-07-30 21:11:00+03	136200.00
43E139	2017-08-10 22:19:00+03	121400.00
43E13C	2017-08-11 01:44:00+03	406200.00
43E1B1	2017-07-12 01:52:00+03	99300.00
43E1CD	2017-07-10 08:10:00+03	64700.00
43E1DA	2017-08-09 02:42:00+03	6800.00
43E1FF	2017-07-04 05:17:00+03	29600.00
43E227	2017-08-05 23:06:00+03	169900.00
43E251	2017-08-04 05:59:00+03	44000.00
43E261	2017-07-21 16:57:00+03	7400.00
43E270	2017-07-26 02:11:00+03	26600.00
43E280	2017-07-31 03:12:00+03	67600.00
43E29B	2017-07-15 20:06:00+03	13200.00
43E301	2017-07-27 19:37:00+03	265700.00
43E30E	2017-07-19 23:33:00+03	22000.00
43E32B	2017-08-02 12:39:00+03	126300.00
43E39B	2017-07-17 07:18:00+03	56000.00
43E4CD	2017-07-30 14:04:00+03	48200.00
43E512	2017-08-01 16:30:00+03	66700.00
43E54F	2017-07-13 21:46:00+03	60400.00
43E578	2017-07-31 18:11:00+03	29600.00
43E5D4	2017-07-25 17:53:00+03	135400.00
43E5F9	2017-07-18 19:36:00+03	132400.00
43E61D	2017-07-26 19:03:00+03	56000.00
43E6D9	2017-08-11 09:54:00+03	26000.00
43E6DD	2017-08-11 23:15:00+03	20100.00
43E6DE	2017-07-22 05:01:00+03	68800.00
43E705	2017-08-03 02:40:00+03	124200.00
43E722	2017-08-15 01:20:00+03	52800.00
43E747	2017-07-31 03:44:00+03	133700.00
43E749	2017-07-24 03:13:00+03	42900.00
43E77E	2017-08-13 22:06:00+03	31200.00
43E7B3	2017-07-12 13:19:00+03	155600.00
43E88A	2017-08-08 18:08:00+03	77000.00
43E892	2017-07-14 16:37:00+03	79200.00
43E8CA	2017-07-20 19:25:00+03	23200.00
43E8F7	2017-07-10 01:09:00+03	31200.00
43E907	2017-08-12 00:23:00+03	531400.00
43E924	2017-07-13 16:57:00+03	25100.00
43E9D3	2017-07-16 15:05:00+03	81600.00
43E9FA	2017-08-11 18:17:00+03	135900.00
43EA23	2017-07-21 20:31:00+03	44800.00
43EA36	2017-07-17 19:19:00+03	37700.00
43EA4C	2017-07-22 07:49:00+03	36200.00
43EA9F	2017-07-06 19:55:00+03	12600.00
43EAB8	2017-07-02 17:07:00+03	23200.00
43EB15	2017-07-31 23:35:00+03	48800.00
43EB70	2017-07-12 01:42:00+03	82900.00
43EBBD	2017-07-04 07:01:00+03	552000.00
43EBD0	2017-07-06 20:52:00+03	265600.00
43EC23	2017-07-24 00:48:00+03	24300.00
43ED32	2017-07-17 10:57:00+03	28000.00
43ED9F	2017-07-02 10:49:00+03	59400.00
43EE1F	2017-07-10 22:20:00+03	26700.00
43EE52	2017-06-28 18:33:00+03	64600.00
43EE53	2017-07-04 17:21:00+03	13400.00
43EE88	2017-07-05 22:41:00+03	22000.00
43EEA0	2017-07-21 04:26:00+03	260300.00
43EEC6	2017-07-07 08:46:00+03	29600.00
43EF14	2017-07-28 12:01:00+03	67600.00
43EF25	2017-08-07 01:59:00+03	61900.00
43EF3A	2017-08-09 13:26:00+03	29000.00
43EFB9	2017-07-06 12:25:00+03	19800.00
43F064	2017-07-11 12:38:00+03	23600.00
43F06D	2017-08-10 10:06:00+03	85000.00
43F084	2017-08-03 18:55:00+03	92800.00
43F089	2017-07-07 16:43:00+03	6800.00
43F09D	2017-07-09 09:26:00+03	22000.00
43F173	2017-08-10 09:59:00+03	46200.00
43F1A3	2017-07-11 02:44:00+03	29400.00
43F1B0	2017-07-28 12:18:00+03	25400.00
43F1D0	2017-07-15 13:30:00+03	54400.00
43F1D6	2017-08-12 22:48:00+03	121800.00
43F2AF	2017-07-08 13:58:00+03	156500.00
43F2E4	2017-07-30 20:39:00+03	64600.00
43F32A	2017-07-20 21:40:00+03	22000.00
43F34C	2017-08-12 11:33:00+03	58400.00
43F384	2017-07-17 05:32:00+03	62600.00
43F3A0	2017-07-31 20:50:00+03	408600.00
43F465	2017-07-10 07:03:00+03	8000.00
43F46E	2017-08-01 16:37:00+03	68800.00
43F4BF	2017-07-11 14:45:00+03	68800.00
43F549	2017-08-14 08:54:00+03	89700.00
43F591	2017-07-08 01:33:00+03	55800.00
43F5A3	2017-08-04 00:18:00+03	272400.00
43F5AA	2017-08-15 13:51:00+03	14000.00
43F5CA	2017-07-31 06:31:00+03	48800.00
43F5DB	2017-07-26 14:57:00+03	62600.00
43F60B	2017-08-01 09:32:00+03	7400.00
43F60D	2017-07-28 15:18:00+03	31400.00
43F655	2017-07-30 18:18:00+03	123000.00
43F6CA	2017-08-06 17:44:00+03	99200.00
43F7A7	2017-07-27 16:04:00+03	75300.00
43F7CF	2017-08-12 20:13:00+03	95500.00
43F805	2017-07-27 20:15:00+03	101200.00
43F873	2017-07-01 10:20:00+03	147700.00
43F981	2017-07-11 03:00:00+03	89600.00
43F98B	2017-08-10 17:02:00+03	11600.00
43F994	2017-07-31 04:01:00+03	58000.00
43F9B3	2017-07-29 00:39:00+03	46800.00
43F9D7	2017-08-11 14:03:00+03	101200.00
43F9FD	2017-08-08 13:08:00+03	27200.00
43FAB0	2017-08-04 21:33:00+03	39200.00
43FACA	2017-07-17 06:45:00+03	18600.00
43FADE	2017-07-11 14:53:00+03	27900.00
43FB23	2017-07-17 14:45:00+03	23400.00
43FB55	2017-08-13 19:22:00+03	20600.00
43FB82	2017-07-25 02:51:00+03	36200.00
43FBAE	2017-07-25 03:21:00+03	6800.00
43FBD0	2017-08-03 01:16:00+03	22000.00
43FBFD	2017-07-07 16:05:00+03	156300.00
43FC7D	2017-07-26 11:39:00+03	15800.00
43FCC8	2017-07-11 05:43:00+03	70600.00
43FD79	2017-07-06 08:22:00+03	32400.00
43FD9D	2017-07-12 07:51:00+03	129600.00
43FDA3	2017-07-28 23:03:00+03	23600.00
43FDC2	2017-07-20 17:43:00+03	92700.00
43FDC9	2017-08-11 03:35:00+03	51200.00
43FDFD	2017-07-29 01:33:00+03	85000.00
43FE0B	2017-08-14 00:37:00+03	103500.00
43FE2D	2017-08-12 20:10:00+03	40000.00
43FE99	2017-07-11 07:25:00+03	18800.00
43FEB9	2017-08-14 05:29:00+03	27600.00
43FECA	2017-07-19 14:08:00+03	53700.00
43FEE3	2017-08-03 07:04:00+03	266400.00
43FF1E	2017-07-19 20:18:00+03	61800.00
43FF8A	2017-07-16 10:45:00+03	98200.00
43FF8B	2017-07-26 00:29:00+03	85000.00
440017	2017-07-11 03:19:00+03	69500.00
440047	2017-07-06 10:56:00+03	63500.00
440055	2017-08-12 12:38:00+03	123000.00
44006E	2017-07-12 09:46:00+03	226800.00
44006F	2017-08-12 13:46:00+03	43200.00
440083	2017-07-06 17:23:00+03	186000.00
44017F	2017-07-10 17:17:00+03	300700.00
440214	2017-06-28 23:52:00+03	14000.00
44022B	2017-07-13 09:33:00+03	92000.00
440259	2017-07-30 23:12:00+03	56600.00
44027C	2017-07-12 04:09:00+03	32700.00
440297	2017-07-31 12:24:00+03	69700.00
4402FB	2017-07-09 00:04:00+03	92900.00
440332	2017-07-09 14:43:00+03	23100.00
44038D	2017-07-22 23:05:00+03	31400.00
4403A6	2017-07-28 09:28:00+03	96800.00
4403BD	2017-07-11 14:22:00+03	123900.00
440422	2017-07-13 02:17:00+03	134400.00
440479	2017-08-12 13:42:00+03	273200.00
44047E	2017-07-06 06:30:00+03	85000.00
44049E	2017-07-19 06:09:00+03	74200.00
4404D0	2017-08-07 08:04:00+03	84300.00
4404DC	2017-07-11 02:53:00+03	24400.00
44051E	2017-07-18 19:02:00+03	24400.00
440528	2017-07-01 04:30:00+03	27500.00
44052D	2017-07-06 06:51:00+03	41600.00
44064E	2017-08-02 10:04:00+03	133200.00
440660	2017-07-19 13:03:00+03	246000.00
440682	2017-07-19 13:10:00+03	121800.00
440794	2017-08-11 08:02:00+03	136200.00
440829	2017-08-01 12:48:00+03	23600.00
44092E	2017-07-03 13:02:00+03	12600.00
440949	2017-07-20 20:43:00+03	20200.00
44097B	2017-08-04 23:58:00+03	6700.00
4409BA	2017-07-02 00:12:00+03	139400.00
440A0B	2017-08-03 09:44:00+03	65500.00
440AB9	2017-07-15 09:06:00+03	134400.00
440AE8	2017-07-04 02:05:00+03	25600.00
440B65	2017-08-06 09:04:00+03	8400.00
440BDE	2017-06-29 03:39:00+03	89100.00
440C28	2017-07-02 21:36:00+03	28000.00
440C3F	2017-08-02 09:19:00+03	27200.00
440CC1	2017-07-06 20:43:00+03	46300.00
440D12	2017-08-13 16:15:00+03	8200.00
440D6C	2017-06-29 21:15:00+03	58900.00
440DE0	2017-07-03 13:50:00+03	176500.00
440E01	2017-08-14 09:08:00+03	18600.00
440E4E	2017-07-20 17:14:00+03	120100.00
440E5D	2017-07-11 10:42:00+03	28800.00
440E67	2017-08-14 03:39:00+03	31600.00
440E81	2017-08-15 14:23:00+03	93900.00
440E8E	2017-07-30 13:28:00+03	33300.00
440EC6	2017-08-13 04:37:00+03	86600.00
440EE6	2017-07-22 13:09:00+03	132800.00
440F90	2017-07-03 22:13:00+03	16400.00
440FA0	2017-08-13 02:04:00+03	46500.00
440FEF	2017-07-10 07:37:00+03	277800.00
440FF5	2017-07-08 20:10:00+03	40000.00
441010	2017-08-06 15:15:00+03	58200.00
44101D	2017-07-12 19:49:00+03	47100.00
441033	2017-08-12 04:08:00+03	179400.00
441092	2017-08-06 03:31:00+03	25800.00
44109B	2017-07-27 01:47:00+03	29400.00
4410AC	2017-07-06 13:55:00+03	7400.00
441175	2017-08-05 23:02:00+03	38500.00
44117C	2017-07-11 22:24:00+03	65600.00
4411A7	2017-07-11 07:36:00+03	135600.00
4411E1	2017-08-06 09:52:00+03	112000.00
441230	2017-08-04 18:05:00+03	66600.00
44124C	2017-08-06 15:44:00+03	29600.00
441255	2017-08-05 21:49:00+03	69900.00
4412C6	2017-08-05 13:39:00+03	32700.00
44130D	2017-08-11 22:35:00+03	59700.00
441380	2017-06-28 02:33:00+03	26600.00
44139F	2017-08-14 21:06:00+03	23400.00
4413F1	2017-07-28 00:53:00+03	42600.00
4413FE	2017-07-13 11:28:00+03	398500.00
441412	2017-08-10 11:54:00+03	167500.00
441418	2017-07-27 22:58:00+03	55800.00
44144F	2017-08-09 16:22:00+03	88300.00
441465	2017-07-16 12:15:00+03	121400.00
4414BA	2017-07-07 01:56:00+03	31500.00
4414F3	2017-07-05 02:15:00+03	12400.00
44152C	2017-07-03 19:59:00+03	92900.00
441559	2017-07-26 21:33:00+03	78700.00
4415B3	2017-07-07 16:02:00+03	76600.00
441691	2017-07-31 06:03:00+03	42800.00
44173B	2017-07-22 04:34:00+03	86500.00
44177A	2017-07-26 23:54:00+03	23200.00
441799	2017-07-15 16:09:00+03	283700.00
44179D	2017-07-16 18:50:00+03	111600.00
441882	2017-07-17 12:09:00+03	56000.00
44188C	2017-08-06 20:16:00+03	123000.00
4418F8	2017-07-26 22:13:00+03	44000.00
4418FD	2017-07-20 14:53:00+03	67600.00
4419B9	2017-07-24 12:04:00+03	67200.00
4419E0	2017-07-16 00:58:00+03	49100.00
4419E9	2017-06-27 07:15:00+03	56900.00
441A6F	2017-08-10 13:35:00+03	38600.00
441A7A	2017-07-18 06:40:00+03	256400.00
441ADC	2017-07-08 16:10:00+03	26800.00
441B07	2017-08-05 09:42:00+03	325600.00
441B84	2017-07-31 18:23:00+03	31400.00
441BC7	2017-07-05 06:08:00+03	249100.00
441C35	2017-07-25 03:46:00+03	134400.00
441C3A	2017-08-13 07:56:00+03	194000.00
441C51	2017-07-21 11:31:00+03	28000.00
441C75	2017-08-14 09:52:00+03	97800.00
441C78	2017-08-03 08:25:00+03	158400.00
441C7C	2017-08-11 17:16:00+03	107900.00
441C96	2017-08-02 12:02:00+03	106400.00
441CC0	2017-07-08 14:51:00+03	153200.00
441CCB	2017-08-10 17:54:00+03	23200.00
441CE5	2017-07-02 17:46:00+03	124200.00
441CF8	2017-07-16 12:07:00+03	202400.00
441D0E	2017-07-12 13:24:00+03	27200.00
441D33	2017-07-11 09:22:00+03	42700.00
441D8A	2017-07-18 08:34:00+03	38600.00
441DC8	2017-08-10 07:57:00+03	37700.00
441DCE	2017-07-28 01:49:00+03	92400.00
441DD2	2017-07-28 07:19:00+03	28300.00
441E33	2017-07-21 09:13:00+03	52000.00
441E6F	2017-07-09 10:44:00+03	75300.00
441F34	2017-08-13 04:52:00+03	27900.00
441FBC	2017-07-02 01:30:00+03	28800.00
441FF9	2017-07-24 15:15:00+03	89700.00
441FFB	2017-08-13 05:38:00+03	136600.00
442017	2017-08-15 13:58:00+03	66000.00
44202B	2017-08-15 00:25:00+03	73500.00
442083	2017-07-15 07:57:00+03	36200.00
4420D5	2017-06-27 09:43:00+03	108900.00
4420E5	2017-07-08 11:53:00+03	243600.00
44212B	2017-07-24 16:06:00+03	54000.00
44216C	2017-08-06 01:11:00+03	115600.00
4421C6	2017-07-22 08:32:00+03	125400.00
4421F0	2017-07-07 21:27:00+03	22000.00
442200	2017-07-28 18:27:00+03	61800.00
442206	2017-07-02 04:57:00+03	73700.00
44221D	2017-07-29 09:28:00+03	40200.00
4422F2	2017-08-09 23:14:00+03	24400.00
442326	2017-08-07 11:46:00+03	52000.00
44233E	2017-08-07 01:23:00+03	23200.00
442384	2017-07-21 08:33:00+03	46400.00
44238B	2017-07-18 08:57:00+03	27900.00
4423F8	2017-07-12 09:32:00+03	73600.00
442427	2017-07-23 15:52:00+03	26000.00
442499	2017-07-20 13:46:00+03	59800.00
4424B7	2017-07-20 00:23:00+03	67000.00
4424F6	2017-08-01 14:12:00+03	85000.00
442506	2017-07-06 06:56:00+03	189800.00
44251B	2017-07-27 06:45:00+03	31600.00
44253C	2017-07-04 18:42:00+03	43000.00
442543	2017-07-17 12:41:00+03	54000.00
442609	2017-07-21 09:31:00+03	35300.00
442627	2017-07-23 02:17:00+03	85700.00
442637	2017-07-21 21:51:00+03	38600.00
4426F8	2017-08-14 07:56:00+03	56000.00
4426FE	2017-08-02 13:37:00+03	67700.00
442726	2017-07-28 15:57:00+03	70500.00
44272D	2017-07-08 04:26:00+03	42700.00
442777	2017-08-02 09:03:00+03	40800.00
44278F	2017-08-08 17:59:00+03	6800.00
4427D1	2017-08-15 04:50:00+03	107500.00
4427D9	2017-07-05 11:56:00+03	135600.00
442803	2017-08-13 09:33:00+03	167500.00
442806	2017-07-21 15:58:00+03	14000.00
442810	2017-07-17 10:37:00+03	119400.00
44283C	2017-07-21 15:07:00+03	306600.00
44286F	2017-07-30 21:23:00+03	74100.00
442893	2017-07-04 21:32:00+03	62000.00
44290C	2017-07-23 20:50:00+03	55800.00
442911	2017-07-28 09:53:00+03	16000.00
44293B	2017-07-20 04:21:00+03	94700.00
442956	2017-07-08 09:33:00+03	25700.00
4429F5	2017-07-08 15:04:00+03	258400.00
442A5E	2017-07-30 19:37:00+03	28000.00
442A8C	2017-07-07 09:09:00+03	117000.00
442A9B	2017-07-28 07:40:00+03	23200.00
442AF3	2017-07-12 02:08:00+03	28800.00
442B35	2017-07-11 15:05:00+03	75500.00
442B41	2017-07-08 16:22:00+03	26700.00
442B73	2017-08-03 23:43:00+03	272300.00
442B89	2017-07-23 13:34:00+03	49300.00
442BFC	2017-08-10 02:55:00+03	75600.00
442C03	2017-08-08 16:44:00+03	44800.00
442C16	2017-07-16 04:42:00+03	70700.00
442D81	2017-07-22 10:09:00+03	34400.00
442D83	2017-08-06 04:13:00+03	55800.00
442D97	2017-08-05 15:51:00+03	190000.00
442E34	2017-08-14 18:13:00+03	20200.00
442EA1	2017-06-29 23:33:00+03	28000.00
442EC5	2017-07-02 01:08:00+03	167100.00
442ED0	2017-08-15 05:58:00+03	86100.00
442F19	2017-08-10 14:24:00+03	25600.00
442F35	2017-08-03 06:04:00+03	38400.00
443004	2017-07-21 05:23:00+03	48500.00
443053	2017-07-27 06:36:00+03	24400.00
4430D1	2017-07-01 11:22:00+03	60400.00
4430F0	2017-08-09 18:20:00+03	56000.00
44321C	2017-06-30 05:27:00+03	56600.00
4432A1	2017-07-24 06:51:00+03	89800.00
4432A6	2017-07-12 07:57:00+03	34000.00
4432C6	2017-07-10 17:07:00+03	93900.00
4432D5	2017-07-18 17:35:00+03	103100.00
4432ED	2017-07-31 05:46:00+03	186900.00
4432F4	2017-07-07 13:30:00+03	92800.00
4432F6	2017-08-15 05:47:00+03	66600.00
443360	2017-08-04 17:40:00+03	30200.00
44336E	2017-07-25 12:29:00+03	27300.00
44339D	2017-07-03 19:51:00+03	98400.00
4433A2	2017-07-15 22:00:00+03	43100.00
4433B1	2017-08-10 03:03:00+03	26800.00
44343E	2017-07-16 06:37:00+03	26000.00
443489	2017-07-22 08:16:00+03	139200.00
443491	2017-08-13 21:33:00+03	58800.00
44349A	2017-08-08 04:59:00+03	62600.00
44356B	2017-07-13 05:08:00+03	181600.00
443598	2017-07-14 07:56:00+03	41100.00
4435B3	2017-07-22 12:29:00+03	57600.00
44367E	2017-07-30 20:17:00+03	28000.00
4436C4	2017-07-05 22:18:00+03	35400.00
443717	2017-08-12 05:11:00+03	56900.00
443773	2017-08-07 07:10:00+03	75600.00
443796	2017-06-30 09:54:00+03	28000.00
443805	2017-08-06 08:59:00+03	62800.00
44388A	2017-07-05 12:41:00+03	12600.00
4438BC	2017-08-11 11:41:00+03	62600.00
4438C0	2017-06-27 20:03:00+03	112000.00
4438DF	2017-07-17 07:33:00+03	66400.00
44398A	2017-08-10 04:14:00+03	72400.00
4439B2	2017-07-17 12:50:00+03	170000.00
443A0C	2017-07-12 22:57:00+03	35900.00
443A30	2017-08-07 23:20:00+03	135400.00
443A31	2017-08-05 21:23:00+03	61700.00
443A47	2017-08-14 01:48:00+03	38100.00
443A67	2017-07-27 19:15:00+03	40800.00
443A86	2017-07-31 01:34:00+03	55800.00
443AA4	2017-08-04 23:15:00+03	70800.00
443AE1	2017-07-21 03:56:00+03	32800.00
443B14	2017-07-08 05:00:00+03	57500.00
443B21	2017-07-09 19:02:00+03	58900.00
443BB7	2017-07-13 18:01:00+03	158300.00
443BD1	2017-07-22 00:26:00+03	60000.00
443C07	2017-07-14 11:27:00+03	32200.00
443C41	2017-07-12 00:04:00+03	246000.00
443C4F	2017-07-14 14:30:00+03	9200.00
443C76	2017-08-04 05:58:00+03	246000.00
443CA5	2017-07-24 09:21:00+03	69500.00
443CB8	2017-07-31 13:14:00+03	23600.00
443CC9	2017-07-01 06:19:00+03	11600.00
443D48	2017-07-26 01:27:00+03	21800.00
443D9E	2017-07-03 11:49:00+03	209900.00
443E14	2017-08-04 19:22:00+03	72400.00
443E69	2017-08-14 21:38:00+03	141600.00
443F57	2017-07-25 16:18:00+03	217200.00
443FAF	2017-08-01 14:45:00+03	60400.00
444012	2017-08-02 16:08:00+03	114800.00
444020	2017-07-16 02:25:00+03	47400.00
444057	2017-07-07 15:10:00+03	92900.00
444079	2017-07-02 12:51:00+03	279300.00
4440DF	2017-06-29 07:34:00+03	116900.00
4440FB	2017-07-09 11:48:00+03	42800.00
44413C	2017-07-12 10:29:00+03	65100.00
44417A	2017-07-31 03:45:00+03	36200.00
4441A3	2017-08-01 20:39:00+03	300700.00
4441BC	2017-07-22 04:17:00+03	75600.00
4441EA	2017-08-15 04:36:00+03	37200.00
4441F9	2017-08-06 14:19:00+03	32400.00
44422C	2017-07-11 17:53:00+03	20200.00
44423B	2017-08-03 17:17:00+03	80000.00
44425D	2017-07-20 18:23:00+03	116800.00
44426F	2017-07-14 15:35:00+03	85400.00
444322	2017-07-20 04:53:00+03	86800.00
444329	2017-07-15 03:04:00+03	46400.00
44432F	2017-07-24 15:11:00+03	26700.00
44437C	2017-07-21 20:05:00+03	130900.00
4443B2	2017-08-15 01:19:00+03	26000.00
4443C7	2017-08-10 12:56:00+03	272400.00
44448D	2017-07-12 16:58:00+03	27800.00
444525	2017-07-30 01:45:00+03	123000.00
444576	2017-08-02 23:58:00+03	31000.00
44458F	2017-07-02 02:56:00+03	223200.00
4445D9	2017-07-09 18:20:00+03	55800.00
4445DD	2017-07-14 10:21:00+03	75600.00
4445EA	2017-07-18 03:59:00+03	39200.00
4445F7	2017-08-13 08:12:00+03	24000.00
444608	2017-07-08 09:25:00+03	133200.00
44460C	2017-07-17 11:14:00+03	23200.00
4447CB	2017-07-16 04:59:00+03	7400.00
444803	2017-07-09 22:07:00+03	44000.00
44484E	2017-07-09 10:38:00+03	133100.00
44487F	2017-07-13 18:38:00+03	113300.00
444895	2017-07-23 04:11:00+03	168000.00
4448E1	2017-08-01 01:21:00+03	100600.00
444911	2017-07-02 16:26:00+03	88800.00
44497C	2017-08-10 12:26:00+03	27400.00
44498B	2017-07-24 09:48:00+03	28800.00
4449B2	2017-07-12 09:50:00+03	166000.00
444A67	2017-08-03 12:37:00+03	61700.00
444A90	2017-07-05 22:50:00+03	68400.00
444B6D	2017-07-05 00:27:00+03	75300.00
444BC8	2017-08-12 01:32:00+03	27200.00
444C00	2017-07-22 21:27:00+03	20200.00
444C06	2017-07-17 11:02:00+03	55600.00
444C07	2017-07-31 23:13:00+03	74400.00
444C49	2017-08-02 06:35:00+03	19600.00
444C75	2017-08-13 10:48:00+03	28000.00
444C7A	2017-08-15 13:24:00+03	266300.00
444CD8	2017-07-13 20:24:00+03	59000.00
444D05	2017-07-31 03:26:00+03	23600.00
444D56	2017-07-16 11:21:00+03	38400.00
444D6C	2017-08-09 23:30:00+03	85000.00
444E36	2017-06-29 08:27:00+03	147700.00
444E3B	2017-07-02 04:38:00+03	67200.00
444E40	2017-07-22 11:29:00+03	28000.00
444E42	2017-08-04 08:33:00+03	49800.00
444EB3	2017-07-12 18:38:00+03	111600.00
444F2B	2017-07-13 13:46:00+03	70700.00
444F78	2017-07-09 08:39:00+03	199800.00
444FA3	2017-07-26 03:55:00+03	46400.00
444FEE	2017-07-08 18:55:00+03	95600.00
444FFF	2017-07-15 02:19:00+03	102600.00
44502E	2017-08-07 15:53:00+03	117200.00
445084	2017-08-03 15:52:00+03	37400.00
44509C	2017-07-22 17:28:00+03	51900.00
4450A8	2017-07-15 01:19:00+03	93900.00
445131	2017-08-12 10:56:00+03	73500.00
445139	2017-08-04 00:31:00+03	19600.00
445153	2017-07-06 23:46:00+03	68100.00
44516A	2017-08-05 13:47:00+03	248400.00
4451DF	2017-08-05 11:59:00+03	266400.00
445220	2017-08-15 14:20:00+03	331500.00
445227	2017-08-03 16:35:00+03	14800.00
44522B	2017-07-16 10:47:00+03	46000.00
44522D	2017-08-05 06:45:00+03	48800.00
44524D	2017-07-12 06:15:00+03	81700.00
4452B8	2017-07-21 10:11:00+03	159200.00
4452BD	2017-07-10 21:54:00+03	43500.00
4452C0	2017-07-24 14:06:00+03	240800.00
4452EC	2017-07-30 21:23:00+03	28800.00
445315	2017-07-14 16:46:00+03	23500.00
445383	2017-07-15 13:09:00+03	88600.00
44538C	2017-08-12 22:05:00+03	12600.00
445394	2017-08-14 11:28:00+03	148200.00
4453D1	2017-08-12 17:17:00+03	75600.00
4453E1	2017-08-15 08:55:00+03	186900.00
445415	2017-07-04 19:26:00+03	35200.00
445430	2017-07-31 00:10:00+03	62700.00
445519	2017-06-29 18:25:00+03	22000.00
445546	2017-08-15 10:01:00+03	24400.00
44558E	2017-07-20 12:50:00+03	48500.00
4455A0	2017-08-02 19:41:00+03	153300.00
445667	2017-07-27 13:34:00+03	72300.00
445685	2017-07-14 02:54:00+03	31600.00
4456D1	2017-08-04 01:03:00+03	37900.00
445750	2017-08-10 18:32:00+03	97900.00
4457A6	2017-07-13 05:43:00+03	24700.00
4457F4	2017-07-14 13:39:00+03	6300.00
4457FE	2017-07-25 21:20:00+03	22000.00
445867	2017-07-21 22:36:00+03	45200.00
445914	2017-07-22 03:07:00+03	12600.00
445A0F	2017-07-21 18:59:00+03	4000.00
445A33	2017-07-23 18:58:00+03	204800.00
445B54	2017-07-31 13:00:00+03	31400.00
445B5C	2017-07-30 05:36:00+03	46400.00
445BF2	2017-07-27 15:59:00+03	46000.00
445C00	2017-08-05 20:04:00+03	69100.00
445C08	2017-07-05 00:12:00+03	110500.00
445C7C	2017-07-28 15:03:00+03	173900.00
445CAF	2017-07-03 19:55:00+03	62600.00
445D3D	2017-07-19 04:11:00+03	111600.00
445D53	2017-07-01 23:25:00+03	25800.00
445D7F	2017-08-07 04:04:00+03	66600.00
445E29	2017-07-01 00:35:00+03	57800.00
445F18	2017-07-25 06:03:00+03	34800.00
445F1D	2017-08-07 09:07:00+03	68800.00
445FA3	2017-08-15 15:26:00+03	28000.00
445FBD	2017-08-07 05:10:00+03	88100.00
446018	2017-07-09 22:41:00+03	40000.00
446198	2017-08-03 18:14:00+03	70600.00
4461A5	2017-07-07 04:27:00+03	134400.00
44622A	2017-08-06 17:45:00+03	42800.00
446255	2017-08-04 23:48:00+03	21400.00
446282	2017-08-04 18:18:00+03	84500.00
4462ED	2017-08-08 03:40:00+03	119500.00
4462F0	2017-07-31 12:45:00+03	49300.00
446341	2017-07-14 10:48:00+03	85000.00
446391	2017-08-13 11:25:00+03	53000.00
4463A5	2017-07-02 19:18:00+03	16400.00
446419	2017-07-20 21:00:00+03	396500.00
44643E	2017-07-17 22:56:00+03	21400.00
44644B	2017-07-05 01:22:00+03	77900.00
44647D	2017-08-11 16:01:00+03	50800.00
4464B8	2017-08-11 11:40:00+03	148200.00
4464EC	2017-08-11 11:17:00+03	209800.00
4465D0	2017-08-04 15:12:00+03	26800.00
44660A	2017-07-01 13:52:00+03	286500.00
4466D3	2017-07-18 15:56:00+03	117200.00
446712	2017-08-14 18:14:00+03	38800.00
446714	2017-07-28 06:44:00+03	19600.00
4467F1	2017-08-15 14:52:00+03	28000.00
446822	2017-07-08 20:03:00+03	58900.00
44688B	2017-06-29 17:33:00+03	26800.00
4468F1	2017-07-21 16:11:00+03	67500.00
44691C	2017-07-11 22:50:00+03	89600.00
4469BB	2017-08-08 13:19:00+03	25000.00
4469EF	2017-08-03 21:10:00+03	30000.00
446A3C	2017-07-03 11:57:00+03	170200.00
446A41	2017-07-13 01:03:00+03	124600.00
446A4A	2017-07-01 05:00:00+03	25400.00
446A5F	2017-08-11 01:48:00+03	28800.00
446A99	2017-07-10 20:16:00+03	147400.00
446ABB	2017-07-18 13:01:00+03	133100.00
446B49	2017-07-18 05:03:00+03	28800.00
446BE0	2017-07-22 10:08:00+03	30200.00
446C14	2017-07-18 17:39:00+03	50000.00
446C75	2017-06-28 15:57:00+03	47400.00
446D22	2017-07-14 07:47:00+03	29600.00
446D34	2017-07-31 03:40:00+03	21000.00
446D7A	2017-07-19 00:42:00+03	268800.00
446D98	2017-07-08 14:33:00+03	23200.00
446DFB	2017-07-12 08:46:00+03	32800.00
446E3B	2017-07-23 19:44:00+03	61400.00
446E58	2017-07-06 09:52:00+03	30400.00
446E5D	2017-07-05 09:14:00+03	201200.00
446F86	2017-07-15 08:00:00+03	69900.00
446F8E	2017-07-26 20:54:00+03	20000.00
446FF1	2017-08-13 14:12:00+03	36800.00
44714A	2017-07-17 07:43:00+03	112000.00
44716D	2017-08-01 17:28:00+03	57800.00
447174	2017-07-10 00:46:00+03	137400.00
447181	2017-07-24 02:42:00+03	19600.00
4471BB	2017-07-04 04:03:00+03	47700.00
4471CC	2017-06-26 15:08:00+03	53600.00
4471E4	2017-07-26 20:47:00+03	28800.00
447272	2017-07-11 19:34:00+03	137700.00
447277	2017-07-23 12:03:00+03	73500.00
447293	2017-07-28 19:44:00+03	204200.00
4472BC	2017-07-29 07:52:00+03	32800.00
44739F	2017-07-14 14:36:00+03	34000.00
4473D5	2017-07-26 07:47:00+03	40800.00
4473DB	2017-07-23 20:44:00+03	22000.00
4473F4	2017-08-04 23:01:00+03	36200.00
4473F9	2017-07-12 17:27:00+03	7800.00
44740F	2017-07-27 07:23:00+03	259000.00
447437	2017-07-29 08:09:00+03	24400.00
44746F	2017-08-04 11:05:00+03	29600.00
447473	2017-07-11 01:51:00+03	369000.00
44747E	2017-08-14 17:07:00+03	26700.00
44749E	2017-08-08 02:15:00+03	29600.00
4475F2	2017-07-11 16:51:00+03	111600.00
4475F6	2017-07-26 07:46:00+03	83200.00
447613	2017-08-08 17:48:00+03	27200.00
447617	2017-07-11 02:44:00+03	20000.00
447648	2017-07-25 13:28:00+03	75600.00
4476DE	2017-07-16 14:36:00+03	111600.00
4476E1	2017-08-08 17:06:00+03	23400.00
4476E2	2017-07-15 16:58:00+03	14000.00
447712	2017-07-16 21:42:00+03	27200.00
44771B	2017-07-10 21:47:00+03	54800.00
447725	2017-07-22 06:17:00+03	106500.00
44775D	2017-07-23 01:22:00+03	25600.00
4477B0	2017-07-31 21:03:00+03	51900.00
4477B5	2017-07-16 16:18:00+03	35200.00
4477BA	2017-08-07 23:42:00+03	50200.00
4477BF	2017-07-17 07:27:00+03	24400.00
4477EC	2017-07-31 21:59:00+03	18600.00
4478C6	2017-07-06 14:35:00+03	188000.00
447953	2017-08-12 18:56:00+03	48800.00
4479C0	2017-08-07 01:17:00+03	13700.00
447A11	2017-07-11 08:01:00+03	56600.00
447A51	2017-07-06 00:23:00+03	58600.00
447A56	2017-08-14 08:43:00+03	67600.00
447AA7	2017-07-03 14:30:00+03	24300.00
447AAE	2017-07-25 07:38:00+03	39500.00
447AB7	2017-08-04 07:12:00+03	20200.00
447AC3	2017-07-18 16:28:00+03	56900.00
447ADD	2017-07-13 10:19:00+03	123000.00
447AEA	2017-08-06 04:56:00+03	92000.00
447B13	2017-08-02 16:11:00+03	193100.00
447B29	2017-07-23 15:19:00+03	54300.00
447B31	2017-07-01 12:27:00+03	62600.00
447B34	2017-06-27 04:38:00+03	38800.00
447B43	2017-07-02 20:54:00+03	406100.00
447B49	2017-07-23 18:48:00+03	520600.00
447BE8	2017-07-29 05:33:00+03	104600.00
447C45	2017-08-10 06:33:00+03	155600.00
447C6C	2017-08-08 12:54:00+03	51200.00
447CB5	2017-08-02 22:20:00+03	58600.00
447CBB	2017-07-19 15:09:00+03	28000.00
447CF2	2017-07-13 06:52:00+03	99700.00
447D22	2017-07-30 10:00:00+03	8400.00
447D6B	2017-08-10 10:36:00+03	68800.00
447D95	2017-08-11 14:55:00+03	18600.00
447DB0	2017-07-30 03:53:00+03	28800.00
447DD4	2017-07-26 11:56:00+03	58200.00
447E0F	2017-07-04 09:23:00+03	46000.00
447F39	2017-06-27 12:42:00+03	70200.00
447FB2	2017-07-30 09:13:00+03	76600.00
448041	2017-08-04 10:46:00+03	86500.00
4480AB	2017-08-08 06:33:00+03	15400.00
4480CC	2017-07-18 18:50:00+03	184600.00
448100	2017-08-13 18:41:00+03	57600.00
44813C	2017-07-31 12:39:00+03	16400.00
44815A	2017-08-13 03:05:00+03	71400.00
44818B	2017-07-17 17:56:00+03	13200.00
448251	2017-07-10 07:59:00+03	71400.00
44828A	2017-07-31 11:03:00+03	67600.00
44828E	2017-07-09 21:18:00+03	34100.00
4482F8	2017-08-10 16:35:00+03	50100.00
448327	2017-07-21 05:08:00+03	28800.00
448336	2017-06-29 07:51:00+03	52700.00
448404	2017-07-30 12:47:00+03	59600.00
44841F	2017-07-02 20:58:00+03	62600.00
448529	2017-08-01 01:50:00+03	23400.00
448544	2017-07-08 06:23:00+03	66600.00
448617	2017-07-17 19:13:00+03	25400.00
448666	2017-07-22 18:21:00+03	40600.00
4486F8	2017-08-02 09:12:00+03	47000.00
448722	2017-08-03 10:44:00+03	40800.00
44874C	2017-07-12 20:09:00+03	97000.00
448774	2017-08-09 08:03:00+03	289800.00
448783	2017-08-12 01:14:00+03	22000.00
448802	2017-07-03 12:34:00+03	20800.00
44887D	2017-08-10 05:54:00+03	18400.00
448892	2017-08-11 11:02:00+03	136200.00
4488BA	2017-07-16 02:09:00+03	116400.00
4488EC	2017-08-03 18:58:00+03	123000.00
448901	2017-08-07 13:35:00+03	81600.00
448920	2017-07-11 18:03:00+03	62600.00
448A9C	2017-07-31 15:07:00+03	136200.00
448B4E	2017-08-11 07:12:00+03	151200.00
448B56	2017-07-13 00:17:00+03	20600.00
448BCA	2017-08-03 04:48:00+03	48400.00
448C7B	2017-07-16 05:53:00+03	38400.00
448C8B	2017-07-28 13:03:00+03	142300.00
448C8D	2017-07-25 16:47:00+03	46200.00
448CBB	2017-07-11 06:17:00+03	28000.00
448CE5	2017-08-11 23:18:00+03	56000.00
448DA4	2017-07-19 16:42:00+03	23600.00
448DDB	2017-07-05 19:20:00+03	43800.00
448E0E	2017-07-15 22:12:00+03	30200.00
448E5E	2017-08-14 18:50:00+03	12000.00
448EF7	2017-08-12 03:00:00+03	26000.00
448F03	2017-07-13 21:00:00+03	65000.00
448F3D	2017-07-30 00:24:00+03	50600.00
448FB8	2017-07-29 17:17:00+03	50600.00
448FDF	2017-07-20 11:04:00+03	10600.00
449014	2017-08-05 19:18:00+03	18600.00
449076	2017-08-01 07:15:00+03	34000.00
4490F7	2017-08-14 08:41:00+03	38800.00
449101	2017-08-03 20:50:00+03	51900.00
449205	2017-07-24 08:19:00+03	88600.00
44921A	2017-07-21 06:18:00+03	10800.00
44922A	2017-08-02 18:17:00+03	99200.00
44925B	2017-07-05 03:37:00+03	43200.00
449333	2017-08-15 08:05:00+03	29500.00
449347	2017-07-29 05:00:00+03	55800.00
449352	2017-08-01 07:13:00+03	135400.00
449377	2017-07-28 14:06:00+03	369000.00
44937D	2017-08-05 22:33:00+03	22000.00
4493BA	2017-07-19 20:32:00+03	254900.00
4493DA	2017-08-03 01:52:00+03	169900.00
44941E	2017-08-01 19:58:00+03	70800.00
449455	2017-07-13 08:43:00+03	75800.00
44947B	2017-07-27 15:01:00+03	63500.00
4494A0	2017-08-04 21:47:00+03	16400.00
4494C9	2017-07-11 22:22:00+03	75300.00
4494DC	2017-07-10 13:52:00+03	144400.00
44952C	2017-07-07 20:45:00+03	311200.00
44957E	2017-07-18 04:56:00+03	48800.00
449605	2017-07-27 18:59:00+03	100600.00
44961C	2017-07-23 13:16:00+03	50400.00
449649	2017-07-07 04:21:00+03	49100.00
4496AF	2017-07-18 11:05:00+03	23600.00
4496C6	2017-08-13 08:26:00+03	25900.00
4496F6	2017-07-07 07:48:00+03	32700.00
449701	2017-08-13 13:36:00+03	25000.00
44972E	2017-07-03 12:04:00+03	23200.00
449752	2017-07-13 18:19:00+03	65600.00
44981B	2017-07-13 18:21:00+03	43400.00
449836	2017-07-06 08:50:00+03	89700.00
44983C	2017-07-01 10:39:00+03	98600.00
44984C	2017-07-16 12:31:00+03	114800.00
44987F	2017-07-21 05:29:00+03	130300.00
449974	2017-07-14 01:20:00+03	42000.00
44997C	2017-07-05 00:04:00+03	25600.00
44998F	2017-07-08 19:22:00+03	28800.00
4499E1	2017-08-03 09:26:00+03	53400.00
449A5A	2017-07-14 05:25:00+03	66000.00
449A70	2017-07-22 20:41:00+03	47600.00
449B7C	2017-07-01 00:26:00+03	23200.00
449C5E	2017-08-01 23:12:00+03	62000.00
449C81	2017-07-04 09:42:00+03	16400.00
449CC9	2017-07-12 03:10:00+03	60000.00
449CE4	2017-08-08 01:34:00+03	182100.00
449CF3	2017-06-29 17:08:00+03	173600.00
449D10	2017-08-12 07:58:00+03	22000.00
449D48	2017-07-17 03:06:00+03	47000.00
449D58	2017-08-10 03:42:00+03	24700.00
449D82	2017-07-04 19:09:00+03	23200.00
449E88	2017-08-12 06:43:00+03	484300.00
449EAE	2017-07-14 13:27:00+03	16400.00
449EC9	2017-07-12 23:51:00+03	113700.00
449ED6	2017-08-06 01:56:00+03	110300.00
449F09	2017-07-19 01:31:00+03	28800.00
449F36	2017-07-09 13:28:00+03	26800.00
449F9B	2017-08-15 09:29:00+03	123000.00
449FB4	2017-07-08 00:54:00+03	28000.00
449FF7	2017-07-19 02:18:00+03	19000.00
44A009	2017-07-13 20:45:00+03	21400.00
44A016	2017-08-08 19:41:00+03	64300.00
44A055	2017-07-29 01:51:00+03	56000.00
44A08D	2017-07-08 13:06:00+03	23400.00
44A0B9	2017-07-31 04:02:00+03	10700.00
44A1D4	2017-07-04 20:14:00+03	38600.00
44A307	2017-07-12 05:39:00+03	30000.00
44A333	2017-07-29 11:50:00+03	52400.00
44A446	2017-07-30 05:32:00+03	266400.00
44A499	2017-07-06 23:02:00+03	29400.00
44A4EC	2017-07-17 11:46:00+03	18300.00
44A4EE	2017-07-26 20:19:00+03	135000.00
44A4F1	2017-07-06 00:54:00+03	16400.00
44A513	2017-08-08 20:48:00+03	60700.00
44A558	2017-07-11 23:31:00+03	24000.00
44A682	2017-07-19 08:14:00+03	95400.00
44A73E	2017-08-14 18:09:00+03	10800.00
44A76A	2017-08-04 13:41:00+03	166100.00
44A76C	2017-07-12 02:18:00+03	118400.00
44A77B	2017-08-09 21:21:00+03	65000.00
44A794	2017-07-09 13:54:00+03	84100.00
44A7A0	2017-07-06 05:58:00+03	12600.00
44A7B0	2017-07-27 15:35:00+03	117700.00
44A7F2	2017-07-21 18:13:00+03	56000.00
44A824	2017-07-06 17:06:00+03	43500.00
44A840	2017-07-24 03:30:00+03	139100.00
44A850	2017-08-05 15:26:00+03	133200.00
44A895	2017-07-23 17:00:00+03	57300.00
44A8CF	2017-07-19 11:24:00+03	744900.00
44A912	2017-08-01 07:36:00+03	92600.00
44A917	2017-07-04 21:50:00+03	24400.00
44A94B	2017-07-07 15:27:00+03	49000.00
44A958	2017-07-11 10:35:00+03	46000.00
44A96F	2017-08-05 11:32:00+03	81300.00
44A986	2017-07-19 05:56:00+03	62800.00
44AA48	2017-08-10 17:16:00+03	58800.00
44AA55	2017-08-14 07:01:00+03	273600.00
44AA6B	2017-07-18 13:33:00+03	55800.00
44AAC4	2017-07-06 09:12:00+03	27400.00
44AAEC	2017-07-10 05:36:00+03	54500.00
44AB26	2017-08-13 10:30:00+03	78000.00
44ABF7	2017-08-07 12:06:00+03	40400.00
44AC2B	2017-07-21 06:07:00+03	30200.00
44AC33	2017-07-02 10:38:00+03	57800.00
44AC35	2017-07-03 11:52:00+03	100400.00
44AC39	2017-07-16 23:00:00+03	26000.00
44ACA9	2017-06-30 03:07:00+03	59200.00
44ACEC	2017-08-06 20:09:00+03	16400.00
44AD03	2017-07-13 15:03:00+03	29600.00
44AD6B	2017-07-01 02:34:00+03	111600.00
44AD9B	2017-07-07 23:54:00+03	51900.00
44AE77	2017-07-14 13:10:00+03	87200.00
44AECA	2017-07-03 13:20:00+03	123000.00
44AF04	2017-07-29 23:45:00+03	56000.00
44AF12	2017-08-12 08:22:00+03	291600.00
44AF1E	2017-08-12 18:41:00+03	496600.00
44AF31	2017-08-12 07:42:00+03	18400.00
44B01F	2017-08-15 01:03:00+03	246000.00
44B067	2017-08-06 20:16:00+03	40100.00
44B0B5	2017-07-20 21:28:00+03	139300.00
44B0DC	2017-07-02 00:44:00+03	16000.00
44B0E8	2017-08-13 22:31:00+03	27900.00
44B10B	2017-07-22 19:42:00+03	99300.00
44B16B	2017-06-30 03:32:00+03	135600.00
44B1EB	2017-07-14 14:26:00+03	101600.00
44B1ED	2017-08-14 00:14:00+03	14000.00
44B204	2017-07-08 05:41:00+03	58800.00
44B23C	2017-07-04 07:59:00+03	7400.00
44B26B	2017-07-15 13:47:00+03	28800.00
44B2F2	2017-07-11 03:35:00+03	89700.00
44B352	2017-08-04 11:47:00+03	51300.00
44B370	2017-07-06 03:18:00+03	73600.00
44B3AB	2017-07-05 03:12:00+03	53300.00
44B41B	2017-08-03 15:08:00+03	36200.00
44B51A	2017-07-22 20:16:00+03	266400.00
44B559	2017-07-18 22:15:00+03	151000.00
44B55D	2017-07-25 06:35:00+03	50100.00
44B57A	2017-07-12 00:30:00+03	39500.00
44B617	2017-07-31 02:34:00+03	57500.00
44B62B	2017-06-30 04:30:00+03	88800.00
44B63F	2017-07-30 17:05:00+03	83600.00
44B65C	2017-07-12 17:01:00+03	48800.00
44B69C	2017-07-14 16:44:00+03	94700.00
44B6D9	2017-06-28 02:23:00+03	6300.00
44B71F	2017-07-08 05:50:00+03	6800.00
44B750	2017-08-10 05:25:00+03	55800.00
44B7A7	2017-07-01 03:16:00+03	31400.00
44B7F7	2017-06-30 18:27:00+03	47000.00
44B817	2017-07-29 06:47:00+03	46400.00
44B885	2017-07-06 02:20:00+03	135200.00
44B8A1	2017-06-30 03:58:00+03	90000.00
44B8A5	2017-07-28 21:56:00+03	51900.00
44B8B1	2017-08-12 23:40:00+03	34000.00
44B8EA	2017-07-15 16:37:00+03	36800.00
44B912	2017-08-05 21:15:00+03	75300.00
44B970	2017-08-06 12:10:00+03	24000.00
44B9D3	2017-08-05 04:15:00+03	25300.00
44B9D6	2017-07-06 03:32:00+03	6000.00
44BABA	2017-07-09 02:01:00+03	25600.00
44BAC3	2017-07-27 21:16:00+03	57600.00
44BAE8	2017-08-10 15:12:00+03	96200.00
44BB15	2017-08-14 11:58:00+03	135300.00
44BB38	2017-08-14 14:40:00+03	38400.00
44BB85	2017-07-19 18:49:00+03	29100.00
44BBA2	2017-08-01 17:02:00+03	92800.00
44BBE2	2017-06-29 07:56:00+03	93600.00
44BC78	2017-07-27 23:30:00+03	26700.00
44BC83	2017-07-18 21:27:00+03	44000.00
44BCA9	2017-08-12 22:46:00+03	44800.00
44BCD3	2017-07-25 11:20:00+03	56000.00
44BCFD	2017-07-29 23:11:00+03	46400.00
44BD0F	2017-07-21 21:14:00+03	165500.00
44BD74	2017-08-04 00:32:00+03	12200.00
44BD83	2017-07-22 17:25:00+03	273400.00
44BDF2	2017-08-14 09:26:00+03	25100.00
44BE97	2017-07-25 02:22:00+03	30200.00
44BEB5	2017-08-08 04:55:00+03	410400.00
44BF03	2017-08-07 22:42:00+03	98300.00
44BF61	2017-08-12 01:19:00+03	12000.00
44BF89	2017-07-09 10:02:00+03	74500.00
44BF96	2017-07-21 18:22:00+03	81900.00
44C02B	2017-07-12 02:48:00+03	115300.00
44C04A	2017-08-11 16:12:00+03	24400.00
44C05B	2017-08-07 12:17:00+03	89600.00
44C0AC	2017-06-30 05:11:00+03	11600.00
44C150	2017-07-17 06:49:00+03	12600.00
44C156	2017-07-18 15:24:00+03	7300.00
44C1C1	2017-07-13 02:05:00+03	12400.00
44C1C5	2017-07-14 09:04:00+03	46400.00
44C1DD	2017-08-10 19:33:00+03	369000.00
44C1F9	2017-07-12 05:40:00+03	111600.00
44C217	2017-08-14 02:38:00+03	27800.00
44C260	2017-07-14 15:25:00+03	92800.00
44C2EE	2017-07-16 15:42:00+03	21400.00
44C38C	2017-08-01 04:54:00+03	28800.00
44C3E0	2017-07-19 00:35:00+03	6300.00
44C3EE	2017-08-07 18:06:00+03	28000.00
44C415	2017-07-05 04:39:00+03	135400.00
44C445	2017-07-05 07:15:00+03	27400.00
44C4A0	2017-07-02 18:19:00+03	28000.00
44C4A7	2017-07-06 09:15:00+03	21200.00
44C4D2	2017-07-17 07:17:00+03	12400.00
44C4E1	2017-08-10 12:15:00+03	23400.00
44C50B	2017-08-06 10:46:00+03	141600.00
44C5C0	2017-08-08 13:47:00+03	55800.00
44C6CF	2017-07-21 01:04:00+03	9200.00
44C6D0	2017-07-12 11:10:00+03	14000.00
44C6E0	2017-07-19 06:52:00+03	34600.00
44C6F9	2017-07-24 06:52:00+03	7200.00
44C737	2017-07-12 19:51:00+03	103600.00
44C746	2017-07-16 02:10:00+03	124300.00
44C764	2017-06-30 19:30:00+03	26700.00
44C785	2017-07-03 15:14:00+03	85200.00
44C7A2	2017-08-03 09:55:00+03	56000.00
44C836	2017-06-28 07:27:00+03	166000.00
44C83D	2017-07-21 09:30:00+03	40200.00
44C858	2017-08-01 15:05:00+03	47000.00
44C935	2017-07-23 01:54:00+03	24600.00
44C937	2017-08-02 17:05:00+03	79600.00
44C988	2017-07-04 10:40:00+03	193100.00
44C9A3	2017-07-08 14:10:00+03	39200.00
44C9FC	2017-08-03 18:29:00+03	188000.00
44CA07	2017-08-03 00:22:00+03	131100.00
44CA1A	2017-07-21 13:33:00+03	28000.00
44CA61	2017-07-01 20:39:00+03	170500.00
44CA65	2017-07-19 05:14:00+03	14000.00
44CAAE	2017-07-23 01:37:00+03	233000.00
44CAF9	2017-08-14 16:05:00+03	26700.00
44CB64	2017-07-11 13:00:00+03	136500.00
44CB70	2017-07-08 06:13:00+03	38600.00
44CB95	2017-07-09 03:30:00+03	96200.00
44CBFF	2017-08-14 16:46:00+03	112000.00
44CC02	2017-07-17 07:06:00+03	8200.00
44CC1C	2017-07-17 17:02:00+03	26800.00
44CD31	2017-07-21 08:39:00+03	54500.00
44CD94	2017-07-22 10:22:00+03	153300.00
44CD97	2017-07-22 07:20:00+03	27200.00
44CDB2	2017-08-15 07:22:00+03	26000.00
44CDB6	2017-07-16 19:34:00+03	36700.00
44CDD2	2017-07-16 08:34:00+03	61500.00
44CDD6	2017-08-10 00:58:00+03	70200.00
44CDE5	2017-07-30 10:53:00+03	19600.00
44CDFE	2017-07-04 13:15:00+03	92700.00
44CE34	2017-08-08 21:42:00+03	83500.00
44CE87	2017-07-13 05:24:00+03	44700.00
44CE99	2017-07-08 18:15:00+03	71400.00
44CFFF	2017-06-29 11:00:00+03	136200.00
44D056	2017-07-30 12:19:00+03	97900.00
44D059	2017-07-26 15:46:00+03	57500.00
44D0BD	2017-06-28 03:58:00+03	42800.00
44D0E9	2017-07-08 16:30:00+03	210800.00
44D14E	2017-08-10 07:52:00+03	70400.00
44D177	2017-08-13 03:05:00+03	199800.00
44D17C	2017-07-15 06:49:00+03	52300.00
44D1E7	2017-07-16 08:06:00+03	12600.00
44D234	2017-07-24 22:07:00+03	92800.00
44D283	2017-08-15 11:53:00+03	135400.00
44D286	2017-07-31 02:15:00+03	15900.00
44D38F	2017-08-05 18:02:00+03	6000.00
44D39E	2017-08-05 14:33:00+03	24700.00
44D3A3	2017-07-03 10:29:00+03	69700.00
44D3A4	2017-07-28 01:15:00+03	173500.00
44D49C	2017-08-11 05:00:00+03	52900.00
44D4D2	2017-07-07 13:25:00+03	27200.00
44D4FD	2017-08-15 09:54:00+03	84500.00
44D5D5	2017-08-06 04:56:00+03	27800.00
44D6B7	2017-07-15 05:50:00+03	26000.00
44D771	2017-07-09 23:50:00+03	56000.00
44D786	2017-08-12 17:32:00+03	111600.00
44D78C	2017-08-01 22:48:00+03	27200.00
44D799	2017-07-12 16:21:00+03	47900.00
44D833	2017-07-01 04:33:00+03	20400.00
44D867	2017-08-13 02:27:00+03	12600.00
44D86D	2017-07-07 23:12:00+03	12600.00
44D8A6	2017-08-07 03:41:00+03	31000.00
44D8F1	2017-07-19 12:34:00+03	53600.00
44D946	2017-07-22 13:27:00+03	133200.00
44D9BB	2017-07-29 09:49:00+03	24200.00
44D9F1	2017-07-27 23:35:00+03	143200.00
44DA6D	2017-08-01 05:51:00+03	45200.00
44DB03	2017-08-06 05:47:00+03	26800.00
44DB05	2017-07-18 14:13:00+03	99200.00
44DB45	2017-07-18 18:40:00+03	21400.00
44DB50	2017-08-13 01:35:00+03	13000.00
44DBA2	2017-07-31 21:35:00+03	50800.00
44DBCA	2017-07-08 11:20:00+03	343900.00
44DC23	2017-07-23 06:24:00+03	25400.00
44DC2F	2017-07-02 13:34:00+03	73100.00
44DC32	2017-08-07 18:30:00+03	39300.00
44DC94	2017-06-29 02:12:00+03	30200.00
44DC9A	2017-07-28 18:11:00+03	51600.00
44DCD5	2017-07-03 04:09:00+03	52300.00
44DCE1	2017-07-24 10:56:00+03	40600.00
44DD27	2017-08-11 22:04:00+03	38600.00
44DDE8	2017-07-31 03:59:00+03	103500.00
44DE30	2017-07-30 07:41:00+03	15000.00
44DF0E	2017-08-11 05:19:00+03	40800.00
44DF49	2017-07-07 13:58:00+03	16400.00
44DF9B	2017-07-07 01:49:00+03	20400.00
44DFA9	2017-07-10 23:50:00+03	203000.00
44E0A5	2017-07-22 06:23:00+03	99300.00
44E127	2017-08-01 00:37:00+03	85800.00
44E15E	2017-07-19 17:00:00+03	6700.00
44E222	2017-07-14 13:01:00+03	136200.00
44E294	2017-07-28 19:26:00+03	102300.00
44E295	2017-06-29 19:30:00+03	40000.00
44E2A4	2017-08-06 20:05:00+03	37900.00
44E2F1	2017-07-24 04:51:00+03	14000.00
44E30D	2017-07-09 06:13:00+03	133900.00
44E336	2017-07-25 09:41:00+03	191400.00
44E33C	2017-07-07 12:54:00+03	43900.00
44E398	2017-07-18 07:42:00+03	13700.00
44E39B	2017-07-14 04:00:00+03	59300.00
44E479	2017-08-01 05:06:00+03	266400.00
44E52C	2017-08-02 17:42:00+03	466000.00
44E56C	2017-08-15 02:23:00+03	111600.00
44E5A8	2017-08-09 04:36:00+03	69800.00
44E62E	2017-07-18 04:03:00+03	36000.00
44E642	2017-08-09 12:54:00+03	58800.00
44E64A	2017-08-08 14:19:00+03	43200.00
44E6CA	2017-07-18 10:47:00+03	114700.00
44E6E3	2017-08-01 15:53:00+03	58000.00
44E6EA	2017-07-29 00:12:00+03	6000.00
44E74B	2017-08-10 22:58:00+03	118100.00
44E764	2017-08-04 03:34:00+03	123000.00
44E773	2017-07-02 06:54:00+03	22000.00
44E7D5	2017-07-18 13:03:00+03	123000.00
44E8E1	2017-08-08 11:02:00+03	7400.00
44E8F8	2017-07-16 07:32:00+03	38800.00
44E90B	2017-07-03 17:41:00+03	44800.00
44E90C	2017-08-05 13:56:00+03	147700.00
44E926	2017-08-14 07:09:00+03	54800.00
44EA31	2017-07-03 12:11:00+03	93900.00
44EA4A	2017-08-10 17:17:00+03	131100.00
44EA4D	2017-07-03 11:55:00+03	65700.00
44EA77	2017-06-30 01:34:00+03	51800.00
44EAA7	2017-07-28 13:00:00+03	36800.00
44EAB8	2017-07-21 17:23:00+03	113000.00
44EABC	2017-08-15 00:30:00+03	117600.00
44EB5E	2017-08-10 11:06:00+03	47600.00
44EB71	2017-07-16 09:09:00+03	25200.00
44EB94	2017-08-08 12:39:00+03	532800.00
44EC87	2017-07-27 15:38:00+03	41600.00
44ECA1	2017-07-16 23:56:00+03	6700.00
44ECD3	2017-07-23 01:27:00+03	124300.00
44ECF6	2017-07-25 19:47:00+03	27200.00
44ECFD	2017-07-11 20:39:00+03	57400.00
44ED64	2017-08-05 12:17:00+03	52300.00
44ED6A	2017-08-11 23:08:00+03	40800.00
44ED70	2017-07-15 21:59:00+03	30000.00
44EDBB	2017-08-12 07:47:00+03	58000.00
44EDD1	2017-08-02 01:52:00+03	155600.00
44EDE3	2017-07-16 04:49:00+03	46300.00
44EDE5	2017-07-07 02:50:00+03	112600.00
44EEA9	2017-08-03 22:38:00+03	90800.00
44EED5	2017-08-11 14:01:00+03	57400.00
44EF1D	2017-07-29 06:46:00+03	43400.00
44EF5E	2017-08-09 17:00:00+03	56000.00
44F09F	2017-08-09 13:17:00+03	43700.00
44F160	2017-07-11 13:00:00+03	28000.00
44F169	2017-08-03 04:54:00+03	55800.00
44F192	2017-07-17 00:46:00+03	6300.00
44F22A	2017-07-25 02:28:00+03	26000.00
44F34E	2017-08-04 14:05:00+03	29500.00
44F366	2017-07-13 18:42:00+03	64200.00
44F388	2017-08-15 11:32:00+03	28800.00
44F421	2017-08-15 05:22:00+03	41500.00
44F432	2017-07-27 14:04:00+03	24200.00
44F45A	2017-07-23 20:39:00+03	639000.00
44F4CC	2017-07-09 13:46:00+03	101200.00
44F4DC	2017-07-02 19:40:00+03	21500.00
44F4E7	2017-08-13 22:46:00+03	38200.00
44F547	2017-07-08 21:45:00+03	185300.00
44F55B	2017-08-11 17:00:00+03	31600.00
44F60C	2017-08-13 22:32:00+03	269400.00
44F662	2017-07-27 00:32:00+03	109000.00
44F6E6	2017-07-03 14:56:00+03	111600.00
44F6E9	2017-08-09 03:04:00+03	29600.00
44F709	2017-07-12 09:50:00+03	37900.00
44F711	2017-07-11 23:33:00+03	47000.00
44F722	2017-07-10 11:14:00+03	94700.00
44F748	2017-08-07 12:09:00+03	14000.00
44F76F	2017-07-19 10:50:00+03	89600.00
44F7AC	2017-07-28 15:56:00+03	92700.00
44F865	2017-07-04 22:47:00+03	92900.00
44F880	2017-08-04 18:56:00+03	249100.00
44F89E	2017-08-15 01:25:00+03	84100.00
44F8D6	2017-07-23 20:05:00+03	56000.00
44F8E9	2017-07-01 17:29:00+03	73200.00
44F8FF	2017-07-23 06:08:00+03	51900.00
44F905	2017-07-21 18:05:00+03	99300.00
44F92B	2017-07-01 20:25:00+03	93900.00
44F96F	2017-07-21 21:34:00+03	24800.00
44FA32	2017-07-08 07:40:00+03	89600.00
44FA95	2017-08-11 13:01:00+03	44000.00
44FADF	2017-07-30 12:47:00+03	95000.00
44FB2A	2017-07-03 02:29:00+03	124200.00
44FB3B	2017-06-29 20:10:00+03	187600.00
44FB3C	2017-07-15 01:55:00+03	84500.00
44FB87	2017-07-31 15:44:00+03	266400.00
44FB89	2017-08-15 16:14:00+03	48400.00
44FBA7	2017-07-29 21:49:00+03	7400.00
44FC46	2017-07-18 20:13:00+03	178800.00
44FC76	2017-08-01 03:22:00+03	265600.00
44FC9A	2017-07-02 03:26:00+03	103400.00
44FCA9	2017-07-07 12:14:00+03	56900.00
44FCB3	2017-08-10 05:12:00+03	19000.00
44FCB4	2017-07-10 00:53:00+03	386300.00
44FCEF	2017-07-14 04:02:00+03	85700.00
44FD0A	2017-07-03 23:49:00+03	79600.00
44FDC4	2017-07-13 07:49:00+03	40800.00
44FDE0	2017-07-14 14:40:00+03	44000.00
44FDEA	2017-07-30 18:57:00+03	116000.00
44FE22	2017-06-30 09:30:00+03	55800.00
44FE36	2017-06-30 04:08:00+03	37200.00
44FE4B	2017-08-05 14:31:00+03	92400.00
44FE9E	2017-08-06 04:05:00+03	57900.00
44FED1	2017-07-27 21:47:00+03	123000.00
44FEE3	2017-08-14 05:35:00+03	147700.00
44FEF2	2017-07-10 05:52:00+03	46300.00
44FF7D	2017-07-28 16:31:00+03	37200.00
44FF7E	2017-07-23 16:10:00+03	99600.00
44FFA0	2017-07-07 17:14:00+03	29600.00
450002	2017-07-09 20:46:00+03	131600.00
45000E	2017-07-27 08:42:00+03	34000.00
4500CE	2017-08-14 12:54:00+03	209100.00
4500FA	2017-07-04 07:03:00+03	62000.00
45016B	2017-07-10 11:50:00+03	182300.00
450174	2017-08-14 15:04:00+03	17000.00
450195	2017-07-30 07:00:00+03	23200.00
4501E1	2017-07-21 23:09:00+03	46300.00
450210	2017-08-12 15:17:00+03	119500.00
450223	2017-07-08 08:48:00+03	45500.00
4502B0	2017-07-12 23:16:00+03	34800.00
4502B3	2017-07-01 23:36:00+03	18800.00
45031E	2017-07-25 17:31:00+03	26800.00
450388	2017-07-30 01:12:00+03	125400.00
450392	2017-06-29 21:32:00+03	6600.00
45044A	2017-07-09 12:32:00+03	33800.00
45045C	2017-07-10 20:23:00+03	290500.00
450512	2017-07-23 12:41:00+03	43500.00
450534	2017-07-28 11:05:00+03	26000.00
450631	2017-06-30 21:02:00+03	123000.00
450685	2017-08-07 17:33:00+03	47200.00
45068A	2017-08-05 08:57:00+03	28000.00
450691	2017-07-01 04:24:00+03	6000.00
450698	2017-07-05 06:21:00+03	56000.00
45069C	2017-07-30 15:52:00+03	87900.00
4506CC	2017-07-06 20:04:00+03	46400.00
4506EA	2017-07-02 02:09:00+03	99300.00
4506ED	2017-06-30 16:33:00+03	46000.00
45070F	2017-08-02 16:04:00+03	65900.00
45073D	2017-07-24 13:56:00+03	32800.00
45078B	2017-07-10 03:07:00+03	43500.00
45078C	2017-07-04 00:40:00+03	61800.00
45079E	2017-07-21 16:14:00+03	199700.00
4507E1	2017-08-04 13:48:00+03	48800.00
4507EA	2017-08-09 16:02:00+03	67700.00
4507EF	2017-06-30 04:35:00+03	18000.00
450854	2017-08-11 09:04:00+03	120700.00
450871	2017-08-01 04:46:00+03	146400.00
4508D5	2017-08-01 05:26:00+03	26600.00
450970	2017-07-15 08:12:00+03	120900.00
450978	2017-07-27 19:00:00+03	211500.00
450994	2017-07-22 09:59:00+03	133100.00
450A8C	2017-07-23 21:17:00+03	13700.00
450AFF	2017-08-14 08:27:00+03	66000.00
450B06	2017-08-03 04:40:00+03	492000.00
450B21	2017-06-30 02:12:00+03	118000.00
450B23	2017-08-04 13:51:00+03	126700.00
450B39	2017-07-24 16:53:00+03	189700.00
450B4E	2017-07-12 04:30:00+03	132000.00
450B83	2017-07-26 20:35:00+03	27600.00
450B92	2017-07-11 14:18:00+03	194300.00
450C08	2017-07-14 17:10:00+03	89700.00
450C43	2017-07-14 17:34:00+03	75300.00
450C57	2017-08-11 08:30:00+03	46400.00
450C5B	2017-08-10 22:45:00+03	89700.00
450CD6	2017-08-15 13:06:00+03	35600.00
450CEA	2017-07-25 07:09:00+03	46400.00
450CED	2017-07-12 15:22:00+03	29200.00
450D2B	2017-07-13 15:08:00+03	59100.00
450D2D	2017-08-03 21:33:00+03	111600.00
450D54	2017-07-26 17:54:00+03	86800.00
450DB8	2017-07-16 22:08:00+03	144700.00
450E25	2017-07-12 18:24:00+03	273000.00
450E7D	2017-07-30 16:16:00+03	53600.00
450F98	2017-07-12 22:34:00+03	28000.00
450FB2	2017-07-26 07:45:00+03	89200.00
450FC6	2017-07-21 15:32:00+03	30200.00
451049	2017-08-13 20:28:00+03	57100.00
45104B	2017-07-16 02:24:00+03	26000.00
45109D	2017-07-10 06:50:00+03	6300.00
45109E	2017-07-03 13:12:00+03	92000.00
451124	2017-07-09 14:07:00+03	74900.00
45117B	2017-08-15 15:54:00+03	67600.00
4511D3	2017-07-22 03:52:00+03	94700.00
4511F5	2017-07-09 16:56:00+03	148200.00
451216	2017-07-21 23:41:00+03	11600.00
451230	2017-07-07 11:02:00+03	102100.00
451247	2017-07-31 23:47:00+03	27800.00
451255	2017-07-08 00:17:00+03	29400.00
45128A	2017-08-04 22:49:00+03	31400.00
4512A1	2017-07-05 02:53:00+03	38600.00
4512FF	2017-07-29 11:14:00+03	67600.00
451386	2017-07-24 05:56:00+03	92400.00
4513B4	2017-07-30 14:28:00+03	220200.00
4513FB	2017-07-03 14:22:00+03	6000.00
451411	2017-07-29 21:19:00+03	28200.00
4514AF	2017-07-20 10:22:00+03	51200.00
4514C5	2017-07-26 21:02:00+03	29400.00
451505	2017-08-12 06:26:00+03	16400.00
451586	2017-08-05 10:56:00+03	136800.00
4515B2	2017-07-06 05:12:00+03	61800.00
4516AA	2017-08-08 16:39:00+03	133200.00
4516E1	2017-08-08 20:12:00+03	57400.00
4516FA	2017-07-11 11:53:00+03	69500.00
45176C	2017-08-07 15:12:00+03	28800.00
4517B1	2017-08-15 09:44:00+03	113500.00
4517C2	2017-07-22 00:57:00+03	99700.00
4517D6	2017-07-11 23:41:00+03	14300.00
4517FA	2017-08-10 23:10:00+03	248400.00
45184B	2017-07-12 16:48:00+03	501200.00
451888	2017-08-11 15:51:00+03	186100.00
45189C	2017-07-27 07:37:00+03	24400.00
4518D8	2017-08-02 15:57:00+03	49200.00
451987	2017-07-06 12:10:00+03	64600.00
451A52	2017-08-04 05:09:00+03	75300.00
451A9D	2017-08-13 05:33:00+03	87000.00
451AA3	2017-08-09 16:41:00+03	52000.00
451AB5	2017-08-04 11:11:00+03	113100.00
451B05	2017-06-26 00:43:00+03	29200.00
451B1E	2017-07-21 18:29:00+03	86600.00
451B34	2017-07-03 17:07:00+03	16400.00
451B47	2017-07-09 18:30:00+03	37700.00
451C40	2017-07-18 02:22:00+03	36400.00
451C61	2017-07-18 08:48:00+03	45100.00
451CA6	2017-08-04 12:00:00+03	123000.00
451CA9	2017-07-25 07:26:00+03	90000.00
451CD5	2017-07-03 13:02:00+03	62600.00
451D41	2017-08-12 17:38:00+03	35800.00
451D4E	2017-07-02 06:36:00+03	52000.00
451D64	2017-08-09 01:58:00+03	96800.00
451DF3	2017-08-13 07:06:00+03	126600.00
451E47	2017-06-28 05:58:00+03	37200.00
451E92	2017-08-01 00:58:00+03	39800.00
451E9C	2017-06-30 05:12:00+03	47100.00
451F27	2017-07-23 11:31:00+03	48800.00
451F65	2017-07-13 20:35:00+03	29400.00
451FBB	2017-07-24 23:06:00+03	18600.00
451FC3	2017-08-03 05:17:00+03	45500.00
452042	2017-08-11 09:31:00+03	117200.00
452090	2017-07-04 18:34:00+03	139800.00
4520AD	2017-07-07 13:52:00+03	65100.00
4520CE	2017-07-16 17:53:00+03	111600.00
45210A	2017-07-25 11:57:00+03	35800.00
452195	2017-07-23 15:59:00+03	64700.00
4521DC	2017-08-11 08:27:00+03	7400.00
4521E2	2017-07-02 02:52:00+03	49400.00
452254	2017-08-04 14:07:00+03	14400.00
452316	2017-08-12 10:49:00+03	97600.00
4523D0	2017-08-11 10:39:00+03	43600.00
4523F2	2017-07-17 16:52:00+03	31600.00
452484	2017-07-04 19:18:00+03	185300.00
4524F0	2017-08-03 16:27:00+03	46000.00
45251D	2017-08-09 11:08:00+03	40000.00
4525D4	2017-07-01 11:06:00+03	59800.00
45261E	2017-07-09 05:37:00+03	6800.00
452633	2017-07-21 14:41:00+03	36800.00
452669	2017-07-27 12:47:00+03	26800.00
452671	2017-07-13 05:40:00+03	86400.00
452728	2017-08-02 14:10:00+03	53200.00
452732	2017-07-06 17:45:00+03	46000.00
452738	2017-08-08 12:09:00+03	6700.00
452743	2017-07-06 21:59:00+03	54800.00
4527BB	2017-07-01 11:01:00+03	43400.00
4527EA	2017-08-01 10:42:00+03	123600.00
45282A	2017-06-30 11:08:00+03	119500.00
452847	2017-07-10 13:43:00+03	289800.00
452885	2017-08-04 13:22:00+03	51600.00
4528AF	2017-08-15 05:07:00+03	34000.00
4528D6	2017-07-19 00:53:00+03	46400.00
4528D9	2017-08-02 15:25:00+03	63200.00
4528FA	2017-08-05 01:22:00+03	89600.00
45290A	2017-08-07 06:35:00+03	97800.00
452925	2017-07-19 06:44:00+03	67600.00
45292A	2017-07-21 11:29:00+03	64200.00
45295C	2017-07-14 02:56:00+03	67700.00
452999	2017-08-11 09:01:00+03	94800.00
4529CB	2017-08-14 16:59:00+03	56000.00
452A64	2017-08-08 18:43:00+03	269900.00
452AC8	2017-07-09 18:59:00+03	189200.00
452AF3	2017-08-07 01:10:00+03	58000.00
452B3F	2017-07-06 07:19:00+03	69500.00
452B53	2017-07-25 07:29:00+03	44000.00
452B78	2017-08-10 23:41:00+03	34300.00
452C15	2017-08-10 21:42:00+03	104800.00
452C3A	2017-08-03 03:54:00+03	146300.00
452D23	2017-07-22 06:37:00+03	139400.00
452D43	2017-07-05 04:58:00+03	22000.00
452D4A	2017-07-11 02:07:00+03	124200.00
452D4D	2017-07-31 06:15:00+03	21800.00
452E5F	2017-08-11 16:31:00+03	94000.00
452E91	2017-07-28 20:13:00+03	30000.00
452ED6	2017-08-08 17:37:00+03	32400.00
452EE2	2017-07-25 20:43:00+03	13400.00
452EFB	2017-07-14 05:55:00+03	135400.00
452F23	2017-08-02 13:03:00+03	189800.00
452F2F	2017-07-13 06:27:00+03	174900.00
45301E	2017-08-13 03:21:00+03	30200.00
4530B6	2017-07-08 07:03:00+03	89700.00
4530CD	2017-07-06 17:00:00+03	39800.00
4530FA	2017-07-20 14:53:00+03	41800.00
45314A	2017-07-13 17:57:00+03	40800.00
4531A1	2017-07-25 01:47:00+03	38800.00
4531E3	2017-06-30 01:56:00+03	66100.00
4531EC	2017-08-01 21:48:00+03	49200.00
4531F6	2017-07-15 02:57:00+03	124200.00
45323A	2017-07-11 01:16:00+03	8200.00
453299	2017-07-25 00:11:00+03	88500.00
4532E4	2017-08-15 03:51:00+03	16800.00
4532F5	2017-07-31 11:51:00+03	27800.00
453390	2017-07-06 15:15:00+03	21800.00
4533A9	2017-07-05 22:28:00+03	43200.00
4533CE	2017-07-24 18:19:00+03	14000.00
453421	2017-07-23 05:49:00+03	124200.00
45345A	2017-07-24 00:06:00+03	203600.00
4534B9	2017-07-20 01:35:00+03	130000.00
4534D1	2017-07-03 04:56:00+03	294400.00
4534F5	2017-07-07 17:58:00+03	25800.00
453528	2017-08-03 09:18:00+03	6700.00
45353E	2017-07-18 10:54:00+03	44000.00
4535FD	2017-08-14 05:07:00+03	26000.00
45366D	2017-08-07 03:36:00+03	228900.00
453695	2017-08-03 13:21:00+03	25400.00
4536C8	2017-08-02 11:26:00+03	67500.00
4536E3	2017-08-14 23:52:00+03	39500.00
4536F6	2017-07-17 09:19:00+03	131600.00
45377A	2017-07-13 05:34:00+03	13400.00
4537A7	2017-07-05 08:58:00+03	16400.00
4537A8	2017-07-29 17:55:00+03	50700.00
45386B	2017-07-27 10:51:00+03	30800.00
4538D6	2017-08-11 03:53:00+03	74800.00
453902	2017-07-11 18:14:00+03	16400.00
45396D	2017-07-30 07:26:00+03	529200.00
453987	2017-08-10 21:27:00+03	81700.00
4539E6	2017-08-05 13:36:00+03	27000.00
4539F7	2017-07-18 21:13:00+03	164300.00
453A1B	2017-07-30 01:49:00+03	28000.00
453A6D	2017-07-16 17:10:00+03	32800.00
453A71	2017-08-04 11:18:00+03	53700.00
453A7F	2017-08-07 09:02:00+03	199400.00
453ACA	2017-07-25 11:11:00+03	55800.00
453AD7	2017-08-10 07:25:00+03	280200.00
453B54	2017-07-10 00:06:00+03	113800.00
453B80	2017-07-26 13:35:00+03	39300.00
453BBA	2017-07-10 02:17:00+03	12600.00
453BC5	2017-07-04 15:39:00+03	115600.00
453BF2	2017-08-10 05:03:00+03	79000.00
453C11	2017-07-30 13:30:00+03	47300.00
453C2C	2017-08-07 19:07:00+03	51900.00
453C43	2017-07-19 05:01:00+03	133200.00
453C75	2017-07-11 00:50:00+03	135400.00
453C86	2017-08-05 00:20:00+03	74800.00
453C9F	2017-08-15 09:40:00+03	97000.00
453CB4	2017-08-01 01:48:00+03	56000.00
453CBC	2017-08-13 08:16:00+03	160100.00
453D47	2017-07-26 22:34:00+03	76400.00
453D6B	2017-08-10 02:03:00+03	29600.00
453D77	2017-08-11 20:53:00+03	25600.00
453D7F	2017-07-11 02:46:00+03	28800.00
453D81	2017-08-14 12:55:00+03	6800.00
453DB7	2017-07-27 08:23:00+03	73900.00
453DD9	2017-08-13 03:41:00+03	66700.00
453E67	2017-06-30 17:50:00+03	47100.00
453E6E	2017-07-08 22:02:00+03	206700.00
453EA0	2017-07-07 13:52:00+03	89700.00
453F05	2017-07-28 03:52:00+03	38600.00
453F78	2017-07-01 02:26:00+03	111600.00
454003	2017-07-24 16:14:00+03	266400.00
454006	2017-07-18 03:48:00+03	92600.00
45401C	2017-07-01 11:55:00+03	196800.00
454053	2017-06-30 16:37:00+03	29400.00
45409E	2017-08-08 20:25:00+03	59300.00
4540F7	2017-08-07 21:54:00+03	83100.00
4540FF	2017-07-10 23:57:00+03	99200.00
454183	2017-07-02 15:33:00+03	48800.00
454188	2017-08-11 09:02:00+03	88200.00
454195	2017-07-26 11:29:00+03	28800.00
454197	2017-08-14 03:29:00+03	126400.00
45427C	2017-07-19 22:32:00+03	30200.00
454299	2017-08-10 17:57:00+03	67700.00
454312	2017-07-31 09:47:00+03	213200.00
45435A	2017-08-12 01:05:00+03	25200.00
45438B	2017-07-19 14:31:00+03	16400.00
454445	2017-07-02 15:58:00+03	30200.00
45448A	2017-07-31 20:58:00+03	128800.00
4545F6	2017-07-12 13:18:00+03	139400.00
454606	2017-08-14 01:07:00+03	37000.00
454686	2017-07-18 01:10:00+03	111600.00
4546B2	2017-08-07 23:17:00+03	56000.00
454721	2017-07-23 21:34:00+03	40200.00
45473D	2017-07-19 14:18:00+03	92000.00
454742	2017-07-25 15:32:00+03	138500.00
45475C	2017-07-15 13:56:00+03	291500.00
454785	2017-08-03 05:20:00+03	31900.00
45481A	2017-08-04 04:06:00+03	44200.00
454837	2017-07-26 22:17:00+03	84100.00
45487A	2017-07-12 19:16:00+03	8200.00
4548B0	2017-07-23 10:50:00+03	28300.00
4548D0	2017-06-30 14:07:00+03	36900.00
454932	2017-07-15 20:25:00+03	44000.00
45497D	2017-07-17 16:40:00+03	135400.00
454989	2017-07-28 05:05:00+03	85600.00
454992	2017-08-13 21:41:00+03	13900.00
4549E3	2017-07-27 12:50:00+03	60400.00
4549E4	2017-07-13 11:32:00+03	32800.00
454A08	2017-07-15 21:37:00+03	64800.00
454A36	2017-08-13 17:42:00+03	48800.00
454AAE	2017-08-03 21:58:00+03	126300.00
454AB1	2017-08-09 19:42:00+03	40600.00
454B39	2017-07-08 18:27:00+03	34000.00
454B43	2017-08-07 19:29:00+03	266900.00
454B8E	2017-08-05 22:33:00+03	16400.00
454BBC	2017-07-27 14:34:00+03	49800.00
454CB7	2017-08-07 08:52:00+03	46000.00
454CB9	2017-07-27 06:33:00+03	26800.00
454CBC	2017-07-20 03:11:00+03	13800.00
454CFD	2017-07-05 18:14:00+03	52300.00
454D09	2017-07-07 02:41:00+03	43900.00
454DA0	2017-08-13 17:38:00+03	48800.00
454DBF	2017-08-05 06:15:00+03	45200.00
454DC3	2017-07-09 11:18:00+03	106700.00
454DDE	2017-07-19 12:58:00+03	286100.00
454DF5	2017-08-07 20:19:00+03	47200.00
454E10	2017-08-06 12:40:00+03	196700.00
454E49	2017-07-04 05:46:00+03	86400.00
454E9B	2017-07-15 21:41:00+03	139000.00
454EA7	2017-08-10 14:19:00+03	123000.00
454EBF	2017-07-18 08:55:00+03	39500.00
454F06	2017-07-29 06:28:00+03	128800.00
454F23	2017-07-20 23:54:00+03	23400.00
454FB7	2017-08-01 00:32:00+03	131100.00
454FD5	2017-07-06 13:06:00+03	65800.00
454FED	2017-07-11 23:09:00+03	9200.00
455013	2017-08-02 12:38:00+03	246000.00
45515F	2017-07-20 05:22:00+03	286100.00
4551A2	2017-07-20 11:18:00+03	177600.00
4551D7	2017-07-11 23:01:00+03	46400.00
4551DA	2017-08-07 20:14:00+03	10600.00
4551E5	2017-07-15 16:08:00+03	186900.00
45526F	2017-07-24 20:06:00+03	52000.00
455299	2017-07-16 12:12:00+03	48700.00
4552BD	2017-08-10 20:37:00+03	26000.00
4552DB	2017-08-02 17:09:00+03	153600.00
455300	2017-07-30 10:49:00+03	55800.00
455358	2017-08-11 20:05:00+03	83000.00
455385	2017-08-08 01:49:00+03	46400.00
4553D3	2017-07-10 07:31:00+03	46300.00
455438	2017-07-11 04:08:00+03	75500.00
45548A	2017-07-31 08:49:00+03	25100.00
4554BC	2017-07-03 16:37:00+03	44800.00
4554D7	2017-08-05 09:09:00+03	90800.00
4554DB	2017-08-08 18:37:00+03	67700.00
45554B	2017-08-12 15:09:00+03	201200.00
455569	2017-07-13 10:41:00+03	132800.00
4555DE	2017-07-10 21:37:00+03	56100.00
4555E1	2017-07-07 02:11:00+03	112600.00
4555E5	2017-07-01 20:38:00+03	86300.00
45569E	2017-07-14 17:35:00+03	206800.00
4556B5	2017-07-11 06:40:00+03	54500.00
4556C9	2017-07-27 14:24:00+03	398500.00
4556DA	2017-08-04 15:37:00+03	74300.00
4556E1	2017-08-11 09:29:00+03	22600.00
455715	2017-07-04 17:58:00+03	27200.00
455730	2017-07-29 21:56:00+03	9300.00
45579B	2017-08-10 16:58:00+03	96300.00
4557A4	2017-06-29 04:45:00+03	46300.00
4557B4	2017-07-21 15:16:00+03	102000.00
4557E6	2017-08-02 00:49:00+03	56600.00
455812	2017-07-31 14:38:00+03	39800.00
455890	2017-08-13 20:34:00+03	57800.00
4558B2	2017-08-15 06:52:00+03	75800.00
4558EA	2017-07-11 13:05:00+03	44500.00
4559DD	2017-08-02 18:24:00+03	61900.00
455B1C	2017-07-25 00:33:00+03	25400.00
455B4E	2017-07-28 06:26:00+03	72400.00
455B92	2017-08-03 06:22:00+03	24400.00
455BA4	2017-07-15 03:07:00+03	43200.00
455BD4	2017-07-12 19:35:00+03	131600.00
455C27	2017-07-16 22:38:00+03	166900.00
455C2F	2017-07-29 18:54:00+03	21500.00
455C8A	2017-06-30 10:50:00+03	179400.00
455E19	2017-06-29 09:05:00+03	12400.00
455E43	2017-07-14 15:40:00+03	14800.00
455E62	2017-07-29 16:11:00+03	44700.00
455EAC	2017-08-14 10:44:00+03	26700.00
455EAF	2017-07-14 03:20:00+03	28800.00
455F44	2017-08-05 01:15:00+03	43800.00
455F73	2017-07-02 14:01:00+03	199700.00
455FD3	2017-07-02 09:06:00+03	53100.00
455FEA	2017-07-22 00:54:00+03	51300.00
45601E	2017-07-12 04:57:00+03	11800.00
45602C	2017-07-07 22:20:00+03	12100.00
45602E	2017-08-10 01:11:00+03	46700.00
4560A1	2017-07-15 08:12:00+03	55800.00
4560B3	2017-07-12 22:57:00+03	13400.00
4560E4	2017-08-09 17:18:00+03	133200.00
456105	2017-07-15 16:01:00+03	38400.00
456123	2017-07-02 20:16:00+03	67800.00
456150	2017-08-12 11:51:00+03	271200.00
4561B4	2017-08-14 10:04:00+03	79800.00
456212	2017-07-27 23:36:00+03	55500.00
456243	2017-07-23 07:44:00+03	6000.00
45627C	2017-07-15 07:11:00+03	65600.00
4562A6	2017-08-09 19:07:00+03	101200.00
4562BC	2017-07-21 11:30:00+03	492000.00
456302	2017-07-16 00:52:00+03	33400.00
456346	2017-07-07 17:36:00+03	25400.00
456349	2017-07-16 05:31:00+03	266300.00
456363	2017-07-08 02:57:00+03	134200.00
456368	2017-07-07 18:19:00+03	62200.00
456385	2017-07-10 02:24:00+03	26300.00
456396	2017-07-31 09:56:00+03	46000.00
4564E8	2017-07-21 17:00:00+03	112000.00
45655B	2017-07-28 04:36:00+03	66600.00
456579	2017-07-17 00:32:00+03	47200.00
45658B	2017-07-11 23:41:00+03	111600.00
4565CD	2017-08-10 17:19:00+03	117600.00
456609	2017-08-11 21:50:00+03	56000.00
45667F	2017-08-13 10:23:00+03	57600.00
4566AC	2017-07-25 06:52:00+03	78900.00
4566B7	2017-07-24 15:24:00+03	34400.00
45670A	2017-08-09 09:19:00+03	22400.00
4567DD	2017-08-01 15:08:00+03	54000.00
456871	2017-08-13 02:08:00+03	73500.00
456882	2017-07-27 07:35:00+03	25600.00
45688B	2017-07-26 10:28:00+03	258400.00
456906	2017-08-08 15:57:00+03	12400.00
456926	2017-07-20 05:24:00+03	97600.00
456959	2017-07-21 03:32:00+03	48100.00
45696A	2017-06-29 19:28:00+03	133100.00
4569D3	2017-07-09 17:00:00+03	119500.00
456A71	2017-08-13 00:34:00+03	114800.00
456B26	2017-07-07 23:06:00+03	266400.00
456B2E	2017-06-30 04:43:00+03	148200.00
456B56	2017-08-11 23:15:00+03	23400.00
456B94	2017-07-23 03:06:00+03	37500.00
456C5E	2017-07-25 18:29:00+03	202100.00
456CA6	2017-07-14 17:29:00+03	302600.00
456D52	2017-08-06 11:41:00+03	6700.00
456D6B	2017-08-12 11:49:00+03	13400.00
456D7D	2017-07-18 14:46:00+03	23200.00
456E12	2017-08-11 17:29:00+03	27200.00
456E80	2017-08-09 14:42:00+03	75600.00
456EB4	2017-07-08 13:29:00+03	229900.00
456EF4	2017-08-12 10:35:00+03	27800.00
456F03	2017-08-08 05:15:00+03	66600.00
457010	2017-07-29 03:00:00+03	40400.00
4570DD	2017-07-30 22:42:00+03	39100.00
4570E6	2017-08-09 03:56:00+03	62100.00
4570F6	2017-07-25 12:59:00+03	170000.00
4571DE	2017-08-05 20:58:00+03	76400.00
4571EC	2017-07-07 21:01:00+03	27200.00
45720F	2017-08-13 20:37:00+03	24000.00
457243	2017-08-02 01:57:00+03	62600.00
45724B	2017-07-18 06:37:00+03	28000.00
457272	2017-08-11 16:30:00+03	123700.00
457328	2017-08-14 22:43:00+03	41200.00
457360	2017-07-03 15:58:00+03	77900.00
457380	2017-08-03 22:14:00+03	107200.00
4573BB	2017-08-12 14:24:00+03	135200.00
4573C4	2017-08-15 03:11:00+03	46300.00
457428	2017-08-13 18:16:00+03	86400.00
457439	2017-07-03 18:46:00+03	56100.00
45748F	2017-07-11 10:52:00+03	32200.00
457494	2017-07-07 12:25:00+03	47100.00
4574DD	2017-07-08 23:32:00+03	85000.00
4574FE	2017-08-15 16:20:00+03	34100.00
45753E	2017-07-02 20:22:00+03	75300.00
4575B9	2017-08-09 16:31:00+03	56900.00
4575BF	2017-07-08 18:46:00+03	89700.00
4575C0	2017-08-07 15:23:00+03	47100.00
457678	2017-07-06 02:24:00+03	133200.00
457728	2017-07-08 08:17:00+03	25200.00
457750	2017-08-03 02:29:00+03	14400.00
4577CB	2017-07-10 19:44:00+03	16400.00
457869	2017-08-03 21:24:00+03	49100.00
4578A0	2017-06-27 00:24:00+03	88500.00
4578F1	2017-08-11 22:04:00+03	28000.00
4578F6	2017-07-29 20:47:00+03	44800.00
45793D	2017-07-13 04:30:00+03	23600.00
457951	2017-08-09 08:12:00+03	206700.00
4579D3	2017-07-14 22:45:00+03	62800.00
4579D7	2017-07-08 21:59:00+03	72600.00
457A20	2017-07-06 05:20:00+03	26700.00
457A24	2017-07-16 03:31:00+03	37900.00
457AA2	2017-07-02 00:11:00+03	35300.00
457ABA	2017-07-16 18:04:00+03	54000.00
457AC7	2017-08-01 17:28:00+03	24400.00
457AD8	2017-08-09 14:21:00+03	88900.00
457B2A	2017-07-02 17:03:00+03	52100.00
457B85	2017-07-24 05:54:00+03	61800.00
457B8F	2017-07-10 23:15:00+03	14800.00
457BA8	2017-08-01 05:54:00+03	258000.00
457BD8	2017-07-30 22:02:00+03	266800.00
457C28	2017-08-11 01:09:00+03	234100.00
457C54	2017-07-15 13:52:00+03	43800.00
457C7E	2017-07-08 08:53:00+03	136200.00
457CA0	2017-07-17 19:21:00+03	50600.00
457CD8	2017-08-07 03:32:00+03	100900.00
457D1D	2017-07-17 19:52:00+03	28800.00
457D99	2017-07-15 09:29:00+03	40600.00
457DC4	2017-07-24 16:54:00+03	46500.00
457DC7	2017-08-15 09:57:00+03	23200.00
457DE0	2017-08-11 06:54:00+03	170000.00
457DE2	2017-08-01 07:47:00+03	123000.00
457E04	2017-08-09 01:45:00+03	8000.00
457E12	2017-08-14 20:48:00+03	55800.00
457E41	2017-08-05 06:24:00+03	75600.00
457E4B	2017-07-29 10:28:00+03	55800.00
457E56	2017-07-24 15:46:00+03	92100.00
457E59	2017-07-15 19:58:00+03	123000.00
457E89	2017-08-09 00:49:00+03	22400.00
457E91	2017-07-05 23:42:00+03	147600.00
457F20	2017-07-19 15:43:00+03	34400.00
457F56	2017-07-16 03:16:00+03	26500.00
457F70	2017-08-12 21:39:00+03	23200.00
457F83	2017-07-26 05:25:00+03	40800.00
457F88	2017-08-14 00:07:00+03	12600.00
45803D	2017-07-30 23:35:00+03	270000.00
458042	2017-08-08 20:57:00+03	111600.00
458076	2017-07-03 21:44:00+03	67000.00
45809D	2017-07-07 21:40:00+03	427100.00
4580AC	2017-07-05 13:02:00+03	24400.00
4580BB	2017-08-07 08:28:00+03	17600.00
45810E	2017-08-02 15:53:00+03	104200.00
45814B	2017-08-09 01:45:00+03	106400.00
458197	2017-08-03 09:15:00+03	189200.00
45820F	2017-07-25 19:11:00+03	55800.00
458289	2017-07-05 04:14:00+03	14800.00
458294	2017-07-27 15:37:00+03	98100.00
4582D7	2017-07-29 06:25:00+03	43600.00
4582F7	2017-07-24 11:48:00+03	156300.00
45832E	2017-07-11 03:59:00+03	23200.00
45833D	2017-08-15 15:35:00+03	47500.00
458358	2017-07-08 19:44:00+03	116000.00
458368	2017-08-08 22:19:00+03	3700.00
45838F	2017-07-05 22:30:00+03	75300.00
45842A	2017-07-11 06:38:00+03	6600.00
4584B1	2017-07-26 15:26:00+03	40100.00
4584F0	2017-08-13 16:25:00+03	50300.00
4584FF	2017-07-15 06:48:00+03	47200.00
458583	2017-07-22 06:19:00+03	122800.00
4585DE	2017-07-21 11:44:00+03	28000.00
458626	2017-07-25 20:22:00+03	75800.00
4586D0	2017-07-12 06:22:00+03	6000.00
4586DB	2017-08-01 18:20:00+03	60400.00
4586F7	2017-08-04 23:56:00+03	59300.00
458735	2017-07-18 21:16:00+03	194800.00
458795	2017-08-15 05:28:00+03	61300.00
458811	2017-07-05 18:05:00+03	269300.00
458819	2017-08-03 03:00:00+03	119800.00
4588C5	2017-07-20 09:59:00+03	12400.00
458913	2017-07-30 20:12:00+03	7300.00
458936	2017-07-09 08:59:00+03	70800.00
45893F	2017-07-07 12:49:00+03	12400.00
458966	2017-07-14 21:13:00+03	229600.00
4589A8	2017-07-10 05:04:00+03	16400.00
4589CA	2017-07-17 22:23:00+03	198400.00
4589D0	2017-07-24 19:59:00+03	31500.00
458A03	2017-08-12 06:28:00+03	53900.00
458A1A	2017-07-09 22:47:00+03	92900.00
458A23	2017-08-15 06:51:00+03	12400.00
458A5B	2017-07-07 15:18:00+03	31600.00
458A60	2017-07-31 11:33:00+03	24400.00
458ACF	2017-07-15 08:47:00+03	62900.00
458AF8	2017-07-15 14:29:00+03	6000.00
458AFD	2017-08-01 13:49:00+03	44100.00
458B5D	2017-07-16 13:34:00+03	46000.00
458B80	2017-08-13 19:36:00+03	135400.00
458BC0	2017-07-14 01:23:00+03	13400.00
458C21	2017-07-20 18:00:00+03	27200.00
458C32	2017-08-05 20:45:00+03	70700.00
458C4F	2017-08-15 16:48:00+03	12000.00
458C61	2017-06-30 02:51:00+03	67900.00
458C67	2017-06-28 21:26:00+03	39500.00
458C7E	2017-08-13 18:34:00+03	39800.00
458C7F	2017-08-11 17:33:00+03	43800.00
458D14	2017-08-01 00:33:00+03	18400.00
458D44	2017-07-14 23:53:00+03	182300.00
458D72	2017-08-10 23:31:00+03	65900.00
458EAD	2017-07-09 04:06:00+03	70800.00
458EC4	2017-07-26 22:53:00+03	39200.00
458F0A	2017-08-08 05:28:00+03	103800.00
458F2C	2017-08-09 08:35:00+03	45800.00
458F39	2017-07-20 16:50:00+03	406700.00
458F52	2017-07-16 20:13:00+03	88600.00
458F57	2017-07-02 12:17:00+03	124000.00
458F65	2017-08-09 05:37:00+03	145500.00
458F6D	2017-07-19 18:38:00+03	55800.00
458FA7	2017-07-19 09:49:00+03	46400.00
458FD7	2017-07-05 21:42:00+03	39500.00
458FE0	2017-07-17 06:10:00+03	56600.00
458FE6	2017-07-26 03:46:00+03	32200.00
45905E	2017-08-03 08:22:00+03	17000.00
459087	2017-07-31 13:38:00+03	27800.00
4590E4	2017-07-06 09:36:00+03	36400.00
45916E	2017-07-31 19:45:00+03	115700.00
459189	2017-08-01 02:09:00+03	147900.00
45922E	2017-06-28 21:52:00+03	87000.00
459253	2017-08-02 07:07:00+03	139500.00
4592E1	2017-07-14 17:47:00+03	89600.00
459310	2017-07-17 14:55:00+03	6800.00
459324	2017-07-31 12:47:00+03	69000.00
459335	2017-07-15 00:53:00+03	26000.00
459336	2017-07-28 09:39:00+03	72400.00
459342	2017-08-11 00:53:00+03	195900.00
4593D2	2017-07-21 05:47:00+03	40800.00
4593F8	2017-08-01 13:40:00+03	22000.00
45940B	2017-08-02 18:34:00+03	167500.00
459412	2017-07-25 06:48:00+03	31600.00
459422	2017-07-22 02:19:00+03	92000.00
45944F	2017-07-06 01:02:00+03	30200.00
4594B2	2017-08-09 00:38:00+03	179400.00
459513	2017-08-07 01:46:00+03	40800.00
459515	2017-07-15 05:55:00+03	165200.00
459555	2017-07-15 00:03:00+03	147200.00
459575	2017-07-24 18:25:00+03	271200.00
4595A7	2017-07-19 23:39:00+03	36200.00
4595BD	2017-08-01 01:54:00+03	15400.00
4595C5	2017-07-16 18:28:00+03	70800.00
459649	2017-07-09 22:24:00+03	6300.00
4596A6	2017-07-22 01:44:00+03	119800.00
4596CA	2017-07-25 21:44:00+03	133200.00
45971F	2017-08-01 10:44:00+03	32800.00
4597A2	2017-07-04 09:21:00+03	64000.00
459804	2017-07-22 03:44:00+03	266400.00
459838	2017-07-24 23:51:00+03	21800.00
459843	2017-06-25 06:32:00+03	46400.00
459851	2017-08-09 02:29:00+03	40600.00
459853	2017-08-04 02:23:00+03	159200.00
4598D2	2017-07-08 13:49:00+03	125200.00
459915	2017-07-09 18:15:00+03	40800.00
45998B	2017-08-11 22:23:00+03	22400.00
4599C5	2017-08-14 08:14:00+03	102100.00
459A0A	2017-07-05 23:14:00+03	24400.00
459A78	2017-07-04 12:55:00+03	31200.00
459A8A	2017-08-10 01:43:00+03	99200.00
459AB6	2017-07-16 22:31:00+03	54800.00
459B7E	2017-07-18 11:41:00+03	112600.00
459C49	2017-07-16 13:54:00+03	56900.00
459C65	2017-08-13 02:45:00+03	92100.00
459CA4	2017-08-12 11:31:00+03	28800.00
459CC5	2017-07-08 13:59:00+03	92400.00
459D2D	2017-08-04 06:24:00+03	48900.00
459D39	2017-08-01 04:48:00+03	40800.00
459D99	2017-07-01 07:36:00+03	48800.00
459DEA	2017-08-15 15:49:00+03	106300.00
459E1A	2017-07-18 00:15:00+03	65300.00
459ECA	2017-07-05 12:24:00+03	47200.00
459F0D	2017-08-04 11:54:00+03	66000.00
459F47	2017-08-13 09:03:00+03	13400.00
459FD3	2017-07-03 12:25:00+03	21400.00
459FE2	2017-07-06 04:51:00+03	75600.00
45A02C	2017-08-09 21:18:00+03	270800.00
45A02F	2017-07-04 16:49:00+03	292600.00
45A043	2017-07-21 08:00:00+03	29000.00
45A0A2	2017-08-10 02:46:00+03	10700.00
45A15E	2017-07-18 21:16:00+03	56000.00
45A16F	2017-08-01 11:23:00+03	108500.00
45A1A8	2017-07-14 03:27:00+03	61800.00
45A1C9	2017-08-15 15:14:00+03	51900.00
45A215	2017-07-13 16:28:00+03	86300.00
45A230	2017-08-01 03:20:00+03	81600.00
45A26D	2017-08-10 03:06:00+03	28800.00
45A26F	2017-07-31 02:02:00+03	67200.00
45A279	2017-08-09 19:56:00+03	73300.00
45A293	2017-07-15 05:45:00+03	111600.00
45A2A2	2017-06-30 06:55:00+03	25000.00
45A2B5	2017-07-23 10:45:00+03	48700.00
45A2C7	2017-07-17 20:35:00+03	68400.00
45A2E9	2017-08-11 08:57:00+03	108200.00
45A352	2017-08-15 15:54:00+03	23600.00
45A375	2017-07-16 11:12:00+03	70700.00
45A386	2017-07-11 18:31:00+03	46000.00
45A3EF	2017-07-01 02:05:00+03	68800.00
45A41A	2017-08-11 14:53:00+03	120800.00
45A424	2017-07-18 22:09:00+03	387400.00
45A425	2017-07-14 23:43:00+03	20600.00
45A42A	2017-07-20 07:02:00+03	193400.00
45A442	2017-08-11 17:04:00+03	11600.00
45A528	2017-07-04 07:19:00+03	41200.00
45A532	2017-08-13 13:33:00+03	62700.00
45A537	2017-07-07 13:32:00+03	53400.00
45A572	2017-07-11 15:27:00+03	136200.00
45A59E	2017-07-07 04:32:00+03	28000.00
45A5A0	2017-07-17 17:49:00+03	102200.00
45A6BA	2017-06-28 15:28:00+03	29600.00
45A6E1	2017-08-09 15:08:00+03	19800.00
45A73D	2017-07-21 13:24:00+03	28300.00
45A77F	2017-07-23 06:49:00+03	117200.00
45A8BD	2017-08-06 23:27:00+03	122800.00
45A8ED	2017-08-06 22:08:00+03	36800.00
45A91D	2017-07-17 01:07:00+03	50000.00
45A93E	2017-08-04 14:21:00+03	84500.00
45A97D	2017-08-05 16:20:00+03	140900.00
45A9AF	2017-07-12 03:29:00+03	118700.00
45AA1F	2017-08-10 08:43:00+03	22000.00
45AA40	2017-07-01 06:21:00+03	13600.00
45AAD5	2017-06-28 20:26:00+03	56000.00
45AAE4	2017-07-12 08:23:00+03	56000.00
45AB00	2017-08-10 12:17:00+03	13400.00
45AB4E	2017-06-29 20:35:00+03	86400.00
45AB88	2017-07-30 01:37:00+03	468000.00
45ABA3	2017-08-04 01:47:00+03	40800.00
45AC0F	2017-08-09 12:35:00+03	68800.00
45AC2E	2017-07-17 12:40:00+03	191200.00
45AC99	2017-08-04 12:44:00+03	13200.00
45ACA9	2017-07-31 19:55:00+03	23900.00
45AD43	2017-08-10 02:25:00+03	136200.00
45AD84	2017-06-30 01:57:00+03	20500.00
45AE44	2017-07-10 14:03:00+03	123000.00
45AE95	2017-07-11 05:37:00+03	30200.00
45AEAC	2017-07-18 13:31:00+03	30800.00
45AECC	2017-08-05 08:14:00+03	19600.00
45AEE1	2017-07-04 13:49:00+03	86500.00
45AF02	2017-08-15 15:21:00+03	246000.00
45AF75	2017-08-14 11:44:00+03	40000.00
45AF76	2017-07-10 21:06:00+03	20200.00
45AF91	2017-08-04 03:22:00+03	14400.00
45AFD3	2017-07-11 13:18:00+03	13400.00
45AFE7	2017-07-24 03:55:00+03	7400.00
45B02C	2017-08-04 03:51:00+03	179300.00
45B056	2017-07-31 06:50:00+03	17800.00
45B078	2017-08-08 07:35:00+03	276900.00
45B0FB	2017-08-12 02:19:00+03	107600.00
45B106	2017-08-14 16:21:00+03	10300.00
45B16C	2017-07-21 07:30:00+03	47100.00
45B1A6	2017-07-11 20:18:00+03	66800.00
45B1C9	2017-07-21 17:33:00+03	109000.00
45B204	2017-07-05 02:41:00+03	36200.00
45B230	2017-07-20 06:39:00+03	26000.00
45B251	2017-08-04 22:55:00+03	58200.00
45B252	2017-07-28 14:03:00+03	62900.00
45B2DE	2017-07-23 17:56:00+03	6700.00
45B2EB	2017-08-13 00:55:00+03	29400.00
45B330	2017-07-14 22:59:00+03	95700.00
45B36C	2017-07-25 20:55:00+03	123000.00
45B405	2017-08-03 18:49:00+03	85800.00
45B408	2017-07-27 17:02:00+03	106400.00
45B427	2017-07-29 01:04:00+03	56000.00
45B441	2017-07-11 14:36:00+03	38600.00
45B45E	2017-07-27 07:27:00+03	48800.00
45B46D	2017-08-06 19:36:00+03	23200.00
45B481	2017-08-05 00:01:00+03	23200.00
45B49B	2017-07-17 08:15:00+03	21400.00
45B4B0	2017-08-08 10:59:00+03	89700.00
45B51E	2017-08-01 15:40:00+03	144400.00
45B5DB	2017-06-25 23:27:00+03	44800.00
45B5F2	2017-07-28 20:30:00+03	90600.00
45B667	2017-07-15 19:40:00+03	258400.00
45B67F	2017-07-13 04:59:00+03	26600.00
45B693	2017-08-04 13:41:00+03	46000.00
45B6A0	2017-08-05 12:05:00+03	87400.00
45B6B4	2017-08-14 05:32:00+03	56000.00
45B6BE	2017-08-11 04:55:00+03	170000.00
45B714	2017-07-15 00:24:00+03	12600.00
45B73D	2017-08-02 14:23:00+03	36800.00
45B76F	2017-07-13 21:07:00+03	103700.00
45B779	2017-07-29 17:01:00+03	20400.00
45B788	2017-07-17 05:42:00+03	16400.00
45B7B1	2017-07-23 14:02:00+03	265700.00
45B7B4	2017-07-26 12:17:00+03	31100.00
45B7CB	2017-07-28 13:32:00+03	35300.00
45B803	2017-07-01 12:25:00+03	48800.00
45B80D	2017-07-07 07:34:00+03	354200.00
45B821	2017-07-18 09:10:00+03	103500.00
45B869	2017-07-21 11:58:00+03	154900.00
45B8C1	2017-08-07 16:52:00+03	56600.00
45B8D4	2017-06-29 23:32:00+03	23100.00
45B8DC	2017-08-15 12:36:00+03	25100.00
45B8E6	2017-07-11 15:51:00+03	93800.00
45B906	2017-08-12 01:12:00+03	289800.00
45B943	2017-06-30 02:37:00+03	56000.00
45B95D	2017-07-15 06:13:00+03	85000.00
45B999	2017-07-03 02:48:00+03	111600.00
45B9B4	2017-07-08 14:06:00+03	188200.00
45B9D4	2017-08-02 01:10:00+03	547000.00
45B9ED	2017-07-29 00:42:00+03	28800.00
45BA08	2017-08-12 10:43:00+03	49500.00
45BABA	2017-06-30 21:18:00+03	135600.00
45BADD	2017-07-03 07:01:00+03	36700.00
45BAE9	2017-07-12 20:56:00+03	21800.00
45BB74	2017-07-25 23:53:00+03	72400.00
45BB96	2017-07-28 13:13:00+03	47000.00
45BBC3	2017-07-19 04:01:00+03	25200.00
45BBE4	2017-08-01 00:04:00+03	31600.00
45BC43	2017-07-23 05:47:00+03	117600.00
45BCA1	2017-07-13 18:49:00+03	21800.00
45BCA2	2017-07-08 19:01:00+03	46300.00
45BCAA	2017-07-04 12:45:00+03	45200.00
45BCFB	2017-07-24 03:53:00+03	22000.00
45BD2E	2017-08-10 14:46:00+03	54500.00
45BE09	2017-07-18 06:55:00+03	36200.00
45BE18	2017-08-15 07:40:00+03	550600.00
45BE2B	2017-07-27 02:08:00+03	67100.00
45BE32	2017-07-01 12:01:00+03	102000.00
45BE59	2017-07-26 02:48:00+03	38200.00
45BE93	2017-07-07 18:31:00+03	76600.00
45BEA6	2017-08-13 03:12:00+03	79700.00
45BEC4	2017-07-04 18:44:00+03	115700.00
45BF28	2017-08-03 19:38:00+03	202800.00
45BF94	2017-07-10 08:38:00+03	14800.00
45BF98	2017-07-12 20:36:00+03	24400.00
45BFD2	2017-07-17 19:11:00+03	22600.00
45C003	2017-07-12 02:38:00+03	84100.00
45C029	2017-07-31 04:14:00+03	15900.00
45C037	2017-07-08 00:14:00+03	99300.00
45C040	2017-08-05 13:50:00+03	138500.00
45C055	2017-07-10 13:03:00+03	112600.00
45C060	2017-08-14 23:43:00+03	24400.00
45C069	2017-08-07 09:24:00+03	62700.00
45C0BA	2017-08-05 14:26:00+03	122000.00
45C0D9	2017-08-12 17:47:00+03	29600.00
45C0DE	2017-07-20 04:26:00+03	22600.00
45C0E7	2017-07-14 00:36:00+03	92700.00
45C117	2017-06-30 06:41:00+03	40800.00
45C14D	2017-08-14 20:42:00+03	21800.00
45C151	2017-08-07 02:57:00+03	8000.00
45C168	2017-08-04 14:26:00+03	54800.00
45C1AB	2017-07-08 21:19:00+03	134400.00
45C1CC	2017-07-20 18:26:00+03	46200.00
45C1D2	2017-07-02 01:26:00+03	399400.00
45C1D6	2017-07-11 02:35:00+03	123800.00
45C1F6	2017-07-20 20:34:00+03	82900.00
45C204	2017-07-06 08:11:00+03	62600.00
45C2C2	2017-08-12 13:11:00+03	69500.00
45C2D2	2017-07-05 16:10:00+03	46900.00
45C37C	2017-07-18 19:50:00+03	17800.00
45C3A0	2017-08-10 09:17:00+03	121400.00
45C3A5	2017-07-17 12:04:00+03	75600.00
45C3B9	2017-08-10 15:45:00+03	62000.00
45C3C3	2017-07-29 17:42:00+03	66100.00
45C452	2017-07-28 22:39:00+03	56000.00
45C4BF	2017-07-15 01:28:00+03	199300.00
45C4DA	2017-08-06 16:03:00+03	56000.00
45C4F9	2017-08-06 04:31:00+03	55000.00
45C505	2017-07-13 19:41:00+03	22000.00
45C588	2017-08-11 08:58:00+03	10800.00
45C58B	2017-07-16 00:02:00+03	17000.00
45C592	2017-08-11 16:06:00+03	46500.00
45C5B6	2017-08-01 20:39:00+03	28000.00
45C681	2017-07-12 20:32:00+03	316700.00
45C6DC	2017-08-10 03:04:00+03	29300.00
45C729	2017-07-29 15:36:00+03	28800.00
45C76E	2017-08-01 15:54:00+03	65600.00
45C7AB	2017-07-03 04:42:00+03	99600.00
45C7B7	2017-07-19 15:10:00+03	150600.00
45C7D4	2017-07-07 06:01:00+03	38400.00
45C7F8	2017-07-09 10:54:00+03	50000.00
45C80B	2017-07-30 22:33:00+03	77200.00
45C817	2017-08-09 00:50:00+03	180000.00
45C866	2017-07-10 23:52:00+03	49600.00
45C880	2017-07-04 08:01:00+03	46300.00
45C8D4	2017-07-07 05:57:00+03	102100.00
45C8DE	2017-07-05 12:09:00+03	39200.00
45C910	2017-06-28 14:00:00+03	16400.00
45C9AE	2017-08-04 02:15:00+03	29600.00
45C9E6	2017-08-12 11:16:00+03	76400.00
45C9F8	2017-07-19 21:50:00+03	25600.00
45CA18	2017-08-14 04:32:00+03	44800.00
45CAC7	2017-07-28 01:57:00+03	76800.00
45CB0F	2017-08-14 14:14:00+03	24400.00
45CC3C	2017-08-09 10:22:00+03	28800.00
45CCCD	2017-07-07 20:25:00+03	199200.00
45CD25	2017-08-11 00:12:00+03	16800.00
45CD44	2017-07-20 06:31:00+03	144400.00
45CD73	2017-08-01 23:37:00+03	62600.00
45CE6D	2017-08-02 11:50:00+03	41600.00
45CF2C	2017-08-12 12:37:00+03	26200.00
45CFAF	2017-07-09 07:18:00+03	42700.00
45CFB7	2017-08-11 06:48:00+03	151300.00
45CFBA	2017-08-04 21:46:00+03	26000.00
45CFBD	2017-07-15 13:57:00+03	40600.00
45CFF9	2017-07-28 01:39:00+03	269200.00
45D038	2017-07-20 02:50:00+03	40400.00
45D06F	2017-07-29 05:22:00+03	13000.00
45D09B	2017-08-07 17:01:00+03	101200.00
45D10A	2017-07-05 19:53:00+03	67600.00
45D10C	2017-07-29 02:17:00+03	21200.00
45D1DC	2017-08-15 01:52:00+03	95700.00
45D215	2017-07-22 13:50:00+03	400000.00
45D286	2017-07-26 20:49:00+03	26000.00
45D29D	2017-07-10 06:02:00+03	229400.00
45D30D	2017-07-14 16:34:00+03	40800.00
45D317	2017-07-12 07:55:00+03	26000.00
45D45F	2017-08-13 05:27:00+03	111600.00
45D48C	2017-08-01 14:59:00+03	71600.00
45D49A	2017-07-26 12:39:00+03	56000.00
45D4E4	2017-07-15 11:03:00+03	27300.00
45D540	2017-08-12 15:41:00+03	169600.00
45D575	2017-08-15 00:06:00+03	6800.00
45D5DD	2017-07-24 06:14:00+03	23200.00
45D60E	2017-08-09 22:05:00+03	78600.00
45D611	2017-07-29 14:23:00+03	49900.00
45D61F	2017-08-06 23:41:00+03	133100.00
45D656	2017-07-31 21:15:00+03	24000.00
45D6B0	2017-07-21 07:52:00+03	28000.00
45D708	2017-08-11 07:04:00+03	109800.00
45D72C	2017-07-26 18:17:00+03	50600.00
45D739	2017-08-05 00:50:00+03	271100.00
45D773	2017-07-16 15:54:00+03	16400.00
45D7E9	2017-07-21 19:17:00+03	58600.00
45D7F2	2017-07-17 08:19:00+03	28800.00
45D8AF	2017-07-20 03:29:00+03	62300.00
45D91F	2017-08-01 17:17:00+03	67700.00
45DA0B	2017-08-03 10:22:00+03	123000.00
45DA1E	2017-08-06 03:46:00+03	15900.00
45DA2E	2017-08-09 11:50:00+03	26800.00
45DACB	2017-07-12 10:13:00+03	69900.00
45DAF1	2017-07-21 10:53:00+03	265600.00
45DAFB	2017-06-30 12:21:00+03	130000.00
45DB03	2017-07-17 01:57:00+03	31600.00
45DB16	2017-08-03 20:00:00+03	67200.00
45DB1B	2017-07-28 17:48:00+03	64600.00
45DB68	2017-07-23 01:20:00+03	26200.00
45DB7B	2017-08-13 00:28:00+03	150600.00
45DBE7	2017-07-12 08:34:00+03	6700.00
45DBFD	2017-07-21 19:46:00+03	333400.00
45DC26	2017-07-13 19:13:00+03	28800.00
45DC78	2017-07-08 09:26:00+03	36400.00
45DC7B	2017-07-05 23:17:00+03	266200.00
45DCCC	2017-08-14 14:22:00+03	11800.00
45DD43	2017-06-28 09:10:00+03	133200.00
45DD6C	2017-07-07 07:26:00+03	44000.00
45DDBC	2017-07-06 01:44:00+03	25200.00
45DDCF	2017-08-15 03:21:00+03	28800.00
45DE12	2017-08-09 03:36:00+03	114700.00
45DE22	2017-07-20 02:02:00+03	47200.00
45DE2D	2017-07-07 21:58:00+03	59300.00
45DE77	2017-08-12 03:38:00+03	85000.00
45DEA7	2017-07-11 02:16:00+03	271200.00
45DEBA	2017-07-11 09:44:00+03	73900.00
45DED4	2017-08-02 06:37:00+03	37600.00
45DF1D	2017-07-07 11:20:00+03	29200.00
45DF9C	2017-07-19 04:39:00+03	119500.00
45DFE6	2017-07-12 21:36:00+03	55700.00
45DFF7	2017-07-03 18:00:00+03	27700.00
45E001	2017-07-19 00:11:00+03	136500.00
45E027	2017-07-16 22:46:00+03	23400.00
45E039	2017-08-06 00:10:00+03	55800.00
45E04B	2017-08-03 13:45:00+03	134400.00
45E05D	2017-07-30 23:37:00+03	8000.00
45E09C	2017-08-06 10:38:00+03	75300.00
45E0E1	2017-07-14 00:12:00+03	132800.00
45E0E5	2017-07-17 11:52:00+03	66600.00
45E105	2017-07-07 07:28:00+03	44000.00
45E19E	2017-07-18 16:07:00+03	46300.00
45E1C5	2017-07-09 14:25:00+03	131000.00
45E1E4	2017-07-26 03:54:00+03	98400.00
45E203	2017-08-06 11:59:00+03	51900.00
45E239	2017-06-30 14:56:00+03	109000.00
45E242	2017-07-29 10:45:00+03	229900.00
45E30C	2017-07-15 00:43:00+03	99300.00
45E326	2017-08-15 01:41:00+03	53100.00
45E388	2017-07-09 02:11:00+03	325500.00
45E38E	2017-07-18 14:08:00+03	62000.00
45E3FD	2017-07-27 05:02:00+03	166900.00
45E4AF	2017-07-15 17:51:00+03	212700.00
45E4DF	2017-07-09 23:33:00+03	67600.00
45E506	2017-07-01 11:43:00+03	190700.00
45E514	2017-07-30 11:39:00+03	44000.00
45E54B	2017-08-02 05:32:00+03	43000.00
45E673	2017-07-12 10:55:00+03	28800.00
45E6C1	2017-07-03 03:29:00+03	104000.00
45E753	2017-07-26 00:44:00+03	54500.00
45E78F	2017-08-08 13:39:00+03	56600.00
45E799	2017-08-15 12:35:00+03	60400.00
45E862	2017-07-19 22:22:00+03	32700.00
45E87F	2017-07-21 18:57:00+03	32700.00
45E8E0	2017-07-26 02:28:00+03	237900.00
45E911	2017-08-08 13:21:00+03	21000.00
45E956	2017-07-20 20:59:00+03	52900.00
45E958	2017-08-14 05:27:00+03	35800.00
45EA09	2017-07-07 22:52:00+03	270800.00
45EA14	2017-07-04 05:55:00+03	53700.00
45EAAB	2017-07-13 23:48:00+03	113700.00
45EAAE	2017-07-07 05:14:00+03	133300.00
45EABA	2017-07-11 10:45:00+03	37200.00
45EAF4	2017-07-14 09:55:00+03	47900.00
45EB12	2017-08-11 10:39:00+03	26300.00
45EC2C	2017-07-22 05:42:00+03	66800.00
45EC2E	2017-07-08 07:57:00+03	19600.00
45EC34	2017-07-21 01:31:00+03	124200.00
45EC96	2017-07-24 16:45:00+03	111700.00
45ED81	2017-07-10 22:24:00+03	111600.00
45EDA0	2017-07-19 14:09:00+03	81700.00
45EDCD	2017-07-11 08:23:00+03	269600.00
45EE92	2017-07-06 07:24:00+03	26000.00
45EEE9	2017-07-24 00:59:00+03	109600.00
45EF10	2017-08-09 12:24:00+03	18600.00
45EF23	2017-07-28 04:23:00+03	132800.00
45EF44	2017-07-25 13:21:00+03	167400.00
45EF7D	2017-07-06 07:47:00+03	63600.00
45EF9A	2017-07-25 07:03:00+03	26400.00
45EFA1	2017-08-07 07:54:00+03	38400.00
45EFA8	2017-07-17 16:33:00+03	115800.00
45EFD5	2017-08-02 13:41:00+03	28000.00
45EFD7	2017-07-24 05:43:00+03	6000.00
45F000	2017-07-13 06:39:00+03	134100.00
45F026	2017-07-30 08:59:00+03	16400.00
45F02E	2017-08-10 10:47:00+03	47000.00
45F089	2017-07-11 13:03:00+03	54800.00
45F0B0	2017-08-14 22:24:00+03	51600.00
45F129	2017-08-12 05:25:00+03	47200.00
45F17B	2017-07-25 00:53:00+03	369000.00
45F1CF	2017-08-14 23:33:00+03	27400.00
45F1E8	2017-08-07 04:50:00+03	26000.00
45F241	2017-08-03 19:07:00+03	6000.00
45F2C6	2017-07-13 06:42:00+03	120800.00
45F2EB	2017-08-07 17:48:00+03	68400.00
45F328	2017-07-19 10:56:00+03	52300.00
45F3E6	2017-08-15 15:25:00+03	55000.00
45F3FB	2017-08-04 21:09:00+03	25200.00
45F421	2017-07-30 14:36:00+03	29200.00
45F425	2017-08-10 15:59:00+03	89700.00
45F471	2017-07-07 01:28:00+03	22000.00
45F492	2017-07-10 03:31:00+03	77800.00
45F4C4	2017-07-17 22:59:00+03	39500.00
45F4C5	2017-08-08 04:37:00+03	26800.00
45F57B	2017-07-22 22:01:00+03	75300.00
45F584	2017-08-09 22:00:00+03	124300.00
45F595	2017-06-30 15:24:00+03	174700.00
45F623	2017-07-19 20:34:00+03	50600.00
45F644	2017-08-05 23:57:00+03	29600.00
45F646	2017-07-10 11:56:00+03	31600.00
45F770	2017-07-21 02:38:00+03	55800.00
45F791	2017-07-16 02:49:00+03	96200.00
45F7C7	2017-08-06 16:52:00+03	18000.00
45F7E7	2017-07-22 08:36:00+03	54800.00
45F837	2017-08-10 18:14:00+03	34200.00
45F85D	2017-08-10 04:37:00+03	73500.00
45F9A6	2017-08-13 10:28:00+03	133200.00
45F9A7	2017-07-16 10:13:00+03	92200.00
45F9D2	2017-07-11 00:46:00+03	24400.00
45F9EF	2017-08-09 18:11:00+03	102100.00
45F9F7	2017-08-13 08:01:00+03	201200.00
45FA12	2017-08-05 21:41:00+03	111700.00
45FA45	2017-08-09 03:53:00+03	7400.00
45FA46	2017-08-10 17:07:00+03	137100.00
45FB0D	2017-07-24 08:19:00+03	24400.00
45FB50	2017-07-12 06:29:00+03	35000.00
45FBAD	2017-08-10 21:19:00+03	67200.00
45FBB0	2017-07-25 13:10:00+03	151800.00
45FBB6	2017-07-23 12:37:00+03	187600.00
45FBDD	2017-07-31 06:09:00+03	273000.00
45FC77	2017-08-05 08:49:00+03	67000.00
45FC80	2017-07-05 01:26:00+03	46000.00
45FC97	2017-07-30 06:16:00+03	108000.00
45FCB7	2017-07-31 19:16:00+03	98400.00
45FCBD	2017-07-19 07:41:00+03	23200.00
45FCC0	2017-08-02 13:08:00+03	31400.00
45FCE8	2017-07-09 10:35:00+03	46800.00
45FD42	2017-08-03 13:17:00+03	53500.00
45FD9B	2017-07-15 20:18:00+03	58600.00
45FDD7	2017-07-07 05:49:00+03	47100.00
45FE00	2017-08-08 05:53:00+03	28000.00
45FE08	2017-07-27 23:30:00+03	95400.00
45FE34	2017-07-28 20:06:00+03	177600.00
45FE4D	2017-07-06 19:35:00+03	90200.00
45FE73	2017-08-03 08:23:00+03	29600.00
45FE83	2017-08-12 18:07:00+03	23200.00
45FF27	2017-08-14 14:06:00+03	47500.00
45FF9D	2017-07-14 06:30:00+03	30200.00
45FFCE	2017-07-29 10:49:00+03	199200.00
45FFF9	2017-07-17 22:34:00+03	7400.00
460050	2017-08-02 10:51:00+03	112000.00
46005C	2017-08-14 12:26:00+03	330600.00
4600D9	2017-08-06 17:57:00+03	6000.00
4600E1	2017-07-20 10:45:00+03	7400.00
4600E7	2017-08-01 15:01:00+03	22400.00
4600F6	2017-07-17 02:34:00+03	111600.00
460126	2017-07-01 03:33:00+03	87500.00
460185	2017-07-30 02:41:00+03	36000.00
4601A9	2017-08-15 06:59:00+03	101200.00
4601AD	2017-07-13 04:42:00+03	42600.00
4601B5	2017-08-07 03:03:00+03	131600.00
4601DA	2017-07-09 09:12:00+03	23600.00
4601EA	2017-08-11 12:56:00+03	64400.00
460264	2017-07-28 12:02:00+03	182300.00
46028B	2017-06-30 02:12:00+03	46900.00
460321	2017-07-16 10:58:00+03	92800.00
460413	2017-07-12 15:36:00+03	92800.00
460434	2017-07-12 04:15:00+03	135400.00
46044A	2017-07-14 21:20:00+03	39500.00
4604EA	2017-07-28 04:32:00+03	156300.00
46059A	2017-07-21 05:53:00+03	375200.00
4605D6	2017-07-19 05:38:00+03	57600.00
46062F	2017-08-02 21:56:00+03	79900.00
46069F	2017-07-31 23:56:00+03	26600.00
4606E9	2017-07-27 20:33:00+03	28000.00
46075F	2017-07-08 01:55:00+03	16400.00
46076B	2017-07-18 00:21:00+03	46000.00
4607A9	2017-08-08 23:09:00+03	46200.00
4607DA	2017-08-11 03:04:00+03	79000.00
4607EF	2017-08-03 11:32:00+03	46000.00
46080D	2017-07-29 09:05:00+03	40800.00
460814	2017-07-12 19:46:00+03	56900.00
460818	2017-07-16 11:25:00+03	397700.00
46088A	2017-07-11 15:40:00+03	50900.00
460899	2017-06-30 15:25:00+03	47000.00
460919	2017-07-10 10:10:00+03	112000.00
460941	2017-08-05 18:22:00+03	66600.00
460999	2017-06-28 09:53:00+03	49900.00
4609B9	2017-08-02 12:25:00+03	369000.00
4609D9	2017-06-26 21:32:00+03	54800.00
4609F0	2017-08-01 15:19:00+03	8400.00
460AAE	2017-06-27 01:44:00+03	17600.00
460AFB	2017-07-29 02:27:00+03	44000.00
460B2A	2017-07-16 21:35:00+03	39500.00
460B53	2017-07-24 15:26:00+03	44500.00
460B57	2017-07-05 15:28:00+03	12400.00
460B5A	2017-08-02 00:32:00+03	53700.00
460B86	2017-07-22 19:44:00+03	134400.00
460BE8	2017-07-30 07:27:00+03	127800.00
460C0F	2017-08-12 21:33:00+03	66300.00
460C6A	2017-08-03 13:17:00+03	193000.00
460C72	2017-07-18 06:14:00+03	32800.00
460CA1	2017-07-05 17:33:00+03	37500.00
460CB7	2017-08-15 00:50:00+03	6000.00
460CE2	2017-06-29 09:55:00+03	14400.00
460D02	2017-08-07 00:23:00+03	54800.00
460D3E	2017-07-30 05:30:00+03	98400.00
460D3F	2017-08-13 11:04:00+03	271100.00
460D77	2017-08-14 21:17:00+03	189800.00
460D7C	2017-07-26 20:27:00+03	35200.00
460DDC	2017-07-22 20:55:00+03	27900.00
460DEC	2017-07-12 17:58:00+03	204800.00
460E30	2017-08-03 21:18:00+03	133200.00
460F06	2017-07-01 17:18:00+03	49100.00
460F18	2017-08-03 20:48:00+03	85700.00
460F54	2017-07-01 13:17:00+03	369000.00
460FAF	2017-07-22 11:29:00+03	55800.00
460FF1	2017-06-30 01:31:00+03	32800.00
461005	2017-07-24 14:05:00+03	10700.00
461055	2017-07-09 04:11:00+03	23400.00
461061	2017-07-26 19:32:00+03	91200.00
461073	2017-08-06 21:14:00+03	35600.00
4610B9	2017-07-14 05:49:00+03	75000.00
4610C1	2017-07-22 06:24:00+03	51900.00
4610DF	2017-08-10 05:36:00+03	78800.00
461103	2017-07-27 23:56:00+03	112000.00
461106	2017-07-21 17:23:00+03	27200.00
461134	2017-08-01 01:27:00+03	68000.00
461196	2017-07-24 18:06:00+03	100700.00
46125C	2017-08-07 19:15:00+03	288600.00
461288	2017-08-15 14:54:00+03	39800.00
461290	2017-07-24 19:31:00+03	123000.00
4612A1	2017-07-12 10:58:00+03	28800.00
461328	2017-07-25 10:49:00+03	67600.00
461359	2017-07-18 02:38:00+03	30800.00
46139E	2017-08-05 19:32:00+03	73200.00
4613DF	2017-08-15 14:59:00+03	14400.00
4613F3	2017-08-13 13:41:00+03	111600.00
461412	2017-07-09 19:56:00+03	26700.00
461415	2017-07-16 19:37:00+03	81500.00
4614B0	2017-07-25 19:23:00+03	21000.00
46151D	2017-07-31 10:32:00+03	83000.00
46155D	2017-07-25 23:17:00+03	20200.00
461589	2017-08-01 05:11:00+03	98400.00
461642	2017-08-02 21:13:00+03	8200.00
461678	2017-07-06 03:14:00+03	73200.00
461699	2017-08-15 10:26:00+03	114000.00
46169B	2017-07-05 01:39:00+03	81700.00
4616A3	2017-08-11 16:12:00+03	26000.00
4616C1	2017-07-06 08:15:00+03	147700.00
4616EC	2017-07-21 21:34:00+03	85000.00
461722	2017-07-27 13:57:00+03	26200.00
461742	2017-07-06 18:17:00+03	25200.00
461752	2017-07-17 07:30:00+03	56100.00
46175E	2017-08-03 07:39:00+03	311100.00
461785	2017-08-14 10:06:00+03	325500.00
4617C2	2017-08-01 11:46:00+03	246000.00
4617E1	2017-07-04 09:00:00+03	143600.00
461806	2017-07-16 13:42:00+03	56600.00
461861	2017-08-09 17:45:00+03	102300.00
46188A	2017-07-14 18:18:00+03	47400.00
461898	2017-07-26 23:07:00+03	153900.00
46189E	2017-07-02 23:57:00+03	68900.00
4618F9	2017-07-29 05:01:00+03	39200.00
46193E	2017-08-01 17:28:00+03	40000.00
4619C7	2017-07-17 16:22:00+03	78100.00
461A13	2017-07-01 17:20:00+03	66600.00
461A2B	2017-07-30 06:16:00+03	72300.00
461A87	2017-07-23 20:13:00+03	133200.00
461B51	2017-08-12 14:06:00+03	111600.00
461B71	2017-08-06 04:03:00+03	62600.00
461BB4	2017-07-07 03:46:00+03	281500.00
461BD9	2017-08-04 18:30:00+03	62000.00
461BFD	2017-07-04 19:21:00+03	6000.00
461C17	2017-08-15 10:20:00+03	21400.00
461D8B	2017-06-29 11:16:00+03	90400.00
461E2B	2017-07-13 21:48:00+03	87000.00
461E2D	2017-08-09 11:01:00+03	56600.00
461E58	2017-07-22 02:53:00+03	31800.00
461EBB	2017-08-14 17:49:00+03	18700.00
461F11	2017-07-13 20:11:00+03	59200.00
461F22	2017-07-09 17:14:00+03	46200.00
461F3F	2017-08-12 22:14:00+03	173600.00
461F73	2017-07-28 17:09:00+03	246000.00
461FBF	2017-07-28 17:30:00+03	59300.00
462000	2017-07-18 06:32:00+03	40400.00
4620C6	2017-07-28 13:10:00+03	199700.00
4620EE	2017-07-15 09:17:00+03	15700.00
4620F4	2017-07-14 07:40:00+03	110300.00
462107	2017-07-23 14:10:00+03	121800.00
46210B	2017-07-31 16:27:00+03	14000.00
4621EC	2017-07-08 10:33:00+03	16800.00
4621FF	2017-07-22 22:45:00+03	24000.00
462204	2017-08-03 02:55:00+03	14000.00
462205	2017-08-04 00:19:00+03	132800.00
462212	2017-08-11 13:14:00+03	149600.00
46226D	2017-07-23 19:59:00+03	38600.00
4622D1	2017-08-15 12:22:00+03	81600.00
4622FA	2017-07-19 12:02:00+03	81600.00
46233A	2017-07-30 16:44:00+03	93900.00
462346	2017-07-02 09:13:00+03	80800.00
462349	2017-07-18 00:17:00+03	48500.00
462368	2017-08-13 21:42:00+03	16300.00
4623EC	2017-07-14 20:38:00+03	320400.00
462408	2017-07-30 23:13:00+03	31600.00
46242D	2017-08-01 04:30:00+03	10800.00
462431	2017-07-04 13:26:00+03	26000.00
46244E	2017-07-21 06:36:00+03	26000.00
462461	2017-07-05 12:05:00+03	64700.00
462493	2017-07-15 15:42:00+03	68800.00
462557	2017-08-09 09:54:00+03	23400.00
462565	2017-07-07 11:04:00+03	31600.00
462566	2017-08-02 08:55:00+03	100200.00
4625CD	2017-07-26 20:06:00+03	112000.00
4625D7	2017-07-05 14:34:00+03	100600.00
462608	2017-08-09 11:32:00+03	92800.00
462682	2017-07-02 21:51:00+03	8200.00
4626A1	2017-07-18 09:42:00+03	51600.00
4626EC	2017-07-22 23:53:00+03	147700.00
46270B	2017-08-05 04:46:00+03	46800.00
462735	2017-07-25 23:51:00+03	87000.00
462743	2017-08-09 03:13:00+03	38800.00
46274E	2017-07-13 21:05:00+03	111600.00
462780	2017-08-10 17:09:00+03	61800.00
46281C	2017-07-26 11:27:00+03	75300.00
46283A	2017-08-06 04:09:00+03	20200.00
462845	2017-08-01 06:10:00+03	8200.00
462880	2017-08-01 15:51:00+03	40000.00
46289A	2017-07-03 22:40:00+03	81500.00
462908	2017-07-21 13:20:00+03	25200.00
46290A	2017-07-15 09:05:00+03	56000.00
462928	2017-07-30 01:25:00+03	26700.00
462968	2017-07-26 14:19:00+03	521200.00
46296D	2017-07-14 19:53:00+03	92400.00
4629A7	2017-07-17 21:06:00+03	57500.00
4629B7	2017-07-22 12:18:00+03	55800.00
4629F6	2017-06-26 07:46:00+03	24400.00
462A22	2017-07-10 14:04:00+03	95700.00
462A8F	2017-07-20 02:31:00+03	70700.00
462A92	2017-07-14 06:29:00+03	112000.00
462AA1	2017-07-22 09:33:00+03	28000.00
462ABE	2017-07-10 14:22:00+03	88800.00
462AD3	2017-07-24 05:57:00+03	37900.00
462AF3	2017-08-05 01:54:00+03	62800.00
462B7D	2017-07-16 22:31:00+03	35300.00
462B8A	2017-07-12 23:02:00+03	207300.00
462BC4	2017-07-05 09:07:00+03	160200.00
462BEA	2017-07-22 15:01:00+03	183300.00
462BF1	2017-08-02 06:21:00+03	38600.00
462C3C	2017-07-10 12:36:00+03	23200.00
462C50	2017-07-24 08:55:00+03	127500.00
462C86	2017-07-07 08:05:00+03	265800.00
462D75	2017-07-24 21:13:00+03	112000.00
462D76	2017-07-19 07:41:00+03	34000.00
462DFE	2017-08-07 01:54:00+03	47500.00
462E40	2017-08-09 11:55:00+03	16400.00
462E72	2017-07-23 13:21:00+03	140300.00
462F54	2017-08-06 22:50:00+03	107600.00
463013	2017-07-04 02:17:00+03	7400.00
4630D0	2017-07-21 13:12:00+03	23200.00
4630E9	2017-07-06 11:51:00+03	22000.00
46317D	2017-08-14 04:07:00+03	14400.00
4631D7	2017-07-05 14:41:00+03	36200.00
463238	2017-07-29 20:15:00+03	14000.00
463266	2017-07-26 19:56:00+03	6000.00
463315	2017-08-12 02:04:00+03	375200.00
463336	2017-07-17 20:34:00+03	37900.00
46333B	2017-06-30 09:13:00+03	23400.00
463417	2017-07-06 20:52:00+03	28000.00
463428	2017-07-05 14:12:00+03	58600.00
463445	2017-08-08 22:51:00+03	47400.00
463446	2017-07-03 04:42:00+03	83200.00
463456	2017-07-13 09:07:00+03	69600.00
463466	2017-07-29 21:41:00+03	32800.00
463497	2017-08-15 03:29:00+03	81600.00
4634B3	2017-07-01 01:11:00+03	21400.00
4634B8	2017-07-04 01:30:00+03	12600.00
463606	2017-07-20 20:11:00+03	24400.00
463614	2017-08-10 00:10:00+03	284700.00
463686	2017-08-10 10:00:00+03	72200.00
46368B	2017-07-03 19:56:00+03	37600.00
463728	2017-07-04 14:00:00+03	51600.00
463774	2017-08-12 01:43:00+03	89600.00
46378C	2017-08-11 14:04:00+03	12000.00
4637B4	2017-08-14 21:02:00+03	80500.00
4637C7	2017-07-03 23:22:00+03	46800.00
46382E	2017-08-02 00:15:00+03	44500.00
46386D	2017-08-11 04:58:00+03	136800.00
46386E	2017-07-25 18:28:00+03	28800.00
463920	2017-08-03 10:56:00+03	50700.00
463937	2017-07-13 00:39:00+03	16400.00
4639B3	2017-08-11 15:18:00+03	56000.00
4639DB	2017-07-02 13:29:00+03	26000.00
463A07	2017-07-29 21:17:00+03	73200.00
463A28	2017-07-02 01:11:00+03	15000.00
463AE8	2017-08-07 06:49:00+03	358200.00
463B4A	2017-08-10 23:43:00+03	65400.00
463C05	2017-07-10 22:49:00+03	19600.00
463C28	2017-07-25 19:59:00+03	38200.00
463C65	2017-07-07 13:26:00+03	28800.00
463CE6	2017-08-07 09:16:00+03	13400.00
463D02	2017-08-14 03:52:00+03	55800.00
463D59	2017-08-05 12:53:00+03	132800.00
463DE0	2017-07-05 17:22:00+03	62700.00
463DE6	2017-08-03 15:30:00+03	46400.00
463E15	2017-07-20 16:25:00+03	63700.00
463E3B	2017-07-14 09:47:00+03	177600.00
463E42	2017-08-10 19:36:00+03	30200.00
463E4C	2017-08-09 12:23:00+03	336800.00
463E60	2017-08-10 19:56:00+03	397100.00
463E78	2017-07-13 22:19:00+03	126800.00
463E84	2017-08-04 18:53:00+03	80000.00
463E90	2017-08-11 14:30:00+03	31200.00
463EA0	2017-08-13 16:52:00+03	248300.00
463EB1	2017-07-08 11:34:00+03	98300.00
463F48	2017-07-19 18:02:00+03	30800.00
463F5A	2017-07-10 22:35:00+03	9800.00
463FE8	2017-07-16 23:27:00+03	287200.00
464057	2017-08-13 16:20:00+03	77000.00
464078	2017-07-01 05:41:00+03	139200.00
4640AB	2017-08-08 23:42:00+03	28000.00
464101	2017-07-18 05:34:00+03	53300.00
46412E	2017-07-10 21:25:00+03	288400.00
464151	2017-07-13 23:05:00+03	248500.00
46418A	2017-08-05 13:44:00+03	23200.00
4641AA	2017-07-03 07:34:00+03	6300.00
464271	2017-07-01 10:43:00+03	65600.00
464278	2017-07-02 14:27:00+03	270500.00
46433B	2017-07-27 12:21:00+03	85000.00
46435C	2017-08-10 15:33:00+03	28800.00
464383	2017-08-01 13:20:00+03	19600.00
46441E	2017-07-04 17:01:00+03	25600.00
464444	2017-08-14 15:37:00+03	174400.00
464460	2017-07-23 03:12:00+03	35200.00
464466	2017-07-01 10:32:00+03	106100.00
46450A	2017-08-04 19:31:00+03	6700.00
464615	2017-07-20 17:06:00+03	65600.00
464657	2017-08-06 22:27:00+03	66600.00
46467F	2017-08-13 19:21:00+03	19600.00
46470D	2017-08-14 01:39:00+03	26800.00
464754	2017-07-05 02:50:00+03	49800.00
464854	2017-08-05 06:42:00+03	12000.00
46486F	2017-07-10 18:23:00+03	111600.00
464881	2017-08-03 20:00:00+03	37900.00
4648DB	2017-07-01 19:27:00+03	23600.00
46494D	2017-07-03 12:28:00+03	53600.00
464958	2017-07-20 13:44:00+03	25800.00
46495A	2017-07-30 05:21:00+03	58600.00
464964	2017-07-28 00:27:00+03	28800.00
464990	2017-08-09 03:29:00+03	77200.00
4649B0	2017-07-28 06:43:00+03	26000.00
4649BC	2017-07-01 00:27:00+03	23200.00
464A0E	2017-08-15 04:04:00+03	58400.00
464AA9	2017-07-30 12:58:00+03	88800.00
464AE8	2017-07-10 04:46:00+03	28000.00
464BA4	2017-07-03 19:28:00+03	25200.00
464BB2	2017-07-16 00:56:00+03	266400.00
464C20	2017-08-03 16:12:00+03	26800.00
464CAC	2017-08-09 14:59:00+03	27300.00
464CC3	2017-07-07 03:38:00+03	19600.00
464D13	2017-07-21 20:09:00+03	62600.00
464D2A	2017-07-18 19:12:00+03	31600.00
464D4A	2017-07-17 15:04:00+03	38400.00
464D64	2017-07-30 06:12:00+03	67600.00
464D8E	2017-08-05 18:10:00+03	55800.00
464E15	2017-08-15 07:06:00+03	37700.00
464E47	2017-07-08 16:57:00+03	76200.00
464E90	2017-07-22 09:32:00+03	28000.00
464F05	2017-07-18 17:59:00+03	36400.00
464F5D	2017-08-01 10:12:00+03	19600.00
464F84	2017-08-06 00:13:00+03	56600.00
465002	2017-08-13 21:36:00+03	16400.00
46504D	2017-08-04 06:37:00+03	23600.00
465115	2017-07-11 21:32:00+03	12400.00
46523C	2017-08-03 09:30:00+03	92900.00
465281	2017-07-24 11:44:00+03	169300.00
4652A2	2017-07-23 07:42:00+03	114800.00
4652B3	2017-07-26 03:51:00+03	61800.00
4652DF	2017-07-17 22:19:00+03	57800.00
465315	2017-08-05 04:34:00+03	7400.00
465317	2017-07-30 11:28:00+03	74100.00
465363	2017-07-08 00:38:00+03	61800.00
4653CE	2017-07-18 21:51:00+03	27400.00
46540B	2017-08-10 16:55:00+03	53600.00
46540E	2017-08-10 08:09:00+03	152900.00
46552E	2017-08-05 10:35:00+03	77200.00
46553B	2017-07-21 10:48:00+03	76600.00
465551	2017-07-26 03:53:00+03	30200.00
46557D	2017-07-20 21:10:00+03	59800.00
465630	2017-07-08 07:28:00+03	246000.00
465646	2017-08-06 05:10:00+03	15000.00
465650	2017-08-15 06:46:00+03	339900.00
46565E	2017-08-04 12:00:00+03	35200.00
465696	2017-08-01 13:48:00+03	38600.00
4656E2	2017-07-26 00:23:00+03	56900.00
4656E4	2017-07-19 09:28:00+03	8200.00
4656E6	2017-07-17 04:32:00+03	148200.00
465738	2017-07-03 21:52:00+03	32400.00
4657A3	2017-07-14 23:33:00+03	57600.00
4657B5	2017-07-09 03:46:00+03	99200.00
4657D8	2017-07-20 19:44:00+03	28300.00
465871	2017-08-01 15:46:00+03	179700.00
46590A	2017-07-31 00:51:00+03	100000.00
465981	2017-07-06 06:34:00+03	156500.00
46598B	2017-07-19 13:27:00+03	52100.00
4659B5	2017-07-02 03:25:00+03	23200.00
4659F8	2017-07-02 21:54:00+03	40100.00
465A3F	2017-07-15 13:08:00+03	86400.00
465A9B	2017-07-14 18:53:00+03	159800.00
465AB4	2017-07-29 00:03:00+03	55800.00
465AC7	2017-08-14 05:11:00+03	102100.00
465B44	2017-07-25 14:13:00+03	125200.00
465B91	2017-07-28 03:50:00+03	131900.00
465C8E	2017-07-07 14:32:00+03	258400.00
465CC7	2017-07-06 14:07:00+03	99200.00
465CD4	2017-08-12 07:35:00+03	27200.00
465D3F	2017-07-31 15:38:00+03	12600.00
465DB7	2017-07-03 08:28:00+03	51900.00
465DBF	2017-07-22 14:40:00+03	28000.00
465DF9	2017-07-10 21:02:00+03	99700.00
465E3A	2017-07-30 00:43:00+03	57500.00
465EC0	2017-08-08 14:32:00+03	88800.00
465FB6	2017-07-25 05:17:00+03	108300.00
4660D7	2017-07-26 09:24:00+03	12900.00
4660EC	2017-07-30 15:24:00+03	23600.00
4660F4	2017-07-14 16:37:00+03	53600.00
46612F	2017-07-18 11:31:00+03	18000.00
466173	2017-08-08 20:56:00+03	276200.00
4661C1	2017-08-15 04:26:00+03	61300.00
4661CF	2017-08-13 20:45:00+03	90100.00
4661D1	2017-07-28 20:15:00+03	111600.00
4661E5	2017-07-08 10:21:00+03	124300.00
46621B	2017-06-29 05:51:00+03	72200.00
466231	2017-08-07 01:04:00+03	406700.00
46623C	2017-08-06 04:13:00+03	6700.00
46624E	2017-07-05 05:23:00+03	23600.00
4662BD	2017-07-28 13:33:00+03	21600.00
466352	2017-07-23 07:34:00+03	40300.00
466371	2017-08-11 18:47:00+03	27600.00
4663AA	2017-07-13 03:44:00+03	6300.00
4663D5	2017-08-13 19:02:00+03	81800.00
4663DC	2017-07-11 09:32:00+03	6000.00
46640E	2017-08-06 11:25:00+03	69500.00
466429	2017-07-11 04:50:00+03	29200.00
46646B	2017-07-01 06:12:00+03	6000.00
466483	2017-08-06 08:01:00+03	15700.00
46655E	2017-08-12 16:28:00+03	12600.00
466589	2017-07-20 10:56:00+03	39300.00
46659D	2017-07-14 18:05:00+03	133100.00
466709	2017-08-05 15:24:00+03	35800.00
466710	2017-07-24 22:22:00+03	108600.00
466766	2017-06-29 02:32:00+03	42400.00
466773	2017-07-19 22:44:00+03	248400.00
466776	2017-07-06 21:00:00+03	30000.00
4667CC	2017-07-24 21:35:00+03	66600.00
466802	2017-08-07 22:33:00+03	37700.00
46683B	2017-07-27 08:27:00+03	119800.00
46685B	2017-07-20 01:44:00+03	27600.00
46687A	2017-08-09 11:36:00+03	20000.00
4668E8	2017-07-15 04:02:00+03	81200.00
4668FD	2017-08-01 07:06:00+03	24400.00
466911	2017-07-01 16:39:00+03	31600.00
46691C	2017-07-19 03:49:00+03	35200.00
466936	2017-08-07 16:56:00+03	111100.00
466A03	2017-07-23 14:37:00+03	26000.00
466A5F	2017-07-30 23:37:00+03	399600.00
466B4C	2017-07-01 14:55:00+03	89600.00
466B5F	2017-08-05 06:56:00+03	47000.00
466B63	2017-07-31 21:23:00+03	30000.00
466B7E	2017-07-03 16:22:00+03	155600.00
466BA9	2017-06-28 15:06:00+03	296000.00
466BB0	2017-08-04 15:40:00+03	46300.00
466CB9	2017-07-28 17:27:00+03	202700.00
466CE9	2017-06-30 10:50:00+03	114700.00
466CED	2017-07-23 21:30:00+03	112000.00
466D12	2017-07-29 04:14:00+03	98600.00
466D61	2017-08-08 18:55:00+03	87200.00
466D81	2017-07-31 10:44:00+03	69500.00
466E31	2017-07-10 15:22:00+03	67100.00
466E46	2017-07-28 04:11:00+03	36800.00
466E64	2017-07-09 00:51:00+03	83600.00
466E66	2017-07-24 00:06:00+03	37900.00
466E78	2017-08-02 14:28:00+03	20400.00
466E94	2017-08-05 02:25:00+03	24400.00
466EED	2017-08-01 19:00:00+03	54000.00
466F0B	2017-07-15 14:39:00+03	170700.00
466F44	2017-08-01 01:24:00+03	65900.00
466FF0	2017-07-11 06:08:00+03	37300.00
46704D	2017-08-02 15:50:00+03	67300.00
467079	2017-07-01 16:37:00+03	14000.00
4670AB	2017-08-04 15:28:00+03	131700.00
4670E5	2017-07-15 09:00:00+03	132800.00
467157	2017-08-05 23:44:00+03	108200.00
4671CD	2017-07-25 22:11:00+03	25200.00
4671E6	2017-08-11 07:39:00+03	29400.00
4671FB	2017-07-04 22:30:00+03	384400.00
467203	2017-07-23 12:06:00+03	8000.00
467240	2017-07-03 00:36:00+03	47400.00
46729F	2017-07-22 05:04:00+03	59200.00
4672BC	2017-07-17 05:51:00+03	397100.00
4672C4	2017-07-29 16:24:00+03	229400.00
4672D1	2017-08-11 16:32:00+03	133100.00
467340	2017-07-15 22:39:00+03	12600.00
4673E5	2017-08-07 09:39:00+03	33600.00
46741C	2017-07-07 17:24:00+03	26000.00
46745F	2017-08-03 00:02:00+03	64700.00
467475	2017-07-30 05:03:00+03	24800.00
467493	2017-07-05 23:22:00+03	185500.00
4674BF	2017-07-06 08:49:00+03	35200.00
4674D2	2017-07-02 13:38:00+03	199700.00
467523	2017-08-01 22:01:00+03	37200.00
46754D	2017-06-29 20:22:00+03	89700.00
467626	2017-08-01 17:18:00+03	192400.00
4676C0	2017-07-09 03:41:00+03	103000.00
4676FC	2017-07-04 09:56:00+03	78900.00
4677A7	2017-07-03 20:48:00+03	114800.00
4677AB	2017-07-17 12:23:00+03	27700.00
4677AE	2017-08-02 14:51:00+03	23200.00
4677B4	2017-07-24 22:08:00+03	54800.00
4677D0	2017-07-03 13:22:00+03	36200.00
46781D	2017-08-11 15:58:00+03	112000.00
46785A	2017-08-04 19:13:00+03	154800.00
467885	2017-06-28 20:55:00+03	24400.00
4678AD	2017-07-15 11:56:00+03	104600.00
4678F2	2017-08-15 15:29:00+03	57400.00
46790F	2017-08-01 12:42:00+03	58600.00
4679AE	2017-07-23 23:13:00+03	113800.00
4679D1	2017-08-05 22:26:00+03	60800.00
4679D5	2017-08-07 01:55:00+03	184300.00
4679E1	2017-07-27 22:48:00+03	21400.00
4679EA	2017-07-16 07:45:00+03	116400.00
467A10	2017-08-04 04:15:00+03	31600.00
467B0D	2017-08-15 05:02:00+03	67600.00
467B2A	2017-07-23 01:34:00+03	259500.00
467B46	2017-08-05 10:07:00+03	55400.00
467B5C	2017-07-16 02:53:00+03	56000.00
467B70	2017-07-23 02:12:00+03	11800.00
467B87	2017-07-21 07:35:00+03	51200.00
467B9A	2017-07-25 03:40:00+03	258400.00
467BBF	2017-08-01 17:55:00+03	93700.00
467C60	2017-08-10 02:57:00+03	59300.00
467C62	2017-07-22 20:26:00+03	40000.00
467C80	2017-07-19 23:17:00+03	13800.00
467CD4	2017-06-29 02:08:00+03	149500.00
467D2F	2017-08-02 09:12:00+03	581100.00
467D87	2017-08-08 19:33:00+03	26000.00
467DCD	2017-06-30 02:11:00+03	19800.00
467E66	2017-07-12 13:37:00+03	14000.00
467EA0	2017-07-03 19:29:00+03	54800.00
467EAB	2017-08-14 01:16:00+03	133200.00
467EE6	2017-08-12 11:44:00+03	23600.00
467F1D	2017-07-23 09:31:00+03	77900.00
467F22	2017-08-01 15:15:00+03	54800.00
467F36	2017-07-11 21:40:00+03	38600.00
467F39	2017-08-13 05:44:00+03	6700.00
467F5E	2017-06-30 12:09:00+03	31600.00
467F60	2017-06-30 08:07:00+03	177600.00
467FFA	2017-07-05 08:11:00+03	3400.00
46800E	2017-08-15 15:23:00+03	18000.00
468038	2017-07-22 15:57:00+03	137600.00
46806E	2017-08-01 06:11:00+03	23400.00
4680EB	2017-07-30 15:39:00+03	102000.00
468156	2017-07-24 13:35:00+03	11800.00
46815D	2017-08-08 21:05:00+03	43200.00
46815F	2017-07-23 08:18:00+03	25100.00
4681B0	2017-07-25 20:26:00+03	33300.00
4681C8	2017-07-28 14:59:00+03	21400.00
4681CF	2017-07-10 12:30:00+03	51800.00
468229	2017-08-09 23:45:00+03	29600.00
468252	2017-07-11 07:44:00+03	28800.00
46831F	2017-06-30 12:40:00+03	48500.00
46837B	2017-07-13 11:11:00+03	57400.00
468413	2017-07-04 08:28:00+03	6800.00
4684AB	2017-07-22 04:29:00+03	86300.00
4684C7	2017-08-06 18:41:00+03	63800.00
4684EC	2017-07-04 04:51:00+03	28800.00
46850C	2017-08-12 12:16:00+03	170000.00
4685B5	2017-07-19 06:56:00+03	160900.00
4685E6	2017-07-27 21:32:00+03	67700.00
46860B	2017-08-11 08:47:00+03	23400.00
468618	2017-07-17 20:34:00+03	42700.00
468636	2017-07-10 08:28:00+03	111600.00
46866F	2017-07-11 03:46:00+03	39500.00
46868C	2017-08-12 08:50:00+03	59800.00
4686BF	2017-07-04 05:03:00+03	133200.00
4686CB	2017-08-10 02:36:00+03	16400.00
4686FF	2017-08-04 05:21:00+03	124100.00
468715	2017-08-10 14:35:00+03	12600.00
468766	2017-07-19 04:06:00+03	21800.00
4687E5	2017-08-13 10:48:00+03	270200.00
4687F4	2017-07-04 06:53:00+03	31600.00
468829	2017-07-06 03:11:00+03	124200.00
46882C	2017-08-02 20:59:00+03	32800.00
468839	2017-08-07 18:46:00+03	121800.00
46889D	2017-08-14 13:42:00+03	266400.00
468924	2017-08-10 19:13:00+03	25100.00
46896B	2017-07-16 07:26:00+03	348800.00
468972	2017-07-20 17:26:00+03	28800.00
4689C6	2017-07-03 22:38:00+03	90400.00
4689CD	2017-08-14 17:44:00+03	14400.00
468A54	2017-07-10 10:54:00+03	49100.00
468A82	2017-07-19 20:26:00+03	40800.00
468A8B	2017-07-20 08:53:00+03	46000.00
468AA1	2017-07-24 11:43:00+03	81200.00
468AE4	2017-08-02 01:40:00+03	54800.00
468B22	2017-07-16 12:27:00+03	11600.00
468B8A	2017-07-09 03:30:00+03	23200.00
468BFB	2017-07-23 03:01:00+03	28800.00
468C66	2017-06-30 06:35:00+03	75300.00
468C87	2017-07-30 17:13:00+03	78400.00
468CC2	2017-07-13 14:07:00+03	85000.00
468CE8	2017-07-16 19:32:00+03	14400.00
468DB3	2017-07-30 20:55:00+03	91000.00
468E21	2017-08-07 04:53:00+03	130900.00
468E23	2017-07-09 16:36:00+03	13400.00
468E3E	2017-08-15 13:56:00+03	23400.00
468EC1	2017-07-09 16:19:00+03	141000.00
468EDA	2017-08-02 23:09:00+03	75500.00
468FF7	2017-07-31 13:42:00+03	48100.00
46903D	2017-08-01 11:01:00+03	100200.00
469048	2017-07-14 11:12:00+03	112000.00
4690AC	2017-08-03 08:11:00+03	23200.00
4690B7	2017-07-21 19:53:00+03	135400.00
4690CA	2017-08-06 11:37:00+03	72800.00
469115	2017-07-29 13:01:00+03	22200.00
469142	2017-08-11 15:06:00+03	67600.00
469155	2017-07-11 00:42:00+03	51800.00
4691B7	2017-07-29 16:06:00+03	118500.00
4691C8	2017-08-07 14:07:00+03	39100.00
4691EE	2017-07-01 04:37:00+03	210900.00
469208	2017-07-06 07:08:00+03	25400.00
46924D	2017-07-29 15:42:00+03	135400.00
46928A	2017-08-15 14:22:00+03	65300.00
4693ED	2017-08-09 05:24:00+03	118100.00
469464	2017-07-29 19:16:00+03	21800.00
469490	2017-07-22 06:01:00+03	146000.00
469501	2017-07-30 16:56:00+03	59800.00
469542	2017-07-27 08:58:00+03	135400.00
46954D	2017-07-25 03:20:00+03	8400.00
4695A8	2017-07-05 05:37:00+03	47000.00
4695C9	2017-07-21 20:08:00+03	136800.00
4695EE	2017-08-06 09:08:00+03	26200.00
469635	2017-07-24 15:07:00+03	71800.00
46968A	2017-07-09 22:59:00+03	38600.00
46968F	2017-07-14 08:04:00+03	276200.00
4696D3	2017-08-11 18:35:00+03	75600.00
46971A	2017-06-25 13:01:00+03	92800.00
469737	2017-07-07 20:42:00+03	199700.00
46986D	2017-08-01 07:35:00+03	24400.00
46987A	2017-07-02 13:54:00+03	24300.00
4698DB	2017-08-14 08:43:00+03	39200.00
4698E9	2017-08-11 23:21:00+03	170300.00
469992	2017-08-14 14:58:00+03	32200.00
46999C	2017-07-24 17:02:00+03	68600.00
4699BE	2017-07-07 18:37:00+03	123000.00
4699D0	2017-07-27 21:24:00+03	154300.00
469A07	2017-07-15 20:34:00+03	63100.00
469A29	2017-07-03 09:16:00+03	68100.00
469A64	2017-08-08 09:38:00+03	23200.00
469A9D	2017-07-27 13:00:00+03	99200.00
469B15	2017-07-24 14:06:00+03	17800.00
469B54	2017-07-30 05:50:00+03	55500.00
469BBF	2017-08-15 03:47:00+03	24800.00
469BEA	2017-07-20 07:48:00+03	65900.00
469C0B	2017-07-14 14:36:00+03	36200.00
469C76	2017-08-10 21:22:00+03	53900.00
469C88	2017-07-14 09:07:00+03	19800.00
469D33	2017-07-01 20:33:00+03	100800.00
469D5A	2017-08-06 20:02:00+03	57400.00
469D6E	2017-08-04 15:29:00+03	117100.00
469D82	2017-08-05 23:10:00+03	16400.00
469D86	2017-07-26 08:33:00+03	49100.00
469DB9	2017-07-15 03:57:00+03	23600.00
469DCA	2017-07-03 23:02:00+03	24500.00
469DD2	2017-07-26 04:34:00+03	94700.00
469E56	2017-08-06 12:23:00+03	58600.00
469E5F	2017-08-15 03:22:00+03	62000.00
469E65	2017-08-14 21:51:00+03	64200.00
469E72	2017-07-08 01:08:00+03	12600.00
469E8A	2017-08-12 22:09:00+03	55800.00
469EB1	2017-07-21 13:18:00+03	101800.00
469F32	2017-07-08 06:34:00+03	43000.00
469F6C	2017-07-19 08:48:00+03	54400.00
469F8A	2017-07-30 04:56:00+03	147700.00
469FA4	2017-07-11 22:54:00+03	20800.00
469FAB	2017-07-30 21:45:00+03	38600.00
469FB1	2017-08-06 12:01:00+03	56600.00
469FC7	2017-07-28 02:56:00+03	68400.00
469FE7	2017-07-31 13:13:00+03	21400.00
46A021	2017-07-24 09:27:00+03	265800.00
46A075	2017-07-25 13:39:00+03	23200.00
46A0E3	2017-07-16 14:58:00+03	67400.00
46A0F8	2017-08-03 07:00:00+03	99900.00
46A100	2017-06-29 23:02:00+03	115600.00
46A1CE	2017-07-06 15:21:00+03	23400.00
46A1D6	2017-07-02 10:39:00+03	46200.00
46A21C	2017-07-07 02:54:00+03	48500.00
46A24F	2017-08-10 02:45:00+03	67600.00
46A258	2017-07-11 09:50:00+03	43600.00
46A25F	2017-08-13 07:39:00+03	23400.00
46A2CE	2017-07-06 21:11:00+03	103500.00
46A304	2017-08-02 09:33:00+03	50100.00
46A310	2017-07-27 09:16:00+03	38200.00
46A3BD	2017-07-23 02:22:00+03	153300.00
46A3C5	2017-07-02 09:59:00+03	47200.00
46A3CA	2017-07-05 16:33:00+03	31800.00
46A3D2	2017-08-15 00:29:00+03	61300.00
46A444	2017-07-27 11:00:00+03	149300.00
46A586	2017-07-08 05:37:00+03	119700.00
46A5EE	2017-07-26 04:44:00+03	14000.00
46A602	2017-07-25 13:23:00+03	32800.00
46A636	2017-07-19 15:09:00+03	87400.00
46A70A	2017-08-10 16:02:00+03	16400.00
46A782	2017-07-19 09:40:00+03	22000.00
46A7BC	2017-08-04 18:16:00+03	6600.00
46A7C0	2017-07-19 07:52:00+03	46300.00
46A8BB	2017-07-17 15:26:00+03	58600.00
46A935	2017-07-29 11:09:00+03	56000.00
46A94E	2017-07-17 11:57:00+03	131100.00
46A96B	2017-07-29 16:50:00+03	106600.00
46A975	2017-08-07 01:05:00+03	56600.00
46A97D	2017-07-24 01:07:00+03	49100.00
46A9AB	2017-07-18 12:24:00+03	99200.00
46AA03	2017-07-28 13:12:00+03	135400.00
46AA07	2017-07-21 00:22:00+03	133100.00
46AA68	2017-08-13 06:48:00+03	25200.00
46AA89	2017-07-04 03:16:00+03	28800.00
46AA94	2017-08-02 23:35:00+03	106400.00
46AB02	2017-07-11 08:22:00+03	86300.00
46AB28	2017-07-06 17:44:00+03	32200.00
46AB35	2017-07-21 05:09:00+03	35600.00
46AB54	2017-07-26 23:54:00+03	14700.00
46ABE6	2017-07-23 13:03:00+03	151200.00
46AC57	2017-08-12 08:20:00+03	89600.00
46ACA0	2017-08-10 20:21:00+03	28000.00
46ADB4	2017-08-07 13:33:00+03	387000.00
46ADFD	2017-08-05 20:58:00+03	452600.00
46AE66	2017-08-02 22:11:00+03	26000.00
46AEA0	2017-07-07 06:33:00+03	67300.00
46AEC2	2017-07-14 02:27:00+03	46500.00
46AECF	2017-07-12 04:12:00+03	103500.00
46AEF6	2017-07-08 02:07:00+03	19600.00
46AFD7	2017-07-18 22:27:00+03	272900.00
46AFFC	2017-07-03 22:46:00+03	26000.00
46B02F	2017-07-22 03:30:00+03	6000.00
46B034	2017-07-19 10:59:00+03	32800.00
46B03F	2017-08-13 14:51:00+03	43200.00
46B05F	2017-07-19 07:22:00+03	61400.00
46B0BC	2017-08-13 03:21:00+03	116400.00
46B0EB	2017-08-09 02:08:00+03	55400.00
46B0F2	2017-08-01 22:13:00+03	109600.00
46B11A	2017-07-02 15:45:00+03	56000.00
46B163	2017-07-13 06:40:00+03	12600.00
46B297	2017-07-30 00:34:00+03	46400.00
46B33F	2017-08-10 21:19:00+03	40600.00
46B3B2	2017-08-12 05:27:00+03	106600.00
46B3B8	2017-07-29 05:15:00+03	75300.00
46B3CF	2017-07-11 07:21:00+03	14400.00
46B3D9	2017-08-13 21:11:00+03	7200.00
46B3E0	2017-08-02 11:47:00+03	177600.00
46B40B	2017-08-11 07:51:00+03	135400.00
46B40D	2017-07-04 18:05:00+03	44000.00
46B43C	2017-08-15 12:32:00+03	40000.00
46B46B	2017-07-27 17:25:00+03	83700.00
46B46D	2017-07-11 03:51:00+03	133200.00
46B484	2017-08-12 04:24:00+03	66600.00
46B4CA	2017-07-24 13:11:00+03	58900.00
46B547	2017-07-02 17:36:00+03	32800.00
46B58C	2017-08-09 09:55:00+03	58000.00
46B5C5	2017-07-20 11:11:00+03	13600.00
46B5DB	2017-08-09 05:48:00+03	6700.00
46B5EA	2017-07-19 08:39:00+03	25000.00
46B64B	2017-08-07 17:26:00+03	25000.00
46B657	2017-07-25 20:46:00+03	52000.00
46B698	2017-08-09 04:21:00+03	369000.00
46B6AA	2017-07-03 14:47:00+03	45100.00
46B6BC	2017-07-25 16:37:00+03	43200.00
46B6C2	2017-07-05 09:49:00+03	48400.00
46B72A	2017-08-13 23:59:00+03	128800.00
46B74C	2017-07-26 08:02:00+03	31800.00
46B76C	2017-07-13 09:44:00+03	95600.00
46B7C2	2017-08-06 15:22:00+03	55800.00
46B7FB	2017-07-29 13:50:00+03	131600.00
46B86C	2017-08-11 06:05:00+03	87500.00
46B8B3	2017-07-19 20:19:00+03	25100.00
46B8FA	2017-07-13 16:57:00+03	6700.00
46B8FD	2017-07-13 17:56:00+03	122400.00
46B91D	2017-07-08 20:02:00+03	39200.00
46B936	2017-07-01 12:28:00+03	73500.00
46B953	2017-07-30 08:20:00+03	46300.00
46B9D3	2017-07-27 09:16:00+03	24400.00
46B9E1	2017-08-06 22:10:00+03	136200.00
46B9F4	2017-08-13 11:17:00+03	132800.00
46B9F9	2017-07-14 21:45:00+03	55800.00
46BA58	2017-07-15 01:26:00+03	59300.00
46BAB1	2017-07-04 10:06:00+03	133100.00
46BAB4	2017-08-07 01:13:00+03	47600.00
46BAE8	2017-07-30 05:53:00+03	39800.00
46BB03	2017-07-07 06:46:00+03	166100.00
46BB55	2017-08-01 19:11:00+03	56000.00
46BB87	2017-08-08 07:25:00+03	298600.00
46BBCB	2017-07-22 15:46:00+03	46800.00
46BBE1	2017-07-25 04:42:00+03	90400.00
46BC77	2017-07-05 13:05:00+03	69900.00
46BC93	2017-07-30 22:33:00+03	32700.00
46BC9B	2017-07-24 23:50:00+03	179400.00
46BCA0	2017-08-10 02:05:00+03	13400.00
46BCB9	2017-07-13 04:41:00+03	59800.00
46BCBD	2017-07-18 05:59:00+03	90400.00
46BCCE	2017-07-28 10:42:00+03	46200.00
46BCDC	2017-08-02 11:01:00+03	49800.00
46BD42	2017-07-09 14:04:00+03	53600.00
46BD44	2017-07-30 02:13:00+03	38400.00
46BD4C	2017-07-15 17:11:00+03	14400.00
46BD92	2017-07-05 19:29:00+03	56000.00
46BDA6	2017-07-07 00:08:00+03	159200.00
46BE16	2017-08-05 21:47:00+03	32200.00
46BE35	2017-07-22 21:28:00+03	168000.00
46BF01	2017-07-26 04:31:00+03	54000.00
46C028	2017-07-10 19:13:00+03	56600.00
46C08A	2017-07-19 11:41:00+03	258300.00
46C0F8	2017-07-27 00:04:00+03	133200.00
46C0FE	2017-07-08 19:09:00+03	43800.00
46C18B	2017-08-06 03:45:00+03	10800.00
46C1BB	2017-08-14 13:35:00+03	47000.00
46C1EE	2017-07-21 08:52:00+03	19600.00
46C20B	2017-07-21 01:14:00+03	76000.00
46C215	2017-07-12 11:09:00+03	46400.00
46C234	2017-08-01 23:50:00+03	37900.00
46C262	2017-08-08 01:52:00+03	56600.00
46C2B5	2017-07-07 22:56:00+03	67400.00
46C2DF	2017-07-14 10:37:00+03	57800.00
46C2F4	2017-07-13 15:55:00+03	122100.00
46C311	2017-06-27 09:39:00+03	75500.00
46C369	2017-07-24 21:33:00+03	25100.00
46C3BB	2017-08-04 01:45:00+03	516800.00
46C4B8	2017-07-18 10:02:00+03	222000.00
46C4CF	2017-08-09 02:26:00+03	31600.00
46C53C	2017-07-18 04:37:00+03	402400.00
46C562	2017-08-02 12:47:00+03	22400.00
46C618	2017-07-26 08:21:00+03	90400.00
46C663	2017-07-25 07:16:00+03	6700.00
46C665	2017-08-14 17:45:00+03	47000.00
46C6F2	2017-07-08 20:32:00+03	7400.00
46C702	2017-07-26 20:35:00+03	112600.00
46C7AF	2017-08-14 02:23:00+03	20600.00
46C7B8	2017-07-30 11:00:00+03	54800.00
46C823	2017-08-06 15:11:00+03	37600.00
46C836	2017-07-26 13:30:00+03	46300.00
46C84A	2017-07-24 10:00:00+03	53600.00
46C86C	2017-07-20 06:41:00+03	6700.00
46C87C	2017-08-08 09:46:00+03	23600.00
46C892	2017-08-13 22:56:00+03	36900.00
46C901	2017-08-14 11:57:00+03	98200.00
46C9AC	2017-08-08 06:02:00+03	27900.00
46CA91	2017-07-20 21:55:00+03	100000.00
46CA98	2017-07-11 12:27:00+03	75600.00
46CAB1	2017-07-26 10:35:00+03	37100.00
46CAC6	2017-08-06 19:21:00+03	28000.00
46CB09	2017-07-02 03:40:00+03	26700.00
46CB75	2017-07-23 05:12:00+03	28800.00
46CB91	2017-07-17 23:03:00+03	47900.00
46CBB1	2017-07-07 18:57:00+03	28000.00
46CBFE	2017-08-09 02:00:00+03	24700.00
46CC37	2017-07-08 02:59:00+03	66600.00
46CCCF	2017-08-12 19:26:00+03	289600.00
46CCE2	2017-08-06 10:05:00+03	56000.00
46CD08	2017-08-14 07:40:00+03	52400.00
46CD0C	2017-08-04 09:07:00+03	58200.00
46CD14	2017-07-29 01:07:00+03	25400.00
46CD45	2017-07-03 02:20:00+03	28800.00
46CDB5	2017-07-26 17:23:00+03	26800.00
46CDBB	2017-07-11 12:15:00+03	29600.00
46CDCD	2017-07-11 01:09:00+03	47100.00
46CDF3	2017-07-10 10:17:00+03	8200.00
46CE28	2017-08-11 18:03:00+03	188000.00
46CEA0	2017-08-14 09:04:00+03	84500.00
46CEBA	2017-08-10 10:32:00+03	108500.00
46CED5	2017-07-17 11:02:00+03	135200.00
46CEDA	2017-07-26 08:06:00+03	44000.00
46CEF8	2017-08-08 07:39:00+03	30200.00
46CF3B	2017-07-18 23:48:00+03	26800.00
46CF5C	2017-08-07 00:44:00+03	56000.00
46CF8A	2017-07-28 06:16:00+03	147000.00
46CFAB	2017-08-05 03:00:00+03	26800.00
46CFD8	2017-07-01 18:30:00+03	113700.00
46CFDF	2017-07-07 05:16:00+03	398500.00
46CFFC	2017-07-09 09:58:00+03	99200.00
46D093	2017-08-15 14:49:00+03	301800.00
46D0AA	2017-06-28 05:44:00+03	67700.00
46D153	2017-07-06 14:02:00+03	39600.00
46D154	2017-07-02 13:00:00+03	31600.00
46D20C	2017-07-27 06:25:00+03	12400.00
46D2B4	2017-07-08 04:37:00+03	131600.00
46D2C4	2017-07-06 01:14:00+03	58900.00
46D2E7	2017-07-19 17:57:00+03	42800.00
46D2F2	2017-07-29 01:27:00+03	24000.00
46D35E	2017-07-21 12:31:00+03	55800.00
46D36A	2017-07-13 03:50:00+03	57600.00
46D394	2017-07-27 16:58:00+03	18300.00
46D39F	2017-07-30 15:34:00+03	56900.00
46D3B1	2017-07-09 07:48:00+03	15800.00
46D3C2	2017-07-22 03:05:00+03	57600.00
46D3E6	2017-07-28 23:46:00+03	134400.00
46D464	2017-08-10 18:45:00+03	135400.00
46D49B	2017-07-03 17:37:00+03	16400.00
46D4D3	2017-06-30 23:47:00+03	52300.00
46D50C	2017-07-31 12:07:00+03	43500.00
46D562	2017-07-25 20:26:00+03	55800.00
46D576	2017-07-02 17:07:00+03	23900.00
46D57F	2017-08-15 10:30:00+03	100200.00
46D5BE	2017-07-16 04:21:00+03	32800.00
46D5BF	2017-07-31 06:39:00+03	56000.00
46D5C7	2017-07-11 10:35:00+03	34000.00
46D5D4	2017-08-01 05:14:00+03	246000.00
46D635	2017-08-09 12:45:00+03	86400.00
46D636	2017-07-25 13:13:00+03	23200.00
46D643	2017-08-06 09:47:00+03	26000.00
46D678	2017-07-10 04:08:00+03	105000.00
46D687	2017-07-26 13:57:00+03	32800.00
46D6BC	2017-08-13 02:06:00+03	179200.00
46D74D	2017-08-13 06:12:00+03	26800.00
46D775	2017-07-28 20:05:00+03	75300.00
46D7BB	2017-08-13 23:36:00+03	369000.00
46D803	2017-07-11 10:35:00+03	46000.00
46D86E	2017-07-16 00:00:00+03	12600.00
46D8B2	2017-08-01 15:25:00+03	17800.00
46D8B4	2017-07-13 04:40:00+03	115600.00
46D8BD	2017-07-27 15:39:00+03	22000.00
46D952	2017-07-26 16:16:00+03	160200.00
46D98C	2017-07-13 06:47:00+03	96100.00
46DA02	2017-07-04 05:14:00+03	23900.00
46DA29	2017-07-31 06:24:00+03	52300.00
46DA60	2017-08-11 17:26:00+03	21800.00
46DACD	2017-07-27 23:13:00+03	21800.00
46DB6C	2017-07-10 16:02:00+03	28000.00
46DBAE	2017-08-15 13:48:00+03	57300.00
46DC01	2017-07-29 11:23:00+03	16400.00
46DC79	2017-08-13 19:44:00+03	40800.00
46DCDD	2017-08-05 23:59:00+03	49100.00
46DD72	2017-08-09 10:57:00+03	58900.00
46DD83	2017-08-10 21:23:00+03	78400.00
46DDA2	2017-08-07 01:05:00+03	47000.00
46DDA9	2017-07-03 19:19:00+03	34000.00
46DDF8	2017-07-30 03:49:00+03	97900.00
46DE1D	2017-08-01 16:38:00+03	133200.00
46DE24	2017-08-11 17:35:00+03	119600.00
46DE58	2017-07-19 22:15:00+03	270800.00
46DEA8	2017-07-11 14:07:00+03	23200.00
46DEAC	2017-07-18 04:58:00+03	14000.00
46DEB3	2017-08-02 11:30:00+03	64400.00
46DECC	2017-07-01 12:08:00+03	36800.00
46DEEA	2017-07-28 21:08:00+03	22600.00
46DEF4	2017-07-29 10:43:00+03	51200.00
46DF11	2017-07-25 17:51:00+03	111600.00
46DF1B	2017-07-16 23:30:00+03	28800.00
46DF20	2017-07-03 06:49:00+03	40200.00
46DF7E	2017-08-12 21:27:00+03	147700.00
46DFA9	2017-07-14 07:27:00+03	24800.00
46DFE1	2017-06-27 19:10:00+03	35200.00
46DFF6	2017-07-12 16:22:00+03	195400.00
46DFFC	2017-07-21 06:06:00+03	30400.00
46E008	2017-07-10 11:06:00+03	38700.00
46E009	2017-08-12 15:33:00+03	97600.00
46E08E	2017-07-29 00:57:00+03	35200.00
46E0D5	2017-07-07 00:14:00+03	85000.00
46E1DD	2017-08-10 13:59:00+03	58400.00
46E249	2017-08-15 02:00:00+03	28800.00
46E278	2017-07-23 13:19:00+03	117500.00
46E2A5	2017-08-03 23:02:00+03	119700.00
46E2CA	2017-07-18 06:56:00+03	56000.00
46E2F4	2017-07-27 17:03:00+03	40600.00
46E2FE	2017-08-13 09:38:00+03	54800.00
46E318	2017-07-21 23:17:00+03	28800.00
46E31B	2017-08-10 02:18:00+03	133200.00
46E325	2017-07-09 08:37:00+03	51300.00
46E36D	2017-08-10 09:56:00+03	12600.00
46E3B0	2017-07-23 12:18:00+03	123200.00
46E3B8	2017-07-16 16:02:00+03	24400.00
46E3D4	2017-08-08 20:55:00+03	139000.00
46E414	2017-07-23 09:16:00+03	36200.00
46E44B	2017-07-31 03:54:00+03	34000.00
46E4DC	2017-07-25 02:17:00+03	17800.00
46E4E2	2017-07-26 03:55:00+03	50400.00
46E4F1	2017-08-05 17:58:00+03	20400.00
46E4F5	2017-08-10 14:08:00+03	30000.00
46E530	2017-07-20 04:33:00+03	81300.00
46E555	2017-07-12 16:01:00+03	100600.00
46E599	2017-07-27 07:33:00+03	172600.00
46E59A	2017-07-01 18:35:00+03	30400.00
46E5F0	2017-07-30 23:23:00+03	51900.00
46E630	2017-07-20 12:19:00+03	57400.00
46E641	2017-07-28 11:15:00+03	395400.00
46E703	2017-07-27 12:22:00+03	27300.00
46E763	2017-07-31 07:47:00+03	46800.00
46E781	2017-08-06 05:41:00+03	92700.00
46E791	2017-08-14 02:41:00+03	59600.00
46E7DE	2017-07-30 22:24:00+03	40300.00
46E804	2017-07-29 08:37:00+03	102100.00
46E80D	2017-07-08 15:25:00+03	56600.00
46E93A	2017-07-12 12:24:00+03	60400.00
46E97E	2017-08-08 17:32:00+03	50800.00
46E9F4	2017-07-05 04:26:00+03	57800.00
46EAAC	2017-08-04 01:19:00+03	40000.00
46EAB5	2017-07-09 13:00:00+03	280200.00
46EABD	2017-07-21 11:53:00+03	56000.00
46EB71	2017-07-31 00:17:00+03	11600.00
46EB8D	2017-07-30 07:33:00+03	132800.00
46EC1B	2017-07-10 11:50:00+03	22600.00
46ECBE	2017-07-14 06:05:00+03	91200.00
46ED3D	2017-07-16 19:01:00+03	80000.00
46ED3F	2017-08-06 03:22:00+03	39500.00
46ED55	2017-07-18 20:02:00+03	52300.00
46EDB5	2017-07-08 01:03:00+03	281500.00
46EDF8	2017-08-06 03:40:00+03	385000.00
46EE29	2017-07-30 08:19:00+03	25600.00
46EE58	2017-08-13 23:21:00+03	24000.00
46EE6A	2017-07-08 14:02:00+03	55800.00
46EE79	2017-07-23 19:44:00+03	18800.00
46EEED	2017-07-21 23:00:00+03	20400.00
46EF1C	2017-08-12 01:51:00+03	155600.00
46EFA1	2017-08-15 12:39:00+03	92100.00
46EFD0	2017-07-23 22:48:00+03	18700.00
46F0B3	2017-07-20 14:10:00+03	139200.00
46F0D1	2017-08-12 04:38:00+03	25200.00
46F14E	2017-07-21 01:18:00+03	102100.00
46F185	2017-07-15 05:00:00+03	14000.00
46F1CB	2017-08-05 12:54:00+03	86400.00
46F1E9	2017-07-13 09:24:00+03	32700.00
46F1F8	2017-08-03 03:07:00+03	56000.00
46F262	2017-07-23 03:51:00+03	6700.00
46F276	2017-08-04 20:38:00+03	12600.00
46F287	2017-07-21 02:17:00+03	77600.00
46F295	2017-07-20 23:17:00+03	75300.00
46F365	2017-07-05 17:08:00+03	65000.00
46F484	2017-07-22 00:01:00+03	52700.00
46F4D9	2017-08-11 11:34:00+03	20200.00
46F50B	2017-07-29 01:39:00+03	16400.00
46F536	2017-08-01 16:53:00+03	6700.00
46F55D	2017-08-09 02:44:00+03	143100.00
46F6DB	2017-07-29 03:27:00+03	73100.00
46F7E3	2017-07-30 09:00:00+03	58200.00
46F7F0	2017-08-04 05:56:00+03	25100.00
46F7FE	2017-07-31 02:59:00+03	88600.00
46F816	2017-08-10 19:46:00+03	104200.00
46F818	2017-07-17 03:18:00+03	56600.00
46F85A	2017-07-04 23:42:00+03	24700.00
46F886	2017-07-28 15:57:00+03	270700.00
46F975	2017-07-28 20:11:00+03	46000.00
46F984	2017-07-17 00:36:00+03	48800.00
46F9EC	2017-07-04 08:14:00+03	4000.00
46F9FA	2017-08-07 05:20:00+03	18000.00
46FA22	2017-07-19 04:42:00+03	26000.00
46FA76	2017-08-10 12:05:00+03	99700.00
46FA94	2017-07-22 01:05:00+03	58900.00
46FAEA	2017-07-22 22:16:00+03	67800.00
46FB1A	2017-07-14 22:11:00+03	52900.00
46FBA5	2017-08-13 15:42:00+03	42600.00
46FC14	2017-07-05 08:41:00+03	14400.00
46FC35	2017-07-11 20:08:00+03	15700.00
46FC78	2017-07-04 09:42:00+03	131800.00
46FC7D	2017-08-02 23:04:00+03	93900.00
46FCC8	2017-07-05 19:19:00+03	149400.00
46FD5E	2017-07-16 07:59:00+03	65300.00
46FD8E	2017-07-22 06:38:00+03	124200.00
46FDE2	2017-08-13 07:21:00+03	51300.00
46FDFC	2017-08-10 14:36:00+03	30200.00
46FE05	2017-07-06 12:54:00+03	47400.00
46FE17	2017-07-13 03:08:00+03	93900.00
46FEC7	2017-07-04 15:21:00+03	265600.00
46FEC8	2017-07-05 02:58:00+03	51900.00
46FF1B	2017-08-14 01:49:00+03	27200.00
470037	2017-07-21 05:23:00+03	24000.00
470067	2017-08-11 23:52:00+03	30200.00
470083	2017-07-27 18:19:00+03	55800.00
4700A8	2017-07-26 06:02:00+03	58700.00
4700E7	2017-07-31 23:54:00+03	83800.00
4700F1	2017-07-01 20:52:00+03	78300.00
470147	2017-08-13 01:51:00+03	19600.00
470180	2017-08-15 14:09:00+03	270800.00
470190	2017-08-02 08:42:00+03	39600.00
470231	2017-07-13 15:01:00+03	46400.00
470234	2017-07-19 20:24:00+03	28900.00
4702A3	2017-08-05 21:37:00+03	65000.00
4702E3	2017-08-04 21:19:00+03	28800.00
470331	2017-07-09 03:33:00+03	69500.00
47033A	2017-07-22 22:02:00+03	36800.00
470367	2017-07-26 22:58:00+03	136500.00
4703C8	2017-08-01 07:12:00+03	35200.00
47043F	2017-07-10 07:06:00+03	54300.00
470463	2017-08-04 09:27:00+03	54000.00
470466	2017-07-28 11:09:00+03	202300.00
470527	2017-07-17 02:28:00+03	123800.00
470551	2017-07-23 08:36:00+03	21400.00
470592	2017-08-07 09:03:00+03	22600.00
4705AF	2017-07-22 03:37:00+03	66600.00
4705BF	2017-07-15 15:37:00+03	18300.00
4705D2	2017-08-02 03:26:00+03	123000.00
4705F4	2017-07-25 18:52:00+03	24400.00
4706D0	2017-07-12 01:33:00+03	65900.00
4706D7	2017-07-05 07:54:00+03	102200.00
4706FC	2017-07-04 20:52:00+03	64700.00
470706	2017-07-23 05:49:00+03	85000.00
47070A	2017-07-18 19:12:00+03	94000.00
47074A	2017-08-13 23:15:00+03	59400.00
47078F	2017-07-16 07:05:00+03	19600.00
4707A3	2017-08-06 10:17:00+03	32800.00
470824	2017-08-13 20:06:00+03	32200.00
470857	2017-08-05 05:02:00+03	102600.00
47086C	2017-07-11 02:07:00+03	21800.00
470874	2017-07-06 13:40:00+03	87100.00
470878	2017-07-19 12:51:00+03	46700.00
4708A9	2017-08-07 06:19:00+03	34000.00
4708B3	2017-07-02 05:58:00+03	56000.00
470911	2017-08-11 21:44:00+03	41600.00
4709E8	2017-07-29 12:37:00+03	46200.00
470A29	2017-07-16 00:35:00+03	23200.00
470A44	2017-08-12 17:42:00+03	199000.00
470A90	2017-07-22 15:02:00+03	83000.00
470B32	2017-07-23 11:36:00+03	95200.00
470B5E	2017-07-27 16:10:00+03	47200.00
470BFF	2017-07-01 13:31:00+03	6000.00
470C2E	2017-08-03 08:32:00+03	44600.00
470C2F	2017-08-08 23:16:00+03	45200.00
470C7D	2017-06-28 07:00:00+03	23600.00
470CAA	2017-07-10 12:41:00+03	59800.00
470CD2	2017-07-09 03:09:00+03	28600.00
470CDF	2017-08-05 08:40:00+03	61700.00
470D3D	2017-07-16 08:20:00+03	134200.00
470DA7	2017-07-06 17:28:00+03	150600.00
470DB8	2017-08-08 00:56:00+03	81600.00
470DD7	2017-07-28 22:22:00+03	26000.00
470DF0	2017-07-26 13:19:00+03	55000.00
470E49	2017-07-30 17:22:00+03	58800.00
470E7E	2017-08-12 00:48:00+03	51600.00
470E8B	2017-07-14 17:50:00+03	129700.00
470E92	2017-07-15 21:57:00+03	138500.00
470E98	2017-07-27 04:37:00+03	66400.00
470EE0	2017-07-24 02:37:00+03	28000.00
470F3F	2017-07-25 09:40:00+03	23400.00
470F6F	2017-07-23 02:38:00+03	118300.00
470FF5	2017-08-10 14:34:00+03	50800.00
47103F	2017-08-08 19:08:00+03	182700.00
471042	2017-08-15 01:32:00+03	20200.00
471066	2017-07-28 18:50:00+03	46000.00
4710A1	2017-07-06 23:08:00+03	64400.00
47114A	2017-07-26 19:06:00+03	58900.00
471173	2017-08-09 18:44:00+03	30200.00
471181	2017-07-17 18:33:00+03	14800.00
4711A4	2017-08-11 16:39:00+03	13400.00
4711BE	2017-07-19 03:30:00+03	76600.00
471285	2017-07-01 14:46:00+03	258400.00
471359	2017-07-31 23:12:00+03	31400.00
471383	2017-08-13 03:56:00+03	129700.00
4713D1	2017-07-26 09:43:00+03	20200.00
4713F6	2017-07-24 08:07:00+03	69000.00
471408	2017-08-10 04:33:00+03	226200.00
471417	2017-07-21 04:16:00+03	124200.00
471461	2017-07-04 05:26:00+03	124200.00
47154D	2017-08-03 00:58:00+03	46400.00
471574	2017-07-20 00:57:00+03	120400.00
47158C	2017-07-17 18:37:00+03	93900.00
47159A	2017-07-04 20:17:00+03	30200.00
4715E7	2017-07-29 14:34:00+03	59300.00
471606	2017-07-31 15:47:00+03	46800.00
471711	2017-07-31 02:31:00+03	56000.00
47172E	2017-07-02 09:22:00+03	39500.00
4717CF	2017-07-15 20:43:00+03	41600.00
4717D6	2017-06-26 23:37:00+03	26100.00
4717F6	2017-07-06 03:29:00+03	65500.00
471865	2017-07-31 11:19:00+03	48400.00
4718A3	2017-07-08 10:49:00+03	11600.00
471993	2017-07-09 11:54:00+03	6700.00
4719C6	2017-07-10 01:44:00+03	56000.00
471A10	2017-07-22 21:34:00+03	68000.00
471A88	2017-07-28 10:10:00+03	148200.00
471AAA	2017-07-04 07:50:00+03	29500.00
471AC3	2017-07-16 07:56:00+03	19600.00
471AF4	2017-07-26 05:22:00+03	65600.00
471B0C	2017-07-20 11:08:00+03	110300.00
471B22	2017-07-02 21:02:00+03	6300.00
471B44	2017-07-04 22:31:00+03	168000.00
471B7D	2017-07-22 02:36:00+03	50600.00
471B90	2017-07-29 15:27:00+03	166000.00
471BC0	2017-08-11 23:10:00+03	265600.00
471BFE	2017-07-23 14:37:00+03	51200.00
471C9F	2017-07-13 17:55:00+03	39800.00
471D08	2017-07-18 02:59:00+03	20400.00
471D47	2017-07-26 07:28:00+03	6000.00
471D5D	2017-07-18 10:47:00+03	114800.00
471E83	2017-08-12 01:04:00+03	246000.00
471EBD	2017-08-11 20:18:00+03	28800.00
471F3C	2017-07-25 00:13:00+03	189200.00
472092	2017-07-28 14:24:00+03	28800.00
4720B1	2017-08-05 04:22:00+03	123000.00
472184	2017-07-15 13:55:00+03	55800.00
472193	2017-07-19 12:44:00+03	179500.00
4721D9	2017-07-04 05:01:00+03	21400.00
472201	2017-08-09 18:08:00+03	46300.00
472259	2017-08-01 10:32:00+03	196800.00
47225D	2017-07-25 15:42:00+03	55800.00
47226D	2017-08-03 12:44:00+03	75300.00
472272	2017-07-20 00:23:00+03	57000.00
4722CF	2017-08-10 00:46:00+03	38200.00
472326	2017-06-28 22:18:00+03	28800.00
472369	2017-08-09 21:41:00+03	26000.00
47237F	2017-07-21 00:17:00+03	89700.00
4723CA	2017-07-10 23:53:00+03	399600.00
47240A	2017-07-17 12:22:00+03	132800.00
472489	2017-07-20 18:16:00+03	46800.00
4724C2	2017-07-01 09:04:00+03	24400.00
4724CB	2017-08-07 15:49:00+03	29600.00
4724DB	2017-08-13 01:16:00+03	56000.00
47254D	2017-08-08 22:05:00+03	56000.00
47254F	2017-07-17 19:43:00+03	101200.00
472578	2017-08-01 17:04:00+03	65500.00
4725A3	2017-07-22 16:45:00+03	23200.00
4725B2	2017-07-21 18:47:00+03	127800.00
4725D5	2017-07-08 20:36:00+03	94000.00
4725D9	2017-08-12 11:18:00+03	12200.00
4725E9	2017-07-30 18:55:00+03	116400.00
472719	2017-07-09 00:14:00+03	240600.00
47273C	2017-08-10 18:56:00+03	34000.00
472754	2017-07-19 22:45:00+03	50800.00
47276A	2017-07-23 22:45:00+03	39200.00
47286F	2017-07-24 15:56:00+03	97900.00
472890	2017-08-01 18:01:00+03	104000.00
4728D2	2017-08-11 12:31:00+03	23600.00
472907	2017-08-01 16:44:00+03	135600.00
47290E	2017-07-16 06:54:00+03	61800.00
472981	2017-07-01 04:09:00+03	73600.00
472A15	2017-07-27 15:44:00+03	45000.00
472A17	2017-08-03 11:35:00+03	32800.00
472A5A	2017-07-12 04:27:00+03	73200.00
472A60	2017-07-04 02:38:00+03	26000.00
472A88	2017-08-09 22:32:00+03	25200.00
472A9B	2017-07-08 18:02:00+03	145300.00
472AF2	2017-07-08 12:45:00+03	54000.00
472B56	2017-07-14 20:50:00+03	24800.00
472C1C	2017-07-30 08:38:00+03	85000.00
472CEF	2017-08-15 07:27:00+03	25800.00
472D4F	2017-07-11 00:00:00+03	6000.00
472D58	2017-08-08 11:00:00+03	73200.00
472D8F	2017-07-21 04:40:00+03	43600.00
472DB0	2017-07-11 00:12:00+03	39600.00
472DFE	2017-06-30 00:13:00+03	40000.00
472E38	2017-07-05 20:25:00+03	56600.00
472E51	2017-07-24 11:08:00+03	202100.00
472E6D	2017-07-05 10:42:00+03	72200.00
472EB9	2017-08-06 10:58:00+03	31800.00
472EBC	2017-07-31 01:38:00+03	22000.00
472EC9	2017-07-17 16:44:00+03	113800.00
472F28	2017-07-26 02:47:00+03	68800.00
472F2F	2017-07-01 01:12:00+03	185300.00
472FA0	2017-07-08 00:00:00+03	170700.00
472FEB	2017-07-06 18:57:00+03	32800.00
473005	2017-07-09 20:22:00+03	19600.00
473010	2017-07-02 07:23:00+03	160200.00
473066	2017-07-11 18:01:00+03	182300.00
4730A9	2017-08-06 23:08:00+03	54800.00
4730B7	2017-08-15 11:57:00+03	147700.00
473278	2017-07-20 05:00:00+03	73400.00
4732C4	2017-07-19 21:15:00+03	58000.00
4732EE	2017-07-14 17:39:00+03	54800.00
473308	2017-07-18 07:17:00+03	201000.00
473339	2017-08-14 05:38:00+03	19600.00
4733DA	2017-07-01 15:18:00+03	46800.00
4733F4	2017-08-03 17:35:00+03	174400.00
473468	2017-07-05 02:25:00+03	32800.00
473471	2017-07-21 02:19:00+03	46200.00
4734E5	2017-08-14 11:47:00+03	179600.00
47353C	2017-08-06 11:02:00+03	47000.00
473574	2017-07-13 19:08:00+03	32900.00
47362A	2017-08-15 17:03:00+03	102800.00
4736B3	2017-08-05 22:10:00+03	82000.00
4736E0	2017-07-19 15:30:00+03	103800.00
4736E1	2017-07-04 21:36:00+03	173100.00
47374C	2017-08-06 09:53:00+03	40700.00
473796	2017-07-31 05:34:00+03	67200.00
473811	2017-08-14 07:32:00+03	13400.00
473883	2017-07-25 16:35:00+03	25200.00
473891	2017-07-27 01:09:00+03	8400.00
4738AA	2017-07-30 05:22:00+03	106400.00
4738E6	2017-08-14 03:25:00+03	13200.00
473911	2017-08-14 19:38:00+03	294200.00
473956	2017-07-23 07:18:00+03	9800.00
4739E5	2017-07-28 13:27:00+03	23100.00
473A1F	2017-07-21 21:00:00+03	49100.00
473A65	2017-07-17 14:18:00+03	46400.00
473AA5	2017-07-18 10:37:00+03	38800.00
473ABB	2017-08-06 07:10:00+03	396500.00
473B06	2017-07-03 11:39:00+03	433300.00
473B09	2017-08-09 05:25:00+03	119700.00
473B4A	2017-07-24 22:38:00+03	46200.00
473B57	2017-07-16 08:51:00+03	89700.00
473BBA	2017-07-18 05:29:00+03	29200.00
473BBF	2017-08-05 18:14:00+03	46400.00
473C70	2017-08-09 21:48:00+03	174800.00
473CB3	2017-07-13 13:20:00+03	46400.00
473CB9	2017-07-27 23:50:00+03	26200.00
473CC4	2017-08-13 05:01:00+03	70600.00
473D4F	2017-07-11 00:53:00+03	102300.00
473D90	2017-08-14 06:20:00+03	133100.00
473E3F	2017-07-29 17:25:00+03	72400.00
473E7C	2017-07-19 13:20:00+03	6000.00
473EA7	2017-08-06 05:18:00+03	23600.00
473EAA	2017-07-25 11:31:00+03	47100.00
473EAF	2017-07-21 19:23:00+03	31400.00
473EE6	2017-07-08 08:34:00+03	112000.00
473EFB	2017-07-05 08:36:00+03	163800.00
473F01	2017-07-19 21:37:00+03	65900.00
473F34	2017-08-14 14:41:00+03	71100.00
473FB1	2017-07-07 00:55:00+03	357300.00
47400C	2017-07-30 13:16:00+03	14400.00
474039	2017-07-31 19:34:00+03	117200.00
474068	2017-07-13 19:55:00+03	34000.00
474074	2017-07-18 02:37:00+03	14000.00
47407D	2017-08-12 01:03:00+03	37000.00
47408C	2017-08-15 03:35:00+03	55800.00
4740BE	2017-08-04 22:29:00+03	14400.00
4740D3	2017-08-14 02:28:00+03	21800.00
4740E4	2017-08-05 11:15:00+03	131600.00
4740F2	2017-07-22 21:31:00+03	21400.00
474139	2017-07-13 01:21:00+03	14800.00
47416E	2017-07-16 10:48:00+03	44600.00
47416F	2017-07-09 00:06:00+03	23400.00
474179	2017-07-15 14:04:00+03	13000.00
47418E	2017-07-31 18:36:00+03	58400.00
4741FE	2017-08-06 02:38:00+03	65000.00
47420C	2017-07-16 15:37:00+03	32700.00
474259	2017-08-12 22:04:00+03	51900.00
474281	2017-08-14 16:06:00+03	62300.00
4742B1	2017-07-28 05:59:00+03	44800.00
474359	2017-07-24 14:20:00+03	6800.00
4743DA	2017-07-18 07:55:00+03	67200.00
4743ED	2017-06-29 02:16:00+03	46200.00
47442F	2017-08-06 02:42:00+03	70900.00
474467	2017-07-03 12:27:00+03	51300.00
474477	2017-07-23 00:55:00+03	102800.00
4744F8	2017-08-11 04:48:00+03	44000.00
47451F	2017-07-03 06:33:00+03	43200.00
474524	2017-07-17 11:51:00+03	16400.00
474530	2017-07-02 04:59:00+03	56600.00
474596	2017-07-23 19:14:00+03	59500.00
4745B5	2017-07-02 10:23:00+03	137400.00
4745FC	2017-07-18 14:43:00+03	46000.00
474623	2017-07-13 08:56:00+03	111600.00
474649	2017-07-24 18:26:00+03	110500.00
474677	2017-07-25 17:38:00+03	13700.00
47469B	2017-07-22 03:36:00+03	51600.00
47469D	2017-07-07 03:21:00+03	62200.00
4746F5	2017-08-10 17:55:00+03	100600.00
47470F	2017-07-04 05:01:00+03	123000.00
474738	2017-07-17 14:07:00+03	8200.00
474784	2017-07-14 23:30:00+03	174000.00
47482D	2017-08-15 01:59:00+03	6300.00
474898	2017-07-15 20:09:00+03	6800.00
47489F	2017-08-10 20:37:00+03	38400.00
4748A8	2017-08-04 14:06:00+03	30600.00
4748F6	2017-08-09 07:56:00+03	26700.00
47492A	2017-07-31 07:56:00+03	50400.00
4749F8	2017-07-19 11:13:00+03	185500.00
474A24	2017-07-09 20:03:00+03	182300.00
474A89	2017-07-02 01:00:00+03	50200.00
474A96	2017-07-30 14:00:00+03	60800.00
474AB7	2017-07-13 18:42:00+03	56000.00
474ACD	2017-07-02 14:07:00+03	20800.00
474AE9	2017-08-15 15:39:00+03	57700.00
474B0D	2017-07-15 17:59:00+03	46200.00
474B31	2017-08-11 08:17:00+03	123600.00
474BCF	2017-07-07 04:42:00+03	14000.00
474BE2	2017-07-14 09:27:00+03	37200.00
474C00	2017-08-11 17:38:00+03	124200.00
474C77	2017-08-14 17:44:00+03	49500.00
474D11	2017-07-27 21:45:00+03	37900.00
474D9B	2017-07-24 13:47:00+03	179700.00
474DB0	2017-07-25 05:59:00+03	7200.00
474DD5	2017-08-12 14:18:00+03	51800.00
474DD6	2017-07-17 11:31:00+03	87200.00
474E32	2017-08-05 18:57:00+03	46200.00
474E5A	2017-07-09 19:00:00+03	41700.00
474E80	2017-08-09 04:46:00+03	40600.00
474E8F	2017-08-12 09:16:00+03	8400.00
474E95	2017-07-20 07:37:00+03	203000.00
474EA1	2017-07-16 20:53:00+03	53700.00
474ECE	2017-07-09 08:02:00+03	65400.00
474EF5	2017-07-17 21:36:00+03	136500.00
474F2D	2017-07-15 03:36:00+03	69100.00
474F58	2017-08-09 17:41:00+03	20600.00
474F5F	2017-08-10 23:26:00+03	6000.00
47500C	2017-06-26 18:24:00+03	7400.00
475096	2017-07-17 14:47:00+03	123000.00
4750B7	2017-07-05 14:23:00+03	397700.00
475126	2017-08-09 17:14:00+03	28800.00
47513C	2017-07-30 08:46:00+03	336100.00
475163	2017-07-08 21:50:00+03	67600.00
475170	2017-07-26 18:07:00+03	131600.00
4751C3	2017-07-21 13:53:00+03	23200.00
4751F8	2017-08-02 04:43:00+03	14000.00
47525B	2017-07-31 15:18:00+03	76800.00
4752D8	2017-07-06 23:10:00+03	112000.00
475345	2017-07-03 06:24:00+03	87100.00
475363	2017-07-12 02:54:00+03	12600.00
475379	2017-07-16 01:28:00+03	43500.00
47537F	2017-07-08 20:44:00+03	24400.00
47539C	2017-08-15 12:07:00+03	53600.00
4753AE	2017-08-03 07:36:00+03	135400.00
4753B6	2017-08-06 22:48:00+03	6000.00
4753D3	2017-08-15 14:01:00+03	202600.00
4753E7	2017-08-03 00:13:00+03	69000.00
4753F2	2017-08-02 23:04:00+03	199800.00
475441	2017-07-11 19:07:00+03	25000.00
47546B	2017-08-05 02:19:00+03	87000.00
475471	2017-08-13 14:20:00+03	16400.00
475483	2017-07-08 21:02:00+03	84500.00
475489	2017-07-19 19:16:00+03	8400.00
475559	2017-07-14 05:33:00+03	78900.00
4755ED	2017-07-06 02:34:00+03	269300.00
4755EF	2017-07-12 23:06:00+03	20600.00
4755FA	2017-07-21 03:34:00+03	51900.00
47563B	2017-08-11 02:02:00+03	75600.00
475645	2017-07-20 15:38:00+03	51900.00
47564C	2017-07-18 08:54:00+03	102100.00
475657	2017-08-10 11:43:00+03	88100.00
475661	2017-08-06 08:22:00+03	56000.00
47568F	2017-08-14 02:59:00+03	415300.00
4756D7	2017-07-16 19:57:00+03	28000.00
4756E8	2017-07-30 09:54:00+03	73600.00
47573F	2017-08-06 07:40:00+03	88100.00
47574E	2017-08-11 18:50:00+03	28800.00
47576E	2017-07-16 19:25:00+03	253200.00
475784	2017-07-27 02:17:00+03	265600.00
4757AC	2017-07-29 19:59:00+03	62600.00
4757F3	2017-07-20 08:25:00+03	23200.00
4758A3	2017-08-15 17:13:00+03	88900.00
4758C5	2017-07-08 21:14:00+03	194200.00
4758F3	2017-07-23 18:29:00+03	47400.00
47591E	2017-07-27 18:36:00+03	7200.00
475952	2017-07-19 19:31:00+03	199700.00
475956	2017-07-22 17:44:00+03	48400.00
475987	2017-07-29 15:49:00+03	47000.00
47599B	2017-07-11 21:00:00+03	132800.00
4759FD	2017-07-15 02:54:00+03	28800.00
475A4F	2017-07-27 07:51:00+03	46300.00
475A6A	2017-08-09 15:59:00+03	112000.00
475A6D	2017-07-16 08:11:00+03	58000.00
475AB2	2017-07-23 04:22:00+03	84500.00
475AC1	2017-07-07 00:54:00+03	67500.00
475AEB	2017-07-13 11:58:00+03	73300.00
475B3B	2017-07-30 17:17:00+03	65500.00
475BA5	2017-07-16 07:31:00+03	62600.00
475BAB	2017-07-18 04:03:00+03	93200.00
475BB0	2017-07-17 19:55:00+03	192400.00
475BDF	2017-08-04 12:29:00+03	304100.00
475BF4	2017-08-04 05:00:00+03	25400.00
475C0C	2017-07-24 02:47:00+03	159200.00
475C5C	2017-07-25 16:33:00+03	89200.00
475C5D	2017-08-02 03:25:00+03	399600.00
475CFB	2017-07-08 00:56:00+03	297600.00
475D4C	2017-08-08 05:01:00+03	6300.00
475D78	2017-07-17 03:44:00+03	28000.00
475DD8	2017-07-12 21:27:00+03	6700.00
475E82	2017-07-27 02:51:00+03	6700.00
475ECC	2017-08-05 22:23:00+03	68400.00
475F0D	2017-07-18 20:57:00+03	117800.00
475F17	2017-08-09 13:00:00+03	93500.00
475F20	2017-07-27 03:47:00+03	26200.00
475F9D	2017-07-20 00:29:00+03	75300.00
475FA3	2017-07-04 19:31:00+03	6000.00
476037	2017-08-12 23:42:00+03	43200.00
47603C	2017-07-31 21:50:00+03	59000.00
47604C	2017-08-01 02:56:00+03	265600.00
476073	2017-07-21 20:08:00+03	18400.00
476128	2017-08-04 06:46:00+03	70400.00
47615F	2017-07-19 13:01:00+03	26600.00
4761BD	2017-07-28 04:22:00+03	24400.00
47625F	2017-07-04 12:35:00+03	260300.00
47626A	2017-08-10 22:45:00+03	28800.00
4762B5	2017-07-04 15:24:00+03	283100.00
4762DA	2017-07-12 11:31:00+03	17800.00
47633B	2017-08-06 07:09:00+03	23400.00
47635E	2017-07-06 00:35:00+03	37900.00
47637E	2017-08-14 11:41:00+03	49100.00
476387	2017-08-12 04:44:00+03	202300.00
47638D	2017-07-11 23:04:00+03	408500.00
4763C9	2017-07-26 21:51:00+03	31600.00
476461	2017-07-22 21:42:00+03	62600.00
4764C7	2017-08-05 01:14:00+03	6700.00
47651F	2017-08-12 23:54:00+03	27200.00
47655A	2017-08-11 13:53:00+03	47500.00
47656E	2017-07-02 08:05:00+03	26000.00
4765FF	2017-08-01 14:16:00+03	6700.00
47660B	2017-07-01 23:45:00+03	46000.00
476610	2017-08-13 22:42:00+03	11000.00
476612	2017-07-17 09:38:00+03	275600.00
476629	2017-07-07 11:48:00+03	22000.00
476631	2017-07-31 00:40:00+03	31400.00
47671B	2017-08-11 10:21:00+03	22000.00
476729	2017-08-03 07:55:00+03	98000.00
476797	2017-07-22 17:21:00+03	13000.00
476798	2017-07-20 11:02:00+03	23400.00
476814	2017-07-23 23:12:00+03	22600.00
476850	2017-07-29 05:39:00+03	13600.00
476855	2017-07-20 23:57:00+03	23200.00
476868	2017-08-12 04:41:00+03	22600.00
476869	2017-07-15 10:32:00+03	24800.00
476896	2017-07-27 17:36:00+03	14400.00
4768A4	2017-07-22 18:07:00+03	71900.00
4768F8	2017-07-27 06:32:00+03	101500.00
476906	2017-07-26 20:59:00+03	136200.00
476926	2017-07-18 02:06:00+03	246000.00
476969	2017-07-05 03:26:00+03	28000.00
4769EB	2017-07-08 07:29:00+03	42800.00
476A1D	2017-07-27 16:40:00+03	31600.00
476ABA	2017-08-15 02:13:00+03	40700.00
476AD8	2017-07-27 06:38:00+03	109600.00
476B17	2017-07-29 03:59:00+03	70100.00
476B65	2017-08-04 13:24:00+03	55800.00
476B93	2017-07-19 02:31:00+03	117700.00
476BCB	2017-07-30 05:59:00+03	114800.00
476BFD	2017-08-15 09:53:00+03	264000.00
476C68	2017-08-06 16:49:00+03	43200.00
476CCD	2017-07-22 13:52:00+03	133100.00
476CDA	2017-07-01 19:20:00+03	60600.00
476D7D	2017-08-05 15:55:00+03	118500.00
476DB3	2017-07-12 06:42:00+03	45200.00
476E09	2017-08-02 15:45:00+03	20400.00
476E33	2017-08-12 20:10:00+03	14400.00
476E35	2017-08-04 19:03:00+03	64200.00
476ED8	2017-08-09 03:42:00+03	59200.00
476ED9	2017-07-21 13:51:00+03	19600.00
476EEE	2017-08-09 13:49:00+03	260300.00
476F73	2017-08-01 02:17:00+03	135200.00
476F90	2017-07-31 14:49:00+03	31400.00
476FF3	2017-08-13 12:43:00+03	21800.00
477000	2017-08-13 12:42:00+03	68100.00
4770B3	2017-07-10 01:43:00+03	62000.00
4770D2	2017-07-08 16:17:00+03	62800.00
4770DC	2017-08-06 10:00:00+03	49100.00
4770E8	2017-08-07 17:07:00+03	23100.00
4770E9	2017-08-13 13:44:00+03	142200.00
477129	2017-07-10 13:57:00+03	32900.00
47719D	2017-08-11 20:09:00+03	59900.00
4771AB	2017-08-04 09:43:00+03	40100.00
4771AD	2017-07-06 10:10:00+03	111600.00
477267	2017-07-09 19:29:00+03	6700.00
477285	2017-07-22 12:28:00+03	51900.00
4772C6	2017-08-04 14:41:00+03	112000.00
477313	2017-08-08 01:56:00+03	57600.00
477333	2017-08-10 00:55:00+03	70700.00
477341	2017-07-06 11:07:00+03	46300.00
477362	2017-07-29 09:54:00+03	40600.00
477452	2017-07-22 23:17:00+03	123000.00
477478	2017-07-05 10:30:00+03	86600.00
47748F	2017-07-20 18:55:00+03	46200.00
477496	2017-08-02 15:45:00+03	95200.00
477505	2017-07-06 06:16:00+03	28000.00
47751E	2017-08-05 02:30:00+03	89200.00
477577	2017-08-07 03:35:00+03	59800.00
47759B	2017-08-13 07:22:00+03	67600.00
4775E4	2017-07-06 05:44:00+03	131600.00
477600	2017-08-05 12:55:00+03	48300.00
47762B	2017-07-18 10:06:00+03	18400.00
47762C	2017-07-07 09:56:00+03	54000.00
477633	2017-08-10 16:27:00+03	29500.00
477641	2017-07-04 13:09:00+03	93900.00
477642	2017-06-30 10:22:00+03	6300.00
47771C	2017-07-11 14:19:00+03	92400.00
47778C	2017-07-27 11:19:00+03	60400.00
4777F1	2017-07-14 17:19:00+03	48800.00
477854	2017-08-08 12:24:00+03	34000.00
4778EB	2017-07-03 07:03:00+03	68100.00
477964	2017-07-23 21:51:00+03	28000.00
4779C9	2017-07-05 12:18:00+03	19600.00
477A48	2017-07-13 10:26:00+03	37200.00
477A58	2017-08-07 05:15:00+03	19600.00
477A59	2017-08-10 08:38:00+03	206000.00
477AAE	2017-08-10 01:39:00+03	99500.00
477B35	2017-08-10 09:15:00+03	273000.00
477B93	2017-07-30 16:06:00+03	23900.00
477BA0	2017-08-14 18:11:00+03	29400.00
477C58	2017-07-14 16:43:00+03	227600.00
477CBA	2017-07-15 18:45:00+03	22000.00
477D09	2017-07-18 18:14:00+03	21800.00
477D0B	2017-08-03 02:30:00+03	78700.00
477D11	2017-07-28 19:08:00+03	135400.00
477D38	2017-07-09 12:28:00+03	112600.00
477DAA	2017-07-08 08:52:00+03	25800.00
477DC5	2017-07-20 19:35:00+03	65500.00
477DD2	2017-08-12 23:41:00+03	25400.00
477E24	2017-08-05 14:45:00+03	26000.00
477E32	2017-08-10 01:46:00+03	85500.00
477EA0	2017-08-06 17:58:00+03	41900.00
477F2F	2017-07-17 04:31:00+03	65500.00
477F48	2017-08-07 19:52:00+03	86600.00
477F5B	2017-08-01 22:08:00+03	46000.00
477F6C	2017-08-04 10:23:00+03	38400.00
477F7E	2017-08-11 20:22:00+03	29800.00
477FB1	2017-08-05 09:05:00+03	123000.00
477FB8	2017-07-02 02:12:00+03	258400.00
477FBD	2017-07-08 20:07:00+03	15500.00
477FDF	2017-07-13 16:54:00+03	30200.00
478006	2017-08-10 21:43:00+03	64600.00
47801B	2017-08-15 04:47:00+03	8000.00
478023	2017-08-08 16:21:00+03	19600.00
478042	2017-08-03 21:45:00+03	55600.00
4780C1	2017-07-15 16:55:00+03	78600.00
4780D0	2017-08-13 05:49:00+03	27300.00
478100	2017-06-30 15:48:00+03	10600.00
478155	2017-07-21 16:37:00+03	11700.00
4781FC	2017-07-18 20:09:00+03	20500.00
478233	2017-06-30 11:23:00+03	58800.00
478240	2017-07-17 22:15:00+03	37500.00
47824E	2017-07-21 04:13:00+03	173400.00
4782C0	2017-07-12 08:04:00+03	91600.00
478350	2017-07-16 22:51:00+03	55800.00
478398	2017-08-04 00:37:00+03	47100.00
4783CF	2017-07-01 12:14:00+03	187600.00
4783EA	2017-07-19 10:11:00+03	48800.00
478426	2017-07-17 13:29:00+03	136200.00
47844E	2017-07-03 13:50:00+03	23600.00
478478	2017-07-19 00:21:00+03	54800.00
4784F9	2017-07-12 01:49:00+03	93000.00
4785AC	2017-08-02 14:52:00+03	26100.00
4785F7	2017-07-17 04:30:00+03	23600.00
47869E	2017-07-08 12:22:00+03	31500.00
4786A3	2017-07-20 03:10:00+03	24700.00
4786F2	2017-07-26 05:21:00+03	56000.00
478717	2017-08-01 07:26:00+03	13000.00
478735	2017-08-06 15:35:00+03	48100.00
478768	2017-08-09 20:57:00+03	122300.00
478775	2017-08-11 14:30:00+03	32800.00
47877B	2017-07-14 09:54:00+03	59800.00
4787D6	2017-07-21 17:45:00+03	7400.00
4787D7	2017-06-25 15:29:00+03	37100.00
478832	2017-08-09 01:45:00+03	12600.00
478871	2017-08-07 07:43:00+03	99700.00
4788CB	2017-08-08 21:59:00+03	111600.00
4788D6	2017-07-04 16:30:00+03	13600.00
47892D	2017-07-07 16:14:00+03	38400.00
47898D	2017-08-05 12:17:00+03	25800.00
4789C2	2017-08-07 20:45:00+03	66600.00
4789C4	2017-06-26 09:32:00+03	129700.00
4789E4	2017-08-15 11:44:00+03	156300.00
478A19	2017-07-19 09:57:00+03	32200.00
478A32	2017-07-27 06:22:00+03	196800.00
478A78	2017-08-02 05:57:00+03	36200.00
478A8B	2017-07-31 07:24:00+03	34000.00
478AA1	2017-08-08 02:48:00+03	8000.00
478AD2	2017-07-31 00:54:00+03	119500.00
478B03	2017-07-25 23:27:00+03	55800.00
478B0A	2017-08-13 15:27:00+03	60400.00
478B95	2017-06-29 08:02:00+03	56100.00
478BB7	2017-08-02 22:32:00+03	26000.00
478BF8	2017-07-27 15:55:00+03	26700.00
478C38	2017-07-07 04:16:00+03	70800.00
478C68	2017-08-13 15:46:00+03	85000.00
478C96	2017-07-04 14:36:00+03	14800.00
478CA1	2017-07-04 16:41:00+03	44800.00
478D0E	2017-07-23 21:13:00+03	105400.00
478D1F	2017-08-09 05:36:00+03	19600.00
478EAF	2017-07-24 06:59:00+03	61800.00
478EC4	2017-08-01 17:30:00+03	36400.00
478F11	2017-07-28 09:34:00+03	75300.00
478F1B	2017-07-11 00:51:00+03	83000.00
478F31	2017-07-17 22:04:00+03	24400.00
478F38	2017-08-11 10:19:00+03	43600.00
479073	2017-07-24 02:08:00+03	68800.00
4790E6	2017-08-03 22:32:00+03	125100.00
4790ED	2017-08-10 02:42:00+03	38600.00
479163	2017-07-22 06:05:00+03	52000.00
479185	2017-07-22 21:37:00+03	45200.00
4791F8	2017-07-07 06:01:00+03	265700.00
479260	2017-08-13 04:22:00+03	112600.00
479277	2017-08-10 14:00:00+03	69000.00
479289	2017-08-07 05:57:00+03	67500.00
479312	2017-07-10 16:12:00+03	56600.00
479330	2017-07-14 21:57:00+03	209000.00
479366	2017-07-21 03:05:00+03	144700.00
4793A8	2017-08-01 07:45:00+03	105100.00
4793FD	2017-07-04 17:21:00+03	21000.00
479409	2017-07-13 23:08:00+03	67600.00
47941D	2017-07-12 14:05:00+03	27200.00
47944E	2017-07-28 06:41:00+03	51900.00
479466	2017-07-27 21:16:00+03	22600.00
47946C	2017-08-04 12:49:00+03	28800.00
479483	2017-07-12 01:06:00+03	52400.00
4794D8	2017-07-04 02:18:00+03	23200.00
4794DF	2017-08-02 05:47:00+03	99200.00
479501	2017-08-13 03:01:00+03	57500.00
47950A	2017-08-13 06:48:00+03	54800.00
479513	2017-07-16 02:45:00+03	28800.00
479585	2017-08-05 02:56:00+03	46400.00
479588	2017-07-30 00:04:00+03	59300.00
479626	2017-08-03 06:32:00+03	133200.00
47965B	2017-07-16 06:00:00+03	12000.00
4796E6	2017-07-20 04:16:00+03	104000.00
47973F	2017-07-23 10:53:00+03	88000.00
4797AB	2017-08-15 10:18:00+03	117600.00
4797AC	2017-08-15 02:31:00+03	28300.00
4797CB	2017-08-01 22:00:00+03	40600.00
4797D0	2017-07-06 05:42:00+03	86400.00
4797E2	2017-07-18 10:19:00+03	199200.00
4797E6	2017-07-09 06:53:00+03	74300.00
479800	2017-07-07 15:23:00+03	70400.00
479805	2017-08-03 04:59:00+03	65000.00
479841	2017-07-16 16:19:00+03	29600.00
4798F0	2017-07-06 05:16:00+03	55800.00
4798FD	2017-07-31 04:53:00+03	55800.00
4799B4	2017-08-10 23:49:00+03	265800.00
479A3B	2017-08-14 03:08:00+03	47000.00
479A5D	2017-08-02 17:56:00+03	70700.00
479B44	2017-07-10 08:03:00+03	145300.00
479B4C	2017-07-30 15:11:00+03	59800.00
479BD5	2017-07-31 16:54:00+03	29600.00
479C51	2017-07-08 04:14:00+03	48900.00
479C52	2017-07-14 12:49:00+03	110600.00
479C7E	2017-07-22 22:08:00+03	118500.00
479CDD	2017-07-08 16:35:00+03	162700.00
479D01	2017-08-09 09:33:00+03	38100.00
479DC8	2017-07-28 13:40:00+03	73500.00
479E20	2017-07-09 01:12:00+03	96800.00
479EC4	2017-07-01 12:56:00+03	28800.00
479ECA	2017-07-15 15:05:00+03	57500.00
479ED7	2017-08-09 01:26:00+03	38600.00
479F58	2017-08-12 12:54:00+03	40800.00
479F83	2017-08-13 19:41:00+03	175300.00
479F9D	2017-08-14 17:06:00+03	36200.00
479FB0	2017-08-02 04:45:00+03	77500.00
479FB5	2017-07-30 06:55:00+03	101100.00
479FE7	2017-08-09 15:26:00+03	21000.00
47A01D	2017-07-12 09:24:00+03	55800.00
47A01E	2017-07-31 05:20:00+03	47100.00
47A027	2017-08-10 21:41:00+03	46000.00
47A05C	2017-08-04 19:50:00+03	62700.00
47A104	2017-07-21 19:27:00+03	89600.00
47A142	2017-07-29 06:05:00+03	29200.00
47A14B	2017-08-02 16:14:00+03	68800.00
47A18B	2017-07-11 18:32:00+03	132800.00
47A1C3	2017-07-25 11:24:00+03	6000.00
47A1D0	2017-08-07 21:27:00+03	44000.00
47A1E9	2017-08-08 08:50:00+03	115400.00
47A217	2017-07-23 01:19:00+03	32700.00
47A227	2017-07-06 23:33:00+03	92400.00
47A236	2017-07-09 09:01:00+03	118600.00
47A28C	2017-08-15 01:23:00+03	12600.00
47A292	2017-07-04 16:29:00+03	47400.00
47A2F0	2017-08-01 17:04:00+03	58000.00
47A31C	2017-07-06 18:45:00+03	135300.00
47A38F	2017-07-27 03:16:00+03	46800.00
47A3DD	2017-07-12 19:07:00+03	32800.00
47A3E0	2017-07-28 00:31:00+03	265600.00
47A407	2017-08-12 19:03:00+03	15300.00
47A423	2017-07-24 01:03:00+03	23200.00
47A438	2017-07-13 09:06:00+03	37500.00
47A44D	2017-07-31 10:53:00+03	26000.00
47A48B	2017-07-26 11:33:00+03	56600.00
47A500	2017-07-11 07:21:00+03	271400.00
47A57B	2017-07-08 02:51:00+03	123000.00
47A630	2017-07-20 00:32:00+03	48500.00
47A651	2017-07-13 08:39:00+03	70700.00
47A659	2017-08-14 18:53:00+03	128900.00
47A6CF	2017-07-23 02:39:00+03	45400.00
47A7B5	2017-07-30 21:55:00+03	131900.00
47A81B	2017-07-16 07:45:00+03	28300.00
47A87E	2017-08-14 05:04:00+03	113800.00
47A8C5	2017-07-19 14:10:00+03	48100.00
47A8D1	2017-07-31 09:01:00+03	40400.00
47A8E4	2017-07-12 00:04:00+03	80900.00
47A8EE	2017-07-14 12:46:00+03	54800.00
47A926	2017-07-12 11:14:00+03	343900.00
47A950	2017-08-09 17:49:00+03	55800.00
47A9D3	2017-07-05 08:56:00+03	47000.00
47A9F4	2017-07-25 16:55:00+03	243600.00
47AA03	2017-08-04 18:49:00+03	7400.00
47AA07	2017-07-31 19:56:00+03	18000.00
47AA09	2017-07-23 20:29:00+03	59800.00
47AA0E	2017-07-09 20:32:00+03	114400.00
47AA32	2017-07-01 21:22:00+03	84000.00
47AA3C	2017-08-03 12:51:00+03	47500.00
47AA3D	2017-07-15 19:53:00+03	56900.00
47AA48	2017-07-08 20:14:00+03	6000.00
47AA5F	2017-07-07 06:41:00+03	58700.00
47AAB6	2017-07-17 16:26:00+03	81200.00
47AADE	2017-07-09 07:43:00+03	39800.00
47AB12	2017-07-06 07:18:00+03	66600.00
47AB24	2017-07-01 18:45:00+03	23200.00
47AB29	2017-08-14 18:57:00+03	14000.00
47ABBA	2017-07-31 14:15:00+03	56900.00
47ABE9	2017-08-05 07:20:00+03	103800.00
47AC1B	2017-07-29 23:18:00+03	113200.00
47AC1F	2017-07-13 13:12:00+03	24200.00
47AC39	2017-07-03 15:40:00+03	47600.00
47ACD1	2017-07-06 11:35:00+03	147700.00
47AD36	2017-08-02 15:22:00+03	37900.00
47AD42	2017-06-30 16:47:00+03	42600.00
47AD53	2017-07-31 09:18:00+03	35800.00
47ADB7	2017-07-19 11:00:00+03	54800.00
47ADE0	2017-07-28 09:52:00+03	88500.00
47AE0B	2017-07-31 23:58:00+03	28800.00
47AF0E	2017-07-28 08:16:00+03	69500.00
47AFEF	2017-08-11 01:02:00+03	38700.00
47B00F	2017-06-29 03:05:00+03	44800.00
47B04F	2017-07-17 04:20:00+03	34600.00
47B073	2017-07-04 03:39:00+03	29600.00
47B105	2017-07-04 00:27:00+03	40800.00
47B128	2017-08-05 13:43:00+03	166600.00
47B199	2017-08-09 07:34:00+03	46800.00
47B1AD	2017-07-12 00:07:00+03	44600.00
47B1B2	2017-07-31 17:35:00+03	14000.00
47B1C7	2017-08-01 19:56:00+03	40200.00
47B1C9	2017-08-11 04:45:00+03	45000.00
47B21B	2017-06-30 16:25:00+03	206400.00
47B21F	2017-07-11 12:31:00+03	32800.00
47B228	2017-08-01 04:06:00+03	68400.00
47B271	2017-08-02 12:59:00+03	28800.00
47B2A0	2017-06-28 06:06:00+03	12600.00
47B2B7	2017-07-23 13:19:00+03	6700.00
47B2C7	2017-08-05 01:35:00+03	78700.00
47B2F9	2017-08-13 06:46:00+03	102200.00
47B336	2017-07-17 01:39:00+03	67900.00
47B35A	2017-07-28 05:24:00+03	75600.00
47B40C	2017-07-15 13:25:00+03	13600.00
47B423	2017-08-11 03:58:00+03	133200.00
47B4C2	2017-07-01 03:15:00+03	45200.00
47B520	2017-08-11 14:07:00+03	44800.00
47B538	2017-07-23 11:48:00+03	25600.00
47B539	2017-08-02 02:43:00+03	492000.00
47B595	2017-07-07 16:09:00+03	28300.00
47B597	2017-07-25 13:48:00+03	125400.00
47B5B6	2017-07-13 01:45:00+03	26200.00
47B61E	2017-07-31 04:08:00+03	40800.00
47B62F	2017-08-13 05:52:00+03	137100.00
47B634	2017-07-04 04:57:00+03	25000.00
47B660	2017-07-14 20:01:00+03	56600.00
47B663	2017-07-12 07:53:00+03	140900.00
47B676	2017-07-10 05:58:00+03	94900.00
47B67B	2017-07-01 06:51:00+03	174400.00
47B703	2017-08-03 14:58:00+03	216000.00
47B738	2017-07-11 18:42:00+03	69500.00
47B73F	2017-08-10 17:26:00+03	105200.00
47B784	2017-07-30 07:28:00+03	135400.00
47B7A0	2017-07-26 12:40:00+03	92800.00
47B7E8	2017-07-20 20:25:00+03	54200.00
47B85B	2017-07-18 21:17:00+03	310400.00
47B863	2017-08-10 06:21:00+03	53600.00
47B8A5	2017-08-13 02:49:00+03	56000.00
47B8DC	2017-08-02 04:15:00+03	16000.00
47B91B	2017-08-06 19:41:00+03	106400.00
47B934	2017-08-08 16:53:00+03	72400.00
47B95E	2017-07-16 06:07:00+03	46400.00
47B970	2017-07-06 22:18:00+03	273000.00
47B987	2017-07-15 03:10:00+03	37900.00
47B998	2017-07-13 00:16:00+03	135400.00
47BA15	2017-08-10 13:48:00+03	258400.00
47BAA7	2017-07-02 16:07:00+03	35600.00
47BAAE	2017-08-13 06:58:00+03	181600.00
47BAE9	2017-07-18 22:57:00+03	32700.00
47BB1F	2017-07-15 03:01:00+03	94800.00
47BB2A	2017-07-25 11:30:00+03	86600.00
47BB30	2017-08-03 00:14:00+03	23200.00
47BB73	2017-07-24 05:55:00+03	11800.00
47BB90	2017-07-07 07:05:00+03	133200.00
47BBA7	2017-07-08 03:36:00+03	244400.00
47BBAA	2017-07-30 08:01:00+03	13500.00
47BBCE	2017-07-22 11:59:00+03	28700.00
47BBDE	2017-07-15 15:51:00+03	369000.00
47BC01	2017-07-10 19:56:00+03	112000.00
47BC30	2017-07-08 14:08:00+03	112000.00
47BCB6	2017-07-06 20:31:00+03	69500.00
47BCDA	2017-06-30 10:05:00+03	123900.00
47BDB1	2017-07-13 18:07:00+03	81300.00
47BE7D	2017-07-26 23:18:00+03	59300.00
47BE9E	2017-07-03 06:12:00+03	32800.00
47BEAA	2017-07-18 16:41:00+03	46000.00
47BECE	2017-07-23 06:42:00+03	29600.00
47BEEF	2017-07-21 20:51:00+03	47200.00
47BF27	2017-07-31 20:53:00+03	56600.00
47BF36	2017-07-29 02:25:00+03	136800.00
47BFE4	2017-08-10 03:18:00+03	61400.00
47C09B	2017-07-24 06:11:00+03	75300.00
47C10B	2017-07-21 05:20:00+03	28000.00
47C121	2017-07-13 23:38:00+03	42800.00
47C12C	2017-07-24 16:46:00+03	125100.00
47C149	2017-07-31 19:33:00+03	72300.00
47C18A	2017-08-05 06:03:00+03	28000.00
47C224	2017-07-05 22:37:00+03	86800.00
47C24A	2017-07-29 15:49:00+03	46300.00
47C299	2017-07-15 15:55:00+03	72400.00
47C2BF	2017-07-21 12:26:00+03	96800.00
47C2EE	2017-07-31 04:23:00+03	266300.00
47C374	2017-07-14 08:57:00+03	301600.00
47C38A	2017-08-06 22:02:00+03	27200.00
47C3CA	2017-07-31 00:30:00+03	47800.00
47C44C	2017-08-10 18:55:00+03	12600.00
47C460	2017-08-03 01:21:00+03	50400.00
47C467	2017-08-10 09:44:00+03	27800.00
47C473	2017-08-10 20:31:00+03	44500.00
47C482	2017-08-09 17:38:00+03	177700.00
47C50E	2017-08-02 07:00:00+03	259600.00
47C51A	2017-07-09 16:08:00+03	35200.00
47C573	2017-08-10 18:17:00+03	56000.00
47C57B	2017-07-15 22:57:00+03	51800.00
47C58F	2017-07-08 10:27:00+03	147100.00
47C5A0	2017-07-11 18:33:00+03	35200.00
47C5B8	2017-07-30 10:16:00+03	23600.00
47C5E2	2017-06-25 07:13:00+03	88600.00
47C5FC	2017-06-30 05:33:00+03	57600.00
47C5FD	2017-06-29 02:03:00+03	59000.00
47C613	2017-08-02 12:00:00+03	49500.00
47C695	2017-07-11 09:51:00+03	56100.00
47C6B7	2017-07-21 09:30:00+03	13000.00
47C6EA	2017-07-20 00:49:00+03	16400.00
47C706	2017-07-29 09:33:00+03	85000.00
47C725	2017-08-09 02:23:00+03	75300.00
47C72B	2017-07-11 17:22:00+03	28000.00
47C74E	2017-08-15 06:15:00+03	14000.00
47C7BC	2017-07-20 08:38:00+03	28000.00
47C84A	2017-07-20 17:37:00+03	176500.00
47C85A	2017-07-21 19:38:00+03	99200.00
47C8D1	2017-07-08 01:39:00+03	44400.00
47C8D6	2017-08-15 11:44:00+03	73200.00
47C8F3	2017-07-30 00:58:00+03	24400.00
47C8FC	2017-08-03 18:37:00+03	95600.00
47C96C	2017-08-09 02:47:00+03	27200.00
47C97F	2017-07-08 14:03:00+03	56100.00
47C9F8	2017-07-25 00:52:00+03	39400.00
47CA38	2017-07-28 14:11:00+03	95200.00
47CA48	2017-07-26 04:37:00+03	64800.00
47CA97	2017-08-04 07:06:00+03	58400.00
47CAAD	2017-07-05 23:32:00+03	400000.00
47CAB4	2017-07-31 02:12:00+03	70600.00
47CAB7	2017-07-09 00:23:00+03	135400.00
47CAF4	2017-07-12 05:27:00+03	81700.00
47CB14	2017-08-13 07:05:00+03	56000.00
47CB37	2017-07-12 11:10:00+03	56600.00
47CBDE	2017-08-06 12:39:00+03	271100.00
47CC34	2017-07-07 17:42:00+03	197800.00
47CC37	2017-07-31 01:13:00+03	56200.00
47CD6F	2017-08-14 16:29:00+03	74200.00
47CDA2	2017-07-29 12:18:00+03	28800.00
47CDB5	2017-08-10 10:11:00+03	98200.00
47CDF1	2017-07-03 22:05:00+03	47100.00
47CE3D	2017-08-01 21:45:00+03	75600.00
47CE54	2017-07-07 20:09:00+03	44600.00
47CE5A	2017-08-10 08:52:00+03	38400.00
47CE87	2017-07-24 19:21:00+03	57500.00
47CE96	2017-08-10 21:02:00+03	14400.00
47CEBD	2017-07-24 18:26:00+03	94700.00
47CF3A	2017-07-30 18:58:00+03	15000.00
47CF71	2017-07-24 04:43:00+03	59800.00
47CFB5	2017-08-10 13:35:00+03	37200.00
47CFDF	2017-08-09 20:22:00+03	68100.00
47D014	2017-07-24 06:15:00+03	76600.00
47D064	2017-07-02 08:17:00+03	75600.00
47D065	2017-07-23 03:45:00+03	8000.00
47D099	2017-07-11 12:19:00+03	30200.00
47D142	2017-07-24 21:03:00+03	88600.00
47D25D	2017-07-24 10:05:00+03	53600.00
47D2B7	2017-07-22 13:13:00+03	135400.00
47D2BF	2017-07-02 08:47:00+03	36200.00
47D380	2017-06-26 20:41:00+03	24200.00
47D383	2017-08-12 13:39:00+03	112000.00
47D3CE	2017-07-12 23:34:00+03	61800.00
47D446	2017-08-12 22:43:00+03	21400.00
47D453	2017-07-13 18:57:00+03	55800.00
47D4B0	2017-08-04 03:09:00+03	246000.00
47D515	2017-07-29 02:44:00+03	101900.00
47D554	2017-07-10 21:34:00+03	36200.00
47D662	2017-07-07 08:51:00+03	28000.00
47D672	2017-07-27 15:55:00+03	19600.00
47D6C5	2017-08-12 17:36:00+03	50000.00
47D6E2	2017-07-04 19:57:00+03	40000.00
47D72A	2017-08-15 07:46:00+03	32700.00
47D77A	2017-07-13 16:20:00+03	73400.00
47D846	2017-07-02 12:02:00+03	119500.00
47D86D	2017-08-10 07:50:00+03	48800.00
47D920	2017-07-23 12:34:00+03	39300.00
47D93D	2017-07-22 13:18:00+03	14000.00
47D95B	2017-07-28 19:09:00+03	67200.00
47D961	2017-07-06 06:25:00+03	36200.00
47D98E	2017-07-29 19:56:00+03	202300.00
47D9F5	2017-07-07 20:15:00+03	135400.00
47D9F7	2017-07-09 05:48:00+03	67600.00
47DA74	2017-07-12 23:34:00+03	6000.00
47DAEF	2017-08-03 11:05:00+03	20100.00
47DB29	2017-07-28 00:24:00+03	208100.00
47DB4A	2017-08-02 00:25:00+03	13400.00
47DB50	2017-07-14 09:39:00+03	6300.00
47DB54	2017-07-17 10:07:00+03	27200.00
47DB94	2017-07-14 17:19:00+03	68000.00
47DC60	2017-07-14 18:36:00+03	12600.00
47DC6F	2017-07-20 19:48:00+03	44400.00
47DC7B	2017-07-20 18:53:00+03	154800.00
47DCAD	2017-08-01 01:55:00+03	92700.00
47DCEA	2017-08-11 04:59:00+03	6300.00
47DD70	2017-08-14 22:54:00+03	58600.00
47DD85	2017-07-18 11:21:00+03	86800.00
47DDC9	2017-07-14 19:01:00+03	56600.00
47DDEA	2017-07-18 00:39:00+03	123700.00
47DE30	2017-07-23 04:29:00+03	74400.00
47DE50	2017-07-13 02:00:00+03	77200.00
47DEC7	2017-07-21 11:56:00+03	398500.00
47DED8	2017-07-22 20:45:00+03	37900.00
47DF20	2017-08-15 07:45:00+03	62300.00
47DF47	2017-07-08 05:25:00+03	77600.00
47DF6B	2017-07-13 20:50:00+03	25600.00
47DF6D	2017-08-04 14:56:00+03	25000.00
47DF70	2017-07-15 17:17:00+03	131300.00
47DF93	2017-08-05 08:26:00+03	8200.00
47E029	2017-07-28 16:07:00+03	48800.00
47E0AD	2017-08-04 06:56:00+03	64700.00
47E185	2017-07-26 00:14:00+03	14400.00
47E18F	2017-07-20 13:48:00+03	44000.00
47E195	2017-06-29 00:05:00+03	28800.00
47E1AE	2017-07-06 19:54:00+03	37100.00
47E202	2017-07-07 08:07:00+03	38400.00
47E212	2017-07-11 23:42:00+03	73600.00
47E22C	2017-07-10 01:04:00+03	46400.00
47E243	2017-07-06 23:10:00+03	138000.00
47E24D	2017-07-06 23:17:00+03	55800.00
47E27B	2017-07-30 01:19:00+03	29600.00
47E28A	2017-08-13 14:44:00+03	148200.00
47E296	2017-08-15 14:43:00+03	35700.00
47E2DE	2017-07-22 08:09:00+03	155600.00
47E446	2017-08-10 12:59:00+03	69400.00
47E470	2017-08-01 10:57:00+03	46900.00
47E476	2017-07-22 00:50:00+03	26000.00
47E481	2017-07-04 15:40:00+03	101200.00
47E4DD	2017-08-14 12:03:00+03	129700.00
47E4EC	2017-08-06 17:41:00+03	103600.00
47E560	2017-08-08 19:58:00+03	47600.00
47E594	2017-08-05 17:36:00+03	94800.00
47E5C5	2017-07-24 13:54:00+03	140900.00
47E5FF	2017-08-03 07:03:00+03	239400.00
47E618	2017-08-05 10:04:00+03	205700.00
47E6AB	2017-07-12 17:16:00+03	52700.00
47E6B9	2017-08-01 02:39:00+03	52300.00
47E71A	2017-08-02 16:19:00+03	72400.00
47E749	2017-07-01 13:01:00+03	46000.00
47E7E0	2017-07-14 16:44:00+03	168000.00
47E7F0	2017-07-14 03:59:00+03	92000.00
47E7F7	2017-07-08 16:41:00+03	20400.00
47E82C	2017-08-11 01:03:00+03	100600.00
47E840	2017-08-01 09:29:00+03	24400.00
47E8CC	2017-07-11 06:07:00+03	25600.00
47E912	2017-07-26 19:31:00+03	40200.00
47E941	2017-07-21 02:19:00+03	137800.00
47EABD	2017-07-28 16:40:00+03	38400.00
47EACB	2017-07-11 12:13:00+03	88600.00
47EB23	2017-08-08 17:06:00+03	53200.00
47EB3C	2017-08-12 03:48:00+03	39500.00
47EB58	2017-08-14 07:29:00+03	60400.00
47EB64	2017-07-22 03:56:00+03	177600.00
47EB6A	2017-07-12 21:59:00+03	32200.00
47EB8F	2017-07-26 11:31:00+03	266400.00
47EBAD	2017-07-23 04:16:00+03	21800.00
47EBE3	2017-06-30 13:46:00+03	28000.00
47EBFB	2017-08-10 05:14:00+03	28000.00
47EC4B	2017-07-24 05:23:00+03	44800.00
47EC5A	2017-07-27 13:55:00+03	49300.00
47ECC4	2017-08-09 03:00:00+03	57600.00
47ECCA	2017-07-20 04:17:00+03	4400.00
47ECE8	2017-08-12 03:28:00+03	119500.00
47ECFF	2017-08-09 12:38:00+03	544700.00
47ED2C	2017-07-21 06:30:00+03	48800.00
47ED5B	2017-08-02 16:05:00+03	57600.00
47ED79	2017-07-04 01:13:00+03	26000.00
47EDA6	2017-08-07 18:38:00+03	66600.00
47EE24	2017-07-01 08:58:00+03	32700.00
47EE4D	2017-08-02 12:32:00+03	399600.00
47EE68	2017-07-07 19:35:00+03	67200.00
47EE90	2017-07-03 22:12:00+03	58900.00
47EF10	2017-07-30 09:00:00+03	22000.00
47EFA6	2017-07-14 00:05:00+03	25000.00
47EFB5	2017-07-30 23:41:00+03	56900.00
47EFBE	2017-07-19 16:31:00+03	66800.00
47EFF2	2017-07-14 20:32:00+03	20200.00
47F01A	2017-08-04 22:18:00+03	29600.00
47F034	2017-07-06 17:44:00+03	137400.00
47F09C	2017-08-08 10:37:00+03	29400.00
47F136	2017-07-22 05:55:00+03	14400.00
47F15F	2017-07-22 04:30:00+03	118600.00
47F18F	2017-07-22 20:18:00+03	119600.00
47F1C9	2017-07-05 17:27:00+03	84200.00
47F1D2	2017-07-30 07:51:00+03	83000.00
47F1F6	2017-08-14 01:36:00+03	28800.00
47F21E	2017-07-24 10:08:00+03	26000.00
47F22E	2017-07-14 04:32:00+03	28000.00
47F2EC	2017-07-03 15:03:00+03	34000.00
47F326	2017-07-27 19:37:00+03	12400.00
47F3D4	2017-08-09 19:15:00+03	93900.00
47F42B	2017-08-04 00:44:00+03	123000.00
47F471	2017-07-15 21:42:00+03	240600.00
47F489	2017-07-16 09:13:00+03	47200.00
47F48F	2017-07-15 03:25:00+03	36400.00
47F4B6	2017-07-21 16:50:00+03	19600.00
47F4BE	2017-08-01 14:21:00+03	8200.00
47F4EC	2017-07-07 17:38:00+03	99300.00
47F50E	2017-08-07 17:58:00+03	26000.00
47F555	2017-08-08 08:35:00+03	63000.00
47F5A1	2017-08-12 10:52:00+03	28000.00
47F617	2017-08-04 01:27:00+03	57800.00
47F654	2017-07-31 13:58:00+03	92000.00
47F6DB	2017-07-31 00:01:00+03	89600.00
47F7E5	2017-07-13 18:04:00+03	14400.00
47F7E8	2017-07-10 10:03:00+03	15900.00
47F823	2017-08-13 18:56:00+03	57600.00
47F837	2017-07-24 23:06:00+03	56600.00
47F861	2017-07-10 20:38:00+03	26200.00
47F8D7	2017-07-25 17:04:00+03	174600.00
47F8E5	2017-07-25 22:45:00+03	229900.00
47F8FE	2017-06-29 05:50:00+03	40000.00
47F940	2017-07-30 21:00:00+03	139200.00
47F94D	2017-08-14 20:52:00+03	45100.00
47F984	2017-07-19 08:18:00+03	50400.00
47F9FF	2017-08-12 11:02:00+03	41200.00
47FA3B	2017-07-13 21:32:00+03	197200.00
47FA45	2017-07-08 04:25:00+03	32300.00
47FA46	2017-07-31 07:01:00+03	51200.00
47FA74	2017-08-14 11:23:00+03	6600.00
47FB00	2017-07-22 00:19:00+03	38600.00
47FBF6	2017-07-15 22:57:00+03	50000.00
47FCBC	2017-08-01 03:06:00+03	40000.00
47FCCF	2017-07-04 21:09:00+03	56000.00
47FCE7	2017-07-31 14:41:00+03	20400.00
47FD37	2017-08-15 17:50:00+03	71800.00
47FD7F	2017-07-03 05:24:00+03	195800.00
47FE16	2017-08-12 03:21:00+03	109000.00
47FE3D	2017-08-15 10:01:00+03	66300.00
47FE95	2017-08-04 08:32:00+03	200500.00
47FEE1	2017-07-21 11:23:00+03	94800.00
47FF0E	2017-07-11 06:21:00+03	112600.00
47FF8A	2017-07-28 04:48:00+03	273000.00
47FFA1	2017-07-15 00:01:00+03	136800.00
48000B	2017-07-18 04:06:00+03	12600.00
480031	2017-07-28 03:23:00+03	67200.00
480072	2017-07-30 03:04:00+03	69500.00
480079	2017-07-31 22:41:00+03	55600.00
4800AD	2017-08-03 14:26:00+03	42800.00
4800C3	2017-07-19 10:23:00+03	20900.00
480111	2017-08-11 20:42:00+03	73200.00
480120	2017-07-10 23:47:00+03	92800.00
480129	2017-07-18 14:26:00+03	48500.00
480167	2017-07-22 06:04:00+03	28000.00
4801A8	2017-07-21 22:05:00+03	22000.00
4801AD	2017-07-22 20:26:00+03	24600.00
4801FA	2017-07-22 13:42:00+03	143200.00
48021E	2017-08-02 03:09:00+03	28800.00
48022B	2017-07-10 08:28:00+03	24800.00
48025B	2017-07-13 23:33:00+03	325500.00
48025E	2017-07-15 06:39:00+03	11700.00
48026A	2017-08-07 17:56:00+03	43000.00
480277	2017-07-23 08:51:00+03	75600.00
480296	2017-08-03 09:48:00+03	84300.00
480310	2017-08-15 05:30:00+03	170800.00
48033B	2017-07-04 20:18:00+03	56000.00
480351	2017-07-25 00:32:00+03	24000.00
480352	2017-08-03 07:12:00+03	57600.00
480368	2017-08-11 14:31:00+03	54800.00
480376	2017-07-17 05:40:00+03	68000.00
480382	2017-07-28 07:35:00+03	26800.00
4803BD	2017-07-31 23:36:00+03	147900.00
480449	2017-07-06 20:55:00+03	79100.00
480459	2017-07-17 08:25:00+03	67600.00
480474	2017-07-01 20:29:00+03	95900.00
4804D2	2017-07-15 18:17:00+03	100400.00
4804EB	2017-07-13 13:47:00+03	145300.00
480572	2017-07-06 20:11:00+03	35300.00
48057F	2017-08-02 02:34:00+03	20400.00
4805BD	2017-07-30 13:24:00+03	16400.00
4805BF	2017-07-30 12:45:00+03	58000.00
4805CD	2017-08-05 04:11:00+03	103500.00
4805D7	2017-08-08 16:29:00+03	50700.00
4805DF	2017-07-01 15:46:00+03	28000.00
480613	2017-07-26 13:37:00+03	284300.00
48061B	2017-08-11 11:04:00+03	47100.00
480643	2017-07-26 04:32:00+03	252200.00
480647	2017-06-29 09:42:00+03	45200.00
4806CE	2017-08-03 21:53:00+03	62600.00
4806DF	2017-07-09 08:21:00+03	29800.00
48070E	2017-07-05 05:45:00+03	81700.00
48078E	2017-07-17 20:36:00+03	131600.00
4807C5	2017-08-07 17:32:00+03	68100.00
4807D8	2017-07-12 10:11:00+03	6700.00
4807F7	2017-07-19 05:19:00+03	6000.00
480867	2017-07-29 14:08:00+03	129500.00
480881	2017-08-08 16:18:00+03	86500.00
4808EE	2017-08-11 03:26:00+03	26200.00
48094C	2017-08-12 10:15:00+03	58500.00
48096E	2017-08-06 13:31:00+03	47800.00
480980	2017-07-22 22:49:00+03	68800.00
480985	2017-07-26 04:21:00+03	13400.00
48098E	2017-07-16 09:40:00+03	82500.00
4809E6	2017-07-09 21:46:00+03	33300.00
480A74	2017-06-30 20:43:00+03	63700.00
480AB9	2017-08-11 04:47:00+03	25800.00
480AEF	2017-08-13 12:29:00+03	55100.00
480AFA	2017-08-14 08:00:00+03	41400.00
480B70	2017-07-18 04:28:00+03	112000.00
480B7B	2017-07-25 11:12:00+03	25100.00
480BC1	2017-07-05 02:38:00+03	174400.00
480C4D	2017-08-14 00:46:00+03	96800.00
480C61	2017-07-26 22:13:00+03	90800.00
480C8B	2017-07-28 04:02:00+03	28800.00
480CBC	2017-07-22 14:22:00+03	35200.00
480D15	2017-07-15 05:14:00+03	23600.00
480D59	2017-08-09 06:50:00+03	56000.00
480D65	2017-07-24 00:16:00+03	44000.00
480DFA	2017-08-01 10:47:00+03	134400.00
480E1D	2017-07-18 09:13:00+03	46800.00
480E5E	2017-07-25 04:48:00+03	92800.00
480EBC	2017-07-26 10:43:00+03	59200.00
480F0E	2017-07-09 17:45:00+03	36200.00
480F1C	2017-07-21 13:45:00+03	66000.00
480F34	2017-07-08 19:51:00+03	73200.00
480F5D	2017-08-04 19:16:00+03	168600.00
480F6E	2017-07-23 09:33:00+03	27200.00
480F73	2017-08-01 12:43:00+03	103200.00
480F8B	2017-08-11 05:37:00+03	12600.00
480FA5	2017-07-06 14:43:00+03	136200.00
480FB4	2017-08-03 19:14:00+03	26700.00
481010	2017-07-30 18:28:00+03	46000.00
481012	2017-08-06 21:48:00+03	219300.00
481099	2017-08-09 13:19:00+03	55800.00
4810A9	2017-08-10 09:33:00+03	247800.00
4810C3	2017-08-07 23:48:00+03	73600.00
481123	2017-08-07 15:17:00+03	45100.00
48114E	2017-07-22 16:36:00+03	116500.00
48116F	2017-07-23 15:45:00+03	32800.00
48126A	2017-07-30 05:23:00+03	52000.00
481272	2017-08-04 15:14:00+03	6300.00
4812B2	2017-08-13 10:41:00+03	21000.00
481351	2017-07-02 16:39:00+03	271200.00
48144B	2017-07-09 19:35:00+03	47900.00
4814DB	2017-08-08 02:57:00+03	41600.00
481524	2017-07-13 03:32:00+03	170300.00
481594	2017-07-22 05:16:00+03	92400.00
481619	2017-07-09 08:38:00+03	75600.00
481678	2017-08-04 06:38:00+03	66800.00
481685	2017-08-06 14:32:00+03	39300.00
48174C	2017-06-26 14:45:00+03	124200.00
48175F	2017-07-16 03:25:00+03	20400.00
481765	2017-08-07 23:40:00+03	46200.00
481788	2017-07-12 21:49:00+03	6000.00
4817F6	2017-08-08 16:11:00+03	22000.00
481863	2017-06-30 21:41:00+03	16400.00
481870	2017-08-13 03:30:00+03	6800.00
48189C	2017-07-15 09:39:00+03	104600.00
4818B1	2017-08-09 06:17:00+03	168000.00
4818F8	2017-07-12 03:39:00+03	29400.00
48191F	2017-07-07 01:41:00+03	40400.00
481922	2017-08-12 02:02:00+03	23200.00
48195F	2017-07-22 12:12:00+03	56000.00
48196E	2017-07-23 05:50:00+03	46300.00
4819A9	2017-08-14 02:53:00+03	134800.00
481A12	2017-07-15 23:50:00+03	60700.00
481A2A	2017-08-11 08:06:00+03	60000.00
481AA9	2017-07-02 13:19:00+03	167500.00
481AE0	2017-08-06 10:17:00+03	52000.00
481B70	2017-07-01 06:44:00+03	26000.00
481B81	2017-07-20 08:30:00+03	27400.00
481C47	2017-07-06 04:14:00+03	15000.00
481CB2	2017-07-21 20:24:00+03	83700.00
481CCF	2017-08-08 09:12:00+03	47400.00
481D55	2017-07-30 16:12:00+03	47000.00
481DBA	2017-07-23 06:09:00+03	246000.00
481DDA	2017-07-24 12:13:00+03	90600.00
481E10	2017-07-29 19:30:00+03	36400.00
481E33	2017-07-05 12:44:00+03	45100.00
481E67	2017-07-29 00:57:00+03	58900.00
481E8F	2017-08-13 07:24:00+03	10800.00
481E91	2017-08-15 17:50:00+03	369000.00
481EAA	2017-07-07 15:07:00+03	70900.00
481EB8	2017-08-14 06:21:00+03	96200.00
481EDE	2017-07-29 23:39:00+03	28000.00
481F25	2017-07-05 05:05:00+03	25800.00
481F4F	2017-07-18 22:41:00+03	36200.00
481F5C	2017-07-15 23:01:00+03	19600.00
481F80	2017-06-30 17:30:00+03	45100.00
481F89	2017-06-29 22:05:00+03	68800.00
481FDC	2017-08-07 18:29:00+03	167500.00
481FDF	2017-06-29 05:48:00+03	54800.00
482026	2017-08-07 04:01:00+03	25000.00
482027	2017-07-07 06:55:00+03	85000.00
482039	2017-07-12 07:21:00+03	66600.00
482042	2017-07-04 05:54:00+03	57400.00
48207E	2017-07-19 23:01:00+03	29200.00
48209A	2017-08-08 10:16:00+03	134400.00
4820C0	2017-06-28 14:49:00+03	119600.00
48210E	2017-07-06 14:48:00+03	194400.00
482235	2017-08-03 05:53:00+03	49700.00
48223A	2017-06-29 18:56:00+03	47400.00
482246	2017-08-06 22:34:00+03	29100.00
4822C0	2017-07-06 06:33:00+03	481000.00
4822FE	2017-07-18 07:27:00+03	32800.00
48232C	2017-07-29 18:59:00+03	68800.00
48239B	2017-07-23 14:07:00+03	40000.00
4823DB	2017-08-12 09:51:00+03	28000.00
48242F	2017-07-13 05:58:00+03	6700.00
482435	2017-07-29 18:26:00+03	10800.00
482437	2017-07-13 22:24:00+03	94800.00
48247E	2017-08-01 15:47:00+03	224000.00
482530	2017-07-15 22:10:00+03	21400.00
4825B6	2017-08-08 23:48:00+03	100600.00
482617	2017-07-09 12:33:00+03	25000.00
48261A	2017-08-13 07:02:00+03	52400.00
482626	2017-08-12 09:36:00+03	34100.00
482631	2017-07-16 23:38:00+03	33600.00
4826AB	2017-07-15 17:59:00+03	25400.00
4826C4	2017-07-25 05:35:00+03	6700.00
4826CD	2017-08-02 01:02:00+03	106500.00
482707	2017-07-26 17:24:00+03	84500.00
482740	2017-08-08 10:08:00+03	70700.00
4827BC	2017-07-24 16:40:00+03	11600.00
482827	2017-07-19 07:38:00+03	73900.00
48292F	2017-06-27 03:34:00+03	31600.00
482985	2017-08-03 03:20:00+03	144700.00
4829C3	2017-08-08 22:42:00+03	86800.00
4829D5	2017-08-06 07:31:00+03	59700.00
4829D9	2017-08-08 00:45:00+03	44800.00
482A38	2017-08-13 07:00:00+03	182000.00
482A70	2017-08-13 11:58:00+03	27800.00
482AD5	2017-07-10 05:13:00+03	32200.00
482AD9	2017-08-02 14:03:00+03	270800.00
482B07	2017-08-07 05:29:00+03	31400.00
482BAD	2017-08-01 11:09:00+03	398500.00
482BCA	2017-07-27 00:16:00+03	45000.00
482C0A	2017-07-15 21:54:00+03	27800.00
482C17	2017-07-24 16:13:00+03	56000.00
482C66	2017-08-13 08:58:00+03	28800.00
482CB9	2017-08-08 21:51:00+03	78700.00
482D20	2017-08-13 16:59:00+03	87700.00
482D22	2017-08-10 03:00:00+03	58400.00
482D57	2017-07-18 20:32:00+03	96800.00
482DA5	2017-07-14 13:01:00+03	25000.00
482DB7	2017-08-08 00:44:00+03	46700.00
482E34	2017-08-04 20:49:00+03	116900.00
482E6B	2017-08-10 12:32:00+03	26800.00
482EEC	2017-08-02 21:18:00+03	14400.00
482F00	2017-07-30 07:03:00+03	36200.00
482F48	2017-07-10 10:41:00+03	12400.00
482FAB	2017-07-18 23:16:00+03	40100.00
482FE7	2017-08-11 19:30:00+03	149500.00
483015	2017-07-27 12:32:00+03	366600.00
483029	2017-08-15 07:25:00+03	15900.00
48306C	2017-07-08 03:19:00+03	40400.00
4830A6	2017-08-11 11:07:00+03	91500.00
483144	2017-07-20 09:58:00+03	73600.00
48315D	2017-07-23 20:41:00+03	29600.00
4831BB	2017-08-15 11:46:00+03	19600.00
4831CF	2017-08-07 00:27:00+03	38600.00
4831F7	2017-07-08 07:44:00+03	69500.00
48320A	2017-07-20 12:20:00+03	283100.00
483269	2017-07-21 21:27:00+03	54600.00
483283	2017-07-13 06:10:00+03	56000.00
483284	2017-07-08 02:12:00+03	187600.00
4832AE	2017-08-11 17:08:00+03	115900.00
48330D	2017-07-08 05:49:00+03	133100.00
48331B	2017-07-13 06:58:00+03	64200.00
48334D	2017-07-18 14:05:00+03	38800.00
483378	2017-07-12 08:40:00+03	28000.00
48338C	2017-08-01 09:58:00+03	31600.00
48341F	2017-07-20 21:12:00+03	111600.00
483461	2017-08-06 19:50:00+03	29100.00
483495	2017-07-27 05:35:00+03	6300.00
4834FF	2017-08-15 10:05:00+03	128800.00
48355E	2017-07-23 04:04:00+03	138000.00
483568	2017-07-21 20:48:00+03	47000.00
483581	2017-08-08 17:32:00+03	226200.00
483586	2017-07-24 02:57:00+03	13100.00
4835C6	2017-07-13 07:50:00+03	26000.00
4836B1	2017-08-15 14:58:00+03	24800.00
4836DA	2017-08-15 05:20:00+03	43700.00
4836F7	2017-08-10 04:25:00+03	6800.00
483716	2017-08-14 10:37:00+03	187200.00
483764	2017-07-27 15:49:00+03	90400.00
4837A8	2017-07-03 04:35:00+03	26200.00
4837B9	2017-07-04 00:13:00+03	12400.00
4837D4	2017-07-22 08:20:00+03	101200.00
483819	2017-06-28 01:49:00+03	58900.00
4838BA	2017-07-24 16:09:00+03	50400.00
4838DD	2017-07-29 01:40:00+03	202400.00
4838DF	2017-07-05 04:08:00+03	53200.00
483907	2017-08-11 03:35:00+03	82200.00
48390A	2017-07-23 08:14:00+03	75300.00
48394E	2017-07-10 11:27:00+03	66700.00
483959	2017-07-23 07:32:00+03	62600.00
48396D	2017-07-15 04:05:00+03	66700.00
48399D	2017-08-09 09:41:00+03	123000.00
4839FD	2017-07-21 15:57:00+03	56000.00
483A3D	2017-07-03 10:08:00+03	67200.00
483A54	2017-07-26 08:04:00+03	12400.00
483A9B	2017-07-06 12:33:00+03	112000.00
483B13	2017-07-05 01:29:00+03	77000.00
483B1A	2017-07-31 22:01:00+03	170700.00
483B82	2017-07-02 17:29:00+03	90400.00
483B96	2017-07-30 14:23:00+03	43500.00
483B97	2017-08-15 02:41:00+03	25600.00
483BAF	2017-07-21 14:08:00+03	23600.00
483BD6	2017-08-03 00:38:00+03	58600.00
483BD9	2017-07-19 03:05:00+03	68400.00
483BE8	2017-07-25 23:45:00+03	65900.00
483BFB	2017-07-10 02:51:00+03	32700.00
483C06	2017-07-10 20:03:00+03	52800.00
483CAD	2017-07-10 16:27:00+03	186900.00
483D1D	2017-08-08 15:00:00+03	21800.00
483D8C	2017-07-20 11:53:00+03	40100.00
483DC1	2017-07-17 19:11:00+03	55900.00
483E26	2017-08-05 02:18:00+03	22000.00
483EBD	2017-07-03 01:38:00+03	105000.00
483F58	2017-08-13 23:25:00+03	67400.00
483F69	2017-07-09 04:05:00+03	48800.00
483F9F	2017-07-06 18:55:00+03	7400.00
484037	2017-07-29 22:11:00+03	55800.00
484058	2017-07-02 04:50:00+03	56000.00
484084	2017-08-01 20:10:00+03	65900.00
484085	2017-08-07 22:44:00+03	67800.00
4840B6	2017-07-07 22:02:00+03	58800.00
4840B8	2017-07-15 15:16:00+03	99200.00
4840D7	2017-07-13 08:48:00+03	10800.00
484175	2017-08-08 01:43:00+03	6600.00
4841D7	2017-07-13 03:24:00+03	28700.00
484222	2017-08-06 22:56:00+03	44500.00
484265	2017-08-10 02:59:00+03	56100.00
48428E	2017-07-08 21:20:00+03	166100.00
4842DC	2017-07-11 07:48:00+03	47000.00
484305	2017-07-03 02:59:00+03	23200.00
48435C	2017-08-14 11:23:00+03	92700.00
48437E	2017-07-21 01:02:00+03	58600.00
4843CC	2017-08-12 18:32:00+03	42700.00
484408	2017-08-02 04:25:00+03	53000.00
484426	2017-07-16 13:46:00+03	132800.00
48446A	2017-08-05 20:09:00+03	133200.00
4844E0	2017-07-15 04:10:00+03	258400.00
4844EF	2017-07-13 01:59:00+03	56900.00
484517	2017-07-25 02:02:00+03	265600.00
4845C0	2017-07-18 02:56:00+03	24400.00
4845C4	2017-08-04 17:41:00+03	58200.00
4845ED	2017-07-15 12:52:00+03	16000.00
484642	2017-08-06 15:47:00+03	30200.00
48465B	2017-07-28 01:28:00+03	35800.00
4846D4	2017-07-12 19:58:00+03	24400.00
4846F2	2017-07-13 14:27:00+03	73100.00
484754	2017-08-03 20:53:00+03	27300.00
484791	2017-07-17 08:41:00+03	12600.00
4847C7	2017-06-30 20:52:00+03	9300.00
484806	2017-08-08 04:01:00+03	189200.00
48480C	2017-08-11 02:26:00+03	114700.00
48482E	2017-08-14 22:18:00+03	149300.00
48484C	2017-08-12 11:47:00+03	49100.00
4848E6	2017-07-04 05:46:00+03	122500.00
484907	2017-07-06 01:18:00+03	147900.00
484933	2017-07-24 21:38:00+03	25400.00
484940	2017-08-10 11:16:00+03	21400.00
484952	2017-07-12 20:09:00+03	12600.00
48496F	2017-07-10 07:05:00+03	54400.00
4849A8	2017-07-14 22:06:00+03	13400.00
4849AA	2017-07-25 18:19:00+03	145300.00
4849AD	2017-08-12 12:42:00+03	56000.00
484A45	2017-07-17 09:50:00+03	101200.00
484A6E	2017-07-09 14:21:00+03	46400.00
484A9F	2017-07-12 08:26:00+03	131600.00
484AA5	2017-07-17 18:43:00+03	67900.00
484B11	2017-07-06 16:36:00+03	257600.00
484B14	2017-07-29 01:43:00+03	241300.00
484B5A	2017-08-12 21:23:00+03	115700.00
484BAC	2017-07-03 21:06:00+03	17200.00
484BB6	2017-07-23 03:37:00+03	29300.00
484C59	2017-07-07 16:41:00+03	92800.00
484C73	2017-06-29 11:41:00+03	52700.00
484C75	2017-08-02 19:40:00+03	37100.00
484C85	2017-08-06 12:52:00+03	59800.00
484D3B	2017-08-03 17:25:00+03	42800.00
484DC6	2017-08-07 12:32:00+03	20200.00
484EA4	2017-07-26 20:31:00+03	199800.00
484F25	2017-07-12 19:44:00+03	21800.00
484F3B	2017-07-12 12:48:00+03	166000.00
484F5C	2017-07-31 21:56:00+03	135400.00
484F81	2017-07-27 06:57:00+03	26000.00
484F85	2017-07-08 23:17:00+03	12600.00
484F94	2017-07-14 15:26:00+03	35600.00
484FBB	2017-07-28 08:10:00+03	108200.00
484FC8	2017-07-21 18:25:00+03	187800.00
485018	2017-07-18 05:53:00+03	54500.00
485048	2017-08-14 05:32:00+03	12000.00
485068	2017-08-05 22:34:00+03	43600.00
4850F3	2017-07-16 14:34:00+03	14400.00
485117	2017-07-14 21:50:00+03	89600.00
4851C9	2017-07-27 13:51:00+03	65600.00
485210	2017-07-03 08:44:00+03	52000.00
485223	2017-07-08 18:21:00+03	134400.00
485272	2017-07-08 21:14:00+03	13400.00
485275	2017-08-04 16:52:00+03	22000.00
48527D	2017-07-02 00:28:00+03	40400.00
4852DD	2017-07-28 11:57:00+03	63200.00
48531B	2017-07-23 06:35:00+03	26800.00
48532C	2017-07-12 07:24:00+03	93700.00
485351	2017-07-18 21:25:00+03	40000.00
48538E	2017-08-02 04:05:00+03	187600.00
485427	2017-07-28 03:46:00+03	61800.00
48546F	2017-07-02 06:00:00+03	97500.00
485470	2017-08-13 23:27:00+03	16400.00
4854CC	2017-08-01 18:42:00+03	16400.00
48550A	2017-07-19 07:48:00+03	133100.00
48552C	2017-07-18 19:49:00+03	119500.00
485609	2017-07-27 13:57:00+03	25000.00
485631	2017-06-29 11:16:00+03	46200.00
485642	2017-07-01 15:52:00+03	66800.00
485652	2017-08-13 09:01:00+03	56600.00
485658	2017-07-31 19:14:00+03	8600.00
485662	2017-07-17 04:59:00+03	31500.00
4856BD	2017-07-16 14:58:00+03	46000.00
4856EE	2017-07-30 20:05:00+03	32200.00
485729	2017-07-16 17:25:00+03	85000.00
485732	2017-07-19 00:08:00+03	21400.00
485754	2017-06-27 03:00:00+03	85000.00
4857EE	2017-07-19 18:26:00+03	7200.00
485832	2017-07-26 21:26:00+03	37200.00
485867	2017-08-06 22:57:00+03	112100.00
4858B2	2017-08-10 22:04:00+03	16400.00
48590D	2017-08-05 23:56:00+03	55800.00
485923	2017-07-22 16:14:00+03	81600.00
485957	2017-08-12 09:59:00+03	12600.00
485999	2017-07-22 11:24:00+03	52400.00
48599D	2017-08-03 00:15:00+03	56000.00
4859EE	2017-07-18 13:01:00+03	24000.00
4859F1	2017-07-30 17:27:00+03	6000.00
4859F8	2017-07-18 01:14:00+03	410200.00
485A1B	2017-07-28 06:17:00+03	66600.00
485A1E	2017-07-24 07:59:00+03	257600.00
485A33	2017-07-23 11:26:00+03	28000.00
485A38	2017-08-15 05:53:00+03	37700.00
485A86	2017-08-04 14:57:00+03	40100.00
485AB7	2017-07-15 06:42:00+03	48400.00
485AEB	2017-07-13 11:10:00+03	75600.00
485AF0	2017-07-05 13:47:00+03	37500.00
485B1E	2017-08-13 20:07:00+03	14000.00
485B4A	2017-07-06 22:20:00+03	155600.00
485B58	2017-08-06 05:53:00+03	46300.00
485BBC	2017-06-29 17:24:00+03	102300.00
485BC8	2017-08-01 05:11:00+03	88000.00
485BD3	2017-07-26 12:21:00+03	61800.00
485C22	2017-07-20 04:05:00+03	204500.00
485C59	2017-08-06 04:09:00+03	17800.00
485C84	2017-07-28 12:46:00+03	149300.00
485C8D	2017-07-26 16:34:00+03	125400.00
485CC1	2017-08-15 00:10:00+03	15400.00
485D1B	2017-08-10 20:33:00+03	32200.00
485D39	2017-07-13 15:44:00+03	21600.00
485D4F	2017-07-24 10:06:00+03	100800.00
485D7C	2017-07-11 21:33:00+03	94300.00
485D83	2017-07-21 03:14:00+03	56000.00
485DC1	2017-07-13 23:51:00+03	30200.00
485E31	2017-08-09 03:28:00+03	64700.00
485E39	2017-08-08 04:09:00+03	19600.00
485EA2	2017-06-28 09:59:00+03	18800.00
485ED5	2017-07-21 17:43:00+03	56000.00
485F12	2017-08-03 00:37:00+03	56000.00
485F39	2017-07-26 08:42:00+03	93400.00
485F88	2017-08-08 23:25:00+03	50000.00
486043	2017-08-15 08:51:00+03	42800.00
486059	2017-08-11 14:51:00+03	23200.00
486092	2017-07-15 10:40:00+03	55800.00
486121	2017-08-15 16:38:00+03	128800.00
486134	2017-08-15 03:05:00+03	111600.00
48613A	2017-08-06 07:46:00+03	112000.00
486185	2017-07-25 06:38:00+03	36200.00
486193	2017-07-30 21:26:00+03	140500.00
486205	2017-08-07 10:49:00+03	167400.00
486228	2017-07-05 03:16:00+03	40000.00
486287	2017-07-11 20:11:00+03	225000.00
48629A	2017-07-13 17:11:00+03	19800.00
4862D7	2017-07-31 01:35:00+03	135200.00
48630A	2017-07-29 12:01:00+03	54800.00
486366	2017-07-10 18:23:00+03	140400.00
48643D	2017-07-22 08:30:00+03	152900.00
486478	2017-08-06 19:48:00+03	26300.00
486552	2017-07-19 03:18:00+03	14400.00
48658F	2017-08-10 11:24:00+03	26800.00
4865A0	2017-07-05 11:16:00+03	28800.00
4865BF	2017-07-10 14:44:00+03	34800.00
4865C7	2017-07-11 12:08:00+03	100200.00
4865CB	2017-07-15 22:05:00+03	42600.00
48663B	2017-07-15 19:27:00+03	18000.00
48670A	2017-07-28 03:13:00+03	26000.00
486720	2017-08-08 12:08:00+03	37800.00
486799	2017-08-10 14:35:00+03	132800.00
48679D	2017-07-23 21:45:00+03	39500.00
4867D9	2017-07-26 09:45:00+03	48800.00
4867F5	2017-07-10 23:19:00+03	63600.00
48682C	2017-07-09 09:04:00+03	131600.00
4868DF	2017-07-11 23:24:00+03	65000.00
486926	2017-07-30 09:58:00+03	97900.00
48699C	2017-07-14 22:06:00+03	6700.00
4869BD	2017-07-28 07:20:00+03	89700.00
486A14	2017-07-03 17:08:00+03	90400.00
486A30	2017-07-31 01:04:00+03	7400.00
486A4E	2017-07-07 06:49:00+03	39100.00
486AC5	2017-07-28 14:31:00+03	82500.00
486B35	2017-07-28 23:27:00+03	147700.00
486B8E	2017-07-07 11:05:00+03	41600.00
486B95	2017-08-11 00:48:00+03	85500.00
486C5B	2017-07-21 06:18:00+03	73600.00
486C7A	2017-08-12 18:46:00+03	50600.00
486C8F	2017-08-11 12:44:00+03	15100.00
486CA9	2017-08-03 15:20:00+03	54000.00
486DB8	2017-07-18 09:30:00+03	24000.00
486DF0	2017-08-01 08:00:00+03	65900.00
486E32	2017-07-17 20:57:00+03	40000.00
486E68	2017-07-23 12:46:00+03	406100.00
486EAA	2017-08-03 03:41:00+03	32600.00
486EF2	2017-08-02 08:19:00+03	44000.00
486EFC	2017-07-30 01:32:00+03	135600.00
486F48	2017-08-06 01:49:00+03	43600.00
486F8F	2017-08-14 12:29:00+03	39400.00
486F99	2017-07-07 15:45:00+03	46200.00
486FCF	2017-07-03 08:49:00+03	26800.00
486FFE	2017-07-17 11:47:00+03	59200.00
487051	2017-07-25 01:21:00+03	76600.00
48709C	2017-07-27 16:42:00+03	16400.00
48713C	2017-07-11 23:23:00+03	265700.00
487205	2017-07-12 01:19:00+03	45100.00
487218	2017-08-03 18:58:00+03	28300.00
487226	2017-07-18 17:41:00+03	399600.00
48727D	2017-07-23 00:33:00+03	30200.00
4872B4	2017-07-18 21:30:00+03	165800.00
48735A	2017-07-24 15:15:00+03	199700.00
4873A0	2017-06-30 06:26:00+03	22600.00
487489	2017-08-14 06:28:00+03	19600.00
48759C	2017-06-29 11:54:00+03	12600.00
4875E8	2017-07-11 12:39:00+03	143100.00
4875F7	2017-08-01 02:02:00+03	66800.00
487637	2017-08-08 09:25:00+03	31200.00
487701	2017-08-12 18:39:00+03	215200.00
487746	2017-07-03 11:19:00+03	63200.00
48774E	2017-08-10 20:40:00+03	6800.00
4877A0	2017-07-24 06:42:00+03	26000.00
4877D0	2017-07-22 11:30:00+03	94000.00
4878BD	2017-07-28 04:13:00+03	94700.00
4878C0	2017-07-26 17:34:00+03	32700.00
4878D8	2017-07-02 16:03:00+03	60400.00
48795B	2017-06-29 07:28:00+03	14000.00
487964	2017-07-18 14:30:00+03	77700.00
4879B0	2017-07-06 16:15:00+03	85000.00
4879CA	2017-07-18 20:23:00+03	369000.00
4879EC	2017-07-25 05:13:00+03	15000.00
487A21	2017-08-12 16:46:00+03	24600.00
487A2B	2017-07-23 17:34:00+03	38400.00
487A38	2017-07-12 18:30:00+03	63200.00
487AFD	2017-06-29 22:07:00+03	23200.00
487AFF	2017-07-13 23:15:00+03	20400.00
487B14	2017-07-22 08:49:00+03	69500.00
487B4B	2017-07-08 16:00:00+03	35300.00
487BA1	2017-08-11 09:18:00+03	48800.00
487BF9	2017-07-09 18:59:00+03	36200.00
487BFB	2017-07-07 13:43:00+03	54800.00
487C14	2017-07-05 05:21:00+03	56000.00
487C32	2017-08-04 14:45:00+03	277800.00
487CC2	2017-06-27 16:49:00+03	112000.00
487D79	2017-08-06 16:18:00+03	100200.00
487DB6	2017-07-03 22:24:00+03	38400.00
487DC0	2017-07-12 09:25:00+03	55700.00
487DD5	2017-08-10 00:07:00+03	248300.00
487DEC	2017-07-12 17:18:00+03	84500.00
487DFA	2017-08-13 15:15:00+03	222000.00
487E0A	2017-07-31 17:34:00+03	35600.00
487E27	2017-08-10 10:55:00+03	114400.00
487E33	2017-07-01 09:01:00+03	68800.00
487E84	2017-07-17 03:14:00+03	55800.00
487EF7	2017-07-26 21:25:00+03	241300.00
487F33	2017-07-03 07:48:00+03	13600.00
487F41	2017-07-26 20:30:00+03	152900.00
487FAA	2017-07-13 20:27:00+03	21200.00
48804C	2017-08-06 03:52:00+03	39700.00
488079	2017-07-05 08:53:00+03	197600.00
4880EF	2017-07-06 08:24:00+03	25100.00
48813A	2017-08-09 16:31:00+03	42700.00
488156	2017-07-04 17:42:00+03	12600.00
488182	2017-08-08 19:13:00+03	26000.00
488257	2017-08-04 00:35:00+03	24400.00
488271	2017-07-19 13:54:00+03	57500.00
48829B	2017-07-09 15:30:00+03	75600.00
4882C2	2017-07-15 10:25:00+03	6300.00
488322	2017-07-25 13:12:00+03	160200.00
488365	2017-08-14 13:16:00+03	56000.00
488375	2017-07-30 02:00:00+03	18600.00
4883D3	2017-08-12 18:55:00+03	21800.00
4883F9	2017-07-11 07:08:00+03	280400.00
488435	2017-07-15 17:05:00+03	28800.00
488438	2017-08-15 03:07:00+03	124200.00
488514	2017-07-28 05:42:00+03	52000.00
48855B	2017-07-14 00:39:00+03	201200.00
4885BF	2017-07-21 18:34:00+03	37200.00
4885DC	2017-07-28 04:11:00+03	83000.00
4885F3	2017-08-06 13:45:00+03	251700.00
4885FC	2017-08-10 16:51:00+03	400000.00
488611	2017-08-10 09:23:00+03	8000.00
488621	2017-08-05 22:32:00+03	92800.00
488651	2017-07-21 17:20:00+03	186900.00
48874C	2017-08-11 18:02:00+03	55800.00
48874F	2017-08-13 11:59:00+03	110800.00
48875A	2017-08-09 01:22:00+03	206400.00
488764	2017-07-09 05:25:00+03	31200.00
4887AF	2017-08-02 20:53:00+03	123000.00
4887BC	2017-07-19 16:23:00+03	67600.00
488898	2017-07-05 22:30:00+03	32200.00
488904	2017-07-31 21:03:00+03	56000.00
4889C4	2017-07-21 03:52:00+03	26000.00
4889D7	2017-07-21 17:02:00+03	67200.00
488A0B	2017-08-07 00:13:00+03	30200.00
488A0D	2017-08-12 03:26:00+03	56100.00
488A42	2017-07-10 22:39:00+03	25200.00
488A71	2017-07-09 10:47:00+03	13000.00
488A77	2017-08-06 03:19:00+03	28000.00
488AC2	2017-07-18 11:09:00+03	70800.00
488ACA	2017-07-20 03:29:00+03	13600.00
488AD2	2017-07-26 17:52:00+03	81300.00
488B0D	2017-08-09 04:23:00+03	23600.00
488B42	2017-08-07 18:51:00+03	69500.00
488B44	2017-08-12 16:15:00+03	23200.00
488B56	2017-07-09 21:56:00+03	38200.00
488BBC	2017-07-01 20:21:00+03	162200.00
488C53	2017-06-29 08:58:00+03	19600.00
488C7B	2017-07-26 13:56:00+03	14000.00
488C81	2017-08-11 18:24:00+03	62900.00
488CF0	2017-07-08 01:12:00+03	57600.00
488DBB	2017-08-07 14:44:00+03	140900.00
488E1D	2017-06-30 08:51:00+03	36100.00
488E26	2017-07-09 04:29:00+03	48800.00
488E2E	2017-07-11 08:07:00+03	30200.00
488E5F	2017-07-03 03:47:00+03	13400.00
488E80	2017-07-14 07:55:00+03	119500.00
488EE1	2017-07-28 23:32:00+03	24600.00
488F07	2017-07-07 20:31:00+03	23600.00
488F2D	2017-08-08 11:11:00+03	72200.00
488F37	2017-07-06 08:44:00+03	61800.00
488F6C	2017-08-15 09:35:00+03	70800.00
488FF9	2017-07-19 04:28:00+03	67700.00
48906D	2017-08-07 00:59:00+03	21800.00
4890D0	2017-07-23 18:29:00+03	18000.00
4890E9	2017-07-02 17:40:00+03	363200.00
489102	2017-07-06 04:14:00+03	26800.00
489172	2017-07-18 18:37:00+03	84600.00
489175	2017-07-19 01:20:00+03	136800.00
489197	2017-07-01 15:45:00+03	113200.00
4891A8	2017-07-29 00:29:00+03	59200.00
4891A9	2017-07-03 06:11:00+03	38600.00
4891D2	2017-07-29 21:48:00+03	55800.00
489202	2017-08-09 17:20:00+03	14400.00
48921B	2017-08-03 18:11:00+03	27800.00
4892DB	2017-08-13 15:47:00+03	23400.00
48932D	2017-07-14 22:45:00+03	229900.00
489348	2017-07-22 11:39:00+03	166400.00
489379	2017-07-09 04:14:00+03	128800.00
4893A1	2017-07-02 05:30:00+03	133200.00
4894DC	2017-08-09 15:51:00+03	354400.00
48950B	2017-07-20 10:32:00+03	7800.00
489517	2017-07-08 11:21:00+03	129000.00
48958A	2017-08-02 20:56:00+03	258400.00
4895D0	2017-07-02 04:28:00+03	32800.00
4895E6	2017-07-23 15:01:00+03	115000.00
4895E9	2017-07-01 21:01:00+03	54800.00
4895F0	2017-07-19 14:07:00+03	61500.00
48963C	2017-07-28 22:12:00+03	70600.00
48964E	2017-07-21 22:10:00+03	28000.00
489681	2017-07-07 00:17:00+03	66100.00
489689	2017-07-06 11:19:00+03	39100.00
4896DB	2017-08-15 07:06:00+03	111600.00
48970F	2017-07-13 06:30:00+03	66400.00
489757	2017-08-03 23:19:00+03	9800.00
48976C	2017-08-15 01:51:00+03	166900.00
489791	2017-08-02 10:05:00+03	44000.00
4897E0	2017-07-22 04:03:00+03	26000.00
489826	2017-08-09 23:16:00+03	17800.00
489860	2017-08-04 09:26:00+03	50200.00
489911	2017-08-04 03:43:00+03	28800.00
48991D	2017-07-07 10:40:00+03	266300.00
48997F	2017-07-23 12:44:00+03	28000.00
48998B	2017-07-02 16:21:00+03	40100.00
489A4D	2017-07-09 07:59:00+03	13600.00
489A76	2017-07-02 13:27:00+03	101100.00
489A82	2017-08-10 06:05:00+03	148200.00
489ABB	2017-07-31 19:37:00+03	28000.00
489AE5	2017-07-05 07:23:00+03	12600.00
489B57	2017-07-27 19:13:00+03	6800.00
489BB2	2017-07-24 19:18:00+03	38400.00
489BE0	2017-08-15 03:47:00+03	63700.00
489C30	2017-07-26 05:07:00+03	96200.00
489CC9	2017-07-05 17:37:00+03	83700.00
489D36	2017-07-13 23:40:00+03	44800.00
489D61	2017-07-11 22:38:00+03	46000.00
489D65	2017-08-12 07:17:00+03	87600.00
489E06	2017-07-08 05:26:00+03	46800.00
489E2A	2017-08-06 17:25:00+03	111700.00
489E39	2017-07-11 00:36:00+03	56000.00
489F36	2017-07-04 05:41:00+03	60400.00
489F7E	2017-07-05 09:06:00+03	76300.00
489F9A	2017-07-03 18:44:00+03	38800.00
489FCD	2017-07-02 13:33:00+03	68100.00
48A028	2017-07-04 21:25:00+03	695400.00
48A064	2017-07-05 06:59:00+03	23200.00
48A080	2017-07-23 02:22:00+03	54200.00
48A0EE	2017-07-17 21:03:00+03	18400.00
48A113	2017-08-11 00:47:00+03	48700.00
48A119	2017-07-23 16:25:00+03	9200.00
48A150	2017-08-12 20:03:00+03	49400.00
48A1A6	2017-08-01 15:59:00+03	25900.00
48A1AF	2017-07-11 11:03:00+03	54800.00
48A1E3	2017-07-30 21:19:00+03	31600.00
48A1EB	2017-07-30 22:12:00+03	17200.00
48A1FC	2017-07-20 04:50:00+03	41200.00
48A23B	2017-07-22 01:35:00+03	29600.00
48A302	2017-07-20 17:42:00+03	238200.00
48A348	2017-07-02 10:49:00+03	135000.00
48A35B	2017-07-29 06:09:00+03	42800.00
48A383	2017-08-11 17:13:00+03	23600.00
48A3F3	2017-08-07 11:08:00+03	86400.00
48A409	2017-07-27 04:26:00+03	124200.00
48A44B	2017-08-05 09:48:00+03	97000.00
48A4A3	2017-07-09 01:37:00+03	181000.00
48A500	2017-07-24 22:41:00+03	70800.00
48A525	2017-08-03 16:45:00+03	189800.00
48A534	2017-07-22 13:26:00+03	23600.00
48A5A2	2017-08-06 05:39:00+03	42800.00
48A5B7	2017-08-15 15:46:00+03	40800.00
48A649	2017-08-14 04:09:00+03	65900.00
48A676	2017-08-15 12:42:00+03	27200.00
48A6CA	2017-08-05 12:11:00+03	92800.00
48A6D6	2017-07-29 23:09:00+03	67600.00
48A6DC	2017-08-05 03:59:00+03	136200.00
48A6F8	2017-08-02 19:28:00+03	13600.00
48A7C5	2017-07-30 17:59:00+03	326300.00
48A83D	2017-07-19 06:04:00+03	398900.00
48A882	2017-08-01 12:39:00+03	108000.00
48A8B3	2017-07-01 12:41:00+03	84100.00
48A8B7	2017-08-08 15:10:00+03	36800.00
48A8DC	2017-07-07 17:58:00+03	88600.00
48A8E8	2017-07-12 15:12:00+03	66600.00
48A919	2017-08-15 08:29:00+03	147700.00
48A991	2017-07-15 23:58:00+03	12600.00
48A9A5	2017-07-18 00:37:00+03	145200.00
48A9A8	2017-08-08 21:40:00+03	23400.00
48A9D7	2017-07-22 01:08:00+03	52800.00
48AA7D	2017-07-06 10:21:00+03	49300.00
48AAA0	2017-07-25 14:47:00+03	217600.00
48AAD7	2017-07-25 05:49:00+03	75600.00
48AB19	2017-07-03 05:59:00+03	295400.00
48AB68	2017-08-11 03:37:00+03	12400.00
48AB87	2017-07-23 16:18:00+03	103800.00
48ABD1	2017-07-07 04:38:00+03	47000.00
48AC03	2017-08-05 02:21:00+03	22400.00
48AC51	2017-07-16 03:54:00+03	55800.00
48AC61	2017-07-28 04:38:00+03	15900.00
48AC7A	2017-07-28 09:53:00+03	28000.00
48AC85	2017-07-13 21:26:00+03	28800.00
48AD3E	2017-07-25 13:15:00+03	38800.00
48AD5E	2017-07-08 04:09:00+03	24400.00
48ADEF	2017-08-04 19:25:00+03	47500.00
48AE4A	2017-07-01 23:20:00+03	52000.00
48AE4E	2017-07-25 11:36:00+03	125200.00
48AE95	2017-07-11 01:31:00+03	42700.00
48AF4B	2017-07-25 18:52:00+03	87100.00
48B064	2017-08-14 09:51:00+03	556800.00
48B0E8	2017-06-29 15:51:00+03	12900.00
48B123	2017-07-16 14:38:00+03	57600.00
48B152	2017-08-11 12:48:00+03	290400.00
48B16D	2017-08-10 23:53:00+03	33300.00
48B1F4	2017-08-07 20:45:00+03	26800.00
48B209	2017-06-30 06:16:00+03	46400.00
48B22C	2017-07-28 04:49:00+03	12600.00
48B245	2017-07-07 07:59:00+03	102100.00
48B253	2017-08-05 14:58:00+03	123200.00
48B264	2017-07-02 13:47:00+03	84800.00
48B289	2017-08-03 04:12:00+03	19600.00
48B2B5	2017-07-08 09:39:00+03	36200.00
48B31F	2017-07-19 14:07:00+03	25400.00
48B325	2017-07-25 20:12:00+03	39600.00
48B34C	2017-07-14 02:37:00+03	31600.00
48B358	2017-07-20 07:12:00+03	46000.00
48B385	2017-07-09 16:36:00+03	108900.00
48B38D	2017-06-30 21:19:00+03	7800.00
48B416	2017-06-30 08:10:00+03	50000.00
48B41D	2017-08-02 11:40:00+03	67100.00
48B435	2017-07-09 06:28:00+03	83000.00
48B449	2017-07-24 11:22:00+03	7400.00
48B48C	2017-07-19 22:28:00+03	28000.00
48B49F	2017-07-24 11:41:00+03	133200.00
48B53C	2017-07-26 10:47:00+03	18000.00
48B547	2017-07-17 07:15:00+03	172400.00
48B5A7	2017-08-08 13:24:00+03	32200.00
48B606	2017-07-08 18:07:00+03	62800.00
48B612	2017-07-16 03:15:00+03	60400.00
48B677	2017-08-14 13:52:00+03	80000.00
48B710	2017-08-14 10:58:00+03	33100.00
48B72A	2017-08-07 09:17:00+03	67200.00
48B753	2017-07-18 04:59:00+03	47400.00
48B7F4	2017-07-02 20:40:00+03	24400.00
48B86D	2017-07-18 18:41:00+03	40000.00
48B8D0	2017-07-09 09:22:00+03	59400.00
48B91D	2017-08-13 17:52:00+03	27200.00
48B971	2017-07-20 10:34:00+03	61900.00
48B97D	2017-08-10 02:31:00+03	55900.00
48B9AF	2017-07-06 17:11:00+03	51900.00
48B9F6	2017-07-19 03:44:00+03	81300.00
48BA3F	2017-07-24 21:26:00+03	28600.00
48BA67	2017-07-12 11:12:00+03	27800.00
48BA99	2017-08-08 00:20:00+03	28000.00
48BAC1	2017-07-21 05:56:00+03	46000.00
48BB03	2017-07-29 05:25:00+03	242000.00
48BB39	2017-08-14 17:31:00+03	136200.00
48BB42	2017-07-12 09:44:00+03	25600.00
48BB81	2017-07-18 10:56:00+03	48500.00
48BBCD	2017-08-15 00:59:00+03	103800.00
48BC0C	2017-08-11 23:45:00+03	10800.00
48BC78	2017-07-29 09:04:00+03	14000.00
48BC97	2017-07-06 02:46:00+03	23200.00
48BD4C	2017-08-14 03:05:00+03	48800.00
48BD80	2017-07-08 18:07:00+03	38600.00
48BDA4	2017-07-26 20:21:00+03	38600.00
48BE08	2017-07-09 15:58:00+03	34000.00
48BE45	2017-07-31 03:12:00+03	68800.00
48BF23	2017-07-11 01:52:00+03	52800.00
48BF5F	2017-08-06 10:16:00+03	28000.00
48BFBE	2017-07-04 02:13:00+03	68800.00
48BFC3	2017-08-11 15:37:00+03	124000.00
48C03E	2017-07-12 05:43:00+03	53300.00
48C056	2017-07-06 00:39:00+03	32800.00
48C058	2017-07-19 08:19:00+03	61500.00
48C132	2017-07-23 17:19:00+03	17800.00
48C167	2017-08-07 16:29:00+03	6000.00
48C182	2017-07-30 02:30:00+03	23400.00
48C1FE	2017-08-02 15:12:00+03	51600.00
48C200	2017-07-26 05:10:00+03	18700.00
48C22D	2017-07-14 18:20:00+03	61800.00
48C249	2017-08-05 20:59:00+03	182300.00
48C27F	2017-08-12 05:08:00+03	16400.00
48C2BA	2017-07-21 07:21:00+03	37100.00
48C2F2	2017-08-10 01:27:00+03	23000.00
48C322	2017-08-12 00:29:00+03	47200.00
48C3C3	2017-07-23 02:38:00+03	123000.00
48C3C6	2017-07-26 20:02:00+03	44000.00
48C419	2017-07-08 20:18:00+03	75600.00
48C46A	2017-08-13 03:55:00+03	203600.00
48C4CF	2017-07-29 09:34:00+03	16400.00
48C4EC	2017-07-05 10:50:00+03	86800.00
48C56F	2017-07-21 21:44:00+03	134200.00
48C58B	2017-07-10 23:50:00+03	46800.00
48C5BA	2017-07-02 16:15:00+03	135400.00
48C5BE	2017-07-03 10:45:00+03	25000.00
48C65C	2017-07-03 12:37:00+03	28000.00
48C685	2017-07-12 12:14:00+03	52000.00
48C68E	2017-07-25 22:11:00+03	50800.00
48C6CE	2017-07-13 03:11:00+03	26800.00
48C706	2017-08-02 20:18:00+03	6800.00
48C78D	2017-07-13 07:55:00+03	123000.00
48C799	2017-07-31 14:33:00+03	39900.00
48C7BB	2017-08-13 00:31:00+03	23200.00
48C877	2017-08-06 13:00:00+03	56000.00
48C8C8	2017-07-26 21:40:00+03	46400.00
48C8D9	2017-08-15 02:48:00+03	26000.00
48C912	2017-07-27 23:34:00+03	115700.00
48C927	2017-07-08 19:16:00+03	12600.00
48C970	2017-07-25 08:17:00+03	186900.00
48C971	2017-07-01 06:51:00+03	21800.00
48C981	2017-08-14 23:32:00+03	172200.00
48C987	2017-07-02 10:20:00+03	14400.00
48C98F	2017-08-03 13:14:00+03	51600.00
48C99F	2017-07-10 04:53:00+03	8000.00
48C9FB	2017-07-13 03:06:00+03	369000.00
48CA27	2017-08-11 00:53:00+03	42400.00
48CA60	2017-08-10 08:15:00+03	54100.00
48CA9C	2017-07-10 02:56:00+03	12600.00
48CA9D	2017-07-30 13:06:00+03	28000.00
48CAC7	2017-08-12 17:24:00+03	11700.00
48CAEC	2017-07-14 18:38:00+03	100200.00
48CB0B	2017-07-26 21:24:00+03	12600.00
48CB88	2017-07-16 10:22:00+03	94000.00
48CBA6	2017-07-21 20:54:00+03	208100.00
48CC39	2017-07-12 02:52:00+03	36800.00
48CC68	2017-07-02 14:43:00+03	75100.00
48CC6F	2017-07-17 14:48:00+03	81300.00
48CC77	2017-08-02 14:18:00+03	68000.00
48CCEE	2017-07-04 09:29:00+03	95300.00
48CCFF	2017-07-02 09:19:00+03	40800.00
48CD53	2017-07-29 04:18:00+03	23400.00
48CD71	2017-07-15 10:38:00+03	50100.00
48CDC2	2017-08-14 18:49:00+03	120000.00
48CDD0	2017-07-18 23:25:00+03	28000.00
48CE43	2017-07-15 18:13:00+03	103000.00
48CE6E	2017-08-06 10:29:00+03	177200.00
48CE7B	2017-07-06 01:52:00+03	37200.00
48CEC0	2017-08-14 16:31:00+03	133700.00
48CF40	2017-07-24 00:07:00+03	60700.00
48CF48	2017-08-08 23:50:00+03	69000.00
48CF5D	2017-07-06 04:26:00+03	38600.00
48CF83	2017-07-17 09:43:00+03	37700.00
48CFB3	2017-07-22 12:46:00+03	102100.00
48D0DB	2017-08-09 11:59:00+03	193500.00
48D13B	2017-07-31 22:33:00+03	28600.00
48D184	2017-07-03 13:55:00+03	56000.00
48D1AF	2017-08-08 21:10:00+03	112000.00
48D235	2017-07-08 19:24:00+03	26000.00
48D253	2017-07-15 03:52:00+03	26800.00
48D270	2017-07-18 12:32:00+03	229000.00
48D275	2017-08-01 04:04:00+03	26000.00
48D2D3	2017-07-02 01:44:00+03	58800.00
48D322	2017-07-30 02:00:00+03	52900.00
48D36A	2017-08-15 03:24:00+03	40800.00
48D372	2017-07-17 12:39:00+03	135400.00
48D419	2017-07-29 06:50:00+03	46400.00
48D443	2017-07-19 23:09:00+03	24200.00
48D464	2017-07-19 21:03:00+03	99300.00
48D4F5	2017-08-15 04:03:00+03	265700.00
48D50B	2017-07-24 10:44:00+03	136300.00
48D54E	2017-07-12 07:36:00+03	199700.00
48D5B6	2017-07-18 02:55:00+03	396500.00
48D684	2017-07-18 08:57:00+03	30200.00
48D6A8	2017-07-07 13:05:00+03	42800.00
48D6BE	2017-08-11 17:52:00+03	66400.00
48D6F9	2017-07-12 19:34:00+03	192400.00
48D702	2017-06-28 09:19:00+03	102400.00
48D720	2017-08-12 11:57:00+03	28000.00
48D735	2017-07-12 06:22:00+03	85000.00
48D7AD	2017-07-19 23:39:00+03	26000.00
48D822	2017-07-30 20:11:00+03	6700.00
48D859	2017-07-14 02:10:00+03	101900.00
48D85F	2017-07-19 10:19:00+03	121400.00
48D866	2017-08-08 23:56:00+03	51900.00
48D883	2017-08-12 08:26:00+03	20400.00
48D8BD	2017-07-22 08:04:00+03	142000.00
48D94D	2017-08-01 06:29:00+03	29000.00
48D959	2017-07-07 07:00:00+03	19800.00
48D98E	2017-08-13 12:18:00+03	25000.00
48D9A0	2017-07-27 04:36:00+03	50600.00
48D9A7	2017-08-11 14:32:00+03	34000.00
48D9B7	2017-07-31 00:10:00+03	28000.00
48DA34	2017-06-30 00:49:00+03	20400.00
48DA4D	2017-07-15 05:41:00+03	197200.00
48DA94	2017-07-30 14:01:00+03	126500.00
48DAA3	2017-08-01 07:30:00+03	132800.00
48DB14	2017-07-27 13:31:00+03	27800.00
48DB1B	2017-07-26 11:21:00+03	208200.00
48DB6C	2017-07-24 13:24:00+03	104600.00
48DB6F	2017-08-08 09:05:00+03	234000.00
48DBB2	2017-08-04 08:53:00+03	46500.00
48DBE2	2017-08-07 13:43:00+03	73500.00
48DC24	2017-07-26 12:11:00+03	97800.00
48DC30	2017-08-04 01:58:00+03	68400.00
48DC4A	2017-07-07 21:10:00+03	88800.00
48DC5E	2017-08-03 21:20:00+03	79400.00
48DC7C	2017-07-16 11:46:00+03	168000.00
48DCA6	2017-07-09 13:52:00+03	64300.00
48DCB4	2017-07-22 06:46:00+03	20400.00
48DCCF	2017-07-29 00:31:00+03	14800.00
48DD17	2017-08-08 05:16:00+03	49600.00
48DD78	2017-08-09 17:11:00+03	56000.00
48DDBD	2017-07-04 22:22:00+03	26000.00
48DE41	2017-07-21 12:04:00+03	47300.00
48DE4D	2017-07-06 17:57:00+03	54400.00
48DE62	2017-08-11 03:59:00+03	87100.00
48DEAE	2017-07-03 11:38:00+03	55800.00
48DEB6	2017-07-25 08:03:00+03	34000.00
48DF66	2017-07-18 04:42:00+03	6700.00
48DF97	2017-08-05 23:17:00+03	115800.00
48E00E	2017-07-07 15:38:00+03	13400.00
48E024	2017-08-10 11:54:00+03	123000.00
48E027	2017-07-21 23:20:00+03	22100.00
48E03D	2017-07-21 14:29:00+03	24400.00
48E0B9	2017-06-25 03:08:00+03	52900.00
48E0BC	2017-08-02 00:31:00+03	103400.00
48E0D3	2017-08-15 11:34:00+03	198400.00
48E119	2017-07-28 20:33:00+03	89700.00
48E137	2017-07-18 05:10:00+03	182300.00
48E1EE	2017-07-15 10:59:00+03	6000.00
48E1EF	2017-07-04 06:31:00+03	25000.00
48E264	2017-08-03 04:15:00+03	123000.00
48E2F4	2017-07-08 12:08:00+03	140900.00
48E37E	2017-07-15 07:23:00+03	25200.00
48E384	2017-08-03 02:24:00+03	68000.00
48E38D	2017-08-10 03:33:00+03	43300.00
48E3F3	2017-07-30 16:04:00+03	37800.00
48E3F5	2017-08-03 03:22:00+03	53300.00
48E498	2017-07-02 18:18:00+03	87000.00
48E554	2017-08-11 10:18:00+03	32700.00
48E615	2017-08-14 19:00:00+03	13400.00
48E617	2017-08-13 15:40:00+03	37200.00
48E618	2017-07-09 07:45:00+03	19600.00
48E61C	2017-07-06 06:53:00+03	58200.00
48E61F	2017-07-13 22:45:00+03	63300.00
48E66E	2017-07-28 11:56:00+03	89600.00
48E6C9	2017-07-21 01:32:00+03	38800.00
48E701	2017-07-06 15:46:00+03	55800.00
48E719	2017-07-19 23:59:00+03	43700.00
48E751	2017-08-03 11:40:00+03	26300.00
48E752	2017-07-02 06:04:00+03	58000.00
48E774	2017-08-14 00:16:00+03	56000.00
48E7C4	2017-07-05 02:32:00+03	55800.00
48E7D4	2017-08-05 05:34:00+03	30200.00
48E7FC	2017-07-01 21:28:00+03	19600.00
48E86F	2017-06-27 21:58:00+03	89600.00
48E8E6	2017-07-01 12:20:00+03	60400.00
48E8FF	2017-08-14 09:15:00+03	93500.00
48E935	2017-06-28 10:46:00+03	112000.00
48E955	2017-07-29 18:38:00+03	94800.00
48E967	2017-07-29 14:14:00+03	61800.00
48E978	2017-08-04 11:53:00+03	88500.00
48E9AD	2017-08-09 11:22:00+03	28800.00
48EA05	2017-07-20 15:36:00+03	55800.00
48EA08	2017-08-02 21:56:00+03	42800.00
48EA81	2017-07-12 21:29:00+03	24000.00
48EB4B	2017-07-10 22:04:00+03	36200.00
48EB6C	2017-07-06 10:32:00+03	21800.00
48EB86	2017-07-12 14:42:00+03	22600.00
48EBA5	2017-07-28 07:26:00+03	6700.00
48EBC3	2017-07-09 11:17:00+03	25800.00
48EBCC	2017-08-12 02:49:00+03	31600.00
48EC45	2017-08-06 02:15:00+03	72400.00
48EC7A	2017-07-15 05:55:00+03	144700.00
48EC94	2017-07-31 10:48:00+03	55500.00
48ED36	2017-07-28 21:29:00+03	121200.00
48ED7E	2017-07-01 18:02:00+03	102100.00
48ED8A	2017-07-21 23:51:00+03	171100.00
48EE48	2017-07-18 11:56:00+03	21400.00
48EE5A	2017-08-09 16:55:00+03	67100.00
48EECD	2017-08-02 15:08:00+03	44800.00
48EF69	2017-07-02 08:37:00+03	27900.00
48EF81	2017-08-11 09:41:00+03	10800.00
48EFA4	2017-07-14 05:53:00+03	56000.00
48EFA5	2017-07-05 05:04:00+03	67600.00
48EFB8	2017-07-31 23:17:00+03	112000.00
48F01E	2017-07-11 15:26:00+03	81300.00
48F033	2017-08-14 22:46:00+03	133200.00
48F04B	2017-07-22 17:50:00+03	28300.00
48F07A	2017-08-04 15:31:00+03	166100.00
48F099	2017-07-18 11:01:00+03	56000.00
48F0A8	2017-08-03 08:43:00+03	28000.00
48F0B9	2017-07-08 09:30:00+03	43500.00
48F16C	2017-07-15 02:15:00+03	14000.00
48F229	2017-07-26 21:09:00+03	73500.00
48F2B3	2017-08-07 05:40:00+03	133200.00
48F2C5	2017-08-01 05:03:00+03	23200.00
48F2EC	2017-07-26 14:26:00+03	109600.00
48F305	2017-07-19 21:25:00+03	73300.00
48F335	2017-08-15 09:49:00+03	118000.00
48F343	2017-07-06 13:53:00+03	39800.00
48F34F	2017-07-05 04:06:00+03	20400.00
48F371	2017-07-10 07:29:00+03	13000.00
48F394	2017-07-28 16:33:00+03	13400.00
48F39D	2017-08-14 20:41:00+03	88600.00
48F414	2017-07-19 22:29:00+03	59200.00
48F44E	2017-07-27 14:48:00+03	56000.00
48F452	2017-07-12 12:50:00+03	29600.00
48F45C	2017-08-02 01:51:00+03	62600.00
48F461	2017-08-03 02:39:00+03	55800.00
48F4A6	2017-08-10 13:26:00+03	281500.00
48F4E4	2017-08-13 10:19:00+03	131100.00
48F4F6	2017-07-14 22:05:00+03	8400.00
48F505	2017-08-04 04:36:00+03	69700.00
48F527	2017-08-01 17:52:00+03	232800.00
48F53C	2017-07-14 14:31:00+03	127300.00
48F547	2017-07-02 12:07:00+03	50800.00
48F567	2017-07-13 17:52:00+03	35900.00
48F574	2017-08-10 08:55:00+03	76400.00
48F579	2017-07-30 22:20:00+03	67600.00
48F596	2017-08-13 06:24:00+03	55800.00
48F5A2	2017-07-31 19:48:00+03	114800.00
48F5AA	2017-07-13 13:19:00+03	289800.00
48F5F3	2017-07-14 00:58:00+03	114700.00
48F5FB	2017-07-26 04:18:00+03	28800.00
48F62F	2017-08-14 08:11:00+03	119300.00
48F643	2017-08-11 04:16:00+03	116000.00
48F67D	2017-07-27 01:00:00+03	75600.00
48F684	2017-07-30 14:21:00+03	78300.00
48F6A6	2017-07-13 16:05:00+03	10800.00
48F6CA	2017-08-14 12:25:00+03	97900.00
48F6F5	2017-08-14 03:51:00+03	14800.00
48F74B	2017-08-15 13:54:00+03	67200.00
48F7B7	2017-08-01 03:55:00+03	48900.00
48F7C7	2017-07-26 00:49:00+03	103900.00
48F809	2017-08-06 00:33:00+03	53700.00
48F88A	2017-07-23 09:58:00+03	64100.00
48F8DB	2017-08-09 09:33:00+03	23400.00
48F8E6	2017-08-15 09:07:00+03	43600.00
48F8F1	2017-07-08 18:51:00+03	79200.00
48F928	2017-08-06 23:55:00+03	26000.00
48F944	2017-07-12 07:29:00+03	65200.00
48F9A7	2017-07-05 23:58:00+03	10700.00
48F9F3	2017-08-12 07:15:00+03	37100.00
48FA02	2017-07-17 02:23:00+03	42800.00
48FA09	2017-07-19 08:50:00+03	55800.00
48FA7C	2017-07-15 04:04:00+03	23600.00
48FACC	2017-07-17 12:16:00+03	24400.00
48FACD	2017-08-13 07:13:00+03	47600.00
48FAE2	2017-08-08 22:48:00+03	67600.00
48FB07	2017-07-27 15:55:00+03	54000.00
48FB83	2017-07-26 07:59:00+03	99200.00
48FBA8	2017-07-14 13:17:00+03	372500.00
48FBC4	2017-07-28 11:49:00+03	64500.00
48FBED	2017-07-03 16:54:00+03	81600.00
48FC0B	2017-07-31 09:51:00+03	134400.00
48FC73	2017-08-15 01:41:00+03	177600.00
48FC76	2017-07-25 20:11:00+03	34600.00
48FCA6	2017-08-15 03:03:00+03	24000.00
48FCEE	2017-07-22 15:31:00+03	37900.00
48FD2E	2017-07-04 12:06:00+03	92100.00
48FD6D	2017-07-31 05:06:00+03	46700.00
48FD7A	2017-07-20 21:43:00+03	39800.00
48FDE1	2017-08-11 11:10:00+03	31200.00
48FDE6	2017-07-25 20:44:00+03	46300.00
48FE51	2017-07-05 08:13:00+03	57300.00
48FF28	2017-08-09 00:08:00+03	29600.00
48FF3F	2017-08-04 18:57:00+03	10800.00
48FF44	2017-07-06 05:31:00+03	207200.00
48FF49	2017-07-01 05:33:00+03	29200.00
48FF59	2017-07-31 06:59:00+03	25400.00
48FF66	2017-06-29 08:10:00+03	139300.00
48FF9A	2017-07-17 13:33:00+03	390400.00
48FFEC	2017-08-06 07:14:00+03	409100.00
490018	2017-07-07 14:49:00+03	193700.00
49004E	2017-08-14 17:58:00+03	46000.00
49005F	2017-08-09 09:46:00+03	123600.00
490087	2017-07-10 01:39:00+03	39200.00
4900E7	2017-07-30 01:42:00+03	94100.00
4900EE	2017-07-07 00:09:00+03	21500.00
490102	2017-07-09 17:26:00+03	115900.00
49011D	2017-08-14 17:33:00+03	27200.00
490228	2017-07-19 07:27:00+03	223200.00
490241	2017-07-18 21:55:00+03	65500.00
490295	2017-07-29 14:16:00+03	54800.00
4902B7	2017-07-18 17:25:00+03	270200.00
49030E	2017-07-26 11:43:00+03	57600.00
4903C9	2017-08-14 13:15:00+03	87100.00
490405	2017-07-28 07:32:00+03	23100.00
4904C0	2017-07-29 00:57:00+03	18800.00
49052D	2017-07-09 20:19:00+03	98400.00
49055C	2017-07-08 08:58:00+03	23200.00
49061B	2017-08-12 05:38:00+03	90000.00
490623	2017-08-05 20:58:00+03	26700.00
49063B	2017-08-14 16:09:00+03	57700.00
490641	2017-07-02 10:29:00+03	37600.00
490683	2017-08-14 11:27:00+03	38600.00
490698	2017-07-27 18:21:00+03	27800.00
4906E9	2017-08-14 20:24:00+03	34800.00
49075A	2017-07-17 14:37:00+03	56400.00
490792	2017-07-25 11:05:00+03	166000.00
490914	2017-07-31 16:31:00+03	36200.00
490A04	2017-06-28 21:11:00+03	55000.00
490A0E	2017-07-26 08:29:00+03	57400.00
490A3D	2017-07-21 18:35:00+03	146400.00
490A68	2017-07-30 01:21:00+03	71600.00
490A7B	2017-08-10 01:16:00+03	70600.00
490AC8	2017-08-01 22:52:00+03	48800.00
490B40	2017-07-04 09:55:00+03	55800.00
490B66	2017-08-03 10:16:00+03	51800.00
490BC5	2017-08-08 03:35:00+03	81700.00
490CA0	2017-07-17 16:55:00+03	24400.00
490D18	2017-07-07 16:28:00+03	21400.00
490DB5	2017-07-24 16:36:00+03	32100.00
490E22	2017-07-23 02:18:00+03	125800.00
490E53	2017-07-02 11:35:00+03	20000.00
490EA9	2017-08-08 02:23:00+03	76600.00
490EB2	2017-07-21 23:37:00+03	108500.00
490EB4	2017-07-31 19:44:00+03	153700.00
490F0F	2017-07-18 23:59:00+03	67000.00
490F25	2017-07-13 14:13:00+03	257600.00
490F2C	2017-07-09 01:07:00+03	27200.00
490F88	2017-08-01 08:44:00+03	106100.00
490F90	2017-07-31 15:51:00+03	111600.00
491004	2017-07-13 02:28:00+03	109600.00
49104E	2017-08-09 02:25:00+03	94000.00
491053	2017-06-30 10:32:00+03	40400.00
4910A2	2017-08-04 11:32:00+03	266400.00
4910FF	2017-08-15 08:58:00+03	11300.00
491154	2017-07-17 12:46:00+03	84500.00
491158	2017-08-10 18:07:00+03	12000.00
4911CC	2017-07-11 05:46:00+03	37200.00
491239	2017-07-23 13:44:00+03	11600.00
49125D	2017-07-30 10:09:00+03	134600.00
491278	2017-08-10 20:14:00+03	14400.00
491341	2017-08-11 17:07:00+03	64100.00
491349	2017-08-13 21:50:00+03	40800.00
491395	2017-07-25 12:41:00+03	126600.00
4913F8	2017-07-04 22:11:00+03	200000.00
49155D	2017-07-12 17:09:00+03	24000.00
4915A6	2017-08-11 03:15:00+03	25600.00
4915F1	2017-07-11 21:50:00+03	46200.00
4915FC	2017-07-25 12:44:00+03	104600.00
491692	2017-07-17 23:02:00+03	99200.00
4916F3	2017-07-10 05:11:00+03	18400.00
4916F7	2017-08-07 21:33:00+03	50400.00
49184C	2017-07-24 06:24:00+03	99300.00
49184E	2017-07-13 23:09:00+03	174400.00
49184F	2017-07-10 21:47:00+03	35400.00
491869	2017-07-03 01:45:00+03	61800.00
491877	2017-07-12 21:40:00+03	16400.00
491887	2017-08-07 05:13:00+03	48400.00
491897	2017-07-06 08:09:00+03	30200.00
4918A8	2017-07-17 02:14:00+03	27200.00
491928	2017-08-12 00:48:00+03	28800.00
49195A	2017-07-24 09:02:00+03	147700.00
4919BE	2017-07-02 05:34:00+03	46000.00
4919C8	2017-08-01 01:07:00+03	56600.00
491AA1	2017-08-05 10:52:00+03	12000.00
491AA9	2017-07-14 09:21:00+03	60800.00
491B09	2017-06-30 13:27:00+03	402700.00
491B1B	2017-07-20 04:46:00+03	149000.00
491B24	2017-07-30 02:26:00+03	23200.00
491B2C	2017-07-10 00:02:00+03	119500.00
491B2D	2017-07-04 18:28:00+03	202300.00
491B37	2017-07-04 13:30:00+03	96200.00
491B60	2017-07-19 16:50:00+03	118200.00
491B65	2017-06-30 18:28:00+03	29600.00
491BD6	2017-07-31 01:23:00+03	62600.00
491BEF	2017-07-08 13:55:00+03	25400.00
491C1B	2017-07-15 00:10:00+03	40100.00
491C7C	2017-07-20 01:25:00+03	25100.00
491CF4	2017-07-04 17:05:00+03	59200.00
491D18	2017-06-30 04:54:00+03	20200.00
491D7E	2017-07-23 02:32:00+03	40000.00
491DDE	2017-07-23 18:52:00+03	28000.00
491DDF	2017-07-14 06:49:00+03	73500.00
491E8B	2017-07-08 03:05:00+03	266200.00
491EC0	2017-07-11 03:38:00+03	354400.00
491FE9	2017-08-14 00:30:00+03	94900.00
492028	2017-07-06 10:27:00+03	44000.00
49202F	2017-08-10 15:53:00+03	40100.00
492032	2017-07-25 19:07:00+03	10800.00
492037	2017-08-12 07:54:00+03	28800.00
49210C	2017-07-26 03:25:00+03	258000.00
492141	2017-08-01 03:06:00+03	23600.00
492161	2017-06-28 23:02:00+03	67500.00
49219D	2017-07-24 00:01:00+03	36200.00
4921D5	2017-07-16 23:04:00+03	40600.00
492242	2017-08-12 08:53:00+03	31600.00
4922CF	2017-08-06 10:36:00+03	23600.00
4922F9	2017-07-10 21:43:00+03	28000.00
4922FD	2017-07-02 18:42:00+03	43500.00
49236B	2017-07-10 18:05:00+03	55800.00
4923CC	2017-08-09 03:18:00+03	31600.00
4923CE	2017-07-17 04:51:00+03	137600.00
4923E7	2017-07-07 00:15:00+03	135700.00
49243E	2017-08-14 21:40:00+03	37900.00
492443	2017-08-08 16:06:00+03	41400.00
492463	2017-08-14 21:13:00+03	65900.00
492483	2017-07-25 04:13:00+03	38400.00
492485	2017-08-09 00:49:00+03	34000.00
4924C6	2017-07-30 17:29:00+03	28800.00
4924D7	2017-07-25 12:29:00+03	170800.00
4924DB	2017-07-11 09:50:00+03	68100.00
49253D	2017-07-27 04:28:00+03	47000.00
4925AE	2017-07-17 05:10:00+03	130100.00
4925B4	2017-07-20 22:50:00+03	116000.00
4925E1	2017-08-15 01:00:00+03	311900.00
492621	2017-08-13 20:29:00+03	131100.00
4926D6	2017-07-25 15:46:00+03	98800.00
4926F5	2017-07-28 17:55:00+03	17600.00
492732	2017-07-29 22:51:00+03	26000.00
4927DB	2017-08-11 18:47:00+03	135400.00
49286D	2017-07-08 11:39:00+03	6000.00
492916	2017-07-31 20:25:00+03	12600.00
492AE4	2017-07-19 15:55:00+03	28000.00
492AF6	2017-08-12 17:18:00+03	286100.00
492B0A	2017-07-18 04:24:00+03	52900.00
492B34	2017-07-15 12:00:00+03	57600.00
492BDC	2017-07-25 20:12:00+03	85000.00
492BE3	2017-08-03 19:46:00+03	147700.00
492BE9	2017-08-03 00:38:00+03	46400.00
492BF7	2017-07-20 03:57:00+03	463300.00
492C02	2017-07-29 04:57:00+03	23200.00
492C09	2017-07-04 18:00:00+03	56900.00
492C37	2017-07-27 18:02:00+03	73400.00
492C42	2017-08-07 01:06:00+03	50000.00
492CA8	2017-08-05 17:14:00+03	23400.00
492D57	2017-07-31 00:29:00+03	50600.00
492D92	2017-08-13 20:42:00+03	36800.00
492DEA	2017-08-13 06:23:00+03	260300.00
492E00	2017-07-20 01:19:00+03	26000.00
492E4B	2017-08-09 17:14:00+03	62700.00
492E78	2017-07-11 16:42:00+03	184300.00
492FFE	2017-07-12 05:00:00+03	193700.00
493012	2017-08-07 06:24:00+03	95600.00
49307B	2017-07-06 18:02:00+03	67000.00
493083	2017-08-13 12:54:00+03	46400.00
493159	2017-07-06 17:25:00+03	28000.00
49315B	2017-08-12 21:54:00+03	98400.00
493168	2017-08-15 16:13:00+03	56000.00
4931C3	2017-08-13 04:03:00+03	86400.00
493240	2017-08-11 18:43:00+03	67200.00
493251	2017-07-26 17:00:00+03	7200.00
49327F	2017-07-11 19:00:00+03	59300.00
49329C	2017-07-15 19:30:00+03	67600.00
4932AB	2017-07-27 20:02:00+03	88900.00
4932F7	2017-08-08 06:14:00+03	59300.00
493303	2017-08-10 23:30:00+03	13600.00
493304	2017-07-05 21:50:00+03	52000.00
493314	2017-07-14 14:38:00+03	31400.00
49336D	2017-07-04 07:46:00+03	25600.00
49347C	2017-07-24 18:15:00+03	28000.00
49347D	2017-07-22 00:42:00+03	16400.00
49348D	2017-07-31 17:06:00+03	28000.00
493491	2017-08-01 07:34:00+03	133200.00
493501	2017-07-18 09:44:00+03	25600.00
49350B	2017-08-02 17:07:00+03	28000.00
49353E	2017-07-27 01:48:00+03	8200.00
493540	2017-08-08 12:21:00+03	55000.00
493543	2017-07-27 03:09:00+03	119700.00
493554	2017-07-23 09:25:00+03	86800.00
493569	2017-08-13 20:20:00+03	23200.00
493575	2017-08-12 21:54:00+03	54800.00
4935B5	2017-07-24 14:50:00+03	119500.00
4935CA	2017-07-27 13:23:00+03	23200.00
4935EC	2017-08-11 04:28:00+03	71200.00
49367B	2017-07-06 09:05:00+03	97800.00
49368F	2017-07-14 12:11:00+03	28000.00
4936D1	2017-07-22 04:37:00+03	45800.00
493702	2017-08-11 13:54:00+03	24800.00
493741	2017-07-17 15:19:00+03	133100.00
49375A	2017-06-29 17:43:00+03	52300.00
49378D	2017-07-30 07:18:00+03	121500.00
4937BF	2017-08-08 17:49:00+03	75300.00
493863	2017-08-12 23:18:00+03	114800.00
49389A	2017-08-13 17:48:00+03	23200.00
49396B	2017-08-01 12:36:00+03	111600.00
4939E1	2017-07-18 10:04:00+03	12200.00
493A24	2017-07-15 22:01:00+03	43500.00
493AB0	2017-08-05 11:49:00+03	87000.00
493AB4	2017-07-19 18:20:00+03	194200.00
493B29	2017-07-17 16:19:00+03	137900.00
493B5D	2017-07-17 01:47:00+03	60400.00
493BAC	2017-08-02 11:01:00+03	54300.00
493BD6	2017-07-14 22:18:00+03	73100.00
493C2F	2017-08-05 06:21:00+03	8400.00
493C5E	2017-07-06 01:10:00+03	23200.00
493D07	2017-07-31 23:35:00+03	56000.00
493D0A	2017-07-18 23:23:00+03	6900.00
493D46	2017-07-02 18:05:00+03	23400.00
493D4A	2017-08-07 15:02:00+03	23600.00
493D61	2017-08-10 02:50:00+03	122700.00
493F0D	2017-07-06 22:19:00+03	538000.00
493F54	2017-08-06 05:36:00+03	106400.00
494021	2017-07-16 21:05:00+03	46800.00
49404D	2017-07-30 22:14:00+03	136500.00
4940A8	2017-07-01 18:18:00+03	24800.00
4940AF	2017-07-31 07:03:00+03	26000.00
4940C0	2017-08-13 04:47:00+03	38800.00
4940D1	2017-08-10 08:58:00+03	147700.00
494159	2017-08-05 12:37:00+03	19600.00
4941A2	2017-07-29 13:58:00+03	39800.00
4941CC	2017-08-08 17:40:00+03	30000.00
49424F	2017-07-01 04:45:00+03	45200.00
49428B	2017-07-05 19:23:00+03	96800.00
4942BD	2017-07-17 13:52:00+03	12600.00
494301	2017-07-14 13:19:00+03	265700.00
494344	2017-08-05 23:47:00+03	68000.00
494358	2017-08-08 04:04:00+03	65600.00
49436F	2017-07-14 10:45:00+03	103000.00
49439A	2017-07-04 18:51:00+03	61600.00
4943B1	2017-07-19 10:54:00+03	55800.00
4943F5	2017-07-17 22:36:00+03	48400.00
494404	2017-08-08 09:06:00+03	19600.00
494412	2017-07-12 01:28:00+03	8000.00
494418	2017-07-31 06:07:00+03	285500.00
49442F	2017-08-12 00:32:00+03	36200.00
494433	2017-07-19 02:14:00+03	90400.00
49443D	2017-07-16 17:18:00+03	40000.00
494452	2017-08-15 09:59:00+03	30600.00
494453	2017-08-11 09:48:00+03	134400.00
4944BA	2017-07-19 05:00:00+03	41200.00
4944CC	2017-08-08 03:54:00+03	47100.00
4944E2	2017-08-13 11:34:00+03	35900.00
49450D	2017-08-09 02:48:00+03	117800.00
49452E	2017-06-29 15:33:00+03	21800.00
494537	2017-08-01 15:59:00+03	29600.00
494591	2017-08-06 23:43:00+03	44600.00
4945EE	2017-07-15 10:07:00+03	133200.00
494610	2017-07-26 14:11:00+03	123000.00
49464F	2017-07-18 20:07:00+03	31600.00
49469A	2017-08-02 22:07:00+03	11600.00
494770	2017-07-05 20:10:00+03	6600.00
49477E	2017-08-09 04:33:00+03	246000.00
4947F3	2017-08-08 13:25:00+03	17800.00
494813	2017-07-26 14:11:00+03	40000.00
494852	2017-07-06 21:48:00+03	55800.00
4948A4	2017-07-04 02:00:00+03	58000.00
4948BB	2017-07-17 14:40:00+03	29600.00
4948D3	2017-07-15 18:27:00+03	93400.00
49490E	2017-07-24 17:09:00+03	397600.00
494A0C	2017-07-22 16:37:00+03	121300.00
494A32	2017-07-11 17:51:00+03	69900.00
494A42	2017-07-28 02:45:00+03	156600.00
494A69	2017-08-13 00:14:00+03	43600.00
494AD6	2017-08-08 23:22:00+03	28000.00
494B22	2017-08-03 02:59:00+03	89700.00
494B71	2017-07-04 18:33:00+03	46400.00
494BC7	2017-07-22 13:35:00+03	266800.00
494BEB	2017-07-11 10:54:00+03	98000.00
494C2F	2017-08-07 09:25:00+03	72000.00
494CF6	2017-07-21 23:03:00+03	14400.00
494D06	2017-07-01 08:07:00+03	202400.00
494D36	2017-07-14 05:17:00+03	53300.00
494D50	2017-07-04 10:19:00+03	27300.00
494DFC	2017-06-27 16:22:00+03	67600.00
494E33	2017-08-11 18:34:00+03	67400.00
494E4C	2017-08-08 17:01:00+03	8000.00
494E70	2017-08-13 09:46:00+03	54800.00
494E99	2017-07-20 19:50:00+03	42800.00
494ECE	2017-08-13 18:23:00+03	30400.00
494EF9	2017-07-30 16:50:00+03	125200.00
494F48	2017-07-16 05:19:00+03	69000.00
494F6F	2017-08-15 00:03:00+03	149100.00
494F82	2017-07-24 13:28:00+03	291000.00
49500D	2017-07-18 04:41:00+03	28000.00
495035	2017-07-10 03:36:00+03	157700.00
49507E	2017-07-27 22:30:00+03	47200.00
49511A	2017-07-25 03:57:00+03	207100.00
49512D	2017-08-02 19:32:00+03	36800.00
495199	2017-07-30 18:55:00+03	44000.00
49519A	2017-08-04 08:14:00+03	127900.00
4951BB	2017-07-12 08:03:00+03	4000.00
4951E5	2017-07-13 22:49:00+03	131100.00
495221	2017-07-23 00:32:00+03	134400.00
49525B	2017-08-05 13:59:00+03	25000.00
49527A	2017-07-12 10:50:00+03	28000.00
4952B8	2017-07-11 14:04:00+03	48300.00
495305	2017-07-26 06:18:00+03	92700.00
495358	2017-07-11 10:47:00+03	42600.00
49537D	2017-07-25 05:42:00+03	265700.00
4953B9	2017-08-13 06:23:00+03	56000.00
495416	2017-07-22 06:40:00+03	21800.00
495448	2017-08-08 08:03:00+03	26800.00
4954CB	2017-07-21 07:09:00+03	36700.00
4954FE	2017-07-12 06:30:00+03	87400.00
495556	2017-07-02 07:00:00+03	65900.00
495560	2017-07-22 11:09:00+03	26000.00
495592	2017-08-09 21:29:00+03	25600.00
4955D9	2017-07-10 18:38:00+03	192400.00
495626	2017-07-23 00:10:00+03	28700.00
49570D	2017-07-30 23:01:00+03	56600.00
49574C	2017-08-04 14:31:00+03	12400.00
495802	2017-07-15 15:41:00+03	41800.00
495821	2017-07-17 12:08:00+03	14400.00
495859	2017-07-22 07:31:00+03	43600.00
495885	2017-08-14 13:27:00+03	127700.00
495890	2017-08-05 02:23:00+03	133200.00
4958C4	2017-07-06 13:57:00+03	21800.00
4958DC	2017-08-09 13:48:00+03	242300.00
4958E0	2017-07-12 15:11:00+03	68000.00
495947	2017-07-05 05:49:00+03	372500.00
495979	2017-08-15 04:06:00+03	26700.00
4959B6	2017-08-07 07:18:00+03	58800.00
4959C2	2017-08-04 16:11:00+03	6800.00
4959EA	2017-08-12 15:45:00+03	119700.00
495A66	2017-07-15 06:29:00+03	24400.00
495A8B	2017-07-20 17:31:00+03	62000.00
495B62	2017-08-14 12:47:00+03	87000.00
495BAF	2017-08-02 23:11:00+03	145300.00
495C5D	2017-07-08 18:20:00+03	27400.00
495CB8	2017-07-25 23:14:00+03	54500.00
495D0F	2017-07-10 18:51:00+03	162600.00
495D21	2017-07-20 00:34:00+03	30000.00
495D35	2017-08-14 02:39:00+03	279800.00
495D3B	2017-08-14 09:01:00+03	37200.00
495D86	2017-07-30 18:35:00+03	10700.00
495DA7	2017-06-30 15:48:00+03	179400.00
495E38	2017-08-12 07:54:00+03	27200.00
495E47	2017-07-18 05:01:00+03	12200.00
495E53	2017-08-10 06:31:00+03	7400.00
495E61	2017-07-17 20:29:00+03	36200.00
495E7D	2017-07-26 06:00:00+03	135400.00
495E8E	2017-07-09 16:07:00+03	28800.00
495EDF	2017-07-27 10:30:00+03	53800.00
495EE7	2017-07-29 15:04:00+03	144400.00
495EF9	2017-07-02 16:52:00+03	125400.00
495F04	2017-08-06 14:39:00+03	26200.00
495F1F	2017-07-18 09:21:00+03	62000.00
495F7F	2017-07-05 00:53:00+03	7400.00
496042	2017-08-15 07:08:00+03	8200.00
496090	2017-08-07 18:43:00+03	100000.00
4960C4	2017-07-23 16:33:00+03	399600.00
496176	2017-07-26 15:02:00+03	49300.00
4961C9	2017-08-10 08:40:00+03	7400.00
4961F1	2017-07-25 06:59:00+03	41400.00
4962BC	2017-07-19 01:32:00+03	16400.00
496336	2017-07-21 00:18:00+03	31400.00
49638C	2017-08-01 14:28:00+03	28600.00
49639B	2017-07-02 09:16:00+03	44800.00
49640E	2017-07-20 18:24:00+03	73300.00
496456	2017-07-20 00:57:00+03	127800.00
496542	2017-07-04 23:33:00+03	114800.00
4965DE	2017-07-04 16:33:00+03	26000.00
49660E	2017-08-06 17:51:00+03	65900.00
4966B2	2017-07-13 01:38:00+03	61800.00
496717	2017-08-09 05:29:00+03	32800.00
49672D	2017-08-08 18:00:00+03	58200.00
4967F6	2017-06-25 20:29:00+03	240600.00
4967F9	2017-07-16 04:38:00+03	68900.00
496828	2017-07-03 00:11:00+03	279800.00
496916	2017-07-30 11:12:00+03	50400.00
49695B	2017-08-14 17:22:00+03	198500.00
496975	2017-08-08 01:13:00+03	6300.00
496A48	2017-07-15 18:33:00+03	133100.00
496A56	2017-07-12 08:17:00+03	40600.00
496AAC	2017-07-01 10:54:00+03	55800.00
496ACD	2017-07-11 10:33:00+03	28000.00
496B4B	2017-07-22 09:41:00+03	81500.00
496B84	2017-08-10 07:41:00+03	184300.00
496B88	2017-08-15 07:54:00+03	115900.00
496B8A	2017-07-05 02:02:00+03	28000.00
496BC7	2017-07-25 02:46:00+03	7200.00
496C2F	2017-07-20 04:28:00+03	36800.00
496C4B	2017-07-31 21:59:00+03	26700.00
496C5B	2017-07-26 06:55:00+03	99700.00
496CC2	2017-08-14 02:35:00+03	42400.00
496CFA	2017-08-05 00:43:00+03	206800.00
496D14	2017-07-21 20:26:00+03	179400.00
496D37	2017-06-28 20:15:00+03	13400.00
496D60	2017-07-24 12:56:00+03	57800.00
496E25	2017-07-18 21:32:00+03	82900.00
496E98	2017-07-04 09:11:00+03	17600.00
496EBE	2017-07-04 23:31:00+03	84000.00
496F2D	2017-07-09 14:55:00+03	28000.00
496F31	2017-07-26 22:27:00+03	26800.00
496F5D	2017-07-20 09:29:00+03	25100.00
496FAF	2017-08-15 14:21:00+03	68800.00
496FB2	2017-08-03 11:58:00+03	92600.00
496FDC	2017-07-18 11:23:00+03	98000.00
497053	2017-08-10 03:31:00+03	6700.00
4970A2	2017-08-11 22:31:00+03	178800.00
49712C	2017-07-17 01:47:00+03	281900.00
49712E	2017-07-24 17:27:00+03	29600.00
49713E	2017-07-04 23:17:00+03	105000.00
497143	2017-07-22 23:00:00+03	663600.00
497165	2017-07-27 15:41:00+03	6700.00
49719E	2017-08-10 13:18:00+03	92800.00
49720D	2017-08-04 12:52:00+03	6600.00
497280	2017-07-27 13:45:00+03	202300.00
4972A1	2017-07-17 16:13:00+03	57400.00
4972C9	2017-08-09 13:34:00+03	28000.00
497315	2017-07-23 22:27:00+03	409600.00
497344	2017-06-24 02:29:00+03	61800.00
497370	2017-07-08 04:26:00+03	60000.00
4973B2	2017-07-08 08:58:00+03	105600.00
497415	2017-07-21 12:54:00+03	53700.00
497433	2017-08-08 14:27:00+03	69500.00
497481	2017-07-26 07:08:00+03	119600.00
4974BF	2017-07-27 16:09:00+03	48800.00
4974E3	2017-07-28 06:34:00+03	70400.00
4974EE	2017-07-31 07:18:00+03	75300.00
49753D	2017-07-26 04:32:00+03	67600.00
497545	2017-06-30 13:33:00+03	31600.00
49756F	2017-07-04 13:30:00+03	62800.00
497603	2017-08-14 15:36:00+03	68400.00
497613	2017-07-29 16:56:00+03	135400.00
49761C	2017-07-07 10:10:00+03	44800.00
4976AD	2017-07-15 07:04:00+03	6000.00
4976FA	2017-08-11 10:29:00+03	27200.00
497746	2017-07-30 05:06:00+03	43800.00
497783	2017-07-27 18:13:00+03	23100.00
4977AE	2017-07-19 21:26:00+03	112000.00
497866	2017-07-17 09:18:00+03	45000.00
497919	2017-07-28 11:18:00+03	47000.00
497924	2017-08-11 21:57:00+03	26000.00
497966	2017-07-05 02:34:00+03	13400.00
497983	2017-08-08 07:06:00+03	34000.00
4979F4	2017-07-09 01:43:00+03	159100.00
497A73	2017-07-02 15:03:00+03	24400.00
497AA7	2017-07-04 05:08:00+03	8200.00
497AB7	2017-07-09 11:28:00+03	166700.00
497AFF	2017-07-24 02:20:00+03	38800.00
497B55	2017-07-30 05:50:00+03	266400.00
497BB7	2017-06-26 23:59:00+03	29600.00
497BCE	2017-08-07 15:57:00+03	39300.00
497BD1	2017-08-12 15:18:00+03	179200.00
497C05	2017-08-10 20:44:00+03	22000.00
497C06	2017-06-30 07:39:00+03	28800.00
497C08	2017-07-21 00:54:00+03	11000.00
497C29	2017-07-11 09:19:00+03	147000.00
497C87	2017-07-07 18:42:00+03	136200.00
497E14	2017-07-07 17:54:00+03	6300.00
497E2C	2017-08-05 20:45:00+03	165000.00
497EE2	2017-07-23 10:22:00+03	89600.00
497F30	2017-07-15 13:57:00+03	50600.00
497FEA	2017-07-14 20:47:00+03	21800.00
497FFF	2017-08-11 11:49:00+03	6000.00
498025	2017-07-15 22:07:00+03	36600.00
498046	2017-08-10 13:37:00+03	30200.00
49811D	2017-08-03 14:28:00+03	136000.00
498120	2017-07-07 10:30:00+03	30200.00
498236	2017-07-27 12:39:00+03	25200.00
498244	2017-07-19 15:00:00+03	187600.00
498274	2017-07-04 08:51:00+03	398600.00
49828C	2017-08-01 11:27:00+03	68100.00
4982B4	2017-07-30 23:25:00+03	45200.00
498311	2017-08-01 15:48:00+03	86800.00
498329	2017-08-12 20:41:00+03	14000.00
49836A	2017-07-06 10:08:00+03	291600.00
49837C	2017-08-09 01:45:00+03	315500.00
4983AD	2017-07-19 17:41:00+03	147700.00
4983D6	2017-07-13 10:12:00+03	47000.00
49842C	2017-07-29 04:42:00+03	133100.00
49842D	2017-07-15 14:26:00+03	22400.00
49842F	2017-08-08 06:26:00+03	115800.00
498431	2017-08-02 17:30:00+03	28000.00
498488	2017-07-16 07:38:00+03	46000.00
498497	2017-07-23 13:57:00+03	30200.00
49850B	2017-07-06 07:09:00+03	23200.00
49852C	2017-08-08 08:59:00+03	186900.00
49858E	2017-07-14 11:29:00+03	377100.00
4985A7	2017-07-25 19:21:00+03	398300.00
498608	2017-08-09 22:39:00+03	43200.00
49863A	2017-07-08 14:49:00+03	75300.00
498682	2017-08-10 19:03:00+03	39500.00
4986A7	2017-08-09 07:19:00+03	136200.00
49879E	2017-08-09 19:12:00+03	106200.00
4987A8	2017-07-23 11:46:00+03	58600.00
4987F2	2017-07-23 04:08:00+03	82900.00
498824	2017-08-14 16:22:00+03	73500.00
49884E	2017-07-03 09:36:00+03	16400.00
4988E0	2017-07-25 00:03:00+03	6700.00
498954	2017-07-02 06:59:00+03	6300.00
49896D	2017-07-15 10:30:00+03	67000.00
498988	2017-07-28 18:47:00+03	106000.00
498A13	2017-07-17 02:05:00+03	66000.00
498A3E	2017-08-11 05:19:00+03	43200.00
498A4C	2017-07-07 10:19:00+03	29200.00
498A6B	2017-07-20 13:55:00+03	26000.00
498AE0	2017-07-08 05:13:00+03	88800.00
498B2F	2017-08-02 21:59:00+03	16400.00
498C91	2017-07-18 05:38:00+03	35800.00
498C98	2017-08-10 01:48:00+03	31200.00
498D38	2017-07-24 19:36:00+03	61300.00
498DFB	2017-07-31 22:38:00+03	34000.00
498E1F	2017-07-27 04:53:00+03	192200.00
498E28	2017-07-04 12:00:00+03	23600.00
498E3E	2017-08-14 09:00:00+03	44800.00
498E59	2017-07-24 03:23:00+03	85000.00
498E5E	2017-07-26 04:29:00+03	134400.00
498EBF	2017-08-14 13:47:00+03	25900.00
498EDD	2017-07-30 18:14:00+03	12600.00
498F1A	2017-07-22 03:57:00+03	47700.00
498F5F	2017-08-12 23:33:00+03	43600.00
498F79	2017-07-20 22:19:00+03	16400.00
498FB3	2017-07-30 19:15:00+03	46000.00
499000	2017-07-15 18:39:00+03	89700.00
499019	2017-07-22 02:29:00+03	49200.00
49902C	2017-07-12 19:04:00+03	93900.00
499032	2017-07-08 20:30:00+03	19600.00
49905A	2017-07-22 12:41:00+03	67600.00
49906C	2017-07-20 06:12:00+03	46400.00
4990DE	2017-07-15 08:23:00+03	79000.00
4990E7	2017-07-20 13:32:00+03	246000.00
499111	2017-07-21 03:51:00+03	54200.00
49913C	2017-08-06 09:22:00+03	57600.00
499146	2017-07-29 16:55:00+03	6700.00
499159	2017-07-03 13:24:00+03	188500.00
499178	2017-08-09 01:00:00+03	54200.00
499184	2017-07-18 07:47:00+03	37200.00
49918B	2017-06-30 11:29:00+03	34600.00
499280	2017-08-03 03:01:00+03	17200.00
4992A2	2017-07-18 19:08:00+03	44000.00
4992B8	2017-07-18 09:39:00+03	174000.00
4992C7	2017-07-31 12:41:00+03	59800.00
499328	2017-07-19 12:08:00+03	6700.00
49933B	2017-08-07 17:49:00+03	118500.00
499451	2017-07-25 21:59:00+03	66600.00
499494	2017-08-14 02:31:00+03	134800.00
4994B5	2017-08-10 05:45:00+03	26800.00
4994CD	2017-08-14 16:57:00+03	20400.00
4994FD	2017-07-30 12:34:00+03	20600.00
499547	2017-07-02 21:29:00+03	64500.00
499584	2017-07-08 07:37:00+03	30200.00
499599	2017-07-23 18:46:00+03	112000.00
4995BF	2017-08-12 13:35:00+03	67600.00
4995D4	2017-06-30 23:39:00+03	125700.00
49965B	2017-08-12 17:48:00+03	24400.00
499680	2017-08-11 15:17:00+03	28000.00
499724	2017-07-01 17:57:00+03	39800.00
499762	2017-08-15 03:51:00+03	23100.00
4997C7	2017-07-16 17:09:00+03	77900.00
4997D0	2017-07-18 16:10:00+03	69500.00
499851	2017-07-06 11:27:00+03	8200.00
499874	2017-08-11 14:44:00+03	67600.00
499895	2017-07-09 07:35:00+03	23600.00
4998AC	2017-08-01 01:39:00+03	218000.00
499909	2017-07-09 23:18:00+03	24600.00
49995E	2017-07-24 21:16:00+03	165500.00
49996F	2017-07-21 11:18:00+03	56600.00
499986	2017-07-11 15:22:00+03	27300.00
4999B7	2017-07-12 22:15:00+03	55800.00
4999ED	2017-07-05 02:49:00+03	131100.00
499A28	2017-07-14 23:04:00+03	23200.00
499A34	2017-07-08 03:47:00+03	63200.00
499A5C	2017-08-05 15:18:00+03	24800.00
499A69	2017-07-10 16:22:00+03	56000.00
499A7C	2017-08-03 22:42:00+03	56000.00
499AD8	2017-08-12 01:48:00+03	42800.00
499AFC	2017-07-05 20:31:00+03	37900.00
499B74	2017-07-16 09:06:00+03	13400.00
499BD9	2017-08-15 16:13:00+03	8200.00
499C05	2017-08-13 12:42:00+03	167400.00
499C3A	2017-08-13 17:43:00+03	123000.00
499D3B	2017-07-23 08:45:00+03	136000.00
499D73	2017-07-07 11:16:00+03	21000.00
499D81	2017-08-12 00:25:00+03	39100.00
499D9E	2017-07-08 05:21:00+03	37900.00
499E58	2017-07-23 17:18:00+03	28000.00
499E84	2017-07-25 01:39:00+03	135400.00
499F0C	2017-07-22 10:14:00+03	33800.00
499F21	2017-07-17 06:21:00+03	123200.00
499F3C	2017-07-18 00:36:00+03	70600.00
499F4E	2017-07-27 19:25:00+03	59100.00
499FBE	2017-08-04 15:13:00+03	66600.00
499FE8	2017-08-03 06:19:00+03	42800.00
499FFC	2017-07-13 20:53:00+03	25400.00
49A02C	2017-07-04 14:19:00+03	161300.00
49A05D	2017-07-21 00:41:00+03	170700.00
49A07C	2017-08-15 04:31:00+03	58800.00
49A084	2017-07-22 05:34:00+03	13200.00
49A092	2017-07-28 08:01:00+03	57600.00
49A0A7	2017-07-27 18:59:00+03	78000.00
49A0DA	2017-07-15 12:08:00+03	80000.00
49A10E	2017-08-15 04:49:00+03	257200.00
49A11E	2017-07-28 20:46:00+03	64500.00
49A12C	2017-08-12 06:10:00+03	43200.00
49A1D9	2017-07-13 21:58:00+03	80000.00
49A205	2017-07-02 07:41:00+03	68800.00
49A22D	2017-08-08 05:19:00+03	643700.00
49A253	2017-07-22 04:46:00+03	114400.00
49A261	2017-08-07 15:26:00+03	28800.00
49A2CC	2017-08-01 10:22:00+03	24400.00
49A2F4	2017-07-31 09:02:00+03	228700.00
49A340	2017-08-06 05:56:00+03	85600.00
49A347	2017-07-05 16:12:00+03	26700.00
49A354	2017-08-02 21:58:00+03	60400.00
49A36A	2017-08-10 00:52:00+03	92800.00
49A387	2017-07-18 00:29:00+03	87400.00
49A3B3	2017-07-25 09:34:00+03	50800.00
49A428	2017-08-12 18:17:00+03	26700.00
49A438	2017-07-27 11:00:00+03	127800.00
49A487	2017-08-01 12:41:00+03	111600.00
49A498	2017-08-02 02:38:00+03	57400.00
49A4CF	2017-07-11 19:10:00+03	40300.00
49A4E6	2017-08-01 06:53:00+03	95300.00
49A52F	2017-07-28 01:56:00+03	46800.00
49A5E1	2017-07-25 21:44:00+03	160700.00
49A626	2017-07-07 07:03:00+03	58400.00
49A677	2017-07-28 00:59:00+03	20400.00
49A67B	2017-07-09 13:48:00+03	202700.00
49A6C8	2017-07-19 16:10:00+03	40600.00
49A6D0	2017-07-27 00:04:00+03	56600.00
49A7AC	2017-07-30 22:20:00+03	6300.00
49A7AD	2017-07-06 12:35:00+03	76600.00
49A7B2	2017-07-16 11:27:00+03	289700.00
49A7D4	2017-07-30 21:12:00+03	20000.00
49A7E2	2017-07-14 07:22:00+03	56000.00
49A7EE	2017-08-05 19:45:00+03	233700.00
49A806	2017-08-09 10:45:00+03	12600.00
49A81E	2017-07-10 03:37:00+03	89700.00
49A825	2017-07-08 02:10:00+03	141000.00
49A85F	2017-08-04 10:41:00+03	32700.00
49A899	2017-08-04 02:56:00+03	11000.00
49A8D5	2017-08-08 11:53:00+03	79800.00
49A928	2017-07-19 03:24:00+03	66900.00
49A944	2017-07-02 10:59:00+03	28000.00
49A986	2017-06-28 04:52:00+03	133100.00
49A9BF	2017-08-12 05:41:00+03	8400.00
49A9E5	2017-07-22 22:56:00+03	26800.00
49AA60	2017-08-13 00:37:00+03	6800.00
49AB1E	2017-08-03 21:25:00+03	26700.00
49ABA7	2017-07-26 01:44:00+03	28000.00
49ABE4	2017-07-30 07:40:00+03	18000.00
49AC8C	2017-08-03 19:38:00+03	34400.00
49AC8E	2017-07-03 13:46:00+03	10800.00
49ACFA	2017-07-05 09:44:00+03	83200.00
49AD58	2017-07-17 15:38:00+03	129400.00
49AD5B	2017-07-28 14:21:00+03	113200.00
49AD7E	2017-07-06 23:31:00+03	52000.00
49ADC3	2017-07-03 03:16:00+03	134200.00
49AE56	2017-07-01 18:38:00+03	35300.00
49AEE7	2017-07-27 10:16:00+03	40800.00
49AEFB	2017-07-12 11:21:00+03	23200.00
49AF48	2017-07-14 10:54:00+03	28000.00
49AFB8	2017-08-03 02:40:00+03	23600.00
49B01F	2017-08-10 06:45:00+03	24800.00
49B05B	2017-07-13 22:32:00+03	37700.00
49B063	2017-07-21 09:37:00+03	89600.00
49B0C4	2017-07-23 16:20:00+03	26700.00
49B13C	2017-07-13 22:02:00+03	135600.00
49B1B7	2017-07-20 13:40:00+03	202100.00
49B1B9	2017-07-27 04:16:00+03	23400.00
49B258	2017-08-10 22:17:00+03	63700.00
49B27E	2017-08-09 20:40:00+03	32200.00
49B28D	2017-08-12 18:08:00+03	23400.00
49B2D2	2017-07-03 20:03:00+03	42800.00
49B2EB	2017-08-08 14:57:00+03	68800.00
49B2F1	2017-07-13 01:53:00+03	83000.00
49B41E	2017-07-31 02:47:00+03	87000.00
49B41F	2017-08-14 15:06:00+03	36100.00
49B461	2017-07-16 10:54:00+03	150600.00
49B466	2017-07-08 23:47:00+03	81600.00
49B509	2017-07-28 12:57:00+03	46300.00
49B56D	2017-07-30 02:57:00+03	70800.00
49B59E	2017-07-26 08:05:00+03	35700.00
49B609	2017-07-22 12:30:00+03	70800.00
49B656	2017-07-24 18:00:00+03	22000.00
49B66E	2017-06-30 15:45:00+03	15400.00
49B682	2017-08-13 01:22:00+03	69500.00
49B684	2017-07-20 21:08:00+03	29600.00
49B6CF	2017-08-10 04:38:00+03	55800.00
49B70A	2017-07-08 21:35:00+03	103700.00
49B754	2017-07-25 02:23:00+03	32800.00
49B75C	2017-07-09 04:31:00+03	39800.00
49B774	2017-07-28 15:14:00+03	107400.00
49B78D	2017-07-09 23:52:00+03	48800.00
49B79F	2017-07-28 12:47:00+03	55800.00
49B7BF	2017-08-01 08:17:00+03	229300.00
49B7C1	2017-07-02 03:37:00+03	112000.00
49B7D9	2017-07-22 01:56:00+03	46200.00
49B7E5	2017-07-03 05:30:00+03	45000.00
49B872	2017-07-27 17:52:00+03	242700.00
49B8BC	2017-07-17 22:18:00+03	46400.00
49B8E9	2017-07-21 22:58:00+03	14300.00
49B934	2017-07-03 07:28:00+03	11700.00
49B950	2017-07-28 15:07:00+03	46200.00
49B998	2017-07-25 20:07:00+03	27400.00
49B9AB	2017-08-05 08:24:00+03	26000.00
49BA37	2017-07-13 20:24:00+03	13700.00
49BAC3	2017-07-03 15:39:00+03	6700.00
49BB01	2017-08-07 08:21:00+03	167400.00
49BB43	2017-07-13 05:19:00+03	38400.00
49BBC5	2017-08-05 19:14:00+03	99300.00
49BBE6	2017-07-20 05:16:00+03	45800.00
49BC10	2017-07-05 09:50:00+03	266400.00
49BC63	2017-08-02 08:50:00+03	24600.00
49BC6B	2017-07-20 16:12:00+03	50600.00
49BCB0	2017-07-28 11:48:00+03	52900.00
49BCE9	2017-08-05 06:59:00+03	59800.00
49BCF4	2017-08-10 16:43:00+03	788200.00
49BD53	2017-07-09 19:48:00+03	19600.00
49BD60	2017-07-07 19:02:00+03	145300.00
49BD8C	2017-07-31 11:22:00+03	63700.00
49BD91	2017-07-31 15:33:00+03	111600.00
49BDA0	2017-08-06 12:01:00+03	685200.00
49BDD0	2017-07-18 08:32:00+03	55800.00
49BDFB	2017-08-14 21:23:00+03	85600.00
49BE1F	2017-08-05 04:19:00+03	56000.00
49BE3E	2017-07-01 20:29:00+03	248400.00
49BE56	2017-07-23 08:15:00+03	22000.00
49BE6C	2017-07-14 10:36:00+03	29200.00
49BE87	2017-07-06 14:14:00+03	55800.00
49BEC9	2017-08-12 09:16:00+03	532800.00
49BEE8	2017-08-04 21:28:00+03	25400.00
49BFA3	2017-07-21 23:58:00+03	28800.00
49C010	2017-08-04 15:42:00+03	200400.00
49C09A	2017-08-14 07:56:00+03	26700.00
49C0B8	2017-07-27 08:15:00+03	119700.00
49C0C2	2017-07-21 18:09:00+03	40800.00
49C0C4	2017-08-11 18:07:00+03	16900.00
49C104	2017-07-06 00:53:00+03	168000.00
49C105	2017-07-31 03:51:00+03	92700.00
49C10A	2017-08-12 17:14:00+03	36200.00
49C11B	2017-08-01 21:30:00+03	50600.00
49C157	2017-08-02 14:41:00+03	43200.00
49C17D	2017-08-03 12:46:00+03	35200.00
49C197	2017-08-15 06:39:00+03	120600.00
49C1C1	2017-07-10 13:23:00+03	66800.00
49C1F1	2017-08-08 01:58:00+03	47200.00
49C23B	2017-07-28 20:25:00+03	88100.00
49C24E	2017-07-13 16:10:00+03	65500.00
49C264	2017-07-03 01:06:00+03	135600.00
49C272	2017-07-31 16:32:00+03	34100.00
49C2B9	2017-07-04 01:59:00+03	37200.00
49C307	2017-08-06 01:15:00+03	39300.00
49C355	2017-08-13 15:26:00+03	62600.00
49C35F	2017-08-15 17:31:00+03	68800.00
49C37F	2017-07-25 04:44:00+03	42700.00
49C393	2017-07-16 13:38:00+03	131600.00
49C3BB	2017-08-10 19:18:00+03	53600.00
49C3D5	2017-08-02 21:31:00+03	28000.00
49C440	2017-08-10 02:27:00+03	68000.00
49C44F	2017-07-30 09:15:00+03	70700.00
49C48D	2017-07-29 01:42:00+03	28000.00
49C4DA	2017-07-01 17:55:00+03	77600.00
49C4DB	2017-07-13 05:17:00+03	78200.00
49C4E9	2017-07-26 07:01:00+03	23600.00
49C504	2017-07-28 02:58:00+03	9300.00
49C523	2017-07-23 13:19:00+03	16400.00
49C540	2017-07-08 07:54:00+03	31100.00
49C56E	2017-08-01 23:20:00+03	76600.00
49C57B	2017-07-03 09:26:00+03	47000.00
49C594	2017-07-27 12:05:00+03	57300.00
49C5CA	2017-07-03 16:54:00+03	39500.00
49C60C	2017-07-31 07:26:00+03	132800.00
49C636	2017-08-12 12:32:00+03	66600.00
49C651	2017-07-12 02:38:00+03	65900.00
49C65C	2017-07-23 11:17:00+03	41200.00
49C668	2017-08-14 06:27:00+03	61500.00
49C690	2017-08-06 11:21:00+03	48300.00
49C6B9	2017-07-21 00:57:00+03	81900.00
49C6E3	2017-08-10 01:32:00+03	54800.00
49C75B	2017-07-19 12:39:00+03	6800.00
49C78E	2017-07-28 14:48:00+03	199700.00
49C809	2017-07-06 11:59:00+03	40100.00
49C82C	2017-07-10 01:48:00+03	55600.00
49C8C5	2017-06-27 01:08:00+03	166100.00
49C8D7	2017-07-02 22:38:00+03	48800.00
49C8DE	2017-07-07 23:14:00+03	69600.00
49C8EE	2017-07-22 16:50:00+03	24400.00
49C928	2017-07-29 16:47:00+03	8000.00
49C954	2017-08-10 23:01:00+03	23400.00
49C963	2017-07-20 03:51:00+03	62600.00
49CA26	2017-07-10 19:48:00+03	28000.00
49CA7A	2017-07-10 17:50:00+03	28800.00
49CA8B	2017-08-13 14:03:00+03	47400.00
49CA8D	2017-07-19 18:03:00+03	166000.00
49CA98	2017-08-10 14:56:00+03	55800.00
49CAEE	2017-08-11 08:46:00+03	69500.00
49CB53	2017-08-01 10:42:00+03	46300.00
49CB5B	2017-08-04 19:10:00+03	84500.00
49CB67	2017-07-21 04:04:00+03	6700.00
49CB6A	2017-08-08 20:00:00+03	30200.00
49CB6E	2017-08-07 13:31:00+03	115400.00
49CB74	2017-07-23 15:42:00+03	408500.00
49CB9D	2017-07-05 06:24:00+03	8000.00
49CBA1	2017-07-29 22:40:00+03	28000.00
49CBA5	2017-07-23 22:10:00+03	23600.00
49CBB3	2017-07-24 23:08:00+03	25400.00
49CC14	2017-07-25 19:15:00+03	40600.00
49CC76	2017-07-26 01:35:00+03	6700.00
49CC7B	2017-07-18 12:56:00+03	13400.00
49CC82	2017-07-14 20:13:00+03	102100.00
49CC8F	2017-07-04 01:11:00+03	7400.00
49CD3E	2017-07-11 00:30:00+03	33300.00
49CE1A	2017-07-16 05:31:00+03	41600.00
49CE35	2017-07-24 00:38:00+03	139100.00
49CE3F	2017-07-15 10:58:00+03	237400.00
49CE42	2017-07-25 14:07:00+03	266200.00
49CE4F	2017-08-13 07:17:00+03	193700.00
49CF08	2017-07-25 02:01:00+03	114800.00
49CF24	2017-07-25 19:55:00+03	52600.00
49CF37	2017-07-26 20:05:00+03	9200.00
49CFB3	2017-07-11 08:49:00+03	104000.00
49D054	2017-08-11 05:56:00+03	147400.00
49D07A	2017-06-30 03:56:00+03	56000.00
49D092	2017-07-02 10:59:00+03	29600.00
49D0C5	2017-08-12 10:48:00+03	30400.00
49D0FC	2017-08-06 09:43:00+03	32800.00
49D154	2017-07-07 15:58:00+03	168000.00
49D16D	2017-08-09 07:40:00+03	27200.00
49D1B0	2017-07-13 11:18:00+03	39500.00
49D1CE	2017-08-12 04:54:00+03	246000.00
49D1CF	2017-07-23 22:30:00+03	255600.00
49D1FD	2017-07-29 15:32:00+03	111600.00
49D20B	2017-06-29 22:30:00+03	81200.00
49D214	2017-07-10 23:09:00+03	118300.00
49D21E	2017-08-02 07:14:00+03	239400.00
49D228	2017-08-12 09:48:00+03	124200.00
49D35B	2017-07-24 07:54:00+03	28800.00
49D3C5	2017-08-10 15:24:00+03	50800.00
49D433	2017-07-13 03:29:00+03	75300.00
49D444	2017-07-10 15:52:00+03	67600.00
49D45A	2017-07-15 12:05:00+03	291500.00
49D480	2017-07-02 15:10:00+03	69000.00
49D4BE	2017-08-12 17:32:00+03	19800.00
49D5E9	2017-07-27 19:38:00+03	79800.00
49D5EA	2017-07-04 03:07:00+03	28800.00
49D5FF	2017-07-26 09:31:00+03	55600.00
49D613	2017-08-07 05:00:00+03	250400.00
49D686	2017-07-14 04:53:00+03	55800.00
49D6D9	2017-07-31 09:13:00+03	38400.00
49D6E6	2017-08-08 10:43:00+03	73500.00
49D6F0	2017-07-08 00:30:00+03	6300.00
49D704	2017-07-08 20:48:00+03	23200.00
49D70A	2017-07-06 03:45:00+03	35200.00
49D75F	2017-07-23 00:48:00+03	28000.00
49D772	2017-07-11 01:43:00+03	63200.00
49D78D	2017-07-26 08:30:00+03	44600.00
49D790	2017-08-08 12:22:00+03	122300.00
49D7A0	2017-08-03 01:45:00+03	47400.00
49D7A4	2017-07-07 02:32:00+03	257600.00
49D7BA	2017-08-10 01:16:00+03	112600.00
49D80C	2017-07-12 08:42:00+03	24400.00
49D81A	2017-07-01 11:30:00+03	25100.00
49D824	2017-08-08 10:54:00+03	40000.00
49D828	2017-08-01 07:57:00+03	42400.00
49D891	2017-07-08 15:16:00+03	59200.00
49D89D	2017-08-01 11:23:00+03	26800.00
49D89F	2017-08-15 11:58:00+03	42000.00
49D8AE	2017-07-08 00:43:00+03	51600.00
49D8CE	2017-07-14 12:48:00+03	100600.00
49D90A	2017-08-11 13:11:00+03	16400.00
49D965	2017-07-17 05:22:00+03	78300.00
49D97C	2017-08-15 16:11:00+03	24000.00
49D98C	2017-07-18 15:57:00+03	57400.00
49D9B7	2017-08-08 11:36:00+03	114400.00
49DA02	2017-07-06 18:33:00+03	46000.00
49DA08	2017-07-05 15:47:00+03	69600.00
49DA21	2017-07-12 23:12:00+03	23600.00
49DA52	2017-07-31 19:09:00+03	155600.00
49DA66	2017-08-15 16:18:00+03	17600.00
49DA7C	2017-07-15 18:27:00+03	34000.00
49DAD7	2017-07-05 13:17:00+03	213200.00
49DAF7	2017-07-09 07:45:00+03	40800.00
49DB09	2017-07-12 17:07:00+03	69000.00
49DB1B	2017-07-21 10:18:00+03	92400.00
49DB68	2017-07-18 00:50:00+03	211000.00
49DBFA	2017-08-03 02:13:00+03	26800.00
49DC3B	2017-07-13 02:02:00+03	119700.00
49DC71	2017-08-14 18:03:00+03	51200.00
49DC8A	2017-07-21 00:10:00+03	79200.00
49DCC8	2017-08-02 02:50:00+03	14400.00
49DD77	2017-07-12 20:34:00+03	286600.00
49DE4A	2017-08-01 12:19:00+03	62100.00
49DE64	2017-08-03 11:31:00+03	92700.00
49DEB9	2017-07-15 11:31:00+03	56000.00
49DF7F	2017-07-22 15:52:00+03	109300.00
49DF8B	2017-07-22 09:05:00+03	160500.00
49DF9F	2017-07-02 08:58:00+03	71000.00
49DFF9	2017-06-30 02:48:00+03	26000.00
49E08E	2017-07-19 20:57:00+03	18000.00
49E0DD	2017-07-07 09:48:00+03	14300.00
49E101	2017-08-02 01:12:00+03	214900.00
49E18B	2017-07-09 14:32:00+03	71400.00
49E19B	2017-08-06 22:38:00+03	93000.00
49E1AE	2017-07-29 02:54:00+03	207200.00
49E1E1	2017-07-02 23:21:00+03	54400.00
49E251	2017-07-09 08:30:00+03	112000.00
49E27B	2017-07-29 06:16:00+03	57500.00
49E286	2017-08-15 17:55:00+03	23200.00
49E32B	2017-07-27 15:30:00+03	15000.00
49E3AB	2017-07-21 09:53:00+03	28000.00
49E3D6	2017-07-18 07:13:00+03	67000.00
49E409	2017-07-16 23:31:00+03	77600.00
49E437	2017-07-06 08:22:00+03	272800.00
49E43E	2017-08-05 18:10:00+03	54800.00
49E43F	2017-08-09 09:04:00+03	139200.00
49E443	2017-08-11 17:43:00+03	210700.00
49E457	2017-07-13 05:50:00+03	55800.00
49E45D	2017-07-26 09:36:00+03	62600.00
49E515	2017-07-22 20:33:00+03	32700.00
49E56C	2017-08-08 01:10:00+03	120700.00
49E58D	2017-07-07 07:59:00+03	70800.00
49E5B9	2017-08-15 01:55:00+03	23100.00
49E5CE	2017-07-19 07:39:00+03	36800.00
49E674	2017-08-06 06:04:00+03	25400.00
49E75C	2017-08-07 10:12:00+03	7400.00
49E76B	2017-07-03 14:55:00+03	187600.00
49E80F	2017-07-11 19:36:00+03	279800.00
49E82E	2017-07-10 04:32:00+03	149300.00
49E83C	2017-07-11 17:47:00+03	56100.00
49E8BC	2017-07-09 01:44:00+03	28000.00
49E900	2017-07-21 00:00:00+03	23200.00
49E95E	2017-07-31 04:54:00+03	35200.00
49E9B1	2017-08-10 18:16:00+03	76800.00
49EA80	2017-07-08 01:32:00+03	267700.00
49EA8F	2017-08-02 21:04:00+03	23600.00
49EAB5	2017-07-20 13:16:00+03	54800.00
49EBD0	2017-07-04 08:39:00+03	73600.00
49EBD8	2017-07-20 08:42:00+03	77600.00
49EC34	2017-08-12 19:59:00+03	291000.00
49EC6F	2017-08-02 21:58:00+03	29400.00
49EC81	2017-07-05 21:33:00+03	28000.00
49ECA9	2017-07-17 09:44:00+03	116800.00
49ECD0	2017-07-18 22:03:00+03	28800.00
49ECF7	2017-07-26 20:06:00+03	92800.00
49ED1D	2017-07-10 12:24:00+03	179300.00
49ED58	2017-08-01 15:54:00+03	67900.00
49ED8E	2017-07-24 22:53:00+03	46400.00
49EDB6	2017-06-29 17:24:00+03	199600.00
49EDC8	2017-08-14 17:38:00+03	27900.00
49EE7A	2017-08-05 00:35:00+03	133200.00
49EEC6	2017-07-30 21:43:00+03	155600.00
49EF00	2017-08-03 10:04:00+03	187800.00
49EF5B	2017-08-05 01:02:00+03	13400.00
49EFE0	2017-08-06 02:45:00+03	51600.00
49EFE3	2017-07-24 23:09:00+03	42800.00
49F06B	2017-07-21 21:48:00+03	202000.00
49F084	2017-07-31 19:24:00+03	16000.00
49F0AE	2017-08-13 11:29:00+03	132800.00
49F146	2017-07-02 18:12:00+03	130400.00
49F159	2017-08-01 14:29:00+03	57300.00
49F198	2017-08-08 11:32:00+03	281500.00
49F1B6	2017-07-08 21:23:00+03	19800.00
49F1BF	2017-07-12 17:23:00+03	40800.00
49F1F1	2017-07-22 05:17:00+03	15800.00
49F215	2017-07-24 02:40:00+03	110500.00
49F224	2017-07-31 00:21:00+03	71200.00
49F235	2017-07-15 14:43:00+03	98200.00
49F2E0	2017-07-22 10:05:00+03	66600.00
49F2F3	2017-08-11 00:30:00+03	76600.00
49F30A	2017-07-21 02:40:00+03	75600.00
49F35B	2017-08-06 00:32:00+03	136800.00
49F394	2017-07-14 02:17:00+03	43200.00
49F3A1	2017-07-23 11:09:00+03	48500.00
49F449	2017-07-05 06:31:00+03	302400.00
49F455	2017-08-14 21:00:00+03	154500.00
49F4A3	2017-07-05 09:09:00+03	36000.00
49F4B1	2017-07-13 21:10:00+03	12000.00
49F4B2	2017-07-16 12:22:00+03	13600.00
49F4DD	2017-07-31 22:41:00+03	79000.00
49F582	2017-07-05 09:04:00+03	14800.00
49F5B0	2017-07-27 10:17:00+03	32400.00
49F5FD	2017-08-07 08:03:00+03	81500.00
49F604	2017-07-10 09:33:00+03	104200.00
49F62B	2017-07-08 09:47:00+03	273000.00
49F657	2017-07-17 18:53:00+03	16400.00
49F687	2017-07-10 20:08:00+03	25600.00
49F68E	2017-07-11 07:23:00+03	58600.00
49F6BD	2017-08-07 20:48:00+03	149000.00
49F6CB	2017-07-05 14:41:00+03	57600.00
49F732	2017-08-04 02:39:00+03	47200.00
49F768	2017-07-25 17:52:00+03	31400.00
49F789	2017-07-15 23:22:00+03	44700.00
49F822	2017-07-02 21:06:00+03	105100.00
49F867	2017-07-29 03:26:00+03	95200.00
49F8A1	2017-07-05 12:57:00+03	134400.00
49F8A3	2017-07-21 13:53:00+03	205700.00
49F936	2017-07-31 05:38:00+03	34100.00
49F947	2017-08-15 05:52:00+03	38500.00
49F9DB	2017-08-15 02:33:00+03	179300.00
49FA3D	2017-07-25 00:05:00+03	79000.00
49FAD4	2017-07-26 03:25:00+03	33400.00
49FAF7	2017-07-02 18:26:00+03	27200.00
49FB01	2017-07-14 12:28:00+03	7600.00
49FB12	2017-08-11 04:33:00+03	387400.00
49FB41	2017-06-30 03:38:00+03	111600.00
49FB85	2017-08-11 23:58:00+03	310600.00
49FB91	2017-07-09 19:31:00+03	100200.00
49FC11	2017-07-22 01:22:00+03	46800.00
49FC29	2017-07-20 19:13:00+03	30900.00
49FC2A	2017-07-01 12:07:00+03	25200.00
49FC38	2017-07-31 23:32:00+03	54600.00
49FC4C	2017-08-12 18:38:00+03	26600.00
49FCD6	2017-08-02 04:51:00+03	37700.00
49FD2D	2017-07-02 02:36:00+03	233800.00
49FDBA	2017-08-08 10:34:00+03	28000.00
49FDD1	2017-07-27 13:43:00+03	20200.00
49FE48	2017-07-23 14:58:00+03	26800.00
49FE7F	2017-07-18 15:19:00+03	74400.00
49FEA9	2017-08-02 21:21:00+03	40000.00
49FEFB	2017-08-09 01:45:00+03	77000.00
49FEFF	2017-08-03 11:55:00+03	144700.00
49FF40	2017-07-05 18:39:00+03	6700.00
49FF47	2017-07-10 13:43:00+03	23400.00
49FF61	2017-07-24 11:33:00+03	54800.00
49FF84	2017-07-02 05:00:00+03	56000.00
49FF9F	2017-07-12 10:21:00+03	42100.00
49FFF5	2017-08-14 07:45:00+03	55400.00
4A0016	2017-07-16 03:19:00+03	6700.00
4A0019	2017-08-08 14:51:00+03	176400.00
4A009B	2017-07-19 03:27:00+03	68400.00
4A00F4	2017-07-22 07:57:00+03	30200.00
4A0113	2017-08-10 08:01:00+03	38600.00
4A0122	2017-07-13 05:41:00+03	94200.00
4A01F8	2017-08-04 14:27:00+03	10700.00
4A01FC	2017-07-12 17:00:00+03	51000.00
4A0200	2017-07-01 13:26:00+03	111600.00
4A0215	2017-07-21 04:36:00+03	33800.00
4A021A	2017-07-05 21:07:00+03	94000.00
4A023E	2017-07-13 11:20:00+03	162600.00
4A0329	2017-07-06 20:21:00+03	55800.00
4A038E	2017-06-30 04:58:00+03	67400.00
4A03D6	2017-08-13 22:25:00+03	44300.00
4A0408	2017-07-18 09:05:00+03	160400.00
4A0416	2017-07-26 04:00:00+03	114900.00
4A0447	2017-07-31 12:54:00+03	119700.00
4A044E	2017-07-14 20:13:00+03	94900.00
4A0489	2017-08-04 07:19:00+03	57700.00
4A04F5	2017-07-28 11:51:00+03	246000.00
4A055E	2017-07-01 22:43:00+03	68200.00
4A05D9	2017-07-16 05:55:00+03	29000.00
4A0635	2017-08-15 12:50:00+03	13400.00
4A077C	2017-07-31 00:52:00+03	119500.00
4A0894	2017-07-02 22:14:00+03	125900.00
4A08AC	2017-08-12 08:21:00+03	36900.00
4A0927	2017-07-14 09:04:00+03	62600.00
4A092F	2017-07-04 16:29:00+03	47100.00
4A097C	2017-08-13 23:33:00+03	135600.00
4A0998	2017-07-06 14:17:00+03	6300.00
4A09EF	2017-07-12 00:52:00+03	14800.00
4A0A5A	2017-08-14 20:02:00+03	155600.00
4A0A77	2017-08-12 14:19:00+03	273000.00
4A0A98	2017-08-14 10:09:00+03	21800.00
4A0B0A	2017-08-06 03:20:00+03	38600.00
4A0BD6	2017-07-25 16:49:00+03	135600.00
4A0BDB	2017-08-08 22:46:00+03	31000.00
4A0BF3	2017-07-30 02:26:00+03	6300.00
4A0BFE	2017-07-15 06:22:00+03	19600.00
4A0C01	2017-08-05 03:25:00+03	136600.00
4A0C72	2017-08-08 09:41:00+03	59600.00
4A0CBA	2017-07-09 13:12:00+03	54800.00
4A0E14	2017-07-19 17:46:00+03	30200.00
4A0E15	2017-07-13 00:27:00+03	25800.00
4A0E27	2017-07-12 12:05:00+03	66600.00
4A0E48	2017-07-21 12:13:00+03	260300.00
4A0E5E	2017-08-07 14:24:00+03	88900.00
4A0E71	2017-08-10 23:00:00+03	48800.00
4A0E7E	2017-07-20 23:57:00+03	250100.00
4A0EAF	2017-07-21 14:38:00+03	66200.00
4A0ED1	2017-07-25 21:13:00+03	174800.00
4A0F07	2017-07-28 14:38:00+03	115900.00
4A0F34	2017-07-25 14:08:00+03	13600.00
4A0F3D	2017-08-02 23:37:00+03	6300.00
4A0F4A	2017-07-07 12:24:00+03	79000.00
4A0F97	2017-07-28 17:51:00+03	32200.00
4A0FAC	2017-07-23 05:28:00+03	58400.00
4A0FEB	2017-07-16 00:12:00+03	16400.00
4A0FFD	2017-08-04 01:50:00+03	168000.00
4A10AE	2017-07-15 03:13:00+03	26500.00
4A10C4	2017-07-11 06:25:00+03	56100.00
4A114D	2017-07-15 09:05:00+03	14400.00
4A11DD	2017-08-14 20:41:00+03	131600.00
4A1220	2017-07-22 19:06:00+03	56000.00
4A127C	2017-07-05 00:38:00+03	56000.00
4A127F	2017-07-25 00:30:00+03	149800.00
4A131D	2017-07-07 01:17:00+03	36000.00
4A137B	2017-07-21 16:53:00+03	89700.00
4A1396	2017-07-26 13:32:00+03	393000.00
4A1398	2017-07-27 12:12:00+03	214100.00
4A13F0	2017-07-05 03:40:00+03	170000.00
4A1436	2017-07-20 08:45:00+03	50800.00
4A1485	2017-07-05 05:03:00+03	62800.00
4A1499	2017-07-25 08:04:00+03	135000.00
4A14AF	2017-07-23 16:02:00+03	53700.00
4A14D0	2017-08-06 07:58:00+03	109600.00
4A1524	2017-07-13 15:26:00+03	13600.00
4A152D	2017-07-26 05:50:00+03	48400.00
4A1570	2017-07-15 11:53:00+03	73300.00
4A15B4	2017-07-18 19:14:00+03	40400.00
4A15BE	2017-07-20 17:35:00+03	36200.00
4A15D8	2017-06-30 01:38:00+03	23600.00
4A15E9	2017-07-28 11:38:00+03	69600.00
4A15F3	2017-07-20 07:38:00+03	111600.00
4A16B3	2017-07-24 19:00:00+03	46200.00
4A16F9	2017-07-29 13:59:00+03	13400.00
4A1701	2017-08-06 09:19:00+03	39200.00
4A1729	2017-07-09 02:28:00+03	94400.00
4A174E	2017-07-26 03:06:00+03	125600.00
4A1771	2017-07-29 00:19:00+03	37500.00
4A1775	2017-08-13 20:32:00+03	46200.00
4A1779	2017-08-09 01:21:00+03	172800.00
4A17B1	2017-07-30 08:22:00+03	103500.00
4A17D6	2017-07-20 05:13:00+03	133100.00
4A1840	2017-07-15 19:29:00+03	86300.00
4A1876	2017-08-14 09:42:00+03	91700.00
4A18F3	2017-08-12 23:49:00+03	123000.00
4A1940	2017-08-15 13:54:00+03	16400.00
4A1954	2017-07-29 01:39:00+03	38600.00
4A196D	2017-07-15 03:01:00+03	181100.00
4A1970	2017-07-12 14:41:00+03	28000.00
4A197C	2017-07-06 19:37:00+03	30300.00
4A19A9	2017-08-11 18:32:00+03	46400.00
4A19AC	2017-08-11 14:39:00+03	12600.00
4A19F6	2017-07-11 04:11:00+03	14800.00
4A19FA	2017-07-30 00:59:00+03	258400.00
4A1A3A	2017-07-30 06:33:00+03	6200.00
4A1A57	2017-07-05 12:31:00+03	26000.00
4A1A64	2017-07-20 09:13:00+03	22000.00
4A1A6F	2017-08-13 13:05:00+03	125700.00
4A1A77	2017-07-09 07:56:00+03	24400.00
4A1A94	2017-08-06 11:57:00+03	63200.00
4A1A9D	2017-07-07 21:22:00+03	83400.00
4A1AC9	2017-08-06 11:58:00+03	29000.00
4A1B31	2017-08-13 07:26:00+03	25600.00
4A1B92	2017-06-30 13:51:00+03	99600.00
4A1BBF	2017-07-27 23:30:00+03	86600.00
4A1BC1	2017-08-10 00:11:00+03	25600.00
4A1BEF	2017-07-30 05:00:00+03	6700.00
4A1C73	2017-08-05 09:52:00+03	60200.00
4A1CAC	2017-07-03 02:26:00+03	6700.00
4A1CAF	2017-07-21 01:46:00+03	51200.00
4A1CD1	2017-07-15 04:34:00+03	39900.00
4A1D38	2017-08-08 10:25:00+03	177600.00
4A1DA6	2017-07-30 13:38:00+03	417000.00
4A1E4D	2017-07-29 11:55:00+03	49400.00
4A1E76	2017-07-03 03:44:00+03	50600.00
4A1E81	2017-08-10 23:23:00+03	88400.00
4A1EC3	2017-08-15 06:17:00+03	73300.00
4A1EE3	2017-08-04 22:15:00+03	26200.00
4A1F34	2017-07-25 00:08:00+03	79400.00
4A1F5C	2017-07-09 03:35:00+03	56600.00
4A1FA8	2017-08-10 15:38:00+03	15900.00
4A1FC4	2017-07-10 20:20:00+03	24200.00
4A1FD7	2017-06-29 11:06:00+03	71900.00
4A1FEF	2017-07-23 08:04:00+03	29400.00
4A1FF5	2017-07-26 21:08:00+03	107300.00
4A202F	2017-08-04 16:44:00+03	78600.00
4A206D	2017-07-16 04:23:00+03	140900.00
4A20AF	2017-08-05 16:29:00+03	55800.00
4A20B1	2017-07-10 04:25:00+03	79000.00
4A20E2	2017-07-17 23:54:00+03	68100.00
4A20F6	2017-08-05 09:28:00+03	36400.00
4A2111	2017-07-24 12:58:00+03	23600.00
4A215D	2017-08-03 03:28:00+03	31400.00
4A218E	2017-07-15 06:33:00+03	6000.00
4A21A9	2017-07-07 09:06:00+03	166000.00
4A21DE	2017-07-05 15:29:00+03	65500.00
4A2231	2017-08-01 13:16:00+03	45200.00
4A223D	2017-07-10 11:40:00+03	7400.00
4A229A	2017-08-06 17:36:00+03	22000.00
4A22A0	2017-07-15 22:00:00+03	49100.00
4A22D4	2017-08-05 08:00:00+03	60400.00
4A2301	2017-08-13 06:28:00+03	85000.00
4A2310	2017-07-04 13:23:00+03	193700.00
4A2363	2017-07-22 20:59:00+03	47000.00
4A2384	2017-08-12 17:40:00+03	65800.00
4A23E1	2017-07-21 16:33:00+03	13400.00
4A244C	2017-08-13 15:47:00+03	28300.00
4A2454	2017-07-12 21:25:00+03	143000.00
4A24B2	2017-07-05 21:59:00+03	74400.00
4A2528	2017-08-09 09:10:00+03	65900.00
4A2548	2017-08-13 03:51:00+03	135100.00
4A25DC	2017-07-25 13:50:00+03	23600.00
4A25E5	2017-08-06 18:21:00+03	116900.00
4A25F6	2017-08-15 00:30:00+03	22000.00
4A2601	2017-07-21 21:12:00+03	178800.00
4A2634	2017-07-15 20:58:00+03	17600.00
4A2697	2017-08-03 13:48:00+03	27300.00
4A26BA	2017-07-14 11:21:00+03	35600.00
4A26BE	2017-07-20 15:25:00+03	16400.00
4A26C9	2017-07-29 17:57:00+03	56600.00
4A26DC	2017-07-22 01:00:00+03	67700.00
4A271E	2017-07-04 23:19:00+03	27200.00
4A275B	2017-07-27 16:34:00+03	26800.00
4A2782	2017-07-30 06:06:00+03	6800.00
4A27AE	2017-07-26 07:03:00+03	51900.00
4A27B1	2017-07-15 04:16:00+03	24200.00
4A27B4	2017-08-02 13:52:00+03	85600.00
4A27F7	2017-07-14 00:12:00+03	46800.00
4A2855	2017-08-05 05:31:00+03	42400.00
4A2890	2017-07-21 02:02:00+03	144000.00
4A28BA	2017-07-03 08:17:00+03	271100.00
4A28BD	2017-07-28 20:57:00+03	32400.00
4A28E4	2017-07-11 01:14:00+03	93000.00
4A28E9	2017-07-22 17:18:00+03	224000.00
4A291C	2017-07-20 23:21:00+03	348800.00
4A296D	2017-08-01 12:39:00+03	68000.00
4A29EB	2017-07-23 00:23:00+03	11600.00
4A2A1D	2017-07-24 17:29:00+03	72400.00
4A2A27	2017-06-27 09:08:00+03	11600.00
4A2A28	2017-07-07 15:57:00+03	135000.00
4A2A42	2017-07-28 17:51:00+03	234300.00
4A2A61	2017-08-12 16:48:00+03	66600.00
4A2A78	2017-08-01 00:39:00+03	24800.00
4A2A7F	2017-07-01 01:30:00+03	283100.00
4A2A8B	2017-07-09 05:44:00+03	43200.00
4A2AAF	2017-07-26 22:02:00+03	84100.00
4A2AF1	2017-08-14 22:57:00+03	117200.00
4A2B1F	2017-08-12 20:09:00+03	24400.00
4A2B33	2017-08-08 11:11:00+03	85000.00
4A2B53	2017-07-22 19:53:00+03	139400.00
4A2BA1	2017-08-12 21:12:00+03	185400.00
4A2BB8	2017-08-03 19:58:00+03	7200.00
4A2BCC	2017-07-22 23:26:00+03	21400.00
4A2C30	2017-07-08 19:40:00+03	38800.00
4A2C4B	2017-08-08 01:49:00+03	40800.00
4A2C54	2017-07-07 11:45:00+03	55800.00
4A2CFA	2017-07-06 21:06:00+03	131600.00
4A2CFE	2017-07-17 00:55:00+03	14400.00
4A2D06	2017-07-03 06:41:00+03	6700.00
4A2D90	2017-07-24 15:16:00+03	96300.00
4A2DAE	2017-07-13 13:57:00+03	92900.00
4A2E5C	2017-08-12 02:46:00+03	35400.00
4A2E6E	2017-07-08 06:20:00+03	229300.00
4A2EDC	2017-07-29 17:40:00+03	148200.00
4A2EF3	2017-07-29 02:24:00+03	291300.00
4A2EFF	2017-07-02 07:22:00+03	131600.00
4A2FB6	2017-07-13 11:17:00+03	39300.00
4A2FC4	2017-07-27 14:33:00+03	78100.00
4A2FD0	2017-07-23 18:05:00+03	52000.00
4A3140	2017-07-21 02:38:00+03	28000.00
4A3143	2017-08-05 17:58:00+03	26800.00
4A3165	2017-08-10 16:38:00+03	46400.00
4A316A	2017-06-30 02:19:00+03	67600.00
4A3186	2017-07-08 05:07:00+03	114800.00
4A31A6	2017-07-11 17:25:00+03	85000.00
4A31B4	2017-07-03 12:05:00+03	47000.00
4A31C5	2017-07-25 04:17:00+03	56000.00
4A31D9	2017-08-12 02:21:00+03	99900.00
4A31E6	2017-07-29 04:19:00+03	28000.00
4A3202	2017-08-02 00:00:00+03	52400.00
4A3274	2017-07-11 13:19:00+03	19600.00
4A328D	2017-08-10 02:44:00+03	31400.00
4A32C3	2017-07-09 12:10:00+03	206400.00
4A32D7	2017-07-12 00:44:00+03	65900.00
4A3394	2017-07-29 04:47:00+03	104900.00
4A3451	2017-07-24 12:59:00+03	46200.00
4A3480	2017-07-15 03:45:00+03	35200.00
4A34A3	2017-07-31 00:45:00+03	24400.00
4A34F3	2017-07-06 07:50:00+03	45200.00
4A34FA	2017-07-18 22:38:00+03	84100.00
4A350B	2017-07-22 22:33:00+03	92100.00
4A3517	2017-07-22 20:15:00+03	155600.00
4A3562	2017-07-07 18:28:00+03	48800.00
4A3593	2017-07-25 00:05:00+03	63800.00
4A35DE	2017-07-11 09:00:00+03	88200.00
4A3612	2017-07-04 16:41:00+03	195900.00
4A3614	2017-08-15 04:08:00+03	24400.00
4A3628	2017-08-09 03:20:00+03	127500.00
4A364A	2017-07-17 10:19:00+03	35800.00
4A3702	2017-08-03 10:54:00+03	220700.00
4A372B	2017-07-24 19:34:00+03	69700.00
4A37B2	2017-07-13 00:33:00+03	73300.00
4A381C	2017-07-18 13:23:00+03	88500.00
4A3885	2017-07-03 02:42:00+03	58800.00
4A38B6	2017-08-13 01:26:00+03	284400.00
4A38CE	2017-08-03 08:28:00+03	157100.00
4A38D8	2017-08-08 10:12:00+03	51800.00
4A38EF	2017-08-14 08:28:00+03	28800.00
4A394E	2017-07-06 15:53:00+03	133100.00
4A396E	2017-07-01 08:32:00+03	58400.00
4A397C	2017-07-27 01:45:00+03	73600.00
4A3989	2017-07-18 08:44:00+03	102100.00
4A3994	2017-08-12 11:08:00+03	26000.00
4A39B7	2017-07-10 10:54:00+03	11600.00
4A39C7	2017-08-11 13:14:00+03	171600.00
4A3A0B	2017-07-10 05:42:00+03	87100.00
4A3A61	2017-08-11 12:36:00+03	14800.00
4A3A84	2017-07-27 23:43:00+03	13400.00
4A3AC7	2017-07-09 03:19:00+03	48700.00
4A3AF0	2017-07-21 04:00:00+03	47200.00
4A3BBB	2017-07-14 18:19:00+03	34000.00
4A3BEC	2017-08-12 22:43:00+03	54800.00
4A3C0E	2017-07-16 22:16:00+03	105800.00
4A3D2F	2017-07-22 05:17:00+03	14000.00
4A3D71	2017-08-10 13:28:00+03	179300.00
4A3DE8	2017-07-01 21:31:00+03	166100.00
4A3E1F	2017-07-31 03:09:00+03	99100.00
4A3E5A	2017-08-12 13:38:00+03	132800.00
4A3E77	2017-08-14 10:01:00+03	46300.00
4A3EDA	2017-08-14 15:20:00+03	29600.00
4A3EF9	2017-08-03 22:45:00+03	54800.00
4A3F1D	2017-07-16 22:27:00+03	22600.00
4A3F2A	2017-07-15 17:09:00+03	58200.00
4A3F30	2017-07-17 10:59:00+03	131100.00
4A3F42	2017-07-08 11:36:00+03	28600.00
4A3F84	2017-07-16 15:35:00+03	57700.00
4A40CD	2017-06-30 08:26:00+03	113200.00
4A40DC	2017-08-03 00:27:00+03	41300.00
4A410A	2017-07-02 05:35:00+03	28000.00
4A4164	2017-07-09 22:37:00+03	84500.00
4A4169	2017-08-05 07:52:00+03	115800.00
4A4182	2017-07-26 11:23:00+03	112000.00
4A41D8	2017-07-31 08:40:00+03	57800.00
4A4211	2017-07-23 20:46:00+03	203000.00
4A4391	2017-07-25 20:11:00+03	36400.00
4A4404	2017-07-09 06:19:00+03	39300.00
4A4417	2017-08-10 16:24:00+03	28800.00
4A4458	2017-07-01 18:14:00+03	37900.00
4A44AA	2017-07-17 09:12:00+03	46400.00
4A44FA	2017-07-22 07:12:00+03	6700.00
4A451A	2017-08-13 12:37:00+03	25200.00
4A452B	2017-07-07 14:23:00+03	55800.00
4A452C	2017-08-10 21:03:00+03	24400.00
4A4567	2017-07-30 17:02:00+03	258900.00
4A458E	2017-07-13 15:41:00+03	6000.00
4A459E	2017-08-11 08:54:00+03	31400.00
4A45B6	2017-08-12 19:18:00+03	56600.00
4A45C5	2017-07-28 05:04:00+03	369000.00
4A45D6	2017-07-19 07:17:00+03	44200.00
4A462F	2017-07-24 17:21:00+03	68800.00
4A468A	2017-08-15 10:46:00+03	26200.00
4A4699	2017-07-01 11:40:00+03	28000.00
4A471C	2017-08-13 18:38:00+03	66900.00
4A477A	2017-07-03 16:24:00+03	174600.00
4A47C5	2017-08-02 00:25:00+03	54400.00
4A4807	2017-07-22 14:42:00+03	17800.00
4A4822	2017-07-26 13:24:00+03	288300.00
4A487F	2017-07-29 21:38:00+03	40000.00
4A48A3	2017-08-10 16:57:00+03	218100.00
4A48C4	2017-08-01 02:06:00+03	48500.00
4A498E	2017-08-02 20:24:00+03	25400.00
4A4993	2017-08-02 13:42:00+03	112000.00
4A4A62	2017-06-29 08:38:00+03	47000.00
4A4A9E	2017-06-30 06:09:00+03	111600.00
4A4B31	2017-08-03 09:26:00+03	13400.00
4A4B36	2017-08-01 20:49:00+03	44000.00
4A4B7C	2017-08-08 10:07:00+03	137600.00
4A4BF3	2017-07-01 09:03:00+03	16400.00
4A4C48	2017-07-26 06:46:00+03	25600.00
4A4C5A	2017-07-22 19:49:00+03	47500.00
4A4C9B	2017-07-18 19:59:00+03	97900.00
4A4CEF	2017-07-25 17:45:00+03	157100.00
4A4D27	2017-08-06 16:19:00+03	56000.00
4A4D40	2017-07-13 20:48:00+03	369000.00
4A4DF8	2017-07-27 06:33:00+03	172100.00
4A4E43	2017-08-04 05:34:00+03	16400.00
4A4E5F	2017-08-13 04:02:00+03	86000.00
4A4E63	2017-08-02 15:28:00+03	33300.00
4A4EC4	2017-08-10 09:14:00+03	94000.00
4A4EE6	2017-07-27 17:25:00+03	398500.00
4A4EEA	2017-07-31 09:39:00+03	46400.00
4A4EFB	2017-08-11 17:57:00+03	99200.00
4A4F06	2017-07-06 11:44:00+03	55800.00
4A4F18	2017-08-02 02:10:00+03	79600.00
4A4F41	2017-08-04 10:17:00+03	12000.00
4A4F5E	2017-08-10 02:24:00+03	81500.00
4A4F67	2017-08-06 19:51:00+03	31600.00
4A4F75	2017-07-29 17:20:00+03	147200.00
4A4FBC	2017-07-05 19:00:00+03	109600.00
4A4FCB	2017-08-11 11:59:00+03	23400.00
4A5054	2017-07-07 00:01:00+03	92400.00
4A506D	2017-07-20 14:52:00+03	44600.00
4A50DE	2017-07-18 11:45:00+03	107400.00
4A50E5	2017-08-08 02:00:00+03	41800.00
4A50F5	2017-07-23 21:01:00+03	266300.00
4A51A5	2017-07-18 11:33:00+03	68800.00
4A51C1	2017-08-12 18:04:00+03	56000.00
4A51DB	2017-07-05 21:11:00+03	147200.00
4A51F7	2017-07-20 01:43:00+03	70200.00
4A5216	2017-08-10 23:41:00+03	46000.00
4A5240	2017-07-10 23:04:00+03	346700.00
4A5255	2017-07-16 14:59:00+03	47100.00
4A5273	2017-07-26 01:34:00+03	92100.00
4A52A6	2017-07-20 13:17:00+03	14000.00
4A52A7	2017-08-13 07:20:00+03	28800.00
4A52CD	2017-07-07 14:14:00+03	51300.00
4A533A	2017-07-13 23:03:00+03	64700.00
4A5420	2017-07-23 22:38:00+03	26000.00
4A5426	2017-07-04 13:23:00+03	265200.00
4A5490	2017-07-02 02:22:00+03	60400.00
4A550D	2017-07-01 22:01:00+03	42800.00
4A5533	2017-07-14 10:11:00+03	23200.00
4A5596	2017-07-13 08:47:00+03	99200.00
4A55A5	2017-07-07 17:13:00+03	56000.00
4A561F	2017-08-07 19:29:00+03	66700.00
4A5624	2017-08-02 08:25:00+03	66600.00
4A5650	2017-08-08 01:50:00+03	85000.00
4A56B6	2017-08-09 10:04:00+03	302600.00
4A56EB	2017-07-20 20:51:00+03	50600.00
4A56ED	2017-07-29 17:50:00+03	8200.00
4A56F9	2017-07-04 02:50:00+03	85200.00
4A5757	2017-07-08 10:43:00+03	101500.00
4A579A	2017-08-06 08:55:00+03	54300.00
4A57A6	2017-07-13 10:04:00+03	67100.00
4A57BD	2017-08-15 15:09:00+03	13400.00
4A57DC	2017-07-24 13:51:00+03	29600.00
4A57F3	2017-07-18 23:35:00+03	24700.00
4A5806	2017-07-06 10:56:00+03	55800.00
4A5862	2017-08-09 09:52:00+03	117800.00
4A589B	2017-08-10 12:20:00+03	23200.00
4A58D3	2017-07-09 21:20:00+03	70500.00
4A59BA	2017-07-24 03:24:00+03	135600.00
4A59ED	2017-07-20 14:28:00+03	115900.00
4A5A0A	2017-07-03 08:11:00+03	56600.00
4A5A73	2017-07-08 07:51:00+03	103800.00
4A5AB3	2017-07-31 16:29:00+03	271400.00
4A5AC8	2017-08-03 06:08:00+03	235200.00
4A5AD4	2017-07-04 15:01:00+03	13000.00
4A5B15	2017-08-04 17:19:00+03	51600.00
4A5B2B	2017-07-27 23:03:00+03	92400.00
4A5B2F	2017-07-05 20:09:00+03	68800.00
4A5B42	2017-08-01 00:01:00+03	21400.00
4A5BD3	2017-08-13 14:18:00+03	302600.00
4A5BFB	2017-07-13 13:25:00+03	72400.00
4A5C28	2017-07-03 14:29:00+03	39600.00
4A5C61	2017-08-02 11:00:00+03	123000.00
4A5D58	2017-07-09 03:32:00+03	56000.00
4A5D96	2017-06-29 16:14:00+03	48100.00
4A5DD7	2017-07-11 11:57:00+03	273600.00
4A5DE0	2017-07-08 02:28:00+03	170700.00
4A5DE6	2017-07-27 20:50:00+03	42800.00
4A5E3A	2017-08-02 14:51:00+03	46300.00
4A5E4B	2017-07-28 12:28:00+03	170200.00
4A5E69	2017-08-09 21:25:00+03	112100.00
4A5E7F	2017-07-27 20:25:00+03	72400.00
4A5E83	2017-07-30 03:50:00+03	131600.00
4A5E9B	2017-07-22 13:42:00+03	182500.00
4A5EA9	2017-07-13 10:14:00+03	57300.00
4A5EBF	2017-08-11 01:56:00+03	124400.00
4A5EEC	2017-08-08 07:57:00+03	38000.00
4A5F72	2017-07-19 15:18:00+03	61800.00
4A5F95	2017-08-02 23:05:00+03	89700.00
4A5FB8	2017-07-27 13:10:00+03	38800.00
4A5FD3	2017-08-07 18:45:00+03	26700.00
4A6042	2017-08-13 20:23:00+03	92700.00
4A608C	2017-07-05 22:07:00+03	47400.00
4A60A2	2017-07-20 03:40:00+03	49100.00
4A60B7	2017-08-07 05:03:00+03	59200.00
4A60F5	2017-08-15 09:17:00+03	34000.00
4A6193	2017-07-05 19:46:00+03	22000.00
4A61A8	2017-07-15 20:54:00+03	75300.00
4A61B2	2017-07-18 22:41:00+03	69900.00
4A6224	2017-08-12 18:34:00+03	28600.00
4A62B3	2017-08-13 23:35:00+03	27800.00
4A62EA	2017-08-13 23:56:00+03	17600.00
4A6372	2017-08-11 06:59:00+03	56000.00
4A63BE	2017-07-23 12:54:00+03	55800.00
4A63FB	2017-07-15 20:43:00+03	67200.00
4A6412	2017-07-09 14:02:00+03	6800.00
4A6498	2017-07-04 06:35:00+03	28800.00
4A64F9	2017-08-10 16:43:00+03	223200.00
4A6505	2017-08-10 21:12:00+03	155500.00
4A6518	2017-08-07 19:36:00+03	23200.00
4A6527	2017-08-03 06:20:00+03	106900.00
4A655B	2017-08-15 14:27:00+03	73400.00
4A656E	2017-07-04 16:25:00+03	88500.00
4A6644	2017-08-11 04:23:00+03	37900.00
4A66C7	2017-07-30 23:03:00+03	515000.00
4A66E3	2017-07-28 00:33:00+03	6600.00
4A673B	2017-07-13 15:34:00+03	6700.00
4A6778	2017-07-13 16:16:00+03	89000.00
4A6799	2017-07-31 21:54:00+03	27200.00
4A67D6	2017-07-18 01:19:00+03	136500.00
4A68E2	2017-07-08 13:04:00+03	68800.00
4A6910	2017-08-04 19:09:00+03	69500.00
4A695B	2017-07-23 19:38:00+03	54500.00
4A6A14	2017-08-15 11:55:00+03	26000.00
4A6A15	2017-07-30 18:44:00+03	86500.00
4A6A7B	2017-07-18 15:51:00+03	49800.00
4A6A96	2017-07-28 09:23:00+03	54600.00
4A6AB6	2017-07-05 04:31:00+03	128400.00
4A6B38	2017-08-04 18:50:00+03	24200.00
4A6B43	2017-07-05 22:17:00+03	32200.00
4A6B69	2017-07-12 11:58:00+03	11700.00
4A6B77	2017-07-11 20:41:00+03	135600.00
4A6B8C	2017-07-31 21:21:00+03	16400.00
4A6BB5	2017-08-12 22:56:00+03	73600.00
4A6C11	2017-07-04 06:59:00+03	189800.00
4A6C3E	2017-07-09 04:42:00+03	111600.00
4A6C5B	2017-08-06 00:23:00+03	21800.00
4A6C71	2017-08-07 18:00:00+03	58600.00
4A6C85	2017-07-28 20:59:00+03	39300.00
4A6CAA	2017-07-15 01:52:00+03	30900.00
4A6CC0	2017-08-09 03:57:00+03	146300.00
4A6D06	2017-07-04 13:23:00+03	124800.00
4A6D32	2017-08-05 21:04:00+03	179400.00
4A6D5D	2017-08-14 06:11:00+03	12100.00
4A6D6A	2017-07-04 01:50:00+03	66600.00
4A6D85	2017-07-19 07:10:00+03	44000.00
4A6DC9	2017-08-09 12:15:00+03	44500.00
4A6E28	2017-07-30 14:52:00+03	188000.00
4A6EA5	2017-07-24 00:03:00+03	73300.00
4A6ED0	2017-08-07 08:20:00+03	139200.00
4A6EE8	2017-07-23 05:47:00+03	55800.00
4A6F01	2017-07-13 21:27:00+03	51800.00
4A6F05	2017-08-13 03:18:00+03	24400.00
4A6F63	2017-07-06 13:38:00+03	44600.00
4A7035	2017-08-06 11:28:00+03	46300.00
4A7047	2017-08-07 11:11:00+03	92000.00
4A704F	2017-07-10 00:01:00+03	81900.00
4A706B	2017-08-07 21:49:00+03	135200.00
4A7080	2017-08-13 19:09:00+03	28800.00
4A7125	2017-08-14 12:02:00+03	30200.00
4A7156	2017-07-24 17:42:00+03	13700.00
4A7176	2017-07-03 07:59:00+03	100600.00
4A71F5	2017-07-23 22:57:00+03	230400.00
4A726F	2017-08-14 07:37:00+03	111400.00
4A72B5	2017-07-25 15:53:00+03	24400.00
4A736E	2017-07-28 07:26:00+03	56000.00
4A739E	2017-06-30 08:08:00+03	89800.00
4A73E9	2017-07-13 02:32:00+03	24400.00
4A7413	2017-08-11 06:20:00+03	53500.00
4A7428	2017-07-21 13:55:00+03	32700.00
4A745F	2017-07-03 01:10:00+03	85600.00
4A749C	2017-08-02 15:02:00+03	45500.00
4A74BA	2017-07-13 17:46:00+03	58400.00
4A75EA	2017-07-05 13:08:00+03	70700.00
4A75FC	2017-08-13 23:12:00+03	147000.00
4A7602	2017-07-12 03:06:00+03	24800.00
4A7667	2017-07-31 12:09:00+03	27900.00
4A7681	2017-07-25 01:49:00+03	57800.00
4A769D	2017-07-15 17:36:00+03	98300.00
4A773F	2017-07-31 02:10:00+03	32800.00
4A7754	2017-07-20 02:14:00+03	129200.00
4A775E	2017-07-22 13:33:00+03	78500.00
4A77B6	2017-07-24 02:18:00+03	24200.00
4A77BE	2017-08-13 02:58:00+03	8400.00
4A77CB	2017-07-25 05:28:00+03	90100.00
4A77E9	2017-08-05 02:56:00+03	38800.00
4A7812	2017-08-01 17:59:00+03	72200.00
4A784E	2017-08-10 07:49:00+03	45100.00
4A7851	2017-08-03 17:28:00+03	266400.00
4A7859	2017-07-18 08:30:00+03	32700.00
4A7863	2017-07-17 13:59:00+03	27200.00
4A790F	2017-07-03 16:17:00+03	65900.00
4A791D	2017-07-12 06:07:00+03	46000.00
4A7957	2017-07-03 18:27:00+03	133100.00
4A7989	2017-07-10 05:53:00+03	52000.00
4A798F	2017-08-13 06:09:00+03	117800.00
4A79A9	2017-07-26 17:02:00+03	99200.00
4A79E4	2017-07-03 21:27:00+03	57700.00
4A79E7	2017-08-12 17:54:00+03	46000.00
4A7A17	2017-07-02 15:17:00+03	26500.00
4A7A4D	2017-07-31 03:53:00+03	25400.00
4A7A54	2017-07-09 03:11:00+03	147200.00
4A7A7E	2017-08-08 14:07:00+03	12000.00
4A7ABF	2017-07-28 18:01:00+03	123000.00
4A7B27	2017-07-24 23:48:00+03	56000.00
4A7B3E	2017-07-19 11:50:00+03	233700.00
4A7B60	2017-08-14 02:30:00+03	23600.00
4A7B99	2017-08-03 05:55:00+03	56900.00
4A7BE0	2017-07-09 23:50:00+03	93100.00
4A7C6D	2017-07-11 09:55:00+03	52100.00
4A7CE9	2017-08-11 10:54:00+03	21700.00
4A7D5E	2017-07-27 00:23:00+03	68100.00
4A7E36	2017-07-14 17:04:00+03	16400.00
4A7E3F	2017-08-08 11:28:00+03	46000.00
4A7F49	2017-07-23 17:18:00+03	43600.00
4A7F6A	2017-08-10 12:21:00+03	86400.00
4A7F8A	2017-07-31 08:18:00+03	54500.00
4A7FA9	2017-07-30 20:50:00+03	57600.00
4A7FF4	2017-07-29 23:06:00+03	7200.00
4A8047	2017-08-01 01:28:00+03	56900.00
4A809E	2017-07-21 01:39:00+03	8200.00
4A80CC	2017-07-17 14:03:00+03	169600.00
4A80D1	2017-07-05 14:30:00+03	64600.00
4A8175	2017-07-04 20:36:00+03	88300.00
4A8178	2017-08-01 17:42:00+03	133800.00
4A81BF	2017-07-20 03:26:00+03	80400.00
4A820D	2017-08-15 04:14:00+03	70700.00
4A8215	2017-08-10 08:33:00+03	160000.00
4A821E	2017-07-10 11:28:00+03	21400.00
4A8239	2017-07-16 11:54:00+03	19600.00
4A823D	2017-08-06 08:15:00+03	32800.00
4A8242	2017-07-15 15:24:00+03	56200.00
4A82AE	2017-07-24 04:35:00+03	315300.00
4A8352	2017-07-18 18:30:00+03	75000.00
4A8365	2017-08-11 06:43:00+03	67600.00
4A8428	2017-08-14 07:59:00+03	112700.00
4A84EE	2017-08-09 22:39:00+03	23100.00
4A84EF	2017-07-12 04:03:00+03	99300.00
4A8520	2017-08-13 06:31:00+03	52000.00
4A8543	2017-07-16 22:21:00+03	115600.00
4A8611	2017-08-12 13:54:00+03	57700.00
4A8616	2017-06-28 21:28:00+03	67600.00
4A8648	2017-08-09 09:26:00+03	67600.00
4A8677	2017-07-22 21:31:00+03	23200.00
4A869F	2017-08-04 12:17:00+03	24300.00
4A86E8	2017-07-28 11:04:00+03	492000.00
4A86FB	2017-07-30 16:25:00+03	39200.00
4A8710	2017-08-11 05:20:00+03	12600.00
4A87D5	2017-07-05 11:24:00+03	89200.00
4A8839	2017-07-15 12:32:00+03	65600.00
4A88A7	2017-08-04 12:23:00+03	67800.00
4A88CB	2017-07-19 01:24:00+03	143100.00
4A8916	2017-07-25 20:42:00+03	88600.00
4A891C	2017-07-20 00:50:00+03	14800.00
4A8946	2017-07-22 22:46:00+03	75600.00
4A8959	2017-08-04 12:34:00+03	168000.00
4A8976	2017-07-03 23:26:00+03	54500.00
4A8981	2017-07-29 13:46:00+03	65100.00
4A89ED	2017-07-25 07:11:00+03	21800.00
4A8ABC	2017-08-04 08:30:00+03	50300.00
4A8B1C	2017-08-08 17:41:00+03	56100.00
4A8B9C	2017-07-13 08:40:00+03	69500.00
4A8C95	2017-07-08 16:21:00+03	24400.00
4A8C96	2017-07-18 08:43:00+03	47600.00
4A8CB4	2017-08-12 12:17:00+03	56600.00
4A8CCD	2017-08-03 08:03:00+03	40600.00
4A8DC6	2017-08-09 04:27:00+03	21600.00
4A8EE8	2017-08-14 19:36:00+03	23200.00
4A8EF1	2017-07-14 19:44:00+03	62000.00
4A8F02	2017-07-31 18:08:00+03	16400.00
4A8F13	2017-07-25 04:12:00+03	57400.00
4A8F1E	2017-07-24 21:53:00+03	95200.00
4A8F52	2017-07-27 09:41:00+03	113600.00
4A8FCE	2017-07-22 03:25:00+03	239000.00
4A9063	2017-07-14 19:03:00+03	72400.00
4A90A4	2017-07-27 06:28:00+03	20200.00
4A90AE	2017-08-14 19:34:00+03	24000.00
4A90FD	2017-07-06 07:00:00+03	16400.00
4A9125	2017-08-11 20:39:00+03	66600.00
4A9146	2017-08-02 06:54:00+03	299200.00
4A9149	2017-08-11 20:21:00+03	136500.00
4A9157	2017-08-03 17:00:00+03	167200.00
4A915D	2017-07-07 14:15:00+03	42700.00
4A915E	2017-08-10 23:20:00+03	65900.00
4A9178	2017-07-02 08:52:00+03	64700.00
4A919A	2017-08-05 05:58:00+03	75500.00
4A91DB	2017-07-16 04:39:00+03	65900.00
4A920B	2017-07-18 05:49:00+03	66600.00
4A9213	2017-07-26 18:43:00+03	14000.00
4A9276	2017-06-29 08:41:00+03	111600.00
4A927D	2017-08-13 03:18:00+03	38600.00
4A92A2	2017-07-16 12:59:00+03	81200.00
4A92CB	2017-08-10 14:41:00+03	26000.00
4A92F2	2017-08-09 10:25:00+03	22000.00
4A9300	2017-07-18 13:45:00+03	189200.00
4A932F	2017-07-16 12:01:00+03	26600.00
4A9363	2017-07-23 17:18:00+03	52300.00
4A9365	2017-08-08 12:29:00+03	174900.00
4A93BC	2017-07-08 19:07:00+03	6700.00
4A94A7	2017-07-19 10:07:00+03	47400.00
4A94B7	2017-08-10 11:47:00+03	21200.00
4A95A7	2017-07-08 04:46:00+03	43400.00
4A95B8	2017-07-10 20:37:00+03	51800.00
4A95DA	2017-08-14 21:19:00+03	12000.00
4A9602	2017-07-23 11:19:00+03	57300.00
4A965D	2017-07-28 22:25:00+03	73500.00
4A9680	2017-07-12 05:20:00+03	56000.00
4A96C6	2017-08-13 15:27:00+03	28800.00
4A9710	2017-08-05 06:34:00+03	12600.00
4A9728	2017-08-14 11:27:00+03	59100.00
4A97D6	2017-07-10 22:31:00+03	25200.00
4A97EC	2017-08-03 19:58:00+03	252200.00
4A987F	2017-07-15 22:47:00+03	144400.00
4A994E	2017-08-06 01:34:00+03	103500.00
4A99E3	2017-08-05 21:14:00+03	85000.00
4A99E8	2017-07-08 10:28:00+03	25800.00
4A9A3D	2017-08-10 13:40:00+03	58900.00
4A9A4B	2017-08-07 03:16:00+03	6300.00
4A9A90	2017-07-12 16:19:00+03	13000.00
4A9AEB	2017-08-11 13:23:00+03	28300.00
4A9B03	2017-08-12 04:11:00+03	26000.00
4A9B16	2017-07-23 01:54:00+03	47400.00
4A9B70	2017-07-30 21:59:00+03	169900.00
4A9B8A	2017-08-05 10:14:00+03	48800.00
4A9B9A	2017-07-21 04:05:00+03	64700.00
4A9BFF	2017-08-11 14:19:00+03	387400.00
4A9C62	2017-08-04 09:03:00+03	53300.00
4A9CA5	2017-07-14 15:38:00+03	90800.00
4A9CDD	2017-07-18 18:12:00+03	55800.00
4A9CEA	2017-08-11 21:17:00+03	10800.00
4A9D01	2017-07-04 17:54:00+03	111600.00
4A9D78	2017-07-03 12:13:00+03	119700.00
4A9DB7	2017-08-15 05:26:00+03	56000.00
4A9DBF	2017-07-27 04:31:00+03	20100.00
4A9DDE	2017-07-30 14:13:00+03	41300.00
4A9E01	2017-08-02 22:28:00+03	382800.00
4A9E1C	2017-07-24 14:52:00+03	48800.00
4A9E9D	2017-07-30 08:45:00+03	22400.00
4A9F20	2017-07-26 12:59:00+03	37700.00
4AA0D0	2017-07-20 16:56:00+03	121400.00
4AA160	2017-07-23 11:23:00+03	266400.00
4AA207	2017-07-06 09:28:00+03	23400.00
4AA251	2017-07-23 12:33:00+03	47400.00
4AA272	2017-07-18 17:28:00+03	112000.00
4AA302	2017-07-22 03:00:00+03	33600.00
4AA338	2017-07-03 14:28:00+03	6700.00
4AA362	2017-07-13 03:21:00+03	54800.00
4AA37A	2017-07-09 02:39:00+03	7400.00
4AA389	2017-07-03 00:17:00+03	32200.00
4AA392	2017-07-23 06:44:00+03	92800.00
4AA3C5	2017-08-10 22:13:00+03	75700.00
4AA40C	2017-08-03 06:13:00+03	48800.00
4AA433	2017-07-14 12:25:00+03	46400.00
4AA4B1	2017-07-01 22:20:00+03	136800.00
4AA54A	2017-07-13 11:10:00+03	13000.00
4AA554	2017-07-14 14:50:00+03	10800.00
4AA596	2017-07-07 23:47:00+03	17800.00
4AA5A9	2017-07-13 08:52:00+03	16000.00
4AA5BA	2017-08-07 08:03:00+03	68800.00
4AA606	2017-07-14 06:12:00+03	168000.00
4AA638	2017-08-07 01:34:00+03	59000.00
4AA674	2017-08-02 02:02:00+03	14800.00
4AA68A	2017-07-03 08:21:00+03	134600.00
4AA6D4	2017-07-08 03:38:00+03	160900.00
4AA6F4	2017-07-24 07:17:00+03	45400.00
4AA78B	2017-07-02 08:28:00+03	319700.00
4AA85C	2017-08-06 21:55:00+03	28800.00
4AA871	2017-08-13 05:55:00+03	57700.00
4AA88C	2017-08-10 23:59:00+03	29400.00
4AA8A4	2017-07-11 00:54:00+03	56600.00
4AA948	2017-08-11 18:45:00+03	77900.00
4AAA18	2017-07-13 05:01:00+03	130300.00
4AAA88	2017-07-19 21:56:00+03	161800.00
4AAAEE	2017-07-27 08:56:00+03	116000.00
4AAB07	2017-08-06 03:43:00+03	62600.00
4AAB26	2017-07-30 13:29:00+03	119600.00
4AAB61	2017-07-15 06:19:00+03	66000.00
4AAB6C	2017-07-30 01:04:00+03	88500.00
4AABF4	2017-07-14 12:03:00+03	47100.00
4AAC43	2017-08-06 19:40:00+03	223200.00
4AAC59	2017-07-12 23:39:00+03	24000.00
4AAC8A	2017-07-26 23:35:00+03	89600.00
4AAC96	2017-07-13 18:28:00+03	116800.00
4AACBA	2017-08-02 16:32:00+03	119700.00
4AACCB	2017-07-18 11:21:00+03	33200.00
4AACF3	2017-07-04 14:25:00+03	29400.00
4AAD07	2017-07-09 01:32:00+03	89700.00
4AAD23	2017-07-02 05:03:00+03	14800.00
4AAD29	2017-07-08 23:20:00+03	99200.00
4AAD2A	2017-07-06 23:01:00+03	114800.00
4AAD82	2017-08-15 01:54:00+03	48200.00
4AAD83	2017-07-29 04:01:00+03	66600.00
4AAD99	2017-08-14 14:59:00+03	136200.00
4AADD6	2017-07-14 18:30:00+03	53300.00
4AADF4	2017-07-17 10:50:00+03	242600.00
4AAE00	2017-07-01 00:35:00+03	103200.00
4AAE16	2017-07-14 11:37:00+03	12600.00
4AAEB5	2017-08-13 18:01:00+03	131100.00
4AAF0B	2017-07-29 00:30:00+03	98400.00
4AAF34	2017-08-14 12:54:00+03	217200.00
4AAF8C	2017-08-03 23:01:00+03	46000.00
4AAFBD	2017-07-22 19:30:00+03	124200.00
4AB00C	2017-07-25 00:38:00+03	86600.00
4AB017	2017-07-23 03:48:00+03	61800.00
4AB02E	2017-08-04 23:39:00+03	40200.00
4AB05F	2017-08-14 20:17:00+03	58600.00
4AB09B	2017-08-09 15:44:00+03	271100.00
4AB0BE	2017-07-16 11:26:00+03	6000.00
4AB0C2	2017-08-07 04:20:00+03	39600.00
4AB0D4	2017-07-20 17:49:00+03	294200.00
4AB153	2017-07-08 03:11:00+03	254900.00
4AB188	2017-07-07 02:17:00+03	193300.00
4AB1E6	2017-07-30 04:12:00+03	112600.00
4AB245	2017-08-14 06:44:00+03	62700.00
4AB2E1	2017-07-28 17:14:00+03	75300.00
4AB310	2017-07-31 15:05:00+03	65600.00
4AB367	2017-07-19 00:13:00+03	28800.00
4AB369	2017-07-13 02:05:00+03	14400.00
4AB3B8	2017-08-11 01:27:00+03	43000.00
4AB3D1	2017-07-22 05:01:00+03	46200.00
4AB3E2	2017-07-08 22:50:00+03	14400.00
4AB420	2017-08-07 13:46:00+03	8400.00
4AB4B8	2017-08-09 14:17:00+03	98300.00
4AB4C2	2017-07-07 11:00:00+03	28000.00
4AB502	2017-06-29 00:10:00+03	157000.00
4AB511	2017-08-04 08:05:00+03	61200.00
4AB5B4	2017-08-13 16:08:00+03	83700.00
4AB65A	2017-08-12 06:28:00+03	167400.00
4AB67B	2017-07-21 14:18:00+03	131600.00
4AB686	2017-08-02 18:44:00+03	283100.00
4AB691	2017-08-12 18:24:00+03	65900.00
4AB693	2017-08-02 16:58:00+03	83000.00
4AB6AA	2017-08-07 19:17:00+03	57500.00
4AB6BB	2017-08-11 12:52:00+03	138300.00
4AB73C	2017-07-17 13:24:00+03	22000.00
4AB787	2017-07-09 00:40:00+03	60700.00
4AB794	2017-08-13 04:40:00+03	40300.00
4AB7B3	2017-08-12 08:05:00+03	39300.00
4AB7C7	2017-08-04 08:10:00+03	40800.00
4AB832	2017-06-29 00:59:00+03	30000.00
4AB837	2017-07-01 15:19:00+03	117200.00
4AB966	2017-07-02 01:39:00+03	276200.00
4AB9C4	2017-08-15 01:33:00+03	13200.00
4AB9F4	2017-07-24 13:53:00+03	94900.00
4ABA21	2017-07-24 14:26:00+03	85000.00
4ABA72	2017-07-21 10:39:00+03	29500.00
4ABB62	2017-06-28 12:13:00+03	134400.00
4ABB81	2017-06-30 07:32:00+03	66600.00
4ABBA8	2017-07-22 19:54:00+03	58400.00
4ABBEE	2017-07-18 18:27:00+03	23400.00
4ABC3F	2017-06-29 02:20:00+03	135400.00
4ABC63	2017-07-31 07:58:00+03	405200.00
4ABC6D	2017-07-01 20:19:00+03	131600.00
4ABCAD	2017-07-29 05:15:00+03	101800.00
4ABCB4	2017-07-04 20:13:00+03	67400.00
4ABCE0	2017-07-31 07:23:00+03	38600.00
4ABD98	2017-07-05 22:31:00+03	15400.00
4ABDB2	2017-07-25 19:32:00+03	101200.00
4ABDC6	2017-08-03 00:56:00+03	125300.00
4ABDD7	2017-08-04 15:10:00+03	56000.00
4ABE6C	2017-07-18 09:27:00+03	81600.00
4ABE72	2017-07-03 20:11:00+03	257500.00
4ABE8B	2017-07-28 20:02:00+03	42800.00
4ABF77	2017-08-03 07:30:00+03	54800.00
4ABFD8	2017-08-12 00:38:00+03	284400.00
4ABFE0	2017-07-04 23:47:00+03	6700.00
4ABFFF	2017-08-13 23:11:00+03	20600.00
4AC01D	2017-08-05 21:16:00+03	24400.00
4AC05D	2017-07-19 14:39:00+03	13700.00
4AC17B	2017-07-09 02:21:00+03	7800.00
4AC1B4	2017-07-18 03:41:00+03	59400.00
4AC1BC	2017-07-11 09:47:00+03	90700.00
4AC229	2017-07-20 17:20:00+03	177200.00
4AC24B	2017-08-02 11:36:00+03	38400.00
4AC26A	2017-08-14 07:00:00+03	61800.00
4AC26E	2017-08-14 10:25:00+03	34800.00
4AC299	2017-07-31 10:31:00+03	114600.00
4AC30A	2017-07-10 21:56:00+03	56000.00
4AC316	2017-07-31 02:35:00+03	58400.00
4AC3AD	2017-08-15 08:03:00+03	147700.00
4AC3CE	2017-08-07 19:15:00+03	80000.00
4AC3E8	2017-07-06 14:57:00+03	73200.00
4AC46E	2017-08-03 10:01:00+03	91500.00
4AC49D	2017-08-04 21:43:00+03	46400.00
4AC4D7	2017-07-30 08:01:00+03	135400.00
4AC4E6	2017-07-15 06:51:00+03	241300.00
4AC572	2017-06-30 03:39:00+03	246000.00
4AC58A	2017-07-18 04:23:00+03	6000.00
4AC61D	2017-08-15 15:55:00+03	55100.00
4AC67F	2017-07-29 09:13:00+03	138000.00
4AC6CA	2017-08-10 10:22:00+03	65400.00
4AC71D	2017-07-08 17:41:00+03	48800.00
4AC78A	2017-06-30 02:15:00+03	56100.00
4AC797	2017-07-08 01:29:00+03	112400.00
4AC79C	2017-07-10 15:05:00+03	136800.00
4AC7A5	2017-07-05 13:38:00+03	6700.00
4AC7B1	2017-08-03 16:44:00+03	56600.00
4AC7BD	2017-07-31 13:24:00+03	58200.00
4AC810	2017-07-16 00:50:00+03	58600.00
4AC82A	2017-08-12 02:10:00+03	112000.00
4AC82D	2017-07-25 13:51:00+03	20400.00
4AC86E	2017-07-29 04:16:00+03	32700.00
4AC8BC	2017-07-20 16:23:00+03	29400.00
4AC8C7	2017-07-27 18:22:00+03	96800.00
4AC8DB	2017-07-27 19:12:00+03	62600.00
4AC937	2017-06-27 21:17:00+03	51600.00
4AC967	2017-08-04 21:07:00+03	90400.00
4AC979	2017-07-19 05:38:00+03	46400.00
4AC986	2017-08-03 02:53:00+03	79900.00
4AC993	2017-07-16 19:31:00+03	24400.00
4ACA80	2017-07-23 17:59:00+03	56000.00
4ACAB8	2017-07-12 04:55:00+03	26600.00
4ACB1B	2017-07-22 19:33:00+03	8400.00
4ACB2C	2017-08-13 14:17:00+03	116000.00
4ACB3F	2017-08-13 20:53:00+03	155600.00
4ACB95	2017-07-01 05:28:00+03	28600.00
4ACBE9	2017-07-22 01:40:00+03	26800.00
4ACCC4	2017-08-07 14:54:00+03	179500.00
4ACCCC	2017-08-02 20:01:00+03	231800.00
4ACCDE	2017-08-11 19:54:00+03	138900.00
4ACD3F	2017-08-11 21:46:00+03	137600.00
4ACD5E	2017-08-03 11:56:00+03	53300.00
4ACD6B	2017-07-17 07:07:00+03	53700.00
4ACD86	2017-07-01 20:30:00+03	13700.00
4ACDBE	2017-07-05 03:18:00+03	111600.00
4ACE0A	2017-07-23 07:11:00+03	29400.00
4ACE40	2017-08-01 10:05:00+03	35600.00
4ACE8C	2017-07-24 02:13:00+03	173200.00
4ACEC7	2017-08-06 11:14:00+03	34000.00
4ACEFF	2017-08-05 04:29:00+03	53700.00
4ACF40	2017-08-02 16:07:00+03	66600.00
4AD030	2017-07-06 13:51:00+03	136500.00
4AD051	2017-08-12 18:03:00+03	136200.00
4AD05B	2017-07-09 05:20:00+03	52600.00
4AD07F	2017-07-31 05:36:00+03	77900.00
4AD08D	2017-08-06 23:32:00+03	62600.00
4AD125	2017-08-12 19:37:00+03	54800.00
4AD1AA	2017-07-04 16:21:00+03	12000.00
4AD1C4	2017-08-07 21:27:00+03	124300.00
4AD1DB	2017-07-23 17:13:00+03	198400.00
4AD260	2017-08-12 07:32:00+03	23600.00
4AD28B	2017-07-21 03:44:00+03	25800.00
4AD2C5	2017-08-08 23:13:00+03	25800.00
4AD34E	2017-07-06 11:53:00+03	167400.00
4AD36D	2017-08-08 19:33:00+03	113800.00
4AD375	2017-08-09 19:01:00+03	136200.00
4AD385	2017-08-05 09:27:00+03	42700.00
4AD3E4	2017-07-08 11:02:00+03	22000.00
4AD43D	2017-08-03 15:09:00+03	42600.00
4AD464	2017-07-26 14:38:00+03	54500.00
4AD4B0	2017-07-17 15:55:00+03	102100.00
4AD4CF	2017-08-14 11:16:00+03	270000.00
4AD4EA	2017-07-29 15:58:00+03	80400.00
4AD57B	2017-07-05 18:19:00+03	234600.00
4AD5CA	2017-07-22 18:27:00+03	64800.00
4AD5CE	2017-07-22 09:40:00+03	117700.00
4AD628	2017-08-15 14:46:00+03	115900.00
4AD62E	2017-07-12 18:46:00+03	77600.00
4AD636	2017-07-09 04:00:00+03	20600.00
4AD659	2017-07-26 16:32:00+03	48400.00
4AD6E2	2017-07-23 05:01:00+03	131100.00
4AD74A	2017-07-31 04:12:00+03	28800.00
4AD76B	2017-07-08 22:15:00+03	36800.00
4AD787	2017-08-06 13:31:00+03	48500.00
4AD80E	2017-08-06 20:41:00+03	15800.00
4AD817	2017-07-16 00:40:00+03	386300.00
4AD81B	2017-07-22 23:44:00+03	18500.00
4AD838	2017-08-12 13:41:00+03	170700.00
4AD8D3	2017-07-15 11:23:00+03	231200.00
4AD99C	2017-07-17 04:15:00+03	260800.00
4AD9D1	2017-08-13 07:27:00+03	101200.00
4AD9DC	2017-07-16 23:50:00+03	34000.00
4ADA0D	2017-07-07 13:12:00+03	68000.00
4ADA4B	2017-07-06 22:27:00+03	13000.00
4ADAA1	2017-07-29 02:37:00+03	56000.00
4ADAA8	2017-07-24 18:37:00+03	73500.00
4ADB5E	2017-07-10 19:11:00+03	21400.00
4ADC2F	2017-07-28 19:20:00+03	271200.00
4ADC33	2017-07-06 15:59:00+03	49600.00
4ADCAC	2017-07-21 21:22:00+03	55800.00
4ADCFC	2017-07-10 16:03:00+03	12800.00
4ADD33	2017-08-06 08:49:00+03	112200.00
4ADD35	2017-07-07 08:51:00+03	149600.00
4ADDA9	2017-07-18 11:08:00+03	29600.00
4ADDC7	2017-07-19 15:52:00+03	65500.00
4ADE53	2017-08-14 00:59:00+03	66600.00
4ADE7D	2017-08-11 21:27:00+03	88100.00
4ADE8A	2017-07-03 07:56:00+03	55800.00
4ADEAF	2017-07-03 07:57:00+03	37100.00
4ADEF7	2017-07-20 03:02:00+03	106900.00
4ADF2A	2017-08-08 22:23:00+03	27300.00
4ADF2D	2017-07-26 06:29:00+03	32800.00
4ADF52	2017-07-03 19:29:00+03	12600.00
4ADF67	2017-07-20 11:19:00+03	124200.00
4ADF85	2017-07-07 20:08:00+03	99200.00
4ADFC1	2017-07-15 17:03:00+03	29600.00
4AE06B	2017-07-14 17:26:00+03	55800.00
4AE08B	2017-07-18 15:25:00+03	18600.00
4AE09C	2017-07-10 16:48:00+03	77900.00
4AE0B8	2017-07-07 06:02:00+03	112000.00
4AE1AB	2017-08-10 14:47:00+03	377100.00
4AE242	2017-07-25 08:30:00+03	28800.00
4AE280	2017-08-10 20:19:00+03	80000.00
4AE2A9	2017-08-08 11:32:00+03	46400.00
4AE2F0	2017-07-29 23:22:00+03	42600.00
4AE307	2017-07-04 03:17:00+03	70700.00
4AE342	2017-08-15 13:18:00+03	62700.00
4AE361	2017-08-12 20:52:00+03	100600.00
4AE391	2017-08-04 08:58:00+03	89600.00
4AE3B2	2017-07-31 23:40:00+03	43600.00
4AE414	2017-08-08 02:53:00+03	122500.00
4AE428	2017-08-09 20:50:00+03	46400.00
4AE470	2017-07-29 02:15:00+03	188000.00
4AE504	2017-08-15 09:10:00+03	52700.00
4AE50F	2017-08-14 10:17:00+03	54500.00
4AE510	2017-07-11 19:27:00+03	92400.00
4AE531	2017-07-15 06:47:00+03	93500.00
4AE5FA	2017-07-08 02:23:00+03	65400.00
4AE628	2017-07-05 22:40:00+03	3700.00
4AE636	2017-08-02 11:11:00+03	23600.00
4AE707	2017-07-31 01:59:00+03	131100.00
4AE752	2017-07-10 15:45:00+03	69800.00
4AE77D	2017-08-06 01:35:00+03	28000.00
4AE787	2017-08-08 19:33:00+03	372400.00
4AE7B3	2017-07-14 15:52:00+03	27800.00
4AE7CA	2017-07-07 14:34:00+03	89700.00
4AE7CD	2017-07-31 03:22:00+03	63200.00
4AE7FA	2017-07-08 13:53:00+03	22000.00
4AE82F	2017-07-30 01:52:00+03	166100.00
4AE87C	2017-07-22 09:41:00+03	75300.00
4AE891	2017-07-28 02:03:00+03	129200.00
4AE8D4	2017-08-10 11:30:00+03	11300.00
4AE8EC	2017-07-27 19:10:00+03	57800.00
4AE908	2017-07-03 14:15:00+03	64500.00
4AE96E	2017-08-06 09:52:00+03	21800.00
4AEA12	2017-08-02 16:22:00+03	137100.00
4AEA50	2017-07-20 18:17:00+03	23600.00
4AEA64	2017-07-02 15:48:00+03	173500.00
4AEAC0	2017-07-17 11:37:00+03	113000.00
4AEAC3	2017-08-02 12:21:00+03	67600.00
4AEACC	2017-07-29 09:21:00+03	21400.00
4AEB37	2017-07-19 06:52:00+03	139300.00
4AEB84	2017-07-25 19:53:00+03	86800.00
4AEC0C	2017-07-07 17:01:00+03	66000.00
4AEC1C	2017-07-01 15:43:00+03	23600.00
4AEC2A	2017-08-14 10:23:00+03	31600.00
4AEC31	2017-07-29 06:34:00+03	37200.00
4AEC54	2017-07-31 20:52:00+03	83000.00
4AEC81	2017-08-08 19:09:00+03	42600.00
4AEC88	2017-07-23 01:07:00+03	177800.00
4AECCF	2017-07-12 04:54:00+03	54000.00
4AECE5	2017-07-21 03:05:00+03	36200.00
4AED53	2017-07-25 03:16:00+03	56000.00
4AED6E	2017-08-12 18:41:00+03	29600.00
4AED77	2017-08-01 02:32:00+03	73600.00
4AEDA2	2017-07-25 14:04:00+03	23200.00
4AEE17	2017-08-03 04:25:00+03	27200.00
4AEE1F	2017-07-07 16:17:00+03	200300.00
4AEE75	2017-07-04 18:33:00+03	32800.00
4AEEA8	2017-07-17 09:42:00+03	42800.00
4AEF84	2017-08-06 03:42:00+03	31600.00
4AF00F	2017-07-19 10:03:00+03	135200.00
4AF03F	2017-08-01 15:20:00+03	116400.00
4AF0A3	2017-08-13 08:19:00+03	85700.00
4AF0ED	2017-08-14 09:33:00+03	8000.00
4AF116	2017-07-15 04:53:00+03	52100.00
4AF225	2017-07-23 22:51:00+03	73200.00
4AF26D	2017-06-30 20:23:00+03	24000.00
4AF276	2017-07-24 05:39:00+03	73600.00
4AF28A	2017-07-16 02:52:00+03	60500.00
4AF2C0	2017-07-03 09:17:00+03	25200.00
4AF2DB	2017-07-31 16:22:00+03	47000.00
4AF333	2017-07-06 22:54:00+03	86500.00
4AF35B	2017-08-02 00:12:00+03	28800.00
4AF467	2017-08-08 19:40:00+03	155600.00
4AF4B5	2017-07-13 02:10:00+03	75300.00
4AF4E9	2017-07-30 00:40:00+03	80000.00
4AF500	2017-08-05 09:20:00+03	30200.00
4AF526	2017-07-12 01:31:00+03	44800.00
4AF53C	2017-08-11 10:21:00+03	94700.00
4AF589	2017-07-27 16:35:00+03	17200.00
4AF591	2017-07-22 07:25:00+03	120100.00
4AF5A6	2017-08-05 14:24:00+03	31900.00
4AF5E2	2017-07-06 05:58:00+03	184300.00
4AF645	2017-08-03 12:52:00+03	26800.00
4AF64D	2017-07-15 23:16:00+03	21800.00
4AF686	2017-07-09 14:16:00+03	38400.00
4AF73A	2017-07-04 04:29:00+03	59800.00
4AF78F	2017-07-18 22:11:00+03	7200.00
4AF796	2017-07-12 19:29:00+03	51900.00
4AF7B7	2017-07-05 15:29:00+03	7400.00
4AF7CD	2017-07-11 05:42:00+03	36000.00
4AF7E6	2017-07-07 02:15:00+03	92000.00
4AF811	2017-07-30 01:47:00+03	36400.00
4AF820	2017-07-31 02:34:00+03	37600.00
4AF8DD	2017-07-21 16:34:00+03	296400.00
4AF95B	2017-07-27 22:02:00+03	31900.00
4AF9EC	2017-07-30 13:05:00+03	24000.00
4AFA76	2017-08-02 12:34:00+03	19600.00
4AFA9F	2017-07-08 18:36:00+03	83700.00
4AFAAA	2017-07-14 23:14:00+03	67600.00
4AFB12	2017-08-06 16:42:00+03	187600.00
4AFB13	2017-07-24 09:37:00+03	49600.00
4AFB51	2017-08-05 07:33:00+03	57800.00
4AFB60	2017-07-14 22:04:00+03	32200.00
4AFBDF	2017-08-10 18:38:00+03	70400.00
4AFC3E	2017-07-02 01:45:00+03	56000.00
4AFC4E	2017-08-04 17:23:00+03	56000.00
4AFC63	2017-08-12 10:57:00+03	16800.00
4AFC98	2017-08-15 02:19:00+03	46600.00
4AFCA7	2017-08-12 13:57:00+03	26800.00
4AFD0E	2017-07-21 00:01:00+03	58600.00
4AFD34	2017-07-26 14:46:00+03	231900.00
4AFDA2	2017-07-01 18:28:00+03	27600.00
4AFDBF	2017-07-04 13:36:00+03	14400.00
4AFDE6	2017-07-03 04:24:00+03	37100.00
4AFE29	2017-07-23 05:13:00+03	26200.00
4AFE7A	2017-07-07 23:00:00+03	66600.00
4AFE96	2017-07-24 00:37:00+03	51900.00
4AFEA9	2017-07-17 13:42:00+03	282600.00
4AFEF1	2017-08-05 17:18:00+03	40000.00
4AFF9D	2017-08-10 17:05:00+03	29800.00
4AFFAB	2017-08-12 20:27:00+03	84500.00
4B0050	2017-08-04 09:20:00+03	11700.00
4B006E	2017-07-23 00:22:00+03	36200.00
4B007A	2017-08-02 16:15:00+03	13400.00
4B00BD	2017-08-12 00:53:00+03	69000.00
4B012C	2017-07-10 06:49:00+03	49400.00
4B01A8	2017-08-03 19:14:00+03	52000.00
4B01B3	2017-08-11 09:08:00+03	67600.00
4B01FB	2017-07-12 19:16:00+03	96100.00
4B0211	2017-07-18 14:36:00+03	257600.00
4B0251	2017-08-15 09:38:00+03	13400.00
4B0253	2017-08-09 14:01:00+03	36800.00
4B02A2	2017-08-08 02:07:00+03	65800.00
4B0325	2017-08-09 13:35:00+03	46400.00
4B0364	2017-08-09 10:13:00+03	68400.00
4B0393	2017-06-30 04:09:00+03	116800.00
4B03AB	2017-07-09 02:43:00+03	12600.00
4B03C4	2017-07-02 10:31:00+03	72400.00
4B041D	2017-07-26 03:24:00+03	53600.00
4B042D	2017-07-15 19:27:00+03	118100.00
4B0452	2017-08-03 05:26:00+03	101200.00
4B04A8	2017-07-30 20:53:00+03	45600.00
4B04B1	2017-07-10 11:57:00+03	47000.00
4B04B8	2017-07-10 15:09:00+03	257500.00
4B04BC	2017-08-08 23:44:00+03	18600.00
4B053F	2017-08-03 10:25:00+03	61900.00
4B055E	2017-07-21 07:08:00+03	55600.00
4B059E	2017-07-18 00:33:00+03	45200.00
4B05E7	2017-07-08 10:55:00+03	271100.00
4B069F	2017-07-12 17:55:00+03	31400.00
4B06A1	2017-08-02 13:51:00+03	72000.00
4B06CA	2017-07-10 12:47:00+03	47000.00
4B0780	2017-07-04 04:10:00+03	65600.00
4B07AD	2017-08-09 11:22:00+03	89700.00
4B0815	2017-07-14 05:58:00+03	132800.00
4B081F	2017-07-28 09:13:00+03	86000.00
4B08D5	2017-08-09 12:13:00+03	44800.00
4B08D6	2017-07-10 22:22:00+03	16400.00
4B08FF	2017-08-04 18:28:00+03	35600.00
4B0928	2017-07-05 06:47:00+03	101200.00
4B0931	2017-07-08 01:44:00+03	58200.00
4B0957	2017-08-15 09:32:00+03	77000.00
4B0961	2017-06-30 20:38:00+03	25600.00
4B09A8	2017-07-11 14:26:00+03	26000.00
4B0A17	2017-07-21 16:13:00+03	37000.00
4B0A1C	2017-07-20 10:15:00+03	115900.00
4B0AA4	2017-08-12 14:46:00+03	119500.00
4B0AD2	2017-07-02 22:47:00+03	133200.00
4B0AEB	2017-07-04 04:12:00+03	105100.00
4B0AFE	2017-07-06 17:26:00+03	169300.00
4B0B02	2017-08-09 09:03:00+03	29400.00
4B0B11	2017-08-01 22:19:00+03	62600.00
4B0B22	2017-08-06 08:19:00+03	20000.00
4B0B64	2017-07-02 19:29:00+03	14400.00
4B0C31	2017-08-08 13:37:00+03	44000.00
4B0C49	2017-07-31 17:09:00+03	21400.00
4B0C5C	2017-07-18 02:17:00+03	270000.00
4B0C71	2017-07-19 15:27:00+03	47800.00
4B0C82	2017-08-04 06:08:00+03	91500.00
4B0CCE	2017-07-03 05:23:00+03	114800.00
4B0CDA	2017-07-25 23:04:00+03	31600.00
4B0D46	2017-07-23 02:32:00+03	181600.00
4B0DB4	2017-07-16 03:34:00+03	47200.00
4B0DCA	2017-07-30 11:38:00+03	89600.00
4B0E71	2017-08-15 16:19:00+03	12400.00
4B0F55	2017-07-25 11:53:00+03	17600.00
4B0FB4	2017-07-26 18:44:00+03	84000.00
4B1006	2017-08-09 21:17:00+03	40000.00
4B100B	2017-08-10 07:13:00+03	32700.00
4B101B	2017-07-05 20:54:00+03	68800.00
4B1044	2017-08-07 19:38:00+03	16400.00
4B1175	2017-06-29 20:43:00+03	68400.00
4B1178	2017-07-29 02:59:00+03	52000.00
4B11F2	2017-07-01 20:50:00+03	23200.00
4B1211	2017-08-02 23:30:00+03	27200.00
4B1256	2017-08-05 03:40:00+03	166900.00
4B1259	2017-07-08 00:58:00+03	43600.00
4B12B7	2017-07-12 22:33:00+03	25200.00
4B130B	2017-07-23 05:33:00+03	47100.00
4B1393	2017-08-12 03:29:00+03	72400.00
4B13B0	2017-07-05 01:15:00+03	261000.00
4B140C	2017-07-17 02:01:00+03	12000.00
4B1493	2017-07-04 19:55:00+03	19600.00
4B14B2	2017-08-09 14:05:00+03	73600.00
4B14D9	2017-07-13 13:38:00+03	6000.00
4B1554	2017-08-10 20:25:00+03	98400.00
4B1569	2017-07-03 05:02:00+03	60600.00
4B1590	2017-08-02 09:03:00+03	37600.00
4B15C0	2017-07-27 15:21:00+03	38800.00
4B15F7	2017-08-12 05:43:00+03	97600.00
4B1663	2017-08-05 13:30:00+03	6700.00
4B16D6	2017-08-14 12:55:00+03	44600.00
4B16DE	2017-07-29 06:14:00+03	99500.00
4B1745	2017-07-24 17:48:00+03	201800.00
4B17AE	2017-07-04 06:45:00+03	84500.00
4B17B3	2017-07-15 04:13:00+03	99500.00
4B1805	2017-07-31 23:19:00+03	265700.00
4B188D	2017-07-27 02:53:00+03	359600.00
4B18C5	2017-07-19 16:02:00+03	22000.00
4B18C7	2017-07-26 04:05:00+03	67600.00
4B18D1	2017-07-25 04:57:00+03	357600.00
4B194E	2017-07-20 09:42:00+03	149500.00
4B1977	2017-07-14 18:26:00+03	47400.00
4B19DB	2017-07-24 08:57:00+03	36900.00
4B19F8	2017-08-10 03:35:00+03	84100.00
4B1A63	2017-07-24 00:51:00+03	112000.00
4B1A92	2017-08-05 22:40:00+03	144400.00
4B1AA3	2017-07-13 06:36:00+03	189100.00
4B1AD2	2017-07-07 15:52:00+03	52900.00
4B1B2E	2017-07-25 08:32:00+03	492000.00
4B1B47	2017-07-30 17:13:00+03	40600.00
4B1B89	2017-08-03 13:52:00+03	159100.00
4B1B9C	2017-07-03 15:32:00+03	65900.00
4B1C65	2017-07-07 08:00:00+03	166300.00
4B1CA4	2017-07-12 09:00:00+03	48300.00
4B1CB7	2017-07-13 06:22:00+03	38600.00
4B1DA2	2017-08-09 19:42:00+03	283600.00
4B1DCE	2017-07-18 13:59:00+03	13000.00
4B1EBC	2017-08-03 21:11:00+03	30200.00
4B1F27	2017-08-06 13:06:00+03	24700.00
4B1F31	2017-08-10 02:16:00+03	139000.00
4B1F37	2017-08-08 15:18:00+03	49800.00
4B1F73	2017-08-03 20:00:00+03	147000.00
4B1F9C	2017-08-07 06:24:00+03	27200.00
4B1FC1	2017-07-09 02:21:00+03	265700.00
4B1FCB	2017-08-04 12:40:00+03	23600.00
4B2000	2017-08-05 03:20:00+03	14400.00
4B2009	2017-08-04 08:56:00+03	8600.00
4B2095	2017-08-04 08:01:00+03	140800.00
4B20A5	2017-07-16 23:45:00+03	76100.00
4B20B7	2017-08-08 17:57:00+03	15800.00
4B20C8	2017-07-26 04:01:00+03	85900.00
4B20D4	2017-07-10 01:03:00+03	23600.00
4B20FE	2017-07-05 16:43:00+03	28800.00
4B215B	2017-07-11 01:40:00+03	26800.00
4B218E	2017-07-06 21:14:00+03	65400.00
4B2198	2017-07-27 21:30:00+03	187600.00
4B21EE	2017-08-10 02:57:00+03	189200.00
4B2222	2017-07-13 19:28:00+03	90000.00
4B2234	2017-07-06 23:45:00+03	157100.00
4B2254	2017-08-12 16:07:00+03	35200.00
4B22D7	2017-07-02 13:50:00+03	246000.00
4B22F6	2017-07-26 18:05:00+03	80800.00
4B2339	2017-07-01 12:34:00+03	48800.00
4B234A	2017-07-21 16:06:00+03	23200.00
4B237D	2017-07-12 23:50:00+03	57800.00
4B238E	2017-08-10 10:56:00+03	81900.00
4B23F4	2017-08-03 23:36:00+03	48400.00
4B2423	2017-07-24 00:50:00+03	28800.00
4B246A	2017-07-12 16:47:00+03	131600.00
4B2474	2017-08-12 17:30:00+03	87100.00
4B2485	2017-07-17 11:56:00+03	39600.00
4B24A4	2017-08-11 04:44:00+03	271400.00
4B24C8	2017-07-07 16:32:00+03	38600.00
4B24D9	2017-07-28 19:01:00+03	9800.00
4B24F6	2017-08-07 02:51:00+03	67100.00
4B25D2	2017-07-09 23:50:00+03	85400.00
4B25D9	2017-06-30 23:01:00+03	116500.00
4B2603	2017-08-08 01:18:00+03	27900.00
4B2615	2017-07-16 09:51:00+03	76600.00
4B264E	2017-07-03 14:22:00+03	8000.00
4B267B	2017-07-18 11:47:00+03	295300.00
4B2685	2017-07-26 16:05:00+03	51900.00
4B26FA	2017-07-26 10:08:00+03	106700.00
4B2732	2017-07-09 07:44:00+03	123000.00
4B27C2	2017-07-20 09:00:00+03	38200.00
4B283E	2017-08-12 05:07:00+03	28800.00
4B284C	2017-08-05 21:06:00+03	48800.00
4B2896	2017-08-04 09:19:00+03	76600.00
4B2942	2017-08-15 09:49:00+03	66600.00
4B298B	2017-07-07 19:45:00+03	88000.00
4B2992	2017-08-05 08:33:00+03	105600.00
4B29BF	2017-07-25 04:53:00+03	6800.00
4B2A8F	2017-08-10 05:27:00+03	28000.00
4B2A94	2017-08-07 12:58:00+03	26000.00
4B2AC0	2017-07-31 13:13:00+03	28800.00
4B2ADF	2017-07-26 02:43:00+03	22600.00
4B2AE3	2017-07-26 16:09:00+03	77400.00
4B2B23	2017-08-14 11:51:00+03	98400.00
4B2B5E	2017-07-14 03:28:00+03	55800.00
4B2B63	2017-07-28 18:04:00+03	24400.00
4B2B9C	2017-08-09 01:41:00+03	6700.00
4B2BF7	2017-07-25 19:53:00+03	64400.00
4B2C7A	2017-07-25 05:02:00+03	86800.00
4B2CB9	2017-08-08 17:06:00+03	14000.00
4B2CBD	2017-07-17 23:40:00+03	160700.00
4B2D1A	2017-07-25 20:20:00+03	40400.00
4B2D37	2017-08-06 15:22:00+03	68000.00
4B2E05	2017-07-08 09:21:00+03	63200.00
4B2E24	2017-08-04 10:44:00+03	65900.00
4B2E4E	2017-07-21 04:33:00+03	76600.00
4B2E8F	2017-07-11 06:18:00+03	99200.00
4B2E93	2017-07-04 10:06:00+03	56900.00
4B2E9D	2017-06-30 11:19:00+03	47200.00
4B2EB4	2017-07-23 02:08:00+03	14800.00
4B2EBC	2017-08-09 16:48:00+03	23200.00
4B2EF2	2017-07-08 16:22:00+03	69500.00
4B2F82	2017-07-21 02:31:00+03	41100.00
4B2F97	2017-08-04 11:45:00+03	13400.00
4B2FA4	2017-08-01 18:11:00+03	59000.00
4B2FB0	2017-07-10 01:58:00+03	17600.00
4B2FC4	2017-08-04 16:52:00+03	410400.00
4B2FED	2017-07-27 19:45:00+03	47400.00
4B301B	2017-07-12 23:36:00+03	31200.00
4B304F	2017-07-10 14:08:00+03	131600.00
4B306F	2017-07-19 18:13:00+03	25400.00
4B309D	2017-08-11 00:35:00+03	52000.00
4B30A4	2017-07-22 10:47:00+03	20200.00
4B30CD	2017-07-11 17:50:00+03	85000.00
4B3141	2017-07-09 09:32:00+03	16400.00
4B316E	2017-07-12 13:38:00+03	29100.00
4B31E8	2017-07-26 22:07:00+03	58600.00
4B31FD	2017-07-25 16:15:00+03	12400.00
4B3273	2017-08-06 01:46:00+03	70800.00
4B329B	2017-07-26 21:47:00+03	136500.00
4B32E2	2017-07-23 20:41:00+03	37900.00
4B32FC	2017-07-17 11:33:00+03	29600.00
4B330E	2017-06-30 14:53:00+03	28000.00
4B3349	2017-08-04 23:55:00+03	28000.00
4B336C	2017-07-10 13:45:00+03	106400.00
4B3377	2017-08-10 22:23:00+03	55800.00
4B3380	2017-07-05 03:02:00+03	65500.00
4B3388	2017-07-05 08:14:00+03	56600.00
4B3398	2017-08-09 15:00:00+03	23200.00
4B33AF	2017-08-06 02:00:00+03	57400.00
4B3493	2017-08-06 01:19:00+03	27600.00
4B34EE	2017-08-09 16:16:00+03	114800.00
4B3531	2017-07-24 05:18:00+03	67500.00
4B3563	2017-08-10 09:28:00+03	135600.00
4B35B4	2017-07-25 03:27:00+03	43000.00
4B35C1	2017-07-10 14:31:00+03	248500.00
4B3648	2017-08-06 01:11:00+03	31600.00
4B3664	2017-08-15 14:14:00+03	76600.00
4B3744	2017-08-07 13:41:00+03	95200.00
4B3766	2017-08-11 07:56:00+03	131100.00
4B3778	2017-07-11 17:02:00+03	32800.00
4B37AB	2017-07-11 15:27:00+03	29600.00
4B3856	2017-07-26 14:18:00+03	20200.00
4B385D	2017-06-27 22:35:00+03	8200.00
4B3861	2017-07-28 12:20:00+03	13700.00
4B3886	2017-08-14 10:06:00+03	44900.00
4B38BB	2017-07-30 08:07:00+03	31400.00
4B38CE	2017-07-26 11:15:00+03	56000.00
4B38EF	2017-08-01 21:05:00+03	105100.00
4B3913	2017-08-11 18:47:00+03	66600.00
4B3974	2017-07-11 07:03:00+03	59000.00
4B39BB	2017-07-26 09:17:00+03	60000.00
4B39C7	2017-08-02 23:39:00+03	104000.00
4B3A17	2017-07-28 11:13:00+03	110000.00
4B3A29	2017-07-15 10:11:00+03	23600.00
4B3ADB	2017-07-25 16:53:00+03	47900.00
4B3B47	2017-08-02 14:31:00+03	23200.00
4B3B5D	2017-08-07 18:28:00+03	89600.00
4B3C57	2017-07-29 18:18:00+03	30200.00
4B3D5C	2017-08-01 07:00:00+03	130200.00
4B3D8D	2017-07-28 01:44:00+03	24400.00
4B3DF6	2017-08-01 15:36:00+03	37900.00
4B3E25	2017-07-16 22:44:00+03	126400.00
4B3E3B	2017-07-09 19:38:00+03	30200.00
4B3E44	2017-07-14 13:12:00+03	12000.00
4B3E4D	2017-07-21 07:20:00+03	55800.00
4B3EAF	2017-08-10 14:16:00+03	57400.00
4B3EE9	2017-08-13 21:54:00+03	16400.00
4B3FF5	2017-07-31 18:10:00+03	32200.00
4B4021	2017-07-02 06:53:00+03	56600.00
4B40A6	2017-07-07 22:34:00+03	6900.00
4B40A9	2017-06-30 17:07:00+03	23200.00
4B4159	2017-07-11 21:41:00+03	40600.00
4B4164	2017-07-05 01:42:00+03	61800.00
4B416E	2017-08-06 11:52:00+03	83100.00
4B41A6	2017-07-05 09:46:00+03	14400.00
4B41E6	2017-08-10 03:54:00+03	81900.00
4B41FE	2017-08-15 16:47:00+03	53600.00
4B4232	2017-07-18 14:50:00+03	50800.00
4B4239	2017-07-29 14:43:00+03	37900.00
4B4273	2017-07-26 03:26:00+03	149200.00
4B4309	2017-08-06 02:22:00+03	37200.00
4B4381	2017-07-08 02:04:00+03	29600.00
4B438B	2017-07-14 19:20:00+03	140900.00
4B43C2	2017-07-15 23:54:00+03	78200.00
4B43E7	2017-07-19 04:10:00+03	112400.00
4B4497	2017-07-17 17:28:00+03	28000.00
4B44A0	2017-07-13 11:56:00+03	34100.00
4B44AF	2017-08-10 16:49:00+03	46200.00
4B44DC	2017-08-03 06:59:00+03	49100.00
4B44FF	2017-07-17 07:10:00+03	46500.00
4B450E	2017-07-04 16:53:00+03	137100.00
4B4516	2017-06-30 22:12:00+03	77600.00
4B4542	2017-07-21 21:29:00+03	67100.00
4B4592	2017-07-14 11:58:00+03	63200.00
4B4598	2017-08-06 21:34:00+03	14800.00
4B45E7	2017-07-03 08:20:00+03	123000.00
4B463C	2017-07-14 11:52:00+03	12400.00
4B4650	2017-07-13 02:55:00+03	67900.00
4B46B4	2017-07-03 01:42:00+03	117200.00
4B4702	2017-08-14 01:58:00+03	93600.00
4B4741	2017-07-06 19:56:00+03	46400.00
4B478D	2017-07-11 14:57:00+03	20200.00
4B47C3	2017-08-05 01:49:00+03	149200.00
4B47FC	2017-08-13 08:26:00+03	59900.00
4B4836	2017-07-14 02:37:00+03	37800.00
4B48BF	2017-07-16 17:37:00+03	177200.00
4B492C	2017-07-05 11:17:00+03	8200.00
4B49D0	2017-08-05 00:07:00+03	241300.00
4B4A0E	2017-07-07 02:39:00+03	38800.00
4B4A1E	2017-07-15 06:13:00+03	53200.00
4B4A56	2017-08-04 17:00:00+03	23200.00
4B4A92	2017-06-30 17:05:00+03	14000.00
4B4AAC	2017-07-13 10:11:00+03	12600.00
4B4AB2	2017-08-04 04:34:00+03	14800.00
4B4AB4	2017-07-08 13:45:00+03	246000.00
4B4B0B	2017-07-23 16:02:00+03	43000.00
4B4B1E	2017-07-29 17:31:00+03	56500.00
4B4B40	2017-07-19 07:49:00+03	30000.00
4B4B96	2017-07-11 01:35:00+03	44800.00
4B4BC6	2017-07-04 05:42:00+03	134700.00
4B4C11	2017-06-29 16:05:00+03	83000.00
4B4C18	2017-07-17 04:34:00+03	145100.00
4B4CF2	2017-07-22 05:33:00+03	58600.00
4B4D2E	2017-07-18 20:23:00+03	122300.00
4B4D49	2017-07-07 15:06:00+03	73500.00
4B4D9B	2017-07-27 03:10:00+03	57700.00
4B4E0C	2017-07-21 17:34:00+03	54400.00
4B4E24	2017-06-30 21:40:00+03	48800.00
4B4E41	2017-07-21 00:00:00+03	16400.00
4B4E69	2017-07-08 01:43:00+03	99200.00
4B4EFA	2017-07-24 09:09:00+03	265700.00
4B4F28	2017-08-07 15:11:00+03	42800.00
4B4F97	2017-07-08 15:26:00+03	47500.00
4B4FF1	2017-07-29 15:57:00+03	51100.00
4B4FF9	2017-07-16 06:04:00+03	26200.00
4B500A	2017-07-23 15:22:00+03	20600.00
4B5130	2017-08-03 22:52:00+03	27200.00
4B5136	2017-07-28 04:20:00+03	100400.00
4B51A6	2017-07-06 23:37:00+03	70200.00
4B5225	2017-08-12 02:24:00+03	16400.00
4B52B4	2017-08-14 19:21:00+03	99200.00
4B52B5	2017-07-10 13:27:00+03	119800.00
4B530F	2017-07-19 22:34:00+03	58900.00
4B5335	2017-07-27 11:36:00+03	23200.00
4B5337	2017-07-13 07:40:00+03	6300.00
4B538B	2017-07-18 01:17:00+03	35300.00
4B53A5	2017-08-09 06:07:00+03	8200.00
4B53AE	2017-08-08 12:19:00+03	57500.00
4B53C4	2017-07-31 05:33:00+03	98000.00
4B5405	2017-07-07 01:19:00+03	89700.00
4B54A8	2017-06-30 23:24:00+03	30400.00
4B54F5	2017-07-23 07:39:00+03	36900.00
4B552F	2017-07-26 13:21:00+03	29400.00
4B556B	2017-07-06 18:54:00+03	199800.00
4B55A6	2017-07-05 00:04:00+03	119600.00
4B55F6	2017-08-11 07:12:00+03	46400.00
4B55FC	2017-07-08 05:44:00+03	36200.00
4B567E	2017-07-30 09:10:00+03	37900.00
4B5700	2017-07-20 13:23:00+03	39300.00
4B5747	2017-07-08 10:35:00+03	73600.00
4B5748	2017-08-15 12:24:00+03	96200.00
4B5787	2017-08-14 14:59:00+03	40800.00
4B5791	2017-07-05 18:09:00+03	19600.00
4B5854	2017-07-19 05:10:00+03	106100.00
4B58F5	2017-07-09 10:01:00+03	16400.00
4B5930	2017-07-22 02:36:00+03	93400.00
4B5950	2017-08-05 00:12:00+03	145300.00
4B5964	2017-07-16 20:44:00+03	48800.00
4B5A53	2017-07-22 13:15:00+03	18800.00
4B5B96	2017-07-14 21:09:00+03	106100.00
4B5C41	2017-07-21 03:24:00+03	6700.00
4B5C44	2017-07-25 16:48:00+03	60400.00
4B5CD6	2017-07-14 22:56:00+03	46400.00
4B5D42	2017-08-11 09:14:00+03	65900.00
4B5D57	2017-07-08 20:30:00+03	42800.00
4B5D5A	2017-08-13 03:52:00+03	203500.00
4B5DB5	2017-07-24 18:08:00+03	38800.00
4B5DE6	2017-07-03 00:50:00+03	44000.00
4B5E0E	2017-07-29 00:42:00+03	87000.00
4B5EA1	2017-08-14 19:41:00+03	94400.00
4B5EEA	2017-08-10 15:16:00+03	206400.00
4B5F37	2017-08-06 11:47:00+03	52100.00
4B5F53	2017-08-12 18:26:00+03	108500.00
4B5FDE	2017-08-11 05:38:00+03	129000.00
4B5FE4	2017-08-04 03:12:00+03	25000.00
4B5FF7	2017-08-01 05:34:00+03	47200.00
4B6037	2017-07-01 04:49:00+03	53600.00
4B6038	2017-08-05 18:58:00+03	369000.00
4B607A	2017-08-05 05:47:00+03	120700.00
4B616A	2017-08-12 20:10:00+03	25000.00
4B61E5	2017-07-13 06:24:00+03	47400.00
4B61E8	2017-08-08 04:05:00+03	293600.00
4B6254	2017-07-31 09:31:00+03	46000.00
4B626E	2017-07-19 20:03:00+03	55800.00
4B62A5	2017-07-07 03:32:00+03	496600.00
4B62A9	2017-08-12 07:30:00+03	25600.00
4B62AC	2017-07-06 13:56:00+03	75300.00
4B6353	2017-07-05 13:38:00+03	147000.00
4B6382	2017-07-08 01:28:00+03	30200.00
4B6476	2017-06-28 11:05:00+03	6700.00
4B6478	2017-06-30 08:57:00+03	111600.00
4B64A2	2017-07-18 00:08:00+03	121800.00
4B64B5	2017-07-27 00:47:00+03	155600.00
4B64C0	2017-07-28 02:01:00+03	148200.00
4B64C6	2017-08-14 17:19:00+03	123000.00
4B651F	2017-07-21 20:33:00+03	62800.00
4B653A	2017-08-03 14:27:00+03	6000.00
4B6554	2017-07-30 17:20:00+03	68400.00
4B6576	2017-07-22 22:00:00+03	113300.00
4B657B	2017-08-09 09:23:00+03	111700.00
4B6582	2017-07-01 06:12:00+03	43000.00
4B65EB	2017-08-13 20:21:00+03	66600.00
4B6605	2017-07-10 13:46:00+03	102000.00
4B6607	2017-07-17 08:33:00+03	29000.00
4B662B	2017-07-08 21:02:00+03	432900.00
4B663E	2017-07-14 21:03:00+03	139300.00
4B664F	2017-08-05 09:44:00+03	51000.00
4B6701	2017-08-07 16:46:00+03	133200.00
4B6727	2017-07-05 16:07:00+03	16400.00
4B6811	2017-08-11 19:04:00+03	46800.00
4B682E	2017-08-10 22:42:00+03	86600.00
4B6884	2017-07-21 03:05:00+03	12600.00
4B6889	2017-07-28 09:40:00+03	167400.00
4B68C3	2017-08-08 21:16:00+03	123900.00
4B68E0	2017-07-19 09:13:00+03	246000.00
4B691D	2017-07-25 19:37:00+03	64700.00
4B6942	2017-07-12 08:38:00+03	56000.00
4B6945	2017-07-11 19:52:00+03	49600.00
4B696E	2017-08-12 20:45:00+03	50800.00
4B699F	2017-07-11 03:49:00+03	104600.00
4B69DB	2017-08-12 16:48:00+03	26300.00
4B6A38	2017-08-15 02:31:00+03	65300.00
4B6A50	2017-08-11 11:57:00+03	25100.00
4B6AA5	2017-07-08 09:16:00+03	135200.00
4B6B2B	2017-07-02 01:04:00+03	123000.00
4B6B5C	2017-07-31 05:30:00+03	56600.00
4B6B91	2017-07-31 16:23:00+03	28000.00
4B6BA3	2017-08-08 14:31:00+03	46200.00
4B6BB9	2017-07-31 07:07:00+03	79600.00
4B6BF5	2017-07-13 04:58:00+03	125400.00
4B6C88	2017-08-14 16:10:00+03	100000.00
4B6CED	2017-07-15 00:55:00+03	199200.00
4B6CF3	2017-07-25 09:03:00+03	56000.00
4B6CFE	2017-07-10 13:52:00+03	111600.00
4B6D3A	2017-07-11 12:26:00+03	42100.00
4B6D3B	2017-07-07 03:01:00+03	20800.00
4B6DC0	2017-07-18 18:59:00+03	65900.00
4B6E67	2017-07-29 21:15:00+03	77600.00
4B6EB2	2017-07-02 16:31:00+03	84000.00
4B6F21	2017-08-04 01:58:00+03	53000.00
4B6FB0	2017-07-27 20:02:00+03	65900.00
4B6FCA	2017-08-13 17:42:00+03	23600.00
4B6FDE	2017-07-31 04:35:00+03	65600.00
4B6FF9	2017-07-05 17:51:00+03	202500.00
4B6FFF	2017-07-15 00:10:00+03	56000.00
4B7001	2017-07-04 17:03:00+03	24400.00
4B702E	2017-07-06 00:59:00+03	255600.00
4B7063	2017-07-12 16:03:00+03	67600.00
4B7083	2017-07-23 04:36:00+03	12600.00
4B70CD	2017-07-25 13:39:00+03	87100.00
4B711B	2017-07-12 22:23:00+03	54400.00
4B7150	2017-08-15 12:04:00+03	18600.00
4B717D	2017-07-05 07:41:00+03	56600.00
4B7181	2017-08-15 05:45:00+03	16400.00
4B71A4	2017-07-20 09:52:00+03	78200.00
4B71F3	2017-08-08 20:44:00+03	6000.00
4B721A	2017-07-20 12:18:00+03	60500.00
4B72B7	2017-07-27 02:38:00+03	218400.00
4B7307	2017-07-30 19:50:00+03	191600.00
4B7355	2017-07-22 09:22:00+03	46000.00
4B739A	2017-08-03 02:02:00+03	84500.00
4B73A1	2017-07-28 22:20:00+03	125200.00
4B73C6	2017-07-03 13:18:00+03	37900.00
4B73E9	2017-07-23 01:22:00+03	156500.00
4B740C	2017-07-12 18:37:00+03	12600.00
4B7434	2017-08-05 12:21:00+03	42400.00
4B745E	2017-08-04 02:27:00+03	49800.00
4B7462	2017-07-03 07:35:00+03	90700.00
4B749F	2017-08-06 05:16:00+03	15100.00
4B74FB	2017-07-15 02:20:00+03	29400.00
4B751A	2017-07-10 19:37:00+03	12400.00
4B7537	2017-07-07 02:20:00+03	62800.00
4B7578	2017-07-28 05:37:00+03	92900.00
4B758B	2017-08-07 10:58:00+03	30000.00
4B75A9	2017-07-05 08:30:00+03	28300.00
4B75CD	2017-07-10 16:51:00+03	70600.00
4B75D1	2017-07-05 20:49:00+03	18500.00
4B760B	2017-07-09 19:51:00+03	266200.00
4B7610	2017-07-16 23:03:00+03	86400.00
4B7674	2017-07-09 13:24:00+03	6000.00
4B769C	2017-06-26 01:33:00+03	26700.00
4B76CB	2017-07-16 06:12:00+03	112600.00
4B76DD	2017-08-03 14:04:00+03	59400.00
4B7705	2017-07-15 01:13:00+03	11700.00
4B7715	2017-07-09 04:43:00+03	56000.00
4B7729	2017-07-19 14:43:00+03	43600.00
4B7784	2017-08-14 21:36:00+03	65500.00
4B77B9	2017-07-16 00:14:00+03	29400.00
4B7818	2017-07-14 00:56:00+03	32900.00
4B7824	2017-07-05 05:43:00+03	125200.00
4B7884	2017-07-28 13:19:00+03	24800.00
4B78AE	2017-07-28 13:38:00+03	120500.00
4B791D	2017-08-04 00:35:00+03	79600.00
4B7922	2017-08-04 21:35:00+03	81600.00
4B7934	2017-08-06 11:17:00+03	52800.00
4B795C	2017-07-16 06:36:00+03	137600.00
4B7A20	2017-07-26 01:04:00+03	52300.00
4B7A7B	2017-07-04 13:08:00+03	27200.00
4B7B0D	2017-08-10 11:31:00+03	23100.00
4B7B88	2017-07-18 16:13:00+03	46000.00
4B7B8E	2017-07-22 11:59:00+03	55800.00
4B7BB2	2017-08-15 06:43:00+03	233200.00
4B7C45	2017-08-06 03:40:00+03	28800.00
4B7D85	2017-08-06 13:10:00+03	97900.00
4B7DEF	2017-07-13 08:38:00+03	58400.00
4B7E71	2017-07-17 00:46:00+03	33100.00
4B7E7B	2017-07-10 17:03:00+03	27600.00
4B7E91	2017-07-31 03:59:00+03	74400.00
4B7EFC	2017-08-13 09:45:00+03	394400.00
4B7F53	2017-07-26 16:06:00+03	65900.00
4B7F5B	2017-07-05 22:23:00+03	23200.00
4B808D	2017-07-13 11:33:00+03	58800.00
4B80B4	2017-08-07 22:26:00+03	21400.00
4B80D0	2017-07-31 01:02:00+03	75300.00
4B80E6	2017-07-08 20:25:00+03	113200.00
4B810C	2017-07-20 20:39:00+03	69000.00
4B8110	2017-07-10 19:54:00+03	58200.00
4B81C8	2017-08-02 20:57:00+03	101200.00
4B81FA	2017-07-15 15:59:00+03	125100.00
4B8207	2017-07-08 18:48:00+03	44000.00
4B8214	2017-07-22 10:26:00+03	45000.00
4B828F	2017-07-01 13:53:00+03	27200.00
4B82D1	2017-08-12 11:59:00+03	80000.00
4B82EB	2017-08-06 22:39:00+03	85000.00
4B8344	2017-07-25 07:04:00+03	103500.00
4B837A	2017-07-05 08:07:00+03	258400.00
4B83AF	2017-08-15 08:13:00+03	38800.00
4B83DF	2017-07-18 03:06:00+03	56200.00
4B8408	2017-07-27 16:59:00+03	277800.00
4B8467	2017-07-23 04:15:00+03	75600.00
4B84A1	2017-07-25 04:57:00+03	16800.00
4B84CC	2017-07-30 23:37:00+03	16400.00
4B84FB	2017-08-02 02:46:00+03	25400.00
4B853B	2017-07-06 17:19:00+03	29400.00
4B854F	2017-08-07 02:29:00+03	124300.00
4B8579	2017-07-22 18:47:00+03	70800.00
4B8582	2017-07-07 08:00:00+03	92400.00
4B85A8	2017-07-08 12:15:00+03	372500.00
4B85DF	2017-07-19 05:33:00+03	171700.00
4B85EE	2017-08-10 21:36:00+03	68800.00
4B8629	2017-07-23 17:30:00+03	41200.00
4B863A	2017-07-13 18:20:00+03	28800.00
4B865C	2017-08-03 06:30:00+03	44800.00
4B86BF	2017-08-14 03:11:00+03	38000.00
4B86E2	2017-08-02 08:56:00+03	73300.00
4B8714	2017-07-14 04:15:00+03	281500.00
4B87AA	2017-07-03 00:46:00+03	95600.00
4B8873	2017-07-24 23:12:00+03	89700.00
4B8883	2017-07-07 23:23:00+03	27600.00
4B88CE	2017-07-10 14:43:00+03	44000.00
4B88ED	2017-07-16 01:55:00+03	25600.00
4B8948	2017-08-05 00:02:00+03	94000.00
4B89B4	2017-07-14 10:51:00+03	6300.00
4B89C3	2017-08-12 08:55:00+03	57800.00
4B8A1E	2017-07-03 02:27:00+03	67200.00
4B8A3D	2017-08-15 07:24:00+03	36200.00
4B8A6E	2017-08-13 16:31:00+03	101400.00
4B8A82	2017-08-01 14:52:00+03	45100.00
4B8AB4	2017-08-10 12:04:00+03	73600.00
4B8AD4	2017-08-11 02:49:00+03	56900.00
4B8AF6	2017-07-20 17:17:00+03	114200.00
4B8B19	2017-07-28 21:40:00+03	47000.00
4B8B78	2017-08-06 01:33:00+03	23400.00
4B8B84	2017-07-05 02:33:00+03	12600.00
4B8B9D	2017-08-03 15:22:00+03	46400.00
4B8BBE	2017-08-03 21:06:00+03	84000.00
4B8BC8	2017-08-15 02:50:00+03	94200.00
4B8BDB	2017-08-13 16:31:00+03	6000.00
4B8BEB	2017-07-23 22:47:00+03	40800.00
4B8C06	2017-08-04 06:11:00+03	27200.00
4B8C7F	2017-07-24 14:11:00+03	39300.00
4B8CAD	2017-08-08 13:48:00+03	33100.00
4B8D07	2017-07-30 06:41:00+03	11700.00
4B8D20	2017-07-14 12:41:00+03	12400.00
4B8D28	2017-07-09 06:18:00+03	16400.00
4B8D5E	2017-07-04 10:21:00+03	23200.00
4B8D7D	2017-08-07 23:06:00+03	48800.00
4B8DA5	2017-07-02 04:16:00+03	38400.00
4B8DC1	2017-07-24 00:33:00+03	101200.00
4B8DC3	2017-08-12 05:01:00+03	28800.00
4B8DDC	2017-07-03 21:18:00+03	55800.00
4B8E80	2017-07-28 14:52:00+03	67600.00
4B8EF2	2017-07-24 19:27:00+03	50600.00
4B8F02	2017-07-07 11:09:00+03	73600.00
4B8FA6	2017-08-01 05:11:00+03	46300.00
4B8FA9	2017-07-09 19:18:00+03	92800.00
4B8FAE	2017-07-19 11:16:00+03	68900.00
4B8FB0	2017-08-11 22:31:00+03	39800.00
4B8FCD	2017-08-02 19:12:00+03	128800.00
4B900A	2017-07-20 16:47:00+03	32800.00
4B901C	2017-08-03 00:35:00+03	28800.00
4B9036	2017-08-06 21:18:00+03	56000.00
4B903B	2017-07-03 11:08:00+03	28800.00
4B9072	2017-07-19 16:18:00+03	75600.00
4B90B3	2017-07-13 18:05:00+03	102500.00
4B90D9	2017-07-07 21:03:00+03	92900.00
4B90F2	2017-08-10 12:44:00+03	65900.00
4B90FF	2017-08-15 16:04:00+03	83000.00
4B913E	2017-08-02 06:31:00+03	48800.00
4B914E	2017-07-05 20:28:00+03	64100.00
4B917E	2017-07-19 09:48:00+03	86600.00
4B91B7	2017-08-07 14:26:00+03	14400.00
4B91BA	2017-07-04 02:39:00+03	62000.00
4B920C	2017-07-16 02:01:00+03	21400.00
4B9249	2017-07-14 15:38:00+03	66000.00
4B9285	2017-08-07 12:45:00+03	126500.00
4B92CE	2017-08-08 15:17:00+03	36400.00
4B9355	2017-07-17 13:47:00+03	30000.00
4B93A2	2017-08-01 11:32:00+03	48800.00
4B93C8	2017-07-26 04:37:00+03	83600.00
4B9468	2017-08-07 19:05:00+03	28000.00
4B94C2	2017-07-28 13:55:00+03	90300.00
4B94C5	2017-07-16 20:02:00+03	175200.00
4B94E3	2017-07-17 03:45:00+03	53300.00
4B94FC	2017-07-06 11:42:00+03	79000.00
4B9515	2017-08-11 00:21:00+03	18600.00
4B9589	2017-08-10 19:01:00+03	66000.00
4B9594	2017-08-09 16:26:00+03	21800.00
4B95C2	2017-08-01 14:12:00+03	55800.00
4B95CD	2017-08-03 07:19:00+03	403600.00
4B9650	2017-07-19 05:00:00+03	179600.00
4B9790	2017-08-05 12:09:00+03	71900.00
4B97B0	2017-07-29 01:32:00+03	46400.00
4B981B	2017-07-05 12:23:00+03	53400.00
4B985E	2017-07-31 04:14:00+03	124200.00
4B9877	2017-07-09 01:02:00+03	8400.00
4B98CB	2017-07-24 20:10:00+03	35600.00
4B98F7	2017-08-07 15:39:00+03	47200.00
4B98FC	2017-07-25 19:25:00+03	32200.00
4B9997	2017-07-12 19:09:00+03	48800.00
4B99C6	2017-07-26 03:48:00+03	240600.00
4B99D5	2017-07-07 14:34:00+03	54000.00
4B99F1	2017-08-10 22:08:00+03	18400.00
4B9A65	2017-07-28 12:36:00+03	11000.00
4B9BD2	2017-08-10 12:17:00+03	26400.00
4B9C56	2017-07-30 23:28:00+03	76600.00
4B9CE8	2017-08-11 08:41:00+03	65500.00
4B9CEB	2017-07-06 23:21:00+03	46400.00
4B9CFF	2017-08-08 05:46:00+03	53600.00
4B9D5C	2017-08-01 23:14:00+03	128800.00
4B9DC8	2017-07-28 22:26:00+03	58600.00
4B9DE7	2017-07-22 16:28:00+03	109600.00
4B9E90	2017-08-15 10:03:00+03	27700.00
4B9E96	2017-07-16 06:38:00+03	14400.00
4B9EFF	2017-07-30 13:05:00+03	97500.00
4B9F22	2017-08-08 13:55:00+03	147700.00
4B9F4F	2017-07-11 00:10:00+03	100600.00
4B9F68	2017-07-19 17:48:00+03	61400.00
4B9F80	2017-07-02 05:50:00+03	24400.00
4B9FE6	2017-07-20 12:34:00+03	189800.00
4B9FFA	2017-07-19 13:33:00+03	47600.00
4BA005	2017-07-21 23:31:00+03	57600.00
4BA006	2017-08-10 23:54:00+03	270800.00
4BA008	2017-07-03 20:11:00+03	88600.00
4BA012	2017-07-28 02:30:00+03	147200.00
4BA049	2017-07-08 19:30:00+03	52300.00
4BA063	2017-07-04 07:12:00+03	46300.00
4BA105	2017-07-20 19:42:00+03	80700.00
4BA10B	2017-07-03 23:58:00+03	28400.00
4BA17C	2017-07-31 13:09:00+03	50900.00
4BA187	2017-06-29 18:53:00+03	7400.00
4BA243	2017-08-04 21:55:00+03	6000.00
4BA27F	2017-08-01 00:54:00+03	40800.00
4BA2CA	2017-07-02 23:44:00+03	86300.00
4BA2E4	2017-08-01 21:09:00+03	72200.00
4BA334	2017-07-02 09:07:00+03	25100.00
4BA35F	2017-07-12 07:59:00+03	76300.00
4BA3A5	2017-07-05 07:26:00+03	191000.00
4BA3AD	2017-08-02 19:24:00+03	51200.00
4BA44A	2017-07-06 08:11:00+03	66600.00
4BA472	2017-08-11 12:07:00+03	23900.00
4BA4DD	2017-06-30 15:21:00+03	12600.00
4BA4E2	2017-08-09 21:58:00+03	240600.00
4BA587	2017-07-09 15:24:00+03	69700.00
4BA5EC	2017-08-05 12:50:00+03	73100.00
4BA650	2017-07-10 05:24:00+03	248400.00
4BA65F	2017-08-10 16:58:00+03	59400.00
4BA686	2017-07-14 21:00:00+03	26700.00
4BA696	2017-08-06 12:54:00+03	145300.00
4BA6AA	2017-07-15 14:02:00+03	22000.00
4BA6BB	2017-07-22 02:02:00+03	23400.00
4BA75A	2017-08-10 09:04:00+03	45000.00
4BA768	2017-08-14 03:34:00+03	28000.00
4BA76A	2017-07-04 14:14:00+03	44800.00
4BA772	2017-07-05 00:59:00+03	13600.00
4BA7AA	2017-08-04 03:35:00+03	28700.00
4BA7C5	2017-08-15 13:03:00+03	24400.00
4BA813	2017-07-17 19:23:00+03	37900.00
4BA858	2017-08-09 20:45:00+03	40400.00
4BA874	2017-07-05 04:19:00+03	37200.00
4BA8ED	2017-08-13 15:25:00+03	75600.00
4BA935	2017-07-24 13:37:00+03	66000.00
4BA949	2017-07-28 02:43:00+03	39000.00
4BA965	2017-07-20 05:37:00+03	52100.00
4BA9F8	2017-08-07 12:04:00+03	46400.00
4BAA08	2017-08-09 11:54:00+03	381800.00
4BAA17	2017-07-31 18:47:00+03	135600.00
4BAA21	2017-07-15 20:21:00+03	111600.00
4BAA2D	2017-08-11 21:04:00+03	24000.00
4BAA6F	2017-07-07 22:35:00+03	40800.00
4BAABE	2017-07-28 03:39:00+03	64600.00
4BAB2C	2017-08-05 13:00:00+03	36000.00
4BAB61	2017-07-07 08:57:00+03	69500.00
4BAB6E	2017-08-06 17:12:00+03	59800.00
4BAB95	2017-07-01 01:42:00+03	34000.00
4BAC70	2017-07-14 16:52:00+03	8200.00
4BAD24	2017-07-11 16:31:00+03	134400.00
4BAD44	2017-07-18 17:14:00+03	290900.00
4BAD80	2017-07-08 04:02:00+03	58200.00
4BAD8D	2017-07-29 18:09:00+03	29600.00
4BADB6	2017-07-02 18:55:00+03	61800.00
4BAE0D	2017-08-06 23:28:00+03	33600.00
4BAE3F	2017-07-14 10:17:00+03	8000.00
4BAE4E	2017-08-05 00:29:00+03	27200.00
4BAE8E	2017-06-22 07:22:00+03	46300.00
4BAEAD	2017-07-12 05:12:00+03	49400.00
4BAEDB	2017-07-12 12:43:00+03	51900.00
4BAEE6	2017-07-26 13:29:00+03	14000.00
4BAF1D	2017-07-15 07:25:00+03	46300.00
4BAF25	2017-07-13 01:28:00+03	67400.00
4BAF5B	2017-08-13 21:29:00+03	62000.00
4BAF5D	2017-07-30 21:52:00+03	53700.00
4BAFB9	2017-07-14 21:20:00+03	83000.00
4BB047	2017-07-17 08:01:00+03	31600.00
4BB04B	2017-06-29 04:07:00+03	32800.00
4BB065	2017-08-10 21:59:00+03	169600.00
4BB0D7	2017-08-02 01:30:00+03	36700.00
4BB0D9	2017-07-24 11:01:00+03	124300.00
4BB0DF	2017-07-05 06:58:00+03	19600.00
4BB129	2017-08-12 09:10:00+03	37400.00
4BB153	2017-08-13 02:57:00+03	57600.00
4BB192	2017-07-06 00:44:00+03	67900.00
4BB19D	2017-07-27 06:05:00+03	26200.00
4BB1AD	2017-08-11 19:25:00+03	27200.00
4BB1DA	2017-07-17 05:34:00+03	112000.00
4BB28B	2017-08-09 09:37:00+03	14400.00
4BB314	2017-07-25 13:48:00+03	101200.00
4BB349	2017-08-08 10:29:00+03	89600.00
4BB356	2017-07-30 22:24:00+03	92400.00
4BB39B	2017-07-09 20:39:00+03	99100.00
4BB44C	2017-07-08 16:33:00+03	16400.00
4BB47A	2017-07-27 04:25:00+03	76600.00
4BB489	2017-07-14 13:55:00+03	23400.00
4BB4D6	2017-07-29 18:33:00+03	143800.00
4BB500	2017-08-12 21:11:00+03	46800.00
4BB5A2	2017-07-25 12:31:00+03	73500.00
4BB699	2017-07-27 16:02:00+03	24000.00
4BB6BC	2017-07-06 01:31:00+03	28800.00
4BB797	2017-07-16 18:55:00+03	30200.00
4BB7FF	2017-08-01 07:20:00+03	54500.00
4BB831	2017-08-13 04:50:00+03	26600.00
4BB88C	2017-07-31 12:17:00+03	64600.00
4BB8AE	2017-07-19 04:52:00+03	139800.00
4BB8FF	2017-08-13 13:05:00+03	63200.00
4BB9F7	2017-07-03 01:54:00+03	69500.00
4BBA20	2017-07-10 12:04:00+03	14000.00
4BBA31	2017-07-24 10:12:00+03	52900.00
4BBADB	2017-07-22 20:27:00+03	87300.00
4BBAFC	2017-07-28 04:55:00+03	11600.00
4BBB38	2017-08-09 00:41:00+03	306300.00
4BBB81	2017-07-23 16:15:00+03	235800.00
4BBBF4	2017-07-10 11:18:00+03	28000.00
4BBC09	2017-07-08 09:39:00+03	15800.00
4BBC74	2017-07-27 15:05:00+03	92700.00
4BBCC3	2017-07-12 00:13:00+03	46200.00
4BBCF5	2017-07-23 02:52:00+03	23200.00
4BBD26	2017-07-19 18:59:00+03	111600.00
4BBDA8	2017-08-04 12:10:00+03	69900.00
4BBDD7	2017-07-16 19:18:00+03	89700.00
4BBDDD	2017-08-14 11:14:00+03	56200.00
4BBDE2	2017-08-12 20:15:00+03	131600.00
4BBDEF	2017-08-05 15:54:00+03	62000.00
4BBE0B	2017-07-06 21:56:00+03	31600.00
4BBE25	2017-07-19 05:20:00+03	57400.00
4BBE3F	2017-08-07 04:56:00+03	41200.00
4BBE4C	2017-07-25 11:31:00+03	88100.00
4BBED8	2017-07-08 09:51:00+03	23200.00
4BBF41	2017-08-05 23:45:00+03	28000.00
4BBF4C	2017-08-03 14:08:00+03	72200.00
4BBF95	2017-07-06 16:11:00+03	56000.00
4BBFAF	2017-07-02 18:09:00+03	91100.00
4BBFF2	2017-08-01 13:47:00+03	175300.00
4BC039	2017-08-13 19:13:00+03	265600.00
4BC06C	2017-07-25 20:11:00+03	80000.00
4BC07B	2017-08-04 10:59:00+03	137900.00
4BC0FC	2017-08-08 11:35:00+03	34000.00
4BC100	2017-08-14 08:42:00+03	52400.00
4BC11E	2017-08-04 01:57:00+03	94900.00
4BC19E	2017-07-23 16:50:00+03	25400.00
4BC209	2017-07-07 19:44:00+03	6000.00
4BC26A	2017-08-11 03:45:00+03	49700.00
4BC2A1	2017-07-25 23:00:00+03	53200.00
4BC2E1	2017-08-09 13:54:00+03	31400.00
4BC339	2017-08-08 03:08:00+03	50000.00
4BC39F	2017-07-04 10:04:00+03	25400.00
4BC448	2017-07-27 20:15:00+03	40800.00
4BC450	2017-07-26 18:04:00+03	26000.00
4BC489	2017-07-16 03:36:00+03	66600.00
4BC48D	2017-07-13 01:49:00+03	19600.00
4BC495	2017-07-05 03:54:00+03	111600.00
4BC4B9	2017-07-09 08:44:00+03	136100.00
4BC5C9	2017-08-07 21:19:00+03	16400.00
4BC5E8	2017-08-09 08:06:00+03	111600.00
4BC679	2017-07-18 12:15:00+03	29600.00
4BC717	2017-08-02 04:55:00+03	56000.00
4BC7B3	2017-07-29 04:47:00+03	65900.00
4BC7F3	2017-07-12 06:06:00+03	175900.00
4BC800	2017-08-03 01:27:00+03	47500.00
4BC81E	2017-08-07 09:29:00+03	160200.00
4BC871	2017-06-26 10:23:00+03	29600.00
4BC974	2017-07-25 01:04:00+03	89600.00
4BC975	2017-07-25 16:11:00+03	75600.00
4BC98D	2017-07-25 14:00:00+03	48300.00
4BC9AC	2017-07-05 07:40:00+03	64700.00
4BC9CF	2017-08-09 06:51:00+03	131600.00
4BCA16	2017-08-12 09:10:00+03	98700.00
4BCA91	2017-07-07 01:14:00+03	21800.00
4BCAF3	2017-08-15 15:17:00+03	496700.00
4BCAFB	2017-08-13 20:31:00+03	8200.00
4BCB23	2017-07-11 12:54:00+03	52300.00
4BCBA5	2017-07-09 01:22:00+03	64700.00
4BCBDC	2017-08-06 10:51:00+03	29600.00
4BCBEC	2017-08-11 14:54:00+03	6700.00
4BCBF6	2017-07-06 05:12:00+03	44800.00
4BCBFD	2017-08-07 01:23:00+03	75800.00
4BCC12	2017-07-28 22:31:00+03	63200.00
4BCC1B	2017-07-05 16:32:00+03	61200.00
4BCCA7	2017-07-18 19:17:00+03	56600.00
4BCCCB	2017-07-08 20:17:00+03	94200.00
4BCD34	2017-08-15 01:37:00+03	80000.00
4BCD5C	2017-08-04 03:37:00+03	98000.00
4BCD73	2017-07-12 10:08:00+03	135400.00
4BCDC8	2017-08-01 20:43:00+03	192100.00
4BCE47	2017-07-20 06:55:00+03	62600.00
4BCE53	2017-07-22 17:56:00+03	61800.00
4BCE54	2017-06-29 08:13:00+03	231900.00
4BCE80	2017-07-05 19:30:00+03	75600.00
4BCE94	2017-08-05 09:57:00+03	13000.00
4BCEB6	2017-08-08 16:06:00+03	193100.00
4BD00E	2017-07-31 19:57:00+03	29400.00
4BD04A	2017-07-31 07:46:00+03	36200.00
4BD073	2017-07-24 13:50:00+03	48400.00
4BD12A	2017-07-04 06:09:00+03	133100.00
4BD171	2017-07-16 17:23:00+03	80000.00
4BD178	2017-06-30 22:09:00+03	26000.00
4BD17D	2017-07-06 10:42:00+03	25900.00
4BD18E	2017-07-20 14:17:00+03	44800.00
4BD1DE	2017-07-22 09:17:00+03	44800.00
4BD1EA	2017-07-14 21:39:00+03	53400.00
4BD229	2017-07-22 11:34:00+03	133100.00
4BD25E	2017-08-14 01:07:00+03	113300.00
4BD2B8	2017-08-07 20:40:00+03	45100.00
4BD2F6	2017-07-21 19:18:00+03	23200.00
4BD2FD	2017-07-11 05:11:00+03	23200.00
4BD31E	2017-07-28 08:56:00+03	36100.00
4BD349	2017-07-31 14:28:00+03	53200.00
4BD350	2017-08-12 07:32:00+03	6700.00
4BD46A	2017-07-05 02:32:00+03	28800.00
4BD48A	2017-07-07 15:07:00+03	27300.00
4BD4F4	2017-07-19 16:08:00+03	29600.00
4BD5CE	2017-07-14 19:27:00+03	189800.00
4BD603	2017-08-03 19:31:00+03	182300.00
4BD611	2017-07-21 09:42:00+03	54400.00
4BD639	2017-08-15 04:44:00+03	13400.00
4BD63E	2017-07-22 13:51:00+03	109600.00
4BD696	2017-07-24 22:36:00+03	86500.00
4BD6C8	2017-08-07 09:04:00+03	98000.00
4BD71A	2017-07-23 18:39:00+03	119500.00
4BD760	2017-08-09 16:11:00+03	79200.00
4BD766	2017-08-05 16:28:00+03	114800.00
4BD7EF	2017-07-20 11:24:00+03	65000.00
4BD884	2017-07-08 14:25:00+03	38600.00
4BD895	2017-07-15 06:25:00+03	199700.00
4BD8F1	2017-08-14 13:08:00+03	52700.00
4BD956	2017-07-30 19:38:00+03	135400.00
4BD965	2017-07-02 09:01:00+03	193700.00
4BD96D	2017-07-26 19:11:00+03	58000.00
4BD9B5	2017-08-06 13:41:00+03	57400.00
4BD9CD	2017-07-12 03:55:00+03	102100.00
4BD9DD	2017-07-09 20:05:00+03	52400.00
4BD9DE	2017-08-08 17:44:00+03	58500.00
4BDA0D	2017-08-12 02:12:00+03	137100.00
4BDA1A	2017-07-24 13:01:00+03	115100.00
4BDA1B	2017-07-22 05:31:00+03	52000.00
4BDA64	2017-07-08 15:06:00+03	21400.00
4BDA75	2017-07-17 22:39:00+03	141600.00
4BDA90	2017-07-17 02:55:00+03	132800.00
4BDAD5	2017-07-11 11:05:00+03	24400.00
4BDB99	2017-08-14 18:24:00+03	19600.00
4BDBC0	2017-07-19 13:12:00+03	169600.00
4BDBD5	2017-08-03 20:55:00+03	68000.00
4BDBDF	2017-08-11 20:53:00+03	189200.00
4BDBF5	2017-07-08 08:22:00+03	34400.00
4BDC4C	2017-07-23 02:21:00+03	129000.00
4BDC5E	2017-07-20 16:28:00+03	92600.00
4BDCA7	2017-07-16 03:22:00+03	58000.00
4BDCAD	2017-08-15 00:25:00+03	79600.00
4BDD2F	2017-07-01 18:47:00+03	94000.00
4BDD4E	2017-08-06 23:30:00+03	25600.00
4BDE4B	2017-08-08 21:28:00+03	99600.00
4BDE89	2017-07-05 00:48:00+03	15400.00
4BDEB2	2017-07-04 00:50:00+03	131600.00
4BDF2A	2017-07-02 05:55:00+03	24400.00
4BDFC8	2017-08-11 10:03:00+03	13400.00
4BDFFD	2017-07-27 03:23:00+03	16400.00
4BE06F	2017-08-12 16:59:00+03	24000.00
4BE0AC	2017-07-15 00:50:00+03	25800.00
4BE0D9	2017-07-15 01:15:00+03	58900.00
4BE0DE	2017-07-23 04:32:00+03	95700.00
4BE193	2017-08-02 22:09:00+03	32800.00
4BE265	2017-08-11 08:31:00+03	54300.00
4BE270	2017-07-09 09:03:00+03	136600.00
4BE2A6	2017-07-07 06:05:00+03	138700.00
4BE2EB	2017-07-26 00:15:00+03	21400.00
4BE32C	2017-07-09 07:08:00+03	148300.00
4BE353	2017-07-13 06:54:00+03	25000.00
4BE371	2017-08-15 10:07:00+03	29400.00
4BE37E	2017-07-31 05:51:00+03	67600.00
4BE389	2017-08-12 11:58:00+03	93900.00
4BE40D	2017-07-05 06:45:00+03	111600.00
4BE520	2017-07-08 15:13:00+03	66300.00
4BE534	2017-07-18 19:54:00+03	32200.00
4BE5B5	2017-07-01 04:46:00+03	11700.00
4BE634	2017-07-25 12:37:00+03	166100.00
4BE64F	2017-07-08 06:45:00+03	51300.00
4BE656	2017-07-21 23:23:00+03	84500.00
4BE6A0	2017-08-07 01:58:00+03	68400.00
4BE70C	2017-07-08 17:41:00+03	52700.00
4BE720	2017-07-30 08:39:00+03	248400.00
4BE759	2017-07-30 07:44:00+03	152400.00
4BE77B	2017-07-30 20:39:00+03	25400.00
4BE80C	2017-07-12 09:33:00+03	288800.00
4BE822	2017-07-28 01:21:00+03	39100.00
4BE838	2017-07-10 06:00:00+03	24600.00
4BE8C3	2017-07-22 12:13:00+03	102000.00
4BE926	2017-07-13 00:17:00+03	127300.00
4BE94F	2017-08-10 02:27:00+03	40000.00
4BE986	2017-07-23 05:33:00+03	137800.00
4BE98C	2017-07-14 21:41:00+03	113800.00
4BEA42	2017-08-04 04:48:00+03	77600.00
4BEA82	2017-08-11 19:33:00+03	64500.00
4BEA85	2017-07-20 10:27:00+03	43900.00
4BEA9C	2017-07-21 20:20:00+03	40800.00
4BEB34	2017-08-05 05:09:00+03	137900.00
4BEB36	2017-08-15 15:01:00+03	16400.00
4BEC4C	2017-07-08 21:40:00+03	56800.00
4BEC7C	2017-07-08 00:54:00+03	82900.00
4BEC7D	2017-08-02 08:56:00+03	548300.00
4BECB6	2017-08-10 10:58:00+03	40100.00
4BECE6	2017-08-08 10:31:00+03	23400.00
4BEE35	2017-08-14 02:20:00+03	86400.00
4BEEB0	2017-08-09 20:23:00+03	143600.00
4BEED8	2017-07-11 01:56:00+03	47000.00
4BEF65	2017-07-07 16:13:00+03	273400.00
4BEF7B	2017-08-11 01:42:00+03	32800.00
4BEF97	2017-07-03 01:06:00+03	28800.00
4BEFEC	2017-07-07 05:30:00+03	30800.00
4BF00F	2017-08-08 08:06:00+03	59800.00
4BF094	2017-07-06 05:06:00+03	43200.00
4BF0B7	2017-07-28 02:42:00+03	37200.00
4BF0DB	2017-07-27 21:03:00+03	53400.00
4BF0F1	2017-08-03 12:14:00+03	170000.00
4BF1B4	2017-06-30 13:40:00+03	47000.00
4BF1C7	2017-07-13 17:45:00+03	47100.00
4BF1C9	2017-07-12 19:00:00+03	35200.00
4BF1F0	2017-07-12 12:13:00+03	16400.00
4BF20B	2017-07-11 04:54:00+03	134800.00
4BF29F	2017-07-20 01:58:00+03	167400.00
4BF37F	2017-08-14 07:32:00+03	32700.00
4BF3B2	2017-07-09 06:57:00+03	123000.00
4BF3C5	2017-07-07 12:48:00+03	16000.00
4BF430	2017-08-13 12:08:00+03	96800.00
4BF4A9	2017-07-15 17:11:00+03	100600.00
4BF4F1	2017-07-10 15:01:00+03	22000.00
4BF521	2017-07-09 11:12:00+03	59200.00
4BF52D	2017-07-09 03:59:00+03	28000.00
4BF5A1	2017-07-22 21:39:00+03	33100.00
4BF694	2017-07-08 00:30:00+03	190400.00
4BF6AA	2017-08-15 14:57:00+03	23200.00
4BF6C2	2017-07-03 19:53:00+03	200300.00
4BF6C4	2017-07-08 07:51:00+03	169700.00
4BF6E4	2017-07-17 07:34:00+03	15000.00
4BF768	2017-07-01 03:03:00+03	56000.00
4BF7EF	2017-07-09 17:12:00+03	130800.00
4BF7FA	2017-08-09 07:14:00+03	70700.00
4BF818	2017-07-20 02:36:00+03	88900.00
4BF836	2017-07-19 04:26:00+03	161400.00
4BF83E	2017-07-28 04:38:00+03	288700.00
4BF84F	2017-07-24 17:07:00+03	205000.00
4BF8EF	2017-07-07 14:54:00+03	56000.00
4BF93D	2017-08-02 01:03:00+03	57600.00
4BF9B7	2017-08-08 00:35:00+03	112000.00
4BFA25	2017-07-22 10:35:00+03	55800.00
4BFA30	2017-07-02 19:29:00+03	273400.00
4BFA5E	2017-07-25 13:45:00+03	112000.00
4BFA8B	2017-08-01 01:13:00+03	28800.00
4BFA94	2017-07-21 20:26:00+03	37900.00
4BFADB	2017-07-30 19:40:00+03	103600.00
4BFADC	2017-07-20 03:41:00+03	64500.00
4BFAE9	2017-08-05 08:06:00+03	42800.00
4BFAED	2017-07-30 12:00:00+03	23600.00
4BFB6F	2017-07-19 02:41:00+03	31800.00
4BFB9C	2017-07-24 05:17:00+03	102100.00
4BFBB5	2017-07-01 16:58:00+03	26700.00
4BFC1A	2017-07-05 02:12:00+03	99500.00
4BFC20	2017-07-11 21:55:00+03	60400.00
4BFC81	2017-07-22 09:43:00+03	202300.00
4BFC86	2017-07-09 07:58:00+03	90400.00
4BFD04	2017-07-31 22:18:00+03	39600.00
4BFD9D	2017-08-09 20:17:00+03	65900.00
4BFDA5	2017-07-25 03:37:00+03	88900.00
4BFDE3	2017-08-06 16:08:00+03	28800.00
4BFE41	2017-07-30 04:31:00+03	6300.00
4BFE73	2017-07-24 06:18:00+03	124200.00
4BFE93	2017-07-19 14:50:00+03	92400.00
4BFF3E	2017-07-11 05:19:00+03	124300.00
4BFF50	2017-08-02 21:13:00+03	59200.00
4BFF54	2017-08-06 03:29:00+03	17200.00
4BFFAE	2017-07-22 13:02:00+03	65000.00
4BFFF6	2017-07-17 08:23:00+03	88800.00
4C0016	2017-07-18 07:10:00+03	69900.00
4C0054	2017-07-26 08:15:00+03	46800.00
4C00C4	2017-07-28 10:06:00+03	54000.00
4C00CF	2017-07-11 19:05:00+03	28000.00
4C0102	2017-08-08 09:23:00+03	39100.00
4C010F	2017-08-09 19:01:00+03	136800.00
4C016C	2017-08-14 13:45:00+03	27300.00
4C017D	2017-07-30 09:40:00+03	32800.00
4C01C9	2017-07-06 17:16:00+03	114800.00
4C026B	2017-07-25 00:26:00+03	283100.00
4C02C0	2017-08-09 21:26:00+03	11800.00
4C02F8	2017-07-01 19:07:00+03	78800.00
4C02FD	2017-07-31 02:25:00+03	9200.00
4C0355	2017-07-04 00:40:00+03	138000.00
4C0373	2017-08-04 12:03:00+03	19600.00
4C03BC	2017-07-16 10:18:00+03	144400.00
4C03E7	2017-07-13 14:20:00+03	47200.00
4C0406	2017-08-08 03:48:00+03	89800.00
4C0474	2017-08-13 14:06:00+03	35200.00
4C048E	2017-07-28 15:54:00+03	123000.00
4C04A7	2017-08-11 08:07:00+03	47000.00
4C052F	2017-07-10 22:54:00+03	70600.00
4C0570	2017-07-03 10:21:00+03	60600.00
4C0589	2017-07-05 17:48:00+03	143400.00
4C05A8	2017-06-29 01:11:00+03	112000.00
4C05B7	2017-08-01 19:02:00+03	67200.00
4C05E9	2017-08-04 13:42:00+03	130300.00
4C0602	2017-07-20 09:31:00+03	136600.00
4C0618	2017-07-12 21:22:00+03	289300.00
4C0638	2017-07-31 01:56:00+03	92800.00
4C0639	2017-07-11 12:06:00+03	11000.00
4C0732	2017-07-25 08:51:00+03	92800.00
4C07B5	2017-07-19 11:46:00+03	94000.00
4C082B	2017-08-15 17:49:00+03	25100.00
4C086A	2017-07-21 02:01:00+03	46400.00
4C0882	2017-07-16 03:45:00+03	38600.00
4C0887	2017-07-13 01:20:00+03	80000.00
4C088C	2017-07-21 07:39:00+03	266400.00
4C08D2	2017-07-01 09:57:00+03	56100.00
4C08DE	2017-08-14 14:06:00+03	62800.00
4C0921	2017-08-13 11:04:00+03	20900.00
4C0969	2017-08-12 00:13:00+03	43000.00
4C0993	2017-07-29 20:44:00+03	160300.00
4C09C6	2017-07-25 08:48:00+03	27800.00
4C09DA	2017-07-15 12:36:00+03	112000.00
4C0A10	2017-07-23 16:02:00+03	23400.00
4C0A57	2017-07-27 07:35:00+03	25200.00
4C0A99	2017-07-16 10:04:00+03	146500.00
4C0AA1	2017-08-07 17:04:00+03	112000.00
4C0ABD	2017-08-09 20:23:00+03	19600.00
4C0ABF	2017-07-24 21:01:00+03	123000.00
4C0B53	2017-07-19 17:08:00+03	115700.00
4C0B5D	2017-07-11 20:49:00+03	24800.00
4C0B6C	2017-07-10 03:42:00+03	257500.00
4C0B93	2017-08-12 05:06:00+03	124300.00
4C0BE6	2017-08-14 13:16:00+03	60300.00
4C0C1F	2017-07-07 21:14:00+03	37700.00
4C0C4C	2017-08-08 12:37:00+03	18800.00
4C0CBC	2017-08-02 17:30:00+03	128800.00
4C0D90	2017-08-15 09:50:00+03	23200.00
4C0E76	2017-07-25 23:46:00+03	81700.00
4C0E9F	2017-07-02 15:41:00+03	51300.00
4C0EF9	2017-07-17 08:16:00+03	61800.00
4C0FE4	2017-07-22 09:28:00+03	103800.00
4C1059	2017-08-05 05:28:00+03	46000.00
4C1067	2017-07-24 16:02:00+03	27200.00
4C1068	2017-07-10 21:06:00+03	130500.00
4C1080	2017-07-06 22:59:00+03	22000.00
4C1096	2017-07-12 02:06:00+03	443000.00
4C10CA	2017-07-25 11:48:00+03	39800.00
4C112E	2017-07-03 01:59:00+03	123900.00
4C114C	2017-06-28 04:06:00+03	12600.00
4C1155	2017-07-21 04:20:00+03	86400.00
4C1197	2017-07-03 14:11:00+03	368400.00
4C1252	2017-07-05 15:06:00+03	73600.00
4C139D	2017-08-15 17:27:00+03	6000.00
4C13A1	2017-07-20 15:12:00+03	32800.00
4C13C1	2017-08-09 07:23:00+03	272400.00
4C13E6	2017-07-20 14:44:00+03	56000.00
4C1400	2017-07-03 16:27:00+03	615000.00
4C1402	2017-08-11 19:36:00+03	28800.00
4C1405	2017-08-02 06:49:00+03	198400.00
4C1417	2017-08-07 05:15:00+03	66600.00
4C1418	2017-08-03 15:29:00+03	37200.00
4C1460	2017-08-14 14:31:00+03	18400.00
4C14B9	2017-07-21 16:54:00+03	24400.00
4C14DD	2017-08-01 23:56:00+03	56600.00
4C1535	2017-07-27 13:14:00+03	57700.00
4C156B	2017-08-13 08:21:00+03	61800.00
4C157D	2017-08-07 03:16:00+03	16400.00
4C15F2	2017-07-31 21:28:00+03	123000.00
4C15FF	2017-08-12 14:49:00+03	271200.00
4C1605	2017-08-14 06:54:00+03	83700.00
4C1608	2017-07-15 19:30:00+03	38500.00
4C1659	2017-08-02 03:55:00+03	23400.00
4C166E	2017-07-10 18:14:00+03	153400.00
4C1687	2017-08-01 04:17:00+03	260900.00
4C16BA	2017-07-15 20:38:00+03	92800.00
4C16DD	2017-07-10 08:39:00+03	56900.00
4C171C	2017-08-07 06:18:00+03	23400.00
4C171D	2017-07-07 17:07:00+03	114800.00
4C1768	2017-08-03 11:18:00+03	70800.00
4C1786	2017-08-04 22:25:00+03	15000.00
4C178C	2017-07-26 13:42:00+03	60700.00
4C179A	2017-08-04 09:52:00+03	176800.00
4C1805	2017-07-14 22:25:00+03	119500.00
4C1819	2017-07-02 19:20:00+03	21400.00
4C1867	2017-07-29 01:16:00+03	399600.00
4C1895	2017-06-25 15:29:00+03	46400.00
4C18FB	2017-08-14 02:54:00+03	233600.00
4C199C	2017-07-14 12:37:00+03	28800.00
4C19BC	2017-08-12 07:39:00+03	50700.00
4C1A64	2017-07-30 05:11:00+03	100600.00
4C1A76	2017-07-18 04:38:00+03	73600.00
4C1ADD	2017-07-13 13:38:00+03	67600.00
4C1AF6	2017-07-04 17:00:00+03	32700.00
4C1B7A	2017-08-12 15:58:00+03	173500.00
4C1B8D	2017-07-22 20:27:00+03	93700.00
4C1BC7	2017-07-18 04:19:00+03	35600.00
4C1BE5	2017-07-16 23:20:00+03	43600.00
4C1BED	2017-07-07 12:13:00+03	198900.00
4C1BEF	2017-07-30 02:45:00+03	64800.00
4C1CEC	2017-08-01 09:45:00+03	34400.00
4C1D52	2017-08-06 18:56:00+03	134700.00
4C1D9C	2017-07-18 11:11:00+03	25000.00
4C1D9F	2017-07-29 16:28:00+03	16000.00
4C1DC5	2017-08-14 13:34:00+03	25600.00
4C1DDD	2017-08-12 22:20:00+03	133200.00
4C1E01	2017-07-22 03:57:00+03	47700.00
4C1E7A	2017-07-02 10:28:00+03	111600.00
4C1E82	2017-06-26 13:43:00+03	28800.00
4C1EE8	2017-07-09 02:59:00+03	162600.00
4C1F0C	2017-08-15 11:21:00+03	21500.00
4C1FB6	2017-08-08 23:49:00+03	60400.00
4C1FC6	2017-07-01 09:15:00+03	28800.00
4C1FFE	2017-07-31 09:16:00+03	22000.00
4C2027	2017-07-13 13:54:00+03	81700.00
4C21EB	2017-07-23 19:08:00+03	150600.00
4C222E	2017-07-06 17:49:00+03	73100.00
4C2236	2017-07-25 10:08:00+03	27400.00
4C2248	2017-07-07 13:53:00+03	119800.00
4C2309	2017-08-05 13:21:00+03	137600.00
4C23A0	2017-07-13 10:38:00+03	180800.00
4C23CB	2017-07-11 00:43:00+03	42800.00
4C23DE	2017-07-29 05:57:00+03	166000.00
4C24CF	2017-07-22 20:36:00+03	47100.00
4C257C	2017-07-04 18:03:00+03	174200.00
4C25AB	2017-07-04 22:00:00+03	109600.00
4C25BE	2017-07-30 17:06:00+03	26000.00
4C261D	2017-07-05 06:02:00+03	26000.00
4C2645	2017-07-23 19:44:00+03	92800.00
4C265A	2017-07-26 01:31:00+03	89100.00
4C2663	2017-08-03 03:50:00+03	143800.00
4C270E	2017-07-10 04:18:00+03	64000.00
4C2716	2017-07-12 04:33:00+03	101900.00
4C2757	2017-08-04 03:33:00+03	100600.00
4C2801	2017-08-02 13:12:00+03	112000.00
4C2856	2017-08-08 04:40:00+03	23200.00
4C2874	2017-07-04 04:22:00+03	76600.00
4C28AA	2017-07-02 15:54:00+03	56000.00
4C28DF	2017-08-04 13:23:00+03	8200.00
4C28FA	2017-07-13 10:30:00+03	93700.00
4C2900	2017-06-30 08:38:00+03	85600.00
4C2905	2017-07-15 03:51:00+03	136100.00
4C297C	2017-08-06 06:13:00+03	85000.00
4C2991	2017-08-09 11:03:00+03	96800.00
4C29D0	2017-08-13 23:43:00+03	85800.00
4C29E2	2017-07-30 05:33:00+03	140800.00
4C2A2B	2017-07-19 20:40:00+03	6600.00
4C2A3B	2017-07-20 19:16:00+03	112000.00
4C2A79	2017-07-24 19:14:00+03	28300.00
4C2AAE	2017-07-27 05:38:00+03	246000.00
4C2B8C	2017-07-06 03:10:00+03	78600.00
4C2C13	2017-07-06 23:05:00+03	337400.00
4C2C27	2017-07-03 19:22:00+03	57600.00
4C2C29	2017-07-04 08:33:00+03	126300.00
4C2C43	2017-07-11 09:05:00+03	33300.00
4C2C85	2017-08-01 04:46:00+03	81600.00
4C2CB8	2017-08-08 01:20:00+03	46000.00
4C2CBF	2017-07-20 12:30:00+03	123600.00
4C2D1E	2017-07-26 17:43:00+03	47000.00
4C2D2D	2017-08-15 03:53:00+03	66800.00
4C2D4F	2017-08-11 05:03:00+03	88500.00
4C2D83	2017-07-17 17:45:00+03	57600.00
4C2DB4	2017-07-13 22:32:00+03	14000.00
4C2EA4	2017-07-25 02:01:00+03	92400.00
4C2EF6	2017-08-10 09:40:00+03	84100.00
4C2F03	2017-07-07 18:26:00+03	21400.00
4C2F07	2017-08-11 15:34:00+03	27400.00
4C2F3F	2017-08-10 08:24:00+03	46400.00
4C30F3	2017-07-19 00:48:00+03	26000.00
4C3103	2017-08-09 06:33:00+03	23400.00
4C315A	2017-07-11 10:08:00+03	199700.00
4C316D	2017-07-12 16:30:00+03	12600.00
4C31AB	2017-08-07 01:38:00+03	29600.00
4C31F5	2017-06-30 19:23:00+03	54100.00
4C327C	2017-07-10 02:36:00+03	43900.00
4C3316	2017-07-16 17:41:00+03	34000.00
4C333B	2017-07-08 08:27:00+03	17600.00
4C334B	2017-06-29 23:50:00+03	28800.00
4C3351	2017-07-19 08:34:00+03	119600.00
4C338F	2017-08-15 04:14:00+03	56000.00
4C33D2	2017-07-07 04:14:00+03	24000.00
4C33F5	2017-08-08 09:25:00+03	47200.00
4C34CA	2017-07-27 12:16:00+03	228700.00
4C34D8	2017-08-13 05:42:00+03	42400.00
4C350C	2017-07-10 10:33:00+03	399600.00
4C3518	2017-07-25 05:22:00+03	46000.00
4C3583	2017-08-02 00:58:00+03	56000.00
4C360C	2017-07-01 03:44:00+03	72200.00
4C362A	2017-07-20 03:36:00+03	42400.00
4C3637	2017-07-16 04:44:00+03	40900.00
4C3660	2017-08-08 01:34:00+03	75800.00
4C369B	2017-08-13 19:25:00+03	67800.00
4C3704	2017-07-27 02:49:00+03	62600.00
4C3777	2017-08-11 21:46:00+03	10600.00
4C38AA	2017-07-29 21:53:00+03	40800.00
4C38C3	2017-07-24 03:55:00+03	246000.00
4C3942	2017-08-02 01:29:00+03	187600.00
4C395F	2017-07-26 06:49:00+03	123000.00
4C3A0C	2017-07-07 21:56:00+03	198400.00
4C3A0F	2017-08-06 01:21:00+03	91800.00
4C3AB7	2017-07-27 13:05:00+03	332800.00
4C3B0B	2017-07-29 10:07:00+03	153200.00
4C3B1B	2017-07-05 20:30:00+03	492000.00
4C3B20	2017-08-07 06:19:00+03	12600.00
4C3B2F	2017-08-07 03:21:00+03	117600.00
4C3B62	2017-07-13 01:35:00+03	14400.00
4C3BB9	2017-07-09 20:19:00+03	246000.00
4C3C00	2017-07-15 09:20:00+03	46000.00
4C3C52	2017-07-02 09:39:00+03	26000.00
4C3C82	2017-07-26 09:48:00+03	46500.00
4C3CAB	2017-07-03 21:50:00+03	56600.00
4C3CB1	2017-07-04 19:36:00+03	46000.00
4C3CD3	2017-08-07 15:44:00+03	47200.00
4C3CEE	2017-08-12 18:34:00+03	56600.00
4C3D5B	2017-07-27 07:36:00+03	99200.00
4C3D9D	2017-08-12 23:18:00+03	60400.00
4C3DB8	2017-07-04 01:32:00+03	672600.00
4C3DD0	2017-07-27 16:48:00+03	294400.00
4C3DD1	2017-08-12 06:59:00+03	65300.00
4C3E2E	2017-08-10 21:17:00+03	112600.00
4C3E48	2017-07-14 05:55:00+03	178000.00
4C3E63	2017-07-25 15:56:00+03	47200.00
4C3ECE	2017-07-24 09:47:00+03	64800.00
4C3F07	2017-08-03 04:29:00+03	113200.00
4C3F46	2017-08-01 12:51:00+03	78300.00
4C3F56	2017-07-13 07:29:00+03	174400.00
4C3FC2	2017-07-26 13:15:00+03	202100.00
4C3FF5	2017-07-09 23:08:00+03	31400.00
4C400E	2017-07-17 11:27:00+03	41200.00
4C4026	2017-08-08 20:48:00+03	138500.00
4C4037	2017-07-11 20:04:00+03	46300.00
4C403C	2017-07-27 15:28:00+03	90600.00
4C4043	2017-06-30 14:47:00+03	81200.00
4C4088	2017-07-29 08:21:00+03	36800.00
4C408D	2017-07-12 00:07:00+03	27700.00
4C40C7	2017-07-03 11:25:00+03	325500.00
4C40E7	2017-08-01 04:16:00+03	19600.00
4C4102	2017-07-19 09:24:00+03	23600.00
4C4107	2017-07-16 19:05:00+03	84500.00
4C411B	2017-08-08 13:21:00+03	27700.00
4C4127	2017-08-03 09:04:00+03	84100.00
4C4131	2017-07-13 02:53:00+03	148300.00
4C417F	2017-07-26 12:55:00+03	13200.00
4C4200	2017-07-18 09:43:00+03	20200.00
4C4258	2017-07-15 18:10:00+03	46900.00
4C426B	2017-07-21 09:16:00+03	56600.00
4C42D4	2017-07-15 01:31:00+03	85000.00
4C42D5	2017-08-10 19:21:00+03	13800.00
4C42E1	2017-07-31 05:45:00+03	70600.00
4C4339	2017-07-14 00:24:00+03	13600.00
4C4435	2017-08-13 00:41:00+03	58600.00
4C4472	2017-07-12 09:10:00+03	139100.00
4C45EC	2017-07-27 12:58:00+03	66800.00
4C4634	2017-07-12 08:44:00+03	56600.00
4C4636	2017-07-01 12:58:00+03	16800.00
4C463C	2017-07-08 22:00:00+03	37900.00
4C466C	2017-07-17 14:19:00+03	22000.00
4C46B3	2017-07-23 10:02:00+03	23200.00
4C46F2	2017-07-10 23:57:00+03	139300.00
4C4717	2017-08-15 07:36:00+03	37700.00
4C4731	2017-08-04 18:12:00+03	75300.00
4C4773	2017-07-07 01:58:00+03	198400.00
4C4813	2017-08-08 01:35:00+03	411900.00
4C4818	2017-07-30 01:10:00+03	24400.00
4C4872	2017-07-19 07:56:00+03	265400.00
4C4878	2017-08-05 04:33:00+03	107800.00
4C48B8	2017-07-27 00:55:00+03	56600.00
4C48BA	2017-07-27 11:47:00+03	14000.00
4C48BF	2017-07-03 18:30:00+03	30900.00
4C48E1	2017-07-30 09:09:00+03	55800.00
4C491A	2017-08-08 07:31:00+03	19600.00
4C494D	2017-07-07 06:26:00+03	54400.00
4C4952	2017-08-12 20:00:00+03	13600.00
4C49AF	2017-08-10 19:50:00+03	87400.00
4C4A11	2017-08-05 10:17:00+03	11700.00
4C4ACE	2017-07-15 15:28:00+03	234700.00
4C4B70	2017-07-24 22:50:00+03	67300.00
4C4B8B	2017-08-02 07:16:00+03	44600.00
4C4BD2	2017-07-01 01:27:00+03	40000.00
4C4BE0	2017-07-08 05:24:00+03	37100.00
4C4BE7	2017-07-20 11:24:00+03	32800.00
4C4BF8	2017-07-22 12:08:00+03	61500.00
4C4C1C	2017-07-31 03:55:00+03	58700.00
4C4C57	2017-08-15 08:00:00+03	122300.00
4C4C61	2017-06-30 14:48:00+03	57500.00
4C4C86	2017-07-27 19:14:00+03	223200.00
4C4CAE	2017-07-08 16:18:00+03	155600.00
4C4CE5	2017-07-06 18:16:00+03	136200.00
4C4D20	2017-07-08 15:52:00+03	74800.00
4C4D9D	2017-07-31 07:46:00+03	136800.00
4C4DA2	2017-08-09 19:17:00+03	96800.00
4C4E01	2017-07-24 21:19:00+03	57600.00
4C4E11	2017-07-04 10:42:00+03	10800.00
4C4E67	2017-07-19 20:18:00+03	52000.00
4C4E7C	2017-07-14 13:04:00+03	28000.00
4C4EBA	2017-07-16 08:05:00+03	37200.00
4C4FCB	2017-06-30 02:45:00+03	151200.00
4C4FE7	2017-07-22 22:12:00+03	36400.00
4C4FFC	2017-08-09 22:44:00+03	133200.00
4C5001	2017-08-14 17:13:00+03	55100.00
4C5030	2017-08-09 04:58:00+03	119000.00
4C5031	2017-07-10 07:43:00+03	136100.00
4C507A	2017-07-15 00:07:00+03	6700.00
4C50A6	2017-07-22 15:49:00+03	77500.00
4C50E2	2017-07-02 11:32:00+03	258400.00
4C5148	2017-08-03 13:03:00+03	32700.00
4C514E	2017-08-01 23:34:00+03	33400.00
4C519D	2017-07-11 11:44:00+03	16000.00
4C51DD	2017-07-03 10:45:00+03	66600.00
4C51E0	2017-08-10 00:02:00+03	130400.00
4C51E6	2017-07-03 02:22:00+03	84500.00
4C5266	2017-07-22 12:19:00+03	72700.00
4C52A3	2017-08-03 06:50:00+03	39000.00
4C52D6	2017-07-26 04:14:00+03	12600.00
4C5307	2017-08-09 11:17:00+03	49100.00
4C5333	2017-06-30 22:17:00+03	64300.00
4C534C	2017-07-11 08:32:00+03	59200.00
4C539C	2017-08-09 00:46:00+03	64500.00
4C53B3	2017-08-07 17:51:00+03	54800.00
4C53CE	2017-08-06 21:59:00+03	28700.00
4C53FF	2017-07-20 20:54:00+03	83700.00
4C541B	2017-07-04 21:23:00+03	38400.00
4C5426	2017-07-20 12:33:00+03	64900.00
4C54AC	2017-08-10 03:42:00+03	113300.00
4C54D0	2017-07-29 21:22:00+03	70700.00
4C5619	2017-06-30 16:26:00+03	289300.00
4C566C	2017-07-06 18:48:00+03	52400.00
4C56B4	2017-07-07 17:11:00+03	125200.00
4C56C7	2017-07-03 01:55:00+03	133200.00
4C5751	2017-07-17 22:16:00+03	102100.00
4C57A6	2017-07-03 02:45:00+03	286100.00
4C5853	2017-07-08 15:36:00+03	61500.00
4C5894	2017-07-29 09:43:00+03	12600.00
4C5908	2017-07-20 20:00:00+03	96800.00
4C5930	2017-07-01 02:50:00+03	48700.00
4C599F	2017-07-27 16:41:00+03	240600.00
4C59AA	2017-07-28 14:30:00+03	46800.00
4C5A0A	2017-08-03 21:33:00+03	89500.00
4C5BFF	2017-07-18 22:57:00+03	68600.00
4C5C35	2017-07-29 13:51:00+03	73200.00
4C5CAA	2017-08-10 19:55:00+03	27900.00
4C5CD1	2017-07-10 17:59:00+03	68000.00
4C5D53	2017-07-14 13:06:00+03	23400.00
4C5D57	2017-08-07 23:51:00+03	42700.00
4C5D63	2017-08-13 12:50:00+03	28800.00
4C5DE1	2017-07-13 17:08:00+03	30200.00
4C5E05	2017-07-13 21:06:00+03	23400.00
4C5F92	2017-07-08 06:15:00+03	24300.00
4C5FC7	2017-08-12 02:09:00+03	13400.00
4C5FFB	2017-07-26 20:51:00+03	189100.00
4C608A	2017-07-24 14:43:00+03	59400.00
4C608E	2017-07-28 11:11:00+03	57800.00
4C60DF	2017-07-23 19:36:00+03	31600.00
4C60F1	2017-08-13 23:34:00+03	26600.00
4C60FE	2017-07-07 06:10:00+03	54000.00
4C6106	2017-07-25 12:34:00+03	119500.00
4C6176	2017-08-09 03:06:00+03	122400.00
4C61DA	2017-07-13 03:33:00+03	306600.00
4C620D	2017-07-11 08:51:00+03	46400.00
4C6246	2017-07-04 10:16:00+03	81300.00
4C6253	2017-07-05 01:35:00+03	18300.00
4C627B	2017-07-10 15:08:00+03	48400.00
4C62D5	2017-08-14 15:04:00+03	67600.00
4C6345	2017-07-24 17:15:00+03	90800.00
4C6349	2017-07-30 22:29:00+03	28800.00
4C6359	2017-08-11 08:44:00+03	13400.00
4C63C2	2017-07-06 01:05:00+03	126700.00
4C63CA	2017-07-13 00:05:00+03	148800.00
4C6402	2017-07-03 10:41:00+03	20400.00
4C6409	2017-08-02 04:01:00+03	6700.00
4C6415	2017-08-01 22:45:00+03	23400.00
4C64A4	2017-08-04 23:56:00+03	70500.00
4C657F	2017-07-17 12:34:00+03	54800.00
4C65C7	2017-07-12 05:09:00+03	84500.00
4C65CA	2017-07-17 10:32:00+03	88900.00
4C660D	2017-07-23 07:09:00+03	141600.00
4C6618	2017-08-05 12:57:00+03	52300.00
4C662B	2017-07-06 16:44:00+03	54600.00
4C66C4	2017-07-08 12:02:00+03	60400.00
4C66E3	2017-07-10 23:18:00+03	7400.00
4C670D	2017-07-28 12:17:00+03	44100.00
4C67AA	2017-07-15 23:29:00+03	33300.00
4C67BA	2017-07-19 10:35:00+03	55800.00
4C67C2	2017-07-30 08:22:00+03	135200.00
4C6809	2017-07-26 07:31:00+03	78600.00
4C6849	2017-08-08 14:27:00+03	198600.00
4C6851	2017-08-07 02:23:00+03	40000.00
4C685C	2017-07-17 15:07:00+03	62900.00
4C6860	2017-07-18 22:47:00+03	65500.00
4C686A	2017-08-11 05:11:00+03	22400.00
4C68C2	2017-07-01 01:20:00+03	28000.00
4C6970	2017-07-26 19:04:00+03	46000.00
4C69B6	2017-08-10 15:17:00+03	67200.00
4C69CB	2017-07-04 09:42:00+03	7400.00
4C6A72	2017-07-17 00:00:00+03	26000.00
4C6A82	2017-07-30 11:46:00+03	28600.00
4C6B3D	2017-07-26 12:53:00+03	42800.00
4C6B61	2017-08-07 02:39:00+03	102200.00
4C6B8B	2017-07-18 08:13:00+03	6000.00
4C6BC6	2017-07-30 16:57:00+03	19600.00
4C6BD6	2017-08-02 09:30:00+03	119400.00
4C6BD9	2017-08-01 22:02:00+03	11600.00
4C6C0B	2017-08-08 15:54:00+03	75300.00
4C6C0D	2017-07-23 22:31:00+03	46200.00
4C6C69	2017-08-05 18:25:00+03	28000.00
4C6C83	2017-08-07 09:17:00+03	6000.00
4C6D2E	2017-07-20 00:41:00+03	205500.00
4C6D9A	2017-07-10 17:18:00+03	75300.00
4C6DA6	2017-07-26 22:52:00+03	44800.00
4C6E3E	2017-07-07 10:52:00+03	46400.00
4C6ED4	2017-07-12 15:50:00+03	8400.00
4C6F20	2017-08-09 23:49:00+03	28800.00
4C6FB9	2017-08-06 18:37:00+03	70700.00
4C7094	2017-07-20 18:40:00+03	11800.00
4C70D7	2017-07-30 09:15:00+03	342400.00
4C7145	2017-08-03 05:18:00+03	301500.00
4C714C	2017-07-13 06:52:00+03	6700.00
4C716D	2017-07-07 18:52:00+03	15400.00
4C7173	2017-07-11 18:28:00+03	85000.00
4C7185	2017-07-05 08:49:00+03	123000.00
4C7189	2017-07-06 10:11:00+03	20200.00
4C71CE	2017-08-14 22:31:00+03	57600.00
4C7212	2017-08-13 06:15:00+03	13400.00
4C7264	2017-07-15 01:06:00+03	21400.00
4C72C5	2017-08-06 17:30:00+03	46000.00
4C734D	2017-07-18 05:24:00+03	55800.00
4C7362	2017-07-25 16:00:00+03	148200.00
4C7374	2017-08-04 23:00:00+03	49600.00
4C73CE	2017-08-06 01:15:00+03	32400.00
4C742F	2017-07-31 16:56:00+03	56000.00
4C7487	2017-08-10 21:47:00+03	27900.00
4C7494	2017-08-09 09:21:00+03	88000.00
4C74AF	2017-06-28 06:20:00+03	30200.00
4C756C	2017-08-05 05:26:00+03	77000.00
4C75B2	2017-08-07 20:08:00+03	185800.00
4C75DC	2017-07-07 21:09:00+03	25200.00
4C7602	2017-08-07 07:47:00+03	91300.00
4C764B	2017-07-19 20:45:00+03	133200.00
4C764E	2017-07-18 18:10:00+03	75300.00
4C76C2	2017-07-01 17:14:00+03	71600.00
4C76E4	2017-08-12 16:08:00+03	68400.00
4C76EC	2017-07-24 13:26:00+03	67300.00
4C7786	2017-07-17 04:17:00+03	123000.00
4C7859	2017-08-10 19:20:00+03	38600.00
4C787C	2017-07-30 13:05:00+03	28800.00
4C78C8	2017-07-26 20:51:00+03	20200.00
4C78CD	2017-08-13 15:52:00+03	66000.00
4C792D	2017-08-01 07:12:00+03	135400.00
4C7941	2017-07-21 20:22:00+03	12400.00
4C7959	2017-08-13 20:52:00+03	136800.00
4C795B	2017-08-09 15:31:00+03	16400.00
4C79D3	2017-07-07 08:02:00+03	12600.00
4C79DD	2017-07-15 04:27:00+03	283100.00
4C79F0	2017-07-13 23:03:00+03	75700.00
4C79F3	2017-07-04 23:37:00+03	46800.00
4C7A49	2017-07-08 09:14:00+03	111700.00
4C7A5B	2017-07-01 03:03:00+03	292400.00
4C7A73	2017-07-14 22:58:00+03	196800.00
4C7B83	2017-08-06 14:16:00+03	14000.00
4C7BDC	2017-08-02 03:14:00+03	52000.00
4C7C06	2017-07-21 05:35:00+03	58400.00
4C7C30	2017-08-12 17:17:00+03	66800.00
4C7C71	2017-07-09 10:35:00+03	139200.00
4C7D31	2017-08-06 09:42:00+03	26000.00
4C7D4B	2017-07-24 19:57:00+03	130400.00
4C7D4E	2017-07-18 17:49:00+03	48300.00
4C7D6C	2017-08-06 00:12:00+03	92000.00
4C7DB1	2017-08-07 18:12:00+03	137400.00
4C7DD7	2017-07-15 02:10:00+03	81300.00
4C7E0D	2017-08-15 06:44:00+03	52800.00
4C7E52	2017-08-10 02:55:00+03	133200.00
4C7EA0	2017-07-22 03:07:00+03	111000.00
4C7ED5	2017-07-29 09:51:00+03	84500.00
4C7F36	2017-07-11 07:16:00+03	142300.00
4C7F5D	2017-07-07 10:17:00+03	95200.00
4C7F68	2017-07-25 15:50:00+03	66600.00
4C7F6A	2017-08-15 06:09:00+03	56000.00
4C8002	2017-07-27 16:00:00+03	88400.00
4C803B	2017-08-05 19:40:00+03	59400.00
4C81C4	2017-07-05 17:26:00+03	25600.00
4C81EF	2017-07-29 23:42:00+03	41800.00
4C8222	2017-07-10 13:12:00+03	6700.00
4C824D	2017-07-12 04:10:00+03	45200.00
4C82CF	2017-08-10 09:45:00+03	50600.00
4C834F	2017-07-16 03:39:00+03	29600.00
4C8358	2017-08-12 19:05:00+03	60000.00
4C836E	2017-08-11 08:32:00+03	80000.00
4C83AA	2017-08-10 00:37:00+03	6700.00
4C8416	2017-08-15 01:26:00+03	48000.00
4C8464	2017-08-11 04:14:00+03	27200.00
4C8469	2017-08-11 03:52:00+03	59800.00
4C848D	2017-07-25 20:09:00+03	50300.00
4C84DF	2017-07-23 22:52:00+03	112000.00
4C84F9	2017-07-02 17:14:00+03	99200.00
4C8509	2017-07-06 11:05:00+03	56000.00
4C851E	2017-07-24 05:18:00+03	23400.00
4C852A	2017-08-12 08:45:00+03	123000.00
4C85C8	2017-08-15 09:23:00+03	66000.00
4C8665	2017-08-14 09:03:00+03	13400.00
4C8673	2017-07-12 08:19:00+03	38600.00
4C86AE	2017-07-22 02:16:00+03	65400.00
4C86E0	2017-08-11 00:47:00+03	39100.00
4C873F	2017-07-25 08:04:00+03	246000.00
4C8788	2017-08-08 22:50:00+03	64900.00
4C878F	2017-07-10 09:20:00+03	6800.00
4C888C	2017-07-01 23:16:00+03	6300.00
4C8895	2017-07-21 16:07:00+03	44800.00
4C889D	2017-07-19 14:07:00+03	68400.00
4C890A	2017-07-24 19:42:00+03	107000.00
4C8956	2017-08-12 17:07:00+03	32800.00
4C89A0	2017-07-03 13:07:00+03	17200.00
4C8A08	2017-07-25 23:58:00+03	59800.00
4C8A50	2017-08-09 03:52:00+03	23400.00
4C8A5C	2017-08-13 02:44:00+03	185300.00
4C8A92	2017-08-07 08:17:00+03	8200.00
4C8AA4	2017-07-08 23:21:00+03	13800.00
4C8B00	2017-08-10 03:43:00+03	35400.00
4C8B22	2017-07-05 21:43:00+03	24000.00
4C8C37	2017-06-26 16:46:00+03	48500.00
4C8C60	2017-07-06 00:38:00+03	136800.00
4C8CB8	2017-08-03 20:43:00+03	55000.00
4C8D3E	2017-08-10 17:52:00+03	8200.00
4C8E2C	2017-07-13 19:07:00+03	6600.00
4C8E40	2017-08-12 12:00:00+03	95700.00
4C8E86	2017-08-08 16:49:00+03	53600.00
4C8E9B	2017-07-03 23:31:00+03	54800.00
4C8EBB	2017-07-25 03:50:00+03	75600.00
4C8ECE	2017-08-14 15:43:00+03	56600.00
4C8ED0	2017-07-18 06:06:00+03	77900.00
4C8EF0	2017-07-14 23:33:00+03	27500.00
4C8EF1	2017-07-10 18:08:00+03	243600.00
4C8F62	2017-07-15 21:31:00+03	51800.00
4C8F63	2017-07-12 04:49:00+03	45600.00
4C8F6F	2017-07-16 11:13:00+03	62200.00
4C8FC5	2017-07-15 09:15:00+03	133100.00
4C8FE1	2017-07-10 04:25:00+03	30000.00
4C8FE3	2017-07-19 23:31:00+03	24000.00
4C9036	2017-07-13 05:46:00+03	32700.00
4C9043	2017-07-12 21:25:00+03	131600.00
4C9114	2017-06-28 03:24:00+03	131100.00
4C916B	2017-08-09 02:52:00+03	398600.00
4C9278	2017-08-04 15:38:00+03	9200.00
4C928F	2017-08-14 22:43:00+03	129200.00
4C92A1	2017-07-31 05:55:00+03	26800.00
4C92BB	2017-08-14 10:34:00+03	40100.00
4C92C2	2017-07-25 00:09:00+03	25200.00
4C92EF	2017-07-25 20:29:00+03	138400.00
4C9302	2017-07-19 10:49:00+03	34000.00
4C9316	2017-07-19 04:33:00+03	16400.00
4C932F	2017-07-06 21:05:00+03	27400.00
4C9364	2017-07-22 12:43:00+03	58800.00
4C9379	2017-07-20 23:51:00+03	46000.00
4C937F	2017-07-15 06:28:00+03	22600.00
4C9384	2017-08-05 01:21:00+03	14800.00
4C93E7	2017-07-28 17:23:00+03	69600.00
4C9416	2017-07-22 02:56:00+03	236000.00
4C9428	2017-07-04 15:05:00+03	13400.00
4C9450	2017-08-15 09:21:00+03	28800.00
4C9453	2017-08-06 16:22:00+03	170500.00
4C9461	2017-06-30 07:02:00+03	69600.00
4C949D	2017-08-13 19:02:00+03	49900.00
4C9505	2017-07-03 08:11:00+03	112000.00
4C952D	2017-07-17 21:33:00+03	40800.00
4C9556	2017-07-31 09:02:00+03	26000.00
4C95AB	2017-08-07 13:36:00+03	79900.00
4C95B1	2017-07-13 13:51:00+03	12000.00
4C95F1	2017-08-11 06:22:00+03	58200.00
4C9660	2017-07-30 09:19:00+03	6600.00
4C9719	2017-08-11 14:48:00+03	12600.00
4C973F	2017-06-29 02:59:00+03	66000.00
4C979E	2017-07-29 10:45:00+03	81900.00
4C97DB	2017-07-23 10:46:00+03	63200.00
4C98B4	2017-08-11 23:08:00+03	49800.00
4C98F4	2017-08-02 13:27:00+03	131600.00
4C9908	2017-07-24 08:01:00+03	6700.00
4C99F7	2017-07-08 22:22:00+03	37900.00
4C9A02	2017-07-02 13:10:00+03	32800.00
4C9A17	2017-07-31 13:11:00+03	13000.00
4C9A1B	2017-07-23 22:10:00+03	72200.00
4C9B96	2017-07-13 23:42:00+03	92400.00
4C9B9B	2017-07-11 12:56:00+03	44600.00
4C9BBD	2017-07-10 04:38:00+03	28000.00
4C9BE6	2017-07-07 07:57:00+03	62000.00
4C9BEC	2017-07-13 03:21:00+03	18000.00
4C9C0F	2017-08-15 09:47:00+03	73600.00
4C9C17	2017-06-28 03:09:00+03	16400.00
4C9C64	2017-08-04 20:47:00+03	86300.00
4C9CAA	2017-07-13 16:18:00+03	184000.00
4C9CF1	2017-07-31 05:30:00+03	42400.00
4C9CF2	2017-07-17 16:28:00+03	283600.00
4C9DB6	2017-07-24 15:34:00+03	266400.00
4C9E10	2017-06-30 21:24:00+03	6800.00
4C9E14	2017-07-22 08:34:00+03	61800.00
4C9E84	2017-07-14 03:14:00+03	28000.00
4C9E8B	2017-07-01 16:21:00+03	187100.00
4C9F11	2017-08-08 12:53:00+03	38600.00
4C9F14	2017-07-22 11:08:00+03	110100.00
4C9F49	2017-07-12 09:04:00+03	35300.00
4C9FA3	2017-07-14 18:18:00+03	111600.00
4C9FC3	2017-07-28 00:52:00+03	119600.00
4CA00A	2017-07-02 18:32:00+03	79900.00
4CA0AE	2017-07-19 05:07:00+03	25600.00
4CA0CF	2017-07-16 08:44:00+03	26700.00
4CA0FD	2017-08-09 23:57:00+03	49500.00
4CA15B	2017-07-28 03:02:00+03	133200.00
4CA2A1	2017-07-28 08:18:00+03	40600.00
4CA2BD	2017-07-06 13:33:00+03	113800.00
4CA2C2	2017-07-18 01:17:00+03	182300.00
4CA2C6	2017-07-28 11:19:00+03	273100.00
4CA2D7	2017-07-17 03:23:00+03	60400.00
4CA2E1	2017-07-10 16:51:00+03	66600.00
4CA39C	2017-07-19 12:43:00+03	36200.00
4CA3B8	2017-07-30 18:58:00+03	26000.00
4CA3D9	2017-07-08 14:11:00+03	56000.00
4CA41A	2017-08-13 17:51:00+03	148200.00
4CA41F	2017-07-15 16:19:00+03	101800.00
4CA44F	2017-07-01 13:23:00+03	115700.00
4CA495	2017-08-05 07:05:00+03	66000.00
4CA49D	2017-07-04 18:53:00+03	59900.00
4CA49E	2017-08-09 14:02:00+03	61800.00
4CA52F	2017-08-08 15:41:00+03	24200.00
4CA569	2017-07-29 03:41:00+03	62000.00
4CA6AB	2017-07-05 09:43:00+03	55000.00
4CA795	2017-07-08 03:52:00+03	61700.00
4CA7C1	2017-07-15 19:12:00+03	75200.00
4CA7CA	2017-08-14 07:16:00+03	38000.00
4CA7DC	2017-08-03 12:54:00+03	40000.00
4CA7E3	2017-07-27 07:37:00+03	119500.00
4CA7F2	2017-08-09 22:11:00+03	60700.00
4CA810	2017-07-11 19:31:00+03	28000.00
4CA83D	2017-08-10 17:29:00+03	176400.00
4CA845	2017-07-12 10:56:00+03	125400.00
4CA877	2017-07-02 19:06:00+03	46300.00
4CA8E5	2017-07-11 09:43:00+03	113700.00
4CA8EF	2017-07-15 07:54:00+03	155600.00
4CA8F1	2017-07-24 20:02:00+03	210000.00
4CA976	2017-07-11 18:39:00+03	28800.00
4CA994	2017-08-10 08:29:00+03	27600.00
4CA9FE	2017-07-19 15:57:00+03	98400.00
4CAA66	2017-07-28 09:47:00+03	12000.00
4CAAFB	2017-07-10 16:21:00+03	68800.00
4CAB0C	2017-07-17 06:34:00+03	37200.00
4CAB0F	2017-07-11 00:10:00+03	16400.00
4CAB1C	2017-07-14 18:39:00+03	88200.00
4CAB35	2017-08-05 23:14:00+03	84100.00
4CAB5D	2017-08-01 12:47:00+03	26000.00
4CABBC	2017-07-09 23:10:00+03	79600.00
4CAC5A	2017-08-13 14:22:00+03	27200.00
4CAC5B	2017-07-06 16:01:00+03	123000.00
4CACD5	2017-08-15 10:07:00+03	25100.00
4CAD0B	2017-07-31 23:17:00+03	44400.00
4CAD17	2017-07-09 07:07:00+03	115900.00
4CAD77	2017-07-15 19:20:00+03	19600.00
4CADBA	2017-07-29 15:16:00+03	55800.00
4CADBF	2017-07-04 08:58:00+03	70800.00
4CAE68	2017-08-08 19:38:00+03	31500.00
4CAE6A	2017-07-11 03:02:00+03	33100.00
4CAEA0	2017-07-19 23:54:00+03	135600.00
4CAEA2	2017-08-09 21:47:00+03	184300.00
4CAEA9	2017-07-15 08:37:00+03	21600.00
4CAED5	2017-08-10 06:54:00+03	81600.00
4CAEF4	2017-07-16 00:34:00+03	103400.00
4CAF00	2017-08-13 00:53:00+03	61400.00
4CAF0B	2017-07-16 15:28:00+03	7400.00
4CAF4B	2017-07-23 08:51:00+03	99300.00
4CAFCA	2017-07-17 15:46:00+03	39500.00
4CB18D	2017-07-07 06:33:00+03	284400.00
4CB1C7	2017-08-11 03:28:00+03	173500.00
4CB261	2017-07-06 06:54:00+03	42100.00
4CB26B	2017-08-03 02:24:00+03	27300.00
4CB299	2017-08-06 07:49:00+03	31800.00
4CB2A2	2017-07-27 10:13:00+03	49800.00
4CB2A6	2017-07-23 01:13:00+03	40000.00
4CB2DB	2017-07-05 12:22:00+03	41800.00
4CB2F0	2017-07-17 19:56:00+03	49100.00
4CB325	2017-07-17 20:56:00+03	95700.00
4CB33F	2017-06-29 00:53:00+03	58400.00
4CB35D	2017-08-13 19:54:00+03	26000.00
4CB3D5	2017-07-06 19:07:00+03	108200.00
4CB3D6	2017-06-29 13:59:00+03	19800.00
4CB3D7	2017-07-27 09:49:00+03	6800.00
4CB48D	2017-07-12 09:04:00+03	405200.00
4CB493	2017-07-22 11:18:00+03	12600.00
4CB52C	2017-08-09 17:08:00+03	99700.00
4CB5CB	2017-08-09 09:07:00+03	56900.00
4CB609	2017-08-15 12:03:00+03	23200.00
4CB659	2017-06-26 09:44:00+03	31600.00
4CB6B3	2017-07-20 11:42:00+03	51900.00
4CB6C9	2017-08-06 07:09:00+03	55000.00
4CB6CD	2017-07-15 23:41:00+03	30800.00
4CB6FE	2017-07-21 14:06:00+03	84100.00
4CB774	2017-08-07 17:36:00+03	99300.00
4CB77C	2017-08-12 21:09:00+03	89600.00
4CB797	2017-08-08 02:13:00+03	92800.00
4CB807	2017-07-07 02:17:00+03	24400.00
4CB812	2017-07-30 00:30:00+03	112000.00
4CB871	2017-08-07 20:08:00+03	51300.00
4CB889	2017-07-14 03:13:00+03	32700.00
4CB8C0	2017-08-06 08:06:00+03	28800.00
4CB908	2017-07-31 00:53:00+03	74800.00
4CB978	2017-07-26 13:38:00+03	14400.00
4CB9A5	2017-07-19 14:47:00+03	56000.00
4CBA16	2017-07-30 21:49:00+03	21400.00
4CBA23	2017-07-01 02:19:00+03	91500.00
4CBA4B	2017-08-09 09:37:00+03	110900.00
4CBA56	2017-07-21 05:01:00+03	25600.00
4CBA6B	2017-08-01 04:41:00+03	37200.00
4CBA8E	2017-07-16 03:12:00+03	8200.00
4CBB26	2017-08-11 21:05:00+03	57700.00
4CBBF3	2017-08-13 20:43:00+03	56000.00
4CBC07	2017-07-05 09:05:00+03	44800.00
4CBC33	2017-07-12 23:39:00+03	112000.00
4CBC4A	2017-07-02 06:13:00+03	136200.00
4CBC6B	2017-07-18 06:39:00+03	26000.00
4CBCA6	2017-08-06 18:59:00+03	32200.00
4CBCC9	2017-08-13 03:40:00+03	114400.00
4CBCDD	2017-08-01 07:48:00+03	46700.00
4CBCFA	2017-08-14 04:27:00+03	48800.00
4CBD01	2017-07-17 07:04:00+03	44000.00
4CBD12	2017-07-26 12:31:00+03	12400.00
4CBD21	2017-07-17 15:59:00+03	7400.00
4CBD25	2017-08-15 01:31:00+03	12000.00
4CBD48	2017-08-04 07:34:00+03	11600.00
4CBD93	2017-07-17 18:09:00+03	111600.00
4CBDD7	2017-08-15 17:22:00+03	28800.00
4CBDE9	2017-07-29 00:01:00+03	8000.00
4CBE56	2017-08-10 14:28:00+03	128800.00
4CBEE2	2017-08-05 11:19:00+03	59800.00
4CBF16	2017-07-25 10:11:00+03	68800.00
4CBF40	2017-08-05 19:27:00+03	12000.00
4CBFA6	2017-07-05 16:51:00+03	93900.00
4CBFE3	2017-08-04 15:30:00+03	224100.00
4CC10D	2017-07-18 15:22:00+03	70000.00
4CC116	2017-08-01 03:39:00+03	39800.00
4CC126	2017-07-11 20:15:00+03	43000.00
4CC12E	2017-07-25 03:37:00+03	111600.00
4CC147	2017-07-30 08:06:00+03	31600.00
4CC1E8	2017-08-11 10:06:00+03	406700.00
4CC1FB	2017-07-22 22:13:00+03	58500.00
4CC2DE	2017-07-04 22:37:00+03	73500.00
4CC376	2017-08-10 06:43:00+03	166000.00
4CC3D7	2017-06-27 20:48:00+03	59200.00
4CC3EA	2017-07-13 08:25:00+03	26800.00
4CC464	2017-07-29 04:23:00+03	135600.00
4CC49F	2017-06-27 01:46:00+03	147700.00
4CC4CB	2017-08-02 01:39:00+03	13400.00
4CC4CC	2017-07-14 08:49:00+03	25900.00
4CC55B	2017-07-06 01:58:00+03	189800.00
4CC56A	2017-07-05 14:58:00+03	44600.00
4CC64E	2017-08-08 07:02:00+03	24200.00
4CC6AB	2017-07-30 02:13:00+03	11000.00
4CC6D2	2017-08-12 06:01:00+03	246000.00
4CC710	2017-07-16 10:00:00+03	68400.00
4CC730	2017-08-06 08:35:00+03	73500.00
4CC757	2017-07-06 00:28:00+03	55600.00
4CC75F	2017-07-25 08:02:00+03	26000.00
4CC777	2017-07-27 16:42:00+03	20900.00
4CC791	2017-07-22 22:26:00+03	22600.00
4CC7E1	2017-07-26 01:22:00+03	229600.00
4CC7EB	2017-07-30 04:01:00+03	51300.00
4CC809	2017-08-13 19:38:00+03	47200.00
4CC8AF	2017-07-17 16:07:00+03	6800.00
4CC981	2017-07-06 08:54:00+03	93900.00
4CC9CA	2017-08-04 06:51:00+03	30200.00
4CCA0E	2017-08-02 11:59:00+03	56200.00
4CCA10	2017-07-24 03:36:00+03	248300.00
4CCA6E	2017-07-11 16:18:00+03	110600.00
4CCA85	2017-07-13 22:16:00+03	29200.00
4CCAE5	2017-08-07 14:59:00+03	47400.00
4CCB48	2017-07-05 07:32:00+03	37100.00
4CCB74	2017-07-25 14:59:00+03	133200.00
4CCB9C	2017-07-11 00:18:00+03	34100.00
4CCBA8	2017-08-12 23:47:00+03	36900.00
4CCBB2	2017-07-06 16:41:00+03	6000.00
4CCBE7	2017-08-02 05:12:00+03	64600.00
4CCC6C	2017-07-30 15:38:00+03	92000.00
4CCCCA	2017-07-13 07:00:00+03	66800.00
4CCD23	2017-07-13 18:57:00+03	193700.00
4CCDBA	2017-07-08 03:32:00+03	83300.00
4CCDF9	2017-07-23 09:12:00+03	68800.00
4CCE1F	2017-08-08 05:51:00+03	43700.00
4CCE92	2017-07-16 04:26:00+03	46700.00
4CCEAC	2017-07-02 12:28:00+03	71200.00
4CCEF3	2017-08-14 13:45:00+03	44800.00
4CCF24	2017-07-30 19:08:00+03	24400.00
4CCF4D	2017-07-18 13:02:00+03	92400.00
4CCF63	2017-07-22 16:31:00+03	85000.00
4CCF87	2017-07-17 10:09:00+03	15000.00
4CCFBC	2017-07-11 16:37:00+03	18800.00
4CCFDF	2017-07-13 06:00:00+03	14400.00
4CD087	2017-08-02 06:56:00+03	71500.00
4CD0AB	2017-08-10 11:59:00+03	118000.00
4CD101	2017-07-16 00:37:00+03	43600.00
4CD156	2017-07-26 06:13:00+03	195900.00
4CD15B	2017-07-18 20:04:00+03	46400.00
4CD21A	2017-07-29 02:26:00+03	185500.00
4CD26A	2017-07-31 09:39:00+03	18700.00
4CD2D2	2017-07-09 01:56:00+03	129700.00
4CD2D6	2017-07-09 21:15:00+03	162700.00
4CD322	2017-07-22 15:15:00+03	6000.00
4CD3AA	2017-08-10 00:15:00+03	386300.00
4CD3AE	2017-07-28 12:44:00+03	10100.00
4CD3CD	2017-07-06 04:02:00+03	46400.00
4CD3DE	2017-07-20 12:20:00+03	7900.00
4CD410	2017-08-03 18:27:00+03	52000.00
4CD504	2017-08-12 11:40:00+03	152200.00
4CD52E	2017-07-08 21:46:00+03	13400.00
4CD560	2017-06-28 04:05:00+03	40400.00
4CD5CF	2017-08-05 12:50:00+03	399600.00
4CD5E1	2017-07-23 02:04:00+03	133200.00
4CD609	2017-07-10 16:42:00+03	38600.00
4CD633	2017-07-02 15:06:00+03	83700.00
4CD69E	2017-07-31 09:24:00+03	23400.00
4CD6CF	2017-07-26 19:02:00+03	46400.00
4CD743	2017-08-03 04:25:00+03	23200.00
4CD95E	2017-07-29 07:50:00+03	46300.00
4CD96B	2017-08-09 07:18:00+03	27900.00
4CD9FE	2017-08-06 10:26:00+03	86300.00
4CDA03	2017-08-11 21:23:00+03	19600.00
4CDA07	2017-07-03 02:59:00+03	48800.00
4CDA18	2017-07-14 08:35:00+03	9800.00
4CDA31	2017-07-10 14:46:00+03	19600.00
4CDA3C	2017-07-13 03:47:00+03	100600.00
4CDABD	2017-07-05 13:07:00+03	131600.00
4CDADE	2017-08-14 12:48:00+03	68400.00
4CDAF3	2017-08-04 15:21:00+03	16400.00
4CDAFF	2017-08-15 02:09:00+03	117100.00
4CDB8F	2017-07-17 16:11:00+03	18100.00
4CDC69	2017-08-07 02:58:00+03	223200.00
4CDC7A	2017-07-21 10:54:00+03	211600.00
4CDC9D	2017-07-31 21:35:00+03	7300.00
4CDD39	2017-08-15 15:46:00+03	103900.00
4CDD3C	2017-08-14 07:38:00+03	26000.00
4CDDE5	2017-07-11 06:26:00+03	37200.00
4CDE00	2017-07-08 19:16:00+03	12400.00
4CDE38	2017-07-11 20:33:00+03	114300.00
4CDE84	2017-07-03 22:15:00+03	28600.00
4CDEA9	2017-08-12 00:37:00+03	109800.00
4CDF09	2017-07-12 04:28:00+03	7400.00
4CDF14	2017-08-03 11:46:00+03	77700.00
4CDF21	2017-06-28 06:31:00+03	41600.00
4CDF27	2017-07-07 13:11:00+03	46200.00
4CDF65	2017-08-13 20:28:00+03	154000.00
4CDFAA	2017-08-15 06:38:00+03	10800.00
4CDFC2	2017-07-23 01:10:00+03	189000.00
4CDFC6	2017-07-31 13:56:00+03	35600.00
4CDFDF	2017-08-04 18:39:00+03	44000.00
4CDFF3	2017-07-17 12:50:00+03	43600.00
4CE02E	2017-06-29 23:19:00+03	134700.00
4CE04E	2017-08-04 05:25:00+03	95600.00
4CE054	2017-07-06 19:18:00+03	56000.00
4CE07A	2017-07-06 13:30:00+03	99200.00
4CE0D1	2017-07-26 16:32:00+03	67600.00
4CE0FE	2017-08-07 23:11:00+03	135400.00
4CE118	2017-07-10 21:31:00+03	56000.00
4CE162	2017-07-17 01:26:00+03	20400.00
4CE197	2017-08-10 19:13:00+03	168000.00
4CE21C	2017-07-21 13:06:00+03	149300.00
4CE228	2017-07-15 01:27:00+03	66200.00
4CE235	2017-08-11 11:01:00+03	58200.00
4CE2AB	2017-07-18 04:06:00+03	29500.00
4CE34C	2017-06-28 03:43:00+03	81700.00
4CE45E	2017-08-09 18:27:00+03	24500.00
4CE482	2017-07-03 18:04:00+03	58600.00
4CE4A0	2017-07-19 01:14:00+03	45200.00
4CE4AF	2017-07-10 14:11:00+03	123000.00
4CE4EE	2017-07-06 00:21:00+03	28800.00
4CE537	2017-07-22 01:39:00+03	68600.00
4CE590	2017-08-11 07:13:00+03	29000.00
4CE5EA	2017-07-16 08:27:00+03	14400.00
4CE620	2017-08-13 23:20:00+03	56600.00
4CE63D	2017-07-01 08:32:00+03	30200.00
4CE6A4	2017-08-09 12:50:00+03	23600.00
4CE700	2017-08-09 02:30:00+03	28000.00
4CE735	2017-07-25 20:19:00+03	111600.00
4CE75A	2017-08-02 00:20:00+03	201800.00
4CE76E	2017-08-15 11:23:00+03	38200.00
4CE782	2017-07-08 23:09:00+03	35200.00
4CE7A5	2017-07-04 19:47:00+03	125200.00
4CE7C2	2017-07-31 18:17:00+03	26000.00
4CE7E6	2017-07-02 01:16:00+03	131100.00
4CE822	2017-08-14 03:31:00+03	61800.00
4CE829	2017-07-26 04:37:00+03	50800.00
4CE88D	2017-07-16 01:21:00+03	74300.00
4CE88F	2017-07-18 20:57:00+03	151200.00
4CE8A5	2017-07-31 10:49:00+03	246000.00
4CE8C0	2017-07-13 16:03:00+03	45000.00
4CE8C6	2017-08-03 10:47:00+03	32800.00
4CE92C	2017-07-23 02:21:00+03	55800.00
4CE94D	2017-08-01 18:55:00+03	531400.00
4CE9AA	2017-07-19 08:54:00+03	15400.00
4CE9EF	2017-08-13 08:29:00+03	133200.00
4CEA23	2017-07-29 22:26:00+03	273800.00
4CEA37	2017-07-22 05:20:00+03	67400.00
4CEA96	2017-08-15 01:19:00+03	73500.00
4CEB0E	2017-08-05 13:23:00+03	13400.00
4CEB12	2017-07-15 18:27:00+03	542300.00
4CEB45	2017-07-10 12:15:00+03	40800.00
4CEBE9	2017-07-24 18:07:00+03	16400.00
4CEBFC	2017-07-10 18:29:00+03	29600.00
4CEC33	2017-08-10 10:55:00+03	34600.00
4CEC80	2017-07-17 03:53:00+03	16000.00
4CECAE	2017-08-08 11:17:00+03	52000.00
4CECBB	2017-08-11 09:14:00+03	44800.00
4CECC0	2017-07-15 09:49:00+03	119700.00
4CECD5	2017-07-09 16:56:00+03	17800.00
4CECDF	2017-07-18 22:40:00+03	13000.00
4CECFB	2017-07-04 04:00:00+03	43000.00
4CED36	2017-08-02 18:19:00+03	44400.00
4CED3D	2017-07-29 14:15:00+03	12600.00
4CED50	2017-08-12 19:58:00+03	111600.00
4CED69	2017-08-10 20:14:00+03	50200.00
4CED9F	2017-08-11 13:10:00+03	47400.00
4CEDBD	2017-07-24 10:43:00+03	37900.00
4CEDFC	2017-08-15 12:41:00+03	46400.00
4CEE33	2017-07-18 14:20:00+03	86600.00
4CEE3F	2017-08-09 21:03:00+03	136800.00
4CEE66	2017-08-09 08:37:00+03	67400.00
4CEE91	2017-08-13 07:10:00+03	37200.00
4CEF8C	2017-07-18 08:07:00+03	46900.00
4CEF98	2017-07-16 21:47:00+03	188000.00
4CEFAD	2017-08-02 00:58:00+03	47700.00
4CEFAF	2017-07-10 15:08:00+03	135600.00
4CEFBE	2017-08-06 14:26:00+03	124800.00
4CEFC2	2017-07-13 05:33:00+03	80600.00
4CEFDF	2017-08-01 04:43:00+03	25100.00
4CEFE0	2017-07-07 17:47:00+03	16400.00
4CF004	2017-07-29 19:34:00+03	271100.00
4CF04E	2017-08-10 16:54:00+03	29600.00
4CF077	2017-08-14 19:08:00+03	47400.00
4CF08A	2017-08-05 03:02:00+03	28800.00
4CF0D0	2017-06-30 09:13:00+03	79300.00
4CF157	2017-07-28 18:50:00+03	120700.00
4CF18A	2017-08-12 15:12:00+03	95400.00
4CF1EB	2017-08-09 07:04:00+03	23200.00
4CF21B	2017-07-31 12:41:00+03	90000.00
4CF21F	2017-07-03 20:33:00+03	42800.00
4CF247	2017-07-22 02:34:00+03	149500.00
4CF251	2017-07-07 13:32:00+03	36200.00
4CF274	2017-07-22 07:16:00+03	40800.00
4CF279	2017-07-05 00:30:00+03	55900.00
4CF28D	2017-07-28 11:23:00+03	65900.00
4CF2A3	2017-07-17 00:11:00+03	26800.00
4CF2ED	2017-07-27 21:25:00+03	89600.00
4CF2FB	2017-07-06 10:47:00+03	14400.00
4CF30A	2017-07-18 06:50:00+03	293900.00
4CF367	2017-07-03 17:29:00+03	23200.00
4CF3C3	2017-08-12 10:23:00+03	24000.00
4CF3F6	2017-08-03 01:28:00+03	56600.00
4CF401	2017-07-24 09:17:00+03	140800.00
4CF424	2017-08-04 09:11:00+03	40800.00
4CF430	2017-07-21 15:10:00+03	415200.00
4CF436	2017-07-26 16:46:00+03	40000.00
4CF4A4	2017-07-15 04:18:00+03	83000.00
4CF4D8	2017-08-01 17:41:00+03	435400.00
4CF4EE	2017-07-14 11:42:00+03	13400.00
4CF52A	2017-07-16 21:08:00+03	20000.00
4CF547	2017-06-28 10:20:00+03	85400.00
4CF585	2017-08-01 13:29:00+03	47100.00
4CF5C5	2017-08-04 03:29:00+03	37800.00
4CF61F	2017-08-08 03:41:00+03	67100.00
4CF62D	2017-08-14 13:04:00+03	55100.00
4CF6C5	2017-08-10 19:25:00+03	111600.00
4CF6D3	2017-07-22 15:46:00+03	56000.00
4CF6F9	2017-07-24 10:17:00+03	31100.00
4CF71F	2017-07-23 14:33:00+03	73500.00
4CF72E	2017-07-26 03:24:00+03	135400.00
4CF764	2017-08-10 08:36:00+03	100400.00
4CF7B8	2017-08-07 02:54:00+03	80700.00
4CF816	2017-07-12 07:38:00+03	97500.00
4CF83C	2017-07-19 01:57:00+03	23600.00
4CF8AB	2017-08-10 22:41:00+03	56000.00
4CF8AC	2017-07-20 15:54:00+03	56600.00
4CF8BB	2017-07-14 04:31:00+03	48500.00
4CF9B8	2017-07-16 08:06:00+03	60700.00
4CF9E2	2017-07-22 09:48:00+03	64500.00
4CFA1E	2017-07-06 22:24:00+03	181100.00
4CFAA8	2017-08-06 15:57:00+03	31600.00
4CFADC	2017-07-16 13:31:00+03	60400.00
4CFAF6	2017-08-03 23:20:00+03	35600.00
4CFB99	2017-08-14 15:13:00+03	56900.00
4CFBD8	2017-08-10 13:10:00+03	166100.00
4CFC05	2017-08-05 00:51:00+03	92100.00
4CFC6C	2017-08-08 11:59:00+03	85000.00
4CFCA6	2017-08-05 14:32:00+03	55000.00
4CFCB7	2017-07-04 02:28:00+03	26800.00
4CFD2C	2017-07-02 09:37:00+03	12400.00
4CFD3D	2017-07-26 08:02:00+03	160700.00
4CFD5C	2017-07-06 00:36:00+03	181800.00
4CFDB4	2017-07-04 06:10:00+03	79200.00
4CFDB5	2017-08-08 04:42:00+03	68900.00
4CFDB6	2017-07-09 22:57:00+03	24600.00
4CFE12	2017-07-27 19:08:00+03	23400.00
4CFE36	2017-07-16 15:35:00+03	103200.00
4CFE48	2017-07-09 23:03:00+03	99700.00
4CFE5F	2017-08-15 17:32:00+03	91800.00
4CFF30	2017-07-20 06:09:00+03	32800.00
4CFF40	2017-08-11 19:48:00+03	80300.00
4CFFB0	2017-08-05 07:25:00+03	56000.00
4CFFB3	2017-07-29 17:53:00+03	136800.00
4D0014	2017-07-27 07:03:00+03	28800.00
4D0049	2017-07-04 03:08:00+03	66600.00
4D013C	2017-08-02 14:19:00+03	44600.00
4D0153	2017-08-13 08:26:00+03	55800.00
4D025F	2017-07-30 08:03:00+03	26000.00
4D02A1	2017-08-08 22:57:00+03	58900.00
4D0300	2017-08-13 10:30:00+03	201200.00
4D0311	2017-08-09 08:19:00+03	43000.00
4D033A	2017-06-30 03:24:00+03	55800.00
4D0347	2017-08-12 06:22:00+03	42800.00
4D045E	2017-07-13 03:24:00+03	517400.00
4D0469	2017-08-09 22:39:00+03	25600.00
4D04C4	2017-07-05 04:05:00+03	46400.00
4D04DD	2017-08-10 18:03:00+03	38600.00
4D0509	2017-07-10 23:06:00+03	28000.00
4D0536	2017-07-29 06:05:00+03	23600.00
4D0545	2017-07-21 04:12:00+03	49800.00
4D0550	2017-08-01 15:39:00+03	73000.00
4D0578	2017-08-09 15:23:00+03	89600.00
4D057E	2017-07-14 20:36:00+03	133200.00
4D05E3	2017-07-09 09:23:00+03	53600.00
4D06A5	2017-08-08 17:36:00+03	16400.00
4D0721	2017-08-14 07:03:00+03	29600.00
4D0723	2017-08-11 13:43:00+03	113600.00
4D0780	2017-07-14 08:10:00+03	31400.00
4D07A8	2017-07-17 06:47:00+03	25000.00
4D07F2	2017-07-01 05:06:00+03	34600.00
4D085A	2017-07-27 01:24:00+03	39000.00
4D0877	2017-07-09 23:53:00+03	23600.00
4D08B8	2017-07-16 17:54:00+03	16800.00
4D08C1	2017-07-14 19:30:00+03	18700.00
4D0938	2017-07-19 01:48:00+03	51900.00
4D095E	2017-08-14 03:53:00+03	13400.00
4D0984	2017-08-11 21:22:00+03	23200.00
4D098F	2017-07-27 20:07:00+03	28800.00
4D099D	2017-07-14 12:20:00+03	88800.00
4D09E3	2017-08-12 23:21:00+03	84000.00
4D09F4	2017-08-05 10:36:00+03	32800.00
4D09F8	2017-08-04 00:06:00+03	31600.00
4D0A18	2017-07-02 01:04:00+03	34000.00
4D0A49	2017-08-02 08:48:00+03	43900.00
4D0AC3	2017-06-30 21:39:00+03	46400.00
4D0B19	2017-08-14 23:40:00+03	48800.00
4D0B4B	2017-07-16 09:49:00+03	37200.00
4D0BD9	2017-07-04 05:12:00+03	301500.00
4D0C6C	2017-07-28 07:54:00+03	116900.00
4D0CCE	2017-07-17 03:09:00+03	111600.00
4D0CD9	2017-07-05 09:28:00+03	81300.00
4D0D04	2017-07-11 19:01:00+03	28800.00
4D0D07	2017-08-13 13:16:00+03	52700.00
4D0D1D	2017-08-03 15:17:00+03	39200.00
4D0DA3	2017-07-19 05:56:00+03	11600.00
4D0DB1	2017-08-12 05:03:00+03	46400.00
4D0DD0	2017-07-20 08:42:00+03	75300.00
4D0DFA	2017-06-28 20:21:00+03	157600.00
4D0E16	2017-07-07 17:26:00+03	21800.00
4D0E29	2017-07-27 17:50:00+03	51600.00
4D0E5F	2017-08-08 22:25:00+03	39300.00
4D0E73	2017-08-11 23:34:00+03	40800.00
4D0EB7	2017-08-05 22:24:00+03	325600.00
4D0F6B	2017-07-08 05:55:00+03	68800.00
4D0F73	2017-08-08 08:23:00+03	234200.00
4D0F82	2017-07-27 10:49:00+03	132800.00
4D0F85	2017-08-14 11:25:00+03	35400.00
4D0F95	2017-06-27 14:55:00+03	49200.00
4D0FFB	2017-07-16 20:46:00+03	49100.00
4D1001	2017-08-14 17:32:00+03	303500.00
4D1009	2017-08-11 21:43:00+03	135400.00
4D105C	2017-08-08 18:59:00+03	129700.00
4D1066	2017-07-25 17:27:00+03	25400.00
4D10B7	2017-07-17 21:56:00+03	24400.00
4D10C4	2017-07-04 18:21:00+03	61800.00
4D1105	2017-07-19 03:38:00+03	73200.00
4D1174	2017-08-09 09:25:00+03	41600.00
4D1189	2017-07-27 08:52:00+03	265700.00
4D121B	2017-07-18 22:00:00+03	111600.00
4D1254	2017-07-18 03:35:00+03	65500.00
4D127A	2017-07-28 01:57:00+03	44800.00
4D12AE	2017-08-11 02:08:00+03	173400.00
4D12E3	2017-07-02 02:14:00+03	47000.00
4D12F6	2017-07-09 00:49:00+03	6700.00
4D12FA	2017-07-21 23:53:00+03	51600.00
4D132F	2017-07-12 17:23:00+03	6300.00
4D1335	2017-07-23 04:52:00+03	56600.00
4D133F	2017-08-09 23:58:00+03	62300.00
4D13AB	2017-07-24 07:19:00+03	54400.00
4D140E	2017-07-30 07:47:00+03	54800.00
4D1415	2017-07-16 18:05:00+03	88300.00
4D144F	2017-08-06 09:29:00+03	92900.00
4D145A	2017-07-21 06:19:00+03	547000.00
4D14D1	2017-07-16 17:34:00+03	35600.00
4D1504	2017-07-16 00:08:00+03	87600.00
4D153B	2017-08-01 17:18:00+03	111600.00
4D156F	2017-08-02 04:53:00+03	22600.00
4D15E9	2017-08-12 04:12:00+03	57400.00
4D1607	2017-07-18 05:12:00+03	24400.00
4D16A3	2017-07-27 09:19:00+03	28800.00
4D16A8	2017-08-15 14:58:00+03	27800.00
4D16D5	2017-07-16 20:51:00+03	16400.00
4D16F3	2017-08-04 10:32:00+03	64700.00
4D16FB	2017-08-04 05:42:00+03	136500.00
4D1745	2017-07-11 05:54:00+03	12600.00
4D17AA	2017-07-29 04:36:00+03	25100.00
4D17C1	2017-07-05 05:49:00+03	155600.00
4D17DC	2017-07-14 02:55:00+03	121500.00
4D17F3	2017-07-25 10:47:00+03	266400.00
4D184D	2017-06-28 13:03:00+03	22000.00
4D189F	2017-07-14 14:36:00+03	75600.00
4D194C	2017-07-10 19:55:00+03	27400.00
4D1963	2017-08-04 07:28:00+03	92100.00
4D19D2	2017-07-31 13:34:00+03	50000.00
4D1AC0	2017-07-06 20:35:00+03	19600.00
4D1B0B	2017-08-07 20:19:00+03	65500.00
4D1B38	2017-07-15 22:16:00+03	19800.00
4D1BDF	2017-07-02 03:54:00+03	67400.00
4D1BE3	2017-08-03 07:22:00+03	135600.00
4D1BF3	2017-08-11 10:17:00+03	30000.00
4D1C07	2017-07-21 16:54:00+03	92800.00
4D1C16	2017-07-04 04:05:00+03	187600.00
4D1C1C	2017-07-29 13:55:00+03	51000.00
4D1C41	2017-07-09 05:06:00+03	120900.00
4D1CC1	2017-06-29 15:29:00+03	55400.00
4D1D00	2017-08-10 00:45:00+03	332700.00
4D1D5D	2017-07-22 08:29:00+03	110500.00
4D1D7A	2017-07-19 17:07:00+03	134400.00
4D1D97	2017-07-19 02:01:00+03	85200.00
4D1DB3	2017-08-03 12:43:00+03	146300.00
4D1E0F	2017-07-13 00:05:00+03	52700.00
4D1E2C	2017-08-09 02:46:00+03	47200.00
4D1E45	2017-07-30 03:28:00+03	193200.00
4D1E5C	2017-08-06 21:56:00+03	40000.00
4D1EE4	2017-08-08 07:35:00+03	272300.00
4D1F04	2017-07-02 05:09:00+03	46000.00
4D1F18	2017-08-13 20:42:00+03	25400.00
4D1F21	2017-08-03 06:06:00+03	143100.00
4D1F4B	2017-07-31 01:56:00+03	182200.00
4D1FC7	2017-07-27 00:00:00+03	59300.00
4D1FF8	2017-07-06 15:36:00+03	57600.00
4D203B	2017-07-16 03:31:00+03	51000.00
4D20CE	2017-07-14 04:01:00+03	87600.00
4D2104	2017-07-09 00:26:00+03	44000.00
4D21E4	2017-08-03 14:33:00+03	28000.00
4D21F7	2017-07-12 04:41:00+03	57800.00
4D2266	2017-07-08 11:01:00+03	381000.00
4D22C6	2017-07-15 14:45:00+03	52000.00
4D22CB	2017-07-09 13:44:00+03	42700.00
4D23AC	2017-07-09 09:46:00+03	61600.00
4D23B9	2017-07-17 21:25:00+03	66000.00
4D2413	2017-07-11 14:48:00+03	56000.00
4D2457	2017-07-16 23:27:00+03	67200.00
4D2482	2017-07-26 03:13:00+03	135600.00
4D24B6	2017-07-10 13:30:00+03	125400.00
4D24DC	2017-07-24 22:52:00+03	6000.00
4D24DE	2017-07-27 15:50:00+03	25400.00
4D24E3	2017-07-19 03:05:00+03	19600.00
4D24E6	2017-08-13 02:10:00+03	21400.00
4D257D	2017-07-15 12:35:00+03	99300.00
4D257F	2017-08-04 21:26:00+03	32200.00
4D25B1	2017-07-15 17:45:00+03	73600.00
4D2603	2017-08-06 23:43:00+03	98400.00
4D2625	2017-06-30 23:45:00+03	66000.00
4D2649	2017-07-29 02:00:00+03	30200.00
4D2685	2017-07-10 17:47:00+03	133200.00
4D26F9	2017-07-11 07:26:00+03	248300.00
4D26FA	2017-08-06 01:15:00+03	49900.00
4D2798	2017-07-26 10:30:00+03	14400.00
4D27B7	2017-07-07 05:20:00+03	123000.00
4D27CE	2017-07-21 17:01:00+03	181200.00
4D2809	2017-07-04 12:01:00+03	8000.00
4D280A	2017-07-17 09:55:00+03	8000.00
4D2822	2017-07-25 17:54:00+03	10800.00
4D2871	2017-07-03 13:36:00+03	21800.00
4D289C	2017-07-20 22:29:00+03	27200.00
4D28C8	2017-07-18 11:21:00+03	55800.00
4D29E0	2017-07-10 16:22:00+03	22000.00
4D2A02	2017-08-03 17:06:00+03	29600.00
4D2A31	2017-08-10 16:10:00+03	60400.00
4D2A9B	2017-06-30 05:48:00+03	32800.00
4D2AEC	2017-07-20 15:13:00+03	27200.00
4D2AF4	2017-07-24 04:52:00+03	8200.00
4D2B3E	2017-08-14 15:02:00+03	71600.00
4D2B68	2017-07-10 01:08:00+03	12000.00
4D2B90	2017-07-17 10:25:00+03	12400.00
4D2BBF	2017-07-13 00:47:00+03	109400.00
4D2BDC	2017-07-11 01:21:00+03	449700.00
4D2C2F	2017-08-02 07:44:00+03	150600.00
4D2C43	2017-08-11 06:38:00+03	56000.00
4D2C62	2017-07-16 10:27:00+03	56100.00
4D2D11	2017-07-27 21:38:00+03	182000.00
4D2D3C	2017-07-31 11:02:00+03	185700.00
4D2D8E	2017-07-15 10:18:00+03	265800.00
4D2DD6	2017-08-07 20:58:00+03	118800.00
4D2E03	2017-07-15 08:17:00+03	100200.00
4D2E08	2017-07-19 08:08:00+03	66600.00
4D2E5E	2017-08-07 14:03:00+03	18600.00
4D2E7B	2017-08-15 02:58:00+03	97900.00
4D2E86	2017-07-17 06:12:00+03	28600.00
4D2EC1	2017-07-25 23:51:00+03	178800.00
4D2EE9	2017-08-07 05:53:00+03	83200.00
4D2F61	2017-08-03 02:44:00+03	58000.00
4D2F85	2017-08-14 02:56:00+03	112000.00
4D2FAB	2017-08-11 17:24:00+03	77900.00
4D2FD5	2017-07-27 06:59:00+03	45400.00
4D2FF1	2017-07-09 22:51:00+03	52900.00
4D3044	2017-07-27 13:29:00+03	290500.00
4D3052	2017-07-26 00:21:00+03	73100.00
4D30B4	2017-08-14 05:02:00+03	71900.00
4D3125	2017-07-02 18:37:00+03	23600.00
4D3130	2017-08-12 21:35:00+03	113200.00
4D3234	2017-08-07 10:52:00+03	84800.00
4D3243	2017-06-28 19:15:00+03	43400.00
4D3265	2017-07-30 06:42:00+03	6000.00
4D3267	2017-07-31 19:58:00+03	66600.00
4D32B6	2017-07-19 07:00:00+03	68200.00
4D32F7	2017-07-13 09:24:00+03	36200.00
4D3309	2017-07-26 21:33:00+03	14800.00
4D3391	2017-07-20 01:16:00+03	19600.00
4D342C	2017-08-15 16:44:00+03	42400.00
4D346B	2017-08-11 23:34:00+03	50200.00
4D3487	2017-07-07 15:17:00+03	45200.00
4D349A	2017-07-03 20:52:00+03	58000.00
4D34A2	2017-08-13 06:02:00+03	56000.00
4D34DD	2017-08-15 13:25:00+03	28000.00
4D34FE	2017-07-13 01:01:00+03	273300.00
4D354C	2017-07-09 20:47:00+03	52800.00
4D354F	2017-08-10 20:48:00+03	103900.00
4D3561	2017-07-03 15:18:00+03	27200.00
4D3576	2017-08-12 17:30:00+03	189200.00
4D3608	2017-07-15 10:19:00+03	58900.00
4D3685	2017-07-30 09:25:00+03	14800.00
4D36DB	2017-08-12 21:50:00+03	43900.00
4D36DF	2017-08-05 05:38:00+03	181200.00
4D36F9	2017-07-28 02:31:00+03	53200.00
4D370E	2017-07-16 13:33:00+03	85000.00
4D3710	2017-07-18 04:50:00+03	133200.00
4D371C	2017-07-21 09:23:00+03	112600.00
4D3752	2017-07-02 03:51:00+03	44800.00
4D376D	2017-07-08 02:13:00+03	69500.00
4D37C9	2017-08-08 03:04:00+03	62000.00
4D3809	2017-08-12 03:30:00+03	54800.00
4D3837	2017-07-27 07:21:00+03	28000.00
4D3855	2017-07-21 03:37:00+03	54800.00
4D3867	2017-07-30 16:34:00+03	102100.00
4D389A	2017-07-19 18:26:00+03	67600.00
4D38A6	2017-08-15 17:03:00+03	12000.00
4D38B3	2017-06-30 15:36:00+03	65400.00
4D38C8	2017-08-02 02:33:00+03	144400.00
4D3974	2017-07-04 01:14:00+03	27200.00
4D3A20	2017-07-29 07:07:00+03	67100.00
4D3A2C	2017-08-05 12:38:00+03	54600.00
4D3AED	2017-07-07 21:50:00+03	139800.00
4D3B24	2017-07-09 05:52:00+03	16400.00
4D3B52	2017-07-24 09:52:00+03	354400.00
4D3BC2	2017-08-13 19:54:00+03	56200.00
4D3C26	2017-07-17 12:17:00+03	28800.00
4D3C6F	2017-07-25 04:21:00+03	44000.00
4D3D0D	2017-08-13 16:24:00+03	8200.00
4D3D2A	2017-06-28 14:20:00+03	150100.00
4D3D61	2017-08-15 08:13:00+03	50800.00
4D3D7D	2017-07-06 00:22:00+03	114600.00
4D3DBD	2017-08-07 10:24:00+03	41900.00
4D3DE3	2017-08-07 07:44:00+03	98700.00
4D3DE7	2017-07-14 10:13:00+03	68400.00
4D3DE8	2017-07-16 11:52:00+03	32800.00
4D3E2A	2017-07-12 06:09:00+03	46400.00
4D3EED	2017-08-02 18:53:00+03	119600.00
4D3F8A	2017-08-06 13:54:00+03	16400.00
4D3FB8	2017-08-02 12:29:00+03	47100.00
4D3FF2	2017-08-09 18:19:00+03	55800.00
4D4070	2017-06-30 13:16:00+03	248300.00
4D40A5	2017-07-08 05:32:00+03	106900.00
4D40BB	2017-07-14 11:55:00+03	133200.00
4D414D	2017-07-08 10:31:00+03	14800.00
4D4169	2017-07-30 01:53:00+03	170200.00
4D419F	2017-07-08 02:07:00+03	139500.00
4D41A0	2017-06-28 17:26:00+03	112000.00
4D41EC	2017-07-12 11:02:00+03	56600.00
4D4270	2017-07-19 02:36:00+03	43800.00
4D427E	2017-07-09 04:30:00+03	30200.00
4D4307	2017-08-07 19:41:00+03	78200.00
4D4345	2017-08-13 15:14:00+03	66600.00
4D43A6	2017-08-15 10:10:00+03	69600.00
4D4498	2017-07-06 14:34:00+03	33400.00
4D449F	2017-07-12 02:14:00+03	133200.00
4D44C8	2017-07-25 22:04:00+03	55500.00
4D44E0	2017-08-09 12:25:00+03	44600.00
4D44E8	2017-07-27 10:45:00+03	128700.00
4D450D	2017-07-27 13:18:00+03	29200.00
4D4511	2017-07-17 16:39:00+03	70700.00
4D4527	2017-07-08 10:37:00+03	82200.00
4D4544	2017-07-16 09:42:00+03	32700.00
4D4592	2017-07-31 03:49:00+03	112000.00
4D459F	2017-08-11 10:54:00+03	70600.00
4D45B3	2017-07-27 04:24:00+03	132800.00
4D461A	2017-08-07 11:05:00+03	235000.00
4D4644	2017-07-10 09:47:00+03	26800.00
4D4658	2017-07-16 15:27:00+03	23200.00
4D4669	2017-07-31 07:41:00+03	80900.00
4D46DE	2017-08-09 10:26:00+03	79900.00
4D4783	2017-08-10 23:16:00+03	36200.00
4D4804	2017-07-29 16:14:00+03	25100.00
4D4825	2017-07-30 04:24:00+03	135200.00
4D4873	2017-08-09 05:59:00+03	124600.00
4D4899	2017-07-05 12:04:00+03	16400.00
4D489A	2017-08-02 04:39:00+03	96800.00
4D48D2	2017-07-24 14:02:00+03	112000.00
4D4900	2017-07-02 03:16:00+03	34000.00
4D4916	2017-07-30 02:25:00+03	257500.00
4D4936	2017-08-15 17:58:00+03	23600.00
4D4945	2017-07-05 11:02:00+03	67300.00
4D4949	2017-07-18 04:13:00+03	110500.00
4D4962	2017-08-08 08:25:00+03	111600.00
4D49CD	2017-07-19 01:53:00+03	27200.00
4D49FF	2017-07-06 21:28:00+03	100600.00
4D4A9C	2017-08-05 08:13:00+03	25100.00
4D4B3E	2017-07-09 16:17:00+03	32700.00
4D4B5F	2017-07-30 09:05:00+03	104800.00
4D4B8B	2017-07-01 11:13:00+03	249100.00
4D4B92	2017-08-13 07:19:00+03	246000.00
4D4BC8	2017-07-19 16:52:00+03	48800.00
4D4C52	2017-08-12 06:46:00+03	115400.00
4D4CDA	2017-06-30 20:28:00+03	59000.00
4D4CEA	2017-07-08 17:15:00+03	26000.00
4D4D33	2017-08-12 09:52:00+03	20200.00
4D4DA0	2017-07-02 07:43:00+03	14400.00
4D4DA2	2017-07-05 02:33:00+03	229800.00
4D4DCB	2017-07-24 01:27:00+03	28800.00
4D4EBC	2017-08-05 02:02:00+03	106400.00
4D4EC5	2017-07-29 23:15:00+03	23200.00
4D4EDA	2017-07-28 13:19:00+03	47400.00
4D4F46	2017-08-03 14:25:00+03	133100.00
4D4FAB	2017-07-23 02:56:00+03	17000.00
4D4FAE	2017-07-15 19:12:00+03	94000.00
4D4FB5	2017-08-14 03:49:00+03	12600.00
4D4FD6	2017-07-17 12:29:00+03	32100.00
4D503E	2017-08-01 17:32:00+03	6800.00
4D508E	2017-08-04 22:50:00+03	271200.00
4D50D3	2017-06-30 14:43:00+03	218400.00
4D50F8	2017-07-31 05:22:00+03	53200.00
4D511E	2017-06-27 08:02:00+03	393800.00
4D516A	2017-07-07 03:32:00+03	23600.00
4D5190	2017-08-01 21:47:00+03	123000.00
4D5250	2017-07-12 22:10:00+03	56000.00
4D5265	2017-07-12 22:27:00+03	80300.00
4D5277	2017-07-17 23:31:00+03	56000.00
4D52B4	2017-06-28 05:54:00+03	406100.00
4D52BB	2017-08-01 08:25:00+03	132800.00
4D52C5	2017-08-14 15:22:00+03	23600.00
4D52D6	2017-08-13 08:36:00+03	28200.00
4D52EE	2017-07-24 15:33:00+03	28800.00
4D5330	2017-07-20 16:24:00+03	34600.00
4D535E	2017-08-08 00:07:00+03	182300.00
4D53CD	2017-06-26 19:12:00+03	25200.00
4D540D	2017-07-27 20:45:00+03	13400.00
4D54C7	2017-07-19 02:45:00+03	133200.00
4D54D9	2017-07-29 08:04:00+03	8200.00
4D5552	2017-07-31 21:11:00+03	99600.00
4D557F	2017-07-19 20:03:00+03	100200.00
4D5589	2017-08-13 04:20:00+03	40000.00
4D55B0	2017-08-12 14:58:00+03	6000.00
4D56B9	2017-07-11 17:44:00+03	88800.00
4D56EF	2017-07-02 16:34:00+03	125400.00
4D579D	2017-08-14 05:56:00+03	48800.00
4D57E9	2017-07-09 18:32:00+03	45200.00
4D5806	2017-06-28 16:23:00+03	92700.00
4D5837	2017-07-28 06:34:00+03	246000.00
4D58A0	2017-07-28 20:12:00+03	174200.00
4D58CB	2017-08-09 12:32:00+03	282300.00
4D58CC	2017-07-26 14:45:00+03	19600.00
4D58DB	2017-08-13 17:38:00+03	32900.00
4D5956	2017-07-12 10:27:00+03	62800.00
4D59BE	2017-08-04 02:49:00+03	226200.00
4D59EB	2017-07-31 17:31:00+03	28800.00
4D5A61	2017-08-03 09:15:00+03	62800.00
4D5B0D	2017-08-09 00:01:00+03	28000.00
4D5B10	2017-07-31 07:21:00+03	168000.00
4D5B22	2017-08-05 04:25:00+03	131900.00
4D5B50	2017-08-06 16:09:00+03	89400.00
4D5B55	2017-08-11 22:33:00+03	36200.00
4D5B6E	2017-08-13 04:03:00+03	166000.00
4D5BD5	2017-08-14 10:46:00+03	137600.00
4D5C6D	2017-08-09 07:09:00+03	12000.00
4D5C8D	2017-07-30 11:39:00+03	12600.00
4D5C97	2017-07-31 20:55:00+03	28000.00
4D5D4F	2017-08-10 03:01:00+03	22600.00
4D5D91	2017-08-13 00:27:00+03	27300.00
4D5DA8	2017-07-31 04:06:00+03	257600.00
4D5DBB	2017-07-25 02:52:00+03	69500.00
4D5E5B	2017-08-12 01:35:00+03	85000.00
4D5E78	2017-07-20 06:17:00+03	424800.00
4D5F48	2017-07-14 07:56:00+03	49100.00
4D5F5E	2017-07-01 07:37:00+03	136100.00
4D6080	2017-08-09 22:50:00+03	26200.00
4D6093	2017-07-17 10:11:00+03	69100.00
4D60A5	2017-07-20 21:33:00+03	108200.00
4D60B6	2017-08-10 18:31:00+03	131100.00
4D60EE	2017-08-09 17:17:00+03	131600.00
4D611A	2017-08-13 16:38:00+03	260900.00
4D6174	2017-07-21 19:16:00+03	161200.00
4D6192	2017-08-03 18:15:00+03	3400.00
4D61A9	2017-07-14 01:20:00+03	93500.00
4D61F7	2017-07-07 14:13:00+03	38400.00
4D624C	2017-08-01 06:07:00+03	93700.00
4D6265	2017-07-04 19:58:00+03	28000.00
4D6270	2017-08-06 08:34:00+03	12600.00
4D627F	2017-07-07 15:12:00+03	35600.00
4D6306	2017-08-06 06:27:00+03	233000.00
4D6323	2017-07-23 11:34:00+03	144400.00
4D632B	2017-07-04 00:22:00+03	20800.00
4D634E	2017-07-19 10:40:00+03	188900.00
4D6366	2017-08-14 00:28:00+03	160700.00
4D6413	2017-08-08 09:07:00+03	167400.00
4D6458	2017-07-31 06:18:00+03	55800.00
4D64DA	2017-06-28 11:35:00+03	49100.00
4D65C8	2017-07-26 16:05:00+03	75200.00
4D666F	2017-08-03 00:01:00+03	109600.00
4D66AD	2017-07-13 03:53:00+03	92100.00
4D66C0	2017-07-07 08:34:00+03	75300.00
4D66C3	2017-07-12 12:59:00+03	153300.00
4D67BB	2017-08-10 20:35:00+03	148900.00
4D6897	2017-07-24 17:07:00+03	61500.00
4D68A5	2017-08-11 18:56:00+03	29600.00
4D68AB	2017-07-29 23:59:00+03	66600.00
4D68BB	2017-08-09 06:11:00+03	29400.00
4D68FA	2017-07-17 23:40:00+03	66600.00
4D6A12	2017-07-16 04:36:00+03	156500.00
4D6AA2	2017-07-02 18:30:00+03	179400.00
4D6AC5	2017-07-08 19:46:00+03	43600.00
4D6AF3	2017-08-02 22:31:00+03	42700.00
4D6B55	2017-07-08 09:00:00+03	68800.00
4D6C06	2017-07-01 02:39:00+03	105900.00
4D6C35	2017-08-04 05:23:00+03	54600.00
4D6C46	2017-07-03 19:53:00+03	273400.00
4D6C96	2017-08-08 02:04:00+03	177600.00
4D6CDA	2017-07-16 20:09:00+03	406800.00
4D6CFC	2017-07-05 02:30:00+03	68100.00
4D6D6A	2017-07-06 13:20:00+03	51900.00
4D6DA0	2017-07-22 20:17:00+03	148400.00
4D6DA1	2017-07-12 20:23:00+03	20800.00
4D6DAE	2017-07-11 09:17:00+03	75300.00
4D6DBD	2017-08-10 22:52:00+03	46900.00
4D6DE7	2017-07-30 22:32:00+03	28800.00
4D6E3A	2017-08-09 08:12:00+03	6600.00
4D6E48	2017-07-13 05:39:00+03	60400.00
4D6E57	2017-08-04 00:47:00+03	23200.00
4D6E60	2017-07-12 06:05:00+03	42000.00
4D6EB0	2017-08-03 00:53:00+03	90600.00
4D6EEB	2017-07-25 10:47:00+03	73500.00
4D6F17	2017-07-12 00:50:00+03	234400.00
4D6FF9	2017-07-16 01:52:00+03	46400.00
4D703E	2017-07-10 04:03:00+03	49100.00
4D7131	2017-08-12 05:31:00+03	99200.00
4D714F	2017-07-03 22:02:00+03	191200.00
4D71B6	2017-08-06 16:36:00+03	31400.00
4D7200	2017-08-01 13:33:00+03	70900.00
4D7228	2017-07-13 17:25:00+03	116000.00
4D7265	2017-08-08 09:32:00+03	23600.00
4D72E5	2017-07-20 03:50:00+03	329100.00
4D7339	2017-08-07 04:45:00+03	44100.00
4D7368	2017-08-07 09:12:00+03	23200.00
4D7425	2017-07-20 20:11:00+03	65800.00
4D74A2	2017-07-15 04:34:00+03	89600.00
4D74F0	2017-07-14 21:47:00+03	412400.00
4D7523	2017-08-12 04:36:00+03	6600.00
4D753D	2017-07-06 03:33:00+03	44800.00
4D760D	2017-07-04 02:03:00+03	31000.00
4D7644	2017-07-25 19:14:00+03	35200.00
4D76DF	2017-07-04 19:06:00+03	68800.00
4D7715	2017-07-07 23:21:00+03	54400.00
4D7737	2017-07-15 01:57:00+03	97600.00
4D7750	2017-07-23 18:22:00+03	246000.00
4D7783	2017-07-13 18:17:00+03	9200.00
4D77C2	2017-08-07 16:15:00+03	88600.00
4D77C4	2017-08-07 15:54:00+03	23600.00
4D7807	2017-07-10 16:32:00+03	123000.00
4D7894	2017-07-08 03:41:00+03	18600.00
4D789F	2017-07-16 18:43:00+03	123200.00
4D78EE	2017-07-28 12:15:00+03	19600.00
4D790C	2017-07-18 17:07:00+03	72400.00
4D7957	2017-07-06 08:43:00+03	70100.00
4D7992	2017-07-21 18:20:00+03	36100.00
4D79E6	2017-08-13 15:03:00+03	19600.00
4D7A04	2017-08-04 20:32:00+03	23400.00
4D7A56	2017-07-01 08:28:00+03	20200.00
4D7A5D	2017-07-15 20:46:00+03	99200.00
4D7AD4	2017-07-29 01:27:00+03	59200.00
4D7AEC	2017-07-24 00:51:00+03	56000.00
4D7B23	2017-07-09 04:21:00+03	28800.00
4D7B4B	2017-07-18 08:14:00+03	56000.00
4D7B56	2017-07-13 22:20:00+03	7400.00
4D7B75	2017-08-06 07:53:00+03	167400.00
4D7BA8	2017-07-31 07:30:00+03	42000.00
4D7BB5	2017-07-02 08:26:00+03	73600.00
4D7BBF	2017-07-28 16:32:00+03	62800.00
4D7BD1	2017-08-07 11:11:00+03	27300.00
4D7BE3	2017-08-13 10:59:00+03	89200.00
4D7C0B	2017-07-27 19:48:00+03	91500.00
4D7C15	2017-08-10 21:45:00+03	82100.00
4D7CD4	2017-07-20 11:33:00+03	66600.00
4D7D95	2017-08-08 02:36:00+03	90800.00
4D7D96	2017-07-11 12:14:00+03	444200.00
4D7DD7	2017-07-07 13:15:00+03	542300.00
4D7E6B	2017-07-02 16:31:00+03	28000.00
4D7EC7	2017-07-14 08:54:00+03	62200.00
4D7EEF	2017-07-11 06:36:00+03	68800.00
4D7F21	2017-07-08 23:06:00+03	30200.00
4D7F6A	2017-08-06 00:19:00+03	25600.00
4D7F7E	2017-08-01 22:31:00+03	61800.00
4D7F85	2017-07-25 09:42:00+03	122000.00
4D7FCA	2017-08-09 21:30:00+03	86500.00
4D800F	2017-07-15 18:26:00+03	56600.00
4D808D	2017-07-07 02:44:00+03	248500.00
4D80C3	2017-08-01 21:33:00+03	81700.00
4D811B	2017-07-27 19:22:00+03	23900.00
4D8158	2017-08-03 20:45:00+03	68000.00
4D815F	2017-07-03 23:07:00+03	6700.00
4D8188	2017-06-29 22:11:00+03	16800.00
4D81D4	2017-07-18 05:28:00+03	34000.00
4D822E	2017-07-01 02:14:00+03	22000.00
4D8253	2017-08-04 22:14:00+03	59800.00
4D8333	2017-08-15 07:15:00+03	38200.00
4D8399	2017-07-30 04:32:00+03	6900.00
4D841A	2017-07-22 22:17:00+03	59200.00
4D848D	2017-07-11 17:38:00+03	10800.00
4D849D	2017-07-07 23:31:00+03	88900.00
4D84D5	2017-06-25 00:55:00+03	135600.00
4D8562	2017-07-07 05:43:00+03	59300.00
4D860E	2017-08-14 12:22:00+03	75300.00
4D868F	2017-08-08 01:33:00+03	135600.00
4D86B2	2017-06-30 04:24:00+03	112000.00
4D86F4	2017-07-31 21:28:00+03	68800.00
4D8725	2017-07-25 17:53:00+03	109300.00
4D885E	2017-08-12 05:10:00+03	37100.00
4D8988	2017-08-03 21:00:00+03	75600.00
4D8994	2017-07-25 06:18:00+03	77900.00
4D8A2F	2017-07-30 17:59:00+03	208200.00
4D8AAF	2017-08-13 05:45:00+03	10100.00
4D8AD9	2017-08-06 10:02:00+03	40600.00
4D8B0D	2017-07-29 12:21:00+03	25600.00
4D8B20	2017-07-03 13:25:00+03	269500.00
4D8B2C	2017-08-08 07:35:00+03	55800.00
4D8B52	2017-07-27 20:39:00+03	86800.00
4D8C8A	2017-07-14 04:54:00+03	78400.00
4D8CAC	2017-08-01 04:36:00+03	54500.00
4D8D04	2017-08-10 10:02:00+03	59800.00
4D8D5C	2017-07-20 22:29:00+03	16800.00
4D8DA0	2017-07-24 19:58:00+03	56000.00
4D8DA5	2017-07-29 07:15:00+03	52000.00
4D8DAF	2017-08-07 23:05:00+03	85000.00
4D8DDE	2017-07-09 04:20:00+03	66600.00
4D8E0C	2017-06-27 04:55:00+03	88000.00
4D8E4A	2017-08-01 03:01:00+03	64200.00
4D8E73	2017-07-14 19:22:00+03	186900.00
4D8E7F	2017-08-02 04:31:00+03	131600.00
4D8EA1	2017-08-07 09:29:00+03	19600.00
4D8EE5	2017-07-13 14:08:00+03	21800.00
4D8F2B	2017-07-25 16:16:00+03	6600.00
4D8F2D	2017-07-13 12:18:00+03	27200.00
4D8F48	2017-07-07 23:37:00+03	36200.00
4D8F76	2017-07-26 16:11:00+03	28000.00
4D8F92	2017-07-29 19:00:00+03	38600.00
4D8FA3	2017-07-31 02:59:00+03	54000.00
4D8FB1	2017-07-11 02:25:00+03	187600.00
4D8FCD	2017-07-23 11:59:00+03	32200.00
4D8FDD	2017-08-06 08:37:00+03	155500.00
4D8FF3	2017-08-09 10:49:00+03	146300.00
4D9015	2017-07-28 14:22:00+03	55800.00
4D9020	2017-08-05 20:40:00+03	212900.00
4D9069	2017-07-28 14:16:00+03	28000.00
4D9076	2017-08-15 12:12:00+03	62600.00
4D90F8	2017-07-22 12:03:00+03	6600.00
4D90FF	2017-07-06 18:05:00+03	33200.00
4D9226	2017-07-08 17:43:00+03	66000.00
4D9233	2017-08-04 22:50:00+03	47200.00
4D9295	2017-07-18 02:19:00+03	28800.00
4D92CF	2017-08-04 04:52:00+03	91400.00
4D9368	2017-08-08 12:35:00+03	21400.00
4D9388	2017-07-23 13:36:00+03	19600.00
4D9405	2017-07-28 21:25:00+03	234700.00
4D9408	2017-08-14 02:17:00+03	46100.00
4D9491	2017-07-27 09:42:00+03	79300.00
4D949B	2017-08-05 03:15:00+03	46300.00
4D94A4	2017-08-04 12:01:00+03	36200.00
4D94E2	2017-08-03 18:52:00+03	34100.00
4D94EA	2017-07-23 07:02:00+03	74400.00
4D94EF	2017-07-18 23:38:00+03	14800.00
4D95C1	2017-08-05 20:53:00+03	238700.00
4D95F4	2017-06-29 08:09:00+03	42700.00
4D96B0	2017-07-13 01:48:00+03	46200.00
4D9713	2017-08-11 12:04:00+03	13800.00
4D9719	2017-07-17 14:22:00+03	37200.00
4D9736	2017-07-18 14:23:00+03	32400.00
4D973D	2017-07-02 01:44:00+03	7400.00
4D974A	2017-08-09 19:22:00+03	49700.00
4D98F5	2017-08-02 02:37:00+03	62700.00
4D9916	2017-08-08 03:04:00+03	38600.00
4D9971	2017-08-12 09:43:00+03	24400.00
4D99BB	2017-06-29 06:21:00+03	65900.00
4D99DA	2017-08-07 21:44:00+03	75600.00
4D99F6	2017-08-15 11:14:00+03	167900.00
4D9A06	2017-08-15 06:34:00+03	21400.00
4D9A33	2017-07-17 07:28:00+03	73200.00
4D9A75	2017-07-03 08:20:00+03	67700.00
4D9B0B	2017-08-08 17:08:00+03	49000.00
4D9B18	2017-07-27 10:04:00+03	44000.00
4D9B2A	2017-07-16 11:32:00+03	92800.00
4D9B7D	2017-08-10 07:04:00+03	24400.00
4D9D25	2017-08-11 05:11:00+03	20200.00
4D9D97	2017-07-19 22:04:00+03	43200.00
4D9DFB	2017-07-20 12:31:00+03	26800.00
4D9E6F	2017-07-19 05:41:00+03	56900.00
4D9E73	2017-07-17 15:45:00+03	101200.00
4D9F4A	2017-08-15 06:57:00+03	93900.00
4D9FB6	2017-07-25 06:10:00+03	31700.00
4D9FBC	2017-07-27 17:52:00+03	64400.00
4D9FCA	2017-07-21 07:05:00+03	46000.00
4D9FCF	2017-08-09 15:37:00+03	266400.00
4D9FF7	2017-07-02 00:38:00+03	45000.00
4DA005	2017-07-29 12:13:00+03	11800.00
4DA026	2017-07-07 12:11:00+03	146300.00
4DA0DC	2017-07-27 05:16:00+03	34000.00
4DA149	2017-08-07 12:28:00+03	69500.00
4DA153	2017-07-07 03:29:00+03	64800.00
4DA263	2017-07-25 01:00:00+03	23600.00
4DA27B	2017-07-31 20:05:00+03	136200.00
4DA29A	2017-07-09 11:53:00+03	14000.00
4DA29B	2017-07-27 22:02:00+03	48800.00
4DA2DE	2017-07-15 23:42:00+03	271200.00
4DA312	2017-08-13 22:17:00+03	56600.00
4DA339	2017-07-17 19:41:00+03	43400.00
4DA33B	2017-07-08 04:26:00+03	296400.00
4DA377	2017-07-18 07:54:00+03	19600.00
4DA382	2017-08-13 07:30:00+03	44600.00
4DA3BA	2017-07-21 17:45:00+03	28000.00
4DA3C5	2017-07-29 00:15:00+03	97900.00
4DA404	2017-08-09 19:54:00+03	62000.00
4DA410	2017-07-19 04:10:00+03	67600.00
4DA423	2017-07-18 09:42:00+03	67200.00
4DA42D	2017-07-26 18:16:00+03	29800.00
4DA4BD	2017-07-07 08:28:00+03	38400.00
4DA4C7	2017-08-04 18:32:00+03	59200.00
4DA50C	2017-06-28 00:28:00+03	75500.00
4DA567	2017-07-28 12:06:00+03	46400.00
4DA583	2017-08-06 10:28:00+03	167400.00
4DA5B5	2017-07-09 10:20:00+03	67100.00
4DA5D6	2017-08-14 04:40:00+03	66200.00
4DA632	2017-07-20 19:13:00+03	54000.00
4DA646	2017-08-03 03:05:00+03	34200.00
4DA68B	2017-07-09 20:47:00+03	26800.00
4DA6C5	2017-08-12 05:59:00+03	77200.00
4DA710	2017-07-10 19:31:00+03	23200.00
4DA773	2017-07-24 12:15:00+03	56100.00
4DA77B	2017-07-06 01:05:00+03	23600.00
4DA7DA	2017-06-28 16:22:00+03	112000.00
4DA826	2017-07-20 02:58:00+03	8000.00
4DA885	2017-08-13 00:09:00+03	45100.00
4DA8B5	2017-07-12 12:02:00+03	21800.00
4DAA15	2017-07-18 11:59:00+03	114400.00
4DAA38	2017-07-08 02:06:00+03	40600.00
4DAA55	2017-07-06 18:08:00+03	56600.00
4DAA97	2017-07-14 07:57:00+03	234700.00
4DABD9	2017-08-02 12:14:00+03	26000.00
4DAC04	2017-07-25 17:22:00+03	95600.00
4DAC2D	2017-07-15 09:20:00+03	76100.00
4DAC4E	2017-08-04 21:44:00+03	14400.00
4DAC52	2017-08-11 15:05:00+03	17000.00
4DACA8	2017-08-04 17:05:00+03	68100.00
4DACD1	2017-07-25 01:46:00+03	69500.00
4DAD57	2017-07-25 09:06:00+03	61800.00
4DADF2	2017-08-11 18:53:00+03	242200.00
4DAE00	2017-07-23 17:26:00+03	53400.00
4DAE14	2017-08-01 08:25:00+03	100700.00
4DAE46	2017-07-20 08:11:00+03	85700.00
4DAE90	2017-08-04 03:50:00+03	14400.00
4DAEA1	2017-07-01 09:32:00+03	187800.00
4DAEB2	2017-07-17 16:16:00+03	39800.00
4DAEF5	2017-07-10 01:21:00+03	31600.00
4DAF0F	2017-08-06 09:47:00+03	34000.00
4DAF3C	2017-08-02 02:00:00+03	29600.00
4DAF56	2017-07-17 16:50:00+03	23400.00
4DAF99	2017-07-03 13:27:00+03	148200.00
4DAFF7	2017-08-01 15:28:00+03	28700.00
4DB035	2017-07-27 14:54:00+03	29400.00
4DB063	2017-08-13 10:42:00+03	50600.00
4DB09E	2017-07-22 15:39:00+03	22000.00
4DB0EE	2017-08-10 07:16:00+03	132400.00
4DB10A	2017-07-07 07:51:00+03	189200.00
4DB15A	2017-07-09 18:54:00+03	64600.00
4DB160	2017-08-12 04:04:00+03	58900.00
4DB182	2017-08-07 21:12:00+03	67600.00
4DB18A	2017-08-03 20:15:00+03	77900.00
4DB194	2017-08-15 11:12:00+03	42400.00
4DB199	2017-07-13 09:47:00+03	21800.00
4DB1BD	2017-06-26 10:41:00+03	27800.00
4DB2A1	2017-07-26 00:57:00+03	57500.00
4DB2C3	2017-08-03 09:20:00+03	40900.00
4DB2E2	2017-07-31 12:57:00+03	35600.00
4DB2F4	2017-07-09 11:35:00+03	40800.00
4DB342	2017-07-11 17:10:00+03	32700.00
4DB382	2017-08-13 04:04:00+03	38400.00
4DB3D2	2017-07-15 09:01:00+03	56000.00
4DB3FC	2017-07-09 16:40:00+03	19600.00
4DB43A	2017-07-13 03:31:00+03	8200.00
4DB448	2017-07-21 22:22:00+03	28000.00
4DB4ED	2017-08-14 13:24:00+03	6000.00
4DB517	2017-07-29 06:10:00+03	58500.00
4DB5B9	2017-07-18 09:42:00+03	9000.00
4DB5C8	2017-07-23 10:29:00+03	14400.00
4DB5EA	2017-07-17 06:57:00+03	170200.00
4DB5EB	2017-07-30 12:45:00+03	22000.00
4DB6B5	2017-08-06 11:50:00+03	75300.00
4DB6BA	2017-07-27 19:22:00+03	13600.00
4DB6C3	2017-08-02 12:34:00+03	11600.00
4DB703	2017-08-04 21:48:00+03	85000.00
4DB7BB	2017-07-11 01:27:00+03	111900.00
4DB7DE	2017-06-26 19:14:00+03	33800.00
4DB85E	2017-08-05 23:16:00+03	12600.00
4DB877	2017-08-04 04:43:00+03	34000.00
4DB880	2017-07-22 03:28:00+03	41200.00
4DB887	2017-06-30 22:24:00+03	32900.00
4DB8C3	2017-07-08 15:33:00+03	58400.00
4DB8C9	2017-07-22 09:38:00+03	67200.00
4DB8D2	2017-07-27 02:01:00+03	30200.00
4DB955	2017-06-30 16:26:00+03	33100.00
4DBA57	2017-08-14 21:01:00+03	25400.00
4DBAA9	2017-06-25 01:43:00+03	203800.00
4DBAEC	2017-07-23 10:24:00+03	27200.00
4DBAF8	2017-07-30 23:34:00+03	24400.00
4DBC26	2017-08-07 12:14:00+03	84100.00
4DBC3E	2017-08-07 01:55:00+03	57600.00
4DBC63	2017-08-06 19:17:00+03	27900.00
4DBD09	2017-07-14 16:48:00+03	46000.00
4DBD3F	2017-08-10 08:40:00+03	50100.00
4DBDC9	2017-07-18 15:51:00+03	16400.00
4DBDD5	2017-07-14 00:08:00+03	14000.00
4DBEAC	2017-08-10 11:27:00+03	111600.00
4DBEE8	2017-08-03 06:44:00+03	177200.00
4DBF1F	2017-07-30 23:26:00+03	57500.00
4DBFEA	2017-07-11 19:54:00+03	167400.00
4DC00A	2017-07-28 08:12:00+03	80800.00
4DC03C	2017-08-13 08:09:00+03	16400.00
4DC0B0	2017-08-03 03:07:00+03	14400.00
4DC0C0	2017-08-09 13:17:00+03	58000.00
4DC0CA	2017-08-06 08:51:00+03	46400.00
4DC0F1	2017-08-08 00:59:00+03	24400.00
4DC11A	2017-06-29 15:02:00+03	35700.00
4DC130	2017-08-10 04:49:00+03	6200.00
4DC13D	2017-08-05 15:43:00+03	246000.00
4DC153	2017-07-29 17:28:00+03	6700.00
4DC164	2017-06-30 16:07:00+03	56600.00
4DC172	2017-08-15 09:12:00+03	30800.00
4DC182	2017-08-06 05:04:00+03	65400.00
4DC19F	2017-07-16 19:41:00+03	21800.00
4DC1A7	2017-08-07 17:01:00+03	46200.00
4DC1C1	2017-07-10 23:34:00+03	86300.00
4DC1DB	2017-07-28 00:37:00+03	303500.00
4DC1E0	2017-07-22 20:03:00+03	31400.00
4DC24E	2017-07-28 20:34:00+03	28000.00
4DC2A2	2017-07-10 22:07:00+03	46800.00
4DC2D3	2017-07-07 19:22:00+03	48800.00
4DC31C	2017-07-05 21:33:00+03	28000.00
4DC351	2017-08-05 14:40:00+03	27200.00
4DC361	2017-07-07 16:39:00+03	112700.00
4DC362	2017-07-09 02:32:00+03	320300.00
4DC3BD	2017-07-26 12:19:00+03	55800.00
4DC42E	2017-07-10 23:11:00+03	23400.00
4DC443	2017-07-16 05:31:00+03	47300.00
4DC44F	2017-07-18 21:14:00+03	12600.00
4DC46E	2017-07-19 06:55:00+03	44400.00
4DC50D	2017-07-31 08:20:00+03	66000.00
4DC516	2017-07-13 04:47:00+03	123000.00
4DC591	2017-07-14 16:36:00+03	26000.00
4DC662	2017-07-28 13:27:00+03	11300.00
4DC68F	2017-07-22 17:44:00+03	369000.00
4DC691	2017-08-15 12:37:00+03	23200.00
4DC735	2017-08-11 05:48:00+03	31600.00
4DC778	2017-07-31 11:49:00+03	27300.00
4DC78B	2017-08-01 11:32:00+03	43900.00
4DC805	2017-08-12 06:24:00+03	136000.00
4DC865	2017-07-07 20:54:00+03	50600.00
4DC867	2017-07-28 20:51:00+03	68800.00
4DC8B3	2017-08-13 03:47:00+03	12000.00
4DC8C6	2017-07-09 15:06:00+03	13000.00
4DC974	2017-07-06 14:42:00+03	160700.00
4DC9B3	2017-08-06 12:30:00+03	96300.00
4DCA85	2017-07-15 11:39:00+03	27800.00
4DCAAA	2017-08-02 14:45:00+03	78300.00
4DCAC9	2017-07-22 06:18:00+03	57800.00
4DCADA	2017-07-14 16:53:00+03	23200.00
4DCAE4	2017-07-17 00:16:00+03	31600.00
4DCB73	2017-08-06 14:52:00+03	61800.00
4DCB96	2017-07-14 09:38:00+03	53600.00
4DCBB0	2017-08-03 20:07:00+03	59300.00
4DCBB5	2017-08-06 21:41:00+03	45400.00
4DCBBF	2017-07-16 03:07:00+03	51600.00
4DCBC9	2017-07-10 00:08:00+03	14800.00
4DCBD7	2017-07-23 15:55:00+03	59300.00
4DCBE9	2017-07-16 15:32:00+03	43000.00
4DCC00	2017-07-31 09:00:00+03	68800.00
4DCC07	2017-08-10 08:46:00+03	40400.00
4DCC18	2017-08-04 06:40:00+03	531300.00
4DCC9D	2017-08-04 20:48:00+03	133100.00
4DCD28	2017-08-14 07:46:00+03	52000.00
4DCD9A	2017-07-22 16:44:00+03	28000.00
4DCDA8	2017-08-13 14:23:00+03	80400.00
4DCDEC	2017-07-04 15:58:00+03	69900.00
4DCE14	2017-07-13 21:06:00+03	38800.00
4DCE39	2017-08-08 13:40:00+03	84100.00
4DCE56	2017-08-05 05:40:00+03	133000.00
4DCEC5	2017-07-16 11:08:00+03	23200.00
4DCF01	2017-07-09 18:50:00+03	14800.00
4DCF38	2017-07-07 22:28:00+03	57400.00
4DCF91	2017-07-04 04:41:00+03	114700.00
4DCFB6	2017-07-20 15:51:00+03	11000.00
4DCFC5	2017-07-29 18:52:00+03	26800.00
4DCFD5	2017-07-06 02:29:00+03	55800.00
4DD05D	2017-07-12 23:18:00+03	43400.00
4DD066	2017-07-03 13:17:00+03	135700.00
4DD0A2	2017-07-18 11:06:00+03	56000.00
4DD0AF	2017-08-02 11:48:00+03	99300.00
4DD0B7	2017-08-14 02:34:00+03	40800.00
4DD0BA	2017-07-15 22:21:00+03	14000.00
4DD12F	2017-08-12 06:13:00+03	135400.00
4DD14D	2017-07-27 23:29:00+03	88900.00
4DD14F	2017-08-15 06:16:00+03	98400.00
4DD17E	2017-07-19 21:02:00+03	21800.00
4DD256	2017-07-31 17:39:00+03	58600.00
4DD2F1	2017-07-13 06:11:00+03	99200.00
4DD303	2017-08-03 01:39:00+03	28300.00
4DD316	2017-07-06 06:52:00+03	46200.00
4DD37E	2017-07-05 01:57:00+03	6700.00
4DD3B2	2017-07-14 09:19:00+03	81700.00
4DD3C2	2017-07-12 15:27:00+03	55800.00
4DD3E6	2017-07-17 17:32:00+03	36200.00
4DD418	2017-07-06 19:45:00+03	246000.00
4DD452	2017-07-16 13:15:00+03	75300.00
4DD484	2017-07-29 06:58:00+03	25600.00
4DD4BB	2017-08-12 03:59:00+03	77200.00
4DD4F7	2017-07-15 20:28:00+03	151200.00
4DD58F	2017-07-01 00:45:00+03	76000.00
4DD5A8	2017-07-01 07:38:00+03	186900.00
4DD5C7	2017-08-09 23:37:00+03	49100.00
4DD5D3	2017-08-05 11:03:00+03	246000.00
4DD6C8	2017-08-11 15:46:00+03	63200.00
4DD7BF	2017-08-05 04:57:00+03	13000.00
4DD7DF	2017-07-03 22:28:00+03	123000.00
4DD854	2017-07-28 13:06:00+03	46300.00
4DD87A	2017-07-31 23:35:00+03	28000.00
4DD895	2017-07-12 11:55:00+03	16400.00
4DD8BB	2017-07-31 21:22:00+03	119500.00
4DD8D0	2017-06-29 00:45:00+03	102100.00
4DD8DF	2017-08-08 10:01:00+03	18600.00
4DD98E	2017-07-10 12:22:00+03	123000.00
4DD9B2	2017-07-18 21:20:00+03	50400.00
4DD9DD	2017-08-14 16:35:00+03	29400.00
4DD9F7	2017-07-29 23:29:00+03	16400.00
4DDA24	2017-07-11 18:10:00+03	40600.00
4DDA2F	2017-07-06 00:40:00+03	26000.00
4DDACB	2017-08-02 19:26:00+03	47900.00
4DDB3B	2017-08-08 23:28:00+03	59000.00
4DDBB8	2017-07-23 05:04:00+03	66600.00
4DDC16	2017-08-15 11:15:00+03	39500.00
4DDC6F	2017-07-25 22:54:00+03	154500.00
4DDC9A	2017-07-24 21:18:00+03	87000.00
4DDCC2	2017-07-15 20:07:00+03	265800.00
4DDCFF	2017-07-27 17:15:00+03	59300.00
4DDD01	2017-07-19 23:44:00+03	21500.00
4DDD52	2017-07-14 20:27:00+03	48700.00
4DDD6C	2017-07-30 00:39:00+03	136800.00
4DDD9D	2017-07-10 18:15:00+03	28000.00
4DDDD9	2017-08-01 04:42:00+03	48800.00
4DDE01	2017-08-03 18:36:00+03	111600.00
4DDE43	2017-08-03 07:07:00+03	73100.00
4DDE76	2017-07-25 03:37:00+03	56900.00
4DDED0	2017-07-19 02:58:00+03	58000.00
4DDFEB	2017-08-02 18:29:00+03	92800.00
4DE02D	2017-08-01 01:59:00+03	18000.00
4DE065	2017-07-11 11:00:00+03	101200.00
4DE06E	2017-07-13 01:44:00+03	76600.00
4DE094	2017-08-09 17:21:00+03	111600.00
4DE0AC	2017-07-17 21:54:00+03	6000.00
4DE10C	2017-07-01 13:20:00+03	35300.00
4DE1D4	2017-07-31 20:01:00+03	97700.00
4DE21A	2017-07-14 13:15:00+03	27300.00
4DE2B3	2017-07-24 07:05:00+03	24200.00
4DE34D	2017-08-10 23:05:00+03	6900.00
4DE38F	2017-08-10 02:58:00+03	170200.00
4DE3B9	2017-08-08 17:50:00+03	42700.00
4DE3E0	2017-08-08 10:12:00+03	104600.00
4DE43C	2017-07-15 16:44:00+03	186900.00
4DE444	2017-07-06 00:22:00+03	136100.00
4DE468	2017-08-15 05:51:00+03	124100.00
4DE488	2017-08-07 20:54:00+03	48800.00
4DE513	2017-08-12 21:24:00+03	28800.00
4DE558	2017-08-02 14:43:00+03	73100.00
4DE574	2017-08-02 10:41:00+03	18800.00
4DE586	2017-08-05 08:36:00+03	14800.00
4DE5CC	2017-08-14 17:00:00+03	257500.00
4DE5CF	2017-08-04 00:12:00+03	79900.00
4DE5DA	2017-07-04 02:04:00+03	16400.00
4DE611	2017-08-14 09:26:00+03	23200.00
4DE61C	2017-07-15 22:18:00+03	43800.00
4DE6BA	2017-07-19 19:18:00+03	67600.00
4DE700	2017-07-28 04:38:00+03	25600.00
4DE712	2017-07-12 21:17:00+03	28700.00
4DE7A9	2017-08-01 09:35:00+03	28000.00
4DE7D0	2017-07-14 10:27:00+03	30800.00
4DE82C	2017-08-04 12:24:00+03	11600.00
4DE868	2017-07-13 16:36:00+03	8000.00
4DE888	2017-07-31 15:01:00+03	99600.00
4DE899	2017-07-30 14:13:00+03	28000.00
4DE89D	2017-08-13 02:57:00+03	75600.00
4DE8B1	2017-07-22 05:38:00+03	234700.00
4DE8F4	2017-07-12 08:32:00+03	123600.00
4DE904	2017-08-04 09:44:00+03	36200.00
4DE9B0	2017-08-08 19:30:00+03	85700.00
4DE9B9	2017-08-05 10:08:00+03	148200.00
4DE9E7	2017-07-10 03:03:00+03	40300.00
4DEA22	2017-08-02 16:57:00+03	85000.00
4DEA26	2017-08-06 12:56:00+03	6600.00
4DEA4B	2017-07-05 21:40:00+03	246000.00
4DEA6A	2017-07-23 05:29:00+03	46000.00
4DEA6C	2017-07-10 21:48:00+03	294800.00
4DEAA2	2017-07-16 12:29:00+03	38800.00
4DEB99	2017-08-10 04:13:00+03	57800.00
4DEBC6	2017-07-04 00:57:00+03	81000.00
4DEC0C	2017-07-23 05:12:00+03	67600.00
4DEC0E	2017-08-15 08:55:00+03	29800.00
4DEC0F	2017-07-06 12:23:00+03	39300.00
4DEC18	2017-07-19 16:22:00+03	131100.00
4DEC4D	2017-07-26 23:13:00+03	87200.00
4DEC61	2017-08-11 05:49:00+03	58400.00
4DED6D	2017-07-30 13:54:00+03	133900.00
4DED8A	2017-07-23 09:37:00+03	23600.00
4DEDAA	2017-08-06 03:35:00+03	33300.00
4DEDB6	2017-08-09 05:59:00+03	36500.00
4DEDF9	2017-07-29 21:47:00+03	139400.00
4DEE4F	2017-08-05 13:23:00+03	201200.00
4DEEA3	2017-07-03 06:29:00+03	42000.00
4DEEC3	2017-08-05 17:44:00+03	56700.00
4DEEC4	2017-08-01 09:31:00+03	27200.00
4DEED6	2017-07-26 02:10:00+03	246000.00
4DEF00	2017-07-17 04:05:00+03	21200.00
4DEF3A	2017-07-14 07:09:00+03	189400.00
4DEF67	2017-08-02 05:04:00+03	84000.00
4DEFCF	2017-08-05 16:45:00+03	148200.00
4DF013	2017-08-08 18:17:00+03	66600.00
4DF015	2017-07-16 14:29:00+03	270800.00
4DF093	2017-08-01 01:48:00+03	66900.00
4DF09C	2017-07-09 11:17:00+03	56000.00
4DF146	2017-07-06 22:08:00+03	393800.00
4DF152	2017-07-03 20:34:00+03	6000.00
4DF169	2017-07-04 01:19:00+03	75600.00
4DF18F	2017-08-13 04:23:00+03	111700.00
4DF19C	2017-08-10 08:31:00+03	92700.00
4DF28F	2017-07-22 01:31:00+03	44400.00
4DF328	2017-08-03 23:29:00+03	121400.00
4DF35D	2017-08-10 06:18:00+03	172100.00
4DF3BF	2017-07-15 12:37:00+03	58800.00
4DF3FC	2017-07-05 02:55:00+03	131100.00
4DF40A	2017-08-07 05:21:00+03	103800.00
4DF41C	2017-07-29 20:00:00+03	29600.00
4DF472	2017-07-08 06:18:00+03	66600.00
4DF476	2017-07-23 13:09:00+03	31200.00
4DF4D1	2017-07-30 13:00:00+03	69500.00
4DF550	2017-06-30 09:32:00+03	46200.00
4DF581	2017-07-26 03:30:00+03	26000.00
4DF5A5	2017-08-09 01:35:00+03	69500.00
4DF67A	2017-07-17 18:23:00+03	273000.00
4DF707	2017-08-06 04:34:00+03	36700.00
4DF714	2017-08-03 11:49:00+03	15900.00
4DF77F	2017-08-12 04:15:00+03	56000.00
4DF787	2017-07-14 13:52:00+03	69500.00
4DF7E1	2017-07-23 21:19:00+03	6700.00
4DF803	2017-08-10 04:01:00+03	397700.00
4DF828	2017-07-06 08:34:00+03	71400.00
4DF82F	2017-07-24 03:43:00+03	15400.00
4DF904	2017-07-07 00:42:00+03	26700.00
4DF920	2017-07-02 14:18:00+03	75900.00
4DF9F9	2017-08-01 05:57:00+03	254900.00
4DFA07	2017-07-22 12:06:00+03	67500.00
4DFA59	2017-07-20 13:43:00+03	116900.00
4DFA99	2017-08-10 21:32:00+03	129700.00
4DFB01	2017-07-29 22:14:00+03	55800.00
4DFB8E	2017-07-13 20:28:00+03	114700.00
4DFB8F	2017-07-18 22:13:00+03	28800.00
4DFBAE	2017-07-15 17:50:00+03	36000.00
4DFC1D	2017-08-11 09:24:00+03	615000.00
4DFC4A	2017-07-10 19:46:00+03	92700.00
4DFCE2	2017-07-12 10:47:00+03	40100.00
4DFCE7	2017-07-21 20:59:00+03	171400.00
4DFCEE	2017-07-16 03:18:00+03	42400.00
4DFD11	2017-08-12 01:42:00+03	28000.00
4DFD69	2017-07-26 15:42:00+03	75600.00
4DFDB2	2017-07-27 08:32:00+03	25000.00
4DFDEF	2017-07-25 17:22:00+03	17800.00
4DFE77	2017-07-27 13:22:00+03	79600.00
4DFE7D	2017-08-07 13:19:00+03	19600.00
4DFFE3	2017-07-06 02:17:00+03	17000.00
4E004C	2017-07-02 09:26:00+03	51900.00
4E0087	2017-07-19 20:30:00+03	123000.00
4E00D0	2017-07-05 15:45:00+03	55800.00
4E00F6	2017-08-07 16:07:00+03	268400.00
4E0100	2017-07-08 20:25:00+03	56900.00
4E012B	2017-08-10 06:05:00+03	47000.00
4E013D	2017-07-11 08:56:00+03	40000.00
4E014E	2017-08-15 07:26:00+03	198800.00
4E017A	2017-07-06 17:04:00+03	38600.00
4E01B2	2017-07-14 07:38:00+03	28800.00
4E01EC	2017-08-13 10:25:00+03	112000.00
4E020D	2017-07-22 01:38:00+03	100000.00
4E023C	2017-07-08 23:53:00+03	27200.00
4E0284	2017-08-13 20:11:00+03	27400.00
4E02DA	2017-08-13 03:20:00+03	14800.00
4E02EF	2017-07-10 17:33:00+03	77500.00
4E0336	2017-08-07 15:31:00+03	66600.00
4E0342	2017-07-22 04:25:00+03	56600.00
4E03C9	2017-07-24 03:37:00+03	55900.00
4E0515	2017-07-02 21:45:00+03	81600.00
4E055C	2017-08-10 20:34:00+03	132800.00
4E056B	2017-07-03 23:39:00+03	113300.00
4E05BD	2017-08-08 20:44:00+03	69700.00
4E060A	2017-07-12 01:16:00+03	25800.00
4E0645	2017-07-09 14:12:00+03	64300.00
4E06CA	2017-08-01 03:56:00+03	52000.00
4E0725	2017-08-10 02:05:00+03	230800.00
4E074B	2017-07-13 05:15:00+03	67600.00
4E07B1	2017-07-10 03:17:00+03	44000.00
4E07C4	2017-08-03 20:17:00+03	39300.00
4E0802	2017-07-14 19:02:00+03	302600.00
4E0818	2017-07-09 05:14:00+03	52900.00
4E0865	2017-08-15 13:27:00+03	25700.00
4E0906	2017-07-03 13:12:00+03	40000.00
4E0907	2017-08-15 17:39:00+03	72000.00
4E090C	2017-07-29 03:29:00+03	52100.00
4E096D	2017-07-25 15:49:00+03	295400.00
4E0976	2017-07-24 04:14:00+03	6000.00
4E09B9	2017-08-10 00:57:00+03	56600.00
4E09C6	2017-07-13 19:34:00+03	67200.00
4E09E7	2017-07-05 18:21:00+03	21000.00
4E0B69	2017-08-01 18:44:00+03	16800.00
4E0BD7	2017-08-04 08:19:00+03	64200.00
4E0C22	2017-07-25 23:17:00+03	201200.00
4E0C2F	2017-08-07 12:43:00+03	35800.00
4E0C91	2017-07-29 18:37:00+03	48800.00
4E0D55	2017-08-12 10:10:00+03	25200.00
4E0DA7	2017-08-05 04:01:00+03	131800.00
4E0E2D	2017-08-03 17:00:00+03	216200.00
4E0E40	2017-07-03 00:38:00+03	189200.00
4E0E59	2017-07-22 05:20:00+03	27800.00
4E0E74	2017-07-06 02:53:00+03	89600.00
4E0E91	2017-08-13 05:57:00+03	22600.00
4E0EA3	2017-08-12 05:08:00+03	86800.00
4E0F01	2017-08-04 05:36:00+03	35800.00
4E0FFA	2017-07-15 15:17:00+03	67700.00
4E105D	2017-07-07 22:42:00+03	56000.00
4E1128	2017-07-22 05:23:00+03	254900.00
4E119F	2017-07-02 18:37:00+03	139500.00
4E11B8	2017-08-05 23:04:00+03	91700.00
4E11E0	2017-07-26 00:00:00+03	46400.00
4E122A	2017-07-14 13:33:00+03	91600.00
4E123F	2017-07-25 05:58:00+03	20200.00
4E12E4	2017-07-09 06:54:00+03	36600.00
4E12F1	2017-07-15 11:51:00+03	57400.00
4E12FA	2017-07-19 10:10:00+03	56000.00
4E1335	2017-07-13 20:05:00+03	10600.00
4E1351	2017-08-10 01:10:00+03	51300.00
4E1358	2017-08-09 23:29:00+03	68400.00
4E1385	2017-07-25 01:12:00+03	50600.00
4E139F	2017-07-13 05:38:00+03	46400.00
4E13AA	2017-07-02 10:33:00+03	31600.00
4E13CD	2017-07-16 02:26:00+03	135600.00
4E1417	2017-07-03 20:00:00+03	55600.00
4E142A	2017-07-05 17:53:00+03	39800.00
4E144B	2017-08-04 19:58:00+03	28800.00
4E1465	2017-08-07 20:57:00+03	28800.00
4E148D	2017-07-24 11:42:00+03	393800.00
4E14D2	2017-07-16 07:06:00+03	27400.00
4E151E	2017-07-23 17:30:00+03	104200.00
4E154E	2017-07-06 20:45:00+03	52700.00
4E1551	2017-07-20 09:15:00+03	90700.00
4E1571	2017-08-04 04:52:00+03	26000.00
4E15D9	2017-07-22 17:33:00+03	37900.00
4E15E5	2017-07-17 07:13:00+03	16400.00
4E1604	2017-07-29 16:34:00+03	76800.00
4E1694	2017-07-20 21:49:00+03	21400.00
4E16FE	2017-08-11 22:26:00+03	56100.00
4E1737	2017-07-26 07:17:00+03	43200.00
4E1796	2017-07-25 13:37:00+03	138600.00
4E17F0	2017-08-03 17:41:00+03	40000.00
4E17FF	2017-06-29 13:23:00+03	131600.00
4E184D	2017-08-10 01:19:00+03	56900.00
4E1869	2017-08-06 06:26:00+03	20400.00
4E18BC	2017-07-12 05:11:00+03	62800.00
4E18D1	2017-07-03 10:26:00+03	35200.00
4E1900	2017-07-03 06:02:00+03	108000.00
4E191C	2017-07-24 12:55:00+03	87400.00
4E198D	2017-08-07 08:16:00+03	34000.00
4E19E5	2017-08-09 04:35:00+03	129600.00
4E19FD	2017-07-27 17:42:00+03	142800.00
4E19FE	2017-07-09 03:39:00+03	56900.00
4E1A1D	2017-07-20 04:45:00+03	42800.00
4E1A57	2017-07-21 19:09:00+03	40200.00
4E1A89	2017-08-06 05:58:00+03	246000.00
4E1A94	2017-07-01 10:27:00+03	248300.00
4E1AA4	2017-08-13 18:07:00+03	32700.00
4E1AB3	2017-07-19 09:36:00+03	6000.00
4E1B09	2017-07-13 07:21:00+03	11700.00
4E1B64	2017-07-18 18:41:00+03	86500.00
4E1B76	2017-07-06 09:13:00+03	67400.00
4E1B93	2017-06-30 12:16:00+03	48500.00
4E1BF4	2017-07-31 06:59:00+03	58200.00
4E1C65	2017-07-23 07:03:00+03	7400.00
4E1C73	2017-08-15 07:09:00+03	123000.00
4E1C7B	2017-07-21 15:15:00+03	24400.00
4E1C7F	2017-07-12 05:33:00+03	32200.00
4E1CCB	2017-07-09 10:11:00+03	56200.00
4E1CE9	2017-07-22 15:04:00+03	136400.00
4E1D31	2017-08-10 17:50:00+03	20200.00
4E1D42	2017-07-13 06:45:00+03	81400.00
4E1E08	2017-08-11 16:02:00+03	98000.00
4E1E76	2017-07-16 03:51:00+03	67600.00
4E1F13	2017-08-03 20:07:00+03	45100.00
4E1F1D	2017-08-14 06:35:00+03	105000.00
4E1F39	2017-07-14 11:37:00+03	36800.00
4E1F5F	2017-07-31 13:56:00+03	44800.00
4E1FC0	2017-08-14 19:42:00+03	52000.00
4E2022	2017-07-24 10:23:00+03	147700.00
4E2059	2017-07-05 07:44:00+03	52300.00
4E206B	2017-08-07 20:51:00+03	40100.00
4E20C9	2017-07-20 03:52:00+03	84800.00
4E20FA	2017-07-04 02:26:00+03	220900.00
4E2113	2017-07-25 18:38:00+03	6000.00
4E218C	2017-07-02 01:27:00+03	125100.00
4E219E	2017-07-05 12:46:00+03	23600.00
4E21E5	2017-07-21 18:19:00+03	28000.00
4E2208	2017-07-13 02:28:00+03	67600.00
4E2263	2017-07-15 19:43:00+03	36200.00
4E2288	2017-07-06 17:45:00+03	8000.00
4E230E	2017-08-05 18:11:00+03	166100.00
4E2326	2017-08-12 14:12:00+03	14400.00
4E23B3	2017-07-01 10:36:00+03	27800.00
4E23F6	2017-07-18 22:43:00+03	51900.00
4E23FF	2017-07-05 16:41:00+03	57500.00
4E240F	2017-07-15 06:09:00+03	115600.00
4E246D	2017-07-19 21:17:00+03	32500.00
4E248C	2017-07-25 02:17:00+03	25200.00
4E24D6	2017-08-10 07:08:00+03	59300.00
4E24F8	2017-08-13 03:13:00+03	240600.00
4E2512	2017-07-10 02:33:00+03	38200.00
4E2543	2017-06-30 14:04:00+03	26000.00
4E25DB	2017-07-15 03:31:00+03	405000.00
4E261A	2017-08-13 23:25:00+03	12000.00
4E2688	2017-07-22 17:15:00+03	30800.00
4E2692	2017-08-15 14:20:00+03	48800.00
4E2718	2017-08-14 23:09:00+03	265600.00
4E276E	2017-08-01 01:32:00+03	46400.00
4E278F	2017-07-16 02:09:00+03	15700.00
4E27E2	2017-08-13 11:32:00+03	46400.00
4E27FD	2017-07-04 13:02:00+03	21800.00
4E280A	2017-07-06 00:05:00+03	31800.00
4E283D	2017-07-13 23:29:00+03	10100.00
4E285F	2017-07-26 15:49:00+03	10700.00
4E286B	2017-06-27 11:36:00+03	37200.00
4E287C	2017-07-07 19:10:00+03	59800.00
4E2887	2017-07-20 16:12:00+03	75300.00
4E28CA	2017-08-11 17:42:00+03	40800.00
4E296D	2017-07-31 08:29:00+03	89700.00
4E29A8	2017-07-02 20:12:00+03	271100.00
4E2A25	2017-08-09 18:04:00+03	75300.00
4E2A96	2017-07-16 21:39:00+03	23400.00
4E2AAE	2017-07-15 14:47:00+03	38800.00
4E2ACD	2017-07-16 11:16:00+03	11600.00
4E2B0F	2017-07-27 04:17:00+03	32800.00
4E2B35	2017-07-30 08:00:00+03	111600.00
4E2B3A	2017-07-05 10:10:00+03	204500.00
4E2BA2	2017-07-19 22:32:00+03	124600.00
4E2BB6	2017-08-05 18:48:00+03	45600.00
4E2BBD	2017-08-07 07:15:00+03	42100.00
4E2BFD	2017-07-31 19:17:00+03	104800.00
4E2C24	2017-08-10 12:32:00+03	139500.00
4E2C3C	2017-08-03 00:27:00+03	26100.00
4E2C76	2017-08-09 06:14:00+03	36200.00
4E2CB2	2017-07-28 05:01:00+03	168000.00
4E2CD6	2017-07-04 04:14:00+03	44600.00
4E2CDE	2017-08-14 02:26:00+03	83600.00
4E2CDF	2017-08-02 01:14:00+03	19600.00
4E2D5D	2017-08-13 22:16:00+03	182300.00
4E2D6D	2017-07-29 09:49:00+03	242600.00
4E2D8D	2017-07-22 00:36:00+03	101300.00
4E2DB9	2017-08-04 19:14:00+03	45600.00
4E2DCB	2017-08-09 03:17:00+03	131600.00
4E2EC6	2017-08-10 05:43:00+03	72200.00
4E2F5D	2017-07-05 09:13:00+03	24400.00
4E2FD7	2017-07-12 15:38:00+03	82200.00
4E2FDB	2017-08-03 23:30:00+03	64800.00
4E2FE7	2017-07-02 04:14:00+03	46400.00
4E300A	2017-07-13 02:27:00+03	70700.00
4E3024	2017-08-09 01:30:00+03	51900.00
4E3038	2017-08-07 11:14:00+03	48800.00
4E3063	2017-07-22 12:38:00+03	46400.00
4E306C	2017-07-22 11:14:00+03	402400.00
4E3142	2017-07-19 02:34:00+03	56000.00
4E3144	2017-08-01 13:47:00+03	62000.00
4E314C	2017-08-06 01:09:00+03	37600.00
4E319E	2017-07-11 07:16:00+03	67600.00
4E31CE	2017-08-07 17:33:00+03	8000.00
4E31D3	2017-07-20 02:36:00+03	58600.00
4E326A	2017-07-19 11:54:00+03	41600.00
4E32DC	2017-07-22 19:50:00+03	42800.00
4E32EA	2017-07-24 07:23:00+03	62600.00
4E330B	2017-07-11 17:26:00+03	40400.00
4E33A9	2017-07-22 20:31:00+03	65400.00
4E33D5	2017-07-07 09:48:00+03	51900.00
4E3427	2017-07-02 23:07:00+03	26000.00
4E3472	2017-07-06 18:36:00+03	46400.00
4E34F9	2017-08-01 21:33:00+03	52000.00
4E3535	2017-07-20 22:20:00+03	37900.00
4E3590	2017-07-02 16:42:00+03	14000.00
4E35A8	2017-08-07 21:41:00+03	50800.00
4E35B0	2017-07-19 18:59:00+03	71000.00
4E35B9	2017-07-28 04:30:00+03	101200.00
4E35D6	2017-08-10 03:04:00+03	39400.00
4E35E9	2017-08-10 03:34:00+03	57300.00
4E3616	2017-07-16 13:57:00+03	309200.00
4E361F	2017-07-19 23:28:00+03	86300.00
4E363E	2017-07-14 16:42:00+03	19800.00
4E3693	2017-07-28 10:32:00+03	30200.00
4E36DB	2017-08-13 04:25:00+03	56000.00
4E36E0	2017-08-09 07:23:00+03	24400.00
4E3704	2017-07-20 08:34:00+03	60400.00
4E3758	2017-07-14 08:41:00+03	46300.00
4E379A	2017-08-09 22:34:00+03	100600.00
4E37F2	2017-08-10 00:14:00+03	90800.00
4E384D	2017-07-01 20:42:00+03	42100.00
4E389B	2017-07-01 07:21:00+03	113300.00
4E38F2	2017-07-22 06:12:00+03	101200.00
4E3928	2017-06-30 01:38:00+03	47000.00
4E393D	2017-07-22 20:50:00+03	96800.00
4E398E	2017-07-26 10:03:00+03	146800.00
4E39AB	2017-07-20 01:47:00+03	133200.00
4E39B2	2017-07-01 02:33:00+03	392700.00
4E39E3	2017-07-26 07:12:00+03	67800.00
4E39E7	2017-07-25 00:37:00+03	25200.00
4E3A17	2017-08-04 05:35:00+03	132800.00
4E3A49	2017-08-06 01:01:00+03	397100.00
4E3A74	2017-08-15 07:44:00+03	6700.00
4E3A91	2017-08-06 17:36:00+03	36400.00
4E3AA9	2017-07-11 11:07:00+03	46400.00
4E3AB1	2017-08-03 02:21:00+03	139300.00
4E3AD0	2017-08-02 14:56:00+03	29600.00
4E3B92	2017-08-10 06:00:00+03	26700.00
4E3BB1	2017-08-08 05:39:00+03	46400.00
4E3BB8	2017-07-12 21:37:00+03	25200.00
4E3BE5	2017-08-09 15:15:00+03	55800.00
4E3BF3	2017-07-18 13:04:00+03	29600.00
4E3C48	2017-07-19 07:59:00+03	26000.00
4E3C99	2017-07-08 06:38:00+03	139800.00
4E3C9A	2017-08-14 21:05:00+03	47400.00
4E3CAF	2017-07-10 18:27:00+03	65400.00
4E3CB0	2017-07-30 16:35:00+03	28800.00
4E3CBC	2017-07-01 02:09:00+03	56600.00
4E3CC2	2017-07-07 08:32:00+03	48500.00
4E3CCF	2017-07-11 03:48:00+03	23200.00
4E3D81	2017-07-13 05:14:00+03	22100.00
4E3DBE	2017-08-05 06:11:00+03	281500.00
4E3DC9	2017-07-09 18:42:00+03	172100.00
4E3E1B	2017-08-11 22:41:00+03	27200.00
4E3E5A	2017-07-28 05:52:00+03	46800.00
4E3E89	2017-07-07 07:30:00+03	135400.00
4E3E95	2017-07-15 01:20:00+03	37900.00
4E3F23	2017-08-02 09:08:00+03	69600.00
4E3FDB	2017-07-27 22:11:00+03	31400.00
4E3FED	2017-07-06 09:39:00+03	43700.00
4E4086	2017-07-13 23:36:00+03	77600.00
4E4094	2017-07-19 09:09:00+03	398500.00
4E40D2	2017-07-18 07:54:00+03	12600.00
4E40DA	2017-07-18 04:09:00+03	42400.00
4E4160	2017-07-20 03:29:00+03	21800.00
4E4190	2017-08-13 02:52:00+03	52400.00
4E41DA	2017-07-27 06:43:00+03	68000.00
4E423A	2017-08-09 11:22:00+03	120900.00
4E4249	2017-08-05 10:35:00+03	246000.00
4E4250	2017-08-08 01:17:00+03	14400.00
4E427A	2017-07-31 04:24:00+03	46800.00
4E4282	2017-08-01 07:39:00+03	29600.00
4E42CC	2017-07-21 00:27:00+03	58800.00
4E431B	2017-07-23 13:23:00+03	23100.00
4E4389	2017-08-05 09:28:00+03	40800.00
4E438D	2017-08-09 17:45:00+03	14400.00
4E43A9	2017-08-01 14:46:00+03	67700.00
4E43F8	2017-07-16 13:38:00+03	66600.00
4E4455	2017-07-03 21:10:00+03	92800.00
4E4467	2017-07-05 03:32:00+03	123900.00
4E4468	2017-07-25 05:04:00+03	28300.00
4E4479	2017-08-01 04:59:00+03	21500.00
4E447C	2017-08-04 01:36:00+03	93000.00
4E44BA	2017-07-07 14:14:00+03	162200.00
4E44D7	2017-08-10 09:28:00+03	67600.00
4E4541	2017-07-21 00:30:00+03	211900.00
4E454A	2017-08-11 10:33:00+03	284400.00
4E454B	2017-08-07 06:51:00+03	21400.00
4E4565	2017-08-05 01:56:00+03	87400.00
4E45B7	2017-07-31 19:15:00+03	24400.00
4E45BB	2017-06-30 01:27:00+03	28000.00
4E464D	2017-06-30 14:02:00+03	106100.00
4E46A0	2017-07-15 19:59:00+03	27200.00
4E46B5	2017-08-06 16:29:00+03	21600.00
4E46C9	2017-07-11 17:34:00+03	75800.00
4E4712	2017-07-14 00:38:00+03	49700.00
4E4719	2017-07-09 09:56:00+03	54300.00
4E4761	2017-08-03 06:58:00+03	39300.00
4E47E3	2017-08-07 18:03:00+03	27200.00
4E47FB	2017-07-10 05:01:00+03	31600.00
4E4809	2017-07-02 12:32:00+03	37700.00
4E480B	2017-07-14 17:49:00+03	170600.00
4E4811	2017-08-06 02:26:00+03	68800.00
4E4868	2017-08-03 02:18:00+03	50000.00
4E4876	2017-08-09 15:47:00+03	86800.00
4E4888	2017-07-27 18:13:00+03	162200.00
4E48A0	2017-08-09 09:16:00+03	92000.00
4E48DD	2017-07-06 15:13:00+03	49200.00
4E49D4	2017-06-30 10:56:00+03	40200.00
4E49EB	2017-07-09 05:36:00+03	13400.00
4E4A03	2017-08-07 08:24:00+03	257600.00
4E4A17	2017-08-10 09:14:00+03	40000.00
4E4A4A	2017-07-15 02:09:00+03	136800.00
4E4A61	2017-07-31 12:41:00+03	57600.00
4E4A8B	2017-08-11 16:28:00+03	354400.00
4E4AFF	2017-08-07 05:00:00+03	139800.00
4E4B1E	2017-08-11 19:31:00+03	59200.00
4E4B45	2017-07-26 13:04:00+03	22100.00
4E4B87	2017-07-02 00:55:00+03	28300.00
4E4BA2	2017-07-09 19:32:00+03	13400.00
4E4C58	2017-08-04 08:28:00+03	61200.00
4E4C82	2017-07-12 00:20:00+03	55800.00
4E4CA9	2017-08-08 16:54:00+03	44800.00
4E4CBA	2017-08-10 05:44:00+03	213200.00
4E4CD1	2017-08-02 08:46:00+03	87400.00
4E4D5D	2017-07-02 21:22:00+03	154400.00
4E4DE0	2017-07-05 20:31:00+03	30200.00
4E4E0D	2017-07-07 13:45:00+03	28000.00
4E4E5F	2017-07-05 10:29:00+03	66000.00
4E4EF6	2017-07-04 00:25:00+03	233000.00
4E4F2A	2017-07-28 15:28:00+03	14000.00
4E4F46	2017-08-05 23:07:00+03	56000.00
4E4F54	2017-07-28 10:52:00+03	49200.00
4E4F65	2017-06-30 14:27:00+03	22000.00
4E4FD0	2017-07-06 19:01:00+03	34100.00
4E4FD7	2017-08-03 08:53:00+03	133100.00
4E5015	2017-08-11 00:52:00+03	68400.00
4E5042	2017-07-02 11:22:00+03	44000.00
4E5077	2017-07-16 07:46:00+03	76800.00
4E50DE	2017-07-04 20:04:00+03	76800.00
4E517B	2017-07-11 05:52:00+03	34700.00
4E5200	2017-07-17 13:12:00+03	21500.00
4E5227	2017-08-15 08:10:00+03	27200.00
4E526B	2017-07-12 13:05:00+03	289600.00
4E52E3	2017-07-20 20:22:00+03	201200.00
4E52EA	2017-07-29 19:09:00+03	28000.00
4E5302	2017-08-04 00:54:00+03	65500.00
4E5308	2017-08-01 17:06:00+03	67600.00
4E5348	2017-07-03 17:16:00+03	36000.00
4E5352	2017-08-01 23:49:00+03	56000.00
4E539F	2017-07-03 22:54:00+03	283700.00
4E53E1	2017-08-09 03:16:00+03	14400.00
4E5444	2017-07-21 14:57:00+03	131600.00
4E544E	2017-08-13 20:40:00+03	50100.00
4E544F	2017-07-24 15:23:00+03	56000.00
4E54E2	2017-07-09 07:44:00+03	66000.00
4E550F	2017-08-09 22:34:00+03	46400.00
4E5544	2017-07-12 22:06:00+03	188600.00
4E55DE	2017-07-02 07:54:00+03	47100.00
4E561D	2017-07-11 06:57:00+03	55800.00
4E563D	2017-07-24 14:55:00+03	62600.00
4E5648	2017-07-05 19:04:00+03	42800.00
4E5684	2017-07-04 11:08:00+03	167400.00
4E56EA	2017-07-02 18:21:00+03	23200.00
4E5743	2017-07-25 11:05:00+03	14000.00
4E5748	2017-07-31 08:39:00+03	28000.00
4E575B	2017-07-13 15:49:00+03	88100.00
4E57A4	2017-08-10 14:53:00+03	56000.00
4E57C7	2017-07-14 12:55:00+03	56100.00
4E57DB	2017-07-15 01:46:00+03	41200.00
4E581E	2017-07-09 21:43:00+03	26000.00
4E5886	2017-07-28 01:00:00+03	147100.00
4E58BF	2017-07-28 12:28:00+03	15100.00
4E58E0	2017-07-07 08:42:00+03	59000.00
4E5938	2017-07-01 08:50:00+03	9200.00
4E599C	2017-08-06 07:54:00+03	59200.00
4E59C5	2017-07-17 19:37:00+03	66600.00
4E59C7	2017-07-28 22:29:00+03	81600.00
4E59E9	2017-07-10 00:26:00+03	405200.00
4E59F5	2017-06-29 01:06:00+03	58600.00
4E5A21	2017-07-25 20:42:00+03	64800.00
4E5A5C	2017-08-10 07:26:00+03	76300.00
4E5A74	2017-07-16 09:58:00+03	57600.00
4E5B16	2017-08-07 08:41:00+03	28000.00
4E5B32	2017-08-08 02:51:00+03	10800.00
4E5B52	2017-07-19 16:08:00+03	56600.00
4E5B5C	2017-08-12 14:11:00+03	155600.00
4E5C37	2017-07-13 21:50:00+03	29600.00
4E5C9A	2017-07-31 13:21:00+03	36800.00
4E5CBF	2017-07-28 03:39:00+03	115400.00
4E5DA1	2017-07-11 03:19:00+03	31600.00
4E5DB0	2017-07-31 09:25:00+03	65200.00
4E5DCB	2017-07-15 15:46:00+03	284400.00
4E5E51	2017-08-09 02:23:00+03	14000.00
4E5E5E	2017-07-05 04:03:00+03	213200.00
4E5E6B	2017-07-03 17:51:00+03	56000.00
4E5EB1	2017-08-10 23:34:00+03	48400.00
4E5EBF	2017-08-05 08:22:00+03	22600.00
4E5EE9	2017-07-30 16:05:00+03	129000.00
4E5F06	2017-06-28 23:05:00+03	42800.00
4E5F37	2017-07-18 00:56:00+03	66600.00
4E5F3E	2017-07-29 07:03:00+03	23900.00
4E5F56	2017-08-10 21:44:00+03	83300.00
4E5F93	2017-08-15 12:09:00+03	64800.00
4E6003	2017-07-21 11:23:00+03	92800.00
4E6021	2017-07-13 11:00:00+03	290200.00
4E605D	2017-07-30 08:49:00+03	55800.00
4E605F	2017-07-27 08:42:00+03	25600.00
4E60A1	2017-07-05 04:25:00+03	66600.00
4E60C7	2017-07-11 10:26:00+03	492000.00
4E60E6	2017-08-13 04:34:00+03	26000.00
4E60E9	2017-08-08 13:16:00+03	23200.00
4E60FE	2017-08-08 11:56:00+03	56000.00
4E6176	2017-07-28 23:10:00+03	277800.00
4E6184	2017-07-28 07:57:00+03	70800.00
4E61AA	2017-08-06 20:53:00+03	12600.00
4E61F7	2017-07-24 02:10:00+03	23400.00
4E6218	2017-07-22 06:41:00+03	88600.00
4E632A	2017-08-07 15:07:00+03	51600.00
4E63F3	2017-08-03 04:31:00+03	61900.00
4E63F8	2017-08-13 08:35:00+03	15000.00
4E6448	2017-08-14 10:02:00+03	96400.00
4E6492	2017-07-19 08:13:00+03	28000.00
4E6495	2017-06-30 23:14:00+03	46900.00
4E64BA	2017-07-04 13:36:00+03	44600.00
4E64EE	2017-08-15 12:26:00+03	128600.00
4E654B	2017-07-16 08:41:00+03	111600.00
4E655E	2017-08-03 05:41:00+03	12400.00
4E6574	2017-08-14 07:26:00+03	203000.00
4E65E4	2017-08-10 23:51:00+03	11600.00
4E65FF	2017-07-26 01:27:00+03	214300.00
4E663A	2017-08-02 14:22:00+03	55800.00
4E664B	2017-08-11 00:43:00+03	55800.00
4E664E	2017-07-19 06:36:00+03	14400.00
4E6679	2017-07-28 23:17:00+03	28800.00
4E669B	2017-08-08 21:19:00+03	40600.00
4E66CF	2017-08-10 12:58:00+03	738000.00
4E66F9	2017-08-04 21:42:00+03	56000.00
4E671C	2017-07-20 15:55:00+03	28800.00
4E673E	2017-08-09 19:06:00+03	36200.00
4E6741	2017-07-29 11:39:00+03	15400.00
4E67B6	2017-07-01 11:30:00+03	13600.00
4E67EA	2017-06-30 22:58:00+03	8600.00
4E690E	2017-07-21 15:55:00+03	29400.00
4E6A87	2017-07-04 21:54:00+03	9800.00
4E6AE5	2017-08-15 14:15:00+03	24700.00
4E6B18	2017-08-10 00:00:00+03	22200.00
4E6B1E	2017-08-05 13:09:00+03	224000.00
4E6BC2	2017-07-07 14:19:00+03	108000.00
4E6C17	2017-07-22 22:25:00+03	143000.00
4E6C6F	2017-07-06 07:02:00+03	12000.00
4E6C7F	2017-07-21 12:50:00+03	148200.00
4E6CD6	2017-07-29 07:15:00+03	99200.00
4E6CFA	2017-08-09 11:24:00+03	34400.00
4E6D6F	2017-07-17 20:47:00+03	57500.00
4E6DC0	2017-07-15 06:16:00+03	294200.00
4E6DE5	2017-07-11 07:51:00+03	118800.00
4E6E0E	2017-08-15 08:24:00+03	99200.00
4E6ECF	2017-07-20 18:06:00+03	66600.00
4E6EE6	2017-08-15 08:33:00+03	42500.00
4E6EE7	2017-07-23 18:26:00+03	83000.00
4E6EF3	2017-07-14 03:31:00+03	86300.00
4E6F36	2017-07-16 00:11:00+03	98400.00
4E6FA2	2017-07-10 22:00:00+03	36400.00
4E6FB5	2017-07-21 22:08:00+03	123000.00
4E7000	2017-07-11 10:33:00+03	26200.00
4E702E	2017-07-21 09:52:00+03	112000.00
4E7064	2017-07-31 15:26:00+03	34600.00
4E708C	2017-08-07 22:33:00+03	96100.00
4E70B9	2017-08-06 13:15:00+03	42700.00
4E70FA	2017-08-14 15:29:00+03	59800.00
4E7101	2017-07-09 22:05:00+03	65400.00
4E715E	2017-07-16 07:41:00+03	10600.00
4E7167	2017-07-26 15:32:00+03	65900.00
4E7169	2017-07-27 10:21:00+03	51900.00
4E71F0	2017-07-03 20:52:00+03	62600.00
4E71F8	2017-07-23 01:06:00+03	114800.00
4E7219	2017-07-25 19:10:00+03	28300.00
4E724F	2017-08-09 22:40:00+03	83000.00
4E7266	2017-07-09 05:03:00+03	47000.00
4E72F2	2017-07-04 16:07:00+03	68100.00
4E7374	2017-08-09 11:30:00+03	130400.00
4E73A4	2017-07-04 07:31:00+03	64400.00
4E73A7	2017-07-16 07:31:00+03	22400.00
4E741B	2017-07-06 03:22:00+03	55600.00
4E741F	2017-07-31 18:34:00+03	91100.00
4E74B0	2017-07-12 07:30:00+03	43600.00
4E7526	2017-07-28 20:28:00+03	62800.00
4E753A	2017-07-09 04:27:00+03	75200.00
4E7559	2017-08-02 10:20:00+03	131100.00
4E7569	2017-08-13 20:36:00+03	6300.00
4E760A	2017-08-01 22:40:00+03	36200.00
4E7616	2017-07-02 16:32:00+03	91800.00
4E761A	2017-07-26 16:20:00+03	86100.00
4E7624	2017-07-15 19:34:00+03	270800.00
4E7633	2017-07-11 04:37:00+03	39500.00
4E7674	2017-07-12 07:20:00+03	399600.00
4E767D	2017-07-31 03:41:00+03	30000.00
4E7680	2017-06-30 06:29:00+03	235200.00
4E7691	2017-08-05 17:31:00+03	25800.00
4E76C0	2017-08-07 08:31:00+03	6800.00
4E76DB	2017-08-11 02:07:00+03	48800.00
4E7713	2017-07-07 07:21:00+03	26600.00
4E7719	2017-07-23 12:06:00+03	43500.00
4E7774	2017-07-17 00:36:00+03	49800.00
4E7794	2017-06-29 15:53:00+03	34000.00
4E77BD	2017-08-09 14:07:00+03	135200.00
4E77D7	2017-07-18 07:36:00+03	61800.00
4E7815	2017-07-22 20:59:00+03	44800.00
4E7837	2017-07-10 06:01:00+03	14800.00
4E7839	2017-07-04 12:43:00+03	28600.00
4E78B3	2017-07-07 03:52:00+03	56900.00
4E78C1	2017-07-15 20:56:00+03	42800.00
4E78E1	2017-08-14 07:44:00+03	34000.00
4E78EF	2017-07-06 06:19:00+03	119500.00
4E78F7	2017-07-17 18:35:00+03	166100.00
4E7901	2017-08-09 18:56:00+03	135000.00
4E7A14	2017-07-23 13:54:00+03	75300.00
4E7AD5	2017-08-13 21:46:00+03	72400.00
4E7B15	2017-08-04 08:03:00+03	123000.00
4E7B1B	2017-07-21 09:48:00+03	46400.00
4E7B1C	2017-07-20 16:58:00+03	56600.00
4E7B1E	2017-06-30 11:46:00+03	114400.00
4E7B6C	2017-07-15 01:07:00+03	112000.00
4E7B9C	2017-07-14 06:19:00+03	24700.00
4E7BBF	2017-08-09 15:57:00+03	25400.00
4E7BC1	2017-07-04 01:47:00+03	248300.00
4E7BCB	2017-07-31 06:13:00+03	24800.00
4E7C45	2017-07-25 23:02:00+03	129200.00
4E7C78	2017-07-09 16:53:00+03	58600.00
4E7C80	2017-08-15 08:57:00+03	54800.00
4E7CE2	2017-07-17 20:52:00+03	55800.00
4E7D2C	2017-08-12 07:06:00+03	114800.00
4E7D89	2017-07-10 05:06:00+03	105100.00
4E7DAC	2017-08-01 13:53:00+03	28600.00
4E7E05	2017-07-17 04:34:00+03	48800.00
4E7E42	2017-07-03 03:22:00+03	7400.00
4E7E81	2017-07-28 06:03:00+03	70200.00
4E7ED9	2017-07-02 13:57:00+03	66400.00
4E7F03	2017-07-09 05:27:00+03	532800.00
4E7F4D	2017-08-11 03:39:00+03	66600.00
4E7F76	2017-07-06 09:26:00+03	99300.00
4E7F8A	2017-08-03 14:07:00+03	165100.00
4E7FB0	2017-07-28 15:47:00+03	57400.00
4E8016	2017-07-25 05:27:00+03	71500.00
4E8021	2017-08-06 08:43:00+03	135600.00
4E80EE	2017-08-11 22:03:00+03	189200.00
4E81EC	2017-07-25 06:49:00+03	100000.00
4E81F6	2017-07-14 19:04:00+03	246000.00
4E8305	2017-07-13 14:29:00+03	85700.00
4E8307	2017-08-09 05:31:00+03	42700.00
4E8382	2017-07-27 21:42:00+03	24400.00
4E83AA	2017-08-01 15:11:00+03	73600.00
4E83B5	2017-07-19 04:49:00+03	60300.00
4E83E4	2017-08-09 03:20:00+03	115000.00
4E8403	2017-07-20 10:12:00+03	28000.00
4E8425	2017-07-09 00:30:00+03	24400.00
4E842F	2017-06-28 03:30:00+03	89700.00
4E8477	2017-07-21 23:53:00+03	123000.00
4E8517	2017-07-18 01:58:00+03	85000.00
4E854D	2017-07-28 05:22:00+03	27000.00
4E85E2	2017-08-11 13:31:00+03	174900.00
4E8632	2017-07-08 07:28:00+03	22000.00
4E864C	2017-07-27 03:55:00+03	118900.00
4E8656	2017-07-16 03:20:00+03	383200.00
4E86CB	2017-07-14 18:12:00+03	75600.00
4E8728	2017-07-12 04:44:00+03	57300.00
4E876A	2017-07-25 18:43:00+03	289800.00
4E87B0	2017-08-08 07:08:00+03	83200.00
4E87EF	2017-07-09 18:49:00+03	14400.00
4E8802	2017-07-13 07:21:00+03	43200.00
4E8806	2017-07-23 13:43:00+03	48400.00
4E8819	2017-07-04 01:19:00+03	295400.00
4E8822	2017-07-16 15:54:00+03	156300.00
4E8891	2017-08-08 09:59:00+03	189100.00
4E889B	2017-07-12 00:38:00+03	8000.00
4E89BB	2017-08-11 15:32:00+03	257500.00
4E89CC	2017-08-05 09:15:00+03	136200.00
4E8A0F	2017-08-04 11:00:00+03	134700.00
4E8A50	2017-07-15 10:28:00+03	76600.00
4E8A6D	2017-07-17 11:38:00+03	29600.00
4E8AA4	2017-07-15 05:05:00+03	64400.00
4E8AC5	2017-07-02 00:37:00+03	39000.00
4E8B5E	2017-08-14 15:21:00+03	21400.00
4E8BB1	2017-07-17 10:04:00+03	23200.00
4E8CCE	2017-07-26 03:29:00+03	28800.00
4E8D0C	2017-06-28 19:12:00+03	36100.00
4E8D5E	2017-07-01 03:41:00+03	57400.00
4E8D72	2017-07-26 18:59:00+03	88800.00
4E8D85	2017-07-03 22:47:00+03	125200.00
4E8E07	2017-08-01 09:48:00+03	14000.00
4E8E7D	2017-07-13 20:59:00+03	199800.00
4E8EE6	2017-07-15 18:39:00+03	228000.00
4E8F2F	2017-08-06 06:05:00+03	52700.00
4E8F36	2017-08-05 22:29:00+03	112000.00
4E8F78	2017-08-14 22:29:00+03	68800.00
4E8F9C	2017-07-03 11:03:00+03	28800.00
4E8FFB	2017-07-15 20:14:00+03	137600.00
4E9026	2017-07-11 04:23:00+03	56600.00
4E903B	2017-08-02 22:48:00+03	83000.00
4E9042	2017-07-19 06:22:00+03	14800.00
4E9081	2017-08-14 16:47:00+03	44700.00
4E909A	2017-08-03 22:47:00+03	75300.00
4E90B2	2017-07-26 14:45:00+03	38400.00
4E90BE	2017-08-03 04:24:00+03	106400.00
4E90CF	2017-08-12 19:08:00+03	46200.00
4E9117	2017-07-24 00:41:00+03	43000.00
4E9141	2017-07-30 01:35:00+03	202400.00
4E9171	2017-07-15 17:54:00+03	379600.00
4E917A	2017-07-02 16:25:00+03	25000.00
4E91DB	2017-07-07 23:37:00+03	23200.00
4E91DE	2017-08-05 12:15:00+03	266300.00
4E9220	2017-07-22 13:35:00+03	114800.00
4E929C	2017-07-29 23:13:00+03	67600.00
4E92F4	2017-07-19 05:45:00+03	66600.00
4E9316	2017-07-25 12:06:00+03	237100.00
4E934F	2017-08-04 21:37:00+03	62700.00
4E9362	2017-07-23 17:00:00+03	10800.00
4E9405	2017-07-11 21:58:00+03	64700.00
4E944B	2017-07-24 23:20:00+03	41600.00
4E944C	2017-07-24 05:01:00+03	154800.00
4E94AF	2017-07-15 08:43:00+03	27200.00
4E94D8	2017-08-01 07:03:00+03	234100.00
4E9503	2017-07-19 02:17:00+03	26800.00
4E954C	2017-07-26 21:04:00+03	110500.00
4E95DA	2017-07-03 20:24:00+03	28800.00
4E9609	2017-07-02 01:35:00+03	86500.00
4E9666	2017-07-27 08:26:00+03	42700.00
4E9707	2017-08-03 14:07:00+03	13600.00
4E9710	2017-08-04 20:17:00+03	58400.00
4E9778	2017-08-02 01:46:00+03	21600.00
4E9789	2017-07-31 07:30:00+03	46400.00
4E9793	2017-06-29 01:27:00+03	28800.00
4E97D7	2017-07-23 21:45:00+03	73600.00
4E97E4	2017-07-08 18:29:00+03	28800.00
4E97EB	2017-07-03 18:30:00+03	61700.00
4E98FC	2017-07-05 02:40:00+03	73200.00
4E98FE	2017-08-05 13:16:00+03	23200.00
4E9928	2017-08-06 13:05:00+03	48700.00
4E994B	2017-07-23 12:46:00+03	220600.00
4E997F	2017-07-16 13:38:00+03	94700.00
4E999B	2017-07-07 23:07:00+03	75700.00
4E9A44	2017-08-10 19:46:00+03	56000.00
4E9AB5	2017-07-28 12:15:00+03	47100.00
4E9AFB	2017-08-12 10:46:00+03	28800.00
4E9C5C	2017-08-10 11:12:00+03	59800.00
4E9C70	2017-07-17 07:43:00+03	79800.00
4E9C9C	2017-07-19 09:31:00+03	108500.00
4E9CB3	2017-07-17 06:49:00+03	23200.00
4E9CBC	2017-07-29 10:40:00+03	24200.00
4E9CF2	2017-08-10 19:57:00+03	59200.00
4E9D47	2017-07-04 13:39:00+03	76300.00
4E9D59	2017-07-09 04:55:00+03	113600.00
4E9D63	2017-07-08 01:21:00+03	78000.00
4E9D69	2017-07-31 02:41:00+03	17800.00
4E9D82	2017-07-18 03:37:00+03	39800.00
4E9DA7	2017-07-25 04:10:00+03	73300.00
4E9DB9	2017-07-04 22:55:00+03	20600.00
4E9DEC	2017-07-17 00:49:00+03	137800.00
4E9F41	2017-07-15 01:45:00+03	85700.00
4E9F82	2017-08-08 02:18:00+03	16400.00
4E9F97	2017-08-08 02:28:00+03	61800.00
4E9F9B	2017-07-11 09:57:00+03	34000.00
4E9FBD	2017-08-02 23:54:00+03	136200.00
4EA088	2017-07-22 18:45:00+03	39400.00
4EA095	2017-07-23 03:46:00+03	140800.00
4EA0D1	2017-07-19 16:32:00+03	34000.00
4EA0FE	2017-07-10 11:53:00+03	131100.00
4EA163	2017-08-04 03:05:00+03	48200.00
4EA1D3	2017-07-28 02:22:00+03	23400.00
4EA1EB	2017-07-13 16:56:00+03	57500.00
4EA201	2017-07-09 10:32:00+03	46200.00
4EA240	2017-07-10 16:05:00+03	37900.00
4EA265	2017-08-09 23:48:00+03	85000.00
4EA29E	2017-07-25 00:36:00+03	38400.00
4EA29F	2017-07-08 06:01:00+03	30000.00
4EA2A0	2017-07-16 01:35:00+03	45200.00
4EA2FB	2017-08-15 05:01:00+03	22000.00
4EA35D	2017-07-31 13:12:00+03	112000.00
4EA38D	2017-07-31 01:30:00+03	43200.00
4EA3F8	2017-08-05 23:15:00+03	75300.00
4EA40F	2017-07-09 06:25:00+03	20400.00
4EA461	2017-08-08 23:57:00+03	72400.00
4EA49F	2017-07-25 23:07:00+03	16400.00
4EA4B4	2017-07-14 04:41:00+03	68800.00
4EA4E3	2017-07-08 18:40:00+03	25600.00
4EA502	2017-07-30 08:05:00+03	23600.00
4EA510	2017-07-29 15:28:00+03	55800.00
4EA523	2017-07-17 04:03:00+03	128800.00
4EA52A	2017-07-14 05:18:00+03	14400.00
4EA546	2017-07-11 22:00:00+03	69500.00
4EA590	2017-07-17 03:46:00+03	26000.00
4EA5DE	2017-07-25 18:35:00+03	50200.00
4EA650	2017-07-15 07:28:00+03	135400.00
4EA695	2017-07-17 20:24:00+03	73900.00
4EA6DF	2017-07-05 18:34:00+03	38400.00
4EA794	2017-07-21 04:37:00+03	67300.00
4EA799	2017-08-08 20:18:00+03	28000.00
4EA7AA	2017-07-02 12:57:00+03	12400.00
4EA83E	2017-07-23 16:57:00+03	44500.00
4EA846	2017-07-23 04:33:00+03	69800.00
4EA848	2017-07-29 00:26:00+03	18000.00
4EA8F1	2017-07-26 12:15:00+03	15100.00
4EA914	2017-07-10 09:08:00+03	40000.00
4EA98B	2017-07-05 15:23:00+03	212000.00
4EAA09	2017-08-02 23:30:00+03	6000.00
4EAA0F	2017-07-02 06:35:00+03	95600.00
4EAA56	2017-07-21 12:25:00+03	28000.00
4EAABE	2017-07-29 11:16:00+03	123000.00
4EAAC0	2017-07-23 20:19:00+03	40000.00
4EAAC7	2017-08-04 18:19:00+03	24000.00
4EAACF	2017-07-05 10:48:00+03	136600.00
4EAAD1	2017-07-14 19:43:00+03	28000.00
4EAB48	2017-08-04 12:58:00+03	6700.00
4EAB59	2017-07-07 17:40:00+03	26700.00
4EAB8D	2017-07-16 14:38:00+03	47000.00
4EABBD	2017-07-15 23:18:00+03	50600.00
4EAC1C	2017-08-11 23:42:00+03	64700.00
4EAC39	2017-08-14 18:07:00+03	22000.00
4EAC6F	2017-07-22 17:49:00+03	45200.00
4EAD2D	2017-08-13 01:12:00+03	52000.00
4EADDD	2017-07-21 01:02:00+03	16400.00
4EADFB	2017-08-12 16:48:00+03	12600.00
4EAE0D	2017-08-07 03:02:00+03	29600.00
4EAE67	2017-08-04 04:49:00+03	8200.00
4EAE93	2017-07-18 02:25:00+03	45200.00
4EAEA8	2017-08-08 13:49:00+03	88600.00
4EAEB1	2017-07-14 13:56:00+03	28800.00
4EAF22	2017-08-02 06:27:00+03	270200.00
4EAF38	2017-07-04 00:14:00+03	45200.00
4EAF96	2017-07-04 10:08:00+03	16400.00
4EAFA7	2017-07-11 11:55:00+03	43400.00
4EB03F	2017-08-11 20:22:00+03	108800.00
4EB0C0	2017-08-13 12:14:00+03	23400.00
4EB13E	2017-07-07 10:27:00+03	133600.00
4EB169	2017-07-02 13:07:00+03	119500.00
4EB1A5	2017-07-26 15:05:00+03	59300.00
4EB1CC	2017-07-16 22:52:00+03	146900.00
4EB1D6	2017-07-25 14:29:00+03	81600.00
4EB1E4	2017-07-06 15:28:00+03	234600.00
4EB1EE	2017-07-21 19:20:00+03	74100.00
4EB1FA	2017-07-23 01:23:00+03	54300.00
4EB215	2017-08-03 23:16:00+03	46000.00
4EB241	2017-07-13 06:14:00+03	83000.00
4EB282	2017-08-13 15:44:00+03	81200.00
4EB292	2017-08-13 15:53:00+03	91600.00
4EB2B4	2017-08-04 12:53:00+03	23200.00
4EB2DD	2017-08-05 18:30:00+03	85000.00
4EB304	2017-07-30 00:19:00+03	31700.00
4EB315	2017-07-22 03:38:00+03	6000.00
4EB368	2017-07-20 12:45:00+03	70600.00
4EB3BC	2017-07-21 10:07:00+03	111600.00
4EB3C3	2017-07-26 15:53:00+03	78500.00
4EB3CC	2017-08-08 06:01:00+03	60400.00
4EB3DB	2017-07-15 04:46:00+03	46800.00
4EB3F1	2017-07-22 00:17:00+03	32900.00
4EB40A	2017-08-10 17:52:00+03	616000.00
4EB41C	2017-07-08 12:42:00+03	89600.00
4EB44B	2017-07-27 08:03:00+03	37000.00
4EB46E	2017-07-18 16:23:00+03	128800.00
4EB4C6	2017-07-20 18:33:00+03	23200.00
4EB60C	2017-07-16 10:02:00+03	87000.00
4EB624	2017-07-23 11:17:00+03	40800.00
4EB6B6	2017-07-17 19:52:00+03	81600.00
4EB6B7	2017-07-16 23:30:00+03	46300.00
4EB6EB	2017-07-25 06:21:00+03	31400.00
4EB6F1	2017-08-01 16:21:00+03	74200.00
4EB75B	2017-07-29 06:02:00+03	67200.00
4EB78C	2017-08-15 08:01:00+03	62600.00
4EB7CE	2017-07-18 05:30:00+03	28800.00
4EB7ED	2017-07-23 16:33:00+03	65400.00
4EB898	2017-08-12 04:16:00+03	56000.00
4EB8E1	2017-07-30 19:50:00+03	59100.00
4EB90A	2017-08-04 12:09:00+03	55800.00
4EB91C	2017-07-03 23:02:00+03	61800.00
4EB92F	2017-07-27 09:12:00+03	59600.00
4EB95A	2017-07-09 12:47:00+03	123000.00
4EB977	2017-07-04 15:58:00+03	12400.00
4EB9A9	2017-07-20 04:24:00+03	40800.00
4EBA6B	2017-08-04 18:57:00+03	20200.00
4EBA72	2017-07-11 07:52:00+03	6600.00
4EBA86	2017-07-16 09:35:00+03	54400.00
4EBA93	2017-08-04 09:23:00+03	66600.00
4EBAF3	2017-07-23 23:01:00+03	112600.00
4EBB18	2017-07-21 08:21:00+03	49100.00
4EBB3B	2017-07-05 22:28:00+03	290600.00
4EBBE9	2017-07-14 08:48:00+03	46000.00
4EBC22	2017-07-24 08:50:00+03	55000.00
4EBC87	2017-07-05 07:36:00+03	6700.00
4EBC91	2017-08-08 15:46:00+03	96800.00
4EBCD9	2017-08-01 11:39:00+03	123000.00
4EBCFC	2017-08-13 13:29:00+03	77000.00
4EBD0E	2017-07-18 03:51:00+03	48800.00
4EBD40	2017-07-17 06:49:00+03	36800.00
4EBD78	2017-07-14 21:16:00+03	75600.00
4EBDC8	2017-07-09 17:37:00+03	13600.00
4EBDEE	2017-07-18 06:26:00+03	37900.00
4EBE32	2017-07-08 22:18:00+03	35600.00
4EBE41	2017-07-19 06:16:00+03	179400.00
4EBE57	2017-07-07 14:11:00+03	39100.00
4EBEA1	2017-07-16 03:03:00+03	28800.00
4EBED6	2017-07-30 12:20:00+03	12000.00
4EBF65	2017-08-06 00:56:00+03	38400.00
4EBFC1	2017-08-05 06:22:00+03	61500.00
4EBFDA	2017-07-27 10:12:00+03	123700.00
4EBFE0	2017-07-19 23:41:00+03	28200.00
4EC033	2017-08-12 23:50:00+03	6000.00
4EC0E2	2017-08-12 13:28:00+03	35400.00
4EC15D	2017-08-02 19:47:00+03	12900.00
4EC16E	2017-07-09 06:09:00+03	46500.00
4EC1D8	2017-07-09 16:12:00+03	46400.00
4EC1DB	2017-07-06 00:44:00+03	56600.00
4EC237	2017-07-12 08:07:00+03	75300.00
4EC265	2017-07-12 08:21:00+03	43200.00
4EC39B	2017-07-05 23:31:00+03	18000.00
4EC3E6	2017-07-02 11:27:00+03	23200.00
4EC41E	2017-08-12 11:46:00+03	97900.00
4EC44C	2017-07-30 17:57:00+03	26000.00
4EC46E	2017-07-07 18:53:00+03	36200.00
4EC505	2017-08-13 04:41:00+03	137600.00
4EC580	2017-08-09 11:08:00+03	32800.00
4EC5F3	2017-07-01 23:30:00+03	59300.00
4EC60E	2017-07-04 05:44:00+03	78000.00
4EC62F	2017-07-23 20:42:00+03	169900.00
4EC6D7	2017-07-02 14:42:00+03	403000.00
4EC6D9	2017-08-01 08:00:00+03	29600.00
4EC758	2017-08-06 11:32:00+03	21800.00
4EC770	2017-07-22 18:47:00+03	276200.00
4EC775	2017-07-15 20:07:00+03	28000.00
4EC7DE	2017-08-10 16:09:00+03	64700.00
4EC84F	2017-07-16 16:38:00+03	12600.00
4EC85B	2017-06-30 23:58:00+03	31400.00
4EC8CE	2017-07-12 15:54:00+03	123000.00
4EC8F0	2017-07-04 04:47:00+03	28000.00
4EC912	2017-07-26 00:57:00+03	416700.00
4EC983	2017-07-15 22:45:00+03	90800.00
4EC9B0	2017-07-24 13:48:00+03	23600.00
4EC9C6	2017-07-10 20:53:00+03	6700.00
4ECA03	2017-08-11 00:33:00+03	240600.00
4ECA14	2017-07-29 21:15:00+03	37700.00
4ECA76	2017-08-04 18:37:00+03	48800.00
4ECA8F	2017-08-08 01:53:00+03	46400.00
4ECB68	2017-06-30 19:07:00+03	170500.00
4ECC21	2017-07-05 00:47:00+03	23600.00
4ECC2C	2017-07-10 01:13:00+03	19600.00
4ECC37	2017-08-02 16:41:00+03	46400.00
4ECCD7	2017-07-05 16:07:00+03	20200.00
4ECCDB	2017-08-11 20:34:00+03	101300.00
4ECCFB	2017-08-12 03:57:00+03	55800.00
4ECD2A	2017-07-24 06:17:00+03	37600.00
4ECD68	2017-07-14 13:59:00+03	36200.00
4ECD70	2017-07-30 19:27:00+03	124200.00
4ECD8B	2017-07-26 16:08:00+03	116800.00
4ECD95	2017-07-10 14:39:00+03	100600.00
4ECDEC	2017-07-17 17:07:00+03	52300.00
4ECE01	2017-07-15 22:15:00+03	31400.00
4ECE03	2017-06-25 18:14:00+03	7400.00
4ECE6F	2017-07-10 17:47:00+03	74400.00
4ECED0	2017-08-04 21:41:00+03	13400.00
4ECF02	2017-07-18 23:38:00+03	83100.00
4ECFC2	2017-07-14 04:21:00+03	58800.00
4ECFC6	2017-08-12 14:58:00+03	102000.00
4ECFDB	2017-07-29 04:43:00+03	136200.00
4ED04A	2017-07-20 19:45:00+03	111600.00
4ED061	2017-07-06 18:53:00+03	40000.00
4ED066	2017-08-08 22:47:00+03	10800.00
4ED091	2017-08-15 13:59:00+03	58000.00
4ED0B0	2017-07-12 06:02:00+03	272300.00
4ED0BA	2017-08-08 17:44:00+03	56000.00
4ED14D	2017-08-11 18:38:00+03	68800.00
4ED173	2017-08-09 00:46:00+03	85000.00
4ED192	2017-07-03 11:48:00+03	30200.00
4ED219	2017-08-13 17:14:00+03	165100.00
4ED225	2017-07-20 02:16:00+03	65100.00
4ED292	2017-08-08 02:14:00+03	37700.00
4ED296	2017-07-13 13:14:00+03	46800.00
4ED2B8	2017-08-13 21:42:00+03	73600.00
4ED2F4	2017-07-09 07:52:00+03	169300.00
4ED346	2017-08-01 14:45:00+03	28800.00
4ED350	2017-08-05 17:04:00+03	70500.00
4ED394	2017-07-31 08:51:00+03	64400.00
4ED3F9	2017-07-15 06:23:00+03	147100.00
4ED4B5	2017-08-10 04:09:00+03	119500.00
4ED4D7	2017-07-24 16:52:00+03	36200.00
4ED4DF	2017-08-11 06:12:00+03	58200.00
4ED4E9	2017-08-15 05:14:00+03	28000.00
4ED511	2017-07-26 20:10:00+03	51800.00
4ED5A2	2017-07-13 02:41:00+03	60600.00
4ED61D	2017-07-20 11:25:00+03	70800.00
4ED61F	2017-07-05 19:49:00+03	127300.00
4ED62B	2017-07-24 22:55:00+03	204000.00
4ED631	2017-07-21 10:28:00+03	121400.00
4ED68D	2017-08-09 16:11:00+03	137600.00
4ED704	2017-07-23 10:35:00+03	182500.00
4ED709	2017-08-14 23:24:00+03	13200.00
4ED781	2017-07-14 03:46:00+03	112900.00
4ED7A7	2017-08-06 07:18:00+03	21400.00
4ED817	2017-07-14 09:12:00+03	42800.00
4ED847	2017-07-10 19:06:00+03	93900.00
4ED865	2017-07-16 12:13:00+03	100200.00
4ED867	2017-07-17 10:40:00+03	101200.00
4ED901	2017-07-10 04:47:00+03	46400.00
4ED934	2017-07-25 18:25:00+03	56900.00
4ED937	2017-08-02 23:00:00+03	46400.00
4ED94B	2017-07-06 10:10:00+03	35200.00
4ED975	2017-07-09 15:51:00+03	39100.00
4ED9A1	2017-08-11 20:38:00+03	6000.00
4ED9B1	2017-08-09 03:55:00+03	57400.00
4ED9FF	2017-08-01 22:41:00+03	35100.00
4EDA31	2017-07-17 04:16:00+03	23400.00
4EDA34	2017-08-05 00:55:00+03	28000.00
4EDA4F	2017-08-12 17:27:00+03	109300.00
4EDA8E	2017-07-26 21:06:00+03	24800.00
4EDAA3	2017-07-04 21:21:00+03	89600.00
4EDAC0	2017-07-16 15:50:00+03	72400.00
4EDB66	2017-07-19 10:03:00+03	101500.00
4EDB91	2017-07-20 00:43:00+03	110600.00
4EDBDF	2017-07-15 00:26:00+03	175200.00
4EDC2F	2017-07-21 22:25:00+03	139500.00
4EDC53	2017-07-19 03:49:00+03	16400.00
4EDC7D	2017-07-07 08:05:00+03	58400.00
4EDCCC	2017-08-07 14:31:00+03	38500.00
4EDCDB	2017-08-05 03:26:00+03	57700.00
4EDCF9	2017-07-31 15:08:00+03	59100.00
4EDD11	2017-07-15 08:44:00+03	7800.00
4EDD2D	2017-07-29 07:01:00+03	33100.00
4EDD77	2017-07-19 03:51:00+03	76900.00
4EDDB1	2017-07-03 10:12:00+03	89500.00
4EDDB7	2017-07-20 23:20:00+03	59800.00
4EDDBD	2017-07-14 17:48:00+03	73600.00
4EDDC7	2017-07-28 20:47:00+03	37000.00
4EDDE3	2017-07-03 18:23:00+03	29600.00
4EDDEB	2017-07-26 00:32:00+03	41600.00
4EDE5E	2017-07-31 18:27:00+03	68800.00
4EDE7D	2017-06-30 15:21:00+03	53100.00
4EDE96	2017-07-04 22:39:00+03	61800.00
4EDEE2	2017-07-05 06:31:00+03	55600.00
4EDFAF	2017-07-13 13:29:00+03	133200.00
4EDFF0	2017-07-01 15:28:00+03	49100.00
4EE14D	2017-07-08 05:22:00+03	92800.00
4EE159	2017-08-01 17:51:00+03	64600.00
4EE168	2017-08-03 10:26:00+03	57400.00
4EE1A1	2017-07-07 22:21:00+03	28000.00
4EE1CE	2017-08-10 15:37:00+03	111600.00
4EE1EE	2017-07-12 12:18:00+03	127600.00
4EE23C	2017-06-28 01:42:00+03	46300.00
4EE247	2017-08-06 01:29:00+03	20200.00
4EE253	2017-07-25 13:59:00+03	75800.00
4EE29F	2017-07-18 08:26:00+03	39300.00
4EE2BA	2017-08-05 14:12:00+03	19800.00
4EE2EA	2017-08-01 03:15:00+03	198400.00
4EE2EF	2017-08-01 23:39:00+03	39500.00
4EE348	2017-07-17 04:35:00+03	25400.00
4EE34A	2017-07-31 22:36:00+03	104600.00
4EE36D	2017-07-20 16:33:00+03	96400.00
4EE41F	2017-08-09 20:25:00+03	56000.00
4EE445	2017-08-07 19:38:00+03	48800.00
4EE4CE	2017-07-13 00:49:00+03	35200.00
4EE4F8	2017-07-07 05:40:00+03	47900.00
4EE504	2017-07-28 14:51:00+03	170000.00
4EE58A	2017-08-08 23:14:00+03	58600.00
4EE67B	2017-07-15 11:50:00+03	67400.00
4EE717	2017-08-10 00:58:00+03	62000.00
4EE71D	2017-07-11 22:12:00+03	14400.00
4EE79D	2017-07-09 17:09:00+03	291500.00
4EE7A3	2017-08-12 04:20:00+03	94000.00
4EE7B0	2017-08-01 03:21:00+03	56900.00
4EE7BA	2017-08-14 18:06:00+03	7400.00
4EE7BC	2017-07-03 08:44:00+03	271200.00
4EE7C0	2017-08-09 22:57:00+03	6000.00
4EE813	2017-07-26 22:42:00+03	60000.00
4EE81C	2017-07-10 23:14:00+03	55800.00
4EE837	2017-08-14 09:59:00+03	52000.00
4EE944	2017-08-14 07:03:00+03	25100.00
4EE95A	2017-07-05 17:23:00+03	22000.00
4EE9A4	2017-07-27 15:31:00+03	8000.00
4EE9CC	2017-07-28 01:00:00+03	168000.00
4EEA5B	2017-07-31 10:23:00+03	22100.00
4EEA68	2017-08-12 18:29:00+03	40000.00
4EEA75	2017-07-19 18:25:00+03	148200.00
4EEAFA	2017-07-06 05:31:00+03	270800.00
4EEB2B	2017-07-12 22:32:00+03	19600.00
4EEB2F	2017-08-11 20:38:00+03	42400.00
4EEB6A	2017-08-03 07:32:00+03	89600.00
4EEB74	2017-07-07 15:23:00+03	78200.00
4EEB78	2017-08-03 22:39:00+03	39300.00
4EEB92	2017-07-22 00:36:00+03	24000.00
4EEB98	2017-07-08 09:27:00+03	6300.00
4EEBA7	2017-08-15 08:53:00+03	44600.00
4EEBB9	2017-08-11 15:52:00+03	73500.00
4EEBC5	2017-06-28 07:39:00+03	48800.00
4EEC39	2017-07-01 20:08:00+03	423200.00
4EEC71	2017-07-07 22:12:00+03	65300.00
4EEC92	2017-07-23 00:11:00+03	167500.00
4EED3E	2017-07-16 06:25:00+03	34000.00
4EED5C	2017-08-02 19:16:00+03	81700.00
4EED8C	2017-07-06 11:32:00+03	12600.00
4EED98	2017-08-03 09:01:00+03	124600.00
4EEDB5	2017-07-30 16:04:00+03	38800.00
4EEDCB	2017-07-16 17:15:00+03	34100.00
4EEDF1	2017-07-13 22:45:00+03	20200.00
4EEE23	2017-06-27 00:08:00+03	27200.00
4EEE61	2017-07-09 16:54:00+03	100500.00
4EEEC1	2017-08-12 16:31:00+03	179600.00
4EEEEE	2017-07-30 22:49:00+03	100600.00
4EEEFA	2017-07-14 21:03:00+03	35600.00
4EEF01	2017-07-08 12:11:00+03	18600.00
4EEF2E	2017-07-13 07:36:00+03	11600.00
4EEF98	2017-07-01 05:46:00+03	8200.00
4EEFA0	2017-08-13 07:04:00+03	103500.00
4EF007	2017-06-28 19:31:00+03	34100.00
4EF060	2017-08-06 04:53:00+03	6000.00
4EF07D	2017-08-13 00:40:00+03	123000.00
4EF09F	2017-07-05 04:46:00+03	59300.00
4EF0AE	2017-08-01 22:53:00+03	4000.00
4EF0CE	2017-08-04 18:52:00+03	37900.00
4EF0E6	2017-07-28 19:49:00+03	85000.00
4EF0F7	2017-08-14 07:40:00+03	40400.00
4EF113	2017-08-01 08:20:00+03	28600.00
4EF18F	2017-07-18 19:33:00+03	35200.00
4EF196	2017-07-03 02:01:00+03	199700.00
4EF1E5	2017-08-03 09:54:00+03	283600.00
4EF242	2017-07-09 20:46:00+03	71800.00
4EF259	2017-08-13 23:11:00+03	39200.00
4EF27E	2017-07-06 01:52:00+03	6700.00
4EF2C5	2017-07-08 00:41:00+03	89200.00
4EF2E9	2017-07-28 00:46:00+03	81200.00
4EF2F8	2017-08-05 00:02:00+03	39200.00
4EF35A	2017-07-23 00:27:00+03	25600.00
4EF3B3	2017-07-16 20:04:00+03	32400.00
4EF3BE	2017-07-13 14:49:00+03	179300.00
4EF414	2017-08-04 18:54:00+03	111600.00
4EF438	2017-07-26 14:01:00+03	164400.00
4EF43F	2017-07-02 02:20:00+03	139100.00
4EF44B	2017-07-19 13:59:00+03	73300.00
4EF453	2017-07-13 23:19:00+03	111600.00
4EF479	2017-07-06 23:54:00+03	23400.00
4EF482	2017-07-11 14:08:00+03	28000.00
4EF491	2017-07-27 15:10:00+03	82600.00
4EF4DC	2017-07-08 04:25:00+03	36800.00
4EF4FD	2017-07-03 14:13:00+03	23200.00
4EF519	2017-08-10 22:11:00+03	28800.00
4EF529	2017-07-26 00:35:00+03	15000.00
4EF541	2017-08-02 22:28:00+03	56000.00
4EF561	2017-08-09 22:43:00+03	10800.00
4EF637	2017-07-04 19:35:00+03	6000.00
4EF685	2017-07-22 12:15:00+03	7400.00
4EF693	2017-08-12 23:12:00+03	150100.00
4EF696	2017-08-07 06:36:00+03	85000.00
4EF76B	2017-07-03 10:12:00+03	58600.00
4EF773	2017-07-15 15:49:00+03	390400.00
4EF787	2017-08-02 01:56:00+03	67200.00
4EF7DD	2017-07-08 16:54:00+03	24300.00
4EF800	2017-08-07 21:02:00+03	7400.00
4EF888	2017-07-21 05:18:00+03	52400.00
4EF9A3	2017-08-12 05:47:00+03	88300.00
4EF9CC	2017-07-15 13:52:00+03	77600.00
4EF9EA	2017-07-05 12:51:00+03	12600.00
4EF9FF	2017-08-03 12:06:00+03	40900.00
4EFA0E	2017-07-27 05:48:00+03	114400.00
4EFA65	2017-07-12 06:25:00+03	28000.00
4EFA6E	2017-07-27 17:51:00+03	44600.00
4EFA79	2017-07-04 18:12:00+03	40800.00
4EFAA1	2017-07-02 19:58:00+03	15800.00
4EFABC	2017-07-02 09:10:00+03	100200.00
4EFBAC	2017-07-12 16:56:00+03	31800.00
4EFBCB	2017-07-25 14:46:00+03	30400.00
4EFBD1	2017-07-27 01:18:00+03	33100.00
4EFBDC	2017-07-28 04:48:00+03	64800.00
4EFC03	2017-08-11 21:38:00+03	189200.00
4EFC2A	2017-07-15 03:50:00+03	48800.00
4EFC33	2017-07-11 22:58:00+03	83100.00
4EFC7A	2017-07-03 10:02:00+03	28600.00
4EFCD8	2017-07-29 17:29:00+03	48500.00
4EFD78	2017-07-06 05:00:00+03	118500.00
4EFD8A	2017-08-05 08:33:00+03	55800.00
4EFE0A	2017-08-08 19:11:00+03	39200.00
4EFE12	2017-07-18 09:29:00+03	456600.00
4EFE56	2017-08-01 15:24:00+03	55800.00
4EFE69	2017-07-12 09:08:00+03	265600.00
4EFF14	2017-08-08 00:56:00+03	185100.00
4EFF1E	2017-08-11 05:01:00+03	88000.00
4EFF31	2017-08-14 07:59:00+03	76800.00
4EFF60	2017-07-12 04:08:00+03	55800.00
4EFF92	2017-07-13 01:42:00+03	32200.00
4F000D	2017-07-25 22:16:00+03	38400.00
4F003A	2017-07-04 15:23:00+03	369000.00
4F003E	2017-08-12 00:06:00+03	114800.00
4F0052	2017-07-14 21:19:00+03	633700.00
4F00C4	2017-07-15 14:36:00+03	46400.00
4F00E0	2017-07-11 06:04:00+03	99200.00
4F01A5	2017-07-28 15:26:00+03	85000.00
4F01DC	2017-07-06 21:41:00+03	123000.00
4F0209	2017-07-10 21:06:00+03	13400.00
4F030D	2017-07-18 15:11:00+03	28800.00
4F0338	2017-07-12 04:13:00+03	71900.00
4F0354	2017-07-28 21:19:00+03	32700.00
4F0375	2017-07-25 20:06:00+03	13800.00
4F0377	2017-07-04 20:14:00+03	88500.00
4F037C	2017-07-09 13:10:00+03	440700.00
4F03B4	2017-07-20 20:42:00+03	48800.00
4F03FB	2017-08-14 04:06:00+03	119600.00
4F043F	2017-08-06 07:52:00+03	154500.00
4F0443	2017-07-13 23:19:00+03	15700.00
4F04AE	2017-07-14 11:15:00+03	55800.00
4F04D3	2017-07-22 21:32:00+03	56200.00
4F050C	2017-08-09 12:42:00+03	66600.00
4F05B4	2017-07-21 08:17:00+03	16800.00
4F05FC	2017-07-11 10:54:00+03	118300.00
4F0618	2017-07-31 00:16:00+03	56000.00
4F06B0	2017-07-06 15:29:00+03	46400.00
4F06B7	2017-08-03 07:46:00+03	9300.00
4F0712	2017-07-28 21:08:00+03	99300.00
4F0714	2017-07-30 22:18:00+03	134700.00
4F0739	2017-08-14 05:29:00+03	61200.00
4F077B	2017-08-04 14:09:00+03	36200.00
4F07C2	2017-07-22 09:17:00+03	55600.00
4F07F0	2017-07-18 18:26:00+03	66000.00
4F0848	2017-08-08 14:53:00+03	106400.00
4F0851	2017-07-14 14:37:00+03	101200.00
4F08D6	2017-07-31 20:50:00+03	48800.00
4F08E2	2017-07-11 04:48:00+03	27200.00
4F0968	2017-08-10 11:39:00+03	102300.00
4F096E	2017-07-13 21:47:00+03	22000.00
4F0A0C	2017-07-18 10:59:00+03	168000.00
4F0A5D	2017-07-24 14:50:00+03	34700.00
4F0A63	2017-07-27 10:41:00+03	95400.00
4F0AEE	2017-08-10 14:28:00+03	88800.00
4F0AF2	2017-07-20 07:19:00+03	123000.00
4F0B1D	2017-07-22 04:40:00+03	14000.00
4F0BD4	2017-07-22 09:51:00+03	14000.00
4F0C57	2017-07-15 21:53:00+03	19600.00
4F0CD0	2017-08-08 13:38:00+03	28000.00
4F0CDC	2017-07-25 22:04:00+03	23600.00
4F0D97	2017-07-12 02:07:00+03	31600.00
4F0DA4	2017-07-14 16:10:00+03	135800.00
4F0DB6	2017-08-10 07:56:00+03	10800.00
4F0DFF	2017-07-27 16:52:00+03	99600.00
4F0E20	2017-08-07 10:27:00+03	35800.00
4F0E77	2017-07-20 09:21:00+03	70800.00
4F0F48	2017-08-13 00:46:00+03	40800.00
4F0FD1	2017-07-17 00:30:00+03	69500.00
4F1021	2017-07-08 15:52:00+03	28000.00
4F1066	2017-08-03 15:28:00+03	14000.00
4F10A5	2017-07-28 01:47:00+03	12400.00
4F10C5	2017-08-13 09:17:00+03	95000.00
4F10D8	2017-07-20 02:03:00+03	28800.00
4F10D9	2017-08-07 12:15:00+03	8200.00
4F1166	2017-08-04 09:23:00+03	47100.00
4F119D	2017-07-04 19:20:00+03	16400.00
4F11CB	2017-07-24 11:01:00+03	131600.00
4F11EB	2017-08-01 09:07:00+03	68100.00
4F1221	2017-08-02 05:44:00+03	52800.00
4F12A5	2017-07-18 20:31:00+03	82600.00
4F12CF	2017-08-14 08:51:00+03	78800.00
4F1378	2017-07-28 01:48:00+03	25600.00
4F13AD	2017-07-27 08:44:00+03	118600.00
4F13C2	2017-07-30 22:15:00+03	168000.00
4F13C5	2017-08-08 19:11:00+03	20600.00
4F141A	2017-07-05 16:15:00+03	56000.00
4F141E	2017-08-11 12:55:00+03	24200.00
4F1437	2017-07-16 07:06:00+03	147900.00
4F146B	2017-06-28 12:57:00+03	78400.00
4F1484	2017-07-05 21:31:00+03	12600.00
4F1500	2017-07-05 10:18:00+03	56100.00
4F1536	2017-07-26 06:07:00+03	13600.00
4F15F6	2017-07-24 04:56:00+03	114800.00
4F1602	2017-07-16 18:50:00+03	188000.00
4F16B6	2017-07-08 18:36:00+03	95600.00
4F16F5	2017-08-15 05:41:00+03	63200.00
4F1723	2017-08-13 06:58:00+03	52000.00
4F172B	2017-07-24 15:02:00+03	94700.00
4F1781	2017-07-14 11:32:00+03	187600.00
4F17B5	2017-07-30 16:33:00+03	111600.00
4F17BA	2017-07-15 21:06:00+03	78100.00
4F17E8	2017-07-26 22:08:00+03	406700.00
4F17EA	2017-08-15 04:08:00+03	52000.00
4F1824	2017-08-02 21:38:00+03	68000.00
4F1844	2017-08-15 07:53:00+03	79300.00
4F1881	2017-07-18 19:42:00+03	167900.00
4F19CF	2017-07-08 15:51:00+03	56000.00
4F1A1C	2017-07-21 16:43:00+03	228000.00
4F1A46	2017-08-05 22:31:00+03	56600.00
4F1A5C	2017-08-06 10:02:00+03	102100.00
4F1A6C	2017-08-12 07:43:00+03	40600.00
4F1A79	2017-07-18 21:59:00+03	68800.00
4F1A84	2017-07-07 16:27:00+03	38600.00
4F1A99	2017-07-07 18:37:00+03	57500.00
4F1AA1	2017-07-15 03:36:00+03	26000.00
4F1B18	2017-08-07 09:01:00+03	116900.00
4F1B24	2017-08-05 03:42:00+03	12400.00
4F1B5A	2017-07-19 17:56:00+03	88000.00
4F1B6E	2017-08-05 04:59:00+03	109100.00
4F1B70	2017-07-08 12:28:00+03	6300.00
4F1B8E	2017-07-28 06:46:00+03	47000.00
4F1BB9	2017-07-25 16:41:00+03	37200.00
4F1BC0	2017-08-02 03:31:00+03	270000.00
4F1BFA	2017-07-29 22:18:00+03	86500.00
4F1BFE	2017-08-04 00:58:00+03	45000.00
4F1C3B	2017-07-02 06:02:00+03	66900.00
4F1C43	2017-08-13 17:37:00+03	66600.00
4F1C5A	2017-08-02 01:06:00+03	29200.00
4F1C94	2017-07-06 20:33:00+03	8000.00
4F1CD7	2017-07-20 09:31:00+03	86400.00
4F1D99	2017-07-04 11:06:00+03	166100.00
4F1DCD	2017-06-29 03:20:00+03	13600.00
4F1E2B	2017-08-06 11:19:00+03	13700.00
4F1EA6	2017-07-26 13:50:00+03	40600.00
4F1EC1	2017-08-14 14:51:00+03	45200.00
4F1F1E	2017-07-05 20:39:00+03	97900.00
4F1F41	2017-07-29 22:49:00+03	258400.00
4F1F4E	2017-07-22 02:31:00+03	67900.00
4F1F66	2017-07-30 15:47:00+03	38800.00
4F1FA6	2017-07-28 07:56:00+03	22000.00
4F1FF2	2017-08-13 21:56:00+03	24200.00
4F2075	2017-08-01 13:42:00+03	58600.00
4F208D	2017-07-28 17:32:00+03	75300.00
4F20E2	2017-07-14 00:54:00+03	12600.00
4F2169	2017-08-09 18:32:00+03	31400.00
4F216F	2017-07-16 04:11:00+03	30600.00
4F21BC	2017-07-26 17:04:00+03	149500.00
4F21DE	2017-07-08 13:22:00+03	117600.00
4F21E3	2017-08-05 20:56:00+03	40800.00
4F2206	2017-07-24 11:28:00+03	46200.00
4F2263	2017-07-26 04:04:00+03	46400.00
4F2295	2017-07-24 21:41:00+03	90300.00
4F22F9	2017-07-23 06:29:00+03	27900.00
4F2343	2017-07-24 08:26:00+03	20400.00
4F2361	2017-07-31 22:07:00+03	51200.00
4F2372	2017-07-11 20:20:00+03	25600.00
4F23A7	2017-08-09 02:48:00+03	12200.00
4F23DC	2017-07-15 04:04:00+03	26000.00
4F2424	2017-07-01 10:20:00+03	28300.00
4F244B	2017-08-08 23:57:00+03	58500.00
4F2492	2017-07-08 15:45:00+03	39800.00
4F249D	2017-07-26 03:42:00+03	176500.00
4F24C4	2017-07-28 20:01:00+03	25800.00
4F255E	2017-08-12 10:51:00+03	84500.00
4F25D4	2017-08-06 23:15:00+03	166900.00
4F2616	2017-07-07 07:56:00+03	40300.00
4F264C	2017-08-09 21:00:00+03	14000.00
4F2676	2017-07-12 08:02:00+03	21800.00
4F2684	2017-07-21 23:03:00+03	131600.00
4F268C	2017-08-11 16:50:00+03	133200.00
4F26A4	2017-07-07 14:21:00+03	19600.00
4F26A5	2017-08-05 22:32:00+03	78600.00
4F26BD	2017-07-10 17:34:00+03	117600.00
4F26DA	2017-07-17 17:01:00+03	24400.00
4F271F	2017-08-04 06:22:00+03	143200.00
4F2747	2017-07-09 22:17:00+03	177200.00
4F27B7	2017-07-04 13:00:00+03	24400.00
4F27C4	2017-07-23 12:42:00+03	19600.00
4F2844	2017-07-02 18:53:00+03	56600.00
4F28E1	2017-07-22 14:51:00+03	49300.00
4F2908	2017-07-20 14:57:00+03	31400.00
4F2953	2017-07-27 11:47:00+03	56000.00
4F29B4	2017-07-08 03:14:00+03	92800.00
4F29B8	2017-08-02 13:12:00+03	40200.00
4F29E0	2017-06-29 15:02:00+03	49400.00
4F29ED	2017-07-01 18:32:00+03	115300.00
4F2A38	2017-07-01 02:55:00+03	270700.00
4F2A56	2017-07-10 19:27:00+03	38800.00
4F2B34	2017-07-19 21:09:00+03	6700.00
4F2B67	2017-07-01 01:24:00+03	112000.00
4F2B8A	2017-07-17 01:47:00+03	32800.00
4F2B98	2017-07-18 11:52:00+03	133100.00
4F2BA4	2017-07-15 02:58:00+03	122800.00
4F2BA5	2017-07-06 21:56:00+03	23200.00
4F2BC6	2017-08-02 23:57:00+03	28900.00
4F2BE8	2017-07-20 09:24:00+03	37400.00
4F2C3B	2017-07-28 18:50:00+03	98400.00
4F2C46	2017-06-27 18:01:00+03	28000.00
4F2C5C	2017-07-19 06:44:00+03	54500.00
4F2CA3	2017-07-16 05:15:00+03	47400.00
4F2D8C	2017-07-07 10:45:00+03	29600.00
4F2DCC	2017-07-28 01:43:00+03	10800.00
4F2E33	2017-07-18 04:59:00+03	48500.00
4F2EA5	2017-07-15 15:47:00+03	246000.00
4F2EB2	2017-07-15 02:43:00+03	78800.00
4F2EBC	2017-08-15 05:56:00+03	138600.00
4F2EC3	2017-08-02 17:28:00+03	73600.00
4F2EDC	2017-08-05 23:28:00+03	27900.00
4F2EE8	2017-07-13 13:51:00+03	135400.00
4F2EFB	2017-07-28 00:27:00+03	72700.00
4F2F07	2017-07-11 20:11:00+03	24400.00
4F2F4A	2017-08-01 19:35:00+03	28800.00
4F2FB7	2017-08-08 06:19:00+03	92800.00
4F2FD2	2017-08-01 12:32:00+03	38000.00
4F2FD4	2017-07-25 09:34:00+03	68800.00
4F2FDB	2017-07-27 19:25:00+03	40900.00
4F3008	2017-06-29 14:16:00+03	137200.00
4F3021	2017-07-16 03:17:00+03	30200.00
4F3051	2017-07-03 08:02:00+03	116400.00
4F3053	2017-07-19 16:17:00+03	133200.00
4F3082	2017-07-30 14:31:00+03	393000.00
4F308F	2017-08-01 09:35:00+03	614800.00
4F3092	2017-07-10 01:28:00+03	43900.00
4F30B4	2017-07-24 20:18:00+03	73100.00
4F30CF	2017-08-05 12:43:00+03	136500.00
4F3131	2017-07-06 06:10:00+03	37900.00
4F3196	2017-07-12 15:54:00+03	241200.00
4F31AB	2017-07-27 14:27:00+03	135600.00
4F3203	2017-07-30 08:56:00+03	126200.00
4F3236	2017-07-23 15:08:00+03	51900.00
4F32E4	2017-08-10 04:00:00+03	26700.00
4F330C	2017-08-13 03:51:00+03	27200.00
4F335B	2017-07-14 00:25:00+03	72300.00
4F3360	2017-08-05 20:51:00+03	75600.00
4F3361	2017-07-12 04:31:00+03	155600.00
4F3370	2017-07-28 19:58:00+03	40100.00
4F3378	2017-08-05 12:04:00+03	6000.00
4F3392	2017-07-06 03:45:00+03	54600.00
4F33CE	2017-07-21 12:45:00+03	121100.00
4F3424	2017-07-23 03:41:00+03	169800.00
4F343D	2017-08-01 07:41:00+03	31400.00
4F34B8	2017-07-21 09:01:00+03	128800.00
4F34EB	2017-08-05 23:50:00+03	47100.00
4F3582	2017-07-13 04:45:00+03	124600.00
4F359B	2017-08-02 17:49:00+03	26000.00
4F35D6	2017-08-08 00:16:00+03	23200.00
4F35F9	2017-06-29 09:03:00+03	40400.00
4F360F	2017-07-09 01:30:00+03	62000.00
4F3658	2017-07-03 21:22:00+03	171500.00
4F3661	2017-07-14 10:14:00+03	393800.00
4F368B	2017-08-03 07:41:00+03	13800.00
4F36B0	2017-07-12 16:15:00+03	79900.00
4F36BB	2017-07-25 05:39:00+03	247600.00
4F37EB	2017-07-17 05:47:00+03	62700.00
4F3816	2017-07-23 06:09:00+03	72300.00
4F3820	2017-07-31 09:24:00+03	22000.00
4F3822	2017-07-11 03:16:00+03	71600.00
4F3842	2017-07-12 10:13:00+03	92800.00
4F3923	2017-08-02 02:02:00+03	92900.00
4F393C	2017-07-15 11:39:00+03	24700.00
4F3980	2017-07-29 19:47:00+03	88800.00
4F3A5A	2017-07-28 08:23:00+03	48800.00
4F3A65	2017-08-06 05:16:00+03	62900.00
4F3A95	2017-07-18 00:31:00+03	98400.00
4F3A99	2017-07-03 23:24:00+03	47100.00
4F3ABC	2017-07-17 12:13:00+03	24300.00
4F3B21	2017-07-07 23:39:00+03	36400.00
4F3B49	2017-08-02 01:07:00+03	26800.00
4F3B83	2017-06-30 14:48:00+03	48800.00
4F3BB0	2017-08-15 15:55:00+03	52800.00
4F3DA6	2017-07-21 00:00:00+03	23600.00
4F3DD6	2017-08-11 00:38:00+03	14400.00
4F3DDD	2017-08-05 18:40:00+03	26000.00
4F3DFF	2017-08-05 20:12:00+03	178800.00
4F3E1D	2017-07-09 15:40:00+03	104600.00
4F3E5F	2017-07-16 04:16:00+03	7400.00
4F3E91	2017-07-16 21:29:00+03	23200.00
4F3EB5	2017-07-24 03:48:00+03	42800.00
4F3EDC	2017-07-10 18:59:00+03	28000.00
4F3F41	2017-08-03 14:25:00+03	248400.00
4F3F56	2017-07-08 01:04:00+03	19600.00
4F3F92	2017-07-09 21:21:00+03	25800.00
4F3FC1	2017-07-20 14:44:00+03	60400.00
4F405F	2017-07-04 13:20:00+03	19600.00
4F4091	2017-07-10 01:22:00+03	82900.00
4F40AF	2017-08-04 00:17:00+03	69500.00
4F411D	2017-08-14 22:32:00+03	66800.00
4F4138	2017-07-15 10:25:00+03	112000.00
4F416B	2017-08-05 18:10:00+03	26800.00
4F4176	2017-07-20 13:55:00+03	8000.00
4F4194	2017-08-14 06:26:00+03	77400.00
4F41FD	2017-07-27 01:34:00+03	28300.00
4F4202	2017-08-10 19:03:00+03	23400.00
4F422A	2017-07-11 16:01:00+03	21800.00
4F428B	2017-08-09 22:19:00+03	184000.00
4F430D	2017-07-10 08:55:00+03	24200.00
4F431C	2017-08-05 07:10:00+03	20400.00
4F4357	2017-08-07 04:52:00+03	101200.00
4F4379	2017-08-07 06:40:00+03	59200.00
4F43A9	2017-08-14 08:05:00+03	100600.00
4F43B6	2017-07-19 08:56:00+03	28000.00
4F4417	2017-07-26 11:05:00+03	139500.00
4F441E	2017-07-22 03:25:00+03	28800.00
4F4494	2017-08-01 13:58:00+03	40800.00
4F44DB	2017-07-07 05:38:00+03	78000.00
4F451B	2017-07-31 02:14:00+03	71800.00
4F451D	2017-07-31 21:22:00+03	53400.00
4F4522	2017-08-04 13:17:00+03	37100.00
4F453F	2017-07-22 10:11:00+03	92800.00
4F4568	2017-07-22 01:37:00+03	34000.00
4F456D	2017-07-16 02:05:00+03	76400.00
4F45BC	2017-07-18 23:56:00+03	57500.00
4F45FE	2017-07-06 08:47:00+03	42400.00
4F460F	2017-07-23 01:29:00+03	147500.00
4F464A	2017-07-01 15:05:00+03	47000.00
4F465A	2017-07-15 13:28:00+03	26000.00
4F465B	2017-08-11 01:05:00+03	100600.00
4F46E8	2017-08-08 19:52:00+03	131100.00
4F4710	2017-08-04 09:54:00+03	115700.00
4F4723	2017-08-02 00:28:00+03	123000.00
4F477E	2017-07-25 20:12:00+03	130800.00
4F4794	2017-07-16 13:59:00+03	28600.00
4F4799	2017-07-28 05:56:00+03	55700.00
4F47DD	2017-07-20 02:37:00+03	20800.00
4F481E	2017-07-22 00:51:00+03	135000.00
4F4832	2017-08-02 22:48:00+03	28000.00
4F48A2	2017-08-10 16:56:00+03	19600.00
4F48BE	2017-07-20 15:38:00+03	139200.00
4F4983	2017-07-13 12:53:00+03	68100.00
4F4999	2017-08-05 09:18:00+03	199800.00
4F49CE	2017-08-13 07:58:00+03	67300.00
4F49E3	2017-07-25 02:05:00+03	65100.00
4F4A3C	2017-07-10 23:22:00+03	61800.00
4F4A70	2017-08-06 21:49:00+03	32900.00
4F4A83	2017-08-05 23:15:00+03	90600.00
4F4B00	2017-08-07 14:37:00+03	21800.00
4F4B5D	2017-08-13 15:32:00+03	24300.00
4F4B7C	2017-08-10 13:56:00+03	133200.00
4F4BBB	2017-06-29 00:16:00+03	133100.00
4F4BBF	2017-07-07 05:57:00+03	189800.00
4F4BDF	2017-08-11 17:06:00+03	272700.00
4F4C08	2017-08-15 11:06:00+03	23600.00
4F4C0A	2017-07-31 13:14:00+03	50400.00
4F4C50	2017-07-19 02:25:00+03	55800.00
4F4CB3	2017-07-19 07:43:00+03	158500.00
4F4CC3	2017-07-13 15:52:00+03	93400.00
4F4CD6	2017-07-26 08:58:00+03	28000.00
4F4D24	2017-08-07 20:28:00+03	54500.00
4F4D3F	2017-07-09 03:01:00+03	138100.00
4F4D44	2017-08-11 08:36:00+03	262200.00
4F4D83	2017-08-01 09:54:00+03	46400.00
4F4DAB	2017-07-03 04:06:00+03	26800.00
4F4E21	2017-07-09 01:05:00+03	54800.00
4F4E43	2017-07-29 05:45:00+03	6300.00
4F4E67	2017-08-07 22:03:00+03	260900.00
4F4EA6	2017-07-13 16:57:00+03	6000.00
4F4ED4	2017-07-13 15:39:00+03	19800.00
4F4EE6	2017-07-27 09:46:00+03	22800.00
4F4F49	2017-07-17 05:38:00+03	25800.00
4F4F7D	2017-07-11 22:42:00+03	114700.00
4F4FB0	2017-07-21 15:20:00+03	224000.00
4F5018	2017-07-20 23:14:00+03	49600.00
4F50AA	2017-07-07 22:54:00+03	25200.00
4F5116	2017-08-06 23:47:00+03	72400.00
4F512B	2017-07-14 13:24:00+03	28000.00
4F515F	2017-07-12 20:54:00+03	131100.00
4F51B4	2017-07-01 02:59:00+03	112000.00
4F5207	2017-08-08 10:16:00+03	90600.00
4F5336	2017-07-10 04:52:00+03	12600.00
4F537C	2017-07-18 10:04:00+03	24200.00
4F53A5	2017-08-12 18:07:00+03	246000.00
4F5422	2017-08-12 02:52:00+03	73300.00
4F5561	2017-08-14 22:56:00+03	24000.00
4F5578	2017-07-27 22:40:00+03	156500.00
4F560F	2017-07-22 04:16:00+03	73600.00
4F570F	2017-07-21 18:22:00+03	23400.00
4F5723	2017-07-13 01:16:00+03	31800.00
4F5796	2017-07-10 20:33:00+03	30200.00
4F5807	2017-07-12 17:13:00+03	14400.00
4F583A	2017-07-19 20:46:00+03	18500.00
4F5848	2017-07-05 04:57:00+03	101800.00
4F584D	2017-07-10 13:54:00+03	30000.00
4F58CB	2017-07-27 01:09:00+03	47200.00
4F5947	2017-07-15 13:42:00+03	25600.00
4F5975	2017-07-13 11:54:00+03	101000.00
4F598B	2017-07-01 04:02:00+03	196000.00
4F5A65	2017-07-18 03:55:00+03	25600.00
4F5AF3	2017-08-03 06:00:00+03	61800.00
4F5AF7	2017-07-27 22:03:00+03	63400.00
4F5C80	2017-07-12 20:09:00+03	14400.00
4F5C93	2017-06-29 12:39:00+03	87700.00
4F5CAA	2017-07-24 03:59:00+03	136800.00
4F5CD7	2017-07-24 09:46:00+03	75400.00
4F5CEF	2017-07-11 15:45:00+03	32700.00
4F5D8A	2017-07-02 08:05:00+03	147700.00
4F5E13	2017-07-19 14:12:00+03	6700.00
4F5EB8	2017-07-21 07:53:00+03	139500.00
4F5F10	2017-07-09 17:59:00+03	68100.00
4F5F4B	2017-08-01 03:48:00+03	28000.00
4F601C	2017-07-16 04:16:00+03	40200.00
4F6034	2017-07-19 07:22:00+03	86500.00
4F6043	2017-07-23 15:15:00+03	6000.00
4F6045	2017-08-09 23:01:00+03	128800.00
4F606C	2017-07-05 23:05:00+03	32800.00
4F6078	2017-07-22 05:16:00+03	29600.00
4F60B1	2017-07-03 16:06:00+03	31100.00
4F610B	2017-07-19 22:15:00+03	36000.00
4F6156	2017-07-23 05:12:00+03	118600.00
4F616E	2017-07-17 15:52:00+03	13400.00
4F61A8	2017-07-05 22:31:00+03	69600.00
4F6273	2017-07-02 02:01:00+03	53600.00
4F62A4	2017-07-12 11:41:00+03	147900.00
4F62BD	2017-07-02 21:51:00+03	260900.00
4F6314	2017-07-21 07:23:00+03	67700.00
4F637F	2017-07-30 11:04:00+03	40100.00
4F63BF	2017-07-28 22:28:00+03	46700.00
4F63C3	2017-08-02 06:11:00+03	8200.00
4F641F	2017-08-05 00:04:00+03	116800.00
4F6469	2017-08-15 09:12:00+03	38800.00
4F648D	2017-07-04 00:01:00+03	24800.00
4F64A5	2017-06-25 10:46:00+03	93900.00
4F64A9	2017-07-17 02:28:00+03	135600.00
4F6513	2017-08-06 05:28:00+03	49000.00
4F651D	2017-08-11 22:30:00+03	38500.00
4F6548	2017-07-21 04:40:00+03	55800.00
4F654F	2017-07-26 13:31:00+03	79200.00
4F658A	2017-08-07 01:22:00+03	246000.00
4F658F	2017-07-05 01:55:00+03	106400.00
4F659D	2017-07-04 05:38:00+03	17600.00
4F659F	2017-07-24 14:56:00+03	13400.00
4F65B5	2017-07-24 01:00:00+03	237700.00
4F65F7	2017-07-24 11:05:00+03	39500.00
4F65FF	2017-07-05 20:34:00+03	16400.00
4F666E	2017-08-01 10:10:00+03	10700.00
4F6682	2017-07-13 20:43:00+03	136800.00
4F66B4	2017-07-09 09:46:00+03	30800.00
4F6717	2017-07-07 07:57:00+03	74400.00
4F6731	2017-08-13 23:23:00+03	84100.00
4F6807	2017-08-11 10:01:00+03	30800.00
4F6840	2017-08-04 16:09:00+03	108500.00
4F685D	2017-07-11 09:23:00+03	15000.00
4F6865	2017-07-24 12:51:00+03	75300.00
4F6882	2017-07-05 15:22:00+03	17800.00
4F6893	2017-07-23 13:04:00+03	354200.00
4F68B4	2017-08-05 03:24:00+03	88500.00
4F6982	2017-07-04 16:39:00+03	60400.00
4F69C8	2017-07-19 01:53:00+03	68000.00
4F69FB	2017-07-08 06:13:00+03	287100.00
4F6A1B	2017-07-29 04:38:00+03	61800.00
4F6AAB	2017-07-11 21:06:00+03	14000.00
4F6AFF	2017-08-01 07:54:00+03	118400.00
4F6B58	2017-07-25 02:06:00+03	57400.00
4F6BA4	2017-07-14 18:15:00+03	143800.00
4F6BC2	2017-08-01 23:35:00+03	71000.00
4F6C60	2017-06-29 06:32:00+03	23600.00
4F6C68	2017-07-10 18:51:00+03	36200.00
4F6C6D	2017-07-15 15:32:00+03	25800.00
4F6C98	2017-07-18 22:46:00+03	70600.00
4F6D44	2017-08-10 00:33:00+03	13600.00
4F6DAA	2017-07-17 08:56:00+03	25000.00
4F6E05	2017-07-25 02:55:00+03	56000.00
4F6E13	2017-08-11 14:13:00+03	58800.00
4F6E2C	2017-06-30 07:02:00+03	28800.00
4F6E2F	2017-08-10 04:23:00+03	77000.00
4F6E3E	2017-07-18 01:41:00+03	57300.00
4F6ED3	2017-08-07 18:23:00+03	51900.00
4F6F0A	2017-08-02 01:15:00+03	40600.00
4F6FE7	2017-06-28 19:54:00+03	56900.00
4F7058	2017-07-02 10:09:00+03	243600.00
4F7068	2017-08-15 08:50:00+03	78400.00
4F70AE	2017-08-04 14:53:00+03	17800.00
4F70DB	2017-08-01 04:41:00+03	123900.00
4F7116	2017-08-05 12:27:00+03	28000.00
4F7151	2017-08-10 22:08:00+03	59100.00
4F716D	2017-08-13 01:38:00+03	39300.00
4F7191	2017-07-09 06:03:00+03	534500.00
4F71C9	2017-07-29 18:36:00+03	52300.00
4F71F3	2017-07-28 03:56:00+03	99300.00
4F71F7	2017-08-05 14:14:00+03	17000.00
4F720B	2017-08-01 23:17:00+03	22100.00
4F7219	2017-07-04 01:15:00+03	56900.00
4F7244	2017-07-18 01:51:00+03	147700.00
4F7270	2017-07-07 21:04:00+03	23400.00
4F727B	2017-07-04 07:54:00+03	46300.00
4F7285	2017-07-12 07:44:00+03	132100.00
4F7287	2017-08-13 08:55:00+03	58400.00
4F730E	2017-07-26 11:20:00+03	94800.00
4F731B	2017-08-09 11:24:00+03	133100.00
4F731F	2017-07-20 08:30:00+03	88600.00
4F7323	2017-07-12 11:51:00+03	19600.00
4F73BA	2017-07-20 19:41:00+03	35200.00
4F73E3	2017-08-05 19:30:00+03	22000.00
4F740D	2017-07-12 11:34:00+03	16400.00
4F741E	2017-07-09 04:51:00+03	111600.00
4F745F	2017-07-14 06:34:00+03	70700.00
4F7464	2017-07-11 19:13:00+03	28000.00
4F74A0	2017-07-31 17:14:00+03	126200.00
4F74C1	2017-07-09 13:19:00+03	21400.00
4F74D1	2017-07-26 19:27:00+03	16400.00
4F7512	2017-07-21 19:01:00+03	141100.00
4F755B	2017-07-04 11:01:00+03	72200.00
4F7570	2017-06-26 01:19:00+03	50600.00
4F757D	2017-08-07 17:45:00+03	19600.00
4F759B	2017-07-08 11:43:00+03	53400.00
4F75B7	2017-07-09 16:00:00+03	521500.00
4F75E7	2017-07-21 19:56:00+03	16400.00
4F765C	2017-07-02 02:56:00+03	50800.00
4F76A1	2017-08-11 08:58:00+03	56000.00
4F771A	2017-08-13 07:54:00+03	277000.00
4F773E	2017-07-11 17:21:00+03	56000.00
4F777A	2017-08-03 02:02:00+03	76600.00
4F77E1	2017-07-08 06:08:00+03	31000.00
4F7828	2017-07-16 16:50:00+03	40000.00
4F78C0	2017-08-01 03:20:00+03	58100.00
4F798E	2017-07-17 07:14:00+03	136600.00
4F79E2	2017-08-03 02:36:00+03	21200.00
4F7A5F	2017-08-03 20:33:00+03	70700.00
4F7A81	2017-07-13 10:40:00+03	45100.00
4F7B30	2017-08-03 16:22:00+03	38800.00
4F7B93	2017-08-06 05:50:00+03	56600.00
4F7C96	2017-07-19 10:29:00+03	57700.00
4F7D33	2017-07-25 03:38:00+03	12000.00
4F7DA4	2017-08-06 14:55:00+03	13700.00
4F7DA6	2017-08-14 06:03:00+03	26800.00
4F7E5E	2017-07-17 01:54:00+03	28000.00
4F7E95	2017-07-08 22:53:00+03	14800.00
4F7EFD	2017-07-30 00:06:00+03	24800.00
4F7F42	2017-08-10 14:35:00+03	24400.00
4F7F50	2017-08-03 01:33:00+03	68900.00
4F7F8F	2017-07-31 21:21:00+03	147700.00
4F7FEC	2017-08-12 02:41:00+03	26000.00
4F8020	2017-07-13 19:25:00+03	24400.00
4F8052	2017-08-14 04:40:00+03	137800.00
4F8088	2017-07-12 12:11:00+03	14400.00
4F81B9	2017-07-13 19:08:00+03	133200.00
4F83BE	2017-07-09 21:13:00+03	43200.00
4F83CE	2017-08-03 12:15:00+03	28000.00
4F83F2	2017-07-26 15:02:00+03	296400.00
4F842C	2017-07-13 18:47:00+03	53600.00
4F8496	2017-08-04 15:04:00+03	54300.00
4F8527	2017-07-19 21:29:00+03	23100.00
4F8530	2017-08-08 22:01:00+03	81600.00
4F85D7	2017-08-08 12:13:00+03	32800.00
4F860E	2017-08-02 07:10:00+03	8000.00
4F8610	2017-08-02 14:40:00+03	20800.00
4F8631	2017-08-14 02:14:00+03	81600.00
4F864D	2017-08-15 04:26:00+03	270200.00
4F864F	2017-07-16 23:40:00+03	104600.00
4F86B6	2017-08-14 23:38:00+03	26700.00
4F8747	2017-08-01 15:54:00+03	45200.00
4F87C5	2017-07-30 16:50:00+03	46000.00
4F8828	2017-07-21 14:46:00+03	59800.00
4F882C	2017-07-26 19:36:00+03	23200.00
4F8836	2017-07-13 14:53:00+03	46000.00
4F887E	2017-08-11 03:09:00+03	37200.00
4F88A5	2017-08-07 21:38:00+03	43200.00
4F88D2	2017-07-07 07:56:00+03	18600.00
4F88EA	2017-07-09 17:14:00+03	52400.00
4F88EC	2017-08-06 12:43:00+03	52100.00
4F8918	2017-07-02 10:55:00+03	47400.00
4F891F	2017-07-24 08:40:00+03	23200.00
4F8965	2017-07-22 19:02:00+03	123000.00
4F8998	2017-08-01 03:16:00+03	28000.00
4F8A27	2017-08-01 05:16:00+03	41800.00
4F8A50	2017-08-13 10:19:00+03	26000.00
4F8AB1	2017-08-11 06:04:00+03	28800.00
4F8B0D	2017-07-20 11:45:00+03	6300.00
4F8B88	2017-08-03 00:39:00+03	15900.00
4F8B93	2017-07-20 07:27:00+03	47200.00
4F8BBD	2017-07-17 21:21:00+03	15800.00
4F8C18	2017-08-10 16:13:00+03	8600.00
4F8C31	2017-08-02 06:26:00+03	37700.00
4F8C84	2017-07-06 18:42:00+03	26000.00
4F8C8A	2017-07-11 11:35:00+03	28800.00
4F8C9B	2017-07-16 05:46:00+03	42100.00
4F8D99	2017-08-11 09:00:00+03	89800.00
4F8E01	2017-07-23 06:09:00+03	52800.00
4F8E38	2017-08-08 11:56:00+03	48800.00
4F8E8A	2017-07-11 21:58:00+03	188300.00
4F8E9D	2017-08-09 06:31:00+03	65000.00
4F8EAD	2017-08-08 09:13:00+03	128800.00
4F8F04	2017-07-19 07:19:00+03	92600.00
4F8F21	2017-07-21 09:54:00+03	55800.00
4F8F38	2017-07-14 18:35:00+03	47200.00
4F8F8C	2017-07-10 01:57:00+03	23200.00
4F8FF1	2017-07-24 15:15:00+03	40800.00
4F9015	2017-07-10 18:05:00+03	53600.00
4F902E	2017-07-05 21:48:00+03	290600.00
4F907A	2017-07-31 19:43:00+03	6300.00
4F90A8	2017-07-23 17:39:00+03	20000.00
4F90DF	2017-08-08 08:51:00+03	135600.00
4F90F8	2017-08-09 23:25:00+03	318000.00
4F9105	2017-08-08 01:07:00+03	40800.00
4F9130	2017-07-11 05:10:00+03	28800.00
4F9137	2017-07-16 06:08:00+03	40000.00
4F9175	2017-08-14 17:01:00+03	39000.00
4F91D9	2017-07-31 19:22:00+03	23600.00
4F91F9	2017-07-14 04:52:00+03	26000.00
4F9275	2017-07-16 15:12:00+03	392700.00
4F92EE	2017-08-10 05:35:00+03	36800.00
4F932E	2017-08-01 15:47:00+03	111600.00
4F93E9	2017-07-06 14:26:00+03	406100.00
4F946E	2017-07-21 14:00:00+03	155600.00
4F947E	2017-07-31 00:18:00+03	141600.00
4F9482	2017-07-16 20:53:00+03	71600.00
4F94ED	2017-07-04 21:28:00+03	23600.00
4F956C	2017-08-11 01:13:00+03	81700.00
4F95A7	2017-08-11 03:05:00+03	136200.00
4F95B2	2017-06-26 11:38:00+03	16400.00
4F95C9	2017-08-01 03:21:00+03	75600.00
4F9626	2017-08-02 19:56:00+03	99300.00
4F9634	2017-07-03 16:36:00+03	88900.00
4F96B0	2017-07-06 03:09:00+03	49100.00
4F96C9	2017-08-03 21:59:00+03	104600.00
4F96DA	2017-08-04 05:15:00+03	70700.00
4F96E2	2017-07-03 20:31:00+03	26200.00
4F97A3	2017-07-05 13:11:00+03	13400.00
4F97F5	2017-08-10 13:23:00+03	40000.00
4F9802	2017-08-13 07:11:00+03	55800.00
4F98AB	2017-07-31 06:08:00+03	23200.00
4F98B2	2017-07-14 08:29:00+03	67700.00
4F98B7	2017-07-02 13:12:00+03	23200.00
4F98C5	2017-07-11 02:17:00+03	46300.00
4F98FD	2017-07-29 22:48:00+03	27200.00
4F9920	2017-07-16 20:06:00+03	55800.00
4F996D	2017-08-14 11:13:00+03	118600.00
4F99AB	2017-06-28 06:47:00+03	38800.00
4F99C1	2017-06-28 04:33:00+03	56000.00
4F9A1B	2017-07-10 20:27:00+03	198400.00
4F9A6F	2017-07-19 18:14:00+03	6000.00
4F9B00	2017-07-07 20:40:00+03	62500.00
4F9B55	2017-08-05 19:33:00+03	16200.00
4F9B62	2017-08-02 18:30:00+03	28000.00
4F9B67	2017-08-13 07:09:00+03	81600.00
4F9BF4	2017-07-29 11:19:00+03	69000.00
4F9BFC	2017-07-20 08:09:00+03	128800.00
4F9C45	2017-08-05 19:48:00+03	14000.00
4F9C6A	2017-08-14 15:28:00+03	20000.00
4F9CF1	2017-07-24 16:51:00+03	14000.00
4F9D85	2017-08-10 22:56:00+03	41400.00
4F9DA7	2017-07-03 03:06:00+03	48800.00
4F9DEB	2017-07-21 07:38:00+03	86800.00
4F9E01	2017-07-07 00:55:00+03	20700.00
4F9E06	2017-07-19 01:14:00+03	54000.00
4F9E21	2017-08-15 02:41:00+03	25600.00
4F9E4E	2017-07-10 14:37:00+03	99300.00
4F9EBD	2017-07-24 19:39:00+03	68300.00
4F9ECF	2017-08-15 01:33:00+03	38300.00
4F9F90	2017-07-10 18:56:00+03	22100.00
4F9FCC	2017-07-20 22:53:00+03	70700.00
4F9FDC	2017-07-02 01:25:00+03	71000.00
4FA007	2017-07-23 07:09:00+03	47700.00
4FA015	2017-08-13 15:15:00+03	55800.00
4FA023	2017-07-19 19:18:00+03	8000.00
4FA034	2017-07-01 15:53:00+03	183100.00
4FA042	2017-07-02 10:22:00+03	303500.00
4FA06C	2017-07-08 04:10:00+03	15700.00
4FA07E	2017-07-05 13:15:00+03	56000.00
4FA09D	2017-07-17 12:01:00+03	62000.00
4FA0BF	2017-08-08 08:38:00+03	86500.00
4FA0CD	2017-07-14 18:27:00+03	24300.00
4FA14C	2017-08-12 10:49:00+03	39500.00
4FA180	2017-07-25 15:24:00+03	103600.00
4FA1A4	2017-07-29 02:53:00+03	236700.00
4FA1B3	2017-07-06 07:31:00+03	62900.00
4FA214	2017-07-09 14:49:00+03	46000.00
4FA23D	2017-08-12 01:01:00+03	34000.00
4FA246	2017-07-08 21:30:00+03	46400.00
4FA2A7	2017-08-04 07:07:00+03	34700.00
4FA365	2017-07-16 07:23:00+03	150000.00
4FA380	2017-07-01 04:48:00+03	8200.00
4FA3A6	2017-08-14 00:53:00+03	143100.00
4FA3B5	2017-08-13 14:10:00+03	25100.00
4FA452	2017-07-24 01:45:00+03	21800.00
4FA49C	2017-07-18 09:37:00+03	12700.00
4FA57D	2017-07-29 15:29:00+03	78800.00
4FA5AD	2017-07-17 04:33:00+03	46800.00
4FA5BB	2017-07-24 09:35:00+03	29600.00
4FA5DE	2017-08-14 04:46:00+03	55800.00
4FA5FB	2017-08-03 16:15:00+03	21800.00
4FA606	2017-08-02 16:44:00+03	136500.00
4FA6BF	2017-08-12 03:20:00+03	73200.00
4FA743	2017-08-02 17:36:00+03	189200.00
4FA81A	2017-07-27 00:44:00+03	31400.00
4FA821	2017-08-08 02:35:00+03	66600.00
4FA86B	2017-08-02 09:20:00+03	35700.00
4FA872	2017-07-11 05:32:00+03	43500.00
4FA884	2017-07-03 18:00:00+03	20000.00
4FA886	2017-07-25 12:19:00+03	58000.00
4FA88A	2017-06-25 01:59:00+03	27200.00
4FA9D8	2017-07-24 16:38:00+03	133200.00
4FA9E7	2017-07-23 06:35:00+03	75300.00
4FAA0F	2017-08-13 10:58:00+03	78300.00
4FAA25	2017-07-03 22:21:00+03	60700.00
4FAA47	2017-07-22 23:32:00+03	176600.00
4FAA90	2017-07-11 02:43:00+03	111600.00
4FAAF2	2017-07-09 16:27:00+03	35800.00
4FAB86	2017-07-09 01:15:00+03	51900.00
4FAB98	2017-08-07 23:04:00+03	91600.00
4FAC14	2017-07-09 15:51:00+03	59900.00
4FAC8D	2017-08-02 02:59:00+03	26800.00
4FACFE	2017-08-14 03:54:00+03	13700.00
4FAD62	2017-07-30 15:57:00+03	55600.00
4FAE2F	2017-08-14 14:33:00+03	114900.00
4FAEB6	2017-08-04 11:48:00+03	6200.00
4FAEE3	2017-08-09 23:49:00+03	134400.00
4FAF0B	2017-06-29 18:24:00+03	12200.00
4FAF47	2017-08-05 23:44:00+03	143200.00
4FAF4A	2017-07-02 06:22:00+03	36800.00
4FAF57	2017-07-24 11:04:00+03	75600.00
4FAF7A	2017-07-19 10:42:00+03	159800.00
4FAFD6	2017-07-06 07:55:00+03	394400.00
4FB02B	2017-08-03 21:03:00+03	9300.00
4FB055	2017-07-07 21:09:00+03	14000.00
4FB062	2017-08-15 04:29:00+03	6400.00
4FB09D	2017-07-13 20:33:00+03	140000.00
4FB0EF	2017-07-06 10:06:00+03	135400.00
4FB0FC	2017-07-11 11:05:00+03	6800.00
4FB0FE	2017-07-22 09:27:00+03	154500.00
4FB100	2017-08-14 17:43:00+03	116100.00
4FB106	2017-08-14 01:35:00+03	114800.00
4FB143	2017-07-07 04:28:00+03	102100.00
4FB145	2017-08-14 18:12:00+03	26700.00
4FB156	2017-06-28 21:07:00+03	70700.00
4FB19A	2017-07-30 05:15:00+03	226200.00
4FB1FE	2017-08-10 08:02:00+03	16400.00
4FB217	2017-06-30 13:53:00+03	53400.00
4FB225	2017-07-14 06:27:00+03	6800.00
4FB233	2017-07-10 08:10:00+03	95600.00
4FB23D	2017-07-21 18:35:00+03	46000.00
4FB253	2017-08-07 18:58:00+03	6300.00
4FB296	2017-08-08 22:52:00+03	59200.00
4FB2DD	2017-08-03 20:40:00+03	54000.00
4FB325	2017-07-19 14:16:00+03	77900.00
4FB342	2017-07-15 15:20:00+03	12600.00
4FB386	2017-07-07 15:20:00+03	92800.00
4FB38A	2017-07-08 12:25:00+03	35600.00
4FB3E5	2017-07-03 10:59:00+03	59800.00
4FB3FF	2017-07-29 16:44:00+03	369000.00
4FB4C1	2017-07-11 20:30:00+03	38600.00
4FB4DC	2017-08-12 08:57:00+03	35700.00
4FB4ED	2017-07-21 17:40:00+03	42800.00
4FB521	2017-08-05 11:25:00+03	46300.00
4FB523	2017-07-05 17:49:00+03	50800.00
4FB553	2017-07-12 14:30:00+03	21400.00
4FB5F2	2017-08-15 11:00:00+03	160700.00
4FB5FE	2017-08-03 19:04:00+03	28800.00
4FB67F	2017-08-07 10:44:00+03	23400.00
4FB6A9	2017-07-31 18:30:00+03	30200.00
4FB6BA	2017-07-26 21:42:00+03	23200.00
4FB6F7	2017-08-04 09:32:00+03	56600.00
4FB706	2017-07-13 00:38:00+03	55800.00
4FB728	2017-07-19 19:27:00+03	48800.00
4FB72D	2017-07-24 00:45:00+03	43800.00
4FB7B6	2017-08-15 02:42:00+03	412000.00
4FB7D7	2017-07-18 18:39:00+03	27700.00
4FB82F	2017-07-16 22:06:00+03	112000.00
4FB873	2017-07-31 21:19:00+03	68100.00
4FB885	2017-07-18 00:22:00+03	34000.00
4FB8BC	2017-07-16 22:48:00+03	7400.00
4FB8DD	2017-08-07 05:18:00+03	29000.00
4FB90E	2017-07-29 04:02:00+03	179300.00
4FB917	2017-07-21 01:14:00+03	13600.00
4FB93D	2017-07-23 19:31:00+03	111700.00
4FB978	2017-07-16 22:50:00+03	98200.00
4FB98F	2017-07-29 08:36:00+03	56000.00
4FB9D2	2017-08-09 07:04:00+03	68800.00
4FBA10	2017-08-01 09:11:00+03	46300.00
4FBA32	2017-08-12 05:03:00+03	179200.00
4FBA53	2017-07-11 02:23:00+03	80800.00
4FBA64	2017-08-11 22:24:00+03	56000.00
4FBA6C	2017-08-12 14:32:00+03	98400.00
4FBA8F	2017-08-13 20:46:00+03	16400.00
4FBAD6	2017-07-29 11:43:00+03	163500.00
4FBAE9	2017-07-31 17:45:00+03	31100.00
4FBB08	2017-07-02 00:40:00+03	21800.00
4FBC3E	2017-07-17 08:17:00+03	112000.00
4FBC48	2017-07-26 13:18:00+03	40600.00
4FBC5E	2017-07-07 04:15:00+03	57500.00
4FBD02	2017-07-10 01:43:00+03	156000.00
4FBD7F	2017-07-18 02:44:00+03	10800.00
4FBE9B	2017-08-11 12:42:00+03	12600.00
4FBEBA	2017-07-27 15:16:00+03	72400.00
4FBEC6	2017-07-22 14:19:00+03	279800.00
4FBF46	2017-07-31 05:53:00+03	36200.00
4FBF5C	2017-08-05 07:11:00+03	42400.00
4FBF91	2017-07-17 14:02:00+03	240600.00
4FBFA7	2017-07-03 13:06:00+03	380700.00
4FBFB3	2017-07-19 17:03:00+03	50600.00
4FC000	2017-08-04 18:57:00+03	47600.00
4FC04D	2017-07-21 15:23:00+03	57400.00
4FC05E	2017-07-16 07:47:00+03	246000.00
4FC0A4	2017-07-14 13:39:00+03	58200.00
4FC115	2017-07-05 14:03:00+03	28800.00
4FC140	2017-07-14 10:55:00+03	144000.00
4FC16E	2017-08-10 15:13:00+03	56000.00
4FC18B	2017-08-15 00:19:00+03	66600.00
4FC1C5	2017-07-14 13:45:00+03	58900.00
4FC1D8	2017-08-15 06:49:00+03	192500.00
4FC1F3	2017-07-08 03:52:00+03	84300.00
4FC22E	2017-07-07 13:57:00+03	28800.00
4FC236	2017-07-02 23:06:00+03	92700.00
4FC291	2017-08-12 20:26:00+03	20600.00
4FC2CC	2017-08-12 18:56:00+03	64200.00
4FC2F6	2017-08-14 02:44:00+03	89600.00
4FC3A2	2017-08-06 22:14:00+03	13400.00
4FC407	2017-08-01 04:01:00+03	92000.00
4FC409	2017-08-13 13:48:00+03	57400.00
4FC40F	2017-07-02 03:52:00+03	13200.00
4FC448	2017-07-10 06:20:00+03	56000.00
4FC4DF	2017-07-13 07:20:00+03	92700.00
4FC52A	2017-07-27 05:34:00+03	76600.00
4FC657	2017-08-14 01:24:00+03	42600.00
4FC6FB	2017-08-05 00:32:00+03	284400.00
4FC718	2017-07-26 18:15:00+03	46300.00
4FC747	2017-07-05 01:07:00+03	174600.00
4FC75A	2017-07-13 04:50:00+03	119500.00
4FC776	2017-07-25 17:50:00+03	37800.00
4FC794	2017-08-07 14:32:00+03	9300.00
4FC797	2017-08-09 10:40:00+03	56600.00
4FC7B7	2017-07-21 07:24:00+03	57400.00
4FC7F2	2017-08-06 15:32:00+03	85400.00
4FC88A	2017-07-16 07:15:00+03	46000.00
4FC8D3	2017-07-23 13:59:00+03	13400.00
4FC985	2017-08-03 15:10:00+03	28000.00
4FC9A4	2017-08-10 07:18:00+03	44000.00
4FC9B1	2017-07-14 19:23:00+03	9800.00
4FC9D3	2017-07-24 16:01:00+03	75600.00
4FC9E6	2017-08-12 17:36:00+03	281500.00
4FC9FB	2017-07-26 22:25:00+03	58400.00
4FCA10	2017-08-02 14:18:00+03	28000.00
4FCA2F	2017-07-09 03:01:00+03	67600.00
4FCA4B	2017-07-24 10:10:00+03	56000.00
4FCA92	2017-07-12 14:10:00+03	46800.00
4FCABB	2017-08-10 12:16:00+03	58000.00
4FCAC9	2017-07-03 12:08:00+03	179400.00
4FCAF8	2017-08-09 10:30:00+03	95600.00
4FCB0C	2017-06-29 18:54:00+03	101200.00
4FCC1C	2017-08-07 23:07:00+03	39300.00
4FCC84	2017-08-09 10:10:00+03	57400.00
4FCD0A	2017-07-21 18:24:00+03	41200.00
4FCD33	2017-08-08 07:19:00+03	103500.00
4FCDCB	2017-07-27 13:58:00+03	90000.00
4FCDF4	2017-07-13 19:10:00+03	14000.00
4FCE31	2017-06-27 12:49:00+03	281500.00
4FCEA9	2017-07-15 16:18:00+03	30100.00
4FCEB1	2017-08-14 21:20:00+03	111000.00
4FCEE5	2017-08-15 02:26:00+03	196900.00
4FCEE6	2017-07-07 20:07:00+03	33300.00
4FCF11	2017-07-21 21:28:00+03	128800.00
4FCFB0	2017-07-23 08:01:00+03	202300.00
4FD023	2017-08-09 04:22:00+03	28800.00
4FD02B	2017-07-06 06:39:00+03	26000.00
4FD070	2017-07-10 13:58:00+03	52400.00
4FD08B	2017-08-08 21:47:00+03	265700.00
4FD0C1	2017-07-12 07:41:00+03	67600.00
4FD0CD	2017-07-30 20:57:00+03	124200.00
4FD10B	2017-07-20 15:44:00+03	28000.00
4FD10C	2017-08-15 11:17:00+03	111400.00
4FD177	2017-07-28 02:40:00+03	139300.00
4FD182	2017-07-25 01:08:00+03	28000.00
4FD1A1	2017-07-06 14:14:00+03	75600.00
4FD1AE	2017-07-28 05:33:00+03	46700.00
4FD1EF	2017-07-15 05:16:00+03	14800.00
4FD202	2017-07-03 18:26:00+03	11900.00
4FD22B	2017-08-07 04:03:00+03	16400.00
4FD233	2017-07-19 07:06:00+03	6300.00
4FD29A	2017-07-20 14:16:00+03	14000.00
4FD311	2017-07-06 10:25:00+03	119700.00
4FD368	2017-08-02 06:20:00+03	126700.00
4FD388	2017-07-13 19:50:00+03	79800.00
4FD39A	2017-08-10 14:33:00+03	66000.00
4FD39E	2017-07-19 10:22:00+03	79600.00
4FD40B	2017-08-03 13:30:00+03	21800.00
4FD55D	2017-08-07 17:04:00+03	55600.00
4FD56E	2017-07-28 22:22:00+03	6000.00
4FD5DC	2017-07-09 20:29:00+03	58200.00
4FD75B	2017-07-07 12:06:00+03	55800.00
4FD761	2017-08-15 16:23:00+03	55800.00
4FD7D4	2017-07-13 12:08:00+03	77000.00
4FD979	2017-07-17 10:31:00+03	273000.00
4FDA51	2017-07-02 05:51:00+03	45200.00
4FDA5C	2017-07-07 07:31:00+03	57800.00
4FDA94	2017-07-08 11:29:00+03	40800.00
4FDB90	2017-08-01 05:31:00+03	47100.00
4FDBB7	2017-07-01 01:03:00+03	31700.00
4FDBDE	2017-07-14 16:09:00+03	75300.00
4FDBE5	2017-08-06 15:16:00+03	51900.00
4FDBF5	2017-07-25 16:08:00+03	123000.00
4FDC18	2017-07-04 04:17:00+03	138500.00
4FDC70	2017-07-09 02:14:00+03	156000.00
4FDC9D	2017-08-10 16:36:00+03	26800.00
4FDCD1	2017-07-04 05:33:00+03	55600.00
4FDDA2	2017-07-28 22:56:00+03	496700.00
4FDE46	2017-08-12 03:39:00+03	31600.00
4FDE8F	2017-07-21 03:45:00+03	12000.00
4FDEAC	2017-07-28 19:26:00+03	66600.00
4FDEDF	2017-07-28 03:42:00+03	20800.00
4FDEF5	2017-08-03 22:39:00+03	50600.00
4FDF2C	2017-07-14 02:55:00+03	131900.00
4FDF66	2017-07-06 14:18:00+03	271200.00
4FDF6C	2017-07-31 21:04:00+03	44100.00
4FDFB6	2017-08-10 01:34:00+03	271100.00
4FDFCD	2017-08-03 12:11:00+03	23600.00
4FDFEE	2017-08-09 15:17:00+03	28000.00
4FE002	2017-07-08 08:39:00+03	139000.00
4FE027	2017-07-21 09:43:00+03	34000.00
4FE08B	2017-08-02 08:27:00+03	39800.00
4FE0F1	2017-06-30 17:45:00+03	26600.00
4FE0FD	2017-07-14 09:56:00+03	135400.00
4FE105	2017-07-04 09:04:00+03	31600.00
4FE180	2017-08-09 20:54:00+03	32200.00
4FE181	2017-07-16 01:54:00+03	23200.00
4FE209	2017-07-21 19:24:00+03	189800.00
4FE20C	2017-07-31 21:55:00+03	27200.00
4FE26D	2017-07-26 13:26:00+03	82700.00
4FE2BF	2017-07-16 14:45:00+03	56000.00
4FE2C4	2017-08-05 04:40:00+03	155600.00
4FE30E	2017-07-03 06:28:00+03	46200.00
4FE313	2017-08-13 04:30:00+03	23200.00
4FE32F	2017-08-11 08:02:00+03	56600.00
4FE382	2017-07-15 04:41:00+03	124200.00
4FE384	2017-07-24 17:13:00+03	39500.00
4FE392	2017-07-03 14:26:00+03	179700.00
4FE3C6	2017-08-14 11:27:00+03	240500.00
4FE410	2017-07-24 08:17:00+03	480600.00
4FE473	2017-08-13 23:58:00+03	258700.00
4FE4CF	2017-07-04 04:49:00+03	87800.00
4FE5D0	2017-07-19 23:13:00+03	43800.00
4FE5FD	2017-07-03 10:11:00+03	114800.00
4FE646	2017-07-24 21:05:00+03	67900.00
4FE744	2017-07-18 22:52:00+03	59000.00
4FE768	2017-07-22 23:19:00+03	136200.00
4FE77D	2017-07-10 11:45:00+03	15000.00
4FE7AB	2017-08-09 17:24:00+03	91800.00
4FE7CB	2017-07-13 21:33:00+03	65100.00
4FE7DE	2017-07-31 13:42:00+03	151900.00
4FE8CB	2017-07-05 13:52:00+03	281500.00
4FE8D9	2017-08-04 13:48:00+03	37200.00
4FE93F	2017-07-12 01:08:00+03	60800.00
4FE967	2017-08-11 03:05:00+03	34700.00
4FEA01	2017-08-12 16:18:00+03	135600.00
4FEA2A	2017-07-10 02:29:00+03	29600.00
4FEA43	2017-07-13 03:07:00+03	86600.00
4FEAA4	2017-07-08 20:29:00+03	24800.00
4FEAAE	2017-08-11 12:21:00+03	83200.00
4FEAE7	2017-08-12 06:37:00+03	182300.00
4FEB10	2017-06-29 07:48:00+03	94900.00
4FEB28	2017-08-07 05:46:00+03	114800.00
4FEB2F	2017-08-09 23:08:00+03	199700.00
4FEBA9	2017-07-23 10:25:00+03	36800.00
4FEBBB	2017-07-10 09:47:00+03	70800.00
4FEBC9	2017-07-16 02:52:00+03	38200.00
4FEBDF	2017-07-15 16:42:00+03	92000.00
4FED4E	2017-07-05 09:41:00+03	7400.00
4FED51	2017-07-23 08:02:00+03	32300.00
4FED85	2017-08-05 13:21:00+03	61800.00
4FEDB9	2017-08-05 09:17:00+03	16400.00
4FEE39	2017-07-29 06:14:00+03	52300.00
4FEE8E	2017-07-30 04:54:00+03	56600.00
4FEE98	2017-07-10 06:26:00+03	71800.00
4FEEB7	2017-07-19 20:16:00+03	92000.00
4FEEE5	2017-07-18 10:33:00+03	19600.00
4FEF14	2017-07-09 12:47:00+03	13200.00
4FEFD1	2017-07-30 13:23:00+03	123000.00
4FF02F	2017-07-15 23:33:00+03	28000.00
4FF03B	2017-07-24 23:47:00+03	26800.00
4FF079	2017-07-04 10:19:00+03	125100.00
4FF07E	2017-08-03 22:55:00+03	106900.00
4FF095	2017-07-28 12:23:00+03	129700.00
4FF0A2	2017-08-14 00:07:00+03	112000.00
4FF0A7	2017-07-13 14:53:00+03	103800.00
4FF0B3	2017-07-06 07:35:00+03	96200.00
4FF0C7	2017-07-15 22:10:00+03	76900.00
4FF0FE	2017-07-05 01:12:00+03	198400.00
4FF198	2017-07-13 07:54:00+03	75300.00
4FF20B	2017-07-03 15:58:00+03	51600.00
4FF215	2017-07-30 02:39:00+03	202800.00
4FF229	2017-08-14 04:32:00+03	27200.00
4FF244	2017-07-04 01:01:00+03	23600.00
4FF24F	2017-07-01 06:28:00+03	57600.00
4FF278	2017-07-28 09:25:00+03	156100.00
4FF294	2017-07-30 16:12:00+03	28000.00
4FF2AE	2017-06-30 08:51:00+03	18600.00
4FF2CF	2017-07-14 15:12:00+03	35800.00
4FF330	2017-07-21 02:18:00+03	133200.00
4FF36A	2017-07-23 19:01:00+03	94000.00
4FF39E	2017-07-10 20:00:00+03	35300.00
4FF3DB	2017-07-10 09:32:00+03	30800.00
4FF3F2	2017-07-31 18:49:00+03	94000.00
4FF3FE	2017-07-21 01:03:00+03	38800.00
4FF40F	2017-08-09 06:45:00+03	67200.00
4FF449	2017-07-19 08:24:00+03	134400.00
4FF4C4	2017-07-24 06:38:00+03	6000.00
4FF5A8	2017-08-12 20:00:00+03	137600.00
4FF5DC	2017-07-14 12:27:00+03	13200.00
4FF608	2017-07-24 09:26:00+03	56000.00
4FF60B	2017-07-30 09:59:00+03	24400.00
4FF6C0	2017-08-05 10:56:00+03	74600.00
4FF6D5	2017-08-12 21:49:00+03	46300.00
4FF716	2017-07-27 15:24:00+03	135600.00
4FF71C	2017-07-16 19:57:00+03	181100.00
4FF77E	2017-08-08 19:21:00+03	30400.00
4FF7F6	2017-07-26 15:00:00+03	86800.00
4FF89C	2017-08-10 04:28:00+03	160900.00
4FF8F5	2017-07-26 13:34:00+03	177600.00
4FF999	2017-08-03 09:54:00+03	78000.00
4FF9A0	2017-07-12 05:19:00+03	25100.00
4FF9FF	2017-08-15 00:10:00+03	136400.00
4FFA3B	2017-07-08 06:29:00+03	13400.00
4FFA64	2017-07-20 21:41:00+03	62000.00
4FFA73	2017-07-19 22:34:00+03	55800.00
4FFA8C	2017-08-01 09:13:00+03	30000.00
4FFB91	2017-07-06 23:18:00+03	58400.00
4FFBAC	2017-07-21 09:08:00+03	112000.00
4FFC24	2017-07-10 17:43:00+03	56000.00
4FFC4B	2017-07-28 12:51:00+03	399600.00
4FFC4E	2017-07-26 03:10:00+03	38600.00
4FFD15	2017-07-02 12:09:00+03	132800.00
4FFD2C	2017-07-19 06:56:00+03	49800.00
4FFD3E	2017-07-31 15:48:00+03	85700.00
4FFD67	2017-08-14 10:40:00+03	68800.00
4FFD8E	2017-07-19 02:41:00+03	45000.00
4FFDA3	2017-07-18 19:00:00+03	81600.00
4FFE1A	2017-07-05 19:12:00+03	42700.00
4FFE24	2017-07-08 10:38:00+03	31100.00
4FFE40	2017-08-09 16:56:00+03	7200.00
4FFE43	2017-07-18 04:01:00+03	47700.00
4FFE4D	2017-07-17 22:43:00+03	57600.00
4FFE9D	2017-08-06 03:38:00+03	62600.00
4FFE9F	2017-07-20 19:41:00+03	46700.00
4FFEC9	2017-08-09 23:25:00+03	31400.00
4FFECB	2017-07-06 05:40:00+03	102100.00
4FFF54	2017-07-28 04:56:00+03	111600.00
500011	2017-08-07 13:54:00+03	111600.00
50005E	2017-07-20 17:21:00+03	85000.00
5000AA	2017-08-15 01:33:00+03	32800.00
50011E	2017-07-23 14:35:00+03	139500.00
500123	2017-06-27 06:53:00+03	81200.00
500183	2017-07-26 17:53:00+03	36200.00
500285	2017-07-18 19:17:00+03	67900.00
50028E	2017-07-30 23:29:00+03	30400.00
5002C5	2017-08-03 20:04:00+03	131600.00
5002F1	2017-07-03 08:50:00+03	172600.00
500303	2017-07-05 05:35:00+03	47200.00
500360	2017-08-09 14:43:00+03	272400.00
500384	2017-07-24 18:48:00+03	76600.00
50040D	2017-08-13 09:59:00+03	65600.00
500440	2017-07-18 20:10:00+03	13600.00
500466	2017-07-02 22:23:00+03	95600.00
500509	2017-07-31 12:06:00+03	79600.00
500547	2017-07-21 13:05:00+03	43400.00
50055C	2017-07-09 05:43:00+03	19600.00
500572	2017-07-21 06:11:00+03	27200.00
50068D	2017-07-29 00:27:00+03	301800.00
5006BA	2017-07-21 18:23:00+03	33800.00
500703	2017-08-12 07:48:00+03	16400.00
500704	2017-06-30 16:36:00+03	40400.00
500707	2017-07-15 11:02:00+03	133100.00
500764	2017-07-15 11:23:00+03	26000.00
5007ED	2017-07-04 05:22:00+03	66600.00
500838	2017-08-01 14:20:00+03	64700.00
500845	2017-07-18 08:54:00+03	28200.00
50084B	2017-08-03 06:48:00+03	15700.00
50084D	2017-07-28 17:45:00+03	11000.00
5008C8	2017-07-03 18:06:00+03	54800.00
500904	2017-07-02 21:56:00+03	76300.00
500906	2017-07-02 19:52:00+03	187700.00
500952	2017-08-01 19:48:00+03	28000.00
5009C7	2017-07-22 09:41:00+03	96800.00
500A06	2017-07-19 06:23:00+03	89700.00
500A87	2017-08-05 22:34:00+03	59100.00
500AD6	2017-07-12 21:09:00+03	76700.00
500B2E	2017-07-28 17:34:00+03	140900.00
500B45	2017-07-08 07:07:00+03	71400.00
500B78	2017-08-08 08:32:00+03	76400.00
500B84	2017-07-06 19:33:00+03	96800.00
500C59	2017-07-10 00:59:00+03	57400.00
500CB4	2017-07-12 17:38:00+03	119700.00
500D17	2017-07-04 00:47:00+03	55800.00
500D2D	2017-07-30 12:34:00+03	200800.00
500D55	2017-08-05 06:17:00+03	65600.00
500DA8	2017-08-06 05:06:00+03	28000.00
500DDA	2017-08-06 23:57:00+03	46400.00
500DEB	2017-08-08 23:03:00+03	16400.00
500E02	2017-07-14 07:29:00+03	23200.00
500E4A	2017-06-30 18:08:00+03	54000.00
500E56	2017-07-11 22:18:00+03	141300.00
500E65	2017-06-29 06:15:00+03	18800.00
500E78	2017-06-28 17:11:00+03	122500.00
500EBC	2017-07-16 23:52:00+03	85000.00
500F10	2017-08-03 06:40:00+03	34000.00
500F35	2017-08-10 09:19:00+03	55000.00
500F46	2017-07-20 02:20:00+03	213300.00
500F7F	2017-08-09 05:45:00+03	68700.00
500F9B	2017-08-05 13:35:00+03	56000.00
500FBE	2017-07-30 20:42:00+03	6300.00
500FF8	2017-07-05 04:03:00+03	15700.00
500FFD	2017-07-16 01:18:00+03	128300.00
501043	2017-07-08 19:38:00+03	47400.00
501099	2017-07-24 02:09:00+03	38400.00
501141	2017-07-17 22:11:00+03	7200.00
501154	2017-06-30 12:45:00+03	270800.00
50116F	2017-07-29 22:44:00+03	133100.00
501178	2017-08-08 20:40:00+03	44700.00
5011C2	2017-07-19 10:27:00+03	265700.00
501201	2017-07-04 09:29:00+03	28000.00
501223	2017-07-30 00:54:00+03	52900.00
5012C0	2017-08-12 01:33:00+03	62600.00
5012C8	2017-07-27 21:13:00+03	44000.00
5012D5	2017-08-03 07:07:00+03	20400.00
5012DF	2017-08-03 22:00:00+03	59800.00
501331	2017-08-07 22:02:00+03	42900.00
5013B9	2017-07-20 12:43:00+03	41800.00
5013DA	2017-07-01 11:09:00+03	14400.00
5013E1	2017-07-22 14:41:00+03	100900.00
5013FE	2017-07-21 04:18:00+03	148200.00
501431	2017-07-22 17:48:00+03	29600.00
501447	2017-08-08 16:26:00+03	199600.00
501455	2017-07-29 22:36:00+03	123000.00
50145C	2017-07-23 21:24:00+03	189100.00
50147E	2017-08-04 15:46:00+03	52000.00
501526	2017-08-03 05:44:00+03	67500.00
501589	2017-07-24 21:11:00+03	16400.00
50159A	2017-07-23 00:17:00+03	20400.00
5015BE	2017-07-12 23:29:00+03	59800.00
5015F4	2017-08-08 09:08:00+03	71900.00
501609	2017-08-15 17:16:00+03	69000.00
501617	2017-08-13 05:39:00+03	29800.00
50162F	2017-08-10 18:10:00+03	56000.00
501645	2017-07-02 05:42:00+03	46200.00
501669	2017-08-02 05:24:00+03	399600.00
50176A	2017-07-24 08:07:00+03	81700.00
50177E	2017-08-15 09:48:00+03	28800.00
501863	2017-07-01 05:26:00+03	39800.00
501884	2017-07-03 17:24:00+03	167400.00
5018DB	2017-08-10 14:02:00+03	28000.00
501917	2017-07-25 22:21:00+03	26700.00
50191C	2017-07-26 09:51:00+03	128800.00
501922	2017-08-08 20:30:00+03	66600.00
501928	2017-07-18 16:29:00+03	35200.00
501A2D	2017-07-28 02:00:00+03	28000.00
501A6D	2017-08-06 07:24:00+03	58200.00
501ABE	2017-08-11 10:48:00+03	195300.00
501AC7	2017-07-26 04:59:00+03	46200.00
501AEC	2017-08-09 23:37:00+03	54000.00
501AF7	2017-07-09 03:10:00+03	19600.00
501B0E	2017-08-14 22:26:00+03	87700.00
501B16	2017-07-20 22:39:00+03	14400.00
501B6B	2017-08-15 00:46:00+03	18600.00
501B82	2017-07-28 23:56:00+03	24400.00
501BA5	2017-07-29 15:14:00+03	73500.00
501BF8	2017-08-02 17:27:00+03	81600.00
501C07	2017-07-26 14:12:00+03	135400.00
501C58	2017-07-05 09:04:00+03	235900.00
501CC4	2017-07-25 02:56:00+03	54800.00
501D7B	2017-08-06 00:26:00+03	141600.00
501E38	2017-07-09 17:39:00+03	108500.00
501E55	2017-07-22 06:33:00+03	19600.00
501E80	2017-07-09 11:15:00+03	12000.00
501E93	2017-07-22 10:59:00+03	94200.00
501ECD	2017-07-08 11:41:00+03	26000.00
501EF5	2017-08-09 17:06:00+03	16400.00
501F4E	2017-07-21 04:43:00+03	23200.00
501F71	2017-07-26 06:14:00+03	101200.00
501F77	2017-07-10 03:13:00+03	49800.00
502053	2017-07-17 11:50:00+03	123000.00
502060	2017-07-30 04:12:00+03	122000.00
5020C3	2017-08-03 06:17:00+03	73500.00
50214B	2017-07-24 14:09:00+03	55800.00
502163	2017-08-09 20:41:00+03	69500.00
50221B	2017-07-20 02:04:00+03	111900.00
50222A	2017-08-06 01:16:00+03	153300.00
5022F5	2017-07-24 20:56:00+03	13600.00
5022FC	2017-08-08 20:02:00+03	142000.00
50232C	2017-08-11 02:12:00+03	11800.00
50236A	2017-08-15 04:06:00+03	70800.00
502380	2017-08-14 11:01:00+03	20400.00
5023D3	2017-08-15 15:48:00+03	27200.00
5023DD	2017-08-08 07:45:00+03	46400.00
502495	2017-08-04 21:24:00+03	67100.00
5024BE	2017-07-12 04:15:00+03	136200.00
5024C6	2017-08-05 16:22:00+03	25600.00
502510	2017-07-30 16:33:00+03	193600.00
502529	2017-07-03 07:35:00+03	131600.00
502547	2017-08-09 09:01:00+03	50200.00
50267A	2017-07-16 18:05:00+03	133100.00
502691	2017-08-07 20:46:00+03	51900.00
5026A0	2017-08-05 04:22:00+03	28000.00
502708	2017-07-29 23:01:00+03	643800.00
5027CC	2017-07-03 00:42:00+03	88500.00
5027DA	2017-06-30 22:46:00+03	32200.00
502867	2017-06-29 18:06:00+03	23200.00
5028BF	2017-08-10 23:51:00+03	34400.00
5028E7	2017-08-03 15:42:00+03	54400.00
502903	2017-08-01 18:22:00+03	75800.00
50296D	2017-07-20 05:42:00+03	515000.00
50297B	2017-07-09 12:14:00+03	266400.00
502992	2017-07-10 01:25:00+03	9800.00
5029DE	2017-07-09 15:31:00+03	87100.00
502A12	2017-07-08 06:15:00+03	78200.00
502A8C	2017-07-27 21:24:00+03	32200.00
502B73	2017-07-24 07:35:00+03	37200.00
502B97	2017-08-15 17:03:00+03	38600.00
502BCE	2017-07-27 09:36:00+03	32800.00
502C69	2017-07-31 11:28:00+03	29400.00
502C6D	2017-07-15 21:59:00+03	54300.00
502CDD	2017-06-30 14:41:00+03	31000.00
502CED	2017-07-20 08:44:00+03	46200.00
502D3B	2017-07-14 14:46:00+03	29200.00
502D56	2017-07-11 15:10:00+03	37200.00
502DA3	2017-07-17 07:57:00+03	21400.00
502DD6	2017-08-04 03:07:00+03	59000.00
502E99	2017-07-15 08:21:00+03	65600.00
502EA6	2017-07-10 00:32:00+03	23600.00
502F2E	2017-08-06 10:37:00+03	55800.00
502F7A	2017-07-10 07:40:00+03	40400.00
502F95	2017-07-29 00:30:00+03	58000.00
502F9D	2017-08-14 02:58:00+03	65100.00
50300B	2017-07-21 18:31:00+03	103200.00
503023	2017-08-14 18:25:00+03	68100.00
50307C	2017-07-19 17:02:00+03	153200.00
503092	2017-07-04 06:29:00+03	156600.00
5030A4	2017-07-15 07:51:00+03	69500.00
5030B9	2017-07-20 14:12:00+03	112000.00
5030D2	2017-07-14 04:37:00+03	49600.00
503117	2017-08-01 18:18:00+03	93900.00
50312D	2017-08-01 12:04:00+03	316800.00
503132	2017-07-19 20:59:00+03	117700.00
5031B4	2017-07-02 16:03:00+03	13400.00
50321A	2017-07-24 03:29:00+03	93000.00
503270	2017-07-25 14:20:00+03	36400.00
503287	2017-08-07 08:20:00+03	69500.00
5032A4	2017-08-14 18:46:00+03	17000.00
5032F5	2017-07-07 10:41:00+03	102200.00
503354	2017-07-16 15:26:00+03	48500.00
50335E	2017-07-25 06:49:00+03	73300.00
503366	2017-07-15 14:53:00+03	20200.00
5033EA	2017-08-08 22:46:00+03	126600.00
5033EB	2017-07-22 05:06:00+03	97800.00
503408	2017-07-19 06:52:00+03	79000.00
503428	2017-07-14 19:22:00+03	28300.00
50342E	2017-07-25 00:54:00+03	306800.00
50343D	2017-07-14 06:29:00+03	16400.00
50344E	2017-07-29 04:11:00+03	290600.00
50345B	2017-07-18 00:29:00+03	14000.00
503489	2017-07-30 15:55:00+03	40000.00
5034C9	2017-08-07 00:48:00+03	100600.00
5034ED	2017-08-02 19:52:00+03	37900.00
50352B	2017-07-08 07:28:00+03	72200.00
50356D	2017-08-11 00:53:00+03	6800.00
503572	2017-07-18 03:09:00+03	32800.00
503575	2017-08-06 04:35:00+03	6000.00
503585	2017-07-04 13:25:00+03	135400.00
5035D9	2017-07-11 22:14:00+03	29600.00
503629	2017-07-16 00:59:00+03	139200.00
50367F	2017-07-23 18:50:00+03	11700.00
5036B3	2017-08-06 06:14:00+03	11000.00
5036CB	2017-07-27 17:56:00+03	70800.00
5036F4	2017-08-01 20:13:00+03	133200.00
50372F	2017-07-30 15:08:00+03	62700.00
503757	2017-08-07 21:47:00+03	29600.00
50375E	2017-07-30 02:01:00+03	25800.00
503768	2017-08-02 06:39:00+03	32400.00
5037D9	2017-08-12 17:03:00+03	76300.00
503842	2017-07-17 03:02:00+03	94800.00
503864	2017-07-08 00:26:00+03	123000.00
50387E	2017-07-22 06:51:00+03	38200.00
503880	2017-08-14 07:09:00+03	28000.00
503943	2017-07-15 07:41:00+03	240500.00
5039C6	2017-07-15 14:17:00+03	61400.00
503A31	2017-08-11 22:41:00+03	234800.00
503A7F	2017-08-10 16:20:00+03	136600.00
503A86	2017-08-13 13:03:00+03	246000.00
503A8D	2017-07-17 15:23:00+03	86600.00
503ABB	2017-08-05 08:54:00+03	40800.00
503AD3	2017-07-29 11:18:00+03	55600.00
503B0B	2017-07-05 19:18:00+03	23200.00
503BC2	2017-07-22 15:48:00+03	137600.00
503BE2	2017-07-09 17:58:00+03	75600.00
503C18	2017-08-01 13:20:00+03	6000.00
503C2A	2017-08-13 06:44:00+03	13400.00
503CB9	2017-07-19 05:12:00+03	28800.00
503CC3	2017-07-14 14:22:00+03	136800.00
503CCA	2017-07-02 03:55:00+03	169600.00
503D28	2017-08-04 14:29:00+03	117600.00
503DAB	2017-07-12 12:53:00+03	77600.00
503E10	2017-08-12 22:49:00+03	155400.00
503E33	2017-07-22 19:53:00+03	46200.00
503E7A	2017-07-16 04:53:00+03	56000.00
503EF3	2017-08-12 13:32:00+03	64400.00
503F08	2017-08-07 16:49:00+03	40400.00
503F10	2017-08-02 02:36:00+03	529200.00
503FB0	2017-08-13 08:23:00+03	23200.00
503FD6	2017-07-15 09:26:00+03	54400.00
504074	2017-07-31 17:02:00+03	75600.00
50414E	2017-08-04 01:33:00+03	40000.00
504166	2017-08-14 14:43:00+03	40000.00
5041BC	2017-07-14 08:43:00+03	28800.00
504219	2017-07-25 01:50:00+03	28800.00
504225	2017-08-14 03:07:00+03	132500.00
504239	2017-07-21 09:59:00+03	31400.00
50424A	2017-08-05 13:55:00+03	69400.00
50425B	2017-07-27 20:55:00+03	32200.00
50427B	2017-07-12 15:33:00+03	65900.00
50434D	2017-07-16 08:15:00+03	51200.00
50435C	2017-08-11 08:18:00+03	46400.00
504440	2017-07-08 17:19:00+03	301800.00
504459	2017-07-13 11:25:00+03	26000.00
504471	2017-07-17 05:46:00+03	14400.00
5044AB	2017-08-12 18:54:00+03	6200.00
5044D1	2017-07-24 20:24:00+03	23200.00
504545	2017-07-21 17:24:00+03	31100.00
504554	2017-07-24 20:32:00+03	47100.00
504562	2017-07-16 14:47:00+03	70600.00
5045C3	2017-08-03 21:03:00+03	111600.00
5045FF	2017-07-16 19:57:00+03	57400.00
504622	2017-07-13 13:10:00+03	125200.00
504640	2017-06-28 16:11:00+03	26000.00
504675	2017-08-14 08:20:00+03	56100.00
50467F	2017-07-10 07:31:00+03	44000.00
504689	2017-08-14 15:39:00+03	26800.00
5046A5	2017-08-10 19:47:00+03	29000.00
5046D8	2017-08-15 14:41:00+03	76300.00
504713	2017-07-01 14:58:00+03	103500.00
504759	2017-07-03 16:40:00+03	19600.00
5047D7	2017-07-21 11:15:00+03	72400.00
50480A	2017-07-06 05:48:00+03	126500.00
504817	2017-07-22 06:49:00+03	30400.00
504872	2017-08-12 12:38:00+03	123000.00
5048E3	2017-07-22 12:44:00+03	93900.00
50493B	2017-07-19 20:19:00+03	21400.00
50497A	2017-08-15 11:38:00+03	313100.00
5049B2	2017-07-28 09:04:00+03	30200.00
5049C8	2017-07-28 21:24:00+03	33100.00
5049FE	2017-07-23 03:57:00+03	105900.00
504A3F	2017-08-08 02:11:00+03	32800.00
504B10	2017-07-29 21:37:00+03	38800.00
504B66	2017-07-29 04:09:00+03	64700.00
504B6D	2017-08-11 01:10:00+03	70000.00
504BDF	2017-07-15 03:39:00+03	173600.00
504C55	2017-07-11 02:53:00+03	80300.00
504D85	2017-07-12 22:19:00+03	62600.00
504D90	2017-07-23 18:00:00+03	201800.00
504DBD	2017-08-12 11:43:00+03	37000.00
504E15	2017-07-12 03:44:00+03	14000.00
504E3D	2017-07-07 07:10:00+03	56600.00
504E54	2017-08-09 19:55:00+03	112000.00
504EB8	2017-07-12 05:04:00+03	28800.00
504ECD	2017-07-12 15:12:00+03	16400.00
504F03	2017-07-08 16:03:00+03	73100.00
504F49	2017-08-04 03:10:00+03	25400.00
504F82	2017-07-11 20:54:00+03	8400.00
504F83	2017-07-10 07:12:00+03	12600.00
504F96	2017-07-09 15:33:00+03	101500.00
504FBE	2017-07-09 06:24:00+03	239400.00
50501F	2017-07-29 17:18:00+03	65500.00
505023	2017-07-09 22:06:00+03	35200.00
505036	2017-08-13 13:03:00+03	70400.00
505051	2017-07-21 04:57:00+03	115100.00
5050A4	2017-07-21 21:51:00+03	24000.00
50515B	2017-07-22 03:17:00+03	46400.00
505198	2017-06-29 11:45:00+03	61800.00
505205	2017-07-26 19:42:00+03	273000.00
505206	2017-08-10 07:52:00+03	30700.00
50521A	2017-07-28 05:47:00+03	40000.00
505236	2017-07-18 07:09:00+03	43200.00
505262	2017-07-11 00:45:00+03	18800.00
5052A7	2017-07-22 17:17:00+03	50800.00
50533E	2017-08-03 12:34:00+03	274300.00
50536F	2017-07-29 05:34:00+03	76800.00
5053A4	2017-07-14 17:08:00+03	169500.00
5053BD	2017-06-29 02:46:00+03	35600.00
5053DE	2017-07-12 22:47:00+03	24200.00
50547C	2017-08-07 19:51:00+03	56900.00
5054A3	2017-08-14 08:50:00+03	202600.00
5054C9	2017-07-21 06:21:00+03	6800.00
5054F4	2017-08-06 23:18:00+03	36200.00
50550F	2017-08-05 16:05:00+03	36800.00
505526	2017-08-01 10:48:00+03	58700.00
505581	2017-07-18 14:59:00+03	28000.00
5055A3	2017-07-23 10:36:00+03	56000.00
5055E7	2017-07-08 04:37:00+03	40600.00
50566C	2017-07-01 17:32:00+03	103600.00
505674	2017-07-23 05:19:00+03	63500.00
5056DF	2017-07-16 01:23:00+03	53300.00
5056ED	2017-08-11 04:16:00+03	27200.00
5056F6	2017-07-21 06:36:00+03	46800.00
50574F	2017-08-08 02:47:00+03	81500.00
505770	2017-07-21 02:23:00+03	199800.00
50578D	2017-06-27 17:43:00+03	37200.00
5057B0	2017-07-08 17:19:00+03	8000.00
505810	2017-07-08 22:14:00+03	55100.00
505835	2017-07-16 17:17:00+03	59000.00
5058CA	2017-07-02 06:59:00+03	112600.00
5058D1	2017-07-21 12:32:00+03	52700.00
505918	2017-08-08 00:48:00+03	16400.00
50597C	2017-07-07 19:55:00+03	55800.00
5059C5	2017-07-29 21:02:00+03	53700.00
505A0D	2017-07-16 17:24:00+03	213200.00
505AAE	2017-07-14 03:10:00+03	99300.00
505B06	2017-07-15 07:20:00+03	161200.00
505B3B	2017-08-08 22:37:00+03	48800.00
505B7A	2017-07-25 04:44:00+03	6700.00
505C0A	2017-08-01 06:27:00+03	93900.00
505C26	2017-07-03 05:09:00+03	26000.00
505C8E	2017-07-29 14:36:00+03	12000.00
505CEF	2017-08-09 12:34:00+03	66600.00
505CFA	2017-07-17 11:59:00+03	143200.00
505D04	2017-08-11 19:50:00+03	27200.00
505D0B	2017-07-07 05:59:00+03	38600.00
505DAB	2017-08-05 21:20:00+03	117900.00
505E06	2017-07-31 08:19:00+03	103800.00
505E0B	2017-07-27 03:09:00+03	43500.00
505E27	2017-07-17 23:15:00+03	46400.00
505E4F	2017-08-09 07:36:00+03	174900.00
505E86	2017-07-25 11:04:00+03	91200.00
505F65	2017-08-12 15:35:00+03	214900.00
505F7A	2017-07-09 02:35:00+03	46500.00
505F85	2017-07-24 01:30:00+03	85000.00
50602D	2017-08-07 01:17:00+03	30000.00
506086	2017-07-22 09:45:00+03	39800.00
50609E	2017-08-04 01:36:00+03	46200.00
5060B2	2017-07-03 02:50:00+03	52000.00
5060BA	2017-08-08 12:58:00+03	86300.00
5060E7	2017-07-18 15:14:00+03	23200.00
506115	2017-07-27 06:43:00+03	49200.00
5061A6	2017-08-11 11:07:00+03	189100.00
5061B2	2017-07-10 09:13:00+03	35400.00
5061DB	2017-08-01 11:25:00+03	101200.00
506207	2017-07-03 12:57:00+03	48400.00
506211	2017-07-30 21:33:00+03	16400.00
5062B3	2017-08-07 21:46:00+03	131100.00
5062D2	2017-08-15 09:24:00+03	13400.00
506321	2017-07-17 21:34:00+03	78300.00
506328	2017-07-18 08:42:00+03	57500.00
50639B	2017-07-20 14:30:00+03	102100.00
5063C7	2017-08-06 21:58:00+03	131100.00
5063E9	2017-08-03 13:07:00+03	43200.00
50645F	2017-07-05 13:03:00+03	86400.00
50648A	2017-08-02 05:54:00+03	45200.00
5064A4	2017-08-13 20:46:00+03	37100.00
5064CC	2017-07-29 12:18:00+03	55800.00
5064DA	2017-07-21 19:41:00+03	29400.00
50653F	2017-07-02 16:11:00+03	27200.00
5065FC	2017-08-07 02:35:00+03	68100.00
50661A	2017-07-20 17:30:00+03	15000.00
506726	2017-08-09 15:54:00+03	49000.00
506749	2017-08-13 13:06:00+03	40000.00
50675C	2017-07-15 01:03:00+03	12600.00
5067AB	2017-07-24 15:56:00+03	36200.00
50685D	2017-07-19 22:35:00+03	81300.00
5068A6	2017-07-30 15:56:00+03	134700.00
5068D3	2017-08-07 05:40:00+03	73100.00
5068E4	2017-07-07 02:04:00+03	248300.00
506948	2017-07-28 21:00:00+03	57400.00
5069D5	2017-08-05 04:15:00+03	46400.00
5069D6	2017-08-11 00:51:00+03	44800.00
5069FE	2017-07-30 02:43:00+03	177200.00
506A1B	2017-07-19 16:17:00+03	66600.00
506A5B	2017-08-13 13:31:00+03	117500.00
506B06	2017-07-09 02:01:00+03	27800.00
506B49	2017-07-28 00:27:00+03	179500.00
506BD5	2017-07-31 14:49:00+03	126300.00
506BEC	2017-07-15 22:41:00+03	103100.00
506BF7	2017-07-23 04:17:00+03	226200.00
506C57	2017-07-18 00:11:00+03	114800.00
506CB5	2017-07-09 17:37:00+03	135000.00
506CE1	2017-07-15 22:43:00+03	69500.00
506D2D	2017-07-20 20:56:00+03	58200.00
506DA8	2017-08-05 13:23:00+03	13400.00
506DE5	2017-07-03 03:51:00+03	369000.00
506E75	2017-07-12 17:34:00+03	66000.00
506F16	2017-07-11 06:54:00+03	12400.00
506F32	2017-07-06 15:04:00+03	40000.00
506F6D	2017-08-04 18:45:00+03	25000.00
506FCB	2017-06-30 19:24:00+03	46700.00
507057	2017-07-10 09:22:00+03	269200.00
507061	2017-07-13 11:52:00+03	37700.00
5070AD	2017-07-27 05:44:00+03	123000.00
5070E3	2017-08-12 18:11:00+03	8000.00
5070F2	2017-08-12 18:07:00+03	15700.00
5071B3	2017-07-26 00:47:00+03	28800.00
5071E1	2017-07-26 08:07:00+03	39500.00
5071F7	2017-07-01 20:03:00+03	17800.00
50724D	2017-07-24 14:13:00+03	119500.00
507260	2017-08-09 16:15:00+03	46400.00
507270	2017-08-02 04:28:00+03	143100.00
507274	2017-08-14 00:10:00+03	26000.00
5072B0	2017-08-02 23:48:00+03	56000.00
507318	2017-08-04 19:25:00+03	57500.00
50739E	2017-07-31 03:37:00+03	99200.00
5073B5	2017-07-19 04:38:00+03	20200.00
5073BE	2017-07-12 08:20:00+03	28000.00
50747E	2017-08-03 09:07:00+03	15000.00
507483	2017-07-31 10:21:00+03	46300.00
507496	2017-07-12 17:35:00+03	55900.00
5074A3	2017-08-08 05:05:00+03	43400.00
5074C0	2017-07-17 12:54:00+03	23400.00
5074C2	2017-07-01 11:57:00+03	137900.00
507529	2017-08-14 15:51:00+03	34000.00
507551	2017-08-05 13:56:00+03	169200.00
507580	2017-07-19 19:36:00+03	16400.00
50758D	2017-07-25 00:35:00+03	73600.00
507591	2017-07-02 03:12:00+03	136200.00
5075C8	2017-07-01 14:11:00+03	132800.00
5075D1	2017-07-29 08:56:00+03	28800.00
5076E4	2017-07-16 08:58:00+03	265700.00
50778A	2017-07-13 20:04:00+03	100600.00
5077A2	2017-08-07 09:44:00+03	8800.00
5077EB	2017-07-05 12:03:00+03	6700.00
5077F5	2017-08-02 10:52:00+03	244900.00
50781D	2017-08-03 04:00:00+03	27900.00
50782A	2017-07-18 01:54:00+03	58000.00
507843	2017-07-29 16:33:00+03	16800.00
507844	2017-08-13 15:11:00+03	26800.00
50786C	2017-07-30 15:50:00+03	35400.00
50786D	2017-07-02 01:05:00+03	64700.00
5078DC	2017-08-14 16:12:00+03	87000.00
507930	2017-06-28 13:42:00+03	74000.00
5079D8	2017-08-14 16:22:00+03	101600.00
5079F7	2017-07-03 02:44:00+03	43600.00
507A3D	2017-08-06 17:57:00+03	28000.00
507A50	2017-07-16 08:02:00+03	79200.00
507A78	2017-07-18 11:17:00+03	30200.00
507A92	2017-07-18 22:41:00+03	59000.00
507AC6	2017-08-06 13:09:00+03	70600.00
507AD1	2017-07-18 18:23:00+03	102100.00
507AED	2017-07-24 07:51:00+03	45200.00
507B69	2017-07-24 10:53:00+03	92800.00
507B78	2017-06-29 22:56:00+03	18000.00
507B9B	2017-07-05 07:09:00+03	44800.00
507BA2	2017-07-31 15:25:00+03	25600.00
507C78	2017-07-17 20:42:00+03	23400.00
507CB3	2017-07-18 17:04:00+03	46400.00
507D04	2017-07-15 17:28:00+03	88800.00
507E01	2017-07-04 14:23:00+03	14000.00
507E2F	2017-08-14 07:50:00+03	44700.00
507E31	2017-07-06 06:07:00+03	31300.00
507E43	2017-07-15 09:57:00+03	538100.00
507E4C	2017-07-13 09:06:00+03	139300.00
507E71	2017-07-02 18:14:00+03	28000.00
507E88	2017-07-22 00:21:00+03	54100.00
507EEE	2017-08-05 22:20:00+03	28800.00
507F39	2017-08-13 05:46:00+03	12000.00
507F4C	2017-07-12 10:53:00+03	135400.00
507F78	2017-07-27 13:25:00+03	26700.00
507F7B	2017-08-07 10:14:00+03	37700.00
507FC2	2017-07-03 10:34:00+03	24400.00
507FE4	2017-07-21 05:15:00+03	23600.00
507FE7	2017-08-04 19:30:00+03	237900.00
5080B5	2017-07-27 20:06:00+03	53300.00
5080F6	2017-07-31 01:16:00+03	43500.00
508100	2017-07-07 10:57:00+03	86800.00
50810F	2017-07-18 02:38:00+03	131100.00
508110	2017-07-01 14:11:00+03	82600.00
508112	2017-07-17 18:59:00+03	406100.00
508149	2017-06-30 12:30:00+03	84500.00
508172	2017-07-18 01:54:00+03	44800.00
50817F	2017-07-04 20:52:00+03	48200.00
508201	2017-07-14 20:29:00+03	103500.00
508230	2017-07-03 04:28:00+03	56900.00
508234	2017-07-24 16:35:00+03	32300.00
508298	2017-07-15 01:41:00+03	23600.00
5082A3	2017-07-22 10:40:00+03	30200.00
5082BE	2017-07-22 07:56:00+03	118500.00
508300	2017-07-20 08:37:00+03	29600.00
508342	2017-08-04 11:57:00+03	116300.00
508360	2017-08-02 14:45:00+03	43200.00
50837E	2017-08-02 04:45:00+03	23600.00
5083A2	2017-07-12 15:47:00+03	311200.00
5083CF	2017-07-23 10:51:00+03	27900.00
5083EB	2017-07-08 18:35:00+03	136800.00
50841B	2017-08-02 12:58:00+03	33400.00
50846B	2017-07-16 23:25:00+03	62900.00
508475	2017-07-28 03:56:00+03	24400.00
50848A	2017-08-07 17:58:00+03	74900.00
50848C	2017-08-04 03:56:00+03	398500.00
5084A4	2017-08-13 18:56:00+03	16400.00
5084CD	2017-07-25 12:15:00+03	92800.00
50852F	2017-08-09 13:49:00+03	51800.00
508625	2017-08-01 08:48:00+03	24800.00
508669	2017-06-28 13:52:00+03	28000.00
5086D3	2017-07-31 18:37:00+03	46200.00
508762	2017-06-29 16:46:00+03	38600.00
5087CE	2017-07-16 03:43:00+03	22600.00
5087D7	2017-08-03 16:04:00+03	132500.00
508847	2017-07-04 02:11:00+03	29600.00
50885E	2017-08-13 08:53:00+03	53400.00
5088BA	2017-07-04 13:07:00+03	23200.00
5088DB	2017-08-04 14:19:00+03	62800.00
5088E8	2017-08-11 09:21:00+03	64700.00
508902	2017-07-03 13:43:00+03	21400.00
50890F	2017-07-10 17:11:00+03	119600.00
508934	2017-08-07 06:10:00+03	95200.00
508975	2017-07-13 17:03:00+03	170500.00
50897D	2017-07-09 10:32:00+03	25200.00
508983	2017-07-30 06:55:00+03	58000.00
50899D	2017-08-13 03:41:00+03	53500.00
5089D4	2017-08-05 14:59:00+03	37900.00
508A22	2017-07-24 22:15:00+03	81800.00
508A24	2017-07-02 07:10:00+03	58600.00
508A61	2017-07-20 19:41:00+03	174000.00
508AC2	2017-07-02 12:14:00+03	56900.00
508B2E	2017-08-12 02:38:00+03	31600.00
508B62	2017-08-12 01:18:00+03	63200.00
508B71	2017-07-07 01:42:00+03	28800.00
508B85	2017-08-06 03:38:00+03	132800.00
508BC5	2017-07-20 15:21:00+03	25000.00
508CB9	2017-07-22 20:41:00+03	75600.00
508CF4	2017-07-26 00:01:00+03	408500.00
508D1B	2017-07-19 04:41:00+03	24400.00
508D3D	2017-08-14 00:38:00+03	23400.00
508DA4	2017-08-02 15:21:00+03	27400.00
508E25	2017-07-18 08:02:00+03	38800.00
508E88	2017-07-09 00:45:00+03	72400.00
508EE0	2017-07-21 09:43:00+03	6000.00
508EFE	2017-07-03 17:11:00+03	29600.00
508FB1	2017-08-04 10:18:00+03	77900.00
508FEE	2017-08-07 10:53:00+03	16800.00
5090E9	2017-07-31 01:15:00+03	58600.00
509129	2017-07-01 01:09:00+03	37800.00
50916F	2017-07-13 15:47:00+03	86400.00
5091F5	2017-08-09 05:15:00+03	148200.00
509234	2017-08-03 06:18:00+03	23200.00
50923E	2017-07-19 00:00:00+03	56600.00
509282	2017-08-11 16:35:00+03	233400.00
5092F6	2017-07-21 09:53:00+03	133100.00
509313	2017-07-17 09:35:00+03	90300.00
509326	2017-08-06 18:31:00+03	52000.00
509379	2017-08-02 22:46:00+03	59800.00
5093E5	2017-07-07 04:53:00+03	135600.00
50941A	2017-08-09 02:56:00+03	31600.00
509458	2017-07-27 11:27:00+03	236000.00
509462	2017-06-28 12:02:00+03	119500.00
50946F	2017-07-11 12:18:00+03	62600.00
5094B4	2017-08-10 05:56:00+03	91500.00
509501	2017-08-13 09:18:00+03	6300.00
5095C5	2017-07-28 14:36:00+03	37900.00
5095E7	2017-07-09 14:00:00+03	31600.00
509619	2017-07-26 04:48:00+03	44500.00
50964D	2017-07-13 21:49:00+03	132800.00
509660	2017-07-21 14:51:00+03	6300.00
5096C3	2017-07-25 08:56:00+03	31600.00
5096CD	2017-08-06 00:43:00+03	146300.00
5096F6	2017-07-04 13:25:00+03	32400.00
509753	2017-06-29 20:47:00+03	75500.00
509765	2017-07-16 08:35:00+03	16400.00
50976F	2017-06-29 15:50:00+03	83200.00
509786	2017-07-22 08:03:00+03	135400.00
5097C0	2017-07-03 08:41:00+03	119500.00
50980D	2017-07-07 04:16:00+03	31600.00
50982D	2017-08-15 09:52:00+03	44600.00
509834	2017-07-06 20:21:00+03	6800.00
509849	2017-07-11 16:19:00+03	229600.00
5098A9	2017-08-11 19:21:00+03	64400.00
50990D	2017-06-30 20:59:00+03	89000.00
509944	2017-07-18 14:23:00+03	58100.00
50995C	2017-08-04 07:07:00+03	31600.00
5099CB	2017-07-13 14:49:00+03	79600.00
509A65	2017-07-28 00:09:00+03	70900.00
509A66	2017-07-25 14:16:00+03	298500.00
509A7C	2017-08-04 06:18:00+03	56000.00
509AAA	2017-07-07 19:00:00+03	213200.00
509AC0	2017-07-08 22:39:00+03	43400.00
509B24	2017-07-16 14:55:00+03	36800.00
509B6B	2017-07-10 05:08:00+03	46200.00
509BA3	2017-07-16 01:15:00+03	8000.00
509C84	2017-08-09 07:37:00+03	68400.00
509CAC	2017-07-04 04:44:00+03	102100.00
509D0F	2017-07-12 11:17:00+03	67400.00
509D4B	2017-07-09 13:13:00+03	113700.00
509DC4	2017-07-12 20:35:00+03	45100.00
509E06	2017-07-25 16:32:00+03	55800.00
509E3E	2017-07-25 02:05:00+03	26000.00
509E50	2017-07-05 16:25:00+03	114800.00
509E54	2017-08-04 19:39:00+03	68800.00
509E6E	2017-08-14 16:25:00+03	176800.00
509EFA	2017-07-27 07:52:00+03	50800.00
509F7F	2017-08-08 00:12:00+03	95200.00
509FFC	2017-08-01 19:33:00+03	60400.00
50A00F	2017-08-08 13:08:00+03	58000.00
50A030	2017-07-10 12:48:00+03	55800.00
50A0A6	2017-08-15 10:35:00+03	27900.00
50A0B2	2017-08-08 09:30:00+03	48400.00
50A0D5	2017-07-09 05:16:00+03	46400.00
50A124	2017-07-18 22:01:00+03	23800.00
50A1F7	2017-07-26 00:08:00+03	26000.00
50A286	2017-08-02 14:27:00+03	6000.00
50A288	2017-07-12 19:34:00+03	55600.00
50A2A6	2017-08-11 16:42:00+03	51900.00
50A2B0	2017-07-08 00:50:00+03	24800.00
50A2DC	2017-08-01 20:04:00+03	40800.00
50A322	2017-08-08 18:09:00+03	114100.00
50A3AE	2017-07-15 15:23:00+03	34000.00
50A3BB	2017-07-02 20:14:00+03	398500.00
50A3D3	2017-07-04 00:50:00+03	49900.00
50A3DF	2017-07-27 18:15:00+03	43300.00
50A3EE	2017-07-16 10:07:00+03	42400.00
50A405	2017-07-22 22:13:00+03	138100.00
50A40D	2017-07-24 18:28:00+03	19600.00
50A462	2017-07-19 23:32:00+03	56000.00
50A46F	2017-07-18 18:05:00+03	38600.00
50A4DE	2017-08-11 22:55:00+03	136200.00
50A52E	2017-07-11 14:20:00+03	79900.00
50A548	2017-07-30 17:02:00+03	108300.00
50A5D0	2017-07-16 09:09:00+03	26000.00
50A61D	2017-08-10 11:57:00+03	34100.00
50A673	2017-07-19 15:17:00+03	133800.00
50A6BF	2017-07-10 15:29:00+03	39300.00
50A6CE	2017-07-17 06:39:00+03	152600.00
50A736	2017-07-03 15:46:00+03	124200.00
50A768	2017-07-30 18:59:00+03	45200.00
50A7AA	2017-08-11 18:27:00+03	88000.00
50A7D8	2017-07-02 23:10:00+03	62100.00
50A7E3	2017-07-04 21:04:00+03	58000.00
50A840	2017-07-26 22:17:00+03	69000.00
50A843	2017-08-14 23:10:00+03	108600.00
50A848	2017-08-11 17:37:00+03	166100.00
50A85D	2017-07-20 07:23:00+03	26800.00
50A862	2017-08-11 02:06:00+03	211300.00
50A8F5	2017-08-11 07:37:00+03	24400.00
50A8F7	2017-08-01 05:35:00+03	58400.00
50A942	2017-07-28 16:27:00+03	83200.00
50A982	2017-08-07 15:59:00+03	48300.00
50A990	2017-07-07 21:30:00+03	23100.00
50A999	2017-07-08 00:23:00+03	58200.00
50A9FD	2017-08-08 03:46:00+03	35800.00
50AA7F	2017-07-04 17:47:00+03	62600.00
50AA92	2017-07-03 02:04:00+03	26800.00
50AAA0	2017-07-06 13:15:00+03	51500.00
50AAFB	2017-07-23 22:49:00+03	64800.00
50AB0C	2017-07-18 12:10:00+03	92900.00
50AB22	2017-07-23 00:32:00+03	97500.00
50AB4B	2017-07-25 22:29:00+03	173500.00
50AB61	2017-07-17 18:18:00+03	46400.00
50AB74	2017-07-30 11:16:00+03	90800.00
50ABD3	2017-07-31 05:09:00+03	6000.00
50AC80	2017-07-05 11:29:00+03	65500.00
50AD2A	2017-08-06 21:57:00+03	26800.00
50AD2B	2017-07-03 04:50:00+03	86800.00
50AE20	2017-08-02 17:20:00+03	67800.00
50AE53	2017-08-11 02:01:00+03	113200.00
50AE64	2017-07-17 01:00:00+03	56000.00
50AE8E	2017-08-11 11:10:00+03	46300.00
50AEA3	2017-07-09 18:03:00+03	123000.00
50AF75	2017-07-05 07:59:00+03	13300.00
50AF7D	2017-07-17 19:56:00+03	51200.00
50AFA2	2017-07-22 23:15:00+03	23600.00
50AFD7	2017-07-07 21:37:00+03	46400.00
50B064	2017-07-25 23:16:00+03	39300.00
50B074	2017-07-11 18:31:00+03	218000.00
50B08E	2017-07-23 05:36:00+03	48900.00
50B0C8	2017-08-11 04:17:00+03	39600.00
50B0DA	2017-08-10 20:14:00+03	133200.00
50B121	2017-08-03 19:27:00+03	38600.00
50B171	2017-07-05 13:55:00+03	60400.00
50B196	2017-07-28 00:52:00+03	46500.00
50B1B1	2017-07-12 06:14:00+03	21800.00
50B215	2017-07-11 03:12:00+03	87100.00
50B2CC	2017-08-12 05:10:00+03	96200.00
50B2DB	2017-07-22 22:26:00+03	354400.00
50B35F	2017-07-10 16:40:00+03	95600.00
50B36A	2017-08-12 17:15:00+03	120100.00
50B37F	2017-08-02 11:39:00+03	57200.00
50B3C9	2017-08-02 00:31:00+03	41400.00
50B418	2017-07-09 11:53:00+03	46300.00
50B556	2017-07-28 15:12:00+03	55600.00
50B5B0	2017-07-16 23:50:00+03	17200.00
50B5B1	2017-07-18 17:59:00+03	66600.00
50B650	2017-07-17 16:21:00+03	33000.00
50B677	2017-08-09 09:52:00+03	28000.00
50B6AB	2017-08-12 08:42:00+03	103200.00
50B6AE	2017-07-21 12:33:00+03	191200.00
50B6D6	2017-07-22 00:06:00+03	130400.00
50B6EF	2017-08-09 19:26:00+03	69600.00
50B6F2	2017-07-20 12:34:00+03	135000.00
50B70D	2017-08-12 05:45:00+03	147000.00
50B71B	2017-07-25 03:56:00+03	37600.00
50B7EE	2017-07-20 07:22:00+03	51900.00
50B818	2017-07-30 17:29:00+03	73600.00
50B86B	2017-07-02 00:27:00+03	45200.00
50B86E	2017-08-10 15:29:00+03	99300.00
50B870	2017-07-30 15:28:00+03	156500.00
50B894	2017-08-05 11:52:00+03	70700.00
50B8C3	2017-08-01 19:35:00+03	16000.00
50B95B	2017-07-19 23:19:00+03	535400.00
50B9A4	2017-07-01 21:43:00+03	102100.00
50B9C1	2017-08-01 01:03:00+03	38800.00
50B9D5	2017-07-26 10:17:00+03	71900.00
50BA04	2017-08-06 02:52:00+03	50100.00
50BA85	2017-07-31 10:52:00+03	28000.00
50BABB	2017-07-07 15:01:00+03	34100.00
50BB27	2017-08-15 08:32:00+03	42800.00
50BB6C	2017-08-13 18:29:00+03	92400.00
50BC07	2017-07-31 15:56:00+03	132800.00
50BD0A	2017-08-05 23:25:00+03	12600.00
50BD6D	2017-07-27 00:45:00+03	199200.00
50BD75	2017-08-06 09:41:00+03	12600.00
50BD77	2017-07-16 02:35:00+03	14400.00
50BDC6	2017-07-10 02:55:00+03	34800.00
50BE2E	2017-08-12 19:08:00+03	138000.00
50BE4B	2017-07-04 23:52:00+03	28000.00
50BEBF	2017-07-12 01:55:00+03	32300.00
50BF03	2017-08-11 16:15:00+03	46000.00
50BF2B	2017-07-29 12:59:00+03	136800.00
50BF7F	2017-08-05 02:05:00+03	131600.00
50C00B	2017-07-06 11:28:00+03	42800.00
50C06A	2017-07-13 21:05:00+03	66600.00
50C090	2017-08-08 11:48:00+03	112000.00
50C0C5	2017-07-17 15:06:00+03	25100.00
50C17F	2017-07-06 01:18:00+03	73200.00
50C191	2017-08-13 23:52:00+03	397100.00
50C198	2017-07-08 12:33:00+03	50100.00
50C1B2	2017-07-17 15:10:00+03	73500.00
50C1E4	2017-08-15 15:07:00+03	86400.00
50C1F5	2017-06-25 09:02:00+03	134600.00
50C23D	2017-06-29 07:19:00+03	89600.00
50C267	2017-08-05 09:19:00+03	65900.00
50C310	2017-07-04 08:03:00+03	56400.00
50C39B	2017-07-13 15:02:00+03	22000.00
50C433	2017-07-18 21:21:00+03	52300.00
50C43F	2017-07-18 22:26:00+03	246800.00
50C4C5	2017-07-10 15:29:00+03	30000.00
50C4C7	2017-08-10 01:34:00+03	100600.00
50C4CD	2017-07-17 19:25:00+03	266400.00
50C4D7	2017-08-03 18:47:00+03	26700.00
50C4E6	2017-07-06 14:19:00+03	46000.00
50C52B	2017-08-10 15:02:00+03	82800.00
50C538	2017-07-20 18:29:00+03	57600.00
50C54E	2017-06-30 18:34:00+03	24400.00
50C563	2017-07-05 04:47:00+03	28000.00
50C56B	2017-07-22 16:23:00+03	27900.00
50C650	2017-08-13 12:29:00+03	66600.00
50C6AE	2017-07-12 21:22:00+03	18900.00
50C6E8	2017-07-14 22:09:00+03	13600.00
50C702	2017-07-29 18:04:00+03	27800.00
50C785	2017-07-14 18:16:00+03	6600.00
50C79B	2017-07-21 04:40:00+03	21800.00
50C83B	2017-07-13 03:48:00+03	16400.00
50C842	2017-08-14 08:47:00+03	41400.00
50C8B2	2017-08-09 03:13:00+03	13000.00
50C8B8	2017-07-01 22:23:00+03	311200.00
50C914	2017-08-12 00:06:00+03	73300.00
50C91D	2017-07-18 13:53:00+03	26800.00
50C987	2017-07-03 00:53:00+03	193000.00
50CA2B	2017-07-05 18:22:00+03	172100.00
50CA40	2017-07-04 13:09:00+03	23600.00
50CA5D	2017-08-09 11:40:00+03	26700.00
50CA60	2017-08-13 09:18:00+03	22000.00
50CA6B	2017-08-14 16:10:00+03	36200.00
50CADF	2017-07-12 02:53:00+03	46000.00
50CB05	2017-08-09 11:05:00+03	54400.00
50CB8F	2017-07-26 12:50:00+03	202100.00
50CC2E	2017-07-09 01:26:00+03	8200.00
50CC8B	2017-07-08 22:11:00+03	107500.00
50CD60	2017-07-16 01:07:00+03	53600.00
50CD9A	2017-07-27 10:35:00+03	123000.00
50CDA4	2017-07-07 19:35:00+03	26000.00
50CDB5	2017-07-14 19:09:00+03	16400.00
50CDBB	2017-07-15 07:07:00+03	500100.00
50CE15	2017-07-05 15:49:00+03	29200.00
50CE3A	2017-07-24 16:23:00+03	135000.00
50CE69	2017-07-27 14:32:00+03	26000.00
50CEF6	2017-08-01 19:45:00+03	67900.00
50CF08	2017-08-01 07:33:00+03	75800.00
50CF6D	2017-07-27 10:38:00+03	57800.00
50CF8F	2017-07-01 01:37:00+03	31600.00
50CFBC	2017-07-17 23:06:00+03	79300.00
50D09C	2017-06-26 17:21:00+03	46000.00
50D0F1	2017-08-14 17:32:00+03	131400.00
50D0F8	2017-08-05 08:01:00+03	50300.00
50D10B	2017-07-07 13:58:00+03	28000.00
50D177	2017-07-28 12:35:00+03	16800.00
50D190	2017-07-31 18:44:00+03	73600.00
50D197	2017-07-09 10:22:00+03	29400.00
50D1B6	2017-07-30 11:33:00+03	95900.00
50D21E	2017-08-09 06:14:00+03	96800.00
50D266	2017-07-05 07:27:00+03	178800.00
50D2A5	2017-08-06 19:22:00+03	21800.00
50D2A9	2017-07-28 16:03:00+03	37100.00
50D2AA	2017-07-13 07:29:00+03	57600.00
50D356	2017-07-31 20:41:00+03	18000.00
50D36E	2017-07-03 20:36:00+03	147200.00
50D388	2017-07-20 19:22:00+03	24400.00
50D3EB	2017-07-31 00:31:00+03	93900.00
50D400	2017-08-08 07:25:00+03	266000.00
50D41D	2017-07-23 18:43:00+03	24800.00
50D44F	2017-08-08 19:38:00+03	14800.00
50D481	2017-07-11 05:14:00+03	217600.00
50D50C	2017-06-30 00:59:00+03	23600.00
50D51A	2017-07-13 00:31:00+03	47500.00
50D546	2017-07-13 05:01:00+03	27200.00
50D57B	2017-08-08 07:26:00+03	134400.00
50D5FA	2017-08-09 05:38:00+03	34400.00
50D64B	2017-07-30 07:41:00+03	36000.00
50D70F	2017-07-20 07:46:00+03	76600.00
50D78A	2017-07-04 01:05:00+03	108000.00
50D7FC	2017-08-04 06:33:00+03	69700.00
50D848	2017-07-10 14:38:00+03	46200.00
50D87C	2017-07-21 12:42:00+03	89600.00
50D8C9	2017-07-10 06:54:00+03	93900.00
50D928	2017-08-02 06:22:00+03	128000.00
50D92D	2017-08-15 17:19:00+03	122300.00
50DA1F	2017-08-03 21:23:00+03	94800.00
50DA3D	2017-07-22 22:23:00+03	44000.00
50DA3F	2017-07-23 02:51:00+03	6700.00
50DA71	2017-08-15 07:38:00+03	211100.00
50DAA1	2017-07-26 14:04:00+03	98400.00
50DAB6	2017-08-11 12:46:00+03	93100.00
50DAB9	2017-07-03 15:56:00+03	58600.00
50DB2F	2017-07-03 01:34:00+03	48800.00
50DB56	2017-07-26 10:10:00+03	22100.00
50DB7D	2017-08-10 15:45:00+03	123000.00
50DBF7	2017-07-08 07:21:00+03	52900.00
50DC01	2017-08-10 11:20:00+03	93400.00
50DC31	2017-08-07 20:52:00+03	140300.00
50DC81	2017-07-23 03:48:00+03	55800.00
50DCA3	2017-07-27 22:15:00+03	36800.00
50DCAF	2017-07-15 16:25:00+03	4000.00
50DCD5	2017-07-08 11:56:00+03	33100.00
50DCE2	2017-07-18 04:59:00+03	46800.00
50DCF1	2017-08-14 11:01:00+03	31600.00
50DD6E	2017-07-13 14:42:00+03	35200.00
50DD7B	2017-07-31 10:08:00+03	43900.00
50DD83	2017-08-11 03:34:00+03	137600.00
50DDBF	2017-07-29 20:59:00+03	38200.00
50DE31	2017-07-08 00:02:00+03	272300.00
50DE3D	2017-08-05 02:25:00+03	86300.00
50DE80	2017-07-25 04:04:00+03	39300.00
50DEDE	2017-07-23 16:37:00+03	57600.00
50DEE9	2017-06-29 01:40:00+03	190700.00
50DEEF	2017-07-06 22:32:00+03	131100.00
50DEF2	2017-07-29 20:22:00+03	58000.00
50E052	2017-07-04 12:41:00+03	62200.00
50E05B	2017-08-14 11:54:00+03	25600.00
50E0BB	2017-07-07 07:32:00+03	58600.00
50E0D2	2017-08-08 19:45:00+03	284400.00
50E167	2017-07-03 15:31:00+03	22600.00
50E18C	2017-07-08 03:44:00+03	408600.00
50E18E	2017-08-05 13:59:00+03	13600.00
50E19B	2017-08-07 10:28:00+03	133100.00
50E1B1	2017-08-10 10:17:00+03	92000.00
50E207	2017-07-17 09:15:00+03	38200.00
50E20B	2017-07-31 08:32:00+03	42000.00
50E318	2017-07-31 06:59:00+03	51900.00
50E33E	2017-07-22 04:37:00+03	123000.00
50E353	2017-08-12 21:04:00+03	95800.00
50E47C	2017-07-13 09:11:00+03	170000.00
50E4A9	2017-08-09 22:33:00+03	89600.00
50E4B8	2017-08-02 08:54:00+03	155600.00
50E4D9	2017-08-12 01:55:00+03	14000.00
50E4E1	2017-08-09 17:45:00+03	54400.00
50E4ED	2017-08-03 17:50:00+03	40800.00
50E599	2017-08-04 06:55:00+03	28000.00
50E5A6	2017-08-12 05:53:00+03	45200.00
50E622	2017-07-09 03:04:00+03	14800.00
50E652	2017-08-06 17:22:00+03	56000.00
50E658	2017-07-31 20:52:00+03	47400.00
50E688	2017-07-22 01:04:00+03	59100.00
50E749	2017-08-08 23:31:00+03	23200.00
50E764	2017-07-28 15:16:00+03	100600.00
50E7FA	2017-08-01 02:33:00+03	354200.00
50E807	2017-08-01 08:54:00+03	246000.00
50E845	2017-07-07 23:56:00+03	49200.00
50E872	2017-07-19 14:36:00+03	51900.00
50E87F	2017-07-22 12:59:00+03	112600.00
50E890	2017-07-24 03:19:00+03	62700.00
50E898	2017-07-06 00:22:00+03	134800.00
50E938	2017-08-09 10:36:00+03	33000.00
50E9C1	2017-08-07 12:38:00+03	26000.00
50EA3A	2017-07-08 13:43:00+03	73600.00
50EA9E	2017-07-15 04:40:00+03	29100.00
50EAC6	2017-07-30 04:20:00+03	50800.00
50EB0E	2017-08-01 13:16:00+03	46300.00
50EB2E	2017-06-28 10:47:00+03	40600.00
50EB67	2017-07-22 16:57:00+03	98200.00
50EBAE	2017-08-02 17:56:00+03	27800.00
50EBB8	2017-08-14 13:45:00+03	65900.00
50EC3F	2017-08-13 06:11:00+03	130800.00
50ECB0	2017-07-04 13:09:00+03	48800.00
50ECDC	2017-08-02 11:01:00+03	38000.00
50ECF4	2017-07-26 21:59:00+03	186900.00
50EDDA	2017-08-15 01:02:00+03	93700.00
50EE0B	2017-08-11 21:43:00+03	111600.00
50EE0F	2017-07-20 00:38:00+03	34400.00
50EE35	2017-08-08 20:15:00+03	15000.00
50EE46	2017-08-12 08:00:00+03	56000.00
50EEAF	2017-08-13 03:46:00+03	71100.00
50EEF5	2017-08-15 16:19:00+03	115200.00
50EF95	2017-07-20 16:39:00+03	65900.00
50EFD2	2017-07-04 07:12:00+03	112000.00
50F01B	2017-07-22 09:14:00+03	60400.00
50F110	2017-07-03 08:42:00+03	23200.00
50F120	2017-08-08 21:45:00+03	24700.00
50F14F	2017-07-09 06:15:00+03	28800.00
50F154	2017-08-13 13:32:00+03	51300.00
50F180	2017-07-02 01:09:00+03	29400.00
50F186	2017-07-04 03:40:00+03	116900.00
50F191	2017-07-06 22:28:00+03	95000.00
50F19A	2017-08-14 05:22:00+03	48800.00
50F1EA	2017-07-06 08:58:00+03	56600.00
50F217	2017-07-22 20:01:00+03	14400.00
50F2AF	2017-08-09 01:06:00+03	41400.00
50F2BA	2017-08-10 07:51:00+03	6800.00
50F2EA	2017-07-17 16:42:00+03	23200.00
50F30B	2017-07-27 16:21:00+03	53300.00
50F30F	2017-08-15 03:12:00+03	90900.00
50F338	2017-07-02 05:39:00+03	22000.00
50F352	2017-07-25 13:13:00+03	41800.00
50F354	2017-08-12 19:22:00+03	49300.00
50F3CD	2017-07-16 08:11:00+03	125400.00
50F3EB	2017-07-29 21:33:00+03	20200.00
50F3F3	2017-07-14 12:13:00+03	223200.00
50F409	2017-07-14 04:43:00+03	148900.00
50F42C	2017-07-29 17:45:00+03	62100.00
50F45B	2017-07-06 23:42:00+03	28800.00
50F4EF	2017-07-02 00:19:00+03	153600.00
50F5DA	2017-07-09 05:36:00+03	7400.00
50F5F5	2017-08-12 14:22:00+03	15900.00
50F6D2	2017-07-20 14:21:00+03	57800.00
50F6DD	2017-08-15 09:04:00+03	80700.00
50F6DF	2017-08-06 06:14:00+03	52400.00
50F75C	2017-07-09 17:27:00+03	23100.00
50F787	2017-07-26 02:32:00+03	271500.00
50F7AC	2017-07-14 14:05:00+03	58000.00
50F7D3	2017-07-07 11:09:00+03	47400.00
50F815	2017-07-09 07:03:00+03	369000.00
50F831	2017-07-08 15:14:00+03	56000.00
50F837	2017-07-09 04:57:00+03	340200.00
50F8C1	2017-07-03 08:46:00+03	93900.00
50F8DA	2017-07-04 06:31:00+03	43000.00
50F8E4	2017-07-26 21:40:00+03	57500.00
50F945	2017-07-16 17:26:00+03	25700.00
50FA22	2017-08-09 00:25:00+03	196000.00
50FA58	2017-08-13 02:42:00+03	171400.00
50FA60	2017-07-30 08:48:00+03	21400.00
50FAA4	2017-07-22 08:49:00+03	100000.00
50FABE	2017-08-11 07:30:00+03	15000.00
50FB48	2017-08-03 22:23:00+03	26700.00
50FB4A	2017-08-02 02:16:00+03	106800.00
50FB58	2017-07-16 11:27:00+03	28000.00
50FB5C	2017-08-04 19:48:00+03	40000.00
50FB7E	2017-07-05 20:38:00+03	46800.00
50FBB6	2017-07-26 01:44:00+03	28800.00
50FBC2	2017-07-30 13:04:00+03	73300.00
50FBEC	2017-06-28 11:42:00+03	31600.00
50FBF5	2017-08-13 06:17:00+03	66600.00
50FC32	2017-07-30 22:26:00+03	57500.00
50FCAA	2017-07-28 21:27:00+03	68400.00
50FCE4	2017-08-06 01:21:00+03	21800.00
50FD0A	2017-07-22 08:04:00+03	492000.00
50FD17	2017-08-02 23:03:00+03	81600.00
50FD50	2017-07-04 07:56:00+03	16400.00
50FDC6	2017-08-10 21:52:00+03	31600.00
50FE70	2017-08-10 01:06:00+03	70100.00
50FEB8	2017-07-04 07:46:00+03	146500.00
50FEFC	2017-08-02 18:32:00+03	57800.00
51002A	2017-08-02 15:35:00+03	97000.00
51004B	2017-07-25 17:40:00+03	112000.00
510077	2017-07-20 16:40:00+03	28300.00
510078	2017-07-17 06:45:00+03	65200.00
5100B0	2017-07-09 06:19:00+03	175700.00
5100C2	2017-07-06 13:19:00+03	135600.00
5100DD	2017-08-12 03:20:00+03	36200.00
5100F0	2017-08-07 17:34:00+03	26000.00
5100F5	2017-08-03 10:07:00+03	6700.00
51010F	2017-07-27 10:55:00+03	81600.00
510123	2017-07-19 23:53:00+03	55800.00
51017D	2017-07-26 10:56:00+03	36900.00
5101CA	2017-07-10 17:19:00+03	23600.00
51020B	2017-08-08 19:04:00+03	113100.00
5102A8	2017-07-08 20:24:00+03	28000.00
510340	2017-07-21 10:48:00+03	7400.00
51037E	2017-08-02 15:15:00+03	57600.00
5103B5	2017-07-03 11:22:00+03	57100.00
5103F7	2017-08-04 16:40:00+03	93400.00
5103FF	2017-07-27 03:48:00+03	28800.00
510466	2017-07-25 11:45:00+03	53200.00
510559	2017-07-03 05:30:00+03	26000.00
510583	2017-07-16 09:27:00+03	135000.00
5105A3	2017-07-11 05:24:00+03	59300.00
5105F2	2017-07-25 10:19:00+03	6300.00
510622	2017-07-09 04:28:00+03	17800.00
5106BA	2017-08-01 20:18:00+03	23400.00
510725	2017-07-02 17:39:00+03	99700.00
51074C	2017-08-06 12:15:00+03	69600.00
510775	2017-07-17 08:44:00+03	24800.00
5107BC	2017-08-12 06:45:00+03	114800.00
5107E3	2017-07-30 06:23:00+03	89700.00
5107FF	2017-07-31 06:04:00+03	34000.00
51084C	2017-06-30 22:46:00+03	28000.00
51084E	2017-07-01 19:57:00+03	85700.00
510862	2017-07-03 18:19:00+03	28000.00
510871	2017-07-13 18:08:00+03	672600.00
5108EB	2017-07-23 02:03:00+03	70900.00
5109C7	2017-07-22 06:20:00+03	32800.00
5109D2	2017-08-12 14:11:00+03	21400.00
5109E1	2017-07-16 21:33:00+03	48100.00
5109FD	2017-07-16 23:53:00+03	179500.00
510A11	2017-07-10 18:59:00+03	66400.00
510A25	2017-07-09 00:31:00+03	34000.00
510A2F	2017-08-10 15:43:00+03	26000.00
510A4C	2017-07-03 06:41:00+03	23600.00
510A90	2017-07-25 10:51:00+03	94200.00
510B2D	2017-07-16 10:39:00+03	26700.00
510B32	2017-07-03 22:17:00+03	61900.00
510B5F	2017-07-07 02:07:00+03	85600.00
510BB1	2017-07-12 14:11:00+03	62600.00
510BDD	2017-08-10 11:57:00+03	38800.00
510C07	2017-07-15 10:40:00+03	83200.00
510C8B	2017-07-22 09:26:00+03	22100.00
510CD0	2017-07-27 12:34:00+03	44500.00
510CFA	2017-08-02 06:19:00+03	116000.00
510D4A	2017-07-27 02:21:00+03	44800.00
510D55	2017-07-27 15:04:00+03	38600.00
510D61	2017-07-18 06:22:00+03	26000.00
510DB2	2017-07-06 02:09:00+03	59400.00
510DCB	2017-07-23 18:08:00+03	40000.00
510DEC	2017-08-02 19:44:00+03	111600.00
510E4B	2017-07-05 19:24:00+03	46200.00
510F19	2017-07-05 18:23:00+03	69700.00
510F84	2017-07-26 13:32:00+03	39300.00
510FAD	2017-08-12 23:28:00+03	23200.00
510FD6	2017-08-08 03:13:00+03	50600.00
510FE9	2017-07-26 13:27:00+03	252200.00
510FF3	2017-08-12 04:16:00+03	44800.00
511030	2017-07-29 05:03:00+03	35400.00
511080	2017-08-12 20:17:00+03	34000.00
5110B6	2017-07-03 19:52:00+03	31600.00
5110C9	2017-07-10 19:43:00+03	137800.00
5110D9	2017-07-06 14:48:00+03	133100.00
511169	2017-07-27 14:34:00+03	13000.00
51117A	2017-07-01 15:00:00+03	56000.00
5111C6	2017-08-09 05:27:00+03	10100.00
5111E8	2017-07-05 09:33:00+03	136200.00
511243	2017-08-11 22:54:00+03	47100.00
511290	2017-08-11 18:12:00+03	6800.00
511314	2017-06-27 04:55:00+03	44000.00
511315	2017-07-20 11:35:00+03	173600.00
511389	2017-07-16 16:31:00+03	83500.00
5113CE	2017-08-08 00:15:00+03	68000.00
5113F8	2017-07-29 22:43:00+03	62200.00
51143E	2017-07-08 18:38:00+03	123000.00
51147A	2017-07-14 11:26:00+03	58600.00
511488	2017-07-16 01:51:00+03	28800.00
5114C2	2017-08-09 19:24:00+03	19500.00
5114ED	2017-07-11 01:32:00+03	6200.00
511510	2017-08-02 23:19:00+03	28300.00
511575	2017-07-18 00:16:00+03	62600.00
511580	2017-08-05 07:24:00+03	256300.00
5115E0	2017-07-31 20:33:00+03	155200.00
51165B	2017-07-28 19:23:00+03	56600.00
511687	2017-08-14 13:48:00+03	86800.00
5116DB	2017-07-27 01:35:00+03	15000.00
5116DF	2017-06-29 18:58:00+03	75500.00
511755	2017-07-30 20:09:00+03	46400.00
511775	2017-07-09 02:41:00+03	103500.00
5117D7	2017-06-29 01:38:00+03	24400.00
5117DF	2017-07-05 17:49:00+03	32800.00
511806	2017-07-23 06:17:00+03	101200.00
511833	2017-07-26 13:02:00+03	70100.00
511863	2017-07-14 03:47:00+03	48800.00
5118AF	2017-08-13 01:10:00+03	23400.00
5118CA	2017-07-30 13:56:00+03	188200.00
511901	2017-08-07 07:54:00+03	55800.00
511938	2017-06-25 07:17:00+03	106400.00
5119B8	2017-07-04 12:37:00+03	43400.00
5119C4	2017-08-15 05:25:00+03	56000.00
511A88	2017-08-08 10:58:00+03	21200.00
511AF1	2017-07-24 06:54:00+03	19600.00
511AF4	2017-07-07 08:10:00+03	58000.00
511B09	2017-07-30 17:27:00+03	46400.00
511B0B	2017-06-26 03:12:00+03	26700.00
511B16	2017-07-27 04:11:00+03	67600.00
511B2B	2017-08-08 18:16:00+03	28800.00
511B4D	2017-07-14 00:51:00+03	26200.00
511B59	2017-07-28 23:19:00+03	37700.00
511B7F	2017-07-26 19:07:00+03	23600.00
511B84	2017-06-30 04:15:00+03	56600.00
511D18	2017-07-17 15:09:00+03	18400.00
511D23	2017-07-23 14:04:00+03	62700.00
511D87	2017-07-22 15:00:00+03	111600.00
511DD2	2017-08-09 12:52:00+03	26200.00
511E5F	2017-08-13 11:39:00+03	109300.00
511E6E	2017-08-04 11:18:00+03	134800.00
511E76	2017-07-08 17:18:00+03	103200.00
511EA5	2017-07-03 05:11:00+03	13400.00
511EB4	2017-08-10 02:47:00+03	26000.00
511EE4	2017-08-07 13:23:00+03	135400.00
511F11	2017-08-09 07:09:00+03	34000.00
511F44	2017-08-13 12:58:00+03	32400.00
512062	2017-08-13 23:29:00+03	26700.00
512085	2017-08-13 03:44:00+03	92000.00
5120A1	2017-07-13 00:45:00+03	32800.00
5120D2	2017-08-04 20:36:00+03	28800.00
5120D7	2017-08-05 07:29:00+03	127800.00
51214B	2017-06-30 15:14:00+03	29600.00
512158	2017-07-02 14:20:00+03	65500.00
512168	2017-08-04 12:47:00+03	25800.00
512236	2017-07-09 06:50:00+03	28300.00
512241	2017-07-18 01:17:00+03	27200.00
51224B	2017-07-15 18:54:00+03	25000.00
512265	2017-08-05 16:21:00+03	123000.00
5122AA	2017-07-21 23:23:00+03	27200.00
5122CA	2017-08-08 02:31:00+03	172200.00
5122D5	2017-07-23 08:03:00+03	24700.00
512396	2017-07-19 19:27:00+03	43400.00
5123EE	2017-08-14 12:42:00+03	3400.00
5123F1	2017-08-12 08:29:00+03	39300.00
5123FD	2017-08-05 15:20:00+03	83300.00
512413	2017-07-12 14:02:00+03	28800.00
512433	2017-08-13 12:23:00+03	68400.00
512441	2017-06-28 16:39:00+03	46300.00
512471	2017-08-12 17:01:00+03	20400.00
5124D0	2017-08-10 00:50:00+03	37200.00
512530	2017-06-30 07:17:00+03	46400.00
512559	2017-07-24 08:14:00+03	118700.00
5125C7	2017-08-09 23:05:00+03	77900.00
5126A1	2017-07-05 18:51:00+03	38800.00
512707	2017-08-14 22:28:00+03	98200.00
5127A6	2017-07-17 15:36:00+03	43900.00
5127BB	2017-07-11 07:18:00+03	38600.00
512805	2017-07-19 16:10:00+03	246000.00
51281B	2017-08-01 04:37:00+03	40800.00
512844	2017-07-15 09:02:00+03	99900.00
51285C	2017-07-31 07:46:00+03	36800.00
51288F	2017-07-14 07:35:00+03	53400.00
51289F	2017-07-27 13:52:00+03	73600.00
5128D8	2017-08-04 00:30:00+03	112000.00
5128E6	2017-07-28 05:19:00+03	31400.00
51290F	2017-07-14 05:36:00+03	137400.00
51298F	2017-07-20 23:20:00+03	66600.00
512A59	2017-08-10 20:26:00+03	27800.00
512A64	2017-07-01 04:59:00+03	54800.00
512A67	2017-07-20 21:12:00+03	92400.00
512AA6	2017-07-14 16:38:00+03	137600.00
512AB4	2017-06-26 16:23:00+03	54000.00
512ACD	2017-08-11 00:04:00+03	139400.00
512AF8	2017-08-06 01:23:00+03	60400.00
512B09	2017-07-26 22:28:00+03	74300.00
512B5E	2017-07-05 22:45:00+03	25600.00
512B98	2017-07-08 03:41:00+03	35800.00
512BD2	2017-08-03 23:01:00+03	125200.00
512C95	2017-07-29 05:01:00+03	99300.00
512CBA	2017-07-31 03:15:00+03	26600.00
512CC8	2017-07-20 09:00:00+03	117700.00
512CCE	2017-08-02 15:15:00+03	139200.00
512CF9	2017-07-31 01:14:00+03	28000.00
512D2F	2017-07-27 22:25:00+03	53100.00
512D5B	2017-07-03 04:38:00+03	13300.00
512DBF	2017-06-28 13:27:00+03	27800.00
512DC4	2017-08-07 05:19:00+03	20800.00
512E25	2017-08-01 21:08:00+03	41600.00
512E5F	2017-07-09 05:03:00+03	136500.00
512E94	2017-07-12 23:27:00+03	38400.00
512EA1	2017-08-09 05:00:00+03	65500.00
512F7E	2017-07-20 11:50:00+03	64600.00
51302D	2017-08-09 21:57:00+03	73200.00
513062	2017-07-12 19:05:00+03	165000.00
5130AD	2017-07-31 17:22:00+03	109600.00
5130B1	2017-07-07 21:56:00+03	149600.00
5130CA	2017-07-25 06:55:00+03	29600.00
513126	2017-08-11 15:26:00+03	45300.00
513161	2017-07-19 09:46:00+03	56900.00
5131E4	2017-07-12 19:22:00+03	28800.00
51321D	2017-07-28 22:32:00+03	23400.00
5132C2	2017-08-01 13:24:00+03	70600.00
51332B	2017-08-08 06:40:00+03	39800.00
51337D	2017-07-05 08:37:00+03	26000.00
513383	2017-07-25 21:24:00+03	130900.00
5133EC	2017-07-05 17:59:00+03	29000.00
513418	2017-07-03 07:41:00+03	58600.00
51343D	2017-07-29 02:49:00+03	43300.00
51344D	2017-07-28 04:46:00+03	86600.00
513459	2017-07-04 11:33:00+03	77200.00
513462	2017-08-10 23:10:00+03	23200.00
51348E	2017-07-31 17:55:00+03	58200.00
51349C	2017-07-21 12:07:00+03	40800.00
5134BC	2017-08-05 01:52:00+03	34600.00
5134C6	2017-07-03 12:52:00+03	593700.00
513524	2017-07-17 13:38:00+03	23200.00
513592	2017-08-01 10:13:00+03	50000.00
5136B9	2017-08-06 04:34:00+03	83700.00
5136C7	2017-07-21 07:40:00+03	23200.00
513700	2017-08-10 20:57:00+03	12000.00
51376F	2017-08-02 04:30:00+03	82700.00
513867	2017-08-13 21:13:00+03	57500.00
51386C	2017-07-12 04:07:00+03	53100.00
513872	2017-08-14 22:16:00+03	83200.00
513876	2017-07-23 15:13:00+03	145500.00
51388C	2017-07-30 12:54:00+03	18000.00
513904	2017-07-12 21:18:00+03	101900.00
51393C	2017-07-22 06:50:00+03	19600.00
51393D	2017-07-17 21:54:00+03	131100.00
51396D	2017-07-26 00:01:00+03	67600.00
513982	2017-07-11 06:39:00+03	28000.00
5139D6	2017-06-30 23:32:00+03	14400.00
5139E7	2017-07-16 14:17:00+03	78500.00
513A46	2017-07-27 05:17:00+03	128300.00
513A6C	2017-07-21 01:21:00+03	187800.00
513AC2	2017-08-04 05:40:00+03	173200.00
513B1E	2017-07-24 09:18:00+03	56000.00
513B40	2017-07-04 19:58:00+03	56000.00
513B49	2017-07-15 19:09:00+03	67700.00
513B6A	2017-07-17 05:23:00+03	26000.00
513B7A	2017-07-03 18:09:00+03	257600.00
513B8E	2017-07-15 03:52:00+03	28000.00
513BF6	2017-08-12 19:17:00+03	22400.00
513C40	2017-08-14 22:06:00+03	22000.00
513C60	2017-07-06 11:00:00+03	189800.00
513C80	2017-07-17 00:20:00+03	63700.00
513C83	2017-08-09 11:59:00+03	502900.00
513CCF	2017-07-04 20:21:00+03	23200.00
513CF4	2017-07-05 03:13:00+03	85800.00
513D6C	2017-07-06 12:17:00+03	65900.00
513DDB	2017-07-15 05:40:00+03	65800.00
513E0C	2017-07-09 17:32:00+03	62400.00
513E11	2017-07-05 18:23:00+03	56000.00
513E19	2017-07-05 06:53:00+03	83700.00
513E1B	2017-07-15 19:05:00+03	6300.00
513E94	2017-07-12 13:42:00+03	68400.00
513E9E	2017-07-23 10:54:00+03	38600.00
513EDF	2017-07-18 09:58:00+03	51600.00
513F00	2017-07-06 10:55:00+03	23400.00
513F18	2017-08-05 03:29:00+03	77900.00
513F1D	2017-07-29 21:31:00+03	23200.00
513F87	2017-07-30 03:51:00+03	75600.00
513FC1	2017-07-22 21:46:00+03	145300.00
513FF4	2017-07-02 01:25:00+03	71600.00
51401B	2017-07-15 02:50:00+03	44100.00
51404F	2017-08-12 23:45:00+03	26800.00
5140A9	2017-07-21 12:27:00+03	37900.00
5140C5	2017-07-05 01:22:00+03	48800.00
5140DD	2017-08-06 19:35:00+03	69100.00
514121	2017-07-16 23:52:00+03	14400.00
51415B	2017-07-19 14:46:00+03	46400.00
514172	2017-07-28 16:18:00+03	50800.00
5141B0	2017-07-26 02:15:00+03	273400.00
51421B	2017-08-08 05:40:00+03	431800.00
51422B	2017-07-04 14:11:00+03	15800.00
51428D	2017-07-17 05:16:00+03	69500.00
51432B	2017-08-14 16:29:00+03	13400.00
514333	2017-07-21 23:41:00+03	68600.00
514357	2017-07-18 04:16:00+03	13600.00
514481	2017-08-01 03:33:00+03	26000.00
514577	2017-07-08 13:41:00+03	111000.00
51460F	2017-07-16 12:02:00+03	139800.00
514612	2017-08-09 09:16:00+03	378300.00
514693	2017-08-12 19:00:00+03	28800.00
5146F6	2017-08-04 22:55:00+03	56000.00
51471C	2017-07-19 20:11:00+03	169300.00
514738	2017-08-11 20:37:00+03	38400.00
5147C7	2017-08-11 13:47:00+03	48800.00
51480F	2017-07-15 15:15:00+03	40100.00
51482E	2017-07-23 04:35:00+03	31800.00
514836	2017-07-16 15:01:00+03	95200.00
51488E	2017-07-17 14:20:00+03	99200.00
514892	2017-08-04 01:16:00+03	28800.00
5148A1	2017-08-14 06:52:00+03	204500.00
5148A2	2017-07-12 00:32:00+03	67600.00
5148A7	2017-07-07 12:30:00+03	204200.00
5148AC	2017-08-01 10:24:00+03	10800.00
5148B7	2017-07-18 11:44:00+03	61800.00
5149A0	2017-07-23 16:46:00+03	68900.00
5149D9	2017-06-30 19:27:00+03	46300.00
514A0C	2017-08-10 17:21:00+03	36900.00
514AA9	2017-06-28 05:22:00+03	46400.00
514AAD	2017-07-30 11:05:00+03	72600.00
514B12	2017-07-10 06:47:00+03	23100.00
514B48	2017-07-19 00:37:00+03	82600.00
514BAE	2017-07-12 08:39:00+03	65100.00
514CA6	2017-07-27 05:07:00+03	955000.00
514D4A	2017-06-30 19:04:00+03	43900.00
514D78	2017-07-30 10:34:00+03	57600.00
514DDF	2017-08-13 09:38:00+03	18700.00
514E3B	2017-07-16 13:50:00+03	28800.00
514E59	2017-07-30 11:44:00+03	88000.00
514E8B	2017-06-28 09:18:00+03	133200.00
514E8C	2017-07-18 07:08:00+03	25600.00
514F1F	2017-08-08 10:56:00+03	131600.00
514FFE	2017-07-14 09:04:00+03	92800.00
51506B	2017-07-21 08:47:00+03	168000.00
515078	2017-07-14 08:50:00+03	55800.00
515092	2017-07-13 23:59:00+03	185600.00
5150B6	2017-08-09 06:54:00+03	52300.00
51513F	2017-07-20 15:41:00+03	11600.00
515183	2017-08-09 05:55:00+03	46400.00
5151BC	2017-07-16 20:19:00+03	51900.00
5152BD	2017-07-05 06:08:00+03	16400.00
51530B	2017-08-01 13:57:00+03	38600.00
515315	2017-08-05 10:03:00+03	51800.00
515361	2017-07-28 13:05:00+03	46000.00
51536A	2017-07-28 11:30:00+03	6000.00
515390	2017-07-23 10:12:00+03	52600.00
51540E	2017-08-06 09:08:00+03	76100.00
515421	2017-07-06 08:26:00+03	31000.00
515449	2017-07-27 16:48:00+03	106900.00
515453	2017-08-12 09:25:00+03	137900.00
515478	2017-07-20 09:44:00+03	56600.00
515486	2017-07-06 01:55:00+03	46000.00
5154F6	2017-06-26 21:56:00+03	23600.00
51551F	2017-06-27 10:58:00+03	23400.00
515532	2017-06-30 17:28:00+03	144400.00
5155D3	2017-07-23 20:09:00+03	140300.00
515608	2017-08-09 02:43:00+03	44600.00
5157D7	2017-07-26 20:28:00+03	12400.00
5157EE	2017-07-03 01:35:00+03	12400.00
5157F0	2017-07-19 04:26:00+03	103400.00
5157F8	2017-08-15 05:19:00+03	113000.00
51581A	2017-07-20 14:41:00+03	26000.00
515829	2017-08-08 13:03:00+03	399600.00
51586F	2017-07-22 05:20:00+03	336100.00
515872	2017-08-04 18:27:00+03	171900.00
5158CE	2017-06-30 00:50:00+03	266400.00
515940	2017-08-10 20:11:00+03	26000.00
51596B	2017-08-15 09:15:00+03	89700.00
515994	2017-07-01 12:33:00+03	51700.00
515AF0	2017-07-04 07:11:00+03	60700.00
515AFE	2017-07-19 04:54:00+03	251100.00
515B25	2017-08-09 15:26:00+03	77900.00
515B45	2017-07-12 11:59:00+03	14000.00
515B6B	2017-07-04 11:08:00+03	22400.00
515B74	2017-07-31 01:46:00+03	28000.00
515BBD	2017-08-02 08:50:00+03	57600.00
515C45	2017-08-12 07:33:00+03	46300.00
515C98	2017-08-03 04:30:00+03	85700.00
515CB2	2017-08-06 01:15:00+03	19600.00
515CC4	2017-08-05 05:08:00+03	25200.00
515CD2	2017-07-08 23:18:00+03	56000.00
515D18	2017-07-20 19:12:00+03	54000.00
515DC5	2017-08-12 00:38:00+03	81700.00
515DE3	2017-07-17 08:06:00+03	122600.00
515DE9	2017-07-05 23:09:00+03	40800.00
515E50	2017-08-08 23:21:00+03	137100.00
515ECC	2017-07-09 13:23:00+03	75200.00
515EE5	2017-07-24 23:24:00+03	12400.00
515F30	2017-07-17 01:38:00+03	36100.00
515F50	2017-07-19 08:08:00+03	257600.00
515FAA	2017-07-20 17:16:00+03	40600.00
515FB7	2017-07-12 21:18:00+03	99300.00
515FD2	2017-07-21 15:49:00+03	44800.00
515FD9	2017-08-02 01:17:00+03	79900.00
516041	2017-07-17 03:16:00+03	28000.00
516081	2017-08-09 12:05:00+03	35300.00
5160A6	2017-07-17 05:06:00+03	22000.00
5160A9	2017-08-10 12:40:00+03	200800.00
5160C7	2017-07-15 21:45:00+03	69700.00
5160DB	2017-07-18 18:41:00+03	27200.00
51610A	2017-07-03 10:28:00+03	60400.00
5162DB	2017-07-27 21:07:00+03	56000.00
51631F	2017-07-27 01:26:00+03	13000.00
51633B	2017-07-04 09:00:00+03	47000.00
516355	2017-08-11 17:38:00+03	14400.00
51637A	2017-07-31 15:39:00+03	61800.00
516394	2017-06-30 06:57:00+03	40100.00
5163AA	2017-07-29 15:56:00+03	114800.00
5163BE	2017-07-28 23:39:00+03	35600.00
516437	2017-08-04 19:10:00+03	25200.00
51646D	2017-07-14 19:42:00+03	93900.00
5164CC	2017-07-05 20:46:00+03	46300.00
5164E3	2017-07-18 02:39:00+03	34000.00
516516	2017-07-29 18:15:00+03	46900.00
5165FA	2017-07-08 15:25:00+03	28800.00
516629	2017-07-08 01:50:00+03	57800.00
51663B	2017-07-13 16:24:00+03	75300.00
516681	2017-08-07 15:45:00+03	6700.00
516707	2017-08-03 13:22:00+03	139300.00
516735	2017-08-08 05:46:00+03	139300.00
516773	2017-08-06 04:15:00+03	31200.00
5167CE	2017-07-21 09:16:00+03	23200.00
5167E8	2017-07-08 11:29:00+03	59800.00
516820	2017-08-06 18:00:00+03	123000.00
516825	2017-08-12 00:04:00+03	53100.00
51691B	2017-08-15 03:08:00+03	29600.00
516974	2017-08-15 06:48:00+03	48400.00
51697B	2017-08-07 23:05:00+03	52300.00
516A02	2017-08-04 23:35:00+03	59100.00
516A35	2017-07-30 14:37:00+03	23200.00
516A67	2017-07-10 21:06:00+03	163800.00
516A7B	2017-07-07 02:18:00+03	32200.00
516A8C	2017-07-11 01:23:00+03	68100.00
516C1B	2017-07-06 16:26:00+03	37800.00
516D54	2017-07-09 11:08:00+03	356200.00
516D89	2017-08-04 09:58:00+03	8200.00
516D8E	2017-08-03 08:11:00+03	19600.00
516E80	2017-08-08 04:56:00+03	25600.00
516ED8	2017-07-15 12:59:00+03	64100.00
516EED	2017-07-24 20:38:00+03	28800.00
516F1B	2017-07-25 11:31:00+03	136200.00
516F72	2017-07-11 18:28:00+03	59000.00
516FBF	2017-08-01 13:56:00+03	80800.00
516FE3	2017-07-31 10:15:00+03	24400.00
517046	2017-08-13 12:13:00+03	44800.00
517082	2017-07-26 00:33:00+03	32700.00
517098	2017-07-06 19:59:00+03	31600.00
5170AF	2017-08-10 14:42:00+03	38800.00
5170D1	2017-08-07 01:04:00+03	23400.00
51710F	2017-07-07 22:41:00+03	64100.00
51714A	2017-07-29 00:52:00+03	99600.00
51714C	2017-07-23 20:31:00+03	24200.00
5171A3	2017-06-28 03:25:00+03	135900.00
5171D2	2017-07-24 16:11:00+03	38400.00
5171E6	2017-07-31 05:54:00+03	51800.00
5172AA	2017-08-11 20:38:00+03	44000.00
5172F0	2017-07-21 16:40:00+03	29800.00
51735D	2017-07-14 09:33:00+03	72200.00
51741A	2017-07-02 01:10:00+03	56100.00
5174C2	2017-07-12 02:09:00+03	11600.00
5174FD	2017-07-16 04:50:00+03	202600.00
51751D	2017-07-13 04:22:00+03	59900.00
517586	2017-07-24 01:25:00+03	115700.00
517596	2017-07-04 02:40:00+03	93800.00
51760A	2017-08-04 11:07:00+03	135600.00
517634	2017-07-24 20:03:00+03	92800.00
5176A1	2017-07-24 15:22:00+03	56000.00
5176C7	2017-07-28 10:29:00+03	136200.00
5176E7	2017-08-13 08:59:00+03	40800.00
5176F0	2017-07-09 12:04:00+03	64800.00
5177ED	2017-08-13 13:49:00+03	16400.00
517846	2017-07-19 04:51:00+03	111600.00
517860	2017-07-21 20:10:00+03	130400.00
517905	2017-07-28 13:54:00+03	405200.00
517914	2017-07-22 13:25:00+03	136100.00
51799A	2017-07-14 04:44:00+03	89700.00
517A9B	2017-08-14 07:39:00+03	25000.00
517AC4	2017-08-04 15:07:00+03	82400.00
517B40	2017-07-13 10:45:00+03	105000.00
517B5C	2017-07-04 13:56:00+03	91200.00
517B9C	2017-07-11 01:31:00+03	67900.00
517BE6	2017-07-22 06:50:00+03	120800.00
517CFC	2017-07-22 01:22:00+03	41500.00
517D7B	2017-07-03 08:55:00+03	43400.00
517D7D	2017-08-08 02:37:00+03	123000.00
517DF9	2017-07-31 03:36:00+03	88800.00
517EBB	2017-07-19 15:28:00+03	111600.00
517EE5	2017-08-15 07:01:00+03	24200.00
517F0B	2017-08-03 05:30:00+03	43700.00
517F23	2017-08-06 02:33:00+03	18800.00
517F33	2017-08-10 21:21:00+03	39400.00
517F49	2017-07-30 12:32:00+03	71400.00
517F50	2017-08-03 01:38:00+03	26000.00
517FC9	2017-08-08 08:40:00+03	38600.00
517FD3	2017-07-23 03:21:00+03	36200.00
517FF4	2017-07-30 19:13:00+03	115900.00
5180E5	2017-07-18 05:31:00+03	153300.00
518100	2017-07-22 11:58:00+03	111200.00
518101	2017-07-06 00:22:00+03	69200.00
51817F	2017-07-22 14:31:00+03	74600.00
5182E6	2017-07-30 05:55:00+03	38200.00
518315	2017-07-25 03:17:00+03	64700.00
51831B	2017-08-13 03:19:00+03	74900.00
518357	2017-07-18 16:42:00+03	28800.00
51837F	2017-07-15 03:42:00+03	33100.00
5183F2	2017-07-07 04:22:00+03	20400.00
518403	2017-08-14 12:04:00+03	66800.00
51845D	2017-08-08 14:40:00+03	140900.00
518478	2017-07-07 10:06:00+03	130400.00
51847A	2017-07-18 00:39:00+03	37900.00
5184F9	2017-07-16 04:46:00+03	23400.00
51852D	2017-07-02 23:11:00+03	22600.00
518538	2017-08-04 02:10:00+03	26000.00
518553	2017-08-05 05:25:00+03	39300.00
518573	2017-07-22 23:39:00+03	14800.00
518595	2017-07-28 22:40:00+03	87000.00
518668	2017-07-05 23:34:00+03	20100.00
518699	2017-07-25 08:05:00+03	25000.00
51869D	2017-07-26 14:22:00+03	55800.00
51877C	2017-07-05 22:15:00+03	124600.00
51879F	2017-07-31 16:00:00+03	79700.00
5187B9	2017-08-04 03:41:00+03	84800.00
5187EB	2017-07-17 15:36:00+03	123000.00
518815	2017-08-05 22:49:00+03	56900.00
51888F	2017-07-06 17:29:00+03	55800.00
5188E7	2017-06-29 03:10:00+03	29400.00
518913	2017-07-19 09:45:00+03	66800.00
518955	2017-07-23 12:22:00+03	86400.00
518984	2017-07-20 15:13:00+03	26000.00
518A01	2017-08-02 01:09:00+03	27800.00
518A4D	2017-08-11 01:42:00+03	33800.00
518A64	2017-08-06 03:43:00+03	94000.00
518A88	2017-07-06 00:47:00+03	92400.00
518AB0	2017-07-09 12:41:00+03	26000.00
518AC1	2017-08-04 13:44:00+03	23200.00
518B29	2017-08-15 02:59:00+03	64800.00
518B30	2017-07-04 16:12:00+03	149200.00
518B3E	2017-07-03 16:47:00+03	36200.00
518B85	2017-07-17 07:02:00+03	22000.00
518B8A	2017-07-31 03:22:00+03	55800.00
518BE0	2017-07-19 09:54:00+03	115900.00
518BE5	2017-08-06 22:34:00+03	22000.00
518BFF	2017-08-11 23:55:00+03	114800.00
518C21	2017-07-11 08:04:00+03	215500.00
518C61	2017-07-30 17:11:00+03	56100.00
518CD7	2017-08-07 08:28:00+03	138900.00
518CF4	2017-07-11 08:16:00+03	16400.00
518D00	2017-07-02 11:53:00+03	22100.00
518D21	2017-08-07 01:14:00+03	90000.00
518D52	2017-07-01 04:53:00+03	61800.00
518D6B	2017-08-14 09:52:00+03	25600.00
518DB9	2017-07-10 10:55:00+03	57900.00
518DE7	2017-07-06 11:24:00+03	265600.00
518E14	2017-08-15 06:36:00+03	16400.00
518EB1	2017-07-17 20:02:00+03	38600.00
518EC1	2017-07-22 13:43:00+03	56600.00
518EC5	2017-08-14 21:47:00+03	103800.00
518EE3	2017-07-19 03:02:00+03	45200.00
518EFC	2017-07-20 18:23:00+03	23200.00
518F85	2017-07-31 18:09:00+03	40400.00
518F9F	2017-08-05 19:01:00+03	75600.00
518FAA	2017-08-07 18:58:00+03	49100.00
518FE9	2017-07-24 18:13:00+03	8000.00
518FF9	2017-07-21 16:22:00+03	56000.00
519000	2017-08-05 01:39:00+03	52400.00
519058	2017-07-07 14:07:00+03	28800.00
519074	2017-08-15 17:27:00+03	135400.00
5190E7	2017-07-12 07:39:00+03	32700.00
5190FC	2017-07-30 13:44:00+03	179400.00
519114	2017-07-10 02:06:00+03	15800.00
519149	2017-07-22 08:05:00+03	116400.00
519157	2017-08-04 22:00:00+03	266200.00
51916F	2017-07-26 09:35:00+03	30200.00
5191E0	2017-07-22 04:00:00+03	20200.00
51923E	2017-07-15 08:33:00+03	26000.00
519292	2017-08-15 10:52:00+03	14800.00
5192C8	2017-07-12 00:57:00+03	127200.00
5192FB	2017-07-27 21:14:00+03	56000.00
519316	2017-07-11 16:35:00+03	6000.00
51932D	2017-07-15 18:16:00+03	81500.00
5193F3	2017-07-20 13:08:00+03	408600.00
519405	2017-07-01 14:08:00+03	83000.00
5194FE	2017-08-04 08:41:00+03	112000.00
51951B	2017-07-11 23:18:00+03	11600.00
5195AC	2017-08-13 20:12:00+03	46800.00
5195B7	2017-08-05 22:45:00+03	11600.00
5195CD	2017-07-30 19:41:00+03	14000.00
5195DA	2017-08-07 11:29:00+03	113700.00
51960E	2017-08-10 00:49:00+03	102100.00
519613	2017-08-07 06:16:00+03	64100.00
519645	2017-07-24 13:56:00+03	72200.00
5196F7	2017-07-11 08:00:00+03	34000.00
5197DD	2017-08-07 06:48:00+03	13400.00
5197E6	2017-08-14 08:22:00+03	209200.00
519831	2017-07-26 00:12:00+03	118200.00
51983C	2017-07-31 15:33:00+03	72400.00
519855	2017-08-08 22:41:00+03	58200.00
5198A1	2017-07-24 15:24:00+03	36000.00
5198A9	2017-07-07 08:30:00+03	135400.00
51995C	2017-07-06 06:39:00+03	202000.00
51997F	2017-07-10 04:19:00+03	185500.00
5199BB	2017-08-01 05:39:00+03	53800.00
5199F3	2017-08-06 17:40:00+03	23200.00
519A33	2017-07-27 09:48:00+03	67600.00
519A36	2017-08-11 23:45:00+03	79600.00
519AC0	2017-08-08 21:48:00+03	67900.00
519ACD	2017-07-06 00:33:00+03	65600.00
519B32	2017-07-30 10:29:00+03	101500.00
519B4F	2017-07-15 16:23:00+03	20200.00
519B5B	2017-07-13 01:51:00+03	292900.00
519BB2	2017-07-28 10:07:00+03	129200.00
519BE2	2017-08-12 12:14:00+03	59000.00
519BEA	2017-07-14 12:06:00+03	42000.00
519C49	2017-07-18 19:05:00+03	15800.00
519CCC	2017-08-05 00:27:00+03	23600.00
519CCD	2017-08-09 02:06:00+03	51900.00
519D07	2017-07-09 16:31:00+03	71900.00
519D10	2017-07-17 06:38:00+03	6700.00
519D43	2017-07-31 11:01:00+03	286700.00
519D51	2017-07-30 06:00:00+03	61800.00
519DC3	2017-08-13 15:00:00+03	25600.00
519DE3	2017-07-18 15:04:00+03	112000.00
519E0E	2017-08-03 18:12:00+03	29600.00
519E47	2017-08-10 03:17:00+03	106100.00
519E48	2017-07-18 07:46:00+03	66600.00
519EB4	2017-07-03 12:13:00+03	121200.00
519EFF	2017-08-01 15:38:00+03	24000.00
519F52	2017-06-28 23:36:00+03	252200.00
519F97	2017-08-10 14:20:00+03	55000.00
519FBF	2017-07-26 15:13:00+03	62200.00
51A0D4	2017-07-06 05:24:00+03	62700.00
51A0EF	2017-06-30 20:15:00+03	52100.00
51A101	2017-07-29 16:35:00+03	52800.00
51A10B	2017-07-30 06:32:00+03	23400.00
51A133	2017-07-23 03:41:00+03	46000.00
51A14C	2017-07-07 20:04:00+03	93900.00
51A15F	2017-08-14 04:02:00+03	26800.00
51A17B	2017-08-12 20:41:00+03	39400.00
51A1E1	2017-07-29 15:01:00+03	68800.00
51A1E5	2017-08-11 10:11:00+03	54000.00
51A2A1	2017-07-16 11:27:00+03	56000.00
51A2DC	2017-08-13 10:01:00+03	59400.00
51A355	2017-07-20 07:40:00+03	62100.00
51A360	2017-08-03 23:57:00+03	35800.00
51A3AD	2017-07-27 09:13:00+03	38600.00
51A3C4	2017-07-26 19:42:00+03	56600.00
51A3C8	2017-07-26 06:40:00+03	119500.00
51A420	2017-08-13 05:24:00+03	55800.00
51A439	2017-07-16 04:38:00+03	28800.00
51A45A	2017-08-03 21:24:00+03	147200.00
51A4AC	2017-07-17 18:03:00+03	133900.00
51A4BC	2017-07-24 04:20:00+03	70100.00
51A508	2017-07-20 14:50:00+03	6700.00
51A51F	2017-07-24 10:45:00+03	19600.00
51A530	2017-07-26 09:15:00+03	82900.00
51A5C7	2017-07-05 01:37:00+03	39800.00
51A5DA	2017-07-24 03:08:00+03	92400.00
51A5E4	2017-07-29 04:29:00+03	43100.00
51A66A	2017-07-02 01:09:00+03	23100.00
51A687	2017-07-28 00:23:00+03	73600.00
51A6AE	2017-07-13 06:00:00+03	28800.00
51A732	2017-07-29 19:39:00+03	116400.00
51A764	2017-08-04 23:42:00+03	189400.00
51A777	2017-07-25 09:19:00+03	260900.00
51A7BE	2017-06-29 08:05:00+03	29600.00
51A7FF	2017-07-29 20:32:00+03	37600.00
51A804	2017-07-12 00:22:00+03	54800.00
51A81F	2017-08-09 16:52:00+03	56000.00
51A853	2017-07-23 10:34:00+03	43200.00
51A877	2017-07-22 11:13:00+03	73500.00
51A904	2017-07-13 05:19:00+03	58600.00
51A97B	2017-08-01 11:06:00+03	56600.00
51AA0F	2017-08-08 07:41:00+03	259000.00
51AA65	2017-07-10 11:32:00+03	48800.00
51AAA6	2017-07-10 08:29:00+03	23200.00
51AB26	2017-07-23 18:30:00+03	396500.00
51AB4D	2017-07-25 14:58:00+03	13400.00
51AB60	2017-08-12 06:18:00+03	29600.00
51ABA9	2017-07-09 00:33:00+03	32700.00
51ABAB	2017-08-07 04:36:00+03	17000.00
51ABDD	2017-07-31 05:17:00+03	34000.00
51ABE4	2017-07-20 19:26:00+03	169600.00
51ABFA	2017-07-22 11:33:00+03	55800.00
51AC03	2017-07-15 17:24:00+03	20200.00
51AC21	2017-08-05 00:13:00+03	71700.00
51AC64	2017-08-05 00:10:00+03	25600.00
51AC95	2017-07-03 21:06:00+03	208200.00
51AD14	2017-07-13 23:55:00+03	50600.00
51AD7E	2017-07-02 04:07:00+03	229900.00
51ADAF	2017-07-09 19:55:00+03	59600.00
51AE5B	2017-08-10 07:49:00+03	50600.00
51AE73	2017-07-16 07:14:00+03	35400.00
51AEAD	2017-07-08 06:55:00+03	46200.00
51AED7	2017-07-28 03:50:00+03	41400.00
51AF07	2017-08-10 20:11:00+03	23600.00
51AF12	2017-08-10 22:49:00+03	8200.00
51AF5E	2017-08-10 08:06:00+03	89800.00
51AF68	2017-07-22 02:32:00+03	60300.00
51AFD6	2017-08-08 22:22:00+03	7400.00
51AFE8	2017-07-17 21:26:00+03	12000.00
51AFEB	2017-07-06 20:31:00+03	78100.00
51B030	2017-08-09 08:59:00+03	54800.00
51B037	2017-07-28 04:56:00+03	58800.00
51B05D	2017-08-11 11:10:00+03	31400.00
51B05E	2017-08-06 02:28:00+03	28800.00
51B073	2017-07-22 03:38:00+03	26800.00
51B0F0	2017-07-06 12:25:00+03	65000.00
51B109	2017-07-13 12:40:00+03	112600.00
51B132	2017-07-28 00:29:00+03	124200.00
51B178	2017-07-10 03:30:00+03	23200.00
51B187	2017-08-01 14:08:00+03	26700.00
51B24B	2017-07-31 04:44:00+03	23200.00
51B24F	2017-07-20 20:45:00+03	31200.00
51B259	2017-07-22 05:53:00+03	14000.00
51B29D	2017-07-06 01:17:00+03	202100.00
51B2D7	2017-08-14 07:36:00+03	111600.00
51B345	2017-08-04 14:30:00+03	50600.00
51B34B	2017-08-04 13:05:00+03	56000.00
51B356	2017-07-22 15:52:00+03	100000.00
51B3C4	2017-07-18 07:30:00+03	29400.00
51B3C7	2017-07-24 18:46:00+03	56100.00
51B411	2017-08-12 14:17:00+03	7400.00
51B41C	2017-07-30 08:14:00+03	91200.00
51B470	2017-07-13 06:34:00+03	135400.00
51B54C	2017-07-20 14:13:00+03	184300.00
51B58A	2017-07-18 17:34:00+03	40000.00
51B5C0	2017-07-23 23:55:00+03	392100.00
51B5D2	2017-08-11 09:14:00+03	53200.00
51B5F3	2017-07-16 06:06:00+03	154500.00
51B5FF	2017-08-06 21:37:00+03	205500.00
51B608	2017-07-30 08:14:00+03	51900.00
51B627	2017-07-15 22:10:00+03	57500.00
51B672	2017-08-14 15:12:00+03	25400.00
51B679	2017-07-14 04:36:00+03	68800.00
51B687	2017-08-06 14:55:00+03	46800.00
51B68E	2017-07-17 20:40:00+03	75300.00
51B694	2017-08-04 11:08:00+03	458600.00
51B6A2	2017-07-18 13:39:00+03	47600.00
51B6E1	2017-08-09 13:15:00+03	27300.00
51B70F	2017-08-08 06:59:00+03	12600.00
51B735	2017-07-29 21:55:00+03	58600.00
51B792	2017-08-14 04:22:00+03	54800.00
51B799	2017-08-12 15:48:00+03	28000.00
51B7F1	2017-07-20 00:10:00+03	21800.00
51B7FB	2017-07-31 10:32:00+03	47100.00
51B88A	2017-08-14 19:15:00+03	20200.00
51B8B6	2017-07-18 02:28:00+03	32700.00
51B8F8	2017-08-14 04:47:00+03	51900.00
51B90B	2017-07-05 00:29:00+03	62700.00
51B927	2017-08-02 18:42:00+03	246000.00
51B989	2017-08-14 00:05:00+03	67400.00
51B9B0	2017-08-01 07:51:00+03	99300.00
51B9B4	2017-08-01 08:03:00+03	33100.00
51B9C5	2017-07-31 02:35:00+03	69600.00
51B9D1	2017-07-18 09:25:00+03	67600.00
51B9EA	2017-07-14 22:01:00+03	113800.00
51BA0F	2017-07-31 10:29:00+03	50100.00
51BA55	2017-08-11 17:01:00+03	25800.00
51BA57	2017-07-23 13:04:00+03	95600.00
51BA6C	2017-07-15 00:18:00+03	79000.00
51BA8F	2017-07-06 01:58:00+03	7400.00
51BAB6	2017-07-22 03:01:00+03	58900.00
51BAB7	2017-07-10 12:38:00+03	28000.00
51BABB	2017-07-01 07:40:00+03	14800.00
51BB3B	2017-07-26 04:20:00+03	224000.00
51BBB0	2017-08-06 19:27:00+03	36200.00
51BBE5	2017-07-20 14:57:00+03	37700.00
51BC1F	2017-08-04 09:43:00+03	43100.00
51BC6B	2017-07-12 19:27:00+03	142400.00
51BC85	2017-07-31 08:02:00+03	41400.00
51BCB1	2017-08-02 13:22:00+03	143000.00
51BCC6	2017-07-25 04:16:00+03	65900.00
51BCC9	2017-07-13 18:29:00+03	198300.00
51BD22	2017-07-19 11:15:00+03	18000.00
51BD4B	2017-08-15 05:49:00+03	42000.00
51BD73	2017-07-14 11:32:00+03	70600.00
51BDB3	2017-08-07 21:09:00+03	93000.00
51BDC4	2017-08-12 18:31:00+03	29200.00
51BDE0	2017-08-14 22:39:00+03	54800.00
51BDE7	2017-07-31 10:08:00+03	14000.00
51BDE9	2017-07-17 00:49:00+03	177200.00
51BDEE	2017-07-24 07:40:00+03	26000.00
51BEAD	2017-07-06 10:55:00+03	70600.00
51BECF	2017-08-03 13:17:00+03	106800.00
51BF0B	2017-06-29 07:16:00+03	81600.00
51BF45	2017-07-26 07:38:00+03	166900.00
51BF81	2017-08-12 14:30:00+03	59400.00
51BFBA	2017-07-03 15:20:00+03	38400.00
51BFC0	2017-07-01 16:29:00+03	25600.00
51C030	2017-07-18 01:46:00+03	20200.00
51C146	2017-07-04 15:05:00+03	36400.00
51C176	2017-08-11 10:46:00+03	147600.00
51C270	2017-07-05 22:17:00+03	96800.00
51C281	2017-07-19 08:36:00+03	26000.00
51C28E	2017-07-08 00:56:00+03	22000.00
51C317	2017-07-13 06:25:00+03	28800.00
51C33A	2017-08-03 12:06:00+03	136800.00
51C342	2017-08-11 18:59:00+03	33200.00
51C343	2017-07-29 17:29:00+03	16400.00
51C361	2017-07-18 20:27:00+03	199700.00
51C37B	2017-07-26 19:07:00+03	81300.00
51C37D	2017-07-23 05:55:00+03	6700.00
51C37E	2017-08-02 11:46:00+03	21600.00
51C380	2017-08-12 01:19:00+03	119700.00
51C392	2017-08-07 13:17:00+03	48300.00
51C393	2017-08-13 05:18:00+03	42400.00
51C3AA	2017-07-18 19:31:00+03	173200.00
51C3B1	2017-07-23 21:14:00+03	25400.00
51C3ED	2017-08-04 03:02:00+03	28800.00
51C401	2017-08-06 01:35:00+03	6300.00
51C450	2017-07-09 12:28:00+03	73200.00
51C459	2017-08-11 02:10:00+03	41600.00
51C472	2017-07-08 03:28:00+03	26500.00
51C4A7	2017-07-09 17:36:00+03	91100.00
51C4B2	2017-07-26 04:42:00+03	17800.00
51C4BD	2017-08-08 09:53:00+03	38800.00
51C4DF	2017-07-25 05:07:00+03	320400.00
51C50C	2017-08-10 13:09:00+03	365400.00
51C5E8	2017-07-11 08:52:00+03	67600.00
51C5FA	2017-07-30 02:09:00+03	615000.00
51C626	2017-07-12 06:42:00+03	66600.00
51C647	2017-07-28 21:23:00+03	176900.00
51C703	2017-07-24 18:17:00+03	29600.00
51C76E	2017-08-08 06:43:00+03	106900.00
51C7CC	2017-07-19 17:39:00+03	61800.00
51C7F0	2017-08-12 14:44:00+03	60700.00
51C85D	2017-07-13 05:33:00+03	266400.00
51C882	2017-07-09 23:58:00+03	100600.00
51C883	2017-08-04 07:29:00+03	136600.00
51C8B0	2017-08-12 04:58:00+03	65100.00
51C8C8	2017-07-20 23:38:00+03	11800.00
51C8D8	2017-07-05 09:29:00+03	67000.00
51C8DD	2017-08-02 08:12:00+03	42700.00
51C8ED	2017-08-02 19:33:00+03	78300.00
51C93F	2017-07-26 09:00:00+03	55800.00
51C949	2017-08-12 10:50:00+03	56600.00
51C975	2017-08-04 14:09:00+03	58600.00
51C9A2	2017-07-23 02:34:00+03	168700.00
51C9C8	2017-08-04 14:35:00+03	89600.00
51C9EE	2017-08-02 05:36:00+03	294400.00
51CA24	2017-07-08 14:29:00+03	131100.00
51CA3F	2017-07-27 00:40:00+03	248300.00
51CAD4	2017-08-01 22:36:00+03	44800.00
51CAD6	2017-07-31 01:30:00+03	31100.00
51CB14	2017-07-04 02:51:00+03	72200.00
51CB82	2017-08-03 10:41:00+03	15400.00
51CBD6	2017-08-14 08:37:00+03	29000.00
51CBEC	2017-07-26 14:48:00+03	68100.00
51CC2A	2017-08-02 13:52:00+03	25100.00
51CC47	2017-07-10 12:35:00+03	111600.00
51CC86	2017-08-14 03:59:00+03	28800.00
51CCDA	2017-07-02 07:59:00+03	291700.00
51CD07	2017-07-25 12:30:00+03	6300.00
51CD57	2017-07-15 13:05:00+03	27300.00
51CDD2	2017-07-29 05:48:00+03	7200.00
51CE24	2017-07-05 17:13:00+03	10800.00
51CEBD	2017-07-13 06:18:00+03	184300.00
51CEDF	2017-07-27 11:34:00+03	25400.00
51CF21	2017-08-03 21:20:00+03	39400.00
51CF2F	2017-07-07 13:44:00+03	91600.00
51CF69	2017-08-13 23:40:00+03	66800.00
51CFC4	2017-07-12 06:22:00+03	84500.00
51D00F	2017-07-16 23:15:00+03	103900.00
51D038	2017-07-08 08:13:00+03	74700.00
51D191	2017-07-07 01:07:00+03	92700.00
51D1A7	2017-07-20 00:58:00+03	46300.00
51D1C9	2017-07-16 14:04:00+03	114600.00
51D298	2017-07-01 11:34:00+03	64500.00
51D2C8	2017-07-23 11:46:00+03	28800.00
51D342	2017-07-25 18:54:00+03	13000.00
51D41A	2017-08-06 23:59:00+03	55900.00
51D484	2017-07-30 20:05:00+03	7200.00
51D4AE	2017-07-18 16:52:00+03	36200.00
51D4CB	2017-08-09 03:17:00+03	62100.00
51D503	2017-08-11 19:06:00+03	28800.00
51D506	2017-07-21 12:00:00+03	229500.00
51D53E	2017-06-29 06:58:00+03	50900.00
51D548	2017-06-29 06:58:00+03	141600.00
51D56D	2017-07-12 04:40:00+03	141200.00
51D58C	2017-07-16 18:41:00+03	67600.00
51D593	2017-07-24 01:09:00+03	26200.00
51D5AB	2017-08-13 17:41:00+03	24400.00
51D5B6	2017-08-05 04:54:00+03	208200.00
51D5CE	2017-07-10 12:29:00+03	59600.00
51D5E8	2017-07-23 22:37:00+03	44000.00
51D662	2017-07-30 08:44:00+03	78800.00
51D667	2017-07-25 11:29:00+03	21400.00
51D672	2017-07-31 02:16:00+03	229300.00
51D762	2017-08-13 09:08:00+03	266400.00
51D784	2017-08-09 21:24:00+03	85000.00
51D793	2017-08-02 13:30:00+03	15700.00
51D794	2017-07-09 03:15:00+03	46300.00
51D7C6	2017-07-17 19:59:00+03	114400.00
51D7EA	2017-07-27 04:47:00+03	40400.00
51D7FB	2017-07-18 16:48:00+03	66600.00
51D813	2017-07-30 01:57:00+03	22600.00
51D816	2017-08-04 23:43:00+03	116900.00
51D832	2017-07-07 16:06:00+03	58400.00
51D85F	2017-08-08 17:09:00+03	40800.00
51D865	2017-08-07 04:30:00+03	26800.00
51D8D4	2017-07-07 15:26:00+03	19600.00
51D8DF	2017-07-07 21:47:00+03	112600.00
51D91B	2017-08-05 15:58:00+03	30400.00
51D979	2017-08-05 15:21:00+03	86300.00
51D980	2017-08-07 01:09:00+03	111600.00
51DA4F	2017-07-25 14:45:00+03	92600.00
51DA53	2017-07-13 20:11:00+03	57500.00
51DA6F	2017-07-18 16:12:00+03	55600.00
51DAC9	2017-07-18 00:19:00+03	62700.00
51DACD	2017-08-08 10:09:00+03	26200.00
51DB44	2017-07-06 21:27:00+03	56900.00
51DC5F	2017-07-23 01:34:00+03	14400.00
51DC8B	2017-07-29 09:03:00+03	56600.00
51DC8C	2017-07-13 02:39:00+03	31400.00
51DCB0	2017-08-11 00:04:00+03	20400.00
51DCFC	2017-07-28 21:37:00+03	24200.00
51DD1F	2017-08-10 14:14:00+03	123000.00
51DD5E	2017-08-10 04:35:00+03	126800.00
51DD5F	2017-07-25 15:02:00+03	31200.00
51DDC3	2017-08-04 03:33:00+03	14400.00
51DDEE	2017-07-18 01:59:00+03	112600.00
51DE21	2017-07-10 09:15:00+03	67000.00
51DEBE	2017-07-11 14:19:00+03	63700.00
51DED0	2017-08-15 07:51:00+03	123200.00
51DEDE	2017-08-07 15:13:00+03	55200.00
51DF0B	2017-07-16 05:35:00+03	20400.00
51DF34	2017-08-10 21:59:00+03	40800.00
51DF4A	2017-08-14 06:25:00+03	78100.00
51DFE2	2017-08-12 02:59:00+03	136200.00
51E041	2017-07-18 19:14:00+03	6800.00
51E047	2017-07-02 18:54:00+03	15000.00
51E101	2017-07-31 21:51:00+03	96400.00
51E10C	2017-07-16 13:00:00+03	246000.00
51E13D	2017-08-15 16:42:00+03	65100.00
51E160	2017-08-06 13:02:00+03	24700.00
51E18E	2017-07-03 12:36:00+03	46300.00
51E1F4	2017-07-07 08:44:00+03	28800.00
51E282	2017-07-29 07:30:00+03	54300.00
51E2E8	2017-07-20 06:06:00+03	131100.00
51E31D	2017-07-08 12:38:00+03	49100.00
51E32A	2017-08-10 11:13:00+03	92100.00
51E361	2017-07-28 23:15:00+03	37200.00
51E3E6	2017-08-10 18:32:00+03	40800.00
51E448	2017-08-01 09:02:00+03	66600.00
51E47B	2017-08-05 02:05:00+03	135600.00
51E47E	2017-07-11 15:04:00+03	26200.00
51E495	2017-07-07 10:55:00+03	66600.00
51E4DF	2017-07-19 19:20:00+03	271200.00
51E4F2	2017-08-07 15:08:00+03	187600.00
51E513	2017-08-05 02:40:00+03	68800.00
51E564	2017-07-14 18:46:00+03	271100.00
51E58A	2017-07-08 17:55:00+03	55800.00
51E59E	2017-08-02 16:20:00+03	89600.00
51E60E	2017-07-11 10:33:00+03	72300.00
51E63B	2017-07-24 09:58:00+03	90400.00
51E692	2017-07-22 07:45:00+03	37900.00
51E6DF	2017-07-01 05:47:00+03	56000.00
51E729	2017-07-28 17:44:00+03	12600.00
51E735	2017-08-13 04:48:00+03	18400.00
51E752	2017-07-13 08:44:00+03	136500.00
51E7AA	2017-08-07 02:42:00+03	69700.00
51E7CF	2017-08-04 05:17:00+03	40000.00
51E83C	2017-08-13 20:09:00+03	46000.00
51E84D	2017-08-12 03:44:00+03	83000.00
51E85C	2017-08-04 02:39:00+03	23400.00
51E863	2017-07-11 01:44:00+03	59200.00
51E8E8	2017-08-13 17:54:00+03	52700.00
51E8EF	2017-08-02 20:20:00+03	112000.00
51E917	2017-06-30 20:08:00+03	77900.00
51E943	2017-08-11 09:24:00+03	35300.00
51E980	2017-07-31 19:03:00+03	52000.00
51E9C3	2017-08-03 07:35:00+03	86500.00
51E9CD	2017-07-10 10:41:00+03	79400.00
51E9CE	2017-07-13 00:36:00+03	283100.00
51EA2D	2017-07-10 11:12:00+03	111600.00
51EA32	2017-07-05 20:37:00+03	31600.00
51EA4F	2017-08-14 17:53:00+03	60400.00
51EAA7	2017-07-28 09:58:00+03	95200.00
51EAD4	2017-07-16 14:26:00+03	24800.00
51EB1C	2017-07-01 15:32:00+03	28300.00
51EB3B	2017-07-03 17:54:00+03	23200.00
51EB58	2017-08-15 10:08:00+03	27600.00
51EB63	2017-07-11 09:20:00+03	58600.00
51EB89	2017-08-11 06:35:00+03	67800.00
51EBC3	2017-07-20 13:44:00+03	48800.00
51EBCE	2017-07-22 15:48:00+03	77000.00
51EC46	2017-07-14 14:52:00+03	46700.00
51EC93	2017-07-23 23:35:00+03	24000.00
51ECA9	2017-07-08 16:08:00+03	147700.00
51ECB0	2017-07-05 22:46:00+03	168000.00
51ED3C	2017-07-31 14:53:00+03	45200.00
51EDCD	2017-08-04 11:51:00+03	135400.00
51EDD4	2017-07-23 20:44:00+03	179400.00
51EE0F	2017-07-07 09:52:00+03	25600.00
51EE31	2017-07-18 05:58:00+03	54800.00
51EE54	2017-07-19 02:18:00+03	28000.00
51EE7D	2017-07-28 06:39:00+03	59000.00
51EEB0	2017-08-06 16:07:00+03	12000.00
51EEC0	2017-07-20 09:20:00+03	119500.00
51EF10	2017-07-09 21:45:00+03	29200.00
51EF79	2017-07-24 23:39:00+03	26000.00
51F018	2017-08-15 11:25:00+03	91500.00
51F034	2017-08-01 12:25:00+03	10800.00
51F036	2017-07-05 03:14:00+03	95100.00
51F040	2017-07-24 13:50:00+03	229000.00
51F049	2017-08-15 16:02:00+03	54500.00
51F050	2017-06-29 11:19:00+03	46800.00
51F063	2017-07-24 20:57:00+03	136800.00
51F09F	2017-07-29 23:30:00+03	57800.00
51F11D	2017-07-07 18:43:00+03	14800.00
51F14D	2017-07-15 04:46:00+03	265600.00
51F1D0	2017-07-28 02:37:00+03	26000.00
51F1D6	2017-08-01 23:16:00+03	50800.00
51F206	2017-07-31 02:59:00+03	59300.00
51F216	2017-07-12 17:09:00+03	69500.00
51F222	2017-07-18 05:54:00+03	6000.00
51F2F1	2017-07-14 18:38:00+03	31600.00
51F334	2017-06-30 21:34:00+03	6800.00
51F33B	2017-08-15 12:05:00+03	23200.00
51F467	2017-07-03 22:56:00+03	7400.00
51F4D0	2017-07-09 02:16:00+03	9200.00
51F4D4	2017-07-29 23:58:00+03	55800.00
51F525	2017-07-21 20:59:00+03	26000.00
51F577	2017-07-28 06:22:00+03	260700.00
51F5DD	2017-07-05 11:09:00+03	39300.00
51F5FC	2017-06-28 15:04:00+03	185000.00
51F5FF	2017-08-08 07:03:00+03	26000.00
51F612	2017-07-18 11:20:00+03	15000.00
51F665	2017-07-19 16:32:00+03	34000.00
51F698	2017-08-04 23:49:00+03	103600.00
51F6A5	2017-07-18 20:19:00+03	43500.00
51F6AB	2017-07-27 14:15:00+03	58800.00
51F6CE	2017-08-07 23:31:00+03	197300.00
51F6F3	2017-07-05 08:28:00+03	139000.00
51F710	2017-08-12 14:41:00+03	28800.00
51F71B	2017-07-21 17:17:00+03	30800.00
51F724	2017-08-05 00:57:00+03	125400.00
51F72F	2017-08-09 13:20:00+03	210000.00
51F756	2017-07-16 07:11:00+03	49200.00
51F89D	2017-08-03 17:23:00+03	43600.00
51F8A6	2017-08-14 16:49:00+03	125000.00
51F91F	2017-08-13 11:41:00+03	272300.00
51F9E3	2017-07-23 22:31:00+03	6800.00
51FA36	2017-07-10 01:25:00+03	23200.00
51FBA7	2017-07-16 18:23:00+03	37700.00
51FBC7	2017-08-03 09:02:00+03	28000.00
51FBD9	2017-07-31 03:19:00+03	13600.00
51FC0F	2017-08-09 18:06:00+03	12600.00
51FC8B	2017-07-21 18:56:00+03	111600.00
51FCA0	2017-08-11 20:49:00+03	155500.00
51FCA3	2017-07-17 23:20:00+03	92900.00
51FCA9	2017-07-04 01:18:00+03	25600.00
51FCCB	2017-07-05 14:42:00+03	11000.00
51FCD7	2017-07-14 03:29:00+03	12600.00
51FCDB	2017-08-04 19:00:00+03	242200.00
51FCF2	2017-08-07 11:33:00+03	44800.00
51FD02	2017-08-04 12:00:00+03	34200.00
51FD14	2017-08-10 20:25:00+03	133700.00
51FD34	2017-07-25 03:46:00+03	24400.00
51FD5E	2017-07-15 11:53:00+03	126200.00
51FDB8	2017-08-10 09:42:00+03	133700.00
51FE56	2017-08-14 16:30:00+03	288800.00
51FEA7	2017-06-30 09:57:00+03	36600.00
51FEB5	2017-07-15 14:38:00+03	11700.00
51FEC6	2017-08-12 11:57:00+03	89100.00
51FF0A	2017-07-13 16:47:00+03	29600.00
51FF2D	2017-08-12 14:59:00+03	14400.00
51FF83	2017-08-11 03:22:00+03	93700.00
51FF90	2017-08-14 16:10:00+03	18000.00
51FFA3	2017-07-02 22:21:00+03	48800.00
51FFB8	2017-08-08 11:15:00+03	166100.00
51FFEE	2017-07-02 17:04:00+03	117200.00
520012	2017-08-09 14:16:00+03	11700.00
52001B	2017-08-03 02:08:00+03	480600.00
52002D	2017-08-01 21:43:00+03	47000.00
52003D	2017-08-11 17:44:00+03	16400.00
520075	2017-07-03 07:00:00+03	20400.00
520079	2017-08-15 06:10:00+03	28800.00
520082	2017-07-05 07:07:00+03	27800.00
5200B1	2017-07-30 20:58:00+03	40200.00
5200F4	2017-07-23 15:14:00+03	23600.00
520109	2017-07-08 09:31:00+03	73400.00
520128	2017-08-09 20:05:00+03	56000.00
52014F	2017-07-06 15:59:00+03	29600.00
520204	2017-07-21 03:43:00+03	271100.00
52021E	2017-07-13 21:31:00+03	38200.00
52023D	2017-08-01 20:52:00+03	386300.00
52025D	2017-08-11 01:56:00+03	29500.00
5202B1	2017-07-14 07:07:00+03	272400.00
5202DF	2017-08-09 17:22:00+03	72600.00
520301	2017-07-21 09:23:00+03	664300.00
52030A	2017-08-13 15:14:00+03	157200.00
520320	2017-07-21 05:46:00+03	20600.00
52036F	2017-07-02 19:08:00+03	25400.00
520371	2017-07-29 16:44:00+03	141500.00
5203BC	2017-07-23 18:26:00+03	20400.00
5203C3	2017-08-09 05:25:00+03	57500.00
5203E5	2017-08-03 04:15:00+03	29400.00
520406	2017-07-20 02:28:00+03	60800.00
52044A	2017-07-09 16:17:00+03	34200.00
5204A3	2017-07-06 00:59:00+03	547800.00
5204B4	2017-07-26 17:10:00+03	107700.00
520529	2017-07-11 13:45:00+03	6000.00
52055A	2017-07-16 04:05:00+03	50600.00
52058D	2017-08-14 19:32:00+03	23600.00
5205AF	2017-07-10 14:00:00+03	109600.00
5205EA	2017-08-14 04:58:00+03	8600.00
52064C	2017-08-06 04:16:00+03	12000.00
52064D	2017-07-19 02:58:00+03	184500.00
520681	2017-08-08 22:05:00+03	34100.00
5206B8	2017-07-08 19:36:00+03	156000.00
520728	2017-07-14 01:57:00+03	42100.00
520790	2017-07-20 11:39:00+03	141600.00
5207A7	2017-07-19 07:25:00+03	90000.00
5207B3	2017-07-04 04:55:00+03	57600.00
5207C2	2017-07-15 13:03:00+03	44800.00
520822	2017-07-23 04:36:00+03	84900.00
52088C	2017-08-13 05:15:00+03	36400.00
5208AE	2017-07-18 15:35:00+03	38400.00
5209A9	2017-08-14 00:34:00+03	14400.00
5209B2	2017-06-29 11:45:00+03	26800.00
520A26	2017-07-24 10:39:00+03	37600.00
520AC4	2017-07-02 02:24:00+03	64200.00
520B55	2017-07-20 22:52:00+03	20800.00
520B93	2017-08-02 04:20:00+03	108600.00
520C0C	2017-07-18 16:03:00+03	73300.00
520C96	2017-07-07 07:12:00+03	40800.00
520CFD	2017-07-26 12:44:00+03	65500.00
520D00	2017-08-11 03:04:00+03	294400.00
520D10	2017-07-31 17:06:00+03	38600.00
520DE2	2017-07-04 05:44:00+03	78400.00
520DFB	2017-07-16 05:06:00+03	112000.00
520E20	2017-08-09 04:03:00+03	133100.00
520E55	2017-08-14 10:59:00+03	13400.00
520EB8	2017-07-26 11:53:00+03	100000.00
520EE9	2017-08-15 05:09:00+03	71900.00
520F13	2017-08-12 16:56:00+03	8000.00
520F61	2017-07-15 00:47:00+03	84100.00
52100E	2017-08-07 18:10:00+03	22000.00
52101F	2017-07-06 23:13:00+03	147700.00
52107E	2017-07-28 01:20:00+03	55800.00
521082	2017-08-01 22:04:00+03	12400.00
521102	2017-07-29 16:36:00+03	27400.00
52113F	2017-07-19 16:33:00+03	283100.00
52118B	2017-07-28 12:47:00+03	117900.00
5211D4	2017-06-29 14:47:00+03	316400.00
5211D8	2017-08-04 05:16:00+03	111600.00
5211EA	2017-07-14 02:27:00+03	26000.00
521206	2017-07-22 23:24:00+03	73600.00
52123A	2017-07-11 16:10:00+03	44500.00
52124E	2017-07-31 22:11:00+03	165700.00
52126C	2017-07-05 23:38:00+03	57500.00
521270	2017-07-23 03:16:00+03	23600.00
5212E3	2017-08-07 22:26:00+03	35700.00
5212E9	2017-07-21 22:59:00+03	35600.00
5212EA	2017-08-15 12:28:00+03	79900.00
52136C	2017-07-25 09:45:00+03	38400.00
52138A	2017-07-02 21:07:00+03	93000.00
521396	2017-08-02 15:39:00+03	25000.00
5213C0	2017-07-29 11:15:00+03	21800.00
5213FC	2017-08-09 23:03:00+03	88500.00
521454	2017-06-29 16:30:00+03	153400.00
521462	2017-07-18 06:12:00+03	118500.00
52146D	2017-07-26 06:39:00+03	58800.00
521488	2017-08-05 00:54:00+03	112000.00
5214C6	2017-08-08 08:07:00+03	406600.00
521526	2017-07-02 05:34:00+03	93500.00
52152D	2017-08-12 08:30:00+03	18800.00
52152F	2017-08-01 20:49:00+03	66900.00
521597	2017-08-03 12:34:00+03	22000.00
52161C	2017-08-02 19:59:00+03	26000.00
521636	2017-07-26 00:34:00+03	60400.00
521658	2017-07-07 11:08:00+03	63400.00
5216A9	2017-07-20 22:26:00+03	57800.00
5216D2	2017-07-15 20:33:00+03	47000.00
5216E5	2017-07-31 16:44:00+03	47500.00
5216FA	2017-08-09 07:45:00+03	397100.00
521740	2017-07-11 09:26:00+03	95400.00
5218AC	2017-08-06 21:40:00+03	174600.00
5218FF	2017-08-07 22:02:00+03	92000.00
521939	2017-07-20 06:51:00+03	262100.00
521970	2017-08-13 14:35:00+03	313600.00
521A12	2017-08-05 19:28:00+03	88600.00
521A1B	2017-07-16 00:15:00+03	26000.00
521A25	2017-08-15 16:52:00+03	40100.00
521A3C	2017-07-04 17:33:00+03	6000.00
521A7D	2017-07-29 00:38:00+03	144400.00
521AC4	2017-08-06 14:52:00+03	114300.00
521B5B	2017-08-07 13:21:00+03	123000.00
521B8A	2017-07-05 13:32:00+03	78200.00
521BB0	2017-08-14 04:23:00+03	451600.00
521BF9	2017-07-24 05:02:00+03	273000.00
521C09	2017-06-29 21:33:00+03	36200.00
521C2E	2017-07-22 14:13:00+03	68400.00
521C31	2017-08-15 00:12:00+03	86700.00
521C38	2017-08-08 07:53:00+03	84000.00
521C53	2017-07-08 09:25:00+03	985500.00
521C54	2017-07-19 19:36:00+03	88900.00
521C66	2017-08-06 09:07:00+03	116800.00
521CDF	2017-07-05 07:14:00+03	116900.00
521CE5	2017-07-25 12:29:00+03	6000.00
521D1F	2017-07-10 22:06:00+03	75600.00
521D2D	2017-08-04 12:07:00+03	149200.00
521D30	2017-07-21 22:37:00+03	6300.00
521D58	2017-07-29 16:57:00+03	55800.00
521D6E	2017-08-06 19:31:00+03	40000.00
521DD0	2017-08-14 17:58:00+03	27300.00
521DF4	2017-07-21 02:32:00+03	8800.00
521E17	2017-07-30 13:05:00+03	99200.00
521E18	2017-08-15 16:43:00+03	58400.00
521E21	2017-07-25 01:42:00+03	239000.00
521E85	2017-08-10 00:19:00+03	23400.00
521EC6	2017-07-03 09:15:00+03	30200.00
521F0A	2017-07-02 16:31:00+03	59100.00
521F20	2017-07-28 18:16:00+03	22000.00
521F85	2017-07-19 06:40:00+03	42800.00
521F91	2017-07-13 06:59:00+03	319900.00
521FFF	2017-07-17 16:57:00+03	23900.00
52203F	2017-08-06 19:49:00+03	131600.00
522059	2017-07-20 22:49:00+03	25400.00
5220C2	2017-08-02 18:06:00+03	18600.00
5220C6	2017-07-30 22:25:00+03	46400.00
5220E1	2017-07-18 05:30:00+03	132800.00
522123	2017-07-09 11:02:00+03	20000.00
52219D	2017-07-16 01:15:00+03	12600.00
5221C6	2017-08-11 09:15:00+03	19600.00
5221FC	2017-07-21 17:38:00+03	46400.00
52221E	2017-08-09 18:26:00+03	29400.00
52223B	2017-08-13 07:34:00+03	112600.00
522286	2017-06-30 03:11:00+03	106800.00
5222AE	2017-08-13 15:23:00+03	51900.00
5222C4	2017-08-07 02:13:00+03	16400.00
52232C	2017-07-13 01:11:00+03	18300.00
522364	2017-07-23 22:36:00+03	59300.00
52236D	2017-08-13 11:09:00+03	16400.00
522376	2017-07-22 03:11:00+03	290600.00
52238E	2017-08-02 03:37:00+03	122100.00
5223C4	2017-07-06 11:22:00+03	65300.00
522403	2017-07-10 03:18:00+03	8600.00
52245D	2017-08-03 13:05:00+03	70700.00
52249D	2017-08-06 12:13:00+03	102100.00
5224A9	2017-06-29 09:38:00+03	16400.00
5224E4	2017-07-29 22:35:00+03	46000.00
52252D	2017-07-16 08:07:00+03	16400.00
52258B	2017-07-02 10:46:00+03	46400.00
52259E	2017-07-08 03:50:00+03	40600.00
5225E7	2017-08-15 09:36:00+03	13400.00
5225FC	2017-07-08 08:59:00+03	26000.00
522627	2017-07-20 01:53:00+03	20600.00
52266D	2017-08-15 17:32:00+03	19000.00
522694	2017-08-09 12:40:00+03	65400.00
522698	2017-07-26 10:12:00+03	40000.00
5226EB	2017-08-14 22:40:00+03	46700.00
522737	2017-07-05 10:01:00+03	270700.00
522795	2017-07-17 16:14:00+03	38600.00
5227C8	2017-07-09 08:36:00+03	37100.00
522852	2017-07-23 06:25:00+03	6000.00
522892	2017-07-27 10:04:00+03	19800.00
5228C7	2017-06-29 12:53:00+03	48800.00
5228CD	2017-07-13 21:40:00+03	50000.00
5228D9	2017-07-16 19:43:00+03	87200.00
5228FE	2017-08-13 09:24:00+03	118400.00
52291E	2017-07-02 05:22:00+03	71600.00
522973	2017-07-20 20:23:00+03	14000.00
522990	2017-07-24 16:09:00+03	28800.00
522A48	2017-07-24 00:37:00+03	16400.00
522A54	2017-07-26 22:09:00+03	133100.00
522B08	2017-07-28 03:32:00+03	199600.00
522BD1	2017-07-15 14:00:00+03	466800.00
522C01	2017-08-06 08:17:00+03	115000.00
522C08	2017-07-06 03:40:00+03	38200.00
522C21	2017-07-08 06:48:00+03	44400.00
522C3D	2017-08-01 14:07:00+03	35800.00
522D15	2017-08-05 06:22:00+03	58800.00
522DE8	2017-07-13 00:09:00+03	24800.00
522DF1	2017-07-27 04:03:00+03	29400.00
522E03	2017-07-22 23:43:00+03	119500.00
522E7C	2017-07-19 20:44:00+03	35200.00
522ED2	2017-07-04 01:18:00+03	28800.00
522EF1	2017-08-01 08:53:00+03	27000.00
522F17	2017-07-05 05:29:00+03	139300.00
522F22	2017-08-15 10:03:00+03	12000.00
522F32	2017-07-22 15:31:00+03	47500.00
522F39	2017-07-30 17:23:00+03	71200.00
522FC8	2017-07-24 18:53:00+03	170200.00
522FE9	2017-07-10 04:03:00+03	18400.00
522FF1	2017-08-02 11:05:00+03	151900.00
52304F	2017-07-20 03:13:00+03	28000.00
523059	2017-08-12 00:22:00+03	61800.00
523060	2017-07-02 16:19:00+03	43200.00
5230B9	2017-07-16 08:48:00+03	60700.00
5230CD	2017-06-28 14:03:00+03	26700.00
52310F	2017-07-10 17:03:00+03	58400.00
52317C	2017-07-31 18:16:00+03	224000.00
52317E	2017-07-06 02:55:00+03	56600.00
5231F2	2017-07-06 00:59:00+03	24400.00
5231F7	2017-07-26 16:46:00+03	26000.00
5231FB	2017-08-08 03:57:00+03	185300.00
52320E	2017-07-18 17:15:00+03	27200.00
523211	2017-08-01 11:01:00+03	13300.00
523220	2017-07-28 02:08:00+03	147700.00
52324A	2017-07-30 09:57:00+03	133100.00
5232EC	2017-07-08 11:08:00+03	26600.00
523304	2017-07-19 07:51:00+03	174500.00
52330E	2017-07-26 05:05:00+03	64700.00
5233DF	2017-07-05 02:39:00+03	147100.00
523402	2017-06-30 17:48:00+03	29600.00
52340A	2017-08-08 11:02:00+03	75600.00
523417	2017-07-14 21:58:00+03	56000.00
52342A	2017-07-27 06:23:00+03	135400.00
523488	2017-08-02 02:39:00+03	52700.00
5234D7	2017-08-15 01:31:00+03	90800.00
5234FD	2017-08-01 10:23:00+03	133100.00
523508	2017-07-11 03:31:00+03	70700.00
523528	2017-07-23 01:54:00+03	56000.00
52354A	2017-07-03 12:41:00+03	135400.00
523557	2017-07-22 14:20:00+03	229900.00
523580	2017-07-29 13:39:00+03	123000.00
5235E1	2017-07-01 01:46:00+03	38600.00
52363C	2017-08-05 03:35:00+03	54500.00
523653	2017-07-07 09:11:00+03	49600.00
5236C1	2017-07-14 21:54:00+03	55800.00
523711	2017-07-27 03:10:00+03	52800.00
52377F	2017-08-05 13:24:00+03	47000.00
523786	2017-07-08 00:40:00+03	67600.00
5237DA	2017-07-04 18:36:00+03	73500.00
523817	2017-07-06 00:36:00+03	132800.00
52389A	2017-07-06 08:45:00+03	47400.00
5238B4	2017-07-16 14:37:00+03	53800.00
5238F1	2017-07-30 17:04:00+03	20800.00
52396B	2017-07-28 09:42:00+03	246000.00
523A0F	2017-08-13 21:28:00+03	134400.00
523A25	2017-08-12 13:06:00+03	76800.00
523A6A	2017-07-10 18:31:00+03	70500.00
523A8B	2017-08-10 04:41:00+03	102100.00
523A94	2017-07-06 15:09:00+03	130300.00
523AF1	2017-08-13 03:12:00+03	44000.00
523B20	2017-07-20 11:15:00+03	73800.00
523BBC	2017-08-10 07:31:00+03	75600.00
523BD6	2017-07-19 11:39:00+03	67600.00
523BF8	2017-07-24 10:46:00+03	28600.00
523BFA	2017-08-13 07:56:00+03	154500.00
523C03	2017-08-15 01:51:00+03	31800.00
523C13	2017-07-28 07:30:00+03	34000.00
523CF6	2017-06-30 15:09:00+03	67900.00
523D1B	2017-07-24 15:56:00+03	15800.00
523D52	2017-07-15 21:51:00+03	64700.00
523E29	2017-08-12 14:35:00+03	149700.00
523E5C	2017-07-07 07:45:00+03	44800.00
523F67	2017-08-07 03:30:00+03	6800.00
523F6C	2017-07-11 01:27:00+03	52000.00
5240BC	2017-08-03 04:48:00+03	144400.00
5240D2	2017-07-20 15:15:00+03	57600.00
524132	2017-08-06 23:19:00+03	26000.00
52413A	2017-07-20 23:49:00+03	56600.00
52415F	2017-07-31 14:31:00+03	55800.00
5242D0	2017-07-30 01:53:00+03	62600.00
5242DF	2017-07-14 08:38:00+03	25200.00
5242E9	2017-08-07 09:36:00+03	55800.00
524373	2017-08-10 22:24:00+03	51800.00
52437A	2017-07-03 00:00:00+03	148100.00
5243CF	2017-08-03 22:10:00+03	71800.00
5243D6	2017-07-12 00:36:00+03	109600.00
5244E0	2017-08-06 08:57:00+03	117200.00
5244E6	2017-07-07 14:31:00+03	54400.00
524541	2017-07-10 14:19:00+03	18600.00
524586	2017-07-24 10:28:00+03	14800.00
5245FA	2017-07-22 12:51:00+03	85700.00
524667	2017-07-08 06:28:00+03	72500.00
52467A	2017-07-10 01:13:00+03	13400.00
5246A8	2017-07-31 06:16:00+03	11800.00
5246CC	2017-06-27 04:25:00+03	16800.00
5246E6	2017-08-04 06:04:00+03	24400.00
524716	2017-08-09 09:09:00+03	12400.00
524754	2017-08-08 07:36:00+03	56000.00
5247C1	2017-08-02 21:18:00+03	21200.00
5247D6	2017-07-08 18:40:00+03	142800.00
5248CC	2017-07-06 00:34:00+03	162400.00
5248DA	2017-08-03 04:44:00+03	12400.00
5248E2	2017-08-03 16:08:00+03	12000.00
5248E5	2017-07-19 03:16:00+03	25200.00
524968	2017-07-16 11:39:00+03	65300.00
5249BB	2017-07-22 17:38:00+03	55800.00
5249F5	2017-07-06 07:28:00+03	399600.00
524A87	2017-07-02 05:55:00+03	39300.00
524A93	2017-07-10 04:33:00+03	260900.00
524A9D	2017-07-23 06:42:00+03	39500.00
524AAC	2017-07-16 12:14:00+03	92900.00
524AD1	2017-08-01 15:09:00+03	515100.00
524AF6	2017-07-03 13:16:00+03	62600.00
524B1E	2017-07-13 02:17:00+03	39300.00
524B7C	2017-08-12 14:47:00+03	32400.00
524B87	2017-08-10 19:05:00+03	101200.00
524BD2	2017-07-28 12:55:00+03	40400.00
524C30	2017-08-04 20:39:00+03	67200.00
524C71	2017-07-16 01:39:00+03	75600.00
524C76	2017-07-26 07:12:00+03	521900.00
524D2D	2017-08-02 19:23:00+03	88300.00
524D92	2017-08-03 09:56:00+03	67600.00
524E84	2017-08-10 15:02:00+03	75600.00
524E97	2017-07-12 10:20:00+03	93900.00
524E99	2017-06-25 16:59:00+03	172100.00
524EF7	2017-08-15 04:27:00+03	124200.00
524F0A	2017-08-01 21:02:00+03	47100.00
524F39	2017-07-24 03:55:00+03	47000.00
524F55	2017-07-25 19:00:00+03	38800.00
524F56	2017-08-01 21:30:00+03	41200.00
524F77	2017-07-16 13:29:00+03	100200.00
52507D	2017-07-07 13:38:00+03	28800.00
525090	2017-07-07 02:15:00+03	47000.00
525124	2017-07-03 23:15:00+03	34000.00
52513A	2017-07-26 10:06:00+03	55800.00
525160	2017-07-11 13:06:00+03	81600.00
5251CF	2017-07-20 19:31:00+03	40600.00
5251FD	2017-08-07 16:58:00+03	59200.00
52523C	2017-08-11 14:01:00+03	73600.00
52532D	2017-08-07 21:50:00+03	25200.00
525335	2017-07-26 18:05:00+03	61100.00
52534A	2017-07-24 08:13:00+03	56000.00
525399	2017-07-16 16:32:00+03	81600.00
5253C8	2017-07-07 12:24:00+03	28800.00
5253FF	2017-08-04 05:55:00+03	83000.00
525434	2017-07-08 13:51:00+03	224000.00
525443	2017-07-06 20:49:00+03	38800.00
52546B	2017-07-16 10:19:00+03	23200.00
52546C	2017-08-14 22:49:00+03	15000.00
525570	2017-07-29 08:23:00+03	42800.00
52557D	2017-07-03 20:52:00+03	86500.00
525596	2017-08-03 17:44:00+03	68400.00
525621	2017-07-13 14:02:00+03	20100.00
525663	2017-07-29 10:03:00+03	94300.00
5257EE	2017-07-21 17:42:00+03	110300.00
5257F3	2017-07-11 03:20:00+03	44800.00
5258E6	2017-07-06 10:18:00+03	40000.00
5258F2	2017-07-19 07:29:00+03	6800.00
52592B	2017-07-08 08:16:00+03	28000.00
525968	2017-07-28 09:57:00+03	205400.00
5259C4	2017-08-13 22:47:00+03	62600.00
5259E5	2017-07-18 07:57:00+03	43400.00
525A0F	2017-07-27 03:17:00+03	123000.00
525A2B	2017-07-28 10:09:00+03	78000.00
525A43	2017-07-14 02:24:00+03	33800.00
525B10	2017-06-28 20:15:00+03	48700.00
525B41	2017-07-14 04:30:00+03	177200.00
525B57	2017-07-21 00:31:00+03	105100.00
525BEC	2017-07-07 04:26:00+03	211100.00
525C19	2017-07-10 14:08:00+03	62900.00
525C1C	2017-08-14 14:28:00+03	23600.00
525C52	2017-07-06 15:21:00+03	31400.00
525C71	2017-07-30 05:45:00+03	94800.00
525D09	2017-08-13 07:56:00+03	6700.00
525D14	2017-07-09 06:32:00+03	27800.00
525D54	2017-08-04 07:31:00+03	52800.00
525D73	2017-07-25 01:23:00+03	104900.00
525E5E	2017-08-04 05:20:00+03	50800.00
525E5F	2017-08-14 02:31:00+03	26200.00
525E67	2017-07-31 09:43:00+03	40400.00
525EC9	2017-08-08 08:07:00+03	49600.00
525ECC	2017-07-03 15:57:00+03	75300.00
525ECD	2017-08-08 09:50:00+03	99700.00
525ED5	2017-07-06 06:58:00+03	117800.00
525EFB	2017-07-13 04:49:00+03	109600.00
525F16	2017-08-12 10:55:00+03	75300.00
525F1D	2017-07-25 05:53:00+03	29600.00
525F35	2017-07-27 14:40:00+03	52000.00
525F5F	2017-08-15 06:59:00+03	136200.00
525F62	2017-07-19 05:07:00+03	150500.00
525F78	2017-08-11 11:03:00+03	35300.00
525F8B	2017-08-12 21:09:00+03	34000.00
525FA6	2017-08-10 15:18:00+03	246000.00
525FB1	2017-07-18 13:24:00+03	46000.00
525FD7	2017-08-13 13:50:00+03	61800.00
52605C	2017-07-29 04:20:00+03	18800.00
526082	2017-08-14 14:24:00+03	59300.00
526123	2017-07-07 19:13:00+03	46300.00
5261A1	2017-07-13 13:26:00+03	44500.00
5261B5	2017-07-10 17:36:00+03	71000.00
5261CE	2017-07-04 09:37:00+03	7200.00
526201	2017-07-15 02:21:00+03	20200.00
526215	2017-07-08 06:50:00+03	13400.00
5262D6	2017-07-16 10:19:00+03	34000.00
5262D8	2017-08-03 09:04:00+03	37800.00
526396	2017-08-02 19:56:00+03	296300.00
5263C9	2017-08-01 23:51:00+03	31000.00
5263D8	2017-07-12 14:35:00+03	47200.00
526463	2017-08-13 21:21:00+03	247300.00
5264DC	2017-08-14 04:49:00+03	85000.00
526524	2017-07-12 16:10:00+03	155600.00
526548	2017-07-28 10:43:00+03	13400.00
52654C	2017-08-04 04:37:00+03	143100.00
52660A	2017-07-21 17:17:00+03	99300.00
526702	2017-07-07 22:11:00+03	28000.00
52677B	2017-08-10 18:00:00+03	154800.00
5267A2	2017-07-03 21:41:00+03	105100.00
5267E7	2017-08-07 06:46:00+03	39300.00
526805	2017-07-21 19:01:00+03	112100.00
526820	2017-07-24 12:53:00+03	40600.00
526838	2017-07-19 12:59:00+03	265700.00
52684D	2017-07-07 16:19:00+03	77600.00
52688C	2017-07-22 02:53:00+03	125200.00
52688E	2017-07-26 13:09:00+03	28800.00
5268A2	2017-07-26 16:37:00+03	6000.00
52692B	2017-07-03 12:20:00+03	122300.00
526940	2017-07-13 17:30:00+03	44800.00
52695A	2017-07-25 02:42:00+03	60400.00
526968	2017-08-01 18:24:00+03	83600.00
52699D	2017-07-07 01:15:00+03	135400.00
526A36	2017-08-14 10:05:00+03	45200.00
526AAF	2017-08-11 13:33:00+03	25600.00
526B4C	2017-07-21 23:08:00+03	16400.00
526BB9	2017-08-15 12:42:00+03	21400.00
526BBB	2017-07-29 02:20:00+03	124100.00
526BE2	2017-08-04 00:20:00+03	46400.00
526BFC	2017-07-21 17:23:00+03	26800.00
526C8C	2017-07-16 04:17:00+03	124200.00
526C97	2017-07-09 02:56:00+03	156000.00
526CC9	2017-07-08 05:33:00+03	47600.00
526CE4	2017-08-07 13:23:00+03	54700.00
526CF8	2017-07-10 11:29:00+03	31400.00
526D5F	2017-08-06 19:53:00+03	6700.00
526D9F	2017-07-24 13:13:00+03	10800.00
526DA2	2017-08-09 13:15:00+03	16400.00
526DBD	2017-07-28 09:48:00+03	30200.00
526E68	2017-07-05 22:33:00+03	30000.00
526E98	2017-08-08 02:07:00+03	112000.00
526EB6	2017-08-07 11:26:00+03	27900.00
526EBD	2017-07-09 04:00:00+03	47400.00
526EBE	2017-08-09 08:47:00+03	101200.00
526EFB	2017-08-02 12:14:00+03	32800.00
526FCD	2017-07-24 07:30:00+03	63200.00
52708E	2017-08-01 19:10:00+03	40000.00
5270A0	2017-07-30 15:02:00+03	68800.00
5270B0	2017-07-26 10:47:00+03	283100.00
52711D	2017-08-03 00:02:00+03	52700.00
5271D0	2017-08-08 03:27:00+03	82900.00
5271F8	2017-08-15 01:50:00+03	62300.00
527214	2017-08-13 20:41:00+03	108400.00
5272E8	2017-07-28 11:12:00+03	139800.00
5272EA	2017-07-19 23:35:00+03	124200.00
527316	2017-07-04 08:10:00+03	35600.00
527325	2017-08-05 23:57:00+03	31600.00
52732C	2017-07-29 17:55:00+03	21600.00
52734B	2017-08-09 06:42:00+03	39500.00
52736B	2017-07-30 20:13:00+03	28000.00
5273E4	2017-07-25 21:07:00+03	46300.00
527413	2017-08-01 08:15:00+03	32200.00
527420	2017-07-25 03:05:00+03	87000.00
527450	2017-08-07 21:20:00+03	21500.00
527477	2017-07-03 08:52:00+03	52100.00
5274A6	2017-07-15 12:30:00+03	234300.00
5274F0	2017-07-15 03:58:00+03	169900.00
52750E	2017-08-06 08:53:00+03	32700.00
527533	2017-07-11 17:20:00+03	34000.00
527550	2017-07-16 13:18:00+03	67200.00
5275CE	2017-08-09 13:04:00+03	39400.00
5275D7	2017-08-13 00:01:00+03	29400.00
527634	2017-08-01 16:52:00+03	163200.00
527645	2017-08-08 16:28:00+03	34600.00
52764C	2017-08-03 04:25:00+03	7200.00
52767C	2017-07-12 13:58:00+03	265800.00
5276F2	2017-07-15 07:03:00+03	103500.00
527707	2017-07-09 21:58:00+03	29600.00
527731	2017-07-29 13:48:00+03	133700.00
52778B	2017-07-07 17:31:00+03	194800.00
5277B2	2017-07-16 02:19:00+03	46400.00
5277FE	2017-07-15 02:49:00+03	38600.00
52781E	2017-07-17 12:24:00+03	75200.00
52783A	2017-07-22 16:02:00+03	55800.00
52784D	2017-07-03 02:49:00+03	113600.00
527874	2017-08-11 09:19:00+03	95600.00
527888	2017-08-13 17:16:00+03	58100.00
5278B2	2017-07-23 18:04:00+03	108000.00
5278F2	2017-07-23 14:42:00+03	57400.00
5279ED	2017-07-04 11:50:00+03	24700.00
5279FE	2017-08-01 21:58:00+03	70700.00
527A3D	2017-07-09 12:49:00+03	7400.00
527A65	2017-08-06 09:26:00+03	112600.00
527A9D	2017-08-07 23:43:00+03	25400.00
527AA7	2017-08-10 04:08:00+03	84100.00
527B21	2017-07-09 02:09:00+03	136200.00
527B3B	2017-07-19 01:37:00+03	58600.00
527B64	2017-07-19 02:59:00+03	25200.00
527B7C	2017-07-10 13:18:00+03	28000.00
527B97	2017-07-24 23:34:00+03	50200.00
527BBF	2017-08-10 03:35:00+03	28800.00
527BFB	2017-06-27 01:28:00+03	69600.00
527C5E	2017-07-11 19:02:00+03	43600.00
527C64	2017-08-08 12:50:00+03	177200.00
527CC9	2017-08-13 10:26:00+03	468000.00
527D1F	2017-07-27 17:49:00+03	84500.00
527D74	2017-07-18 01:50:00+03	23200.00
527D81	2017-07-25 21:34:00+03	46000.00
527D9E	2017-08-03 18:47:00+03	92800.00
527E1A	2017-07-10 18:59:00+03	124000.00
527E3F	2017-07-20 15:40:00+03	65600.00
527E5A	2017-07-13 16:35:00+03	50300.00
527E74	2017-07-25 05:27:00+03	69600.00
527EDB	2017-08-09 20:18:00+03	66000.00
527F15	2017-08-11 18:06:00+03	36200.00
527F44	2017-08-15 13:00:00+03	408500.00
527FB0	2017-07-30 22:20:00+03	67400.00
527FC8	2017-07-22 15:57:00+03	243600.00
527FF6	2017-07-27 06:50:00+03	153300.00
528006	2017-08-10 03:22:00+03	37600.00
528040	2017-07-21 16:50:00+03	31600.00
52804A	2017-07-31 13:23:00+03	156400.00
528069	2017-08-07 13:49:00+03	68800.00
5280AE	2017-07-25 07:18:00+03	27000.00
528101	2017-07-13 15:16:00+03	63600.00
52811B	2017-07-28 16:04:00+03	133100.00
528158	2017-07-04 02:06:00+03	25200.00
52815A	2017-08-09 04:37:00+03	10600.00
5281BA	2017-07-25 00:51:00+03	56100.00
5281E4	2017-07-15 04:17:00+03	112000.00
5281FA	2017-07-18 13:08:00+03	65900.00
52828B	2017-07-23 19:56:00+03	56600.00
52829B	2017-06-30 02:13:00+03	92800.00
5282D3	2017-08-03 03:32:00+03	18800.00
5282EF	2017-08-12 16:51:00+03	189500.00
52832A	2017-07-10 09:07:00+03	6400.00
52833B	2017-07-15 04:33:00+03	111000.00
5283A2	2017-07-30 14:26:00+03	56000.00
5283BF	2017-07-04 18:38:00+03	226200.00
528491	2017-07-12 05:03:00+03	85300.00
5284B0	2017-08-03 12:09:00+03	186900.00
5284C0	2017-07-24 11:46:00+03	187400.00
5284D0	2017-08-02 13:43:00+03	155600.00
5284FF	2017-08-07 03:02:00+03	123000.00
52850E	2017-07-24 19:26:00+03	55800.00
528534	2017-07-04 10:55:00+03	103500.00
52853E	2017-08-02 01:22:00+03	177200.00
528541	2017-07-28 16:01:00+03	51600.00
52856B	2017-08-01 13:22:00+03	38600.00
528571	2017-07-30 09:24:00+03	42600.00
5285BA	2017-08-05 13:43:00+03	57600.00
5286CA	2017-08-02 17:03:00+03	28900.00
5286E6	2017-07-11 04:08:00+03	50600.00
528799	2017-08-14 17:52:00+03	133600.00
528858	2017-07-04 08:49:00+03	26000.00
528896	2017-08-13 18:37:00+03	123700.00
5288A8	2017-07-08 10:08:00+03	219900.00
52892F	2017-07-13 06:46:00+03	10600.00
52897B	2017-08-04 09:11:00+03	22600.00
528A39	2017-07-02 02:51:00+03	55800.00
528A97	2017-07-24 18:00:00+03	133200.00
528A9B	2017-07-26 14:00:00+03	56000.00
528AA2	2017-07-24 11:27:00+03	16400.00
528AA8	2017-08-15 03:30:00+03	26000.00
528B0A	2017-07-06 16:35:00+03	265600.00
528C39	2017-07-05 13:44:00+03	40000.00
528C49	2017-08-04 16:50:00+03	44800.00
528C61	2017-08-04 13:31:00+03	85000.00
528CE2	2017-07-08 06:33:00+03	26700.00
528D8F	2017-06-28 15:17:00+03	40800.00
528DF7	2017-07-02 13:58:00+03	40800.00
528E4C	2017-08-05 05:25:00+03	80300.00
528E83	2017-07-03 08:18:00+03	55700.00
528E9E	2017-07-07 21:44:00+03	113200.00
528EF6	2017-08-15 00:55:00+03	13000.00
528F4D	2017-07-21 12:16:00+03	112000.00
528F84	2017-08-15 10:06:00+03	318300.00
528F95	2017-07-13 17:12:00+03	57800.00
528F9B	2017-07-03 04:19:00+03	57600.00
528FD3	2017-07-31 13:54:00+03	26000.00
52902F	2017-07-05 14:31:00+03	30700.00
529072	2017-07-16 01:02:00+03	69500.00
5290C4	2017-08-06 20:09:00+03	67200.00
529120	2017-07-19 00:12:00+03	159200.00
52915C	2017-07-23 12:06:00+03	58900.00
52918F	2017-08-08 05:36:00+03	115000.00
5291A1	2017-07-24 10:20:00+03	100700.00
5291E3	2017-07-18 05:44:00+03	33600.00
52926B	2017-08-06 03:40:00+03	24400.00
5292C7	2017-08-13 01:29:00+03	78200.00
5292C8	2017-07-17 15:55:00+03	110000.00
5292D2	2017-07-27 11:46:00+03	112600.00
5292F3	2017-08-12 12:40:00+03	193100.00
5292F5	2017-08-02 06:04:00+03	51200.00
529365	2017-07-03 05:06:00+03	97900.00
5293D0	2017-07-29 12:32:00+03	31600.00
52941C	2017-07-16 04:23:00+03	73600.00
529484	2017-07-05 11:32:00+03	35600.00
529497	2017-08-09 18:21:00+03	14000.00
5294DC	2017-08-04 17:35:00+03	68000.00
529591	2017-08-04 13:34:00+03	142800.00
5295A9	2017-07-13 17:10:00+03	46500.00
5295E7	2017-08-12 04:58:00+03	37900.00
529617	2017-07-28 19:21:00+03	43000.00
529644	2017-07-29 15:53:00+03	169000.00
52964B	2017-07-21 13:15:00+03	6000.00
529660	2017-07-10 20:30:00+03	184300.00
529680	2017-08-03 20:10:00+03	56000.00
529820	2017-07-20 07:28:00+03	58000.00
52982F	2017-07-09 14:11:00+03	133200.00
529863	2017-08-08 14:11:00+03	75300.00
5298B3	2017-07-03 14:12:00+03	10800.00
529945	2017-06-27 08:34:00+03	73500.00
529965	2017-07-27 12:01:00+03	151800.00
5299AC	2017-07-29 06:02:00+03	56600.00
5299CE	2017-08-11 18:13:00+03	39300.00
5299EB	2017-07-30 11:24:00+03	43100.00
529A41	2017-08-07 13:08:00+03	231900.00
529AF7	2017-07-24 18:39:00+03	67100.00
529AFB	2017-07-31 04:38:00+03	84000.00
529B8E	2017-07-14 22:05:00+03	64000.00
529BC7	2017-07-07 00:28:00+03	59900.00
529BCF	2017-08-12 13:28:00+03	24400.00
529BDC	2017-07-21 14:47:00+03	32400.00
529C61	2017-07-27 11:46:00+03	86800.00
529CE6	2017-08-02 07:04:00+03	28000.00
529D3D	2017-07-09 00:13:00+03	40800.00
529D50	2017-07-21 16:15:00+03	17200.00
529D9A	2017-07-15 07:32:00+03	31100.00
529DA5	2017-08-14 02:05:00+03	14400.00
529DA6	2017-07-23 21:40:00+03	23200.00
529DBD	2017-07-02 19:18:00+03	48700.00
529DDD	2017-07-04 15:18:00+03	56000.00
529E6D	2017-06-30 13:01:00+03	32700.00
529E70	2017-07-06 05:45:00+03	113200.00
529EFF	2017-07-15 23:39:00+03	97900.00
529F22	2017-07-20 14:34:00+03	56600.00
529F40	2017-07-20 16:27:00+03	77600.00
529F9A	2017-07-13 02:36:00+03	131100.00
529FA8	2017-07-23 18:14:00+03	55800.00
529FB8	2017-07-16 04:09:00+03	115300.00
52A008	2017-07-26 16:06:00+03	198400.00
52A037	2017-07-22 11:56:00+03	41400.00
52A03B	2017-07-08 00:58:00+03	23100.00
52A064	2017-08-12 08:01:00+03	73400.00
52A117	2017-07-06 09:02:00+03	99200.00
52A146	2017-07-07 03:48:00+03	29600.00
52A15D	2017-07-22 19:15:00+03	111600.00
52A24A	2017-08-15 14:09:00+03	58000.00
52A2C3	2017-07-19 21:00:00+03	542200.00
52A2DA	2017-07-21 11:18:00+03	28000.00
52A380	2017-07-20 09:13:00+03	18900.00
52A3C8	2017-08-14 08:01:00+03	147700.00
52A436	2017-07-06 14:20:00+03	156600.00
52A437	2017-07-20 18:24:00+03	12000.00
52A47A	2017-07-02 17:06:00+03	116700.00
52A48D	2017-07-15 02:39:00+03	31800.00
52A4BE	2017-07-07 04:03:00+03	88500.00
52A4DB	2017-08-08 19:41:00+03	99300.00
52A4E9	2017-08-10 14:17:00+03	12400.00
52A562	2017-08-02 06:02:00+03	102800.00
52A579	2017-08-07 11:13:00+03	39800.00
52A5A6	2017-07-07 21:55:00+03	273400.00
52A5BD	2017-08-06 06:49:00+03	57500.00
52A5C0	2017-08-13 15:27:00+03	60500.00
52A5C5	2017-07-04 19:14:00+03	13800.00
52A5FB	2017-07-10 03:30:00+03	144700.00
52A645	2017-07-02 10:43:00+03	35800.00
52A66E	2017-08-14 18:30:00+03	93800.00
52A678	2017-08-12 00:47:00+03	62600.00
52A826	2017-07-03 15:51:00+03	21800.00
52A855	2017-08-12 22:38:00+03	18000.00
52A85B	2017-07-12 07:25:00+03	260900.00
52A891	2017-08-07 02:42:00+03	79200.00
52A926	2017-07-23 04:28:00+03	9800.00
52A940	2017-07-12 14:41:00+03	77900.00
52A9A8	2017-07-27 20:52:00+03	31100.00
52A9CC	2017-07-17 08:10:00+03	14000.00
52A9D1	2017-07-30 03:42:00+03	23200.00
52A9F7	2017-07-26 07:59:00+03	6700.00
52AA4E	2017-08-08 23:34:00+03	26000.00
52AA62	2017-07-19 03:59:00+03	55800.00
52AA7F	2017-07-11 17:34:00+03	23200.00
52AAA0	2017-08-04 00:03:00+03	40800.00
52AAB5	2017-07-11 09:04:00+03	67900.00
52AAD3	2017-07-16 06:33:00+03	246000.00
52AB19	2017-08-06 16:35:00+03	27000.00
52AB9F	2017-07-17 19:14:00+03	104000.00
52AC18	2017-07-31 17:50:00+03	73200.00
52AC3E	2017-07-18 05:15:00+03	398500.00
52AC7D	2017-07-05 13:52:00+03	6300.00
52AC9C	2017-06-29 20:42:00+03	12600.00
52ACAD	2017-08-09 20:04:00+03	51900.00
52AD64	2017-07-10 19:43:00+03	393600.00
52AD7A	2017-07-26 06:48:00+03	106400.00
52ADFF	2017-08-03 02:29:00+03	67400.00
52AE31	2017-07-02 19:46:00+03	153100.00
52AE67	2017-07-11 02:45:00+03	40200.00
52AE86	2017-08-12 14:40:00+03	40600.00
52AEB3	2017-07-07 11:47:00+03	23600.00
52AF3F	2017-07-20 11:11:00+03	14000.00
52AF59	2017-07-21 16:04:00+03	22000.00
52B033	2017-07-05 17:54:00+03	14000.00
52B06E	2017-07-21 07:30:00+03	47900.00
52B09A	2017-07-04 22:46:00+03	56000.00
52B0B0	2017-07-18 05:51:00+03	30200.00
52B112	2017-07-22 02:37:00+03	113300.00
52B11C	2017-07-08 20:00:00+03	24400.00
52B1DE	2017-08-02 13:58:00+03	62700.00
52B260	2017-07-17 11:08:00+03	25000.00
52B26E	2017-07-09 16:05:00+03	33100.00
52B294	2017-08-13 12:21:00+03	87700.00
52B2D7	2017-07-01 17:46:00+03	265700.00
52B2F7	2017-08-09 00:21:00+03	240500.00
52B316	2017-07-18 07:11:00+03	9800.00
52B319	2017-07-20 03:33:00+03	28000.00
52B31D	2017-07-03 04:56:00+03	73500.00
52B32B	2017-07-09 10:22:00+03	31600.00
52B345	2017-07-12 19:53:00+03	27200.00
52B368	2017-08-13 17:05:00+03	272400.00
52B373	2017-07-17 05:33:00+03	103500.00
52B3EC	2017-07-28 02:26:00+03	13600.00
52B3EF	2017-07-23 00:03:00+03	28000.00
52B3F9	2017-08-13 19:09:00+03	147700.00
52B503	2017-07-31 11:51:00+03	56000.00
52B567	2017-08-15 13:52:00+03	65600.00
52B57C	2017-08-05 03:08:00+03	101100.00
52B607	2017-08-11 04:32:00+03	39200.00
52B665	2017-07-18 23:38:00+03	46800.00
52B66D	2017-07-22 03:11:00+03	6000.00
52B67F	2017-07-06 11:09:00+03	21800.00
52B6A8	2017-07-05 06:40:00+03	40000.00
52B6C9	2017-07-11 02:07:00+03	49100.00
52B6F2	2017-08-05 03:12:00+03	36400.00
52B6F8	2017-07-13 04:09:00+03	14000.00
52B700	2017-08-07 19:46:00+03	14000.00
52B740	2017-08-14 13:12:00+03	56100.00
52B86A	2017-07-08 17:02:00+03	19600.00
52B91C	2017-08-12 11:02:00+03	260300.00
52B93A	2017-07-07 04:25:00+03	54800.00
52B941	2017-07-04 08:06:00+03	10600.00
52B94A	2017-08-07 23:57:00+03	49000.00
52B975	2017-07-23 21:17:00+03	11700.00
52BA6C	2017-07-03 07:10:00+03	65900.00
52BA87	2017-07-17 02:35:00+03	38800.00
52BB15	2017-08-12 00:20:00+03	73900.00
52BB29	2017-07-11 14:39:00+03	29200.00
52BB9B	2017-06-28 22:56:00+03	17200.00
52BBD2	2017-07-31 23:54:00+03	35600.00
52BC44	2017-07-21 12:44:00+03	112600.00
52BC5B	2017-07-14 06:03:00+03	99600.00
52BC93	2017-08-14 09:47:00+03	184300.00
52BCD8	2017-08-13 10:18:00+03	84000.00
52BDE8	2017-07-16 22:29:00+03	123900.00
52BE55	2017-07-01 08:58:00+03	75800.00
52BE95	2017-07-04 09:09:00+03	66800.00
52BEBC	2017-08-14 07:10:00+03	23600.00
52BEDF	2017-07-23 16:14:00+03	24400.00
52BF13	2017-07-25 00:00:00+03	492000.00
52BF57	2017-08-03 05:47:00+03	43700.00
52BF97	2017-07-05 00:23:00+03	46300.00
52BFDF	2017-08-01 00:46:00+03	29800.00
52C053	2017-07-13 06:01:00+03	26000.00
52C09A	2017-07-30 08:19:00+03	46000.00
52C0D1	2017-07-09 19:59:00+03	23200.00
52C118	2017-07-21 04:30:00+03	135200.00
52C13D	2017-07-17 00:55:00+03	111600.00
52C174	2017-07-14 14:46:00+03	118300.00
52C179	2017-08-01 04:57:00+03	29400.00
52C199	2017-07-12 22:09:00+03	16400.00
52C1A2	2017-07-20 09:15:00+03	23600.00
52C1F0	2017-08-15 05:08:00+03	266300.00
52C22C	2017-07-21 17:05:00+03	55600.00
52C274	2017-08-11 20:18:00+03	7800.00
52C275	2017-08-07 13:18:00+03	41200.00
52C279	2017-08-12 20:16:00+03	31800.00
52C29E	2017-08-09 20:40:00+03	77200.00
52C2C7	2017-07-26 03:52:00+03	23600.00
52C34F	2017-07-30 13:59:00+03	84500.00
52C3D3	2017-08-13 22:04:00+03	78800.00
52C3F8	2017-07-27 23:18:00+03	13400.00
52C4BA	2017-07-29 20:18:00+03	66000.00
52C4D8	2017-08-05 02:24:00+03	29600.00
52C4EB	2017-07-13 03:11:00+03	27300.00
52C512	2017-07-05 03:13:00+03	173600.00
52C550	2017-07-27 02:13:00+03	28800.00
52C57F	2017-07-11 00:22:00+03	6000.00
52C5A9	2017-08-14 19:57:00+03	54800.00
52C5AA	2017-07-19 11:10:00+03	21600.00
52C5F5	2017-07-29 02:26:00+03	22000.00
52C63D	2017-08-14 16:52:00+03	15600.00
52C6AD	2017-08-12 03:44:00+03	45200.00
52C760	2017-08-01 09:36:00+03	26800.00
52C777	2017-07-07 20:42:00+03	435200.00
52C79B	2017-07-26 08:53:00+03	57600.00
52C7A9	2017-08-11 12:20:00+03	6700.00
52C7C2	2017-07-12 21:03:00+03	137800.00
52C7C6	2017-07-02 15:50:00+03	28800.00
52C7D8	2017-08-11 12:25:00+03	46200.00
52C7F4	2017-08-07 14:09:00+03	24200.00
52C7F6	2017-06-24 21:48:00+03	123000.00
52C81D	2017-07-04 19:49:00+03	66000.00
52C839	2017-07-16 10:41:00+03	30900.00
52C866	2017-08-03 10:38:00+03	56000.00
52C870	2017-07-15 05:11:00+03	52300.00
52C89D	2017-07-24 11:00:00+03	34400.00
52C8B2	2017-08-12 10:40:00+03	45200.00
52C8C6	2017-07-01 23:37:00+03	169000.00
52C8E0	2017-07-16 05:53:00+03	43600.00
52C990	2017-06-30 20:17:00+03	88600.00
52C9B6	2017-07-14 01:18:00+03	34000.00
52CA3A	2017-07-25 11:02:00+03	118900.00
52CA6F	2017-08-06 21:27:00+03	40800.00
52CABC	2017-07-07 02:03:00+03	23200.00
52CAE4	2017-07-09 19:21:00+03	35200.00
52CB24	2017-07-08 14:54:00+03	146700.00
52CB57	2017-08-15 14:33:00+03	36000.00
52CBAB	2017-08-06 11:57:00+03	32800.00
52CBC5	2017-07-07 18:50:00+03	114800.00
52CC0E	2017-08-08 06:58:00+03	87900.00
52CC15	2017-08-08 02:25:00+03	44000.00
52CC29	2017-08-05 10:23:00+03	74800.00
52CC48	2017-07-27 07:52:00+03	399600.00
52CCA3	2017-07-25 03:00:00+03	13400.00
52CCA8	2017-07-12 13:01:00+03	57600.00
52CD50	2017-08-07 21:10:00+03	31800.00
52CD80	2017-08-05 11:00:00+03	167400.00
52CDEB	2017-08-07 11:29:00+03	216400.00
52CDFA	2017-08-15 13:00:00+03	66600.00
52CE12	2017-06-28 09:38:00+03	137100.00
52CE4F	2017-08-01 03:18:00+03	129400.00
52CE64	2017-07-13 16:54:00+03	36900.00
52CEBF	2017-08-04 23:16:00+03	86300.00
52CECD	2017-07-06 17:54:00+03	34000.00
52CED5	2017-08-08 17:32:00+03	49500.00
52CEDE	2017-07-29 17:45:00+03	22000.00
52CEF0	2017-07-17 22:17:00+03	123600.00
52CF3E	2017-07-26 02:51:00+03	41800.00
52CFBA	2017-07-28 17:12:00+03	69600.00
52CFC5	2017-07-01 09:12:00+03	14400.00
52CFD1	2017-07-04 15:46:00+03	32700.00
52CFE8	2017-06-27 02:32:00+03	54800.00
52D001	2017-08-01 03:28:00+03	189800.00
52D014	2017-07-05 10:59:00+03	62700.00
52D08A	2017-07-28 11:20:00+03	80800.00
52D0B3	2017-08-09 08:02:00+03	55800.00
52D0B6	2017-07-28 16:29:00+03	24000.00
52D0FF	2017-07-18 20:08:00+03	28000.00
52D18C	2017-07-28 04:15:00+03	99300.00
52D2B7	2017-07-10 21:39:00+03	34000.00
52D2C0	2017-07-29 21:18:00+03	23200.00
52D2DB	2017-07-09 07:29:00+03	233800.00
52D2ED	2017-08-04 10:37:00+03	27300.00
52D305	2017-08-10 19:22:00+03	27800.00
52D3F4	2017-07-21 05:36:00+03	99300.00
52D41B	2017-07-04 23:19:00+03	260900.00
52D41C	2017-06-28 19:20:00+03	56600.00
52D421	2017-08-07 08:20:00+03	135600.00
52D428	2017-07-09 20:07:00+03	36200.00
52D43D	2017-07-30 16:56:00+03	46000.00
52D477	2017-07-16 09:10:00+03	16000.00
52D4E1	2017-07-09 07:43:00+03	136500.00
52D51B	2017-07-11 07:21:00+03	56000.00
52D57F	2017-08-01 09:47:00+03	19000.00
52D5A2	2017-07-30 14:20:00+03	135400.00
52D5EE	2017-07-21 06:06:00+03	36200.00
52D603	2017-07-18 13:18:00+03	28000.00
52D649	2017-08-14 11:53:00+03	265700.00
52D653	2017-07-29 16:57:00+03	116700.00
52D67B	2017-07-09 04:17:00+03	65200.00
52D690	2017-07-30 12:25:00+03	75300.00
52D734	2017-07-16 03:10:00+03	86500.00
52D73C	2017-07-01 09:33:00+03	58800.00
52D763	2017-07-23 03:59:00+03	68800.00
52D765	2017-07-13 06:42:00+03	23400.00
52D7A4	2017-08-07 10:46:00+03	92900.00
52D7AC	2017-07-03 12:42:00+03	310500.00
52D836	2017-07-21 13:54:00+03	94000.00
52D83C	2017-06-29 11:06:00+03	36600.00
52D883	2017-07-16 09:45:00+03	14700.00
52D8B7	2017-07-16 05:26:00+03	63500.00
52D8C7	2017-08-15 01:06:00+03	40000.00
52D8E1	2017-07-17 20:20:00+03	31900.00
52D8E5	2017-08-09 16:28:00+03	87100.00
52D8FC	2017-07-28 07:02:00+03	114500.00
52D939	2017-08-09 09:18:00+03	158500.00
52D960	2017-08-04 12:50:00+03	189200.00
52D9BD	2017-07-12 21:50:00+03	24700.00
52D9D0	2017-07-10 05:04:00+03	66200.00
52D9EF	2017-07-25 11:58:00+03	56100.00
52DA21	2017-08-05 04:20:00+03	115800.00
52DA2D	2017-07-01 14:55:00+03	95600.00
52DA7A	2017-07-16 12:42:00+03	46500.00
52DACC	2017-07-19 09:37:00+03	26800.00
52DAD2	2017-07-17 04:55:00+03	90600.00
52DADF	2017-08-07 03:45:00+03	266400.00
52DB14	2017-07-19 16:27:00+03	100600.00
52DB40	2017-08-10 00:24:00+03	63700.00
52DB80	2017-07-20 01:03:00+03	174600.00
52DB86	2017-07-19 11:46:00+03	67600.00
52DC02	2017-07-20 19:27:00+03	8200.00
52DC0C	2017-07-04 10:57:00+03	94000.00
52DC4C	2017-08-14 06:33:00+03	16400.00
52DC6E	2017-07-04 07:32:00+03	47200.00
52DC9E	2017-07-18 23:43:00+03	123000.00
52DCEF	2017-06-30 08:49:00+03	6700.00
52DD3E	2017-07-06 01:18:00+03	175700.00
52DD51	2017-07-17 13:21:00+03	111600.00
52DDD1	2017-07-08 19:35:00+03	46000.00
52DDF9	2017-07-25 16:53:00+03	270700.00
52DE24	2017-07-03 19:28:00+03	23600.00
52DE2C	2017-07-12 17:17:00+03	63600.00
52DE30	2017-07-27 13:20:00+03	101900.00
52DE63	2017-07-17 07:36:00+03	16800.00
52DF38	2017-07-25 02:06:00+03	31400.00
52DF40	2017-07-08 04:10:00+03	28000.00
52DF73	2017-07-25 15:32:00+03	15000.00
52DFA4	2017-08-02 00:38:00+03	70700.00
52DFC3	2017-08-13 01:29:00+03	187600.00
52E036	2017-07-06 07:03:00+03	70200.00
52E05C	2017-07-10 14:05:00+03	58600.00
52E08D	2017-08-01 16:35:00+03	8400.00
52E0B6	2017-07-29 14:25:00+03	46700.00
52E0F2	2017-08-03 04:15:00+03	26800.00
52E12B	2017-08-08 00:55:00+03	40800.00
52E19E	2017-08-12 20:34:00+03	126800.00
52E1E4	2017-08-01 17:47:00+03	31400.00
52E226	2017-08-01 04:46:00+03	56100.00
52E25A	2017-07-10 05:07:00+03	179400.00
52E290	2017-07-24 04:10:00+03	38600.00
52E2E0	2017-07-25 01:50:00+03	50000.00
52E354	2017-07-20 08:23:00+03	105000.00
52E36A	2017-07-21 15:04:00+03	13600.00
52E36B	2017-07-28 10:48:00+03	133100.00
52E36C	2017-08-06 08:39:00+03	102300.00
52E39E	2017-08-09 12:56:00+03	168000.00
52E3D2	2017-07-10 22:32:00+03	46000.00
52E413	2017-08-12 07:19:00+03	59200.00
52E492	2017-07-19 12:04:00+03	46200.00
52E4B2	2017-07-22 00:11:00+03	46400.00
52E51E	2017-07-04 18:06:00+03	111600.00
52E533	2017-08-11 13:01:00+03	120900.00
52E546	2017-08-03 16:27:00+03	89800.00
52E656	2017-08-14 05:30:00+03	29400.00
52E696	2017-07-06 12:42:00+03	32200.00
52E69E	2017-07-13 23:17:00+03	41800.00
52E72F	2017-08-11 02:28:00+03	12600.00
52E740	2017-08-11 02:35:00+03	70800.00
52E767	2017-08-12 10:21:00+03	62000.00
52E7B5	2017-08-12 18:02:00+03	265700.00
52E808	2017-07-22 14:27:00+03	53700.00
52E822	2017-08-02 08:09:00+03	13200.00
52E831	2017-08-09 00:21:00+03	120400.00
52E885	2017-08-10 22:16:00+03	128700.00
52E8D4	2017-07-17 15:06:00+03	105000.00
52E8E9	2017-07-02 14:02:00+03	133200.00
52E8F0	2017-08-14 01:40:00+03	24000.00
52E908	2017-08-09 16:51:00+03	27000.00
52EA1D	2017-07-10 16:07:00+03	57600.00
52EA2C	2017-07-16 13:29:00+03	131600.00
52EBB8	2017-07-26 19:44:00+03	16400.00
52EC54	2017-07-07 12:07:00+03	94700.00
52EC59	2017-07-12 00:19:00+03	32200.00
52ECA4	2017-08-08 12:14:00+03	39600.00
52ECBC	2017-08-02 15:36:00+03	89700.00
52ECE7	2017-07-11 23:32:00+03	23400.00
52ED0B	2017-08-08 10:38:00+03	86500.00
52ED1A	2017-07-31 16:25:00+03	176600.00
52EE68	2017-07-04 23:29:00+03	46400.00
52EE7D	2017-07-17 21:09:00+03	36400.00
52EECD	2017-07-02 15:49:00+03	55800.00
52EEEB	2017-08-05 21:39:00+03	240600.00
52EEF5	2017-07-24 07:14:00+03	47400.00
52EF08	2017-08-15 03:22:00+03	59300.00
52EFF1	2017-07-08 14:41:00+03	103800.00
52EFF5	2017-07-06 16:14:00+03	45500.00
52F014	2017-08-10 12:30:00+03	32800.00
52F121	2017-08-10 22:39:00+03	135600.00
52F133	2017-08-10 16:53:00+03	6600.00
52F150	2017-08-07 03:35:00+03	53800.00
52F1BD	2017-07-31 01:12:00+03	44800.00
52F1C7	2017-08-14 16:56:00+03	12000.00
52F21A	2017-07-12 23:32:00+03	31900.00
52F24F	2017-08-09 02:12:00+03	26800.00
52F312	2017-08-02 01:32:00+03	58600.00
52F33C	2017-08-05 04:59:00+03	19800.00
52F34F	2017-07-14 16:53:00+03	7300.00
52F37A	2017-08-14 21:05:00+03	55600.00
52F410	2017-07-11 05:42:00+03	26700.00
52F449	2017-07-28 03:17:00+03	34000.00
52F477	2017-07-11 09:11:00+03	40000.00
52F48E	2017-07-21 18:38:00+03	24000.00
52F4C4	2017-08-13 06:42:00+03	47000.00
52F54C	2017-07-27 06:53:00+03	114800.00
52F557	2017-08-02 01:05:00+03	185900.00
52F56D	2017-07-11 16:42:00+03	48800.00
52F69E	2017-07-04 02:44:00+03	36800.00
52F6E6	2017-08-12 01:56:00+03	23600.00
52F714	2017-06-27 22:21:00+03	31600.00
52F7A2	2017-08-04 01:35:00+03	39200.00
52F824	2017-08-08 01:24:00+03	100900.00
52F850	2017-07-28 02:43:00+03	29300.00
52F869	2017-08-13 02:20:00+03	51600.00
52F893	2017-07-08 17:08:00+03	60400.00
52F8E9	2017-07-12 08:57:00+03	246000.00
52F931	2017-07-21 12:20:00+03	57600.00
52F93F	2017-07-14 03:17:00+03	83300.00
52F967	2017-07-21 12:43:00+03	45200.00
52F986	2017-07-05 18:31:00+03	154600.00
52F9D2	2017-07-16 19:25:00+03	75800.00
52FA41	2017-07-23 15:35:00+03	20600.00
52FA73	2017-07-12 15:38:00+03	38400.00
52FAE2	2017-07-30 17:17:00+03	178800.00
52FB4E	2017-07-28 07:59:00+03	6800.00
52FB82	2017-07-14 10:22:00+03	29400.00
52FBE8	2017-07-06 03:36:00+03	22600.00
52FC10	2017-07-05 19:10:00+03	38400.00
52FC25	2017-08-05 12:08:00+03	20100.00
52FC3F	2017-08-05 07:37:00+03	57600.00
52FC7D	2017-07-25 12:28:00+03	11800.00
52FC95	2017-08-15 16:56:00+03	250600.00
52FCA1	2017-08-04 04:29:00+03	69500.00
52FDAA	2017-07-14 01:54:00+03	48400.00
52FE6F	2017-07-05 04:13:00+03	149300.00
52FE7B	2017-07-19 00:25:00+03	38400.00
52FEA0	2017-08-15 10:49:00+03	278400.00
52FEEB	2017-07-25 10:26:00+03	64800.00
52FF1D	2017-08-07 21:49:00+03	133200.00
52FF62	2017-07-07 23:09:00+03	139100.00
52FF7C	2017-08-10 06:11:00+03	28800.00
530024	2017-08-02 16:59:00+03	19600.00
53011D	2017-07-25 02:36:00+03	31600.00
530149	2017-07-31 00:08:00+03	39200.00
530179	2017-08-01 03:37:00+03	21400.00
53017B	2017-08-03 06:15:00+03	59400.00
530213	2017-07-23 13:44:00+03	94800.00
53021A	2017-08-09 22:18:00+03	16400.00
530262	2017-07-28 15:52:00+03	85000.00
530263	2017-07-01 08:39:00+03	58700.00
530286	2017-08-14 21:10:00+03	68100.00
5302ED	2017-07-29 01:17:00+03	67600.00
5302F9	2017-08-05 19:38:00+03	47400.00
53030F	2017-08-15 14:19:00+03	32800.00
53035B	2017-08-10 15:08:00+03	173600.00
53038B	2017-06-29 13:50:00+03	136200.00
5303AD	2017-07-11 14:35:00+03	32700.00
5303B7	2017-08-15 02:10:00+03	161500.00
5303C1	2017-07-08 00:22:00+03	101200.00
5303E3	2017-08-15 02:09:00+03	59800.00
530438	2017-07-02 03:33:00+03	423800.00
5304D5	2017-07-28 19:56:00+03	141300.00
530542	2017-07-24 01:51:00+03	39100.00
530583	2017-07-04 10:26:00+03	23200.00
5305E0	2017-07-14 15:36:00+03	59200.00
53067E	2017-07-30 18:46:00+03	134400.00
5306C3	2017-07-07 09:45:00+03	81600.00
530737	2017-07-06 22:58:00+03	13400.00
53074E	2017-07-07 05:45:00+03	152900.00
530750	2017-08-06 06:00:00+03	43200.00
5307E5	2017-07-19 12:43:00+03	66600.00
5307EE	2017-08-03 19:40:00+03	53700.00
530804	2017-07-11 18:49:00+03	177200.00
530808	2017-07-30 04:04:00+03	92400.00
53083A	2017-07-28 10:26:00+03	56000.00
530872	2017-07-15 21:46:00+03	14800.00
53088C	2017-07-21 22:30:00+03	6000.00
530891	2017-07-13 13:32:00+03	54500.00
530894	2017-07-11 15:51:00+03	131100.00
5308EB	2017-07-26 04:04:00+03	26000.00
530965	2017-08-07 12:12:00+03	8000.00
5309FB	2017-07-11 02:14:00+03	47800.00
530A0B	2017-08-04 13:07:00+03	62600.00
530ACA	2017-08-11 18:45:00+03	75300.00
530AFE	2017-07-03 07:29:00+03	229900.00
530B4D	2017-07-22 14:20:00+03	56000.00
530B99	2017-07-08 16:00:00+03	22000.00
530BA4	2017-07-07 22:34:00+03	59700.00
530BEB	2017-07-06 06:32:00+03	8400.00
530BFF	2017-07-07 00:31:00+03	67600.00
530C15	2017-07-25 20:27:00+03	11700.00
530C72	2017-07-21 03:55:00+03	47600.00
530D48	2017-08-03 23:52:00+03	37900.00
530DD5	2017-08-01 14:16:00+03	114300.00
530E1F	2017-07-10 06:50:00+03	62600.00
530E8B	2017-07-19 23:43:00+03	19600.00
530EF3	2017-08-14 18:52:00+03	7800.00
530F26	2017-07-28 16:36:00+03	144500.00
530F2B	2017-08-05 19:23:00+03	161800.00
530F63	2017-07-03 20:50:00+03	282100.00
530F70	2017-07-13 15:03:00+03	369000.00
530F86	2017-07-17 01:01:00+03	88400.00
530FC7	2017-07-14 07:03:00+03	13000.00
530FE9	2017-06-27 19:03:00+03	101200.00
530FFF	2017-08-07 05:51:00+03	37900.00
53100F	2017-07-03 07:43:00+03	40400.00
531055	2017-08-06 12:44:00+03	11600.00
53109A	2017-07-07 09:41:00+03	13400.00
531133	2017-08-06 07:08:00+03	44800.00
53119E	2017-07-23 20:19:00+03	42800.00
531213	2017-07-14 12:36:00+03	24400.00
531233	2017-07-23 09:52:00+03	32200.00
53125C	2017-08-06 23:24:00+03	46000.00
531283	2017-07-29 22:35:00+03	133100.00
5312A3	2017-07-09 13:54:00+03	58600.00
5312B6	2017-08-11 03:30:00+03	20000.00
5312ED	2017-07-06 09:20:00+03	24400.00
531319	2017-07-18 17:11:00+03	28000.00
53132D	2017-07-18 21:24:00+03	40800.00
53133E	2017-07-24 12:32:00+03	86000.00
531356	2017-07-20 04:04:00+03	66600.00
531416	2017-07-25 08:30:00+03	23200.00
53141E	2017-08-12 17:15:00+03	36800.00
531432	2017-08-09 19:39:00+03	65900.00
5314F2	2017-08-01 14:32:00+03	23200.00
531531	2017-07-26 01:11:00+03	56000.00
531593	2017-07-25 06:48:00+03	46400.00
5315EE	2017-07-13 19:19:00+03	32800.00
531697	2017-07-08 13:43:00+03	213800.00
5316EE	2017-07-30 05:09:00+03	6700.00
5316FE	2017-07-07 23:50:00+03	20400.00
531765	2017-07-31 15:48:00+03	25600.00
5317C1	2017-08-12 02:16:00+03	42800.00
5317F4	2017-06-28 01:40:00+03	136800.00
531882	2017-07-24 21:11:00+03	62800.00
5318D4	2017-08-06 18:08:00+03	73100.00
531953	2017-08-08 07:56:00+03	35600.00
53195B	2017-07-26 17:34:00+03	22600.00
531982	2017-07-21 03:38:00+03	46200.00
531A19	2017-07-24 23:29:00+03	496600.00
531A54	2017-07-16 19:53:00+03	56000.00
531A6B	2017-08-01 09:09:00+03	94800.00
531A92	2017-06-29 12:28:00+03	28000.00
531AAB	2017-07-17 09:55:00+03	173900.00
531AB2	2017-08-09 19:13:00+03	133100.00
531B10	2017-08-01 05:31:00+03	38600.00
531B3B	2017-08-10 10:57:00+03	40600.00
531B95	2017-07-20 02:08:00+03	59200.00
531BA8	2017-07-22 12:15:00+03	64700.00
531C92	2017-06-25 11:26:00+03	60400.00
531CDE	2017-07-06 13:12:00+03	23200.00
531CEE	2017-07-09 09:36:00+03	70400.00
531D25	2017-08-07 20:10:00+03	68800.00
531D36	2017-07-11 12:14:00+03	81700.00
531DB2	2017-07-21 09:50:00+03	37200.00
531E36	2017-07-09 10:40:00+03	21800.00
531E7E	2017-08-08 03:00:00+03	37200.00
531E7F	2017-07-13 18:59:00+03	56900.00
531EDD	2017-07-04 16:04:00+03	23600.00
531EE2	2017-07-13 08:49:00+03	66600.00
531EF1	2017-08-06 08:01:00+03	66600.00
531F17	2017-08-07 15:35:00+03	47200.00
531F46	2017-07-17 12:10:00+03	39800.00
531F71	2017-07-25 12:53:00+03	72200.00
531FA4	2017-07-07 15:18:00+03	103400.00
531FEB	2017-08-15 01:35:00+03	13400.00
532010	2017-08-04 00:19:00+03	273000.00
532063	2017-07-18 19:22:00+03	27300.00
53207B	2017-08-07 11:38:00+03	52000.00
5320A1	2017-08-03 10:47:00+03	28000.00
5320CD	2017-07-11 14:09:00+03	75300.00
5320CF	2017-08-12 11:57:00+03	31600.00
5320E9	2017-08-13 20:20:00+03	41400.00
5320EC	2017-07-08 15:21:00+03	138000.00
532100	2017-06-29 17:59:00+03	66100.00
53210F	2017-07-16 18:54:00+03	135400.00
532113	2017-07-29 23:02:00+03	12400.00
532142	2017-08-01 21:20:00+03	369000.00
5321C5	2017-08-11 00:30:00+03	23600.00
53222E	2017-07-20 09:49:00+03	111100.00
532232	2017-07-19 18:37:00+03	40800.00
53225B	2017-08-06 16:13:00+03	112600.00
53226A	2017-08-05 06:46:00+03	23200.00
5322B1	2017-07-20 12:29:00+03	85800.00
53230F	2017-08-15 17:00:00+03	170000.00
53237B	2017-07-20 09:31:00+03	66600.00
53248F	2017-07-11 04:23:00+03	59200.00
5324B5	2017-08-04 05:17:00+03	59800.00
5324BD	2017-07-20 08:40:00+03	135600.00
5324DE	2017-07-12 06:20:00+03	70700.00
5324E3	2017-08-04 15:30:00+03	48600.00
5324ED	2017-07-13 18:53:00+03	48500.00
532554	2017-07-25 13:40:00+03	26500.00
532571	2017-07-18 07:39:00+03	66800.00
532593	2017-07-22 09:41:00+03	56000.00
5325AC	2017-08-03 20:38:00+03	14400.00
5325AD	2017-07-20 13:17:00+03	76600.00
5325B4	2017-07-12 05:47:00+03	46000.00
532643	2017-07-31 18:12:00+03	43400.00
5327D4	2017-07-18 19:58:00+03	258400.00
5327F9	2017-08-04 23:03:00+03	15000.00
5328FE	2017-08-13 14:22:00+03	92500.00
532982	2017-08-09 07:26:00+03	38800.00
532A1D	2017-07-28 10:32:00+03	169900.00
532A62	2017-07-17 21:34:00+03	25800.00
532AA2	2017-07-16 15:43:00+03	38800.00
532AF7	2017-07-14 21:30:00+03	57400.00
532B19	2017-07-05 04:41:00+03	46500.00
532B89	2017-07-06 01:17:00+03	394400.00
532C0A	2017-08-13 23:01:00+03	26900.00
532C28	2017-08-07 19:10:00+03	23600.00
532C56	2017-07-25 11:48:00+03	46000.00
532C82	2017-07-31 20:37:00+03	65900.00
532C8B	2017-07-31 12:10:00+03	193600.00
532C91	2017-08-06 15:13:00+03	167400.00
532CEF	2017-08-07 13:07:00+03	23400.00
532D2F	2017-07-30 15:42:00+03	123000.00
532DBB	2017-07-04 19:45:00+03	9800.00
532DE0	2017-08-06 14:33:00+03	43100.00
532E0E	2017-07-20 23:49:00+03	27200.00
532E33	2017-08-06 14:24:00+03	102700.00
532E66	2017-08-04 01:22:00+03	39600.00
532E84	2017-07-24 17:57:00+03	26000.00
532F00	2017-07-29 23:00:00+03	11600.00
532F73	2017-07-06 22:15:00+03	50600.00
532FA4	2017-07-15 15:13:00+03	266300.00
533023	2017-08-14 11:42:00+03	33800.00
533092	2017-08-09 06:02:00+03	55500.00
5330CE	2017-07-28 17:08:00+03	84200.00
533114	2017-07-06 19:48:00+03	30800.00
533120	2017-08-07 13:56:00+03	77700.00
5331FA	2017-07-08 15:33:00+03	6000.00
533238	2017-07-24 05:04:00+03	15000.00
53328C	2017-08-07 17:57:00+03	63700.00
5332AB	2017-07-09 23:57:00+03	73500.00
533317	2017-08-11 08:03:00+03	113600.00
5333A7	2017-07-15 12:29:00+03	39700.00
5333BA	2017-07-17 16:42:00+03	85700.00
5333F1	2017-08-01 08:56:00+03	16000.00
533490	2017-07-30 08:11:00+03	65900.00
5334AC	2017-07-05 21:25:00+03	68800.00
5334C9	2017-07-06 02:28:00+03	40000.00
5334D7	2017-07-03 17:05:00+03	32700.00
5334E3	2017-07-30 20:00:00+03	13400.00
5334F2	2017-07-09 23:08:00+03	38600.00
533508	2017-07-02 20:13:00+03	37100.00
5335DB	2017-08-15 02:58:00+03	56900.00
5335E1	2017-08-03 09:19:00+03	31400.00
5335F3	2017-07-18 06:02:00+03	92900.00
53367E	2017-07-03 07:38:00+03	27300.00
53368F	2017-07-20 14:04:00+03	38600.00
5336BB	2017-07-12 08:27:00+03	43800.00
5336BE	2017-08-09 23:50:00+03	266400.00
5336F4	2017-07-29 21:49:00+03	47000.00
5336FB	2017-07-07 10:36:00+03	19600.00
53379C	2017-08-13 02:53:00+03	28800.00
5337A1	2017-07-26 16:13:00+03	270000.00
5337D0	2017-08-10 07:26:00+03	47200.00
5337DD	2017-07-13 03:10:00+03	170200.00
533801	2017-07-24 10:51:00+03	6700.00
533851	2017-08-08 19:47:00+03	27400.00
533872	2017-07-08 22:22:00+03	89600.00
5338CA	2017-07-14 13:34:00+03	38300.00
5338CE	2017-07-22 12:33:00+03	127600.00
5338D8	2017-07-29 14:53:00+03	99300.00
533949	2017-07-21 00:37:00+03	28800.00
5339E8	2017-07-23 19:24:00+03	44800.00
5339F8	2017-07-11 18:00:00+03	28800.00
533A35	2017-08-10 10:41:00+03	202200.00
533A4A	2017-07-17 13:36:00+03	27700.00
533AFC	2017-08-14 20:51:00+03	23200.00
533B02	2017-07-05 06:47:00+03	56600.00
533B5A	2017-07-15 00:22:00+03	7400.00
533C63	2017-07-25 05:55:00+03	13400.00
533C7C	2017-08-12 09:06:00+03	24400.00
533D62	2017-07-26 05:13:00+03	28800.00
533D96	2017-07-18 21:15:00+03	59300.00
533DAE	2017-08-13 11:45:00+03	81700.00
533DCA	2017-07-06 10:50:00+03	56000.00
533E4B	2017-07-05 08:28:00+03	62900.00
533E53	2017-07-20 18:33:00+03	167400.00
533F08	2017-08-12 12:40:00+03	101200.00
533F85	2017-06-28 14:58:00+03	155600.00
533FDB	2017-07-16 03:10:00+03	153300.00
534008	2017-07-21 05:54:00+03	21800.00
534114	2017-08-07 05:24:00+03	80000.00
534125	2017-07-07 18:46:00+03	270200.00
534134	2017-07-01 17:02:00+03	24400.00
5341BE	2017-07-31 14:22:00+03	62000.00
5341CC	2017-07-25 14:47:00+03	49200.00
534205	2017-08-01 15:46:00+03	40000.00
534215	2017-07-19 07:37:00+03	13400.00
534296	2017-07-28 15:44:00+03	65500.00
53429B	2017-07-31 09:23:00+03	31600.00
53433F	2017-07-02 12:54:00+03	246000.00
5343C6	2017-07-29 07:11:00+03	56000.00
534405	2017-07-25 05:08:00+03	23200.00
53445B	2017-07-29 06:30:00+03	81600.00
53445C	2017-07-08 00:50:00+03	17000.00
534509	2017-07-05 17:34:00+03	93900.00
5345E4	2017-07-12 08:43:00+03	22000.00
534654	2017-07-18 01:06:00+03	21400.00
5346AA	2017-07-24 20:28:00+03	56100.00
5346DF	2017-07-07 06:35:00+03	39100.00
5346E5	2017-08-12 02:14:00+03	135100.00
53470E	2017-07-05 11:24:00+03	14400.00
53472C	2017-07-18 15:59:00+03	11600.00
534764	2017-07-22 15:32:00+03	47600.00
534812	2017-08-02 20:14:00+03	40400.00
534882	2017-07-21 06:22:00+03	131600.00
5348BB	2017-08-04 06:57:00+03	28000.00
5348ED	2017-07-31 19:49:00+03	45100.00
534932	2017-08-06 10:28:00+03	24800.00
534960	2017-08-06 17:03:00+03	55800.00
5349B0	2017-07-10 09:37:00+03	58000.00
5349DE	2017-07-25 23:07:00+03	55700.00
534A84	2017-08-13 12:15:00+03	54000.00
534ACD	2017-07-29 15:03:00+03	45100.00
534B39	2017-08-06 04:13:00+03	175200.00
534BB3	2017-07-09 01:35:00+03	10700.00
534C92	2017-07-04 22:04:00+03	56100.00
534CF0	2017-08-12 00:33:00+03	198400.00
534D2B	2017-07-12 12:37:00+03	56000.00
534D52	2017-07-09 04:41:00+03	133100.00
534D9E	2017-08-01 16:59:00+03	25000.00
534DA7	2017-08-09 13:08:00+03	34100.00
534DE2	2017-08-05 19:21:00+03	160700.00
534E0F	2017-07-05 20:14:00+03	114300.00
534E26	2017-08-04 06:28:00+03	270000.00
534E3B	2017-06-30 11:31:00+03	135600.00
534E4A	2017-07-26 07:49:00+03	190100.00
534E5B	2017-07-29 18:25:00+03	27200.00
534E62	2017-08-02 14:17:00+03	21800.00
534E9D	2017-07-27 07:15:00+03	46400.00
534EF9	2017-08-14 01:33:00+03	56100.00
534F39	2017-07-02 02:26:00+03	44800.00
534F55	2017-07-27 01:22:00+03	27400.00
53500C	2017-07-06 22:00:00+03	28000.00
53503F	2017-08-07 05:31:00+03	225200.00
5350B8	2017-08-04 05:12:00+03	47100.00
5350F4	2017-08-01 05:39:00+03	85000.00
535111	2017-08-05 01:05:00+03	258400.00
53514A	2017-08-14 13:39:00+03	46800.00
53514E	2017-07-11 02:34:00+03	73100.00
535157	2017-07-10 01:42:00+03	86600.00
53521D	2017-07-26 11:16:00+03	84000.00
535228	2017-08-09 21:27:00+03	187800.00
535244	2017-08-13 17:46:00+03	21600.00
5352D6	2017-07-11 16:58:00+03	139800.00
5352D8	2017-07-13 07:30:00+03	12400.00
53530D	2017-07-26 00:46:00+03	12200.00
535311	2017-07-27 15:42:00+03	55800.00
535318	2017-08-02 12:25:00+03	85700.00
535353	2017-07-31 23:34:00+03	15900.00
535385	2017-08-11 08:32:00+03	21400.00
5353A5	2017-08-11 21:00:00+03	73300.00
53546E	2017-07-13 08:20:00+03	27200.00
535499	2017-07-28 04:26:00+03	131600.00
53549F	2017-07-31 08:37:00+03	123000.00
5354CF	2017-07-26 08:47:00+03	56100.00
53550B	2017-08-14 10:19:00+03	57600.00
535569	2017-07-15 17:42:00+03	102100.00
535587	2017-07-05 19:24:00+03	199600.00
535589	2017-08-02 16:11:00+03	153600.00
53558D	2017-07-27 17:18:00+03	9200.00
5355DC	2017-07-07 03:24:00+03	290400.00
535668	2017-07-07 23:20:00+03	48400.00
5356BB	2017-08-01 22:13:00+03	62600.00
5356F5	2017-07-31 13:42:00+03	132800.00
535767	2017-07-13 00:41:00+03	10800.00
53576C	2017-07-22 17:58:00+03	6700.00
535780	2017-08-09 04:41:00+03	369000.00
535788	2017-07-18 06:48:00+03	76600.00
53578C	2017-07-14 15:17:00+03	28800.00
5357B6	2017-08-15 11:06:00+03	39800.00
5357C7	2017-07-17 08:30:00+03	51900.00
535802	2017-07-06 14:07:00+03	31400.00
535919	2017-07-05 18:31:00+03	29000.00
53596C	2017-07-16 01:17:00+03	89700.00
5359C2	2017-07-17 18:14:00+03	398500.00
535A13	2017-07-02 17:36:00+03	23400.00
535A84	2017-08-10 23:57:00+03	170400.00
535A88	2017-07-30 15:32:00+03	75600.00
535AB1	2017-08-01 06:37:00+03	46400.00
535B52	2017-07-08 15:55:00+03	66000.00
535BEB	2017-07-15 07:32:00+03	25100.00
535BFD	2017-08-11 20:11:00+03	13400.00
535C0E	2017-07-17 00:47:00+03	77000.00
535C2E	2017-08-13 08:18:00+03	20200.00
535CDA	2017-08-01 17:23:00+03	106500.00
535CDB	2017-07-14 22:10:00+03	112000.00
535D7D	2017-07-22 18:34:00+03	56000.00
535DC4	2017-07-17 23:49:00+03	168000.00
535DE9	2017-07-02 09:19:00+03	70500.00
535E06	2017-07-19 11:13:00+03	24000.00
535E63	2017-07-22 18:41:00+03	65500.00
535E82	2017-07-30 20:37:00+03	36200.00
535F2A	2017-07-04 14:34:00+03	21800.00
535F2D	2017-07-01 08:44:00+03	70700.00
535F50	2017-08-12 16:41:00+03	66600.00
535F6D	2017-07-07 21:13:00+03	36800.00
535FFA	2017-07-15 17:54:00+03	23600.00
536035	2017-08-14 23:00:00+03	67500.00
5360C5	2017-08-07 10:05:00+03	23200.00
53611A	2017-08-04 22:02:00+03	116400.00
536135	2017-08-01 23:14:00+03	85000.00
5361CC	2017-07-08 11:34:00+03	111600.00
536231	2017-08-01 09:14:00+03	67600.00
536243	2017-07-11 18:57:00+03	104300.00
53628D	2017-07-15 05:56:00+03	43900.00
5362C2	2017-07-26 04:58:00+03	136800.00
5362E0	2017-07-12 12:48:00+03	147200.00
536307	2017-07-21 07:28:00+03	266400.00
53631B	2017-07-13 18:51:00+03	47500.00
536334	2017-08-13 17:46:00+03	23600.00
536340	2017-07-06 20:56:00+03	378400.00
5363EB	2017-08-13 03:28:00+03	59200.00
53641A	2017-08-01 03:42:00+03	174000.00
53646E	2017-08-04 02:24:00+03	70800.00
53648C	2017-07-13 04:30:00+03	92000.00
536587	2017-08-01 11:22:00+03	207000.00
536638	2017-08-12 03:03:00+03	11000.00
536724	2017-07-25 23:41:00+03	56000.00
536798	2017-07-16 10:22:00+03	57600.00
53680D	2017-07-23 04:09:00+03	200500.00
53685D	2017-08-03 19:35:00+03	88900.00
53692D	2017-07-19 00:39:00+03	12200.00
536944	2017-07-31 02:25:00+03	32400.00
536999	2017-07-05 04:14:00+03	137300.00
5369D7	2017-08-08 18:11:00+03	85700.00
536A3D	2017-07-06 15:19:00+03	35200.00
536A48	2017-07-13 05:48:00+03	24200.00
536A72	2017-08-03 11:03:00+03	12400.00
536AD9	2017-07-19 03:15:00+03	46000.00
536B12	2017-07-13 01:04:00+03	40600.00
536B3B	2017-07-16 09:30:00+03	48600.00
536B60	2017-08-10 09:33:00+03	170000.00
536C69	2017-08-05 19:53:00+03	97600.00
536CCE	2017-08-05 13:31:00+03	104900.00
536CDA	2017-07-03 03:28:00+03	30200.00
536CFB	2017-08-15 11:34:00+03	60400.00
536DDD	2017-07-10 18:43:00+03	28300.00
536E26	2017-07-18 12:58:00+03	19600.00
536EE2	2017-07-23 16:43:00+03	28800.00
536F01	2017-06-30 20:50:00+03	75600.00
536F27	2017-08-03 04:54:00+03	137000.00
536F38	2017-08-03 13:58:00+03	47200.00
536F44	2017-07-16 05:11:00+03	144800.00
536F68	2017-08-03 07:01:00+03	65900.00
536FC2	2017-06-30 11:47:00+03	16400.00
536FD5	2017-07-19 00:07:00+03	21800.00
536FE7	2017-07-13 09:07:00+03	125400.00
5370A8	2017-07-12 10:17:00+03	6700.00
537119	2017-08-08 17:18:00+03	236500.00
53713C	2017-08-14 16:42:00+03	81600.00
5371AF	2017-08-07 13:55:00+03	57800.00
5371DD	2017-07-18 14:25:00+03	23600.00
537218	2017-08-02 22:44:00+03	98400.00
53722D	2017-06-30 09:07:00+03	54500.00
537240	2017-07-04 04:50:00+03	270700.00
53725F	2017-08-08 07:52:00+03	140000.00
5372A9	2017-08-13 03:21:00+03	32300.00
5372BE	2017-07-18 12:12:00+03	75300.00
537331	2017-07-08 06:39:00+03	77200.00
537348	2017-07-15 15:59:00+03	87300.00
537368	2017-08-08 01:44:00+03	24000.00
53739A	2017-08-13 23:18:00+03	80900.00
5373DB	2017-08-04 06:17:00+03	44800.00
537456	2017-07-21 21:45:00+03	16400.00
53745B	2017-07-07 19:50:00+03	6300.00
53746A	2017-08-13 14:05:00+03	26000.00
53747F	2017-07-11 21:41:00+03	28800.00
537494	2017-07-27 23:13:00+03	66600.00
5374A0	2017-07-24 01:15:00+03	32200.00
5374EE	2017-06-29 18:13:00+03	45400.00
537501	2017-07-02 17:34:00+03	48800.00
537551	2017-07-12 11:31:00+03	37100.00
5375EC	2017-07-31 20:28:00+03	246000.00
537615	2017-07-17 23:38:00+03	186900.00
53762F	2017-08-15 05:53:00+03	397100.00
537666	2017-07-18 08:42:00+03	175300.00
5376A7	2017-07-16 17:48:00+03	37900.00
5376CE	2017-07-09 00:43:00+03	28800.00
5376DF	2017-07-22 14:17:00+03	35800.00
53772D	2017-07-21 08:52:00+03	87700.00
53775C	2017-07-03 04:06:00+03	26700.00
53777A	2017-07-12 08:39:00+03	27900.00
5377CC	2017-07-30 18:36:00+03	72800.00
5377D3	2017-07-30 02:00:00+03	33100.00
5378B2	2017-08-14 16:21:00+03	12000.00
5378D6	2017-06-30 02:26:00+03	6800.00
5378F8	2017-08-08 00:39:00+03	73600.00
537912	2017-07-11 03:06:00+03	40800.00
537936	2017-06-30 08:54:00+03	62800.00
53793E	2017-06-27 18:01:00+03	135600.00
537949	2017-07-29 05:41:00+03	67000.00
537A49	2017-08-05 03:31:00+03	18400.00
537A7A	2017-07-09 11:57:00+03	34000.00
537B17	2017-06-30 20:35:00+03	10600.00
537B84	2017-07-25 07:58:00+03	135000.00
537B90	2017-08-13 14:51:00+03	204500.00
537BC3	2017-07-21 00:55:00+03	51800.00
537BC7	2017-07-01 05:57:00+03	28000.00
537C52	2017-08-02 01:44:00+03	67600.00
537C64	2017-08-04 23:07:00+03	59800.00
537CAD	2017-07-16 04:33:00+03	53300.00
537CEA	2017-07-13 09:07:00+03	22000.00
537CEB	2017-07-27 22:49:00+03	249200.00
537D66	2017-07-15 21:48:00+03	31400.00
537DE3	2017-07-12 11:06:00+03	41200.00
537E3B	2017-08-07 15:36:00+03	153300.00
537EA5	2017-07-18 14:01:00+03	53000.00
537EB2	2017-07-22 21:30:00+03	101500.00
537EC6	2017-07-19 20:27:00+03	131600.00
537EDA	2017-07-21 10:20:00+03	136600.00
537F15	2017-08-15 04:41:00+03	68800.00
537F27	2017-07-18 19:10:00+03	135400.00
537F50	2017-07-11 09:47:00+03	139400.00
537F84	2017-07-23 23:57:00+03	31600.00
537FEF	2017-08-09 06:01:00+03	115900.00
538006	2017-08-14 10:07:00+03	142000.00
538019	2017-07-21 19:37:00+03	56100.00
538025	2017-08-12 08:29:00+03	26800.00
5380E4	2017-07-14 01:59:00+03	7200.00
538109	2017-08-12 15:31:00+03	25200.00
53811E	2017-07-03 13:40:00+03	170500.00
538167	2017-07-02 15:31:00+03	135400.00
53818D	2017-08-02 18:43:00+03	64600.00
5381E3	2017-07-06 07:32:00+03	9200.00
53824C	2017-08-04 04:21:00+03	16400.00
5382EE	2017-07-07 11:10:00+03	111600.00
538363	2017-08-13 13:11:00+03	333400.00
538384	2017-08-03 16:10:00+03	25100.00
53838E	2017-07-12 04:11:00+03	390400.00
538444	2017-07-16 09:58:00+03	88100.00
538491	2017-08-08 19:54:00+03	38500.00
5384E6	2017-07-31 03:25:00+03	92800.00
5384F4	2017-08-15 05:12:00+03	64700.00
538540	2017-08-15 16:49:00+03	273600.00
538601	2017-07-19 16:58:00+03	80900.00
53860E	2017-08-11 03:28:00+03	102000.00
538665	2017-07-20 19:05:00+03	24400.00
5386B3	2017-07-29 13:23:00+03	94700.00
538713	2017-07-22 17:42:00+03	30200.00
53877B	2017-07-02 08:24:00+03	64700.00
5387BD	2017-08-15 03:46:00+03	72600.00
5387ED	2017-07-15 09:04:00+03	92800.00
538802	2017-08-14 03:16:00+03	7000.00
53880A	2017-07-02 07:43:00+03	27200.00
53880B	2017-07-30 21:42:00+03	31600.00
538884	2017-07-27 18:35:00+03	12600.00
53897C	2017-07-13 19:05:00+03	24000.00
5389D0	2017-07-24 15:43:00+03	47500.00
538AA5	2017-07-31 15:34:00+03	44000.00
538AB3	2017-08-10 16:34:00+03	56900.00
538AB4	2017-07-25 05:03:00+03	90400.00
538ACA	2017-08-15 12:35:00+03	42800.00
538B39	2017-07-13 23:45:00+03	6000.00
538B4E	2017-07-27 12:28:00+03	14800.00
538B7B	2017-06-30 16:32:00+03	81700.00
538B80	2017-07-17 10:49:00+03	16400.00
538C33	2017-07-10 05:51:00+03	18900.00
538C73	2017-07-25 22:08:00+03	89600.00
538CA9	2017-07-16 18:26:00+03	23200.00
538CAF	2017-07-20 02:16:00+03	40400.00
538D14	2017-07-12 06:43:00+03	14400.00
538D5F	2017-08-15 17:28:00+03	196800.00
538D88	2017-06-30 04:56:00+03	80300.00
538DDE	2017-07-12 09:05:00+03	46400.00
538DF1	2017-07-30 06:41:00+03	339300.00
538E3E	2017-07-10 02:48:00+03	199200.00
538EAC	2017-07-27 23:17:00+03	178800.00
538F12	2017-08-08 15:07:00+03	49500.00
538FAB	2017-08-12 07:15:00+03	111600.00
538FBF	2017-07-08 19:56:00+03	80200.00
539030	2017-07-07 02:07:00+03	21400.00
5390CF	2017-08-11 07:20:00+03	265600.00
53910B	2017-07-16 07:28:00+03	58200.00
539132	2017-07-16 20:10:00+03	119600.00
53915E	2017-07-11 08:42:00+03	34000.00
5391DA	2017-07-07 10:34:00+03	111600.00
539216	2017-07-09 15:48:00+03	55800.00
539265	2017-08-12 00:10:00+03	65900.00
5392B7	2017-07-23 05:01:00+03	260300.00
53935B	2017-07-18 02:14:00+03	43200.00
539382	2017-07-29 17:02:00+03	95600.00
53940C	2017-07-10 15:52:00+03	61800.00
539435	2017-08-13 18:05:00+03	65900.00
539476	2017-08-13 05:49:00+03	134400.00
539498	2017-08-05 00:08:00+03	95200.00
5394DB	2017-07-24 06:52:00+03	23000.00
5394EC	2017-07-13 05:55:00+03	62200.00
539539	2017-08-09 04:47:00+03	269200.00
53956E	2017-07-30 04:04:00+03	54000.00
5395C6	2017-08-04 18:47:00+03	75400.00
5395FA	2017-07-18 08:44:00+03	121400.00
53960E	2017-07-25 08:02:00+03	48400.00
5396E4	2017-07-24 16:21:00+03	60300.00
5396F4	2017-07-07 22:54:00+03	179200.00
539731	2017-07-13 10:06:00+03	24200.00
53975D	2017-07-10 08:13:00+03	23200.00
539774	2017-08-13 23:00:00+03	14400.00
539775	2017-08-04 00:05:00+03	99300.00
5397BD	2017-08-10 21:07:00+03	14000.00
5397EA	2017-08-13 19:01:00+03	29600.00
539841	2017-07-18 02:12:00+03	56000.00
539862	2017-08-01 21:32:00+03	189200.00
539888	2017-08-06 14:59:00+03	265600.00
5398D6	2017-07-07 06:29:00+03	25600.00
5398E5	2017-08-07 05:52:00+03	311200.00
539930	2017-07-23 17:24:00+03	6700.00
5399DB	2017-07-27 13:38:00+03	55000.00
5399E3	2017-07-23 06:20:00+03	62600.00
539A03	2017-08-11 21:26:00+03	66400.00
539A3E	2017-07-17 20:28:00+03	29600.00
539A7D	2017-07-29 14:04:00+03	56600.00
539ACE	2017-07-28 10:30:00+03	191200.00
539AD9	2017-08-09 16:15:00+03	271100.00
539AEB	2017-08-11 00:55:00+03	22600.00
539AF2	2017-08-04 13:54:00+03	55800.00
539B59	2017-08-14 04:15:00+03	45200.00
539BB2	2017-07-09 11:54:00+03	99600.00
539BB5	2017-07-31 03:19:00+03	41900.00
539C01	2017-07-22 10:40:00+03	58800.00
539C2E	2017-07-10 06:31:00+03	131600.00
539D09	2017-08-14 05:19:00+03	26000.00
539D2B	2017-07-18 00:36:00+03	70200.00
539D8F	2017-07-18 12:19:00+03	25700.00
539DB0	2017-07-23 02:43:00+03	85000.00
539DDA	2017-07-11 07:34:00+03	36800.00
539DEF	2017-07-11 09:12:00+03	23400.00
539E04	2017-07-23 19:19:00+03	169300.00
539E30	2017-07-28 13:26:00+03	26800.00
539E34	2017-06-29 14:31:00+03	65300.00
539E4F	2017-07-21 13:08:00+03	14400.00
539E6E	2017-08-03 11:55:00+03	152500.00
539F3C	2017-07-25 22:10:00+03	73900.00
53A00A	2017-08-03 20:52:00+03	28800.00
53A05A	2017-07-26 07:40:00+03	31200.00
53A05D	2017-08-07 23:52:00+03	77900.00
53A0EC	2017-08-02 03:49:00+03	68100.00
53A135	2017-07-27 11:22:00+03	42700.00
53A13C	2017-08-12 17:47:00+03	89700.00
53A140	2017-07-22 14:45:00+03	24700.00
53A173	2017-07-05 06:47:00+03	65600.00
53A17B	2017-07-18 15:14:00+03	21600.00
53A1F8	2017-08-09 07:59:00+03	66600.00
53A250	2017-08-05 23:19:00+03	21600.00
53A256	2017-07-20 13:13:00+03	160500.00
53A2BB	2017-06-27 06:59:00+03	42800.00
53A32D	2017-07-29 05:43:00+03	48800.00
53A383	2017-07-18 04:20:00+03	40600.00
53A391	2017-07-15 02:12:00+03	28000.00
53A3CB	2017-07-30 08:40:00+03	325500.00
53A46F	2017-07-23 01:58:00+03	26800.00
53A4A1	2017-07-10 10:08:00+03	26000.00
53A565	2017-07-13 10:32:00+03	56000.00
53A579	2017-08-08 13:46:00+03	56900.00
53A5AF	2017-08-13 07:56:00+03	168000.00
53A5C4	2017-07-02 09:46:00+03	95200.00
53A70B	2017-08-11 06:42:00+03	34800.00
53A72D	2017-07-20 11:56:00+03	92400.00
53A7A2	2017-07-28 05:15:00+03	184300.00
53A820	2017-07-28 04:42:00+03	50600.00
53A821	2017-07-30 18:01:00+03	188000.00
53A838	2017-07-18 15:12:00+03	106400.00
53A846	2017-07-11 03:32:00+03	125400.00
53A884	2017-08-07 05:29:00+03	281500.00
53A8AD	2017-07-22 05:17:00+03	56600.00
53A8C4	2017-06-29 01:33:00+03	54500.00
53A907	2017-07-19 08:15:00+03	140900.00
53A932	2017-08-12 20:44:00+03	21400.00
53A958	2017-08-01 00:21:00+03	60400.00
53A973	2017-07-24 05:37:00+03	136200.00
53A9E1	2017-08-13 19:41:00+03	80400.00
53AA82	2017-07-27 01:03:00+03	39200.00
53AAA3	2017-07-03 02:59:00+03	257600.00
53AABC	2017-08-02 09:08:00+03	184200.00
53AB17	2017-07-04 20:43:00+03	112000.00
53AB27	2017-07-09 05:04:00+03	13700.00
53AB5B	2017-08-02 08:46:00+03	56900.00
53AB7D	2017-07-05 04:20:00+03	84100.00
53ABAE	2017-07-05 20:59:00+03	38200.00
53AD3A	2017-07-26 00:21:00+03	57500.00
53AD5C	2017-08-15 10:30:00+03	13600.00
53ADA1	2017-07-16 19:04:00+03	34400.00
53ADDA	2017-08-15 03:16:00+03	42800.00
53ADF6	2017-06-28 20:41:00+03	100600.00
53AE17	2017-07-04 18:21:00+03	206800.00
53AE44	2017-08-05 09:45:00+03	12400.00
53AEBD	2017-07-21 08:03:00+03	189800.00
53AEE6	2017-07-04 17:30:00+03	71400.00
53AF19	2017-07-29 23:43:00+03	40000.00
53AF50	2017-07-29 14:17:00+03	78500.00
53AFB6	2017-08-13 13:39:00+03	27800.00
53B001	2017-08-06 13:22:00+03	34600.00
53B011	2017-07-30 07:38:00+03	23200.00
53B021	2017-07-31 08:58:00+03	44800.00
53B0A9	2017-07-06 17:50:00+03	61800.00
53B0C2	2017-08-02 15:59:00+03	56000.00
53B0C6	2017-07-30 11:13:00+03	52000.00
53B127	2017-08-05 19:38:00+03	25400.00
53B158	2017-08-02 08:09:00+03	268800.00
53B162	2017-08-14 09:58:00+03	22400.00
53B1E0	2017-07-27 16:11:00+03	38400.00
53B1E4	2017-07-04 04:25:00+03	31400.00
53B1E7	2017-07-03 20:38:00+03	120900.00
53B1F0	2017-08-09 08:34:00+03	35900.00
53B25E	2017-07-17 16:28:00+03	25800.00
53B267	2017-07-18 14:39:00+03	53600.00
53B284	2017-08-13 04:02:00+03	24800.00
53B2AF	2017-07-02 00:26:00+03	77600.00
53B2B4	2017-07-13 04:45:00+03	42800.00
53B2B9	2017-07-28 21:42:00+03	68800.00
53B2DA	2017-07-19 13:35:00+03	59100.00
53B330	2017-08-09 10:57:00+03	47000.00
53B348	2017-07-10 21:11:00+03	17200.00
53B35A	2017-07-09 11:31:00+03	76300.00
53B35B	2017-08-15 11:52:00+03	7400.00
53B39F	2017-06-30 13:19:00+03	48500.00
53B3D9	2017-07-14 18:56:00+03	99300.00
53B3E7	2017-07-01 06:05:00+03	39200.00
53B4A6	2017-08-04 17:42:00+03	135400.00
53B4EF	2017-07-18 08:31:00+03	31600.00
53B4FE	2017-06-29 17:58:00+03	26000.00
53B52B	2017-07-03 13:07:00+03	159800.00
53B549	2017-08-10 06:02:00+03	26000.00
53B58E	2017-07-20 07:43:00+03	65500.00
53B64C	2017-08-06 22:39:00+03	13400.00
53B6C5	2017-08-15 10:47:00+03	34400.00
53B6F0	2017-07-19 12:51:00+03	31600.00
53B74D	2017-07-29 22:20:00+03	46400.00
53B750	2017-08-01 17:18:00+03	52100.00
53B766	2017-07-11 21:07:00+03	132800.00
53B7E0	2017-07-25 14:55:00+03	18000.00
53B81C	2017-07-28 18:05:00+03	136100.00
53B820	2017-07-06 05:11:00+03	39300.00
53B86F	2017-08-04 12:11:00+03	14000.00
53B8BF	2017-08-05 17:51:00+03	10800.00
53B8F1	2017-08-13 21:17:00+03	116000.00
53B906	2017-08-09 19:59:00+03	168000.00
53B90A	2017-08-09 01:20:00+03	65900.00
53B926	2017-08-04 16:23:00+03	47500.00
53B966	2017-08-14 14:03:00+03	38600.00
53B9F0	2017-07-20 17:31:00+03	46400.00
53BA45	2017-08-03 03:53:00+03	26800.00
53BA6B	2017-07-21 21:54:00+03	6000.00
53BAF1	2017-07-16 12:28:00+03	36800.00
53BB07	2017-08-10 01:45:00+03	135400.00
53BB19	2017-07-09 00:25:00+03	60400.00
53BB42	2017-07-12 16:59:00+03	58600.00
53BB92	2017-07-24 00:35:00+03	78000.00
53BBF9	2017-07-20 10:27:00+03	265600.00
53BC09	2017-07-30 08:41:00+03	27700.00
53BC65	2017-08-13 21:33:00+03	3800.00
53BCC7	2017-07-12 19:46:00+03	13600.00
53BD03	2017-07-14 06:52:00+03	83300.00
53BDD5	2017-07-31 12:23:00+03	58000.00
53BDFF	2017-07-21 06:06:00+03	26000.00
53BE7A	2017-08-14 08:19:00+03	34000.00
53BEA3	2017-08-13 23:42:00+03	32500.00
53BEA6	2017-07-20 08:32:00+03	170500.00
53BEC0	2017-07-17 01:11:00+03	135600.00
53BED9	2017-07-09 13:36:00+03	52000.00
53BEEA	2017-08-07 22:49:00+03	133200.00
53BEEE	2017-07-29 09:44:00+03	12400.00
53BF1B	2017-07-07 12:36:00+03	37900.00
53BF5C	2017-07-28 21:27:00+03	51600.00
53BFE8	2017-08-03 10:34:00+03	41600.00
53C017	2017-08-11 01:33:00+03	135600.00
53C024	2017-07-08 13:24:00+03	46400.00
53C0A1	2017-07-24 06:02:00+03	14000.00
53C167	2017-07-01 03:26:00+03	136000.00
53C179	2017-07-31 05:11:00+03	100600.00
53C189	2017-08-01 11:13:00+03	98400.00
53C1BC	2017-07-20 08:33:00+03	21800.00
53C1CE	2017-06-30 19:30:00+03	26000.00
53C20E	2017-06-26 04:30:00+03	142400.00
53C20F	2017-07-15 21:47:00+03	87100.00
53C284	2017-07-06 02:57:00+03	69500.00
53C296	2017-06-29 20:30:00+03	94300.00
53C29D	2017-08-14 11:14:00+03	29600.00
53C346	2017-07-15 06:14:00+03	61900.00
53C350	2017-07-27 05:34:00+03	103800.00
53C35A	2017-07-03 21:19:00+03	29600.00
53C36A	2017-07-03 10:51:00+03	101700.00
53C38E	2017-07-16 11:04:00+03	96200.00
53C41C	2017-07-11 05:50:00+03	60400.00
53C465	2017-08-05 17:11:00+03	22000.00
53C471	2017-07-02 11:52:00+03	113100.00
53C497	2017-08-15 18:00:00+03	67600.00
53C535	2017-07-06 05:22:00+03	42800.00
53C53E	2017-07-25 18:58:00+03	666000.00
53C585	2017-08-06 17:39:00+03	59800.00
53C5F9	2017-08-13 22:25:00+03	153300.00
53C614	2017-08-04 05:20:00+03	131100.00
53C672	2017-07-31 18:45:00+03	40000.00
53C686	2017-08-14 09:24:00+03	110700.00
53C6A3	2017-07-24 04:11:00+03	93900.00
53C705	2017-07-25 23:54:00+03	154300.00
53C785	2017-07-04 22:44:00+03	156000.00
53C7AD	2017-07-29 17:35:00+03	271200.00
53C7B9	2017-07-09 19:51:00+03	70700.00
53C7F4	2017-07-01 23:34:00+03	20600.00
53C7FC	2017-08-14 15:59:00+03	58400.00
53C822	2017-07-26 22:45:00+03	118000.00
53C860	2017-07-28 12:42:00+03	24400.00
53C8A8	2017-07-30 09:11:00+03	47500.00
53C931	2017-07-22 09:13:00+03	79800.00
53C961	2017-07-03 14:37:00+03	172600.00
53C99D	2017-07-17 20:36:00+03	58600.00
53CAB5	2017-08-03 15:35:00+03	28800.00
53CB0A	2017-08-11 11:25:00+03	15700.00
53CB63	2017-07-30 22:58:00+03	139400.00
53CB7A	2017-07-30 12:01:00+03	28000.00
53CC0F	2017-07-24 05:11:00+03	139100.00
53CC14	2017-08-15 01:02:00+03	77900.00
53CCCB	2017-07-25 03:08:00+03	231300.00
53CCDC	2017-07-28 16:01:00+03	133200.00
53CCF1	2017-07-09 07:45:00+03	52400.00
53CD10	2017-07-17 08:34:00+03	24800.00
53CE1B	2017-07-16 00:56:00+03	8200.00
53CE2C	2017-08-11 12:21:00+03	256700.00
53CE35	2017-07-19 10:46:00+03	43600.00
53CE5A	2017-07-20 03:01:00+03	162600.00
53CE72	2017-07-31 09:17:00+03	38600.00
53CEA4	2017-08-13 11:33:00+03	51900.00
53CEE0	2017-08-12 13:04:00+03	124200.00
53CEFB	2017-07-15 12:49:00+03	89600.00
53CF14	2017-07-09 06:25:00+03	28000.00
53CF32	2017-08-09 19:00:00+03	39200.00
53CFC4	2017-07-31 18:30:00+03	56000.00
53CFCD	2017-07-09 09:25:00+03	133100.00
53D002	2017-08-05 10:27:00+03	29600.00
53D01D	2017-07-18 20:18:00+03	51900.00
53D02C	2017-07-08 01:21:00+03	44800.00
53D04D	2017-07-26 17:58:00+03	64100.00
53D066	2017-07-21 19:51:00+03	179700.00
53D121	2017-08-06 07:06:00+03	57600.00
53D14A	2017-08-02 01:43:00+03	71300.00
53D16E	2017-07-15 09:45:00+03	63500.00
53D228	2017-06-30 16:36:00+03	24400.00
53D278	2017-07-21 23:42:00+03	28000.00
53D2C7	2017-07-31 19:43:00+03	73500.00
53D2DA	2017-07-26 19:48:00+03	6000.00
53D2DE	2017-08-10 16:27:00+03	60200.00
53D2FE	2017-07-16 05:36:00+03	46400.00
53D30B	2017-08-03 07:41:00+03	54800.00
53D311	2017-07-30 21:27:00+03	67600.00
53D317	2017-08-07 00:31:00+03	88600.00
53D340	2017-07-17 05:24:00+03	27600.00
53D3CA	2017-07-07 16:49:00+03	199700.00
53D47D	2017-07-27 01:59:00+03	43200.00
53D550	2017-07-11 09:54:00+03	37400.00
53D565	2017-08-02 11:35:00+03	46000.00
53D5CC	2017-08-04 23:22:00+03	56000.00
53D5F4	2017-07-09 07:48:00+03	21400.00
53D626	2017-08-03 09:22:00+03	63800.00
53D67C	2017-07-07 16:38:00+03	40700.00
53D68E	2017-07-08 12:44:00+03	397700.00
53D69F	2017-07-08 00:10:00+03	71900.00
53D6D7	2017-08-15 03:31:00+03	12000.00
53D778	2017-07-31 02:52:00+03	6700.00
53D860	2017-07-31 02:47:00+03	50600.00
53D86F	2017-08-13 12:27:00+03	40700.00
53D8C2	2017-07-25 03:04:00+03	139500.00
53D8E5	2017-08-06 18:35:00+03	85000.00
53D91F	2017-08-11 07:43:00+03	91100.00
53D929	2017-07-28 10:51:00+03	46300.00
53D941	2017-08-05 06:11:00+03	54800.00
53D9B4	2017-08-06 18:57:00+03	18400.00
53DA0C	2017-07-20 01:28:00+03	6300.00
53DAC7	2017-07-15 02:42:00+03	10600.00
53DACD	2017-07-12 09:24:00+03	85000.00
53DAEC	2017-07-17 16:57:00+03	51600.00
53DB26	2017-08-07 21:57:00+03	52900.00
53DB2A	2017-07-23 14:34:00+03	81700.00
53DBE3	2017-08-12 19:10:00+03	111600.00
53DC2A	2017-07-10 06:42:00+03	56600.00
53DC3A	2017-08-04 20:50:00+03	160900.00
53DC64	2017-07-26 08:38:00+03	56000.00
53DCA8	2017-08-14 13:18:00+03	83600.00
53DCC7	2017-07-24 00:10:00+03	102100.00
53DCE3	2017-07-19 18:54:00+03	52600.00
53DD28	2017-07-28 05:39:00+03	23600.00
53DD2C	2017-08-03 11:38:00+03	121400.00
53DD49	2017-08-01 22:40:00+03	279200.00
53DE04	2017-07-27 08:33:00+03	10800.00
53DE63	2017-07-01 20:46:00+03	15000.00
53DEF5	2017-07-29 06:26:00+03	18400.00
53DF2C	2017-08-05 07:36:00+03	13600.00
53DF64	2017-08-10 09:27:00+03	134400.00
53E010	2017-06-28 03:05:00+03	24200.00
53E0AF	2017-07-06 00:08:00+03	84500.00
53E143	2017-07-08 19:38:00+03	134400.00
53E154	2017-07-31 16:43:00+03	23400.00
53E188	2017-08-15 13:01:00+03	27300.00
53E18D	2017-07-31 15:25:00+03	283100.00
53E21B	2017-08-14 08:36:00+03	246000.00
53E285	2017-08-09 02:19:00+03	178800.00
53E2BA	2017-07-17 14:20:00+03	58400.00
53E2DD	2017-08-09 10:45:00+03	6600.00
53E358	2017-08-07 22:15:00+03	310600.00
53E37C	2017-08-08 22:35:00+03	46000.00
53E3D5	2017-07-27 05:43:00+03	27200.00
53E3E5	2017-08-07 17:48:00+03	15400.00
53E411	2017-07-12 09:52:00+03	65800.00
53E420	2017-07-29 01:29:00+03	83000.00
53E469	2017-07-01 18:47:00+03	20000.00
53E4A9	2017-07-27 17:16:00+03	73500.00
53E5E1	2017-08-11 02:06:00+03	10800.00
53E624	2017-07-24 12:40:00+03	24800.00
53E62D	2017-07-13 10:12:00+03	28800.00
53E66F	2017-07-06 09:58:00+03	114800.00
53E675	2017-07-07 23:38:00+03	39800.00
53E696	2017-07-02 06:24:00+03	146600.00
53E71C	2017-07-29 12:40:00+03	67000.00
53E7A4	2017-07-19 00:08:00+03	103400.00
53E800	2017-07-23 02:24:00+03	23600.00
53E81B	2017-07-23 15:52:00+03	60400.00
53E853	2017-08-07 06:16:00+03	57500.00
53E85D	2017-08-13 03:29:00+03	46000.00
53E878	2017-08-03 18:39:00+03	59100.00
53E885	2017-07-31 17:51:00+03	26800.00
53E8D9	2017-07-26 06:13:00+03	46200.00
53E8DA	2017-07-07 18:41:00+03	14300.00
53E99A	2017-06-26 21:48:00+03	148200.00
53E99E	2017-07-03 03:54:00+03	23200.00
53E9F5	2017-07-23 21:20:00+03	84900.00
53EA10	2017-08-08 09:53:00+03	18400.00
53EA20	2017-07-28 13:22:00+03	64800.00
53EA2B	2017-07-06 00:45:00+03	53400.00
53EA42	2017-07-07 16:11:00+03	123000.00
53EA6D	2017-08-08 20:40:00+03	6700.00
53EAF4	2017-07-19 10:35:00+03	16400.00
53EB70	2017-08-07 03:27:00+03	70800.00
53EB7F	2017-07-29 11:34:00+03	51900.00
53EBA5	2017-08-07 07:35:00+03	24400.00
53EC13	2017-07-01 03:41:00+03	12400.00
53EC38	2017-08-05 22:47:00+03	32200.00
53EC66	2017-07-23 14:48:00+03	67200.00
53EC6B	2017-07-25 20:32:00+03	12000.00
53ECB0	2017-07-13 12:55:00+03	155600.00
53ED15	2017-07-06 01:17:00+03	181200.00
53ED99	2017-08-12 11:07:00+03	46400.00
53EDC8	2017-07-13 02:19:00+03	66600.00
53EDEE	2017-06-25 11:01:00+03	26700.00
53EE1F	2017-08-03 15:11:00+03	39900.00
53EEF7	2017-07-14 14:26:00+03	8400.00
53EF23	2017-07-28 04:24:00+03	23200.00
53EF32	2017-07-26 23:33:00+03	39800.00
53F047	2017-07-26 06:05:00+03	28300.00
53F053	2017-07-07 22:20:00+03	12000.00
53F083	2017-07-10 08:23:00+03	38800.00
53F096	2017-07-02 14:13:00+03	20200.00
53F0B2	2017-07-23 22:10:00+03	56000.00
53F0CF	2017-07-26 05:23:00+03	48800.00
53F114	2017-07-09 11:27:00+03	382800.00
53F120	2017-07-29 05:34:00+03	78000.00
53F1E9	2017-07-31 21:00:00+03	13200.00
53F1EF	2017-07-27 19:50:00+03	181100.00
53F202	2017-07-31 22:49:00+03	45100.00
53F215	2017-07-21 23:45:00+03	70600.00
53F23C	2017-08-12 16:07:00+03	113700.00
53F253	2017-07-17 04:33:00+03	53300.00
53F29C	2017-07-13 17:45:00+03	67600.00
53F2A8	2017-07-06 05:36:00+03	50600.00
53F2B2	2017-07-13 00:21:00+03	28800.00
53F354	2017-07-02 17:09:00+03	65900.00
53F377	2017-07-20 15:24:00+03	148200.00
53F3C8	2017-07-10 06:39:00+03	66000.00
53F3EF	2017-07-15 13:10:00+03	55800.00
53F40F	2017-07-11 08:48:00+03	54800.00
53F47E	2017-07-19 13:41:00+03	38800.00
53F4B9	2017-07-29 08:52:00+03	265600.00
53F4BB	2017-08-10 13:13:00+03	31400.00
53F4C4	2017-07-03 11:15:00+03	41200.00
53F4D7	2017-07-18 09:08:00+03	17800.00
53F4F8	2017-07-22 00:04:00+03	12600.00
53F4FF	2017-07-29 04:37:00+03	269400.00
53F558	2017-07-06 15:34:00+03	95700.00
53F58A	2017-07-19 20:55:00+03	48800.00
53F5D7	2017-08-12 09:23:00+03	56100.00
53F665	2017-07-12 13:15:00+03	123000.00
53F85A	2017-07-23 07:46:00+03	51800.00
53F85D	2017-07-03 23:11:00+03	176400.00
53F876	2017-07-07 09:25:00+03	246000.00
53F8AF	2017-07-31 08:16:00+03	24400.00
53F915	2017-07-02 07:29:00+03	199600.00
53FA3F	2017-08-01 11:45:00+03	14000.00
53FA61	2017-07-24 13:25:00+03	62600.00
53FA7B	2017-07-31 07:46:00+03	90400.00
53FA9E	2017-07-08 21:11:00+03	8200.00
53FB33	2017-07-11 20:43:00+03	31100.00
53FB5A	2017-08-06 08:30:00+03	39800.00
53FB67	2017-08-04 08:39:00+03	35200.00
53FB7D	2017-08-07 16:22:00+03	68800.00
53FB8E	2017-08-07 10:17:00+03	191200.00
53FC3C	2017-07-12 18:57:00+03	56600.00
53FC6F	2017-07-09 03:10:00+03	131100.00
53FCA9	2017-07-26 09:46:00+03	22100.00
53FD16	2017-07-27 23:42:00+03	106100.00
53FD73	2017-07-05 06:16:00+03	59800.00
53FD78	2017-08-14 09:43:00+03	332700.00
53FD7C	2017-07-20 17:17:00+03	53600.00
53FDA5	2017-07-14 04:26:00+03	38600.00
53FDD7	2017-08-13 20:18:00+03	23600.00
53FE24	2017-08-02 13:34:00+03	22000.00
53FE39	2017-07-26 09:44:00+03	56000.00
53FE55	2017-07-26 13:19:00+03	10800.00
53FECA	2017-07-01 17:17:00+03	75600.00
53FF9D	2017-08-02 06:33:00+03	76600.00
53FFAE	2017-07-17 12:36:00+03	112000.00
53FFC2	2017-08-08 06:37:00+03	14400.00
540004	2017-08-13 23:53:00+03	77900.00
540005	2017-07-05 03:47:00+03	140900.00
540017	2017-08-01 20:24:00+03	55800.00
540029	2017-07-24 12:16:00+03	136200.00
540061	2017-08-08 20:22:00+03	47400.00
540091	2017-07-11 14:20:00+03	56100.00
5400C7	2017-07-23 21:56:00+03	6700.00
5400C9	2017-07-22 19:27:00+03	23200.00
5400D8	2017-08-07 11:37:00+03	56000.00
54011B	2017-07-19 21:59:00+03	15400.00
540162	2017-08-12 06:15:00+03	70800.00
5401F7	2017-06-23 09:01:00+03	49800.00
540212	2017-07-31 18:08:00+03	54400.00
54026C	2017-07-14 04:08:00+03	281900.00
540270	2017-08-14 01:31:00+03	91100.00
540293	2017-07-07 08:19:00+03	70800.00
54030C	2017-07-21 05:31:00+03	67600.00
54031C	2017-08-03 21:33:00+03	6300.00
540342	2017-08-03 09:29:00+03	46400.00
540358	2017-07-18 21:57:00+03	24400.00
54036D	2017-07-13 16:08:00+03	6700.00
5403C3	2017-07-09 07:38:00+03	85500.00
540458	2017-07-22 21:43:00+03	265800.00
54051E	2017-07-25 04:21:00+03	77000.00
54054E	2017-07-26 09:59:00+03	120900.00
540558	2017-07-08 11:05:00+03	35300.00
54059D	2017-07-20 18:10:00+03	272300.00
5405B9	2017-08-04 00:10:00+03	92800.00
5405DC	2017-07-04 15:34:00+03	32200.00
5405F1	2017-08-06 20:53:00+03	12600.00
5405FE	2017-07-17 18:23:00+03	46700.00
54062C	2017-08-08 08:24:00+03	81700.00
540632	2017-08-04 14:07:00+03	16400.00
540648	2017-07-21 14:00:00+03	85000.00
5406C4	2017-08-05 14:23:00+03	28800.00
5406F6	2017-07-27 09:13:00+03	47600.00
54079B	2017-07-13 02:46:00+03	65900.00
5407AB	2017-08-05 18:38:00+03	58000.00
5407D2	2017-07-12 01:13:00+03	53200.00
54082D	2017-07-22 02:47:00+03	134700.00
5408C3	2017-07-23 19:26:00+03	15000.00
5408D1	2017-07-30 21:52:00+03	51500.00
5408D7	2017-08-08 07:14:00+03	38600.00
540935	2017-07-19 04:56:00+03	23400.00
540939	2017-07-06 05:04:00+03	123000.00
540944	2017-07-19 02:12:00+03	38600.00
540A30	2017-08-15 15:31:00+03	26000.00
540A3E	2017-07-21 02:54:00+03	74600.00
540A40	2017-07-20 06:05:00+03	55800.00
540AD9	2017-08-13 10:40:00+03	59800.00
540B1E	2017-07-11 07:21:00+03	56000.00
540B37	2017-07-09 19:51:00+03	25000.00
540B39	2017-08-07 02:50:00+03	25200.00
540B4A	2017-07-02 06:08:00+03	177800.00
540BB0	2017-06-30 03:14:00+03	109000.00
540BD7	2017-08-09 12:33:00+03	9200.00
540C53	2017-07-31 14:52:00+03	17000.00
540C68	2017-07-03 19:12:00+03	62900.00
540CAF	2017-07-11 14:40:00+03	52000.00
540CEC	2017-08-08 02:13:00+03	26000.00
540D07	2017-08-01 12:08:00+03	80100.00
540D26	2017-08-04 07:26:00+03	57500.00
540D73	2017-08-06 11:00:00+03	19600.00
540D76	2017-07-31 01:08:00+03	135200.00
540D99	2017-07-20 13:27:00+03	62000.00
540DA1	2017-08-15 12:04:00+03	36700.00
540E35	2017-07-11 23:25:00+03	87300.00
540E4C	2017-07-17 08:28:00+03	56000.00
540E5F	2017-08-14 01:46:00+03	134800.00
540E7F	2017-07-29 20:33:00+03	46900.00
540E8A	2017-07-17 10:26:00+03	524000.00
540F0F	2017-07-06 02:24:00+03	26000.00
540F42	2017-07-14 22:10:00+03	14400.00
540F65	2017-07-07 18:42:00+03	73600.00
540F6C	2017-07-06 04:55:00+03	67600.00
541013	2017-07-12 22:09:00+03	69000.00
541040	2017-08-02 10:25:00+03	48800.00
54105B	2017-08-14 06:05:00+03	57600.00
54108E	2017-08-06 16:00:00+03	36200.00
5410E6	2017-08-11 20:01:00+03	133200.00
541116	2017-07-25 13:03:00+03	41600.00
54113F	2017-07-30 01:51:00+03	27400.00
541149	2017-07-01 14:36:00+03	121400.00
541170	2017-07-20 07:46:00+03	133200.00
54118F	2017-07-02 18:06:00+03	66200.00
5411CE	2017-07-23 01:25:00+03	43200.00
5411D9	2017-07-09 07:29:00+03	6000.00
5411DA	2017-08-07 14:13:00+03	34000.00
5411E0	2017-07-04 14:22:00+03	211200.00
54126F	2017-08-07 04:14:00+03	58000.00
54128D	2017-07-31 03:34:00+03	36200.00
5412B4	2017-07-21 13:56:00+03	73500.00
5412B5	2017-07-21 01:27:00+03	62600.00
5412EB	2017-08-04 17:39:00+03	51900.00
54130B	2017-07-27 16:54:00+03	116000.00
541361	2017-07-29 21:14:00+03	82900.00
54139A	2017-07-06 12:14:00+03	21200.00
5414D6	2017-06-28 03:07:00+03	47500.00
541515	2017-08-11 21:50:00+03	101200.00
541529	2017-07-28 22:25:00+03	69900.00
54155F	2017-07-04 20:06:00+03	26000.00
541573	2017-08-08 09:04:00+03	103900.00
541576	2017-08-10 20:40:00+03	32700.00
541595	2017-08-06 07:29:00+03	125400.00
5415B3	2017-07-09 00:04:00+03	36200.00
541601	2017-07-04 15:59:00+03	50900.00
5416B8	2017-08-09 13:00:00+03	289800.00
5416BD	2017-08-12 14:01:00+03	27200.00
541702	2017-08-13 19:54:00+03	131600.00
541719	2017-07-23 16:53:00+03	17600.00
54172E	2017-07-11 12:52:00+03	30200.00
541778	2017-08-07 18:21:00+03	28000.00
54178A	2017-08-09 09:16:00+03	46500.00
541838	2017-08-11 14:23:00+03	54800.00
541842	2017-07-05 18:10:00+03	28000.00
54185C	2017-08-05 09:15:00+03	31100.00
54186B	2017-08-12 00:06:00+03	137700.00
541897	2017-07-26 08:46:00+03	399600.00
5418FE	2017-08-12 23:31:00+03	70700.00
54199E	2017-07-02 20:22:00+03	44000.00
5419AC	2017-07-18 21:16:00+03	28000.00
5419BD	2017-07-02 06:39:00+03	46300.00
5419C9	2017-08-08 02:40:00+03	89600.00
5419D6	2017-07-12 17:46:00+03	60700.00
5419ED	2017-07-16 16:14:00+03	61800.00
541A01	2017-07-21 22:58:00+03	46400.00
541A24	2017-07-07 23:30:00+03	119800.00
541A2F	2017-08-02 19:29:00+03	196100.00
541A44	2017-08-14 03:49:00+03	46000.00
541A4F	2017-08-13 11:35:00+03	63200.00
541A88	2017-07-31 20:24:00+03	52000.00
541AA9	2017-08-06 03:37:00+03	23200.00
541AE3	2017-08-08 09:57:00+03	92000.00
541AEB	2017-08-01 06:14:00+03	83200.00
541AFC	2017-07-23 02:02:00+03	11600.00
541B20	2017-07-31 07:06:00+03	15700.00
541B8A	2017-07-12 02:09:00+03	54800.00
541BD4	2017-08-02 10:57:00+03	111600.00
541C55	2017-08-01 13:53:00+03	82600.00
541C5E	2017-07-23 10:32:00+03	43900.00
541D58	2017-07-16 23:09:00+03	56600.00
541D60	2017-07-16 06:26:00+03	43000.00
541D74	2017-07-20 04:59:00+03	6800.00
541DC9	2017-08-11 13:46:00+03	135700.00
541E0A	2017-07-25 17:57:00+03	159200.00
541E34	2017-07-25 06:33:00+03	44000.00
541E9D	2017-07-27 12:35:00+03	23200.00
541EAB	2017-07-23 06:20:00+03	93500.00
541F14	2017-08-11 14:41:00+03	64800.00
541F41	2017-08-09 02:14:00+03	93700.00
542000	2017-07-31 01:21:00+03	40400.00
542001	2017-07-21 00:12:00+03	93900.00
5420CE	2017-08-06 04:28:00+03	32700.00
5420E7	2017-07-21 12:52:00+03	62700.00
542125	2017-07-30 21:27:00+03	24800.00
542141	2017-07-14 15:58:00+03	58000.00
542175	2017-08-05 14:53:00+03	26700.00
5421A1	2017-08-09 08:28:00+03	252200.00
54221B	2017-07-09 21:23:00+03	96800.00
5422EB	2017-08-13 01:42:00+03	102100.00
5422F6	2017-07-17 13:31:00+03	31600.00
542322	2017-08-13 22:53:00+03	35800.00
54232C	2017-07-27 14:37:00+03	86800.00
542337	2017-07-04 17:18:00+03	92800.00
542340	2017-07-30 17:31:00+03	25200.00
542357	2017-07-01 06:05:00+03	13000.00
542391	2017-07-04 11:13:00+03	135000.00
542475	2017-07-10 14:21:00+03	57800.00
54248A	2017-07-30 15:09:00+03	233800.00
5424C0	2017-07-19 21:49:00+03	69500.00
5424EC	2017-08-15 13:34:00+03	85600.00
542540	2017-07-30 20:00:00+03	23200.00
542590	2017-07-13 10:13:00+03	13000.00
542613	2017-07-24 11:36:00+03	232800.00
54261C	2017-07-10 02:16:00+03	13200.00
542658	2017-08-07 09:04:00+03	81600.00
542839	2017-07-29 04:34:00+03	47400.00
54287D	2017-07-06 14:20:00+03	43600.00
5428C2	2017-07-07 08:19:00+03	80000.00
5428D9	2017-07-07 07:18:00+03	73600.00
5429BA	2017-07-04 15:13:00+03	17200.00
5429E3	2017-07-08 00:23:00+03	516000.00
542A2C	2017-08-07 04:28:00+03	89600.00
542A3E	2017-07-16 17:50:00+03	187800.00
542AB2	2017-07-25 02:45:00+03	70300.00
542AC7	2017-08-02 07:19:00+03	67900.00
542B04	2017-08-02 12:13:00+03	57400.00
542B71	2017-07-12 11:15:00+03	46300.00
542B88	2017-07-30 01:01:00+03	21400.00
542B93	2017-08-08 10:27:00+03	123000.00
542BA0	2017-07-05 22:32:00+03	14800.00
542C00	2017-07-21 18:10:00+03	136800.00
542C8B	2017-08-09 21:54:00+03	42700.00
542CA2	2017-07-23 21:49:00+03	41600.00
542CA7	2017-06-29 02:42:00+03	20200.00
542D26	2017-07-28 07:00:00+03	22000.00
542D46	2017-07-26 05:03:00+03	25400.00
542D63	2017-07-03 11:38:00+03	73900.00
542D69	2017-08-13 23:15:00+03	14000.00
542DB5	2017-07-17 04:38:00+03	395000.00
542E6C	2017-07-05 16:36:00+03	51000.00
542ED3	2017-08-12 05:53:00+03	90800.00
542EFD	2017-07-08 10:30:00+03	28000.00
542FFB	2017-07-14 02:11:00+03	28000.00
54301D	2017-08-03 10:05:00+03	46300.00
543026	2017-07-29 10:12:00+03	111600.00
54306F	2017-08-14 02:54:00+03	51900.00
5430F1	2017-08-13 07:09:00+03	153600.00
5430FD	2017-08-07 00:18:00+03	128800.00
54310E	2017-07-04 11:16:00+03	86500.00
54317E	2017-07-11 16:38:00+03	664100.00
5431AE	2017-07-30 14:37:00+03	122000.00
543204	2017-07-25 04:24:00+03	28800.00
543245	2017-08-10 09:07:00+03	76800.00
5432A5	2017-07-19 23:11:00+03	31400.00
543425	2017-07-20 03:39:00+03	25600.00
543457	2017-07-08 23:55:00+03	66000.00
543479	2017-08-15 10:47:00+03	87600.00
5434C2	2017-08-10 22:52:00+03	64600.00
5434E9	2017-08-04 10:47:00+03	34800.00
543500	2017-08-04 22:32:00+03	199600.00
543530	2017-07-25 14:01:00+03	50700.00
5435C0	2017-07-26 16:35:00+03	580200.00
5435DE	2017-08-10 22:08:00+03	111700.00
5435E6	2017-07-23 05:05:00+03	27700.00
5435E7	2017-07-07 22:28:00+03	38600.00
543631	2017-08-07 15:32:00+03	21400.00
54366E	2017-07-22 21:21:00+03	56000.00
5436D2	2017-07-15 07:51:00+03	142800.00
5436F7	2017-08-01 08:09:00+03	109600.00
54370A	2017-07-10 02:04:00+03	260900.00
54372C	2017-08-04 09:35:00+03	54300.00
5437C8	2017-08-08 00:16:00+03	62600.00
5437DD	2017-07-10 08:13:00+03	28000.00
5437E4	2017-07-10 23:32:00+03	29200.00
54384E	2017-08-12 09:17:00+03	85000.00
543864	2017-06-30 14:59:00+03	39800.00
543892	2017-07-14 00:52:00+03	24400.00
5438A8	2017-08-10 10:56:00+03	87200.00
5438CE	2017-07-31 16:16:00+03	72400.00
543947	2017-07-09 20:21:00+03	13700.00
5439DA	2017-08-08 02:58:00+03	76700.00
5439E4	2017-07-14 02:36:00+03	36200.00
5439F9	2017-07-31 12:45:00+03	45200.00
543A1C	2017-07-13 01:08:00+03	101500.00
543AA7	2017-08-07 23:27:00+03	64500.00
543AD8	2017-07-27 23:39:00+03	92400.00
543B12	2017-07-17 23:38:00+03	23600.00
543B70	2017-07-31 15:19:00+03	84000.00
543BCE	2017-08-09 01:08:00+03	77500.00
543BD5	2017-07-05 23:06:00+03	22000.00
543C45	2017-07-01 19:35:00+03	207200.00
543CA5	2017-07-06 02:39:00+03	27900.00
543CF9	2017-08-10 05:24:00+03	13600.00
543DA0	2017-07-14 21:09:00+03	83000.00
543DC6	2017-08-12 04:46:00+03	116400.00
543E2E	2017-08-04 00:05:00+03	6400.00
543E5A	2017-07-02 14:22:00+03	64700.00
543E77	2017-08-13 02:11:00+03	168700.00
543F34	2017-08-06 19:49:00+03	68800.00
543F72	2017-07-04 23:55:00+03	47400.00
543F95	2017-07-19 17:46:00+03	41600.00
543FAB	2017-08-04 21:28:00+03	73600.00
543FB6	2017-07-16 10:43:00+03	59800.00
543FB7	2017-07-15 20:11:00+03	49800.00
54400F	2017-07-17 03:38:00+03	26000.00
544049	2017-08-01 01:23:00+03	23200.00
544050	2017-07-20 22:47:00+03	182300.00
544080	2017-07-31 01:12:00+03	68900.00
5440A9	2017-07-03 15:09:00+03	42800.00
5440DF	2017-08-13 21:52:00+03	86500.00
544179	2017-07-06 22:35:00+03	55800.00
5441C3	2017-07-06 17:16:00+03	57500.00
5441F3	2017-06-29 22:35:00+03	40600.00
5442E7	2017-08-03 05:12:00+03	113700.00
544309	2017-08-07 23:48:00+03	23600.00
544363	2017-07-27 12:56:00+03	314300.00
54438A	2017-07-03 17:01:00+03	30200.00
54438F	2017-07-02 13:28:00+03	65100.00
5443A9	2017-07-04 07:39:00+03	28300.00
5443AE	2017-08-15 14:36:00+03	176500.00
5443B2	2017-07-31 03:40:00+03	88900.00
5443B7	2017-08-09 08:33:00+03	22400.00
5443C6	2017-07-16 06:41:00+03	57600.00
5443EB	2017-07-13 22:35:00+03	284400.00
54441F	2017-07-20 20:54:00+03	74800.00
544451	2017-06-29 00:26:00+03	65600.00
544452	2017-08-01 18:04:00+03	92000.00
54447C	2017-07-26 12:54:00+03	133100.00
544517	2017-07-11 06:34:00+03	209500.00
544522	2017-07-23 23:33:00+03	61800.00
54453A	2017-08-07 01:32:00+03	35600.00
544548	2017-07-25 18:54:00+03	37900.00
5445AA	2017-07-16 11:35:00+03	195800.00
5445CF	2017-07-05 13:46:00+03	58600.00
5445DB	2017-08-01 02:35:00+03	105600.00
544614	2017-07-21 19:29:00+03	25100.00
54462C	2017-08-04 10:05:00+03	132500.00
54466C	2017-08-05 05:22:00+03	28000.00
544686	2017-07-28 13:00:00+03	67700.00
5446B0	2017-07-06 03:09:00+03	13000.00
5446F5	2017-08-03 16:36:00+03	28300.00
5446FF	2017-07-08 02:41:00+03	38600.00
544738	2017-07-17 10:50:00+03	78000.00
544757	2017-07-18 23:00:00+03	119800.00
544767	2017-08-01 21:22:00+03	66600.00
544775	2017-07-30 00:03:00+03	37900.00
5447D8	2017-07-12 21:07:00+03	25100.00
54484A	2017-08-02 05:51:00+03	78100.00
5448A3	2017-08-04 05:05:00+03	29600.00
54497D	2017-07-14 04:36:00+03	131100.00
5449B5	2017-07-25 17:15:00+03	25800.00
5449EC	2017-07-22 08:28:00+03	132800.00
544AB3	2017-07-18 23:09:00+03	101500.00
544AC9	2017-07-22 23:02:00+03	57300.00
544B5F	2017-07-22 08:53:00+03	127300.00
544BDB	2017-07-11 21:20:00+03	142800.00
544BE5	2017-07-05 07:50:00+03	49300.00
544C2C	2017-07-21 12:25:00+03	58400.00
544CB3	2017-07-13 07:52:00+03	8200.00
544D1B	2017-08-13 02:23:00+03	69000.00
544D24	2017-08-11 16:51:00+03	35800.00
544D8B	2017-07-04 11:13:00+03	31600.00
544DA5	2017-07-15 15:46:00+03	23600.00
544E65	2017-07-27 20:48:00+03	29600.00
544E78	2017-08-09 09:19:00+03	133200.00
544F2B	2017-08-11 02:23:00+03	46400.00
544FBF	2017-07-09 06:48:00+03	47700.00
545004	2017-08-09 08:03:00+03	16000.00
545006	2017-08-06 06:26:00+03	52800.00
54502C	2017-08-11 12:12:00+03	301800.00
5450A4	2017-06-28 04:49:00+03	125200.00
5450D2	2017-08-04 07:57:00+03	68800.00
5450FD	2017-08-06 12:11:00+03	75300.00
545125	2017-07-15 11:10:00+03	37900.00
545147	2017-07-29 01:20:00+03	55800.00
54514F	2017-07-06 22:40:00+03	248300.00
54516E	2017-08-14 08:46:00+03	31800.00
545192	2017-07-11 01:58:00+03	40800.00
545195	2017-07-13 17:48:00+03	6000.00
5451C1	2017-06-28 21:09:00+03	14400.00
5451DB	2017-08-06 23:58:00+03	137600.00
54523C	2017-07-05 08:27:00+03	99200.00
545301	2017-07-15 16:21:00+03	62600.00
545325	2017-07-15 11:35:00+03	29400.00
54535B	2017-07-24 21:09:00+03	54400.00
54535F	2017-07-30 16:54:00+03	62800.00
545396	2017-07-09 18:11:00+03	32200.00
545403	2017-07-04 11:44:00+03	52700.00
54542F	2017-08-05 11:36:00+03	139300.00
5454A4	2017-07-16 07:37:00+03	40800.00
54552B	2017-07-09 07:59:00+03	23400.00
545577	2017-08-02 11:33:00+03	92800.00
5455D6	2017-08-13 23:24:00+03	13400.00
545624	2017-07-14 23:30:00+03	37500.00
545634	2017-08-03 11:02:00+03	27400.00
5456A0	2017-07-19 07:46:00+03	56600.00
5456BB	2017-07-05 12:22:00+03	114800.00
5456DA	2017-08-11 18:18:00+03	46400.00
545732	2017-08-10 04:31:00+03	32800.00
545792	2017-07-14 13:36:00+03	71900.00
5457DF	2017-08-11 05:32:00+03	24300.00
5458B0	2017-07-30 06:39:00+03	181100.00
5458D9	2017-08-15 17:22:00+03	129000.00
5458FC	2017-08-03 00:34:00+03	112000.00
545988	2017-07-28 21:20:00+03	187600.00
54598E	2017-07-01 16:24:00+03	19600.00
54599D	2017-08-01 18:04:00+03	38200.00
5459D5	2017-08-02 12:00:00+03	18800.00
545A14	2017-08-07 00:38:00+03	27200.00
545AA5	2017-08-13 11:31:00+03	74000.00
545AC7	2017-07-24 00:49:00+03	104600.00
545B05	2017-07-14 23:41:00+03	20200.00
545B28	2017-07-21 14:24:00+03	23100.00
545B3B	2017-08-02 14:08:00+03	182800.00
545B40	2017-07-18 08:20:00+03	69500.00
545B76	2017-07-28 16:32:00+03	32200.00
545B7E	2017-07-15 00:57:00+03	71800.00
545BA4	2017-08-11 17:23:00+03	49100.00
545BB9	2017-08-09 12:55:00+03	76800.00
545BC9	2017-07-23 01:47:00+03	67900.00
545C44	2017-07-10 08:31:00+03	69600.00
545C6C	2017-07-18 08:07:00+03	135400.00
545C9A	2017-07-02 14:10:00+03	49800.00
545CA4	2017-07-16 16:47:00+03	71900.00
545CD6	2017-08-13 02:55:00+03	32400.00
545D0C	2017-08-05 08:02:00+03	247300.00
545D8C	2017-07-08 00:18:00+03	288800.00
545DAD	2017-07-28 20:34:00+03	81600.00
545DBA	2017-07-31 14:05:00+03	72400.00
545DF3	2017-08-06 01:30:00+03	47100.00
545E23	2017-07-18 02:44:00+03	166100.00
545F0E	2017-08-03 15:51:00+03	174400.00
545F16	2017-07-22 14:49:00+03	292200.00
545F2A	2017-07-21 21:19:00+03	27800.00
545FDF	2017-07-31 15:51:00+03	23200.00
546016	2017-07-06 17:48:00+03	23400.00
546021	2017-07-19 11:13:00+03	59800.00
546023	2017-07-20 12:28:00+03	45200.00
546080	2017-07-05 23:20:00+03	67700.00
5461AF	2017-07-17 20:56:00+03	46400.00
5461D7	2017-08-11 19:27:00+03	39500.00
5461F8	2017-07-18 00:16:00+03	26600.00
546216	2017-07-05 22:47:00+03	20800.00
54621D	2017-08-11 06:31:00+03	62900.00
54622C	2017-07-19 04:46:00+03	88500.00
546242	2017-08-11 01:06:00+03	46200.00
546282	2017-07-20 14:17:00+03	39600.00
546308	2017-07-21 16:23:00+03	52000.00
54636D	2017-08-09 15:37:00+03	170700.00
546373	2017-08-05 08:51:00+03	119500.00
546381	2017-08-07 13:08:00+03	67600.00
54644E	2017-08-07 14:06:00+03	6900.00
546459	2017-07-24 00:10:00+03	26000.00
546464	2017-08-01 02:19:00+03	135600.00
5464B0	2017-07-05 04:52:00+03	71600.00
546526	2017-07-23 19:57:00+03	13600.00
54652D	2017-07-12 05:53:00+03	46200.00
54657A	2017-08-12 08:39:00+03	29400.00
54663E	2017-07-16 23:16:00+03	47800.00
546678	2017-08-13 17:17:00+03	31600.00
54667A	2017-08-06 02:04:00+03	114400.00
5466D1	2017-07-16 06:31:00+03	75300.00
5466FB	2017-07-19 23:16:00+03	25600.00
54676A	2017-08-02 18:42:00+03	47800.00
546779	2017-07-31 01:44:00+03	77900.00
5467C0	2017-07-14 02:46:00+03	14400.00
5467D1	2017-07-29 15:21:00+03	14800.00
546814	2017-08-07 14:47:00+03	24000.00
5468CD	2017-07-28 12:18:00+03	45200.00
5468D0	2017-07-27 11:30:00+03	43400.00
546954	2017-08-14 21:28:00+03	13000.00
54696F	2017-08-02 08:03:00+03	20200.00
5469B4	2017-07-13 12:52:00+03	25200.00
546A14	2017-07-12 19:18:00+03	62200.00
546ABA	2017-07-27 12:11:00+03	46000.00
546ACF	2017-07-28 18:17:00+03	153800.00
546B04	2017-07-16 03:58:00+03	53300.00
546B0F	2017-07-17 15:30:00+03	55800.00
546B28	2017-07-14 06:18:00+03	67600.00
546B5B	2017-08-02 09:05:00+03	40000.00
546C05	2017-07-05 13:48:00+03	36200.00
546C78	2017-07-08 22:28:00+03	33800.00
546CB1	2017-08-11 08:19:00+03	207200.00
546CCD	2017-07-06 18:34:00+03	73300.00
546D1C	2017-07-21 00:00:00+03	67200.00
546D32	2017-07-23 11:34:00+03	99900.00
546D49	2017-08-06 01:42:00+03	22000.00
546D9D	2017-07-11 03:38:00+03	147000.00
546DE5	2017-08-07 01:50:00+03	57500.00
546DF3	2017-08-06 13:05:00+03	47500.00
546DF9	2017-08-06 04:04:00+03	39400.00
546E4F	2017-08-01 11:06:00+03	52700.00
546E92	2017-07-05 12:42:00+03	96600.00
546EDE	2017-07-10 06:36:00+03	22000.00
546EF3	2017-08-01 09:28:00+03	6800.00
546F43	2017-08-01 23:30:00+03	53600.00
5470A0	2017-07-04 04:54:00+03	42400.00
5470A7	2017-07-11 17:11:00+03	67100.00
5470D9	2017-08-03 21:41:00+03	56000.00
5470E9	2017-07-10 02:54:00+03	36600.00
547159	2017-07-02 09:41:00+03	40800.00
547174	2017-08-15 14:25:00+03	24000.00
547185	2017-07-26 16:18:00+03	12000.00
5471C7	2017-08-14 08:08:00+03	50200.00
5471D6	2017-07-05 00:05:00+03	86600.00
547244	2017-08-06 05:29:00+03	108900.00
54726A	2017-07-03 17:19:00+03	101000.00
5472BA	2017-07-14 17:44:00+03	15100.00
5472F7	2017-08-14 02:12:00+03	33300.00
547302	2017-08-02 02:34:00+03	46300.00
54737D	2017-08-14 12:16:00+03	56600.00
5473C7	2017-07-17 01:56:00+03	50400.00
5473CB	2017-07-11 06:12:00+03	125600.00
5473DF	2017-07-09 10:48:00+03	28800.00
547473	2017-07-14 16:50:00+03	26000.00
547514	2017-07-12 13:50:00+03	44500.00
54752C	2017-07-19 07:16:00+03	149000.00
54755F	2017-06-29 15:03:00+03	64100.00
5475EF	2017-07-25 01:07:00+03	117000.00
54763F	2017-07-18 06:50:00+03	214100.00
547692	2017-08-12 18:17:00+03	38400.00
5476BF	2017-07-27 05:57:00+03	83200.00
5476CD	2017-07-05 01:58:00+03	174000.00
547744	2017-08-11 00:41:00+03	97000.00
547751	2017-07-05 21:25:00+03	54100.00
547762	2017-07-07 04:05:00+03	39300.00
547765	2017-07-26 17:24:00+03	95700.00
547768	2017-07-27 17:37:00+03	44500.00
547788	2017-08-13 01:09:00+03	47400.00
547797	2017-08-05 05:08:00+03	39400.00
5477D9	2017-07-28 13:19:00+03	178300.00
547918	2017-07-07 22:35:00+03	56700.00
547937	2017-08-10 05:34:00+03	46400.00
5479CF	2017-08-05 15:56:00+03	104400.00
5479FE	2017-07-18 02:54:00+03	98400.00
547A05	2017-07-13 17:12:00+03	75600.00
547A06	2017-07-19 01:20:00+03	171600.00
547A19	2017-07-02 21:47:00+03	179300.00
547A35	2017-07-30 17:53:00+03	146400.00
547A8B	2017-08-14 17:34:00+03	20500.00
547AA8	2017-06-30 02:00:00+03	6700.00
547B27	2017-07-10 23:04:00+03	84000.00
547B2D	2017-08-15 09:46:00+03	76900.00
547B38	2017-07-05 06:31:00+03	24400.00
547B7A	2017-07-02 20:02:00+03	26500.00
547BD2	2017-07-29 07:08:00+03	78300.00
547C11	2017-08-05 22:36:00+03	112600.00
547C41	2017-07-12 03:37:00+03	114800.00
547D4A	2017-07-05 16:58:00+03	32700.00
547D87	2017-08-06 23:26:00+03	48800.00
547DF7	2017-08-01 03:34:00+03	118100.00
547E20	2017-07-28 00:48:00+03	12600.00
547E24	2017-07-27 13:03:00+03	49100.00
547E31	2017-08-05 00:44:00+03	56000.00
547E36	2017-07-05 13:44:00+03	135600.00
547F11	2017-07-31 21:01:00+03	265700.00
547F98	2017-07-27 08:38:00+03	57500.00
54801D	2017-07-20 19:24:00+03	54000.00
548035	2017-08-02 07:33:00+03	46000.00
548039	2017-07-23 07:21:00+03	39800.00
5480E0	2017-08-02 09:58:00+03	85500.00
54811E	2017-08-13 14:02:00+03	19600.00
54818E	2017-07-09 21:33:00+03	14000.00
5481BC	2017-07-26 23:25:00+03	93700.00
5481D3	2017-08-08 00:02:00+03	237400.00
548227	2017-08-15 01:34:00+03	58400.00
548236	2017-07-04 19:23:00+03	36900.00
54824D	2017-08-02 01:41:00+03	132800.00
548278	2017-08-08 06:41:00+03	284400.00
5482BE	2017-08-08 11:51:00+03	41800.00
548351	2017-07-04 11:33:00+03	56000.00
548359	2017-07-03 03:26:00+03	62800.00
54838D	2017-08-12 05:45:00+03	39300.00
548401	2017-07-27 14:52:00+03	46000.00
54840E	2017-08-14 12:12:00+03	63200.00
548475	2017-07-21 01:58:00+03	55800.00
5484BE	2017-07-01 20:36:00+03	32700.00
5484DF	2017-08-09 01:36:00+03	35600.00
54850F	2017-07-29 15:40:00+03	398500.00
548531	2017-07-18 02:41:00+03	25100.00
548533	2017-07-12 18:43:00+03	26000.00
54861D	2017-07-10 10:24:00+03	26000.00
54869C	2017-07-25 18:41:00+03	23200.00
5486B1	2017-08-15 10:01:00+03	46400.00
5486C9	2017-08-07 22:48:00+03	22000.00
5486E8	2017-07-16 14:09:00+03	234600.00
5486F3	2017-08-12 21:32:00+03	37900.00
548711	2017-08-08 18:40:00+03	48800.00
548737	2017-07-27 18:55:00+03	25400.00
548746	2017-07-15 16:46:00+03	49000.00
54874D	2017-08-03 00:37:00+03	73500.00
548774	2017-08-14 14:29:00+03	535300.00
54879D	2017-07-31 01:16:00+03	42800.00
5487C0	2017-07-23 01:34:00+03	57600.00
548801	2017-08-11 18:53:00+03	21800.00
548864	2017-07-25 07:55:00+03	173200.00
548888	2017-08-04 11:05:00+03	21200.00
5488C8	2017-08-11 03:55:00+03	50800.00
5488F7	2017-08-01 17:53:00+03	10600.00
54891F	2017-07-22 22:44:00+03	24800.00
548940	2017-07-15 13:39:00+03	125200.00
548949	2017-08-02 21:13:00+03	131600.00
5489A9	2017-07-24 13:02:00+03	85000.00
548A1E	2017-08-03 11:21:00+03	96100.00
548A3B	2017-08-15 09:01:00+03	26700.00
548AFF	2017-07-06 02:28:00+03	25600.00
548B36	2017-08-05 13:27:00+03	46000.00
548B45	2017-07-21 08:30:00+03	406100.00
548BCF	2017-08-07 06:32:00+03	31600.00
548BD5	2017-07-18 03:41:00+03	46400.00
548C55	2017-07-21 03:22:00+03	80000.00
548C6F	2017-07-09 10:11:00+03	43700.00
548D27	2017-08-12 22:01:00+03	24800.00
548D5E	2017-08-05 23:39:00+03	86300.00
548EA4	2017-07-18 19:22:00+03	56900.00
548EB4	2017-07-24 07:31:00+03	185000.00
548EEC	2017-08-12 11:45:00+03	89700.00
548F9F	2017-07-11 14:29:00+03	21400.00
548FAC	2017-08-02 19:14:00+03	13400.00
549014	2017-08-06 12:57:00+03	386400.00
549027	2017-08-14 22:06:00+03	13600.00
549091	2017-08-02 01:57:00+03	57400.00
5490E1	2017-07-28 20:26:00+03	8000.00
54910B	2017-07-21 23:43:00+03	56000.00
54913E	2017-06-27 06:34:00+03	117600.00
549143	2017-08-06 19:52:00+03	13400.00
549168	2017-07-03 09:45:00+03	17800.00
5491D3	2017-08-02 11:48:00+03	83300.00
5491DA	2017-08-06 20:25:00+03	24800.00
549208	2017-08-11 00:40:00+03	40000.00
549214	2017-07-01 22:33:00+03	45200.00
549289	2017-07-30 13:29:00+03	133200.00
5492B3	2017-08-14 14:40:00+03	20200.00
5492CD	2017-07-07 00:40:00+03	96800.00
5492E7	2017-08-03 22:30:00+03	103200.00
549319	2017-08-01 01:04:00+03	95600.00
549366	2017-07-18 01:43:00+03	8000.00
549371	2017-07-28 10:10:00+03	13000.00
549392	2017-08-06 19:17:00+03	69100.00
549393	2017-08-08 07:24:00+03	286100.00
54939C	2017-08-08 13:59:00+03	56100.00
5493BC	2017-08-07 07:24:00+03	47100.00
549417	2017-07-09 08:35:00+03	24400.00
549455	2017-06-27 16:50:00+03	67600.00
5494AA	2017-07-22 18:50:00+03	99300.00
5494D0	2017-07-02 01:37:00+03	37900.00
5494F9	2017-08-09 00:18:00+03	180000.00
549532	2017-07-19 20:38:00+03	524400.00
54957D	2017-08-06 21:48:00+03	44600.00
549683	2017-07-08 09:55:00+03	23100.00
54970E	2017-07-08 05:34:00+03	56000.00
549733	2017-08-14 16:30:00+03	53400.00
549782	2017-07-25 01:36:00+03	42800.00
549784	2017-07-24 18:50:00+03	23600.00
54978A	2017-08-02 10:18:00+03	31400.00
5497F9	2017-07-13 14:58:00+03	166100.00
549831	2017-07-26 18:38:00+03	67700.00
54986B	2017-08-10 04:16:00+03	517700.00
549910	2017-07-12 00:58:00+03	92000.00
549945	2017-07-27 08:30:00+03	54300.00
54995C	2017-07-05 16:08:00+03	70700.00
549992	2017-07-29 11:34:00+03	33100.00
5499C1	2017-08-07 21:53:00+03	69000.00
549A28	2017-08-12 22:52:00+03	85000.00
549A48	2017-08-01 05:07:00+03	54500.00
549AC3	2017-08-14 13:58:00+03	22100.00
549ACB	2017-07-13 14:27:00+03	11600.00
549AD6	2017-07-11 20:25:00+03	34000.00
549ADA	2017-06-28 08:13:00+03	24400.00
549B4C	2017-08-14 18:48:00+03	39100.00
549B5B	2017-07-21 09:09:00+03	19600.00
549B67	2017-07-31 13:26:00+03	64300.00
549B84	2017-07-10 21:31:00+03	36200.00
549B8F	2017-08-10 17:02:00+03	46400.00
549C5E	2017-07-05 10:08:00+03	95600.00
549C64	2017-07-19 12:46:00+03	108500.00
549C81	2017-07-10 23:19:00+03	40800.00
549C8F	2017-08-12 07:24:00+03	31400.00
549C99	2017-07-07 23:02:00+03	56600.00
549CB7	2017-08-02 06:11:00+03	198300.00
549CD5	2017-08-06 08:00:00+03	6700.00
549D1B	2017-07-29 15:21:00+03	106100.00
549D40	2017-07-12 21:04:00+03	49500.00
549D7C	2017-07-31 04:25:00+03	13400.00
549D7F	2017-08-08 09:14:00+03	32800.00
549DA8	2017-08-12 09:47:00+03	14800.00
549DD2	2017-07-23 19:45:00+03	26800.00
549E4B	2017-08-05 16:23:00+03	79900.00
549E77	2017-07-28 18:33:00+03	53700.00
549F01	2017-08-05 08:52:00+03	188000.00
549F48	2017-08-05 18:39:00+03	14400.00
549FE2	2017-07-17 18:06:00+03	53300.00
54A012	2017-07-04 00:53:00+03	108600.00
54A058	2017-08-03 17:54:00+03	131000.00
54A07D	2017-07-09 20:59:00+03	135200.00
54A0A0	2017-07-24 15:20:00+03	68100.00
54A0F3	2017-07-04 21:27:00+03	86400.00
54A0F5	2017-07-03 19:36:00+03	80800.00
54A154	2017-07-18 13:25:00+03	39200.00
54A155	2017-07-17 02:18:00+03	38000.00
54A1B0	2017-08-14 05:46:00+03	17000.00
54A21D	2017-07-09 03:45:00+03	135600.00
54A22C	2017-07-05 10:04:00+03	62800.00
54A232	2017-07-09 14:04:00+03	38400.00
54A23B	2017-08-11 00:56:00+03	73400.00
54A266	2017-08-04 03:06:00+03	133200.00
54A276	2017-08-15 16:01:00+03	40100.00
54A28C	2017-07-15 23:06:00+03	104800.00
54A33B	2017-08-13 19:06:00+03	51900.00
54A37E	2017-07-31 22:29:00+03	89600.00
54A380	2017-08-15 00:05:00+03	6300.00
54A3BA	2017-07-18 21:33:00+03	105400.00
54A400	2017-07-31 00:12:00+03	29200.00
54A43A	2017-07-23 17:57:00+03	69700.00
54A56A	2017-08-10 06:14:00+03	56000.00
54A57C	2017-06-27 12:29:00+03	62400.00
54A5A4	2017-06-28 19:46:00+03	13200.00
54A5A9	2017-06-26 08:18:00+03	16400.00
54A5D8	2017-07-15 16:07:00+03	48000.00
54A5EE	2017-07-07 01:40:00+03	50400.00
54A61A	2017-07-28 05:21:00+03	21800.00
54A64E	2017-07-03 00:53:00+03	49500.00
54A66D	2017-08-14 06:59:00+03	15900.00
54A675	2017-08-05 07:59:00+03	181800.00
54A679	2017-07-25 00:18:00+03	27300.00
54A6CB	2017-07-08 03:34:00+03	6600.00
54A6D3	2017-07-13 23:58:00+03	266200.00
54A721	2017-07-01 09:06:00+03	55800.00
54A73F	2017-08-06 05:00:00+03	28000.00
54A79D	2017-07-23 14:25:00+03	23600.00
54A816	2017-07-16 10:12:00+03	56000.00
54A829	2017-08-15 05:22:00+03	212000.00
54A836	2017-07-20 23:49:00+03	28800.00
54A896	2017-08-13 14:52:00+03	93600.00
54A903	2017-07-16 23:52:00+03	48400.00
54A9CC	2017-07-05 07:09:00+03	12200.00
54A9D0	2017-07-21 13:05:00+03	39800.00
54A9DA	2017-07-18 17:31:00+03	56200.00
54AA14	2017-07-10 14:26:00+03	256700.00
54AA2B	2017-08-10 16:12:00+03	51900.00
54AA90	2017-08-15 03:17:00+03	123200.00
54AA92	2017-07-16 05:13:00+03	136800.00
54AADB	2017-07-11 02:52:00+03	56000.00
54AAE4	2017-07-03 07:45:00+03	49100.00
54AB07	2017-08-02 20:52:00+03	52700.00
54AB23	2017-08-02 18:30:00+03	71100.00
54AB2D	2017-08-10 21:37:00+03	28800.00
54AB32	2017-07-18 19:50:00+03	36600.00
54AB3B	2017-07-01 19:18:00+03	50600.00
54AB92	2017-07-07 13:50:00+03	89700.00
54ABFE	2017-07-15 17:00:00+03	12400.00
54AC04	2017-07-15 20:31:00+03	23500.00
54AC13	2017-08-07 11:36:00+03	155500.00
54ACE2	2017-07-28 04:55:00+03	52000.00
54ACE9	2017-08-12 03:58:00+03	38000.00
54AD1F	2017-07-17 04:48:00+03	360400.00
54AD3D	2017-08-13 18:53:00+03	55600.00
54ADA7	2017-08-11 19:31:00+03	54800.00
54ADB9	2017-08-15 01:52:00+03	34000.00
54ADFA	2017-07-19 23:03:00+03	135600.00
54AE01	2017-07-01 15:02:00+03	25600.00
54AE5B	2017-08-10 18:24:00+03	36400.00
54AEA0	2017-08-07 07:16:00+03	100400.00
54AEBF	2017-07-23 11:00:00+03	246000.00
54AEDC	2017-08-11 22:27:00+03	23400.00
54AEEB	2017-07-05 04:51:00+03	100000.00
54AEFB	2017-08-04 19:44:00+03	54800.00
54AF14	2017-08-01 16:09:00+03	28800.00
54AF16	2017-08-02 07:19:00+03	40400.00
54AF25	2017-08-01 20:40:00+03	176400.00
54AFE2	2017-07-06 23:49:00+03	21600.00
54B01A	2017-07-29 12:11:00+03	6800.00
54B03B	2017-07-04 10:32:00+03	71200.00
54B083	2017-07-24 02:45:00+03	20800.00
54B131	2017-07-11 06:01:00+03	136800.00
54B168	2017-08-12 17:15:00+03	23100.00
54B1C7	2017-07-26 13:19:00+03	20400.00
54B2B4	2017-08-13 04:20:00+03	19600.00
54B2C0	2017-08-14 16:28:00+03	49400.00
54B2F6	2017-08-08 00:15:00+03	56000.00
54B316	2017-08-01 03:48:00+03	68100.00
54B391	2017-08-08 11:30:00+03	44000.00
54B3B7	2017-07-29 06:46:00+03	40200.00
54B3E8	2017-08-03 12:04:00+03	100600.00
54B431	2017-07-10 19:11:00+03	47000.00
54B55B	2017-07-15 11:09:00+03	135400.00
54B588	2017-07-10 07:26:00+03	168000.00
54B5A2	2017-08-12 02:40:00+03	97900.00
54B5A5	2017-08-09 19:33:00+03	85600.00
54B5A6	2017-08-11 07:42:00+03	73300.00
54B5EF	2017-08-07 19:17:00+03	65900.00
54B608	2017-08-02 04:02:00+03	76800.00
54B651	2017-07-21 07:49:00+03	290500.00
54B6F0	2017-06-29 22:05:00+03	34400.00
54B74F	2017-08-15 05:16:00+03	23600.00
54B774	2017-07-17 08:49:00+03	9800.00
54B7AE	2017-07-27 08:59:00+03	39200.00
54B7BB	2017-07-30 11:24:00+03	46300.00
54B826	2017-07-03 15:45:00+03	92800.00
54B829	2017-07-15 08:00:00+03	48800.00
54B885	2017-07-11 23:25:00+03	36900.00
54B8F7	2017-06-29 23:48:00+03	249200.00
54B910	2017-07-18 11:58:00+03	131600.00
54B943	2017-07-31 05:06:00+03	92800.00
54B97F	2017-07-24 18:32:00+03	46200.00
54B990	2017-07-23 20:21:00+03	26000.00
54B9D8	2017-07-28 22:05:00+03	113100.00
54BA41	2017-08-12 03:49:00+03	28800.00
54BA68	2017-07-27 07:48:00+03	48800.00
54BAA3	2017-08-03 21:01:00+03	46200.00
54BB2F	2017-08-10 02:28:00+03	13600.00
54BBAC	2017-08-12 16:04:00+03	76200.00
54BBBA	2017-07-15 17:03:00+03	125000.00
54BD02	2017-08-02 13:21:00+03	27200.00
54BD32	2017-07-11 00:55:00+03	12600.00
54BD57	2017-07-12 17:04:00+03	45600.00
54BDB4	2017-08-15 03:28:00+03	12000.00
54BE21	2017-08-10 04:39:00+03	37900.00
54BE47	2017-08-14 16:36:00+03	13300.00
54BE64	2017-07-17 05:42:00+03	54000.00
54BEB7	2017-08-02 05:47:00+03	119600.00
54BEE1	2017-07-31 17:13:00+03	70700.00
54BF21	2017-07-06 19:03:00+03	56000.00
54BF3A	2017-08-04 20:56:00+03	232700.00
54BF54	2017-07-12 18:48:00+03	71200.00
54BF57	2017-07-31 06:38:00+03	60300.00
54BFAA	2017-08-06 16:19:00+03	13400.00
54C028	2017-08-14 09:48:00+03	23100.00
54C084	2017-08-12 01:37:00+03	44800.00
54C0EA	2017-07-15 02:05:00+03	56300.00
54C12A	2017-07-21 15:13:00+03	49100.00
54C139	2017-07-28 09:31:00+03	61800.00
54C1A3	2017-07-09 15:28:00+03	119000.00
54C1AE	2017-07-09 07:31:00+03	57700.00
54C251	2017-08-09 19:44:00+03	132800.00
54C25E	2017-07-11 02:45:00+03	30000.00
54C2B9	2017-06-30 09:53:00+03	37900.00
54C2D9	2017-07-09 18:00:00+03	17000.00
54C2F1	2017-08-11 22:14:00+03	10600.00
54C30F	2017-07-04 17:51:00+03	25600.00
54C38C	2017-08-04 01:03:00+03	6700.00
54C41B	2017-07-26 15:15:00+03	37400.00
54C4A8	2017-08-09 02:44:00+03	48100.00
54C4B6	2017-07-27 07:26:00+03	56600.00
54C4C8	2017-08-06 04:01:00+03	25600.00
54C4E8	2017-07-02 07:40:00+03	109600.00
54C516	2017-08-13 00:05:00+03	13600.00
54C53D	2017-07-06 23:41:00+03	57600.00
54C59E	2017-08-13 05:40:00+03	149700.00
54C5A0	2017-07-25 01:54:00+03	55800.00
54C5EA	2017-07-20 21:09:00+03	52000.00
54C616	2017-07-08 03:25:00+03	47700.00
54C635	2017-07-16 14:44:00+03	23200.00
54C69D	2017-07-23 20:31:00+03	42700.00
54C6D5	2017-07-02 16:02:00+03	75300.00
54C705	2017-07-21 04:34:00+03	25600.00
54C728	2017-08-13 05:04:00+03	24000.00
54C77C	2017-08-06 13:12:00+03	86600.00
54C77E	2017-08-12 13:15:00+03	96500.00
54C78D	2017-08-03 01:34:00+03	46400.00
54C834	2017-07-13 07:36:00+03	31700.00
54C851	2017-07-29 05:17:00+03	83300.00
54C85B	2017-08-08 11:11:00+03	125900.00
54C85D	2017-07-06 13:31:00+03	21200.00
54C879	2017-07-07 11:11:00+03	59200.00
54C8AC	2017-07-21 06:51:00+03	67800.00
54C8BC	2017-07-04 09:35:00+03	38400.00
54C8E1	2017-07-14 14:14:00+03	136200.00
54C960	2017-07-05 12:05:00+03	6700.00
54CA0A	2017-07-20 16:17:00+03	40600.00
54CA10	2017-07-09 19:44:00+03	10600.00
54CABC	2017-07-11 23:29:00+03	30200.00
54CBAB	2017-07-20 09:25:00+03	7800.00
54CBE0	2017-08-06 21:19:00+03	28400.00
54CC79	2017-07-22 04:42:00+03	246000.00
54CC8D	2017-08-13 09:39:00+03	76600.00
54CC9A	2017-07-08 23:29:00+03	46800.00
54CCA6	2017-07-11 18:27:00+03	198000.00
54CCC8	2017-07-14 15:19:00+03	265700.00
54CCCA	2017-07-09 21:05:00+03	47400.00
54CD0C	2017-07-08 13:23:00+03	28000.00
54CD0D	2017-07-20 16:21:00+03	26800.00
54CD3A	2017-07-14 21:44:00+03	40400.00
54CD40	2017-07-10 01:01:00+03	27200.00
54CDBF	2017-07-29 05:50:00+03	36200.00
54CDE7	2017-07-30 01:24:00+03	32800.00
54CDF1	2017-08-13 23:14:00+03	19200.00
54CE7E	2017-07-15 18:16:00+03	106900.00
54CE83	2017-08-04 19:08:00+03	54000.00
54CEBD	2017-07-21 22:25:00+03	42400.00
54CF13	2017-07-17 09:42:00+03	135400.00
54CF42	2017-07-27 15:25:00+03	246000.00
54CF4B	2017-07-02 03:23:00+03	67600.00
54CFB6	2017-08-15 06:03:00+03	76800.00
54CFC9	2017-08-12 14:31:00+03	75900.00
54D02B	2017-07-06 11:09:00+03	24200.00
54D068	2017-08-01 15:27:00+03	61800.00
54D080	2017-08-11 09:23:00+03	34000.00
54D0F0	2017-07-28 05:25:00+03	51900.00
54D108	2017-07-16 11:29:00+03	25200.00
54D15B	2017-08-14 08:35:00+03	13400.00
54D178	2017-07-22 03:19:00+03	24400.00
54D1A5	2017-07-10 16:56:00+03	43600.00
54D1AD	2017-08-04 04:25:00+03	96800.00
54D1BE	2017-07-25 04:37:00+03	56000.00
54D1C1	2017-08-12 03:44:00+03	48700.00
54D1E8	2017-08-07 00:53:00+03	30000.00
54D24C	2017-08-05 01:47:00+03	54200.00
54D25C	2017-07-29 12:36:00+03	100600.00
54D28C	2017-08-02 07:52:00+03	52000.00
54D34A	2017-07-19 03:56:00+03	21400.00
54D371	2017-08-14 17:26:00+03	180200.00
54D383	2017-07-13 00:06:00+03	26800.00
54D3BD	2017-07-11 12:56:00+03	71900.00
54D3BF	2017-07-30 20:27:00+03	66800.00
54D3CB	2017-07-11 03:37:00+03	8200.00
54D3EE	2017-07-20 12:26:00+03	15000.00
54D467	2017-08-05 20:00:00+03	46200.00
54D481	2017-07-12 06:53:00+03	12400.00
54D49A	2017-07-08 10:36:00+03	68100.00
54D4FE	2017-06-25 02:45:00+03	40800.00
54D53A	2017-07-31 01:12:00+03	71200.00
54D545	2017-08-06 04:00:00+03	29200.00
54D5AA	2017-07-30 05:18:00+03	19600.00
54D5C2	2017-08-14 00:59:00+03	67600.00
54D5D1	2017-07-28 01:28:00+03	64500.00
54D5FB	2017-08-09 02:38:00+03	186900.00
54D625	2017-07-12 15:27:00+03	27700.00
54D644	2017-08-09 04:16:00+03	393000.00
54D6C5	2017-08-06 07:38:00+03	51900.00
54D717	2017-07-25 14:37:00+03	37900.00
54D734	2017-08-07 21:39:00+03	26800.00
54D74C	2017-06-28 13:18:00+03	50800.00
54D76D	2017-08-07 19:44:00+03	111700.00
54D7D9	2017-08-02 14:58:00+03	46300.00
54D7F8	2017-07-16 07:00:00+03	101200.00
54D80F	2017-08-04 10:56:00+03	129200.00
54D87D	2017-07-30 03:09:00+03	34000.00
54D8F0	2017-08-05 21:33:00+03	16000.00
54D9A1	2017-07-13 18:22:00+03	36800.00
54D9C5	2017-08-14 05:30:00+03	15700.00
54DA9B	2017-07-01 10:05:00+03	42800.00
54DAB5	2017-08-07 11:45:00+03	31200.00
54DB1D	2017-07-03 07:50:00+03	6800.00
54DB4C	2017-08-15 12:22:00+03	54600.00
54DB8C	2017-07-04 17:58:00+03	39200.00
54DB8D	2017-07-28 09:20:00+03	28000.00
54DC48	2017-07-06 13:43:00+03	145500.00
54DCFC	2017-08-08 08:13:00+03	73500.00
54DD13	2017-07-26 00:50:00+03	538100.00
54DD74	2017-07-02 10:57:00+03	91700.00
54DDC5	2017-08-07 17:31:00+03	123000.00
54DDDB	2017-07-05 06:00:00+03	182300.00
54DE07	2017-08-13 13:19:00+03	11700.00
54DE1B	2017-08-12 07:38:00+03	80800.00
54DE25	2017-07-20 05:20:00+03	6000.00
54DE5D	2017-07-29 08:54:00+03	51100.00
54DE72	2017-08-01 19:41:00+03	135400.00
54DE73	2017-07-29 01:25:00+03	130100.00
54DE79	2017-08-12 22:02:00+03	14000.00
54DEAB	2017-08-15 01:35:00+03	26000.00
54DEBA	2017-07-14 13:26:00+03	46400.00
54DED3	2017-07-22 21:03:00+03	29400.00
54DF2C	2017-07-15 05:07:00+03	34000.00
54DF71	2017-07-17 22:38:00+03	231200.00
54DFA1	2017-08-13 01:53:00+03	174400.00
54DFAD	2017-08-13 20:02:00+03	99700.00
54DFC4	2017-07-05 16:38:00+03	48800.00
54E043	2017-07-11 14:03:00+03	28000.00
54E04E	2017-07-22 00:26:00+03	25600.00
54E06A	2017-08-10 03:19:00+03	37900.00
54E09A	2017-08-13 07:34:00+03	26800.00
54E114	2017-07-08 18:28:00+03	53600.00
54E18B	2017-08-14 00:08:00+03	56600.00
54E1BF	2017-07-23 00:34:00+03	21800.00
54E1D0	2017-07-13 11:32:00+03	32800.00
54E1E7	2017-07-29 22:22:00+03	149200.00
54E1FF	2017-08-10 20:19:00+03	58600.00
54E219	2017-08-12 20:34:00+03	85000.00
54E239	2017-08-12 03:13:00+03	26700.00
54E24F	2017-07-10 11:07:00+03	67600.00
54E267	2017-07-23 20:13:00+03	46400.00
54E26F	2017-07-31 22:55:00+03	13200.00
54E280	2017-08-12 15:17:00+03	36200.00
54E2D6	2017-07-23 13:41:00+03	65400.00
54E474	2017-08-04 05:40:00+03	55800.00
54E518	2017-08-14 00:23:00+03	133200.00
54E52A	2017-08-08 15:16:00+03	59200.00
54E5BF	2017-07-12 03:07:00+03	65600.00
54E5C5	2017-07-04 16:29:00+03	59800.00
54E5E1	2017-07-03 00:23:00+03	75300.00
54E677	2017-07-14 14:10:00+03	108500.00
54E67A	2017-08-13 11:30:00+03	30000.00
54E6B8	2017-08-13 08:58:00+03	135600.00
54E6E3	2017-07-30 20:27:00+03	40600.00
54E6F1	2017-07-20 10:26:00+03	398500.00
54E703	2017-07-08 03:54:00+03	72400.00
54E729	2017-07-17 07:45:00+03	44800.00
54E73E	2017-08-06 13:24:00+03	40800.00
54E760	2017-06-28 14:34:00+03	75300.00
54E7DA	2017-07-12 10:58:00+03	56200.00
54E87C	2017-07-25 14:38:00+03	26500.00
54E886	2017-08-02 12:36:00+03	60400.00
54E93C	2017-06-29 02:48:00+03	12000.00
54EA44	2017-07-01 05:36:00+03	99300.00
54EA48	2017-07-21 18:46:00+03	76400.00
54EA52	2017-07-06 15:32:00+03	199600.00
54EA73	2017-07-20 11:12:00+03	287200.00
54EAF7	2017-07-31 08:31:00+03	44600.00
54EAF8	2017-07-09 23:08:00+03	51600.00
54EB43	2017-07-21 00:34:00+03	72300.00
54EBAF	2017-07-22 21:32:00+03	3700.00
54EBF4	2017-08-10 02:12:00+03	56000.00
54EC25	2017-07-25 09:23:00+03	99300.00
54EC3C	2017-07-08 23:22:00+03	133100.00
54EC75	2017-07-12 14:30:00+03	52900.00
54EC7F	2017-07-25 05:43:00+03	75300.00
54EC8A	2017-08-03 05:37:00+03	57600.00
54ECB8	2017-08-06 11:29:00+03	610400.00
54ECD8	2017-08-13 22:11:00+03	16400.00
54ECED	2017-06-30 02:15:00+03	28000.00
54ED30	2017-07-20 18:21:00+03	36200.00
54ED92	2017-08-10 00:33:00+03	313800.00
54EDB8	2017-08-07 11:52:00+03	164700.00
54EDF8	2017-07-18 13:11:00+03	102000.00
54EE33	2017-07-28 13:54:00+03	44000.00
54EE7D	2017-07-20 19:51:00+03	26700.00
54EE81	2017-08-14 02:20:00+03	106300.00
54EE86	2017-07-19 03:29:00+03	99200.00
54EEC0	2017-08-11 14:13:00+03	160700.00
54EEED	2017-07-02 20:16:00+03	28000.00
54EEFE	2017-08-10 19:42:00+03	46200.00
54EF01	2017-07-15 04:21:00+03	92800.00
54EF33	2017-07-14 07:22:00+03	62200.00
54EF3E	2017-08-14 01:16:00+03	84300.00
54EF9A	2017-07-23 12:36:00+03	77600.00
54EFD0	2017-07-11 07:56:00+03	201200.00
54EFF6	2017-08-01 06:04:00+03	112000.00
54EFF9	2017-08-15 10:32:00+03	28800.00
54F02C	2017-07-11 09:37:00+03	106500.00
54F047	2017-07-26 23:37:00+03	87000.00
54F060	2017-07-03 02:23:00+03	43600.00
54F062	2017-08-15 11:51:00+03	181000.00
54F0C2	2017-07-09 00:41:00+03	47400.00
54F0C8	2017-08-04 01:49:00+03	166100.00
54F0D8	2017-07-23 03:03:00+03	116900.00
54F126	2017-07-08 00:00:00+03	48800.00
54F147	2017-07-30 14:45:00+03	56000.00
54F17E	2017-07-15 08:14:00+03	72200.00
54F1CD	2017-07-05 16:58:00+03	333600.00
54F221	2017-07-27 10:13:00+03	28000.00
54F246	2017-07-20 04:32:00+03	195500.00
54F297	2017-07-08 19:46:00+03	12600.00
54F2A8	2017-07-03 09:40:00+03	56000.00
54F2AF	2017-07-24 11:42:00+03	8200.00
54F2FD	2017-08-13 20:01:00+03	20200.00
54F33F	2017-07-21 15:14:00+03	46000.00
54F343	2017-07-09 05:01:00+03	111600.00
54F360	2017-08-14 11:23:00+03	44500.00
54F3BC	2017-08-13 05:38:00+03	54400.00
54F5DF	2017-07-08 18:23:00+03	23200.00
54F5F6	2017-08-13 12:27:00+03	89200.00
54F5F9	2017-08-06 15:32:00+03	66800.00
54F62F	2017-08-06 09:30:00+03	25600.00
54F699	2017-08-02 04:33:00+03	15000.00
54F6B3	2017-08-14 15:35:00+03	31000.00
54F6C3	2017-08-02 19:27:00+03	119600.00
54F6CC	2017-07-26 04:23:00+03	265700.00
54F75D	2017-07-27 04:13:00+03	25600.00
54F78D	2017-08-04 22:02:00+03	61800.00
54F79A	2017-08-01 17:37:00+03	10800.00
54F7BF	2017-08-11 02:57:00+03	62000.00
54F7F6	2017-08-01 10:25:00+03	317600.00
54F84D	2017-07-18 02:44:00+03	52900.00
54F90C	2017-08-09 16:30:00+03	4000.00
54F99B	2017-07-25 23:30:00+03	64300.00
54F99F	2017-07-03 08:45:00+03	41900.00
54F9C0	2017-07-17 14:52:00+03	26000.00
54F9DE	2017-08-03 15:29:00+03	28000.00
54F9E8	2017-07-02 23:56:00+03	125400.00
54FA3B	2017-06-27 04:13:00+03	33300.00
54FA61	2017-08-11 08:34:00+03	66000.00
54FAE1	2017-08-11 18:17:00+03	26800.00
54FB0D	2017-07-12 08:33:00+03	46800.00
54FB1E	2017-08-12 09:41:00+03	21000.00
54FB36	2017-07-10 07:51:00+03	133200.00
54FB65	2017-07-20 17:38:00+03	6700.00
54FB9A	2017-07-09 11:52:00+03	12600.00
54FBC5	2017-08-15 07:50:00+03	81700.00
54FBF1	2017-07-10 02:10:00+03	75600.00
54FBFD	2017-07-16 21:39:00+03	56000.00
54FC61	2017-07-03 22:48:00+03	47500.00
54FCD4	2017-07-27 14:16:00+03	289800.00
54FD1A	2017-08-02 08:47:00+03	24800.00
54FD6A	2017-07-09 16:11:00+03	379000.00
54FD75	2017-07-12 12:27:00+03	26000.00
54FD8B	2017-07-16 04:24:00+03	48800.00
54FDF4	2017-07-11 04:13:00+03	53500.00
54FE38	2017-07-26 18:23:00+03	70800.00
54FE41	2017-08-13 08:45:00+03	41900.00
54FE51	2017-07-09 21:31:00+03	16400.00
54FEEC	2017-08-07 17:31:00+03	59000.00
550006	2017-07-02 01:56:00+03	37700.00
55001D	2017-07-18 13:01:00+03	101100.00
5500B6	2017-08-15 03:53:00+03	112000.00
550178	2017-08-12 13:30:00+03	38400.00
550180	2017-08-06 13:36:00+03	265600.00
5501FE	2017-08-13 10:45:00+03	19600.00
550212	2017-07-17 01:45:00+03	22000.00
55022F	2017-08-09 16:43:00+03	67600.00
550279	2017-07-05 21:10:00+03	44800.00
55034F	2017-08-12 03:19:00+03	14400.00
550375	2017-08-07 11:30:00+03	50000.00
5503C0	2017-06-28 17:04:00+03	153300.00
5503D3	2017-07-06 14:58:00+03	26000.00
550424	2017-08-14 00:44:00+03	57600.00
5504AC	2017-07-14 07:24:00+03	64400.00
5504C1	2017-07-31 02:53:00+03	125200.00
5504D1	2017-06-30 01:58:00+03	47000.00
55058B	2017-07-25 20:22:00+03	89200.00
5505AE	2017-07-18 20:24:00+03	55800.00
55061D	2017-07-10 12:41:00+03	76600.00
550635	2017-07-26 09:49:00+03	36600.00
55067F	2017-08-06 22:09:00+03	57500.00
550723	2017-07-06 11:59:00+03	39500.00
550724	2017-08-08 16:58:00+03	55000.00
5507BD	2017-07-16 23:54:00+03	126500.00
5507CA	2017-07-23 22:37:00+03	86400.00
5507FD	2017-07-20 18:41:00+03	21600.00
550822	2017-07-30 00:36:00+03	339900.00
550860	2017-07-02 00:45:00+03	98000.00
55088B	2017-08-01 22:43:00+03	83400.00
5508C5	2017-07-25 12:46:00+03	57600.00
5508E8	2017-07-19 02:32:00+03	199200.00
5508FE	2017-08-15 08:08:00+03	40800.00
55093D	2017-07-31 05:40:00+03	46400.00
55093F	2017-07-01 04:04:00+03	86300.00
550949	2017-07-07 03:48:00+03	32600.00
550967	2017-07-17 15:41:00+03	21400.00
5509B8	2017-07-10 01:36:00+03	73600.00
550A01	2017-07-30 13:17:00+03	32900.00
550A40	2017-08-10 09:29:00+03	28000.00
550AC4	2017-07-03 15:14:00+03	29600.00
550B3D	2017-07-17 12:05:00+03	6000.00
550B7F	2017-07-30 06:49:00+03	26000.00
550B89	2017-07-28 22:45:00+03	125800.00
550B95	2017-07-31 22:20:00+03	40800.00
550D36	2017-07-13 10:39:00+03	46400.00
550D5C	2017-07-04 10:57:00+03	26700.00
550DBD	2017-08-08 01:23:00+03	57700.00
550DBE	2017-07-26 20:30:00+03	8200.00
550DC9	2017-08-05 01:48:00+03	12400.00
550DCA	2017-08-06 21:57:00+03	31200.00
550DED	2017-08-13 03:54:00+03	177200.00
550DF7	2017-08-09 12:42:00+03	56900.00
550E1C	2017-08-03 23:54:00+03	10800.00
550EAC	2017-07-06 17:44:00+03	148200.00
550EB2	2017-08-05 06:05:00+03	111600.00
550F37	2017-07-01 20:03:00+03	29300.00
550F73	2017-07-31 08:10:00+03	23600.00
550F76	2017-08-08 12:56:00+03	48500.00
550F9B	2017-07-15 16:43:00+03	40800.00
550FEA	2017-07-07 20:44:00+03	59000.00
550FFF	2017-07-12 20:35:00+03	23200.00
551013	2017-07-24 00:37:00+03	92600.00
55109A	2017-08-15 06:22:00+03	6300.00
551100	2017-07-06 21:31:00+03	27200.00
551117	2017-07-23 14:12:00+03	90000.00
5511BB	2017-08-14 22:18:00+03	44300.00
551223	2017-07-05 22:38:00+03	10800.00
551275	2017-08-01 21:24:00+03	94800.00
5512A1	2017-06-27 02:50:00+03	217600.00
5512B1	2017-07-26 14:35:00+03	29400.00
551304	2017-08-06 23:11:00+03	23200.00
551320	2017-08-06 03:58:00+03	35200.00
55133F	2017-07-29 00:00:00+03	26800.00
55135F	2017-07-27 16:01:00+03	112000.00
55138E	2017-08-06 12:24:00+03	29400.00
55139A	2017-07-15 19:51:00+03	28800.00
5513F7	2017-06-30 09:06:00+03	55800.00
551436	2017-07-30 12:43:00+03	6800.00
55148E	2017-07-28 04:25:00+03	149000.00
5514EC	2017-07-07 14:52:00+03	189100.00
5514EE	2017-08-11 01:09:00+03	20400.00
551550	2017-07-06 17:34:00+03	58400.00
5515A1	2017-07-30 17:55:00+03	261700.00
5515B1	2017-08-11 11:07:00+03	25000.00
5515C1	2017-07-11 21:24:00+03	281500.00
5515C9	2017-08-08 05:46:00+03	369000.00
55161B	2017-07-01 13:10:00+03	40900.00
551624	2017-07-22 14:56:00+03	58800.00
551628	2017-07-09 11:24:00+03	136700.00
55164A	2017-08-13 12:12:00+03	12000.00
551657	2017-07-30 11:59:00+03	151200.00
551660	2017-08-12 10:13:00+03	75600.00
55171E	2017-07-08 16:42:00+03	55800.00
551733	2017-07-23 06:34:00+03	6300.00
5517F8	2017-07-31 19:09:00+03	67600.00
551802	2017-08-15 06:02:00+03	94300.00
551851	2017-07-06 10:18:00+03	133200.00
55185C	2017-07-16 01:59:00+03	19600.00
55187E	2017-07-26 23:56:00+03	23100.00
551897	2017-07-11 20:50:00+03	86500.00
55189F	2017-07-10 03:48:00+03	34100.00
5518AF	2017-08-05 17:39:00+03	46000.00
551914	2017-07-19 10:30:00+03	96800.00
551961	2017-07-12 11:14:00+03	62700.00
55197B	2017-07-24 03:51:00+03	91000.00
5519FA	2017-07-03 02:19:00+03	21800.00
551A3A	2017-08-06 05:43:00+03	44800.00
551B2E	2017-07-05 05:31:00+03	112100.00
551B62	2017-07-10 12:25:00+03	26000.00
551B67	2017-07-29 08:55:00+03	56000.00
551BDD	2017-07-03 21:45:00+03	23200.00
551BF2	2017-07-17 01:41:00+03	125600.00
551BFD	2017-07-08 08:36:00+03	111600.00
551C2C	2017-08-09 03:00:00+03	6700.00
551CAE	2017-07-07 19:44:00+03	23400.00
551CBC	2017-07-23 11:01:00+03	19600.00
551CDE	2017-07-18 16:57:00+03	46000.00
551DC7	2017-07-12 20:28:00+03	25600.00
551DE7	2017-07-21 17:33:00+03	187600.00
551DF3	2017-08-01 07:27:00+03	25600.00
551E02	2017-08-02 22:38:00+03	213200.00
551E36	2017-06-29 15:02:00+03	27200.00
551EC9	2017-07-01 07:26:00+03	28000.00
551ECB	2017-07-12 00:01:00+03	23100.00
551EDD	2017-07-25 09:26:00+03	8200.00
551EEB	2017-08-12 01:45:00+03	3400.00
551F7F	2017-08-08 07:38:00+03	118900.00
551F93	2017-07-20 10:38:00+03	40300.00
551FE3	2017-08-10 16:26:00+03	38400.00
552018	2017-07-19 23:35:00+03	12400.00
552035	2017-07-24 20:07:00+03	17200.00
5520BB	2017-07-31 16:04:00+03	65500.00
5520C0	2017-07-10 08:22:00+03	532800.00
5520F4	2017-07-24 00:14:00+03	126300.00
552104	2017-07-11 17:58:00+03	23200.00
5521F7	2017-07-17 22:40:00+03	22000.00
552265	2017-07-04 11:47:00+03	77500.00
5522A4	2017-07-16 03:25:00+03	26000.00
552318	2017-07-23 09:55:00+03	28000.00
55237E	2017-08-04 22:28:00+03	106500.00
5523AA	2017-08-10 18:24:00+03	14000.00
5523B9	2017-08-04 13:54:00+03	123000.00
5523D6	2017-07-20 18:34:00+03	19600.00
552407	2017-08-06 13:33:00+03	68100.00
552409	2017-08-11 01:21:00+03	68800.00
552430	2017-08-13 21:08:00+03	82900.00
552434	2017-07-06 21:53:00+03	200200.00
552489	2017-07-26 09:54:00+03	14000.00
55249F	2017-08-12 17:20:00+03	51800.00
55251F	2017-07-23 15:45:00+03	23200.00
55252B	2017-07-07 18:15:00+03	65500.00
552539	2017-07-25 13:51:00+03	40800.00
55257E	2017-07-23 20:38:00+03	112600.00
55258C	2017-07-26 08:30:00+03	78000.00
5525B5	2017-08-03 15:52:00+03	272400.00
5525F4	2017-07-02 04:03:00+03	109600.00
552600	2017-08-04 06:58:00+03	94000.00
552619	2017-08-07 09:06:00+03	22600.00
55268A	2017-07-27 21:43:00+03	23600.00
55268F	2017-08-03 09:01:00+03	55800.00
5526B9	2017-06-28 06:07:00+03	56900.00
5526C5	2017-07-27 16:38:00+03	136500.00
5526E9	2017-08-11 22:11:00+03	64100.00
552701	2017-08-06 09:29:00+03	43600.00
55270C	2017-07-21 02:31:00+03	79600.00
552730	2017-07-01 08:20:00+03	118800.00
552733	2017-07-19 11:46:00+03	38400.00
552735	2017-08-07 01:14:00+03	32800.00
552775	2017-07-05 03:31:00+03	187800.00
552788	2017-07-31 09:00:00+03	49800.00
5527CA	2017-07-04 16:52:00+03	28000.00
552806	2017-07-13 04:11:00+03	122500.00
55282D	2017-08-14 00:07:00+03	136500.00
552875	2017-08-07 05:54:00+03	21200.00
55293E	2017-07-01 23:00:00+03	75600.00
55295E	2017-07-13 12:36:00+03	27200.00
552988	2017-08-09 15:36:00+03	35900.00
552995	2017-07-29 22:38:00+03	50000.00
552996	2017-07-25 13:29:00+03	102100.00
5529A8	2017-07-30 13:06:00+03	28700.00
5529D8	2017-07-23 14:23:00+03	35700.00
5529DC	2017-07-18 11:59:00+03	95100.00
5529EC	2017-07-29 00:47:00+03	13000.00
5529EF	2017-08-10 06:27:00+03	28000.00
5529F0	2017-07-15 20:35:00+03	68800.00
552A1D	2017-07-13 23:34:00+03	209100.00
552AB6	2017-08-04 14:05:00+03	313200.00
552AE0	2017-07-08 01:53:00+03	69500.00
552AF6	2017-07-30 21:21:00+03	9800.00
552B0E	2017-07-19 15:47:00+03	32800.00
552B20	2017-07-28 09:47:00+03	73600.00
552B54	2017-08-15 17:36:00+03	51900.00
552B90	2017-07-22 17:54:00+03	112000.00
552BA8	2017-07-28 17:15:00+03	167400.00
552BDF	2017-07-09 22:53:00+03	123000.00
552C04	2017-07-24 16:24:00+03	36200.00
552C75	2017-08-09 09:08:00+03	88100.00
552CAC	2017-07-06 06:41:00+03	43600.00
552CDF	2017-07-23 10:26:00+03	156500.00
552D4E	2017-07-05 03:45:00+03	28700.00
552D8C	2017-07-22 11:49:00+03	46300.00
552DA1	2017-08-12 21:03:00+03	47000.00
552DE9	2017-07-13 19:34:00+03	28000.00
552DF7	2017-08-10 01:20:00+03	135600.00
552E0A	2017-08-12 04:57:00+03	199200.00
552E94	2017-07-20 17:08:00+03	92600.00
552E9F	2017-08-08 02:00:00+03	169300.00
552EBD	2017-07-10 00:36:00+03	17800.00
552EDC	2017-08-07 10:50:00+03	56100.00
552F07	2017-08-11 07:54:00+03	24400.00
552F1F	2017-08-07 16:26:00+03	28000.00
55300D	2017-07-23 22:59:00+03	243400.00
553052	2017-08-05 10:53:00+03	42800.00
553146	2017-08-12 07:05:00+03	175200.00
553193	2017-07-03 23:07:00+03	270400.00
553242	2017-07-11 14:31:00+03	65300.00
55325B	2017-07-06 09:50:00+03	85000.00
5532D5	2017-07-27 23:31:00+03	23100.00
5532F7	2017-07-24 00:38:00+03	48800.00
553362	2017-08-07 11:17:00+03	92900.00
5533CB	2017-07-24 01:02:00+03	166900.00
5533D5	2017-08-05 00:35:00+03	37100.00
55342D	2017-07-19 01:21:00+03	43600.00
55349A	2017-07-04 06:45:00+03	155600.00
5534EF	2017-07-10 03:13:00+03	169600.00
553536	2017-07-04 02:33:00+03	133200.00
553557	2017-07-22 00:49:00+03	10800.00
55357A	2017-07-13 08:48:00+03	56200.00
55357B	2017-07-05 10:25:00+03	7400.00
553599	2017-08-13 19:09:00+03	108800.00
5535C2	2017-08-07 17:27:00+03	147600.00
553617	2017-08-10 10:21:00+03	35200.00
55361B	2017-07-17 05:26:00+03	210000.00
55368A	2017-07-04 09:01:00+03	67000.00
553698	2017-08-01 11:29:00+03	68900.00
5536AB	2017-07-02 09:37:00+03	14800.00
5536C5	2017-07-14 23:47:00+03	27500.00
553703	2017-08-04 07:57:00+03	28000.00
553765	2017-07-29 13:53:00+03	46000.00
5537FE	2017-07-26 21:38:00+03	133200.00
553815	2017-07-26 20:41:00+03	270700.00
55389F	2017-07-05 11:47:00+03	106300.00
5538DF	2017-07-21 03:24:00+03	89800.00
5538F1	2017-08-13 16:57:00+03	141200.00
55390E	2017-07-13 07:31:00+03	62700.00
55392B	2017-07-31 04:08:00+03	208100.00
553974	2017-07-09 16:44:00+03	100600.00
5539EB	2017-07-20 17:42:00+03	112600.00
5539EF	2017-08-15 01:33:00+03	6600.00
553A05	2017-08-12 02:16:00+03	137900.00
553A14	2017-07-14 10:19:00+03	76600.00
553A27	2017-08-06 09:49:00+03	31600.00
553A92	2017-07-27 18:46:00+03	20200.00
553AA2	2017-07-20 23:20:00+03	46300.00
553AD7	2017-07-19 04:40:00+03	10100.00
553B70	2017-08-08 13:29:00+03	102100.00
553B95	2017-07-20 22:07:00+03	10600.00
553BAB	2017-07-23 00:43:00+03	140100.00
553BD3	2017-08-11 11:21:00+03	67200.00
553C10	2017-07-25 10:52:00+03	26000.00
553C1F	2017-07-10 23:14:00+03	54400.00
553C6E	2017-07-16 13:16:00+03	72400.00
553C73	2017-07-01 19:39:00+03	102300.00
553C77	2017-08-03 21:05:00+03	283100.00
553C84	2017-07-05 01:06:00+03	112600.00
553CA8	2017-07-03 09:24:00+03	129200.00
553CB5	2017-07-18 06:39:00+03	52000.00
553CCA	2017-08-03 16:16:00+03	15800.00
553CFD	2017-08-08 08:10:00+03	57800.00
553D18	2017-06-30 09:36:00+03	23600.00
553D21	2017-08-09 12:12:00+03	24200.00
553D71	2017-07-20 11:26:00+03	40000.00
553E18	2017-07-11 08:34:00+03	20800.00
553E48	2017-07-29 22:56:00+03	40800.00
553F18	2017-08-05 16:19:00+03	20400.00
553F93	2017-08-12 15:46:00+03	21400.00
553FAB	2017-07-28 23:38:00+03	177600.00
553FD1	2017-07-01 14:06:00+03	240600.00
553FE4	2017-07-20 07:32:00+03	87900.00
553FE9	2017-07-16 06:22:00+03	37500.00
554023	2017-07-22 17:16:00+03	24800.00
5540C1	2017-07-05 17:34:00+03	89900.00
5540F9	2017-08-08 20:23:00+03	265600.00
554106	2017-08-15 17:33:00+03	28800.00
554108	2017-06-29 13:09:00+03	193700.00
554183	2017-07-22 16:49:00+03	91600.00
5541EF	2017-07-27 20:57:00+03	52800.00
554202	2017-07-10 23:03:00+03	198600.00
554222	2017-07-30 08:53:00+03	131100.00
554253	2017-08-07 16:57:00+03	14100.00
55426A	2017-06-28 17:29:00+03	10800.00
5542B2	2017-08-03 17:48:00+03	52000.00
5542CF	2017-08-14 00:42:00+03	179300.00
554316	2017-07-15 19:42:00+03	125200.00
55432D	2017-07-01 12:28:00+03	54800.00
554340	2017-06-25 19:04:00+03	36200.00
554499	2017-08-11 23:54:00+03	97500.00
554552	2017-08-13 17:54:00+03	62900.00
55455F	2017-07-25 04:55:00+03	43200.00
554599	2017-08-02 10:27:00+03	198400.00
55459F	2017-07-31 18:58:00+03	29800.00
5545AC	2017-08-05 05:05:00+03	28000.00
5545BE	2017-07-16 23:29:00+03	193200.00
5545E8	2017-07-25 07:44:00+03	30200.00
5545F8	2017-08-15 15:58:00+03	65900.00
554632	2017-07-29 08:27:00+03	96400.00
554634	2017-07-27 01:15:00+03	46700.00
55467E	2017-07-20 21:16:00+03	19800.00
55469F	2017-07-23 01:41:00+03	73500.00
5546CB	2017-08-13 17:10:00+03	175400.00
5546F6	2017-07-08 11:43:00+03	75300.00
5546F7	2017-06-30 13:11:00+03	266200.00
55472B	2017-07-17 01:34:00+03	64400.00
55476C	2017-07-04 05:57:00+03	97500.00
55482E	2017-07-19 09:14:00+03	62000.00
554857	2017-08-15 01:36:00+03	38600.00
5548B6	2017-08-11 04:39:00+03	40000.00
5548DE	2017-08-14 04:33:00+03	56600.00
55493C	2017-08-13 07:10:00+03	44800.00
554967	2017-07-11 20:25:00+03	16400.00
5549A9	2017-08-10 05:47:00+03	36600.00
5549BC	2017-07-17 03:11:00+03	54300.00
5549FD	2017-08-08 01:07:00+03	43200.00
554A1C	2017-07-20 18:06:00+03	6000.00
554A30	2017-07-16 18:31:00+03	22800.00
554ABE	2017-07-11 04:33:00+03	121400.00
554AF4	2017-07-07 19:53:00+03	12000.00
554B78	2017-07-06 16:57:00+03	113700.00
554BAB	2017-08-13 09:11:00+03	117800.00
554BB0	2017-07-05 06:27:00+03	73900.00
554BC9	2017-07-10 08:55:00+03	28300.00
554BF0	2017-07-12 00:12:00+03	77000.00
554BF4	2017-08-08 17:18:00+03	31400.00
554C5C	2017-07-12 18:30:00+03	87900.00
554C99	2017-08-11 10:01:00+03	57400.00
554CD3	2017-08-04 14:48:00+03	40000.00
554D74	2017-07-29 20:11:00+03	13200.00
554DAD	2017-08-14 18:21:00+03	59300.00
554DFD	2017-07-29 09:43:00+03	14800.00
554E7D	2017-07-15 04:32:00+03	67600.00
554E85	2017-08-02 08:08:00+03	34000.00
554E95	2017-07-13 16:43:00+03	75600.00
554F08	2017-08-15 09:34:00+03	166100.00
554F26	2017-08-12 01:53:00+03	23200.00
554F4D	2017-07-10 07:57:00+03	20200.00
554F68	2017-08-07 02:38:00+03	6400.00
554FA4	2017-07-03 06:37:00+03	48400.00
55502E	2017-08-13 07:37:00+03	31200.00
55505B	2017-08-10 09:18:00+03	85700.00
555061	2017-07-23 20:32:00+03	26500.00
555085	2017-07-07 11:39:00+03	168000.00
55508A	2017-07-08 17:57:00+03	110500.00
555096	2017-08-04 19:41:00+03	29600.00
5551C1	2017-08-06 20:21:00+03	16400.00
5552EB	2017-08-01 21:39:00+03	168600.00
5552F3	2017-07-14 15:04:00+03	114800.00
555319	2017-08-02 10:59:00+03	44800.00
555345	2017-07-28 23:43:00+03	111600.00
55536F	2017-07-19 01:30:00+03	21200.00
55539B	2017-07-12 20:52:00+03	23200.00
5553A5	2017-08-09 01:16:00+03	78200.00
5553B2	2017-07-09 00:45:00+03	137400.00
555485	2017-08-09 00:27:00+03	46000.00
555498	2017-07-02 04:56:00+03	69500.00
5554D1	2017-07-10 10:31:00+03	28800.00
5554EA	2017-07-13 09:06:00+03	26200.00
555519	2017-08-13 13:03:00+03	242300.00
555557	2017-08-11 01:04:00+03	44700.00
55557E	2017-06-29 16:49:00+03	19600.00
555591	2017-07-18 01:20:00+03	165800.00
5555A8	2017-07-14 06:59:00+03	56900.00
5555C1	2017-07-24 06:47:00+03	74400.00
555650	2017-08-04 09:38:00+03	128800.00
55567E	2017-07-24 23:02:00+03	63800.00
55568A	2017-08-09 05:02:00+03	26000.00
5556BA	2017-08-09 05:30:00+03	6000.00
5556E3	2017-08-08 15:43:00+03	37100.00
55575F	2017-07-14 09:41:00+03	28000.00
5557AC	2017-07-07 06:18:00+03	76800.00
5557C3	2017-06-29 19:26:00+03	57300.00
55582D	2017-08-11 02:09:00+03	31400.00
555846	2017-07-06 20:58:00+03	61800.00
55588D	2017-08-04 00:23:00+03	166000.00
5558AB	2017-08-02 16:49:00+03	57200.00
5558E0	2017-08-05 23:13:00+03	208200.00
5558E7	2017-07-10 23:36:00+03	24400.00
555920	2017-07-28 18:18:00+03	41400.00
5559B7	2017-07-26 17:42:00+03	46400.00
5559CA	2017-07-15 06:06:00+03	84900.00
5559CB	2017-07-12 04:10:00+03	267700.00
555A65	2017-08-13 04:04:00+03	65900.00
555A7C	2017-08-10 16:45:00+03	132700.00
555B16	2017-07-30 08:04:00+03	41900.00
555B20	2017-08-06 01:27:00+03	26000.00
555B52	2017-07-13 08:54:00+03	225800.00
555B6B	2017-07-21 12:04:00+03	56000.00
555B9F	2017-07-04 19:33:00+03	119500.00
555BE4	2017-07-03 15:18:00+03	48900.00
555BF7	2017-08-11 03:41:00+03	64500.00
555C30	2017-07-05 01:03:00+03	79000.00
555C57	2017-06-30 10:20:00+03	52900.00
555C86	2017-08-05 09:39:00+03	147100.00
555CAE	2017-08-05 11:30:00+03	31000.00
555CC6	2017-08-15 03:49:00+03	272800.00
555CC8	2017-07-18 19:09:00+03	73300.00
555CEB	2017-07-21 11:39:00+03	19600.00
555D04	2017-08-02 16:01:00+03	41400.00
555D29	2017-06-30 10:39:00+03	24400.00
555DB3	2017-08-13 20:10:00+03	125400.00
555DE0	2017-07-18 11:11:00+03	96800.00
555E1E	2017-08-05 02:48:00+03	114300.00
555E53	2017-07-30 13:47:00+03	10800.00
555E6E	2017-07-11 16:34:00+03	57800.00
555EC5	2017-08-06 17:08:00+03	173600.00
555F2D	2017-07-19 04:10:00+03	44000.00
555F3F	2017-07-10 04:18:00+03	67700.00
555F40	2017-07-11 02:28:00+03	36800.00
555F8A	2017-07-14 23:07:00+03	148200.00
555FDE	2017-07-15 06:09:00+03	81600.00
555FFF	2017-08-08 12:24:00+03	248400.00
556000	2017-07-09 21:40:00+03	57300.00
556088	2017-07-07 09:59:00+03	95600.00
5560A1	2017-07-14 01:40:00+03	113700.00
556158	2017-07-05 22:01:00+03	54400.00
556162	2017-07-25 15:12:00+03	26800.00
55616F	2017-07-08 09:16:00+03	54200.00
5561E2	2017-07-12 06:08:00+03	137400.00
5561E7	2017-08-05 12:06:00+03	397100.00
556214	2017-07-13 00:47:00+03	24800.00
556281	2017-07-18 03:16:00+03	13400.00
556294	2017-07-03 16:14:00+03	14800.00
55632F	2017-07-26 09:18:00+03	13200.00
556342	2017-07-26 00:30:00+03	42800.00
5563C4	2017-07-05 18:59:00+03	55600.00
556484	2017-07-15 10:30:00+03	86800.00
5564BA	2017-07-11 12:04:00+03	56200.00
5564D4	2017-07-13 01:00:00+03	63500.00
5564E8	2017-07-20 10:31:00+03	25200.00
556549	2017-08-07 13:06:00+03	273600.00
556567	2017-08-13 20:19:00+03	40600.00
556574	2017-07-08 21:35:00+03	58400.00
556659	2017-07-31 18:15:00+03	46200.00
5566AA	2017-07-12 19:09:00+03	44500.00
5567CF	2017-07-14 22:21:00+03	52000.00
5568C0	2017-08-06 03:47:00+03	107000.00
5568CF	2017-07-06 17:47:00+03	184500.00
5568DB	2017-08-02 09:16:00+03	23200.00
5568E9	2017-08-06 08:36:00+03	12600.00
556930	2017-07-21 02:58:00+03	84500.00
556965	2017-08-01 06:22:00+03	47000.00
55696F	2017-06-30 18:28:00+03	117600.00
55698D	2017-07-17 21:54:00+03	135400.00
556A3B	2017-08-15 11:00:00+03	18100.00
556A4A	2017-07-08 02:28:00+03	38800.00
556A98	2017-07-30 11:35:00+03	155600.00
556ABB	2017-07-03 08:42:00+03	33100.00
556ACD	2017-07-26 08:11:00+03	54400.00
556AD3	2017-07-08 17:22:00+03	87100.00
556B2F	2017-07-04 20:44:00+03	266400.00
556B4D	2017-08-11 14:11:00+03	37100.00
556BE8	2017-07-12 05:18:00+03	131100.00
556BF2	2017-07-16 05:36:00+03	101200.00
556C45	2017-08-04 12:21:00+03	62700.00
556C78	2017-06-29 19:57:00+03	68800.00
556CA4	2017-07-12 18:03:00+03	196800.00
556CF2	2017-06-28 03:55:00+03	36800.00
556D07	2017-08-03 12:00:00+03	12600.00
556D56	2017-07-12 10:52:00+03	44800.00
556DDC	2017-07-13 07:32:00+03	40800.00
556E0B	2017-07-05 02:59:00+03	35200.00
556F19	2017-07-13 17:52:00+03	47200.00
556F33	2017-07-27 00:49:00+03	184000.00
556FB0	2017-07-24 06:40:00+03	60200.00
55708C	2017-07-22 06:35:00+03	167400.00
55708F	2017-07-06 10:37:00+03	23200.00
5570A0	2017-07-23 01:09:00+03	55600.00
5570AE	2017-08-06 10:23:00+03	21800.00
557115	2017-08-10 10:42:00+03	51900.00
5571AE	2017-07-01 14:09:00+03	34000.00
5571EF	2017-08-08 23:40:00+03	88900.00
557214	2017-08-03 05:02:00+03	68400.00
557296	2017-08-13 04:16:00+03	56000.00
55735F	2017-08-11 06:01:00+03	15900.00
5573C7	2017-08-07 23:16:00+03	57300.00
557481	2017-07-11 02:03:00+03	40300.00
5574F8	2017-08-10 00:35:00+03	23200.00
55751D	2017-08-12 08:40:00+03	24200.00
5575DA	2017-07-05 15:21:00+03	53800.00
5575EB	2017-07-08 08:27:00+03	54000.00
55767A	2017-07-18 12:50:00+03	30800.00
557685	2017-08-01 20:58:00+03	47000.00
5576CF	2017-07-16 21:30:00+03	136800.00
557736	2017-07-22 14:42:00+03	31600.00
557758	2017-08-04 05:01:00+03	24400.00
557775	2017-07-13 04:54:00+03	92800.00
5577F5	2017-08-05 17:45:00+03	62400.00
557804	2017-08-11 16:12:00+03	86600.00
557844	2017-07-27 17:39:00+03	56000.00
55787C	2017-07-10 23:29:00+03	124300.00
5578AA	2017-07-03 06:47:00+03	43600.00
5578D7	2017-07-24 19:23:00+03	47000.00
557905	2017-07-23 07:17:00+03	88800.00
5579C6	2017-06-30 02:46:00+03	26000.00
5579DC	2017-07-30 15:19:00+03	59800.00
557A1C	2017-07-07 20:50:00+03	61400.00
557A35	2017-08-09 15:01:00+03	137400.00
557ADF	2017-08-08 05:55:00+03	27300.00
557B5F	2017-07-25 18:08:00+03	155600.00
557BA1	2017-07-08 10:09:00+03	137600.00
557C2B	2017-07-10 14:33:00+03	141100.00
557C36	2017-07-04 15:32:00+03	152400.00
557C46	2017-08-02 01:11:00+03	54800.00
557C4E	2017-07-20 12:14:00+03	37900.00
557C72	2017-07-04 16:05:00+03	80000.00
557D00	2017-08-14 08:42:00+03	15300.00
557D2D	2017-08-04 11:59:00+03	15000.00
557D70	2017-07-14 08:30:00+03	68400.00
557D7B	2017-07-07 17:13:00+03	98700.00
557D93	2017-06-29 19:23:00+03	31600.00
557DBC	2017-07-27 04:42:00+03	112400.00
557E11	2017-08-07 00:55:00+03	56000.00
557E5F	2017-07-27 10:57:00+03	91600.00
557E60	2017-08-14 16:46:00+03	31200.00
557E67	2017-08-15 16:29:00+03	265700.00
557E7E	2017-08-03 10:22:00+03	28000.00
557F2E	2017-07-06 21:52:00+03	50300.00
557F32	2017-07-25 04:47:00+03	28800.00
557F4C	2017-07-17 02:21:00+03	87200.00
557FC6	2017-08-13 19:16:00+03	27400.00
557FE6	2017-07-12 11:01:00+03	123000.00
55803D	2017-07-27 02:14:00+03	16000.00
558088	2017-07-19 11:20:00+03	15800.00
558097	2017-08-02 19:24:00+03	33400.00
5580A4	2017-07-11 16:08:00+03	37900.00
5580B4	2017-07-29 05:39:00+03	11600.00
5580CB	2017-07-07 14:27:00+03	66600.00
5580CC	2017-07-05 16:43:00+03	31600.00
55815B	2017-07-08 07:06:00+03	28800.00
55818E	2017-07-22 06:42:00+03	46400.00
55819B	2017-07-05 09:14:00+03	49100.00
5581C0	2017-08-04 11:15:00+03	21400.00
55822D	2017-08-08 11:48:00+03	139600.00
558232	2017-08-10 08:51:00+03	27200.00
558239	2017-08-02 02:06:00+03	67700.00
558289	2017-07-03 09:44:00+03	56100.00
5582FB	2017-07-13 00:02:00+03	66600.00
558348	2017-07-09 05:49:00+03	6800.00
55834C	2017-08-15 13:03:00+03	36000.00
5583A6	2017-08-08 21:34:00+03	36200.00
55840A	2017-08-05 07:19:00+03	68400.00
55842B	2017-08-01 10:01:00+03	62900.00
55845B	2017-07-11 06:01:00+03	39300.00
5584B0	2017-07-08 13:24:00+03	117800.00
5584CD	2017-07-24 00:41:00+03	116700.00
5584D0	2017-07-27 04:40:00+03	71000.00
5585C4	2017-08-04 12:28:00+03	43600.00
5585CE	2017-08-08 07:18:00+03	56100.00
558608	2017-08-05 12:54:00+03	28000.00
5586F5	2017-08-09 06:17:00+03	43100.00
558717	2017-08-04 06:48:00+03	270700.00
55876A	2017-07-05 19:45:00+03	46000.00
5587B6	2017-07-30 23:51:00+03	152900.00
5587C4	2017-07-10 08:55:00+03	402400.00
558861	2017-07-12 05:40:00+03	286900.00
5588A0	2017-07-10 22:32:00+03	40600.00
5588B7	2017-08-03 12:00:00+03	25200.00
5588CB	2017-07-14 05:25:00+03	25100.00
55898A	2017-08-08 22:19:00+03	46400.00
5589C5	2017-07-22 16:14:00+03	54800.00
5589F1	2017-08-12 14:38:00+03	25100.00
558A2C	2017-08-15 02:35:00+03	73600.00
558A2D	2017-07-17 06:26:00+03	35200.00
558A31	2017-07-30 00:57:00+03	24600.00
558A34	2017-08-15 03:41:00+03	43500.00
558A3A	2017-07-23 01:06:00+03	23600.00
558A4D	2017-07-29 10:49:00+03	131100.00
558AE8	2017-08-14 19:35:00+03	13400.00
558AF2	2017-07-06 07:16:00+03	14800.00
558AF5	2017-07-16 23:55:00+03	136800.00
558AF8	2017-08-08 18:47:00+03	26800.00
558BB4	2017-08-12 02:20:00+03	10600.00
558C12	2017-07-14 01:28:00+03	131100.00
558C1E	2017-08-03 21:06:00+03	47200.00
558C2F	2017-08-13 15:52:00+03	45200.00
558C94	2017-07-28 21:14:00+03	18300.00
558D36	2017-07-16 17:35:00+03	6000.00
558D6C	2017-08-06 04:33:00+03	65600.00
558DA2	2017-07-17 18:44:00+03	131100.00
558DF8	2017-07-15 04:14:00+03	26000.00
558E68	2017-07-03 18:32:00+03	19600.00
558E75	2017-07-18 12:09:00+03	63800.00
558E8C	2017-07-21 15:10:00+03	169300.00
558E99	2017-07-20 10:22:00+03	45200.00
558ED1	2017-08-05 02:13:00+03	63400.00
558F67	2017-07-12 23:05:00+03	84300.00
558FD5	2017-07-15 00:32:00+03	262000.00
558FE4	2017-07-28 06:26:00+03	48400.00
559052	2017-07-03 04:32:00+03	18800.00
5590AE	2017-07-31 05:26:00+03	75600.00
559118	2017-08-14 12:37:00+03	114800.00
559150	2017-07-30 00:56:00+03	283100.00
559157	2017-07-04 19:46:00+03	50800.00
559171	2017-07-01 14:35:00+03	24800.00
5591AD	2017-08-13 05:41:00+03	92000.00
559280	2017-08-02 02:27:00+03	58800.00
55931F	2017-07-24 02:23:00+03	246000.00
559374	2017-08-15 01:56:00+03	36000.00
559387	2017-07-29 03:30:00+03	64400.00
5593A3	2017-07-25 01:55:00+03	56000.00
5593A4	2017-08-12 12:25:00+03	59900.00
559407	2017-07-16 11:53:00+03	6300.00
559410	2017-07-12 06:37:00+03	539400.00
559417	2017-07-11 17:30:00+03	40800.00
559457	2017-07-31 09:00:00+03	30800.00
55946C	2017-07-30 10:47:00+03	108000.00
559518	2017-08-13 02:40:00+03	61800.00
55954A	2017-07-17 09:14:00+03	89600.00
559564	2017-07-30 09:15:00+03	394800.00
559596	2017-08-08 17:51:00+03	135600.00
55959D	2017-08-12 17:47:00+03	47200.00
5595D0	2017-08-01 07:31:00+03	61500.00
559622	2017-08-02 04:53:00+03	59000.00
5596AB	2017-07-18 06:09:00+03	59200.00
55974D	2017-07-15 08:22:00+03	147700.00
55977F	2017-08-05 10:48:00+03	21400.00
5597CE	2017-08-14 11:28:00+03	18000.00
5597F1	2017-07-07 10:34:00+03	44600.00
559829	2017-08-12 12:57:00+03	35800.00
5598D2	2017-07-16 20:29:00+03	28000.00
5598F7	2017-07-05 08:57:00+03	198800.00
559936	2017-08-12 10:07:00+03	92800.00
5599AE	2017-07-16 14:02:00+03	81300.00
5599C2	2017-08-13 18:09:00+03	26700.00
5599D0	2017-07-08 19:22:00+03	96800.00
559A11	2017-07-12 13:39:00+03	18000.00
559A78	2017-07-17 04:53:00+03	28000.00
559AB0	2017-07-26 22:21:00+03	83400.00
559AD3	2017-08-03 17:19:00+03	48800.00
559B64	2017-07-17 03:30:00+03	43600.00
559B7D	2017-07-07 22:23:00+03	28800.00
559BAB	2017-08-11 16:45:00+03	46400.00
559C6F	2017-07-04 02:49:00+03	68000.00
559C8C	2017-07-01 03:05:00+03	95900.00
559D0A	2017-07-06 13:40:00+03	27900.00
559D1D	2017-07-28 11:47:00+03	65500.00
559D26	2017-07-04 23:13:00+03	57500.00
559D73	2017-07-04 08:12:00+03	74900.00
559D7F	2017-07-21 19:12:00+03	35800.00
559DD9	2017-07-03 05:58:00+03	136800.00
559DEF	2017-07-11 06:23:00+03	52100.00
559E3A	2017-08-04 13:21:00+03	189300.00
559E87	2017-08-09 14:15:00+03	8200.00
559E90	2017-07-02 10:10:00+03	46000.00
559E92	2017-07-24 03:04:00+03	12600.00
559EF2	2017-07-27 22:04:00+03	65900.00
559F12	2017-08-10 08:42:00+03	184300.00
55A005	2017-07-06 23:49:00+03	31600.00
55A050	2017-08-11 16:28:00+03	156600.00
55A0AD	2017-07-15 08:44:00+03	421100.00
55A0F3	2017-07-19 19:38:00+03	24700.00
55A11D	2017-08-10 03:48:00+03	28800.00
55A151	2017-07-30 14:55:00+03	396100.00
55A15E	2017-07-21 09:51:00+03	47100.00
55A186	2017-08-02 13:31:00+03	143200.00
55A194	2017-08-10 13:47:00+03	291000.00
55A1D2	2017-07-04 09:45:00+03	240500.00
55A1F0	2017-07-10 18:24:00+03	283300.00
55A222	2017-07-14 01:18:00+03	37900.00
55A2B7	2017-06-27 16:16:00+03	22000.00
55A325	2017-07-18 20:31:00+03	408500.00
55A3D2	2017-07-15 04:36:00+03	128800.00
55A47E	2017-07-04 03:11:00+03	122100.00
55A4BF	2017-08-11 07:40:00+03	19600.00
55A53E	2017-07-26 20:42:00+03	169900.00
55A560	2017-07-08 01:16:00+03	117900.00
55A56B	2017-07-08 10:49:00+03	131600.00
55A5A7	2017-08-12 10:36:00+03	34000.00
55A5D3	2017-07-05 22:51:00+03	83000.00
55A609	2017-07-08 00:54:00+03	95200.00
55A679	2017-07-01 04:43:00+03	56900.00
55A6E3	2017-07-19 20:30:00+03	81200.00
55A728	2017-07-26 13:39:00+03	25600.00
55A734	2017-06-25 22:48:00+03	75600.00
55A756	2017-08-06 15:31:00+03	246000.00
55A757	2017-07-22 21:29:00+03	48300.00
55A785	2017-07-23 21:31:00+03	119400.00
55A79B	2017-07-30 17:57:00+03	58000.00
55A7AE	2017-08-15 06:24:00+03	46000.00
55A7C9	2017-07-24 07:50:00+03	22000.00
55A7CB	2017-08-03 19:10:00+03	28800.00
55A7D5	2017-08-07 19:44:00+03	38800.00
55A7E3	2017-08-13 20:04:00+03	51300.00
55A82E	2017-08-01 04:41:00+03	36200.00
55A849	2017-07-31 01:16:00+03	27900.00
55A84C	2017-07-24 07:22:00+03	15000.00
55A864	2017-07-29 13:35:00+03	46000.00
55A926	2017-07-21 15:26:00+03	135400.00
55A931	2017-07-13 20:54:00+03	102100.00
55A940	2017-07-22 04:27:00+03	46000.00
55A97E	2017-07-14 18:42:00+03	26000.00
55AA61	2017-07-29 18:53:00+03	89700.00
55AA6A	2017-08-05 01:26:00+03	178900.00
55AAC3	2017-07-19 22:33:00+03	71200.00
55AACE	2017-07-04 13:27:00+03	72400.00
55AB10	2017-08-15 13:56:00+03	18600.00
55AB2D	2017-08-01 05:13:00+03	48800.00
55ABB9	2017-07-29 19:57:00+03	28000.00
55ABDC	2017-07-24 19:52:00+03	20400.00
55AC2A	2017-07-21 22:44:00+03	96500.00
55AC61	2017-07-25 16:12:00+03	46800.00
55ACBA	2017-06-28 12:32:00+03	369000.00
55ACC6	2017-08-05 23:48:00+03	114800.00
55AD2C	2017-07-15 01:36:00+03	132800.00
55AD2F	2017-08-15 16:05:00+03	72200.00
55AD32	2017-08-11 23:02:00+03	38800.00
55AD57	2017-07-30 15:50:00+03	68400.00
55AD84	2017-07-30 22:48:00+03	75300.00
55AE19	2017-08-13 03:04:00+03	180000.00
55AE22	2017-07-09 20:02:00+03	123000.00
55AE76	2017-08-06 09:57:00+03	26000.00
55AEC9	2017-07-09 22:04:00+03	166100.00
55AF88	2017-08-09 04:12:00+03	35400.00
55AFAE	2017-07-12 21:37:00+03	75300.00
55AFBC	2017-08-14 22:57:00+03	105100.00
55B012	2017-07-16 01:28:00+03	38200.00
55B06E	2017-08-11 05:59:00+03	14800.00
55B070	2017-07-24 08:55:00+03	57700.00
55B092	2017-07-21 08:07:00+03	36200.00
55B0A6	2017-07-04 18:17:00+03	27200.00
55B0E5	2017-07-20 22:08:00+03	212200.00
55B10C	2017-07-02 14:01:00+03	65500.00
55B143	2017-07-27 00:33:00+03	56000.00
55B181	2017-07-11 04:24:00+03	354400.00
55B1DF	2017-08-07 03:51:00+03	58600.00
55B1F3	2017-08-13 02:38:00+03	43400.00
55B20C	2017-07-04 01:10:00+03	48400.00
55B212	2017-07-15 11:09:00+03	192700.00
55B257	2017-07-02 19:00:00+03	26000.00
55B25B	2017-07-30 06:26:00+03	78100.00
55B279	2017-07-26 07:14:00+03	50600.00
55B292	2017-08-14 12:00:00+03	89700.00
55B2B1	2017-07-07 15:55:00+03	248300.00
55B2CE	2017-08-08 23:57:00+03	14000.00
55B2EC	2017-07-17 03:31:00+03	246000.00
55B34A	2017-07-15 20:27:00+03	47100.00
55B374	2017-07-08 04:16:00+03	117200.00
55B3AE	2017-07-22 21:20:00+03	56000.00
55B3BA	2017-08-13 00:12:00+03	64100.00
55B3C0	2017-07-17 19:44:00+03	67200.00
55B3DB	2017-08-11 16:18:00+03	38400.00
55B4AC	2017-07-29 21:28:00+03	86500.00
55B517	2017-07-25 02:21:00+03	59800.00
55B528	2017-07-19 04:10:00+03	10800.00
55B56D	2017-07-25 13:27:00+03	59800.00
55B597	2017-08-07 03:48:00+03	99300.00
55B617	2017-07-20 16:15:00+03	56200.00
55B62F	2017-07-06 11:33:00+03	26000.00
55B635	2017-07-10 13:17:00+03	27200.00
55B64E	2017-07-04 01:40:00+03	28800.00
55B690	2017-07-01 23:23:00+03	60800.00
55B6BE	2017-07-31 02:31:00+03	81300.00
55B6EA	2017-07-28 06:57:00+03	28800.00
55B720	2017-07-12 19:06:00+03	68100.00
55B73A	2017-06-27 13:05:00+03	11800.00
55B752	2017-08-13 17:32:00+03	132800.00
55B765	2017-08-12 16:02:00+03	39900.00
55B78E	2017-08-04 10:29:00+03	155600.00
55B822	2017-08-05 21:03:00+03	136200.00
55B88A	2017-07-19 05:53:00+03	49000.00
55B8A6	2017-07-07 02:19:00+03	10100.00
55B8D7	2017-07-03 15:11:00+03	52000.00
55B8DC	2017-07-01 09:02:00+03	46200.00
55B8FA	2017-08-13 19:53:00+03	68100.00
55B8FF	2017-08-13 06:32:00+03	38600.00
55B977	2017-07-22 03:42:00+03	67600.00
55BA11	2017-07-18 09:49:00+03	48800.00
55BA19	2017-08-07 11:10:00+03	65000.00
55BA25	2017-07-24 23:53:00+03	88600.00
55BAFA	2017-07-08 13:17:00+03	34000.00
55BB4B	2017-07-06 23:05:00+03	29600.00
55BC19	2017-07-05 03:42:00+03	64200.00
55BC59	2017-07-11 14:38:00+03	29600.00
55BCB1	2017-08-14 14:00:00+03	66600.00
55BCD7	2017-07-10 02:46:00+03	9200.00
55BD04	2017-07-17 18:40:00+03	78400.00
55BD0A	2017-07-30 04:21:00+03	62100.00
55BD35	2017-07-24 07:24:00+03	301800.00
55BD40	2017-07-13 20:12:00+03	53600.00
55BD58	2017-08-08 02:52:00+03	63400.00
55BD66	2017-08-09 02:02:00+03	59800.00
55BD7F	2017-07-06 16:24:00+03	58600.00
55BDB9	2017-07-17 00:54:00+03	23600.00
55BE41	2017-07-31 04:04:00+03	38300.00
55BE94	2017-07-07 17:28:00+03	110000.00
55BEAC	2017-07-15 16:26:00+03	44800.00
55BEAE	2017-08-13 06:09:00+03	169300.00
55BEF6	2017-07-09 16:21:00+03	52100.00
55BEFB	2017-07-07 08:18:00+03	92600.00
55BF1F	2017-08-04 20:09:00+03	125700.00
55BF43	2017-07-17 02:39:00+03	10800.00
55BFBC	2017-07-10 07:05:00+03	73600.00
55BFD7	2017-08-14 19:51:00+03	320900.00
55BFF8	2017-07-29 19:54:00+03	56100.00
55C03E	2017-07-06 07:12:00+03	22000.00
55C044	2017-07-05 05:56:00+03	38800.00
55C053	2017-07-14 03:34:00+03	59300.00
55C0A5	2017-07-22 00:21:00+03	21600.00
55C0CD	2017-07-10 18:29:00+03	156500.00
55C131	2017-07-24 18:05:00+03	10800.00
55C1D9	2017-07-23 10:04:00+03	38800.00
55C21A	2017-08-13 07:52:00+03	100600.00
55C23B	2017-08-13 14:13:00+03	6000.00
55C2F2	2017-07-17 09:46:00+03	187600.00
55C2F3	2017-07-11 18:08:00+03	67600.00
55C30A	2017-08-12 13:31:00+03	26000.00
55C356	2017-07-04 21:04:00+03	38600.00
55C376	2017-06-30 01:10:00+03	68800.00
55C3E9	2017-07-08 01:41:00+03	62300.00
55C422	2017-08-02 18:33:00+03	369000.00
55C47E	2017-07-25 18:13:00+03	59300.00
55C4A8	2017-07-12 20:17:00+03	78000.00
55C4BC	2017-07-30 22:31:00+03	28000.00
55C4F4	2017-08-11 07:02:00+03	9300.00
55C518	2017-08-06 05:59:00+03	29600.00
55C537	2017-07-01 20:44:00+03	102100.00
55C569	2017-08-07 12:58:00+03	8000.00
55C582	2017-08-06 00:46:00+03	39200.00
55C5AB	2017-07-20 17:59:00+03	182500.00
55C5DE	2017-08-04 08:52:00+03	40800.00
55C5EF	2017-07-20 05:26:00+03	57700.00
55C5FC	2017-07-08 12:56:00+03	58200.00
55C675	2017-07-14 00:43:00+03	83700.00
55C6E1	2017-08-05 18:25:00+03	68800.00
55C705	2017-06-30 04:26:00+03	95700.00
55C70C	2017-07-14 05:00:00+03	36100.00
55C72D	2017-07-28 12:52:00+03	183100.00
55C73F	2017-07-01 19:29:00+03	13700.00
55C756	2017-07-28 00:33:00+03	651900.00
55C757	2017-07-28 14:37:00+03	57600.00
55C78E	2017-07-29 21:10:00+03	58200.00
55C794	2017-07-03 13:41:00+03	112000.00
55C7B8	2017-07-27 02:49:00+03	44000.00
55C7BB	2017-07-13 04:01:00+03	166100.00
55C812	2017-07-08 21:44:00+03	6000.00
55C82E	2017-07-12 18:17:00+03	246200.00
55C836	2017-08-14 09:49:00+03	85600.00
55C840	2017-07-04 20:08:00+03	46500.00
55C863	2017-07-18 00:18:00+03	28000.00
55C87B	2017-07-28 01:13:00+03	17800.00
55C87E	2017-07-13 21:24:00+03	65900.00
55C8DC	2017-07-23 10:22:00+03	58600.00
55C92F	2017-08-05 00:48:00+03	99300.00
55C947	2017-07-26 15:57:00+03	34100.00
55C97C	2017-07-21 11:36:00+03	406600.00
55CA07	2017-07-12 13:24:00+03	135200.00
55CA10	2017-08-02 09:00:00+03	92700.00
55CA4D	2017-07-31 00:51:00+03	54000.00
55CA5D	2017-08-06 07:32:00+03	46000.00
55CAD9	2017-07-23 13:20:00+03	43600.00
55CB14	2017-07-05 20:44:00+03	99200.00
55CB27	2017-08-14 09:17:00+03	66600.00
55CB63	2017-07-22 10:27:00+03	28000.00
55CBBD	2017-07-21 00:42:00+03	102100.00
55CBC5	2017-08-07 11:23:00+03	125400.00
55CBD2	2017-08-10 04:13:00+03	37200.00
55CBE2	2017-07-31 15:13:00+03	28000.00
55CC08	2017-07-20 01:52:00+03	45200.00
55CC15	2017-08-05 01:22:00+03	29400.00
55CC29	2017-08-08 15:23:00+03	118100.00
55CC44	2017-07-16 21:01:00+03	15000.00
55CCA4	2017-07-25 13:50:00+03	51900.00
55CCAD	2017-06-25 22:57:00+03	21800.00
55CCCF	2017-07-03 00:37:00+03	43500.00
55CD0A	2017-07-13 15:48:00+03	30200.00
55CD11	2017-07-20 08:34:00+03	24800.00
55CD16	2017-07-28 05:47:00+03	33800.00
55CD8F	2017-07-02 06:41:00+03	69000.00
55CD96	2017-07-09 10:16:00+03	51900.00
55CDA6	2017-08-03 02:12:00+03	69000.00
55CE19	2017-07-25 12:23:00+03	72000.00
55CE57	2017-08-05 06:19:00+03	23400.00
55CEAD	2017-07-23 02:37:00+03	32700.00
55CF99	2017-08-14 13:22:00+03	48000.00
55D008	2017-07-15 08:07:00+03	169900.00
55D016	2017-08-04 03:08:00+03	46400.00
55D039	2017-07-14 18:35:00+03	105100.00
55D06F	2017-08-03 03:02:00+03	56600.00
55D105	2017-08-05 15:41:00+03	48800.00
55D145	2017-07-13 14:19:00+03	40800.00
55D152	2017-07-23 22:59:00+03	102100.00
55D178	2017-07-08 10:12:00+03	112000.00
55D1B8	2017-08-02 02:50:00+03	44300.00
55D1CA	2017-08-06 10:52:00+03	42800.00
55D1FB	2017-08-01 18:58:00+03	290600.00
55D284	2017-08-01 18:26:00+03	38400.00
55D28E	2017-07-14 18:30:00+03	28000.00
55D462	2017-08-07 19:03:00+03	57500.00
55D46D	2017-08-05 03:23:00+03	67800.00
55D47D	2017-07-04 16:02:00+03	59300.00
55D4C1	2017-08-09 14:22:00+03	50100.00
55D4E7	2017-08-08 02:34:00+03	60400.00
55D52B	2017-07-07 17:07:00+03	231400.00
55D5C5	2017-07-23 13:09:00+03	254900.00
55D691	2017-08-04 16:24:00+03	23200.00
55D6E9	2017-07-27 15:34:00+03	28700.00
55D6EA	2017-08-08 23:02:00+03	44600.00
55D7A7	2017-08-05 20:13:00+03	83200.00
55D7C2	2017-08-12 19:12:00+03	182300.00
55D7DF	2017-07-03 19:39:00+03	225200.00
55D7FC	2017-07-29 20:07:00+03	68800.00
55D895	2017-07-08 05:14:00+03	17200.00
55D8CD	2017-07-03 14:56:00+03	38600.00
55D8EC	2017-07-21 18:18:00+03	44000.00
55D902	2017-07-26 02:44:00+03	25900.00
55D920	2017-07-31 05:14:00+03	34000.00
55D97B	2017-07-10 14:59:00+03	15900.00
55D990	2017-07-13 07:56:00+03	410800.00
55D9B4	2017-07-05 02:57:00+03	147700.00
55D9DD	2017-08-13 16:48:00+03	91500.00
55D9E6	2017-07-29 17:09:00+03	62700.00
55D9EB	2017-07-06 20:56:00+03	13600.00
55DA23	2017-07-30 07:36:00+03	22000.00
55DA3B	2017-07-19 06:15:00+03	26000.00
55DAC7	2017-07-30 18:59:00+03	100200.00
55DB14	2017-07-27 10:58:00+03	26700.00
55DB35	2017-07-22 06:14:00+03	26800.00
55DB50	2017-07-12 20:01:00+03	242000.00
55DB88	2017-08-11 15:20:00+03	58400.00
55DB8E	2017-07-22 07:51:00+03	38400.00
55DB97	2017-08-14 03:21:00+03	24000.00
55DC07	2017-06-30 17:27:00+03	133200.00
55DCFC	2017-08-10 07:41:00+03	17800.00
55DDAE	2017-07-19 05:46:00+03	24000.00
55DE46	2017-08-14 11:40:00+03	40800.00
55DED8	2017-08-10 00:17:00+03	24400.00
55DF38	2017-08-15 17:49:00+03	23200.00
55DFB9	2017-07-21 19:45:00+03	57800.00
55DFBD	2017-08-02 14:46:00+03	31700.00
55DFDB	2017-07-30 06:04:00+03	123000.00
55E020	2017-08-11 08:59:00+03	38200.00
55E0BA	2017-08-03 21:20:00+03	152200.00
55E0DE	2017-08-11 21:54:00+03	38900.00
55E123	2017-07-02 16:38:00+03	89600.00
55E229	2017-07-28 06:15:00+03	13200.00
55E242	2017-08-05 23:13:00+03	75600.00
55E2CE	2017-07-23 09:26:00+03	85700.00
55E2E4	2017-08-09 04:58:00+03	50000.00
55E33D	2017-08-01 10:47:00+03	28000.00
55E382	2017-08-14 22:55:00+03	84100.00
55E3C2	2017-07-06 14:00:00+03	16400.00
55E3CB	2017-07-10 04:16:00+03	29600.00
55E3DD	2017-07-10 02:20:00+03	133100.00
55E40B	2017-07-15 22:02:00+03	136200.00
55E417	2017-07-24 03:55:00+03	26000.00
55E4B8	2017-07-04 19:28:00+03	78600.00
55E4FA	2017-07-22 01:43:00+03	27300.00
55E4FF	2017-07-14 17:31:00+03	54500.00
55E57E	2017-08-05 22:51:00+03	33100.00
55E583	2017-08-09 22:54:00+03	79600.00
55E596	2017-08-15 06:01:00+03	54600.00
55E5F9	2017-08-02 11:00:00+03	113800.00
55E600	2017-06-30 17:26:00+03	56900.00
55E66E	2017-08-09 10:20:00+03	20900.00
55E6B8	2017-08-13 01:24:00+03	40100.00
55E717	2017-07-29 13:54:00+03	46300.00
55E72A	2017-08-07 01:14:00+03	44000.00
55E7E0	2017-08-14 18:53:00+03	29200.00
55E7FA	2017-06-29 20:20:00+03	61800.00
55E8D1	2017-07-27 06:25:00+03	85600.00
55E93A	2017-07-14 23:06:00+03	58000.00
55E945	2017-08-15 10:49:00+03	27200.00
55E985	2017-07-05 04:28:00+03	148200.00
55EA29	2017-07-29 08:41:00+03	3700.00
55EA3B	2017-07-04 14:45:00+03	25800.00
55EAB3	2017-07-30 17:49:00+03	85000.00
55EABF	2017-07-06 04:15:00+03	42800.00
55EB3F	2017-07-13 12:25:00+03	55800.00
55EB6D	2017-07-29 11:08:00+03	20800.00
55EBA2	2017-07-15 10:48:00+03	43200.00
55EC3B	2017-07-15 03:59:00+03	52800.00
55EC74	2017-08-12 07:57:00+03	52100.00
55ECFC	2017-07-25 12:46:00+03	79900.00
55ED03	2017-08-06 12:38:00+03	111600.00
55ED25	2017-07-11 19:33:00+03	56000.00
55EDBE	2017-07-28 13:52:00+03	56000.00
55EEC9	2017-07-14 07:41:00+03	23200.00
55EF0A	2017-07-08 21:38:00+03	21400.00
55EFC6	2017-07-15 04:03:00+03	174400.00
55EFD0	2017-08-02 22:50:00+03	6300.00
55F00E	2017-08-05 15:49:00+03	24800.00
55F01E	2017-07-28 02:40:00+03	56000.00
55F027	2017-07-07 00:41:00+03	57000.00
55F042	2017-07-22 05:04:00+03	59000.00
55F08C	2017-07-10 07:44:00+03	86300.00
55F122	2017-07-10 20:55:00+03	10800.00
55F18A	2017-08-08 22:15:00+03	73600.00
55F198	2017-07-18 08:44:00+03	60700.00
55F1AA	2017-07-18 04:08:00+03	94200.00
55F1EC	2017-07-18 21:30:00+03	27200.00
55F22E	2017-07-17 20:23:00+03	25100.00
55F266	2017-07-08 06:16:00+03	10800.00
55F2CD	2017-07-24 06:09:00+03	24700.00
55F2E4	2017-08-03 04:03:00+03	132800.00
55F36B	2017-08-15 14:37:00+03	103200.00
55F3AD	2017-07-14 15:40:00+03	102100.00
55F3D5	2017-07-17 15:09:00+03	61800.00
55F4AC	2017-08-11 00:04:00+03	46000.00
55F4AF	2017-07-25 15:29:00+03	166900.00
55F4BE	2017-08-07 06:29:00+03	46400.00
55F4C6	2017-07-06 12:33:00+03	31600.00
55F4DB	2017-07-25 19:39:00+03	92400.00
55F552	2017-07-24 19:07:00+03	75600.00
55F559	2017-07-24 00:40:00+03	103800.00
55F58A	2017-07-20 20:11:00+03	125700.00
55F69D	2017-07-03 19:35:00+03	48500.00
55F6B4	2017-07-03 19:18:00+03	83800.00
55F6C4	2017-07-20 01:47:00+03	44000.00
55F701	2017-07-09 12:00:00+03	90800.00
55F727	2017-06-26 13:06:00+03	68100.00
55F72C	2017-07-28 15:22:00+03	64500.00
55F790	2017-08-01 14:33:00+03	64800.00
55F7AA	2017-07-27 17:31:00+03	75300.00
55F7DB	2017-07-22 14:11:00+03	46800.00
55F7EF	2017-06-28 06:06:00+03	116000.00
55F826	2017-08-11 19:46:00+03	67000.00
55F895	2017-07-30 16:58:00+03	36800.00
55F8FA	2017-07-22 10:18:00+03	206400.00
55F91F	2017-07-05 08:01:00+03	266400.00
55FA27	2017-08-04 17:18:00+03	74800.00
55FA98	2017-07-24 08:58:00+03	28000.00
55FAB8	2017-08-08 01:48:00+03	40600.00
55FAD4	2017-07-04 06:42:00+03	68100.00
55FADD	2017-08-07 09:27:00+03	173200.00
55FB5D	2017-08-05 17:57:00+03	66600.00
55FC23	2017-07-21 17:18:00+03	8200.00
55FC51	2017-08-11 21:21:00+03	34400.00
55FC5C	2017-08-13 17:50:00+03	57300.00
55FC67	2017-07-24 04:52:00+03	75300.00
55FC6E	2017-07-19 14:41:00+03	96800.00
55FC79	2017-07-15 09:18:00+03	136200.00
55FCA0	2017-08-01 06:13:00+03	62800.00
55FCA8	2017-07-05 08:52:00+03	55800.00
55FCCE	2017-07-22 08:24:00+03	8200.00
55FCD7	2017-07-23 09:35:00+03	400000.00
55FD42	2017-08-05 06:31:00+03	16400.00
55FD66	2017-07-24 07:11:00+03	64500.00
55FDA1	2017-07-26 12:29:00+03	263000.00
55FE3A	2017-07-09 05:39:00+03	111600.00
55FE41	2017-07-20 13:07:00+03	26000.00
55FE49	2017-07-20 00:09:00+03	104000.00
55FE53	2017-07-15 23:49:00+03	28000.00
55FE5E	2017-07-26 01:20:00+03	27800.00
55FF10	2017-07-21 16:54:00+03	19600.00
55FF45	2017-07-15 10:41:00+03	58900.00
55FF6F	2017-07-25 05:46:00+03	67200.00
55FF9D	2017-08-09 08:31:00+03	84500.00
55FFF4	2017-07-06 21:54:00+03	133100.00
560027	2017-08-04 07:55:00+03	97900.00
56008F	2017-07-20 17:12:00+03	69500.00
5600E5	2017-07-21 10:00:00+03	347000.00
5600EC	2017-07-05 23:59:00+03	78100.00
560114	2017-07-12 06:34:00+03	7400.00
560130	2017-07-16 20:47:00+03	62600.00
560164	2017-07-06 13:45:00+03	35500.00
5601B0	2017-07-13 19:29:00+03	6700.00
5601E8	2017-08-10 14:05:00+03	270800.00
560235	2017-08-13 23:56:00+03	36600.00
560243	2017-08-12 06:46:00+03	68800.00
56026D	2017-08-01 19:51:00+03	31400.00
560278	2017-07-28 11:06:00+03	20200.00
5602F4	2017-07-27 01:52:00+03	44800.00
560304	2017-07-15 22:08:00+03	30000.00
560362	2017-08-02 03:41:00+03	380700.00
560364	2017-08-14 04:49:00+03	196800.00
560381	2017-07-17 13:17:00+03	40000.00
56039C	2017-08-14 00:42:00+03	246000.00
5603F4	2017-07-14 10:10:00+03	161800.00
560450	2017-07-23 03:50:00+03	122300.00
560469	2017-07-13 13:19:00+03	37900.00
5604A5	2017-08-02 18:49:00+03	146900.00
5604E0	2017-08-03 19:06:00+03	98300.00
560508	2017-08-14 18:36:00+03	56000.00
560585	2017-08-10 13:42:00+03	23600.00
5605A3	2017-08-01 13:05:00+03	48800.00
5605AC	2017-08-06 09:25:00+03	51600.00
5605E4	2017-07-11 09:22:00+03	24400.00
56067E	2017-07-04 07:20:00+03	207200.00
560736	2017-07-12 17:44:00+03	34800.00
5607B9	2017-08-07 20:21:00+03	13600.00
5607F8	2017-08-03 22:20:00+03	56100.00
560812	2017-07-31 08:12:00+03	81600.00
560861	2017-08-05 18:01:00+03	101400.00
56086E	2017-08-14 09:12:00+03	52000.00
5608A4	2017-07-23 17:25:00+03	229900.00
5608F9	2017-08-01 18:27:00+03	118600.00
560933	2017-08-15 08:56:00+03	43200.00
560965	2017-07-21 03:25:00+03	21400.00
56097B	2017-07-09 05:17:00+03	6700.00
560980	2017-07-31 04:48:00+03	119600.00
56098F	2017-07-27 07:26:00+03	8400.00
5609DC	2017-07-23 12:27:00+03	120700.00
560A49	2017-07-02 02:35:00+03	19600.00
560A57	2017-07-29 18:04:00+03	46800.00
560A8E	2017-07-25 06:04:00+03	19600.00
560ABE	2017-07-31 11:35:00+03	128900.00
560AE3	2017-07-12 06:09:00+03	130400.00
560AE7	2017-07-31 10:22:00+03	48800.00
560B03	2017-07-30 10:10:00+03	13200.00
560B39	2017-07-06 02:01:00+03	69500.00
560B9B	2017-06-27 02:59:00+03	85800.00
560BB0	2017-08-07 19:20:00+03	66600.00
560C00	2017-08-07 09:20:00+03	104000.00
560C2C	2017-08-13 18:41:00+03	127600.00
560C55	2017-07-10 15:13:00+03	52000.00
560C68	2017-07-06 09:28:00+03	24400.00
560CE2	2017-07-17 13:20:00+03	43600.00
560D4C	2017-07-17 12:43:00+03	189200.00
560E16	2017-08-08 21:37:00+03	47200.00
560E17	2017-08-11 10:28:00+03	119500.00
560E5E	2017-07-23 04:14:00+03	46000.00
560E88	2017-08-06 00:27:00+03	23600.00
560EAE	2017-07-01 06:07:00+03	106400.00
560EE5	2017-07-02 08:22:00+03	14000.00
560F13	2017-08-13 11:52:00+03	42700.00
560F1E	2017-07-20 07:11:00+03	28000.00
560F56	2017-07-13 16:04:00+03	42700.00
561009	2017-07-20 09:45:00+03	135200.00
561075	2017-07-27 14:19:00+03	88000.00
56107C	2017-07-01 18:52:00+03	37200.00
561092	2017-08-03 00:03:00+03	136200.00
5610B6	2017-08-02 01:56:00+03	29200.00
5610EC	2017-07-25 11:04:00+03	87900.00
561113	2017-08-02 18:17:00+03	25600.00
561121	2017-08-11 04:15:00+03	39600.00
56113B	2017-07-21 07:44:00+03	46400.00
5611FE	2017-07-03 17:26:00+03	135000.00
561230	2017-07-23 20:20:00+03	26000.00
561262	2017-07-05 14:44:00+03	36000.00
561263	2017-08-13 16:05:00+03	85000.00
5612F8	2017-07-20 14:33:00+03	132800.00
56131E	2017-07-30 00:25:00+03	32800.00
56132A	2017-08-10 00:27:00+03	123000.00
56133A	2017-07-13 06:27:00+03	25200.00
561350	2017-07-24 17:15:00+03	104500.00
56135B	2017-07-28 14:56:00+03	186900.00
561378	2017-07-04 23:56:00+03	40300.00
5613A6	2017-07-18 15:49:00+03	46900.00
5613B1	2017-07-16 01:03:00+03	64400.00
5613D8	2017-07-09 08:33:00+03	67000.00
5613E6	2017-08-04 20:48:00+03	61200.00
5613F1	2017-07-24 00:12:00+03	202300.00
561423	2017-08-07 08:39:00+03	58200.00
561457	2017-07-26 09:43:00+03	20200.00
561468	2017-07-28 02:04:00+03	40600.00
5614BF	2017-08-05 21:52:00+03	162500.00
5614E6	2017-07-14 13:24:00+03	36400.00
561500	2017-07-30 04:33:00+03	133100.00
561518	2017-07-24 01:23:00+03	80200.00
561557	2017-08-08 11:10:00+03	13400.00
56156E	2017-07-23 05:15:00+03	38800.00
561573	2017-07-18 16:21:00+03	28000.00
5615C0	2017-07-04 18:25:00+03	148200.00
561632	2017-07-24 01:06:00+03	59800.00
561645	2017-07-20 05:54:00+03	25800.00
561661	2017-07-16 16:01:00+03	44000.00
561676	2017-07-31 21:00:00+03	49600.00
5616CF	2017-08-02 01:41:00+03	94400.00
5616E7	2017-07-27 12:27:00+03	36200.00
56172D	2017-07-19 04:18:00+03	73200.00
561782	2017-07-03 14:04:00+03	48100.00
561795	2017-07-08 01:48:00+03	12000.00
5617B0	2017-08-10 03:11:00+03	26000.00
5618A8	2017-08-05 02:26:00+03	29600.00
5618AD	2017-07-10 04:34:00+03	27200.00
5618BC	2017-07-17 06:57:00+03	89700.00
5618E8	2017-07-25 10:00:00+03	24700.00
561948	2017-08-12 19:45:00+03	13400.00
561960	2017-08-10 20:44:00+03	51300.00
561981	2017-07-21 08:31:00+03	43200.00
5619A4	2017-07-10 22:10:00+03	214100.00
5619C3	2017-08-11 09:39:00+03	21200.00
5619D6	2017-07-19 09:48:00+03	46300.00
561A19	2017-08-15 09:48:00+03	36200.00
561A9A	2017-08-13 02:15:00+03	133200.00
561AB5	2017-08-12 07:43:00+03	10800.00
561AC0	2017-08-02 20:02:00+03	22400.00
561B24	2017-08-07 23:31:00+03	266400.00
561B45	2017-07-24 12:50:00+03	76600.00
561BA6	2017-07-05 05:59:00+03	27200.00
561BA7	2017-07-11 01:40:00+03	377900.00
561C35	2017-07-15 14:55:00+03	46300.00
561C7F	2017-08-15 06:27:00+03	18400.00
561C9B	2017-07-31 03:29:00+03	357600.00
561CE4	2017-07-21 13:59:00+03	119400.00
561D7C	2017-07-04 19:03:00+03	169600.00
561D85	2017-07-03 13:46:00+03	58100.00
561D9B	2017-08-05 07:45:00+03	136200.00
561DC0	2017-07-18 22:34:00+03	136000.00
561DE0	2017-08-12 06:55:00+03	76100.00
561E1A	2017-08-03 17:03:00+03	45100.00
561E74	2017-07-04 21:58:00+03	28000.00
561E98	2017-07-15 11:28:00+03	23200.00
561EB4	2017-07-28 02:48:00+03	392800.00
561EF2	2017-07-25 00:22:00+03	6600.00
561F6E	2017-08-01 16:26:00+03	28300.00
561FBF	2017-07-11 14:14:00+03	32800.00
561FCF	2017-07-01 10:58:00+03	217200.00
561FDE	2017-07-31 07:38:00+03	131600.00
561FFC	2017-07-01 21:52:00+03	84300.00
562100	2017-07-04 23:13:00+03	23400.00
562113	2017-07-02 22:00:00+03	112600.00
562130	2017-07-18 02:57:00+03	87000.00
5621A4	2017-07-06 07:09:00+03	94000.00
5621A9	2017-07-19 17:10:00+03	66600.00
5621B2	2017-08-07 02:59:00+03	238300.00
5621B4	2017-07-29 00:25:00+03	61800.00
5621BF	2017-08-11 03:45:00+03	53600.00
562253	2017-07-08 16:23:00+03	58600.00
562299	2017-08-04 19:40:00+03	27200.00
5622F8	2017-07-29 20:30:00+03	58200.00
5622FB	2017-07-20 23:38:00+03	65600.00
56235D	2017-07-28 14:31:00+03	131900.00
5623B0	2017-08-11 00:41:00+03	58600.00
5623EC	2017-07-14 12:47:00+03	38800.00
562412	2017-07-10 15:18:00+03	134900.00
56244C	2017-07-19 11:00:00+03	24300.00
562482	2017-07-20 23:11:00+03	54800.00
562516	2017-07-11 06:48:00+03	241400.00
562553	2017-07-17 02:06:00+03	32200.00
5625A4	2017-08-01 15:28:00+03	32400.00
562609	2017-07-05 15:11:00+03	26200.00
56261C	2017-08-14 11:49:00+03	117100.00
562626	2017-07-17 15:06:00+03	258400.00
562630	2017-07-29 05:25:00+03	51900.00
562676	2017-07-22 12:18:00+03	55800.00
5626B0	2017-07-12 03:19:00+03	28000.00
5626CE	2017-07-16 13:52:00+03	59600.00
5626E9	2017-07-29 00:23:00+03	28000.00
5626F7	2017-07-31 10:43:00+03	17600.00
5627A6	2017-08-14 17:11:00+03	70600.00
5627B7	2017-08-14 16:03:00+03	123900.00
5627D6	2017-07-06 01:23:00+03	6000.00
5627F2	2017-08-03 01:34:00+03	68000.00
56283D	2017-07-15 16:26:00+03	21800.00
56283F	2017-08-09 12:03:00+03	11000.00
562850	2017-08-05 03:51:00+03	37500.00
56289A	2017-08-08 20:39:00+03	35300.00
5628D8	2017-07-21 01:57:00+03	78800.00
5628DA	2017-06-28 08:51:00+03	47400.00
562944	2017-07-28 08:14:00+03	103900.00
56294D	2017-07-16 16:36:00+03	58200.00
56295B	2017-08-15 11:39:00+03	101900.00
562986	2017-07-10 10:16:00+03	47000.00
5629B3	2017-07-19 17:12:00+03	123000.00
562A18	2017-07-07 22:42:00+03	75300.00
562A39	2017-08-13 13:12:00+03	57400.00
562A61	2017-08-14 17:57:00+03	40100.00
562A8D	2017-07-25 09:25:00+03	50600.00
562AE5	2017-07-23 19:41:00+03	131000.00
562B16	2017-08-11 18:02:00+03	24800.00
562B51	2017-07-22 15:11:00+03	51800.00
562B65	2017-08-08 11:48:00+03	103800.00
562BF1	2017-07-22 04:34:00+03	54700.00
562C47	2017-07-31 11:08:00+03	40600.00
562CFB	2017-08-15 00:10:00+03	23200.00
562D14	2017-08-04 10:59:00+03	21800.00
562D26	2017-07-01 15:59:00+03	67600.00
562D79	2017-08-12 17:54:00+03	199700.00
562DDE	2017-07-25 13:01:00+03	43600.00
562DE9	2017-07-18 18:29:00+03	32800.00
562DF7	2017-07-04 00:24:00+03	150400.00
562E1D	2017-07-24 15:40:00+03	56100.00
562E38	2017-07-19 10:05:00+03	19600.00
562E40	2017-08-06 04:09:00+03	57400.00
562E61	2017-07-13 23:19:00+03	332800.00
562E70	2017-07-19 15:17:00+03	25600.00
562E82	2017-08-12 18:58:00+03	16400.00
562E9A	2017-08-07 19:53:00+03	14000.00
562E9B	2017-07-18 07:31:00+03	85000.00
562EBE	2017-08-12 06:00:00+03	60400.00
562ED7	2017-08-12 12:19:00+03	99700.00
562EFA	2017-08-15 00:32:00+03	56000.00
562F2D	2017-08-06 11:02:00+03	61800.00
562F8B	2017-07-13 14:00:00+03	135400.00
563039	2017-08-02 06:33:00+03	103000.00
5630E5	2017-08-12 04:17:00+03	246000.00
5630F0	2017-08-04 22:56:00+03	26200.00
563151	2017-07-17 09:35:00+03	111200.00
563153	2017-07-11 23:10:00+03	133900.00
563163	2017-07-20 02:41:00+03	13600.00
563191	2017-08-15 02:45:00+03	6300.00
5631E4	2017-07-25 05:54:00+03	124000.00
5631FA	2017-07-23 09:27:00+03	396500.00
563239	2017-07-26 13:54:00+03	57800.00
563240	2017-07-21 13:28:00+03	55600.00
563272	2017-07-15 04:24:00+03	30600.00
563288	2017-07-25 10:13:00+03	26000.00
5632C7	2017-07-24 20:08:00+03	169600.00
56334A	2017-07-27 21:17:00+03	122000.00
5633A7	2017-08-05 22:34:00+03	15000.00
56340A	2017-07-29 07:56:00+03	32800.00
563415	2017-08-01 11:27:00+03	106400.00
563490	2017-07-05 16:04:00+03	72400.00
5634CC	2017-08-15 10:15:00+03	17000.00
5634E4	2017-07-23 09:55:00+03	28800.00
563506	2017-08-02 15:38:00+03	135400.00
563521	2017-07-24 12:08:00+03	58000.00
56356C	2017-07-08 21:01:00+03	185400.00
56357A	2017-07-20 05:11:00+03	64700.00
56369F	2017-08-04 09:00:00+03	172100.00
5636D5	2017-07-10 02:59:00+03	49200.00
5636DB	2017-08-02 18:47:00+03	103500.00
563760	2017-07-14 09:43:00+03	97900.00
563781	2017-08-14 14:21:00+03	96300.00
5637B2	2017-08-15 10:29:00+03	39300.00
563807	2017-07-08 16:15:00+03	28800.00
563893	2017-08-05 12:22:00+03	16400.00
5638A1	2017-08-15 04:59:00+03	66600.00
5638A8	2017-06-29 00:02:00+03	6000.00
5638C8	2017-08-02 19:16:00+03	57500.00
563913	2017-08-12 21:17:00+03	89500.00
56392C	2017-07-20 19:12:00+03	6900.00
5639C2	2017-07-31 14:07:00+03	40800.00
563A18	2017-07-03 05:06:00+03	62000.00
563A2E	2017-07-27 18:28:00+03	199600.00
563A52	2017-07-10 07:05:00+03	12000.00
563B02	2017-07-06 11:24:00+03	39300.00
563B71	2017-08-07 01:56:00+03	180000.00
563BDE	2017-07-28 19:12:00+03	46200.00
563C1B	2017-07-23 06:56:00+03	22000.00
563C2A	2017-07-20 07:14:00+03	306500.00
563C5E	2017-07-24 11:08:00+03	27900.00
563CB7	2017-07-21 20:20:00+03	76100.00
563CE4	2017-08-11 08:51:00+03	163200.00
563D0C	2017-08-03 21:29:00+03	48500.00
563D14	2017-07-10 20:16:00+03	46800.00
563D56	2017-07-21 04:10:00+03	28800.00
563D74	2017-07-17 09:00:00+03	107500.00
563DA4	2017-07-07 09:42:00+03	39300.00
563DD8	2017-07-12 12:41:00+03	32600.00
563DE2	2017-07-14 02:47:00+03	8600.00
563F50	2017-07-16 06:40:00+03	39200.00
563F51	2017-07-24 17:32:00+03	56100.00
563F55	2017-08-06 09:17:00+03	43400.00
563FB3	2017-06-29 11:28:00+03	7400.00
563FF4	2017-07-03 18:37:00+03	34400.00
563FF5	2017-07-25 17:07:00+03	16400.00
564054	2017-08-03 23:59:00+03	25400.00
56407B	2017-07-03 05:04:00+03	135600.00
56409F	2017-08-07 01:17:00+03	39500.00
5640AC	2017-07-29 21:51:00+03	34000.00
5640C6	2017-07-20 02:57:00+03	35200.00
56410A	2017-07-13 16:58:00+03	409200.00
564117	2017-07-15 01:34:00+03	23600.00
564132	2017-06-29 02:12:00+03	122300.00
564158	2017-07-27 04:58:00+03	20200.00
564160	2017-07-10 03:40:00+03	43500.00
5641C8	2017-07-17 04:28:00+03	42800.00
564200	2017-08-09 12:01:00+03	55900.00
564246	2017-07-22 02:02:00+03	123000.00
56427B	2017-06-30 03:31:00+03	178000.00
564285	2017-08-10 10:14:00+03	55800.00
5642D7	2017-07-30 11:16:00+03	72400.00
56431A	2017-08-10 10:38:00+03	6800.00
5643AC	2017-08-06 22:41:00+03	284600.00
564429	2017-08-13 08:51:00+03	77600.00
56446B	2017-07-12 23:10:00+03	76400.00
56448A	2017-06-28 10:48:00+03	16800.00
564493	2017-06-27 11:27:00+03	23600.00
564536	2017-07-24 19:39:00+03	26200.00
56457F	2017-07-09 04:54:00+03	15900.00
564605	2017-08-15 15:17:00+03	13600.00
5646AC	2017-07-24 00:01:00+03	28800.00
5646E6	2017-07-31 23:09:00+03	410800.00
56474C	2017-07-15 22:31:00+03	111600.00
564784	2017-07-03 01:18:00+03	136200.00
5647DD	2017-08-09 01:46:00+03	295400.00
564813	2017-07-24 04:35:00+03	27200.00
564853	2017-08-01 13:54:00+03	46000.00
5648EA	2017-07-30 19:27:00+03	112200.00
564936	2017-08-03 05:34:00+03	35300.00
5649CC	2017-07-31 01:50:00+03	67400.00
5649FF	2017-07-31 09:46:00+03	6000.00
564A76	2017-07-13 04:15:00+03	122000.00
564AD5	2017-07-14 22:00:00+03	24800.00
564AD8	2017-07-07 12:10:00+03	14400.00
564AE4	2017-07-04 06:53:00+03	150500.00
564AEE	2017-07-16 19:48:00+03	144200.00
564B00	2017-08-04 21:32:00+03	131800.00
564B20	2017-08-03 13:40:00+03	95700.00
564B4C	2017-08-10 14:25:00+03	123000.00
564B9C	2017-07-24 08:19:00+03	3400.00
564BDB	2017-08-01 12:28:00+03	29600.00
564C2D	2017-07-21 06:29:00+03	46400.00
564CBE	2017-08-05 01:14:00+03	58400.00
564CD9	2017-07-28 02:06:00+03	55800.00
564D25	2017-08-07 02:40:00+03	41300.00
564D60	2017-07-10 01:32:00+03	202000.00
564D64	2017-07-26 01:54:00+03	128800.00
564DBB	2017-07-17 07:32:00+03	28800.00
564E17	2017-07-19 10:44:00+03	79500.00
564E38	2017-07-23 06:40:00+03	26200.00
564ED7	2017-07-25 23:11:00+03	196000.00
564FAF	2017-07-20 01:00:00+03	32800.00
565024	2017-07-20 11:04:00+03	56000.00
565032	2017-07-05 06:27:00+03	8000.00
565202	2017-07-11 15:30:00+03	84500.00
56525A	2017-08-15 10:50:00+03	45000.00
565278	2017-07-14 17:41:00+03	14000.00
565288	2017-07-06 08:40:00+03	51600.00
5652D9	2017-07-11 14:15:00+03	32800.00
565309	2017-08-07 14:35:00+03	35000.00
565319	2017-08-07 14:16:00+03	17800.00
565320	2017-07-09 06:39:00+03	35800.00
565356	2017-07-24 19:49:00+03	29400.00
56538E	2017-07-10 09:29:00+03	101200.00
5653DB	2017-07-29 11:44:00+03	68000.00
5653E4	2017-07-23 02:03:00+03	46200.00
565482	2017-07-19 10:21:00+03	25000.00
565592	2017-08-14 02:16:00+03	124200.00
565630	2017-07-14 20:57:00+03	14000.00
56565B	2017-08-15 02:13:00+03	40300.00
56565D	2017-08-15 15:15:00+03	55800.00
565711	2017-08-01 07:58:00+03	73600.00
565809	2017-07-04 01:53:00+03	108000.00
56581F	2017-07-07 09:13:00+03	92800.00
56583F	2017-08-07 07:20:00+03	26800.00
5658C8	2017-07-09 12:13:00+03	55800.00
565936	2017-08-09 01:24:00+03	25600.00
565946	2017-07-16 22:29:00+03	40100.00
565958	2017-08-03 18:01:00+03	47100.00
565994	2017-07-21 21:36:00+03	6600.00
56599B	2017-07-24 09:27:00+03	29400.00
5659A0	2017-06-27 07:32:00+03	95700.00
5659C0	2017-07-12 09:58:00+03	133100.00
5659D3	2017-07-19 01:41:00+03	56000.00
5659FC	2017-07-14 01:27:00+03	46500.00
565A09	2017-07-02 19:03:00+03	26000.00
565A93	2017-07-15 16:00:00+03	64800.00
565B2A	2017-07-26 23:21:00+03	40800.00
565B36	2017-07-13 02:21:00+03	59800.00
565B3A	2017-07-26 06:28:00+03	26000.00
565B51	2017-07-22 20:45:00+03	174200.00
565C2B	2017-07-15 16:48:00+03	23200.00
565C2D	2017-08-11 15:54:00+03	420600.00
565C4C	2017-07-15 11:41:00+03	115900.00
565C5D	2017-07-24 07:06:00+03	24400.00
565C6A	2017-08-08 20:38:00+03	24000.00
565CC3	2017-08-15 00:26:00+03	25400.00
565CEE	2017-07-25 16:58:00+03	88600.00
565D3F	2017-08-06 08:59:00+03	99300.00
565D46	2017-07-29 09:53:00+03	37500.00
565DEB	2017-07-24 19:29:00+03	246000.00
565DED	2017-08-14 23:53:00+03	19600.00
565E23	2017-07-26 14:46:00+03	80200.00
565E3E	2017-07-14 15:28:00+03	44800.00
565EA3	2017-07-31 19:59:00+03	36400.00
565F4C	2017-08-03 05:49:00+03	81800.00
565F7B	2017-07-19 01:01:00+03	206400.00
565F89	2017-07-25 17:47:00+03	55600.00
565FED	2017-07-15 04:29:00+03	44400.00
566003	2017-08-14 03:25:00+03	59800.00
5660F0	2017-07-07 21:46:00+03	48500.00
56611A	2017-08-14 11:36:00+03	70700.00
566189	2017-08-11 12:59:00+03	168000.00
566193	2017-07-22 07:57:00+03	194000.00
5661F8	2017-08-07 15:42:00+03	99300.00
566271	2017-07-16 06:32:00+03	23200.00
5662E2	2017-07-07 18:04:00+03	105700.00
56630D	2017-07-16 04:44:00+03	20400.00
5663A0	2017-07-14 06:52:00+03	31400.00
5663D4	2017-07-11 17:14:00+03	26500.00
566406	2017-08-14 08:52:00+03	169000.00
566408	2017-08-11 15:45:00+03	61200.00
566409	2017-08-14 09:17:00+03	21800.00
566491	2017-07-27 00:37:00+03	65600.00
5664A1	2017-07-07 11:19:00+03	177200.00
566594	2017-07-05 18:46:00+03	70100.00
566595	2017-08-08 08:14:00+03	66400.00
5665A5	2017-08-11 22:55:00+03	46000.00
5666C8	2017-07-28 13:12:00+03	33100.00
5666F5	2017-08-05 09:48:00+03	14000.00
566760	2017-07-16 23:52:00+03	67900.00
5667C1	2017-07-29 20:35:00+03	36400.00
56683C	2017-08-11 06:33:00+03	24800.00
56688D	2017-07-27 14:46:00+03	125200.00
56694D	2017-07-25 07:59:00+03	26200.00
5669EB	2017-07-29 08:15:00+03	47000.00
5669EF	2017-08-08 19:09:00+03	66600.00
566A5B	2017-07-12 11:55:00+03	84500.00
566AE8	2017-07-06 03:59:00+03	43200.00
566AEF	2017-07-28 08:00:00+03	15400.00
566B56	2017-08-14 07:45:00+03	39800.00
566B6A	2017-08-13 09:37:00+03	42700.00
566B71	2017-07-25 05:41:00+03	28800.00
566C20	2017-07-04 16:04:00+03	72200.00
566C7F	2017-07-29 21:23:00+03	23200.00
566D02	2017-07-16 21:27:00+03	68800.00
566E06	2017-07-26 02:51:00+03	26000.00
566E27	2017-07-03 01:39:00+03	27200.00
566E32	2017-08-13 09:47:00+03	80200.00
566EE3	2017-08-12 23:19:00+03	47200.00
566FA6	2017-08-14 12:45:00+03	21400.00
566FB1	2017-07-24 08:36:00+03	10100.00
566FDA	2017-08-15 10:08:00+03	6000.00
566FDE	2017-08-05 17:17:00+03	13200.00
56704C	2017-07-09 01:47:00+03	27200.00
567090	2017-08-12 15:28:00+03	266200.00
56709E	2017-07-30 18:33:00+03	6000.00
567138	2017-07-14 22:36:00+03	53800.00
567179	2017-07-07 20:39:00+03	372500.00
567197	2017-08-09 18:06:00+03	36800.00
5671B5	2017-07-21 10:50:00+03	265600.00
5672ED	2017-08-13 14:52:00+03	189800.00
567302	2017-07-21 09:31:00+03	46400.00
56730E	2017-07-17 21:03:00+03	28800.00
567326	2017-08-12 04:31:00+03	13400.00
56734A	2017-07-19 04:16:00+03	124200.00
567371	2017-07-18 01:15:00+03	26000.00
56739D	2017-07-31 23:10:00+03	67600.00
5673A1	2017-07-27 15:06:00+03	117700.00
5673A9	2017-07-07 08:20:00+03	33100.00
5673B5	2017-08-14 07:35:00+03	64800.00
5673FC	2017-07-22 06:26:00+03	28800.00
567416	2017-08-02 03:44:00+03	19600.00
5674EE	2017-07-11 08:31:00+03	252200.00
56754D	2017-07-07 21:20:00+03	86800.00
567575	2017-08-13 23:26:00+03	25100.00
56757A	2017-08-08 05:37:00+03	23600.00
5675A2	2017-07-19 14:43:00+03	16400.00
5675D8	2017-07-23 12:11:00+03	57500.00
5675E7	2017-07-02 23:46:00+03	197200.00
5676A3	2017-08-05 12:14:00+03	28800.00
567702	2017-08-13 18:54:00+03	14400.00
56773A	2017-07-14 23:48:00+03	142300.00
567747	2017-08-11 15:19:00+03	55100.00
5677FC	2017-07-26 12:26:00+03	17800.00
567900	2017-08-09 02:57:00+03	125200.00
567914	2017-08-15 10:55:00+03	26700.00
567953	2017-08-09 01:55:00+03	13400.00
567996	2017-06-29 22:59:00+03	70600.00
5679AB	2017-07-04 14:05:00+03	140500.00
567A6C	2017-07-15 07:11:00+03	19800.00
567A73	2017-08-12 16:21:00+03	83300.00
567B10	2017-08-04 11:41:00+03	6700.00
567B30	2017-07-02 10:42:00+03	189800.00
567B3A	2017-07-02 20:59:00+03	115800.00
567BDD	2017-08-05 16:01:00+03	19600.00
567C2B	2017-08-10 21:43:00+03	31000.00
567C54	2017-07-01 05:03:00+03	182300.00
567C9F	2017-07-19 22:48:00+03	40000.00
567CD5	2017-07-10 10:33:00+03	46400.00
567D11	2017-07-05 22:31:00+03	22000.00
567D3C	2017-07-10 11:35:00+03	73600.00
567DC7	2017-08-01 16:53:00+03	123000.00
567E18	2017-08-04 21:43:00+03	64700.00
567E82	2017-08-14 04:06:00+03	31100.00
567E8F	2017-07-28 11:09:00+03	532800.00
567EED	2017-08-12 15:23:00+03	46200.00
567F05	2017-07-18 07:45:00+03	75600.00
567F97	2017-07-04 12:59:00+03	55000.00
567FCC	2017-07-31 05:02:00+03	62200.00
568083	2017-07-16 08:12:00+03	43200.00
5680B8	2017-08-06 01:43:00+03	62000.00
568107	2017-08-07 19:17:00+03	92800.00
56812C	2017-08-06 04:17:00+03	89700.00
568139	2017-08-15 04:48:00+03	72000.00
568145	2017-08-03 18:32:00+03	45100.00
56814B	2017-07-08 07:47:00+03	54400.00
5681D7	2017-08-13 23:58:00+03	115400.00
5681DC	2017-07-04 20:04:00+03	67200.00
5681E2	2017-07-28 08:37:00+03	223200.00
5681EF	2017-07-21 22:03:00+03	14900.00
568215	2017-07-08 03:36:00+03	56000.00
568360	2017-08-03 19:35:00+03	142300.00
568385	2017-07-24 13:07:00+03	71000.00
56838D	2017-08-09 15:17:00+03	85500.00
5684F0	2017-07-03 22:01:00+03	148200.00
568526	2017-07-25 00:05:00+03	48100.00
5685A5	2017-08-05 04:14:00+03	43600.00
5685CC	2017-08-12 18:22:00+03	63400.00
5685F5	2017-07-24 16:05:00+03	28000.00
568600	2017-07-18 19:56:00+03	10800.00
56863D	2017-07-17 09:06:00+03	50600.00
568688	2017-06-30 04:05:00+03	26000.00
568722	2017-08-02 07:03:00+03	46400.00
568728	2017-07-10 21:56:00+03	52000.00
568730	2017-08-13 07:42:00+03	23200.00
56873C	2017-07-06 20:04:00+03	38200.00
568778	2017-07-20 10:09:00+03	140900.00
5687C0	2017-07-13 03:26:00+03	62800.00
568829	2017-08-12 11:29:00+03	75800.00
568862	2017-08-01 12:37:00+03	33100.00
568879	2017-07-30 22:12:00+03	34000.00
5688BB	2017-07-16 04:22:00+03	64500.00
5688BC	2017-07-30 03:56:00+03	112000.00
568934	2017-08-04 03:39:00+03	33100.00
568948	2017-08-10 19:48:00+03	20800.00
568949	2017-07-06 23:21:00+03	39100.00
568969	2017-07-16 18:41:00+03	12000.00
5689C8	2017-07-21 10:02:00+03	55800.00
5689E1	2017-08-09 00:10:00+03	131100.00
5689EC	2017-06-29 12:40:00+03	111600.00
568A5A	2017-07-03 04:58:00+03	47200.00
568A6C	2017-07-01 16:07:00+03	34700.00
568ABE	2017-07-11 01:00:00+03	65900.00
568B03	2017-07-04 09:57:00+03	116800.00
568B13	2017-07-31 06:53:00+03	56000.00
568B37	2017-07-01 10:07:00+03	28000.00
568B8C	2017-07-14 21:33:00+03	23200.00
568BA3	2017-07-09 01:39:00+03	49900.00
568BA9	2017-07-11 21:52:00+03	139100.00
568C2B	2017-08-12 07:37:00+03	52000.00
568C32	2017-06-29 15:51:00+03	56000.00
568C58	2017-07-30 00:49:00+03	58800.00
568C5D	2017-08-12 17:47:00+03	118900.00
568D06	2017-07-24 03:22:00+03	29200.00
568E21	2017-07-20 18:47:00+03	21800.00
568E4D	2017-07-03 11:55:00+03	111000.00
568E6A	2017-08-08 10:40:00+03	59400.00
568EBD	2017-08-09 17:09:00+03	58600.00
568F43	2017-07-10 21:02:00+03	25900.00
568F68	2017-07-23 05:06:00+03	260300.00
568FA3	2017-08-15 16:37:00+03	17600.00
568FBF	2017-06-27 05:11:00+03	56000.00
568FD3	2017-07-03 06:12:00+03	23200.00
569046	2017-07-12 21:49:00+03	133100.00
569077	2017-07-28 13:17:00+03	30200.00
56907F	2017-07-16 01:06:00+03	61400.00
56908D	2017-07-18 16:33:00+03	7400.00
56909C	2017-07-26 07:07:00+03	121200.00
5690B7	2017-07-31 23:33:00+03	87000.00
5690ED	2017-07-27 12:01:00+03	46300.00
569165	2017-08-04 08:39:00+03	61600.00
569168	2017-06-30 09:27:00+03	33600.00
56923E	2017-07-29 14:17:00+03	26000.00
56927F	2017-07-14 01:12:00+03	60400.00
5692A1	2017-08-07 13:26:00+03	30200.00
5692A5	2017-07-26 18:35:00+03	26000.00
5692D8	2017-07-25 16:59:00+03	14800.00
569311	2017-07-11 18:50:00+03	20600.00
569329	2017-07-20 23:43:00+03	100600.00
569352	2017-07-27 17:06:00+03	23400.00
5693DC	2017-07-17 14:18:00+03	14400.00
569444	2017-07-25 06:45:00+03	118900.00
569590	2017-07-03 18:14:00+03	169300.00
569599	2017-07-27 05:17:00+03	78000.00
5695C5	2017-08-05 10:10:00+03	37200.00
5695D2	2017-08-08 06:42:00+03	23400.00
5695DD	2017-07-02 12:04:00+03	36200.00
5695DE	2017-07-21 09:01:00+03	85000.00
5695F7	2017-08-15 07:17:00+03	45400.00
569637	2017-08-01 02:16:00+03	72400.00
569641	2017-07-12 16:14:00+03	26000.00
56965C	2017-07-19 23:46:00+03	39500.00
569671	2017-08-05 12:35:00+03	81300.00
569699	2017-07-02 10:39:00+03	96800.00
569745	2017-07-06 21:26:00+03	83700.00
569785	2017-07-31 09:36:00+03	86900.00
56979F	2017-08-11 22:40:00+03	28000.00
569812	2017-07-05 13:58:00+03	87100.00
56981C	2017-07-06 17:57:00+03	15800.00
56989F	2017-07-14 09:34:00+03	188000.00
5698BC	2017-07-31 20:10:00+03	244200.00
5698DE	2017-08-09 00:02:00+03	32800.00
569951	2017-07-28 02:25:00+03	248400.00
56995B	2017-07-23 12:19:00+03	27800.00
5699F3	2017-07-11 09:26:00+03	23200.00
5699FA	2017-07-10 13:11:00+03	24400.00
569A06	2017-08-14 00:58:00+03	31400.00
569A52	2017-08-03 10:38:00+03	57400.00
569AA8	2017-07-02 02:18:00+03	49200.00
569AB3	2017-07-09 19:25:00+03	58200.00
569AD4	2017-07-25 12:22:00+03	14800.00
569B27	2017-07-05 14:56:00+03	106600.00
569B8A	2017-07-09 03:54:00+03	37900.00
569BA2	2017-07-12 15:32:00+03	43400.00
569C0A	2017-08-04 05:57:00+03	27300.00
569C16	2017-07-29 19:28:00+03	27400.00
569C52	2017-08-06 10:21:00+03	48800.00
569C6A	2017-07-20 19:06:00+03	135600.00
569D43	2017-07-13 07:13:00+03	86400.00
569D9E	2017-07-07 04:08:00+03	36200.00
569DA1	2017-07-26 07:51:00+03	70800.00
569DD4	2017-08-12 19:53:00+03	55800.00
569E0A	2017-08-04 18:10:00+03	53600.00
569E41	2017-07-17 15:35:00+03	52000.00
569E47	2017-07-22 08:17:00+03	46200.00
569E9C	2017-07-07 21:36:00+03	325500.00
569EB8	2017-07-19 01:11:00+03	65500.00
569EC1	2017-08-03 21:35:00+03	393800.00
569F2A	2017-07-18 12:28:00+03	135000.00
56A0F9	2017-07-16 20:30:00+03	27200.00
56A11A	2017-08-01 21:06:00+03	65100.00
56A12B	2017-07-27 10:09:00+03	68100.00
56A17F	2017-08-02 05:23:00+03	81600.00
56A193	2017-08-06 21:24:00+03	111600.00
56A1A4	2017-07-02 19:43:00+03	46000.00
56A1BA	2017-07-19 14:50:00+03	114800.00
56A1E8	2017-08-05 13:11:00+03	44600.00
56A202	2017-07-13 08:25:00+03	44000.00
56A282	2017-07-24 23:17:00+03	85700.00
56A2A7	2017-08-13 03:19:00+03	127200.00
56A2D6	2017-08-11 09:40:00+03	12600.00
56A2E2	2017-07-30 10:49:00+03	26000.00
56A2E7	2017-07-22 11:45:00+03	54800.00
56A31E	2017-08-08 16:02:00+03	42000.00
56A367	2017-07-15 20:28:00+03	31000.00
56A37B	2017-07-07 14:58:00+03	68000.00
56A3B8	2017-07-13 14:23:00+03	6300.00
56A3D4	2017-07-30 00:53:00+03	38400.00
56A411	2017-07-17 01:01:00+03	22400.00
56A424	2017-07-07 08:25:00+03	16400.00
56A453	2017-07-25 20:37:00+03	30000.00
56A46F	2017-08-01 14:57:00+03	160800.00
56A48A	2017-07-27 03:47:00+03	12900.00
56A51F	2017-07-20 14:18:00+03	32700.00
56A533	2017-07-11 17:59:00+03	21800.00
56A534	2017-08-04 15:49:00+03	83100.00
56A5B6	2017-07-28 07:36:00+03	115600.00
56A60E	2017-08-06 22:29:00+03	56000.00
56A615	2017-08-12 10:19:00+03	111700.00
56A65A	2017-07-19 14:15:00+03	81600.00
56A669	2017-07-27 23:32:00+03	265700.00
56A6A0	2017-07-06 17:42:00+03	54800.00
56A6F9	2017-08-05 15:06:00+03	102100.00
56A700	2017-07-28 06:30:00+03	55800.00
56A71B	2017-06-27 17:51:00+03	7400.00
56A732	2017-07-26 19:17:00+03	100400.00
56A775	2017-07-24 15:02:00+03	7300.00
56A7FB	2017-07-14 13:00:00+03	84100.00
56A813	2017-07-24 22:33:00+03	28800.00
56A826	2017-07-28 17:26:00+03	135400.00
56A836	2017-07-25 09:43:00+03	59300.00
56A847	2017-08-12 13:29:00+03	43900.00
56A84B	2017-07-13 03:51:00+03	28000.00
56A871	2017-07-17 06:21:00+03	28600.00
56A874	2017-07-11 14:51:00+03	22000.00
56A900	2017-07-25 21:36:00+03	271100.00
56A9AD	2017-06-29 12:31:00+03	46000.00
56AA58	2017-08-15 10:42:00+03	26000.00
56AA85	2017-07-25 02:14:00+03	30200.00
56AA8D	2017-07-03 03:54:00+03	165500.00
56AAFF	2017-08-06 01:06:00+03	17800.00
56AB10	2017-07-24 09:01:00+03	76600.00
56AB4E	2017-07-14 19:12:00+03	172300.00
56AB59	2017-07-21 20:38:00+03	28000.00
56AB64	2017-07-05 00:08:00+03	89700.00
56ABC4	2017-08-04 07:30:00+03	81800.00
56AC03	2017-08-11 05:18:00+03	15000.00
56AC16	2017-07-27 19:39:00+03	73500.00
56AC88	2017-07-15 03:10:00+03	28000.00
56AD22	2017-07-23 14:04:00+03	46000.00
56AD31	2017-08-10 23:43:00+03	260900.00
56AD3F	2017-07-21 09:21:00+03	6200.00
56AD5D	2017-07-19 18:26:00+03	33100.00
56AD6B	2017-07-26 22:51:00+03	52400.00
56ADA6	2017-07-15 09:13:00+03	26700.00
56AE4E	2017-08-15 14:44:00+03	118700.00
56AE78	2017-07-22 03:42:00+03	119500.00
56AEA5	2017-07-05 01:13:00+03	19600.00
56AEB8	2017-07-10 22:14:00+03	59300.00
56AEBD	2017-07-05 12:47:00+03	212700.00
56AED1	2017-07-03 21:55:00+03	8000.00
56AEDA	2017-07-11 04:21:00+03	35600.00
56AF50	2017-07-20 13:22:00+03	89700.00
56AF51	2017-07-15 17:44:00+03	297900.00
56AF92	2017-08-12 03:09:00+03	96300.00
56AFC2	2017-07-22 07:07:00+03	24400.00
56AFEC	2017-07-08 21:33:00+03	39200.00
56AFF5	2017-07-29 03:48:00+03	25600.00
56AFF7	2017-08-11 13:14:00+03	37400.00
56B054	2017-07-11 19:02:00+03	68400.00
56B082	2017-07-10 04:25:00+03	23200.00
56B098	2017-07-08 18:36:00+03	13400.00
56B114	2017-08-09 13:39:00+03	12600.00
56B131	2017-07-25 01:53:00+03	134400.00
56B135	2017-07-24 20:02:00+03	38400.00
56B138	2017-08-09 10:13:00+03	179300.00
56B17F	2017-08-03 03:47:00+03	113300.00
56B198	2017-08-10 11:46:00+03	7400.00
56B1F8	2017-07-24 05:04:00+03	161900.00
56B285	2017-07-19 11:03:00+03	155600.00
56B28A	2017-07-29 00:07:00+03	56600.00
56B29B	2017-07-16 06:52:00+03	129000.00
56B2B8	2017-07-18 15:53:00+03	59800.00
56B2D9	2017-07-19 19:07:00+03	134800.00
56B2F6	2017-08-08 07:27:00+03	65600.00
56B371	2017-07-14 05:36:00+03	40600.00
56B446	2017-07-07 02:10:00+03	78100.00
56B44D	2017-08-13 09:33:00+03	5400.00
56B4CF	2017-07-11 16:37:00+03	64600.00
56B4D7	2017-08-07 08:16:00+03	58100.00
56B58F	2017-07-09 14:16:00+03	68100.00
56B5A5	2017-07-26 00:55:00+03	47200.00
56B5AA	2017-07-29 14:17:00+03	42700.00
56B62E	2017-07-15 04:54:00+03	44400.00
56B678	2017-07-24 02:46:00+03	111600.00
56B6C8	2017-08-15 04:58:00+03	88600.00
56B79F	2017-07-13 15:52:00+03	547000.00
56B819	2017-06-30 02:53:00+03	55800.00
56B8C8	2017-08-01 17:40:00+03	89600.00
56B8E0	2017-08-14 00:13:00+03	68400.00
56B8FC	2017-07-26 08:20:00+03	66700.00
56B90A	2017-08-06 14:39:00+03	79800.00
56B930	2017-07-25 00:23:00+03	52700.00
56B93B	2017-08-14 15:53:00+03	119500.00
56B97C	2017-07-29 02:36:00+03	100600.00
56B994	2017-07-16 13:21:00+03	114800.00
56B9FC	2017-08-02 22:56:00+03	23500.00
56BA3E	2017-07-28 17:01:00+03	59800.00
56BA52	2017-08-10 14:07:00+03	137600.00
56BA66	2017-08-11 09:46:00+03	49000.00
56BAF6	2017-07-16 02:29:00+03	272400.00
56BB02	2017-07-15 08:21:00+03	48800.00
56BB48	2017-07-14 03:53:00+03	39000.00
56BB67	2017-07-06 20:00:00+03	14300.00
56BB90	2017-07-09 12:35:00+03	23200.00
56BBB2	2017-07-23 06:21:00+03	57400.00
56BBE0	2017-08-08 15:22:00+03	51300.00
56BC04	2017-06-28 00:16:00+03	29600.00
56BC2B	2017-07-28 15:16:00+03	91900.00
56BC6E	2017-07-21 16:51:00+03	54800.00
56BD07	2017-07-25 10:48:00+03	270000.00
56BD37	2017-07-17 20:49:00+03	193200.00
56BD75	2017-08-04 15:26:00+03	85000.00
56BE33	2017-07-07 15:42:00+03	20600.00
56BE55	2017-07-20 05:40:00+03	102900.00
56BE5F	2017-08-01 16:56:00+03	28000.00
56BE89	2017-07-31 07:27:00+03	6700.00
56BE9B	2017-07-31 07:39:00+03	99200.00
56BEC6	2017-08-08 10:35:00+03	95000.00
56BED0	2017-08-09 08:00:00+03	27900.00
56BED1	2017-07-19 23:01:00+03	47400.00
56BFAC	2017-08-03 22:23:00+03	108000.00
56BFE4	2017-08-06 01:36:00+03	43900.00
56C033	2017-07-01 07:25:00+03	54500.00
56C09C	2017-08-09 20:03:00+03	135400.00
56C09F	2017-07-04 16:28:00+03	25800.00
56C0DC	2017-08-11 14:28:00+03	57700.00
56C153	2017-07-04 03:03:00+03	539400.00
56C181	2017-08-05 04:00:00+03	12600.00
56C1D3	2017-07-24 13:03:00+03	43600.00
56C1D4	2017-08-06 18:32:00+03	23400.00
56C201	2017-07-05 22:45:00+03	33400.00
56C235	2017-07-16 08:21:00+03	179400.00
56C24B	2017-07-16 23:12:00+03	136600.00
56C34E	2017-07-15 17:28:00+03	16400.00
56C388	2017-07-08 04:29:00+03	56200.00
56C3CF	2017-07-16 04:09:00+03	29600.00
56C3FB	2017-07-31 00:50:00+03	37700.00
56C413	2017-07-16 04:34:00+03	123900.00
56C4C3	2017-07-17 18:58:00+03	23400.00
56C4F7	2017-07-07 08:47:00+03	152500.00
56C500	2017-07-02 11:52:00+03	26000.00
56C548	2017-08-07 09:19:00+03	20000.00
56C568	2017-08-14 08:10:00+03	46400.00
56C5F0	2017-06-30 20:05:00+03	116400.00
56C610	2017-07-04 02:50:00+03	174600.00
56C6BA	2017-08-13 06:36:00+03	27200.00
56C6FD	2017-08-02 12:54:00+03	272300.00
56C757	2017-08-03 11:23:00+03	28000.00
56C7ED	2017-07-16 19:54:00+03	94000.00
56C867	2017-07-21 04:56:00+03	123000.00
56C868	2017-07-22 21:16:00+03	137100.00
56C897	2017-07-17 10:43:00+03	46800.00
56C8A8	2017-07-11 04:32:00+03	31600.00
56C8BB	2017-07-03 06:55:00+03	47100.00
56C8EA	2017-08-04 05:10:00+03	56600.00
56C962	2017-07-09 23:11:00+03	67100.00
56C994	2017-07-09 05:47:00+03	13400.00
56C9DE	2017-08-12 10:17:00+03	48500.00
56CA44	2017-07-15 06:03:00+03	47000.00
56CA69	2017-08-05 17:32:00+03	265600.00
56CB5E	2017-07-04 13:36:00+03	30800.00
56CB9A	2017-07-13 10:30:00+03	88600.00
56CBA3	2017-08-09 23:24:00+03	32800.00
56CBF5	2017-08-06 18:33:00+03	49600.00
56CD01	2017-07-31 16:27:00+03	8400.00
56CD12	2017-08-05 02:42:00+03	38800.00
56CD83	2017-08-13 14:26:00+03	12200.00
56CDAC	2017-07-15 02:36:00+03	115700.00
56CE0D	2017-07-14 10:58:00+03	57600.00
56CE1D	2017-07-05 01:24:00+03	36200.00
56CEF3	2017-07-19 02:48:00+03	125200.00
56CF04	2017-07-14 14:05:00+03	48800.00
56CF19	2017-07-24 08:51:00+03	29600.00
56CF4A	2017-07-20 13:04:00+03	56000.00
56CF77	2017-07-22 05:45:00+03	115800.00
56CF99	2017-07-13 05:36:00+03	21400.00
56CFBF	2017-07-15 20:39:00+03	69500.00
56CFFC	2017-07-02 05:08:00+03	82900.00
56D0A0	2017-07-24 16:05:00+03	92800.00
56D15E	2017-07-25 16:16:00+03	63700.00
56D183	2017-08-14 08:21:00+03	40800.00
56D1FF	2017-07-21 10:22:00+03	64700.00
56D20B	2017-07-27 04:16:00+03	8200.00
56D24E	2017-08-14 17:47:00+03	68000.00
56D26C	2017-07-17 01:43:00+03	124000.00
56D28A	2017-07-05 04:33:00+03	269400.00
56D34A	2017-07-08 04:24:00+03	44800.00
56D36D	2017-08-12 23:56:00+03	37700.00
56D3EC	2017-07-07 17:42:00+03	38800.00
56D43C	2017-08-15 07:04:00+03	35200.00
56D45F	2017-07-28 16:06:00+03	37000.00
56D467	2017-07-16 22:02:00+03	19600.00
56D487	2017-07-17 07:42:00+03	38800.00
56D48A	2017-07-19 10:33:00+03	16400.00
56D4AD	2017-08-12 20:37:00+03	34000.00
56D555	2017-07-13 10:09:00+03	47100.00
56D563	2017-07-18 21:50:00+03	16400.00
56D570	2017-07-28 21:24:00+03	123000.00
56D5C6	2017-08-09 10:59:00+03	27200.00
56D668	2017-08-07 09:57:00+03	103500.00
56D6A9	2017-07-04 16:14:00+03	55500.00
56D6AB	2017-07-31 00:00:00+03	92100.00
56D6AC	2017-08-15 14:40:00+03	75600.00
56D6CE	2017-08-04 00:29:00+03	87600.00
56D73A	2017-07-28 00:16:00+03	21600.00
56D761	2017-07-01 14:04:00+03	38600.00
56D795	2017-08-02 06:28:00+03	6300.00
56D827	2017-08-13 15:04:00+03	57500.00
56D833	2017-07-18 16:49:00+03	115600.00
56D83A	2017-07-15 11:23:00+03	111600.00
56D840	2017-08-05 15:24:00+03	290500.00
56D87B	2017-08-14 22:07:00+03	31600.00
56D89E	2017-07-09 03:15:00+03	70700.00
56D8CB	2017-07-14 08:47:00+03	135400.00
56D911	2017-08-06 06:46:00+03	32800.00
56D913	2017-07-14 14:30:00+03	76600.00
56D93E	2017-07-07 14:15:00+03	37000.00
56D948	2017-08-09 04:29:00+03	67300.00
56D9C7	2017-07-20 01:27:00+03	24400.00
56D9E0	2017-07-20 01:49:00+03	28000.00
56DA5E	2017-06-30 04:56:00+03	69500.00
56DA91	2017-08-15 13:38:00+03	62800.00
56DAAC	2017-08-15 05:39:00+03	136200.00
56DB20	2017-08-10 01:44:00+03	85200.00
56DB35	2017-08-09 13:11:00+03	137900.00
56DB77	2017-07-19 04:17:00+03	75600.00
56DBB6	2017-07-12 00:51:00+03	109600.00
56DBE5	2017-07-21 16:45:00+03	65600.00
56DC7C	2017-08-03 00:30:00+03	13800.00
56DD19	2017-07-24 02:39:00+03	98300.00
56DD92	2017-07-25 00:34:00+03	28800.00
56DDC5	2017-07-04 02:53:00+03	73300.00
56DDC9	2017-08-03 01:13:00+03	26000.00
56DE1B	2017-07-18 00:31:00+03	369000.00
56DE2C	2017-07-09 16:16:00+03	56000.00
56DE4C	2017-07-18 23:37:00+03	44000.00
56DE98	2017-08-02 18:54:00+03	11800.00
56DEA9	2017-08-01 19:18:00+03	205600.00
56DEB9	2017-07-13 07:11:00+03	13600.00
56DEBC	2017-07-14 09:58:00+03	46400.00
56DECB	2017-07-27 16:30:00+03	406800.00
56DEDA	2017-07-16 22:20:00+03	93000.00
56DF05	2017-07-25 05:54:00+03	28800.00
56DF1B	2017-08-13 06:33:00+03	32700.00
56DF24	2017-07-31 12:07:00+03	26000.00
56DF6A	2017-07-12 18:25:00+03	135400.00
56DF72	2017-08-05 11:33:00+03	25600.00
56DF8A	2017-07-18 05:45:00+03	69500.00
56DFA2	2017-07-13 10:14:00+03	28800.00
56DFB4	2017-07-11 21:27:00+03	68800.00
56DFF4	2017-08-02 16:25:00+03	169900.00
56E043	2017-07-29 11:28:00+03	148200.00
56E04A	2017-07-15 18:09:00+03	21800.00
56E0C4	2017-07-23 18:33:00+03	23200.00
56E0D5	2017-08-08 15:22:00+03	18600.00
56E171	2017-08-06 12:28:00+03	23200.00
56E1D8	2017-07-30 10:34:00+03	167400.00
56E213	2017-07-24 09:40:00+03	15400.00
56E233	2017-07-28 07:06:00+03	93900.00
56E2F0	2017-07-30 02:03:00+03	116900.00
56E308	2017-07-08 17:07:00+03	106400.00
56E377	2017-07-26 20:41:00+03	71800.00
56E37C	2017-07-15 08:29:00+03	39400.00
56E3F0	2017-07-28 10:34:00+03	23200.00
56E406	2017-08-10 18:44:00+03	31600.00
56E42E	2017-08-08 09:18:00+03	29800.00
56E491	2017-07-09 17:46:00+03	49800.00
56E4B2	2017-07-06 17:18:00+03	46400.00
56E4EC	2017-08-08 02:00:00+03	103500.00
56E4FC	2017-08-10 09:52:00+03	35300.00
56E521	2017-08-02 16:05:00+03	194600.00
56E556	2017-07-18 19:28:00+03	92800.00
56E57E	2017-07-22 22:44:00+03	20200.00
56E5EA	2017-08-15 13:26:00+03	23200.00
56E623	2017-08-08 15:05:00+03	124200.00
56E628	2017-07-01 09:08:00+03	53400.00
56E637	2017-07-13 15:18:00+03	10600.00
56E6DC	2017-08-12 01:45:00+03	96600.00
56E7F9	2017-08-05 08:55:00+03	57400.00
56E829	2017-07-22 01:25:00+03	32800.00
56E894	2017-07-29 09:01:00+03	46300.00
56E8CB	2017-08-02 16:35:00+03	6700.00
56E93C	2017-07-02 21:39:00+03	78300.00
56E949	2017-08-05 07:25:00+03	57800.00
56E991	2017-07-07 08:03:00+03	164600.00
56E9BF	2017-07-13 08:56:00+03	68800.00
56EA0E	2017-07-06 21:46:00+03	62600.00
56EA1A	2017-07-22 08:10:00+03	27900.00
56EA22	2017-07-19 04:30:00+03	94800.00
56EA26	2017-07-15 18:36:00+03	133100.00
56EA2A	2017-07-26 07:55:00+03	167400.00
56EAFD	2017-08-07 08:16:00+03	23400.00
56EB69	2017-07-13 14:11:00+03	36200.00
56EB6F	2017-07-09 14:22:00+03	39300.00
56EC16	2017-08-05 03:21:00+03	56200.00
56ECE3	2017-07-11 01:35:00+03	281100.00
56ECE7	2017-08-03 11:04:00+03	75600.00
56ECFC	2017-08-13 11:39:00+03	51600.00
56ED1A	2017-06-30 10:45:00+03	32200.00
56ED46	2017-07-11 09:46:00+03	44700.00
56ED5B	2017-08-09 15:53:00+03	43900.00
56ED6B	2017-08-09 11:06:00+03	35600.00
56EDB9	2017-08-04 04:11:00+03	44000.00
56EE0B	2017-07-05 08:06:00+03	37200.00
56EE3C	2017-07-08 21:01:00+03	43600.00
56EE80	2017-07-11 02:06:00+03	156300.00
56EF08	2017-08-08 00:29:00+03	56600.00
56EF84	2017-08-11 09:01:00+03	65900.00
56EF97	2017-07-19 04:39:00+03	50000.00
56EFF1	2017-08-12 16:31:00+03	212800.00
56F0B9	2017-07-28 19:20:00+03	48200.00
56F10E	2017-08-11 21:25:00+03	48800.00
56F120	2017-08-11 19:55:00+03	12000.00
56F1BA	2017-07-16 14:32:00+03	113200.00
56F207	2017-08-04 17:18:00+03	27900.00
56F20F	2017-07-05 16:10:00+03	189200.00
56F2C3	2017-08-06 01:56:00+03	165500.00
56F30A	2017-08-08 05:34:00+03	102100.00
56F318	2017-08-02 20:07:00+03	48500.00
56F35C	2017-07-16 07:23:00+03	65500.00
56F3FB	2017-07-26 02:02:00+03	47400.00
56F449	2017-06-30 23:49:00+03	103600.00
56F488	2017-08-11 16:34:00+03	64500.00
56F4A1	2017-08-14 17:56:00+03	143200.00
56F4BB	2017-07-19 03:28:00+03	67400.00
56F56D	2017-07-22 15:40:00+03	198300.00
56F5E7	2017-07-23 23:35:00+03	46900.00
56F664	2017-07-21 02:11:00+03	88200.00
56F697	2017-08-14 10:26:00+03	300800.00
56F6A7	2017-07-19 07:37:00+03	53600.00
56F6CA	2017-07-16 08:12:00+03	13000.00
56F73F	2017-07-24 20:18:00+03	234900.00
56F77A	2017-07-08 17:02:00+03	20200.00
56F817	2017-08-08 01:54:00+03	46900.00
56F82E	2017-07-10 18:23:00+03	23600.00
56F875	2017-08-15 17:35:00+03	28800.00
56F962	2017-06-30 10:10:00+03	51600.00
56FA73	2017-07-18 22:22:00+03	22000.00
56FA92	2017-08-13 22:00:00+03	56000.00
56FB49	2017-08-10 10:57:00+03	79600.00
56FB56	2017-07-30 19:22:00+03	57500.00
56FB74	2017-07-28 11:35:00+03	73500.00
56FBAB	2017-08-03 05:58:00+03	131100.00
56FBB3	2017-07-03 10:48:00+03	56000.00
56FC37	2017-08-12 07:17:00+03	103400.00
56FC53	2017-08-13 14:29:00+03	271200.00
56FC78	2017-07-03 20:50:00+03	65100.00
56FC85	2017-08-11 13:00:00+03	67600.00
56FCAB	2017-07-15 05:09:00+03	69500.00
56FCC6	2017-07-21 23:33:00+03	54300.00
56FCD5	2017-07-13 04:39:00+03	6700.00
56FCE9	2017-08-09 21:48:00+03	136200.00
56FCF0	2017-06-29 08:37:00+03	38800.00
56FD1D	2017-08-03 08:32:00+03	95600.00
56FD58	2017-07-31 06:05:00+03	92400.00
56FD72	2017-07-29 09:07:00+03	15000.00
56FDCF	2017-07-06 01:24:00+03	52300.00
56FDE3	2017-08-04 22:08:00+03	213200.00
56FDF1	2017-07-11 04:25:00+03	36200.00
56FEA0	2017-08-03 15:53:00+03	90400.00
56FEA5	2017-08-13 02:38:00+03	111600.00
56FED2	2017-07-21 14:55:00+03	46000.00
56FEFB	2017-07-28 23:35:00+03	98200.00
56FF83	2017-06-29 18:48:00+03	38800.00
56FFA6	2017-07-26 00:39:00+03	19600.00
56FFAC	2017-07-30 03:18:00+03	86000.00
57008A	2017-08-09 18:49:00+03	75600.00
570098	2017-07-06 14:15:00+03	66600.00
5700A6	2017-07-24 00:46:00+03	70400.00
5700A7	2017-07-29 12:15:00+03	27700.00
570109	2017-07-05 15:37:00+03	43200.00
570118	2017-07-10 07:21:00+03	19600.00
57011B	2017-08-15 05:17:00+03	131600.00
570126	2017-08-03 22:53:00+03	65500.00
570130	2017-07-17 06:30:00+03	13600.00
570188	2017-08-13 16:43:00+03	79600.00
5701D6	2017-08-09 23:18:00+03	146300.00
5701EC	2017-06-29 17:36:00+03	40600.00
57021C	2017-07-06 00:23:00+03	112600.00
5702D9	2017-08-09 11:10:00+03	63300.00
570333	2017-08-04 10:04:00+03	16400.00
57033A	2017-08-12 22:41:00+03	169900.00
57035B	2017-07-29 00:53:00+03	51600.00
5703C6	2017-07-04 12:17:00+03	271100.00
570409	2017-08-12 21:02:00+03	27200.00
570426	2017-07-18 15:34:00+03	131600.00
570439	2017-08-13 01:29:00+03	20400.00
570459	2017-07-03 13:43:00+03	36200.00
570489	2017-07-20 15:42:00+03	46000.00
570506	2017-07-04 13:11:00+03	40800.00
5705B9	2017-07-29 14:09:00+03	80700.00
5705F5	2017-08-11 19:46:00+03	93900.00
570619	2017-07-27 13:10:00+03	85000.00
570620	2017-07-27 20:52:00+03	109700.00
5706BF	2017-08-01 04:44:00+03	28400.00
570717	2017-07-16 15:25:00+03	32900.00
57074E	2017-08-12 01:16:00+03	48200.00
570788	2017-07-26 22:29:00+03	44000.00
5707F2	2017-07-18 20:10:00+03	16400.00
5707FF	2017-07-23 06:46:00+03	135300.00
570829	2017-07-18 08:24:00+03	233800.00
57083B	2017-07-07 21:05:00+03	277600.00
570873	2017-07-21 14:42:00+03	112000.00
5708E1	2017-07-04 23:45:00+03	72400.00
570916	2017-08-03 10:36:00+03	58600.00
570987	2017-07-13 03:38:00+03	78300.00
5709BD	2017-06-29 20:30:00+03	41800.00
5709CF	2017-08-13 03:37:00+03	90800.00
5709FB	2017-08-13 06:15:00+03	38600.00
570A08	2017-08-11 08:17:00+03	89600.00
570A73	2017-07-15 14:33:00+03	42800.00
570A7D	2017-07-16 21:30:00+03	53600.00
570B55	2017-08-02 09:22:00+03	258300.00
570B78	2017-07-18 00:54:00+03	194200.00
570C53	2017-07-31 08:36:00+03	92000.00
570D10	2017-08-08 12:53:00+03	38800.00
570E1B	2017-08-11 13:42:00+03	248400.00
570EBD	2017-08-06 23:31:00+03	135400.00
570ED4	2017-08-13 08:18:00+03	125500.00
570EF2	2017-07-31 03:04:00+03	24000.00
570F6E	2017-07-12 11:01:00+03	27300.00
570F87	2017-07-21 15:50:00+03	30000.00
570FB3	2017-07-10 00:57:00+03	252200.00
570FCC	2017-08-14 09:37:00+03	56900.00
57100A	2017-07-14 07:30:00+03	189800.00
571016	2017-07-23 21:10:00+03	31200.00
57106A	2017-07-29 12:14:00+03	75600.00
5710BB	2017-07-26 12:28:00+03	23200.00
57112F	2017-07-31 12:22:00+03	67300.00
571150	2017-07-03 06:13:00+03	100600.00
57117F	2017-08-04 11:48:00+03	48800.00
5711EC	2017-07-03 02:17:00+03	52300.00
571202	2017-07-25 04:16:00+03	48800.00
5712B7	2017-08-04 17:21:00+03	35800.00
5712D9	2017-08-14 04:04:00+03	258400.00
571304	2017-07-02 12:00:00+03	11800.00
571327	2017-08-13 18:02:00+03	12000.00
571352	2017-07-25 16:32:00+03	92000.00
57135F	2017-06-28 21:39:00+03	8200.00
571385	2017-07-08 19:02:00+03	136600.00
57139C	2017-08-11 12:05:00+03	174300.00
5713A0	2017-08-08 06:58:00+03	291400.00
5713DB	2017-07-20 21:34:00+03	36400.00
5713E4	2017-07-08 20:08:00+03	75800.00
57147B	2017-07-23 03:54:00+03	12000.00
5714B9	2017-07-19 15:33:00+03	112000.00
5714E7	2017-07-17 00:13:00+03	124300.00
571524	2017-07-18 22:52:00+03	46400.00
571535	2017-07-09 22:37:00+03	28700.00
571561	2017-07-27 07:09:00+03	15700.00
57157E	2017-07-11 05:56:00+03	40600.00
5715FA	2017-07-09 16:25:00+03	135400.00
571626	2017-08-10 08:12:00+03	135400.00
5716A2	2017-07-09 00:20:00+03	47200.00
5716C6	2017-07-17 13:25:00+03	23200.00
5716FC	2017-08-03 18:38:00+03	73600.00
57179C	2017-07-02 09:46:00+03	175000.00
5717A9	2017-07-12 17:54:00+03	55800.00
5717CC	2017-06-25 15:25:00+03	492000.00
5717EE	2017-07-30 11:54:00+03	257600.00
57180B	2017-08-11 06:55:00+03	87700.00
571817	2017-07-17 14:07:00+03	91500.00
571855	2017-07-14 22:52:00+03	25600.00
5718D1	2017-07-22 12:20:00+03	21400.00
571922	2017-07-22 01:05:00+03	10100.00
57194B	2017-07-30 07:54:00+03	44600.00
571951	2017-07-18 23:39:00+03	32800.00
5719AB	2017-08-07 13:21:00+03	155600.00
5719C1	2017-07-17 13:58:00+03	54400.00
5719E5	2017-08-05 20:13:00+03	26700.00
571A18	2017-07-30 14:14:00+03	88100.00
571A64	2017-08-12 11:30:00+03	43600.00
571A6F	2017-07-29 23:20:00+03	137700.00
571A79	2017-07-15 18:36:00+03	199700.00
571B24	2017-08-07 19:49:00+03	48800.00
571B9C	2017-07-11 08:29:00+03	28800.00
571BAF	2017-07-21 09:16:00+03	177800.00
571BBD	2017-07-27 20:18:00+03	60900.00
571BE5	2017-07-14 02:15:00+03	16000.00
571CA7	2017-07-12 15:30:00+03	126300.00
571CB7	2017-08-12 15:32:00+03	64700.00
571CBE	2017-07-31 02:27:00+03	15900.00
571CF4	2017-07-05 07:51:00+03	47500.00
571CF7	2017-08-13 04:21:00+03	99500.00
571D54	2017-07-28 09:21:00+03	135300.00
571E13	2017-07-15 01:15:00+03	20200.00
571E40	2017-07-06 14:28:00+03	61700.00
571E86	2017-07-22 12:08:00+03	6300.00
571EE2	2017-08-07 07:37:00+03	26000.00
571EF0	2017-07-11 01:10:00+03	44800.00
571F04	2017-08-05 12:25:00+03	66600.00
571F57	2017-07-31 03:49:00+03	24300.00
571F71	2017-08-06 10:47:00+03	27200.00
572029	2017-07-17 14:32:00+03	522400.00
572072	2017-07-06 08:42:00+03	67600.00
572099	2017-07-13 13:15:00+03	69500.00
5720DF	2017-08-06 07:53:00+03	135300.00
5720F8	2017-06-24 16:21:00+03	6800.00
572116	2017-07-28 08:43:00+03	94200.00
572120	2017-07-06 15:14:00+03	34400.00
572201	2017-08-01 03:07:00+03	88500.00
572226	2017-08-15 11:30:00+03	56000.00
57222B	2017-08-06 19:40:00+03	173500.00
572294	2017-07-03 21:01:00+03	38500.00
57230E	2017-08-01 05:36:00+03	189800.00
572348	2017-07-16 01:41:00+03	81200.00
572384	2017-07-10 10:22:00+03	21200.00
5723B0	2017-08-14 01:24:00+03	21800.00
5723B9	2017-07-17 09:15:00+03	47000.00
5723C2	2017-07-26 08:45:00+03	8000.00
5724B6	2017-07-13 10:24:00+03	66600.00
57255C	2017-07-19 15:37:00+03	11600.00
572564	2017-08-06 09:58:00+03	26600.00
57258C	2017-07-07 13:49:00+03	79600.00
57259A	2017-07-20 15:24:00+03	58400.00
5725C3	2017-07-22 22:59:00+03	53000.00
572609	2017-07-04 08:29:00+03	168300.00
572624	2017-07-17 10:25:00+03	54800.00
572656	2017-06-30 02:16:00+03	28000.00
572671	2017-08-12 21:09:00+03	199700.00
5726A7	2017-07-25 18:12:00+03	58900.00
5726B0	2017-07-10 20:52:00+03	63200.00
5726E2	2017-07-29 07:23:00+03	102700.00
572720	2017-07-07 21:21:00+03	28600.00
5727B7	2017-07-25 08:08:00+03	71000.00
572804	2017-07-25 22:07:00+03	119800.00
57284F	2017-08-08 07:59:00+03	75300.00
572890	2017-08-07 16:46:00+03	69500.00
572895	2017-07-07 14:54:00+03	23600.00
5728CE	2017-08-04 05:23:00+03	14400.00
57290C	2017-08-13 02:27:00+03	96800.00
57296C	2017-07-22 10:52:00+03	71700.00
572997	2017-07-05 00:52:00+03	25400.00
5729A2	2017-07-24 18:52:00+03	13200.00
572A29	2017-07-18 21:15:00+03	18600.00
572A3C	2017-07-07 21:44:00+03	22000.00
572A61	2017-08-11 15:59:00+03	28800.00
572A76	2017-07-04 17:53:00+03	17200.00
572AAD	2017-07-20 13:58:00+03	117000.00
572ABD	2017-07-10 23:02:00+03	26700.00
572B5E	2017-08-09 16:46:00+03	135200.00
572B65	2017-07-22 16:12:00+03	153300.00
572C11	2017-07-11 17:09:00+03	33500.00
572C46	2017-08-14 17:59:00+03	38600.00
572C66	2017-07-31 21:31:00+03	95700.00
572C86	2017-08-10 12:57:00+03	41300.00
572C89	2017-07-27 00:21:00+03	58100.00
572CAA	2017-07-26 23:12:00+03	70700.00
572D10	2017-07-29 20:26:00+03	303500.00
572D21	2017-07-18 01:13:00+03	21800.00
572D75	2017-06-30 09:40:00+03	199700.00
572DB0	2017-07-10 16:35:00+03	27300.00
572DD7	2017-07-10 04:10:00+03	13400.00
572E3C	2017-07-19 13:00:00+03	55800.00
572E53	2017-07-23 04:37:00+03	38800.00
572EAF	2017-07-31 11:27:00+03	39800.00
572F67	2017-07-09 22:44:00+03	39800.00
572F94	2017-07-31 04:45:00+03	26000.00
572FCE	2017-08-03 18:00:00+03	31400.00
57308C	2017-08-08 14:54:00+03	78300.00
5730D6	2017-07-31 21:54:00+03	6700.00
5731C6	2017-08-04 19:49:00+03	62000.00
5731D9	2017-08-12 09:19:00+03	47100.00
5731DF	2017-07-06 00:22:00+03	28000.00
57325B	2017-07-22 01:43:00+03	119500.00
573381	2017-07-20 04:48:00+03	56000.00
573459	2017-08-13 07:03:00+03	90800.00
5734D5	2017-08-10 01:33:00+03	15400.00
5734FB	2017-07-07 12:25:00+03	137700.00
573541	2017-08-07 15:33:00+03	114400.00
573581	2017-07-22 04:42:00+03	22000.00
57366D	2017-08-15 12:48:00+03	225800.00
573673	2017-08-07 14:07:00+03	110900.00
573683	2017-07-07 19:23:00+03	28800.00
57369A	2017-07-02 01:13:00+03	23200.00
5736E6	2017-07-17 05:51:00+03	249000.00
573734	2017-07-10 08:42:00+03	10800.00
573798	2017-08-06 00:11:00+03	65600.00
5738AE	2017-07-08 02:21:00+03	257600.00
5738FA	2017-07-19 10:19:00+03	102100.00
57392C	2017-08-07 04:05:00+03	23600.00
573953	2017-07-28 05:53:00+03	16400.00
57395B	2017-07-02 08:39:00+03	8400.00
57395F	2017-08-07 17:49:00+03	24700.00
573975	2017-07-14 00:25:00+03	51400.00
5739F1	2017-08-09 18:43:00+03	131100.00
573A0B	2017-07-06 17:52:00+03	27200.00
573A45	2017-08-15 05:14:00+03	81600.00
573A4F	2017-08-14 13:59:00+03	27600.00
573A77	2017-08-06 11:25:00+03	31600.00
573A7E	2017-08-13 16:37:00+03	48800.00
573A8F	2017-07-06 00:02:00+03	67700.00
573ADD	2017-07-08 20:31:00+03	56000.00
573B23	2017-07-27 12:45:00+03	68400.00
573B74	2017-08-07 05:30:00+03	12600.00
573B93	2017-07-26 23:17:00+03	56000.00
573C15	2017-07-08 07:03:00+03	6300.00
573C16	2017-07-07 10:11:00+03	88400.00
573C46	2017-07-19 11:41:00+03	28200.00
573C52	2017-07-09 01:35:00+03	128600.00
573C89	2017-07-29 17:23:00+03	14400.00
573C8C	2017-08-12 12:20:00+03	15400.00
573D17	2017-07-22 02:58:00+03	77900.00
573D40	2017-08-10 17:59:00+03	43800.00
573D69	2017-08-05 00:52:00+03	43800.00
573D88	2017-07-30 03:42:00+03	64000.00
573D97	2017-07-25 11:13:00+03	13200.00
573DA8	2017-07-21 04:55:00+03	28800.00
573E38	2017-07-03 00:01:00+03	13400.00
573E5D	2017-08-06 20:42:00+03	142400.00
573E97	2017-07-24 07:56:00+03	64700.00
573EBD	2017-07-03 09:44:00+03	95700.00
573EE9	2017-07-02 01:56:00+03	24200.00
573F0C	2017-07-14 12:58:00+03	28800.00
573FDE	2017-07-18 03:43:00+03	89600.00
574064	2017-07-19 03:23:00+03	13200.00
574095	2017-08-06 06:44:00+03	65900.00
574098	2017-07-01 09:39:00+03	52800.00
57409A	2017-08-14 03:02:00+03	15400.00
57409D	2017-07-06 14:00:00+03	128800.00
5740CF	2017-07-16 22:49:00+03	15800.00
574192	2017-07-07 18:03:00+03	14400.00
5741BA	2017-08-12 22:23:00+03	73500.00
5741D9	2017-07-19 08:11:00+03	52800.00
5741E7	2017-08-10 16:38:00+03	43300.00
574249	2017-08-10 06:34:00+03	47700.00
574283	2017-07-16 13:48:00+03	242100.00
5742F0	2017-07-08 06:07:00+03	58900.00
574387	2017-07-21 20:24:00+03	15400.00
5743D6	2017-07-02 17:42:00+03	41200.00
57448B	2017-08-09 21:11:00+03	141600.00
5744BD	2017-07-26 12:48:00+03	32800.00
5744C0	2017-08-04 16:05:00+03	81800.00
574513	2017-07-07 07:19:00+03	58600.00
574552	2017-07-11 01:10:00+03	73600.00
5745AA	2017-07-21 00:36:00+03	36200.00
574623	2017-07-15 08:13:00+03	23600.00
574682	2017-08-15 13:27:00+03	7400.00
57468E	2017-07-10 14:51:00+03	40000.00
5746AB	2017-07-21 11:10:00+03	36100.00
5746BB	2017-07-11 15:35:00+03	50800.00
5746E7	2017-07-08 20:29:00+03	49800.00
5747DF	2017-08-09 06:07:00+03	75600.00
5747FE	2017-07-25 15:23:00+03	189200.00
574801	2017-07-05 18:54:00+03	139300.00
57485D	2017-08-02 15:22:00+03	38300.00
574861	2017-07-18 11:08:00+03	36200.00
574888	2017-07-07 20:12:00+03	33100.00
5748C3	2017-08-06 16:41:00+03	6700.00
5748DF	2017-07-07 04:21:00+03	20400.00
574934	2017-07-15 22:26:00+03	206100.00
57499D	2017-08-09 15:11:00+03	32800.00
5749FC	2017-07-18 15:29:00+03	55800.00
574A3B	2017-08-03 09:11:00+03	28800.00
574A96	2017-08-06 20:21:00+03	26700.00
574AC7	2017-07-02 10:54:00+03	611700.00
574AF5	2017-07-04 22:43:00+03	75600.00
574B94	2017-07-03 06:32:00+03	40800.00
574BE7	2017-07-03 21:39:00+03	269000.00
574C18	2017-07-11 01:38:00+03	67100.00
574C57	2017-08-11 10:11:00+03	62000.00
574C72	2017-07-05 04:12:00+03	166100.00
574C78	2017-07-27 03:00:00+03	10700.00
574C94	2017-07-24 12:52:00+03	31600.00
574C9A	2017-08-08 10:20:00+03	28800.00
574CB6	2017-07-16 23:53:00+03	55800.00
574D08	2017-07-06 09:35:00+03	21400.00
574DAF	2017-07-26 09:09:00+03	50800.00
574DB4	2017-08-13 05:25:00+03	46400.00
574DE0	2017-07-07 22:00:00+03	10800.00
574E2C	2017-07-14 09:49:00+03	23400.00
574E3B	2017-07-02 07:20:00+03	48300.00
574E93	2017-08-13 09:11:00+03	16400.00
574E9B	2017-07-10 16:35:00+03	40800.00
574F3C	2017-07-05 01:15:00+03	6700.00
574F68	2017-07-20 22:13:00+03	22100.00
575015	2017-07-12 09:13:00+03	60200.00
575036	2017-07-04 06:03:00+03	266300.00
575050	2017-08-09 01:18:00+03	44000.00
575052	2017-07-02 02:41:00+03	44500.00
5750C1	2017-08-03 11:22:00+03	24200.00
5750FB	2017-07-08 16:43:00+03	46400.00
575120	2017-07-13 13:17:00+03	14000.00
575143	2017-08-09 22:59:00+03	7400.00
575166	2017-07-22 20:35:00+03	55000.00
575195	2017-07-19 04:31:00+03	39300.00
5751B5	2017-07-05 04:19:00+03	171700.00
57522E	2017-07-26 06:28:00+03	40800.00
575246	2017-08-02 12:39:00+03	95200.00
5752C7	2017-07-19 23:18:00+03	43500.00
5752DE	2017-07-15 14:02:00+03	112000.00
57530F	2017-07-28 20:21:00+03	57400.00
575344	2017-07-15 22:55:00+03	44600.00
57537E	2017-07-26 16:49:00+03	59300.00
5753D7	2017-07-02 23:36:00+03	96800.00
575408	2017-07-18 22:21:00+03	59300.00
575490	2017-08-13 09:32:00+03	6800.00
575497	2017-07-08 14:09:00+03	63600.00
5754F2	2017-07-12 04:43:00+03	82400.00
57558E	2017-07-31 21:27:00+03	31400.00
575625	2017-07-09 18:44:00+03	279200.00
5756F3	2017-07-10 22:47:00+03	132800.00
575747	2017-07-16 10:27:00+03	48500.00
575815	2017-07-22 18:23:00+03	65200.00
575838	2017-07-28 14:30:00+03	15000.00
5758C0	2017-07-26 03:39:00+03	30200.00
575930	2017-06-29 02:14:00+03	52000.00
57593E	2017-08-09 11:57:00+03	19800.00
575A52	2017-07-10 22:53:00+03	87400.00
575AB2	2017-07-04 07:53:00+03	102100.00
575B47	2017-06-28 02:11:00+03	89700.00
575B4F	2017-07-14 20:39:00+03	23200.00
575BA8	2017-07-31 16:01:00+03	15100.00
575C28	2017-08-01 19:58:00+03	46200.00
575C35	2017-08-01 06:42:00+03	28000.00
575C54	2017-06-30 05:41:00+03	46400.00
575C79	2017-07-05 10:06:00+03	726200.00
575D26	2017-07-25 02:25:00+03	24700.00
575D73	2017-06-30 18:33:00+03	62900.00
575D96	2017-07-17 11:08:00+03	38800.00
575D99	2017-08-01 08:53:00+03	112000.00
575DCC	2017-07-11 21:40:00+03	46300.00
575DEC	2017-08-07 02:41:00+03	89600.00
575E16	2017-08-10 08:40:00+03	56000.00
575E36	2017-07-09 14:58:00+03	51900.00
575EF2	2017-07-25 06:19:00+03	14400.00
575F11	2017-08-06 07:16:00+03	26600.00
575F91	2017-07-03 01:50:00+03	36200.00
575FDD	2017-07-24 00:30:00+03	25800.00
575FF3	2017-07-31 19:23:00+03	96800.00
576015	2017-07-20 16:34:00+03	46500.00
576022	2017-07-08 09:05:00+03	398500.00
576024	2017-07-18 05:21:00+03	78400.00
57603E	2017-08-06 12:04:00+03	100600.00
576064	2017-07-23 13:00:00+03	77600.00
57609A	2017-07-05 13:33:00+03	295400.00
57610F	2017-07-22 21:27:00+03	87100.00
576170	2017-07-06 19:28:00+03	53400.00
57622C	2017-07-06 23:15:00+03	23200.00
576263	2017-07-08 05:12:00+03	26800.00
576298	2017-07-28 15:56:00+03	25200.00
5762E4	2017-07-15 18:26:00+03	78200.00
576311	2017-07-25 13:22:00+03	157600.00
576325	2017-08-15 08:28:00+03	12600.00
576330	2017-07-27 17:35:00+03	56900.00
576343	2017-07-21 17:53:00+03	55800.00
576345	2017-07-19 05:20:00+03	120900.00
57635A	2017-08-06 20:08:00+03	64700.00
57639D	2017-08-07 01:47:00+03	14000.00
5763BC	2017-08-15 12:25:00+03	58900.00
5763E5	2017-07-14 17:45:00+03	152900.00
576400	2017-06-28 09:47:00+03	131600.00
576430	2017-07-17 00:27:00+03	21800.00
576444	2017-08-12 12:54:00+03	67400.00
5764CE	2017-07-17 03:58:00+03	142800.00
5765DA	2017-06-27 23:19:00+03	40000.00
5766DA	2017-07-04 18:33:00+03	23400.00
5766E5	2017-07-22 14:47:00+03	46400.00
5766F4	2017-08-02 15:40:00+03	6000.00
576718	2017-07-18 01:10:00+03	25900.00
576724	2017-07-05 00:41:00+03	284400.00
576730	2017-08-09 15:31:00+03	44600.00
576774	2017-07-12 00:36:00+03	46000.00
576775	2017-07-29 01:07:00+03	149000.00
576793	2017-07-15 04:51:00+03	9800.00
5767C6	2017-07-28 11:34:00+03	55100.00
5767D8	2017-07-20 00:53:00+03	56000.00
5767F8	2017-06-29 12:37:00+03	6000.00
5767F9	2017-07-10 09:41:00+03	57600.00
576815	2017-07-19 20:31:00+03	50000.00
576874	2017-07-06 19:24:00+03	28800.00
5768A8	2017-07-26 13:33:00+03	37100.00
5768C4	2017-08-06 16:16:00+03	143600.00
5768C8	2017-07-21 07:30:00+03	23200.00
5768E8	2017-07-22 13:47:00+03	35800.00
57690D	2017-07-01 01:16:00+03	92600.00
57691D	2017-07-28 02:01:00+03	43600.00
576937	2017-07-03 15:34:00+03	58800.00
57693F	2017-07-14 22:47:00+03	44000.00
576A91	2017-07-14 22:22:00+03	123600.00
576AC3	2017-07-25 06:56:00+03	112000.00
576B0A	2017-07-01 12:57:00+03	40400.00
576B8C	2017-08-14 07:35:00+03	116400.00
576BAB	2017-07-27 06:40:00+03	14000.00
576BD6	2017-07-14 08:49:00+03	69500.00
576C2D	2017-07-02 12:28:00+03	187600.00
576C57	2017-07-13 10:33:00+03	38900.00
576CA3	2017-07-19 23:21:00+03	76600.00
576CAE	2017-08-05 06:37:00+03	252700.00
576CE4	2017-08-13 01:19:00+03	55800.00
576D15	2017-08-13 22:47:00+03	40100.00
576D25	2017-07-30 20:01:00+03	57700.00
576D76	2017-07-12 16:28:00+03	37400.00
576DDB	2017-08-15 00:08:00+03	41800.00
576E41	2017-07-23 04:00:00+03	133100.00
576E8E	2017-08-12 01:31:00+03	422900.00
576EA1	2017-07-13 06:09:00+03	27200.00
576EC6	2017-07-23 04:17:00+03	14000.00
576EEF	2017-07-17 08:39:00+03	75300.00
576EFE	2017-07-30 05:53:00+03	190400.00
576F09	2017-08-06 12:08:00+03	98400.00
576F44	2017-08-14 21:54:00+03	48100.00
576F4D	2017-07-26 15:47:00+03	22200.00
576F97	2017-08-03 16:11:00+03	190400.00
577042	2017-07-16 18:38:00+03	187600.00
57705B	2017-07-19 00:08:00+03	75300.00
577073	2017-08-13 23:25:00+03	22600.00
5770EF	2017-07-21 06:28:00+03	36200.00
577102	2017-07-17 01:55:00+03	66100.00
577131	2017-07-31 05:08:00+03	28000.00
577191	2017-08-04 16:32:00+03	43200.00
5771A0	2017-07-21 12:41:00+03	55600.00
5771CC	2017-07-03 12:56:00+03	46200.00
57721A	2017-07-29 20:43:00+03	112000.00
577246	2017-07-13 07:27:00+03	114700.00
577284	2017-07-12 15:47:00+03	25400.00
5772AC	2017-07-17 14:28:00+03	192400.00
5772E5	2017-08-11 17:31:00+03	48800.00
577322	2017-07-19 03:17:00+03	14400.00
5773B0	2017-08-14 12:48:00+03	123000.00
577432	2017-07-10 12:25:00+03	48500.00
577475	2017-07-17 21:22:00+03	46000.00
577476	2017-07-22 06:03:00+03	76600.00
57748E	2017-07-02 06:02:00+03	66600.00
5774A6	2017-07-21 15:09:00+03	24400.00
5774EA	2017-07-14 09:24:00+03	33100.00
5774F8	2017-07-01 00:16:00+03	26600.00
57753E	2017-07-10 21:49:00+03	55600.00
57756C	2017-07-21 16:03:00+03	23200.00
577574	2017-07-28 20:17:00+03	123000.00
57759D	2017-06-29 17:52:00+03	25600.00
577606	2017-08-08 04:39:00+03	45200.00
577619	2017-07-15 00:29:00+03	51000.00
577676	2017-07-19 09:34:00+03	23600.00
57771F	2017-07-30 03:12:00+03	48800.00
57772C	2017-08-03 20:03:00+03	6400.00
57774E	2017-08-04 23:57:00+03	43200.00
577750	2017-08-10 18:54:00+03	136000.00
577753	2017-07-28 08:59:00+03	55800.00
57776F	2017-08-10 11:06:00+03	28000.00
577781	2017-07-23 21:45:00+03	6900.00
57778B	2017-07-08 11:05:00+03	57500.00
577790	2017-08-08 08:31:00+03	13000.00
5777B1	2017-08-05 11:09:00+03	26000.00
5778E0	2017-08-01 22:59:00+03	6600.00
577910	2017-08-11 12:50:00+03	103000.00
57794B	2017-08-13 01:35:00+03	46700.00
577969	2017-08-11 04:56:00+03	18600.00
5779E5	2017-07-12 11:40:00+03	147600.00
577A56	2017-07-19 11:53:00+03	31600.00
577A68	2017-08-12 01:42:00+03	515100.00
577ADE	2017-08-12 15:43:00+03	6000.00
577AE6	2017-08-13 04:46:00+03	134200.00
577B72	2017-08-14 10:45:00+03	57400.00
577B80	2017-07-26 18:34:00+03	67600.00
577BB4	2017-07-30 22:54:00+03	81800.00
577C38	2017-07-04 08:30:00+03	46200.00
577C91	2017-07-18 21:02:00+03	30200.00
577C96	2017-08-06 18:31:00+03	69000.00
577CC8	2017-06-30 06:42:00+03	28800.00
577CF0	2017-07-27 08:32:00+03	46400.00
577D08	2017-07-01 09:45:00+03	73200.00
577D43	2017-07-31 09:42:00+03	56000.00
577D4F	2017-07-10 16:27:00+03	11700.00
577D67	2017-07-07 00:21:00+03	12000.00
577D6C	2017-07-31 18:27:00+03	239400.00
577D7C	2017-07-17 14:11:00+03	47200.00
577E12	2017-08-12 15:26:00+03	20200.00
577E34	2017-08-13 15:13:00+03	189800.00
577E6A	2017-07-23 09:46:00+03	40600.00
577E81	2017-07-12 03:08:00+03	23600.00
577EBB	2017-07-12 01:47:00+03	24400.00
577F0E	2017-07-02 08:33:00+03	69500.00
577F16	2017-07-30 19:24:00+03	133700.00
577F3F	2017-07-18 14:56:00+03	75600.00
577F49	2017-07-30 03:02:00+03	133200.00
577F65	2017-07-13 21:31:00+03	266400.00
577F79	2017-07-17 19:13:00+03	29600.00
577F82	2017-08-05 01:36:00+03	100600.00
577F98	2017-08-12 13:19:00+03	8400.00
577FEA	2017-07-09 07:36:00+03	48100.00
57802F	2017-07-15 09:48:00+03	62100.00
578030	2017-07-21 23:24:00+03	72800.00
5780A0	2017-08-01 21:22:00+03	28800.00
5780B4	2017-07-04 04:45:00+03	16400.00
5780E6	2017-07-04 11:38:00+03	65200.00
57812B	2017-07-06 09:43:00+03	47200.00
5781C4	2017-08-04 16:20:00+03	396500.00
578216	2017-07-03 15:36:00+03	28000.00
578260	2017-07-18 06:37:00+03	62000.00
578269	2017-08-12 19:11:00+03	103500.00
5782EF	2017-06-27 05:05:00+03	38400.00
57834A	2017-08-10 08:36:00+03	119500.00
57836A	2017-07-28 01:05:00+03	270800.00
5783A5	2017-07-18 06:00:00+03	28700.00
5783B1	2017-07-23 21:35:00+03	34000.00
578414	2017-08-14 05:40:00+03	93900.00
578416	2017-07-01 09:12:00+03	120700.00
57841E	2017-07-23 12:55:00+03	45200.00
578443	2017-07-20 15:57:00+03	172600.00
578459	2017-07-31 04:42:00+03	35100.00
57849B	2017-08-03 04:38:00+03	6300.00
5784B3	2017-07-06 04:38:00+03	92000.00
578554	2017-07-10 20:59:00+03	28800.00
578582	2017-08-12 11:15:00+03	31600.00
578598	2017-07-10 06:20:00+03	57800.00
5785AC	2017-07-21 00:46:00+03	26800.00
5785DD	2017-08-06 08:00:00+03	40400.00
5785E5	2017-07-14 10:02:00+03	8200.00
578603	2017-07-28 00:34:00+03	30700.00
578630	2017-07-12 01:27:00+03	162700.00
57863A	2017-08-01 20:58:00+03	22600.00
578735	2017-07-13 19:58:00+03	61800.00
578778	2017-08-11 10:27:00+03	7400.00
57877B	2017-07-13 18:01:00+03	19800.00
57878D	2017-07-11 07:06:00+03	215600.00
5787BA	2017-07-18 04:36:00+03	43200.00
5787F2	2017-08-04 13:01:00+03	223200.00
578802	2017-07-03 14:02:00+03	66600.00
57880E	2017-07-12 06:53:00+03	126500.00
57888B	2017-08-02 08:39:00+03	43200.00
5788AB	2017-07-22 01:56:00+03	12600.00
5788B9	2017-08-09 15:02:00+03	26000.00
5788D0	2017-07-19 14:55:00+03	6000.00
578A41	2017-08-14 00:19:00+03	61800.00
578A58	2017-07-24 07:10:00+03	48800.00
578A6E	2017-08-13 15:48:00+03	372500.00
578A88	2017-08-07 21:01:00+03	21400.00
578A96	2017-08-10 05:37:00+03	168000.00
578ADD	2017-07-31 21:56:00+03	43600.00
578B6B	2017-07-17 22:58:00+03	50600.00
578BA8	2017-07-03 03:03:00+03	64500.00
578BF8	2017-08-03 22:31:00+03	23200.00
578C6A	2017-07-31 21:12:00+03	30200.00
578C86	2017-07-16 23:58:00+03	69500.00
578CB6	2017-08-13 10:10:00+03	34000.00
578CC0	2017-07-16 20:42:00+03	87100.00
578CE5	2017-07-04 23:17:00+03	62000.00
578D37	2017-07-24 22:06:00+03	11600.00
578D45	2017-07-24 23:39:00+03	8200.00
578D6C	2017-07-31 03:10:00+03	107200.00
578D6F	2017-07-11 01:16:00+03	8000.00
578DCD	2017-07-28 02:08:00+03	44000.00
578E78	2017-07-08 04:07:00+03	270600.00
578E90	2017-07-18 13:18:00+03	63200.00
578E95	2017-08-01 06:16:00+03	52000.00
578EA1	2017-07-04 08:42:00+03	12600.00
578EEC	2017-07-29 04:39:00+03	23600.00
578EEF	2017-08-10 12:08:00+03	52000.00
578F47	2017-08-03 16:06:00+03	43100.00
578F71	2017-07-23 03:37:00+03	130900.00
578F82	2017-08-11 19:52:00+03	16400.00
578F9A	2017-07-24 08:50:00+03	66000.00
578FBC	2017-07-23 00:29:00+03	57600.00
578FCF	2017-07-17 15:53:00+03	103000.00
578FD3	2017-07-18 23:22:00+03	91700.00
57900E	2017-07-17 07:04:00+03	51500.00
579095	2017-07-08 10:47:00+03	119500.00
57918E	2017-07-30 22:15:00+03	26000.00
5791F8	2017-07-22 07:53:00+03	217600.00
57922F	2017-07-02 19:35:00+03	85700.00
579260	2017-07-09 03:22:00+03	52300.00
579292	2017-07-17 00:55:00+03	257500.00
5792FD	2017-08-14 21:57:00+03	280000.00
579384	2017-07-06 05:15:00+03	21400.00
5793C6	2017-07-05 22:36:00+03	63200.00
57940F	2017-07-07 14:16:00+03	92000.00
579471	2017-07-14 17:45:00+03	254900.00
579520	2017-07-17 23:11:00+03	133200.00
57955E	2017-08-11 18:36:00+03	54400.00
57960C	2017-07-14 00:03:00+03	26700.00
579627	2017-07-17 10:43:00+03	78800.00
57964D	2017-07-07 18:03:00+03	48100.00
579655	2017-07-24 02:31:00+03	76600.00
5796AD	2017-08-07 18:33:00+03	46500.00
5796C4	2017-08-15 08:14:00+03	56000.00
5796F4	2017-06-29 20:37:00+03	26700.00
579754	2017-07-17 20:08:00+03	50600.00
57977E	2017-08-02 21:53:00+03	293700.00
579796	2017-08-14 20:33:00+03	96800.00
5797B7	2017-08-01 10:24:00+03	94900.00
5797C7	2017-07-12 11:50:00+03	30900.00
5797C8	2017-07-20 10:02:00+03	36200.00
5797D2	2017-07-20 13:46:00+03	39800.00
579824	2017-08-05 14:10:00+03	135000.00
579827	2017-07-29 17:45:00+03	31000.00
579828	2017-07-01 05:07:00+03	35600.00
579836	2017-08-13 21:56:00+03	36100.00
579843	2017-08-10 11:51:00+03	47900.00
579847	2017-07-25 12:07:00+03	39800.00
57985D	2017-08-06 22:02:00+03	15400.00
579877	2017-07-01 04:07:00+03	26000.00
579880	2017-07-17 17:49:00+03	31700.00
57989C	2017-07-16 04:31:00+03	118500.00
57993D	2017-07-07 16:00:00+03	54600.00
57995D	2017-08-14 22:19:00+03	91000.00
5799C4	2017-07-27 02:22:00+03	173500.00
5799FD	2017-07-13 18:24:00+03	25100.00
579A15	2017-07-22 11:16:00+03	23600.00
579A3A	2017-08-14 08:31:00+03	47200.00
579A56	2017-08-12 15:52:00+03	91800.00
579A7F	2017-07-25 10:18:00+03	23400.00
579A81	2017-07-11 14:06:00+03	23200.00
579AA7	2017-07-28 07:42:00+03	54400.00
579ABE	2017-07-16 19:21:00+03	92600.00
579AEC	2017-07-08 15:01:00+03	133100.00
579BDD	2017-07-08 22:06:00+03	20600.00
579BE4	2017-07-03 17:58:00+03	36200.00
579C0A	2017-08-06 10:41:00+03	69000.00
579C6E	2017-08-09 04:36:00+03	162900.00
579C96	2017-07-12 09:07:00+03	56000.00
579CDB	2017-08-13 05:19:00+03	80700.00
579D04	2017-08-13 21:23:00+03	25600.00
579D17	2017-07-18 13:34:00+03	6300.00
579D20	2017-08-06 04:26:00+03	239100.00
579D4F	2017-07-14 21:41:00+03	148200.00
579D95	2017-07-19 19:19:00+03	134400.00
579E0E	2017-07-21 15:52:00+03	52000.00
579E60	2017-07-04 06:20:00+03	83600.00
579EF7	2017-07-28 03:28:00+03	89700.00
579EFD	2017-07-23 16:04:00+03	21400.00
579F2C	2017-07-31 09:33:00+03	117600.00
579F78	2017-07-24 06:48:00+03	97900.00
579F81	2017-07-07 18:36:00+03	43200.00
579F8C	2017-07-17 02:14:00+03	23600.00
57A00E	2017-07-29 17:12:00+03	28000.00
57A029	2017-07-18 18:10:00+03	64200.00
57A17A	2017-08-12 23:37:00+03	115700.00
57A17E	2017-07-08 01:42:00+03	6300.00
57A182	2017-08-03 04:21:00+03	13400.00
57A1E0	2017-07-16 23:39:00+03	16400.00
57A24E	2017-07-20 22:57:00+03	23600.00
57A2BC	2017-07-28 21:19:00+03	80700.00
57A2BE	2017-08-14 10:52:00+03	97900.00
57A2CF	2017-08-01 00:35:00+03	29600.00
57A2D7	2017-07-02 03:26:00+03	32800.00
57A2EE	2017-07-28 03:03:00+03	23100.00
57A33D	2017-07-10 15:49:00+03	28600.00
57A406	2017-07-17 07:31:00+03	246000.00
57A4CF	2017-07-02 03:42:00+03	30800.00
57A4DA	2017-07-23 09:08:00+03	27700.00
57A4ED	2017-07-04 08:39:00+03	89400.00
57A509	2017-07-18 05:59:00+03	55800.00
57A536	2017-07-29 12:56:00+03	20200.00
57A623	2017-07-01 03:59:00+03	38600.00
57A64F	2017-07-26 19:20:00+03	135400.00
57A661	2017-08-01 09:29:00+03	92900.00
57A672	2017-07-09 14:36:00+03	72400.00
57A683	2017-08-15 03:16:00+03	23600.00
57A686	2017-07-29 01:02:00+03	22000.00
57A6B2	2017-08-05 13:40:00+03	54800.00
57A6C0	2017-07-14 23:18:00+03	86100.00
57A6E7	2017-07-27 10:40:00+03	57600.00
57A6FD	2017-08-02 14:13:00+03	16400.00
57A729	2017-07-20 13:28:00+03	67700.00
57A79F	2017-08-01 08:52:00+03	38600.00
57A7D1	2017-07-08 01:05:00+03	78100.00
57A7DD	2017-07-04 16:41:00+03	39600.00
57A7ED	2017-07-10 22:09:00+03	169900.00
57A82F	2017-07-13 00:50:00+03	23200.00
57A847	2017-08-08 02:16:00+03	16400.00
57A857	2017-08-02 22:18:00+03	89700.00
57A876	2017-07-20 11:45:00+03	99300.00
57A8D3	2017-07-12 13:31:00+03	81600.00
57A8EB	2017-07-10 12:52:00+03	14000.00
57A8FC	2017-07-19 21:55:00+03	65100.00
57A8FE	2017-08-10 23:10:00+03	59000.00
57A914	2017-07-09 00:50:00+03	28800.00
57A921	2017-07-14 22:50:00+03	349200.00
57A92D	2017-07-10 15:37:00+03	48800.00
57AA18	2017-07-08 04:15:00+03	43400.00
57AA25	2017-07-14 06:02:00+03	23800.00
57AA26	2017-07-23 17:39:00+03	46400.00
57AA9A	2017-07-16 01:45:00+03	70000.00
57AB71	2017-07-23 15:52:00+03	40800.00
57ABA6	2017-07-14 02:20:00+03	58400.00
57AC26	2017-08-07 08:46:00+03	16800.00
57AC44	2017-07-13 19:52:00+03	67600.00
57AC94	2017-07-23 20:14:00+03	26000.00
57AC95	2017-08-01 22:37:00+03	28800.00
57AD7D	2017-08-04 23:44:00+03	138000.00
57ADB6	2017-07-01 23:02:00+03	88600.00
57ADC9	2017-08-02 16:01:00+03	49800.00
57AE11	2017-08-14 08:08:00+03	23200.00
57AE12	2017-08-06 09:14:00+03	40800.00
57AE6F	2017-07-24 16:44:00+03	47500.00
57AEBE	2017-07-13 04:32:00+03	54000.00
57AEC7	2017-06-29 09:16:00+03	112000.00
57AED8	2017-07-14 03:19:00+03	104000.00
57AF1F	2017-07-10 10:43:00+03	28800.00
57AF70	2017-08-03 08:09:00+03	62100.00
57AF81	2017-07-09 21:45:00+03	66600.00
57AF8E	2017-08-06 21:48:00+03	187800.00
57B03C	2017-08-02 09:20:00+03	10700.00
57B05B	2017-07-25 19:47:00+03	362100.00
57B133	2017-07-09 19:49:00+03	75100.00
57B1CB	2017-08-02 14:53:00+03	136000.00
57B267	2017-07-12 22:51:00+03	151200.00
57B275	2017-07-15 12:38:00+03	126600.00
57B294	2017-07-01 11:48:00+03	66600.00
57B2C4	2017-08-01 06:01:00+03	65600.00
57B2D0	2017-08-15 17:52:00+03	32400.00
57B309	2017-08-01 16:56:00+03	29200.00
57B310	2017-07-14 01:53:00+03	116400.00
57B3DC	2017-07-09 05:52:00+03	83300.00
57B3E6	2017-08-12 11:26:00+03	58900.00
57B46E	2017-07-22 14:16:00+03	44000.00
57B474	2017-07-13 15:35:00+03	131100.00
57B49F	2017-08-01 00:13:00+03	248300.00
57B4B3	2017-07-09 21:40:00+03	23200.00
57B4FE	2017-07-30 15:12:00+03	32700.00
57B580	2017-08-06 01:27:00+03	57800.00
57B5A9	2017-07-22 20:44:00+03	126300.00
57B656	2017-08-03 18:52:00+03	23600.00
57B6A4	2017-08-03 16:23:00+03	92100.00
57B768	2017-08-14 22:26:00+03	65400.00
57B7B5	2017-08-10 14:31:00+03	28800.00
57B809	2017-07-11 06:15:00+03	55800.00
57B8C5	2017-07-14 21:47:00+03	53300.00
57B8EC	2017-07-31 07:05:00+03	25000.00
57B901	2017-08-03 20:36:00+03	114700.00
57B935	2017-08-04 21:14:00+03	42000.00
57B953	2017-08-01 16:13:00+03	28600.00
57B965	2017-07-22 14:57:00+03	100200.00
57B9A9	2017-08-08 09:35:00+03	68000.00
57B9BE	2017-07-27 18:10:00+03	231900.00
57B9C2	2017-07-05 16:27:00+03	49600.00
57BA1D	2017-07-09 10:34:00+03	27200.00
57BA42	2017-08-08 16:19:00+03	120000.00
57BA5C	2017-07-24 22:40:00+03	90800.00
57BA9D	2017-07-11 15:58:00+03	13800.00
57BAE2	2017-07-27 17:08:00+03	20000.00
57BAEA	2017-07-16 22:57:00+03	75300.00
57BB20	2017-08-05 13:27:00+03	133100.00
57BB2B	2017-07-17 22:18:00+03	59000.00
57BB42	2017-08-06 15:31:00+03	28000.00
57BB5E	2017-07-14 13:43:00+03	43600.00
57BB93	2017-07-25 22:45:00+03	103000.00
57BC39	2017-07-22 07:11:00+03	68100.00
57BCF5	2017-07-31 23:08:00+03	80000.00
57BD61	2017-07-11 16:34:00+03	43600.00
57BE1E	2017-07-24 05:18:00+03	111600.00
57BE88	2017-08-13 12:55:00+03	53100.00
57BF03	2017-07-28 04:38:00+03	65900.00
57BF1E	2017-08-04 20:41:00+03	46400.00
57BF22	2017-07-31 07:20:00+03	13000.00
57BF24	2017-08-14 03:55:00+03	37100.00
57BF26	2017-07-25 18:33:00+03	26000.00
57BF7A	2017-07-16 18:23:00+03	112800.00
57BF85	2017-08-15 04:58:00+03	213200.00
57BF93	2017-07-20 13:12:00+03	8200.00
57BFA9	2017-07-20 14:50:00+03	20200.00
57C013	2017-08-15 15:28:00+03	22000.00
57C053	2017-08-05 02:22:00+03	57600.00
57C06A	2017-06-27 11:20:00+03	67400.00
57C07C	2017-08-06 07:57:00+03	28800.00
57C0FB	2017-07-23 14:50:00+03	266400.00
57C14E	2017-07-08 05:17:00+03	117600.00
57C1DB	2017-07-24 03:43:00+03	18400.00
57C209	2017-07-22 04:51:00+03	46000.00
57C230	2017-07-03 15:02:00+03	25100.00
57C297	2017-07-24 08:08:00+03	57100.00
57C29B	2017-08-14 04:39:00+03	23200.00
57C2D1	2017-07-17 02:02:00+03	27200.00
57C33A	2017-07-24 10:30:00+03	65500.00
57C33F	2017-07-30 15:10:00+03	63700.00
57C39F	2017-07-07 07:47:00+03	55600.00
57C406	2017-07-15 20:43:00+03	11600.00
57C442	2017-07-03 04:09:00+03	25600.00
57C44B	2017-08-08 18:09:00+03	81600.00
57C472	2017-08-04 11:07:00+03	21800.00
57C47E	2017-07-10 23:11:00+03	26100.00
57C521	2017-08-02 15:02:00+03	266400.00
57C525	2017-07-10 04:19:00+03	99600.00
57C5E1	2017-08-05 15:34:00+03	62600.00
57C60F	2017-07-28 03:14:00+03	70200.00
57C6A8	2017-08-10 22:31:00+03	149300.00
57C6C6	2017-07-08 12:30:00+03	291600.00
57C743	2017-07-13 23:06:00+03	28000.00
57C79D	2017-08-10 09:21:00+03	25600.00
57C7AE	2017-06-30 06:40:00+03	132800.00
57C8CC	2017-07-10 21:05:00+03	40100.00
57C8D7	2017-08-10 23:55:00+03	182300.00
57C8F3	2017-08-14 04:26:00+03	62600.00
57C920	2017-07-27 19:37:00+03	65100.00
57C950	2017-08-01 05:35:00+03	31500.00
57C990	2017-07-07 21:05:00+03	37900.00
57C9B7	2017-07-20 06:16:00+03	32200.00
57C9C4	2017-08-09 07:39:00+03	37200.00
57C9CD	2017-07-03 07:29:00+03	136800.00
57CA0F	2017-07-29 15:57:00+03	31600.00
57CA46	2017-07-16 11:47:00+03	32800.00
57CA71	2017-08-09 22:26:00+03	133100.00
57CA8F	2017-07-25 07:05:00+03	101000.00
57CA96	2017-07-13 23:55:00+03	48800.00
57CA9D	2017-06-30 07:22:00+03	13400.00
57CAA6	2017-08-07 11:09:00+03	13800.00
57CAB1	2017-08-13 19:24:00+03	43000.00
57CAD0	2017-07-02 15:53:00+03	32200.00
57CB50	2017-07-05 00:12:00+03	46200.00
57CB65	2017-07-06 08:58:00+03	28600.00
57CB6C	2017-07-06 01:55:00+03	26000.00
57CBA9	2017-08-10 09:17:00+03	145100.00
57CBB3	2017-08-13 14:18:00+03	28000.00
57CC1C	2017-08-07 16:35:00+03	56900.00
57CD50	2017-06-28 03:36:00+03	57800.00
57CD5E	2017-06-29 23:14:00+03	32200.00
57CDA1	2017-08-14 07:47:00+03	256300.00
57CDDB	2017-07-17 15:10:00+03	42400.00
57CDEB	2017-07-07 04:24:00+03	81300.00
57CE51	2017-08-13 19:59:00+03	198400.00
57CE6B	2017-07-14 19:07:00+03	201200.00
57CEE7	2017-08-10 01:21:00+03	67600.00
57CF31	2017-07-28 12:44:00+03	133100.00
57CF81	2017-07-16 08:17:00+03	85700.00
57CF9E	2017-08-10 20:27:00+03	44000.00
57D02B	2017-08-11 01:46:00+03	24400.00
57D0B6	2017-07-20 06:49:00+03	24400.00
57D15A	2017-07-09 13:13:00+03	115800.00
57D19C	2017-07-21 14:36:00+03	28000.00
57D226	2017-07-21 00:33:00+03	46400.00
57D27B	2017-08-07 04:56:00+03	28000.00
57D2B4	2017-07-13 02:21:00+03	86400.00
57D2C6	2017-08-05 08:33:00+03	6000.00
57D352	2017-08-10 16:54:00+03	70700.00
57D37C	2017-07-14 10:55:00+03	59300.00
57D383	2017-08-05 15:13:00+03	8000.00
57D391	2017-08-15 08:09:00+03	14000.00
57D588	2017-07-22 06:24:00+03	85000.00
57D5B7	2017-07-25 00:56:00+03	272800.00
57D5B8	2017-07-06 01:25:00+03	89700.00
57D5CC	2017-07-22 13:12:00+03	28000.00
57D64E	2017-07-12 00:45:00+03	129600.00
57D651	2017-07-17 20:25:00+03	98600.00
57D65E	2017-07-29 12:44:00+03	36000.00
57D68B	2017-07-19 05:56:00+03	25100.00
57D6E0	2017-07-09 22:40:00+03	77200.00
57D6F9	2017-07-22 15:39:00+03	61100.00
57D7B5	2017-08-06 07:56:00+03	26500.00
57D836	2017-08-08 03:26:00+03	55600.00
57D85D	2017-07-24 09:35:00+03	229300.00
57D884	2017-08-12 20:50:00+03	29500.00
57D88F	2017-08-08 03:38:00+03	283100.00
57D89C	2017-08-01 19:39:00+03	30200.00
57D93D	2017-07-05 16:08:00+03	29600.00
57D9C7	2017-07-28 12:20:00+03	75300.00
57D9EE	2017-08-13 13:28:00+03	25400.00
57DA05	2017-07-03 07:48:00+03	241300.00
57DA76	2017-07-09 02:18:00+03	89200.00
57DA7A	2017-08-14 00:24:00+03	75300.00
57DA94	2017-08-09 07:37:00+03	28000.00
57DAA8	2017-07-07 02:48:00+03	24300.00
57DAF9	2017-07-29 19:20:00+03	24000.00
57DAFB	2017-07-23 13:17:00+03	170800.00
57DB2D	2017-07-23 07:15:00+03	117600.00
57DB58	2017-07-20 13:58:00+03	78600.00
57DB64	2017-08-06 18:26:00+03	6700.00
57DBA6	2017-07-17 02:49:00+03	99200.00
57DBCE	2017-07-29 10:13:00+03	19000.00
57DC68	2017-08-03 10:08:00+03	36200.00
57DC8E	2017-08-07 06:40:00+03	58200.00
57DCA8	2017-07-02 12:59:00+03	85600.00
57DD54	2017-08-05 06:12:00+03	161900.00
57DD81	2017-08-11 01:43:00+03	99200.00
57DDAD	2017-08-02 17:27:00+03	118300.00
57DDD4	2017-08-06 00:23:00+03	64400.00
57DDE7	2017-08-07 01:13:00+03	111600.00
57DE24	2017-08-04 13:18:00+03	12600.00
57DE31	2017-08-11 14:22:00+03	139100.00
57DE53	2017-07-09 01:46:00+03	402400.00
57DE6D	2017-07-29 04:26:00+03	105700.00
57DEF2	2017-07-09 07:04:00+03	65400.00
57DEFC	2017-08-02 16:48:00+03	26800.00
57DF6B	2017-08-12 05:35:00+03	143400.00
57DFBC	2017-08-15 10:04:00+03	115700.00
57E03D	2017-07-05 05:07:00+03	20800.00
57E09E	2017-07-25 05:13:00+03	29500.00
57E0E6	2017-08-06 08:06:00+03	73500.00
57E141	2017-07-28 15:07:00+03	69500.00
57E187	2017-08-12 06:49:00+03	272400.00
57E1A2	2017-07-12 23:55:00+03	56900.00
57E294	2017-07-29 22:21:00+03	40800.00
57E2D3	2017-07-08 17:26:00+03	15100.00
57E361	2017-07-14 08:35:00+03	98800.00
57E383	2017-07-29 07:48:00+03	68800.00
57E3B7	2017-08-12 22:55:00+03	8200.00
57E3B9	2017-07-06 16:02:00+03	56000.00
57E3F3	2017-08-07 20:25:00+03	30200.00
57E4B2	2017-07-16 11:02:00+03	33400.00
57E4E8	2017-07-07 06:55:00+03	14000.00
57E53B	2017-07-24 17:44:00+03	123000.00
57E544	2017-07-06 18:50:00+03	40800.00
57E556	2017-07-13 02:11:00+03	97200.00
57E581	2017-07-18 03:49:00+03	28000.00
57E690	2017-07-21 17:31:00+03	58200.00
57E701	2017-07-30 18:56:00+03	15400.00
57E781	2017-08-15 08:36:00+03	115200.00
57E7A8	2017-07-22 11:58:00+03	28000.00
57E7B2	2017-08-15 11:47:00+03	42600.00
57E845	2017-08-06 20:17:00+03	47200.00
57E8D0	2017-07-12 17:25:00+03	133700.00
57E8E3	2017-07-04 11:58:00+03	100700.00
57E8EA	2017-07-01 05:15:00+03	267000.00
57E92B	2017-08-02 14:35:00+03	89500.00
57E977	2017-07-29 06:29:00+03	163400.00
57E982	2017-07-16 00:42:00+03	75600.00
57E99A	2017-08-12 21:03:00+03	94400.00
57E9ED	2017-07-27 01:08:00+03	167200.00
57EA37	2017-07-24 12:33:00+03	67400.00
57EA57	2017-07-23 11:29:00+03	35800.00
57EA75	2017-08-09 20:39:00+03	40300.00
57EA99	2017-07-19 05:15:00+03	23400.00
57EA9F	2017-07-28 08:45:00+03	94800.00
57EB19	2017-08-07 07:55:00+03	81900.00
57EB77	2017-07-24 11:53:00+03	92700.00
57EBC3	2017-07-10 05:33:00+03	78200.00
57EBDE	2017-07-17 06:13:00+03	27400.00
57EBFB	2017-07-27 21:12:00+03	246000.00
57EC03	2017-07-23 09:16:00+03	53600.00
57EC0C	2017-06-28 22:45:00+03	23400.00
57EC10	2017-07-08 19:09:00+03	66600.00
57EC28	2017-07-21 02:07:00+03	6400.00
57EC4B	2017-08-04 16:25:00+03	65000.00
57EC9E	2017-07-01 02:36:00+03	167400.00
57ECA1	2017-07-05 19:20:00+03	56000.00
57ECB7	2017-08-12 12:17:00+03	40600.00
57ED61	2017-07-28 06:51:00+03	47200.00
57ED68	2017-08-09 09:16:00+03	7400.00
57EDB2	2017-07-14 11:11:00+03	20200.00
57EDD0	2017-08-08 02:50:00+03	38400.00
57EE35	2017-08-09 18:01:00+03	27600.00
57EE4E	2017-08-10 17:55:00+03	59300.00
57EE57	2017-08-10 11:00:00+03	98400.00
57EED4	2017-08-12 10:50:00+03	109500.00
57EF03	2017-08-09 22:41:00+03	38400.00
57EFB8	2017-07-12 01:11:00+03	25200.00
57EFCE	2017-08-03 16:55:00+03	27300.00
57EFFE	2017-08-12 07:52:00+03	103500.00
57F01C	2017-07-23 23:45:00+03	26000.00
57F02B	2017-07-25 19:47:00+03	258700.00
57F030	2017-07-16 02:30:00+03	135200.00
57F1E1	2017-07-10 00:10:00+03	99200.00
57F1F2	2017-08-09 05:46:00+03	47000.00
57F26B	2017-08-14 13:45:00+03	97500.00
57F279	2017-08-05 10:28:00+03	83000.00
57F285	2017-07-16 21:34:00+03	75300.00
57F28B	2017-08-09 15:14:00+03	273000.00
57F2A6	2017-07-28 20:26:00+03	16400.00
57F30C	2017-07-08 20:56:00+03	27200.00
57F317	2017-08-07 00:18:00+03	56000.00
57F326	2017-08-08 11:21:00+03	95200.00
57F430	2017-08-01 06:15:00+03	81600.00
57F43A	2017-08-01 12:38:00+03	92900.00
57F43C	2017-07-03 08:43:00+03	108500.00
57F43F	2017-07-07 07:50:00+03	74900.00
57F499	2017-07-03 11:00:00+03	46900.00
57F4C5	2017-08-13 03:58:00+03	12600.00
57F4E1	2017-07-22 05:40:00+03	138900.00
57F4E3	2017-07-17 08:18:00+03	123000.00
57F521	2017-07-26 08:42:00+03	246000.00
57F587	2017-08-06 10:43:00+03	82900.00
57F58D	2017-07-27 15:10:00+03	11600.00
57F5C8	2017-07-27 03:07:00+03	74400.00
57F5D2	2017-07-03 01:25:00+03	7400.00
57F5EB	2017-07-31 16:38:00+03	410200.00
57F62D	2017-07-18 01:00:00+03	92800.00
57F630	2017-07-10 07:40:00+03	69500.00
57F639	2017-08-02 07:48:00+03	46300.00
57F664	2017-07-30 20:39:00+03	113200.00
57F66B	2017-07-25 04:15:00+03	83000.00
57F6AF	2017-07-19 22:57:00+03	70700.00
57F74A	2017-08-05 21:17:00+03	55800.00
57F778	2017-07-06 01:37:00+03	100600.00
57F779	2017-07-25 04:40:00+03	52100.00
57F7B9	2017-07-17 19:52:00+03	47200.00
57F849	2017-08-02 17:29:00+03	28800.00
57F8D3	2017-07-14 07:59:00+03	110500.00
57F8D9	2017-07-24 11:53:00+03	149100.00
57F8E5	2017-07-01 14:38:00+03	81300.00
57F961	2017-07-30 15:36:00+03	12700.00
57F9B9	2017-07-12 18:59:00+03	23600.00
57F9CB	2017-07-06 18:56:00+03	38800.00
57FA09	2017-07-05 00:12:00+03	3700.00
57FA17	2017-07-18 15:10:00+03	39300.00
57FA4D	2017-07-20 06:14:00+03	28800.00
57FA65	2017-07-29 06:59:00+03	48800.00
57FA79	2017-08-12 09:36:00+03	43600.00
57FA7D	2017-07-04 04:47:00+03	55000.00
57FA7E	2017-08-03 00:02:00+03	28800.00
57FA83	2017-08-13 23:46:00+03	170800.00
57FABA	2017-08-13 10:22:00+03	170800.00
57FAD3	2017-08-10 23:40:00+03	23100.00
57FB11	2017-07-22 18:02:00+03	23200.00
57FB7A	2017-07-23 13:40:00+03	83600.00
57FB90	2017-08-08 17:06:00+03	66600.00
57FC8B	2017-07-25 08:06:00+03	69000.00
57FC98	2017-07-21 17:03:00+03	28000.00
57FCD8	2017-08-15 14:22:00+03	29900.00
57FD2D	2017-07-05 11:03:00+03	66600.00
57FD58	2017-08-11 20:41:00+03	35700.00
57FD70	2017-07-28 22:53:00+03	80500.00
57FDB8	2017-07-27 21:38:00+03	22000.00
57FDEB	2017-07-19 13:50:00+03	31200.00
57FE08	2017-07-23 17:45:00+03	59200.00
57FE1A	2017-07-06 22:39:00+03	67200.00
57FE36	2017-08-09 04:29:00+03	26700.00
57FE5B	2017-08-02 11:38:00+03	9200.00
57FEFB	2017-08-05 13:17:00+03	88600.00
57FF03	2017-07-05 08:05:00+03	56200.00
57FF42	2017-07-08 12:45:00+03	26200.00
57FFC4	2017-07-07 23:43:00+03	63200.00
57FFCC	2017-08-15 14:56:00+03	23600.00
57FFEE	2017-08-12 20:01:00+03	111600.00
5800FC	2017-07-12 09:28:00+03	387200.00
580174	2017-07-25 09:55:00+03	96800.00
58019E	2017-08-01 00:50:00+03	46400.00
5801A8	2017-07-16 18:58:00+03	160600.00
5801C5	2017-07-25 06:23:00+03	29600.00
580226	2017-08-15 02:35:00+03	43900.00
58023C	2017-07-06 06:58:00+03	52400.00
580258	2017-07-28 16:24:00+03	15000.00
580274	2017-08-12 08:59:00+03	40000.00
5802EE	2017-07-20 04:25:00+03	125200.00
5803E6	2017-07-14 23:15:00+03	56000.00
580463	2017-07-06 03:03:00+03	47800.00
58051C	2017-08-05 22:20:00+03	70600.00
5805A7	2017-07-15 12:24:00+03	46200.00
5805AC	2017-07-13 11:33:00+03	147700.00
5805AE	2017-07-15 18:00:00+03	75300.00
5805C7	2017-07-18 16:36:00+03	12600.00
580615	2017-07-11 03:07:00+03	199200.00
58062B	2017-07-22 01:46:00+03	67200.00
5806A4	2017-07-04 14:35:00+03	27600.00
5806CF	2017-08-03 07:50:00+03	16400.00
580716	2017-08-13 19:24:00+03	58400.00
580742	2017-07-30 09:28:00+03	88600.00
58077D	2017-08-14 22:54:00+03	23200.00
58078C	2017-07-11 07:32:00+03	88100.00
58078E	2017-07-17 01:28:00+03	44600.00
5807C1	2017-07-27 08:25:00+03	31200.00
5807C5	2017-08-02 13:44:00+03	44800.00
58082F	2017-07-07 01:29:00+03	55400.00
580871	2017-07-27 14:35:00+03	28000.00
5808BC	2017-07-31 12:38:00+03	23400.00
5808C8	2017-07-04 08:29:00+03	56000.00
5808CA	2017-06-28 04:46:00+03	47500.00
58090F	2017-07-09 19:25:00+03	64500.00
580997	2017-07-15 23:20:00+03	45400.00
5809B0	2017-08-05 08:52:00+03	12600.00
5809E0	2017-08-08 02:42:00+03	28800.00
580A18	2017-07-27 12:21:00+03	133200.00
580A37	2017-07-17 20:28:00+03	52900.00
580A62	2017-07-31 04:50:00+03	92900.00
580A7C	2017-08-13 17:29:00+03	65300.00
580B22	2017-08-13 02:39:00+03	54400.00
580B41	2017-08-10 14:43:00+03	104400.00
580BF0	2017-07-22 03:05:00+03	68400.00
580CD9	2017-07-19 00:25:00+03	23200.00
580D11	2017-08-01 11:27:00+03	43600.00
580D22	2017-07-24 15:59:00+03	133100.00
580D59	2017-08-14 19:35:00+03	53600.00
580D80	2017-07-20 03:46:00+03	7200.00
580DB8	2017-07-31 22:59:00+03	31600.00
580DBC	2017-08-14 22:32:00+03	13700.00
580E20	2017-08-04 11:52:00+03	159800.00
580EB2	2017-07-03 02:31:00+03	52700.00
580EDC	2017-08-04 16:34:00+03	189800.00
580F0D	2017-07-12 20:33:00+03	136800.00
580FC0	2017-07-09 08:39:00+03	123000.00
580FC9	2017-07-29 01:02:00+03	56600.00
581009	2017-07-25 00:31:00+03	21400.00
5810C2	2017-06-30 17:36:00+03	8400.00
58111C	2017-08-11 16:46:00+03	28000.00
581124	2017-07-05 01:34:00+03	113700.00
581142	2017-07-16 11:45:00+03	53700.00
581174	2017-07-06 06:48:00+03	20000.00
581186	2017-08-07 20:23:00+03	42700.00
581208	2017-07-27 15:24:00+03	27000.00
58125F	2017-08-09 21:23:00+03	69000.00
581266	2017-08-09 21:14:00+03	147100.00
5812A2	2017-07-15 14:43:00+03	201200.00
5812A9	2017-08-10 04:15:00+03	26000.00
5812EB	2017-08-04 04:49:00+03	72000.00
58135C	2017-07-25 17:27:00+03	77200.00
581428	2017-07-23 19:53:00+03	24400.00
5814FF	2017-08-10 10:00:00+03	48100.00
581502	2017-07-14 21:25:00+03	265700.00
581548	2017-06-27 21:49:00+03	41400.00
581550	2017-08-03 16:30:00+03	71200.00
5815AA	2017-08-07 04:12:00+03	59300.00
5815DA	2017-08-09 03:01:00+03	295400.00
58160C	2017-07-23 13:36:00+03	26000.00
5816B7	2017-08-14 01:42:00+03	42400.00
581700	2017-07-18 00:13:00+03	55800.00
581856	2017-07-22 17:52:00+03	24400.00
581871	2017-07-21 20:38:00+03	54800.00
581877	2017-07-25 16:11:00+03	61700.00
5818DC	2017-07-17 04:38:00+03	18800.00
581904	2017-08-07 20:26:00+03	26600.00
581905	2017-07-31 08:05:00+03	93400.00
581907	2017-07-31 01:51:00+03	23200.00
581992	2017-07-15 16:55:00+03	106700.00
58199A	2017-07-27 19:37:00+03	75600.00
581A22	2017-07-22 01:58:00+03	59300.00
581A48	2017-08-03 16:10:00+03	26000.00
581AA7	2017-08-12 05:03:00+03	26700.00
581B24	2017-07-18 02:53:00+03	38300.00
581B2E	2017-07-19 14:55:00+03	418400.00
581B2F	2017-07-15 10:14:00+03	73500.00
581B7E	2017-07-31 19:17:00+03	68800.00
581B87	2017-07-29 01:11:00+03	135200.00
581BA2	2017-07-04 01:18:00+03	30800.00
581BC3	2017-07-18 09:15:00+03	57600.00
581C1E	2017-08-12 06:46:00+03	43900.00
581C51	2017-07-28 22:10:00+03	66000.00
581CD5	2017-07-02 14:53:00+03	130900.00
581D3E	2017-07-07 20:17:00+03	6700.00
581D56	2017-07-10 13:46:00+03	20200.00
581D73	2017-07-16 14:14:00+03	89600.00
581DD9	2017-07-18 01:15:00+03	116900.00
581DF6	2017-08-01 10:30:00+03	28800.00
581E05	2017-07-04 17:50:00+03	49200.00
581E2A	2017-07-24 01:12:00+03	81200.00
581E8F	2017-07-09 04:37:00+03	46200.00
581EF7	2017-07-26 11:49:00+03	62600.00
581F6C	2017-08-11 12:31:00+03	147100.00
581FB7	2017-08-10 23:06:00+03	29200.00
581FBB	2017-08-06 21:37:00+03	28800.00
581FC6	2017-07-21 14:25:00+03	149800.00
581FF3	2017-07-05 06:32:00+03	93900.00
582039	2017-07-26 20:10:00+03	96800.00
5820CB	2017-08-13 16:04:00+03	254900.00
5820ED	2017-07-30 11:03:00+03	102300.00
5821BF	2017-07-11 00:26:00+03	11800.00
5821D1	2017-07-30 19:26:00+03	12400.00
582217	2017-07-14 10:08:00+03	58000.00
582219	2017-07-28 02:34:00+03	46400.00
582244	2017-06-30 10:36:00+03	59800.00
5822B3	2017-07-06 12:01:00+03	168600.00
5822D7	2017-08-09 01:08:00+03	409700.00
58233F	2017-07-31 21:39:00+03	132800.00
58246C	2017-07-01 15:57:00+03	35600.00
582482	2017-07-31 14:57:00+03	163500.00
582491	2017-07-29 10:35:00+03	21800.00
5824E7	2017-08-07 11:55:00+03	123400.00
58257C	2017-08-13 04:17:00+03	109600.00
58257F	2017-06-26 16:21:00+03	12600.00
5825AC	2017-07-29 18:04:00+03	38800.00
582600	2017-07-08 14:47:00+03	46300.00
58261E	2017-07-25 21:56:00+03	97100.00
582663	2017-07-04 09:09:00+03	66600.00
582666	2017-08-04 01:58:00+03	89700.00
582685	2017-07-15 19:12:00+03	29600.00
58268A	2017-08-03 21:15:00+03	7400.00
5826E0	2017-07-25 11:17:00+03	11000.00
582745	2017-07-15 11:09:00+03	28000.00
5827D0	2017-07-13 19:15:00+03	43400.00
5827F0	2017-07-10 21:11:00+03	147300.00
582818	2017-08-14 20:11:00+03	28800.00
582822	2017-07-28 00:52:00+03	168000.00
5828FC	2017-08-12 14:54:00+03	59300.00
582998	2017-07-28 21:31:00+03	100600.00
5829C0	2017-08-13 22:08:00+03	18100.00
582A11	2017-08-09 08:12:00+03	31600.00
582A1B	2017-07-27 14:54:00+03	43200.00
582A35	2017-07-18 18:55:00+03	29600.00
582A77	2017-08-10 12:34:00+03	26700.00
582A7A	2017-08-10 16:13:00+03	46800.00
582AA3	2017-08-04 21:29:00+03	58400.00
582AA7	2017-07-28 23:27:00+03	495500.00
582ACF	2017-07-04 15:42:00+03	28800.00
582B12	2017-07-02 01:27:00+03	46000.00
582B33	2017-07-11 05:11:00+03	75300.00
582B95	2017-08-09 15:29:00+03	65500.00
582BA5	2017-08-02 09:36:00+03	109500.00
582BA8	2017-08-05 04:02:00+03	111600.00
582C29	2017-07-01 17:02:00+03	77600.00
582C2C	2017-08-03 23:33:00+03	71200.00
582C4C	2017-08-14 11:12:00+03	81700.00
582C58	2017-08-09 09:07:00+03	31600.00
582CA1	2017-07-31 12:19:00+03	154300.00
582D89	2017-08-02 02:25:00+03	101100.00
582E47	2017-07-24 10:51:00+03	24400.00
582E89	2017-07-04 13:56:00+03	201200.00
582E93	2017-07-03 11:23:00+03	92700.00
582F77	2017-07-25 07:13:00+03	53400.00
582F83	2017-07-19 09:49:00+03	39800.00
582FB6	2017-07-04 04:14:00+03	114700.00
582FBA	2017-07-08 20:20:00+03	30300.00
583002	2017-07-17 10:42:00+03	39500.00
583051	2017-07-17 04:20:00+03	83000.00
583076	2017-07-23 17:46:00+03	94200.00
5830D8	2017-08-12 12:13:00+03	73600.00
5830FD	2017-07-06 11:20:00+03	105400.00
583105	2017-07-22 13:54:00+03	103200.00
58314B	2017-08-06 09:51:00+03	89200.00
583171	2017-07-24 22:15:00+03	258300.00
58317C	2017-07-29 17:52:00+03	15100.00
58319A	2017-06-28 18:21:00+03	99700.00
5831A5	2017-08-11 06:15:00+03	112000.00
5831E4	2017-07-25 17:09:00+03	21700.00
5831E8	2017-07-21 00:24:00+03	149800.00
583204	2017-07-18 15:04:00+03	25000.00
58327B	2017-07-06 06:10:00+03	48800.00
58327E	2017-06-29 15:59:00+03	100500.00
583292	2017-07-05 11:48:00+03	32800.00
5832B7	2017-07-05 17:56:00+03	77500.00
5832F2	2017-07-03 19:16:00+03	139300.00
58336C	2017-07-23 07:53:00+03	183300.00
5833A0	2017-08-09 13:16:00+03	54800.00
5833B6	2017-08-05 07:49:00+03	17600.00
5833C6	2017-07-05 01:53:00+03	40800.00
5833D4	2017-07-07 06:36:00+03	160800.00
5833D6	2017-07-18 00:55:00+03	28700.00
5833DF	2017-08-12 17:02:00+03	137700.00
5833E9	2017-07-14 22:55:00+03	44000.00
583416	2017-07-01 03:42:00+03	18000.00
583417	2017-07-10 10:21:00+03	91200.00
58341F	2017-08-02 21:23:00+03	51900.00
5834B9	2017-08-14 00:12:00+03	54800.00
5834C6	2017-07-05 21:09:00+03	89600.00
5834D9	2017-08-08 16:03:00+03	66600.00
58356A	2017-08-03 03:45:00+03	26200.00
58357E	2017-07-24 21:59:00+03	30200.00
5835CA	2017-07-09 13:49:00+03	37700.00
5835DF	2017-07-31 04:32:00+03	86500.00
583619	2017-07-13 13:27:00+03	23200.00
583621	2017-07-24 05:30:00+03	47400.00
58366C	2017-07-18 23:46:00+03	9200.00
5836C1	2017-08-03 06:04:00+03	16400.00
583747	2017-08-09 17:56:00+03	56000.00
583769	2017-07-27 10:19:00+03	95900.00
58378A	2017-08-04 23:34:00+03	20200.00
5837A2	2017-08-06 17:36:00+03	103500.00
5837D8	2017-07-14 15:29:00+03	16400.00
5837EA	2017-07-23 04:30:00+03	132800.00
583828	2017-07-27 01:53:00+03	32400.00
58382D	2017-08-06 20:35:00+03	43600.00
583891	2017-08-14 18:44:00+03	14400.00
5838D0	2017-07-12 17:24:00+03	28000.00
5838EC	2017-07-05 17:06:00+03	21000.00
58390A	2017-08-11 14:59:00+03	56600.00
5839CD	2017-08-13 06:23:00+03	23600.00
583A41	2017-07-14 05:29:00+03	62600.00
583A4B	2017-07-19 13:38:00+03	56000.00
583A76	2017-07-29 20:10:00+03	77200.00
583A97	2017-08-05 07:05:00+03	108300.00
583AAF	2017-08-06 17:55:00+03	68100.00
583ABF	2017-07-27 01:08:00+03	22000.00
583AF4	2017-07-19 04:15:00+03	73600.00
583B14	2017-08-03 06:15:00+03	196100.00
583B45	2017-07-21 11:15:00+03	64400.00
583BBA	2017-08-06 17:11:00+03	29600.00
583BFB	2017-07-29 13:52:00+03	105000.00
583C34	2017-08-04 03:28:00+03	31100.00
583D72	2017-07-15 16:59:00+03	26000.00
583D9F	2017-07-06 00:27:00+03	75300.00
583DD2	2017-08-05 01:39:00+03	56000.00
583E01	2017-07-15 19:11:00+03	56600.00
583E79	2017-08-04 05:26:00+03	14400.00
583E7D	2017-07-03 19:04:00+03	136000.00
583E99	2017-07-08 07:02:00+03	14800.00
583F80	2017-07-14 23:01:00+03	169300.00
583F9D	2017-08-01 02:41:00+03	289600.00
5840AA	2017-07-31 15:54:00+03	104600.00
5840CF	2017-08-07 23:44:00+03	34600.00
5840D3	2017-08-14 11:19:00+03	46200.00
584121	2017-07-12 22:27:00+03	155600.00
584239	2017-07-19 00:05:00+03	73500.00
58426B	2017-07-31 14:24:00+03	40800.00
58428B	2017-07-10 16:11:00+03	14400.00
58428D	2017-08-03 02:06:00+03	73300.00
584377	2017-07-09 03:02:00+03	49600.00
5843BB	2017-07-11 02:40:00+03	189200.00
584413	2017-07-20 01:35:00+03	28300.00
584416	2017-08-11 22:06:00+03	68800.00
584465	2017-07-30 10:55:00+03	38800.00
584481	2017-07-16 09:20:00+03	16400.00
5844A5	2017-08-06 15:04:00+03	51500.00
5844B7	2017-07-20 21:26:00+03	20600.00
5844C0	2017-08-12 11:51:00+03	56000.00
58451F	2017-07-01 17:06:00+03	24400.00
58454C	2017-08-03 07:08:00+03	135400.00
584564	2017-07-18 02:19:00+03	29200.00
584590	2017-07-16 01:27:00+03	40800.00
58459A	2017-07-17 10:48:00+03	128300.00
58459D	2017-07-12 05:26:00+03	134700.00
5845A9	2017-08-10 05:03:00+03	6700.00
5845F9	2017-08-12 03:21:00+03	96800.00
5845FD	2017-07-15 04:15:00+03	26800.00
58461D	2017-08-05 16:51:00+03	24600.00
584630	2017-08-09 11:46:00+03	10800.00
584660	2017-07-09 12:13:00+03	79600.00
5846A2	2017-07-28 22:01:00+03	256600.00
5846A9	2017-07-09 18:46:00+03	88300.00
58470B	2017-07-07 21:18:00+03	28000.00
584738	2017-07-03 17:37:00+03	12600.00
584766	2017-07-11 05:48:00+03	52000.00
584772	2017-07-31 11:42:00+03	123000.00
5847AC	2017-07-22 18:24:00+03	53500.00
5847F5	2017-07-26 21:05:00+03	21800.00
584839	2017-07-06 12:37:00+03	51900.00
584895	2017-08-01 01:34:00+03	26800.00
58491A	2017-07-14 12:57:00+03	28800.00
584973	2017-08-14 18:09:00+03	154400.00
5849AB	2017-07-18 18:12:00+03	13800.00
584A1F	2017-08-15 08:50:00+03	40100.00
584A6D	2017-08-14 11:23:00+03	75300.00
584A85	2017-07-22 10:29:00+03	19600.00
584B3D	2017-08-06 05:40:00+03	72800.00
584B45	2017-08-01 03:32:00+03	20200.00
584B65	2017-07-03 05:39:00+03	125600.00
584B6D	2017-07-03 15:38:00+03	64300.00
584B71	2017-07-25 04:19:00+03	43900.00
584BA3	2017-08-09 01:07:00+03	77600.00
584BB7	2017-07-04 17:50:00+03	16400.00
584C16	2017-07-02 14:24:00+03	132800.00
584C6F	2017-07-01 16:45:00+03	133200.00
584CEB	2017-08-12 18:24:00+03	46000.00
584D10	2017-08-14 20:29:00+03	76300.00
584E1D	2017-07-23 13:38:00+03	68800.00
584E33	2017-08-15 15:29:00+03	28000.00
584E57	2017-07-17 17:51:00+03	128800.00
584EBB	2017-07-21 16:20:00+03	55800.00
584ED3	2017-07-12 15:12:00+03	86500.00
584EFF	2017-08-11 21:31:00+03	46000.00
584F86	2017-08-15 12:38:00+03	25400.00
585034	2017-08-04 04:17:00+03	54400.00
58506F	2017-07-19 14:15:00+03	23200.00
58510B	2017-07-30 20:04:00+03	54500.00
58522B	2017-08-12 10:16:00+03	71200.00
585235	2017-07-06 13:58:00+03	64700.00
5852E1	2017-08-08 14:05:00+03	26000.00
5852E3	2017-08-03 17:22:00+03	98100.00
5852F2	2017-08-05 05:03:00+03	10800.00
5852F9	2017-07-22 17:16:00+03	46000.00
5852FD	2017-07-11 05:51:00+03	399600.00
58530A	2017-08-05 23:05:00+03	23600.00
58534B	2017-07-08 08:40:00+03	67600.00
58534E	2017-08-12 00:51:00+03	24400.00
585397	2017-08-10 08:32:00+03	288800.00
5853B2	2017-08-02 03:36:00+03	28000.00
585405	2017-08-13 20:54:00+03	40000.00
58541D	2017-06-29 03:25:00+03	24400.00
585433	2017-08-12 02:48:00+03	117000.00
58543F	2017-07-17 08:15:00+03	168100.00
585447	2017-07-02 12:11:00+03	47100.00
585499	2017-07-29 02:15:00+03	13400.00
5854CD	2017-08-07 19:52:00+03	41600.00
5854E8	2017-07-03 11:11:00+03	21800.00
5854FD	2017-07-07 20:34:00+03	57600.00
58550A	2017-07-03 08:14:00+03	24400.00
58554D	2017-08-14 10:15:00+03	30200.00
585566	2017-07-29 23:03:00+03	16400.00
5855AC	2017-07-30 02:47:00+03	234800.00
5855BE	2017-08-11 14:13:00+03	139400.00
58567E	2017-07-06 05:19:00+03	23200.00
58569A	2017-08-14 06:06:00+03	25400.00
5856B1	2017-08-14 12:24:00+03	48900.00
5856C4	2017-08-03 03:01:00+03	198600.00
58571E	2017-07-05 06:37:00+03	76600.00
58576B	2017-07-13 01:55:00+03	4000.00
585780	2017-08-13 18:27:00+03	260300.00
58579D	2017-06-30 07:32:00+03	23200.00
5857EE	2017-07-29 05:27:00+03	71600.00
58583E	2017-07-04 08:05:00+03	34000.00
585882	2017-08-08 17:59:00+03	27200.00
585892	2017-07-19 20:35:00+03	66600.00
5858D1	2017-07-18 18:46:00+03	14000.00
5858F1	2017-07-31 10:56:00+03	136200.00
5858F6	2017-07-29 16:10:00+03	64400.00
585913	2017-08-11 14:58:00+03	26000.00
585930	2017-07-31 05:43:00+03	28800.00
585A42	2017-08-13 08:20:00+03	25100.00
585A58	2017-07-24 23:34:00+03	246000.00
585A68	2017-07-08 09:17:00+03	9200.00
585ABB	2017-07-15 15:06:00+03	97700.00
585AC5	2017-08-09 05:58:00+03	62600.00
585AF7	2017-07-19 15:30:00+03	35600.00
585AFB	2017-07-05 12:52:00+03	14000.00
585B1F	2017-07-21 22:06:00+03	19600.00
585BCD	2017-08-04 23:33:00+03	244300.00
585C08	2017-07-22 20:15:00+03	67100.00
585C2E	2017-07-17 01:16:00+03	26800.00
585C31	2017-07-05 22:05:00+03	23400.00
585C6F	2017-08-14 08:47:00+03	41400.00
585C71	2017-07-26 02:41:00+03	62100.00
585C77	2017-07-15 15:32:00+03	123000.00
585CBC	2017-07-23 21:47:00+03	39900.00
585D70	2017-08-08 14:26:00+03	75600.00
585DA9	2017-07-29 16:55:00+03	102000.00
585DB2	2017-07-17 23:33:00+03	73100.00
585DE4	2017-07-04 02:05:00+03	56000.00
585E37	2017-08-13 04:15:00+03	12600.00
585E82	2017-08-07 03:31:00+03	32500.00
585EB7	2017-06-28 12:36:00+03	68400.00
585EC7	2017-07-12 14:39:00+03	30900.00
585EE2	2017-08-11 15:42:00+03	38600.00
585EEC	2017-08-01 10:58:00+03	23200.00
585F6A	2017-08-10 22:31:00+03	76300.00
585F96	2017-08-04 23:46:00+03	46400.00
585F98	2017-08-14 00:03:00+03	286200.00
585FF4	2017-08-14 08:18:00+03	31100.00
586023	2017-07-03 20:16:00+03	28800.00
586172	2017-08-03 17:47:00+03	48700.00
5861B5	2017-08-11 23:37:00+03	38700.00
5861BA	2017-07-03 05:46:00+03	40600.00
586206	2017-08-07 05:37:00+03	59000.00
5862EA	2017-07-22 15:49:00+03	38800.00
586348	2017-07-01 05:00:00+03	56000.00
58635F	2017-07-24 06:20:00+03	34000.00
58638C	2017-08-11 03:19:00+03	22000.00
5863A8	2017-07-02 12:00:00+03	136600.00
586486	2017-07-02 15:47:00+03	18000.00
58648B	2017-07-17 00:35:00+03	51900.00
5864E2	2017-07-29 13:53:00+03	13600.00
586570	2017-07-17 12:36:00+03	116400.00
5865A5	2017-07-02 08:42:00+03	70700.00
5865B1	2017-07-24 05:13:00+03	140400.00
5865C1	2017-07-14 13:55:00+03	69500.00
586647	2017-07-23 03:19:00+03	52600.00
5866DC	2017-08-09 17:41:00+03	25600.00
58674D	2017-08-01 16:20:00+03	113600.00
5867C3	2017-08-03 06:52:00+03	80400.00
586804	2017-07-06 11:49:00+03	123000.00
58687B	2017-07-11 11:27:00+03	6000.00
5868AB	2017-07-02 20:10:00+03	112000.00
586910	2017-08-12 23:43:00+03	35600.00
58693D	2017-07-20 07:48:00+03	42000.00
586976	2017-07-15 07:19:00+03	43300.00
5869FD	2017-07-01 16:23:00+03	13400.00
586A0A	2017-07-20 20:15:00+03	16400.00
586A1A	2017-08-15 07:49:00+03	311200.00
586A6E	2017-07-04 06:23:00+03	76200.00
586A81	2017-07-16 01:48:00+03	86300.00
586A9F	2017-07-04 19:16:00+03	26000.00
586BC5	2017-07-18 19:44:00+03	66600.00
586BC8	2017-07-31 10:57:00+03	92000.00
586BDC	2017-08-01 01:07:00+03	147600.00
586BE4	2017-08-15 01:37:00+03	187600.00
586BF1	2017-08-05 12:45:00+03	28300.00
586C11	2017-08-06 02:02:00+03	8000.00
586C1E	2017-08-15 12:14:00+03	399600.00
586C29	2017-07-18 19:11:00+03	6700.00
586C5A	2017-07-06 01:21:00+03	272400.00
586C5C	2017-07-26 11:28:00+03	75600.00
586C72	2017-07-24 23:51:00+03	49100.00
586C78	2017-07-24 21:43:00+03	399300.00
586CBC	2017-08-14 17:16:00+03	12600.00
586CEE	2017-07-03 04:02:00+03	29200.00
586CF1	2017-08-13 22:57:00+03	13400.00
586D07	2017-07-30 14:56:00+03	20800.00
586D17	2017-07-17 20:03:00+03	73200.00
586D7E	2017-07-18 07:01:00+03	29600.00
586E5F	2017-07-06 02:46:00+03	72400.00
586E80	2017-07-21 21:18:00+03	18700.00
586F2B	2017-08-09 03:24:00+03	136500.00
586F54	2017-07-08 10:15:00+03	124200.00
586F7B	2017-07-07 22:42:00+03	73600.00
586FB1	2017-07-23 15:55:00+03	246000.00
587023	2017-07-11 15:00:00+03	81900.00
587046	2017-08-13 15:22:00+03	23200.00
587065	2017-07-03 06:42:00+03	21400.00
58709F	2017-07-15 13:56:00+03	57800.00
5870A4	2017-08-15 15:45:00+03	265800.00
5870E2	2017-07-09 05:26:00+03	14400.00
5870F9	2017-07-21 22:02:00+03	56600.00
587128	2017-08-09 01:33:00+03	20800.00
58719F	2017-07-03 03:12:00+03	62600.00
5871B8	2017-07-16 22:57:00+03	6700.00
5871C0	2017-07-23 11:43:00+03	68300.00
5871E4	2017-07-01 00:47:00+03	133100.00
5871EA	2017-08-10 21:16:00+03	128800.00
5871EB	2017-08-08 04:55:00+03	27200.00
587208	2017-07-22 23:29:00+03	56000.00
587238	2017-07-15 12:53:00+03	26600.00
58724D	2017-07-14 17:21:00+03	58800.00
58729C	2017-08-08 01:54:00+03	90800.00
5872B8	2017-07-07 16:39:00+03	174900.00
5872D0	2017-07-16 20:43:00+03	27900.00
5872E1	2017-08-05 02:57:00+03	112000.00
587437	2017-07-20 22:15:00+03	13400.00
587451	2017-08-06 15:43:00+03	12400.00
5874CB	2017-07-18 12:48:00+03	90400.00
587538	2017-07-16 13:26:00+03	62100.00
5875E3	2017-07-06 12:23:00+03	119800.00
587673	2017-08-01 19:23:00+03	47600.00
5876B3	2017-08-13 04:18:00+03	7200.00
5876D1	2017-08-04 12:49:00+03	13400.00
5876FA	2017-08-15 08:45:00+03	28600.00
587704	2017-07-03 15:48:00+03	21500.00
587712	2017-07-12 21:54:00+03	20400.00
587736	2017-07-11 14:53:00+03	129400.00
587773	2017-07-02 23:55:00+03	65200.00
58782C	2017-08-07 07:09:00+03	136600.00
58788D	2017-07-10 22:43:00+03	39200.00
587943	2017-07-26 03:06:00+03	32400.00
587997	2017-07-30 05:20:00+03	38800.00
587A10	2017-08-15 08:40:00+03	124200.00
587B06	2017-08-07 08:49:00+03	168600.00
587B5D	2017-08-15 03:00:00+03	12600.00
587B5E	2017-06-28 20:52:00+03	104000.00
587B63	2017-08-14 17:04:00+03	13400.00
587BED	2017-07-19 01:52:00+03	56600.00
587BF1	2017-07-18 00:54:00+03	30200.00
587CE3	2017-07-14 23:03:00+03	116400.00
587D2D	2017-07-14 13:44:00+03	40600.00
587D45	2017-08-01 19:30:00+03	14800.00
587D6A	2017-07-03 23:53:00+03	109600.00
587D6B	2017-07-26 00:21:00+03	14000.00
587DAA	2017-06-29 15:26:00+03	28000.00
587DEC	2017-07-25 02:18:00+03	18000.00
587E4B	2017-07-31 07:40:00+03	222000.00
587E5F	2017-07-21 21:52:00+03	131100.00
587E73	2017-07-28 14:27:00+03	57400.00
588033	2017-07-09 04:52:00+03	79300.00
58809B	2017-08-02 22:25:00+03	72000.00
588110	2017-07-10 14:32:00+03	30200.00
588120	2017-07-04 14:35:00+03	265800.00
588146	2017-07-27 06:26:00+03	62600.00
5881AC	2017-07-11 18:49:00+03	150500.00
588242	2017-07-17 08:53:00+03	145300.00
588258	2017-07-18 13:55:00+03	406700.00
5882A6	2017-07-01 08:46:00+03	115800.00
5882CB	2017-07-03 15:04:00+03	355200.00
588301	2017-07-14 16:53:00+03	47100.00
588322	2017-08-03 05:20:00+03	67600.00
588349	2017-07-26 13:51:00+03	492000.00
588368	2017-07-10 07:12:00+03	21400.00
58838A	2017-06-28 02:36:00+03	7400.00
58838D	2017-08-11 14:25:00+03	87200.00
5883B3	2017-07-16 08:42:00+03	51900.00
5883B4	2017-07-07 21:24:00+03	60600.00
5883DA	2017-08-15 08:25:00+03	129800.00
5883E6	2017-07-15 01:47:00+03	99200.00
58841F	2017-08-09 12:04:00+03	145300.00
588462	2017-08-07 03:41:00+03	50600.00
588469	2017-07-05 17:46:00+03	234700.00
5884CF	2017-08-08 22:44:00+03	6000.00
5884EB	2017-07-11 04:02:00+03	14000.00
5884F9	2017-08-10 05:45:00+03	132400.00
588547	2017-07-13 02:15:00+03	28800.00
58854A	2017-07-17 17:53:00+03	127200.00
588554	2017-08-15 17:02:00+03	57500.00
5885CF	2017-07-05 10:48:00+03	17600.00
588741	2017-08-15 06:04:00+03	45200.00
5887B5	2017-07-15 03:54:00+03	58400.00
5887BF	2017-07-22 08:54:00+03	94300.00
5887CE	2017-08-10 19:03:00+03	56900.00
58884C	2017-08-07 23:03:00+03	24400.00
588930	2017-07-21 20:28:00+03	54800.00
588950	2017-07-20 08:31:00+03	23200.00
588968	2017-07-24 05:12:00+03	113700.00
5889C1	2017-07-04 14:57:00+03	19600.00
588A31	2017-07-16 20:24:00+03	23600.00
588A97	2017-07-10 22:46:00+03	48800.00
588AAF	2017-07-04 00:48:00+03	26800.00
588AD4	2017-07-14 13:29:00+03	106400.00
588B8A	2017-07-31 12:23:00+03	295400.00
588B8D	2017-07-13 16:10:00+03	28000.00
588BCF	2017-08-13 01:27:00+03	66600.00
588C44	2017-07-10 09:49:00+03	6000.00
588C54	2017-07-03 01:40:00+03	31600.00
588C5B	2017-07-10 08:36:00+03	131600.00
588C67	2017-08-02 16:50:00+03	139400.00
588C6A	2017-07-23 14:53:00+03	35700.00
588C88	2017-07-16 02:00:00+03	28000.00
588C99	2017-07-21 04:00:00+03	23400.00
588C9A	2017-08-11 19:11:00+03	162900.00
588CA5	2017-07-06 23:37:00+03	136600.00
588D07	2017-07-26 20:28:00+03	99000.00
588D56	2017-08-14 15:18:00+03	46400.00
588DB3	2017-08-11 10:50:00+03	55800.00
588E57	2017-07-17 05:19:00+03	72200.00
588E8B	2017-08-12 23:16:00+03	8200.00
588E9C	2017-08-05 09:02:00+03	26800.00
588EDB	2017-07-16 19:23:00+03	97400.00
588EEF	2017-07-28 02:43:00+03	30400.00
588EFD	2017-07-02 09:59:00+03	6400.00
588F07	2017-08-02 16:13:00+03	21800.00
588F3F	2017-07-07 22:29:00+03	66600.00
588F66	2017-07-06 07:48:00+03	56100.00
588F7A	2017-08-15 16:51:00+03	81300.00
588FA0	2017-07-31 08:41:00+03	56600.00
588FA3	2017-07-08 03:17:00+03	17800.00
588FE3	2017-07-01 21:51:00+03	28000.00
589021	2017-08-11 02:19:00+03	28000.00
58902F	2017-08-13 03:44:00+03	56000.00
589062	2017-08-05 05:29:00+03	14400.00
589093	2017-07-17 12:41:00+03	78600.00
5890C3	2017-07-03 10:08:00+03	115800.00
5890C5	2017-07-30 20:37:00+03	66600.00
5890CD	2017-07-16 16:26:00+03	205700.00
58914B	2017-08-15 16:33:00+03	148200.00
589196	2017-08-14 13:36:00+03	27900.00
5891A5	2017-07-05 07:43:00+03	59200.00
5891E0	2017-08-01 06:25:00+03	52000.00
58924B	2017-07-16 18:29:00+03	70200.00
58925D	2017-08-15 04:52:00+03	6000.00
5892AF	2017-07-22 22:07:00+03	57100.00
58930A	2017-07-09 01:58:00+03	46200.00
58935C	2017-08-10 01:17:00+03	36200.00
589374	2017-08-11 11:46:00+03	50800.00
589391	2017-07-31 23:29:00+03	149300.00
58939F	2017-08-04 20:35:00+03	302600.00
58947D	2017-07-07 06:18:00+03	40800.00
589484	2017-08-11 02:42:00+03	42400.00
5894C8	2017-08-11 12:12:00+03	52700.00
589517	2017-08-13 14:41:00+03	35200.00
58953A	2017-07-12 12:41:00+03	6700.00
589549	2017-07-25 13:21:00+03	48500.00
589554	2017-08-14 10:39:00+03	26800.00
58958E	2017-08-10 10:44:00+03	56000.00
589617	2017-08-09 21:06:00+03	73600.00
589635	2017-08-02 11:14:00+03	56000.00
58966B	2017-08-14 02:36:00+03	136200.00
58969E	2017-08-14 17:26:00+03	127400.00
5896AE	2017-07-13 09:44:00+03	54500.00
589702	2017-07-06 06:27:00+03	36800.00
589717	2017-07-09 00:32:00+03	369000.00
58971A	2017-08-10 02:28:00+03	56900.00
58974A	2017-08-10 12:24:00+03	56000.00
589760	2017-07-07 12:24:00+03	68400.00
589776	2017-07-16 19:37:00+03	65600.00
589778	2017-07-23 18:13:00+03	162700.00
5897BC	2017-07-21 07:57:00+03	12600.00
5897BE	2017-07-14 18:53:00+03	56600.00
5897F7	2017-07-09 10:52:00+03	24800.00
58981B	2017-07-29 00:01:00+03	73600.00
589847	2017-07-07 14:30:00+03	57400.00
589873	2017-08-14 08:48:00+03	37700.00
589897	2017-07-16 02:37:00+03	113800.00
5898ED	2017-08-10 17:52:00+03	232400.00
589942	2017-07-24 01:47:00+03	496600.00
589985	2017-07-25 03:18:00+03	26000.00
589A0D	2017-07-15 21:41:00+03	72300.00
589A4D	2017-07-22 17:35:00+03	46400.00
589A83	2017-08-01 20:51:00+03	50600.00
589AAA	2017-07-01 12:37:00+03	95200.00
589AD0	2017-08-09 19:49:00+03	223200.00
589AED	2017-08-10 15:50:00+03	42800.00
589AFA	2017-07-31 16:45:00+03	55800.00
589B24	2017-07-26 08:07:00+03	26000.00
589B9D	2017-08-08 07:38:00+03	30200.00
589BFE	2017-08-01 12:10:00+03	73500.00
589C0B	2017-08-14 05:32:00+03	23200.00
589C37	2017-07-17 12:00:00+03	55800.00
589C4B	2017-08-01 03:05:00+03	52000.00
589C4E	2017-07-22 21:20:00+03	84100.00
589C5F	2017-08-14 10:09:00+03	24200.00
589C91	2017-08-14 05:48:00+03	31600.00
589CB1	2017-07-12 16:39:00+03	40000.00
589CF1	2017-08-05 11:36:00+03	31100.00
589D07	2017-07-15 16:44:00+03	136800.00
589D6C	2017-07-20 04:02:00+03	64700.00
589D82	2017-07-14 09:36:00+03	73500.00
589D95	2017-08-08 02:19:00+03	166100.00
589DB9	2017-08-10 15:07:00+03	19600.00
589DC1	2017-07-19 23:33:00+03	75300.00
589DE8	2017-08-09 21:38:00+03	48800.00
589DFC	2017-08-08 03:19:00+03	38400.00
589E44	2017-07-24 01:30:00+03	98200.00
589E5D	2017-07-05 20:02:00+03	54400.00
589E80	2017-07-24 22:10:00+03	125200.00
589E91	2017-08-11 23:39:00+03	198600.00
589EB5	2017-07-17 00:52:00+03	26700.00
589EE6	2017-07-24 00:46:00+03	136500.00
589F08	2017-08-10 19:08:00+03	61900.00
589F23	2017-08-14 17:25:00+03	30300.00
589FB6	2017-07-28 11:33:00+03	43300.00
58A034	2017-08-06 13:55:00+03	28800.00
58A0C4	2017-07-06 10:41:00+03	160000.00
58A0C9	2017-08-04 23:20:00+03	80000.00
58A147	2017-07-19 16:46:00+03	147000.00
58A1AB	2017-07-21 01:07:00+03	24300.00
58A1CA	2017-07-20 01:43:00+03	67200.00
58A218	2017-07-04 10:39:00+03	25400.00
58A249	2017-07-19 03:25:00+03	84300.00
58A256	2017-07-02 01:34:00+03	68100.00
58A334	2017-08-13 12:49:00+03	131000.00
58A3C1	2017-08-14 23:57:00+03	398400.00
58A3C9	2017-07-22 20:26:00+03	229000.00
58A3CE	2017-08-15 16:47:00+03	64500.00
58A40C	2017-08-11 00:07:00+03	37900.00
58A41D	2017-07-24 11:51:00+03	45200.00
58A4A6	2017-07-10 06:28:00+03	301600.00
58A4D2	2017-07-19 15:56:00+03	142300.00
58A4DF	2017-08-04 03:38:00+03	55800.00
58A4FC	2017-07-07 18:10:00+03	139600.00
58A508	2017-07-25 06:32:00+03	133100.00
58A536	2017-08-07 20:24:00+03	39300.00
58A54F	2017-08-02 04:56:00+03	23200.00
58A5E5	2017-07-01 11:35:00+03	133100.00
58A614	2017-07-12 13:54:00+03	99600.00
58A6D8	2017-08-15 01:14:00+03	33500.00
58A743	2017-08-06 06:07:00+03	44800.00
58A79E	2017-07-11 01:32:00+03	113800.00
58A7A1	2017-06-28 22:27:00+03	23600.00
58A7E3	2017-07-17 19:02:00+03	73600.00
58A817	2017-07-02 00:05:00+03	58200.00
58A82B	2017-07-09 06:01:00+03	23600.00
58A892	2017-07-15 05:20:00+03	123000.00
58A90B	2017-08-15 13:27:00+03	8200.00
58A931	2017-07-12 17:14:00+03	65400.00
58A936	2017-07-13 15:21:00+03	40600.00
58A96F	2017-07-07 22:23:00+03	75300.00
58A97A	2017-07-10 23:28:00+03	56000.00
58A9F3	2017-07-03 02:23:00+03	46000.00
58AA1C	2017-08-04 05:49:00+03	46000.00
58AA43	2017-07-09 02:40:00+03	14400.00
58AA46	2017-07-10 18:08:00+03	66600.00
58AA61	2017-07-28 09:20:00+03	50100.00
58AA6F	2017-08-01 02:37:00+03	63200.00
58AA9A	2017-08-08 18:37:00+03	8200.00
58AABF	2017-08-06 07:21:00+03	47200.00
58AAD9	2017-07-12 19:24:00+03	8400.00
58AB04	2017-07-14 03:17:00+03	43000.00
58AB19	2017-08-10 07:08:00+03	18600.00
58AB69	2017-07-02 20:37:00+03	28800.00
58AB79	2017-07-15 23:11:00+03	95000.00
58ABE5	2017-07-07 16:58:00+03	21800.00
58ABE9	2017-08-01 20:36:00+03	46800.00
58AC40	2017-07-10 00:31:00+03	24400.00
58ACB9	2017-07-12 17:44:00+03	26000.00
58AD72	2017-07-28 20:00:00+03	14700.00
58AD8B	2017-08-12 10:40:00+03	199700.00
58ADAE	2017-07-14 22:04:00+03	6700.00
58ADB7	2017-07-17 04:31:00+03	36000.00
58ADC9	2017-08-15 05:40:00+03	92000.00
58ADFE	2017-08-12 19:21:00+03	177600.00
58AE1C	2017-07-05 08:52:00+03	266400.00
58AE4C	2017-08-14 22:43:00+03	26000.00
58AEA2	2017-08-09 03:44:00+03	16400.00
58AEB2	2017-08-03 00:23:00+03	92100.00
58AEC0	2017-07-14 07:10:00+03	11900.00
58AECB	2017-07-04 10:49:00+03	28800.00
58AF10	2017-08-07 23:25:00+03	80000.00
58AF1F	2017-07-03 19:10:00+03	46000.00
58AF32	2017-07-12 11:25:00+03	129000.00
58AFBC	2017-08-02 23:17:00+03	75600.00
58AFD9	2017-08-07 07:44:00+03	26000.00
58B00F	2017-08-01 06:58:00+03	125400.00
58B025	2017-07-20 14:10:00+03	396500.00
58B03B	2017-07-16 06:38:00+03	105000.00
58B076	2017-08-02 21:44:00+03	50300.00
58B0E3	2017-07-12 09:51:00+03	33600.00
58B0E4	2017-07-04 12:34:00+03	52600.00
58B0E5	2017-08-10 21:21:00+03	30400.00
58B147	2017-07-15 14:15:00+03	29800.00
58B1CB	2017-07-31 07:09:00+03	75300.00
58B1D9	2017-07-28 23:58:00+03	46400.00
58B218	2017-08-15 01:19:00+03	69000.00
58B284	2017-08-07 12:18:00+03	105000.00
58B292	2017-08-14 11:37:00+03	35800.00
58B297	2017-08-11 09:20:00+03	119500.00
58B355	2017-07-23 20:36:00+03	26000.00
58B35C	2017-07-01 11:04:00+03	56900.00
58B387	2017-07-28 09:24:00+03	22800.00
58B3E5	2017-07-18 17:27:00+03	32200.00
58B3F8	2017-08-07 20:04:00+03	24400.00
58B424	2017-07-24 17:44:00+03	7400.00
58B443	2017-07-25 08:15:00+03	133100.00
58B560	2017-07-11 11:17:00+03	28000.00
58B56A	2017-08-11 17:28:00+03	47400.00
58B56D	2017-08-13 20:00:00+03	115800.00
58B5CC	2017-07-04 07:42:00+03	26200.00
58B5FF	2017-07-15 19:51:00+03	137100.00
58B61D	2017-07-11 16:14:00+03	94000.00
58B66C	2017-08-09 20:07:00+03	26000.00
58B6B9	2017-07-24 07:00:00+03	38400.00
58B6C7	2017-08-15 10:51:00+03	9200.00
58B705	2017-08-07 16:43:00+03	54900.00
58B706	2017-07-17 22:22:00+03	32300.00
58B74B	2017-07-02 19:39:00+03	37200.00
58B76A	2017-07-07 01:51:00+03	18600.00
58B76E	2017-07-25 13:16:00+03	50400.00
58B781	2017-08-12 16:46:00+03	246000.00
58B79B	2017-07-26 13:15:00+03	62600.00
58B81F	2017-08-13 05:47:00+03	23600.00
58B864	2017-08-12 09:21:00+03	135200.00
58B868	2017-07-19 10:23:00+03	187800.00
58B896	2017-07-11 14:45:00+03	12600.00
58B8CF	2017-07-22 08:36:00+03	93900.00
58B8D6	2017-07-03 19:46:00+03	24700.00
58B8F9	2017-07-23 00:04:00+03	89100.00
58B904	2017-08-11 05:53:00+03	43600.00
58B934	2017-07-27 08:29:00+03	25400.00
58B96C	2017-07-31 19:54:00+03	210500.00
58B9E5	2017-08-01 12:35:00+03	69500.00
58B9F5	2017-08-06 19:59:00+03	58200.00
58BA0B	2017-08-09 18:41:00+03	37200.00
58BAAA	2017-08-13 22:05:00+03	23400.00
58BAF1	2017-08-11 10:23:00+03	75300.00
58BB03	2017-07-11 05:22:00+03	47000.00
58BB06	2017-07-24 23:03:00+03	66600.00
58BB67	2017-07-21 23:51:00+03	58200.00
58BBB1	2017-07-01 00:43:00+03	81800.00
58BBD0	2017-08-11 11:21:00+03	199300.00
58BBD4	2017-07-04 06:35:00+03	32700.00
58BBDF	2017-07-14 07:48:00+03	37700.00
58BC0C	2017-07-17 15:40:00+03	37200.00
58BC11	2017-07-08 14:24:00+03	38800.00
58BC55	2017-07-19 14:58:00+03	6700.00
58BD28	2017-08-02 01:00:00+03	7400.00
58BD38	2017-07-05 02:25:00+03	15400.00
58BD73	2017-08-04 17:56:00+03	62600.00
58BDBC	2017-08-05 23:38:00+03	61700.00
58BDCE	2017-08-13 11:22:00+03	246000.00
58BDFC	2017-07-27 20:36:00+03	56000.00
58BE0F	2017-08-13 02:02:00+03	40300.00
58BE7C	2017-07-30 14:13:00+03	21400.00
58BF52	2017-07-02 05:24:00+03	77500.00
58BF76	2017-07-25 05:46:00+03	23200.00
58BF7F	2017-07-26 07:31:00+03	236100.00
58BFC1	2017-08-11 18:40:00+03	77900.00
58C07B	2017-08-12 14:47:00+03	27800.00
58C113	2017-08-07 17:27:00+03	65900.00
58C173	2017-07-04 19:41:00+03	90000.00
58C1AD	2017-08-11 23:41:00+03	40800.00
58C1AE	2017-07-26 22:26:00+03	11000.00
58C1EF	2017-08-01 08:39:00+03	47200.00
58C2FF	2017-07-10 05:37:00+03	38400.00
58C313	2017-07-31 07:23:00+03	193700.00
58C3FC	2017-07-15 01:06:00+03	76600.00
58C416	2017-08-12 01:49:00+03	21400.00
58C42A	2017-07-03 21:15:00+03	27400.00
58C4A6	2017-08-11 17:47:00+03	27000.00
58C4B0	2017-08-09 02:04:00+03	166900.00
58C4D1	2017-08-02 21:53:00+03	93900.00
58C4EB	2017-08-12 16:23:00+03	32200.00
58C5EC	2017-07-16 03:59:00+03	15000.00
58C60B	2017-07-28 20:03:00+03	16400.00
58C677	2017-07-10 08:36:00+03	89600.00
58C68F	2017-07-18 22:59:00+03	72800.00
58C6A3	2017-08-01 00:27:00+03	135400.00
58C6B7	2017-07-15 13:15:00+03	56100.00
58C71F	2017-08-10 04:49:00+03	8400.00
58C75E	2017-08-02 00:50:00+03	23600.00
58C773	2017-08-12 05:14:00+03	18100.00
58C80C	2017-07-07 10:18:00+03	51900.00
58C899	2017-08-05 16:45:00+03	212800.00
58C92A	2017-07-27 07:37:00+03	52900.00
58C97E	2017-07-22 21:12:00+03	108000.00
58C9B1	2017-07-28 18:01:00+03	51600.00
58C9C7	2017-07-17 20:38:00+03	156400.00
58CA33	2017-07-06 23:52:00+03	24400.00
58CA8E	2017-08-04 00:31:00+03	114700.00
58CAB9	2017-07-30 18:30:00+03	70200.00
58CB93	2017-07-18 05:14:00+03	52400.00
58CC28	2017-08-15 08:22:00+03	117800.00
58CC64	2017-08-07 09:05:00+03	42800.00
58CCAB	2017-08-14 13:04:00+03	112000.00
58CCB5	2017-07-03 21:07:00+03	24700.00
58CD42	2017-08-13 20:30:00+03	14000.00
58CD5D	2017-08-13 20:00:00+03	128300.00
58CD79	2017-07-12 01:38:00+03	43300.00
58CD98	2017-08-02 17:07:00+03	93900.00
58CDE0	2017-07-28 07:25:00+03	67600.00
58CDFB	2017-08-12 20:25:00+03	42800.00
58CE5E	2017-07-21 16:07:00+03	37900.00
58CE7E	2017-07-16 19:49:00+03	73300.00
58CECA	2017-08-09 03:50:00+03	48500.00
58CEE4	2017-07-01 03:35:00+03	14000.00
58CF0D	2017-07-28 11:35:00+03	95600.00
58CFB3	2017-07-11 07:36:00+03	99300.00
58CFDF	2017-08-04 07:44:00+03	44600.00
58CFE2	2017-08-13 16:30:00+03	36000.00
58D01F	2017-07-25 13:49:00+03	22100.00
58D072	2017-07-11 02:02:00+03	8200.00
58D0BE	2017-07-19 05:41:00+03	36400.00
58D135	2017-08-10 04:06:00+03	24400.00
58D151	2017-07-21 06:54:00+03	24000.00
58D15B	2017-07-25 09:16:00+03	123900.00
58D190	2017-07-31 12:09:00+03	79600.00
58D273	2017-08-01 15:19:00+03	56600.00
58D28F	2017-08-04 12:11:00+03	52000.00
58D2B5	2017-07-29 13:58:00+03	23200.00
58D2D1	2017-07-03 20:46:00+03	28800.00
58D339	2017-07-25 13:47:00+03	246000.00
58D380	2017-08-05 21:10:00+03	193500.00
58D397	2017-08-15 03:36:00+03	7400.00
58D3F8	2017-07-12 08:37:00+03	55800.00
58D45A	2017-08-08 17:34:00+03	90000.00
58D460	2017-07-07 04:12:00+03	23200.00
58D545	2017-08-12 13:38:00+03	108900.00
58D555	2017-07-24 20:51:00+03	30200.00
58D573	2017-07-15 06:09:00+03	19600.00
58D5BA	2017-07-14 18:35:00+03	111600.00
58D5F8	2017-08-15 07:40:00+03	53700.00
58D67A	2017-08-01 05:13:00+03	56000.00
58D6C9	2017-07-27 01:15:00+03	58000.00
58D71D	2017-07-23 15:13:00+03	56900.00
58D741	2017-07-18 15:42:00+03	61900.00
58D750	2017-07-08 01:27:00+03	24300.00
58D775	2017-07-21 04:19:00+03	67200.00
58D7C3	2017-08-09 14:38:00+03	399600.00
58D85A	2017-07-10 14:33:00+03	46200.00
58D8E1	2017-07-05 00:31:00+03	248300.00
58D908	2017-07-05 07:04:00+03	67600.00
58D964	2017-07-15 19:34:00+03	56100.00
58D985	2017-08-01 00:02:00+03	62700.00
58D992	2017-08-02 23:41:00+03	54300.00
58D9A1	2017-07-24 13:34:00+03	32400.00
58D9DC	2017-06-30 00:29:00+03	29600.00
58D9EC	2017-08-14 01:15:00+03	32800.00
58DA17	2017-08-10 21:48:00+03	344100.00
58DA51	2017-07-11 17:17:00+03	65500.00
58DA95	2017-08-08 06:29:00+03	36400.00
58DADF	2017-08-13 21:28:00+03	182200.00
58DAF5	2017-07-20 08:14:00+03	49300.00
58DB13	2017-07-05 16:36:00+03	13300.00
58DB16	2017-07-05 00:53:00+03	40800.00
58DB26	2017-07-07 07:21:00+03	15900.00
58DB4E	2017-07-08 14:11:00+03	54500.00
58DB67	2017-08-12 19:19:00+03	139000.00
58DB6F	2017-07-15 23:11:00+03	75700.00
58DB9B	2017-08-15 13:50:00+03	23600.00
58DC89	2017-07-16 02:31:00+03	40400.00
58DCA1	2017-07-30 08:36:00+03	16400.00
58DCA9	2017-07-19 16:57:00+03	193600.00
58DCB1	2017-07-03 19:12:00+03	96800.00
58DCB2	2017-07-18 14:30:00+03	28800.00
58DCE9	2017-07-28 07:02:00+03	97700.00
58DD3A	2017-08-13 06:22:00+03	8600.00
58DD48	2017-08-13 05:07:00+03	105200.00
58DD87	2017-07-21 05:34:00+03	22600.00
58DDC9	2017-07-10 18:09:00+03	21400.00
58DE33	2017-07-21 15:48:00+03	24400.00
58DE8A	2017-07-13 18:57:00+03	16400.00
58DF45	2017-08-06 17:56:00+03	13700.00
58DF4F	2017-07-01 03:59:00+03	176800.00
58DF61	2017-07-10 15:19:00+03	58000.00
58E038	2017-07-29 17:51:00+03	81600.00
58E040	2017-08-15 12:30:00+03	25100.00
58E046	2017-08-14 02:38:00+03	49600.00
58E08F	2017-07-13 11:16:00+03	167900.00
58E0B5	2017-07-21 03:06:00+03	56000.00
58E1E4	2017-07-11 03:43:00+03	40000.00
58E208	2017-07-09 17:53:00+03	85000.00
58E240	2017-08-09 16:07:00+03	70700.00
58E2E0	2017-07-01 00:10:00+03	72900.00
58E2E3	2017-07-23 16:08:00+03	6300.00
58E2E6	2017-07-16 20:10:00+03	53600.00
58E2EA	2017-08-01 16:59:00+03	72400.00
58E349	2017-07-22 10:07:00+03	67600.00
58E3AA	2017-07-14 08:40:00+03	87000.00
58E3C0	2017-07-12 21:05:00+03	43600.00
58E3C9	2017-07-17 15:00:00+03	31400.00
58E3E7	2017-07-17 06:43:00+03	75800.00
58E3F6	2017-07-22 19:33:00+03	53400.00
58E3FA	2017-08-09 10:43:00+03	52900.00
58E403	2017-07-08 00:23:00+03	73600.00
58E44D	2017-07-10 11:27:00+03	75300.00
58E473	2017-08-15 05:41:00+03	94000.00
58E475	2017-07-09 18:18:00+03	185400.00
58E4E5	2017-07-13 18:16:00+03	25800.00
58E55D	2017-07-11 13:26:00+03	27300.00
58E587	2017-08-14 00:35:00+03	23200.00
58E5D8	2017-07-17 10:59:00+03	52000.00
58E62E	2017-07-21 07:42:00+03	36200.00
58E65C	2017-07-19 07:50:00+03	399600.00
58E66B	2017-08-03 13:40:00+03	58200.00
58E6CA	2017-08-07 18:46:00+03	146200.00
58E6D4	2017-08-14 00:57:00+03	16800.00
58E6D7	2017-08-08 07:10:00+03	272400.00
58E76D	2017-07-29 22:12:00+03	172100.00
58E77D	2017-07-02 06:44:00+03	109000.00
58E7B9	2017-08-03 00:33:00+03	48900.00
58E85E	2017-07-10 22:54:00+03	56200.00
58E8AA	2017-07-31 14:39:00+03	125900.00
58E8B5	2017-07-26 05:30:00+03	55800.00
58E8C0	2017-08-07 05:48:00+03	56000.00
58E945	2017-08-01 10:51:00+03	135400.00
58E9F4	2017-07-25 08:00:00+03	295300.00
58EA02	2017-07-17 11:22:00+03	155900.00
58EA1C	2017-08-15 01:15:00+03	93000.00
58EA24	2017-08-03 18:44:00+03	134700.00
58EA56	2017-07-03 15:18:00+03	6700.00
58EA67	2017-08-08 02:30:00+03	66600.00
58EAE3	2017-07-24 02:10:00+03	61200.00
58EBD8	2017-06-26 04:33:00+03	179500.00
58EBE8	2017-08-15 17:18:00+03	47100.00
58EBF5	2017-07-03 21:17:00+03	43600.00
58ECA2	2017-07-31 04:33:00+03	97900.00
58ECAB	2017-07-29 20:31:00+03	44300.00
58ED84	2017-07-27 17:32:00+03	49500.00
58ED99	2017-08-12 20:05:00+03	28800.00
58EE28	2017-07-06 21:14:00+03	89200.00
58EE9F	2017-07-31 23:26:00+03	27200.00
58EEBB	2017-07-16 10:57:00+03	13700.00
58EEF9	2017-07-12 01:17:00+03	74700.00
58EF98	2017-07-27 20:47:00+03	32800.00
58EFC8	2017-07-01 21:04:00+03	139300.00
58F00F	2017-07-25 06:29:00+03	42200.00
58F01F	2017-07-31 10:02:00+03	73500.00
58F056	2017-08-05 07:17:00+03	39300.00
58F095	2017-08-01 01:31:00+03	46000.00
58F150	2017-07-30 15:04:00+03	16400.00
58F15F	2017-08-01 07:11:00+03	28000.00
58F1B2	2017-07-26 21:52:00+03	41400.00
58F1B9	2017-07-17 18:18:00+03	94400.00
58F21E	2017-07-22 02:12:00+03	40800.00
58F2BD	2017-07-25 19:57:00+03	18900.00
58F311	2017-07-06 02:59:00+03	13400.00
58F337	2017-07-14 07:33:00+03	26000.00
58F3A6	2017-07-27 13:06:00+03	32000.00
58F3EA	2017-07-25 03:46:00+03	40000.00
58F441	2017-07-18 12:22:00+03	101500.00
58F45E	2017-08-01 04:36:00+03	129700.00
58F464	2017-08-13 02:24:00+03	75600.00
58F4A3	2017-07-08 10:52:00+03	29600.00
58F4B9	2017-08-11 05:21:00+03	75700.00
58F553	2017-07-09 15:16:00+03	23600.00
58F570	2017-07-15 20:26:00+03	26000.00
58F60F	2017-07-22 20:15:00+03	43500.00
58F626	2017-07-31 21:15:00+03	53600.00
58F641	2017-07-17 07:58:00+03	28800.00
58F646	2017-07-02 00:07:00+03	51200.00
58F679	2017-07-20 23:08:00+03	133100.00
58F67E	2017-07-04 01:55:00+03	38700.00
58F6B7	2017-07-17 18:17:00+03	28800.00
58F6D8	2017-07-13 05:37:00+03	37900.00
58F6EE	2017-08-10 00:33:00+03	114300.00
58F759	2017-08-13 20:56:00+03	93800.00
58F760	2017-07-26 02:51:00+03	117600.00
58F783	2017-07-29 16:50:00+03	26000.00
58F78B	2017-07-01 09:49:00+03	229000.00
58F7A6	2017-08-04 12:14:00+03	58200.00
58F7E2	2017-08-14 02:01:00+03	16400.00
58F801	2017-07-15 19:56:00+03	19600.00
58F82A	2017-07-24 01:06:00+03	103600.00
58F895	2017-08-02 02:46:00+03	62600.00
58F8FF	2017-07-10 01:41:00+03	22000.00
58F983	2017-07-23 22:48:00+03	303100.00
58FA23	2017-08-09 22:33:00+03	37900.00
58FA74	2017-08-02 18:30:00+03	32900.00
58FAF8	2017-07-29 04:49:00+03	179400.00
58FB4D	2017-07-05 04:54:00+03	481700.00
58FBD2	2017-07-17 22:24:00+03	47200.00
58FBD3	2017-07-26 02:33:00+03	47400.00
58FC16	2017-08-02 09:41:00+03	23400.00
58FCD0	2017-07-18 20:32:00+03	14000.00
58FD2C	2017-07-25 18:41:00+03	57600.00
58FD41	2017-07-24 06:34:00+03	37200.00
58FD5D	2017-07-08 14:53:00+03	76600.00
58FD5F	2017-08-02 10:02:00+03	71900.00
58FD81	2017-07-03 17:55:00+03	26000.00
58FDBD	2017-08-08 14:02:00+03	21400.00
58FDE1	2017-08-14 00:45:00+03	6700.00
58FED6	2017-07-25 17:09:00+03	270800.00
58FEED	2017-07-14 14:39:00+03	110500.00
58FF94	2017-08-14 16:07:00+03	62700.00
58FFA4	2017-07-26 06:40:00+03	112000.00
58FFF4	2017-07-27 23:33:00+03	59800.00
590055	2017-07-08 19:55:00+03	25100.00
590064	2017-08-03 23:29:00+03	13400.00
590187	2017-08-05 20:28:00+03	26000.00
59019F	2017-07-27 08:28:00+03	29600.00
5901AA	2017-07-24 13:27:00+03	52800.00
5901CB	2017-08-12 08:41:00+03	64100.00
590218	2017-06-26 14:37:00+03	70700.00
590275	2017-07-03 13:45:00+03	27200.00
590389	2017-08-14 13:41:00+03	273000.00
590393	2017-07-05 14:12:00+03	210000.00
5903CA	2017-07-18 16:50:00+03	76800.00
5904F6	2017-07-16 18:50:00+03	60800.00
590510	2017-07-11 02:21:00+03	47200.00
590521	2017-08-06 18:51:00+03	14800.00
59057C	2017-07-02 19:24:00+03	13600.00
5905C9	2017-07-05 21:16:00+03	39700.00
5905CB	2017-07-27 09:59:00+03	31600.00
59061D	2017-08-04 06:06:00+03	24400.00
59063F	2017-07-25 13:18:00+03	213800.00
590645	2017-08-03 05:40:00+03	54800.00
59064E	2017-07-13 04:26:00+03	62600.00
590695	2017-08-02 14:16:00+03	26800.00
59070F	2017-08-01 23:49:00+03	13700.00
590737	2017-07-21 17:50:00+03	56000.00
590743	2017-07-16 13:58:00+03	57500.00
59076A	2017-07-15 19:07:00+03	69500.00
5907C4	2017-08-13 18:51:00+03	50600.00
59083D	2017-07-25 04:02:00+03	135600.00
59089E	2017-08-14 20:34:00+03	69900.00
5908BB	2017-07-22 20:10:00+03	85000.00
5908E5	2017-08-02 07:35:00+03	14000.00
590936	2017-08-14 19:46:00+03	116100.00
590938	2017-07-03 07:09:00+03	21800.00
59094B	2017-08-15 08:21:00+03	103600.00
5909F3	2017-07-27 06:11:00+03	6700.00
590A02	2017-08-01 03:17:00+03	32800.00
590A16	2017-07-15 16:54:00+03	119900.00
590A49	2017-07-08 21:54:00+03	62600.00
590AC5	2017-07-26 00:49:00+03	49800.00
590AD2	2017-07-17 01:43:00+03	28000.00
590B84	2017-08-09 09:02:00+03	123900.00
590B91	2017-07-26 21:55:00+03	26000.00
590BE0	2017-07-24 05:35:00+03	55800.00
590C06	2017-07-21 16:01:00+03	24200.00
590C2A	2017-07-05 08:52:00+03	45500.00
590C32	2017-07-10 02:41:00+03	182300.00
590D0A	2017-08-15 04:39:00+03	26800.00
590D3D	2017-07-25 01:09:00+03	14000.00
590D4B	2017-07-31 23:48:00+03	135600.00
590D7E	2017-07-15 05:34:00+03	147700.00
590D99	2017-07-24 20:31:00+03	92800.00
590DF7	2017-07-23 21:14:00+03	56600.00
590E21	2017-07-04 17:33:00+03	111700.00
590E40	2017-07-27 14:00:00+03	78400.00
590E5D	2017-07-21 12:47:00+03	173000.00
590EB3	2017-06-28 08:15:00+03	56000.00
590ED8	2017-07-06 06:16:00+03	23200.00
590ED9	2017-07-18 04:57:00+03	29600.00
590F0F	2017-07-31 09:52:00+03	71900.00
590F26	2017-07-02 19:02:00+03	232400.00
590F3D	2017-08-10 03:34:00+03	24400.00
590F77	2017-07-04 05:58:00+03	95600.00
590FD6	2017-07-29 02:17:00+03	119700.00
591002	2017-07-30 23:35:00+03	46400.00
5910A4	2017-07-02 10:49:00+03	92800.00
5910F5	2017-07-30 12:38:00+03	369000.00
5911CF	2017-07-31 21:23:00+03	399600.00
591218	2017-07-03 14:11:00+03	124300.00
5912CA	2017-07-29 07:53:00+03	135600.00
5912D5	2017-07-05 17:52:00+03	6400.00
5912F3	2017-07-19 22:26:00+03	56000.00
591331	2017-08-15 17:14:00+03	132800.00
59133B	2017-07-09 09:58:00+03	56600.00
591343	2017-08-04 08:09:00+03	155600.00
59134A	2017-07-07 04:35:00+03	91100.00
5913A8	2017-08-01 15:49:00+03	19600.00
591431	2017-08-06 21:33:00+03	24000.00
591473	2017-07-17 11:26:00+03	40800.00
5914E1	2017-08-04 08:49:00+03	40200.00
59150F	2017-08-07 13:40:00+03	27200.00
59153C	2017-07-29 04:20:00+03	73600.00
591671	2017-07-23 21:42:00+03	48800.00
591674	2017-07-21 19:05:00+03	44000.00
591681	2017-07-21 20:12:00+03	18200.00
59171C	2017-07-20 19:59:00+03	28800.00
591751	2017-07-15 22:30:00+03	6300.00
59176C	2017-08-07 09:26:00+03	38400.00
59179F	2017-08-01 09:59:00+03	14000.00
5917E4	2017-07-24 07:42:00+03	40800.00
5917E5	2017-07-29 15:47:00+03	46400.00
591825	2017-08-09 13:53:00+03	37200.00
591865	2017-07-20 20:32:00+03	43500.00
5918AF	2017-08-01 21:28:00+03	43800.00
5918C2	2017-06-29 18:34:00+03	56000.00
59190D	2017-08-11 11:24:00+03	56000.00
59194D	2017-07-23 10:27:00+03	38500.00
591998	2017-07-30 02:02:00+03	378700.00
5919C6	2017-07-26 20:23:00+03	59200.00
5919F8	2017-07-21 22:35:00+03	169500.00
591A0A	2017-08-01 07:48:00+03	92800.00
591A2C	2017-08-06 12:01:00+03	12400.00
591A5E	2017-07-16 08:30:00+03	265800.00
591A83	2017-07-23 19:22:00+03	111700.00
591A84	2017-07-01 17:03:00+03	23200.00
591AD7	2017-08-09 22:57:00+03	99200.00
591B20	2017-08-06 17:19:00+03	135200.00
591BAA	2017-07-19 04:31:00+03	58000.00
591BC7	2017-07-20 17:47:00+03	19600.00
591BDB	2017-07-31 01:55:00+03	88500.00
591C59	2017-08-12 00:38:00+03	28800.00
591C5B	2017-08-08 15:24:00+03	25400.00
591C6D	2017-07-17 23:31:00+03	83000.00
591D2C	2017-08-14 19:19:00+03	56000.00
591DDE	2017-08-10 04:03:00+03	42800.00
591E44	2017-07-21 21:21:00+03	25600.00
591EA6	2017-07-28 06:21:00+03	70800.00
591EAE	2017-08-01 17:10:00+03	68000.00
591EB3	2017-07-15 19:02:00+03	39200.00
591ECB	2017-07-27 02:47:00+03	55600.00
591EDC	2017-07-19 13:25:00+03	111600.00
591EE6	2017-08-15 11:05:00+03	48800.00
591EFC	2017-07-16 23:59:00+03	46400.00
591F2A	2017-07-12 04:41:00+03	152500.00
591F8D	2017-07-30 19:48:00+03	230000.00
591F92	2017-07-29 13:09:00+03	26700.00
591FFB	2017-07-04 10:15:00+03	56600.00
592083	2017-07-14 15:47:00+03	31600.00
5920A3	2017-08-11 16:20:00+03	28300.00
5920C2	2017-07-08 13:09:00+03	21800.00
5920E0	2017-08-04 07:42:00+03	26000.00
5920FF	2017-07-13 05:15:00+03	73300.00
592175	2017-08-15 14:26:00+03	49800.00
5921CD	2017-08-11 10:57:00+03	27200.00
5921EB	2017-08-13 05:26:00+03	102100.00
592226	2017-07-01 16:47:00+03	23200.00
592294	2017-07-01 05:26:00+03	70700.00
5922A2	2017-07-05 23:55:00+03	53400.00
592361	2017-07-29 16:29:00+03	67800.00
5923DB	2017-07-11 04:56:00+03	90800.00
59245E	2017-07-14 02:41:00+03	70700.00
59248D	2017-08-12 11:07:00+03	73600.00
5924CD	2017-07-17 13:23:00+03	43600.00
592500	2017-07-13 05:23:00+03	240600.00
59250A	2017-07-17 17:01:00+03	6700.00
592544	2017-08-14 21:34:00+03	86600.00
592576	2017-07-08 16:19:00+03	37500.00
592624	2017-07-24 20:12:00+03	33300.00
59267D	2017-08-05 20:06:00+03	123000.00
59267F	2017-07-12 08:27:00+03	44600.00
5926C1	2017-08-15 10:32:00+03	65000.00
5926C6	2017-07-17 00:39:00+03	47400.00
5926E7	2017-08-12 00:40:00+03	18900.00
5926FB	2017-07-22 15:33:00+03	62800.00
59270B	2017-08-06 19:57:00+03	141000.00
59273C	2017-08-10 12:38:00+03	92400.00
592757	2017-07-26 08:50:00+03	22000.00
592762	2017-07-23 06:22:00+03	48700.00
59279E	2017-07-19 14:56:00+03	126900.00
592863	2017-07-09 12:23:00+03	44500.00
592895	2017-08-12 19:27:00+03	90800.00
59289D	2017-07-09 23:49:00+03	36800.00
5928A1	2017-07-26 15:11:00+03	58600.00
5928E1	2017-07-13 06:45:00+03	6800.00
592931	2017-07-17 08:43:00+03	33200.00
592977	2017-08-10 18:47:00+03	131100.00
59297F	2017-07-31 17:10:00+03	68100.00
5929E1	2017-07-27 02:42:00+03	20200.00
5929F9	2017-07-08 04:15:00+03	119500.00
5929FE	2017-08-02 05:32:00+03	246000.00
5929FF	2017-07-24 01:32:00+03	23200.00
592A1B	2017-08-15 03:11:00+03	118200.00
592A3A	2017-06-27 11:53:00+03	27200.00
592A69	2017-07-30 23:57:00+03	44000.00
592AFD	2017-07-08 03:22:00+03	62600.00
592B10	2017-08-15 06:35:00+03	165100.00
592B26	2017-08-03 21:13:00+03	58600.00
592BB7	2017-08-10 02:37:00+03	25600.00
592C48	2017-08-13 01:31:00+03	23800.00
592C68	2017-07-27 12:28:00+03	14900.00
592CBA	2017-08-06 16:46:00+03	47100.00
592CC2	2017-07-31 02:23:00+03	57800.00
592CE0	2017-07-18 11:08:00+03	299600.00
592CEA	2017-07-28 18:58:00+03	34000.00
592D36	2017-07-15 11:02:00+03	241400.00
592DE7	2017-07-11 21:23:00+03	23200.00
592E15	2017-08-14 18:57:00+03	24700.00
592E19	2017-08-15 02:25:00+03	61500.00
592EEB	2017-07-11 14:40:00+03	16400.00
592EFA	2017-08-14 06:21:00+03	56900.00
592F1F	2017-07-11 23:15:00+03	6700.00
592F55	2017-08-13 15:08:00+03	15400.00
592FA7	2017-08-05 03:07:00+03	75300.00
593056	2017-07-09 15:34:00+03	270200.00
593068	2017-07-31 10:30:00+03	43400.00
593069	2017-07-12 21:50:00+03	266200.00
59306E	2017-07-28 11:24:00+03	122700.00
59309C	2017-07-06 11:43:00+03	47000.00
5930A1	2017-07-16 00:46:00+03	64800.00
5930DA	2017-07-24 08:39:00+03	6300.00
593109	2017-06-30 22:40:00+03	25600.00
59316A	2017-07-20 09:40:00+03	302400.00
593173	2017-06-30 11:20:00+03	56000.00
5931BC	2017-08-02 07:39:00+03	40800.00
5931E9	2017-07-20 16:38:00+03	6800.00
59323F	2017-07-03 01:07:00+03	19600.00
593252	2017-07-17 13:25:00+03	77200.00
5932D6	2017-07-02 04:43:00+03	100000.00
593307	2017-07-24 06:36:00+03	199300.00
593366	2017-07-29 09:37:00+03	33600.00
593389	2017-07-09 19:56:00+03	144700.00
593395	2017-08-14 13:08:00+03	28800.00
5933A7	2017-07-17 12:48:00+03	114800.00
5933B5	2017-07-21 01:59:00+03	12200.00
593441	2017-08-15 04:51:00+03	12600.00
593452	2017-08-10 18:19:00+03	42600.00
593474	2017-08-03 14:45:00+03	133100.00
593484	2017-07-10 19:04:00+03	28000.00
59348E	2017-07-04 18:30:00+03	51200.00
59350E	2017-08-01 17:51:00+03	305500.00
593525	2017-07-08 06:54:00+03	40000.00
593539	2017-08-12 13:42:00+03	93600.00
5935DE	2017-08-05 15:52:00+03	56000.00
593603	2017-06-28 15:39:00+03	37100.00
593630	2017-07-21 15:29:00+03	23200.00
593651	2017-07-15 16:38:00+03	148200.00
59367B	2017-07-19 03:25:00+03	66600.00
59368F	2017-07-01 18:51:00+03	56000.00
5936AE	2017-07-04 06:07:00+03	15000.00
5936FB	2017-06-29 07:54:00+03	57600.00
5936FF	2017-07-25 22:06:00+03	37900.00
593742	2017-07-25 05:07:00+03	30200.00
59374D	2017-07-31 07:15:00+03	167200.00
59379B	2017-07-25 16:48:00+03	27200.00
5937B5	2017-08-14 01:31:00+03	29600.00
5937D7	2017-07-24 09:53:00+03	101800.00
593836	2017-08-14 08:56:00+03	52100.00
5938B0	2017-08-14 02:18:00+03	258400.00
5938D5	2017-07-31 13:59:00+03	46400.00
5938E3	2017-07-16 22:33:00+03	58600.00
59390A	2017-07-31 10:53:00+03	43200.00
593943	2017-08-01 10:19:00+03	26000.00
593948	2017-08-09 21:48:00+03	90800.00
593A50	2017-07-16 05:46:00+03	46500.00
593A7A	2017-08-05 05:29:00+03	18000.00
593AA0	2017-07-27 10:39:00+03	36800.00
593AEB	2017-08-01 09:44:00+03	26000.00
593AED	2017-08-10 00:26:00+03	28800.00
593B03	2017-07-05 19:14:00+03	369000.00
593B0E	2017-07-07 07:28:00+03	21400.00
593B21	2017-07-29 23:53:00+03	144300.00
593B24	2017-07-25 10:59:00+03	56100.00
593B34	2017-07-04 22:41:00+03	97000.00
593C25	2017-07-05 08:16:00+03	111600.00
593D05	2017-07-21 07:58:00+03	248300.00
593DFC	2017-08-01 04:57:00+03	78600.00
593E55	2017-07-23 12:53:00+03	56200.00
593E63	2017-06-30 23:40:00+03	24400.00
593E69	2017-08-01 16:56:00+03	43600.00
593E88	2017-07-10 17:32:00+03	134400.00
593E9B	2017-07-15 09:19:00+03	75600.00
593F98	2017-07-03 09:36:00+03	28800.00
594022	2017-07-31 21:27:00+03	92000.00
594046	2017-08-15 17:10:00+03	18600.00
59406E	2017-07-15 06:19:00+03	46400.00
59407F	2017-08-08 22:21:00+03	22000.00
594098	2017-07-07 06:38:00+03	56000.00
5940C3	2017-08-13 10:55:00+03	100800.00
5940E3	2017-08-11 05:14:00+03	43600.00
59410F	2017-08-01 07:05:00+03	45200.00
594110	2017-08-07 04:46:00+03	136800.00
59416E	2017-08-10 01:49:00+03	49100.00
594193	2017-07-22 02:20:00+03	119400.00
5941F9	2017-07-23 12:01:00+03	21600.00
5941FB	2017-07-14 07:40:00+03	53400.00
59437D	2017-07-18 10:35:00+03	21200.00
594386	2017-08-12 21:20:00+03	56000.00
594393	2017-07-13 22:38:00+03	20200.00
594398	2017-07-02 19:31:00+03	46300.00
594416	2017-08-06 01:58:00+03	134700.00
59442A	2017-07-08 12:41:00+03	123000.00
594457	2017-08-09 01:38:00+03	25600.00
59446F	2017-07-24 15:00:00+03	18600.00
5944AA	2017-07-12 10:15:00+03	16400.00
5945B4	2017-07-02 20:32:00+03	246000.00
5945BD	2017-07-24 04:09:00+03	73500.00
5945E5	2017-07-07 16:56:00+03	230200.00
594620	2017-07-04 07:10:00+03	58900.00
594623	2017-07-09 13:12:00+03	123600.00
594630	2017-07-16 10:22:00+03	26000.00
59464E	2017-08-12 04:26:00+03	122800.00
59468F	2017-07-29 11:40:00+03	258400.00
594694	2017-07-24 20:00:00+03	123000.00
5946BA	2017-07-04 06:48:00+03	116700.00
594716	2017-07-15 13:53:00+03	20600.00
59474A	2017-08-14 03:50:00+03	111700.00
594767	2017-08-09 21:29:00+03	375200.00
5947A8	2017-08-08 14:54:00+03	24800.00
5947B8	2017-08-05 07:50:00+03	93400.00
5947C2	2017-08-04 23:14:00+03	103400.00
5947C5	2017-07-12 16:16:00+03	28700.00
5947F1	2017-08-14 02:42:00+03	13400.00
594812	2017-07-08 11:11:00+03	18000.00
594824	2017-07-25 18:01:00+03	132800.00
594825	2017-06-26 10:52:00+03	92400.00
59482C	2017-08-14 05:32:00+03	99200.00
594835	2017-08-05 03:39:00+03	38400.00
594850	2017-08-11 05:11:00+03	6300.00
594897	2017-08-05 06:47:00+03	70700.00
594899	2017-08-14 14:39:00+03	43400.00
5948F8	2017-08-05 14:05:00+03	59900.00
594920	2017-08-04 02:40:00+03	95200.00
5949C6	2017-07-14 18:16:00+03	114700.00
594A05	2017-07-08 01:02:00+03	226200.00
594A25	2017-07-23 00:55:00+03	50000.00
594A74	2017-07-01 10:25:00+03	81800.00
594A96	2017-07-31 11:24:00+03	400900.00
594AA8	2017-07-19 06:58:00+03	258000.00
594B79	2017-06-27 21:26:00+03	187600.00
594BB5	2017-07-18 05:50:00+03	123000.00
594BDA	2017-08-09 01:50:00+03	21000.00
594BEB	2017-07-20 21:07:00+03	31100.00
594C54	2017-08-07 00:40:00+03	23200.00
594C63	2017-07-14 07:23:00+03	35600.00
594C9D	2017-07-30 23:47:00+03	8200.00
594CF0	2017-07-03 08:05:00+03	20400.00
594D05	2017-08-07 15:04:00+03	254900.00
594D2C	2017-07-30 18:58:00+03	40800.00
594D56	2017-08-03 18:19:00+03	56000.00
594DC9	2017-08-15 13:19:00+03	38400.00
594DE8	2017-07-11 00:12:00+03	67600.00
594E11	2017-07-05 11:32:00+03	266400.00
594E9C	2017-08-04 00:09:00+03	16400.00
594EBE	2017-07-31 11:57:00+03	32800.00
594F16	2017-07-18 18:08:00+03	44000.00
594F25	2017-07-31 19:53:00+03	130600.00
594F87	2017-08-12 22:55:00+03	21800.00
594FB5	2017-06-29 11:24:00+03	112600.00
594FB9	2017-07-07 17:31:00+03	48700.00
594FD6	2017-08-09 22:59:00+03	18600.00
59504E	2017-07-20 14:15:00+03	7800.00
595054	2017-07-02 06:14:00+03	23400.00
59508B	2017-07-18 03:04:00+03	6700.00
5950BA	2017-07-15 21:31:00+03	136200.00
5950C9	2017-07-28 10:07:00+03	92800.00
5950CF	2017-07-15 09:16:00+03	33100.00
59510D	2017-08-02 19:16:00+03	281500.00
595113	2017-07-12 16:00:00+03	28000.00
595118	2017-07-07 03:30:00+03	71400.00
59511E	2017-08-11 21:49:00+03	40600.00
595146	2017-08-06 16:29:00+03	47100.00
595147	2017-08-08 02:33:00+03	58600.00
595148	2017-07-31 00:58:00+03	56000.00
59514F	2017-08-08 21:32:00+03	12600.00
5951D2	2017-07-04 09:01:00+03	28800.00
5951E1	2017-08-08 20:53:00+03	123000.00
59520B	2017-07-08 11:32:00+03	133100.00
59521B	2017-08-02 00:31:00+03	26000.00
595232	2017-07-28 14:42:00+03	44800.00
5952A4	2017-08-13 02:40:00+03	28800.00
5952A6	2017-08-03 02:19:00+03	18800.00
5952CF	2017-08-07 11:53:00+03	70700.00
5952D7	2017-07-20 22:57:00+03	20200.00
5952D9	2017-08-05 03:32:00+03	78000.00
5952FB	2017-07-18 00:37:00+03	87900.00
595319	2017-08-11 02:07:00+03	47000.00
59533B	2017-07-08 11:09:00+03	51900.00
59535B	2017-08-07 10:44:00+03	53200.00
595406	2017-08-05 05:18:00+03	49100.00
5954C7	2017-08-12 22:19:00+03	73200.00
595547	2017-07-03 12:30:00+03	37600.00
595609	2017-07-29 09:45:00+03	34400.00
595638	2017-07-13 21:59:00+03	27900.00
595683	2017-08-02 02:17:00+03	23600.00
5956BC	2017-08-11 20:07:00+03	130400.00
5957D3	2017-07-06 03:50:00+03	135400.00
5957ED	2017-07-11 20:09:00+03	58900.00
595807	2017-07-04 11:15:00+03	6600.00
595852	2017-08-14 01:39:00+03	28800.00
595870	2017-07-18 14:28:00+03	28800.00
595871	2017-07-17 19:15:00+03	199800.00
5958FC	2017-07-27 18:49:00+03	68800.00
59590D	2017-07-08 03:06:00+03	215500.00
595955	2017-07-30 17:43:00+03	186900.00
595963	2017-06-30 01:11:00+03	55800.00
595971	2017-08-08 17:12:00+03	139300.00
59597B	2017-07-05 20:02:00+03	189100.00
5959A2	2017-08-04 07:06:00+03	42800.00
5959CF	2017-07-17 20:41:00+03	92000.00
5959F4	2017-08-13 07:54:00+03	28800.00
595A44	2017-07-14 20:17:00+03	136200.00
595AB4	2017-07-12 11:14:00+03	80000.00
595ADA	2017-08-03 20:28:00+03	48900.00
595AF6	2017-08-04 13:43:00+03	114700.00
595B01	2017-07-23 12:57:00+03	179300.00
595B57	2017-07-24 10:51:00+03	75600.00
595B5C	2017-08-14 14:22:00+03	102200.00
595BAB	2017-08-06 02:01:00+03	92400.00
595C09	2017-08-03 08:19:00+03	38600.00
595C2D	2017-07-23 15:22:00+03	28000.00
595C7D	2017-07-12 08:00:00+03	87700.00
595C8F	2017-07-08 19:48:00+03	28800.00
595CDC	2017-07-16 09:18:00+03	65900.00
595CED	2017-07-27 10:45:00+03	40000.00
595CFB	2017-08-06 01:23:00+03	25600.00
595D04	2017-08-02 08:07:00+03	54200.00
595D24	2017-07-18 21:31:00+03	141700.00
595D97	2017-07-16 03:48:00+03	93900.00
595DC7	2017-07-22 09:58:00+03	6800.00
595E43	2017-07-24 01:57:00+03	92700.00
595E59	2017-07-30 17:46:00+03	75600.00
595E9A	2017-06-29 03:37:00+03	153300.00
595F34	2017-08-09 10:14:00+03	135400.00
595F35	2017-07-25 10:10:00+03	399600.00
595F90	2017-08-04 09:28:00+03	26200.00
595FE8	2017-07-18 21:31:00+03	120100.00
596025	2017-07-15 10:00:00+03	54800.00
596094	2017-08-11 09:14:00+03	30300.00
5960A5	2017-07-04 08:08:00+03	33300.00
596167	2017-08-03 11:17:00+03	14000.00
5961AA	2017-07-26 01:46:00+03	27400.00
5961C9	2017-06-30 16:03:00+03	55800.00
59620B	2017-07-27 02:58:00+03	31400.00
596255	2017-07-29 02:11:00+03	18800.00
5962D5	2017-07-04 21:05:00+03	46300.00
59630D	2017-08-14 04:02:00+03	28000.00
596327	2017-07-03 12:46:00+03	63700.00
59635E	2017-08-03 01:02:00+03	139000.00
59636B	2017-07-28 04:14:00+03	19600.00
596386	2017-07-16 18:24:00+03	192400.00
596396	2017-07-11 20:22:00+03	28800.00
5963B5	2017-07-13 08:18:00+03	23200.00
5963FE	2017-07-16 09:29:00+03	113600.00
596423	2017-08-05 01:47:00+03	12600.00
596470	2017-08-08 07:53:00+03	62000.00
5964C5	2017-07-07 13:03:00+03	124300.00
5965FF	2017-08-03 05:07:00+03	99700.00
596623	2017-07-08 21:00:00+03	56600.00
596652	2017-08-13 15:39:00+03	75300.00
596679	2017-07-30 11:48:00+03	40600.00
5966B5	2017-08-14 07:58:00+03	43500.00
596753	2017-07-22 23:26:00+03	46500.00
59676A	2017-07-19 01:16:00+03	133200.00
596794	2017-07-25 12:05:00+03	88700.00
5967A2	2017-07-03 05:18:00+03	37900.00
5967E2	2017-07-10 01:40:00+03	44000.00
5967EF	2017-07-02 15:14:00+03	52000.00
5968C3	2017-08-10 02:44:00+03	22000.00
5968E1	2017-08-11 16:16:00+03	8200.00
596969	2017-07-21 21:28:00+03	99200.00
59696E	2017-07-05 12:37:00+03	148200.00
5969BD	2017-07-02 08:14:00+03	37900.00
596A04	2017-07-09 12:19:00+03	27200.00
596A4D	2017-08-07 21:03:00+03	87000.00
596A9E	2017-07-23 10:20:00+03	133100.00
596ABE	2017-08-07 04:54:00+03	139500.00
596AC4	2017-07-02 23:23:00+03	58200.00
596B09	2017-07-27 16:34:00+03	40100.00
596B27	2017-08-03 19:05:00+03	26500.00
596B3D	2017-07-07 12:35:00+03	21800.00
596B4A	2017-08-07 00:21:00+03	56000.00
596B5B	2017-07-12 03:26:00+03	67600.00
596B83	2017-06-30 16:38:00+03	40800.00
596B95	2017-07-08 14:01:00+03	406700.00
596BA7	2017-08-09 10:45:00+03	73600.00
596BF3	2017-07-06 22:15:00+03	23200.00
596C7F	2017-07-11 18:43:00+03	16400.00
596CB5	2017-07-19 01:49:00+03	52000.00
596CE5	2017-07-26 10:30:00+03	43200.00
596D19	2017-07-17 17:54:00+03	28000.00
596E0A	2017-07-26 02:01:00+03	64500.00
596E0E	2017-08-05 11:28:00+03	39900.00
596E1C	2017-07-23 17:52:00+03	13400.00
596E3C	2017-07-30 00:15:00+03	135400.00
596EE4	2017-07-26 15:04:00+03	22000.00
596F19	2017-07-06 03:19:00+03	68400.00
596F20	2017-07-30 16:27:00+03	137100.00
596F47	2017-07-11 16:59:00+03	70600.00
596F57	2017-07-07 10:19:00+03	23200.00
596FF6	2017-07-08 01:43:00+03	12600.00
597018	2017-08-06 08:29:00+03	46300.00
597097	2017-07-19 16:13:00+03	57600.00
597098	2017-08-07 09:54:00+03	14000.00
59709F	2017-07-23 07:29:00+03	6600.00
597153	2017-07-16 17:33:00+03	34000.00
597174	2017-07-13 05:53:00+03	23600.00
597199	2017-08-04 23:08:00+03	6700.00
5971CD	2017-07-07 01:16:00+03	153300.00
5971DD	2017-07-11 21:50:00+03	156000.00
5972C0	2017-07-13 05:18:00+03	54400.00
5972D5	2017-07-06 22:34:00+03	292500.00
59739A	2017-07-20 03:51:00+03	25200.00
5973F5	2017-07-13 14:45:00+03	145300.00
597404	2017-07-19 16:44:00+03	53700.00
597450	2017-07-07 06:51:00+03	32800.00
597504	2017-07-15 22:05:00+03	9800.00
597515	2017-07-12 01:07:00+03	28000.00
597570	2017-08-14 03:53:00+03	118000.00
59757C	2017-07-02 02:51:00+03	93900.00
597586	2017-08-02 15:16:00+03	28000.00
5975B3	2017-08-06 05:46:00+03	81700.00
5975D1	2017-07-31 22:46:00+03	29600.00
5975F9	2017-07-10 05:40:00+03	39500.00
597602	2017-07-22 06:05:00+03	11600.00
597636	2017-07-23 05:44:00+03	60400.00
59766A	2017-07-23 09:24:00+03	126400.00
597744	2017-08-14 02:59:00+03	88800.00
5977AC	2017-07-05 17:26:00+03	56000.00
5977DF	2017-07-09 09:08:00+03	38200.00
597803	2017-08-05 06:31:00+03	333400.00
597866	2017-07-01 19:34:00+03	27200.00
5978B7	2017-07-31 20:02:00+03	260300.00
5978C4	2017-08-01 19:34:00+03	150600.00
597915	2017-08-13 03:15:00+03	258000.00
59792E	2017-07-08 02:31:00+03	145200.00
59795E	2017-08-14 11:42:00+03	40100.00
597985	2017-08-09 09:48:00+03	112000.00
59798C	2017-07-12 16:51:00+03	29200.00
5979B9	2017-08-08 00:58:00+03	166000.00
597A39	2017-08-11 22:27:00+03	28000.00
597A4B	2017-07-24 06:50:00+03	117000.00
597A75	2017-08-03 20:39:00+03	46400.00
597AA0	2017-07-03 07:31:00+03	23100.00
597AD5	2017-07-15 05:34:00+03	32900.00
597B8D	2017-07-19 18:34:00+03	296200.00
597C66	2017-07-30 07:41:00+03	29200.00
597C72	2017-07-01 14:52:00+03	187600.00
597C86	2017-07-12 03:22:00+03	77900.00
597CA3	2017-07-23 17:50:00+03	266400.00
597CAC	2017-08-09 01:27:00+03	94000.00
597D56	2017-06-26 12:24:00+03	56000.00
597DD2	2017-07-19 15:25:00+03	52000.00
597E4E	2017-08-02 17:15:00+03	108200.00
597E79	2017-07-04 13:18:00+03	75300.00
597F00	2017-08-07 19:12:00+03	26000.00
597F48	2017-07-19 13:17:00+03	58600.00
597F85	2017-08-13 15:08:00+03	32800.00
597F90	2017-07-22 05:11:00+03	46400.00
597FBC	2017-08-03 22:57:00+03	75600.00
597FC8	2017-08-03 02:12:00+03	201800.00
597FF4	2017-08-03 03:05:00+03	74000.00
59806F	2017-07-17 23:34:00+03	56600.00
598088	2017-07-30 11:41:00+03	22000.00
5980E9	2017-08-06 22:40:00+03	48800.00
59812D	2017-07-18 07:24:00+03	43600.00
5981CD	2017-08-06 23:46:00+03	135100.00
5981E5	2017-07-25 04:21:00+03	161900.00
598221	2017-08-13 22:49:00+03	22300.00
598224	2017-07-17 14:30:00+03	6800.00
598256	2017-07-02 01:19:00+03	369000.00
598261	2017-08-06 18:18:00+03	47500.00
598273	2017-07-30 23:45:00+03	28000.00
59828C	2017-07-24 04:55:00+03	59300.00
598310	2017-08-10 13:59:00+03	36000.00
598324	2017-07-02 20:21:00+03	200200.00
598339	2017-07-09 02:22:00+03	270800.00
5983A5	2017-07-05 03:31:00+03	75300.00
598408	2017-07-25 15:45:00+03	93900.00
59842D	2017-07-21 17:28:00+03	19600.00
598446	2017-07-07 07:07:00+03	265600.00
59849B	2017-07-07 21:32:00+03	58600.00
59849F	2017-07-12 04:39:00+03	70000.00
5984B8	2017-08-06 12:58:00+03	13400.00
5984CA	2017-07-15 00:25:00+03	22600.00
598505	2017-08-12 16:38:00+03	224000.00
598561	2017-08-07 17:45:00+03	81600.00
59861E	2017-08-05 02:52:00+03	37400.00
598624	2017-07-15 12:26:00+03	48100.00
598645	2017-07-19 06:57:00+03	84500.00
59868A	2017-08-13 03:47:00+03	21800.00
598696	2017-07-14 23:19:00+03	68100.00
5986AA	2017-07-06 23:40:00+03	24800.00
5986D4	2017-07-12 09:59:00+03	54800.00
5986DA	2017-07-02 10:28:00+03	13400.00
5986F5	2017-08-15 03:26:00+03	98000.00
5986F7	2017-08-09 08:16:00+03	16400.00
59870F	2017-08-04 10:24:00+03	62600.00
598722	2017-07-22 08:56:00+03	55800.00
598886	2017-07-17 05:37:00+03	24700.00
59890A	2017-07-07 12:45:00+03	30700.00
598934	2017-08-12 11:04:00+03	114400.00
5989A5	2017-07-24 00:36:00+03	545900.00
5989BD	2017-07-16 23:45:00+03	38400.00
5989D5	2017-07-17 18:48:00+03	52600.00
598A02	2017-08-11 22:14:00+03	24400.00
598A1A	2017-08-14 06:06:00+03	73200.00
598A2F	2017-08-02 10:09:00+03	92600.00
598A47	2017-08-11 18:33:00+03	14000.00
598A74	2017-07-15 15:40:00+03	82900.00
598A83	2017-07-25 17:00:00+03	125200.00
598ACC	2017-07-20 13:03:00+03	68800.00
598AEA	2017-07-13 12:04:00+03	50000.00
598B78	2017-08-01 23:18:00+03	105200.00
598B93	2017-08-11 13:34:00+03	46000.00
598B97	2017-07-13 23:46:00+03	384900.00
598BDE	2017-07-29 23:39:00+03	28000.00
598BE6	2017-07-06 20:33:00+03	21400.00
598CCE	2017-07-26 11:15:00+03	6000.00
598CE4	2017-08-03 22:13:00+03	168700.00
598CEC	2017-08-07 02:32:00+03	47400.00
598CF4	2017-07-04 05:57:00+03	51800.00
598CFB	2017-08-13 18:35:00+03	191600.00
598D0D	2017-07-17 08:18:00+03	13600.00
598D3A	2017-07-26 21:05:00+03	22000.00
598D93	2017-07-19 09:14:00+03	38200.00
598DB2	2017-07-11 14:57:00+03	30200.00
598E0A	2017-06-29 14:20:00+03	23200.00
598EA8	2017-07-11 16:46:00+03	81800.00
598EBF	2017-07-13 03:36:00+03	46400.00
598EC3	2017-07-16 01:19:00+03	40800.00
598ED1	2017-08-15 12:15:00+03	25100.00
598F36	2017-08-07 06:07:00+03	124200.00
598F47	2017-08-06 18:12:00+03	116900.00
598FDC	2017-07-13 02:37:00+03	14000.00
598FDE	2017-06-28 23:10:00+03	26000.00
598FF8	2017-08-06 19:40:00+03	58600.00
599002	2017-08-01 07:44:00+03	364600.00
599017	2017-07-11 19:27:00+03	87200.00
599055	2017-07-04 15:45:00+03	92000.00
59906C	2017-07-25 08:41:00+03	272300.00
5990A4	2017-07-19 02:58:00+03	44000.00
5990B0	2017-07-02 23:31:00+03	33200.00
5990CF	2017-07-31 05:13:00+03	129300.00
599112	2017-07-03 12:58:00+03	147200.00
599127	2017-07-24 19:31:00+03	93700.00
59912D	2017-07-31 11:12:00+03	24400.00
599191	2017-07-11 13:35:00+03	46000.00
599194	2017-07-07 11:40:00+03	55800.00
5991E4	2017-07-20 08:54:00+03	39500.00
599209	2017-07-19 07:36:00+03	40400.00
599232	2017-08-12 13:50:00+03	44800.00
59929A	2017-08-11 15:49:00+03	6300.00
5992C0	2017-07-15 05:03:00+03	55800.00
599304	2017-07-22 03:56:00+03	50600.00
5993B2	2017-07-25 21:41:00+03	92000.00
5993E7	2017-08-06 21:25:00+03	133200.00
5993FB	2017-08-02 08:17:00+03	25400.00
599423	2017-08-07 00:44:00+03	111900.00
599483	2017-08-10 22:45:00+03	52100.00
599487	2017-08-03 22:41:00+03	123000.00
59948C	2017-07-16 02:25:00+03	23900.00
599546	2017-08-03 05:26:00+03	85000.00
5995AF	2017-07-06 07:09:00+03	13700.00
599629	2017-08-14 06:55:00+03	60400.00
599638	2017-07-09 18:39:00+03	131100.00
59964A	2017-08-01 06:51:00+03	34000.00
599652	2017-07-25 20:09:00+03	123000.00
59972F	2017-06-29 14:51:00+03	94600.00
59978D	2017-07-20 01:53:00+03	145100.00
5997D1	2017-08-06 10:11:00+03	152500.00
5997E1	2017-07-27 18:41:00+03	38400.00
59980F	2017-07-07 06:13:00+03	75600.00
599839	2017-08-15 03:52:00+03	81600.00
5998A4	2017-07-26 02:10:00+03	101000.00
5998EA	2017-06-27 13:20:00+03	35200.00
5998F6	2017-07-27 15:57:00+03	25000.00
59990B	2017-07-03 00:43:00+03	257600.00
59991E	2017-07-20 15:01:00+03	81700.00
59996A	2017-07-09 04:02:00+03	64100.00
599A5C	2017-07-14 19:52:00+03	11300.00
599A5D	2017-07-22 09:24:00+03	260900.00
599A68	2017-07-27 19:55:00+03	19600.00
599A92	2017-07-20 11:44:00+03	16400.00
599AC5	2017-08-01 01:41:00+03	10800.00
599B19	2017-07-25 01:31:00+03	55400.00
599B22	2017-07-21 14:39:00+03	39500.00
599B2F	2017-07-16 08:08:00+03	17800.00
599B69	2017-08-03 17:54:00+03	22000.00
599B71	2017-07-06 12:15:00+03	66100.00
599B9B	2017-07-23 06:30:00+03	136200.00
599C17	2017-08-04 20:13:00+03	14000.00
599CE3	2017-08-11 15:06:00+03	64700.00
599D26	2017-07-03 16:18:00+03	59300.00
599D56	2017-07-31 20:38:00+03	85000.00
599D57	2017-07-17 23:18:00+03	43900.00
599D83	2017-08-09 20:47:00+03	46000.00
599DFE	2017-07-18 14:21:00+03	23200.00
599E44	2017-07-17 16:38:00+03	37900.00
599E50	2017-07-26 22:55:00+03	23200.00
599E8E	2017-08-08 11:02:00+03	36200.00
599E9B	2017-07-01 22:28:00+03	18600.00
599EC6	2017-08-06 16:40:00+03	136800.00
599F00	2017-07-12 06:48:00+03	180300.00
599F2B	2017-08-08 06:13:00+03	27900.00
599FCF	2017-08-10 22:28:00+03	6800.00
59A088	2017-08-03 09:56:00+03	92300.00
59A08F	2017-08-01 04:23:00+03	62700.00
59A155	2017-08-04 09:16:00+03	270800.00
59A191	2017-08-02 12:14:00+03	44600.00
59A1BA	2017-08-06 17:16:00+03	6800.00
59A1CB	2017-07-28 19:13:00+03	77200.00
59A1E9	2017-07-03 21:07:00+03	38800.00
59A1F7	2017-07-08 08:52:00+03	68100.00
59A1FF	2017-07-31 02:31:00+03	22400.00
59A245	2017-07-06 05:13:00+03	51200.00
59A2AE	2017-07-28 11:05:00+03	48800.00
59A32E	2017-07-31 12:00:00+03	154500.00
59A34D	2017-07-28 15:30:00+03	123000.00
59A376	2017-08-11 16:31:00+03	130000.00
59A393	2017-07-28 15:12:00+03	66600.00
59A3F8	2017-07-27 00:43:00+03	28700.00
59A413	2017-08-08 18:35:00+03	32200.00
59A428	2017-07-12 00:48:00+03	46400.00
59A4CA	2017-07-31 10:36:00+03	46800.00
59A4CD	2017-07-09 17:36:00+03	113200.00
59A4D7	2017-08-09 15:24:00+03	123400.00
59A4D8	2017-08-14 07:35:00+03	164600.00
59A539	2017-07-29 18:16:00+03	136500.00
59A567	2017-07-31 17:07:00+03	42400.00
59A58C	2017-07-06 07:05:00+03	59400.00
59A59C	2017-08-13 07:32:00+03	92000.00
59A5DB	2017-08-05 10:34:00+03	46400.00
59A5EF	2017-07-31 14:39:00+03	105000.00
59A6B0	2017-07-23 11:26:00+03	99200.00
59A6DA	2017-07-31 08:33:00+03	84100.00
59A761	2017-08-01 00:36:00+03	75300.00
59A7FF	2017-06-30 15:53:00+03	28400.00
59A83F	2017-07-11 15:56:00+03	56000.00
59A84D	2017-08-12 08:54:00+03	97900.00
59A86E	2017-07-28 19:32:00+03	94200.00
59A871	2017-06-29 15:31:00+03	29600.00
59A87E	2017-08-03 15:14:00+03	21800.00
59A88D	2017-07-03 02:38:00+03	100600.00
59A8E3	2017-08-03 17:02:00+03	50800.00
59A8FB	2017-07-15 14:21:00+03	58000.00
59A913	2017-07-23 01:06:00+03	21200.00
59A922	2017-07-14 08:56:00+03	112000.00
59A99A	2017-07-29 02:26:00+03	181100.00
59A9F9	2017-07-01 15:11:00+03	28800.00
59AA03	2017-07-23 11:12:00+03	246000.00
59AA0A	2017-07-20 09:52:00+03	100200.00
59AA84	2017-07-21 16:49:00+03	40100.00
59AAEC	2017-08-03 10:21:00+03	39800.00
59AAF5	2017-07-29 14:15:00+03	67400.00
59AB01	2017-07-09 15:28:00+03	46500.00
59AB46	2017-07-15 18:03:00+03	56900.00
59AB5C	2017-07-15 09:08:00+03	17200.00
59AB8B	2017-07-18 00:04:00+03	103400.00
59AC5B	2017-07-10 23:53:00+03	96300.00
59ACCA	2017-08-04 02:25:00+03	22000.00
59AD3D	2017-08-04 13:23:00+03	270800.00
59AD95	2017-08-12 22:28:00+03	100600.00
59ADA2	2017-07-13 16:51:00+03	36200.00
59ADFA	2017-08-13 08:17:00+03	32800.00
59AEB1	2017-07-17 13:54:00+03	14000.00
59AEBE	2017-08-11 01:29:00+03	37000.00
59AEC7	2017-08-06 00:27:00+03	50000.00
59AEEE	2017-07-22 18:27:00+03	46400.00
59AF66	2017-08-02 01:44:00+03	154700.00
59AF6D	2017-07-18 08:02:00+03	40400.00
59AFBA	2017-07-22 14:45:00+03	30200.00
59B026	2017-07-31 13:03:00+03	399300.00
59B13C	2017-08-06 22:51:00+03	75300.00
59B18D	2017-08-06 22:06:00+03	45100.00
59B19F	2017-08-13 16:21:00+03	128800.00
59B1FA	2017-07-29 21:50:00+03	48800.00
59B1FD	2017-07-22 21:18:00+03	71900.00
59B24F	2017-07-03 05:37:00+03	108000.00
59B266	2017-07-14 11:40:00+03	26000.00
59B285	2017-07-12 15:05:00+03	28800.00
59B2D2	2017-08-02 14:19:00+03	36400.00
59B2EE	2017-08-13 19:53:00+03	103500.00
59B301	2017-07-27 16:04:00+03	32700.00
59B365	2017-07-20 05:47:00+03	119500.00
59B3CE	2017-08-05 21:11:00+03	123000.00
59B3ED	2017-07-14 17:31:00+03	99200.00
59B423	2017-07-05 23:04:00+03	55800.00
59B480	2017-08-12 11:11:00+03	31000.00
59B4AC	2017-07-12 00:30:00+03	28300.00
59B4BC	2017-08-02 19:57:00+03	26000.00
59B4DE	2017-07-17 06:51:00+03	56000.00
59B54D	2017-06-28 10:37:00+03	119800.00
59B588	2017-07-06 12:10:00+03	37900.00
59B644	2017-08-07 22:42:00+03	128800.00
59B691	2017-07-23 04:30:00+03	28800.00
59B777	2017-06-27 04:25:00+03	28800.00
59B77D	2017-08-12 06:38:00+03	62000.00
59B7A3	2017-07-09 05:02:00+03	64700.00
59B7A9	2017-08-08 15:26:00+03	90000.00
59B7B8	2017-07-27 06:04:00+03	88800.00
59B7BC	2017-08-11 15:12:00+03	93900.00
59B7FD	2017-07-15 17:00:00+03	51300.00
59B80C	2017-08-01 19:40:00+03	60700.00
59B81D	2017-07-17 01:03:00+03	484100.00
59B875	2017-06-30 20:58:00+03	27200.00
59B893	2017-06-29 13:13:00+03	88500.00
59B8A3	2017-07-12 14:52:00+03	78800.00
59B8FA	2017-07-28 21:04:00+03	24400.00
59B91B	2017-07-26 10:18:00+03	73200.00
59B936	2017-07-19 17:13:00+03	56000.00
59B963	2017-07-11 01:07:00+03	25600.00
59B97F	2017-08-08 01:15:00+03	60400.00
59B9BE	2017-08-04 11:21:00+03	46400.00
59BA32	2017-07-25 01:22:00+03	28000.00
59BA8D	2017-07-23 17:33:00+03	55800.00
59BABB	2017-08-02 14:29:00+03	24400.00
59BAD0	2017-08-09 05:15:00+03	174400.00
59BB22	2017-08-09 17:12:00+03	290600.00
59BB43	2017-07-04 07:46:00+03	315000.00
59BB82	2017-07-29 17:56:00+03	28700.00
59BB96	2017-07-05 08:27:00+03	14400.00
59BBB7	2017-08-04 22:53:00+03	73600.00
59BBE8	2017-07-30 20:29:00+03	12600.00
59BCAA	2017-07-12 18:44:00+03	31400.00
59BCB3	2017-07-03 08:11:00+03	178300.00
59BD2D	2017-08-12 23:09:00+03	56900.00
59BDAC	2017-07-31 06:13:00+03	103500.00
59BDAD	2017-07-04 08:03:00+03	56600.00
59BDB1	2017-07-20 04:14:00+03	88000.00
59BDBC	2017-08-02 03:34:00+03	10600.00
59BDC7	2017-07-20 05:41:00+03	58600.00
59BE00	2017-07-19 12:32:00+03	85000.00
59BEA0	2017-07-24 17:40:00+03	101200.00
59BEB8	2017-07-19 23:33:00+03	23100.00
59BF3A	2017-07-27 22:30:00+03	97600.00
59BF75	2017-07-08 15:47:00+03	39100.00
59BFB4	2017-07-20 02:33:00+03	19600.00
59BFF5	2017-08-04 13:56:00+03	27800.00
59C050	2017-07-13 08:39:00+03	65500.00
59C07A	2017-07-05 15:04:00+03	52300.00
59C083	2017-08-06 10:07:00+03	126300.00
59C0CF	2017-07-07 22:55:00+03	10800.00
59C10E	2017-07-13 02:25:00+03	6700.00
59C160	2017-08-02 21:22:00+03	29400.00
59C1B7	2017-07-06 03:32:00+03	103300.00
59C1C0	2017-07-12 14:00:00+03	168000.00
59C202	2017-07-19 04:51:00+03	147300.00
59C24E	2017-08-08 16:56:00+03	61800.00
59C2A4	2017-08-03 14:45:00+03	32200.00
59C2D1	2017-07-28 20:12:00+03	51200.00
59C2F0	2017-07-24 07:02:00+03	92400.00
59C332	2017-08-03 16:12:00+03	15000.00
59C3C3	2017-07-27 17:04:00+03	185800.00
59C3E2	2017-07-08 08:14:00+03	28800.00
59C4EE	2017-07-26 19:38:00+03	133200.00
59C585	2017-07-17 07:20:00+03	103200.00
59C58E	2017-07-30 15:38:00+03	49800.00
59C61D	2017-08-09 04:30:00+03	63200.00
59C6AE	2017-08-14 20:54:00+03	12600.00
59C6BB	2017-07-22 03:29:00+03	25900.00
59C6D2	2017-07-22 07:55:00+03	111600.00
59C6FB	2017-07-11 05:58:00+03	23400.00
59C74E	2017-07-03 11:21:00+03	51600.00
59C795	2017-07-26 01:37:00+03	43600.00
59C7A5	2017-08-07 10:44:00+03	47000.00
59C7C3	2017-07-10 10:12:00+03	89700.00
59C7E5	2017-08-01 14:57:00+03	67600.00
59C802	2017-07-25 02:44:00+03	21600.00
59C819	2017-07-07 12:38:00+03	258400.00
59C83F	2017-08-15 01:14:00+03	284400.00
59C8BC	2017-08-04 10:13:00+03	6300.00
59C8D0	2017-07-22 18:24:00+03	49300.00
59C8E8	2017-07-22 23:54:00+03	29400.00
59C96B	2017-07-12 11:17:00+03	6700.00
59C97C	2017-07-22 06:32:00+03	206100.00
59C9C0	2017-07-03 13:41:00+03	265800.00
59C9C7	2017-07-21 04:09:00+03	6800.00
59C9D5	2017-07-27 13:10:00+03	35400.00
59CA2D	2017-08-04 02:47:00+03	50000.00
59CA5F	2017-07-03 22:14:00+03	154100.00
59CAC1	2017-07-13 22:27:00+03	10600.00
59CAE1	2017-06-29 20:27:00+03	28800.00
59CAEA	2017-08-09 12:03:00+03	92400.00
59CB1B	2017-08-09 17:51:00+03	99200.00
59CB37	2017-07-27 04:45:00+03	60400.00
59CB4A	2017-08-05 21:28:00+03	26800.00
59CB6D	2017-08-04 10:35:00+03	61800.00
59CBAF	2017-08-07 20:45:00+03	26800.00
59CBD1	2017-08-03 00:20:00+03	56000.00
59CBF2	2017-08-12 07:43:00+03	82300.00
59CBF5	2017-07-13 15:29:00+03	41600.00
59CC2B	2017-08-08 15:31:00+03	139200.00
59CC5C	2017-07-28 10:54:00+03	372500.00
59CCBC	2017-07-07 21:53:00+03	17800.00
59CD17	2017-07-25 15:36:00+03	13600.00
59CD27	2017-07-28 16:46:00+03	25600.00
59CD52	2017-07-21 22:42:00+03	57800.00
59CDAD	2017-07-25 16:28:00+03	25200.00
59CDD7	2017-08-06 07:23:00+03	270200.00
59CE05	2017-07-17 19:40:00+03	155000.00
59CE32	2017-07-02 02:33:00+03	52800.00
59CEA9	2017-08-12 00:01:00+03	143000.00
59CEB7	2017-07-21 19:21:00+03	38400.00
59CEC4	2017-07-04 11:38:00+03	40100.00
59CFBD	2017-07-23 06:17:00+03	192100.00
59CFE8	2017-07-06 04:02:00+03	15000.00
59D005	2017-07-10 09:58:00+03	132400.00
59D00D	2017-08-03 13:47:00+03	95000.00
59D048	2017-07-03 02:40:00+03	69000.00
59D05B	2017-07-03 08:39:00+03	36200.00
59D05F	2017-07-07 18:02:00+03	44600.00
59D111	2017-07-16 01:39:00+03	150200.00
59D123	2017-08-07 14:51:00+03	16400.00
59D1C2	2017-07-31 05:23:00+03	27200.00
59D1D1	2017-08-03 03:31:00+03	20400.00
59D1FD	2017-08-04 10:06:00+03	69700.00
59D2F0	2017-07-21 16:04:00+03	151200.00
59D361	2017-07-16 17:00:00+03	6000.00
59D377	2017-08-08 13:57:00+03	201800.00
59D387	2017-07-09 10:19:00+03	406200.00
59D3CB	2017-08-09 00:46:00+03	65500.00
59D3D7	2017-07-27 13:37:00+03	150600.00
59D47E	2017-08-13 09:43:00+03	64500.00
59D480	2017-08-01 00:59:00+03	68000.00
59D4A7	2017-07-30 23:46:00+03	46400.00
59D4AF	2017-08-10 03:40:00+03	51800.00
59D4D1	2017-07-14 08:37:00+03	25800.00
59D57F	2017-08-02 00:02:00+03	77900.00
59D58B	2017-07-29 13:59:00+03	13400.00
59D63D	2017-08-10 22:34:00+03	19800.00
59D64B	2017-08-06 10:37:00+03	123000.00
59D65E	2017-07-20 03:41:00+03	27900.00
59D81C	2017-08-02 10:47:00+03	133100.00
59D873	2017-07-27 07:25:00+03	30400.00
59D891	2017-07-31 16:58:00+03	62800.00
59D8A8	2017-07-29 13:35:00+03	97900.00
59D8F5	2017-07-05 10:36:00+03	34800.00
59D909	2017-07-03 16:10:00+03	72400.00
59DA9D	2017-07-01 20:21:00+03	122300.00
59DBCC	2017-08-10 14:22:00+03	26000.00
59DBCE	2017-07-18 19:26:00+03	16400.00
59DBFE	2017-07-22 18:52:00+03	196800.00
59DC39	2017-07-19 15:05:00+03	26000.00
59DC46	2017-07-04 03:10:00+03	23200.00
59DC7F	2017-08-06 15:12:00+03	130400.00
59DCF9	2017-08-02 15:01:00+03	142800.00
59DD1C	2017-07-14 05:06:00+03	64800.00
59DD43	2017-08-04 01:09:00+03	30000.00
59DD9D	2017-07-23 07:09:00+03	24600.00
59DDA0	2017-07-23 10:14:00+03	73100.00
59DDBF	2017-08-09 07:45:00+03	99700.00
59DE1E	2017-08-11 07:36:00+03	61800.00
59DE38	2017-07-07 18:00:00+03	28800.00
59DEB3	2017-08-12 19:31:00+03	35600.00
59DEE9	2017-08-03 04:48:00+03	147000.00
59DF16	2017-07-21 09:34:00+03	187800.00
59DF40	2017-08-15 12:15:00+03	36200.00
59DF97	2017-07-25 07:04:00+03	37700.00
59E018	2017-07-26 11:03:00+03	78300.00
59E029	2017-07-09 01:14:00+03	16400.00
59E060	2017-07-24 18:22:00+03	101200.00
59E161	2017-07-31 22:39:00+03	41600.00
59E176	2017-08-10 04:17:00+03	46700.00
59E1A8	2017-07-05 21:37:00+03	31200.00
59E201	2017-07-23 11:14:00+03	108800.00
59E246	2017-08-04 08:19:00+03	46400.00
59E24F	2017-08-05 18:04:00+03	79600.00
59E25D	2017-07-08 04:34:00+03	23400.00
59E26B	2017-07-13 09:21:00+03	46500.00
59E2C1	2017-07-02 18:07:00+03	282000.00
59E33B	2017-07-24 13:33:00+03	40800.00
59E39A	2017-07-10 23:27:00+03	38600.00
59E3D3	2017-08-02 18:46:00+03	6800.00
59E447	2017-07-08 11:32:00+03	103500.00
59E487	2017-07-20 17:54:00+03	58600.00
59E4D9	2017-08-02 01:12:00+03	281800.00
59E4EA	2017-08-10 17:25:00+03	71800.00
59E500	2017-07-29 03:54:00+03	153300.00
59E508	2017-08-04 19:02:00+03	123800.00
59E552	2017-06-28 12:45:00+03	78500.00
59E56C	2017-06-29 11:01:00+03	64600.00
59E579	2017-07-16 01:13:00+03	61800.00
59E5EA	2017-08-01 23:33:00+03	13400.00
59E620	2017-07-13 22:47:00+03	80200.00
59E64D	2017-07-15 02:46:00+03	68100.00
59E658	2017-07-13 03:04:00+03	83700.00
59E66B	2017-07-27 17:25:00+03	116400.00
59E6DB	2017-07-23 01:57:00+03	61800.00
59E74D	2017-07-28 15:53:00+03	307900.00
59E759	2017-07-03 20:44:00+03	28000.00
59E77B	2017-07-07 02:54:00+03	114800.00
59E786	2017-08-02 08:00:00+03	11700.00
59E7D6	2017-07-07 23:12:00+03	20400.00
59E7E3	2017-08-14 07:31:00+03	24000.00
59E7F2	2017-07-17 08:23:00+03	168000.00
59E853	2017-08-06 13:08:00+03	59800.00
59E854	2017-07-06 06:49:00+03	20200.00
59E879	2017-08-08 23:24:00+03	106400.00
59E8A5	2017-07-11 19:49:00+03	23600.00
59E8B7	2017-07-17 01:26:00+03	63200.00
59E8C4	2017-07-19 22:59:00+03	6700.00
59E8C5	2017-08-12 10:04:00+03	24000.00
59E941	2017-08-15 02:36:00+03	56000.00
59E97A	2017-07-04 02:01:00+03	21200.00
59E9A5	2017-07-03 15:07:00+03	14400.00
59E9CC	2017-06-29 00:00:00+03	133200.00
59EA02	2017-07-24 04:58:00+03	46000.00
59EA2C	2017-07-10 21:01:00+03	67900.00
59EA36	2017-08-08 05:10:00+03	26800.00
59EAAD	2017-08-07 04:35:00+03	85000.00
59EAC1	2017-08-05 05:43:00+03	58600.00
59EAC2	2017-08-06 16:19:00+03	14800.00
59EB37	2017-07-24 17:16:00+03	133100.00
59EBB8	2017-07-21 11:11:00+03	6400.00
59EC84	2017-08-06 17:57:00+03	37200.00
59EC89	2017-07-22 21:22:00+03	123000.00
59ED47	2017-08-13 01:04:00+03	76600.00
59EDBB	2017-08-11 09:13:00+03	26000.00
59EDC4	2017-07-28 20:15:00+03	406700.00
59EE10	2017-08-15 09:22:00+03	56000.00
59EE7D	2017-07-08 23:45:00+03	16400.00
59EE8D	2017-07-02 16:12:00+03	59300.00
59EEB7	2017-08-10 13:33:00+03	22000.00
59EECC	2017-07-10 11:27:00+03	103500.00
59EF30	2017-07-28 18:06:00+03	28300.00
59EF52	2017-08-13 06:14:00+03	31600.00
59EF61	2017-07-06 17:15:00+03	24400.00
59EF76	2017-08-08 10:32:00+03	81700.00
59EF8C	2017-08-11 09:23:00+03	6700.00
59EF8E	2017-07-13 05:33:00+03	67600.00
59EFBC	2017-08-03 17:17:00+03	91000.00
59EFCF	2017-07-12 00:09:00+03	35200.00
59F012	2017-07-02 02:51:00+03	54400.00
59F0CD	2017-07-16 06:09:00+03	72700.00
59F100	2017-06-30 11:09:00+03	46900.00
59F113	2017-08-03 13:02:00+03	54800.00
59F196	2017-07-10 20:30:00+03	6000.00
59F1B4	2017-08-03 14:53:00+03	123000.00
59F1CC	2017-07-23 09:42:00+03	63200.00
59F1ED	2017-07-12 17:12:00+03	40800.00
59F1EF	2017-08-07 19:45:00+03	7400.00
59F2A8	2017-07-28 12:59:00+03	174600.00
59F2C1	2017-07-26 12:15:00+03	65100.00
59F32E	2017-07-25 06:09:00+03	56200.00
59F339	2017-07-01 03:06:00+03	112000.00
59F37E	2017-07-27 02:23:00+03	48800.00
59F3C7	2017-06-26 06:36:00+03	60400.00
59F3F4	2017-08-06 07:39:00+03	67600.00
59F41A	2017-08-13 23:18:00+03	26000.00
59F43B	2017-07-15 05:25:00+03	46400.00
59F469	2017-07-15 03:14:00+03	36800.00
59F498	2017-08-04 21:34:00+03	92800.00
59F49C	2017-07-17 14:34:00+03	243600.00
59F4C3	2017-07-20 20:41:00+03	44000.00
59F520	2017-07-30 02:23:00+03	91800.00
59F542	2017-08-14 08:00:00+03	135200.00
59F564	2017-07-29 09:04:00+03	40000.00
59F621	2017-07-15 01:47:00+03	19600.00
59F652	2017-07-12 05:00:00+03	92100.00
59F695	2017-07-07 00:48:00+03	10600.00
59F6BA	2017-07-20 18:16:00+03	25600.00
59F722	2017-07-06 03:35:00+03	56900.00
59F724	2017-07-18 23:46:00+03	14300.00
59F729	2017-07-14 02:42:00+03	23100.00
59F73A	2017-07-15 07:11:00+03	23200.00
59F742	2017-08-03 14:48:00+03	58000.00
59F783	2017-07-01 01:32:00+03	81600.00
59F786	2017-08-15 16:04:00+03	121800.00
59F789	2017-08-05 03:50:00+03	58900.00
59F7CC	2017-07-25 02:29:00+03	25800.00
59F828	2017-07-28 08:24:00+03	56200.00
59F847	2017-07-27 03:26:00+03	66600.00
59F862	2017-07-22 09:20:00+03	64700.00
59F867	2017-07-30 03:35:00+03	111600.00
59F882	2017-07-06 18:39:00+03	168000.00
59F93E	2017-07-06 06:06:00+03	58000.00
59F95C	2017-07-06 11:35:00+03	26200.00
59F95E	2017-07-25 23:01:00+03	27200.00
59F98E	2017-07-09 13:53:00+03	21800.00
59F9D8	2017-08-07 20:59:00+03	54500.00
59F9ED	2017-07-18 10:12:00+03	123000.00
59FA17	2017-07-30 15:17:00+03	24400.00
59FA64	2017-07-16 03:48:00+03	30400.00
59FA88	2017-07-09 08:11:00+03	45200.00
59FA8C	2017-07-17 10:42:00+03	19600.00
59FAEA	2017-08-07 12:46:00+03	50000.00
59FAF4	2017-08-14 10:11:00+03	66600.00
59FB0F	2017-07-08 04:33:00+03	130300.00
59FB50	2017-07-24 02:48:00+03	101200.00
59FB93	2017-08-10 04:54:00+03	70800.00
59FB94	2017-07-22 05:43:00+03	28000.00
59FBBE	2017-07-10 19:57:00+03	44800.00
59FC27	2017-07-18 19:13:00+03	170000.00
59FCC2	2017-07-20 09:49:00+03	84500.00
59FD38	2017-08-12 21:33:00+03	47000.00
59FD46	2017-07-19 14:58:00+03	49800.00
59FD61	2017-08-01 13:54:00+03	24500.00
59FD88	2017-08-15 13:44:00+03	72300.00
59FE21	2017-08-14 13:56:00+03	24700.00
59FE22	2017-07-21 22:33:00+03	29600.00
59FE39	2017-07-30 20:34:00+03	91200.00
59FE75	2017-07-13 10:55:00+03	131600.00
59FE91	2017-07-17 20:02:00+03	103400.00
59FEB1	2017-08-10 04:47:00+03	39800.00
59FEF3	2017-08-12 03:37:00+03	142400.00
59FF82	2017-07-20 07:22:00+03	84800.00
59FF97	2017-07-08 21:46:00+03	201800.00
59FFF3	2017-07-10 19:31:00+03	113000.00
5A00AD	2017-07-27 02:42:00+03	250600.00
5A014E	2017-07-14 20:07:00+03	56100.00
5A0197	2017-07-29 02:20:00+03	57800.00
5A019B	2017-06-29 01:18:00+03	46400.00
5A024C	2017-07-07 12:32:00+03	68800.00
5A028C	2017-08-05 08:58:00+03	42700.00
5A0297	2017-08-15 11:48:00+03	112000.00
5A02EB	2017-07-13 00:17:00+03	28000.00
5A0325	2017-07-14 03:46:00+03	67700.00
5A0344	2017-08-15 09:47:00+03	301800.00
5A0362	2017-07-25 10:38:00+03	56000.00
5A0369	2017-07-26 23:40:00+03	7200.00
5A0377	2017-08-14 08:29:00+03	16400.00
5A039A	2017-07-07 08:55:00+03	148500.00
5A03AA	2017-07-10 14:32:00+03	35400.00
5A03FB	2017-07-16 08:27:00+03	37000.00
5A0441	2017-07-21 15:20:00+03	37200.00
5A0467	2017-08-04 21:50:00+03	45200.00
5A04CE	2017-08-01 17:58:00+03	136600.00
5A04EB	2017-08-01 21:19:00+03	58000.00
5A04F9	2017-07-05 13:00:00+03	18300.00
5A0524	2017-07-06 10:02:00+03	39900.00
5A0541	2017-07-30 23:30:00+03	110500.00
5A0554	2017-07-02 02:44:00+03	73600.00
5A0564	2017-08-07 03:59:00+03	173400.00
5A0579	2017-07-30 01:26:00+03	12600.00
5A059E	2017-08-11 08:38:00+03	94700.00
5A0603	2017-07-12 07:03:00+03	48800.00
5A060B	2017-07-16 21:02:00+03	246000.00
5A0635	2017-07-27 04:03:00+03	48800.00
5A0655	2017-08-08 02:34:00+03	131100.00
5A066A	2017-07-06 09:14:00+03	100600.00
5A0674	2017-08-15 02:02:00+03	45100.00
5A06D6	2017-07-14 18:59:00+03	40000.00
5A0702	2017-08-07 17:20:00+03	26000.00
5A0749	2017-08-03 10:12:00+03	46400.00
5A0792	2017-08-04 18:36:00+03	304100.00
5A07C9	2017-08-13 05:44:00+03	246000.00
5A081F	2017-08-10 13:33:00+03	118700.00
5A0823	2017-08-03 02:52:00+03	67200.00
5A0850	2017-07-03 08:45:00+03	68900.00
5A08A4	2017-07-13 23:43:00+03	109600.00
5A08ED	2017-07-01 20:12:00+03	26700.00
5A0921	2017-07-08 09:03:00+03	210900.00
5A0955	2017-08-05 09:33:00+03	27200.00
5A0A28	2017-08-12 00:43:00+03	28000.00
5A0A4E	2017-06-30 01:38:00+03	52000.00
5A0A5D	2017-07-31 14:46:00+03	24400.00
5A0AFF	2017-08-13 13:48:00+03	12200.00
5A0B3A	2017-08-08 19:20:00+03	6300.00
5A0B47	2017-07-13 18:31:00+03	15000.00
5A0B4A	2017-07-14 15:35:00+03	35300.00
5A0B51	2017-08-09 05:18:00+03	45400.00
5A0B77	2017-07-29 23:52:00+03	29600.00
5A0B88	2017-08-15 01:35:00+03	52500.00
5A0B95	2017-06-29 03:26:00+03	89600.00
5A0BB6	2017-07-30 13:42:00+03	64700.00
5A0BC1	2017-07-20 22:37:00+03	6000.00
5A0C1F	2017-07-16 12:14:00+03	326400.00
5A0C8B	2017-07-18 16:52:00+03	69500.00
5A0CD5	2017-08-05 20:34:00+03	117600.00
5A0CD7	2017-07-28 04:50:00+03	25200.00
5A0CDE	2017-08-01 22:54:00+03	62300.00
5A0D23	2017-07-22 05:00:00+03	80800.00
5A0D30	2017-08-02 08:50:00+03	45200.00
5A0D3E	2017-07-04 19:00:00+03	186900.00
5A0D87	2017-07-20 03:03:00+03	44000.00
5A0DBE	2017-08-05 05:39:00+03	95200.00
5A0DC0	2017-07-07 16:35:00+03	265700.00
5A0DF7	2017-07-28 23:51:00+03	364600.00
5A0E4A	2017-08-02 18:37:00+03	52000.00
5A0E6F	2017-06-29 06:02:00+03	71200.00
5A0ECC	2017-08-07 13:12:00+03	65900.00
5A0F7A	2017-07-30 22:59:00+03	60400.00
5A0FD5	2017-07-06 14:36:00+03	66600.00
5A1028	2017-08-04 07:20:00+03	406100.00
5A10C6	2017-07-21 01:49:00+03	41600.00
5A1114	2017-08-02 16:26:00+03	63400.00
5A1116	2017-08-05 03:51:00+03	138900.00
5A111D	2017-07-13 22:38:00+03	6000.00
5A1148	2017-08-07 06:54:00+03	75300.00
5A11CA	2017-07-27 04:31:00+03	13800.00
5A123A	2017-07-09 06:23:00+03	6600.00
5A123C	2017-08-03 19:37:00+03	15000.00
5A127C	2017-07-07 20:27:00+03	47400.00
5A12E9	2017-07-17 05:21:00+03	181200.00
5A12F5	2017-07-21 16:46:00+03	151200.00
5A1371	2017-08-11 18:31:00+03	246100.00
5A1475	2017-07-31 17:41:00+03	26000.00
5A14D0	2017-07-09 00:31:00+03	135600.00
5A1504	2017-08-11 21:21:00+03	91500.00
5A1517	2017-07-18 10:25:00+03	87100.00
5A1527	2017-07-21 04:10:00+03	56600.00
5A1569	2017-07-03 22:05:00+03	25800.00
5A1575	2017-07-24 07:57:00+03	16400.00
5A158E	2017-07-24 19:53:00+03	187800.00
5A1604	2017-07-11 03:15:00+03	23600.00
5A1657	2017-07-03 23:15:00+03	54600.00
5A16BF	2017-07-07 08:43:00+03	119600.00
5A1722	2017-08-10 15:10:00+03	56100.00
5A17B6	2017-07-05 22:43:00+03	199300.00
5A17C0	2017-08-10 22:46:00+03	173500.00
5A17C6	2017-08-01 15:15:00+03	271100.00
5A17D9	2017-07-10 17:25:00+03	214900.00
5A1848	2017-08-02 17:58:00+03	25200.00
5A186D	2017-08-04 05:32:00+03	40800.00
5A1879	2017-07-03 19:54:00+03	37000.00
5A1912	2017-08-05 03:22:00+03	12000.00
5A1940	2017-07-02 07:15:00+03	101500.00
5A19D2	2017-07-17 12:30:00+03	27300.00
5A19F8	2017-07-22 07:44:00+03	113200.00
5A1A57	2017-08-06 23:28:00+03	117600.00
5A1A89	2017-07-22 11:20:00+03	235700.00
5A1AC5	2017-07-18 21:50:00+03	32700.00
5A1B17	2017-07-09 00:04:00+03	257600.00
5A1B74	2017-07-27 22:23:00+03	46300.00
5A1B79	2017-07-06 12:39:00+03	23200.00
5A1BC2	2017-07-14 22:05:00+03	55800.00
5A1BD0	2017-07-11 07:52:00+03	189700.00
5A1C17	2017-07-09 18:12:00+03	79600.00
5A1C45	2017-07-18 02:26:00+03	26000.00
5A1C52	2017-07-16 09:00:00+03	17000.00
5A1CB6	2017-07-03 15:27:00+03	27200.00
5A1CC3	2017-08-03 08:09:00+03	46000.00
5A1CE9	2017-07-25 10:58:00+03	29600.00
5A1CEE	2017-08-06 20:37:00+03	32700.00
5A1D51	2017-08-11 00:05:00+03	52000.00
5A1D65	2017-08-10 11:26:00+03	101600.00
5A1D98	2017-07-12 20:57:00+03	75300.00
5A1DCD	2017-07-09 09:16:00+03	77900.00
5A1E3A	2017-07-27 18:33:00+03	21400.00
5A1E8F	2017-08-10 01:11:00+03	14000.00
5A1ED3	2017-07-19 11:24:00+03	22000.00
5A1EF2	2017-07-17 15:33:00+03	45100.00
5A1F1C	2017-07-03 21:19:00+03	12000.00
5A1FC0	2017-07-16 09:31:00+03	58200.00
5A1FFF	2017-07-21 10:35:00+03	117800.00
5A2006	2017-08-15 10:39:00+03	31200.00
5A2078	2017-07-16 07:47:00+03	34800.00
5A2086	2017-07-07 01:33:00+03	40800.00
5A20D4	2017-06-29 23:29:00+03	21800.00
5A2125	2017-08-02 12:41:00+03	439200.00
5A2158	2017-08-08 09:16:00+03	64800.00
5A221D	2017-07-18 20:51:00+03	37700.00
5A22BD	2017-07-05 10:28:00+03	27400.00
5A2322	2017-08-13 08:09:00+03	58400.00
5A232C	2017-08-04 22:26:00+03	54500.00
5A237A	2017-08-12 14:31:00+03	182800.00
5A2387	2017-08-14 03:48:00+03	129700.00
5A238B	2017-08-07 03:16:00+03	94200.00
5A239B	2017-07-14 13:16:00+03	25600.00
5A23AD	2017-07-26 03:47:00+03	67600.00
5A23C2	2017-07-27 09:16:00+03	31400.00
5A2461	2017-08-11 12:47:00+03	30200.00
5A2636	2017-08-02 08:53:00+03	58000.00
5A263C	2017-08-11 09:50:00+03	186900.00
5A2691	2017-07-18 03:51:00+03	28000.00
5A2692	2017-07-26 14:00:00+03	99200.00
5A26A1	2017-08-03 08:18:00+03	85700.00
5A26D9	2017-07-11 16:34:00+03	16400.00
5A26EB	2017-07-26 10:46:00+03	28000.00
5A26EF	2017-07-16 09:16:00+03	44000.00
5A2768	2017-07-13 02:08:00+03	30000.00
5A27A5	2017-08-14 13:24:00+03	33200.00
5A27C6	2017-08-09 18:51:00+03	8000.00
5A2809	2017-08-10 20:59:00+03	19600.00
5A280E	2017-07-06 13:58:00+03	75300.00
5A291C	2017-08-10 08:36:00+03	132800.00
5A2933	2017-07-04 02:44:00+03	138600.00
5A29BF	2017-07-31 05:27:00+03	36200.00
5A2A02	2017-07-21 06:45:00+03	12600.00
5A2A43	2017-07-04 11:44:00+03	62100.00
5A2A4B	2017-07-10 01:09:00+03	16400.00
5A2A60	2017-07-23 01:47:00+03	23600.00
5A2AD2	2017-07-02 03:44:00+03	32800.00
5A2B01	2017-07-18 16:24:00+03	38800.00
5A2B10	2017-07-21 21:28:00+03	25400.00
5A2B22	2017-07-22 19:51:00+03	133100.00
5A2BDA	2017-07-14 08:56:00+03	35300.00
5A2C91	2017-07-03 16:23:00+03	31600.00
5A2CB0	2017-07-24 16:17:00+03	50600.00
5A2CF6	2017-07-10 03:47:00+03	100600.00
5A2D04	2017-07-04 07:35:00+03	47800.00
5A2D29	2017-08-15 12:21:00+03	11600.00
5A2D39	2017-08-07 13:16:00+03	13800.00
5A2D56	2017-07-08 03:30:00+03	124200.00
5A2D69	2017-07-09 08:36:00+03	132800.00
5A2D76	2017-07-14 15:13:00+03	124200.00
5A2DAC	2017-08-03 12:20:00+03	70100.00
5A2DFB	2017-07-10 03:52:00+03	6000.00
5A2E67	2017-08-11 16:25:00+03	72200.00
5A2E88	2017-08-11 03:05:00+03	145000.00
5A2F49	2017-07-05 20:02:00+03	52100.00
5A2F77	2017-08-02 17:35:00+03	19600.00
5A2F81	2017-07-06 18:10:00+03	46500.00
5A2F86	2017-07-16 02:47:00+03	89800.00
5A2F92	2017-08-03 19:45:00+03	40000.00
5A3036	2017-07-07 14:25:00+03	136600.00
5A305C	2017-08-01 20:19:00+03	298600.00
5A305D	2017-07-09 02:10:00+03	70100.00
5A305E	2017-07-22 22:52:00+03	79200.00
5A3071	2017-08-13 10:53:00+03	176900.00
5A3084	2017-07-11 08:04:00+03	33300.00
5A308C	2017-08-08 17:36:00+03	75000.00
5A30C3	2017-07-16 16:27:00+03	34400.00
5A30D0	2017-07-06 16:30:00+03	101200.00
5A312B	2017-07-17 05:03:00+03	25600.00
5A3179	2017-08-14 11:57:00+03	95700.00
5A319F	2017-07-03 03:42:00+03	32700.00
5A31A2	2017-08-01 12:15:00+03	147700.00
5A31FD	2017-07-19 00:26:00+03	47100.00
5A3261	2017-07-28 03:46:00+03	114900.00
5A3271	2017-07-13 08:43:00+03	63200.00
5A330F	2017-08-02 17:27:00+03	154500.00
5A33C5	2017-07-08 01:05:00+03	58900.00
5A33DD	2017-08-13 20:50:00+03	278500.00
5A3436	2017-08-08 14:03:00+03	146600.00
5A3455	2017-07-19 15:52:00+03	43200.00
5A345E	2017-07-19 02:27:00+03	133200.00
5A346A	2017-06-30 19:12:00+03	125400.00
5A34B7	2017-06-30 17:06:00+03	32200.00
5A34C7	2017-07-18 11:58:00+03	28000.00
5A34FB	2017-06-25 02:24:00+03	59300.00
5A351A	2017-07-29 08:58:00+03	48500.00
5A3595	2017-07-25 21:07:00+03	47600.00
5A3598	2017-08-07 17:29:00+03	48400.00
5A35C9	2017-08-02 08:18:00+03	31600.00
5A35F1	2017-07-13 11:30:00+03	258400.00
5A368D	2017-07-31 16:40:00+03	238900.00
5A36A0	2017-07-31 07:24:00+03	46000.00
5A36DC	2017-08-02 01:11:00+03	6300.00
5A3707	2017-07-25 22:52:00+03	6000.00
5A370B	2017-07-09 11:28:00+03	23600.00
5A373C	2017-07-03 04:52:00+03	13800.00
5A37EA	2017-08-15 01:15:00+03	113300.00
5A380F	2017-06-27 08:15:00+03	55800.00
5A38B5	2017-08-03 16:22:00+03	59000.00
5A38C9	2017-07-26 09:29:00+03	14900.00
5A38E7	2017-07-28 14:37:00+03	34000.00
5A3948	2017-08-15 16:53:00+03	56000.00
5A397D	2017-07-20 18:49:00+03	369000.00
5A39C8	2017-08-06 12:40:00+03	28000.00
5A39D1	2017-08-05 01:47:00+03	24400.00
5A3A1A	2017-07-30 13:40:00+03	70700.00
5A3A49	2017-07-13 17:34:00+03	40800.00
5A3A66	2017-08-08 19:17:00+03	131100.00
5A3A88	2017-07-24 14:07:00+03	94100.00
5A3AF9	2017-07-17 23:27:00+03	246000.00
5A3B7F	2017-08-12 10:04:00+03	39400.00
5A3BA2	2017-07-08 16:18:00+03	193200.00
5A3BA5	2017-08-08 00:53:00+03	133700.00
5A3BD0	2017-08-12 07:54:00+03	28000.00
5A3BFA	2017-08-08 00:36:00+03	58600.00
5A3C83	2017-07-22 06:45:00+03	96200.00
5A3CE5	2017-07-04 05:03:00+03	184300.00
5A3E23	2017-07-15 16:41:00+03	50000.00
5A3E43	2017-07-17 12:09:00+03	9800.00
5A3E56	2017-08-10 18:09:00+03	316000.00
5A3E6E	2017-08-08 22:36:00+03	24600.00
5A3F42	2017-07-27 11:35:00+03	55800.00
5A3F6C	2017-07-12 22:50:00+03	35700.00
5A4061	2017-08-03 08:02:00+03	62600.00
5A40F5	2017-07-20 21:00:00+03	34400.00
5A4111	2017-07-27 05:24:00+03	184400.00
5A416E	2017-07-17 16:26:00+03	28000.00
5A41BE	2017-07-19 13:28:00+03	11000.00
5A41E3	2017-06-30 08:50:00+03	36200.00
5A41E4	2017-08-04 09:30:00+03	189200.00
5A4252	2017-07-06 13:57:00+03	195600.00
5A427F	2017-08-07 00:34:00+03	57000.00
5A4286	2017-07-05 21:37:00+03	92800.00
5A42E5	2017-07-21 16:09:00+03	18800.00
5A437B	2017-06-25 13:07:00+03	295400.00
5A437E	2017-08-08 10:27:00+03	85000.00
5A4449	2017-07-26 21:21:00+03	92900.00
5A4458	2017-07-26 12:37:00+03	128000.00
5A4484	2017-07-25 14:40:00+03	92000.00
5A44D1	2017-08-03 13:46:00+03	246000.00
5A44D3	2017-07-20 18:36:00+03	42800.00
5A451D	2017-07-04 23:45:00+03	47200.00
5A4565	2017-07-18 22:28:00+03	34000.00
5A457B	2017-07-05 01:40:00+03	24700.00
5A4675	2017-07-10 21:22:00+03	223200.00
5A46F2	2017-07-10 23:13:00+03	8200.00
5A471F	2017-07-12 06:40:00+03	85000.00
5A476D	2017-07-07 17:17:00+03	38800.00
5A4783	2017-07-26 08:15:00+03	46400.00
5A48F7	2017-07-06 19:33:00+03	12600.00
5A491D	2017-08-07 01:05:00+03	26300.00
5A4924	2017-07-09 22:54:00+03	115600.00
5A495E	2017-07-23 12:28:00+03	28000.00
5A4990	2017-08-04 23:15:00+03	75300.00
5A49B0	2017-07-01 22:27:00+03	132800.00
5A49D3	2017-08-05 23:48:00+03	52700.00
5A49D4	2017-08-02 00:52:00+03	32400.00
5A49FC	2017-07-11 00:15:00+03	10700.00
5A4A23	2017-08-02 05:37:00+03	58200.00
5A4A47	2017-08-13 03:10:00+03	46200.00
5A4A99	2017-08-10 04:37:00+03	84100.00
5A4ACA	2017-07-13 06:27:00+03	95600.00
5A4B4B	2017-07-16 18:44:00+03	27600.00
5A4B83	2017-06-28 21:45:00+03	46300.00
5A4B98	2017-07-27 03:22:00+03	123000.00
5A4BA2	2017-07-10 20:33:00+03	108600.00
5A4BE5	2017-07-14 06:26:00+03	75300.00
5A4C02	2017-07-11 05:18:00+03	257600.00
5A4C18	2017-07-17 11:20:00+03	52100.00
5A4CAE	2017-07-30 22:26:00+03	28000.00
5A4CBD	2017-07-22 10:37:00+03	40400.00
5A4D2C	2017-08-02 15:31:00+03	31600.00
5A4D3E	2017-07-06 06:14:00+03	23600.00
5A4DAD	2017-08-12 10:33:00+03	117200.00
5A4DB3	2017-08-08 01:46:00+03	70600.00
5A4DD0	2017-08-04 10:24:00+03	72400.00
5A4E03	2017-07-01 02:10:00+03	122600.00
5A4E12	2017-08-05 13:19:00+03	31900.00
5A4EDC	2017-07-05 14:26:00+03	66600.00
5A4F43	2017-07-01 09:33:00+03	35200.00
5A4F55	2017-07-25 23:44:00+03	40700.00
5A4F84	2017-07-16 03:25:00+03	43500.00
5A4FBD	2017-07-10 12:13:00+03	406200.00
5A4FF2	2017-08-10 09:01:00+03	19300.00
5A4FF6	2017-06-26 06:06:00+03	26700.00
5A500B	2017-08-10 10:34:00+03	8200.00
5A5011	2017-08-14 18:01:00+03	23200.00
5A50AA	2017-07-14 03:01:00+03	172600.00
5A50CF	2017-07-17 20:19:00+03	67900.00
5A511A	2017-07-03 07:28:00+03	13600.00
5A513A	2017-07-05 09:40:00+03	29600.00
5A5197	2017-07-08 23:03:00+03	108500.00
5A51C2	2017-07-13 06:32:00+03	34000.00
5A51D2	2017-07-22 20:18:00+03	43200.00
5A52C1	2017-07-26 02:31:00+03	42700.00
5A52EC	2017-07-20 01:59:00+03	122300.00
5A52FD	2017-07-11 20:36:00+03	176400.00
5A5318	2017-08-09 17:54:00+03	30200.00
5A535E	2017-08-05 06:51:00+03	139600.00
5A5374	2017-07-14 17:39:00+03	51300.00
5A53A8	2017-07-19 15:42:00+03	24400.00
5A53BB	2017-07-02 04:51:00+03	132800.00
5A53D7	2017-07-03 16:18:00+03	27800.00
5A53DF	2017-07-15 19:22:00+03	97100.00
5A53FA	2017-07-02 12:01:00+03	121400.00
5A5474	2017-08-03 14:05:00+03	30200.00
5A54A2	2017-08-12 04:05:00+03	56000.00
5A551C	2017-08-12 13:08:00+03	87000.00
5A5534	2017-07-07 12:56:00+03	41800.00
5A55A4	2017-07-05 20:48:00+03	57500.00
5A55AC	2017-08-13 13:06:00+03	66600.00
5A55FE	2017-07-06 15:02:00+03	56000.00
5A561D	2017-07-07 20:21:00+03	369000.00
5A562F	2017-07-20 04:09:00+03	56600.00
5A56A0	2017-08-07 05:37:00+03	93900.00
5A5748	2017-07-09 04:26:00+03	113300.00
5A5794	2017-06-30 22:30:00+03	9300.00
5A5826	2017-08-11 09:02:00+03	15000.00
5A5833	2017-07-09 19:50:00+03	40200.00
5A5837	2017-07-10 11:47:00+03	266400.00
5A5861	2017-07-16 13:09:00+03	68400.00
5A58AF	2017-07-08 08:27:00+03	20500.00
5A5931	2017-08-05 01:00:00+03	30200.00
5A5946	2017-08-08 21:19:00+03	73600.00
5A5956	2017-08-05 21:38:00+03	57500.00
5A5985	2017-07-11 01:23:00+03	171400.00
5A59C2	2017-08-03 09:32:00+03	152400.00
5A5A34	2017-07-17 22:04:00+03	246100.00
5A5A5C	2017-07-20 22:28:00+03	56000.00
5A5A8D	2017-07-02 22:25:00+03	56600.00
5A5AD1	2017-08-10 00:35:00+03	57800.00
5A5B25	2017-07-13 17:09:00+03	79900.00
5A5BA1	2017-07-21 10:04:00+03	107200.00
5A5C07	2017-07-18 13:47:00+03	26000.00
5A5C1B	2017-08-03 20:22:00+03	102200.00
5A5C52	2017-08-14 11:02:00+03	515000.00
5A5CB8	2017-08-06 02:33:00+03	117900.00
5A5CE2	2017-07-19 15:19:00+03	192400.00
5A5D45	2017-07-14 11:34:00+03	48800.00
5A5DB5	2017-07-08 09:14:00+03	51800.00
5A5EC6	2017-08-08 20:29:00+03	136800.00
5A5EF0	2017-08-12 05:33:00+03	229600.00
5A5F23	2017-07-08 04:05:00+03	248400.00
5A5F26	2017-07-08 04:40:00+03	55800.00
5A5F32	2017-07-26 19:44:00+03	91300.00
5A5F88	2017-08-07 09:10:00+03	58600.00
5A5FA3	2017-08-03 02:55:00+03	21800.00
5A5FE3	2017-08-04 02:25:00+03	127100.00
5A604B	2017-08-08 06:09:00+03	83000.00
5A6093	2017-08-01 15:28:00+03	54800.00
5A6094	2017-08-02 22:29:00+03	8200.00
5A60CE	2017-07-26 21:27:00+03	79900.00
5A6116	2017-07-21 04:31:00+03	15000.00
5A617A	2017-08-13 01:44:00+03	84000.00
5A61CB	2017-07-10 09:05:00+03	28000.00
5A620C	2017-07-21 07:21:00+03	56100.00
5A6299	2017-08-15 07:03:00+03	102400.00
5A62D2	2017-08-06 20:59:00+03	73600.00
5A63AF	2017-08-14 05:06:00+03	134200.00
5A6443	2017-07-04 13:25:00+03	26200.00
5A645A	2017-08-14 09:42:00+03	257500.00
5A6491	2017-07-13 22:01:00+03	123000.00
5A6496	2017-08-03 18:54:00+03	27200.00
5A6565	2017-07-26 03:41:00+03	78600.00
5A657C	2017-07-08 15:41:00+03	28200.00
5A659E	2017-08-07 21:46:00+03	23200.00
5A65EC	2017-07-13 21:29:00+03	23400.00
5A660C	2017-08-03 05:28:00+03	38500.00
5A661C	2017-07-06 08:06:00+03	57400.00
5A66F6	2017-08-03 16:53:00+03	56000.00
5A6730	2017-08-10 14:43:00+03	135000.00
5A676B	2017-07-16 14:34:00+03	243900.00
5A6885	2017-07-01 16:39:00+03	31200.00
5A68B3	2017-08-11 00:00:00+03	52800.00
5A68D3	2017-07-24 16:23:00+03	23200.00
5A68DF	2017-07-25 16:21:00+03	246000.00
5A6948	2017-08-12 15:36:00+03	166500.00
5A6969	2017-07-03 18:41:00+03	32900.00
5A6976	2017-08-05 17:43:00+03	48800.00
5A6988	2017-07-25 22:52:00+03	22000.00
5A698F	2017-08-03 15:18:00+03	6000.00
5A6A16	2017-08-05 18:09:00+03	18000.00
5A6A64	2017-07-23 15:00:00+03	67100.00
5A6A76	2017-07-21 17:45:00+03	12600.00
5A6B20	2017-06-29 14:03:00+03	92800.00
5A6B6D	2017-08-04 04:38:00+03	25400.00
5A6BA3	2017-07-08 17:44:00+03	167400.00
5A6BEF	2017-06-28 07:23:00+03	14800.00
5A6C66	2017-07-21 13:00:00+03	26200.00
5A6CC8	2017-07-18 22:46:00+03	85000.00
5A6CDC	2017-07-07 22:07:00+03	25600.00
5A6E20	2017-08-06 03:20:00+03	40800.00
5A6E2A	2017-07-20 13:22:00+03	245900.00
5A6E7F	2017-08-11 15:54:00+03	6600.00
5A6EC6	2017-08-08 06:39:00+03	6000.00
5A6F23	2017-08-11 20:42:00+03	125400.00
5A6F31	2017-07-16 11:12:00+03	114300.00
5A6F53	2017-08-03 00:34:00+03	6000.00
5A6F85	2017-07-02 21:17:00+03	8200.00
5A6FD6	2017-08-08 18:33:00+03	19600.00
5A706A	2017-08-13 11:27:00+03	86300.00
5A70B5	2017-08-12 11:19:00+03	42000.00
5A70B9	2017-08-08 06:50:00+03	36200.00
5A70C7	2017-07-06 10:17:00+03	14000.00
5A7123	2017-06-30 07:25:00+03	46800.00
5A71A3	2017-07-10 12:01:00+03	44800.00
5A7217	2017-06-30 16:32:00+03	42700.00
5A721E	2017-08-07 06:29:00+03	102100.00
5A7234	2017-08-03 06:21:00+03	61800.00
5A7259	2017-07-22 23:52:00+03	120900.00
5A726D	2017-08-14 16:18:00+03	13400.00
5A7271	2017-07-24 12:29:00+03	80000.00
5A7282	2017-08-13 01:27:00+03	56000.00
5A7287	2017-07-07 15:05:00+03	46000.00
5A72DE	2017-06-25 20:19:00+03	103200.00
5A7301	2017-07-23 11:40:00+03	140200.00
5A7312	2017-07-01 01:52:00+03	31100.00
5A732C	2017-07-22 05:53:00+03	391000.00
5A7345	2017-07-09 00:03:00+03	136600.00
5A735F	2017-07-07 09:56:00+03	12400.00
5A73C6	2017-07-13 07:22:00+03	27000.00
5A743B	2017-08-02 22:14:00+03	14800.00
5A7451	2017-07-28 20:03:00+03	246000.00
5A7459	2017-08-05 21:30:00+03	43800.00
5A74F7	2017-07-24 07:57:00+03	38000.00
5A7503	2017-07-27 13:02:00+03	132800.00
5A751F	2017-07-20 09:44:00+03	143200.00
5A757B	2017-07-26 03:41:00+03	33100.00
5A75A2	2017-07-31 18:52:00+03	90100.00
5A75EF	2017-08-02 17:17:00+03	406600.00
5A75F8	2017-07-08 02:14:00+03	86800.00
5A7605	2017-07-15 20:55:00+03	46400.00
5A774C	2017-07-06 18:55:00+03	31600.00
5A77A7	2017-08-15 08:53:00+03	32500.00
5A7801	2017-07-09 09:20:00+03	266400.00
5A78A9	2017-07-05 07:11:00+03	136000.00
5A78AF	2017-06-26 11:43:00+03	21800.00
5A7918	2017-08-14 20:54:00+03	139300.00
5A794A	2017-08-08 15:00:00+03	316000.00
5A79B9	2017-07-22 01:52:00+03	457800.00
5A79CD	2017-08-04 15:27:00+03	111600.00
5A7A03	2017-08-11 11:00:00+03	36000.00
5A7A28	2017-07-22 05:53:00+03	46500.00
5A7A52	2017-08-11 11:48:00+03	28000.00
5A7A86	2017-07-26 14:26:00+03	110500.00
5A7A90	2017-07-16 15:30:00+03	37900.00
5A7AE8	2017-07-11 10:12:00+03	394900.00
5A7AEC	2017-08-08 22:41:00+03	144000.00
5A7AFE	2017-07-02 22:36:00+03	119400.00
5A7B0F	2017-07-28 20:59:00+03	53100.00
5A7B25	2017-06-29 14:11:00+03	78800.00
5A7B5E	2017-07-31 10:34:00+03	56000.00
5A7B8E	2017-07-30 07:00:00+03	399600.00
5A7BC7	2017-07-08 11:39:00+03	205200.00
5A7C1B	2017-07-19 08:19:00+03	375400.00
5A7C26	2017-07-27 20:32:00+03	36200.00
5A7D2C	2017-07-16 16:30:00+03	23600.00
5A7D56	2017-07-20 07:23:00+03	75800.00
5A7D71	2017-07-27 16:37:00+03	46300.00
5A7E26	2017-07-02 01:04:00+03	135400.00
5A7E39	2017-07-13 12:53:00+03	76100.00
5A7E76	2017-07-16 01:31:00+03	111600.00
5A7EA5	2017-07-11 07:51:00+03	22100.00
5A7EE2	2017-08-02 08:38:00+03	25400.00
5A7EE3	2017-07-07 11:03:00+03	48800.00
5A7EFE	2017-07-12 06:03:00+03	20800.00
5A7F2F	2017-08-10 21:01:00+03	53200.00
5A7F36	2017-07-05 23:26:00+03	73500.00
5A7F5F	2017-08-05 23:44:00+03	97800.00
5A7F66	2017-08-10 17:04:00+03	289800.00
5A80A2	2017-07-11 03:02:00+03	28800.00
5A812D	2017-08-12 04:30:00+03	61800.00
5A8132	2017-07-14 03:49:00+03	191000.00
5A814D	2017-07-27 13:24:00+03	46400.00
5A81A8	2017-08-03 16:03:00+03	22400.00
5A81F1	2017-07-27 17:47:00+03	215400.00
5A821C	2017-07-03 21:48:00+03	13400.00
5A8256	2017-08-04 04:09:00+03	9300.00
5A8288	2017-07-29 01:19:00+03	25000.00
5A82E0	2017-07-20 02:52:00+03	51900.00
5A8326	2017-07-24 09:26:00+03	14400.00
5A834C	2017-08-09 23:29:00+03	23600.00
5A8356	2017-07-25 05:03:00+03	60900.00
5A83D2	2017-08-13 14:58:00+03	55700.00
5A83EF	2017-08-10 03:24:00+03	62100.00
5A8477	2017-07-20 01:50:00+03	124200.00
5A8535	2017-07-02 08:00:00+03	6300.00
5A853C	2017-08-12 18:19:00+03	282100.00
5A8563	2017-07-19 01:41:00+03	27200.00
5A8588	2017-07-20 02:24:00+03	89700.00
5A85DD	2017-07-30 07:16:00+03	83700.00
5A85EE	2017-07-15 09:19:00+03	57600.00
5A8621	2017-08-07 05:38:00+03	175200.00
5A8740	2017-07-04 01:22:00+03	100900.00
5A876E	2017-08-10 17:02:00+03	75600.00
5A8776	2017-07-08 16:13:00+03	181100.00
5A878A	2017-08-06 04:56:00+03	134400.00
5A8876	2017-08-11 14:42:00+03	47400.00
5A88D0	2017-07-12 06:11:00+03	40800.00
5A88E7	2017-07-08 13:04:00+03	78400.00
5A88F9	2017-07-15 23:33:00+03	92900.00
5A898E	2017-07-07 03:38:00+03	71600.00
5A89D8	2017-07-27 22:39:00+03	186900.00
5A8A41	2017-07-03 17:57:00+03	183100.00
5A8AB3	2017-07-15 22:36:00+03	71000.00
5A8ACF	2017-06-25 08:38:00+03	26500.00
5A8B02	2017-07-02 22:50:00+03	46300.00
5A8B28	2017-07-02 20:47:00+03	30200.00
5A8B75	2017-07-31 12:59:00+03	174200.00
5A8BAE	2017-07-29 00:17:00+03	10700.00
5A8BC6	2017-07-26 00:40:00+03	87100.00
5A8BDE	2017-08-04 05:18:00+03	66000.00
5A8BEB	2017-07-07 16:28:00+03	76800.00
5A8C04	2017-08-06 06:49:00+03	6000.00
5A8C52	2017-07-31 03:15:00+03	46000.00
5A8C8E	2017-08-15 04:56:00+03	12600.00
5A8CBC	2017-08-04 10:43:00+03	10600.00
5A8CC9	2017-08-12 01:37:00+03	56600.00
5A8D1F	2017-07-04 20:50:00+03	44000.00
5A8D30	2017-06-30 17:30:00+03	23400.00
5A8D98	2017-08-01 21:49:00+03	26700.00
5A8D9E	2017-07-07 13:03:00+03	8200.00
5A8EA4	2017-08-10 09:14:00+03	37200.00
5A8EB3	2017-07-17 08:39:00+03	46400.00
5A8EC7	2017-08-01 14:19:00+03	81200.00
5A8EFE	2017-07-07 13:16:00+03	84100.00
5A8F1F	2017-07-25 16:31:00+03	48800.00
5A8F23	2017-07-10 15:46:00+03	98300.00
5A8FD6	2017-07-19 00:31:00+03	86600.00
5A9024	2017-08-10 10:58:00+03	76600.00
5A9029	2017-08-11 22:37:00+03	131400.00
5A9057	2017-08-03 23:32:00+03	103500.00
5A908A	2017-07-20 09:40:00+03	26000.00
5A90C5	2017-07-13 23:29:00+03	52400.00
5A9105	2017-08-04 20:50:00+03	206400.00
5A9120	2017-07-24 07:08:00+03	59600.00
5A9124	2017-07-30 09:49:00+03	28800.00
5A9130	2017-08-04 02:38:00+03	136600.00
5A915A	2017-07-01 21:07:00+03	20600.00
5A9187	2017-08-11 11:13:00+03	31400.00
5A91A1	2017-07-27 03:36:00+03	49100.00
5A9232	2017-07-27 17:44:00+03	56600.00
5A931C	2017-07-07 15:28:00+03	56000.00
5A932D	2017-07-23 00:57:00+03	49400.00
5A9338	2017-07-11 00:34:00+03	89700.00
5A9349	2017-07-31 10:44:00+03	186900.00
5A93F2	2017-07-18 13:50:00+03	6000.00
5A946F	2017-08-01 12:53:00+03	55400.00
5A94B3	2017-07-03 22:50:00+03	75200.00
5A957C	2017-08-12 08:37:00+03	42700.00
5A9589	2017-08-13 16:34:00+03	68800.00
5A95B7	2017-08-04 13:22:00+03	6800.00
5A95B9	2017-07-17 19:14:00+03	32800.00
5A9624	2017-07-07 21:27:00+03	149400.00
5A9669	2017-07-04 07:01:00+03	70600.00
5A967B	2017-08-14 11:19:00+03	6000.00
5A96CD	2017-08-13 01:21:00+03	28000.00
5A96DB	2017-07-14 09:17:00+03	47400.00
5A9782	2017-07-21 18:55:00+03	14000.00
5A97EB	2017-07-01 04:36:00+03	38400.00
5A9812	2017-07-16 07:00:00+03	12600.00
5A9814	2017-08-13 21:47:00+03	202800.00
5A9816	2017-07-08 09:23:00+03	13200.00
5A985C	2017-07-09 19:29:00+03	22000.00
5A98ED	2017-07-01 02:03:00+03	246400.00
5A9917	2017-08-12 00:45:00+03	61800.00
5A996E	2017-07-17 02:32:00+03	521800.00
5A9987	2017-07-05 04:48:00+03	47400.00
5A99A2	2017-08-12 12:15:00+03	232800.00
5A99B7	2017-07-19 04:42:00+03	56600.00
5A99FB	2017-08-06 15:36:00+03	169700.00
5A9A38	2017-08-07 05:38:00+03	53000.00
5A9A42	2017-08-15 02:54:00+03	31600.00
5A9A66	2017-07-12 05:36:00+03	38600.00
5A9AA0	2017-07-21 09:16:00+03	95300.00
5A9B02	2017-07-24 13:07:00+03	43600.00
5A9B19	2017-07-21 00:06:00+03	55600.00
5A9B50	2017-06-29 14:46:00+03	59800.00
5A9B5D	2017-08-03 23:49:00+03	177600.00
5A9B8D	2017-08-03 09:53:00+03	49100.00
5A9BC4	2017-07-17 07:28:00+03	13400.00
5A9BEB	2017-08-01 14:16:00+03	21400.00
5A9C0D	2017-08-15 11:41:00+03	13000.00
5A9C36	2017-07-17 05:31:00+03	79900.00
5A9CC8	2017-07-11 02:20:00+03	44000.00
5A9CCF	2017-08-09 19:03:00+03	15400.00
5A9D02	2017-07-23 02:58:00+03	73100.00
5A9D1A	2017-07-04 04:54:00+03	97900.00
5A9D1E	2017-08-09 16:25:00+03	289800.00
5A9D51	2017-07-24 05:43:00+03	69500.00
5A9D63	2017-07-31 00:27:00+03	229900.00
5A9D6C	2017-07-27 07:14:00+03	123000.00
5A9E0D	2017-07-07 12:40:00+03	125400.00
5A9E3E	2017-06-28 18:14:00+03	42700.00
5A9E81	2017-08-10 22:58:00+03	23600.00
5A9EB0	2017-07-03 05:02:00+03	224000.00
5A9EC9	2017-08-09 06:27:00+03	136600.00
5A9EDA	2017-07-14 14:45:00+03	128800.00
5A9EDC	2017-07-06 11:14:00+03	29300.00
5A9EE1	2017-08-02 23:12:00+03	20000.00
5A9F4B	2017-08-03 15:09:00+03	183300.00
5A9F67	2017-08-06 02:24:00+03	167200.00
5A9F86	2017-07-25 05:01:00+03	56900.00
5A9F93	2017-08-09 12:50:00+03	86300.00
5A9FA9	2017-07-05 08:46:00+03	40000.00
5A9FB6	2017-07-19 19:45:00+03	49600.00
5A9FE5	2017-08-06 17:41:00+03	134900.00
5A9FEE	2017-07-15 16:49:00+03	223200.00
5AA051	2017-06-30 18:45:00+03	178800.00
5AA07E	2017-07-21 00:25:00+03	64300.00
5AA085	2017-08-12 14:50:00+03	10700.00
5AA0C1	2017-07-12 04:19:00+03	76800.00
5AA1B0	2017-08-02 07:03:00+03	40000.00
5AA1C5	2017-07-24 21:04:00+03	29600.00
5AA1DB	2017-07-15 09:48:00+03	349200.00
5AA1DD	2017-08-06 01:30:00+03	6000.00
5AA1EC	2017-08-14 06:50:00+03	37900.00
5AA1F3	2017-06-30 13:28:00+03	69500.00
5AA21F	2017-08-14 11:36:00+03	28800.00
5AA228	2017-07-28 14:55:00+03	14800.00
5AA290	2017-07-05 08:51:00+03	36200.00
5AA298	2017-08-15 04:37:00+03	131100.00
5AA2F6	2017-07-03 03:56:00+03	260900.00
5AA368	2017-07-20 21:39:00+03	191200.00
5AA390	2017-07-21 16:42:00+03	65600.00
5AA3A4	2017-07-05 13:52:00+03	66000.00
5AA3CC	2017-07-14 11:48:00+03	123000.00
5AA429	2017-07-22 05:48:00+03	17800.00
5AA44B	2017-07-15 08:42:00+03	38800.00
5AA45D	2017-07-10 04:47:00+03	18600.00
5AA4CA	2017-07-29 06:04:00+03	50800.00
5AA4D3	2017-07-22 07:32:00+03	6000.00
5AA4F1	2017-08-15 00:32:00+03	133200.00
5AA4F9	2017-07-31 22:17:00+03	46400.00
5AA552	2017-08-08 16:42:00+03	123000.00
5AA556	2017-08-04 21:15:00+03	16400.00
5AA602	2017-07-12 05:14:00+03	143300.00
5AA69E	2017-08-07 11:54:00+03	43100.00
5AA6AB	2017-08-05 12:23:00+03	18400.00
5AA6B9	2017-07-04 17:38:00+03	43600.00
5AA797	2017-07-20 18:53:00+03	38800.00
5AA7B9	2017-08-13 13:24:00+03	102100.00
5AA8E1	2017-07-23 18:08:00+03	46000.00
5AA909	2017-07-31 21:08:00+03	35700.00
5AA91B	2017-06-29 04:27:00+03	68000.00
5AA922	2017-07-07 10:29:00+03	96800.00
5AA92E	2017-07-19 22:26:00+03	72400.00
5AA964	2017-07-26 22:51:00+03	55800.00
5AA9AA	2017-07-23 15:19:00+03	45100.00
5AA9CB	2017-08-08 20:38:00+03	199200.00
5AA9D8	2017-07-27 04:16:00+03	131100.00
5AA9E4	2017-08-14 04:30:00+03	7400.00
5AAA45	2017-07-25 01:49:00+03	62100.00
5AAA9F	2017-08-10 08:22:00+03	165800.00
5AAB04	2017-07-03 23:45:00+03	62600.00
5AAB97	2017-07-09 19:28:00+03	103500.00
5AABE3	2017-08-08 17:17:00+03	28000.00
5AAC41	2017-07-26 06:26:00+03	17000.00
5AAC83	2017-07-09 11:28:00+03	199800.00
5AAC97	2017-07-31 23:49:00+03	46400.00
5AACBE	2017-07-24 16:31:00+03	111000.00
5AACC5	2017-07-13 13:59:00+03	54500.00
5AACC7	2017-08-02 17:39:00+03	32800.00
5AAD1D	2017-07-13 12:36:00+03	128800.00
5AAD34	2017-08-08 15:24:00+03	113300.00
5AAD74	2017-07-02 08:02:00+03	59200.00
5AAD92	2017-07-25 11:13:00+03	13400.00
5AADAE	2017-07-12 22:14:00+03	56000.00
5AADCA	2017-07-14 18:28:00+03	29400.00
5AADD9	2017-08-07 18:31:00+03	42000.00
5AADF9	2017-07-02 02:21:00+03	32800.00
5AAE00	2017-07-08 16:48:00+03	311200.00
5AAE37	2017-07-05 22:55:00+03	58900.00
5AAE60	2017-08-11 23:54:00+03	122800.00
5AAE62	2017-07-01 07:54:00+03	23200.00
5AAFE9	2017-08-01 20:17:00+03	45400.00
5AAFFE	2017-08-03 16:20:00+03	15000.00
5AB03A	2017-08-07 04:09:00+03	131600.00
5AB061	2017-07-29 19:54:00+03	111600.00
5AB065	2017-07-24 23:31:00+03	419100.00
5AB0A0	2017-07-24 14:34:00+03	67600.00
5AB0FA	2017-07-19 11:34:00+03	98200.00
5AB117	2017-07-18 13:35:00+03	56600.00
5AB1C1	2017-07-11 17:25:00+03	90600.00
5AB1F7	2017-07-29 21:20:00+03	189800.00
5AB236	2017-07-21 08:18:00+03	81600.00
5AB238	2017-08-10 14:09:00+03	56600.00
5AB299	2017-07-06 20:06:00+03	109500.00
5AB2B4	2017-07-25 08:12:00+03	78200.00
5AB2DD	2017-08-07 00:57:00+03	46400.00
5AB2E0	2017-07-27 06:15:00+03	49200.00
5AB2F4	2017-08-06 06:57:00+03	131900.00
5AB33D	2017-07-06 16:23:00+03	123000.00
5AB387	2017-07-09 09:38:00+03	86400.00
5AB394	2017-07-24 16:33:00+03	86300.00
5AB3BA	2017-07-24 08:26:00+03	27800.00
5AB410	2017-07-02 18:29:00+03	38800.00
5AB438	2017-08-14 20:41:00+03	10800.00
5AB475	2017-08-09 08:32:00+03	46800.00
5AB490	2017-07-02 01:14:00+03	51000.00
5AB494	2017-08-12 23:14:00+03	7400.00
5AB49E	2017-07-15 07:02:00+03	96400.00
5AB4EE	2017-07-29 20:53:00+03	35600.00
5AB51E	2017-07-11 09:56:00+03	39600.00
5AB53A	2017-07-17 14:01:00+03	48800.00
5AB566	2017-07-05 21:45:00+03	52700.00
5AB5CD	2017-07-20 10:15:00+03	8000.00
5AB66F	2017-07-14 06:24:00+03	271200.00
5AB694	2017-07-31 23:51:00+03	85000.00
5AB6D2	2017-07-12 16:25:00+03	101200.00
5AB732	2017-07-27 03:05:00+03	24400.00
5AB73F	2017-08-02 16:11:00+03	27200.00
5AB79F	2017-06-30 02:52:00+03	56000.00
5AB7E4	2017-08-09 13:21:00+03	18400.00
5AB7F4	2017-07-03 09:11:00+03	19600.00
5AB807	2017-07-23 19:01:00+03	134400.00
5AB856	2017-07-01 10:51:00+03	46000.00
5AB904	2017-07-12 05:34:00+03	86600.00
5AB932	2017-07-18 08:46:00+03	57600.00
5AB942	2017-07-07 09:21:00+03	46300.00
5AB95F	2017-07-04 07:21:00+03	136200.00
5AB96C	2017-08-12 23:31:00+03	168000.00
5AB984	2017-07-07 21:25:00+03	46400.00
5AB98A	2017-07-26 16:42:00+03	41600.00
5ABA0A	2017-07-03 21:02:00+03	111600.00
5ABAAA	2017-07-20 19:50:00+03	148200.00
5ABADF	2017-07-10 11:24:00+03	314400.00
5ABAE3	2017-08-13 23:06:00+03	132500.00
5ABB35	2017-07-22 17:11:00+03	6000.00
5ABC3E	2017-07-04 15:12:00+03	73600.00
5ABC62	2017-07-04 04:10:00+03	36200.00
5ABC76	2017-07-22 14:23:00+03	77600.00
5ABCBE	2017-08-06 10:12:00+03	74400.00
5ABD0C	2017-08-09 05:38:00+03	44300.00
5ABD7C	2017-07-05 18:32:00+03	11600.00
5ABDB2	2017-08-06 23:02:00+03	56000.00
5ABDD0	2017-07-07 04:46:00+03	46000.00
5ABDF5	2017-08-01 05:50:00+03	201200.00
5ABE05	2017-07-12 11:10:00+03	28100.00
5ABE12	2017-07-26 03:52:00+03	301500.00
5ABEC2	2017-08-10 03:47:00+03	102100.00
5ABFB6	2017-08-15 03:13:00+03	6300.00
5ABFCF	2017-08-03 04:42:00+03	46400.00
5AC04D	2017-08-11 18:16:00+03	53300.00
5AC0A6	2017-07-06 21:40:00+03	8200.00
5AC0D9	2017-07-25 12:02:00+03	131600.00
5AC0E0	2017-07-25 17:17:00+03	56600.00
5AC13B	2017-07-18 22:04:00+03	190900.00
5AC152	2017-08-09 04:58:00+03	47000.00
5AC17B	2017-07-17 20:04:00+03	28800.00
5AC274	2017-07-28 10:32:00+03	28700.00
5AC2AD	2017-06-29 21:06:00+03	43900.00
5AC2B5	2017-07-22 19:04:00+03	55800.00
5AC2D1	2017-07-07 22:11:00+03	37900.00
5AC302	2017-07-04 20:41:00+03	28800.00
5AC38E	2017-08-04 12:06:00+03	230000.00
5AC3AA	2017-07-15 10:11:00+03	75000.00
5AC3B0	2017-08-05 17:24:00+03	13400.00
5AC3BD	2017-06-29 17:05:00+03	26700.00
5AC3F5	2017-08-02 15:48:00+03	16400.00
5AC420	2017-07-05 00:27:00+03	19600.00
5AC421	2017-08-09 16:49:00+03	73300.00
5AC45F	2017-08-08 04:00:00+03	100200.00
5AC59F	2017-08-08 02:48:00+03	67200.00
5AC5AA	2017-08-09 22:41:00+03	32400.00
5AC5C0	2017-07-11 01:13:00+03	93900.00
5AC617	2017-07-15 05:47:00+03	139500.00
5AC65E	2017-07-12 09:17:00+03	103000.00
5AC6E1	2017-07-12 22:33:00+03	12400.00
5AC71C	2017-08-04 22:36:00+03	31600.00
5AC794	2017-07-25 19:55:00+03	47400.00
5AC796	2017-07-22 06:46:00+03	283100.00
5AC7E0	2017-07-26 15:40:00+03	65600.00
5AC80A	2017-07-21 10:22:00+03	13600.00
5AC818	2017-07-14 16:29:00+03	28000.00
5AC8BF	2017-07-17 06:38:00+03	87200.00
5AC93D	2017-07-27 02:17:00+03	15800.00
5AC99E	2017-08-06 15:31:00+03	85700.00
5AC9DD	2017-08-02 19:06:00+03	55800.00
5ACA14	2017-07-11 06:35:00+03	46000.00
5ACA5C	2017-07-10 00:46:00+03	32800.00
5ACB18	2017-07-26 23:30:00+03	53400.00
5ACB3C	2017-08-14 19:28:00+03	50700.00
5ACB9B	2017-07-14 16:50:00+03	61200.00
5ACBBF	2017-07-29 08:27:00+03	103800.00
5ACBE6	2017-07-12 03:38:00+03	27200.00
5ACC1F	2017-07-26 13:34:00+03	13000.00
5ACC85	2017-06-27 00:01:00+03	22600.00
5ACCBE	2017-07-22 06:14:00+03	48300.00
5ACCD1	2017-07-29 15:19:00+03	26000.00
5ACD41	2017-08-12 21:59:00+03	54800.00
5ACE09	2017-07-29 00:11:00+03	21800.00
5ACEB3	2017-07-30 08:10:00+03	94000.00
5ACED1	2017-08-15 11:39:00+03	53100.00
5ACEDB	2017-07-22 11:17:00+03	87600.00
5ACF10	2017-07-20 22:15:00+03	69600.00
5ACFD9	2017-07-08 19:03:00+03	25200.00
5ACFE1	2017-07-16 23:00:00+03	12600.00
5AD041	2017-08-07 12:31:00+03	70100.00
5AD0BF	2017-07-08 17:41:00+03	136200.00
5AD0D6	2017-07-18 14:00:00+03	90400.00
5AD149	2017-08-13 23:06:00+03	133100.00
5AD1BC	2017-08-03 07:55:00+03	63000.00
5AD261	2017-08-13 14:45:00+03	12000.00
5AD276	2017-07-29 05:17:00+03	29400.00
5AD2A7	2017-07-26 00:06:00+03	24300.00
5AD2A8	2017-08-14 04:59:00+03	78100.00
5AD2B5	2017-07-31 09:18:00+03	32700.00
5AD33E	2017-08-06 14:14:00+03	58600.00
5AD348	2017-08-13 07:57:00+03	112000.00
5AD38D	2017-08-15 11:30:00+03	36000.00
5AD3B2	2017-07-14 05:27:00+03	24800.00
5AD3B9	2017-07-03 01:21:00+03	23200.00
5AD3CC	2017-08-05 04:10:00+03	145300.00
5AD41E	2017-08-10 10:10:00+03	103600.00
5AD4AE	2017-08-11 00:53:00+03	143100.00
5AD4F4	2017-08-02 02:04:00+03	324800.00
5AD51E	2017-08-12 03:25:00+03	59800.00
5AD57C	2017-07-30 10:28:00+03	28000.00
5AD57E	2017-07-06 15:37:00+03	58800.00
5AD609	2017-07-22 21:59:00+03	13800.00
5AD673	2017-08-13 09:34:00+03	111000.00
5AD736	2017-07-21 15:08:00+03	59900.00
5AD759	2017-07-14 05:33:00+03	132800.00
5AD770	2017-08-08 06:51:00+03	38200.00
5AD778	2017-07-02 04:10:00+03	58400.00
5AD781	2017-08-08 20:53:00+03	76600.00
5AD7A5	2017-08-14 01:37:00+03	73500.00
5AD7E9	2017-07-17 18:53:00+03	83800.00
5AD829	2017-08-07 14:33:00+03	8000.00
5AD893	2017-07-18 13:40:00+03	94200.00
5AD8BA	2017-08-11 06:46:00+03	14400.00
5AD8ED	2017-08-09 05:55:00+03	117000.00
5AD925	2017-06-30 06:11:00+03	68800.00
5AD96F	2017-08-10 02:20:00+03	16400.00
5AD9CD	2017-07-09 01:45:00+03	28000.00
5AD9ED	2017-08-04 23:50:00+03	56100.00
5ADA25	2017-07-18 04:34:00+03	36700.00
5ADB11	2017-07-18 01:15:00+03	28000.00
5ADB12	2017-08-09 07:52:00+03	84100.00
5ADB16	2017-07-19 01:40:00+03	101800.00
5ADB44	2017-07-29 04:21:00+03	56000.00
5ADBB7	2017-07-15 20:12:00+03	7400.00
5ADBD0	2017-07-14 17:28:00+03	112000.00
5ADC0F	2017-07-05 21:30:00+03	32800.00
5ADC19	2017-07-12 10:08:00+03	12600.00
5ADC24	2017-07-22 02:44:00+03	46200.00
5ADC28	2017-07-18 08:33:00+03	61800.00
5ADCB0	2017-08-03 21:56:00+03	6300.00
5ADD1C	2017-07-30 21:39:00+03	799200.00
5ADD28	2017-07-20 22:27:00+03	39200.00
5ADD40	2017-08-13 07:07:00+03	104000.00
5ADD68	2017-07-16 15:10:00+03	25100.00
5ADDD8	2017-07-30 14:11:00+03	46000.00
5ADE14	2017-08-14 06:09:00+03	61100.00
5ADE18	2017-07-11 06:43:00+03	56200.00
5ADE22	2017-07-20 15:45:00+03	46200.00
5ADE70	2017-07-11 22:31:00+03	56000.00
5ADEB7	2017-07-22 00:50:00+03	68800.00
5ADEBB	2017-08-06 09:41:00+03	680800.00
5ADEE9	2017-07-24 16:08:00+03	28000.00
5ADF21	2017-06-29 15:14:00+03	123000.00
5ADF7D	2017-07-05 09:40:00+03	92800.00
5ADFA7	2017-08-05 07:55:00+03	54500.00
5ADFAC	2017-07-16 00:13:00+03	102100.00
5ADFB1	2017-07-09 13:22:00+03	48400.00
5AE02B	2017-08-10 03:52:00+03	37200.00
5AE04E	2017-07-01 21:34:00+03	266400.00
5AE070	2017-08-01 09:54:00+03	56000.00
5AE094	2017-07-10 14:10:00+03	88900.00
5AE0FB	2017-07-25 12:01:00+03	59600.00
5AE10B	2017-07-04 10:16:00+03	67200.00
5AE11C	2017-08-01 12:20:00+03	57800.00
5AE19F	2017-07-07 02:20:00+03	28000.00
5AE1A7	2017-07-26 02:34:00+03	199700.00
5AE1AE	2017-07-20 17:09:00+03	58900.00
5AE225	2017-07-23 04:34:00+03	67800.00
5AE22E	2017-07-10 20:48:00+03	155600.00
5AE30D	2017-08-14 12:36:00+03	89500.00
5AE424	2017-08-09 19:34:00+03	56600.00
5AE44B	2017-07-14 12:22:00+03	112200.00
5AE47C	2017-07-23 08:24:00+03	132800.00
5AE4D4	2017-08-04 10:05:00+03	29600.00
5AE4F1	2017-07-18 14:15:00+03	123600.00
5AE4F9	2017-07-16 02:50:00+03	34100.00
5AE553	2017-08-12 19:15:00+03	105000.00
5AE597	2017-07-04 23:58:00+03	78200.00
5AE689	2017-07-26 12:10:00+03	70700.00
5AE829	2017-07-12 14:40:00+03	60600.00
5AE879	2017-07-13 07:22:00+03	55800.00
5AE88A	2017-07-28 22:29:00+03	177500.00
5AE90B	2017-08-05 14:34:00+03	178800.00
5AE95A	2017-07-27 17:51:00+03	27400.00
5AE961	2017-07-25 17:31:00+03	282300.00
5AE99F	2017-06-30 23:52:00+03	133100.00
5AE9CB	2017-07-04 17:59:00+03	21400.00
5AEA13	2017-07-08 06:33:00+03	66600.00
5AEA61	2017-08-10 03:21:00+03	249900.00
5AEA8C	2017-08-15 02:24:00+03	280400.00
5AEAFF	2017-08-09 12:52:00+03	42800.00
5AEB62	2017-07-12 15:25:00+03	288600.00
5AEBA8	2017-07-12 08:49:00+03	378400.00
5AEC1B	2017-07-21 12:16:00+03	31400.00
5AEC5C	2017-07-14 07:04:00+03	46300.00
5AEC80	2017-08-06 17:41:00+03	60400.00
5AEC95	2017-08-06 08:13:00+03	30200.00
5AED15	2017-07-06 20:42:00+03	61600.00
5AED3F	2017-08-14 09:27:00+03	33800.00
5AEDE0	2017-08-04 01:15:00+03	23600.00
5AEE3E	2017-08-11 06:22:00+03	52300.00
5AEE5E	2017-07-18 05:17:00+03	93400.00
5AEE6D	2017-08-06 08:26:00+03	26000.00
5AEF29	2017-08-14 18:12:00+03	572600.00
5AEF6C	2017-08-04 17:02:00+03	182300.00
5AEF70	2017-07-31 22:46:00+03	46300.00
5AEF79	2017-07-16 15:16:00+03	166000.00
5AEFCD	2017-07-15 06:45:00+03	14400.00
5AF024	2017-08-10 11:02:00+03	272600.00
5AF04C	2017-07-23 11:09:00+03	43500.00
5AF092	2017-08-11 05:47:00+03	55600.00
5AF093	2017-07-11 00:24:00+03	86600.00
5AF0B3	2017-07-16 15:04:00+03	39600.00
5AF0C4	2017-08-10 05:44:00+03	16400.00
5AF166	2017-07-08 19:35:00+03	21000.00
5AF17D	2017-07-03 23:32:00+03	25000.00
5AF184	2017-07-15 11:41:00+03	18600.00
5AF1B9	2017-07-11 13:50:00+03	27200.00
5AF1CB	2017-06-30 10:18:00+03	50800.00
5AF231	2017-08-07 06:58:00+03	24500.00
5AF2AA	2017-08-03 19:17:00+03	28000.00
5AF2B4	2017-08-07 18:11:00+03	59800.00
5AF2B7	2017-08-15 05:20:00+03	133100.00
5AF2E0	2017-08-02 05:31:00+03	202300.00
5AF2E8	2017-07-11 22:34:00+03	38600.00
5AF2F1	2017-08-08 23:38:00+03	56000.00
5AF396	2017-08-02 09:21:00+03	39100.00
5AF3D6	2017-08-02 20:35:00+03	25600.00
5AF3F9	2017-07-03 04:14:00+03	133200.00
5AF415	2017-07-11 07:34:00+03	33400.00
5AF4B8	2017-07-08 18:19:00+03	56000.00
5AF4DE	2017-08-03 07:58:00+03	48800.00
5AF511	2017-08-02 17:12:00+03	55800.00
5AF572	2017-06-29 20:05:00+03	92000.00
5AF589	2017-07-01 19:33:00+03	25400.00
5AF5BF	2017-07-16 07:51:00+03	58600.00
5AF662	2017-08-05 10:18:00+03	43800.00
5AF69F	2017-08-11 00:42:00+03	128800.00
5AF6D1	2017-07-11 22:46:00+03	28000.00
5AF6DA	2017-07-26 00:51:00+03	85000.00
5AF6E9	2017-07-30 10:47:00+03	114700.00
5AF746	2017-08-03 03:37:00+03	531400.00
5AF761	2017-08-12 04:22:00+03	22000.00
5AF76B	2017-08-08 23:22:00+03	69000.00
5AF7A1	2017-07-13 10:05:00+03	73100.00
5AF7B5	2017-07-12 21:05:00+03	59000.00
5AF812	2017-07-06 11:13:00+03	36900.00
5AF831	2017-08-13 01:56:00+03	142400.00
5AF8BA	2017-07-19 04:24:00+03	30400.00
5AF8FB	2017-08-12 04:19:00+03	94200.00
5AF91E	2017-08-06 05:11:00+03	41100.00
5AF99C	2017-06-30 15:24:00+03	23400.00
5AFA03	2017-07-02 00:45:00+03	87100.00
5AFA6E	2017-08-11 15:09:00+03	29600.00
5AFA89	2017-07-22 13:23:00+03	37200.00
5AFADB	2017-07-22 14:08:00+03	162500.00
5AFB10	2017-08-13 01:48:00+03	77400.00
5AFB4F	2017-07-12 03:33:00+03	58400.00
5AFB85	2017-08-09 22:24:00+03	117000.00
5AFB91	2017-07-20 23:05:00+03	66000.00
5AFBE5	2017-07-20 05:47:00+03	156500.00
5AFCA3	2017-08-11 09:30:00+03	147700.00
5AFD42	2017-07-16 23:37:00+03	100000.00
5AFDAC	2017-06-30 23:52:00+03	13400.00
5AFE63	2017-08-02 17:32:00+03	224000.00
5AFF45	2017-07-08 16:55:00+03	40800.00
5AFF4E	2017-08-11 22:21:00+03	37800.00
5AFF56	2017-07-05 01:30:00+03	68800.00
5AFF93	2017-08-11 05:23:00+03	36200.00
5AFFB5	2017-08-08 16:18:00+03	31600.00
5AFFE1	2017-07-02 07:55:00+03	55800.00
5B006B	2017-07-15 03:45:00+03	54800.00
5B006C	2017-07-10 04:41:00+03	23600.00
5B0076	2017-07-02 23:47:00+03	131600.00
5B0089	2017-07-19 12:12:00+03	52900.00
5B00C5	2017-08-05 17:40:00+03	161400.00
5B00D4	2017-08-09 04:39:00+03	43600.00
5B00FE	2017-07-25 10:04:00+03	454500.00
5B0142	2017-07-13 18:07:00+03	55800.00
5B01A1	2017-07-18 04:04:00+03	185200.00
5B0225	2017-07-21 09:24:00+03	18600.00
5B0276	2017-06-28 06:25:00+03	67100.00
5B0279	2017-08-14 02:37:00+03	123000.00
5B0291	2017-07-18 20:40:00+03	84000.00
5B02F1	2017-08-11 16:25:00+03	27300.00
5B030C	2017-08-13 05:12:00+03	25600.00
5B032E	2017-07-30 03:36:00+03	63700.00
5B039C	2017-08-03 06:54:00+03	85000.00
5B03DD	2017-06-28 19:29:00+03	134400.00
5B040B	2017-07-04 16:51:00+03	86800.00
5B042F	2017-06-30 06:29:00+03	42600.00
5B044B	2017-08-10 20:55:00+03	42000.00
5B04E7	2017-07-23 18:26:00+03	55800.00
5B04F9	2017-07-30 03:36:00+03	80500.00
5B0508	2017-08-01 11:59:00+03	64500.00
5B057D	2017-07-23 12:48:00+03	55800.00
5B05D4	2017-07-04 20:22:00+03	23600.00
5B05E6	2017-06-25 12:20:00+03	67800.00
5B05F8	2017-08-10 23:21:00+03	185000.00
5B060F	2017-07-29 06:16:00+03	111600.00
5B0615	2017-07-15 16:02:00+03	55900.00
5B06BE	2017-08-04 14:44:00+03	32800.00
5B06E8	2017-07-29 18:52:00+03	78300.00
5B06EB	2017-08-01 20:43:00+03	86100.00
5B071F	2017-07-07 23:40:00+03	56000.00
5B0737	2017-07-18 03:19:00+03	36700.00
5B076E	2017-07-19 18:35:00+03	37000.00
5B07B8	2017-07-04 08:15:00+03	52000.00
5B07CF	2017-06-30 05:27:00+03	49500.00
5B07F2	2017-07-19 21:05:00+03	54800.00
5B085C	2017-08-14 11:20:00+03	118900.00
5B086F	2017-07-30 21:54:00+03	398500.00
5B0882	2017-08-04 07:28:00+03	73100.00
5B08CC	2017-07-18 16:14:00+03	229600.00
5B08E2	2017-08-03 10:07:00+03	406700.00
5B0933	2017-07-25 17:21:00+03	12200.00
5B094B	2017-08-11 11:55:00+03	26600.00
5B09DD	2017-08-10 14:50:00+03	6300.00
5B0A00	2017-07-10 23:35:00+03	97400.00
5B0A4C	2017-07-31 17:09:00+03	55800.00
5B0A6B	2017-08-10 02:35:00+03	53600.00
5B0A81	2017-07-17 18:07:00+03	48800.00
5B0AAB	2017-07-07 06:07:00+03	62700.00
5B0B0A	2017-07-03 17:31:00+03	18000.00
5B0B0E	2017-07-06 23:18:00+03	73500.00
5B0B11	2017-08-02 15:59:00+03	21400.00
5B0B46	2017-07-09 04:48:00+03	54000.00
5B0C04	2017-07-10 13:01:00+03	50600.00
5B0C09	2017-07-11 09:08:00+03	137600.00
5B0C29	2017-08-04 04:08:00+03	117200.00
5B0CAA	2017-08-05 16:01:00+03	224000.00
5B0CD4	2017-08-03 07:43:00+03	28800.00
5B0D39	2017-07-20 02:55:00+03	46000.00
5B0DEF	2017-06-29 20:48:00+03	29600.00
5B0E0A	2017-07-07 12:49:00+03	45200.00
5B0E40	2017-07-29 15:04:00+03	112000.00
5B0E56	2017-08-02 11:46:00+03	46000.00
5B0E8D	2017-07-29 04:54:00+03	134700.00
5B0F03	2017-07-17 23:14:00+03	34800.00
5B0F10	2017-08-03 17:11:00+03	77900.00
5B0F17	2017-08-05 09:59:00+03	63000.00
5B0F19	2017-07-21 23:25:00+03	44600.00
5B0FB9	2017-07-23 10:04:00+03	93700.00
5B1049	2017-08-04 18:02:00+03	180100.00
5B105B	2017-08-02 15:10:00+03	58400.00
5B10DA	2017-08-03 18:20:00+03	38400.00
5B1113	2017-07-02 01:27:00+03	14400.00
5B117B	2017-07-10 02:32:00+03	34200.00
5B117C	2017-08-13 19:17:00+03	26800.00
5B118A	2017-07-17 16:39:00+03	56000.00
5B11A5	2017-07-04 14:00:00+03	92400.00
5B11C2	2017-07-26 07:56:00+03	152500.00
5B11EC	2017-08-09 14:32:00+03	75600.00
5B1227	2017-07-19 05:38:00+03	105600.00
5B1232	2017-07-06 05:30:00+03	21800.00
5B1298	2017-08-12 07:52:00+03	26800.00
5B12A1	2017-08-13 03:36:00+03	32100.00
5B131D	2017-06-28 23:17:00+03	135600.00
5B1322	2017-07-15 08:02:00+03	15400.00
5B134B	2017-07-10 13:10:00+03	22800.00
5B13D5	2017-07-30 09:45:00+03	48800.00
5B1420	2017-07-07 13:23:00+03	12600.00
5B1461	2017-08-01 13:44:00+03	125200.00
5B1490	2017-07-09 23:31:00+03	32800.00
5B14A5	2017-07-26 01:31:00+03	40600.00
5B14DE	2017-07-15 16:13:00+03	38400.00
5B14EF	2017-08-03 13:59:00+03	32200.00
5B1526	2017-08-04 03:26:00+03	142700.00
5B1568	2017-08-15 06:26:00+03	70600.00
5B15A7	2017-07-26 17:42:00+03	26200.00
5B15D0	2017-07-24 05:34:00+03	32400.00
5B15DC	2017-08-14 08:03:00+03	69500.00
5B1605	2017-08-06 17:33:00+03	31200.00
5B1629	2017-07-24 14:42:00+03	23600.00
5B16D2	2017-07-26 20:56:00+03	81700.00
5B17AC	2017-07-08 00:34:00+03	67800.00
5B185E	2017-07-29 20:39:00+03	27200.00
5B18B8	2017-07-13 01:26:00+03	53100.00
5B18BD	2017-08-12 23:57:00+03	53400.00
5B18C5	2017-07-20 05:06:00+03	56600.00
5B18C8	2017-07-06 19:59:00+03	135200.00
5B1917	2017-07-25 07:44:00+03	113600.00
5B19A9	2017-07-31 04:40:00+03	134400.00
5B1A38	2017-07-12 17:43:00+03	421000.00
5B1AE8	2017-07-30 20:02:00+03	54500.00
5B1B06	2017-07-25 07:14:00+03	42400.00
5B1B0E	2017-07-06 08:26:00+03	72600.00
5B1B18	2017-08-12 19:30:00+03	66600.00
5B1B21	2017-08-02 04:04:00+03	93900.00
5B1B28	2017-07-15 19:40:00+03	23200.00
5B1BFE	2017-07-11 02:04:00+03	13800.00
5B1C40	2017-08-11 15:08:00+03	66400.00
5B1C5B	2017-06-30 14:35:00+03	80300.00
5B1C6E	2017-07-10 03:40:00+03	111600.00
5B1C8E	2017-07-05 02:50:00+03	118600.00
5B1CBD	2017-08-03 22:36:00+03	67200.00
5B1CDC	2017-07-29 18:00:00+03	27200.00
5B1D06	2017-07-17 18:04:00+03	13600.00
5B1D23	2017-07-04 16:59:00+03	43200.00
5B1D2A	2017-07-23 19:15:00+03	6300.00
5B1D32	2017-08-09 11:57:00+03	137100.00
5B1E01	2017-07-02 09:56:00+03	45200.00
5B1E11	2017-06-27 14:13:00+03	75600.00
5B1E1E	2017-08-12 23:37:00+03	28400.00
5B1E71	2017-08-09 22:01:00+03	54000.00
5B1ECC	2017-07-25 03:20:00+03	132800.00
5B1EFF	2017-08-07 02:23:00+03	9800.00
5B1F79	2017-07-10 06:42:00+03	167500.00
5B1F7E	2017-07-09 04:37:00+03	56600.00
5B1FE9	2017-08-04 08:52:00+03	62100.00
5B2016	2017-08-11 12:03:00+03	56600.00
5B20CB	2017-07-18 08:56:00+03	46400.00
5B212E	2017-08-01 22:56:00+03	46000.00
5B219E	2017-07-13 22:35:00+03	191200.00
5B2263	2017-07-17 11:35:00+03	89200.00
5B22A9	2017-07-19 19:28:00+03	20800.00
5B22E6	2017-07-26 20:31:00+03	22000.00
5B2313	2017-08-14 02:40:00+03	92800.00
5B242F	2017-07-18 16:29:00+03	81500.00
5B2482	2017-08-13 16:34:00+03	117600.00
5B24A6	2017-07-17 22:54:00+03	223200.00
5B24B7	2017-07-24 22:48:00+03	22600.00
5B24D1	2017-07-06 11:43:00+03	254600.00
5B2505	2017-07-10 22:53:00+03	31000.00
5B25F5	2017-08-11 20:49:00+03	36600.00
5B25F9	2017-08-12 09:38:00+03	59100.00
5B25FC	2017-08-13 16:14:00+03	33100.00
5B2662	2017-07-17 19:55:00+03	26600.00
5B2708	2017-07-12 00:16:00+03	13000.00
5B27B3	2017-07-18 03:12:00+03	14700.00
5B27C2	2017-08-06 22:27:00+03	36600.00
5B28F3	2017-08-09 02:19:00+03	12600.00
5B2906	2017-07-26 02:00:00+03	132800.00
5B293D	2017-07-17 14:15:00+03	28800.00
5B2956	2017-07-15 21:53:00+03	42700.00
5B2999	2017-07-27 07:10:00+03	138000.00
5B299F	2017-08-12 06:53:00+03	437600.00
5B2A7E	2017-08-05 03:00:00+03	67800.00
5B2ACE	2017-08-02 18:55:00+03	62600.00
5B2B3B	2017-08-13 21:15:00+03	21500.00
5B2B52	2017-08-13 21:28:00+03	492000.00
5B2B79	2017-07-04 11:20:00+03	279800.00
5B2B8E	2017-08-10 07:58:00+03	8000.00
5B2BD2	2017-08-02 04:55:00+03	159800.00
5B2BDF	2017-07-03 21:56:00+03	45500.00
5B2BE0	2017-08-08 09:38:00+03	119600.00
5B2BFD	2017-08-15 07:08:00+03	48800.00
5B2C06	2017-06-26 11:42:00+03	38400.00
5B2C49	2017-07-25 04:34:00+03	85000.00
5B2C5E	2017-08-01 21:59:00+03	254900.00
5B2D3B	2017-07-17 21:21:00+03	76800.00
5B2D81	2017-07-22 18:19:00+03	89700.00
5B2DC3	2017-07-09 02:51:00+03	86400.00
5B2DC6	2017-07-25 04:31:00+03	11800.00
5B2DE9	2017-08-04 08:38:00+03	47000.00
5B2DFF	2017-07-04 15:03:00+03	15000.00
5B2E16	2017-07-15 03:38:00+03	102300.00
5B2E2D	2017-08-11 08:24:00+03	47700.00
5B2E38	2017-08-11 22:05:00+03	97700.00
5B2E46	2017-08-01 06:30:00+03	16400.00
5B2E62	2017-08-07 23:42:00+03	198200.00
5B2E7D	2017-07-02 10:39:00+03	25400.00
5B2E82	2017-06-29 08:17:00+03	12600.00
5B2ED1	2017-07-18 03:20:00+03	282100.00
5B2F97	2017-07-16 03:09:00+03	516200.00
5B2FC7	2017-07-21 00:43:00+03	66600.00
5B300F	2017-08-09 03:54:00+03	54500.00
5B3052	2017-06-29 04:26:00+03	6900.00
5B3109	2017-07-22 18:00:00+03	61800.00
5B313F	2017-08-10 05:41:00+03	86300.00
5B315A	2017-07-11 22:44:00+03	76300.00
5B31DF	2017-07-14 13:54:00+03	43400.00
5B3252	2017-08-13 11:50:00+03	38800.00
5B325B	2017-07-21 08:12:00+03	167500.00
5B339A	2017-08-09 01:53:00+03	57500.00
5B3442	2017-07-24 09:47:00+03	51100.00
5B349A	2017-07-06 02:42:00+03	35200.00
5B34A8	2017-07-21 23:47:00+03	119600.00
5B34F8	2017-07-24 06:21:00+03	23600.00
5B3527	2017-07-15 16:42:00+03	28000.00
5B35C2	2017-07-03 11:41:00+03	128800.00
5B3669	2017-07-15 11:42:00+03	116900.00
5B36FF	2017-08-04 01:39:00+03	18800.00
5B3734	2017-07-15 01:16:00+03	189800.00
5B3736	2017-07-10 13:01:00+03	48500.00
5B375C	2017-07-31 04:03:00+03	12400.00
5B37A3	2017-07-18 01:46:00+03	111600.00
5B37B7	2017-07-18 15:58:00+03	56000.00
5B37BD	2017-07-15 16:26:00+03	27800.00
5B37C7	2017-08-10 11:47:00+03	112600.00
5B37CF	2017-08-02 14:22:00+03	103500.00
5B386A	2017-08-13 22:51:00+03	24000.00
5B391E	2017-08-05 07:05:00+03	125200.00
5B3933	2017-07-22 10:41:00+03	112600.00
5B3947	2017-08-03 14:17:00+03	70600.00
5B3990	2017-08-13 19:37:00+03	95100.00
5B3A29	2017-07-31 10:14:00+03	64300.00
5B3A80	2017-08-03 03:10:00+03	48100.00
5B3A83	2017-07-19 13:01:00+03	117200.00
5B3ABA	2017-07-11 07:06:00+03	29800.00
5B3B1E	2017-06-28 02:03:00+03	55800.00
5B3B24	2017-07-13 11:52:00+03	216600.00
5B3B75	2017-07-13 01:47:00+03	225900.00
5B3B82	2017-08-05 18:12:00+03	58600.00
5B3BCF	2017-06-28 03:47:00+03	48200.00
5B3BFF	2017-07-15 12:47:00+03	46000.00
5B3C2A	2017-07-31 18:45:00+03	121400.00
5B3C42	2017-07-21 19:24:00+03	69500.00
5B3C4F	2017-08-07 09:01:00+03	84800.00
5B3C96	2017-08-06 06:19:00+03	12200.00
5B3C9E	2017-07-16 09:34:00+03	47400.00
5B3CC5	2017-08-08 16:31:00+03	93900.00
5B3CE6	2017-08-12 05:04:00+03	73300.00
5B3CF9	2017-07-20 17:08:00+03	65600.00
5B3D42	2017-08-09 05:42:00+03	64800.00
5B3D51	2017-08-15 11:41:00+03	131600.00
5B3DB9	2017-07-18 15:20:00+03	39200.00
5B3DBF	2017-07-25 10:06:00+03	59800.00
5B3DE5	2017-07-03 03:49:00+03	8600.00
5B3DFE	2017-07-23 00:52:00+03	120000.00
5B3EA5	2017-07-01 05:47:00+03	21800.00
5B3EAF	2017-08-03 00:44:00+03	26300.00
5B3EC7	2017-08-12 16:22:00+03	42000.00
5B3EEA	2017-07-20 20:47:00+03	48300.00
5B3F0C	2017-08-09 10:08:00+03	54400.00
5B3F1A	2017-07-10 02:45:00+03	62000.00
5B3F30	2017-07-12 17:34:00+03	66400.00
5B3F37	2017-07-01 20:59:00+03	134400.00
5B3F92	2017-07-26 07:29:00+03	393800.00
5B3FC7	2017-08-04 06:49:00+03	6000.00
5B3FD5	2017-08-07 11:02:00+03	64500.00
5B3FE5	2017-07-14 09:01:00+03	44600.00
5B3FE9	2017-07-26 11:33:00+03	22400.00
5B3FF0	2017-08-05 15:29:00+03	236500.00
5B4048	2017-07-31 18:31:00+03	386200.00
5B404C	2017-07-15 13:07:00+03	29400.00
5B4069	2017-07-01 20:19:00+03	46500.00
5B4153	2017-08-14 22:38:00+03	52000.00
5B4158	2017-08-13 01:31:00+03	70700.00
5B41B3	2017-07-04 15:19:00+03	37600.00
5B424D	2017-08-14 09:47:00+03	21800.00
5B4260	2017-07-27 13:27:00+03	112400.00
5B42F4	2017-07-31 23:01:00+03	12400.00
5B4343	2017-07-17 00:02:00+03	36000.00
5B43AD	2017-06-29 01:50:00+03	75600.00
5B4402	2017-07-27 19:24:00+03	25800.00
5B449C	2017-07-06 17:04:00+03	396400.00
5B4584	2017-07-30 12:51:00+03	59800.00
5B45BC	2017-07-26 01:54:00+03	58600.00
5B45CE	2017-07-19 23:20:00+03	45200.00
5B45F0	2017-07-13 12:05:00+03	392100.00
5B4667	2017-08-08 16:58:00+03	28700.00
5B4698	2017-07-13 02:11:00+03	105000.00
5B46AD	2017-07-18 01:19:00+03	28000.00
5B46BA	2017-07-27 22:04:00+03	202700.00
5B4707	2017-07-29 06:40:00+03	83200.00
5B4719	2017-08-07 16:33:00+03	59000.00
5B471C	2017-07-05 20:57:00+03	9000.00
5B47A6	2017-08-10 07:56:00+03	33100.00
5B481D	2017-07-23 17:24:00+03	64100.00
5B4820	2017-07-30 07:43:00+03	120700.00
5B48B4	2017-07-13 22:22:00+03	200400.00
5B4942	2017-07-26 19:24:00+03	18300.00
5B4945	2017-07-08 08:49:00+03	62700.00
5B4953	2017-07-10 17:09:00+03	224000.00
5B4963	2017-07-03 05:46:00+03	9800.00
5B496B	2017-07-15 19:44:00+03	38800.00
5B49B9	2017-07-18 04:33:00+03	36600.00
5B49C1	2017-07-29 04:06:00+03	67700.00
5B4A46	2017-08-07 00:47:00+03	11800.00
5B4ADB	2017-07-09 17:04:00+03	62600.00
5B4AEB	2017-07-19 12:56:00+03	64800.00
5B4AF6	2017-08-02 14:50:00+03	14000.00
5B4B04	2017-07-06 06:31:00+03	47200.00
5B4B24	2017-08-02 15:42:00+03	88100.00
5B4BDF	2017-07-29 04:59:00+03	65100.00
5B4C30	2017-08-13 21:46:00+03	32800.00
5B4C56	2017-08-14 22:21:00+03	39300.00
5B4CCD	2017-08-14 07:07:00+03	25200.00
5B4D3C	2017-07-23 10:15:00+03	9200.00
5B4D7B	2017-07-17 16:56:00+03	289800.00
5B4D87	2017-07-16 22:07:00+03	53200.00
5B4DB6	2017-07-29 19:12:00+03	31200.00
5B4DBA	2017-08-03 04:43:00+03	25600.00
5B4E45	2017-08-12 17:42:00+03	133200.00
5B4E59	2017-07-10 10:28:00+03	83000.00
5B4E9B	2017-08-11 23:29:00+03	254900.00
5B4EA4	2017-07-28 03:08:00+03	114500.00
5B4EA6	2017-08-07 01:04:00+03	77600.00
5B4EB6	2017-08-09 20:30:00+03	397100.00
5B4EFC	2017-07-17 11:42:00+03	10800.00
5B4F1F	2017-07-17 16:43:00+03	89000.00
5B4F68	2017-07-28 20:58:00+03	48500.00
5B4FD1	2017-08-13 03:42:00+03	116400.00
5B4FEF	2017-07-27 00:03:00+03	43800.00
5B502C	2017-08-11 03:47:00+03	6700.00
5B5070	2017-08-02 07:38:00+03	25600.00
5B5081	2017-07-20 15:58:00+03	43200.00
5B50FB	2017-07-17 18:22:00+03	15800.00
5B51DB	2017-07-24 06:36:00+03	118000.00
5B5258	2017-08-03 13:43:00+03	378400.00
5B5316	2017-07-11 21:43:00+03	124200.00
5B540F	2017-08-07 20:50:00+03	84500.00
5B5436	2017-08-15 04:28:00+03	26000.00
5B5440	2017-08-10 18:48:00+03	32800.00
5B54C0	2017-08-10 10:08:00+03	16800.00
5B54E0	2017-07-23 20:04:00+03	39200.00
5B5537	2017-08-08 02:09:00+03	10600.00
5B553A	2017-08-10 06:51:00+03	55800.00
5B5579	2017-08-02 13:36:00+03	6000.00
5B557F	2017-07-16 04:05:00+03	82900.00
5B55AD	2017-07-08 12:50:00+03	6000.00
5B55B3	2017-07-15 17:08:00+03	61600.00
5B55E3	2017-07-21 14:45:00+03	69500.00
5B5620	2017-08-14 01:52:00+03	31900.00
5B562E	2017-08-04 09:33:00+03	39500.00
5B5631	2017-06-27 10:28:00+03	23200.00
5B5639	2017-07-01 01:21:00+03	71200.00
5B565B	2017-07-15 11:55:00+03	45100.00
5B565C	2017-08-13 15:31:00+03	73500.00
5B5673	2017-08-04 07:40:00+03	103000.00
5B567D	2017-07-01 18:17:00+03	182800.00
5B5684	2017-06-28 14:26:00+03	246200.00
5B5685	2017-08-11 03:27:00+03	85000.00
5B5688	2017-07-29 16:28:00+03	92000.00
5B569F	2017-08-03 07:52:00+03	66000.00
5B5712	2017-07-14 22:11:00+03	53400.00
5B5725	2017-07-18 08:07:00+03	94500.00
5B5745	2017-06-30 07:15:00+03	37000.00
5B5747	2017-07-13 10:00:00+03	99600.00
5B5782	2017-07-07 19:28:00+03	138500.00
5B578A	2017-08-14 12:20:00+03	89700.00
5B57A8	2017-08-03 10:32:00+03	61100.00
5B57C1	2017-08-05 18:15:00+03	84000.00
5B584D	2017-07-23 04:33:00+03	47100.00
5B5895	2017-07-10 04:37:00+03	27800.00
5B5A12	2017-08-15 06:31:00+03	31400.00
5B5A13	2017-07-20 03:27:00+03	61900.00
5B5A2C	2017-08-01 04:31:00+03	98400.00
5B5AAC	2017-07-24 15:30:00+03	139000.00
5B5ACF	2017-08-12 07:41:00+03	21400.00
5B5AD4	2017-06-29 07:41:00+03	131100.00
5B5AFF	2017-07-28 23:54:00+03	6800.00
5B5B28	2017-07-02 03:58:00+03	69000.00
5B5BB9	2017-07-08 02:14:00+03	108300.00
5B5BE3	2017-07-13 20:43:00+03	147000.00
5B5C0F	2017-07-25 06:11:00+03	24800.00
5B5C26	2017-08-03 22:04:00+03	28800.00
5B5C3E	2017-08-05 15:15:00+03	133100.00
5B5C87	2017-07-30 12:46:00+03	111600.00
5B5C94	2017-07-16 17:06:00+03	43500.00
5B5DA4	2017-08-09 04:16:00+03	140200.00
5B5DCD	2017-07-02 01:26:00+03	46300.00
5B5DDB	2017-07-29 23:23:00+03	11800.00
5B5DFF	2017-07-03 13:32:00+03	43200.00
5B5E19	2017-07-29 13:42:00+03	99600.00
5B5E4A	2017-07-31 15:19:00+03	7400.00
5B5FB2	2017-07-26 00:04:00+03	168900.00
5B5FB6	2017-08-10 18:53:00+03	177200.00
5B5FF1	2017-07-27 04:42:00+03	218000.00
5B6042	2017-07-08 13:50:00+03	246000.00
5B606C	2017-08-15 09:52:00+03	23200.00
5B60B1	2017-07-17 11:56:00+03	30200.00
5B610D	2017-08-10 13:28:00+03	75300.00
5B6153	2017-08-12 05:16:00+03	81900.00
5B6170	2017-07-24 00:45:00+03	133100.00
5B6212	2017-07-21 14:35:00+03	20200.00
5B6292	2017-08-07 15:01:00+03	126000.00
5B6300	2017-08-06 03:27:00+03	101200.00
5B6301	2017-08-12 05:37:00+03	24000.00
5B6335	2017-08-13 18:01:00+03	13600.00
5B63A4	2017-08-15 08:42:00+03	258700.00
5B63C5	2017-07-09 23:35:00+03	139600.00
5B643C	2017-07-02 15:00:00+03	57600.00
5B64F3	2017-07-01 13:35:00+03	46400.00
5B64F6	2017-06-30 06:45:00+03	38600.00
5B65CB	2017-08-01 02:15:00+03	227400.00
5B65F1	2017-07-25 19:38:00+03	81600.00
5B65F8	2017-07-06 18:35:00+03	257500.00
5B6601	2017-08-07 12:58:00+03	131600.00
5B664D	2017-07-28 08:20:00+03	19600.00
5B6686	2017-07-02 00:29:00+03	152500.00
5B66E5	2017-07-17 08:05:00+03	26800.00
5B6744	2017-07-15 20:06:00+03	259300.00
5B677A	2017-07-10 03:06:00+03	29400.00
5B678E	2017-07-09 19:19:00+03	23400.00
5B67D3	2017-07-13 03:09:00+03	16000.00
5B682F	2017-07-18 00:42:00+03	28000.00
5B68B2	2017-07-23 13:10:00+03	30200.00
5B69A5	2017-07-17 22:27:00+03	94700.00
5B69DA	2017-08-11 20:14:00+03	37000.00
5B6A0A	2017-07-22 01:47:00+03	54800.00
5B6A73	2017-07-20 18:05:00+03	67200.00
5B6A93	2017-07-20 14:58:00+03	134800.00
5B6AC6	2017-08-13 13:22:00+03	148200.00
5B6B3C	2017-07-16 02:23:00+03	135600.00
5B6B46	2017-07-20 18:22:00+03	34200.00
5B6B90	2017-06-29 11:29:00+03	84400.00
5B6BBE	2017-07-23 08:39:00+03	12600.00
5B6BC6	2017-07-11 06:32:00+03	20200.00
5B6C2E	2017-07-24 13:44:00+03	27800.00
5B6C3B	2017-07-09 22:05:00+03	265700.00
5B6CBA	2017-07-29 01:59:00+03	28000.00
5B6D24	2017-07-15 17:32:00+03	25200.00
5B6D5A	2017-08-14 08:22:00+03	39200.00
5B6D65	2017-07-23 16:22:00+03	45200.00
5B6DF6	2017-07-11 09:11:00+03	26600.00
5B6F17	2017-07-10 19:12:00+03	121400.00
5B6F2F	2017-07-13 00:14:00+03	45200.00
5B6FB0	2017-08-03 21:19:00+03	59300.00
5B6FD8	2017-08-12 03:56:00+03	56000.00
5B7019	2017-08-05 14:13:00+03	40200.00
5B706A	2017-07-09 19:13:00+03	55800.00
5B708D	2017-08-12 03:44:00+03	40400.00
5B7094	2017-08-11 23:14:00+03	67900.00
5B70DD	2017-08-05 10:03:00+03	18700.00
5B70FA	2017-07-04 00:06:00+03	40800.00
5B7113	2017-08-06 19:01:00+03	23200.00
5B713F	2017-07-12 22:44:00+03	52000.00
5B714C	2017-07-12 21:27:00+03	202300.00
5B7178	2017-08-03 16:23:00+03	32400.00
5B717C	2017-07-26 07:00:00+03	6700.00
5B71A1	2017-07-27 05:59:00+03	110400.00
5B71D0	2017-08-08 06:20:00+03	15100.00
5B71D8	2017-08-14 12:28:00+03	138000.00
5B7290	2017-07-22 09:38:00+03	35200.00
5B72B0	2017-07-23 13:42:00+03	112600.00
5B72B1	2017-07-24 04:08:00+03	6700.00
5B72C5	2017-07-28 19:39:00+03	99000.00
5B737D	2017-07-26 19:12:00+03	48900.00
5B745B	2017-08-09 01:14:00+03	50900.00
5B74F4	2017-06-30 21:25:00+03	25600.00
5B74F6	2017-07-17 17:05:00+03	19800.00
5B7596	2017-07-22 09:52:00+03	38800.00
5B75E8	2017-07-17 16:30:00+03	151800.00
5B7653	2017-07-31 21:25:00+03	74400.00
5B766F	2017-07-06 01:27:00+03	29200.00
5B767D	2017-07-14 22:23:00+03	24200.00
5B7683	2017-07-15 09:58:00+03	40800.00
5B7707	2017-07-15 15:15:00+03	42800.00
5B7709	2017-07-19 00:28:00+03	23400.00
5B77A5	2017-07-06 01:48:00+03	37500.00
5B781D	2017-07-09 11:20:00+03	34000.00
5B783B	2017-07-24 02:12:00+03	24400.00
5B7852	2017-07-10 06:54:00+03	14800.00
5B7870	2017-08-04 18:43:00+03	109000.00
5B7880	2017-07-01 17:05:00+03	54700.00
5B788C	2017-07-21 00:43:00+03	87000.00
5B78DF	2017-07-27 17:42:00+03	335900.00
5B78F8	2017-07-10 00:16:00+03	82900.00
5B7909	2017-08-13 02:24:00+03	111600.00
5B7984	2017-08-09 13:28:00+03	23600.00
5B79D8	2017-08-06 21:20:00+03	54500.00
5B7A1F	2017-08-06 22:22:00+03	14800.00
5B7A6A	2017-07-06 06:14:00+03	57800.00
5B7AA2	2017-07-07 03:13:00+03	7200.00
5B7ABF	2017-06-30 03:04:00+03	133100.00
5B7ACF	2017-07-04 21:33:00+03	40100.00
5B7AEA	2017-07-12 20:03:00+03	89200.00
5B7AFD	2017-07-18 10:08:00+03	82100.00
5B7B07	2017-07-28 11:17:00+03	70800.00
5B7B0A	2017-07-24 09:16:00+03	67400.00
5B7B57	2017-07-30 14:48:00+03	35600.00
5B7B99	2017-07-29 06:29:00+03	206800.00
5B7C3C	2017-08-13 08:47:00+03	31200.00
5B7CBC	2017-08-02 04:09:00+03	24400.00
5B7CD7	2017-07-21 00:53:00+03	93900.00
5B7D33	2017-08-09 16:55:00+03	151200.00
5B7E36	2017-08-01 22:43:00+03	99700.00
5B7E94	2017-08-14 00:33:00+03	132800.00
5B7EA3	2017-07-21 05:03:00+03	24400.00
5B7EC3	2017-07-19 14:15:00+03	29600.00
5B7EF5	2017-07-11 20:21:00+03	124200.00
5B7F05	2017-08-13 05:07:00+03	148200.00
5B7F0C	2017-07-21 09:48:00+03	265700.00
5B7F18	2017-08-05 06:02:00+03	110700.00
5B7F4E	2017-07-22 15:55:00+03	41400.00
5B7F7D	2017-07-30 14:30:00+03	516800.00
5B7FED	2017-07-05 00:23:00+03	25400.00
5B80B4	2017-07-12 00:11:00+03	56000.00
5B8111	2017-08-02 11:41:00+03	13500.00
5B813D	2017-08-14 06:25:00+03	38800.00
5B82E5	2017-07-05 07:23:00+03	6000.00
5B82EB	2017-07-20 05:43:00+03	106800.00
5B830C	2017-06-27 03:26:00+03	34000.00
5B83C6	2017-07-11 15:45:00+03	54600.00
5B83FA	2017-07-22 15:37:00+03	40800.00
5B8416	2017-07-26 23:02:00+03	26800.00
5B8436	2017-07-23 03:21:00+03	133100.00
5B8463	2017-08-03 09:04:00+03	56800.00
5B84F2	2017-07-03 08:28:00+03	44800.00
5B84FC	2017-07-05 17:13:00+03	21200.00
5B8517	2017-08-13 18:49:00+03	111600.00
5B8528	2017-08-07 23:32:00+03	300700.00
5B85A8	2017-08-01 22:54:00+03	182300.00
5B85DE	2017-07-24 05:32:00+03	178800.00
5B85E6	2017-07-25 03:43:00+03	398500.00
5B86CC	2017-07-13 12:38:00+03	14400.00
5B86FC	2017-07-05 22:17:00+03	81900.00
5B8732	2017-07-25 05:46:00+03	59800.00
5B875E	2017-08-07 18:02:00+03	13600.00
5B87AC	2017-08-15 16:50:00+03	160200.00
5B87EC	2017-07-01 09:00:00+03	14000.00
5B8802	2017-07-11 18:28:00+03	369000.00
5B881B	2017-08-09 19:14:00+03	23600.00
5B8827	2017-07-20 16:04:00+03	38800.00
5B884E	2017-07-25 14:09:00+03	123000.00
5B88F2	2017-08-09 15:13:00+03	177600.00
5B8918	2017-07-11 00:44:00+03	42800.00
5B8921	2017-08-07 23:49:00+03	56000.00
5B898F	2017-08-11 00:45:00+03	6300.00
5B89C8	2017-07-08 14:08:00+03	60400.00
5B89EC	2017-08-01 21:32:00+03	89700.00
5B89FA	2017-07-14 13:59:00+03	55600.00
5B8AC5	2017-07-23 16:50:00+03	40000.00
5B8AD2	2017-07-27 23:23:00+03	16400.00
5B8B01	2017-07-28 11:58:00+03	71100.00
5B8B4E	2017-07-12 09:30:00+03	14000.00
5B8B79	2017-07-04 10:51:00+03	43100.00
5B8BB9	2017-08-03 08:22:00+03	45400.00
5B8BE1	2017-07-03 22:27:00+03	22000.00
5B8BEB	2017-07-02 03:23:00+03	73100.00
5B8C2B	2017-08-03 17:31:00+03	111900.00
5B8C75	2017-07-04 05:30:00+03	97900.00
5B8CEC	2017-07-19 18:58:00+03	28800.00
5B8CEF	2017-07-08 17:03:00+03	8000.00
5B8D67	2017-07-08 20:37:00+03	23200.00
5B8D71	2017-08-07 13:16:00+03	48800.00
5B8DED	2017-08-11 20:25:00+03	47100.00
5B8E11	2017-07-12 07:17:00+03	51200.00
5B8E3E	2017-07-19 15:53:00+03	91500.00
5B8EB5	2017-07-29 02:01:00+03	30200.00
5B8EBE	2017-08-10 11:20:00+03	16400.00
5B8F00	2017-07-17 08:54:00+03	285000.00
5B8F3B	2017-07-02 23:17:00+03	14700.00
5B8F45	2017-08-11 20:50:00+03	50700.00
5B8F4F	2017-07-17 05:06:00+03	103000.00
5B8F55	2017-07-23 19:28:00+03	91100.00
5B8F6C	2017-08-03 07:44:00+03	55800.00
5B9073	2017-07-04 07:45:00+03	92400.00
5B907B	2017-08-13 10:41:00+03	44600.00
5B90CA	2017-07-21 18:37:00+03	414400.00
5B910C	2017-07-14 22:46:00+03	90000.00
5B9146	2017-07-03 00:33:00+03	81900.00
5B9186	2017-08-10 00:28:00+03	116700.00
5B918E	2017-07-22 07:42:00+03	42800.00
5B91EC	2017-07-07 06:36:00+03	64800.00
5B920C	2017-08-04 21:30:00+03	7200.00
5B9271	2017-08-14 08:52:00+03	90400.00
5B9289	2017-08-05 07:42:00+03	50800.00
5B92A1	2017-06-30 10:07:00+03	6700.00
5B931F	2017-07-14 21:12:00+03	156900.00
5B9327	2017-07-29 23:29:00+03	50400.00
5B9336	2017-07-03 07:19:00+03	43200.00
5B934A	2017-08-07 11:22:00+03	49800.00
5B9372	2017-08-05 19:46:00+03	113200.00
5B93A9	2017-07-11 00:08:00+03	49200.00
5B93D5	2017-08-03 02:31:00+03	68800.00
5B9409	2017-07-17 19:02:00+03	28000.00
5B9444	2017-07-16 18:43:00+03	23200.00
5B945C	2017-07-10 15:29:00+03	65600.00
5B94D4	2017-07-25 05:59:00+03	46300.00
5B95B8	2017-07-24 20:30:00+03	46000.00
5B95BC	2017-08-06 04:55:00+03	199700.00
5B9614	2017-07-10 18:59:00+03	96800.00
5B964B	2017-08-11 09:47:00+03	7200.00
5B9659	2017-08-15 04:45:00+03	52500.00
5B966F	2017-08-06 03:18:00+03	131600.00
5B967D	2017-07-06 01:12:00+03	56000.00
5B9684	2017-07-20 23:51:00+03	84500.00
5B96CC	2017-07-30 05:28:00+03	301400.00
5B96E7	2017-08-04 13:49:00+03	73600.00
5B96F3	2017-07-25 23:37:00+03	173200.00
5B96FB	2017-07-18 05:43:00+03	124300.00
5B9757	2017-07-12 21:14:00+03	28800.00
5B9822	2017-07-10 19:56:00+03	58700.00
5B98AB	2017-07-19 07:54:00+03	56000.00
5B98DB	2017-07-28 19:25:00+03	246000.00
5B98EF	2017-08-08 17:38:00+03	62700.00
5B9900	2017-08-06 23:39:00+03	105100.00
5B990C	2017-07-31 12:46:00+03	31000.00
5B9918	2017-07-19 09:39:00+03	203900.00
5B99A2	2017-08-11 12:30:00+03	265700.00
5B99A5	2017-08-08 00:13:00+03	56600.00
5B99C2	2017-07-02 07:45:00+03	159600.00
5B99F8	2017-07-17 11:39:00+03	75300.00
5B9A41	2017-08-14 03:50:00+03	26200.00
5B9A52	2017-07-24 07:40:00+03	68800.00
5B9A62	2017-07-27 03:26:00+03	41900.00
5B9A97	2017-08-10 12:39:00+03	29600.00
5B9AC7	2017-07-07 13:20:00+03	47200.00
5B9ACF	2017-08-12 20:30:00+03	19600.00
5B9ADC	2017-07-09 04:01:00+03	67200.00
5B9AE9	2017-08-07 05:58:00+03	133100.00
5B9AEF	2017-07-27 10:33:00+03	28800.00
5B9B18	2017-08-14 16:40:00+03	78800.00
5B9B3B	2017-07-25 20:47:00+03	26200.00
5B9B7E	2017-08-02 21:16:00+03	84100.00
5B9BA2	2017-07-01 13:50:00+03	43200.00
5B9C4D	2017-07-23 08:25:00+03	14000.00
5B9CAE	2017-07-01 18:50:00+03	154000.00
5B9D12	2017-07-12 14:25:00+03	93700.00
5B9D36	2017-07-23 20:39:00+03	24400.00
5B9D42	2017-07-12 13:09:00+03	90900.00
5B9D7B	2017-07-19 17:58:00+03	136200.00
5B9D8A	2017-07-20 02:41:00+03	88600.00
5B9DD3	2017-07-10 11:45:00+03	65000.00
5B9DEA	2017-07-09 16:12:00+03	39400.00
5B9E2E	2017-08-06 22:48:00+03	112000.00
5B9E5A	2017-07-26 15:31:00+03	60600.00
5B9E5E	2017-08-10 01:05:00+03	22000.00
5B9EC5	2017-08-01 06:53:00+03	38400.00
5B9F0B	2017-07-08 02:11:00+03	229000.00
5B9F10	2017-07-03 10:14:00+03	41200.00
5B9F29	2017-07-15 17:37:00+03	189800.00
5B9F2B	2017-08-11 07:11:00+03	39500.00
5B9F42	2017-07-26 15:23:00+03	27200.00
5B9F74	2017-08-05 07:19:00+03	111200.00
5B9F8D	2017-07-05 21:13:00+03	66000.00
5BA00F	2017-08-03 00:27:00+03	18800.00
5BA03F	2017-07-31 15:14:00+03	95200.00
5BA040	2017-07-24 11:32:00+03	58000.00
5BA063	2017-07-03 20:31:00+03	136800.00
5BA0EF	2017-07-06 18:27:00+03	43600.00
5BA186	2017-07-04 19:33:00+03	332800.00
5BA200	2017-07-18 15:45:00+03	119400.00
5BA230	2017-08-07 04:39:00+03	56000.00
5BA34B	2017-07-04 05:48:00+03	23600.00
5BA39B	2017-08-15 10:00:00+03	38400.00
5BA43C	2017-07-02 23:59:00+03	83000.00
5BA46F	2017-08-04 01:31:00+03	42700.00
5BA496	2017-08-15 16:50:00+03	61400.00
5BA4A4	2017-07-21 20:47:00+03	12600.00
5BA4AA	2017-07-22 22:20:00+03	36600.00
5BA56C	2017-08-03 00:58:00+03	38600.00
5BA57A	2017-07-10 23:40:00+03	36800.00
5BA589	2017-08-10 04:06:00+03	20400.00
5BA593	2017-08-10 22:30:00+03	133200.00
5BA5EC	2017-07-29 03:51:00+03	31200.00
5BA622	2017-07-17 22:09:00+03	88000.00
5BA673	2017-08-08 19:53:00+03	38800.00
5BA6C0	2017-08-07 12:55:00+03	7400.00
5BA715	2017-07-05 05:42:00+03	123000.00
5BA760	2017-07-23 07:48:00+03	69000.00
5BA832	2017-07-20 08:27:00+03	110200.00
5BA8E0	2017-08-13 01:58:00+03	47200.00
5BA91D	2017-07-15 05:23:00+03	60400.00
5BA948	2017-08-06 17:42:00+03	58600.00
5BAA13	2017-07-12 07:54:00+03	239100.00
5BAA2A	2017-07-27 11:59:00+03	8000.00
5BAA5F	2017-07-11 18:07:00+03	26000.00
5BAA90	2017-07-11 19:10:00+03	59800.00
5BAAD8	2017-07-18 07:32:00+03	93900.00
5BAB2C	2017-08-07 10:41:00+03	55800.00
5BAB5D	2017-08-09 02:31:00+03	18000.00
5BAB79	2017-08-13 06:45:00+03	31200.00
5BAB8E	2017-08-13 15:03:00+03	81900.00
5BABA0	2017-08-01 01:30:00+03	35200.00
5BABB6	2017-08-13 23:15:00+03	43900.00
5BABBF	2017-08-13 22:29:00+03	12600.00
5BABE1	2017-07-10 19:08:00+03	270800.00
5BAC25	2017-07-17 01:53:00+03	143600.00
5BAC45	2017-08-12 03:42:00+03	153900.00
5BAC9A	2017-07-25 20:59:00+03	58400.00
5BAC9E	2017-07-02 18:57:00+03	71800.00
5BAD06	2017-07-26 18:44:00+03	28000.00
5BADD4	2017-07-20 02:13:00+03	421000.00
5BAE13	2017-07-26 03:44:00+03	27300.00
5BAE4F	2017-07-03 11:30:00+03	39400.00
5BAF0C	2017-07-14 16:42:00+03	40400.00
5BAF42	2017-08-10 06:33:00+03	69700.00
5BAF68	2017-07-05 02:58:00+03	24400.00
5BB01C	2017-07-13 09:28:00+03	20200.00
5BB048	2017-08-08 00:41:00+03	90000.00
5BB04E	2017-06-29 20:10:00+03	270800.00
5BB068	2017-07-25 12:48:00+03	51900.00
5BB077	2017-07-10 11:53:00+03	6000.00
5BB169	2017-07-17 20:21:00+03	93900.00
5BB16C	2017-07-19 03:42:00+03	266200.00
5BB1D8	2017-07-28 17:26:00+03	191300.00
5BB2D0	2017-07-22 14:16:00+03	27200.00
5BB3B3	2017-08-04 17:08:00+03	23200.00
5BB448	2017-08-14 17:50:00+03	27200.00
5BB450	2017-08-07 23:57:00+03	172600.00
5BB458	2017-07-12 12:48:00+03	28000.00
5BB45D	2017-07-03 06:49:00+03	170000.00
5BB48F	2017-08-05 23:22:00+03	43200.00
5BB4A4	2017-07-14 19:01:00+03	131600.00
5BB4C7	2017-07-11 13:14:00+03	114400.00
5BB4D6	2017-07-18 15:53:00+03	28000.00
5BB507	2017-07-14 15:55:00+03	145700.00
5BB5A8	2017-08-11 15:13:00+03	110000.00
5BB5AE	2017-08-07 08:58:00+03	23200.00
5BB5D9	2017-07-22 09:07:00+03	23200.00
5BB63A	2017-07-15 02:14:00+03	12600.00
5BB646	2017-07-21 04:10:00+03	12600.00
5BB65A	2017-07-06 18:30:00+03	40600.00
5BB6C9	2017-07-21 13:12:00+03	128800.00
5BB6CC	2017-08-07 18:09:00+03	335200.00
5BB6FF	2017-08-12 02:23:00+03	57700.00
5BB715	2017-07-22 11:34:00+03	174400.00
5BB7CA	2017-08-02 04:08:00+03	133200.00
5BB7CE	2017-07-30 11:32:00+03	12000.00
5BB7E8	2017-08-06 23:12:00+03	31400.00
5BB94A	2017-07-11 17:53:00+03	115700.00
5BB967	2017-08-14 10:52:00+03	89700.00
5BB970	2017-07-31 10:01:00+03	56600.00
5BB97E	2017-07-15 20:18:00+03	143400.00
5BB9AF	2017-07-25 09:00:00+03	58000.00
5BB9B2	2017-08-10 12:46:00+03	67200.00
5BBA43	2017-08-08 10:32:00+03	106000.00
5BBA54	2017-07-30 00:52:00+03	94700.00
5BBA71	2017-07-14 06:46:00+03	23600.00
5BBA96	2017-07-21 15:02:00+03	26000.00
5BBAA8	2017-07-23 09:55:00+03	67200.00
5BBAE9	2017-08-14 08:56:00+03	90000.00
5BBB43	2017-07-31 08:58:00+03	46300.00
5BBB7C	2017-07-02 09:08:00+03	112000.00
5BBBFF	2017-07-06 00:21:00+03	131100.00
5BBC03	2017-07-20 14:54:00+03	155600.00
5BBC07	2017-07-14 09:41:00+03	129200.00
5BBC28	2017-07-29 06:02:00+03	42800.00
5BBC68	2017-07-10 16:10:00+03	73600.00
5BBCA5	2017-08-01 05:19:00+03	83800.00
5BBCD2	2017-08-03 10:03:00+03	27800.00
5BBD0A	2017-08-07 16:10:00+03	155600.00
5BBD62	2017-07-17 10:17:00+03	15400.00
5BBD75	2017-08-12 12:24:00+03	136800.00
5BBDD6	2017-07-07 02:23:00+03	36200.00
5BBE70	2017-08-05 18:58:00+03	54800.00
5BBEC3	2017-08-13 11:05:00+03	23400.00
5BBED6	2017-08-11 16:51:00+03	101200.00
5BBEFB	2017-07-18 14:39:00+03	31200.00
5BBF82	2017-08-11 12:59:00+03	270800.00
5BBF92	2017-07-30 23:18:00+03	27500.00
5BBFCF	2017-08-04 14:02:00+03	49800.00
5BBFF8	2017-07-09 10:53:00+03	62700.00
5BBFFB	2017-07-06 01:36:00+03	66400.00
5BBFFD	2017-07-14 15:29:00+03	258400.00
5BC021	2017-08-03 15:17:00+03	19600.00
5BC03A	2017-07-10 13:14:00+03	146600.00
5BC076	2017-07-22 23:50:00+03	97900.00
5BC07E	2017-07-25 15:53:00+03	56000.00
5BC0DE	2017-07-12 04:36:00+03	170000.00
5BC0E4	2017-07-05 10:42:00+03	76300.00
5BC134	2017-08-15 07:06:00+03	13200.00
5BC141	2017-07-21 21:54:00+03	28000.00
5BC16F	2017-07-27 01:10:00+03	166700.00
5BC1AE	2017-07-05 01:11:00+03	147200.00
5BC1E2	2017-07-25 22:55:00+03	24200.00
5BC252	2017-07-22 02:59:00+03	17800.00
5BC288	2017-07-11 22:02:00+03	25600.00
5BC2A4	2017-07-16 17:00:00+03	31400.00
5BC2FA	2017-07-03 19:31:00+03	25200.00
5BC328	2017-06-30 15:10:00+03	28800.00
5BC363	2017-08-02 07:54:00+03	93900.00
5BC368	2017-08-01 02:49:00+03	53300.00
5BC3C2	2017-07-30 15:30:00+03	132800.00
5BC43A	2017-08-11 19:17:00+03	66700.00
5BC44C	2017-08-10 22:52:00+03	114100.00
5BC4B0	2017-08-01 21:47:00+03	49400.00
5BC4C7	2017-07-22 22:07:00+03	45100.00
5BC4DB	2017-07-18 02:10:00+03	399600.00
5BC514	2017-07-03 17:03:00+03	6800.00
5BC594	2017-07-01 14:51:00+03	77200.00
5BC5C2	2017-07-06 17:07:00+03	35800.00
5BC62C	2017-08-04 11:31:00+03	47000.00
5BC64B	2017-08-13 11:13:00+03	14000.00
5BC668	2017-07-16 20:38:00+03	53300.00
5BC69F	2017-07-27 07:36:00+03	66600.00
5BC6EC	2017-07-20 04:38:00+03	69500.00
5BC712	2017-07-30 00:25:00+03	146300.00
5BC784	2017-08-06 02:48:00+03	155600.00
5BC78D	2017-07-24 15:18:00+03	8200.00
5BC7DA	2017-06-30 20:50:00+03	62600.00
5BC80C	2017-07-11 16:31:00+03	28000.00
5BC826	2017-08-06 05:31:00+03	531300.00
5BC851	2017-07-06 03:05:00+03	48800.00
5BC86B	2017-08-12 21:39:00+03	56000.00
5BC86D	2017-07-06 07:47:00+03	67600.00
5BC8B5	2017-07-07 00:26:00+03	386400.00
5BCB0C	2017-07-27 17:39:00+03	86400.00
5BCB46	2017-07-24 11:05:00+03	136200.00
5BCC41	2017-07-23 12:16:00+03	66100.00
5BCC59	2017-08-01 20:28:00+03	369000.00
5BCC78	2017-07-02 10:48:00+03	37200.00
5BCC88	2017-07-02 03:16:00+03	132800.00
5BCC93	2017-07-22 20:18:00+03	278800.00
5BCCCD	2017-07-11 23:14:00+03	46400.00
5BCCFC	2017-08-06 13:49:00+03	36200.00
5BCD1A	2017-07-17 18:04:00+03	189800.00
5BCD33	2017-07-25 01:27:00+03	14800.00
5BCD34	2017-08-11 04:24:00+03	265700.00
5BCD51	2017-07-16 03:06:00+03	70200.00
5BCD62	2017-08-12 01:09:00+03	39700.00
5BCD6D	2017-06-29 21:58:00+03	246000.00
5BCD82	2017-07-06 17:41:00+03	118800.00
5BCD83	2017-08-01 12:15:00+03	202800.00
5BCDAF	2017-07-05 06:39:00+03	46000.00
5BCE2D	2017-07-21 06:32:00+03	150000.00
5BCE7C	2017-08-07 06:38:00+03	15000.00
5BCE96	2017-07-06 15:25:00+03	26000.00
5BCEB7	2017-08-15 01:47:00+03	44400.00
5BCF33	2017-08-11 19:28:00+03	161200.00
5BCF90	2017-08-02 08:30:00+03	16000.00
5BCF9D	2017-07-01 18:22:00+03	175200.00
5BD029	2017-07-06 05:06:00+03	144400.00
5BD047	2017-07-20 14:47:00+03	11800.00
5BD0A0	2017-07-20 20:21:00+03	16800.00
5BD0B3	2017-08-15 10:32:00+03	22400.00
5BD0C7	2017-07-10 16:05:00+03	270800.00
5BD10D	2017-07-15 21:53:00+03	133200.00
5BD21F	2017-08-07 08:24:00+03	14400.00
5BD244	2017-08-11 18:39:00+03	53400.00
5BD245	2017-07-10 13:07:00+03	27200.00
5BD2DE	2017-07-09 17:41:00+03	48800.00
5BD2DF	2017-07-28 00:53:00+03	75600.00
5BD322	2017-07-23 08:58:00+03	34000.00
5BD34A	2017-08-14 18:25:00+03	100000.00
5BD351	2017-07-31 08:45:00+03	27200.00
5BD3A2	2017-07-31 18:20:00+03	6700.00
5BD3CF	2017-07-02 11:35:00+03	27200.00
5BD3D6	2017-07-16 21:57:00+03	12600.00
5BD413	2017-08-12 02:41:00+03	219900.00
5BD415	2017-08-11 08:18:00+03	45200.00
5BD418	2017-07-26 18:49:00+03	30200.00
5BD47B	2017-07-17 04:18:00+03	12600.00
5BD52B	2017-08-04 05:18:00+03	153300.00
5BD5C0	2017-08-01 16:52:00+03	49100.00
5BD5DF	2017-07-27 04:57:00+03	27200.00
5BD638	2017-07-04 16:34:00+03	52800.00
5BD673	2017-07-19 10:26:00+03	57600.00
5BD676	2017-07-05 18:31:00+03	85000.00
5BD687	2017-08-09 18:58:00+03	50600.00
5BD6D0	2017-08-01 02:44:00+03	408500.00
5BD6F8	2017-08-06 08:27:00+03	56000.00
5BD70A	2017-07-04 01:09:00+03	16800.00
5BD787	2017-07-13 13:28:00+03	83000.00
5BD796	2017-07-08 20:17:00+03	24400.00
5BD7C9	2017-07-23 09:55:00+03	46300.00
5BD7CA	2017-07-12 04:05:00+03	75300.00
5BD918	2017-08-14 09:53:00+03	44400.00
5BD98B	2017-08-01 20:17:00+03	25200.00
5BD997	2017-08-08 18:58:00+03	18800.00
5BD9A0	2017-08-07 20:25:00+03	56000.00
5BD9BA	2017-08-11 13:32:00+03	52400.00
5BD9BD	2017-07-30 08:27:00+03	73500.00
5BDA2D	2017-07-04 16:45:00+03	123000.00
5BDA99	2017-07-18 10:31:00+03	80000.00
5BDAE0	2017-07-16 14:10:00+03	155600.00
5BDB02	2017-08-12 04:00:00+03	28800.00
5BDB81	2017-08-05 18:18:00+03	67200.00
5BDBE3	2017-07-17 00:32:00+03	133100.00
5BDC13	2017-07-26 01:56:00+03	25400.00
5BDCB2	2017-08-03 01:48:00+03	112000.00
5BDD28	2017-07-26 07:35:00+03	149400.00
5BDD30	2017-07-22 11:48:00+03	131100.00
5BDD70	2017-07-31 15:02:00+03	67700.00
5BDD8E	2017-08-10 19:36:00+03	284300.00
5BDDEE	2017-07-25 11:38:00+03	58400.00
5BDDF2	2017-08-09 22:16:00+03	86800.00
5BDDF4	2017-07-31 14:36:00+03	25800.00
5BDE33	2017-07-26 21:48:00+03	29400.00
5BDEB9	2017-08-07 10:48:00+03	31400.00
5BDEF4	2017-07-28 07:51:00+03	23200.00
5BDF2A	2017-07-29 10:42:00+03	24400.00
5BDF55	2017-07-29 02:24:00+03	63200.00
5BDFCB	2017-08-14 00:30:00+03	23400.00
5BE022	2017-07-29 09:38:00+03	128800.00
5BE038	2017-07-02 21:39:00+03	51200.00
5BE0A3	2017-07-18 07:09:00+03	60400.00
5BE0F9	2017-07-11 06:36:00+03	59100.00
5BE163	2017-07-05 06:07:00+03	21800.00
5BE18D	2017-07-02 05:32:00+03	28300.00
5BE1DF	2017-08-02 20:29:00+03	43600.00
5BE212	2017-07-06 06:44:00+03	23200.00
5BE290	2017-08-06 17:18:00+03	90600.00
5BE2FE	2017-08-10 16:18:00+03	211000.00
5BE377	2017-08-11 16:08:00+03	8000.00
5BE38B	2017-08-14 08:23:00+03	153200.00
5BE42E	2017-07-19 02:53:00+03	64500.00
5BE430	2017-07-30 05:51:00+03	9300.00
5BE43D	2017-07-14 02:06:00+03	47200.00
5BE4C0	2017-07-15 11:10:00+03	24200.00
5BE4CA	2017-07-27 20:41:00+03	37900.00
5BE511	2017-07-18 04:04:00+03	246000.00
5BE561	2017-07-15 10:30:00+03	62000.00
5BE566	2017-07-05 14:20:00+03	42600.00
5BE56E	2017-07-17 05:30:00+03	87900.00
5BE5BE	2017-07-08 13:46:00+03	28000.00
5BE5CB	2017-08-05 04:14:00+03	28800.00
5BE5D5	2017-07-14 07:56:00+03	56000.00
5BE5DE	2017-07-28 04:13:00+03	50600.00
5BE61C	2017-07-29 04:38:00+03	149400.00
5BE631	2017-07-02 02:46:00+03	30900.00
5BE69D	2017-07-22 13:21:00+03	59000.00
5BE6A0	2017-07-23 04:52:00+03	13600.00
5BE6A7	2017-07-04 02:58:00+03	46400.00
5BE723	2017-08-11 14:56:00+03	65900.00
5BE759	2017-08-06 04:00:00+03	65600.00
5BE75D	2017-07-01 09:33:00+03	190400.00
5BE79F	2017-08-14 08:29:00+03	61800.00
5BE7A2	2017-08-13 02:55:00+03	7400.00
5BE7A3	2017-07-18 06:20:00+03	43200.00
5BE7AA	2017-08-02 15:23:00+03	19800.00
5BE7F6	2017-08-11 01:35:00+03	59300.00
5BE7F7	2017-07-16 21:18:00+03	14700.00
5BE82B	2017-08-09 04:32:00+03	169300.00
5BE8D5	2017-07-21 19:52:00+03	87900.00
5BE954	2017-08-05 19:24:00+03	133200.00
5BE96A	2017-08-06 12:22:00+03	66600.00
5BE9A9	2017-06-29 07:58:00+03	51900.00
5BEA01	2017-07-24 06:21:00+03	26000.00
5BEA0E	2017-07-11 11:56:00+03	138000.00
5BEB0F	2017-07-26 14:22:00+03	246000.00
5BEBBB	2017-08-13 20:15:00+03	112000.00
5BEBCC	2017-07-12 22:55:00+03	14000.00
5BEBEA	2017-07-16 23:38:00+03	92700.00
5BEC11	2017-07-14 14:17:00+03	27800.00
5BEC36	2017-07-21 02:49:00+03	102600.00
5BEC38	2017-06-29 04:25:00+03	23200.00
5BEC98	2017-08-08 05:03:00+03	132800.00
5BECBE	2017-07-24 02:11:00+03	58200.00
5BECD3	2017-07-13 18:14:00+03	15000.00
5BED85	2017-08-02 12:18:00+03	246000.00
5BED87	2017-07-13 20:47:00+03	59300.00
5BEDA7	2017-08-07 14:30:00+03	109600.00
5BEE03	2017-08-03 06:55:00+03	123400.00
5BEE30	2017-07-30 08:19:00+03	42800.00
5BEE44	2017-07-10 15:47:00+03	23200.00
5BEE74	2017-07-06 08:17:00+03	6000.00
5BEE91	2017-07-31 12:02:00+03	56000.00
5BEE92	2017-07-16 21:30:00+03	20200.00
5BEEEC	2017-07-28 18:58:00+03	88200.00
5BEEF1	2017-07-05 22:35:00+03	71400.00
5BEEFB	2017-07-22 01:20:00+03	13600.00
5BEF3C	2017-08-09 13:32:00+03	62000.00
5BEF7E	2017-08-07 00:18:00+03	277000.00
5BEFF9	2017-07-19 17:51:00+03	46000.00
5BF04B	2017-07-06 03:33:00+03	37900.00
5BF06E	2017-07-28 21:14:00+03	25600.00
5BF0BB	2017-08-11 16:07:00+03	73300.00
5BF0C9	2017-07-07 07:19:00+03	47200.00
5BF16E	2017-08-10 17:42:00+03	123000.00
5BF246	2017-07-09 00:38:00+03	16400.00
5BF2C1	2017-08-08 17:29:00+03	72600.00
5BF2E6	2017-07-17 00:38:00+03	13400.00
5BF2F3	2017-08-03 07:53:00+03	177200.00
5BF300	2017-08-13 18:29:00+03	32200.00
5BF32E	2017-07-15 23:28:00+03	39800.00
5BF33F	2017-07-30 22:57:00+03	23200.00
5BF3A5	2017-07-07 00:49:00+03	26000.00
5BF3CB	2017-07-18 23:10:00+03	34700.00
5BF49B	2017-07-27 09:13:00+03	67600.00
5BF4A5	2017-08-08 15:03:00+03	23600.00
5BF4F1	2017-07-08 04:49:00+03	25400.00
5BF51B	2017-08-09 11:08:00+03	56000.00
5BF52F	2017-07-04 19:16:00+03	78300.00
5BF544	2017-08-11 00:07:00+03	62600.00
5BF58C	2017-07-29 08:03:00+03	38800.00
5BF58F	2017-07-13 05:53:00+03	133800.00
5BF614	2017-07-22 10:23:00+03	112200.00
5BF661	2017-06-30 15:00:00+03	134000.00
5BF672	2017-08-14 03:50:00+03	152600.00
5BF699	2017-07-15 22:46:00+03	6600.00
5BF6A4	2017-08-13 10:18:00+03	14900.00
5BF6E3	2017-08-03 16:41:00+03	39400.00
5BF6F0	2017-07-29 21:08:00+03	22600.00
5BF755	2017-08-15 05:51:00+03	10800.00
5BF7DB	2017-08-05 10:52:00+03	11700.00
5BF801	2017-08-10 07:46:00+03	224400.00
5BF80D	2017-08-08 08:38:00+03	14700.00
5BF84D	2017-07-13 16:02:00+03	221900.00
5BF8A8	2017-08-13 07:56:00+03	33600.00
5BF8E9	2017-07-17 18:55:00+03	290400.00
5BF99B	2017-08-07 04:06:00+03	6700.00
5BF9A7	2017-07-21 22:44:00+03	18600.00
5BFA05	2017-07-18 15:48:00+03	18000.00
5BFA6B	2017-08-14 14:29:00+03	55600.00
5BFA97	2017-07-21 05:14:00+03	43600.00
5BFABA	2017-08-05 12:44:00+03	9800.00
5BFAF2	2017-07-15 02:47:00+03	15400.00
5BFB0D	2017-07-08 19:58:00+03	87200.00
5BFB1E	2017-07-05 02:12:00+03	28700.00
5BFC0D	2017-07-14 16:54:00+03	147200.00
5BFC51	2017-07-23 07:57:00+03	75600.00
5BFD3E	2017-08-07 08:38:00+03	95900.00
5BFD67	2017-07-31 06:17:00+03	55000.00
5BFD9B	2017-08-12 03:39:00+03	149400.00
5BFE71	2017-08-15 07:17:00+03	18000.00
5BFE8D	2017-08-14 21:57:00+03	129400.00
5BFE90	2017-07-12 12:01:00+03	57500.00
5BFEA4	2017-07-13 17:00:00+03	6800.00
5BFEEE	2017-07-26 19:21:00+03	69500.00
5BFF46	2017-08-02 08:05:00+03	62800.00
5BFF84	2017-07-05 16:19:00+03	99200.00
5BFFB4	2017-07-13 18:58:00+03	15000.00
5BFFDB	2017-07-16 22:52:00+03	16400.00
5BFFEC	2017-08-09 19:22:00+03	151200.00
5C0005	2017-07-29 09:20:00+03	92800.00
5C0016	2017-08-08 05:54:00+03	34600.00
5C00D0	2017-07-25 13:37:00+03	26800.00
5C00E7	2017-07-07 03:32:00+03	7200.00
5C0134	2017-07-25 02:49:00+03	32300.00
5C0169	2017-07-20 12:37:00+03	20200.00
5C01B5	2017-07-26 23:15:00+03	6300.00
5C01BC	2017-07-09 12:39:00+03	48800.00
5C01BE	2017-08-06 18:08:00+03	136500.00
5C01DD	2017-07-14 14:09:00+03	73500.00
5C028C	2017-07-29 08:36:00+03	116800.00
5C029A	2017-07-24 21:01:00+03	15900.00
5C02BE	2017-07-01 15:26:00+03	29000.00
5C02C8	2017-07-22 10:20:00+03	108000.00
5C02DF	2017-08-14 05:42:00+03	203000.00
5C031F	2017-08-09 16:29:00+03	28800.00
5C0340	2017-08-03 21:02:00+03	74400.00
5C03DD	2017-07-05 02:59:00+03	88100.00
5C0444	2017-07-17 10:32:00+03	25800.00
5C04AD	2017-07-31 15:52:00+03	24000.00
5C04BB	2017-07-29 13:08:00+03	111600.00
5C0539	2017-07-10 23:37:00+03	52700.00
5C055D	2017-08-14 17:30:00+03	51300.00
5C0565	2017-08-02 12:20:00+03	50200.00
5C0578	2017-07-29 11:17:00+03	57500.00
5C05B0	2017-07-29 09:32:00+03	43900.00
5C05E4	2017-07-12 09:50:00+03	10800.00
5C05ED	2017-08-13 01:56:00+03	108000.00
5C0665	2017-07-29 03:42:00+03	65400.00
5C0678	2017-07-31 01:09:00+03	74900.00
5C06E2	2017-07-25 16:16:00+03	135200.00
5C0750	2017-07-11 03:05:00+03	111600.00
5C0763	2017-07-07 06:47:00+03	104500.00
5C07AD	2017-07-09 17:37:00+03	13600.00
5C07CA	2017-07-17 17:06:00+03	88800.00
5C07D1	2017-07-18 06:19:00+03	76400.00
5C07E5	2017-07-16 10:30:00+03	542300.00
5C0854	2017-07-25 17:37:00+03	55800.00
5C085E	2017-07-26 13:42:00+03	75600.00
5C0870	2017-07-13 16:44:00+03	152900.00
5C088A	2017-07-24 23:11:00+03	24400.00
5C0892	2017-08-02 11:06:00+03	42400.00
5C090B	2017-08-10 05:55:00+03	48400.00
5C09EC	2017-08-12 06:08:00+03	14400.00
5C09F6	2017-07-08 05:25:00+03	88600.00
5C0A85	2017-07-30 05:04:00+03	26000.00
5C0B27	2017-07-14 16:53:00+03	232000.00
5C0B77	2017-08-05 01:59:00+03	19600.00
5C0BB2	2017-08-06 04:41:00+03	45200.00
5C0C1A	2017-07-22 08:10:00+03	23200.00
5C0C2C	2017-08-15 00:09:00+03	27200.00
5C0C74	2017-07-23 18:04:00+03	116400.00
5C0C7F	2017-07-15 11:06:00+03	14400.00
5C0CAB	2017-07-02 11:14:00+03	49400.00
5C0CDB	2017-08-04 06:17:00+03	166100.00
5C0D24	2017-08-06 12:54:00+03	215500.00
5C0D75	2017-07-29 04:41:00+03	59800.00
5C0DA1	2017-07-17 10:26:00+03	24400.00
5C0DEE	2017-08-06 03:55:00+03	6300.00
5C0E0F	2017-08-07 17:53:00+03	26000.00
5C0E53	2017-07-17 12:46:00+03	88800.00
5C0E82	2017-08-13 11:39:00+03	27200.00
5C0EB7	2017-08-13 23:28:00+03	112000.00
5C0F2F	2017-08-09 10:52:00+03	75300.00
5C0F5F	2017-07-19 12:01:00+03	38400.00
5C0F68	2017-07-09 18:45:00+03	133100.00
5C0FA0	2017-08-08 07:37:00+03	229600.00
5C0FA6	2017-07-25 14:45:00+03	66600.00
5C0FD9	2017-08-02 22:12:00+03	110500.00
5C1013	2017-07-22 05:18:00+03	160200.00
5C10A3	2017-07-28 22:40:00+03	11700.00
5C10AA	2017-08-07 18:05:00+03	64800.00
5C10AE	2017-07-23 23:39:00+03	70500.00
5C10D1	2017-07-28 01:04:00+03	83200.00
5C112A	2017-07-01 09:38:00+03	22000.00
5C1229	2017-07-09 01:45:00+03	12600.00
5C127D	2017-07-26 12:42:00+03	101200.00
5C1284	2017-07-31 04:05:00+03	27300.00
5C12A6	2017-07-02 19:47:00+03	55800.00
5C1311	2017-07-05 15:36:00+03	108900.00
5C1333	2017-08-09 22:07:00+03	28000.00
5C1393	2017-07-11 12:24:00+03	29600.00
5C13A2	2017-08-03 09:26:00+03	66000.00
5C1445	2017-07-21 07:54:00+03	184300.00
5C148B	2017-07-09 10:32:00+03	136000.00
5C14ED	2017-07-31 19:58:00+03	114800.00
5C14FE	2017-07-15 16:12:00+03	131100.00
5C1527	2017-08-05 00:36:00+03	47100.00
5C153C	2017-08-03 03:33:00+03	58400.00
5C15CA	2017-07-26 00:06:00+03	29800.00
5C1609	2017-07-30 02:25:00+03	67600.00
5C164F	2017-08-12 11:34:00+03	21800.00
5C169C	2017-08-14 09:49:00+03	24600.00
5C1705	2017-07-07 16:44:00+03	24400.00
5C171A	2017-08-08 04:03:00+03	23600.00
5C1788	2017-07-02 21:08:00+03	44700.00
5C178A	2017-08-12 15:54:00+03	116500.00
5C178B	2017-08-10 18:59:00+03	49400.00
5C17A9	2017-07-02 05:12:00+03	6700.00
5C17E5	2017-08-05 03:40:00+03	139200.00
5C1808	2017-07-15 20:24:00+03	8000.00
5C1810	2017-07-12 21:37:00+03	60700.00
5C1834	2017-07-06 08:42:00+03	28000.00
5C18B0	2017-07-11 07:09:00+03	41300.00
5C18EF	2017-08-09 19:48:00+03	66600.00
5C18FA	2017-07-12 15:42:00+03	295400.00
5C194E	2017-07-13 21:03:00+03	49100.00
5C1991	2017-08-06 03:24:00+03	23200.00
5C19BE	2017-08-08 02:21:00+03	48500.00
5C1ABA	2017-08-01 22:56:00+03	9000.00
5C1AC0	2017-07-31 10:35:00+03	25200.00
5C1B0D	2017-07-16 15:15:00+03	28000.00
5C1B18	2017-08-06 14:06:00+03	82200.00
5C1B2D	2017-07-18 12:11:00+03	134400.00
5C1B32	2017-07-23 13:37:00+03	61800.00
5C1B56	2017-07-14 07:36:00+03	99300.00
5C1B73	2017-08-01 09:37:00+03	43900.00
5C1B8C	2017-07-14 22:11:00+03	86300.00
5C1C13	2017-07-19 15:46:00+03	28000.00
5C1C62	2017-07-15 04:55:00+03	260300.00
5C1C6C	2017-08-10 22:56:00+03	56100.00
5C1CA3	2017-07-14 14:38:00+03	261500.00
5C1CC3	2017-08-09 11:33:00+03	115000.00
5C1DA2	2017-08-06 14:54:00+03	28000.00
5C1DAB	2017-07-12 21:13:00+03	47000.00
5C1DE4	2017-07-07 08:23:00+03	101200.00
5C1E60	2017-08-10 16:55:00+03	134900.00
5C1E66	2017-07-04 10:12:00+03	66200.00
5C1E8F	2017-07-26 18:03:00+03	55800.00
5C1ECD	2017-07-11 09:55:00+03	123000.00
5C1ECF	2017-07-16 20:35:00+03	28800.00
5C1EDD	2017-07-20 18:29:00+03	246000.00
5C1EE4	2017-08-08 02:21:00+03	177000.00
5C2079	2017-08-15 13:34:00+03	88600.00
5C20A8	2017-07-12 09:15:00+03	22000.00
5C20EA	2017-06-28 20:15:00+03	37900.00
5C20FF	2017-08-01 03:00:00+03	42800.00
5C2142	2017-08-02 06:59:00+03	32200.00
5C2147	2017-08-02 19:09:00+03	85000.00
5C2159	2017-08-13 20:29:00+03	173900.00
5C2160	2017-08-06 20:19:00+03	11000.00
5C2178	2017-07-07 20:25:00+03	190400.00
5C2189	2017-07-10 19:10:00+03	132800.00
5C21C7	2017-07-20 14:38:00+03	149700.00
5C21D0	2017-07-31 07:52:00+03	46400.00
5C21DB	2017-07-19 13:57:00+03	46400.00
5C2275	2017-07-16 12:25:00+03	197000.00
5C2290	2017-07-01 09:35:00+03	135600.00
5C22BE	2017-07-22 23:15:00+03	6000.00
5C22D1	2017-08-01 13:01:00+03	58000.00
5C22F2	2017-07-07 21:39:00+03	36800.00
5C22FE	2017-07-13 08:46:00+03	81300.00
5C2365	2017-07-02 00:58:00+03	27800.00
5C2380	2017-07-16 14:26:00+03	166100.00
5C23B9	2017-08-15 05:54:00+03	167400.00
5C23DA	2017-06-28 20:38:00+03	25600.00
5C24E4	2017-08-06 02:05:00+03	13400.00
5C251D	2017-07-12 12:07:00+03	32400.00
5C2573	2017-07-11 00:38:00+03	26000.00
5C25D4	2017-07-24 10:19:00+03	37900.00
5C2627	2017-07-03 02:43:00+03	32700.00
5C2698	2017-07-11 16:43:00+03	31800.00
5C2742	2017-07-26 20:32:00+03	48100.00
5C277E	2017-07-13 06:02:00+03	124200.00
5C27D4	2017-08-07 12:04:00+03	28800.00
5C2864	2017-07-22 12:04:00+03	54000.00
5C2894	2017-07-11 21:11:00+03	84200.00
5C28AD	2017-07-03 14:12:00+03	38200.00
5C28C4	2017-07-12 08:42:00+03	44500.00
5C28C5	2017-07-18 04:53:00+03	54800.00
5C2902	2017-07-30 21:36:00+03	85000.00
5C2914	2017-08-12 21:14:00+03	10600.00
5C295E	2017-07-13 01:31:00+03	69500.00
5C2964	2017-07-24 21:18:00+03	49800.00
5C2977	2017-07-13 01:25:00+03	35800.00
5C2979	2017-08-05 19:58:00+03	41800.00
5C2980	2017-07-23 16:03:00+03	265700.00
5C2995	2017-08-08 03:55:00+03	236800.00
5C29BE	2017-08-04 11:13:00+03	56000.00
5C29DF	2017-08-14 07:00:00+03	23900.00
5C29F9	2017-07-17 22:41:00+03	16400.00
5C2AD2	2017-07-16 03:28:00+03	89600.00
5C2AE7	2017-07-24 06:18:00+03	67600.00
5C2B40	2017-07-29 14:01:00+03	67200.00
5C2BB1	2017-08-15 08:12:00+03	111000.00
5C2BFC	2017-07-07 16:25:00+03	189100.00
5C2C00	2017-07-05 14:10:00+03	39500.00
5C2C1D	2017-07-16 15:27:00+03	72300.00
5C2C64	2017-08-08 04:28:00+03	280400.00
5C2C69	2017-07-27 21:49:00+03	32700.00
5C2CB2	2017-07-17 14:06:00+03	26800.00
5C2CF9	2017-07-07 19:59:00+03	75300.00
5C2CFF	2017-07-16 04:11:00+03	257600.00
5C2D0D	2017-07-23 17:40:00+03	226800.00
5C2D12	2017-07-22 15:46:00+03	13800.00
5C2D1C	2017-07-03 21:54:00+03	58000.00
5C2D4C	2017-08-05 16:06:00+03	136800.00
5C2D7B	2017-07-07 23:40:00+03	27000.00
5C2DAA	2017-08-15 07:29:00+03	125200.00
5C2DDE	2017-07-18 12:15:00+03	70800.00
5C2E0B	2017-08-14 11:27:00+03	66600.00
5C2E7C	2017-08-03 20:58:00+03	12600.00
5C2E8A	2017-08-15 14:13:00+03	14400.00
5C2F07	2017-07-04 13:40:00+03	28800.00
5C2F2A	2017-06-29 08:16:00+03	55800.00
5C2F43	2017-08-14 22:25:00+03	7400.00
5C305E	2017-08-10 09:01:00+03	59800.00
5C3091	2017-07-09 01:13:00+03	81100.00
5C30AC	2017-08-15 12:28:00+03	6600.00
5C3165	2017-07-20 17:55:00+03	16400.00
5C3168	2017-07-31 06:31:00+03	28600.00
5C31BF	2017-06-28 09:10:00+03	46300.00
5C322F	2017-08-02 04:15:00+03	53400.00
5C323E	2017-07-31 00:36:00+03	92600.00
5C32AD	2017-07-09 18:48:00+03	93900.00
5C3306	2017-08-12 15:16:00+03	13400.00
5C3309	2017-07-13 07:51:00+03	95700.00
5C332B	2017-07-18 15:24:00+03	14900.00
5C3385	2017-08-08 07:50:00+03	27200.00
5C33B4	2017-07-09 20:53:00+03	21800.00
5C33B9	2017-08-08 06:25:00+03	130400.00
5C33DE	2017-07-03 04:58:00+03	42400.00
5C3434	2017-07-27 12:11:00+03	27900.00
5C3468	2017-07-03 14:42:00+03	124200.00
5C34A7	2017-07-25 09:40:00+03	369000.00
5C34B4	2017-08-15 16:27:00+03	92600.00
5C34CF	2017-07-08 19:53:00+03	56000.00
5C35F1	2017-07-29 17:46:00+03	30900.00
5C360B	2017-07-15 17:53:00+03	183100.00
5C370B	2017-07-26 18:49:00+03	134400.00
5C3722	2017-07-12 17:31:00+03	12600.00
5C378D	2017-07-03 18:25:00+03	58800.00
5C37F2	2017-07-03 15:37:00+03	76400.00
5C3824	2017-07-12 02:53:00+03	111600.00
5C385A	2017-07-13 09:20:00+03	8200.00
5C3882	2017-08-10 01:26:00+03	86800.00
5C38C8	2017-07-05 09:11:00+03	67400.00
5C38F7	2017-07-21 04:53:00+03	46000.00
5C3958	2017-07-13 07:44:00+03	30400.00
5C3996	2017-07-31 06:08:00+03	42800.00
5C39AF	2017-08-11 20:53:00+03	46400.00
5C3A1C	2017-07-07 10:54:00+03	50800.00
5C3A35	2017-08-09 23:27:00+03	58400.00
5C3A95	2017-08-09 17:55:00+03	101200.00
5C3B1B	2017-07-19 01:38:00+03	34000.00
5C3B27	2017-07-24 17:52:00+03	55800.00
5C3B6E	2017-07-28 13:55:00+03	10800.00
5C3C24	2017-07-17 11:22:00+03	95200.00
5C3D15	2017-06-30 19:42:00+03	44000.00
5C3D43	2017-07-12 05:13:00+03	166100.00
5C3D54	2017-08-06 05:30:00+03	6700.00
5C3D62	2017-07-18 12:55:00+03	103800.00
5C3D7B	2017-07-06 08:25:00+03	298600.00
5C3E24	2017-07-06 17:32:00+03	46900.00
5C3E5F	2017-07-17 20:06:00+03	111600.00
5C3E8A	2017-07-19 09:37:00+03	153900.00
5C3EF6	2017-07-04 05:58:00+03	161800.00
5C3EFE	2017-07-19 20:44:00+03	28000.00
5C3F19	2017-08-05 23:26:00+03	23200.00
5C3F20	2017-07-13 02:47:00+03	79800.00
5C3F24	2017-07-28 17:46:00+03	86500.00
5C3F83	2017-07-09 02:39:00+03	59800.00
5C402A	2017-08-03 05:10:00+03	37200.00
5C4054	2017-07-10 19:07:00+03	99200.00
5C410E	2017-08-04 04:51:00+03	47200.00
5C4110	2017-07-31 07:53:00+03	202600.00
5C412C	2017-07-26 11:06:00+03	58600.00
5C4182	2017-08-08 09:47:00+03	112000.00
5C4250	2017-08-07 14:34:00+03	318800.00
5C4285	2017-08-01 01:45:00+03	120000.00
5C42B4	2017-07-19 10:47:00+03	39800.00
5C42CE	2017-08-06 23:22:00+03	23400.00
5C42D9	2017-07-06 16:13:00+03	7400.00
5C4314	2017-07-08 01:49:00+03	45400.00
5C432F	2017-08-07 05:51:00+03	22000.00
5C4334	2017-07-19 15:58:00+03	24000.00
5C4365	2017-07-21 17:25:00+03	16400.00
5C43AE	2017-07-20 12:01:00+03	99300.00
5C43BD	2017-07-01 14:42:00+03	64400.00
5C43DB	2017-07-03 16:10:00+03	432600.00
5C43EB	2017-08-08 05:50:00+03	142800.00
5C43F0	2017-07-31 07:21:00+03	189700.00
5C4428	2017-07-05 14:19:00+03	108600.00
5C443A	2017-08-12 14:46:00+03	44800.00
5C44D6	2017-08-06 12:59:00+03	14400.00
5C44EE	2017-07-17 15:32:00+03	50000.00
5C457A	2017-07-23 05:58:00+03	391800.00
5C45E2	2017-07-24 03:35:00+03	28000.00
5C460D	2017-07-23 23:03:00+03	185300.00
5C461A	2017-07-16 04:32:00+03	46200.00
5C4667	2017-07-03 03:26:00+03	57600.00
5C4722	2017-08-14 13:07:00+03	92900.00
5C474A	2017-08-09 07:20:00+03	34000.00
5C4752	2017-07-13 17:07:00+03	59200.00
5C4757	2017-07-21 12:10:00+03	70700.00
5C47AB	2017-07-25 08:06:00+03	58400.00
5C47F3	2017-08-13 18:35:00+03	6000.00
5C482F	2017-08-07 10:12:00+03	12600.00
5C48CB	2017-07-20 01:19:00+03	65500.00
5C48F3	2017-08-05 11:49:00+03	84500.00
5C4911	2017-07-23 15:10:00+03	8400.00
5C4939	2017-07-29 01:54:00+03	25400.00
5C4953	2017-08-11 10:15:00+03	41600.00
5C4996	2017-07-16 04:24:00+03	214900.00
5C49FF	2017-07-19 16:09:00+03	58900.00
5C4A4E	2017-07-19 02:11:00+03	229600.00
5C4B37	2017-07-17 22:34:00+03	117200.00
5C4B48	2017-07-12 16:20:00+03	105000.00
5C4B54	2017-07-02 06:50:00+03	40100.00
5C4B5B	2017-07-25 17:31:00+03	99200.00
5C4B77	2017-07-04 00:34:00+03	46400.00
5C4B9E	2017-08-11 09:42:00+03	246000.00
5C4BAE	2017-08-12 12:26:00+03	135400.00
5C4C51	2017-08-03 16:35:00+03	14100.00
5C4CA2	2017-07-29 03:13:00+03	62600.00
5C4D03	2017-07-11 07:44:00+03	20400.00
5C4D80	2017-07-30 20:08:00+03	15000.00
5C4D8A	2017-07-17 16:04:00+03	35900.00
5C4E33	2017-06-26 21:54:00+03	150600.00
5C4E67	2017-07-24 00:40:00+03	27200.00
5C4F1B	2017-07-30 15:27:00+03	60400.00
5C4F31	2017-08-11 06:48:00+03	78300.00
5C4F48	2017-07-27 23:57:00+03	96600.00
5C4FB4	2017-07-01 08:35:00+03	75600.00
5C5020	2017-07-17 20:34:00+03	13000.00
5C5029	2017-08-07 01:14:00+03	46400.00
5C5106	2017-08-06 18:16:00+03	12600.00
5C511B	2017-07-06 23:37:00+03	47100.00
5C5176	2017-07-20 16:02:00+03	106400.00
5C51BD	2017-08-12 21:45:00+03	58700.00
5C51D3	2017-07-20 10:33:00+03	139200.00
5C51E8	2017-08-07 02:48:00+03	24600.00
5C521D	2017-07-06 17:58:00+03	124200.00
5C5231	2017-07-20 03:41:00+03	90600.00
5C5244	2017-08-09 00:53:00+03	273400.00
5C5292	2017-07-05 22:13:00+03	21800.00
5C52C6	2017-07-26 04:47:00+03	33300.00
5C5342	2017-07-13 15:05:00+03	49400.00
5C53BF	2017-08-03 13:29:00+03	21200.00
5C53D0	2017-08-14 14:01:00+03	36200.00
5C54AE	2017-07-19 01:12:00+03	59800.00
5C5500	2017-07-05 22:46:00+03	25200.00
5C5506	2017-08-01 04:52:00+03	85500.00
5C5532	2017-07-08 03:18:00+03	143600.00
5C5562	2017-08-10 21:53:00+03	61900.00
5C5571	2017-07-17 06:59:00+03	26000.00
5C55D8	2017-08-09 20:45:00+03	43200.00
5C55FA	2017-07-08 00:02:00+03	103800.00
5C5642	2017-08-11 02:27:00+03	56000.00
5C56C3	2017-08-03 21:40:00+03	28800.00
5C56F1	2017-07-29 05:33:00+03	23900.00
5C5701	2017-07-12 13:49:00+03	56000.00
5C5714	2017-07-09 10:48:00+03	55800.00
5C5729	2017-08-14 17:16:00+03	73300.00
5C573A	2017-07-23 04:13:00+03	94000.00
5C57F5	2017-08-08 22:45:00+03	48800.00
5C582E	2017-08-04 01:14:00+03	58000.00
5C5853	2017-07-21 15:15:00+03	103800.00
5C589B	2017-06-30 13:36:00+03	73600.00
5C58A3	2017-07-03 04:19:00+03	270400.00
5C58CD	2017-07-07 14:45:00+03	56000.00
5C5989	2017-08-09 16:25:00+03	51600.00
5C59EA	2017-07-26 12:49:00+03	20400.00
5C5A13	2017-07-26 03:13:00+03	182300.00
5C5A7D	2017-07-12 20:42:00+03	26200.00
5C5A94	2017-07-23 21:48:00+03	33800.00
5C5B0F	2017-08-05 02:14:00+03	75300.00
5C5B48	2017-08-04 23:46:00+03	13400.00
5C5B67	2017-08-15 13:38:00+03	12000.00
5C5BB1	2017-07-22 11:02:00+03	47700.00
5C5BCC	2017-07-01 17:29:00+03	55500.00
5C5C25	2017-07-10 00:14:00+03	112000.00
5C5C46	2017-08-01 11:49:00+03	131100.00
5C5C9B	2017-07-31 02:30:00+03	531400.00
5C5D35	2017-08-10 04:02:00+03	15100.00
5C5D44	2017-07-24 22:28:00+03	47200.00
5C5D6D	2017-07-16 18:17:00+03	24400.00
5C5D81	2017-07-27 08:06:00+03	23200.00
5C5DBC	2017-07-13 11:27:00+03	46900.00
5C5E46	2017-07-19 20:40:00+03	24600.00
5C5EDA	2017-07-31 09:28:00+03	28800.00
5C5F07	2017-07-11 18:19:00+03	55800.00
5C5F08	2017-08-06 12:26:00+03	24800.00
5C5F3B	2017-08-02 07:52:00+03	86300.00
5C5FE8	2017-08-02 15:22:00+03	132500.00
5C5FF2	2017-07-22 19:26:00+03	44000.00
5C60B3	2017-08-10 08:09:00+03	70700.00
5C612C	2017-07-12 23:57:00+03	60700.00
5C6145	2017-07-15 06:48:00+03	25000.00
5C6158	2017-08-06 13:17:00+03	167400.00
5C615D	2017-07-27 21:29:00+03	70200.00
5C6160	2017-07-08 07:45:00+03	64700.00
5C61AA	2017-07-19 09:37:00+03	73500.00
5C61EC	2017-07-27 08:38:00+03	56000.00
5C6247	2017-08-02 07:12:00+03	55800.00
5C6263	2017-07-10 23:37:00+03	46500.00
5C62A4	2017-07-13 00:47:00+03	103400.00
5C634F	2017-07-13 01:05:00+03	69500.00
5C6351	2017-07-17 05:53:00+03	151200.00
5C638F	2017-07-09 13:25:00+03	67400.00
5C6452	2017-08-12 17:11:00+03	66600.00
5C64A7	2017-07-01 14:52:00+03	46300.00
5C64B5	2017-08-05 23:40:00+03	40000.00
5C64CE	2017-08-06 08:45:00+03	94000.00
5C64EE	2017-07-22 22:00:00+03	61800.00
5C6503	2017-07-18 08:01:00+03	117600.00
5C6507	2017-08-03 11:22:00+03	6000.00
5C650A	2017-07-28 22:31:00+03	59300.00
5C6584	2017-07-27 11:56:00+03	139100.00
5C65FE	2017-08-13 12:59:00+03	24400.00
5C6653	2017-07-23 07:05:00+03	71000.00
5C66D5	2017-07-08 13:30:00+03	99200.00
5C6727	2017-08-10 07:00:00+03	131600.00
5C6760	2017-08-12 08:39:00+03	27800.00
5C67C8	2017-08-11 20:40:00+03	94000.00
5C67F6	2017-08-11 02:46:00+03	92700.00
5C681B	2017-07-07 21:51:00+03	92800.00
5C6823	2017-07-07 11:04:00+03	81300.00
5C6851	2017-07-13 00:05:00+03	48700.00
5C6876	2017-08-10 11:13:00+03	38600.00
5C68D7	2017-07-26 19:38:00+03	20400.00
5C68ED	2017-07-12 01:51:00+03	12600.00
5C6902	2017-08-07 18:38:00+03	40800.00
5C696C	2017-08-03 04:59:00+03	90800.00
5C6A4B	2017-08-02 03:30:00+03	128800.00
5C6A57	2017-07-05 15:53:00+03	229900.00
5C6A70	2017-08-15 12:58:00+03	45500.00
5C6B0E	2017-07-29 22:07:00+03	49100.00
5C6C3F	2017-08-03 04:46:00+03	39700.00
5C6C70	2017-08-15 10:05:00+03	46700.00
5C6C7C	2017-07-27 11:27:00+03	41800.00
5C6C87	2017-08-05 14:38:00+03	28800.00
5C6CD3	2017-07-21 00:44:00+03	12600.00
5C6D07	2017-07-15 13:15:00+03	34000.00
5C6D2C	2017-07-21 05:35:00+03	126300.00
5C6D33	2017-08-08 00:59:00+03	43900.00
5C6D7C	2017-08-14 02:06:00+03	57400.00
5C6DA5	2017-08-14 23:28:00+03	154400.00
5C6DC2	2017-06-27 17:33:00+03	66000.00
5C6DC6	2017-08-15 10:55:00+03	50100.00
5C6EB0	2017-08-03 13:04:00+03	37100.00
5C6EC0	2017-07-05 02:52:00+03	66800.00
5C6F2C	2017-07-09 08:43:00+03	133100.00
5C6F5B	2017-08-06 05:10:00+03	28000.00
5C6F7C	2017-07-31 22:39:00+03	58900.00
5C6F97	2017-07-28 00:22:00+03	111200.00
5C6FB0	2017-08-04 17:26:00+03	133900.00
5C6FFB	2017-07-10 14:35:00+03	28000.00
5C700D	2017-07-14 23:09:00+03	36200.00
5C7057	2017-08-09 18:55:00+03	24600.00
5C70AB	2017-07-24 19:56:00+03	44000.00
5C70DC	2017-07-05 02:23:00+03	98300.00
5C7116	2017-07-19 11:52:00+03	131100.00
5C717F	2017-08-15 15:35:00+03	87800.00
5C7207	2017-07-17 06:48:00+03	43100.00
5C722B	2017-08-01 17:49:00+03	58700.00
5C7243	2017-08-09 14:45:00+03	23600.00
5C7265	2017-07-07 01:38:00+03	56000.00
5C72AB	2017-08-04 04:28:00+03	134600.00
5C7333	2017-07-11 22:30:00+03	516800.00
5C7338	2017-07-01 12:52:00+03	113600.00
5C739B	2017-07-21 05:20:00+03	10800.00
5C73A8	2017-07-05 17:52:00+03	112000.00
5C73AB	2017-08-11 03:37:00+03	83500.00
5C7425	2017-07-02 03:41:00+03	184000.00
5C7448	2017-07-20 23:47:00+03	66000.00
5C7472	2017-07-12 11:00:00+03	7400.00
5C7491	2017-08-15 12:59:00+03	55800.00
5C74A0	2017-06-30 14:59:00+03	99300.00
5C74C1	2017-08-14 04:15:00+03	16400.00
5C7502	2017-07-30 18:45:00+03	138600.00
5C752C	2017-07-01 16:26:00+03	14000.00
5C7543	2017-08-04 09:24:00+03	54800.00
5C7572	2017-07-31 04:50:00+03	31400.00
5C75A7	2017-07-11 05:00:00+03	139400.00
5C75EC	2017-07-14 11:46:00+03	103500.00
5C7614	2017-07-28 11:55:00+03	246000.00
5C76BC	2017-08-05 23:31:00+03	22000.00
5C76FE	2017-07-02 07:10:00+03	135400.00
5C7740	2017-07-20 09:14:00+03	107200.00
5C7790	2017-08-05 11:41:00+03	20200.00
5C7796	2017-07-29 00:37:00+03	45200.00
5C782A	2017-08-10 12:29:00+03	23600.00
5C787A	2017-07-30 18:50:00+03	13600.00
5C787E	2017-08-13 10:55:00+03	184300.00
5C7972	2017-07-03 00:16:00+03	25100.00
5C7B25	2017-08-05 11:52:00+03	72400.00
5C7B37	2017-08-08 16:12:00+03	57500.00
5C7B44	2017-07-04 02:59:00+03	108300.00
5C7B6D	2017-07-08 02:06:00+03	32800.00
5C7BA6	2017-07-12 12:54:00+03	137600.00
5C7BEB	2017-08-03 10:14:00+03	66600.00
5C7C3A	2017-07-24 01:20:00+03	115600.00
5C7C78	2017-07-25 03:29:00+03	84100.00
5C7CC8	2017-07-14 02:23:00+03	44300.00
5C7CDD	2017-07-13 02:43:00+03	223200.00
5C7D88	2017-08-14 13:03:00+03	88800.00
5C7E96	2017-08-08 20:11:00+03	56400.00
5C7F0D	2017-07-06 15:01:00+03	14800.00
5C7F0F	2017-07-20 07:55:00+03	76600.00
5C7F83	2017-08-13 07:08:00+03	47100.00
5C7FEC	2017-07-08 04:32:00+03	53400.00
5C801F	2017-07-05 16:10:00+03	43900.00
5C8058	2017-07-15 02:30:00+03	30200.00
5C806A	2017-08-14 17:34:00+03	47100.00
5C8085	2017-07-16 22:51:00+03	34000.00
5C80C1	2017-07-14 09:50:00+03	52000.00
5C80D5	2017-07-10 20:42:00+03	53800.00
5C80E5	2017-08-08 03:46:00+03	112000.00
5C8177	2017-07-15 19:48:00+03	170000.00
5C821F	2017-08-12 00:17:00+03	123600.00
5C8235	2017-07-06 23:49:00+03	174600.00
5C827E	2017-07-07 20:13:00+03	97800.00
5C82B4	2017-08-10 20:11:00+03	288400.00
5C82DD	2017-08-08 13:20:00+03	18000.00
5C8335	2017-07-28 20:02:00+03	28000.00
5C83A2	2017-07-03 20:30:00+03	81200.00
5C83B0	2017-08-11 12:40:00+03	38800.00
5C84CB	2017-07-29 00:33:00+03	94200.00
5C8556	2017-07-30 00:13:00+03	55800.00
5C8581	2017-07-15 07:43:00+03	122000.00
5C8582	2017-08-14 21:28:00+03	64100.00
5C85F7	2017-08-13 04:06:00+03	115100.00
5C8606	2017-08-15 09:19:00+03	12600.00
5C8659	2017-07-12 12:47:00+03	32400.00
5C86AD	2017-07-18 17:44:00+03	119000.00
5C86C6	2017-07-09 20:11:00+03	44800.00
5C86DF	2017-07-08 19:30:00+03	189700.00
5C8724	2017-08-14 14:55:00+03	369000.00
5C8734	2017-08-13 19:07:00+03	26800.00
5C874B	2017-07-10 13:45:00+03	44500.00
5C8773	2017-08-02 13:19:00+03	28800.00
5C8819	2017-08-08 03:45:00+03	38400.00
5C8850	2017-08-03 17:33:00+03	34000.00
5C8870	2017-08-07 03:51:00+03	56000.00
5C8906	2017-07-03 09:16:00+03	119500.00
5C890A	2017-07-21 15:09:00+03	111600.00
5C893B	2017-08-10 14:29:00+03	60700.00
5C8969	2017-08-02 02:48:00+03	24700.00
5C8980	2017-08-08 20:27:00+03	23600.00
5C8A56	2017-07-02 05:50:00+03	21400.00
5C8A6C	2017-08-06 17:27:00+03	29300.00
5C8AD2	2017-08-11 05:02:00+03	147700.00
5C8AE5	2017-07-09 07:13:00+03	224600.00
5C8B9F	2017-08-01 20:36:00+03	122300.00
5C8BBF	2017-07-12 09:57:00+03	75300.00
5C8C41	2017-07-13 01:01:00+03	62600.00
5C8C42	2017-07-30 15:52:00+03	73500.00
5C8C8E	2017-07-18 00:54:00+03	32700.00
5C8D11	2017-07-31 20:26:00+03	182300.00
5C8D7C	2017-07-19 10:51:00+03	46200.00
5C8DBF	2017-07-21 19:05:00+03	79000.00
5C8DC0	2017-07-28 01:51:00+03	86800.00
5C8E68	2017-07-18 06:57:00+03	29600.00
5C8F27	2017-07-06 09:26:00+03	50600.00
5C8F59	2017-06-28 05:26:00+03	31600.00
5C8F92	2017-07-29 20:56:00+03	40000.00
5C90A5	2017-07-16 18:20:00+03	6000.00
5C90E2	2017-08-05 22:01:00+03	34000.00
5C910B	2017-06-27 18:34:00+03	47100.00
5C911F	2017-07-05 15:09:00+03	99300.00
5C9140	2017-08-09 01:03:00+03	6200.00
5C91C6	2017-07-09 17:13:00+03	23200.00
5C91E2	2017-08-12 23:36:00+03	15100.00
5C9205	2017-08-06 08:14:00+03	56600.00
5C921B	2017-08-04 23:40:00+03	67800.00
5C9257	2017-08-11 21:55:00+03	59300.00
5C9285	2017-07-01 15:38:00+03	59800.00
5C9287	2017-07-07 07:17:00+03	56000.00
5C9301	2017-07-16 04:05:00+03	71600.00
5C930D	2017-07-05 01:06:00+03	32800.00
5C9311	2017-08-08 13:19:00+03	111700.00
5C9343	2017-07-24 11:26:00+03	6000.00
5C93DD	2017-08-04 02:13:00+03	12600.00
5C93DF	2017-07-02 16:25:00+03	66600.00
5C93FB	2017-07-06 07:45:00+03	226200.00
5C93FC	2017-08-14 03:02:00+03	82900.00
5C9433	2017-07-31 14:47:00+03	92300.00
5C94B1	2017-07-01 18:54:00+03	12400.00
5C9507	2017-07-06 22:24:00+03	56600.00
5C9519	2017-08-08 21:01:00+03	62000.00
5C9555	2017-07-19 17:00:00+03	35200.00
5C9558	2017-07-20 14:50:00+03	45100.00
5C9576	2017-08-14 11:27:00+03	274300.00
5C9612	2017-07-31 20:49:00+03	23200.00
5C965F	2017-06-30 09:53:00+03	140200.00
5C9660	2017-07-22 00:26:00+03	28800.00
5C9674	2017-08-01 04:15:00+03	92400.00
5C9697	2017-07-05 22:08:00+03	67200.00
5C96BC	2017-08-10 06:22:00+03	28800.00
5C96DF	2017-07-23 15:03:00+03	69000.00
5C96F8	2017-08-08 15:04:00+03	76600.00
5C9734	2017-07-21 03:51:00+03	64400.00
5C9773	2017-08-14 12:17:00+03	60800.00
5C97C5	2017-07-05 16:50:00+03	28800.00
5C97CC	2017-07-21 18:25:00+03	73600.00
5C97D0	2017-08-11 17:34:00+03	35600.00
5C97D2	2017-07-02 06:55:00+03	75300.00
5C97F8	2017-08-08 07:52:00+03	187600.00
5C9815	2017-08-02 06:16:00+03	285100.00
5C985E	2017-07-19 01:16:00+03	7400.00
5C988F	2017-07-19 10:26:00+03	23200.00
5C9912	2017-07-15 10:23:00+03	40300.00
5C99AE	2017-06-30 12:53:00+03	87900.00
5C9A4E	2017-06-30 20:26:00+03	112000.00
5C9A63	2017-07-20 19:10:00+03	66000.00
5C9A8C	2017-07-05 23:30:00+03	23600.00
5C9ABD	2017-07-18 19:02:00+03	177200.00
5C9AD7	2017-07-25 13:26:00+03	73600.00
5C9AEE	2017-07-25 02:08:00+03	44800.00
5C9AFD	2017-08-05 18:47:00+03	21400.00
5C9B54	2017-07-23 11:19:00+03	7400.00
5C9B6D	2017-08-14 09:41:00+03	15000.00
5C9B99	2017-08-03 15:38:00+03	123000.00
5C9C11	2017-08-09 07:14:00+03	31600.00
5C9CDE	2017-07-14 00:24:00+03	88600.00
5C9CEE	2017-08-11 10:47:00+03	66100.00
5C9D22	2017-08-04 16:21:00+03	113700.00
5C9D25	2017-07-28 12:50:00+03	48400.00
5C9D32	2017-07-19 03:02:00+03	93900.00
5C9D89	2017-07-17 22:44:00+03	28800.00
5C9E6F	2017-07-23 18:34:00+03	14800.00
5C9E8B	2017-07-20 13:35:00+03	266400.00
5C9EA3	2017-07-23 07:17:00+03	27200.00
5C9EC0	2017-07-22 13:06:00+03	6700.00
5C9ED7	2017-08-05 15:47:00+03	6800.00
5C9F0C	2017-08-04 03:14:00+03	47800.00
5C9F20	2017-08-11 04:33:00+03	22000.00
5C9F96	2017-07-10 17:33:00+03	61800.00
5C9FA9	2017-08-05 02:15:00+03	117600.00
5C9FAC	2017-07-23 21:19:00+03	121400.00
5C9FE3	2017-07-19 17:02:00+03	372000.00
5C9FE4	2017-07-08 16:49:00+03	229900.00
5C9FF8	2017-07-04 05:23:00+03	62000.00
5CA063	2017-08-06 06:14:00+03	27400.00
5CA088	2017-07-23 17:23:00+03	46000.00
5CA0D0	2017-08-01 02:42:00+03	66600.00
5CA11D	2017-08-01 17:53:00+03	123000.00
5CA149	2017-08-09 09:49:00+03	116700.00
5CA175	2017-08-14 04:43:00+03	58000.00
5CA177	2017-07-26 16:50:00+03	33400.00
5CA18D	2017-08-05 22:47:00+03	26000.00
5CA18F	2017-08-01 10:17:00+03	23900.00
5CA1A4	2017-08-09 23:27:00+03	191600.00
5CA1B7	2017-07-25 07:09:00+03	71900.00
5CA1ED	2017-08-07 10:05:00+03	40200.00
5CA1F2	2017-08-03 21:28:00+03	155600.00
5CA27F	2017-08-11 06:18:00+03	190100.00
5CA2DD	2017-07-16 06:26:00+03	34400.00
5CA34F	2017-08-15 16:53:00+03	110300.00
5CA363	2017-07-21 14:36:00+03	135400.00
5CA394	2017-08-03 03:39:00+03	138200.00
5CA43F	2017-07-03 03:53:00+03	123000.00
5CA497	2017-07-27 13:31:00+03	68000.00
5CA4A0	2017-07-17 17:32:00+03	55800.00
5CA4F2	2017-07-14 08:50:00+03	125000.00
5CA526	2017-08-04 05:34:00+03	27300.00
5CA55E	2017-08-03 22:20:00+03	20200.00
5CA566	2017-07-18 21:28:00+03	92100.00
5CA584	2017-07-11 20:25:00+03	45400.00
5CA5A3	2017-07-06 14:47:00+03	74800.00
5CA5DA	2017-08-06 20:48:00+03	147000.00
5CA609	2017-07-31 18:53:00+03	108300.00
5CA64B	2017-08-07 14:22:00+03	80800.00
5CA6F0	2017-07-12 10:22:00+03	56100.00
5CA720	2017-08-01 18:26:00+03	21400.00
5CA73D	2017-08-07 12:02:00+03	28000.00
5CA74B	2017-08-10 10:56:00+03	26000.00
5CA7C9	2017-08-02 02:15:00+03	21400.00
5CA7CF	2017-08-15 09:48:00+03	147700.00
5CA83A	2017-08-06 09:17:00+03	40400.00
5CA86D	2017-07-31 17:19:00+03	248500.00
5CA88E	2017-06-30 14:36:00+03	93600.00
5CA8A9	2017-07-05 19:24:00+03	20000.00
5CA8D5	2017-07-11 18:31:00+03	167400.00
5CA919	2017-07-06 06:39:00+03	12000.00
5CA94C	2017-07-23 19:27:00+03	123000.00
5CA95C	2017-08-15 08:42:00+03	44800.00
5CA999	2017-07-03 22:47:00+03	164600.00
5CA9A2	2017-07-17 07:29:00+03	28800.00
5CA9F4	2017-07-15 23:59:00+03	35200.00
5CA9FC	2017-07-06 22:54:00+03	143200.00
5CAA29	2017-08-07 08:22:00+03	57500.00
5CAAC8	2017-07-26 06:58:00+03	28000.00
5CAB13	2017-06-29 11:25:00+03	13400.00
5CAB5A	2017-07-09 07:27:00+03	15700.00
5CABD4	2017-07-19 04:38:00+03	52300.00
5CAC04	2017-08-05 03:10:00+03	86300.00
5CACA0	2017-07-07 18:08:00+03	26800.00
5CACDE	2017-08-12 11:57:00+03	21400.00
5CAD33	2017-07-24 09:07:00+03	167400.00
5CAD3E	2017-07-15 11:33:00+03	43100.00
5CAD57	2017-08-13 04:57:00+03	70500.00
5CADFC	2017-08-06 07:52:00+03	271100.00
5CAEF3	2017-08-14 12:23:00+03	73500.00
5CAF4F	2017-07-28 07:56:00+03	112600.00
5CAFED	2017-07-10 10:43:00+03	141600.00
5CB023	2017-07-27 23:55:00+03	91600.00
5CB04A	2017-07-14 23:40:00+03	13700.00
5CB053	2017-07-12 01:13:00+03	23600.00
5CB131	2017-08-12 12:34:00+03	56000.00
5CB13C	2017-08-14 18:25:00+03	33100.00
5CB1F3	2017-07-09 16:59:00+03	77000.00
5CB20A	2017-08-04 01:33:00+03	101900.00
5CB211	2017-07-03 13:35:00+03	68800.00
5CB215	2017-08-03 15:32:00+03	178800.00
5CB22F	2017-07-29 16:02:00+03	19600.00
5CB292	2017-07-04 05:16:00+03	134400.00
5CB294	2017-08-05 01:03:00+03	246000.00
5CB2BD	2017-07-07 22:47:00+03	100000.00
5CB2D3	2017-06-27 19:39:00+03	26000.00
5CB2EF	2017-07-17 16:19:00+03	56000.00
5CB30D	2017-07-22 07:20:00+03	160400.00
5CB31A	2017-08-06 17:44:00+03	38600.00
5CB338	2017-08-10 09:55:00+03	67000.00
5CB384	2017-08-10 09:46:00+03	143100.00
5CB38D	2017-07-28 23:34:00+03	89700.00
5CB38F	2017-07-02 17:03:00+03	38200.00
5CB3A0	2017-07-27 08:24:00+03	66600.00
5CB3A5	2017-08-11 01:23:00+03	257600.00
5CB3D3	2017-08-10 07:07:00+03	88200.00
5CB401	2017-07-21 00:56:00+03	12600.00
5CB403	2017-08-03 04:35:00+03	71300.00
5CB458	2017-07-04 08:09:00+03	149300.00
5CB4D3	2017-07-10 01:25:00+03	86400.00
5CB4F8	2017-08-15 08:43:00+03	12600.00
5CB500	2017-07-26 13:10:00+03	46400.00
5CB516	2017-08-07 08:54:00+03	29600.00
5CB549	2017-07-28 16:14:00+03	23200.00
5CB576	2017-08-08 23:48:00+03	40000.00
5CB5DB	2017-07-12 22:03:00+03	48900.00
5CB641	2017-07-24 09:46:00+03	271100.00
5CB655	2017-07-29 14:20:00+03	115900.00
5CB662	2017-08-04 01:28:00+03	73600.00
5CB697	2017-07-11 22:16:00+03	24400.00
5CB69E	2017-07-07 19:18:00+03	184500.00
5CB6A8	2017-07-30 07:36:00+03	46300.00
5CB6BE	2017-06-29 01:24:00+03	37200.00
5CB6E6	2017-07-26 13:13:00+03	47000.00
5CB720	2017-07-19 20:03:00+03	250800.00
5CB75D	2017-07-27 23:01:00+03	128800.00
5CB837	2017-07-29 17:24:00+03	32200.00
5CB83D	2017-08-08 23:08:00+03	141600.00
5CB88B	2017-06-28 01:04:00+03	111600.00
5CB90D	2017-07-23 17:45:00+03	27900.00
5CB91C	2017-07-27 12:11:00+03	131100.00
5CB959	2017-08-13 21:45:00+03	35600.00
5CB967	2017-07-28 15:50:00+03	56600.00
5CB969	2017-07-11 18:30:00+03	16000.00
5CBA06	2017-07-20 22:12:00+03	31100.00
5CBAA0	2017-08-12 08:39:00+03	246000.00
5CBAC3	2017-06-28 10:38:00+03	35200.00
5CBAC5	2017-07-02 14:31:00+03	27400.00
5CBB07	2017-07-20 11:52:00+03	28000.00
5CBB48	2017-07-01 23:28:00+03	23200.00
5CBB64	2017-07-14 17:41:00+03	115700.00
5CBB6E	2017-07-06 21:05:00+03	33300.00
5CBBA8	2017-07-20 03:58:00+03	54300.00
5CBBE7	2017-07-16 12:17:00+03	200500.00
5CBC20	2017-08-15 12:25:00+03	56000.00
5CBC49	2017-07-20 22:16:00+03	57800.00
5CBC87	2017-08-10 00:19:00+03	26000.00
5CBCAA	2017-08-04 07:47:00+03	25000.00
5CBCC0	2017-08-08 06:18:00+03	241300.00
5CBD07	2017-08-10 10:44:00+03	38600.00
5CBD6D	2017-07-27 07:05:00+03	27400.00
5CBD80	2017-07-05 20:46:00+03	124200.00
5CBD93	2017-07-16 17:34:00+03	310600.00
5CBD9F	2017-07-10 20:23:00+03	170800.00
5CBDE8	2017-08-14 17:37:00+03	155500.00
5CBE38	2017-07-06 13:17:00+03	64500.00
5CBEBA	2017-07-16 07:27:00+03	36200.00
5CBEC3	2017-07-17 20:24:00+03	55800.00
5CBF2E	2017-08-07 20:59:00+03	131600.00
5CBF45	2017-08-15 03:31:00+03	38600.00
5CBF5A	2017-08-01 17:21:00+03	38400.00
5CBF81	2017-07-12 17:54:00+03	75600.00
5CBF94	2017-07-14 07:00:00+03	116400.00
5CC038	2017-07-20 14:42:00+03	44800.00
5CC0A6	2017-07-05 11:44:00+03	6800.00
5CC0AB	2017-08-13 01:04:00+03	23200.00
5CC101	2017-07-05 18:39:00+03	42100.00
5CC117	2017-08-02 05:47:00+03	56000.00
5CC15D	2017-07-09 04:53:00+03	67600.00
5CC1E4	2017-07-20 16:55:00+03	85000.00
5CC223	2017-08-15 09:19:00+03	67200.00
5CC297	2017-08-15 14:31:00+03	72300.00
5CC29E	2017-07-22 19:50:00+03	89600.00
5CC2D1	2017-07-24 15:34:00+03	46000.00
5CC2D2	2017-07-08 22:01:00+03	58600.00
5CC332	2017-07-17 18:11:00+03	12600.00
5CC3F0	2017-08-12 02:57:00+03	111600.00
5CC4AF	2017-08-11 02:20:00+03	40800.00
5CC51E	2017-08-06 15:50:00+03	29600.00
5CC571	2017-07-03 01:13:00+03	20200.00
5CC5DD	2017-07-12 16:49:00+03	76600.00
5CC5E9	2017-07-18 00:37:00+03	26000.00
5CC6B2	2017-07-08 19:48:00+03	134400.00
5CC6B7	2017-07-24 23:13:00+03	24400.00
5CC6BB	2017-07-09 20:38:00+03	18600.00
5CC6FD	2017-08-04 16:32:00+03	101500.00
5CC722	2017-07-25 05:10:00+03	14000.00
5CC730	2017-07-06 20:59:00+03	26800.00
5CC743	2017-07-31 01:20:00+03	24400.00
5CC75F	2017-08-04 08:46:00+03	132800.00
5CC872	2017-07-19 01:25:00+03	61000.00
5CC886	2017-08-03 08:24:00+03	16400.00
5CC88B	2017-08-12 08:45:00+03	30800.00
5CC99C	2017-07-31 17:18:00+03	79900.00
5CCA19	2017-07-04 06:46:00+03	18000.00
5CCA4A	2017-08-06 00:37:00+03	61800.00
5CCA73	2017-07-02 00:45:00+03	28000.00
5CCACE	2017-07-30 01:55:00+03	36200.00
5CCB07	2017-07-16 09:31:00+03	116900.00
5CCB26	2017-07-20 13:20:00+03	229900.00
5CCC03	2017-07-28 14:46:00+03	69500.00
5CCC2C	2017-08-11 14:19:00+03	128800.00
5CCC6B	2017-08-14 11:17:00+03	62900.00
5CCCAD	2017-07-16 09:53:00+03	150600.00
5CCD45	2017-08-01 11:10:00+03	23600.00
5CCD53	2017-07-07 00:58:00+03	289800.00
5CCDD8	2017-07-16 08:08:00+03	48800.00
5CCDDC	2017-08-04 17:11:00+03	92400.00
5CCE21	2017-06-28 12:15:00+03	56000.00
5CCE30	2017-07-05 13:52:00+03	6800.00
5CCE4B	2017-07-17 01:03:00+03	38200.00
5CCE90	2017-07-27 10:45:00+03	58600.00
5CCED5	2017-07-14 04:11:00+03	28300.00
5CCEFE	2017-07-19 01:23:00+03	26800.00
5CCF00	2017-07-11 23:50:00+03	38200.00
5CCF16	2017-08-10 04:29:00+03	106900.00
5CCF2F	2017-06-29 04:01:00+03	30000.00
5CCF67	2017-07-09 07:06:00+03	61800.00
5CCFDD	2017-08-08 22:55:00+03	75600.00
5CCFF1	2017-07-30 02:39:00+03	89600.00
5CD01B	2017-08-01 23:40:00+03	92900.00
5CD07D	2017-07-22 22:25:00+03	129200.00
5CD109	2017-08-01 11:32:00+03	57600.00
5CD11F	2017-08-08 14:52:00+03	102000.00
5CD130	2017-07-26 06:40:00+03	63200.00
5CD141	2017-07-20 11:12:00+03	31900.00
5CD162	2017-07-20 11:39:00+03	246000.00
5CD1BA	2017-07-22 10:37:00+03	93400.00
5CD1DB	2017-07-24 05:01:00+03	20400.00
5CD248	2017-07-22 10:27:00+03	67200.00
5CD28D	2017-07-29 20:20:00+03	101900.00
5CD2C7	2017-08-09 12:53:00+03	24800.00
5CD310	2017-07-29 04:11:00+03	67600.00
5CD342	2017-07-23 02:27:00+03	20200.00
5CD362	2017-07-08 21:08:00+03	32400.00
5CD438	2017-07-26 15:48:00+03	32800.00
5CD45F	2017-08-04 22:05:00+03	131600.00
5CD514	2017-08-05 04:16:00+03	22600.00
5CD529	2017-08-09 04:51:00+03	23600.00
5CD552	2017-08-13 17:55:00+03	203400.00
5CD5AF	2017-08-14 03:32:00+03	81900.00
5CD5C5	2017-07-30 01:05:00+03	286600.00
5CD61F	2017-08-10 07:17:00+03	39900.00
5CD69A	2017-07-13 12:19:00+03	85300.00
5CD6B4	2017-08-04 15:08:00+03	23400.00
5CD714	2017-07-30 18:15:00+03	91600.00
5CD723	2017-07-13 20:28:00+03	192700.00
5CD72C	2017-07-11 23:05:00+03	27800.00
5CD749	2017-08-09 17:49:00+03	28800.00
5CD807	2017-08-07 19:45:00+03	23200.00
5CD840	2017-07-04 14:21:00+03	19800.00
5CD870	2017-07-02 10:26:00+03	32400.00
5CD8F4	2017-08-14 20:59:00+03	148200.00
5CD95D	2017-07-18 13:25:00+03	28000.00
5CDA5D	2017-07-19 16:57:00+03	210900.00
5CDAA7	2017-07-26 15:30:00+03	24600.00
5CDB8E	2017-07-16 22:26:00+03	23200.00
5CDC36	2017-08-14 21:10:00+03	29600.00
5CDD2A	2017-07-24 08:17:00+03	35200.00
5CDD33	2017-08-06 20:04:00+03	67200.00
5CDDFB	2017-07-14 13:04:00+03	86800.00
5CDE35	2017-07-12 01:48:00+03	59800.00
5CDE7D	2017-07-05 20:49:00+03	79600.00
5CDEDC	2017-08-09 19:33:00+03	34000.00
5CDF23	2017-07-11 16:11:00+03	20600.00
5CDFFE	2017-07-28 00:01:00+03	64200.00
5CE081	2017-08-06 16:25:00+03	134800.00
5CE0CC	2017-08-11 02:04:00+03	133100.00
5CE11F	2017-07-21 21:10:00+03	112000.00
5CE195	2017-07-10 14:21:00+03	8200.00
5CE1F8	2017-08-09 11:03:00+03	27300.00
5CE201	2017-08-08 11:43:00+03	47000.00
5CE203	2017-08-10 17:37:00+03	40800.00
5CE210	2017-06-27 05:18:00+03	271100.00
5CE257	2017-07-10 18:59:00+03	99200.00
5CE25F	2017-07-10 01:31:00+03	17800.00
5CE2A5	2017-07-22 07:39:00+03	50100.00
5CE2B4	2017-07-25 01:59:00+03	6900.00
5CE2CA	2017-07-11 02:01:00+03	131600.00
5CE2DC	2017-07-03 16:32:00+03	155300.00
5CE2F1	2017-08-08 22:59:00+03	76600.00
5CE36E	2017-08-09 17:47:00+03	260900.00
5CE377	2017-07-11 14:11:00+03	105600.00
5CE4B5	2017-07-24 14:10:00+03	21800.00
5CE523	2017-07-29 08:49:00+03	6300.00
5CE528	2017-07-31 01:57:00+03	146300.00
5CE574	2017-07-06 16:41:00+03	31100.00
5CE5BC	2017-08-06 18:15:00+03	12000.00
5CE5C3	2017-07-09 08:58:00+03	103900.00
5CE622	2017-06-28 03:11:00+03	135400.00
5CE674	2017-07-24 21:58:00+03	133200.00
5CE694	2017-07-10 11:44:00+03	28000.00
5CE6CA	2017-08-07 18:33:00+03	103500.00
5CE6F8	2017-07-22 14:17:00+03	51200.00
5CE727	2017-07-21 01:20:00+03	56100.00
5CE7A6	2017-08-07 05:18:00+03	86300.00
5CE7E3	2017-07-15 12:56:00+03	46200.00
5CE846	2017-06-30 10:58:00+03	26000.00
5CE848	2017-07-29 21:39:00+03	23600.00
5CE88A	2017-08-08 03:17:00+03	41400.00
5CE897	2017-07-12 21:57:00+03	83000.00
5CE8B9	2017-08-12 14:07:00+03	65500.00
5CE92A	2017-07-27 20:38:00+03	56000.00
5CE96E	2017-07-12 03:09:00+03	52000.00
5CE97E	2017-07-16 02:33:00+03	21500.00
5CE9A1	2017-08-14 19:34:00+03	47200.00
5CEA1A	2017-08-07 00:16:00+03	35700.00
5CEA23	2017-08-02 10:32:00+03	130200.00
5CEA2F	2017-08-08 15:05:00+03	146400.00
5CEAC7	2017-08-12 04:56:00+03	56000.00
5CEACB	2017-07-09 16:23:00+03	14000.00
5CEB4C	2017-07-27 23:40:00+03	44000.00
5CEBDF	2017-07-12 21:47:00+03	92800.00
5CEBE2	2017-08-06 01:24:00+03	90400.00
5CEC03	2017-07-30 07:50:00+03	117600.00
5CEC09	2017-08-07 14:15:00+03	93800.00
5CEC9D	2017-07-18 20:38:00+03	36200.00
5CED7E	2017-07-09 02:50:00+03	94000.00
5CED85	2017-07-03 12:11:00+03	27000.00
5CEE2B	2017-08-02 03:48:00+03	94700.00
5CEE75	2017-08-04 01:19:00+03	80400.00
5CEE7C	2017-08-10 18:40:00+03	38000.00
5CF089	2017-07-04 19:13:00+03	24400.00
5CF08B	2017-07-01 07:04:00+03	24000.00
5CF0CC	2017-07-10 15:48:00+03	112000.00
5CF139	2017-07-23 15:23:00+03	75800.00
5CF15B	2017-07-31 18:35:00+03	56000.00
5CF186	2017-08-05 08:21:00+03	113500.00
5CF1A1	2017-07-23 03:00:00+03	144000.00
5CF1CD	2017-08-04 01:25:00+03	22000.00
5CF245	2017-08-07 22:41:00+03	20400.00
5CF267	2017-07-21 01:18:00+03	58200.00
5CF2B3	2017-08-14 10:30:00+03	84100.00
5CF34C	2017-07-06 23:00:00+03	26200.00
5CF3BC	2017-08-14 16:43:00+03	135400.00
5CF3E6	2017-07-06 18:22:00+03	70800.00
5CF412	2017-08-08 17:21:00+03	101400.00
5CF43A	2017-08-08 04:12:00+03	68100.00
5CF47C	2017-07-21 04:55:00+03	47000.00
5CF482	2017-06-30 21:05:00+03	21800.00
5CF4A4	2017-07-30 14:39:00+03	22000.00
5CF4BE	2017-08-11 16:37:00+03	56000.00
5CF4ED	2017-07-23 12:59:00+03	46300.00
5CF502	2017-07-07 09:38:00+03	58200.00
5CF55C	2017-08-06 16:19:00+03	24400.00
5CF645	2017-08-09 09:05:00+03	40800.00
5CF68A	2017-07-24 19:21:00+03	90600.00
5CF6B3	2017-08-15 16:51:00+03	112000.00
5CF6B7	2017-08-11 13:02:00+03	78800.00
5CF71E	2017-08-02 00:46:00+03	13400.00
5CF721	2017-07-13 19:13:00+03	105600.00
5CF76C	2017-07-07 22:03:00+03	273000.00
5CF7D4	2017-08-09 15:07:00+03	52300.00
5CF7FB	2017-07-23 17:35:00+03	182300.00
5CF80F	2017-08-07 20:02:00+03	144000.00
5CF88B	2017-07-25 02:48:00+03	56600.00
5CF899	2017-07-14 17:10:00+03	15400.00
5CF8BA	2017-07-29 12:24:00+03	6000.00
5CF8DE	2017-07-15 08:19:00+03	13700.00
5CF9AB	2017-07-27 09:10:00+03	37200.00
5CF9C5	2017-07-30 03:48:00+03	56000.00
5CFA29	2017-07-05 06:38:00+03	11000.00
5CFA2C	2017-08-15 14:40:00+03	28000.00
5CFA85	2017-07-24 20:20:00+03	13600.00
5CFB57	2017-08-04 04:07:00+03	173500.00
5CFBB1	2017-08-07 02:27:00+03	149800.00
5CFC36	2017-08-11 03:26:00+03	189200.00
5CFC77	2017-07-25 11:15:00+03	75300.00
5CFC7D	2017-08-04 04:28:00+03	113300.00
5CFC8C	2017-08-10 17:29:00+03	64600.00
5CFCE2	2017-07-15 22:24:00+03	16400.00
5CFD17	2017-08-12 00:31:00+03	38600.00
5CFD25	2017-07-26 12:44:00+03	58600.00
5CFD3F	2017-07-11 21:06:00+03	62600.00
5CFD5D	2017-07-29 08:46:00+03	66600.00
5CFDAE	2017-08-02 15:24:00+03	7800.00
5CFDB9	2017-08-10 14:04:00+03	269000.00
5CFE87	2017-07-27 02:44:00+03	13000.00
5CFE8E	2017-07-04 16:16:00+03	68800.00
5CFEAD	2017-08-08 12:17:00+03	85500.00
5CFEB0	2017-08-14 15:22:00+03	93900.00
5CFEC8	2017-07-09 23:11:00+03	224000.00
5CFED3	2017-08-05 16:12:00+03	57800.00
5CFF0C	2017-08-04 10:40:00+03	12700.00
5CFF47	2017-08-10 20:46:00+03	162300.00
5CFF90	2017-07-19 09:02:00+03	24000.00
5CFFB2	2017-07-17 10:32:00+03	91200.00
5CFFE4	2017-07-21 22:19:00+03	201800.00
5D001E	2017-07-31 06:18:00+03	15600.00
5D002C	2017-07-19 19:55:00+03	34400.00
5D00D5	2017-08-14 06:29:00+03	12600.00
5D0164	2017-07-07 13:06:00+03	41200.00
5D0167	2017-08-07 11:42:00+03	56000.00
5D0216	2017-07-22 03:31:00+03	56000.00
5D0225	2017-06-30 07:11:00+03	23400.00
5D0262	2017-07-23 07:01:00+03	92600.00
5D0284	2017-08-05 05:34:00+03	96400.00
5D0290	2017-07-28 03:24:00+03	24400.00
5D02C7	2017-07-07 20:48:00+03	260300.00
5D02F2	2017-07-03 13:01:00+03	45100.00
5D03C1	2017-07-31 21:47:00+03	124200.00
5D03C5	2017-07-08 20:00:00+03	32800.00
5D044D	2017-08-10 20:36:00+03	103300.00
5D044E	2017-07-12 01:07:00+03	88600.00
5D052B	2017-07-22 02:52:00+03	16400.00
5D052E	2017-07-06 12:16:00+03	201800.00
5D05F3	2017-07-13 06:17:00+03	25400.00
5D05FC	2017-08-02 13:14:00+03	94000.00
5D074C	2017-07-23 07:20:00+03	23200.00
5D07AF	2017-08-13 13:33:00+03	32700.00
5D07B2	2017-08-01 21:41:00+03	107800.00
5D07F6	2017-07-06 03:02:00+03	39200.00
5D082C	2017-07-30 00:04:00+03	152000.00
5D086E	2017-08-04 15:27:00+03	65200.00
5D088B	2017-08-11 12:15:00+03	166100.00
5D0895	2017-08-10 22:44:00+03	369000.00
5D08C4	2017-07-01 17:41:00+03	39000.00
5D0906	2017-07-24 11:20:00+03	201600.00
5D0910	2017-07-13 18:02:00+03	91500.00
5D0949	2017-07-03 18:11:00+03	313800.00
5D09A7	2017-08-09 17:50:00+03	135400.00
5D09E8	2017-07-13 04:49:00+03	47100.00
5D09F0	2017-08-14 22:38:00+03	288200.00
5D09F9	2017-07-12 22:52:00+03	24000.00
5D0AA7	2017-08-06 20:31:00+03	15400.00
5D0AAA	2017-07-21 13:38:00+03	133200.00
5D0B08	2017-07-29 07:12:00+03	137000.00
5D0B5B	2017-08-12 19:33:00+03	13000.00
5D0B6D	2017-07-15 18:19:00+03	28000.00
5D0B9D	2017-08-03 01:08:00+03	96200.00
5D0BB5	2017-07-01 03:38:00+03	139300.00
5D0BBC	2017-08-14 19:11:00+03	12600.00
5D0BCA	2017-08-13 01:24:00+03	21800.00
5D0BEB	2017-08-09 11:05:00+03	265700.00
5D0C24	2017-07-23 18:09:00+03	133100.00
5D0CB9	2017-07-31 22:52:00+03	106400.00
5D0CE1	2017-07-13 05:55:00+03	59300.00
5D0CF6	2017-07-04 17:05:00+03	28000.00
5D0D65	2017-07-08 10:26:00+03	117500.00
5D0D91	2017-08-11 00:03:00+03	79900.00
5D0DAB	2017-07-09 11:56:00+03	31600.00
5D0DAF	2017-08-13 14:17:00+03	20200.00
5D0DE1	2017-08-04 20:34:00+03	62000.00
5D0E7A	2017-07-30 20:47:00+03	25600.00
5D0E88	2017-07-22 14:42:00+03	113300.00
5D0EDD	2017-07-23 02:24:00+03	37900.00
5D0F22	2017-08-01 15:36:00+03	28000.00
5D0F47	2017-07-05 20:21:00+03	55800.00
5D0F79	2017-08-07 19:52:00+03	10800.00
5D0F84	2017-08-14 10:16:00+03	88500.00
5D0FCD	2017-07-28 08:08:00+03	134400.00
5D0FE8	2017-07-03 20:13:00+03	23400.00
5D0FEC	2017-08-10 06:06:00+03	141500.00
5D1004	2017-07-30 01:32:00+03	29500.00
5D102B	2017-07-01 05:30:00+03	316800.00
5D1047	2017-07-31 18:01:00+03	17000.00
5D1069	2017-07-30 06:41:00+03	398500.00
5D1092	2017-08-10 16:32:00+03	23600.00
5D1099	2017-08-12 05:08:00+03	16800.00
5D10DF	2017-08-02 16:22:00+03	22600.00
5D1115	2017-07-16 14:59:00+03	75100.00
5D112C	2017-07-19 08:57:00+03	297300.00
5D1194	2017-07-30 21:39:00+03	129600.00
5D11D2	2017-08-12 00:06:00+03	45900.00
5D11DD	2017-07-09 07:25:00+03	56600.00
5D11F9	2017-07-21 08:49:00+03	7300.00
5D1237	2017-08-03 23:53:00+03	27900.00
5D1275	2017-08-08 11:26:00+03	56000.00
5D12AD	2017-08-02 20:40:00+03	6700.00
5D12CD	2017-07-29 12:48:00+03	22000.00
5D1391	2017-07-27 12:03:00+03	67600.00
5D1443	2017-07-03 21:28:00+03	74100.00
5D145E	2017-07-17 17:48:00+03	213200.00
5D146B	2017-07-01 11:20:00+03	112600.00
5D1488	2017-08-14 10:32:00+03	12000.00
5D14EA	2017-08-04 17:13:00+03	40700.00
5D1537	2017-08-01 20:57:00+03	33300.00
5D153B	2017-07-28 00:11:00+03	13400.00
5D15E4	2017-07-21 14:42:00+03	115600.00
5D160B	2017-07-20 16:35:00+03	107700.00
5D1650	2017-07-08 19:00:00+03	16600.00
5D1654	2017-07-10 14:06:00+03	65600.00
5D1678	2017-08-15 17:20:00+03	102100.00
5D16A0	2017-08-01 10:52:00+03	196900.00
5D16AF	2017-08-04 01:23:00+03	49200.00
5D1736	2017-06-23 18:58:00+03	97900.00
5D1748	2017-07-17 15:45:00+03	15000.00
5D1773	2017-07-04 15:55:00+03	16400.00
5D1776	2017-07-03 17:16:00+03	103500.00
5D17A1	2017-07-07 10:52:00+03	50000.00
5D17B7	2017-07-16 15:08:00+03	13700.00
5D17C4	2017-07-26 01:05:00+03	46000.00
5D17EF	2017-08-08 10:13:00+03	24200.00
5D17F4	2017-07-09 09:24:00+03	17800.00
5D1860	2017-07-22 21:03:00+03	21800.00
5D186B	2017-07-03 06:07:00+03	29400.00
5D1905	2017-08-04 03:34:00+03	37200.00
5D1980	2017-07-13 01:31:00+03	28000.00
5D19D3	2017-08-07 00:49:00+03	39600.00
5D1A7B	2017-08-15 12:34:00+03	110200.00
5D1B9A	2017-08-08 06:31:00+03	16400.00
5D1BC5	2017-08-15 16:40:00+03	56100.00
5D1BFA	2017-07-18 07:55:00+03	28000.00
5D1C12	2017-07-28 06:29:00+03	7400.00
5D1C1A	2017-07-21 06:12:00+03	26000.00
5D1C2F	2017-07-18 19:15:00+03	131600.00
5D1C6B	2017-08-07 02:51:00+03	88800.00
5D1C70	2017-07-17 04:13:00+03	134400.00
5D1CC6	2017-06-27 02:42:00+03	192400.00
5D1D5B	2017-08-07 15:27:00+03	118500.00
5D1D6E	2017-08-02 11:13:00+03	30200.00
5D1DF5	2017-08-01 09:52:00+03	24400.00
5D1E71	2017-08-12 06:53:00+03	61200.00
5D1F20	2017-07-24 11:16:00+03	56100.00
5D1F73	2017-08-10 13:25:00+03	14400.00
5D1F7E	2017-07-22 12:40:00+03	15700.00
5D1F81	2017-07-27 02:15:00+03	62900.00
5D1F99	2017-07-31 19:25:00+03	20000.00
5D1FD8	2017-07-07 02:19:00+03	33100.00
5D1FDD	2017-08-05 16:36:00+03	57600.00
5D1FF3	2017-07-05 10:55:00+03	28800.00
5D2030	2017-07-19 06:37:00+03	57400.00
5D2054	2017-07-21 00:35:00+03	68800.00
5D2073	2017-07-28 22:46:00+03	47200.00
5D2094	2017-08-10 16:42:00+03	68000.00
5D211D	2017-08-07 11:15:00+03	76800.00
5D2125	2017-07-23 01:40:00+03	13600.00
5D212C	2017-08-13 19:57:00+03	46000.00
5D2162	2017-07-11 02:08:00+03	135200.00
5D21C9	2017-08-08 12:12:00+03	93900.00
5D21D4	2017-07-21 06:30:00+03	117700.00
5D222F	2017-07-30 04:16:00+03	98400.00
5D2282	2017-08-03 13:30:00+03	39800.00
5D2287	2017-08-04 01:27:00+03	16400.00
5D2296	2017-08-02 18:20:00+03	46200.00
5D22C9	2017-06-30 19:57:00+03	102000.00
5D235E	2017-08-14 01:40:00+03	55800.00
5D2377	2017-07-13 20:58:00+03	92000.00
5D23A2	2017-08-01 15:21:00+03	6700.00
5D23F7	2017-08-04 03:23:00+03	30000.00
5D2416	2017-07-17 02:34:00+03	316800.00
5D246A	2017-07-31 03:22:00+03	13700.00
5D2501	2017-07-20 08:13:00+03	246000.00
5D2526	2017-07-11 21:00:00+03	131800.00
5D2559	2017-07-28 07:20:00+03	52300.00
5D2569	2017-07-23 20:06:00+03	166000.00
5D259B	2017-08-13 17:38:00+03	31600.00
5D25FB	2017-07-06 12:36:00+03	206400.00
5D264C	2017-08-12 14:46:00+03	6300.00
5D26B7	2017-07-28 08:13:00+03	13200.00
5D26C7	2017-07-14 01:24:00+03	92600.00
5D26F4	2017-07-19 18:29:00+03	55800.00
5D2761	2017-07-02 02:58:00+03	56000.00
5D27C6	2017-08-15 07:54:00+03	46400.00
5D27E9	2017-06-29 04:52:00+03	296000.00
5D27F3	2017-07-20 00:25:00+03	23200.00
5D281F	2017-06-29 07:56:00+03	52900.00
5D284D	2017-08-02 16:46:00+03	61500.00
5D2854	2017-08-14 04:12:00+03	94000.00
5D2856	2017-08-02 01:47:00+03	187800.00
5D286D	2017-07-20 03:56:00+03	174600.00
5D2870	2017-08-13 03:29:00+03	133200.00
5D28CC	2017-08-05 09:17:00+03	166000.00
5D28D8	2017-08-01 17:54:00+03	14000.00
5D293B	2017-07-05 13:30:00+03	39800.00
5D29B0	2017-07-23 17:46:00+03	28300.00
5D29C7	2017-08-12 03:21:00+03	52000.00
5D2A1B	2017-08-06 22:06:00+03	48100.00
5D2A30	2017-08-07 06:07:00+03	27000.00
5D2A63	2017-08-05 09:36:00+03	88400.00
5D2AC5	2017-07-03 20:33:00+03	44000.00
5D2AD0	2017-07-04 20:52:00+03	44000.00
5D2B05	2017-07-28 03:49:00+03	92000.00
5D2B88	2017-08-10 22:18:00+03	31100.00
5D2B8B	2017-07-14 20:45:00+03	81300.00
5D2BAB	2017-07-29 08:17:00+03	44000.00
5D2BF6	2017-08-09 20:30:00+03	154500.00
5D2C55	2017-07-30 08:55:00+03	66000.00
5D2C75	2017-07-22 10:59:00+03	46400.00
5D2CE6	2017-07-16 05:20:00+03	149200.00
5D2E45	2017-07-26 03:55:00+03	28000.00
5D2E6C	2017-07-12 04:30:00+03	87200.00
5D2EF1	2017-07-07 13:31:00+03	46400.00
5D2F04	2017-07-05 09:44:00+03	14400.00
5D2F5E	2017-07-10 17:56:00+03	54500.00
5D2F80	2017-07-03 02:15:00+03	76800.00
5D2FD0	2017-08-12 13:08:00+03	43600.00
5D2FE2	2017-07-28 16:44:00+03	19600.00
5D3036	2017-07-12 14:20:00+03	19600.00
5D3071	2017-08-10 22:06:00+03	803800.00
5D30C5	2017-07-22 17:57:00+03	85700.00
5D30CA	2017-07-25 23:05:00+03	34000.00
5D30D0	2017-07-06 21:56:00+03	266400.00
5D3104	2017-07-16 18:31:00+03	166900.00
5D3116	2017-07-09 10:13:00+03	117600.00
5D318E	2017-07-23 18:42:00+03	57800.00
5D31BB	2017-07-16 22:33:00+03	81900.00
5D31CA	2017-07-23 02:39:00+03	6800.00
5D31E5	2017-08-14 04:21:00+03	41200.00
5D3234	2017-07-13 03:58:00+03	31100.00
5D32CF	2017-08-11 22:01:00+03	89700.00
5D32DA	2017-07-22 03:59:00+03	56000.00
5D32F0	2017-07-02 17:06:00+03	31800.00
5D3363	2017-08-09 18:52:00+03	43900.00
5D3380	2017-07-03 08:52:00+03	114800.00
5D338C	2017-07-10 11:27:00+03	46300.00
5D3395	2017-07-27 05:43:00+03	6700.00
5D33DE	2017-08-14 01:04:00+03	87000.00
5D3449	2017-07-09 01:45:00+03	190200.00
5D3479	2017-07-20 05:42:00+03	37100.00
5D34AA	2017-07-13 02:13:00+03	56000.00
5D34D4	2017-07-13 17:56:00+03	43200.00
5D3517	2017-07-18 04:13:00+03	45200.00
5D351D	2017-07-03 12:27:00+03	22000.00
5D3582	2017-07-14 07:55:00+03	36200.00
5D358A	2017-08-12 12:40:00+03	113000.00
5D3599	2017-08-07 17:55:00+03	86800.00
5D35DA	2017-07-14 18:12:00+03	246000.00
5D3689	2017-07-26 21:32:00+03	159000.00
5D36A4	2017-08-03 13:01:00+03	56000.00
5D36CB	2017-07-15 08:54:00+03	61800.00
5D3723	2017-07-06 07:41:00+03	56000.00
5D3732	2017-07-03 13:15:00+03	135600.00
5D378F	2017-08-14 02:33:00+03	92600.00
5D385A	2017-08-04 10:52:00+03	39600.00
5D3875	2017-07-08 16:47:00+03	54500.00
5D38BB	2017-07-24 21:48:00+03	23900.00
5D38F2	2017-08-05 12:19:00+03	111600.00
5D391A	2017-07-30 19:58:00+03	213600.00
5D39B9	2017-08-02 05:52:00+03	28000.00
5D3A58	2017-06-30 23:12:00+03	86600.00
5D3A94	2017-07-20 11:19:00+03	43400.00
5D3AA5	2017-08-10 01:23:00+03	57800.00
5D3AB9	2017-08-11 13:16:00+03	115400.00
5D3ADB	2017-07-27 17:29:00+03	8200.00
5D3B0E	2017-08-11 22:45:00+03	32800.00
5D3B26	2017-07-06 12:34:00+03	259600.00
5D3B2C	2017-08-12 03:32:00+03	79600.00
5D3B3A	2017-08-11 21:04:00+03	46000.00
5D3BA9	2017-08-06 20:28:00+03	60700.00
5D3BAC	2017-08-04 03:23:00+03	23200.00
5D3BB2	2017-07-17 11:08:00+03	96300.00
5D3C73	2017-07-22 08:14:00+03	59300.00
5D3CA8	2017-08-01 13:31:00+03	174400.00
5D3CE5	2017-07-27 13:12:00+03	147100.00
5D3D18	2017-07-14 12:09:00+03	123600.00
5D3DEE	2017-07-16 08:22:00+03	119600.00
5D3E01	2017-07-05 14:44:00+03	65900.00
5D3E65	2017-07-11 11:31:00+03	123000.00
5D3EAE	2017-07-20 14:37:00+03	135400.00
5D3EFA	2017-07-08 17:31:00+03	148200.00
5D3F66	2017-06-29 07:29:00+03	111600.00
5D3FB6	2017-07-25 04:56:00+03	7400.00
5D403F	2017-08-14 19:42:00+03	66600.00
5D4049	2017-07-25 15:46:00+03	265600.00
5D404C	2017-08-12 06:46:00+03	252400.00
5D407A	2017-07-10 15:39:00+03	6700.00
5D409F	2017-08-08 12:53:00+03	91900.00
5D40C8	2017-07-18 16:09:00+03	46200.00
5D4116	2017-08-10 23:30:00+03	104100.00
5D4167	2017-07-20 13:05:00+03	24800.00
5D4193	2017-08-15 11:08:00+03	25200.00
5D41D5	2017-08-01 15:34:00+03	32500.00
5D4245	2017-08-05 23:45:00+03	124300.00
5D425F	2017-08-15 00:21:00+03	31400.00
5D4340	2017-07-13 00:20:00+03	58800.00
5D4353	2017-08-05 06:59:00+03	54800.00
5D438A	2017-07-10 03:35:00+03	61700.00
5D43F8	2017-07-20 19:50:00+03	48300.00
5D440C	2017-08-08 20:46:00+03	48800.00
5D446F	2017-07-13 02:07:00+03	18800.00
5D44D7	2017-07-24 18:01:00+03	147000.00
5D44DE	2017-07-29 06:16:00+03	56100.00
5D45BE	2017-07-26 11:58:00+03	85000.00
5D466C	2017-07-02 06:58:00+03	24700.00
5D4736	2017-08-03 12:53:00+03	51600.00
5D4740	2017-07-30 03:59:00+03	29300.00
5D4748	2017-08-09 18:48:00+03	86500.00
5D4781	2017-07-18 19:41:00+03	24000.00
5D4817	2017-07-21 16:05:00+03	52900.00
5D4891	2017-08-10 15:47:00+03	235400.00
5D48F4	2017-07-31 05:52:00+03	79900.00
5D4911	2017-07-21 14:07:00+03	156100.00
5D49EA	2017-07-02 21:31:00+03	111600.00
5D4A05	2017-08-03 20:21:00+03	65900.00
5D4A5A	2017-08-12 13:39:00+03	99300.00
5D4AA9	2017-06-26 05:07:00+03	265700.00
5D4AEE	2017-07-26 13:12:00+03	40800.00
5D4B12	2017-08-15 10:34:00+03	28000.00
5D4B50	2017-08-10 18:59:00+03	152200.00
5D4BE8	2017-07-05 09:47:00+03	60300.00
5D4C8D	2017-07-23 18:44:00+03	61900.00
5D4C8F	2017-08-07 02:13:00+03	10800.00
5D4CF7	2017-08-12 02:09:00+03	18100.00
5D4D02	2017-07-30 05:36:00+03	157200.00
5D4D52	2017-07-08 03:45:00+03	21400.00
5D4D69	2017-07-09 17:48:00+03	140300.00
5D4F01	2017-07-22 04:12:00+03	37100.00
5D4F11	2017-07-10 07:29:00+03	21000.00
5D4F25	2017-07-12 14:28:00+03	72200.00
5D4F37	2017-07-13 17:29:00+03	58700.00
5D5001	2017-08-07 18:13:00+03	97500.00
5D5016	2017-07-29 09:51:00+03	70800.00
5D5112	2017-08-04 14:03:00+03	60400.00
5D5136	2017-07-07 18:53:00+03	23200.00
5D5138	2017-07-30 09:38:00+03	65900.00
5D5168	2017-07-20 22:30:00+03	26600.00
5D519A	2017-07-04 11:15:00+03	20200.00
5D51D1	2017-06-27 17:34:00+03	56000.00
5D5239	2017-07-15 18:48:00+03	22900.00
5D524D	2017-07-12 03:37:00+03	47200.00
5D5253	2017-07-06 13:25:00+03	78600.00
5D52B4	2017-07-05 22:12:00+03	204300.00
5D52EC	2017-07-24 01:34:00+03	28800.00
5D52EE	2017-07-11 06:39:00+03	25600.00
5D533B	2017-07-19 18:18:00+03	99800.00
5D535D	2017-07-16 16:44:00+03	67900.00
5D536E	2017-07-29 16:30:00+03	162300.00
5D53A3	2017-08-01 10:00:00+03	55400.00
5D54A1	2017-07-20 04:20:00+03	10600.00
5D54E0	2017-07-30 19:02:00+03	46000.00
5D551A	2017-07-27 13:51:00+03	24000.00
5D5536	2017-07-29 15:19:00+03	57600.00
5D5575	2017-07-20 17:57:00+03	6600.00
5D55B5	2017-07-26 14:33:00+03	89600.00
5D55D6	2017-07-27 04:08:00+03	41600.00
5D55E0	2017-08-05 06:46:00+03	114400.00
5D5619	2017-07-16 12:02:00+03	34600.00
5D561B	2017-08-09 10:26:00+03	68900.00
5D5628	2017-07-15 03:09:00+03	147200.00
5D564D	2017-07-22 06:08:00+03	40800.00
5D5689	2017-07-29 02:23:00+03	177900.00
5D56CF	2017-08-10 13:10:00+03	23200.00
5D5705	2017-07-14 06:19:00+03	52000.00
5D571C	2017-07-01 06:25:00+03	46200.00
5D572A	2017-08-09 05:56:00+03	26800.00
5D5741	2017-07-25 06:27:00+03	100600.00
5D5790	2017-08-11 11:56:00+03	137800.00
5D5799	2017-07-04 00:42:00+03	28000.00
5D57B9	2017-07-11 18:46:00+03	59000.00
5D57F4	2017-07-01 16:42:00+03	89600.00
5D5800	2017-08-15 13:51:00+03	40800.00
5D5818	2017-08-07 18:37:00+03	38600.00
5D583B	2017-07-16 03:44:00+03	19800.00
5D5899	2017-07-23 19:25:00+03	61600.00
5D58A2	2017-07-08 06:11:00+03	19600.00
5D58A9	2017-07-22 20:13:00+03	92900.00
5D591F	2017-07-01 00:10:00+03	31900.00
5D5938	2017-08-05 22:52:00+03	56000.00
5D5940	2017-07-28 16:46:00+03	98700.00
5D598D	2017-08-13 09:57:00+03	39100.00
5D5994	2017-08-15 01:45:00+03	75800.00
5D59AB	2017-07-03 10:32:00+03	56100.00
5D5A13	2017-08-08 21:43:00+03	68000.00
5D5A43	2017-08-11 02:10:00+03	92800.00
5D5A7C	2017-07-23 05:52:00+03	23600.00
5D5AAF	2017-07-12 17:16:00+03	125400.00
5D5AD1	2017-07-16 14:43:00+03	55400.00
5D5B0E	2017-08-07 19:03:00+03	62000.00
5D5B17	2017-08-07 11:22:00+03	73300.00
5D5B30	2017-07-07 11:23:00+03	93800.00
5D5B4E	2017-08-11 04:44:00+03	193200.00
5D5BBF	2017-07-20 20:46:00+03	123000.00
5D5C19	2017-07-12 15:57:00+03	4000.00
5D5C37	2017-08-10 18:46:00+03	32700.00
5D5C94	2017-08-14 20:58:00+03	43900.00
5D5C9B	2017-07-27 05:52:00+03	43500.00
5D5CC0	2017-07-03 13:10:00+03	43500.00
5D5D10	2017-06-29 19:04:00+03	20400.00
5D5F12	2017-08-04 10:11:00+03	25700.00
5D5F2B	2017-07-04 11:56:00+03	121400.00
5D5F66	2017-08-03 06:26:00+03	30600.00
5D5FB4	2017-07-24 06:05:00+03	27400.00
5D5FC9	2017-08-06 07:38:00+03	113300.00
5D5FEA	2017-07-28 23:26:00+03	23600.00
5D6028	2017-07-26 02:18:00+03	71200.00
5D608B	2017-07-15 07:16:00+03	136800.00
5D60AE	2017-08-11 05:33:00+03	31800.00
5D60C3	2017-08-13 02:47:00+03	24300.00
5D60C4	2017-07-31 20:49:00+03	166100.00
5D6102	2017-07-24 06:39:00+03	91500.00
5D613A	2017-07-27 08:50:00+03	71600.00
5D617E	2017-07-06 00:33:00+03	29600.00
5D61C9	2017-07-19 14:19:00+03	65500.00
5D620A	2017-07-01 11:31:00+03	96200.00
5D6215	2017-08-04 01:20:00+03	185600.00
5D621F	2017-08-14 00:23:00+03	48800.00
5D6255	2017-07-16 04:43:00+03	123000.00
5D6278	2017-08-13 23:32:00+03	44800.00
5D627C	2017-07-21 22:14:00+03	46500.00
5D6282	2017-07-28 13:36:00+03	6000.00
5D62F7	2017-07-31 22:07:00+03	17200.00
5D6369	2017-07-14 12:17:00+03	52700.00
5D63A0	2017-07-28 16:56:00+03	68400.00
5D63C5	2017-07-29 07:14:00+03	6300.00
5D63C8	2017-08-07 07:15:00+03	35800.00
5D63FC	2017-07-15 17:34:00+03	38800.00
5D6417	2017-07-31 12:37:00+03	117200.00
5D641B	2017-07-30 11:30:00+03	129200.00
5D6445	2017-06-26 15:24:00+03	52100.00
5D646C	2017-07-30 17:59:00+03	31100.00
5D64C1	2017-07-21 13:52:00+03	29600.00
5D64EB	2017-07-10 09:54:00+03	31800.00
5D650F	2017-08-15 05:50:00+03	40500.00
5D6528	2017-07-17 11:11:00+03	80300.00
5D6535	2017-07-30 20:49:00+03	246000.00
5D654A	2017-08-01 01:56:00+03	6800.00
5D663B	2017-07-11 17:29:00+03	8200.00
5D6665	2017-07-06 08:21:00+03	85000.00
5D66B0	2017-07-30 12:06:00+03	61500.00
5D66C8	2017-07-18 05:00:00+03	40000.00
5D66E9	2017-08-07 20:56:00+03	136800.00
5D6734	2017-08-11 00:00:00+03	14400.00
5D6745	2017-08-12 22:16:00+03	57600.00
5D6809	2017-08-03 22:21:00+03	40600.00
5D68C9	2017-08-15 00:03:00+03	57600.00
5D68D3	2017-08-11 02:54:00+03	100600.00
5D68FA	2017-08-03 15:51:00+03	21500.00
5D6921	2017-07-29 19:51:00+03	34600.00
5D6925	2017-07-15 03:11:00+03	58900.00
5D6929	2017-07-29 03:40:00+03	87200.00
5D692A	2017-08-10 08:49:00+03	38800.00
5D695A	2017-07-21 10:21:00+03	89200.00
5D69B1	2017-07-08 16:22:00+03	103500.00
5D69B9	2017-08-12 03:16:00+03	26000.00
5D69DC	2017-07-15 14:13:00+03	189200.00
5D6A0A	2017-07-30 00:25:00+03	135600.00
5D6A21	2017-07-17 03:50:00+03	89700.00
5D6A73	2017-08-04 08:52:00+03	114800.00
5D6AE2	2017-07-14 02:06:00+03	179500.00
5D6AFB	2017-08-07 12:30:00+03	136800.00
5D6B0B	2017-07-10 15:10:00+03	61300.00
5D6B64	2017-06-30 00:04:00+03	61800.00
5D6B7E	2017-08-14 01:28:00+03	12600.00
5D6B95	2017-08-11 14:04:00+03	99300.00
5D6B97	2017-08-04 02:02:00+03	23400.00
5D6BDE	2017-07-27 02:31:00+03	289800.00
5D6C12	2017-07-04 19:57:00+03	55800.00
5D6CDA	2017-08-02 19:06:00+03	42800.00
5D6CFC	2017-08-09 09:45:00+03	54800.00
5D6D47	2017-08-08 03:56:00+03	119800.00
5D6D95	2017-07-07 11:46:00+03	99200.00
5D6DBB	2017-07-09 16:15:00+03	201200.00
5D6DD6	2017-07-13 18:24:00+03	49100.00
5D6DE8	2017-07-30 06:55:00+03	75600.00
5D6E31	2017-07-21 15:41:00+03	84000.00
5D6E3B	2017-08-14 16:08:00+03	73400.00
5D6E53	2017-07-01 19:22:00+03	202700.00
5D6E5D	2017-07-05 22:06:00+03	40400.00
5D6E7A	2017-08-09 20:09:00+03	39300.00
5D6E8A	2017-07-11 19:02:00+03	81300.00
5D6F97	2017-08-14 16:35:00+03	87000.00
5D6FB3	2017-06-29 07:55:00+03	56000.00
5D7014	2017-07-19 20:57:00+03	76600.00
5D709C	2017-07-13 07:55:00+03	92000.00
5D714F	2017-08-14 01:50:00+03	56000.00
5D716B	2017-08-10 22:27:00+03	133800.00
5D7187	2017-08-03 19:37:00+03	28800.00
5D71A9	2017-08-12 02:21:00+03	114800.00
5D724B	2017-07-27 17:30:00+03	94500.00
5D72B9	2017-08-09 23:45:00+03	58800.00
5D72CC	2017-07-17 20:52:00+03	46400.00
5D72F8	2017-07-05 02:32:00+03	78600.00
5D7302	2017-07-11 22:15:00+03	79600.00
5D731F	2017-08-12 19:10:00+03	79100.00
5D7341	2017-08-07 16:23:00+03	123000.00
5D7362	2017-06-30 09:13:00+03	133700.00
5D7374	2017-08-14 07:04:00+03	27700.00
5D7394	2017-07-15 07:09:00+03	46400.00
5D73CB	2017-07-20 18:30:00+03	12200.00
5D73DD	2017-07-01 20:47:00+03	720400.00
5D73F0	2017-08-05 18:39:00+03	97900.00
5D7436	2017-06-29 12:36:00+03	6000.00
5D7461	2017-07-07 18:15:00+03	13000.00
5D748F	2017-08-07 22:40:00+03	38000.00
5D7499	2017-07-21 17:03:00+03	59700.00
5D74CA	2017-07-17 16:37:00+03	46400.00
5D74D9	2017-07-26 10:08:00+03	40000.00
5D753B	2017-08-13 08:42:00+03	15100.00
5D7576	2017-07-20 06:51:00+03	47200.00
5D75AA	2017-07-14 18:15:00+03	44600.00
5D75B1	2017-08-10 18:34:00+03	137600.00
5D75CA	2017-07-16 10:48:00+03	23600.00
5D75E0	2017-07-01 21:11:00+03	6600.00
5D76AB	2017-06-30 04:34:00+03	22100.00
5D771B	2017-07-24 03:31:00+03	28000.00
5D772A	2017-07-20 00:09:00+03	154900.00
5D7745	2017-07-02 06:16:00+03	62800.00
5D774F	2017-07-25 14:59:00+03	92400.00
5D7758	2017-08-09 13:53:00+03	43200.00
5D775A	2017-07-25 02:40:00+03	152900.00
5D775B	2017-07-06 18:50:00+03	65300.00
5D775F	2017-07-10 17:31:00+03	35900.00
5D7788	2017-07-11 03:30:00+03	103400.00
5D77A6	2017-07-04 17:39:00+03	28800.00
5D77F3	2017-08-10 05:02:00+03	29200.00
5D7831	2017-08-03 07:31:00+03	25600.00
5D7853	2017-08-14 13:34:00+03	66600.00
5D7857	2017-07-29 12:40:00+03	32800.00
5D78B4	2017-07-19 22:24:00+03	40000.00
5D78DD	2017-07-10 01:27:00+03	27900.00
5D7922	2017-07-18 02:29:00+03	80500.00
5D799E	2017-07-10 02:44:00+03	24400.00
5D79B4	2017-08-04 03:03:00+03	8000.00
5D79C2	2017-08-10 23:19:00+03	40100.00
5D79EB	2017-08-03 16:33:00+03	72800.00
5D79EC	2017-07-26 07:53:00+03	48800.00
5D7A2E	2017-08-13 18:21:00+03	26000.00
5D7A4B	2017-07-12 05:29:00+03	34000.00
5D7A87	2017-07-10 10:50:00+03	320000.00
5D7ACC	2017-08-13 06:35:00+03	7400.00
5D7AEF	2017-08-05 21:27:00+03	50400.00
5D7BE7	2017-07-24 05:50:00+03	191200.00
5D7C06	2017-07-21 00:20:00+03	38800.00
5D7C07	2017-08-15 13:44:00+03	26000.00
5D7C49	2017-07-20 07:51:00+03	58400.00
5D7C66	2017-07-21 14:30:00+03	139500.00
5D7C98	2017-07-07 05:48:00+03	45200.00
5D7C9D	2017-08-04 22:58:00+03	9200.00
5D7CBB	2017-07-06 15:31:00+03	59400.00
5D7CFD	2017-08-14 22:26:00+03	28000.00
5D7D02	2017-07-16 00:42:00+03	100600.00
5D7D64	2017-08-02 16:09:00+03	193700.00
5D7D7D	2017-07-23 13:26:00+03	6600.00
5D7DEF	2017-07-23 02:01:00+03	49800.00
5D7E03	2017-07-09 16:08:00+03	101200.00
5D7E53	2017-08-02 11:44:00+03	85000.00
5D7E5A	2017-08-02 19:03:00+03	28800.00
5D7E7D	2017-07-06 10:49:00+03	123000.00
5D7E83	2017-07-03 12:34:00+03	84400.00
5D7EC4	2017-07-13 10:40:00+03	35600.00
5D7EFF	2017-07-11 15:43:00+03	8400.00
5D7FFF	2017-06-30 21:23:00+03	34600.00
5D8014	2017-08-09 22:32:00+03	28800.00
5D8093	2017-08-10 00:10:00+03	126700.00
5D81E1	2017-07-13 12:38:00+03	30000.00
5D823F	2017-07-19 08:54:00+03	12600.00
5D8272	2017-08-09 16:36:00+03	73400.00
5D827F	2017-08-05 19:22:00+03	627000.00
5D82CE	2017-07-25 03:40:00+03	62800.00
5D83BE	2017-07-18 09:52:00+03	46200.00
5D83C5	2017-08-04 05:33:00+03	32800.00
5D83D5	2017-07-26 01:30:00+03	49800.00
5D8423	2017-07-17 16:46:00+03	65900.00
5D845F	2017-07-29 08:01:00+03	29600.00
5D85C1	2017-08-01 23:12:00+03	26800.00
5D85D2	2017-07-05 00:43:00+03	26000.00
5D85F5	2017-07-21 05:31:00+03	14000.00
5D85FF	2017-07-30 10:00:00+03	47800.00
5D861A	2017-08-07 09:06:00+03	128800.00
5D864C	2017-07-14 13:18:00+03	73300.00
5D8677	2017-08-10 00:57:00+03	103700.00
5D86D0	2017-07-28 00:04:00+03	35300.00
5D871C	2017-08-03 16:48:00+03	75600.00
5D872E	2017-07-13 09:21:00+03	32700.00
5D8739	2017-08-15 01:17:00+03	23600.00
5D873E	2017-08-06 18:35:00+03	85000.00
5D8798	2017-08-13 07:42:00+03	67700.00
5D87D1	2017-07-24 01:45:00+03	80800.00
5D8859	2017-08-13 05:31:00+03	156000.00
5D88CB	2017-08-14 15:24:00+03	38000.00
5D88CC	2017-07-07 01:50:00+03	32900.00
5D8929	2017-07-11 01:06:00+03	80700.00
5D89A5	2017-07-10 22:24:00+03	19600.00
5D89C5	2017-07-19 06:42:00+03	89700.00
5D8A06	2017-08-04 08:51:00+03	29400.00
5D8A6B	2017-07-23 06:35:00+03	40600.00
5D8A78	2017-08-11 00:08:00+03	81000.00
5D8A7E	2017-08-05 00:44:00+03	135200.00
5D8AB8	2017-06-30 21:27:00+03	147000.00
5D8AE0	2017-07-11 08:16:00+03	26000.00
5D8AE1	2017-08-09 03:19:00+03	396500.00
5D8B16	2017-07-20 15:29:00+03	86800.00
5D8B28	2017-07-03 23:26:00+03	36200.00
5D8B31	2017-08-10 12:19:00+03	254600.00
5D8B7F	2017-08-10 08:44:00+03	53100.00
5D8BD4	2017-08-02 18:38:00+03	115400.00
5D8BE4	2017-06-29 06:59:00+03	124200.00
5D8BF8	2017-08-05 11:22:00+03	24400.00
5D8C4A	2017-08-02 17:22:00+03	10800.00
5D8D1B	2017-07-26 17:20:00+03	105000.00
5D8E3C	2017-08-15 00:50:00+03	46400.00
5D8E83	2017-06-29 00:51:00+03	87000.00
5D8ED0	2017-07-18 00:05:00+03	32800.00
5D8F0A	2017-08-07 19:59:00+03	74300.00
5D8F46	2017-08-09 11:27:00+03	103000.00
5D8F4C	2017-08-04 03:30:00+03	65500.00
5D8F60	2017-07-14 21:05:00+03	114800.00
5D8F93	2017-07-25 22:53:00+03	28000.00
5D8FB0	2017-07-12 06:04:00+03	47800.00
5D8FDB	2017-06-28 05:31:00+03	46000.00
5D902E	2017-07-04 11:45:00+03	16400.00
5D907D	2017-07-13 02:03:00+03	408500.00
5D9083	2017-07-13 08:19:00+03	28000.00
5D908B	2017-07-10 01:00:00+03	78900.00
5D9098	2017-07-15 22:46:00+03	46500.00
5D90A6	2017-07-23 07:25:00+03	118000.00
5D90E8	2017-08-03 16:54:00+03	78300.00
5D918F	2017-07-25 18:55:00+03	47000.00
5D91D8	2017-08-08 20:21:00+03	128800.00
5D91ED	2017-08-10 05:37:00+03	70800.00
5D9200	2017-07-06 16:04:00+03	281500.00
5D9252	2017-07-29 05:51:00+03	112000.00
5D928C	2017-07-31 20:32:00+03	125400.00
5D9363	2017-08-06 19:44:00+03	23400.00
5D9389	2017-07-09 09:50:00+03	6900.00
5D93AF	2017-08-10 05:44:00+03	31400.00
5D93BB	2017-07-24 21:16:00+03	56000.00
5D93C6	2017-08-15 03:50:00+03	21400.00
5D93DD	2017-07-02 17:03:00+03	19600.00
5D93FD	2017-08-05 02:45:00+03	100600.00
5D9445	2017-08-04 15:47:00+03	40400.00
5D94CF	2017-08-06 12:55:00+03	112600.00
5D9565	2017-07-13 01:54:00+03	57400.00
5D961E	2017-06-28 23:36:00+03	316900.00
5D962F	2017-07-28 22:37:00+03	67400.00
5D9640	2017-07-12 02:18:00+03	42900.00
5D9680	2017-07-03 09:46:00+03	121400.00
5D9728	2017-07-12 21:00:00+03	141000.00
5D972E	2017-07-10 06:42:00+03	15100.00
5D9761	2017-07-26 07:19:00+03	24400.00
5D977D	2017-08-13 23:16:00+03	113200.00
5D979D	2017-08-09 12:38:00+03	200600.00
5D97DF	2017-08-14 08:20:00+03	55800.00
5D97E6	2017-08-05 05:21:00+03	128800.00
5D97E9	2017-07-08 04:38:00+03	73600.00
5D981F	2017-07-25 13:20:00+03	73600.00
5D984F	2017-07-21 17:02:00+03	50700.00
5D9861	2017-08-01 09:31:00+03	46800.00
5D98A6	2017-07-15 04:08:00+03	67200.00
5D98DA	2017-07-18 10:36:00+03	46400.00
5D991D	2017-08-02 03:20:00+03	88600.00
5D9935	2017-07-17 22:30:00+03	50800.00
5D9949	2017-08-15 07:38:00+03	44800.00
5D9A0F	2017-07-15 13:08:00+03	19800.00
5D9AC0	2017-07-19 04:08:00+03	49200.00
5D9B0C	2017-07-11 00:17:00+03	27200.00
5D9B17	2017-07-22 12:11:00+03	16000.00
5D9B5E	2017-08-04 06:01:00+03	26800.00
5D9B81	2017-07-14 21:37:00+03	12400.00
5D9BDB	2017-07-04 14:47:00+03	45200.00
5D9BF7	2017-08-03 08:55:00+03	29600.00
5D9C01	2017-07-30 22:50:00+03	28600.00
5D9CF5	2017-07-18 21:19:00+03	118300.00
5D9D04	2017-07-27 17:36:00+03	49000.00
5D9D15	2017-07-16 05:27:00+03	246000.00
5D9D8C	2017-07-23 19:16:00+03	57500.00
5D9D95	2017-07-02 16:51:00+03	28000.00
5D9DA1	2017-08-11 19:58:00+03	58800.00
5D9DF2	2017-08-05 15:35:00+03	266400.00
5D9E38	2017-06-24 20:09:00+03	27300.00
5D9E95	2017-08-03 01:39:00+03	49200.00
5D9EBF	2017-07-20 11:52:00+03	175200.00
5D9F09	2017-07-27 23:24:00+03	59100.00
5D9F0B	2017-07-30 10:15:00+03	137500.00
5D9F9C	2017-07-15 15:09:00+03	59800.00
5D9FE4	2017-07-22 22:51:00+03	19600.00
5DA218	2017-07-26 11:37:00+03	232200.00
5DA304	2017-08-14 23:32:00+03	28800.00
5DA386	2017-07-08 03:43:00+03	118600.00
5DA3F1	2017-07-19 18:09:00+03	137100.00
5DA40A	2017-08-09 00:18:00+03	56000.00
5DA430	2017-07-22 18:31:00+03	6000.00
5DA452	2017-08-10 09:44:00+03	92000.00
5DA47D	2017-08-13 03:20:00+03	114100.00
5DA4BB	2017-07-24 06:47:00+03	52000.00
5DA4BE	2017-07-15 01:12:00+03	57600.00
5DA535	2017-07-22 20:03:00+03	202500.00
5DA537	2017-07-20 19:45:00+03	40000.00
5DA53A	2017-08-03 02:07:00+03	30200.00
5DA53F	2017-08-12 19:03:00+03	26700.00
5DA54D	2017-07-30 18:05:00+03	56000.00
5DA58B	2017-07-21 02:01:00+03	73600.00
5DA62D	2017-07-12 23:29:00+03	194300.00
5DA680	2017-07-09 20:19:00+03	23600.00
5DA70B	2017-07-11 16:52:00+03	22000.00
5DA70C	2017-07-15 09:20:00+03	75600.00
5DA7B8	2017-07-04 11:39:00+03	7200.00
5DA7DA	2017-07-13 16:23:00+03	93700.00
5DA7DE	2017-07-08 01:34:00+03	176500.00
5DA839	2017-07-20 08:05:00+03	310100.00
5DA896	2017-07-15 07:56:00+03	28000.00
5DA8F8	2017-07-05 17:42:00+03	6000.00
5DA92C	2017-08-05 14:55:00+03	66300.00
5DA9FF	2017-07-17 16:32:00+03	31600.00
5DAA2C	2017-07-10 07:57:00+03	12400.00
5DAA4D	2017-07-15 16:16:00+03	13400.00
5DAA63	2017-07-29 03:53:00+03	55800.00
5DAAA9	2017-07-09 18:46:00+03	260900.00
5DAABC	2017-07-05 23:42:00+03	25800.00
5DAB00	2017-07-11 14:56:00+03	24400.00
5DAC5B	2017-07-18 07:56:00+03	100200.00
5DACC5	2017-07-15 04:10:00+03	26800.00
5DACE7	2017-07-05 11:02:00+03	234600.00
5DAD23	2017-07-26 15:47:00+03	48500.00
5DAD48	2017-08-07 15:33:00+03	57600.00
5DAD90	2017-08-12 07:36:00+03	37700.00
5DADE5	2017-07-15 06:29:00+03	96800.00
5DAE1D	2017-07-14 00:31:00+03	112000.00
5DAE30	2017-07-22 03:26:00+03	14000.00
5DAE56	2017-07-26 15:33:00+03	659000.00
5DAE5B	2017-07-21 03:42:00+03	71200.00
5DAE9B	2017-07-14 02:11:00+03	27200.00
5DAEC2	2017-07-01 00:42:00+03	133100.00
5DAEE5	2017-07-30 09:36:00+03	65600.00
5DAF77	2017-07-01 02:24:00+03	28800.00
5DB021	2017-07-10 16:59:00+03	260300.00
5DB085	2017-08-02 12:01:00+03	21200.00
5DB086	2017-07-11 17:43:00+03	33200.00
5DB0FF	2017-07-31 13:36:00+03	272300.00
5DB10F	2017-07-23 23:10:00+03	99200.00
5DB112	2017-07-15 22:13:00+03	242600.00
5DB116	2017-07-12 16:27:00+03	6000.00
5DB152	2017-07-21 00:27:00+03	12000.00
5DB189	2017-07-23 14:30:00+03	144400.00
5DB18C	2017-07-29 08:29:00+03	99300.00
5DB202	2017-07-06 10:00:00+03	280300.00
5DB261	2017-07-13 06:00:00+03	133100.00
5DB284	2017-08-12 22:58:00+03	57400.00
5DB355	2017-07-14 21:12:00+03	23200.00
5DB35B	2017-07-08 19:48:00+03	66800.00
5DB3CF	2017-08-14 05:54:00+03	26000.00
5DB3F5	2017-08-05 02:22:00+03	135300.00
5DB440	2017-07-11 04:32:00+03	67100.00
5DB492	2017-07-18 04:36:00+03	73900.00
5DB4D4	2017-07-27 07:47:00+03	16400.00
5DB4EC	2017-07-28 00:37:00+03	40400.00
5DB544	2017-07-05 10:08:00+03	36200.00
5DB617	2017-08-13 04:18:00+03	42800.00
5DB687	2017-07-11 01:49:00+03	16400.00
5DB6B3	2017-08-13 14:25:00+03	92000.00
5DB6DF	2017-07-04 05:35:00+03	47000.00
5DB6F6	2017-07-22 03:52:00+03	105600.00
5DB828	2017-08-13 23:46:00+03	23100.00
5DB907	2017-07-16 05:32:00+03	125200.00
5DB913	2017-07-26 12:03:00+03	14000.00
5DB92D	2017-07-23 05:48:00+03	136200.00
5DB96D	2017-07-15 20:29:00+03	126700.00
5DBA3D	2017-08-06 16:24:00+03	12600.00
5DBA5E	2017-07-27 16:37:00+03	47400.00
5DBA6B	2017-07-14 07:42:00+03	79300.00
5DBAB3	2017-07-09 07:34:00+03	67600.00
5DBABD	2017-07-24 13:56:00+03	60900.00
5DBB05	2017-07-06 13:11:00+03	24400.00
5DBB4F	2017-07-02 12:31:00+03	58800.00
5DBB61	2017-08-03 16:21:00+03	28000.00
5DBB6D	2017-07-31 10:46:00+03	39200.00
5DBB89	2017-07-23 10:58:00+03	169600.00
5DBBAA	2017-07-28 23:47:00+03	28700.00
5DBBB7	2017-07-13 05:36:00+03	36200.00
5DBC03	2017-07-13 01:46:00+03	181800.00
5DBC1D	2017-08-08 09:49:00+03	398500.00
5DBC31	2017-08-15 07:39:00+03	61200.00
5DBC61	2017-07-18 04:14:00+03	61500.00
5DBC6A	2017-07-24 10:12:00+03	135600.00
5DBCDC	2017-07-16 09:14:00+03	407300.00
5DBCF1	2017-08-04 21:17:00+03	51900.00
5DBCFA	2017-07-18 11:02:00+03	6700.00
5DBD66	2017-07-15 15:22:00+03	46200.00
5DBD7D	2017-08-01 02:59:00+03	84800.00
5DBDD4	2017-07-13 12:00:00+03	40800.00
5DBE13	2017-07-24 03:44:00+03	85000.00
5DBE14	2017-08-02 09:38:00+03	16400.00
5DBE18	2017-08-10 21:57:00+03	103900.00
5DBE69	2017-07-04 19:09:00+03	134400.00
5DBE71	2017-07-16 07:09:00+03	76100.00
5DBE86	2017-06-30 06:26:00+03	39800.00
5DBEB4	2017-06-29 17:15:00+03	83700.00
5DBEF2	2017-07-09 12:26:00+03	89600.00
5DBFA9	2017-06-29 13:38:00+03	89600.00
5DBFCE	2017-07-07 02:14:00+03	37900.00
5DC020	2017-08-10 01:33:00+03	21800.00
5DC056	2017-07-30 16:20:00+03	65000.00
5DC09A	2017-07-25 10:37:00+03	26800.00
5DC0F4	2017-08-03 21:12:00+03	28000.00
5DC12B	2017-07-26 21:19:00+03	42400.00
5DC15E	2017-08-02 19:44:00+03	23900.00
5DC1AF	2017-07-24 19:37:00+03	29600.00
5DC1D3	2017-07-19 14:04:00+03	87100.00
5DC1EF	2017-07-20 10:25:00+03	47200.00
5DC22B	2017-07-29 00:43:00+03	7400.00
5DC238	2017-06-30 07:57:00+03	40800.00
5DC29B	2017-07-04 10:25:00+03	64800.00
5DC2BC	2017-07-05 09:04:00+03	86300.00
5DC2E8	2017-08-13 11:42:00+03	48900.00
5DC2EF	2017-08-12 20:35:00+03	58700.00
5DC307	2017-07-29 15:10:00+03	50800.00
5DC330	2017-07-11 12:12:00+03	283100.00
5DC3D7	2017-08-11 16:49:00+03	27200.00
5DC448	2017-07-19 19:32:00+03	26000.00
5DC449	2017-07-15 03:49:00+03	120000.00
5DC530	2017-07-09 04:01:00+03	89000.00
5DC575	2017-07-09 09:21:00+03	38400.00
5DC594	2017-07-05 10:24:00+03	198400.00
5DC5AD	2017-08-10 16:55:00+03	80000.00
5DC5CC	2017-08-07 20:33:00+03	56000.00
5DC67C	2017-08-05 05:35:00+03	51900.00
5DC6E0	2017-08-07 14:45:00+03	118100.00
5DC6F2	2017-07-06 01:02:00+03	55800.00
5DC6F5	2017-07-30 19:35:00+03	40800.00
5DC735	2017-07-11 02:50:00+03	66600.00
5DC75D	2017-07-20 15:31:00+03	70100.00
5DC7D9	2017-07-25 00:51:00+03	80900.00
5DC846	2017-07-29 10:07:00+03	24000.00
5DC8A4	2017-07-23 03:25:00+03	14000.00
5DC96A	2017-07-01 00:27:00+03	270700.00
5DC996	2017-07-10 01:58:00+03	31600.00
5DC9C6	2017-08-14 20:07:00+03	201200.00
5DCA09	2017-07-03 20:12:00+03	113600.00
5DCA31	2017-08-06 20:16:00+03	23600.00
5DCAAD	2017-08-12 00:42:00+03	46800.00
5DCB4C	2017-08-14 11:27:00+03	21800.00
5DCB5B	2017-08-13 14:30:00+03	81500.00
5DCB63	2017-08-09 23:58:00+03	32800.00
5DCB7C	2017-08-04 05:10:00+03	104000.00
5DCC34	2017-08-08 00:01:00+03	58800.00
5DCC47	2017-07-09 18:32:00+03	38200.00
5DCC84	2017-07-23 03:46:00+03	112000.00
5DCCAE	2017-08-13 08:56:00+03	35600.00
5DCD4A	2017-07-22 01:35:00+03	26800.00
5DCD9D	2017-07-25 02:01:00+03	24400.00
5DCE01	2017-07-23 20:28:00+03	26000.00
5DCE5B	2017-07-28 16:47:00+03	56200.00
5DCECA	2017-08-02 10:37:00+03	40400.00
5DCF14	2017-08-05 20:01:00+03	40000.00
5DCF63	2017-08-14 19:53:00+03	80500.00
5DCFBC	2017-07-23 07:45:00+03	319000.00
5DCFD1	2017-07-13 10:16:00+03	15400.00
5DCFEE	2017-08-06 16:31:00+03	26000.00
5DCFF8	2017-07-24 16:33:00+03	92000.00
5DCFFB	2017-07-08 16:03:00+03	126400.00
5DD004	2017-07-26 20:09:00+03	124100.00
5DD01B	2017-07-07 15:49:00+03	348800.00
5DD044	2017-08-15 06:53:00+03	77000.00
5DD066	2017-07-27 20:02:00+03	6000.00
5DD08B	2017-07-16 17:28:00+03	248500.00
5DD0F6	2017-08-08 10:12:00+03	35500.00
5DD116	2017-08-11 11:41:00+03	171100.00
5DD147	2017-07-30 23:40:00+03	108400.00
5DD1E1	2017-07-09 10:42:00+03	47000.00
5DD26A	2017-07-10 09:38:00+03	25600.00
5DD287	2017-07-05 12:50:00+03	25800.00
5DD2A9	2017-07-24 08:48:00+03	130800.00
5DD2C4	2017-08-07 22:11:00+03	26700.00
5DD305	2017-08-13 22:48:00+03	56000.00
5DD3AE	2017-08-08 08:12:00+03	51900.00
5DD3CE	2017-07-08 07:41:00+03	46400.00
5DD419	2017-08-01 15:01:00+03	303500.00
5DD484	2017-08-08 00:38:00+03	96300.00
5DD513	2017-07-16 02:49:00+03	291000.00
5DD58C	2017-07-28 04:47:00+03	46000.00
5DD67B	2017-08-13 19:11:00+03	69600.00
5DD692	2017-07-07 04:07:00+03	65400.00
5DD693	2017-07-08 14:00:00+03	85400.00
5DD6A2	2017-07-07 01:44:00+03	64700.00
5DD6DA	2017-07-23 03:42:00+03	119600.00
5DD731	2017-08-03 16:13:00+03	27200.00
5DD7CB	2017-08-10 18:37:00+03	22600.00
5DD7F7	2017-08-01 15:16:00+03	399600.00
5DD81D	2017-07-21 03:23:00+03	12100.00
5DD829	2017-07-20 12:45:00+03	31100.00
5DD859	2017-07-18 12:19:00+03	92800.00
5DD88C	2017-07-30 07:21:00+03	32700.00
5DD8CC	2017-08-01 21:58:00+03	86600.00
5DD8CE	2017-07-25 06:54:00+03	40800.00
5DD8D6	2017-08-07 14:53:00+03	65500.00
5DD922	2017-06-27 13:59:00+03	56600.00
5DD934	2017-08-05 11:33:00+03	62600.00
5DD9E1	2017-07-05 09:56:00+03	27300.00
5DD9F4	2017-07-24 18:30:00+03	14400.00
5DDB02	2017-07-31 02:42:00+03	40400.00
5DDB36	2017-07-10 17:20:00+03	13700.00
5DDB4E	2017-08-07 11:21:00+03	35600.00
5DDB78	2017-08-10 04:56:00+03	224700.00
5DDBCF	2017-08-14 16:32:00+03	132000.00
5DDC21	2017-07-17 11:34:00+03	55600.00
5DDC3F	2017-07-23 10:58:00+03	25200.00
5DDD7A	2017-08-08 08:30:00+03	52400.00
5DDD7F	2017-07-23 00:39:00+03	257600.00
5DDDB3	2017-07-17 15:50:00+03	319200.00
5DDE5B	2017-08-14 19:27:00+03	29800.00
5DDE8E	2017-08-15 13:41:00+03	55100.00
5DDEA5	2017-08-13 23:35:00+03	43800.00
5DDEAC	2017-07-27 18:58:00+03	22100.00
5DDEB3	2017-08-05 07:07:00+03	408500.00
5DDF7A	2017-07-13 16:41:00+03	59800.00
5DDF98	2017-07-03 13:11:00+03	55600.00
5DDFE4	2017-07-15 21:34:00+03	46400.00
5DE037	2017-08-09 12:03:00+03	56000.00
5DE060	2017-07-09 00:18:00+03	73300.00
5DE06E	2017-08-09 01:46:00+03	9200.00
5DE071	2017-07-16 10:00:00+03	99300.00
5DE0B9	2017-07-03 13:52:00+03	62000.00
5DE13D	2017-07-29 05:39:00+03	36200.00
5DE149	2017-07-11 07:17:00+03	46500.00
5DE1FF	2017-07-19 19:45:00+03	14000.00
5DE259	2017-06-26 16:52:00+03	117700.00
5DE25D	2017-07-05 11:01:00+03	13400.00
5DE2F4	2017-07-16 01:07:00+03	31100.00
5DE38A	2017-07-29 07:17:00+03	94800.00
5DE39F	2017-07-12 05:11:00+03	67600.00
5DE3BA	2017-07-18 05:41:00+03	11800.00
5DE47B	2017-08-01 13:41:00+03	31200.00
5DE4A9	2017-08-03 02:43:00+03	58600.00
5DE503	2017-08-11 22:45:00+03	55800.00
5DE596	2017-07-09 07:18:00+03	79900.00
5DE598	2017-07-13 18:11:00+03	8200.00
5DE5BA	2017-08-12 05:33:00+03	21200.00
5DE5F9	2017-08-08 00:06:00+03	258400.00
5DE604	2017-08-04 22:44:00+03	23200.00
5DE64D	2017-07-28 16:58:00+03	6700.00
5DE6ED	2017-07-15 12:04:00+03	27200.00
5DE6FA	2017-08-09 09:23:00+03	132800.00
5DE707	2017-08-10 16:23:00+03	60900.00
5DE780	2017-07-11 02:38:00+03	22000.00
5DE7C2	2017-08-15 16:08:00+03	28800.00
5DE8F7	2017-07-20 00:39:00+03	201800.00
5DE91F	2017-07-16 11:58:00+03	125100.00
5DE944	2017-07-18 16:21:00+03	147900.00
5DE950	2017-07-14 08:07:00+03	46400.00
5DE9F1	2017-08-11 17:18:00+03	11000.00
5DEA1C	2017-07-08 17:21:00+03	23600.00
5DEA3F	2017-08-05 07:15:00+03	43600.00
5DEA69	2017-07-18 13:49:00+03	55800.00
5DEB08	2017-08-15 01:34:00+03	24300.00
5DEBA1	2017-08-03 04:03:00+03	39800.00
5DEBAD	2017-08-13 17:05:00+03	103900.00
5DEBF1	2017-07-16 08:41:00+03	124600.00
5DEBF4	2017-07-18 01:17:00+03	25800.00
5DEC32	2017-07-03 00:27:00+03	162000.00
5DEC33	2017-07-12 12:33:00+03	28800.00
5DEC7D	2017-07-10 03:12:00+03	27800.00
5DECAA	2017-07-14 07:09:00+03	119700.00
5DECC4	2017-08-02 16:45:00+03	79600.00
5DECE2	2017-08-09 21:17:00+03	94000.00
5DED21	2017-08-04 15:47:00+03	36000.00
5DEDA6	2017-07-11 10:14:00+03	6000.00
5DEDF3	2017-07-21 20:30:00+03	67900.00
5DEDF7	2017-07-23 21:07:00+03	112000.00
5DEE56	2017-07-31 19:09:00+03	38500.00
5DEE5D	2017-07-18 02:17:00+03	14000.00
5DEE77	2017-07-25 20:18:00+03	80800.00
5DEED7	2017-08-11 00:12:00+03	30200.00
5DEFB6	2017-07-24 15:32:00+03	23500.00
5DEFE5	2017-08-06 01:09:00+03	26800.00
5DF02B	2017-07-28 19:43:00+03	75300.00
5DF067	2017-07-19 00:14:00+03	133200.00
5DF088	2017-08-09 08:30:00+03	46300.00
5DF125	2017-08-03 02:15:00+03	185400.00
5DF151	2017-07-25 07:38:00+03	72300.00
5DF173	2017-08-01 21:23:00+03	36200.00
5DF1BE	2017-07-15 06:42:00+03	29600.00
5DF1D1	2017-06-30 14:37:00+03	56900.00
5DF1DA	2017-08-12 22:27:00+03	59600.00
5DF283	2017-08-12 17:21:00+03	24000.00
5DF293	2017-07-21 13:56:00+03	4400.00
5DF2C0	2017-07-09 15:54:00+03	115100.00
5DF33D	2017-08-11 19:09:00+03	23200.00
5DF399	2017-07-30 05:45:00+03	188000.00
5DF39A	2017-07-27 05:58:00+03	27200.00
5DF3EB	2017-07-30 16:33:00+03	70400.00
5DF3F1	2017-07-22 05:25:00+03	28700.00
5DF465	2017-07-08 18:24:00+03	406700.00
5DF4CC	2017-08-11 02:08:00+03	48800.00
5DF4DE	2017-08-08 17:26:00+03	28000.00
5DF4EC	2017-08-09 20:12:00+03	72900.00
5DF500	2017-07-16 19:23:00+03	27700.00
5DF550	2017-07-15 19:55:00+03	9800.00
5DF55A	2017-08-08 17:32:00+03	209900.00
5DF5B7	2017-07-23 09:40:00+03	33400.00
5DF5C4	2017-07-18 11:36:00+03	37100.00
5DF5E7	2017-07-13 10:56:00+03	38600.00
5DF62B	2017-07-14 00:40:00+03	40400.00
5DF7F6	2017-07-20 08:08:00+03	71100.00
5DF7FA	2017-07-23 00:03:00+03	66100.00
5DF867	2017-07-22 09:44:00+03	246000.00
5DF8A4	2017-07-24 02:06:00+03	54800.00
5DF8EB	2017-08-10 13:47:00+03	189800.00
5DF8F4	2017-08-11 08:14:00+03	56800.00
5DF8F6	2017-08-01 20:01:00+03	41200.00
5DF9EF	2017-08-04 07:50:00+03	21800.00
5DFA31	2017-08-15 11:22:00+03	85000.00
5DFA4B	2017-07-17 23:59:00+03	33300.00
5DFAA6	2017-07-30 04:46:00+03	246000.00
5DFAE6	2017-07-26 09:20:00+03	51900.00
5DFB22	2017-08-07 07:12:00+03	131000.00
5DFB28	2017-08-05 14:29:00+03	47300.00
5DFB84	2017-07-03 15:32:00+03	26000.00
5DFBB8	2017-07-31 02:16:00+03	62800.00
5DFBEA	2017-07-16 12:33:00+03	30600.00
5DFC03	2017-07-21 04:26:00+03	188000.00
5DFC2D	2017-07-20 03:53:00+03	26200.00
5DFCD7	2017-08-09 04:16:00+03	12600.00
5DFD01	2017-07-25 21:27:00+03	90400.00
5DFD0E	2017-08-02 15:59:00+03	19600.00
5DFD5A	2017-06-30 09:10:00+03	24400.00
5DFD71	2017-07-16 06:11:00+03	32400.00
5DFDAC	2017-07-18 19:38:00+03	199700.00
5DFDB5	2017-07-24 17:12:00+03	155400.00
5DFE4F	2017-07-23 16:00:00+03	231800.00
5DFFB8	2017-07-21 02:20:00+03	57400.00
5DFFC7	2017-07-24 07:50:00+03	47200.00
5E0044	2017-07-31 15:30:00+03	516600.00
5E0059	2017-08-04 12:59:00+03	16400.00
5E0060	2017-07-22 15:21:00+03	21800.00
5E009E	2017-07-18 20:03:00+03	189200.00
5E00A6	2017-08-15 01:23:00+03	73600.00
5E00C0	2017-08-11 13:23:00+03	39000.00
5E0190	2017-07-03 05:03:00+03	85000.00
5E022F	2017-07-10 16:23:00+03	58200.00
5E023E	2017-07-27 19:42:00+03	7300.00
5E0267	2017-07-04 06:27:00+03	189800.00
5E0273	2017-07-25 09:48:00+03	90800.00
5E0296	2017-08-15 02:15:00+03	12600.00
5E02B8	2017-07-22 14:37:00+03	26800.00
5E02DB	2017-07-16 13:06:00+03	74900.00
5E02F5	2017-08-09 21:46:00+03	53500.00
5E0300	2017-07-21 16:25:00+03	53300.00
5E034C	2017-08-10 22:16:00+03	48800.00
5E0391	2017-07-13 18:29:00+03	28700.00
5E0466	2017-08-13 00:54:00+03	18800.00
5E0495	2017-07-29 03:50:00+03	40100.00
5E04F8	2017-07-13 23:47:00+03	130400.00
5E0512	2017-07-09 11:05:00+03	54000.00
5E053D	2017-08-12 16:05:00+03	25100.00
5E0562	2017-07-26 12:13:00+03	44800.00
5E0570	2017-07-21 16:49:00+03	252700.00
5E0596	2017-07-18 15:11:00+03	139200.00
5E0695	2017-07-17 02:06:00+03	68800.00
5E06AD	2017-07-08 09:56:00+03	76000.00
5E06F5	2017-08-12 06:55:00+03	35700.00
5E0741	2017-07-26 12:19:00+03	85000.00
5E0810	2017-08-05 19:26:00+03	194100.00
5E0873	2017-08-05 03:19:00+03	87000.00
5E08B4	2017-07-07 00:22:00+03	60900.00
5E08CF	2017-08-03 16:02:00+03	135600.00
5E0915	2017-07-23 00:07:00+03	8200.00
5E093C	2017-07-14 22:39:00+03	85900.00
5E095A	2017-07-01 16:13:00+03	66600.00
5E0970	2017-07-17 11:08:00+03	25400.00
5E09AD	2017-08-07 14:54:00+03	205700.00
5E09B7	2017-07-17 23:35:00+03	131600.00
5E0A36	2017-08-08 09:35:00+03	76300.00
5E0A3D	2017-07-19 09:45:00+03	37200.00
5E0A6E	2017-08-12 12:00:00+03	38600.00
5E0BDB	2017-07-02 23:02:00+03	133100.00
5E0D06	2017-08-03 14:33:00+03	123900.00
5E0D0E	2017-07-31 14:50:00+03	103500.00
5E0D3A	2017-07-06 22:09:00+03	233700.00
5E0D63	2017-07-28 20:36:00+03	30300.00
5E0D76	2017-08-02 12:40:00+03	20400.00
5E0DAB	2017-07-26 06:57:00+03	68100.00
5E0E94	2017-07-02 22:03:00+03	29400.00
5E0EA0	2017-07-29 22:15:00+03	111600.00
5E0ED5	2017-08-14 15:29:00+03	236500.00
5E0EDA	2017-07-06 14:45:00+03	59300.00
5E0EFD	2017-07-29 00:37:00+03	56100.00
5E0F03	2017-08-13 02:46:00+03	136200.00
5E0F43	2017-08-09 12:27:00+03	44600.00
5E0FBF	2017-07-06 05:56:00+03	24700.00
5E0FC6	2017-07-21 04:56:00+03	32400.00
5E0FEC	2017-08-03 04:44:00+03	75500.00
5E1061	2017-07-08 02:39:00+03	81700.00
5E10CC	2017-07-11 12:40:00+03	57600.00
5E10EF	2017-07-10 13:18:00+03	50700.00
5E10FC	2017-07-12 23:48:00+03	282000.00
5E1118	2017-07-24 04:17:00+03	49400.00
5E114C	2017-07-19 23:15:00+03	33800.00
5E11D4	2017-07-27 19:11:00+03	14400.00
5E11EF	2017-08-11 00:28:00+03	61800.00
5E1206	2017-08-13 05:42:00+03	37500.00
5E1210	2017-07-02 20:15:00+03	85000.00
5E1228	2017-07-13 06:49:00+03	52700.00
5E1291	2017-07-26 01:54:00+03	75500.00
5E1365	2017-08-05 00:03:00+03	118500.00
5E13E1	2017-07-07 01:04:00+03	31600.00
5E13EA	2017-07-01 13:42:00+03	31900.00
5E1416	2017-08-05 10:09:00+03	44600.00
5E1420	2017-08-01 08:04:00+03	8400.00
5E1515	2017-07-23 09:59:00+03	46000.00
5E153A	2017-08-10 19:39:00+03	42700.00
5E15A2	2017-07-27 20:36:00+03	46200.00
5E15FE	2017-07-26 11:59:00+03	32200.00
5E160C	2017-07-21 14:31:00+03	96600.00
5E1623	2017-07-19 03:48:00+03	99300.00
5E1631	2017-07-22 04:01:00+03	14400.00
5E16AC	2017-08-07 19:58:00+03	26000.00
5E16B3	2017-08-12 03:48:00+03	22300.00
5E16EE	2017-07-23 01:52:00+03	179400.00
5E1721	2017-07-04 14:51:00+03	298600.00
5E1782	2017-07-14 01:20:00+03	22000.00
5E17B9	2017-07-14 22:03:00+03	272400.00
5E1834	2017-07-21 01:36:00+03	27900.00
5E1932	2017-08-08 02:21:00+03	32300.00
5E19C6	2017-07-01 03:33:00+03	14000.00
5E19E6	2017-07-29 15:21:00+03	34400.00
5E1A79	2017-07-21 20:43:00+03	13200.00
5E1B0D	2017-07-06 10:18:00+03	59800.00
5E1B83	2017-08-14 21:06:00+03	30200.00
5E1B93	2017-07-28 16:17:00+03	52400.00
5E1BD8	2017-07-04 15:54:00+03	33800.00
5E1C29	2017-08-04 20:47:00+03	249200.00
5E1C9A	2017-07-03 00:48:00+03	67000.00
5E1CD2	2017-08-10 10:17:00+03	26000.00
5E1D43	2017-07-18 16:47:00+03	22000.00
5E1DA5	2017-08-05 10:41:00+03	93400.00
5E1DB8	2017-08-04 02:25:00+03	40800.00
5E1DCD	2017-08-01 10:03:00+03	63200.00
5E1DD9	2017-07-29 22:49:00+03	31600.00
5E1E0B	2017-07-19 07:47:00+03	32800.00
5E1E4D	2017-08-10 12:41:00+03	132800.00
5E1E4F	2017-07-15 04:38:00+03	108000.00
5E1EE2	2017-07-03 13:34:00+03	91300.00
5E1EF1	2017-07-19 16:15:00+03	41600.00
5E1F68	2017-07-06 17:52:00+03	28000.00
5E2035	2017-07-15 03:15:00+03	24800.00
5E2047	2017-08-14 15:35:00+03	78100.00
5E2079	2017-07-26 04:53:00+03	23200.00
5E20F9	2017-07-27 20:27:00+03	26000.00
5E217B	2017-07-27 06:56:00+03	36200.00
5E217E	2017-07-12 17:29:00+03	43000.00
5E219E	2017-07-06 00:17:00+03	100600.00
5E2215	2017-07-23 01:46:00+03	28000.00
5E2217	2017-07-23 19:05:00+03	112000.00
5E221A	2017-08-12 07:31:00+03	31600.00
5E2236	2017-08-12 01:48:00+03	154300.00
5E225C	2017-07-17 06:37:00+03	223400.00
5E2279	2017-07-15 21:28:00+03	96300.00
5E22D4	2017-08-02 11:30:00+03	64800.00
5E22DC	2017-07-20 22:36:00+03	14300.00
5E23E5	2017-07-07 23:28:00+03	64800.00
5E2416	2017-07-22 03:36:00+03	28000.00
5E2467	2017-07-14 23:56:00+03	26000.00
5E24FA	2017-08-12 13:08:00+03	420500.00
5E2528	2017-07-24 17:56:00+03	23600.00
5E255D	2017-08-04 04:07:00+03	58000.00
5E2565	2017-07-04 17:28:00+03	62600.00
5E2586	2017-07-04 19:16:00+03	20200.00
5E2591	2017-08-15 05:55:00+03	266400.00
5E25BF	2017-07-23 08:09:00+03	18000.00
5E2692	2017-07-10 04:22:00+03	94000.00
5E269D	2017-08-13 22:15:00+03	219300.00
5E26B4	2017-07-21 02:21:00+03	16400.00
5E26D2	2017-07-30 19:06:00+03	28000.00
5E26D8	2017-07-10 10:20:00+03	136800.00
5E2706	2017-08-03 01:45:00+03	31400.00
5E2732	2017-07-11 07:36:00+03	53600.00
5E275A	2017-08-13 13:55:00+03	43600.00
5E276F	2017-07-31 08:55:00+03	141600.00
5E27A7	2017-07-04 01:41:00+03	75500.00
5E280B	2017-06-28 23:15:00+03	35800.00
5E2841	2017-07-15 15:10:00+03	28300.00
5E2845	2017-07-24 22:04:00+03	49100.00
5E286D	2017-07-19 10:37:00+03	29200.00
5E290B	2017-07-16 17:04:00+03	111600.00
5E2A78	2017-08-13 03:43:00+03	40800.00
5E2AB7	2017-07-01 14:46:00+03	49600.00
5E2ABF	2017-08-13 16:50:00+03	52000.00
5E2AF7	2017-06-27 03:58:00+03	12400.00
5E2B11	2017-07-16 06:50:00+03	56000.00
5E2B62	2017-08-04 23:03:00+03	28800.00
5E2BF4	2017-08-05 05:38:00+03	54500.00
5E2C17	2017-08-02 14:19:00+03	67700.00
5E2C81	2017-07-03 22:29:00+03	31600.00
5E2C93	2017-07-12 18:42:00+03	46400.00
5E2CF8	2017-07-14 06:56:00+03	190400.00
5E2D08	2017-07-04 03:55:00+03	16400.00
5E2D3A	2017-06-26 14:34:00+03	85000.00
5E2D97	2017-07-14 12:25:00+03	73400.00
5E2DA4	2017-07-26 16:20:00+03	100600.00
5E2DC3	2017-08-07 23:15:00+03	15600.00
5E2DC6	2017-07-30 18:49:00+03	42800.00
5E2DF5	2017-08-14 13:22:00+03	12600.00
5E2E56	2017-07-14 18:31:00+03	13200.00
5E2E61	2017-08-05 14:22:00+03	48800.00
5E2E69	2017-07-18 21:11:00+03	36200.00
5E2E75	2017-07-29 13:03:00+03	385700.00
5E2E7B	2017-07-17 23:49:00+03	44800.00
5E2EE4	2017-08-05 03:31:00+03	43500.00
5E2F85	2017-07-08 20:30:00+03	59800.00
5E2FBA	2017-07-28 14:57:00+03	27300.00
5E2FBE	2017-08-04 10:24:00+03	116800.00
5E303B	2017-08-13 17:29:00+03	106400.00
5E305F	2017-07-15 17:00:00+03	88000.00
5E30BF	2017-07-07 03:34:00+03	98200.00
5E3114	2017-08-13 21:20:00+03	89700.00
5E3126	2017-07-04 12:36:00+03	60400.00
5E31BF	2017-07-12 07:42:00+03	67600.00
5E3202	2017-07-31 18:30:00+03	6000.00
5E3251	2017-08-08 00:53:00+03	101100.00
5E327A	2017-08-02 21:53:00+03	170000.00
5E32A7	2017-07-26 08:48:00+03	63200.00
5E32B7	2017-07-11 09:15:00+03	22000.00
5E3321	2017-07-15 01:11:00+03	139200.00
5E3357	2017-07-12 04:59:00+03	139500.00
5E3366	2017-07-19 16:47:00+03	73500.00
5E339E	2017-07-30 14:17:00+03	148200.00
5E33B0	2017-07-28 07:35:00+03	60400.00
5E33D6	2017-07-06 07:59:00+03	173500.00
5E33DC	2017-08-15 16:01:00+03	12000.00
5E33E4	2017-07-13 01:14:00+03	48800.00
5E33E9	2017-07-17 17:22:00+03	32800.00
5E33FC	2017-08-02 17:44:00+03	34000.00
5E3478	2017-07-05 11:30:00+03	150600.00
5E34F5	2017-07-23 15:03:00+03	138100.00
5E34F6	2017-07-04 12:04:00+03	46000.00
5E3585	2017-08-12 03:21:00+03	46300.00
5E3635	2017-08-08 15:29:00+03	53200.00
5E369F	2017-08-06 02:11:00+03	246000.00
5E36B6	2017-08-11 14:10:00+03	138000.00
5E36BD	2017-07-11 22:46:00+03	21200.00
5E36C2	2017-07-01 18:12:00+03	14400.00
5E370D	2017-07-08 14:56:00+03	135200.00
5E371B	2017-07-15 18:52:00+03	65400.00
5E3728	2017-08-13 05:51:00+03	11600.00
5E374A	2017-07-15 16:09:00+03	123000.00
5E3774	2017-07-06 09:22:00+03	229300.00
5E3778	2017-07-14 01:36:00+03	54800.00
5E37B0	2017-07-18 17:22:00+03	29600.00
5E37BA	2017-07-25 00:07:00+03	155600.00
5E37BF	2017-07-04 14:38:00+03	16400.00
5E37CB	2017-08-15 16:43:00+03	133200.00
5E38BF	2017-07-06 11:56:00+03	43900.00
5E38D2	2017-08-12 10:59:00+03	80700.00
5E38DE	2017-07-08 14:04:00+03	166100.00
5E38F2	2017-07-20 17:55:00+03	65500.00
5E3931	2017-07-23 12:55:00+03	16400.00
5E39CA	2017-08-11 04:12:00+03	87700.00
5E3AD8	2017-07-13 03:10:00+03	44000.00
5E3B50	2017-07-11 12:11:00+03	136200.00
5E3B81	2017-08-15 06:25:00+03	46700.00
5E3BA4	2017-07-22 16:45:00+03	46400.00
5E3BB2	2017-07-01 05:05:00+03	46700.00
5E3BBB	2017-07-10 22:49:00+03	58200.00
5E3BC7	2017-07-11 01:44:00+03	64200.00
5E3C19	2017-07-15 23:48:00+03	66000.00
5E3C24	2017-07-26 15:56:00+03	73600.00
5E3C5E	2017-07-11 12:58:00+03	53600.00
5E3C67	2017-08-15 17:44:00+03	17000.00
5E3C69	2017-08-03 16:00:00+03	98800.00
5E3C78	2017-08-07 17:00:00+03	67500.00
5E3C7A	2017-07-30 06:48:00+03	32700.00
5E3C82	2017-08-09 17:38:00+03	136800.00
5E3CA6	2017-07-06 01:27:00+03	193100.00
5E3D20	2017-07-28 09:28:00+03	320400.00
5E3D63	2017-08-03 00:11:00+03	223200.00
5E3D74	2017-07-15 01:12:00+03	63900.00
5E3D97	2017-06-29 13:35:00+03	135400.00
5E3DC7	2017-08-10 12:53:00+03	8200.00
5E3DCA	2017-07-21 20:57:00+03	26000.00
5E3DF7	2017-07-04 13:12:00+03	49900.00
5E3DFB	2017-08-11 19:49:00+03	31600.00
5E3E80	2017-08-09 12:52:00+03	289800.00
5E3EE3	2017-07-09 04:55:00+03	6800.00
5E3EF3	2017-07-26 16:11:00+03	16400.00
5E3F05	2017-07-19 19:00:00+03	111600.00
5E3F1D	2017-07-19 20:59:00+03	45200.00
5E40F3	2017-07-25 07:26:00+03	27300.00
5E41A0	2017-08-10 21:42:00+03	56000.00
5E41AE	2017-08-13 05:19:00+03	24000.00
5E41B0	2017-08-10 19:30:00+03	39500.00
5E41F2	2017-08-04 02:01:00+03	48500.00
5E4201	2017-08-08 16:08:00+03	62800.00
5E4203	2017-07-24 21:57:00+03	14000.00
5E420A	2017-07-04 09:47:00+03	59300.00
5E4243	2017-08-11 03:40:00+03	29100.00
5E4297	2017-06-30 19:17:00+03	38600.00
5E42C8	2017-07-05 02:27:00+03	26000.00
5E42F6	2017-07-20 14:52:00+03	75300.00
5E43B3	2017-08-05 12:04:00+03	63200.00
5E43BE	2017-08-07 21:36:00+03	46400.00
5E43E4	2017-07-18 05:26:00+03	18600.00
5E441C	2017-08-11 17:43:00+03	120900.00
5E4423	2017-06-26 08:38:00+03	43900.00
5E4436	2017-07-10 05:25:00+03	102100.00
5E448A	2017-08-10 02:43:00+03	84100.00
5E4595	2017-08-15 08:13:00+03	63000.00
5E45A6	2017-08-12 17:48:00+03	136000.00
5E45EF	2017-08-12 00:57:00+03	29400.00
5E4679	2017-07-16 05:19:00+03	27200.00
5E467C	2017-08-13 22:47:00+03	229900.00
5E467F	2017-08-15 07:56:00+03	46200.00
5E4696	2017-07-30 22:03:00+03	27500.00
5E46C6	2017-07-01 06:22:00+03	24200.00
5E46F3	2017-07-24 07:49:00+03	39600.00
5E473B	2017-07-27 06:40:00+03	7800.00
5E4796	2017-07-05 07:29:00+03	22300.00
5E4873	2017-07-09 00:19:00+03	13200.00
5E4891	2017-07-28 16:56:00+03	48800.00
5E48A7	2017-07-28 19:01:00+03	21400.00
5E48A8	2017-08-03 06:46:00+03	92800.00
5E4900	2017-07-02 19:05:00+03	30600.00
5E493D	2017-06-28 04:20:00+03	52700.00
5E49A2	2017-07-31 15:32:00+03	50800.00
5E49E5	2017-07-19 10:43:00+03	57700.00
5E4A09	2017-07-28 18:46:00+03	24300.00
5E4A20	2017-06-28 21:08:00+03	71000.00
5E4A31	2017-07-22 04:15:00+03	29800.00
5E4B3F	2017-08-14 05:03:00+03	30900.00
5E4B4E	2017-08-08 10:31:00+03	14000.00
5E4C22	2017-07-01 13:28:00+03	15000.00
5E4C2D	2017-08-10 02:00:00+03	80100.00
5E4C40	2017-08-12 03:33:00+03	52300.00
5E4C4F	2017-07-03 05:42:00+03	26400.00
5E4D18	2017-06-29 01:24:00+03	116000.00
5E4D20	2017-08-10 20:59:00+03	28600.00
5E4D2B	2017-07-07 05:58:00+03	51000.00
5E4D43	2017-08-11 20:17:00+03	33200.00
5E4DF6	2017-07-26 14:36:00+03	46400.00
5E4DFF	2017-07-08 06:38:00+03	105700.00
5E4E0F	2017-07-10 09:36:00+03	95000.00
5E4E2D	2017-07-18 21:43:00+03	85600.00
5E4EE5	2017-07-30 08:08:00+03	252200.00
5E4EF8	2017-07-08 19:50:00+03	36200.00
5E4EFB	2017-08-02 07:00:00+03	88800.00
5E4F23	2017-08-14 01:32:00+03	56600.00
5E4F36	2017-07-03 02:44:00+03	26000.00
5E4F64	2017-08-10 08:24:00+03	73500.00
5E4F8C	2017-07-10 10:21:00+03	195600.00
5E4FB0	2017-07-24 13:38:00+03	283100.00
5E4FD2	2017-08-12 18:21:00+03	28800.00
5E501C	2017-08-04 06:37:00+03	24800.00
5E5052	2017-07-08 20:35:00+03	23900.00
5E507D	2017-07-06 19:28:00+03	40000.00
5E508C	2017-08-11 19:45:00+03	28000.00
5E508E	2017-08-01 13:17:00+03	26000.00
5E5093	2017-07-28 22:13:00+03	155700.00
5E5168	2017-07-16 09:18:00+03	13400.00
5E516E	2017-07-07 23:02:00+03	270200.00
5E519E	2017-08-02 13:02:00+03	38800.00
5E5200	2017-08-05 17:00:00+03	56000.00
5E5204	2017-08-13 10:21:00+03	36800.00
5E5219	2017-06-28 21:34:00+03	32800.00
5E525A	2017-07-28 05:31:00+03	149800.00
5E526C	2017-08-12 05:27:00+03	45100.00
5E5284	2017-07-12 00:34:00+03	162200.00
5E534E	2017-08-06 15:13:00+03	46000.00
5E536F	2017-07-30 17:53:00+03	16300.00
5E53E9	2017-08-08 13:28:00+03	44500.00
5E541D	2017-07-18 11:42:00+03	62600.00
5E542A	2017-08-04 01:23:00+03	60400.00
5E5470	2017-07-17 02:59:00+03	134400.00
5E54C2	2017-08-01 02:19:00+03	83200.00
5E553A	2017-08-08 19:00:00+03	375200.00
5E5570	2017-07-20 03:43:00+03	59800.00
5E5584	2017-07-04 19:21:00+03	28000.00
5E558F	2017-07-12 20:20:00+03	55800.00
5E559F	2017-07-07 20:15:00+03	57600.00
5E55A1	2017-07-23 18:57:00+03	112000.00
5E55A4	2017-07-07 08:28:00+03	113000.00
5E5605	2017-07-03 01:25:00+03	6300.00
5E5653	2017-07-24 03:49:00+03	8400.00
5E5696	2017-07-19 02:50:00+03	135600.00
5E569C	2017-07-05 10:24:00+03	198400.00
5E56BC	2017-07-09 19:49:00+03	58700.00
5E56C3	2017-08-12 18:02:00+03	50600.00
5E56FF	2017-07-02 21:10:00+03	375200.00
5E57C7	2017-08-11 10:57:00+03	26800.00
5E5803	2017-07-10 19:02:00+03	41400.00
5E5819	2017-07-03 14:28:00+03	133200.00
5E582E	2017-07-31 23:36:00+03	67200.00
5E585F	2017-08-01 02:02:00+03	28400.00
5E58C7	2017-06-30 09:42:00+03	39300.00
5E58E2	2017-08-01 15:30:00+03	58800.00
5E5928	2017-07-29 08:40:00+03	23200.00
5E5941	2017-07-05 15:19:00+03	23600.00
5E595A	2017-07-22 09:22:00+03	49100.00
5E5995	2017-07-31 07:24:00+03	36100.00
5E59A1	2017-07-28 14:44:00+03	52300.00
5E59C8	2017-07-04 16:30:00+03	24400.00
5E5A4F	2017-08-14 02:06:00+03	50100.00
5E5A61	2017-08-11 14:05:00+03	393000.00
5E5A6B	2017-07-15 16:41:00+03	87100.00
5E5B18	2017-08-13 23:40:00+03	86300.00
5E5B29	2017-07-06 07:15:00+03	56000.00
5E5B31	2017-07-16 18:21:00+03	615000.00
5E5B34	2017-08-04 11:22:00+03	67600.00
5E5B48	2017-07-25 08:04:00+03	111600.00
5E5C0D	2017-07-07 00:54:00+03	224000.00
5E5C1F	2017-08-10 06:56:00+03	82600.00
5E5C29	2017-08-11 23:03:00+03	43600.00
5E5C6B	2017-07-13 10:34:00+03	129200.00
5E5C72	2017-07-05 12:29:00+03	67200.00
5E5C84	2017-07-27 20:28:00+03	131600.00
5E5C91	2017-07-19 01:18:00+03	69700.00
5E5CB6	2017-07-10 04:45:00+03	58600.00
5E5D37	2017-07-28 01:25:00+03	56000.00
5E5D4F	2017-07-09 21:58:00+03	83000.00
5E5DA7	2017-07-07 21:36:00+03	68100.00
5E5DBD	2017-08-13 22:52:00+03	11700.00
5E5E98	2017-08-03 21:18:00+03	97800.00
5E5F18	2017-07-17 05:52:00+03	66600.00
5E5F22	2017-07-24 20:03:00+03	75600.00
5E5F78	2017-07-18 21:01:00+03	24400.00
5E5FA7	2017-08-14 07:16:00+03	12600.00
5E5FC2	2017-08-10 11:38:00+03	28000.00
5E5FDA	2017-07-11 19:14:00+03	242300.00
5E6096	2017-08-03 19:28:00+03	271100.00
5E60A1	2017-07-17 09:33:00+03	31900.00
5E60D0	2017-08-05 17:22:00+03	86600.00
5E6137	2017-08-02 23:29:00+03	113300.00
5E6180	2017-07-06 05:04:00+03	52300.00
5E61C3	2017-07-02 10:24:00+03	15400.00
5E6296	2017-08-15 02:47:00+03	51400.00
5E6363	2017-08-08 07:16:00+03	113200.00
5E63C1	2017-07-14 16:21:00+03	116400.00
5E63CF	2017-07-09 04:32:00+03	28800.00
5E6404	2017-07-04 17:18:00+03	129700.00
5E6419	2017-07-06 02:17:00+03	154800.00
5E6436	2017-07-24 08:48:00+03	39900.00
5E6453	2017-08-09 09:16:00+03	30700.00
5E6494	2017-08-05 13:42:00+03	102000.00
5E649D	2017-08-08 02:16:00+03	22600.00
5E64C0	2017-07-15 19:52:00+03	92800.00
5E64E7	2017-07-05 07:28:00+03	37900.00
5E651D	2017-07-09 12:02:00+03	55800.00
5E6538	2017-08-11 08:42:00+03	155600.00
5E65BB	2017-07-30 04:27:00+03	67600.00
5E65DB	2017-06-30 18:53:00+03	123600.00
5E65DF	2017-08-05 07:01:00+03	37900.00
5E6666	2017-08-12 16:48:00+03	260300.00
5E667A	2017-08-04 09:35:00+03	11100.00
5E67B3	2017-08-09 02:18:00+03	14400.00
5E67C6	2017-07-22 10:12:00+03	55800.00
5E67EF	2017-08-03 00:46:00+03	61100.00
5E67F3	2017-07-31 01:15:00+03	28000.00
5E6839	2017-08-14 04:46:00+03	46400.00
5E6842	2017-07-16 11:59:00+03	25600.00
5E6857	2017-07-29 13:48:00+03	21400.00
5E68E0	2017-08-09 17:00:00+03	14000.00
5E6929	2017-07-04 00:14:00+03	57800.00
5E6953	2017-07-08 04:37:00+03	34600.00
5E6977	2017-07-19 16:08:00+03	369000.00
5E6995	2017-08-08 06:12:00+03	36800.00
5E69B7	2017-07-30 07:58:00+03	63200.00
5E69BC	2017-07-12 19:02:00+03	133100.00
5E69CB	2017-07-09 06:00:00+03	85800.00
5E6A60	2017-07-23 15:19:00+03	94700.00
5E6A96	2017-07-30 07:40:00+03	92800.00
5E6AAC	2017-07-15 18:20:00+03	98700.00
5E6B0A	2017-07-21 00:11:00+03	36200.00
5E6B14	2017-08-07 07:54:00+03	84500.00
5E6B77	2017-07-17 16:23:00+03	22000.00
5E6BC2	2017-08-03 16:58:00+03	25000.00
5E6C35	2017-08-08 13:01:00+03	282000.00
5E6CBB	2017-07-11 10:33:00+03	77100.00
5E6D23	2017-08-13 10:23:00+03	42800.00
5E6D70	2017-07-29 16:09:00+03	62600.00
5E6D7D	2017-07-11 03:53:00+03	51900.00
5E6D93	2017-08-14 08:09:00+03	89700.00
5E6DC9	2017-07-10 18:35:00+03	88000.00
5E6DD3	2017-07-17 01:01:00+03	86100.00
5E6DF9	2017-07-27 00:44:00+03	46000.00
5E6E44	2017-07-14 20:32:00+03	134400.00
5E6E98	2017-07-22 21:35:00+03	23600.00
5E6EE4	2017-07-20 20:57:00+03	29600.00
5E6FCB	2017-08-02 11:38:00+03	35200.00
5E6FEE	2017-07-09 07:17:00+03	119400.00
5E6FF5	2017-08-05 05:17:00+03	206400.00
5E708C	2017-08-02 16:20:00+03	46200.00
5E70A3	2017-07-10 22:12:00+03	54300.00
5E70D4	2017-07-21 09:09:00+03	27000.00
5E70F9	2017-08-09 01:43:00+03	77600.00
5E70FB	2017-07-08 22:21:00+03	111000.00
5E717A	2017-07-12 14:16:00+03	67600.00
5E71A8	2017-07-05 16:17:00+03	153900.00
5E71DC	2017-08-10 08:27:00+03	49200.00
5E7224	2017-07-11 00:02:00+03	73300.00
5E7244	2017-07-30 18:35:00+03	23600.00
5E7248	2017-08-14 12:15:00+03	66600.00
5E7281	2017-08-07 03:14:00+03	186900.00
5E72E7	2017-08-12 10:12:00+03	92800.00
5E7382	2017-07-13 15:24:00+03	44800.00
5E73BB	2017-08-08 13:07:00+03	15900.00
5E73DE	2017-07-14 21:33:00+03	182300.00
5E7427	2017-07-04 10:31:00+03	48800.00
5E74BB	2017-08-11 00:45:00+03	136100.00
5E74D2	2017-08-09 05:12:00+03	31600.00
5E7570	2017-06-30 04:31:00+03	26000.00
5E75D6	2017-06-27 15:19:00+03	31400.00
5E75F1	2017-08-05 00:42:00+03	83300.00
5E75F3	2017-06-30 09:43:00+03	109600.00
5E760E	2017-07-25 06:33:00+03	158600.00
5E7618	2017-07-28 12:56:00+03	43200.00
5E76C7	2017-07-11 04:28:00+03	50600.00
5E7723	2017-07-16 06:51:00+03	50800.00
5E7759	2017-07-11 09:52:00+03	20200.00
5E775F	2017-08-15 16:47:00+03	24700.00
5E7783	2017-07-25 10:37:00+03	38400.00
5E77C0	2017-07-28 11:06:00+03	46400.00
5E77E1	2017-08-15 07:08:00+03	48200.00
5E7847	2017-07-02 23:59:00+03	44700.00
5E78B3	2017-07-12 10:48:00+03	84000.00
5E78C5	2017-07-14 05:31:00+03	40800.00
5E78E6	2017-07-16 06:11:00+03	40800.00
5E78E8	2017-07-20 03:24:00+03	27300.00
5E78FC	2017-07-22 11:56:00+03	57600.00
5E7953	2017-07-31 01:41:00+03	45200.00
5E7955	2017-07-11 02:12:00+03	579000.00
5E795D	2017-07-31 02:04:00+03	49100.00
5E7977	2017-07-12 06:07:00+03	11800.00
5E7985	2017-07-29 16:40:00+03	146600.00
5E79E7	2017-08-06 21:04:00+03	68800.00
5E7A53	2017-07-28 05:45:00+03	35800.00
5E7AE7	2017-07-23 04:35:00+03	39200.00
5E7B19	2017-07-18 02:43:00+03	157900.00
5E7B35	2017-08-08 17:08:00+03	35700.00
5E7C43	2017-08-14 17:00:00+03	13000.00
5E7CB2	2017-07-23 08:54:00+03	81800.00
5E7D14	2017-07-20 12:54:00+03	175000.00
5E7D3D	2017-07-07 07:21:00+03	31600.00
5E7D4B	2017-07-16 18:25:00+03	129100.00
5E7D76	2017-08-14 15:40:00+03	52300.00
5E7D9C	2017-07-26 22:06:00+03	76600.00
5E7DBC	2017-07-25 14:43:00+03	27800.00
5E7DCE	2017-08-04 20:00:00+03	381500.00
5E7E27	2017-07-31 09:27:00+03	90800.00
5E7E30	2017-07-10 21:23:00+03	11700.00
5E7E43	2017-08-08 01:15:00+03	59200.00
5E7E8A	2017-07-17 22:05:00+03	48500.00
5E7EE3	2017-07-16 09:27:00+03	40100.00
5E7F1C	2017-08-11 16:53:00+03	35400.00
5E7F41	2017-08-05 03:15:00+03	22000.00
5E7F43	2017-08-03 19:22:00+03	111600.00
5E7F79	2017-07-31 04:24:00+03	89200.00
5E7F8A	2017-07-29 15:53:00+03	160200.00
5E7FC2	2017-08-13 07:01:00+03	144900.00
5E7FD7	2017-07-18 14:19:00+03	23200.00
5E7FE9	2017-08-05 09:36:00+03	83900.00
5E80AC	2017-08-10 08:52:00+03	114800.00
5E812B	2017-07-28 14:46:00+03	39800.00
5E8144	2017-07-31 03:16:00+03	15000.00
5E8199	2017-07-15 20:37:00+03	37500.00
5E81A1	2017-07-29 11:54:00+03	94000.00
5E81C7	2017-07-09 14:39:00+03	65300.00
5E821D	2017-07-04 10:37:00+03	76800.00
5E822C	2017-07-14 08:00:00+03	44000.00
5E8249	2017-06-29 19:45:00+03	28000.00
5E8251	2017-07-17 03:10:00+03	8400.00
5E82AF	2017-07-08 04:22:00+03	78300.00
5E82FC	2017-08-03 01:51:00+03	147100.00
5E82FE	2017-07-02 13:27:00+03	24700.00
5E831F	2017-07-27 19:43:00+03	28200.00
5E83B4	2017-07-02 12:23:00+03	502800.00
5E83E1	2017-08-15 09:09:00+03	135000.00
5E83E9	2017-08-09 00:08:00+03	99200.00
5E847D	2017-07-06 20:01:00+03	34100.00
5E84A7	2017-07-21 06:39:00+03	14100.00
5E84D1	2017-07-22 17:38:00+03	15900.00
5E8528	2017-08-14 07:10:00+03	292900.00
5E852D	2017-07-08 06:50:00+03	47200.00
5E855E	2017-08-05 22:29:00+03	87200.00
5E85DD	2017-08-15 09:11:00+03	108600.00
5E85F4	2017-07-14 06:57:00+03	38500.00
5E862B	2017-07-25 05:03:00+03	6300.00
5E8651	2017-07-14 01:09:00+03	11800.00
5E86B5	2017-07-05 10:01:00+03	62000.00
5E8779	2017-07-27 18:30:00+03	106900.00
5E878B	2017-07-15 03:51:00+03	73900.00
5E8801	2017-07-29 18:19:00+03	118500.00
5E881C	2017-08-13 08:50:00+03	123000.00
5E8848	2017-07-15 18:16:00+03	49400.00
5E8851	2017-08-05 14:34:00+03	44000.00
5E88D2	2017-07-04 03:37:00+03	67000.00
5E8916	2017-07-29 14:41:00+03	38800.00
5E892B	2017-07-07 03:32:00+03	22600.00
5E8945	2017-08-15 07:10:00+03	40000.00
5E895C	2017-08-15 01:46:00+03	36600.00
5E8969	2017-07-06 08:26:00+03	36000.00
5E8A27	2017-07-04 08:08:00+03	12600.00
5E8A82	2017-08-11 11:10:00+03	31200.00
5E8AC3	2017-07-23 10:02:00+03	153200.00
5E8AD2	2017-07-08 08:38:00+03	44000.00
5E8B76	2017-07-12 12:13:00+03	17200.00
5E8BCC	2017-08-06 06:07:00+03	58600.00
5E8C1E	2017-08-06 14:05:00+03	13200.00
5E8C6B	2017-07-11 05:17:00+03	92800.00
5E8C71	2017-07-12 21:55:00+03	34100.00
5E8C8A	2017-07-01 22:47:00+03	265700.00
5E8CE6	2017-07-29 10:55:00+03	51900.00
5E8CF5	2017-07-10 17:05:00+03	11300.00
5E8CFE	2017-07-08 06:26:00+03	32800.00
5E8D20	2017-08-04 20:53:00+03	66800.00
5E8D50	2017-07-29 03:25:00+03	20600.00
5E8D5C	2017-07-24 06:55:00+03	67600.00
5E8D5E	2017-07-31 01:07:00+03	47100.00
5E8D8F	2017-07-11 09:59:00+03	42100.00
5E8D97	2017-07-09 21:59:00+03	67200.00
5E8E34	2017-07-23 05:38:00+03	85000.00
5E8F04	2017-08-02 23:47:00+03	28000.00
5E8F08	2017-07-11 04:24:00+03	85700.00
5E8F7A	2017-08-13 23:45:00+03	35800.00
5E8FBF	2017-08-01 20:37:00+03	73500.00
5E905D	2017-07-22 06:18:00+03	73200.00
5E9085	2017-08-04 04:50:00+03	91500.00
5E908B	2017-07-24 04:39:00+03	71600.00
5E90DA	2017-08-13 02:22:00+03	93400.00
5E90E0	2017-07-13 17:07:00+03	78300.00
5E9159	2017-07-04 10:07:00+03	291000.00
5E9174	2017-07-19 16:04:00+03	34800.00
5E91B0	2017-07-10 18:46:00+03	43600.00
5E9225	2017-06-26 13:02:00+03	26200.00
5E92C3	2017-07-14 14:43:00+03	122700.00
5E92E7	2017-07-25 06:59:00+03	147100.00
5E93B1	2017-07-09 23:51:00+03	43600.00
5E93BB	2017-08-14 16:06:00+03	32400.00
5E93F1	2017-07-23 21:51:00+03	63100.00
5E93F6	2017-06-29 07:06:00+03	46700.00
5E93FE	2017-07-09 07:33:00+03	114800.00
5E9424	2017-07-28 20:19:00+03	61800.00
5E9463	2017-07-28 09:41:00+03	55800.00
5E9474	2017-07-05 13:47:00+03	101900.00
5E947A	2017-07-05 04:47:00+03	28700.00
5E94A1	2017-08-08 06:23:00+03	28000.00
5E94A8	2017-07-24 03:30:00+03	82000.00
5E94CC	2017-08-10 20:54:00+03	68400.00
5E95EC	2017-07-17 22:19:00+03	26000.00
5E9619	2017-08-03 09:47:00+03	49600.00
5E9647	2017-08-10 23:45:00+03	44000.00
5E966C	2017-07-04 03:25:00+03	14400.00
5E9697	2017-08-01 14:59:00+03	93400.00
5E96B3	2017-07-31 04:29:00+03	6000.00
5E96CA	2017-07-16 07:29:00+03	11800.00
5E96F2	2017-08-06 00:20:00+03	56600.00
5E971C	2017-07-26 22:29:00+03	59800.00
5E9765	2017-07-27 17:48:00+03	18000.00
5E97FE	2017-08-13 00:39:00+03	180000.00
5E980E	2017-07-19 14:24:00+03	115600.00
5E983D	2017-08-02 03:09:00+03	12600.00
5E9882	2017-07-26 02:13:00+03	64500.00
5E9890	2017-07-06 08:01:00+03	76600.00
5E98B5	2017-07-25 01:10:00+03	90300.00
5E98BA	2017-07-29 21:10:00+03	12600.00
5E98CE	2017-07-14 23:28:00+03	47500.00
5E98E0	2017-07-09 11:53:00+03	56000.00
5E98E9	2017-08-06 11:29:00+03	17200.00
5E98FB	2017-07-23 14:56:00+03	65200.00
5E9908	2017-07-16 08:17:00+03	25800.00
5E99F5	2017-07-29 03:51:00+03	45100.00
5E9A27	2017-08-02 19:39:00+03	99300.00
5E9AC7	2017-08-11 18:44:00+03	6700.00
5E9B89	2017-07-14 07:46:00+03	27900.00
5E9BDB	2017-07-01 15:14:00+03	77000.00
5E9C16	2017-08-12 19:41:00+03	165100.00
5E9C3D	2017-07-02 14:53:00+03	102200.00
5E9C47	2017-07-10 16:20:00+03	75100.00
5E9C6F	2017-07-08 22:08:00+03	28800.00
5E9D0F	2017-07-29 14:11:00+03	29200.00
5E9D60	2017-07-06 22:39:00+03	10700.00
5E9DB6	2017-07-07 11:28:00+03	57200.00
5E9DD3	2017-07-22 19:08:00+03	123600.00
5E9DF4	2017-08-05 06:40:00+03	72200.00
5E9DF6	2017-06-30 05:13:00+03	131600.00
5E9E14	2017-07-29 02:15:00+03	183600.00
5E9EB3	2017-08-05 22:10:00+03	13600.00
5E9ED7	2017-08-01 09:04:00+03	26700.00
5E9EED	2017-07-24 03:56:00+03	199700.00
5E9F2D	2017-08-12 00:30:00+03	62600.00
5E9F3D	2017-07-08 16:29:00+03	112000.00
5E9F5C	2017-08-15 02:29:00+03	59200.00
5E9FDB	2017-08-08 18:22:00+03	40400.00
5E9FE0	2017-07-05 22:32:00+03	26000.00
5EA093	2017-08-04 12:26:00+03	39500.00
5EA09C	2017-06-30 02:27:00+03	19800.00
5EA0A2	2017-08-07 23:22:00+03	73400.00
5EA0AF	2017-08-10 08:42:00+03	27200.00
5EA0B5	2017-07-20 17:04:00+03	67200.00
5EA0C0	2017-08-09 07:39:00+03	112000.00
5EA0D0	2017-07-15 11:13:00+03	71400.00
5EA18C	2017-07-29 23:06:00+03	57500.00
5EA1DA	2017-07-14 06:59:00+03	31600.00
5EA233	2017-07-27 03:19:00+03	91300.00
5EA252	2017-07-04 23:55:00+03	24300.00
5EA269	2017-07-08 02:40:00+03	40800.00
5EA26B	2017-07-18 08:44:00+03	6800.00
5EA277	2017-08-01 01:16:00+03	27200.00
5EA2DC	2017-08-07 19:58:00+03	16400.00
5EA327	2017-08-06 00:36:00+03	149200.00
5EA372	2017-07-30 16:10:00+03	80700.00
5EA3C2	2017-07-11 10:33:00+03	58200.00
5EA3DE	2017-08-05 18:00:00+03	76400.00
5EA3EB	2017-07-19 10:52:00+03	102800.00
5EA461	2017-07-29 16:11:00+03	44000.00
5EA48A	2017-07-18 16:44:00+03	19800.00
5EA4E8	2017-08-01 22:51:00+03	66800.00
5EA503	2017-08-03 19:02:00+03	12200.00
5EA508	2017-08-06 08:08:00+03	14000.00
5EA56D	2017-08-02 00:48:00+03	25400.00
5EA57B	2017-07-16 02:26:00+03	12000.00
5EA5F2	2017-08-10 11:31:00+03	52000.00
5EA675	2017-07-10 03:55:00+03	62800.00
5EA6DA	2017-08-05 14:06:00+03	160300.00
5EA6F4	2017-07-11 23:47:00+03	17600.00
5EA721	2017-07-14 12:13:00+03	20200.00
5EA731	2017-08-04 00:11:00+03	27800.00
5EA7CD	2017-07-17 13:26:00+03	23600.00
5EA861	2017-07-26 03:15:00+03	45600.00
5EA86A	2017-07-08 03:59:00+03	99200.00
5EA898	2017-08-08 00:41:00+03	23200.00
5EA909	2017-06-28 12:32:00+03	55000.00
5EA937	2017-08-13 21:24:00+03	136800.00
5EA946	2017-08-12 07:48:00+03	84700.00
5EA97B	2017-07-05 09:59:00+03	46000.00
5EA9A5	2017-08-02 00:49:00+03	398500.00
5EA9BC	2017-08-10 02:34:00+03	48000.00
5EAA3B	2017-08-12 15:56:00+03	26700.00
5EAA3C	2017-07-18 03:42:00+03	12600.00
5EAA4F	2017-07-04 23:26:00+03	68900.00
5EAA79	2017-08-03 20:46:00+03	72800.00
5EAA99	2017-07-24 12:27:00+03	16400.00
5EAAA4	2017-08-04 15:54:00+03	17800.00
5EAB20	2017-08-03 10:19:00+03	23400.00
5EAB46	2017-07-07 10:39:00+03	57400.00
5EAB6A	2017-07-04 03:30:00+03	62600.00
5EAB97	2017-08-11 05:38:00+03	52000.00
5EABF9	2017-07-20 13:17:00+03	14000.00
5EAC82	2017-07-11 17:00:00+03	13400.00
5EAC96	2017-07-21 04:05:00+03	84100.00
5EACA9	2017-08-09 12:01:00+03	134400.00
5EAD3E	2017-08-10 23:30:00+03	177200.00
5EAD80	2017-08-03 02:31:00+03	24700.00
5EAD9B	2017-08-11 19:38:00+03	27200.00
5EAE69	2017-07-10 20:21:00+03	130800.00
5EAF03	2017-07-11 13:21:00+03	48800.00
5EAF59	2017-07-28 14:17:00+03	70400.00
5EAF6F	2017-07-06 23:03:00+03	57600.00
5EAFE4	2017-07-19 11:36:00+03	45200.00
5EB06F	2017-07-16 23:01:00+03	81600.00
5EB073	2017-07-11 07:55:00+03	55800.00
5EB0B6	2017-07-21 01:34:00+03	109600.00
5EB0BF	2017-07-08 20:22:00+03	106100.00
5EB1AF	2017-07-29 09:02:00+03	73400.00
5EB229	2017-08-12 16:59:00+03	6000.00
5EB24E	2017-07-07 19:41:00+03	86400.00
5EB25C	2017-08-01 02:37:00+03	43700.00
5EB2AE	2017-08-04 10:07:00+03	25200.00
5EB2F2	2017-08-07 06:08:00+03	37900.00
5EB37B	2017-07-12 11:25:00+03	112000.00
5EB3B6	2017-07-08 20:00:00+03	72900.00
5EB3F2	2017-07-04 14:54:00+03	86800.00
5EB44D	2017-08-12 01:07:00+03	56100.00
5EB476	2017-07-12 12:54:00+03	90000.00
5EB47B	2017-07-27 20:47:00+03	12600.00
5EB494	2017-07-24 17:25:00+03	64200.00
5EB4A3	2017-07-07 22:54:00+03	65600.00
5EB4DA	2017-07-22 06:28:00+03	123000.00
5EB542	2017-07-29 14:34:00+03	132800.00
5EB575	2017-07-14 19:21:00+03	46300.00
5EB5E7	2017-08-02 16:46:00+03	137600.00
5EB65C	2017-08-05 13:43:00+03	158000.00
5EB6ED	2017-08-10 03:43:00+03	24400.00
5EB70A	2017-07-15 05:16:00+03	129000.00
5EB793	2017-07-14 04:05:00+03	90800.00
5EB821	2017-08-12 23:00:00+03	47600.00
5EB89B	2017-07-19 00:29:00+03	46400.00
5EB8C7	2017-07-19 01:54:00+03	55800.00
5EB903	2017-08-01 23:43:00+03	271400.00
5EB919	2017-07-02 11:59:00+03	12400.00
5EB925	2017-07-27 10:44:00+03	131000.00
5EB98C	2017-07-14 21:49:00+03	30800.00
5EB99D	2017-08-11 07:00:00+03	18600.00
5EBA68	2017-08-14 18:16:00+03	14400.00
5EBA7C	2017-08-08 21:42:00+03	26200.00
5EBA90	2017-07-25 18:28:00+03	26800.00
5EBB4D	2017-07-26 10:16:00+03	24000.00
5EBB4F	2017-08-04 12:17:00+03	46000.00
5EBB86	2017-07-11 03:57:00+03	99300.00
5EBBA5	2017-07-31 05:41:00+03	75300.00
5EBBB6	2017-08-09 23:01:00+03	27200.00
5EBBC8	2017-08-02 02:27:00+03	6000.00
5EBC58	2017-08-03 06:57:00+03	23200.00
5EBC91	2017-07-12 04:26:00+03	14800.00
5EBCF2	2017-07-25 22:22:00+03	43400.00
5EBD5E	2017-08-02 19:49:00+03	76900.00
5EBD65	2017-08-11 07:01:00+03	52400.00
5EBD87	2017-08-09 01:47:00+03	8400.00
5EBDAE	2017-08-10 00:47:00+03	11600.00
5EBDF8	2017-08-08 05:12:00+03	67400.00
5EBE65	2017-07-14 15:13:00+03	12400.00
5EBE68	2017-07-17 06:45:00+03	96000.00
5EBEFA	2017-07-04 15:50:00+03	136500.00
5EBF4F	2017-07-08 08:03:00+03	56000.00
5EBF7E	2017-07-12 11:58:00+03	266400.00
5EBF86	2017-07-16 05:24:00+03	27300.00
5EBFE3	2017-07-22 14:07:00+03	18000.00
5EC040	2017-07-17 06:49:00+03	55800.00
5EC0B5	2017-08-13 01:33:00+03	32200.00
5EC0C9	2017-07-06 16:41:00+03	27200.00
5EC0F7	2017-07-30 13:58:00+03	92000.00
5EC141	2017-07-07 10:37:00+03	101200.00
5EC19F	2017-08-14 16:52:00+03	534300.00
5EC1BE	2017-08-06 21:12:00+03	36600.00
5EC1E1	2017-07-18 11:00:00+03	84800.00
5EC26B	2017-07-11 07:34:00+03	111600.00
5EC2DF	2017-08-14 12:41:00+03	12600.00
5EC371	2017-07-24 22:35:00+03	194800.00
5EC3C1	2017-08-01 12:14:00+03	37800.00
5EC400	2017-07-29 20:57:00+03	111600.00
5EC403	2017-08-12 22:43:00+03	26800.00
5EC418	2017-07-06 00:31:00+03	57500.00
5EC43E	2017-07-13 07:44:00+03	34600.00
5EC4E1	2017-07-23 08:26:00+03	103200.00
5EC500	2017-07-16 01:37:00+03	61800.00
5EC566	2017-07-27 10:36:00+03	117200.00
5EC58C	2017-07-02 11:28:00+03	80900.00
5EC5D4	2017-07-21 21:37:00+03	16400.00
5EC5EB	2017-07-30 12:22:00+03	56700.00
5EC60F	2017-08-01 19:34:00+03	67600.00
5EC753	2017-08-05 20:09:00+03	111600.00
5EC784	2017-08-06 22:01:00+03	73600.00
5EC7D7	2017-07-07 19:45:00+03	46400.00
5EC7F8	2017-07-03 06:42:00+03	43500.00
5EC84D	2017-08-12 11:41:00+03	27200.00
5EC871	2017-07-05 21:04:00+03	167400.00
5EC903	2017-07-06 22:31:00+03	53800.00
5EC968	2017-07-24 16:18:00+03	46800.00
5EC971	2017-08-07 22:53:00+03	11600.00
5EC9AE	2017-06-30 02:33:00+03	29400.00
5EC9B5	2017-07-21 01:02:00+03	20200.00
5EC9C5	2017-07-15 13:39:00+03	46300.00
5ECA84	2017-08-14 17:57:00+03	185900.00
5ECA8C	2017-08-05 23:16:00+03	38600.00
5ECA97	2017-08-04 19:50:00+03	23400.00
5ECAE2	2017-07-27 03:48:00+03	27000.00
5ECAEC	2017-07-08 13:09:00+03	62600.00
5ECAF5	2017-07-09 16:20:00+03	73100.00
5ECB29	2017-07-07 19:10:00+03	38800.00
5ECB50	2017-07-29 19:44:00+03	43900.00
5ECB5B	2017-07-19 18:29:00+03	92900.00
5ECC1B	2017-08-04 17:46:00+03	79600.00
5ECCA7	2017-07-26 02:17:00+03	46200.00
5ECCAD	2017-06-28 23:06:00+03	53400.00
5ECCF1	2017-08-04 10:50:00+03	71900.00
5ECD20	2017-08-12 20:47:00+03	62800.00
5ECD34	2017-08-08 04:16:00+03	78600.00
5ECD5D	2017-07-09 04:45:00+03	179200.00
5ECD6E	2017-08-12 15:55:00+03	113700.00
5ECDE9	2017-07-20 21:37:00+03	56600.00
5ECE01	2017-08-09 18:10:00+03	18600.00
5ECE1B	2017-07-30 21:58:00+03	100600.00
5ECE20	2017-08-06 16:31:00+03	92100.00
5ECEAA	2017-07-28 03:58:00+03	64100.00
5ECF0F	2017-07-05 10:41:00+03	46000.00
5ECF30	2017-07-29 15:27:00+03	246000.00
5ECF5F	2017-07-18 03:48:00+03	31600.00
5ECF74	2017-07-06 14:02:00+03	129700.00
5ED0F3	2017-07-12 01:32:00+03	24200.00
5ED0F4	2017-07-28 09:36:00+03	28000.00
5ED0FA	2017-07-07 10:00:00+03	92800.00
5ED15A	2017-08-02 14:28:00+03	200300.00
5ED17A	2017-07-22 04:33:00+03	26000.00
5ED17F	2017-07-12 06:36:00+03	258400.00
5ED1BD	2017-08-13 04:52:00+03	75600.00
5ED221	2017-07-25 15:02:00+03	62800.00
5ED248	2017-07-10 20:25:00+03	250800.00
5ED25F	2017-07-04 14:06:00+03	40000.00
5ED2ED	2017-07-30 21:58:00+03	38600.00
5ED342	2017-08-01 02:02:00+03	46400.00
5ED440	2017-07-26 08:35:00+03	76600.00
5ED46E	2017-08-14 15:23:00+03	43000.00
5ED490	2017-07-13 21:49:00+03	44600.00
5ED4DE	2017-07-20 00:46:00+03	46400.00
5ED54F	2017-08-03 19:11:00+03	31400.00
5ED598	2017-07-16 08:53:00+03	62600.00
5ED5BA	2017-07-25 09:14:00+03	252200.00
5ED608	2017-08-01 15:14:00+03	58600.00
5ED6BD	2017-08-14 11:51:00+03	40800.00
5ED6FB	2017-07-11 04:48:00+03	73500.00
5ED768	2017-07-08 15:20:00+03	148200.00
5ED82D	2017-07-31 23:09:00+03	21800.00
5ED842	2017-08-10 20:01:00+03	58200.00
5ED8AA	2017-08-10 22:30:00+03	119600.00
5ED914	2017-07-09 06:48:00+03	143100.00
5ED92D	2017-07-17 20:34:00+03	34100.00
5ED940	2017-08-09 06:19:00+03	137800.00
5ED9D7	2017-07-28 19:21:00+03	67600.00
5ED9F5	2017-08-03 17:10:00+03	135200.00
5EDA00	2017-08-06 14:30:00+03	101200.00
5EDA1D	2017-07-20 09:14:00+03	393000.00
5EDA38	2017-07-19 05:38:00+03	36800.00
5EDAFB	2017-08-05 09:36:00+03	26000.00
5EDB4B	2017-07-19 10:49:00+03	36000.00
5EDB51	2017-07-24 23:57:00+03	55800.00
5EDBAF	2017-08-07 10:54:00+03	28800.00
5EDBBC	2017-07-16 19:46:00+03	125200.00
5EDBC1	2017-07-27 01:31:00+03	197600.00
5EDBCD	2017-07-04 22:08:00+03	24400.00
5EDBE2	2017-07-29 23:44:00+03	24400.00
5EDBEF	2017-08-03 12:38:00+03	79300.00
5EDC09	2017-07-13 14:06:00+03	187800.00
5EDC23	2017-07-11 00:00:00+03	43500.00
5EDC9C	2017-07-01 18:48:00+03	40800.00
5EDCB5	2017-07-29 01:53:00+03	12600.00
5EDCC2	2017-08-15 00:54:00+03	13400.00
5EDCFA	2017-07-19 11:59:00+03	68400.00
5EDD16	2017-07-07 01:19:00+03	46300.00
5EDD3D	2017-08-10 06:17:00+03	16000.00
5EDE1E	2017-07-16 06:10:00+03	23600.00
5EDEE9	2017-08-12 23:11:00+03	28600.00
5EDF06	2017-07-03 22:03:00+03	243600.00
5EDF0B	2017-08-13 14:42:00+03	135400.00
5EE076	2017-08-03 18:49:00+03	8000.00
5EE192	2017-08-03 23:36:00+03	65300.00
5EE1F2	2017-07-03 11:39:00+03	52700.00
5EE21E	2017-07-29 09:05:00+03	35400.00
5EE269	2017-07-17 05:23:00+03	56000.00
5EE26E	2017-07-04 16:40:00+03	23400.00
5EE2B5	2017-07-08 15:52:00+03	47000.00
5EE3AA	2017-07-25 02:26:00+03	40000.00
5EE425	2017-07-24 14:31:00+03	273000.00
5EE55D	2017-07-06 12:50:00+03	75300.00
5EE67A	2017-07-18 16:20:00+03	56000.00
5EE684	2017-07-27 20:07:00+03	21800.00
5EE686	2017-08-12 02:05:00+03	53100.00
5EE693	2017-07-06 20:16:00+03	22800.00
5EE6F4	2017-07-07 23:10:00+03	47800.00
5EE71A	2017-08-05 05:59:00+03	39800.00
5EE723	2017-07-31 01:44:00+03	24400.00
5EE87D	2017-07-21 23:59:00+03	55800.00
5EE8A2	2017-06-30 16:21:00+03	75800.00
5EE8D0	2017-08-13 07:23:00+03	136800.00
5EE907	2017-07-08 14:06:00+03	81400.00
5EE920	2017-08-06 12:17:00+03	99200.00
5EE92C	2017-07-11 14:05:00+03	96200.00
5EE93D	2017-07-11 11:19:00+03	68800.00
5EE95F	2017-07-30 21:22:00+03	119700.00
5EE965	2017-08-09 15:25:00+03	266200.00
5EE96D	2017-07-11 01:38:00+03	100600.00
5EE980	2017-07-20 21:46:00+03	23400.00
5EE997	2017-08-09 00:01:00+03	81600.00
5EE99D	2017-07-19 15:38:00+03	23200.00
5EE9F2	2017-07-20 08:20:00+03	12600.00
5EEA47	2017-08-02 12:33:00+03	44000.00
5EEA4A	2017-07-23 04:38:00+03	46700.00
5EEA7D	2017-08-12 01:00:00+03	56000.00
5EEA85	2017-07-31 01:49:00+03	37200.00
5EEAAF	2017-07-20 22:42:00+03	136800.00
5EEAD9	2017-08-07 13:29:00+03	35200.00
5EEB03	2017-07-19 05:13:00+03	25100.00
5EEB21	2017-07-21 16:19:00+03	58700.00
5EEB47	2017-07-06 12:34:00+03	22000.00
5EEBAC	2017-07-22 02:09:00+03	28000.00
5EEBB2	2017-07-23 12:25:00+03	170300.00
5EEC38	2017-08-03 14:21:00+03	14000.00
5EEC57	2017-08-05 00:15:00+03	34000.00
5EEC67	2017-08-12 07:52:00+03	43600.00
5EECBC	2017-08-15 06:49:00+03	67200.00
5EECBE	2017-07-29 08:34:00+03	46200.00
5EECC2	2017-07-21 09:37:00+03	47500.00
5EED19	2017-08-12 12:44:00+03	8000.00
5EED2F	2017-07-30 07:27:00+03	92900.00
5EED43	2017-08-09 09:43:00+03	316000.00
5EED7B	2017-07-04 19:37:00+03	55600.00
5EEDCD	2017-08-14 01:00:00+03	36400.00
5EEE13	2017-07-26 07:16:00+03	129000.00
5EEE53	2017-07-02 15:38:00+03	15000.00
5EEE71	2017-08-03 02:45:00+03	6300.00
5EEEC8	2017-07-31 15:49:00+03	38500.00
5EEECA	2017-07-07 15:59:00+03	69100.00
5EEEDA	2017-07-21 10:58:00+03	185600.00
5EEEEA	2017-07-05 13:17:00+03	28000.00
5EEF3B	2017-07-21 18:37:00+03	68800.00
5EEF6C	2017-07-23 19:56:00+03	69200.00
5EEFB8	2017-08-11 13:17:00+03	28000.00
5EEFBF	2017-07-14 15:13:00+03	55800.00
5EEFC8	2017-07-16 08:21:00+03	108600.00
5EEFD3	2017-08-06 05:33:00+03	14900.00
5EF002	2017-07-18 12:58:00+03	64700.00
5EF00C	2017-07-26 07:39:00+03	77200.00
5EF075	2017-07-09 03:52:00+03	26000.00
5EF0D4	2017-07-29 05:59:00+03	238800.00
5EF115	2017-07-31 10:25:00+03	16800.00
5EF166	2017-08-01 23:25:00+03	23400.00
5EF1C6	2017-07-16 00:01:00+03	88000.00
5EF2C0	2017-07-21 12:29:00+03	24300.00
5EF2EB	2017-08-03 03:53:00+03	70800.00
5EF30C	2017-08-06 17:20:00+03	46400.00
5EF320	2017-07-10 10:45:00+03	93900.00
5EF369	2017-07-12 23:31:00+03	58400.00
5EF39E	2017-07-15 12:52:00+03	53800.00
5EF3AF	2017-08-11 07:15:00+03	160800.00
5EF3E3	2017-07-29 03:27:00+03	14900.00
5EF45E	2017-07-20 13:58:00+03	22100.00
5EF48A	2017-07-30 14:07:00+03	399300.00
5EF49E	2017-08-05 19:56:00+03	67600.00
5EF4E2	2017-07-30 19:46:00+03	102600.00
5EF50B	2017-08-02 22:50:00+03	66000.00
5EF54C	2017-08-02 06:20:00+03	75600.00
5EF556	2017-07-12 09:19:00+03	75800.00
5EF580	2017-07-22 00:43:00+03	6000.00
5EF5B4	2017-08-05 13:05:00+03	47000.00
5EF5E0	2017-07-30 14:58:00+03	40400.00
5EF610	2017-08-02 18:46:00+03	25400.00
5EF68A	2017-08-01 09:20:00+03	92800.00
5EF6D4	2017-08-03 03:41:00+03	55800.00
5EF791	2017-07-04 01:08:00+03	31900.00
5EF79A	2017-07-15 11:11:00+03	132800.00
5EF867	2017-08-11 14:55:00+03	38600.00
5EF876	2017-07-23 09:43:00+03	149200.00
5EF98B	2017-07-06 07:30:00+03	51800.00
5EF9CD	2017-07-13 06:37:00+03	59800.00
5EFA42	2017-06-27 20:48:00+03	7400.00
5EFA56	2017-07-16 04:28:00+03	58900.00
5EFA5C	2017-07-06 07:16:00+03	25200.00
5EFA6A	2017-07-20 08:29:00+03	23400.00
5EFAE8	2017-07-11 23:10:00+03	112000.00
5EFB37	2017-08-08 22:39:00+03	28000.00
5EFB80	2017-08-13 16:36:00+03	246000.00
5EFB93	2017-07-31 00:07:00+03	6000.00
5EFBBC	2017-07-30 15:05:00+03	249200.00
5EFBF2	2017-08-01 22:51:00+03	76400.00
5EFC60	2017-07-29 18:23:00+03	119600.00
5EFC71	2017-07-04 03:20:00+03	81700.00
5EFC8F	2017-07-23 10:12:00+03	14800.00
5EFC97	2017-07-29 06:48:00+03	41200.00
5EFCE8	2017-08-09 23:50:00+03	239200.00
5EFD55	2017-07-18 01:28:00+03	133200.00
5EFD5C	2017-08-05 07:38:00+03	26000.00
5EFDB8	2017-08-01 15:23:00+03	90400.00
5EFDE0	2017-07-12 05:52:00+03	68800.00
5EFDF2	2017-08-04 16:57:00+03	111600.00
5EFE1B	2017-07-14 22:11:00+03	56600.00
5EFE1D	2017-08-07 03:29:00+03	656800.00
5EFEC6	2017-07-02 21:10:00+03	31200.00
5EFECE	2017-07-06 13:17:00+03	70700.00
5EFF30	2017-07-22 07:33:00+03	39300.00
5EFF34	2017-07-06 18:18:00+03	22100.00
5EFFE7	2017-08-10 02:11:00+03	24800.00
5F0009	2017-07-31 20:52:00+03	67700.00
5F0045	2017-08-09 06:48:00+03	58800.00
5F004D	2017-07-05 13:41:00+03	40800.00
5F0086	2017-08-05 05:19:00+03	80000.00
5F00A6	2017-07-17 12:05:00+03	56100.00
5F011E	2017-08-09 04:56:00+03	35900.00
5F012E	2017-08-12 15:21:00+03	56000.00
5F014A	2017-07-10 12:58:00+03	94400.00
5F0197	2017-07-03 11:13:00+03	28300.00
5F0233	2017-07-07 08:20:00+03	23200.00
5F024C	2017-07-06 13:43:00+03	26700.00
5F0283	2017-08-02 10:54:00+03	56000.00
5F02D6	2017-08-11 01:17:00+03	71800.00
5F0315	2017-08-09 15:21:00+03	67600.00
5F0375	2017-07-07 13:40:00+03	36000.00
5F041F	2017-07-15 22:15:00+03	111600.00
5F0463	2017-08-07 23:02:00+03	115600.00
5F04C8	2017-07-04 23:23:00+03	23600.00
5F055E	2017-08-05 09:11:00+03	96800.00
5F05CE	2017-07-07 06:22:00+03	224000.00
5F0614	2017-08-06 01:46:00+03	31600.00
5F0643	2017-07-06 01:01:00+03	115100.00
5F06C7	2017-08-15 07:59:00+03	135400.00
5F06D0	2017-08-06 08:24:00+03	26800.00
5F06DD	2017-07-25 14:20:00+03	67800.00
5F0743	2017-06-29 05:56:00+03	375200.00
5F0789	2017-07-28 18:24:00+03	86800.00
5F07AA	2017-07-04 09:25:00+03	16400.00
5F07CF	2017-07-31 11:49:00+03	34000.00
5F07F7	2017-07-13 15:42:00+03	92800.00
5F081F	2017-08-03 06:49:00+03	6000.00
5F08CE	2017-07-19 11:42:00+03	286100.00
5F08D6	2017-07-02 14:15:00+03	77200.00
5F09BA	2017-07-02 21:53:00+03	16400.00
5F09EE	2017-08-01 18:01:00+03	55800.00
5F0A07	2017-08-14 10:25:00+03	221500.00
5F0A74	2017-07-26 05:18:00+03	21800.00
5F0A89	2017-07-14 03:00:00+03	87100.00
5F0AAC	2017-07-08 03:05:00+03	48800.00
5F0ACC	2017-08-03 19:14:00+03	16400.00
5F0AE2	2017-07-23 19:50:00+03	40600.00
5F0BED	2017-07-10 23:41:00+03	24700.00
5F0CBA	2017-07-26 12:29:00+03	116100.00
5F0DF3	2017-07-16 06:18:00+03	34100.00
5F0E13	2017-08-09 13:10:00+03	26000.00
5F0E77	2017-07-04 00:23:00+03	77000.00
5F0E86	2017-07-14 06:18:00+03	73200.00
5F0E9C	2017-08-14 08:07:00+03	85000.00
5F0EE8	2017-08-01 14:26:00+03	89700.00
5F0F50	2017-07-21 02:21:00+03	46400.00
5F0F6E	2017-07-08 02:24:00+03	106100.00
5F0F91	2017-07-23 02:23:00+03	621200.00
5F0FD0	2017-06-25 00:02:00+03	201100.00
5F0FDD	2017-07-08 22:40:00+03	74200.00
5F0FEB	2017-08-01 17:13:00+03	19600.00
5F1009	2017-08-15 13:40:00+03	157600.00
5F1045	2017-07-22 18:30:00+03	266400.00
5F105F	2017-07-03 21:01:00+03	24200.00
5F1083	2017-07-19 05:12:00+03	46200.00
5F10FA	2017-07-20 12:45:00+03	12600.00
5F1145	2017-08-04 18:28:00+03	67400.00
5F1159	2017-07-08 21:50:00+03	36200.00
5F117D	2017-08-15 04:45:00+03	56000.00
5F11B7	2017-07-08 17:38:00+03	85400.00
5F11BE	2017-08-10 08:13:00+03	124200.00
5F11C2	2017-07-09 06:49:00+03	31400.00
5F11D3	2017-07-24 10:05:00+03	14400.00
5F1220	2017-07-08 22:28:00+03	118300.00
5F1264	2017-07-16 09:35:00+03	38800.00
5F127D	2017-08-13 23:24:00+03	40800.00
5F12A6	2017-08-03 23:05:00+03	51300.00
5F12D7	2017-07-23 15:56:00+03	38400.00
5F1355	2017-07-25 01:34:00+03	48000.00
5F1358	2017-07-13 12:10:00+03	83600.00
5F1385	2017-07-22 00:09:00+03	83000.00
5F13DD	2017-07-31 06:40:00+03	248300.00
5F1409	2017-07-11 12:09:00+03	101100.00
5F1468	2017-07-01 19:00:00+03	7200.00
5F147B	2017-08-06 21:09:00+03	75800.00
5F14B0	2017-07-03 16:27:00+03	32300.00
5F14B7	2017-07-05 02:49:00+03	49500.00
5F14E6	2017-07-19 17:40:00+03	56000.00
5F14FC	2017-07-09 15:19:00+03	39200.00
5F1523	2017-07-28 00:23:00+03	86600.00
5F15D2	2017-07-10 04:21:00+03	49100.00
5F15F7	2017-07-12 04:25:00+03	28000.00
5F15F9	2017-08-05 18:31:00+03	6000.00
5F160E	2017-08-11 08:27:00+03	114800.00
5F166C	2017-08-10 20:10:00+03	65500.00
5F1671	2017-07-22 10:51:00+03	11800.00
5F17A0	2017-08-13 12:56:00+03	16400.00
5F17A4	2017-08-14 13:51:00+03	37100.00
5F17B8	2017-08-04 20:30:00+03	44800.00
5F17D4	2017-08-03 09:44:00+03	59800.00
5F17F4	2017-08-09 15:17:00+03	50000.00
5F1888	2017-08-06 11:06:00+03	67200.00
5F18D8	2017-08-11 10:41:00+03	290500.00
5F18DB	2017-07-06 04:04:00+03	55800.00
5F192D	2017-08-14 18:28:00+03	135400.00
5F195A	2017-07-18 04:11:00+03	47800.00
5F1987	2017-07-02 19:50:00+03	75300.00
5F19A3	2017-08-03 08:45:00+03	123000.00
5F19C1	2017-07-30 00:13:00+03	40600.00
5F19DD	2017-07-04 05:12:00+03	20800.00
5F1AF5	2017-07-28 09:07:00+03	278600.00
5F1B26	2017-07-19 20:29:00+03	64800.00
5F1B91	2017-08-05 12:32:00+03	31400.00
5F1BF7	2017-07-04 06:07:00+03	97700.00
5F1C16	2017-07-08 12:56:00+03	46300.00
5F1C29	2017-07-19 12:47:00+03	43500.00
5F1C41	2017-07-27 00:59:00+03	67800.00
5F1CD7	2017-07-18 18:56:00+03	25800.00
5F1CF5	2017-07-28 13:56:00+03	31600.00
5F1D10	2017-07-26 10:41:00+03	136600.00
5F1D57	2017-08-14 08:06:00+03	22000.00
5F1D60	2017-07-07 22:09:00+03	28000.00
5F1D89	2017-07-13 02:20:00+03	135100.00
5F1DB3	2017-08-13 12:10:00+03	131600.00
5F1DD9	2017-07-26 04:02:00+03	41600.00
5F1DFB	2017-07-28 22:47:00+03	139700.00
5F1E38	2017-07-14 23:32:00+03	94700.00
5F1E8F	2017-07-13 11:11:00+03	65900.00
5F1EA6	2017-07-10 12:32:00+03	79800.00
5F1F7F	2017-07-24 13:31:00+03	133100.00
5F1F86	2017-07-05 23:52:00+03	123000.00
5F2038	2017-08-15 08:13:00+03	75600.00
5F20B8	2017-07-04 19:03:00+03	106900.00
5F2161	2017-06-29 02:32:00+03	90800.00
5F2197	2017-07-12 20:40:00+03	84200.00
5F21FA	2017-07-29 13:37:00+03	117600.00
5F2201	2017-08-10 09:51:00+03	135600.00
5F2231	2017-07-19 13:45:00+03	13600.00
5F2262	2017-07-21 01:14:00+03	57600.00
5F2286	2017-07-06 05:12:00+03	44000.00
5F22D9	2017-08-01 05:19:00+03	129600.00
5F2338	2017-07-22 09:13:00+03	52000.00
5F237F	2017-07-30 08:27:00+03	36600.00
5F2391	2017-07-29 20:49:00+03	11300.00
5F23CD	2017-07-15 13:07:00+03	46200.00
5F23D6	2017-08-06 06:21:00+03	67800.00
5F244E	2017-07-06 10:45:00+03	111600.00
5F245D	2017-07-23 11:53:00+03	46800.00
5F246A	2017-07-25 01:52:00+03	186900.00
5F2482	2017-07-16 20:04:00+03	56000.00
5F2490	2017-08-11 10:11:00+03	270700.00
5F2491	2017-07-23 20:40:00+03	42800.00
5F253D	2017-07-26 09:05:00+03	38400.00
5F2555	2017-08-08 17:30:00+03	83100.00
5F255F	2017-07-27 14:00:00+03	111600.00
5F2575	2017-07-05 11:04:00+03	31600.00
5F2584	2017-07-27 11:31:00+03	111600.00
5F2588	2017-08-14 13:04:00+03	39600.00
5F2604	2017-08-03 20:47:00+03	22000.00
5F2608	2017-07-06 14:50:00+03	44000.00
5F2612	2017-07-22 03:28:00+03	77300.00
5F2644	2017-07-24 11:49:00+03	85000.00
5F26A9	2017-07-07 18:53:00+03	62600.00
5F26C7	2017-07-29 02:39:00+03	43200.00
5F271E	2017-07-15 13:44:00+03	127300.00
5F2721	2017-07-27 10:57:00+03	19600.00
5F2734	2017-07-29 11:27:00+03	56600.00
5F2768	2017-08-12 07:50:00+03	24200.00
5F2783	2017-07-20 12:23:00+03	24200.00
5F27E8	2017-07-24 06:13:00+03	15800.00
5F282B	2017-07-06 05:01:00+03	71900.00
5F282D	2017-08-13 23:31:00+03	23600.00
5F2865	2017-07-19 12:17:00+03	113300.00
5F28B9	2017-08-10 20:12:00+03	28700.00
5F28E5	2017-07-12 04:11:00+03	22200.00
5F28F1	2017-08-05 23:09:00+03	57800.00
5F294B	2017-08-04 17:48:00+03	42700.00
5F2956	2017-07-18 15:24:00+03	27600.00
5F2A15	2017-07-21 07:08:00+03	36400.00
5F2A69	2017-07-16 19:21:00+03	62900.00
5F2A77	2017-07-11 13:10:00+03	52000.00
5F2A96	2017-07-08 14:54:00+03	23600.00
5F2AD5	2017-08-10 16:40:00+03	50600.00
5F2B50	2017-07-12 19:49:00+03	28800.00
5F2BBB	2017-08-08 03:18:00+03	58900.00
5F2BD5	2017-08-01 13:09:00+03	325800.00
5F2BEA	2017-07-29 04:47:00+03	56100.00
5F2BFD	2017-07-11 02:17:00+03	28000.00
5F2C09	2017-07-10 22:14:00+03	28800.00
5F2C28	2017-08-02 07:41:00+03	60400.00
5F2C58	2017-07-13 03:46:00+03	6700.00
5F2CC3	2017-07-22 20:21:00+03	58200.00
5F2D11	2017-07-14 10:36:00+03	44100.00
5F2D2F	2017-07-22 02:30:00+03	14400.00
5F2D8D	2017-07-12 23:54:00+03	23100.00
5F2DE4	2017-07-29 14:45:00+03	140200.00
5F2E0E	2017-07-19 02:41:00+03	59300.00
5F2E22	2017-07-06 12:44:00+03	41200.00
5F2F0E	2017-08-06 21:44:00+03	7200.00
5F2F3D	2017-07-22 03:46:00+03	8200.00
5F2F83	2017-07-21 06:37:00+03	69000.00
5F2F8D	2017-07-07 11:57:00+03	91600.00
5F2F92	2017-08-01 01:47:00+03	113000.00
5F2FAA	2017-07-27 20:09:00+03	124200.00
5F2FC8	2017-08-07 07:22:00+03	56600.00
5F2FED	2017-08-03 22:03:00+03	54400.00
5F303D	2017-07-28 10:18:00+03	35200.00
5F3045	2017-08-01 11:15:00+03	13600.00
5F309D	2017-08-02 16:30:00+03	88300.00
5F30F5	2017-08-11 03:31:00+03	37200.00
5F3160	2017-08-15 14:38:00+03	151600.00
5F319E	2017-07-12 23:10:00+03	27800.00
5F31DF	2017-07-11 22:06:00+03	89700.00
5F321B	2017-08-03 00:00:00+03	23200.00
5F322B	2017-07-07 07:52:00+03	32200.00
5F3231	2017-07-23 23:12:00+03	104600.00
5F3249	2017-07-27 10:32:00+03	75600.00
5F3292	2017-07-05 06:04:00+03	57400.00
5F32BF	2017-07-02 18:28:00+03	20600.00
5F3330	2017-07-29 20:07:00+03	124000.00
5F3332	2017-08-14 22:55:00+03	74600.00
5F33AB	2017-08-10 06:29:00+03	24000.00
5F33CF	2017-07-21 17:47:00+03	112600.00
5F33E7	2017-07-17 12:45:00+03	98300.00
5F3432	2017-07-29 12:21:00+03	105000.00
5F3487	2017-08-10 20:24:00+03	67600.00
5F348B	2017-07-11 14:22:00+03	8400.00
5F348C	2017-08-06 06:38:00+03	112600.00
5F34E0	2017-08-01 13:25:00+03	99300.00
5F3531	2017-07-03 12:45:00+03	155100.00
5F355D	2017-06-30 22:59:00+03	23200.00
5F35EE	2017-07-19 03:39:00+03	6600.00
5F3615	2017-06-28 14:38:00+03	25200.00
5F36BF	2017-08-11 02:44:00+03	27200.00
5F36D8	2017-07-26 18:43:00+03	52800.00
5F36EE	2017-08-11 05:24:00+03	62000.00
5F370B	2017-08-09 06:27:00+03	23200.00
5F372A	2017-07-07 02:17:00+03	31400.00
5F3765	2017-07-06 08:07:00+03	61800.00
5F377E	2017-08-03 04:20:00+03	28000.00
5F3790	2017-08-15 14:11:00+03	31600.00
5F37CA	2017-07-07 01:18:00+03	6700.00
5F37CD	2017-07-28 03:17:00+03	27300.00
5F3873	2017-07-13 05:38:00+03	50800.00
5F387B	2017-07-15 14:30:00+03	189800.00
5F389F	2017-07-13 02:00:00+03	77700.00
5F38C9	2017-07-27 17:24:00+03	199300.00
5F3905	2017-07-30 06:34:00+03	69500.00
5F3909	2017-07-08 03:21:00+03	132800.00
5F393C	2017-07-24 18:15:00+03	36800.00
5F3952	2017-07-15 02:46:00+03	12600.00
5F3953	2017-07-02 03:21:00+03	285000.00
5F397F	2017-07-03 11:16:00+03	58400.00
5F39CD	2017-08-12 20:04:00+03	7400.00
5F3A29	2017-07-11 16:35:00+03	133200.00
5F3A35	2017-07-17 12:33:00+03	94000.00
5F3A63	2017-07-07 02:11:00+03	100600.00
5F3A87	2017-07-22 08:19:00+03	63500.00
5F3B71	2017-07-06 16:16:00+03	52400.00
5F3B72	2017-07-22 11:53:00+03	133200.00
5F3B91	2017-08-12 07:52:00+03	52000.00
5F3BB7	2017-06-30 00:29:00+03	39200.00
5F3BBE	2017-07-24 15:13:00+03	19600.00
5F3BC7	2017-08-13 06:23:00+03	100000.00
5F3BDC	2017-07-24 03:58:00+03	19800.00
5F3C16	2017-08-12 21:18:00+03	74400.00
5F3C31	2017-07-16 20:53:00+03	40200.00
5F3C3E	2017-07-07 04:30:00+03	45200.00
5F3CA1	2017-07-13 07:25:00+03	266400.00
5F3CB8	2017-08-07 05:25:00+03	69500.00
5F3CF1	2017-07-23 23:14:00+03	37200.00
5F3D0F	2017-08-05 16:04:00+03	65900.00
5F3D61	2017-07-15 02:51:00+03	176400.00
5F3D62	2017-07-24 12:03:00+03	185600.00
5F3E4F	2017-08-13 21:46:00+03	92000.00
5F3ED3	2017-08-13 15:47:00+03	111600.00
5F3EEC	2017-07-22 00:24:00+03	48400.00
5F3EF8	2017-07-25 15:16:00+03	21200.00
5F3F1C	2017-07-12 18:52:00+03	77000.00
5F3F80	2017-07-07 07:46:00+03	11700.00
5F3FDB	2017-08-06 17:36:00+03	55800.00
5F4038	2017-07-19 02:49:00+03	37200.00
5F406D	2017-07-07 07:34:00+03	85700.00
5F4082	2017-08-02 18:19:00+03	88500.00
5F40CC	2017-07-15 01:40:00+03	29600.00
5F4156	2017-07-03 10:16:00+03	66000.00
5F41FA	2017-07-15 04:15:00+03	65800.00
5F422C	2017-07-23 14:04:00+03	23600.00
5F42BA	2017-08-14 07:00:00+03	29100.00
5F42CE	2017-07-13 05:41:00+03	25200.00
5F42D8	2017-08-12 23:29:00+03	127800.00
5F42F5	2017-08-11 14:50:00+03	128800.00
5F4336	2017-08-13 19:45:00+03	43900.00
5F43DF	2017-07-11 00:27:00+03	39200.00
5F43E2	2017-07-29 02:15:00+03	20400.00
5F43F0	2017-08-09 14:11:00+03	271800.00
5F441A	2017-07-16 01:38:00+03	25100.00
5F4465	2017-08-08 04:02:00+03	27200.00
5F447A	2017-07-31 00:54:00+03	38600.00
5F44AC	2017-07-19 14:39:00+03	45600.00
5F44B8	2017-07-26 16:26:00+03	177600.00
5F44F0	2017-07-08 07:31:00+03	148200.00
5F44FD	2017-08-13 00:07:00+03	47000.00
5F4513	2017-07-06 03:44:00+03	23900.00
5F4516	2017-08-14 02:06:00+03	52400.00
5F4536	2017-08-14 04:03:00+03	13400.00
5F4595	2017-07-11 08:13:00+03	83000.00
5F461F	2017-07-15 23:50:00+03	276500.00
5F4621	2017-07-30 00:46:00+03	35200.00
5F463E	2017-07-21 13:23:00+03	8200.00
5F465D	2017-07-08 06:20:00+03	16400.00
5F469A	2017-07-30 15:18:00+03	50100.00
5F4731	2017-07-22 21:07:00+03	43200.00
5F4739	2017-08-01 14:50:00+03	65800.00
5F473D	2017-08-01 18:49:00+03	101200.00
5F47A0	2017-08-02 14:28:00+03	59800.00
5F4814	2017-08-04 01:20:00+03	13600.00
5F4818	2017-07-17 18:07:00+03	65500.00
5F4819	2017-07-05 18:46:00+03	67700.00
5F4899	2017-07-05 16:41:00+03	241400.00
5F48D7	2017-07-15 14:58:00+03	6200.00
5F4904	2017-07-22 03:01:00+03	27600.00
5F4955	2017-07-10 13:25:00+03	50300.00
5F49FB	2017-08-06 02:36:00+03	22000.00
5F4A54	2017-08-07 16:17:00+03	93000.00
5F4BCA	2017-08-09 06:58:00+03	191000.00
5F4BF8	2017-08-06 03:09:00+03	23800.00
5F4BFE	2017-07-11 18:09:00+03	56000.00
5F4C0A	2017-07-18 22:32:00+03	46400.00
5F4C17	2017-07-08 01:08:00+03	61500.00
5F4C42	2017-07-01 07:13:00+03	256800.00
5F4C49	2017-07-11 14:36:00+03	141300.00
5F4C70	2017-08-02 21:17:00+03	76600.00
5F4CC3	2017-07-14 20:14:00+03	62600.00
5F4CE0	2017-08-03 18:35:00+03	28800.00
5F4CF1	2017-07-06 13:51:00+03	286100.00
5F4CFB	2017-08-13 05:26:00+03	18600.00
5F4D23	2017-07-29 11:37:00+03	34000.00
5F4D28	2017-08-11 19:30:00+03	6300.00
5F4DF0	2017-07-25 19:09:00+03	31900.00
5F4E60	2017-07-01 06:28:00+03	102100.00
5F4E6D	2017-08-03 00:39:00+03	150100.00
5F4E81	2017-06-30 02:21:00+03	146300.00
5F4EA0	2017-07-03 02:40:00+03	64800.00
5F4EA6	2017-07-11 08:32:00+03	101200.00
5F4F28	2017-07-29 02:13:00+03	40600.00
5F4F30	2017-07-22 06:38:00+03	266400.00
5F4F31	2017-07-21 17:52:00+03	207600.00
5F4F35	2017-07-24 10:16:00+03	194000.00
5F4F69	2017-07-04 01:11:00+03	23200.00
5F4FA0	2017-08-14 17:12:00+03	48400.00
5F5046	2017-07-19 19:58:00+03	32800.00
5F507F	2017-07-25 05:46:00+03	46400.00
5F50BD	2017-07-05 00:51:00+03	46400.00
5F5157	2017-07-09 01:01:00+03	13800.00
5F5178	2017-08-11 09:20:00+03	26800.00
5F51A5	2017-08-02 06:12:00+03	56000.00
5F51A7	2017-06-30 23:24:00+03	85000.00
5F51AF	2017-07-20 23:57:00+03	26000.00
5F51EE	2017-08-05 08:07:00+03	46000.00
5F5202	2017-07-19 23:13:00+03	36800.00
5F52D1	2017-08-07 13:23:00+03	257500.00
5F52E6	2017-07-23 00:13:00+03	36200.00
5F52ED	2017-08-07 23:06:00+03	51000.00
5F5446	2017-08-08 09:08:00+03	16400.00
5F5534	2017-07-13 22:07:00+03	51600.00
5F5552	2017-07-06 12:43:00+03	12600.00
5F5557	2017-08-08 09:31:00+03	83500.00
5F55C2	2017-08-10 06:57:00+03	48500.00
5F55DB	2017-07-03 05:13:00+03	18000.00
5F5605	2017-07-28 21:55:00+03	172700.00
5F5626	2017-07-12 16:20:00+03	13400.00
5F5645	2017-07-10 18:01:00+03	133200.00
5F569D	2017-08-02 09:29:00+03	16400.00
5F569E	2017-08-12 02:52:00+03	89200.00
5F56A5	2017-07-27 06:40:00+03	123000.00
5F56C6	2017-08-06 03:03:00+03	31600.00
5F5720	2017-08-02 01:46:00+03	51900.00
5F572F	2017-07-30 20:34:00+03	21200.00
5F5752	2017-07-30 02:18:00+03	173600.00
5F5778	2017-07-13 08:32:00+03	35700.00
5F578C	2017-07-02 18:50:00+03	95200.00
5F579C	2017-08-09 03:04:00+03	31200.00
5F57B7	2017-07-10 15:50:00+03	10800.00
5F57E9	2017-07-05 07:07:00+03	8400.00
5F580C	2017-07-27 20:42:00+03	61800.00
5F5862	2017-08-05 18:51:00+03	32800.00
5F5900	2017-07-01 00:28:00+03	30400.00
5F591C	2017-07-30 12:49:00+03	68800.00
5F5972	2017-07-25 01:19:00+03	67600.00
5F5982	2017-08-10 20:27:00+03	48800.00
5F5A1B	2017-07-06 07:04:00+03	53300.00
5F5A36	2017-07-06 16:38:00+03	23400.00
5F5A65	2017-07-22 19:07:00+03	96800.00
5F5A84	2017-07-15 13:38:00+03	28800.00
5F5B13	2017-07-06 13:09:00+03	47700.00
5F5B45	2017-08-15 01:31:00+03	103900.00
5F5B6E	2017-06-30 08:45:00+03	89700.00
5F5B9A	2017-07-14 09:57:00+03	35800.00
5F5BDF	2017-08-15 16:59:00+03	46400.00
5F5C0C	2017-08-12 02:49:00+03	124200.00
5F5C8B	2017-07-12 06:37:00+03	75600.00
5F5C93	2017-07-13 23:01:00+03	114800.00
5F5C9E	2017-06-28 19:00:00+03	103700.00
5F5CBA	2017-07-06 06:42:00+03	98700.00
5F5D1E	2017-07-15 12:05:00+03	44600.00
5F5DF1	2017-07-05 04:56:00+03	47900.00
5F5DF2	2017-08-06 12:56:00+03	128100.00
5F5E1A	2017-07-16 10:08:00+03	176500.00
5F5E21	2017-07-01 13:33:00+03	38400.00
5F5E89	2017-07-26 02:33:00+03	72200.00
5F5E8D	2017-08-04 17:17:00+03	133200.00
5F5E8E	2017-07-13 03:49:00+03	135400.00
5F5E96	2017-07-23 20:11:00+03	10600.00
5F5E97	2017-07-30 02:27:00+03	70700.00
5F5E9A	2017-08-10 19:15:00+03	26000.00
5F5E9D	2017-07-21 10:59:00+03	40000.00
5F5EF6	2017-07-26 05:39:00+03	40000.00
5F5F04	2017-08-09 15:39:00+03	203400.00
5F5F17	2017-06-30 18:58:00+03	56100.00
5F5F25	2017-07-09 11:20:00+03	40800.00
5F5F45	2017-07-03 13:18:00+03	26700.00
5F5F99	2017-07-27 13:04:00+03	20200.00
5F5FA0	2017-07-04 19:13:00+03	133200.00
5F5FE6	2017-07-11 06:01:00+03	6300.00
5F6035	2017-08-04 04:33:00+03	311900.00
5F604F	2017-08-01 03:50:00+03	117600.00
5F605A	2017-07-30 09:35:00+03	51900.00
5F6060	2017-07-21 03:24:00+03	114400.00
5F60F0	2017-08-14 18:42:00+03	104600.00
5F60F6	2017-07-23 23:14:00+03	13600.00
5F6176	2017-07-01 17:04:00+03	56000.00
5F61B5	2017-07-10 13:58:00+03	101200.00
5F61D3	2017-08-07 02:56:00+03	36200.00
5F61E0	2017-07-30 06:18:00+03	37900.00
5F6203	2017-07-15 18:15:00+03	48500.00
5F6271	2017-08-14 19:36:00+03	183100.00
5F628B	2017-08-01 06:48:00+03	38600.00
5F62D3	2017-07-22 14:42:00+03	12600.00
5F62ED	2017-08-07 00:21:00+03	54500.00
5F635E	2017-08-09 15:06:00+03	32700.00
5F63AC	2017-07-18 18:06:00+03	22600.00
5F63E0	2017-07-06 09:38:00+03	77500.00
5F6401	2017-07-10 23:11:00+03	97600.00
5F640C	2017-08-11 17:56:00+03	132600.00
5F640D	2017-08-06 16:22:00+03	76900.00
5F641F	2017-07-14 15:43:00+03	28800.00
5F6425	2017-07-16 11:04:00+03	20200.00
5F6426	2017-07-10 19:17:00+03	48900.00
5F6438	2017-08-06 11:38:00+03	85000.00
5F646E	2017-07-04 20:42:00+03	14900.00
5F64F8	2017-07-27 02:14:00+03	18600.00
5F6526	2017-08-03 03:04:00+03	72100.00
5F6563	2017-08-05 13:41:00+03	46400.00
5F6578	2017-07-07 02:06:00+03	59300.00
5F65B8	2017-08-14 11:05:00+03	6000.00
5F65F4	2017-07-31 17:00:00+03	54900.00
5F6614	2017-08-11 16:06:00+03	92800.00
5F6630	2017-07-27 23:38:00+03	76400.00
5F66A3	2017-07-23 03:00:00+03	19600.00
5F66DD	2017-07-29 18:54:00+03	25200.00
5F6701	2017-07-08 18:00:00+03	24400.00
5F671C	2017-07-23 19:06:00+03	92000.00
5F6746	2017-07-18 12:28:00+03	147700.00
5F67E6	2017-07-18 19:51:00+03	119500.00
5F67EC	2017-07-05 04:56:00+03	31600.00
5F67FC	2017-07-20 10:57:00+03	148200.00
5F68A7	2017-07-31 01:00:00+03	88800.00
5F68BB	2017-07-05 07:27:00+03	6000.00
5F68F4	2017-08-02 20:28:00+03	58900.00
5F6902	2017-07-28 10:40:00+03	223400.00
5F691B	2017-08-05 20:24:00+03	50800.00
5F6968	2017-07-09 23:57:00+03	40000.00
5F6981	2017-07-05 19:43:00+03	46400.00
5F698E	2017-07-31 21:33:00+03	125700.00
5F69A2	2017-06-30 04:31:00+03	47500.00
5F69F5	2017-08-08 21:06:00+03	26800.00
5F6A10	2017-07-03 05:23:00+03	99300.00
5F6A1B	2017-07-22 16:34:00+03	266400.00
5F6A82	2017-08-11 00:37:00+03	32200.00
5F6A9E	2017-07-06 10:53:00+03	232200.00
5F6AAF	2017-08-09 13:36:00+03	50300.00
5F6AD7	2017-07-10 12:52:00+03	107900.00
5F6AD8	2017-07-24 11:40:00+03	22100.00
5F6AD9	2017-08-06 13:45:00+03	40000.00
5F6B32	2017-07-25 23:37:00+03	65900.00
5F6B7F	2017-08-01 09:15:00+03	58200.00
5F6BC2	2017-07-21 06:08:00+03	36200.00
5F6C3A	2017-07-16 22:21:00+03	114700.00
5F6C61	2017-08-12 16:56:00+03	85600.00
5F6CAA	2017-07-20 19:35:00+03	30400.00
5F6D88	2017-07-05 12:20:00+03	43200.00
5F6DB1	2017-07-20 11:44:00+03	52700.00
5F6E18	2017-08-10 04:59:00+03	398400.00
5F6E20	2017-07-29 08:27:00+03	24200.00
5F6E7C	2017-07-28 07:11:00+03	49300.00
5F6EA7	2017-08-15 04:16:00+03	49800.00
5F6F2D	2017-08-09 17:37:00+03	40800.00
5F6F83	2017-07-07 16:23:00+03	24400.00
5F6F92	2017-08-01 01:19:00+03	66600.00
5F6FA7	2017-07-02 17:23:00+03	6700.00
5F7031	2017-07-10 01:41:00+03	67200.00
5F703C	2017-08-06 02:02:00+03	34000.00
5F707F	2017-08-02 18:20:00+03	73100.00
5F7101	2017-07-26 03:10:00+03	114100.00
5F7105	2017-08-07 20:33:00+03	20200.00
5F7161	2017-08-12 23:16:00+03	206400.00
5F7168	2017-07-04 11:11:00+03	179400.00
5F716A	2017-08-09 16:03:00+03	266400.00
5F7180	2017-08-02 16:25:00+03	26000.00
5F71A9	2017-07-29 08:22:00+03	18400.00
5F71C9	2017-07-24 21:49:00+03	71900.00
5F7223	2017-07-18 01:35:00+03	301600.00
5F7280	2017-07-13 18:29:00+03	26000.00
5F72AB	2017-07-16 22:50:00+03	94400.00
5F72DE	2017-07-04 13:11:00+03	6000.00
5F72F3	2017-07-15 11:33:00+03	28000.00
5F736D	2017-07-30 21:40:00+03	160700.00
5F73C2	2017-07-12 12:53:00+03	68800.00
5F73E2	2017-08-08 23:32:00+03	14000.00
5F73F2	2017-07-19 06:56:00+03	47600.00
5F74B1	2017-08-03 04:55:00+03	30200.00
5F74BF	2017-07-08 22:17:00+03	47000.00
5F756D	2017-07-26 14:01:00+03	65900.00
5F75DF	2017-07-22 17:03:00+03	39300.00
5F764C	2017-08-08 02:36:00+03	16400.00
5F765A	2017-07-13 21:14:00+03	53600.00
5F765C	2017-07-13 07:39:00+03	81500.00
5F7679	2017-07-25 23:19:00+03	58000.00
5F767E	2017-08-12 03:02:00+03	65500.00
5F76E3	2017-07-15 17:55:00+03	49900.00
5F772D	2017-07-10 08:31:00+03	112000.00
5F77B2	2017-08-01 00:51:00+03	25000.00
5F783B	2017-07-08 02:11:00+03	56000.00
5F7853	2017-07-21 13:48:00+03	48800.00
5F78BF	2017-08-01 07:05:00+03	72400.00
5F78C6	2017-08-09 07:09:00+03	169900.00
5F792A	2017-07-15 19:53:00+03	24700.00
5F792E	2017-08-06 05:06:00+03	554600.00
5F797C	2017-08-11 00:04:00+03	103500.00
5F79C1	2017-07-05 03:47:00+03	96800.00
5F79CC	2017-07-10 14:43:00+03	98600.00
5F79FA	2017-08-10 16:34:00+03	23600.00
5F7A5B	2017-08-15 15:15:00+03	205700.00
5F7AF9	2017-07-28 09:54:00+03	24200.00
5F7B10	2017-07-18 10:59:00+03	57600.00
5F7BFE	2017-08-15 04:12:00+03	18000.00
5F7C48	2017-07-06 13:35:00+03	111600.00
5F7C6B	2017-06-25 04:19:00+03	48500.00
5F7C79	2017-08-10 22:55:00+03	11800.00
5F7C95	2017-07-03 14:03:00+03	6800.00
5F7CA3	2017-07-16 13:04:00+03	135600.00
5F7CFF	2017-08-13 07:59:00+03	24400.00
5F7D1D	2017-07-11 15:44:00+03	31400.00
5F7D5B	2017-08-14 20:29:00+03	12600.00
5F7DC0	2017-08-03 14:02:00+03	35800.00
5F7DE5	2017-07-25 14:42:00+03	27800.00
5F7E0C	2017-07-25 02:32:00+03	509300.00
5F7E86	2017-07-20 09:56:00+03	26200.00
5F7EB8	2017-08-12 06:11:00+03	258400.00
5F7EF2	2017-07-09 16:16:00+03	90000.00
5F7F17	2017-08-02 22:59:00+03	23200.00
5F7F62	2017-07-16 23:53:00+03	185600.00
5F7F75	2017-07-17 00:36:00+03	52400.00
5F7FD3	2017-07-26 21:05:00+03	47200.00
5F802E	2017-08-15 15:27:00+03	386300.00
5F8056	2017-07-19 01:53:00+03	71100.00
5F805C	2017-07-18 23:07:00+03	11200.00
5F8084	2017-07-17 17:36:00+03	125700.00
5F808A	2017-07-09 20:32:00+03	19600.00
5F80BE	2017-07-14 03:34:00+03	75300.00
5F80CF	2017-07-18 11:44:00+03	22000.00
5F80D6	2017-07-24 03:37:00+03	15900.00
5F813E	2017-07-20 22:51:00+03	42700.00
5F8185	2017-06-30 12:06:00+03	57400.00
5F818F	2017-07-13 04:02:00+03	81500.00
5F81CF	2017-08-09 15:33:00+03	62300.00
5F81FE	2017-07-15 03:45:00+03	135400.00
5F8201	2017-07-31 18:58:00+03	73200.00
5F826F	2017-07-10 16:53:00+03	99200.00
5F828F	2017-08-01 19:30:00+03	6000.00
5F8290	2017-07-06 09:49:00+03	48800.00
5F82C9	2017-08-15 11:16:00+03	12600.00
5F82FF	2017-07-10 16:27:00+03	110500.00
5F8316	2017-07-06 14:00:00+03	76400.00
5F8377	2017-07-14 03:17:00+03	15000.00
5F83E6	2017-07-18 17:34:00+03	47100.00
5F840E	2017-06-29 11:03:00+03	32700.00
5F8432	2017-07-26 02:57:00+03	42700.00
5F8461	2017-08-09 00:53:00+03	48800.00
5F847F	2017-07-08 14:07:00+03	8200.00
5F84BA	2017-08-13 17:47:00+03	156300.00
5F8501	2017-07-09 00:28:00+03	30200.00
5F8549	2017-08-13 12:53:00+03	39100.00
5F8583	2017-07-17 14:26:00+03	60900.00
5F85A2	2017-08-14 09:51:00+03	89600.00
5F8610	2017-07-14 10:22:00+03	26200.00
5F8636	2017-07-12 16:12:00+03	273600.00
5F865B	2017-07-22 23:57:00+03	133200.00
5F869F	2017-07-08 23:51:00+03	53600.00
5F86D0	2017-08-04 09:53:00+03	48400.00
5F8711	2017-07-09 03:34:00+03	17000.00
5F8720	2017-08-12 15:58:00+03	46300.00
5F873F	2017-07-15 02:34:00+03	103800.00
5F874B	2017-08-04 10:55:00+03	47500.00
5F8779	2017-08-09 01:18:00+03	90800.00
5F87BC	2017-07-30 19:36:00+03	37200.00
5F883F	2017-07-13 01:20:00+03	33300.00
5F88F5	2017-08-07 12:05:00+03	62600.00
5F8961	2017-07-18 04:36:00+03	100600.00
5F8A10	2017-07-28 04:50:00+03	131100.00
5F8A58	2017-07-19 09:52:00+03	131100.00
5F8A94	2017-07-29 09:49:00+03	81800.00
5F8ABC	2017-07-07 18:48:00+03	55800.00
5F8AED	2017-07-03 02:53:00+03	26000.00
5F8BB2	2017-07-09 00:33:00+03	34200.00
5F8BC8	2017-07-22 01:57:00+03	65100.00
5F8C0E	2017-08-14 18:43:00+03	266400.00
5F8C6B	2017-08-03 08:10:00+03	14400.00
5F8CC9	2017-07-31 14:29:00+03	75800.00
5F8CF3	2017-07-21 03:55:00+03	37200.00
5F8CFE	2017-07-15 01:35:00+03	12600.00
5F8D20	2017-07-22 05:55:00+03	65600.00
5F8D32	2017-07-08 12:43:00+03	122000.00
5F8D3B	2017-07-26 10:34:00+03	23200.00
5F8D59	2017-07-29 12:16:00+03	27300.00
5F8D83	2017-08-05 04:13:00+03	22100.00
5F8DD9	2017-07-04 07:21:00+03	13600.00
5F8E0E	2017-08-01 12:25:00+03	91600.00
5F8E5A	2017-06-29 13:58:00+03	39400.00
5F8E69	2017-07-06 09:02:00+03	90100.00
5F8EB7	2017-08-14 08:18:00+03	21500.00
5F8EDC	2017-07-12 02:29:00+03	144400.00
5F8F59	2017-07-29 22:20:00+03	69900.00
5F8F69	2017-07-11 02:52:00+03	28800.00
5F9045	2017-07-08 11:41:00+03	36200.00
5F90D0	2017-07-27 03:47:00+03	170000.00
5F9131	2017-07-05 17:48:00+03	93700.00
5F914F	2017-06-30 21:17:00+03	61500.00
5F9169	2017-07-25 16:40:00+03	28200.00
5F9197	2017-07-11 05:53:00+03	175200.00
5F91B9	2017-07-07 08:02:00+03	38400.00
5F924A	2017-07-03 22:09:00+03	56900.00
5F9290	2017-07-08 04:26:00+03	154500.00
5F9298	2017-06-28 11:54:00+03	16400.00
5F92DC	2017-07-17 02:57:00+03	38600.00
5F935F	2017-07-26 03:44:00+03	56000.00
5F936D	2017-07-12 21:24:00+03	58800.00
5F9385	2017-07-22 02:16:00+03	15000.00
5F93B0	2017-08-11 22:49:00+03	137600.00
5F93D0	2017-07-29 05:40:00+03	56900.00
5F940E	2017-07-07 01:47:00+03	12600.00
5F9430	2017-07-23 22:39:00+03	46400.00
5F9435	2017-08-03 15:31:00+03	136200.00
5F9457	2017-07-13 06:45:00+03	43200.00
5F947A	2017-07-19 16:32:00+03	203500.00
5F947B	2017-08-08 21:20:00+03	27300.00
5F94B8	2017-07-26 18:07:00+03	62700.00
5F9504	2017-08-10 00:56:00+03	32600.00
5F9514	2017-07-27 15:45:00+03	55700.00
5F95A6	2017-08-14 03:29:00+03	135400.00
5F95AE	2017-07-26 01:42:00+03	22600.00
5F95CA	2017-07-26 06:43:00+03	42700.00
5F95F5	2017-07-29 21:03:00+03	38400.00
5F963B	2017-08-03 09:04:00+03	45300.00
5F9648	2017-07-25 17:22:00+03	21800.00
5F9651	2017-08-04 14:18:00+03	111600.00
5F9673	2017-07-16 15:29:00+03	36200.00
5F96C0	2017-08-04 23:12:00+03	91300.00
5F971D	2017-07-21 00:32:00+03	57400.00
5F972D	2017-07-31 23:28:00+03	43200.00
5F9766	2017-07-16 09:03:00+03	66000.00
5F97FE	2017-07-14 05:46:00+03	78300.00
5F981F	2017-08-06 10:44:00+03	57400.00
5F9857	2017-07-22 06:33:00+03	21500.00
5F985F	2017-07-31 06:07:00+03	43200.00
5F98D5	2017-07-31 02:50:00+03	42400.00
5F9941	2017-08-11 09:44:00+03	26000.00
5F99B7	2017-06-27 16:14:00+03	90800.00
5F99BB	2017-07-24 05:17:00+03	39000.00
5F9A07	2017-07-25 11:49:00+03	39800.00
5F9AB7	2017-07-06 10:13:00+03	54500.00
5F9AD1	2017-07-22 23:39:00+03	14800.00
5F9AE5	2017-07-23 01:18:00+03	65500.00
5F9AE9	2017-07-26 18:40:00+03	44000.00
5F9BA8	2017-08-05 02:20:00+03	62600.00
5F9BD1	2017-07-25 00:27:00+03	406700.00
5F9C72	2017-08-07 21:55:00+03	26000.00
5F9D4E	2017-07-23 03:01:00+03	92800.00
5F9D79	2017-07-30 19:10:00+03	106100.00
5F9D92	2017-07-09 09:04:00+03	57500.00
5F9D9E	2017-06-30 11:48:00+03	226800.00
5F9DF1	2017-07-23 20:49:00+03	387400.00
5F9E13	2017-07-30 12:08:00+03	38200.00
5F9E84	2017-08-09 12:06:00+03	46200.00
5F9ECC	2017-06-30 16:24:00+03	30400.00
5F9F02	2017-07-10 10:27:00+03	31400.00
5F9F06	2017-07-28 09:59:00+03	39200.00
5F9F10	2017-07-08 12:43:00+03	21800.00
5F9F1F	2017-07-04 15:54:00+03	64300.00
5F9F3F	2017-07-13 06:03:00+03	191200.00
5F9F4B	2017-07-30 03:27:00+03	85700.00
5F9F75	2017-07-18 16:46:00+03	26000.00
5F9FCE	2017-07-31 09:32:00+03	24400.00
5FA034	2017-06-30 22:08:00+03	84100.00
5FA043	2017-07-16 08:33:00+03	24400.00
5FA0A2	2017-07-19 14:05:00+03	12600.00
5FA0C4	2017-08-02 10:01:00+03	28800.00
5FA0FF	2017-07-08 16:05:00+03	53600.00
5FA123	2017-07-16 23:08:00+03	248400.00
5FA18B	2017-08-07 02:05:00+03	55800.00
5FA1B8	2017-08-09 07:23:00+03	69500.00
5FA1BA	2017-08-01 04:39:00+03	152900.00
5FA1FE	2017-08-01 19:20:00+03	59000.00
5FA20F	2017-08-04 08:19:00+03	105000.00
5FA284	2017-07-20 09:22:00+03	50600.00
5FA34E	2017-06-29 02:57:00+03	83000.00
5FA39A	2017-08-05 20:45:00+03	56600.00
5FA3EB	2017-06-29 09:44:00+03	28800.00
5FA3F7	2017-08-06 12:53:00+03	114300.00
5FA441	2017-08-12 14:05:00+03	55800.00
5FA44E	2017-07-28 08:18:00+03	28600.00
5FA48E	2017-07-07 12:31:00+03	46000.00
5FA4E7	2017-07-09 09:13:00+03	114600.00
5FA510	2017-07-28 06:43:00+03	63200.00
5FA523	2017-08-03 00:51:00+03	59000.00
5FA55C	2017-07-11 01:08:00+03	23600.00
5FA68A	2017-07-12 19:11:00+03	368700.00
5FA6E9	2017-08-08 18:38:00+03	56600.00
5FA6FD	2017-08-09 23:46:00+03	81600.00
5FA771	2017-07-13 18:51:00+03	56000.00
5FA7D4	2017-07-18 20:21:00+03	82000.00
5FA84C	2017-07-28 21:27:00+03	18000.00
5FA877	2017-07-31 13:58:00+03	210000.00
5FA88E	2017-07-18 17:16:00+03	79200.00
5FA8ED	2017-08-04 08:28:00+03	142700.00
5FA960	2017-07-06 15:06:00+03	66600.00
5FA96B	2017-07-11 07:31:00+03	67600.00
5FA975	2017-08-06 16:45:00+03	47400.00
5FA97E	2017-07-03 20:02:00+03	36800.00
5FA98E	2017-07-16 14:44:00+03	28700.00
5FA9A7	2017-07-23 23:25:00+03	92700.00
5FAA11	2017-06-29 20:04:00+03	12600.00
5FAAA4	2017-07-26 23:27:00+03	69500.00
5FAAB7	2017-08-01 17:40:00+03	39200.00
5FAB0A	2017-07-05 07:08:00+03	532800.00
5FAB1B	2017-07-01 02:22:00+03	52600.00
5FAB48	2017-07-11 02:40:00+03	26200.00
5FAB64	2017-07-10 06:07:00+03	73600.00
5FAB8E	2017-07-19 16:42:00+03	55800.00
5FABB9	2017-07-02 17:16:00+03	60700.00
5FAC37	2017-07-10 09:08:00+03	81500.00
5FAC54	2017-08-08 16:39:00+03	56000.00
5FAC7E	2017-08-14 14:15:00+03	408500.00
5FAC95	2017-08-05 02:23:00+03	52700.00
5FACC7	2017-08-09 02:21:00+03	93900.00
5FAD2C	2017-07-06 20:53:00+03	56100.00
5FAD2E	2017-08-03 05:21:00+03	6700.00
5FAD7E	2017-07-12 17:43:00+03	135400.00
5FADFC	2017-08-05 04:27:00+03	86500.00
5FAE7F	2017-06-30 10:17:00+03	40600.00
5FAEDE	2017-07-25 19:24:00+03	31600.00
5FAF2B	2017-08-14 03:29:00+03	62600.00
5FAFA8	2017-07-22 20:11:00+03	295300.00
5FB007	2017-07-11 06:23:00+03	56000.00
5FB038	2017-07-07 14:26:00+03	57600.00
5FB052	2017-07-11 03:38:00+03	135400.00
5FB073	2017-07-26 22:53:00+03	21800.00
5FB08A	2017-07-19 00:04:00+03	56000.00
5FB091	2017-08-05 22:21:00+03	128800.00
5FB0B2	2017-08-14 07:07:00+03	27300.00
5FB10E	2017-08-03 01:12:00+03	92200.00
5FB144	2017-08-04 21:06:00+03	91500.00
5FB146	2017-07-28 01:39:00+03	27300.00
5FB181	2017-07-03 12:48:00+03	133200.00
5FB1CC	2017-07-19 10:34:00+03	261800.00
5FB1DE	2017-07-29 12:26:00+03	88500.00
5FB1E2	2017-07-12 01:22:00+03	43200.00
5FB1ED	2017-07-20 14:14:00+03	191200.00
5FB224	2017-07-12 18:51:00+03	43300.00
5FB22E	2017-08-15 02:39:00+03	19800.00
5FB22F	2017-07-29 21:23:00+03	57600.00
5FB246	2017-06-29 15:05:00+03	13200.00
5FB267	2017-07-07 08:53:00+03	71100.00
5FB363	2017-07-16 08:04:00+03	24700.00
5FB3C5	2017-07-17 14:05:00+03	41900.00
5FB3C8	2017-07-29 03:33:00+03	12000.00
5FB41E	2017-08-10 20:58:00+03	24600.00
5FB493	2017-07-15 15:17:00+03	112000.00
5FB53C	2017-07-27 16:50:00+03	128800.00
5FB540	2017-08-10 20:04:00+03	36600.00
5FB612	2017-08-05 13:22:00+03	62000.00
5FB631	2017-08-11 11:27:00+03	152400.00
5FB6C1	2017-08-09 05:24:00+03	33600.00
5FB6D2	2017-08-15 09:32:00+03	45200.00
5FB748	2017-08-05 10:17:00+03	59000.00
5FB771	2017-07-26 14:11:00+03	44000.00
5FB789	2017-07-12 10:58:00+03	20800.00
5FB78E	2017-08-03 15:45:00+03	23200.00
5FB7C5	2017-07-23 16:44:00+03	56000.00
5FB823	2017-07-11 03:08:00+03	132800.00
5FB88B	2017-07-21 21:11:00+03	36200.00
5FB8E0	2017-08-14 00:58:00+03	135200.00
5FB8F7	2017-08-07 01:57:00+03	76400.00
5FB951	2017-06-30 16:10:00+03	85400.00
5FB978	2017-08-11 04:42:00+03	31200.00
5FB9A0	2017-08-09 10:27:00+03	125100.00
5FB9BF	2017-07-22 00:11:00+03	119800.00
5FBA38	2017-08-11 11:11:00+03	48000.00
5FBA86	2017-08-11 14:12:00+03	16400.00
5FBACA	2017-07-03 05:46:00+03	23600.00
5FBADB	2017-08-03 17:52:00+03	40800.00
5FBAE8	2017-08-02 00:42:00+03	143100.00
5FBB74	2017-07-30 06:03:00+03	29600.00
5FBBCE	2017-08-09 00:26:00+03	18000.00
5FBC03	2017-07-23 09:16:00+03	21600.00
5FBC8A	2017-08-10 20:03:00+03	25800.00
5FBC9C	2017-07-04 16:38:00+03	372500.00
5FBCB4	2017-07-23 22:16:00+03	119500.00
5FBD4A	2017-07-21 14:33:00+03	14000.00
5FBD62	2017-07-27 11:04:00+03	318000.00
5FBEB4	2017-07-07 15:55:00+03	57700.00
5FBEBC	2017-07-19 00:33:00+03	92900.00
5FBEF8	2017-07-04 20:48:00+03	43600.00
5FBF50	2017-07-08 02:19:00+03	187600.00
5FBF95	2017-07-31 17:54:00+03	120100.00
5FBFE9	2017-08-03 14:12:00+03	258000.00
5FC082	2017-07-25 15:35:00+03	27400.00
5FC09A	2017-08-11 22:13:00+03	21200.00
5FC16D	2017-07-07 11:49:00+03	73600.00
5FC1A0	2017-07-17 19:18:00+03	103600.00
5FC20B	2017-07-18 04:15:00+03	12600.00
5FC242	2017-07-27 23:22:00+03	117800.00
5FC248	2017-07-10 16:12:00+03	119600.00
5FC24D	2017-08-01 20:53:00+03	36800.00
5FC277	2017-08-13 17:07:00+03	40800.00
5FC2D8	2017-08-08 14:16:00+03	47400.00
5FC30D	2017-07-06 12:49:00+03	369000.00
5FC3AF	2017-07-05 15:35:00+03	57300.00
5FC3F7	2017-07-27 14:01:00+03	131100.00
5FC413	2017-07-31 07:10:00+03	47200.00
5FC420	2017-07-02 12:47:00+03	24300.00
5FC43B	2017-07-11 16:58:00+03	141200.00
5FC4C9	2017-08-07 13:09:00+03	42200.00
5FC5B0	2017-07-02 13:49:00+03	38600.00
5FC5D8	2017-07-04 23:39:00+03	158600.00
5FC5F4	2017-08-10 00:58:00+03	29600.00
5FC63C	2017-07-13 00:18:00+03	15100.00
5FC6FB	2017-07-21 18:14:00+03	135200.00
5FC79B	2017-08-10 18:54:00+03	172100.00
5FC7B6	2017-07-12 05:47:00+03	132800.00
5FC7E7	2017-07-18 05:29:00+03	77600.00
5FC874	2017-08-08 04:00:00+03	55800.00
5FC87C	2017-08-14 01:26:00+03	30500.00
5FC90B	2017-08-04 20:47:00+03	11700.00
5FC967	2017-07-27 10:58:00+03	406700.00
5FC9BC	2017-07-26 18:19:00+03	56000.00
5FC9E6	2017-07-25 20:32:00+03	102100.00
5FCA09	2017-07-18 01:44:00+03	55800.00
5FCA2D	2017-07-19 17:39:00+03	169900.00
5FCB00	2017-07-26 18:25:00+03	80800.00
5FCB06	2017-07-22 05:38:00+03	19200.00
5FCB7B	2017-08-04 17:11:00+03	40800.00
5FCBC7	2017-08-13 04:33:00+03	99700.00
5FCC4E	2017-07-16 18:38:00+03	46000.00
5FCC6C	2017-07-24 05:30:00+03	65500.00
5FCCBC	2017-08-15 08:34:00+03	20300.00
5FCCD4	2017-07-15 02:48:00+03	125400.00
5FCCEA	2017-07-01 06:19:00+03	34600.00
5FCDAF	2017-06-30 19:11:00+03	207100.00
5FCDE0	2017-07-13 13:21:00+03	14800.00
5FCE05	2017-08-04 02:20:00+03	42800.00
5FCE21	2017-07-22 05:33:00+03	37100.00
5FCE24	2017-07-27 03:17:00+03	60600.00
5FCE50	2017-07-28 10:26:00+03	44000.00
5FCE84	2017-08-10 01:25:00+03	45400.00
5FCE8A	2017-07-27 01:25:00+03	68800.00
5FCECD	2017-07-13 06:00:00+03	289800.00
5FCF35	2017-08-11 01:29:00+03	18400.00
5FCF88	2017-08-02 21:11:00+03	26800.00
5FCF92	2017-07-13 16:19:00+03	20400.00
5FCFED	2017-07-31 15:34:00+03	24600.00
5FD01D	2017-07-12 21:50:00+03	6800.00
5FD08E	2017-08-03 23:04:00+03	85000.00
5FD095	2017-07-08 21:08:00+03	28000.00
5FD1F3	2017-07-04 02:23:00+03	55800.00
5FD238	2017-07-09 07:31:00+03	135000.00
5FD264	2017-07-03 05:55:00+03	131100.00
5FD2B7	2017-07-19 22:56:00+03	47600.00
5FD2F9	2017-07-02 11:09:00+03	117200.00
5FD306	2017-07-13 10:07:00+03	20400.00
5FD34C	2017-07-16 10:38:00+03	124400.00
5FD360	2017-08-02 23:51:00+03	44800.00
5FD386	2017-07-25 13:42:00+03	28800.00
5FD3BB	2017-08-13 01:45:00+03	148200.00
5FD3C3	2017-07-20 12:50:00+03	24400.00
5FD3E3	2017-07-10 14:37:00+03	46500.00
5FD43B	2017-07-19 03:28:00+03	56000.00
5FD47B	2017-08-09 00:58:00+03	21800.00
5FD47C	2017-08-01 20:21:00+03	58600.00
5FD48D	2017-08-12 20:47:00+03	186100.00
5FD4AB	2017-08-14 12:37:00+03	81700.00
5FD543	2017-08-07 10:36:00+03	49200.00
5FD617	2017-07-16 10:31:00+03	112000.00
5FD625	2017-08-05 22:56:00+03	16400.00
5FD681	2017-07-12 04:55:00+03	32200.00
5FD69B	2017-08-09 22:14:00+03	85000.00
5FD69C	2017-07-17 02:18:00+03	67200.00
5FD749	2017-07-31 15:56:00+03	15100.00
5FD7D6	2017-08-09 13:06:00+03	80000.00
5FD7FB	2017-08-05 10:46:00+03	25000.00
5FD80C	2017-07-23 17:24:00+03	23200.00
5FD82F	2017-07-20 04:24:00+03	50600.00
5FD884	2017-07-23 19:01:00+03	27400.00
5FD899	2017-07-06 07:43:00+03	186900.00
5FD8AD	2017-07-26 07:18:00+03	74900.00
5FD8C9	2017-07-14 13:33:00+03	17800.00
5FD901	2017-07-05 09:08:00+03	52000.00
5FD922	2017-08-06 11:57:00+03	56000.00
5FD93B	2017-07-14 15:11:00+03	7900.00
5FD9BF	2017-07-15 14:57:00+03	260900.00
5FD9E5	2017-07-19 03:19:00+03	179400.00
5FD9F7	2017-07-18 20:26:00+03	86300.00
5FD9FD	2017-08-06 10:55:00+03	24300.00
5FDA1F	2017-07-02 08:22:00+03	73300.00
5FDA2C	2017-08-15 17:00:00+03	46000.00
5FDAB8	2017-08-05 17:28:00+03	43600.00
5FDACC	2017-07-04 17:21:00+03	35200.00
5FDB47	2017-08-12 14:25:00+03	95600.00
5FDB58	2017-07-10 01:05:00+03	86400.00
5FDB62	2017-07-05 21:09:00+03	59800.00
5FDB8D	2017-07-20 11:53:00+03	68700.00
5FDB91	2017-07-21 08:44:00+03	132800.00
5FDBD4	2017-07-01 20:57:00+03	29400.00
5FDBF4	2017-07-26 16:50:00+03	13600.00
5FDC19	2017-07-15 06:29:00+03	202600.00
5FDC1E	2017-07-22 02:02:00+03	31400.00
5FDC41	2017-07-30 03:17:00+03	28000.00
5FDCB1	2017-07-06 05:48:00+03	301800.00
5FDCC3	2017-08-05 01:01:00+03	58800.00
5FDD31	2017-07-27 23:53:00+03	56600.00
5FDD82	2017-07-04 04:38:00+03	105000.00
5FDD89	2017-08-14 22:34:00+03	47200.00
5FDD8D	2017-08-04 09:42:00+03	68800.00
5FDE15	2017-08-06 03:42:00+03	105100.00
5FDE4B	2017-08-05 05:14:00+03	62900.00
5FDE6C	2017-08-01 04:58:00+03	82000.00
5FDECD	2017-07-12 09:24:00+03	56000.00
5FDEF2	2017-08-08 07:42:00+03	20600.00
5FDEFB	2017-08-11 05:56:00+03	92000.00
5FDF15	2017-07-20 22:17:00+03	111600.00
5FDF24	2017-07-23 04:58:00+03	173900.00
5FDF26	2017-08-14 18:22:00+03	39400.00
5FDF5C	2017-07-13 06:05:00+03	91500.00
5FDFBA	2017-08-12 23:27:00+03	90600.00
5FE046	2017-07-17 06:22:00+03	66600.00
5FE048	2017-08-10 23:12:00+03	88800.00
5FE05A	2017-07-30 12:32:00+03	114100.00
5FE07C	2017-07-31 22:00:00+03	105000.00
5FE089	2017-07-22 20:06:00+03	50600.00
5FE0AA	2017-07-31 07:52:00+03	54800.00
5FE0F7	2017-07-02 17:40:00+03	28000.00
5FE1D1	2017-08-08 11:03:00+03	153300.00
5FE259	2017-07-04 14:59:00+03	56900.00
5FE265	2017-07-06 11:06:00+03	24400.00
5FE27F	2017-08-10 17:19:00+03	29600.00
5FE2D2	2017-08-10 21:27:00+03	131600.00
5FE2D3	2017-07-03 11:56:00+03	46400.00
5FE2E8	2017-07-11 18:20:00+03	92900.00
5FE2EE	2017-08-03 10:04:00+03	187600.00
5FE38E	2017-07-22 10:19:00+03	111600.00
5FE393	2017-06-30 07:40:00+03	62600.00
5FE39C	2017-07-13 07:31:00+03	31600.00
5FE39F	2017-07-23 22:19:00+03	53300.00
5FE3B5	2017-08-11 14:04:00+03	48700.00
5FE3B6	2017-08-05 03:44:00+03	12600.00
5FE413	2017-07-29 06:08:00+03	94000.00
5FE53F	2017-08-14 02:48:00+03	50300.00
5FE54A	2017-07-14 15:27:00+03	26000.00
5FE58E	2017-07-22 01:59:00+03	46400.00
5FE620	2017-08-01 12:36:00+03	6800.00
5FE644	2017-07-07 05:47:00+03	66800.00
5FE6A5	2017-07-11 12:27:00+03	56000.00
5FE6E0	2017-07-05 11:49:00+03	85000.00
5FE733	2017-07-18 05:14:00+03	27400.00
5FE7AC	2017-08-05 20:54:00+03	24400.00
5FE7D0	2017-07-11 16:56:00+03	57700.00
5FE802	2017-07-31 17:38:00+03	46400.00
5FE867	2017-07-30 12:33:00+03	105000.00
5FE8D6	2017-07-27 10:39:00+03	11800.00
5FE8D8	2017-07-25 13:55:00+03	67700.00
5FE926	2017-08-06 21:18:00+03	58600.00
5FE967	2017-07-31 04:37:00+03	6800.00
5FE983	2017-07-16 16:04:00+03	3400.00
5FE9B4	2017-07-27 10:51:00+03	65400.00
5FE9C7	2017-07-21 14:33:00+03	23200.00
5FEA02	2017-07-23 01:53:00+03	53600.00
5FEA11	2017-07-01 03:38:00+03	38600.00
5FEA64	2017-07-23 18:04:00+03	24400.00
5FEA71	2017-08-13 03:33:00+03	24400.00
5FEA77	2017-08-15 06:41:00+03	48500.00
5FEA9D	2017-07-20 00:38:00+03	110500.00
5FEAA0	2017-07-14 11:44:00+03	47000.00
5FEAB8	2017-08-04 13:09:00+03	67600.00
5FEACE	2017-07-24 16:53:00+03	28000.00
5FEB01	2017-08-02 17:03:00+03	31600.00
5FEB02	2017-07-07 03:48:00+03	115800.00
5FEB29	2017-08-12 19:20:00+03	70800.00
5FEB67	2017-07-27 06:07:00+03	46000.00
5FEB6E	2017-08-14 07:51:00+03	58900.00
5FEB84	2017-07-07 04:20:00+03	84500.00
5FEBBE	2017-07-12 02:17:00+03	40000.00
5FEBCD	2017-07-30 01:23:00+03	44800.00
5FECA2	2017-07-28 06:04:00+03	164600.00
5FECB9	2017-07-13 13:44:00+03	249200.00
5FED10	2017-07-07 13:56:00+03	53200.00
5FED23	2017-08-09 12:50:00+03	12400.00
5FED28	2017-07-23 15:26:00+03	23200.00
5FED49	2017-07-08 01:16:00+03	15100.00
5FED85	2017-08-08 05:23:00+03	174200.00
5FED8A	2017-07-16 20:14:00+03	173300.00
5FEE8F	2017-07-18 08:56:00+03	283100.00
5FEEA9	2017-07-03 01:18:00+03	29500.00
5FEF23	2017-07-20 16:55:00+03	123000.00
5FEF2F	2017-07-20 03:38:00+03	123000.00
5FEF78	2017-07-26 00:28:00+03	23400.00
5FEF7A	2017-07-12 13:29:00+03	109200.00
5FEFA4	2017-07-26 06:04:00+03	39300.00
5FEFFA	2017-07-03 10:00:00+03	187600.00
5FF002	2017-07-27 11:54:00+03	67900.00
5FF099	2017-07-25 05:26:00+03	28800.00
5FF105	2017-07-11 02:18:00+03	344600.00
5FF169	2017-08-10 11:42:00+03	65900.00
5FF178	2017-07-25 08:11:00+03	81500.00
5FF19B	2017-07-29 23:04:00+03	23200.00
5FF1AE	2017-08-12 13:19:00+03	49400.00
5FF1D4	2017-07-22 05:28:00+03	44000.00
5FF1D9	2017-08-10 18:21:00+03	23200.00
5FF20E	2017-08-10 18:36:00+03	23200.00
5FF2D4	2017-07-09 19:57:00+03	14400.00
5FF2E5	2017-07-09 22:11:00+03	29400.00
5FF301	2017-07-30 00:44:00+03	187600.00
5FF346	2017-08-02 22:51:00+03	55800.00
5FF37A	2017-08-02 14:38:00+03	150600.00
5FF3B5	2017-07-23 10:27:00+03	20000.00
5FF42B	2017-08-09 18:15:00+03	26700.00
5FF43F	2017-08-08 05:52:00+03	52800.00
5FF63F	2017-07-13 21:34:00+03	65900.00
5FF64F	2017-07-20 15:58:00+03	21400.00
5FF675	2017-07-20 09:35:00+03	56000.00
5FF6B8	2017-07-23 02:38:00+03	6700.00
5FF6B9	2017-07-10 23:32:00+03	24200.00
5FF6C3	2017-07-02 02:20:00+03	43200.00
5FF6C5	2017-07-25 17:51:00+03	39800.00
5FF703	2017-07-13 06:48:00+03	26700.00
5FF723	2017-08-14 03:50:00+03	252200.00
5FF79A	2017-08-14 03:01:00+03	56100.00
5FF89F	2017-08-07 03:39:00+03	56000.00
5FF9F4	2017-07-04 11:53:00+03	19100.00
5FFA1B	2017-07-19 14:30:00+03	78500.00
5FFA48	2017-07-14 03:10:00+03	78100.00
5FFA9C	2017-07-21 19:52:00+03	26000.00
5FFAD5	2017-07-19 10:31:00+03	276000.00
5FFAE9	2017-08-12 15:09:00+03	120700.00
5FFB79	2017-07-05 18:53:00+03	63000.00
5FFB86	2017-06-28 04:13:00+03	42900.00
5FFB96	2017-07-17 02:47:00+03	30200.00
5FFBA6	2017-07-27 06:57:00+03	43600.00
5FFC85	2017-07-31 02:30:00+03	16400.00
5FFC9F	2017-07-06 09:50:00+03	45100.00
5FFD53	2017-07-23 01:59:00+03	35200.00
5FFD8D	2017-07-15 02:36:00+03	201800.00
5FFDA0	2017-07-10 12:43:00+03	153300.00
5FFE01	2017-08-03 05:43:00+03	39600.00
5FFE06	2017-08-06 06:11:00+03	59200.00
5FFE35	2017-08-14 16:06:00+03	179400.00
5FFE64	2017-08-15 08:48:00+03	29900.00
5FFE97	2017-07-07 04:05:00+03	21200.00
5FFEA5	2017-07-13 20:34:00+03	35600.00
5FFEAE	2017-08-15 09:45:00+03	37900.00
5FFFB9	2017-07-05 12:39:00+03	77900.00
5FFFBD	2017-07-05 05:48:00+03	76400.00
5FFFF0	2017-07-18 20:36:00+03	246000.00
600043	2017-07-26 21:26:00+03	36200.00
600100	2017-07-15 15:51:00+03	13800.00
60011A	2017-07-18 01:45:00+03	34100.00
600139	2017-07-11 06:54:00+03	95700.00
600144	2017-07-25 09:01:00+03	14700.00
600145	2017-08-14 05:30:00+03	8400.00
600164	2017-06-30 02:14:00+03	40000.00
6001CD	2017-07-09 00:34:00+03	26000.00
6001D3	2017-08-07 20:00:00+03	98300.00
600205	2017-07-19 14:34:00+03	40700.00
600257	2017-07-04 01:01:00+03	24800.00
600281	2017-08-15 12:30:00+03	139900.00
60028C	2017-08-01 01:09:00+03	27900.00
6002CA	2017-07-19 04:25:00+03	58000.00
6002E7	2017-07-07 06:06:00+03	79500.00
6002F1	2017-08-07 21:28:00+03	46400.00
600329	2017-08-12 06:55:00+03	9200.00
600341	2017-08-10 03:49:00+03	43900.00
600365	2017-07-20 22:18:00+03	41400.00
60039C	2017-07-24 19:57:00+03	125100.00
6003B0	2017-07-11 09:10:00+03	155600.00
600527	2017-07-11 20:58:00+03	70700.00
6005D5	2017-08-11 02:41:00+03	15400.00
6005F6	2017-08-12 23:30:00+03	57500.00
6005FF	2017-07-18 00:28:00+03	28800.00
600603	2017-08-15 13:28:00+03	30400.00
60061E	2017-08-09 15:34:00+03	910600.00
600629	2017-07-20 02:05:00+03	85700.00
600631	2017-07-03 04:29:00+03	92000.00
6006DE	2017-08-10 13:29:00+03	76800.00
600711	2017-07-12 19:19:00+03	19600.00
600773	2017-08-10 20:34:00+03	60400.00
60077F	2017-07-20 11:05:00+03	135400.00
600781	2017-07-05 14:30:00+03	68800.00
600792	2017-07-29 02:41:00+03	56000.00
60079B	2017-07-28 03:41:00+03	19300.00
6007B2	2017-07-02 21:47:00+03	67200.00
6007F8	2017-07-18 18:24:00+03	93900.00
60088D	2017-07-07 14:36:00+03	54200.00
600892	2017-08-03 08:15:00+03	26000.00
60089A	2017-08-07 09:20:00+03	76600.00
6008B6	2017-07-12 08:09:00+03	41900.00
6008E0	2017-07-10 21:09:00+03	90400.00
600900	2017-08-10 08:52:00+03	231800.00
600902	2017-07-02 05:01:00+03	51300.00
600958	2017-07-18 17:25:00+03	168000.00
60099E	2017-07-23 16:43:00+03	73100.00
6009D4	2017-07-24 06:50:00+03	56600.00
6009E7	2017-07-20 23:27:00+03	179400.00
6009FE	2017-07-14 21:35:00+03	100300.00
600A61	2017-07-06 04:55:00+03	160700.00
600B0A	2017-08-13 01:36:00+03	45100.00
600B76	2017-08-07 10:26:00+03	36200.00
600BAF	2017-07-18 23:44:00+03	42800.00
600C01	2017-07-13 18:28:00+03	139300.00
600C29	2017-07-28 06:22:00+03	58900.00
600CE2	2017-07-24 17:24:00+03	80300.00
600CF2	2017-08-06 17:13:00+03	37900.00
600CF9	2017-07-07 01:50:00+03	29600.00
600D36	2017-07-20 15:00:00+03	32700.00
600D45	2017-07-30 10:28:00+03	108200.00
600D4E	2017-07-26 09:11:00+03	64100.00
600DE7	2017-08-01 03:24:00+03	31100.00
600DF3	2017-08-07 00:46:00+03	25100.00
600E15	2017-08-06 10:34:00+03	124200.00
600E46	2017-08-07 08:22:00+03	274200.00
600E8E	2017-07-13 04:41:00+03	51300.00
600EDD	2017-07-15 11:35:00+03	111600.00
600EEA	2017-08-14 13:54:00+03	177200.00
600FFA	2017-08-13 23:56:00+03	51900.00
601019	2017-08-05 17:10:00+03	123000.00
60104F	2017-07-07 08:15:00+03	82600.00
601083	2017-08-01 16:35:00+03	26000.00
60108C	2017-07-22 02:04:00+03	19600.00
6010F2	2017-07-28 09:16:00+03	12400.00
6010FC	2017-07-28 09:02:00+03	30200.00
601104	2017-07-12 04:38:00+03	25600.00
601136	2017-07-08 04:44:00+03	127300.00
601163	2017-07-19 07:36:00+03	67400.00
601191	2017-08-04 21:16:00+03	22600.00
6011A5	2017-07-22 20:45:00+03	35300.00
6011E3	2017-08-10 19:25:00+03	258400.00
6011E5	2017-08-02 04:47:00+03	145100.00
6012BA	2017-07-03 09:12:00+03	28000.00
6012BB	2017-08-05 03:06:00+03	129900.00
6012C9	2017-07-16 04:14:00+03	6300.00
60132A	2017-07-10 08:03:00+03	65400.00
601360	2017-07-08 15:14:00+03	44600.00
6014CA	2017-07-05 09:40:00+03	198400.00
6014D4	2017-07-29 01:42:00+03	49200.00
6014FD	2017-08-13 06:32:00+03	7400.00
601510	2017-07-02 21:09:00+03	55800.00
601522	2017-07-16 07:43:00+03	112000.00
601552	2017-07-18 14:05:00+03	188800.00
601572	2017-08-04 21:44:00+03	47100.00
6015E9	2017-07-25 03:15:00+03	98000.00
6015EE	2017-07-18 04:52:00+03	301800.00
60163B	2017-08-09 03:50:00+03	14000.00
6016DF	2017-07-16 17:53:00+03	119500.00
60170D	2017-08-02 23:05:00+03	55800.00
601763	2017-08-09 15:49:00+03	63700.00
60179A	2017-07-18 08:00:00+03	67800.00
6017B9	2017-07-30 11:35:00+03	58600.00
6017C1	2017-07-08 13:19:00+03	65500.00
601803	2017-07-31 08:42:00+03	115900.00
601811	2017-08-12 16:35:00+03	23100.00
601868	2017-07-26 07:53:00+03	53200.00
601869	2017-07-25 14:22:00+03	72800.00
6018AE	2017-08-15 17:08:00+03	27300.00
6018C5	2017-07-20 17:58:00+03	246000.00
6018D1	2017-07-06 04:46:00+03	248300.00
6018FC	2017-08-13 09:25:00+03	59300.00
60191E	2017-08-10 04:24:00+03	86100.00
6019A0	2017-07-03 23:24:00+03	7400.00
6019E6	2017-07-18 19:32:00+03	86600.00
601AA7	2017-07-31 20:21:00+03	136200.00
601AA8	2017-07-09 20:13:00+03	72400.00
601C3F	2017-07-03 15:44:00+03	66600.00
601C47	2017-08-14 09:19:00+03	81700.00
601C6F	2017-07-14 20:34:00+03	43400.00
601C9F	2017-07-28 12:15:00+03	73600.00
601CB4	2017-08-04 03:02:00+03	105000.00
601CD2	2017-08-11 17:54:00+03	75300.00
601CEE	2017-07-20 04:39:00+03	135400.00
601D1C	2017-08-07 18:11:00+03	40600.00
601D3D	2017-08-05 05:25:00+03	20200.00
601DC1	2017-08-10 13:56:00+03	23600.00
601DCF	2017-08-08 03:01:00+03	57400.00
601DDE	2017-07-16 13:55:00+03	66600.00
601E40	2017-07-12 18:52:00+03	70700.00
601E74	2017-08-14 05:34:00+03	196800.00
601EB7	2017-07-30 10:34:00+03	32600.00
601ECE	2017-07-11 13:50:00+03	37900.00
601F1E	2017-08-14 20:25:00+03	92200.00
601FE6	2017-07-23 21:12:00+03	26700.00
60200F	2017-07-07 19:42:00+03	111600.00
602021	2017-08-13 16:01:00+03	103500.00
60204E	2017-07-30 12:34:00+03	55800.00
602074	2017-07-08 21:04:00+03	55800.00
6020D2	2017-07-18 08:13:00+03	47100.00
6020F4	2017-07-01 22:21:00+03	40400.00
602102	2017-08-12 07:37:00+03	92800.00
60211C	2017-07-22 15:50:00+03	17800.00
60214C	2017-08-07 12:51:00+03	195600.00
60216A	2017-07-10 11:09:00+03	99200.00
6021AB	2017-07-31 18:17:00+03	45200.00
6021FF	2017-07-25 01:15:00+03	22600.00
602249	2017-07-14 13:58:00+03	270800.00
6022B5	2017-07-21 09:30:00+03	39600.00
6022BD	2017-08-03 00:45:00+03	191300.00
6022EE	2017-06-30 22:02:00+03	135600.00
60230C	2017-08-02 02:43:00+03	132700.00
60231A	2017-07-10 22:06:00+03	131100.00
60235C	2017-07-06 23:47:00+03	66600.00
602360	2017-07-17 01:14:00+03	188000.00
6023D5	2017-07-22 18:28:00+03	26400.00
602421	2017-07-07 17:09:00+03	34000.00
6024E5	2017-07-12 13:31:00+03	47200.00
60252F	2017-08-11 13:54:00+03	134400.00
602565	2017-07-14 06:08:00+03	101200.00
6025A6	2017-07-06 14:59:00+03	34400.00
6025C5	2017-08-11 06:05:00+03	23200.00
6025D0	2017-08-13 17:55:00+03	22000.00
602630	2017-08-12 03:25:00+03	67800.00
602632	2017-07-23 09:19:00+03	14400.00
602647	2017-07-07 22:54:00+03	14000.00
60268A	2017-06-30 01:19:00+03	46300.00
6026A6	2017-07-22 21:10:00+03	6300.00
6026D1	2017-07-01 19:22:00+03	56000.00
6026F4	2017-07-01 21:19:00+03	198400.00
6026FA	2017-07-27 14:44:00+03	54400.00
60270E	2017-07-29 14:48:00+03	56600.00
602719	2017-08-12 14:00:00+03	48800.00
602759	2017-07-21 22:33:00+03	113700.00
602774	2017-07-21 23:45:00+03	84800.00
6027D9	2017-08-12 12:42:00+03	17600.00
60282C	2017-07-14 15:38:00+03	201200.00
6028B2	2017-07-23 21:52:00+03	139400.00
6028C8	2017-08-05 12:36:00+03	56900.00
6028FE	2017-07-18 00:40:00+03	44000.00
602947	2017-08-08 13:05:00+03	71000.00
602991	2017-07-30 22:08:00+03	20200.00
6029DA	2017-07-22 13:46:00+03	59800.00
6029E8	2017-07-18 21:06:00+03	36400.00
6029F3	2017-07-22 10:54:00+03	37200.00
6029F7	2017-08-06 22:24:00+03	37900.00
6029FB	2017-07-13 02:27:00+03	24400.00
6029FE	2017-07-26 09:11:00+03	101200.00
602A1C	2017-08-04 09:04:00+03	62600.00
602A81	2017-07-21 07:32:00+03	258400.00
602AAC	2017-08-07 15:48:00+03	170700.00
602AC5	2017-07-23 02:18:00+03	55800.00
602B21	2017-08-07 01:39:00+03	40000.00
602B2E	2017-08-07 02:02:00+03	234800.00
602B58	2017-08-07 12:08:00+03	42800.00
602B79	2017-08-06 18:22:00+03	73600.00
602C23	2017-08-11 05:38:00+03	118000.00
602C40	2017-07-23 16:51:00+03	44800.00
602C57	2017-07-08 10:57:00+03	26200.00
602C5B	2017-08-02 00:33:00+03	24400.00
602C68	2017-08-07 01:14:00+03	84500.00
602CE3	2017-08-06 22:39:00+03	59400.00
602D24	2017-07-07 05:50:00+03	77600.00
602D5C	2017-08-07 06:52:00+03	92100.00
602DD3	2017-07-02 09:10:00+03	28300.00
602E53	2017-07-18 16:46:00+03	8000.00
602ECC	2017-07-29 13:28:00+03	258300.00
602ED1	2017-08-10 21:14:00+03	48300.00
602EEC	2017-08-11 02:09:00+03	115700.00
602F0E	2017-08-08 14:22:00+03	67400.00
602F29	2017-07-16 06:26:00+03	59800.00
602F4C	2017-08-03 09:20:00+03	28000.00
602F4F	2017-08-10 10:06:00+03	49800.00
603045	2017-07-13 04:15:00+03	23400.00
603127	2017-08-02 18:21:00+03	35800.00
603135	2017-07-31 22:56:00+03	282800.00
603171	2017-08-02 03:52:00+03	6800.00
603178	2017-07-24 14:29:00+03	19800.00
60319D	2017-07-10 15:07:00+03	85000.00
6031B7	2017-08-13 14:34:00+03	25200.00
6031C0	2017-08-15 03:02:00+03	25800.00
603256	2017-07-20 15:27:00+03	140800.00
603293	2017-07-07 22:18:00+03	62000.00
60329C	2017-07-21 18:50:00+03	83600.00
6032E8	2017-08-14 18:34:00+03	40000.00
6032EF	2017-07-12 07:55:00+03	35400.00
60331D	2017-07-20 18:55:00+03	152500.00
603344	2017-07-12 14:37:00+03	24700.00
603359	2017-07-17 05:57:00+03	62600.00
60339B	2017-08-08 03:37:00+03	56000.00
60339C	2017-08-08 19:12:00+03	54500.00
6033EC	2017-07-26 05:54:00+03	28800.00
6033FF	2017-07-10 16:14:00+03	28000.00
603471	2017-08-08 03:58:00+03	68400.00
6034EC	2017-07-19 00:49:00+03	58200.00
6034F5	2017-08-02 05:59:00+03	66600.00
603507	2017-08-08 03:42:00+03	8200.00
60354A	2017-07-17 04:17:00+03	70600.00
603551	2017-07-13 16:26:00+03	150600.00
603558	2017-07-14 07:04:00+03	21000.00
603593	2017-08-15 15:23:00+03	51100.00
6035ED	2017-07-21 05:44:00+03	100200.00
6035F5	2017-07-30 18:06:00+03	44600.00
60360B	2017-06-30 07:00:00+03	89700.00
60362B	2017-08-03 00:26:00+03	84000.00
603660	2017-07-06 15:01:00+03	128800.00
60373D	2017-07-24 13:02:00+03	36000.00
603790	2017-07-27 02:26:00+03	108500.00
6037D1	2017-07-18 16:45:00+03	119600.00
6037F6	2017-07-30 11:13:00+03	148200.00
6038AF	2017-07-30 21:19:00+03	139700.00
6038E4	2017-08-02 05:20:00+03	32700.00
603902	2017-08-06 21:36:00+03	123000.00
60392A	2017-07-16 08:03:00+03	19600.00
60392B	2017-07-10 12:19:00+03	47000.00
60395F	2017-08-06 10:07:00+03	12400.00
603976	2017-07-27 06:30:00+03	424800.00
6039F7	2017-07-23 10:10:00+03	147100.00
603A0E	2017-07-11 09:13:00+03	31800.00
603A1D	2017-07-30 17:01:00+03	173900.00
603A40	2017-07-19 17:10:00+03	49100.00
603A53	2017-07-30 09:22:00+03	64700.00
603A6A	2017-07-13 09:22:00+03	26000.00
603B09	2017-07-31 22:01:00+03	52800.00
603B87	2017-07-04 18:47:00+03	65500.00
603BB5	2017-08-11 04:39:00+03	90300.00
603C01	2017-07-19 17:31:00+03	23200.00
603C68	2017-07-29 17:32:00+03	27800.00
603C73	2017-08-12 23:22:00+03	32700.00
603CE1	2017-07-25 18:55:00+03	198600.00
603D47	2017-07-02 09:04:00+03	56000.00
603D60	2017-08-14 21:10:00+03	39300.00
603DDC	2017-07-10 05:48:00+03	44100.00
603DE7	2017-08-12 00:48:00+03	167500.00
603E28	2017-07-28 09:18:00+03	55800.00
603E33	2017-07-24 09:40:00+03	14000.00
603E45	2017-07-27 08:51:00+03	6600.00
603E65	2017-07-31 18:03:00+03	114400.00
603E70	2017-07-28 11:08:00+03	52700.00
603EAB	2017-08-04 23:20:00+03	111600.00
604006	2017-08-11 21:03:00+03	19600.00
60401B	2017-06-29 19:52:00+03	28800.00
604027	2017-07-24 12:41:00+03	38600.00
604050	2017-07-27 09:41:00+03	37100.00
604060	2017-07-19 12:59:00+03	246000.00
6040B0	2017-08-06 03:43:00+03	81700.00
6040C7	2017-08-14 07:52:00+03	119800.00
6040DB	2017-07-03 23:28:00+03	13400.00
604172	2017-07-18 04:21:00+03	180000.00
6041AC	2017-07-20 03:17:00+03	289400.00
6041D4	2017-07-04 06:28:00+03	62900.00
6041D5	2017-08-01 05:51:00+03	230000.00
6041EE	2017-07-13 09:30:00+03	133200.00
6041F8	2017-08-06 13:07:00+03	29200.00
6042C1	2017-07-22 07:54:00+03	28000.00
6042D6	2017-08-01 14:02:00+03	19600.00
604301	2017-08-09 07:36:00+03	29600.00
604307	2017-07-29 12:53:00+03	169000.00
60432A	2017-08-06 00:37:00+03	483900.00
6043A8	2017-07-06 09:54:00+03	57600.00
6043BE	2017-07-20 10:57:00+03	155600.00
60448E	2017-08-01 11:15:00+03	289100.00
60449A	2017-08-08 09:23:00+03	94200.00
6044BE	2017-07-28 02:11:00+03	70800.00
604574	2017-08-12 06:46:00+03	115800.00
604593	2017-07-06 14:54:00+03	264000.00
6045F8	2017-07-29 12:54:00+03	24400.00
604668	2017-07-09 08:56:00+03	8000.00
60470F	2017-07-19 04:32:00+03	57400.00
60474D	2017-07-20 02:23:00+03	86300.00
604760	2017-07-16 04:37:00+03	45100.00
6047DE	2017-07-06 03:24:00+03	108000.00
60482E	2017-07-13 17:35:00+03	17000.00
604855	2017-08-03 03:50:00+03	125200.00
60486B	2017-07-18 16:23:00+03	6000.00
60486D	2017-07-16 16:25:00+03	43200.00
604899	2017-07-16 18:42:00+03	54800.00
6048B7	2017-07-04 09:33:00+03	16400.00
6048B8	2017-07-16 22:54:00+03	73600.00
604931	2017-07-29 01:17:00+03	119700.00
604950	2017-07-09 15:51:00+03	27900.00
604976	2017-07-11 07:58:00+03	6000.00
604991	2017-08-13 17:59:00+03	92800.00
604997	2017-08-14 09:40:00+03	46400.00
6049B4	2017-07-14 22:54:00+03	50000.00
6049BB	2017-07-05 10:58:00+03	257500.00
604A64	2017-07-12 21:35:00+03	124200.00
604AC5	2017-06-30 10:00:00+03	325500.00
604C57	2017-08-11 14:08:00+03	13400.00
604C73	2017-07-28 16:26:00+03	17000.00
604CC3	2017-07-06 09:17:00+03	21600.00
604CC7	2017-07-24 15:15:00+03	14000.00
604CDA	2017-07-26 18:41:00+03	77900.00
604D42	2017-08-11 04:05:00+03	133200.00
604D98	2017-08-01 10:41:00+03	283100.00
604E4E	2017-08-15 05:45:00+03	134400.00
604E90	2017-08-07 11:30:00+03	23400.00
604EB2	2017-08-13 11:11:00+03	28000.00
604F1C	2017-08-02 07:54:00+03	797000.00
604FA1	2017-07-09 08:01:00+03	50100.00
604FC6	2017-07-04 09:30:00+03	22000.00
605000	2017-07-10 23:12:00+03	31000.00
60507A	2017-07-09 17:58:00+03	28000.00
605168	2017-07-07 14:54:00+03	117500.00
60517A	2017-08-09 07:11:00+03	38200.00
6051D1	2017-07-19 13:27:00+03	56000.00
605259	2017-07-29 22:02:00+03	52400.00
605274	2017-07-31 22:58:00+03	115900.00
6052DF	2017-08-07 17:10:00+03	94000.00
605359	2017-07-28 03:39:00+03	46300.00
60535E	2017-07-23 13:38:00+03	90800.00
6053D2	2017-07-10 01:45:00+03	89500.00
60542A	2017-07-01 11:51:00+03	18800.00
60542C	2017-07-26 23:05:00+03	81600.00
605433	2017-07-11 01:40:00+03	52000.00
60548B	2017-08-08 17:39:00+03	344700.00
6054B2	2017-07-26 00:43:00+03	92800.00
60553D	2017-07-24 17:08:00+03	26000.00
60554C	2017-07-13 18:50:00+03	240600.00
605559	2017-07-14 07:51:00+03	29400.00
60556D	2017-08-04 08:14:00+03	111600.00
605589	2017-07-20 07:54:00+03	12400.00
6055E2	2017-07-05 20:37:00+03	42600.00
6055F5	2017-07-18 13:08:00+03	95000.00
60561A	2017-07-05 03:17:00+03	38000.00
605669	2017-07-16 12:52:00+03	98200.00
605698	2017-07-11 19:20:00+03	27200.00
60572C	2017-07-15 20:14:00+03	28000.00
6057E0	2017-07-24 04:29:00+03	19600.00
605809	2017-07-20 11:19:00+03	34000.00
60583A	2017-07-21 21:14:00+03	136500.00
60587F	2017-08-06 12:28:00+03	18000.00
6058FB	2017-08-01 16:22:00+03	27400.00
60592F	2017-07-07 14:53:00+03	47000.00
60595C	2017-07-06 13:45:00+03	28000.00
605978	2017-07-23 20:00:00+03	213200.00
605A67	2017-07-24 03:33:00+03	133600.00
605A6E	2017-08-07 17:29:00+03	57800.00
605AAA	2017-07-24 05:47:00+03	49100.00
605AAB	2017-08-06 09:08:00+03	92100.00
605B10	2017-08-03 13:51:00+03	23400.00
605B96	2017-06-29 23:29:00+03	51600.00
605BAC	2017-07-03 00:51:00+03	66200.00
605C1A	2017-08-13 11:19:00+03	52000.00
605CA1	2017-07-31 12:17:00+03	76400.00
605CF0	2017-07-09 08:26:00+03	6700.00
605D3D	2017-07-27 20:03:00+03	38800.00
605D64	2017-08-05 00:33:00+03	76600.00
605DF4	2017-07-08 23:35:00+03	112000.00
605DFA	2017-07-09 17:18:00+03	120900.00
605E10	2017-07-29 01:11:00+03	48800.00
605E44	2017-07-03 11:38:00+03	6700.00
605E4B	2017-08-03 08:00:00+03	35200.00
605EBD	2017-08-07 05:20:00+03	56600.00
605EF9	2017-08-15 02:26:00+03	41800.00
605F03	2017-07-14 07:29:00+03	89600.00
605FBD	2017-07-18 22:14:00+03	40000.00
606053	2017-06-25 04:58:00+03	36200.00
6060AB	2017-08-09 14:30:00+03	59300.00
6060AC	2017-08-06 05:23:00+03	31000.00
6060F8	2017-07-06 01:43:00+03	56000.00
606146	2017-07-24 08:19:00+03	46700.00
606159	2017-07-08 01:33:00+03	29400.00
60616B	2017-08-04 09:29:00+03	114800.00
6061D5	2017-08-11 13:10:00+03	30200.00
6061F4	2017-07-06 10:25:00+03	43800.00
606200	2017-07-13 00:04:00+03	175500.00
606219	2017-07-18 12:49:00+03	133100.00
606238	2017-07-07 13:29:00+03	13400.00
60623E	2017-06-27 13:07:00+03	6000.00
60624F	2017-08-03 17:27:00+03	91100.00
606251	2017-08-11 08:25:00+03	21400.00
606257	2017-07-29 19:19:00+03	54500.00
6062A5	2017-07-29 14:16:00+03	33100.00
6062A7	2017-07-30 14:11:00+03	103200.00
606302	2017-07-08 13:44:00+03	80200.00
606307	2017-07-29 22:48:00+03	109000.00
60635E	2017-07-04 04:12:00+03	50100.00
6063D4	2017-08-03 03:20:00+03	135300.00
6063DF	2017-08-14 11:43:00+03	114400.00
6063E7	2017-07-29 11:31:00+03	22000.00
6063EF	2017-08-13 08:40:00+03	38400.00
606421	2017-08-10 10:09:00+03	122800.00
6064A4	2017-08-03 17:13:00+03	26200.00
6064BB	2017-07-08 22:41:00+03	65500.00
6064ED	2017-06-30 20:16:00+03	22000.00
606553	2017-07-02 03:05:00+03	118800.00
606589	2017-08-05 13:17:00+03	135200.00
606590	2017-06-29 08:19:00+03	114400.00
60659E	2017-07-30 01:32:00+03	43200.00
60659F	2017-08-15 13:31:00+03	68400.00
6065CA	2017-07-27 22:02:00+03	43800.00
606622	2017-07-09 20:29:00+03	75600.00
60662B	2017-08-01 00:09:00+03	67600.00
606740	2017-07-16 17:06:00+03	67600.00
606765	2017-07-26 12:59:00+03	42400.00
60680A	2017-07-17 04:45:00+03	66600.00
60683E	2017-07-05 07:01:00+03	32800.00
6068E7	2017-07-15 03:33:00+03	72600.00
6069A1	2017-08-07 16:11:00+03	7200.00
6069C7	2017-07-12 14:45:00+03	37200.00
6069F4	2017-08-09 13:22:00+03	26800.00
606AAB	2017-07-28 20:14:00+03	64400.00
606AAC	2017-07-23 15:10:00+03	11600.00
606ABA	2017-08-06 22:13:00+03	22400.00
606B5D	2017-07-19 01:16:00+03	16300.00
606B98	2017-08-02 01:57:00+03	10700.00
606BCA	2017-08-06 04:58:00+03	43200.00
606C30	2017-06-29 20:29:00+03	28000.00
606C79	2017-07-22 05:18:00+03	48800.00
606CE0	2017-07-15 02:17:00+03	44600.00
606CF2	2017-07-28 13:10:00+03	12600.00
606CF8	2017-07-02 03:05:00+03	32800.00
606D2A	2017-07-24 18:54:00+03	256100.00
606D70	2017-08-14 07:29:00+03	53500.00
606D77	2017-07-19 17:39:00+03	40100.00
606DA0	2017-07-15 04:31:00+03	88000.00
606E45	2017-07-20 23:13:00+03	79600.00
606E5E	2017-07-29 22:29:00+03	66600.00
606E8F	2017-08-12 05:39:00+03	39100.00
606EAC	2017-07-23 04:06:00+03	45400.00
606EBB	2017-07-16 20:40:00+03	89700.00
606EBE	2017-07-05 18:33:00+03	6600.00
606EC8	2017-07-01 02:42:00+03	53800.00
606EE3	2017-07-07 09:33:00+03	80100.00
606EFD	2017-06-30 03:15:00+03	38400.00
606F08	2017-07-25 14:27:00+03	48500.00
606F47	2017-07-27 23:12:00+03	47000.00
606FB4	2017-07-20 04:49:00+03	40400.00
607005	2017-07-14 12:25:00+03	10700.00
60700E	2017-07-22 11:17:00+03	60400.00
6070FD	2017-08-06 16:47:00+03	135400.00
607111	2017-08-12 14:51:00+03	110500.00
60712D	2017-07-05 16:27:00+03	123000.00
6071A1	2017-08-15 17:21:00+03	51900.00
60721D	2017-07-15 19:12:00+03	21400.00
60722A	2017-07-19 19:07:00+03	36800.00
60727B	2017-08-07 08:55:00+03	30000.00
60729F	2017-07-17 05:09:00+03	23600.00
6072BA	2017-07-29 09:06:00+03	23400.00
6072CE	2017-07-12 11:22:00+03	62000.00
6072F8	2017-07-31 23:40:00+03	55800.00
607309	2017-07-31 02:36:00+03	50600.00
6073B8	2017-06-28 21:12:00+03	26700.00
6073E7	2017-08-09 03:22:00+03	96800.00
607448	2017-08-07 23:14:00+03	47000.00
607488	2017-08-11 21:10:00+03	24400.00
607500	2017-07-07 16:02:00+03	40800.00
607541	2017-08-01 17:29:00+03	190100.00
60757E	2017-08-13 12:13:00+03	89400.00
6075B9	2017-08-03 02:00:00+03	84000.00
607626	2017-07-01 13:54:00+03	80000.00
60763E	2017-07-14 15:39:00+03	26700.00
607651	2017-07-26 06:59:00+03	6800.00
60765E	2017-07-26 03:49:00+03	89700.00
607683	2017-08-02 01:37:00+03	14800.00
607731	2017-07-18 15:38:00+03	15900.00
607852	2017-07-20 15:10:00+03	57500.00
60786A	2017-07-18 15:59:00+03	21800.00
6078B6	2017-08-01 17:58:00+03	45100.00
6078D8	2017-08-06 08:52:00+03	100600.00
60790D	2017-07-05 10:52:00+03	75600.00
607916	2017-08-01 14:06:00+03	67600.00
607922	2017-07-12 23:57:00+03	6800.00
60798C	2017-07-10 19:03:00+03	124200.00
6079A8	2017-07-15 01:01:00+03	31900.00
607A0C	2017-07-18 04:03:00+03	60700.00
607A13	2017-07-09 05:48:00+03	71600.00
607A30	2017-08-04 04:14:00+03	66600.00
607A43	2017-07-17 06:49:00+03	19600.00
607AB9	2017-07-15 22:16:00+03	253200.00
607ACD	2017-07-02 06:47:00+03	57300.00
607B52	2017-08-12 12:06:00+03	62600.00
607C17	2017-07-18 09:08:00+03	378700.00
607CA8	2017-07-25 07:33:00+03	96800.00
607CAD	2017-07-20 18:02:00+03	265600.00
607CB9	2017-06-28 11:21:00+03	44500.00
607D02	2017-07-12 17:12:00+03	203400.00
607D3B	2017-08-08 18:17:00+03	87900.00
607E72	2017-08-04 15:14:00+03	14000.00
607E9B	2017-07-07 10:25:00+03	22000.00
607EB6	2017-08-08 14:40:00+03	666000.00
607FA2	2017-07-06 13:28:00+03	85700.00
607FAA	2017-06-28 21:31:00+03	87800.00
608027	2017-07-11 22:00:00+03	123000.00
608031	2017-07-14 19:29:00+03	47900.00
608045	2017-07-24 19:43:00+03	90800.00
608046	2017-07-10 12:46:00+03	52000.00
6080AE	2017-07-11 02:54:00+03	94000.00
6080EA	2017-07-09 03:37:00+03	62600.00
608141	2017-08-13 19:02:00+03	192500.00
608148	2017-07-28 04:47:00+03	102100.00
6081B6	2017-08-10 09:47:00+03	109600.00
608267	2017-07-16 18:19:00+03	30200.00
6082AE	2017-07-15 09:50:00+03	65400.00
6082CD	2017-08-02 02:59:00+03	180200.00
60831F	2017-07-03 03:42:00+03	49100.00
608376	2017-07-18 03:05:00+03	51900.00
60837E	2017-07-01 06:49:00+03	134200.00
6083BD	2017-08-12 18:05:00+03	39500.00
6083C1	2017-07-22 17:13:00+03	32200.00
6083C8	2017-06-26 14:04:00+03	87200.00
6083CB	2017-07-06 15:55:00+03	25600.00
6083CF	2017-07-23 01:32:00+03	65800.00
608417	2017-08-03 14:28:00+03	101200.00
60841C	2017-07-10 18:38:00+03	37400.00
60842A	2017-08-01 09:57:00+03	67400.00
608454	2017-08-09 15:10:00+03	18800.00
6084C3	2017-07-14 23:14:00+03	202100.00
608507	2017-07-20 12:00:00+03	26000.00
60850C	2017-08-04 16:00:00+03	63200.00
608589	2017-07-23 12:44:00+03	79600.00
608592	2017-07-20 20:02:00+03	28800.00
60861F	2017-08-15 13:46:00+03	24600.00
6086C4	2017-08-07 23:03:00+03	48800.00
6086F6	2017-08-05 14:30:00+03	246000.00
608714	2017-07-18 01:01:00+03	55400.00
608769	2017-07-06 16:16:00+03	19000.00
608792	2017-08-03 17:56:00+03	27900.00
60885B	2017-07-31 15:54:00+03	286400.00
608963	2017-07-09 05:15:00+03	100200.00
608994	2017-08-10 03:47:00+03	10600.00
608996	2017-07-04 06:04:00+03	6000.00
608A13	2017-07-08 13:16:00+03	21800.00
608A24	2017-07-20 18:19:00+03	65200.00
608A37	2017-07-07 16:14:00+03	28000.00
608A51	2017-07-30 13:59:00+03	42700.00
608A57	2017-07-06 17:46:00+03	56000.00
608A65	2017-07-04 06:10:00+03	53400.00
608B51	2017-08-01 09:20:00+03	192900.00
608B6B	2017-08-10 13:10:00+03	13400.00
608BA4	2017-07-17 13:17:00+03	156300.00
608BD6	2017-07-27 10:00:00+03	113900.00
608BEC	2017-08-01 02:14:00+03	56000.00
608BFB	2017-07-24 10:53:00+03	113300.00
608C3B	2017-08-15 05:42:00+03	53600.00
608CD6	2017-07-27 09:56:00+03	81700.00
608CE0	2017-06-25 05:52:00+03	123000.00
608D15	2017-07-30 16:37:00+03	92800.00
608D21	2017-07-08 06:56:00+03	56900.00
608D2A	2017-07-24 03:02:00+03	67700.00
608D59	2017-07-14 00:15:00+03	23400.00
608DB2	2017-08-10 10:39:00+03	114800.00
608DCD	2017-08-02 07:38:00+03	65600.00
608E75	2017-08-01 12:23:00+03	6700.00
608EE6	2017-07-06 19:51:00+03	46700.00
608F20	2017-08-13 20:20:00+03	67600.00
608F49	2017-07-31 06:25:00+03	126500.00
608F9E	2017-07-12 06:52:00+03	10800.00
608FC2	2017-08-06 14:41:00+03	547600.00
608FCE	2017-08-04 10:35:00+03	155400.00
60907D	2017-07-03 13:16:00+03	21000.00
60907E	2017-07-31 17:21:00+03	37600.00
609125	2017-08-01 08:55:00+03	11600.00
609172	2017-07-19 10:26:00+03	28400.00
609180	2017-08-09 12:03:00+03	19300.00
609217	2017-07-18 23:47:00+03	133200.00
609246	2017-07-28 22:06:00+03	265700.00
6093A2	2017-08-07 22:10:00+03	75000.00
6094AF	2017-08-09 22:17:00+03	75300.00
60951D	2017-06-26 23:13:00+03	30600.00
60951F	2017-06-30 10:29:00+03	20000.00
60952F	2017-08-08 01:22:00+03	25200.00
609551	2017-07-18 00:13:00+03	13400.00
609571	2017-08-02 12:34:00+03	63700.00
60963F	2017-08-13 08:42:00+03	132800.00
609654	2017-08-10 22:47:00+03	16400.00
6096E1	2017-08-01 14:21:00+03	117100.00
609705	2017-07-20 23:50:00+03	16000.00
609844	2017-08-05 06:12:00+03	92800.00
609885	2017-08-10 08:48:00+03	38400.00
609889	2017-07-29 13:59:00+03	134800.00
6098D2	2017-07-19 08:02:00+03	27600.00
6098E1	2017-07-20 23:51:00+03	6700.00
6098F2	2017-08-05 02:03:00+03	266400.00
609970	2017-07-12 07:01:00+03	189700.00
609998	2017-07-31 08:42:00+03	25400.00
6099B2	2017-07-09 19:42:00+03	28800.00
6099EE	2017-08-09 08:49:00+03	21800.00
609A4E	2017-08-09 11:17:00+03	92900.00
609A58	2017-07-06 21:28:00+03	37700.00
609A61	2017-07-14 12:34:00+03	7200.00
609AC0	2017-07-29 13:20:00+03	138500.00
609AEE	2017-07-29 06:18:00+03	68100.00
609B16	2017-08-01 18:45:00+03	75300.00
609B69	2017-07-08 07:01:00+03	26000.00
609B81	2017-07-28 22:26:00+03	52000.00
609B91	2017-08-15 00:17:00+03	40800.00
609BDD	2017-08-13 22:30:00+03	72800.00
609BF3	2017-07-05 13:37:00+03	12600.00
609C1E	2017-08-14 19:13:00+03	70700.00
609C33	2017-08-04 09:40:00+03	129400.00
609C5C	2017-07-26 01:52:00+03	20200.00
609C89	2017-07-15 10:31:00+03	7400.00
609CE5	2017-08-07 07:42:00+03	28800.00
609D00	2017-07-31 01:36:00+03	103500.00
609DC3	2017-07-14 06:03:00+03	58000.00
609DFC	2017-07-15 04:50:00+03	56000.00
609E12	2017-07-16 04:08:00+03	456400.00
609E6E	2017-08-15 04:30:00+03	44000.00
609E7D	2017-08-03 22:58:00+03	60400.00
609E88	2017-07-31 02:52:00+03	96800.00
609E91	2017-07-06 06:10:00+03	46400.00
609EFD	2017-07-30 20:52:00+03	62800.00
609F07	2017-07-04 03:32:00+03	28000.00
609F66	2017-07-04 04:05:00+03	47900.00
609F6E	2017-07-25 12:59:00+03	172600.00
609FC5	2017-07-16 22:11:00+03	46300.00
60A033	2017-07-10 20:16:00+03	6300.00
60A0BD	2017-07-09 03:02:00+03	28800.00
60A1F2	2017-08-10 06:54:00+03	70700.00
60A29C	2017-07-04 08:23:00+03	148200.00
60A35F	2017-07-28 10:14:00+03	46400.00
60A361	2017-08-03 18:44:00+03	119600.00
60A427	2017-07-04 21:17:00+03	22000.00
60A430	2017-07-19 14:34:00+03	88900.00
60A48E	2017-07-14 20:21:00+03	141800.00
60A4B5	2017-07-23 21:09:00+03	14400.00
60A4CC	2017-07-22 10:08:00+03	47400.00
60A4D9	2017-07-17 03:44:00+03	72400.00
60A4F9	2017-07-04 19:08:00+03	371600.00
60A564	2017-08-08 16:59:00+03	46300.00
60A5BC	2017-07-08 16:46:00+03	27300.00
60A5E8	2017-07-06 00:53:00+03	69400.00
60A60C	2017-07-01 11:29:00+03	28000.00
60A6A0	2017-07-18 00:12:00+03	100600.00
60A6B2	2017-08-15 13:37:00+03	28000.00
60A74A	2017-08-14 10:59:00+03	39200.00
60A765	2017-08-10 00:09:00+03	150500.00
60A7CB	2017-07-06 08:02:00+03	136500.00
60A8A4	2017-07-08 02:30:00+03	61600.00
60A8AF	2017-07-31 10:38:00+03	123000.00
60A8C3	2017-08-14 16:29:00+03	108900.00
60A913	2017-08-06 05:08:00+03	142400.00
60A931	2017-08-15 13:40:00+03	24400.00
60A959	2017-08-04 21:44:00+03	20400.00
60A9D9	2017-07-04 02:10:00+03	54100.00
60AA4A	2017-07-06 05:34:00+03	73600.00
60AA61	2017-07-06 09:09:00+03	187600.00
60AAD3	2017-07-06 10:13:00+03	542300.00
60ACE6	2017-07-30 12:56:00+03	280000.00
60ACF7	2017-07-10 04:10:00+03	56000.00
60AD0F	2017-07-05 20:12:00+03	6700.00
60AD20	2017-07-25 19:23:00+03	40000.00
60AD4C	2017-07-02 09:50:00+03	36400.00
60AD6E	2017-07-01 08:06:00+03	8200.00
60ADD3	2017-07-12 09:25:00+03	145800.00
60AE97	2017-07-29 05:41:00+03	39200.00
60AEEE	2017-07-09 01:23:00+03	21400.00
60AF59	2017-07-12 21:49:00+03	198600.00
60AF92	2017-07-13 02:43:00+03	74600.00
60AFE1	2017-08-03 12:10:00+03	62900.00
60AFF3	2017-08-05 19:45:00+03	18600.00
60B13B	2017-07-10 07:32:00+03	31600.00
60B146	2017-07-14 19:02:00+03	17600.00
60B196	2017-08-12 07:07:00+03	59300.00
60B254	2017-08-08 03:24:00+03	70100.00
60B2DC	2017-08-04 05:46:00+03	73200.00
60B32F	2017-07-15 22:13:00+03	47500.00
60B3AF	2017-06-27 22:55:00+03	16400.00
60B3DD	2017-07-20 08:38:00+03	16400.00
60B3E6	2017-07-24 12:47:00+03	66500.00
60B422	2017-07-22 15:35:00+03	34000.00
60B430	2017-08-15 03:09:00+03	46000.00
60B433	2017-07-09 16:10:00+03	31000.00
60B43B	2017-07-29 07:54:00+03	133200.00
60B5E3	2017-06-27 15:00:00+03	26700.00
60B645	2017-07-12 03:35:00+03	160000.00
60B6AF	2017-08-12 03:33:00+03	19800.00
60B6DF	2017-07-20 13:35:00+03	105600.00
60B6FB	2017-07-05 16:47:00+03	37700.00
60B6FD	2017-08-10 16:12:00+03	67000.00
60B7C6	2017-08-07 09:48:00+03	532800.00
60B7D0	2017-07-16 23:59:00+03	39400.00
60B806	2017-07-25 18:03:00+03	79100.00
60B80A	2017-07-31 18:44:00+03	136800.00
60B85F	2017-08-04 06:07:00+03	190400.00
60B88F	2017-08-06 13:47:00+03	32700.00
60B979	2017-07-31 17:39:00+03	21400.00
60B9C7	2017-08-12 03:03:00+03	42600.00
60B9DB	2017-08-11 21:10:00+03	147200.00
60B9EA	2017-07-27 00:16:00+03	46300.00
60BA5C	2017-07-14 02:36:00+03	200400.00
60BA63	2017-08-15 06:08:00+03	265800.00
60BA8C	2017-07-12 02:59:00+03	77700.00
60BB09	2017-07-04 18:33:00+03	25900.00
60BB1F	2017-07-20 01:50:00+03	336300.00
60BB78	2017-07-20 07:31:00+03	58200.00
60BB8F	2017-07-30 00:15:00+03	10600.00
60BB93	2017-08-05 22:56:00+03	77200.00
60BBB6	2017-07-24 01:25:00+03	36200.00
60BBEE	2017-07-04 13:09:00+03	6700.00
60BC55	2017-08-15 07:42:00+03	43000.00
60BC59	2017-07-14 14:00:00+03	83900.00
60BC5E	2017-08-10 12:21:00+03	81200.00
60BD51	2017-07-26 19:27:00+03	56000.00
60BD58	2017-07-13 08:11:00+03	238500.00
60BE1D	2017-07-28 18:26:00+03	39800.00
60BF3D	2017-08-15 11:25:00+03	31400.00
60BF46	2017-07-15 09:03:00+03	54800.00
60BFB7	2017-07-31 02:05:00+03	40700.00
60BFEB	2017-08-06 01:18:00+03	90000.00
60BFFA	2017-07-02 02:31:00+03	38800.00
60C001	2017-07-31 05:04:00+03	69400.00
60C03E	2017-08-11 02:44:00+03	18400.00
60C081	2017-07-31 07:57:00+03	29400.00
60C0A8	2017-07-22 11:14:00+03	260900.00
60C0C9	2017-07-08 15:41:00+03	112000.00
60C0EF	2017-08-12 09:43:00+03	29500.00
60C11D	2017-07-07 04:19:00+03	25800.00
60C13C	2017-07-31 02:59:00+03	135200.00
60C181	2017-06-26 06:32:00+03	95200.00
60C196	2017-06-30 07:47:00+03	48200.00
60C1E9	2017-07-10 01:06:00+03	120900.00
60C1F3	2017-07-19 06:19:00+03	67000.00
60C293	2017-08-02 14:10:00+03	23200.00
60C2C8	2017-08-02 12:52:00+03	189200.00
60C31D	2017-07-27 14:44:00+03	16400.00
60C47F	2017-07-23 12:36:00+03	50000.00
60C4D0	2017-08-11 11:17:00+03	92100.00
60C52E	2017-07-20 00:32:00+03	246000.00
60C572	2017-07-14 04:59:00+03	36800.00
60C580	2017-08-05 10:18:00+03	89600.00
60C606	2017-06-30 16:35:00+03	26800.00
60C638	2017-07-30 01:15:00+03	28000.00
60C6C2	2017-08-07 05:03:00+03	58600.00
60C70E	2017-08-05 00:43:00+03	248300.00
60C718	2017-07-13 16:36:00+03	21500.00
60C757	2017-07-23 07:49:00+03	71200.00
60C7C2	2017-07-28 06:21:00+03	50600.00
60C7D3	2017-08-09 11:04:00+03	136800.00
60C7D5	2017-08-04 00:09:00+03	10600.00
60C84B	2017-07-03 22:24:00+03	46000.00
60C884	2017-07-07 23:36:00+03	31600.00
60C91F	2017-07-15 20:14:00+03	24400.00
60C949	2017-07-13 06:24:00+03	76300.00
60C980	2017-07-10 17:29:00+03	113200.00
60C98E	2017-08-13 08:44:00+03	67200.00
60C9AC	2017-07-28 03:03:00+03	10600.00
60CA05	2017-08-02 15:13:00+03	44000.00
60CA0A	2017-07-14 04:14:00+03	20200.00
60CA66	2017-07-05 13:04:00+03	28000.00
60CA85	2017-07-29 05:22:00+03	88200.00
60CB50	2017-07-06 23:36:00+03	70600.00
60CB59	2017-08-05 04:34:00+03	51900.00
60CBF9	2017-08-07 20:37:00+03	71600.00
60CC0A	2017-07-22 08:49:00+03	30800.00
60CC67	2017-08-14 05:27:00+03	13400.00
60CC6E	2017-08-10 15:14:00+03	62600.00
60CC9B	2017-07-08 10:44:00+03	62700.00
60CCE9	2017-07-01 00:37:00+03	65400.00
60CCF8	2017-07-24 16:15:00+03	72400.00
60CD38	2017-07-13 01:51:00+03	100000.00
60CD9E	2017-07-06 05:36:00+03	481800.00
60CDD8	2017-07-11 02:14:00+03	40900.00
60CE19	2017-07-10 10:29:00+03	386300.00
60CE6E	2017-08-04 21:52:00+03	46000.00
60CE8C	2017-07-14 02:47:00+03	47200.00
60CEE0	2017-07-04 19:36:00+03	177200.00
60CF05	2017-08-08 09:43:00+03	62600.00
60CF8D	2017-08-04 00:31:00+03	60800.00
60CFD9	2017-08-07 03:06:00+03	202600.00
60D072	2017-08-15 14:31:00+03	195800.00
60D0BC	2017-07-28 05:56:00+03	69500.00
60D0FC	2017-06-24 17:10:00+03	28700.00
60D101	2017-07-17 13:22:00+03	89100.00
60D140	2017-08-03 16:39:00+03	67200.00
60D151	2017-07-19 16:40:00+03	92700.00
60D165	2017-07-04 03:39:00+03	38800.00
60D168	2017-08-04 00:14:00+03	53400.00
60D1C3	2017-07-13 19:14:00+03	48800.00
60D1F9	2017-08-15 15:45:00+03	61500.00
60D22D	2017-07-19 05:38:00+03	144400.00
60D234	2017-07-18 01:55:00+03	101100.00
60D2D6	2017-08-08 06:47:00+03	43900.00
60D2E0	2017-07-03 15:47:00+03	123000.00
60D319	2017-07-24 12:24:00+03	46000.00
60D31C	2017-07-14 17:01:00+03	162600.00
60D3C8	2017-08-13 08:36:00+03	95600.00
60D3ED	2017-08-09 21:40:00+03	62700.00
60D432	2017-08-02 20:25:00+03	43900.00
60D452	2017-06-29 01:32:00+03	23600.00
60D460	2017-07-01 08:00:00+03	78600.00
60D4B9	2017-07-30 18:38:00+03	43200.00
60D508	2017-06-29 06:02:00+03	84500.00
60D573	2017-07-02 03:18:00+03	67600.00
60D5B5	2017-08-11 07:36:00+03	54300.00
60D60B	2017-08-07 22:17:00+03	120000.00
60D627	2017-07-19 23:57:00+03	42800.00
60D674	2017-08-01 04:03:00+03	135400.00
60D750	2017-07-11 22:18:00+03	68800.00
60D758	2017-07-09 16:55:00+03	58000.00
60D7BA	2017-07-10 14:16:00+03	19600.00
60D7F3	2017-08-13 17:29:00+03	128900.00
60D803	2017-08-02 02:54:00+03	46300.00
60D859	2017-07-13 07:13:00+03	135600.00
60D85C	2017-07-14 22:42:00+03	270000.00
60D8C3	2017-07-06 17:30:00+03	40800.00
60D8DB	2017-07-21 11:43:00+03	131100.00
60D903	2017-07-17 15:29:00+03	28800.00
60D916	2017-07-31 19:05:00+03	27200.00
60D966	2017-08-09 20:05:00+03	11600.00
60D981	2017-07-22 17:44:00+03	106800.00
60DA36	2017-07-24 09:18:00+03	56900.00
60DA4F	2017-07-13 20:57:00+03	23400.00
60DA6F	2017-07-02 15:48:00+03	199700.00
60DA8C	2017-08-11 11:22:00+03	49600.00
60DADD	2017-07-29 01:48:00+03	117700.00
60DAF5	2017-07-22 07:06:00+03	12600.00
60DB06	2017-08-08 19:50:00+03	73600.00
60DB13	2017-08-13 10:22:00+03	38400.00
60DB25	2017-07-17 02:47:00+03	106300.00
60DB28	2017-07-05 22:51:00+03	85000.00
60DB8B	2017-06-26 18:07:00+03	114800.00
60DBB4	2017-08-15 02:48:00+03	55400.00
60DBCD	2017-08-14 05:09:00+03	46000.00
60DC16	2017-07-24 19:03:00+03	133100.00
60DC53	2017-08-02 08:03:00+03	137600.00
60DD31	2017-08-09 13:44:00+03	59200.00
60DD37	2017-07-22 00:48:00+03	118600.00
60DEE2	2017-07-21 22:01:00+03	96200.00
60DF0B	2017-07-09 21:36:00+03	26000.00
60DF68	2017-07-26 22:16:00+03	53300.00
60DF6A	2017-08-07 11:03:00+03	46400.00
60DF85	2017-07-28 07:29:00+03	8600.00
60DFA1	2017-07-06 12:40:00+03	20100.00
60DFCE	2017-07-22 02:18:00+03	77900.00
60DFCF	2017-06-27 19:22:00+03	25100.00
60DFE3	2017-07-03 19:57:00+03	178800.00
60E025	2017-08-09 00:26:00+03	25000.00
60E043	2017-07-21 11:08:00+03	134100.00
60E04E	2017-07-22 07:27:00+03	313400.00
60E134	2017-07-11 11:02:00+03	56000.00
60E146	2017-07-07 04:02:00+03	73400.00
60E172	2017-07-16 12:46:00+03	13000.00
60E1EF	2017-08-10 21:09:00+03	91100.00
60E2BB	2017-07-17 13:10:00+03	147200.00
60E2CB	2017-07-08 16:03:00+03	47600.00
60E308	2017-07-12 02:18:00+03	21800.00
60E340	2017-07-08 07:28:00+03	52600.00
60E395	2017-06-28 10:55:00+03	167400.00
60E39A	2017-07-10 15:15:00+03	95700.00
60E401	2017-07-13 01:54:00+03	100600.00
60E42E	2017-07-04 13:34:00+03	86800.00
60E488	2017-07-27 20:53:00+03	28000.00
60E48C	2017-08-12 14:52:00+03	170000.00
60E49A	2017-08-11 05:24:00+03	53000.00
60E4F8	2017-07-08 11:30:00+03	12400.00
60E5D6	2017-07-23 14:45:00+03	341400.00
60E64C	2017-07-16 12:00:00+03	39000.00
60E670	2017-07-26 05:31:00+03	31600.00
60E687	2017-08-01 17:21:00+03	111600.00
60E694	2017-06-30 04:15:00+03	136800.00
60E6D3	2017-08-08 00:09:00+03	59800.00
60E6D6	2017-08-15 01:27:00+03	12600.00
60E70D	2017-08-05 12:21:00+03	64700.00
60E72F	2017-07-21 04:44:00+03	91200.00
60E750	2017-07-05 07:49:00+03	73200.00
60E78C	2017-07-05 00:01:00+03	33400.00
60E79B	2017-07-02 10:26:00+03	62800.00
60E7B8	2017-08-15 06:52:00+03	38600.00
60E7BD	2017-08-10 23:19:00+03	47600.00
60E81E	2017-08-09 17:23:00+03	25600.00
60E836	2017-06-27 09:07:00+03	68100.00
60E839	2017-07-13 07:49:00+03	37100.00
60E8BD	2017-07-05 08:37:00+03	40800.00
60E8CE	2017-07-22 13:09:00+03	6700.00
60E97A	2017-07-31 16:06:00+03	70700.00
60E97C	2017-07-12 01:58:00+03	40400.00
60E97D	2017-07-08 20:56:00+03	27800.00
60E993	2017-07-14 20:13:00+03	66600.00
60E9AC	2017-07-30 13:47:00+03	56600.00
60E9C0	2017-07-14 09:25:00+03	47000.00
60E9CF	2017-08-15 12:51:00+03	117200.00
60EA2D	2017-07-09 12:44:00+03	42800.00
60EA72	2017-07-06 00:54:00+03	55800.00
60EA86	2017-08-01 09:21:00+03	66600.00
60EA93	2017-07-12 03:17:00+03	75700.00
60EA98	2017-08-02 14:13:00+03	50600.00
60EACA	2017-08-04 05:08:00+03	88000.00
60EB1C	2017-07-04 11:26:00+03	6300.00
60EB25	2017-07-29 13:13:00+03	28000.00
60EB3F	2017-07-11 21:33:00+03	30400.00
60EB43	2017-07-17 22:32:00+03	75300.00
60EB7F	2017-07-21 13:35:00+03	73500.00
60EB91	2017-07-10 04:39:00+03	46400.00
60EBBE	2017-07-28 14:42:00+03	38400.00
60EBE4	2017-08-15 06:38:00+03	89700.00
60EBF0	2017-08-09 13:48:00+03	56000.00
60EC25	2017-07-16 22:18:00+03	123000.00
60EC57	2017-08-01 14:59:00+03	66600.00
60ECD1	2017-08-02 14:01:00+03	28800.00
60ED0F	2017-08-14 00:17:00+03	56000.00
60ED2B	2017-07-14 08:37:00+03	52300.00
60EE36	2017-08-08 07:41:00+03	22000.00
60EEE5	2017-07-12 23:58:00+03	30300.00
60EF0A	2017-08-11 10:04:00+03	92800.00
60EF6C	2017-07-08 18:13:00+03	47500.00
60EF6D	2017-06-29 10:10:00+03	138800.00
60EF8C	2017-07-04 14:16:00+03	84500.00
60EF94	2017-07-25 23:56:00+03	108700.00
60EFF4	2017-08-05 09:47:00+03	26800.00
60F000	2017-08-08 00:17:00+03	70700.00
60F098	2017-07-30 06:27:00+03	55500.00
60F0B1	2017-07-04 18:03:00+03	41400.00
60F17C	2017-07-01 03:26:00+03	58400.00
60F1E9	2017-07-12 23:41:00+03	96800.00
60F21D	2017-08-02 22:52:00+03	25600.00
60F259	2017-08-03 03:42:00+03	13200.00
60F276	2017-07-28 21:35:00+03	14800.00
60F294	2017-07-26 18:30:00+03	23600.00
60F2C8	2017-07-28 09:51:00+03	265700.00
60F335	2017-08-11 09:40:00+03	23600.00
60F359	2017-07-29 08:30:00+03	75300.00
60F3D0	2017-07-27 23:04:00+03	192900.00
60F3DA	2017-08-14 13:07:00+03	35900.00
60F3ED	2017-08-13 00:02:00+03	23200.00
60F42C	2017-08-01 18:15:00+03	49600.00
60F441	2017-07-16 06:41:00+03	235900.00
60F4DC	2017-07-23 04:53:00+03	194000.00
60F4E9	2017-07-22 15:26:00+03	61800.00
60F4F5	2017-07-07 07:58:00+03	96800.00
60F527	2017-08-15 08:25:00+03	39100.00
60F52C	2017-07-10 22:07:00+03	57600.00
60F549	2017-06-30 08:29:00+03	9800.00
60F55F	2017-08-13 11:56:00+03	155000.00
60F5A8	2017-08-07 04:42:00+03	56000.00
60F5EE	2017-07-17 19:50:00+03	33600.00
60F600	2017-07-21 00:12:00+03	59300.00
60F607	2017-08-06 12:53:00+03	59800.00
60F62E	2017-07-08 12:57:00+03	62200.00
60F659	2017-07-05 22:58:00+03	269400.00
60F6EA	2017-07-03 17:06:00+03	58200.00
60F705	2017-07-02 17:07:00+03	25600.00
60F760	2017-07-02 01:34:00+03	6000.00
60F7E7	2017-07-24 23:40:00+03	67400.00
60F810	2017-07-31 06:10:00+03	25800.00
60F837	2017-07-22 18:56:00+03	18600.00
60F86A	2017-07-31 22:21:00+03	123000.00
60F944	2017-07-30 15:59:00+03	49800.00
60FA2C	2017-07-04 07:49:00+03	64800.00
60FAA6	2017-08-05 15:33:00+03	83000.00
60FB06	2017-08-03 08:50:00+03	25400.00
60FB47	2017-07-27 20:33:00+03	24000.00
60FB72	2017-08-08 21:46:00+03	39800.00
60FB75	2017-07-09 21:33:00+03	24800.00
60FB7E	2017-07-12 11:29:00+03	134400.00
60FB93	2017-08-07 00:23:00+03	137700.00
60FBBA	2017-08-02 09:11:00+03	6700.00
60FBBE	2017-06-29 08:02:00+03	23200.00
60FBCF	2017-07-20 05:48:00+03	62600.00
60FC07	2017-07-05 15:48:00+03	75300.00
60FC2F	2017-07-07 06:14:00+03	15000.00
60FCB3	2017-08-02 16:01:00+03	148200.00
60FCD8	2017-07-10 14:32:00+03	6700.00
60FD3F	2017-06-30 13:36:00+03	69500.00
60FD55	2017-08-02 16:54:00+03	88400.00
60FD72	2017-08-12 23:11:00+03	49300.00
60FD77	2017-07-06 13:09:00+03	26100.00
60FDB4	2017-07-15 03:38:00+03	99300.00
60FE04	2017-08-13 17:25:00+03	40600.00
60FE44	2017-07-13 17:46:00+03	406700.00
60FE6E	2017-08-14 00:20:00+03	115700.00
60FEA6	2017-07-24 07:37:00+03	16400.00
60FEB9	2017-07-10 01:01:00+03	67200.00
60FF1A	2017-07-02 08:13:00+03	57600.00
61006E	2017-08-11 00:56:00+03	67600.00
6100FD	2017-07-13 17:32:00+03	26000.00
610126	2017-07-08 09:26:00+03	68400.00
61012F	2017-07-29 04:02:00+03	12600.00
610160	2017-07-30 16:36:00+03	81300.00
61017A	2017-08-01 08:52:00+03	199700.00
61017F	2017-08-02 19:26:00+03	46400.00
6101F7	2017-07-28 16:05:00+03	22200.00
61020B	2017-07-03 13:38:00+03	59200.00
61022E	2017-07-27 19:41:00+03	26000.00
610240	2017-08-12 14:14:00+03	34400.00
61025A	2017-08-02 10:37:00+03	44800.00
6102A1	2017-08-04 04:23:00+03	59300.00
61031C	2017-07-21 09:56:00+03	61200.00
61035A	2017-07-31 04:45:00+03	91600.00
610379	2017-08-12 18:10:00+03	186900.00
6103C1	2017-06-29 23:44:00+03	131100.00
6103DD	2017-08-11 16:33:00+03	30200.00
6103EB	2017-08-08 23:21:00+03	78200.00
61043A	2017-07-19 06:46:00+03	146700.00
610453	2017-07-06 05:23:00+03	119500.00
610479	2017-06-28 02:48:00+03	22000.00
6104AA	2017-07-19 08:43:00+03	189800.00
6104C3	2017-08-11 15:09:00+03	36200.00
6104D7	2017-07-21 12:13:00+03	28800.00
6104FB	2017-07-11 12:09:00+03	46200.00
610516	2017-07-12 20:55:00+03	26000.00
61054D	2017-07-03 09:33:00+03	55800.00
610585	2017-08-03 05:47:00+03	54000.00
610646	2017-07-29 19:46:00+03	94700.00
61067B	2017-08-04 08:16:00+03	123000.00
6106A1	2017-07-27 09:59:00+03	39800.00
6106B8	2017-08-05 19:13:00+03	52300.00
610751	2017-07-09 19:43:00+03	26000.00
61077A	2017-08-13 19:13:00+03	86300.00
6107F5	2017-07-13 03:27:00+03	56800.00
61080E	2017-07-18 17:26:00+03	133200.00
61085C	2017-07-24 09:40:00+03	140400.00
61085F	2017-08-08 12:45:00+03	53400.00
610871	2017-07-16 13:39:00+03	23400.00
6108C3	2017-08-08 23:23:00+03	85400.00
6108C7	2017-08-10 01:10:00+03	57400.00
610929	2017-07-09 22:46:00+03	125400.00
610942	2017-07-19 12:51:00+03	54800.00
610A01	2017-07-07 02:20:00+03	92100.00
610A2D	2017-08-07 22:43:00+03	23200.00
610A9F	2017-07-15 16:55:00+03	214400.00
610B26	2017-08-14 07:56:00+03	119500.00
610B98	2017-07-15 00:18:00+03	66600.00
610BA6	2017-07-03 10:20:00+03	18000.00
610BE3	2017-08-14 14:04:00+03	38600.00
610BE9	2017-07-07 19:37:00+03	280000.00
610C0E	2017-07-08 13:47:00+03	33300.00
610C21	2017-07-11 10:28:00+03	38500.00
610C2A	2017-07-16 19:12:00+03	41400.00
610C2D	2017-08-12 00:57:00+03	93900.00
610C8F	2017-08-13 05:01:00+03	17800.00
610C96	2017-07-17 05:31:00+03	29500.00
610CB9	2017-07-21 20:19:00+03	70200.00
610CD9	2017-07-15 18:44:00+03	163900.00
610D11	2017-07-28 15:42:00+03	60800.00
610D52	2017-07-21 14:51:00+03	71200.00
610D73	2017-07-04 15:29:00+03	79200.00
610D7F	2017-08-03 17:30:00+03	58600.00
610DE8	2017-07-28 20:21:00+03	55800.00
610E4B	2017-08-11 06:12:00+03	115600.00
610E73	2017-08-10 22:24:00+03	16400.00
610E83	2017-07-27 06:06:00+03	26000.00
610EBE	2017-07-09 19:29:00+03	21800.00
610EC6	2017-07-19 01:19:00+03	55800.00
610FCF	2017-07-23 17:27:00+03	12400.00
610FFD	2017-07-29 22:25:00+03	35800.00
611006	2017-07-28 15:54:00+03	12600.00
61105C	2017-07-31 08:17:00+03	66600.00
61107E	2017-07-23 08:06:00+03	89700.00
6110DA	2017-07-19 19:21:00+03	25600.00
6111A3	2017-07-29 12:09:00+03	22400.00
6111CE	2017-07-04 23:52:00+03	81600.00
6111E3	2017-07-18 17:43:00+03	24400.00
611210	2017-07-07 05:28:00+03	25000.00
61124F	2017-07-13 05:18:00+03	86600.00
6112A2	2017-07-27 05:32:00+03	11300.00
611349	2017-07-22 11:47:00+03	47200.00
611362	2017-07-08 11:22:00+03	16400.00
611368	2017-07-14 13:05:00+03	111600.00
611385	2017-07-17 12:19:00+03	75700.00
611446	2017-07-05 20:20:00+03	419500.00
611460	2017-08-08 09:19:00+03	43400.00
611465	2017-07-01 06:30:00+03	58400.00
611470	2017-07-13 02:37:00+03	35600.00
61147D	2017-08-08 06:00:00+03	165800.00
6114CE	2017-08-08 09:38:00+03	97700.00
6114D6	2017-08-02 22:41:00+03	257500.00
6114E1	2017-07-03 06:33:00+03	66000.00
6114FE	2017-06-27 19:18:00+03	55500.00
61153E	2017-07-18 17:40:00+03	108500.00
611558	2017-07-06 00:29:00+03	29400.00
611596	2017-08-07 11:11:00+03	52000.00
6115B9	2017-07-19 08:21:00+03	42800.00
61162A	2017-08-06 08:25:00+03	8400.00
61166A	2017-07-16 12:11:00+03	239000.00
61167C	2017-07-16 08:43:00+03	21800.00
611694	2017-08-10 09:30:00+03	62800.00
6116BD	2017-08-12 00:45:00+03	46200.00
6116D2	2017-08-01 17:07:00+03	28800.00
611713	2017-07-05 10:13:00+03	67600.00
61178C	2017-07-23 12:53:00+03	21800.00
611797	2017-07-17 15:42:00+03	60400.00
61179F	2017-07-02 00:31:00+03	37900.00
6117A9	2017-07-25 01:09:00+03	108500.00
611835	2017-07-05 19:02:00+03	69500.00
6118B9	2017-07-24 03:47:00+03	92600.00
6118F4	2017-07-09 22:27:00+03	38500.00
61190E	2017-08-06 05:44:00+03	68000.00
611913	2017-08-02 08:09:00+03	27800.00
61192B	2017-08-10 03:33:00+03	24400.00
611938	2017-08-10 11:06:00+03	8200.00
61198A	2017-07-20 23:04:00+03	46800.00
61199D	2017-07-08 10:51:00+03	34000.00
6119F2	2017-07-27 13:01:00+03	37400.00
611A01	2017-08-10 16:30:00+03	73600.00
611A3A	2017-07-17 05:21:00+03	43200.00
611A4C	2017-08-12 23:07:00+03	239100.00
611A71	2017-07-05 15:27:00+03	21400.00
611AFC	2017-07-05 21:13:00+03	169900.00
611B82	2017-07-21 20:42:00+03	46900.00
611B9D	2017-08-06 18:28:00+03	40800.00
611BC4	2017-08-12 14:29:00+03	68800.00
611C04	2017-07-14 09:36:00+03	66700.00
611C3B	2017-07-17 03:05:00+03	28000.00
611C89	2017-08-05 09:51:00+03	132800.00
611CCD	2017-07-07 09:37:00+03	124200.00
611CF7	2017-07-21 08:30:00+03	23200.00
611D42	2017-07-30 06:08:00+03	138100.00
611D61	2017-07-02 16:23:00+03	266400.00
611D77	2017-07-06 18:01:00+03	26800.00
611DD0	2017-07-28 15:01:00+03	27200.00
611E3A	2017-07-27 10:59:00+03	132800.00
611EB1	2017-08-11 08:23:00+03	46400.00
611F66	2017-07-20 22:59:00+03	108200.00
611F7D	2017-07-01 21:00:00+03	27600.00
611FB3	2017-07-06 06:24:00+03	177200.00
612003	2017-08-04 06:45:00+03	21800.00
612016	2017-08-12 18:34:00+03	356400.00
61205A	2017-08-14 14:15:00+03	97700.00
61206B	2017-08-06 13:43:00+03	505800.00
6120A1	2017-08-02 09:56:00+03	7800.00
612104	2017-08-11 22:08:00+03	84100.00
612124	2017-07-02 11:34:00+03	58600.00
61213D	2017-07-17 10:37:00+03	59300.00
6121FD	2017-07-04 16:40:00+03	30200.00
612214	2017-07-30 02:59:00+03	53600.00
612229	2017-08-04 10:18:00+03	3700.00
61222E	2017-08-11 13:25:00+03	199600.00
612262	2017-08-11 16:30:00+03	28000.00
6122E1	2017-07-24 22:10:00+03	123700.00
61232D	2017-07-21 00:46:00+03	137900.00
61239A	2017-07-23 06:20:00+03	23200.00
6124C0	2017-08-12 14:02:00+03	68800.00
6125AA	2017-06-30 15:33:00+03	496600.00
612606	2017-07-26 20:56:00+03	28000.00
61261C	2017-07-01 03:27:00+03	90000.00
612621	2017-07-16 16:45:00+03	22000.00
61266B	2017-07-02 06:40:00+03	14000.00
61266E	2017-07-03 11:23:00+03	97500.00
61267B	2017-07-14 01:23:00+03	61800.00
612696	2017-07-31 09:34:00+03	62700.00
6126B3	2017-07-24 02:03:00+03	153200.00
6126C8	2017-07-19 23:59:00+03	28800.00
6126DE	2017-07-06 17:24:00+03	50600.00
6126F8	2017-07-03 13:17:00+03	131600.00
61270B	2017-07-24 23:57:00+03	67000.00
612779	2017-07-18 16:22:00+03	49700.00
612793	2017-08-02 08:00:00+03	66100.00
6127A8	2017-07-31 02:28:00+03	25200.00
6127CA	2017-08-05 15:21:00+03	68800.00
6127CF	2017-08-15 00:56:00+03	23600.00
6127E6	2017-07-10 04:20:00+03	6700.00
6127F3	2017-07-08 09:42:00+03	242600.00
6127FA	2017-08-12 12:27:00+03	78800.00
612854	2017-07-08 19:27:00+03	27200.00
61286B	2017-07-10 13:01:00+03	55800.00
6128C1	2017-07-06 02:14:00+03	132800.00
61290D	2017-07-12 16:11:00+03	96300.00
6129A5	2017-07-25 18:44:00+03	23400.00
612A2E	2017-08-15 11:29:00+03	71400.00
612A5E	2017-08-02 12:02:00+03	47200.00
612AA2	2017-08-03 07:23:00+03	8200.00
612AAB	2017-08-10 19:27:00+03	64700.00
612B38	2017-07-31 15:20:00+03	69700.00
612B5F	2017-08-06 02:28:00+03	89200.00
612B77	2017-08-04 09:56:00+03	62600.00
612BA6	2017-08-14 15:38:00+03	28000.00
612BC0	2017-08-07 04:09:00+03	24200.00
612BDF	2017-08-07 21:49:00+03	73600.00
612C1C	2017-07-15 05:34:00+03	257600.00
612C44	2017-08-09 08:49:00+03	8000.00
612CB7	2017-08-11 06:53:00+03	56000.00
612CBF	2017-08-12 04:11:00+03	31600.00
612D0B	2017-07-09 20:52:00+03	8200.00
612DEB	2017-07-08 02:17:00+03	196800.00
612E28	2017-07-08 15:06:00+03	67400.00
612E59	2017-07-19 12:23:00+03	28000.00
612E99	2017-07-26 17:07:00+03	60400.00
612E9D	2017-07-17 05:45:00+03	39100.00
612EA8	2017-07-27 02:02:00+03	8000.00
612EC1	2017-07-04 17:06:00+03	21800.00
612F37	2017-07-20 14:06:00+03	36800.00
612F40	2017-08-05 11:20:00+03	86400.00
612FBE	2017-08-14 14:37:00+03	392100.00
612FE5	2017-07-21 02:12:00+03	182300.00
613017	2017-07-09 09:45:00+03	12600.00
61307D	2017-08-06 12:42:00+03	23400.00
61309B	2017-07-08 20:30:00+03	92800.00
6130E4	2017-06-29 05:41:00+03	187600.00
613190	2017-07-20 07:39:00+03	193800.00
6131D5	2017-07-18 04:11:00+03	47400.00
6131EB	2017-08-09 05:38:00+03	24000.00
61325A	2017-08-06 12:30:00+03	55800.00
61328B	2017-07-20 09:58:00+03	46300.00
6132B6	2017-08-10 03:03:00+03	101500.00
6132C1	2017-07-19 22:55:00+03	26700.00
6132C7	2017-07-21 21:32:00+03	85000.00
61331A	2017-08-14 05:10:00+03	95400.00
613340	2017-08-03 15:08:00+03	68000.00
613364	2017-07-15 09:37:00+03	67200.00
61338B	2017-08-01 09:18:00+03	23600.00
613418	2017-07-10 13:20:00+03	46300.00
61342B	2017-08-10 09:06:00+03	114400.00
613434	2017-07-05 22:56:00+03	58500.00
613463	2017-08-15 00:58:00+03	32800.00
61346C	2017-07-01 17:21:00+03	28200.00
6134A3	2017-07-18 10:20:00+03	55600.00
61352A	2017-07-31 17:33:00+03	65900.00
613540	2017-08-07 13:29:00+03	39800.00
613582	2017-07-23 00:52:00+03	12800.00
6135D4	2017-07-12 01:27:00+03	22000.00
61361B	2017-07-05 14:15:00+03	121100.00
61361E	2017-07-07 23:21:00+03	97700.00
613633	2017-08-09 14:11:00+03	50600.00
613652	2017-08-01 02:17:00+03	88900.00
61365A	2017-08-14 10:17:00+03	19600.00
61365E	2017-08-13 12:42:00+03	55800.00
613661	2017-08-04 05:44:00+03	79000.00
6136EF	2017-08-05 04:43:00+03	38600.00
613765	2017-07-09 13:10:00+03	31000.00
613786	2017-07-13 20:45:00+03	189900.00
61387D	2017-07-05 19:06:00+03	56900.00
61388D	2017-07-28 12:24:00+03	54800.00
6138B0	2017-08-08 09:25:00+03	85000.00
6138D0	2017-07-20 13:36:00+03	39500.00
613968	2017-07-20 17:54:00+03	188800.00
613A0B	2017-07-31 05:54:00+03	16800.00
613A41	2017-08-14 13:33:00+03	89200.00
613A6E	2017-07-23 17:37:00+03	31600.00
613A70	2017-07-31 03:50:00+03	50800.00
613A7F	2017-07-18 10:53:00+03	44800.00
613ADD	2017-07-05 04:11:00+03	13400.00
613B05	2017-07-22 19:51:00+03	38600.00
613B25	2017-08-09 20:26:00+03	47600.00
613B2F	2017-08-03 11:21:00+03	23600.00
613B38	2017-08-06 23:37:00+03	37900.00
613B4B	2017-08-09 21:24:00+03	93800.00
613B75	2017-07-19 14:24:00+03	24400.00
613BA3	2017-07-07 02:58:00+03	77000.00
613BB8	2017-07-29 15:08:00+03	117200.00
613C02	2017-08-03 04:29:00+03	28000.00
613C3A	2017-08-06 02:40:00+03	32700.00
613C82	2017-07-26 20:10:00+03	12600.00
613CA7	2017-07-15 02:42:00+03	58000.00
613CEA	2017-08-02 09:15:00+03	56000.00
613CF9	2017-07-28 02:23:00+03	67700.00
613D31	2017-07-10 18:58:00+03	369000.00
613DE4	2017-07-13 04:19:00+03	113100.00
613E16	2017-08-06 23:38:00+03	178900.00
613E3C	2017-08-05 00:24:00+03	13400.00
613E48	2017-07-25 09:52:00+03	25800.00
613EC3	2017-07-14 07:02:00+03	46400.00
613FA4	2017-07-03 03:41:00+03	123000.00
613FC4	2017-07-26 00:10:00+03	8200.00
61410D	2017-07-19 20:57:00+03	106400.00
61413D	2017-08-13 14:34:00+03	72700.00
614148	2017-07-10 02:58:00+03	76400.00
6141DC	2017-07-12 06:48:00+03	155000.00
614223	2017-07-28 09:56:00+03	37600.00
614225	2017-07-23 02:11:00+03	21600.00
6142AC	2017-07-18 08:16:00+03	290400.00
6142C1	2017-08-03 02:00:00+03	155300.00
6142CC	2017-06-28 15:11:00+03	31600.00
614361	2017-06-27 23:44:00+03	369000.00
614391	2017-08-07 16:41:00+03	70700.00
6143F2	2017-07-14 15:40:00+03	13600.00
614460	2017-08-05 14:17:00+03	114400.00
614482	2017-07-14 13:32:00+03	119300.00
6144AD	2017-07-28 15:28:00+03	41200.00
6144FA	2017-07-27 15:07:00+03	153300.00
6144FE	2017-07-06 18:39:00+03	236300.00
6145B0	2017-07-27 04:46:00+03	14800.00
61464E	2017-07-12 10:43:00+03	46200.00
61466F	2017-07-07 08:58:00+03	62000.00
6146C0	2017-08-05 12:19:00+03	21800.00
6146E5	2017-07-03 18:59:00+03	48800.00
6146FA	2017-07-13 03:36:00+03	70400.00
61478E	2017-07-22 11:05:00+03	124200.00
61485F	2017-07-14 07:48:00+03	59200.00
614879	2017-07-30 13:54:00+03	37700.00
61491E	2017-07-13 16:04:00+03	187600.00
614929	2017-08-09 22:33:00+03	24400.00
61492E	2017-07-13 07:40:00+03	12400.00
61494A	2017-07-25 23:55:00+03	103200.00
614953	2017-07-31 11:13:00+03	85000.00
6149C7	2017-07-14 14:34:00+03	137100.00
6149F1	2017-07-21 01:43:00+03	12100.00
614A1F	2017-07-30 16:01:00+03	202600.00
614A2A	2017-08-12 07:00:00+03	80100.00
614A8B	2017-07-16 01:31:00+03	28800.00
614ACA	2017-07-06 03:36:00+03	169600.00
614ACB	2017-07-12 18:16:00+03	181600.00
614AF0	2017-07-12 01:30:00+03	67600.00
614B8B	2017-08-02 04:24:00+03	34000.00
614B92	2017-07-21 04:17:00+03	23200.00
614BA5	2017-07-20 14:27:00+03	130400.00
614BAD	2017-07-23 00:09:00+03	60400.00
614C17	2017-07-06 07:20:00+03	41600.00
614C23	2017-07-04 21:30:00+03	68400.00
614C56	2017-08-11 19:46:00+03	36200.00
614C85	2017-07-07 06:39:00+03	62600.00
614CA6	2017-07-13 17:56:00+03	169900.00
614CD4	2017-07-27 18:25:00+03	200500.00
614CED	2017-07-19 16:58:00+03	20600.00
614CF0	2017-08-02 11:27:00+03	6700.00
614D0A	2017-07-22 17:52:00+03	28000.00
614D19	2017-08-10 02:42:00+03	13400.00
614DAE	2017-07-20 04:51:00+03	67600.00
614DD3	2017-07-18 22:49:00+03	209200.00
614DFC	2017-07-06 16:36:00+03	26000.00
614E6E	2017-08-11 08:19:00+03	100600.00
614E95	2017-08-02 03:55:00+03	28000.00
614EFF	2017-07-16 00:28:00+03	115400.00
614F1F	2017-07-05 22:35:00+03	13600.00
614F4B	2017-07-17 13:49:00+03	89600.00
614F6E	2017-08-01 17:07:00+03	26000.00
614F75	2017-08-13 02:57:00+03	19800.00
614F81	2017-07-03 04:25:00+03	54000.00
614FC9	2017-08-10 22:22:00+03	36000.00
614FEF	2017-07-18 02:16:00+03	119600.00
615042	2017-07-08 19:01:00+03	137400.00
61505D	2017-08-09 04:17:00+03	81600.00
6150A4	2017-08-06 05:43:00+03	13400.00
61516F	2017-07-08 18:00:00+03	190400.00
6151A8	2017-07-15 22:29:00+03	47000.00
61520C	2017-08-09 02:07:00+03	99700.00
61523E	2017-07-16 16:05:00+03	42000.00
615265	2017-07-18 18:41:00+03	175800.00
61527E	2017-07-08 17:58:00+03	46400.00
6152DA	2017-07-08 17:29:00+03	8200.00
6152DD	2017-07-04 11:12:00+03	6000.00
615323	2017-07-23 07:26:00+03	142400.00
61532B	2017-07-24 01:33:00+03	31600.00
615341	2017-08-05 00:23:00+03	89300.00
61534E	2017-07-20 04:17:00+03	116500.00
6153CE	2017-08-01 12:21:00+03	23600.00
615438	2017-07-16 05:02:00+03	7600.00
615459	2017-08-14 13:48:00+03	61800.00
615468	2017-07-19 16:10:00+03	40800.00
6154A6	2017-08-06 11:44:00+03	12200.00
6154B8	2017-08-08 08:23:00+03	78400.00
6154CD	2017-08-03 18:16:00+03	192700.00
6154E1	2017-08-09 17:33:00+03	55800.00
615532	2017-07-30 18:44:00+03	55800.00
6155BC	2017-07-12 17:51:00+03	19600.00
6155CF	2017-08-09 20:53:00+03	67400.00
61561F	2017-08-10 10:20:00+03	193700.00
615642	2017-07-16 04:40:00+03	46000.00
615677	2017-08-12 16:04:00+03	15000.00
615696	2017-07-15 07:32:00+03	46300.00
6156A0	2017-07-29 02:17:00+03	15100.00
6157D1	2017-07-29 01:15:00+03	28000.00
615801	2017-07-07 04:11:00+03	25100.00
61588E	2017-07-11 02:12:00+03	70700.00
6158A9	2017-07-21 08:53:00+03	12600.00
6158B4	2017-07-14 23:44:00+03	60200.00
6158C1	2017-08-07 18:30:00+03	49600.00
6158FD	2017-08-02 21:41:00+03	16400.00
6159AF	2017-08-15 01:54:00+03	386300.00
615A47	2017-07-28 18:11:00+03	21400.00
615A51	2017-08-10 17:45:00+03	125200.00
615A6D	2017-07-30 00:46:00+03	133100.00
615B4B	2017-08-05 01:28:00+03	41800.00
615B6F	2017-07-09 02:34:00+03	14400.00
615BD8	2017-08-12 07:19:00+03	138000.00
615BE1	2017-07-27 02:22:00+03	116600.00
615C2B	2017-07-26 20:22:00+03	23200.00
615C75	2017-08-11 15:32:00+03	57300.00
615D09	2017-07-24 20:24:00+03	215500.00
615D31	2017-07-10 08:23:00+03	26000.00
615D82	2017-08-12 17:35:00+03	153200.00
615DC9	2017-08-12 04:49:00+03	57500.00
615DCA	2017-07-27 10:40:00+03	417000.00
615DEA	2017-07-10 17:39:00+03	14400.00
615E07	2017-07-28 21:54:00+03	30200.00
615E2B	2017-08-06 05:14:00+03	38400.00
615E9C	2017-07-31 16:21:00+03	56600.00
615F57	2017-07-19 07:02:00+03	117200.00
615F5C	2017-07-17 03:34:00+03	69600.00
615F60	2017-07-31 11:02:00+03	21400.00
615F66	2017-07-03 13:54:00+03	53700.00
615F6B	2017-08-10 22:51:00+03	31900.00
615F97	2017-07-15 00:01:00+03	119500.00
615FF1	2017-07-29 00:31:00+03	21200.00
615FF7	2017-08-09 07:22:00+03	46400.00
61600C	2017-07-06 12:30:00+03	148200.00
61601D	2017-07-14 08:11:00+03	44000.00
616042	2017-07-29 05:10:00+03	56600.00
61605A	2017-07-12 06:14:00+03	615000.00
61608A	2017-07-18 10:05:00+03	56900.00
6160C3	2017-07-06 15:53:00+03	110500.00
6160F0	2017-08-11 06:13:00+03	36200.00
6160F4	2017-07-30 20:23:00+03	269500.00
6160FC	2017-08-06 03:56:00+03	20600.00
61614F	2017-08-11 12:31:00+03	28000.00
616158	2017-07-25 19:20:00+03	173400.00
61617B	2017-07-08 09:00:00+03	58600.00
616180	2017-08-04 18:00:00+03	23200.00
616186	2017-07-25 19:51:00+03	82900.00
6161BB	2017-07-09 21:06:00+03	169300.00
6161E6	2017-07-31 02:31:00+03	308700.00
61623C	2017-07-28 06:08:00+03	195100.00
616250	2017-07-13 00:00:00+03	58200.00
61627D	2017-08-03 02:03:00+03	29600.00
6162A7	2017-07-08 15:02:00+03	57800.00
6162FB	2017-07-17 19:42:00+03	39200.00
616389	2017-08-07 03:54:00+03	49800.00
6163D8	2017-08-10 13:21:00+03	69500.00
616417	2017-08-11 09:46:00+03	92700.00
61641A	2017-08-13 23:14:00+03	92900.00
61646E	2017-07-21 03:29:00+03	131600.00
616477	2017-08-01 10:42:00+03	62900.00
61649A	2017-08-11 21:03:00+03	170000.00
61649D	2017-07-30 06:58:00+03	84500.00
6164E0	2017-07-03 00:35:00+03	56000.00
616522	2017-07-16 17:41:00+03	36200.00
616533	2017-08-07 02:23:00+03	7300.00
616573	2017-07-22 22:10:00+03	47000.00
6165F9	2017-07-08 15:09:00+03	48400.00
616626	2017-08-01 06:45:00+03	73500.00
616636	2017-07-15 04:53:00+03	93900.00
616676	2017-07-22 07:07:00+03	196800.00
6166CF	2017-07-12 00:36:00+03	131600.00
6166F0	2017-08-15 07:36:00+03	117900.00
61676E	2017-07-26 07:39:00+03	103500.00
616789	2017-08-07 00:46:00+03	28000.00
616796	2017-07-23 14:09:00+03	8200.00
6167D2	2017-08-12 22:50:00+03	76600.00
6167D3	2017-08-13 20:22:00+03	23200.00
6167DB	2017-08-13 16:42:00+03	520600.00
6167F9	2017-08-13 06:25:00+03	44300.00
616866	2017-07-24 01:30:00+03	24300.00
6168A1	2017-08-01 13:53:00+03	40800.00
6168D3	2017-07-12 09:19:00+03	24400.00
6168D9	2017-07-14 11:57:00+03	105200.00
6168DE	2017-07-12 05:53:00+03	35200.00
6169C9	2017-07-23 04:26:00+03	6000.00
616A24	2017-07-04 19:07:00+03	92800.00
616A2C	2017-08-13 00:59:00+03	65600.00
616A41	2017-07-24 22:38:00+03	28800.00
616A4E	2017-07-13 03:12:00+03	479000.00
616B05	2017-08-11 10:06:00+03	83700.00
616B3B	2017-07-15 23:21:00+03	102100.00
616B50	2017-07-29 08:01:00+03	59000.00
616BC8	2017-07-13 20:54:00+03	39300.00
616C40	2017-07-14 20:26:00+03	62600.00
616C6A	2017-07-26 04:01:00+03	16400.00
616CBA	2017-08-05 19:50:00+03	33100.00
616D43	2017-08-01 12:19:00+03	21800.00
616D65	2017-08-09 05:58:00+03	132800.00
616D72	2017-08-14 03:43:00+03	123000.00
616E5D	2017-07-26 12:22:00+03	8000.00
616E6E	2017-07-17 16:31:00+03	56000.00
616F31	2017-08-09 00:06:00+03	106200.00
616F54	2017-07-03 22:48:00+03	49800.00
616F7C	2017-08-14 08:04:00+03	99200.00
616FD8	2017-07-20 14:40:00+03	50700.00
616FEA	2017-07-26 23:44:00+03	67600.00
61700E	2017-07-30 06:06:00+03	173500.00
61704B	2017-08-15 17:42:00+03	155600.00
617091	2017-08-11 09:59:00+03	149300.00
6170B4	2017-07-21 18:03:00+03	131100.00
617130	2017-07-20 16:01:00+03	73400.00
617151	2017-08-12 07:18:00+03	62400.00
617160	2017-07-31 00:30:00+03	16400.00
617177	2017-07-10 01:19:00+03	66600.00
617287	2017-07-05 04:15:00+03	6600.00
6172A8	2017-08-15 14:14:00+03	62700.00
617350	2017-07-30 10:46:00+03	24400.00
61736F	2017-07-20 13:31:00+03	6700.00
617372	2017-06-29 18:16:00+03	94000.00
617408	2017-08-14 18:48:00+03	266400.00
61740C	2017-07-07 19:03:00+03	44600.00
617414	2017-08-04 02:33:00+03	89600.00
61742C	2017-08-02 21:59:00+03	71200.00
61744C	2017-06-30 06:45:00+03	19600.00
61745A	2017-07-19 14:27:00+03	70800.00
617499	2017-06-30 04:52:00+03	81300.00
6174AD	2017-08-07 20:53:00+03	13200.00
6174C2	2017-07-17 06:49:00+03	135400.00
6174DF	2017-08-15 11:07:00+03	38800.00
617505	2017-07-07 13:22:00+03	79300.00
617543	2017-08-05 12:01:00+03	396500.00
61758A	2017-08-08 14:59:00+03	67600.00
6175E1	2017-08-02 17:56:00+03	117200.00
61762A	2017-07-15 00:06:00+03	40800.00
61768F	2017-07-24 10:40:00+03	58400.00
6176C7	2017-08-15 04:45:00+03	24000.00
617716	2017-07-26 01:04:00+03	272400.00
61777D	2017-08-12 07:36:00+03	26400.00
617781	2017-08-04 21:25:00+03	54600.00
617792	2017-08-09 14:32:00+03	38200.00
6177DC	2017-08-05 23:56:00+03	53400.00
617809	2017-07-29 04:13:00+03	63200.00
6178D9	2017-07-06 08:37:00+03	73200.00
617930	2017-07-08 04:18:00+03	129700.00
617946	2017-08-09 08:07:00+03	203600.00
61794A	2017-07-16 13:26:00+03	94800.00
6179A1	2017-08-07 22:30:00+03	38500.00
6179DA	2017-07-25 10:31:00+03	664500.00
617A05	2017-07-21 21:29:00+03	35600.00
617B1B	2017-08-08 13:20:00+03	56300.00
617B36	2017-07-20 09:13:00+03	28300.00
617C15	2017-07-30 13:51:00+03	46500.00
617C39	2017-07-19 22:20:00+03	123000.00
617CA1	2017-07-11 01:01:00+03	13200.00
617D68	2017-07-09 18:20:00+03	75600.00
617D78	2017-08-12 13:03:00+03	157700.00
617DF5	2017-08-12 21:01:00+03	20400.00
617E81	2017-08-02 15:27:00+03	376700.00
617EBF	2017-07-04 03:34:00+03	26600.00
617F24	2017-08-08 01:29:00+03	36200.00
617F77	2017-08-12 01:57:00+03	37900.00
617F95	2017-07-26 12:18:00+03	29300.00
617FAE	2017-07-16 08:22:00+03	99200.00
617FE7	2017-07-10 04:43:00+03	73300.00
61806D	2017-07-26 17:08:00+03	71300.00
6180B3	2017-08-02 17:26:00+03	40400.00
618143	2017-07-11 17:02:00+03	8000.00
61815F	2017-08-15 02:50:00+03	25800.00
61818A	2017-08-14 08:38:00+03	55800.00
618199	2017-08-04 22:21:00+03	25400.00
61819C	2017-07-06 12:23:00+03	144400.00
6181AC	2017-08-02 11:15:00+03	22600.00
618233	2017-07-14 19:11:00+03	180800.00
61827D	2017-07-30 04:29:00+03	20400.00
618296	2017-07-15 05:41:00+03	168000.00
6182C6	2017-08-02 11:13:00+03	23200.00
6182D9	2017-07-23 14:05:00+03	16000.00
6182DE	2017-07-15 14:50:00+03	20400.00
6182F6	2017-07-20 03:21:00+03	286500.00
61838D	2017-07-18 08:45:00+03	39600.00
6183AE	2017-07-20 07:55:00+03	72200.00
61842D	2017-07-13 15:46:00+03	89500.00
618452	2017-08-12 11:11:00+03	14400.00
618466	2017-07-23 17:34:00+03	95600.00
61849B	2017-07-05 02:40:00+03	60400.00
6184B9	2017-07-12 09:04:00+03	56000.00
6184F5	2017-07-22 07:54:00+03	46000.00
61850C	2017-08-13 04:21:00+03	93900.00
61851B	2017-08-12 12:31:00+03	136600.00
61860D	2017-07-30 02:41:00+03	66600.00
618695	2017-08-10 19:52:00+03	44700.00
618696	2017-07-14 07:19:00+03	399600.00
6186A3	2017-07-30 08:32:00+03	97200.00
61870A	2017-07-28 22:02:00+03	95600.00
618734	2017-07-04 15:22:00+03	99200.00
6187E3	2017-07-03 22:42:00+03	72300.00
61881E	2017-07-05 10:57:00+03	13400.00
6188C1	2017-08-10 13:45:00+03	43900.00
618926	2017-08-14 01:18:00+03	136200.00
6189BC	2017-07-04 14:59:00+03	129200.00
618A32	2017-07-22 14:21:00+03	130400.00
618A81	2017-07-24 06:31:00+03	23400.00
618A87	2017-07-01 12:31:00+03	70600.00
618AA0	2017-07-10 09:11:00+03	66600.00
618B42	2017-07-23 07:59:00+03	373800.00
618B59	2017-07-20 21:12:00+03	109600.00
618B72	2017-07-27 09:07:00+03	101200.00
618C28	2017-07-28 03:40:00+03	222400.00
618C90	2017-08-07 21:18:00+03	59800.00
618CC7	2017-08-01 14:09:00+03	181600.00
618D53	2017-07-04 20:46:00+03	31100.00
618D7A	2017-07-05 03:22:00+03	160700.00
618D90	2017-07-13 17:57:00+03	65900.00
618DC6	2017-07-14 04:39:00+03	114400.00
618E3D	2017-07-28 04:19:00+03	68000.00
618E41	2017-07-12 09:18:00+03	53500.00
618E6F	2017-08-01 04:43:00+03	193200.00
618E78	2017-07-18 01:01:00+03	75300.00
618EC3	2017-07-06 22:26:00+03	185700.00
618ECE	2017-08-08 08:24:00+03	31600.00
618EEA	2017-07-22 01:29:00+03	20400.00
618F66	2017-07-17 21:36:00+03	92800.00
618FA6	2017-07-21 22:03:00+03	16400.00
618FC0	2017-07-26 18:17:00+03	46000.00
618FCB	2017-06-30 04:27:00+03	138000.00
61900F	2017-07-27 15:04:00+03	39300.00
6190A8	2017-08-12 01:03:00+03	8000.00
6190B2	2017-07-23 15:52:00+03	56000.00
6190B6	2017-07-01 06:00:00+03	27200.00
6190DF	2017-07-01 06:58:00+03	117600.00
6190E4	2017-08-15 17:21:00+03	217300.00
6190F2	2017-07-31 04:28:00+03	54400.00
619116	2017-07-15 15:34:00+03	85000.00
61915D	2017-07-17 15:16:00+03	88900.00
61917E	2017-08-06 08:41:00+03	10700.00
6191F3	2017-07-27 23:56:00+03	56000.00
6191F5	2017-07-30 08:33:00+03	29600.00
619258	2017-07-10 12:00:00+03	28700.00
619262	2017-07-31 10:19:00+03	123000.00
6192AA	2017-07-09 23:19:00+03	32400.00
6192B2	2017-07-23 04:24:00+03	100600.00
6192ED	2017-07-31 01:19:00+03	299600.00
619313	2017-07-21 04:08:00+03	120800.00
619318	2017-07-05 22:47:00+03	23600.00
619321	2017-07-10 05:30:00+03	36800.00
619365	2017-07-20 16:59:00+03	64800.00
6193AC	2017-07-17 08:05:00+03	34000.00
6193AD	2017-07-31 05:34:00+03	24400.00
6193C1	2017-07-30 12:31:00+03	80500.00
619421	2017-07-15 14:09:00+03	111600.00
619428	2017-07-22 17:42:00+03	123000.00
61942A	2017-07-11 11:02:00+03	70700.00
6194B6	2017-07-22 02:16:00+03	25400.00
6194E9	2017-08-14 15:51:00+03	21700.00
61952A	2017-08-07 05:49:00+03	25100.00
619531	2017-08-15 03:44:00+03	66000.00
6195AD	2017-07-28 17:15:00+03	155600.00
6195F3	2017-07-16 18:14:00+03	32800.00
619607	2017-07-10 05:41:00+03	8200.00
61961C	2017-08-02 18:17:00+03	90300.00
619687	2017-07-08 07:13:00+03	48000.00
6196E6	2017-07-22 17:49:00+03	254900.00
6196F8	2017-07-24 16:04:00+03	18800.00
619715	2017-08-08 07:41:00+03	46000.00
61972E	2017-08-05 04:57:00+03	46400.00
6197A1	2017-08-09 06:02:00+03	16400.00
6197A6	2017-07-24 11:54:00+03	69200.00
619807	2017-07-21 21:37:00+03	31600.00
61987B	2017-06-29 22:08:00+03	47400.00
619896	2017-07-08 10:57:00+03	61900.00
6198A3	2017-08-01 09:02:00+03	201200.00
6198D8	2017-07-19 21:38:00+03	102000.00
6198DF	2017-07-24 14:54:00+03	332200.00
619912	2017-08-08 15:09:00+03	16400.00
6199CC	2017-07-14 16:26:00+03	61800.00
6199CD	2017-07-09 09:41:00+03	220700.00
6199E9	2017-07-02 10:43:00+03	38800.00
6199F9	2017-07-06 18:06:00+03	26000.00
619A93	2017-08-01 19:30:00+03	213200.00
619AC2	2017-08-10 07:46:00+03	272500.00
619AD2	2017-07-29 12:10:00+03	29600.00
619B0D	2017-06-30 09:24:00+03	123000.00
619B21	2017-08-15 10:04:00+03	87900.00
619B3F	2017-07-14 20:18:00+03	176800.00
619B40	2017-07-25 13:03:00+03	6000.00
619B41	2017-08-10 01:33:00+03	28200.00
619C23	2017-08-01 15:48:00+03	53300.00
619C3F	2017-08-07 20:37:00+03	32700.00
619CE9	2017-07-05 11:53:00+03	39300.00
619D0F	2017-08-10 14:38:00+03	386400.00
619D40	2017-07-10 00:50:00+03	28300.00
619D4A	2017-07-17 20:35:00+03	95200.00
619D6B	2017-07-14 14:24:00+03	77500.00
619D78	2017-07-11 07:09:00+03	77200.00
619D9E	2017-08-08 18:45:00+03	24500.00
619DA1	2017-07-19 11:19:00+03	50000.00
619DB8	2017-07-18 01:17:00+03	58600.00
619E5C	2017-08-11 04:09:00+03	134400.00
619E72	2017-07-08 08:15:00+03	28800.00
619FEA	2017-08-11 01:08:00+03	18600.00
61A017	2017-07-27 19:58:00+03	46400.00
61A01D	2017-07-31 13:17:00+03	40800.00
61A01F	2017-07-28 15:20:00+03	133200.00
61A033	2017-08-13 15:15:00+03	157900.00
61A038	2017-07-18 01:09:00+03	7400.00
61A07E	2017-07-07 01:35:00+03	81800.00
61A129	2017-07-27 13:55:00+03	75300.00
61A18E	2017-07-18 14:09:00+03	24800.00
61A19F	2017-08-03 15:43:00+03	65000.00
61A1EA	2017-07-29 15:42:00+03	13400.00
61A273	2017-08-10 04:23:00+03	41600.00
61A2FC	2017-08-14 02:48:00+03	36200.00
61A318	2017-07-01 10:12:00+03	124200.00
61A34D	2017-07-20 11:59:00+03	64200.00
61A358	2017-08-04 14:56:00+03	92700.00
61A393	2017-07-13 19:29:00+03	45500.00
61A39A	2017-07-08 05:28:00+03	246000.00
61A3A9	2017-08-13 22:53:00+03	83200.00
61A3FB	2017-08-15 08:29:00+03	13400.00
61A417	2017-07-30 03:18:00+03	9200.00
61A487	2017-07-31 14:58:00+03	75300.00
61A495	2017-07-23 20:17:00+03	7400.00
61A4BB	2017-07-09 23:16:00+03	62700.00
61A503	2017-08-15 06:47:00+03	34000.00
61A5BE	2017-08-04 18:37:00+03	81700.00
61A5F2	2017-07-29 07:29:00+03	58400.00
61A683	2017-08-07 23:20:00+03	292200.00
61A689	2017-07-22 20:02:00+03	50700.00
61A6C4	2017-07-30 18:34:00+03	26200.00
61A6CC	2017-07-23 01:54:00+03	13400.00
61A6E6	2017-07-14 11:54:00+03	12600.00
61A734	2017-08-10 13:56:00+03	66600.00
61A852	2017-07-01 15:23:00+03	42700.00
61A867	2017-07-25 13:44:00+03	73100.00
61A923	2017-06-30 00:07:00+03	111600.00
61AA81	2017-08-06 00:46:00+03	92700.00
61AAC1	2017-07-29 18:24:00+03	75300.00
61AB23	2017-08-02 15:47:00+03	35800.00
61ABF2	2017-08-02 21:26:00+03	130400.00
61AC57	2017-07-19 21:04:00+03	147700.00
61ACAF	2017-07-07 11:28:00+03	155600.00
61ACB0	2017-07-25 15:40:00+03	43800.00
61ACBC	2017-07-11 01:47:00+03	49600.00
61ACEB	2017-07-30 15:34:00+03	28000.00
61AD36	2017-08-15 11:22:00+03	131600.00
61AD4A	2017-07-02 13:31:00+03	33300.00
61AD6A	2017-07-08 15:44:00+03	167400.00
61ADA0	2017-07-13 21:20:00+03	92800.00
61ADD4	2017-06-29 15:34:00+03	24400.00
61ADFC	2017-08-14 05:07:00+03	89600.00
61AEBC	2017-07-08 06:41:00+03	117100.00
61AF1B	2017-08-06 11:39:00+03	109200.00
61AF3A	2017-07-18 13:27:00+03	119700.00
61AF9A	2017-07-25 08:15:00+03	31600.00
61B026	2017-07-20 15:00:00+03	47200.00
61B093	2017-08-07 01:51:00+03	210000.00
61B09D	2017-07-26 22:53:00+03	39200.00
61B0DD	2017-07-16 17:03:00+03	67200.00
61B118	2017-07-16 18:35:00+03	101200.00
61B146	2017-07-24 14:25:00+03	19800.00
61B157	2017-08-15 08:28:00+03	49500.00
61B1A3	2017-07-24 14:26:00+03	106100.00
61B1B3	2017-07-03 22:42:00+03	123000.00
61B1D4	2017-08-03 20:07:00+03	49800.00
61B27E	2017-08-02 17:44:00+03	26200.00
61B290	2017-07-31 08:26:00+03	265600.00
61B2A0	2017-07-27 05:47:00+03	48500.00
61B2C7	2017-07-15 03:36:00+03	177900.00
61B316	2017-07-28 23:35:00+03	48400.00
61B3BB	2017-08-03 02:18:00+03	24400.00
61B3E6	2017-08-03 19:20:00+03	6000.00
61B406	2017-07-07 08:10:00+03	15800.00
61B41E	2017-08-02 21:03:00+03	131600.00
61B428	2017-07-28 01:11:00+03	50400.00
61B43A	2017-08-03 02:52:00+03	42700.00
61B469	2017-07-20 20:19:00+03	30700.00
61B49D	2017-08-03 17:17:00+03	23200.00
61B4B5	2017-08-11 13:47:00+03	12600.00
61B4D2	2017-07-04 03:11:00+03	21400.00
61B4F5	2017-07-10 01:17:00+03	32200.00
61B590	2017-07-31 03:55:00+03	201200.00
61B644	2017-08-11 06:29:00+03	49800.00
61B67B	2017-08-04 10:11:00+03	123000.00
61B704	2017-07-29 12:45:00+03	48800.00
61B711	2017-07-14 11:17:00+03	8400.00
61B76F	2017-07-28 01:13:00+03	28000.00
61B78F	2017-07-15 22:54:00+03	9800.00
61B7F6	2017-07-29 07:12:00+03	58600.00
61B800	2017-07-13 00:27:00+03	109300.00
61B877	2017-07-19 01:46:00+03	78800.00
61B8B5	2017-08-12 11:58:00+03	62100.00
61B8CA	2017-07-12 23:23:00+03	18800.00
61B8D0	2017-07-19 05:41:00+03	56900.00
61B8D1	2017-07-06 17:02:00+03	28000.00
61B8D7	2017-08-07 12:29:00+03	37900.00
61B8FA	2017-08-01 00:19:00+03	61800.00
61B942	2017-07-18 15:07:00+03	8000.00
61B966	2017-07-07 09:54:00+03	23100.00
61B9B7	2017-07-19 03:22:00+03	22400.00
61BA37	2017-07-28 11:13:00+03	86600.00
61BA78	2017-07-16 14:24:00+03	46300.00
61BA96	2017-07-31 01:17:00+03	13600.00
61BAFD	2017-08-12 12:41:00+03	40000.00
61BB0D	2017-07-15 14:31:00+03	27000.00
61BB26	2017-07-05 12:00:00+03	19600.00
61BB3D	2017-07-19 06:21:00+03	55800.00
61BB95	2017-07-28 16:01:00+03	133100.00
61BBCF	2017-07-20 18:43:00+03	28800.00
61BBDD	2017-08-04 23:05:00+03	59800.00
61BBE6	2017-07-23 09:42:00+03	31800.00
61BC24	2017-07-10 18:44:00+03	47800.00
61BC56	2017-07-06 12:26:00+03	50700.00
61BCA9	2017-08-15 15:54:00+03	31600.00
61BCE0	2017-07-18 18:09:00+03	79200.00
61BCEF	2017-07-10 19:31:00+03	48800.00
61BCF3	2017-07-06 20:54:00+03	531300.00
61BDE4	2017-07-04 22:27:00+03	73100.00
61BE76	2017-08-09 05:48:00+03	155600.00
61BE92	2017-07-27 10:58:00+03	61800.00
61BE98	2017-08-12 03:22:00+03	93800.00
61BEA2	2017-08-09 20:17:00+03	79600.00
61BF9C	2017-08-12 19:04:00+03	61900.00
61BFB3	2017-08-02 18:01:00+03	22000.00
61BFE5	2017-07-23 05:24:00+03	41800.00
61C014	2017-07-08 03:08:00+03	74900.00
61C033	2017-07-07 04:15:00+03	72400.00
61C04F	2017-07-02 00:22:00+03	67200.00
61C075	2017-07-11 23:36:00+03	65900.00
61C094	2017-07-06 14:46:00+03	246000.00
61C102	2017-08-05 05:26:00+03	16400.00
61C147	2017-08-04 03:30:00+03	14400.00
61C17E	2017-08-02 20:05:00+03	532800.00
61C197	2017-07-02 03:57:00+03	98300.00
61C28A	2017-08-07 09:45:00+03	182200.00
61C2DE	2017-08-08 00:20:00+03	32600.00
61C2E0	2017-07-04 01:11:00+03	43600.00
61C315	2017-07-09 00:37:00+03	29400.00
61C32C	2017-07-29 06:09:00+03	168000.00
61C334	2017-07-19 07:02:00+03	260300.00
61C336	2017-07-20 19:06:00+03	14000.00
61C337	2017-08-07 16:15:00+03	94000.00
61C3A1	2017-07-21 17:33:00+03	32800.00
61C3A9	2017-07-30 06:58:00+03	44600.00
61C3BF	2017-08-02 00:17:00+03	23400.00
61C3E5	2017-07-09 01:20:00+03	69500.00
61C445	2017-07-23 03:21:00+03	29600.00
61C4B8	2017-07-16 05:18:00+03	11600.00
61C55D	2017-07-17 01:41:00+03	31900.00
61C57C	2017-08-14 08:00:00+03	37900.00
61C5CC	2017-08-04 18:56:00+03	65900.00
61C609	2017-08-15 09:20:00+03	32700.00
61C71F	2017-07-16 00:34:00+03	21400.00
61C73A	2017-07-14 20:36:00+03	40800.00
61C782	2017-07-30 09:57:00+03	237900.00
61C7CD	2017-07-03 05:20:00+03	39300.00
61C7F6	2017-07-07 18:00:00+03	47600.00
61C7FD	2017-07-15 05:48:00+03	41600.00
61C80D	2017-07-29 10:19:00+03	96200.00
61C822	2017-07-17 16:50:00+03	116000.00
61C82C	2017-07-25 01:42:00+03	20400.00
61C838	2017-08-12 21:15:00+03	8200.00
61C840	2017-07-30 18:24:00+03	187600.00
61C845	2017-07-08 10:49:00+03	142400.00
61C85C	2017-07-29 05:26:00+03	54800.00
61C884	2017-07-28 04:38:00+03	89200.00
61C89D	2017-07-04 10:06:00+03	89400.00
61C8FD	2017-06-27 11:47:00+03	37000.00
61C911	2017-07-29 03:54:00+03	23200.00
61C933	2017-07-20 05:08:00+03	258700.00
61C940	2017-07-10 22:14:00+03	123000.00
61C998	2017-06-29 03:12:00+03	94200.00
61C9B7	2017-07-16 09:05:00+03	84500.00
61CA03	2017-08-11 18:07:00+03	270700.00
61CA3F	2017-08-09 09:27:00+03	123600.00
61CA7B	2017-07-01 02:56:00+03	25100.00
61CAFC	2017-08-08 15:23:00+03	88800.00
61CBA3	2017-07-19 01:46:00+03	25400.00
61CBF3	2017-07-22 06:57:00+03	24200.00
61CC66	2017-07-15 07:22:00+03	119600.00
61CC81	2017-08-14 09:48:00+03	63000.00
61CC96	2017-07-22 18:43:00+03	28000.00
61CCB5	2017-07-14 07:17:00+03	10600.00
61CCFA	2017-07-13 07:16:00+03	32700.00
61CD0B	2017-07-25 20:46:00+03	29600.00
61CD27	2017-07-22 19:03:00+03	34000.00
61CD81	2017-07-10 22:34:00+03	53200.00
61CD9F	2017-07-26 16:04:00+03	47700.00
61CDA9	2017-08-02 14:59:00+03	19800.00
61CDAC	2017-07-28 14:36:00+03	51300.00
61CE68	2017-07-29 20:34:00+03	24400.00
61CE79	2017-08-07 08:49:00+03	24400.00
61CED1	2017-08-07 13:54:00+03	135200.00
61CEEA	2017-07-15 06:23:00+03	199700.00
61CF16	2017-07-31 11:05:00+03	65900.00
61CF48	2017-07-11 13:43:00+03	46300.00
61CF88	2017-08-02 22:35:00+03	56000.00
61CF8E	2017-07-29 05:05:00+03	32800.00
61D010	2017-07-17 03:15:00+03	40400.00
61D081	2017-07-21 07:54:00+03	70600.00
61D0A6	2017-07-20 10:02:00+03	26000.00
61D0EA	2017-07-19 23:20:00+03	24200.00
61D100	2017-08-01 11:05:00+03	14000.00
61D102	2017-08-03 19:28:00+03	26000.00
61D122	2017-08-10 07:14:00+03	10600.00
61D124	2017-07-24 14:11:00+03	24400.00
61D12D	2017-07-29 11:30:00+03	39300.00
61D174	2017-07-21 16:53:00+03	348800.00
61D240	2017-08-12 22:10:00+03	37900.00
61D30C	2017-07-03 07:56:00+03	44000.00
61D35E	2017-07-15 16:31:00+03	78500.00
61D388	2017-08-07 12:52:00+03	94900.00
61D3C1	2017-08-10 08:43:00+03	115400.00
61D3E6	2017-08-08 10:48:00+03	10800.00
61D47A	2017-07-09 11:13:00+03	7400.00
61D4CF	2017-08-05 18:55:00+03	58200.00
61D542	2017-07-26 05:53:00+03	117000.00
61D59E	2017-07-09 21:32:00+03	30400.00
61D5F4	2017-08-11 17:18:00+03	56700.00
61D633	2017-08-15 09:33:00+03	45200.00
61D676	2017-08-11 04:53:00+03	32700.00
61D6AB	2017-07-23 03:01:00+03	9200.00
61D6AF	2017-07-17 16:23:00+03	28800.00
61D713	2017-08-02 00:16:00+03	123000.00
61D71B	2017-08-13 18:45:00+03	113700.00
61D737	2017-07-08 01:45:00+03	58600.00
61D73E	2017-07-14 16:50:00+03	112000.00
61D7A2	2017-08-03 02:16:00+03	52000.00
61D7F8	2017-07-16 21:59:00+03	88100.00
61D8A4	2017-07-21 00:25:00+03	36400.00
61D8A6	2017-07-04 02:33:00+03	40000.00
61D904	2017-07-29 19:58:00+03	142300.00
61D920	2017-07-06 07:39:00+03	48800.00
61D93B	2017-07-17 00:30:00+03	119600.00
61D96C	2017-07-29 06:25:00+03	28000.00
61D9AD	2017-07-24 17:54:00+03	142400.00
61D9EA	2017-07-14 07:04:00+03	37900.00
61DA70	2017-07-24 06:48:00+03	87200.00
61DA77	2017-08-10 12:03:00+03	381400.00
61DAB4	2017-07-13 06:54:00+03	6700.00
61DB09	2017-07-14 03:21:00+03	46000.00
61DB55	2017-07-27 07:06:00+03	27400.00
61DB70	2017-07-31 17:04:00+03	13400.00
61DB8A	2017-08-08 23:58:00+03	85700.00
61DB97	2017-08-02 09:22:00+03	84000.00
61DC04	2017-07-08 06:48:00+03	43200.00
61DC0B	2017-08-07 02:42:00+03	39600.00
61DC29	2017-07-22 10:37:00+03	38800.00
61DC54	2017-07-22 07:40:00+03	86300.00
61DC5D	2017-07-11 05:45:00+03	66600.00
61DC86	2017-07-13 03:35:00+03	62800.00
61DE38	2017-07-22 23:29:00+03	179300.00
61DE50	2017-07-05 21:34:00+03	79800.00
61DE5A	2017-07-20 18:14:00+03	57600.00
61DE82	2017-07-24 11:42:00+03	92800.00
61DE92	2017-08-12 06:08:00+03	128800.00
61DEA1	2017-07-25 12:29:00+03	29800.00
61DEB0	2017-07-12 13:54:00+03	67700.00
61DEC3	2017-07-01 21:30:00+03	100600.00
61DF12	2017-07-17 05:09:00+03	28600.00
61DF3A	2017-07-19 17:25:00+03	196400.00
61DFD9	2017-07-08 08:22:00+03	149900.00
61E041	2017-07-03 06:14:00+03	24700.00
61E054	2017-07-30 12:08:00+03	87200.00
61E12D	2017-07-09 05:25:00+03	57400.00
61E1CC	2017-08-03 08:40:00+03	28800.00
61E1E8	2017-07-14 23:59:00+03	62700.00
61E24E	2017-07-07 13:04:00+03	50800.00
61E287	2017-07-04 23:19:00+03	56000.00
61E2A2	2017-08-08 17:50:00+03	84100.00
61E2B5	2017-07-28 00:17:00+03	30900.00
61E2F4	2017-07-15 07:52:00+03	46500.00
61E315	2017-08-07 04:15:00+03	61800.00
61E328	2017-07-04 05:48:00+03	28000.00
61E3F1	2017-07-14 10:14:00+03	67600.00
61E43E	2017-07-08 00:57:00+03	179400.00
61E488	2017-07-14 21:44:00+03	123000.00
61E4B4	2017-07-25 19:15:00+03	18600.00
61E4FB	2017-08-08 20:49:00+03	210000.00
61E523	2017-07-30 06:57:00+03	111600.00
61E585	2017-08-09 01:24:00+03	67600.00
61E596	2017-08-02 22:34:00+03	95700.00
61E5B1	2017-08-14 09:02:00+03	27300.00
61E5C9	2017-08-10 20:24:00+03	35900.00
61E5F4	2017-08-04 01:32:00+03	30800.00
61E67E	2017-07-14 01:03:00+03	32800.00
61E6AB	2017-07-29 08:12:00+03	56000.00
61E6D5	2017-07-23 05:21:00+03	20200.00
61E728	2017-08-11 12:57:00+03	64300.00
61E7A0	2017-07-22 16:11:00+03	123000.00
61E7BD	2017-07-17 08:07:00+03	80300.00
61E7C3	2017-08-06 21:01:00+03	32400.00
61E821	2017-08-02 03:32:00+03	36200.00
61E8B5	2017-07-27 20:47:00+03	93900.00
61E928	2017-08-11 19:18:00+03	6000.00
61E932	2017-07-15 11:14:00+03	39600.00
61E968	2017-07-27 23:29:00+03	57500.00
61E993	2017-07-07 15:28:00+03	17800.00
61EA09	2017-08-04 12:42:00+03	72200.00
61EAA7	2017-07-11 09:34:00+03	49800.00
61EAC7	2017-06-21 14:05:00+03	52000.00
61EAF0	2017-08-05 01:31:00+03	32800.00
61EBA8	2017-07-27 23:52:00+03	36200.00
61EBDE	2017-07-14 12:13:00+03	26700.00
61EBFC	2017-08-14 13:34:00+03	27200.00
61EC07	2017-07-29 19:07:00+03	20400.00
61EC1E	2017-07-12 23:07:00+03	30200.00
61EC99	2017-08-06 17:01:00+03	41200.00
61ED10	2017-07-17 04:43:00+03	40800.00
61ED3F	2017-07-27 02:41:00+03	73200.00
61ED65	2017-07-02 01:44:00+03	28000.00
61ED70	2017-07-16 11:40:00+03	105300.00
61ED9D	2017-07-17 19:37:00+03	52300.00
61EDFC	2017-07-20 15:55:00+03	136200.00
61EDFE	2017-07-17 11:36:00+03	79000.00
61EE0C	2017-08-11 19:22:00+03	46400.00
61EE3B	2017-07-23 07:05:00+03	72400.00
61EE95	2017-07-28 03:21:00+03	29600.00
61EE9A	2017-08-01 11:17:00+03	77000.00
61EE9F	2017-07-30 05:13:00+03	7400.00
61EEA8	2017-07-21 02:23:00+03	73600.00
61EEBE	2017-07-12 22:35:00+03	200500.00
61EEEF	2017-07-25 17:54:00+03	84100.00
61EF40	2017-07-06 06:11:00+03	15700.00
61EF7B	2017-07-17 12:52:00+03	28300.00
61EF87	2017-08-12 14:45:00+03	20000.00
61EFCE	2017-08-06 01:23:00+03	282300.00
61F01F	2017-07-23 15:25:00+03	199600.00
61F0A9	2017-07-10 08:32:00+03	81200.00
61F0AB	2017-07-22 18:36:00+03	111700.00
61F138	2017-06-25 11:42:00+03	10100.00
61F185	2017-07-06 01:16:00+03	56000.00
61F1A1	2017-07-21 21:12:00+03	54400.00
61F1AB	2017-07-31 07:05:00+03	186900.00
61F218	2017-07-11 12:58:00+03	50600.00
61F227	2017-08-11 19:42:00+03	39400.00
61F22F	2017-07-15 00:04:00+03	79300.00
61F26D	2017-08-14 23:59:00+03	191500.00
61F26F	2017-08-13 14:30:00+03	147300.00
61F273	2017-07-25 22:56:00+03	48500.00
61F2DC	2017-08-04 22:00:00+03	89600.00
61F349	2017-07-10 09:55:00+03	82900.00
61F35E	2017-08-10 17:16:00+03	46400.00
61F36F	2017-08-08 21:34:00+03	26000.00
61F388	2017-07-26 07:00:00+03	67600.00
61F396	2017-07-26 08:17:00+03	41200.00
61F427	2017-07-11 03:09:00+03	57500.00
61F4EF	2017-07-26 15:50:00+03	44800.00
61F538	2017-08-07 08:47:00+03	42700.00
61F615	2017-08-11 18:26:00+03	41300.00
61F636	2017-08-03 01:39:00+03	184300.00
61F644	2017-08-03 18:15:00+03	16400.00
61F679	2017-07-24 13:55:00+03	24800.00
61F6A8	2017-07-16 04:28:00+03	89600.00
61F6B0	2017-08-10 17:09:00+03	101200.00
61F6B8	2017-07-28 08:32:00+03	131600.00
61F73E	2017-07-20 15:51:00+03	92800.00
61F760	2017-07-08 02:36:00+03	8400.00
61F766	2017-07-19 15:40:00+03	74300.00
61F777	2017-08-06 16:43:00+03	123000.00
61F8B5	2017-07-26 20:24:00+03	73200.00
61F8EE	2017-07-26 17:45:00+03	52000.00
61F9C7	2017-07-10 08:29:00+03	89600.00
61F9D2	2017-08-15 05:16:00+03	8400.00
61FA0A	2017-08-11 05:41:00+03	61800.00
61FA17	2017-07-14 08:58:00+03	86300.00
61FAA6	2017-07-08 06:04:00+03	183300.00
61FB03	2017-07-20 15:51:00+03	69100.00
61FB15	2017-08-03 09:18:00+03	173200.00
61FB17	2017-08-03 21:23:00+03	36200.00
61FB39	2017-07-03 19:29:00+03	67100.00
61FB47	2017-07-17 04:00:00+03	38800.00
61FB4B	2017-08-06 15:15:00+03	220500.00
61FC0A	2017-07-11 09:49:00+03	266400.00
61FC72	2017-07-31 11:28:00+03	25400.00
61FC87	2017-07-17 19:25:00+03	56000.00
61FD1A	2017-07-25 04:42:00+03	65600.00
61FD23	2017-08-10 21:03:00+03	26000.00
61FD72	2017-07-12 20:30:00+03	214900.00
61FD87	2017-07-16 10:16:00+03	62800.00
61FD94	2017-07-08 16:30:00+03	56000.00
61FDB2	2017-08-02 14:02:00+03	104500.00
61FE43	2017-08-08 23:27:00+03	332900.00
61FE86	2017-07-19 04:10:00+03	316000.00
61FE89	2017-07-11 07:50:00+03	419400.00
61FF1C	2017-07-19 08:40:00+03	112000.00
61FFCE	2017-06-25 12:33:00+03	81600.00
61FFD1	2017-07-18 13:08:00+03	99200.00
61FFD5	2017-07-21 19:12:00+03	99700.00
6200B9	2017-07-09 00:56:00+03	46300.00
6200FB	2017-08-13 12:18:00+03	83700.00
620132	2017-07-11 21:55:00+03	16400.00
620144	2017-08-12 19:02:00+03	192500.00
6201B1	2017-08-07 05:11:00+03	28000.00
62022A	2017-08-10 18:20:00+03	33100.00
620296	2017-07-15 20:29:00+03	73200.00
620316	2017-07-07 10:09:00+03	27400.00
620321	2017-07-30 16:34:00+03	16400.00
6203B4	2017-07-14 14:54:00+03	97900.00
6203F4	2017-08-14 14:45:00+03	80000.00
6203F7	2017-07-01 03:15:00+03	11000.00
620404	2017-08-11 06:02:00+03	19600.00
620426	2017-08-15 04:09:00+03	26000.00
620502	2017-08-05 20:21:00+03	117700.00
620507	2017-08-01 17:34:00+03	26000.00
62053F	2017-08-04 14:29:00+03	40100.00
620565	2017-07-31 12:55:00+03	16400.00
6205D5	2017-08-01 06:01:00+03	23200.00
6206B2	2017-07-03 20:02:00+03	372500.00
620773	2017-07-24 09:08:00+03	22000.00
620775	2017-07-20 21:34:00+03	46000.00
620973	2017-08-04 17:36:00+03	58600.00
62097F	2017-08-01 12:37:00+03	160400.00
620999	2017-07-30 01:26:00+03	10800.00
62099F	2017-07-28 21:53:00+03	97700.00
620A15	2017-08-01 15:04:00+03	85600.00
620A68	2017-08-12 01:57:00+03	42700.00
620AB6	2017-08-03 18:12:00+03	151400.00
620B01	2017-07-04 09:36:00+03	188000.00
620B3D	2017-07-24 12:54:00+03	46000.00
620B65	2017-07-17 15:17:00+03	15000.00
620BA7	2017-07-12 00:05:00+03	32700.00
620BBB	2017-07-10 01:42:00+03	144500.00
620C41	2017-07-25 09:06:00+03	43100.00
620CBD	2017-07-07 15:17:00+03	123000.00
620D3D	2017-07-29 11:28:00+03	54800.00
620DC0	2017-07-22 06:57:00+03	23200.00
620E28	2017-07-07 12:51:00+03	270000.00
620EAA	2017-07-31 14:17:00+03	26200.00
620EB9	2017-07-03 14:35:00+03	248300.00
620ECC	2017-07-03 19:05:00+03	50600.00
620ED0	2017-08-08 09:29:00+03	26200.00
620EE0	2017-07-02 10:08:00+03	67000.00
620EE4	2017-07-03 02:33:00+03	32700.00
620EEA	2017-07-12 04:57:00+03	14000.00
62101C	2017-07-04 01:37:00+03	27200.00
62102E	2017-07-27 05:37:00+03	136200.00
62107D	2017-08-10 09:20:00+03	56900.00
621088	2017-08-10 04:15:00+03	137800.00
6210CD	2017-07-09 12:06:00+03	73300.00
62110C	2017-08-06 00:42:00+03	90300.00
62116D	2017-07-18 17:14:00+03	62800.00
62117D	2017-07-23 22:19:00+03	26000.00
621204	2017-07-09 11:51:00+03	27900.00
621261	2017-07-27 02:34:00+03	151200.00
62129E	2017-07-17 21:09:00+03	9300.00
6212A4	2017-07-11 04:28:00+03	26200.00
621302	2017-07-07 02:27:00+03	56900.00
62133C	2017-08-14 11:54:00+03	135400.00
621345	2017-08-04 09:36:00+03	266400.00
62134A	2017-07-14 15:32:00+03	29600.00
6213E9	2017-07-10 13:59:00+03	27200.00
62141D	2017-07-06 22:37:00+03	656600.00
62145C	2017-08-11 05:23:00+03	46000.00
6214CC	2017-08-05 04:16:00+03	103500.00
6214E1	2017-08-08 01:26:00+03	148300.00
6214FA	2017-06-28 11:51:00+03	114800.00
621504	2017-07-02 21:32:00+03	320400.00
6215CE	2017-07-24 18:45:00+03	26000.00
621692	2017-07-31 21:01:00+03	139300.00
6216A7	2017-07-15 19:21:00+03	51300.00
6216E6	2017-08-03 10:52:00+03	13700.00
621720	2017-08-13 16:29:00+03	25600.00
621729	2017-07-19 19:18:00+03	46400.00
621793	2017-07-11 02:20:00+03	14000.00
6217F3	2017-07-26 00:32:00+03	136200.00
62181A	2017-08-15 03:57:00+03	42800.00
621820	2017-07-31 12:15:00+03	48000.00
6218D4	2017-07-09 05:01:00+03	126300.00
621911	2017-07-03 11:04:00+03	135600.00
621926	2017-08-08 19:32:00+03	81100.00
621979	2017-07-25 22:57:00+03	28000.00
621983	2017-07-18 00:26:00+03	15000.00
6219A5	2017-06-27 08:55:00+03	189800.00
6219B0	2017-07-02 11:25:00+03	66600.00
621A26	2017-07-07 04:08:00+03	58400.00
621A6D	2017-07-07 04:03:00+03	28000.00
621A7F	2017-08-13 15:38:00+03	36200.00
621AE3	2017-07-19 02:51:00+03	280000.00
621BA3	2017-07-27 14:49:00+03	31800.00
621BAA	2017-08-06 09:25:00+03	58000.00
621C0E	2017-07-15 04:49:00+03	40400.00
621C21	2017-07-20 04:20:00+03	72800.00
621C5C	2017-07-21 17:53:00+03	14800.00
621C7C	2017-07-30 19:03:00+03	84100.00
621C87	2017-07-24 15:36:00+03	246000.00
621CC3	2017-07-18 02:04:00+03	62600.00
621CC9	2017-08-14 10:24:00+03	57700.00
621CCD	2017-07-08 00:30:00+03	26000.00
621CD7	2017-08-03 02:48:00+03	27300.00
621D22	2017-07-21 07:24:00+03	19600.00
621DBA	2017-07-28 02:43:00+03	80000.00
621DCA	2017-08-08 02:21:00+03	188000.00
621E17	2017-08-08 12:47:00+03	28400.00
621E19	2017-07-26 16:13:00+03	47600.00
621E89	2017-08-06 08:16:00+03	21800.00
621ECB	2017-07-03 05:35:00+03	74600.00
621ECC	2017-07-21 08:33:00+03	102100.00
621F07	2017-07-30 19:36:00+03	47500.00
621F1C	2017-08-01 13:28:00+03	28600.00
621FC3	2017-07-17 00:43:00+03	100800.00
621FE2	2017-07-26 10:24:00+03	49600.00
62205C	2017-08-07 05:08:00+03	26000.00
622079	2017-07-10 09:52:00+03	62600.00
622095	2017-07-19 03:43:00+03	62800.00
6220E5	2017-07-12 22:47:00+03	57400.00
62211B	2017-08-11 04:05:00+03	86500.00
62212C	2017-07-16 13:12:00+03	113700.00
622133	2017-07-05 21:51:00+03	84500.00
622145	2017-07-17 15:26:00+03	50800.00
622167	2017-08-15 15:22:00+03	17200.00
622186	2017-08-02 03:37:00+03	28000.00
622190	2017-07-13 16:30:00+03	131100.00
62219A	2017-07-20 19:07:00+03	31800.00
6221A3	2017-08-13 06:54:00+03	27300.00
6221F0	2017-07-28 08:45:00+03	44000.00
622229	2017-08-01 23:54:00+03	78900.00
622232	2017-07-29 05:19:00+03	189200.00
622252	2017-08-14 10:14:00+03	31200.00
622268	2017-07-19 19:54:00+03	70700.00
6222F6	2017-08-02 00:46:00+03	48800.00
622310	2017-07-31 20:51:00+03	55800.00
622318	2017-07-13 14:59:00+03	67600.00
622342	2017-07-03 13:25:00+03	29800.00
622385	2017-08-07 19:14:00+03	40800.00
6223FB	2017-07-22 21:18:00+03	146600.00
622477	2017-08-06 04:12:00+03	151200.00
622488	2017-07-31 11:00:00+03	46200.00
62248E	2017-07-06 06:34:00+03	27600.00
6224C7	2017-07-27 23:06:00+03	20400.00
622516	2017-07-09 00:16:00+03	29600.00
622540	2017-08-13 08:46:00+03	39500.00
62255E	2017-07-10 07:46:00+03	47500.00
6225C3	2017-07-23 20:13:00+03	136500.00
6225E3	2017-07-30 09:44:00+03	6800.00
622647	2017-08-02 19:18:00+03	24000.00
622663	2017-08-07 15:58:00+03	76000.00
6226AD	2017-08-10 16:27:00+03	95200.00
6226B0	2017-08-10 14:22:00+03	7200.00
6226CA	2017-07-18 12:13:00+03	38400.00
6226FA	2017-08-12 05:15:00+03	31700.00
62277D	2017-08-01 21:04:00+03	75300.00
622786	2017-08-10 16:13:00+03	73800.00
622832	2017-07-27 12:21:00+03	52800.00
62288C	2017-08-14 22:09:00+03	36600.00
6228CB	2017-07-19 21:03:00+03	29500.00
6228CD	2017-07-15 10:06:00+03	136200.00
622950	2017-08-01 10:34:00+03	123000.00
6229A5	2017-07-28 16:21:00+03	14000.00
6229DD	2017-08-01 17:12:00+03	18600.00
622A8D	2017-08-12 02:24:00+03	12200.00
622ABA	2017-07-31 17:11:00+03	59800.00
622AC3	2017-07-31 19:10:00+03	174300.00
622BB7	2017-07-12 07:03:00+03	353600.00
622BD0	2017-07-21 10:45:00+03	24200.00
622BEB	2017-07-23 14:55:00+03	37900.00
622C3A	2017-07-03 17:45:00+03	114300.00
622CF2	2017-07-15 03:50:00+03	112000.00
622D59	2017-08-11 23:42:00+03	100000.00
622DBC	2017-08-04 17:27:00+03	100600.00
622DD3	2017-07-21 15:28:00+03	8000.00
622DE2	2017-07-23 11:59:00+03	55000.00
622DF8	2017-08-12 14:06:00+03	85800.00
622E04	2017-07-16 12:02:00+03	150600.00
622E05	2017-07-21 02:28:00+03	26000.00
622E63	2017-08-11 19:01:00+03	171000.00
622E81	2017-07-28 23:58:00+03	102700.00
622EBF	2017-07-23 00:06:00+03	124200.00
622EC8	2017-07-12 02:44:00+03	43600.00
622EC9	2017-07-17 11:10:00+03	27900.00
622EE5	2017-07-05 14:41:00+03	53600.00
622FDB	2017-08-09 02:53:00+03	62900.00
622FF8	2017-08-07 17:40:00+03	94200.00
623007	2017-07-22 23:19:00+03	123000.00
62303A	2017-07-28 09:09:00+03	68400.00
623047	2017-07-29 22:31:00+03	30200.00
62307A	2017-07-03 12:37:00+03	44600.00
6230D4	2017-07-19 03:25:00+03	27200.00
6230F0	2017-07-04 19:08:00+03	62600.00
623127	2017-07-31 05:48:00+03	41200.00
623164	2017-08-15 02:11:00+03	51900.00
6231A4	2017-07-04 16:22:00+03	86600.00
6231BC	2017-08-11 06:08:00+03	93900.00
6231FC	2017-07-18 08:58:00+03	13400.00
623210	2017-07-18 23:03:00+03	8400.00
623241	2017-07-14 15:29:00+03	106100.00
623294	2017-07-10 09:36:00+03	112600.00
62341E	2017-07-28 02:21:00+03	35800.00
623468	2017-08-15 09:32:00+03	80000.00
6234EC	2017-07-25 15:54:00+03	24800.00
6234ED	2017-07-07 00:56:00+03	105400.00
623501	2017-08-11 11:52:00+03	63300.00
623530	2017-08-15 11:26:00+03	57400.00
623652	2017-07-19 02:19:00+03	14400.00
623662	2017-07-02 12:00:00+03	23400.00
62368A	2017-07-19 22:21:00+03	181500.00
6236C6	2017-07-04 08:22:00+03	23600.00
6236F9	2017-07-14 08:56:00+03	33000.00
62376F	2017-07-11 20:53:00+03	57500.00
6237FD	2017-07-06 17:46:00+03	111600.00
62380D	2017-07-10 16:34:00+03	75300.00
6238CA	2017-07-07 11:31:00+03	3700.00
6238CF	2017-07-30 08:22:00+03	213200.00
6238EC	2017-08-09 16:47:00+03	23600.00
6238FD	2017-08-11 07:16:00+03	119000.00
623928	2017-08-14 22:05:00+03	23200.00
6239B9	2017-07-16 06:38:00+03	46300.00
6239EE	2017-07-03 02:37:00+03	55800.00
623AA3	2017-07-02 04:18:00+03	294300.00
623AF7	2017-08-09 03:00:00+03	31900.00
623B49	2017-07-10 03:40:00+03	73300.00
623BA0	2017-07-27 00:07:00+03	90600.00
623CF1	2017-08-06 10:38:00+03	133200.00
623CFD	2017-08-11 18:29:00+03	55800.00
623D57	2017-07-31 18:48:00+03	18600.00
623D6F	2017-08-14 03:57:00+03	51300.00
623DB7	2017-08-06 19:45:00+03	56000.00
623E89	2017-07-21 23:15:00+03	8000.00
623EA6	2017-08-10 18:04:00+03	73500.00
623EB5	2017-07-26 18:44:00+03	37700.00
623ECF	2017-08-11 23:59:00+03	42600.00
623F3D	2017-08-05 01:32:00+03	8000.00
623F57	2017-07-25 00:11:00+03	40800.00
62406C	2017-07-17 14:49:00+03	73500.00
6240AC	2017-08-08 20:08:00+03	39700.00
624170	2017-07-05 00:12:00+03	25000.00
62418D	2017-07-13 14:01:00+03	61800.00
62419D	2017-07-06 08:57:00+03	19600.00
6241D0	2017-07-21 11:34:00+03	24400.00
624221	2017-08-02 21:45:00+03	35800.00
624288	2017-07-20 14:16:00+03	123000.00
6242A1	2017-07-19 12:51:00+03	182100.00
6242B3	2017-07-03 16:39:00+03	35200.00
6242E5	2017-07-15 06:49:00+03	83600.00
62434A	2017-07-07 16:43:00+03	28800.00
62438B	2017-07-20 05:45:00+03	38400.00
6243EC	2017-07-25 12:08:00+03	65500.00
624432	2017-08-15 15:14:00+03	58600.00
624441	2017-08-03 10:57:00+03	44700.00
624455	2017-08-09 21:47:00+03	134600.00
624478	2017-07-07 01:58:00+03	185600.00
6244DD	2017-07-19 16:38:00+03	12400.00
624511	2017-07-16 07:50:00+03	36600.00
62451F	2017-08-06 05:35:00+03	26200.00
624554	2017-07-22 07:11:00+03	189200.00
624564	2017-08-13 15:33:00+03	72300.00
624575	2017-07-22 18:05:00+03	23600.00
62461A	2017-07-16 23:08:00+03	13400.00
624624	2017-07-07 23:53:00+03	57600.00
624642	2017-07-11 15:29:00+03	56000.00
6246EA	2017-08-08 22:30:00+03	52000.00
6246EE	2017-08-05 17:03:00+03	19600.00
62470F	2017-08-05 01:00:00+03	177200.00
62478F	2017-07-04 03:58:00+03	25600.00
6248D0	2017-08-12 23:37:00+03	38600.00
6248F5	2017-07-18 12:21:00+03	61800.00
62499E	2017-08-10 07:31:00+03	177600.00
6249A3	2017-07-18 20:58:00+03	138800.00
624AD6	2017-07-20 12:55:00+03	13000.00
624B4E	2017-07-27 15:17:00+03	124200.00
624B6D	2017-08-09 04:27:00+03	36800.00
624B98	2017-07-26 18:39:00+03	49400.00
624BAB	2017-07-02 05:04:00+03	141400.00
624BD1	2017-08-09 10:07:00+03	130100.00
624BD6	2017-07-18 05:58:00+03	23900.00
624BEE	2017-08-11 15:43:00+03	143100.00
624C1B	2017-07-04 20:44:00+03	39000.00
624CF4	2017-07-29 07:01:00+03	59800.00
624D01	2017-08-12 05:02:00+03	284900.00
624D40	2017-07-07 04:25:00+03	43800.00
624D4D	2017-07-18 20:00:00+03	24400.00
624D66	2017-07-12 12:30:00+03	11600.00
624DAD	2017-07-02 06:14:00+03	46500.00
624DE9	2017-07-24 05:45:00+03	15100.00
624E3A	2017-07-06 06:28:00+03	179400.00
624E6A	2017-08-07 08:13:00+03	59000.00
624E80	2017-07-21 15:44:00+03	406200.00
624E9A	2017-06-29 02:19:00+03	32700.00
624E9F	2017-07-31 06:59:00+03	14700.00
624EBE	2017-08-02 11:34:00+03	37500.00
624F2B	2017-08-04 21:15:00+03	83600.00
624F3B	2017-08-07 00:40:00+03	47600.00
624F9D	2017-07-16 04:46:00+03	61900.00
624FDA	2017-07-24 14:25:00+03	38800.00
624FEF	2017-08-14 12:28:00+03	35800.00
624FF9	2017-07-09 07:47:00+03	16100.00
625012	2017-07-20 10:50:00+03	55800.00
625037	2017-07-27 01:11:00+03	28000.00
62507E	2017-07-25 00:53:00+03	27800.00
6250A3	2017-07-25 02:26:00+03	48500.00
6250AB	2017-08-14 19:37:00+03	76800.00
6251C4	2017-07-29 07:43:00+03	52400.00
62522A	2017-07-24 21:34:00+03	54800.00
62522C	2017-07-17 22:57:00+03	37700.00
625235	2017-07-14 09:10:00+03	6000.00
625238	2017-07-24 00:31:00+03	40800.00
625254	2017-07-12 15:33:00+03	177200.00
625276	2017-06-30 18:09:00+03	80400.00
6252BD	2017-08-06 00:45:00+03	151000.00
6252D7	2017-06-27 11:05:00+03	50100.00
62532E	2017-07-11 14:11:00+03	39300.00
625375	2017-07-26 20:50:00+03	139300.00
625397	2017-07-28 13:02:00+03	332100.00
6253BA	2017-08-12 04:01:00+03	85700.00
6253E6	2017-08-14 16:49:00+03	37700.00
625471	2017-08-11 11:18:00+03	46200.00
625474	2017-07-09 09:28:00+03	13000.00
625482	2017-08-14 11:26:00+03	47400.00
6254BA	2017-07-22 02:33:00+03	55800.00
6254BE	2017-07-07 16:13:00+03	18700.00
625514	2017-07-11 13:55:00+03	271200.00
625516	2017-07-25 15:52:00+03	155100.00
625522	2017-07-10 21:35:00+03	28800.00
625574	2017-08-06 16:29:00+03	24000.00
6255B8	2017-07-04 10:00:00+03	43600.00
62562C	2017-08-07 22:45:00+03	47200.00
62564A	2017-06-26 05:15:00+03	63700.00
6256A0	2017-08-15 05:21:00+03	35600.00
6256B4	2017-07-07 10:03:00+03	102100.00
6256D4	2017-08-11 12:28:00+03	99500.00
62570B	2017-08-08 16:23:00+03	25200.00
62571B	2017-07-02 20:53:00+03	53100.00
625722	2017-07-19 03:28:00+03	49600.00
625733	2017-07-31 02:38:00+03	94000.00
625754	2017-07-22 02:26:00+03	16400.00
6257B0	2017-06-29 21:48:00+03	40100.00
6257B3	2017-08-14 03:16:00+03	129200.00
6257C4	2017-08-06 17:20:00+03	31400.00
62586B	2017-08-14 08:49:00+03	52400.00
625877	2017-07-10 17:40:00+03	64700.00
6258A9	2017-07-09 13:49:00+03	95000.00
62591C	2017-07-23 23:59:00+03	56000.00
625A36	2017-07-31 17:57:00+03	23600.00
625A57	2017-08-02 13:46:00+03	139800.00
625B15	2017-08-06 23:59:00+03	112000.00
625B38	2017-07-08 01:24:00+03	13400.00
625B3C	2017-08-04 05:45:00+03	18100.00
625BB1	2017-06-30 13:55:00+03	28000.00
625BB5	2017-06-26 17:30:00+03	95200.00
625C22	2017-07-02 22:05:00+03	62900.00
625C52	2017-08-13 12:11:00+03	295500.00
625CC7	2017-08-08 04:46:00+03	55800.00
625D3E	2017-07-07 00:32:00+03	115000.00
625D4C	2017-07-11 14:11:00+03	106800.00
625D6B	2017-07-14 17:00:00+03	102700.00
625DAB	2017-07-19 03:58:00+03	252200.00
625DFF	2017-06-28 02:25:00+03	28000.00
625E13	2017-08-02 18:05:00+03	21800.00
625E20	2017-08-15 15:21:00+03	90800.00
625E79	2017-07-05 22:19:00+03	272300.00
625EB6	2017-08-11 18:01:00+03	106400.00
625EFD	2017-07-07 19:14:00+03	66600.00
625F1B	2017-07-06 01:50:00+03	301800.00
625F52	2017-07-13 20:18:00+03	54500.00
625F56	2017-07-18 18:11:00+03	394400.00
625FFA	2017-07-05 12:32:00+03	56000.00
626005	2017-07-14 01:08:00+03	62600.00
626015	2017-07-17 07:50:00+03	147200.00
626022	2017-07-24 13:26:00+03	56600.00
62602A	2017-07-14 05:15:00+03	36200.00
626032	2017-08-02 05:06:00+03	26200.00
626081	2017-07-06 01:57:00+03	46000.00
6261CC	2017-07-26 22:16:00+03	167400.00
626238	2017-07-14 04:33:00+03	36800.00
6262E7	2017-08-07 19:59:00+03	54400.00
626320	2017-07-23 01:27:00+03	38600.00
6263B7	2017-07-15 22:59:00+03	66600.00
6263EC	2017-08-06 05:45:00+03	38600.00
626402	2017-07-07 01:51:00+03	38800.00
626465	2017-07-06 09:25:00+03	22000.00
6264B2	2017-07-27 16:55:00+03	16400.00
6264BA	2017-07-05 20:38:00+03	44700.00
6264CA	2017-07-14 00:46:00+03	37900.00
626500	2017-06-29 05:02:00+03	79600.00
626501	2017-07-26 07:16:00+03	55800.00
62653F	2017-08-06 16:28:00+03	23100.00
626543	2017-07-03 11:30:00+03	92400.00
6265BC	2017-08-04 19:14:00+03	26000.00
62661F	2017-08-07 21:44:00+03	24400.00
626630	2017-08-05 04:50:00+03	65300.00
62663B	2017-08-03 13:10:00+03	59200.00
626684	2017-08-02 08:19:00+03	238700.00
626692	2017-08-02 20:11:00+03	37900.00
626725	2017-07-05 23:58:00+03	66000.00
626739	2017-07-17 11:11:00+03	214900.00
62674E	2017-07-20 00:08:00+03	124200.00
626772	2017-07-23 22:49:00+03	37100.00
626781	2017-07-13 16:27:00+03	112000.00
626789	2017-08-01 07:17:00+03	222800.00
626820	2017-07-07 07:25:00+03	53600.00
62684B	2017-07-03 10:10:00+03	70100.00
626889	2017-07-14 21:22:00+03	57400.00
626931	2017-07-10 10:13:00+03	44000.00
62695C	2017-07-21 01:10:00+03	134400.00
6269E6	2017-07-16 21:46:00+03	408500.00
626A51	2017-07-27 16:26:00+03	73200.00
626A5F	2017-07-01 11:22:00+03	23200.00
626A90	2017-07-07 06:16:00+03	7200.00
626ACD	2017-07-04 02:22:00+03	85000.00
626B02	2017-08-07 16:38:00+03	52700.00
626B0F	2017-08-11 10:38:00+03	92700.00
626B3D	2017-07-12 00:27:00+03	49200.00
626B7C	2017-07-13 20:38:00+03	37900.00
626B87	2017-07-27 22:08:00+03	56600.00
626BA4	2017-08-13 11:25:00+03	8600.00
626BAE	2017-07-28 01:24:00+03	12400.00
626BCF	2017-06-30 23:31:00+03	148200.00
626C46	2017-08-14 23:02:00+03	12000.00
626C62	2017-08-05 19:18:00+03	67600.00
626C91	2017-07-19 09:58:00+03	6300.00
626CB9	2017-07-03 21:48:00+03	46400.00
626CC8	2017-07-11 09:40:00+03	113700.00
626CDD	2017-08-15 06:57:00+03	227400.00
626CE9	2017-08-12 23:08:00+03	136000.00
626CED	2017-08-09 00:36:00+03	36200.00
626D33	2017-07-18 22:41:00+03	76500.00
626D6C	2017-08-08 18:22:00+03	44600.00
626DEB	2017-08-05 07:52:00+03	369000.00
626DFB	2017-07-17 00:51:00+03	49600.00
626E0C	2017-08-06 07:55:00+03	11200.00
626E41	2017-08-15 15:27:00+03	32800.00
626E5A	2017-08-07 08:25:00+03	188000.00
626E61	2017-07-28 11:45:00+03	115600.00
626ECC	2017-07-20 21:28:00+03	56000.00
626EF8	2017-07-28 08:08:00+03	143100.00
626F53	2017-07-20 12:04:00+03	56000.00
626F6B	2017-06-25 14:35:00+03	53700.00
626F75	2017-06-30 18:24:00+03	26000.00
626FAE	2017-07-23 22:08:00+03	252200.00
626FDA	2017-07-31 01:03:00+03	113700.00
627009	2017-07-22 22:10:00+03	56000.00
627076	2017-08-01 21:09:00+03	32800.00
6270A7	2017-08-13 16:46:00+03	58200.00
62716F	2017-07-26 06:29:00+03	28700.00
62717A	2017-07-13 00:04:00+03	28800.00
627182	2017-08-10 13:45:00+03	72300.00
6271D8	2017-07-28 14:48:00+03	24000.00
62721E	2017-08-15 07:32:00+03	26000.00
62726D	2017-07-28 10:20:00+03	98000.00
627286	2017-08-07 21:43:00+03	73300.00
62728B	2017-08-01 00:10:00+03	44500.00
6272F9	2017-07-13 16:22:00+03	110400.00
62734F	2017-08-13 19:31:00+03	95600.00
62738F	2017-08-05 03:52:00+03	75600.00
6273C1	2017-07-01 11:50:00+03	27600.00
6273D1	2017-07-30 13:37:00+03	117600.00
62744A	2017-07-01 04:18:00+03	26700.00
6274AD	2017-07-08 22:50:00+03	23600.00
6274B9	2017-07-27 19:33:00+03	85000.00
627534	2017-07-28 04:46:00+03	218700.00
627553	2017-07-26 08:34:00+03	492000.00
627561	2017-07-29 12:25:00+03	13400.00
627580	2017-07-12 19:27:00+03	75600.00
62758A	2017-08-14 23:42:00+03	62100.00
627595	2017-08-10 22:31:00+03	20600.00
627682	2017-07-14 10:53:00+03	55800.00
62768A	2017-06-29 03:27:00+03	16400.00
627694	2017-07-09 06:39:00+03	153300.00
627698	2017-08-13 14:42:00+03	60400.00
6276B3	2017-07-26 10:23:00+03	110500.00
6276C2	2017-07-07 08:17:00+03	26000.00
6276FE	2017-08-02 14:30:00+03	75600.00
627707	2017-07-21 19:34:00+03	123000.00
627724	2017-08-12 14:58:00+03	234600.00
62772D	2017-08-12 01:04:00+03	48800.00
627741	2017-07-24 18:35:00+03	75300.00
62775C	2017-07-29 04:18:00+03	229600.00
627780	2017-07-03 22:15:00+03	55600.00
6277CD	2017-08-13 08:16:00+03	285100.00
627806	2017-08-06 14:58:00+03	78600.00
62784A	2017-08-07 07:46:00+03	54800.00
627887	2017-07-12 06:59:00+03	40800.00
627899	2017-07-25 20:15:00+03	21400.00
6278A8	2017-07-07 22:03:00+03	99200.00
6278BB	2017-08-06 15:46:00+03	492000.00
627963	2017-08-15 08:47:00+03	52700.00
627984	2017-08-15 06:28:00+03	101200.00
6279A4	2017-08-07 11:15:00+03	73400.00
6279E3	2017-07-04 18:45:00+03	406700.00
6279F1	2017-07-20 17:53:00+03	13400.00
6279F2	2017-07-25 19:27:00+03	23200.00
627A0F	2017-07-28 18:31:00+03	25900.00
627A54	2017-08-12 01:00:00+03	64500.00
627B4C	2017-07-02 05:26:00+03	73600.00
627BC9	2017-08-11 00:01:00+03	15400.00
627CBA	2017-07-20 19:16:00+03	113800.00
627CEF	2017-07-27 15:31:00+03	29800.00
627D2B	2017-08-15 08:31:00+03	58400.00
627D5A	2017-08-12 06:14:00+03	86300.00
627D69	2017-08-02 03:44:00+03	32400.00
627D9A	2017-07-23 13:51:00+03	92800.00
627DB0	2017-07-09 10:38:00+03	67200.00
627DD9	2017-08-03 00:44:00+03	46300.00
627DE8	2017-07-21 11:08:00+03	40400.00
627E1A	2017-07-03 22:03:00+03	90800.00
627E5C	2017-07-28 19:48:00+03	615000.00
627E65	2017-07-05 20:00:00+03	279500.00
627ECF	2017-07-18 22:46:00+03	41400.00
627EE2	2017-07-03 23:13:00+03	14000.00
627F29	2017-07-03 06:34:00+03	246000.00
627F2B	2017-08-11 17:33:00+03	398500.00
627F37	2017-08-07 19:50:00+03	57400.00
627F69	2017-08-03 07:00:00+03	22000.00
627FAC	2017-08-12 01:47:00+03	62100.00
62802F	2017-08-13 11:58:00+03	40000.00
628035	2017-07-04 15:23:00+03	44800.00
6280A6	2017-07-31 12:18:00+03	43900.00
6280A8	2017-07-27 06:34:00+03	38800.00
6280BC	2017-07-13 14:44:00+03	19600.00
62818C	2017-07-01 05:25:00+03	54800.00
62819D	2017-07-13 20:44:00+03	86300.00
6281A2	2017-06-30 02:55:00+03	48800.00
6281D2	2017-07-17 19:24:00+03	46400.00
628211	2017-08-03 20:40:00+03	136300.00
628287	2017-07-06 16:40:00+03	111900.00
628302	2017-07-31 11:00:00+03	98300.00
628333	2017-07-12 12:09:00+03	14400.00
6283CA	2017-07-08 23:31:00+03	54800.00
628449	2017-07-30 08:00:00+03	135000.00
628492	2017-08-09 20:41:00+03	9200.00
628569	2017-07-22 18:53:00+03	15400.00
6285A8	2017-06-29 23:54:00+03	86400.00
628628	2017-08-11 17:44:00+03	46400.00
62865F	2017-08-07 02:36:00+03	21800.00
628664	2017-07-10 16:41:00+03	12200.00
62867B	2017-07-28 23:48:00+03	31600.00
62869A	2017-08-08 02:48:00+03	144400.00
6286B3	2017-07-29 10:55:00+03	175700.00
628711	2017-07-15 05:32:00+03	99000.00
62872E	2017-07-29 07:51:00+03	48500.00
628762	2017-07-15 14:37:00+03	217200.00
628788	2017-07-22 15:28:00+03	59900.00
6287B8	2017-07-13 18:32:00+03	47200.00
6287D5	2017-07-02 10:45:00+03	52800.00
6287E3	2017-07-01 07:44:00+03	22100.00
6287F6	2017-07-29 06:53:00+03	27200.00
6287FF	2017-07-04 20:34:00+03	23200.00
62881E	2017-08-08 05:13:00+03	39200.00
6288F3	2017-08-01 08:25:00+03	125700.00
628902	2017-07-28 15:40:00+03	176500.00
62898C	2017-07-12 07:29:00+03	20000.00
6289B7	2017-07-03 17:02:00+03	26200.00
6289CB	2017-08-01 08:45:00+03	125400.00
6289DD	2017-08-07 16:12:00+03	59200.00
628A78	2017-08-03 00:29:00+03	119600.00
628B38	2017-06-30 07:43:00+03	129600.00
628B50	2017-07-26 16:55:00+03	174600.00
628B80	2017-08-04 10:45:00+03	56000.00
628BB5	2017-07-03 05:23:00+03	48500.00
628C24	2017-07-08 07:03:00+03	24400.00
628C48	2017-07-20 07:41:00+03	27200.00
628C7B	2017-07-23 16:16:00+03	92800.00
628C94	2017-08-07 01:41:00+03	24400.00
628D00	2017-07-20 12:55:00+03	7400.00
628D08	2017-07-21 11:52:00+03	101200.00
628D0D	2017-07-05 16:48:00+03	26000.00
628D27	2017-07-28 07:18:00+03	21400.00
628D3C	2017-07-02 20:04:00+03	28000.00
628D72	2017-07-23 22:41:00+03	24400.00
628D8D	2017-08-02 05:14:00+03	52000.00
628E2E	2017-08-13 21:25:00+03	50800.00
628E38	2017-08-14 07:39:00+03	168400.00
628E39	2017-07-27 22:15:00+03	75300.00
628E5B	2017-07-23 23:29:00+03	117200.00
628EAE	2017-07-18 12:37:00+03	56100.00
628ED5	2017-08-15 02:43:00+03	24400.00
628EEB	2017-08-14 04:31:00+03	155600.00
628F04	2017-07-09 22:53:00+03	32400.00
628F10	2017-08-06 11:12:00+03	89700.00
629056	2017-07-04 13:09:00+03	63500.00
62907E	2017-08-10 14:54:00+03	71900.00
6290EF	2017-07-28 14:04:00+03	49100.00
629105	2017-07-28 08:00:00+03	12400.00
629164	2017-08-07 08:16:00+03	92400.00
6291BF	2017-08-14 04:17:00+03	26700.00
629211	2017-07-12 09:38:00+03	39500.00
62922B	2017-07-23 10:45:00+03	152200.00
62929D	2017-08-14 15:42:00+03	15100.00
6292A5	2017-08-14 00:21:00+03	171800.00
6292BD	2017-08-02 19:48:00+03	129200.00
6292DB	2017-06-30 22:27:00+03	37100.00
6292FE	2017-08-13 09:48:00+03	32800.00
629324	2017-08-06 08:39:00+03	40400.00
62932C	2017-07-23 23:43:00+03	207200.00
629371	2017-07-18 01:10:00+03	57600.00
6293A8	2017-08-07 01:53:00+03	47000.00
62949E	2017-07-01 07:30:00+03	78400.00
6294D4	2017-07-23 18:18:00+03	48800.00
6294F6	2017-07-12 03:57:00+03	69000.00
62950D	2017-07-18 09:38:00+03	11300.00
62956D	2017-07-06 12:42:00+03	26700.00
629576	2017-08-14 10:56:00+03	73300.00
6295A7	2017-08-03 10:54:00+03	13600.00
6295B0	2017-07-15 17:33:00+03	60200.00
6295E1	2017-08-05 21:53:00+03	31600.00
6295FB	2017-08-06 11:31:00+03	143100.00
62963F	2017-08-06 13:18:00+03	246100.00
6296F3	2017-08-02 22:14:00+03	156400.00
62971F	2017-07-07 21:29:00+03	51900.00
629726	2017-08-01 17:35:00+03	39500.00
629786	2017-07-23 09:45:00+03	24400.00
62978A	2017-08-06 08:47:00+03	22000.00
62979B	2017-08-02 02:01:00+03	16000.00
6298A9	2017-08-05 19:45:00+03	47200.00
6298EF	2017-08-06 09:15:00+03	56900.00
629922	2017-07-10 12:08:00+03	86400.00
629941	2017-08-12 09:31:00+03	54800.00
629947	2017-07-31 08:37:00+03	72800.00
62995C	2017-07-28 06:14:00+03	140200.00
629987	2017-07-20 11:46:00+03	80600.00
62999C	2017-07-04 20:58:00+03	55800.00
629A03	2017-07-13 23:44:00+03	48300.00
629A06	2017-07-27 11:47:00+03	84100.00
629A43	2017-07-06 15:36:00+03	14400.00
629AB8	2017-07-09 07:36:00+03	25600.00
629AE5	2017-07-05 16:48:00+03	22000.00
629B3E	2017-07-27 20:04:00+03	119500.00
629B47	2017-07-19 14:36:00+03	31100.00
629B68	2017-07-30 07:32:00+03	83000.00
629BAF	2017-07-20 12:05:00+03	55800.00
629C6C	2017-08-01 05:46:00+03	65900.00
629C7C	2017-07-19 23:34:00+03	26800.00
629CC8	2017-07-26 01:55:00+03	83200.00
629D27	2017-07-29 02:32:00+03	11600.00
629E18	2017-08-03 13:48:00+03	137100.00
629E24	2017-07-02 00:56:00+03	55800.00
629E5C	2017-07-07 22:17:00+03	46400.00
629ECE	2017-07-12 23:39:00+03	101100.00
629EED	2017-07-22 09:31:00+03	253600.00
629EF8	2017-07-09 19:51:00+03	45500.00
629F11	2017-08-08 11:59:00+03	27200.00
629F5E	2017-07-17 08:53:00+03	123000.00
629F76	2017-07-21 04:01:00+03	31100.00
629F86	2017-07-07 06:20:00+03	95700.00
629F92	2017-08-05 12:27:00+03	103100.00
629FB3	2017-08-13 05:18:00+03	112000.00
62A036	2017-07-19 16:04:00+03	60400.00
62A07B	2017-07-19 08:21:00+03	28000.00
62A0DC	2017-07-20 05:31:00+03	151200.00
62A16C	2017-07-11 15:33:00+03	102300.00
62A184	2017-08-01 15:16:00+03	18600.00
62A218	2017-07-19 01:16:00+03	56000.00
62A244	2017-07-27 19:59:00+03	14000.00
62A267	2017-08-01 10:09:00+03	25200.00
62A2A1	2017-07-03 21:29:00+03	59800.00
62A2C3	2017-07-25 06:24:00+03	56000.00
62A329	2017-08-07 22:20:00+03	101200.00
62A34D	2017-07-25 22:35:00+03	24400.00
62A396	2017-07-01 20:42:00+03	21000.00
62A3E3	2017-07-26 05:16:00+03	332900.00
62A420	2017-07-17 10:53:00+03	300800.00
62A475	2017-08-10 10:25:00+03	56600.00
62A48D	2017-07-05 02:56:00+03	246000.00
62A49A	2017-07-10 22:07:00+03	67800.00
62A4E2	2017-07-26 15:43:00+03	62400.00
62A560	2017-07-29 18:33:00+03	24800.00
62A59D	2017-07-02 09:35:00+03	225200.00
62A5AA	2017-07-25 19:28:00+03	68800.00
62A5AE	2017-08-07 14:05:00+03	49600.00
62A6A9	2017-07-05 05:46:00+03	184300.00
62A756	2017-08-03 04:58:00+03	56000.00
62A78A	2017-07-13 17:42:00+03	409400.00
62A7A2	2017-07-27 17:33:00+03	56000.00
62A7EF	2017-07-24 01:31:00+03	34000.00
62A840	2017-08-14 07:10:00+03	4000.00
62A852	2017-07-16 14:37:00+03	13200.00
62A8C4	2017-08-05 08:49:00+03	46200.00
62A8D4	2017-08-12 16:15:00+03	35200.00
62A8DC	2017-08-01 20:40:00+03	80000.00
62A94F	2017-07-25 13:03:00+03	65900.00
62A986	2017-06-28 23:38:00+03	57500.00
62A999	2017-07-21 21:07:00+03	55800.00
62A9BF	2017-08-08 08:46:00+03	64800.00
62AA0F	2017-07-03 00:27:00+03	89200.00
62AA2D	2017-08-04 23:40:00+03	52000.00
62AA3A	2017-08-13 05:49:00+03	50000.00
62AA85	2017-07-21 09:16:00+03	28000.00
62AA8E	2017-07-13 21:06:00+03	47000.00
62AA99	2017-08-14 12:37:00+03	26800.00
62AA9A	2017-07-21 10:20:00+03	47700.00
62AABF	2017-07-16 00:43:00+03	203400.00
62AB06	2017-07-24 07:06:00+03	23100.00
62AB07	2017-08-02 23:32:00+03	114800.00
62AB16	2017-07-23 05:28:00+03	100000.00
62AB6D	2017-07-18 15:09:00+03	168000.00
62ABF2	2017-07-25 03:26:00+03	27200.00
62ABF7	2017-07-17 17:32:00+03	20500.00
62AC34	2017-08-15 04:38:00+03	40800.00
62AC5B	2017-08-03 16:30:00+03	115100.00
62AC61	2017-07-03 14:59:00+03	31200.00
62AC66	2017-07-15 17:33:00+03	26700.00
62ACC2	2017-06-30 07:05:00+03	58000.00
62ACDD	2017-08-12 12:50:00+03	44600.00
62AD8F	2017-07-31 13:00:00+03	69500.00
62ADE6	2017-07-07 11:11:00+03	72400.00
62AE2F	2017-07-24 07:53:00+03	14800.00
62AE65	2017-07-19 10:36:00+03	44100.00
62AEB7	2017-07-19 13:34:00+03	82900.00
62AF28	2017-07-20 09:28:00+03	99900.00
62AF8B	2017-07-17 11:37:00+03	73300.00
62AF97	2017-08-15 05:58:00+03	100300.00
62AF9C	2017-07-04 00:28:00+03	19300.00
62AFA3	2017-07-14 19:05:00+03	12400.00
62AFA8	2017-07-12 15:12:00+03	54400.00
62B0C1	2017-07-26 12:54:00+03	260300.00
62B0C2	2017-07-03 14:33:00+03	46000.00
62B0CC	2017-07-12 03:21:00+03	64700.00
62B195	2017-08-11 01:27:00+03	13200.00
62B1C5	2017-08-07 22:56:00+03	108500.00
62B22A	2017-07-28 06:24:00+03	44000.00
62B22E	2017-07-30 09:55:00+03	36800.00
62B24E	2017-07-28 18:22:00+03	31400.00
62B297	2017-07-16 14:12:00+03	246000.00
62B2AB	2017-08-04 22:44:00+03	37200.00
62B2E4	2017-07-23 16:13:00+03	81300.00
62B356	2017-07-09 01:30:00+03	122300.00
62B36F	2017-08-08 06:44:00+03	19600.00
62B38F	2017-07-26 21:40:00+03	66600.00
62B3BE	2017-07-04 22:02:00+03	221500.00
62B3FF	2017-07-02 05:22:00+03	22000.00
62B410	2017-07-21 23:42:00+03	28000.00
62B429	2017-07-26 04:42:00+03	47100.00
62B44A	2017-07-19 22:13:00+03	246000.00
62B44E	2017-07-14 11:53:00+03	202800.00
62B450	2017-07-10 20:01:00+03	28000.00
62B478	2017-07-11 13:53:00+03	19600.00
62B488	2017-07-17 07:50:00+03	102100.00
62B4C1	2017-07-16 19:13:00+03	84300.00
62B4F7	2017-07-30 20:25:00+03	43200.00
62B5A0	2017-07-26 15:54:00+03	87300.00
62B5FC	2017-07-14 21:51:00+03	123000.00
62B64C	2017-07-21 22:38:00+03	40700.00
62B69F	2017-08-06 17:32:00+03	42000.00
62B6C5	2017-07-07 08:10:00+03	406600.00
62B6F1	2017-08-04 10:05:00+03	66100.00
62B739	2017-08-05 17:25:00+03	56600.00
62B75C	2017-07-05 15:40:00+03	28000.00
62B7A0	2017-07-07 05:45:00+03	55800.00
62B81B	2017-07-10 16:33:00+03	105600.00
62B998	2017-08-08 08:12:00+03	143300.00
62B9E4	2017-07-04 15:25:00+03	54100.00
62BA20	2017-08-12 18:39:00+03	86600.00
62BA32	2017-07-10 14:57:00+03	6000.00
62BA50	2017-07-15 08:36:00+03	61400.00
62BA75	2017-07-09 17:58:00+03	26000.00
62BB0C	2017-06-29 10:29:00+03	118300.00
62BB52	2017-07-19 21:52:00+03	78300.00
62BB65	2017-07-31 15:15:00+03	132800.00
62BB66	2017-08-10 08:41:00+03	136200.00
62BB76	2017-07-19 18:15:00+03	42400.00
62BC18	2017-07-22 16:57:00+03	86300.00
62BC89	2017-08-03 18:09:00+03	23600.00
62BCCE	2017-08-10 13:10:00+03	22000.00
62BD2D	2017-08-10 21:41:00+03	382200.00
62BD54	2017-07-17 02:48:00+03	56000.00
62BD5E	2017-07-29 07:48:00+03	71200.00
62BDBA	2017-07-31 19:29:00+03	289800.00
62BDCA	2017-07-06 21:06:00+03	206400.00
62BE16	2017-07-26 01:02:00+03	59400.00
62BE2B	2017-07-18 15:16:00+03	40000.00
62BE33	2017-07-24 09:33:00+03	71400.00
62BE54	2017-07-27 12:18:00+03	23200.00
62BEA0	2017-08-08 18:54:00+03	12200.00
62BEDB	2017-07-15 21:31:00+03	73600.00
62BEDC	2017-07-08 18:46:00+03	156600.00
62BFD4	2017-07-29 18:46:00+03	87900.00
62BFD5	2017-07-17 22:40:00+03	85000.00
62BFE6	2017-08-10 10:35:00+03	42200.00
62BFEB	2017-07-18 13:57:00+03	47400.00
62C011	2017-08-11 10:38:00+03	53700.00
62C119	2017-08-08 08:37:00+03	155600.00
62C164	2017-07-10 01:45:00+03	43800.00
62C170	2017-07-23 12:43:00+03	8200.00
62C193	2017-07-16 17:21:00+03	6000.00
62C214	2017-07-13 00:32:00+03	75300.00
62C216	2017-07-24 03:04:00+03	25400.00
62C22F	2017-08-11 08:06:00+03	35900.00
62C252	2017-07-28 17:14:00+03	56000.00
62C284	2017-08-11 07:08:00+03	114700.00
62C2A1	2017-08-09 23:10:00+03	66600.00
62C2A8	2017-07-14 16:47:00+03	36800.00
62C317	2017-08-01 19:34:00+03	11600.00
62C38F	2017-08-10 00:42:00+03	36200.00
62C3C4	2017-07-23 06:10:00+03	37200.00
62C3D7	2017-07-21 13:27:00+03	23600.00
62C4BA	2017-07-02 14:58:00+03	140900.00
62C519	2017-08-05 14:24:00+03	88600.00
62C536	2017-07-05 12:06:00+03	57500.00
62C590	2017-08-10 15:40:00+03	40600.00
62C5B8	2017-07-16 21:48:00+03	52700.00
62C61B	2017-08-12 14:21:00+03	86300.00
62C62F	2017-07-27 04:05:00+03	75300.00
62C630	2017-07-15 15:38:00+03	16400.00
62C67C	2017-08-10 23:29:00+03	11800.00
62C6F8	2017-07-23 19:01:00+03	187800.00
62C716	2017-07-23 02:33:00+03	132800.00
62C717	2017-07-14 17:01:00+03	82900.00
62C74A	2017-07-29 14:38:00+03	10700.00
62C74B	2017-07-22 08:44:00+03	51900.00
62C788	2017-08-02 18:40:00+03	81300.00
62C7E9	2017-07-21 07:09:00+03	21400.00
62C7FA	2017-08-11 01:56:00+03	43800.00
62C8A4	2017-08-03 08:13:00+03	46400.00
62C8E0	2017-07-18 06:42:00+03	29600.00
62C967	2017-07-21 23:43:00+03	48400.00
62C9A8	2017-07-17 10:13:00+03	26300.00
62C9CD	2017-07-27 22:23:00+03	447100.00
62CA16	2017-08-05 10:46:00+03	38600.00
62CA31	2017-07-22 17:52:00+03	79900.00
62CA51	2017-08-06 22:20:00+03	29500.00
62CA81	2017-08-15 08:38:00+03	266400.00
62CAC1	2017-08-05 13:20:00+03	73600.00
62CB06	2017-07-22 11:41:00+03	47400.00
62CB94	2017-08-03 13:13:00+03	147100.00
62CBC3	2017-08-09 20:06:00+03	28800.00
62CBEC	2017-07-29 20:39:00+03	65000.00
62CBFB	2017-08-13 20:17:00+03	43600.00
62CC18	2017-08-10 00:40:00+03	103500.00
62CCFD	2017-07-04 21:50:00+03	46000.00
62CD11	2017-06-28 18:45:00+03	81200.00
62CD97	2017-08-11 14:22:00+03	62900.00
62CD9A	2017-07-25 14:11:00+03	64700.00
62CDBC	2017-06-30 08:40:00+03	20400.00
62CDCB	2017-07-24 02:35:00+03	75600.00
62CDE6	2017-07-20 00:11:00+03	23200.00
62CDF6	2017-08-10 19:37:00+03	35600.00
62CE4A	2017-07-02 12:46:00+03	34000.00
62CE6E	2017-07-04 04:46:00+03	24700.00
62CE77	2017-08-04 15:50:00+03	37900.00
62CE94	2017-08-11 12:25:00+03	85000.00
62CEB9	2017-07-09 15:16:00+03	67200.00
62CEC8	2017-07-08 20:34:00+03	43200.00
62CEE6	2017-07-15 04:02:00+03	71200.00
62CF1F	2017-08-13 21:32:00+03	141500.00
62D012	2017-07-15 16:41:00+03	48700.00
62D01B	2017-07-10 21:47:00+03	21800.00
62D07B	2017-08-12 10:14:00+03	54300.00
62D087	2017-08-13 21:13:00+03	49800.00
62D0E6	2017-07-23 21:50:00+03	123000.00
62D123	2017-08-11 13:17:00+03	11700.00
62D196	2017-07-23 02:59:00+03	63900.00
62D1B7	2017-07-20 21:23:00+03	26000.00
62D1C3	2017-08-09 08:28:00+03	46800.00
62D273	2017-07-19 12:48:00+03	9200.00
62D2E8	2017-08-05 00:10:00+03	399800.00
62D320	2017-07-09 01:41:00+03	28800.00
62D354	2017-08-09 06:45:00+03	58800.00
62D36E	2017-07-18 06:07:00+03	52000.00
62D3AF	2017-07-08 18:31:00+03	6000.00
62D3D1	2017-07-09 03:51:00+03	39200.00
62D4B2	2017-08-09 01:29:00+03	8200.00
62D4C3	2017-08-10 02:57:00+03	6000.00
62D4D0	2017-08-06 11:13:00+03	22600.00
62D590	2017-08-05 23:27:00+03	111600.00
62D5A0	2017-07-05 14:08:00+03	54000.00
62D5A2	2017-08-04 00:09:00+03	28800.00
62D5D3	2017-08-11 09:59:00+03	137400.00
62D5D8	2017-07-18 08:07:00+03	265700.00
62D5F3	2017-07-26 15:10:00+03	113700.00
62D654	2017-08-13 14:47:00+03	137600.00
62D6A2	2017-08-05 07:26:00+03	117200.00
62D707	2017-08-11 11:57:00+03	80500.00
62D799	2017-08-05 02:38:00+03	88600.00
62D814	2017-07-04 11:11:00+03	67400.00
62D829	2017-07-01 14:34:00+03	43700.00
62D833	2017-07-23 18:10:00+03	31600.00
62D843	2017-07-22 06:18:00+03	8200.00
62D87F	2017-08-12 01:18:00+03	43600.00
62D884	2017-07-27 20:07:00+03	58200.00
62D88B	2017-07-14 04:32:00+03	9800.00
62D899	2017-07-03 20:54:00+03	40800.00
62D8A9	2017-08-13 12:43:00+03	120700.00
62D90E	2017-07-22 00:52:00+03	26000.00
62D934	2017-07-02 05:20:00+03	48500.00
62D94B	2017-07-07 19:14:00+03	138000.00
62D959	2017-08-12 12:24:00+03	28000.00
62D98B	2017-07-08 01:48:00+03	7300.00
62D9B9	2017-07-19 07:10:00+03	52700.00
62D9C9	2017-07-04 18:49:00+03	29600.00
62D9D9	2017-07-12 02:50:00+03	433100.00
62DA16	2017-08-04 00:46:00+03	62900.00
62DA57	2017-07-30 16:38:00+03	38400.00
62DABB	2017-08-13 17:43:00+03	20700.00
62DB42	2017-07-29 00:17:00+03	38600.00
62DBEC	2017-07-05 14:40:00+03	26200.00
62DC2E	2017-08-02 10:52:00+03	23100.00
62DC50	2017-07-10 06:33:00+03	10800.00
62DC67	2017-07-03 11:33:00+03	55800.00
62DC6F	2017-08-04 20:33:00+03	67200.00
62DC75	2017-07-01 07:59:00+03	55800.00
62DC85	2017-08-13 01:38:00+03	111600.00
62DC99	2017-08-03 13:53:00+03	51900.00
62DCE3	2017-07-09 13:52:00+03	156300.00
62DCF4	2017-07-04 10:11:00+03	46800.00
62DCFB	2017-07-13 13:15:00+03	339900.00
62DD57	2017-07-31 22:18:00+03	49500.00
62DDC4	2017-08-14 09:08:00+03	66600.00
62DDC5	2017-07-12 03:52:00+03	43800.00
62DDDC	2017-08-02 06:56:00+03	55800.00
62DDF3	2017-07-14 06:36:00+03	27700.00
62DE75	2017-07-26 07:25:00+03	28000.00
62DF4F	2017-07-08 17:37:00+03	70800.00
62DF81	2017-07-17 15:02:00+03	174000.00
62DFAD	2017-07-14 06:19:00+03	58600.00
62DFB2	2017-08-08 19:14:00+03	14800.00
62DFC5	2017-07-04 08:55:00+03	184300.00
62DFE0	2017-07-06 23:02:00+03	146000.00
62E005	2017-07-14 05:13:00+03	19600.00
62E034	2017-08-04 08:21:00+03	100500.00
62E047	2017-07-17 04:20:00+03	89700.00
62E057	2017-07-18 14:13:00+03	103500.00
62E059	2017-08-12 07:09:00+03	137100.00
62E05C	2017-07-18 12:44:00+03	114400.00
62E0BE	2017-07-12 00:47:00+03	101100.00
62E0E8	2017-07-30 22:08:00+03	22000.00
62E131	2017-08-09 01:46:00+03	135600.00
62E185	2017-07-30 01:08:00+03	24400.00
62E1D1	2017-07-31 07:57:00+03	14800.00
62E1E8	2017-08-15 09:58:00+03	23200.00
62E217	2017-07-27 04:35:00+03	258500.00
62E293	2017-08-03 18:25:00+03	33100.00
62E294	2017-08-07 21:08:00+03	70700.00
62E299	2017-08-01 00:20:00+03	16800.00
62E2D8	2017-07-30 09:06:00+03	69000.00
62E2E8	2017-06-25 02:55:00+03	16400.00
62E335	2017-07-22 01:37:00+03	26200.00
62E38D	2017-07-29 08:28:00+03	6000.00
62E3B1	2017-07-24 02:57:00+03	25100.00
62E455	2017-07-09 07:58:00+03	57500.00
62E456	2017-08-12 23:00:00+03	86400.00
62E46D	2017-08-06 13:53:00+03	57600.00
62E4BE	2017-06-27 01:54:00+03	81700.00
62E4E4	2017-07-26 13:27:00+03	14400.00
62E534	2017-07-08 10:59:00+03	106200.00
62E55B	2017-07-18 06:54:00+03	154400.00
62E598	2017-07-29 06:45:00+03	20600.00
62E5E8	2017-07-25 20:14:00+03	27800.00
62E62A	2017-08-10 01:57:00+03	167200.00
62E65D	2017-08-02 15:17:00+03	8000.00
62E70C	2017-07-04 22:20:00+03	52400.00
62E7AA	2017-08-11 00:01:00+03	100600.00
62E82E	2017-07-30 17:23:00+03	131100.00
62E857	2017-07-03 08:00:00+03	12600.00
62E85D	2017-08-14 18:59:00+03	56000.00
62E8C4	2017-07-08 17:00:00+03	38400.00
62E8CB	2017-07-03 04:44:00+03	67100.00
62E966	2017-08-03 21:21:00+03	75600.00
62E968	2017-07-08 12:46:00+03	99200.00
62EA02	2017-06-29 10:53:00+03	94100.00
62EA44	2017-07-06 17:25:00+03	12400.00
62EA69	2017-07-08 12:36:00+03	123000.00
62EAB3	2017-08-09 19:09:00+03	36200.00
62EB0E	2017-08-11 04:19:00+03	54000.00
62EB7B	2017-07-21 13:06:00+03	92800.00
62EB8B	2017-08-05 18:30:00+03	56600.00
62EBD8	2017-07-11 19:52:00+03	58900.00
62EBDA	2017-07-22 22:08:00+03	54500.00
62EC63	2017-07-04 05:51:00+03	234600.00
62EC98	2017-08-02 12:52:00+03	142800.00
62ECCF	2017-08-08 10:27:00+03	85700.00
62ECED	2017-07-01 13:06:00+03	59800.00
62ED59	2017-08-09 09:23:00+03	24400.00
62ED69	2017-08-04 17:48:00+03	69500.00
62ED6D	2017-08-13 19:48:00+03	19600.00
62ED7B	2017-08-11 09:44:00+03	28000.00
62ED92	2017-07-19 23:20:00+03	50600.00
62EE9B	2017-08-04 11:05:00+03	399600.00
62EEB1	2017-07-15 19:05:00+03	120900.00
62EEB8	2017-08-01 09:37:00+03	40000.00
62EED4	2017-07-01 09:18:00+03	119500.00
62EEEF	2017-08-01 15:01:00+03	89600.00
62EF90	2017-08-06 15:46:00+03	46200.00
62EF95	2017-07-21 08:19:00+03	23600.00
62F024	2017-08-03 06:45:00+03	42800.00
62F02B	2017-08-13 08:00:00+03	99200.00
62F05B	2017-08-02 20:41:00+03	59800.00
62F098	2017-07-08 16:52:00+03	132800.00
62F11C	2017-07-28 09:54:00+03	74400.00
62F16C	2017-08-13 08:03:00+03	266400.00
62F1A3	2017-07-31 06:24:00+03	17600.00
62F1C9	2017-07-27 22:28:00+03	98100.00
62F2D9	2017-08-14 04:25:00+03	43600.00
62F336	2017-06-29 10:36:00+03	36800.00
62F343	2017-07-16 18:20:00+03	207200.00
62F35C	2017-08-08 13:08:00+03	54800.00
62F3AD	2017-07-04 06:04:00+03	41900.00
62F3D1	2017-07-04 00:34:00+03	448400.00
62F431	2017-08-05 04:12:00+03	54500.00
62F442	2017-08-03 03:41:00+03	46700.00
62F466	2017-07-20 13:09:00+03	28800.00
62F476	2017-08-03 19:38:00+03	67200.00
62F49A	2017-07-10 09:13:00+03	135600.00
62F4A5	2017-08-05 19:40:00+03	133100.00
62F4E3	2017-07-01 21:39:00+03	173200.00
62F4EC	2017-08-12 02:04:00+03	97600.00
62F514	2017-07-12 11:26:00+03	63200.00
62F51E	2017-07-01 22:30:00+03	47600.00
62F590	2017-07-06 06:54:00+03	392700.00
62F5E1	2017-08-14 06:37:00+03	67700.00
62F5EF	2017-08-09 04:20:00+03	61700.00
62F611	2017-08-03 13:48:00+03	92800.00
62F639	2017-08-09 11:20:00+03	8800.00
62F63A	2017-08-03 14:49:00+03	37200.00
62F6C9	2017-08-10 23:50:00+03	24400.00
62F6FE	2017-07-22 01:37:00+03	182300.00
62F74F	2017-07-19 15:04:00+03	50600.00
62F75B	2017-08-02 11:42:00+03	93000.00
62F7A9	2017-07-15 16:03:00+03	23200.00
62F7E4	2017-07-05 03:35:00+03	30000.00
62F855	2017-07-18 15:17:00+03	69900.00
62F876	2017-07-17 16:42:00+03	62900.00
62F887	2017-07-31 20:43:00+03	153200.00
62F898	2017-07-31 10:58:00+03	179900.00
62F8A7	2017-07-23 03:28:00+03	102100.00
62F8D7	2017-08-04 11:52:00+03	16400.00
62F9AA	2017-07-08 23:42:00+03	131600.00
62FA18	2017-08-08 01:39:00+03	393800.00
62FAB7	2017-07-26 19:56:00+03	111600.00
62FB33	2017-07-11 17:52:00+03	32700.00
62FB47	2017-08-11 23:39:00+03	32200.00
62FB4D	2017-07-09 14:18:00+03	60900.00
62FB5C	2017-08-10 05:36:00+03	44700.00
62FB69	2017-07-28 18:07:00+03	94700.00
62FB9C	2017-08-10 11:08:00+03	213800.00
62FC0B	2017-08-12 02:12:00+03	35800.00
62FC39	2017-07-23 11:55:00+03	54800.00
62FC5C	2017-07-08 06:42:00+03	55800.00
62FC76	2017-07-21 10:28:00+03	23200.00
62FCEB	2017-07-27 23:44:00+03	48400.00
62FCF8	2017-07-18 14:55:00+03	56000.00
62FD19	2017-08-05 06:36:00+03	146300.00
62FD56	2017-08-01 16:05:00+03	66600.00
62FD95	2017-07-21 05:19:00+03	38800.00
62FE5F	2017-08-09 16:26:00+03	58400.00
62FE6B	2017-08-14 09:56:00+03	88800.00
62FF28	2017-08-10 18:01:00+03	155000.00
62FF59	2017-07-26 08:51:00+03	90100.00
62FF85	2017-07-11 14:29:00+03	114800.00
62FFD5	2017-07-19 11:33:00+03	25600.00
62FFE2	2017-07-12 03:39:00+03	34600.00
63001A	2017-07-23 22:00:00+03	94000.00
6300A0	2017-07-04 20:47:00+03	123000.00
63013F	2017-08-03 17:08:00+03	21600.00
630142	2017-07-12 11:58:00+03	46000.00
6301A3	2017-08-03 13:45:00+03	46400.00
6301AE	2017-07-28 03:57:00+03	153300.00
6302A2	2017-07-11 12:42:00+03	51000.00
6302B6	2017-07-24 12:00:00+03	66600.00
6302EB	2017-07-19 18:36:00+03	10800.00
630307	2017-07-01 14:51:00+03	377800.00
63033A	2017-07-05 20:04:00+03	14000.00
630373	2017-07-28 11:28:00+03	155600.00
6303EC	2017-07-16 12:02:00+03	55800.00
630410	2017-08-04 23:16:00+03	27800.00
6304F5	2017-08-11 01:17:00+03	56000.00
630532	2017-07-02 15:30:00+03	47600.00
63053C	2017-07-30 07:54:00+03	73300.00
630573	2017-07-22 23:33:00+03	40400.00
6305DA	2017-07-10 03:47:00+03	56900.00
6306B7	2017-07-18 11:03:00+03	33100.00
6306BB	2017-08-13 09:32:00+03	48500.00
6306F7	2017-07-06 13:19:00+03	80700.00
63072C	2017-07-10 08:20:00+03	51200.00
63075B	2017-08-13 14:24:00+03	14400.00
6307B9	2017-06-27 04:06:00+03	39200.00
6307F0	2017-08-05 17:07:00+03	176000.00
63083A	2017-08-15 13:20:00+03	93900.00
6308F2	2017-07-28 12:13:00+03	293700.00
6308FF	2017-07-26 04:18:00+03	91100.00
63090F	2017-08-05 10:18:00+03	134700.00
630910	2017-07-04 14:09:00+03	89600.00
63091C	2017-07-19 19:17:00+03	66100.00
630962	2017-08-03 03:37:00+03	23400.00
63097F	2017-08-10 20:35:00+03	83100.00
630982	2017-08-06 09:58:00+03	26000.00
6309EB	2017-06-29 16:32:00+03	59100.00
630A6D	2017-07-25 11:28:00+03	26700.00
630AAF	2017-08-13 22:00:00+03	28000.00
630AE9	2017-08-15 14:02:00+03	103200.00
630AFB	2017-07-30 18:17:00+03	43800.00
630B3D	2017-07-09 18:30:00+03	91100.00
630B69	2017-07-10 18:28:00+03	88800.00
630B77	2017-07-23 17:26:00+03	123000.00
630BAB	2017-08-08 13:01:00+03	56600.00
630BB0	2017-07-23 08:10:00+03	277900.00
630BD9	2017-07-26 05:54:00+03	28000.00
630C0D	2017-07-26 07:22:00+03	55500.00
630C18	2017-07-21 21:45:00+03	46400.00
630CA4	2017-07-13 02:44:00+03	14400.00
630D33	2017-07-10 02:18:00+03	14000.00
630D45	2017-08-01 23:37:00+03	57400.00
630DAF	2017-07-14 09:22:00+03	25600.00
630DCF	2017-07-28 19:57:00+03	47000.00
630E8D	2017-08-11 23:19:00+03	70200.00
630EA7	2017-07-28 05:59:00+03	67600.00
630EFF	2017-07-30 04:27:00+03	225200.00
630F41	2017-07-13 21:32:00+03	40800.00
630F92	2017-08-13 00:14:00+03	35200.00
630FA1	2017-07-02 14:01:00+03	44600.00
630FA8	2017-08-02 16:32:00+03	83000.00
630FCC	2017-07-31 12:07:00+03	68400.00
630FF9	2017-07-27 00:51:00+03	68000.00
63109A	2017-07-16 21:00:00+03	50800.00
6310E4	2017-07-20 03:00:00+03	53600.00
631156	2017-07-06 20:27:00+03	68400.00
631177	2017-08-08 08:59:00+03	24600.00
6311C8	2017-07-05 21:18:00+03	21400.00
6311E5	2017-07-02 20:48:00+03	190400.00
63126E	2017-07-11 05:08:00+03	6200.00
6312BC	2017-08-13 05:42:00+03	25200.00
6312C3	2017-07-14 13:07:00+03	51800.00
6312ED	2017-07-06 00:47:00+03	72300.00
63130F	2017-08-09 17:17:00+03	23200.00
631315	2017-07-12 07:59:00+03	297600.00
6313F2	2017-07-25 07:35:00+03	256400.00
63148B	2017-08-01 21:10:00+03	16400.00
631519	2017-07-04 13:51:00+03	32900.00
631539	2017-07-04 13:28:00+03	68400.00
631580	2017-08-15 13:57:00+03	213200.00
631592	2017-07-05 21:12:00+03	40400.00
6315EA	2017-07-07 04:30:00+03	14000.00
6315FD	2017-07-17 02:09:00+03	96700.00
631609	2017-08-14 09:33:00+03	136800.00
63164C	2017-07-09 22:03:00+03	24600.00
631667	2017-08-03 09:16:00+03	43200.00
63167B	2017-08-07 16:38:00+03	56000.00
631686	2017-07-23 06:21:00+03	13600.00
63168A	2017-08-03 07:36:00+03	163900.00
6316B0	2017-08-11 00:44:00+03	148200.00
6316F0	2017-07-13 11:59:00+03	94700.00
63170E	2017-08-15 09:26:00+03	14000.00
631710	2017-08-07 16:00:00+03	52800.00
631745	2017-07-28 01:31:00+03	11800.00
63182B	2017-08-11 15:55:00+03	82400.00
631830	2017-06-30 17:24:00+03	87100.00
631856	2017-07-22 11:31:00+03	40600.00
6318BD	2017-07-05 22:38:00+03	46700.00
6318C5	2017-07-31 07:24:00+03	81800.00
6318EE	2017-08-01 01:04:00+03	202100.00
631909	2017-07-27 04:06:00+03	85000.00
63191C	2017-07-16 13:56:00+03	55800.00
63192D	2017-07-08 22:19:00+03	124500.00
63199D	2017-06-29 22:33:00+03	88100.00
6319F7	2017-07-26 22:15:00+03	100600.00
631A3B	2017-07-16 19:06:00+03	23600.00
631A9C	2017-07-30 06:50:00+03	542100.00
631ADF	2017-07-16 02:52:00+03	68700.00
631B1D	2017-08-01 06:04:00+03	22600.00
631B38	2017-07-15 08:10:00+03	170800.00
631B42	2017-07-05 20:46:00+03	28000.00
631C62	2017-08-08 05:49:00+03	38800.00
631CB1	2017-07-08 01:55:00+03	301800.00
631CB5	2017-07-08 08:36:00+03	42000.00
631CF7	2017-08-04 21:38:00+03	86500.00
631D10	2017-06-29 04:38:00+03	83600.00
631D96	2017-08-09 13:04:00+03	23200.00
631DCA	2017-07-27 22:08:00+03	132800.00
631DD1	2017-07-07 06:27:00+03	79000.00
631EEC	2017-07-26 09:55:00+03	117500.00
631FC8	2017-07-02 01:44:00+03	85000.00
631FFD	2017-08-14 15:34:00+03	37600.00
632001	2017-07-16 20:07:00+03	7400.00
632049	2017-07-04 06:38:00+03	26800.00
632122	2017-07-08 08:42:00+03	65500.00
63216A	2017-07-03 18:37:00+03	50300.00
63216C	2017-08-07 03:32:00+03	16400.00
632181	2017-08-12 09:19:00+03	369000.00
632230	2017-07-14 17:48:00+03	64900.00
6322BF	2017-08-13 03:10:00+03	19600.00
6322D0	2017-08-07 01:04:00+03	101200.00
632322	2017-08-04 01:02:00+03	40400.00
632381	2017-07-09 20:48:00+03	25400.00
6323E1	2017-07-23 07:52:00+03	48800.00
632429	2017-07-02 08:30:00+03	95200.00
632498	2017-07-07 07:56:00+03	101200.00
6324B1	2017-07-15 02:19:00+03	132300.00
6324DE	2017-08-09 19:07:00+03	246000.00
63252D	2017-07-20 04:57:00+03	28600.00
632530	2017-07-25 03:04:00+03	255900.00
63256B	2017-08-13 16:18:00+03	124000.00
63257D	2017-08-02 23:44:00+03	26000.00
632652	2017-07-21 09:22:00+03	11600.00
6326A2	2017-07-26 08:25:00+03	67200.00
6326A3	2017-07-14 12:37:00+03	399600.00
6326B5	2017-08-03 11:46:00+03	258400.00
632721	2017-07-09 12:05:00+03	12400.00
632779	2017-07-30 19:12:00+03	57400.00
632780	2017-07-30 16:32:00+03	72400.00
632782	2017-08-04 15:39:00+03	36800.00
6327E4	2017-08-14 11:19:00+03	189800.00
6327ED	2017-07-08 04:06:00+03	43000.00
632815	2017-07-23 13:08:00+03	44800.00
63282D	2017-07-07 20:37:00+03	199700.00
63284D	2017-08-12 17:19:00+03	34300.00
6328CA	2017-08-15 00:47:00+03	89800.00
6328FE	2017-08-13 00:54:00+03	12200.00
632919	2017-07-17 06:21:00+03	84300.00
632934	2017-07-17 08:11:00+03	24300.00
632979	2017-07-06 05:29:00+03	26800.00
632980	2017-07-25 19:30:00+03	223200.00
63298C	2017-07-13 04:01:00+03	179400.00
6329CE	2017-08-08 16:01:00+03	71400.00
632A0B	2017-08-05 08:59:00+03	62000.00
632A29	2017-07-16 20:33:00+03	147100.00
632A66	2017-08-10 11:54:00+03	25200.00
632A79	2017-08-13 23:36:00+03	75300.00
632AB2	2017-07-06 17:58:00+03	128800.00
632AD7	2017-08-08 19:24:00+03	36100.00
632B2D	2017-08-01 05:57:00+03	44500.00
632B36	2017-07-03 18:17:00+03	73500.00
632B69	2017-07-07 05:26:00+03	6800.00
632B7A	2017-07-27 06:09:00+03	43900.00
632B7D	2017-07-10 19:30:00+03	265600.00
632B96	2017-07-26 20:26:00+03	179200.00
632BC8	2017-07-22 22:37:00+03	248300.00
632C30	2017-08-14 08:47:00+03	136100.00
632C31	2017-07-01 05:35:00+03	81700.00
632C39	2017-07-01 14:08:00+03	13400.00
632C4B	2017-08-11 00:54:00+03	150600.00
632CBC	2017-07-12 14:44:00+03	12000.00
632D26	2017-07-12 23:23:00+03	48200.00
632D2D	2017-07-16 16:26:00+03	98400.00
632D64	2017-07-11 23:11:00+03	113700.00
632D82	2017-07-24 00:55:00+03	213800.00
632DE9	2017-08-08 18:20:00+03	41800.00
632E3B	2017-07-10 13:33:00+03	50100.00
632E49	2017-07-09 01:52:00+03	6400.00
632E7A	2017-07-08 21:32:00+03	138900.00
632EA9	2017-07-21 11:14:00+03	83300.00
632ED3	2017-07-31 11:03:00+03	55800.00
632F05	2017-08-01 19:21:00+03	109600.00
632F07	2017-08-07 11:31:00+03	27400.00
632F26	2017-06-30 08:08:00+03	66600.00
632F3F	2017-08-13 13:45:00+03	45200.00
632F5D	2017-07-27 15:01:00+03	59800.00
632FD7	2017-07-19 16:52:00+03	92000.00
632FF2	2017-08-06 04:55:00+03	78200.00
633007	2017-08-08 19:05:00+03	16400.00
6330AF	2017-07-03 12:37:00+03	59800.00
6330D6	2017-06-30 05:03:00+03	20200.00
6330EE	2017-07-19 13:22:00+03	75600.00
633140	2017-08-02 11:21:00+03	63300.00
633189	2017-07-30 23:06:00+03	106200.00
6331CC	2017-07-05 05:34:00+03	170700.00
633306	2017-08-04 03:09:00+03	58100.00
63333D	2017-07-19 09:52:00+03	149000.00
63338A	2017-07-23 09:58:00+03	13400.00
63339D	2017-08-11 22:37:00+03	34000.00
6333AA	2017-08-05 01:03:00+03	111600.00
633463	2017-07-20 10:39:00+03	139100.00
6334B8	2017-08-15 06:03:00+03	29200.00
633541	2017-07-18 06:08:00+03	31600.00
633569	2017-08-08 09:46:00+03	13400.00
63357E	2017-06-27 08:11:00+03	229000.00
6335AB	2017-07-26 03:44:00+03	197000.00
63365E	2017-07-11 02:04:00+03	133100.00
633671	2017-07-19 19:02:00+03	92100.00
63368F	2017-08-08 23:09:00+03	56100.00
63369C	2017-07-29 20:25:00+03	40800.00
6336A8	2017-07-13 13:29:00+03	70000.00
6336C8	2017-07-27 03:11:00+03	49100.00
633703	2017-07-27 07:21:00+03	24400.00
633723	2017-07-13 03:11:00+03	28000.00
63373B	2017-08-11 20:08:00+03	18000.00
63374F	2017-08-15 15:31:00+03	34300.00
6337A8	2017-07-13 04:12:00+03	48700.00
633807	2017-07-02 22:39:00+03	48800.00
633831	2017-07-21 11:03:00+03	75600.00
63383B	2017-08-04 14:45:00+03	27200.00
633846	2017-08-03 11:01:00+03	58600.00
633883	2017-07-18 18:51:00+03	86400.00
633917	2017-07-08 18:12:00+03	78500.00
633931	2017-07-02 12:46:00+03	43500.00
633981	2017-08-07 21:15:00+03	7200.00
633982	2017-07-29 11:33:00+03	398500.00
63398F	2017-07-28 14:28:00+03	28800.00
6339C7	2017-07-05 08:58:00+03	112000.00
6339ED	2017-08-01 18:22:00+03	38600.00
633A46	2017-08-08 23:51:00+03	262600.00
633A9B	2017-07-24 16:32:00+03	177200.00
633AA4	2017-07-24 17:03:00+03	20000.00
633B00	2017-08-08 06:04:00+03	44500.00
633B0F	2017-07-28 04:14:00+03	167400.00
633B34	2017-08-14 19:10:00+03	44300.00
633B4D	2017-07-15 14:03:00+03	66600.00
633B71	2017-08-13 04:39:00+03	46200.00
633B7C	2017-08-13 07:08:00+03	226400.00
633BEE	2017-07-12 07:55:00+03	54000.00
633BF9	2017-07-11 01:08:00+03	52800.00
633C23	2017-08-09 14:16:00+03	23200.00
633C7C	2017-08-06 06:15:00+03	119500.00
633C90	2017-07-04 00:52:00+03	46000.00
633CD6	2017-07-29 06:49:00+03	48700.00
633D44	2017-08-10 09:22:00+03	61400.00
633D97	2017-07-23 11:37:00+03	272300.00
633DA4	2017-07-10 19:03:00+03	81300.00
633DBA	2017-08-11 19:13:00+03	224000.00
633DD0	2017-07-05 04:31:00+03	78000.00
633DF1	2017-07-11 16:22:00+03	40400.00
633E0E	2017-07-03 16:58:00+03	26000.00
633EA3	2017-08-10 21:26:00+03	54400.00
633EB9	2017-07-08 12:00:00+03	35600.00
633EED	2017-07-17 19:10:00+03	233800.00
633F34	2017-07-25 16:31:00+03	73500.00
633F8B	2017-08-06 01:51:00+03	69900.00
633F9B	2017-08-10 13:27:00+03	43600.00
633FAE	2017-07-27 14:34:00+03	109600.00
633FC0	2017-08-03 01:12:00+03	74900.00
63404A	2017-07-19 14:11:00+03	165500.00
63404D	2017-07-20 01:49:00+03	28000.00
63406B	2017-08-04 11:55:00+03	58800.00
6340EF	2017-07-23 12:46:00+03	26000.00
634107	2017-07-27 06:31:00+03	75600.00
63411D	2017-07-28 21:43:00+03	8200.00
634157	2017-07-18 21:56:00+03	42800.00
63418D	2017-08-09 10:16:00+03	42700.00
6341BF	2017-08-11 04:53:00+03	38500.00
6341C5	2017-07-01 23:44:00+03	22000.00
6341CC	2017-07-27 11:25:00+03	171000.00
634329	2017-07-04 23:28:00+03	61800.00
63438F	2017-07-06 19:01:00+03	52800.00
634393	2017-08-15 13:31:00+03	28000.00
6343C5	2017-07-13 01:52:00+03	28000.00
6343ED	2017-07-11 22:17:00+03	44700.00
634401	2017-07-11 06:43:00+03	48300.00
634443	2017-07-09 01:00:00+03	95000.00
63445C	2017-08-06 16:46:00+03	52900.00
634484	2017-07-04 22:17:00+03	23200.00
6344B2	2017-06-27 04:10:00+03	13600.00
634541	2017-07-20 21:53:00+03	26700.00
634574	2017-07-04 03:01:00+03	75600.00
634592	2017-07-07 20:53:00+03	24400.00
634598	2017-08-13 06:11:00+03	259000.00
634615	2017-08-13 18:18:00+03	59800.00
634660	2017-08-02 14:01:00+03	60400.00
6346D0	2017-07-13 00:50:00+03	55900.00
6346EE	2017-07-25 14:09:00+03	24400.00
634721	2017-08-08 09:12:00+03	202300.00
634738	2017-07-08 21:52:00+03	36200.00
63473B	2017-06-29 14:07:00+03	65600.00
634789	2017-07-29 14:40:00+03	20400.00
6347A2	2017-07-19 20:44:00+03	179200.00
634828	2017-07-01 12:06:00+03	79800.00
63483F	2017-07-17 04:42:00+03	35200.00
6348AD	2017-07-02 02:12:00+03	135400.00
6348D7	2017-08-05 15:51:00+03	66400.00
6348E7	2017-07-16 16:40:00+03	34000.00
6348F9	2017-07-13 13:56:00+03	108000.00
634977	2017-07-31 09:00:00+03	64600.00
6349CA	2017-07-19 22:32:00+03	46000.00
6349F7	2017-07-19 03:36:00+03	29300.00
634A12	2017-08-12 08:08:00+03	11600.00
634A1D	2017-08-13 03:46:00+03	22600.00
634A20	2017-08-08 22:01:00+03	19600.00
634A6E	2017-07-21 19:58:00+03	36200.00
634A7D	2017-07-25 11:02:00+03	99600.00
634B97	2017-08-03 11:36:00+03	136500.00
634BFB	2017-07-31 18:22:00+03	55800.00
634C4A	2017-07-11 08:19:00+03	797100.00
634C54	2017-07-08 13:50:00+03	48600.00
634C72	2017-07-19 15:56:00+03	23600.00
634C74	2017-07-13 01:49:00+03	27200.00
634CBB	2017-06-30 15:19:00+03	24400.00
634CCE	2017-08-04 07:42:00+03	28000.00
634CD6	2017-07-02 08:59:00+03	24400.00
634D19	2017-07-02 03:51:00+03	101200.00
634D73	2017-07-05 18:51:00+03	44600.00
634E3A	2017-07-15 17:55:00+03	78200.00
634EAA	2017-07-29 21:17:00+03	115900.00
634EC6	2017-08-09 22:39:00+03	284400.00
634EF8	2017-07-07 03:58:00+03	151200.00
634F4F	2017-07-22 21:23:00+03	56300.00
634FB9	2017-07-03 08:36:00+03	29400.00
63502F	2017-08-13 07:36:00+03	7200.00
635084	2017-07-26 09:47:00+03	46400.00
63509B	2017-08-15 06:56:00+03	24000.00
6350FA	2017-07-08 08:28:00+03	26800.00
63510A	2017-07-27 05:39:00+03	10800.00
635119	2017-08-06 11:20:00+03	58400.00
63519A	2017-07-05 22:35:00+03	13600.00
6351BE	2017-07-08 22:26:00+03	46000.00
63530F	2017-07-22 06:50:00+03	28000.00
635313	2017-08-06 02:47:00+03	65500.00
635320	2017-08-02 08:22:00+03	66800.00
635341	2017-08-06 08:59:00+03	92000.00
635347	2017-07-21 13:06:00+03	92700.00
635375	2017-08-05 17:39:00+03	173200.00
63539E	2017-07-11 21:08:00+03	40400.00
6353E2	2017-07-09 15:05:00+03	65200.00
6353F0	2017-07-19 08:23:00+03	34800.00
6353F6	2017-08-13 13:33:00+03	46400.00
6353F8	2017-07-20 11:04:00+03	111300.00
635419	2017-06-29 20:00:00+03	40800.00
635420	2017-07-08 04:01:00+03	16400.00
635488	2017-07-19 10:06:00+03	94000.00
6354A9	2017-07-26 20:49:00+03	69400.00
6354D4	2017-08-13 16:07:00+03	31200.00
6354DB	2017-08-03 05:59:00+03	112600.00
635519	2017-07-25 09:51:00+03	21800.00
63556E	2017-07-20 08:35:00+03	78800.00
6355AD	2017-08-07 19:21:00+03	190300.00
6355EE	2017-07-05 03:11:00+03	23200.00
635604	2017-07-22 23:45:00+03	83100.00
635614	2017-07-11 21:06:00+03	62900.00
63565E	2017-06-28 21:10:00+03	135200.00
635663	2017-07-18 18:20:00+03	62600.00
63568F	2017-07-08 19:20:00+03	34400.00
6356B5	2017-06-29 23:40:00+03	67600.00
635727	2017-07-22 00:19:00+03	187600.00
635774	2017-07-29 04:49:00+03	135800.00
6357E5	2017-07-03 22:51:00+03	48800.00
6357EE	2017-08-03 16:24:00+03	55500.00
6357F8	2017-07-19 18:32:00+03	113700.00
63581A	2017-07-03 18:36:00+03	46400.00
635826	2017-08-07 10:51:00+03	38600.00
635891	2017-08-01 00:58:00+03	23600.00
635894	2017-08-10 03:39:00+03	49100.00
6358BC	2017-08-09 03:26:00+03	14000.00
635934	2017-07-22 01:16:00+03	42800.00
63596E	2017-07-31 05:20:00+03	48800.00
6359A1	2017-07-09 08:35:00+03	46400.00
635A24	2017-08-08 01:00:00+03	41600.00
635A82	2017-08-02 23:32:00+03	25100.00
635AA1	2017-08-14 10:22:00+03	28800.00
635B09	2017-07-28 09:42:00+03	146000.00
635B86	2017-07-26 17:42:00+03	92800.00
635BDD	2017-08-11 06:01:00+03	122700.00
635C1E	2017-06-30 10:17:00+03	106200.00
635C2E	2017-08-08 19:12:00+03	32800.00
635C49	2017-07-23 21:35:00+03	43200.00
635C4E	2017-07-14 20:48:00+03	25800.00
635CA3	2017-07-12 04:00:00+03	66600.00
635D25	2017-07-21 04:32:00+03	20200.00
635D7D	2017-07-16 06:53:00+03	413400.00
635D90	2017-08-14 17:31:00+03	61500.00
635DB9	2017-08-11 10:58:00+03	14000.00
635DD0	2017-07-12 13:34:00+03	229500.00
635DE7	2017-07-04 00:20:00+03	95600.00
635E1F	2017-07-18 20:15:00+03	78400.00
635E56	2017-07-09 08:02:00+03	137600.00
635E70	2017-08-14 05:04:00+03	8000.00
635F47	2017-07-09 01:54:00+03	40600.00
635F66	2017-08-06 12:19:00+03	184200.00
635F6C	2017-07-02 06:56:00+03	26000.00
635FAD	2017-07-26 21:10:00+03	131600.00
635FCD	2017-07-31 03:34:00+03	66000.00
635FD1	2017-07-25 11:52:00+03	31400.00
636004	2017-08-10 18:52:00+03	84000.00
636015	2017-07-11 06:13:00+03	25200.00
636021	2017-08-07 19:48:00+03	81700.00
63603D	2017-08-05 00:04:00+03	81600.00
63605D	2017-08-13 03:10:00+03	41500.00
636086	2017-07-01 18:27:00+03	65800.00
636093	2017-07-14 09:03:00+03	112000.00
6360A0	2017-08-05 19:53:00+03	257600.00
636114	2017-07-06 21:02:00+03	6300.00
63617B	2017-08-12 08:12:00+03	21800.00
6361C6	2017-07-18 17:22:00+03	248400.00
636211	2017-06-29 11:57:00+03	27700.00
636233	2017-08-13 15:35:00+03	43400.00
636267	2017-07-10 01:01:00+03	128800.00
6362A3	2017-07-16 06:12:00+03	168700.00
636305	2017-07-26 01:37:00+03	13600.00
63632F	2017-07-15 02:59:00+03	28000.00
63637E	2017-08-01 18:23:00+03	61300.00
6363C3	2017-07-14 02:56:00+03	134400.00
636437	2017-07-27 08:29:00+03	20200.00
636443	2017-07-08 22:40:00+03	68800.00
63644E	2017-07-31 05:36:00+03	38400.00
636457	2017-08-07 01:38:00+03	13600.00
636459	2017-07-29 13:29:00+03	136200.00
6364CB	2017-07-31 14:04:00+03	31600.00
63654B	2017-07-24 07:04:00+03	56900.00
636550	2017-08-09 02:24:00+03	132800.00
63658C	2017-08-10 09:08:00+03	119900.00
6365AC	2017-07-16 11:21:00+03	31500.00
6365CA	2017-07-22 02:18:00+03	19600.00
636604	2017-08-13 07:36:00+03	46300.00
63661F	2017-07-06 01:34:00+03	20000.00
636624	2017-06-29 03:04:00+03	19600.00
636643	2017-07-28 14:33:00+03	8400.00
6366A8	2017-07-16 20:21:00+03	44000.00
6366F5	2017-07-03 18:32:00+03	53400.00
636709	2017-06-29 04:42:00+03	131800.00
636803	2017-07-19 12:55:00+03	42700.00
636818	2017-08-14 16:53:00+03	23600.00
636820	2017-07-16 11:35:00+03	44000.00
6368B9	2017-07-12 02:15:00+03	170700.00
636928	2017-08-10 12:42:00+03	132800.00
6369A4	2017-07-25 04:19:00+03	77200.00
6369A8	2017-08-07 18:16:00+03	28800.00
636A24	2017-07-17 21:26:00+03	44000.00
636A30	2017-07-19 14:33:00+03	35200.00
636A53	2017-08-02 00:16:00+03	28000.00
636A6D	2017-08-10 02:46:00+03	54800.00
636AFA	2017-07-22 18:04:00+03	113700.00
636B66	2017-07-08 09:09:00+03	23200.00
636B97	2017-07-01 17:11:00+03	73500.00
636BF0	2017-07-04 06:23:00+03	50900.00
636C72	2017-08-07 10:10:00+03	112000.00
636C83	2017-08-07 13:18:00+03	51900.00
636CAF	2017-07-23 14:12:00+03	40400.00
636CB2	2017-07-28 13:12:00+03	393000.00
636D24	2017-08-09 18:08:00+03	48800.00
636D8B	2017-08-11 12:14:00+03	15100.00
636D9D	2017-07-30 23:50:00+03	69600.00
636DB1	2017-08-01 09:53:00+03	73600.00
636DB6	2017-07-23 14:01:00+03	24800.00
636E3D	2017-07-03 14:40:00+03	69700.00
636E79	2017-08-12 00:23:00+03	39500.00
636E81	2017-06-27 19:04:00+03	46000.00
636E9D	2017-08-09 09:23:00+03	6800.00
636F1D	2017-07-08 21:11:00+03	36800.00
636F72	2017-07-17 11:34:00+03	32900.00
636FB9	2017-07-25 21:12:00+03	70600.00
636FF7	2017-08-09 13:46:00+03	16400.00
63701B	2017-07-08 12:11:00+03	28000.00
637074	2017-07-12 16:05:00+03	77900.00
637081	2017-07-06 19:54:00+03	30200.00
6370F8	2017-07-24 18:03:00+03	38800.00
63714B	2017-08-14 15:22:00+03	94000.00
6371B6	2017-07-16 18:17:00+03	293700.00
6371D8	2017-08-02 00:26:00+03	44000.00
6371E2	2017-07-17 14:37:00+03	32400.00
63729E	2017-07-27 01:39:00+03	26000.00
637341	2017-07-19 05:30:00+03	444000.00
637372	2017-07-20 22:05:00+03	92000.00
63738D	2017-07-31 01:30:00+03	72400.00
6373EA	2017-07-06 03:23:00+03	36400.00
637439	2017-07-20 17:08:00+03	271200.00
63743B	2017-08-14 23:07:00+03	56000.00
637449	2017-08-05 10:00:00+03	51600.00
63747C	2017-08-12 09:11:00+03	36900.00
6374CE	2017-08-09 06:43:00+03	59700.00
63750A	2017-07-20 06:11:00+03	9800.00
63750B	2017-06-29 07:11:00+03	131600.00
637542	2017-08-10 11:40:00+03	66600.00
637593	2017-08-15 08:14:00+03	67800.00
637594	2017-07-09 21:29:00+03	36100.00
637598	2017-07-17 19:06:00+03	40800.00
6375A9	2017-08-13 10:52:00+03	6300.00
6375EF	2017-07-28 14:11:00+03	56600.00
637612	2017-07-29 17:42:00+03	232900.00
63761C	2017-08-14 02:36:00+03	36800.00
6376A5	2017-07-30 19:46:00+03	38800.00
6376D4	2017-08-13 15:14:00+03	85000.00
6376D7	2017-08-04 23:14:00+03	6000.00
6377E0	2017-08-09 22:24:00+03	192400.00
637856	2017-07-18 05:04:00+03	135000.00
637864	2017-08-07 21:33:00+03	131100.00
63788A	2017-07-09 11:42:00+03	16400.00
63790A	2017-07-30 23:54:00+03	246000.00
63791D	2017-08-04 06:26:00+03	99200.00
6379E5	2017-08-10 21:15:00+03	29100.00
637A1C	2017-07-26 00:39:00+03	59000.00
637A31	2017-07-25 04:57:00+03	131100.00
637A68	2017-07-13 22:12:00+03	68100.00
637AFD	2017-08-02 19:45:00+03	135200.00
637B18	2017-07-08 20:04:00+03	56100.00
637B2D	2017-07-18 10:22:00+03	92800.00
637B94	2017-08-13 08:54:00+03	87900.00
637C38	2017-07-16 14:08:00+03	124400.00
637C9E	2017-08-14 23:08:00+03	33600.00
637CA0	2017-08-15 00:42:00+03	64700.00
637D09	2017-08-02 20:34:00+03	38800.00
637D0E	2017-07-09 01:22:00+03	136200.00
637D3B	2017-07-04 12:33:00+03	52900.00
637D6B	2017-07-09 06:06:00+03	46700.00
637D8A	2017-07-04 10:59:00+03	42800.00
637DE2	2017-07-17 10:00:00+03	28300.00
637DEE	2017-07-23 21:41:00+03	38400.00
637E6C	2017-07-20 18:25:00+03	7200.00
637EAA	2017-07-12 15:17:00+03	15000.00
637F2E	2017-07-31 20:16:00+03	55600.00
637F5A	2017-07-18 03:24:00+03	38200.00
637F8B	2017-07-24 19:33:00+03	26700.00
637FAF	2017-07-16 08:15:00+03	165500.00
637FEE	2017-08-04 22:36:00+03	155600.00
63805F	2017-08-03 20:16:00+03	58800.00
63807E	2017-07-23 21:50:00+03	133200.00
6380B6	2017-07-11 00:59:00+03	68400.00
6380C6	2017-07-29 23:42:00+03	236700.00
638100	2017-07-29 15:54:00+03	44600.00
63813C	2017-07-27 01:10:00+03	18000.00
6381BF	2017-06-28 19:42:00+03	104800.00
63820D	2017-07-06 21:18:00+03	49900.00
638237	2017-07-17 00:58:00+03	13200.00
63826D	2017-08-04 15:31:00+03	46200.00
638391	2017-07-21 04:10:00+03	40000.00
6383CC	2017-07-23 21:23:00+03	293700.00
6383CF	2017-07-19 08:38:00+03	43800.00
6383E6	2017-08-11 22:57:00+03	28800.00
638419	2017-07-20 20:05:00+03	57700.00
6384CB	2017-07-23 04:55:00+03	65000.00
6384DB	2017-08-04 15:24:00+03	353600.00
63858D	2017-07-29 22:52:00+03	6800.00
6385A9	2017-08-04 16:04:00+03	42000.00
63861E	2017-07-26 05:54:00+03	28000.00
638645	2017-07-15 03:12:00+03	295400.00
638665	2017-07-31 10:06:00+03	133200.00
6386D7	2017-07-30 09:55:00+03	81900.00
6386E1	2017-08-04 18:17:00+03	73500.00
6386E2	2017-07-22 01:12:00+03	19800.00
638727	2017-08-12 13:29:00+03	47000.00
63872B	2017-07-15 15:02:00+03	186000.00
638740	2017-08-14 16:53:00+03	32200.00
63883E	2017-08-09 15:06:00+03	58000.00
63885C	2017-08-10 17:09:00+03	118900.00
638871	2017-07-01 12:56:00+03	51300.00
63888C	2017-07-24 17:28:00+03	28700.00
638897	2017-08-08 19:39:00+03	78200.00
6388A1	2017-07-03 16:04:00+03	24700.00
6388D8	2017-07-01 01:47:00+03	283100.00
6388E6	2017-08-02 11:15:00+03	8400.00
638939	2017-07-27 17:03:00+03	80000.00
63893F	2017-07-31 18:15:00+03	56000.00
63894C	2017-07-21 04:31:00+03	43600.00
638979	2017-08-07 06:13:00+03	111600.00
6389B2	2017-08-04 22:14:00+03	55800.00
6389CD	2017-07-23 14:55:00+03	133100.00
6389EF	2017-07-17 15:12:00+03	7400.00
6389F0	2017-07-25 13:23:00+03	102100.00
6389FB	2017-06-28 06:35:00+03	12400.00
638AC1	2017-06-29 17:10:00+03	45000.00
638B0A	2017-08-04 19:49:00+03	202100.00
638B32	2017-07-08 14:37:00+03	60100.00
638B47	2017-07-31 01:04:00+03	58600.00
638B67	2017-07-14 09:43:00+03	93900.00
638BEA	2017-08-03 15:47:00+03	56000.00
638C10	2017-07-26 10:34:00+03	30100.00
638C11	2017-08-10 15:25:00+03	210900.00
638C59	2017-07-19 14:25:00+03	64500.00
638C67	2017-08-06 17:36:00+03	114400.00
638CC3	2017-07-08 13:13:00+03	76600.00
638CCE	2017-07-31 00:48:00+03	67200.00
638CD5	2017-07-23 10:50:00+03	57600.00
638D24	2017-08-02 05:23:00+03	78300.00
638D56	2017-08-13 07:58:00+03	88600.00
638DA1	2017-07-15 14:24:00+03	61800.00
638E98	2017-07-18 00:58:00+03	52300.00
638EA8	2017-07-05 00:51:00+03	94000.00
638F95	2017-08-14 01:17:00+03	38800.00
6390E0	2017-07-23 12:34:00+03	50200.00
6390FA	2017-08-04 08:17:00+03	127100.00
6391BA	2017-08-06 01:03:00+03	6400.00
639201	2017-08-09 11:13:00+03	27400.00
6392F0	2017-07-06 11:03:00+03	45700.00
639335	2017-08-09 15:13:00+03	169900.00
639345	2017-08-11 19:53:00+03	133200.00
6393A5	2017-07-11 05:10:00+03	94400.00
6393C3	2017-07-10 14:20:00+03	46400.00
6393FF	2017-07-28 17:36:00+03	6700.00
639455	2017-07-06 20:21:00+03	86400.00
639498	2017-07-04 10:17:00+03	123000.00
6394E8	2017-07-06 14:45:00+03	24400.00
63950F	2017-07-03 17:56:00+03	14000.00
639556	2017-08-10 11:17:00+03	42800.00
63960B	2017-07-09 00:53:00+03	67200.00
639695	2017-07-17 08:46:00+03	23600.00
6396DF	2017-08-02 21:59:00+03	84000.00
6396E4	2017-08-10 05:06:00+03	16400.00
6396F9	2017-08-08 15:34:00+03	68000.00
63973A	2017-07-22 15:20:00+03	78500.00
639769	2017-08-10 10:20:00+03	57400.00
6397AB	2017-07-02 08:59:00+03	29600.00
6397E5	2017-08-09 02:32:00+03	46200.00
6397F3	2017-07-18 18:06:00+03	44800.00
639812	2017-08-09 02:58:00+03	134200.00
6398B7	2017-07-22 14:14:00+03	80900.00
6398C0	2017-07-04 23:53:00+03	24600.00
639972	2017-07-17 01:50:00+03	13600.00
639979	2017-07-24 08:52:00+03	17200.00
63997B	2017-07-02 19:33:00+03	53300.00
639980	2017-07-29 15:21:00+03	94000.00
6399C8	2017-07-10 01:02:00+03	26800.00
639A01	2017-07-21 20:17:00+03	89700.00
639A0A	2017-08-03 04:37:00+03	46500.00
639A33	2017-07-23 00:35:00+03	16400.00
639A59	2017-07-14 15:34:00+03	199700.00
639A9A	2017-07-03 08:33:00+03	82700.00
639ABE	2017-07-15 14:15:00+03	6000.00
639AC9	2017-07-04 11:33:00+03	38600.00
639B25	2017-07-13 17:22:00+03	101100.00
639B56	2017-06-30 09:33:00+03	59000.00
639B58	2017-07-19 02:25:00+03	19600.00
639B63	2017-07-23 08:53:00+03	16400.00
639C08	2017-07-08 10:23:00+03	266400.00
639C45	2017-07-26 07:51:00+03	101300.00
639D49	2017-08-08 11:30:00+03	28800.00
639D52	2017-07-31 23:03:00+03	120000.00
639D65	2017-07-27 04:13:00+03	75600.00
639DEC	2017-06-25 16:25:00+03	65900.00
639ED0	2017-07-21 00:17:00+03	94000.00
639F0B	2017-07-01 01:25:00+03	54800.00
639FDD	2017-07-02 18:35:00+03	29600.00
63A027	2017-08-12 05:33:00+03	40300.00
63A03A	2017-08-05 16:40:00+03	7400.00
63A049	2017-07-20 15:16:00+03	55800.00
63A059	2017-07-31 21:09:00+03	304100.00
63A096	2017-07-30 00:14:00+03	87100.00
63A0A3	2017-07-05 08:19:00+03	115800.00
63A0BF	2017-07-07 14:25:00+03	67100.00
63A0D2	2017-07-03 18:21:00+03	48800.00
63A0DE	2017-07-05 05:46:00+03	63000.00
63A109	2017-08-15 17:11:00+03	7000.00
63A137	2017-07-05 10:39:00+03	54800.00
63A187	2017-07-27 04:06:00+03	46800.00
63A18E	2017-07-28 23:34:00+03	60400.00
63A212	2017-07-29 10:12:00+03	111600.00
63A264	2017-08-15 03:33:00+03	7400.00
63A2F6	2017-07-21 08:44:00+03	115700.00
63A351	2017-07-12 20:09:00+03	70400.00
63A355	2017-07-28 15:14:00+03	23900.00
63A38B	2017-07-24 15:02:00+03	59300.00
63A498	2017-07-10 12:31:00+03	35200.00
63A4CF	2017-07-10 12:36:00+03	6800.00
63A4D6	2017-08-08 22:16:00+03	68800.00
63A4F0	2017-07-29 05:19:00+03	145100.00
63A502	2017-07-07 13:09:00+03	52000.00
63A508	2017-07-13 01:55:00+03	17800.00
63A539	2017-07-11 02:48:00+03	49200.00
63A583	2017-07-19 10:08:00+03	38200.00
63A5A5	2017-07-21 13:21:00+03	15800.00
63A5DE	2017-07-17 08:59:00+03	33300.00
63A636	2017-08-10 10:29:00+03	60400.00
63A637	2017-08-06 22:37:00+03	92800.00
63A673	2017-07-18 16:26:00+03	51200.00
63A73E	2017-07-18 05:28:00+03	123000.00
63A7CA	2017-07-09 07:41:00+03	40400.00
63A7CC	2017-08-11 17:40:00+03	99100.00
63A827	2017-08-12 23:35:00+03	14800.00
63A8A6	2017-07-27 16:44:00+03	39300.00
63A94D	2017-07-29 04:31:00+03	26800.00
63A953	2017-07-12 03:20:00+03	393800.00
63A95B	2017-08-12 16:05:00+03	52900.00
63A985	2017-08-11 05:16:00+03	6700.00
63A98E	2017-08-12 03:58:00+03	123000.00
63A991	2017-07-28 10:46:00+03	67400.00
63A9B0	2017-08-04 01:54:00+03	42800.00
63A9BA	2017-07-17 19:48:00+03	14800.00
63A9DF	2017-08-12 03:56:00+03	85000.00
63A9F2	2017-07-26 09:35:00+03	62000.00
63A9FD	2017-07-11 06:21:00+03	8200.00
63AA13	2017-07-10 12:45:00+03	86800.00
63AA69	2017-07-19 02:25:00+03	92800.00
63AAE4	2017-07-10 08:21:00+03	33100.00
63AB67	2017-08-10 03:33:00+03	65400.00
63AC41	2017-08-06 16:49:00+03	28800.00
63AC64	2017-07-14 03:27:00+03	40800.00
63ACC1	2017-07-18 03:54:00+03	202300.00
63AD1E	2017-07-27 12:23:00+03	43600.00
63AD6D	2017-07-15 00:17:00+03	16400.00
63AD9C	2017-08-07 18:48:00+03	163500.00
63ADA2	2017-07-20 17:45:00+03	21800.00
63AE19	2017-07-23 18:45:00+03	26000.00
63AE65	2017-08-04 10:04:00+03	66900.00
63AF1C	2017-08-12 05:43:00+03	32400.00
63AF42	2017-07-16 08:52:00+03	92700.00
63AF62	2017-06-29 22:24:00+03	91600.00
63AF76	2017-07-31 15:22:00+03	62600.00
63AF8C	2017-08-10 18:52:00+03	6300.00
63AFE4	2017-07-25 08:33:00+03	75500.00
63AFE8	2017-08-12 18:31:00+03	29600.00
63B016	2017-07-31 15:22:00+03	79200.00
63B044	2017-07-31 21:11:00+03	33200.00
63B057	2017-08-13 21:07:00+03	38200.00
63B060	2017-08-04 18:23:00+03	157100.00
63B0CF	2017-07-24 11:12:00+03	332700.00
63B0D4	2017-08-07 14:54:00+03	56000.00
63B0E4	2017-08-15 06:49:00+03	36600.00
63B13E	2017-07-17 09:42:00+03	67600.00
63B14E	2017-07-31 07:44:00+03	13000.00
63B1E8	2017-07-11 19:23:00+03	55800.00
63B23F	2017-07-15 03:16:00+03	67100.00
63B2D7	2017-07-14 13:34:00+03	64100.00
63B2E2	2017-08-14 03:33:00+03	108000.00
63B2FE	2017-07-22 03:11:00+03	28000.00
63B355	2017-07-08 10:40:00+03	204200.00
63B35A	2017-08-15 03:52:00+03	27800.00
63B36A	2017-08-05 13:42:00+03	39500.00
63B374	2017-08-02 07:52:00+03	159200.00
63B392	2017-07-08 00:57:00+03	8400.00
63B3DC	2017-08-02 11:13:00+03	37100.00
63B3F9	2017-07-19 14:44:00+03	66600.00
63B448	2017-08-03 17:26:00+03	14900.00
63B45A	2017-08-09 13:58:00+03	31400.00
63B463	2017-07-10 05:52:00+03	239100.00
63B48B	2017-07-22 04:56:00+03	112000.00
63B4A4	2017-07-18 20:30:00+03	63500.00
63B4C4	2017-07-08 11:14:00+03	23100.00
63B50A	2017-07-17 18:12:00+03	80800.00
63B56B	2017-07-22 17:33:00+03	132800.00
63B651	2017-08-12 19:37:00+03	111600.00
63B688	2017-08-12 20:30:00+03	98300.00
63B77B	2017-07-06 22:30:00+03	92900.00
63B784	2017-08-12 18:30:00+03	31700.00
63B7CF	2017-07-05 16:21:00+03	12200.00
63B7E6	2017-08-07 10:04:00+03	369000.00
63B7F4	2017-07-17 10:09:00+03	21800.00
63B89C	2017-08-04 08:08:00+03	28000.00
63B9C1	2017-07-07 17:55:00+03	23600.00
63B9C6	2017-08-03 11:07:00+03	41600.00
63BA3A	2017-08-04 04:19:00+03	57800.00
63BA41	2017-07-12 16:08:00+03	102300.00
63BA49	2017-07-22 03:03:00+03	481000.00
63BA9E	2017-07-29 03:50:00+03	160100.00
63BACD	2017-08-01 19:55:00+03	163000.00
63BAF8	2017-07-06 10:14:00+03	20900.00
63BB07	2017-08-04 19:43:00+03	69700.00
63BB4E	2017-08-13 22:22:00+03	36000.00
63BBAB	2017-07-10 15:55:00+03	306600.00
63BC1D	2017-08-08 12:27:00+03	12600.00
63BC7D	2017-07-15 15:12:00+03	260900.00
63BCAC	2017-07-28 04:30:00+03	49900.00
63BCC4	2017-07-04 22:34:00+03	89700.00
63BD6C	2017-07-04 16:41:00+03	56900.00
63BD9E	2017-08-10 01:28:00+03	44000.00
63BDD6	2017-07-25 20:42:00+03	24800.00
63BEBA	2017-07-04 07:30:00+03	61500.00
63BEC8	2017-07-31 10:37:00+03	93000.00
63BEE3	2017-08-09 08:51:00+03	51900.00
63BEEC	2017-08-12 16:11:00+03	26000.00
63BF17	2017-08-02 11:02:00+03	54800.00
63BFAB	2017-07-06 22:34:00+03	46700.00
63BFF0	2017-07-12 22:49:00+03	12600.00
63C00A	2017-07-11 06:10:00+03	189800.00
63C013	2017-07-10 05:28:00+03	27900.00
63C031	2017-08-12 05:05:00+03	57100.00
63C035	2017-08-14 09:25:00+03	19600.00
63C039	2017-08-09 18:12:00+03	213200.00
63C03A	2017-07-24 06:35:00+03	67400.00
63C057	2017-07-20 23:38:00+03	28000.00
63C06D	2017-07-24 00:40:00+03	112000.00
63C070	2017-07-04 09:55:00+03	13800.00
63C0C0	2017-08-13 16:50:00+03	124200.00
63C131	2017-07-16 10:59:00+03	46400.00
63C148	2017-07-20 20:28:00+03	31900.00
63C1E2	2017-07-16 18:15:00+03	23200.00
63C22A	2017-07-15 00:32:00+03	28000.00
63C28D	2017-08-14 07:02:00+03	88500.00
63C336	2017-07-23 16:49:00+03	20200.00
63C369	2017-08-02 09:58:00+03	72200.00
63C36F	2017-06-30 12:25:00+03	41400.00
63C395	2017-07-03 21:42:00+03	7400.00
63C3A1	2017-08-05 02:32:00+03	70800.00
63C3C3	2017-08-04 13:16:00+03	296400.00
63C439	2017-08-12 17:55:00+03	24400.00
63C4E1	2017-07-02 13:05:00+03	36600.00
63C4E8	2017-08-02 10:47:00+03	15800.00
63C4F1	2017-07-25 12:50:00+03	47000.00
63C4F6	2017-08-01 19:10:00+03	39200.00
63C52F	2017-07-29 01:58:00+03	170200.00
63C54C	2017-08-15 03:15:00+03	197100.00
63C57F	2017-07-16 22:39:00+03	258400.00
63C597	2017-07-03 01:13:00+03	46400.00
63C5F1	2017-07-21 20:08:00+03	4000.00
63C639	2017-07-24 21:42:00+03	38800.00
63C643	2017-07-22 06:41:00+03	455200.00
63C661	2017-07-25 12:26:00+03	14400.00
63C688	2017-07-06 20:38:00+03	22600.00
63C754	2017-07-03 07:30:00+03	547000.00
63C7BA	2017-08-01 16:55:00+03	25200.00
63C7C0	2017-07-08 07:42:00+03	25200.00
63C822	2017-07-25 23:10:00+03	75600.00
63C82E	2017-08-03 00:12:00+03	43200.00
63C889	2017-08-06 10:38:00+03	159500.00
63C932	2017-07-21 06:26:00+03	39300.00
63C947	2017-07-26 00:37:00+03	112000.00
63C98B	2017-08-03 00:27:00+03	14000.00
63CA3C	2017-08-10 12:57:00+03	10800.00
63CA9B	2017-08-12 22:10:00+03	18500.00
63CB3C	2017-07-19 04:43:00+03	28000.00
63CB91	2017-07-17 03:45:00+03	65900.00
63CBF0	2017-07-04 01:39:00+03	77500.00
63CC17	2017-07-27 18:47:00+03	93700.00
63CC26	2017-07-07 18:13:00+03	20500.00
63CCE9	2017-07-20 19:46:00+03	73100.00
63CD22	2017-07-17 20:01:00+03	46800.00
63CD33	2017-07-18 19:38:00+03	29600.00
63CD41	2017-07-29 01:40:00+03	66800.00
63CD4B	2017-07-05 09:38:00+03	46400.00
63CD56	2017-08-11 03:37:00+03	7200.00
63CD72	2017-08-01 10:16:00+03	31400.00
63CD7B	2017-08-01 03:34:00+03	64200.00
63CEFB	2017-07-09 10:54:00+03	12700.00
63CEFC	2017-08-15 08:48:00+03	24400.00
63CF7C	2017-07-30 06:21:00+03	38600.00
63CFB2	2017-07-07 17:33:00+03	66600.00
63CFB4	2017-08-05 14:51:00+03	101100.00
63CFEC	2017-07-10 12:35:00+03	36200.00
63D04E	2017-07-10 11:28:00+03	20400.00
63D056	2017-06-28 01:30:00+03	42800.00
63D0A4	2017-07-10 06:37:00+03	27400.00
63D0AB	2017-07-17 10:53:00+03	39300.00
63D18F	2017-07-18 09:00:00+03	39500.00
63D19B	2017-08-12 02:19:00+03	104700.00
63D1C5	2017-07-29 00:24:00+03	246000.00
63D2CF	2017-08-12 04:26:00+03	43000.00
63D2E6	2017-07-11 07:08:00+03	12600.00
63D306	2017-08-12 07:28:00+03	10800.00
63D327	2017-07-12 05:53:00+03	32500.00
63D3A7	2017-08-11 23:46:00+03	61400.00
63D3BB	2017-07-30 06:29:00+03	33200.00
63D3C7	2017-07-20 13:09:00+03	16400.00
63D48E	2017-08-12 02:24:00+03	90400.00
63D4A6	2017-07-30 19:14:00+03	133100.00
63D4A9	2017-07-08 00:12:00+03	35300.00
63D515	2017-07-28 08:19:00+03	273600.00
63D51C	2017-07-29 01:19:00+03	13400.00
63D532	2017-07-04 17:37:00+03	14000.00
63D545	2017-08-08 14:12:00+03	57500.00
63D5B7	2017-07-27 19:28:00+03	84000.00
63D5E3	2017-07-19 00:37:00+03	112000.00
63D606	2017-07-25 01:45:00+03	203000.00
63D6D3	2017-08-12 02:16:00+03	119300.00
63D71E	2017-08-05 11:34:00+03	6600.00
63D73F	2017-08-07 13:36:00+03	3700.00
63D7D1	2017-07-31 18:25:00+03	6700.00
63D7D9	2017-07-12 05:29:00+03	30200.00
63D7E6	2017-07-07 05:25:00+03	119900.00
63D7EB	2017-08-13 08:44:00+03	8200.00
63D818	2017-07-13 07:42:00+03	89700.00
63D81C	2017-07-15 17:55:00+03	532800.00
63D963	2017-07-28 18:12:00+03	8200.00
63DA21	2017-07-12 11:24:00+03	166100.00
63DA74	2017-07-23 22:03:00+03	140900.00
63DA98	2017-08-15 04:49:00+03	21400.00
63DADE	2017-07-21 14:22:00+03	44500.00
63DAE2	2017-07-22 07:07:00+03	99300.00
63DB04	2017-08-08 20:54:00+03	101200.00
63DB42	2017-07-12 14:48:00+03	303100.00
63DBB4	2017-07-21 05:08:00+03	66000.00
63DBFB	2017-07-12 03:14:00+03	96200.00
63DC49	2017-08-15 03:44:00+03	29800.00
63DC8D	2017-07-30 04:03:00+03	29200.00
63DCB1	2017-07-14 02:40:00+03	119400.00
63DCE3	2017-07-05 15:58:00+03	125100.00
63DCF4	2017-08-09 14:59:00+03	6800.00
63DD10	2017-07-22 11:26:00+03	77500.00
63DD8D	2017-07-13 14:51:00+03	248300.00
63DD9C	2017-07-12 15:21:00+03	41200.00
63DDF3	2017-07-04 09:03:00+03	419400.00
63DE40	2017-07-14 09:57:00+03	21400.00
63DE87	2017-07-21 11:36:00+03	74300.00
63DEBB	2017-08-04 17:14:00+03	21000.00
63DEC8	2017-07-27 01:38:00+03	90700.00
63DECA	2017-07-12 21:59:00+03	122300.00
63DEFD	2017-06-30 01:09:00+03	25800.00
63DF17	2017-07-18 18:25:00+03	64900.00
63DF56	2017-07-15 19:25:00+03	26000.00
63DFAC	2017-08-10 23:11:00+03	39300.00
63E005	2017-08-14 13:30:00+03	55600.00
63E089	2017-07-31 20:27:00+03	31400.00
63E119	2017-08-08 17:55:00+03	26000.00
63E1D1	2017-07-18 00:53:00+03	37200.00
63E272	2017-07-14 17:27:00+03	135400.00
63E294	2017-07-03 22:16:00+03	56900.00
63E335	2017-07-10 00:52:00+03	195900.00
63E363	2017-07-12 05:30:00+03	55800.00
63E37B	2017-08-07 12:02:00+03	124200.00
63E456	2017-08-04 02:18:00+03	147700.00
63E49A	2017-08-04 16:13:00+03	96800.00
63E4B3	2017-07-26 22:04:00+03	25400.00
63E5A4	2017-06-29 10:37:00+03	10800.00
63E627	2017-07-13 17:06:00+03	28000.00
63E632	2017-07-11 07:13:00+03	69500.00
63E66B	2017-07-29 06:20:00+03	67900.00
63E69D	2017-07-09 23:07:00+03	34700.00
63E6A9	2017-08-03 02:04:00+03	88600.00
63E778	2017-07-02 12:47:00+03	119600.00
63E7D0	2017-07-28 00:00:00+03	23200.00
63E7E2	2017-07-20 23:32:00+03	164400.00
63E7F8	2017-07-24 02:58:00+03	16400.00
63E84B	2017-07-15 14:57:00+03	37900.00
63E8C5	2017-08-11 05:09:00+03	296400.00
63E8E1	2017-07-13 02:27:00+03	98200.00
63E8F6	2017-07-22 10:39:00+03	124300.00
63E96F	2017-07-15 07:59:00+03	643800.00
63E9BC	2017-08-02 21:18:00+03	83600.00
63E9C8	2017-08-13 08:30:00+03	25800.00
63EA18	2017-07-09 03:45:00+03	46000.00
63EA3D	2017-08-09 07:07:00+03	62600.00
63EA5C	2017-07-06 21:03:00+03	58200.00
63EAEB	2017-08-05 03:54:00+03	48800.00
63EBA9	2017-08-05 11:33:00+03	66600.00
63EBC9	2017-07-03 19:47:00+03	12600.00
63EC11	2017-07-16 17:46:00+03	56000.00
63EC94	2017-07-20 20:41:00+03	14400.00
63ECB0	2017-07-07 08:53:00+03	55900.00
63ED01	2017-07-19 00:09:00+03	25200.00
63ED05	2017-08-14 00:54:00+03	38800.00
63ED64	2017-07-11 13:57:00+03	62900.00
63ED7E	2017-08-10 00:10:00+03	123000.00
63EDAE	2017-07-27 12:33:00+03	58200.00
63EDBC	2017-07-03 11:20:00+03	45600.00
63EDBD	2017-08-05 13:34:00+03	93300.00
63EEB9	2017-07-11 21:44:00+03	418500.00
63EF19	2017-07-09 08:51:00+03	79600.00
63EF37	2017-07-23 03:18:00+03	167400.00
63EF41	2017-07-19 13:31:00+03	61900.00
63EF66	2017-07-25 23:50:00+03	24800.00
63EFB2	2017-07-17 12:28:00+03	75800.00
63EFBE	2017-07-12 15:33:00+03	76100.00
63EFCB	2017-08-06 21:36:00+03	47400.00
63F046	2017-08-13 04:53:00+03	80300.00
63F049	2017-07-17 13:43:00+03	101100.00
63F0B0	2017-07-20 14:15:00+03	49000.00
63F107	2017-08-05 23:13:00+03	112600.00
63F141	2017-07-02 11:34:00+03	100000.00
63F148	2017-07-25 00:04:00+03	25400.00
63F188	2017-07-16 17:32:00+03	177600.00
63F190	2017-07-12 16:19:00+03	86600.00
63F1D0	2017-08-13 18:50:00+03	24400.00
63F238	2017-08-02 12:12:00+03	86300.00
63F25F	2017-07-08 18:37:00+03	59300.00
63F284	2017-07-20 09:51:00+03	8200.00
63F339	2017-07-28 06:37:00+03	173200.00
63F40C	2017-07-27 23:25:00+03	116700.00
63F40E	2017-07-24 16:57:00+03	65500.00
63F41C	2017-08-07 14:17:00+03	12400.00
63F45A	2017-07-13 13:54:00+03	130900.00
63F4B1	2017-07-17 12:13:00+03	73500.00
63F4B3	2017-08-10 09:24:00+03	141200.00
63F5FA	2017-08-14 12:50:00+03	43800.00
63F65B	2017-08-11 07:19:00+03	22000.00
63F748	2017-07-23 16:20:00+03	27200.00
63F752	2017-07-02 01:02:00+03	79600.00
63F763	2017-07-31 00:10:00+03	67200.00
63F766	2017-08-08 10:56:00+03	94900.00
63F76F	2017-07-21 01:27:00+03	10800.00
63F773	2017-06-28 09:21:00+03	49600.00
63F789	2017-08-10 16:35:00+03	26700.00
63F793	2017-07-04 11:22:00+03	23200.00
63F7C6	2017-07-07 10:11:00+03	61700.00
63F803	2017-08-06 04:29:00+03	39200.00
63F825	2017-07-28 13:13:00+03	40800.00
63F8D6	2017-07-04 06:46:00+03	6600.00
63F91C	2017-07-29 10:45:00+03	58600.00
63F960	2017-07-31 16:52:00+03	196000.00
63F98E	2017-08-04 13:13:00+03	71000.00
63F994	2017-07-23 14:49:00+03	67700.00
63FA32	2017-08-13 09:11:00+03	102100.00
63FA50	2017-06-28 07:27:00+03	67600.00
63FA55	2017-08-12 03:00:00+03	48800.00
63FA6E	2017-08-08 07:09:00+03	59100.00
63FAD6	2017-07-15 08:39:00+03	55600.00
63FB4E	2017-08-09 07:17:00+03	119500.00
63FBFB	2017-07-26 12:12:00+03	52000.00
63FC1D	2017-08-06 07:12:00+03	155600.00
63FC2D	2017-07-29 16:22:00+03	88600.00
63FC34	2017-07-04 17:20:00+03	68100.00
63FC44	2017-06-30 05:04:00+03	119600.00
63FC5C	2017-08-07 09:55:00+03	92600.00
63FD1D	2017-08-10 01:58:00+03	123000.00
63FD51	2017-07-15 17:13:00+03	102100.00
63FD6F	2017-07-22 08:46:00+03	43700.00
63FE3E	2017-08-05 16:02:00+03	24400.00
63FE5E	2017-07-25 17:30:00+03	24500.00
63FE76	2017-07-05 11:14:00+03	28000.00
63FEBC	2017-08-03 11:47:00+03	43600.00
63FF50	2017-07-20 05:03:00+03	153300.00
63FF54	2017-07-06 12:53:00+03	83600.00
63FFB7	2017-07-08 19:45:00+03	54800.00
63FFE3	2017-07-08 15:07:00+03	27200.00
63FFFD	2017-07-17 12:36:00+03	65900.00
64004D	2017-07-15 19:36:00+03	66600.00
64007A	2017-08-15 02:59:00+03	18000.00
640102	2017-07-07 23:21:00+03	56000.00
640123	2017-08-07 20:33:00+03	128800.00
640156	2017-07-13 11:31:00+03	105100.00
640179	2017-07-21 21:40:00+03	66800.00
6401BF	2017-08-15 13:43:00+03	64600.00
64026E	2017-07-31 22:17:00+03	24400.00
640295	2017-07-31 01:43:00+03	27300.00
640322	2017-07-01 22:29:00+03	88500.00
640330	2017-08-13 03:15:00+03	27200.00
640398	2017-08-04 05:50:00+03	47600.00
6403C1	2017-08-14 11:16:00+03	36200.00
6403CD	2017-08-14 21:18:00+03	23200.00
6404A9	2017-07-08 00:43:00+03	23400.00
64054F	2017-07-14 04:43:00+03	7400.00
64055A	2017-08-01 20:09:00+03	155000.00
64059D	2017-07-07 20:29:00+03	33300.00
6405AC	2017-07-04 09:37:00+03	97900.00
64062B	2017-08-05 14:45:00+03	14400.00
64064D	2017-07-12 21:00:00+03	84100.00
6406BC	2017-07-12 10:58:00+03	40000.00
64071B	2017-06-28 11:32:00+03	36200.00
640724	2017-07-16 00:25:00+03	55800.00
640757	2017-08-07 21:22:00+03	32800.00
640774	2017-07-23 04:13:00+03	354100.00
6407A1	2017-07-23 01:08:00+03	538600.00
640852	2017-07-04 23:24:00+03	29600.00
640859	2017-08-06 13:46:00+03	40000.00
6408B1	2017-08-15 13:33:00+03	12000.00
640A02	2017-07-07 18:04:00+03	64500.00
640A24	2017-08-05 20:57:00+03	45200.00
640A2E	2017-07-13 02:20:00+03	248400.00
640A52	2017-08-07 18:11:00+03	18600.00
640A90	2017-07-09 14:54:00+03	69900.00
640AB7	2017-07-24 10:38:00+03	143000.00
640AB8	2017-07-01 20:52:00+03	57500.00
640AC1	2017-07-18 05:51:00+03	20200.00
640ACE	2017-07-04 13:10:00+03	272300.00
640AE9	2017-07-09 14:26:00+03	65900.00
640B18	2017-06-30 02:13:00+03	103800.00
640B35	2017-07-26 12:07:00+03	14000.00
640BF8	2017-07-09 05:54:00+03	10600.00
640C2A	2017-07-21 01:41:00+03	128800.00
640C7B	2017-07-08 11:55:00+03	6000.00
640CD1	2017-08-12 03:09:00+03	103100.00
640DAB	2017-07-15 09:47:00+03	13200.00
640DC9	2017-07-09 12:44:00+03	136600.00
640E4B	2017-07-23 07:32:00+03	117600.00
640E56	2017-07-13 07:56:00+03	94700.00
640E88	2017-07-05 20:29:00+03	26700.00
640E9C	2017-07-28 19:02:00+03	40600.00
640EE6	2017-07-18 11:38:00+03	30400.00
640F93	2017-07-28 01:46:00+03	36200.00
640FA1	2017-07-21 08:31:00+03	63300.00
640FE0	2017-06-30 16:59:00+03	49500.00
640FF5	2017-07-09 15:32:00+03	62600.00
640FF8	2017-06-29 03:35:00+03	187900.00
64103C	2017-07-12 14:24:00+03	51300.00
641042	2017-07-19 07:31:00+03	91600.00
6410B7	2017-07-03 17:07:00+03	44000.00
6410C1	2017-08-01 05:13:00+03	62700.00
641197	2017-08-15 02:22:00+03	108000.00
6411AA	2017-07-13 20:55:00+03	94300.00
6411BE	2017-07-12 23:33:00+03	40800.00
6411CA	2017-07-02 14:17:00+03	59800.00
641207	2017-08-07 20:52:00+03	75600.00
641216	2017-07-31 01:35:00+03	59800.00
641263	2017-07-10 23:41:00+03	86400.00
641271	2017-07-12 08:25:00+03	65500.00
64127B	2017-07-19 03:30:00+03	260300.00
641284	2017-07-31 10:13:00+03	42900.00
6412C7	2017-07-22 02:57:00+03	133200.00
6412EC	2017-08-04 16:42:00+03	38000.00
6412F0	2017-07-31 00:18:00+03	203300.00
641302	2017-08-13 23:05:00+03	13400.00
641332	2017-08-02 08:31:00+03	40800.00
641362	2017-07-07 17:23:00+03	57600.00
641385	2017-07-23 05:19:00+03	71200.00
641403	2017-07-07 06:35:00+03	22200.00
641485	2017-08-03 15:33:00+03	65900.00
641488	2017-07-28 23:28:00+03	11600.00
6414C8	2017-06-29 08:36:00+03	6800.00
6414D1	2017-08-12 16:46:00+03	187600.00
641508	2017-07-08 13:45:00+03	354400.00
641515	2017-07-31 18:12:00+03	66600.00
64155C	2017-07-12 01:50:00+03	8400.00
641567	2017-07-26 05:34:00+03	28000.00
641597	2017-08-07 23:44:00+03	42700.00
641600	2017-08-03 01:10:00+03	175300.00
641647	2017-07-16 04:12:00+03	28800.00
64167E	2017-07-16 12:42:00+03	177600.00
64177C	2017-08-02 06:33:00+03	20400.00
64178D	2017-07-21 10:26:00+03	81300.00
6417D3	2017-07-30 02:57:00+03	81300.00
6417F5	2017-07-10 20:44:00+03	9200.00
641819	2017-07-16 04:37:00+03	50700.00
64190D	2017-08-06 07:52:00+03	69700.00
64196B	2017-08-11 18:05:00+03	42800.00
641993	2017-07-20 18:00:00+03	6700.00
64199F	2017-08-05 07:56:00+03	21400.00
6419BA	2017-08-13 05:57:00+03	54100.00
641A9B	2017-07-11 18:25:00+03	68600.00
641AA1	2017-08-01 02:20:00+03	62600.00
641AAE	2017-07-29 13:54:00+03	60700.00
641AD6	2017-07-06 13:39:00+03	135400.00
641ADF	2017-07-22 02:43:00+03	45200.00
641AF2	2017-07-23 13:14:00+03	24400.00
641B20	2017-07-04 14:26:00+03	56000.00
641BB6	2017-07-20 21:43:00+03	134400.00
641BC6	2017-07-27 13:41:00+03	47800.00
641BE3	2017-08-05 01:05:00+03	26800.00
641C06	2017-07-13 14:25:00+03	28000.00
641C41	2017-08-13 11:41:00+03	91800.00
641C85	2017-07-28 17:27:00+03	41200.00
641CBB	2017-08-02 19:00:00+03	59800.00
641D28	2017-07-31 02:28:00+03	68400.00
641D4D	2017-06-30 14:17:00+03	14600.00
641D52	2017-07-22 16:47:00+03	73300.00
641D5F	2017-07-09 19:10:00+03	90100.00
641DAA	2017-08-12 14:44:00+03	56000.00
641DCF	2017-07-20 10:38:00+03	29600.00
641DF1	2017-07-12 11:02:00+03	67200.00
641E12	2017-07-16 21:03:00+03	36200.00
641E2E	2017-07-13 10:05:00+03	16400.00
641E81	2017-08-13 14:47:00+03	29600.00
641E97	2017-08-11 08:10:00+03	29600.00
641EAB	2017-07-07 20:58:00+03	101200.00
641EB7	2017-06-30 22:16:00+03	113600.00
641EBC	2017-07-06 16:51:00+03	46900.00
641ECA	2017-07-14 11:55:00+03	46400.00
641ECB	2017-08-03 08:23:00+03	15800.00
641EF1	2017-07-20 18:27:00+03	132800.00
641F1D	2017-07-14 14:14:00+03	40000.00
641F3E	2017-07-11 02:13:00+03	46400.00
641F89	2017-08-13 02:05:00+03	22000.00
641F99	2017-08-11 16:41:00+03	46400.00
642025	2017-08-07 20:59:00+03	26000.00
64207F	2017-07-10 08:23:00+03	147700.00
642081	2017-07-31 16:59:00+03	135600.00
642098	2017-08-14 15:44:00+03	64600.00
6420AF	2017-07-29 19:06:00+03	70700.00
6420DE	2017-08-07 07:56:00+03	26200.00
64212C	2017-08-12 06:59:00+03	43500.00
642138	2017-08-11 18:00:00+03	58800.00
64213B	2017-07-15 08:16:00+03	7400.00
642228	2017-07-18 14:42:00+03	88600.00
642300	2017-07-03 06:20:00+03	26000.00
642388	2017-07-01 23:18:00+03	6800.00
6423D7	2017-08-07 05:03:00+03	44800.00
6423FF	2017-07-13 07:21:00+03	76000.00
642423	2017-08-08 04:43:00+03	49800.00
642429	2017-07-06 04:01:00+03	160200.00
642435	2017-07-09 06:32:00+03	70800.00
64243D	2017-07-29 21:22:00+03	51200.00
6424DB	2017-07-17 12:12:00+03	62700.00
6424F6	2017-06-29 08:16:00+03	99300.00
642516	2017-07-29 05:24:00+03	103400.00
6425BE	2017-07-31 01:17:00+03	24200.00
6425E9	2017-07-30 23:29:00+03	218800.00
642603	2017-06-30 03:26:00+03	21600.00
64263F	2017-07-28 22:18:00+03	186900.00
642691	2017-07-26 11:11:00+03	35600.00
6426B2	2017-07-09 01:34:00+03	10800.00
6426BE	2017-06-30 04:06:00+03	241500.00
6426CC	2017-07-13 01:19:00+03	86600.00
64271A	2017-08-12 11:31:00+03	62100.00
642739	2017-07-14 06:09:00+03	138000.00
642836	2017-07-31 16:12:00+03	190700.00
642840	2017-07-20 03:22:00+03	66900.00
642864	2017-08-04 16:23:00+03	64900.00
6428DF	2017-08-03 14:17:00+03	102100.00
642978	2017-08-09 11:50:00+03	38200.00
6429CD	2017-07-21 03:47:00+03	28000.00
6429E4	2017-07-28 16:22:00+03	26000.00
6429E8	2017-08-01 04:00:00+03	119700.00
6429F5	2017-07-24 09:54:00+03	16400.00
6429FC	2017-08-01 09:34:00+03	26800.00
642A3E	2017-08-07 17:14:00+03	56000.00
642B74	2017-07-03 19:06:00+03	36200.00
642B76	2017-08-03 07:59:00+03	12600.00
642BB6	2017-07-26 11:11:00+03	91200.00
642C4D	2017-08-07 21:39:00+03	66600.00
642D1E	2017-07-14 16:57:00+03	31600.00
642D31	2017-08-15 02:45:00+03	13200.00
642D3E	2017-07-06 04:24:00+03	103600.00
642E59	2017-07-16 00:45:00+03	118700.00
642E7A	2017-07-13 06:20:00+03	192700.00
642E85	2017-07-16 16:05:00+03	3700.00
642E98	2017-07-02 19:54:00+03	96300.00
642EC2	2017-07-08 12:53:00+03	99300.00
642ED5	2017-06-30 20:41:00+03	55900.00
642EEF	2017-08-10 17:41:00+03	50200.00
642F22	2017-07-13 21:45:00+03	69000.00
642F27	2017-07-27 23:34:00+03	135600.00
642F39	2017-08-13 03:47:00+03	28000.00
642F49	2017-07-21 04:04:00+03	56900.00
642F99	2017-07-11 15:37:00+03	73200.00
642FE1	2017-08-09 00:03:00+03	72500.00
643026	2017-07-10 14:48:00+03	6600.00
643056	2017-07-26 01:19:00+03	25800.00
643057	2017-08-09 06:01:00+03	23600.00
643079	2017-07-19 03:40:00+03	27200.00
64308B	2017-07-24 17:01:00+03	123600.00
643101	2017-07-03 18:12:00+03	93900.00
64315C	2017-07-13 01:21:00+03	97900.00
643204	2017-07-20 13:34:00+03	81600.00
643207	2017-07-19 13:15:00+03	124800.00
64322A	2017-07-18 17:43:00+03	43600.00
643232	2017-08-01 00:50:00+03	28800.00
6432B1	2017-07-31 10:27:00+03	75600.00
6432F4	2017-08-10 15:01:00+03	302400.00
643328	2017-08-10 14:58:00+03	66600.00
6433D4	2017-08-12 13:53:00+03	37900.00
643409	2017-07-11 21:15:00+03	24000.00
6434A7	2017-07-29 14:57:00+03	12000.00
6434D2	2017-07-09 15:51:00+03	46200.00
6434F1	2017-08-12 07:13:00+03	77000.00
643502	2017-07-04 22:32:00+03	49800.00
643563	2017-07-18 07:43:00+03	39600.00
643596	2017-07-25 17:32:00+03	121400.00
6435D8	2017-07-20 07:07:00+03	42800.00
643623	2017-07-15 18:17:00+03	16000.00
643693	2017-08-13 03:48:00+03	40000.00
6436B7	2017-07-09 06:15:00+03	21600.00
643747	2017-07-07 15:33:00+03	6300.00
643755	2017-07-13 23:38:00+03	66800.00
643832	2017-08-12 13:16:00+03	70600.00
64384A	2017-08-05 02:12:00+03	56100.00
6438CE	2017-07-30 05:44:00+03	37100.00
643907	2017-07-22 00:04:00+03	31100.00
64391C	2017-07-28 05:11:00+03	33300.00
64395F	2017-08-02 14:45:00+03	69500.00
643A27	2017-07-15 07:34:00+03	136200.00
643AA8	2017-08-02 02:50:00+03	52400.00
643AAD	2017-08-15 15:28:00+03	56000.00
643AFD	2017-07-27 06:58:00+03	23200.00
643B1D	2017-07-16 19:29:00+03	73200.00
643B24	2017-08-04 22:24:00+03	85700.00
643B34	2017-08-11 14:19:00+03	8000.00
643B41	2017-07-20 19:33:00+03	92700.00
643B4A	2017-07-08 13:46:00+03	24400.00
643BDC	2017-07-12 21:20:00+03	56000.00
643C34	2017-07-29 01:32:00+03	149300.00
643C52	2017-07-05 01:38:00+03	16400.00
643C65	2017-07-03 17:21:00+03	86600.00
643C85	2017-08-10 21:30:00+03	50600.00
643CF2	2017-06-30 13:56:00+03	39300.00
643D0E	2017-08-07 05:24:00+03	6900.00
643D20	2017-07-09 19:57:00+03	27300.00
643D5D	2017-08-10 04:41:00+03	369000.00
643D7B	2017-07-19 02:27:00+03	76800.00
643D92	2017-08-13 14:40:00+03	36000.00
643D9F	2017-07-26 03:19:00+03	20200.00
643DD8	2017-07-22 17:52:00+03	36200.00
643E17	2017-08-05 01:09:00+03	79800.00
643E66	2017-08-06 16:46:00+03	139800.00
643E8F	2017-07-05 05:56:00+03	70200.00
643ED6	2017-08-11 10:22:00+03	67600.00
643F30	2017-08-08 06:04:00+03	37100.00
643F7D	2017-07-24 09:42:00+03	135000.00
644046	2017-08-12 10:20:00+03	14000.00
64408C	2017-08-09 13:29:00+03	89100.00
6440B5	2017-08-01 19:36:00+03	77600.00
64416E	2017-07-14 22:44:00+03	56600.00
644198	2017-07-04 11:29:00+03	67200.00
6441EA	2017-08-14 06:29:00+03	60700.00
64420B	2017-08-11 05:49:00+03	138000.00
64424A	2017-07-27 06:15:00+03	112000.00
644263	2017-07-30 22:27:00+03	111600.00
644277	2017-08-04 21:03:00+03	92800.00
64427A	2017-08-12 08:57:00+03	241300.00
6442B4	2017-08-04 08:41:00+03	38800.00
644346	2017-07-07 22:29:00+03	46000.00
644361	2017-07-30 17:51:00+03	13700.00
644378	2017-07-28 21:38:00+03	86400.00
6443AE	2017-07-09 03:07:00+03	37900.00
64440C	2017-08-03 21:43:00+03	112000.00
64444C	2017-07-29 13:26:00+03	88900.00
64449A	2017-07-18 07:02:00+03	67200.00
6444AF	2017-07-31 22:11:00+03	32800.00
6444E5	2017-08-03 14:45:00+03	16400.00
644545	2017-07-19 20:50:00+03	46900.00
6445ED	2017-08-14 13:40:00+03	15000.00
6445FF	2017-07-18 00:48:00+03	51900.00
644615	2017-07-15 01:11:00+03	185000.00
64463C	2017-07-23 02:01:00+03	175400.00
64467B	2017-08-01 14:16:00+03	51600.00
6446C7	2017-07-21 11:57:00+03	92000.00
6446EB	2017-07-11 09:06:00+03	72000.00
64472F	2017-07-09 07:59:00+03	53300.00
644795	2017-07-13 23:56:00+03	37200.00
6447D6	2017-07-21 08:07:00+03	31600.00
64484E	2017-07-30 09:05:00+03	89600.00
644854	2017-07-08 10:12:00+03	34000.00
644893	2017-07-12 18:50:00+03	60400.00
6448A5	2017-07-26 09:19:00+03	26000.00
6448FE	2017-08-11 05:31:00+03	181000.00
644941	2017-07-01 16:48:00+03	23200.00
64495B	2017-08-14 04:02:00+03	23400.00
64495D	2017-07-01 00:11:00+03	6600.00
6449B1	2017-08-11 14:14:00+03	112000.00
6449BC	2017-07-22 00:32:00+03	112400.00
6449C7	2017-07-06 14:53:00+03	24400.00
644A3D	2017-07-25 12:22:00+03	31400.00
644A4C	2017-07-27 07:55:00+03	19600.00
644AC7	2017-08-10 18:13:00+03	13400.00
644AE4	2017-07-21 17:46:00+03	37200.00
644AFD	2017-07-31 09:37:00+03	200200.00
644B12	2017-08-05 02:55:00+03	53000.00
644B37	2017-08-01 20:08:00+03	67100.00
644B80	2017-07-20 09:47:00+03	111700.00
644B81	2017-07-25 15:06:00+03	132800.00
644B8E	2017-08-03 17:16:00+03	26600.00
644B9C	2017-07-15 12:02:00+03	135000.00
644BB9	2017-07-15 14:17:00+03	38600.00
644C15	2017-07-02 07:52:00+03	96200.00
644C28	2017-07-04 16:15:00+03	6000.00
644C46	2017-07-12 19:58:00+03	28800.00
644C6C	2017-07-12 04:54:00+03	56000.00
644C6E	2017-07-10 15:27:00+03	90800.00
644CB2	2017-07-17 12:57:00+03	21400.00
644CB6	2017-07-15 04:51:00+03	25600.00
644CD3	2017-08-03 20:49:00+03	57500.00
644CD9	2017-08-12 16:22:00+03	99200.00
644CE0	2017-07-08 06:02:00+03	36400.00
644CEB	2017-07-31 20:18:00+03	42800.00
644D01	2017-07-26 21:19:00+03	53300.00
644D0D	2017-08-06 18:30:00+03	35800.00
644D28	2017-08-03 05:07:00+03	56900.00
644D70	2017-07-24 13:04:00+03	119700.00
644DBC	2017-07-24 12:08:00+03	406200.00
644E0C	2017-07-20 18:27:00+03	335400.00
644E22	2017-08-02 13:34:00+03	74200.00
644E5F	2017-08-12 03:46:00+03	39600.00
644E63	2017-08-06 07:56:00+03	134700.00
644E67	2017-07-27 16:11:00+03	62100.00
644ED1	2017-08-13 20:13:00+03	155600.00
644EE6	2017-07-14 15:03:00+03	129700.00
644F54	2017-07-04 19:36:00+03	88400.00
644F9C	2017-07-05 17:38:00+03	12400.00
644FFD	2017-07-17 06:37:00+03	117100.00
6450C1	2017-07-11 14:35:00+03	23600.00
6450EC	2017-07-25 23:33:00+03	8600.00
645109	2017-06-30 02:54:00+03	43200.00
645114	2017-07-08 07:49:00+03	50700.00
645131	2017-08-11 15:16:00+03	41600.00
645163	2017-08-05 14:26:00+03	144000.00
64517C	2017-07-06 01:49:00+03	55800.00
645181	2017-07-07 08:10:00+03	93900.00
64519B	2017-07-19 04:00:00+03	25800.00
6451F2	2017-08-05 20:12:00+03	49400.00
645203	2017-07-17 20:25:00+03	134700.00
64521B	2017-07-12 02:45:00+03	56000.00
645229	2017-08-12 05:10:00+03	37900.00
64527D	2017-08-13 09:21:00+03	69500.00
645290	2017-07-16 08:25:00+03	41800.00
6452F5	2017-07-18 20:56:00+03	238800.00
64531F	2017-07-16 02:08:00+03	13400.00
645368	2017-07-11 01:51:00+03	40800.00
645399	2017-07-30 08:04:00+03	59800.00
6453DD	2017-08-07 14:44:00+03	39500.00
6453E7	2017-07-24 08:27:00+03	24300.00
64545E	2017-07-28 05:28:00+03	77500.00
645495	2017-07-19 06:34:00+03	57700.00
6454B4	2017-08-10 17:59:00+03	25600.00
6454C9	2017-08-05 02:02:00+03	4000.00
6455C0	2017-08-14 21:01:00+03	131600.00
6455C3	2017-07-04 10:35:00+03	136800.00
6455DC	2017-08-07 12:44:00+03	123000.00
64563E	2017-07-26 08:05:00+03	148200.00
645668	2017-07-29 15:57:00+03	13800.00
6456A2	2017-07-17 00:40:00+03	80800.00
6456F7	2017-08-06 10:23:00+03	25900.00
645739	2017-07-10 12:42:00+03	66600.00
645759	2017-07-05 00:04:00+03	23200.00
645768	2017-08-07 04:12:00+03	101200.00
645792	2017-06-30 11:35:00+03	50600.00
645811	2017-07-16 00:10:00+03	229600.00
645850	2017-08-09 09:21:00+03	21000.00
645853	2017-07-30 10:31:00+03	135600.00
64587F	2017-07-22 14:00:00+03	25400.00
6458C0	2017-08-14 05:01:00+03	30200.00
645954	2017-08-11 06:45:00+03	35200.00
645974	2017-07-27 22:48:00+03	45100.00
6459A0	2017-08-04 17:03:00+03	66600.00
6459A9	2017-07-01 05:34:00+03	101200.00
6459AD	2017-08-02 07:09:00+03	47200.00
645AB9	2017-07-10 13:23:00+03	92000.00
645ABF	2017-07-25 21:23:00+03	28800.00
645AC6	2017-07-09 10:00:00+03	69900.00
645ADA	2017-07-14 12:49:00+03	36600.00
645B28	2017-07-25 05:20:00+03	69700.00
645B59	2017-08-13 04:13:00+03	90800.00
645BCD	2017-07-06 20:19:00+03	35200.00
645C0C	2017-07-18 11:27:00+03	50800.00
645CEB	2017-07-27 21:06:00+03	223200.00
645D4C	2017-07-15 09:40:00+03	26000.00
645D85	2017-06-26 07:17:00+03	71900.00
645DAF	2017-07-15 03:14:00+03	29000.00
645DCB	2017-07-18 04:28:00+03	27900.00
645DD8	2017-08-08 08:16:00+03	40100.00
645E0B	2017-07-28 12:38:00+03	55800.00
645EDB	2017-07-17 05:10:00+03	56600.00
645F29	2017-08-07 21:07:00+03	27400.00
645F43	2017-08-13 14:22:00+03	149800.00
645F4C	2017-07-17 19:47:00+03	63500.00
645F81	2017-08-11 06:02:00+03	398500.00
645F9A	2017-08-11 13:36:00+03	62000.00
645FA8	2017-08-11 13:34:00+03	185700.00
645FC7	2017-07-04 13:14:00+03	52400.00
646044	2017-07-31 12:07:00+03	26300.00
646074	2017-07-16 22:23:00+03	34000.00
646150	2017-07-31 03:18:00+03	42800.00
646153	2017-08-03 02:36:00+03	20400.00
6461AD	2017-07-06 18:25:00+03	75300.00
6461C2	2017-07-23 02:02:00+03	27200.00
6461CF	2017-07-05 15:29:00+03	32700.00
6461D5	2017-08-09 18:50:00+03	26700.00
64620A	2017-07-16 11:02:00+03	72400.00
64624A	2017-07-29 18:26:00+03	14000.00
646289	2017-07-04 22:17:00+03	92100.00
64629D	2017-08-11 05:56:00+03	47000.00
6462A6	2017-06-28 15:31:00+03	43100.00
64631C	2017-08-11 23:58:00+03	26700.00
64632B	2017-07-13 05:00:00+03	28700.00
646336	2017-08-05 07:27:00+03	59800.00
646338	2017-07-04 08:53:00+03	73900.00
64639B	2017-07-17 11:10:00+03	67800.00
6463A7	2017-08-14 23:11:00+03	134000.00
6463C7	2017-07-14 19:58:00+03	52700.00
6463F6	2017-08-10 03:03:00+03	85000.00
64647E	2017-07-17 21:51:00+03	14000.00
646491	2017-07-30 06:28:00+03	125000.00
6464C7	2017-07-05 13:03:00+03	89700.00
6464F2	2017-07-06 08:47:00+03	23200.00
646501	2017-08-07 13:17:00+03	28000.00
646504	2017-07-10 04:18:00+03	62000.00
646522	2017-07-16 01:06:00+03	123000.00
64653B	2017-07-17 07:15:00+03	54000.00
646553	2017-07-18 08:49:00+03	30400.00
64656A	2017-07-07 04:10:00+03	99200.00
6465C4	2017-07-22 07:49:00+03	34000.00
6465C9	2017-07-10 04:53:00+03	134400.00
6465E6	2017-08-12 22:18:00+03	13600.00
646620	2017-07-20 15:50:00+03	12400.00
64662F	2017-07-19 02:03:00+03	26700.00
646775	2017-07-13 15:02:00+03	151200.00
646787	2017-08-10 03:38:00+03	28000.00
64679B	2017-07-28 13:51:00+03	54100.00
64685A	2017-07-27 04:45:00+03	14400.00
646866	2017-07-10 00:06:00+03	55500.00
646870	2017-07-22 19:06:00+03	89200.00
6468A0	2017-08-02 01:44:00+03	95300.00
6468F5	2017-07-23 04:51:00+03	79000.00
6468F7	2017-07-30 03:28:00+03	57600.00
64696F	2017-08-05 23:01:00+03	116000.00
6469AB	2017-07-11 20:45:00+03	132800.00
6469D9	2017-08-11 11:25:00+03	85400.00
6469DB	2017-07-02 03:26:00+03	49300.00
646A5E	2017-08-03 22:24:00+03	81900.00
646AAD	2017-07-20 04:57:00+03	48700.00
646AB5	2017-06-30 21:36:00+03	38400.00
646B01	2017-07-08 02:22:00+03	164400.00
646B3C	2017-07-23 18:24:00+03	134800.00
646B6F	2017-08-13 21:40:00+03	145100.00
646BAC	2017-07-27 20:18:00+03	43700.00
646BBE	2017-07-04 08:25:00+03	85800.00
646BD9	2017-07-18 05:00:00+03	40300.00
646CB8	2017-08-01 18:37:00+03	14400.00
646CC3	2017-07-24 21:12:00+03	39800.00
646CCD	2017-07-31 10:59:00+03	28000.00
646CFC	2017-08-08 15:21:00+03	62600.00
646D16	2017-07-02 12:11:00+03	79600.00
646D1A	2017-08-12 01:33:00+03	20400.00
646D84	2017-07-13 03:02:00+03	51200.00
646D98	2017-07-11 13:06:00+03	86400.00
646E7C	2017-07-18 10:51:00+03	67600.00
646EBB	2017-07-04 20:57:00+03	147100.00
646F3F	2017-08-04 09:34:00+03	119500.00
646FEE	2017-07-03 21:41:00+03	139300.00
646FF2	2017-07-10 02:56:00+03	100500.00
647043	2017-08-06 08:24:00+03	46200.00
647066	2017-08-10 23:54:00+03	51800.00
647117	2017-07-14 13:20:00+03	6700.00
647119	2017-07-15 05:39:00+03	68800.00
647138	2017-07-30 07:29:00+03	43600.00
647196	2017-08-12 20:00:00+03	122000.00
647259	2017-07-17 23:14:00+03	270800.00
647279	2017-07-21 19:07:00+03	266400.00
647295	2017-07-28 20:08:00+03	21500.00
647296	2017-08-05 02:48:00+03	36200.00
647320	2017-07-02 16:16:00+03	62900.00
6473D4	2017-06-30 12:05:00+03	293700.00
6474D9	2017-07-10 16:45:00+03	242400.00
6475A1	2017-07-10 20:06:00+03	27200.00
6475AB	2017-07-11 18:41:00+03	84000.00
64760A	2017-07-22 10:07:00+03	77200.00
64762F	2017-07-10 11:30:00+03	87300.00
64767E	2017-07-29 04:00:00+03	55800.00
64769F	2017-07-24 18:53:00+03	170000.00
6476C2	2017-07-08 09:43:00+03	56000.00
6476F3	2017-08-07 22:38:00+03	42600.00
647734	2017-07-04 01:06:00+03	14400.00
647854	2017-08-02 05:59:00+03	159700.00
647890	2017-08-01 05:02:00+03	62600.00
6478A2	2017-07-31 21:05:00+03	48100.00
6478AF	2017-08-07 16:15:00+03	47100.00
6478F5	2017-07-31 17:22:00+03	241300.00
64791C	2017-08-04 09:34:00+03	85000.00
64791E	2017-08-12 19:01:00+03	46300.00
64793B	2017-08-08 23:54:00+03	69500.00
647A21	2017-08-07 22:56:00+03	78600.00
647A25	2017-08-01 12:06:00+03	153300.00
647A46	2017-08-04 21:39:00+03	93900.00
647A5A	2017-07-25 21:36:00+03	102100.00
647A61	2017-07-27 01:51:00+03	265600.00
647BB5	2017-08-11 15:26:00+03	6600.00
647BBC	2017-07-04 11:08:00+03	46000.00
647BBF	2017-07-16 17:19:00+03	28800.00
647BCA	2017-07-05 07:49:00+03	56000.00
647BF4	2017-07-29 10:32:00+03	49100.00
647C22	2017-07-12 06:03:00+03	48500.00
647D0C	2017-08-03 18:49:00+03	27200.00
647D46	2017-08-14 05:15:00+03	36800.00
647D48	2017-07-14 16:37:00+03	55800.00
647D86	2017-07-19 01:23:00+03	78400.00
647D8E	2017-07-12 04:24:00+03	54500.00
647DCA	2017-07-31 22:24:00+03	62800.00
647E21	2017-07-11 00:31:00+03	42800.00
647E4C	2017-07-16 22:59:00+03	56000.00
647E5A	2017-08-13 18:11:00+03	136800.00
647E6D	2017-07-26 19:34:00+03	147200.00
647E8C	2017-07-23 02:24:00+03	68800.00
647E92	2017-07-15 00:49:00+03	38600.00
647ED3	2017-07-26 22:21:00+03	56000.00
647F2B	2017-08-05 00:52:00+03	77600.00
647FEF	2017-08-07 19:45:00+03	56000.00
64805B	2017-07-08 05:51:00+03	139300.00
648082	2017-08-13 19:17:00+03	95200.00
64809A	2017-06-30 01:45:00+03	32200.00
6480F1	2017-07-27 08:13:00+03	140800.00
6480FE	2017-08-08 09:56:00+03	52400.00
64810D	2017-08-13 17:55:00+03	13600.00
648124	2017-07-16 19:06:00+03	28000.00
648158	2017-07-28 08:12:00+03	32800.00
648186	2017-08-11 14:49:00+03	24400.00
648191	2017-07-30 18:50:00+03	28000.00
6481C1	2017-06-30 02:37:00+03	406100.00
6481F5	2017-08-12 11:37:00+03	39500.00
64829F	2017-07-11 06:04:00+03	108000.00
6482A8	2017-06-30 15:25:00+03	65900.00
6482C1	2017-08-13 23:26:00+03	56600.00
6482C7	2017-07-26 00:43:00+03	114800.00
648339	2017-07-06 19:15:00+03	131900.00
6483D5	2017-08-07 07:33:00+03	113200.00
648424	2017-07-21 19:23:00+03	57700.00
648457	2017-07-15 18:51:00+03	56000.00
6484C7	2017-08-11 13:22:00+03	6700.00
6484D7	2017-08-14 20:48:00+03	22000.00
6484F4	2017-08-06 05:50:00+03	13400.00
648500	2017-08-01 16:23:00+03	58100.00
648552	2017-08-11 10:32:00+03	27300.00
64857C	2017-08-06 23:17:00+03	15000.00
6485B9	2017-07-18 10:04:00+03	48800.00
6485CD	2017-06-29 12:18:00+03	89600.00
6485F1	2017-07-20 06:00:00+03	133200.00
648610	2017-07-25 14:14:00+03	59200.00
64861A	2017-07-23 18:29:00+03	34600.00
64862E	2017-07-02 21:16:00+03	39000.00
6486AF	2017-07-20 05:34:00+03	276200.00
6486B1	2017-08-14 03:09:00+03	21600.00
648736	2017-08-09 22:24:00+03	18600.00
648740	2017-07-21 10:22:00+03	198300.00
648741	2017-08-08 00:46:00+03	20800.00
648773	2017-07-16 05:13:00+03	23200.00
6487A3	2017-07-20 00:37:00+03	94000.00
6487A6	2017-07-29 12:16:00+03	19600.00
648805	2017-06-28 04:41:00+03	258400.00
64880B	2017-08-08 17:14:00+03	56600.00
648826	2017-08-03 08:21:00+03	42800.00
648867	2017-07-12 06:14:00+03	11600.00
6488B8	2017-07-14 05:21:00+03	246000.00
64894D	2017-08-04 19:04:00+03	67700.00
648966	2017-08-12 06:57:00+03	246000.00
6489BC	2017-08-09 05:50:00+03	104000.00
648A33	2017-07-01 02:25:00+03	54800.00
648AD2	2017-08-04 00:31:00+03	15000.00
648B88	2017-07-26 22:33:00+03	138800.00
648CA8	2017-07-17 22:00:00+03	28800.00
648CAE	2017-08-04 18:38:00+03	93900.00
648CF2	2017-07-06 00:05:00+03	24400.00
648D34	2017-08-08 16:58:00+03	63200.00
648E43	2017-08-10 14:21:00+03	372500.00
648E44	2017-08-10 16:44:00+03	210800.00
648E47	2017-08-01 05:28:00+03	22000.00
648E79	2017-07-27 11:13:00+03	118500.00
648EBC	2017-07-22 14:28:00+03	73500.00
648F41	2017-08-06 11:12:00+03	93900.00
648FBD	2017-07-05 03:19:00+03	53600.00
648FD0	2017-07-19 16:36:00+03	45200.00
648FD7	2017-07-30 13:09:00+03	36200.00
648FF4	2017-08-11 19:56:00+03	138000.00
64903E	2017-07-01 12:49:00+03	23200.00
64905F	2017-07-15 09:51:00+03	29600.00
6490CF	2017-07-13 11:51:00+03	31600.00
649143	2017-07-14 11:16:00+03	82500.00
64919D	2017-08-11 00:40:00+03	80000.00
649209	2017-08-07 02:59:00+03	86300.00
649265	2017-08-05 07:29:00+03	33100.00
64927E	2017-07-25 17:55:00+03	132800.00
6492D2	2017-07-05 15:56:00+03	55800.00
6492EA	2017-07-15 04:22:00+03	57400.00
64930D	2017-08-11 14:21:00+03	35400.00
6493FC	2017-07-12 01:51:00+03	47100.00
649436	2017-07-14 19:20:00+03	229900.00
649478	2017-08-01 07:00:00+03	135400.00
6494B7	2017-08-07 00:23:00+03	50200.00
6494D8	2017-07-22 06:24:00+03	90800.00
6494FC	2017-08-02 02:25:00+03	80800.00
649576	2017-08-11 17:24:00+03	72800.00
649587	2017-07-03 14:00:00+03	37900.00
6495A1	2017-07-25 09:54:00+03	131000.00
6495A2	2017-07-12 04:00:00+03	369000.00
64967A	2017-08-02 13:11:00+03	44000.00
649683	2017-08-13 21:26:00+03	61900.00
6496E1	2017-07-06 16:58:00+03	36800.00
6496F9	2017-07-28 23:20:00+03	46000.00
64971B	2017-08-06 10:54:00+03	58900.00
649722	2017-07-30 23:44:00+03	37000.00
64972D	2017-08-14 02:49:00+03	102300.00
649737	2017-07-27 19:20:00+03	225200.00
649745	2017-07-03 14:22:00+03	37000.00
6497B6	2017-07-27 13:55:00+03	62600.00
6497BD	2017-07-05 21:15:00+03	246000.00
649854	2017-08-06 17:00:00+03	6700.00
649870	2017-07-26 13:53:00+03	6700.00
649880	2017-07-29 04:12:00+03	49800.00
6498C2	2017-07-04 17:54:00+03	35600.00
649938	2017-07-23 04:39:00+03	14400.00
649948	2017-07-23 21:43:00+03	26000.00
6499CF	2017-07-02 10:06:00+03	38200.00
6499E9	2017-07-19 22:02:00+03	799200.00
649A20	2017-08-05 04:43:00+03	82900.00
649A22	2017-07-25 22:17:00+03	69600.00
649A3B	2017-07-22 13:08:00+03	47200.00
649A55	2017-06-28 15:35:00+03	69500.00
649A5F	2017-07-23 00:01:00+03	131100.00
649A78	2017-08-03 23:11:00+03	64500.00
649A85	2017-08-03 09:33:00+03	28000.00
649ADF	2017-07-31 07:56:00+03	14800.00
649B0D	2017-07-23 20:35:00+03	9800.00
649B1D	2017-07-13 07:32:00+03	34100.00
649B26	2017-08-13 20:13:00+03	135200.00
649B2E	2017-08-15 03:32:00+03	177200.00
649B34	2017-08-15 05:19:00+03	42800.00
649B4C	2017-07-13 20:25:00+03	63200.00
649BAE	2017-07-28 15:24:00+03	132800.00
649BE4	2017-08-13 12:16:00+03	246000.00
649CA6	2017-07-21 00:47:00+03	13600.00
649CE3	2017-08-01 09:37:00+03	112800.00
649E2E	2017-07-28 10:58:00+03	52000.00
649E62	2017-08-02 18:26:00+03	16400.00
649E7B	2017-08-13 01:42:00+03	75800.00
649EB3	2017-07-30 12:34:00+03	56000.00
649EB4	2017-08-15 14:49:00+03	52300.00
649EEF	2017-07-10 16:01:00+03	181600.00
649F40	2017-08-03 20:18:00+03	81500.00
649F7D	2017-08-07 10:44:00+03	31400.00
64A037	2017-07-04 21:11:00+03	99600.00
64A069	2017-07-07 16:31:00+03	28800.00
64A0B7	2017-07-12 12:19:00+03	12600.00
64A163	2017-07-11 17:20:00+03	131600.00
64A1AF	2017-08-04 02:45:00+03	124200.00
64A1BB	2017-08-09 15:50:00+03	55800.00
64A1C9	2017-07-05 04:05:00+03	47000.00
64A1E9	2017-08-05 05:00:00+03	22400.00
64A1F1	2017-08-06 10:01:00+03	37200.00
64A2AB	2017-07-25 20:45:00+03	16400.00
64A2DB	2017-07-10 07:20:00+03	29600.00
64A2E1	2017-07-23 03:46:00+03	35800.00
64A2FB	2017-07-28 06:28:00+03	67400.00
64A3A5	2017-08-04 22:34:00+03	124000.00
64A3C1	2017-08-09 15:49:00+03	11600.00
64A3E5	2017-07-26 18:21:00+03	30400.00
64A407	2017-08-06 08:53:00+03	7200.00
64A45B	2017-07-21 08:06:00+03	84500.00
64A48B	2017-07-30 14:45:00+03	339800.00
64A516	2017-08-10 13:14:00+03	82600.00
64A562	2017-07-27 17:31:00+03	39400.00
64A579	2017-07-04 09:03:00+03	45200.00
64A583	2017-07-26 05:59:00+03	92200.00
64A616	2017-07-20 14:08:00+03	88100.00
64A666	2017-07-22 05:36:00+03	186900.00
64A6CC	2017-08-05 16:25:00+03	112000.00
64A745	2017-08-05 23:02:00+03	38800.00
64A78E	2017-07-12 23:35:00+03	242300.00
64A7C9	2017-08-15 07:43:00+03	55600.00
64A7E9	2017-07-10 02:08:00+03	73600.00
64A7F9	2017-07-17 16:00:00+03	44000.00
64A81E	2017-07-20 10:39:00+03	56000.00
64A866	2017-08-08 11:33:00+03	246000.00
64A87F	2017-07-09 15:41:00+03	56000.00
64A8F0	2017-07-19 22:56:00+03	42800.00
64A924	2017-08-04 15:54:00+03	46800.00
64A9A4	2017-08-05 12:14:00+03	103600.00
64A9FF	2017-07-19 07:41:00+03	10600.00
64AA03	2017-07-09 20:40:00+03	64300.00
64AA8C	2017-07-31 11:36:00+03	28800.00
64AAE1	2017-08-11 18:35:00+03	111600.00
64AB04	2017-07-06 23:46:00+03	95200.00
64AB0C	2017-08-10 12:24:00+03	94200.00
64AB51	2017-07-10 10:34:00+03	37200.00
64AB73	2017-08-04 20:04:00+03	72200.00
64AB9B	2017-08-06 15:13:00+03	14000.00
64ABB9	2017-08-04 15:24:00+03	37800.00
64ABBE	2017-07-17 22:04:00+03	11600.00
64ABC6	2017-07-28 08:55:00+03	46400.00
64AC03	2017-08-03 14:22:00+03	23600.00
64AC25	2017-06-28 19:41:00+03	128800.00
64AC8D	2017-07-02 14:52:00+03	98400.00
64AC95	2017-07-05 04:36:00+03	206400.00
64AC96	2017-07-27 10:55:00+03	112600.00
64AC9E	2017-07-17 09:15:00+03	140900.00
64AD05	2017-07-31 16:49:00+03	271300.00
64AD19	2017-07-07 15:33:00+03	32400.00
64AD20	2017-08-05 01:47:00+03	33600.00
64AD31	2017-07-08 15:40:00+03	57800.00
64AD63	2017-07-27 12:52:00+03	123000.00
64ADC6	2017-07-18 23:26:00+03	78600.00
64AE28	2017-07-05 06:29:00+03	26100.00
64AE38	2017-07-13 05:34:00+03	88800.00
64AE78	2017-07-17 13:07:00+03	167400.00
64AEB0	2017-07-14 19:50:00+03	49500.00
64AED8	2017-07-01 00:30:00+03	28800.00
64AF88	2017-08-03 14:58:00+03	248400.00
64AFE1	2017-07-07 18:48:00+03	170300.00
64B02B	2017-06-28 14:29:00+03	258000.00
64B053	2017-07-03 02:29:00+03	184300.00
64B06E	2017-08-08 16:58:00+03	50600.00
64B089	2017-08-10 00:51:00+03	34000.00
64B0EC	2017-07-08 01:23:00+03	68900.00
64B0F9	2017-07-28 12:13:00+03	34000.00
64B104	2017-07-15 00:11:00+03	40800.00
64B122	2017-08-14 02:03:00+03	34000.00
64B12A	2017-07-31 16:59:00+03	73600.00
64B142	2017-07-01 23:25:00+03	23200.00
64B146	2017-07-09 19:53:00+03	47000.00
64B1D9	2017-08-05 11:54:00+03	37700.00
64B20F	2017-08-01 21:15:00+03	70800.00
64B26A	2017-08-11 21:38:00+03	125400.00
64B2E5	2017-07-26 05:49:00+03	46400.00
64B31F	2017-08-13 03:27:00+03	58400.00
64B340	2017-08-13 05:50:00+03	128600.00
64B3BF	2017-07-15 06:40:00+03	19600.00
64B3DA	2017-07-25 18:06:00+03	58500.00
64B4A7	2017-07-18 23:43:00+03	26200.00
64B4BB	2017-08-07 03:11:00+03	89700.00
64B533	2017-07-15 04:40:00+03	50600.00
64B604	2017-07-17 01:52:00+03	56900.00
64B71B	2017-08-06 05:39:00+03	27300.00
64B74E	2017-07-02 06:42:00+03	54800.00
64B791	2017-07-17 20:44:00+03	86800.00
64B7A3	2017-07-05 00:06:00+03	106300.00
64B837	2017-07-23 01:04:00+03	128900.00
64B879	2017-08-08 02:24:00+03	86600.00
64B900	2017-07-03 05:27:00+03	61500.00
64B939	2017-07-05 07:15:00+03	45200.00
64B97C	2017-08-09 21:56:00+03	28800.00
64B98B	2017-08-08 18:13:00+03	66000.00
64BA22	2017-07-31 04:16:00+03	55800.00
64BA3B	2017-07-11 03:18:00+03	27300.00
64BAD4	2017-07-13 13:58:00+03	61400.00
64BB0F	2017-07-15 03:41:00+03	19600.00
64BB21	2017-07-29 18:01:00+03	129400.00
64BB69	2017-07-26 12:45:00+03	165500.00
64BC3B	2017-07-16 17:27:00+03	43000.00
64BC48	2017-08-14 03:32:00+03	45100.00
64BCDE	2017-08-06 14:49:00+03	46400.00
64BD2F	2017-07-06 03:50:00+03	48800.00
64BD48	2017-08-10 15:43:00+03	37200.00
64BD9D	2017-08-05 05:39:00+03	186900.00
64BDD0	2017-08-01 11:15:00+03	28800.00
64BDFC	2017-08-09 17:40:00+03	47100.00
64BE1A	2017-08-01 20:01:00+03	28700.00
64BE2C	2017-07-04 04:48:00+03	6000.00
64BE3D	2017-07-10 01:48:00+03	123000.00
64BE5F	2017-07-24 02:45:00+03	273400.00
64BE7C	2017-07-17 10:34:00+03	135000.00
64BE88	2017-07-23 14:29:00+03	43200.00
64BEB7	2017-08-01 08:36:00+03	100600.00
64BEC5	2017-08-05 21:29:00+03	37700.00
64BECC	2017-07-24 10:19:00+03	23200.00
64BF9E	2017-08-01 16:14:00+03	15400.00
64C011	2017-07-14 13:36:00+03	134800.00
64C045	2017-08-15 02:57:00+03	9800.00
64C089	2017-07-07 16:36:00+03	33100.00
64C0D6	2017-07-03 18:09:00+03	82900.00
64C126	2017-07-23 10:21:00+03	179300.00
64C176	2017-08-14 09:15:00+03	273000.00
64C184	2017-08-09 16:00:00+03	37000.00
64C1A8	2017-07-03 05:08:00+03	90400.00
64C1AD	2017-08-02 02:53:00+03	12600.00
64C1E0	2017-08-10 02:41:00+03	27000.00
64C236	2017-08-03 00:13:00+03	28600.00
64C259	2017-07-13 18:59:00+03	55800.00
64C2B0	2017-07-12 14:51:00+03	60600.00
64C2C8	2017-07-05 21:37:00+03	92100.00
64C2DD	2017-07-08 03:56:00+03	44000.00
64C357	2017-07-13 19:34:00+03	205400.00
64C365	2017-08-01 06:18:00+03	22000.00
64C3A4	2017-08-11 15:45:00+03	34400.00
64C3E7	2017-06-26 20:59:00+03	15000.00
64C3EE	2017-07-12 00:58:00+03	68800.00
64C41A	2017-07-21 01:40:00+03	53100.00
64C44C	2017-07-19 13:51:00+03	246000.00
64C49E	2017-07-21 19:49:00+03	20400.00
64C4F2	2017-07-16 16:46:00+03	123000.00
64C575	2017-07-25 05:03:00+03	52900.00
64C620	2017-07-21 18:01:00+03	29600.00
64C634	2017-07-26 05:14:00+03	46200.00
64C63D	2017-08-04 00:10:00+03	399600.00
64C657	2017-07-21 03:25:00+03	56600.00
64C6A3	2017-07-04 12:47:00+03	43800.00
64C77D	2017-08-02 03:50:00+03	23600.00
64C7A1	2017-08-11 03:39:00+03	37900.00
64C7C0	2017-07-22 08:18:00+03	112600.00
64C7C5	2017-08-15 12:47:00+03	26200.00
64C7CD	2017-08-01 21:33:00+03	45100.00
64C7D2	2017-08-10 20:13:00+03	14800.00
64C86F	2017-07-08 13:08:00+03	52000.00
64C881	2017-07-09 03:03:00+03	62600.00
64C8CF	2017-07-29 16:34:00+03	99200.00
64C8FB	2017-07-04 23:43:00+03	12600.00
64C928	2017-08-14 01:20:00+03	44800.00
64C930	2017-07-09 12:04:00+03	56000.00
64C94E	2017-07-31 12:02:00+03	123000.00
64C971	2017-07-07 14:53:00+03	177200.00
64CA28	2017-08-11 15:48:00+03	210200.00
64CA5A	2017-07-24 11:57:00+03	48800.00
64CB26	2017-08-04 19:19:00+03	75300.00
64CB58	2017-08-08 21:10:00+03	24000.00
64CB81	2017-07-14 02:53:00+03	48800.00
64CBDF	2017-07-19 23:09:00+03	59800.00
64CC5B	2017-07-28 02:52:00+03	28600.00
64CC60	2017-07-06 22:30:00+03	28800.00
64CC7E	2017-08-06 21:46:00+03	199300.00
64CCCE	2017-07-09 15:35:00+03	78000.00
64CD3C	2017-08-09 22:34:00+03	46400.00
64CD61	2017-07-04 14:31:00+03	93500.00
64CDC2	2017-08-03 17:54:00+03	47100.00
64CE20	2017-07-03 18:48:00+03	31600.00
64CEC0	2017-08-04 22:23:00+03	93900.00
64CEC2	2017-07-23 13:38:00+03	46000.00
64CF00	2017-08-10 19:51:00+03	24200.00
64D011	2017-07-31 09:32:00+03	20900.00
64D026	2017-08-09 11:21:00+03	131600.00
64D028	2017-07-07 02:16:00+03	147700.00
64D043	2017-07-04 22:50:00+03	57600.00
64D058	2017-07-26 17:03:00+03	24200.00
64D072	2017-07-06 23:10:00+03	39400.00
64D086	2017-07-23 06:19:00+03	81300.00
64D0D5	2017-08-09 02:48:00+03	167400.00
64D0E6	2017-08-04 20:57:00+03	21400.00
64D114	2017-08-14 09:18:00+03	44300.00
64D123	2017-08-09 02:00:00+03	24200.00
64D165	2017-08-15 05:14:00+03	136600.00
64D1CB	2017-07-15 10:55:00+03	65500.00
64D251	2017-07-30 22:17:00+03	16800.00
64D263	2017-07-12 01:26:00+03	65400.00
64D2CA	2017-07-27 01:09:00+03	89700.00
64D3C4	2017-08-03 19:40:00+03	56000.00
64D3D0	2017-08-05 15:55:00+03	57600.00
64D3FF	2017-07-01 01:23:00+03	80200.00
64D422	2017-08-09 03:12:00+03	59200.00
64D449	2017-07-09 23:50:00+03	80000.00
64D49B	2017-08-06 20:33:00+03	38800.00
64D4C2	2017-08-04 16:18:00+03	27800.00
64D4DC	2017-07-30 02:36:00+03	94800.00
64D514	2017-07-13 18:38:00+03	24800.00
64D51C	2017-08-10 04:05:00+03	129200.00
64D52E	2017-07-07 00:59:00+03	93400.00
64D53D	2017-07-03 07:08:00+03	176000.00
64D56C	2017-08-06 02:28:00+03	82000.00
64D58E	2017-07-29 17:34:00+03	6800.00
64D5B0	2017-07-20 22:47:00+03	94000.00
64D66F	2017-07-09 00:29:00+03	57800.00
64D6EA	2017-07-11 13:48:00+03	56200.00
64D708	2017-07-19 12:27:00+03	67600.00
64D742	2017-07-04 12:20:00+03	8200.00
64D762	2017-08-01 06:12:00+03	93400.00
64D7A3	2017-07-31 18:53:00+03	94700.00
64D7AE	2017-08-08 16:07:00+03	32800.00
64D7CA	2017-07-31 20:50:00+03	56900.00
64D7FF	2017-07-02 14:25:00+03	58200.00
64D806	2017-07-29 02:54:00+03	164600.00
64D832	2017-07-11 11:40:00+03	140100.00
64D841	2017-07-19 18:01:00+03	14000.00
64D8A5	2017-07-24 04:59:00+03	145700.00
64D8C3	2017-07-25 11:39:00+03	69200.00
64D8CA	2017-08-02 00:59:00+03	36200.00
64D938	2017-07-08 03:34:00+03	38400.00
64D952	2017-07-30 15:09:00+03	44000.00
64DA39	2017-07-04 12:37:00+03	229300.00
64DA91	2017-07-25 19:26:00+03	299200.00
64DAA1	2017-07-12 11:30:00+03	28000.00
64DBA0	2017-08-15 06:28:00+03	25800.00
64DBC7	2017-07-18 01:29:00+03	86400.00
64DBED	2017-08-05 01:09:00+03	86600.00
64DBEF	2017-07-10 15:02:00+03	57600.00
64DC2C	2017-08-04 02:22:00+03	89700.00
64DCF6	2017-08-03 21:55:00+03	38600.00
64DD10	2017-08-06 14:15:00+03	34400.00
64DD14	2017-07-30 01:10:00+03	56100.00
64DD2A	2017-07-20 05:16:00+03	49100.00
64DD2E	2017-08-13 03:10:00+03	39100.00
64DDE6	2017-08-13 20:25:00+03	31600.00
64DE78	2017-07-05 03:14:00+03	48800.00
64DF3D	2017-07-31 14:50:00+03	45300.00
64DF46	2017-07-07 13:15:00+03	51600.00
64DF63	2017-08-10 03:56:00+03	99200.00
64DF73	2017-07-24 18:30:00+03	57500.00
64DF83	2017-08-05 19:39:00+03	9800.00
64DFEE	2017-07-23 05:16:00+03	27800.00
64DFF2	2017-07-03 17:25:00+03	31600.00
64E0DF	2017-07-05 09:24:00+03	24400.00
64E0FE	2017-07-12 20:22:00+03	28000.00
64E11B	2017-07-10 07:56:00+03	28800.00
64E191	2017-07-08 12:13:00+03	246000.00
64E19A	2017-08-05 14:53:00+03	38400.00
64E1A5	2017-07-17 23:50:00+03	135600.00
64E1B4	2017-07-25 02:52:00+03	69000.00
64E24C	2017-07-27 12:54:00+03	52000.00
64E26F	2017-08-07 22:30:00+03	88800.00
64E2B0	2017-08-13 12:29:00+03	32500.00
64E2DF	2017-08-03 01:34:00+03	148200.00
64E2EF	2017-08-13 15:12:00+03	64800.00
64E358	2017-07-01 08:32:00+03	25800.00
64E35B	2017-07-13 13:31:00+03	40800.00
64E3B0	2017-08-08 14:20:00+03	54000.00
64E3DC	2017-08-10 07:26:00+03	30400.00
64E3EE	2017-06-29 15:52:00+03	34600.00
64E3FF	2017-08-01 18:17:00+03	49000.00
64E42D	2017-07-15 07:22:00+03	135600.00
64E437	2017-07-22 01:05:00+03	86800.00
64E49D	2017-08-13 13:21:00+03	85200.00
64E503	2017-08-14 03:06:00+03	25400.00
64E51D	2017-07-14 09:41:00+03	111600.00
64E57F	2017-08-01 07:20:00+03	148800.00
64E5AB	2017-08-13 15:23:00+03	13700.00
64E5AE	2017-07-31 16:59:00+03	50800.00
64E5B4	2017-08-06 16:11:00+03	105600.00
64E5D9	2017-07-13 18:23:00+03	80000.00
64E6E1	2017-07-20 15:56:00+03	6700.00
64E6FD	2017-08-01 19:21:00+03	70600.00
64E772	2017-08-09 12:23:00+03	87900.00
64E7BA	2017-07-09 20:49:00+03	37500.00
64E7EC	2017-07-03 12:46:00+03	123000.00
64E7F4	2017-07-15 17:42:00+03	12600.00
64E7FD	2017-08-14 16:40:00+03	114400.00
64E89C	2017-08-12 01:29:00+03	17800.00
64E91E	2017-07-20 18:51:00+03	75600.00
64E944	2017-07-27 21:29:00+03	97600.00
64E9AF	2017-07-09 21:37:00+03	57600.00
64E9C3	2017-07-29 16:18:00+03	40000.00
64E9DD	2017-07-30 14:09:00+03	32700.00
64E9E5	2017-08-05 18:03:00+03	49400.00
64E9FD	2017-07-21 00:35:00+03	62600.00
64EA1B	2017-07-03 04:53:00+03	273600.00
64EABC	2017-07-13 17:03:00+03	55800.00
64EAF9	2017-07-02 12:43:00+03	55800.00
64EAFA	2017-07-27 22:46:00+03	86400.00
64EB17	2017-07-31 21:42:00+03	196100.00
64EBD9	2017-07-09 06:39:00+03	11600.00
64EBFD	2017-07-24 08:30:00+03	65100.00
64EC44	2017-08-14 15:26:00+03	39200.00
64EC97	2017-07-22 18:50:00+03	60400.00
64EC99	2017-07-04 08:59:00+03	109600.00
64ED2C	2017-07-22 15:52:00+03	47200.00
64ED80	2017-08-14 15:26:00+03	92800.00
64EDC6	2017-08-04 00:30:00+03	108800.00
64EDE9	2017-07-07 23:09:00+03	15200.00
64EDEE	2017-08-11 23:18:00+03	52400.00
64EE20	2017-07-31 05:07:00+03	106400.00
64EE3B	2017-07-19 16:56:00+03	25100.00
64EE40	2017-07-07 00:10:00+03	114800.00
64EF65	2017-07-15 22:28:00+03	54400.00
64EFBF	2017-07-26 05:28:00+03	115600.00
64EFCF	2017-07-04 08:58:00+03	28000.00
64F000	2017-08-10 09:30:00+03	59200.00
64F001	2017-07-24 12:44:00+03	54500.00
64F021	2017-08-07 11:08:00+03	23200.00
64F039	2017-08-01 09:08:00+03	305100.00
64F058	2017-08-04 03:40:00+03	189000.00
64F066	2017-08-10 06:31:00+03	147700.00
64F074	2017-07-24 01:19:00+03	11800.00
64F11A	2017-07-01 00:16:00+03	14400.00
64F130	2017-07-13 04:22:00+03	13000.00
64F151	2017-08-08 17:21:00+03	199800.00
64F190	2017-07-18 07:11:00+03	20800.00
64F27F	2017-07-31 22:12:00+03	59900.00
64F295	2017-07-24 00:51:00+03	208200.00
64F2F6	2017-07-29 23:26:00+03	32500.00
64F36A	2017-07-10 03:39:00+03	80700.00
64F390	2017-07-31 03:54:00+03	58000.00
64F449	2017-07-03 13:55:00+03	38400.00
64F471	2017-07-21 15:03:00+03	123000.00
64F494	2017-07-23 22:07:00+03	78300.00
64F4F8	2017-08-01 19:50:00+03	39800.00
64F519	2017-08-02 23:42:00+03	73500.00
64F526	2017-08-08 19:33:00+03	153300.00
64F5A4	2017-06-25 00:56:00+03	45100.00
64F5CD	2017-07-14 00:49:00+03	15000.00
64F615	2017-08-04 06:45:00+03	46800.00
64F6A4	2017-07-10 04:36:00+03	41200.00
64F6AF	2017-07-11 02:59:00+03	6300.00
64F6F4	2017-07-19 00:11:00+03	31100.00
64F78F	2017-07-17 04:58:00+03	90300.00
64F7FF	2017-07-12 22:12:00+03	94900.00
64F836	2017-07-15 21:38:00+03	136600.00
64F866	2017-07-22 02:18:00+03	58900.00
64F899	2017-07-03 02:06:00+03	46200.00
64F89A	2017-07-03 08:30:00+03	24700.00
64F8D7	2017-07-21 14:12:00+03	28700.00
64F920	2017-08-11 01:16:00+03	26000.00
64F98A	2017-08-12 10:18:00+03	28800.00
64F98D	2017-07-04 20:18:00+03	47900.00
64F996	2017-07-27 04:27:00+03	58800.00
64F998	2017-07-01 12:01:00+03	76400.00
64F9C0	2017-07-10 02:39:00+03	105000.00
64FA0B	2017-07-08 03:27:00+03	9300.00
64FA49	2017-07-22 11:25:00+03	135300.00
64FA7F	2017-08-05 11:24:00+03	14800.00
64FB1E	2017-07-31 06:29:00+03	120700.00
64FB39	2017-07-30 12:38:00+03	62600.00
64FB9E	2017-07-11 03:21:00+03	32200.00
64FBAD	2017-07-15 02:05:00+03	22600.00
64FC26	2017-07-26 03:34:00+03	68800.00
64FC48	2017-08-05 13:36:00+03	72400.00
64FCFF	2017-08-13 13:44:00+03	81500.00
64FD24	2017-07-25 00:19:00+03	126300.00
64FD47	2017-07-10 17:42:00+03	20400.00
64FD66	2017-08-14 11:13:00+03	26000.00
64FDFB	2017-08-07 05:39:00+03	61800.00
64FE06	2017-07-24 09:00:00+03	28000.00
64FE24	2017-08-13 18:22:00+03	28000.00
64FE64	2017-08-12 21:59:00+03	62100.00
64FECF	2017-08-08 01:01:00+03	316000.00
64FEE3	2017-07-24 16:33:00+03	112000.00
64FEE5	2017-08-05 19:12:00+03	43200.00
64FEFF	2017-08-11 15:24:00+03	38000.00
64FF28	2017-08-12 03:29:00+03	30200.00
64FF3A	2017-07-30 10:46:00+03	21600.00
64FF7A	2017-08-08 02:12:00+03	68600.00
64FFE3	2017-07-19 02:18:00+03	67400.00
650018	2017-07-25 09:47:00+03	56000.00
6500BD	2017-07-15 14:23:00+03	7400.00
6500C4	2017-08-09 21:54:00+03	117000.00
65016E	2017-07-12 01:31:00+03	47200.00
650175	2017-08-12 09:36:00+03	39200.00
6501A6	2017-08-10 21:19:00+03	125200.00
6501F9	2017-08-10 20:02:00+03	182200.00
65020D	2017-07-02 08:11:00+03	93800.00
650215	2017-08-10 01:47:00+03	30800.00
65024B	2017-08-03 16:35:00+03	199700.00
6502C6	2017-07-03 02:14:00+03	20400.00
650303	2017-08-13 02:14:00+03	156100.00
650304	2017-08-11 13:01:00+03	85400.00
650398	2017-07-21 07:10:00+03	56000.00
650408	2017-08-13 21:35:00+03	23600.00
65042C	2017-07-18 19:06:00+03	67600.00
650488	2017-07-08 03:32:00+03	56000.00
650496	2017-07-15 06:03:00+03	44800.00
6504CB	2017-07-05 21:15:00+03	23900.00
6504EC	2017-07-23 18:46:00+03	51900.00
650537	2017-06-27 09:38:00+03	56900.00
650566	2017-08-05 17:50:00+03	31400.00
650594	2017-08-10 18:49:00+03	292100.00
6505EF	2017-07-10 19:16:00+03	23100.00
65065D	2017-08-05 02:27:00+03	76400.00
6506D8	2017-07-13 14:12:00+03	48400.00
65072B	2017-08-15 17:39:00+03	99300.00
6507E0	2017-07-31 19:05:00+03	12600.00
65080D	2017-07-12 08:48:00+03	73500.00
650854	2017-07-06 12:27:00+03	78800.00
650878	2017-07-29 02:48:00+03	46400.00
650936	2017-08-02 11:08:00+03	59200.00
650940	2017-07-24 08:08:00+03	50400.00
650941	2017-08-07 12:35:00+03	9800.00
65096E	2017-07-08 02:15:00+03	6800.00
6509A4	2017-07-23 07:09:00+03	12400.00
6509AA	2017-07-29 01:46:00+03	46000.00
650A2E	2017-08-06 14:36:00+03	48800.00
650A33	2017-07-01 12:47:00+03	49900.00
650A34	2017-08-15 01:01:00+03	18000.00
650A74	2017-07-10 21:25:00+03	71600.00
650AB0	2017-07-03 04:21:00+03	154800.00
650B70	2017-07-29 19:14:00+03	55800.00
650B8A	2017-08-09 09:03:00+03	12600.00
650C02	2017-07-08 10:48:00+03	96200.00
650C1D	2017-07-16 10:36:00+03	19300.00
650C97	2017-07-22 01:29:00+03	28000.00
650CA1	2017-07-28 07:30:00+03	36200.00
650CBC	2017-08-07 05:19:00+03	24800.00
650D02	2017-07-12 14:21:00+03	26800.00
650D08	2017-07-27 01:41:00+03	86600.00
650D31	2017-08-07 22:44:00+03	265700.00
650D6E	2017-07-17 13:20:00+03	140200.00
650D78	2017-08-09 20:38:00+03	113900.00
650E10	2017-08-10 05:53:00+03	73600.00
650E56	2017-08-10 20:23:00+03	290500.00
650E6A	2017-07-22 01:25:00+03	22000.00
650E80	2017-07-27 03:28:00+03	12600.00
650EAC	2017-08-10 18:55:00+03	31000.00
650EF2	2017-07-20 21:11:00+03	39300.00
650F0A	2017-08-15 12:41:00+03	30800.00
650F26	2017-07-08 07:15:00+03	170000.00
650F44	2017-07-24 03:47:00+03	28000.00
650F54	2017-06-29 16:15:00+03	35200.00
650F65	2017-07-18 22:13:00+03	132800.00
650FCA	2017-08-07 06:43:00+03	131600.00
650FCC	2017-08-02 02:45:00+03	58400.00
650FCE	2017-07-10 06:49:00+03	56000.00
650FFC	2017-07-27 19:54:00+03	122700.00
651002	2017-08-11 06:22:00+03	128800.00
651076	2017-07-05 23:15:00+03	15800.00
651103	2017-07-27 03:21:00+03	118000.00
65113B	2017-08-12 01:32:00+03	70100.00
651150	2017-08-14 07:23:00+03	146300.00
651182	2017-07-23 02:38:00+03	197000.00
651282	2017-08-03 03:09:00+03	94000.00
651295	2017-07-09 22:02:00+03	31600.00
6512B6	2017-08-11 01:18:00+03	66000.00
6512D3	2017-08-11 01:20:00+03	73600.00
6512FE	2017-07-12 11:26:00+03	70500.00
651302	2017-08-09 06:03:00+03	57400.00
651337	2017-08-13 16:11:00+03	28800.00
65144E	2017-08-15 12:53:00+03	246000.00
6514AE	2017-08-14 03:53:00+03	32700.00
6514BC	2017-07-15 19:38:00+03	28000.00
6514CD	2017-07-19 09:18:00+03	172400.00
651586	2017-08-02 07:21:00+03	81300.00
6515B1	2017-07-03 06:20:00+03	56000.00
6515BA	2017-08-06 12:21:00+03	44000.00
6515C4	2017-08-10 12:21:00+03	35300.00
6515C9	2017-07-07 16:03:00+03	37200.00
65162F	2017-08-06 04:52:00+03	49100.00
65167B	2017-07-11 05:52:00+03	46400.00
651689	2017-07-31 02:46:00+03	86400.00
6516A8	2017-07-26 08:03:00+03	32500.00
6516F3	2017-07-27 00:04:00+03	118300.00
6516F9	2017-08-10 16:17:00+03	65500.00
65173E	2017-08-06 04:18:00+03	57500.00
651774	2017-08-04 19:00:00+03	24400.00
651789	2017-08-09 18:24:00+03	95200.00
6517B2	2017-07-22 21:19:00+03	316900.00
6517C1	2017-07-14 08:30:00+03	42400.00
6517DC	2017-07-01 15:34:00+03	75600.00
6517F4	2017-07-19 01:54:00+03	46300.00
6518AA	2017-07-14 19:29:00+03	66000.00
6518C3	2017-08-05 20:58:00+03	132800.00
6518E9	2017-07-12 21:49:00+03	92400.00
651953	2017-07-19 03:56:00+03	34000.00
651985	2017-08-11 17:39:00+03	129400.00
6519A4	2017-08-13 12:40:00+03	50100.00
6519C4	2017-08-14 16:36:00+03	120400.00
651A37	2017-08-12 23:14:00+03	112600.00
651A47	2017-07-07 05:31:00+03	68800.00
651B0A	2017-08-07 11:51:00+03	124200.00
651B39	2017-07-23 00:54:00+03	148800.00
651B71	2017-07-09 04:09:00+03	124200.00
651B77	2017-07-31 21:10:00+03	23200.00
651B81	2017-07-06 14:11:00+03	28000.00
651BCD	2017-08-08 14:33:00+03	13400.00
651C9F	2017-07-28 10:09:00+03	51800.00
651CBF	2017-08-04 20:48:00+03	16400.00
651CC2	2017-07-05 02:02:00+03	112000.00
651CDE	2017-07-12 02:46:00+03	105600.00
651D35	2017-07-19 16:03:00+03	23200.00
651DB3	2017-07-29 00:15:00+03	408500.00
651E00	2017-07-11 10:35:00+03	52700.00
651E2C	2017-07-02 01:20:00+03	23200.00
651E2D	2017-07-14 07:39:00+03	12600.00
651E41	2017-07-09 19:15:00+03	55800.00
651EBD	2017-07-12 13:05:00+03	113000.00
651F0E	2017-07-10 06:57:00+03	224000.00
651F85	2017-07-17 23:28:00+03	40800.00
651FA8	2017-08-14 04:30:00+03	26800.00
652044	2017-08-03 05:18:00+03	22600.00
65204B	2017-07-18 23:47:00+03	23100.00
6520C6	2017-08-12 13:29:00+03	71900.00
65211C	2017-07-09 23:41:00+03	16400.00
65214E	2017-07-30 07:46:00+03	270700.00
6521B0	2017-08-14 16:08:00+03	18700.00
6521F6	2017-07-30 18:55:00+03	49600.00
652271	2017-07-24 04:25:00+03	81600.00
65227B	2017-08-07 18:33:00+03	112600.00
652327	2017-08-11 14:55:00+03	114800.00
65232B	2017-07-02 19:59:00+03	54300.00
65234B	2017-08-05 12:58:00+03	50200.00
65235A	2017-07-20 18:28:00+03	137600.00
6523B7	2017-07-15 08:55:00+03	217900.00
6523BF	2017-08-01 00:13:00+03	35200.00
6523D8	2017-07-24 05:45:00+03	39300.00
6523F5	2017-08-13 16:15:00+03	80300.00
652415	2017-08-10 09:17:00+03	16400.00
652417	2017-07-04 22:29:00+03	57400.00
65249B	2017-08-13 21:41:00+03	22000.00
652531	2017-08-07 02:58:00+03	40800.00
65263B	2017-08-05 20:07:00+03	46200.00
652659	2017-07-07 05:54:00+03	166100.00
6526C7	2017-07-31 07:07:00+03	113000.00
6526FE	2017-08-06 19:16:00+03	46200.00
652818	2017-08-07 08:11:00+03	112600.00
652848	2017-07-03 21:17:00+03	72400.00
65284F	2017-07-30 15:35:00+03	87200.00
65286A	2017-07-02 22:08:00+03	26200.00
6528A1	2017-07-28 17:59:00+03	118400.00
652907	2017-07-24 04:22:00+03	67600.00
65292B	2017-08-12 09:52:00+03	113300.00
652934	2017-08-08 12:59:00+03	101200.00
6529A4	2017-07-01 06:46:00+03	94200.00
6529DC	2017-07-30 09:44:00+03	79500.00
652A01	2017-07-12 13:27:00+03	54800.00
652A6B	2017-07-18 05:24:00+03	46200.00
652AB3	2017-07-02 05:31:00+03	100800.00
652ABB	2017-07-08 10:39:00+03	128600.00
652B17	2017-07-01 02:44:00+03	23200.00
652BA1	2017-07-21 18:27:00+03	75800.00
652BB6	2017-07-18 22:22:00+03	26800.00
652C11	2017-08-13 01:33:00+03	112000.00
652C5B	2017-07-25 15:48:00+03	93400.00
652CB6	2017-08-08 09:26:00+03	286700.00
652D15	2017-07-30 19:50:00+03	58500.00
652D4B	2017-08-09 14:59:00+03	35800.00
652D88	2017-07-30 06:44:00+03	40400.00
652DAA	2017-07-10 15:45:00+03	47900.00
652DFB	2017-07-04 05:53:00+03	79600.00
652E0A	2017-07-22 19:44:00+03	52900.00
652E11	2017-07-14 22:23:00+03	114300.00
652E12	2017-07-31 15:09:00+03	46000.00
652E4F	2017-07-07 16:13:00+03	28000.00
652E93	2017-08-01 11:08:00+03	25600.00
652E95	2017-08-12 13:01:00+03	63700.00
652ED6	2017-06-29 19:13:00+03	54800.00
652EE6	2017-08-15 06:23:00+03	257700.00
652F5A	2017-08-08 09:38:00+03	269400.00
652FEC	2017-07-27 05:20:00+03	168000.00
652FF0	2017-07-26 14:39:00+03	68800.00
652FFF	2017-07-15 01:44:00+03	52800.00
65307D	2017-07-14 01:09:00+03	24800.00
653094	2017-08-08 08:54:00+03	28000.00
6530B6	2017-07-15 20:44:00+03	75600.00
6530F3	2017-07-06 13:36:00+03	47400.00
653120	2017-07-27 02:39:00+03	57400.00
653153	2017-08-04 05:28:00+03	28800.00
653180	2017-07-13 00:50:00+03	138000.00
65324E	2017-08-13 14:25:00+03	23200.00
6532BB	2017-07-22 06:29:00+03	36400.00
653386	2017-07-17 08:34:00+03	55800.00
6533F2	2017-07-23 04:26:00+03	27200.00
653415	2017-07-13 21:44:00+03	8200.00
65343B	2017-07-08 15:00:00+03	28800.00
65347B	2017-07-23 09:41:00+03	65200.00
6534E6	2017-07-15 12:35:00+03	40000.00
653519	2017-07-01 16:35:00+03	89600.00
653529	2017-07-23 05:08:00+03	206200.00
653537	2017-07-13 14:21:00+03	393000.00
6535D5	2017-06-29 09:28:00+03	70600.00
6535D8	2017-07-28 11:02:00+03	23600.00
6535E2	2017-07-11 13:26:00+03	72400.00
653613	2017-08-15 05:14:00+03	21400.00
653631	2017-07-23 14:27:00+03	58600.00
653634	2017-07-01 10:22:00+03	246000.00
653663	2017-07-07 05:53:00+03	79900.00
65367B	2017-08-03 05:36:00+03	29600.00
65374B	2017-07-12 16:08:00+03	26000.00
65374C	2017-08-13 03:38:00+03	12600.00
653772	2017-07-22 01:18:00+03	13000.00
653778	2017-07-25 08:03:00+03	56000.00
65378E	2017-07-05 16:31:00+03	179400.00
65379B	2017-07-16 02:38:00+03	23200.00
65379D	2017-07-06 18:25:00+03	37900.00
6537E3	2017-07-08 11:52:00+03	272800.00
65380B	2017-07-18 11:55:00+03	23600.00
6538C7	2017-07-20 18:28:00+03	29600.00
653A20	2017-07-21 00:08:00+03	88400.00
653A70	2017-07-15 13:26:00+03	119700.00
653A77	2017-08-03 03:12:00+03	95600.00
653A9E	2017-07-05 10:39:00+03	62800.00
653B4F	2017-07-11 19:39:00+03	148200.00
653B8D	2017-08-10 14:24:00+03	135400.00
653BED	2017-08-06 16:24:00+03	26000.00
653BEE	2017-07-06 08:21:00+03	515000.00
653BF1	2017-08-05 00:33:00+03	92800.00
653C37	2017-07-26 07:09:00+03	49100.00
653C3E	2017-08-08 08:20:00+03	79600.00
653C6D	2017-07-18 22:39:00+03	168000.00
653C9C	2017-08-12 12:46:00+03	23400.00
653CB0	2017-07-25 21:33:00+03	55800.00
653D43	2017-07-31 16:08:00+03	225800.00
653D50	2017-07-24 10:37:00+03	57400.00
653D59	2017-07-13 22:29:00+03	39300.00
653D6D	2017-08-12 04:17:00+03	56000.00
653DD4	2017-07-08 23:24:00+03	67700.00
653DFD	2017-07-23 21:02:00+03	305900.00
653E6F	2017-08-11 07:38:00+03	28700.00
653F3B	2017-07-26 02:46:00+03	111600.00
653FD9	2017-07-01 10:30:00+03	70700.00
654051	2017-07-31 08:19:00+03	64700.00
654095	2017-07-02 16:32:00+03	58600.00
65409D	2017-07-06 00:54:00+03	46900.00
6540BB	2017-06-28 20:29:00+03	61900.00
6540D5	2017-07-02 12:11:00+03	38600.00
654118	2017-07-22 14:04:00+03	75500.00
654123	2017-07-22 08:19:00+03	21600.00
65413F	2017-08-02 07:34:00+03	13300.00
6541CE	2017-07-02 07:46:00+03	28000.00
654203	2017-07-06 08:14:00+03	46000.00
654213	2017-08-15 02:32:00+03	56900.00
654244	2017-06-28 07:33:00+03	246000.00
654289	2017-07-02 15:57:00+03	25200.00
654296	2017-08-11 22:37:00+03	19600.00
6542BE	2017-07-10 02:19:00+03	50800.00
6542D5	2017-08-06 13:14:00+03	58900.00
6542FB	2017-08-02 01:00:00+03	44000.00
6543E9	2017-07-20 02:55:00+03	284400.00
654434	2017-07-29 23:47:00+03	21800.00
654440	2017-07-24 18:48:00+03	72600.00
65447A	2017-08-03 02:57:00+03	13600.00
6544AA	2017-07-19 10:37:00+03	113800.00
65450A	2017-07-08 09:43:00+03	13400.00
654515	2017-07-31 11:34:00+03	57400.00
654535	2017-07-26 03:09:00+03	53400.00
65456B	2017-08-15 04:18:00+03	166000.00
65458F	2017-08-04 03:03:00+03	220800.00
6545C9	2017-08-03 16:21:00+03	131900.00
654684	2017-07-23 22:37:00+03	28000.00
65470B	2017-07-03 11:41:00+03	47200.00
65471B	2017-07-08 01:26:00+03	28800.00
654747	2017-07-31 05:26:00+03	55800.00
65476A	2017-08-06 07:19:00+03	37200.00
654788	2017-07-23 11:30:00+03	37900.00
654794	2017-08-04 06:42:00+03	23200.00
65483E	2017-08-09 18:03:00+03	114700.00
654844	2017-07-03 22:29:00+03	123900.00
654852	2017-07-26 09:26:00+03	157200.00
654883	2017-07-09 23:35:00+03	28000.00
65488D	2017-07-30 19:17:00+03	56600.00
654890	2017-07-18 16:16:00+03	6700.00
654891	2017-07-08 21:52:00+03	17000.00
6548E9	2017-07-27 13:06:00+03	69000.00
65499D	2017-08-10 12:36:00+03	56600.00
6549CA	2017-07-03 00:09:00+03	83600.00
6549DA	2017-07-06 18:27:00+03	19600.00
654A09	2017-07-24 13:16:00+03	54000.00
654A6E	2017-08-09 02:53:00+03	66800.00
654A71	2017-07-27 06:52:00+03	99300.00
654AB5	2017-07-01 19:51:00+03	26800.00
654B16	2017-07-24 02:34:00+03	399600.00
654B4C	2017-08-06 06:45:00+03	30400.00
654B78	2017-07-25 15:48:00+03	46000.00
654B7F	2017-07-21 01:21:00+03	20800.00
654BBF	2017-08-03 02:12:00+03	92800.00
654C14	2017-07-05 22:12:00+03	13400.00
654C2A	2017-08-07 08:33:00+03	42800.00
654C73	2017-07-12 08:25:00+03	26800.00
654D12	2017-07-09 15:26:00+03	72400.00
654D1B	2017-07-29 01:23:00+03	135400.00
654D49	2017-08-12 13:52:00+03	12600.00
654DB6	2017-07-20 23:16:00+03	25400.00
654DCE	2017-08-11 21:17:00+03	29600.00
654DF2	2017-08-09 23:20:00+03	62600.00
654DFD	2017-07-01 21:44:00+03	100600.00
654E1C	2017-07-27 04:02:00+03	66600.00
654E27	2017-07-04 04:59:00+03	73500.00
654E4C	2017-07-24 00:46:00+03	24300.00
654EC6	2017-08-09 14:47:00+03	55800.00
654F08	2017-08-13 23:50:00+03	229300.00
654F18	2017-07-09 12:16:00+03	418500.00
654F20	2017-07-05 02:55:00+03	29800.00
654FAF	2017-08-06 09:58:00+03	113300.00
655003	2017-08-06 06:26:00+03	70700.00
65510C	2017-08-07 11:34:00+03	23600.00
65512A	2017-07-22 20:44:00+03	58800.00
65513E	2017-08-09 02:10:00+03	135400.00
655144	2017-08-15 01:01:00+03	25100.00
655158	2017-08-09 18:50:00+03	131100.00
655164	2017-07-16 23:10:00+03	133200.00
655175	2017-07-14 00:34:00+03	32200.00
6551E5	2017-07-03 19:29:00+03	36400.00
6551EB	2017-07-15 15:59:00+03	26800.00
655215	2017-08-11 01:36:00+03	100900.00
65528C	2017-07-21 13:50:00+03	19600.00
65529B	2017-07-04 19:09:00+03	187800.00
6552AD	2017-07-07 18:45:00+03	36800.00
6552C2	2017-07-01 12:01:00+03	98400.00
6552D1	2017-08-13 04:08:00+03	42800.00
6552D5	2017-07-11 09:37:00+03	70300.00
655365	2017-08-04 13:59:00+03	54400.00
65537F	2017-07-19 16:47:00+03	88000.00
6553AB	2017-08-09 02:44:00+03	6300.00
6553E0	2017-08-04 17:14:00+03	117200.00
6553FC	2017-07-07 06:57:00+03	62800.00
655443	2017-07-02 16:52:00+03	12400.00
65546B	2017-08-03 03:16:00+03	46200.00
65549D	2017-08-14 11:02:00+03	171000.00
655545	2017-07-29 21:02:00+03	111600.00
655555	2017-08-07 05:24:00+03	26800.00
65559D	2017-07-13 02:17:00+03	56600.00
6555BC	2017-07-02 18:46:00+03	24400.00
655652	2017-08-10 17:05:00+03	29400.00
6556BA	2017-08-05 20:25:00+03	133100.00
6556C1	2017-07-25 14:04:00+03	37300.00
65573E	2017-07-03 05:51:00+03	19600.00
655797	2017-07-08 02:23:00+03	69200.00
6557A7	2017-07-03 18:45:00+03	21800.00
6557AE	2017-07-28 19:17:00+03	189200.00
6557CB	2017-06-30 01:12:00+03	257600.00
6557EB	2017-08-03 16:02:00+03	28000.00
655853	2017-08-11 07:35:00+03	38600.00
6558CE	2017-07-15 16:08:00+03	46300.00
6558F7	2017-07-12 02:17:00+03	54300.00
65590D	2017-08-01 01:31:00+03	12400.00
65592D	2017-08-02 02:22:00+03	43200.00
655941	2017-07-05 14:47:00+03	50000.00
655974	2017-07-09 18:23:00+03	140100.00
6559F2	2017-07-19 15:19:00+03	97800.00
655A2D	2017-07-19 12:10:00+03	48400.00
655ABA	2017-08-09 06:25:00+03	11800.00
655B46	2017-07-24 01:13:00+03	67100.00
655BCB	2017-07-23 05:49:00+03	26800.00
655C00	2017-07-10 14:01:00+03	36200.00
655C13	2017-07-26 15:45:00+03	14800.00
655C35	2017-07-23 10:13:00+03	13600.00
655C7B	2017-06-30 18:51:00+03	36400.00
655CD2	2017-07-22 15:07:00+03	49800.00
655CDC	2017-08-13 03:40:00+03	27200.00
655DD3	2017-07-19 15:36:00+03	55800.00
655DD6	2017-07-23 18:14:00+03	46200.00
655EBA	2017-07-12 17:20:00+03	26000.00
655EC1	2017-07-05 03:15:00+03	52000.00
655EF8	2017-07-25 10:34:00+03	103000.00
655F1B	2017-07-05 14:13:00+03	62800.00
655F5B	2017-07-05 19:20:00+03	30900.00
655F9B	2017-08-07 12:19:00+03	135400.00
65600F	2017-07-23 05:27:00+03	135400.00
656010	2017-08-06 22:16:00+03	59800.00
6560C1	2017-07-16 02:52:00+03	16400.00
656130	2017-07-09 15:14:00+03	8000.00
65617E	2017-08-09 12:42:00+03	94200.00
6561EC	2017-07-26 19:22:00+03	9200.00
65625B	2017-08-05 20:33:00+03	133900.00
656300	2017-07-14 04:32:00+03	147200.00
65630C	2017-07-25 15:18:00+03	58200.00
65635F	2017-08-12 01:52:00+03	25100.00
6563E5	2017-08-15 00:22:00+03	56600.00
656423	2017-08-09 14:33:00+03	43600.00
6564BA	2017-07-12 10:13:00+03	55800.00
6564F5	2017-07-28 05:55:00+03	286700.00
65650E	2017-08-03 10:51:00+03	397700.00
65651F	2017-07-06 19:00:00+03	42800.00
65653B	2017-07-22 23:10:00+03	134700.00
656554	2017-07-04 04:59:00+03	181300.00
6566C3	2017-07-26 17:03:00+03	56000.00
6566CE	2017-07-25 14:43:00+03	58200.00
6566CF	2017-07-30 17:29:00+03	38800.00
6566DC	2017-08-01 14:50:00+03	271100.00
6567AA	2017-07-06 04:51:00+03	42700.00
6567E1	2017-07-26 18:56:00+03	199200.00
6567FC	2017-07-26 19:02:00+03	265700.00
656808	2017-07-29 18:59:00+03	32800.00
65680A	2017-08-02 14:06:00+03	56000.00
656850	2017-07-22 12:22:00+03	76800.00
65687B	2017-07-19 05:50:00+03	131600.00
656890	2017-08-10 11:46:00+03	21500.00
6568D1	2017-08-12 22:47:00+03	51900.00
6568F6	2017-07-03 18:52:00+03	19600.00
656955	2017-07-17 01:22:00+03	28300.00
656998	2017-07-30 11:16:00+03	72300.00
6569AC	2017-07-07 01:08:00+03	84800.00
656A4C	2017-08-14 08:39:00+03	76600.00
656A6A	2017-07-08 17:27:00+03	89600.00
656A6F	2017-08-09 10:32:00+03	393800.00
656ACC	2017-07-11 04:37:00+03	23200.00
656B13	2017-07-05 04:56:00+03	16400.00
656B1D	2017-08-14 23:29:00+03	76600.00
656B33	2017-07-31 17:17:00+03	25600.00
656B36	2017-07-20 03:47:00+03	100300.00
656B93	2017-08-02 13:22:00+03	77400.00
656BB6	2017-07-18 16:13:00+03	273000.00
656C0C	2017-07-24 17:59:00+03	9200.00
656C7C	2017-07-01 21:07:00+03	70400.00
656D27	2017-07-23 19:10:00+03	82700.00
656D40	2017-07-22 06:19:00+03	70800.00
656D5A	2017-08-11 18:31:00+03	144400.00
656E56	2017-07-19 07:30:00+03	22600.00
656EDE	2017-07-23 13:26:00+03	83500.00
656F3D	2017-07-18 05:50:00+03	71800.00
656FAB	2017-07-20 20:46:00+03	20600.00
656FE5	2017-06-28 22:21:00+03	30200.00
65708A	2017-08-03 19:00:00+03	67800.00
65708B	2017-07-03 19:39:00+03	115100.00
6570D3	2017-07-15 06:47:00+03	47600.00
6570D9	2017-08-02 03:27:00+03	56600.00
6570F9	2017-07-25 13:49:00+03	51600.00
657115	2017-08-13 20:56:00+03	81600.00
657122	2017-07-30 06:35:00+03	14000.00
657128	2017-07-29 15:54:00+03	302200.00
657176	2017-07-17 00:54:00+03	98600.00
657192	2017-07-08 17:43:00+03	106800.00
6571AB	2017-08-06 10:41:00+03	263700.00
6571C1	2017-08-04 16:40:00+03	73200.00
6571DB	2017-07-02 02:06:00+03	81500.00
6571E3	2017-07-04 11:45:00+03	41600.00
6572EA	2017-07-28 23:44:00+03	258000.00
657331	2017-07-11 23:25:00+03	131600.00
657340	2017-08-02 17:38:00+03	15000.00
657398	2017-08-04 13:13:00+03	28800.00
6573B5	2017-08-11 11:47:00+03	152400.00
65741C	2017-08-04 09:49:00+03	109200.00
657490	2017-08-11 02:17:00+03	56600.00
6574FB	2017-08-12 14:35:00+03	266400.00
657536	2017-08-12 20:05:00+03	13400.00
657571	2017-06-29 12:40:00+03	68000.00
65757A	2017-08-14 22:14:00+03	385000.00
6575F4	2017-08-06 23:35:00+03	65900.00
657622	2017-07-27 09:02:00+03	56000.00
657628	2017-07-06 10:21:00+03	36000.00
6576EE	2017-07-11 07:48:00+03	23400.00
6576FA	2017-07-24 15:33:00+03	101200.00
65773A	2017-08-05 20:34:00+03	85000.00
65775A	2017-07-07 02:26:00+03	28000.00
6577BD	2017-07-23 08:46:00+03	66000.00
657880	2017-08-01 05:18:00+03	73200.00
657881	2017-06-29 06:01:00+03	23600.00
65789A	2017-07-16 05:43:00+03	26000.00
6578CA	2017-07-07 23:17:00+03	99500.00
65790B	2017-07-05 16:31:00+03	108500.00
657915	2017-08-11 20:30:00+03	56000.00
657929	2017-06-30 03:02:00+03	135400.00
657942	2017-07-03 16:39:00+03	51600.00
657951	2017-07-14 00:00:00+03	52600.00
6579A6	2017-07-16 10:16:00+03	35200.00
6579C0	2017-07-24 04:17:00+03	101900.00
6579D7	2017-07-08 02:45:00+03	131600.00
6579DC	2017-08-06 06:18:00+03	58000.00
6579E8	2017-08-13 21:30:00+03	132800.00
657A60	2017-08-02 02:25:00+03	22000.00
657AEF	2017-08-12 12:30:00+03	69500.00
657AFD	2017-08-11 21:48:00+03	57600.00
657B12	2017-07-23 20:05:00+03	189800.00
657B7F	2017-07-31 13:58:00+03	167400.00
657B85	2017-07-07 20:48:00+03	60800.00
657BCC	2017-08-15 13:09:00+03	28800.00
657BD0	2017-08-05 21:15:00+03	98600.00
657BE3	2017-08-06 23:03:00+03	64700.00
657BFC	2017-08-13 00:28:00+03	31600.00
657C00	2017-07-24 05:08:00+03	180000.00
657C18	2017-07-12 20:09:00+03	43900.00
657C2C	2017-06-29 02:16:00+03	103500.00
657C45	2017-07-30 12:48:00+03	133100.00
657CE6	2017-07-11 21:13:00+03	40300.00
657CFA	2017-08-11 18:42:00+03	87900.00
657D74	2017-08-14 17:51:00+03	83600.00
657D7E	2017-08-08 21:39:00+03	153300.00
657DA1	2017-08-01 11:08:00+03	52600.00
657DDA	2017-07-12 22:50:00+03	156400.00
657E55	2017-08-05 13:28:00+03	129600.00
657E92	2017-07-22 13:56:00+03	147700.00
657EC7	2017-08-12 00:41:00+03	136800.00
657F06	2017-08-03 02:44:00+03	136200.00
657F1B	2017-07-04 20:27:00+03	26000.00
657F67	2017-07-15 01:39:00+03	173500.00
657F86	2017-07-10 15:19:00+03	34100.00
657FA7	2017-08-10 09:01:00+03	20400.00
658036	2017-08-15 16:00:00+03	32700.00
658095	2017-07-17 17:50:00+03	22600.00
658171	2017-07-01 16:42:00+03	21800.00
6581FA	2017-07-08 23:44:00+03	27300.00
658216	2017-07-15 21:43:00+03	67600.00
658299	2017-08-05 23:52:00+03	46000.00
6582EE	2017-07-13 00:18:00+03	73600.00
658324	2017-07-03 21:14:00+03	195800.00
658372	2017-08-08 04:19:00+03	83600.00
6583B4	2017-07-30 22:47:00+03	56000.00
6583E8	2017-07-07 17:50:00+03	29100.00
6583F8	2017-08-03 23:12:00+03	85400.00
6583FD	2017-07-16 01:27:00+03	56000.00
65841C	2017-07-11 13:42:00+03	84100.00
65844D	2017-07-14 07:12:00+03	85800.00
6584C4	2017-07-21 07:48:00+03	48500.00
6584E1	2017-07-08 04:14:00+03	47900.00
6584FF	2017-07-01 12:23:00+03	120700.00
658512	2017-07-13 00:00:00+03	46400.00
658517	2017-07-25 19:11:00+03	28000.00
658597	2017-07-12 21:44:00+03	6700.00
65859A	2017-07-16 19:14:00+03	27600.00
6585C3	2017-07-21 16:14:00+03	24000.00
658601	2017-07-07 19:26:00+03	149900.00
65861A	2017-07-19 15:09:00+03	36200.00
658621	2017-07-10 02:52:00+03	19600.00
658628	2017-07-01 03:07:00+03	29600.00
65863B	2017-07-08 04:47:00+03	31700.00
6586C8	2017-08-15 05:33:00+03	29600.00
6586EA	2017-08-11 21:09:00+03	66800.00
6586EF	2017-07-04 17:50:00+03	50100.00
6586F0	2017-08-09 03:16:00+03	56900.00
65870D	2017-07-12 11:46:00+03	98400.00
65870F	2017-07-21 13:34:00+03	31800.00
658757	2017-07-17 14:35:00+03	92700.00
65875C	2017-07-28 15:32:00+03	54000.00
65878D	2017-07-06 03:58:00+03	64800.00
658795	2017-07-25 03:43:00+03	16400.00
658797	2017-07-11 10:16:00+03	64800.00
6587AB	2017-08-03 03:57:00+03	47100.00
6587DF	2017-08-01 05:13:00+03	19600.00
65882D	2017-08-13 19:37:00+03	129400.00
658874	2017-07-09 21:00:00+03	14000.00
6588D9	2017-07-29 00:40:00+03	71300.00
65890A	2017-07-11 05:28:00+03	62600.00
658926	2017-07-11 05:16:00+03	26700.00
65897F	2017-07-05 03:33:00+03	58700.00
6589AE	2017-08-06 18:56:00+03	71800.00
6589C0	2017-07-21 03:42:00+03	47600.00
6589C6	2017-07-08 20:47:00+03	67000.00
6589E4	2017-08-11 03:23:00+03	155600.00
658A26	2017-07-21 22:52:00+03	133100.00
658A3A	2017-07-10 13:06:00+03	18000.00
658A3C	2017-07-22 17:06:00+03	45500.00
658A6C	2017-08-03 00:34:00+03	70600.00
658A73	2017-08-08 22:07:00+03	38200.00
658A8C	2017-08-04 14:00:00+03	40000.00
658AE3	2017-07-16 14:31:00+03	6000.00
658BCE	2017-07-22 06:59:00+03	94400.00
658C18	2017-07-08 20:56:00+03	65700.00
658C6F	2017-07-17 20:20:00+03	271300.00
658CA8	2017-07-15 09:52:00+03	15000.00
658CFE	2017-07-30 17:52:00+03	89600.00
658D5F	2017-08-05 20:23:00+03	76800.00
658D6A	2017-07-10 14:24:00+03	55000.00
658DAA	2017-07-28 15:46:00+03	58600.00
658DD1	2017-07-14 19:55:00+03	55800.00
658DF3	2017-07-02 21:25:00+03	6000.00
658DF6	2017-08-11 09:55:00+03	84100.00
658E08	2017-08-06 14:39:00+03	37700.00
658E2A	2017-07-20 07:21:00+03	119600.00
658E51	2017-07-11 01:29:00+03	56100.00
658FA1	2017-08-01 02:22:00+03	39900.00
658FF9	2017-07-22 19:42:00+03	59300.00
659006	2017-08-03 07:56:00+03	20600.00
659009	2017-07-10 01:06:00+03	19600.00
659025	2017-07-08 02:58:00+03	36700.00
6590C6	2017-07-21 05:15:00+03	56600.00
6590EA	2017-07-16 19:24:00+03	28000.00
6590FF	2017-07-26 14:49:00+03	10800.00
659107	2017-08-06 05:38:00+03	56900.00
65910C	2017-07-23 02:10:00+03	62600.00
65912B	2017-07-24 15:34:00+03	43800.00
659176	2017-07-26 03:57:00+03	50800.00
659197	2017-08-08 08:25:00+03	17800.00
6591BD	2017-07-22 21:34:00+03	271100.00
6591E6	2017-07-31 09:57:00+03	148800.00
65924F	2017-07-04 13:13:00+03	35800.00
6592C3	2017-07-20 09:26:00+03	56000.00
6592E0	2017-07-31 10:37:00+03	105100.00
6592E5	2017-07-22 13:51:00+03	133100.00
659418	2017-07-16 19:35:00+03	154800.00
659442	2017-07-25 14:49:00+03	77000.00
6594A4	2017-07-10 17:59:00+03	12400.00
6594A5	2017-08-09 15:58:00+03	47600.00
6594BB	2017-07-22 18:18:00+03	195900.00
659524	2017-07-28 04:33:00+03	28000.00
659589	2017-07-29 10:34:00+03	189800.00
65958A	2017-08-14 00:56:00+03	29800.00
6595FC	2017-07-11 19:21:00+03	22000.00
65968D	2017-08-11 22:53:00+03	136800.00
6596FE	2017-07-01 17:01:00+03	46400.00
65971A	2017-07-01 05:12:00+03	6700.00
65973C	2017-08-04 22:25:00+03	31400.00
65978E	2017-07-03 08:15:00+03	81500.00
6597BA	2017-08-13 19:20:00+03	92100.00
659800	2017-08-06 12:48:00+03	96000.00
65980D	2017-07-13 19:36:00+03	43000.00
659840	2017-08-08 22:24:00+03	185500.00
6598B1	2017-07-25 05:22:00+03	136200.00
6598FD	2017-07-15 08:29:00+03	38600.00
659983	2017-07-15 01:19:00+03	59200.00
659A0A	2017-08-04 06:41:00+03	81700.00
659A12	2017-07-22 00:40:00+03	240600.00
659A34	2017-07-16 01:35:00+03	63200.00
659A58	2017-07-05 14:28:00+03	97900.00
659A60	2017-07-30 03:27:00+03	92000.00
659A61	2017-07-06 02:01:00+03	6700.00
659A9E	2017-07-26 05:16:00+03	140900.00
659AEF	2017-07-28 14:52:00+03	69500.00
659AFE	2017-07-06 03:05:00+03	133600.00
659B65	2017-07-28 04:47:00+03	111600.00
659B80	2017-07-10 15:11:00+03	55800.00
659BF2	2017-08-07 18:36:00+03	32700.00
659BFE	2017-07-27 08:01:00+03	10800.00
659C74	2017-07-14 02:11:00+03	36200.00
659D0E	2017-08-01 10:59:00+03	17200.00
659D11	2017-06-30 14:24:00+03	26800.00
659D21	2017-06-30 03:57:00+03	55800.00
659D22	2017-07-16 18:50:00+03	17600.00
659D73	2017-08-15 06:27:00+03	114400.00
659D9A	2017-07-31 09:33:00+03	224000.00
659DEF	2017-07-07 23:18:00+03	246000.00
659DF2	2017-06-30 15:26:00+03	28700.00
659EB1	2017-07-23 02:35:00+03	43900.00
659EC8	2017-07-19 16:18:00+03	47500.00
659F15	2017-07-19 22:23:00+03	111600.00
659F43	2017-08-15 00:41:00+03	60400.00
659F61	2017-07-28 01:02:00+03	35200.00
659F99	2017-08-05 19:24:00+03	26000.00
65A02E	2017-08-09 09:40:00+03	36000.00
65A04F	2017-07-02 22:16:00+03	44000.00
65A077	2017-07-28 19:19:00+03	24400.00
65A07A	2017-08-14 05:21:00+03	103500.00
65A0B8	2017-08-05 07:56:00+03	410100.00
65A0D2	2017-08-05 11:23:00+03	119800.00
65A136	2017-07-04 16:09:00+03	62800.00
65A170	2017-07-16 01:09:00+03	42000.00
65A179	2017-08-05 05:01:00+03	57500.00
65A1FD	2017-08-08 03:26:00+03	39800.00
65A20E	2017-07-06 07:32:00+03	167500.00
65A22A	2017-07-10 15:26:00+03	8000.00
65A236	2017-08-06 02:42:00+03	51900.00
65A258	2017-08-13 23:59:00+03	136600.00
65A25C	2017-08-09 15:56:00+03	28000.00
65A269	2017-07-08 19:18:00+03	36200.00
65A29E	2017-07-10 20:25:00+03	36000.00
65A2AB	2017-08-11 06:06:00+03	56000.00
65A2B8	2017-08-03 01:27:00+03	39800.00
65A332	2017-07-17 23:24:00+03	73300.00
65A374	2017-07-21 03:17:00+03	36200.00
65A3AD	2017-08-14 20:47:00+03	22400.00
65A3E0	2017-07-06 06:29:00+03	35600.00
65A402	2017-07-20 04:51:00+03	106100.00
65A497	2017-07-25 01:17:00+03	70800.00
65A4C7	2017-07-09 15:34:00+03	20000.00
65A575	2017-07-11 00:18:00+03	71100.00
65A59E	2017-07-27 19:43:00+03	73200.00
65A614	2017-07-21 15:24:00+03	73300.00
65A62D	2017-06-30 12:11:00+03	23200.00
65A631	2017-07-18 22:21:00+03	136500.00
65A682	2017-08-06 22:49:00+03	123000.00
65A687	2017-07-28 06:05:00+03	53300.00
65A6EA	2017-07-03 06:28:00+03	1065600.00
65A6F9	2017-07-21 18:27:00+03	6700.00
65A751	2017-07-12 15:18:00+03	40800.00
65A799	2017-07-14 02:35:00+03	89100.00
65A89C	2017-07-11 09:32:00+03	46300.00
65A8A4	2017-07-18 14:48:00+03	34000.00
65A8BA	2017-08-14 10:55:00+03	110900.00
65A8CB	2017-07-09 13:26:00+03	263600.00
65A941	2017-07-16 07:42:00+03	24800.00
65A948	2017-07-07 18:32:00+03	59600.00
65A97E	2017-07-06 02:49:00+03	29400.00
65AA5C	2017-06-30 16:51:00+03	114900.00
65AA9A	2017-08-14 17:41:00+03	19600.00
65AAFC	2017-07-06 01:25:00+03	106900.00
65AB54	2017-08-05 21:57:00+03	187600.00
65AB56	2017-07-28 20:15:00+03	49700.00
65ABB0	2017-07-21 22:03:00+03	40800.00
65ABB6	2017-07-23 03:58:00+03	32700.00
65AC1F	2017-07-18 22:12:00+03	58200.00
65AC52	2017-08-10 21:52:00+03	27300.00
65ACB8	2017-07-30 18:06:00+03	56600.00
65ACDE	2017-07-08 22:44:00+03	94000.00
65ACFF	2017-08-11 17:03:00+03	15000.00
65AD23	2017-08-08 21:31:00+03	133100.00
65AD73	2017-07-24 13:54:00+03	24400.00
65AD89	2017-07-28 07:09:00+03	26000.00
65AEB0	2017-07-22 05:01:00+03	44400.00
65AEC5	2017-07-26 11:50:00+03	40000.00
65AEC8	2017-08-15 10:32:00+03	69500.00
65AF13	2017-07-18 19:20:00+03	85000.00
65AF16	2017-07-30 21:39:00+03	66600.00
65AFB2	2017-07-22 19:13:00+03	51900.00
65AFEA	2017-07-12 07:43:00+03	92100.00
65B029	2017-07-26 15:47:00+03	12600.00
65B078	2017-07-03 14:47:00+03	129400.00
65B0C3	2017-07-14 09:32:00+03	27200.00
65B0EE	2017-07-14 17:33:00+03	28800.00
65B10E	2017-07-28 17:29:00+03	117700.00
65B145	2017-07-13 06:17:00+03	34000.00
65B195	2017-07-14 07:07:00+03	66600.00
65B1EA	2017-08-03 00:43:00+03	123000.00
65B1EB	2017-08-06 14:37:00+03	66600.00
65B2B9	2017-07-22 17:42:00+03	281500.00
65B2BD	2017-07-20 14:57:00+03	54600.00
65B2DB	2017-08-12 16:31:00+03	28800.00
65B2E9	2017-08-11 07:56:00+03	115600.00
65B2FC	2017-08-12 15:02:00+03	40400.00
65B33B	2017-07-23 20:55:00+03	72400.00
65B33F	2017-07-30 16:56:00+03	54500.00
65B34B	2017-08-07 12:21:00+03	13400.00
65B369	2017-08-13 10:46:00+03	101100.00
65B3B0	2017-08-13 01:31:00+03	37100.00
65B3D9	2017-08-14 09:44:00+03	23600.00
65B41A	2017-06-30 04:35:00+03	82900.00
65B492	2017-08-09 09:04:00+03	81700.00
65B4AB	2017-07-26 12:40:00+03	59300.00
65B4B1	2017-07-20 21:52:00+03	168000.00
65B4D3	2017-07-30 20:06:00+03	198800.00
65B539	2017-08-12 10:04:00+03	49800.00
65B54F	2017-07-05 13:21:00+03	46400.00
65B583	2017-07-25 15:15:00+03	69500.00
65B59B	2017-07-05 20:22:00+03	177200.00
65B66B	2017-07-30 10:48:00+03	155300.00
65B6B1	2017-07-23 22:38:00+03	22000.00
65B6B2	2017-07-15 09:17:00+03	24400.00
65B6E2	2017-07-23 09:05:00+03	6700.00
65B758	2017-07-26 05:45:00+03	40400.00
65B7AB	2017-07-08 14:04:00+03	26700.00
65B83A	2017-07-17 22:12:00+03	38800.00
65B87B	2017-07-18 02:27:00+03	6700.00
65B888	2017-08-10 09:16:00+03	16400.00
65B8A0	2017-07-14 18:57:00+03	6700.00
65B8EE	2017-07-25 01:55:00+03	56200.00
65B91D	2017-07-06 20:05:00+03	56000.00
65B91E	2017-07-06 14:21:00+03	56900.00
65B93F	2017-07-15 06:02:00+03	62600.00
65B9AC	2017-07-01 20:38:00+03	65900.00
65B9D4	2017-08-12 19:58:00+03	19600.00
65B9DA	2017-07-31 08:08:00+03	38400.00
65B9E4	2017-08-10 18:26:00+03	46000.00
65BA16	2017-07-04 14:20:00+03	47300.00
65BA3C	2017-07-29 03:49:00+03	671300.00
65BB30	2017-08-02 14:58:00+03	28000.00
65BB47	2017-08-04 01:32:00+03	88900.00
65BB6C	2017-06-28 21:11:00+03	201800.00
65BB77	2017-08-09 02:32:00+03	47400.00
65BBA5	2017-08-08 10:57:00+03	33100.00
65BBB7	2017-07-29 08:31:00+03	13800.00
65BC1E	2017-07-05 08:57:00+03	132800.00
65BC1F	2017-07-01 01:36:00+03	19600.00
65BC2F	2017-08-11 11:34:00+03	28300.00
65BC65	2017-06-30 12:04:00+03	55800.00
65BC91	2017-08-04 02:49:00+03	31400.00
65BCC6	2017-08-07 21:58:00+03	98300.00
65BD80	2017-08-05 01:48:00+03	61800.00
65BDA4	2017-08-07 03:26:00+03	84800.00
65BE0E	2017-08-15 14:41:00+03	99300.00
65BE17	2017-07-29 16:00:00+03	385300.00
65BE63	2017-08-10 19:10:00+03	199600.00
65BE78	2017-08-13 14:59:00+03	48800.00
65BEB6	2017-08-01 22:18:00+03	24400.00
65BECA	2017-08-02 19:37:00+03	61600.00
65BEF4	2017-07-22 01:08:00+03	20400.00
65BF44	2017-07-30 12:13:00+03	89600.00
65BF45	2017-08-10 18:54:00+03	95600.00
65C06D	2017-08-07 09:51:00+03	372500.00
65C078	2017-08-07 08:59:00+03	16400.00
65C0A4	2017-07-09 15:51:00+03	26000.00
65C0B0	2017-07-06 03:43:00+03	123000.00
65C1BC	2017-08-13 17:02:00+03	183300.00
65C1C6	2017-07-28 15:26:00+03	72400.00
65C238	2017-07-17 08:06:00+03	64500.00
65C287	2017-08-14 23:08:00+03	47000.00
65C2D9	2017-08-02 21:46:00+03	15800.00
65C309	2017-07-27 09:51:00+03	123000.00
65C326	2017-07-29 11:16:00+03	112400.00
65C359	2017-07-22 18:58:00+03	92600.00
65C36C	2017-07-16 01:51:00+03	27200.00
65C3D5	2017-07-17 22:48:00+03	73600.00
65C436	2017-07-02 22:15:00+03	73300.00
65C45A	2017-07-09 12:55:00+03	399600.00
65C4EB	2017-08-14 21:23:00+03	54300.00
65C66C	2017-08-13 23:01:00+03	288600.00
65C677	2017-07-18 02:59:00+03	135600.00
65C68D	2017-07-10 22:27:00+03	34000.00
65C72E	2017-07-01 19:12:00+03	23600.00
65C73D	2017-08-01 19:47:00+03	14800.00
65C76F	2017-08-07 14:20:00+03	92400.00
65C83D	2017-07-03 19:34:00+03	6000.00
65C890	2017-08-04 02:22:00+03	131100.00
65C89D	2017-07-30 05:01:00+03	47400.00
65C8A3	2017-07-14 08:13:00+03	36800.00
65C90B	2017-07-02 08:01:00+03	32400.00
65C91C	2017-07-09 03:49:00+03	16400.00
65C92F	2017-07-06 11:33:00+03	75600.00
65C968	2017-08-06 20:28:00+03	24200.00
65C9B9	2017-08-14 05:24:00+03	40000.00
65C9CC	2017-07-01 17:08:00+03	260900.00
65CA69	2017-08-11 22:48:00+03	88000.00
65CAD9	2017-07-27 13:28:00+03	20600.00
65CB4A	2017-08-07 02:15:00+03	26800.00
65CBF0	2017-07-10 00:13:00+03	12000.00
65CBF2	2017-08-13 20:52:00+03	37200.00
65CC9E	2017-07-21 22:34:00+03	23200.00
65CCAD	2017-08-09 20:45:00+03	109700.00
65CD03	2017-07-05 10:01:00+03	26000.00
65CD14	2017-07-15 07:00:00+03	203000.00
65CD34	2017-07-31 03:30:00+03	75200.00
65CD69	2017-07-22 07:42:00+03	6000.00
65CD78	2017-07-15 01:39:00+03	28000.00
65CDB4	2017-07-27 15:16:00+03	130400.00
65CDBF	2017-08-15 08:04:00+03	26800.00
65CE32	2017-07-07 08:02:00+03	119900.00
65CE7B	2017-08-06 05:42:00+03	8200.00
65CEE7	2017-08-04 20:50:00+03	107200.00
65CEF0	2017-07-21 00:15:00+03	91000.00
65CEFD	2017-07-29 10:33:00+03	288800.00
65CF99	2017-07-25 21:18:00+03	100000.00
65CFAE	2017-07-29 13:50:00+03	115900.00
65D03B	2017-08-06 18:18:00+03	273400.00
65D053	2017-07-05 18:35:00+03	26000.00
65D093	2017-08-01 03:40:00+03	77900.00
65D0A2	2017-07-31 16:03:00+03	65500.00
65D0B2	2017-07-23 03:21:00+03	105600.00
65D101	2017-07-27 09:20:00+03	28800.00
65D16E	2017-07-28 14:56:00+03	62800.00
65D175	2017-08-14 21:34:00+03	229300.00
65D17C	2017-07-25 17:06:00+03	134700.00
65D1A1	2017-07-19 22:55:00+03	85600.00
65D22F	2017-07-07 17:42:00+03	57700.00
65D299	2017-07-02 11:42:00+03	40800.00
65D33D	2017-08-01 22:13:00+03	3700.00
65D417	2017-07-06 17:50:00+03	185600.00
65D4C6	2017-07-06 12:44:00+03	67200.00
65D4FE	2017-07-24 03:33:00+03	144400.00
65D58F	2017-07-17 00:35:00+03	173200.00
65D673	2017-07-19 11:25:00+03	28800.00
65D690	2017-07-09 08:18:00+03	84100.00
65D6BA	2017-07-15 02:10:00+03	31600.00
65D781	2017-07-09 17:11:00+03	31800.00
65D7B2	2017-06-28 11:40:00+03	91200.00
65D7B7	2017-07-27 00:43:00+03	27600.00
65D840	2017-07-14 17:14:00+03	27200.00
65D93B	2017-08-11 12:24:00+03	29600.00
65D93C	2017-07-09 02:07:00+03	59200.00
65D93D	2017-07-11 13:13:00+03	26000.00
65DA44	2017-07-06 03:55:00+03	95600.00
65DC55	2017-07-26 07:49:00+03	37200.00
65DC70	2017-08-02 10:44:00+03	62600.00
65DC72	2017-07-29 14:20:00+03	57300.00
65DC8D	2017-07-19 21:02:00+03	133100.00
65DCC6	2017-07-26 18:41:00+03	31600.00
65DD00	2017-07-22 02:54:00+03	61400.00
65DD67	2017-07-31 02:16:00+03	266400.00
65DD85	2017-06-28 03:51:00+03	222800.00
65DDAE	2017-08-09 04:52:00+03	9200.00
65DDC8	2017-07-07 07:34:00+03	67700.00
65DDD0	2017-07-08 20:39:00+03	123000.00
65DE7F	2017-07-09 09:36:00+03	39300.00
65DE99	2017-08-12 14:48:00+03	91100.00
65DEAE	2017-07-11 12:13:00+03	128800.00
65DECD	2017-08-06 12:20:00+03	47000.00
65DEFC	2017-07-20 09:46:00+03	139500.00
65DEFE	2017-07-19 18:37:00+03	23600.00
65DF19	2017-08-13 12:27:00+03	81600.00
65DF3D	2017-08-08 14:09:00+03	58200.00
65DF82	2017-08-05 02:57:00+03	132800.00
65DFA9	2017-07-11 01:49:00+03	21400.00
65DFB8	2017-07-03 17:20:00+03	14000.00
65E03D	2017-07-14 00:33:00+03	257600.00
65E091	2017-07-25 00:53:00+03	153100.00
65E145	2017-08-08 02:44:00+03	14400.00
65E162	2017-08-08 23:46:00+03	57300.00
65E16D	2017-08-15 14:40:00+03	21500.00
65E171	2017-08-14 08:39:00+03	44300.00
65E1E1	2017-06-30 04:51:00+03	99200.00
65E1E9	2017-07-14 08:34:00+03	53600.00
65E1F8	2017-08-08 14:00:00+03	152700.00
65E203	2017-07-19 19:35:00+03	31600.00
65E217	2017-07-15 11:21:00+03	25200.00
65E218	2017-07-14 15:22:00+03	23600.00
65E21A	2017-07-03 16:53:00+03	6000.00
65E230	2017-07-27 22:54:00+03	201200.00
65E24A	2017-07-17 23:04:00+03	47800.00
65E292	2017-07-06 20:51:00+03	82900.00
65E29D	2017-07-05 13:13:00+03	6700.00
65E29F	2017-07-06 02:05:00+03	62700.00
65E2CF	2017-07-17 07:50:00+03	64700.00
65E2D0	2017-07-05 13:08:00+03	83000.00
65E2D3	2017-07-29 07:15:00+03	39900.00
65E2D8	2017-07-19 23:58:00+03	67600.00
65E30E	2017-08-04 22:40:00+03	185800.00
65E35F	2017-07-24 21:59:00+03	12600.00
65E384	2017-07-28 21:35:00+03	111700.00
65E399	2017-07-23 06:43:00+03	40800.00
65E4C4	2017-08-11 12:28:00+03	32800.00
65E4FF	2017-07-17 22:36:00+03	81300.00
65E58D	2017-08-06 07:32:00+03	29600.00
65E5B3	2017-07-09 12:24:00+03	47200.00
65E600	2017-08-05 12:58:00+03	48400.00
65E661	2017-08-13 04:37:00+03	23200.00
65E6B9	2017-07-20 07:54:00+03	31600.00
65E6C0	2017-07-16 18:09:00+03	84500.00
65E6D3	2017-07-26 13:40:00+03	294200.00
65E6EF	2017-07-09 13:47:00+03	65900.00
65E6F3	2017-07-11 11:07:00+03	27200.00
65E704	2017-07-12 00:51:00+03	75200.00
65E718	2017-07-20 08:22:00+03	75300.00
65E742	2017-07-17 15:25:00+03	136200.00
65E764	2017-07-10 20:00:00+03	70100.00
65E767	2017-06-25 07:23:00+03	255600.00
65E7AC	2017-07-25 14:11:00+03	37200.00
65E7B8	2017-08-10 03:07:00+03	223200.00
65E7CC	2017-08-12 13:50:00+03	37200.00
65E7E1	2017-07-10 14:55:00+03	88400.00
65E7E8	2017-08-10 14:31:00+03	19600.00
65E861	2017-08-13 09:25:00+03	71100.00
65E88A	2017-07-29 05:51:00+03	93900.00
65E8EE	2017-07-22 21:36:00+03	54800.00
65E910	2017-07-17 18:51:00+03	10800.00
65E973	2017-07-31 04:06:00+03	32700.00
65E9F0	2017-07-01 02:15:00+03	11600.00
65EA01	2017-08-02 10:04:00+03	23600.00
65EA14	2017-07-24 19:34:00+03	258400.00
65EAB6	2017-08-05 22:30:00+03	55000.00
65EBEF	2017-07-31 14:19:00+03	94900.00
65EC22	2017-07-18 15:01:00+03	85400.00
65ECB4	2017-07-16 22:08:00+03	82100.00
65ECD9	2017-07-26 01:00:00+03	47400.00
65ECF0	2017-07-22 18:34:00+03	113800.00
65ED00	2017-07-27 03:36:00+03	38200.00
65ED0B	2017-07-31 22:56:00+03	10800.00
65ED3E	2017-06-28 11:35:00+03	55800.00
65ED5A	2017-07-17 07:17:00+03	26200.00
65ED94	2017-08-13 03:24:00+03	23600.00
65EDB8	2017-07-29 08:35:00+03	120700.00
65EDC3	2017-07-12 20:00:00+03	46000.00
65EE74	2017-07-31 05:34:00+03	118600.00
65EEC6	2017-08-03 03:07:00+03	32800.00
65EECF	2017-07-07 16:58:00+03	223200.00
65EF87	2017-07-12 19:02:00+03	26000.00
65EF89	2017-07-06 17:34:00+03	133200.00
65F036	2017-07-15 00:35:00+03	46400.00
65F0C6	2017-07-02 06:28:00+03	102100.00
65F0DF	2017-07-20 03:43:00+03	14800.00
65F181	2017-07-21 00:39:00+03	356500.00
65F19C	2017-07-24 01:26:00+03	16400.00
65F19D	2017-07-06 16:56:00+03	22000.00
65F1A5	2017-07-17 13:44:00+03	30000.00
65F1E1	2017-07-18 18:55:00+03	88800.00
65F1F8	2017-07-16 22:31:00+03	123000.00
65F24B	2017-08-07 06:40:00+03	67600.00
65F29C	2017-08-09 18:56:00+03	169900.00
65F2A4	2017-07-13 07:44:00+03	6700.00
65F2EE	2017-08-13 03:35:00+03	263900.00
65F345	2017-08-04 12:10:00+03	37900.00
65F366	2017-07-24 03:44:00+03	135600.00
65F3E0	2017-08-13 09:57:00+03	135600.00
65F405	2017-08-12 21:13:00+03	47400.00
65F40F	2017-07-25 02:56:00+03	15800.00
65F4F8	2017-08-07 22:55:00+03	62600.00
65F53D	2017-08-12 17:58:00+03	56000.00
65F568	2017-08-05 08:29:00+03	20400.00
65F61D	2017-07-30 15:38:00+03	31100.00
65F66D	2017-07-23 21:50:00+03	66800.00
65F6A4	2017-07-25 23:11:00+03	25400.00
65F725	2017-08-01 00:47:00+03	29200.00
65F742	2017-08-07 01:33:00+03	270600.00
65F7B4	2017-07-21 13:16:00+03	68200.00
65F7EB	2017-08-14 04:01:00+03	65000.00
65F87D	2017-07-27 17:39:00+03	54800.00
65F8B0	2017-07-29 15:33:00+03	24400.00
65F8B5	2017-07-08 20:10:00+03	93700.00
65F93E	2017-08-07 17:00:00+03	53600.00
65F9FE	2017-08-11 16:55:00+03	106400.00
65FA47	2017-07-15 13:15:00+03	24300.00
65FA6C	2017-07-31 13:57:00+03	33800.00
65FA7D	2017-07-10 23:02:00+03	35300.00
65FA7E	2017-07-14 18:13:00+03	57600.00
65FAD6	2017-07-19 16:46:00+03	13600.00
65FAE9	2017-07-11 21:45:00+03	60800.00
65FB0E	2017-07-08 16:19:00+03	45200.00
65FB17	2017-07-23 12:43:00+03	119700.00
65FB33	2017-07-21 05:45:00+03	28000.00
65FB42	2017-08-02 10:47:00+03	43500.00
65FB7E	2017-07-31 09:19:00+03	66700.00
65FB9F	2017-08-08 18:53:00+03	73600.00
65FBAB	2017-07-10 19:42:00+03	23200.00
65FBC2	2017-08-10 16:08:00+03	36200.00
65FBEB	2017-08-12 17:45:00+03	56200.00
65FC57	2017-07-31 02:08:00+03	50100.00
65FC73	2017-07-18 15:29:00+03	73600.00
65FCE8	2017-07-27 00:06:00+03	40900.00
65FCEF	2017-08-03 13:52:00+03	197100.00
65FD16	2017-07-07 16:51:00+03	78800.00
65FD7B	2017-07-11 07:50:00+03	135200.00
65FD96	2017-07-10 03:37:00+03	85600.00
65FDE6	2017-08-05 21:03:00+03	47200.00
65FDFF	2017-07-31 21:23:00+03	254900.00
65FE23	2017-08-15 17:46:00+03	103800.00
65FE2F	2017-07-25 19:29:00+03	54800.00
65FE7C	2017-07-09 06:07:00+03	70600.00
65FE7F	2017-07-24 23:24:00+03	73500.00
65FF25	2017-07-21 14:25:00+03	28000.00
65FF65	2017-07-06 19:56:00+03	15400.00
65FF6B	2017-08-05 20:27:00+03	112000.00
65FF9F	2017-08-13 18:38:00+03	19600.00
65FFEF	2017-07-09 21:45:00+03	33200.00
65FFFF	2017-07-11 13:18:00+03	12600.00
660049	2017-07-30 08:42:00+03	58600.00
6600DC	2017-07-07 23:26:00+03	21700.00
6601B3	2017-07-21 07:04:00+03	19200.00
660220	2017-08-04 03:35:00+03	257500.00
660275	2017-08-06 08:21:00+03	34900.00
6602AA	2017-07-07 17:15:00+03	39500.00
6602AF	2017-07-16 20:53:00+03	149300.00
6602B8	2017-07-18 04:26:00+03	56000.00
660349	2017-08-08 03:42:00+03	44500.00
660367	2017-07-03 20:47:00+03	18000.00
660377	2017-08-11 16:20:00+03	46000.00
6603BA	2017-07-08 22:19:00+03	123000.00
6603F5	2017-08-09 21:29:00+03	18000.00
6603F8	2017-08-13 19:53:00+03	112000.00
660455	2017-07-03 03:01:00+03	67200.00
660499	2017-07-17 08:09:00+03	28000.00
66049D	2017-07-14 12:33:00+03	39800.00
660580	2017-08-15 05:39:00+03	86400.00
660616	2017-08-01 10:11:00+03	89700.00
6606C4	2017-07-23 05:23:00+03	123600.00
6606C6	2017-08-10 08:39:00+03	61800.00
660713	2017-06-28 04:48:00+03	6800.00
6607B0	2017-08-05 10:00:00+03	133100.00
6607F2	2017-07-24 23:11:00+03	38600.00
660807	2017-07-22 09:06:00+03	186900.00
660826	2017-07-23 20:45:00+03	24700.00
66085D	2017-07-01 21:33:00+03	73600.00
66085F	2017-07-31 11:22:00+03	68400.00
6608AB	2017-07-27 15:11:00+03	18000.00
6608C4	2017-07-07 08:18:00+03	56600.00
6608F4	2017-07-03 06:03:00+03	147800.00
660925	2017-07-01 05:57:00+03	134800.00
660988	2017-07-03 14:40:00+03	136800.00
6609FB	2017-07-05 19:17:00+03	246000.00
660AA1	2017-08-14 16:30:00+03	23600.00
660ABA	2017-07-10 06:57:00+03	133600.00
660B5A	2017-08-09 09:33:00+03	31600.00
660C7E	2017-07-03 18:47:00+03	16800.00
660CA8	2017-08-15 04:10:00+03	6000.00
660CB1	2017-07-25 08:57:00+03	60500.00
660CE3	2017-06-27 07:26:00+03	18000.00
660D06	2017-06-28 15:55:00+03	53300.00
660D6C	2017-08-13 23:15:00+03	51800.00
660DE5	2017-08-13 17:50:00+03	28000.00
660E0A	2017-08-11 03:59:00+03	64800.00
660E52	2017-07-16 06:58:00+03	191000.00
660EC0	2017-08-14 17:45:00+03	40700.00
660F07	2017-07-09 09:33:00+03	23200.00
660F36	2017-07-06 23:06:00+03	23600.00
660F44	2017-07-09 09:15:00+03	114800.00
660F45	2017-07-06 20:49:00+03	55800.00
660F4F	2017-07-31 05:48:00+03	147700.00
660F5B	2017-08-04 16:13:00+03	81300.00
660FA8	2017-08-06 08:41:00+03	25400.00
660FE6	2017-08-06 15:01:00+03	56000.00
661032	2017-08-06 20:57:00+03	36200.00
6610B8	2017-07-24 06:50:00+03	6000.00
6610BC	2017-07-27 00:48:00+03	94700.00
6610C1	2017-08-02 19:57:00+03	83000.00
6610FD	2017-08-01 15:24:00+03	59800.00
66112A	2017-07-04 11:44:00+03	47100.00
661155	2017-07-29 03:01:00+03	186900.00
66116E	2017-08-11 09:15:00+03	291000.00
6611C8	2017-07-21 18:11:00+03	43000.00
6611DF	2017-07-15 19:29:00+03	68400.00
66126A	2017-07-07 10:08:00+03	12400.00
6612BC	2017-07-22 09:55:00+03	84500.00
6612BD	2017-07-24 22:16:00+03	87800.00
6612E6	2017-07-13 12:26:00+03	12600.00
66131F	2017-07-20 22:10:00+03	24400.00
661320	2017-08-05 14:27:00+03	23600.00
661323	2017-08-08 21:48:00+03	88200.00
661348	2017-07-06 15:41:00+03	56000.00
66136C	2017-08-06 14:13:00+03	23200.00
661387	2017-07-20 19:01:00+03	51800.00
6613BA	2017-08-14 12:36:00+03	23600.00
661408	2017-08-14 21:54:00+03	56000.00
661452	2017-07-31 09:20:00+03	28000.00
6614D5	2017-06-29 10:41:00+03	273400.00
66155C	2017-07-06 19:40:00+03	155600.00
6615EB	2017-08-14 05:12:00+03	88800.00
66165A	2017-07-27 14:42:00+03	40600.00
661666	2017-07-21 02:41:00+03	79600.00
6616B8	2017-08-07 05:05:00+03	25800.00
6616C3	2017-07-29 09:34:00+03	35600.00
6617A3	2017-07-11 13:57:00+03	92600.00
6617BD	2017-08-05 18:57:00+03	177900.00
6617CA	2017-07-22 12:26:00+03	93900.00
66182C	2017-07-08 06:05:00+03	46500.00
661863	2017-07-27 13:35:00+03	44800.00
6618A4	2017-08-14 04:55:00+03	238400.00
6618D5	2017-08-06 19:57:00+03	165800.00
66197C	2017-07-06 10:02:00+03	75600.00
6619A2	2017-07-12 09:52:00+03	40000.00
6619AD	2017-06-26 06:46:00+03	119500.00
6619D1	2017-07-13 08:36:00+03	67700.00
661A95	2017-08-06 05:20:00+03	20400.00
661A97	2017-07-23 13:27:00+03	83200.00
661A9B	2017-07-10 16:11:00+03	28800.00
661AC1	2017-08-15 06:12:00+03	23400.00
661B06	2017-07-12 00:10:00+03	76800.00
661B2C	2017-07-17 18:00:00+03	19600.00
661B2E	2017-07-24 20:17:00+03	29600.00
661B5B	2017-07-04 20:24:00+03	399600.00
661B66	2017-07-28 00:55:00+03	354200.00
661C54	2017-08-08 08:10:00+03	56000.00
661C72	2017-07-09 21:33:00+03	111600.00
661C80	2017-07-07 10:06:00+03	133200.00
661C8E	2017-07-09 05:35:00+03	246000.00
661CA9	2017-06-29 03:37:00+03	61400.00
661CE2	2017-08-10 14:05:00+03	49800.00
661CEC	2017-07-18 01:10:00+03	82900.00
661CF4	2017-08-15 10:25:00+03	18800.00
661D01	2017-07-27 19:36:00+03	129200.00
661D06	2017-07-12 04:53:00+03	26700.00
661D0E	2017-07-02 01:08:00+03	24400.00
661D9C	2017-06-29 17:33:00+03	131600.00
661E37	2017-07-11 23:59:00+03	13000.00
661E4B	2017-07-17 16:59:00+03	59800.00
661E61	2017-08-01 00:31:00+03	28000.00
661E67	2017-07-17 12:09:00+03	112000.00
661ECA	2017-07-22 08:46:00+03	36100.00
661F06	2017-08-02 04:58:00+03	22000.00
661F1F	2017-08-09 18:01:00+03	95200.00
661F3D	2017-07-19 03:35:00+03	28800.00
661F43	2017-07-20 17:36:00+03	12600.00
661F8F	2017-07-25 13:50:00+03	106100.00
661FDB	2017-07-08 22:18:00+03	22000.00
66204C	2017-07-08 09:51:00+03	41900.00
662056	2017-08-08 10:45:00+03	34800.00
66208D	2017-07-24 23:50:00+03	55300.00
6620C4	2017-07-10 04:14:00+03	135600.00
6620CA	2017-07-11 23:01:00+03	56900.00
6620F2	2017-08-11 22:42:00+03	43200.00
66210F	2017-07-05 00:46:00+03	78300.00
66213F	2017-07-09 16:08:00+03	20400.00
66220E	2017-08-15 10:44:00+03	30400.00
662259	2017-07-04 19:32:00+03	520600.00
66225B	2017-08-01 17:01:00+03	248400.00
662296	2017-07-29 20:40:00+03	11600.00
6622AC	2017-07-28 02:13:00+03	9300.00
662394	2017-07-29 09:02:00+03	28800.00
662402	2017-08-13 09:50:00+03	14000.00
66242A	2017-07-06 13:33:00+03	58000.00
66242D	2017-07-27 05:36:00+03	12200.00
662483	2017-08-07 23:35:00+03	75600.00
6624A2	2017-08-10 19:32:00+03	130300.00
6624BE	2017-07-02 07:40:00+03	252200.00
6624C8	2017-07-18 16:35:00+03	196600.00
6624EE	2017-07-29 11:58:00+03	85000.00
662529	2017-07-14 18:31:00+03	46400.00
662561	2017-07-17 04:23:00+03	32800.00
662564	2017-07-23 20:12:00+03	19200.00
6625EB	2017-07-17 03:04:00+03	119500.00
662605	2017-07-19 18:09:00+03	436000.00
662648	2017-07-24 22:08:00+03	58600.00
66265D	2017-08-13 05:11:00+03	36200.00
66266A	2017-06-27 10:50:00+03	128600.00
662696	2017-08-06 18:27:00+03	28000.00
6626D8	2017-07-03 17:18:00+03	116000.00
662760	2017-08-06 06:16:00+03	13400.00
6627C7	2017-08-03 06:34:00+03	188000.00
662876	2017-07-30 17:55:00+03	75300.00
6628B8	2017-07-14 12:17:00+03	88800.00
662905	2017-08-14 00:51:00+03	28000.00
662925	2017-08-05 13:10:00+03	64800.00
662964	2017-07-12 01:15:00+03	79800.00
6629AE	2017-08-06 12:49:00+03	13400.00
6629D1	2017-07-12 02:16:00+03	55800.00
6629EE	2017-07-24 16:20:00+03	22400.00
6629FC	2017-07-04 21:29:00+03	19600.00
662AF8	2017-07-09 16:03:00+03	40400.00
662B3E	2017-07-02 06:07:00+03	50000.00
662BAC	2017-07-16 02:21:00+03	78200.00
662BDA	2017-08-02 02:30:00+03	126400.00
662C1D	2017-07-17 06:52:00+03	43200.00
662C53	2017-07-25 17:27:00+03	93100.00
662C6E	2017-08-09 22:04:00+03	123000.00
662CC8	2017-08-05 17:54:00+03	40000.00
662D07	2017-07-01 11:56:00+03	50600.00
662D0D	2017-07-04 22:04:00+03	28800.00
662D2B	2017-08-03 13:16:00+03	153300.00
662D43	2017-07-30 18:24:00+03	168000.00
662D52	2017-08-02 12:27:00+03	111600.00
662DF1	2017-07-24 07:28:00+03	139300.00
662E4F	2017-07-17 20:59:00+03	52000.00
662E7F	2017-07-04 10:59:00+03	77900.00
662EC0	2017-07-26 07:05:00+03	31400.00
662F20	2017-07-05 01:00:00+03	40000.00
662F9A	2017-08-09 11:32:00+03	9200.00
662F9E	2017-08-10 15:15:00+03	35200.00
662FB2	2017-07-06 09:21:00+03	99200.00
662FC2	2017-08-05 12:56:00+03	40000.00
662FD1	2017-07-10 02:44:00+03	136200.00
662FEC	2017-07-26 03:42:00+03	6300.00
663006	2017-08-04 09:43:00+03	273400.00
66304C	2017-08-13 17:39:00+03	69900.00
663067	2017-07-19 15:57:00+03	135600.00
6630AE	2017-08-12 08:40:00+03	9800.00
66311B	2017-08-15 09:15:00+03	42900.00
663139	2017-08-09 17:17:00+03	15800.00
6631F7	2017-07-25 17:31:00+03	69500.00
663230	2017-07-14 10:54:00+03	46800.00
663238	2017-08-06 16:03:00+03	31600.00
663249	2017-07-09 14:34:00+03	77200.00
663255	2017-08-15 04:12:00+03	6700.00
66329D	2017-07-25 12:44:00+03	89700.00
6632B5	2017-08-09 17:23:00+03	105800.00
6632EE	2017-06-29 06:00:00+03	123000.00
663325	2017-07-14 22:41:00+03	93800.00
66339C	2017-07-26 14:16:00+03	21200.00
6633BD	2017-08-06 08:59:00+03	48800.00
6633D0	2017-07-23 17:22:00+03	52300.00
6633EC	2017-07-22 13:36:00+03	133800.00
663420	2017-07-18 10:30:00+03	277900.00
663446	2017-07-07 06:47:00+03	39500.00
663452	2017-08-03 11:12:00+03	282100.00
6634E8	2017-07-17 22:04:00+03	19500.00
6634E9	2017-07-27 08:29:00+03	46200.00
663500	2017-08-11 14:51:00+03	45100.00
663589	2017-08-02 05:43:00+03	46000.00
66358A	2017-07-23 14:02:00+03	154500.00
66359A	2017-07-18 09:31:00+03	38400.00
663611	2017-07-17 16:41:00+03	16400.00
663637	2017-08-04 04:03:00+03	44800.00
6636AF	2017-07-04 02:22:00+03	73200.00
6636BF	2017-08-13 02:47:00+03	49400.00
66380E	2017-07-17 03:42:00+03	92000.00
663822	2017-08-08 21:37:00+03	29400.00
663879	2017-08-13 05:12:00+03	38400.00
663882	2017-08-14 09:57:00+03	10800.00
6638D6	2017-07-31 04:06:00+03	38600.00
663966	2017-07-25 15:22:00+03	28000.00
6639EC	2017-07-24 17:50:00+03	56000.00
663A1B	2017-08-03 15:06:00+03	223200.00
663A2B	2017-08-05 19:49:00+03	64800.00
663A3B	2017-07-15 06:36:00+03	21000.00
663A63	2017-08-02 08:25:00+03	44600.00
663AB7	2017-07-08 03:42:00+03	135200.00
663BB3	2017-07-23 02:29:00+03	94800.00
663C0F	2017-08-15 00:20:00+03	99300.00
663C34	2017-08-13 15:40:00+03	67200.00
663C3E	2017-07-06 15:08:00+03	46400.00
663C5A	2017-06-30 15:47:00+03	178900.00
663C90	2017-07-21 04:00:00+03	116000.00
663CBC	2017-07-24 15:21:00+03	121800.00
663CDC	2017-08-03 18:23:00+03	542300.00
663D09	2017-08-11 23:55:00+03	94000.00
663D2E	2017-07-26 16:33:00+03	156000.00
663DB1	2017-07-07 10:21:00+03	32800.00
663E28	2017-07-11 03:58:00+03	42800.00
663E41	2017-07-04 10:36:00+03	139300.00
663E87	2017-08-10 22:21:00+03	27400.00
663F51	2017-07-14 20:49:00+03	36600.00
663F92	2017-07-03 14:16:00+03	51200.00
663FB8	2017-07-02 17:57:00+03	97200.00
66404D	2017-07-26 19:47:00+03	33600.00
664098	2017-07-09 12:52:00+03	236800.00
6640EC	2017-08-10 03:33:00+03	37900.00
664115	2017-08-13 05:38:00+03	92400.00
66412D	2017-07-18 03:32:00+03	229100.00
66416B	2017-08-02 02:02:00+03	161800.00
6641C8	2017-07-02 15:05:00+03	56600.00
6641F4	2017-08-08 05:17:00+03	84000.00
66424F	2017-08-04 01:02:00+03	100600.00
664268	2017-07-10 20:21:00+03	28000.00
6642C2	2017-07-20 01:59:00+03	70800.00
6642DD	2017-07-18 17:50:00+03	98400.00
664311	2017-07-21 09:46:00+03	115900.00
664360	2017-07-11 08:11:00+03	47400.00
6643A1	2017-07-12 00:58:00+03	38600.00
6643AB	2017-07-05 00:20:00+03	53000.00
6643BD	2017-07-20 04:31:00+03	246000.00
66448E	2017-07-08 19:18:00+03	196800.00
6644CC	2017-07-27 01:25:00+03	7200.00
664508	2017-07-07 23:47:00+03	74400.00
66450D	2017-08-06 17:13:00+03	60400.00
66459B	2017-07-16 06:36:00+03	115900.00
6645A5	2017-08-11 03:52:00+03	40400.00
6645A6	2017-07-19 20:22:00+03	25400.00
6645B4	2017-08-13 09:08:00+03	69500.00
6645BE	2017-08-11 11:27:00+03	26000.00
664623	2017-07-20 12:22:00+03	21400.00
66466A	2017-07-18 22:53:00+03	112000.00
66466E	2017-07-09 05:03:00+03	113200.00
6646AA	2017-07-09 01:04:00+03	24700.00
6646FD	2017-07-30 05:23:00+03	70800.00
66474F	2017-07-12 18:32:00+03	118900.00
6647AA	2017-07-04 23:17:00+03	26700.00
664874	2017-08-06 04:48:00+03	75300.00
664897	2017-08-03 06:57:00+03	58900.00
6648D1	2017-08-05 04:13:00+03	15000.00
6648F5	2017-07-25 07:05:00+03	36200.00
664909	2017-08-14 00:47:00+03	25100.00
66496A	2017-08-03 20:52:00+03	12600.00
6649ED	2017-07-06 00:02:00+03	116400.00
6649F7	2017-07-05 22:54:00+03	75300.00
664A50	2017-07-13 13:11:00+03	538000.00
664AE4	2017-07-10 20:47:00+03	100600.00
664B00	2017-07-07 14:37:00+03	11700.00
664B3D	2017-07-07 05:58:00+03	135600.00
664B74	2017-08-08 05:33:00+03	56000.00
664B7F	2017-08-10 04:08:00+03	166900.00
664B9A	2017-07-18 00:28:00+03	64700.00
664C04	2017-07-28 17:00:00+03	55000.00
664C29	2017-07-03 20:45:00+03	87000.00
664C34	2017-07-01 17:29:00+03	28800.00
664C61	2017-07-09 06:06:00+03	43100.00
664CA8	2017-07-29 21:23:00+03	44000.00
664CB7	2017-08-14 07:54:00+03	90800.00
664CE9	2017-08-04 05:13:00+03	12600.00
664D53	2017-08-09 10:44:00+03	26000.00
664E06	2017-07-09 19:42:00+03	219300.00
664E0E	2017-08-13 13:37:00+03	37800.00
664E63	2017-07-25 01:49:00+03	67800.00
664EC5	2017-08-10 05:10:00+03	35200.00
664ED1	2017-08-05 17:13:00+03	112000.00
664ED9	2017-06-27 06:26:00+03	67700.00
664F8C	2017-07-04 01:06:00+03	369000.00
664F9A	2017-07-22 10:41:00+03	117000.00
664FF0	2017-07-22 02:23:00+03	47600.00
665000	2017-06-30 17:13:00+03	51600.00
665017	2017-07-17 23:16:00+03	20000.00
665030	2017-08-08 09:42:00+03	32800.00
6650DD	2017-08-06 16:08:00+03	64800.00
665109	2017-08-10 09:53:00+03	165500.00
66519D	2017-08-05 06:40:00+03	55800.00
6652F3	2017-07-30 02:51:00+03	65100.00
665369	2017-07-21 17:58:00+03	91600.00
66539A	2017-07-08 21:42:00+03	21400.00
6653A3	2017-06-30 12:59:00+03	52000.00
6653BF	2017-08-04 15:41:00+03	21000.00
6653E4	2017-07-20 08:17:00+03	24400.00
6653E5	2017-07-31 07:23:00+03	132800.00
665426	2017-08-13 06:30:00+03	73600.00
6654C7	2017-08-07 04:09:00+03	55800.00
66551E	2017-06-30 06:07:00+03	188100.00
66553F	2017-07-16 04:29:00+03	57800.00
665544	2017-07-07 06:10:00+03	66600.00
665567	2017-06-28 00:22:00+03	24400.00
6655A0	2017-07-30 22:18:00+03	28000.00
6655CF	2017-08-09 08:08:00+03	12000.00
6655D6	2017-07-13 04:26:00+03	24400.00
6655DA	2017-08-06 12:22:00+03	114300.00
66561A	2017-07-22 13:35:00+03	26000.00
665635	2017-07-19 21:20:00+03	14000.00
665651	2017-07-24 13:11:00+03	68000.00
66565B	2017-07-18 06:34:00+03	38400.00
665660	2017-08-09 11:43:00+03	179200.00
6656C4	2017-08-03 03:52:00+03	186900.00
6656CE	2017-07-25 10:11:00+03	304100.00
665753	2017-07-05 11:58:00+03	44600.00
6657AC	2017-07-22 23:51:00+03	36200.00
6657E5	2017-07-17 22:51:00+03	31000.00
665801	2017-07-15 20:35:00+03	117100.00
66583B	2017-07-17 09:23:00+03	35200.00
665850	2017-07-11 18:25:00+03	62700.00
66585E	2017-07-28 10:11:00+03	15000.00
6658AC	2017-08-01 06:28:00+03	80900.00
6658F3	2017-07-25 07:12:00+03	386400.00
665935	2017-08-01 04:39:00+03	34000.00
665971	2017-06-28 15:54:00+03	39200.00
66597E	2017-08-08 15:06:00+03	26000.00
66599D	2017-07-18 08:59:00+03	28000.00
66599F	2017-08-05 14:14:00+03	8400.00
6659AF	2017-08-09 21:12:00+03	78000.00
665A36	2017-07-27 07:03:00+03	26200.00
665B57	2017-07-07 21:41:00+03	28800.00
665B8B	2017-08-09 11:05:00+03	26800.00
665BBA	2017-08-12 13:23:00+03	8000.00
665C43	2017-07-27 06:14:00+03	23600.00
665C65	2017-07-17 11:50:00+03	22100.00
665D3B	2017-07-19 18:54:00+03	38600.00
665D43	2017-06-30 13:51:00+03	123600.00
665D46	2017-07-08 13:53:00+03	39600.00
665D52	2017-07-26 10:30:00+03	173600.00
665D85	2017-08-11 19:36:00+03	42800.00
665DB9	2017-08-06 16:33:00+03	22000.00
665DE0	2017-07-25 20:15:00+03	14400.00
665DED	2017-07-20 17:47:00+03	8000.00
665DFD	2017-08-11 20:53:00+03	56000.00
665E01	2017-07-23 23:59:00+03	65100.00
665E86	2017-08-02 10:04:00+03	188300.00
665E9A	2017-08-08 21:00:00+03	99200.00
665EA8	2017-07-20 19:14:00+03	101200.00
665EEF	2017-07-14 12:06:00+03	87700.00
665F26	2017-08-14 02:25:00+03	286100.00
665F2E	2017-08-10 23:03:00+03	122500.00
665F79	2017-07-31 19:35:00+03	75800.00
665F8F	2017-07-19 06:39:00+03	67100.00
665FBB	2017-07-13 11:27:00+03	36200.00
665FE6	2017-07-23 01:10:00+03	55600.00
666038	2017-07-26 05:29:00+03	125200.00
666068	2017-08-01 23:12:00+03	49100.00
666090	2017-08-07 23:06:00+03	40000.00
6660C6	2017-07-12 08:07:00+03	20200.00
666104	2017-07-25 02:37:00+03	13400.00
666119	2017-07-25 13:54:00+03	160800.00
66611C	2017-07-14 08:05:00+03	31600.00
66615D	2017-08-15 16:55:00+03	64800.00
66616E	2017-07-05 04:34:00+03	66600.00
66627C	2017-08-02 14:47:00+03	10800.00
6662AB	2017-08-06 08:01:00+03	57500.00
6662FF	2017-07-12 04:36:00+03	139500.00
66631C	2017-08-11 02:44:00+03	60400.00
666389	2017-07-14 13:20:00+03	81500.00
66646A	2017-07-24 04:43:00+03	22800.00
666476	2017-07-26 23:52:00+03	92800.00
6664C7	2017-08-04 11:07:00+03	59800.00
6665F1	2017-07-31 05:03:00+03	55800.00
66666E	2017-07-28 02:31:00+03	206400.00
666675	2017-08-01 23:40:00+03	47200.00
6666D8	2017-06-29 08:46:00+03	26000.00
6666E8	2017-08-03 18:28:00+03	70500.00
6666F3	2017-07-19 19:04:00+03	52000.00
666712	2017-08-05 21:00:00+03	68800.00
666761	2017-08-11 07:05:00+03	12600.00
666775	2017-07-05 18:59:00+03	26600.00
666776	2017-08-01 10:59:00+03	34000.00
666782	2017-07-14 19:13:00+03	16400.00
6667A5	2017-07-04 06:42:00+03	258400.00
666828	2017-07-25 04:06:00+03	64400.00
66682B	2017-07-19 12:18:00+03	46400.00
66685B	2017-08-11 23:28:00+03	222800.00
6668DA	2017-07-11 04:27:00+03	33400.00
6668F3	2017-08-15 00:23:00+03	266400.00
666972	2017-08-07 11:18:00+03	136200.00
6669CD	2017-08-01 05:46:00+03	187600.00
6669F6	2017-07-21 00:38:00+03	89000.00
666A3B	2017-08-12 10:30:00+03	66600.00
666A41	2017-08-01 05:26:00+03	135400.00
666A61	2017-07-15 22:42:00+03	225800.00
666A9E	2017-07-02 19:42:00+03	52400.00
666AB6	2017-07-06 14:03:00+03	16400.00
666BE2	2017-07-05 22:59:00+03	55800.00
666C2D	2017-07-15 13:17:00+03	56900.00
666C69	2017-08-01 04:18:00+03	45500.00
666C97	2017-08-12 06:49:00+03	55800.00
666CAF	2017-07-06 19:47:00+03	39800.00
666D27	2017-07-23 10:20:00+03	170300.00
666E00	2017-08-13 06:22:00+03	76900.00
666E08	2017-07-24 14:45:00+03	14400.00
666E27	2017-08-14 09:06:00+03	112000.00
666E65	2017-07-14 14:13:00+03	61200.00
666E77	2017-07-14 22:56:00+03	38400.00
666EC5	2017-07-16 08:22:00+03	8400.00
666F29	2017-08-15 08:44:00+03	145300.00
666F8B	2017-07-07 11:53:00+03	114800.00
666FD5	2017-07-11 15:20:00+03	17800.00
666FF3	2017-07-11 20:25:00+03	49800.00
667022	2017-07-25 16:16:00+03	49300.00
667057	2017-07-01 19:17:00+03	133100.00
667188	2017-07-23 18:36:00+03	28800.00
6671AF	2017-07-30 23:56:00+03	35400.00
6671F9	2017-07-26 02:27:00+03	23600.00
66726E	2017-08-10 19:37:00+03	99600.00
6672AC	2017-07-24 12:40:00+03	122800.00
66732C	2017-08-08 18:25:00+03	35000.00
6673BE	2017-08-10 13:40:00+03	77900.00
6673BF	2017-08-14 12:54:00+03	66000.00
667426	2017-08-02 17:33:00+03	40100.00
667498	2017-07-11 21:57:00+03	134400.00
6674C9	2017-08-01 08:49:00+03	55800.00
667537	2017-08-09 17:27:00+03	40800.00
667545	2017-07-02 06:28:00+03	84500.00
667548	2017-07-16 12:02:00+03	28800.00
66754D	2017-07-15 06:43:00+03	12600.00
667630	2017-08-14 06:57:00+03	36200.00
667663	2017-06-30 03:54:00+03	45100.00
6676D9	2017-08-12 12:49:00+03	21800.00
6676EA	2017-08-14 04:50:00+03	378400.00
6676FA	2017-07-11 07:42:00+03	12400.00
667738	2017-08-08 06:23:00+03	152900.00
667773	2017-07-18 21:46:00+03	193700.00
66777D	2017-07-21 15:03:00+03	6200.00
6677CC	2017-07-31 16:24:00+03	36200.00
667806	2017-07-10 13:46:00+03	6700.00
66784F	2017-08-07 23:53:00+03	51900.00
66787E	2017-08-06 04:09:00+03	72600.00
667895	2017-07-14 03:22:00+03	185800.00
66789B	2017-08-03 14:49:00+03	39300.00
6678DE	2017-07-05 11:59:00+03	48800.00
6678E9	2017-07-09 22:35:00+03	39600.00
667911	2017-07-26 08:46:00+03	14800.00
667921	2017-07-16 02:31:00+03	48700.00
6679EA	2017-07-31 19:40:00+03	90800.00
667A26	2017-08-01 22:33:00+03	55800.00
667A9C	2017-07-26 05:40:00+03	113700.00
667ABC	2017-07-19 10:14:00+03	167400.00
667B19	2017-07-26 14:33:00+03	31600.00
667BDA	2017-07-27 19:41:00+03	351200.00
667CAC	2017-07-01 08:34:00+03	64500.00
667CDC	2017-08-01 02:00:00+03	99300.00
667DF3	2017-07-05 21:19:00+03	54400.00
667E15	2017-08-01 17:16:00+03	53300.00
667F21	2017-08-03 11:07:00+03	131700.00
667F74	2017-07-02 13:23:00+03	87700.00
667F76	2017-07-22 19:24:00+03	28000.00
668003	2017-07-28 14:31:00+03	36200.00
66806D	2017-07-13 09:01:00+03	32800.00
6680AA	2017-08-04 01:26:00+03	77400.00
6680FE	2017-07-20 14:44:00+03	246000.00
668109	2017-07-15 10:41:00+03	24400.00
66812D	2017-07-18 04:39:00+03	14700.00
668171	2017-07-23 11:14:00+03	12600.00
66817B	2017-07-14 17:04:00+03	229000.00
6682A3	2017-07-15 19:10:00+03	185300.00
6682AF	2017-07-30 21:51:00+03	46200.00
6682DF	2017-07-04 00:20:00+03	65900.00
6682EE	2017-07-23 00:08:00+03	125400.00
66832D	2017-08-13 08:33:00+03	93600.00
668377	2017-07-31 17:34:00+03	87300.00
668396	2017-07-14 10:58:00+03	102100.00
6683DC	2017-07-09 00:06:00+03	32700.00
66841C	2017-06-29 00:44:00+03	46200.00
66848C	2017-07-08 03:20:00+03	181600.00
668497	2017-07-11 05:54:00+03	49300.00
6684CC	2017-07-16 15:02:00+03	26000.00
668504	2017-07-10 12:38:00+03	221800.00
668552	2017-08-07 15:10:00+03	34000.00
6685E7	2017-08-07 18:30:00+03	24400.00
668635	2017-07-12 21:06:00+03	135000.00
668661	2017-08-01 17:18:00+03	43000.00
6686D8	2017-08-01 14:39:00+03	28000.00
668726	2017-07-26 15:39:00+03	39300.00
66872A	2017-07-29 22:26:00+03	25000.00
66872E	2017-07-02 10:48:00+03	67700.00
6687E0	2017-07-16 08:03:00+03	71000.00
6687F0	2017-08-13 13:24:00+03	31400.00
668850	2017-07-19 08:07:00+03	57600.00
66885F	2017-08-13 04:26:00+03	85000.00
6688A9	2017-06-27 20:54:00+03	75300.00
668988	2017-07-29 03:30:00+03	66000.00
6689B9	2017-07-31 15:16:00+03	50600.00
668A25	2017-07-31 18:00:00+03	191200.00
668A87	2017-07-15 07:08:00+03	43100.00
668ACE	2017-08-11 03:43:00+03	21400.00
668B3B	2017-08-04 05:27:00+03	20800.00
668B90	2017-07-07 08:42:00+03	62600.00
668BA2	2017-06-28 23:38:00+03	14000.00
668BC4	2017-07-15 01:02:00+03	52400.00
668C0F	2017-08-03 07:11:00+03	131600.00
668C41	2017-07-22 11:02:00+03	113000.00
668C61	2017-08-09 14:28:00+03	59200.00
668C66	2017-08-06 20:37:00+03	28600.00
668C6F	2017-07-19 19:47:00+03	67600.00
668C86	2017-07-04 23:35:00+03	124200.00
668CA2	2017-07-26 07:15:00+03	73200.00
668CA3	2017-07-19 06:31:00+03	70800.00
668CAF	2017-07-20 22:01:00+03	28000.00
668D02	2017-08-01 21:57:00+03	61200.00
668D12	2017-07-29 10:34:00+03	15000.00
668D41	2017-08-12 18:58:00+03	31700.00
668D83	2017-07-28 08:23:00+03	33300.00
668D9F	2017-07-08 10:16:00+03	140000.00
668DB4	2017-08-07 14:21:00+03	113800.00
668DCE	2017-08-10 20:34:00+03	46400.00
668E09	2017-07-18 22:48:00+03	67800.00
668E28	2017-08-09 21:21:00+03	31400.00
668E50	2017-08-13 16:18:00+03	56100.00
668E53	2017-08-15 11:27:00+03	6700.00
668E81	2017-08-14 15:32:00+03	111600.00
668E8E	2017-07-31 04:06:00+03	40000.00
668E8F	2017-07-11 07:34:00+03	44700.00
668E9D	2017-07-28 01:14:00+03	36600.00
668EA3	2017-07-04 09:40:00+03	28800.00
668EC3	2017-08-15 06:07:00+03	39300.00
668F14	2017-07-14 23:49:00+03	129600.00
668FA6	2017-07-12 13:45:00+03	28600.00
668FAD	2017-07-22 14:44:00+03	12600.00
669038	2017-08-08 17:10:00+03	103500.00
6690A1	2017-07-30 13:46:00+03	30200.00
6690F8	2017-08-11 04:21:00+03	55000.00
669126	2017-07-27 20:22:00+03	47000.00
66913D	2017-07-21 15:27:00+03	240600.00
669145	2017-07-25 00:20:00+03	10800.00
669176	2017-07-06 09:47:00+03	12600.00
6691A8	2017-07-24 09:23:00+03	82200.00
669212	2017-08-15 04:42:00+03	36200.00
669226	2017-07-19 08:08:00+03	28800.00
669254	2017-08-13 15:16:00+03	69500.00
6692DF	2017-07-05 13:44:00+03	65900.00
669310	2017-08-05 17:13:00+03	187600.00
66934F	2017-07-23 10:15:00+03	174600.00
669366	2017-08-06 16:15:00+03	69500.00
669388	2017-07-23 19:38:00+03	49800.00
6693E8	2017-07-22 01:59:00+03	28800.00
66940A	2017-07-15 07:51:00+03	46500.00
66950D	2017-07-19 20:29:00+03	11000.00
669543	2017-07-08 08:43:00+03	28600.00
669598	2017-07-01 18:37:00+03	15100.00
6695B5	2017-08-02 11:04:00+03	67000.00
6695E9	2017-07-29 07:26:00+03	92600.00
6696AB	2017-07-28 00:10:00+03	20200.00
6696C5	2017-08-04 14:42:00+03	181800.00
6696C6	2017-07-05 13:43:00+03	18000.00
6697B7	2017-07-24 11:21:00+03	125400.00
6697C3	2017-08-13 21:06:00+03	66600.00
6697EA	2017-07-24 16:37:00+03	62100.00
6697ED	2017-07-21 06:02:00+03	42800.00
66980F	2017-07-17 21:26:00+03	28000.00
66981B	2017-07-30 21:45:00+03	8000.00
669832	2017-07-06 10:14:00+03	78100.00
669864	2017-07-15 11:17:00+03	131900.00
669877	2017-07-31 20:46:00+03	111000.00
669882	2017-07-13 02:37:00+03	52000.00
6698EB	2017-07-19 20:24:00+03	23200.00
669954	2017-07-26 12:31:00+03	47000.00
669A16	2017-07-15 12:13:00+03	6000.00
669A2F	2017-07-27 18:42:00+03	40800.00
669B32	2017-08-03 12:52:00+03	46400.00
669BAF	2017-07-25 18:31:00+03	15900.00
669C0B	2017-07-21 21:41:00+03	100100.00
669C0F	2017-06-30 13:33:00+03	68600.00
669C18	2017-08-07 00:17:00+03	136800.00
669C19	2017-08-07 12:04:00+03	18800.00
669C5D	2017-07-15 04:54:00+03	45200.00
669CDB	2017-07-14 19:15:00+03	90800.00
669D1E	2017-07-29 11:25:00+03	223200.00
669D2F	2017-07-15 11:40:00+03	12600.00
669D4E	2017-08-04 08:41:00+03	131600.00
669DE6	2017-08-14 00:43:00+03	298500.00
669E61	2017-07-04 02:40:00+03	85000.00
669EE9	2017-07-04 00:05:00+03	92800.00
669F19	2017-07-29 10:22:00+03	56000.00
669F1C	2017-07-14 17:53:00+03	111600.00
669F62	2017-07-15 01:11:00+03	36200.00
669FA6	2017-08-06 20:42:00+03	23200.00
669FAE	2017-06-29 13:42:00+03	91900.00
669FFA	2017-07-30 23:20:00+03	70600.00
66A0FA	2017-07-14 23:11:00+03	69500.00
66A16B	2017-08-01 10:55:00+03	14300.00
66A200	2017-08-06 10:06:00+03	88800.00
66A224	2017-08-02 15:07:00+03	38600.00
66A239	2017-07-15 07:27:00+03	198400.00
66A253	2017-07-10 06:41:00+03	26000.00
66A278	2017-08-09 14:59:00+03	49400.00
66A2CA	2017-07-30 04:30:00+03	28700.00
66A31F	2017-08-05 03:35:00+03	243600.00
66A32C	2017-08-04 04:29:00+03	12400.00
66A338	2017-07-04 22:04:00+03	46200.00
66A352	2017-08-08 02:24:00+03	66600.00
66A382	2017-07-05 19:43:00+03	21400.00
66A40D	2017-07-11 03:19:00+03	62800.00
66A416	2017-08-07 15:53:00+03	54300.00
66A469	2017-07-01 12:03:00+03	75300.00
66A4A4	2017-07-30 11:14:00+03	58600.00
66A4CF	2017-07-27 14:43:00+03	177200.00
66A529	2017-07-25 21:14:00+03	84200.00
66A552	2017-07-23 03:31:00+03	89700.00
66A56B	2017-08-01 11:54:00+03	6000.00
66A5CA	2017-07-06 09:28:00+03	99200.00
66A5D3	2017-07-27 03:27:00+03	47600.00
66A6BB	2017-08-08 09:08:00+03	104600.00
66A6D0	2017-08-08 14:15:00+03	28800.00
66A713	2017-07-17 22:15:00+03	50200.00
66A722	2017-07-29 08:55:00+03	16400.00
66A742	2017-08-08 19:32:00+03	31400.00
66A7B5	2017-06-27 09:02:00+03	155600.00
66A7E4	2017-07-25 15:29:00+03	73500.00
66A803	2017-08-04 16:50:00+03	102100.00
66A807	2017-07-14 08:28:00+03	119000.00
66A84B	2017-07-24 19:27:00+03	119600.00
66A874	2017-08-08 23:05:00+03	7400.00
66A894	2017-08-08 12:13:00+03	114800.00
66A8A2	2017-08-13 09:13:00+03	69700.00
66A8B2	2017-08-03 19:19:00+03	28800.00
66A8DE	2017-07-02 21:47:00+03	224000.00
66A8E5	2017-07-21 18:14:00+03	15800.00
66A917	2017-07-13 06:29:00+03	186900.00
66A926	2017-08-11 08:45:00+03	31400.00
66A9B9	2017-08-09 17:25:00+03	49400.00
66AA1A	2017-06-29 04:26:00+03	40800.00
66AACC	2017-08-05 14:45:00+03	61800.00
66AB2A	2017-07-20 18:37:00+03	169900.00
66AB33	2017-07-07 18:06:00+03	90000.00
66AB54	2017-07-20 02:17:00+03	111600.00
66AB86	2017-08-14 23:26:00+03	70800.00
66AB8F	2017-07-09 00:52:00+03	92200.00
66ABA5	2017-08-12 04:28:00+03	72800.00
66ABD0	2017-07-24 22:52:00+03	44000.00
66AC8A	2017-08-02 21:14:00+03	89400.00
66ACA4	2017-07-28 14:23:00+03	116500.00
66AD04	2017-07-04 05:30:00+03	37400.00
66AD45	2017-07-30 21:45:00+03	45200.00
66ADA6	2017-07-30 07:04:00+03	120700.00
66ADE2	2017-08-08 20:07:00+03	31700.00
66AE35	2017-07-11 20:15:00+03	75200.00
66AEA1	2017-08-05 19:56:00+03	96800.00
66AF7C	2017-08-06 09:28:00+03	111600.00
66AFBC	2017-08-14 19:35:00+03	55800.00
66AFE6	2017-07-28 11:47:00+03	46400.00
66AFF0	2017-08-03 22:04:00+03	48800.00
66B00F	2017-08-06 16:07:00+03	23200.00
66B012	2017-07-22 08:19:00+03	31600.00
66B02A	2017-08-06 11:19:00+03	43100.00
66B079	2017-07-03 00:03:00+03	323900.00
66B0A5	2017-07-18 15:48:00+03	57600.00
66B0E9	2017-07-25 09:28:00+03	54800.00
66B106	2017-07-12 23:42:00+03	43900.00
66B17D	2017-07-15 08:10:00+03	86500.00
66B1DC	2017-07-07 02:42:00+03	28000.00
66B21F	2017-07-20 13:40:00+03	24300.00
66B26B	2017-08-02 17:27:00+03	25700.00
66B295	2017-07-02 16:10:00+03	31400.00
66B2A7	2017-07-14 15:39:00+03	23200.00
66B2E1	2017-08-05 03:28:00+03	68800.00
66B350	2017-07-25 09:12:00+03	54800.00
66B355	2017-07-06 18:25:00+03	111600.00
66B380	2017-07-17 19:25:00+03	14000.00
66B3B2	2017-08-06 11:47:00+03	65600.00
66B3B9	2017-08-07 21:54:00+03	62200.00
66B3CC	2017-07-11 23:11:00+03	124200.00
66B478	2017-07-25 04:05:00+03	32800.00
66B4AE	2017-08-08 00:46:00+03	26000.00
66B4E3	2017-07-01 16:26:00+03	89700.00
66B4F1	2017-07-08 10:34:00+03	55800.00
66B500	2017-08-06 12:17:00+03	25400.00
66B512	2017-07-06 01:50:00+03	84500.00
66B5A7	2017-07-27 00:24:00+03	93400.00
66B5C7	2017-07-23 22:34:00+03	174800.00
66B5C8	2017-08-11 11:34:00+03	28600.00
66B6A1	2017-07-17 03:27:00+03	85400.00
66B6BA	2017-08-11 07:32:00+03	108600.00
66B6E0	2017-07-29 22:01:00+03	56900.00
66B6F0	2017-08-09 04:58:00+03	266400.00
66B767	2017-08-12 00:18:00+03	7400.00
66B7BB	2017-07-18 04:09:00+03	24700.00
66B7BD	2017-07-23 17:06:00+03	12600.00
66B7E6	2017-07-28 20:11:00+03	85000.00
66B80D	2017-07-11 01:42:00+03	73500.00
66B84F	2017-07-09 18:32:00+03	28000.00
66B871	2017-07-19 16:02:00+03	24400.00
66B8D6	2017-08-09 20:43:00+03	12600.00
66B952	2017-07-07 16:47:00+03	62600.00
66B99A	2017-07-07 21:21:00+03	68800.00
66B9D3	2017-08-14 21:39:00+03	14400.00
66B9D6	2017-08-02 01:10:00+03	18800.00
66B9ED	2017-07-23 23:04:00+03	8400.00
66BA33	2017-07-26 05:31:00+03	135400.00
66BA45	2017-08-03 21:48:00+03	40300.00
66BA55	2017-08-03 09:30:00+03	28800.00
66BA9C	2017-07-23 22:48:00+03	26700.00
66BC18	2017-08-07 11:10:00+03	75600.00
66BC1A	2017-07-02 05:05:00+03	6700.00
66BC24	2017-07-23 16:03:00+03	106900.00
66BC29	2017-07-08 16:48:00+03	149300.00
66BD15	2017-07-30 08:47:00+03	133100.00
66BD2E	2017-08-04 11:47:00+03	95600.00
66BD47	2017-06-30 02:38:00+03	109600.00
66BD74	2017-07-06 04:43:00+03	22000.00
66BD77	2017-08-07 05:27:00+03	86600.00
66BE37	2017-07-25 13:20:00+03	28700.00
66BEB4	2017-07-11 09:09:00+03	29800.00
66BEBC	2017-08-08 02:53:00+03	56200.00
66BF22	2017-08-09 03:50:00+03	28000.00
66BF62	2017-07-12 01:25:00+03	136800.00
66BFF6	2017-07-01 19:43:00+03	133200.00
66C00A	2017-08-10 03:46:00+03	59800.00
66C05B	2017-08-09 01:07:00+03	130100.00
66C08A	2017-06-27 23:33:00+03	114300.00
66C0BE	2017-08-04 19:07:00+03	116800.00
66C113	2017-08-12 18:00:00+03	35800.00
66C14C	2017-07-10 14:53:00+03	28300.00
66C15A	2017-07-07 11:59:00+03	38600.00
66C16A	2017-08-07 09:11:00+03	40800.00
66C198	2017-07-19 07:22:00+03	68200.00
66C1DB	2017-07-22 10:56:00+03	56900.00
66C22C	2017-07-23 02:52:00+03	39200.00
66C239	2017-07-13 16:06:00+03	117700.00
66C251	2017-07-01 09:33:00+03	7400.00
66C281	2017-08-13 20:53:00+03	67200.00
66C287	2017-07-21 23:31:00+03	248400.00
66C33A	2017-08-05 00:57:00+03	34000.00
66C364	2017-07-05 13:45:00+03	160200.00
66C371	2017-08-01 13:45:00+03	51800.00
66C3B4	2017-07-17 05:48:00+03	12400.00
66C3B9	2017-07-15 02:35:00+03	386300.00
66C3D0	2017-07-28 13:54:00+03	56000.00
66C424	2017-07-26 16:38:00+03	12100.00
66C431	2017-08-15 08:31:00+03	129700.00
66C4DB	2017-06-29 04:55:00+03	271100.00
66C55C	2017-07-09 21:01:00+03	48800.00
66C58F	2017-07-25 21:17:00+03	114800.00
66C59C	2017-07-31 13:11:00+03	23200.00
66C64B	2017-08-05 11:11:00+03	16400.00
66C66A	2017-07-17 03:37:00+03	115100.00
66C66D	2017-07-07 19:20:00+03	14600.00
66C67A	2017-08-15 13:08:00+03	20200.00
66C681	2017-07-08 01:47:00+03	24400.00
66C6A7	2017-08-13 08:53:00+03	30700.00
66C6D0	2017-07-18 20:42:00+03	79000.00
66C726	2017-08-15 01:45:00+03	55000.00
66C7C5	2017-07-30 07:28:00+03	95200.00
66C8BF	2017-07-27 13:20:00+03	26000.00
66C8E3	2017-08-05 15:23:00+03	414800.00
66C8EC	2017-07-14 18:07:00+03	103500.00
66C8FC	2017-07-02 16:31:00+03	123600.00
66C90D	2017-08-08 16:23:00+03	209000.00
66C918	2017-06-26 06:20:00+03	29600.00
66C98E	2017-07-18 05:52:00+03	265600.00
66C9D6	2017-07-07 04:23:00+03	36500.00
66CA35	2017-07-02 19:10:00+03	128600.00
66CA51	2017-08-05 21:06:00+03	44800.00
66CA83	2017-07-21 23:54:00+03	133200.00
66CAA1	2017-08-09 11:08:00+03	89700.00
66CAEB	2017-07-09 02:46:00+03	66000.00
66CB35	2017-08-03 08:25:00+03	23400.00
66CB8A	2017-07-03 01:51:00+03	115700.00
66CBD1	2017-07-18 16:27:00+03	75500.00
66CBF6	2017-07-23 01:28:00+03	95700.00
66CC59	2017-07-11 19:24:00+03	113700.00
66CCB0	2017-07-26 08:16:00+03	67600.00
66CCF5	2017-07-11 14:54:00+03	52700.00
66CD28	2017-08-10 04:48:00+03	46900.00
66CD44	2017-08-15 03:11:00+03	54000.00
66CDAF	2017-07-28 19:38:00+03	69500.00
66CDBC	2017-07-17 20:38:00+03	55800.00
66CE1D	2017-07-03 18:56:00+03	92600.00
66CE34	2017-07-09 06:44:00+03	69500.00
66CE37	2017-08-11 19:52:00+03	72400.00
66CE8B	2017-08-06 06:03:00+03	30200.00
66CEAF	2017-07-13 03:47:00+03	24200.00
66CEFE	2017-07-19 19:21:00+03	56000.00
66CF32	2017-08-11 20:46:00+03	39500.00
66CF5A	2017-07-07 08:44:00+03	105900.00
66CF8E	2017-07-30 08:33:00+03	136200.00
66CFB4	2017-08-02 02:24:00+03	46400.00
66D053	2017-08-10 19:35:00+03	76600.00
66D126	2017-07-08 23:58:00+03	22600.00
66D16E	2017-07-27 16:09:00+03	60700.00
66D1BD	2017-07-11 01:38:00+03	64700.00
66D203	2017-07-05 01:31:00+03	8000.00
66D242	2017-07-28 08:29:00+03	254900.00
66D26A	2017-07-25 03:18:00+03	123000.00
66D28C	2017-06-27 09:36:00+03	75600.00
66D344	2017-08-07 01:42:00+03	492000.00
66D3C8	2017-07-05 12:08:00+03	6700.00
66D3E9	2017-08-06 01:50:00+03	190700.00
66D406	2017-07-18 10:22:00+03	72000.00
66D4D6	2017-08-14 22:01:00+03	37700.00
66D4DC	2017-07-07 03:41:00+03	137800.00
66D554	2017-08-08 14:04:00+03	187800.00
66D562	2017-07-14 14:25:00+03	43100.00
66D614	2017-08-05 19:01:00+03	301800.00
66D630	2017-07-22 19:52:00+03	23600.00
66D6A7	2017-07-24 18:45:00+03	32800.00
66D710	2017-07-30 11:45:00+03	47100.00
66D725	2017-08-12 11:22:00+03	39800.00
66D727	2017-08-02 23:56:00+03	118000.00
66D728	2017-07-19 20:13:00+03	14400.00
66D7D0	2017-08-10 09:38:00+03	220600.00
66D862	2017-06-30 16:05:00+03	49100.00
66D8D9	2017-08-07 00:13:00+03	260900.00
66D91C	2017-08-05 19:10:00+03	31200.00
66D920	2017-08-12 12:19:00+03	12600.00
66D94C	2017-07-10 19:06:00+03	89600.00
66D94F	2017-07-14 05:43:00+03	49600.00
66D952	2017-07-05 08:06:00+03	11600.00
66DA50	2017-08-04 01:39:00+03	41900.00
66DAB3	2017-07-15 14:39:00+03	90300.00
66DB16	2017-08-04 21:36:00+03	193300.00
66DB3D	2017-07-13 06:00:00+03	8400.00
66DB40	2017-07-22 08:12:00+03	16000.00
66DB49	2017-07-16 11:08:00+03	7900.00
66DB57	2017-07-17 04:16:00+03	58800.00
66DB75	2017-07-08 17:05:00+03	61800.00
66DC2C	2017-07-31 17:58:00+03	8000.00
66DC43	2017-07-13 00:32:00+03	205000.00
66DC92	2017-07-24 00:03:00+03	34000.00
66DD3E	2017-08-06 11:41:00+03	55800.00
66DD47	2017-07-10 17:05:00+03	46300.00
66DD6D	2017-07-07 18:31:00+03	6000.00
66DD7B	2017-07-23 15:36:00+03	79900.00
66DE86	2017-07-06 07:23:00+03	25900.00
66DE96	2017-07-24 04:02:00+03	24200.00
66DEAB	2017-07-10 19:24:00+03	14000.00
66DEC4	2017-07-11 19:02:00+03	75300.00
66DEE4	2017-07-21 01:39:00+03	21300.00
66DEE9	2017-08-07 14:35:00+03	21200.00
66DEF5	2017-08-03 16:13:00+03	46000.00
66DF6E	2017-07-06 03:24:00+03	25000.00
66DFF4	2017-07-02 03:35:00+03	28800.00
66E000	2017-07-14 14:36:00+03	106500.00
66E015	2017-07-21 17:30:00+03	17800.00
66E089	2017-07-19 12:42:00+03	44500.00
66E08E	2017-07-02 08:02:00+03	64700.00
66E0A5	2017-07-05 15:13:00+03	386300.00
66E0E1	2017-08-08 13:23:00+03	28000.00
66E151	2017-07-27 22:32:00+03	6700.00
66E160	2017-07-31 16:29:00+03	73600.00
66E184	2017-08-13 18:14:00+03	81600.00
66E19D	2017-07-24 12:37:00+03	147000.00
66E22E	2017-07-08 08:53:00+03	57800.00
66E282	2017-08-11 16:12:00+03	116000.00
66E2C7	2017-08-13 21:38:00+03	43000.00
66E2D3	2017-08-03 19:37:00+03	26000.00
66E3C1	2017-07-16 15:03:00+03	51900.00
66E449	2017-07-22 11:07:00+03	38200.00
66E488	2017-07-07 01:58:00+03	25600.00
66E4BB	2017-08-15 16:49:00+03	39600.00
66E530	2017-08-13 07:55:00+03	30300.00
66E618	2017-08-14 22:58:00+03	21600.00
66E67F	2017-07-28 23:16:00+03	70000.00
66E681	2017-07-06 05:31:00+03	64100.00
66E7A9	2017-07-31 12:05:00+03	205600.00
66E7B2	2017-08-03 05:51:00+03	33300.00
66E80B	2017-07-11 01:04:00+03	11700.00
66E832	2017-08-13 12:23:00+03	25800.00
66E834	2017-08-05 09:41:00+03	81300.00
66E849	2017-08-15 06:40:00+03	22600.00
66E882	2017-07-08 19:50:00+03	92800.00
66E898	2017-07-21 02:26:00+03	76800.00
66E8B9	2017-08-08 03:02:00+03	21800.00
66E8C5	2017-07-22 08:36:00+03	38800.00
66E922	2017-07-31 09:44:00+03	39200.00
66E92E	2017-07-31 20:52:00+03	26000.00
66E937	2017-07-26 19:34:00+03	14400.00
66E98A	2017-07-24 23:54:00+03	18600.00
66E9AA	2017-07-05 23:00:00+03	129600.00
66EA33	2017-07-26 22:42:00+03	21800.00
66EA8F	2017-07-04 18:29:00+03	37400.00
66EB06	2017-08-07 16:06:00+03	123000.00
66EC00	2017-07-11 07:42:00+03	112000.00
66EC11	2017-07-21 04:53:00+03	49100.00
66EC35	2017-08-07 16:17:00+03	45100.00
66EC52	2017-07-06 15:48:00+03	55500.00
66EC75	2017-07-07 17:57:00+03	28600.00
66EC89	2017-07-06 06:52:00+03	80800.00
66ECBF	2017-07-06 04:30:00+03	133200.00
66ECD3	2017-06-30 23:20:00+03	56600.00
66ED62	2017-07-14 16:47:00+03	58000.00
66ED74	2017-07-28 06:08:00+03	86600.00
66EDA1	2017-07-11 22:04:00+03	75100.00
66EE50	2017-07-26 05:17:00+03	20000.00
66EE6E	2017-08-03 05:21:00+03	29600.00
66EE84	2017-07-27 09:38:00+03	24400.00
66EE87	2017-07-23 16:52:00+03	46400.00
66EE9A	2017-08-01 01:59:00+03	6000.00
66EECC	2017-07-27 14:44:00+03	199700.00
66EF8B	2017-07-19 19:45:00+03	13600.00
66EFA1	2017-07-04 01:35:00+03	24800.00
66EFAC	2017-08-01 23:07:00+03	31100.00
66EFF2	2017-08-01 19:58:00+03	56000.00
66F0AB	2017-07-23 17:34:00+03	246000.00
66F0F7	2017-07-23 23:39:00+03	115700.00
66F19C	2017-07-08 13:58:00+03	123900.00
66F1C6	2017-08-04 04:52:00+03	16400.00
66F1D2	2017-08-14 19:12:00+03	104800.00
66F206	2017-08-11 21:49:00+03	17800.00
66F220	2017-06-29 10:19:00+03	147300.00
66F26C	2017-07-11 11:46:00+03	28200.00
66F274	2017-07-01 07:01:00+03	233700.00
66F2B0	2017-08-10 01:01:00+03	62000.00
66F2F8	2017-07-02 03:49:00+03	109200.00
66F329	2017-08-04 05:39:00+03	42800.00
66F335	2017-07-26 16:57:00+03	101200.00
66F341	2017-07-06 05:18:00+03	68200.00
66F3B6	2017-08-15 04:30:00+03	16000.00
66F3CD	2017-07-14 08:14:00+03	100600.00
66F43B	2017-07-27 07:01:00+03	126700.00
66F521	2017-08-14 10:11:00+03	88900.00
66F5F4	2017-07-03 22:36:00+03	58800.00
66F70F	2017-08-15 05:06:00+03	26000.00
66F775	2017-07-23 16:35:00+03	167400.00
66F798	2017-07-09 14:58:00+03	137100.00
66F7D0	2017-07-05 12:18:00+03	115300.00
66F89D	2017-07-17 17:43:00+03	52300.00
66F8D7	2017-08-03 11:03:00+03	16400.00
66F8F2	2017-08-08 13:03:00+03	28800.00
66F952	2017-07-03 23:06:00+03	36200.00
66F955	2017-08-09 18:21:00+03	133200.00
66F995	2017-07-28 09:50:00+03	145200.00
66F9A7	2017-07-11 16:45:00+03	67800.00
66F9BF	2017-07-21 19:46:00+03	72500.00
66F9CA	2017-07-19 21:28:00+03	25000.00
66FA2E	2017-08-02 19:08:00+03	133100.00
66FA3D	2017-08-06 14:11:00+03	28000.00
66FAB8	2017-07-17 21:43:00+03	27800.00
66FACE	2017-07-15 10:33:00+03	38400.00
66FB04	2017-07-25 02:38:00+03	53700.00
66FB0B	2017-06-30 21:10:00+03	30400.00
66FB2B	2017-07-17 13:12:00+03	36600.00
66FBE6	2017-07-15 02:26:00+03	179400.00
66FBE7	2017-07-27 23:08:00+03	23200.00
66FC3F	2017-08-01 17:05:00+03	22000.00
66FC5B	2017-07-28 04:39:00+03	56000.00
66FC5D	2017-07-11 17:10:00+03	13100.00
66FC61	2017-07-21 00:01:00+03	53900.00
66FC62	2017-08-03 10:11:00+03	67600.00
66FCC8	2017-08-08 20:12:00+03	13600.00
66FD27	2017-07-10 11:15:00+03	135000.00
66FD79	2017-07-24 10:30:00+03	138900.00
66FD90	2017-08-02 09:00:00+03	57800.00
66FDB3	2017-08-05 16:06:00+03	30200.00
66FE13	2017-07-04 18:41:00+03	71900.00
66FE2D	2017-08-05 01:31:00+03	56000.00
66FE3E	2017-07-25 17:15:00+03	54800.00
66FE92	2017-08-14 23:05:00+03	87000.00
66FE97	2017-07-23 09:20:00+03	32500.00
66FEBB	2017-08-05 15:54:00+03	18600.00
66FF01	2017-07-04 09:02:00+03	50600.00
66FF0F	2017-06-29 05:03:00+03	110500.00
66FF16	2017-07-18 18:15:00+03	47000.00
66FF2B	2017-07-08 21:27:00+03	112600.00
670001	2017-07-09 11:48:00+03	35700.00
67007A	2017-08-01 05:36:00+03	102700.00
670131	2017-08-09 17:10:00+03	46400.00
67013A	2017-06-30 12:13:00+03	78600.00
670236	2017-07-17 14:46:00+03	55800.00
6702AD	2017-08-08 15:07:00+03	459900.00
6702EA	2017-07-02 01:13:00+03	24700.00
6702F6	2017-08-06 14:51:00+03	14800.00
670303	2017-07-17 06:15:00+03	173200.00
67030F	2017-08-03 03:56:00+03	23600.00
670356	2017-07-20 13:37:00+03	61800.00
67038D	2017-08-12 00:09:00+03	39300.00
6703C9	2017-07-05 08:30:00+03	36400.00
6703CD	2017-08-12 13:39:00+03	32800.00
6703CE	2017-08-08 21:50:00+03	75300.00
6703D2	2017-07-20 08:09:00+03	223200.00
670407	2017-08-13 03:19:00+03	36200.00
670411	2017-07-14 19:01:00+03	49200.00
670471	2017-07-21 14:18:00+03	68800.00
6704DE	2017-07-14 05:39:00+03	13600.00
670513	2017-07-17 13:29:00+03	131100.00
670516	2017-07-12 07:35:00+03	160400.00
670574	2017-08-08 21:28:00+03	89600.00
6705AF	2017-07-17 22:49:00+03	26800.00
6705C4	2017-07-09 13:38:00+03	36500.00
670693	2017-07-19 08:13:00+03	31400.00
670697	2017-07-10 02:02:00+03	56900.00
6706A6	2017-07-28 23:02:00+03	42000.00
6706BA	2017-07-03 07:18:00+03	11600.00
670700	2017-07-26 00:13:00+03	115900.00
670727	2017-08-01 22:53:00+03	62600.00
67073F	2017-07-25 23:35:00+03	31400.00
670751	2017-08-13 04:25:00+03	73300.00
670761	2017-07-05 06:32:00+03	106400.00
670771	2017-07-06 03:22:00+03	53800.00
670797	2017-07-11 16:12:00+03	25000.00
670837	2017-08-15 03:21:00+03	100000.00
670887	2017-08-05 00:18:00+03	21800.00
6708CA	2017-08-05 21:59:00+03	48600.00
670913	2017-08-13 05:34:00+03	67400.00
670952	2017-07-21 07:30:00+03	87100.00
670A68	2017-08-13 18:31:00+03	28000.00
670A83	2017-07-24 22:20:00+03	43200.00
670A8D	2017-08-13 03:31:00+03	15400.00
670A99	2017-07-22 08:57:00+03	44000.00
670AB8	2017-08-03 13:37:00+03	133200.00
670B7B	2017-07-17 00:24:00+03	11600.00
670BB8	2017-07-04 14:05:00+03	47400.00
670BDE	2017-07-10 03:37:00+03	90600.00
670BEE	2017-07-19 04:06:00+03	67200.00
670C0B	2017-08-11 06:36:00+03	119500.00
670C68	2017-08-07 04:26:00+03	136800.00
670C75	2017-08-08 21:54:00+03	43600.00
670D10	2017-07-26 20:23:00+03	83600.00
670E90	2017-08-07 07:08:00+03	87800.00
670EA4	2017-08-06 13:55:00+03	88800.00
670ECB	2017-07-30 04:51:00+03	279200.00
670EEB	2017-07-04 23:51:00+03	35400.00
670EF3	2017-07-07 10:50:00+03	258400.00
670F42	2017-08-10 08:21:00+03	6600.00
670F45	2017-08-05 17:38:00+03	57400.00
670F59	2017-08-09 23:45:00+03	90600.00
670FEF	2017-07-28 10:53:00+03	6700.00
67107F	2017-08-13 02:59:00+03	47500.00
671149	2017-07-17 23:30:00+03	93700.00
67115F	2017-07-14 08:43:00+03	12400.00
67125E	2017-07-22 09:32:00+03	15700.00
67129C	2017-08-03 14:30:00+03	307500.00
6712FF	2017-07-30 18:20:00+03	81200.00
67130C	2017-08-14 03:25:00+03	126100.00
67136B	2017-08-12 01:46:00+03	74600.00
6713B3	2017-07-19 05:23:00+03	35800.00
67148F	2017-07-07 23:21:00+03	6000.00
67153D	2017-08-08 10:03:00+03	16400.00
671568	2017-07-22 08:30:00+03	19600.00
6715CD	2017-08-09 08:23:00+03	18600.00
67161A	2017-07-06 03:55:00+03	87100.00
671652	2017-08-14 03:08:00+03	35800.00
671674	2017-07-30 01:21:00+03	43900.00
671682	2017-08-03 20:16:00+03	25400.00
6716A7	2017-08-02 23:00:00+03	28000.00
6716C6	2017-07-25 19:03:00+03	102100.00
6716C7	2017-07-15 10:20:00+03	44000.00
671752	2017-07-12 02:21:00+03	34100.00
67177F	2017-07-08 03:48:00+03	28800.00
6717CE	2017-07-17 06:47:00+03	48800.00
6717DC	2017-08-07 05:28:00+03	56000.00
67183B	2017-08-02 20:55:00+03	26700.00
67185D	2017-08-11 17:03:00+03	148700.00
67189C	2017-07-20 18:28:00+03	42800.00
6718C2	2017-07-07 17:24:00+03	31700.00
6718F8	2017-07-06 02:50:00+03	36200.00
671914	2017-07-11 12:42:00+03	63500.00
67192D	2017-08-07 12:48:00+03	115900.00
671932	2017-07-13 06:10:00+03	56000.00
671946	2017-07-30 13:27:00+03	174600.00
67195D	2017-08-04 10:40:00+03	65600.00
671977	2017-08-04 05:58:00+03	25200.00
671987	2017-07-04 01:08:00+03	11600.00
6719CB	2017-08-06 04:24:00+03	160300.00
671A73	2017-07-02 02:35:00+03	23200.00
671AC8	2017-07-11 13:07:00+03	123000.00
671B10	2017-07-08 08:38:00+03	47000.00
671B21	2017-08-02 23:33:00+03	311200.00
671B23	2017-07-24 21:43:00+03	19200.00
671BA3	2017-08-05 08:32:00+03	62200.00
671BBA	2017-08-09 13:26:00+03	136200.00
671BF7	2017-07-28 20:23:00+03	48500.00
671C05	2017-08-15 12:27:00+03	14000.00
671C1B	2017-07-30 15:19:00+03	22200.00
671C31	2017-07-06 14:15:00+03	87000.00
671CB4	2017-07-01 03:32:00+03	132800.00
671DA0	2017-08-06 04:10:00+03	6300.00
671E7B	2017-07-30 04:06:00+03	22000.00
671E9B	2017-08-15 16:53:00+03	149300.00
671ECE	2017-07-27 17:35:00+03	32400.00
671ED3	2017-07-09 06:19:00+03	59200.00
671EE9	2017-07-14 12:30:00+03	102100.00
671F3C	2017-07-10 00:39:00+03	178300.00
671F9B	2017-08-10 21:35:00+03	137900.00
671FA2	2017-08-13 13:01:00+03	124200.00
672020	2017-07-09 05:31:00+03	18000.00
67212F	2017-07-04 09:42:00+03	46300.00
672139	2017-07-14 20:26:00+03	58800.00
67219B	2017-07-03 17:07:00+03	10700.00
672204	2017-07-26 06:26:00+03	56600.00
67223F	2017-07-25 08:06:00+03	139200.00
672255	2017-07-09 22:22:00+03	248300.00
672269	2017-07-09 06:32:00+03	21500.00
6722CF	2017-07-12 10:45:00+03	59200.00
672305	2017-06-28 20:27:00+03	20400.00
672309	2017-07-12 18:40:00+03	139300.00
672326	2017-06-28 09:35:00+03	31000.00
672330	2017-08-01 22:36:00+03	136800.00
672352	2017-08-14 20:05:00+03	43800.00
6723A7	2017-06-29 19:55:00+03	28800.00
6724DD	2017-07-09 05:13:00+03	184200.00
672547	2017-07-23 03:36:00+03	44600.00
67255C	2017-08-07 09:19:00+03	98000.00
67259D	2017-08-02 09:04:00+03	36200.00
6725A0	2017-07-27 00:58:00+03	48800.00
6725A2	2017-07-04 23:46:00+03	135400.00
6725D4	2017-07-11 20:33:00+03	42700.00
67264A	2017-08-12 05:28:00+03	77300.00
67266A	2017-07-13 09:51:00+03	25400.00
67267C	2017-08-09 16:12:00+03	32900.00
6726A2	2017-07-13 05:05:00+03	265700.00
6726BB	2017-07-12 00:54:00+03	92800.00
6726CA	2017-08-04 07:57:00+03	78600.00
672704	2017-08-09 00:21:00+03	85000.00
672725	2017-07-20 06:30:00+03	47200.00
67273F	2017-07-03 12:40:00+03	67600.00
672860	2017-07-06 11:55:00+03	27200.00
672877	2017-07-31 19:40:00+03	33800.00
67297A	2017-08-08 12:35:00+03	59800.00
6729FD	2017-07-09 01:20:00+03	28000.00
672A39	2017-07-08 08:36:00+03	135600.00
672A6F	2017-07-08 20:47:00+03	31400.00
672A7B	2017-07-06 21:24:00+03	21000.00
672AA5	2017-07-15 22:12:00+03	43500.00
672AF3	2017-07-31 12:10:00+03	47800.00
672B11	2017-08-04 17:01:00+03	129200.00
672B1B	2017-08-13 11:57:00+03	42800.00
672B27	2017-07-27 03:37:00+03	136000.00
672B4F	2017-07-09 21:55:00+03	117600.00
672B86	2017-07-18 17:03:00+03	70600.00
672BAF	2017-07-16 14:35:00+03	41200.00
672C30	2017-07-10 12:43:00+03	18000.00
672C91	2017-08-04 17:27:00+03	195900.00
672CDA	2017-07-17 12:41:00+03	87000.00
672D91	2017-07-21 19:27:00+03	70600.00
672DD4	2017-08-07 14:54:00+03	339300.00
672DDB	2017-07-02 11:15:00+03	56900.00
672EB1	2017-08-13 01:18:00+03	129700.00
672F06	2017-07-17 06:16:00+03	130900.00
672F2D	2017-07-22 03:07:00+03	160700.00
672F62	2017-07-21 12:22:00+03	54800.00
672F65	2017-07-10 11:31:00+03	74400.00
672FC6	2017-08-15 09:12:00+03	23500.00
673219	2017-07-26 02:07:00+03	6300.00
673245	2017-07-10 00:38:00+03	27300.00
6732B9	2017-07-11 22:11:00+03	75300.00
6732C3	2017-08-07 15:58:00+03	38400.00
6732D7	2017-07-06 14:11:00+03	25400.00
67330C	2017-07-21 16:25:00+03	43100.00
673385	2017-08-13 18:06:00+03	62600.00
6733DF	2017-07-30 09:43:00+03	173600.00
67356E	2017-07-06 01:36:00+03	29600.00
673582	2017-08-13 00:20:00+03	67600.00
673588	2017-07-24 07:22:00+03	73500.00
673594	2017-08-08 10:12:00+03	45200.00
673605	2017-07-25 13:51:00+03	56000.00
67361A	2017-07-11 15:22:00+03	52700.00
673627	2017-08-02 05:17:00+03	49800.00
673680	2017-07-30 02:15:00+03	25200.00
673697	2017-07-29 20:21:00+03	23200.00
67369B	2017-07-08 22:15:00+03	135600.00
6736D2	2017-07-31 07:00:00+03	265600.00
67373A	2017-08-06 10:12:00+03	46000.00
67376C	2017-07-05 14:45:00+03	6600.00
6737ED	2017-07-22 19:48:00+03	228700.00
6737F1	2017-07-09 02:24:00+03	54800.00
6737F5	2017-08-07 10:37:00+03	56600.00
673842	2017-07-06 19:51:00+03	46200.00
6738CC	2017-06-30 11:29:00+03	44600.00
6738E1	2017-08-11 19:37:00+03	56000.00
673920	2017-07-14 14:09:00+03	111600.00
6739A8	2017-07-02 07:28:00+03	80700.00
6739D0	2017-07-23 17:26:00+03	24400.00
673A10	2017-07-25 05:10:00+03	174000.00
673A65	2017-07-18 00:27:00+03	32200.00
673ABA	2017-08-10 12:29:00+03	33000.00
673ACA	2017-08-13 17:35:00+03	97900.00
673AD4	2017-08-01 04:48:00+03	65600.00
673AEF	2017-08-05 18:37:00+03	59200.00
673B6D	2017-08-15 07:37:00+03	56000.00
673B70	2017-07-04 16:31:00+03	199700.00
673B79	2017-07-13 05:03:00+03	25800.00
673BBD	2017-08-04 23:59:00+03	136200.00
673BBE	2017-07-31 10:22:00+03	32700.00
673BC8	2017-08-03 12:52:00+03	19600.00
673BE3	2017-07-18 23:02:00+03	28000.00
673BFC	2017-08-08 09:47:00+03	32800.00
673C04	2017-08-14 03:49:00+03	50800.00
673C55	2017-07-19 13:38:00+03	38800.00
673C65	2017-07-11 11:44:00+03	57600.00
673CCA	2017-07-13 14:43:00+03	262600.00
673CD7	2017-08-07 12:31:00+03	143200.00
673CED	2017-07-31 09:10:00+03	98400.00
673D29	2017-07-11 22:39:00+03	17200.00
673D35	2017-08-02 23:24:00+03	46300.00
673D52	2017-07-20 16:34:00+03	173200.00
673D5D	2017-07-17 06:04:00+03	103500.00
673D7F	2017-08-01 15:04:00+03	114800.00
673D86	2017-07-16 20:17:00+03	33600.00
673DF4	2017-07-18 17:16:00+03	46800.00
673E4E	2017-07-05 05:07:00+03	27200.00
673ED0	2017-08-03 23:29:00+03	28000.00
673F49	2017-08-03 02:18:00+03	67700.00
673F5B	2017-07-21 13:16:00+03	44800.00
673F6D	2017-07-16 04:05:00+03	96300.00
673F99	2017-07-05 11:03:00+03	62100.00
67401B	2017-07-18 05:51:00+03	18100.00
67407B	2017-07-19 22:29:00+03	27200.00
674083	2017-07-08 18:32:00+03	104300.00
674094	2017-07-19 17:21:00+03	34000.00
6740BF	2017-07-30 20:23:00+03	96200.00
674133	2017-08-15 05:29:00+03	213200.00
674186	2017-07-18 08:08:00+03	27200.00
6741B0	2017-07-03 09:57:00+03	85000.00
6741EA	2017-07-05 03:04:00+03	13400.00
67421F	2017-07-18 07:59:00+03	94800.00
67426C	2017-07-06 04:55:00+03	35600.00
674311	2017-07-16 23:00:00+03	28000.00
674324	2017-08-03 16:18:00+03	27800.00
674334	2017-07-23 00:03:00+03	372500.00
67447A	2017-07-09 19:08:00+03	23200.00
6744C7	2017-08-12 20:32:00+03	75600.00
674525	2017-08-13 03:28:00+03	93800.00
674639	2017-06-29 01:50:00+03	57600.00
674655	2017-08-06 23:03:00+03	200800.00
6746E8	2017-07-29 04:26:00+03	189200.00
674726	2017-07-29 00:52:00+03	8000.00
674788	2017-08-14 14:31:00+03	21800.00
674806	2017-07-30 19:24:00+03	58000.00
67482B	2017-08-12 10:01:00+03	14800.00
67483D	2017-08-15 05:54:00+03	66100.00
6748A4	2017-07-25 15:25:00+03	14400.00
6748E5	2017-08-06 10:25:00+03	114800.00
674958	2017-08-04 00:06:00+03	39300.00
674966	2017-08-07 09:14:00+03	20200.00
674970	2017-08-12 12:08:00+03	43000.00
674976	2017-08-14 11:33:00+03	110300.00
6749B6	2017-07-29 17:38:00+03	56600.00
6749DD	2017-07-07 12:22:00+03	46000.00
674A06	2017-07-27 14:11:00+03	92800.00
674A40	2017-08-12 12:38:00+03	80900.00
674A8C	2017-08-03 18:59:00+03	41600.00
674AC3	2017-08-09 09:00:00+03	37500.00
674ADE	2017-08-02 21:21:00+03	73600.00
674AE7	2017-07-26 20:49:00+03	99200.00
674B07	2017-07-24 15:40:00+03	58400.00
674B24	2017-07-15 12:48:00+03	85000.00
674B3B	2017-07-09 13:15:00+03	32800.00
674B3C	2017-08-06 08:48:00+03	144400.00
674B51	2017-07-22 06:59:00+03	6000.00
674B6D	2017-07-25 09:26:00+03	135000.00
674B73	2017-07-18 00:17:00+03	26000.00
674B9B	2017-07-03 20:39:00+03	54800.00
674BEB	2017-07-04 03:02:00+03	33300.00
674C15	2017-08-15 07:11:00+03	12000.00
674C36	2017-08-14 07:42:00+03	271100.00
674CA5	2017-08-14 17:19:00+03	167400.00
674CD2	2017-08-09 23:05:00+03	16400.00
674D11	2017-07-11 04:10:00+03	28600.00
674E09	2017-07-28 10:46:00+03	129100.00
674EEC	2017-08-10 22:28:00+03	66000.00
674EFB	2017-07-21 21:05:00+03	28800.00
674F3B	2017-08-14 10:02:00+03	14400.00
674FCF	2017-07-05 03:19:00+03	50800.00
67504E	2017-07-16 21:47:00+03	28800.00
675082	2017-07-28 21:35:00+03	14800.00
6750B9	2017-08-08 02:53:00+03	16000.00
6750D9	2017-07-07 01:10:00+03	6800.00
675143	2017-07-06 16:14:00+03	57800.00
675155	2017-07-10 13:06:00+03	29000.00
675228	2017-07-16 09:15:00+03	59800.00
67525A	2017-08-02 13:51:00+03	406700.00
67527E	2017-07-08 09:47:00+03	61700.00
675284	2017-08-10 23:02:00+03	22100.00
6752C6	2017-07-19 15:28:00+03	41600.00
675388	2017-08-05 21:55:00+03	48400.00
675393	2017-07-20 22:07:00+03	25600.00
6753DB	2017-08-10 00:10:00+03	114800.00
6753FE	2017-07-28 05:28:00+03	39200.00
67543E	2017-07-03 04:38:00+03	23200.00
675485	2017-07-27 12:00:00+03	28600.00
6754ED	2017-08-13 23:50:00+03	133900.00
675549	2017-07-17 09:30:00+03	34600.00
675564	2017-08-05 00:47:00+03	49700.00
675586	2017-07-10 14:41:00+03	80500.00
675606	2017-07-14 13:01:00+03	66900.00
67560C	2017-08-09 09:05:00+03	16400.00
675670	2017-07-29 08:02:00+03	13000.00
67567A	2017-07-23 14:54:00+03	29600.00
67568D	2017-07-07 13:35:00+03	37700.00
6756A1	2017-07-02 22:53:00+03	80500.00
6756CD	2017-08-13 05:06:00+03	27800.00
67571C	2017-07-30 18:53:00+03	294500.00
675720	2017-07-23 16:47:00+03	69000.00
67577C	2017-08-02 01:11:00+03	42800.00
6757EA	2017-07-07 02:34:00+03	58900.00
675865	2017-08-01 23:38:00+03	25400.00
6758A0	2017-08-02 17:04:00+03	76400.00
6758D3	2017-07-25 14:38:00+03	112600.00
6758E7	2017-07-09 10:24:00+03	21400.00
6758FA	2017-07-06 10:10:00+03	62600.00
675918	2017-07-27 22:20:00+03	133200.00
675954	2017-07-04 16:21:00+03	167400.00
67595C	2017-07-14 16:06:00+03	58800.00
675973	2017-08-09 20:18:00+03	79900.00
675989	2017-08-15 03:12:00+03	64700.00
6759C0	2017-07-01 15:08:00+03	92800.00
675B1C	2017-07-17 22:20:00+03	54500.00
675BC1	2017-07-06 04:27:00+03	199200.00
675BCF	2017-07-31 15:13:00+03	117600.00
675C53	2017-07-21 15:18:00+03	37200.00
675D45	2017-07-28 07:23:00+03	62900.00
675D69	2017-08-10 03:58:00+03	56000.00
675D72	2017-06-30 12:54:00+03	133200.00
675D96	2017-07-14 11:34:00+03	45200.00
675DB6	2017-08-09 10:12:00+03	88200.00
675DE1	2017-08-05 13:06:00+03	38000.00
675E61	2017-06-30 16:37:00+03	39800.00
675EB8	2017-08-06 01:17:00+03	14800.00
675F1B	2017-07-20 08:23:00+03	57500.00
675F36	2017-08-05 00:26:00+03	138500.00
675F63	2017-07-01 17:25:00+03	19800.00
675F7E	2017-07-05 19:59:00+03	38200.00
675FA7	2017-07-14 04:36:00+03	58400.00
675FAC	2017-07-17 05:28:00+03	36800.00
675FF0	2017-08-09 22:20:00+03	50600.00
67606C	2017-07-20 17:33:00+03	187200.00
6760E6	2017-06-27 09:28:00+03	51200.00
6760FD	2017-07-12 19:50:00+03	36200.00
6761B9	2017-07-29 00:05:00+03	21800.00
676259	2017-07-09 03:12:00+03	115100.00
6762B8	2017-08-14 02:43:00+03	38400.00
676343	2017-07-09 04:17:00+03	56100.00
6763AD	2017-06-30 05:26:00+03	22000.00
6763C5	2017-08-13 13:44:00+03	21400.00
6763FC	2017-07-17 14:52:00+03	45100.00
676411	2017-07-21 12:24:00+03	184300.00
67643B	2017-07-27 09:57:00+03	123000.00
676495	2017-08-10 07:07:00+03	87200.00
676498	2017-07-29 10:36:00+03	49400.00
6764A5	2017-08-08 02:04:00+03	185500.00
6764C3	2017-07-09 12:28:00+03	62600.00
6764E9	2017-07-23 02:46:00+03	103600.00
67654B	2017-07-31 03:59:00+03	23600.00
67655F	2017-08-07 13:41:00+03	28000.00
67665D	2017-07-09 18:25:00+03	101200.00
676680	2017-07-11 07:33:00+03	177600.00
6766A7	2017-07-29 06:48:00+03	603600.00
6766CD	2017-07-09 20:01:00+03	90400.00
676702	2017-08-03 20:05:00+03	25100.00
676709	2017-08-04 23:31:00+03	69000.00
676725	2017-08-09 07:48:00+03	58900.00
67673C	2017-08-07 12:06:00+03	51300.00
676752	2017-07-13 19:19:00+03	30200.00
676760	2017-08-13 23:15:00+03	28000.00
6767A2	2017-07-12 09:07:00+03	59300.00
676819	2017-08-04 18:21:00+03	28000.00
676858	2017-07-22 14:08:00+03	40000.00
67687A	2017-08-09 16:20:00+03	32800.00
6768A4	2017-07-05 12:51:00+03	22600.00
676939	2017-08-05 06:26:00+03	48800.00
6769D9	2017-08-01 03:31:00+03	68400.00
6769F9	2017-08-07 03:28:00+03	28200.00
676A26	2017-08-15 03:21:00+03	13400.00
676AE0	2017-07-09 15:32:00+03	119500.00
676AE3	2017-08-13 19:25:00+03	48700.00
676BFC	2017-07-27 00:17:00+03	51200.00
676C09	2017-08-15 15:18:00+03	84500.00
676C35	2017-08-06 06:25:00+03	20600.00
676C3C	2017-07-09 17:31:00+03	66600.00
676C4E	2017-07-16 12:28:00+03	47400.00
676C8B	2017-07-31 00:59:00+03	23200.00
676C91	2017-07-05 18:06:00+03	20200.00
676CB9	2017-07-13 14:47:00+03	639000.00
676D2B	2017-07-30 00:35:00+03	31600.00
676D44	2017-07-07 21:22:00+03	167400.00
676E27	2017-07-24 04:56:00+03	55800.00
676E4F	2017-08-13 11:46:00+03	68100.00
676E9B	2017-07-19 03:18:00+03	119500.00
676ECD	2017-07-20 15:58:00+03	22000.00
676EEA	2017-07-31 19:05:00+03	9300.00
676EF0	2017-07-12 23:05:00+03	198900.00
676FDC	2017-07-17 22:27:00+03	151800.00
6770D7	2017-07-16 08:27:00+03	114800.00
6770DE	2017-08-13 00:02:00+03	246300.00
67713F	2017-07-09 03:27:00+03	64600.00
677173	2017-08-13 09:12:00+03	39500.00
677189	2017-08-09 15:20:00+03	13400.00
6771C7	2017-08-01 17:22:00+03	135400.00
6771E7	2017-07-13 07:54:00+03	168200.00
6771F0	2017-08-03 21:21:00+03	136400.00
67727F	2017-08-06 10:44:00+03	21400.00
6772C2	2017-08-14 20:03:00+03	46400.00
67730A	2017-08-02 07:24:00+03	133100.00
677324	2017-07-24 08:26:00+03	79600.00
677360	2017-07-14 06:04:00+03	164800.00
67737C	2017-07-27 10:58:00+03	31600.00
677388	2017-07-29 10:16:00+03	56900.00
6773AB	2017-08-08 08:46:00+03	96800.00
6773B7	2017-07-11 04:31:00+03	19800.00
6773C2	2017-08-09 10:56:00+03	31000.00
67743E	2017-08-07 09:35:00+03	273400.00
67746B	2017-08-03 08:01:00+03	201700.00
6774FF	2017-08-06 07:00:00+03	37700.00
67752A	2017-08-11 20:14:00+03	12100.00
677551	2017-07-30 22:06:00+03	16400.00
67755E	2017-07-16 02:33:00+03	56100.00
6775B9	2017-08-15 02:35:00+03	46400.00
67761F	2017-07-09 09:40:00+03	56900.00
67763B	2017-08-12 01:41:00+03	123000.00
67767B	2017-08-03 07:48:00+03	75600.00
677683	2017-07-07 05:23:00+03	22000.00
67768D	2017-07-18 06:29:00+03	102000.00
6776D0	2017-07-17 19:46:00+03	46000.00
6776DD	2017-07-14 19:18:00+03	70700.00
677777	2017-07-24 01:43:00+03	64800.00
67778D	2017-08-05 15:03:00+03	75300.00
677798	2017-08-05 19:49:00+03	20200.00
6777B9	2017-08-11 21:31:00+03	6200.00
677809	2017-08-14 00:32:00+03	38600.00
67780D	2017-07-04 21:58:00+03	133100.00
677845	2017-06-30 04:19:00+03	170200.00
6778CE	2017-07-27 21:48:00+03	23600.00
6778DF	2017-07-17 20:23:00+03	56000.00
6778ED	2017-07-20 19:04:00+03	64300.00
6778F1	2017-07-21 12:29:00+03	27200.00
6778F8	2017-08-02 18:01:00+03	126800.00
67793D	2017-08-14 16:37:00+03	18400.00
677952	2017-08-10 21:05:00+03	26800.00
677A19	2017-08-06 18:04:00+03	36200.00
677A2B	2017-07-27 09:59:00+03	24400.00
677A3B	2017-08-02 10:08:00+03	40800.00
677A4D	2017-07-12 05:08:00+03	23200.00
677A5E	2017-08-08 15:00:00+03	68100.00
677ADA	2017-08-14 22:57:00+03	56600.00
677ADC	2017-07-08 16:17:00+03	56600.00
677B63	2017-08-08 04:01:00+03	28000.00
677B68	2017-08-14 05:20:00+03	27900.00
677BBD	2017-07-25 23:58:00+03	3400.00
677BCA	2017-07-28 01:51:00+03	56200.00
677C0A	2017-07-28 03:30:00+03	406700.00
677C18	2017-07-12 10:34:00+03	23400.00
677C27	2017-07-22 05:28:00+03	74400.00
677C2D	2017-07-17 03:03:00+03	29600.00
677C55	2017-07-01 18:31:00+03	168000.00
677C64	2017-07-16 01:13:00+03	246000.00
677C75	2017-07-16 10:42:00+03	36200.00
677CA1	2017-07-05 05:22:00+03	63200.00
677CAE	2017-08-03 08:25:00+03	135300.00
677CCE	2017-07-29 19:56:00+03	166000.00
677D30	2017-08-05 07:26:00+03	60400.00
677D4C	2017-06-28 07:19:00+03	92600.00
677D51	2017-08-08 13:02:00+03	135400.00
677DEF	2017-06-28 03:14:00+03	75600.00
677EB6	2017-07-14 15:10:00+03	27200.00
677ED9	2017-07-15 03:47:00+03	119300.00
677F5D	2017-07-28 15:40:00+03	123200.00
677F8E	2017-07-26 00:07:00+03	12600.00
677FAD	2017-08-05 18:46:00+03	59300.00
677FB4	2017-07-06 01:28:00+03	39800.00
67802E	2017-08-10 11:15:00+03	272800.00
678058	2017-07-12 19:31:00+03	127300.00
678060	2017-07-17 23:14:00+03	129700.00
678091	2017-08-04 11:33:00+03	141600.00
6780DC	2017-08-03 03:12:00+03	6300.00
6780EB	2017-07-26 09:44:00+03	14400.00
67811B	2017-08-06 22:46:00+03	72300.00
67819A	2017-07-17 11:24:00+03	40000.00
6781B0	2017-07-25 05:31:00+03	89600.00
6781C2	2017-07-11 11:14:00+03	29100.00
678221	2017-08-10 21:58:00+03	14400.00
67822F	2017-08-05 13:38:00+03	70400.00
6782AE	2017-07-12 13:25:00+03	88100.00
67832A	2017-07-31 11:05:00+03	36800.00
678344	2017-07-21 23:31:00+03	175700.00
678392	2017-08-02 09:24:00+03	106600.00
6783AC	2017-07-16 02:53:00+03	75300.00
6783CC	2017-07-13 21:25:00+03	67600.00
678405	2017-08-03 06:49:00+03	88600.00
678491	2017-08-05 07:52:00+03	244400.00
6784C1	2017-08-11 02:46:00+03	31400.00
678511	2017-07-26 10:53:00+03	24700.00
678554	2017-07-14 19:49:00+03	101200.00
678583	2017-07-17 16:49:00+03	24200.00
6785B3	2017-07-18 13:06:00+03	188000.00
6785D7	2017-07-23 06:48:00+03	23600.00
67869D	2017-07-22 11:20:00+03	6000.00
678782	2017-08-06 18:00:00+03	154500.00
67879B	2017-08-09 01:10:00+03	112000.00
6787C0	2017-07-27 11:55:00+03	53600.00
6787CA	2017-06-30 21:58:00+03	14400.00
678801	2017-07-13 23:45:00+03	32400.00
67883D	2017-08-01 08:57:00+03	135200.00
678843	2017-07-27 11:28:00+03	92900.00
67884D	2017-07-11 00:11:00+03	174400.00
6788BB	2017-07-29 21:00:00+03	266400.00
6788C3	2017-07-07 15:32:00+03	122000.00
6788F1	2017-07-24 19:31:00+03	29600.00
67890E	2017-07-08 11:18:00+03	34400.00
67893F	2017-08-09 02:31:00+03	55800.00
67898A	2017-07-31 21:10:00+03	199700.00
6789A0	2017-07-29 16:05:00+03	46400.00
6789E6	2017-07-03 21:08:00+03	47100.00
678A42	2017-08-10 14:38:00+03	47500.00
678A46	2017-07-01 01:18:00+03	12600.00
678A57	2017-07-28 23:31:00+03	49600.00
678AB0	2017-07-16 19:38:00+03	70600.00
678B17	2017-07-26 01:06:00+03	79300.00
678BB7	2017-07-19 17:20:00+03	136600.00
678C4E	2017-07-10 23:06:00+03	37200.00
678C61	2017-08-08 20:53:00+03	19800.00
678C68	2017-07-27 04:04:00+03	99300.00
678C81	2017-07-22 19:18:00+03	129600.00
678CED	2017-08-14 12:35:00+03	42800.00
678CFC	2017-07-12 19:54:00+03	24000.00
678D38	2017-08-10 14:33:00+03	7800.00
678D43	2017-07-24 19:16:00+03	26000.00
678D71	2017-08-09 11:40:00+03	38400.00
678D7E	2017-06-27 23:01:00+03	118800.00
678E14	2017-08-15 15:20:00+03	130300.00
678F97	2017-08-01 23:11:00+03	398500.00
678FEE	2017-07-15 06:21:00+03	96800.00
67905A	2017-07-02 06:34:00+03	37700.00
67906C	2017-08-09 00:24:00+03	88600.00
6790A1	2017-08-02 19:53:00+03	25700.00
6790A9	2017-08-12 12:50:00+03	69500.00
6790DE	2017-07-17 16:22:00+03	16400.00
6790EB	2017-07-08 17:47:00+03	72400.00
6791FB	2017-08-01 02:44:00+03	36200.00
679208	2017-07-25 05:55:00+03	136200.00
6792C3	2017-08-15 16:25:00+03	260300.00
679358	2017-07-18 14:05:00+03	86400.00
67937D	2017-07-07 21:13:00+03	34000.00
67939B	2017-07-31 17:12:00+03	56600.00
6793B2	2017-07-06 18:25:00+03	53700.00
6793D2	2017-07-08 08:37:00+03	135000.00
679414	2017-08-08 07:40:00+03	28700.00
67944D	2017-07-24 14:42:00+03	111600.00
679456	2017-07-13 02:31:00+03	196800.00
679457	2017-08-04 09:06:00+03	133100.00
67945D	2017-07-02 12:18:00+03	41600.00
6794BA	2017-08-14 19:13:00+03	16400.00
6794E6	2017-07-13 10:01:00+03	23600.00
679513	2017-07-06 09:22:00+03	6700.00
679563	2017-07-12 20:37:00+03	58400.00
6795C2	2017-08-10 17:17:00+03	113200.00
6795FA	2017-07-09 23:50:00+03	111600.00
679606	2017-07-12 14:00:00+03	202400.00
67962B	2017-07-17 01:11:00+03	44800.00
67966A	2017-07-17 18:53:00+03	46000.00
679710	2017-07-23 01:54:00+03	94000.00
679728	2017-07-10 12:05:00+03	45100.00
67973B	2017-08-09 22:22:00+03	14000.00
67975A	2017-07-22 01:48:00+03	97900.00
67975D	2017-08-05 03:56:00+03	44600.00
6797A7	2017-06-29 14:42:00+03	369000.00
679802	2017-08-04 05:37:00+03	26800.00
6798D0	2017-07-12 12:32:00+03	15400.00
6798E4	2017-07-14 13:57:00+03	63200.00
6798EA	2017-07-10 11:39:00+03	480600.00
679923	2017-07-02 04:06:00+03	19600.00
679951	2017-07-22 15:38:00+03	7400.00
6799A7	2017-07-20 05:58:00+03	27200.00
6799ED	2017-07-01 05:19:00+03	23200.00
6799F3	2017-08-04 15:41:00+03	123700.00
679A72	2017-07-15 02:13:00+03	67000.00
679B15	2017-08-13 08:05:00+03	101000.00
679BBE	2017-08-14 10:01:00+03	140500.00
679BCC	2017-07-08 09:44:00+03	59400.00
679BD6	2017-08-11 10:32:00+03	92700.00
679BD9	2017-07-09 03:58:00+03	21400.00
679BE7	2017-07-06 12:40:00+03	46200.00
679C52	2017-07-21 07:23:00+03	13800.00
679CA4	2017-07-20 19:00:00+03	43200.00
679CF6	2017-07-09 14:23:00+03	13400.00
679D22	2017-07-10 02:45:00+03	42400.00
679D2C	2017-06-28 18:04:00+03	118600.00
679D39	2017-07-29 12:42:00+03	16800.00
679D7C	2017-08-06 16:29:00+03	40000.00
679D99	2017-07-10 19:40:00+03	56100.00
679DBA	2017-08-08 05:33:00+03	269000.00
679DC0	2017-07-14 19:02:00+03	46200.00
679E2B	2017-07-07 17:45:00+03	25800.00
679E31	2017-07-15 09:35:00+03	46500.00
679E34	2017-07-25 23:38:00+03	89700.00
679E63	2017-07-24 10:52:00+03	6700.00
679E9B	2017-07-06 03:10:00+03	36200.00
679E9E	2017-07-30 21:33:00+03	46300.00
679F69	2017-08-14 20:17:00+03	41600.00
679F6D	2017-08-04 11:08:00+03	24600.00
679F75	2017-07-07 06:04:00+03	88600.00
679FB4	2017-07-11 20:59:00+03	29600.00
679FC1	2017-07-16 09:41:00+03	23200.00
67A076	2017-08-04 19:52:00+03	18100.00
67A079	2017-08-14 08:02:00+03	52800.00
67A0AB	2017-07-09 11:56:00+03	68800.00
67A1B2	2017-07-07 18:08:00+03	64300.00
67A250	2017-08-05 23:03:00+03	28300.00
67A2AF	2017-07-11 21:11:00+03	67600.00
67A331	2017-07-30 10:17:00+03	29200.00
67A38B	2017-07-16 12:16:00+03	52900.00
67A441	2017-08-08 19:42:00+03	246000.00
67A496	2017-08-03 01:28:00+03	168900.00
67A49D	2017-08-08 17:57:00+03	62600.00
67A4C0	2017-07-23 14:09:00+03	21400.00
67A52D	2017-08-03 07:38:00+03	47100.00
67A583	2017-08-07 05:10:00+03	229900.00
67A62C	2017-08-01 21:51:00+03	93900.00
67A63C	2017-07-20 22:30:00+03	30400.00
67A64D	2017-08-05 09:13:00+03	101200.00
67A68F	2017-08-06 11:30:00+03	57800.00
67A709	2017-07-17 01:01:00+03	89700.00
67A70D	2017-08-05 00:22:00+03	112000.00
67A73E	2017-07-03 12:08:00+03	71200.00
67A77A	2017-07-07 03:03:00+03	78500.00
67A7F5	2017-07-09 15:15:00+03	20200.00
67A810	2017-07-31 13:58:00+03	6700.00
67A83E	2017-07-14 10:50:00+03	51900.00
67A877	2017-07-02 03:04:00+03	55800.00
67A90E	2017-07-17 11:02:00+03	11700.00
67A9ED	2017-07-06 01:27:00+03	74200.00
67AA48	2017-07-08 11:44:00+03	66600.00
67AA4C	2017-07-25 11:10:00+03	265700.00
67AA62	2017-07-28 00:21:00+03	119800.00
67AAB4	2017-08-05 19:29:00+03	40400.00
67AB25	2017-07-21 11:04:00+03	147300.00
67AB52	2017-07-26 05:31:00+03	43600.00
67ABC7	2017-07-20 09:18:00+03	217800.00
67ABDD	2017-07-18 13:48:00+03	136800.00
67ABE0	2017-07-13 09:35:00+03	357600.00
67AC6F	2017-08-15 05:03:00+03	58400.00
67AD39	2017-07-28 03:46:00+03	16400.00
67AD51	2017-07-10 11:34:00+03	311200.00
67AD73	2017-06-29 04:54:00+03	54400.00
67AD81	2017-07-17 01:59:00+03	153800.00
67ADFD	2017-07-16 21:30:00+03	48900.00
67AE92	2017-07-17 15:38:00+03	48300.00
67AEC4	2017-07-30 13:27:00+03	13400.00
67AEEC	2017-08-08 00:16:00+03	11600.00
67AFF9	2017-07-22 06:04:00+03	67200.00
67AFFE	2017-07-21 12:21:00+03	9800.00
67B06C	2017-07-12 02:11:00+03	14400.00
67B072	2017-07-23 08:50:00+03	42700.00
67B106	2017-07-02 17:37:00+03	36400.00
67B117	2017-07-19 17:44:00+03	74800.00
67B126	2017-08-13 11:41:00+03	85700.00
67B1B2	2017-07-12 23:15:00+03	47200.00
67B25E	2017-07-21 05:34:00+03	69500.00
67B260	2017-08-07 03:10:00+03	156300.00
67B2B5	2017-07-08 23:19:00+03	26000.00
67B2DE	2017-08-07 08:51:00+03	51600.00
67B313	2017-07-13 18:11:00+03	62600.00
67B343	2017-08-02 00:41:00+03	27200.00
67B387	2017-07-02 11:56:00+03	19000.00
67B398	2017-07-17 23:15:00+03	40300.00
67B3AC	2017-08-10 00:46:00+03	21800.00
67B3E1	2017-07-31 19:11:00+03	43700.00
67B3E8	2017-06-27 02:08:00+03	266200.00
67B421	2017-07-31 08:14:00+03	28000.00
67B46A	2017-08-01 18:19:00+03	6000.00
67B4DC	2017-07-16 22:43:00+03	46200.00
67B503	2017-07-22 10:31:00+03	85000.00
67B50B	2017-07-31 07:51:00+03	51800.00
67B52C	2017-08-12 10:51:00+03	240600.00
67B5CA	2017-08-13 10:27:00+03	38800.00
67B5D8	2017-08-02 21:18:00+03	75600.00
67B60C	2017-07-13 08:50:00+03	22000.00
67B62A	2017-07-22 22:20:00+03	66400.00
67B668	2017-08-14 15:57:00+03	46000.00
67B6AA	2017-07-08 03:23:00+03	23400.00
67B6C6	2017-07-24 11:47:00+03	40800.00
67B6C7	2017-07-30 11:27:00+03	8200.00
67B790	2017-08-01 15:07:00+03	54800.00
67B7B8	2017-07-22 05:21:00+03	47000.00
67B7D3	2017-08-13 18:49:00+03	52000.00
67B7F5	2017-07-22 11:59:00+03	15000.00
67B7FB	2017-08-13 11:19:00+03	53600.00
67B803	2017-07-16 01:02:00+03	79600.00
67B89B	2017-07-05 17:01:00+03	31900.00
67B8CD	2017-07-08 09:21:00+03	69900.00
67B8F0	2017-07-26 11:33:00+03	75600.00
67B8F4	2017-07-05 03:35:00+03	26000.00
67B947	2017-07-29 18:16:00+03	32800.00
67B99F	2017-07-20 05:54:00+03	77900.00
67B9D4	2017-07-14 01:29:00+03	63300.00
67BA5E	2017-07-08 05:30:00+03	60400.00
67BA6E	2017-08-05 18:16:00+03	8400.00
67BA74	2017-08-10 11:47:00+03	71300.00
67BA7E	2017-07-08 23:07:00+03	28000.00
67BA9A	2017-07-03 10:34:00+03	44000.00
67BAC8	2017-07-26 05:22:00+03	46000.00
67BAD7	2017-07-30 05:27:00+03	49900.00
67BB09	2017-07-09 16:29:00+03	78300.00
67BB14	2017-07-30 17:42:00+03	94800.00
67BB8B	2017-07-19 21:36:00+03	47200.00
67BBAF	2017-07-08 11:05:00+03	102400.00
67BBBB	2017-07-22 23:32:00+03	73500.00
67BBCE	2017-07-05 18:52:00+03	67600.00
67BBE5	2017-07-09 00:56:00+03	58600.00
67BBE6	2017-07-12 17:14:00+03	18600.00
67BC21	2017-07-14 14:21:00+03	14000.00
67BC54	2017-08-10 11:10:00+03	124200.00
67BC8D	2017-07-01 19:17:00+03	119500.00
67BCDD	2017-08-12 04:22:00+03	43100.00
67BD35	2017-07-02 02:19:00+03	22000.00
67BD8F	2017-07-20 00:39:00+03	49800.00
67BDE3	2017-07-06 11:06:00+03	200800.00
67BE5A	2017-08-01 02:35:00+03	30700.00
67BE74	2017-08-07 03:42:00+03	103500.00
67BEB1	2017-08-15 16:21:00+03	201600.00
67BF4E	2017-08-08 03:39:00+03	19600.00
67BF70	2017-08-09 04:21:00+03	92800.00
67BF81	2017-08-05 08:04:00+03	29600.00
67BFAA	2017-07-13 05:59:00+03	24800.00
67BFBC	2017-08-07 18:28:00+03	24000.00
67BFBF	2017-07-04 16:40:00+03	24400.00
67C017	2017-08-14 01:43:00+03	113200.00
67C0C5	2017-07-10 07:21:00+03	27400.00
67C171	2017-08-13 16:58:00+03	94000.00
67C174	2017-07-04 02:55:00+03	32800.00
67C1B2	2017-07-11 00:14:00+03	22600.00
67C1B9	2017-07-15 17:08:00+03	11700.00
67C1F8	2017-07-01 10:23:00+03	51900.00
67C1FF	2017-07-14 22:08:00+03	170300.00
67C20B	2017-08-06 05:52:00+03	270800.00
67C214	2017-07-06 00:27:00+03	76800.00
67C253	2017-07-24 19:11:00+03	60700.00
67C25D	2017-07-18 12:00:00+03	92400.00
67C2B3	2017-07-16 21:35:00+03	24400.00
67C339	2017-07-16 08:08:00+03	12200.00
67C35F	2017-07-11 11:34:00+03	26700.00
67C379	2017-07-05 02:31:00+03	38000.00
67C3A1	2017-07-09 04:33:00+03	85000.00
67C3C7	2017-07-13 13:11:00+03	116400.00
67C3E4	2017-07-11 01:35:00+03	84500.00
67C405	2017-07-31 03:47:00+03	46000.00
67C421	2017-07-31 06:47:00+03	297000.00
67C458	2017-07-29 05:35:00+03	16400.00
67C47F	2017-08-11 02:10:00+03	20000.00
67C484	2017-08-04 23:21:00+03	23600.00
67C4D2	2017-07-20 09:12:00+03	85000.00
67C555	2017-07-30 04:47:00+03	85000.00
67C57A	2017-07-20 13:12:00+03	64500.00
67C5B8	2017-08-04 21:36:00+03	69000.00
67C642	2017-07-20 20:17:00+03	50800.00
67C66A	2017-07-14 01:35:00+03	58200.00
67C6B5	2017-08-10 18:37:00+03	25100.00
67C6B8	2017-07-03 04:13:00+03	271200.00
67C706	2017-07-19 21:41:00+03	306600.00
67C746	2017-07-26 22:11:00+03	258400.00
67C7FB	2017-07-23 21:20:00+03	27400.00
67C819	2017-07-04 11:24:00+03	31200.00
67C83D	2017-07-23 10:42:00+03	73100.00
67C852	2017-08-05 02:40:00+03	8000.00
67C860	2017-07-15 11:58:00+03	26200.00
67C88E	2017-07-02 11:07:00+03	81900.00
67C8A6	2017-06-29 10:49:00+03	65000.00
67C8C3	2017-08-04 08:24:00+03	13800.00
67C8D1	2017-08-10 02:41:00+03	240600.00
67C8E3	2017-08-14 02:55:00+03	39400.00
67C902	2017-07-22 14:32:00+03	31800.00
67C969	2017-08-10 12:36:00+03	98400.00
67C9C6	2017-07-04 03:15:00+03	56700.00
67CA25	2017-08-06 07:44:00+03	165200.00
67CA5E	2017-07-29 12:26:00+03	83100.00
67CA94	2017-07-11 05:07:00+03	7400.00
67CAB2	2017-07-02 04:02:00+03	88600.00
67CAC1	2017-07-24 20:37:00+03	23400.00
67CAC5	2017-08-14 06:22:00+03	13400.00
67CAC7	2017-07-07 11:20:00+03	49600.00
67CB17	2017-07-04 05:09:00+03	67600.00
67CB18	2017-07-24 00:03:00+03	14000.00
67CB30	2017-07-03 19:56:00+03	14000.00
67CB48	2017-07-09 14:18:00+03	75600.00
67CB4C	2017-07-18 22:22:00+03	90800.00
67CBC6	2017-07-14 07:29:00+03	133200.00
67CC13	2017-06-30 19:27:00+03	28000.00
67CC6E	2017-08-08 08:21:00+03	25200.00
67CD3A	2017-07-04 18:03:00+03	18300.00
67CD5F	2017-08-14 11:50:00+03	56600.00
67CD7C	2017-07-25 00:48:00+03	85000.00
67CD7E	2017-07-31 10:37:00+03	16400.00
67CDC0	2017-08-02 09:11:00+03	56000.00
67CE64	2017-07-31 22:36:00+03	30200.00
67CE79	2017-07-05 19:23:00+03	14000.00
67CEBE	2017-07-06 22:31:00+03	83000.00
67CEC2	2017-07-14 22:17:00+03	39200.00
67CEC3	2017-08-01 04:15:00+03	59100.00
67CEDA	2017-07-26 10:11:00+03	28000.00
67CF06	2017-08-14 18:10:00+03	68100.00
67CF1D	2017-08-08 08:29:00+03	89600.00
67CF23	2017-08-15 12:55:00+03	11700.00
67CF7E	2017-08-04 11:15:00+03	254100.00
67CFEF	2017-07-03 07:05:00+03	28000.00
67D017	2017-06-29 02:36:00+03	174400.00
67D080	2017-07-20 22:52:00+03	114300.00
67D09A	2017-07-03 09:11:00+03	65000.00
67D1E8	2017-07-15 21:29:00+03	56100.00
67D2BA	2017-07-11 16:27:00+03	28000.00
67D2E9	2017-07-15 18:34:00+03	36100.00
67D326	2017-08-10 11:48:00+03	126300.00
67D331	2017-07-08 05:07:00+03	369000.00
67D3A4	2017-07-13 13:56:00+03	92900.00
67D3AC	2017-07-20 20:17:00+03	27200.00
67D3EF	2017-08-07 04:34:00+03	94000.00
67D46B	2017-07-14 16:32:00+03	23200.00
67D4DE	2017-07-23 05:49:00+03	70600.00
67D523	2017-07-27 15:30:00+03	218000.00
67D53F	2017-07-24 06:56:00+03	31600.00
67D542	2017-07-28 16:19:00+03	63300.00
67D570	2017-07-01 18:13:00+03	124200.00
67D579	2017-07-24 09:26:00+03	24700.00
67D5F8	2017-06-28 20:43:00+03	21600.00
67D6A7	2017-08-09 10:38:00+03	48100.00
67D6AD	2017-07-10 20:00:00+03	75300.00
67D6C9	2017-07-31 04:40:00+03	26800.00
67D71D	2017-08-08 15:45:00+03	26000.00
67D798	2017-08-05 06:13:00+03	31400.00
67D7BA	2017-07-06 16:58:00+03	70700.00
67D7FA	2017-08-11 08:50:00+03	40600.00
67D81B	2017-07-17 12:34:00+03	240600.00
67D88C	2017-08-14 12:33:00+03	137900.00
67D8E5	2017-07-13 09:22:00+03	49800.00
67D8F6	2017-07-30 09:12:00+03	24600.00
67D8FC	2017-07-12 18:32:00+03	8000.00
67D92E	2017-07-25 08:31:00+03	91600.00
67D958	2017-07-11 01:23:00+03	24800.00
67D993	2017-07-03 16:27:00+03	37200.00
67D9D2	2017-08-07 22:34:00+03	56300.00
67D9EC	2017-07-21 22:08:00+03	23100.00
67DA22	2017-07-04 16:27:00+03	36500.00
67DACC	2017-07-16 19:08:00+03	61800.00
67DB4A	2017-07-29 04:00:00+03	46000.00
67DBC3	2017-08-03 01:47:00+03	79200.00
67DBC8	2017-08-07 16:41:00+03	59600.00
67DBDF	2017-07-10 05:54:00+03	133100.00
67DC89	2017-07-23 19:38:00+03	27200.00
67DCC2	2017-07-20 08:40:00+03	176800.00
67DCD4	2017-07-14 14:37:00+03	246000.00
67DCE8	2017-07-29 00:37:00+03	6000.00
67DD53	2017-08-13 02:35:00+03	52400.00
67DD98	2017-07-02 09:14:00+03	25200.00
67DDC0	2017-07-09 02:02:00+03	46800.00
67DDE4	2017-07-21 08:12:00+03	273600.00
67DDF1	2017-08-15 09:40:00+03	21400.00
67DE0A	2017-07-30 01:09:00+03	85000.00
67DE11	2017-08-11 15:23:00+03	529100.00
67DE18	2017-07-08 01:04:00+03	59000.00
67DE38	2017-08-08 19:13:00+03	57500.00
67DEBA	2017-08-03 23:51:00+03	45200.00
67DF6E	2017-08-13 20:35:00+03	246200.00
67DF8F	2017-08-01 16:28:00+03	88400.00
67E027	2017-07-31 08:28:00+03	77900.00
67E02A	2017-07-25 11:34:00+03	283700.00
67E0C9	2017-07-03 04:23:00+03	30000.00
67E109	2017-08-03 14:38:00+03	13000.00
67E10C	2017-08-01 08:43:00+03	132800.00
67E12A	2017-08-11 20:01:00+03	57600.00
67E21D	2017-07-25 12:55:00+03	167400.00
67E244	2017-08-09 18:55:00+03	79600.00
67E248	2017-07-30 08:29:00+03	36200.00
67E271	2017-07-13 09:39:00+03	26000.00
67E27A	2017-08-08 15:48:00+03	72800.00
67E32E	2017-07-20 06:48:00+03	59800.00
67E341	2017-07-21 06:00:00+03	96500.00
67E37F	2017-06-28 06:32:00+03	64800.00
67E397	2017-07-25 09:27:00+03	54000.00
67E3A2	2017-08-05 04:25:00+03	78300.00
67E3DF	2017-08-10 15:17:00+03	55900.00
67E3EA	2017-07-16 22:05:00+03	64300.00
67E488	2017-07-06 01:52:00+03	25000.00
67E558	2017-07-09 09:59:00+03	73500.00
67E59D	2017-07-22 19:08:00+03	111600.00
67E60A	2017-08-15 10:49:00+03	22300.00
67E666	2017-06-30 05:27:00+03	190100.00
67E6E1	2017-08-14 18:27:00+03	56000.00
67E77B	2017-07-11 06:54:00+03	21400.00
67E81D	2017-07-02 18:23:00+03	50600.00
67E859	2017-07-08 19:20:00+03	138000.00
67E8C8	2017-08-10 13:45:00+03	62900.00
67E8E0	2017-07-03 02:08:00+03	125200.00
67E976	2017-07-09 20:05:00+03	28000.00
67E9D5	2017-08-02 23:57:00+03	67600.00
67EA03	2017-07-14 15:11:00+03	69500.00
67EA4A	2017-07-19 04:29:00+03	41400.00
67EA59	2017-08-15 04:54:00+03	58600.00
67EA6A	2017-08-02 15:17:00+03	43200.00
67EA7C	2017-07-19 17:36:00+03	81300.00
67EB7C	2017-07-03 12:37:00+03	177200.00
67EBA1	2017-07-01 17:29:00+03	102100.00
67EBAF	2017-07-21 04:48:00+03	47800.00
67EBDE	2017-07-25 20:19:00+03	25600.00
67EC17	2017-07-19 16:53:00+03	93900.00
67EC31	2017-07-27 12:22:00+03	95200.00
67EC3D	2017-07-19 18:00:00+03	101200.00
67EC44	2017-08-08 02:50:00+03	288800.00
67ECE5	2017-07-16 07:39:00+03	20400.00
67ED04	2017-08-03 09:34:00+03	69400.00
67ED85	2017-07-13 00:58:00+03	73500.00
67EE9D	2017-08-03 01:38:00+03	15000.00
67EF1E	2017-08-02 19:34:00+03	47200.00
67EF61	2017-07-27 06:50:00+03	90600.00
67EFD8	2017-08-02 07:17:00+03	14000.00
67EFE5	2017-08-10 11:35:00+03	138000.00
67F009	2017-07-10 18:56:00+03	6000.00
67F014	2017-07-04 14:45:00+03	49700.00
67F055	2017-08-12 12:21:00+03	182300.00
67F08A	2017-07-06 23:52:00+03	27200.00
67F13D	2017-08-08 23:56:00+03	19600.00
67F1AF	2017-08-14 09:42:00+03	100900.00
67F1C4	2017-07-05 17:48:00+03	24400.00
67F1EA	2017-07-13 13:15:00+03	56900.00
67F1ED	2017-08-01 12:18:00+03	99200.00
67F21A	2017-07-19 10:36:00+03	270200.00
67F272	2017-08-04 22:38:00+03	258400.00
67F2AB	2017-07-26 12:13:00+03	13600.00
67F2EC	2017-07-13 19:50:00+03	14400.00
67F336	2017-08-12 12:43:00+03	17700.00
67F3D8	2017-08-10 02:36:00+03	51800.00
67F3E8	2017-07-05 09:45:00+03	62100.00
67F411	2017-08-07 18:12:00+03	28000.00
67F49A	2017-08-10 06:53:00+03	23200.00
67F4AA	2017-07-18 23:01:00+03	46000.00
67F4C2	2017-07-28 00:09:00+03	27200.00
67F4EB	2017-08-04 14:28:00+03	100600.00
67F511	2017-08-13 19:52:00+03	25100.00
67F51A	2017-08-14 00:39:00+03	115800.00
67F554	2017-07-13 16:24:00+03	133100.00
67F605	2017-07-15 11:36:00+03	30200.00
67F6B5	2017-08-14 19:14:00+03	56900.00
67F6E6	2017-07-22 11:48:00+03	68800.00
67F78A	2017-08-10 08:06:00+03	18600.00
67F800	2017-08-15 10:00:00+03	12600.00
67F82E	2017-07-27 20:29:00+03	369000.00
67F878	2017-07-22 19:32:00+03	111600.00
67F929	2017-07-14 04:30:00+03	22000.00
67F92A	2017-07-25 22:52:00+03	64200.00
67F993	2017-07-23 16:47:00+03	81500.00
67F998	2017-07-14 08:50:00+03	32800.00
67FA88	2017-07-10 19:23:00+03	29200.00
67FADC	2017-08-02 08:45:00+03	56000.00
67FAE1	2017-08-02 04:00:00+03	80000.00
67FAF3	2017-07-04 07:20:00+03	246000.00
67FB61	2017-07-15 08:17:00+03	21000.00
67FB8E	2017-07-11 08:03:00+03	21600.00
67FB97	2017-08-10 21:32:00+03	441400.00
67FBB2	2017-07-16 16:07:00+03	45400.00
67FBB9	2017-08-06 11:25:00+03	81500.00
67FBC9	2017-08-10 17:02:00+03	51600.00
67FC7F	2017-08-14 01:45:00+03	173600.00
67FC97	2017-08-07 00:36:00+03	53300.00
67FCF6	2017-07-02 15:21:00+03	23600.00
67FD20	2017-07-24 11:36:00+03	538100.00
67FD34	2017-08-06 23:43:00+03	72400.00
67FD38	2017-07-24 11:56:00+03	59800.00
67FD56	2017-08-05 20:47:00+03	72400.00
67FD67	2017-07-14 03:50:00+03	83200.00
67FD7F	2017-07-29 22:23:00+03	62700.00
67FD85	2017-07-20 23:19:00+03	202500.00
67FD98	2017-08-02 17:02:00+03	369000.00
67FE01	2017-07-18 11:43:00+03	19600.00
67FE05	2017-07-23 22:30:00+03	19600.00
67FE4D	2017-07-07 19:15:00+03	128800.00
67FE52	2017-07-28 23:44:00+03	26000.00
67FEAF	2017-08-03 16:29:00+03	35900.00
67FEFE	2017-07-29 01:16:00+03	65200.00
67FF17	2017-07-25 15:05:00+03	46000.00
67FF20	2017-07-07 05:18:00+03	30700.00
67FF26	2017-07-10 15:05:00+03	64600.00
67FFF3	2017-07-15 09:03:00+03	23400.00
67FFF9	2017-08-04 11:45:00+03	23600.00
68003C	2017-07-07 02:38:00+03	56000.00
680077	2017-08-10 06:08:00+03	66600.00
6800AF	2017-08-07 08:20:00+03	157400.00
6800CA	2017-07-28 00:33:00+03	23600.00
6800CF	2017-07-07 19:39:00+03	92400.00
680102	2017-07-10 07:18:00+03	43000.00
68016F	2017-07-13 07:56:00+03	43900.00
68027C	2017-06-29 04:08:00+03	25400.00
680299	2017-07-03 04:48:00+03	35200.00
6802F3	2017-07-08 17:49:00+03	112000.00
6802FE	2017-08-05 08:57:00+03	54000.00
680312	2017-07-23 04:51:00+03	55800.00
680369	2017-07-26 02:20:00+03	65500.00
680380	2017-07-10 19:06:00+03	81300.00
6803AD	2017-08-08 18:56:00+03	225200.00
6803EF	2017-07-11 03:28:00+03	133200.00
680440	2017-07-30 08:19:00+03	36400.00
680485	2017-08-07 13:01:00+03	87000.00
680496	2017-07-23 00:42:00+03	113300.00
6804D6	2017-07-15 10:44:00+03	76300.00
680522	2017-07-16 09:28:00+03	28000.00
68052F	2017-08-10 23:09:00+03	123000.00
680562	2017-07-03 01:39:00+03	30000.00
680584	2017-07-29 13:59:00+03	133200.00
680593	2017-07-30 19:09:00+03	52700.00
680595	2017-07-13 16:26:00+03	62600.00
6805AE	2017-07-17 19:59:00+03	20200.00
6805D6	2017-07-07 08:42:00+03	52300.00
680650	2017-08-08 23:26:00+03	40600.00
680675	2017-08-14 01:32:00+03	13200.00
6806C7	2017-07-04 19:03:00+03	70600.00
6806ED	2017-08-15 04:50:00+03	60300.00
6806F3	2017-07-10 13:41:00+03	142400.00
6806F7	2017-08-15 04:36:00+03	29600.00
6806FE	2017-08-04 23:57:00+03	67200.00
68072A	2017-07-21 17:51:00+03	128800.00
680765	2017-07-17 02:38:00+03	55800.00
680835	2017-07-26 21:25:00+03	111600.00
680844	2017-07-18 00:05:00+03	69500.00
6808E0	2017-08-08 01:13:00+03	35200.00
68093B	2017-07-15 02:28:00+03	27200.00
6809B6	2017-07-26 12:13:00+03	25400.00
6809EE	2017-07-18 00:15:00+03	100600.00
6809F6	2017-07-13 09:35:00+03	57700.00
680AA0	2017-08-01 17:19:00+03	75300.00
680AAF	2017-07-19 01:31:00+03	28800.00
680AD9	2017-08-12 20:51:00+03	93600.00
680BDC	2017-07-10 00:44:00+03	36900.00
680C96	2017-07-10 09:32:00+03	14400.00
680CD9	2017-07-10 10:31:00+03	66600.00
680CF0	2017-08-12 21:52:00+03	64700.00
680D13	2017-08-11 11:37:00+03	46000.00
680D1C	2017-08-14 10:56:00+03	28000.00
680D3D	2017-07-12 14:10:00+03	14000.00
680DB8	2017-08-08 03:34:00+03	125700.00
680DF3	2017-07-04 06:53:00+03	120700.00
680E00	2017-07-17 10:42:00+03	65900.00
680E17	2017-08-12 06:22:00+03	98400.00
680E85	2017-08-06 21:07:00+03	40000.00
680F10	2017-07-20 14:02:00+03	28800.00
680FB5	2017-07-07 22:47:00+03	56600.00
680FC2	2017-07-22 22:45:00+03	94700.00
680FCA	2017-07-19 06:35:00+03	13300.00
68105A	2017-07-08 04:09:00+03	40100.00
681068	2017-07-15 19:14:00+03	153300.00
681071	2017-07-05 22:08:00+03	28800.00
6810B2	2017-08-13 08:18:00+03	25600.00
681159	2017-08-04 13:20:00+03	63700.00
681179	2017-07-07 03:00:00+03	14400.00
6811C8	2017-07-06 20:44:00+03	57400.00
681277	2017-07-22 21:17:00+03	76300.00
68128D	2017-08-03 23:23:00+03	46400.00
6812D7	2017-07-03 08:34:00+03	25000.00
68130A	2017-07-06 19:12:00+03	6000.00
6813F7	2017-07-14 14:22:00+03	98200.00
681404	2017-08-05 17:51:00+03	56600.00
68142E	2017-08-15 00:05:00+03	73300.00
681434	2017-08-09 18:37:00+03	24300.00
68145B	2017-07-22 12:02:00+03	46500.00
68148A	2017-06-27 02:12:00+03	14000.00
6814A9	2017-08-10 09:06:00+03	68000.00
6814C0	2017-07-24 20:39:00+03	46000.00
6814CF	2017-07-10 02:38:00+03	38600.00
6814D3	2017-08-06 16:39:00+03	133200.00
6814FE	2017-07-25 23:42:00+03	50200.00
681543	2017-08-02 16:18:00+03	46400.00
681548	2017-07-29 15:14:00+03	73500.00
6815AF	2017-07-28 06:59:00+03	35500.00
681639	2017-08-07 13:39:00+03	6000.00
6816A7	2017-07-20 13:51:00+03	123000.00
6816E7	2017-08-15 01:58:00+03	24000.00
681708	2017-08-06 21:17:00+03	202100.00
681727	2017-07-14 12:27:00+03	38600.00
681729	2017-08-04 04:14:00+03	20100.00
681763	2017-07-20 17:20:00+03	68100.00
68177B	2017-07-23 05:30:00+03	133500.00
68184D	2017-07-15 04:10:00+03	128600.00
68184E	2017-07-20 18:47:00+03	43000.00
6818AD	2017-07-08 14:06:00+03	99200.00
6818CB	2017-07-28 12:21:00+03	37500.00
6818F3	2017-07-07 19:12:00+03	12600.00
681910	2017-07-31 20:13:00+03	23500.00
68191D	2017-07-21 23:53:00+03	28000.00
68192A	2017-07-28 11:30:00+03	57600.00
681944	2017-07-31 03:16:00+03	91700.00
681971	2017-07-18 17:16:00+03	68700.00
6819B3	2017-08-09 13:17:00+03	21800.00
6819DA	2017-07-10 13:44:00+03	38600.00
681A18	2017-08-02 19:42:00+03	28800.00
681AEC	2017-07-31 11:31:00+03	19600.00
681BF4	2017-07-14 02:25:00+03	76600.00
681C0B	2017-07-20 10:54:00+03	200200.00
681C0C	2017-08-06 11:56:00+03	35200.00
681C26	2017-08-07 05:43:00+03	32600.00
681C74	2017-07-26 23:12:00+03	58800.00
681CFC	2017-07-29 15:40:00+03	83200.00
681D81	2017-07-16 14:09:00+03	26100.00
681D9B	2017-07-24 22:34:00+03	206400.00
681DB7	2017-07-30 22:27:00+03	46400.00
681DBE	2017-07-20 00:34:00+03	70200.00
681DE1	2017-08-05 23:28:00+03	20800.00
681DE8	2017-07-10 03:06:00+03	47100.00
681E2B	2017-07-18 14:05:00+03	58800.00
681E9B	2017-07-04 01:48:00+03	73600.00
681EA2	2017-08-12 15:29:00+03	79800.00
681EDF	2017-07-29 11:16:00+03	81300.00
681F05	2017-07-02 05:41:00+03	13400.00
681F46	2017-08-13 18:02:00+03	277000.00
681F73	2017-08-14 01:26:00+03	41800.00
681F8D	2017-07-24 02:36:00+03	135400.00
681FA4	2017-07-05 14:04:00+03	13800.00
682235	2017-07-14 17:03:00+03	65900.00
682264	2017-07-14 11:44:00+03	64400.00
6822B0	2017-07-07 08:21:00+03	26800.00
6822BE	2017-07-12 14:49:00+03	13400.00
6822D3	2017-08-07 06:22:00+03	15900.00
6822DA	2017-07-23 11:13:00+03	211100.00
6822FF	2017-07-19 06:01:00+03	52800.00
68237B	2017-08-12 03:27:00+03	89600.00
68238D	2017-08-15 08:39:00+03	81600.00
6823EB	2017-07-25 23:27:00+03	27800.00
6823EC	2017-06-30 08:29:00+03	32800.00
6823F4	2017-06-27 04:12:00+03	146400.00
682415	2017-07-19 20:02:00+03	13600.00
682433	2017-07-18 20:11:00+03	56600.00
682446	2017-07-11 03:03:00+03	19600.00
682468	2017-08-10 06:39:00+03	99200.00
6824B4	2017-07-31 21:11:00+03	581100.00
6824B5	2017-08-09 19:15:00+03	24400.00
6824B7	2017-07-17 14:40:00+03	55800.00
682510	2017-08-03 00:03:00+03	22400.00
682512	2017-08-04 10:58:00+03	68800.00
682514	2017-07-05 15:55:00+03	26700.00
682525	2017-07-15 11:13:00+03	46000.00
6825D1	2017-07-06 11:49:00+03	75300.00
68260C	2017-08-05 14:06:00+03	62600.00
68261C	2017-07-14 03:07:00+03	47200.00
682637	2017-07-30 02:48:00+03	65400.00
682643	2017-08-13 06:47:00+03	97700.00
682654	2017-07-01 19:50:00+03	12000.00
682677	2017-08-07 13:00:00+03	246000.00
68267F	2017-07-05 17:28:00+03	73500.00
6826DE	2017-07-22 04:36:00+03	33100.00
6826F8	2017-07-11 06:49:00+03	43500.00
682715	2017-07-06 12:47:00+03	93800.00
6827BD	2017-07-11 17:53:00+03	147700.00
6827F4	2017-07-15 06:48:00+03	24300.00
682838	2017-07-08 18:05:00+03	125400.00
6828DB	2017-08-12 02:50:00+03	20200.00
6828E1	2017-08-11 21:46:00+03	113900.00
6829BA	2017-07-18 21:18:00+03	78600.00
6829FF	2017-08-15 12:37:00+03	59300.00
682A4E	2017-07-07 10:53:00+03	50300.00
682A75	2017-08-04 01:09:00+03	77000.00
682AB9	2017-08-09 06:00:00+03	450800.00
682ABC	2017-07-03 05:11:00+03	37800.00
682AD8	2017-07-19 05:35:00+03	128800.00
682B48	2017-06-28 21:22:00+03	24400.00
682C0A	2017-07-21 14:59:00+03	265800.00
682C4A	2017-07-24 23:12:00+03	135400.00
682C56	2017-07-14 05:10:00+03	74200.00
682C7D	2017-07-23 07:17:00+03	87500.00
682CB6	2017-08-14 21:56:00+03	69400.00
682CBC	2017-07-18 22:43:00+03	40800.00
682D29	2017-07-08 12:41:00+03	40600.00
682D2E	2017-07-11 16:33:00+03	6700.00
682D7F	2017-07-27 17:38:00+03	112000.00
682D8A	2017-07-24 22:37:00+03	148400.00
682E09	2017-07-23 04:39:00+03	65900.00
682E14	2017-08-15 07:24:00+03	43600.00
682E2D	2017-08-14 00:34:00+03	22600.00
682E77	2017-08-07 07:51:00+03	66300.00
682EAF	2017-07-04 10:16:00+03	135200.00
682EB2	2017-08-11 02:30:00+03	216100.00
682EBE	2017-08-11 10:29:00+03	27300.00
682F58	2017-07-22 07:09:00+03	105500.00
682F7A	2017-07-12 01:08:00+03	56000.00
683015	2017-07-15 03:29:00+03	123000.00
68303A	2017-08-02 00:39:00+03	81600.00
6830AE	2017-07-03 03:14:00+03	369000.00
683102	2017-07-19 12:26:00+03	396500.00
683127	2017-07-12 16:01:00+03	51900.00
68312D	2017-07-16 11:56:00+03	25100.00
683165	2017-07-22 11:17:00+03	74400.00
68317B	2017-08-15 00:06:00+03	28800.00
6831C1	2017-08-05 02:30:00+03	71200.00
6831C8	2017-08-08 11:56:00+03	26800.00
6831D4	2017-07-06 15:29:00+03	86300.00
68322D	2017-07-22 05:48:00+03	25600.00
683293	2017-07-15 17:36:00+03	38600.00
6832AD	2017-08-06 07:22:00+03	87000.00
6832B0	2017-07-14 00:57:00+03	38800.00
6832BB	2017-07-18 00:47:00+03	23600.00
6833BC	2017-08-11 13:27:00+03	72300.00
683428	2017-07-07 18:59:00+03	149200.00
683471	2017-08-09 01:02:00+03	59200.00
68347A	2017-07-27 08:55:00+03	14800.00
6834AC	2017-08-05 00:21:00+03	26000.00
6834AD	2017-07-09 22:06:00+03	51200.00
6834D4	2017-07-26 18:36:00+03	61800.00
6834DC	2017-07-22 17:29:00+03	375200.00
683555	2017-06-29 02:43:00+03	47000.00
68357A	2017-07-07 02:04:00+03	91600.00
683582	2017-07-30 17:25:00+03	56100.00
6835DF	2017-07-09 15:27:00+03	72400.00
6835FC	2017-08-07 11:22:00+03	57600.00
683608	2017-08-11 17:29:00+03	54800.00
683624	2017-08-12 09:15:00+03	170200.00
683647	2017-07-17 18:49:00+03	67600.00
68367C	2017-07-13 04:59:00+03	137100.00
6836C2	2017-08-02 22:23:00+03	23600.00
683722	2017-08-12 16:42:00+03	39400.00
683740	2017-08-12 16:09:00+03	31900.00
6837E5	2017-07-02 08:33:00+03	282300.00
6837F0	2017-07-07 11:12:00+03	11600.00
683864	2017-08-04 00:36:00+03	56000.00
683915	2017-07-17 22:41:00+03	67600.00
68392B	2017-08-09 23:05:00+03	56000.00
683934	2017-06-29 18:49:00+03	58200.00
683990	2017-07-16 20:12:00+03	61500.00
6839E9	2017-07-03 17:46:00+03	58800.00
683A36	2017-07-04 23:59:00+03	28000.00
683AD3	2017-07-03 02:28:00+03	84100.00
683AD6	2017-06-28 13:43:00+03	135400.00
683AE6	2017-07-22 09:13:00+03	11000.00
683B2A	2017-06-29 21:44:00+03	36200.00
683B95	2017-07-15 12:25:00+03	65400.00
683BA0	2017-07-29 18:55:00+03	123000.00
683BCA	2017-07-11 12:52:00+03	40800.00
683BE2	2017-08-02 12:49:00+03	114800.00
683BE8	2017-07-24 16:58:00+03	19000.00
683BFD	2017-07-22 11:02:00+03	9300.00
683C82	2017-07-20 10:31:00+03	54400.00
683CA4	2017-07-04 04:56:00+03	26000.00
683CB6	2017-07-04 07:07:00+03	67100.00
683CD1	2017-08-04 16:58:00+03	24800.00
683D09	2017-08-04 04:43:00+03	189200.00
683D4E	2017-07-17 22:38:00+03	38600.00
683D85	2017-07-06 12:09:00+03	23200.00
683E39	2017-08-09 18:25:00+03	132800.00
683E3B	2017-08-07 12:24:00+03	92100.00
683E4B	2017-07-28 16:48:00+03	75300.00
683EE1	2017-07-30 01:06:00+03	13400.00
683F37	2017-07-19 20:14:00+03	25800.00
683F91	2017-07-20 00:36:00+03	100600.00
683FA1	2017-08-13 00:55:00+03	44100.00
683FB8	2017-08-13 11:43:00+03	111600.00
683FF2	2017-08-12 22:14:00+03	46200.00
683FF9	2017-07-07 23:50:00+03	320400.00
684016	2017-07-12 09:11:00+03	66800.00
684046	2017-08-01 00:10:00+03	21200.00
684067	2017-08-12 02:43:00+03	53700.00
68406D	2017-08-03 01:05:00+03	94700.00
68410F	2017-08-11 08:34:00+03	26800.00
684214	2017-07-09 19:24:00+03	58700.00
684255	2017-08-15 10:16:00+03	36900.00
6842C5	2017-08-12 01:13:00+03	94000.00
68430D	2017-08-10 23:37:00+03	47800.00
68437A	2017-07-09 21:13:00+03	26200.00
6843A5	2017-07-21 12:28:00+03	126700.00
68454A	2017-07-23 02:40:00+03	85000.00
68454F	2017-07-21 09:59:00+03	23600.00
68458D	2017-07-03 14:07:00+03	143900.00
6845B7	2017-07-31 00:15:00+03	39000.00
6845C6	2017-08-03 20:32:00+03	52000.00
6845F0	2017-08-09 08:25:00+03	133100.00
684612	2017-07-03 19:50:00+03	86300.00
68468E	2017-07-25 02:06:00+03	13400.00
6846A9	2017-08-09 12:15:00+03	408500.00
6846EB	2017-07-11 16:09:00+03	21800.00
684734	2017-07-13 07:00:00+03	6700.00
68473A	2017-07-12 06:02:00+03	260300.00
68474D	2017-07-12 15:26:00+03	57600.00
684757	2017-07-17 05:59:00+03	112000.00
68475D	2017-07-08 14:15:00+03	66000.00
684760	2017-08-07 23:02:00+03	39200.00
68476D	2017-07-24 23:51:00+03	58600.00
684799	2017-08-13 01:44:00+03	30200.00
6847B1	2017-08-13 02:59:00+03	87800.00
684836	2017-08-14 10:03:00+03	12000.00
684878	2017-07-04 13:50:00+03	38900.00
6848A1	2017-07-09 10:29:00+03	58800.00
6848E3	2017-08-12 17:21:00+03	23200.00
684935	2017-08-03 03:15:00+03	182300.00
68494A	2017-08-04 23:15:00+03	134600.00
6849D0	2017-08-04 14:36:00+03	66300.00
684A08	2017-07-13 02:53:00+03	93900.00
684A1B	2017-07-07 06:27:00+03	265600.00
684A1C	2017-07-18 02:28:00+03	103000.00
684A64	2017-08-12 18:36:00+03	133100.00
684A70	2017-07-16 11:38:00+03	119700.00
684AC8	2017-07-25 16:07:00+03	26000.00
684B16	2017-08-04 07:20:00+03	54000.00
684B24	2017-08-07 06:05:00+03	51600.00
684BA5	2017-08-12 03:09:00+03	115600.00
684BBB	2017-08-06 10:20:00+03	56000.00
684BC9	2017-07-01 01:43:00+03	42800.00
684BCE	2017-08-12 11:08:00+03	63200.00
684BED	2017-08-11 03:29:00+03	68400.00
684C40	2017-07-10 13:58:00+03	57800.00
684C5E	2017-07-09 15:44:00+03	46300.00
684CCF	2017-08-13 21:21:00+03	51200.00
684CDA	2017-08-02 15:16:00+03	246000.00
684CEE	2017-07-24 18:19:00+03	31600.00
684CF8	2017-07-20 02:48:00+03	159100.00
684CFC	2017-08-06 00:14:00+03	189100.00
684D66	2017-07-25 23:09:00+03	20200.00
684DD7	2017-07-13 00:36:00+03	19600.00
684E19	2017-07-19 12:10:00+03	44600.00
684E4B	2017-07-17 14:23:00+03	137700.00
684E86	2017-07-18 04:46:00+03	131600.00
684EDC	2017-08-11 16:03:00+03	74400.00
684F3E	2017-07-28 01:37:00+03	153400.00
684F57	2017-07-21 19:26:00+03	14000.00
684FB7	2017-07-14 22:36:00+03	28000.00
685094	2017-07-26 08:39:00+03	55800.00
6850E3	2017-08-06 14:04:00+03	185400.00
685104	2017-07-31 18:14:00+03	65800.00
685117	2017-08-08 19:09:00+03	57500.00
685193	2017-07-07 02:02:00+03	16400.00
6851AC	2017-07-17 19:34:00+03	88500.00
6851C6	2017-08-02 16:27:00+03	140900.00
6851CB	2017-07-14 13:53:00+03	26800.00
6851F1	2017-07-21 00:11:00+03	64000.00
6851F6	2017-07-10 02:07:00+03	241300.00
68527D	2017-07-25 05:24:00+03	136600.00
6852AF	2017-07-10 20:46:00+03	90800.00
6852CB	2017-07-06 09:26:00+03	40100.00
6852E2	2017-07-19 23:39:00+03	140100.00
685375	2017-07-19 02:05:00+03	156400.00
68538E	2017-07-01 17:08:00+03	169800.00
68540E	2017-07-18 16:02:00+03	48300.00
685410	2017-08-02 05:22:00+03	14000.00
68543A	2017-08-11 13:37:00+03	260300.00
68547D	2017-08-13 13:30:00+03	28800.00
685482	2017-08-03 23:28:00+03	32200.00
6854FE	2017-08-10 16:48:00+03	3400.00
68556B	2017-08-15 14:02:00+03	31400.00
68558B	2017-07-07 17:08:00+03	131600.00
685597	2017-08-15 15:46:00+03	52700.00
685630	2017-07-17 23:48:00+03	47100.00
685647	2017-07-11 10:50:00+03	139300.00
685672	2017-08-08 13:02:00+03	40200.00
685684	2017-07-05 14:59:00+03	372500.00
68573E	2017-07-23 14:23:00+03	13000.00
685751	2017-07-07 08:44:00+03	46000.00
685755	2017-08-11 20:04:00+03	8200.00
685788	2017-08-03 16:48:00+03	57500.00
6857CA	2017-07-24 07:47:00+03	31400.00
68580F	2017-07-06 21:42:00+03	79900.00
68582C	2017-07-10 03:15:00+03	122200.00
68583B	2017-07-31 18:45:00+03	113500.00
68584B	2017-07-27 04:38:00+03	92000.00
685861	2017-07-07 16:01:00+03	121700.00
685883	2017-07-14 01:30:00+03	102300.00
6858AF	2017-08-09 14:22:00+03	21800.00
6858C5	2017-07-02 05:24:00+03	26000.00
68594C	2017-07-30 01:11:00+03	260300.00
685A29	2017-07-25 06:31:00+03	97000.00
685A5C	2017-08-09 23:39:00+03	56900.00
685A81	2017-08-10 22:56:00+03	51200.00
685AB4	2017-07-30 11:06:00+03	24800.00
685AB6	2017-08-08 11:09:00+03	28800.00
685B17	2017-07-23 18:22:00+03	304800.00
685BBE	2017-08-15 08:40:00+03	102100.00
685C3D	2017-07-29 00:59:00+03	123000.00
685C48	2017-07-06 16:09:00+03	19600.00
685C4D	2017-08-11 23:47:00+03	47100.00
685C72	2017-07-28 23:16:00+03	7300.00
685C8D	2017-07-23 06:32:00+03	55800.00
685CC8	2017-07-05 17:23:00+03	72300.00
685CE7	2017-07-26 20:00:00+03	15400.00
685D29	2017-06-30 19:43:00+03	11600.00
685D2E	2017-08-12 09:31:00+03	47000.00
685D3A	2017-08-13 21:52:00+03	20000.00
685D5D	2017-07-20 01:52:00+03	14400.00
685D84	2017-08-12 18:23:00+03	6000.00
685DBE	2017-07-10 21:13:00+03	24400.00
685DC0	2017-07-30 11:27:00+03	47000.00
685E2F	2017-07-15 09:23:00+03	29600.00
685E54	2017-07-16 17:14:00+03	58400.00
685F03	2017-07-18 09:58:00+03	65000.00
685F2A	2017-08-08 05:12:00+03	12600.00
685F7B	2017-07-11 17:55:00+03	81300.00
685F87	2017-07-19 00:26:00+03	146700.00
685FE6	2017-07-15 15:23:00+03	11200.00
685FEE	2017-08-15 14:51:00+03	251500.00
686054	2017-07-07 13:52:00+03	65900.00
686140	2017-07-15 01:05:00+03	135000.00
68615E	2017-06-27 18:08:00+03	75300.00
686175	2017-07-05 04:58:00+03	25900.00
6861A9	2017-08-12 07:29:00+03	148200.00
6861C9	2017-07-23 12:59:00+03	55800.00
6861EF	2017-07-25 11:00:00+03	155600.00
68623A	2017-08-05 23:12:00+03	31700.00
686289	2017-07-18 01:25:00+03	393800.00
68629E	2017-08-10 18:19:00+03	38300.00
6862AE	2017-08-11 10:15:00+03	36200.00
68630B	2017-08-15 10:20:00+03	67800.00
68634F	2017-07-12 07:06:00+03	20200.00
686373	2017-07-27 20:41:00+03	105600.00
6863A5	2017-07-27 03:00:00+03	241700.00
6863A9	2017-08-14 10:58:00+03	105100.00
686435	2017-08-10 18:05:00+03	50600.00
686494	2017-07-04 23:46:00+03	135600.00
6864F6	2017-07-03 16:31:00+03	50000.00
686539	2017-07-23 21:36:00+03	79600.00
686555	2017-07-25 20:48:00+03	6000.00
68656A	2017-07-16 07:28:00+03	37100.00
686650	2017-07-03 05:14:00+03	23500.00
686714	2017-08-13 01:05:00+03	6000.00
686773	2017-06-30 22:30:00+03	137700.00
686794	2017-07-10 16:19:00+03	155200.00
6867CB	2017-07-29 08:36:00+03	6700.00
6867D1	2017-07-13 19:10:00+03	93900.00
6867E5	2017-08-11 08:10:00+03	52500.00
6868D0	2017-08-11 06:43:00+03	41800.00
6868EF	2017-08-14 11:19:00+03	67500.00
68691D	2017-07-24 13:50:00+03	136200.00
6869B8	2017-08-13 10:13:00+03	135600.00
6869FD	2017-07-17 01:34:00+03	66600.00
686A16	2017-08-05 12:33:00+03	30200.00
686A1D	2017-07-10 09:20:00+03	10800.00
686A20	2017-08-05 08:02:00+03	6700.00
686A41	2017-08-09 05:01:00+03	125400.00
686AB6	2017-08-09 21:12:00+03	38300.00
686AF3	2017-07-07 03:46:00+03	166100.00
686B1F	2017-07-04 01:24:00+03	199700.00
686B84	2017-07-18 10:05:00+03	94700.00
686B95	2017-08-15 02:38:00+03	65600.00
686BCD	2017-06-30 03:59:00+03	16400.00
686BF0	2017-08-07 11:33:00+03	19100.00
686C65	2017-07-21 15:51:00+03	69000.00
686CD3	2017-07-24 11:01:00+03	92400.00
686D00	2017-07-24 04:09:00+03	6000.00
686D05	2017-08-07 09:46:00+03	10800.00
686D2C	2017-07-04 15:02:00+03	135400.00
686D41	2017-07-06 14:21:00+03	523000.00
686D8A	2017-07-25 18:20:00+03	135400.00
686E80	2017-07-23 21:38:00+03	23200.00
686EB0	2017-07-13 23:39:00+03	233700.00
686ECB	2017-08-01 08:32:00+03	40300.00
686F6B	2017-07-20 11:24:00+03	49800.00
686FD9	2017-07-16 12:01:00+03	56600.00
686FDA	2017-08-05 00:43:00+03	48300.00
687039	2017-08-08 11:29:00+03	304300.00
68704B	2017-08-02 13:19:00+03	32800.00
687094	2017-08-14 10:09:00+03	13200.00
6870BB	2017-08-06 06:46:00+03	281500.00
687100	2017-07-12 02:19:00+03	70100.00
687126	2017-08-04 04:50:00+03	214000.00
687139	2017-07-12 12:57:00+03	46400.00
687148	2017-07-28 20:12:00+03	278000.00
68718D	2017-07-14 00:37:00+03	92100.00
6871E1	2017-08-09 17:16:00+03	23500.00
687206	2017-08-08 14:03:00+03	67600.00
68720D	2017-07-31 17:02:00+03	26700.00
687213	2017-06-30 00:10:00+03	13600.00
68725B	2017-07-10 20:37:00+03	34000.00
6872B7	2017-08-07 11:51:00+03	38700.00
68736A	2017-08-01 14:38:00+03	32800.00
6873D9	2017-07-05 01:05:00+03	153100.00
687425	2017-07-25 12:50:00+03	65600.00
687427	2017-07-04 18:26:00+03	6800.00
687433	2017-08-14 05:15:00+03	56100.00
687449	2017-07-24 12:11:00+03	267500.00
687451	2017-08-11 17:36:00+03	27200.00
6874A0	2017-08-15 14:37:00+03	168000.00
6874CE	2017-08-14 14:04:00+03	27200.00
68750D	2017-06-28 03:27:00+03	55800.00
68750F	2017-08-13 19:01:00+03	52000.00
68751F	2017-07-15 11:10:00+03	6000.00
6875D9	2017-07-18 15:28:00+03	6000.00
687614	2017-08-12 07:52:00+03	16400.00
687639	2017-08-03 12:26:00+03	246000.00
687727	2017-07-31 08:51:00+03	43500.00
6877D3	2017-07-05 09:24:00+03	56000.00
687859	2017-08-04 04:53:00+03	112600.00
687864	2017-08-10 17:23:00+03	89200.00
687941	2017-08-05 19:24:00+03	121400.00
687942	2017-07-22 12:28:00+03	42000.00
687944	2017-07-01 11:00:00+03	7400.00
687950	2017-07-03 05:50:00+03	201200.00
6879A0	2017-07-03 08:12:00+03	49400.00
6879BE	2017-07-23 14:57:00+03	133100.00
6879DF	2017-07-17 01:06:00+03	26000.00
687A1D	2017-08-10 01:35:00+03	23200.00
687A41	2017-07-23 10:20:00+03	16400.00
687AA3	2017-07-20 10:04:00+03	28000.00
687AC6	2017-07-31 07:11:00+03	72400.00
687B04	2017-07-29 00:50:00+03	108600.00
687B63	2017-08-15 13:26:00+03	133200.00
687BB6	2017-08-10 14:35:00+03	135000.00
687C37	2017-08-05 14:00:00+03	16400.00
687CA9	2017-07-15 08:11:00+03	103900.00
687CED	2017-07-12 19:25:00+03	24400.00
687DAF	2017-08-03 09:37:00+03	91200.00
687E15	2017-07-24 01:23:00+03	35600.00
687E1A	2017-08-06 04:14:00+03	27200.00
687E1F	2017-07-09 11:45:00+03	270800.00
687EE6	2017-08-01 02:15:00+03	92800.00
687F55	2017-08-10 01:33:00+03	78200.00
687FDD	2017-08-08 08:03:00+03	136500.00
687FF4	2017-08-13 08:58:00+03	41200.00
68801E	2017-07-26 09:32:00+03	38800.00
688028	2017-07-23 04:02:00+03	29400.00
688087	2017-08-15 00:06:00+03	91600.00
6880C5	2017-08-15 11:31:00+03	246000.00
6880D5	2017-08-09 23:31:00+03	92000.00
68814D	2017-07-12 22:11:00+03	90000.00
68819E	2017-08-02 08:30:00+03	29400.00
6881AB	2017-07-28 14:03:00+03	10600.00
68820C	2017-07-16 18:01:00+03	62100.00
688219	2017-07-25 04:11:00+03	233900.00
688230	2017-07-27 04:46:00+03	36400.00
688235	2017-08-06 23:46:00+03	37400.00
6882C8	2017-07-22 15:06:00+03	37900.00
6882DF	2017-08-15 00:05:00+03	114700.00
6882EE	2017-07-27 11:15:00+03	58400.00
68830B	2017-08-06 03:00:00+03	66600.00
688318	2017-08-09 20:39:00+03	96800.00
68831B	2017-07-07 00:59:00+03	54000.00
688342	2017-08-11 18:49:00+03	24200.00
68837E	2017-07-15 11:57:00+03	32700.00
6883F8	2017-07-24 10:29:00+03	8000.00
688420	2017-08-08 09:56:00+03	27300.00
688443	2017-06-29 13:51:00+03	191500.00
688445	2017-07-08 21:12:00+03	44800.00
68844B	2017-08-15 05:14:00+03	22400.00
688471	2017-07-03 00:36:00+03	79900.00
6884E4	2017-08-07 00:05:00+03	16400.00
688577	2017-07-03 16:37:00+03	42100.00
688598	2017-07-27 09:58:00+03	269300.00
6885BD	2017-07-30 04:11:00+03	111600.00
6885DB	2017-07-31 16:24:00+03	43500.00
6885EA	2017-08-15 03:38:00+03	15000.00
68864F	2017-07-14 11:20:00+03	265800.00
688677	2017-06-29 13:19:00+03	36200.00
6886D6	2017-07-05 14:52:00+03	169900.00
688715	2017-08-06 00:37:00+03	64700.00
688743	2017-07-29 10:31:00+03	48500.00
6887E8	2017-06-26 04:25:00+03	96800.00
688814	2017-07-28 19:37:00+03	28000.00
68881A	2017-07-18 03:11:00+03	49600.00
688933	2017-08-03 23:52:00+03	7200.00
6889E0	2017-07-21 13:10:00+03	24400.00
688A12	2017-08-12 23:47:00+03	6000.00
688A29	2017-07-04 02:56:00+03	43200.00
688A2C	2017-07-21 08:23:00+03	25800.00
688A2E	2017-07-08 17:32:00+03	85400.00
688A41	2017-07-05 12:42:00+03	48500.00
688A56	2017-07-29 08:52:00+03	199100.00
688A6A	2017-07-06 10:09:00+03	185000.00
688A83	2017-07-24 10:17:00+03	53500.00
688A92	2017-07-13 04:25:00+03	111600.00
688B35	2017-08-12 08:20:00+03	18300.00
688BC9	2017-08-11 13:20:00+03	63200.00
688BEB	2017-07-09 21:12:00+03	14800.00
688C03	2017-07-16 08:30:00+03	66000.00
688C29	2017-07-25 14:34:00+03	96400.00
688C4E	2017-07-27 16:09:00+03	25200.00
688CD1	2017-07-22 20:51:00+03	6700.00
688D1F	2017-07-22 20:37:00+03	139000.00
688D2D	2017-07-19 05:06:00+03	32400.00
688D99	2017-07-11 21:25:00+03	40300.00
688DA5	2017-08-05 17:58:00+03	81600.00
688DBD	2017-08-10 19:49:00+03	57300.00
688E21	2017-07-14 22:23:00+03	6700.00
688E45	2017-07-17 11:02:00+03	31600.00
688EAB	2017-07-05 15:43:00+03	15200.00
688EF0	2017-07-05 13:41:00+03	131100.00
688F1F	2017-07-12 17:57:00+03	118800.00
688F25	2017-07-06 15:37:00+03	56900.00
68901F	2017-07-09 05:07:00+03	31600.00
689034	2017-07-10 02:30:00+03	186900.00
689043	2017-08-08 02:33:00+03	26000.00
689094	2017-08-05 09:29:00+03	136000.00
6890AC	2017-07-17 21:44:00+03	9800.00
6890C3	2017-07-12 06:09:00+03	62700.00
689107	2017-08-04 16:02:00+03	121400.00
68910B	2017-07-26 12:04:00+03	23200.00
68921E	2017-07-06 06:34:00+03	165000.00
689238	2017-08-09 21:18:00+03	66000.00
6892DF	2017-07-30 14:39:00+03	13400.00
689310	2017-07-09 12:30:00+03	56600.00
68933A	2017-07-19 04:12:00+03	20200.00
689357	2017-08-06 10:06:00+03	51600.00
68938E	2017-08-15 03:44:00+03	68000.00
6893D8	2017-08-07 16:49:00+03	246000.00
689401	2017-07-24 13:30:00+03	26700.00
689422	2017-07-12 09:42:00+03	52100.00
689436	2017-07-17 19:14:00+03	73400.00
689485	2017-07-08 01:17:00+03	155600.00
6894C5	2017-08-13 20:49:00+03	83000.00
6894E5	2017-08-10 18:54:00+03	67300.00
68950B	2017-07-10 11:25:00+03	13200.00
68952A	2017-06-30 15:17:00+03	140900.00
689532	2017-08-01 03:33:00+03	33300.00
689535	2017-07-12 11:35:00+03	57400.00
689545	2017-08-03 21:25:00+03	49100.00
689575	2017-07-08 13:15:00+03	49800.00
68962E	2017-08-04 08:00:00+03	134500.00
6896D6	2017-07-26 13:16:00+03	59800.00
689748	2017-06-30 14:10:00+03	73200.00
689753	2017-07-16 23:01:00+03	399600.00
689779	2017-07-10 03:38:00+03	26000.00
6897A1	2017-07-05 22:45:00+03	106700.00
6897CB	2017-07-10 10:20:00+03	86500.00
6897F6	2017-07-08 13:59:00+03	103900.00
689824	2017-07-24 03:04:00+03	27800.00
689857	2017-07-22 16:43:00+03	69500.00
68990E	2017-08-10 06:40:00+03	44800.00
689916	2017-07-07 16:23:00+03	12600.00
68991F	2017-07-17 01:26:00+03	100600.00
689952	2017-07-19 12:42:00+03	20200.00
6899C5	2017-07-22 01:20:00+03	73200.00
6899E5	2017-07-27 19:11:00+03	41600.00
689A05	2017-07-02 10:06:00+03	71900.00
689A48	2017-08-11 22:05:00+03	56100.00
689ABA	2017-07-08 00:08:00+03	43200.00
689AC0	2017-08-12 16:34:00+03	99600.00
689C78	2017-07-29 09:56:00+03	48800.00
689C91	2017-08-02 07:34:00+03	99800.00
689CD3	2017-07-30 15:15:00+03	225300.00
689D74	2017-07-15 16:43:00+03	21800.00
689D80	2017-07-06 19:39:00+03	32700.00
689D91	2017-08-05 08:40:00+03	94000.00
689D93	2017-06-29 09:51:00+03	19600.00
689DF5	2017-08-06 07:13:00+03	150300.00
689E54	2017-07-29 01:09:00+03	134600.00
689E6C	2017-07-13 07:37:00+03	20200.00
689E94	2017-08-01 15:56:00+03	40800.00
689F08	2017-07-26 17:55:00+03	26700.00
689FD4	2017-07-13 14:21:00+03	24400.00
689FDC	2017-07-22 02:59:00+03	86400.00
689FDE	2017-07-19 15:06:00+03	40800.00
68A035	2017-08-02 19:28:00+03	47600.00
68A095	2017-07-21 01:06:00+03	132800.00
68A0E1	2017-07-28 18:20:00+03	70400.00
68A0E6	2017-08-13 20:37:00+03	15100.00
68A0F1	2017-08-05 06:55:00+03	133200.00
68A137	2017-07-05 14:29:00+03	119500.00
68A149	2017-07-21 14:33:00+03	52300.00
68A19A	2017-07-18 17:13:00+03	7200.00
68A1B5	2017-07-13 11:11:00+03	6700.00
68A1E3	2017-07-28 13:58:00+03	46400.00
68A288	2017-07-11 07:19:00+03	149200.00
68A314	2017-07-09 12:25:00+03	7800.00
68A32F	2017-07-01 12:40:00+03	46300.00
68A358	2017-07-15 15:34:00+03	36200.00
68A364	2017-07-05 19:32:00+03	27500.00
68A39F	2017-08-10 06:29:00+03	84100.00
68A3AD	2017-08-02 14:30:00+03	6700.00
68A3B6	2017-07-11 10:31:00+03	95500.00
68A3D5	2017-07-16 02:54:00+03	88800.00
68A3ED	2017-07-17 21:35:00+03	44000.00
68A485	2017-07-27 14:49:00+03	25000.00
68A48E	2017-08-15 16:02:00+03	26200.00
68A528	2017-07-18 16:28:00+03	12200.00
68A52A	2017-07-14 03:48:00+03	13600.00
68A531	2017-07-26 12:39:00+03	113800.00
68A538	2017-07-17 13:12:00+03	156500.00
68A56E	2017-08-09 18:40:00+03	40000.00
68A575	2017-07-09 11:43:00+03	21800.00
68A5CA	2017-08-07 10:58:00+03	26000.00
68A64B	2017-08-03 10:56:00+03	54800.00
68A710	2017-07-21 06:05:00+03	89200.00
68A74D	2017-07-23 01:15:00+03	34000.00
68A759	2017-08-08 20:54:00+03	23600.00
68A761	2017-07-06 19:15:00+03	43900.00
68A7A4	2017-08-06 15:31:00+03	37000.00
68A80C	2017-07-06 10:15:00+03	61800.00
68A80E	2017-07-27 01:58:00+03	40600.00
68A838	2017-07-26 01:51:00+03	103800.00
68A869	2017-08-11 18:26:00+03	139100.00
68A8B0	2017-08-07 17:07:00+03	22000.00
68A8D1	2017-07-29 13:03:00+03	542200.00
68A974	2017-06-29 02:59:00+03	55800.00
68A9BB	2017-07-01 07:57:00+03	41600.00
68AA1B	2017-08-09 21:25:00+03	99200.00
68AA24	2017-08-14 12:15:00+03	14000.00
68AA34	2017-07-30 08:03:00+03	27900.00
68AA35	2017-07-19 14:20:00+03	40600.00
68AAE1	2017-08-09 01:00:00+03	46300.00
68AAF2	2017-07-28 11:00:00+03	23200.00
68AB4E	2017-07-30 21:35:00+03	44500.00
68AC44	2017-07-15 16:56:00+03	21800.00
68AC61	2017-07-08 02:55:00+03	8200.00
68AC68	2017-07-02 08:32:00+03	11600.00
68AC7F	2017-08-08 05:34:00+03	57500.00
68ACC5	2017-08-03 14:20:00+03	32400.00
68AD2C	2017-07-10 21:13:00+03	152900.00
68AD52	2017-07-19 08:40:00+03	20200.00
68AD61	2017-07-15 00:35:00+03	34200.00
68AD6E	2017-07-09 02:59:00+03	37900.00
68ADB2	2017-07-07 17:13:00+03	77200.00
68ADEC	2017-07-11 16:28:00+03	66600.00
68AE12	2017-08-10 10:29:00+03	12000.00
68AE58	2017-07-31 02:39:00+03	62800.00
68AE5D	2017-08-10 00:57:00+03	68400.00
68AE89	2017-07-16 12:17:00+03	87000.00
68AE98	2017-07-14 01:54:00+03	13800.00
68AEA1	2017-07-19 09:24:00+03	83600.00
68AEC8	2017-08-06 11:22:00+03	66700.00
68AF28	2017-07-06 20:17:00+03	28800.00
68AF2D	2017-07-10 01:35:00+03	109600.00
68AF7D	2017-08-01 18:27:00+03	111600.00
68AFBC	2017-07-09 07:04:00+03	80000.00
68B036	2017-07-13 03:19:00+03	66600.00
68B048	2017-07-24 04:00:00+03	39300.00
68B088	2017-08-08 10:19:00+03	121500.00
68B0E9	2017-07-13 16:11:00+03	168000.00
68B11D	2017-07-02 10:54:00+03	26000.00
68B14E	2017-08-10 07:19:00+03	30400.00
68B1DD	2017-07-16 07:58:00+03	36200.00
68B1E1	2017-08-10 22:32:00+03	61800.00
68B244	2017-08-08 23:22:00+03	30400.00
68B2B7	2017-08-06 00:22:00+03	13600.00
68B2E1	2017-08-14 12:06:00+03	36800.00
68B304	2017-08-11 17:52:00+03	40000.00
68B30D	2017-07-15 06:10:00+03	28000.00
68B3C5	2017-07-04 11:06:00+03	21400.00
68B401	2017-08-11 09:15:00+03	26000.00
68B43F	2017-07-20 11:49:00+03	38800.00
68B474	2017-08-04 02:13:00+03	56000.00
68B4C1	2017-08-15 13:20:00+03	24400.00
68B52F	2017-08-01 09:21:00+03	43600.00
68B566	2017-07-11 02:00:00+03	133800.00
68B5E8	2017-07-31 22:08:00+03	13400.00
68B60F	2017-08-03 00:10:00+03	46400.00
68B62F	2017-07-24 11:22:00+03	36900.00
68B6A4	2017-07-19 05:31:00+03	16400.00
68B766	2017-07-17 07:14:00+03	26400.00
68B7C6	2017-07-31 09:29:00+03	52900.00
68B80A	2017-08-15 03:29:00+03	11700.00
68B80F	2017-07-05 08:52:00+03	6700.00
68B832	2017-08-10 14:53:00+03	37100.00
68B86E	2017-07-24 00:33:00+03	55800.00
68B8BB	2017-08-12 05:05:00+03	37200.00
68B909	2017-08-02 19:27:00+03	6300.00
68B97D	2017-08-11 01:16:00+03	15000.00
68B981	2017-08-11 01:51:00+03	20000.00
68B9CB	2017-08-13 09:05:00+03	50800.00
68B9E3	2017-07-23 19:13:00+03	26200.00
68BA11	2017-07-23 08:47:00+03	6000.00
68BA42	2017-07-07 01:26:00+03	70600.00
68BAF7	2017-07-28 14:42:00+03	32200.00
68BC36	2017-08-10 15:50:00+03	80000.00
68BC42	2017-07-17 19:33:00+03	202100.00
68BCB9	2017-07-29 08:31:00+03	21200.00
68BD21	2017-07-12 10:32:00+03	56600.00
68BD28	2017-08-08 08:01:00+03	139000.00
68BD91	2017-07-05 00:34:00+03	13400.00
68BD9B	2017-07-25 13:18:00+03	16400.00
68BDD6	2017-07-13 16:01:00+03	95200.00
68BE0D	2017-08-13 05:00:00+03	28000.00
68BE51	2017-07-07 21:40:00+03	242100.00
68BE56	2017-07-25 05:45:00+03	46400.00
68BE86	2017-07-27 15:58:00+03	97800.00
68BF61	2017-07-25 14:38:00+03	76800.00
68BFCD	2017-07-02 15:35:00+03	187800.00
68C059	2017-06-30 10:22:00+03	48000.00
68C11F	2017-07-16 05:33:00+03	112000.00
68C178	2017-08-10 08:45:00+03	148200.00
68C198	2017-07-01 10:10:00+03	28000.00
68C1BE	2017-07-29 07:19:00+03	57500.00
68C202	2017-07-31 15:16:00+03	56100.00
68C249	2017-07-16 18:40:00+03	155600.00
68C294	2017-07-16 15:29:00+03	65900.00
68C299	2017-08-11 14:46:00+03	96400.00
68C2A6	2017-08-10 19:21:00+03	111600.00
68C2D4	2017-07-17 22:39:00+03	29400.00
68C2E3	2017-07-22 02:36:00+03	177200.00
68C338	2017-07-06 20:34:00+03	20200.00
68C351	2017-08-09 10:08:00+03	55800.00
68C388	2017-07-21 17:16:00+03	54000.00
68C3EE	2017-08-02 23:00:00+03	136800.00
68C405	2017-07-09 03:04:00+03	155100.00
68C4D3	2017-07-21 14:45:00+03	99700.00
68C4D7	2017-07-11 06:23:00+03	116800.00
68C4FD	2017-08-07 18:46:00+03	19600.00
68C50F	2017-07-28 16:35:00+03	12600.00
68C526	2017-07-05 08:44:00+03	114700.00
68C552	2017-07-16 14:18:00+03	6800.00
68C58D	2017-07-18 00:56:00+03	78500.00
68C5FF	2017-07-22 02:47:00+03	294800.00
68C611	2017-08-12 05:55:00+03	43300.00
68C671	2017-07-11 21:29:00+03	260300.00
68C72D	2017-07-14 08:50:00+03	66000.00
68C759	2017-07-20 00:06:00+03	75300.00
68C75E	2017-07-20 03:28:00+03	64100.00
68C761	2017-07-31 02:34:00+03	38000.00
68C777	2017-06-30 12:57:00+03	53300.00
68C791	2017-07-26 16:40:00+03	271100.00
68C7B2	2017-07-24 20:46:00+03	56000.00
68C7E4	2017-08-13 16:48:00+03	52000.00
68C7E7	2017-08-14 10:09:00+03	187800.00
68C7EC	2017-07-12 15:11:00+03	38800.00
68C81E	2017-08-05 12:06:00+03	124200.00
68C82D	2017-08-08 00:15:00+03	28800.00
68C83B	2017-06-28 05:20:00+03	70600.00
68C889	2017-07-31 07:34:00+03	67600.00
68C91A	2017-07-22 17:49:00+03	42700.00
68C94C	2017-07-12 20:35:00+03	29300.00
68CA89	2017-07-18 05:40:00+03	136200.00
68CA90	2017-08-08 04:04:00+03	57400.00
68CBF7	2017-08-10 15:13:00+03	74200.00
68CC08	2017-07-24 20:22:00+03	38800.00
68CCBF	2017-07-05 16:29:00+03	92600.00
68CD2B	2017-07-12 01:54:00+03	67000.00
68CD44	2017-07-01 07:38:00+03	26200.00
68CD61	2017-08-07 11:01:00+03	46000.00
68CD7F	2017-08-08 22:28:00+03	24200.00
68CDA2	2017-07-21 01:09:00+03	73600.00
68CDB9	2017-07-23 10:52:00+03	70800.00
68CDBE	2017-08-09 04:11:00+03	64500.00
68CE70	2017-07-20 22:46:00+03	88500.00
68CE83	2017-08-02 15:16:00+03	56600.00
68CE8B	2017-08-01 13:33:00+03	15000.00
68CE91	2017-08-10 00:11:00+03	44800.00
68CEBC	2017-07-12 13:01:00+03	32900.00
68CF05	2017-07-23 11:16:00+03	27400.00
68CF95	2017-07-20 07:31:00+03	24600.00
68CFBE	2017-07-16 14:44:00+03	55800.00
68CFC3	2017-08-10 13:51:00+03	89800.00
68D01A	2017-07-13 10:39:00+03	44800.00
68D033	2017-07-16 02:54:00+03	36800.00
68D066	2017-08-10 16:39:00+03	13700.00
68D07A	2017-07-18 18:44:00+03	15900.00
68D07D	2017-08-04 20:25:00+03	23200.00
68D0A1	2017-07-22 12:45:00+03	56000.00
68D129	2017-07-09 09:07:00+03	257500.00
68D1D4	2017-08-14 17:38:00+03	57600.00
68D1EF	2017-07-26 01:14:00+03	105100.00
68D221	2017-08-09 15:02:00+03	70700.00
68D24B	2017-08-02 17:13:00+03	23200.00
68D26D	2017-08-04 12:21:00+03	78900.00
68D2AE	2017-08-03 19:39:00+03	103200.00
68D3C2	2017-07-23 06:46:00+03	104600.00
68D3C8	2017-07-18 18:14:00+03	37900.00
68D3DA	2017-07-24 13:47:00+03	121200.00
68D43A	2017-08-10 10:34:00+03	6000.00
68D45B	2017-07-18 22:51:00+03	29400.00
68D4A1	2017-07-14 21:04:00+03	35200.00
68D4DA	2017-08-02 13:55:00+03	66200.00
68D4E2	2017-06-30 10:26:00+03	81500.00
68D4EF	2017-07-26 16:07:00+03	11800.00
68D510	2017-07-19 11:17:00+03	138300.00
68D56B	2017-07-01 11:14:00+03	18000.00
68D5CA	2017-08-01 17:04:00+03	48100.00
68D627	2017-07-04 01:07:00+03	28800.00
68D67F	2017-07-04 21:04:00+03	87400.00
68D770	2017-08-07 22:34:00+03	43400.00
68D78A	2017-07-29 03:48:00+03	7200.00
68D7EA	2017-07-31 16:01:00+03	68800.00
68D820	2017-08-05 04:10:00+03	64900.00
68D835	2017-07-27 21:17:00+03	46300.00
68D885	2017-07-23 00:05:00+03	15100.00
68D88B	2017-07-26 03:21:00+03	203100.00
68D899	2017-08-06 18:47:00+03	30200.00
68D8AF	2017-07-31 22:29:00+03	68800.00
68D8C0	2017-08-10 08:32:00+03	258400.00
68D8C5	2017-08-09 15:55:00+03	32200.00
68D92C	2017-07-16 21:45:00+03	32700.00
68D937	2017-08-08 21:17:00+03	80100.00
68D972	2017-08-13 07:43:00+03	13600.00
68D975	2017-08-07 03:40:00+03	73300.00
68D9ED	2017-08-03 02:48:00+03	54100.00
68DA00	2017-07-25 03:54:00+03	6000.00
68DA0D	2017-08-15 14:33:00+03	38400.00
68DA3F	2017-07-21 10:55:00+03	26000.00
68DA80	2017-07-24 02:59:00+03	110500.00
68DADE	2017-07-18 19:39:00+03	246000.00
68DAF7	2017-08-12 06:07:00+03	136200.00
68DB01	2017-07-18 08:05:00+03	27800.00
68DB06	2017-08-04 07:44:00+03	75800.00
68DB23	2017-07-12 23:43:00+03	67600.00
68DB9A	2017-07-08 10:23:00+03	56000.00
68DBA6	2017-07-06 18:11:00+03	271100.00
68DBAF	2017-07-07 23:23:00+03	24400.00
68DBDC	2017-08-01 02:50:00+03	35200.00
68DBF2	2017-07-21 04:08:00+03	129200.00
68DC6A	2017-08-14 18:30:00+03	25100.00
68DCE8	2017-07-24 21:07:00+03	64700.00
68DD66	2017-07-02 21:52:00+03	28800.00
68DD89	2017-08-01 09:44:00+03	28800.00
68DE4F	2017-08-11 00:17:00+03	98300.00
68DE94	2017-08-09 13:03:00+03	28800.00
68DE99	2017-07-17 05:51:00+03	51600.00
68DEE2	2017-07-25 12:58:00+03	37200.00
68DEE4	2017-07-14 08:40:00+03	50600.00
68DF6B	2017-08-01 19:45:00+03	292300.00
68DFFD	2017-08-06 11:18:00+03	38400.00
68E09D	2017-07-14 07:05:00+03	114200.00
68E0A3	2017-08-02 04:19:00+03	84500.00
68E1CE	2017-08-10 05:40:00+03	85000.00
68E253	2017-07-18 00:08:00+03	15800.00
68E305	2017-07-30 05:43:00+03	13400.00
68E34D	2017-07-09 22:53:00+03	52000.00
68E3CE	2017-08-08 20:07:00+03	13400.00
68E408	2017-07-25 01:21:00+03	202100.00
68E449	2017-07-27 16:03:00+03	23200.00
68E564	2017-07-29 20:25:00+03	127100.00
68E56B	2017-07-18 01:39:00+03	28800.00
68E593	2017-08-06 20:51:00+03	62600.00
68E5B7	2017-08-13 21:13:00+03	81700.00
68E645	2017-07-01 03:27:00+03	193500.00
68E646	2017-07-22 17:30:00+03	19600.00
68E6CF	2017-07-03 04:45:00+03	93000.00
68E6E6	2017-07-25 20:46:00+03	23400.00
68E70A	2017-08-09 08:18:00+03	139000.00
68E73E	2017-07-26 15:32:00+03	57800.00
68E763	2017-07-04 07:27:00+03	369000.00
68E7C9	2017-07-30 13:51:00+03	55800.00
68E7CF	2017-06-30 23:59:00+03	8200.00
68E7EE	2017-08-14 09:08:00+03	37700.00
68E7F5	2017-07-20 16:46:00+03	72700.00
68E837	2017-07-21 07:53:00+03	153300.00
68E88F	2017-08-02 15:02:00+03	26000.00
68E8A8	2017-07-21 20:39:00+03	41800.00
68EAB1	2017-07-31 01:40:00+03	17800.00
68EADC	2017-08-04 22:13:00+03	67900.00
68EAE9	2017-07-11 16:33:00+03	51300.00
68EAFE	2017-07-05 14:38:00+03	152700.00
68EAFF	2017-07-07 22:41:00+03	219500.00
68EB1A	2017-08-11 15:32:00+03	56000.00
68EB35	2017-08-01 06:11:00+03	468000.00
68EB51	2017-07-07 00:10:00+03	23600.00
68EB69	2017-08-11 06:58:00+03	65500.00
68EB7F	2017-07-24 22:51:00+03	28800.00
68EBF8	2017-08-14 17:34:00+03	6000.00
68EC1A	2017-08-02 04:01:00+03	115600.00
68EC25	2017-07-07 22:55:00+03	82000.00
68EC7A	2017-08-12 17:26:00+03	73600.00
68EC98	2017-07-22 17:26:00+03	11600.00
68ECEF	2017-07-21 23:52:00+03	92000.00
68ED40	2017-07-31 07:19:00+03	32700.00
68ED6D	2017-08-13 04:12:00+03	40700.00
68EDB8	2017-08-04 02:02:00+03	43200.00
68EDC1	2017-08-02 22:12:00+03	65500.00
68EE45	2017-07-23 06:50:00+03	200400.00
68EE5C	2017-07-07 22:58:00+03	8000.00
68EE5D	2017-07-17 08:42:00+03	6800.00
68EEBC	2017-07-23 13:24:00+03	92900.00
68EEDF	2017-08-12 14:05:00+03	55800.00
68EEE1	2017-07-22 00:31:00+03	12000.00
68EF1C	2017-07-07 01:00:00+03	27200.00
68EF36	2017-07-26 17:50:00+03	34000.00
68EF61	2017-07-15 10:56:00+03	44800.00
68EFB9	2017-07-24 06:19:00+03	79600.00
68EFD5	2017-07-25 19:22:00+03	118000.00
68EFF7	2017-08-10 04:33:00+03	38600.00
68F017	2017-07-15 21:49:00+03	118000.00
68F06A	2017-08-03 21:07:00+03	58900.00
68F093	2017-07-07 18:28:00+03	56000.00
68F0DD	2017-07-15 10:18:00+03	65500.00
68F0F6	2017-07-28 03:59:00+03	56900.00
68F103	2017-07-28 01:36:00+03	142300.00
68F12F	2017-08-14 15:54:00+03	11700.00
68F1FE	2017-07-17 19:32:00+03	18600.00
68F222	2017-08-06 14:00:00+03	85000.00
68F2E0	2017-07-21 04:40:00+03	67600.00
68F33A	2017-07-18 16:31:00+03	133200.00
68F3A8	2017-08-05 01:48:00+03	56000.00
68F3C2	2017-07-03 23:50:00+03	46000.00
68F3C6	2017-07-27 14:40:00+03	35800.00
68F424	2017-07-12 11:07:00+03	85700.00
68F48A	2017-07-23 13:05:00+03	41800.00
68F48B	2017-07-31 02:08:00+03	26000.00
68F527	2017-08-10 15:31:00+03	59200.00
68F563	2017-08-11 15:09:00+03	38800.00
68F592	2017-07-13 20:49:00+03	26300.00
68F5A8	2017-08-15 14:35:00+03	37900.00
68F5FC	2017-07-06 06:52:00+03	73600.00
68F60B	2017-07-04 20:52:00+03	24400.00
68F6DE	2017-07-21 12:54:00+03	101200.00
68F71B	2017-08-05 06:05:00+03	49700.00
68F742	2017-07-23 01:21:00+03	26200.00
68F783	2017-07-24 07:35:00+03	31400.00
68F7DD	2017-07-05 12:34:00+03	119700.00
68F7F0	2017-08-12 01:17:00+03	119500.00
68F869	2017-07-26 20:47:00+03	154500.00
68F910	2017-07-30 14:12:00+03	40800.00
68F964	2017-07-12 19:32:00+03	40800.00
68F99A	2017-08-10 18:47:00+03	34000.00
68F9DA	2017-08-06 16:52:00+03	54800.00
68FA07	2017-07-09 07:12:00+03	22000.00
68FA20	2017-07-20 19:33:00+03	67600.00
68FA72	2017-07-18 11:27:00+03	295200.00
68FAAF	2017-08-02 23:46:00+03	32200.00
68FAC1	2017-07-24 21:02:00+03	86800.00
68FB00	2017-07-08 11:38:00+03	136200.00
68FBC9	2017-08-10 10:44:00+03	63900.00
68FBE0	2017-07-28 02:20:00+03	40800.00
68FD77	2017-08-12 08:35:00+03	177200.00
68FD85	2017-07-29 12:22:00+03	122300.00
68FD87	2017-07-02 03:42:00+03	40800.00
68FD9F	2017-08-02 18:03:00+03	31000.00
68FDF2	2017-07-05 11:39:00+03	54400.00
68FDF4	2017-07-28 05:21:00+03	62700.00
68FE1D	2017-07-25 19:39:00+03	48800.00
68FEB2	2017-07-06 19:03:00+03	37200.00
68FEC0	2017-08-08 05:48:00+03	16400.00
68FEE4	2017-07-04 07:37:00+03	75600.00
68FF30	2017-07-05 13:24:00+03	8200.00
68FF9C	2017-07-16 06:04:00+03	45200.00
690055	2017-07-29 15:54:00+03	141600.00
690062	2017-07-30 12:40:00+03	23200.00
69006B	2017-07-27 13:19:00+03	23600.00
690199	2017-07-23 21:16:00+03	62000.00
6901CD	2017-07-21 14:04:00+03	44600.00
6901D5	2017-07-30 16:34:00+03	71900.00
6901E7	2017-07-20 16:36:00+03	298600.00
69020B	2017-07-17 03:31:00+03	72400.00
69022E	2017-07-20 03:12:00+03	12400.00
6902DE	2017-07-29 09:19:00+03	100000.00
6902FE	2017-07-26 23:02:00+03	116000.00
690362	2017-08-13 18:30:00+03	161900.00
6903C4	2017-07-09 05:13:00+03	24400.00
690402	2017-07-19 12:59:00+03	248400.00
690403	2017-08-11 23:50:00+03	32800.00
690411	2017-07-06 00:00:00+03	47400.00
690456	2017-08-08 18:02:00+03	207200.00
690474	2017-08-01 09:55:00+03	17800.00
6904E3	2017-08-06 13:19:00+03	10800.00
690568	2017-08-12 22:59:00+03	246000.00
690570	2017-07-12 07:47:00+03	28000.00
6905B0	2017-07-20 06:49:00+03	27300.00
6905B1	2017-07-06 19:48:00+03	6600.00
6905CB	2017-08-13 23:14:00+03	105600.00
6905D8	2017-07-09 02:35:00+03	59800.00
6905F4	2017-07-08 04:44:00+03	257600.00
690632	2017-08-09 22:33:00+03	12600.00
69064B	2017-08-01 08:07:00+03	143900.00
690704	2017-07-28 19:31:00+03	135400.00
690714	2017-08-13 20:58:00+03	96800.00
690717	2017-08-06 13:48:00+03	39500.00
690758	2017-07-11 13:47:00+03	6000.00
6907FC	2017-08-09 22:12:00+03	25600.00
690801	2017-07-10 20:04:00+03	39400.00
69087B	2017-08-09 23:13:00+03	46200.00
690897	2017-08-02 11:59:00+03	13300.00
6908A1	2017-06-30 21:40:00+03	124000.00
690903	2017-07-03 10:43:00+03	41600.00
69094E	2017-07-21 14:22:00+03	19800.00
690958	2017-07-13 11:40:00+03	46400.00
6909D8	2017-07-13 13:27:00+03	23400.00
6909F6	2017-07-10 08:48:00+03	22000.00
690A24	2017-08-13 22:05:00+03	31400.00
690A2B	2017-07-09 21:41:00+03	43200.00
690A35	2017-08-01 17:12:00+03	116000.00
690A4C	2017-08-11 13:09:00+03	67400.00
690A56	2017-07-16 08:00:00+03	22600.00
690A57	2017-07-18 21:03:00+03	27300.00
690A81	2017-07-20 12:09:00+03	305500.00
690AA7	2017-06-28 21:24:00+03	67600.00
690AC2	2017-08-06 10:28:00+03	112000.00
690ADD	2017-07-03 14:55:00+03	46000.00
690B66	2017-08-10 12:37:00+03	348100.00
690B81	2017-08-13 12:17:00+03	66100.00
690BA9	2017-07-24 05:34:00+03	68400.00
690BB0	2017-08-14 02:01:00+03	119600.00
690BF5	2017-08-06 21:39:00+03	56000.00
690C96	2017-07-18 19:50:00+03	38800.00
690D49	2017-07-12 21:47:00+03	96200.00
690D85	2017-07-23 05:48:00+03	169300.00
690DAC	2017-07-16 04:23:00+03	29000.00
690DFB	2017-08-02 08:27:00+03	25600.00
690E0F	2017-07-18 07:49:00+03	85000.00
690E25	2017-08-07 18:47:00+03	41000.00
690E6C	2017-07-10 08:25:00+03	185500.00
690E75	2017-06-28 23:35:00+03	31600.00
690E87	2017-07-07 06:30:00+03	6800.00
690F03	2017-07-01 02:41:00+03	187600.00
690F2E	2017-06-30 18:25:00+03	170500.00
690F36	2017-07-31 16:04:00+03	73200.00
69100A	2017-07-24 18:05:00+03	73900.00
691118	2017-07-25 05:53:00+03	21800.00
69115A	2017-07-04 08:17:00+03	44000.00
691185	2017-08-05 12:34:00+03	26800.00
6911A2	2017-08-01 11:24:00+03	55800.00
6911D7	2017-07-27 05:22:00+03	13400.00
6911DB	2017-08-15 04:58:00+03	135400.00
691200	2017-07-12 09:16:00+03	27600.00
691209	2017-07-02 06:50:00+03	28800.00
691273	2017-07-22 20:32:00+03	67700.00
69127F	2017-06-30 14:54:00+03	172600.00
691352	2017-07-23 17:58:00+03	40300.00
691369	2017-07-07 13:01:00+03	26800.00
69136C	2017-08-01 06:24:00+03	103800.00
691376	2017-08-10 01:26:00+03	69100.00
691398	2017-07-31 16:16:00+03	105600.00
6913A7	2017-07-26 05:19:00+03	36400.00
691403	2017-07-06 07:31:00+03	141800.00
691446	2017-08-07 19:40:00+03	16400.00
691451	2017-07-23 14:54:00+03	174900.00
69146E	2017-07-13 12:54:00+03	46300.00
69148C	2017-07-21 11:01:00+03	224000.00
69148D	2017-08-01 21:54:00+03	174400.00
6914B0	2017-07-11 06:19:00+03	32800.00
6914C9	2017-07-20 16:00:00+03	22100.00
69150C	2017-07-15 19:18:00+03	56000.00
691574	2017-07-09 13:18:00+03	139600.00
6915A5	2017-07-22 07:40:00+03	198400.00
691603	2017-08-06 00:15:00+03	46400.00
691629	2017-07-13 06:35:00+03	58000.00
691658	2017-07-14 03:14:00+03	12600.00
6916AA	2017-08-02 14:28:00+03	59200.00
6916C1	2017-08-03 00:53:00+03	56900.00
6916CE	2017-07-01 14:29:00+03	39400.00
6916D1	2017-08-07 16:12:00+03	38200.00
6916D7	2017-07-06 18:34:00+03	84500.00
691745	2017-07-03 06:38:00+03	117900.00
691764	2017-07-05 04:22:00+03	92800.00
6917BD	2017-08-05 17:24:00+03	28800.00
69181A	2017-07-20 05:45:00+03	130000.00
69188D	2017-08-08 04:38:00+03	73200.00
691904	2017-07-21 07:00:00+03	337400.00
69190E	2017-08-10 09:21:00+03	146400.00
691918	2017-07-26 21:01:00+03	202100.00
69194D	2017-08-11 19:48:00+03	222800.00
691969	2017-08-10 10:03:00+03	406700.00
69197E	2017-07-05 00:59:00+03	56000.00
691980	2017-08-12 20:45:00+03	25000.00
6919AA	2017-07-14 07:32:00+03	123000.00
6919EA	2017-07-14 00:24:00+03	57500.00
6919F1	2017-07-30 23:46:00+03	112600.00
6919F2	2017-07-27 16:54:00+03	23100.00
6919FE	2017-07-10 05:07:00+03	31900.00
691A19	2017-08-12 15:02:00+03	44500.00
691A1B	2017-07-31 01:36:00+03	83000.00
691A40	2017-07-12 16:30:00+03	74400.00
691A49	2017-07-03 18:46:00+03	344700.00
691A51	2017-07-30 08:01:00+03	39500.00
691ACE	2017-08-13 10:13:00+03	229300.00
691B22	2017-08-13 12:54:00+03	21400.00
691B4B	2017-07-13 11:40:00+03	119700.00
691B6F	2017-07-26 04:24:00+03	28000.00
691BA6	2017-07-12 10:17:00+03	68800.00
691BCF	2017-07-22 04:31:00+03	21800.00
691BE7	2017-07-08 01:02:00+03	40000.00
691C0D	2017-07-13 22:19:00+03	114400.00
691C48	2017-07-15 08:56:00+03	12600.00
691C66	2017-07-27 09:40:00+03	112600.00
691C96	2017-08-08 09:44:00+03	8200.00
691CAD	2017-08-05 09:36:00+03	23200.00
691CC7	2017-07-30 08:30:00+03	25600.00
691CD0	2017-08-08 06:11:00+03	55800.00
691CD3	2017-08-03 02:22:00+03	8400.00
691CD6	2017-08-15 07:52:00+03	196800.00
691CDD	2017-07-26 13:45:00+03	94000.00
691DC8	2017-08-13 05:58:00+03	54400.00
691E35	2017-08-13 18:30:00+03	369000.00
691EB8	2017-08-10 10:06:00+03	226800.00
691F69	2017-07-10 07:07:00+03	123000.00
691F99	2017-08-04 19:34:00+03	40000.00
691F9F	2017-07-14 20:48:00+03	23200.00
691FDE	2017-07-05 18:27:00+03	26000.00
692007	2017-07-07 07:18:00+03	67600.00
692023	2017-07-31 03:20:00+03	76600.00
6920B9	2017-07-13 05:57:00+03	99300.00
6920D5	2017-07-22 16:41:00+03	51600.00
6920DC	2017-07-12 13:13:00+03	37900.00
69211A	2017-08-06 12:46:00+03	50400.00
692190	2017-07-14 14:00:00+03	129400.00
6921A6	2017-08-13 03:26:00+03	57500.00
692205	2017-07-30 10:19:00+03	136100.00
692275	2017-08-03 22:34:00+03	237600.00
6922F0	2017-08-06 14:12:00+03	13000.00
692331	2017-07-02 18:32:00+03	28000.00
692385	2017-07-19 19:30:00+03	56600.00
69243C	2017-07-24 07:52:00+03	57400.00
692499	2017-08-11 14:50:00+03	24800.00
6924AD	2017-07-19 23:25:00+03	27900.00
6924D1	2017-08-15 05:48:00+03	29600.00
692535	2017-08-13 04:57:00+03	39200.00
69257D	2017-07-03 23:04:00+03	23200.00
69259D	2017-07-10 13:18:00+03	61400.00
69265F	2017-07-06 18:55:00+03	131100.00
692691	2017-07-13 11:27:00+03	83200.00
692698	2017-07-20 01:01:00+03	42800.00
6926DE	2017-08-14 03:22:00+03	28700.00
69276B	2017-07-26 04:19:00+03	14000.00
692799	2017-08-02 07:58:00+03	177200.00
6927F7	2017-07-11 03:29:00+03	14000.00
692815	2017-08-15 08:29:00+03	24400.00
692840	2017-07-09 03:46:00+03	47400.00
692864	2017-08-07 01:41:00+03	398500.00
6928E2	2017-07-14 10:41:00+03	70400.00
6928E8	2017-07-16 23:42:00+03	55800.00
692900	2017-07-18 23:21:00+03	67900.00
692903	2017-08-01 05:02:00+03	44600.00
6929A5	2017-07-30 12:02:00+03	21400.00
6929DE	2017-08-05 20:08:00+03	23200.00
692A05	2017-07-05 19:31:00+03	52600.00
692A5C	2017-07-21 10:38:00+03	92800.00
692A6D	2017-08-13 02:41:00+03	44500.00
692A7A	2017-07-10 21:06:00+03	90400.00
692B07	2017-07-20 23:00:00+03	14000.00
692B4A	2017-08-07 08:08:00+03	103200.00
692B53	2017-07-03 11:10:00+03	24000.00
692B7F	2017-07-02 13:51:00+03	114200.00
692C93	2017-07-02 17:49:00+03	13600.00
692D4E	2017-07-26 22:08:00+03	86000.00
692D8D	2017-08-01 06:38:00+03	37600.00
692DCD	2017-07-09 13:30:00+03	93400.00
692E97	2017-07-09 19:29:00+03	25600.00
692EC1	2017-07-11 20:43:00+03	135600.00
692F18	2017-07-12 13:21:00+03	86500.00
692F2C	2017-07-09 00:21:00+03	114200.00
692F43	2017-07-28 01:29:00+03	20000.00
692F6A	2017-07-22 13:41:00+03	259000.00
692FE3	2017-07-21 04:57:00+03	257500.00
693004	2017-07-18 18:14:00+03	28000.00
693041	2017-08-13 08:20:00+03	72600.00
69309E	2017-07-03 06:52:00+03	71000.00
693183	2017-07-18 21:19:00+03	57500.00
6931C4	2017-07-24 04:35:00+03	56600.00
6931DB	2017-08-08 03:08:00+03	372500.00
693215	2017-07-21 21:48:00+03	13100.00
693247	2017-06-29 08:52:00+03	112000.00
6932DF	2017-07-05 11:27:00+03	59400.00
693325	2017-08-12 09:27:00+03	86800.00
69336A	2017-07-08 20:10:00+03	56000.00
69336B	2017-07-19 22:31:00+03	248400.00
693373	2017-07-21 22:25:00+03	40100.00
693376	2017-07-30 17:31:00+03	78300.00
6933D3	2017-07-18 16:07:00+03	43200.00
6933E1	2017-08-09 10:19:00+03	99200.00
6933F2	2017-08-05 02:38:00+03	131600.00
6933FD	2017-08-15 06:13:00+03	74900.00
693417	2017-07-02 02:06:00+03	31000.00
693439	2017-07-28 10:28:00+03	75300.00
69353A	2017-07-14 02:13:00+03	40400.00
693540	2017-07-02 17:45:00+03	266200.00
693585	2017-07-06 06:39:00+03	133100.00
693672	2017-08-10 06:11:00+03	298800.00
6936EC	2017-07-11 20:36:00+03	33600.00
693705	2017-07-26 02:40:00+03	107600.00
693725	2017-07-16 15:37:00+03	185500.00
693789	2017-07-29 05:58:00+03	58200.00
6937BA	2017-08-07 10:58:00+03	131600.00
693816	2017-08-09 18:25:00+03	19800.00
693885	2017-07-28 18:46:00+03	73300.00
693888	2017-08-02 17:01:00+03	65200.00
693916	2017-08-09 12:17:00+03	28000.00
69397D	2017-07-12 11:27:00+03	25400.00
693982	2017-08-10 15:12:00+03	85000.00
6939B2	2017-07-17 01:11:00+03	46400.00
6939B7	2017-08-11 19:17:00+03	66700.00
693A1C	2017-07-12 18:40:00+03	49200.00
693A5C	2017-08-11 23:55:00+03	125400.00
693A64	2017-07-30 19:49:00+03	29600.00
693A9D	2017-08-06 05:40:00+03	20200.00
693AAF	2017-08-14 07:23:00+03	64400.00
693B2E	2017-07-23 19:26:00+03	196800.00
693B46	2017-07-18 20:38:00+03	28000.00
693B8F	2017-08-15 02:58:00+03	24000.00
693B95	2017-07-01 06:42:00+03	46000.00
693BA5	2017-07-25 06:21:00+03	68800.00
693BCA	2017-08-10 01:34:00+03	45100.00
693C66	2017-08-02 03:39:00+03	56000.00
693CDB	2017-07-31 11:58:00+03	75600.00
693CDD	2017-07-15 15:00:00+03	182800.00
693D6E	2017-07-10 05:19:00+03	102100.00
693D75	2017-07-23 21:23:00+03	92600.00
693DB9	2017-08-15 16:31:00+03	18400.00
693DF8	2017-08-10 04:21:00+03	26000.00
693E49	2017-06-30 05:44:00+03	28000.00
693E60	2017-07-31 02:03:00+03	47400.00
693E6D	2017-07-07 12:37:00+03	31400.00
693E8C	2017-07-28 09:18:00+03	132800.00
693E91	2017-07-17 23:46:00+03	65900.00
693EA9	2017-07-11 05:32:00+03	109600.00
693F01	2017-07-06 18:46:00+03	128400.00
693F07	2017-08-06 03:41:00+03	52600.00
693F0D	2017-07-11 05:18:00+03	48700.00
693F28	2017-07-04 00:34:00+03	115600.00
693FB6	2017-08-14 19:20:00+03	39500.00
69401A	2017-07-05 15:53:00+03	115800.00
694060	2017-07-11 03:18:00+03	27900.00
694161	2017-07-21 00:43:00+03	123000.00
694190	2017-08-13 15:53:00+03	99700.00
6941E0	2017-07-20 12:16:00+03	58000.00
694211	2017-07-09 19:09:00+03	27200.00
694235	2017-07-08 18:10:00+03	202100.00
694289	2017-07-02 01:05:00+03	27800.00
6942B6	2017-08-03 06:06:00+03	18600.00
6942BA	2017-06-29 17:38:00+03	47100.00
69430A	2017-08-09 16:44:00+03	47000.00
69431E	2017-07-29 07:53:00+03	61800.00
69435A	2017-07-18 11:42:00+03	192900.00
69435D	2017-08-02 06:26:00+03	199800.00
69438E	2017-07-14 18:14:00+03	21200.00
694398	2017-08-03 16:29:00+03	56100.00
694439	2017-07-19 20:42:00+03	27200.00
694560	2017-07-08 12:01:00+03	40000.00
69456E	2017-08-10 14:50:00+03	69000.00
694575	2017-07-17 23:26:00+03	38600.00
6945EC	2017-07-16 11:29:00+03	56000.00
6945F3	2017-08-10 16:28:00+03	260300.00
6945FB	2017-08-14 23:50:00+03	31600.00
694705	2017-07-27 00:30:00+03	36200.00
69470C	2017-08-05 17:50:00+03	50800.00
694714	2017-07-28 00:23:00+03	50100.00
6947A5	2017-07-31 10:06:00+03	515000.00
6947AC	2017-07-30 05:08:00+03	92400.00
6947D6	2017-08-14 07:25:00+03	13400.00
69480A	2017-07-31 07:31:00+03	114800.00
694838	2017-06-30 06:31:00+03	12000.00
694839	2017-07-07 21:24:00+03	16400.00
694851	2017-07-12 10:38:00+03	70800.00
69490D	2017-08-13 07:56:00+03	177200.00
694955	2017-08-05 10:29:00+03	46200.00
69495D	2017-08-08 01:31:00+03	37900.00
694968	2017-08-11 00:42:00+03	101800.00
6949C0	2017-07-23 00:18:00+03	114700.00
694A16	2017-08-06 08:16:00+03	101200.00
694A7A	2017-08-02 00:14:00+03	36200.00
694AA2	2017-08-05 13:23:00+03	55800.00
694AB6	2017-08-06 14:23:00+03	26000.00
694B0F	2017-07-07 13:30:00+03	85000.00
694B32	2017-07-07 13:04:00+03	13000.00
694BDB	2017-08-11 03:46:00+03	39800.00
694C0E	2017-07-13 01:48:00+03	81600.00
694C47	2017-08-15 17:28:00+03	97600.00
694C4E	2017-07-15 15:55:00+03	24400.00
694C5A	2017-07-25 21:28:00+03	14000.00
694C69	2017-08-07 16:29:00+03	133100.00
694C7C	2017-08-12 11:28:00+03	56100.00
694CB0	2017-07-11 13:06:00+03	14000.00
694CE6	2017-07-14 19:22:00+03	16800.00
694D99	2017-07-21 16:54:00+03	140800.00
694DF5	2017-08-12 23:43:00+03	80300.00
694E61	2017-08-09 04:05:00+03	111600.00
694F33	2017-06-30 07:17:00+03	23500.00
694F4D	2017-08-04 03:18:00+03	46300.00
694F89	2017-07-13 09:42:00+03	31600.00
694FCC	2017-07-09 05:13:00+03	23400.00
6950F6	2017-07-17 17:34:00+03	58000.00
6951A9	2017-08-14 12:41:00+03	13400.00
6951EF	2017-08-15 14:28:00+03	84000.00
69528E	2017-07-23 20:17:00+03	25600.00
695299	2017-08-10 22:40:00+03	131600.00
695349	2017-08-09 11:59:00+03	112000.00
695353	2017-08-08 18:41:00+03	86300.00
695370	2017-07-15 06:11:00+03	30400.00
6953A5	2017-08-14 15:48:00+03	24000.00
6953E7	2017-07-13 04:42:00+03	68800.00
69543A	2017-08-02 03:07:00+03	52400.00
6954A4	2017-07-14 05:51:00+03	12000.00
695543	2017-07-13 00:43:00+03	11300.00
69558C	2017-07-05 10:43:00+03	57600.00
695591	2017-08-10 00:41:00+03	170700.00
69559D	2017-06-28 01:57:00+03	40600.00
6955AB	2017-07-28 11:50:00+03	20100.00
6955F3	2017-07-14 08:16:00+03	98600.00
695611	2017-07-02 20:17:00+03	56000.00
69563C	2017-07-19 06:48:00+03	164700.00
69569E	2017-07-29 14:41:00+03	29400.00
6956CC	2017-08-11 07:35:00+03	23200.00
6956ED	2017-07-13 06:58:00+03	114800.00
6956F5	2017-07-12 20:57:00+03	116000.00
695711	2017-07-21 02:03:00+03	317300.00
695717	2017-07-24 14:05:00+03	52400.00
69571F	2017-08-02 16:59:00+03	38600.00
6957BC	2017-07-27 07:30:00+03	56100.00
6957DD	2017-07-12 08:24:00+03	64800.00
695815	2017-08-06 11:37:00+03	36200.00
69589F	2017-07-25 04:59:00+03	26000.00
6958D1	2017-07-22 15:21:00+03	76400.00
6958F2	2017-07-11 11:35:00+03	73200.00
6958FB	2017-07-27 03:52:00+03	46000.00
69590C	2017-08-09 10:16:00+03	111600.00
695958	2017-08-13 07:10:00+03	39000.00
6959E4	2017-07-11 03:22:00+03	21800.00
695A27	2017-07-17 15:08:00+03	53600.00
695A3D	2017-08-04 07:32:00+03	143100.00
695A54	2017-07-06 13:39:00+03	94000.00
695A6D	2017-08-09 12:21:00+03	111700.00
695AC3	2017-07-16 17:38:00+03	62700.00
695AC7	2017-07-09 14:38:00+03	32700.00
695B07	2017-08-15 07:05:00+03	113300.00
695B57	2017-08-03 05:08:00+03	41600.00
695B6F	2017-08-14 19:34:00+03	59800.00
695BB4	2017-07-02 05:39:00+03	190700.00
695BB6	2017-07-10 16:12:00+03	78800.00
695C71	2017-07-23 21:46:00+03	58800.00
695CAE	2017-08-11 14:34:00+03	109600.00
695DF1	2017-07-06 07:02:00+03	202300.00
695E59	2017-07-19 04:23:00+03	59200.00
695E7F	2017-06-27 06:12:00+03	123600.00
695E89	2017-07-07 19:32:00+03	27900.00
695F29	2017-07-15 04:21:00+03	246000.00
695F2E	2017-07-02 16:53:00+03	55000.00
695F40	2017-07-26 07:05:00+03	62600.00
695F7A	2017-07-10 05:09:00+03	26000.00
695FE2	2017-07-19 13:30:00+03	29200.00
696068	2017-07-18 13:56:00+03	46300.00
6960B4	2017-07-01 17:02:00+03	34000.00
6960D2	2017-08-01 08:18:00+03	68100.00
69611E	2017-07-18 12:29:00+03	79600.00
696128	2017-08-02 10:00:00+03	147000.00
69614E	2017-08-13 06:26:00+03	6800.00
69615E	2017-08-10 16:03:00+03	60600.00
696173	2017-07-19 14:56:00+03	22200.00
696176	2017-07-29 14:10:00+03	18600.00
6961A9	2017-07-08 01:51:00+03	21600.00
69623C	2017-07-04 01:08:00+03	56600.00
69633F	2017-08-12 05:39:00+03	26600.00
69635D	2017-07-21 21:24:00+03	68800.00
696362	2017-08-04 18:12:00+03	189800.00
69639E	2017-07-25 17:26:00+03	56900.00
6963E9	2017-06-27 19:50:00+03	160200.00
6963FF	2017-07-12 00:12:00+03	47000.00
69640E	2017-07-07 21:27:00+03	294600.00
6964F0	2017-07-28 07:47:00+03	57700.00
69650A	2017-08-04 19:48:00+03	47200.00
696550	2017-07-23 19:11:00+03	12000.00
696563	2017-07-16 09:47:00+03	55600.00
6965BC	2017-08-11 18:21:00+03	37900.00
6965E0	2017-07-07 05:21:00+03	123000.00
6965F1	2017-07-23 16:03:00+03	97900.00
696645	2017-07-12 23:07:00+03	73100.00
69664D	2017-07-12 16:58:00+03	135600.00
69667D	2017-08-15 09:42:00+03	214800.00
6966B3	2017-07-11 03:34:00+03	186900.00
6966DB	2017-07-18 13:31:00+03	66600.00
696722	2017-07-03 02:01:00+03	55800.00
696735	2017-07-22 10:59:00+03	369000.00
6967B4	2017-07-13 07:59:00+03	66600.00
6967E4	2017-08-06 13:27:00+03	25400.00
696847	2017-07-05 13:15:00+03	37900.00
696874	2017-06-26 21:27:00+03	93900.00
696878	2017-07-31 17:14:00+03	112000.00
6968B7	2017-08-07 18:43:00+03	136200.00
6968EB	2017-08-01 06:23:00+03	196000.00
6968FF	2017-07-11 01:06:00+03	24700.00
696934	2017-07-20 10:24:00+03	68800.00
696972	2017-06-29 12:30:00+03	54400.00
6969BC	2017-08-15 11:08:00+03	89700.00
696A24	2017-08-13 21:06:00+03	16400.00
696A43	2017-07-27 14:30:00+03	88600.00
696ABE	2017-08-05 13:18:00+03	14400.00
696B03	2017-08-15 05:51:00+03	14800.00
696B05	2017-07-16 19:52:00+03	7400.00
696B87	2017-07-21 01:01:00+03	6000.00
696BC0	2017-07-28 08:12:00+03	135600.00
696C2E	2017-07-16 10:33:00+03	26800.00
696C38	2017-08-12 04:49:00+03	24000.00
696C71	2017-08-13 15:42:00+03	28800.00
696C7C	2017-07-08 16:50:00+03	40800.00
696CC7	2017-07-04 17:32:00+03	60400.00
696D01	2017-08-14 00:50:00+03	260900.00
696D48	2017-07-28 00:49:00+03	34000.00
696DCC	2017-07-14 07:15:00+03	32800.00
696E13	2017-08-06 22:40:00+03	7400.00
696E29	2017-07-18 05:56:00+03	34200.00
696E6E	2017-08-02 15:40:00+03	56900.00
696EC9	2017-08-12 13:23:00+03	13400.00
696F53	2017-07-26 13:37:00+03	20200.00
696FF6	2017-07-01 02:26:00+03	125400.00
697073	2017-07-08 08:42:00+03	131100.00
697087	2017-07-10 03:47:00+03	35300.00
6970D3	2017-07-23 20:00:00+03	27200.00
6970DB	2017-07-30 21:45:00+03	59000.00
697122	2017-07-15 23:08:00+03	116000.00
6971A2	2017-07-30 07:59:00+03	154500.00
6971D9	2017-07-12 06:00:00+03	40600.00
6971F1	2017-08-10 09:01:00+03	98700.00
6971F6	2017-08-06 04:24:00+03	42200.00
69723D	2017-07-21 02:31:00+03	99200.00
6972AD	2017-07-09 16:18:00+03	70600.00
6972C4	2017-07-20 04:57:00+03	83000.00
69734B	2017-08-10 20:38:00+03	136500.00
697363	2017-08-01 20:26:00+03	67900.00
6973F4	2017-07-30 03:38:00+03	46900.00
697408	2017-07-25 10:18:00+03	278600.00
69740B	2017-07-31 15:03:00+03	46000.00
697458	2017-08-14 23:54:00+03	55800.00
697488	2017-07-12 14:44:00+03	123000.00
697573	2017-07-14 03:28:00+03	81700.00
69757E	2017-08-08 18:07:00+03	177900.00
6975AA	2017-06-30 20:59:00+03	167400.00
697614	2017-08-10 02:42:00+03	8200.00
69761F	2017-08-06 13:18:00+03	24400.00
69762A	2017-08-13 04:24:00+03	28800.00
697683	2017-07-14 02:18:00+03	19600.00
6976B4	2017-08-01 15:56:00+03	64800.00
6977E7	2017-08-02 08:19:00+03	52400.00
6977F3	2017-07-29 05:02:00+03	44600.00
697810	2017-07-11 11:34:00+03	22400.00
69787A	2017-08-02 02:38:00+03	23200.00
69787B	2017-07-29 13:28:00+03	58200.00
6978EF	2017-07-11 19:53:00+03	179500.00
697973	2017-07-13 08:29:00+03	26700.00
697985	2017-08-13 14:51:00+03	10800.00
6979A8	2017-07-17 09:45:00+03	60800.00
6979C7	2017-07-01 01:15:00+03	42400.00
6979D8	2017-07-11 07:28:00+03	21000.00
697A07	2017-07-05 10:22:00+03	39400.00
697A24	2017-08-13 07:32:00+03	148200.00
697ACD	2017-06-30 12:45:00+03	227400.00
697AF5	2017-07-02 17:34:00+03	137400.00
697B11	2017-07-18 06:48:00+03	136800.00
697B1A	2017-07-25 06:00:00+03	297400.00
697B3A	2017-07-30 12:01:00+03	37200.00
697BCB	2017-07-18 10:00:00+03	28800.00
697C09	2017-07-28 17:02:00+03	42800.00
697C5B	2017-08-03 13:25:00+03	88800.00
697C87	2017-07-10 16:01:00+03	61800.00
697CA8	2017-06-30 21:18:00+03	12600.00
697D26	2017-08-07 14:08:00+03	12200.00
697D4B	2017-07-02 21:03:00+03	72300.00
697D5F	2017-07-23 20:41:00+03	22000.00
697DB0	2017-08-07 10:11:00+03	12000.00
697E0F	2017-07-24 03:18:00+03	29400.00
697E15	2017-08-15 11:47:00+03	135200.00
697E36	2017-07-14 09:16:00+03	85000.00
697ECE	2017-07-09 02:04:00+03	43200.00
697F5F	2017-07-16 08:11:00+03	48100.00
69801A	2017-07-29 02:04:00+03	125400.00
698064	2017-07-16 20:10:00+03	99700.00
69807E	2017-07-12 03:41:00+03	26700.00
698209	2017-07-26 01:11:00+03	39800.00
69823A	2017-08-04 12:11:00+03	85600.00
698269	2017-07-24 21:16:00+03	26200.00
698274	2017-08-08 02:09:00+03	84500.00
698295	2017-08-01 20:42:00+03	357600.00
69829B	2017-07-27 19:06:00+03	16400.00
6982A3	2017-07-31 20:09:00+03	133100.00
6982D9	2017-08-12 15:46:00+03	6700.00
6982F1	2017-08-11 05:59:00+03	27200.00
698337	2017-07-28 14:10:00+03	29600.00
69837D	2017-08-13 20:37:00+03	55800.00
6983D6	2017-07-26 10:39:00+03	3400.00
698430	2017-07-25 01:10:00+03	86800.00
698440	2017-07-27 17:26:00+03	73500.00
69844D	2017-07-11 23:03:00+03	95700.00
6984AA	2017-07-03 20:44:00+03	14000.00
6984CF	2017-07-16 10:39:00+03	51900.00
6984FD	2017-08-05 20:42:00+03	201200.00
6984FE	2017-07-10 16:44:00+03	136600.00
6985CB	2017-08-03 14:49:00+03	54000.00
698633	2017-08-11 05:14:00+03	167400.00
698644	2017-07-25 07:46:00+03	112100.00
698677	2017-08-06 13:18:00+03	16800.00
6986E6	2017-08-06 21:27:00+03	115200.00
69872E	2017-07-16 16:51:00+03	64400.00
69875B	2017-07-05 15:01:00+03	324500.00
698826	2017-07-03 19:09:00+03	444300.00
698828	2017-07-02 09:30:00+03	43200.00
698875	2017-07-06 12:00:00+03	29600.00
6988F2	2017-07-22 02:40:00+03	40800.00
698A3A	2017-07-15 05:09:00+03	44100.00
698A40	2017-07-01 20:23:00+03	32300.00
698A69	2017-07-07 10:02:00+03	115900.00
698AAF	2017-07-15 06:30:00+03	64400.00
698B22	2017-07-10 03:06:00+03	42700.00
698B41	2017-07-26 04:52:00+03	40800.00
698B95	2017-07-26 22:39:00+03	24000.00
698BCE	2017-07-05 00:04:00+03	23200.00
698C02	2017-08-08 06:43:00+03	81600.00
698C7F	2017-08-03 20:12:00+03	87900.00
698D52	2017-07-08 05:37:00+03	36200.00
698D5A	2017-07-15 02:33:00+03	32800.00
698DD7	2017-07-16 16:29:00+03	62800.00
698DF0	2017-07-02 10:52:00+03	47200.00
698E07	2017-07-14 12:56:00+03	25600.00
698E49	2017-07-22 17:28:00+03	31200.00
698EAE	2017-07-23 06:00:00+03	186900.00
698EB2	2017-07-24 10:06:00+03	37600.00
698EE2	2017-08-05 05:17:00+03	25600.00
698FCF	2017-07-11 16:23:00+03	35800.00
698FD0	2017-06-26 23:28:00+03	24400.00
698FFC	2017-07-07 03:31:00+03	38600.00
699033	2017-08-13 13:49:00+03	25600.00
69906B	2017-08-13 09:27:00+03	40800.00
699081	2017-07-19 20:05:00+03	192200.00
69908A	2017-07-24 11:36:00+03	54800.00
6990C8	2017-07-24 15:21:00+03	59100.00
69917E	2017-07-30 09:30:00+03	22000.00
699252	2017-07-24 00:34:00+03	28800.00
699262	2017-07-29 06:11:00+03	28800.00
69928E	2017-08-09 13:04:00+03	154500.00
6992D3	2017-07-03 14:40:00+03	75300.00
6992D6	2017-07-24 15:13:00+03	397700.00
6992E2	2017-07-10 17:31:00+03	128800.00
699384	2017-07-29 17:11:00+03	104800.00
6993CD	2017-08-04 04:28:00+03	21800.00
6993F2	2017-07-09 08:40:00+03	84600.00
6993F6	2017-08-14 03:18:00+03	88900.00
699424	2017-07-11 00:45:00+03	76800.00
69946B	2017-07-30 00:41:00+03	88500.00
69947B	2017-06-25 04:22:00+03	20200.00
699494	2017-07-29 03:01:00+03	52300.00
6994D2	2017-07-14 05:26:00+03	35800.00
6994F8	2017-08-08 19:49:00+03	58800.00
699501	2017-08-04 12:34:00+03	265700.00
69951D	2017-08-05 04:24:00+03	28200.00
69953E	2017-07-25 15:11:00+03	44700.00
69954C	2017-07-24 23:44:00+03	135400.00
69956B	2017-07-22 13:14:00+03	276000.00
69963E	2017-07-04 04:24:00+03	76600.00
699652	2017-07-04 01:28:00+03	16400.00
699666	2017-07-19 07:41:00+03	187600.00
6996F1	2017-06-26 05:20:00+03	27200.00
699713	2017-07-26 02:50:00+03	301800.00
699720	2017-07-02 18:33:00+03	39100.00
699723	2017-07-15 08:02:00+03	65500.00
69976C	2017-08-09 23:42:00+03	173200.00
699801	2017-08-13 15:19:00+03	140900.00
699978	2017-07-09 01:07:00+03	36400.00
6999B5	2017-08-14 19:40:00+03	38500.00
6999E4	2017-07-02 09:08:00+03	23200.00
6999F7	2017-08-12 17:35:00+03	140500.00
699A34	2017-07-15 12:57:00+03	140800.00
699A6D	2017-07-23 23:38:00+03	57600.00
699AB0	2017-07-17 00:56:00+03	231900.00
699B1D	2017-07-14 06:19:00+03	24000.00
699B26	2017-07-29 21:42:00+03	38800.00
699B54	2017-08-13 14:09:00+03	80500.00
699B72	2017-07-01 09:11:00+03	94300.00
699BCD	2017-07-20 00:11:00+03	70700.00
699BD3	2017-08-14 01:27:00+03	46300.00
699BDB	2017-08-11 20:42:00+03	13600.00
699BED	2017-07-06 07:36:00+03	56100.00
699BEE	2017-07-03 13:24:00+03	119400.00
699C07	2017-07-14 11:22:00+03	56100.00
699CA4	2017-07-03 19:50:00+03	74800.00
699CAD	2017-07-21 16:01:00+03	89600.00
699CC4	2017-07-23 11:06:00+03	70500.00
699CDD	2017-08-11 19:01:00+03	32700.00
699D24	2017-08-08 01:58:00+03	33300.00
699D73	2017-07-04 20:39:00+03	31600.00
699D93	2017-07-09 18:01:00+03	8200.00
699E48	2017-08-14 21:18:00+03	59600.00
699E6B	2017-08-11 06:26:00+03	90300.00
699E6E	2017-08-13 09:33:00+03	23200.00
699EC1	2017-08-02 07:30:00+03	128800.00
699F3E	2017-07-07 14:00:00+03	73100.00
699F70	2017-08-15 16:00:00+03	31900.00
699F9C	2017-07-19 05:22:00+03	100600.00
699FE0	2017-07-15 19:04:00+03	9800.00
69A018	2017-08-15 16:25:00+03	50900.00
69A152	2017-07-30 23:49:00+03	45400.00
69A1CB	2017-07-13 22:02:00+03	67900.00
69A1EB	2017-07-20 04:02:00+03	322600.00
69A251	2017-08-08 14:09:00+03	173500.00
69A29E	2017-08-11 11:19:00+03	12600.00
69A2DB	2017-07-09 09:00:00+03	81700.00
69A2F7	2017-08-03 17:40:00+03	23200.00
69A3A5	2017-08-07 08:05:00+03	6000.00
69A3B6	2017-07-10 12:25:00+03	26000.00
69A454	2017-07-11 15:44:00+03	136200.00
69A48A	2017-07-15 06:30:00+03	87700.00
69A4BC	2017-07-11 08:07:00+03	70800.00
69A4EB	2017-07-22 21:10:00+03	28000.00
69A53A	2017-06-29 05:35:00+03	120700.00
69A5B0	2017-07-11 14:04:00+03	55800.00
69A5F5	2017-08-03 21:39:00+03	24700.00
69A62A	2017-08-01 15:42:00+03	22100.00
69A6A7	2017-07-04 01:55:00+03	115600.00
69A6B9	2017-08-13 03:58:00+03	61400.00
69A6E0	2017-07-19 12:38:00+03	57500.00
69A701	2017-07-29 23:24:00+03	64300.00
69A724	2017-08-15 17:13:00+03	133100.00
69A785	2017-07-06 16:39:00+03	24600.00
69A7ED	2017-07-05 14:24:00+03	169300.00
69A7F6	2017-07-29 11:01:00+03	75300.00
69A849	2017-06-27 19:27:00+03	44000.00
69A8E5	2017-08-03 05:04:00+03	73300.00
69A8F2	2017-07-14 04:01:00+03	76800.00
69A8F7	2017-07-02 01:08:00+03	107400.00
69A902	2017-07-30 12:03:00+03	13200.00
69A915	2017-08-10 07:31:00+03	13400.00
69A948	2017-07-01 02:19:00+03	12600.00
69A98C	2017-07-14 11:43:00+03	12400.00
69A9E6	2017-07-02 09:32:00+03	9800.00
69AA07	2017-07-20 03:33:00+03	133100.00
69AA8D	2017-08-06 06:29:00+03	28000.00
69AAC2	2017-07-07 19:52:00+03	111600.00
69AAD6	2017-07-27 14:04:00+03	70100.00
69AAE7	2017-07-04 07:28:00+03	62600.00
69AB0F	2017-08-05 02:48:00+03	50800.00
69ABDB	2017-08-11 22:55:00+03	84000.00
69ABDF	2017-08-01 17:09:00+03	57500.00
69AC21	2017-08-15 00:35:00+03	6000.00
69AC60	2017-07-08 03:41:00+03	47000.00
69AC7A	2017-08-04 15:02:00+03	99300.00
69AC85	2017-08-04 06:22:00+03	24200.00
69ACC3	2017-07-10 10:26:00+03	111100.00
69ACFB	2017-07-30 17:50:00+03	64700.00
69AD25	2017-08-04 06:22:00+03	106300.00
69AD2C	2017-07-14 13:04:00+03	171400.00
69AD86	2017-07-01 17:33:00+03	6000.00
69ADA6	2017-07-24 20:01:00+03	12400.00
69ADBE	2017-08-08 22:48:00+03	93300.00
69ADCA	2017-07-14 18:07:00+03	112000.00
69ADD6	2017-08-13 08:13:00+03	57300.00
69AE10	2017-07-17 22:49:00+03	66600.00
69AE49	2017-07-04 12:56:00+03	149300.00
69AE4F	2017-07-10 11:00:00+03	151200.00
69AE5C	2017-07-28 04:41:00+03	24400.00
69AEB5	2017-07-08 03:00:00+03	28000.00
69AF1D	2017-07-11 17:39:00+03	164400.00
69AF5D	2017-07-29 00:25:00+03	29600.00
69AFBD	2017-08-08 18:06:00+03	28000.00
69AFFA	2017-07-12 14:23:00+03	27200.00
69B048	2017-07-07 21:04:00+03	7400.00
69B084	2017-08-13 18:07:00+03	110200.00
69B0CE	2017-08-09 04:47:00+03	26000.00
69B122	2017-08-02 14:16:00+03	77400.00
69B126	2017-08-07 16:00:00+03	13400.00
69B136	2017-07-25 21:41:00+03	65000.00
69B15D	2017-07-14 20:33:00+03	6800.00
69B177	2017-07-17 20:54:00+03	51600.00
69B1F2	2017-08-11 01:07:00+03	32400.00
69B23E	2017-07-19 22:00:00+03	54400.00
69B263	2017-07-24 21:47:00+03	58700.00
69B2A5	2017-07-06 02:27:00+03	13400.00
69B2B1	2017-07-16 16:28:00+03	43600.00
69B2BE	2017-07-31 22:56:00+03	103500.00
69B335	2017-07-28 16:38:00+03	23200.00
69B33D	2017-07-28 23:40:00+03	29400.00
69B3AC	2017-08-09 14:28:00+03	41400.00
69B3D6	2017-07-03 06:06:00+03	31400.00
69B3DA	2017-07-03 18:31:00+03	27200.00
69B3F3	2017-08-12 21:53:00+03	27500.00
69B41B	2017-07-13 07:07:00+03	97900.00
69B42B	2017-07-06 15:30:00+03	30000.00
69B437	2017-07-06 17:23:00+03	164400.00
69B443	2017-07-28 04:01:00+03	61800.00
69B444	2017-07-21 10:19:00+03	21400.00
69B454	2017-07-30 03:57:00+03	19600.00
69B4BB	2017-07-28 14:44:00+03	69500.00
69B545	2017-08-06 09:12:00+03	156700.00
69B556	2017-07-20 04:50:00+03	110500.00
69B5D9	2017-08-05 21:18:00+03	86200.00
69B5E8	2017-08-09 03:42:00+03	53400.00
69B654	2017-08-08 15:30:00+03	67600.00
69B6D1	2017-07-13 15:55:00+03	66800.00
69B6EF	2017-07-13 09:12:00+03	56000.00
69B735	2017-08-06 03:15:00+03	92800.00
69B75D	2017-07-06 00:03:00+03	6800.00
69B76F	2017-07-14 17:56:00+03	101500.00
69B776	2017-07-28 16:38:00+03	159800.00
69B782	2017-07-20 16:13:00+03	17800.00
69B799	2017-07-30 18:06:00+03	89600.00
69B830	2017-08-15 13:43:00+03	26000.00
69B85C	2017-07-29 16:46:00+03	73400.00
69B8BE	2017-08-14 04:41:00+03	37600.00
69B8DE	2017-07-23 02:08:00+03	28800.00
69B962	2017-08-15 14:30:00+03	92000.00
69B966	2017-07-04 19:31:00+03	111600.00
69B96A	2017-08-08 08:02:00+03	158200.00
69B970	2017-08-11 01:42:00+03	117600.00
69BA1B	2017-07-20 20:29:00+03	85000.00
69BA2C	2017-08-03 22:09:00+03	28000.00
69BA88	2017-08-11 18:03:00+03	87700.00
69BA91	2017-07-28 23:02:00+03	125200.00
69BB3A	2017-08-11 13:45:00+03	26100.00
69BB57	2017-07-26 23:40:00+03	42700.00
69BB5F	2017-07-09 15:32:00+03	27400.00
69BC23	2017-08-12 09:09:00+03	30200.00
69BC3A	2017-07-29 16:47:00+03	27900.00
69BC54	2017-08-12 01:05:00+03	70700.00
69BC5B	2017-08-04 03:06:00+03	29800.00
69BC60	2017-08-10 07:12:00+03	369200.00
69BC68	2017-08-13 07:45:00+03	50600.00
69BC79	2017-07-13 11:46:00+03	47100.00
69BD4A	2017-08-01 04:22:00+03	45200.00
69BD4E	2017-07-07 17:20:00+03	28600.00
69BD54	2017-07-29 22:39:00+03	12400.00
69BD56	2017-07-03 03:26:00+03	115700.00
69BD7A	2017-07-06 04:07:00+03	71400.00
69BD8E	2017-08-01 08:40:00+03	69500.00
69BD97	2017-08-06 02:58:00+03	98400.00
69BE4D	2017-07-20 15:47:00+03	30200.00
69BE66	2017-07-03 16:49:00+03	56900.00
69BE6A	2017-08-04 04:19:00+03	44000.00
69BE78	2017-08-15 07:35:00+03	39400.00
69BED9	2017-07-06 12:13:00+03	86600.00
69BF54	2017-07-12 12:59:00+03	25600.00
69BF74	2017-08-01 01:16:00+03	56000.00
69BF81	2017-08-09 20:14:00+03	25100.00
69BF95	2017-07-30 20:55:00+03	26000.00
69BFBA	2017-07-30 08:30:00+03	89700.00
69C051	2017-07-12 09:53:00+03	66400.00
69C0B2	2017-08-09 01:14:00+03	18600.00
69C0BA	2017-07-11 08:58:00+03	174600.00
69C0E8	2017-08-13 22:17:00+03	16400.00
69C162	2017-08-05 06:41:00+03	20200.00
69C17F	2017-07-15 20:17:00+03	55000.00
69C193	2017-07-01 12:27:00+03	48100.00
69C1DA	2017-07-11 21:16:00+03	46300.00
69C1E6	2017-07-26 19:24:00+03	32200.00
69C203	2017-07-16 07:18:00+03	23600.00
69C24E	2017-08-11 05:11:00+03	59600.00
69C27B	2017-07-16 16:54:00+03	258000.00
69C355	2017-07-22 21:10:00+03	57500.00
69C435	2017-08-03 12:26:00+03	129600.00
69C4DB	2017-06-29 02:22:00+03	81700.00
69C53B	2017-07-31 04:51:00+03	6700.00
69C55B	2017-07-30 09:05:00+03	267400.00
69C56D	2017-08-10 00:09:00+03	56000.00
69C57F	2017-07-06 02:11:00+03	28000.00
69C58E	2017-07-14 21:30:00+03	23600.00
69C5A0	2017-07-15 02:24:00+03	85000.00
69C5DA	2017-07-24 04:11:00+03	93700.00
69C601	2017-07-15 15:00:00+03	94000.00
69C682	2017-08-07 15:28:00+03	64800.00
69C68A	2017-08-02 00:58:00+03	114400.00
69C763	2017-07-03 04:28:00+03	57400.00
69C7E4	2017-07-29 08:07:00+03	53700.00
69C850	2017-07-14 17:24:00+03	61800.00
69C864	2017-07-05 11:25:00+03	115600.00
69C8AA	2017-08-07 02:08:00+03	24600.00
69C8CD	2017-07-24 12:51:00+03	23400.00
69C8D3	2017-08-08 11:32:00+03	270800.00
69C8DB	2017-07-02 23:06:00+03	265700.00
69C912	2017-07-04 03:34:00+03	120700.00
69C9EB	2017-07-11 11:21:00+03	96800.00
69CA48	2017-07-27 18:16:00+03	65900.00
69CA58	2017-08-08 22:10:00+03	187600.00
69CA93	2017-07-10 08:23:00+03	101700.00
69CA94	2017-08-10 07:05:00+03	123000.00
69CB03	2017-07-11 06:49:00+03	85000.00
69CB38	2017-07-21 17:15:00+03	47600.00
69CB77	2017-08-11 07:43:00+03	35200.00
69CBA0	2017-07-06 16:29:00+03	11000.00
69CBCB	2017-07-10 00:00:00+03	27200.00
69CBFB	2017-07-15 20:58:00+03	143100.00
69CC3A	2017-07-06 09:02:00+03	248400.00
69CC70	2017-07-10 22:36:00+03	76600.00
69CCB2	2017-08-13 07:04:00+03	23200.00
69CCE0	2017-07-08 13:16:00+03	81300.00
69CD19	2017-08-05 06:42:00+03	16400.00
69CD29	2017-07-12 05:57:00+03	14000.00
69CDA3	2017-08-13 13:32:00+03	15000.00
69CE04	2017-07-27 21:54:00+03	136200.00
69CE2A	2017-07-30 06:16:00+03	146200.00
69CE45	2017-07-08 20:22:00+03	179400.00
69CE58	2017-08-01 06:05:00+03	67100.00
69CE68	2017-07-25 06:57:00+03	39400.00
69CE74	2017-07-11 23:55:00+03	14000.00
69CEB0	2017-08-14 21:16:00+03	38800.00
69CEDC	2017-07-22 13:17:00+03	68400.00
69CEF6	2017-07-23 08:06:00+03	47100.00
69CF90	2017-08-11 15:56:00+03	31600.00
69CFAB	2017-07-16 04:37:00+03	172200.00
69CFB4	2017-07-19 20:42:00+03	35300.00
69CFF8	2017-07-03 15:08:00+03	15800.00
69D01C	2017-08-08 14:43:00+03	57700.00
69D05B	2017-08-15 07:28:00+03	97600.00
69D09E	2017-07-28 07:46:00+03	19000.00
69D0E9	2017-07-30 20:54:00+03	125400.00
69D0EF	2017-07-14 19:55:00+03	55800.00
69D133	2017-07-22 23:17:00+03	61500.00
69D15E	2017-06-30 03:42:00+03	68000.00
69D1EC	2017-08-11 09:22:00+03	186900.00
69D206	2017-08-12 05:53:00+03	242100.00
69D243	2017-08-14 17:03:00+03	36200.00
69D246	2017-08-14 19:28:00+03	23600.00
69D248	2017-08-13 01:08:00+03	146300.00
69D25A	2017-07-13 14:08:00+03	135600.00
69D2A1	2017-08-15 07:07:00+03	22000.00
69D2DB	2017-08-12 23:38:00+03	135600.00
69D2E2	2017-07-03 20:58:00+03	32800.00
69D2FA	2017-07-08 17:24:00+03	14000.00
69D31F	2017-07-14 08:16:00+03	55800.00
69D392	2017-07-02 16:08:00+03	56000.00
69D3B1	2017-07-22 15:41:00+03	29600.00
69D3B2	2017-07-14 16:13:00+03	104800.00
69D3F2	2017-08-06 00:48:00+03	38800.00
69D433	2017-08-07 19:45:00+03	111700.00
69D44A	2017-07-08 10:46:00+03	166900.00
69D495	2017-07-25 01:03:00+03	16400.00
69D4CE	2017-08-11 21:20:00+03	15700.00
69D4DD	2017-07-05 21:03:00+03	80400.00
69D6E0	2017-08-04 12:03:00+03	44000.00
69D702	2017-08-13 13:29:00+03	57600.00
69D710	2017-08-04 13:00:00+03	101200.00
69D72B	2017-07-12 04:33:00+03	63500.00
69D795	2017-07-28 01:43:00+03	48300.00
69D82C	2017-07-24 20:42:00+03	8200.00
69D884	2017-08-06 12:35:00+03	56000.00
69D8DD	2017-07-10 08:28:00+03	52600.00
69D8FE	2017-07-12 11:48:00+03	22100.00
69D918	2017-07-10 12:30:00+03	56000.00
69D9CD	2017-08-01 09:05:00+03	66600.00
69D9E8	2017-07-09 02:53:00+03	136200.00
69D9F7	2017-08-13 22:06:00+03	32800.00
69D9FD	2017-07-28 18:30:00+03	56600.00
69DA10	2017-08-03 15:06:00+03	30600.00
69DA1C	2017-07-07 09:11:00+03	154800.00
69DA72	2017-08-04 20:18:00+03	55800.00
69DA7A	2017-08-12 23:37:00+03	98300.00
69DA7D	2017-07-21 20:19:00+03	261500.00
69DA8D	2017-08-08 02:11:00+03	137100.00
69DAD1	2017-07-07 11:46:00+03	18600.00
69DB0F	2017-07-01 09:35:00+03	6900.00
69DB3E	2017-07-12 18:51:00+03	30900.00
69DB85	2017-08-10 14:00:00+03	75200.00
69DB93	2017-06-30 17:37:00+03	56000.00
69DB9E	2017-07-14 21:38:00+03	28600.00
69DBDD	2017-07-08 22:44:00+03	6700.00
69DC52	2017-07-17 15:14:00+03	27800.00
69DC58	2017-07-05 02:35:00+03	133100.00
69DC82	2017-06-30 09:22:00+03	28000.00
69DCC7	2017-06-30 07:48:00+03	32800.00
69DCC8	2017-08-03 12:26:00+03	112000.00
69DD66	2017-07-26 09:47:00+03	133200.00
69DD9F	2017-07-14 22:02:00+03	100600.00
69DDDB	2017-07-10 06:37:00+03	8000.00
69DE08	2017-07-21 21:01:00+03	58400.00
69DE17	2017-07-14 15:03:00+03	28800.00
69DE37	2017-07-06 01:24:00+03	47600.00
69DED7	2017-07-18 07:26:00+03	29400.00
69DF10	2017-07-07 10:07:00+03	10600.00
69DF3B	2017-07-28 01:08:00+03	76600.00
69DF52	2017-07-30 14:13:00+03	91000.00
69DF88	2017-07-15 20:18:00+03	93900.00
69DFE3	2017-08-07 05:55:00+03	124600.00
69E14A	2017-07-10 10:42:00+03	6300.00
69E1C3	2017-07-25 12:48:00+03	272300.00
69E1EB	2017-06-29 03:28:00+03	26000.00
69E202	2017-07-17 04:58:00+03	66000.00
69E208	2017-08-09 21:40:00+03	31600.00
69E229	2017-07-03 12:48:00+03	91100.00
69E239	2017-07-18 00:08:00+03	100600.00
69E284	2017-07-09 08:18:00+03	154300.00
69E2C8	2017-08-15 14:58:00+03	80500.00
69E2E0	2017-07-14 19:22:00+03	21200.00
69E37B	2017-08-12 14:56:00+03	43600.00
69E41F	2017-07-22 14:59:00+03	28000.00
69E43B	2017-07-10 10:06:00+03	88800.00
69E4BE	2017-07-20 15:19:00+03	88600.00
69E4F4	2017-07-10 20:40:00+03	32800.00
69E51C	2017-07-30 22:54:00+03	12400.00
69E520	2017-07-11 16:23:00+03	14000.00
69E53C	2017-07-17 00:53:00+03	121500.00
69E556	2017-07-30 05:35:00+03	97200.00
69E59C	2017-07-21 20:55:00+03	12600.00
69E5AA	2017-07-16 01:54:00+03	67600.00
69E5AC	2017-07-30 23:11:00+03	112600.00
69E5E9	2017-07-26 05:20:00+03	15000.00
69E617	2017-07-06 09:03:00+03	293700.00
69E6C5	2017-07-06 11:13:00+03	39600.00
69E6E9	2017-08-06 10:12:00+03	156500.00
69E765	2017-07-12 13:51:00+03	28000.00
69E797	2017-08-09 03:52:00+03	23400.00
69E7C3	2017-07-28 10:16:00+03	56900.00
69E7D9	2017-08-14 11:52:00+03	71900.00
69E7FF	2017-07-18 23:51:00+03	46000.00
69E896	2017-07-10 11:10:00+03	85700.00
69E89F	2017-07-03 00:39:00+03	99100.00
69E8DC	2017-07-20 01:42:00+03	61800.00
69E974	2017-07-29 08:15:00+03	85300.00
69E99F	2017-08-12 19:24:00+03	68800.00
69E9A0	2017-08-04 01:17:00+03	16400.00
69E9F7	2017-08-11 02:29:00+03	23400.00
69EA0B	2017-08-12 19:40:00+03	48900.00
69EA1A	2017-08-07 04:55:00+03	112000.00
69EA37	2017-07-26 05:09:00+03	336100.00
69EA39	2017-08-03 14:09:00+03	25200.00
69EA77	2017-07-17 09:26:00+03	28800.00
69EB2D	2017-07-15 09:16:00+03	75600.00
69EBDA	2017-08-11 19:16:00+03	7400.00
69EBF3	2017-07-05 12:40:00+03	25100.00
69ECA3	2017-08-13 23:09:00+03	174300.00
69ECBE	2017-08-01 20:56:00+03	48800.00
69ECCF	2017-07-09 02:14:00+03	79900.00
69ED01	2017-07-09 19:39:00+03	31600.00
69EDAA	2017-08-09 15:19:00+03	49800.00
69EDD2	2017-07-21 12:09:00+03	14400.00
69EE3E	2017-07-26 10:54:00+03	77200.00
69EE57	2017-07-16 22:26:00+03	92900.00
69EE94	2017-07-01 22:33:00+03	14000.00
69EF16	2017-07-08 03:21:00+03	18000.00
69EF19	2017-06-28 05:42:00+03	155600.00
69EF28	2017-08-03 12:58:00+03	23600.00
69EF69	2017-07-26 20:44:00+03	28000.00
69EF81	2017-07-28 17:05:00+03	26000.00
69EFA9	2017-07-06 17:08:00+03	96800.00
69F011	2017-07-29 21:02:00+03	6800.00
69F077	2017-07-30 22:49:00+03	38400.00
69F07B	2017-08-10 09:26:00+03	56000.00
69F0B8	2017-07-03 06:12:00+03	43200.00
69F0CA	2017-07-18 17:21:00+03	39300.00
69F0F6	2017-07-18 08:55:00+03	69700.00
69F101	2017-07-15 20:03:00+03	92900.00
69F1B3	2017-07-17 16:35:00+03	85000.00
69F1EA	2017-07-13 00:54:00+03	15700.00
69F260	2017-07-10 16:05:00+03	31000.00
69F272	2017-07-29 06:52:00+03	65000.00
69F2F3	2017-07-03 02:14:00+03	35300.00
69F30A	2017-08-07 19:37:00+03	156100.00
69F310	2017-07-17 15:30:00+03	124200.00
69F33F	2017-08-13 06:59:00+03	47200.00
69F349	2017-07-16 05:05:00+03	266400.00
69F34D	2017-07-20 02:10:00+03	89600.00
69F36B	2017-08-10 09:30:00+03	54600.00
69F3E6	2017-07-23 19:18:00+03	149300.00
69F403	2017-07-31 20:28:00+03	64800.00
69F487	2017-07-17 22:15:00+03	47000.00
69F4EE	2017-06-30 09:47:00+03	44500.00
69F582	2017-08-15 03:16:00+03	495400.00
69F5C7	2017-07-24 10:17:00+03	52400.00
69F5DF	2017-07-10 09:17:00+03	99200.00
69F689	2017-07-05 00:51:00+03	49100.00
69F832	2017-08-09 16:48:00+03	66200.00
69F89A	2017-07-15 11:17:00+03	36200.00
69F8C6	2017-08-09 03:37:00+03	19600.00
69F8D3	2017-07-07 08:42:00+03	90700.00
69F8F7	2017-07-23 07:14:00+03	67800.00
69F92A	2017-08-14 07:04:00+03	30200.00
69F95E	2017-08-08 08:33:00+03	290500.00
69FA9F	2017-07-22 23:34:00+03	113000.00
69FAE5	2017-08-01 22:35:00+03	10600.00
69FB9D	2017-07-19 04:12:00+03	131100.00
69FCE9	2017-08-04 12:14:00+03	125100.00
69FD22	2017-07-31 20:07:00+03	26000.00
69FD8A	2017-08-13 22:15:00+03	146600.00
69FDE5	2017-07-23 14:22:00+03	55800.00
69FE58	2017-08-09 04:37:00+03	41800.00
69FEA9	2017-07-25 14:11:00+03	25400.00
69FEBC	2017-08-02 02:05:00+03	25400.00
69FF18	2017-07-27 21:17:00+03	130900.00
69FF81	2017-08-13 11:45:00+03	28800.00
69FFB0	2017-08-01 00:19:00+03	75600.00
69FFBD	2017-07-20 09:38:00+03	27400.00
6A00FB	2017-08-04 07:53:00+03	123000.00
6A0127	2017-07-19 01:53:00+03	265200.00
6A0135	2017-07-15 01:01:00+03	26000.00
6A01F7	2017-08-02 01:44:00+03	243300.00
6A021D	2017-07-30 19:24:00+03	22000.00
6A0234	2017-07-20 23:04:00+03	111600.00
6A0309	2017-08-01 02:01:00+03	79600.00
6A031D	2017-08-10 02:12:00+03	34400.00
6A0340	2017-07-06 12:01:00+03	166000.00
6A0359	2017-07-28 20:15:00+03	291200.00
6A0368	2017-08-09 09:09:00+03	139000.00
6A0378	2017-06-26 16:03:00+03	28000.00
6A042C	2017-07-14 00:57:00+03	22000.00
6A04A5	2017-08-05 14:25:00+03	124200.00
6A04A8	2017-08-08 18:44:00+03	69900.00
6A04F8	2017-07-15 23:41:00+03	46000.00
6A0523	2017-07-13 02:30:00+03	43000.00
6A0540	2017-07-07 23:14:00+03	396500.00
6A0559	2017-08-07 23:02:00+03	20400.00
6A058A	2017-08-06 01:22:00+03	89700.00
6A05D8	2017-07-21 02:39:00+03	107000.00
6A05F4	2017-08-07 06:39:00+03	246000.00
6A060D	2017-08-09 20:25:00+03	43700.00
6A0646	2017-07-14 23:56:00+03	22000.00
6A066C	2017-08-12 22:28:00+03	124200.00
6A0690	2017-08-02 00:59:00+03	91100.00
6A069C	2017-08-12 23:44:00+03	24400.00
6A06EA	2017-08-15 08:55:00+03	119300.00
6A0720	2017-07-20 23:34:00+03	189200.00
6A077D	2017-08-13 07:33:00+03	50600.00
6A0780	2017-08-01 23:48:00+03	37600.00
6A0787	2017-07-09 19:57:00+03	21400.00
6A07EE	2017-08-04 01:56:00+03	30200.00
6A081A	2017-07-04 16:21:00+03	281500.00
6A0879	2017-07-11 22:54:00+03	45400.00
6A087A	2017-07-13 19:49:00+03	37900.00
6A0881	2017-07-27 00:26:00+03	176800.00
6A0898	2017-08-10 13:44:00+03	59300.00
6A08B2	2017-07-24 02:49:00+03	75600.00
6A08B7	2017-07-20 04:51:00+03	75800.00
6A08D6	2017-07-14 14:10:00+03	135400.00
6A09CB	2017-07-26 02:26:00+03	137200.00
6A0AC2	2017-08-11 08:05:00+03	125400.00
6A0B0E	2017-08-07 04:05:00+03	25600.00
6A0BFE	2017-08-11 02:41:00+03	59200.00
6A0C18	2017-06-28 15:36:00+03	23600.00
6A0D06	2017-07-08 05:15:00+03	64800.00
6A0D8A	2017-08-05 08:08:00+03	23600.00
6A0E61	2017-07-26 13:00:00+03	46400.00
6A0EB5	2017-08-03 03:56:00+03	88500.00
6A0EB7	2017-07-13 14:48:00+03	41900.00
6A0EDA	2017-07-14 14:34:00+03	25800.00
6A0FC7	2017-08-15 11:01:00+03	50800.00
6A1121	2017-07-19 09:59:00+03	54400.00
6A115E	2017-08-04 08:55:00+03	139800.00
6A11A8	2017-08-13 18:30:00+03	27200.00
6A1207	2017-08-08 18:35:00+03	423800.00
6A120D	2017-07-29 18:36:00+03	81300.00
6A122A	2017-07-10 12:01:00+03	6800.00
6A1252	2017-08-07 08:57:00+03	46000.00
6A129D	2017-08-08 03:15:00+03	32800.00
6A12B3	2017-07-22 05:53:00+03	25000.00
6A12BE	2017-07-20 18:59:00+03	46300.00
6A12D3	2017-07-31 04:56:00+03	58900.00
6A132E	2017-06-30 23:11:00+03	53600.00
6A13C9	2017-07-14 21:42:00+03	14800.00
6A1401	2017-07-23 08:04:00+03	56000.00
6A1472	2017-08-01 03:45:00+03	30800.00
6A152E	2017-08-03 13:27:00+03	10100.00
6A162E	2017-07-30 12:05:00+03	55000.00
6A1642	2017-07-30 05:25:00+03	295400.00
6A167A	2017-07-01 23:26:00+03	13400.00
6A16DD	2017-08-14 01:12:00+03	66600.00
6A16F0	2017-08-06 13:15:00+03	47200.00
6A16F8	2017-07-23 16:36:00+03	54500.00
6A1741	2017-08-07 19:01:00+03	48500.00
6A175B	2017-07-29 02:16:00+03	66400.00
6A17B8	2017-08-09 15:39:00+03	43000.00
6A1895	2017-08-04 23:15:00+03	19600.00
6A18F3	2017-07-22 01:31:00+03	38400.00
6A1902	2017-07-06 05:04:00+03	81600.00
6A19B3	2017-07-25 16:50:00+03	81500.00
6A19B6	2017-07-01 04:57:00+03	50000.00
6A19C5	2017-07-03 01:57:00+03	76800.00
6A19D0	2017-08-13 18:00:00+03	53600.00
6A1ABC	2017-08-06 02:48:00+03	116700.00
6A1ADF	2017-07-28 20:49:00+03	246000.00
6A1B39	2017-08-11 09:38:00+03	22000.00
6A1CF3	2017-07-30 05:50:00+03	19800.00
6A1D46	2017-07-28 17:38:00+03	75500.00
6A1D57	2017-08-10 16:10:00+03	12000.00
6A1F0C	2017-08-03 06:41:00+03	416000.00
6A1F2B	2017-07-06 06:19:00+03	47700.00
6A1F5A	2017-07-20 18:56:00+03	11000.00
6A1F71	2017-07-02 01:31:00+03	26800.00
6A1FBD	2017-07-31 20:10:00+03	302200.00
6A1FC4	2017-08-05 14:06:00+03	86300.00
6A2109	2017-07-28 10:47:00+03	37900.00
6A211E	2017-07-27 01:18:00+03	112600.00
6A21D4	2017-07-24 08:10:00+03	153300.00
6A222E	2017-07-31 06:28:00+03	133200.00
6A224F	2017-07-03 08:04:00+03	41600.00
6A225D	2017-07-07 07:30:00+03	76600.00
6A227A	2017-08-07 16:59:00+03	105000.00
6A2292	2017-08-05 01:59:00+03	22600.00
6A2295	2017-07-25 09:32:00+03	27200.00
6A22DB	2017-08-12 18:21:00+03	27200.00
6A239A	2017-07-23 05:26:00+03	35300.00
6A23AF	2017-06-30 08:22:00+03	125200.00
6A2489	2017-07-16 16:38:00+03	713800.00
6A248A	2017-07-12 07:37:00+03	75300.00
6A24C0	2017-07-21 20:42:00+03	240600.00
6A2504	2017-08-11 09:47:00+03	21600.00
6A250A	2017-07-28 11:13:00+03	53600.00
6A25A3	2017-07-17 23:19:00+03	6800.00
6A25A6	2017-06-30 01:52:00+03	57500.00
6A25B2	2017-07-22 23:27:00+03	54500.00
6A2631	2017-07-21 12:49:00+03	23600.00
6A2632	2017-07-23 15:24:00+03	99200.00
6A2662	2017-07-03 05:04:00+03	112100.00
6A268D	2017-07-29 11:30:00+03	99300.00
6A2696	2017-07-08 04:08:00+03	85000.00
6A2698	2017-07-30 16:10:00+03	59100.00
6A2722	2017-07-12 00:41:00+03	14000.00
6A282B	2017-07-18 22:21:00+03	114800.00
6A2889	2017-08-03 19:54:00+03	20400.00
6A2898	2017-06-25 02:01:00+03	6000.00
6A28B1	2017-07-08 12:53:00+03	34000.00
6A28C2	2017-07-04 11:10:00+03	23200.00
6A293E	2017-08-01 22:07:00+03	79600.00
6A2971	2017-08-07 07:35:00+03	110500.00
6A299C	2017-07-21 20:34:00+03	40800.00
6A29BA	2017-07-25 04:22:00+03	21800.00
6A29F2	2017-07-07 17:19:00+03	62000.00
6A2A03	2017-08-14 18:10:00+03	184500.00
6A2A1D	2017-07-19 03:49:00+03	17800.00
6A2A74	2017-07-31 06:03:00+03	31400.00
6A2A8E	2017-08-02 00:04:00+03	38600.00
6A2AA2	2017-07-24 00:48:00+03	57700.00
6A2ACF	2017-07-27 15:09:00+03	133200.00
6A2ADE	2017-07-25 06:36:00+03	25100.00
6A2B13	2017-07-12 20:41:00+03	58000.00
6A2B41	2017-07-07 21:58:00+03	42700.00
6A2B7B	2017-07-21 14:34:00+03	169900.00
6A2B7F	2017-07-21 22:53:00+03	44000.00
6A2B80	2017-07-11 06:12:00+03	64800.00
6A2BBA	2017-07-12 16:30:00+03	25800.00
6A2BDC	2017-07-10 08:26:00+03	119500.00
6A2C21	2017-07-02 12:34:00+03	123000.00
6A2C8E	2017-07-08 02:00:00+03	87700.00
6A2CD3	2017-07-26 18:20:00+03	25800.00
6A2D6D	2017-07-11 08:07:00+03	19600.00
6A2DB6	2017-07-23 01:33:00+03	56000.00
6A2DE6	2017-07-19 15:11:00+03	119900.00
6A2DF4	2017-07-22 21:47:00+03	15000.00
6A2E05	2017-08-04 10:56:00+03	46400.00
6A2E72	2017-07-07 11:59:00+03	48100.00
6A2E8F	2017-07-05 23:43:00+03	27200.00
6A2EA0	2017-08-14 07:20:00+03	112000.00
6A2EC2	2017-07-25 18:20:00+03	27300.00
6A2F50	2017-07-21 22:25:00+03	74900.00
6A2FA9	2017-07-13 20:50:00+03	117500.00
6A2FB0	2017-08-11 05:28:00+03	24000.00
6A2FD1	2017-07-24 16:32:00+03	30000.00
6A2FD9	2017-08-11 10:53:00+03	140100.00
6A301E	2017-08-15 13:40:00+03	19500.00
6A309E	2017-07-07 09:17:00+03	248400.00
6A311A	2017-07-19 04:13:00+03	111600.00
6A3138	2017-07-20 07:19:00+03	120900.00
6A3157	2017-08-03 00:43:00+03	55800.00
6A3167	2017-07-24 15:55:00+03	369000.00
6A319F	2017-08-05 10:46:00+03	23600.00
6A3216	2017-07-14 05:06:00+03	208300.00
6A324A	2017-07-06 16:13:00+03	99700.00
6A32C2	2017-07-08 22:49:00+03	61800.00
6A32E7	2017-07-13 22:05:00+03	57400.00
6A32FA	2017-08-06 16:20:00+03	28000.00
6A3302	2017-07-05 02:37:00+03	54100.00
6A332D	2017-07-22 21:56:00+03	54000.00
6A3334	2017-07-28 06:54:00+03	191000.00
6A33B0	2017-07-13 22:30:00+03	115700.00
6A3439	2017-08-05 13:47:00+03	78100.00
6A343C	2017-08-15 16:55:00+03	135600.00
6A348A	2017-08-14 06:30:00+03	71500.00
6A3562	2017-07-23 05:07:00+03	23600.00
6A356F	2017-07-29 11:22:00+03	100600.00
6A35B1	2017-07-04 03:32:00+03	49100.00
6A35E3	2017-07-27 12:09:00+03	24800.00
6A3624	2017-08-09 09:31:00+03	81800.00
6A362A	2017-08-15 16:04:00+03	124400.00
6A3642	2017-08-08 21:15:00+03	20100.00
6A3655	2017-07-31 03:03:00+03	30200.00
6A3656	2017-08-12 07:46:00+03	92900.00
6A3662	2017-08-06 18:29:00+03	266500.00
6A368F	2017-08-12 19:10:00+03	6700.00
6A3727	2017-07-31 14:04:00+03	100200.00
6A3757	2017-08-04 00:31:00+03	65900.00
6A37F0	2017-07-22 19:55:00+03	179400.00
6A3834	2017-07-04 17:01:00+03	26200.00
6A391E	2017-08-12 01:57:00+03	170800.00
6A3A03	2017-07-28 21:16:00+03	67000.00
6A3A46	2017-08-05 06:34:00+03	73300.00
6A3A4A	2017-07-14 16:16:00+03	28800.00
6A3B63	2017-07-06 07:05:00+03	43900.00
6A3B6B	2017-07-19 01:41:00+03	46200.00
6A3B96	2017-07-07 01:26:00+03	8000.00
6A3C23	2017-07-20 02:36:00+03	99700.00
6A3CC0	2017-07-23 13:26:00+03	12600.00
6A3CC4	2017-07-02 02:15:00+03	13300.00
6A3CD2	2017-08-11 04:32:00+03	56000.00
6A3D19	2017-08-09 12:52:00+03	408500.00
6A3D3A	2017-08-10 07:53:00+03	148200.00
6A3D5C	2017-07-09 23:06:00+03	106800.00
6A3D60	2017-07-31 12:21:00+03	47100.00
6A3D8F	2017-08-01 15:45:00+03	54500.00
6A3DA1	2017-08-09 13:40:00+03	32700.00
6A3DAD	2017-07-31 15:13:00+03	115700.00
6A3E2A	2017-07-30 17:49:00+03	52000.00
6A3E6F	2017-08-05 15:43:00+03	398500.00
6A3E71	2017-08-10 04:32:00+03	6800.00
6A3E95	2017-07-10 11:48:00+03	289300.00
6A3F30	2017-07-28 21:23:00+03	302600.00
6A3F57	2017-07-20 10:00:00+03	31100.00
6A3FB9	2017-07-24 19:56:00+03	296600.00
6A3FE7	2017-08-14 17:39:00+03	73300.00
6A403B	2017-08-08 00:04:00+03	28800.00
6A4048	2017-07-02 15:25:00+03	44800.00
6A40B9	2017-08-10 08:17:00+03	76600.00
6A40DD	2017-07-25 10:12:00+03	56000.00
6A4144	2017-07-21 01:01:00+03	79000.00
6A4222	2017-07-01 05:13:00+03	51900.00
6A4310	2017-08-06 07:02:00+03	29200.00
6A4345	2017-07-14 02:00:00+03	64600.00
6A4351	2017-07-03 15:21:00+03	81600.00
6A4380	2017-07-06 08:36:00+03	515100.00
6A43C4	2017-07-05 04:43:00+03	44800.00
6A441B	2017-08-05 03:52:00+03	136400.00
6A444A	2017-07-06 10:40:00+03	24800.00
6A446A	2017-07-11 05:22:00+03	48800.00
6A446E	2017-07-20 21:51:00+03	88900.00
6A447D	2017-07-30 19:35:00+03	26000.00
6A4483	2017-07-04 02:32:00+03	36200.00
6A44A0	2017-07-15 20:47:00+03	6800.00
6A44F8	2017-07-17 06:43:00+03	96100.00
6A454E	2017-07-06 18:55:00+03	271200.00
6A457D	2017-08-09 07:26:00+03	84000.00
6A4580	2017-08-11 01:14:00+03	23200.00
6A45C5	2017-08-06 02:56:00+03	56600.00
6A46AA	2017-07-28 07:57:00+03	183300.00
6A46C8	2017-07-26 15:58:00+03	258400.00
6A46D3	2017-08-12 20:14:00+03	24400.00
6A46FA	2017-06-30 03:13:00+03	43200.00
6A470C	2017-08-01 13:47:00+03	26000.00
6A472E	2017-07-22 04:02:00+03	27300.00
6A4747	2017-07-11 08:42:00+03	199200.00
6A4812	2017-08-15 06:28:00+03	44600.00
6A4835	2017-07-30 17:29:00+03	88600.00
6A4836	2017-07-12 11:11:00+03	113800.00
6A4842	2017-07-23 21:09:00+03	60800.00
6A4885	2017-06-27 02:14:00+03	19600.00
6A48B7	2017-07-09 14:01:00+03	28800.00
6A48C1	2017-07-23 17:11:00+03	68100.00
6A494A	2017-08-11 23:30:00+03	12400.00
6A494B	2017-07-18 07:18:00+03	47000.00
6A4980	2017-07-28 12:11:00+03	65500.00
6A49BE	2017-08-11 17:09:00+03	58200.00
6A49C9	2017-08-02 23:23:00+03	49500.00
6A49FD	2017-08-07 20:14:00+03	32800.00
6A49FF	2017-08-01 17:36:00+03	156400.00
6A4A0E	2017-08-12 00:16:00+03	70600.00
6A4AA4	2017-08-15 04:51:00+03	295100.00
6A4B00	2017-07-03 13:06:00+03	10700.00
6A4BA0	2017-07-18 18:02:00+03	60400.00
6A4BB2	2017-07-29 03:07:00+03	47100.00
6A4C28	2017-08-04 22:24:00+03	18000.00
6A4C30	2017-07-13 11:27:00+03	8000.00
6A4C34	2017-07-31 07:15:00+03	24000.00
6A4C3C	2017-07-19 22:42:00+03	6700.00
6A4C93	2017-07-23 06:08:00+03	58500.00
6A4CA9	2017-07-30 07:20:00+03	129200.00
6A4D7B	2017-07-20 16:44:00+03	76600.00
6A4DF9	2017-07-16 08:31:00+03	112000.00
6A4E1E	2017-07-27 14:11:00+03	55800.00
6A4E20	2017-08-12 23:52:00+03	193600.00
6A4E4C	2017-08-13 20:28:00+03	39800.00
6A4EB5	2017-07-08 08:43:00+03	369000.00
6A4ED3	2017-07-17 15:42:00+03	65900.00
6A4ED7	2017-08-11 22:06:00+03	128800.00
6A4F01	2017-08-15 11:23:00+03	12600.00
6A4F33	2017-07-11 01:58:00+03	25200.00
6A4F39	2017-07-23 07:46:00+03	12400.00
6A4F56	2017-08-06 02:26:00+03	25800.00
6A4F57	2017-07-12 17:06:00+03	19000.00
6A4F86	2017-08-13 16:41:00+03	31400.00
6A4FA9	2017-08-14 22:22:00+03	123000.00
6A4FB6	2017-08-14 10:55:00+03	46400.00
6A5018	2017-07-18 12:29:00+03	19600.00
6A504C	2017-07-17 01:15:00+03	41400.00
6A50A1	2017-08-04 11:31:00+03	54600.00
6A50B0	2017-06-29 16:20:00+03	97900.00
6A50F6	2017-07-02 20:42:00+03	32800.00
6A515E	2017-07-25 15:05:00+03	11000.00
6A5174	2017-07-17 22:48:00+03	44100.00
6A51BF	2017-07-10 04:23:00+03	36200.00
6A5207	2017-08-08 15:01:00+03	19600.00
6A5208	2017-08-09 14:28:00+03	26600.00
6A5248	2017-07-10 00:38:00+03	70500.00
6A527C	2017-06-29 09:53:00+03	97500.00
6A5308	2017-07-24 21:19:00+03	266400.00
6A5310	2017-07-08 03:50:00+03	72000.00
6A5344	2017-08-06 21:47:00+03	103500.00
6A5355	2017-08-01 07:30:00+03	19600.00
6A5394	2017-07-20 11:13:00+03	34800.00
6A53A3	2017-07-12 07:08:00+03	238300.00
6A53BD	2017-07-10 19:50:00+03	111600.00
6A53DA	2017-06-30 07:26:00+03	96500.00
6A5498	2017-08-12 21:50:00+03	60000.00
6A5661	2017-08-10 08:35:00+03	97400.00
6A566B	2017-07-27 13:57:00+03	32500.00
6A566D	2017-08-05 23:26:00+03	11000.00
6A5705	2017-07-27 14:39:00+03	19600.00
6A5708	2017-07-16 05:18:00+03	187800.00
6A5722	2017-08-13 05:48:00+03	123000.00
6A5735	2017-07-31 06:33:00+03	12200.00
6A5739	2017-08-01 06:56:00+03	12600.00
6A575D	2017-07-21 19:44:00+03	44000.00
6A576C	2017-07-23 10:46:00+03	29600.00
6A5790	2017-07-08 06:35:00+03	65900.00
6A579E	2017-07-02 12:36:00+03	44800.00
6A57C9	2017-07-31 21:51:00+03	73400.00
6A57F4	2017-07-23 04:46:00+03	81600.00
6A581C	2017-08-15 16:03:00+03	102100.00
6A583A	2017-08-11 21:51:00+03	28800.00
6A584C	2017-07-29 01:03:00+03	60800.00
6A586F	2017-07-19 09:39:00+03	260400.00
6A58D3	2017-07-13 06:14:00+03	69600.00
6A5912	2017-07-02 21:09:00+03	169900.00
6A5948	2017-07-07 17:23:00+03	55800.00
6A594F	2017-08-12 14:37:00+03	136200.00
6A5A5C	2017-08-15 13:43:00+03	29100.00
6A5A82	2017-07-12 16:33:00+03	24300.00
6A5ABE	2017-07-29 18:11:00+03	744900.00
6A5AEF	2017-07-07 11:16:00+03	62600.00
6A5B33	2017-08-09 20:02:00+03	112000.00
6A5B61	2017-07-10 02:33:00+03	111600.00
6A5B83	2017-08-04 01:57:00+03	56000.00
6A5B97	2017-07-29 01:14:00+03	35800.00
6A5BE7	2017-07-03 17:46:00+03	140800.00
6A5C5A	2017-08-09 00:18:00+03	40200.00
6A5C61	2017-08-14 22:31:00+03	116300.00
6A5C8B	2017-07-30 14:39:00+03	12400.00
6A5CA0	2017-08-11 18:38:00+03	58600.00
6A5CEB	2017-07-12 09:23:00+03	45100.00
6A5CF2	2017-08-15 02:05:00+03	31600.00
6A5D2D	2017-07-13 16:03:00+03	50800.00
6A5D32	2017-07-05 17:51:00+03	28000.00
6A5D34	2017-07-30 06:50:00+03	22000.00
6A5D38	2017-08-12 16:00:00+03	10800.00
6A5D5E	2017-08-05 01:48:00+03	144400.00
6A5D75	2017-07-07 01:12:00+03	71700.00
6A5D97	2017-07-05 15:16:00+03	162700.00
6A5DC6	2017-08-03 04:25:00+03	119300.00
6A5E36	2017-08-02 05:39:00+03	46400.00
6A5E6E	2017-07-26 11:06:00+03	131800.00
6A5F53	2017-08-11 18:45:00+03	19600.00
6A6002	2017-07-28 19:41:00+03	56100.00
6A607A	2017-08-08 15:27:00+03	51300.00
6A609D	2017-08-13 11:28:00+03	16400.00
6A60AB	2017-08-14 11:42:00+03	28000.00
6A60BA	2017-07-17 01:41:00+03	59200.00
6A60E4	2017-07-22 08:47:00+03	15000.00
6A6100	2017-07-22 23:47:00+03	43700.00
6A6152	2017-07-23 03:37:00+03	140500.00
6A6162	2017-07-14 07:31:00+03	131100.00
6A617B	2017-07-26 08:26:00+03	23600.00
6A61AB	2017-07-03 11:15:00+03	43200.00
6A620C	2017-07-21 14:22:00+03	247300.00
6A6220	2017-08-05 20:40:00+03	135400.00
6A6227	2017-07-20 23:24:00+03	6000.00
6A624A	2017-07-27 03:51:00+03	132800.00
6A6266	2017-08-14 11:33:00+03	26600.00
6A6282	2017-07-23 12:01:00+03	94700.00
6A636D	2017-07-16 20:33:00+03	56000.00
6A63CE	2017-07-19 02:08:00+03	73500.00
6A63D1	2017-07-17 05:52:00+03	23600.00
6A63DE	2017-08-14 08:53:00+03	26600.00
6A6403	2017-08-06 19:40:00+03	23600.00
6A642B	2017-07-01 12:10:00+03	66600.00
6A6491	2017-07-03 16:24:00+03	664200.00
6A64A1	2017-07-07 23:48:00+03	66000.00
6A64C3	2017-07-07 07:18:00+03	134400.00
6A64CF	2017-07-10 21:57:00+03	254600.00
6A655F	2017-07-30 01:53:00+03	93700.00
6A65A7	2017-08-02 15:49:00+03	69600.00
6A6671	2017-07-28 04:58:00+03	57500.00
6A66F7	2017-08-14 21:02:00+03	273000.00
6A672E	2017-08-06 08:09:00+03	40400.00
6A674B	2017-07-17 20:35:00+03	42900.00
6A675B	2017-08-15 00:56:00+03	36200.00
6A67E2	2017-07-11 17:15:00+03	35200.00
6A67FB	2017-07-23 14:14:00+03	18600.00
6A680B	2017-08-07 08:53:00+03	84200.00
6A6845	2017-07-12 03:20:00+03	92000.00
6A6852	2017-08-10 23:30:00+03	7400.00
6A6874	2017-07-29 05:09:00+03	39600.00
6A6877	2017-07-15 17:39:00+03	115800.00
6A6887	2017-07-23 00:43:00+03	258000.00
6A6890	2017-06-28 13:47:00+03	57400.00
6A68B0	2017-07-06 20:02:00+03	38400.00
6A698E	2017-07-21 08:11:00+03	97600.00
6A69DD	2017-08-03 22:24:00+03	27200.00
6A6A24	2017-07-30 04:29:00+03	31400.00
6A6A3A	2017-07-01 02:34:00+03	18000.00
6A6A3E	2017-08-11 09:16:00+03	70200.00
6A6A59	2017-07-22 13:01:00+03	98000.00
6A6A7B	2017-08-12 15:37:00+03	201300.00
6A6B4A	2017-07-16 10:41:00+03	68400.00
6A6B70	2017-07-23 23:17:00+03	6800.00
6A6B87	2017-08-04 13:25:00+03	47000.00
6A6B9A	2017-06-28 23:14:00+03	98400.00
6A6C25	2017-08-04 16:49:00+03	84800.00
6A6CA9	2017-07-09 20:43:00+03	117600.00
6A6D71	2017-07-26 03:48:00+03	133100.00
6A6DB5	2017-08-06 14:32:00+03	125800.00
6A6DCD	2017-07-17 22:44:00+03	106600.00
6A6DD7	2017-08-14 07:23:00+03	67600.00
6A6E93	2017-07-10 00:51:00+03	32700.00
6A6EA3	2017-08-03 22:31:00+03	40800.00
6A6EBF	2017-07-31 00:02:00+03	39200.00
6A6EF7	2017-08-14 16:48:00+03	59400.00
6A6F55	2017-08-15 14:31:00+03	37900.00
6A6F97	2017-07-11 14:00:00+03	65200.00
6A6FA4	2017-07-05 04:58:00+03	25600.00
6A6FB1	2017-07-16 05:43:00+03	59800.00
6A702F	2017-07-04 19:37:00+03	246000.00
6A707D	2017-07-23 15:06:00+03	36400.00
6A70AE	2017-07-19 09:50:00+03	108600.00
6A70EC	2017-07-05 02:26:00+03	243700.00
6A70F8	2017-08-11 03:17:00+03	48800.00
6A7102	2017-08-06 18:00:00+03	23100.00
6A710E	2017-07-13 10:23:00+03	23200.00
6A7152	2017-07-06 09:15:00+03	45100.00
6A715B	2017-08-02 01:15:00+03	116400.00
6A71B5	2017-08-01 00:52:00+03	252200.00
6A7237	2017-07-04 15:26:00+03	48500.00
6A7269	2017-07-25 06:15:00+03	59300.00
6A72ED	2017-07-05 22:24:00+03	45200.00
6A732D	2017-07-19 17:05:00+03	45500.00
6A7333	2017-08-01 09:04:00+03	22000.00
6A7347	2017-07-25 16:04:00+03	28800.00
6A738F	2017-08-11 19:30:00+03	66600.00
6A7399	2017-08-08 10:30:00+03	38000.00
6A7402	2017-08-07 22:08:00+03	93000.00
6A7490	2017-08-01 16:34:00+03	37900.00
6A74CC	2017-07-02 07:20:00+03	29800.00
6A74CF	2017-06-30 03:56:00+03	81500.00
6A74DA	2017-07-28 14:57:00+03	116800.00
6A7533	2017-08-01 10:43:00+03	140200.00
6A7547	2017-07-26 08:48:00+03	28200.00
6A757D	2017-07-18 17:44:00+03	38800.00
6A75AB	2017-07-23 08:36:00+03	56000.00
6A75CD	2017-07-25 07:29:00+03	19600.00
6A7634	2017-07-13 00:21:00+03	72400.00
6A763D	2017-07-04 01:13:00+03	115100.00
6A7645	2017-07-26 12:06:00+03	53600.00
6A7651	2017-07-14 06:44:00+03	40800.00
6A767A	2017-06-27 10:35:00+03	124300.00
6A7693	2017-07-12 18:42:00+03	24800.00
6A76A9	2017-07-05 02:48:00+03	50600.00
6A76AF	2017-07-17 22:40:00+03	174900.00
6A76D0	2017-08-02 03:03:00+03	67800.00
6A7738	2017-06-29 08:51:00+03	49900.00
6A7739	2017-07-14 20:57:00+03	47200.00
6A775D	2017-07-19 06:22:00+03	45200.00
6A776F	2017-07-08 00:03:00+03	116000.00
6A7785	2017-07-23 09:09:00+03	52700.00
6A7797	2017-07-28 04:39:00+03	25400.00
6A77D6	2017-08-07 05:31:00+03	46400.00
6A7800	2017-07-29 06:15:00+03	21400.00
6A7812	2017-07-17 06:25:00+03	88800.00
6A7839	2017-07-11 18:09:00+03	46800.00
6A7862	2017-08-11 23:00:00+03	23200.00
6A78AA	2017-07-05 05:01:00+03	38800.00
6A7909	2017-07-11 20:23:00+03	28800.00
6A7929	2017-07-09 03:15:00+03	6000.00
6A7932	2017-07-26 20:01:00+03	67000.00
6A794C	2017-08-13 11:59:00+03	271100.00
6A797E	2017-07-22 00:01:00+03	58800.00
6A79B5	2017-08-02 12:31:00+03	35800.00
6A79E4	2017-08-06 09:15:00+03	132800.00
6A7A53	2017-07-17 00:05:00+03	40800.00
6A7ADF	2017-08-12 08:19:00+03	44800.00
6A7B14	2017-07-29 15:38:00+03	21800.00
6A7B29	2017-07-15 05:32:00+03	120700.00
6A7B44	2017-08-08 14:01:00+03	54400.00
6A7B69	2017-06-29 13:44:00+03	297700.00
6A7B8F	2017-08-11 15:02:00+03	32400.00
6A7BC3	2017-07-24 05:58:00+03	198600.00
6A7C18	2017-07-20 23:07:00+03	128800.00
6A7C8E	2017-07-04 06:13:00+03	23400.00
6A7C94	2017-07-24 19:38:00+03	48800.00
6A7C96	2017-07-23 01:06:00+03	66600.00
6A7CE8	2017-07-05 11:57:00+03	90800.00
6A7DA1	2017-08-06 19:27:00+03	54100.00
6A7DA4	2017-07-26 22:50:00+03	11600.00
6A7DC3	2017-08-09 16:30:00+03	182300.00
6A7DE0	2017-07-24 18:17:00+03	91600.00
6A7DE3	2017-07-28 12:16:00+03	206900.00
6A7DF5	2017-07-01 01:51:00+03	78200.00
6A7E1D	2017-08-11 13:05:00+03	54800.00
6A7E86	2017-08-02 09:33:00+03	94400.00
6A7ED2	2017-07-19 12:04:00+03	23200.00
6A7EF9	2017-07-14 19:59:00+03	90000.00
6A7F88	2017-07-26 18:03:00+03	10600.00
6A7FB9	2017-06-29 11:32:00+03	41600.00
6A8066	2017-08-05 10:18:00+03	92800.00
6A806A	2017-07-05 18:17:00+03	16400.00
6A808A	2017-07-15 21:59:00+03	89700.00
6A80B5	2017-07-21 07:02:00+03	44000.00
6A80D6	2017-07-13 12:12:00+03	12600.00
6A8128	2017-07-08 03:23:00+03	41400.00
6A813B	2017-08-09 21:01:00+03	28800.00
6A8186	2017-08-01 07:01:00+03	37900.00
6A8229	2017-07-17 04:46:00+03	92400.00
6A823C	2017-07-06 16:22:00+03	100600.00
6A827D	2017-08-10 12:38:00+03	56600.00
6A82C9	2017-07-06 19:46:00+03	92100.00
6A82F4	2017-08-07 08:28:00+03	147700.00
6A8305	2017-06-29 02:56:00+03	72400.00
6A8315	2017-07-07 11:06:00+03	136800.00
6A832C	2017-07-20 03:38:00+03	116000.00
6A8369	2017-07-28 09:13:00+03	28000.00
6A837F	2017-07-13 15:51:00+03	39500.00
6A84B5	2017-08-05 04:09:00+03	21800.00
6A84BA	2017-08-08 13:23:00+03	84100.00
6A84E2	2017-08-03 22:04:00+03	16400.00
6A8536	2017-08-04 22:46:00+03	37900.00
6A8572	2017-07-20 18:15:00+03	184200.00
6A858F	2017-07-11 20:45:00+03	133200.00
6A85AB	2017-08-10 12:01:00+03	43000.00
6A85E3	2017-07-03 20:57:00+03	71800.00
6A8677	2017-07-15 16:41:00+03	46400.00
6A8694	2017-08-02 06:44:00+03	18000.00
6A86A7	2017-08-08 06:58:00+03	57600.00
6A86BB	2017-07-30 06:23:00+03	77100.00
6A86BE	2017-08-03 21:14:00+03	184300.00
6A86D3	2017-07-07 05:26:00+03	55800.00
6A8733	2017-08-09 17:46:00+03	46300.00
6A8798	2017-08-07 00:23:00+03	6000.00
6A87AD	2017-07-14 20:57:00+03	11800.00
6A87D2	2017-08-05 06:23:00+03	25100.00
6A87FF	2017-07-06 06:04:00+03	23200.00
6A8816	2017-07-04 11:13:00+03	30000.00
6A8889	2017-07-28 20:43:00+03	139100.00
6A88B1	2017-08-01 06:11:00+03	28000.00
6A88B5	2017-08-14 07:16:00+03	116800.00
6A88E2	2017-07-28 09:19:00+03	114400.00
6A88F7	2017-08-15 10:27:00+03	85000.00
6A8911	2017-07-27 01:02:00+03	26000.00
6A895B	2017-08-07 20:17:00+03	113700.00
6A896E	2017-07-28 09:47:00+03	117200.00
6A8981	2017-07-25 04:58:00+03	26000.00
6A8982	2017-07-11 14:13:00+03	114300.00
6A89BF	2017-08-04 07:15:00+03	78100.00
6A8A01	2017-07-16 16:37:00+03	10600.00
6A8A65	2017-08-06 03:50:00+03	375200.00
6A8A98	2017-07-09 04:20:00+03	234800.00
6A8C00	2017-07-22 10:56:00+03	52700.00
6A8C45	2017-07-10 20:33:00+03	23200.00
6A8C8D	2017-08-15 10:27:00+03	67100.00
6A8CA1	2017-07-30 04:20:00+03	85000.00
6A8CC0	2017-08-04 08:50:00+03	26000.00
6A8CCF	2017-07-05 04:07:00+03	15000.00
6A8CD6	2017-08-12 12:03:00+03	21400.00
6A8CEF	2017-07-15 02:06:00+03	25000.00
6A8D0F	2017-07-28 05:22:00+03	88800.00
6A8E1D	2017-08-09 05:43:00+03	75100.00
6A8E3C	2017-07-07 10:12:00+03	131000.00
6A8E3E	2017-07-23 22:32:00+03	206700.00
6A8E47	2017-08-13 04:02:00+03	104600.00
6A8E6C	2017-07-27 12:25:00+03	61200.00
6A8E90	2017-08-12 15:16:00+03	28000.00
6A8EAB	2017-07-10 03:10:00+03	25000.00
6A8EAF	2017-07-31 13:41:00+03	12000.00
6A8EB9	2017-08-11 09:15:00+03	171000.00
6A8EE3	2017-07-08 21:09:00+03	55900.00
6A8F2D	2017-08-03 04:10:00+03	68800.00
6A8FA1	2017-07-18 23:16:00+03	24800.00
6A8FB5	2017-07-14 21:53:00+03	123000.00
6A8FF1	2017-08-12 03:04:00+03	37900.00
6A8FFE	2017-08-03 15:04:00+03	22400.00
6A9005	2017-08-15 07:40:00+03	24400.00
6A9026	2017-07-12 23:45:00+03	6000.00
6A9063	2017-07-18 03:09:00+03	19600.00
6A90BD	2017-07-02 02:29:00+03	52000.00
6A90C8	2017-07-25 22:45:00+03	51900.00
6A9104	2017-07-26 22:22:00+03	150300.00
6A910B	2017-07-28 23:09:00+03	40800.00
6A92F6	2017-07-18 03:14:00+03	47800.00
6A9312	2017-07-11 21:25:00+03	112000.00
6A934C	2017-07-09 13:35:00+03	47000.00
6A9353	2017-07-08 03:35:00+03	56000.00
6A93A9	2017-07-07 16:15:00+03	139200.00
6A93EE	2017-08-04 07:59:00+03	39200.00
6A946F	2017-07-06 19:37:00+03	17800.00
6A9473	2017-08-10 11:27:00+03	8200.00
6A9485	2017-08-06 05:44:00+03	54000.00
6A952B	2017-07-07 08:29:00+03	114400.00
6A956D	2017-08-15 17:51:00+03	60400.00
6A9641	2017-07-25 12:43:00+03	33300.00
6A9657	2017-07-30 21:08:00+03	20000.00
6A969B	2017-06-28 11:01:00+03	125000.00
6A96FD	2017-07-23 04:59:00+03	398600.00
6A9737	2017-07-03 03:37:00+03	86600.00
6A9748	2017-07-12 01:35:00+03	125200.00
6A975D	2017-07-29 13:01:00+03	26000.00
6A979F	2017-07-19 06:47:00+03	75600.00
6A97A8	2017-08-09 15:36:00+03	92800.00
6A97B1	2017-07-26 22:43:00+03	34200.00
6A97EC	2017-08-07 00:01:00+03	56000.00
6A9879	2017-07-22 02:33:00+03	80100.00
6A98C4	2017-07-26 16:48:00+03	92000.00
6A98DF	2017-07-06 13:25:00+03	12400.00
6A9904	2017-07-06 02:48:00+03	132800.00
6A9963	2017-06-29 05:08:00+03	42600.00
6A99EB	2017-07-04 08:08:00+03	56000.00
6A99ED	2017-08-09 20:02:00+03	70600.00
6A9A26	2017-07-22 13:16:00+03	25200.00
6A9A8B	2017-07-16 19:28:00+03	21800.00
6A9ABE	2017-08-05 13:55:00+03	65100.00
6A9AD5	2017-08-10 08:44:00+03	67000.00
6A9B8B	2017-07-20 10:53:00+03	49600.00
6A9BBD	2017-07-07 23:10:00+03	38800.00
6A9BD4	2017-08-13 01:34:00+03	174900.00
6A9C04	2017-08-12 12:09:00+03	28800.00
6A9C1A	2017-07-08 04:18:00+03	24400.00
6A9CA5	2017-07-14 11:53:00+03	272900.00
6A9D72	2017-07-13 12:39:00+03	10700.00
6A9DA9	2017-08-06 00:29:00+03	66600.00
6A9DAA	2017-07-24 23:26:00+03	59900.00
6A9E06	2017-07-13 04:21:00+03	85000.00
6A9E32	2017-07-11 06:15:00+03	276000.00
6A9E92	2017-07-24 01:45:00+03	72400.00
6A9EFC	2017-07-12 01:46:00+03	111600.00
6A9F1C	2017-07-14 16:22:00+03	369000.00
6A9F5D	2017-08-06 07:05:00+03	6000.00
6A9F85	2017-07-14 04:17:00+03	62600.00
6A9FD5	2017-07-17 03:01:00+03	32800.00
6AA00D	2017-07-05 00:17:00+03	135200.00
6AA02E	2017-08-12 06:35:00+03	19600.00
6AA05C	2017-07-21 11:28:00+03	49600.00
6AA0D4	2017-07-20 08:44:00+03	132800.00
6AA133	2017-08-13 14:39:00+03	14000.00
6AA135	2017-07-17 15:22:00+03	6000.00
6AA153	2017-07-14 09:04:00+03	26800.00
6AA1B9	2017-07-30 18:00:00+03	220800.00
6AA26E	2017-07-11 10:16:00+03	13200.00
6AA299	2017-07-18 23:47:00+03	97900.00
6AA2F0	2017-07-17 14:38:00+03	28000.00
6AA38E	2017-07-25 02:30:00+03	270800.00
6AA3F4	2017-08-10 23:24:00+03	70800.00
6AA4CE	2017-08-08 16:04:00+03	42400.00
6AA4D0	2017-08-12 23:32:00+03	86300.00
6AA4D8	2017-08-09 04:48:00+03	93900.00
6AA4D9	2017-07-16 21:20:00+03	149300.00
6AA54E	2017-07-30 16:31:00+03	146300.00
6AA55F	2017-07-02 22:46:00+03	69400.00
6AA571	2017-07-20 13:59:00+03	176800.00
6AA5DF	2017-08-09 21:44:00+03	123000.00
6AA60F	2017-07-01 11:38:00+03	55800.00
6AA634	2017-08-09 15:53:00+03	246000.00
6AA647	2017-07-20 16:29:00+03	46000.00
6AA67F	2017-07-08 20:44:00+03	114800.00
6AA688	2017-07-29 00:03:00+03	32800.00
6AA6BC	2017-07-07 02:54:00+03	109600.00
6AA6BF	2017-07-25 04:49:00+03	13400.00
6AA78C	2017-07-25 23:41:00+03	29600.00
6AA800	2017-07-21 23:53:00+03	393800.00
6AA8B9	2017-07-24 18:18:00+03	168000.00
6AA8EA	2017-07-21 21:39:00+03	14000.00
6AA8F3	2017-07-02 02:11:00+03	35200.00
6AA940	2017-07-02 02:25:00+03	15000.00
6AA989	2017-08-08 19:21:00+03	135400.00
6AA991	2017-08-07 22:08:00+03	147100.00
6AAA0B	2017-07-10 15:24:00+03	128700.00
6AAA1F	2017-07-24 03:30:00+03	248300.00
6AAA61	2017-08-02 12:42:00+03	81900.00
6AAA73	2017-07-23 02:08:00+03	112000.00
6AAACD	2017-08-06 09:00:00+03	65900.00
6AAB34	2017-07-02 21:57:00+03	23200.00
6AAB85	2017-07-16 03:56:00+03	269200.00
6AAB95	2017-08-13 01:52:00+03	28000.00
6AABB6	2017-07-06 13:31:00+03	38200.00
6AABCA	2017-08-04 02:16:00+03	132800.00
6AAC05	2017-08-03 02:40:00+03	26000.00
6AAC4B	2017-07-26 11:59:00+03	14000.00
6AAC62	2017-07-03 11:19:00+03	142300.00
6AACB4	2017-08-06 20:50:00+03	55800.00
6AAD4D	2017-07-17 10:32:00+03	47500.00
6AAD50	2017-08-04 07:20:00+03	22000.00
6AADF2	2017-07-01 17:54:00+03	7400.00
6AAE96	2017-07-14 11:58:00+03	26000.00
6AAE97	2017-08-12 12:31:00+03	26800.00
6AAED2	2017-08-08 08:31:00+03	26000.00
6AAEE2	2017-07-20 19:11:00+03	70700.00
6AAF12	2017-08-01 00:25:00+03	46200.00
6AAF13	2017-08-15 01:57:00+03	75600.00
6AAFC9	2017-07-14 11:53:00+03	29200.00
6AB06F	2017-08-08 07:02:00+03	134400.00
6AB071	2017-07-28 17:57:00+03	95200.00
6AB0BD	2017-07-25 18:23:00+03	67200.00
6AB0BF	2017-07-07 14:05:00+03	26100.00
6AB0E1	2017-07-09 19:57:00+03	38600.00
6AB0E9	2017-07-27 05:42:00+03	16400.00
6AB0FB	2017-07-17 10:26:00+03	13000.00
6AB131	2017-07-07 08:22:00+03	67200.00
6AB136	2017-07-25 12:56:00+03	54000.00
6AB1A9	2017-07-07 14:11:00+03	46400.00
6AB242	2017-07-15 11:22:00+03	14000.00
6AB258	2017-07-12 13:15:00+03	44700.00
6AB291	2017-08-06 18:50:00+03	35200.00
6AB2EC	2017-08-08 12:53:00+03	75700.00
6AB2FC	2017-06-30 13:11:00+03	28800.00
6AB317	2017-08-13 06:53:00+03	67100.00
6AB32D	2017-07-09 05:22:00+03	56100.00
6AB3BD	2017-07-24 18:38:00+03	86300.00
6AB3D3	2017-08-10 09:45:00+03	56000.00
6AB3E1	2017-07-14 10:29:00+03	59200.00
6AB419	2017-07-11 16:32:00+03	23100.00
6AB443	2017-08-12 17:11:00+03	111600.00
6AB477	2017-07-26 00:53:00+03	28000.00
6AB4B4	2017-08-03 11:39:00+03	92800.00
6AB4E8	2017-07-22 16:41:00+03	8400.00
6AB60B	2017-07-10 00:24:00+03	28300.00
6AB62F	2017-08-13 19:45:00+03	124300.00
6AB636	2017-07-15 17:49:00+03	100000.00
6AB657	2017-08-09 02:27:00+03	21800.00
6AB677	2017-07-15 05:20:00+03	81300.00
6AB69B	2017-07-24 00:23:00+03	62900.00
6AB736	2017-07-02 16:40:00+03	64400.00
6AB7AC	2017-08-08 09:15:00+03	199800.00
6AB7C6	2017-07-28 05:23:00+03	81600.00
6AB88E	2017-08-07 23:42:00+03	70400.00
6AB890	2017-08-02 23:20:00+03	16000.00
6AB8BF	2017-08-15 15:12:00+03	14900.00
6AB8E9	2017-08-13 19:32:00+03	44900.00
6AB98D	2017-08-07 22:04:00+03	39400.00
6AB9BD	2017-07-16 14:23:00+03	45200.00
6AB9CE	2017-08-12 12:14:00+03	20400.00
6AB9FF	2017-08-06 07:32:00+03	17800.00
6ABA00	2017-07-07 19:33:00+03	11700.00
6ABA1D	2017-08-13 12:33:00+03	63500.00
6ABA6F	2017-07-24 23:46:00+03	62400.00
6ABAB4	2017-07-22 04:17:00+03	46000.00
6ABBDB	2017-07-03 16:57:00+03	37900.00
6ABBF7	2017-08-08 18:11:00+03	147700.00
6ABC11	2017-07-10 05:45:00+03	265700.00
6ABC60	2017-07-23 17:04:00+03	64600.00
6ABC91	2017-07-30 22:13:00+03	58400.00
6ABCF9	2017-07-05 06:31:00+03	124200.00
6ABD05	2017-07-07 03:08:00+03	229300.00
6ABD15	2017-08-14 05:02:00+03	6700.00
6ABD19	2017-07-27 02:30:00+03	154400.00
6ABD71	2017-08-09 15:33:00+03	55400.00
6ABD78	2017-07-12 19:25:00+03	28800.00
6ABDAB	2017-07-08 02:46:00+03	46500.00
6ABE44	2017-07-01 03:02:00+03	16400.00
6ABE7D	2017-08-05 00:35:00+03	88400.00
6ABEA0	2017-07-18 18:23:00+03	13400.00
6ABEEA	2017-07-31 20:58:00+03	12600.00
6ABEEE	2017-07-08 09:06:00+03	38600.00
6ABEFA	2017-08-08 15:02:00+03	19600.00
6ABF18	2017-08-05 18:52:00+03	21200.00
6ABF6F	2017-07-19 20:54:00+03	21800.00
6ABF89	2017-07-11 13:56:00+03	160300.00
6ABFE5	2017-08-13 03:07:00+03	97700.00
6AC07B	2017-07-10 02:51:00+03	286100.00
6AC07F	2017-08-02 04:41:00+03	67200.00
6AC085	2017-07-22 07:52:00+03	58200.00
6AC0AA	2017-07-17 21:49:00+03	57700.00
6AC0BA	2017-08-10 01:14:00+03	14400.00
6AC100	2017-07-18 11:42:00+03	189700.00
6AC10F	2017-07-03 00:51:00+03	81900.00
6AC18F	2017-07-26 22:50:00+03	31600.00
6AC191	2017-07-25 14:05:00+03	6300.00
6AC1AE	2017-08-08 15:17:00+03	155300.00
6AC1F3	2017-07-22 14:01:00+03	28700.00
6AC22A	2017-06-28 11:59:00+03	179400.00
6AC24A	2017-07-06 02:37:00+03	23900.00
6AC268	2017-08-15 10:04:00+03	169900.00
6AC284	2017-07-14 07:55:00+03	60400.00
6AC2EB	2017-08-15 00:40:00+03	84300.00
6AC35B	2017-07-08 05:02:00+03	37000.00
6AC427	2017-07-21 14:55:00+03	28800.00
6AC46A	2017-07-06 19:14:00+03	28000.00
6AC512	2017-07-18 09:16:00+03	201200.00
6AC520	2017-07-20 21:45:00+03	46000.00
6AC55D	2017-07-27 07:09:00+03	32800.00
6AC5BE	2017-08-11 11:32:00+03	73500.00
6AC6A3	2017-07-31 03:50:00+03	86500.00
6AC6C6	2017-06-30 05:05:00+03	78500.00
6AC6CC	2017-07-21 15:27:00+03	28800.00
6AC704	2017-08-03 10:52:00+03	51200.00
6AC75F	2017-07-07 05:56:00+03	24400.00
6AC7B6	2017-07-13 06:33:00+03	258400.00
6AC7FB	2017-07-10 09:43:00+03	531400.00
6AC84F	2017-08-07 13:48:00+03	66400.00
6AC85D	2017-07-29 20:53:00+03	29600.00
6AC886	2017-07-14 07:19:00+03	193600.00
6AC893	2017-07-27 09:07:00+03	58000.00
6AC8AB	2017-07-10 18:51:00+03	71900.00
6AC8AD	2017-07-14 00:06:00+03	8200.00
6AC90C	2017-07-24 12:02:00+03	427100.00
6AC921	2017-08-03 05:43:00+03	73600.00
6AC929	2017-08-11 04:34:00+03	173900.00
6ACA19	2017-07-20 14:56:00+03	58200.00
6ACA67	2017-08-04 07:50:00+03	56200.00
6ACAA7	2017-08-09 07:35:00+03	132800.00
6ACB0A	2017-08-01 15:05:00+03	89500.00
6ACB71	2017-07-02 03:09:00+03	90200.00
6ACBA1	2017-07-09 11:45:00+03	27000.00
6ACBA4	2017-08-11 08:32:00+03	37200.00
6ACC93	2017-07-03 21:46:00+03	41400.00
6ACCAC	2017-07-09 03:38:00+03	52000.00
6ACCD9	2017-07-20 09:50:00+03	55500.00
6ACCFD	2017-07-26 02:07:00+03	49500.00
6ACD32	2017-08-08 13:12:00+03	22000.00
6ACDF3	2017-07-10 13:18:00+03	45000.00
6ACE01	2017-07-08 12:53:00+03	56000.00
6ACE64	2017-08-06 22:17:00+03	130900.00
6ACEE1	2017-07-22 20:07:00+03	41200.00
6ACEF7	2017-07-08 00:07:00+03	56000.00
6ACF27	2017-07-18 17:24:00+03	22000.00
6ACF2A	2017-08-06 03:23:00+03	33100.00
6ACFAD	2017-08-05 07:27:00+03	48800.00
6AD042	2017-07-28 03:34:00+03	71000.00
6AD06D	2017-08-04 01:54:00+03	56200.00
6AD08A	2017-07-07 08:25:00+03	51800.00
6AD08D	2017-07-19 23:57:00+03	40800.00
6AD0AE	2017-08-06 12:36:00+03	40000.00
6AD0B4	2017-07-28 10:11:00+03	178800.00
6AD0D5	2017-06-30 12:55:00+03	60000.00
6AD103	2017-06-29 02:43:00+03	56600.00
6AD116	2017-07-03 02:22:00+03	84300.00
6AD117	2017-07-04 00:56:00+03	56600.00
6AD193	2017-08-09 10:17:00+03	36200.00
6AD1BC	2017-07-02 21:50:00+03	113800.00
6AD1E7	2017-07-05 02:34:00+03	23600.00
6AD25D	2017-07-21 07:36:00+03	58800.00
6AD283	2017-07-20 06:45:00+03	77000.00
6AD294	2017-07-23 23:32:00+03	210200.00
6AD2E2	2017-07-10 04:39:00+03	66600.00
6AD309	2017-07-25 01:53:00+03	177600.00
6AD336	2017-07-07 18:47:00+03	46000.00
6AD369	2017-07-24 20:17:00+03	47200.00
6AD37B	2017-07-19 15:21:00+03	73300.00
6AD3C6	2017-07-23 09:01:00+03	87000.00
6AD3E3	2017-07-14 10:31:00+03	6000.00
6AD3ED	2017-08-14 19:35:00+03	132400.00
6AD3F3	2017-07-28 18:49:00+03	120000.00
6AD407	2017-07-12 16:06:00+03	22400.00
6AD41C	2017-07-21 08:00:00+03	168600.00
6AD4B8	2017-07-30 10:10:00+03	34200.00
6AD4D4	2017-07-20 20:27:00+03	27300.00
6AD524	2017-07-31 13:49:00+03	28800.00
6AD536	2017-07-16 05:18:00+03	26800.00
6AD576	2017-07-22 19:23:00+03	11000.00
6AD580	2017-07-15 01:07:00+03	89000.00
6AD586	2017-07-06 23:15:00+03	102100.00
6AD5EE	2017-07-08 08:58:00+03	70800.00
6AD601	2017-08-13 23:53:00+03	12000.00
6AD67D	2017-07-29 16:16:00+03	114800.00
6AD685	2017-07-28 16:54:00+03	27500.00
6AD6FA	2017-07-29 22:16:00+03	68100.00
6AD714	2017-08-15 10:55:00+03	46300.00
6AD81A	2017-08-01 14:05:00+03	265700.00
6AD8B2	2017-07-09 05:13:00+03	48800.00
6AD937	2017-08-02 14:20:00+03	95600.00
6AD983	2017-07-24 20:22:00+03	214900.00
6AD992	2017-07-22 11:51:00+03	41800.00
6AD9B5	2017-08-14 22:45:00+03	39100.00
6ADA64	2017-07-27 12:06:00+03	37200.00
6ADA77	2017-07-20 09:31:00+03	54400.00
6ADAE6	2017-07-17 03:05:00+03	28000.00
6ADAF2	2017-07-10 07:15:00+03	290600.00
6ADB3D	2017-07-28 15:53:00+03	22000.00
6ADB40	2017-07-18 23:44:00+03	69700.00
6ADB8E	2017-08-06 11:48:00+03	148200.00
6ADBC1	2017-07-12 00:47:00+03	229900.00
6ADBD6	2017-08-02 01:40:00+03	45400.00
6ADC21	2017-07-19 05:24:00+03	30200.00
6ADC44	2017-07-20 17:12:00+03	8200.00
6ADC5E	2017-08-12 05:14:00+03	25400.00
6ADCD9	2017-06-29 09:34:00+03	23200.00
6ADD0E	2017-08-05 22:57:00+03	42000.00
6ADDEF	2017-07-10 15:14:00+03	58700.00
6ADE76	2017-07-11 04:04:00+03	57100.00
6ADE8F	2017-07-15 14:04:00+03	35200.00
6ADF19	2017-08-08 23:06:00+03	103200.00
6ADF54	2017-07-15 19:50:00+03	14800.00
6ADF8D	2017-08-11 09:28:00+03	6700.00
6ADFB1	2017-07-28 19:04:00+03	100600.00
6ADFFB	2017-07-26 14:11:00+03	30000.00
6AE02E	2017-06-29 19:32:00+03	14400.00
6AE04C	2017-08-13 00:21:00+03	59000.00
6AE09C	2017-07-12 01:34:00+03	25800.00
6AE0D2	2017-08-06 22:20:00+03	92800.00
6AE0E0	2017-08-11 10:17:00+03	47600.00
6AE0F6	2017-07-24 05:46:00+03	130300.00
6AE119	2017-08-05 03:54:00+03	61500.00
6AE18F	2017-07-23 01:07:00+03	113000.00
6AE196	2017-08-04 18:01:00+03	53300.00
6AE19C	2017-07-05 01:38:00+03	101200.00
6AE213	2017-07-11 14:47:00+03	62600.00
6AE2C0	2017-07-10 21:55:00+03	104800.00
6AE315	2017-07-25 06:36:00+03	29600.00
6AE323	2017-07-26 16:59:00+03	113200.00
6AE32D	2017-08-14 15:21:00+03	68200.00
6AE3B0	2017-07-26 04:09:00+03	161200.00
6AE3C8	2017-07-21 18:54:00+03	90000.00
6AE4D6	2017-07-28 08:28:00+03	16800.00
6AE557	2017-08-09 17:34:00+03	92100.00
6AE562	2017-08-03 04:23:00+03	12600.00
6AE60B	2017-07-07 01:15:00+03	23200.00
6AE610	2017-08-11 13:30:00+03	12000.00
6AE668	2017-07-06 05:04:00+03	240600.00
6AE697	2017-07-01 20:37:00+03	51900.00
6AE6EA	2017-06-29 18:34:00+03	92800.00
6AE6FC	2017-08-02 07:00:00+03	92400.00
6AE768	2017-07-26 23:18:00+03	14400.00
6AE769	2017-07-26 03:13:00+03	25400.00
6AE7AE	2017-07-02 04:49:00+03	169900.00
6AE7EB	2017-07-09 01:19:00+03	46800.00
6AE7F0	2017-07-20 13:50:00+03	56000.00
6AE7FD	2017-07-01 14:10:00+03	67400.00
6AE817	2017-07-29 16:12:00+03	207200.00
6AE823	2017-08-13 14:46:00+03	21000.00
6AE867	2017-08-07 21:38:00+03	46800.00
6AE892	2017-08-03 18:54:00+03	176600.00
6AE910	2017-08-14 17:51:00+03	48800.00
6AE96D	2017-07-10 05:47:00+03	131000.00
6AE999	2017-07-10 17:22:00+03	57400.00
6AE9D8	2017-08-06 02:50:00+03	77200.00
6AEA7F	2017-08-04 23:45:00+03	58600.00
6AEB02	2017-07-19 22:43:00+03	32200.00
6AEC24	2017-08-05 08:07:00+03	28000.00
6AEC55	2017-07-19 01:49:00+03	22600.00
6AEC70	2017-06-29 11:51:00+03	34200.00
6AEC7F	2017-07-19 03:21:00+03	123000.00
6AEC9D	2017-07-08 06:03:00+03	17800.00
6AED14	2017-07-15 18:18:00+03	32800.00
6AED1D	2017-07-08 05:45:00+03	48800.00
6AED7B	2017-07-17 20:08:00+03	40800.00
6AEDA1	2017-07-14 18:14:00+03	38800.00
6AEDCD	2017-06-26 12:00:00+03	40800.00
6AEE00	2017-07-22 05:24:00+03	23600.00
6AEE19	2017-07-30 07:33:00+03	28000.00
6AEE65	2017-07-17 18:18:00+03	70800.00
6AEEAE	2017-07-17 03:41:00+03	25400.00
6AEEE7	2017-08-13 14:04:00+03	50000.00
6AEF01	2017-07-22 04:49:00+03	67600.00
6AEFDD	2017-07-11 06:14:00+03	113200.00
6AF012	2017-07-21 02:25:00+03	54800.00
6AF053	2017-08-05 04:18:00+03	42800.00
6AF081	2017-07-26 04:03:00+03	40800.00
6AF091	2017-07-06 04:05:00+03	29400.00
6AF0A0	2017-08-12 00:40:00+03	69500.00
6AF0D3	2017-07-24 04:26:00+03	57700.00
6AF0F4	2017-07-05 04:38:00+03	56100.00
6AF0F8	2017-08-12 17:37:00+03	32400.00
6AF139	2017-08-01 20:48:00+03	105100.00
6AF14C	2017-08-09 09:48:00+03	115000.00
6AF191	2017-07-27 07:14:00+03	26000.00
6AF1C8	2017-07-22 22:27:00+03	28000.00
6AF1E0	2017-08-06 12:33:00+03	6000.00
6AF21A	2017-07-29 06:11:00+03	43400.00
6AF2CF	2017-07-31 05:35:00+03	115100.00
6AF309	2017-07-13 21:07:00+03	206800.00
6AF310	2017-07-18 20:14:00+03	21400.00
6AF337	2017-06-30 12:40:00+03	101200.00
6AF3D5	2017-07-31 16:14:00+03	6600.00
6AF3E3	2017-08-09 01:35:00+03	135400.00
6AF3E6	2017-07-08 03:01:00+03	37700.00
6AF419	2017-07-05 23:23:00+03	27600.00
6AF423	2017-07-13 02:43:00+03	88900.00
6AF43D	2017-07-25 23:50:00+03	11600.00
6AF450	2017-07-19 16:13:00+03	196000.00
6AF473	2017-07-04 20:09:00+03	119600.00
6AF47E	2017-07-17 20:37:00+03	93900.00
6AF48B	2017-07-15 03:35:00+03	24300.00
6AF48C	2017-08-06 06:10:00+03	111600.00
6AF48E	2017-07-16 18:51:00+03	67000.00
6AF4C0	2017-07-19 08:50:00+03	94800.00
6AF522	2017-07-05 09:50:00+03	57300.00
6AF5B1	2017-07-30 20:25:00+03	87400.00
6AF5D7	2017-08-07 08:48:00+03	246000.00
6AF5E3	2017-08-13 00:43:00+03	210100.00
6AF5EA	2017-08-08 14:41:00+03	56000.00
6AF602	2017-07-25 05:39:00+03	56000.00
6AF670	2017-07-12 22:50:00+03	14800.00
6AF672	2017-08-12 00:04:00+03	111600.00
6AF67A	2017-07-03 08:33:00+03	29000.00
6AF69A	2017-07-13 01:11:00+03	32200.00
6AF789	2017-07-10 00:14:00+03	60700.00
6AF7D2	2017-08-07 05:26:00+03	26000.00
6AF825	2017-08-05 10:19:00+03	39700.00
6AF830	2017-08-12 13:26:00+03	40800.00
6AF833	2017-07-02 04:38:00+03	188400.00
6AF83F	2017-07-23 15:31:00+03	85000.00
6AF863	2017-07-27 16:00:00+03	65900.00
6AF884	2017-08-10 14:14:00+03	66600.00
6AF8C3	2017-07-05 16:29:00+03	35700.00
6AF924	2017-07-28 04:47:00+03	25200.00
6AF956	2017-08-04 04:42:00+03	128800.00
6AF98E	2017-08-04 00:28:00+03	11600.00
6AF993	2017-07-22 02:02:00+03	35200.00
6AF9AC	2017-08-10 02:00:00+03	56900.00
6AF9D5	2017-07-08 06:34:00+03	56900.00
6AFA4F	2017-08-14 22:35:00+03	125000.00
6AFBD1	2017-07-26 18:06:00+03	68000.00
6AFC1A	2017-07-28 07:13:00+03	136800.00
6AFC35	2017-07-19 15:32:00+03	11600.00
6AFC6A	2017-08-03 03:48:00+03	67900.00
6AFC90	2017-07-27 20:36:00+03	45200.00
6AFCC9	2017-07-11 19:20:00+03	184300.00
6AFCD0	2017-07-11 15:14:00+03	26700.00
6AFD41	2017-07-26 01:33:00+03	106800.00
6AFD93	2017-07-11 13:56:00+03	27900.00
6AFDDA	2017-07-19 04:13:00+03	73600.00
6AFDE4	2017-08-09 14:48:00+03	24400.00
6AFE7A	2017-07-12 23:06:00+03	49900.00
6AFEBD	2017-07-07 21:16:00+03	19600.00
6AFEEA	2017-08-11 09:17:00+03	242700.00
6AFF7D	2017-07-02 04:01:00+03	186900.00
6AFF90	2017-07-12 04:45:00+03	92400.00
6AFFE1	2017-08-11 20:12:00+03	137100.00
6B017D	2017-07-29 01:50:00+03	26200.00
6B01BD	2017-07-21 12:18:00+03	117200.00
6B0224	2017-07-21 21:10:00+03	36000.00
6B027F	2017-07-28 10:12:00+03	84200.00
6B02AA	2017-07-03 22:41:00+03	48100.00
6B02BC	2017-08-10 11:00:00+03	105000.00
6B02C8	2017-07-29 10:33:00+03	135200.00
6B02CE	2017-08-08 07:16:00+03	15000.00
6B035F	2017-07-25 21:38:00+03	14000.00
6B037A	2017-07-25 23:23:00+03	113600.00
6B038A	2017-07-12 00:16:00+03	24800.00
6B03E5	2017-07-09 22:49:00+03	56000.00
6B0444	2017-08-13 19:25:00+03	25000.00
6B0488	2017-07-19 19:09:00+03	66000.00
6B05A9	2017-06-26 06:54:00+03	62000.00
6B05DD	2017-08-06 22:41:00+03	25200.00
6B060A	2017-07-06 23:42:00+03	14000.00
6B063F	2017-08-02 17:04:00+03	19600.00
6B06BE	2017-07-05 04:58:00+03	363800.00
6B06D3	2017-07-05 02:03:00+03	50000.00
6B06F9	2017-07-10 03:54:00+03	23200.00
6B078B	2017-07-30 22:28:00+03	27200.00
6B0791	2017-08-10 05:41:00+03	146300.00
6B07B2	2017-07-08 08:44:00+03	26000.00
6B080F	2017-07-12 17:19:00+03	122500.00
6B08EC	2017-07-20 03:27:00+03	103000.00
6B0910	2017-07-05 14:59:00+03	29000.00
6B0A22	2017-08-10 14:39:00+03	21800.00
6B0A33	2017-06-28 01:49:00+03	52800.00
6B0A4B	2017-07-29 05:30:00+03	56000.00
6B0A7F	2017-08-09 09:28:00+03	32200.00
6B0A9F	2017-07-19 08:31:00+03	189200.00
6B0B3C	2017-07-01 15:15:00+03	23200.00
6B0BDF	2017-07-21 18:48:00+03	69100.00
6B0BF3	2017-06-29 11:31:00+03	17200.00
6B0C0B	2017-07-10 19:27:00+03	19600.00
6B0C5C	2017-08-08 15:52:00+03	55800.00
6B0CC4	2017-07-30 11:51:00+03	33600.00
6B0D17	2017-08-07 17:32:00+03	67700.00
6B0D45	2017-07-22 09:52:00+03	77900.00
6B0DA3	2017-07-17 01:12:00+03	6700.00
6B0DE0	2017-08-04 10:08:00+03	29600.00
6B0E02	2017-07-28 11:57:00+03	144000.00
6B0F65	2017-08-12 11:03:00+03	52300.00
6B0F80	2017-06-29 10:02:00+03	155300.00
6B0F85	2017-07-11 19:39:00+03	59800.00
6B0FA2	2017-07-22 08:48:00+03	259000.00
6B1008	2017-07-15 10:56:00+03	22000.00
6B1095	2017-07-08 15:31:00+03	14000.00
6B1098	2017-08-15 07:16:00+03	149100.00
6B10F7	2017-08-02 21:44:00+03	131400.00
6B10FA	2017-08-09 09:28:00+03	53000.00
6B10FE	2017-07-31 16:06:00+03	13000.00
6B1199	2017-08-07 13:56:00+03	73500.00
6B11B9	2017-07-16 14:19:00+03	75600.00
6B120D	2017-07-22 04:01:00+03	31900.00
6B1215	2017-07-27 10:59:00+03	27500.00
6B12E9	2017-07-19 18:03:00+03	136000.00
6B133A	2017-07-21 08:23:00+03	59800.00
6B1361	2017-07-26 04:52:00+03	37900.00
6B1393	2017-07-28 21:53:00+03	111600.00
6B1396	2017-07-14 07:52:00+03	93900.00
6B139E	2017-08-12 00:38:00+03	36200.00
6B13B7	2017-07-06 13:55:00+03	246000.00
6B13D8	2017-08-04 20:54:00+03	100200.00
6B13E6	2017-08-01 12:14:00+03	16400.00
6B1418	2017-07-03 13:00:00+03	88800.00
6B1420	2017-07-10 13:08:00+03	69000.00
6B1479	2017-06-27 07:11:00+03	48700.00
6B1492	2017-07-02 07:21:00+03	43200.00
6B14A1	2017-08-11 22:18:00+03	55000.00
6B14D0	2017-07-10 01:35:00+03	81300.00
6B14FB	2017-08-07 15:54:00+03	56000.00
6B1526	2017-07-28 13:39:00+03	12600.00
6B1581	2017-07-04 07:33:00+03	54800.00
6B158B	2017-07-16 07:20:00+03	116800.00
6B15F2	2017-08-13 22:06:00+03	72400.00
6B1603	2017-08-12 09:33:00+03	19600.00
6B1629	2017-08-08 00:09:00+03	185600.00
6B1637	2017-07-04 14:56:00+03	16400.00
6B1652	2017-08-13 20:07:00+03	56000.00
6B173A	2017-07-07 04:03:00+03	25600.00
6B1778	2017-08-10 01:06:00+03	42700.00
6B17C1	2017-07-18 04:43:00+03	47000.00
6B17C7	2017-08-09 23:55:00+03	96800.00
6B181D	2017-06-29 13:39:00+03	84500.00
6B1827	2017-07-24 19:52:00+03	29600.00
6B1848	2017-06-29 07:39:00+03	214700.00
6B1895	2017-07-14 12:00:00+03	59200.00
6B1898	2017-08-04 02:14:00+03	57800.00
6B18D0	2017-08-12 01:37:00+03	46400.00
6B18DC	2017-08-10 02:24:00+03	82700.00
6B18E2	2017-07-25 15:29:00+03	12600.00
6B199B	2017-07-03 18:47:00+03	201800.00
6B1A60	2017-07-21 03:28:00+03	15400.00
6B1AAA	2017-07-16 12:46:00+03	269300.00
6B1AAB	2017-07-18 13:22:00+03	77600.00
6B1B13	2017-07-26 04:05:00+03	61500.00
6B1B31	2017-08-04 04:04:00+03	13600.00
6B1C95	2017-07-23 06:04:00+03	46400.00
6B1C9B	2017-07-16 07:14:00+03	92100.00
6B1CBA	2017-08-12 01:50:00+03	135400.00
6B1CD3	2017-08-06 11:39:00+03	6000.00
6B1D36	2017-07-15 01:59:00+03	189800.00
6B1DD9	2017-08-07 08:41:00+03	88100.00
6B1EB2	2017-07-29 22:57:00+03	75300.00
6B1EBB	2017-08-15 09:58:00+03	59800.00
6B1ED2	2017-08-14 09:55:00+03	47700.00
6B1F01	2017-06-28 16:17:00+03	62600.00
6B1F28	2017-07-30 07:42:00+03	145400.00
6B1F39	2017-07-19 00:32:00+03	125200.00
6B1F6C	2017-07-11 23:39:00+03	53300.00
6B1FA4	2017-07-11 11:58:00+03	115800.00
6B1FDE	2017-07-10 22:59:00+03	36200.00
6B1FEC	2017-06-26 21:27:00+03	47600.00
6B202F	2017-08-02 14:39:00+03	87600.00
6B2044	2017-07-29 19:27:00+03	30200.00
6B208B	2017-07-09 09:00:00+03	37900.00
6B2092	2017-08-11 21:36:00+03	134700.00
6B209A	2017-08-02 02:00:00+03	12600.00
6B2124	2017-07-09 23:59:00+03	34800.00
6B2133	2017-07-04 18:39:00+03	242700.00
6B213D	2017-08-10 12:29:00+03	46400.00
6B2169	2017-07-29 02:00:00+03	50000.00
6B21C2	2017-07-16 09:38:00+03	96800.00
6B220A	2017-08-02 09:51:00+03	54800.00
6B221D	2017-07-19 16:31:00+03	29600.00
6B2276	2017-08-12 14:05:00+03	167500.00
6B227A	2017-07-12 05:10:00+03	26200.00
6B2301	2017-07-28 11:13:00+03	93500.00
6B2313	2017-07-14 15:51:00+03	39300.00
6B2375	2017-08-03 10:21:00+03	59000.00
6B2392	2017-08-02 05:50:00+03	56600.00
6B23C7	2017-07-19 18:58:00+03	406800.00
6B2444	2017-07-03 04:48:00+03	6700.00
6B244A	2017-08-11 12:55:00+03	23400.00
6B2455	2017-07-28 08:49:00+03	23200.00
6B245A	2017-06-25 16:33:00+03	29600.00
6B24A8	2017-08-04 04:35:00+03	14400.00
6B24BA	2017-08-12 19:24:00+03	49100.00
6B24DC	2017-07-25 20:26:00+03	21800.00
6B24E1	2017-07-09 18:39:00+03	83700.00
6B24E4	2017-07-01 13:04:00+03	50600.00
6B250C	2017-07-05 16:45:00+03	235200.00
6B2587	2017-07-17 21:04:00+03	73900.00
6B25C7	2017-08-09 23:18:00+03	54400.00
6B2688	2017-08-11 16:13:00+03	15000.00
6B2692	2017-07-29 02:48:00+03	36000.00
6B26D3	2017-07-10 19:57:00+03	139100.00
6B26D5	2017-07-10 11:09:00+03	7400.00
6B26FE	2017-06-29 11:52:00+03	58200.00
6B270E	2017-08-13 23:35:00+03	47100.00
6B2727	2017-07-04 04:00:00+03	199600.00
6B27A8	2017-07-07 15:17:00+03	24800.00
6B27AC	2017-07-16 13:06:00+03	6000.00
6B27DE	2017-07-07 19:10:00+03	557300.00
6B2813	2017-07-13 19:14:00+03	60400.00
6B2827	2017-06-29 11:09:00+03	133200.00
6B2930	2017-07-28 08:30:00+03	16000.00
6B2942	2017-07-12 05:16:00+03	11700.00
6B29B2	2017-07-22 12:11:00+03	46300.00
6B29BD	2017-07-29 20:53:00+03	37100.00
6B29D3	2017-07-14 10:45:00+03	124200.00
6B29DE	2017-07-31 11:10:00+03	36200.00
6B29E8	2017-07-11 03:36:00+03	25100.00
6B2A05	2017-08-04 08:14:00+03	32500.00
6B2A7E	2017-08-12 01:35:00+03	22000.00
6B2B69	2017-08-11 21:08:00+03	25400.00
6B2BA1	2017-07-23 08:42:00+03	91100.00
6B2BA7	2017-07-19 22:26:00+03	137900.00
6B2BAE	2017-08-02 22:34:00+03	22000.00
6B2BB5	2017-08-06 07:25:00+03	46400.00
6B2BD3	2017-07-09 19:42:00+03	65900.00
6B2C06	2017-07-21 15:45:00+03	29600.00
6B2C09	2017-07-26 04:30:00+03	49400.00
6B2C43	2017-06-27 12:21:00+03	55800.00
6B2C52	2017-06-30 22:41:00+03	23600.00
6B2CA6	2017-07-08 01:26:00+03	6000.00
6B2CAB	2017-07-30 21:24:00+03	86300.00
6B2CE6	2017-07-01 13:13:00+03	113600.00
6B2D48	2017-07-08 11:14:00+03	260900.00
6B2D8E	2017-07-14 04:01:00+03	99900.00
6B2D9A	2017-07-16 18:30:00+03	62600.00
6B2DB8	2017-07-22 21:00:00+03	46400.00
6B2DBF	2017-07-28 14:15:00+03	185000.00
6B2DE2	2017-08-13 03:19:00+03	128000.00
6B2E0C	2017-07-14 10:49:00+03	62600.00
6B2E32	2017-07-19 11:45:00+03	16400.00
6B2EE7	2017-08-09 12:39:00+03	99300.00
6B2F03	2017-07-09 21:01:00+03	28800.00
6B2F31	2017-07-28 13:48:00+03	32200.00
6B2FE7	2017-07-27 08:25:00+03	38500.00
6B304D	2017-08-12 11:31:00+03	23200.00
6B3059	2017-07-19 23:33:00+03	71100.00
6B3180	2017-08-14 18:52:00+03	56000.00
6B3185	2017-08-13 10:58:00+03	133200.00
6B319D	2017-07-22 06:32:00+03	109900.00
6B3210	2017-07-22 09:21:00+03	44000.00
6B3223	2017-08-12 11:21:00+03	265600.00
6B3226	2017-08-02 21:37:00+03	55800.00
6B3231	2017-07-22 15:17:00+03	21800.00
6B324C	2017-07-29 18:25:00+03	35300.00
6B3264	2017-07-26 07:08:00+03	36400.00
6B32D3	2017-07-18 16:36:00+03	61500.00
6B333E	2017-07-07 02:26:00+03	114200.00
6B3363	2017-08-09 09:25:00+03	67700.00
6B3367	2017-07-07 08:27:00+03	23400.00
6B336B	2017-08-12 16:24:00+03	65200.00
6B3392	2017-07-01 16:03:00+03	6300.00
6B339F	2017-07-03 08:17:00+03	13300.00
6B33CB	2017-07-05 21:05:00+03	59800.00
6B3409	2017-07-25 10:50:00+03	61800.00
6B3434	2017-07-22 06:37:00+03	135000.00
6B34E0	2017-06-30 11:32:00+03	155700.00
6B34F6	2017-06-26 07:22:00+03	23200.00
6B351D	2017-08-03 22:35:00+03	65600.00
6B359C	2017-08-03 21:01:00+03	137600.00
6B35FD	2017-07-09 14:31:00+03	31600.00
6B367B	2017-07-28 22:50:00+03	20600.00
6B369B	2017-07-08 12:31:00+03	55800.00
6B369C	2017-07-08 06:02:00+03	12600.00
6B36F0	2017-06-27 15:13:00+03	93600.00
6B36F1	2017-08-13 03:13:00+03	71200.00
6B371B	2017-07-15 12:25:00+03	393000.00
6B37B2	2017-07-23 10:00:00+03	26100.00
6B3848	2017-06-29 17:14:00+03	111600.00
6B3874	2017-07-14 10:36:00+03	28000.00
6B3877	2017-07-15 23:22:00+03	6000.00
6B38A3	2017-07-30 23:34:00+03	12000.00
6B38B0	2017-07-04 16:45:00+03	16400.00
6B392D	2017-08-08 05:05:00+03	133100.00
6B3943	2017-07-25 14:41:00+03	100900.00
6B394B	2017-08-11 15:09:00+03	116000.00
6B3998	2017-07-23 08:24:00+03	40800.00
6B39AF	2017-07-14 20:13:00+03	30200.00
6B39DB	2017-07-10 22:57:00+03	20600.00
6B3A94	2017-07-05 14:45:00+03	23200.00
6B3A9E	2017-07-04 14:35:00+03	238300.00
6B3B4B	2017-07-16 05:34:00+03	77000.00
6B3B6B	2017-07-01 06:06:00+03	28000.00
6B3C46	2017-08-06 18:06:00+03	23200.00
6B3C62	2017-07-27 15:39:00+03	27200.00
6B3C65	2017-07-08 16:34:00+03	44800.00
6B3D09	2017-08-02 20:15:00+03	89700.00
6B3D0B	2017-07-21 18:34:00+03	101900.00
6B3D1A	2017-07-29 04:15:00+03	49100.00
6B3D54	2017-07-06 18:38:00+03	86300.00
6B3D56	2017-07-21 03:46:00+03	73600.00
6B3DAD	2017-08-07 12:25:00+03	166000.00
6B3DDF	2017-07-04 14:33:00+03	12600.00
6B3DE1	2017-07-14 14:13:00+03	246000.00
6B3E69	2017-07-21 10:36:00+03	7400.00
6B3E9C	2017-07-29 17:18:00+03	67700.00
6B3EEF	2017-07-25 02:56:00+03	12400.00
6B3EF8	2017-07-21 02:08:00+03	32700.00
6B3F1C	2017-07-10 20:06:00+03	37700.00
6B3F7A	2017-07-22 09:05:00+03	46300.00
6B3F82	2017-07-12 08:10:00+03	4000.00
6B3F84	2017-07-04 15:21:00+03	258000.00
6B3F90	2017-07-17 11:23:00+03	240600.00
6B3FC3	2017-08-02 17:05:00+03	73100.00
6B4032	2017-07-21 14:43:00+03	67300.00
6B4044	2017-07-13 12:06:00+03	147900.00
6B4093	2017-07-18 06:36:00+03	112000.00
6B409C	2017-08-03 02:48:00+03	26800.00
6B40C3	2017-07-19 23:48:00+03	56600.00
6B410C	2017-07-11 00:58:00+03	46700.00
6B416B	2017-07-28 13:54:00+03	25000.00
6B41BD	2017-07-29 01:17:00+03	135000.00
6B41C0	2017-07-16 14:01:00+03	23600.00
6B4200	2017-07-12 15:02:00+03	32200.00
6B423E	2017-08-07 15:20:00+03	135600.00
6B426D	2017-07-29 09:30:00+03	117600.00
6B428B	2017-08-10 17:07:00+03	145500.00
6B42A5	2017-07-23 02:30:00+03	66600.00
6B42B7	2017-07-21 12:35:00+03	113800.00
6B4340	2017-07-19 16:41:00+03	22000.00
6B4347	2017-07-21 13:51:00+03	20600.00
6B4390	2017-07-09 14:00:00+03	63200.00
6B439C	2017-08-13 06:25:00+03	26800.00
6B43B2	2017-07-03 21:08:00+03	132400.00
6B43C0	2017-07-02 06:02:00+03	44600.00
6B43CD	2017-07-28 08:32:00+03	23400.00
6B4431	2017-07-23 01:46:00+03	32800.00
6B444C	2017-07-28 09:24:00+03	246000.00
6B44AB	2017-07-22 02:53:00+03	26000.00
6B44AD	2017-08-11 03:00:00+03	58000.00
6B44F2	2017-07-01 20:37:00+03	88300.00
6B44F3	2017-07-29 15:33:00+03	65900.00
6B44F6	2017-08-02 00:18:00+03	55800.00
6B450F	2017-07-13 22:13:00+03	92600.00
6B4513	2017-08-15 07:52:00+03	179200.00
6B4519	2017-07-25 23:43:00+03	62900.00
6B4542	2017-07-10 06:21:00+03	116400.00
6B4581	2017-08-05 03:27:00+03	17000.00
6B458F	2017-07-08 00:15:00+03	55800.00
6B4631	2017-08-04 23:52:00+03	109000.00
6B4691	2017-08-03 17:29:00+03	40800.00
6B46A2	2017-07-01 01:58:00+03	86200.00
6B46C5	2017-08-07 14:03:00+03	168300.00
6B4726	2017-07-16 06:36:00+03	164400.00
6B47BB	2017-06-30 10:42:00+03	16400.00
6B47EF	2017-07-10 19:30:00+03	61100.00
6B4819	2017-07-20 18:55:00+03	398600.00
6B4831	2017-08-04 10:07:00+03	25600.00
6B486D	2017-08-01 03:01:00+03	41600.00
6B4873	2017-08-10 21:06:00+03	28000.00
6B48E7	2017-07-24 21:20:00+03	202400.00
6B4908	2017-08-05 22:18:00+03	135000.00
6B4980	2017-08-14 07:50:00+03	23600.00
6B4987	2017-08-13 15:09:00+03	26700.00
6B498E	2017-07-01 16:55:00+03	24300.00
6B4992	2017-07-14 17:34:00+03	113200.00
6B499F	2017-07-10 22:08:00+03	28000.00
6B49BE	2017-07-18 15:04:00+03	29400.00
6B4A6D	2017-07-04 08:33:00+03	18600.00
6B4AA7	2017-07-12 00:41:00+03	55800.00
6B4AC1	2017-07-15 13:21:00+03	39100.00
6B4B37	2017-07-25 05:15:00+03	30000.00
6B4B95	2017-07-05 13:13:00+03	26000.00
6B4BCF	2017-08-05 08:10:00+03	114500.00
6B4C55	2017-07-14 19:41:00+03	81500.00
6B4CAE	2017-08-03 01:03:00+03	122800.00
6B4CEF	2017-06-30 03:38:00+03	16000.00
6B4D29	2017-07-15 01:17:00+03	6000.00
6B4E48	2017-06-30 05:58:00+03	28600.00
6B4E5B	2017-08-12 02:44:00+03	94000.00
6B4E69	2017-07-08 21:08:00+03	28800.00
6B4EB1	2017-08-07 22:59:00+03	30000.00
6B4F0F	2017-08-05 12:37:00+03	30000.00
6B4F37	2017-08-04 02:34:00+03	31600.00
6B4F4E	2017-08-03 08:52:00+03	48500.00
6B4FC6	2017-08-11 07:36:00+03	18600.00
6B5014	2017-08-03 15:05:00+03	32200.00
6B5047	2017-07-31 18:34:00+03	92000.00
6B507A	2017-07-25 06:38:00+03	65100.00
6B50CD	2017-07-01 10:26:00+03	55800.00
6B510B	2017-07-19 05:53:00+03	49600.00
6B51C1	2017-07-24 08:28:00+03	54800.00
6B5224	2017-07-08 09:37:00+03	433100.00
6B52E1	2017-08-15 05:08:00+03	111600.00
6B5307	2017-07-03 20:11:00+03	38800.00
6B5341	2017-07-30 08:41:00+03	38800.00
6B534C	2017-07-21 04:57:00+03	67000.00
6B5370	2017-07-24 18:01:00+03	344100.00
6B5374	2017-07-28 08:34:00+03	69600.00
6B537D	2017-07-08 17:42:00+03	14000.00
6B53A0	2017-07-08 20:48:00+03	23200.00
6B53C7	2017-07-10 08:33:00+03	39600.00
6B53C8	2017-07-31 22:23:00+03	178800.00
6B53D7	2017-08-12 17:51:00+03	45100.00
6B5405	2017-07-27 00:31:00+03	49100.00
6B5407	2017-08-01 23:47:00+03	56100.00
6B5461	2017-07-03 06:10:00+03	25900.00
6B5472	2017-07-24 20:36:00+03	30200.00
6B5490	2017-07-18 15:33:00+03	64700.00
6B552D	2017-07-25 19:02:00+03	62800.00
6B5547	2017-08-15 03:59:00+03	21200.00
6B5670	2017-08-12 16:51:00+03	75300.00
6B56A5	2017-07-15 22:16:00+03	117000.00
6B56C5	2017-08-04 06:44:00+03	129200.00
6B5714	2017-08-02 07:32:00+03	18000.00
6B5722	2017-07-13 15:55:00+03	42000.00
6B5723	2017-07-22 07:45:00+03	16400.00
6B5757	2017-07-28 00:37:00+03	34000.00
6B5777	2017-07-11 15:55:00+03	24000.00
6B5778	2017-06-28 18:28:00+03	179400.00
6B581D	2017-08-13 01:44:00+03	277800.00
6B583B	2017-07-06 23:46:00+03	87200.00
6B5849	2017-07-05 21:19:00+03	228700.00
6B586F	2017-08-11 02:35:00+03	28800.00
6B58AB	2017-07-09 15:28:00+03	285000.00
6B5913	2017-08-06 18:26:00+03	6700.00
6B597B	2017-07-01 21:28:00+03	47100.00
6B598C	2017-07-23 00:14:00+03	188000.00
6B59F4	2017-07-30 10:48:00+03	19600.00
6B5A04	2017-07-30 11:09:00+03	6000.00
6B5A0F	2017-07-27 20:41:00+03	40800.00
6B5A2F	2017-07-20 07:09:00+03	161900.00
6B5ABC	2017-08-15 16:04:00+03	90000.00
6B5B25	2017-08-09 04:39:00+03	70800.00
6B5B41	2017-08-07 09:12:00+03	246000.00
6B5B8C	2017-07-23 00:33:00+03	68800.00
6B5C29	2017-07-28 15:36:00+03	164600.00
6B5C2E	2017-07-15 23:32:00+03	113200.00
6B5C5A	2017-08-15 12:46:00+03	86600.00
6B5D45	2017-08-07 19:42:00+03	16400.00
6B5DE7	2017-07-28 07:24:00+03	72400.00
6B5DE9	2017-07-06 21:21:00+03	46900.00
6B5DF9	2017-07-30 06:42:00+03	45200.00
6B5E24	2017-07-28 03:41:00+03	283100.00
6B5E60	2017-08-05 23:28:00+03	11000.00
6B5E6B	2017-07-01 04:38:00+03	55800.00
6B5E98	2017-08-04 14:33:00+03	13600.00
6B5EF0	2017-08-11 02:17:00+03	270800.00
6B5F1D	2017-08-05 06:36:00+03	50200.00
6B5F59	2017-07-15 11:00:00+03	29400.00
6B5F60	2017-08-01 04:19:00+03	52000.00
6B5F9C	2017-07-29 18:15:00+03	33100.00
6B6042	2017-07-25 07:49:00+03	240600.00
6B6044	2017-08-03 09:03:00+03	43500.00
6B6085	2017-07-17 18:59:00+03	146300.00
6B6170	2017-08-13 23:46:00+03	26600.00
6B6186	2017-07-16 01:52:00+03	132800.00
6B61B0	2017-07-08 22:31:00+03	35600.00
6B61F8	2017-07-15 03:49:00+03	106200.00
6B6202	2017-08-02 13:01:00+03	80000.00
6B6293	2017-07-31 13:14:00+03	7400.00
6B6299	2017-07-20 17:28:00+03	56000.00
6B629D	2017-07-22 23:31:00+03	196800.00
6B62D8	2017-08-05 05:59:00+03	46400.00
6B63D1	2017-08-09 15:27:00+03	119700.00
6B6453	2017-07-08 04:22:00+03	64500.00
6B6489	2017-07-24 05:52:00+03	21400.00
6B6522	2017-08-12 18:01:00+03	35200.00
6B6529	2017-07-26 19:53:00+03	141100.00
6B65AC	2017-07-16 01:24:00+03	89600.00
6B65CB	2017-07-07 07:17:00+03	67700.00
6B65E7	2017-08-12 14:57:00+03	12000.00
6B6627	2017-07-12 01:09:00+03	12600.00
6B6630	2017-07-17 03:08:00+03	45200.00
6B6666	2017-07-12 15:50:00+03	398500.00
6B6669	2017-08-10 15:23:00+03	24400.00
6B66BD	2017-07-31 18:44:00+03	55800.00
6B6707	2017-07-26 14:30:00+03	54700.00
6B67A6	2017-07-06 07:12:00+03	124200.00
6B686E	2017-07-18 19:51:00+03	187900.00
6B68AE	2017-07-16 10:49:00+03	38600.00
6B68EE	2017-07-13 07:58:00+03	29400.00
6B694B	2017-07-15 03:01:00+03	13600.00
6B6953	2017-08-04 07:53:00+03	34600.00
6B69C6	2017-08-12 10:52:00+03	58800.00
6B69E0	2017-08-14 04:56:00+03	68800.00
6B69FB	2017-08-08 09:03:00+03	98400.00
6B6A31	2017-08-10 06:27:00+03	43600.00
6B6A59	2017-08-13 16:17:00+03	18600.00
6B6A8B	2017-07-15 02:55:00+03	112600.00
6B6AC2	2017-07-26 13:40:00+03	29600.00
6B6B40	2017-07-13 21:51:00+03	56900.00
6B6B4D	2017-07-16 18:54:00+03	65900.00
6B6B62	2017-07-05 04:47:00+03	59300.00
6B6B64	2017-07-21 12:08:00+03	102600.00
6B6B86	2017-07-15 21:01:00+03	66600.00
6B6BFC	2017-07-13 18:35:00+03	167400.00
6B6C0A	2017-07-16 19:47:00+03	182000.00
6B6C53	2017-07-27 10:12:00+03	46000.00
6B6C73	2017-07-29 10:38:00+03	131100.00
6B6C8D	2017-07-22 06:05:00+03	131600.00
6B6CC8	2017-08-04 11:34:00+03	55800.00
6B6D4E	2017-07-08 06:10:00+03	65500.00
6B6D53	2017-07-31 15:16:00+03	173900.00
6B6D6E	2017-08-12 04:41:00+03	56600.00
6B6DF7	2017-07-26 02:02:00+03	96800.00
6B6E4B	2017-07-24 13:36:00+03	35200.00
6B6E65	2017-08-02 02:37:00+03	11600.00
6B6EF7	2017-08-15 16:02:00+03	266400.00
6B6F14	2017-08-06 13:35:00+03	125200.00
6B6FBA	2017-07-21 06:54:00+03	130400.00
6B704A	2017-07-30 07:18:00+03	6900.00
6B7072	2017-07-10 13:34:00+03	44000.00
6B7123	2017-08-13 02:04:00+03	75300.00
6B7144	2017-07-29 07:23:00+03	109400.00
6B7193	2017-07-19 17:37:00+03	13400.00
6B71EB	2017-08-10 15:30:00+03	107700.00
6B71F6	2017-08-05 08:42:00+03	31000.00
6B720B	2017-08-02 17:25:00+03	56600.00
6B7232	2017-08-11 02:51:00+03	18900.00
6B7236	2017-08-14 00:32:00+03	304200.00
6B7260	2017-07-06 23:28:00+03	270700.00
6B7270	2017-07-21 22:27:00+03	149600.00
6B7273	2017-07-29 10:32:00+03	22000.00
6B727F	2017-07-12 23:14:00+03	81700.00
6B7294	2017-07-21 00:27:00+03	32800.00
6B72CE	2017-08-03 19:52:00+03	202100.00
6B7377	2017-08-03 03:04:00+03	42700.00
6B73AB	2017-07-04 10:31:00+03	65900.00
6B73BE	2017-07-22 04:54:00+03	55800.00
6B73EA	2017-08-11 11:26:00+03	35300.00
6B73F6	2017-08-04 01:35:00+03	48700.00
6B7435	2017-07-06 13:52:00+03	27200.00
6B7438	2017-07-16 03:47:00+03	48800.00
6B746F	2017-07-16 05:53:00+03	364600.00
6B7477	2017-07-04 06:29:00+03	56000.00
6B749D	2017-08-01 04:45:00+03	23400.00
6B757C	2017-07-02 02:34:00+03	47500.00
6B75E0	2017-07-05 02:12:00+03	23200.00
6B7662	2017-07-12 08:54:00+03	59800.00
6B7698	2017-07-27 14:22:00+03	52000.00
6B76A1	2017-08-02 07:28:00+03	26000.00
6B76BE	2017-07-20 00:14:00+03	154400.00
6B76C8	2017-08-09 07:27:00+03	67600.00
6B76E4	2017-08-12 19:28:00+03	62800.00
6B7701	2017-08-06 12:30:00+03	20000.00
6B7714	2017-07-05 21:29:00+03	105000.00
6B7726	2017-08-14 15:12:00+03	26700.00
6B7755	2017-07-03 04:55:00+03	88200.00
6B7786	2017-07-08 22:32:00+03	239200.00
6B7798	2017-08-04 05:56:00+03	57600.00
6B77AC	2017-06-28 23:52:00+03	33600.00
6B77DB	2017-08-13 08:39:00+03	33300.00
6B77FA	2017-07-05 23:25:00+03	28800.00
6B783B	2017-07-31 04:42:00+03	27200.00
6B78A2	2017-08-04 20:03:00+03	43700.00
6B7946	2017-08-04 18:46:00+03	65600.00
6B7960	2017-08-04 16:39:00+03	139300.00
6B7967	2017-07-10 06:35:00+03	36200.00
6B7A8E	2017-07-18 02:30:00+03	37900.00
6B7BCC	2017-08-06 21:44:00+03	119600.00
6B7BCE	2017-08-06 20:57:00+03	93700.00
6B7BF4	2017-07-16 19:52:00+03	73600.00
6B7C35	2017-07-31 09:27:00+03	42400.00
6B7C4F	2017-07-02 06:19:00+03	92400.00
6B7C98	2017-07-07 03:35:00+03	89600.00
6B7CA3	2017-08-02 21:27:00+03	40800.00
6B7CA6	2017-07-07 08:47:00+03	57500.00
6B7CBF	2017-08-14 01:48:00+03	13200.00
6B7D1D	2017-07-02 08:24:00+03	48800.00
6B7D9E	2017-07-20 18:24:00+03	28000.00
6B7DB9	2017-07-11 21:11:00+03	16400.00
6B7DE5	2017-07-21 16:25:00+03	52400.00
6B7E38	2017-07-22 05:50:00+03	26000.00
6B7ECA	2017-08-06 10:37:00+03	56000.00
6B7EE1	2017-08-01 07:26:00+03	114700.00
6B7EE3	2017-07-03 23:39:00+03	58600.00
6B7F1A	2017-07-15 22:12:00+03	114600.00
6B7F1D	2017-07-08 22:20:00+03	6800.00
6B7F97	2017-07-20 11:33:00+03	55800.00
6B7FAF	2017-07-26 11:05:00+03	52000.00
6B8012	2017-08-10 19:39:00+03	166400.00
6B80E4	2017-07-28 14:38:00+03	117600.00
6B80EB	2017-07-11 13:42:00+03	67000.00
6B8104	2017-07-16 09:30:00+03	50600.00
6B811E	2017-08-08 16:53:00+03	28800.00
6B81AF	2017-07-25 18:50:00+03	172600.00
6B8234	2017-08-03 15:31:00+03	24400.00
6B828F	2017-08-11 22:17:00+03	123000.00
6B82C8	2017-07-11 03:35:00+03	25000.00
6B8337	2017-07-22 12:27:00+03	23400.00
6B83B9	2017-07-09 00:29:00+03	22000.00
6B83DA	2017-08-15 17:03:00+03	18900.00
6B83E0	2017-07-08 03:11:00+03	74400.00
6B844A	2017-08-07 13:40:00+03	270400.00
6B844E	2017-07-11 12:36:00+03	37700.00
6B847C	2017-07-08 12:52:00+03	67700.00
6B84BD	2017-08-05 14:35:00+03	192400.00
6B84C7	2017-07-21 18:48:00+03	83000.00
6B84D7	2017-08-15 08:59:00+03	57500.00
6B84DE	2017-07-26 06:04:00+03	46500.00
6B84F8	2017-08-10 00:10:00+03	160700.00
6B84FC	2017-07-10 18:09:00+03	28000.00
6B8549	2017-07-01 07:56:00+03	90400.00
6B8598	2017-08-07 02:58:00+03	124200.00
6B85A6	2017-07-17 09:51:00+03	56000.00
6B862F	2017-07-25 17:59:00+03	26000.00
6B8670	2017-08-06 20:53:00+03	69000.00
6B8681	2017-06-30 22:40:00+03	26800.00
6B86DD	2017-07-03 15:31:00+03	73100.00
6B872F	2017-07-09 15:54:00+03	56000.00
6B876D	2017-07-11 08:59:00+03	75300.00
6B8774	2017-08-07 15:42:00+03	199700.00
6B879F	2017-08-02 21:29:00+03	40700.00
6B8802	2017-07-05 19:55:00+03	48300.00
6B88A9	2017-08-12 01:17:00+03	24800.00
6B88FE	2017-07-04 02:30:00+03	85700.00
6B8912	2017-08-04 04:59:00+03	133100.00
6B891A	2017-07-07 12:24:00+03	54800.00
6B8A0D	2017-07-13 09:55:00+03	46200.00
6B8A21	2017-08-02 19:00:00+03	111600.00
6B8A43	2017-08-11 06:16:00+03	17200.00
6B8AB7	2017-08-13 00:49:00+03	50800.00
6B8AFD	2017-07-31 11:13:00+03	20600.00
6B8B8D	2017-08-12 23:45:00+03	19900.00
6B8BBD	2017-07-09 04:26:00+03	24400.00
6B8BD7	2017-07-03 12:12:00+03	34000.00
6B8C14	2017-08-09 08:46:00+03	27200.00
6B8C77	2017-08-13 21:30:00+03	39100.00
6B8C97	2017-07-04 16:53:00+03	94000.00
6B8CAD	2017-08-09 22:44:00+03	133200.00
6B8CEB	2017-07-18 14:12:00+03	28000.00
6B8D48	2017-07-22 02:02:00+03	64200.00
6B8D54	2017-08-05 06:44:00+03	134400.00
6B8D8F	2017-08-01 10:24:00+03	46500.00
6B8DA4	2017-07-10 05:00:00+03	47300.00
6B8DC0	2017-08-07 19:28:00+03	48500.00
6B8E36	2017-07-25 23:42:00+03	272400.00
6B8E48	2017-08-08 22:48:00+03	109400.00
6B8ED6	2017-07-20 15:23:00+03	60400.00
6B8EDC	2017-08-06 14:23:00+03	36200.00
6B8F0D	2017-07-02 01:44:00+03	258400.00
6B8F35	2017-07-14 10:05:00+03	260900.00
6B8F77	2017-07-04 05:12:00+03	272300.00
6B8FDE	2017-07-19 06:51:00+03	27800.00
6B9012	2017-08-06 17:27:00+03	135400.00
6B919A	2017-07-22 23:24:00+03	122700.00
6B9231	2017-08-06 07:24:00+03	55800.00
6B924B	2017-08-01 02:05:00+03	417800.00
6B927D	2017-08-10 08:41:00+03	14000.00
6B92EE	2017-08-09 09:52:00+03	11200.00
6B92F8	2017-08-04 08:16:00+03	46400.00
6B9321	2017-07-26 01:09:00+03	58800.00
6B935A	2017-07-12 17:47:00+03	14400.00
6B9381	2017-07-09 04:25:00+03	111600.00
6B938E	2017-07-10 06:17:00+03	58000.00
6B93DA	2017-07-09 02:56:00+03	39200.00
6B9409	2017-08-09 03:46:00+03	85700.00
6B9410	2017-07-19 00:52:00+03	56000.00
6B9411	2017-07-08 06:25:00+03	30000.00
6B9418	2017-07-07 02:19:00+03	23600.00
6B945E	2017-08-10 03:16:00+03	38600.00
6B9460	2017-07-28 01:06:00+03	32800.00
6B949D	2017-07-05 11:54:00+03	135400.00
6B94EF	2017-08-07 03:56:00+03	58400.00
6B94FD	2017-07-09 04:28:00+03	189800.00
6B954B	2017-07-07 14:03:00+03	229900.00
6B95F8	2017-07-11 00:51:00+03	166100.00
6B9648	2017-07-30 16:27:00+03	12600.00
6B9686	2017-08-02 22:12:00+03	56900.00
6B96DC	2017-07-17 08:09:00+03	115100.00
6B96E5	2017-06-27 23:28:00+03	14000.00
6B977D	2017-07-20 03:44:00+03	50800.00
6B97C1	2017-07-20 23:07:00+03	81300.00
6B987E	2017-07-06 19:15:00+03	62600.00
6B9898	2017-06-29 16:46:00+03	73600.00
6B98B0	2017-06-27 16:19:00+03	149300.00
6B991C	2017-07-10 00:16:00+03	185600.00
6B9963	2017-07-16 20:50:00+03	30400.00
6B9967	2017-08-14 10:03:00+03	53200.00
6B997F	2017-07-02 05:08:00+03	75800.00
6B999C	2017-07-07 01:38:00+03	123000.00
6B9A09	2017-08-12 20:38:00+03	18000.00
6B9A45	2017-07-13 18:21:00+03	67100.00
6B9AD4	2017-07-27 10:32:00+03	65400.00
6B9AFA	2017-08-13 08:19:00+03	29300.00
6B9B69	2017-07-24 19:26:00+03	125400.00
6B9BAC	2017-08-10 13:48:00+03	55800.00
6B9BB4	2017-08-02 07:29:00+03	265700.00
6B9BF0	2017-08-14 15:51:00+03	24000.00
6B9C4B	2017-07-07 06:55:00+03	49100.00
6B9C94	2017-08-12 00:32:00+03	66600.00
6B9C9C	2017-07-14 07:02:00+03	131100.00
6B9CA1	2017-07-17 17:52:00+03	55800.00
6B9CB8	2017-07-02 02:34:00+03	110300.00
6B9CE1	2017-07-17 22:04:00+03	139700.00
6B9D44	2017-08-02 02:33:00+03	33800.00
6B9E39	2017-08-14 04:39:00+03	101200.00
6B9EB3	2017-07-31 01:16:00+03	65200.00
6B9ED0	2017-07-30 23:33:00+03	16400.00
6B9EE5	2017-08-13 17:11:00+03	61500.00
6B9EF4	2017-07-06 07:52:00+03	31600.00
6B9F17	2017-07-12 01:04:00+03	32200.00
6BA013	2017-08-09 16:59:00+03	23200.00
6BA067	2017-07-16 10:19:00+03	112100.00
6BA07D	2017-06-28 11:37:00+03	92000.00
6BA0A3	2017-07-14 03:03:00+03	16400.00
6BA131	2017-08-13 20:22:00+03	150600.00
6BA16F	2017-07-24 05:34:00+03	54300.00
6BA179	2017-07-27 05:35:00+03	28700.00
6BA1C7	2017-08-13 01:39:00+03	95200.00
6BA21C	2017-08-14 06:34:00+03	18900.00
6BA24D	2017-08-01 21:15:00+03	36200.00
6BA250	2017-07-10 06:36:00+03	68600.00
6BA277	2017-08-05 02:04:00+03	25400.00
6BA2B9	2017-07-10 22:55:00+03	46000.00
6BA2BF	2017-08-03 08:13:00+03	23400.00
6BA2D3	2017-07-31 23:29:00+03	135400.00
6BA2D8	2017-08-03 14:16:00+03	61800.00
6BA2F6	2017-07-07 01:58:00+03	46800.00
6BA315	2017-07-15 04:43:00+03	16800.00
6BA323	2017-08-03 23:56:00+03	25200.00
6BA3B4	2017-07-12 09:53:00+03	29600.00
6BA3C1	2017-07-08 00:14:00+03	108000.00
6BA416	2017-08-13 13:37:00+03	46000.00
6BA448	2017-07-29 04:34:00+03	70800.00
6BA469	2017-08-03 21:20:00+03	36200.00
6BA483	2017-07-02 13:18:00+03	189200.00
6BA493	2017-08-05 17:23:00+03	31800.00
6BA4BE	2017-07-06 02:02:00+03	46800.00
6BA4CD	2017-08-02 00:38:00+03	85000.00
6BA4E6	2017-08-06 10:08:00+03	280400.00
6BA562	2017-07-07 19:31:00+03	23200.00
6BA5F0	2017-08-13 19:39:00+03	148200.00
6BA5F3	2017-07-09 06:52:00+03	24800.00
6BA62E	2017-07-26 14:37:00+03	98200.00
6BA63F	2017-07-14 02:27:00+03	78200.00
6BA690	2017-06-29 05:56:00+03	85000.00
6BA6BA	2017-07-19 03:01:00+03	12600.00
6BA6C6	2017-07-15 10:12:00+03	37900.00
6BA6C9	2017-07-17 16:57:00+03	83000.00
6BA7B5	2017-07-22 15:09:00+03	90400.00
6BA7BB	2017-07-04 03:03:00+03	39500.00
6BA7BC	2017-08-09 06:42:00+03	68100.00
6BA7C2	2017-08-02 06:54:00+03	28000.00
6BA824	2017-08-07 21:46:00+03	46400.00
6BA957	2017-07-13 13:39:00+03	65900.00
6BA9A7	2017-07-18 00:49:00+03	122600.00
6BA9F1	2017-07-11 23:34:00+03	124200.00
6BAA85	2017-07-20 18:08:00+03	22100.00
6BAA88	2017-08-14 06:25:00+03	46000.00
6BAAF2	2017-06-30 14:57:00+03	554600.00
6BAB14	2017-07-19 00:52:00+03	270800.00
6BAB5F	2017-07-16 14:00:00+03	28000.00
6BABCC	2017-07-16 15:20:00+03	31400.00
6BABD8	2017-07-26 23:43:00+03	140100.00
6BABE8	2017-07-08 13:43:00+03	32800.00
6BABEC	2017-07-26 01:47:00+03	20000.00
6BABF1	2017-08-05 17:19:00+03	7400.00
6BAC14	2017-08-13 00:05:00+03	28000.00
6BAC16	2017-07-21 06:41:00+03	40400.00
6BAC87	2017-07-11 00:13:00+03	95000.00
6BAC89	2017-07-30 13:50:00+03	32900.00
6BAD9A	2017-07-04 21:51:00+03	139500.00
6BAE8E	2017-08-05 17:29:00+03	58000.00
6BAEAD	2017-07-19 19:53:00+03	45200.00
6BAF12	2017-07-23 18:09:00+03	14000.00
6BAF15	2017-07-08 17:05:00+03	246000.00
6BAF40	2017-07-24 09:57:00+03	43200.00
6BAF7A	2017-07-17 09:36:00+03	130100.00
6BAF81	2017-07-03 21:34:00+03	47100.00
6BAF82	2017-08-06 08:58:00+03	35600.00
6BAFA8	2017-07-22 23:20:00+03	386300.00
6BAFEE	2017-07-10 03:53:00+03	124200.00
6BAFFE	2017-07-22 22:04:00+03	36900.00
6BB017	2017-08-14 04:54:00+03	28700.00
6BB073	2017-07-04 09:41:00+03	189100.00
6BB0C2	2017-08-12 16:51:00+03	174000.00
6BB0E0	2017-08-12 16:13:00+03	27800.00
6BB0E4	2017-07-10 00:34:00+03	119600.00
6BB0FB	2017-07-11 12:14:00+03	46300.00
6BB120	2017-08-03 17:17:00+03	32800.00
6BB136	2017-07-11 11:24:00+03	6000.00
6BB160	2017-07-04 17:29:00+03	86300.00
6BB17E	2017-08-02 16:29:00+03	3400.00
6BB180	2017-08-10 06:28:00+03	102600.00
6BB1C5	2017-07-19 08:03:00+03	87100.00
6BB1F6	2017-07-06 02:28:00+03	263100.00
6BB20E	2017-07-27 20:39:00+03	96400.00
6BB22A	2017-08-01 20:19:00+03	87000.00
6BB292	2017-08-05 03:48:00+03	154500.00
6BB329	2017-06-26 02:33:00+03	26000.00
6BB352	2017-07-27 08:45:00+03	103800.00
6BB364	2017-07-05 15:58:00+03	119600.00
6BB39C	2017-07-31 14:27:00+03	270800.00
6BB3C0	2017-07-31 09:47:00+03	314400.00
6BB3C7	2017-07-29 01:21:00+03	133200.00
6BB42E	2017-07-12 10:31:00+03	29200.00
6BB526	2017-08-07 11:07:00+03	83900.00
6BB54F	2017-06-29 01:11:00+03	23600.00
6BB566	2017-08-03 19:22:00+03	159200.00
6BB567	2017-08-08 21:45:00+03	76300.00
6BB5BE	2017-08-03 20:57:00+03	19600.00
6BB600	2017-08-11 04:32:00+03	167400.00
6BB623	2017-07-15 05:38:00+03	91600.00
6BB65E	2017-07-01 11:21:00+03	43200.00
6BB6E9	2017-07-04 12:10:00+03	98000.00
6BB72A	2017-07-14 07:35:00+03	58700.00
6BB793	2017-08-07 11:24:00+03	73500.00
6BB7EE	2017-07-14 00:38:00+03	58800.00
6BB7F8	2017-08-14 15:18:00+03	40200.00
6BB85A	2017-08-08 10:48:00+03	65500.00
6BB872	2017-07-15 23:22:00+03	31400.00
6BB887	2017-07-17 13:04:00+03	22000.00
6BB89B	2017-07-09 17:21:00+03	49800.00
6BB8B1	2017-07-15 08:43:00+03	81600.00
6BB8E0	2017-07-18 12:44:00+03	39800.00
6BB965	2017-07-17 02:02:00+03	56000.00
6BB987	2017-07-19 06:55:00+03	75800.00
6BBA9D	2017-07-05 13:27:00+03	18000.00
6BBACC	2017-06-30 13:59:00+03	52700.00
6BBB50	2017-07-09 23:13:00+03	19600.00
6BBB6A	2017-08-11 16:31:00+03	60400.00
6BBBA2	2017-08-13 00:29:00+03	135600.00
6BBD34	2017-07-19 12:13:00+03	7400.00
6BBD50	2017-07-12 05:44:00+03	11300.00
6BBD96	2017-07-16 01:56:00+03	24400.00
6BBDCC	2017-07-29 20:25:00+03	30200.00
6BBE1A	2017-08-12 14:50:00+03	9200.00
6BBE9E	2017-07-25 20:01:00+03	547600.00
6BBED5	2017-07-29 16:01:00+03	173500.00
6BBEE6	2017-07-10 13:08:00+03	417000.00
6BBF28	2017-07-26 14:31:00+03	31900.00
6BBF48	2017-08-07 04:54:00+03	58900.00
6BBF7C	2017-07-08 10:03:00+03	93900.00
6BBFC8	2017-08-11 00:38:00+03	112000.00
6BBFE2	2017-07-09 05:49:00+03	64500.00
6BC056	2017-07-19 09:13:00+03	34400.00
6BC06D	2017-08-13 03:09:00+03	96400.00
6BC0A5	2017-07-11 03:56:00+03	13400.00
6BC0E2	2017-08-05 05:44:00+03	47100.00
6BC0EC	2017-07-24 04:47:00+03	16400.00
6BC264	2017-07-22 16:28:00+03	93900.00
6BC27C	2017-08-11 05:01:00+03	53100.00
6BC28C	2017-07-26 18:04:00+03	31600.00
6BC2B4	2017-07-17 01:44:00+03	81500.00
6BC2B8	2017-07-27 16:43:00+03	38500.00
6BC36E	2017-07-04 03:46:00+03	27800.00
6BC3D3	2017-08-06 01:34:00+03	23400.00
6BC3EB	2017-08-08 09:13:00+03	44600.00
6BC3EF	2017-08-03 11:02:00+03	37900.00
6BC480	2017-07-03 03:43:00+03	46400.00
6BC491	2017-07-25 07:38:00+03	21400.00
6BC4A7	2017-07-09 00:24:00+03	65300.00
6BC4D9	2017-07-18 13:14:00+03	213800.00
6BC4E3	2017-07-10 13:00:00+03	40800.00
6BC504	2017-07-04 20:57:00+03	16400.00
6BC518	2017-08-03 13:25:00+03	79500.00
6BC54F	2017-07-10 02:30:00+03	189800.00
6BC560	2017-07-10 18:30:00+03	33000.00
6BC568	2017-07-12 00:08:00+03	65900.00
6BC58A	2017-07-15 13:21:00+03	219200.00
6BC5E3	2017-07-15 12:48:00+03	53600.00
6BC65C	2017-07-14 11:11:00+03	147200.00
6BC690	2017-08-10 22:38:00+03	28000.00
6BC6C6	2017-07-06 20:56:00+03	55800.00
6BC6E3	2017-07-19 23:46:00+03	125100.00
6BC720	2017-07-16 09:23:00+03	72400.00
6BC744	2017-08-10 23:51:00+03	6700.00
6BC80E	2017-07-25 19:02:00+03	136200.00
6BC88F	2017-08-12 15:15:00+03	69500.00
6BC906	2017-08-05 18:46:00+03	26000.00
6BC98A	2017-07-28 11:41:00+03	91200.00
6BC9BA	2017-08-02 09:25:00+03	19800.00
6BC9BB	2017-07-13 17:46:00+03	67600.00
6BC9CE	2017-07-08 10:49:00+03	58600.00
6BC9E0	2017-08-12 14:58:00+03	15000.00
6BCA56	2017-08-05 16:51:00+03	12400.00
6BCA9E	2017-08-07 08:40:00+03	85000.00
6BCAE5	2017-08-04 09:11:00+03	119000.00
6BCBA8	2017-07-17 10:17:00+03	86600.00
6BCBE1	2017-07-23 09:05:00+03	75600.00
6BCBEA	2017-07-15 07:05:00+03	26300.00
6BCC01	2017-07-28 04:47:00+03	65800.00
6BCC07	2017-07-27 15:18:00+03	16400.00
6BCC48	2017-07-03 12:45:00+03	47100.00
6BCC5A	2017-08-09 02:08:00+03	75800.00
6BCC62	2017-07-09 06:35:00+03	6700.00
6BCC88	2017-08-03 18:37:00+03	46300.00
6BCD01	2017-08-02 14:18:00+03	289800.00
6BCDBD	2017-08-13 19:48:00+03	66000.00
6BCDEF	2017-07-10 23:59:00+03	61800.00
6BCE84	2017-07-05 22:20:00+03	31200.00
6BCE8F	2017-07-13 22:52:00+03	56000.00
6BCF09	2017-07-14 00:51:00+03	25600.00
6BCF68	2017-07-25 00:12:00+03	204500.00
6BD075	2017-08-07 15:57:00+03	40000.00
6BD0A5	2017-08-07 21:00:00+03	43000.00
6BD0D4	2017-07-17 20:33:00+03	192200.00
6BD0F4	2017-07-13 13:16:00+03	56600.00
6BD12A	2017-07-05 23:17:00+03	61800.00
6BD1A7	2017-07-26 02:40:00+03	42400.00
6BD1D4	2017-07-08 18:55:00+03	6300.00
6BD2CF	2017-07-09 11:43:00+03	35200.00
6BD345	2017-07-04 05:34:00+03	32200.00
6BD35B	2017-07-05 15:56:00+03	29400.00
6BD3B0	2017-07-21 04:41:00+03	40800.00
6BD3FD	2017-07-29 20:43:00+03	28800.00
6BD42F	2017-08-15 01:51:00+03	169300.00
6BD46B	2017-07-07 20:12:00+03	135400.00
6BD497	2017-06-29 19:08:00+03	57500.00
6BD49C	2017-07-05 23:32:00+03	25600.00
6BD4BC	2017-08-13 02:36:00+03	30200.00
6BD4D5	2017-07-23 23:47:00+03	26000.00
6BD528	2017-08-05 04:49:00+03	72700.00
6BD54A	2017-08-07 02:36:00+03	41200.00
6BD567	2017-07-07 05:48:00+03	8000.00
6BD578	2017-08-11 18:30:00+03	44000.00
6BD5A4	2017-07-13 13:12:00+03	133200.00
6BD5B1	2017-07-08 12:51:00+03	47200.00
6BD633	2017-07-08 22:11:00+03	29400.00
6BD643	2017-07-09 14:29:00+03	73900.00
6BD69C	2017-08-01 05:50:00+03	124400.00
6BD69E	2017-08-06 15:21:00+03	22000.00
6BD6A8	2017-08-06 18:57:00+03	61700.00
6BD6C5	2017-07-24 03:40:00+03	201200.00
6BD6CC	2017-08-05 04:34:00+03	42400.00
6BD71A	2017-07-12 06:56:00+03	73500.00
6BD745	2017-08-14 06:42:00+03	199700.00
6BD7CE	2017-07-15 16:05:00+03	14000.00
6BD7EA	2017-07-07 05:33:00+03	20400.00
6BD86E	2017-08-11 17:14:00+03	37900.00
6BD8FB	2017-07-19 13:25:00+03	46400.00
6BD90F	2017-08-08 01:24:00+03	372500.00
6BD914	2017-07-18 15:53:00+03	26700.00
6BD915	2017-07-16 11:11:00+03	56000.00
6BD91A	2017-08-13 01:15:00+03	27200.00
6BD9A7	2017-08-05 00:58:00+03	6800.00
6BDA31	2017-08-09 09:03:00+03	24400.00
6BDA36	2017-07-17 15:54:00+03	11600.00
6BDA66	2017-08-02 11:58:00+03	23600.00
6BDA87	2017-08-05 01:03:00+03	46400.00
6BDAF7	2017-07-08 12:03:00+03	19600.00
6BDB57	2017-07-14 19:57:00+03	66600.00
6BDBAF	2017-07-21 15:19:00+03	73100.00
6BDBB6	2017-08-15 11:05:00+03	172100.00
6BDBC1	2017-07-04 10:43:00+03	8400.00
6BDBC8	2017-07-26 04:26:00+03	88900.00
6BDBCA	2017-07-10 16:20:00+03	28800.00
6BDBEC	2017-07-12 09:14:00+03	78300.00
6BDC5F	2017-07-27 12:50:00+03	68800.00
6BDD51	2017-07-29 14:04:00+03	112600.00
6BDD8A	2017-07-23 15:03:00+03	26000.00
6BDE04	2017-07-10 04:34:00+03	211300.00
6BDE87	2017-08-05 21:10:00+03	44800.00
6BDE91	2017-08-07 20:18:00+03	56000.00
6BDE95	2017-08-11 05:47:00+03	133700.00
6BDE96	2017-08-13 01:04:00+03	134400.00
6BDEC0	2017-07-18 05:40:00+03	92800.00
6BDEFF	2017-08-11 05:12:00+03	81700.00
6BDF14	2017-07-05 02:40:00+03	6000.00
6BDF2E	2017-07-03 20:56:00+03	131100.00
6BDF64	2017-07-31 23:10:00+03	40800.00
6BDFCF	2017-08-12 11:26:00+03	38600.00
6BDFEB	2017-06-30 16:42:00+03	28000.00
6BDFF4	2017-08-01 00:00:00+03	103200.00
6BE03F	2017-07-14 07:26:00+03	59800.00
6BE046	2017-07-24 00:38:00+03	46400.00
6BE04B	2017-07-08 06:12:00+03	14400.00
6BE067	2017-07-21 01:59:00+03	6300.00
6BE079	2017-07-04 03:17:00+03	14000.00
6BE07C	2017-07-27 21:27:00+03	45100.00
6BE0A5	2017-07-10 16:18:00+03	122900.00
6BE0DE	2017-07-20 07:56:00+03	326300.00
6BE10E	2017-07-28 11:21:00+03	28800.00
6BE13F	2017-08-12 01:06:00+03	37900.00
6BE1BB	2017-07-19 13:15:00+03	48800.00
6BE1D0	2017-08-13 18:23:00+03	36200.00
6BE209	2017-08-12 14:19:00+03	50600.00
6BE25A	2017-07-18 21:12:00+03	94000.00
6BE271	2017-07-19 04:39:00+03	56000.00
6BE297	2017-07-08 14:29:00+03	28000.00
6BE2C7	2017-07-27 10:28:00+03	23200.00
6BE374	2017-07-03 05:04:00+03	30000.00
6BE3BB	2017-08-02 13:22:00+03	68800.00
6BE418	2017-07-05 02:51:00+03	32800.00
6BE4A6	2017-07-02 02:44:00+03	48800.00
6BE51D	2017-07-05 11:35:00+03	65200.00
6BE52C	2017-08-14 02:05:00+03	20200.00
6BE568	2017-07-18 23:44:00+03	21400.00
6BE56C	2017-07-28 19:49:00+03	235800.00
6BE56F	2017-07-03 08:35:00+03	96800.00
6BE5BF	2017-08-09 23:50:00+03	270800.00
6BE5DE	2017-08-02 13:08:00+03	94700.00
6BE6DD	2017-07-16 08:58:00+03	66600.00
6BE74B	2017-06-29 04:15:00+03	101200.00
6BE755	2017-07-02 07:49:00+03	29600.00
6BE759	2017-07-10 04:01:00+03	35200.00
6BE78B	2017-08-03 05:27:00+03	25200.00
6BE7E8	2017-07-13 21:40:00+03	106200.00
6BE7EA	2017-07-16 11:00:00+03	369000.00
6BE802	2017-07-03 20:30:00+03	92800.00
6BE826	2017-07-31 05:30:00+03	68800.00
6BE858	2017-08-13 02:22:00+03	91200.00
6BE864	2017-07-09 00:08:00+03	28300.00
6BE892	2017-07-20 13:04:00+03	26000.00
6BE8F0	2017-06-29 11:21:00+03	34000.00
6BE95D	2017-08-08 08:22:00+03	55800.00
6BE994	2017-07-25 21:05:00+03	15400.00
6BE996	2017-07-03 22:08:00+03	132800.00
6BEA5F	2017-08-07 14:59:00+03	66000.00
6BEA6A	2017-08-14 17:22:00+03	35300.00
6BEA9C	2017-08-02 13:19:00+03	58600.00
6BEAAC	2017-07-01 05:09:00+03	18100.00
6BEAC7	2017-07-11 01:50:00+03	59000.00
6BEB0D	2017-07-04 10:58:00+03	131600.00
6BEB2A	2017-07-21 21:20:00+03	43200.00
6BEB4A	2017-07-23 06:17:00+03	289800.00
6BEB5B	2017-07-15 22:51:00+03	98300.00
6BEB80	2017-07-27 02:59:00+03	27300.00
6BEBC9	2017-07-28 16:12:00+03	44100.00
6BEC02	2017-06-27 21:13:00+03	21800.00
6BEC4E	2017-07-26 19:26:00+03	26000.00
6BEC64	2017-07-01 22:45:00+03	18000.00
6BECD0	2017-07-29 18:40:00+03	52000.00
6BECE5	2017-06-29 07:39:00+03	6700.00
6BED82	2017-07-07 10:00:00+03	111600.00
6BEDFC	2017-08-03 05:18:00+03	73400.00
6BEE0A	2017-07-14 11:03:00+03	335500.00
6BEE25	2017-08-05 02:05:00+03	71600.00
6BEE74	2017-06-29 12:31:00+03	92400.00
6BEE89	2017-07-01 10:21:00+03	396500.00
6BEEE7	2017-07-04 03:55:00+03	158800.00
6BEEF0	2017-06-27 03:37:00+03	14400.00
6BEF22	2017-07-23 14:32:00+03	300700.00
6BEF45	2017-08-15 15:07:00+03	135400.00
6BEF5D	2017-08-04 07:44:00+03	65900.00
6BEF77	2017-07-04 03:55:00+03	48800.00
6BEF7C	2017-07-01 11:18:00+03	39200.00
6BEFB4	2017-08-01 02:53:00+03	22600.00
6BEFB6	2017-08-07 09:38:00+03	49500.00
6BEFF8	2017-07-27 15:20:00+03	52700.00
6BF0A3	2017-07-27 09:57:00+03	111600.00
6BF0A8	2017-08-11 07:25:00+03	89000.00
6BF0C4	2017-08-11 14:42:00+03	31600.00
6BF0CC	2017-07-31 23:50:00+03	56600.00
6BF118	2017-06-27 15:47:00+03	42800.00
6BF168	2017-07-16 08:10:00+03	38600.00
6BF1BA	2017-07-11 18:33:00+03	48800.00
6BF1D8	2017-07-04 13:40:00+03	13700.00
6BF25C	2017-07-27 22:27:00+03	39300.00
6BF2CD	2017-07-01 05:50:00+03	124200.00
6BF303	2017-08-09 23:20:00+03	46800.00
6BF32D	2017-07-10 08:42:00+03	112000.00
6BF384	2017-07-26 12:12:00+03	148200.00
6BF4A5	2017-08-04 00:14:00+03	6300.00
6BF54D	2017-07-22 12:20:00+03	89600.00
6BF561	2017-07-10 20:03:00+03	69500.00
6BF566	2017-08-15 11:00:00+03	78100.00
6BF59C	2017-07-21 19:08:00+03	177800.00
6BF5B2	2017-06-28 05:09:00+03	123000.00
6BF5B9	2017-08-01 22:08:00+03	79600.00
6BF609	2017-07-16 06:09:00+03	155600.00
6BF7FD	2017-08-04 22:08:00+03	58600.00
6BF899	2017-08-15 13:35:00+03	24400.00
6BF8A7	2017-06-29 22:23:00+03	6700.00
6BF91A	2017-08-13 18:38:00+03	41200.00
6BF91F	2017-07-16 04:42:00+03	54800.00
6BF948	2017-08-08 10:22:00+03	24400.00
6BF962	2017-08-02 20:18:00+03	28800.00
6BF9A4	2017-07-11 07:22:00+03	66600.00
6BFA01	2017-07-04 03:00:00+03	112000.00
6BFA1E	2017-07-21 21:11:00+03	65500.00
6BFA43	2017-08-02 08:47:00+03	213200.00
6BFA75	2017-07-16 21:59:00+03	136600.00
6BFA96	2017-07-08 04:31:00+03	266400.00
6BFAF1	2017-07-12 22:37:00+03	23200.00
6BFB00	2017-08-03 13:42:00+03	53300.00
6BFB66	2017-07-09 17:26:00+03	246000.00
6BFB7E	2017-07-30 06:03:00+03	77500.00
6BFB93	2017-07-06 05:24:00+03	55600.00
6BFBBF	2017-07-24 09:35:00+03	10800.00
6BFC1A	2017-07-15 07:58:00+03	163700.00
6BFC38	2017-07-10 05:29:00+03	85000.00
6BFC6E	2017-07-30 13:54:00+03	47000.00
6BFCA6	2017-08-04 07:14:00+03	55800.00
6BFCDC	2017-08-12 21:14:00+03	18700.00
6BFCE6	2017-08-06 19:55:00+03	86300.00
6BFD2B	2017-07-24 07:07:00+03	75600.00
6BFD5A	2017-07-17 07:31:00+03	39800.00
6BFD7B	2017-08-11 03:35:00+03	46200.00
6BFD7C	2017-07-03 17:44:00+03	18600.00
6BFD8A	2017-07-08 07:38:00+03	75300.00
6BFDAD	2017-08-04 00:57:00+03	8400.00
6BFDEF	2017-07-27 02:38:00+03	174000.00
6BFE2A	2017-08-15 10:50:00+03	57500.00
6BFE85	2017-08-12 07:34:00+03	56900.00
6BFEA7	2017-08-05 19:05:00+03	28800.00
6BFEF4	2017-08-11 11:39:00+03	26000.00
6BFF55	2017-07-29 04:23:00+03	21800.00
6BFF6B	2017-08-11 15:12:00+03	75300.00
6BFF9F	2017-08-13 03:51:00+03	123000.00
6BFFA6	2017-07-03 18:10:00+03	22000.00
6C0000	2017-07-05 01:04:00+03	28000.00
6C0024	2017-08-08 06:35:00+03	119000.00
6C0037	2017-07-26 17:52:00+03	39600.00
6C00AD	2017-07-02 04:20:00+03	59100.00
6C00F1	2017-08-09 19:48:00+03	40800.00
6C0105	2017-08-06 10:10:00+03	35200.00
6C0122	2017-07-12 04:27:00+03	217600.00
6C0161	2017-07-22 00:30:00+03	73500.00
6C016A	2017-07-24 09:08:00+03	56000.00
6C01D1	2017-07-23 18:50:00+03	48800.00
6C01F2	2017-08-04 01:57:00+03	69500.00
6C0222	2017-08-09 09:07:00+03	232800.00
6C0259	2017-07-24 21:16:00+03	55900.00
6C02B2	2017-07-24 02:35:00+03	142400.00
6C0304	2017-07-02 10:29:00+03	9200.00
6C034E	2017-08-09 01:51:00+03	247900.00
6C038B	2017-07-19 12:08:00+03	146600.00
6C038C	2017-07-25 02:51:00+03	160800.00
6C03D5	2017-07-29 00:38:00+03	86300.00
6C03F5	2017-08-11 03:30:00+03	31100.00
6C03FD	2017-08-14 01:34:00+03	33400.00
6C0422	2017-08-07 14:08:00+03	45100.00
6C04C0	2017-07-19 05:49:00+03	169900.00
6C054D	2017-07-31 05:52:00+03	65500.00
6C05B7	2017-08-09 06:45:00+03	28000.00
6C05DA	2017-07-23 23:44:00+03	28000.00
6C0652	2017-07-16 19:41:00+03	54800.00
6C0655	2017-07-15 01:46:00+03	78800.00
6C065F	2017-08-10 04:55:00+03	109600.00
6C06DE	2017-07-14 15:46:00+03	23200.00
6C0711	2017-08-04 08:04:00+03	95200.00
6C076A	2017-08-08 11:59:00+03	47100.00
6C079C	2017-08-10 18:44:00+03	145400.00
6C07CC	2017-07-19 02:14:00+03	406700.00
6C08BA	2017-06-27 17:04:00+03	26000.00
6C08EF	2017-07-09 03:52:00+03	66800.00
6C0909	2017-07-05 06:26:00+03	405200.00
6C0975	2017-07-27 03:31:00+03	58100.00
6C0995	2017-08-06 10:55:00+03	78300.00
6C09A3	2017-07-10 13:30:00+03	73600.00
6C09B0	2017-07-29 14:04:00+03	99200.00
6C09FD	2017-07-17 04:32:00+03	52100.00
6C0A0B	2017-08-11 07:28:00+03	62800.00
6C0A1D	2017-08-12 01:03:00+03	28300.00
6C0A47	2017-08-11 20:52:00+03	26800.00
6C0AB8	2017-08-14 20:14:00+03	24400.00
6C0AE4	2017-07-18 06:35:00+03	92700.00
6C0AEF	2017-07-23 00:47:00+03	99200.00
6C0AFA	2017-07-10 02:07:00+03	79900.00
6C0B11	2017-07-08 12:13:00+03	102100.00
6C0B5D	2017-07-14 03:33:00+03	139500.00
6C0B6D	2017-07-22 10:20:00+03	134600.00
6C0BFF	2017-07-30 09:56:00+03	95600.00
6C0C11	2017-07-04 09:21:00+03	174000.00
6C0C21	2017-07-19 09:01:00+03	24800.00
6C0C29	2017-07-11 04:18:00+03	40600.00
6C0C34	2017-08-13 11:39:00+03	21400.00
6C0D7D	2017-07-19 15:57:00+03	13000.00
6C0D96	2017-08-08 14:00:00+03	57800.00
6C0DB2	2017-06-26 11:46:00+03	58400.00
6C0DD0	2017-07-16 08:13:00+03	133200.00
6C0DFD	2017-08-10 05:12:00+03	62800.00
6C0E20	2017-08-05 18:59:00+03	58900.00
6C0E2C	2017-08-08 18:59:00+03	18800.00
6C0E4B	2017-08-08 10:55:00+03	38800.00
6C0E76	2017-08-07 13:28:00+03	28000.00
6C0F8F	2017-08-08 15:27:00+03	89200.00
6C0F91	2017-07-31 10:26:00+03	40800.00
6C0FB3	2017-08-06 11:12:00+03	112100.00
6C0FCF	2017-07-06 12:39:00+03	24300.00
6C0FD1	2017-06-30 18:28:00+03	116700.00
6C1034	2017-08-06 06:13:00+03	86600.00
6C1084	2017-08-10 17:38:00+03	22100.00
6C10FA	2017-07-21 21:26:00+03	46400.00
6C115A	2017-07-18 07:20:00+03	36200.00
6C11D0	2017-07-07 21:01:00+03	492000.00
6C1225	2017-07-18 07:09:00+03	43900.00
6C1235	2017-07-28 00:06:00+03	50800.00
6C1246	2017-07-31 10:55:00+03	73100.00
6C1346	2017-07-10 16:12:00+03	59200.00
6C1374	2017-06-30 05:29:00+03	181000.00
6C1383	2017-07-26 18:43:00+03	24400.00
6C1415	2017-08-07 07:40:00+03	55800.00
6C148C	2017-08-07 15:00:00+03	154800.00
6C14A3	2017-07-12 04:30:00+03	78600.00
6C14FB	2017-07-05 13:15:00+03	92900.00
6C1585	2017-08-01 16:34:00+03	8400.00
6C1589	2017-08-15 12:00:00+03	16400.00
6C15CD	2017-07-22 19:22:00+03	8000.00
6C15E5	2017-08-12 02:49:00+03	14100.00
6C1618	2017-07-12 07:04:00+03	17800.00
6C163A	2017-08-05 15:39:00+03	12400.00
6C1666	2017-08-12 23:29:00+03	133100.00
6C16E6	2017-07-23 21:16:00+03	136200.00
6C1709	2017-07-04 22:40:00+03	103900.00
6C1717	2017-07-19 01:47:00+03	28800.00
6C172E	2017-08-05 13:13:00+03	12400.00
6C1769	2017-07-01 18:28:00+03	139500.00
6C1778	2017-08-05 01:59:00+03	18600.00
6C1787	2017-07-21 17:27:00+03	246000.00
6C17D8	2017-07-18 19:58:00+03	24700.00
6C1824	2017-07-06 11:32:00+03	40800.00
6C182D	2017-07-17 22:55:00+03	8200.00
6C187F	2017-08-13 01:42:00+03	26700.00
6C18D4	2017-08-01 00:46:00+03	66600.00
6C1918	2017-08-04 16:59:00+03	23400.00
6C191F	2017-08-08 21:20:00+03	82900.00
6C1A22	2017-07-26 14:44:00+03	21400.00
6C1A46	2017-07-30 17:49:00+03	118600.00
6C1A47	2017-08-03 15:04:00+03	62000.00
6C1AE7	2017-07-26 14:42:00+03	114500.00
6C1B05	2017-07-08 05:08:00+03	29200.00
6C1BB2	2017-07-19 16:33:00+03	62900.00
6C1C2D	2017-07-15 11:36:00+03	62600.00
6C1C45	2017-07-07 11:47:00+03	201200.00
6C1C5E	2017-08-07 00:46:00+03	77000.00
6C1CA4	2017-07-27 12:09:00+03	36200.00
6C1CA9	2017-08-10 16:18:00+03	70700.00
6C1CDE	2017-07-09 11:09:00+03	23600.00
6C1D6D	2017-07-09 05:33:00+03	12600.00
6C1D96	2017-08-12 19:18:00+03	66200.00
6C1DF3	2017-07-19 22:24:00+03	33300.00
6C1E6C	2017-07-17 03:52:00+03	28000.00
6C1E75	2017-07-02 16:11:00+03	30000.00
6C1EE5	2017-07-21 05:50:00+03	57400.00
6C1FA1	2017-07-06 04:38:00+03	25200.00
6C1FB0	2017-08-05 16:26:00+03	63500.00
6C1FCF	2017-08-14 10:59:00+03	70500.00
6C1FD4	2017-07-14 02:48:00+03	207200.00
6C20D9	2017-07-25 14:23:00+03	69500.00
6C20DE	2017-08-15 17:38:00+03	97500.00
6C21B4	2017-08-12 21:26:00+03	40800.00
6C21B8	2017-07-28 15:04:00+03	159200.00
6C21BC	2017-07-16 21:24:00+03	29600.00
6C225C	2017-07-09 17:56:00+03	46200.00
6C226B	2017-07-14 21:45:00+03	108100.00
6C226E	2017-07-17 02:24:00+03	25200.00
6C2274	2017-07-31 14:29:00+03	18800.00
6C228A	2017-08-10 19:48:00+03	18900.00
6C22AE	2017-08-10 19:22:00+03	38800.00
6C2308	2017-07-16 02:02:00+03	139300.00
6C2355	2017-08-15 08:08:00+03	32700.00
6C2371	2017-07-06 16:39:00+03	42800.00
6C23EC	2017-08-07 12:21:00+03	69100.00
6C2454	2017-07-07 12:55:00+03	120300.00
6C245C	2017-07-23 13:34:00+03	34000.00
6C247B	2017-07-06 17:04:00+03	134900.00
6C250A	2017-08-14 18:27:00+03	198900.00
6C2554	2017-08-15 04:29:00+03	114900.00
6C25B5	2017-07-28 15:06:00+03	8400.00
6C2627	2017-07-12 02:05:00+03	74800.00
6C269D	2017-07-10 07:37:00+03	234800.00
6C26C0	2017-07-04 11:49:00+03	75300.00
6C2719	2017-07-28 04:28:00+03	29000.00
6C2798	2017-07-20 08:40:00+03	183300.00
6C27DF	2017-07-31 11:46:00+03	55800.00
6C280D	2017-08-10 11:57:00+03	47200.00
6C289D	2017-07-11 23:53:00+03	22000.00
6C289E	2017-07-20 04:52:00+03	37900.00
6C28D9	2017-08-02 13:52:00+03	233800.00
6C28DA	2017-08-04 22:01:00+03	57600.00
6C2941	2017-07-22 12:59:00+03	21400.00
6C29D2	2017-07-05 06:07:00+03	32200.00
6C29D6	2017-08-15 12:27:00+03	285600.00
6C29DD	2017-07-21 08:18:00+03	11700.00
6C2A14	2017-08-02 23:41:00+03	54800.00
6C2A3C	2017-06-28 13:53:00+03	66900.00
6C2A62	2017-08-13 03:27:00+03	142800.00
6C2AFB	2017-07-29 23:11:00+03	63500.00
6C2B39	2017-07-24 17:22:00+03	132800.00
6C2B44	2017-07-05 14:05:00+03	28800.00
6C2B9A	2017-07-06 20:27:00+03	78100.00
6C2BCC	2017-07-19 12:10:00+03	26000.00
6C2BEE	2017-07-08 04:01:00+03	129200.00
6C2C00	2017-07-13 13:53:00+03	21500.00
6C2C0C	2017-07-30 12:50:00+03	85700.00
6C2C27	2017-07-12 06:13:00+03	93400.00
6C2C47	2017-07-25 07:29:00+03	148200.00
6C2C71	2017-07-16 18:39:00+03	38800.00
6C2C76	2017-06-28 19:12:00+03	21800.00
6C2C7C	2017-07-30 14:57:00+03	17200.00
6C2C82	2017-08-02 04:34:00+03	65400.00
6C2C97	2017-07-05 01:36:00+03	411200.00
6C2D74	2017-08-05 02:24:00+03	6300.00
6C2D97	2017-08-03 14:44:00+03	42800.00
6C2DA1	2017-07-02 10:42:00+03	62600.00
6C2DA7	2017-07-18 03:13:00+03	31400.00
6C2DE8	2017-08-11 01:51:00+03	239300.00
6C2DFF	2017-07-16 13:01:00+03	28000.00
6C2E07	2017-08-02 11:22:00+03	130000.00
6C2E92	2017-08-05 09:27:00+03	47400.00
6C2F00	2017-08-03 18:26:00+03	68400.00
6C2F1B	2017-07-20 07:53:00+03	28800.00
6C2F32	2017-07-30 10:45:00+03	375200.00
6C2F35	2017-07-22 03:06:00+03	39300.00
6C2F4A	2017-07-22 18:59:00+03	23600.00
6C2F75	2017-07-06 09:00:00+03	54800.00
6C2FB2	2017-07-11 03:55:00+03	25200.00
6C2FF0	2017-07-16 17:30:00+03	39800.00
6C2FF6	2017-07-23 08:46:00+03	40400.00
6C303E	2017-08-05 12:23:00+03	13400.00
6C30B4	2017-07-20 23:51:00+03	23200.00
6C3129	2017-07-18 11:57:00+03	81300.00
6C312B	2017-07-20 17:24:00+03	89600.00
6C312D	2017-06-26 23:24:00+03	218200.00
6C313E	2017-07-02 09:11:00+03	135600.00
6C3165	2017-08-13 02:10:00+03	62100.00
6C3174	2017-07-27 20:21:00+03	24800.00
6C31B2	2017-07-27 03:51:00+03	154400.00
6C31C8	2017-06-28 20:39:00+03	27200.00
6C31E2	2017-07-25 06:02:00+03	27600.00
6C3240	2017-07-27 01:35:00+03	67000.00
6C3244	2017-08-09 08:01:00+03	28000.00
6C32AE	2017-08-10 00:09:00+03	69500.00
6C3344	2017-07-26 22:54:00+03	266200.00
6C3395	2017-07-24 00:12:00+03	132000.00
6C339A	2017-08-09 02:19:00+03	46900.00
6C33E8	2017-07-27 18:21:00+03	20400.00
6C33EF	2017-07-13 23:19:00+03	6800.00
6C3412	2017-07-06 18:51:00+03	21800.00
6C341A	2017-08-01 20:05:00+03	74400.00
6C3464	2017-07-28 13:53:00+03	201200.00
6C346F	2017-07-05 14:54:00+03	6600.00
6C3471	2017-08-08 20:53:00+03	143200.00
6C34B7	2017-08-05 21:22:00+03	14000.00
6C3508	2017-08-01 08:52:00+03	130300.00
6C3509	2017-07-15 18:29:00+03	117600.00
6C3544	2017-08-10 21:31:00+03	98100.00
6C3551	2017-07-25 08:08:00+03	77000.00
6C3565	2017-08-11 22:07:00+03	65600.00
6C357B	2017-08-04 19:45:00+03	75600.00
6C365C	2017-08-12 09:11:00+03	54000.00
6C368D	2017-07-02 20:55:00+03	27800.00
6C36A8	2017-07-19 11:21:00+03	132800.00
6C36BF	2017-07-07 23:33:00+03	52700.00
6C36EF	2017-07-22 06:58:00+03	15100.00
6C36F9	2017-07-10 20:38:00+03	55800.00
6C3719	2017-07-31 11:37:00+03	99300.00
6C371D	2017-07-24 09:51:00+03	29600.00
6C373E	2017-07-06 00:59:00+03	65500.00
6C3775	2017-07-05 01:32:00+03	21400.00
6C37D6	2017-07-31 20:44:00+03	46300.00
6C37E0	2017-07-16 20:38:00+03	97000.00
6C37F5	2017-08-15 10:06:00+03	148200.00
6C3810	2017-07-25 21:49:00+03	72400.00
6C3841	2017-07-26 02:14:00+03	41800.00
6C386E	2017-08-15 07:43:00+03	92800.00
6C3874	2017-07-23 19:18:00+03	29600.00
6C3894	2017-08-02 07:13:00+03	55800.00
6C38D4	2017-08-08 05:40:00+03	128800.00
6C38E1	2017-07-05 21:01:00+03	96300.00
6C3967	2017-07-08 13:25:00+03	128800.00
6C3A10	2017-07-23 05:09:00+03	187600.00
6C3A16	2017-08-05 11:04:00+03	59300.00
6C3A4F	2017-08-10 11:57:00+03	369000.00
6C3A73	2017-08-15 04:31:00+03	28700.00
6C3A7F	2017-07-25 01:01:00+03	47000.00
6C3B0D	2017-07-25 09:46:00+03	98800.00
6C3B0E	2017-07-02 08:48:00+03	58000.00
6C3BA5	2017-07-11 04:46:00+03	37900.00
6C3BCE	2017-07-23 09:46:00+03	92800.00
6C3BE1	2017-07-09 06:15:00+03	66300.00
6C3BF8	2017-07-04 03:11:00+03	248300.00
6C3BFD	2017-07-04 08:08:00+03	44500.00
6C3C28	2017-07-11 13:53:00+03	12600.00
6C3C94	2017-08-11 11:48:00+03	75300.00
6C3D39	2017-07-07 01:13:00+03	12600.00
6C3D3B	2017-07-29 05:45:00+03	28800.00
6C3D40	2017-06-29 06:03:00+03	96800.00
6C3D49	2017-07-20 23:55:00+03	56000.00
6C3D65	2017-07-28 20:16:00+03	67900.00
6C3DD3	2017-07-29 23:09:00+03	254900.00
6C3DE0	2017-07-10 05:47:00+03	33100.00
6C3DF9	2017-07-22 14:37:00+03	290400.00
6C3E05	2017-08-07 18:22:00+03	55800.00
6C3E85	2017-08-07 18:39:00+03	155600.00
6C3EAB	2017-07-14 17:59:00+03	44300.00
6C3ED2	2017-07-19 15:17:00+03	28000.00
6C3F28	2017-07-18 20:04:00+03	55800.00
6C3F5A	2017-07-08 08:28:00+03	22200.00
6C404C	2017-07-09 05:29:00+03	24400.00
6C4053	2017-07-15 02:04:00+03	72400.00
6C4081	2017-07-01 02:04:00+03	66600.00
6C40B5	2017-07-07 19:35:00+03	668200.00
6C40E2	2017-07-12 04:30:00+03	6300.00
6C410B	2017-08-13 09:36:00+03	81700.00
6C413F	2017-07-25 05:30:00+03	50600.00
6C414A	2017-07-20 02:20:00+03	123000.00
6C4154	2017-07-10 11:06:00+03	19600.00
6C41A8	2017-08-03 04:33:00+03	124200.00
6C41C4	2017-08-04 21:51:00+03	32700.00
6C41C8	2017-07-25 08:11:00+03	299600.00
6C42A2	2017-08-06 01:22:00+03	234400.00
6C42CB	2017-08-03 07:38:00+03	39600.00
6C4380	2017-07-13 19:48:00+03	25400.00
6C43C4	2017-08-04 00:46:00+03	113100.00
6C43EB	2017-07-15 11:56:00+03	29400.00
6C4400	2017-07-07 17:08:00+03	252200.00
6C4411	2017-08-15 15:11:00+03	53300.00
6C449D	2017-08-01 20:21:00+03	66600.00
6C44DC	2017-08-10 14:03:00+03	46400.00
6C4556	2017-07-02 19:36:00+03	25600.00
6C455B	2017-07-08 03:01:00+03	12600.00
6C457B	2017-08-10 22:13:00+03	36800.00
6C4581	2017-07-15 17:27:00+03	61800.00
6C45A4	2017-07-10 23:08:00+03	46800.00
6C45C8	2017-07-27 21:31:00+03	79900.00
6C4604	2017-07-04 08:38:00+03	52000.00
6C467E	2017-07-14 02:51:00+03	73600.00
6C46A7	2017-08-09 07:34:00+03	69100.00
6C46B1	2017-07-07 22:16:00+03	40800.00
6C46E2	2017-07-07 02:08:00+03	79600.00
6C46E4	2017-07-17 03:35:00+03	43200.00
6C46ED	2017-07-16 23:08:00+03	27400.00
6C4718	2017-07-06 17:24:00+03	64400.00
6C476E	2017-07-25 12:46:00+03	20000.00
6C47A3	2017-07-06 18:52:00+03	41900.00
6C4862	2017-08-07 03:09:00+03	133200.00
6C4922	2017-07-18 05:03:00+03	31000.00
6C4961	2017-07-15 03:13:00+03	6800.00
6C49C8	2017-07-27 09:44:00+03	25400.00
6C49D4	2017-08-10 19:02:00+03	85000.00
6C49D8	2017-07-04 22:31:00+03	84500.00
6C49E3	2017-08-01 10:34:00+03	35200.00
6C4A1F	2017-08-14 23:16:00+03	62700.00
6C4ACA	2017-07-19 19:56:00+03	63700.00
6C4ADC	2017-08-05 22:34:00+03	122300.00
6C4B02	2017-08-12 12:40:00+03	201800.00
6C4B3B	2017-08-01 08:02:00+03	192700.00
6C4BE4	2017-07-31 10:35:00+03	23400.00
6C4BEA	2017-07-27 16:42:00+03	46300.00
6C4BF2	2017-08-14 01:57:00+03	492000.00
6C4BF9	2017-07-07 21:34:00+03	24800.00
6C4C22	2017-07-06 05:08:00+03	112000.00
6C4C3C	2017-08-15 05:22:00+03	32700.00
6C4C8F	2017-07-10 09:49:00+03	46000.00
6C4CC5	2017-08-09 15:40:00+03	40400.00
6C4D1E	2017-07-21 01:34:00+03	63400.00
6C4D48	2017-07-13 03:21:00+03	16400.00
6C4D98	2017-08-05 18:41:00+03	69000.00
6C4DFD	2017-08-06 09:40:00+03	78100.00
6C4E11	2017-07-03 17:46:00+03	27900.00
6C4E2C	2017-07-24 02:49:00+03	28000.00
6C4E7C	2017-07-12 14:32:00+03	72400.00
6C4EF8	2017-07-01 08:14:00+03	43900.00
6C4F1D	2017-08-06 08:25:00+03	27200.00
6C4F1E	2017-08-07 01:18:00+03	111600.00
6C4F3C	2017-08-03 00:12:00+03	47200.00
6C4FD6	2017-07-15 19:17:00+03	13200.00
6C4FF2	2017-06-30 11:02:00+03	56100.00
6C5093	2017-07-15 09:59:00+03	52600.00
6C50C7	2017-08-14 08:08:00+03	83000.00
6C50EE	2017-08-04 07:17:00+03	37200.00
6C50F6	2017-07-16 03:25:00+03	32800.00
6C5128	2017-08-14 17:04:00+03	54800.00
6C5136	2017-07-04 06:52:00+03	6800.00
6C513F	2017-07-09 13:30:00+03	13600.00
6C517E	2017-07-14 10:08:00+03	53600.00
6C51A7	2017-08-13 07:58:00+03	201000.00
6C51D0	2017-07-17 02:51:00+03	49300.00
6C5291	2017-07-09 07:44:00+03	58000.00
6C52A1	2017-07-19 17:28:00+03	32800.00
6C53C7	2017-07-03 06:42:00+03	67400.00
6C53F6	2017-07-17 18:18:00+03	50600.00
6C543B	2017-07-10 18:09:00+03	25000.00
6C5459	2017-07-19 12:43:00+03	87700.00
6C54D5	2017-07-20 09:13:00+03	86300.00
6C54FD	2017-07-18 06:30:00+03	47000.00
6C5563	2017-07-31 00:31:00+03	77700.00
6C5585	2017-07-12 07:08:00+03	21400.00
6C55AB	2017-07-05 21:01:00+03	39800.00
6C55D2	2017-07-16 08:02:00+03	258400.00
6C5614	2017-07-26 04:41:00+03	32300.00
6C5633	2017-08-05 02:37:00+03	136000.00
6C5642	2017-07-11 15:47:00+03	265600.00
6C56A3	2017-07-21 06:30:00+03	40800.00
6C56DB	2017-07-27 09:20:00+03	47000.00
6C56F7	2017-07-20 12:39:00+03	96800.00
6C570E	2017-07-15 11:23:00+03	16400.00
6C570F	2017-07-05 21:48:00+03	15400.00
6C573A	2017-07-18 20:43:00+03	18000.00
6C573D	2017-07-03 05:21:00+03	91500.00
6C5766	2017-08-07 14:00:00+03	39600.00
6C57C3	2017-07-23 14:47:00+03	134000.00
6C5811	2017-08-06 19:10:00+03	123000.00
6C581D	2017-07-24 06:42:00+03	86800.00
6C5936	2017-07-23 03:48:00+03	24400.00
6C595E	2017-07-29 12:26:00+03	25100.00
6C597E	2017-07-18 09:28:00+03	184300.00
6C5A12	2017-07-09 07:40:00+03	34700.00
6C5A52	2017-07-27 14:24:00+03	25000.00
6C5A95	2017-07-09 23:49:00+03	43200.00
6C5AD8	2017-07-08 14:07:00+03	21400.00
6C5AE6	2017-08-04 00:41:00+03	75300.00
6C5AFA	2017-08-10 17:03:00+03	131100.00
6C5B33	2017-07-02 22:53:00+03	49500.00
6C5C26	2017-07-17 21:54:00+03	103900.00
6C5C42	2017-07-13 16:00:00+03	6000.00
6C5C68	2017-07-02 22:02:00+03	124200.00
6C5CA1	2017-07-06 00:06:00+03	46400.00
6C5CC1	2017-07-18 01:41:00+03	58600.00
6C5CDE	2017-07-22 12:08:00+03	39800.00
6C5D7D	2017-07-18 07:35:00+03	58200.00
6C5DAE	2017-08-12 21:23:00+03	18600.00
6C5DB2	2017-08-12 18:01:00+03	89400.00
6C5E1F	2017-07-16 05:07:00+03	18000.00
6C5E29	2017-07-20 10:33:00+03	23400.00
6C5E3C	2017-07-04 01:40:00+03	92800.00
6C5E98	2017-07-24 03:37:00+03	271100.00
6C5EC6	2017-07-30 16:35:00+03	23600.00
6C5EC7	2017-07-31 04:37:00+03	12600.00
6C5ED3	2017-07-06 01:52:00+03	29300.00
6C5F2A	2017-08-02 11:21:00+03	145400.00
6C5F2D	2017-07-24 07:13:00+03	6300.00
6C5F6C	2017-08-07 22:09:00+03	132800.00
6C5F97	2017-07-31 11:41:00+03	27800.00
6C5FCA	2017-07-25 12:31:00+03	38600.00
6C6046	2017-07-16 05:36:00+03	274200.00
6C608B	2017-07-27 07:39:00+03	13600.00
6C60C6	2017-07-23 18:00:00+03	53400.00
6C60D7	2017-07-14 23:05:00+03	34000.00
6C6116	2017-08-04 20:18:00+03	52000.00
6C6130	2017-07-13 01:14:00+03	31100.00
6C6133	2017-07-31 05:22:00+03	12600.00
6C6166	2017-07-09 04:23:00+03	58900.00
6C6193	2017-08-12 18:12:00+03	53300.00
6C6195	2017-08-06 06:44:00+03	65900.00
6C6199	2017-07-23 15:11:00+03	56000.00
6C61A6	2017-07-30 16:42:00+03	174400.00
6C61FA	2017-07-29 09:28:00+03	296400.00
6C6205	2017-07-09 12:23:00+03	181600.00
6C625E	2017-07-18 20:13:00+03	48800.00
6C62C3	2017-07-08 00:12:00+03	46400.00
6C62D2	2017-07-03 00:09:00+03	15800.00
6C63F5	2017-07-20 05:47:00+03	92400.00
6C649A	2017-07-07 10:24:00+03	31600.00
6C64B9	2017-07-19 04:46:00+03	40000.00
6C659B	2017-07-22 02:47:00+03	52300.00
6C65B7	2017-07-11 10:17:00+03	387800.00
6C65F9	2017-07-16 13:39:00+03	95200.00
6C6629	2017-08-13 23:53:00+03	56600.00
6C663B	2017-07-22 14:46:00+03	25200.00
6C669C	2017-07-27 07:42:00+03	135400.00
6C66C2	2017-08-07 23:07:00+03	135600.00
6C672F	2017-07-05 16:29:00+03	75300.00
6C6738	2017-07-03 08:18:00+03	23200.00
6C67D2	2017-08-06 20:35:00+03	331900.00
6C6849	2017-07-09 01:37:00+03	59800.00
6C68A1	2017-07-13 13:51:00+03	67200.00
6C68C9	2017-08-15 17:26:00+03	46300.00
6C68F0	2017-07-20 17:57:00+03	30400.00
6C693C	2017-07-22 06:17:00+03	103500.00
6C696C	2017-08-08 00:18:00+03	87100.00
6C6989	2017-08-05 07:37:00+03	25400.00
6C69A1	2017-08-02 08:17:00+03	73500.00
6C69C4	2017-07-30 18:34:00+03	25800.00
6C6AAE	2017-07-24 17:07:00+03	147800.00
6C6B5A	2017-07-23 15:50:00+03	62800.00
6C6B8D	2017-07-30 18:04:00+03	227500.00
6C6B9D	2017-07-22 01:33:00+03	56000.00
6C6BBE	2017-08-11 18:28:00+03	135600.00
6C6BBF	2017-08-13 06:42:00+03	16400.00
6C6BC0	2017-07-27 05:59:00+03	246000.00
6C6C1E	2017-07-12 07:26:00+03	56000.00
6C6C42	2017-07-06 22:14:00+03	185500.00
6C6C51	2017-07-29 17:17:00+03	21400.00
6C6C96	2017-07-02 12:20:00+03	131100.00
6C6D1A	2017-07-01 06:05:00+03	201800.00
6C6D50	2017-08-02 13:46:00+03	37100.00
6C6D6A	2017-07-11 20:11:00+03	78600.00
6C6DA6	2017-07-03 08:31:00+03	61800.00
6C6DBB	2017-07-19 17:31:00+03	41800.00
6C6DE0	2017-07-26 19:47:00+03	113200.00
6C6E11	2017-07-17 12:16:00+03	99300.00
6C6E14	2017-07-14 05:14:00+03	105100.00
6C6E1A	2017-07-27 01:40:00+03	6800.00
6C6E88	2017-08-04 13:00:00+03	26000.00
6C6E99	2017-07-03 00:14:00+03	21400.00
6C6EA6	2017-07-16 00:46:00+03	8400.00
6C6F58	2017-07-11 11:31:00+03	55800.00
6C6F8A	2017-07-20 00:07:00+03	86800.00
6C6F98	2017-07-22 11:24:00+03	99300.00
6C6F9A	2017-07-14 11:14:00+03	56000.00
6C6FA0	2017-07-30 14:48:00+03	28800.00
6C6FB0	2017-07-04 12:14:00+03	40800.00
6C6FCC	2017-07-24 10:24:00+03	46200.00
6C6FE9	2017-08-13 22:28:00+03	53700.00
6C6FEE	2017-07-26 10:10:00+03	121800.00
6C706F	2017-06-30 07:46:00+03	136200.00
6C707D	2017-08-14 20:17:00+03	82900.00
6C7080	2017-07-30 19:28:00+03	36600.00
6C70C9	2017-07-29 18:29:00+03	26000.00
6C70DF	2017-08-09 05:21:00+03	23600.00
6C70E3	2017-07-12 11:49:00+03	126000.00
6C70F7	2017-07-08 17:47:00+03	94000.00
6C7191	2017-08-07 12:10:00+03	43200.00
6C71E7	2017-07-15 22:48:00+03	46400.00
6C7210	2017-07-20 23:53:00+03	131100.00
6C7296	2017-07-07 10:05:00+03	188000.00
6C7304	2017-07-02 12:04:00+03	48400.00
6C73B9	2017-08-02 00:24:00+03	75600.00
6C73D0	2017-07-25 03:17:00+03	83000.00
6C73E0	2017-07-25 00:35:00+03	172600.00
6C7415	2017-08-01 23:03:00+03	86600.00
6C7416	2017-08-05 23:40:00+03	142300.00
6C7468	2017-07-29 10:35:00+03	80000.00
6C7497	2017-08-11 23:36:00+03	55800.00
6C7506	2017-07-28 18:00:00+03	29000.00
6C751F	2017-07-31 15:41:00+03	56000.00
6C752C	2017-08-11 12:36:00+03	22000.00
6C753A	2017-07-01 23:04:00+03	90000.00
6C7553	2017-08-07 18:45:00+03	67600.00
6C755C	2017-07-20 12:51:00+03	249100.00
6C75C6	2017-07-25 08:12:00+03	69500.00
6C75F0	2017-07-16 01:31:00+03	283100.00
6C7614	2017-07-25 06:19:00+03	75300.00
6C761B	2017-08-01 21:33:00+03	272300.00
6C7649	2017-07-18 09:38:00+03	52700.00
6C76A6	2017-07-28 21:29:00+03	38600.00
6C76C2	2017-07-24 07:13:00+03	98000.00
6C7702	2017-08-03 18:51:00+03	58800.00
6C7704	2017-07-17 11:16:00+03	28800.00
6C7710	2017-08-02 16:23:00+03	99200.00
6C77AB	2017-07-08 10:04:00+03	47400.00
6C77C0	2017-07-13 19:44:00+03	64700.00
6C7884	2017-08-06 12:25:00+03	70700.00
6C78AE	2017-07-11 21:15:00+03	7400.00
6C78D0	2017-08-09 12:11:00+03	40000.00
6C78FD	2017-07-12 16:31:00+03	7200.00
6C79A2	2017-06-27 13:14:00+03	54000.00
6C7A3E	2017-07-22 17:12:00+03	271100.00
6C7AAB	2017-08-12 15:57:00+03	46400.00
6C7AC0	2017-08-03 07:13:00+03	12600.00
6C7AC6	2017-07-28 21:16:00+03	282300.00
6C7B82	2017-07-21 17:34:00+03	16400.00
6C7BC2	2017-07-15 05:06:00+03	56000.00
6C7C22	2017-07-26 03:00:00+03	130800.00
6C7C85	2017-07-09 10:00:00+03	174400.00
6C7CAE	2017-08-12 19:20:00+03	19600.00
6C7CD4	2017-07-27 22:41:00+03	46300.00
6C7CD8	2017-07-13 19:04:00+03	6900.00
6C7CE2	2017-08-07 07:04:00+03	166000.00
6C7CEF	2017-07-31 23:22:00+03	90000.00
6C7D30	2017-07-15 15:35:00+03	39800.00
6C7D4A	2017-07-13 20:29:00+03	34000.00
6C7D83	2017-07-06 22:38:00+03	265600.00
6C7DA9	2017-07-20 21:25:00+03	28000.00
6C7E1F	2017-08-09 17:02:00+03	41800.00
6C7E60	2017-07-27 22:53:00+03	21400.00
6C7EF3	2017-07-08 13:55:00+03	56000.00
6C7EF6	2017-08-04 12:19:00+03	57500.00
6C7F37	2017-07-10 18:44:00+03	30900.00
6C7F8D	2017-07-03 11:14:00+03	50600.00
6C7FF9	2017-07-02 02:07:00+03	24200.00
6C8032	2017-06-30 11:12:00+03	64800.00
6C8037	2017-07-24 16:30:00+03	88200.00
6C80A4	2017-07-18 00:46:00+03	323600.00
6C80BC	2017-08-05 06:35:00+03	35200.00
6C8139	2017-07-13 05:56:00+03	172500.00
6C8152	2017-07-02 04:03:00+03	42800.00
6C8188	2017-07-29 09:47:00+03	97000.00
6C81A2	2017-07-17 19:39:00+03	26000.00
6C81B2	2017-07-02 13:01:00+03	35300.00
6C81C0	2017-07-09 20:07:00+03	36200.00
6C81C3	2017-08-11 19:57:00+03	31300.00
6C8221	2017-08-14 23:06:00+03	46300.00
6C8247	2017-07-19 07:24:00+03	75600.00
6C8260	2017-07-31 20:51:00+03	54800.00
6C827B	2017-08-02 17:31:00+03	50800.00
6C829E	2017-07-14 18:29:00+03	55800.00
6C82B8	2017-08-13 23:06:00+03	126300.00
6C82F8	2017-07-11 14:17:00+03	20200.00
6C834C	2017-07-06 21:13:00+03	14400.00
6C83D5	2017-07-21 06:01:00+03	68400.00
6C8417	2017-07-28 06:49:00+03	29600.00
6C84A6	2017-07-08 15:27:00+03	46400.00
6C84F9	2017-07-07 18:18:00+03	55800.00
6C8562	2017-07-01 09:06:00+03	47200.00
6C8582	2017-08-06 09:26:00+03	18600.00
6C85AF	2017-07-14 10:40:00+03	21400.00
6C85B8	2017-08-13 20:25:00+03	243700.00
6C85DF	2017-08-13 09:06:00+03	57600.00
6C866C	2017-07-27 13:02:00+03	43400.00
6C86AD	2017-08-14 00:06:00+03	30200.00
6C86F7	2017-07-15 00:19:00+03	75300.00
6C8741	2017-07-07 20:29:00+03	163500.00
6C8748	2017-07-15 09:52:00+03	36800.00
6C875B	2017-07-21 23:59:00+03	46400.00
6C876F	2017-07-28 23:37:00+03	19600.00
6C877A	2017-07-15 13:27:00+03	293100.00
6C87B4	2017-07-11 20:57:00+03	408500.00
6C87B8	2017-08-06 17:50:00+03	20000.00
6C87D9	2017-07-19 22:30:00+03	61800.00
6C87E3	2017-07-03 06:06:00+03	44800.00
6C8820	2017-08-11 06:54:00+03	28800.00
6C8857	2017-07-29 02:04:00+03	265700.00
6C88D7	2017-07-08 05:44:00+03	26000.00
6C88E6	2017-07-13 03:21:00+03	85000.00
6C8902	2017-07-01 06:05:00+03	50600.00
6C891A	2017-07-15 12:29:00+03	12400.00
6C892B	2017-08-06 17:17:00+03	10800.00
6C898C	2017-07-22 01:44:00+03	77200.00
6C899E	2017-08-10 10:48:00+03	94000.00
6C89CE	2017-08-15 07:17:00+03	52700.00
6C8A07	2017-08-12 15:42:00+03	51500.00
6C8A4E	2017-08-13 04:39:00+03	85200.00
6C8A90	2017-07-11 03:26:00+03	47200.00
6C8AFF	2017-08-07 04:50:00+03	55800.00
6C8B03	2017-08-07 10:00:00+03	125000.00
6C8B16	2017-07-12 04:54:00+03	43900.00
6C8B42	2017-07-07 04:38:00+03	139400.00
6C8B52	2017-07-22 14:30:00+03	55800.00
6C8B73	2017-07-08 14:26:00+03	49000.00
6C8B88	2017-07-21 18:11:00+03	26700.00
6C8B90	2017-08-01 15:05:00+03	166000.00
6C8BA3	2017-07-03 11:57:00+03	65800.00
6C8BA7	2017-07-22 08:28:00+03	54600.00
6C8C14	2017-08-08 13:44:00+03	143100.00
6C8C57	2017-07-31 21:36:00+03	26400.00
6C8CA1	2017-07-07 06:49:00+03	492000.00
6C8CBC	2017-07-04 11:15:00+03	19500.00
6C8CC5	2017-08-09 17:38:00+03	136800.00
6C8D0C	2017-07-13 12:56:00+03	20400.00
6C8D2D	2017-07-23 17:27:00+03	23600.00
6C8D49	2017-07-30 09:38:00+03	24800.00
6C8DC5	2017-07-02 18:08:00+03	43500.00
6C8DF2	2017-08-02 01:37:00+03	51300.00
6C8E25	2017-08-01 16:34:00+03	26100.00
6C8E47	2017-07-15 04:35:00+03	28800.00
6C8E5E	2017-07-25 19:34:00+03	32700.00
6C8E64	2017-07-24 14:54:00+03	61800.00
6C8E99	2017-07-30 08:20:00+03	152500.00
6C8E9F	2017-07-17 00:01:00+03	181100.00
6C8F3A	2017-08-01 15:35:00+03	23200.00
6C8F80	2017-07-21 11:16:00+03	54800.00
6C8FC2	2017-07-29 09:28:00+03	65100.00
6C90AF	2017-08-06 22:13:00+03	107400.00
6C90ED	2017-08-11 04:15:00+03	40100.00
6C9137	2017-08-07 09:44:00+03	119600.00
6C914C	2017-07-13 14:56:00+03	36200.00
6C91B4	2017-07-16 20:53:00+03	17800.00
6C91C8	2017-07-31 05:54:00+03	65800.00
6C91EA	2017-08-03 21:52:00+03	66000.00
6C926E	2017-07-21 22:10:00+03	201000.00
6C92DD	2017-07-01 08:19:00+03	49200.00
6C92F3	2017-07-25 08:39:00+03	75400.00
6C9335	2017-07-17 18:34:00+03	177200.00
6C93DD	2017-07-18 00:25:00+03	28800.00
6C943A	2017-07-02 21:07:00+03	208200.00
6C9461	2017-07-25 08:44:00+03	176300.00
6C9532	2017-07-28 07:38:00+03	28000.00
6C95E0	2017-08-01 21:11:00+03	34400.00
6C961B	2017-06-30 08:04:00+03	70800.00
6C96EF	2017-07-29 20:51:00+03	22400.00
6C978F	2017-07-02 11:03:00+03	153300.00
6C97AF	2017-07-10 08:28:00+03	40400.00
6C97B7	2017-07-28 22:39:00+03	40400.00
6C97BB	2017-08-05 18:35:00+03	33100.00
6C9805	2017-07-02 03:36:00+03	170000.00
6C980D	2017-07-19 19:22:00+03	70700.00
6C988F	2017-07-08 21:43:00+03	101200.00
6C98EC	2017-07-09 07:51:00+03	68800.00
6C98EE	2017-08-13 14:11:00+03	29100.00
6C9948	2017-08-13 00:22:00+03	105600.00
6C995F	2017-07-27 06:48:00+03	115700.00
6C9967	2017-07-21 06:09:00+03	23600.00
6C9985	2017-07-26 04:25:00+03	41600.00
6C99A3	2017-08-07 16:52:00+03	123600.00
6C99B7	2017-08-01 13:58:00+03	47000.00
6C99F5	2017-06-30 05:23:00+03	40600.00
6C9A17	2017-08-04 13:42:00+03	201200.00
6C9A47	2017-08-13 17:11:00+03	61700.00
6C9A5E	2017-08-14 11:34:00+03	56000.00
6C9A82	2017-08-08 15:25:00+03	372500.00
6C9A9D	2017-07-08 23:03:00+03	45400.00
6C9AFC	2017-07-20 20:15:00+03	6700.00
6C9B07	2017-07-27 20:40:00+03	56000.00
6C9BC9	2017-08-13 08:22:00+03	34000.00
6C9C2E	2017-08-13 08:43:00+03	142000.00
6C9C71	2017-07-16 04:50:00+03	21400.00
6C9C7B	2017-07-12 06:22:00+03	73000.00
6C9CA4	2017-07-03 08:23:00+03	63700.00
6C9CA9	2017-07-24 22:35:00+03	124200.00
6C9CAC	2017-08-12 23:12:00+03	27600.00
6C9CD1	2017-07-13 10:35:00+03	166100.00
6C9CDC	2017-08-15 02:13:00+03	18600.00
6C9D0F	2017-08-15 17:50:00+03	266200.00
6C9D49	2017-07-15 17:00:00+03	85400.00
6C9D5A	2017-07-07 00:27:00+03	105000.00
6C9D7D	2017-07-24 19:11:00+03	43200.00
6C9E03	2017-07-12 00:37:00+03	27200.00
6C9E0C	2017-07-25 13:10:00+03	16400.00
6C9E56	2017-07-22 02:20:00+03	94700.00
6C9E80	2017-07-14 15:29:00+03	19600.00
6C9E85	2017-08-13 18:04:00+03	3400.00
6C9E9B	2017-07-15 12:44:00+03	68100.00
6C9F00	2017-07-18 09:03:00+03	332700.00
6C9F06	2017-07-24 14:39:00+03	19600.00
6C9F30	2017-07-10 15:59:00+03	81600.00
6C9F48	2017-08-13 11:32:00+03	117600.00
6C9F53	2017-08-01 16:12:00+03	56600.00
6C9F67	2017-08-09 04:38:00+03	33100.00
6C9F68	2017-06-30 18:09:00+03	95600.00
6CA0AC	2017-07-11 02:30:00+03	27200.00
6CA0AE	2017-07-30 20:49:00+03	49800.00
6CA0F9	2017-07-24 04:30:00+03	140600.00
6CA177	2017-07-02 14:22:00+03	38600.00
6CA1A4	2017-07-08 04:58:00+03	60700.00
6CA200	2017-07-16 10:01:00+03	100600.00
6CA27D	2017-07-31 21:15:00+03	37100.00
6CA289	2017-06-29 03:44:00+03	63300.00
6CA2C0	2017-07-07 03:50:00+03	83000.00
6CA2E5	2017-07-24 22:20:00+03	35300.00
6CA339	2017-08-12 06:28:00+03	75800.00
6CA347	2017-07-23 10:35:00+03	64700.00
6CA384	2017-07-29 14:36:00+03	55800.00
6CA388	2017-07-01 15:15:00+03	75600.00
6CA3E4	2017-07-20 08:58:00+03	52300.00
6CA43A	2017-08-14 23:08:00+03	96300.00
6CA443	2017-07-12 13:18:00+03	81800.00
6CA4A9	2017-07-11 05:10:00+03	492000.00
6CA4F5	2017-08-11 11:26:00+03	169300.00
6CA567	2017-07-26 15:03:00+03	22000.00
6CA5F8	2017-08-13 16:23:00+03	123000.00
6CA6CA	2017-07-10 23:54:00+03	56000.00
6CA6F4	2017-08-14 09:57:00+03	124000.00
6CA76C	2017-07-25 22:52:00+03	39500.00
6CA79E	2017-07-16 12:29:00+03	131600.00
6CA7AE	2017-07-08 05:12:00+03	21500.00
6CA7EF	2017-08-13 21:01:00+03	236900.00
6CA809	2017-08-13 01:52:00+03	24400.00
6CA818	2017-07-05 23:00:00+03	81700.00
6CA87F	2017-07-07 06:28:00+03	49100.00
6CA8C1	2017-08-03 11:21:00+03	12000.00
6CA8D6	2017-07-27 08:19:00+03	113300.00
6CA8E6	2017-07-09 01:43:00+03	61800.00
6CA951	2017-06-30 01:22:00+03	289800.00
6CA964	2017-07-25 14:30:00+03	32700.00
6CA9C1	2017-07-10 15:53:00+03	75600.00
6CAA4E	2017-07-26 08:25:00+03	45300.00
6CAA77	2017-07-13 02:06:00+03	27800.00
6CAABC	2017-08-12 17:01:00+03	70400.00
6CAAD9	2017-07-12 20:29:00+03	119500.00
6CAAE1	2017-07-08 13:58:00+03	28800.00
6CAB01	2017-07-02 22:28:00+03	64800.00
6CAB31	2017-07-07 05:47:00+03	94300.00
6CAB36	2017-08-04 03:31:00+03	49800.00
6CAB8B	2017-08-08 19:19:00+03	23600.00
6CABC3	2017-08-12 13:31:00+03	132200.00
6CABDF	2017-07-11 16:17:00+03	21800.00
6CAC24	2017-07-10 02:28:00+03	52400.00
6CAC33	2017-07-08 08:51:00+03	8000.00
6CAC53	2017-08-01 21:12:00+03	59100.00
6CAC64	2017-07-26 23:04:00+03	83600.00
6CAC7A	2017-08-09 07:38:00+03	133200.00
6CAC9B	2017-07-02 15:04:00+03	58200.00
6CAD60	2017-08-01 12:40:00+03	269500.00
6CAD6D	2017-07-21 14:52:00+03	27200.00
6CAD89	2017-07-19 08:06:00+03	92400.00
6CADB0	2017-08-01 08:43:00+03	265800.00
6CADB8	2017-08-14 22:48:00+03	25800.00
6CADCD	2017-08-08 11:32:00+03	90800.00
6CADE9	2017-07-09 18:54:00+03	25600.00
6CADF0	2017-08-14 15:59:00+03	51600.00
6CADF8	2017-07-11 05:34:00+03	191500.00
6CAE9F	2017-07-28 10:52:00+03	24200.00
6CAEDA	2017-07-09 07:52:00+03	31600.00
6CAF14	2017-08-14 07:34:00+03	40000.00
6CAF22	2017-07-14 14:07:00+03	16200.00
6CAF5F	2017-08-10 16:54:00+03	26000.00
6CAF65	2017-07-24 19:19:00+03	55800.00
6CAF92	2017-07-28 12:54:00+03	79600.00
6CB001	2017-07-25 11:59:00+03	144300.00
6CB036	2017-08-12 15:18:00+03	9200.00
6CB068	2017-07-01 10:25:00+03	67600.00
6CB07B	2017-07-26 23:04:00+03	61800.00
6CB0CE	2017-07-21 10:04:00+03	45100.00
6CB17E	2017-07-19 04:58:00+03	50600.00
6CB18E	2017-07-07 12:33:00+03	30200.00
6CB190	2017-07-21 17:21:00+03	185800.00
6CB1A9	2017-07-13 17:00:00+03	38300.00
6CB245	2017-07-18 02:06:00+03	68400.00
6CB275	2017-08-15 08:11:00+03	10600.00
6CB285	2017-07-15 11:28:00+03	19800.00
6CB2FD	2017-07-22 02:31:00+03	44800.00
6CB310	2017-07-31 05:19:00+03	57900.00
6CB324	2017-07-18 12:28:00+03	93400.00
6CB327	2017-07-04 09:32:00+03	14400.00
6CB378	2017-08-02 13:47:00+03	21800.00
6CB438	2017-08-05 07:48:00+03	103400.00
6CB448	2017-07-26 15:59:00+03	35200.00
6CB461	2017-07-19 14:23:00+03	135400.00
6CB4AF	2017-07-13 22:56:00+03	56100.00
6CB4B5	2017-07-21 18:15:00+03	40300.00
6CB52D	2017-08-14 01:06:00+03	56600.00
6CB568	2017-07-06 22:32:00+03	37900.00
6CB57C	2017-07-09 17:16:00+03	56000.00
6CB597	2017-07-12 04:23:00+03	187600.00
6CB61A	2017-07-08 07:54:00+03	31600.00
6CB61C	2017-08-10 00:10:00+03	23200.00
6CB653	2017-08-10 16:17:00+03	50100.00
6CB66A	2017-07-25 11:28:00+03	42800.00
6CB66F	2017-08-11 19:08:00+03	26000.00
6CB6D6	2017-07-09 09:43:00+03	48800.00
6CB6DF	2017-07-26 12:37:00+03	31600.00
6CB6EA	2017-08-05 06:20:00+03	20500.00
6CB720	2017-07-29 07:52:00+03	13400.00
6CB735	2017-08-04 20:53:00+03	82400.00
6CB741	2017-07-25 09:39:00+03	193200.00
6CB7B1	2017-07-24 00:27:00+03	28800.00
6CB7CA	2017-07-09 18:37:00+03	38600.00
6CB7F0	2017-08-15 14:25:00+03	48000.00
6CB83E	2017-07-19 22:41:00+03	87100.00
6CB8AA	2017-08-02 17:55:00+03	36200.00
6CB8F3	2017-07-27 10:48:00+03	119500.00
6CB903	2017-07-28 06:54:00+03	45100.00
6CB95E	2017-07-02 01:20:00+03	55800.00
6CB992	2017-08-13 09:18:00+03	286800.00
6CB9D2	2017-07-29 12:35:00+03	19000.00
6CBA09	2017-07-24 03:00:00+03	53000.00
6CBA17	2017-08-08 21:45:00+03	39400.00
6CBA4C	2017-07-14 08:34:00+03	182300.00
6CBA77	2017-06-29 18:52:00+03	30200.00
6CBAB2	2017-08-08 21:52:00+03	95600.00
6CBABE	2017-07-24 21:38:00+03	107700.00
6CBAD6	2017-07-31 16:17:00+03	6800.00
6CBAFE	2017-08-15 10:22:00+03	6800.00
6CBB25	2017-08-05 17:55:00+03	19300.00
6CBBBA	2017-07-11 20:55:00+03	246000.00
6CBBD4	2017-07-18 13:47:00+03	27300.00
6CBC27	2017-08-14 01:03:00+03	50600.00
6CBC85	2017-08-11 22:16:00+03	180000.00
6CBC98	2017-08-12 11:05:00+03	29000.00
6CBC9C	2017-07-25 00:50:00+03	103200.00
6CBCBA	2017-08-15 05:33:00+03	6000.00
6CBCF2	2017-07-22 09:04:00+03	66600.00
6CBD13	2017-07-22 11:03:00+03	55600.00
6CBDBC	2017-07-07 11:40:00+03	112000.00
6CBDF2	2017-08-06 21:16:00+03	20600.00
6CBE35	2017-07-14 12:59:00+03	36800.00
6CBE47	2017-08-11 23:34:00+03	22100.00
6CBE9A	2017-07-31 21:15:00+03	12000.00
6CBECE	2017-08-07 13:58:00+03	61800.00
6CBF65	2017-07-12 10:11:00+03	26700.00
6CBF66	2017-07-26 09:49:00+03	168000.00
6CBF77	2017-08-11 21:19:00+03	10800.00
6CBFC9	2017-08-12 19:46:00+03	84000.00
6CC071	2017-08-13 11:33:00+03	398400.00
6CC15C	2017-07-17 21:30:00+03	88000.00
6CC1A7	2017-07-12 23:59:00+03	6800.00
6CC1A9	2017-07-25 22:29:00+03	369000.00
6CC200	2017-08-03 17:13:00+03	13000.00
6CC26B	2017-08-07 19:42:00+03	21400.00
6CC28D	2017-07-03 21:26:00+03	88900.00
6CC2A2	2017-08-15 00:01:00+03	42800.00
6CC2C2	2017-08-15 06:58:00+03	199700.00
6CC2C3	2017-07-21 03:06:00+03	77600.00
6CC2E3	2017-07-12 16:03:00+03	168000.00
6CC2EF	2017-08-05 01:36:00+03	170700.00
6CC302	2017-08-05 08:09:00+03	29400.00
6CC354	2017-08-03 23:38:00+03	240600.00
6CC36A	2017-07-06 09:58:00+03	64000.00
6CC381	2017-08-12 16:17:00+03	12600.00
6CC382	2017-07-01 00:38:00+03	115900.00
6CC3AF	2017-07-11 07:31:00+03	46400.00
6CC3EB	2017-07-16 13:33:00+03	65800.00
6CC44F	2017-08-06 19:37:00+03	313800.00
6CC454	2017-07-02 01:56:00+03	32700.00
6CC470	2017-07-31 03:18:00+03	68400.00
6CC473	2017-07-10 09:31:00+03	68800.00
6CC50B	2017-07-07 09:02:00+03	29600.00
6CC5B1	2017-08-02 21:58:00+03	13000.00
6CC5C4	2017-08-05 20:53:00+03	36200.00
6CC5E4	2017-07-11 11:32:00+03	52000.00
6CC5F1	2017-07-04 04:59:00+03	136800.00
6CC65C	2017-07-31 05:01:00+03	41800.00
6CC66B	2017-07-28 14:47:00+03	131600.00
6CC6C9	2017-08-15 15:10:00+03	55800.00
6CC73C	2017-08-11 23:03:00+03	15000.00
6CC73E	2017-07-07 10:44:00+03	57800.00
6CC7CC	2017-08-08 05:38:00+03	8400.00
6CC7FA	2017-07-03 07:48:00+03	23400.00
6CC83B	2017-07-31 05:40:00+03	196100.00
6CC849	2017-07-26 05:56:00+03	45000.00
6CC859	2017-07-17 19:49:00+03	105200.00
6CC872	2017-07-29 13:07:00+03	151800.00
6CC895	2017-07-27 01:06:00+03	13600.00
6CC89E	2017-08-06 13:13:00+03	13500.00
6CC912	2017-07-12 09:04:00+03	56600.00
6CC952	2017-07-01 20:21:00+03	46200.00
6CC987	2017-08-12 23:39:00+03	56900.00
6CCA25	2017-08-02 13:27:00+03	29600.00
6CCA38	2017-07-09 04:28:00+03	56000.00
6CCAD3	2017-07-17 11:54:00+03	21400.00
6CCAD8	2017-07-13 00:34:00+03	34000.00
6CCB1E	2017-07-06 07:26:00+03	140900.00
6CCC69	2017-07-29 10:03:00+03	75200.00
6CCC6A	2017-07-08 17:24:00+03	14000.00
6CCC97	2017-07-05 12:32:00+03	229500.00
6CCCAA	2017-07-26 06:06:00+03	123000.00
6CCCD7	2017-07-20 21:42:00+03	56600.00
6CCCF3	2017-07-08 19:20:00+03	81300.00
6CCD62	2017-07-01 04:55:00+03	209900.00
6CCDB5	2017-07-23 11:01:00+03	39800.00
6CCDC4	2017-08-12 05:00:00+03	44100.00
6CCDCE	2017-07-08 01:39:00+03	77900.00
6CCDE7	2017-07-05 09:30:00+03	14000.00
6CCE00	2017-07-07 00:39:00+03	88500.00
6CCE1D	2017-08-02 05:26:00+03	11200.00
6CCE79	2017-07-27 16:53:00+03	40000.00
6CCE93	2017-08-10 21:04:00+03	33800.00
6CCEA5	2017-07-07 17:06:00+03	128800.00
6CCEF9	2017-07-15 03:57:00+03	100200.00
6CCF29	2017-07-12 01:16:00+03	34800.00
6CCF93	2017-07-16 12:02:00+03	72700.00
6CD045	2017-08-05 07:43:00+03	44800.00
6CD0C9	2017-08-09 14:25:00+03	40800.00
6CD126	2017-08-05 08:29:00+03	46400.00
6CD13F	2017-07-30 10:56:00+03	55800.00
6CD148	2017-08-10 08:20:00+03	56000.00
6CD18B	2017-07-30 17:34:00+03	132500.00
6CD1B4	2017-08-12 19:59:00+03	49200.00
6CD210	2017-07-28 10:08:00+03	91800.00
6CD28D	2017-08-05 23:02:00+03	71300.00
6CD311	2017-07-09 23:56:00+03	25400.00
6CD3BD	2017-07-31 02:26:00+03	38400.00
6CD474	2017-07-02 21:06:00+03	49500.00
6CD48C	2017-07-11 12:28:00+03	199800.00
6CD4E8	2017-08-06 22:52:00+03	44500.00
6CD4EB	2017-07-11 06:15:00+03	24700.00
6CD562	2017-07-17 23:44:00+03	57600.00
6CD584	2017-07-15 14:04:00+03	79000.00
6CD5EF	2017-07-17 03:31:00+03	83000.00
6CD5FD	2017-08-02 08:44:00+03	76800.00
6CD666	2017-06-29 15:47:00+03	43600.00
6CD667	2017-08-12 19:07:00+03	56900.00
6CD684	2017-08-12 03:12:00+03	393000.00
6CD782	2017-07-31 10:26:00+03	6700.00
6CD81A	2017-08-02 18:05:00+03	11000.00
6CD870	2017-08-08 08:03:00+03	25400.00
6CD886	2017-07-15 07:16:00+03	34000.00
6CD8D1	2017-07-19 03:32:00+03	32800.00
6CD8F9	2017-08-03 14:46:00+03	84000.00
6CD980	2017-08-04 09:05:00+03	88600.00
6CD992	2017-08-04 06:16:00+03	28700.00
6CD9CB	2017-08-14 15:10:00+03	224000.00
6CDA3B	2017-08-02 04:14:00+03	31600.00
6CDA75	2017-08-13 17:46:00+03	14400.00
6CDAD4	2017-07-03 17:47:00+03	88200.00
6CDB79	2017-08-11 05:29:00+03	55800.00
6CDB96	2017-07-27 02:49:00+03	97900.00
6CDBDE	2017-08-09 09:24:00+03	114800.00
6CDBEA	2017-07-05 09:00:00+03	58000.00
6CDC29	2017-07-04 07:49:00+03	17800.00
6CDC47	2017-08-04 18:03:00+03	99600.00
6CDCF1	2017-07-28 20:19:00+03	28000.00
6CDD0F	2017-08-12 02:26:00+03	99200.00
6CDD11	2017-07-11 19:18:00+03	85000.00
6CDDA4	2017-08-15 16:39:00+03	55600.00
6CDDD6	2017-08-04 06:19:00+03	29100.00
6CDDE6	2017-07-23 20:06:00+03	16400.00
6CDDF3	2017-08-05 05:58:00+03	46900.00
6CDE04	2017-07-07 10:10:00+03	70700.00
6CDE3E	2017-08-04 15:57:00+03	202400.00
6CDEA5	2017-06-27 17:15:00+03	45100.00
6CDF07	2017-07-10 23:13:00+03	369000.00
6CDF0C	2017-07-27 23:41:00+03	69500.00
6CDF16	2017-07-10 19:54:00+03	14000.00
6CDF29	2017-08-14 04:08:00+03	89100.00
6CDF78	2017-08-09 09:10:00+03	95600.00
6CDFC5	2017-08-10 06:46:00+03	6700.00
6CE043	2017-07-02 19:59:00+03	129600.00
6CE09F	2017-07-20 20:43:00+03	15000.00
6CE0A8	2017-08-13 22:34:00+03	48100.00
6CE0C9	2017-07-19 14:52:00+03	92600.00
6CE16A	2017-07-27 12:16:00+03	94400.00
6CE1E3	2017-07-10 16:16:00+03	73600.00
6CE1F0	2017-08-06 10:03:00+03	51900.00
6CE23B	2017-07-20 10:16:00+03	12400.00
6CE254	2017-07-19 19:05:00+03	44000.00
6CE280	2017-08-04 13:54:00+03	57500.00
6CE28C	2017-08-09 12:53:00+03	13600.00
6CE295	2017-08-07 06:27:00+03	46300.00
6CE2D9	2017-07-14 23:13:00+03	22000.00
6CE2E5	2017-07-02 04:34:00+03	42700.00
6CE389	2017-07-21 17:11:00+03	32800.00
6CE456	2017-07-06 05:26:00+03	59000.00
6CE458	2017-08-11 10:18:00+03	56900.00
6CE4DB	2017-07-21 18:46:00+03	304200.00
6CE59E	2017-07-14 08:58:00+03	80800.00
6CE5D7	2017-07-21 02:46:00+03	46300.00
6CE61F	2017-07-31 20:32:00+03	50400.00
6CE647	2017-08-06 09:06:00+03	58900.00
6CE6BD	2017-07-09 16:34:00+03	16400.00
6CE70E	2017-08-04 10:51:00+03	25600.00
6CE768	2017-07-17 10:54:00+03	48300.00
6CE7A7	2017-08-02 05:16:00+03	66600.00
6CE80B	2017-07-07 02:03:00+03	103200.00
6CE856	2017-07-25 23:30:00+03	93000.00
6CE85A	2017-08-02 10:34:00+03	26000.00
6CE871	2017-07-06 10:19:00+03	83800.00
6CE8AD	2017-07-15 13:43:00+03	23400.00
6CE8F7	2017-07-19 16:02:00+03	155600.00
6CE9C3	2017-08-15 04:01:00+03	146700.00
6CE9E5	2017-07-08 04:48:00+03	123000.00
6CEA5C	2017-08-09 19:08:00+03	47200.00
6CEA86	2017-07-16 20:26:00+03	58900.00
6CEAFB	2017-07-02 14:45:00+03	40600.00
6CEB69	2017-07-26 21:30:00+03	134400.00
6CEBA1	2017-07-13 16:45:00+03	119600.00
6CEBE1	2017-08-15 10:09:00+03	25600.00
6CEBF7	2017-07-23 18:18:00+03	168000.00
6CECC8	2017-08-09 06:24:00+03	103700.00
6CED6C	2017-07-15 18:20:00+03	28300.00
6CEDA5	2017-07-23 18:12:00+03	67600.00
6CEDAD	2017-07-13 17:38:00+03	62000.00
6CEDC0	2017-07-10 06:53:00+03	103700.00
6CEDDB	2017-08-03 07:15:00+03	28000.00
6CEE0A	2017-08-12 21:21:00+03	193700.00
6CEE21	2017-07-22 16:44:00+03	57500.00
6CEE6D	2017-07-04 09:47:00+03	23600.00
6CEE72	2017-07-09 12:23:00+03	53100.00
6CEEF1	2017-07-25 14:04:00+03	27200.00
6CEF30	2017-08-02 02:41:00+03	192200.00
6CEF54	2017-07-30 08:18:00+03	55600.00
6CEF81	2017-07-12 11:01:00+03	44000.00
6CEF8F	2017-08-06 10:56:00+03	20700.00
6CEFA5	2017-06-30 12:06:00+03	65400.00
6CF00B	2017-08-12 03:13:00+03	49200.00
6CF018	2017-08-03 09:08:00+03	28800.00
6CF042	2017-08-10 00:57:00+03	24400.00
6CF151	2017-07-28 01:04:00+03	246000.00
6CF16B	2017-07-11 12:41:00+03	36200.00
6CF217	2017-08-12 09:16:00+03	79600.00
6CF2D1	2017-08-11 22:13:00+03	45100.00
6CF3A3	2017-07-26 02:17:00+03	137100.00
6CF3A6	2017-07-10 11:17:00+03	39800.00
6CF3B7	2017-07-27 02:43:00+03	31400.00
6CF3D3	2017-08-13 13:22:00+03	31600.00
6CF3E4	2017-07-25 22:06:00+03	461300.00
6CF401	2017-06-28 18:35:00+03	24800.00
6CF419	2017-07-19 08:12:00+03	50600.00
6CF459	2017-07-30 14:15:00+03	26500.00
6CF466	2017-08-09 12:52:00+03	30800.00
6CF467	2017-07-16 16:52:00+03	76100.00
6CF516	2017-08-04 12:37:00+03	49600.00
6CF52B	2017-07-16 16:08:00+03	266400.00
6CF545	2017-08-12 18:34:00+03	90600.00
6CF5DB	2017-07-17 22:41:00+03	25600.00
6CF663	2017-07-12 09:52:00+03	30200.00
6CF68F	2017-08-14 01:18:00+03	56100.00
6CF6EF	2017-07-19 14:43:00+03	73600.00
6CF700	2017-07-08 13:19:00+03	56000.00
6CF70F	2017-08-09 11:50:00+03	58000.00
6CF72E	2017-07-15 08:38:00+03	147200.00
6CF7CE	2017-07-22 06:38:00+03	12600.00
6CF821	2017-08-05 19:39:00+03	24400.00
6CF883	2017-07-19 09:24:00+03	58200.00
6CF8A1	2017-07-12 03:15:00+03	46700.00
6CF8B9	2017-08-12 12:17:00+03	48100.00
6CF939	2017-07-22 05:03:00+03	81700.00
6CF974	2017-07-27 23:26:00+03	120700.00
6CFA33	2017-07-01 08:53:00+03	97900.00
6CFAA6	2017-07-24 14:31:00+03	26000.00
6CFB1B	2017-08-04 08:16:00+03	21800.00
6CFB2B	2017-07-14 01:58:00+03	29400.00
6CFB77	2017-07-03 22:56:00+03	134700.00
6CFB8C	2017-07-13 18:31:00+03	23200.00
6CFBB5	2017-07-22 14:05:00+03	89600.00
6CFBC2	2017-07-18 17:00:00+03	55600.00
6CFBE4	2017-07-16 12:46:00+03	25600.00
6CFC32	2017-07-22 23:51:00+03	136000.00
6CFC7D	2017-07-12 21:15:00+03	258400.00
6CFD44	2017-08-06 15:03:00+03	28000.00
6CFDD0	2017-08-12 07:57:00+03	158700.00
6CFDF5	2017-07-05 13:12:00+03	28600.00
6CFE15	2017-07-06 10:23:00+03	99200.00
6CFE39	2017-07-30 14:00:00+03	189100.00
6CFE71	2017-08-13 02:06:00+03	13400.00
6CFEB8	2017-08-09 05:19:00+03	18200.00
6CFEBE	2017-07-11 08:31:00+03	61900.00
6CFF17	2017-07-14 14:48:00+03	133200.00
6CFF22	2017-07-05 09:20:00+03	49400.00
6CFF2F	2017-07-20 12:38:00+03	13400.00
6CFF37	2017-07-19 16:01:00+03	154500.00
6CFF9C	2017-07-26 03:29:00+03	24500.00
6CFFA7	2017-07-20 12:22:00+03	210000.00
6D0047	2017-08-11 12:13:00+03	12600.00
6D004A	2017-07-29 12:06:00+03	12400.00
6D0075	2017-08-13 21:06:00+03	231900.00
6D00A6	2017-07-03 19:38:00+03	36200.00
6D00C5	2017-07-06 13:34:00+03	19200.00
6D00D4	2017-07-10 14:04:00+03	12000.00
6D010F	2017-07-04 04:33:00+03	20400.00
6D0135	2017-07-22 10:50:00+03	67200.00
6D014A	2017-08-09 23:21:00+03	70800.00
6D018E	2017-08-11 14:43:00+03	61700.00
6D01A5	2017-07-09 08:43:00+03	116700.00
6D01AD	2017-08-14 15:12:00+03	37900.00
6D01F9	2017-08-12 01:41:00+03	237400.00
6D0218	2017-08-14 00:53:00+03	77900.00
6D023D	2017-08-05 03:27:00+03	79800.00
6D0256	2017-07-13 07:07:00+03	58200.00
6D02E8	2017-07-11 08:57:00+03	14800.00
6D0365	2017-08-11 14:16:00+03	129000.00
6D0368	2017-08-03 05:24:00+03	67100.00
6D0379	2017-07-28 17:30:00+03	6200.00
6D0398	2017-07-30 06:12:00+03	201200.00
6D0407	2017-07-27 00:56:00+03	8800.00
6D0447	2017-08-10 09:03:00+03	179400.00
6D065A	2017-07-27 21:49:00+03	6300.00
6D06E6	2017-06-30 20:16:00+03	28000.00
6D06F5	2017-08-10 07:56:00+03	38400.00
6D071B	2017-07-27 11:22:00+03	16800.00
6D072C	2017-07-29 00:46:00+03	48800.00
6D077D	2017-07-08 19:40:00+03	133200.00
6D07D1	2017-08-08 13:11:00+03	37000.00
6D080E	2017-07-19 20:42:00+03	23200.00
6D0815	2017-07-20 18:28:00+03	85000.00
6D0820	2017-07-08 19:36:00+03	176600.00
6D082C	2017-07-01 08:16:00+03	14000.00
6D085D	2017-07-16 11:01:00+03	29600.00
6D088B	2017-07-25 07:24:00+03	156400.00
6D08C7	2017-08-04 07:53:00+03	67200.00
6D0907	2017-08-08 04:48:00+03	43100.00
6D097F	2017-08-04 00:56:00+03	16800.00
6D0997	2017-07-24 18:44:00+03	35800.00
6D09A4	2017-07-05 02:27:00+03	21400.00
6D09A7	2017-07-20 14:56:00+03	103200.00
6D0A29	2017-08-15 10:48:00+03	43600.00
6D0AEE	2017-07-25 20:58:00+03	98300.00
6D0B88	2017-08-14 09:01:00+03	67600.00
6D0BBB	2017-08-08 17:37:00+03	10800.00
6D0C4B	2017-08-08 14:07:00+03	84100.00
6D0C54	2017-07-13 17:43:00+03	95200.00
6D0C8E	2017-07-19 12:45:00+03	265600.00
6D0D3F	2017-08-11 02:21:00+03	26700.00
6D0DB4	2017-07-21 10:29:00+03	52000.00
6D0DF3	2017-07-22 09:22:00+03	20200.00
6D0E38	2017-08-08 14:12:00+03	32700.00
6D0E58	2017-07-25 20:14:00+03	28800.00
6D0EC1	2017-06-28 11:00:00+03	84300.00
6D0EEA	2017-08-04 02:26:00+03	66300.00
6D0F2D	2017-07-27 05:45:00+03	81600.00
6D0F3D	2017-07-10 06:03:00+03	94800.00
6D0F94	2017-08-15 16:16:00+03	265800.00
6D0FAB	2017-08-03 06:56:00+03	838200.00
6D0FBB	2017-07-05 04:40:00+03	26800.00
6D0FD1	2017-07-30 08:36:00+03	28000.00
6D0FD7	2017-07-25 23:19:00+03	189800.00
6D0FFA	2017-07-22 21:26:00+03	133100.00
6D1057	2017-08-11 21:03:00+03	24800.00
6D1067	2017-08-06 12:07:00+03	133200.00
6D10A4	2017-07-10 09:41:00+03	116400.00
6D10B8	2017-08-06 10:28:00+03	101200.00
6D10DB	2017-06-30 19:54:00+03	8200.00
6D1119	2017-07-04 13:04:00+03	89700.00
6D1133	2017-08-09 01:40:00+03	77500.00
6D117A	2017-08-04 12:27:00+03	31800.00
6D11DC	2017-07-08 16:53:00+03	56000.00
6D1243	2017-07-24 11:04:00+03	49100.00
6D1249	2017-07-19 06:23:00+03	23200.00
6D125D	2017-08-11 01:10:00+03	19600.00
6D127C	2017-07-13 16:29:00+03	12600.00
6D12B4	2017-07-31 13:03:00+03	10800.00
6D12B7	2017-08-05 13:44:00+03	46400.00
6D12F6	2017-07-30 18:18:00+03	55800.00
6D133C	2017-07-19 01:39:00+03	29400.00
6D133E	2017-08-07 15:44:00+03	28700.00
6D136C	2017-07-23 05:44:00+03	50000.00
6D137F	2017-07-27 15:54:00+03	25400.00
6D13A6	2017-07-12 23:08:00+03	139900.00
6D13BB	2017-07-05 22:48:00+03	21400.00
6D13D3	2017-07-08 08:49:00+03	48800.00
6D1432	2017-07-13 20:40:00+03	93500.00
6D148B	2017-07-26 16:18:00+03	23200.00
6D1501	2017-07-09 22:40:00+03	50400.00
6D1504	2017-07-09 04:13:00+03	62100.00
6D15B2	2017-07-19 21:12:00+03	48800.00
6D15B8	2017-07-06 11:05:00+03	23200.00
6D15FA	2017-07-17 15:00:00+03	59800.00
6D1638	2017-07-13 09:54:00+03	23600.00
6D1645	2017-07-21 19:39:00+03	92000.00
6D1651	2017-07-21 23:26:00+03	291000.00
6D1678	2017-07-13 10:09:00+03	7400.00
6D16B0	2017-08-13 11:36:00+03	47100.00
6D16EC	2017-08-14 07:36:00+03	100600.00
6D170F	2017-07-22 00:48:00+03	98200.00
6D171E	2017-07-19 03:25:00+03	40900.00
6D173D	2017-08-13 08:52:00+03	94300.00
6D173F	2017-07-01 20:19:00+03	428900.00
6D1750	2017-07-02 01:23:00+03	229100.00
6D176A	2017-08-02 16:52:00+03	19600.00
6D17F3	2017-07-05 20:50:00+03	7400.00
6D183E	2017-07-27 22:15:00+03	16400.00
6D1857	2017-07-26 00:45:00+03	142800.00
6D1866	2017-07-17 18:26:00+03	36200.00
6D187E	2017-07-03 15:24:00+03	24400.00
6D1893	2017-08-10 05:26:00+03	8600.00
6D1916	2017-07-27 08:17:00+03	56000.00
6D195D	2017-08-05 15:26:00+03	93700.00
6D1A03	2017-07-11 22:55:00+03	36400.00
6D1A16	2017-08-12 03:14:00+03	184200.00
6D1A2B	2017-07-02 08:28:00+03	71700.00
6D1A33	2017-06-28 13:31:00+03	75600.00
6D1A40	2017-07-21 17:18:00+03	194100.00
6D1A77	2017-07-11 18:19:00+03	98600.00
6D1A86	2017-07-15 22:51:00+03	26000.00
6D1AA4	2017-08-06 21:50:00+03	127900.00
6D1AEE	2017-08-15 02:54:00+03	17200.00
6D1B11	2017-08-01 16:03:00+03	28000.00
6D1B15	2017-07-16 12:38:00+03	63500.00
6D1B31	2017-07-09 19:23:00+03	67600.00
6D1BC7	2017-07-19 21:19:00+03	129400.00
6D1BE0	2017-07-23 05:03:00+03	75600.00
6D1C21	2017-08-05 09:33:00+03	76800.00
6D1C53	2017-07-24 04:35:00+03	38800.00
6D1C55	2017-07-31 06:50:00+03	78600.00
6D1C9C	2017-07-20 00:16:00+03	51300.00
6D1CA1	2017-08-01 20:45:00+03	41100.00
6D1CA5	2017-08-11 17:53:00+03	20000.00
6D1CF4	2017-08-13 15:56:00+03	95200.00
6D1DC5	2017-07-19 23:10:00+03	77200.00
6D1E1F	2017-07-04 08:12:00+03	6000.00
6D1E69	2017-07-03 17:34:00+03	88900.00
6D1F52	2017-08-14 03:20:00+03	257600.00
6D1F67	2017-07-03 06:25:00+03	59600.00
6D2009	2017-08-03 16:30:00+03	34000.00
6D202C	2017-08-01 02:29:00+03	119600.00
6D203D	2017-07-27 12:53:00+03	139400.00
6D2087	2017-08-10 04:19:00+03	131600.00
6D2093	2017-07-12 19:41:00+03	108600.00
6D20A6	2017-08-06 17:52:00+03	266200.00
6D2129	2017-07-05 15:38:00+03	112000.00
6D2152	2017-07-01 10:24:00+03	26800.00
6D215F	2017-07-22 07:07:00+03	52800.00
6D2186	2017-07-31 01:28:00+03	228400.00
6D2213	2017-07-23 14:54:00+03	25400.00
6D222A	2017-08-03 02:20:00+03	28000.00
6D2258	2017-07-16 15:17:00+03	68800.00
6D22C5	2017-07-19 12:23:00+03	173200.00
6D2334	2017-07-04 02:37:00+03	23200.00
6D23DA	2017-07-28 08:21:00+03	81600.00
6D2434	2017-08-11 17:25:00+03	12400.00
6D246A	2017-07-02 10:09:00+03	14400.00
6D24A5	2017-07-30 17:22:00+03	129200.00
6D24B6	2017-08-14 20:15:00+03	56000.00
6D24CD	2017-07-03 20:06:00+03	151800.00
6D24DE	2017-07-02 21:04:00+03	114600.00
6D251B	2017-08-12 06:52:00+03	266400.00
6D2567	2017-06-28 21:46:00+03	46000.00
6D269D	2017-08-12 21:12:00+03	32700.00
6D26FF	2017-07-31 23:01:00+03	23400.00
6D2715	2017-07-20 18:53:00+03	90800.00
6D2761	2017-08-14 06:45:00+03	19600.00
6D2824	2017-08-12 20:39:00+03	15500.00
6D287C	2017-08-01 22:00:00+03	46800.00
6D288D	2017-07-12 01:54:00+03	55800.00
6D28B7	2017-08-12 08:59:00+03	304100.00
6D296E	2017-07-20 19:22:00+03	20600.00
6D2AAA	2017-08-07 21:22:00+03	56600.00
6D2B33	2017-07-14 22:22:00+03	95600.00
6D2B96	2017-07-13 05:50:00+03	59000.00
6D2BB3	2017-08-03 23:13:00+03	23600.00
6D2BD4	2017-07-09 11:10:00+03	58400.00
6D2C25	2017-07-15 19:19:00+03	26000.00
6D2C45	2017-07-31 05:46:00+03	66000.00
6D2C60	2017-08-07 07:04:00+03	94000.00
6D2C78	2017-07-08 06:11:00+03	16400.00
6D2CFA	2017-07-14 16:55:00+03	25000.00
6D2D0F	2017-08-07 07:35:00+03	33400.00
6D2D11	2017-07-25 19:11:00+03	8000.00
6D2D1B	2017-07-21 08:19:00+03	30200.00
6D2D83	2017-08-07 02:05:00+03	61700.00
6D2D8C	2017-07-20 05:57:00+03	133200.00
6D2DA0	2017-07-25 22:16:00+03	386300.00
6D2DC7	2017-07-12 00:31:00+03	28300.00
6D2E77	2017-07-31 12:56:00+03	117600.00
6D2E81	2017-07-30 09:13:00+03	56000.00
6D2EA5	2017-07-19 03:55:00+03	39200.00
6D2ECE	2017-08-04 14:14:00+03	112000.00
6D2EF0	2017-08-14 07:45:00+03	38600.00
6D2F12	2017-08-07 18:31:00+03	30300.00
6D2F2E	2017-07-18 14:58:00+03	99500.00
6D2F51	2017-07-10 15:59:00+03	15000.00
6D2FD9	2017-07-12 18:08:00+03	52400.00
6D300A	2017-07-09 19:39:00+03	112600.00
6D30A4	2017-08-01 13:12:00+03	6000.00
6D30F5	2017-07-24 23:10:00+03	48400.00
6D30FC	2017-07-07 01:06:00+03	23400.00
6D3148	2017-08-12 00:50:00+03	38800.00
6D3159	2017-07-19 06:21:00+03	73500.00
6D315A	2017-07-22 18:23:00+03	28000.00
6D3176	2017-07-12 06:13:00+03	60600.00
6D31E3	2017-07-14 16:56:00+03	41600.00
6D3218	2017-07-18 07:21:00+03	13600.00
6D32E8	2017-07-04 15:14:00+03	176800.00
6D3327	2017-08-11 11:44:00+03	64300.00
6D33F8	2017-08-10 03:57:00+03	100200.00
6D3416	2017-07-02 15:21:00+03	58200.00
6D342E	2017-07-30 14:47:00+03	13600.00
6D3467	2017-08-07 00:06:00+03	21400.00
6D34A2	2017-06-25 15:16:00+03	99200.00
6D34A7	2017-07-30 03:20:00+03	81300.00
6D3521	2017-08-05 08:56:00+03	114500.00
6D3575	2017-07-20 07:18:00+03	12000.00
6D35B0	2017-07-14 03:51:00+03	61800.00
6D3603	2017-07-07 18:57:00+03	107400.00
6D3637	2017-07-20 11:35:00+03	28800.00
6D3675	2017-08-08 20:56:00+03	89700.00
6D368B	2017-07-04 10:47:00+03	22000.00
6D36AF	2017-08-14 22:39:00+03	75700.00
6D36C1	2017-08-02 02:53:00+03	60400.00
6D37BF	2017-07-04 12:49:00+03	20000.00
6D380B	2017-08-13 18:56:00+03	46000.00
6D3835	2017-08-15 11:24:00+03	68600.00
6D38A1	2017-07-05 16:00:00+03	46000.00
6D38A6	2017-07-25 06:47:00+03	269400.00
6D38EB	2017-08-13 11:04:00+03	39500.00
6D392C	2017-07-03 08:35:00+03	55800.00
6D395C	2017-08-05 06:30:00+03	20400.00
6D396E	2017-07-12 12:14:00+03	45200.00
6D397E	2017-07-09 21:33:00+03	67600.00
6D39D2	2017-08-15 14:55:00+03	29900.00
6D39D8	2017-07-07 23:28:00+03	94000.00
6D39DE	2017-08-07 12:39:00+03	56000.00
6D3A08	2017-08-12 16:24:00+03	23600.00
6D3A0D	2017-07-20 22:39:00+03	68800.00
6D3A30	2017-07-24 22:54:00+03	68400.00
6D3A4B	2017-07-09 03:43:00+03	51900.00
6D3AFA	2017-07-05 14:54:00+03	64800.00
6D3B7D	2017-08-10 05:15:00+03	81700.00
6D3BFF	2017-07-07 16:09:00+03	58000.00
6D3C1A	2017-08-12 20:58:00+03	218400.00
6D3CC7	2017-08-02 05:26:00+03	57500.00
6D3DD5	2017-07-19 11:23:00+03	26800.00
6D3DDC	2017-08-15 14:36:00+03	113300.00
6D3E49	2017-08-10 04:18:00+03	145100.00
6D3E94	2017-07-20 00:21:00+03	26000.00
6D3E9D	2017-07-06 02:45:00+03	26000.00
6D3F8B	2017-07-11 00:49:00+03	18900.00
6D3FBC	2017-08-08 15:37:00+03	63400.00
6D3FC3	2017-08-09 09:54:00+03	79000.00
6D3FEC	2017-07-01 04:25:00+03	57500.00
6D403B	2017-08-07 08:25:00+03	40800.00
6D4081	2017-07-06 08:25:00+03	56000.00
6D408E	2017-07-05 06:09:00+03	56900.00
6D408F	2017-08-12 19:24:00+03	10600.00
6D40C7	2017-08-15 15:43:00+03	12000.00
6D40D4	2017-07-04 15:37:00+03	59800.00
6D40FB	2017-07-05 05:36:00+03	70500.00
6D4111	2017-07-06 21:48:00+03	32200.00
6D4121	2017-07-12 12:50:00+03	61700.00
6D41C1	2017-07-03 18:03:00+03	122500.00
6D4267	2017-08-04 07:03:00+03	42800.00
6D42E2	2017-07-16 20:55:00+03	61800.00
6D431B	2017-07-25 04:30:00+03	25000.00
6D4403	2017-07-05 15:10:00+03	339900.00
6D442F	2017-07-18 22:06:00+03	34400.00
6D444E	2017-07-13 23:54:00+03	112000.00
6D44E0	2017-08-13 09:13:00+03	11300.00
6D4577	2017-07-23 03:46:00+03	29600.00
6D4588	2017-07-28 05:25:00+03	10700.00
6D45AB	2017-07-14 03:55:00+03	18000.00
6D45E4	2017-07-20 15:28:00+03	51200.00
6D45FD	2017-08-08 23:01:00+03	134400.00
6D460A	2017-07-05 06:16:00+03	58900.00
6D463C	2017-07-24 17:06:00+03	135400.00
6D465F	2017-08-13 18:28:00+03	19600.00
6D4677	2017-07-30 00:12:00+03	109600.00
6D46B5	2017-08-05 17:32:00+03	23200.00
6D4716	2017-08-04 20:31:00+03	53300.00
6D4732	2017-08-05 15:53:00+03	34000.00
6D473F	2017-07-10 19:33:00+03	270800.00
6D4782	2017-07-06 10:43:00+03	28800.00
6D47E8	2017-07-26 10:16:00+03	17600.00
6D47F9	2017-07-06 20:05:00+03	22100.00
6D4803	2017-07-25 08:40:00+03	24800.00
6D483A	2017-06-28 13:25:00+03	133200.00
6D4848	2017-07-10 16:25:00+03	47200.00
6D4861	2017-07-16 09:06:00+03	38400.00
6D48AB	2017-07-05 11:26:00+03	23400.00
6D48BF	2017-08-14 17:25:00+03	79600.00
6D48D4	2017-08-01 01:45:00+03	59200.00
6D48D7	2017-08-02 14:21:00+03	75600.00
6D4945	2017-07-27 09:43:00+03	53700.00
6D49BB	2017-07-15 15:44:00+03	266400.00
6D4A13	2017-07-24 17:03:00+03	24400.00
6D4A3A	2017-07-08 05:29:00+03	51800.00
6D4A4E	2017-06-27 13:11:00+03	61400.00
6D4A53	2017-07-02 08:52:00+03	47600.00
6D4A71	2017-07-12 08:12:00+03	246000.00
6D4A82	2017-08-14 16:58:00+03	87400.00
6D4A86	2017-07-21 07:30:00+03	49800.00
6D4AA6	2017-07-29 23:44:00+03	113200.00
6D4AA8	2017-07-04 09:49:00+03	10800.00
6D4AE7	2017-08-13 18:09:00+03	43600.00
6D4AFB	2017-07-31 06:07:00+03	44600.00
6D4B7D	2017-07-09 17:20:00+03	42800.00
6D4C65	2017-07-18 08:16:00+03	25400.00
6D4CB6	2017-08-05 04:28:00+03	154800.00
6D4CF0	2017-08-01 03:49:00+03	118400.00
6D4DB9	2017-07-26 07:07:00+03	127300.00
6D4DDB	2017-07-25 12:35:00+03	46000.00
6D4E16	2017-07-18 12:23:00+03	44800.00
6D4E23	2017-08-14 15:37:00+03	22100.00
6D4E4F	2017-07-01 00:48:00+03	43900.00
6D4E8B	2017-08-12 15:05:00+03	45100.00
6D4EBD	2017-07-31 04:50:00+03	36000.00
6D4EBF	2017-07-22 00:47:00+03	12600.00
6D4F70	2017-07-07 04:50:00+03	28000.00
6D4F7D	2017-08-14 17:00:00+03	43600.00
6D501A	2017-08-05 06:23:00+03	12600.00
6D5066	2017-08-05 03:22:00+03	8000.00
6D507A	2017-07-05 07:59:00+03	149000.00
6D514B	2017-08-06 18:25:00+03	246000.00
6D5168	2017-07-22 02:42:00+03	76800.00
6D5186	2017-07-06 07:48:00+03	28800.00
6D51E2	2017-08-13 20:35:00+03	199700.00
6D51F7	2017-07-17 21:10:00+03	114800.00
6D5221	2017-08-01 03:04:00+03	80000.00
6D5266	2017-07-27 16:10:00+03	38600.00
6D528B	2017-07-20 05:28:00+03	52900.00
6D52F8	2017-07-13 17:45:00+03	25400.00
6D5371	2017-06-28 23:09:00+03	177200.00
6D53DE	2017-08-11 23:21:00+03	62900.00
6D54CB	2017-08-06 09:51:00+03	34000.00
6D550B	2017-08-11 14:03:00+03	40000.00
6D5529	2017-07-22 13:56:00+03	92800.00
6D556A	2017-07-15 14:34:00+03	28800.00
6D55BB	2017-08-06 06:52:00+03	58700.00
6D560B	2017-07-01 16:08:00+03	72400.00
6D5617	2017-07-11 05:42:00+03	38400.00
6D5647	2017-07-28 20:36:00+03	84100.00
6D5648	2017-07-31 04:59:00+03	31600.00
6D569B	2017-08-02 07:01:00+03	46400.00
6D57E2	2017-07-10 20:21:00+03	78000.00
6D5842	2017-07-16 13:00:00+03	55800.00
6D585B	2017-08-03 12:01:00+03	83000.00
6D5892	2017-07-06 16:52:00+03	133200.00
6D58C4	2017-07-31 15:31:00+03	6700.00
6D58EF	2017-07-05 18:31:00+03	58400.00
6D5945	2017-07-14 07:43:00+03	25400.00
6D5977	2017-07-26 06:06:00+03	38000.00
6D59AE	2017-07-18 00:12:00+03	8000.00
6D59F2	2017-08-09 17:34:00+03	140400.00
6D5A17	2017-07-06 00:47:00+03	19600.00
6D5A5A	2017-08-06 17:41:00+03	58300.00
6D5A71	2017-07-01 21:39:00+03	398500.00
6D5A8C	2017-08-10 22:03:00+03	58000.00
6D5AC0	2017-07-31 15:07:00+03	40000.00
6D5AE1	2017-07-08 05:12:00+03	85000.00
6D5B80	2017-07-03 22:30:00+03	16400.00
6D5BAA	2017-08-04 15:38:00+03	12000.00
6D5BB8	2017-07-11 12:58:00+03	47000.00
6D5BEF	2017-08-09 08:45:00+03	38200.00
6D5C08	2017-07-14 18:01:00+03	139300.00
6D5C6F	2017-07-24 21:16:00+03	28000.00
6D5CB2	2017-08-02 03:28:00+03	203100.00
6D5CD3	2017-07-08 02:17:00+03	57600.00
6D5CDF	2017-08-13 06:33:00+03	121200.00
6D5CF7	2017-08-08 01:45:00+03	72700.00
6D5D72	2017-08-14 01:49:00+03	369000.00
6D5DC4	2017-07-11 21:43:00+03	54200.00
6D5DF2	2017-07-20 13:31:00+03	81700.00
6D5DF7	2017-07-13 03:29:00+03	298600.00
6D5E17	2017-07-18 23:09:00+03	13700.00
6D5EBE	2017-08-03 14:12:00+03	47000.00
6D5F05	2017-07-18 18:49:00+03	12400.00
6D5F12	2017-07-18 11:27:00+03	69000.00
6D5F15	2017-08-04 22:07:00+03	24400.00
6D5F3C	2017-07-31 14:30:00+03	30400.00
6D5F84	2017-07-31 00:23:00+03	23200.00
6D5F9C	2017-07-28 14:01:00+03	48500.00
6D5FA4	2017-07-08 09:29:00+03	94000.00
6D5FD4	2017-07-24 04:13:00+03	3700.00
6D5FF2	2017-08-08 18:56:00+03	14400.00
6D5FF9	2017-07-16 19:26:00+03	89200.00
6D6030	2017-07-21 12:03:00+03	25200.00
6D604D	2017-08-10 20:53:00+03	29600.00
6D60C8	2017-08-13 08:34:00+03	35200.00
6D60CE	2017-07-30 11:53:00+03	47600.00
6D60F2	2017-07-31 14:31:00+03	89200.00
6D6116	2017-07-03 05:07:00+03	122700.00
6D6170	2017-08-14 14:45:00+03	39300.00
6D61A1	2017-07-19 05:06:00+03	61200.00
6D61EF	2017-07-28 18:44:00+03	131600.00
6D61FB	2017-07-24 06:57:00+03	86500.00
6D6237	2017-07-22 05:16:00+03	64100.00
6D6274	2017-08-08 19:55:00+03	81600.00
6D62ED	2017-07-07 06:58:00+03	99300.00
6D6328	2017-07-16 05:08:00+03	271100.00
6D6349	2017-07-14 12:57:00+03	32800.00
6D6365	2017-08-02 22:33:00+03	40000.00
6D63C1	2017-07-10 07:02:00+03	88100.00
6D6423	2017-07-28 10:13:00+03	106100.00
6D6434	2017-08-01 19:32:00+03	40200.00
6D6438	2017-07-10 05:45:00+03	88800.00
6D6442	2017-07-20 22:22:00+03	34000.00
6D645E	2017-07-09 06:35:00+03	14400.00
6D64E4	2017-07-10 18:30:00+03	400300.00
6D6551	2017-08-07 15:23:00+03	40800.00
6D657B	2017-08-13 11:11:00+03	67200.00
6D658E	2017-07-25 15:12:00+03	162500.00
6D6590	2017-07-31 03:18:00+03	189100.00
6D65CD	2017-07-21 15:47:00+03	37700.00
6D65ED	2017-07-24 17:35:00+03	25200.00
6D662B	2017-07-20 06:44:00+03	43200.00
6D6655	2017-07-18 11:40:00+03	18600.00
6D665B	2017-07-21 08:38:00+03	177200.00
6D6676	2017-07-01 15:03:00+03	92000.00
6D6691	2017-07-21 07:21:00+03	38000.00
6D66C1	2017-07-31 07:20:00+03	163200.00
6D670A	2017-07-18 22:52:00+03	97900.00
6D6778	2017-07-19 02:41:00+03	21400.00
6D6816	2017-07-06 09:46:00+03	67600.00
6D6966	2017-07-25 17:28:00+03	73500.00
6D6968	2017-07-01 13:02:00+03	23200.00
6D69F6	2017-07-04 17:46:00+03	201200.00
6D6A06	2017-07-27 02:58:00+03	40600.00
6D6A7E	2017-08-04 17:19:00+03	14000.00
6D6ABC	2017-07-24 19:28:00+03	21400.00
6D6AD2	2017-07-26 13:27:00+03	13600.00
6D6B0D	2017-08-12 06:36:00+03	41200.00
6D6B88	2017-07-23 21:02:00+03	213300.00
6D6BC7	2017-06-28 07:34:00+03	48100.00
6D6BF6	2017-07-31 04:59:00+03	159100.00
6D6C0C	2017-07-04 15:02:00+03	64400.00
6D6C0E	2017-08-02 10:21:00+03	77200.00
6D6C6A	2017-07-18 21:54:00+03	170800.00
6D6D54	2017-08-01 00:01:00+03	58600.00
6D6D61	2017-07-27 22:03:00+03	124200.00
6D6D9E	2017-08-13 01:56:00+03	54800.00
6D6DBE	2017-07-21 09:04:00+03	28000.00
6D6DBF	2017-08-03 10:02:00+03	131100.00
6D6DF5	2017-07-14 18:28:00+03	24400.00
6D6E06	2017-07-09 04:18:00+03	24800.00
6D6E53	2017-07-27 02:46:00+03	26000.00
6D6EA3	2017-07-30 15:55:00+03	28000.00
6D6F30	2017-07-28 23:21:00+03	29000.00
6D6F32	2017-07-06 10:21:00+03	29200.00
6D6F4F	2017-07-30 23:15:00+03	119600.00
6D7026	2017-07-13 20:09:00+03	136800.00
6D7050	2017-07-18 02:10:00+03	47400.00
6D70E0	2017-08-09 14:43:00+03	18600.00
6D7170	2017-07-02 21:31:00+03	27800.00
6D71A5	2017-07-24 22:17:00+03	97100.00
6D71FA	2017-07-15 03:01:00+03	112200.00
6D7268	2017-08-09 23:38:00+03	36200.00
6D728E	2017-07-31 14:23:00+03	37100.00
6D72BD	2017-07-15 18:55:00+03	135400.00
6D72D6	2017-08-03 14:31:00+03	16400.00
6D7319	2017-08-13 15:31:00+03	133200.00
6D7357	2017-07-10 08:07:00+03	47400.00
6D7358	2017-06-27 22:30:00+03	29400.00
6D735A	2017-07-28 14:22:00+03	25400.00
6D73A9	2017-08-03 21:20:00+03	27200.00
6D7400	2017-07-30 05:20:00+03	28000.00
6D740C	2017-08-01 07:09:00+03	37000.00
6D743D	2017-07-06 16:46:00+03	172500.00
6D7451	2017-08-11 01:30:00+03	24000.00
6D74E5	2017-07-26 02:16:00+03	223200.00
6D7523	2017-07-20 05:15:00+03	199700.00
6D7547	2017-08-13 02:43:00+03	23600.00
6D7568	2017-08-06 03:01:00+03	40300.00
6D75C3	2017-08-07 03:02:00+03	52000.00
6D75F2	2017-07-04 15:16:00+03	46500.00
6D765A	2017-08-09 03:28:00+03	23400.00
6D7674	2017-07-10 07:32:00+03	192400.00
6D7676	2017-07-01 06:39:00+03	163900.00
6D7687	2017-08-05 07:26:00+03	144400.00
6D76A2	2017-08-08 03:41:00+03	136800.00
6D76A8	2017-07-10 14:22:00+03	122200.00
6D76B9	2017-07-20 09:58:00+03	166000.00
6D7724	2017-07-02 00:34:00+03	23200.00
6D7739	2017-08-07 04:07:00+03	70200.00
6D77C3	2017-08-13 18:20:00+03	28800.00
6D77EA	2017-08-12 20:51:00+03	57300.00
6D7838	2017-08-06 12:47:00+03	22600.00
6D7865	2017-07-08 13:41:00+03	25600.00
6D78AB	2017-07-08 21:47:00+03	21800.00
6D78B4	2017-07-30 14:13:00+03	39300.00
6D78D0	2017-07-18 00:35:00+03	92800.00
6D78E0	2017-07-20 23:18:00+03	55800.00
6D7916	2017-08-04 00:13:00+03	84800.00
6D7946	2017-07-20 07:09:00+03	123000.00
6D7957	2017-07-24 19:56:00+03	28800.00
6D7A0C	2017-07-24 14:45:00+03	23200.00
6D7A5F	2017-08-14 17:07:00+03	26700.00
6D7B44	2017-08-11 19:12:00+03	90600.00
6D7B67	2017-07-30 06:31:00+03	54100.00
6D7B6B	2017-07-27 12:29:00+03	112600.00
6D7BA7	2017-07-19 19:03:00+03	95700.00
6D7C6E	2017-07-19 11:10:00+03	135600.00
6D7CCF	2017-07-10 22:54:00+03	16400.00
6D7DAE	2017-07-13 13:57:00+03	24000.00
6D7DC0	2017-07-23 23:48:00+03	43600.00
6D7DF4	2017-07-26 06:54:00+03	46400.00
6D7E08	2017-07-23 11:44:00+03	28000.00
6D7E16	2017-07-27 00:57:00+03	76600.00
6D7E3A	2017-07-10 04:21:00+03	122400.00
6D7E51	2017-07-06 03:19:00+03	23600.00
6D7E69	2017-07-17 11:32:00+03	13400.00
6D7E97	2017-07-16 20:01:00+03	14000.00
6D7EEB	2017-07-23 21:14:00+03	28800.00
6D7F5D	2017-07-07 20:56:00+03	65600.00
6D7FBD	2017-08-08 23:59:00+03	237200.00
6D7FF5	2017-08-14 14:23:00+03	24400.00
6D807A	2017-07-25 00:40:00+03	67000.00
6D80DE	2017-07-03 08:42:00+03	113800.00
6D8127	2017-07-29 05:10:00+03	20200.00
6D8129	2017-08-08 01:45:00+03	96800.00
6D812A	2017-08-04 21:24:00+03	40000.00
6D8147	2017-07-13 11:43:00+03	35900.00
6D81A7	2017-07-22 15:57:00+03	77000.00
6D81BC	2017-07-10 20:57:00+03	37100.00
6D81DD	2017-07-14 22:04:00+03	133900.00
6D81FF	2017-07-25 14:17:00+03	6700.00
6D8206	2017-08-10 19:57:00+03	10800.00
6D8261	2017-07-16 08:48:00+03	28000.00
6D8277	2017-07-25 23:31:00+03	112600.00
6D827D	2017-07-07 11:07:00+03	48800.00
6D8292	2017-08-10 15:07:00+03	46400.00
6D82DE	2017-08-08 18:38:00+03	172100.00
6D82ED	2017-07-29 08:20:00+03	26000.00
6D8300	2017-08-14 04:51:00+03	43400.00
6D8303	2017-08-13 00:10:00+03	84500.00
6D8341	2017-07-08 11:38:00+03	42800.00
6D8361	2017-08-09 19:56:00+03	31100.00
6D858E	2017-07-08 05:31:00+03	16400.00
6D85E9	2017-07-09 11:53:00+03	16400.00
6D85ED	2017-07-18 04:11:00+03	57600.00
6D8641	2017-07-22 06:27:00+03	28800.00
6D8701	2017-07-24 18:53:00+03	112400.00
6D871C	2017-07-14 09:38:00+03	139100.00
6D87D6	2017-07-10 00:55:00+03	284700.00
6D8871	2017-08-10 13:28:00+03	57600.00
6D88B4	2017-07-30 16:00:00+03	266400.00
6D893F	2017-07-19 04:39:00+03	61800.00
6D897F	2017-08-03 19:03:00+03	173500.00
6D89F8	2017-07-04 08:40:00+03	241300.00
6D89FC	2017-07-19 10:12:00+03	34000.00
6D8A03	2017-07-15 03:33:00+03	28000.00
6D8B84	2017-07-23 19:03:00+03	31600.00
6D8C35	2017-08-07 13:14:00+03	31600.00
6D8C84	2017-07-16 01:03:00+03	47000.00
6D8D8B	2017-08-05 20:38:00+03	52700.00
6D8DAD	2017-07-01 10:34:00+03	80800.00
6D8DC8	2017-07-09 11:41:00+03	28800.00
6D8DDA	2017-08-12 11:19:00+03	66600.00
6D8DE9	2017-07-26 05:25:00+03	12000.00
6D8E09	2017-08-02 03:33:00+03	339300.00
6D8E0C	2017-08-13 14:04:00+03	40800.00
6D8E46	2017-08-05 09:36:00+03	55600.00
6D8E64	2017-08-02 16:37:00+03	133200.00
6D8EDE	2017-07-18 23:47:00+03	246000.00
6D8F0B	2017-07-12 13:37:00+03	70100.00
6D8F18	2017-07-12 02:26:00+03	71000.00
6D8F4A	2017-08-04 21:28:00+03	40800.00
6D8F5B	2017-07-18 22:53:00+03	46400.00
6D8F64	2017-08-07 13:35:00+03	56000.00
6D8F8E	2017-08-11 19:38:00+03	27200.00
6D8FDB	2017-07-09 19:34:00+03	8400.00
6D916B	2017-07-19 19:24:00+03	133200.00
6D9189	2017-08-13 09:11:00+03	26800.00
6D91A5	2017-07-31 09:56:00+03	14000.00
6D91B1	2017-08-09 10:01:00+03	59800.00
6D921A	2017-07-17 03:58:00+03	69500.00
6D9239	2017-06-29 09:06:00+03	123000.00
6D929A	2017-07-20 22:03:00+03	46400.00
6D92A8	2017-07-14 05:32:00+03	67600.00
6D92E6	2017-07-14 12:15:00+03	21800.00
6D935B	2017-07-25 11:56:00+03	21800.00
6D9388	2017-07-15 18:40:00+03	56000.00
6D9434	2017-07-08 11:50:00+03	7400.00
6D946B	2017-08-11 23:47:00+03	11600.00
6D94A7	2017-07-18 02:26:00+03	70400.00
6D94FF	2017-07-30 02:54:00+03	123000.00
6D9519	2017-08-14 10:34:00+03	61500.00
6D9577	2017-08-04 08:42:00+03	114600.00
6D9586	2017-08-15 08:48:00+03	59800.00
6D9603	2017-07-12 04:21:00+03	20200.00
6D9605	2017-07-22 12:13:00+03	65500.00
6D962E	2017-08-11 18:44:00+03	38200.00
6D9664	2017-07-30 04:38:00+03	99200.00
6D9687	2017-07-10 01:04:00+03	103800.00
6D96A4	2017-08-15 12:47:00+03	131100.00
6D96CE	2017-07-25 15:16:00+03	113500.00
6D96D4	2017-07-18 21:52:00+03	35400.00
6D9713	2017-07-27 04:44:00+03	68800.00
6D9741	2017-07-28 06:38:00+03	24400.00
6D97E8	2017-07-20 02:06:00+03	22000.00
6D987D	2017-08-15 05:41:00+03	12600.00
6D98C1	2017-08-09 01:31:00+03	124500.00
6D9937	2017-07-20 15:35:00+03	115400.00
6D998A	2017-07-21 17:24:00+03	26000.00
6D9A22	2017-07-28 06:44:00+03	6700.00
6D9A67	2017-08-06 03:54:00+03	118900.00
6D9BAF	2017-07-31 08:31:00+03	25400.00
6D9BFA	2017-07-29 00:26:00+03	81700.00
6D9BFB	2017-07-08 21:07:00+03	117800.00
6D9C13	2017-07-02 15:58:00+03	145300.00
6D9C42	2017-07-06 15:54:00+03	100600.00
6D9C51	2017-08-06 03:17:00+03	201200.00
6D9C7C	2017-07-30 00:56:00+03	36200.00
6D9CFA	2017-07-23 07:02:00+03	325500.00
6D9D00	2017-07-29 14:22:00+03	40800.00
6D9D74	2017-08-01 14:43:00+03	53600.00
6D9DD5	2017-08-13 01:59:00+03	123000.00
6D9E0E	2017-07-26 16:05:00+03	7400.00
6D9E99	2017-07-24 08:30:00+03	56000.00
6D9EE0	2017-07-20 19:22:00+03	206400.00
6D9F13	2017-07-27 22:32:00+03	20400.00
6D9F52	2017-07-03 15:24:00+03	73600.00
6D9F70	2017-07-10 18:25:00+03	100600.00
6D9FA9	2017-07-23 13:28:00+03	44800.00
6D9FAC	2017-07-26 13:26:00+03	63700.00
6DA04A	2017-08-04 13:51:00+03	71500.00
6DA04B	2017-07-31 20:30:00+03	69500.00
6DA04E	2017-07-27 12:51:00+03	12600.00
6DA055	2017-07-07 05:08:00+03	23400.00
6DA056	2017-07-28 14:56:00+03	75800.00
6DA077	2017-08-05 03:57:00+03	96200.00
6DA082	2017-07-09 01:36:00+03	69500.00
6DA08F	2017-07-03 13:08:00+03	38600.00
6DA149	2017-07-30 13:28:00+03	34200.00
6DA184	2017-08-01 19:55:00+03	99200.00
6DA202	2017-07-20 05:58:00+03	26000.00
6DA20A	2017-08-11 22:00:00+03	88500.00
6DA20D	2017-06-26 02:43:00+03	492000.00
6DA217	2017-08-06 07:56:00+03	26000.00
6DA295	2017-07-03 06:49:00+03	36200.00
6DA2AF	2017-08-10 10:21:00+03	50200.00
6DA2D9	2017-06-28 17:30:00+03	85300.00
6DA3FD	2017-07-04 07:28:00+03	41100.00
6DA41A	2017-08-09 13:38:00+03	44000.00
6DA490	2017-06-29 03:46:00+03	57400.00
6DA4A7	2017-07-24 01:01:00+03	266300.00
6DA4E3	2017-07-11 06:35:00+03	12000.00
6DA53E	2017-07-30 15:14:00+03	62600.00
6DA54E	2017-07-15 08:56:00+03	114800.00
6DA551	2017-08-03 23:43:00+03	28000.00
6DA5F1	2017-07-24 16:56:00+03	136800.00
6DA63F	2017-08-14 15:12:00+03	52300.00
6DA675	2017-07-26 15:38:00+03	44800.00
6DA6E8	2017-07-06 17:23:00+03	198300.00
6DA6FA	2017-07-11 17:38:00+03	73200.00
6DA72C	2017-07-15 17:09:00+03	258000.00
6DA72F	2017-07-13 21:56:00+03	18000.00
6DA7B2	2017-07-03 14:17:00+03	46000.00
6DA817	2017-07-23 17:23:00+03	61100.00
6DA896	2017-08-01 09:44:00+03	44800.00
6DA8FC	2017-07-20 05:43:00+03	26000.00
6DA9A9	2017-08-11 19:21:00+03	50400.00
6DA9AD	2017-07-31 07:22:00+03	44000.00
6DA9EB	2017-07-17 02:48:00+03	53600.00
6DAAE4	2017-07-27 06:40:00+03	13400.00
6DAB17	2017-07-29 17:27:00+03	140000.00
6DAB75	2017-07-26 21:21:00+03	22000.00
6DAC05	2017-07-27 22:07:00+03	69600.00
6DAC4A	2017-08-02 23:48:00+03	276200.00
6DAC69	2017-07-26 03:29:00+03	25800.00
6DAC6D	2017-07-15 22:01:00+03	90800.00
6DACB7	2017-07-07 09:22:00+03	40100.00
6DAD42	2017-07-14 08:11:00+03	26800.00
6DAD71	2017-08-10 10:57:00+03	105600.00
6DAD83	2017-07-01 06:40:00+03	68400.00
6DADA1	2017-08-09 17:25:00+03	28800.00
6DAE00	2017-07-08 23:15:00+03	135600.00
6DAE23	2017-07-25 13:38:00+03	116800.00
6DAE81	2017-08-01 21:30:00+03	66600.00
6DAEA2	2017-07-14 04:09:00+03	62400.00
6DAEA6	2017-07-25 23:08:00+03	135400.00
6DAEAD	2017-07-20 07:28:00+03	271100.00
6DAED6	2017-07-30 13:17:00+03	35300.00
6DAF81	2017-07-28 22:41:00+03	95600.00
6DAF83	2017-07-23 09:36:00+03	6700.00
6DAFA7	2017-08-12 22:13:00+03	88000.00
6DAFE5	2017-07-07 02:13:00+03	124200.00
6DB045	2017-07-07 06:41:00+03	6300.00
6DB056	2017-07-07 10:19:00+03	51600.00
6DB0A5	2017-08-09 09:07:00+03	48800.00
6DB0EC	2017-08-06 02:53:00+03	35200.00
6DB10E	2017-07-05 00:09:00+03	67600.00
6DB124	2017-08-12 21:05:00+03	66000.00
6DB146	2017-07-04 15:06:00+03	25200.00
6DB182	2017-07-17 23:16:00+03	189200.00
6DB1A2	2017-07-17 17:17:00+03	46800.00
6DB1CF	2017-07-19 04:20:00+03	59800.00
6DB1FB	2017-07-30 17:40:00+03	9200.00
6DB280	2017-08-07 12:35:00+03	155000.00
6DB2F8	2017-08-12 14:56:00+03	300600.00
6DB308	2017-07-08 23:05:00+03	131800.00
6DB384	2017-08-07 16:09:00+03	44000.00
6DB38F	2017-07-10 05:16:00+03	111900.00
6DB3B9	2017-07-18 15:02:00+03	27300.00
6DB3F1	2017-07-20 04:47:00+03	32200.00
6DB40A	2017-08-03 11:29:00+03	48800.00
6DB452	2017-07-24 17:29:00+03	52000.00
6DB49E	2017-07-26 01:46:00+03	56000.00
6DB53E	2017-07-07 10:24:00+03	29600.00
6DB540	2017-08-05 02:27:00+03	46400.00
6DB5F1	2017-08-08 10:10:00+03	74900.00
6DB5FA	2017-07-15 09:34:00+03	143200.00
6DB657	2017-07-13 16:51:00+03	14000.00
6DB663	2017-08-06 08:28:00+03	91500.00
6DB6ED	2017-07-20 14:52:00+03	26800.00
6DB742	2017-08-05 18:02:00+03	43900.00
6DB7AD	2017-08-11 13:04:00+03	30200.00
6DB7EB	2017-08-03 02:43:00+03	206400.00
6DB84A	2017-07-29 09:13:00+03	28800.00
6DB853	2017-08-13 04:27:00+03	393800.00
6DB89C	2017-07-14 09:46:00+03	245800.00
6DB8BB	2017-07-02 13:42:00+03	44100.00
6DB8DD	2017-07-26 22:54:00+03	62600.00
6DB8EC	2017-07-28 12:26:00+03	64300.00
6DB930	2017-08-10 21:00:00+03	67200.00
6DB9DF	2017-07-10 11:02:00+03	37900.00
6DBA56	2017-08-10 02:32:00+03	70600.00
6DBA6A	2017-07-09 11:03:00+03	36800.00
6DBA86	2017-07-07 15:21:00+03	281500.00
6DBAEF	2017-07-30 10:14:00+03	10800.00
6DBB10	2017-07-16 03:41:00+03	104000.00
6DBC40	2017-08-13 06:41:00+03	79800.00
6DBC6A	2017-07-29 05:01:00+03	50800.00
6DBC80	2017-07-03 06:13:00+03	24400.00
6DBCA1	2017-07-07 06:31:00+03	66600.00
6DBCB1	2017-07-13 09:03:00+03	34000.00
6DBCE2	2017-07-15 18:07:00+03	23600.00
6DBD0D	2017-08-12 07:05:00+03	155000.00
6DBD9B	2017-08-07 09:50:00+03	78200.00
6DBDC2	2017-08-03 10:44:00+03	56000.00
6DBE18	2017-08-02 09:58:00+03	111600.00
6DBE83	2017-08-11 08:11:00+03	28800.00
6DBEA2	2017-08-08 13:12:00+03	8800.00
6DBEB6	2017-08-07 15:18:00+03	116800.00
6DBF2A	2017-08-03 19:01:00+03	185300.00
6DBF38	2017-08-08 06:38:00+03	167500.00
6DBF39	2017-07-06 00:05:00+03	43000.00
6DBF75	2017-07-26 19:56:00+03	78800.00
6DBF8A	2017-07-20 13:12:00+03	219400.00
6DC032	2017-07-26 12:00:00+03	201200.00
6DC055	2017-07-04 08:25:00+03	57800.00
6DC05F	2017-07-10 21:19:00+03	177200.00
6DC0B0	2017-07-09 16:20:00+03	24400.00
6DC11F	2017-07-11 16:30:00+03	57800.00
6DC16C	2017-08-14 05:34:00+03	149200.00
6DC17C	2017-07-24 21:06:00+03	103000.00
6DC1CB	2017-07-15 01:34:00+03	52000.00
6DC1EE	2017-07-17 18:24:00+03	356900.00
6DC2B0	2017-08-01 08:39:00+03	56600.00
6DC2C7	2017-07-23 21:38:00+03	30400.00
6DC318	2017-07-15 13:20:00+03	32800.00
6DC375	2017-08-02 13:52:00+03	103500.00
6DC37A	2017-07-15 17:44:00+03	124200.00
6DC3FE	2017-07-19 02:33:00+03	397700.00
6DC412	2017-07-23 03:30:00+03	64700.00
6DC43A	2017-07-19 15:25:00+03	54500.00
6DC45D	2017-07-21 15:46:00+03	131600.00
6DC4A4	2017-07-17 18:25:00+03	76800.00
6DC4BD	2017-07-04 05:52:00+03	426700.00
6DC4C9	2017-08-10 14:03:00+03	113000.00
6DC4CC	2017-07-27 04:16:00+03	75300.00
6DC579	2017-08-06 16:56:00+03	15000.00
6DC59E	2017-07-12 17:49:00+03	62600.00
6DC616	2017-07-09 13:05:00+03	29000.00
6DC64F	2017-07-04 01:52:00+03	118000.00
6DC680	2017-07-23 21:48:00+03	44800.00
6DC692	2017-08-07 10:51:00+03	89700.00
6DC69B	2017-06-28 02:20:00+03	55800.00
6DC73D	2017-07-01 22:21:00+03	398500.00
6DC787	2017-07-29 11:48:00+03	114800.00
6DC804	2017-07-06 19:04:00+03	56600.00
6DC845	2017-07-19 16:22:00+03	32800.00
6DC876	2017-07-21 21:34:00+03	135600.00
6DC8CF	2017-07-05 05:31:00+03	32800.00
6DC928	2017-07-21 12:56:00+03	46700.00
6DC953	2017-07-01 05:01:00+03	74100.00
6DC969	2017-08-03 17:31:00+03	40400.00
6DC989	2017-07-18 15:38:00+03	81300.00
6DC992	2017-07-09 17:28:00+03	109600.00
6DCA00	2017-07-06 18:23:00+03	46200.00
6DCB4F	2017-08-08 07:05:00+03	23200.00
6DCB52	2017-08-09 15:02:00+03	257500.00
6DCB53	2017-08-09 03:13:00+03	109000.00
6DCBEF	2017-08-02 07:58:00+03	23200.00
6DCBFC	2017-06-30 00:50:00+03	93400.00
6DCC50	2017-07-17 10:13:00+03	52300.00
6DCCEF	2017-07-11 12:19:00+03	31400.00
6DCCFC	2017-07-18 12:18:00+03	42400.00
6DCE34	2017-07-02 13:20:00+03	21400.00
6DCE35	2017-07-03 08:49:00+03	49600.00
6DCE3B	2017-08-14 23:40:00+03	369000.00
6DCE97	2017-08-11 12:31:00+03	40000.00
6DCEA4	2017-07-28 18:22:00+03	31400.00
6DCF03	2017-08-04 05:32:00+03	26000.00
6DCF0B	2017-07-25 02:33:00+03	23600.00
6DCF24	2017-07-01 23:27:00+03	21400.00
6DCF2C	2017-07-17 02:48:00+03	96100.00
6DCF3A	2017-08-06 02:28:00+03	25200.00
6DCFFC	2017-07-15 15:06:00+03	38000.00
6DD042	2017-07-18 09:47:00+03	46300.00
6DD055	2017-08-11 00:18:00+03	109000.00
6DD077	2017-07-09 09:53:00+03	80200.00
6DD0FA	2017-07-10 17:24:00+03	242800.00
6DD113	2017-07-05 15:56:00+03	57600.00
6DD11F	2017-08-04 04:41:00+03	14000.00
6DD129	2017-08-11 11:32:00+03	123000.00
6DD14C	2017-08-01 09:42:00+03	38600.00
6DD14E	2017-08-14 06:11:00+03	35500.00
6DD170	2017-08-05 11:36:00+03	7200.00
6DD17A	2017-06-28 04:15:00+03	31400.00
6DD1E6	2017-08-06 02:19:00+03	98400.00
6DD1F0	2017-07-18 03:53:00+03	125000.00
6DD221	2017-08-06 07:30:00+03	24400.00
6DD253	2017-08-03 22:48:00+03	266200.00
6DD271	2017-06-30 03:36:00+03	12400.00
6DD297	2017-08-01 02:18:00+03	37500.00
6DD31D	2017-08-07 17:31:00+03	25900.00
6DD38A	2017-07-22 17:54:00+03	87000.00
6DD38C	2017-07-06 20:41:00+03	22400.00
6DD3BE	2017-07-28 08:27:00+03	182300.00
6DD3D0	2017-07-23 00:02:00+03	289200.00
6DD3DC	2017-07-08 18:17:00+03	65900.00
6DD426	2017-07-31 12:12:00+03	73500.00
6DD468	2017-07-13 05:50:00+03	65900.00
6DD487	2017-08-14 11:17:00+03	35600.00
6DD4B5	2017-07-08 03:37:00+03	36200.00
6DD4E9	2017-07-04 11:57:00+03	34000.00
6DD512	2017-07-05 03:56:00+03	405600.00
6DD630	2017-07-30 10:24:00+03	104300.00
6DD65A	2017-08-13 11:34:00+03	28800.00
6DD662	2017-08-07 19:15:00+03	31800.00
6DD6D0	2017-07-29 18:17:00+03	78300.00
6DD6F6	2017-07-02 11:44:00+03	112000.00
6DD6F7	2017-07-27 23:30:00+03	28000.00
6DD71B	2017-07-22 14:25:00+03	31600.00
6DD778	2017-08-03 14:17:00+03	13600.00
6DD7FD	2017-07-13 12:20:00+03	68100.00
6DD813	2017-07-28 17:56:00+03	173900.00
6DD81D	2017-08-13 17:28:00+03	23200.00
6DD862	2017-07-01 19:41:00+03	201200.00
6DD88F	2017-08-08 02:54:00+03	87400.00
6DD8C7	2017-07-25 07:56:00+03	79600.00
6DD944	2017-07-30 20:06:00+03	28000.00
6DD957	2017-08-14 18:29:00+03	30100.00
6DD9ED	2017-07-30 23:07:00+03	6700.00
6DD9F5	2017-07-07 18:02:00+03	13400.00
6DDA4E	2017-08-04 00:12:00+03	23600.00
6DDA51	2017-08-01 12:35:00+03	136300.00
6DDA6F	2017-07-12 13:25:00+03	81700.00
6DDA78	2017-07-11 20:30:00+03	68100.00
6DDADB	2017-08-12 23:10:00+03	187900.00
6DDAF7	2017-08-06 19:22:00+03	42400.00
6DDB2B	2017-08-06 04:38:00+03	92900.00
6DDB38	2017-07-13 04:18:00+03	50000.00
6DDBAA	2017-07-05 08:59:00+03	39800.00
6DDBC0	2017-07-09 17:24:00+03	27800.00
6DDBE2	2017-07-10 02:30:00+03	61800.00
6DDD39	2017-08-13 11:59:00+03	7200.00
6DDDCA	2017-08-15 16:34:00+03	106100.00
6DDDF5	2017-07-06 18:49:00+03	28800.00
6DDE25	2017-07-30 08:00:00+03	37900.00
6DDED0	2017-08-09 02:48:00+03	40000.00
6DDF41	2017-07-22 11:07:00+03	56000.00
6DDF6A	2017-08-08 01:14:00+03	77900.00
6DE00C	2017-07-29 02:06:00+03	40000.00
6DE02F	2017-07-28 00:40:00+03	133200.00
6DE051	2017-08-06 14:28:00+03	44000.00
6DE053	2017-08-02 19:27:00+03	66000.00
6DE06F	2017-08-14 12:20:00+03	269200.00
6DE0BB	2017-08-07 00:18:00+03	248400.00
6DE0F9	2017-07-30 05:49:00+03	23500.00
6DE102	2017-08-15 14:18:00+03	25000.00
6DE120	2017-07-01 18:22:00+03	58700.00
6DE1BE	2017-07-08 15:02:00+03	97900.00
6DE212	2017-08-06 10:41:00+03	40200.00
6DE249	2017-07-13 22:05:00+03	152700.00
6DE261	2017-07-12 22:44:00+03	29600.00
6DE2D7	2017-07-05 16:49:00+03	28000.00
6DE2E6	2017-08-14 09:29:00+03	26800.00
6DE30E	2017-07-08 20:06:00+03	52500.00
6DE32F	2017-07-27 20:58:00+03	35800.00
6DE462	2017-07-29 04:53:00+03	108500.00
6DE4B3	2017-07-21 15:48:00+03	44000.00
6DE4D0	2017-07-04 23:25:00+03	28000.00
6DE4FD	2017-06-30 02:59:00+03	89100.00
6DE556	2017-07-20 09:37:00+03	118500.00
6DE581	2017-08-08 05:13:00+03	88000.00
6DE590	2017-07-14 18:22:00+03	187600.00
6DE5F7	2017-07-07 17:39:00+03	24600.00
6DE66C	2017-08-11 15:46:00+03	97400.00
6DE693	2017-08-12 19:24:00+03	59400.00
6DE6DB	2017-08-08 22:40:00+03	40800.00
6DE792	2017-08-01 11:30:00+03	68800.00
6DE79A	2017-07-12 19:55:00+03	79600.00
6DE7C7	2017-07-05 17:44:00+03	75300.00
6DE7EB	2017-08-03 13:02:00+03	22000.00
6DE8AB	2017-07-18 18:30:00+03	46400.00
6DE8C2	2017-08-03 03:43:00+03	48800.00
6DE8C9	2017-07-17 05:58:00+03	84800.00
6DE96C	2017-07-29 06:08:00+03	6000.00
6DE96F	2017-07-05 06:27:00+03	46400.00
6DE9E4	2017-07-09 19:19:00+03	78600.00
6DE9EF	2017-07-18 03:23:00+03	32700.00
6DEA28	2017-08-06 08:37:00+03	174400.00
6DEA38	2017-08-03 21:22:00+03	29600.00
6DEABF	2017-08-01 06:32:00+03	64100.00
6DEB03	2017-08-13 06:20:00+03	21400.00
6DEB3B	2017-07-28 14:36:00+03	96300.00
6DEB4D	2017-07-24 00:18:00+03	6000.00
6DEB55	2017-07-16 12:20:00+03	56000.00
6DEB9B	2017-07-13 02:15:00+03	18000.00
6DEBA6	2017-07-12 22:01:00+03	289800.00
6DEBBC	2017-07-16 14:21:00+03	55800.00
6DEC41	2017-07-07 23:51:00+03	55800.00
6DEC79	2017-06-28 21:23:00+03	173900.00
6DED26	2017-07-27 01:07:00+03	57400.00
6DED27	2017-07-26 01:47:00+03	85700.00
6DED61	2017-07-02 18:16:00+03	31400.00
6DEDA3	2017-07-08 09:56:00+03	246200.00
6DEDC9	2017-07-18 05:28:00+03	107800.00
6DEDF5	2017-07-19 20:21:00+03	134400.00
6DEE30	2017-07-15 11:41:00+03	117200.00
6DEE68	2017-07-20 19:10:00+03	24000.00
6DEE73	2017-08-15 07:50:00+03	32400.00
6DEE7A	2017-07-25 22:09:00+03	10600.00
6DEEB6	2017-08-03 16:05:00+03	28800.00
6DEF00	2017-08-01 11:16:00+03	12600.00
6DEF2A	2017-08-06 08:43:00+03	19600.00
6DEF76	2017-07-27 17:38:00+03	92800.00
6DF029	2017-08-06 11:03:00+03	8000.00
6DF041	2017-07-02 11:30:00+03	21800.00
6DF072	2017-07-09 02:34:00+03	24300.00
6DF0BC	2017-08-14 09:32:00+03	52600.00
6DF0C3	2017-07-18 16:42:00+03	46000.00
6DF168	2017-07-11 13:02:00+03	30600.00
6DF186	2017-08-14 04:39:00+03	41200.00
6DF1A6	2017-07-24 09:18:00+03	38800.00
6DF259	2017-07-06 13:55:00+03	92000.00
6DF29B	2017-07-26 07:15:00+03	44000.00
6DF2B4	2017-07-31 06:38:00+03	39800.00
6DF30E	2017-07-12 04:26:00+03	48800.00
6DF315	2017-07-29 21:15:00+03	125200.00
6DF3DC	2017-07-11 23:56:00+03	24400.00
6DF3F8	2017-07-22 17:10:00+03	7200.00
6DF438	2017-06-30 16:01:00+03	53400.00
6DF453	2017-07-14 05:30:00+03	59800.00
6DF490	2017-07-08 14:56:00+03	68800.00
6DF527	2017-07-14 06:34:00+03	90400.00
6DF542	2017-07-09 11:07:00+03	147300.00
6DF54B	2017-07-15 08:03:00+03	109800.00
6DF568	2017-08-08 08:13:00+03	128800.00
6DF571	2017-08-05 18:06:00+03	47700.00
6DF5EA	2017-08-07 14:45:00+03	6700.00
6DF6A2	2017-07-02 14:14:00+03	14000.00
6DF6D0	2017-08-08 16:56:00+03	76800.00
6DF6DC	2017-08-05 19:00:00+03	24400.00
6DF6EF	2017-07-13 10:44:00+03	75000.00
6DF743	2017-08-14 00:38:00+03	7300.00
6DF757	2017-07-12 22:16:00+03	20800.00
6DF780	2017-07-30 13:43:00+03	117600.00
6DF7B4	2017-07-03 05:49:00+03	56000.00
6DF7C8	2017-07-31 19:22:00+03	78100.00
6DF806	2017-07-17 05:23:00+03	201600.00
6DF808	2017-07-06 09:02:00+03	31400.00
6DF82D	2017-07-31 06:52:00+03	40400.00
6DF83C	2017-07-26 06:48:00+03	100600.00
6DF8A8	2017-08-12 08:56:00+03	96800.00
6DF8D1	2017-08-13 04:57:00+03	21400.00
6DF8E9	2017-07-12 05:09:00+03	21400.00
6DF943	2017-07-08 23:40:00+03	170700.00
6DF953	2017-07-22 13:39:00+03	39100.00
6DF959	2017-07-24 23:32:00+03	88600.00
6DF992	2017-07-19 05:50:00+03	123000.00
6DF9FE	2017-07-29 13:57:00+03	90800.00
6DFA4B	2017-07-31 20:58:00+03	20400.00
6DFADD	2017-07-31 15:33:00+03	13600.00
6DFB05	2017-08-04 10:04:00+03	52400.00
6DFBBB	2017-07-04 11:21:00+03	20900.00
6DFC1C	2017-07-04 20:14:00+03	56100.00
6DFC4A	2017-07-25 12:15:00+03	32400.00
6DFC54	2017-08-10 04:43:00+03	274200.00
6DFC68	2017-07-13 01:24:00+03	56000.00
6DFC9C	2017-08-04 10:43:00+03	81700.00
6DFCD7	2017-07-27 13:30:00+03	75300.00
6DFD43	2017-08-13 10:37:00+03	45300.00
6DFDC5	2017-08-09 05:04:00+03	49200.00
6DFE42	2017-08-14 02:05:00+03	240500.00
6DFE92	2017-08-03 14:37:00+03	76600.00
6DFF00	2017-07-15 13:56:00+03	64800.00
6DFF51	2017-07-16 07:46:00+03	23100.00
6DFF56	2017-07-10 20:36:00+03	113100.00
6DFF77	2017-07-04 05:30:00+03	33100.00
6DFF81	2017-07-20 20:50:00+03	143900.00
6DFF9E	2017-07-13 19:46:00+03	36100.00
6DFFB1	2017-07-07 10:48:00+03	47100.00
6E0011	2017-07-18 14:05:00+03	67100.00
6E0018	2017-08-10 05:01:00+03	12400.00
6E0055	2017-07-11 10:50:00+03	53300.00
6E006F	2017-07-13 11:50:00+03	26000.00
6E009D	2017-07-01 12:32:00+03	73900.00
6E00AA	2017-07-05 08:37:00+03	114800.00
6E00C7	2017-07-22 12:06:00+03	38400.00
6E00DC	2017-08-09 05:53:00+03	58400.00
6E013A	2017-08-04 00:45:00+03	113800.00
6E015B	2017-08-10 10:02:00+03	34000.00
6E018A	2017-07-20 21:17:00+03	70100.00
6E01DA	2017-07-28 08:45:00+03	25200.00
6E0262	2017-08-05 14:13:00+03	100000.00
6E028F	2017-07-26 23:01:00+03	53600.00
6E02C2	2017-08-04 21:38:00+03	13400.00
6E02DD	2017-08-01 20:27:00+03	212800.00
6E0302	2017-07-19 17:16:00+03	265600.00
6E03AF	2017-07-11 22:01:00+03	8200.00
6E03D3	2017-08-13 21:01:00+03	88400.00
6E03D8	2017-07-14 07:06:00+03	46000.00
6E0450	2017-08-01 12:36:00+03	263600.00
6E04F2	2017-07-30 16:03:00+03	23200.00
6E0513	2017-07-20 17:35:00+03	28000.00
6E052F	2017-07-22 10:15:00+03	14000.00
6E05A0	2017-08-13 12:09:00+03	38600.00
6E05C1	2017-08-08 00:31:00+03	92000.00
6E05E6	2017-07-17 08:12:00+03	47700.00
6E0651	2017-08-10 14:09:00+03	37200.00
6E0652	2017-08-04 11:11:00+03	20500.00
6E0677	2017-08-09 06:28:00+03	116600.00
6E06D9	2017-07-15 23:02:00+03	299100.00
6E06EE	2017-08-03 05:28:00+03	125200.00
6E0746	2017-07-25 23:18:00+03	50000.00
6E075C	2017-07-18 04:16:00+03	58800.00
6E07A6	2017-07-31 03:56:00+03	29600.00
6E0839	2017-07-15 11:22:00+03	56900.00
6E0885	2017-08-04 17:57:00+03	50000.00
6E0899	2017-06-30 22:42:00+03	55800.00
6E08AF	2017-08-05 05:36:00+03	28800.00
6E08BC	2017-08-03 00:13:00+03	532800.00
6E08E1	2017-08-11 23:37:00+03	32800.00
6E090F	2017-08-02 12:14:00+03	23200.00
6E091D	2017-07-02 10:36:00+03	187600.00
6E09EE	2017-07-10 08:23:00+03	40600.00
6E0AD7	2017-07-23 14:39:00+03	149800.00
6E0BA0	2017-07-03 19:02:00+03	86800.00
6E0BAE	2017-08-07 17:07:00+03	75600.00
6E0BB0	2017-07-12 15:50:00+03	6700.00
6E0BB9	2017-07-19 00:57:00+03	97200.00
6E0BBB	2017-07-13 23:13:00+03	58000.00
6E0C21	2017-07-30 20:21:00+03	26800.00
6E0C75	2017-07-31 08:34:00+03	65900.00
6E0C8F	2017-08-03 15:16:00+03	6700.00
6E0CEE	2017-07-22 12:03:00+03	28000.00
6E0DBF	2017-08-05 11:26:00+03	99300.00
6E0DD7	2017-08-14 05:55:00+03	228900.00
6E0E6E	2017-08-15 12:37:00+03	81300.00
6E0E85	2017-08-05 10:17:00+03	6700.00
6E0E88	2017-07-05 23:49:00+03	38400.00
6E0E89	2017-07-18 21:51:00+03	117600.00
6E0EAF	2017-08-14 16:19:00+03	88500.00
6E0F06	2017-07-18 16:53:00+03	81700.00
6E0F1D	2017-07-26 00:50:00+03	76600.00
6E0F4C	2017-07-19 02:21:00+03	47900.00
6E0F89	2017-07-27 13:52:00+03	156500.00
6E0F9D	2017-07-15 18:23:00+03	24200.00
6E0FAB	2017-06-28 06:24:00+03	369000.00
6E0FD2	2017-07-31 01:32:00+03	23200.00
6E1007	2017-06-29 22:58:00+03	40200.00
6E1081	2017-08-06 22:27:00+03	76600.00
6E1095	2017-08-15 05:45:00+03	136200.00
6E10A6	2017-07-13 06:00:00+03	100700.00
6E10EA	2017-07-12 17:27:00+03	272400.00
6E10EC	2017-07-17 21:36:00+03	240600.00
6E1118	2017-07-09 16:09:00+03	13700.00
6E113B	2017-08-04 12:03:00+03	48800.00
6E11A7	2017-07-26 22:47:00+03	24800.00
6E11CF	2017-07-10 14:13:00+03	41400.00
6E125A	2017-07-10 10:17:00+03	24300.00
6E1265	2017-08-12 03:14:00+03	72200.00
6E1279	2017-07-10 05:29:00+03	18800.00
6E136F	2017-07-28 21:45:00+03	25600.00
6E13F6	2017-07-29 13:56:00+03	81500.00
6E1423	2017-07-04 05:19:00+03	52000.00
6E147F	2017-07-23 15:03:00+03	59300.00
6E14EB	2017-07-12 02:05:00+03	14400.00
6E150F	2017-07-03 20:09:00+03	258400.00
6E1522	2017-07-27 11:40:00+03	48700.00
6E1554	2017-07-05 17:44:00+03	67600.00
6E159A	2017-07-29 00:21:00+03	66600.00
6E15A1	2017-08-12 18:35:00+03	106000.00
6E15C7	2017-07-23 14:36:00+03	81700.00
6E166E	2017-07-18 16:34:00+03	116800.00
6E16B4	2017-08-05 17:32:00+03	269300.00
6E16C4	2017-08-08 02:19:00+03	244200.00
6E16D9	2017-07-09 19:56:00+03	85000.00
6E1711	2017-07-18 05:05:00+03	134400.00
6E176F	2017-07-20 14:31:00+03	87200.00
6E17A9	2017-08-07 21:10:00+03	42600.00
6E17C3	2017-08-10 06:44:00+03	12200.00
6E189E	2017-07-18 07:02:00+03	26000.00
6E18AB	2017-08-06 01:16:00+03	161800.00
6E18B8	2017-07-26 09:56:00+03	7400.00
6E18FB	2017-07-26 00:48:00+03	134400.00
6E1916	2017-07-10 00:58:00+03	123000.00
6E1954	2017-07-31 02:25:00+03	92800.00
6E197C	2017-08-06 05:35:00+03	134400.00
6E1994	2017-07-08 08:05:00+03	68800.00
6E1A51	2017-08-07 21:41:00+03	47000.00
6E1B90	2017-08-13 12:05:00+03	106400.00
6E1BE0	2017-07-08 12:03:00+03	44200.00
6E1BF2	2017-08-07 04:48:00+03	64400.00
6E1C0A	2017-07-24 00:01:00+03	44600.00
6E1C0C	2017-07-07 05:14:00+03	418400.00
6E1C11	2017-06-28 06:05:00+03	24400.00
6E1C39	2017-08-04 20:26:00+03	31400.00
6E1C42	2017-07-07 17:06:00+03	39200.00
6E1C68	2017-08-14 09:45:00+03	42800.00
6E1C87	2017-08-07 08:35:00+03	149200.00
6E1C90	2017-08-07 09:48:00+03	12400.00
6E1CC1	2017-07-31 21:06:00+03	37900.00
6E1CD0	2017-07-05 05:09:00+03	71900.00
6E1D50	2017-07-05 15:11:00+03	72400.00
6E1D5D	2017-08-09 02:42:00+03	135400.00
6E1DBA	2017-08-03 05:07:00+03	39000.00
6E1DD6	2017-08-10 22:36:00+03	8000.00
6E1E84	2017-07-03 02:30:00+03	40800.00
6E1F20	2017-07-10 19:14:00+03	65900.00
6E1F8F	2017-07-29 02:26:00+03	115700.00
6E1FA2	2017-07-24 23:17:00+03	58800.00
6E2029	2017-07-10 12:02:00+03	53200.00
6E20A1	2017-07-04 03:31:00+03	76800.00
6E2111	2017-07-08 14:53:00+03	252200.00
6E2117	2017-07-30 17:16:00+03	179300.00
6E222C	2017-08-05 06:00:00+03	44000.00
6E22E6	2017-07-24 05:52:00+03	167400.00
6E2325	2017-08-05 07:26:00+03	162700.00
6E2352	2017-07-09 13:33:00+03	57500.00
6E235C	2017-07-19 20:31:00+03	131600.00
6E2367	2017-07-16 00:34:00+03	89600.00
6E23DB	2017-07-19 09:24:00+03	23400.00
6E241E	2017-08-03 09:36:00+03	55800.00
6E2427	2017-07-31 05:05:00+03	67700.00
6E2434	2017-07-12 19:11:00+03	34000.00
6E2506	2017-07-12 16:16:00+03	26700.00
6E250F	2017-07-17 10:53:00+03	65800.00
6E2584	2017-07-06 01:44:00+03	67400.00
6E259C	2017-07-04 14:42:00+03	80600.00
6E2688	2017-08-03 02:08:00+03	135400.00
6E26C0	2017-07-05 12:17:00+03	8400.00
6E26E1	2017-07-28 23:16:00+03	92900.00
6E2701	2017-07-22 17:33:00+03	26800.00
6E2724	2017-07-17 17:46:00+03	271100.00
6E2745	2017-07-05 23:10:00+03	85700.00
6E2764	2017-07-26 03:23:00+03	249100.00
6E2773	2017-08-11 09:40:00+03	33000.00
6E2793	2017-08-11 03:25:00+03	89600.00
6E27AA	2017-07-07 08:43:00+03	73900.00
6E280E	2017-07-17 23:27:00+03	28000.00
6E28DA	2017-08-05 14:25:00+03	59000.00
6E28F5	2017-07-21 13:10:00+03	6300.00
6E2901	2017-08-05 16:34:00+03	140900.00
6E2928	2017-08-07 17:20:00+03	36200.00
6E2959	2017-07-11 04:01:00+03	108800.00
6E29D7	2017-07-03 01:02:00+03	56000.00
6E2A09	2017-07-18 05:30:00+03	246000.00
6E2A26	2017-08-13 15:28:00+03	38400.00
6E2A75	2017-08-10 02:45:00+03	114800.00
6E2AD9	2017-08-07 18:39:00+03	123000.00
6E2B34	2017-07-15 17:10:00+03	25600.00
6E2B4B	2017-06-30 03:02:00+03	62600.00
6E2B4D	2017-07-28 06:54:00+03	54500.00
6E2B91	2017-07-03 05:40:00+03	31900.00
6E2BB0	2017-08-09 04:54:00+03	24400.00
6E2C03	2017-07-25 11:53:00+03	59200.00
6E2C39	2017-07-14 00:45:00+03	22000.00
6E2C63	2017-08-13 04:49:00+03	86700.00
6E2C68	2017-07-29 20:03:00+03	27200.00
6E2C6F	2017-08-15 00:03:00+03	54800.00
6E2CBC	2017-08-09 07:23:00+03	56900.00
6E2CBD	2017-07-10 15:58:00+03	258400.00
6E2CEB	2017-07-12 08:10:00+03	86800.00
6E2CF2	2017-08-09 07:16:00+03	26700.00
6E2D08	2017-07-29 10:20:00+03	38600.00
6E2D25	2017-07-09 22:58:00+03	98400.00
6E2D82	2017-06-27 18:25:00+03	124300.00
6E2D94	2017-06-30 11:34:00+03	21200.00
6E2EAE	2017-08-06 18:27:00+03	123000.00
6E2ED9	2017-07-04 08:15:00+03	46700.00
6E2EE3	2017-08-11 13:25:00+03	46000.00
6E2F3C	2017-08-04 11:54:00+03	28800.00
6E2F87	2017-07-29 07:55:00+03	14400.00
6E3087	2017-07-29 13:07:00+03	341900.00
6E31E8	2017-07-09 19:36:00+03	36400.00
6E3220	2017-07-09 05:58:00+03	23200.00
6E323D	2017-07-17 07:06:00+03	29400.00
6E32A3	2017-07-01 03:26:00+03	266200.00
6E32CE	2017-08-06 19:47:00+03	193600.00
6E331E	2017-08-11 02:07:00+03	193600.00
6E3332	2017-07-02 08:00:00+03	123000.00
6E3365	2017-07-11 19:19:00+03	167500.00
6E339D	2017-07-13 16:45:00+03	37600.00
6E33A9	2017-07-14 17:39:00+03	463800.00
6E33F3	2017-07-19 19:32:00+03	202400.00
6E3414	2017-07-13 11:25:00+03	126400.00
6E341E	2017-07-17 19:04:00+03	6700.00
6E3507	2017-08-13 11:57:00+03	50200.00
6E3511	2017-07-05 03:41:00+03	55800.00
6E355A	2017-08-12 20:27:00+03	52700.00
6E35A6	2017-07-01 02:20:00+03	10800.00
6E35F1	2017-08-12 17:09:00+03	96800.00
6E3636	2017-07-19 13:04:00+03	112200.00
6E3653	2017-08-14 08:33:00+03	90200.00
6E365A	2017-07-05 06:52:00+03	152200.00
6E3670	2017-07-28 05:36:00+03	56000.00
6E36AF	2017-07-10 01:37:00+03	24200.00
6E3703	2017-08-01 10:42:00+03	92000.00
6E3788	2017-08-03 08:55:00+03	115800.00
6E3789	2017-07-06 23:56:00+03	62800.00
6E37A9	2017-07-07 07:52:00+03	63000.00
6E3831	2017-07-31 22:43:00+03	28800.00
6E394B	2017-07-10 03:26:00+03	59800.00
6E39C2	2017-08-03 08:04:00+03	26300.00
6E39EE	2017-07-11 19:08:00+03	95600.00
6E3A25	2017-07-16 22:41:00+03	20200.00
6E3A5D	2017-07-18 01:16:00+03	22200.00
6E3A7F	2017-07-15 17:10:00+03	67200.00
6E3A81	2017-08-06 20:27:00+03	25600.00
6E3AFF	2017-07-04 01:55:00+03	36200.00
6E3B8F	2017-07-13 22:09:00+03	46000.00
6E3BB6	2017-07-21 10:54:00+03	57600.00
6E3BD1	2017-07-17 06:41:00+03	71200.00
6E3C06	2017-08-15 01:06:00+03	16400.00
6E3C0B	2017-07-12 22:48:00+03	68100.00
6E3CD9	2017-06-28 12:04:00+03	132800.00
6E3CF8	2017-07-18 18:40:00+03	78000.00
6E3D0E	2017-07-29 03:56:00+03	116800.00
6E3DAF	2017-07-28 09:45:00+03	21400.00
6E3EAD	2017-08-02 05:46:00+03	45000.00
6E3EC5	2017-07-08 15:21:00+03	114800.00
6E3F2B	2017-08-04 02:41:00+03	20100.00
6E3F60	2017-07-10 08:09:00+03	43400.00
6E4014	2017-07-07 18:45:00+03	40600.00
6E403F	2017-08-09 10:10:00+03	75300.00
6E4080	2017-08-08 17:11:00+03	67500.00
6E40AC	2017-07-26 06:36:00+03	54700.00
6E4101	2017-07-15 18:34:00+03	82100.00
6E4109	2017-07-18 05:06:00+03	57100.00
6E4147	2017-07-09 21:54:00+03	24800.00
6E414B	2017-07-06 02:59:00+03	58900.00
6E416C	2017-07-16 07:41:00+03	32400.00
6E418F	2017-07-16 01:17:00+03	127500.00
6E419A	2017-07-08 10:41:00+03	121800.00
6E4347	2017-07-15 07:52:00+03	77200.00
6E4383	2017-08-07 09:14:00+03	23400.00
6E4437	2017-07-06 12:59:00+03	86300.00
6E4484	2017-07-16 00:28:00+03	52000.00
6E44C7	2017-08-12 16:19:00+03	147600.00
6E44F5	2017-08-12 01:33:00+03	23600.00
6E4537	2017-08-02 05:32:00+03	90800.00
6E457E	2017-08-05 10:15:00+03	23200.00
6E459D	2017-08-04 09:26:00+03	12000.00
6E45D9	2017-07-06 21:53:00+03	32400.00
6E462A	2017-07-25 17:39:00+03	75300.00
6E463B	2017-07-23 20:40:00+03	35300.00
6E469F	2017-08-09 21:12:00+03	67100.00
6E46A8	2017-08-01 16:58:00+03	56600.00
6E4725	2017-08-05 18:29:00+03	58700.00
6E4737	2017-08-09 06:38:00+03	47800.00
6E4766	2017-08-04 10:54:00+03	86800.00
6E477A	2017-08-03 22:25:00+03	88800.00
6E47C8	2017-07-10 21:14:00+03	24800.00
6E4825	2017-07-05 22:14:00+03	21200.00
6E482F	2017-07-28 22:07:00+03	28000.00
6E48D2	2017-07-09 20:31:00+03	92900.00
6E48EB	2017-08-04 15:56:00+03	50800.00
6E4950	2017-07-19 17:56:00+03	68100.00
6E4956	2017-08-01 09:00:00+03	80300.00
6E4961	2017-07-19 03:24:00+03	89600.00
6E4970	2017-08-15 08:20:00+03	39800.00
6E4975	2017-08-11 10:00:00+03	64500.00
6E49C2	2017-06-27 22:56:00+03	123000.00
6E4A04	2017-08-02 02:03:00+03	58400.00
6E4A17	2017-07-23 19:55:00+03	19800.00
6E4A1A	2017-07-08 03:44:00+03	32800.00
6E4A46	2017-08-06 01:29:00+03	32800.00
6E4A47	2017-07-22 18:08:00+03	102000.00
6E4A64	2017-08-03 07:29:00+03	25200.00
6E4A6A	2017-07-26 16:28:00+03	68400.00
6E4A94	2017-07-29 13:57:00+03	38200.00
6E4B01	2017-08-01 09:59:00+03	28900.00
6E4B95	2017-07-20 03:39:00+03	120000.00
6E4BFB	2017-07-28 12:41:00+03	51900.00
6E4C30	2017-07-23 21:57:00+03	26200.00
6E4C33	2017-08-01 13:41:00+03	65500.00
6E4C62	2017-07-09 06:34:00+03	273000.00
6E4C70	2017-07-12 22:55:00+03	14300.00
6E4C7E	2017-07-26 19:03:00+03	135600.00
6E4C9B	2017-07-24 00:56:00+03	11700.00
6E4D5E	2017-07-03 04:27:00+03	103900.00
6E4E8F	2017-07-07 14:05:00+03	57500.00
6E4EC9	2017-08-05 10:53:00+03	26000.00
6E4EE8	2017-07-28 09:59:00+03	78200.00
6E4F01	2017-08-08 08:20:00+03	27300.00
6E4F23	2017-08-04 07:37:00+03	37200.00
6E4F44	2017-07-30 17:45:00+03	188000.00
6E4F9F	2017-08-11 10:52:00+03	70600.00
6E4FCC	2017-07-07 05:19:00+03	6000.00
6E4FD4	2017-08-01 19:31:00+03	59300.00
6E506B	2017-08-15 13:13:00+03	47200.00
6E50D8	2017-07-06 03:11:00+03	56000.00
6E50EB	2017-07-26 10:12:00+03	176800.00
6E5108	2017-08-03 14:52:00+03	48500.00
6E5222	2017-07-18 22:45:00+03	130900.00
6E5229	2017-07-04 00:27:00+03	13400.00
6E5257	2017-07-15 04:47:00+03	233800.00
6E52A9	2017-07-17 11:56:00+03	45200.00
6E5303	2017-07-23 20:57:00+03	29600.00
6E5347	2017-07-25 00:34:00+03	14800.00
6E5349	2017-07-23 10:52:00+03	666000.00
6E5356	2017-07-31 16:25:00+03	49000.00
6E5364	2017-08-11 00:10:00+03	23900.00
6E542C	2017-07-16 08:31:00+03	166100.00
6E5447	2017-07-24 11:48:00+03	13600.00
6E54A8	2017-07-04 06:32:00+03	70800.00
6E54B7	2017-07-16 06:08:00+03	58400.00
6E54EC	2017-08-07 07:52:00+03	45100.00
6E553C	2017-07-12 14:01:00+03	26000.00
6E5555	2017-07-30 10:57:00+03	45200.00
6E5583	2017-08-08 12:54:00+03	33800.00
6E5601	2017-07-05 18:56:00+03	480800.00
6E5675	2017-08-07 01:11:00+03	442100.00
6E56CC	2017-07-21 23:17:00+03	115700.00
6E56EA	2017-07-20 23:44:00+03	23200.00
6E5707	2017-08-09 16:19:00+03	70700.00
6E575D	2017-07-11 10:38:00+03	76700.00
6E57C3	2017-08-11 00:19:00+03	59800.00
6E5802	2017-07-01 05:38:00+03	69100.00
6E5881	2017-07-13 03:46:00+03	26000.00
6E5911	2017-07-30 20:44:00+03	74300.00
6E5924	2017-07-16 17:16:00+03	6600.00
6E593F	2017-08-03 10:27:00+03	68400.00
6E5966	2017-07-08 13:43:00+03	51900.00
6E5985	2017-07-09 22:59:00+03	69000.00
6E5993	2017-08-09 00:33:00+03	53600.00
6E59A0	2017-08-02 22:26:00+03	73600.00
6E59A1	2017-08-11 17:40:00+03	12600.00
6E59CA	2017-08-14 17:49:00+03	100800.00
6E5ABE	2017-07-28 15:00:00+03	50000.00
6E5ACD	2017-07-15 08:08:00+03	95800.00
6E5B08	2017-07-13 02:20:00+03	43800.00
6E5B47	2017-07-09 05:19:00+03	43500.00
6E5B4F	2017-07-27 01:28:00+03	134600.00
6E5BAC	2017-08-02 19:47:00+03	22200.00
6E5BCE	2017-07-17 15:46:00+03	94200.00
6E5BE9	2017-07-09 02:18:00+03	170200.00
6E5C21	2017-08-05 22:54:00+03	23400.00
6E5CB2	2017-07-24 13:56:00+03	43600.00
6E5CF3	2017-08-01 01:52:00+03	65500.00
6E5D33	2017-07-30 18:34:00+03	94400.00
6E5D51	2017-06-30 00:58:00+03	66600.00
6E5E12	2017-07-04 00:14:00+03	24200.00
6E5E44	2017-07-09 14:42:00+03	46700.00
6E5E79	2017-07-10 03:12:00+03	26800.00
6E5EEE	2017-08-12 16:18:00+03	28800.00
6E5F7F	2017-07-03 22:22:00+03	74900.00
6E5F83	2017-08-05 15:57:00+03	15000.00
6E5F9D	2017-06-29 21:36:00+03	24700.00
6E5FA2	2017-07-24 10:41:00+03	25400.00
6E602B	2017-07-19 06:22:00+03	193200.00
6E602E	2017-08-10 20:37:00+03	125200.00
6E6034	2017-08-12 06:37:00+03	93400.00
6E6038	2017-08-01 10:10:00+03	198400.00
6E609D	2017-08-04 16:20:00+03	12600.00
6E60BD	2017-07-13 04:39:00+03	13600.00
6E60C2	2017-07-19 16:26:00+03	38600.00
6E6152	2017-07-05 14:13:00+03	29600.00
6E6167	2017-08-15 09:59:00+03	53700.00
6E6175	2017-07-09 08:16:00+03	32800.00
6E6184	2017-08-11 13:45:00+03	174400.00
6E6197	2017-07-19 20:30:00+03	131600.00
6E61F0	2017-07-03 16:00:00+03	89200.00
6E624A	2017-07-03 02:12:00+03	16400.00
6E6297	2017-07-26 17:02:00+03	135400.00
6E62A2	2017-08-15 08:00:00+03	40800.00
6E62B0	2017-07-18 15:55:00+03	408500.00
6E6343	2017-07-29 23:30:00+03	46800.00
6E6390	2017-07-16 05:29:00+03	18000.00
6E642D	2017-08-05 23:19:00+03	43500.00
6E6458	2017-07-07 22:12:00+03	70800.00
6E64A8	2017-08-10 13:42:00+03	102100.00
6E64AB	2017-08-05 12:53:00+03	86600.00
6E64B7	2017-08-07 01:18:00+03	16800.00
6E64DC	2017-08-02 23:37:00+03	22400.00
6E6517	2017-06-30 22:57:00+03	17200.00
6E661B	2017-07-07 11:39:00+03	8400.00
6E661D	2017-07-09 06:07:00+03	82900.00
6E66A8	2017-08-11 09:27:00+03	99200.00
6E66B6	2017-07-08 10:18:00+03	39000.00
6E66EF	2017-07-08 16:38:00+03	94000.00
6E675C	2017-08-03 08:43:00+03	25600.00
6E67A9	2017-08-02 11:04:00+03	51900.00
6E6800	2017-08-11 08:38:00+03	6700.00
6E68E5	2017-07-31 16:07:00+03	92400.00
6E690A	2017-07-09 10:13:00+03	66600.00
6E6945	2017-07-16 12:12:00+03	66600.00
6E69A3	2017-07-09 08:25:00+03	69500.00
6E6A54	2017-07-17 03:28:00+03	28800.00
6E6AAE	2017-07-30 16:11:00+03	20600.00
6E6ACE	2017-07-21 12:48:00+03	99700.00
6E6B27	2017-07-09 17:19:00+03	63200.00
6E6B8E	2017-07-04 11:29:00+03	101100.00
6E6B98	2017-08-07 14:02:00+03	46000.00
6E6C00	2017-07-22 18:41:00+03	28800.00
6E6C06	2017-08-10 23:05:00+03	87700.00
6E6C15	2017-07-24 01:52:00+03	21400.00
6E6C17	2017-07-31 04:27:00+03	111600.00
6E6C50	2017-07-12 20:47:00+03	48800.00
6E6C5F	2017-07-17 07:29:00+03	47500.00
6E6CB3	2017-07-19 10:42:00+03	433200.00
6E6D51	2017-07-13 10:03:00+03	25600.00
6E6DDB	2017-07-16 07:06:00+03	46400.00
6E6DDF	2017-07-31 10:14:00+03	65500.00
6E6E29	2017-07-30 08:06:00+03	49800.00
6E6F3B	2017-07-25 11:32:00+03	43900.00
6E6F54	2017-08-03 08:15:00+03	28800.00
6E6F62	2017-07-28 06:26:00+03	42000.00
6E6F6D	2017-07-24 10:59:00+03	60700.00
6E6F8D	2017-07-21 02:42:00+03	67600.00
6E6F9C	2017-08-09 14:18:00+03	116800.00
6E6FCB	2017-08-02 09:21:00+03	12600.00
6E6FF6	2017-07-23 19:01:00+03	125200.00
6E6FFE	2017-08-10 09:37:00+03	117700.00
6E7081	2017-08-03 14:34:00+03	123000.00
6E713B	2017-07-06 01:48:00+03	55800.00
6E714E	2017-07-27 15:59:00+03	75300.00
6E71B9	2017-07-09 19:44:00+03	29600.00
6E71C8	2017-08-12 13:57:00+03	60400.00
6E71DA	2017-07-18 19:51:00+03	123000.00
6E724B	2017-07-18 16:32:00+03	25600.00
6E728B	2017-07-14 07:48:00+03	17000.00
6E7299	2017-07-04 22:23:00+03	46900.00
6E7304	2017-07-18 03:18:00+03	60100.00
6E73BA	2017-07-28 07:09:00+03	137800.00
6E7434	2017-07-18 14:35:00+03	18600.00
6E74B0	2017-07-06 16:45:00+03	28000.00
6E7584	2017-06-27 04:29:00+03	116300.00
6E75D8	2017-07-15 00:37:00+03	55600.00
6E75F3	2017-07-29 15:35:00+03	174500.00
6E764D	2017-07-22 10:17:00+03	10600.00
6E7685	2017-07-10 05:45:00+03	13700.00
6E76F5	2017-07-05 14:30:00+03	16800.00
6E772F	2017-07-06 04:38:00+03	31600.00
6E773D	2017-07-16 18:14:00+03	393800.00
6E778F	2017-07-31 17:51:00+03	76800.00
6E77F0	2017-07-01 07:03:00+03	31600.00
6E794B	2017-08-10 18:43:00+03	123000.00
6E7994	2017-07-30 14:07:00+03	53200.00
6E799B	2017-07-28 05:50:00+03	138000.00
6E79C6	2017-08-15 06:22:00+03	62800.00
6E79D1	2017-07-16 20:32:00+03	78100.00
6E7A10	2017-07-17 12:28:00+03	33300.00
6E7A14	2017-08-06 12:46:00+03	37400.00
6E7A45	2017-07-30 16:52:00+03	48500.00
6E7A5E	2017-07-17 14:09:00+03	136700.00
6E7AE4	2017-07-28 17:12:00+03	231600.00
6E7AEF	2017-08-09 04:12:00+03	92800.00
6E7BD5	2017-07-31 04:20:00+03	71600.00
6E7C08	2017-08-02 07:50:00+03	177200.00
6E7C2B	2017-08-15 03:49:00+03	56000.00
6E7CF7	2017-07-19 20:46:00+03	93400.00
6E7D33	2017-08-12 22:11:00+03	135400.00
6E7E87	2017-08-09 05:55:00+03	7400.00
6E7F19	2017-08-08 03:48:00+03	26700.00
6E7F23	2017-07-05 02:50:00+03	128800.00
6E7F2F	2017-07-02 10:24:00+03	93900.00
6E7F4A	2017-07-02 16:02:00+03	148200.00
6E7F84	2017-07-24 11:51:00+03	65000.00
6E7F8B	2017-08-13 03:36:00+03	13400.00
6E7F8C	2017-08-08 12:38:00+03	12000.00
6E7F92	2017-08-01 21:21:00+03	59400.00
6E8054	2017-07-13 14:30:00+03	258400.00
6E8055	2017-07-15 08:30:00+03	60000.00
6E808D	2017-07-09 12:58:00+03	6700.00
6E8145	2017-08-13 23:50:00+03	67600.00
6E8176	2017-07-04 23:03:00+03	348800.00
6E81B8	2017-07-30 05:58:00+03	46000.00
6E8228	2017-07-22 08:31:00+03	122300.00
6E8243	2017-08-12 01:30:00+03	48800.00
6E828F	2017-07-18 19:33:00+03	61900.00
6E82BD	2017-07-06 05:37:00+03	100600.00
6E82F5	2017-07-09 12:40:00+03	20500.00
6E8339	2017-07-02 05:33:00+03	136200.00
6E839E	2017-08-09 06:43:00+03	26200.00
6E839F	2017-08-15 11:56:00+03	38600.00
6E83AF	2017-07-02 07:52:00+03	90800.00
6E83CF	2017-07-29 08:40:00+03	14000.00
6E845E	2017-08-15 12:06:00+03	85200.00
6E8464	2017-08-13 17:16:00+03	130400.00
6E84A9	2017-07-14 04:42:00+03	246000.00
6E84B3	2017-08-02 02:43:00+03	6800.00
6E84D7	2017-08-11 20:45:00+03	40000.00
6E84E5	2017-08-09 11:27:00+03	46000.00
6E8509	2017-08-03 22:42:00+03	28000.00
6E8528	2017-07-16 02:58:00+03	199800.00
6E85BB	2017-07-25 16:42:00+03	12600.00
6E85F4	2017-08-15 09:10:00+03	64000.00
6E85FB	2017-07-14 15:22:00+03	28000.00
6E8642	2017-07-30 18:45:00+03	285000.00
6E86DC	2017-08-14 17:33:00+03	74300.00
6E86E9	2017-08-12 13:34:00+03	149000.00
6E86F8	2017-07-16 09:34:00+03	23400.00
6E8828	2017-07-01 17:26:00+03	75300.00
6E8837	2017-07-24 22:19:00+03	34100.00
6E8872	2017-07-23 22:54:00+03	52400.00
6E887D	2017-08-07 09:30:00+03	33400.00
6E88B3	2017-07-08 21:09:00+03	29600.00
6E88B6	2017-08-04 03:15:00+03	50100.00
6E892B	2017-08-12 21:12:00+03	100200.00
6E892C	2017-07-22 08:00:00+03	118800.00
6E8946	2017-08-15 12:49:00+03	60400.00
6E895A	2017-07-04 21:42:00+03	28000.00
6E8972	2017-07-26 11:03:00+03	133900.00
6E8991	2017-07-18 22:33:00+03	48800.00
6E89D3	2017-07-02 06:10:00+03	100600.00
6E89D4	2017-08-07 02:50:00+03	12600.00
6E8A16	2017-07-08 13:30:00+03	119500.00
6E8A3C	2017-07-25 03:34:00+03	257500.00
6E8A40	2017-08-02 16:38:00+03	28800.00
6E8AF7	2017-07-22 00:32:00+03	47400.00
6E8B08	2017-07-26 05:38:00+03	38000.00
6E8B25	2017-07-28 04:28:00+03	123000.00
6E8B9C	2017-07-08 11:44:00+03	13000.00
6E8BBD	2017-07-21 05:57:00+03	37200.00
6E8BF4	2017-07-21 05:45:00+03	54500.00
6E8CB0	2017-08-10 08:53:00+03	26000.00
6E8CC2	2017-08-12 20:44:00+03	517700.00
6E8D53	2017-07-10 14:27:00+03	22000.00
6E8D8D	2017-07-19 07:15:00+03	49900.00
6E8D99	2017-08-14 10:59:00+03	132500.00
6E8E95	2017-07-03 01:04:00+03	22000.00
6E8F0E	2017-07-04 02:06:00+03	38800.00
6E8FC9	2017-07-10 08:07:00+03	6800.00
6E9022	2017-07-24 11:28:00+03	66600.00
6E9099	2017-07-10 03:46:00+03	18000.00
6E90FF	2017-07-22 08:48:00+03	60700.00
6E9177	2017-08-11 18:09:00+03	171100.00
6E91B1	2017-07-14 16:10:00+03	125600.00
6E91C5	2017-08-05 13:07:00+03	10600.00
6E91F8	2017-07-05 15:43:00+03	131600.00
6E9274	2017-06-24 02:00:00+03	50600.00
6E930A	2017-08-05 21:50:00+03	38800.00
6E930C	2017-07-22 10:54:00+03	90800.00
6E9386	2017-08-06 07:14:00+03	123600.00
6E93CB	2017-07-10 21:14:00+03	111600.00
6E93CC	2017-08-05 04:20:00+03	37200.00
6E93CD	2017-07-15 03:00:00+03	28800.00
6E942B	2017-07-19 19:54:00+03	28300.00
6E944B	2017-08-15 03:41:00+03	105100.00
6E948B	2017-07-18 10:09:00+03	23200.00
6E94B2	2017-08-08 01:15:00+03	36600.00
6E94C5	2017-07-17 14:46:00+03	147700.00
6E94E2	2017-07-06 06:14:00+03	92800.00
6E94EF	2017-08-14 03:16:00+03	56600.00
6E94F1	2017-08-12 17:58:00+03	166100.00
6E95D0	2017-07-14 21:05:00+03	210900.00
6E9615	2017-08-09 11:29:00+03	49400.00
6E964A	2017-07-05 11:54:00+03	60900.00
6E96FA	2017-07-14 23:21:00+03	44000.00
6E9711	2017-08-09 06:54:00+03	72400.00
6E971C	2017-08-14 06:44:00+03	77900.00
6E9741	2017-08-03 00:16:00+03	170000.00
6E97B7	2017-07-29 22:39:00+03	96300.00
6E9879	2017-07-30 10:59:00+03	16400.00
6E98D6	2017-07-14 17:27:00+03	46300.00
6E9931	2017-08-04 10:37:00+03	193600.00
6E99E3	2017-07-16 11:08:00+03	23200.00
6E99F9	2017-07-29 17:58:00+03	369000.00
6E9A30	2017-08-13 14:08:00+03	214300.00
6E9A6C	2017-07-28 04:48:00+03	25600.00
6E9A96	2017-07-19 22:43:00+03	26800.00
6E9AB4	2017-07-30 17:47:00+03	21400.00
6E9B1C	2017-07-19 22:07:00+03	80800.00
6E9B49	2017-07-16 09:55:00+03	67600.00
6E9B5C	2017-08-08 02:14:00+03	141600.00
6E9C4A	2017-08-12 16:10:00+03	531300.00
6E9C5A	2017-08-13 10:26:00+03	24600.00
6E9CBD	2017-08-13 20:36:00+03	28000.00
6E9CF2	2017-08-13 18:09:00+03	86500.00
6E9CFD	2017-08-07 10:39:00+03	34100.00
6E9D29	2017-07-28 02:58:00+03	55800.00
6E9D33	2017-07-20 15:20:00+03	16800.00
6E9D60	2017-07-15 10:19:00+03	45100.00
6E9EC1	2017-07-06 17:32:00+03	42800.00
6E9EE2	2017-07-24 09:47:00+03	84000.00
6E9EE5	2017-07-18 16:33:00+03	111600.00
6E9F00	2017-07-20 21:50:00+03	195600.00
6E9F22	2017-08-03 01:34:00+03	12600.00
6E9F58	2017-08-01 22:32:00+03	26800.00
6E9F9C	2017-07-21 13:31:00+03	52900.00
6E9FCA	2017-07-16 23:33:00+03	93900.00
6E9FD6	2017-07-14 02:58:00+03	32800.00
6E9FE8	2017-08-04 22:13:00+03	367700.00
6E9FF7	2017-08-11 18:56:00+03	112000.00
6EA006	2017-07-30 02:08:00+03	199700.00
6EA00C	2017-08-03 15:23:00+03	54500.00
6EA01D	2017-07-30 14:52:00+03	100600.00
6EA074	2017-08-13 10:02:00+03	34000.00
6EA089	2017-07-22 04:05:00+03	42700.00
6EA095	2017-07-31 04:07:00+03	27200.00
6EA0B1	2017-07-14 21:03:00+03	42400.00
6EA0F0	2017-08-03 10:24:00+03	47700.00
6EA0FB	2017-07-31 17:50:00+03	28000.00
6EA100	2017-08-03 00:17:00+03	42800.00
6EA19D	2017-06-29 15:08:00+03	15400.00
6EA1A1	2017-08-13 22:05:00+03	179500.00
6EA22A	2017-07-07 19:51:00+03	34000.00
6EA24C	2017-07-27 11:16:00+03	25100.00
6EA272	2017-07-08 22:42:00+03	199800.00
6EA284	2017-07-27 01:17:00+03	240600.00
6EA291	2017-08-07 19:21:00+03	291300.00
6EA2A7	2017-08-02 09:04:00+03	99600.00
6EA2AA	2017-07-16 06:11:00+03	20400.00
6EA2B5	2017-07-16 06:35:00+03	56600.00
6EA329	2017-08-13 22:54:00+03	136000.00
6EA39A	2017-07-02 23:26:00+03	83000.00
6EA3CE	2017-07-09 19:23:00+03	99700.00
6EA438	2017-08-06 00:55:00+03	23600.00
6EA485	2017-08-09 05:04:00+03	174500.00
6EA4A0	2017-07-02 01:47:00+03	32800.00
6EA4C0	2017-08-06 03:02:00+03	406600.00
6EA4E0	2017-07-13 23:14:00+03	46800.00
6EA4F8	2017-08-12 14:44:00+03	7200.00
6EA510	2017-08-11 12:35:00+03	265700.00
6EA53E	2017-07-20 04:27:00+03	258400.00
6EA5C7	2017-08-07 09:20:00+03	27200.00
6EA696	2017-08-14 11:43:00+03	13400.00
6EA69A	2017-07-11 10:07:00+03	23200.00
6EA69B	2017-07-19 03:00:00+03	27400.00
6EA74A	2017-08-06 21:34:00+03	217700.00
6EA796	2017-07-18 16:28:00+03	56000.00
6EA7E3	2017-07-13 07:29:00+03	12600.00
6EA7E8	2017-07-03 04:00:00+03	93000.00
6EA7F9	2017-07-30 17:20:00+03	103800.00
6EA87E	2017-07-28 15:52:00+03	55800.00
6EA89C	2017-08-07 02:56:00+03	48500.00
6EA8B0	2017-07-17 02:09:00+03	54800.00
6EA8D9	2017-08-10 22:00:00+03	21600.00
6EA983	2017-07-10 01:06:00+03	165500.00
6EA996	2017-07-09 01:45:00+03	56000.00
6EA99B	2017-07-22 14:38:00+03	16400.00
6EA9CB	2017-07-10 11:56:00+03	50900.00
6EA9CD	2017-07-05 18:52:00+03	23200.00
6EA9FC	2017-08-09 12:48:00+03	103500.00
6EAA35	2017-08-04 20:22:00+03	84100.00
6EAA3B	2017-07-04 10:02:00+03	83500.00
6EAA78	2017-07-02 05:06:00+03	67800.00
6EAA95	2017-07-17 10:30:00+03	81700.00
6EAAA8	2017-08-10 15:31:00+03	248300.00
6EAAF2	2017-07-15 18:20:00+03	27800.00
6EAB62	2017-07-31 19:14:00+03	44500.00
6EAB66	2017-07-07 20:48:00+03	181600.00
6EAB86	2017-07-06 02:00:00+03	19600.00
6EABC6	2017-08-12 10:52:00+03	36200.00
6EABDD	2017-07-21 08:28:00+03	47700.00
6EABE1	2017-07-30 00:55:00+03	92700.00
6EAC12	2017-08-04 11:10:00+03	26000.00
6EAC9B	2017-07-10 23:28:00+03	73300.00
6EACC0	2017-08-10 05:46:00+03	63200.00
6EAD17	2017-07-02 18:34:00+03	25800.00
6EAD67	2017-08-06 17:12:00+03	167400.00
6EAD90	2017-07-18 02:02:00+03	28000.00
6EAD98	2017-07-22 10:40:00+03	29400.00
6EAD9F	2017-08-07 22:08:00+03	136800.00
6EADCF	2017-07-02 14:38:00+03	114400.00
6EADF8	2017-08-15 10:30:00+03	48500.00
6EAED9	2017-08-09 18:45:00+03	21800.00
6EAEF0	2017-07-30 20:54:00+03	584400.00
6EAF34	2017-07-20 20:31:00+03	21600.00
6EAF91	2017-07-30 06:25:00+03	265700.00
6EAF95	2017-07-18 15:05:00+03	46800.00
6EAF98	2017-08-06 19:22:00+03	32700.00
6EAFAA	2017-07-23 16:02:00+03	111600.00
6EAFED	2017-07-11 15:48:00+03	123600.00
6EAFF4	2017-07-24 19:27:00+03	77200.00
6EB026	2017-07-27 23:37:00+03	19600.00
6EB037	2017-07-18 17:02:00+03	124200.00
6EB090	2017-07-24 14:37:00+03	84800.00
6EB0A2	2017-07-06 06:10:00+03	21400.00
6EB145	2017-08-13 14:36:00+03	92800.00
6EB1A1	2017-08-04 19:46:00+03	16400.00
6EB1D6	2017-07-30 08:57:00+03	27300.00
6EB1E6	2017-07-12 14:17:00+03	169300.00
6EB1F6	2017-08-10 19:54:00+03	8200.00
6EB1FB	2017-07-21 02:35:00+03	59200.00
6EB224	2017-08-01 18:16:00+03	42800.00
6EB255	2017-07-25 08:17:00+03	48800.00
6EB288	2017-07-08 05:44:00+03	147700.00
6EB292	2017-07-20 23:46:00+03	73500.00
6EB2BE	2017-07-03 04:47:00+03	179400.00
6EB2DA	2017-07-16 05:06:00+03	56600.00
6EB374	2017-07-20 21:24:00+03	24200.00
6EB376	2017-07-13 13:42:00+03	65100.00
6EB446	2017-07-11 22:28:00+03	28000.00
6EB48F	2017-08-01 02:51:00+03	25000.00
6EB49E	2017-07-09 09:13:00+03	90800.00
6EB53B	2017-07-05 18:05:00+03	95600.00
6EB548	2017-07-28 22:06:00+03	38200.00
6EB550	2017-07-15 15:20:00+03	75600.00
6EB57A	2017-07-06 15:51:00+03	75200.00
6EB584	2017-08-03 13:07:00+03	26300.00
6EB5A3	2017-08-07 19:37:00+03	27200.00
6EB5DC	2017-07-27 13:44:00+03	258400.00
6EB5E1	2017-07-08 19:28:00+03	46200.00
6EB5E5	2017-07-21 22:13:00+03	90700.00
6EB605	2017-07-02 08:49:00+03	49800.00
6EB606	2017-08-09 05:25:00+03	15900.00
6EB61C	2017-07-29 18:54:00+03	38800.00
6EB626	2017-08-08 04:04:00+03	146200.00
6EB66C	2017-07-21 22:28:00+03	40000.00
6EB6D6	2017-07-26 08:53:00+03	131600.00
6EB71D	2017-08-09 13:51:00+03	46700.00
6EB746	2017-07-24 08:42:00+03	80400.00
6EB77A	2017-06-27 10:27:00+03	46300.00
6EB787	2017-08-05 07:11:00+03	149000.00
6EB7F3	2017-07-25 18:43:00+03	156500.00
6EB808	2017-07-26 00:46:00+03	58800.00
6EB816	2017-07-02 05:44:00+03	67600.00
6EB827	2017-07-02 03:36:00+03	51300.00
6EB89E	2017-08-03 09:38:00+03	40000.00
6EB89F	2017-07-30 04:58:00+03	25900.00
6EB939	2017-07-17 19:58:00+03	27900.00
6EB95B	2017-07-28 01:17:00+03	143200.00
6EB967	2017-07-03 23:22:00+03	126500.00
6EB986	2017-08-15 16:53:00+03	25100.00
6EB9B5	2017-08-02 17:06:00+03	12600.00
6EBA47	2017-07-26 20:31:00+03	399600.00
6EBA60	2017-08-05 01:25:00+03	65900.00
6EBA79	2017-07-23 20:49:00+03	58400.00
6EBAA8	2017-07-11 20:46:00+03	16800.00
6EBAAD	2017-07-28 20:34:00+03	135200.00
6EBB68	2017-08-09 11:57:00+03	203300.00
6EBB7E	2017-07-07 00:11:00+03	49300.00
6EBBFD	2017-08-12 06:28:00+03	39800.00
6EBC0F	2017-08-05 11:28:00+03	62700.00
6EBC34	2017-07-11 13:10:00+03	20200.00
6EBC7A	2017-08-15 13:04:00+03	28700.00
6EBCC5	2017-07-03 10:57:00+03	103200.00
6EBD04	2017-07-01 16:03:00+03	112000.00
6EBD52	2017-08-07 01:43:00+03	27200.00
6EBD60	2017-07-31 10:01:00+03	34000.00
6EBD93	2017-07-29 18:16:00+03	70800.00
6EBDE3	2017-08-10 04:37:00+03	123600.00
6EBDFB	2017-07-22 22:58:00+03	114800.00
6EBE0A	2017-08-08 05:46:00+03	36200.00
6EBE1B	2017-08-04 19:10:00+03	35800.00
6EBE40	2017-07-29 17:13:00+03	99700.00
6EBE4A	2017-07-01 02:31:00+03	45100.00
6EBE4E	2017-08-05 10:53:00+03	106300.00
6EBF07	2017-08-02 14:41:00+03	198400.00
6EBF0D	2017-07-18 20:23:00+03	265600.00
6EBF61	2017-08-03 07:54:00+03	27200.00
6EBF72	2017-07-17 03:04:00+03	265600.00
6EBFD6	2017-08-06 22:19:00+03	14400.00
6EBFDB	2017-07-24 10:35:00+03	61800.00
6EBFDF	2017-07-08 02:00:00+03	3400.00
6EC024	2017-07-02 01:51:00+03	185700.00
6EC073	2017-07-04 16:27:00+03	54100.00
6EC088	2017-08-02 13:52:00+03	26700.00
6EC0A0	2017-08-04 14:03:00+03	37900.00
6EC0AB	2017-07-20 16:22:00+03	148200.00
6EC0B0	2017-08-03 02:13:00+03	46400.00
6EC0CC	2017-08-11 02:11:00+03	39500.00
6EC117	2017-07-08 05:00:00+03	26000.00
6EC147	2017-07-14 12:53:00+03	82700.00
6EC1AC	2017-07-08 23:29:00+03	73500.00
6EC1E0	2017-07-15 16:42:00+03	49800.00
6EC1FE	2017-07-21 10:10:00+03	14400.00
6EC20C	2017-07-12 09:13:00+03	191200.00
6EC2CC	2017-07-16 17:18:00+03	14000.00
6EC2F8	2017-07-15 13:57:00+03	21800.00
6EC33B	2017-08-09 10:38:00+03	40200.00
6EC373	2017-07-24 15:23:00+03	64800.00
6EC376	2017-07-27 01:05:00+03	57600.00
6EC3A5	2017-08-05 23:46:00+03	24400.00
6EC400	2017-08-04 02:08:00+03	85000.00
6EC41E	2017-08-04 12:19:00+03	177200.00
6EC424	2017-08-14 21:24:00+03	54300.00
6EC443	2017-07-25 00:44:00+03	54000.00
6EC449	2017-08-14 17:14:00+03	27200.00
6EC45F	2017-07-23 12:28:00+03	119700.00
6EC4BA	2017-06-30 08:09:00+03	128800.00
6EC546	2017-08-15 03:37:00+03	185300.00
6EC5CC	2017-08-02 19:04:00+03	39900.00
6EC5DF	2017-08-03 08:38:00+03	64800.00
6EC5ED	2017-07-19 19:30:00+03	73400.00
6EC5F1	2017-07-13 00:03:00+03	54100.00
6EC622	2017-07-26 18:27:00+03	332800.00
6EC66F	2017-07-02 10:09:00+03	99200.00
6EC695	2017-08-08 09:14:00+03	75600.00
6EC6A9	2017-07-29 01:02:00+03	94000.00
6EC6EF	2017-07-05 20:44:00+03	34000.00
6EC756	2017-07-11 23:39:00+03	14400.00
6EC777	2017-07-23 06:03:00+03	85000.00
6EC876	2017-07-29 10:38:00+03	46000.00
6EC8AA	2017-08-04 18:22:00+03	297600.00
6EC8AF	2017-07-31 01:52:00+03	37900.00
6EC8F8	2017-07-30 11:33:00+03	62700.00
6EC900	2017-08-01 05:58:00+03	46000.00
6EC91A	2017-07-24 02:53:00+03	28800.00
6EC937	2017-07-06 12:32:00+03	6600.00
6EC939	2017-08-08 17:24:00+03	25400.00
6ECA18	2017-07-20 10:49:00+03	64100.00
6ECAE7	2017-08-10 02:30:00+03	44800.00
6ECB50	2017-07-30 18:39:00+03	293400.00
6ECB89	2017-08-12 05:44:00+03	62400.00
6ECBA6	2017-07-31 20:46:00+03	29600.00
6ECBB7	2017-07-15 16:48:00+03	123000.00
6ECBE1	2017-07-05 09:46:00+03	54800.00
6ECC3C	2017-07-17 17:28:00+03	155600.00
6ECCF7	2017-07-29 18:11:00+03	32800.00
6ECD4B	2017-07-22 11:00:00+03	53600.00
6ECDB1	2017-08-05 08:44:00+03	935200.00
6ECDEC	2017-08-03 05:30:00+03	128800.00
6ECDF5	2017-07-27 12:11:00+03	22000.00
6ECE83	2017-07-26 16:29:00+03	8000.00
6ECE91	2017-07-22 11:59:00+03	82000.00
6ECEAD	2017-07-08 05:26:00+03	50600.00
6ECEB2	2017-07-02 22:15:00+03	83200.00
6ECEDE	2017-07-17 08:39:00+03	83300.00
6ECF26	2017-07-05 23:43:00+03	55800.00
6ECF35	2017-08-13 13:02:00+03	34600.00
6ECFCA	2017-07-23 13:05:00+03	88800.00
6ED027	2017-07-06 06:47:00+03	211500.00
6ED056	2017-07-05 14:27:00+03	185600.00
6ED064	2017-07-09 14:19:00+03	21400.00
6ED08D	2017-07-13 14:40:00+03	123000.00
6ED098	2017-08-13 09:47:00+03	265600.00
6ED14F	2017-07-15 14:11:00+03	83400.00
6ED177	2017-07-07 10:31:00+03	153800.00
6ED18A	2017-07-11 11:52:00+03	21800.00
6ED1AA	2017-07-11 17:37:00+03	101200.00
6ED200	2017-07-20 16:50:00+03	282300.00
6ED21D	2017-07-29 04:32:00+03	27000.00
6ED29B	2017-07-24 05:09:00+03	16400.00
6ED2D1	2017-08-14 20:18:00+03	81700.00
6ED2FE	2017-06-29 08:17:00+03	37900.00
6ED308	2017-08-13 21:52:00+03	77800.00
6ED3CC	2017-07-20 05:00:00+03	13800.00
6ED468	2017-07-29 00:56:00+03	21400.00
6ED47B	2017-08-07 21:24:00+03	26000.00
6ED481	2017-07-26 15:06:00+03	184500.00
6ED4AF	2017-07-05 03:31:00+03	355200.00
6ED4CD	2017-08-10 08:09:00+03	67600.00
6ED501	2017-07-28 11:54:00+03	141400.00
6ED51D	2017-08-09 06:40:00+03	56900.00
6ED527	2017-08-01 12:08:00+03	9800.00
6ED54E	2017-07-03 21:07:00+03	49100.00
6ED561	2017-07-21 09:21:00+03	86600.00
6ED5C7	2017-07-08 02:14:00+03	113300.00
6ED5D4	2017-07-04 04:13:00+03	60400.00
6ED620	2017-07-29 11:04:00+03	16400.00
6ED674	2017-07-27 16:51:00+03	124200.00
6ED685	2017-07-29 03:46:00+03	47100.00
6ED6D2	2017-07-02 23:02:00+03	114800.00
6ED6D6	2017-07-25 05:03:00+03	68800.00
6ED6D8	2017-08-12 12:57:00+03	24400.00
6ED734	2017-07-12 11:27:00+03	17800.00
6ED77E	2017-08-03 13:04:00+03	13400.00
6ED7CC	2017-08-03 09:34:00+03	45100.00
6ED7F3	2017-07-17 16:29:00+03	112000.00
6ED83E	2017-07-31 20:15:00+03	207200.00
6ED89C	2017-08-02 07:12:00+03	156400.00
6ED89D	2017-07-07 20:53:00+03	97900.00
6ED8BF	2017-08-07 07:04:00+03	112000.00
6ED8F1	2017-07-11 00:26:00+03	125200.00
6ED8FA	2017-07-22 12:43:00+03	89200.00
6ED910	2017-08-11 03:00:00+03	81600.00
6ED946	2017-08-02 07:47:00+03	21400.00
6ED981	2017-07-17 10:35:00+03	65500.00
6ED986	2017-07-19 16:47:00+03	47100.00
6ED9D6	2017-08-13 23:09:00+03	23200.00
6EDAE7	2017-06-29 06:55:00+03	25100.00
6EDAF8	2017-07-07 11:04:00+03	170200.00
6EDB45	2017-07-23 16:31:00+03	89700.00
6EDB5A	2017-07-03 23:54:00+03	31600.00
6EDBA2	2017-07-27 00:26:00+03	37700.00
6EDBED	2017-07-28 09:21:00+03	28300.00
6EDC14	2017-07-31 10:17:00+03	123000.00
6EDCD8	2017-07-26 04:55:00+03	58400.00
6EDCFE	2017-08-13 11:56:00+03	62100.00
6EDD07	2017-08-13 20:56:00+03	67400.00
6EDDC6	2017-07-31 15:37:00+03	115800.00
6EDDEA	2017-08-13 17:42:00+03	135200.00
6EDE37	2017-07-15 17:34:00+03	141600.00
6EDEC2	2017-07-06 14:33:00+03	67100.00
6EDF10	2017-08-08 12:50:00+03	55800.00
6EDF25	2017-08-04 19:31:00+03	24800.00
6EDF27	2017-07-08 00:38:00+03	38400.00
6EDF6F	2017-07-20 14:48:00+03	89600.00
6EE0BC	2017-07-20 18:25:00+03	54500.00
6EE0C3	2017-08-13 01:55:00+03	27300.00
6EE102	2017-08-05 16:31:00+03	265700.00
6EE10B	2017-07-06 12:16:00+03	56000.00
6EE134	2017-08-12 04:57:00+03	72400.00
6EE15D	2017-08-06 17:06:00+03	46400.00
6EE163	2017-08-06 17:13:00+03	57600.00
6EE24D	2017-07-16 23:31:00+03	62700.00
6EE276	2017-06-30 11:23:00+03	6200.00
6EE2D7	2017-07-19 00:27:00+03	34000.00
6EE2E4	2017-07-20 19:17:00+03	266400.00
6EE471	2017-08-06 23:07:00+03	29400.00
6EE49C	2017-07-15 06:40:00+03	112300.00
6EE4A6	2017-07-12 03:05:00+03	54500.00
6EE50D	2017-07-10 05:51:00+03	40000.00
6EE527	2017-07-24 10:32:00+03	46800.00
6EE573	2017-07-07 17:26:00+03	28800.00
6EE576	2017-07-04 10:57:00+03	46400.00
6EE5E7	2017-08-05 00:34:00+03	36400.00
6EE61A	2017-08-08 00:20:00+03	21800.00
6EE69E	2017-07-02 05:26:00+03	103500.00
6EE6AF	2017-07-08 23:22:00+03	136200.00
6EE705	2017-07-20 11:38:00+03	6700.00
6EE716	2017-08-11 16:22:00+03	155600.00
6EE75C	2017-08-06 16:06:00+03	63400.00
6EE78A	2017-08-09 14:59:00+03	13600.00
6EE7A6	2017-07-12 08:28:00+03	156300.00
6EE81C	2017-08-07 14:58:00+03	89600.00
6EE827	2017-08-04 16:29:00+03	88100.00
6EE8FF	2017-07-14 00:28:00+03	12600.00
6EE923	2017-07-30 02:25:00+03	124700.00
6EE9A2	2017-07-06 09:23:00+03	42400.00
6EEA0F	2017-08-14 11:37:00+03	43400.00
6EEA22	2017-07-17 17:06:00+03	53200.00
6EEA90	2017-08-07 23:17:00+03	32800.00
6EEB05	2017-07-23 06:27:00+03	139800.00
6EEB3E	2017-07-26 01:52:00+03	192400.00
6EEB53	2017-08-09 21:55:00+03	25100.00
6EEB68	2017-08-02 17:08:00+03	121400.00
6EEB93	2017-07-14 23:32:00+03	66600.00
6EEB9D	2017-08-14 18:07:00+03	29400.00
6EEBA8	2017-08-04 18:34:00+03	31800.00
6EEBDE	2017-07-25 12:08:00+03	40600.00
6EEC25	2017-07-20 22:28:00+03	29800.00
6EEC57	2017-07-24 12:07:00+03	30000.00
6EEC67	2017-07-06 10:31:00+03	129200.00
6EECAE	2017-07-11 18:55:00+03	135600.00
6EECBC	2017-07-22 10:52:00+03	13300.00
6EECE3	2017-08-02 14:37:00+03	26000.00
6EECEC	2017-07-08 07:34:00+03	78000.00
6EED3A	2017-08-04 16:35:00+03	41800.00
6EED8F	2017-07-02 22:35:00+03	62900.00
6EEE68	2017-07-14 22:47:00+03	111600.00
6EEE92	2017-07-22 14:00:00+03	23600.00
6EEF02	2017-07-09 21:20:00+03	53300.00
6EEF54	2017-08-10 07:46:00+03	133200.00
6EEF8E	2017-07-18 08:45:00+03	56600.00
6EEFED	2017-07-28 21:31:00+03	396500.00
6EF01C	2017-07-06 20:01:00+03	26000.00
6EF022	2017-07-02 03:38:00+03	56100.00
6EF030	2017-07-24 16:34:00+03	40000.00
6EF06D	2017-08-05 04:20:00+03	27200.00
6EF130	2017-07-13 21:37:00+03	13000.00
6EF140	2017-06-30 11:33:00+03	81600.00
6EF16C	2017-07-20 04:08:00+03	39200.00
6EF1EF	2017-07-22 14:43:00+03	61400.00
6EF21B	2017-07-05 23:38:00+03	26000.00
6EF2DB	2017-08-07 22:19:00+03	87000.00
6EF351	2017-07-17 13:40:00+03	16400.00
6EF36A	2017-07-19 20:30:00+03	93900.00
6EF376	2017-07-15 22:58:00+03	26600.00
6EF418	2017-08-06 21:25:00+03	85000.00
6EF41D	2017-08-03 11:28:00+03	66600.00
6EF45D	2017-07-04 15:31:00+03	174400.00
6EF4E1	2017-08-09 19:29:00+03	147700.00
6EF4F5	2017-07-11 01:08:00+03	210000.00
6EF50C	2017-07-09 04:05:00+03	27400.00
6EF5B0	2017-08-12 18:03:00+03	34100.00
6EF5EC	2017-08-09 18:24:00+03	81900.00
6EF600	2017-08-04 12:54:00+03	242700.00
6EF60B	2017-07-21 04:29:00+03	66600.00
6EF6EA	2017-08-04 18:12:00+03	89000.00
6EF75B	2017-07-23 05:44:00+03	115100.00
6EF79E	2017-08-04 21:31:00+03	64500.00
6EF7D8	2017-08-05 18:29:00+03	13400.00
6EF801	2017-08-01 12:45:00+03	28000.00
6EF86A	2017-08-13 15:49:00+03	36100.00
6EF8C1	2017-08-11 10:18:00+03	67600.00
6EF8F4	2017-07-06 20:17:00+03	24400.00
6EF910	2017-08-14 20:33:00+03	16100.00
6EF918	2017-07-11 21:03:00+03	350300.00
6EF96D	2017-08-15 08:53:00+03	46900.00
6EF98E	2017-07-26 04:35:00+03	123000.00
6EFA1B	2017-07-25 00:53:00+03	15100.00
6EFA35	2017-07-04 07:46:00+03	54600.00
6EFAA4	2017-07-14 10:45:00+03	301600.00
6EFB45	2017-07-14 21:34:00+03	57400.00
6EFB88	2017-08-02 06:57:00+03	223200.00
6EFB8D	2017-07-27 04:24:00+03	348100.00
6EFBBA	2017-07-21 12:43:00+03	13400.00
6EFC3E	2017-08-14 15:42:00+03	25200.00
6EFC7A	2017-07-31 17:09:00+03	398500.00
6EFC81	2017-07-20 13:34:00+03	28000.00
6EFC9A	2017-08-09 21:22:00+03	23200.00
6EFCC8	2017-07-26 10:30:00+03	70700.00
6EFCE3	2017-08-03 21:56:00+03	55500.00
6EFD73	2017-07-23 18:44:00+03	12100.00
6EFDED	2017-07-18 05:51:00+03	6000.00
6EFE12	2017-07-21 13:41:00+03	44000.00
6EFE26	2017-07-16 10:52:00+03	38800.00
6EFE6C	2017-07-16 06:50:00+03	37900.00
6EFEBD	2017-07-03 19:17:00+03	56000.00
6EFF9E	2017-07-01 06:25:00+03	13800.00
6F0062	2017-07-28 10:36:00+03	12100.00
6F00EC	2017-07-22 06:09:00+03	9800.00
6F01E4	2017-08-08 17:03:00+03	236500.00
6F01EA	2017-08-01 00:37:00+03	53200.00
6F01F0	2017-08-11 11:30:00+03	88600.00
6F01F4	2017-08-05 14:05:00+03	54400.00
6F02D4	2017-07-24 19:34:00+03	20200.00
6F036F	2017-07-27 12:18:00+03	28000.00
6F0376	2017-07-01 16:58:00+03	66600.00
6F03A1	2017-07-14 11:44:00+03	67400.00
6F03AF	2017-07-19 07:41:00+03	109200.00
6F0405	2017-07-06 14:14:00+03	42700.00
6F040D	2017-07-24 17:26:00+03	65000.00
6F0499	2017-08-12 17:55:00+03	162600.00
6F049E	2017-08-10 01:57:00+03	149600.00
6F04A3	2017-07-15 01:05:00+03	47000.00
6F04BB	2017-07-13 10:33:00+03	66200.00
6F04DC	2017-07-13 04:55:00+03	23600.00
6F04DF	2017-07-07 18:19:00+03	111600.00
6F0507	2017-08-15 00:40:00+03	24400.00
6F0513	2017-07-20 04:01:00+03	26000.00
6F0515	2017-08-04 07:24:00+03	169900.00
6F0541	2017-07-25 08:51:00+03	203300.00
6F0545	2017-08-03 17:02:00+03	26000.00
6F0577	2017-07-01 23:11:00+03	66600.00
6F05A7	2017-07-25 03:36:00+03	12600.00
6F05B1	2017-08-09 09:23:00+03	101200.00
6F05C7	2017-07-22 07:05:00+03	248400.00
6F05E8	2017-07-16 17:09:00+03	51600.00
6F0665	2017-07-18 18:45:00+03	73500.00
6F0698	2017-08-04 06:45:00+03	18000.00
6F06A3	2017-08-12 17:46:00+03	27200.00
6F06E3	2017-07-11 19:36:00+03	46200.00
6F06FA	2017-08-05 23:57:00+03	133100.00
6F0706	2017-07-06 22:15:00+03	55800.00
6F0740	2017-08-06 08:34:00+03	98200.00
6F07A2	2017-08-01 16:02:00+03	25800.00
6F07D4	2017-08-02 11:32:00+03	78300.00
6F07F3	2017-08-04 05:56:00+03	34100.00
6F0821	2017-08-01 13:59:00+03	20200.00
6F0824	2017-07-17 06:11:00+03	68000.00
6F087C	2017-07-18 20:47:00+03	22000.00
6F0892	2017-08-01 06:04:00+03	291000.00
6F092E	2017-07-01 13:02:00+03	70700.00
6F0960	2017-07-11 09:56:00+03	159800.00
6F0973	2017-07-24 06:17:00+03	40400.00
6F0981	2017-07-21 03:08:00+03	56600.00
6F09DA	2017-08-09 19:33:00+03	75300.00
6F09FD	2017-08-03 11:20:00+03	29400.00
6F0A55	2017-07-07 03:13:00+03	22000.00
6F0A59	2017-07-21 07:08:00+03	27200.00
6F0B4C	2017-07-09 13:04:00+03	71400.00
6F0B6B	2017-07-16 11:12:00+03	56000.00
6F0B7D	2017-07-21 05:45:00+03	135000.00
6F0B83	2017-07-09 23:10:00+03	6800.00
6F0BA0	2017-07-01 11:18:00+03	103800.00
6F0BB8	2017-06-30 09:26:00+03	173900.00
6F0BD5	2017-08-04 03:10:00+03	135400.00
6F0C40	2017-07-21 03:12:00+03	20200.00
6F0C4A	2017-08-14 07:08:00+03	71600.00
6F0C84	2017-07-09 03:03:00+03	23200.00
6F0CE3	2017-07-03 14:35:00+03	62600.00
6F0D74	2017-08-14 22:58:00+03	73000.00
6F0D90	2017-08-03 12:36:00+03	52100.00
6F0DA1	2017-07-11 20:01:00+03	46000.00
6F0DC4	2017-07-24 04:00:00+03	22600.00
6F0E2A	2017-08-08 12:28:00+03	13200.00
6F0E55	2017-08-08 22:15:00+03	47100.00
6F0E6A	2017-07-07 13:12:00+03	55800.00
6F0F25	2017-07-26 17:42:00+03	101200.00
6F0F2A	2017-07-24 12:45:00+03	29800.00
6F0F5F	2017-07-07 16:50:00+03	19000.00
6F0FE0	2017-07-20 22:18:00+03	42400.00
6F1009	2017-08-15 04:50:00+03	19600.00
6F1019	2017-07-03 19:05:00+03	106900.00
6F104D	2017-07-28 10:05:00+03	8400.00
6F1058	2017-06-30 14:12:00+03	15000.00
6F105B	2017-07-05 12:59:00+03	56000.00
6F10B2	2017-08-12 14:20:00+03	117600.00
6F1148	2017-07-24 08:41:00+03	147000.00
6F117A	2017-07-15 02:27:00+03	16400.00
6F1192	2017-07-21 10:34:00+03	21800.00
6F119A	2017-07-19 13:12:00+03	111600.00
6F1210	2017-07-07 10:35:00+03	57600.00
6F1258	2017-07-07 12:53:00+03	52100.00
6F1259	2017-07-20 15:07:00+03	68400.00
6F12B0	2017-07-09 00:08:00+03	46400.00
6F1323	2017-08-03 21:54:00+03	112000.00
6F132E	2017-08-11 20:12:00+03	13400.00
6F137D	2017-07-25 18:34:00+03	58000.00
6F13A8	2017-07-08 12:37:00+03	148800.00
6F1408	2017-08-01 15:14:00+03	16800.00
6F1438	2017-07-07 14:46:00+03	54500.00
6F145E	2017-07-18 20:05:00+03	64300.00
6F148D	2017-07-30 13:09:00+03	28000.00
6F1491	2017-07-03 09:05:00+03	73400.00
6F151B	2017-08-06 10:13:00+03	66200.00
6F153C	2017-06-26 12:28:00+03	199700.00
6F15F8	2017-07-07 02:13:00+03	141100.00
6F161B	2017-07-24 12:46:00+03	202600.00
6F1623	2017-08-04 11:22:00+03	34000.00
6F1686	2017-08-08 21:44:00+03	257500.00
6F16B5	2017-08-04 21:48:00+03	81700.00
6F16BB	2017-08-12 06:21:00+03	27900.00
6F16CD	2017-07-07 18:09:00+03	16400.00
6F16E8	2017-08-15 01:03:00+03	31400.00
6F16FE	2017-07-03 23:51:00+03	65500.00
6F173F	2017-07-08 06:06:00+03	25900.00
6F187D	2017-07-08 21:11:00+03	36100.00
6F1891	2017-07-09 13:20:00+03	45600.00
6F18B0	2017-08-12 21:47:00+03	152200.00
6F18BC	2017-07-10 19:48:00+03	46800.00
6F18C1	2017-08-09 10:29:00+03	14000.00
6F1911	2017-08-05 01:52:00+03	125400.00
6F1960	2017-07-03 12:24:00+03	147000.00
6F1995	2017-08-14 17:41:00+03	13400.00
6F19FA	2017-07-04 09:26:00+03	208000.00
6F1A09	2017-07-17 04:23:00+03	101200.00
6F1A23	2017-07-02 14:36:00+03	38800.00
6F1A5A	2017-07-17 22:05:00+03	23500.00
6F1AA2	2017-07-31 11:55:00+03	57500.00
6F1AC9	2017-08-09 19:46:00+03	30200.00
6F1AD2	2017-07-01 07:20:00+03	283100.00
6F1AD3	2017-07-27 16:44:00+03	77000.00
6F1AFA	2017-07-08 03:04:00+03	89600.00
6F1C06	2017-08-07 00:22:00+03	155600.00
6F1C1C	2017-07-09 06:55:00+03	84100.00
6F1C2E	2017-08-13 18:55:00+03	26700.00
6F1C6F	2017-07-04 01:13:00+03	50800.00
6F1C74	2017-07-14 13:06:00+03	17000.00
6F1C97	2017-08-09 02:24:00+03	134600.00
6F1CEE	2017-08-01 16:00:00+03	82900.00
6F1CF7	2017-07-25 14:32:00+03	31200.00
6F1D16	2017-07-06 20:16:00+03	64700.00
6F1D5A	2017-07-24 22:27:00+03	93900.00
6F1D77	2017-08-05 14:43:00+03	8200.00
6F1E15	2017-08-02 11:00:00+03	29400.00
6F1F06	2017-07-23 06:57:00+03	189100.00
6F1F23	2017-07-12 15:01:00+03	61900.00
6F1F6F	2017-07-04 21:13:00+03	64800.00
6F1F8D	2017-07-22 15:05:00+03	52800.00
6F1FF7	2017-07-28 12:47:00+03	114500.00
6F20B5	2017-07-30 07:01:00+03	55800.00
6F20D0	2017-07-06 21:13:00+03	14400.00
6F219A	2017-07-06 05:35:00+03	41400.00
6F21A2	2017-07-30 05:26:00+03	135600.00
6F21E7	2017-07-24 14:31:00+03	81600.00
6F222B	2017-08-03 20:31:00+03	105800.00
6F2246	2017-07-25 21:04:00+03	130400.00
6F2275	2017-07-29 23:02:00+03	294200.00
6F227C	2017-08-15 03:09:00+03	134200.00
6F229F	2017-07-09 15:17:00+03	92600.00
6F22A2	2017-07-30 14:11:00+03	47000.00
6F2301	2017-07-17 17:40:00+03	129700.00
6F230D	2017-08-07 13:43:00+03	105000.00
6F231D	2017-07-21 21:54:00+03	83000.00
6F232F	2017-08-02 12:13:00+03	89900.00
6F23CB	2017-07-20 18:53:00+03	42800.00
6F23CE	2017-07-31 12:16:00+03	40000.00
6F23DB	2017-07-09 01:38:00+03	35800.00
6F2403	2017-08-03 22:57:00+03	52800.00
6F2446	2017-07-27 13:31:00+03	28600.00
6F244D	2017-07-05 20:35:00+03	242100.00
6F2483	2017-07-15 07:03:00+03	67800.00
6F248E	2017-07-05 09:02:00+03	22000.00
6F24ED	2017-08-11 21:55:00+03	57600.00
6F2556	2017-08-09 17:10:00+03	49700.00
6F258D	2017-08-14 21:32:00+03	70000.00
6F25D8	2017-07-16 02:30:00+03	119300.00
6F2609	2017-08-09 06:30:00+03	27400.00
6F2630	2017-07-16 00:19:00+03	67500.00
6F265F	2017-07-14 01:47:00+03	283100.00
6F2827	2017-08-05 18:29:00+03	135600.00
6F2842	2017-07-08 13:46:00+03	31000.00
6F28E8	2017-07-04 23:45:00+03	28800.00
6F2944	2017-07-18 03:31:00+03	62600.00
6F2A08	2017-07-07 05:29:00+03	31400.00
6F2A27	2017-07-06 14:38:00+03	116400.00
6F2ABF	2017-07-03 12:59:00+03	6700.00
6F2AE9	2017-07-09 10:53:00+03	28000.00
6F2B20	2017-07-07 03:22:00+03	67200.00
6F2BE6	2017-07-08 19:44:00+03	167400.00
6F2C35	2017-07-28 15:33:00+03	40900.00
6F2CE1	2017-07-12 17:16:00+03	52000.00
6F2D10	2017-08-02 04:09:00+03	62800.00
6F2D28	2017-08-07 22:26:00+03	123000.00
6F2D6A	2017-07-09 14:59:00+03	67800.00
6F2D8C	2017-07-11 10:37:00+03	36200.00
6F2DA4	2017-07-31 22:36:00+03	46300.00
6F2DC6	2017-07-29 18:31:00+03	43600.00
6F2DDE	2017-07-19 17:22:00+03	46700.00
6F2E21	2017-07-15 15:28:00+03	66600.00
6F2E4E	2017-08-08 15:04:00+03	166000.00
6F2E82	2017-07-07 08:43:00+03	138400.00
6F2EFF	2017-07-29 15:04:00+03	70600.00
6F2F17	2017-07-05 17:52:00+03	21800.00
6F2FB3	2017-08-11 21:31:00+03	57800.00
6F3008	2017-07-31 19:36:00+03	92000.00
6F307E	2017-07-17 07:36:00+03	28000.00
6F30ED	2017-07-14 03:50:00+03	25200.00
6F30F8	2017-08-11 07:59:00+03	48800.00
6F3221	2017-07-29 15:56:00+03	24400.00
6F3248	2017-08-12 01:45:00+03	23500.00
6F3277	2017-07-22 19:27:00+03	78600.00
6F327C	2017-07-18 17:31:00+03	234800.00
6F32AB	2017-07-17 10:00:00+03	155300.00
6F32B6	2017-08-13 22:30:00+03	29600.00
6F3348	2017-08-03 15:28:00+03	140000.00
6F334A	2017-08-03 08:27:00+03	91700.00
6F336B	2017-08-09 14:56:00+03	55800.00
6F337E	2017-08-07 17:54:00+03	26200.00
6F33C3	2017-07-13 22:14:00+03	127800.00
6F344F	2017-07-02 01:52:00+03	46400.00
6F34B5	2017-07-24 07:29:00+03	76800.00
6F34BF	2017-07-14 11:10:00+03	82900.00
6F34EF	2017-07-23 23:11:00+03	95600.00
6F350D	2017-07-17 12:13:00+03	19600.00
6F3681	2017-08-14 03:06:00+03	124300.00
6F369C	2017-08-13 15:02:00+03	38400.00
6F36DC	2017-07-05 19:34:00+03	43900.00
6F3703	2017-07-27 05:56:00+03	55800.00
6F3755	2017-07-15 13:42:00+03	49400.00
6F3803	2017-07-09 12:10:00+03	59800.00
6F381A	2017-07-05 09:01:00+03	137600.00
6F383F	2017-07-06 05:35:00+03	133100.00
6F384B	2017-08-07 13:47:00+03	28000.00
6F3853	2017-08-15 00:30:00+03	25800.00
6F3880	2017-08-12 20:37:00+03	152700.00
6F3897	2017-08-02 22:03:00+03	36200.00
6F38BB	2017-07-24 04:53:00+03	122000.00
6F38C4	2017-07-09 22:00:00+03	131800.00
6F38CD	2017-08-04 19:42:00+03	67200.00
6F3916	2017-08-08 22:32:00+03	123000.00
6F3928	2017-07-17 00:56:00+03	273200.00
6F3954	2017-08-13 13:48:00+03	27200.00
6F3966	2017-06-30 07:23:00+03	12600.00
6F396C	2017-07-21 01:24:00+03	123000.00
6F39A2	2017-08-14 07:56:00+03	65400.00
6F39C2	2017-07-10 20:03:00+03	40000.00
6F39DD	2017-07-16 02:23:00+03	185800.00
6F3A06	2017-07-19 07:07:00+03	94300.00
6F3A0F	2017-07-25 00:19:00+03	11800.00
6F3A55	2017-07-19 16:03:00+03	67200.00
6F3A82	2017-08-09 13:50:00+03	68200.00
6F3AC3	2017-08-02 08:16:00+03	70600.00
6F3AD1	2017-08-14 22:45:00+03	410800.00
6F3B60	2017-08-11 18:05:00+03	55400.00
6F3B6B	2017-07-15 07:02:00+03	31600.00
6F3B93	2017-07-16 19:10:00+03	69500.00
6F3BFC	2017-07-20 16:34:00+03	123000.00
6F3C09	2017-07-26 10:15:00+03	24400.00
6F3C0F	2017-07-06 23:09:00+03	83000.00
6F3C3E	2017-07-30 08:51:00+03	185000.00
6F3C75	2017-07-16 16:33:00+03	41000.00
6F3D44	2017-07-20 16:01:00+03	78300.00
6F3D4F	2017-08-13 20:22:00+03	43000.00
6F3D7B	2017-07-10 12:40:00+03	43200.00
6F3DCD	2017-07-22 04:50:00+03	25000.00
6F3DE3	2017-07-19 18:34:00+03	28800.00
6F3E18	2017-07-07 00:54:00+03	200300.00
6F3EA8	2017-07-17 16:14:00+03	189200.00
6F3EEB	2017-07-03 14:25:00+03	6700.00
6F3EF8	2017-07-13 04:42:00+03	123000.00
6F3F6E	2017-07-14 05:38:00+03	117700.00
6F3F81	2017-08-03 23:13:00+03	140000.00
6F3F9F	2017-07-12 16:22:00+03	11600.00
6F3FCA	2017-08-06 18:55:00+03	80900.00
6F4003	2017-07-29 21:36:00+03	226200.00
6F400E	2017-07-23 00:21:00+03	6000.00
6F404D	2017-07-13 10:12:00+03	28000.00
6F4050	2017-08-10 10:19:00+03	6800.00
6F409D	2017-08-10 11:10:00+03	30200.00
6F414F	2017-07-23 04:44:00+03	28000.00
6F41D0	2017-07-20 15:10:00+03	83200.00
6F41D5	2017-07-07 21:02:00+03	46500.00
6F4245	2017-08-07 18:14:00+03	92800.00
6F42A8	2017-07-15 20:29:00+03	157900.00
6F42EE	2017-07-31 04:48:00+03	93500.00
6F4309	2017-08-11 20:30:00+03	27300.00
6F4425	2017-08-13 07:23:00+03	136800.00
6F4433	2017-07-24 22:56:00+03	100600.00
6F443D	2017-07-14 15:13:00+03	27800.00
6F4497	2017-07-18 17:51:00+03	13700.00
6F44FF	2017-07-23 08:22:00+03	57500.00
6F4510	2017-07-08 12:51:00+03	68000.00
6F452A	2017-07-22 03:07:00+03	135400.00
6F4531	2017-07-27 12:34:00+03	53300.00
6F45DC	2017-07-11 03:35:00+03	28400.00
6F462F	2017-07-08 08:58:00+03	146700.00
6F4635	2017-08-14 21:49:00+03	24700.00
6F471C	2017-08-03 20:06:00+03	27200.00
6F475A	2017-07-04 19:16:00+03	26800.00
6F475C	2017-08-07 03:21:00+03	6000.00
6F477F	2017-07-24 23:16:00+03	55800.00
6F478E	2017-08-13 14:30:00+03	67500.00
6F4798	2017-08-11 18:12:00+03	328600.00
6F47A7	2017-07-02 21:40:00+03	33100.00
6F47D5	2017-08-01 00:04:00+03	29600.00
6F47E9	2017-07-25 01:31:00+03	95600.00
6F4851	2017-07-17 05:39:00+03	128900.00
6F4854	2017-07-22 06:33:00+03	15700.00
6F4865	2017-08-11 12:51:00+03	69100.00
6F4884	2017-08-02 02:17:00+03	13600.00
6F4886	2017-08-11 15:23:00+03	97200.00
6F48AE	2017-08-02 07:59:00+03	115800.00
6F490B	2017-06-30 22:51:00+03	75300.00
6F4968	2017-07-23 21:17:00+03	191200.00
6F49AC	2017-07-14 18:09:00+03	167400.00
6F49B3	2017-08-02 05:37:00+03	60400.00
6F49EB	2017-08-09 03:15:00+03	40800.00
6F4A71	2017-06-29 07:25:00+03	27200.00
6F4A90	2017-07-11 03:57:00+03	56000.00
6F4ABA	2017-07-12 23:55:00+03	40000.00
6F4ABE	2017-08-03 07:18:00+03	136800.00
6F4ADD	2017-07-28 20:30:00+03	46000.00
6F4AF0	2017-07-03 06:09:00+03	103700.00
6F4B42	2017-08-07 02:00:00+03	20400.00
6F4B50	2017-08-05 06:38:00+03	138400.00
6F4B93	2017-07-31 23:26:00+03	31400.00
6F4BDC	2017-08-09 17:15:00+03	6000.00
6F4BEE	2017-08-03 02:01:00+03	313200.00
6F4C64	2017-08-08 10:41:00+03	45100.00
6F4C8A	2017-07-13 14:56:00+03	51200.00
6F4CA6	2017-06-27 23:21:00+03	212900.00
6F4D1F	2017-07-24 21:22:00+03	15000.00
6F4D79	2017-07-31 17:51:00+03	44000.00
6F4D88	2017-08-12 21:05:00+03	44000.00
6F4D9A	2017-06-30 18:20:00+03	96300.00
6F4DD1	2017-07-21 19:40:00+03	229900.00
6F4DD2	2017-07-11 10:12:00+03	19600.00
6F4DE6	2017-07-05 15:01:00+03	77900.00
6F4E6D	2017-07-20 01:27:00+03	123000.00
6F4E9C	2017-07-26 08:41:00+03	88100.00
6F4F4A	2017-07-09 20:22:00+03	35200.00
6F4F8C	2017-07-20 11:08:00+03	240600.00
6F4F92	2017-07-30 16:28:00+03	28700.00
6F4FB2	2017-07-28 12:50:00+03	21400.00
6F4FD5	2017-07-13 20:01:00+03	19600.00
6F5027	2017-08-14 04:57:00+03	59100.00
6F5034	2017-07-15 00:21:00+03	40900.00
6F504B	2017-08-09 06:29:00+03	13000.00
6F506D	2017-07-12 02:18:00+03	298000.00
6F508A	2017-08-11 07:10:00+03	56000.00
6F50A8	2017-07-29 19:02:00+03	92900.00
6F50A9	2017-08-13 08:34:00+03	130900.00
6F50D4	2017-07-15 02:13:00+03	28000.00
6F50E1	2017-08-09 16:10:00+03	103800.00
6F5119	2017-07-22 20:30:00+03	46800.00
6F514B	2017-07-18 07:45:00+03	61800.00
6F5184	2017-08-14 08:13:00+03	46400.00
6F51A9	2017-07-16 02:08:00+03	47400.00
6F51AC	2017-06-29 14:25:00+03	48800.00
6F531E	2017-08-12 20:03:00+03	65400.00
6F5347	2017-08-09 01:48:00+03	17600.00
6F537C	2017-07-29 06:45:00+03	27300.00
6F538B	2017-07-04 09:57:00+03	57400.00
6F53A1	2017-08-15 17:57:00+03	112200.00
6F53E1	2017-08-11 07:50:00+03	81600.00
6F53F0	2017-07-05 11:52:00+03	112000.00
6F5401	2017-07-29 12:44:00+03	58100.00
6F544E	2017-07-02 14:24:00+03	28800.00
6F5471	2017-07-24 17:46:00+03	135600.00
6F549F	2017-07-11 11:00:00+03	58800.00
6F54B2	2017-07-09 00:22:00+03	130800.00
6F54D9	2017-07-29 13:25:00+03	18000.00
6F551E	2017-08-12 20:20:00+03	10700.00
6F5559	2017-07-28 19:09:00+03	56000.00
6F559E	2017-08-01 04:32:00+03	54800.00
6F55C9	2017-07-02 13:52:00+03	12600.00
6F55F1	2017-08-11 14:12:00+03	23200.00
6F5610	2017-07-20 09:15:00+03	95200.00
6F562B	2017-07-24 23:45:00+03	146400.00
6F5638	2017-08-01 04:42:00+03	13400.00
6F5655	2017-08-05 21:41:00+03	131600.00
6F5657	2017-08-06 12:07:00+03	70600.00
6F56E7	2017-07-23 16:40:00+03	51500.00
6F57AD	2017-08-07 02:40:00+03	6700.00
6F57F5	2017-07-18 22:08:00+03	25000.00
6F57FB	2017-07-29 05:09:00+03	55400.00
6F5806	2017-07-16 23:34:00+03	57300.00
6F58BB	2017-07-29 03:50:00+03	65400.00
6F591B	2017-07-27 09:20:00+03	57600.00
6F596D	2017-07-12 06:02:00+03	44600.00
6F597A	2017-07-23 23:57:00+03	272300.00
6F5980	2017-07-19 07:25:00+03	25100.00
6F59AF	2017-08-12 02:14:00+03	115600.00
6F59E8	2017-08-12 10:34:00+03	8600.00
6F5A15	2017-07-24 13:14:00+03	23400.00
6F5A20	2017-07-09 16:18:00+03	66600.00
6F5A24	2017-07-28 15:01:00+03	124000.00
6F5A75	2017-07-20 00:37:00+03	114800.00
6F5A99	2017-07-17 14:47:00+03	6300.00
6F5B65	2017-08-14 05:36:00+03	270700.00
6F5BFA	2017-07-08 05:10:00+03	26000.00
6F5C07	2017-07-25 20:52:00+03	68800.00
6F5C36	2017-07-22 15:28:00+03	24400.00
6F5C65	2017-08-14 03:15:00+03	32400.00
6F5CA2	2017-07-07 09:12:00+03	27300.00
6F5CBA	2017-07-12 17:51:00+03	43500.00
6F5CC1	2017-08-08 11:13:00+03	46400.00
6F5CCE	2017-07-28 20:46:00+03	49800.00
6F5D01	2017-08-04 23:02:00+03	270200.00
6F5D13	2017-07-21 01:09:00+03	39800.00
6F5DC7	2017-07-20 01:36:00+03	33200.00
6F5DD2	2017-08-10 00:25:00+03	67200.00
6F5DE6	2017-07-12 08:36:00+03	36200.00
6F5E1C	2017-07-24 04:19:00+03	50000.00
6F5E1F	2017-07-06 16:59:00+03	29600.00
6F5E2D	2017-07-13 06:21:00+03	36000.00
6F5EDF	2017-07-24 08:11:00+03	306200.00
6F5EF1	2017-07-16 15:12:00+03	14400.00
6F5F76	2017-07-08 22:43:00+03	14000.00
6F5FA1	2017-07-27 23:54:00+03	93500.00
6F5FB5	2017-08-09 02:10:00+03	248500.00
6F6093	2017-07-27 12:44:00+03	31600.00
6F6116	2017-08-03 11:49:00+03	156300.00
6F61B0	2017-07-09 22:12:00+03	168000.00
6F621A	2017-08-05 04:39:00+03	59800.00
6F62A0	2017-07-17 13:39:00+03	160800.00
6F62AA	2017-07-26 11:58:00+03	36200.00
6F62B9	2017-07-13 11:42:00+03	23400.00
6F62F0	2017-07-08 15:22:00+03	19600.00
6F6333	2017-08-01 00:30:00+03	24800.00
6F6346	2017-08-11 13:01:00+03	57600.00
6F6354	2017-07-15 16:01:00+03	50800.00
6F63A6	2017-08-14 04:09:00+03	197300.00
6F6405	2017-07-10 00:04:00+03	22000.00
6F641F	2017-07-18 15:54:00+03	44100.00
6F6427	2017-07-26 01:46:00+03	47100.00
6F642C	2017-07-11 20:13:00+03	28800.00
6F6465	2017-07-04 23:53:00+03	348800.00
6F64EC	2017-08-04 04:15:00+03	265700.00
6F655B	2017-08-14 16:42:00+03	23200.00
6F6563	2017-08-02 22:58:00+03	111600.00
6F6623	2017-07-03 17:21:00+03	80000.00
6F6630	2017-07-17 20:54:00+03	64800.00
6F6645	2017-06-29 20:30:00+03	46000.00
6F6668	2017-06-30 10:53:00+03	306600.00
6F6694	2017-07-29 16:30:00+03	6000.00
6F66A5	2017-07-07 07:13:00+03	40800.00
6F66FC	2017-08-12 23:48:00+03	35600.00
6F6756	2017-07-19 13:41:00+03	32800.00
6F6765	2017-07-07 08:13:00+03	348800.00
6F676E	2017-07-26 23:10:00+03	81500.00
6F678D	2017-06-30 16:37:00+03	168000.00
6F6793	2017-07-27 19:45:00+03	52300.00
6F67A0	2017-07-20 19:16:00+03	29100.00
6F67BE	2017-07-11 00:26:00+03	8000.00
6F6808	2017-08-10 04:30:00+03	6800.00
6F683D	2017-07-29 04:53:00+03	46400.00
6F68B9	2017-07-16 23:34:00+03	20200.00
6F690B	2017-07-06 12:18:00+03	29600.00
6F6912	2017-07-28 17:29:00+03	32700.00
6F694E	2017-06-30 17:52:00+03	61900.00
6F6950	2017-08-12 08:56:00+03	67000.00
6F698E	2017-08-03 07:56:00+03	30900.00
6F6992	2017-07-14 14:33:00+03	123600.00
6F69FF	2017-08-05 10:16:00+03	112000.00
6F6A3B	2017-06-26 21:53:00+03	40600.00
6F6A71	2017-07-07 12:39:00+03	34000.00
6F6A7F	2017-07-31 15:12:00+03	117100.00
6F6A9F	2017-06-27 03:08:00+03	20200.00
6F6AB1	2017-07-16 22:24:00+03	58200.00
6F6AB2	2017-08-03 13:56:00+03	24400.00
6F6ABD	2017-07-08 18:57:00+03	55800.00
6F6AC2	2017-06-29 21:46:00+03	97900.00
6F6AD6	2017-07-17 00:20:00+03	38800.00
6F6BB7	2017-07-23 15:51:00+03	66600.00
6F6BDA	2017-07-12 01:00:00+03	38800.00
6F6BFE	2017-07-07 03:14:00+03	150600.00
6F6C6F	2017-07-24 16:50:00+03	29600.00
6F6CC0	2017-07-22 17:08:00+03	64700.00
6F6D24	2017-08-11 07:35:00+03	75600.00
6F6D2A	2017-08-06 03:32:00+03	52700.00
6F6D69	2017-07-22 03:10:00+03	533200.00
6F6D72	2017-07-23 02:23:00+03	130200.00
6F6DEE	2017-08-06 21:01:00+03	21400.00
6F6E1B	2017-08-06 09:06:00+03	81300.00
6F6E5B	2017-07-04 18:29:00+03	76300.00
6F6EB3	2017-07-14 07:29:00+03	124200.00
6F6EC8	2017-07-29 13:41:00+03	25800.00
6F6EE2	2017-07-27 22:08:00+03	28000.00
6F6F6F	2017-07-30 10:34:00+03	144000.00
6F6F85	2017-07-13 23:59:00+03	11600.00
6F6F8F	2017-08-02 03:47:00+03	726800.00
6F707A	2017-08-14 10:17:00+03	25200.00
6F70B3	2017-07-02 02:34:00+03	71400.00
6F70BF	2017-07-09 11:30:00+03	85000.00
6F70F2	2017-07-13 02:14:00+03	46000.00
6F7134	2017-08-14 15:57:00+03	272300.00
6F7140	2017-08-05 09:57:00+03	37700.00
6F7178	2017-07-09 13:28:00+03	56000.00
6F71FD	2017-07-13 18:05:00+03	46000.00
6F72A2	2017-07-17 08:19:00+03	28000.00
6F72C2	2017-08-08 22:27:00+03	73100.00
6F72C4	2017-06-30 07:21:00+03	145200.00
6F7300	2017-08-10 23:28:00+03	26000.00
6F7352	2017-08-01 17:39:00+03	169300.00
6F736C	2017-07-28 14:43:00+03	184500.00
6F73C9	2017-07-25 20:15:00+03	66600.00
6F741A	2017-08-08 09:35:00+03	32800.00
6F741F	2017-07-24 22:42:00+03	68400.00
6F7428	2017-07-07 20:23:00+03	129400.00
6F744A	2017-07-09 10:21:00+03	19800.00
6F752F	2017-07-01 12:36:00+03	101200.00
6F7556	2017-07-11 20:59:00+03	110000.00
6F75A4	2017-08-12 19:05:00+03	442100.00
6F75C5	2017-08-06 13:44:00+03	36800.00
6F75E4	2017-08-09 11:46:00+03	32800.00
6F760E	2017-07-25 16:52:00+03	46400.00
6F7624	2017-07-07 15:19:00+03	92000.00
6F7663	2017-07-29 09:43:00+03	26000.00
6F76ED	2017-07-25 10:23:00+03	39100.00
6F76F3	2017-08-06 04:26:00+03	70600.00
6F7726	2017-07-11 20:38:00+03	29600.00
6F773B	2017-07-29 17:53:00+03	15000.00
6F778B	2017-08-04 16:35:00+03	220200.00
6F77DC	2017-08-02 06:04:00+03	7400.00
6F77FE	2017-07-22 12:03:00+03	246000.00
6F788B	2017-07-13 13:34:00+03	72800.00
6F78DA	2017-07-02 17:18:00+03	123000.00
6F78EA	2017-06-30 02:19:00+03	37200.00
6F78FB	2017-07-23 10:09:00+03	94500.00
6F791B	2017-08-14 23:53:00+03	73500.00
6F7944	2017-08-09 18:08:00+03	409100.00
6F796A	2017-07-31 00:10:00+03	8000.00
6F798E	2017-07-12 03:12:00+03	14000.00
6F7A8C	2017-07-08 23:44:00+03	6300.00
6F7AA3	2017-07-19 14:57:00+03	48800.00
6F7AC1	2017-07-13 10:00:00+03	153200.00
6F7B1A	2017-07-08 05:11:00+03	26400.00
6F7B70	2017-07-13 22:09:00+03	14000.00
6F7BC1	2017-07-17 21:09:00+03	114800.00
6F7BCC	2017-08-04 17:54:00+03	24300.00
6F7BDF	2017-07-25 03:40:00+03	48800.00
6F7BFF	2017-08-08 12:13:00+03	166000.00
6F7C17	2017-08-09 03:07:00+03	54200.00
6F7C3B	2017-07-25 23:27:00+03	10700.00
6F7CB8	2017-07-21 11:05:00+03	37100.00
6F7CFA	2017-08-01 06:02:00+03	27600.00
6F7D45	2017-08-15 00:48:00+03	117200.00
6F7D56	2017-07-05 01:12:00+03	178800.00
6F7DAD	2017-08-15 07:39:00+03	59300.00
6F7E08	2017-07-18 07:35:00+03	24200.00
6F7E30	2017-07-04 11:38:00+03	36200.00
6F7E35	2017-07-07 07:25:00+03	111600.00
6F7EDE	2017-07-20 12:41:00+03	46000.00
6F7EEA	2017-08-11 07:11:00+03	91600.00
6F7F01	2017-07-21 21:47:00+03	137600.00
6F7F03	2017-07-01 07:00:00+03	81700.00
6F7F16	2017-08-14 21:01:00+03	92100.00
6F7F4F	2017-08-03 12:51:00+03	68400.00
6F7F58	2017-08-14 01:44:00+03	26700.00
6F7F93	2017-08-13 17:59:00+03	82700.00
6F7F97	2017-07-19 11:43:00+03	141300.00
6F800E	2017-07-30 07:44:00+03	261500.00
6F80F0	2017-07-05 23:11:00+03	166100.00
6F81F7	2017-07-27 07:23:00+03	88800.00
6F8207	2017-07-29 01:15:00+03	33600.00
6F82B1	2017-07-15 13:26:00+03	56200.00
6F843A	2017-07-05 11:09:00+03	14800.00
6F8458	2017-08-11 13:28:00+03	168000.00
6F84A7	2017-07-16 04:18:00+03	248300.00
6F84F0	2017-08-02 08:17:00+03	6300.00
6F85A0	2017-07-02 10:43:00+03	70800.00
6F85D6	2017-08-13 13:50:00+03	14000.00
6F85FE	2017-07-31 14:38:00+03	44800.00
6F8654	2017-07-29 20:23:00+03	198400.00
6F8655	2017-07-08 17:56:00+03	26000.00
6F869A	2017-08-12 22:42:00+03	95600.00
6F86EB	2017-07-13 23:57:00+03	41500.00
6F8761	2017-08-04 06:06:00+03	211200.00
6F8786	2017-07-08 18:47:00+03	78300.00
6F87E8	2017-08-11 00:29:00+03	29600.00
6F8819	2017-07-27 04:51:00+03	28000.00
6F8876	2017-08-05 08:43:00+03	51100.00
6F88AD	2017-07-25 05:20:00+03	65500.00
6F88BB	2017-07-07 09:14:00+03	16400.00
6F8903	2017-07-10 17:35:00+03	96400.00
6F8924	2017-07-20 13:29:00+03	112000.00
6F8927	2017-07-06 18:37:00+03	41200.00
6F8963	2017-07-15 00:00:00+03	29500.00
6F8979	2017-07-20 12:11:00+03	123600.00
6F897F	2017-07-11 13:32:00+03	170700.00
6F8A9B	2017-07-25 06:07:00+03	61800.00
6F8B10	2017-08-11 01:34:00+03	68700.00
6F8B24	2017-08-08 20:35:00+03	77000.00
6F8B3C	2017-07-26 14:18:00+03	171900.00
6F8BA4	2017-07-26 01:03:00+03	199700.00
6F8C07	2017-08-07 16:36:00+03	265700.00
6F8C5F	2017-07-01 02:14:00+03	55800.00
6F8C98	2017-07-14 20:37:00+03	243600.00
6F8CBC	2017-07-27 16:42:00+03	147000.00
6F8CD3	2017-07-12 07:45:00+03	26800.00
6F8CD9	2017-07-25 08:44:00+03	36200.00
6F8D03	2017-08-06 09:51:00+03	135000.00
6F8D57	2017-07-25 21:31:00+03	40100.00
6F8D9D	2017-07-09 00:46:00+03	136200.00
6F8DC6	2017-07-27 17:49:00+03	18000.00
6F8E0D	2017-08-02 06:44:00+03	50300.00
6F8E64	2017-07-06 21:50:00+03	304100.00
6F8EB1	2017-07-06 04:37:00+03	22400.00
6F8EDC	2017-08-12 09:30:00+03	92400.00
6F8EE5	2017-07-21 12:27:00+03	65900.00
6F8EE7	2017-08-14 18:32:00+03	46400.00
6F8EEF	2017-08-15 11:25:00+03	67600.00
6F8F38	2017-07-14 18:56:00+03	31900.00
6F8F4C	2017-07-26 17:26:00+03	112000.00
6F8F53	2017-08-02 23:26:00+03	14000.00
6F8FD4	2017-07-21 20:48:00+03	11800.00
6F9031	2017-07-06 18:42:00+03	61500.00
6F90A3	2017-07-01 15:34:00+03	27000.00
6F90B7	2017-07-14 14:57:00+03	70500.00
6F90C9	2017-07-03 11:43:00+03	27200.00
6F90FC	2017-08-03 20:55:00+03	14000.00
6F910E	2017-07-27 16:59:00+03	31900.00
6F911E	2017-08-04 20:39:00+03	32200.00
6F919D	2017-08-06 20:04:00+03	98200.00
6F919E	2017-08-09 15:22:00+03	61800.00
6F91EC	2017-07-11 21:50:00+03	13400.00
6F91F5	2017-07-23 01:02:00+03	48800.00
6F9208	2017-07-05 23:03:00+03	265700.00
6F923C	2017-07-09 05:01:00+03	106300.00
6F925D	2017-08-10 17:46:00+03	90000.00
6F9386	2017-06-29 12:16:00+03	14000.00
6F943B	2017-08-04 11:28:00+03	393800.00
6F946C	2017-07-30 20:59:00+03	83600.00
6F949F	2017-08-08 02:11:00+03	66400.00
6F94ED	2017-08-14 17:50:00+03	14000.00
6F951F	2017-08-03 01:20:00+03	260300.00
6F9525	2017-08-08 03:15:00+03	38600.00
6F9552	2017-07-21 21:22:00+03	44800.00
6F9575	2017-08-14 08:19:00+03	96300.00
6F962F	2017-07-11 00:04:00+03	44000.00
6F9666	2017-07-29 09:28:00+03	6300.00
6F967C	2017-07-06 07:18:00+03	37600.00
6F96D6	2017-07-03 01:57:00+03	169600.00
6F96FE	2017-08-14 15:54:00+03	73400.00
6F9720	2017-07-29 09:06:00+03	137600.00
6F9731	2017-07-16 19:10:00+03	27200.00
6F9748	2017-07-03 23:15:00+03	16400.00
6F97F8	2017-08-13 06:36:00+03	26000.00
6F9820	2017-07-04 07:55:00+03	29400.00
6F982A	2017-07-09 12:29:00+03	58900.00
6F9858	2017-08-13 13:36:00+03	64700.00
6F98DD	2017-07-02 06:30:00+03	28000.00
6F98FA	2017-08-11 00:11:00+03	270400.00
6F993D	2017-07-02 09:15:00+03	94200.00
6F99C5	2017-07-15 10:03:00+03	11600.00
6F9A0A	2017-08-04 05:16:00+03	56000.00
6F9A1D	2017-08-04 22:06:00+03	29800.00
6F9A5C	2017-08-03 03:25:00+03	254900.00
6F9A7D	2017-07-14 03:42:00+03	28000.00
6F9A8E	2017-07-06 19:58:00+03	48500.00
6F9AE9	2017-08-08 06:06:00+03	128800.00
6F9B19	2017-08-01 23:07:00+03	16800.00
6F9B5C	2017-08-08 12:24:00+03	24400.00
6F9B72	2017-07-24 12:15:00+03	46400.00
6F9B9C	2017-07-20 13:26:00+03	22000.00
6F9BE9	2017-06-29 18:32:00+03	29400.00
6F9BFB	2017-07-31 22:43:00+03	25800.00
6F9BFC	2017-07-14 08:07:00+03	87900.00
6F9C99	2017-07-01 18:12:00+03	228700.00
6F9D0A	2017-07-29 19:29:00+03	48800.00
6F9D31	2017-07-17 01:26:00+03	249100.00
6F9D44	2017-07-16 00:36:00+03	23600.00
6F9D8F	2017-08-09 00:11:00+03	94800.00
6F9DE9	2017-07-01 09:49:00+03	141600.00
6F9E74	2017-07-15 18:51:00+03	51200.00
6F9EA9	2017-07-07 02:05:00+03	55800.00
6F9EAF	2017-07-14 11:13:00+03	424800.00
6F9EB9	2017-07-04 20:14:00+03	31600.00
6F9F62	2017-06-26 23:48:00+03	56000.00
6F9F8F	2017-07-09 16:27:00+03	29600.00
6F9FE7	2017-07-25 00:32:00+03	12000.00
6FA0E6	2017-08-07 18:14:00+03	38600.00
6FA0E8	2017-08-11 10:06:00+03	297600.00
6FA267	2017-07-23 07:36:00+03	99800.00
6FA2A5	2017-08-03 10:40:00+03	61200.00
6FA2C5	2017-08-04 08:33:00+03	75600.00
6FA2DB	2017-07-12 15:16:00+03	535600.00
6FA309	2017-07-15 20:15:00+03	23600.00
6FA30B	2017-07-31 12:17:00+03	123000.00
6FA3D5	2017-07-29 21:29:00+03	38600.00
6FA3DB	2017-08-15 04:44:00+03	123800.00
6FA4A7	2017-07-10 12:22:00+03	27200.00
6FA52F	2017-07-06 05:16:00+03	14400.00
6FA564	2017-08-11 02:44:00+03	43200.00
6FA582	2017-07-07 15:29:00+03	56000.00
6FA603	2017-08-08 11:03:00+03	52600.00
6FA69B	2017-07-02 17:51:00+03	55800.00
6FA6FA	2017-07-27 18:37:00+03	47100.00
6FA6FB	2017-08-13 23:41:00+03	22600.00
6FA70A	2017-07-29 08:14:00+03	25600.00
6FA770	2017-07-02 00:21:00+03	35300.00
6FA77E	2017-07-09 21:40:00+03	57500.00
6FA7B6	2017-07-09 16:58:00+03	40000.00
6FA801	2017-07-14 05:13:00+03	70100.00
6FA812	2017-07-28 10:41:00+03	17600.00
6FA8F6	2017-07-31 02:05:00+03	223200.00
6FA952	2017-08-10 23:44:00+03	34000.00
6FAAA6	2017-07-29 14:19:00+03	11600.00
6FABD4	2017-08-03 04:51:00+03	25400.00
6FABFE	2017-08-13 10:19:00+03	58600.00
6FACA8	2017-08-07 11:05:00+03	57500.00
6FACD2	2017-07-14 23:14:00+03	110600.00
6FAD22	2017-07-21 23:56:00+03	61600.00
6FADCA	2017-07-07 23:07:00+03	60700.00
6FADE9	2017-07-13 14:38:00+03	23200.00
6FAE03	2017-08-12 17:04:00+03	67700.00
6FAE15	2017-08-10 13:22:00+03	32800.00
6FAE65	2017-08-03 02:55:00+03	187800.00
6FAEB8	2017-08-09 19:30:00+03	68800.00
6FAEC9	2017-07-01 23:42:00+03	325500.00
6FAEDB	2017-07-25 12:08:00+03	21000.00
6FAF57	2017-07-10 06:00:00+03	88600.00
6FAF77	2017-08-15 08:56:00+03	110500.00
6FAFD3	2017-07-11 21:56:00+03	114800.00
6FAFFD	2017-07-27 16:52:00+03	68900.00
6FB17C	2017-08-08 12:00:00+03	51200.00
6FB18B	2017-07-13 13:48:00+03	25600.00
6FB206	2017-08-14 03:29:00+03	108500.00
6FB215	2017-08-03 02:34:00+03	46000.00
6FB21C	2017-07-21 09:14:00+03	6300.00
6FB25A	2017-08-02 22:41:00+03	35700.00
6FB27D	2017-07-11 21:44:00+03	48800.00
6FB283	2017-07-21 14:44:00+03	7400.00
6FB2B8	2017-07-29 08:59:00+03	175800.00
6FB2CC	2017-08-09 04:56:00+03	28800.00
6FB34A	2017-07-24 18:48:00+03	18600.00
6FB35B	2017-08-02 23:06:00+03	37900.00
6FB36A	2017-07-14 13:34:00+03	14400.00
6FB3E8	2017-08-15 14:32:00+03	11600.00
6FB40A	2017-08-05 17:32:00+03	51900.00
6FB427	2017-06-24 16:29:00+03	55800.00
6FB53E	2017-07-21 04:00:00+03	60400.00
6FB57A	2017-08-13 02:40:00+03	81300.00
6FB62F	2017-07-07 09:50:00+03	135600.00
6FB686	2017-07-21 11:06:00+03	25600.00
6FB6AB	2017-07-15 11:28:00+03	15400.00
6FB6E2	2017-07-11 18:20:00+03	40800.00
6FB75B	2017-07-16 14:46:00+03	133200.00
6FB78C	2017-07-03 22:07:00+03	21800.00
6FB7AB	2017-08-15 13:48:00+03	36200.00
6FB84E	2017-08-14 03:14:00+03	87200.00
6FB8AA	2017-07-23 23:19:00+03	18600.00
6FB90B	2017-08-13 17:45:00+03	39400.00
6FB938	2017-07-08 07:04:00+03	29600.00
6FB945	2017-07-18 16:44:00+03	139300.00
6FBA64	2017-08-12 03:19:00+03	12600.00
6FBB3A	2017-08-15 16:56:00+03	55600.00
6FBBF5	2017-07-12 01:21:00+03	21800.00
6FBCD5	2017-07-19 09:30:00+03	66600.00
6FBD61	2017-07-06 09:34:00+03	8200.00
6FBDD9	2017-07-30 18:50:00+03	69500.00
6FBDDE	2017-07-10 19:41:00+03	22900.00
6FBE15	2017-08-10 07:44:00+03	39300.00
6FBE1B	2017-07-03 12:31:00+03	13700.00
6FBE81	2017-07-25 10:04:00+03	103600.00
6FBEAE	2017-08-04 10:57:00+03	78300.00
6FBECA	2017-07-12 06:11:00+03	198900.00
6FBECB	2017-08-08 02:31:00+03	62900.00
6FBFA7	2017-06-28 18:00:00+03	378400.00
6FBFAA	2017-07-27 22:42:00+03	398500.00
6FBFC0	2017-07-31 06:13:00+03	28800.00
6FC064	2017-07-31 20:30:00+03	112000.00
6FC101	2017-07-12 20:14:00+03	19600.00
6FC13E	2017-07-31 08:18:00+03	91600.00
6FC1B2	2017-07-19 10:52:00+03	51300.00
6FC1B8	2017-08-02 10:02:00+03	115900.00
6FC1DC	2017-08-04 19:36:00+03	50000.00
6FC213	2017-08-01 08:05:00+03	7400.00
6FC2A5	2017-08-11 11:09:00+03	50400.00
6FC2D9	2017-08-09 10:45:00+03	29600.00
6FC2DD	2017-07-28 02:47:00+03	67400.00
6FC32E	2017-08-07 05:05:00+03	129200.00
6FC367	2017-07-24 23:10:00+03	27900.00
6FC390	2017-07-31 04:34:00+03	12400.00
6FC3AE	2017-07-25 23:16:00+03	31400.00
6FC41B	2017-07-08 03:21:00+03	206400.00
6FC4B7	2017-07-18 07:25:00+03	129900.00
6FC52D	2017-07-12 15:38:00+03	12600.00
6FC651	2017-08-13 04:16:00+03	194000.00
6FC782	2017-07-25 09:54:00+03	70700.00
6FC7A8	2017-07-26 14:03:00+03	14400.00
6FC7F1	2017-07-25 20:08:00+03	119500.00
6FC7FA	2017-08-14 08:17:00+03	58400.00
6FC814	2017-07-20 19:22:00+03	39400.00
6FC82F	2017-08-15 08:40:00+03	81200.00
6FC8A9	2017-08-07 23:26:00+03	188800.00
6FC8D3	2017-07-05 10:39:00+03	129400.00
6FC8F8	2017-07-20 02:03:00+03	43200.00
6FC92A	2017-07-28 22:10:00+03	28000.00
6FC956	2017-08-12 16:17:00+03	19900.00
6FC968	2017-08-14 13:01:00+03	34100.00
6FC996	2017-07-01 13:47:00+03	116000.00
6FC9C4	2017-07-14 22:30:00+03	36200.00
6FCA09	2017-07-21 06:02:00+03	52300.00
6FCA13	2017-08-11 10:42:00+03	276200.00
6FCA3D	2017-07-07 11:21:00+03	118900.00
6FCA77	2017-07-31 10:27:00+03	147700.00
6FCAF3	2017-07-20 02:42:00+03	66600.00
6FCB03	2017-07-25 13:23:00+03	99200.00
6FCB15	2017-07-21 10:13:00+03	70400.00
6FCB2F	2017-07-28 00:25:00+03	179400.00
6FCB3A	2017-07-21 05:30:00+03	103500.00
6FCB48	2017-08-02 21:16:00+03	16400.00
6FCB5A	2017-07-24 05:55:00+03	28800.00
6FCB92	2017-07-13 19:25:00+03	12600.00
6FCBE0	2017-07-16 00:25:00+03	136200.00
6FCCB1	2017-08-10 03:54:00+03	46000.00
6FCCF4	2017-07-19 19:56:00+03	36200.00
6FCD21	2017-08-11 13:27:00+03	90600.00
6FCD72	2017-07-03 21:23:00+03	10800.00
6FCDE7	2017-08-12 21:33:00+03	73400.00
6FCE01	2017-07-26 13:22:00+03	66600.00
6FCE3F	2017-08-05 14:37:00+03	39300.00
6FCE91	2017-07-31 18:52:00+03	148800.00
6FCE93	2017-08-12 05:07:00+03	40100.00
6FCEEC	2017-08-11 10:47:00+03	23200.00
6FCEF8	2017-07-18 12:52:00+03	48800.00
6FCF07	2017-07-08 05:14:00+03	26000.00
6FCF49	2017-07-25 09:28:00+03	47600.00
6FCFA5	2017-07-23 01:52:00+03	55800.00
6FCFA6	2017-07-30 16:53:00+03	58900.00
6FD018	2017-07-05 11:43:00+03	233800.00
6FD09A	2017-07-23 10:38:00+03	48500.00
6FD0AD	2017-06-25 10:34:00+03	23400.00
6FD0E0	2017-07-30 18:46:00+03	57400.00
6FD14D	2017-08-07 07:00:00+03	46700.00
6FD187	2017-08-11 05:19:00+03	123000.00
6FD1F2	2017-07-14 19:49:00+03	57600.00
6FD247	2017-08-11 18:29:00+03	248400.00
6FD25F	2017-08-06 09:50:00+03	26000.00
6FD265	2017-08-05 16:46:00+03	56000.00
6FD2BC	2017-07-17 08:55:00+03	93900.00
6FD30D	2017-07-03 05:51:00+03	47000.00
6FD47F	2017-07-22 13:13:00+03	20200.00
6FD4F6	2017-07-08 02:49:00+03	43600.00
6FD51B	2017-07-07 02:50:00+03	65900.00
6FD54E	2017-07-18 03:09:00+03	26800.00
6FD563	2017-07-16 18:48:00+03	36200.00
6FD58F	2017-07-02 12:14:00+03	31600.00
6FD606	2017-08-09 03:14:00+03	40800.00
6FD607	2017-07-02 09:42:00+03	27900.00
6FD672	2017-08-04 01:53:00+03	18800.00
6FD687	2017-07-07 20:34:00+03	66600.00
6FD6BF	2017-08-10 09:27:00+03	67600.00
6FD6EE	2017-08-08 04:42:00+03	62100.00
6FD744	2017-07-13 19:25:00+03	58800.00
6FD754	2017-07-14 22:35:00+03	112000.00
6FD758	2017-08-05 08:40:00+03	36800.00
6FD75D	2017-08-11 17:31:00+03	50600.00
6FD771	2017-07-13 16:43:00+03	58600.00
6FD781	2017-08-09 19:41:00+03	112600.00
6FD7C6	2017-07-03 01:20:00+03	105000.00
6FD7D8	2017-07-29 16:20:00+03	80000.00
6FD7E8	2017-07-20 19:42:00+03	47200.00
6FD817	2017-07-24 22:33:00+03	148200.00
6FD83D	2017-07-23 17:33:00+03	47100.00
6FD980	2017-07-04 16:35:00+03	6000.00
6FD990	2017-08-03 03:12:00+03	37700.00
6FD99C	2017-07-25 23:13:00+03	32800.00
6FD9DA	2017-07-04 02:43:00+03	36200.00
6FDAAE	2017-08-15 17:05:00+03	56000.00
6FDAD0	2017-07-02 18:40:00+03	79600.00
6FDAD4	2017-07-17 18:45:00+03	139800.00
6FDAF1	2017-07-31 03:13:00+03	121200.00
6FDB1F	2017-07-11 18:25:00+03	87100.00
6FDC22	2017-08-13 02:47:00+03	271700.00
6FDC3D	2017-06-29 09:41:00+03	56000.00
6FDC4F	2017-08-13 13:05:00+03	99300.00
6FDC75	2017-08-07 13:10:00+03	126300.00
6FDC85	2017-08-04 14:06:00+03	136000.00
6FDCF2	2017-07-21 18:59:00+03	51600.00
6FDD04	2017-07-05 23:00:00+03	55600.00
6FDD79	2017-07-10 12:36:00+03	36800.00
6FDD85	2017-08-06 06:40:00+03	103600.00
6FDDAE	2017-06-29 18:37:00+03	25000.00
6FDDF2	2017-07-14 07:54:00+03	65300.00
6FDF23	2017-06-30 03:13:00+03	56900.00
6FDF4C	2017-07-24 14:34:00+03	35300.00
6FDFCB	2017-07-08 12:52:00+03	36200.00
6FDFCF	2017-08-09 20:33:00+03	26500.00
6FE00F	2017-07-27 19:28:00+03	60600.00
6FE0C1	2017-08-05 03:05:00+03	180100.00
6FE0C9	2017-08-14 03:02:00+03	10800.00
6FE0D9	2017-07-28 06:22:00+03	44000.00
6FE0EB	2017-07-12 17:47:00+03	83200.00
6FE0FA	2017-07-27 20:04:00+03	55800.00
6FE146	2017-07-30 23:29:00+03	94000.00
6FE177	2017-07-20 14:06:00+03	29600.00
6FE18E	2017-08-14 09:47:00+03	252000.00
6FE1BE	2017-07-23 08:43:00+03	206200.00
6FE33B	2017-08-09 10:48:00+03	188000.00
6FE36F	2017-07-15 23:06:00+03	23400.00
6FE374	2017-08-12 13:53:00+03	3700.00
6FE37F	2017-07-03 13:25:00+03	78300.00
6FE3A2	2017-07-25 22:37:00+03	123600.00
6FE3A3	2017-07-08 13:22:00+03	27800.00
6FE419	2017-07-31 10:46:00+03	31600.00
6FE425	2017-08-07 09:00:00+03	6900.00
6FE442	2017-08-14 16:03:00+03	148400.00
6FE46B	2017-08-07 20:23:00+03	97900.00
6FE4CB	2017-06-28 01:22:00+03	84500.00
6FE572	2017-07-23 22:03:00+03	132800.00
6FE580	2017-08-13 01:09:00+03	36800.00
6FE5CE	2017-07-15 08:27:00+03	70600.00
6FE669	2017-08-02 03:33:00+03	67200.00
6FE674	2017-07-13 08:27:00+03	127500.00
6FE6EB	2017-08-12 05:15:00+03	131100.00
6FE72F	2017-07-07 07:29:00+03	31000.00
6FE74B	2017-07-04 12:33:00+03	44800.00
6FE78C	2017-07-24 06:22:00+03	23200.00
6FE79C	2017-08-05 11:20:00+03	53000.00
6FE7A1	2017-07-31 11:31:00+03	131100.00
6FE7D7	2017-08-13 22:16:00+03	28000.00
6FE7DF	2017-07-07 16:27:00+03	55900.00
6FE88F	2017-07-26 05:46:00+03	23600.00
6FE965	2017-07-30 18:29:00+03	28800.00
6FE9A3	2017-07-11 18:16:00+03	23400.00
6FE9BD	2017-08-08 03:29:00+03	246000.00
6FEA06	2017-07-21 19:56:00+03	185600.00
6FEA1C	2017-07-04 11:38:00+03	40100.00
6FEA32	2017-07-05 14:39:00+03	87100.00
6FEA9F	2017-07-13 22:17:00+03	6000.00
6FEAD4	2017-07-11 13:36:00+03	23200.00
6FEAE4	2017-07-25 06:49:00+03	21800.00
6FEBAD	2017-08-14 08:07:00+03	53200.00
6FEBBF	2017-07-18 03:48:00+03	24200.00
6FECD6	2017-07-01 03:07:00+03	55800.00
6FECE6	2017-07-17 14:10:00+03	12000.00
6FED46	2017-07-11 23:20:00+03	56000.00
6FED6C	2017-08-06 19:26:00+03	284700.00
6FEDC3	2017-08-10 01:58:00+03	16000.00
6FEDCC	2017-07-10 18:47:00+03	21400.00
6FEDF1	2017-06-30 07:04:00+03	48800.00
6FEE21	2017-08-12 06:07:00+03	93500.00
6FEE74	2017-07-20 01:07:00+03	47700.00
6FEEF1	2017-07-13 13:21:00+03	74400.00
6FEEF3	2017-08-10 19:54:00+03	243700.00
6FEF1E	2017-08-13 00:15:00+03	47100.00
6FEF5F	2017-07-06 05:48:00+03	32200.00
6FEF75	2017-08-06 22:34:00+03	16400.00
6FEF83	2017-07-24 18:30:00+03	112000.00
6FEFB5	2017-07-15 10:54:00+03	81600.00
6FEFE3	2017-07-23 11:26:00+03	50400.00
6FF077	2017-08-03 14:28:00+03	48300.00
6FF0B3	2017-07-24 21:36:00+03	43200.00
6FF100	2017-07-15 15:56:00+03	282300.00
6FF108	2017-07-17 09:08:00+03	24400.00
6FF10E	2017-08-02 00:58:00+03	29800.00
6FF121	2017-07-25 10:39:00+03	67600.00
6FF153	2017-08-01 23:09:00+03	67200.00
6FF19C	2017-07-20 14:17:00+03	28000.00
6FF266	2017-07-02 19:17:00+03	27800.00
6FF2D9	2017-07-13 22:06:00+03	37500.00
6FF327	2017-08-05 03:11:00+03	97800.00
6FF3AB	2017-07-07 20:30:00+03	139200.00
6FF405	2017-07-11 04:40:00+03	13800.00
6FF40A	2017-07-20 04:11:00+03	58200.00
6FF474	2017-08-13 04:26:00+03	16400.00
6FF489	2017-07-05 10:33:00+03	63200.00
6FF4E4	2017-07-07 21:40:00+03	31600.00
6FF5CA	2017-08-03 08:24:00+03	26700.00
6FF684	2017-08-01 16:26:00+03	160100.00
6FF6D6	2017-08-01 13:35:00+03	106100.00
6FF6DD	2017-08-07 15:03:00+03	59000.00
6FF6F9	2017-08-15 01:38:00+03	33600.00
6FF6FD	2017-07-28 04:15:00+03	112000.00
6FF719	2017-07-28 02:25:00+03	131600.00
6FF772	2017-08-01 18:51:00+03	52300.00
6FF78F	2017-07-26 22:25:00+03	31400.00
6FF7C1	2017-08-09 22:33:00+03	76600.00
6FF893	2017-08-15 01:24:00+03	125100.00
6FF8DD	2017-07-24 12:38:00+03	48800.00
6FF94E	2017-08-01 18:04:00+03	28000.00
6FF9C0	2017-07-13 19:35:00+03	136600.00
6FFA29	2017-07-05 14:55:00+03	40800.00
6FFA69	2017-07-24 09:39:00+03	246000.00
6FFAF3	2017-08-11 14:47:00+03	86300.00
6FFB0B	2017-07-04 03:15:00+03	33800.00
6FFB6A	2017-07-18 09:26:00+03	93700.00
6FFB96	2017-08-04 07:32:00+03	75600.00
6FFBCD	2017-07-13 23:07:00+03	31600.00
6FFC05	2017-08-09 06:12:00+03	36100.00
6FFC38	2017-07-17 16:11:00+03	335400.00
6FFC89	2017-08-13 17:19:00+03	50000.00
6FFC9A	2017-07-12 08:06:00+03	21400.00
6FFCB3	2017-08-06 23:54:00+03	239300.00
6FFD2C	2017-07-22 07:48:00+03	135200.00
6FFD74	2017-07-17 10:02:00+03	21200.00
6FFD7E	2017-07-16 09:35:00+03	57500.00
6FFD82	2017-07-04 16:11:00+03	27800.00
6FFDD2	2017-08-08 22:00:00+03	111600.00
6FFDE8	2017-07-02 17:27:00+03	67200.00
6FFE3C	2017-08-09 22:35:00+03	21400.00
6FFE97	2017-06-28 22:25:00+03	92000.00
6FFEB6	2017-08-12 18:43:00+03	28800.00
6FFEF2	2017-08-12 21:43:00+03	139400.00
6FFEFD	2017-07-17 15:36:00+03	36200.00
6FFF49	2017-08-10 14:47:00+03	128800.00
6FFFC4	2017-08-01 06:46:00+03	248300.00
700037	2017-08-12 15:52:00+03	29600.00
700047	2017-07-17 15:43:00+03	278100.00
7000A1	2017-07-30 11:20:00+03	7200.00
7000B8	2017-08-06 15:26:00+03	16400.00
7000D9	2017-07-10 07:56:00+03	162600.00
7000F5	2017-07-01 03:35:00+03	83600.00
700153	2017-08-09 04:40:00+03	116700.00
70015F	2017-08-01 15:15:00+03	53600.00
70020A	2017-08-11 20:02:00+03	201200.00
70021B	2017-07-01 05:36:00+03	187600.00
700298	2017-08-15 15:15:00+03	139300.00
700352	2017-08-15 08:24:00+03	54500.00
700389	2017-07-03 11:26:00+03	547700.00
7003C0	2017-07-23 21:52:00+03	87300.00
7004CF	2017-07-02 11:18:00+03	167500.00
7004F0	2017-07-11 16:29:00+03	21400.00
70053B	2017-07-19 14:51:00+03	155600.00
7005EE	2017-07-08 20:55:00+03	354400.00
7005F0	2017-08-10 21:42:00+03	31600.00
7006A9	2017-07-08 05:05:00+03	12400.00
7006DE	2017-07-10 18:34:00+03	246000.00
70072E	2017-07-01 23:46:00+03	148800.00
700743	2017-07-19 15:55:00+03	7300.00
700755	2017-07-03 10:08:00+03	38400.00
700756	2017-07-18 20:53:00+03	46400.00
7007A7	2017-07-26 08:28:00+03	26000.00
7007FB	2017-07-12 09:27:00+03	46300.00
7008FC	2017-07-09 16:37:00+03	81900.00
700923	2017-07-24 19:30:00+03	18400.00
70092B	2017-08-13 08:16:00+03	198500.00
700952	2017-08-09 13:06:00+03	73400.00
700973	2017-07-16 23:43:00+03	493300.00
700997	2017-07-18 03:00:00+03	52400.00
7009AC	2017-07-26 15:01:00+03	73600.00
7009B0	2017-07-29 14:00:00+03	117900.00
7009C1	2017-07-12 15:21:00+03	78300.00
700A7F	2017-08-13 05:30:00+03	45200.00
700AB6	2017-08-09 05:53:00+03	88500.00
700B29	2017-07-14 18:46:00+03	137600.00
700C46	2017-07-30 22:54:00+03	70700.00
700C7A	2017-07-20 02:38:00+03	26800.00
700CB3	2017-08-01 04:22:00+03	29400.00
700CD7	2017-07-12 16:29:00+03	10100.00
700CD9	2017-08-09 08:45:00+03	521500.00
700D31	2017-08-09 05:15:00+03	27600.00
700D84	2017-08-04 01:19:00+03	66600.00
700DE5	2017-07-13 06:34:00+03	13400.00
700DE8	2017-07-18 02:53:00+03	79200.00
700E23	2017-07-22 07:26:00+03	28000.00
700E30	2017-07-16 18:46:00+03	40200.00
700E78	2017-06-30 04:44:00+03	47700.00
700E8A	2017-08-08 04:36:00+03	142400.00
700EA4	2017-08-07 23:08:00+03	67100.00
700EEF	2017-07-13 11:50:00+03	99300.00
700F0E	2017-07-04 14:33:00+03	7200.00
700F25	2017-07-30 22:18:00+03	23600.00
700F26	2017-07-14 09:06:00+03	93000.00
700F81	2017-07-04 03:12:00+03	46400.00
700FA6	2017-07-02 19:53:00+03	117600.00
700FA9	2017-08-10 16:35:00+03	53700.00
700FD9	2017-07-12 19:43:00+03	94800.00
701022	2017-07-20 14:46:00+03	26000.00
70102E	2017-07-05 20:16:00+03	57600.00
701053	2017-08-07 13:36:00+03	28000.00
701077	2017-08-11 22:02:00+03	17600.00
7010AA	2017-07-12 05:27:00+03	56600.00
7010E4	2017-06-30 23:23:00+03	11000.00
70115D	2017-07-20 21:34:00+03	11800.00
701185	2017-07-26 22:16:00+03	38800.00
701196	2017-08-02 14:07:00+03	257500.00
701283	2017-07-22 23:53:00+03	26200.00
7012DB	2017-07-04 21:23:00+03	399600.00
70133A	2017-08-14 14:54:00+03	67800.00
701441	2017-07-20 04:50:00+03	266400.00
70144F	2017-07-16 10:59:00+03	48500.00
70149A	2017-07-19 23:33:00+03	28000.00
7014B2	2017-07-26 04:16:00+03	51900.00
701520	2017-08-07 21:10:00+03	88600.00
701634	2017-08-14 14:45:00+03	50300.00
70163B	2017-07-13 06:01:00+03	90000.00
701654	2017-07-11 18:04:00+03	97900.00
7016F0	2017-08-03 01:03:00+03	97700.00
70171D	2017-08-11 08:41:00+03	32900.00
701741	2017-08-06 20:16:00+03	40700.00
701756	2017-07-07 23:53:00+03	28000.00
70175B	2017-07-01 00:44:00+03	21800.00
7017B0	2017-07-18 21:15:00+03	196800.00
701825	2017-08-04 05:09:00+03	59800.00
701849	2017-07-06 15:52:00+03	6800.00
701873	2017-07-14 20:38:00+03	76100.00
7018B9	2017-07-16 02:41:00+03	22000.00
7018E9	2017-07-24 12:37:00+03	50800.00
701956	2017-07-30 18:51:00+03	155600.00
70196F	2017-08-14 04:31:00+03	120900.00
7019C9	2017-07-22 07:33:00+03	36200.00
7019D6	2017-08-09 13:25:00+03	55800.00
701A04	2017-07-13 02:52:00+03	53700.00
701A5E	2017-08-05 00:55:00+03	40800.00
701A78	2017-07-08 10:35:00+03	73600.00
701ACD	2017-06-28 06:38:00+03	56000.00
701BB1	2017-08-05 12:01:00+03	105600.00
701BC9	2017-07-17 17:28:00+03	32800.00
701C12	2017-08-14 13:07:00+03	91800.00
701C40	2017-08-01 18:59:00+03	63400.00
701C61	2017-08-11 19:01:00+03	46500.00
701CB7	2017-07-26 00:30:00+03	31700.00
701D18	2017-08-04 15:15:00+03	45500.00
701D44	2017-08-14 18:51:00+03	28800.00
701DD3	2017-07-30 11:29:00+03	54000.00
701DDC	2017-07-27 04:42:00+03	55800.00
701DE1	2017-08-07 11:21:00+03	46400.00
701DF4	2017-08-09 06:15:00+03	78200.00
701E0B	2017-07-28 23:06:00+03	101200.00
701E5D	2017-08-07 22:22:00+03	12600.00
701E7A	2017-08-11 06:38:00+03	24400.00
701EF5	2017-07-27 04:59:00+03	66600.00
701F3A	2017-07-25 17:34:00+03	12600.00
701F9D	2017-08-01 03:40:00+03	60400.00
701FA3	2017-08-10 20:11:00+03	31200.00
701FB5	2017-08-11 09:32:00+03	58800.00
701FC4	2017-07-08 02:30:00+03	24400.00
701FCC	2017-08-02 08:50:00+03	57800.00
702005	2017-07-15 03:34:00+03	32700.00
70204C	2017-08-15 12:06:00+03	26000.00
70205F	2017-08-10 02:03:00+03	49600.00
70209B	2017-07-20 17:57:00+03	27000.00
7020D0	2017-07-06 12:40:00+03	42800.00
7020F0	2017-08-04 20:20:00+03	193900.00
702146	2017-08-04 00:09:00+03	535500.00
7021DF	2017-08-13 05:01:00+03	84100.00
702266	2017-07-16 03:31:00+03	65900.00
702286	2017-08-12 22:30:00+03	86200.00
702290	2017-08-10 08:51:00+03	40800.00
7022E4	2017-07-06 11:32:00+03	136100.00
702397	2017-07-06 19:34:00+03	95200.00
702399	2017-07-16 10:00:00+03	185500.00
70239A	2017-07-13 03:48:00+03	54400.00
7023D5	2017-07-22 23:49:00+03	46300.00
7023EA	2017-07-24 23:47:00+03	65900.00
702435	2017-07-21 01:38:00+03	40000.00
702449	2017-08-05 02:06:00+03	44700.00
702467	2017-06-30 12:28:00+03	46300.00
7024DB	2017-08-10 17:43:00+03	36900.00
7024E8	2017-08-12 01:11:00+03	295400.00
70250E	2017-07-17 01:59:00+03	56600.00
702514	2017-08-13 13:09:00+03	112600.00
702557	2017-07-24 10:54:00+03	58600.00
7025A2	2017-07-09 01:25:00+03	46400.00
7025BC	2017-07-29 17:05:00+03	11000.00
7025CD	2017-08-04 17:29:00+03	36800.00
70263E	2017-08-14 07:17:00+03	48500.00
702689	2017-08-01 12:25:00+03	26700.00
702745	2017-08-11 17:46:00+03	27200.00
70275C	2017-07-10 12:44:00+03	265700.00
702785	2017-07-13 11:22:00+03	63300.00
7027D2	2017-07-17 17:58:00+03	170700.00
7027E1	2017-07-11 22:52:00+03	48800.00
7027F9	2017-07-23 09:14:00+03	11800.00
70280C	2017-08-05 10:09:00+03	30400.00
70283D	2017-07-03 19:07:00+03	52000.00
70289E	2017-08-01 04:34:00+03	136800.00
7028AD	2017-07-04 00:52:00+03	26600.00
7028E0	2017-08-14 02:04:00+03	36200.00
70296E	2017-07-04 13:43:00+03	35600.00
70299A	2017-07-20 15:00:00+03	95600.00
702A02	2017-07-22 02:24:00+03	12600.00
702A0D	2017-07-16 00:34:00+03	491600.00
702A52	2017-07-08 10:11:00+03	23600.00
702AAA	2017-07-05 09:16:00+03	14000.00
702B04	2017-07-21 01:50:00+03	136800.00
702B25	2017-07-18 05:49:00+03	95200.00
702B79	2017-07-10 13:55:00+03	12000.00
702B92	2017-07-28 01:56:00+03	64700.00
702C03	2017-07-23 10:53:00+03	98400.00
702C0E	2017-07-05 11:49:00+03	123000.00
702C10	2017-07-13 10:08:00+03	26000.00
702C38	2017-08-07 20:43:00+03	8400.00
702C60	2017-06-29 20:05:00+03	14000.00
702C6C	2017-07-03 12:34:00+03	31000.00
702CB7	2017-07-22 06:50:00+03	168000.00
702D20	2017-08-15 16:44:00+03	38400.00
702D33	2017-08-13 11:39:00+03	38600.00
702DF7	2017-07-10 17:38:00+03	56000.00
702E8B	2017-08-11 14:08:00+03	113800.00
702F41	2017-08-14 01:16:00+03	25400.00
70307C	2017-07-26 22:47:00+03	135600.00
7030C1	2017-08-07 18:36:00+03	85700.00
703100	2017-08-03 10:01:00+03	21400.00
703106	2017-07-11 22:29:00+03	28000.00
703126	2017-07-03 15:15:00+03	8200.00
703152	2017-07-24 22:20:00+03	40200.00
7031BE	2017-07-30 02:15:00+03	28000.00
7031F1	2017-07-13 10:50:00+03	111600.00
703241	2017-07-21 22:48:00+03	86000.00
703295	2017-08-10 11:22:00+03	420500.00
7032B2	2017-08-09 02:42:00+03	13200.00
7032F7	2017-07-31 09:21:00+03	266200.00
7032F8	2017-07-22 16:36:00+03	73200.00
703448	2017-08-09 17:25:00+03	105200.00
70344F	2017-07-12 10:52:00+03	244200.00
703476	2017-07-18 10:52:00+03	81600.00
7034AC	2017-07-15 01:54:00+03	18000.00
7034BA	2017-08-14 08:43:00+03	54800.00
7034F4	2017-07-08 22:07:00+03	65000.00
70351D	2017-07-06 22:56:00+03	62600.00
70354A	2017-07-30 00:51:00+03	52800.00
7035A0	2017-08-05 15:16:00+03	46400.00
7035AD	2017-07-26 19:59:00+03	32400.00
7035FF	2017-07-15 03:58:00+03	6700.00
703615	2017-08-11 20:39:00+03	28000.00
703665	2017-07-29 19:36:00+03	56000.00
7036B7	2017-08-08 00:58:00+03	131600.00
703744	2017-07-13 14:21:00+03	59300.00
703746	2017-07-31 22:57:00+03	62300.00
7037CE	2017-07-13 13:43:00+03	15000.00
7037F1	2017-08-09 19:18:00+03	17600.00
703884	2017-08-06 21:15:00+03	60700.00
7038B4	2017-07-13 09:27:00+03	28800.00
7038B5	2017-07-24 02:41:00+03	65400.00
70393A	2017-07-14 02:46:00+03	125200.00
70399F	2017-07-07 11:37:00+03	56100.00
7039A6	2017-07-20 21:20:00+03	112000.00
703A01	2017-08-10 16:13:00+03	12600.00
703A33	2017-08-14 02:33:00+03	123000.00
703A67	2017-07-09 09:15:00+03	105100.00
703ACF	2017-08-04 23:29:00+03	99200.00
703B0A	2017-06-29 21:37:00+03	80300.00
703B30	2017-06-30 05:31:00+03	62600.00
703CC8	2017-07-01 14:13:00+03	55800.00
703D4B	2017-08-12 23:30:00+03	131600.00
703D56	2017-07-25 15:22:00+03	24400.00
703DBB	2017-08-15 08:56:00+03	21800.00
703DC0	2017-08-08 11:19:00+03	46400.00
703DE3	2017-07-04 23:50:00+03	77600.00
703F19	2017-07-11 21:44:00+03	57700.00
703F6D	2017-07-25 09:08:00+03	55900.00
703F78	2017-07-04 06:16:00+03	120800.00
703F8E	2017-07-01 16:49:00+03	13300.00
703F9D	2017-08-03 17:59:00+03	46400.00
703FDA	2017-07-14 21:24:00+03	272300.00
703FDD	2017-07-17 23:47:00+03	149600.00
704024	2017-07-29 21:08:00+03	15800.00
70403B	2017-08-15 01:22:00+03	12600.00
70408A	2017-06-29 17:57:00+03	86600.00
7040A8	2017-06-27 01:01:00+03	10600.00
704118	2017-08-09 04:09:00+03	28300.00
70414B	2017-08-07 22:05:00+03	31600.00
704171	2017-07-11 03:05:00+03	15000.00
704193	2017-07-29 11:49:00+03	39800.00
7041CB	2017-08-06 22:28:00+03	32900.00
7041EA	2017-08-12 21:58:00+03	137000.00
7041F6	2017-07-04 23:12:00+03	47500.00
70421B	2017-07-12 16:11:00+03	38400.00
704260	2017-07-15 00:10:00+03	56000.00
70427A	2017-07-10 14:10:00+03	46200.00
7042F7	2017-08-10 16:58:00+03	103800.00
7042F9	2017-08-05 16:56:00+03	43200.00
7043CA	2017-07-17 04:56:00+03	92100.00
7043DE	2017-08-04 23:25:00+03	47000.00
704415	2017-07-18 05:04:00+03	56900.00
70441E	2017-08-05 06:23:00+03	96800.00
70441F	2017-08-12 17:38:00+03	185800.00
70443E	2017-08-05 19:05:00+03	12400.00
70450D	2017-08-07 17:51:00+03	32800.00
704521	2017-07-16 23:01:00+03	47200.00
704538	2017-07-31 19:51:00+03	298400.00
704541	2017-07-27 05:33:00+03	79600.00
704550	2017-07-15 18:49:00+03	393800.00
7045AB	2017-08-14 20:48:00+03	12600.00
7045BD	2017-07-05 04:32:00+03	34000.00
7045BE	2017-07-07 05:23:00+03	49600.00
704677	2017-08-15 03:06:00+03	57600.00
7046AE	2017-07-26 08:24:00+03	12600.00
7046B9	2017-07-05 07:13:00+03	199600.00
704702	2017-07-06 01:34:00+03	28000.00
7047B4	2017-07-22 17:12:00+03	23200.00
7047C2	2017-07-24 17:32:00+03	57600.00
7047C8	2017-08-14 12:23:00+03	161800.00
7047E5	2017-07-04 01:46:00+03	46000.00
70480A	2017-08-13 14:29:00+03	16400.00
704857	2017-07-12 11:48:00+03	35700.00
7048B5	2017-07-27 13:52:00+03	97900.00
704939	2017-07-21 11:35:00+03	40000.00
704993	2017-08-04 02:42:00+03	174600.00
7049A0	2017-08-02 20:08:00+03	58600.00
7049D3	2017-08-12 11:24:00+03	72300.00
704A1C	2017-07-14 03:02:00+03	72400.00
704BD1	2017-07-01 04:33:00+03	65900.00
704C25	2017-07-04 22:44:00+03	27200.00
704C28	2017-07-25 07:49:00+03	113300.00
704CF6	2017-07-18 10:16:00+03	115800.00
704D01	2017-08-10 14:00:00+03	46300.00
704D30	2017-07-22 06:02:00+03	111600.00
704D42	2017-07-22 01:16:00+03	19800.00
704DA6	2017-08-11 14:40:00+03	28000.00
704DC3	2017-07-13 01:42:00+03	31600.00
704DD4	2017-07-22 20:08:00+03	13400.00
704DFA	2017-08-13 18:15:00+03	46500.00
704DFB	2017-07-28 06:01:00+03	28000.00
704E0B	2017-08-15 11:42:00+03	12200.00
704E5A	2017-07-17 05:45:00+03	56600.00
704E68	2017-07-26 07:12:00+03	87200.00
704E70	2017-08-13 16:31:00+03	28800.00
704F79	2017-07-06 14:11:00+03	100300.00
704FA0	2017-07-22 08:51:00+03	113300.00
704FB2	2017-08-08 18:57:00+03	86400.00
704FBB	2017-07-16 07:49:00+03	81700.00
705034	2017-07-06 00:21:00+03	37700.00
705085	2017-07-19 03:19:00+03	133100.00
70508B	2017-07-22 08:24:00+03	58000.00
7050BA	2017-08-09 05:35:00+03	42800.00
7050BC	2017-08-04 19:13:00+03	53100.00
7050DA	2017-07-10 13:58:00+03	48800.00
7050DD	2017-08-15 08:26:00+03	13400.00
7050E0	2017-08-12 13:18:00+03	173200.00
705119	2017-07-13 08:32:00+03	23200.00
705158	2017-07-05 02:45:00+03	43600.00
70515D	2017-08-12 14:15:00+03	56000.00
7051B0	2017-07-19 13:47:00+03	52100.00
7051B4	2017-07-10 10:52:00+03	70100.00
705209	2017-08-01 11:03:00+03	54000.00
705236	2017-08-10 05:31:00+03	70600.00
70525F	2017-07-26 00:45:00+03	21400.00
7052DF	2017-07-05 23:58:00+03	58900.00
705382	2017-08-04 09:23:00+03	25600.00
7053A7	2017-07-25 15:07:00+03	36000.00
7053CD	2017-07-04 14:47:00+03	299100.00
70544C	2017-07-30 22:21:00+03	94200.00
7054DB	2017-07-31 20:08:00+03	372500.00
7054EB	2017-08-04 23:29:00+03	133100.00
7055DE	2017-07-20 06:46:00+03	12600.00
705606	2017-08-14 04:33:00+03	80400.00
705612	2017-08-07 10:32:00+03	47500.00
70568C	2017-07-03 23:34:00+03	17200.00
705706	2017-07-22 00:52:00+03	46400.00
70571A	2017-07-12 06:36:00+03	69900.00
70573E	2017-07-25 15:45:00+03	37300.00
705772	2017-08-09 06:58:00+03	46200.00
7057A3	2017-07-23 08:18:00+03	369000.00
705838	2017-07-04 22:41:00+03	179400.00
70584C	2017-08-10 08:10:00+03	36000.00
7058A5	2017-08-12 16:25:00+03	16400.00
7058B0	2017-07-04 09:20:00+03	13200.00
705923	2017-08-07 16:08:00+03	34000.00
705997	2017-07-09 09:34:00+03	72400.00
705AAF	2017-08-06 16:28:00+03	28000.00
705AF1	2017-07-05 11:15:00+03	54600.00
705B5D	2017-07-03 14:01:00+03	115900.00
705BDA	2017-07-29 17:16:00+03	136800.00
705C38	2017-08-10 21:32:00+03	62700.00
705CC1	2017-07-07 08:36:00+03	51200.00
705CEB	2017-07-08 08:04:00+03	23900.00
705D60	2017-08-02 02:47:00+03	27900.00
705D7A	2017-07-06 21:08:00+03	28800.00
705D96	2017-07-27 06:26:00+03	15900.00
705DB1	2017-07-30 09:49:00+03	112000.00
705DBD	2017-07-04 20:14:00+03	123000.00
705DC4	2017-07-03 23:01:00+03	62900.00
705DCF	2017-07-31 16:57:00+03	29000.00
705DED	2017-08-01 13:31:00+03	61800.00
705E44	2017-07-03 02:14:00+03	96800.00
705E59	2017-08-10 18:21:00+03	59800.00
705E6E	2017-07-07 22:42:00+03	56000.00
705E71	2017-07-26 18:19:00+03	27200.00
705E8C	2017-08-06 03:58:00+03	235500.00
705ED3	2017-07-03 02:52:00+03	13000.00
705F8E	2017-07-04 04:19:00+03	46400.00
705FF1	2017-07-07 19:56:00+03	8200.00
70600E	2017-07-09 09:18:00+03	45300.00
706053	2017-07-25 21:36:00+03	131600.00
7060AC	2017-08-07 01:57:00+03	133900.00
70611C	2017-07-28 03:36:00+03	118800.00
706124	2017-08-13 06:26:00+03	26000.00
7061CE	2017-07-21 00:32:00+03	39000.00
7061EB	2017-07-14 09:59:00+03	82900.00
706205	2017-07-19 08:30:00+03	116100.00
7062A5	2017-08-08 06:31:00+03	152900.00
7062CF	2017-07-04 03:45:00+03	85000.00
7062D6	2017-07-27 08:51:00+03	38800.00
7062EA	2017-07-19 08:41:00+03	27200.00
7062F1	2017-07-20 08:16:00+03	199700.00
706319	2017-07-13 10:02:00+03	14700.00
70633E	2017-08-03 05:03:00+03	224100.00
706349	2017-08-02 03:41:00+03	31600.00
70638B	2017-06-30 07:36:00+03	184300.00
70641E	2017-07-10 04:57:00+03	23200.00
706452	2017-08-14 16:30:00+03	16400.00
706470	2017-07-11 05:29:00+03	6700.00
70653D	2017-07-13 06:24:00+03	42400.00
706552	2017-08-15 05:22:00+03	153300.00
70656A	2017-07-08 05:59:00+03	23400.00
7065B9	2017-07-23 20:26:00+03	246000.00
7065DE	2017-07-13 17:15:00+03	47100.00
7066C2	2017-07-17 23:01:00+03	59800.00
70683B	2017-08-01 14:49:00+03	75600.00
7068B8	2017-07-19 01:54:00+03	96800.00
7068F5	2017-08-02 10:27:00+03	193600.00
706911	2017-07-12 18:46:00+03	119700.00
706946	2017-07-27 02:02:00+03	246000.00
706983	2017-08-13 15:04:00+03	41000.00
7069B4	2017-07-06 15:25:00+03	27900.00
7069C1	2017-06-30 21:30:00+03	208100.00
7069FD	2017-08-13 11:51:00+03	111600.00
706AA2	2017-07-07 08:55:00+03	116400.00
706AE4	2017-07-27 23:55:00+03	274300.00
706AE7	2017-07-14 04:31:00+03	100600.00
706B01	2017-07-25 12:50:00+03	81500.00
706B2D	2017-07-14 22:38:00+03	23200.00
706C43	2017-08-12 11:54:00+03	94000.00
706C46	2017-07-29 08:02:00+03	130400.00
706C4E	2017-07-20 10:55:00+03	73600.00
706C6A	2017-08-10 11:31:00+03	46500.00
706CB1	2017-07-06 03:19:00+03	135400.00
706CB6	2017-07-01 14:16:00+03	94200.00
706CB8	2017-07-14 21:10:00+03	48500.00
706CE3	2017-07-05 02:30:00+03	28000.00
706CF5	2017-08-13 10:15:00+03	189800.00
706D67	2017-07-11 22:39:00+03	60400.00
706E30	2017-07-28 23:49:00+03	24400.00
706E58	2017-07-07 01:54:00+03	88500.00
706ECE	2017-08-04 12:39:00+03	265700.00
706EFD	2017-08-07 10:18:00+03	10600.00
706F9A	2017-08-11 23:40:00+03	16000.00
706FC0	2017-07-12 13:10:00+03	126500.00
706FC1	2017-08-12 04:36:00+03	22000.00
706FF8	2017-07-12 19:48:00+03	136800.00
707048	2017-07-22 06:55:00+03	56900.00
707054	2017-07-13 13:52:00+03	56600.00
707078	2017-07-16 20:05:00+03	131100.00
70709D	2017-07-30 17:55:00+03	65400.00
7070C0	2017-07-06 19:03:00+03	266400.00
70710A	2017-07-20 23:17:00+03	65600.00
70711A	2017-08-02 07:28:00+03	38400.00
70711D	2017-07-16 01:13:00+03	15000.00
70718D	2017-07-07 13:54:00+03	43200.00
70719A	2017-07-05 14:43:00+03	28800.00
7071DC	2017-07-06 10:11:00+03	27200.00
7071F1	2017-07-11 14:08:00+03	94300.00
707205	2017-07-12 17:51:00+03	285100.00
707254	2017-08-08 00:47:00+03	50700.00
70725E	2017-07-14 23:55:00+03	46400.00
70726C	2017-07-03 01:44:00+03	8000.00
7072C5	2017-07-05 16:23:00+03	35800.00
7072E9	2017-07-07 00:06:00+03	123800.00
707303	2017-07-16 08:25:00+03	27900.00
707329	2017-08-12 05:58:00+03	64200.00
7073CA	2017-08-10 12:40:00+03	111600.00
7073F6	2017-08-05 22:42:00+03	261500.00
707571	2017-07-23 00:15:00+03	75600.00
707586	2017-07-31 17:07:00+03	68300.00
7075DD	2017-07-30 14:19:00+03	26000.00
707613	2017-07-11 04:22:00+03	123000.00
70765B	2017-08-09 15:12:00+03	46900.00
7076AA	2017-07-14 00:10:00+03	19600.00
7076D9	2017-07-23 17:57:00+03	76600.00
7076DC	2017-06-28 02:06:00+03	118700.00
707715	2017-07-08 21:00:00+03	147700.00
70771E	2017-07-16 16:11:00+03	25600.00
707728	2017-07-26 23:00:00+03	272300.00
707742	2017-07-10 01:21:00+03	30000.00
7077B2	2017-08-14 10:52:00+03	103800.00
7077E1	2017-07-26 14:10:00+03	36200.00
70786B	2017-07-24 03:57:00+03	87000.00
7078AB	2017-08-10 21:03:00+03	45400.00
7078EE	2017-08-10 21:51:00+03	248400.00
707917	2017-08-11 22:49:00+03	124200.00
707919	2017-08-01 18:34:00+03	157700.00
707930	2017-08-01 16:17:00+03	65900.00
70798C	2017-07-19 05:33:00+03	28000.00
7079E1	2017-08-06 15:34:00+03	48400.00
707A09	2017-08-04 18:35:00+03	143000.00
707A31	2017-08-12 16:32:00+03	111600.00
707A67	2017-07-23 22:21:00+03	82800.00
707A6B	2017-07-26 11:39:00+03	100700.00
707AD9	2017-08-05 21:47:00+03	28800.00
707B02	2017-07-05 13:48:00+03	28800.00
707B28	2017-07-24 06:21:00+03	146600.00
707B8F	2017-07-20 06:04:00+03	35200.00
707B91	2017-08-03 10:48:00+03	214200.00
707BF4	2017-08-08 18:59:00+03	89200.00
707C24	2017-07-29 10:57:00+03	53600.00
707C3B	2017-07-26 08:44:00+03	25600.00
707CDE	2017-07-21 05:05:00+03	38200.00
707D55	2017-08-03 11:43:00+03	81900.00
707D94	2017-08-11 00:37:00+03	6700.00
707D9B	2017-08-11 10:26:00+03	56600.00
707DEC	2017-07-24 19:25:00+03	39200.00
707DFE	2017-07-13 19:33:00+03	133200.00
707E04	2017-07-09 20:22:00+03	28800.00
707EE3	2017-07-31 05:44:00+03	93900.00
707F30	2017-06-28 06:41:00+03	22600.00
707F35	2017-08-10 02:10:00+03	56900.00
707F57	2017-07-11 08:22:00+03	67600.00
707F7C	2017-07-17 22:20:00+03	55000.00
707FD3	2017-08-15 07:48:00+03	13700.00
707FDF	2017-08-13 00:07:00+03	47400.00
708005	2017-07-27 22:03:00+03	26000.00
7080A6	2017-07-26 02:09:00+03	24200.00
7080B4	2017-07-30 22:27:00+03	70700.00
7080C1	2017-07-22 16:42:00+03	46300.00
7080CD	2017-07-07 03:20:00+03	22000.00
7080CF	2017-07-20 03:20:00+03	146300.00
7080DF	2017-07-17 02:32:00+03	80000.00
70812A	2017-07-30 08:29:00+03	57500.00
708135	2017-08-04 09:14:00+03	95200.00
708166	2017-07-20 09:56:00+03	66300.00
708190	2017-07-10 21:24:00+03	30200.00
708192	2017-08-12 09:21:00+03	23200.00
7081FC	2017-08-02 22:18:00+03	167400.00
70821D	2017-07-21 09:32:00+03	88800.00
70823E	2017-07-30 07:24:00+03	107700.00
70823F	2017-08-05 07:44:00+03	67400.00
708262	2017-07-18 03:42:00+03	24400.00
708271	2017-07-05 23:05:00+03	55800.00
70827D	2017-07-22 12:23:00+03	57600.00
708298	2017-08-09 16:24:00+03	67700.00
708384	2017-07-12 02:18:00+03	46400.00
7083DD	2017-07-27 13:30:00+03	199200.00
7083FE	2017-06-30 04:39:00+03	28800.00
708437	2017-08-02 21:05:00+03	50800.00
70846B	2017-08-04 09:26:00+03	37900.00
708482	2017-07-14 11:01:00+03	121500.00
70848E	2017-08-13 03:24:00+03	88500.00
708531	2017-08-14 07:11:00+03	56000.00
70856E	2017-07-19 01:45:00+03	46000.00
70858A	2017-08-08 14:09:00+03	6800.00
70858E	2017-07-10 04:18:00+03	147700.00
7085DE	2017-07-09 07:20:00+03	56000.00
7085F2	2017-08-15 16:43:00+03	42600.00
7085FA	2017-08-08 03:43:00+03	27400.00
70863B	2017-07-30 10:08:00+03	86300.00
708652	2017-08-07 06:07:00+03	17200.00
708683	2017-07-08 17:06:00+03	46000.00
708743	2017-07-05 14:25:00+03	33100.00
708820	2017-07-18 22:41:00+03	21800.00
70883B	2017-07-25 09:12:00+03	18800.00
70884B	2017-07-02 11:54:00+03	26000.00
708861	2017-07-08 17:40:00+03	101200.00
708888	2017-08-14 11:06:00+03	99200.00
7088B8	2017-07-23 09:47:00+03	24800.00
708928	2017-07-26 17:28:00+03	15000.00
708972	2017-08-09 09:19:00+03	59100.00
708982	2017-07-30 17:03:00+03	135000.00
70899B	2017-07-29 20:02:00+03	58400.00
7089D2	2017-08-07 06:30:00+03	68300.00
7089F9	2017-08-09 15:58:00+03	34400.00
708A13	2017-07-12 08:46:00+03	165100.00
708A1E	2017-07-19 04:25:00+03	13800.00
708A27	2017-07-15 22:42:00+03	116400.00
708A5A	2017-07-10 10:40:00+03	38800.00
708A75	2017-07-31 02:37:00+03	123000.00
708A90	2017-08-03 13:47:00+03	43000.00
708AB3	2017-08-14 07:14:00+03	58400.00
708B07	2017-08-12 03:52:00+03	29600.00
708B2E	2017-07-16 13:51:00+03	46200.00
708B78	2017-07-05 02:20:00+03	80700.00
708BC2	2017-07-24 00:25:00+03	184500.00
708BCC	2017-07-28 04:48:00+03	155000.00
708C12	2017-08-14 14:06:00+03	70700.00
708C15	2017-07-05 11:38:00+03	64500.00
708C4A	2017-07-04 17:34:00+03	64500.00
708C4C	2017-07-19 07:47:00+03	62400.00
708C7C	2017-07-23 06:33:00+03	36200.00
708CAF	2017-07-19 05:58:00+03	14800.00
708CCF	2017-07-17 09:10:00+03	50000.00
708CD8	2017-08-07 04:25:00+03	193700.00
708E5F	2017-07-26 09:08:00+03	106200.00
708ED6	2017-07-11 16:28:00+03	42800.00
708ED8	2017-08-01 18:37:00+03	34000.00
708F4B	2017-07-06 15:21:00+03	12600.00
708F6E	2017-07-27 12:31:00+03	147700.00
708F73	2017-07-11 21:31:00+03	73300.00
708FE3	2017-07-13 08:28:00+03	111600.00
70902D	2017-08-14 20:51:00+03	49300.00
709054	2017-07-02 23:13:00+03	58800.00
70909A	2017-07-22 16:18:00+03	144400.00
7090C9	2017-08-09 12:27:00+03	37700.00
7090DB	2017-08-09 11:03:00+03	58200.00
709189	2017-07-20 04:33:00+03	73200.00
70925A	2017-07-13 07:43:00+03	26000.00
709286	2017-07-26 03:43:00+03	250100.00
70929C	2017-07-16 18:20:00+03	56600.00
7092F2	2017-07-08 19:41:00+03	28800.00
709360	2017-07-10 11:52:00+03	31000.00
709371	2017-08-13 07:09:00+03	46300.00
709390	2017-08-01 03:41:00+03	26200.00
7093FB	2017-07-25 04:27:00+03	65500.00
70940B	2017-08-07 22:37:00+03	272400.00
709414	2017-07-16 04:09:00+03	44000.00
709460	2017-08-02 17:01:00+03	136600.00
709479	2017-08-04 10:24:00+03	37900.00
7094B7	2017-07-19 08:13:00+03	135600.00
7094B9	2017-07-19 08:32:00+03	58900.00
709506	2017-07-25 19:19:00+03	369000.00
709578	2017-08-13 19:41:00+03	12600.00
7095A8	2017-07-31 23:14:00+03	79600.00
7095EF	2017-08-02 12:01:00+03	89600.00
709609	2017-07-13 13:24:00+03	53400.00
70965A	2017-07-07 20:21:00+03	149300.00
709664	2017-07-07 10:44:00+03	67100.00
7096A7	2017-08-14 08:33:00+03	27900.00
709700	2017-08-14 00:00:00+03	111600.00
709723	2017-07-05 20:34:00+03	449700.00
70972B	2017-08-11 05:54:00+03	25600.00
709735	2017-07-03 16:49:00+03	59600.00
70977A	2017-07-03 09:42:00+03	71400.00
709786	2017-08-04 22:01:00+03	135200.00
70985B	2017-08-05 17:47:00+03	21400.00
70985C	2017-08-09 11:11:00+03	40800.00
7098B2	2017-08-12 10:13:00+03	199200.00
7098D1	2017-08-04 21:27:00+03	66700.00
70990F	2017-08-13 00:25:00+03	66600.00
709921	2017-08-14 10:21:00+03	31700.00
709A3F	2017-07-11 12:35:00+03	55800.00
709A52	2017-07-24 05:11:00+03	26000.00
709B51	2017-07-14 08:27:00+03	37000.00
709B70	2017-07-06 18:30:00+03	73300.00
709BEB	2017-08-01 06:46:00+03	28000.00
709C34	2017-08-14 15:13:00+03	101000.00
709C3B	2017-08-06 18:41:00+03	289800.00
709CA3	2017-07-27 22:30:00+03	56000.00
709CF8	2017-07-26 06:34:00+03	131100.00
709D0D	2017-07-07 13:37:00+03	25600.00
709DA2	2017-07-29 03:30:00+03	52400.00
709DD5	2017-08-11 11:47:00+03	43000.00
709DEA	2017-08-08 04:48:00+03	92400.00
709E32	2017-07-07 16:58:00+03	144000.00
709E4A	2017-08-08 09:08:00+03	40400.00
709E5B	2017-07-15 18:15:00+03	26700.00
709F9A	2017-07-18 09:25:00+03	24400.00
709FD0	2017-07-09 04:57:00+03	78200.00
70A01B	2017-08-05 13:53:00+03	96600.00
70A02B	2017-07-06 07:38:00+03	6000.00
70A037	2017-07-13 01:51:00+03	30400.00
70A081	2017-08-15 04:42:00+03	553800.00
70A0F9	2017-08-10 17:26:00+03	28000.00
70A100	2017-07-30 21:38:00+03	38600.00
70A193	2017-08-03 07:31:00+03	91800.00
70A1B0	2017-07-16 11:40:00+03	26000.00
70A1BB	2017-07-20 08:30:00+03	89600.00
70A1BE	2017-06-30 04:33:00+03	7400.00
70A1E1	2017-07-14 23:13:00+03	67800.00
70A1F5	2017-07-18 05:17:00+03	28000.00
70A24F	2017-07-06 09:26:00+03	38600.00
70A275	2017-07-12 10:53:00+03	79700.00
70A346	2017-07-09 19:21:00+03	111600.00
70A39C	2017-08-15 05:38:00+03	12000.00
70A3BA	2017-07-23 02:43:00+03	12600.00
70A45C	2017-07-14 10:39:00+03	56000.00
70A478	2017-08-11 17:31:00+03	75300.00
70A482	2017-07-14 17:16:00+03	121400.00
70A4E0	2017-08-01 02:46:00+03	26000.00
70A4F0	2017-07-17 07:01:00+03	46000.00
70A508	2017-07-22 05:03:00+03	140200.00
70A5A1	2017-07-02 02:07:00+03	40800.00
70A5B4	2017-07-15 00:45:00+03	86800.00
70A5CF	2017-08-12 13:16:00+03	44600.00
70A629	2017-08-11 10:26:00+03	119400.00
70A637	2017-07-12 17:28:00+03	50800.00
70A653	2017-07-29 14:21:00+03	14000.00
70A65E	2017-07-18 09:42:00+03	27400.00
70A664	2017-07-11 16:50:00+03	80600.00
70A693	2017-08-06 07:24:00+03	28000.00
70A7A5	2017-07-13 03:17:00+03	84100.00
70A7B8	2017-07-09 10:43:00+03	36600.00
70A85A	2017-07-13 08:27:00+03	52000.00
70A8B8	2017-08-09 15:37:00+03	120900.00
70A8D6	2017-07-22 06:44:00+03	134600.00
70A8F1	2017-08-05 13:42:00+03	20600.00
70A933	2017-08-14 13:03:00+03	96600.00
70A991	2017-07-16 00:09:00+03	42700.00
70A9AB	2017-08-09 01:50:00+03	283100.00
70A9B8	2017-07-06 09:52:00+03	135600.00
70A9CD	2017-07-23 23:17:00+03	19800.00
70A9D6	2017-07-03 18:38:00+03	58600.00
70AA00	2017-07-15 02:16:00+03	36400.00
70AA0F	2017-07-18 03:31:00+03	63700.00
70AA98	2017-07-30 06:03:00+03	99200.00
70AAA1	2017-07-15 01:54:00+03	18600.00
70AACD	2017-07-06 06:56:00+03	26000.00
70AACF	2017-07-05 02:01:00+03	22000.00
70AB4D	2017-08-10 21:44:00+03	28300.00
70AB98	2017-08-06 23:16:00+03	31400.00
70ABD9	2017-07-08 08:01:00+03	240600.00
70ABE2	2017-08-12 22:10:00+03	75300.00
70ABFD	2017-07-09 06:19:00+03	55500.00
70AC07	2017-08-11 00:16:00+03	59300.00
70AC15	2017-07-01 06:05:00+03	128600.00
70AC20	2017-07-08 05:03:00+03	65900.00
70AC24	2017-07-28 10:40:00+03	112600.00
70AC5D	2017-08-15 01:30:00+03	196500.00
70AC8B	2017-08-05 21:51:00+03	23400.00
70AD00	2017-08-02 17:38:00+03	7300.00
70ADB7	2017-07-30 17:52:00+03	75600.00
70AE73	2017-07-16 14:37:00+03	56000.00
70AE85	2017-08-10 16:46:00+03	21000.00
70AEE3	2017-07-03 19:23:00+03	30400.00
70AF02	2017-07-28 19:59:00+03	139500.00
70B073	2017-07-06 21:26:00+03	49600.00
70B08A	2017-07-04 22:43:00+03	44000.00
70B0B3	2017-07-17 10:39:00+03	85700.00
70B1C3	2017-07-11 03:30:00+03	28000.00
70B232	2017-07-27 12:40:00+03	124200.00
70B25E	2017-07-22 15:28:00+03	53600.00
70B271	2017-08-08 11:40:00+03	21200.00
70B2D4	2017-07-01 10:40:00+03	30000.00
70B2F6	2017-07-12 15:41:00+03	14000.00
70B338	2017-07-31 05:40:00+03	46200.00
70B3A7	2017-08-07 13:41:00+03	56000.00
70B3C2	2017-07-20 09:41:00+03	36500.00
70B3C5	2017-07-19 13:48:00+03	55800.00
70B3F8	2017-08-02 14:35:00+03	56200.00
70B3FA	2017-08-14 17:46:00+03	31400.00
70B454	2017-08-06 20:01:00+03	149100.00
70B472	2017-07-26 08:20:00+03	38600.00
70B4C8	2017-07-29 00:03:00+03	28000.00
70B4FD	2017-08-14 00:21:00+03	40800.00
70B528	2017-07-04 16:13:00+03	100400.00
70B535	2017-08-08 10:04:00+03	39500.00
70B539	2017-07-18 04:19:00+03	66600.00
70B545	2017-08-04 10:18:00+03	32700.00
70B55D	2017-08-01 05:20:00+03	63700.00
70B567	2017-08-06 09:18:00+03	24300.00
70B571	2017-07-24 20:56:00+03	85500.00
70B5A2	2017-07-12 05:00:00+03	110500.00
70B5C4	2017-08-02 15:25:00+03	105000.00
70B655	2017-07-11 00:05:00+03	38600.00
70B65B	2017-07-08 12:55:00+03	189800.00
70B676	2017-08-11 16:12:00+03	92800.00
70B6B7	2017-07-18 04:58:00+03	196000.00
70B771	2017-07-15 02:26:00+03	48800.00
70B785	2017-08-01 19:02:00+03	12000.00
70B7BC	2017-07-22 22:28:00+03	30200.00
70B7DF	2017-08-13 07:19:00+03	45200.00
70B882	2017-07-21 22:18:00+03	61400.00
70B8C9	2017-07-12 12:03:00+03	57700.00
70B91A	2017-07-23 04:11:00+03	68000.00
70B962	2017-07-04 06:31:00+03	103800.00
70B96A	2017-08-03 05:15:00+03	53200.00
70B9DE	2017-06-30 15:41:00+03	59300.00
70BA7A	2017-08-03 05:11:00+03	31900.00
70BA81	2017-07-29 18:09:00+03	99200.00
70BAA4	2017-08-11 21:02:00+03	98400.00
70BAA6	2017-07-22 19:02:00+03	48800.00
70BABF	2017-07-20 19:01:00+03	39800.00
70BB92	2017-07-31 04:16:00+03	22200.00
70BBAA	2017-07-14 05:54:00+03	231800.00
70BBB6	2017-08-02 13:18:00+03	111600.00
70BBC2	2017-07-26 21:54:00+03	86600.00
70BC50	2017-07-11 14:14:00+03	186900.00
70BD73	2017-07-14 21:42:00+03	120000.00
70BDB3	2017-08-01 11:56:00+03	67900.00
70BDD7	2017-07-20 23:59:00+03	28800.00
70BE31	2017-08-11 23:53:00+03	117800.00
70BE4D	2017-07-29 23:48:00+03	25600.00
70BEAA	2017-07-23 06:10:00+03	58200.00
70BF29	2017-07-20 07:08:00+03	78600.00
70BF2F	2017-07-29 03:14:00+03	67700.00
70BF4A	2017-07-09 08:17:00+03	103500.00
70BFCD	2017-07-12 13:08:00+03	185400.00
70BFD9	2017-07-31 09:43:00+03	132800.00
70BFFE	2017-07-31 20:04:00+03	34000.00
70C052	2017-06-27 08:42:00+03	116800.00
70C063	2017-07-25 14:23:00+03	84600.00
70C0A8	2017-07-28 07:12:00+03	97900.00
70C11C	2017-08-10 07:37:00+03	136600.00
70C12D	2017-08-04 01:26:00+03	161100.00
70C14D	2017-07-21 00:03:00+03	40000.00
70C16A	2017-07-04 18:20:00+03	24400.00
70C1CF	2017-08-14 11:05:00+03	62600.00
70C1DA	2017-07-26 17:35:00+03	28000.00
70C1E4	2017-07-03 00:01:00+03	66400.00
70C2AE	2017-07-24 04:34:00+03	23400.00
70C34B	2017-08-06 19:34:00+03	69500.00
70C3E1	2017-07-12 16:35:00+03	99700.00
70C3F5	2017-07-29 09:43:00+03	123600.00
70C441	2017-07-06 15:46:00+03	28800.00
70C451	2017-08-08 00:46:00+03	31600.00
70C4E0	2017-07-23 23:03:00+03	139400.00
70C4F3	2017-06-26 01:08:00+03	67400.00
70C51C	2017-08-12 13:16:00+03	83700.00
70C538	2017-08-10 05:09:00+03	57500.00
70C544	2017-07-23 15:05:00+03	101500.00
70C5F0	2017-07-30 13:13:00+03	52000.00
70C60E	2017-07-26 17:58:00+03	39300.00
70C610	2017-07-25 17:52:00+03	22000.00
70C65F	2017-08-10 19:54:00+03	48900.00
70C6AE	2017-08-02 02:50:00+03	24700.00
70C6B3	2017-07-23 03:51:00+03	46200.00
70C6DB	2017-08-11 15:31:00+03	11600.00
70C7D8	2017-07-25 22:24:00+03	167500.00
70C83D	2017-07-27 19:46:00+03	89700.00
70C845	2017-07-31 10:49:00+03	111600.00
70C8AC	2017-08-09 21:29:00+03	23100.00
70C8F7	2017-07-14 05:02:00+03	69500.00
70C9C0	2017-08-07 01:04:00+03	89700.00
70CA7E	2017-06-28 05:01:00+03	201200.00
70CAC4	2017-07-19 10:47:00+03	16400.00
70CB16	2017-08-13 01:03:00+03	406200.00
70CB19	2017-07-18 07:44:00+03	89700.00
70CB2C	2017-08-04 14:13:00+03	85000.00
70CB8D	2017-08-10 01:27:00+03	131100.00
70CB90	2017-07-28 21:43:00+03	39800.00
70CB96	2017-07-02 20:00:00+03	28800.00
70CC14	2017-07-03 18:54:00+03	40800.00
70CC34	2017-07-23 09:36:00+03	202600.00
70CCBD	2017-07-27 07:40:00+03	204500.00
70CD0D	2017-07-02 10:24:00+03	46700.00
70CD71	2017-08-10 02:45:00+03	18700.00
70CE11	2017-07-24 22:05:00+03	258000.00
70CE1B	2017-08-06 08:00:00+03	173400.00
70CE1D	2017-07-22 13:19:00+03	56000.00
70CE36	2017-07-15 07:52:00+03	21800.00
70CE73	2017-06-30 14:10:00+03	93900.00
70CE7D	2017-08-14 06:58:00+03	70200.00
70CE7E	2017-07-25 14:18:00+03	57400.00
70CE87	2017-07-31 19:02:00+03	70500.00
70CEC5	2017-07-26 07:20:00+03	39200.00
70CED3	2017-07-22 06:41:00+03	23600.00
70CFFD	2017-08-01 15:07:00+03	70800.00
70D0B6	2017-08-06 21:43:00+03	133800.00
70D0FF	2017-07-21 18:08:00+03	84800.00
70D121	2017-07-26 15:04:00+03	6700.00
70D165	2017-07-31 10:40:00+03	28800.00
70D16C	2017-07-21 01:48:00+03	85000.00
70D181	2017-07-10 00:39:00+03	76100.00
70D20E	2017-08-14 16:40:00+03	31100.00
70D295	2017-08-12 12:45:00+03	26000.00
70D2BF	2017-08-03 15:26:00+03	100800.00
70D331	2017-08-10 13:09:00+03	7400.00
70D346	2017-07-20 08:33:00+03	81900.00
70D3BE	2017-07-13 10:32:00+03	25400.00
70D3C2	2017-08-09 20:24:00+03	492900.00
70D442	2017-07-07 02:45:00+03	223200.00
70D49F	2017-07-22 15:43:00+03	81700.00
70D4D5	2017-08-07 22:58:00+03	48800.00
70D538	2017-07-24 00:41:00+03	28800.00
70D58B	2017-07-16 15:51:00+03	123000.00
70D59E	2017-08-11 23:03:00+03	15400.00
70D5E1	2017-08-09 05:13:00+03	62700.00
70D6E3	2017-08-12 08:59:00+03	81700.00
70D740	2017-08-11 19:18:00+03	13400.00
70D7B0	2017-08-05 21:06:00+03	109600.00
70D808	2017-08-04 21:17:00+03	7400.00
70D820	2017-08-13 22:00:00+03	21400.00
70D86A	2017-08-06 21:00:00+03	40800.00
70D896	2017-07-28 00:00:00+03	286800.00
70D897	2017-08-12 05:34:00+03	23200.00
70D8B4	2017-07-16 18:34:00+03	11600.00
70D8CA	2017-08-15 14:03:00+03	54400.00
70D8F1	2017-08-04 14:18:00+03	96800.00
70D902	2017-07-16 13:43:00+03	36200.00
70D94A	2017-07-24 21:55:00+03	51300.00
70D986	2017-07-21 11:23:00+03	48800.00
70D9A6	2017-07-23 22:48:00+03	135400.00
70D9E3	2017-07-11 19:59:00+03	12000.00
70DA15	2017-07-14 14:21:00+03	39500.00
70DA28	2017-07-03 21:06:00+03	407400.00
70DA4D	2017-07-22 14:19:00+03	78000.00
70DB16	2017-07-28 13:22:00+03	64700.00
70DB2C	2017-08-13 04:01:00+03	62100.00
70DB6A	2017-08-03 19:09:00+03	90400.00
70DBD9	2017-06-29 10:26:00+03	214300.00
70DC32	2017-08-15 14:48:00+03	17000.00
70DC6B	2017-08-09 21:38:00+03	152500.00
70DD6E	2017-07-12 14:42:00+03	105400.00
70DD85	2017-08-13 18:54:00+03	86500.00
70DD9D	2017-07-08 17:30:00+03	80200.00
70DDEF	2017-08-13 00:10:00+03	72200.00
70DE23	2017-07-02 22:57:00+03	40000.00
70DE4F	2017-08-15 15:10:00+03	24000.00
70DE79	2017-07-14 05:27:00+03	92800.00
70DEAE	2017-07-22 17:16:00+03	6800.00
70DEB5	2017-07-08 09:10:00+03	26000.00
70DEC6	2017-07-26 16:15:00+03	266400.00
70DF85	2017-08-10 21:15:00+03	115900.00
70E021	2017-07-09 17:39:00+03	34000.00
70E0A7	2017-07-23 14:46:00+03	12600.00
70E0E1	2017-07-07 03:04:00+03	46300.00
70E19A	2017-07-18 17:10:00+03	67700.00
70E1B5	2017-07-10 15:05:00+03	47100.00
70E1C6	2017-08-11 12:39:00+03	46400.00
70E1ED	2017-08-05 21:27:00+03	25000.00
70E20D	2017-07-24 12:05:00+03	12000.00
70E2BE	2017-08-13 05:44:00+03	24400.00
70E361	2017-08-13 15:23:00+03	51100.00
70E375	2017-08-04 09:24:00+03	23600.00
70E4A8	2017-07-01 00:04:00+03	6700.00
70E4DD	2017-07-01 01:04:00+03	25600.00
70E4E4	2017-08-01 05:30:00+03	58100.00
70E50E	2017-07-25 18:05:00+03	112000.00
70E573	2017-07-07 21:41:00+03	299600.00
70E5DD	2017-08-13 03:11:00+03	47400.00
70E620	2017-08-02 09:17:00+03	188900.00
70E665	2017-08-09 18:48:00+03	56100.00
70E6B2	2017-07-11 07:32:00+03	55600.00
70E707	2017-08-13 22:18:00+03	31000.00
70E73B	2017-07-24 00:51:00+03	57600.00
70E761	2017-07-27 11:39:00+03	6700.00
70E769	2017-07-23 04:49:00+03	14000.00
70E793	2017-07-12 08:11:00+03	18600.00
70E7E6	2017-08-03 09:26:00+03	35200.00
70E7EE	2017-07-08 13:45:00+03	69900.00
70E85E	2017-07-30 01:01:00+03	40400.00
70E89D	2017-07-15 15:39:00+03	43000.00
70E8BE	2017-07-02 07:45:00+03	123000.00
70E8CC	2017-08-01 00:01:00+03	31600.00
70E8DC	2017-07-06 09:04:00+03	51600.00
70E9C6	2017-08-03 15:02:00+03	46000.00
70E9DD	2017-08-04 05:08:00+03	6300.00
70E9F2	2017-07-24 17:21:00+03	16400.00
70EA0C	2017-07-16 07:44:00+03	22000.00
70EA1A	2017-07-15 18:45:00+03	132800.00
70EA42	2017-07-03 06:03:00+03	26800.00
70EACE	2017-08-05 23:32:00+03	46000.00
70EB2E	2017-07-12 19:17:00+03	125200.00
70EB4D	2017-06-30 04:46:00+03	34000.00
70EB52	2017-07-13 17:03:00+03	70600.00
70EB54	2017-08-10 15:11:00+03	357000.00
70EB97	2017-07-16 20:02:00+03	123000.00
70EB98	2017-07-20 04:18:00+03	94300.00
70EBB4	2017-08-01 17:01:00+03	18600.00
70EBC2	2017-07-18 13:11:00+03	62600.00
70ED55	2017-08-03 09:56:00+03	6200.00
70ED9A	2017-08-12 03:09:00+03	37100.00
70EDA7	2017-08-01 09:14:00+03	56000.00
70EDDF	2017-08-05 13:35:00+03	28000.00
70EDE3	2017-08-15 00:32:00+03	12000.00
70EE94	2017-07-28 22:36:00+03	34000.00
70EF0B	2017-07-05 23:31:00+03	137400.00
70EF3E	2017-07-27 20:46:00+03	64900.00
70EF5B	2017-07-08 20:26:00+03	46200.00
70EFEC	2017-08-15 14:44:00+03	93900.00
70F003	2017-07-02 21:35:00+03	67600.00
70F010	2017-07-07 10:59:00+03	89700.00
70F026	2017-08-10 18:58:00+03	85000.00
70F0B0	2017-07-14 18:38:00+03	28000.00
70F1A9	2017-08-06 03:46:00+03	41200.00
70F20C	2017-07-25 06:34:00+03	128800.00
70F260	2017-08-11 16:53:00+03	75800.00
70F288	2017-07-09 01:55:00+03	32700.00
70F2BC	2017-07-30 15:54:00+03	26000.00
70F2C6	2017-08-04 15:56:00+03	56000.00
70F2F7	2017-07-26 09:06:00+03	47000.00
70F313	2017-07-21 18:45:00+03	50600.00
70F324	2017-07-20 07:15:00+03	68600.00
70F38D	2017-07-15 15:15:00+03	36000.00
70F3AF	2017-07-22 16:08:00+03	8200.00
70F415	2017-08-07 03:40:00+03	46400.00
70F453	2017-07-04 10:05:00+03	85000.00
70F4A2	2017-07-10 20:22:00+03	85000.00
70F4C1	2017-07-28 11:13:00+03	36200.00
70F4DA	2017-08-13 21:53:00+03	67800.00
70F52B	2017-07-08 01:53:00+03	84300.00
70F557	2017-08-10 16:37:00+03	35200.00
70F568	2017-07-08 00:12:00+03	136600.00
70F5D9	2017-08-06 10:00:00+03	51800.00
70F5E5	2017-08-13 18:22:00+03	86500.00
70F606	2017-07-18 09:15:00+03	73200.00
70F61B	2017-07-20 06:31:00+03	285300.00
70F637	2017-08-04 11:13:00+03	81200.00
70F67B	2017-07-15 04:58:00+03	32200.00
70F681	2017-07-04 18:41:00+03	61800.00
70F690	2017-07-31 01:17:00+03	52000.00
70F6C0	2017-08-03 08:40:00+03	70200.00
70F6CD	2017-08-13 16:01:00+03	87200.00
70F6E6	2017-08-05 16:19:00+03	25100.00
70F735	2017-08-06 05:23:00+03	91100.00
70F798	2017-08-04 20:23:00+03	48500.00
70F7B2	2017-07-23 23:06:00+03	79900.00
70F7C6	2017-07-14 17:39:00+03	166100.00
70F7CF	2017-07-11 19:49:00+03	16800.00
70F7DB	2017-07-16 19:48:00+03	42800.00
70F85F	2017-07-20 18:16:00+03	152400.00
70F866	2017-07-23 16:27:00+03	65500.00
70F937	2017-07-19 07:49:00+03	32700.00
70F93E	2017-08-01 03:39:00+03	46000.00
70F95E	2017-07-27 16:08:00+03	10800.00
70F979	2017-06-30 16:10:00+03	38600.00
70F9BE	2017-08-09 23:03:00+03	28800.00
70F9D5	2017-07-17 12:45:00+03	6700.00
70FA16	2017-08-07 02:41:00+03	79600.00
70FA44	2017-07-25 04:00:00+03	66600.00
70FA6D	2017-07-20 21:09:00+03	265600.00
70FA70	2017-07-12 10:47:00+03	125400.00
70FA7C	2017-07-28 01:25:00+03	30000.00
70FAD8	2017-07-22 11:15:00+03	133100.00
70FB10	2017-07-18 00:52:00+03	91600.00
70FB35	2017-07-07 06:30:00+03	399600.00
70FBA2	2017-08-02 23:27:00+03	37900.00
70FBAD	2017-07-28 22:34:00+03	38400.00
70FC0E	2017-07-26 23:25:00+03	125200.00
70FC9D	2017-07-20 12:49:00+03	89200.00
70FCA4	2017-07-10 09:31:00+03	29600.00
70FD52	2017-08-04 21:07:00+03	112000.00
70FEBE	2017-08-11 19:44:00+03	42700.00
70FF63	2017-07-21 11:21:00+03	33800.00
70FF8A	2017-08-13 11:11:00+03	28800.00
70FFA4	2017-07-01 12:20:00+03	11800.00
710026	2017-07-13 23:48:00+03	58800.00
710036	2017-07-01 08:33:00+03	146600.00
71004B	2017-07-24 23:50:00+03	17600.00
710063	2017-07-06 20:45:00+03	316000.00
7100B0	2017-07-16 05:03:00+03	58400.00
7100BB	2017-07-12 02:41:00+03	25000.00
7100FE	2017-07-08 13:46:00+03	67200.00
71010A	2017-08-03 13:14:00+03	103500.00
710147	2017-08-06 04:17:00+03	61500.00
71016F	2017-07-23 22:38:00+03	52100.00
7101BA	2017-08-09 05:23:00+03	72600.00
7102CA	2017-06-29 00:59:00+03	7400.00
7102E1	2017-07-04 06:10:00+03	28000.00
710300	2017-07-31 18:17:00+03	39400.00
71035C	2017-07-27 19:19:00+03	26000.00
71038D	2017-06-30 03:02:00+03	24000.00
71039A	2017-07-16 04:20:00+03	97700.00
7103A7	2017-06-28 17:15:00+03	42800.00
71044F	2017-08-10 10:32:00+03	35300.00
71047D	2017-07-21 21:47:00+03	90800.00
71059B	2017-06-29 09:15:00+03	28000.00
7105E8	2017-07-16 11:24:00+03	55800.00
7105F7	2017-07-11 13:06:00+03	53200.00
710654	2017-07-09 01:32:00+03	28800.00
71066B	2017-07-09 14:18:00+03	77000.00
710672	2017-07-13 01:45:00+03	111600.00
710693	2017-08-10 13:24:00+03	83600.00
7106D6	2017-08-04 17:43:00+03	41800.00
7106EF	2017-08-05 03:27:00+03	564000.00
71072A	2017-08-14 23:53:00+03	80800.00
710730	2017-07-09 01:10:00+03	103500.00
71073A	2017-08-07 14:45:00+03	45000.00
710841	2017-07-06 20:33:00+03	12600.00
710887	2017-07-27 11:40:00+03	50800.00
71088E	2017-07-27 04:15:00+03	68100.00
7108D1	2017-08-03 03:16:00+03	136800.00
7108F5	2017-07-27 06:17:00+03	43200.00
7108FA	2017-07-21 10:28:00+03	26800.00
710921	2017-07-17 20:41:00+03	57400.00
710973	2017-07-28 10:13:00+03	61800.00
710982	2017-07-22 22:10:00+03	29400.00
710988	2017-07-19 10:08:00+03	30200.00
71098C	2017-07-20 09:59:00+03	130400.00
710A00	2017-07-17 22:36:00+03	112000.00
710A31	2017-08-15 05:20:00+03	18000.00
710AB4	2017-07-14 08:35:00+03	65900.00
710ADD	2017-07-24 07:08:00+03	57500.00
710B02	2017-08-05 02:52:00+03	27400.00
710B18	2017-08-13 23:01:00+03	272400.00
710BA8	2017-07-03 22:10:00+03	123000.00
710BAC	2017-07-29 01:19:00+03	56200.00
710BC5	2017-07-29 12:35:00+03	47100.00
710C0D	2017-07-05 08:10:00+03	18800.00
710C48	2017-07-17 09:26:00+03	57500.00
710CA2	2017-07-04 02:59:00+03	24400.00
710CAF	2017-08-14 00:11:00+03	46500.00
710CD1	2017-08-06 12:04:00+03	13400.00
710D29	2017-07-27 00:11:00+03	133200.00
710D99	2017-07-26 14:50:00+03	18400.00
710DBC	2017-08-10 03:22:00+03	106200.00
710DD5	2017-07-19 10:10:00+03	132800.00
710E2F	2017-07-06 02:04:00+03	18800.00
710ECA	2017-07-30 23:37:00+03	11200.00
710F1A	2017-08-14 23:06:00+03	214900.00
710F93	2017-08-01 20:51:00+03	102100.00
710FBC	2017-08-08 12:08:00+03	10800.00
711022	2017-07-18 17:09:00+03	40400.00
711027	2017-08-15 17:01:00+03	19600.00
71102B	2017-07-23 04:10:00+03	69500.00
71105A	2017-08-04 15:56:00+03	81300.00
71105F	2017-08-13 19:26:00+03	71600.00
7111BC	2017-07-25 23:52:00+03	168100.00
71124D	2017-06-29 10:46:00+03	70800.00
711265	2017-07-14 16:55:00+03	142300.00
71126A	2017-08-09 23:29:00+03	62000.00
71127B	2017-07-04 06:22:00+03	136300.00
71131F	2017-07-24 01:07:00+03	28200.00
711359	2017-07-03 14:35:00+03	23200.00
711370	2017-07-04 10:59:00+03	8200.00
711378	2017-07-30 14:04:00+03	22000.00
7114B9	2017-08-07 08:38:00+03	27400.00
7114E5	2017-08-02 04:18:00+03	129900.00
7114EA	2017-07-30 06:20:00+03	14800.00
71150B	2017-07-08 15:22:00+03	62600.00
71154A	2017-07-29 01:23:00+03	85000.00
711627	2017-07-04 09:33:00+03	258400.00
711685	2017-07-18 20:40:00+03	103900.00
7116BA	2017-08-05 06:06:00+03	50600.00
7116BE	2017-07-05 17:41:00+03	69600.00
711704	2017-07-16 22:29:00+03	57600.00
711725	2017-08-09 03:05:00+03	43600.00
711729	2017-08-03 21:58:00+03	31000.00
71176B	2017-07-12 19:09:00+03	73200.00
71177A	2017-08-10 14:26:00+03	19600.00
7117D0	2017-08-10 15:52:00+03	8000.00
7117E4	2017-07-31 04:23:00+03	70700.00
7118B2	2017-07-15 01:26:00+03	32300.00
7118C6	2017-07-09 05:24:00+03	15100.00
7118E8	2017-07-05 12:12:00+03	13400.00
7118F3	2017-07-27 15:19:00+03	56000.00
711903	2017-08-09 18:59:00+03	28800.00
7119AE	2017-08-07 19:34:00+03	13600.00
7119CE	2017-07-20 12:31:00+03	36200.00
711A25	2017-07-22 19:34:00+03	133200.00
711A40	2017-08-12 23:40:00+03	266400.00
711A70	2017-08-03 12:40:00+03	36400.00
711B1B	2017-08-11 10:03:00+03	59800.00
711B91	2017-08-09 11:49:00+03	266400.00
711BAC	2017-08-11 03:20:00+03	52400.00
711BDA	2017-07-05 08:21:00+03	27200.00
711C5C	2017-08-09 16:32:00+03	182400.00
711CFF	2017-07-14 22:13:00+03	66600.00
711D0F	2017-07-06 20:44:00+03	112000.00
711D16	2017-08-15 16:52:00+03	180000.00
711D41	2017-07-13 12:05:00+03	27400.00
711D96	2017-07-07 21:27:00+03	20200.00
711DA4	2017-08-11 19:52:00+03	83600.00
711DDA	2017-08-14 07:03:00+03	72700.00
711DF3	2017-08-01 03:00:00+03	9200.00
711E15	2017-07-28 13:37:00+03	46500.00
711E39	2017-07-26 00:33:00+03	40600.00
711E88	2017-07-05 01:16:00+03	36200.00
711E9B	2017-07-15 16:13:00+03	62700.00
711E9F	2017-07-06 18:50:00+03	19800.00
711EA3	2017-07-03 05:02:00+03	175000.00
711EDC	2017-07-09 07:54:00+03	73400.00
711F2F	2017-07-03 04:48:00+03	265700.00
711F79	2017-07-04 22:06:00+03	16000.00
71209E	2017-08-15 02:45:00+03	40800.00
7120E0	2017-07-12 22:03:00+03	52000.00
7120E6	2017-08-02 04:18:00+03	54500.00
7120EF	2017-07-23 11:35:00+03	24700.00
712116	2017-08-10 23:50:00+03	44800.00
712204	2017-08-03 17:05:00+03	130200.00
7122C4	2017-07-28 04:57:00+03	26000.00
7122CA	2017-07-13 10:57:00+03	14400.00
71234A	2017-08-01 10:14:00+03	532800.00
712363	2017-07-18 15:44:00+03	69500.00
712401	2017-07-30 18:07:00+03	57400.00
7124CD	2017-08-01 16:37:00+03	106800.00
7124D1	2017-07-28 16:10:00+03	76600.00
7124ED	2017-07-18 21:11:00+03	39300.00
7124FB	2017-07-18 13:15:00+03	62900.00
712513	2017-07-26 01:20:00+03	23200.00
71257C	2017-07-13 02:53:00+03	19600.00
7125A7	2017-08-05 12:25:00+03	56900.00
712678	2017-08-09 03:06:00+03	28000.00
712705	2017-07-26 19:54:00+03	27300.00
71276B	2017-07-19 10:00:00+03	38600.00
7127A8	2017-07-04 19:48:00+03	12600.00
7127BF	2017-07-20 18:03:00+03	68100.00
712801	2017-08-02 16:37:00+03	7200.00
712803	2017-07-28 02:49:00+03	59800.00
712818	2017-08-11 17:42:00+03	19600.00
71281F	2017-07-08 09:50:00+03	393300.00
71282E	2017-07-15 14:45:00+03	117600.00
71288F	2017-07-02 11:42:00+03	44800.00
7128C0	2017-08-11 09:13:00+03	6600.00
712901	2017-07-17 09:44:00+03	15400.00
712920	2017-08-14 19:53:00+03	28800.00
71297C	2017-07-10 19:20:00+03	108900.00
712993	2017-07-20 15:28:00+03	55800.00
712995	2017-07-31 10:54:00+03	28000.00
71299A	2017-08-01 17:28:00+03	23400.00
7129F7	2017-07-02 08:19:00+03	18800.00
712AC8	2017-07-11 18:00:00+03	19600.00
712AE7	2017-07-17 20:38:00+03	71200.00
712B00	2017-07-08 06:17:00+03	85000.00
712B4C	2017-07-14 12:46:00+03	13600.00
712B57	2017-08-11 00:46:00+03	112100.00
712B7B	2017-07-18 19:22:00+03	45000.00
712BAB	2017-08-07 20:41:00+03	6800.00
712BAE	2017-08-07 11:16:00+03	55800.00
712BEC	2017-07-11 03:23:00+03	17200.00
712D13	2017-07-04 04:21:00+03	131600.00
712D3F	2017-07-30 18:46:00+03	115600.00
712DAB	2017-07-16 10:19:00+03	14900.00
712DF2	2017-08-09 05:40:00+03	55800.00
712E2F	2017-07-13 13:27:00+03	47000.00
712E31	2017-08-08 18:17:00+03	119600.00
712E37	2017-08-11 13:43:00+03	31400.00
712E4F	2017-07-20 04:17:00+03	135400.00
712E79	2017-07-10 06:16:00+03	90700.00
712EA1	2017-07-28 08:42:00+03	92800.00
712EA4	2017-07-08 18:30:00+03	86800.00
712F32	2017-07-31 16:31:00+03	66600.00
712F43	2017-08-05 04:49:00+03	106800.00
712F8C	2017-07-17 15:40:00+03	6300.00
712FDA	2017-07-11 00:11:00+03	185300.00
712FE5	2017-08-06 02:45:00+03	47200.00
713006	2017-08-01 19:19:00+03	44400.00
713066	2017-07-16 21:51:00+03	39800.00
7130B7	2017-08-01 07:15:00+03	74100.00
7130C7	2017-08-06 07:41:00+03	109500.00
71314E	2017-08-14 06:33:00+03	62000.00
713192	2017-08-08 22:44:00+03	67600.00
7131AC	2017-07-22 08:14:00+03	40800.00
7131C5	2017-06-30 14:18:00+03	46900.00
7131D3	2017-07-28 23:57:00+03	496700.00
7131E2	2017-08-04 18:59:00+03	43600.00
7131E4	2017-07-19 21:20:00+03	26000.00
7131EA	2017-07-31 09:00:00+03	39300.00
71327F	2017-07-22 01:00:00+03	16000.00
7132A1	2017-07-15 14:18:00+03	44800.00
7132A9	2017-07-31 00:24:00+03	301800.00
7132F3	2017-08-15 11:01:00+03	131600.00
71331E	2017-07-29 02:49:00+03	46900.00
713356	2017-07-02 01:50:00+03	40000.00
71335F	2017-07-10 11:21:00+03	23600.00
7133B3	2017-06-30 12:29:00+03	92900.00
7133FE	2017-07-21 22:21:00+03	29400.00
71346D	2017-08-13 15:05:00+03	29800.00
713518	2017-08-09 17:00:00+03	29300.00
713567	2017-07-13 12:11:00+03	105100.00
7135ED	2017-07-20 08:33:00+03	44300.00
713676	2017-07-15 12:12:00+03	85000.00
713697	2017-07-28 21:48:00+03	43200.00
713735	2017-07-14 22:37:00+03	57600.00
71376C	2017-08-14 12:30:00+03	137700.00
713806	2017-08-07 22:07:00+03	20200.00
713813	2017-07-31 12:57:00+03	67200.00
71382C	2017-08-02 05:09:00+03	51600.00
7138BF	2017-07-08 10:30:00+03	39800.00
7138D7	2017-08-12 19:55:00+03	6000.00
7138DB	2017-08-02 14:45:00+03	44400.00
7138EA	2017-08-01 12:09:00+03	25400.00
71398E	2017-06-27 01:47:00+03	12600.00
71399E	2017-07-27 00:01:00+03	22000.00
7139AD	2017-08-14 02:16:00+03	34000.00
7139B4	2017-08-07 00:35:00+03	31200.00
7139E6	2017-07-08 06:28:00+03	239100.00
713A09	2017-08-09 23:01:00+03	50600.00
713B5C	2017-07-09 17:14:00+03	56000.00
713C4A	2017-08-10 19:06:00+03	48800.00
713C67	2017-08-07 06:51:00+03	95200.00
713CCE	2017-08-15 14:52:00+03	21400.00
713DCE	2017-07-11 07:22:00+03	72400.00
713DE2	2017-08-05 07:00:00+03	38800.00
713E3E	2017-06-27 18:15:00+03	121800.00
713E50	2017-08-05 07:25:00+03	97900.00
713E7D	2017-07-26 18:35:00+03	239100.00
713EA6	2017-07-29 00:09:00+03	112000.00
713F16	2017-08-06 14:03:00+03	71900.00
713F22	2017-07-24 01:07:00+03	119600.00
713F4B	2017-07-24 13:42:00+03	40800.00
713F70	2017-07-05 14:42:00+03	29600.00
713F82	2017-07-13 20:46:00+03	99200.00
713FEB	2017-08-11 00:11:00+03	23200.00
713FF4	2017-08-11 05:06:00+03	311200.00
714019	2017-08-06 06:02:00+03	26400.00
714058	2017-07-30 14:54:00+03	62800.00
71407C	2017-06-29 06:10:00+03	111600.00
714110	2017-07-22 17:43:00+03	75200.00
71414A	2017-08-05 11:00:00+03	46200.00
7141AF	2017-07-09 05:43:00+03	56000.00
7141C3	2017-07-15 00:51:00+03	111600.00
7141CD	2017-07-27 07:59:00+03	80800.00
7142A8	2017-06-26 12:52:00+03	27600.00
7142D2	2017-07-11 06:07:00+03	14000.00
7142F7	2017-07-29 02:01:00+03	46500.00
71430A	2017-07-14 15:42:00+03	90100.00
71433B	2017-08-05 00:50:00+03	21800.00
71434E	2017-07-28 12:21:00+03	8200.00
714370	2017-07-16 00:20:00+03	27200.00
7143BC	2017-07-26 10:56:00+03	141600.00
714419	2017-08-08 08:39:00+03	62200.00
714431	2017-08-08 00:40:00+03	56000.00
7144AA	2017-07-07 03:18:00+03	48800.00
714580	2017-07-07 05:33:00+03	69500.00
7145C6	2017-07-17 01:03:00+03	6800.00
7145D3	2017-07-25 19:55:00+03	70800.00
714625	2017-07-12 01:35:00+03	68400.00
71466A	2017-07-06 11:02:00+03	45100.00
71469C	2017-07-13 05:33:00+03	31600.00
714716	2017-07-09 18:08:00+03	46400.00
71473A	2017-07-14 12:44:00+03	166100.00
7147B6	2017-08-08 04:32:00+03	91600.00
7147C1	2017-08-07 07:01:00+03	27800.00
714829	2017-07-06 07:52:00+03	18000.00
71483B	2017-07-31 09:49:00+03	73400.00
71484C	2017-08-15 01:47:00+03	37400.00
71485C	2017-07-17 20:42:00+03	23600.00
71487B	2017-08-07 20:40:00+03	16400.00
71487F	2017-07-15 15:13:00+03	65100.00
7148A6	2017-07-22 08:00:00+03	26000.00
7148D6	2017-08-15 10:17:00+03	21400.00
7148DA	2017-07-14 19:38:00+03	73600.00
7148ED	2017-08-06 05:40:00+03	201800.00
714948	2017-07-08 10:41:00+03	38600.00
714AAD	2017-08-02 14:34:00+03	124200.00
714AAF	2017-07-14 17:41:00+03	99200.00
714ACF	2017-07-25 20:27:00+03	37100.00
714ADC	2017-07-13 01:42:00+03	44000.00
714B17	2017-08-06 16:58:00+03	6800.00
714B4F	2017-07-21 00:32:00+03	8200.00
714B5D	2017-07-26 08:45:00+03	28800.00
714BCD	2017-07-24 20:58:00+03	137600.00
714C1E	2017-07-30 03:33:00+03	24800.00
714C39	2017-08-10 03:57:00+03	93000.00
714C5C	2017-08-15 06:01:00+03	18600.00
714D1D	2017-07-19 18:42:00+03	28800.00
714D31	2017-07-13 12:05:00+03	82900.00
714D5A	2017-06-30 03:12:00+03	135700.00
714D5D	2017-08-04 23:49:00+03	6700.00
714D7B	2017-07-30 17:59:00+03	66100.00
714DAC	2017-07-07 22:02:00+03	16400.00
714DDF	2017-07-30 02:58:00+03	67100.00
714E40	2017-07-28 09:50:00+03	30900.00
714F06	2017-08-11 13:28:00+03	282000.00
714FB8	2017-07-09 11:19:00+03	13600.00
714FBA	2017-07-28 20:26:00+03	46400.00
714FD4	2017-07-17 20:38:00+03	57800.00
715019	2017-08-12 01:11:00+03	103200.00
71503A	2017-07-03 12:13:00+03	51900.00
71505F	2017-08-01 19:49:00+03	208100.00
71506B	2017-07-06 23:21:00+03	8800.00
7150CA	2017-08-06 21:23:00+03	76700.00
7150ED	2017-08-09 07:19:00+03	31700.00
71512D	2017-07-14 12:12:00+03	29600.00
715186	2017-06-28 22:38:00+03	26200.00
715194	2017-08-14 20:33:00+03	86800.00
7151A0	2017-08-10 05:15:00+03	199700.00
7151DF	2017-07-18 17:29:00+03	46000.00
7151FD	2017-08-06 20:04:00+03	133100.00
715240	2017-08-06 22:48:00+03	106400.00
715291	2017-08-12 12:30:00+03	23600.00
7152F9	2017-07-14 22:10:00+03	372500.00
71532E	2017-06-29 18:23:00+03	44000.00
715359	2017-08-11 01:00:00+03	23200.00
715369	2017-08-14 05:43:00+03	136000.00
7153DF	2017-07-27 01:55:00+03	56000.00
715403	2017-08-11 19:09:00+03	26000.00
715476	2017-07-03 11:07:00+03	226900.00
7154D1	2017-08-01 17:05:00+03	25200.00
71552A	2017-07-10 08:40:00+03	31200.00
71555E	2017-07-27 21:46:00+03	28000.00
715586	2017-08-10 14:44:00+03	32700.00
7155BC	2017-07-05 08:26:00+03	55800.00
7155C1	2017-07-24 11:44:00+03	262600.00
715607	2017-08-05 13:56:00+03	229300.00
715632	2017-07-19 16:29:00+03	12100.00
715647	2017-06-26 05:23:00+03	46000.00
715670	2017-08-13 13:42:00+03	48800.00
71567A	2017-08-03 20:19:00+03	40800.00
7156AC	2017-08-13 06:26:00+03	372500.00
715729	2017-07-31 13:29:00+03	19800.00
7157F5	2017-08-15 07:51:00+03	10800.00
71586D	2017-07-01 22:15:00+03	40800.00
71587A	2017-07-31 16:46:00+03	32700.00
7158F6	2017-07-05 05:14:00+03	42800.00
71597E	2017-07-19 11:06:00+03	12400.00
715997	2017-07-31 10:27:00+03	190400.00
7159DF	2017-07-28 06:00:00+03	49300.00
715A85	2017-08-15 12:43:00+03	19600.00
715A88	2017-06-29 07:15:00+03	75600.00
715AD5	2017-07-08 21:20:00+03	38800.00
715ADE	2017-07-07 14:06:00+03	30200.00
715AFE	2017-08-06 22:51:00+03	19600.00
715BCD	2017-06-30 07:02:00+03	16400.00
715BD7	2017-08-03 01:20:00+03	38800.00
715BEF	2017-07-07 06:37:00+03	57500.00
715C53	2017-07-04 11:09:00+03	213200.00
715C9B	2017-06-27 03:17:00+03	46400.00
715CC5	2017-07-19 08:08:00+03	46500.00
715D15	2017-06-30 11:31:00+03	56900.00
715D65	2017-07-19 08:27:00+03	42800.00
715DB2	2017-07-11 20:13:00+03	133200.00
715DD1	2017-07-25 02:19:00+03	266400.00
715E32	2017-07-16 15:36:00+03	52900.00
715E79	2017-07-03 05:22:00+03	23100.00
715E81	2017-07-14 09:49:00+03	8000.00
715E8F	2017-08-11 05:19:00+03	14000.00
715F06	2017-08-11 08:23:00+03	6700.00
715F2A	2017-07-24 20:00:00+03	26000.00
715F45	2017-07-26 22:49:00+03	16400.00
715F87	2017-08-08 13:08:00+03	113800.00
715FBB	2017-07-02 17:16:00+03	66200.00
71607F	2017-07-16 09:17:00+03	135000.00
7160B4	2017-08-06 00:04:00+03	8000.00
7160F3	2017-07-02 09:37:00+03	59900.00
716123	2017-06-27 03:25:00+03	56000.00
716166	2017-07-12 08:59:00+03	155600.00
716275	2017-07-26 02:45:00+03	59500.00
7162BB	2017-08-13 06:38:00+03	38800.00
716314	2017-08-03 22:01:00+03	132800.00
7163AC	2017-08-08 02:45:00+03	29000.00
71645A	2017-07-03 23:45:00+03	124200.00
7164A2	2017-07-29 00:01:00+03	155600.00
7164AE	2017-07-03 10:13:00+03	191000.00
71650F	2017-07-20 08:38:00+03	132800.00
7165A3	2017-07-01 15:36:00+03	103600.00
7165AB	2017-07-18 15:22:00+03	179200.00
7165C0	2017-07-18 05:29:00+03	66600.00
7165E6	2017-07-23 15:16:00+03	102100.00
71660E	2017-08-11 09:53:00+03	75700.00
71661F	2017-07-09 09:49:00+03	103500.00
716647	2017-08-13 09:17:00+03	7400.00
71666F	2017-07-16 05:27:00+03	6300.00
7166A1	2017-08-14 14:15:00+03	15000.00
7166D6	2017-07-20 23:33:00+03	48800.00
716705	2017-08-03 04:15:00+03	23100.00
71673B	2017-08-13 01:04:00+03	59300.00
7167C5	2017-07-13 22:34:00+03	151200.00
71687C	2017-07-22 02:19:00+03	55800.00
7168B4	2017-08-04 20:24:00+03	29100.00
7168CC	2017-07-31 15:48:00+03	155600.00
71690D	2017-07-26 23:33:00+03	248300.00
71692D	2017-08-14 18:06:00+03	20400.00
71693D	2017-08-15 00:25:00+03	25200.00
716961	2017-08-08 16:58:00+03	37100.00
71696F	2017-07-25 13:15:00+03	66600.00
716996	2017-07-27 20:23:00+03	106400.00
716997	2017-07-03 20:45:00+03	26800.00
7169C8	2017-07-23 07:08:00+03	68800.00
7169D2	2017-08-10 08:49:00+03	42800.00
7169E1	2017-07-04 13:40:00+03	47200.00
716A0F	2017-07-04 15:22:00+03	129000.00
716A1A	2017-08-04 15:23:00+03	133200.00
716A27	2017-08-14 08:27:00+03	10100.00
716A47	2017-07-30 10:02:00+03	219300.00
716A8C	2017-07-10 18:27:00+03	48800.00
716AD8	2017-07-29 16:59:00+03	50700.00
716B27	2017-07-05 19:10:00+03	33400.00
716B56	2017-07-12 13:19:00+03	133200.00
716C2D	2017-08-11 08:03:00+03	77000.00
716C98	2017-07-01 10:38:00+03	28000.00
716D0E	2017-08-11 05:01:00+03	50400.00
716D2A	2017-07-26 08:43:00+03	187600.00
716D83	2017-08-10 16:44:00+03	25400.00
716D96	2017-08-07 11:01:00+03	54400.00
716DA2	2017-07-19 22:45:00+03	179400.00
716DA7	2017-07-09 08:53:00+03	119700.00
716DCA	2017-08-10 23:25:00+03	44600.00
716E1C	2017-07-17 23:23:00+03	87700.00
716EA1	2017-07-17 15:04:00+03	81600.00
716EAD	2017-08-09 06:46:00+03	46000.00
716EB2	2017-07-14 05:29:00+03	9800.00
716EE1	2017-07-09 07:53:00+03	132800.00
716F4D	2017-08-08 14:11:00+03	133200.00
716F79	2017-07-13 21:26:00+03	353700.00
716FD2	2017-07-27 18:19:00+03	39300.00
717014	2017-07-01 11:48:00+03	35100.00
717022	2017-07-05 13:10:00+03	132800.00
71703B	2017-07-31 09:05:00+03	16400.00
717048	2017-07-15 06:56:00+03	16400.00
71707B	2017-08-14 06:10:00+03	52800.00
717097	2017-08-01 01:31:00+03	89600.00
717112	2017-07-04 07:30:00+03	34000.00
717116	2017-07-15 03:53:00+03	24400.00
71720B	2017-07-14 18:36:00+03	70700.00
71722C	2017-07-29 14:29:00+03	36400.00
7172A9	2017-08-11 10:06:00+03	22400.00
717382	2017-08-11 04:35:00+03	136200.00
717387	2017-07-10 06:36:00+03	123000.00
7173D6	2017-08-14 00:42:00+03	67200.00
7173E7	2017-08-11 00:28:00+03	76600.00
71744A	2017-07-10 05:03:00+03	23400.00
7174B5	2017-07-22 00:56:00+03	26000.00
7174DC	2017-07-03 08:38:00+03	99200.00
717532	2017-07-07 13:15:00+03	92800.00
717577	2017-07-01 13:42:00+03	135600.00
7175C8	2017-08-05 13:01:00+03	44000.00
717612	2017-08-04 22:25:00+03	27300.00
717655	2017-07-20 11:05:00+03	87000.00
717680	2017-08-15 09:54:00+03	164600.00
7176DE	2017-07-31 06:41:00+03	88200.00
717712	2017-07-13 17:36:00+03	23200.00
71774A	2017-07-19 05:50:00+03	7200.00
71774F	2017-07-17 19:20:00+03	13600.00
71776A	2017-07-10 08:20:00+03	31100.00
7177A0	2017-08-09 20:11:00+03	47200.00
717800	2017-07-24 13:24:00+03	14400.00
717801	2017-07-10 17:11:00+03	22400.00
717857	2017-07-23 18:17:00+03	61700.00
717899	2017-07-03 02:50:00+03	27300.00
7178B3	2017-07-01 23:58:00+03	65900.00
71797B	2017-08-07 15:26:00+03	405600.00
717982	2017-07-21 17:28:00+03	86400.00
7179A6	2017-07-13 00:06:00+03	27200.00
717A75	2017-07-15 05:04:00+03	167400.00
717AAA	2017-08-10 14:07:00+03	77700.00
717AD3	2017-08-06 23:00:00+03	38800.00
717AE9	2017-08-13 12:13:00+03	46400.00
717B40	2017-07-11 18:40:00+03	73200.00
717B8C	2017-08-02 14:20:00+03	36400.00
717BBA	2017-07-15 18:28:00+03	34000.00
717BEB	2017-07-14 18:29:00+03	64700.00
717C34	2017-07-16 13:58:00+03	129200.00
717CAE	2017-07-12 23:02:00+03	75300.00
717CED	2017-08-10 16:18:00+03	12400.00
717D1B	2017-07-08 00:55:00+03	32800.00
717D20	2017-07-23 19:58:00+03	269600.00
717D44	2017-07-19 09:15:00+03	70700.00
717DC6	2017-07-14 19:26:00+03	92800.00
717DED	2017-07-15 03:01:00+03	59800.00
717DFD	2017-08-08 04:38:00+03	218800.00
717E01	2017-07-11 04:14:00+03	51800.00
717E78	2017-07-07 00:30:00+03	38600.00
717E97	2017-07-12 18:38:00+03	6800.00
717EC4	2017-07-21 20:55:00+03	24400.00
717EE5	2017-08-11 11:52:00+03	12100.00
717F15	2017-07-30 04:38:00+03	28000.00
717F16	2017-07-21 02:27:00+03	12600.00
717F21	2017-07-19 11:54:00+03	21800.00
717F79	2017-06-30 19:57:00+03	300600.00
717F9C	2017-07-03 10:14:00+03	132800.00
718019	2017-08-02 15:19:00+03	27200.00
718098	2017-08-08 11:25:00+03	38500.00
7180B2	2017-07-24 10:17:00+03	391000.00
7180D3	2017-07-16 01:31:00+03	4000.00
71811E	2017-07-24 21:23:00+03	77700.00
718135	2017-07-26 00:30:00+03	136800.00
7181A4	2017-07-30 16:20:00+03	54800.00
7181BC	2017-07-28 23:19:00+03	117200.00
71820E	2017-08-12 18:52:00+03	65200.00
718281	2017-07-30 07:22:00+03	15000.00
71833D	2017-07-30 17:10:00+03	97800.00
7183BB	2017-07-21 22:33:00+03	56000.00
7183E7	2017-07-15 03:09:00+03	62000.00
718430	2017-07-22 11:55:00+03	31600.00
718431	2017-08-15 12:06:00+03	8400.00
718434	2017-07-27 13:20:00+03	405000.00
718435	2017-06-23 23:05:00+03	10800.00
71843A	2017-08-13 15:47:00+03	267100.00
71846A	2017-07-22 19:57:00+03	16400.00
71847B	2017-07-28 04:33:00+03	88600.00
718550	2017-07-17 14:52:00+03	95600.00
71858B	2017-07-26 17:34:00+03	12600.00
7185BF	2017-08-04 04:42:00+03	119500.00
71860B	2017-08-06 06:49:00+03	47000.00
71867F	2017-07-01 09:09:00+03	169200.00
718682	2017-08-07 10:47:00+03	86800.00
71868D	2017-06-29 03:13:00+03	60400.00
71869E	2017-08-02 10:34:00+03	168000.00
7186B2	2017-07-18 14:01:00+03	73900.00
718717	2017-07-03 03:35:00+03	112400.00
718742	2017-07-08 11:09:00+03	109800.00
718747	2017-07-04 17:19:00+03	116400.00
71876A	2017-07-15 07:05:00+03	80400.00
7187B9	2017-07-15 19:21:00+03	29600.00
718802	2017-07-09 13:41:00+03	6700.00
718823	2017-08-12 07:57:00+03	156300.00
718879	2017-07-13 09:51:00+03	21800.00
7188B6	2017-07-26 08:41:00+03	111600.00
7188EA	2017-08-01 23:05:00+03	26000.00
71892F	2017-08-14 02:17:00+03	96800.00
71895E	2017-07-06 17:18:00+03	121800.00
7189A1	2017-07-07 00:18:00+03	32000.00
7189A3	2017-07-29 07:11:00+03	86400.00
7189CC	2017-07-02 00:57:00+03	68800.00
7189FF	2017-07-29 06:21:00+03	48100.00
718A17	2017-08-14 05:26:00+03	79700.00
718AAB	2017-07-19 15:49:00+03	110600.00
718AE3	2017-07-29 05:09:00+03	169400.00
718B54	2017-07-16 18:45:00+03	54800.00
718B75	2017-08-06 16:43:00+03	56000.00
718B76	2017-08-07 14:43:00+03	85000.00
718BD9	2017-07-24 13:53:00+03	43900.00
718BEF	2017-07-12 05:38:00+03	60400.00
718C0C	2017-08-14 13:01:00+03	14400.00
718C2E	2017-07-08 13:27:00+03	22000.00
718C39	2017-07-21 23:58:00+03	75600.00
718C69	2017-08-11 09:49:00+03	477500.00
718C91	2017-08-11 08:21:00+03	65400.00
718C9C	2017-08-08 16:10:00+03	28800.00
718CC4	2017-07-11 20:53:00+03	17600.00
718CCE	2017-07-13 09:00:00+03	6700.00
718CD6	2017-07-27 07:33:00+03	95800.00
718D2D	2017-07-19 17:14:00+03	28000.00
718D4B	2017-07-08 01:09:00+03	39500.00
718D80	2017-07-12 11:24:00+03	54800.00
718EAF	2017-07-29 19:44:00+03	28000.00
718EB4	2017-08-09 21:25:00+03	73600.00
718EB8	2017-08-15 16:18:00+03	17400.00
718F0E	2017-08-14 15:36:00+03	68000.00
718F16	2017-07-18 17:09:00+03	52400.00
718F30	2017-08-04 00:31:00+03	119500.00
718F51	2017-07-10 07:39:00+03	95600.00
718F6B	2017-07-11 16:22:00+03	101200.00
718F6F	2017-07-23 17:17:00+03	81600.00
718FF0	2017-07-11 17:38:00+03	69500.00
71901D	2017-08-11 16:49:00+03	41200.00
71903A	2017-08-14 16:45:00+03	29400.00
7190B3	2017-08-02 19:49:00+03	103500.00
7190F3	2017-07-10 12:36:00+03	16400.00
71910F	2017-08-06 17:56:00+03	117000.00
719116	2017-06-28 04:55:00+03	31400.00
719161	2017-07-18 18:56:00+03	123000.00
719179	2017-08-15 01:31:00+03	26600.00
7191E8	2017-07-30 07:56:00+03	157100.00
719250	2017-07-16 16:43:00+03	44000.00
7192BC	2017-07-27 04:45:00+03	20200.00
71930D	2017-08-14 16:45:00+03	45200.00
719320	2017-08-11 09:02:00+03	64800.00
719325	2017-07-26 20:28:00+03	25600.00
719359	2017-08-12 20:08:00+03	34200.00
719373	2017-07-10 18:28:00+03	19600.00
719397	2017-08-07 03:57:00+03	90000.00
7193D2	2017-07-12 02:18:00+03	55800.00
7193EE	2017-08-15 05:04:00+03	61200.00
719434	2017-07-13 09:19:00+03	32200.00
71944B	2017-07-28 02:27:00+03	64700.00
71946C	2017-07-05 05:54:00+03	532800.00
7194E3	2017-08-15 16:49:00+03	14300.00
719579	2017-08-13 03:12:00+03	10700.00
719641	2017-08-02 20:52:00+03	41300.00
719647	2017-07-04 03:53:00+03	131100.00
719650	2017-08-04 22:39:00+03	66100.00
71968A	2017-07-09 12:18:00+03	37100.00
71970A	2017-07-28 04:39:00+03	86000.00
71973A	2017-08-06 11:38:00+03	6900.00
7197DB	2017-08-13 22:36:00+03	11000.00
719846	2017-07-28 11:28:00+03	27200.00
719933	2017-07-18 16:02:00+03	199300.00
719972	2017-07-05 04:00:00+03	52800.00
7199AA	2017-07-22 05:55:00+03	29800.00
7199D2	2017-08-05 21:48:00+03	37600.00
7199FD	2017-07-15 13:02:00+03	492000.00
719A0A	2017-06-29 00:46:00+03	125200.00
719A11	2017-07-16 02:10:00+03	14800.00
719A33	2017-07-01 09:29:00+03	100600.00
719AAA	2017-08-14 00:03:00+03	99200.00
719AC0	2017-08-04 07:43:00+03	45200.00
719AE2	2017-07-30 23:45:00+03	160400.00
719B33	2017-08-12 05:33:00+03	26700.00
719B82	2017-08-11 21:14:00+03	40100.00
719BBD	2017-08-03 22:19:00+03	153200.00
719BC1	2017-07-21 18:39:00+03	34400.00
719BCF	2017-07-22 06:00:00+03	40800.00
719BFC	2017-07-07 16:59:00+03	113000.00
719C10	2017-08-14 00:02:00+03	28800.00
719C7F	2017-07-26 03:28:00+03	27200.00
719CBC	2017-07-13 22:36:00+03	46800.00
719CC4	2017-07-14 03:23:00+03	43200.00
719D45	2017-07-05 10:35:00+03	55800.00
719D61	2017-07-04 04:04:00+03	37100.00
719DB9	2017-08-10 01:56:00+03	46000.00
719DFC	2017-08-08 18:46:00+03	58000.00
719E19	2017-07-12 14:55:00+03	96800.00
719E1C	2017-08-09 08:14:00+03	271200.00
719E7E	2017-07-08 18:50:00+03	44500.00
719E83	2017-07-06 09:10:00+03	26000.00
719E91	2017-08-02 00:29:00+03	26800.00
719E94	2017-07-19 20:04:00+03	28000.00
719EA5	2017-06-30 23:32:00+03	13200.00
719EAF	2017-07-05 14:02:00+03	44800.00
719EBE	2017-08-09 08:33:00+03	54300.00
719EFE	2017-07-12 07:59:00+03	100600.00
719F39	2017-07-28 11:31:00+03	90000.00
719F99	2017-08-01 13:27:00+03	8000.00
71A023	2017-08-12 20:06:00+03	128600.00
71A066	2017-08-05 12:58:00+03	31600.00
71A0A7	2017-08-14 23:52:00+03	81600.00
71A0C1	2017-07-27 20:00:00+03	31400.00
71A180	2017-07-27 22:03:00+03	100000.00
71A1A9	2017-08-11 11:43:00+03	57500.00
71A22D	2017-07-09 14:08:00+03	31800.00
71A278	2017-08-07 09:28:00+03	260300.00
71A2A1	2017-07-31 23:50:00+03	100600.00
71A2E6	2017-08-15 16:39:00+03	40800.00
71A319	2017-07-04 19:30:00+03	116900.00
71A32E	2017-07-11 20:29:00+03	133700.00
71A38B	2017-08-12 14:06:00+03	54400.00
71A493	2017-08-03 19:38:00+03	112600.00
71A4C9	2017-07-03 22:37:00+03	101200.00
71A4E8	2017-07-24 15:54:00+03	80700.00
71A531	2017-08-07 09:33:00+03	11800.00
71A56A	2017-08-04 10:45:00+03	49900.00
71A5FD	2017-07-22 18:09:00+03	73200.00
71A615	2017-08-11 08:24:00+03	75300.00
71A640	2017-07-07 06:45:00+03	43200.00
71A65B	2017-07-05 01:50:00+03	67600.00
71A674	2017-07-27 14:04:00+03	183300.00
71A680	2017-07-25 07:53:00+03	90700.00
71A6EE	2017-08-07 14:55:00+03	100800.00
71A720	2017-08-03 11:29:00+03	46700.00
71A784	2017-07-20 04:29:00+03	69600.00
71A7BB	2017-07-30 00:11:00+03	133200.00
71A7F3	2017-07-29 09:55:00+03	144400.00
71A890	2017-07-08 10:21:00+03	149200.00
71A8C4	2017-07-15 21:22:00+03	42800.00
71A9FF	2017-08-08 14:57:00+03	6000.00
71AA0E	2017-07-14 18:46:00+03	46400.00
71AA30	2017-07-14 01:44:00+03	59100.00
71AA74	2017-07-08 03:35:00+03	124600.00
71AABE	2017-07-27 20:37:00+03	72200.00
71AAD2	2017-07-22 05:55:00+03	50700.00
71AB0C	2017-07-07 04:42:00+03	75300.00
71AB4C	2017-08-05 12:11:00+03	78700.00
71AB92	2017-08-12 18:48:00+03	246000.00
71AC04	2017-07-30 06:39:00+03	62600.00
71AC83	2017-08-14 07:25:00+03	49200.00
71AC85	2017-07-19 03:25:00+03	64700.00
71AC86	2017-07-04 20:49:00+03	86600.00
71AC9B	2017-08-12 19:11:00+03	29400.00
71ACC8	2017-07-14 02:59:00+03	31100.00
71ACE6	2017-07-29 21:50:00+03	88000.00
71AD4B	2017-07-01 00:46:00+03	148700.00
71ADD2	2017-08-07 18:17:00+03	84200.00
71ADE6	2017-07-27 09:07:00+03	14400.00
71ADEC	2017-08-04 13:48:00+03	28000.00
71AE62	2017-07-16 07:19:00+03	21800.00
71AE91	2017-08-10 09:32:00+03	99800.00
71AEE3	2017-07-15 23:23:00+03	22000.00
71AF10	2017-07-01 09:10:00+03	62600.00
71AF65	2017-08-13 05:49:00+03	52900.00
71AF9A	2017-07-06 05:13:00+03	62000.00
71AFA3	2017-07-03 01:00:00+03	13400.00
71AFAE	2017-07-02 13:41:00+03	25100.00
71AFC4	2017-08-01 14:42:00+03	138000.00
71AFC7	2017-07-27 13:31:00+03	13400.00
71B0BB	2017-07-29 23:33:00+03	28000.00
71B111	2017-07-13 19:46:00+03	14000.00
71B11A	2017-08-15 16:41:00+03	62400.00
71B12F	2017-07-30 05:52:00+03	56000.00
71B15A	2017-07-04 17:13:00+03	34000.00
71B16E	2017-07-24 19:31:00+03	56000.00
71B1CF	2017-07-09 14:54:00+03	94900.00
71B1FD	2017-07-15 00:03:00+03	112000.00
71B200	2017-07-09 16:01:00+03	46400.00
71B36C	2017-07-18 04:46:00+03	44600.00
71B39B	2017-07-10 18:11:00+03	18000.00
71B3BE	2017-08-01 00:27:00+03	56000.00
71B3DC	2017-07-23 15:28:00+03	28000.00
71B3FA	2017-07-24 22:37:00+03	53700.00
71B468	2017-07-18 07:10:00+03	182000.00
71B4D0	2017-07-27 12:46:00+03	148200.00
71B4F6	2017-08-09 11:31:00+03	75600.00
71B50F	2017-08-06 09:07:00+03	48800.00
71B581	2017-07-13 09:41:00+03	62800.00
71B621	2017-07-22 09:35:00+03	13200.00
71B679	2017-07-25 00:55:00+03	64700.00
71B684	2017-07-16 08:46:00+03	48200.00
71B735	2017-07-22 22:10:00+03	39300.00
71B7EF	2017-07-20 08:53:00+03	62800.00
71B821	2017-07-09 21:01:00+03	6000.00
71B84D	2017-07-01 21:40:00+03	56100.00
71B878	2017-07-28 14:24:00+03	27300.00
71B932	2017-07-06 01:09:00+03	24300.00
71B9BB	2017-08-12 06:13:00+03	23200.00
71B9C5	2017-08-13 17:39:00+03	134800.00
71B9D9	2017-08-12 06:11:00+03	23900.00
71B9F6	2017-07-17 00:41:00+03	56900.00
71B9FF	2017-08-03 19:59:00+03	53600.00
71BA81	2017-08-03 08:09:00+03	13200.00
71BAC8	2017-07-11 07:27:00+03	31400.00
71BB41	2017-07-17 09:45:00+03	26300.00
71BB61	2017-07-18 18:54:00+03	39100.00
71BB82	2017-07-20 07:52:00+03	32800.00
71BB8A	2017-08-12 11:04:00+03	202100.00
71BB8F	2017-08-03 01:31:00+03	21500.00
71BBB6	2017-08-09 22:16:00+03	43000.00
71BC22	2017-07-24 23:59:00+03	73100.00
71BCC2	2017-07-20 19:17:00+03	111000.00
71BDA6	2017-07-07 15:54:00+03	66600.00
71BDFC	2017-08-06 19:14:00+03	179300.00
71BE4D	2017-07-03 03:40:00+03	56000.00
71BE6E	2017-07-22 09:30:00+03	40300.00
71BE8D	2017-07-18 06:31:00+03	112000.00
71BECD	2017-07-29 18:07:00+03	146300.00
71BF0F	2017-07-06 12:47:00+03	97000.00
71BF73	2017-08-02 23:58:00+03	38500.00
71BF7B	2017-07-22 00:10:00+03	29500.00
71C027	2017-08-03 06:31:00+03	54800.00
71C030	2017-07-11 15:20:00+03	112000.00
71C082	2017-06-29 21:19:00+03	48800.00
71C09F	2017-07-07 07:05:00+03	104300.00
71C0CF	2017-07-16 08:25:00+03	13600.00
71C156	2017-07-28 19:02:00+03	36200.00
71C206	2017-07-21 15:26:00+03	32200.00
71C238	2017-08-02 21:01:00+03	135300.00
71C244	2017-08-07 20:42:00+03	31600.00
71C259	2017-07-22 06:50:00+03	88400.00
71C2B3	2017-07-29 01:29:00+03	24800.00
71C2E1	2017-08-02 21:04:00+03	189800.00
71C301	2017-08-13 18:55:00+03	54100.00
71C346	2017-07-03 14:57:00+03	67600.00
71C3C3	2017-08-01 05:45:00+03	44700.00
71C3FA	2017-08-12 03:51:00+03	28000.00
71C40A	2017-07-19 11:57:00+03	106100.00
71C43F	2017-06-29 21:17:00+03	16400.00
71C44C	2017-07-26 06:56:00+03	14000.00
71C4C4	2017-07-26 16:31:00+03	119700.00
71C4D4	2017-08-06 09:38:00+03	135400.00
71C4F6	2017-07-06 11:27:00+03	108800.00
71C517	2017-08-13 22:38:00+03	70600.00
71C59B	2017-08-07 19:01:00+03	73600.00
71C5A2	2017-07-24 21:29:00+03	92800.00
71C62F	2017-07-13 18:44:00+03	28800.00
71C647	2017-08-06 06:22:00+03	48900.00
71C665	2017-07-01 14:40:00+03	37900.00
71C66E	2017-07-29 19:25:00+03	40000.00
71C70A	2017-07-07 04:21:00+03	193600.00
71C755	2017-07-20 00:37:00+03	123000.00
71C773	2017-07-16 05:14:00+03	14400.00
71C839	2017-08-02 00:33:00+03	24600.00
71C83C	2017-08-11 23:46:00+03	13600.00
71C84D	2017-07-29 19:58:00+03	398500.00
71C87C	2017-07-01 16:13:00+03	89600.00
71C8B0	2017-07-29 14:41:00+03	96300.00
71C90E	2017-07-23 04:45:00+03	48800.00
71C935	2017-08-12 05:37:00+03	58800.00
71C9EC	2017-07-29 08:15:00+03	40800.00
71C9F3	2017-08-04 23:08:00+03	6600.00
71CA32	2017-07-29 01:11:00+03	75300.00
71CA3C	2017-08-05 20:06:00+03	65900.00
71CACD	2017-07-15 08:09:00+03	22400.00
71CB58	2017-08-04 16:59:00+03	35600.00
71CB98	2017-07-10 14:18:00+03	65400.00
71CC4A	2017-07-17 13:36:00+03	56000.00
71CC4F	2017-08-10 05:05:00+03	24700.00
71CC57	2017-07-21 11:21:00+03	56600.00
71CD1C	2017-07-15 00:57:00+03	75600.00
71CD37	2017-08-02 16:27:00+03	52000.00
71CDA0	2017-08-11 16:20:00+03	24400.00
71CDEB	2017-08-07 14:58:00+03	81800.00
71CE46	2017-08-12 13:02:00+03	65500.00
71CE85	2017-07-19 07:16:00+03	93100.00
71CEA2	2017-08-03 23:47:00+03	28800.00
71CEDC	2017-08-06 11:40:00+03	12600.00
71CF07	2017-08-06 19:36:00+03	172200.00
71CF1A	2017-07-21 15:37:00+03	43100.00
71CF1B	2017-07-22 08:51:00+03	55800.00
71CF47	2017-07-13 02:48:00+03	62600.00
71CF87	2017-07-20 16:53:00+03	13000.00
71CFAE	2017-08-09 02:10:00+03	206700.00
71CFC4	2017-07-28 16:00:00+03	153200.00
71CFDB	2017-07-03 10:15:00+03	258400.00
71D004	2017-08-15 06:29:00+03	27400.00
71D057	2017-07-17 19:06:00+03	76600.00
71D0C3	2017-07-05 14:43:00+03	42400.00
71D0DD	2017-07-06 20:00:00+03	176500.00
71D0F4	2017-08-03 11:55:00+03	73300.00
71D15F	2017-07-22 13:43:00+03	336300.00
71D17C	2017-07-22 11:31:00+03	55800.00
71D17F	2017-07-12 23:42:00+03	56600.00
71D1E3	2017-06-30 16:38:00+03	14400.00
71D239	2017-07-04 14:27:00+03	7400.00
71D240	2017-07-07 03:19:00+03	136200.00
71D249	2017-08-08 10:13:00+03	86300.00
71D24E	2017-08-07 08:03:00+03	233000.00
71D26A	2017-07-24 09:59:00+03	56000.00
71D29F	2017-07-04 08:44:00+03	24400.00
71D2B8	2017-08-07 00:59:00+03	37200.00
71D2BD	2017-08-03 03:15:00+03	114600.00
71D355	2017-08-12 19:20:00+03	23500.00
71D37C	2017-07-20 16:07:00+03	63500.00
71D393	2017-08-10 22:45:00+03	79900.00
71D416	2017-07-25 17:51:00+03	59800.00
71D49C	2017-07-13 00:34:00+03	20000.00
71D4A2	2017-08-04 08:03:00+03	87200.00
71D4C4	2017-08-15 00:07:00+03	11600.00
71D4C8	2017-07-04 20:07:00+03	11800.00
71D4D2	2017-07-05 15:34:00+03	77700.00
71D557	2017-08-11 09:58:00+03	56000.00
71D591	2017-08-12 13:15:00+03	46000.00
71D59B	2017-07-29 01:50:00+03	54000.00
71D5CA	2017-07-14 00:53:00+03	25600.00
71D62F	2017-08-04 13:38:00+03	33200.00
71D640	2017-07-28 00:03:00+03	124300.00
71D662	2017-07-27 18:22:00+03	111600.00
71D67F	2017-06-26 14:54:00+03	80900.00
71D6A9	2017-07-08 02:08:00+03	40100.00
71D7B0	2017-07-29 11:21:00+03	56000.00
71D921	2017-07-27 01:19:00+03	132800.00
71D976	2017-08-14 20:01:00+03	69400.00
71D9C2	2017-07-29 14:25:00+03	73600.00
71D9F0	2017-08-14 07:28:00+03	161600.00
71DA15	2017-07-14 18:35:00+03	81900.00
71DA23	2017-08-10 07:54:00+03	47200.00
71DA9A	2017-08-05 05:40:00+03	17600.00
71DAA0	2017-07-22 00:06:00+03	131100.00
71DAA3	2017-07-04 06:02:00+03	290400.00
71DAC8	2017-08-02 15:47:00+03	69500.00
71DB75	2017-08-14 15:16:00+03	191400.00
71DB9B	2017-08-01 04:09:00+03	37900.00
71DBBA	2017-08-08 00:57:00+03	19300.00
71DCE4	2017-08-15 06:46:00+03	119800.00
71DD7E	2017-08-13 17:14:00+03	62600.00
71DD89	2017-08-04 02:06:00+03	96300.00
71DD99	2017-08-14 19:51:00+03	9200.00
71DDA5	2017-08-10 05:38:00+03	43200.00
71DE05	2017-07-26 16:10:00+03	141000.00
71DE13	2017-08-13 07:43:00+03	65900.00
71DE1F	2017-07-11 10:12:00+03	70800.00
71DE59	2017-07-14 09:34:00+03	46400.00
71DE5B	2017-08-04 19:13:00+03	32200.00
71DE63	2017-07-09 19:17:00+03	6000.00
71DED2	2017-07-23 02:46:00+03	149500.00
71DFD0	2017-07-15 06:40:00+03	111600.00
71E033	2017-07-27 09:13:00+03	111600.00
71E05D	2017-07-15 09:10:00+03	69500.00
71E0D2	2017-07-11 07:29:00+03	73600.00
71E112	2017-07-18 15:33:00+03	270700.00
71E1CB	2017-08-07 11:36:00+03	315200.00
71E24A	2017-07-03 02:49:00+03	119500.00
71E281	2017-08-11 03:56:00+03	41600.00
71E2CC	2017-07-17 22:52:00+03	20200.00
71E35A	2017-08-15 10:52:00+03	26800.00
71E3F6	2017-07-15 01:27:00+03	67700.00
71E49A	2017-08-11 11:28:00+03	46700.00
71E4CE	2017-07-19 11:53:00+03	23200.00
71E4E1	2017-08-14 01:11:00+03	23600.00
71E52B	2017-07-24 17:11:00+03	23400.00
71E52C	2017-07-21 15:50:00+03	28800.00
71E559	2017-07-07 07:37:00+03	79900.00
71E591	2017-07-31 10:06:00+03	24400.00
71E630	2017-06-29 11:02:00+03	21800.00
71E667	2017-08-05 07:57:00+03	28000.00
71E68F	2017-07-20 03:04:00+03	38400.00
71E6B4	2017-07-19 22:17:00+03	265700.00
71E6BA	2017-07-08 12:28:00+03	27400.00
71E6BD	2017-08-07 19:22:00+03	201200.00
71E6DB	2017-07-24 07:46:00+03	66400.00
71E730	2017-07-02 17:14:00+03	77800.00
71E765	2017-08-03 04:12:00+03	63500.00
71E7C2	2017-07-17 14:09:00+03	76900.00
71E805	2017-07-06 22:20:00+03	202800.00
71E81F	2017-07-02 02:00:00+03	11800.00
71E830	2017-08-02 06:29:00+03	88900.00
71E869	2017-08-10 10:28:00+03	113000.00
71E878	2017-07-10 05:35:00+03	34400.00
71E8E4	2017-07-10 22:38:00+03	55800.00
71E93E	2017-07-29 16:13:00+03	12000.00
71E981	2017-07-12 18:37:00+03	80900.00
71E986	2017-07-24 02:26:00+03	398600.00
71E9EC	2017-07-30 01:40:00+03	16800.00
71EA34	2017-07-24 09:54:00+03	46400.00
71EA3F	2017-08-09 10:46:00+03	147700.00
71EA5F	2017-08-13 01:10:00+03	84100.00
71EA67	2017-07-15 22:01:00+03	27200.00
71EA93	2017-08-10 13:17:00+03	52000.00
71EA9A	2017-07-11 16:48:00+03	119300.00
71EAE7	2017-07-04 19:36:00+03	171800.00
71EAF7	2017-07-09 22:26:00+03	81600.00
71EAF9	2017-08-12 02:17:00+03	31200.00
71EB44	2017-07-17 11:01:00+03	28000.00
71EB58	2017-08-15 08:06:00+03	6700.00
71EB61	2017-08-01 14:17:00+03	56000.00
71EBD1	2017-07-13 10:55:00+03	24700.00
71ED09	2017-07-17 14:45:00+03	44100.00
71ED16	2017-07-15 03:37:00+03	50000.00
71ED59	2017-07-27 07:08:00+03	54800.00
71ED72	2017-08-05 06:34:00+03	24600.00
71EDF1	2017-07-23 00:06:00+03	31600.00
71EE26	2017-08-05 02:05:00+03	31000.00
71EE31	2017-07-08 19:38:00+03	20200.00
71EE68	2017-08-06 13:28:00+03	137600.00
71EEBB	2017-07-14 01:01:00+03	44100.00
71EEFD	2017-07-01 02:03:00+03	25100.00
71EF12	2017-08-11 08:09:00+03	135400.00
71EF4C	2017-07-11 06:54:00+03	28800.00
71EF9E	2017-08-09 01:21:00+03	14400.00
71F03A	2017-07-22 09:42:00+03	7300.00
71F06F	2017-08-08 19:42:00+03	21800.00
71F086	2017-07-05 10:43:00+03	77000.00
71F088	2017-07-05 13:22:00+03	357600.00
71F147	2017-07-08 17:12:00+03	298500.00
71F154	2017-08-03 07:25:00+03	25800.00
71F18D	2017-07-06 07:44:00+03	83000.00
71F1B4	2017-07-15 06:21:00+03	164700.00
71F25A	2017-07-30 18:54:00+03	372500.00
71F2B8	2017-08-07 12:08:00+03	48400.00
71F2C3	2017-08-14 17:58:00+03	137400.00
71F2D2	2017-07-09 03:54:00+03	21400.00
71F2D4	2017-08-04 21:39:00+03	112000.00
71F2F5	2017-07-11 09:24:00+03	223200.00
71F330	2017-07-17 15:40:00+03	81300.00
71F34C	2017-07-24 21:22:00+03	58400.00
71F355	2017-08-07 08:30:00+03	88600.00
71F386	2017-07-19 10:56:00+03	12000.00
71F39F	2017-08-03 18:06:00+03	119500.00
71F3B1	2017-07-16 00:33:00+03	64500.00
71F3BD	2017-07-18 10:24:00+03	36600.00
71F3C7	2017-07-07 20:08:00+03	25600.00
71F47B	2017-07-16 02:43:00+03	51300.00
71F482	2017-08-09 23:09:00+03	75600.00
71F491	2017-07-30 21:14:00+03	37900.00
71F4E1	2017-07-24 16:32:00+03	41400.00
71F54E	2017-07-04 07:04:00+03	82900.00
71F566	2017-07-24 09:27:00+03	160400.00
71F5C0	2017-07-01 05:34:00+03	35200.00
71F5D0	2017-07-26 07:55:00+03	11000.00
71F5FA	2017-07-10 03:40:00+03	57800.00
71F607	2017-08-09 19:41:00+03	14000.00
71F621	2017-07-02 19:55:00+03	41400.00
71F624	2017-07-17 14:09:00+03	96800.00
71F68D	2017-07-13 03:25:00+03	134200.00
71F6C4	2017-07-18 16:04:00+03	46500.00
71F6D4	2017-08-15 09:05:00+03	114400.00
71F764	2017-08-12 20:14:00+03	53700.00
71F7F4	2017-08-12 01:49:00+03	59400.00
71F8D0	2017-07-20 07:30:00+03	138900.00
71F8E0	2017-08-12 20:15:00+03	92300.00
71F901	2017-07-05 23:25:00+03	207200.00
71F94B	2017-07-12 07:06:00+03	26200.00
71F961	2017-08-13 09:27:00+03	79200.00
71F98D	2017-07-22 06:51:00+03	38600.00
71F9A9	2017-07-17 13:05:00+03	113300.00
71F9C9	2017-07-18 18:29:00+03	22400.00
71FA0C	2017-07-19 15:22:00+03	202600.00
71FA37	2017-08-03 05:56:00+03	70800.00
71FA95	2017-07-25 06:42:00+03	31100.00
71FB02	2017-07-07 00:10:00+03	266400.00
71FB3F	2017-07-01 20:11:00+03	175000.00
71FB4A	2017-07-17 02:05:00+03	91200.00
71FB5F	2017-08-13 04:54:00+03	69000.00
71FBBB	2017-07-22 09:18:00+03	92900.00
71FBDB	2017-07-15 17:42:00+03	29200.00
71FC58	2017-07-24 16:21:00+03	18600.00
71FC72	2017-08-11 13:26:00+03	31800.00
71FC8C	2017-08-09 19:44:00+03	114300.00
71FCBB	2017-07-04 13:59:00+03	14000.00
71FCDD	2017-07-06 11:33:00+03	13300.00
71FD11	2017-07-24 03:16:00+03	130200.00
71FD20	2017-07-18 12:01:00+03	23400.00
71FD8F	2017-07-26 16:24:00+03	46800.00
71FDD0	2017-07-18 14:07:00+03	28000.00
71FE13	2017-08-14 05:44:00+03	45500.00
71FE53	2017-08-09 11:28:00+03	168000.00
71FE56	2017-07-05 03:37:00+03	542200.00
71FE8E	2017-06-30 01:39:00+03	76400.00
71FE9D	2017-07-15 01:55:00+03	29600.00
71FEA9	2017-07-09 20:56:00+03	56000.00
71FEC9	2017-07-30 23:05:00+03	16400.00
71FF3A	2017-07-23 18:05:00+03	63400.00
71FF94	2017-07-19 11:59:00+03	23600.00
71FFC1	2017-07-21 06:51:00+03	542300.00
7200CA	2017-07-18 14:12:00+03	6800.00
7200E7	2017-07-09 06:30:00+03	111900.00
72016B	2017-07-24 17:14:00+03	53700.00
7201D2	2017-06-30 09:28:00+03	47500.00
720229	2017-08-04 19:48:00+03	40600.00
7202F8	2017-07-08 05:05:00+03	30400.00
720325	2017-07-12 16:20:00+03	43600.00
720403	2017-08-04 18:48:00+03	235300.00
72044B	2017-08-02 05:35:00+03	58800.00
720470	2017-08-06 00:50:00+03	135000.00
720478	2017-08-13 06:05:00+03	32700.00
72047C	2017-07-06 06:52:00+03	199700.00
7204FB	2017-07-29 02:10:00+03	85500.00
72054E	2017-08-08 13:05:00+03	33000.00
7205EA	2017-07-12 02:09:00+03	27800.00
72063F	2017-07-08 13:45:00+03	283100.00
720655	2017-08-01 08:18:00+03	174800.00
720684	2017-08-11 05:58:00+03	29600.00
7206BB	2017-08-10 00:02:00+03	41400.00
7206F2	2017-07-07 23:53:00+03	75600.00
720729	2017-08-13 03:32:00+03	45600.00
7207AB	2017-07-11 20:59:00+03	21800.00
7207EE	2017-07-08 03:45:00+03	18600.00
720805	2017-07-27 11:48:00+03	22000.00
72084B	2017-08-15 14:34:00+03	21400.00
72085C	2017-07-31 23:43:00+03	137800.00
72087F	2017-07-26 06:35:00+03	57600.00
7208A2	2017-07-27 02:02:00+03	133100.00
7208BF	2017-08-04 07:53:00+03	401000.00
720902	2017-07-11 18:39:00+03	40800.00
720943	2017-07-08 00:23:00+03	114800.00
72094B	2017-07-14 16:27:00+03	140500.00
72097B	2017-07-05 00:34:00+03	187800.00
7209C0	2017-08-08 07:53:00+03	56000.00
7209E0	2017-07-04 03:13:00+03	384800.00
7209F3	2017-08-01 16:29:00+03	8200.00
720A24	2017-07-12 04:17:00+03	29500.00
720A69	2017-07-29 04:10:00+03	6000.00
720AD4	2017-07-04 14:28:00+03	37900.00
720B81	2017-07-15 01:28:00+03	10100.00
720C6F	2017-08-05 21:39:00+03	101200.00
720CA3	2017-07-06 03:23:00+03	56800.00
720CCA	2017-07-13 03:51:00+03	229900.00
720CE0	2017-07-27 04:55:00+03	208600.00
720D0B	2017-07-23 18:42:00+03	31200.00
720D13	2017-07-17 23:01:00+03	198400.00
720D29	2017-07-30 06:54:00+03	28700.00
720D5F	2017-08-13 02:23:00+03	103600.00
720D88	2017-08-15 17:08:00+03	36000.00
720DA7	2017-08-03 01:11:00+03	176600.00
720DD0	2017-07-16 01:23:00+03	13400.00
720DEA	2017-07-31 19:36:00+03	27200.00
720DF2	2017-07-05 09:46:00+03	27200.00
720E17	2017-07-15 22:29:00+03	54800.00
720EE8	2017-07-16 16:51:00+03	23200.00
720EEC	2017-07-19 14:54:00+03	38200.00
720F0E	2017-08-02 10:03:00+03	276500.00
720F10	2017-08-08 17:27:00+03	119400.00
720F65	2017-07-27 00:19:00+03	168000.00
720F84	2017-07-18 09:49:00+03	23200.00
720F90	2017-07-11 17:18:00+03	120700.00
720F99	2017-07-09 15:56:00+03	62900.00
720FA3	2017-07-26 11:21:00+03	39200.00
720FC9	2017-07-21 00:47:00+03	114800.00
721017	2017-08-12 23:14:00+03	101800.00
721053	2017-07-20 12:52:00+03	67700.00
72106A	2017-06-24 05:56:00+03	44500.00
7210CB	2017-07-05 19:11:00+03	568700.00
7210F4	2017-07-14 15:41:00+03	62600.00
72111D	2017-07-13 15:42:00+03	243700.00
721138	2017-07-17 09:54:00+03	111600.00
72120B	2017-07-05 16:19:00+03	85000.00
72125E	2017-08-15 17:41:00+03	33100.00
7212BC	2017-08-13 07:55:00+03	20400.00
7212DF	2017-07-17 17:09:00+03	67700.00
7212E5	2017-08-11 18:18:00+03	38600.00
72131F	2017-08-15 16:12:00+03	46400.00
72133E	2017-07-10 17:32:00+03	56300.00
721343	2017-07-10 15:01:00+03	311200.00
721403	2017-07-22 09:47:00+03	57500.00
721464	2017-07-25 22:51:00+03	23200.00
721466	2017-07-31 09:22:00+03	94000.00
7214A3	2017-06-30 16:35:00+03	35600.00
72152E	2017-08-14 08:06:00+03	266400.00
721543	2017-07-15 13:11:00+03	52000.00
721663	2017-07-25 15:37:00+03	96300.00
7216E5	2017-07-16 05:00:00+03	63100.00
7216F4	2017-08-11 18:46:00+03	94000.00
721760	2017-07-25 10:45:00+03	202800.00
721784	2017-08-02 11:16:00+03	58800.00
7217A0	2017-07-04 13:21:00+03	97700.00
7217D9	2017-08-14 15:03:00+03	47400.00
7217DF	2017-07-14 21:51:00+03	16400.00
7217EB	2017-08-13 05:10:00+03	154300.00
7217F0	2017-07-31 05:28:00+03	248300.00
721890	2017-08-04 10:53:00+03	76600.00
7218E9	2017-07-23 07:59:00+03	84200.00
72198F	2017-08-05 04:10:00+03	73300.00
721997	2017-07-12 21:26:00+03	88800.00
72199A	2017-07-28 23:14:00+03	43100.00
7219C0	2017-07-18 17:19:00+03	73600.00
7219E6	2017-07-15 15:11:00+03	12400.00
7219F0	2017-07-27 21:06:00+03	70500.00
721A03	2017-07-05 01:29:00+03	101200.00
721A3B	2017-08-12 02:07:00+03	55700.00
721A77	2017-08-11 18:41:00+03	531400.00
721B0D	2017-07-22 02:34:00+03	520600.00
721C02	2017-07-22 14:47:00+03	85000.00
721CE1	2017-07-27 15:55:00+03	113300.00
721D08	2017-08-11 09:54:00+03	55600.00
721D10	2017-07-28 03:36:00+03	26000.00
721D14	2017-07-08 00:39:00+03	26000.00
721D4A	2017-08-05 12:11:00+03	32700.00
721D82	2017-07-13 14:39:00+03	29600.00
721D88	2017-07-28 08:51:00+03	23200.00
721DA4	2017-08-09 14:13:00+03	135200.00
721DF8	2017-08-15 15:53:00+03	26700.00
721E51	2017-08-02 00:51:00+03	186900.00
721E67	2017-08-02 20:36:00+03	55800.00
721F28	2017-08-14 02:42:00+03	23200.00
721F2E	2017-08-03 08:00:00+03	36900.00
721F90	2017-07-28 05:37:00+03	14400.00
72200D	2017-07-20 17:44:00+03	94300.00
72207C	2017-08-04 01:24:00+03	97900.00
7220F0	2017-08-09 04:48:00+03	186900.00
722192	2017-07-27 09:47:00+03	24400.00
7221D0	2017-07-25 07:17:00+03	40000.00
722242	2017-07-08 14:55:00+03	26000.00
7222BA	2017-08-12 01:01:00+03	30200.00
7222E0	2017-07-16 14:02:00+03	23200.00
72236E	2017-07-01 12:17:00+03	52600.00
7223E6	2017-08-07 05:42:00+03	24300.00
722433	2017-08-11 20:03:00+03	28300.00
72245A	2017-07-30 22:56:00+03	61100.00
7224FE	2017-08-03 23:20:00+03	40400.00
72250D	2017-07-26 14:18:00+03	284400.00
722553	2017-08-01 01:48:00+03	79800.00
7225DA	2017-07-21 17:17:00+03	49800.00
7225FE	2017-07-13 21:34:00+03	70500.00
7225FF	2017-08-08 17:01:00+03	49600.00
72267C	2017-07-19 01:22:00+03	105200.00
722683	2017-08-14 05:07:00+03	50800.00
7226BB	2017-08-06 15:18:00+03	174800.00
7226DA	2017-08-14 03:09:00+03	30200.00
7226DF	2017-08-03 09:23:00+03	57500.00
7226F4	2017-06-29 08:16:00+03	31600.00
722705	2017-07-08 05:42:00+03	6000.00
722711	2017-08-05 02:54:00+03	46300.00
722712	2017-07-25 11:42:00+03	12600.00
722718	2017-07-06 13:50:00+03	46200.00
722736	2017-08-08 18:01:00+03	295100.00
722753	2017-07-23 10:04:00+03	36800.00
72275F	2017-07-03 20:54:00+03	30000.00
7227AF	2017-07-13 04:44:00+03	11700.00
7228DC	2017-08-01 16:54:00+03	72200.00
72293B	2017-08-14 09:38:00+03	32200.00
722985	2017-07-27 06:22:00+03	28000.00
722988	2017-08-06 10:35:00+03	73200.00
722998	2017-07-29 11:37:00+03	46000.00
7229A6	2017-06-30 22:09:00+03	99700.00
722A05	2017-07-16 22:01:00+03	58900.00
722A55	2017-07-24 09:00:00+03	48800.00
722A56	2017-08-14 18:33:00+03	30000.00
722A99	2017-07-30 23:58:00+03	12000.00
722AAD	2017-08-07 12:24:00+03	122000.00
722AC7	2017-07-17 03:51:00+03	142900.00
722B9F	2017-07-06 15:29:00+03	111600.00
722BB0	2017-08-01 04:23:00+03	175300.00
722BD3	2017-08-01 05:40:00+03	64000.00
722BD9	2017-08-13 12:45:00+03	145200.00
722BDC	2017-07-14 00:37:00+03	136200.00
722BF2	2017-07-18 21:00:00+03	61500.00
722C0A	2017-07-28 09:54:00+03	54800.00
722C3A	2017-08-06 07:34:00+03	43900.00
722C6D	2017-07-22 03:10:00+03	130900.00
722CC5	2017-07-11 13:48:00+03	46000.00
722CD5	2017-07-25 03:57:00+03	149300.00
722CEC	2017-07-11 04:01:00+03	30900.00
722D00	2017-07-07 22:02:00+03	230600.00
722D19	2017-08-05 18:11:00+03	52400.00
722D49	2017-08-10 01:10:00+03	29200.00
722DD1	2017-07-23 15:49:00+03	59300.00
722DF5	2017-07-14 02:54:00+03	44500.00
722E34	2017-07-12 00:01:00+03	19600.00
722E4D	2017-08-05 04:11:00+03	26000.00
722E96	2017-07-22 14:39:00+03	61200.00
722EC2	2017-07-26 04:59:00+03	94100.00
722F1C	2017-07-20 14:09:00+03	56000.00
722F23	2017-08-10 01:49:00+03	246000.00
722FC4	2017-07-29 09:50:00+03	26000.00
722FEA	2017-08-15 12:09:00+03	39800.00
72300A	2017-07-18 05:08:00+03	80000.00
723070	2017-07-05 06:16:00+03	113200.00
723078	2017-07-09 01:14:00+03	54200.00
7230DB	2017-07-20 21:43:00+03	92800.00
7230EC	2017-07-05 01:46:00+03	23200.00
7230FE	2017-07-18 02:04:00+03	50600.00
723123	2017-08-14 20:05:00+03	161900.00
7231E6	2017-07-26 17:23:00+03	44400.00
723263	2017-07-08 00:12:00+03	201200.00
72330D	2017-08-11 17:54:00+03	55800.00
72333E	2017-08-07 19:03:00+03	316400.00
723348	2017-07-18 07:04:00+03	86800.00
7233DF	2017-08-13 06:51:00+03	23200.00
7233E5	2017-07-30 18:14:00+03	58600.00
7233F6	2017-08-10 03:09:00+03	34000.00
723458	2017-08-01 20:43:00+03	135400.00
72346A	2017-07-09 06:57:00+03	25800.00
72347A	2017-08-02 04:49:00+03	13600.00
72347D	2017-07-17 21:42:00+03	84800.00
7235BA	2017-07-09 02:01:00+03	202900.00
7235CC	2017-07-29 20:46:00+03	23400.00
7235E5	2017-07-29 01:42:00+03	170200.00
723608	2017-07-17 12:45:00+03	56000.00
723673	2017-07-22 02:23:00+03	30400.00
7236A4	2017-08-11 23:51:00+03	31800.00
7236CA	2017-07-19 14:39:00+03	17200.00
7236CD	2017-08-15 10:58:00+03	246000.00
723702	2017-08-10 05:48:00+03	46000.00
723707	2017-07-12 20:57:00+03	7200.00
723728	2017-07-10 06:09:00+03	115900.00
72375C	2017-08-11 05:18:00+03	85700.00
723793	2017-08-10 11:37:00+03	77200.00
7237D5	2017-08-14 12:26:00+03	66100.00
72383B	2017-07-12 21:01:00+03	6900.00
723850	2017-06-30 16:24:00+03	49300.00
7238BA	2017-07-13 23:49:00+03	47000.00
7238CC	2017-07-19 22:29:00+03	160400.00
723934	2017-07-02 19:59:00+03	24200.00
723990	2017-07-16 18:24:00+03	94700.00
7239CC	2017-07-26 18:31:00+03	67600.00
723A26	2017-07-26 01:15:00+03	135400.00
723A79	2017-07-30 16:18:00+03	153200.00
723A85	2017-07-30 07:24:00+03	46400.00
723AAC	2017-08-14 17:20:00+03	66400.00
723ACC	2017-07-27 01:00:00+03	78200.00
723B05	2017-08-01 08:36:00+03	27300.00
723B8A	2017-08-12 08:21:00+03	12000.00
723BB1	2017-07-13 01:34:00+03	95600.00
723BBD	2017-07-02 19:36:00+03	15400.00
723BFC	2017-07-05 05:42:00+03	86800.00
723C07	2017-08-12 06:35:00+03	23200.00
723C6C	2017-06-29 10:33:00+03	123900.00
723C70	2017-08-08 02:45:00+03	46900.00
723C79	2017-08-09 05:20:00+03	57600.00
723CE9	2017-08-09 00:22:00+03	26000.00
723CF9	2017-08-03 23:50:00+03	56000.00
723D09	2017-07-27 01:24:00+03	88600.00
723D0A	2017-07-03 00:30:00+03	34000.00
723D1A	2017-08-07 16:18:00+03	172000.00
723D5B	2017-08-15 07:20:00+03	16400.00
723D7D	2017-07-05 10:40:00+03	18400.00
723DA4	2017-08-01 02:11:00+03	27300.00
723DA6	2017-07-22 16:13:00+03	27200.00
723E05	2017-07-14 06:42:00+03	28800.00
723E0D	2017-07-28 21:18:00+03	42800.00
723E5E	2017-06-27 03:18:00+03	47000.00
723E6F	2017-07-05 02:28:00+03	43600.00
723E8D	2017-08-07 13:01:00+03	28800.00
723EB8	2017-08-02 19:12:00+03	135400.00
723F0A	2017-07-30 09:14:00+03	30400.00
723F43	2017-07-07 11:33:00+03	75000.00
723FBB	2017-07-18 17:39:00+03	31600.00
723FC3	2017-08-10 23:40:00+03	55800.00
723FF5	2017-08-08 08:15:00+03	26000.00
724018	2017-07-20 15:45:00+03	136200.00
724021	2017-07-13 22:11:00+03	141100.00
724026	2017-07-12 08:25:00+03	112200.00
724043	2017-07-28 07:06:00+03	39800.00
724078	2017-07-02 02:15:00+03	359400.00
7240D7	2017-07-18 09:23:00+03	135300.00
724116	2017-07-17 22:48:00+03	133200.00
724140	2017-07-15 10:55:00+03	40800.00
72416E	2017-07-08 21:05:00+03	89700.00
7241E3	2017-07-31 05:27:00+03	112000.00
724213	2017-07-23 15:44:00+03	43500.00
724277	2017-08-11 08:04:00+03	56000.00
724283	2017-07-23 06:36:00+03	44000.00
7242E3	2017-07-12 22:11:00+03	65900.00
724303	2017-08-13 13:57:00+03	117600.00
72432D	2017-07-16 17:19:00+03	11700.00
724344	2017-08-03 02:07:00+03	75300.00
724356	2017-08-09 20:54:00+03	58600.00
724367	2017-08-12 05:58:00+03	24400.00
72438D	2017-08-12 10:52:00+03	98700.00
724461	2017-08-09 12:40:00+03	20000.00
724484	2017-07-28 09:53:00+03	58800.00
724485	2017-07-28 06:16:00+03	95200.00
724496	2017-07-18 13:49:00+03	40200.00
724521	2017-08-09 22:00:00+03	69500.00
72457B	2017-07-06 00:42:00+03	45200.00
7245E6	2017-07-27 22:08:00+03	72400.00
7245FA	2017-08-11 15:53:00+03	146600.00
7245FC	2017-07-24 18:49:00+03	128800.00
72469F	2017-08-04 16:46:00+03	54500.00
724700	2017-07-22 04:27:00+03	83000.00
72475B	2017-07-07 07:00:00+03	66600.00
724780	2017-08-10 04:13:00+03	72600.00
72478E	2017-08-06 05:41:00+03	99200.00
724799	2017-07-20 13:39:00+03	56000.00
7247AD	2017-08-15 16:41:00+03	77500.00
7247C3	2017-07-31 11:45:00+03	135400.00
7247EF	2017-07-11 19:54:00+03	45200.00
72487B	2017-08-12 19:04:00+03	73000.00
724950	2017-08-13 12:16:00+03	40800.00
724984	2017-08-12 18:08:00+03	56000.00
724993	2017-07-15 23:59:00+03	549000.00
724A83	2017-07-12 23:10:00+03	85000.00
724AB7	2017-08-02 11:48:00+03	43000.00
724AE2	2017-06-29 09:14:00+03	81900.00
724AF6	2017-06-30 18:05:00+03	130900.00
724B36	2017-08-07 17:02:00+03	32800.00
724C04	2017-08-07 11:38:00+03	22000.00
724C22	2017-08-14 04:23:00+03	21800.00
724C5A	2017-07-19 23:57:00+03	140500.00
724C5E	2017-07-29 20:12:00+03	45100.00
724C91	2017-08-14 04:47:00+03	49200.00
724CA1	2017-08-09 18:31:00+03	92800.00
724CA8	2017-07-05 16:48:00+03	40100.00
724CB5	2017-07-14 05:42:00+03	290400.00
724CF1	2017-07-06 23:00:00+03	24200.00
724D88	2017-07-10 21:14:00+03	28000.00
724E5A	2017-07-31 03:34:00+03	46000.00
724E60	2017-07-20 10:28:00+03	34600.00
724EFF	2017-08-10 23:22:00+03	272300.00
724F07	2017-08-14 16:11:00+03	137000.00
724F47	2017-08-05 01:54:00+03	92800.00
724F66	2017-07-15 09:54:00+03	55800.00
724F8D	2017-07-06 09:54:00+03	38400.00
724FCD	2017-07-28 11:13:00+03	92800.00
724FE1	2017-08-12 02:31:00+03	34000.00
725011	2017-07-30 07:41:00+03	21800.00
72506B	2017-07-22 19:24:00+03	31900.00
7250C1	2017-07-27 06:06:00+03	313800.00
7250E8	2017-08-04 00:10:00+03	46200.00
725124	2017-08-05 07:25:00+03	75500.00
725125	2017-08-14 11:01:00+03	26700.00
72517D	2017-07-18 15:03:00+03	55800.00
725185	2017-07-06 16:32:00+03	22000.00
72519D	2017-08-07 09:31:00+03	100000.00
725283	2017-08-07 12:35:00+03	39600.00
7252D2	2017-08-05 21:53:00+03	42400.00
72530F	2017-08-13 23:40:00+03	50000.00
725346	2017-07-24 14:40:00+03	14800.00
725362	2017-06-29 10:47:00+03	46800.00
72536D	2017-08-10 18:05:00+03	30400.00
72541D	2017-08-15 03:31:00+03	148200.00
725532	2017-07-03 11:01:00+03	266400.00
72556E	2017-07-29 03:57:00+03	12000.00
72556F	2017-08-11 01:19:00+03	23200.00
725579	2017-08-04 09:23:00+03	184900.00
725582	2017-07-27 13:39:00+03	92800.00
7255AB	2017-07-06 02:14:00+03	15800.00
725645	2017-07-01 16:13:00+03	66600.00
725655	2017-07-24 07:37:00+03	61800.00
72567F	2017-08-03 12:00:00+03	301500.00
7256AB	2017-07-04 06:51:00+03	48100.00
7256CB	2017-07-31 13:48:00+03	117900.00
72572B	2017-08-10 13:50:00+03	62600.00
72572E	2017-07-16 16:56:00+03	6000.00
72575B	2017-07-06 10:44:00+03	86800.00
72577B	2017-07-22 06:39:00+03	58600.00
72578A	2017-07-10 06:12:00+03	100600.00
72579A	2017-08-10 03:12:00+03	142400.00
7257A6	2017-07-14 00:14:00+03	56600.00
7257A8	2017-07-22 10:01:00+03	21800.00
7257B0	2017-07-09 12:44:00+03	84600.00
7257DD	2017-08-10 06:06:00+03	117600.00
72580D	2017-06-29 16:45:00+03	29600.00
725942	2017-08-11 14:35:00+03	27900.00
7259D5	2017-07-13 05:13:00+03	54800.00
7259F5	2017-08-11 22:01:00+03	28800.00
725A0E	2017-07-20 04:29:00+03	15400.00
725A34	2017-08-03 15:35:00+03	26800.00
725A3B	2017-07-08 00:06:00+03	52800.00
725AAC	2017-07-17 16:12:00+03	31600.00
725B71	2017-08-11 02:27:00+03	57700.00
725B95	2017-07-14 09:49:00+03	64100.00
725BC3	2017-08-07 06:34:00+03	28000.00
725BC8	2017-08-03 00:35:00+03	54800.00
725BF9	2017-07-05 06:00:00+03	100200.00
725C46	2017-07-30 01:32:00+03	40000.00
725C75	2017-07-11 20:14:00+03	155600.00
725CB5	2017-07-08 03:17:00+03	15000.00
725CEA	2017-08-10 00:00:00+03	102000.00
725D07	2017-06-30 10:02:00+03	127200.00
725D6C	2017-07-22 15:05:00+03	105600.00
725DD7	2017-07-17 03:14:00+03	13100.00
725DF8	2017-07-17 16:19:00+03	9200.00
725E27	2017-08-08 04:06:00+03	30100.00
725E5E	2017-07-28 10:43:00+03	47700.00
725E90	2017-08-12 22:37:00+03	40100.00
725EB2	2017-07-07 12:00:00+03	394400.00
725EF5	2017-08-12 03:37:00+03	66600.00
725F11	2017-07-27 19:52:00+03	18900.00
725F2F	2017-07-30 04:13:00+03	135600.00
725F93	2017-08-04 00:16:00+03	68400.00
725FE4	2017-07-16 20:02:00+03	51600.00
72602F	2017-08-02 00:39:00+03	112000.00
726037	2017-07-29 14:05:00+03	27300.00
726041	2017-07-10 19:39:00+03	81700.00
72609D	2017-07-25 02:22:00+03	124200.00
7260E1	2017-07-08 09:12:00+03	56900.00
726126	2017-07-08 08:24:00+03	40800.00
72612E	2017-07-04 08:55:00+03	419800.00
726176	2017-07-26 07:19:00+03	34600.00
726178	2017-07-30 18:26:00+03	81900.00
726193	2017-07-06 02:28:00+03	32700.00
726210	2017-07-31 17:12:00+03	92400.00
726279	2017-08-04 07:54:00+03	46200.00
72628E	2017-07-18 10:01:00+03	239000.00
7262B8	2017-08-11 05:02:00+03	98400.00
7262C1	2017-08-02 13:28:00+03	119500.00
7262E4	2017-08-13 20:01:00+03	24700.00
72632A	2017-07-27 06:32:00+03	123200.00
726362	2017-07-15 13:45:00+03	26800.00
726377	2017-07-14 05:17:00+03	147000.00
726384	2017-07-23 22:16:00+03	27900.00
7263C2	2017-08-14 01:27:00+03	19000.00
7263F6	2017-07-03 12:53:00+03	56000.00
726402	2017-06-28 01:23:00+03	38600.00
72644D	2017-08-05 05:47:00+03	73900.00
7264A7	2017-07-25 13:36:00+03	8200.00
7264AB	2017-08-11 21:28:00+03	27200.00
7264AE	2017-07-05 03:00:00+03	109000.00
7265ED	2017-08-10 14:22:00+03	27200.00
726657	2017-07-17 18:22:00+03	78100.00
726668	2017-08-01 11:06:00+03	13600.00
7266B2	2017-08-02 04:44:00+03	69500.00
7266BA	2017-07-16 10:58:00+03	60600.00
7266D7	2017-07-28 16:31:00+03	88800.00
7266D9	2017-07-10 04:22:00+03	189200.00
7266E1	2017-08-07 00:15:00+03	149700.00
7266EC	2017-07-04 00:39:00+03	131100.00
726717	2017-08-10 00:19:00+03	46500.00
72678E	2017-07-25 19:26:00+03	66600.00
72679C	2017-07-27 18:35:00+03	56600.00
7267CD	2017-07-17 12:43:00+03	31600.00
7267E1	2017-07-17 16:46:00+03	26000.00
7267E8	2017-07-01 17:28:00+03	174600.00
72685D	2017-08-15 11:04:00+03	15200.00
726890	2017-06-28 06:56:00+03	260900.00
7268D5	2017-07-14 03:41:00+03	32400.00
726911	2017-07-07 19:44:00+03	6700.00
7269C8	2017-07-16 13:57:00+03	81300.00
726A0E	2017-07-20 07:12:00+03	66600.00
726A30	2017-08-04 18:41:00+03	58000.00
726B79	2017-08-03 19:18:00+03	282000.00
726B82	2017-07-24 00:06:00+03	52700.00
726B94	2017-07-01 06:47:00+03	92800.00
726B96	2017-07-11 13:07:00+03	26200.00
726C05	2017-07-21 02:28:00+03	111600.00
726C10	2017-08-10 21:15:00+03	57800.00
726C16	2017-07-21 16:25:00+03	41800.00
726C18	2017-07-06 15:06:00+03	22600.00
726C46	2017-07-26 01:33:00+03	29000.00
726C7C	2017-07-28 09:06:00+03	139000.00
726CC2	2017-08-04 02:24:00+03	94800.00
726CD3	2017-08-12 23:17:00+03	13000.00
726D64	2017-07-29 01:06:00+03	98300.00
726D6C	2017-07-20 09:25:00+03	15400.00
726D6E	2017-07-01 11:18:00+03	168200.00
726DE6	2017-07-26 13:07:00+03	56600.00
726E02	2017-08-10 05:40:00+03	139100.00
726E21	2017-07-29 10:03:00+03	86800.00
726EA3	2017-08-15 11:40:00+03	36600.00
726EBA	2017-08-14 09:47:00+03	62300.00
726EC1	2017-07-17 10:41:00+03	187600.00
726F07	2017-08-11 19:17:00+03	123000.00
726FBA	2017-08-11 00:56:00+03	100600.00
726FE1	2017-07-30 19:32:00+03	76800.00
727013	2017-07-31 06:02:00+03	35300.00
727077	2017-08-08 18:30:00+03	23200.00
727181	2017-07-01 15:42:00+03	144300.00
72718C	2017-07-21 08:56:00+03	86300.00
72719A	2017-07-05 16:43:00+03	21500.00
727225	2017-08-10 07:35:00+03	132000.00
727241	2017-08-09 17:57:00+03	27300.00
727263	2017-07-08 16:19:00+03	56600.00
727267	2017-08-01 01:07:00+03	12400.00
72729A	2017-08-02 17:38:00+03	46200.00
727300	2017-08-14 15:17:00+03	68800.00
727313	2017-07-06 04:28:00+03	39400.00
727314	2017-07-18 01:07:00+03	26000.00
72732E	2017-07-21 15:31:00+03	56000.00
727406	2017-08-15 03:19:00+03	137300.00
727418	2017-07-16 13:32:00+03	258400.00
727421	2017-08-07 00:03:00+03	46300.00
72744B	2017-07-12 14:28:00+03	51200.00
727491	2017-07-12 21:12:00+03	57600.00
7274AA	2017-07-13 00:34:00+03	26000.00
7274CA	2017-07-24 15:21:00+03	50600.00
72751E	2017-07-27 17:24:00+03	41800.00
72757B	2017-07-04 21:36:00+03	204100.00
72758F	2017-08-12 12:51:00+03	44600.00
72759C	2017-07-24 22:39:00+03	43200.00
7275AE	2017-07-22 17:40:00+03	117600.00
7275D9	2017-07-31 07:24:00+03	47000.00
7275E4	2017-07-18 12:04:00+03	189200.00
727602	2017-08-08 20:00:00+03	24400.00
72760E	2017-08-05 07:05:00+03	20800.00
7276C5	2017-07-06 15:48:00+03	393000.00
7276FA	2017-07-09 11:25:00+03	28000.00
727701	2017-07-21 11:22:00+03	56000.00
72773E	2017-07-20 01:49:00+03	86600.00
727744	2017-08-01 06:21:00+03	27900.00
7277DA	2017-07-03 21:47:00+03	28000.00
727835	2017-07-07 14:36:00+03	311900.00
727864	2017-07-29 21:50:00+03	20800.00
72787E	2017-08-06 00:04:00+03	75300.00
727888	2017-07-05 03:20:00+03	10700.00
7278A1	2017-07-23 00:08:00+03	21800.00
7278B1	2017-07-16 09:27:00+03	28000.00
7278B2	2017-07-23 13:45:00+03	39200.00
7278EE	2017-07-23 18:16:00+03	61400.00
727919	2017-07-24 03:13:00+03	86500.00
72795B	2017-08-07 02:25:00+03	105600.00
7279C0	2017-07-22 13:48:00+03	43600.00
727A2E	2017-07-27 06:09:00+03	92700.00
727A30	2017-08-09 03:29:00+03	18000.00
727A34	2017-07-12 04:29:00+03	30100.00
727A4E	2017-07-31 00:42:00+03	26000.00
727A62	2017-08-03 07:37:00+03	91600.00
727A81	2017-07-23 02:01:00+03	17800.00
727AB9	2017-08-09 19:33:00+03	57600.00
727B97	2017-07-28 06:32:00+03	6800.00
727CEB	2017-07-21 15:24:00+03	265600.00
727D1B	2017-08-12 00:47:00+03	18000.00
727D1C	2017-07-31 14:48:00+03	38200.00
727D1E	2017-08-14 09:41:00+03	6700.00
727D4B	2017-07-16 17:39:00+03	28000.00
727D91	2017-07-10 13:25:00+03	28100.00
727E15	2017-07-06 08:34:00+03	17000.00
727E95	2017-07-09 00:08:00+03	56000.00
727EBF	2017-07-28 03:51:00+03	137600.00
727EEC	2017-07-06 18:39:00+03	54800.00
727EF9	2017-08-15 07:21:00+03	26000.00
727F00	2017-07-12 23:32:00+03	40100.00
727F33	2017-07-14 05:33:00+03	70800.00
727F61	2017-08-05 14:01:00+03	133200.00
727F94	2017-08-13 04:56:00+03	39800.00
728017	2017-08-12 23:57:00+03	90000.00
728035	2017-08-07 00:46:00+03	40000.00
728072	2017-07-09 14:57:00+03	111600.00
72810B	2017-08-13 14:00:00+03	247700.00
728182	2017-08-02 03:20:00+03	64700.00
7281BA	2017-07-10 15:43:00+03	73200.00
728221	2017-08-07 00:03:00+03	21200.00
728284	2017-08-07 19:38:00+03	51200.00
7282AA	2017-07-15 13:22:00+03	23100.00
728357	2017-08-05 18:12:00+03	46000.00
7283AB	2017-06-29 15:59:00+03	39500.00
7283CA	2017-07-12 19:45:00+03	100100.00
72845D	2017-08-15 05:03:00+03	161600.00
7284B7	2017-08-09 17:06:00+03	133200.00
7284CA	2017-07-12 18:46:00+03	25200.00
72852D	2017-07-22 20:31:00+03	31600.00
728581	2017-07-31 18:13:00+03	19600.00
7285D1	2017-07-17 23:04:00+03	31600.00
72863B	2017-07-15 18:29:00+03	88500.00
72864B	2017-08-05 04:47:00+03	81600.00
72865A	2017-07-09 10:36:00+03	55800.00
728744	2017-07-28 01:27:00+03	45100.00
728765	2017-07-03 22:50:00+03	59100.00
72876A	2017-07-02 11:57:00+03	258400.00
7287A0	2017-06-29 05:45:00+03	246000.00
7287EC	2017-08-14 03:39:00+03	24600.00
7287FB	2017-07-10 04:32:00+03	11000.00
72881D	2017-07-07 00:53:00+03	246000.00
728832	2017-08-12 04:25:00+03	28800.00
72885E	2017-06-27 06:01:00+03	41200.00
728873	2017-08-07 11:23:00+03	31600.00
7288A9	2017-08-05 17:31:00+03	73400.00
7288D1	2017-06-30 21:15:00+03	43400.00
7288F1	2017-08-11 20:37:00+03	6300.00
72892A	2017-08-05 04:14:00+03	48100.00
728934	2017-07-30 04:32:00+03	67600.00
728A72	2017-08-05 23:15:00+03	75300.00
728A7F	2017-07-19 22:25:00+03	113300.00
728AAB	2017-07-13 05:01:00+03	57500.00
728AD0	2017-07-29 12:02:00+03	266400.00
728B3A	2017-07-20 22:35:00+03	28000.00
728BA9	2017-07-17 17:39:00+03	43500.00
728BDF	2017-07-28 14:30:00+03	64500.00
728D20	2017-07-30 03:29:00+03	78000.00
728D58	2017-07-21 13:58:00+03	44000.00
728DAD	2017-08-07 02:29:00+03	177000.00
728DCE	2017-08-13 07:59:00+03	22000.00
728DD3	2017-08-09 14:02:00+03	40600.00
728DF3	2017-07-03 08:37:00+03	108000.00
728E0A	2017-07-27 06:21:00+03	63500.00
728E40	2017-07-12 00:08:00+03	42800.00
728EBE	2017-07-02 16:37:00+03	46400.00
728EE0	2017-08-07 08:22:00+03	128800.00
728EE8	2017-08-11 20:51:00+03	65500.00
728F32	2017-07-05 13:04:00+03	30900.00
72900C	2017-08-15 16:05:00+03	20200.00
72904B	2017-08-14 11:50:00+03	48800.00
72905D	2017-07-17 00:06:00+03	58200.00
72906A	2017-08-10 12:43:00+03	56000.00
7290B2	2017-08-02 12:21:00+03	56000.00
72919F	2017-07-19 05:51:00+03	37100.00
7291B5	2017-08-15 11:12:00+03	11700.00
72922D	2017-07-31 19:34:00+03	99000.00
729291	2017-07-01 20:25:00+03	118500.00
7292EF	2017-08-15 08:43:00+03	33600.00
7292FD	2017-07-25 19:19:00+03	25900.00
729315	2017-07-19 08:46:00+03	28000.00
729319	2017-08-12 16:52:00+03	6700.00
729360	2017-08-03 16:28:00+03	198400.00
729378	2017-07-25 11:56:00+03	397000.00
729398	2017-08-02 11:39:00+03	61400.00
7293DE	2017-07-24 19:07:00+03	67200.00
7293F8	2017-08-07 18:08:00+03	47600.00
729463	2017-08-12 21:45:00+03	73500.00
72949B	2017-07-04 08:42:00+03	76600.00
7294DD	2017-07-16 01:38:00+03	9200.00
7294E7	2017-08-15 05:26:00+03	95200.00
729522	2017-08-13 01:58:00+03	6000.00
729555	2017-06-29 16:36:00+03	42800.00
729582	2017-07-14 03:13:00+03	25100.00
7295EC	2017-07-06 07:43:00+03	98400.00
729627	2017-08-05 02:58:00+03	27800.00
729630	2017-07-04 19:16:00+03	94700.00
729684	2017-08-07 09:19:00+03	92100.00
7296B8	2017-08-04 20:01:00+03	85900.00
7296D3	2017-07-23 00:19:00+03	29600.00
729813	2017-07-24 05:04:00+03	28800.00
7298E2	2017-07-22 23:26:00+03	66800.00
729922	2017-08-14 08:48:00+03	57400.00
729956	2017-07-18 05:17:00+03	6700.00
729973	2017-07-18 18:14:00+03	43500.00
729A10	2017-08-10 12:15:00+03	31200.00
729A48	2017-07-09 10:28:00+03	65900.00
729A80	2017-07-26 15:56:00+03	31600.00
729AFD	2017-08-14 02:07:00+03	23200.00
729B4E	2017-07-13 14:21:00+03	44800.00
729B56	2017-08-08 21:19:00+03	75600.00
729B6D	2017-07-30 16:59:00+03	74900.00
729BF2	2017-07-20 10:13:00+03	14400.00
729C23	2017-07-03 21:19:00+03	30400.00
729C8E	2017-07-25 03:07:00+03	46000.00
729D0B	2017-08-12 20:31:00+03	8400.00
729D28	2017-07-13 15:24:00+03	35800.00
729D81	2017-07-21 18:45:00+03	23100.00
729D9B	2017-07-20 19:26:00+03	189800.00
729DB3	2017-08-15 13:34:00+03	51600.00
729DB9	2017-07-24 11:58:00+03	61800.00
729E0A	2017-07-29 14:50:00+03	73000.00
729E41	2017-07-24 10:04:00+03	186900.00
729F3F	2017-08-14 21:01:00+03	39500.00
729FCC	2017-08-07 01:35:00+03	46200.00
72A075	2017-07-08 01:55:00+03	375200.00
72A0CA	2017-08-10 16:04:00+03	270800.00
72A185	2017-07-29 12:31:00+03	77500.00
72A18E	2017-07-18 12:50:00+03	160100.00
72A1F3	2017-08-12 03:32:00+03	66000.00
72A20C	2017-08-07 00:43:00+03	26000.00
72A22A	2017-06-29 20:41:00+03	114700.00
72A25E	2017-08-05 03:51:00+03	159100.00
72A26E	2017-07-09 10:07:00+03	75300.00
72A27E	2017-08-01 21:53:00+03	71000.00
72A2B0	2017-07-29 14:15:00+03	228900.00
72A2C7	2017-08-01 18:15:00+03	133100.00
72A2D3	2017-07-12 04:28:00+03	25200.00
72A31B	2017-07-08 21:58:00+03	10800.00
72A33C	2017-08-14 21:06:00+03	67600.00
72A36B	2017-08-15 12:38:00+03	40300.00
72A3AE	2017-07-26 14:32:00+03	42800.00
72A3C3	2017-07-29 03:59:00+03	186800.00
72A414	2017-08-12 21:28:00+03	26600.00
72A41F	2017-07-08 08:54:00+03	46700.00
72A45F	2017-07-09 09:49:00+03	98400.00
72A4A3	2017-07-15 07:34:00+03	166900.00
72A4CB	2017-07-06 14:12:00+03	11800.00
72A4FE	2017-07-01 22:05:00+03	76600.00
72A521	2017-08-06 14:35:00+03	23200.00
72A556	2017-08-06 10:52:00+03	18000.00
72A557	2017-07-07 13:15:00+03	26600.00
72A5AB	2017-08-14 16:27:00+03	128800.00
72A5B4	2017-07-17 10:18:00+03	136800.00
72A5FC	2017-06-30 16:29:00+03	27900.00
72A603	2017-07-19 00:18:00+03	40400.00
72A609	2017-07-05 01:24:00+03	37600.00
72A682	2017-07-13 06:14:00+03	26700.00
72A6DF	2017-08-09 22:34:00+03	61200.00
72A6F3	2017-07-24 02:33:00+03	110500.00
72A6F6	2017-08-05 19:36:00+03	25600.00
72A780	2017-07-31 20:31:00+03	63500.00
72A7E6	2017-08-14 21:21:00+03	36600.00
72A813	2017-06-29 08:39:00+03	141700.00
72A829	2017-08-01 03:15:00+03	38500.00
72A88A	2017-07-12 14:12:00+03	150600.00
72A895	2017-08-10 10:09:00+03	47200.00
72A912	2017-08-01 22:55:00+03	62600.00
72A925	2017-08-07 06:26:00+03	20000.00
72A9CC	2017-07-15 17:36:00+03	40800.00
72A9FE	2017-07-18 07:01:00+03	56000.00
72AA26	2017-07-29 05:47:00+03	22000.00
72AA7A	2017-07-08 00:04:00+03	28000.00
72AAD4	2017-08-09 01:39:00+03	80300.00
72AB24	2017-07-06 16:48:00+03	16400.00
72AC13	2017-07-31 15:51:00+03	67500.00
72AC19	2017-08-14 02:47:00+03	68700.00
72AC22	2017-07-30 00:24:00+03	20200.00
72AC94	2017-07-29 22:27:00+03	71200.00
72AD06	2017-07-21 14:19:00+03	84500.00
72AD39	2017-08-12 00:47:00+03	28800.00
72ADED	2017-07-16 12:17:00+03	68200.00
72AE2F	2017-07-11 16:52:00+03	62600.00
72AE32	2017-06-29 05:12:00+03	28000.00
72AEA3	2017-08-01 10:04:00+03	55800.00
72AF32	2017-07-10 12:28:00+03	57600.00
72AF33	2017-07-27 19:15:00+03	13500.00
72AF8D	2017-08-01 09:47:00+03	25800.00
72AFB7	2017-08-05 15:36:00+03	43600.00
72B009	2017-07-28 12:18:00+03	42100.00
72B030	2017-06-29 22:45:00+03	55800.00
72B065	2017-08-11 10:32:00+03	6800.00
72B087	2017-08-07 10:41:00+03	56000.00
72B092	2017-07-09 17:23:00+03	40400.00
72B0C2	2017-07-22 16:49:00+03	73200.00
72B0E4	2017-07-29 02:50:00+03	25200.00
72B112	2017-08-03 15:39:00+03	23200.00
72B127	2017-07-26 19:20:00+03	48300.00
72B15E	2017-07-11 15:29:00+03	49900.00
72B1D0	2017-06-30 15:46:00+03	337400.00
72B1F7	2017-07-01 21:45:00+03	14700.00
72B1FC	2017-07-29 23:11:00+03	32200.00
72B203	2017-07-12 07:01:00+03	24400.00
72B261	2017-07-07 07:52:00+03	65900.00
72B278	2017-07-04 10:20:00+03	120900.00
72B2CD	2017-08-15 08:27:00+03	182300.00
72B383	2017-08-14 04:49:00+03	148200.00
72B38D	2017-07-03 22:00:00+03	21800.00
72B39C	2017-07-19 01:24:00+03	122800.00
72B424	2017-08-13 18:38:00+03	56300.00
72B43B	2017-08-11 04:14:00+03	135800.00
72B46D	2017-07-31 20:38:00+03	46500.00
72B4CF	2017-07-04 22:22:00+03	263900.00
72B4DF	2017-07-09 07:48:00+03	118700.00
72B549	2017-08-07 16:43:00+03	38800.00
72B56E	2017-08-10 06:14:00+03	73500.00
72B58D	2017-07-05 22:50:00+03	17600.00
72B592	2017-07-19 04:00:00+03	89200.00
72B5EA	2017-07-05 12:07:00+03	55600.00
72B649	2017-08-11 10:07:00+03	37900.00
72B695	2017-07-02 17:41:00+03	306600.00
72B6C2	2017-07-21 18:57:00+03	96300.00
72B6E5	2017-07-16 23:06:00+03	67600.00
72B6F8	2017-08-15 13:02:00+03	12400.00
72B753	2017-08-02 01:06:00+03	25000.00
72B757	2017-07-26 14:20:00+03	53600.00
72B7AD	2017-07-07 04:47:00+03	69000.00
72B7BB	2017-07-17 00:51:00+03	46400.00
72B7C3	2017-07-27 20:25:00+03	38400.00
72B7CD	2017-07-29 21:29:00+03	85000.00
72B810	2017-07-01 13:10:00+03	19600.00
72B831	2017-07-30 15:57:00+03	50800.00
72B8F4	2017-07-31 20:50:00+03	189200.00
72B918	2017-07-22 09:20:00+03	99600.00
72B92C	2017-07-03 10:18:00+03	150100.00
72B9F8	2017-07-30 21:51:00+03	22000.00
72BA2B	2017-08-09 16:46:00+03	44100.00
72BA69	2017-07-08 04:37:00+03	26400.00
72BAD4	2017-07-20 05:41:00+03	81600.00
72BB43	2017-07-26 11:12:00+03	66000.00
72BB83	2017-07-29 12:09:00+03	20200.00
72BBA2	2017-07-30 04:11:00+03	29400.00
72BBDD	2017-08-03 02:10:00+03	36200.00
72BC1A	2017-07-04 11:15:00+03	50400.00
72BCBA	2017-07-26 08:46:00+03	51600.00
72BCE8	2017-08-08 03:07:00+03	6000.00
72BCF4	2017-06-29 17:19:00+03	86800.00
72BD11	2017-07-01 04:23:00+03	52400.00
72BDAA	2017-07-19 01:11:00+03	37200.00
72BDBF	2017-07-22 13:54:00+03	46700.00
72BE1D	2017-07-03 06:43:00+03	85000.00
72BE21	2017-07-28 15:58:00+03	53600.00
72BE22	2017-07-05 20:35:00+03	66600.00
72BE2E	2017-08-04 06:08:00+03	199700.00
72BE86	2017-07-19 16:45:00+03	55800.00
72BEB6	2017-07-22 12:11:00+03	41800.00
72BF17	2017-07-20 09:15:00+03	246000.00
72BF2E	2017-07-26 18:06:00+03	39300.00
72C004	2017-08-14 02:40:00+03	78300.00
72C017	2017-07-13 14:24:00+03	221000.00
72C064	2017-07-14 16:47:00+03	21000.00
72C07C	2017-06-30 19:44:00+03	23200.00
72C083	2017-08-01 07:38:00+03	22000.00
72C0DF	2017-07-24 20:22:00+03	48400.00
72C126	2017-07-15 06:29:00+03	33000.00
72C142	2017-07-21 07:35:00+03	12400.00
72C160	2017-08-11 04:28:00+03	32200.00
72C262	2017-07-07 21:33:00+03	40400.00
72C277	2017-07-26 08:45:00+03	529100.00
72C27A	2017-08-12 04:48:00+03	38400.00
72C2C4	2017-07-21 00:44:00+03	93700.00
72C2D1	2017-07-30 22:21:00+03	73600.00
72C32D	2017-08-05 04:13:00+03	36200.00
72C361	2017-07-24 12:29:00+03	136300.00
72C39C	2017-08-08 12:59:00+03	13200.00
72C418	2017-07-15 20:27:00+03	46000.00
72C46A	2017-08-15 09:50:00+03	36200.00
72C48B	2017-07-17 01:46:00+03	36200.00
72C50D	2017-08-10 04:57:00+03	38600.00
72C525	2017-07-01 13:32:00+03	23600.00
72C52B	2017-07-14 16:53:00+03	22000.00
72C59B	2017-07-06 02:09:00+03	12600.00
72C5E9	2017-07-23 21:38:00+03	260300.00
72C5F1	2017-07-01 10:29:00+03	67600.00
72C6B2	2017-07-28 00:53:00+03	38800.00
72C72B	2017-08-09 20:51:00+03	26700.00
72C733	2017-08-15 12:22:00+03	185600.00
72C748	2017-07-09 20:46:00+03	36400.00
72C756	2017-07-29 22:38:00+03	55800.00
72C757	2017-08-06 05:26:00+03	129700.00
72C777	2017-07-14 00:14:00+03	272400.00
72C789	2017-07-20 21:35:00+03	28000.00
72C7D8	2017-07-02 00:45:00+03	133100.00
72C7DD	2017-07-07 11:25:00+03	145000.00
72C7E9	2017-07-10 05:56:00+03	118100.00
72C807	2017-07-26 07:41:00+03	46400.00
72C81D	2017-07-15 09:45:00+03	51900.00
72C82B	2017-07-29 06:00:00+03	67600.00
72C835	2017-07-14 03:10:00+03	22400.00
72C853	2017-07-21 00:50:00+03	56600.00
72C87A	2017-07-22 16:49:00+03	14400.00
72C89C	2017-07-20 06:24:00+03	81600.00
72C8B4	2017-07-25 22:42:00+03	48100.00
72C8BE	2017-08-03 14:06:00+03	147400.00
72C8E2	2017-08-14 12:17:00+03	15900.00
72C908	2017-07-29 09:10:00+03	101900.00
72C999	2017-07-05 17:14:00+03	31400.00
72C9B3	2017-07-05 06:04:00+03	52100.00
72C9DF	2017-07-02 23:07:00+03	85000.00
72CA0C	2017-08-03 17:03:00+03	59200.00
72CA45	2017-07-01 19:57:00+03	19300.00
72CA86	2017-07-24 13:18:00+03	24800.00
72CAB2	2017-08-01 22:45:00+03	50900.00
72CB08	2017-07-27 06:43:00+03	92100.00
72CB3A	2017-07-24 01:44:00+03	81600.00
72CB46	2017-07-06 19:18:00+03	51000.00
72CB99	2017-06-30 20:39:00+03	14300.00
72CBB2	2017-07-20 21:27:00+03	16400.00
72CC06	2017-07-18 23:37:00+03	25400.00
72CC10	2017-08-07 01:38:00+03	46000.00
72CC1B	2017-08-14 21:06:00+03	28000.00
72CC33	2017-07-03 03:57:00+03	173600.00
72CC43	2017-06-29 00:14:00+03	95600.00
72CC64	2017-08-03 01:29:00+03	52000.00
72CCA9	2017-07-17 15:36:00+03	32200.00
72CCBD	2017-08-08 17:26:00+03	55800.00
72CD4C	2017-07-15 04:15:00+03	116800.00
72CD55	2017-07-24 23:22:00+03	51300.00
72CDD7	2017-08-02 00:08:00+03	38600.00
72CDF3	2017-07-03 05:27:00+03	123000.00
72CE60	2017-06-27 15:37:00+03	112000.00
72CF2B	2017-08-13 06:16:00+03	66600.00
72CF72	2017-08-14 17:08:00+03	66300.00
72CF94	2017-07-14 08:13:00+03	72200.00
72CFB0	2017-08-06 07:54:00+03	266400.00
72CFBA	2017-07-26 21:47:00+03	45100.00
72CFD4	2017-08-08 17:24:00+03	43000.00
72D0E9	2017-07-20 23:02:00+03	46000.00
72D0EA	2017-07-25 05:46:00+03	29600.00
72D0FC	2017-07-09 18:19:00+03	53800.00
72D159	2017-07-04 09:54:00+03	23200.00
72D15C	2017-07-14 19:29:00+03	123700.00
72D1A8	2017-07-13 19:24:00+03	68400.00
72D1F6	2017-08-12 22:21:00+03	26800.00
72D23B	2017-07-02 18:56:00+03	23200.00
72D27D	2017-07-12 07:11:00+03	80500.00
72D2B5	2017-07-01 18:11:00+03	166100.00
72D326	2017-07-05 08:19:00+03	47200.00
72D3AA	2017-07-31 03:58:00+03	23200.00
72D406	2017-08-05 21:10:00+03	103000.00
72D475	2017-07-26 06:01:00+03	26000.00
72D482	2017-07-15 18:23:00+03	12600.00
72D4BA	2017-07-04 19:43:00+03	125100.00
72D5AC	2017-07-30 14:16:00+03	178300.00
72D5B9	2017-07-28 05:46:00+03	75300.00
72D5C1	2017-07-29 14:33:00+03	83900.00
72D5C4	2017-08-09 18:06:00+03	21800.00
72D631	2017-07-03 13:37:00+03	64500.00
72D633	2017-07-05 05:19:00+03	56000.00
72D63E	2017-08-13 12:19:00+03	13400.00
72D656	2017-07-18 01:00:00+03	57600.00
72D6C2	2017-07-15 01:34:00+03	147700.00
72D706	2017-07-13 23:34:00+03	59000.00
72D775	2017-07-27 19:54:00+03	23200.00
72D7C8	2017-08-13 02:07:00+03	28800.00
72D813	2017-08-04 03:15:00+03	173800.00
72D862	2017-08-10 18:55:00+03	201200.00
72D89A	2017-08-09 13:35:00+03	36600.00
72D8E7	2017-07-10 10:30:00+03	28800.00
72D910	2017-07-22 07:11:00+03	25600.00
72D993	2017-07-01 09:40:00+03	38400.00
72D9B0	2017-08-03 12:41:00+03	58200.00
72D9D8	2017-07-10 17:36:00+03	36200.00
72D9E4	2017-07-22 15:42:00+03	18600.00
72D9F9	2017-07-27 10:21:00+03	52900.00
72DAAF	2017-07-16 16:44:00+03	34400.00
72DAD7	2017-08-10 20:54:00+03	245600.00
72DAED	2017-07-04 22:26:00+03	28000.00
72DAF3	2017-07-03 15:48:00+03	34000.00
72DB22	2017-07-21 22:09:00+03	163800.00
72DB7C	2017-07-08 21:29:00+03	16400.00
72DB83	2017-08-09 04:07:00+03	19600.00
72DBA6	2017-08-09 17:36:00+03	147500.00
72DC06	2017-07-07 12:09:00+03	55400.00
72DC53	2017-07-28 01:07:00+03	69600.00
72DC95	2017-07-12 12:16:00+03	70400.00
72DC9D	2017-07-22 19:30:00+03	46100.00
72DCBD	2017-08-04 17:13:00+03	240600.00
72DD8E	2017-08-02 04:25:00+03	40600.00
72DDE0	2017-06-29 17:23:00+03	30800.00
72DE9D	2017-08-01 07:32:00+03	131800.00
72DEC5	2017-07-25 20:08:00+03	110500.00
72DEDB	2017-07-16 09:27:00+03	47400.00
72DEE9	2017-07-11 11:37:00+03	22600.00
72DEF3	2017-08-06 04:27:00+03	13600.00
72DF52	2017-07-07 21:41:00+03	51900.00
72DF60	2017-07-10 12:09:00+03	56600.00
72E033	2017-07-16 05:02:00+03	28800.00
72E047	2017-07-14 03:09:00+03	131600.00
72E065	2017-08-02 16:46:00+03	93700.00
72E06C	2017-07-26 01:11:00+03	255700.00
72E09F	2017-07-27 00:34:00+03	47400.00
72E0DF	2017-08-07 05:28:00+03	21400.00
72E1C9	2017-08-09 20:45:00+03	260900.00
72E1E0	2017-07-17 06:16:00+03	47000.00
72E1E5	2017-07-07 18:16:00+03	241500.00
72E269	2017-07-14 02:43:00+03	21400.00
72E289	2017-08-07 15:19:00+03	155600.00
72E28C	2017-07-05 14:06:00+03	45100.00
72E2CF	2017-07-26 12:35:00+03	25600.00
72E2FD	2017-07-21 08:41:00+03	81600.00
72E305	2017-06-29 03:02:00+03	23200.00
72E37C	2017-07-17 17:44:00+03	13400.00
72E384	2017-07-16 12:11:00+03	64600.00
72E38C	2017-07-24 12:58:00+03	48400.00
72E3BA	2017-08-12 22:15:00+03	55800.00
72E3C1	2017-08-12 11:42:00+03	80900.00
72E3C5	2017-07-03 10:22:00+03	303500.00
72E3D8	2017-07-23 02:33:00+03	6000.00
72E3F7	2017-07-22 04:50:00+03	57400.00
72E423	2017-07-13 01:42:00+03	12000.00
72E434	2017-08-04 04:53:00+03	47100.00
72E444	2017-07-28 00:50:00+03	82300.00
72E4AC	2017-07-04 10:24:00+03	179400.00
72E513	2017-07-26 00:23:00+03	6000.00
72E598	2017-07-23 08:24:00+03	117200.00
72E5BA	2017-06-30 00:12:00+03	56000.00
72E5DA	2017-08-12 11:52:00+03	29800.00
72E5ED	2017-07-17 00:02:00+03	134700.00
72E646	2017-07-19 11:56:00+03	56000.00
72E730	2017-08-09 11:11:00+03	332800.00
72E758	2017-07-03 23:16:00+03	60400.00
72E76C	2017-07-03 08:36:00+03	21400.00
72E77D	2017-07-16 18:35:00+03	246000.00
72E7AB	2017-07-15 07:58:00+03	28800.00
72E7E9	2017-06-30 18:24:00+03	28000.00
72E81D	2017-07-06 21:22:00+03	148200.00
72E864	2017-07-10 12:33:00+03	26000.00
72E87F	2017-07-16 15:14:00+03	266400.00
72E8AB	2017-07-30 01:20:00+03	68800.00
72E92C	2017-08-07 08:10:00+03	56900.00
72E98D	2017-08-12 06:46:00+03	27200.00
72E9A2	2017-08-14 02:47:00+03	35800.00
72E9D6	2017-07-23 23:26:00+03	46000.00
72E9F6	2017-08-08 14:12:00+03	23200.00
72EA31	2017-06-29 10:44:00+03	56100.00
72EA61	2017-07-29 22:42:00+03	12000.00
72EA8E	2017-07-21 23:20:00+03	111600.00
72EAB9	2017-07-26 19:36:00+03	42600.00
72EAC3	2017-07-22 00:20:00+03	6000.00
72EACA	2017-07-16 20:04:00+03	84100.00
72EACD	2017-07-07 03:12:00+03	56000.00
72EB21	2017-07-25 11:19:00+03	124200.00
72EBD9	2017-08-03 18:02:00+03	112000.00
72EBDE	2017-08-01 21:51:00+03	38400.00
72EC29	2017-07-26 19:33:00+03	51900.00
72EC48	2017-07-15 03:54:00+03	30000.00
72EC61	2017-07-16 19:47:00+03	55800.00
72ECCA	2017-08-01 22:09:00+03	116400.00
72ED6A	2017-07-20 00:20:00+03	30800.00
72ED73	2017-08-05 21:16:00+03	48800.00
72EDB2	2017-07-25 20:04:00+03	113300.00
72EDCF	2017-07-14 09:57:00+03	55000.00
72EE3E	2017-07-17 16:25:00+03	15000.00
72EE8B	2017-07-20 14:09:00+03	16800.00
72EE8C	2017-08-03 12:19:00+03	28800.00
72EE8F	2017-07-07 00:42:00+03	23200.00
72EE98	2017-07-23 12:24:00+03	270500.00
72EE9F	2017-07-13 04:56:00+03	47600.00
72EF58	2017-07-17 17:21:00+03	123000.00
72EF95	2017-07-12 04:40:00+03	89600.00
72EFDF	2017-07-10 02:46:00+03	23200.00
72EFEA	2017-08-15 07:18:00+03	25600.00
72EFEB	2017-07-24 03:33:00+03	50700.00
72EFFD	2017-06-30 07:48:00+03	270800.00
72F041	2017-08-11 06:53:00+03	133100.00
72F042	2017-07-13 06:20:00+03	18300.00
72F134	2017-07-26 16:54:00+03	56600.00
72F137	2017-08-11 06:12:00+03	56600.00
72F153	2017-07-27 14:29:00+03	113800.00
72F16A	2017-07-23 17:57:00+03	24400.00
72F194	2017-07-13 19:21:00+03	64700.00
72F1F4	2017-07-27 08:49:00+03	56000.00
72F254	2017-07-26 08:24:00+03	75000.00
72F272	2017-08-08 15:00:00+03	61200.00
72F282	2017-07-04 23:11:00+03	20600.00
72F392	2017-07-26 14:09:00+03	36200.00
72F3AA	2017-07-06 13:00:00+03	20200.00
72F3C5	2017-07-08 09:05:00+03	81200.00
72F409	2017-07-10 18:19:00+03	47000.00
72F437	2017-07-23 07:39:00+03	77900.00
72F482	2017-08-08 16:51:00+03	26000.00
72F4A1	2017-07-18 12:30:00+03	264600.00
72F4B4	2017-07-14 14:05:00+03	18000.00
72F562	2017-07-19 21:51:00+03	201200.00
72F57A	2017-07-07 04:37:00+03	57100.00
72F58B	2017-07-05 10:26:00+03	8000.00
72F58C	2017-07-02 18:52:00+03	84300.00
72F5B4	2017-08-14 03:47:00+03	83700.00
72F5DE	2017-07-15 07:50:00+03	6700.00
72F5F7	2017-07-12 09:15:00+03	55800.00
72F60D	2017-07-09 11:03:00+03	119600.00
72F629	2017-08-12 09:09:00+03	533200.00
72F63F	2017-08-11 19:36:00+03	136200.00
72F660	2017-08-15 06:25:00+03	8400.00
72F691	2017-08-05 17:27:00+03	14900.00
72F73A	2017-07-21 12:55:00+03	57500.00
72F7EE	2017-07-31 10:30:00+03	51900.00
72F8F9	2017-07-21 08:51:00+03	40100.00
72FA28	2017-07-16 13:52:00+03	6300.00
72FA3F	2017-08-02 23:27:00+03	61800.00
72FA7A	2017-07-19 06:09:00+03	58400.00
72FADF	2017-07-06 20:59:00+03	40000.00
72FBCC	2017-08-06 11:34:00+03	34000.00
72FC05	2017-08-03 10:32:00+03	172300.00
72FC18	2017-07-27 08:56:00+03	98400.00
72FC30	2017-07-22 13:58:00+03	135200.00
72FC74	2017-08-05 18:22:00+03	91600.00
72FCD0	2017-07-26 08:57:00+03	56600.00
72FCF3	2017-08-15 12:11:00+03	129200.00
72FDB4	2017-07-31 12:38:00+03	47000.00
72FDBA	2017-07-20 17:31:00+03	103900.00
72FE3E	2017-07-09 11:49:00+03	67400.00
72FE93	2017-07-28 20:00:00+03	39800.00
72FF60	2017-07-14 04:40:00+03	182300.00
72FF90	2017-08-06 04:31:00+03	229800.00
72FFE2	2017-08-09 12:27:00+03	18000.00
72FFEF	2017-07-24 22:15:00+03	56000.00
73009C	2017-07-31 11:32:00+03	385000.00
7300A4	2017-08-15 00:58:00+03	62600.00
730141	2017-07-05 00:05:00+03	16400.00
730182	2017-08-01 16:24:00+03	12600.00
73018F	2017-07-31 06:55:00+03	40800.00
7301CD	2017-08-11 19:57:00+03	46000.00
730228	2017-07-11 14:15:00+03	115400.00
7302C5	2017-08-10 15:20:00+03	79300.00
7302DC	2017-07-16 04:57:00+03	13400.00
730319	2017-07-28 21:56:00+03	64700.00
73039A	2017-07-02 16:54:00+03	24400.00
7303F3	2017-07-17 04:31:00+03	155600.00
730415	2017-07-12 05:45:00+03	71600.00
73042D	2017-07-30 12:35:00+03	86500.00
730448	2017-07-07 18:12:00+03	42000.00
7304E9	2017-07-17 09:57:00+03	19500.00
730523	2017-07-22 08:56:00+03	369000.00
73053D	2017-08-11 19:03:00+03	12000.00
730562	2017-07-19 15:19:00+03	66100.00
73056C	2017-07-14 16:50:00+03	179400.00
730609	2017-07-24 10:41:00+03	28000.00
73061D	2017-07-21 06:43:00+03	54800.00
730649	2017-08-06 09:16:00+03	43600.00
730675	2017-08-02 19:36:00+03	64800.00
7306BA	2017-07-12 03:59:00+03	62900.00
730703	2017-07-21 08:34:00+03	19500.00
730792	2017-07-07 22:02:00+03	79000.00
7307DE	2017-07-02 03:19:00+03	100600.00
7307EA	2017-07-25 14:17:00+03	6700.00
730827	2017-08-12 11:52:00+03	393800.00
730833	2017-07-02 15:06:00+03	146300.00
73086B	2017-07-16 06:45:00+03	45200.00
73089E	2017-06-30 18:52:00+03	266400.00
7308C4	2017-07-17 14:44:00+03	51600.00
7308E4	2017-08-07 08:40:00+03	100600.00
7308ED	2017-07-12 06:04:00+03	124200.00
730941	2017-07-11 14:32:00+03	24700.00
730994	2017-08-02 18:17:00+03	123000.00
73099A	2017-08-12 12:24:00+03	53800.00
7309C2	2017-07-12 00:14:00+03	58400.00
7309FD	2017-07-30 12:35:00+03	25600.00
730A58	2017-07-07 06:48:00+03	75300.00
730A5F	2017-07-20 19:20:00+03	92900.00
730AC3	2017-07-29 18:18:00+03	48400.00
730AE0	2017-08-15 13:16:00+03	13600.00
730B16	2017-07-27 04:03:00+03	49600.00
730B3D	2017-07-23 16:21:00+03	75000.00
730B4C	2017-07-05 04:42:00+03	27200.00
730B61	2017-07-02 07:48:00+03	16400.00
730B66	2017-07-09 12:02:00+03	271100.00
730B7E	2017-07-17 17:51:00+03	46400.00
730BC3	2017-07-03 07:56:00+03	24400.00
730C1F	2017-07-29 20:22:00+03	93900.00
730C53	2017-07-08 02:29:00+03	22600.00
730CBA	2017-08-01 14:25:00+03	6700.00
730CDA	2017-07-27 09:09:00+03	25000.00
730CDB	2017-07-09 07:53:00+03	22000.00
730D17	2017-08-04 09:28:00+03	72600.00
730DB7	2017-08-10 06:09:00+03	35200.00
730DFC	2017-07-31 01:08:00+03	209200.00
730E90	2017-08-01 16:25:00+03	114300.00
730EB3	2017-08-09 00:52:00+03	57300.00
730F15	2017-07-04 05:17:00+03	109600.00
730F94	2017-08-06 18:02:00+03	48500.00
7310BE	2017-07-17 12:43:00+03	246000.00
731108	2017-07-25 15:38:00+03	23200.00
73116A	2017-08-09 15:52:00+03	15000.00
731221	2017-07-09 08:27:00+03	10700.00
731248	2017-07-22 10:14:00+03	75300.00
7312CF	2017-07-01 15:31:00+03	23200.00
731308	2017-07-23 01:22:00+03	30200.00
731321	2017-07-04 07:11:00+03	98200.00
731361	2017-08-15 14:36:00+03	131600.00
731475	2017-06-29 03:35:00+03	131100.00
73149D	2017-07-07 01:38:00+03	13300.00
7314CE	2017-08-06 10:36:00+03	133200.00
73156C	2017-07-15 15:30:00+03	246000.00
73167A	2017-07-08 14:16:00+03	65900.00
731718	2017-07-25 19:09:00+03	231400.00
73171A	2017-08-01 04:46:00+03	14000.00
731758	2017-08-12 20:11:00+03	129700.00
7317AA	2017-07-17 15:12:00+03	19600.00
7317D4	2017-07-18 23:07:00+03	122500.00
731817	2017-07-18 09:46:00+03	136200.00
731886	2017-07-23 00:23:00+03	78900.00
7318B0	2017-07-05 06:30:00+03	108500.00
7318EC	2017-08-13 19:21:00+03	82000.00
73192E	2017-08-12 20:14:00+03	21400.00
73194B	2017-08-09 11:13:00+03	23900.00
731957	2017-08-03 02:59:00+03	21800.00
7319CE	2017-07-30 08:06:00+03	136600.00
731A1D	2017-08-05 05:39:00+03	58900.00
731A34	2017-08-14 22:07:00+03	94800.00
731AA8	2017-08-12 16:38:00+03	36400.00
731B9B	2017-08-07 03:38:00+03	65200.00
731BA4	2017-07-27 23:35:00+03	92800.00
731BD2	2017-07-03 19:16:00+03	39300.00
731C20	2017-07-31 23:53:00+03	24400.00
731C35	2017-07-02 09:28:00+03	7200.00
731C74	2017-07-13 03:16:00+03	52400.00
731CBB	2017-08-01 21:02:00+03	27200.00
731D47	2017-07-10 10:52:00+03	12600.00
731D6D	2017-07-11 21:56:00+03	80000.00
731DAB	2017-07-14 07:37:00+03	133200.00
731EC8	2017-07-27 03:04:00+03	46000.00
731EDE	2017-07-13 04:28:00+03	26000.00
731EE3	2017-07-26 18:19:00+03	22000.00
731F18	2017-08-11 13:54:00+03	71000.00
731F43	2017-08-11 13:27:00+03	67600.00
73204F	2017-08-13 04:06:00+03	68400.00
732058	2017-08-10 12:58:00+03	72400.00
73206B	2017-07-08 17:27:00+03	14400.00
7320CC	2017-07-13 18:43:00+03	152100.00
7320E2	2017-08-07 05:14:00+03	8400.00
7320E5	2017-08-02 23:49:00+03	88800.00
73217C	2017-07-09 00:06:00+03	24400.00
732193	2017-07-11 20:57:00+03	70700.00
7321C5	2017-07-08 13:31:00+03	47700.00
732255	2017-08-09 14:55:00+03	91600.00
732294	2017-07-17 18:52:00+03	87200.00
732298	2017-07-12 19:24:00+03	23600.00
73229B	2017-08-15 00:49:00+03	26000.00
7322A2	2017-07-09 02:37:00+03	69500.00
7322EA	2017-07-23 14:16:00+03	14000.00
732358	2017-08-12 11:37:00+03	81300.00
7323CF	2017-08-14 15:32:00+03	65500.00
732403	2017-07-04 10:47:00+03	491000.00
732462	2017-07-30 14:50:00+03	92400.00
73247F	2017-08-13 15:59:00+03	123000.00
732492	2017-08-06 23:29:00+03	49600.00
7324C1	2017-07-10 11:07:00+03	23600.00
7324DA	2017-07-18 02:47:00+03	6800.00
732521	2017-07-17 12:36:00+03	32200.00
732531	2017-07-06 07:18:00+03	38800.00
732552	2017-07-28 18:18:00+03	32800.00
732562	2017-07-13 07:43:00+03	66600.00
73256B	2017-07-19 06:11:00+03	336200.00
73264E	2017-07-31 05:12:00+03	23600.00
732670	2017-08-13 01:15:00+03	135600.00
7326B5	2017-08-11 19:55:00+03	112200.00
7326B8	2017-08-01 20:15:00+03	23400.00
7326BC	2017-07-05 16:05:00+03	30200.00
7326F3	2017-07-13 02:42:00+03	18000.00
732711	2017-07-03 05:54:00+03	64500.00
73273B	2017-07-02 14:36:00+03	31600.00
732793	2017-08-04 03:21:00+03	78200.00
7327C3	2017-08-08 06:05:00+03	12400.00
7327F5	2017-07-08 11:28:00+03	62100.00
732827	2017-07-24 23:05:00+03	28000.00
73295D	2017-07-22 14:22:00+03	24800.00
732985	2017-08-12 02:29:00+03	22000.00
7329D7	2017-07-18 21:08:00+03	48800.00
732A2F	2017-07-21 17:01:00+03	137600.00
732A3E	2017-08-07 19:41:00+03	12800.00
732A6A	2017-08-02 19:20:00+03	8400.00
732ACD	2017-08-13 23:24:00+03	32800.00
732AD6	2017-08-14 22:43:00+03	80800.00
732ADE	2017-08-12 11:55:00+03	70600.00
732AFF	2017-08-09 15:33:00+03	106900.00
732B5F	2017-07-19 00:07:00+03	46200.00
732BC0	2017-08-15 05:19:00+03	35200.00
732C2C	2017-07-07 22:27:00+03	50000.00
732CAC	2017-07-23 21:03:00+03	63400.00
732CFE	2017-07-07 16:41:00+03	14800.00
732D2E	2017-07-10 13:09:00+03	226200.00
732D3F	2017-07-30 08:38:00+03	24400.00
732DCF	2017-08-05 06:30:00+03	249100.00
732DFC	2017-07-12 16:43:00+03	29600.00
732E53	2017-08-08 04:36:00+03	47000.00
732E6B	2017-07-22 12:55:00+03	139700.00
732E8F	2017-08-03 14:36:00+03	86600.00
732EBB	2017-07-27 23:25:00+03	32000.00
732EF1	2017-08-01 21:10:00+03	312600.00
732F29	2017-07-18 14:25:00+03	58000.00
732F52	2017-08-02 00:44:00+03	99200.00
732F6C	2017-07-26 20:06:00+03	117600.00
732FAE	2017-07-19 20:35:00+03	23200.00
732FC4	2017-07-20 19:11:00+03	185600.00
733021	2017-07-07 06:38:00+03	12400.00
733036	2017-07-25 19:05:00+03	6700.00
73307B	2017-08-04 22:38:00+03	212400.00
7330BB	2017-08-11 06:39:00+03	8000.00
7330F1	2017-08-04 16:58:00+03	172300.00
7330FF	2017-07-22 08:26:00+03	430800.00
733119	2017-07-24 18:18:00+03	84800.00
733127	2017-07-27 09:17:00+03	32200.00
73321E	2017-07-28 05:41:00+03	42700.00
733279	2017-07-31 05:00:00+03	109000.00
73327F	2017-07-02 04:26:00+03	89600.00
7332E6	2017-08-03 02:28:00+03	110500.00
7332FC	2017-07-25 10:55:00+03	46500.00
73335B	2017-07-25 09:35:00+03	224000.00
73342A	2017-07-23 12:38:00+03	72400.00
73354F	2017-07-27 14:58:00+03	99000.00
73355A	2017-07-01 16:09:00+03	42800.00
733572	2017-08-05 00:22:00+03	69500.00
7335E6	2017-07-17 08:25:00+03	127900.00
733613	2017-08-06 22:42:00+03	187900.00
733657	2017-08-01 08:28:00+03	123000.00
733707	2017-07-16 03:10:00+03	46200.00
73370A	2017-07-07 16:23:00+03	81700.00
733775	2017-08-06 13:21:00+03	46800.00
7337AD	2017-07-01 11:51:00+03	84800.00
7337B8	2017-07-21 03:34:00+03	103100.00
73380E	2017-07-14 07:01:00+03	42700.00
73384B	2017-07-24 00:58:00+03	21400.00
7338AC	2017-08-05 23:24:00+03	212800.00
733971	2017-07-19 19:38:00+03	19800.00
73397B	2017-07-28 08:01:00+03	56100.00
733988	2017-07-28 14:06:00+03	50800.00
733A33	2017-07-26 03:54:00+03	146400.00
733A47	2017-07-06 14:16:00+03	24200.00
733AB6	2017-07-23 01:55:00+03	286700.00
733B98	2017-08-07 06:18:00+03	80400.00
733C10	2017-07-22 10:51:00+03	69900.00
733C91	2017-08-12 14:00:00+03	135200.00
733CE9	2017-08-08 21:24:00+03	176600.00
733D02	2017-07-30 11:01:00+03	50100.00
733D1A	2017-07-08 08:45:00+03	87100.00
733D25	2017-07-11 00:35:00+03	28700.00
733D38	2017-08-14 21:39:00+03	8200.00
733D42	2017-07-18 00:50:00+03	32800.00
733DFD	2017-07-30 07:57:00+03	23200.00
733E59	2017-08-02 00:37:00+03	134400.00
733F29	2017-07-15 15:42:00+03	184200.00
733F31	2017-07-07 08:58:00+03	65000.00
733F85	2017-07-16 12:34:00+03	30200.00
733F90	2017-08-09 10:56:00+03	57300.00
734012	2017-07-15 23:37:00+03	13700.00
734014	2017-07-26 22:37:00+03	26000.00
734034	2017-07-08 15:13:00+03	135000.00
73405B	2017-07-06 07:55:00+03	45200.00
734087	2017-07-08 07:42:00+03	49800.00
734097	2017-08-09 07:37:00+03	125200.00
7340AE	2017-07-20 12:32:00+03	18600.00
7340C4	2017-07-18 13:57:00+03	46700.00
73411C	2017-07-18 14:27:00+03	63000.00
73412E	2017-07-13 01:02:00+03	14000.00
734141	2017-07-30 14:58:00+03	116400.00
734158	2017-07-08 11:28:00+03	58800.00
7341AE	2017-06-27 21:58:00+03	46900.00
734203	2017-07-21 02:26:00+03	77200.00
73422E	2017-08-12 02:16:00+03	94000.00
73429F	2017-07-23 12:46:00+03	258000.00
7342C8	2017-07-22 01:29:00+03	193600.00
73430B	2017-07-31 17:39:00+03	43200.00
734367	2017-07-16 10:01:00+03	53500.00
734400	2017-07-02 04:56:00+03	36800.00
734414	2017-07-04 10:22:00+03	75600.00
73443E	2017-08-03 17:12:00+03	68400.00
73447C	2017-07-16 09:53:00+03	27900.00
7344CF	2017-07-20 13:19:00+03	14000.00
734513	2017-08-06 17:36:00+03	25900.00
73455E	2017-08-03 20:38:00+03	48700.00
734567	2017-07-29 15:58:00+03	271100.00
73456A	2017-07-22 21:08:00+03	291000.00
73457A	2017-07-08 18:07:00+03	56900.00
73459E	2017-07-23 02:12:00+03	53400.00
7345ED	2017-07-27 04:33:00+03	22100.00
73461F	2017-07-22 21:53:00+03	258300.00
73468B	2017-08-15 14:22:00+03	72300.00
7346A1	2017-08-10 19:03:00+03	62200.00
7346BB	2017-08-03 11:33:00+03	77000.00
73471E	2017-08-12 00:21:00+03	109200.00
734729	2017-08-13 15:26:00+03	118600.00
734731	2017-08-10 13:47:00+03	10700.00
734736	2017-08-05 15:37:00+03	28000.00
73477A	2017-08-05 08:00:00+03	13200.00
734835	2017-07-06 09:05:00+03	34000.00
7348D9	2017-07-13 02:49:00+03	213600.00
7348F3	2017-08-06 21:59:00+03	214100.00
734951	2017-07-13 06:51:00+03	6000.00
73496F	2017-07-24 01:50:00+03	59200.00
734AEB	2017-07-27 19:29:00+03	174300.00
734B51	2017-08-03 17:04:00+03	6700.00
734BDB	2017-08-15 11:18:00+03	62700.00
734BF2	2017-08-09 05:35:00+03	30700.00
734BF4	2017-07-31 04:41:00+03	25100.00
734C58	2017-07-21 10:23:00+03	123000.00
734C9E	2017-08-15 16:15:00+03	32800.00
734D0D	2017-08-11 16:59:00+03	20600.00
734D15	2017-07-31 19:36:00+03	78100.00
734D2C	2017-08-01 21:06:00+03	13600.00
734DB2	2017-07-09 03:07:00+03	28000.00
734DDC	2017-07-14 09:27:00+03	57600.00
734E46	2017-07-08 20:55:00+03	153900.00
734E98	2017-08-12 12:11:00+03	252200.00
734EC2	2017-08-11 14:01:00+03	40000.00
734F99	2017-08-11 14:44:00+03	207400.00
735007	2017-07-15 04:40:00+03	28000.00
73501F	2017-07-17 15:34:00+03	47500.00
735080	2017-07-10 23:11:00+03	28000.00
7350F2	2017-08-06 12:00:00+03	97600.00
7351A5	2017-08-15 09:01:00+03	135800.00
7351B9	2017-07-25 15:00:00+03	136200.00
7351D8	2017-08-15 01:58:00+03	99200.00
7351DC	2017-06-28 11:36:00+03	59800.00
735310	2017-08-08 07:56:00+03	42700.00
735383	2017-08-11 15:59:00+03	205700.00
7353AC	2017-07-21 20:52:00+03	55000.00
7353AF	2017-06-28 10:45:00+03	24800.00
7353D1	2017-07-10 06:38:00+03	7400.00
7353E1	2017-07-12 19:26:00+03	115700.00
735438	2017-07-10 01:11:00+03	46400.00
735449	2017-08-13 17:08:00+03	55800.00
7354A6	2017-08-03 03:12:00+03	77500.00
735549	2017-08-05 03:00:00+03	43500.00
735552	2017-08-07 06:25:00+03	58900.00
73556B	2017-07-05 05:50:00+03	39400.00
735575	2017-07-21 14:24:00+03	67600.00
73560C	2017-08-07 02:19:00+03	24800.00
735623	2017-07-29 08:09:00+03	47400.00
735661	2017-07-17 13:11:00+03	132800.00
735674	2017-07-08 22:59:00+03	265700.00
7356B6	2017-08-15 11:24:00+03	67600.00
7356C4	2017-07-07 14:18:00+03	24600.00
7356E9	2017-07-07 12:11:00+03	148700.00
735703	2017-07-26 07:56:00+03	65900.00
7357E2	2017-07-15 14:56:00+03	57400.00
73580D	2017-07-17 22:47:00+03	135400.00
735817	2017-07-27 04:02:00+03	20200.00
735860	2017-07-20 16:19:00+03	26800.00
735872	2017-08-10 14:59:00+03	73600.00
7358AA	2017-08-02 22:33:00+03	24400.00
7358EF	2017-08-09 23:05:00+03	60400.00
735911	2017-07-09 21:58:00+03	63200.00
73593A	2017-07-23 17:03:00+03	24200.00
7359A4	2017-07-31 12:28:00+03	97900.00
7359B9	2017-07-30 21:22:00+03	35200.00
7359BE	2017-07-06 03:26:00+03	111600.00
7359EB	2017-08-07 09:26:00+03	67700.00
7359EE	2017-07-06 13:58:00+03	58800.00
735A0B	2017-07-23 19:54:00+03	28800.00
735A22	2017-07-20 07:54:00+03	45100.00
735A82	2017-07-16 09:53:00+03	26000.00
735AA9	2017-07-23 08:01:00+03	201800.00
735AB6	2017-07-08 11:57:00+03	23200.00
735AD6	2017-08-10 10:29:00+03	56400.00
735AEC	2017-07-22 21:59:00+03	147100.00
735AFC	2017-07-17 15:35:00+03	103500.00
735B26	2017-08-14 15:38:00+03	30200.00
735B77	2017-08-03 10:57:00+03	250600.00
735B90	2017-07-06 05:28:00+03	77200.00
735C26	2017-08-03 22:53:00+03	73900.00
735C92	2017-07-28 18:01:00+03	45100.00
735D32	2017-07-22 05:10:00+03	60400.00
735D8D	2017-08-09 23:37:00+03	149900.00
735DA2	2017-08-02 20:20:00+03	32800.00
735DBA	2017-07-18 02:43:00+03	34000.00
735DC9	2017-07-26 10:15:00+03	57400.00
735DD4	2017-08-08 13:54:00+03	13600.00
735E77	2017-07-01 00:13:00+03	16000.00
735EBA	2017-06-29 01:31:00+03	135400.00
735F14	2017-07-09 16:16:00+03	178100.00
735FB8	2017-06-27 17:23:00+03	44000.00
735FCC	2017-07-24 08:28:00+03	84500.00
735FD9	2017-07-23 01:21:00+03	48400.00
736019	2017-08-01 22:35:00+03	26800.00
736039	2017-07-21 10:29:00+03	16400.00
7360B5	2017-08-10 06:51:00+03	277800.00
7360F8	2017-08-02 15:09:00+03	101200.00
7360FC	2017-08-11 11:21:00+03	40000.00
736128	2017-08-14 06:34:00+03	41200.00
736216	2017-07-05 01:53:00+03	27200.00
736237	2017-07-05 15:12:00+03	67000.00
736250	2017-08-12 04:13:00+03	168000.00
73626A	2017-08-07 03:24:00+03	59000.00
73627C	2017-07-13 23:18:00+03	55800.00
736293	2017-07-23 09:00:00+03	62600.00
7362DC	2017-07-30 13:16:00+03	43400.00
736392	2017-07-26 09:01:00+03	101800.00
7363AB	2017-08-11 07:23:00+03	30000.00
736451	2017-08-15 09:44:00+03	77500.00
736469	2017-08-03 00:19:00+03	20400.00
7364B5	2017-07-26 06:00:00+03	53600.00
7364CD	2017-07-14 19:47:00+03	23400.00
7364D8	2017-07-19 03:28:00+03	29400.00
7364DC	2017-08-03 03:47:00+03	32900.00
7364FA	2017-08-11 15:39:00+03	82000.00
736565	2017-08-01 13:10:00+03	19600.00
73656D	2017-07-21 19:00:00+03	46400.00
736582	2017-08-15 00:26:00+03	20200.00
7365DB	2017-07-17 18:13:00+03	28300.00
73662A	2017-08-03 03:24:00+03	34000.00
736760	2017-08-08 06:59:00+03	56600.00
736767	2017-08-14 13:28:00+03	123600.00
73676C	2017-07-08 09:26:00+03	64500.00
736779	2017-07-30 12:23:00+03	99700.00
736783	2017-07-09 09:32:00+03	79200.00
7367BD	2017-08-13 03:05:00+03	40600.00
7367D7	2017-07-16 23:06:00+03	38600.00
736846	2017-08-04 06:52:00+03	105600.00
736849	2017-07-16 03:58:00+03	146300.00
73686D	2017-07-11 16:01:00+03	27900.00
736895	2017-07-02 21:01:00+03	529800.00
7368A1	2017-07-21 09:02:00+03	34800.00
736970	2017-07-26 22:54:00+03	57800.00
736A47	2017-07-26 04:35:00+03	72400.00
736A54	2017-07-26 03:36:00+03	32400.00
736A61	2017-06-30 15:27:00+03	109600.00
736AED	2017-06-25 21:45:00+03	56100.00
736B4E	2017-07-14 11:25:00+03	193700.00
736B50	2017-07-16 16:11:00+03	36200.00
736B8C	2017-07-22 04:41:00+03	67600.00
736B9A	2017-08-08 17:38:00+03	69500.00
736BAD	2017-08-09 14:17:00+03	84500.00
736BE4	2017-08-10 14:32:00+03	47400.00
736C12	2017-07-12 18:25:00+03	260900.00
736C86	2017-08-02 05:03:00+03	112000.00
736CB0	2017-07-23 05:09:00+03	50800.00
736CB1	2017-06-30 04:36:00+03	14000.00
736CFC	2017-08-11 23:54:00+03	133200.00
736D04	2017-08-15 10:24:00+03	32800.00
736DA3	2017-07-18 01:58:00+03	62800.00
736DEC	2017-07-25 11:53:00+03	37100.00
736DFE	2017-07-23 13:47:00+03	63000.00
736E3B	2017-07-07 05:33:00+03	23200.00
736E61	2017-07-20 08:58:00+03	34800.00
736E70	2017-08-07 20:35:00+03	111600.00
736EFA	2017-07-31 14:30:00+03	378700.00
736F32	2017-08-08 20:20:00+03	57500.00
736F99	2017-07-09 00:39:00+03	84800.00
737022	2017-07-17 11:23:00+03	92400.00
737045	2017-08-12 16:20:00+03	155600.00
73707E	2017-08-09 06:28:00+03	102000.00
7370A8	2017-07-31 09:29:00+03	46400.00
7370E1	2017-08-05 09:13:00+03	72400.00
7370F4	2017-07-10 09:20:00+03	60800.00
737171	2017-08-10 17:34:00+03	32800.00
7371C1	2017-07-27 10:04:00+03	65500.00
737233	2017-08-13 05:03:00+03	88800.00
73724A	2017-07-05 14:27:00+03	13400.00
737253	2017-07-06 21:01:00+03	81600.00
73728B	2017-07-06 10:10:00+03	138100.00
7373AE	2017-07-15 15:13:00+03	22000.00
737445	2017-07-14 22:30:00+03	54300.00
7374E0	2017-08-12 20:05:00+03	44000.00
73757F	2017-06-29 11:11:00+03	132800.00
73759A	2017-07-08 00:48:00+03	58200.00
7375D2	2017-07-05 17:15:00+03	89000.00
73760A	2017-07-09 15:05:00+03	50800.00
73763D	2017-07-03 18:24:00+03	46400.00
7376A1	2017-07-17 06:17:00+03	265800.00
73770B	2017-07-15 09:44:00+03	108200.00
737732	2017-07-31 21:08:00+03	61800.00
737753	2017-07-11 00:08:00+03	246000.00
737773	2017-07-10 08:50:00+03	466800.00
73778B	2017-07-13 16:23:00+03	36200.00
737865	2017-08-07 07:24:00+03	18600.00
737873	2017-08-14 12:47:00+03	166900.00
73788B	2017-08-11 16:18:00+03	21400.00
7378C2	2017-08-15 10:34:00+03	21400.00
7378CC	2017-07-19 20:36:00+03	56000.00
7378EB	2017-07-17 03:45:00+03	37100.00
737902	2017-07-24 18:30:00+03	120700.00
737913	2017-07-21 13:31:00+03	17200.00
737916	2017-07-10 03:57:00+03	39200.00
737920	2017-07-10 14:44:00+03	42700.00
7379DB	2017-08-12 12:56:00+03	55000.00
737A1E	2017-07-27 11:32:00+03	59800.00
737A3F	2017-08-02 23:57:00+03	25200.00
737A5D	2017-07-05 09:45:00+03	24400.00
737A71	2017-07-19 14:03:00+03	19600.00
737A74	2017-07-05 10:13:00+03	87100.00
737AB3	2017-06-29 14:45:00+03	32200.00
737B38	2017-07-16 06:14:00+03	30800.00
737BC5	2017-08-04 01:39:00+03	270600.00
737C04	2017-07-01 01:05:00+03	24400.00
737C09	2017-07-02 18:11:00+03	85700.00
737C70	2017-07-05 07:14:00+03	11200.00
737C92	2017-08-14 07:28:00+03	160800.00
737D01	2017-08-03 22:14:00+03	57400.00
737D24	2017-07-13 09:30:00+03	15000.00
737D37	2017-08-10 01:14:00+03	99200.00
737D7B	2017-07-21 22:46:00+03	116000.00
737D95	2017-07-10 10:10:00+03	28800.00
737E5A	2017-07-21 01:54:00+03	67600.00
737E5B	2017-07-06 22:37:00+03	55000.00
737E94	2017-08-07 16:51:00+03	31200.00
737E99	2017-07-29 16:35:00+03	21400.00
737EA4	2017-08-15 07:16:00+03	31400.00
737EB0	2017-07-23 03:07:00+03	112000.00
737EE2	2017-07-07 17:13:00+03	103800.00
737F0D	2017-07-22 11:02:00+03	188000.00
737FEB	2017-08-14 05:42:00+03	27300.00
738014	2017-07-16 23:25:00+03	26800.00
738044	2017-07-29 03:05:00+03	29600.00
7380AB	2017-08-01 13:43:00+03	45200.00
738111	2017-07-20 04:06:00+03	28000.00
73818E	2017-07-12 15:48:00+03	249100.00
738193	2017-07-31 00:34:00+03	84000.00
738233	2017-06-29 06:43:00+03	91500.00
738239	2017-07-01 20:25:00+03	47200.00
738306	2017-07-03 22:58:00+03	40800.00
738325	2017-08-15 13:35:00+03	62200.00
738365	2017-07-09 20:03:00+03	36800.00
738380	2017-07-25 11:28:00+03	43600.00
738465	2017-07-09 20:01:00+03	67600.00
738467	2017-08-02 17:41:00+03	55600.00
738471	2017-07-25 23:22:00+03	123000.00
738489	2017-07-28 07:43:00+03	233800.00
7384AB	2017-07-13 13:01:00+03	153200.00
738557	2017-07-24 09:32:00+03	93700.00
73857F	2017-07-21 13:38:00+03	130800.00
7385F6	2017-08-09 05:50:00+03	47100.00
73867D	2017-07-19 16:34:00+03	96300.00
7386CB	2017-07-04 11:43:00+03	27200.00
738708	2017-07-27 23:35:00+03	292800.00
73871A	2017-07-13 10:47:00+03	154800.00
738773	2017-08-10 23:15:00+03	24800.00
738787	2017-07-27 01:52:00+03	64800.00
7387D0	2017-07-30 19:41:00+03	26000.00
73882D	2017-08-01 16:31:00+03	15000.00
738846	2017-07-08 11:49:00+03	13400.00
73886B	2017-07-01 13:54:00+03	8000.00
73887A	2017-08-02 20:44:00+03	62600.00
7388F2	2017-08-04 14:33:00+03	42800.00
73897C	2017-08-14 16:05:00+03	166100.00
7389C4	2017-08-06 07:38:00+03	155600.00
7389F6	2017-07-03 20:29:00+03	22000.00
7389FA	2017-07-24 17:19:00+03	20100.00
738A16	2017-07-16 04:21:00+03	62200.00
738A36	2017-07-27 04:42:00+03	560700.00
738A43	2017-07-14 13:02:00+03	56000.00
738A82	2017-08-03 14:39:00+03	46000.00
738B8F	2017-08-07 10:44:00+03	16800.00
738C68	2017-07-30 10:02:00+03	189200.00
738C7B	2017-07-27 07:30:00+03	64300.00
738C86	2017-08-14 14:57:00+03	69500.00
738CA2	2017-07-10 15:40:00+03	134900.00
738CA7	2017-07-04 18:51:00+03	20000.00
738CD8	2017-07-30 13:14:00+03	76600.00
738D2A	2017-08-05 13:04:00+03	297900.00
738D45	2017-07-06 17:15:00+03	66600.00
738D91	2017-08-04 22:20:00+03	30000.00
738E3D	2017-08-13 11:32:00+03	409800.00
738EAF	2017-07-19 20:51:00+03	6400.00
738EDA	2017-07-12 15:40:00+03	37200.00
73900A	2017-08-01 10:08:00+03	153100.00
73903E	2017-07-13 18:48:00+03	101400.00
739042	2017-08-14 17:34:00+03	102100.00
739052	2017-08-02 01:21:00+03	116000.00
7390BC	2017-08-13 20:21:00+03	7400.00
7390D5	2017-07-02 22:10:00+03	75600.00
7390E3	2017-07-17 11:12:00+03	47100.00
73912E	2017-08-12 04:04:00+03	65200.00
73914C	2017-07-22 03:37:00+03	135400.00
739165	2017-08-06 19:51:00+03	39100.00
739183	2017-07-12 23:28:00+03	31400.00
73925C	2017-07-20 08:33:00+03	6300.00
7392EA	2017-07-07 01:30:00+03	7400.00
7392F5	2017-07-04 09:33:00+03	46200.00
73930F	2017-07-28 09:26:00+03	111600.00
739480	2017-08-07 20:58:00+03	14800.00
7394EE	2017-08-12 12:27:00+03	30200.00
7394FB	2017-07-01 13:52:00+03	92800.00
739520	2017-07-23 22:08:00+03	156400.00
739525	2017-08-02 07:54:00+03	452600.00
739547	2017-08-11 17:45:00+03	171800.00
73956F	2017-08-06 07:34:00+03	39500.00
7395BB	2017-07-27 16:40:00+03	93000.00
7395EC	2017-07-28 10:57:00+03	8200.00
7395FF	2017-07-31 03:00:00+03	17800.00
73961D	2017-07-14 03:37:00+03	61800.00
7396B6	2017-08-08 13:21:00+03	75600.00
7396BF	2017-08-03 10:11:00+03	19600.00
7396C1	2017-08-05 17:13:00+03	67000.00
7396EB	2017-07-16 13:26:00+03	118700.00
739723	2017-07-02 04:09:00+03	56000.00
7397A8	2017-07-23 19:19:00+03	54800.00
73980A	2017-07-21 17:22:00+03	93900.00
739832	2017-07-20 23:20:00+03	12400.00
73984D	2017-07-08 22:39:00+03	48800.00
7398CA	2017-07-07 04:27:00+03	43600.00
7398F9	2017-08-02 20:04:00+03	578200.00
73992C	2017-07-12 23:08:00+03	66000.00
73993B	2017-07-02 18:11:00+03	167400.00
739A41	2017-07-11 14:04:00+03	25600.00
739A45	2017-07-19 03:16:00+03	23400.00
739A60	2017-08-07 22:18:00+03	43200.00
739B69	2017-08-08 16:40:00+03	45200.00
739B70	2017-07-24 05:07:00+03	186000.00
739B7B	2017-07-04 06:50:00+03	75300.00
739BCA	2017-08-02 09:08:00+03	24200.00
739C3A	2017-08-11 10:38:00+03	15700.00
739C4A	2017-07-19 04:20:00+03	14000.00
739CA6	2017-07-18 03:07:00+03	44800.00
739CCC	2017-07-28 16:31:00+03	36200.00
739D4B	2017-07-21 04:02:00+03	24800.00
739D6F	2017-08-14 04:12:00+03	149300.00
739D80	2017-07-05 17:46:00+03	152600.00
739DA6	2017-07-07 18:48:00+03	113800.00
739DD8	2017-08-03 11:57:00+03	95600.00
739DE5	2017-08-13 06:10:00+03	51800.00
739E36	2017-08-13 03:49:00+03	28000.00
739E53	2017-07-14 04:56:00+03	148200.00
739E95	2017-08-07 23:53:00+03	135600.00
739ED8	2017-07-16 03:30:00+03	88300.00
739F42	2017-08-15 12:33:00+03	40200.00
739FBC	2017-08-01 07:15:00+03	26000.00
739FDA	2017-08-01 15:52:00+03	142400.00
73A03D	2017-07-21 15:07:00+03	179400.00
73A054	2017-07-27 05:43:00+03	30200.00
73A067	2017-07-18 13:26:00+03	54000.00
73A09D	2017-08-06 06:58:00+03	112000.00
73A0A1	2017-07-07 08:46:00+03	24300.00
73A0E1	2017-07-21 04:21:00+03	37900.00
73A0E4	2017-07-04 14:19:00+03	369000.00
73A144	2017-07-12 02:05:00+03	246000.00
73A1F4	2017-08-09 23:34:00+03	63800.00
73A1FA	2017-07-19 15:04:00+03	114800.00
73A269	2017-08-15 00:34:00+03	23200.00
73A34A	2017-08-12 11:22:00+03	149200.00
73A353	2017-07-24 20:26:00+03	6000.00
73A35A	2017-07-05 05:42:00+03	13600.00
73A385	2017-07-21 14:41:00+03	196800.00
73A386	2017-07-08 13:40:00+03	273200.00
73A3FE	2017-07-27 09:23:00+03	55800.00
73A43A	2017-07-09 06:19:00+03	177200.00
73A49B	2017-08-05 01:50:00+03	47000.00
73A4D7	2017-08-05 00:53:00+03	46000.00
73A52E	2017-07-17 03:43:00+03	26800.00
73A534	2017-07-10 20:44:00+03	155600.00
73A53B	2017-07-16 00:21:00+03	354200.00
73A562	2017-08-13 15:36:00+03	31400.00
73A59E	2017-07-21 09:31:00+03	27400.00
73A5B9	2017-07-16 08:38:00+03	136800.00
73A651	2017-08-04 12:36:00+03	29600.00
73A658	2017-07-27 03:52:00+03	35800.00
73A6C8	2017-07-01 06:23:00+03	26000.00
73A807	2017-08-09 04:58:00+03	118600.00
73A810	2017-07-13 17:48:00+03	58600.00
73A871	2017-07-30 05:04:00+03	22000.00
73A8A3	2017-07-04 08:02:00+03	75300.00
73A8AA	2017-07-07 10:29:00+03	70400.00
73A9AD	2017-08-15 15:16:00+03	278400.00
73A9B3	2017-07-03 05:11:00+03	38800.00
73A9C5	2017-07-11 22:19:00+03	111600.00
73A9ED	2017-08-14 04:58:00+03	28000.00
73AA98	2017-07-17 08:26:00+03	14400.00
73AAE7	2017-08-08 17:18:00+03	102800.00
73AAF5	2017-07-27 07:35:00+03	16400.00
73AAF9	2017-08-11 18:33:00+03	291200.00
73AB4E	2017-07-03 09:17:00+03	147800.00
73AB51	2017-08-02 02:47:00+03	77900.00
73AC2A	2017-08-11 08:20:00+03	85200.00
73AC30	2017-07-15 03:53:00+03	28000.00
73AC44	2017-07-14 00:17:00+03	21500.00
73AC4E	2017-08-03 22:30:00+03	64400.00
73AC5D	2017-07-31 21:19:00+03	123000.00
73ACFA	2017-08-11 21:33:00+03	64400.00
73AD30	2017-06-28 08:35:00+03	88100.00
73ADFE	2017-08-03 20:45:00+03	96800.00
73AE28	2017-07-04 16:50:00+03	92900.00
73AE6B	2017-07-08 10:24:00+03	42900.00
73AEF3	2017-08-03 14:39:00+03	75200.00
73AF0A	2017-07-26 11:00:00+03	27200.00
73AF0B	2017-07-26 05:05:00+03	271100.00
73AFB1	2017-07-21 06:28:00+03	111600.00
73B02A	2017-07-27 11:43:00+03	300800.00
73B047	2017-08-09 08:29:00+03	152700.00
73B061	2017-07-06 15:24:00+03	23200.00
73B074	2017-07-06 11:32:00+03	112000.00
73B07E	2017-07-21 16:10:00+03	12600.00
73B085	2017-08-02 15:36:00+03	85000.00
73B0CE	2017-08-11 00:09:00+03	62800.00
73B0FA	2017-07-27 23:27:00+03	6000.00
73B0FF	2017-07-14 10:19:00+03	155400.00
73B104	2017-08-04 01:00:00+03	20400.00
73B105	2017-08-10 15:19:00+03	28800.00
73B129	2017-08-15 15:41:00+03	44800.00
73B13D	2017-08-09 05:02:00+03	75600.00
73B14F	2017-08-13 12:25:00+03	28800.00
73B16B	2017-08-13 23:10:00+03	56000.00
73B1BE	2017-08-15 01:13:00+03	123000.00
73B1D0	2017-07-16 20:58:00+03	22000.00
73B1D3	2017-08-15 07:01:00+03	34400.00
73B21E	2017-08-03 03:56:00+03	301900.00
73B23E	2017-07-29 19:14:00+03	84800.00
73B25A	2017-07-22 12:55:00+03	28800.00
73B269	2017-08-07 23:35:00+03	270800.00
73B299	2017-08-04 12:42:00+03	339800.00
73B2D7	2017-08-02 15:18:00+03	96200.00
73B32B	2017-07-22 00:25:00+03	122600.00
73B341	2017-08-08 18:20:00+03	56000.00
73B34F	2017-07-25 21:01:00+03	11600.00
73B371	2017-07-09 09:33:00+03	60700.00
73B3C5	2017-07-17 07:45:00+03	137100.00
73B3E7	2017-07-03 03:46:00+03	28000.00
73B450	2017-07-19 02:41:00+03	61800.00
73B47A	2017-07-07 05:09:00+03	286600.00
73B4A8	2017-07-28 03:24:00+03	74300.00
73B513	2017-08-04 19:21:00+03	140400.00
73B545	2017-07-19 05:53:00+03	33800.00
73B54E	2017-07-31 10:28:00+03	62000.00
73B5D3	2017-08-01 00:47:00+03	58800.00
73B5F2	2017-07-17 23:17:00+03	56000.00
73B653	2017-07-03 07:44:00+03	206400.00
73B672	2017-07-13 14:47:00+03	39100.00
73B67F	2017-07-30 21:47:00+03	73600.00
73B693	2017-08-15 10:42:00+03	38600.00
73B698	2017-07-12 09:30:00+03	133200.00
73B710	2017-08-10 16:25:00+03	21200.00
73B772	2017-08-09 15:43:00+03	10600.00
73B7B7	2017-06-28 01:42:00+03	38200.00
73B828	2017-08-02 05:51:00+03	14000.00
73B885	2017-07-12 10:42:00+03	49600.00
73B8B2	2017-08-04 01:20:00+03	246000.00
73B8D4	2017-07-23 04:00:00+03	127800.00
73B8EC	2017-08-15 09:09:00+03	201200.00
73B8EE	2017-07-25 17:44:00+03	23400.00
73B97A	2017-07-28 15:25:00+03	55800.00
73B98A	2017-08-11 15:43:00+03	6000.00
73B9DB	2017-07-23 15:00:00+03	12600.00
73B9EB	2017-07-05 22:13:00+03	23200.00
73B9F8	2017-08-13 09:32:00+03	35500.00
73BA5C	2017-07-02 17:30:00+03	63200.00
73BB8D	2017-08-09 09:18:00+03	62600.00
73BC27	2017-07-16 00:04:00+03	27400.00
73BC6B	2017-07-10 16:54:00+03	46400.00
73BC70	2017-07-04 16:53:00+03	58000.00
73BE0A	2017-08-09 21:30:00+03	83000.00
73BE3B	2017-08-15 15:05:00+03	92600.00
73BE5A	2017-07-17 03:29:00+03	113700.00
73BE65	2017-07-05 20:41:00+03	34000.00
73BE6D	2017-08-09 09:11:00+03	122200.00
73BE7B	2017-07-11 05:51:00+03	46300.00
73BE93	2017-07-31 11:51:00+03	185300.00
73BEE8	2017-07-16 01:50:00+03	23200.00
73C002	2017-07-30 10:55:00+03	32800.00
73C008	2017-07-14 13:01:00+03	58000.00
73C054	2017-07-23 15:08:00+03	68100.00
73C058	2017-08-10 00:40:00+03	21800.00
73C129	2017-08-10 06:59:00+03	67600.00
73C1E3	2017-07-02 13:46:00+03	59800.00
73C206	2017-07-27 00:17:00+03	136200.00
73C210	2017-07-18 00:08:00+03	160200.00
73C2E4	2017-07-18 07:33:00+03	39800.00
73C341	2017-08-12 03:52:00+03	45700.00
73C352	2017-08-05 07:18:00+03	22000.00
73C36B	2017-06-30 09:01:00+03	24400.00
73C37F	2017-07-21 10:25:00+03	55800.00
73C3D6	2017-07-05 20:05:00+03	92700.00
73C426	2017-07-24 09:07:00+03	46000.00
73C51E	2017-08-14 01:00:00+03	22000.00
73C52F	2017-08-09 03:31:00+03	47000.00
73C53D	2017-07-13 00:13:00+03	98700.00
73C556	2017-07-26 20:08:00+03	90000.00
73C5B1	2017-07-08 17:11:00+03	160500.00
73C648	2017-08-05 17:40:00+03	8400.00
73C671	2017-08-11 17:46:00+03	24000.00
73C67B	2017-07-20 13:52:00+03	28800.00
73C6F7	2017-08-02 23:13:00+03	51300.00
73C7E0	2017-07-05 21:17:00+03	57400.00
73C80D	2017-07-09 01:53:00+03	167500.00
73C80F	2017-08-04 10:58:00+03	111600.00
73C813	2017-07-12 22:05:00+03	86600.00
73C847	2017-07-24 01:05:00+03	329000.00
73C860	2017-07-12 07:22:00+03	53700.00
73C873	2017-08-08 11:43:00+03	290900.00
73C8A5	2017-08-08 18:57:00+03	91100.00
73C998	2017-07-14 01:01:00+03	123900.00
73C9A7	2017-08-09 11:19:00+03	64100.00
73C9C8	2017-07-25 20:38:00+03	46400.00
73C9DA	2017-08-10 04:08:00+03	86300.00
73C9E2	2017-08-04 08:27:00+03	53300.00
73CA71	2017-08-12 19:20:00+03	199700.00
73CA82	2017-07-05 13:46:00+03	28300.00
73CAA8	2017-07-11 11:15:00+03	85000.00
73CB0E	2017-07-27 11:30:00+03	39600.00
73CB55	2017-07-01 00:06:00+03	37900.00
73CB61	2017-07-31 01:12:00+03	167900.00
73CBCC	2017-07-12 02:23:00+03	76400.00
73CC30	2017-07-02 01:42:00+03	41400.00
73CC85	2017-08-14 09:53:00+03	64800.00
73CCD3	2017-07-04 13:21:00+03	240500.00
73CD55	2017-07-14 14:23:00+03	75600.00
73CDED	2017-07-20 03:16:00+03	105200.00
73CDF2	2017-07-29 06:19:00+03	67600.00
73CE02	2017-08-11 19:12:00+03	36200.00
73CE06	2017-08-06 19:10:00+03	13000.00
73CE10	2017-08-04 04:49:00+03	97600.00
73CE5B	2017-08-13 01:49:00+03	135600.00
73CE71	2017-07-16 06:05:00+03	50000.00
73CE81	2017-08-13 18:31:00+03	29600.00
73CEB8	2017-07-02 16:10:00+03	31400.00
73CEC5	2017-07-29 09:45:00+03	21800.00
73CF07	2017-07-24 00:51:00+03	44800.00
73CF60	2017-07-29 02:38:00+03	37200.00
73CF77	2017-07-26 08:46:00+03	29600.00
73CF7A	2017-07-08 02:40:00+03	118000.00
73CF9D	2017-07-02 08:45:00+03	26800.00
73D041	2017-07-20 14:06:00+03	666000.00
73D075	2017-07-07 09:03:00+03	24400.00
73D088	2017-06-30 19:16:00+03	25100.00
73D094	2017-08-13 02:38:00+03	13400.00
73D146	2017-07-20 12:45:00+03	131600.00
73D1FB	2017-07-26 00:40:00+03	49100.00
73D2AF	2017-07-30 17:11:00+03	10600.00
73D2C4	2017-07-21 13:08:00+03	8000.00
73D33C	2017-07-20 01:20:00+03	136200.00
73D347	2017-07-11 11:55:00+03	20800.00
73D39D	2017-06-29 03:35:00+03	58800.00
73D48C	2017-07-13 02:39:00+03	66600.00
73D4CC	2017-07-09 02:03:00+03	248400.00
73D4E6	2017-07-12 20:36:00+03	189800.00
73D4F6	2017-08-15 14:01:00+03	26800.00
73D4FB	2017-08-01 14:52:00+03	73500.00
73D51A	2017-07-27 13:02:00+03	111600.00
73D575	2017-07-15 19:00:00+03	26000.00
73D59C	2017-07-12 14:59:00+03	20800.00
73D5B6	2017-07-07 03:58:00+03	94200.00
73D5DE	2017-08-02 08:56:00+03	38600.00
73D5E0	2017-07-23 17:13:00+03	23200.00
73D63C	2017-06-29 03:25:00+03	28800.00
73D697	2017-07-19 09:50:00+03	36400.00
73D6F8	2017-08-10 01:30:00+03	109800.00
73D72E	2017-08-08 08:52:00+03	41600.00
73D775	2017-08-12 10:36:00+03	119500.00
73D7AC	2017-08-08 15:21:00+03	265700.00
73D7D0	2017-07-14 11:39:00+03	137100.00
73D929	2017-07-26 12:09:00+03	167400.00
73D93E	2017-07-21 17:55:00+03	64800.00
73D95E	2017-06-28 02:05:00+03	14000.00
73DA67	2017-08-02 04:31:00+03	85000.00
73DAAA	2017-07-03 15:05:00+03	56000.00
73DAC3	2017-07-06 09:16:00+03	74900.00
73DB57	2017-07-15 08:30:00+03	36200.00
73DB5A	2017-08-13 21:16:00+03	56600.00
73DB5F	2017-07-26 14:19:00+03	46300.00
73DB92	2017-07-06 10:13:00+03	64500.00
73DBA8	2017-08-01 13:19:00+03	26000.00
73DBB6	2017-08-09 13:19:00+03	147700.00
73DBF3	2017-08-14 13:02:00+03	28000.00
73DC21	2017-07-26 06:03:00+03	21400.00
73DC52	2017-07-30 04:44:00+03	47200.00
73DCD3	2017-08-05 15:25:00+03	86800.00
73DD00	2017-08-08 12:01:00+03	115700.00
73DDB5	2017-07-28 13:57:00+03	84100.00
73DDD2	2017-08-14 05:15:00+03	6000.00
73DE0D	2017-07-26 16:11:00+03	52400.00
73DE2E	2017-07-01 23:39:00+03	66900.00
73DE38	2017-07-23 00:37:00+03	6800.00
73DE66	2017-08-01 11:35:00+03	120700.00
73DE7F	2017-07-11 07:39:00+03	26000.00
73DEBD	2017-07-04 04:19:00+03	266400.00
73DEDA	2017-07-09 18:19:00+03	52700.00
73DEE9	2017-07-04 07:34:00+03	285000.00
73DEEE	2017-07-22 18:07:00+03	51600.00
73DF3B	2017-07-30 12:44:00+03	23600.00
73DF69	2017-07-02 01:56:00+03	47000.00
73DFAE	2017-07-30 08:36:00+03	31100.00
73DFFC	2017-06-29 07:45:00+03	92100.00
73E089	2017-07-08 19:01:00+03	51900.00
73E0C8	2017-08-08 00:28:00+03	40400.00
73E0E9	2017-07-17 17:30:00+03	133900.00
73E0EE	2017-07-17 20:58:00+03	31900.00
73E0FD	2017-07-13 04:36:00+03	24800.00
73E107	2017-07-06 03:50:00+03	77900.00
73E11B	2017-08-11 06:15:00+03	166900.00
73E128	2017-07-29 07:13:00+03	31600.00
73E14B	2017-07-20 10:54:00+03	21400.00
73E17D	2017-07-12 09:50:00+03	41800.00
73E180	2017-07-07 11:57:00+03	61500.00
73E1B9	2017-07-03 16:54:00+03	56900.00
73E257	2017-07-17 10:51:00+03	64800.00
73E260	2017-07-31 16:33:00+03	136800.00
73E2A7	2017-08-07 16:59:00+03	8000.00
73E32F	2017-08-15 09:55:00+03	32100.00
73E377	2017-08-12 18:36:00+03	57700.00
73E398	2017-07-21 09:27:00+03	22000.00
73E3F0	2017-07-10 00:52:00+03	55800.00
73E40E	2017-08-06 15:05:00+03	21200.00
73E446	2017-07-21 10:20:00+03	42700.00
73E4BE	2017-07-21 21:42:00+03	170800.00
73E4CB	2017-08-08 19:04:00+03	85000.00
73E5B3	2017-07-03 20:24:00+03	75600.00
73E5E8	2017-08-13 14:29:00+03	14400.00
73E60B	2017-07-27 22:10:00+03	85700.00
73E680	2017-08-11 20:22:00+03	103700.00
73E688	2017-07-10 04:20:00+03	246000.00
73E6C4	2017-08-11 07:27:00+03	78600.00
73E6EB	2017-07-24 11:07:00+03	54300.00
73E70E	2017-08-13 12:31:00+03	234600.00
73E715	2017-08-14 22:06:00+03	127300.00
73E828	2017-08-10 07:36:00+03	199200.00
73E85F	2017-07-16 16:40:00+03	6300.00
73E8FC	2017-07-30 23:46:00+03	68800.00
73E900	2017-07-14 12:59:00+03	240600.00
73E915	2017-07-09 18:23:00+03	45200.00
73E94B	2017-07-02 01:24:00+03	13600.00
73E96B	2017-08-01 15:38:00+03	27300.00
73E9AC	2017-08-07 18:38:00+03	89600.00
73EA3E	2017-07-18 16:59:00+03	158200.00
73EA62	2017-07-13 23:07:00+03	17600.00
73EA67	2017-07-17 09:11:00+03	166900.00
73EA91	2017-06-27 07:43:00+03	134000.00
73EAA5	2017-07-17 01:44:00+03	56000.00
73EB9D	2017-07-31 21:25:00+03	24400.00
73EBD9	2017-07-29 18:10:00+03	28000.00
73EBF0	2017-07-24 12:11:00+03	56600.00
73EC3A	2017-07-05 20:02:00+03	14000.00
73EC3C	2017-07-13 14:31:00+03	171300.00
73EC62	2017-07-14 00:29:00+03	48800.00
73ECD6	2017-07-18 07:31:00+03	25400.00
73ED17	2017-07-11 11:41:00+03	76900.00
73ED7C	2017-07-14 16:48:00+03	24400.00
73EDA4	2017-07-21 11:53:00+03	148200.00
73EE1A	2017-07-21 13:28:00+03	173500.00
73EE21	2017-07-23 13:16:00+03	194400.00
73EEE8	2017-08-10 04:47:00+03	258400.00
73EEE9	2017-08-10 12:19:00+03	99300.00
73EEF4	2017-07-13 19:37:00+03	265600.00
73EF04	2017-07-04 19:18:00+03	48800.00
73EF59	2017-08-03 06:36:00+03	32800.00
73EF80	2017-07-16 04:16:00+03	39600.00
73EF82	2017-08-10 20:51:00+03	16400.00
73EF8F	2017-07-20 08:08:00+03	137700.00
73EFC7	2017-07-06 04:34:00+03	36800.00
73F06B	2017-07-01 09:49:00+03	12600.00
73F08A	2017-06-30 05:50:00+03	65600.00
73F151	2017-07-26 20:14:00+03	57900.00
73F1B6	2017-07-17 06:18:00+03	193300.00
73F1BE	2017-07-06 18:13:00+03	23200.00
73F1E2	2017-08-09 00:04:00+03	28200.00
73F1F4	2017-07-08 04:43:00+03	89700.00
73F205	2017-07-29 09:43:00+03	6700.00
73F249	2017-07-07 01:20:00+03	6000.00
73F266	2017-06-30 01:58:00+03	44800.00
73F369	2017-08-15 04:45:00+03	115900.00
73F36D	2017-07-26 06:21:00+03	27900.00
73F399	2017-07-31 05:46:00+03	42800.00
73F3A0	2017-07-30 23:26:00+03	406200.00
73F3EE	2017-07-11 00:51:00+03	175300.00
73F41B	2017-07-02 11:31:00+03	48800.00
73F453	2017-08-01 07:32:00+03	133200.00
73F53C	2017-07-08 18:01:00+03	133200.00
73F5B7	2017-07-08 03:44:00+03	24400.00
73F5CE	2017-07-02 15:11:00+03	80700.00
73F615	2017-07-09 11:09:00+03	38800.00
73F655	2017-08-10 06:12:00+03	40000.00
73F6AE	2017-07-19 05:31:00+03	81600.00
73F6C4	2017-07-15 21:34:00+03	135400.00
73F73E	2017-07-08 11:20:00+03	25400.00
73F800	2017-08-10 19:10:00+03	48900.00
73F806	2017-07-14 03:49:00+03	85000.00
73F80B	2017-08-14 04:35:00+03	92400.00
73F80E	2017-07-25 18:27:00+03	103500.00
73F81A	2017-07-15 12:14:00+03	28800.00
73F81C	2017-07-05 07:26:00+03	28800.00
73F83B	2017-07-24 23:20:00+03	12600.00
73F840	2017-07-05 10:53:00+03	167400.00
73F841	2017-07-06 06:29:00+03	85000.00
73F88D	2017-08-10 20:30:00+03	36400.00
73F943	2017-08-11 00:32:00+03	48800.00
73F988	2017-08-02 08:03:00+03	112000.00
73F98C	2017-07-13 20:57:00+03	86500.00
73F9DB	2017-07-26 00:20:00+03	112200.00
73F9EA	2017-08-01 21:45:00+03	34000.00
73FA07	2017-07-02 11:48:00+03	11700.00
73FA66	2017-07-21 00:39:00+03	44000.00
73FA7A	2017-08-11 03:59:00+03	77500.00
73FA88	2017-08-04 10:03:00+03	81700.00
73FABD	2017-08-05 13:24:00+03	14800.00
73FB00	2017-08-14 15:09:00+03	67200.00
73FBE3	2017-08-07 07:15:00+03	25200.00
73FC04	2017-07-21 20:17:00+03	46400.00
73FC0E	2017-07-11 23:22:00+03	67000.00
73FC4D	2017-07-02 04:32:00+03	26000.00
73FC52	2017-08-05 04:42:00+03	21000.00
73FC5F	2017-07-17 18:58:00+03	20200.00
73FC68	2017-07-12 00:07:00+03	147200.00
73FCA5	2017-07-07 03:11:00+03	46400.00
73FD55	2017-08-06 18:04:00+03	101800.00
73FD94	2017-07-14 10:29:00+03	111600.00
73FDD0	2017-08-05 04:21:00+03	67100.00
73FE4F	2017-08-11 09:13:00+03	47200.00
73FE84	2017-08-06 09:20:00+03	32100.00
73FEC2	2017-08-08 21:07:00+03	65900.00
73FEDB	2017-07-09 22:37:00+03	86600.00
73FEEB	2017-08-03 21:32:00+03	36400.00
73FEED	2017-07-10 11:42:00+03	26000.00
73FEF6	2017-07-29 23:11:00+03	51600.00
73FF12	2017-08-07 12:54:00+03	46300.00
73FF97	2017-07-18 15:52:00+03	126000.00
73FFAD	2017-08-10 15:16:00+03	40400.00
73FFC5	2017-07-29 00:43:00+03	67200.00
74000D	2017-07-19 07:11:00+03	29600.00
740020	2017-08-14 08:19:00+03	75400.00
7400A1	2017-08-09 06:31:00+03	14400.00
7400CA	2017-07-12 00:21:00+03	58400.00
7400F0	2017-07-17 06:40:00+03	93900.00
740108	2017-07-10 05:33:00+03	399600.00
74012C	2017-07-02 08:21:00+03	10800.00
74013C	2017-08-09 17:17:00+03	67600.00
740198	2017-08-02 20:34:00+03	207300.00
740234	2017-08-07 17:26:00+03	23400.00
74029F	2017-07-20 18:52:00+03	46000.00
740316	2017-07-18 03:48:00+03	54000.00
740356	2017-08-09 10:25:00+03	248300.00
7403D1	2017-07-31 00:53:00+03	95200.00
7403F9	2017-07-06 14:50:00+03	58000.00
7403FB	2017-08-06 03:39:00+03	142800.00
740427	2017-07-06 17:23:00+03	185300.00
74044E	2017-06-30 01:14:00+03	34000.00
74045E	2017-07-31 13:43:00+03	79900.00
740584	2017-07-26 05:47:00+03	23600.00
7405E6	2017-08-15 00:17:00+03	179500.00
7405EC	2017-08-13 12:02:00+03	106800.00
740657	2017-08-08 12:42:00+03	20200.00
740659	2017-07-01 23:23:00+03	56600.00
74065A	2017-06-26 01:27:00+03	101200.00
7406CF	2017-07-26 09:22:00+03	72400.00
7406F8	2017-07-31 16:38:00+03	15400.00
740702	2017-07-18 10:29:00+03	133300.00
740850	2017-07-04 01:46:00+03	13000.00
7408A2	2017-08-14 13:08:00+03	30200.00
7408F0	2017-07-24 11:18:00+03	19600.00
740908	2017-07-04 08:04:00+03	54800.00
740988	2017-07-07 16:13:00+03	133200.00
74099D	2017-08-14 11:48:00+03	38600.00
7409AA	2017-07-03 04:38:00+03	36600.00
740A07	2017-07-27 13:49:00+03	47600.00
740A36	2017-07-16 08:58:00+03	56000.00
740A6D	2017-08-03 10:13:00+03	47400.00
740A84	2017-06-29 05:33:00+03	135600.00
740C54	2017-08-11 18:03:00+03	157200.00
740D6C	2017-07-16 06:22:00+03	118900.00
740D72	2017-07-07 21:46:00+03	23600.00
740E8F	2017-07-16 07:32:00+03	93400.00
740F09	2017-08-07 19:07:00+03	265700.00
740F49	2017-07-03 09:52:00+03	49900.00
740F73	2017-08-14 05:21:00+03	29600.00
741013	2017-07-08 09:40:00+03	56000.00
741015	2017-08-07 19:16:00+03	61800.00
7410F6	2017-08-08 05:39:00+03	68200.00
741112	2017-08-12 17:47:00+03	43200.00
741165	2017-08-12 13:28:00+03	6600.00
741166	2017-08-01 17:49:00+03	105600.00
741183	2017-07-06 10:11:00+03	34600.00
7411B4	2017-08-09 20:03:00+03	30200.00
7411D1	2017-07-29 04:15:00+03	63000.00
7411D3	2017-07-14 13:10:00+03	32800.00
741227	2017-07-04 15:19:00+03	62600.00
74123B	2017-07-14 00:28:00+03	46400.00
741252	2017-07-12 00:16:00+03	150600.00
741284	2017-08-14 00:26:00+03	46400.00
74129A	2017-07-10 05:19:00+03	57800.00
741328	2017-07-25 15:06:00+03	44600.00
741363	2017-07-08 09:28:00+03	88600.00
741373	2017-08-10 19:26:00+03	30800.00
7413D5	2017-07-19 15:12:00+03	57200.00
7414CE	2017-08-06 04:29:00+03	6300.00
7414E6	2017-07-29 12:40:00+03	168000.00
7414F8	2017-07-21 01:55:00+03	44600.00
7415AA	2017-07-23 12:10:00+03	71100.00
7415BD	2017-07-05 12:32:00+03	8200.00
74161B	2017-08-01 21:18:00+03	51900.00
741681	2017-07-29 16:22:00+03	68400.00
741718	2017-07-02 10:38:00+03	135600.00
741722	2017-07-27 11:15:00+03	66000.00
741723	2017-07-03 19:13:00+03	17200.00
741747	2017-08-08 14:03:00+03	44800.00
741748	2017-06-27 21:16:00+03	270500.00
741771	2017-07-10 15:21:00+03	288500.00
741844	2017-08-10 04:59:00+03	30400.00
741883	2017-07-22 17:15:00+03	75300.00
7418AD	2017-07-26 13:57:00+03	135400.00
741900	2017-07-08 22:22:00+03	97800.00
741923	2017-07-11 22:21:00+03	118600.00
741984	2017-07-25 19:49:00+03	144400.00
74199F	2017-06-29 02:58:00+03	65800.00
7419A4	2017-07-29 21:59:00+03	66000.00
741A0E	2017-07-15 09:18:00+03	10600.00
741B12	2017-08-04 09:37:00+03	408500.00
741B1E	2017-07-18 15:15:00+03	88000.00
741B8E	2017-08-02 23:56:00+03	56000.00
741BA0	2017-07-10 22:12:00+03	161200.00
741C57	2017-07-06 19:07:00+03	59100.00
741C7E	2017-07-29 05:12:00+03	134000.00
741C83	2017-07-12 08:47:00+03	40200.00
741CB6	2017-07-04 12:10:00+03	160200.00
741CF0	2017-08-14 18:35:00+03	72400.00
741D7D	2017-08-13 16:48:00+03	150300.00
741DFC	2017-07-19 02:05:00+03	51900.00
741E15	2017-07-19 03:01:00+03	35700.00
741E49	2017-08-07 16:15:00+03	147000.00
741E60	2017-07-16 23:13:00+03	112000.00
741E80	2017-07-05 10:49:00+03	155600.00
741EED	2017-07-09 11:44:00+03	21400.00
741F11	2017-07-08 14:39:00+03	59300.00
741F67	2017-07-23 18:33:00+03	56000.00
741FC6	2017-07-12 00:47:00+03	99200.00
741FD6	2017-07-04 15:17:00+03	378400.00
741FDF	2017-08-05 13:06:00+03	105000.00
7420D5	2017-07-01 16:57:00+03	123000.00
74210B	2017-07-31 02:24:00+03	10800.00
742151	2017-08-13 06:57:00+03	8000.00
742152	2017-07-03 19:22:00+03	58000.00
74215C	2017-07-11 21:20:00+03	23400.00
742244	2017-07-18 05:15:00+03	24400.00
742246	2017-08-09 04:42:00+03	44600.00
74237F	2017-08-12 23:52:00+03	39700.00
742388	2017-07-04 08:40:00+03	136000.00
7423A7	2017-07-05 02:39:00+03	44800.00
7423C8	2017-07-06 21:07:00+03	54800.00
74242A	2017-08-01 20:05:00+03	6700.00
7425D5	2017-07-14 03:49:00+03	13600.00
7425FE	2017-07-30 15:53:00+03	74900.00
74261E	2017-07-22 17:55:00+03	66600.00
742674	2017-07-04 08:23:00+03	68400.00
7426A4	2017-07-22 22:30:00+03	15200.00
7426A5	2017-08-01 18:37:00+03	132800.00
7426C2	2017-07-08 13:37:00+03	82400.00
7426E0	2017-07-29 13:26:00+03	34100.00
7426E8	2017-07-23 17:24:00+03	73200.00
7426EE	2017-07-11 09:05:00+03	43100.00
742760	2017-06-29 20:03:00+03	181700.00
7427BB	2017-07-24 12:19:00+03	158900.00
742818	2017-08-06 07:57:00+03	155600.00
742823	2017-07-02 22:05:00+03	63300.00
742862	2017-08-03 03:18:00+03	108800.00
7428B8	2017-07-17 00:57:00+03	24500.00
7428BD	2017-07-13 09:08:00+03	35200.00
7428DD	2017-08-08 05:39:00+03	273500.00
7429BC	2017-07-21 11:29:00+03	148200.00
7429DA	2017-07-28 00:11:00+03	22000.00
7429E1	2017-07-25 10:05:00+03	111600.00
742AA8	2017-07-24 03:53:00+03	112000.00
742B04	2017-07-24 14:59:00+03	68400.00
742BAA	2017-07-16 12:14:00+03	99600.00
742BAD	2017-08-11 14:11:00+03	59800.00
742BFB	2017-07-04 12:37:00+03	76900.00
742BFE	2017-07-10 03:45:00+03	27300.00
742C04	2017-07-06 15:10:00+03	92600.00
742C25	2017-08-14 02:35:00+03	43100.00
742C27	2017-07-19 14:36:00+03	40800.00
742C6D	2017-08-14 15:10:00+03	84500.00
742D38	2017-07-09 16:34:00+03	38600.00
742EE2	2017-07-12 21:14:00+03	169000.00
742F4E	2017-07-16 13:33:00+03	542200.00
742F6B	2017-07-02 19:28:00+03	57500.00
742F93	2017-07-15 04:40:00+03	46400.00
742FCA	2017-08-13 17:20:00+03	23600.00
743005	2017-08-11 08:25:00+03	112000.00
74309D	2017-08-13 08:58:00+03	75600.00
743127	2017-07-17 18:36:00+03	46300.00
743132	2017-07-10 11:24:00+03	63000.00
74315A	2017-07-18 04:53:00+03	52000.00
74315C	2017-08-03 02:29:00+03	6300.00
743180	2017-08-12 07:43:00+03	131100.00
743194	2017-07-08 21:58:00+03	157900.00
7431DC	2017-07-07 10:37:00+03	8400.00
7431DE	2017-08-03 14:17:00+03	51300.00
7431E3	2017-07-30 09:11:00+03	40000.00
74324C	2017-08-12 09:25:00+03	23200.00
7432B8	2017-07-22 05:40:00+03	140800.00
7432F3	2017-07-22 15:13:00+03	66600.00
74330B	2017-07-14 09:27:00+03	46200.00
74333C	2017-07-07 19:07:00+03	36400.00
743344	2017-07-04 14:48:00+03	56000.00
7433A8	2017-07-02 20:48:00+03	69500.00
743408	2017-07-20 07:51:00+03	82700.00
743419	2017-07-05 09:00:00+03	113700.00
743443	2017-07-28 15:53:00+03	288800.00
743463	2017-07-05 15:47:00+03	28800.00
7434FF	2017-07-31 06:17:00+03	16400.00
743513	2017-07-16 07:52:00+03	35200.00
74358C	2017-08-04 01:51:00+03	98200.00
74359E	2017-07-02 09:06:00+03	19600.00
7435B3	2017-07-28 20:47:00+03	93400.00
7435FA	2017-07-19 05:58:00+03	117200.00
743607	2017-08-07 06:29:00+03	170000.00
74364F	2017-08-15 01:04:00+03	8200.00
743698	2017-07-17 18:51:00+03	246000.00
7436C6	2017-07-19 03:57:00+03	54800.00
743747	2017-07-06 11:54:00+03	39100.00
743748	2017-07-08 21:45:00+03	23200.00
7437E4	2017-08-09 22:36:00+03	46200.00
743839	2017-07-17 23:48:00+03	100600.00
74387F	2017-07-20 03:12:00+03	246000.00
74394E	2017-08-10 01:28:00+03	25600.00
743973	2017-07-30 14:10:00+03	66600.00
743993	2017-08-14 18:01:00+03	75300.00
743999	2017-07-16 05:04:00+03	85000.00
7439C2	2017-07-15 19:49:00+03	12300.00
7439C5	2017-07-03 12:12:00+03	19600.00
743A1F	2017-07-28 23:51:00+03	195800.00
743A43	2017-08-09 00:33:00+03	88800.00
743A87	2017-07-24 18:10:00+03	67600.00
743A9A	2017-07-24 05:23:00+03	128800.00
743AA0	2017-07-16 18:56:00+03	41800.00
743AA6	2017-07-22 18:28:00+03	289800.00
743B18	2017-07-11 14:22:00+03	232800.00
743B65	2017-08-05 20:50:00+03	29600.00
743C3D	2017-07-31 13:00:00+03	101600.00
743C7F	2017-07-22 16:02:00+03	58200.00
743C9B	2017-08-13 23:52:00+03	134000.00
743D2D	2017-07-29 11:53:00+03	48800.00
743DCC	2017-07-29 13:29:00+03	135400.00
743E6E	2017-07-19 15:17:00+03	46200.00
743E74	2017-07-26 08:18:00+03	91500.00
743E8A	2017-07-16 10:04:00+03	39600.00
743EDC	2017-07-19 15:58:00+03	12600.00
743EDE	2017-07-20 05:17:00+03	74700.00
743F66	2017-07-29 15:36:00+03	42600.00
743FBC	2017-07-04 09:25:00+03	55800.00
743FFF	2017-07-08 08:09:00+03	73600.00
744044	2017-08-12 20:33:00+03	186000.00
744094	2017-07-14 23:53:00+03	32800.00
7440D1	2017-08-06 12:57:00+03	65900.00
744107	2017-07-08 22:06:00+03	25400.00
74411B	2017-07-18 17:46:00+03	301800.00
74415C	2017-08-05 22:15:00+03	8600.00
7441AE	2017-07-08 06:24:00+03	70600.00
7441DF	2017-07-10 08:57:00+03	80900.00
7441FC	2017-07-15 00:11:00+03	56900.00
744215	2017-08-02 03:24:00+03	252200.00
74421C	2017-08-14 00:12:00+03	67000.00
74425C	2017-07-27 19:50:00+03	52000.00
74427B	2017-07-01 09:18:00+03	266400.00
74435B	2017-07-09 20:04:00+03	83200.00
744370	2017-08-02 20:22:00+03	10600.00
7443B8	2017-07-15 19:38:00+03	48700.00
7443CF	2017-07-22 13:39:00+03	194200.00
744435	2017-08-05 05:38:00+03	34600.00
74443F	2017-07-01 06:06:00+03	6700.00
7444D8	2017-08-12 18:49:00+03	59800.00
744515	2017-07-10 16:43:00+03	26800.00
744528	2017-07-15 05:13:00+03	73800.00
744565	2017-07-24 03:49:00+03	90400.00
74459E	2017-07-30 16:43:00+03	67200.00
7445B1	2017-07-22 01:28:00+03	57500.00
7445B5	2017-07-14 23:14:00+03	75600.00
7445BF	2017-08-08 06:22:00+03	27200.00
74460D	2017-07-20 07:56:00+03	40100.00
744639	2017-07-05 20:04:00+03	53100.00
744674	2017-07-19 09:03:00+03	153200.00
744683	2017-07-11 21:52:00+03	57500.00
7446A8	2017-07-16 05:28:00+03	123000.00
7446B1	2017-07-21 17:00:00+03	88000.00
7446E5	2017-07-21 22:02:00+03	46400.00
744735	2017-07-10 23:00:00+03	62600.00
744754	2017-08-02 04:55:00+03	67700.00
744767	2017-07-18 22:00:00+03	56100.00
74478E	2017-07-20 07:20:00+03	23600.00
74481F	2017-08-04 05:24:00+03	78600.00
744831	2017-08-12 15:35:00+03	29200.00
74485F	2017-07-17 03:03:00+03	118400.00
7448A5	2017-07-02 00:17:00+03	56000.00
7448E4	2017-07-16 17:47:00+03	99200.00
7448E7	2017-06-30 12:41:00+03	23600.00
744932	2017-07-23 18:00:00+03	37200.00
744941	2017-08-07 10:37:00+03	46200.00
744972	2017-08-01 04:05:00+03	46400.00
7449C1	2017-07-06 01:50:00+03	52400.00
744AF1	2017-07-21 13:52:00+03	26800.00
744B20	2017-07-14 02:20:00+03	44800.00
744B8A	2017-07-03 00:13:00+03	70800.00
744BC3	2017-08-13 23:45:00+03	135000.00
744BFB	2017-07-11 09:02:00+03	201200.00
744C0A	2017-08-10 00:18:00+03	149300.00
744C69	2017-08-12 06:04:00+03	136800.00
744C80	2017-08-09 10:38:00+03	62000.00
744C94	2017-07-21 12:40:00+03	201200.00
744D0D	2017-08-13 13:32:00+03	56100.00
744D90	2017-07-24 21:54:00+03	67600.00
744DD2	2017-07-12 21:50:00+03	61800.00
744DD7	2017-07-23 18:07:00+03	64200.00
744E35	2017-07-28 02:13:00+03	66400.00
744E5D	2017-07-18 18:40:00+03	35200.00
744E64	2017-08-03 10:01:00+03	92100.00
744EB2	2017-07-15 14:55:00+03	81800.00
744ED5	2017-07-02 22:43:00+03	24400.00
744FCB	2017-08-05 12:35:00+03	75200.00
7450B9	2017-06-28 07:36:00+03	21400.00
745120	2017-07-30 20:28:00+03	179200.00
745167	2017-08-04 12:49:00+03	8400.00
7451CF	2017-07-12 02:04:00+03	16400.00
7451F7	2017-08-13 15:41:00+03	149200.00
7451FB	2017-08-07 22:56:00+03	112600.00
745255	2017-07-24 14:37:00+03	41400.00
745284	2017-08-13 06:11:00+03	27800.00
74529A	2017-08-15 14:51:00+03	44300.00
7452C0	2017-06-29 19:17:00+03	26200.00
7452C8	2017-07-07 11:22:00+03	20200.00
7452DE	2017-07-30 21:43:00+03	28000.00
7452F4	2017-06-27 04:45:00+03	14800.00
745305	2017-06-30 06:57:00+03	61400.00
745306	2017-07-07 10:05:00+03	25600.00
745326	2017-07-26 01:33:00+03	170800.00
74532A	2017-08-01 00:00:00+03	122000.00
745337	2017-07-16 03:45:00+03	136200.00
745347	2017-07-03 13:03:00+03	12000.00
74536E	2017-08-03 02:58:00+03	6000.00
7453A6	2017-07-26 07:47:00+03	36200.00
7453CD	2017-07-11 17:59:00+03	49100.00
7453DF	2017-07-24 08:34:00+03	62600.00
74542F	2017-07-07 11:00:00+03	59800.00
74548D	2017-07-16 15:50:00+03	27800.00
74549B	2017-07-07 18:33:00+03	34000.00
7454E7	2017-07-03 16:09:00+03	30200.00
745519	2017-08-12 11:16:00+03	86800.00
745528	2017-07-06 15:05:00+03	100000.00
74552D	2017-07-19 17:02:00+03	59200.00
745555	2017-07-15 17:29:00+03	26000.00
745562	2017-07-25 01:46:00+03	240900.00
745567	2017-07-12 01:17:00+03	25600.00
745599	2017-08-05 23:58:00+03	28800.00
7455D4	2017-07-24 18:37:00+03	23200.00
74569E	2017-08-03 06:31:00+03	24800.00
7456BB	2017-07-22 13:46:00+03	7400.00
74572C	2017-07-01 13:17:00+03	242300.00
745738	2017-08-02 05:27:00+03	55800.00
7457AB	2017-07-22 12:15:00+03	45200.00
7457D8	2017-07-30 03:14:00+03	23200.00
7458B0	2017-07-14 09:12:00+03	113200.00
7458D1	2017-07-19 23:58:00+03	40800.00
7458EF	2017-08-08 15:39:00+03	135000.00
74591F	2017-08-14 22:49:00+03	101200.00
745934	2017-07-18 10:14:00+03	48400.00
745946	2017-07-17 13:11:00+03	123700.00
7459CF	2017-08-07 03:22:00+03	56000.00
7459DB	2017-07-28 07:04:00+03	186900.00
7459DD	2017-07-14 10:16:00+03	135600.00
745A10	2017-07-12 11:47:00+03	27400.00
745A11	2017-08-09 06:20:00+03	29600.00
745A1B	2017-07-13 14:43:00+03	62900.00
745A29	2017-08-03 08:19:00+03	51800.00
745A2B	2017-08-08 04:47:00+03	166100.00
745A61	2017-07-09 00:00:00+03	179500.00
745A6E	2017-07-20 03:35:00+03	35300.00
745ACF	2017-07-29 14:59:00+03	18500.00
745B20	2017-07-06 16:31:00+03	36000.00
745B2B	2017-08-08 18:48:00+03	56900.00
745BB6	2017-07-18 01:42:00+03	61400.00
745BCE	2017-08-03 14:13:00+03	32700.00
745C32	2017-07-06 23:27:00+03	16400.00
745C4C	2017-07-28 22:54:00+03	38400.00
745C5E	2017-07-24 20:32:00+03	28000.00
745CE0	2017-07-30 19:21:00+03	298600.00
745CF8	2017-07-29 20:09:00+03	137100.00
745D7E	2017-08-10 00:52:00+03	6800.00
745D7F	2017-08-09 18:07:00+03	46700.00
745D86	2017-08-15 15:59:00+03	125200.00
745DAB	2017-07-29 09:13:00+03	8200.00
745DC5	2017-07-09 23:04:00+03	52400.00
745DEA	2017-07-14 15:48:00+03	48700.00
745DF1	2017-07-08 14:25:00+03	62700.00
745E28	2017-07-14 22:30:00+03	67600.00
745E77	2017-07-07 18:52:00+03	270800.00
745E7C	2017-07-04 06:07:00+03	44800.00
745F47	2017-07-24 22:56:00+03	54800.00
745F80	2017-08-02 16:38:00+03	52700.00
745FF4	2017-07-10 01:51:00+03	27400.00
74605A	2017-08-04 09:36:00+03	69600.00
7460E1	2017-07-10 03:46:00+03	56900.00
746129	2017-08-06 09:03:00+03	59300.00
746134	2017-07-07 15:03:00+03	38400.00
74614C	2017-07-29 01:20:00+03	93700.00
746183	2017-08-02 05:24:00+03	36200.00
74619D	2017-07-26 22:42:00+03	25400.00
7461AD	2017-08-03 08:27:00+03	20200.00
7461C3	2017-07-07 11:36:00+03	41900.00
74620D	2017-07-07 16:46:00+03	44500.00
74621A	2017-08-13 03:49:00+03	40800.00
74621C	2017-07-24 11:11:00+03	160200.00
746228	2017-07-01 21:21:00+03	90400.00
74624E	2017-07-02 16:53:00+03	15400.00
746286	2017-07-09 02:05:00+03	258400.00
746289	2017-07-02 16:23:00+03	39300.00
7462BA	2017-07-20 01:03:00+03	88000.00
7462C5	2017-07-31 11:11:00+03	22000.00
7462E4	2017-07-20 01:03:00+03	51400.00
746304	2017-07-29 15:22:00+03	75300.00
746323	2017-07-09 02:39:00+03	89600.00
746353	2017-07-13 02:01:00+03	94700.00
746394	2017-08-11 18:23:00+03	88900.00
7463E6	2017-08-03 10:23:00+03	10100.00
746424	2017-07-22 10:06:00+03	40600.00
746425	2017-07-19 15:35:00+03	52000.00
74642F	2017-07-09 22:04:00+03	21000.00
746458	2017-08-04 19:20:00+03	68900.00
7464C3	2017-08-12 18:26:00+03	79500.00
746510	2017-07-25 16:20:00+03	135600.00
746528	2017-07-07 09:17:00+03	78000.00
74655A	2017-07-21 19:17:00+03	139500.00
74656D	2017-07-05 05:14:00+03	21400.00
746573	2017-07-09 20:17:00+03	22000.00
74664E	2017-06-29 03:08:00+03	32700.00
7466EB	2017-07-10 09:05:00+03	75600.00
74675A	2017-08-02 04:17:00+03	56600.00
746782	2017-08-05 12:13:00+03	36500.00
7467F9	2017-08-13 02:30:00+03	28000.00
74680A	2017-08-07 17:00:00+03	36200.00
74687A	2017-08-13 23:50:00+03	11000.00
74689E	2017-07-28 17:05:00+03	35200.00
7468B1	2017-07-09 00:37:00+03	27200.00
7468C9	2017-07-19 05:21:00+03	92800.00
7468FC	2017-07-23 16:26:00+03	42400.00
746906	2017-08-13 19:45:00+03	44300.00
746965	2017-07-28 10:20:00+03	28000.00
746991	2017-08-03 16:24:00+03	78600.00
746997	2017-06-29 09:49:00+03	59200.00
7469E8	2017-07-12 03:28:00+03	77200.00
7469EF	2017-08-02 04:54:00+03	83000.00
746A23	2017-07-09 17:51:00+03	26200.00
746A9C	2017-07-28 23:14:00+03	88100.00
746AAE	2017-08-12 19:47:00+03	111600.00
746B12	2017-08-04 08:19:00+03	60400.00
746B2D	2017-07-19 19:07:00+03	84100.00
746B2F	2017-07-19 08:30:00+03	51200.00
746BC1	2017-07-17 10:36:00+03	97200.00
746C6E	2017-08-12 13:21:00+03	36200.00
746C71	2017-07-04 20:11:00+03	25200.00
746C9D	2017-07-12 01:10:00+03	46500.00
746CA0	2017-07-31 08:52:00+03	46300.00
746CF1	2017-08-08 16:56:00+03	86400.00
746D27	2017-08-06 06:32:00+03	36200.00
746D4B	2017-07-27 21:41:00+03	23200.00
746D57	2017-06-29 10:01:00+03	413500.00
746D69	2017-07-19 09:57:00+03	66600.00
746E20	2017-07-29 11:55:00+03	62600.00
746E96	2017-07-20 01:35:00+03	106500.00
746EC3	2017-07-30 22:51:00+03	21800.00
746EE7	2017-08-15 12:50:00+03	56000.00
746F04	2017-07-12 17:30:00+03	91500.00
746F85	2017-07-23 22:06:00+03	111600.00
747036	2017-08-15 01:08:00+03	55800.00
74705B	2017-07-20 07:20:00+03	23200.00
7470E3	2017-07-16 15:07:00+03	28600.00
7470FB	2017-08-09 00:27:00+03	64700.00
747122	2017-07-23 16:54:00+03	56900.00
747235	2017-07-15 22:20:00+03	50000.00
747249	2017-08-06 17:35:00+03	189700.00
747296	2017-07-08 21:42:00+03	167400.00
7472BF	2017-08-01 13:18:00+03	29200.00
7472DA	2017-07-19 13:50:00+03	103000.00
7472FE	2017-08-15 07:42:00+03	65900.00
747353	2017-08-02 04:24:00+03	65400.00
747387	2017-07-25 09:39:00+03	31400.00
7473D4	2017-07-21 04:41:00+03	26800.00
7473E5	2017-08-12 05:02:00+03	37900.00
7473ED	2017-07-19 03:18:00+03	133200.00
747401	2017-07-30 08:27:00+03	28800.00
747460	2017-08-08 11:43:00+03	29400.00
74746C	2017-07-12 17:57:00+03	34000.00
747474	2017-08-12 14:35:00+03	118300.00
747478	2017-07-04 03:35:00+03	54800.00
7474A1	2017-08-15 05:14:00+03	43500.00
7474BC	2017-07-31 01:31:00+03	43500.00
747522	2017-07-11 22:23:00+03	56000.00
74755C	2017-08-10 07:43:00+03	32700.00
747591	2017-07-05 02:33:00+03	15400.00
747599	2017-07-07 14:52:00+03	48600.00
7475B3	2017-07-26 20:03:00+03	110500.00
7475CB	2017-08-02 17:43:00+03	42400.00
747614	2017-08-12 05:31:00+03	160200.00
747619	2017-07-03 09:04:00+03	18600.00
7476C2	2017-07-30 03:01:00+03	134400.00
7476F4	2017-07-11 22:22:00+03	496700.00
747778	2017-07-23 01:26:00+03	160800.00
7477FC	2017-07-04 13:34:00+03	6000.00
747868	2017-07-25 06:39:00+03	75300.00
7478BF	2017-07-14 23:10:00+03	163900.00
7478D0	2017-07-05 03:27:00+03	86500.00
74791F	2017-08-13 01:42:00+03	48800.00
74792B	2017-07-06 01:58:00+03	61500.00
747995	2017-07-16 00:56:00+03	28800.00
7479B0	2017-07-14 15:13:00+03	41200.00
747A86	2017-07-31 19:11:00+03	26000.00
747AA4	2017-08-09 09:47:00+03	26600.00
747B02	2017-08-07 17:33:00+03	29400.00
747B0A	2017-07-22 23:14:00+03	196100.00
747B63	2017-08-02 15:47:00+03	70100.00
747B94	2017-07-08 13:07:00+03	24800.00
747BCD	2017-08-06 20:33:00+03	46000.00
747C77	2017-08-05 03:26:00+03	68800.00
747D41	2017-07-29 05:13:00+03	6700.00
747D67	2017-07-29 07:59:00+03	133000.00
747D6A	2017-07-13 21:23:00+03	16400.00
747D9E	2017-07-20 12:39:00+03	252200.00
747DAC	2017-08-04 08:10:00+03	136800.00
747DAF	2017-07-22 03:09:00+03	56600.00
747E35	2017-07-29 14:19:00+03	23600.00
747F84	2017-08-07 04:19:00+03	123000.00
747FB2	2017-07-29 19:13:00+03	57400.00
747FCE	2017-07-11 12:15:00+03	26200.00
748032	2017-07-09 02:23:00+03	6800.00
748052	2017-06-30 22:28:00+03	75100.00
748064	2017-07-20 02:33:00+03	227400.00
7480AA	2017-07-12 00:50:00+03	137800.00
748174	2017-07-20 19:06:00+03	66600.00
7481AE	2017-08-03 11:16:00+03	147100.00
7481D7	2017-07-18 21:16:00+03	52700.00
7481F6	2017-07-07 08:07:00+03	48800.00
74824C	2017-07-14 20:21:00+03	111600.00
748356	2017-07-21 07:37:00+03	72400.00
748372	2017-08-14 15:35:00+03	19600.00
74838E	2017-07-22 01:24:00+03	71200.00
7483A8	2017-07-01 07:59:00+03	179300.00
7483E2	2017-08-13 20:07:00+03	21600.00
748426	2017-07-11 19:14:00+03	70700.00
7484D8	2017-07-30 21:04:00+03	52800.00
74851F	2017-07-05 14:47:00+03	26000.00
748525	2017-07-30 21:29:00+03	26800.00
7485C1	2017-08-06 23:24:00+03	28800.00
7485F4	2017-07-12 15:53:00+03	16400.00
74865A	2017-07-30 20:57:00+03	18000.00
74865F	2017-08-04 02:48:00+03	21500.00
748707	2017-07-28 21:36:00+03	66600.00
748708	2017-08-09 03:08:00+03	57800.00
7487D6	2017-08-14 15:45:00+03	40800.00
74887B	2017-08-06 22:01:00+03	57400.00
7488D5	2017-07-18 09:53:00+03	13600.00
748936	2017-07-11 22:47:00+03	40800.00
748A10	2017-07-25 17:16:00+03	32200.00
748A5B	2017-08-06 13:49:00+03	6300.00
748A7D	2017-07-25 07:41:00+03	47400.00
748ABF	2017-08-05 01:34:00+03	70800.00
748AE2	2017-08-02 09:46:00+03	113200.00
748B05	2017-08-13 10:09:00+03	6700.00
748B20	2017-07-17 09:13:00+03	206600.00
748B34	2017-07-04 02:19:00+03	167200.00
748B3C	2017-08-05 04:08:00+03	20700.00
748BAB	2017-07-03 06:36:00+03	67900.00
748C0C	2017-08-11 22:22:00+03	62000.00
748C1D	2017-07-11 02:55:00+03	27300.00
748C21	2017-07-08 05:10:00+03	10800.00
748C24	2017-08-09 22:57:00+03	28000.00
748C31	2017-07-31 21:41:00+03	57800.00
748C99	2017-07-19 08:00:00+03	109400.00
748CC6	2017-07-25 06:24:00+03	100600.00
748CD1	2017-07-11 20:24:00+03	24400.00
748D13	2017-07-06 12:40:00+03	35600.00
748D2B	2017-07-27 18:11:00+03	112000.00
748D47	2017-08-10 05:28:00+03	72800.00
748D53	2017-08-08 03:29:00+03	112200.00
748D96	2017-08-04 17:31:00+03	99800.00
748D9D	2017-07-10 11:08:00+03	135400.00
748DEF	2017-07-11 02:45:00+03	111600.00
748DF8	2017-07-31 07:33:00+03	23600.00
748E94	2017-07-15 23:33:00+03	67600.00
748EA4	2017-07-08 07:06:00+03	25600.00
748EA7	2017-07-05 14:44:00+03	40800.00
748EDF	2017-07-30 14:23:00+03	67800.00
748EFD	2017-07-07 03:52:00+03	18600.00
748FEF	2017-07-13 20:22:00+03	124300.00
749005	2017-07-03 16:57:00+03	36800.00
749036	2017-07-10 06:44:00+03	101700.00
749042	2017-07-12 03:01:00+03	20400.00
749054	2017-07-13 12:16:00+03	23200.00
749089	2017-07-26 13:52:00+03	6800.00
749096	2017-07-08 12:57:00+03	64200.00
7490CF	2017-07-27 04:48:00+03	24400.00
7490F6	2017-08-12 05:55:00+03	24400.00
749132	2017-08-12 00:42:00+03	92800.00
749161	2017-08-15 17:35:00+03	75100.00
749183	2017-08-14 22:41:00+03	29600.00
7491BB	2017-08-01 15:14:00+03	30700.00
7491BE	2017-07-15 00:37:00+03	38000.00
749200	2017-06-30 22:34:00+03	47000.00
74926A	2017-07-28 04:07:00+03	83000.00
7492A9	2017-08-15 13:25:00+03	70700.00
7492C3	2017-07-07 16:59:00+03	173600.00
7492C5	2017-08-05 06:38:00+03	31800.00
749332	2017-07-19 16:31:00+03	277000.00
749390	2017-08-13 16:21:00+03	381400.00
7493A1	2017-08-06 19:42:00+03	57500.00
7493CF	2017-07-10 17:26:00+03	89900.00
7493E4	2017-07-25 04:15:00+03	26000.00
7493EB	2017-07-09 07:46:00+03	31000.00
7493F9	2017-07-23 13:40:00+03	22000.00
749454	2017-08-08 18:35:00+03	55800.00
7494B6	2017-07-03 02:16:00+03	37200.00
7494BB	2017-08-06 12:04:00+03	13400.00
749507	2017-07-08 02:39:00+03	110300.00
74954E	2017-08-13 21:16:00+03	35200.00
74954F	2017-07-11 02:59:00+03	135000.00
7495A4	2017-07-09 14:24:00+03	81700.00
749646	2017-07-18 22:54:00+03	46400.00
749779	2017-07-14 14:09:00+03	12600.00
74977E	2017-08-03 04:32:00+03	17800.00
7497A8	2017-07-04 19:07:00+03	99300.00
7497C8	2017-08-04 15:17:00+03	29800.00
7497D8	2017-07-30 10:02:00+03	64600.00
74982E	2017-07-26 14:27:00+03	66600.00
74984A	2017-07-22 19:38:00+03	27200.00
74984B	2017-08-04 21:18:00+03	40800.00
74984D	2017-07-04 21:54:00+03	83000.00
749876	2017-07-13 22:22:00+03	254900.00
74987A	2017-07-15 19:40:00+03	86400.00
749898	2017-07-31 18:35:00+03	119500.00
749951	2017-07-25 06:50:00+03	55600.00
74996F	2017-07-18 07:42:00+03	69000.00
7499A0	2017-08-06 01:50:00+03	67800.00
7499C1	2017-07-02 17:56:00+03	16400.00
7499D3	2017-07-20 01:05:00+03	35200.00
7499D5	2017-08-12 19:44:00+03	80000.00
749AFA	2017-08-09 17:17:00+03	55600.00
749B1C	2017-07-06 02:29:00+03	265700.00
749B27	2017-08-13 21:02:00+03	67600.00
749B44	2017-07-24 03:02:00+03	39800.00
749B87	2017-07-07 06:30:00+03	22600.00
749B95	2017-07-02 05:40:00+03	24400.00
749C8B	2017-08-12 01:30:00+03	50600.00
749C96	2017-08-04 09:50:00+03	70600.00
749D6F	2017-07-31 09:34:00+03	68800.00
749D83	2017-06-30 10:37:00+03	131100.00
749D8C	2017-07-05 02:34:00+03	70700.00
749DC3	2017-08-12 18:24:00+03	43800.00
749DC4	2017-07-04 15:40:00+03	28000.00
749DCA	2017-08-07 20:22:00+03	44800.00
749E9E	2017-07-17 17:33:00+03	111600.00
749EAB	2017-07-04 10:24:00+03	72200.00
749EFA	2017-07-17 00:33:00+03	62400.00
749EFE	2017-07-28 22:29:00+03	66800.00
749F56	2017-07-13 03:29:00+03	26200.00
749F72	2017-07-21 20:33:00+03	64800.00
749F7B	2017-07-21 12:02:00+03	72200.00
749FC0	2017-07-22 13:06:00+03	51200.00
749FCE	2017-08-05 01:28:00+03	46000.00
749FD4	2017-08-01 11:13:00+03	69600.00
74A020	2017-08-11 15:35:00+03	32200.00
74A092	2017-07-12 11:07:00+03	108600.00
74A12A	2017-08-01 12:32:00+03	13400.00
74A1C5	2017-08-02 10:46:00+03	124200.00
74A1FC	2017-08-08 22:32:00+03	189000.00
74A275	2017-07-08 11:45:00+03	28000.00
74A286	2017-07-11 14:01:00+03	126500.00
74A299	2017-08-04 06:38:00+03	135400.00
74A2A9	2017-08-13 09:52:00+03	13400.00
74A33A	2017-07-10 20:12:00+03	45000.00
74A38E	2017-07-22 17:46:00+03	46500.00
74A433	2017-08-15 11:53:00+03	27400.00
74A44D	2017-07-11 10:41:00+03	21000.00
74A459	2017-06-26 15:05:00+03	20400.00
74A4C6	2017-08-05 06:01:00+03	56000.00
74A4D9	2017-07-18 11:56:00+03	122300.00
74A4DB	2017-07-28 23:19:00+03	15000.00
74A4F9	2017-08-07 23:14:00+03	36400.00
74A592	2017-07-23 03:52:00+03	81600.00
74A5C3	2017-08-03 07:15:00+03	52000.00
74A617	2017-07-13 11:17:00+03	42800.00
74A620	2017-07-24 14:24:00+03	58400.00
74A623	2017-07-18 12:14:00+03	81300.00
74A78B	2017-08-14 01:52:00+03	86600.00
74A79E	2017-08-01 03:35:00+03	67200.00
74A7BB	2017-07-29 22:37:00+03	40800.00
74A7DA	2017-08-12 10:58:00+03	10600.00
74A7DD	2017-07-19 07:48:00+03	58000.00
74A7FE	2017-07-11 13:23:00+03	40400.00
74A81E	2017-07-10 20:24:00+03	59200.00
74A8A3	2017-08-07 16:30:00+03	132100.00
74A8E0	2017-08-03 06:36:00+03	87700.00
74A8ED	2017-08-02 18:17:00+03	70800.00
74A90F	2017-06-30 16:20:00+03	531400.00
74A914	2017-07-26 14:39:00+03	29600.00
74A919	2017-08-15 10:31:00+03	85500.00
74A978	2017-07-18 12:48:00+03	28000.00
74A97B	2017-08-04 07:31:00+03	120400.00
74AA08	2017-07-06 23:50:00+03	199700.00
74AA38	2017-07-03 03:32:00+03	40000.00
74AA7F	2017-07-08 21:21:00+03	111600.00
74AA90	2017-07-04 23:31:00+03	98400.00
74AAF6	2017-07-24 08:07:00+03	122600.00
74AB1A	2017-07-05 14:59:00+03	252200.00
74ABAA	2017-07-19 05:25:00+03	77900.00
74AC6E	2017-08-08 20:25:00+03	65600.00
74AC77	2017-07-05 00:25:00+03	165600.00
74AC86	2017-07-24 19:00:00+03	6000.00
74ACC8	2017-08-01 04:25:00+03	99200.00
74ACE8	2017-07-08 18:58:00+03	19000.00
74ACF2	2017-07-31 20:27:00+03	21800.00
74ACF7	2017-08-01 21:04:00+03	25400.00
74AD9F	2017-07-13 08:20:00+03	85000.00
74ADC1	2017-08-01 21:21:00+03	57600.00
74ADCE	2017-06-29 09:32:00+03	24400.00
74ADE7	2017-08-12 12:48:00+03	13400.00
74ADFD	2017-08-10 11:24:00+03	28800.00
74AE0D	2017-07-22 23:40:00+03	73500.00
74AE46	2017-07-12 12:41:00+03	38200.00
74AE96	2017-07-15 05:06:00+03	83100.00
74AEAA	2017-07-06 11:55:00+03	28800.00
74AED7	2017-07-24 02:01:00+03	168600.00
74AED8	2017-08-14 23:46:00+03	15000.00
74AF0D	2017-07-19 18:15:00+03	124300.00
74AFE1	2017-07-04 12:40:00+03	56000.00
74B06E	2017-06-27 22:38:00+03	102300.00
74B0AD	2017-07-04 13:19:00+03	162900.00
74B0C6	2017-08-02 07:39:00+03	23200.00
74B12F	2017-07-20 04:21:00+03	87200.00
74B1A2	2017-07-03 13:31:00+03	57400.00
74B279	2017-07-21 03:27:00+03	124300.00
74B2DE	2017-07-17 15:40:00+03	50600.00
74B368	2017-08-07 19:15:00+03	211100.00
74B384	2017-08-14 11:15:00+03	28800.00
74B430	2017-07-27 10:04:00+03	21000.00
74B433	2017-06-30 15:09:00+03	138000.00
74B43B	2017-07-16 03:51:00+03	39600.00
74B446	2017-07-19 19:06:00+03	112000.00
74B46B	2017-08-10 17:04:00+03	246000.00
74B482	2017-07-12 20:11:00+03	26800.00
74B4A3	2017-07-13 07:10:00+03	67700.00
74B4E5	2017-08-09 10:07:00+03	186900.00
74B4EF	2017-06-30 15:11:00+03	191600.00
74B50B	2017-07-14 03:36:00+03	135200.00
74B61D	2017-07-25 15:48:00+03	68800.00
74B646	2017-07-13 20:52:00+03	25600.00
74B64E	2017-07-13 05:34:00+03	24300.00
74B65E	2017-07-22 20:52:00+03	49800.00
74B67B	2017-07-22 19:22:00+03	15000.00
74B6A8	2017-07-12 16:31:00+03	71200.00
74B6E2	2017-07-20 02:12:00+03	73100.00
74B744	2017-07-24 09:58:00+03	46300.00
74B753	2017-07-06 01:28:00+03	40600.00
74B786	2017-07-05 20:50:00+03	11700.00
74B78F	2017-07-30 20:59:00+03	21400.00
74B7B3	2017-07-25 14:31:00+03	70700.00
74B7BE	2017-08-09 19:41:00+03	212500.00
74B7C5	2017-07-28 22:59:00+03	88600.00
74B7CC	2017-07-28 04:29:00+03	71900.00
74B816	2017-08-13 01:00:00+03	27200.00
74B853	2017-08-10 02:19:00+03	85000.00
74B876	2017-07-08 18:30:00+03	92000.00
74B897	2017-07-04 03:35:00+03	56900.00
74B8BA	2017-07-04 21:15:00+03	71900.00
74B8C8	2017-07-08 02:02:00+03	13400.00
74B965	2017-07-16 04:32:00+03	187800.00
74B996	2017-07-26 05:39:00+03	46400.00
74B9CA	2017-08-06 09:38:00+03	102000.00
74BA84	2017-07-07 20:43:00+03	37000.00
74BA9C	2017-08-07 22:06:00+03	73600.00
74BAA6	2017-08-14 22:41:00+03	77900.00
74BB1E	2017-07-03 06:51:00+03	119500.00
74BB3B	2017-08-02 19:25:00+03	56000.00
74BB40	2017-07-11 23:22:00+03	6000.00
74BB56	2017-07-08 20:38:00+03	14000.00
74BB91	2017-08-01 19:08:00+03	55500.00
74BBF3	2017-07-12 19:54:00+03	92800.00
74BCA2	2017-07-20 14:45:00+03	66000.00
74BCA4	2017-07-23 02:18:00+03	21800.00
74BCC0	2017-07-05 12:36:00+03	154500.00
74BD17	2017-07-29 08:01:00+03	48300.00
74BDAA	2017-07-31 00:32:00+03	52000.00
74BE3B	2017-07-18 20:49:00+03	11600.00
74BEBC	2017-07-01 12:09:00+03	135600.00
74BEC4	2017-07-19 23:12:00+03	229500.00
74BF04	2017-08-09 04:48:00+03	112100.00
74BF39	2017-07-07 07:48:00+03	69500.00
74BF59	2017-07-31 21:12:00+03	56000.00
74BFDF	2017-08-11 17:12:00+03	116100.00
74C03C	2017-07-07 07:06:00+03	50200.00
74C05D	2017-07-04 06:08:00+03	57400.00
74C0FF	2017-07-28 13:20:00+03	13200.00
74C16E	2017-07-26 09:18:00+03	46400.00
74C173	2017-07-26 21:25:00+03	15100.00
74C193	2017-07-03 10:40:00+03	66600.00
74C19C	2017-07-06 11:57:00+03	45100.00
74C1BB	2017-08-04 18:12:00+03	111600.00
74C20F	2017-07-03 23:58:00+03	81900.00
74C221	2017-07-12 01:32:00+03	49200.00
74C22D	2017-07-21 18:56:00+03	27200.00
74C375	2017-08-07 01:33:00+03	72400.00
74C3AF	2017-08-06 10:38:00+03	177200.00
74C3D9	2017-07-04 09:11:00+03	89600.00
74C3DE	2017-08-01 06:42:00+03	118200.00
74C3F9	2017-07-27 21:39:00+03	133600.00
74C479	2017-07-03 17:04:00+03	110600.00
74C50F	2017-07-08 05:17:00+03	369000.00
74C552	2017-07-08 13:27:00+03	265600.00
74C59C	2017-08-13 10:34:00+03	77000.00
74C646	2017-08-04 21:19:00+03	62800.00
74C648	2017-07-28 04:34:00+03	21400.00
74C664	2017-07-02 22:30:00+03	19200.00
74C68A	2017-07-18 04:20:00+03	12600.00
74C6C2	2017-07-02 20:30:00+03	20000.00
74C6D2	2017-08-05 17:36:00+03	26200.00
74C6E0	2017-07-19 03:38:00+03	36800.00
74C72D	2017-07-29 08:15:00+03	162600.00
74C739	2017-07-14 00:11:00+03	69500.00
74C79D	2017-07-04 10:04:00+03	75600.00
74C7B0	2017-07-17 13:48:00+03	136200.00
74C866	2017-07-15 15:21:00+03	66600.00
74C870	2017-07-21 19:05:00+03	73200.00
74C877	2017-08-12 16:06:00+03	46400.00
74C89E	2017-07-04 18:15:00+03	213200.00
74C91F	2017-08-09 10:19:00+03	99700.00
74C950	2017-07-26 21:46:00+03	12600.00
74CA0C	2017-07-15 03:27:00+03	28000.00
74CA27	2017-08-03 10:34:00+03	22000.00
74CAA8	2017-07-30 04:36:00+03	75600.00
74CADB	2017-07-26 22:55:00+03	112000.00
74CB14	2017-08-11 02:46:00+03	109000.00
74CBB9	2017-07-25 04:05:00+03	199700.00
74CBC1	2017-07-21 14:39:00+03	67600.00
74CBC3	2017-08-13 01:10:00+03	92900.00
74CBE7	2017-08-04 13:43:00+03	67200.00
74CBE8	2017-08-04 15:43:00+03	40800.00
74CC07	2017-08-07 13:31:00+03	116900.00
74CC35	2017-07-07 08:09:00+03	12600.00
74CC3A	2017-07-17 15:45:00+03	246000.00
74CC59	2017-07-22 13:51:00+03	93600.00
74CCAA	2017-07-10 09:29:00+03	142400.00
74CD3D	2017-07-04 04:23:00+03	46400.00
74CD7A	2017-08-03 02:29:00+03	89000.00
74CD96	2017-07-15 18:55:00+03	34600.00
74CDEE	2017-08-05 01:37:00+03	187600.00
74CDFA	2017-08-08 03:56:00+03	56100.00
74CE15	2017-08-10 19:37:00+03	182400.00
74CEC2	2017-07-08 08:33:00+03	134400.00
74CEF8	2017-08-14 14:37:00+03	28800.00
74CF09	2017-07-16 23:54:00+03	187800.00
74CF45	2017-07-11 01:51:00+03	51900.00
74CF59	2017-07-27 00:18:00+03	32800.00
74CF63	2017-07-19 23:52:00+03	44800.00
74CFC1	2017-07-20 21:16:00+03	23200.00
74CFDD	2017-07-16 20:55:00+03	78200.00
74D0BC	2017-07-13 00:30:00+03	119600.00
74D0CE	2017-07-21 06:11:00+03	37900.00
74D0EE	2017-07-03 22:41:00+03	52600.00
74D117	2017-08-04 12:41:00+03	257500.00
74D2FD	2017-08-12 11:03:00+03	21400.00
74D334	2017-07-29 03:31:00+03	41400.00
74D346	2017-07-18 09:01:00+03	135400.00
74D3A1	2017-07-09 16:38:00+03	37200.00
74D3DC	2017-07-27 14:07:00+03	77000.00
74D416	2017-08-06 07:14:00+03	28000.00
74D449	2017-07-24 03:47:00+03	140200.00
74D492	2017-07-12 11:53:00+03	9200.00
74D5D2	2017-08-12 21:24:00+03	26000.00
74D633	2017-07-21 18:29:00+03	39800.00
74D66F	2017-07-04 07:12:00+03	137700.00
74D6EF	2017-07-24 08:32:00+03	55800.00
74D726	2017-07-19 10:35:00+03	23600.00
74D758	2017-07-10 10:42:00+03	160100.00
74D768	2017-07-09 04:44:00+03	182000.00
74D7DF	2017-08-11 19:39:00+03	32700.00
74D7F2	2017-07-01 17:28:00+03	6700.00
74D7F5	2017-07-30 15:51:00+03	224000.00
74D7FE	2017-08-12 19:55:00+03	92000.00
74D816	2017-07-05 08:33:00+03	128700.00
74D8AB	2017-08-10 12:07:00+03	61800.00
74D8CA	2017-07-14 15:41:00+03	30200.00
74D8D3	2017-08-08 16:23:00+03	55800.00
74D8EC	2017-07-25 02:40:00+03	66600.00
74D9B2	2017-07-14 02:41:00+03	49300.00
74D9D6	2017-08-09 03:18:00+03	67700.00
74DA2F	2017-07-07 01:57:00+03	54500.00
74DAB4	2017-07-28 11:17:00+03	37200.00
74DAD8	2017-08-04 14:07:00+03	29600.00
74DB16	2017-07-10 09:24:00+03	175400.00
74DB42	2017-07-21 00:28:00+03	47500.00
74DB66	2017-07-13 21:53:00+03	66100.00
74DBF1	2017-08-12 08:18:00+03	23200.00
74DC0E	2017-07-13 04:01:00+03	53500.00
74DC45	2017-08-15 17:24:00+03	147500.00
74DC60	2017-08-10 01:39:00+03	58200.00
74DC64	2017-06-30 16:01:00+03	51900.00
74DC73	2017-08-09 17:10:00+03	17800.00
74DD2F	2017-08-13 23:09:00+03	399600.00
74DD31	2017-07-21 04:30:00+03	399600.00
74DDAA	2017-07-17 00:45:00+03	40000.00
74DDDD	2017-07-18 06:38:00+03	56000.00
74DE0C	2017-07-16 09:50:00+03	19200.00
74DE21	2017-07-13 00:57:00+03	23400.00
74DEEF	2017-08-04 04:12:00+03	233700.00
74DF00	2017-07-15 01:39:00+03	241400.00
74DF1D	2017-07-06 06:41:00+03	38600.00
74DF2A	2017-08-03 11:57:00+03	114800.00
74DF55	2017-08-09 22:49:00+03	296400.00
74DFCF	2017-08-13 16:48:00+03	404600.00
74DFF2	2017-07-11 07:26:00+03	29600.00
74E00F	2017-07-11 14:03:00+03	123000.00
74E07D	2017-08-15 11:11:00+03	79700.00
74E090	2017-08-07 14:29:00+03	24400.00
74E095	2017-07-29 18:17:00+03	123900.00
74E12F	2017-07-11 09:10:00+03	270000.00
74E148	2017-07-21 16:12:00+03	32400.00
74E18E	2017-07-03 10:09:00+03	65900.00
74E201	2017-07-24 21:19:00+03	12000.00
74E2AF	2017-07-27 08:25:00+03	113300.00
74E315	2017-07-08 11:05:00+03	94300.00
74E31F	2017-08-14 13:27:00+03	13400.00
74E356	2017-08-15 16:50:00+03	283600.00
74E366	2017-08-12 17:41:00+03	103500.00
74E3B4	2017-07-21 11:56:00+03	46300.00
74E3F9	2017-07-25 22:18:00+03	46400.00
74E417	2017-07-28 11:57:00+03	86800.00
74E430	2017-07-20 00:18:00+03	149600.00
74E4C3	2017-07-28 04:58:00+03	86800.00
74E4D1	2017-07-08 20:02:00+03	146300.00
74E50B	2017-07-19 19:22:00+03	120400.00
74E529	2017-07-31 02:38:00+03	139400.00
74E559	2017-07-06 14:16:00+03	46400.00
74E57E	2017-07-20 12:32:00+03	54000.00
74E59D	2017-08-08 23:53:00+03	37800.00
74E59F	2017-08-14 23:50:00+03	369000.00
74E5B6	2017-07-30 07:20:00+03	323800.00
74E5B8	2017-08-10 13:37:00+03	26200.00
74E5C8	2017-07-28 23:28:00+03	63200.00
74E5F4	2017-08-09 18:46:00+03	29600.00
74E653	2017-07-02 04:30:00+03	60800.00
74E65F	2017-07-01 15:52:00+03	127300.00
74E683	2017-07-12 16:58:00+03	52400.00
74E6AF	2017-07-28 07:20:00+03	52800.00
74E6F4	2017-07-14 13:49:00+03	86500.00
74E70E	2017-07-19 19:37:00+03	128600.00
74E768	2017-08-14 01:41:00+03	77200.00
74E770	2017-08-01 22:33:00+03	67900.00
74E79B	2017-07-23 22:48:00+03	127300.00
74E7CF	2017-08-09 11:40:00+03	230000.00
74E7D7	2017-08-04 01:40:00+03	87300.00
74E7DC	2017-08-10 13:54:00+03	61800.00
74E819	2017-08-14 15:33:00+03	86300.00
74E85F	2017-08-10 14:21:00+03	46400.00
74E9F5	2017-07-03 23:10:00+03	69000.00
74EA43	2017-07-30 15:10:00+03	187200.00
74EA48	2017-07-22 22:50:00+03	37100.00
74EA99	2017-08-13 23:07:00+03	78400.00
74EAFE	2017-07-16 05:29:00+03	23600.00
74EB1B	2017-07-20 01:32:00+03	366200.00
74EB4B	2017-07-06 06:26:00+03	108000.00
74EB6F	2017-08-03 10:30:00+03	6700.00
74EC34	2017-08-04 02:18:00+03	174800.00
74EC82	2017-07-30 14:50:00+03	23200.00
74EC94	2017-07-17 21:23:00+03	206800.00
74ECB4	2017-08-14 01:13:00+03	268800.00
74ECB9	2017-07-12 14:03:00+03	113700.00
74ECBC	2017-07-12 19:34:00+03	23600.00
74ECCA	2017-07-29 01:12:00+03	38500.00
74ECDE	2017-08-01 03:51:00+03	492000.00
74ECF7	2017-08-13 10:36:00+03	6000.00
74ED53	2017-07-06 10:34:00+03	6000.00
74EDCC	2017-07-25 05:57:00+03	43000.00
74EE76	2017-07-22 20:05:00+03	49900.00
74EE7C	2017-07-02 02:52:00+03	56600.00
74EEC1	2017-07-16 03:58:00+03	67600.00
74EED1	2017-08-05 20:57:00+03	130400.00
74EF31	2017-08-09 08:00:00+03	56000.00
74EF6C	2017-07-22 16:26:00+03	48800.00
74EF7A	2017-07-18 00:52:00+03	111600.00
74F01B	2017-08-09 11:35:00+03	78200.00
74F039	2017-07-02 09:00:00+03	64500.00
74F118	2017-07-21 21:16:00+03	94000.00
74F145	2017-07-09 13:49:00+03	13400.00
74F167	2017-08-05 04:58:00+03	138000.00
74F1E0	2017-07-07 13:58:00+03	51900.00
74F1F4	2017-08-12 05:38:00+03	119000.00
74F251	2017-08-05 11:44:00+03	64200.00
74F27F	2017-08-04 17:23:00+03	44000.00
74F2A1	2017-08-10 12:53:00+03	121700.00
74F2AE	2017-08-09 20:48:00+03	136200.00
74F313	2017-07-02 01:52:00+03	128600.00
74F31A	2017-07-04 18:24:00+03	9800.00
74F351	2017-08-11 09:53:00+03	28000.00
74F35B	2017-07-19 19:41:00+03	54800.00
74F38A	2017-07-19 02:59:00+03	37200.00
74F3CC	2017-07-30 11:51:00+03	32700.00
74F3E7	2017-07-28 03:14:00+03	258400.00
74F45B	2017-08-04 11:47:00+03	33100.00
74F483	2017-07-08 17:00:00+03	139300.00
74F4B3	2017-08-02 05:10:00+03	14000.00
74F536	2017-08-15 16:58:00+03	58600.00
74F54C	2017-07-15 14:27:00+03	36200.00
74F555	2017-08-12 20:55:00+03	10800.00
74F55A	2017-08-13 09:29:00+03	69600.00
74F565	2017-08-07 01:43:00+03	32700.00
74F596	2017-08-10 11:21:00+03	27200.00
74F61E	2017-07-15 14:09:00+03	174000.00
74F6B4	2017-07-24 13:21:00+03	91100.00
74F702	2017-07-21 08:21:00+03	7400.00
74F731	2017-07-21 10:00:00+03	120000.00
74F759	2017-07-02 07:24:00+03	205600.00
74F785	2017-07-30 13:34:00+03	16600.00
74F7CF	2017-07-25 21:12:00+03	160000.00
74F7D8	2017-07-16 13:20:00+03	8000.00
74F7F0	2017-07-18 17:13:00+03	56000.00
74F838	2017-07-14 02:35:00+03	12600.00
74F857	2017-08-04 06:24:00+03	56000.00
74F8FE	2017-08-11 14:36:00+03	189200.00
74F9AA	2017-07-18 14:45:00+03	75600.00
74F9AF	2017-07-14 16:53:00+03	52900.00
74FA5C	2017-07-20 08:17:00+03	87200.00
74FAB4	2017-07-26 00:04:00+03	59300.00
74FACB	2017-07-10 12:11:00+03	12400.00
74FAE6	2017-08-10 05:17:00+03	129700.00
74FAF1	2017-07-17 11:32:00+03	122300.00
74FB0A	2017-07-09 00:11:00+03	6300.00
74FB18	2017-07-22 05:38:00+03	37200.00
74FB51	2017-07-27 17:45:00+03	97700.00
74FB83	2017-08-11 00:24:00+03	79000.00
74FB99	2017-07-08 19:32:00+03	42800.00
74FBBD	2017-08-10 06:34:00+03	80900.00
74FC38	2017-08-12 17:27:00+03	29800.00
74FC8D	2017-07-20 07:04:00+03	32900.00
74FCB9	2017-07-08 16:11:00+03	48300.00
74FD30	2017-08-04 11:43:00+03	29600.00
74FDDD	2017-07-11 10:28:00+03	8000.00
74FDF5	2017-07-22 23:15:00+03	131600.00
74FDFE	2017-08-08 20:46:00+03	23600.00
74FE0C	2017-08-01 21:03:00+03	231900.00
74FE1A	2017-08-11 11:55:00+03	23600.00
74FE37	2017-08-15 13:58:00+03	136000.00
74FE55	2017-08-13 03:18:00+03	71900.00
74FEF3	2017-07-22 18:59:00+03	309000.00
74FF04	2017-07-17 00:12:00+03	87200.00
74FF81	2017-07-09 12:10:00+03	49600.00
74FF98	2017-07-05 12:54:00+03	11000.00
74FFD3	2017-07-10 04:25:00+03	111600.00
750062	2017-08-07 05:48:00+03	26200.00
75009D	2017-07-25 06:04:00+03	62000.00
7500C8	2017-07-20 23:33:00+03	23200.00
7500CF	2017-07-30 16:27:00+03	19600.00
7500FA	2017-07-24 05:37:00+03	61800.00
750148	2017-07-27 19:58:00+03	36200.00
750181	2017-07-12 01:22:00+03	92400.00
750192	2017-08-03 23:24:00+03	27200.00
75019C	2017-07-26 05:42:00+03	24400.00
7501AF	2017-08-08 23:58:00+03	49200.00
7501CC	2017-08-09 16:38:00+03	87200.00
750227	2017-07-03 17:30:00+03	25000.00
750245	2017-08-03 21:19:00+03	26000.00
750268	2017-08-07 16:42:00+03	123000.00
7502A0	2017-07-21 00:34:00+03	67700.00
7502AB	2017-07-29 08:39:00+03	26000.00
7502B1	2017-07-24 22:50:00+03	31800.00
7502BA	2017-07-22 22:07:00+03	54500.00
7502CB	2017-08-14 19:12:00+03	82000.00
750303	2017-07-08 17:16:00+03	38600.00
750336	2017-07-06 21:10:00+03	47700.00
750376	2017-08-13 07:17:00+03	26800.00
750383	2017-07-27 04:20:00+03	406700.00
75038F	2017-08-03 22:32:00+03	56000.00
7503E5	2017-07-20 20:53:00+03	99700.00
7504C8	2017-07-27 03:49:00+03	16400.00
750531	2017-07-25 08:16:00+03	116000.00
7505C4	2017-07-08 11:47:00+03	21000.00
750616	2017-07-20 10:38:00+03	50300.00
750669	2017-07-04 11:27:00+03	253300.00
750671	2017-07-07 23:13:00+03	58000.00
750721	2017-07-09 22:26:00+03	89700.00
7507F0	2017-07-06 05:16:00+03	26800.00
75080A	2017-07-26 20:01:00+03	75300.00
750876	2017-08-02 18:48:00+03	26000.00
75088D	2017-07-02 17:16:00+03	83900.00
7508B4	2017-07-17 22:46:00+03	289800.00
7508C7	2017-08-02 20:36:00+03	52300.00
7508D0	2017-07-25 15:08:00+03	167900.00
750900	2017-08-03 20:16:00+03	77500.00
7509A0	2017-08-13 09:04:00+03	36000.00
7509A2	2017-08-14 20:01:00+03	32200.00
750A04	2017-07-29 08:01:00+03	69700.00
750A46	2017-07-03 10:20:00+03	300000.00
750A5F	2017-07-06 09:56:00+03	32200.00
750AFB	2017-08-02 08:31:00+03	442800.00
750B0C	2017-07-05 19:37:00+03	35400.00
750B33	2017-08-13 02:55:00+03	13600.00
750B41	2017-08-05 16:18:00+03	67100.00
750B60	2017-07-15 03:48:00+03	23600.00
750B81	2017-07-17 22:25:00+03	36200.00
750BCA	2017-07-02 00:45:00+03	67300.00
750C0F	2017-08-12 18:33:00+03	23200.00
750C1E	2017-07-29 09:49:00+03	39500.00
750C88	2017-07-16 18:34:00+03	169800.00
750CA3	2017-08-03 07:01:00+03	23600.00
750CAA	2017-08-12 10:33:00+03	77900.00
750D21	2017-07-09 06:41:00+03	83600.00
750D29	2017-07-15 08:14:00+03	26000.00
750D5F	2017-08-06 14:34:00+03	176600.00
750D7B	2017-07-20 04:52:00+03	69600.00
750DB0	2017-08-06 16:25:00+03	55800.00
750E5A	2017-06-29 13:56:00+03	49100.00
750E71	2017-08-08 05:58:00+03	22400.00
750E92	2017-08-08 08:27:00+03	23900.00
750FC5	2017-07-28 02:04:00+03	13000.00
750FFE	2017-08-06 12:56:00+03	92800.00
751096	2017-07-27 03:38:00+03	28000.00
7510A2	2017-08-10 09:27:00+03	56000.00
7511B9	2017-08-15 12:14:00+03	31100.00
7511D3	2017-07-24 02:38:00+03	13400.00
7511FF	2017-07-15 03:27:00+03	123000.00
75127F	2017-07-24 19:40:00+03	28800.00
75129C	2017-08-15 10:50:00+03	123000.00
7512C7	2017-07-27 11:28:00+03	49100.00
7512CD	2017-07-22 18:52:00+03	123000.00
751378	2017-07-19 00:06:00+03	118700.00
7513C6	2017-07-17 22:20:00+03	28000.00
751404	2017-07-07 19:15:00+03	25000.00
751405	2017-07-21 09:42:00+03	181000.00
751445	2017-08-12 19:20:00+03	48800.00
751459	2017-07-22 10:05:00+03	47100.00
751469	2017-07-27 12:57:00+03	50000.00
751540	2017-07-18 07:10:00+03	123000.00
75159A	2017-07-16 08:12:00+03	37700.00
7515AD	2017-07-10 05:02:00+03	187600.00
7515C3	2017-07-14 12:26:00+03	8200.00
7515F4	2017-07-16 11:51:00+03	26800.00
751655	2017-08-10 15:27:00+03	73300.00
7516BE	2017-06-27 21:49:00+03	21400.00
7516C4	2017-08-06 09:14:00+03	52700.00
751736	2017-08-05 08:39:00+03	62300.00
75178C	2017-07-18 20:22:00+03	84500.00
7517CC	2017-06-30 21:11:00+03	60000.00
7518A4	2017-07-20 13:28:00+03	73500.00
7518AC	2017-07-05 09:32:00+03	215600.00
7518FA	2017-07-30 03:32:00+03	30200.00
751903	2017-07-28 11:51:00+03	68900.00
75190A	2017-07-27 21:21:00+03	31100.00
75191F	2017-07-23 20:33:00+03	19600.00
75196A	2017-08-02 03:41:00+03	79300.00
751995	2017-07-07 18:22:00+03	56600.00
751A20	2017-07-21 08:47:00+03	23200.00
751A6E	2017-07-04 12:02:00+03	52000.00
751A95	2017-08-08 13:31:00+03	45200.00
751AB0	2017-07-14 16:59:00+03	173500.00
751ACA	2017-07-20 12:30:00+03	67200.00
751B64	2017-07-17 19:11:00+03	72800.00
751B6D	2017-08-11 10:38:00+03	204100.00
751B94	2017-08-13 23:00:00+03	51600.00
751BC9	2017-07-14 16:28:00+03	56000.00
751BF9	2017-07-17 23:25:00+03	13400.00
751C63	2017-07-29 15:13:00+03	7400.00
751C8F	2017-08-13 15:43:00+03	48800.00
751C95	2017-08-02 20:36:00+03	136800.00
751CD3	2017-07-15 12:15:00+03	23200.00
751CF8	2017-07-09 08:47:00+03	66000.00
751D1A	2017-07-06 23:56:00+03	28000.00
751D83	2017-07-26 19:01:00+03	23900.00
751D8D	2017-07-11 11:51:00+03	23200.00
751DA7	2017-07-17 07:58:00+03	132800.00
751DCB	2017-07-21 16:24:00+03	25300.00
751DFE	2017-07-25 19:24:00+03	272900.00
751E42	2017-07-29 18:50:00+03	80000.00
751EB2	2017-07-01 17:05:00+03	36800.00
751EB8	2017-08-11 10:17:00+03	40100.00
751F03	2017-08-03 08:35:00+03	102100.00
751F3A	2017-08-14 18:58:00+03	46800.00
751F4C	2017-08-12 01:45:00+03	28800.00
751F50	2017-07-25 13:01:00+03	70400.00
752040	2017-07-27 16:51:00+03	112000.00
752042	2017-07-30 09:59:00+03	6700.00
752076	2017-08-05 15:36:00+03	140900.00
7520F9	2017-08-02 02:47:00+03	57300.00
75212D	2017-07-07 15:28:00+03	55000.00
7521AA	2017-08-09 07:35:00+03	66000.00
752215	2017-07-21 01:02:00+03	54800.00
752247	2017-07-12 02:08:00+03	88800.00
752249	2017-08-09 12:56:00+03	44700.00
752258	2017-07-09 08:06:00+03	67600.00
7522A6	2017-07-20 18:45:00+03	135400.00
7522C3	2017-07-31 20:19:00+03	146000.00
752372	2017-08-02 00:04:00+03	28000.00
752375	2017-08-14 16:23:00+03	32200.00
7523A5	2017-07-02 19:38:00+03	136200.00
7523C0	2017-08-05 18:32:00+03	258400.00
752451	2017-07-29 20:55:00+03	136600.00
75249D	2017-07-07 21:37:00+03	135600.00
7524F8	2017-07-12 13:45:00+03	58200.00
7524FB	2017-07-18 00:41:00+03	133200.00
75256A	2017-08-10 11:09:00+03	43900.00
7525CC	2017-07-14 17:03:00+03	20000.00
752604	2017-08-06 18:31:00+03	147100.00
75265C	2017-07-12 04:45:00+03	112500.00
752667	2017-07-30 10:07:00+03	23400.00
752688	2017-08-05 09:13:00+03	36200.00
7526A6	2017-08-09 14:03:00+03	84100.00
7526AA	2017-06-30 08:19:00+03	12600.00
752714	2017-08-05 15:28:00+03	21400.00
75277E	2017-07-05 14:12:00+03	11600.00
7527C0	2017-08-10 22:57:00+03	26800.00
7527D7	2017-07-27 15:08:00+03	17200.00
7527E6	2017-07-21 07:34:00+03	206400.00
75280C	2017-08-05 20:35:00+03	102100.00
752883	2017-08-14 14:11:00+03	85000.00
75288D	2017-07-08 18:49:00+03	39800.00
7528AF	2017-07-18 21:10:00+03	112000.00
7528BA	2017-07-02 20:27:00+03	91200.00
7528C4	2017-08-01 22:03:00+03	31600.00
7528FB	2017-07-09 17:53:00+03	15000.00
75290E	2017-07-12 21:24:00+03	84500.00
75293A	2017-07-31 09:09:00+03	46400.00
7529AC	2017-07-12 22:04:00+03	67600.00
752A12	2017-07-08 11:01:00+03	179300.00
752A28	2017-08-10 22:20:00+03	99700.00
752A82	2017-07-23 21:06:00+03	181600.00
752B10	2017-07-13 02:18:00+03	146300.00
752B55	2017-08-07 03:05:00+03	40600.00
752B72	2017-07-15 02:45:00+03	16400.00
752B8C	2017-08-04 19:06:00+03	130100.00
752BCC	2017-08-15 06:34:00+03	67100.00
752BDA	2017-07-14 04:26:00+03	11800.00
752C0E	2017-07-09 14:32:00+03	47200.00
752C1D	2017-07-18 00:24:00+03	112400.00
752C96	2017-07-19 13:27:00+03	35700.00
752CB0	2017-07-26 05:58:00+03	89600.00
752CF1	2017-07-21 05:30:00+03	75600.00
752CF3	2017-08-15 13:07:00+03	22100.00
752D2F	2017-08-08 00:49:00+03	64100.00
752DB8	2017-07-15 05:32:00+03	54400.00
752E6C	2017-08-12 11:38:00+03	23200.00
752E78	2017-08-05 01:33:00+03	79400.00
752EA4	2017-07-06 19:28:00+03	133100.00
752EAB	2017-07-02 13:33:00+03	26000.00
752F63	2017-08-06 17:42:00+03	73600.00
752F76	2017-07-17 10:36:00+03	208100.00
752F86	2017-07-19 01:34:00+03	128800.00
75301F	2017-07-04 14:44:00+03	20400.00
75308B	2017-07-30 18:19:00+03	58400.00
7530D1	2017-07-29 14:02:00+03	6000.00
7530DC	2017-07-22 09:01:00+03	64400.00
753130	2017-08-13 20:03:00+03	132800.00
7531B2	2017-07-04 04:06:00+03	41600.00
7531BB	2017-08-08 07:44:00+03	105600.00
753241	2017-08-04 09:21:00+03	29600.00
753264	2017-08-07 05:20:00+03	55800.00
753297	2017-07-14 18:17:00+03	39500.00
7532C5	2017-08-08 06:24:00+03	82000.00
7532D9	2017-07-27 06:32:00+03	16400.00
753391	2017-07-11 15:36:00+03	35900.00
753406	2017-07-09 09:36:00+03	66600.00
75342A	2017-07-27 01:52:00+03	46200.00
753462	2017-08-15 02:45:00+03	130800.00
7534AB	2017-07-03 01:18:00+03	108000.00
753520	2017-08-03 01:03:00+03	25400.00
753554	2017-08-09 23:00:00+03	22600.00
7535BA	2017-08-02 21:05:00+03	14800.00
753669	2017-07-27 14:42:00+03	93900.00
7536B2	2017-07-23 23:46:00+03	24400.00
7536B9	2017-08-05 19:56:00+03	54800.00
7537A0	2017-07-01 14:19:00+03	112000.00
7537C8	2017-07-25 20:48:00+03	99300.00
75382F	2017-07-21 22:16:00+03	135000.00
753830	2017-08-04 19:57:00+03	30700.00
753855	2017-07-05 11:53:00+03	24300.00
7538A6	2017-07-25 07:21:00+03	111600.00
7538A8	2017-08-07 23:04:00+03	80400.00
7538D3	2017-07-22 09:33:00+03	96800.00
753912	2017-07-28 22:17:00+03	31100.00
75393C	2017-07-28 05:19:00+03	86600.00
7539A9	2017-07-11 08:10:00+03	71800.00
753B26	2017-07-31 22:29:00+03	88500.00
753BAB	2017-07-25 19:54:00+03	131800.00
753C08	2017-08-02 20:47:00+03	23600.00
753C39	2017-08-10 01:44:00+03	54700.00
753C68	2017-08-15 13:02:00+03	46400.00
753C8D	2017-07-15 14:49:00+03	32200.00
753CC2	2017-08-04 04:21:00+03	47100.00
753D21	2017-07-25 12:49:00+03	96600.00
753D32	2017-07-15 00:03:00+03	36100.00
753D59	2017-08-04 20:19:00+03	59100.00
753D97	2017-08-10 08:37:00+03	76400.00
753DB5	2017-08-02 08:12:00+03	12600.00
753DE4	2017-08-10 07:47:00+03	283100.00
753E2C	2017-06-29 22:00:00+03	18800.00
753E42	2017-07-26 13:44:00+03	63200.00
753E4C	2017-07-13 04:32:00+03	64400.00
753E5C	2017-07-31 11:09:00+03	89700.00
753EBE	2017-07-28 18:55:00+03	52000.00
753ED1	2017-07-16 11:48:00+03	86800.00
753F3E	2017-07-04 02:41:00+03	118300.00
753F74	2017-07-15 00:03:00+03	46400.00
753F7A	2017-08-11 19:12:00+03	6700.00
753FD3	2017-07-22 15:13:00+03	20200.00
754010	2017-07-28 22:30:00+03	89700.00
754081	2017-06-30 00:21:00+03	19600.00
7540C6	2017-07-20 18:22:00+03	46400.00
7540DB	2017-08-15 11:58:00+03	28000.00
7540F8	2017-08-11 07:23:00+03	31500.00
75414A	2017-07-02 21:24:00+03	81200.00
75418E	2017-07-28 00:20:00+03	40600.00
754246	2017-08-06 22:48:00+03	48500.00
754263	2017-07-20 06:58:00+03	43200.00
75428E	2017-08-09 09:29:00+03	234700.00
754296	2017-07-17 14:03:00+03	43200.00
7542F4	2017-07-18 16:49:00+03	40900.00
75434E	2017-08-14 13:06:00+03	90400.00
75435C	2017-07-10 09:26:00+03	10800.00
75435E	2017-08-14 07:23:00+03	19600.00
7543FD	2017-08-05 05:34:00+03	32800.00
754420	2017-07-29 08:34:00+03	97900.00
754435	2017-07-27 11:26:00+03	135400.00
75447C	2017-08-10 10:56:00+03	56600.00
7544CA	2017-08-03 00:50:00+03	66600.00
7544D8	2017-07-12 10:11:00+03	12400.00
754518	2017-08-07 23:11:00+03	399600.00
75451F	2017-07-15 05:42:00+03	70400.00
754589	2017-07-23 08:47:00+03	114400.00
754639	2017-07-20 09:30:00+03	365400.00
75467D	2017-08-12 07:22:00+03	278100.00
7546B0	2017-07-25 02:38:00+03	23600.00
7546FF	2017-07-09 10:03:00+03	27600.00
754716	2017-07-09 09:19:00+03	95200.00
754748	2017-07-04 23:58:00+03	12400.00
75477A	2017-07-12 04:22:00+03	23200.00
75478C	2017-08-10 10:47:00+03	135400.00
754790	2017-07-26 14:18:00+03	68300.00
7547E5	2017-07-14 18:46:00+03	85700.00
75481B	2017-07-22 04:59:00+03	402200.00
754841	2017-08-10 19:40:00+03	29600.00
75486D	2017-07-10 21:02:00+03	43500.00
754872	2017-08-03 03:53:00+03	133200.00
7548A0	2017-07-05 07:38:00+03	23400.00
7548EB	2017-07-31 09:53:00+03	47100.00
7549C1	2017-08-12 18:11:00+03	86400.00
7549C4	2017-08-11 11:51:00+03	67600.00
7549D9	2017-08-01 14:31:00+03	14000.00
7549EA	2017-07-25 20:11:00+03	99200.00
754A43	2017-07-24 12:58:00+03	73500.00
754A6A	2017-07-09 14:53:00+03	64700.00
754A88	2017-07-11 16:23:00+03	46400.00
754AB0	2017-07-11 07:26:00+03	57800.00
754AB3	2017-07-12 00:20:00+03	50600.00
754AB5	2017-07-20 05:31:00+03	14000.00
754ACE	2017-08-03 04:42:00+03	92900.00
754AD4	2017-06-27 04:54:00+03	43700.00
754AE9	2017-08-01 12:21:00+03	16400.00
754B43	2017-07-10 06:36:00+03	27200.00
754BA2	2017-08-01 03:13:00+03	40600.00
754C08	2017-08-05 14:37:00+03	59300.00
754C33	2017-07-27 13:11:00+03	266400.00
754C93	2017-07-23 14:12:00+03	257600.00
754CA3	2017-07-19 19:17:00+03	39500.00
754CA4	2017-07-26 07:02:00+03	24400.00
754D16	2017-07-15 11:27:00+03	101400.00
754D47	2017-07-14 08:15:00+03	29400.00
754DA2	2017-07-17 14:08:00+03	66600.00
754ED5	2017-07-21 05:01:00+03	28600.00
754EEA	2017-07-29 11:49:00+03	75600.00
754EF4	2017-08-14 01:32:00+03	112000.00
754F36	2017-07-16 01:23:00+03	8000.00
754F61	2017-07-08 09:35:00+03	44000.00
754F67	2017-07-29 14:36:00+03	13000.00
754FC7	2017-07-12 06:29:00+03	325500.00
754FD6	2017-08-09 12:57:00+03	20200.00
75500F	2017-07-21 22:48:00+03	84100.00
75509B	2017-07-24 23:10:00+03	112000.00
7550B3	2017-07-26 07:54:00+03	13600.00
7550E4	2017-07-29 01:58:00+03	107500.00
75518A	2017-07-15 13:20:00+03	81600.00
75518E	2017-08-03 08:16:00+03	43700.00
7551B5	2017-07-19 06:58:00+03	69500.00
75525B	2017-07-07 20:19:00+03	44800.00
755271	2017-08-08 00:46:00+03	115800.00
7552AB	2017-07-02 10:50:00+03	6700.00
7552BF	2017-07-27 22:30:00+03	62600.00
7552FC	2017-08-01 14:08:00+03	36200.00
755396	2017-07-10 11:40:00+03	398500.00
7553FC	2017-07-13 16:53:00+03	64300.00
755428	2017-08-08 05:02:00+03	17000.00
7554A6	2017-07-24 17:51:00+03	77600.00
7554F3	2017-08-06 03:41:00+03	56200.00
755535	2017-08-14 03:50:00+03	61500.00
755564	2017-08-13 12:41:00+03	21400.00
755589	2017-08-04 13:19:00+03	111600.00
7555A7	2017-07-26 06:50:00+03	85000.00
7555AA	2017-07-10 06:24:00+03	31400.00
7555CA	2017-08-11 14:33:00+03	67200.00
7555D6	2017-08-10 00:40:00+03	134400.00
75564E	2017-07-08 07:02:00+03	55800.00
75567B	2017-07-19 22:22:00+03	6800.00
755722	2017-07-31 08:14:00+03	62800.00
75573D	2017-08-11 20:18:00+03	79000.00
7557FF	2017-07-08 23:34:00+03	61800.00
75591A	2017-07-14 02:11:00+03	46000.00
75591B	2017-07-29 07:32:00+03	22600.00
7559F2	2017-08-09 08:53:00+03	116500.00
7559F8	2017-07-07 08:16:00+03	240600.00
755A29	2017-08-14 13:43:00+03	30200.00
755A38	2017-07-17 08:00:00+03	75300.00
755A73	2017-07-23 11:41:00+03	248300.00
755A8E	2017-07-22 02:04:00+03	85200.00
755AA1	2017-08-08 11:58:00+03	6700.00
755ABD	2017-07-01 00:23:00+03	123600.00
755ABF	2017-07-13 17:21:00+03	89700.00
755ACF	2017-08-06 17:18:00+03	118800.00
755AD6	2017-07-06 02:13:00+03	68400.00
755B5F	2017-07-06 20:24:00+03	24600.00
755C62	2017-07-07 18:04:00+03	123000.00
755C6D	2017-08-05 10:54:00+03	56100.00
755CB7	2017-07-06 16:32:00+03	209700.00
755CDC	2017-07-21 12:52:00+03	110600.00
755D5C	2017-08-06 07:06:00+03	73600.00
755D62	2017-08-02 00:10:00+03	95700.00
755E01	2017-07-31 00:39:00+03	68000.00
755E03	2017-07-31 12:17:00+03	65800.00
755F0B	2017-07-05 09:08:00+03	65400.00
755F53	2017-07-23 12:05:00+03	8600.00
755F6C	2017-07-07 04:48:00+03	204200.00
755F80	2017-07-24 12:07:00+03	42800.00
755FE4	2017-07-15 14:11:00+03	125400.00
755FF9	2017-08-06 23:25:00+03	60400.00
756026	2017-08-10 15:09:00+03	23200.00
756099	2017-07-10 09:06:00+03	36200.00
7560EF	2017-07-11 12:54:00+03	55800.00
7560F1	2017-07-29 22:17:00+03	133200.00
7561F3	2017-08-05 08:32:00+03	56000.00
75621B	2017-06-30 21:29:00+03	28800.00
75621C	2017-07-13 02:28:00+03	75800.00
7562B9	2017-07-20 14:20:00+03	14400.00
756306	2017-08-03 10:29:00+03	111700.00
756346	2017-07-30 01:47:00+03	92000.00
756350	2017-07-02 15:37:00+03	147200.00
7563C2	2017-07-17 00:04:00+03	378400.00
7563ED	2017-07-23 07:58:00+03	26000.00
7563F5	2017-08-12 21:05:00+03	56600.00
756403	2017-07-03 15:47:00+03	272600.00
75645B	2017-07-28 21:06:00+03	103800.00
756481	2017-07-06 21:21:00+03	24300.00
7564F8	2017-07-28 14:02:00+03	13600.00
756547	2017-08-14 10:28:00+03	81700.00
7565E7	2017-07-15 01:25:00+03	35300.00
756684	2017-07-14 03:14:00+03	21400.00
7566AD	2017-07-08 22:23:00+03	72300.00
756748	2017-07-22 07:56:00+03	26000.00
756764	2017-08-08 00:16:00+03	33800.00
75678B	2017-08-09 00:37:00+03	258400.00
7567A5	2017-08-14 13:40:00+03	81300.00
7567A6	2017-08-01 14:07:00+03	258000.00
7567A9	2017-07-12 15:44:00+03	80200.00
7567DE	2017-07-11 22:58:00+03	27600.00
75683D	2017-08-03 07:21:00+03	68800.00
75684A	2017-07-19 13:04:00+03	14000.00
756950	2017-07-20 05:17:00+03	132800.00
7569F7	2017-07-14 04:42:00+03	23200.00
7569FA	2017-07-19 00:29:00+03	136200.00
756A02	2017-07-16 23:56:00+03	28000.00
756A37	2017-07-06 21:23:00+03	46400.00
756A62	2017-07-29 07:57:00+03	48800.00
756A86	2017-07-25 10:48:00+03	47200.00
756A98	2017-07-20 09:25:00+03	131900.00
756ABB	2017-07-17 04:26:00+03	48300.00
756AC7	2017-08-05 09:26:00+03	19600.00
756BA3	2017-07-20 11:51:00+03	123000.00
756BBF	2017-08-02 09:51:00+03	88700.00
756BE2	2017-08-02 12:13:00+03	28000.00
756BEF	2017-07-25 10:45:00+03	24400.00
756C4E	2017-07-10 15:03:00+03	16400.00
756C7C	2017-08-13 06:01:00+03	25600.00
756C8C	2017-08-02 21:00:00+03	89600.00
756C94	2017-07-23 16:53:00+03	22000.00
756CA2	2017-07-31 05:25:00+03	73300.00
756CDA	2017-07-17 08:56:00+03	45200.00
756D4F	2017-06-27 23:54:00+03	28000.00
756DF6	2017-07-17 09:16:00+03	75300.00
756E16	2017-07-28 19:07:00+03	89100.00
756E8C	2017-07-24 00:38:00+03	23200.00
756EAE	2017-07-20 09:13:00+03	29600.00
756EB2	2017-08-13 03:41:00+03	56600.00
756ED9	2017-08-13 04:03:00+03	65200.00
756EF5	2017-08-07 04:52:00+03	46000.00
756F66	2017-08-15 01:39:00+03	66100.00
756F7F	2017-07-05 05:46:00+03	133200.00
756F9E	2017-08-07 17:12:00+03	37900.00
75700E	2017-07-18 16:13:00+03	67600.00
757026	2017-08-03 09:46:00+03	246000.00
75704D	2017-07-16 20:36:00+03	46900.00
757078	2017-08-07 08:26:00+03	16400.00
7570AA	2017-06-30 16:41:00+03	68800.00
7570CA	2017-08-12 03:59:00+03	40800.00
757115	2017-08-13 21:38:00+03	404700.00
757146	2017-07-10 22:11:00+03	45100.00
757156	2017-08-09 20:33:00+03	40800.00
757193	2017-07-10 02:21:00+03	17800.00
7571CD	2017-08-11 04:02:00+03	28000.00
75720A	2017-07-20 00:07:00+03	101200.00
757225	2017-08-13 19:56:00+03	85000.00
757266	2017-08-15 08:34:00+03	88900.00
757289	2017-07-31 08:03:00+03	99200.00
7572B4	2017-07-27 09:19:00+03	68000.00
7572D8	2017-08-03 04:31:00+03	113800.00
7572FB	2017-07-03 11:40:00+03	66600.00
7572FD	2017-08-03 05:07:00+03	69500.00
75731B	2017-07-23 06:10:00+03	22600.00
757368	2017-07-06 05:24:00+03	34000.00
757376	2017-08-09 14:52:00+03	23200.00
757386	2017-07-25 00:42:00+03	66600.00
757473	2017-07-28 04:05:00+03	73500.00
75748E	2017-08-13 21:36:00+03	92000.00
7574FB	2017-07-31 01:32:00+03	27000.00
757546	2017-07-28 00:17:00+03	13400.00
757592	2017-07-07 03:36:00+03	75300.00
7575CF	2017-08-08 16:28:00+03	111000.00
757638	2017-07-22 02:53:00+03	271200.00
757686	2017-08-09 06:21:00+03	49500.00
7576DD	2017-07-19 18:55:00+03	40200.00
7577AB	2017-08-10 03:57:00+03	44800.00
7577B3	2017-06-28 05:55:00+03	65900.00
7577E2	2017-07-22 00:32:00+03	58400.00
7577F4	2017-07-10 11:59:00+03	56900.00
75783D	2017-08-14 12:17:00+03	47700.00
75786B	2017-08-06 15:25:00+03	16400.00
75790A	2017-07-06 12:58:00+03	32200.00
757921	2017-07-21 08:27:00+03	63600.00
757953	2017-08-01 18:00:00+03	159800.00
757979	2017-08-11 05:59:00+03	254900.00
757991	2017-07-25 14:15:00+03	39300.00
7579DF	2017-07-21 15:54:00+03	48800.00
7579FA	2017-07-14 12:31:00+03	73300.00
757A17	2017-08-08 01:08:00+03	270800.00
757ADD	2017-07-11 07:15:00+03	75300.00
757B26	2017-07-25 01:06:00+03	58100.00
757B27	2017-07-14 03:21:00+03	52000.00
757B59	2017-07-05 13:52:00+03	24200.00
757BAD	2017-08-11 06:13:00+03	12600.00
757C57	2017-07-26 13:15:00+03	105600.00
757C88	2017-07-20 12:10:00+03	101200.00
757D2C	2017-08-03 21:25:00+03	47000.00
757D6A	2017-07-27 09:44:00+03	19600.00
757DEE	2017-07-24 13:40:00+03	25700.00
757E07	2017-08-08 21:00:00+03	13600.00
757E55	2017-07-10 15:19:00+03	54500.00
757E5A	2017-08-10 23:13:00+03	18800.00
757EA6	2017-07-05 12:48:00+03	46800.00
757EB1	2017-07-12 14:17:00+03	125600.00
757F14	2017-08-01 20:28:00+03	126300.00
757F4D	2017-06-30 07:06:00+03	79000.00
757F8A	2017-08-07 23:48:00+03	57600.00
757F9A	2017-07-20 09:21:00+03	28700.00
758039	2017-08-10 15:33:00+03	38400.00
758040	2017-07-01 16:40:00+03	12600.00
75806D	2017-08-08 12:38:00+03	192900.00
758119	2017-08-02 23:35:00+03	23200.00
75812F	2017-07-26 18:19:00+03	13700.00
758156	2017-08-13 16:09:00+03	30800.00
758168	2017-07-31 17:08:00+03	55800.00
75816C	2017-08-05 07:07:00+03	22000.00
7581C6	2017-08-14 13:10:00+03	62700.00
7581F9	2017-08-08 05:15:00+03	35800.00
7581FB	2017-07-03 02:59:00+03	8600.00
75825D	2017-07-24 21:43:00+03	97600.00
7582FD	2017-07-29 14:07:00+03	110300.00
75835D	2017-07-21 09:57:00+03	67600.00
7583DE	2017-07-26 09:59:00+03	103600.00
758441	2017-08-04 15:17:00+03	48800.00
75846B	2017-07-26 21:55:00+03	13200.00
758492	2017-07-04 04:40:00+03	65500.00
75849B	2017-07-02 19:16:00+03	12600.00
7584F6	2017-08-07 10:12:00+03	37600.00
758501	2017-06-30 00:14:00+03	84500.00
758502	2017-07-27 16:54:00+03	291000.00
75850F	2017-07-24 19:09:00+03	34000.00
7585B6	2017-07-10 09:08:00+03	48200.00
75860F	2017-07-20 08:33:00+03	132800.00
758674	2017-08-03 22:54:00+03	6300.00
75874F	2017-07-02 02:22:00+03	28000.00
758782	2017-08-15 00:26:00+03	13000.00
75879D	2017-07-14 07:30:00+03	37200.00
7587CD	2017-08-12 02:13:00+03	27400.00
7587D2	2017-08-10 13:00:00+03	26200.00
758861	2017-07-23 09:59:00+03	57600.00
7588B3	2017-07-10 10:00:00+03	249200.00
7588DB	2017-08-03 19:13:00+03	26800.00
7588EB	2017-07-07 14:44:00+03	101200.00
75890C	2017-07-05 12:23:00+03	122700.00
75892A	2017-07-22 13:45:00+03	69500.00
75898C	2017-07-09 08:03:00+03	38400.00
758A38	2017-07-13 04:44:00+03	38200.00
758A7C	2017-08-07 11:34:00+03	50000.00
758B23	2017-08-13 01:20:00+03	81200.00
758B79	2017-07-14 03:56:00+03	23400.00
758BD1	2017-08-06 19:27:00+03	16400.00
758BE1	2017-06-27 18:33:00+03	161600.00
758BE4	2017-08-07 17:41:00+03	46200.00
758CCC	2017-06-30 02:37:00+03	27800.00
758CE8	2017-08-02 02:47:00+03	160300.00
758CF6	2017-07-12 14:49:00+03	44000.00
758D14	2017-07-08 18:53:00+03	51600.00
758DCF	2017-08-02 09:47:00+03	100600.00
758DD0	2017-07-18 01:02:00+03	8200.00
758E06	2017-07-01 10:34:00+03	54800.00
758E2F	2017-07-19 06:10:00+03	102700.00
758E6F	2017-07-17 12:23:00+03	87100.00
758E84	2017-07-17 07:42:00+03	93500.00
758EBE	2017-07-01 04:29:00+03	32800.00
758F0A	2017-07-01 07:37:00+03	13400.00
758F66	2017-07-30 05:51:00+03	64800.00
7590A3	2017-08-05 01:07:00+03	136200.00
7590D7	2017-07-28 23:18:00+03	30400.00
7590E5	2017-07-08 18:28:00+03	25400.00
759154	2017-07-22 00:40:00+03	112000.00
759191	2017-07-21 19:53:00+03	60000.00
7591CF	2017-08-14 23:17:00+03	26300.00
7591D1	2017-07-07 17:09:00+03	57500.00
7591D5	2017-07-19 15:55:00+03	75300.00
75926D	2017-07-13 23:33:00+03	274200.00
7592C9	2017-08-15 07:28:00+03	28000.00
7593BE	2017-08-05 07:43:00+03	43700.00
7593C2	2017-07-27 13:11:00+03	67200.00
7593F4	2017-08-10 13:47:00+03	66000.00
7594A9	2017-07-23 21:19:00+03	91600.00
7594C7	2017-08-05 08:42:00+03	65200.00
7594D1	2017-07-06 06:03:00+03	46400.00
75955F	2017-07-05 15:20:00+03	40800.00
759581	2017-07-11 10:02:00+03	42900.00
7595C3	2017-07-14 01:01:00+03	51900.00
7595D2	2017-07-02 03:08:00+03	81800.00
7595D3	2017-07-25 14:37:00+03	174400.00
759620	2017-08-14 02:01:00+03	184100.00
7596F5	2017-07-13 04:04:00+03	62800.00
7598E9	2017-07-16 06:50:00+03	66900.00
759920	2017-07-16 11:49:00+03	275200.00
7599F0	2017-07-29 12:09:00+03	301800.00
7599F2	2017-07-25 12:05:00+03	138300.00
7599F5	2017-07-30 10:58:00+03	30900.00
759A6A	2017-07-29 22:45:00+03	57500.00
759A87	2017-07-23 12:09:00+03	23100.00
759A90	2017-07-25 02:03:00+03	58600.00
759A93	2017-08-12 07:28:00+03	6300.00
759AAC	2017-08-15 14:04:00+03	27200.00
759B5F	2017-08-06 16:28:00+03	14400.00
759B72	2017-07-10 03:30:00+03	36000.00
759BF0	2017-07-16 02:27:00+03	23900.00
759C29	2017-07-08 19:02:00+03	78700.00
759C2B	2017-07-19 05:42:00+03	33300.00
759C4C	2017-07-09 12:55:00+03	38200.00
759C57	2017-07-16 14:51:00+03	40200.00
759C6D	2017-07-19 21:15:00+03	133200.00
759D30	2017-07-05 11:40:00+03	125200.00
759D48	2017-07-27 03:05:00+03	42800.00
759DE7	2017-07-27 18:10:00+03	99200.00
759DED	2017-07-24 03:53:00+03	24700.00
759E53	2017-07-08 02:56:00+03	24000.00
759ECD	2017-08-05 02:08:00+03	43200.00
759F70	2017-08-06 21:12:00+03	28300.00
759FE1	2017-07-18 19:32:00+03	391200.00
759FED	2017-08-06 19:27:00+03	37200.00
75A037	2017-07-13 12:58:00+03	132800.00
75A044	2017-07-10 23:54:00+03	94200.00
75A0A8	2017-07-09 17:22:00+03	30200.00
75A0C0	2017-08-04 16:22:00+03	43900.00
75A134	2017-07-11 07:04:00+03	87400.00
75A1E5	2017-07-31 16:02:00+03	106900.00
75A1EB	2017-06-28 03:08:00+03	111700.00
75A256	2017-07-22 23:00:00+03	136500.00
75A25E	2017-08-04 16:08:00+03	43100.00
75A26C	2017-07-20 14:34:00+03	147100.00
75A295	2017-08-08 15:24:00+03	14000.00
75A305	2017-07-18 23:05:00+03	68800.00
75A31C	2017-08-05 01:54:00+03	830700.00
75A34A	2017-07-19 03:05:00+03	37800.00
75A364	2017-07-26 07:35:00+03	134400.00
75A3F4	2017-07-22 23:42:00+03	42700.00
75A43D	2017-08-01 13:01:00+03	48300.00
75A449	2017-07-21 03:34:00+03	13400.00
75A481	2017-07-17 05:15:00+03	31200.00
75A4B4	2017-07-21 03:29:00+03	51300.00
75A4CC	2017-08-05 09:40:00+03	48800.00
75A548	2017-07-21 16:01:00+03	22000.00
75A554	2017-07-08 01:57:00+03	57500.00
75A558	2017-07-24 03:53:00+03	136200.00
75A561	2017-07-17 03:42:00+03	51200.00
75A5A6	2017-07-05 06:02:00+03	30400.00
75A6B0	2017-07-12 03:02:00+03	45500.00
75A6E8	2017-07-01 00:25:00+03	29400.00
75A70A	2017-07-09 05:37:00+03	47100.00
75A759	2017-07-27 05:45:00+03	95200.00
75A7BA	2017-07-06 11:14:00+03	23200.00
75A7DA	2017-06-30 17:45:00+03	37900.00
75A7DF	2017-07-01 08:28:00+03	99200.00
75A7E6	2017-08-14 10:57:00+03	38700.00
75A7F4	2017-07-23 09:23:00+03	283700.00
75A826	2017-08-14 03:25:00+03	117200.00
75A92C	2017-07-26 03:03:00+03	19600.00
75A95B	2017-08-02 02:48:00+03	73500.00
75A96D	2017-08-02 07:26:00+03	99200.00
75A9D6	2017-07-14 16:03:00+03	99200.00
75AA5B	2017-08-12 01:39:00+03	26000.00
75AACB	2017-08-01 03:46:00+03	51500.00
75AAD4	2017-08-02 06:07:00+03	195500.00
75AAF5	2017-08-12 10:54:00+03	55800.00
75AC46	2017-06-28 03:40:00+03	93200.00
75AC91	2017-08-13 06:59:00+03	87400.00
75AC97	2017-07-10 03:44:00+03	53900.00
75ACC3	2017-07-20 14:28:00+03	84100.00
75ADE4	2017-07-07 05:51:00+03	393800.00
75AE0F	2017-07-30 03:03:00+03	264000.00
75AEE7	2017-07-06 08:09:00+03	22000.00
75AF0A	2017-07-16 01:11:00+03	38600.00
75AF3A	2017-07-10 18:15:00+03	15700.00
75AF48	2017-08-01 16:48:00+03	28800.00
75AFD7	2017-07-26 21:42:00+03	51900.00
75B02C	2017-07-18 23:57:00+03	27200.00
75B031	2017-07-08 11:16:00+03	6700.00
75B036	2017-07-10 22:49:00+03	30200.00
75B047	2017-07-30 22:13:00+03	135400.00
75B130	2017-08-01 08:04:00+03	110500.00
75B141	2017-07-22 10:11:00+03	55800.00
75B170	2017-07-08 13:39:00+03	260300.00
75B1B8	2017-08-15 13:10:00+03	68600.00
75B1DE	2017-07-30 08:00:00+03	23400.00
75B24A	2017-07-10 15:12:00+03	46200.00
75B296	2017-06-30 20:15:00+03	131600.00
75B301	2017-07-01 11:46:00+03	26400.00
75B335	2017-07-10 00:40:00+03	27200.00
75B340	2017-07-17 06:00:00+03	39500.00
75B385	2017-07-28 15:29:00+03	92700.00
75B425	2017-07-27 22:12:00+03	220800.00
75B43B	2017-07-17 23:10:00+03	54000.00
75B444	2017-08-10 19:23:00+03	38800.00
75B44A	2017-07-13 11:27:00+03	25000.00
75B573	2017-07-07 22:17:00+03	22200.00
75B5DB	2017-07-02 10:32:00+03	85000.00
75B5F1	2017-08-07 11:48:00+03	28800.00
75B5F9	2017-07-09 20:49:00+03	89600.00
75B5FB	2017-07-20 19:56:00+03	6700.00
75B61E	2017-07-24 09:37:00+03	81600.00
75B645	2017-07-12 01:44:00+03	35600.00
75B6A6	2017-08-06 03:34:00+03	193600.00
75B775	2017-07-11 21:20:00+03	129200.00
75B792	2017-08-05 04:34:00+03	17000.00
75B7FA	2017-08-09 00:13:00+03	21400.00
75B816	2017-07-17 21:18:00+03	259300.00
75B879	2017-07-18 03:21:00+03	68100.00
75B87E	2017-07-28 13:11:00+03	64900.00
75B8E6	2017-07-04 01:18:00+03	28800.00
75B94B	2017-07-11 00:49:00+03	106700.00
75B97A	2017-07-02 18:06:00+03	169900.00
75B99B	2017-07-17 12:36:00+03	37900.00
75B9B0	2017-07-08 13:25:00+03	277800.00
75B9B6	2017-07-28 15:02:00+03	22000.00
75B9CC	2017-08-11 14:46:00+03	20600.00
75B9E3	2017-06-30 20:33:00+03	168000.00
75BA2F	2017-08-14 00:18:00+03	187600.00
75BA45	2017-07-02 23:05:00+03	131600.00
75BAA5	2017-07-08 21:32:00+03	28000.00
75BB26	2017-08-08 19:06:00+03	40200.00
75BB79	2017-08-12 03:46:00+03	21800.00
75BBD5	2017-07-09 13:17:00+03	24000.00
75BBE8	2017-07-29 02:24:00+03	28000.00
75BBEB	2017-08-10 15:15:00+03	46900.00
75BC11	2017-08-05 18:12:00+03	110500.00
75BC39	2017-07-12 23:58:00+03	34000.00
75BC52	2017-08-04 18:49:00+03	20000.00
75BC6E	2017-07-06 12:42:00+03	66600.00
75BCA1	2017-08-03 15:25:00+03	49100.00
75BCDC	2017-07-13 18:01:00+03	46500.00
75BCDE	2017-07-24 06:01:00+03	47200.00
75BD0B	2017-07-15 21:37:00+03	22000.00
75BD47	2017-07-24 19:29:00+03	23200.00
75BD98	2017-07-29 14:35:00+03	99300.00
75BDBF	2017-07-17 14:50:00+03	28800.00
75BDC0	2017-07-26 07:47:00+03	23400.00
75BE29	2017-07-08 11:35:00+03	59200.00
75BE6B	2017-07-26 03:01:00+03	14000.00
75BEA7	2017-07-16 22:40:00+03	56000.00
75BEBA	2017-08-01 10:46:00+03	50100.00
75BF10	2017-07-02 19:27:00+03	62600.00
75BF81	2017-07-27 05:27:00+03	66600.00
75BFA9	2017-08-07 14:00:00+03	30200.00
75C059	2017-07-05 21:22:00+03	201200.00
75C194	2017-07-12 02:09:00+03	133900.00
75C1DB	2017-07-08 05:39:00+03	39300.00
75C1DE	2017-07-27 04:37:00+03	38400.00
75C265	2017-08-12 19:37:00+03	62200.00
75C2EA	2017-06-28 18:31:00+03	27200.00
75C302	2017-08-01 08:32:00+03	25800.00
75C315	2017-07-13 22:33:00+03	21800.00
75C32C	2017-07-16 09:43:00+03	54000.00
75C38F	2017-08-10 16:31:00+03	12600.00
75C428	2017-08-04 07:49:00+03	31200.00
75C517	2017-08-05 23:39:00+03	55800.00
75C528	2017-07-19 04:46:00+03	118700.00
75C5AF	2017-08-10 09:41:00+03	94700.00
75C62A	2017-07-23 15:57:00+03	46000.00
75C67E	2017-08-15 01:49:00+03	43900.00
75C69D	2017-07-16 06:36:00+03	26000.00
75C6C1	2017-07-21 15:08:00+03	133700.00
75C6F7	2017-08-13 12:18:00+03	299600.00
75C719	2017-07-26 23:47:00+03	69900.00
75C820	2017-08-01 18:37:00+03	54800.00
75C881	2017-07-08 23:55:00+03	25900.00
75C8E5	2017-07-05 02:40:00+03	206200.00
75C8EE	2017-07-19 03:27:00+03	37600.00
75C90A	2017-08-03 09:13:00+03	51800.00
75C939	2017-07-02 15:42:00+03	30200.00
75C94A	2017-08-13 02:44:00+03	140900.00
75C94F	2017-08-08 06:54:00+03	55500.00
75C992	2017-07-13 00:56:00+03	134400.00
75C9B3	2017-08-05 17:13:00+03	28800.00
75C9FE	2017-08-06 14:04:00+03	123200.00
75CB30	2017-07-06 06:33:00+03	11600.00
75CB68	2017-07-05 15:07:00+03	21800.00
75CBA7	2017-07-20 01:29:00+03	96800.00
75CBD1	2017-08-08 03:21:00+03	22000.00
75CC0C	2017-07-21 02:09:00+03	135600.00
75CC47	2017-07-28 01:28:00+03	25200.00
75CC6D	2017-07-17 13:44:00+03	24000.00
75CC92	2017-08-06 15:56:00+03	91800.00
75CCE8	2017-08-05 06:47:00+03	22000.00
75CCF4	2017-07-22 06:37:00+03	6800.00
75CD7D	2017-07-25 12:47:00+03	57600.00
75CDA4	2017-08-12 05:50:00+03	23600.00
75CDA5	2017-08-13 21:34:00+03	89100.00
75CDBE	2017-08-05 03:19:00+03	30200.00
75CDEC	2017-07-17 18:50:00+03	135400.00
75CE3C	2017-07-26 13:19:00+03	23400.00
75CE51	2017-07-30 13:48:00+03	131600.00
75CE90	2017-07-07 22:32:00+03	120900.00
75CEC3	2017-08-11 10:55:00+03	480600.00
75CF34	2017-08-05 18:12:00+03	168000.00
75CF57	2017-07-15 19:15:00+03	31400.00
75CF7B	2017-07-26 06:42:00+03	107800.00
75CF83	2017-08-13 14:21:00+03	133100.00
75CFC7	2017-08-13 06:24:00+03	136200.00
75D01D	2017-08-05 18:46:00+03	30200.00
75D033	2017-07-21 04:50:00+03	62800.00
75D03F	2017-08-12 03:55:00+03	77900.00
75D106	2017-07-16 12:08:00+03	36200.00
75D13A	2017-08-10 11:43:00+03	43000.00
75D203	2017-07-22 08:48:00+03	28800.00
75D27F	2017-08-12 07:36:00+03	107900.00
75D28C	2017-07-07 05:48:00+03	41200.00
75D2DC	2017-08-14 11:45:00+03	42700.00
75D301	2017-08-07 12:41:00+03	55800.00
75D374	2017-07-02 02:36:00+03	30200.00
75D391	2017-07-12 13:16:00+03	67600.00
75D3A6	2017-07-10 09:44:00+03	55800.00
75D3E2	2017-07-03 19:26:00+03	46800.00
75D421	2017-08-10 12:53:00+03	56000.00
75D453	2017-07-11 04:21:00+03	119700.00
75D47D	2017-07-16 05:55:00+03	34000.00
75D4B0	2017-07-07 12:27:00+03	14400.00
75D50F	2017-06-24 09:25:00+03	15000.00
75D544	2017-07-21 13:58:00+03	22400.00
75D579	2017-07-09 00:18:00+03	192700.00
75D59B	2017-07-15 06:53:00+03	28800.00
75D5A8	2017-07-13 22:08:00+03	241300.00
75D5E5	2017-07-29 05:57:00+03	26000.00
75D5EF	2017-07-29 11:12:00+03	22000.00
75D5F4	2017-07-07 23:02:00+03	35800.00
75D650	2017-08-12 14:39:00+03	76400.00
75D6A4	2017-07-16 13:16:00+03	17000.00
75D6D4	2017-07-26 16:00:00+03	64900.00
75D764	2017-08-15 01:51:00+03	38300.00
75D7A6	2017-07-21 06:11:00+03	54400.00
75D7B1	2017-07-18 20:20:00+03	43500.00
75D7F2	2017-08-14 06:54:00+03	66600.00
75D804	2017-08-03 08:11:00+03	55800.00
75D831	2017-07-08 07:51:00+03	128600.00
75D83E	2017-08-08 08:14:00+03	23600.00
75D8AB	2017-07-08 20:22:00+03	26000.00
75D8B4	2017-07-19 20:44:00+03	54300.00
75D8D7	2017-08-07 22:23:00+03	146300.00
75D8F0	2017-08-15 04:20:00+03	12000.00
75D9B0	2017-08-01 17:36:00+03	246000.00
75D9D6	2017-08-12 12:40:00+03	270700.00
75DA1F	2017-07-18 04:13:00+03	56600.00
75DA4D	2017-08-13 07:42:00+03	101200.00
75DA51	2017-07-04 06:27:00+03	40600.00
75DA89	2017-07-06 13:20:00+03	57100.00
75DADA	2017-07-30 14:46:00+03	16400.00
75DAE5	2017-08-02 18:33:00+03	92100.00
75DB0F	2017-07-07 12:23:00+03	133800.00
75DB27	2017-07-16 08:55:00+03	88500.00
75DB4F	2017-08-09 12:16:00+03	55800.00
75DB60	2017-07-10 02:46:00+03	196800.00
75DBB8	2017-07-31 09:52:00+03	6700.00
75DBDD	2017-07-13 03:43:00+03	36200.00
75DBF9	2017-07-25 08:02:00+03	149200.00
75DC0D	2017-08-02 21:31:00+03	131900.00
75DC80	2017-08-11 18:45:00+03	104600.00
75DD0E	2017-07-29 00:04:00+03	80700.00
75DD11	2017-07-03 22:59:00+03	40800.00
75DD4A	2017-07-28 16:20:00+03	35600.00
75DD4D	2017-07-08 08:30:00+03	177200.00
75DD5E	2017-08-02 16:37:00+03	81600.00
75DD75	2017-08-05 07:17:00+03	21800.00
75DDE5	2017-07-28 04:31:00+03	46000.00
75DE12	2017-08-12 02:26:00+03	85000.00
75DE13	2017-08-03 03:20:00+03	56600.00
75DE74	2017-07-17 14:10:00+03	106000.00
75DEFD	2017-08-10 15:49:00+03	62600.00
75DF47	2017-07-17 07:25:00+03	20200.00
75DF4F	2017-08-02 22:48:00+03	57400.00
75DF82	2017-08-01 11:49:00+03	93900.00
75DFE5	2017-07-31 00:31:00+03	46400.00
75E008	2017-08-07 03:32:00+03	58000.00
75E04F	2017-08-05 03:36:00+03	79900.00
75E05C	2017-07-30 08:15:00+03	23200.00
75E070	2017-08-08 14:35:00+03	40000.00
75E077	2017-07-29 01:51:00+03	40000.00
75E09B	2017-08-06 02:42:00+03	14400.00
75E0AF	2017-08-15 08:00:00+03	13400.00
75E0EB	2017-07-27 23:03:00+03	56000.00
75E118	2017-08-03 17:33:00+03	30000.00
75E15B	2017-08-08 23:01:00+03	75300.00
75E15E	2017-08-05 10:22:00+03	28000.00
75E166	2017-07-31 01:01:00+03	26800.00
75E16E	2017-08-15 09:04:00+03	22400.00
75E222	2017-07-18 05:39:00+03	20400.00
75E24B	2017-07-27 16:44:00+03	26000.00
75E24C	2017-07-04 13:30:00+03	136500.00
75E29B	2017-07-25 15:10:00+03	170700.00
75E2A7	2017-07-12 07:30:00+03	68800.00
75E33F	2017-07-16 01:40:00+03	116900.00
75E3D4	2017-08-06 00:09:00+03	67600.00
75E425	2017-07-26 03:46:00+03	28700.00
75E429	2017-07-21 18:54:00+03	6800.00
75E473	2017-07-27 20:05:00+03	62700.00
75E475	2017-07-25 13:34:00+03	69500.00
75E484	2017-07-07 08:54:00+03	483400.00
75E4A2	2017-08-11 07:47:00+03	536400.00
75E515	2017-07-03 13:19:00+03	57400.00
75E51F	2017-08-03 16:51:00+03	125400.00
75E543	2017-08-12 03:13:00+03	8800.00
75E54A	2017-07-09 04:36:00+03	56600.00
75E5B2	2017-08-15 11:31:00+03	28800.00
75E5D1	2017-08-06 21:13:00+03	56900.00
75E5F0	2017-07-21 16:32:00+03	68800.00
75E61D	2017-08-10 17:16:00+03	89700.00
75E64A	2017-07-10 10:51:00+03	135900.00
75E666	2017-08-06 06:31:00+03	239000.00
75E6E6	2017-08-14 22:16:00+03	106900.00
75E72C	2017-07-13 05:46:00+03	78800.00
75E785	2017-07-29 08:32:00+03	40800.00
75E799	2017-07-23 21:27:00+03	23600.00
75E79F	2017-08-04 15:49:00+03	73500.00
75E827	2017-08-05 18:00:00+03	24400.00
75E829	2017-08-10 00:51:00+03	34100.00
75E84A	2017-08-02 04:29:00+03	203000.00
75E859	2017-08-04 18:01:00+03	31200.00
75E86D	2017-07-19 15:33:00+03	119000.00
75E877	2017-07-26 22:36:00+03	89700.00
75E89C	2017-07-01 22:44:00+03	67600.00
75E89E	2017-08-03 22:54:00+03	24500.00
75E918	2017-08-07 11:04:00+03	85500.00
75E948	2017-08-07 14:07:00+03	43200.00
75E997	2017-07-14 04:57:00+03	53800.00
75E9F0	2017-07-06 08:05:00+03	67600.00
75E9F3	2017-06-30 21:29:00+03	11600.00
75EABC	2017-07-23 20:48:00+03	6000.00
75EAC9	2017-07-10 00:53:00+03	43900.00
75EAD7	2017-08-14 19:31:00+03	62700.00
75EAE7	2017-08-10 18:48:00+03	15900.00
75EB98	2017-07-29 00:48:00+03	75300.00
75EBBC	2017-07-22 05:44:00+03	46400.00
75EC05	2017-07-13 06:00:00+03	26000.00
75EC83	2017-07-20 03:39:00+03	30400.00
75ECDC	2017-07-08 04:19:00+03	55800.00
75ED02	2017-08-06 02:59:00+03	56600.00
75ED8D	2017-07-03 12:49:00+03	162700.00
75EDBA	2017-07-01 14:03:00+03	19600.00
75EDD4	2017-07-17 23:23:00+03	23400.00
75EE0B	2017-07-05 10:59:00+03	75300.00
75EE18	2017-08-14 09:54:00+03	176400.00
75EE63	2017-07-08 02:22:00+03	14000.00
75EEA9	2017-07-25 00:28:00+03	326400.00
75EECB	2017-08-07 07:14:00+03	68800.00
75EF38	2017-07-21 12:09:00+03	27900.00
75EF73	2017-07-06 20:23:00+03	189200.00
75EF9D	2017-08-14 02:01:00+03	6300.00
75F040	2017-07-27 05:34:00+03	18600.00
75F04A	2017-07-25 22:02:00+03	38400.00
75F08F	2017-08-06 05:59:00+03	10700.00
75F0A6	2017-08-11 06:52:00+03	91600.00
75F111	2017-08-10 17:02:00+03	64200.00
75F116	2017-08-14 09:51:00+03	24000.00
75F156	2017-07-21 17:12:00+03	39800.00
75F15C	2017-07-05 14:46:00+03	15800.00
75F1B1	2017-07-30 10:00:00+03	56000.00
75F28B	2017-08-04 10:47:00+03	61800.00
75F2C6	2017-07-09 08:33:00+03	91800.00
75F36A	2017-07-26 00:39:00+03	103800.00
75F426	2017-07-02 08:04:00+03	22000.00
75F42C	2017-07-28 21:40:00+03	148200.00
75F44B	2017-08-15 12:21:00+03	132800.00
75F47E	2017-07-30 13:00:00+03	15800.00
75F4A5	2017-07-06 02:25:00+03	43600.00
75F4D2	2017-08-13 16:31:00+03	147000.00
75F4E6	2017-08-13 21:46:00+03	36200.00
75F4F2	2017-07-18 14:44:00+03	35600.00
75F54C	2017-08-13 09:29:00+03	43200.00
75F58A	2017-08-10 15:25:00+03	35200.00
75F5A0	2017-07-27 09:15:00+03	136200.00
75F5CC	2017-08-03 04:53:00+03	62600.00
75F601	2017-08-13 14:45:00+03	38300.00
75F6A7	2017-07-23 08:45:00+03	32700.00
75F707	2017-07-17 14:50:00+03	70700.00
75F726	2017-07-22 14:13:00+03	38400.00
75F734	2017-08-02 20:41:00+03	210600.00
75F78A	2017-08-07 09:11:00+03	136000.00
75F7AD	2017-08-01 05:58:00+03	216400.00
75F7AE	2017-08-11 06:37:00+03	37200.00
75F7DA	2017-07-18 21:08:00+03	47100.00
75F7FA	2017-06-27 06:30:00+03	47500.00
75F8E7	2017-08-08 07:38:00+03	81400.00
75F912	2017-07-15 10:43:00+03	47100.00
75F924	2017-08-14 03:48:00+03	50200.00
75F957	2017-07-29 09:49:00+03	159600.00
75F96A	2017-07-27 20:01:00+03	118600.00
75F971	2017-07-04 10:14:00+03	59600.00
75F991	2017-08-01 14:28:00+03	12600.00
75F999	2017-07-19 17:03:00+03	33100.00
75FA3A	2017-07-02 18:29:00+03	15000.00
75FA4A	2017-08-03 12:51:00+03	80000.00
75FA5C	2017-08-11 23:39:00+03	16400.00
75FA79	2017-07-25 11:53:00+03	26400.00
75FAE4	2017-08-14 17:36:00+03	24400.00
75FB33	2017-07-25 16:11:00+03	406700.00
75FB8E	2017-07-19 21:50:00+03	176400.00
75FBCD	2017-07-07 11:41:00+03	194300.00
75FBEC	2017-07-14 13:17:00+03	148700.00
75FBFF	2017-07-20 20:33:00+03	46400.00
75FC18	2017-06-27 16:36:00+03	230200.00
75FC49	2017-08-04 13:26:00+03	55800.00
75FC53	2017-07-27 07:49:00+03	70400.00
75FC7A	2017-07-21 17:25:00+03	270700.00
75FC87	2017-08-06 05:50:00+03	51800.00
75FCDF	2017-07-31 23:36:00+03	42000.00
75FCF7	2017-07-27 20:30:00+03	26400.00
75FCFD	2017-07-03 19:03:00+03	68000.00
75FDB3	2017-08-01 13:55:00+03	136800.00
75FDE5	2017-07-17 04:24:00+03	8400.00
75FE00	2017-08-10 16:29:00+03	23200.00
75FE20	2017-07-01 04:06:00+03	189200.00
75FE60	2017-08-05 06:03:00+03	119600.00
75FE71	2017-08-05 10:36:00+03	111600.00
75FE95	2017-08-10 00:51:00+03	26000.00
75FE96	2017-07-27 10:36:00+03	242000.00
75FED2	2017-07-10 05:52:00+03	51200.00
75FF40	2017-08-05 16:05:00+03	13200.00
75FFAB	2017-08-06 22:47:00+03	52000.00
75FFBD	2017-07-29 19:53:00+03	313800.00
75FFD3	2017-07-06 10:04:00+03	94100.00
760005	2017-08-05 00:54:00+03	135600.00
760009	2017-07-12 17:46:00+03	13000.00
760054	2017-07-07 08:38:00+03	9800.00
7600A6	2017-07-02 13:24:00+03	87000.00
7600CE	2017-07-19 01:43:00+03	53300.00
760173	2017-07-31 04:13:00+03	124200.00
760261	2017-07-23 04:14:00+03	189200.00
76030A	2017-07-09 04:23:00+03	62600.00
760318	2017-08-07 22:13:00+03	9800.00
7603BF	2017-07-12 05:17:00+03	45100.00
7603DD	2017-08-14 05:14:00+03	46500.00
760409	2017-08-06 23:15:00+03	49200.00
760448	2017-07-22 20:41:00+03	242700.00
760507	2017-08-05 08:55:00+03	42700.00
76053F	2017-07-21 12:08:00+03	83000.00
7605F3	2017-07-30 08:18:00+03	6800.00
7606DA	2017-08-12 20:14:00+03	147700.00
76075E	2017-07-11 12:33:00+03	147700.00
760799	2017-07-30 23:18:00+03	56000.00
7607AA	2017-06-29 12:42:00+03	58800.00
760826	2017-07-27 22:20:00+03	61700.00
7608BD	2017-07-18 22:20:00+03	50800.00
76090E	2017-07-03 11:41:00+03	145300.00
760945	2017-07-20 11:13:00+03	99300.00
760A4B	2017-07-06 01:23:00+03	74400.00
760AA4	2017-07-19 07:48:00+03	181600.00
760B0F	2017-07-31 04:37:00+03	28800.00
760B29	2017-07-11 04:41:00+03	132800.00
760B2A	2017-08-03 10:38:00+03	56000.00
760B3C	2017-07-25 10:24:00+03	54700.00
760BEA	2017-08-03 14:37:00+03	24400.00
760BEC	2017-07-21 02:54:00+03	24400.00
760C1E	2017-08-13 16:28:00+03	57500.00
760C5D	2017-08-05 05:44:00+03	83000.00
760CAF	2017-08-14 17:04:00+03	37100.00
760CEC	2017-07-14 09:21:00+03	28800.00
760D07	2017-07-04 18:51:00+03	20200.00
760D44	2017-07-24 06:05:00+03	38400.00
760D4D	2017-07-02 02:09:00+03	75300.00
760D4F	2017-07-02 13:54:00+03	31600.00
760DCF	2017-08-10 01:53:00+03	6700.00
760E02	2017-07-05 20:27:00+03	28000.00
760EF9	2017-08-06 11:12:00+03	18000.00
760F24	2017-07-13 17:25:00+03	29400.00
760F34	2017-07-11 14:01:00+03	105100.00
760FB9	2017-08-05 23:38:00+03	14800.00
76102C	2017-08-10 16:40:00+03	28800.00
761055	2017-08-06 18:03:00+03	88000.00
7610D2	2017-07-03 00:15:00+03	116300.00
7610FA	2017-07-11 16:50:00+03	73600.00
761175	2017-08-09 18:08:00+03	65900.00
7611A7	2017-08-03 17:55:00+03	14800.00
7611E2	2017-08-08 01:29:00+03	43600.00
7611E8	2017-07-13 08:57:00+03	70200.00
76126B	2017-07-11 00:53:00+03	26000.00
761288	2017-08-11 00:37:00+03	266400.00
761307	2017-07-20 11:03:00+03	20000.00
76131E	2017-08-13 19:29:00+03	61500.00
761335	2017-07-05 08:07:00+03	16400.00
76137C	2017-08-08 11:28:00+03	66700.00
761437	2017-07-30 11:44:00+03	26700.00
761496	2017-08-14 14:59:00+03	105100.00
7614AE	2017-08-14 23:23:00+03	26600.00
7614BD	2017-07-19 13:32:00+03	56600.00
76155B	2017-07-21 19:53:00+03	55800.00
761669	2017-07-31 18:31:00+03	38800.00
7616C2	2017-06-25 14:15:00+03	26000.00
7616E1	2017-08-08 10:28:00+03	95200.00
761702	2017-07-08 04:31:00+03	119700.00
761727	2017-08-13 02:24:00+03	23200.00
76178F	2017-08-15 03:02:00+03	51200.00
7617C4	2017-08-05 15:04:00+03	136500.00
7617DA	2017-08-02 18:32:00+03	246000.00
7617E8	2017-07-09 18:21:00+03	141500.00
7617ED	2017-07-28 21:12:00+03	81600.00
761821	2017-07-17 14:28:00+03	123000.00
76184F	2017-06-27 06:50:00+03	6700.00
76187C	2017-07-07 12:28:00+03	160100.00
76187F	2017-06-30 01:56:00+03	85000.00
76188A	2017-08-02 04:18:00+03	46800.00
7618BD	2017-08-14 07:33:00+03	36800.00
7618C0	2017-07-12 17:38:00+03	46000.00
7618F9	2017-08-10 00:41:00+03	57400.00
761901	2017-08-09 03:56:00+03	18200.00
76191A	2017-07-11 01:41:00+03	52300.00
76195D	2017-08-15 02:49:00+03	150600.00
761990	2017-07-11 14:14:00+03	40000.00
7619BE	2017-07-04 10:16:00+03	62000.00
7619BF	2017-07-21 05:20:00+03	253200.00
7619D3	2017-07-22 11:42:00+03	25600.00
7619FF	2017-07-21 19:37:00+03	14000.00
761A71	2017-07-14 00:54:00+03	26800.00
761A7F	2017-07-21 11:23:00+03	66200.00
761AB3	2017-07-08 08:38:00+03	24400.00
761B35	2017-07-04 06:13:00+03	16400.00
761B92	2017-07-11 08:10:00+03	224700.00
761BAE	2017-07-23 23:44:00+03	40400.00
761BD7	2017-07-25 18:00:00+03	25400.00
761BD9	2017-08-15 08:50:00+03	14800.00
761C1A	2017-07-13 13:32:00+03	56000.00
761C42	2017-07-24 09:25:00+03	47400.00
761C43	2017-07-25 18:14:00+03	69500.00
761C87	2017-07-13 12:19:00+03	84500.00
761CC4	2017-07-14 22:37:00+03	118600.00
761DA3	2017-07-28 17:12:00+03	24200.00
761DC7	2017-07-07 17:15:00+03	78400.00
761DCE	2017-08-10 17:09:00+03	139500.00
761E10	2017-07-24 10:34:00+03	46000.00
761E24	2017-08-04 16:01:00+03	138900.00
761E34	2017-08-11 15:54:00+03	133900.00
761E4D	2017-07-13 00:43:00+03	19600.00
761E81	2017-07-19 19:29:00+03	21800.00
761EB5	2017-07-02 17:13:00+03	31400.00
761ED1	2017-08-01 17:12:00+03	22400.00
761ED8	2017-07-10 11:19:00+03	196800.00
76207B	2017-07-15 06:07:00+03	102300.00
76207F	2017-08-05 05:49:00+03	100800.00
76208D	2017-08-07 18:32:00+03	271200.00
7620B9	2017-07-27 15:38:00+03	33600.00
7620C1	2017-07-01 12:59:00+03	69600.00
7620F2	2017-07-10 17:08:00+03	65200.00
762125	2017-07-12 07:34:00+03	89700.00
762159	2017-06-30 11:02:00+03	59800.00
7621B1	2017-07-16 17:37:00+03	289300.00
762200	2017-07-29 16:52:00+03	38800.00
762234	2017-07-06 13:51:00+03	103600.00
7622FA	2017-07-20 03:50:00+03	58600.00
76232F	2017-08-11 01:22:00+03	270800.00
762332	2017-07-30 22:39:00+03	111600.00
762372	2017-07-16 12:19:00+03	56000.00
762378	2017-07-07 02:58:00+03	134400.00
762403	2017-08-02 14:17:00+03	16400.00
762411	2017-07-24 15:37:00+03	105400.00
762487	2017-07-22 20:16:00+03	62800.00
7624D6	2017-08-05 02:37:00+03	56000.00
76259D	2017-08-14 02:03:00+03	96300.00
7625E6	2017-07-29 02:08:00+03	145300.00
7625EA	2017-07-26 23:30:00+03	26000.00
762648	2017-07-07 08:05:00+03	6000.00
76264B	2017-08-12 05:44:00+03	243700.00
7626D6	2017-08-14 02:17:00+03	35600.00
7626DC	2017-07-13 16:17:00+03	28000.00
76278D	2017-07-08 14:54:00+03	258000.00
7627FB	2017-07-31 04:16:00+03	135200.00
762849	2017-07-10 04:01:00+03	18800.00
762865	2017-08-01 13:28:00+03	25600.00
76287C	2017-07-12 18:29:00+03	22000.00
762894	2017-07-29 19:22:00+03	23600.00
7628D3	2017-07-27 15:58:00+03	23200.00
7628DC	2017-08-03 21:27:00+03	74900.00
7628F7	2017-08-02 15:45:00+03	25600.00
762912	2017-07-26 12:36:00+03	75300.00
76291D	2017-07-28 12:05:00+03	21800.00
762929	2017-08-05 01:59:00+03	48800.00
762936	2017-08-13 22:17:00+03	246000.00
762969	2017-07-31 17:52:00+03	54000.00
7629C0	2017-08-06 00:28:00+03	63200.00
7629E0	2017-07-13 23:30:00+03	38400.00
762A00	2017-08-15 03:50:00+03	124400.00
762A1E	2017-08-06 04:37:00+03	84100.00
762A78	2017-08-14 07:46:00+03	166100.00
762AA5	2017-07-25 21:35:00+03	40600.00
762B10	2017-07-22 21:05:00+03	86400.00
762B2F	2017-07-08 02:00:00+03	43900.00
762C2E	2017-08-11 08:44:00+03	85800.00
762C3C	2017-07-26 14:56:00+03	123000.00
762CA0	2017-07-22 10:24:00+03	132800.00
762D05	2017-07-10 15:18:00+03	68800.00
762D63	2017-07-17 12:32:00+03	46400.00
762DA8	2017-07-21 19:25:00+03	42700.00
762DBE	2017-07-02 08:11:00+03	15000.00
762DD6	2017-07-26 13:37:00+03	93900.00
762DD7	2017-08-13 11:16:00+03	13400.00
762DD8	2017-07-30 12:27:00+03	46700.00
762E3A	2017-07-07 05:05:00+03	29600.00
762E59	2017-07-08 16:43:00+03	14400.00
762E6E	2017-08-15 11:11:00+03	34000.00
762F0F	2017-07-08 16:38:00+03	38400.00
762F50	2017-08-13 09:01:00+03	36000.00
762FB5	2017-07-05 03:23:00+03	136200.00
762FC0	2017-08-02 00:10:00+03	30200.00
762FEE	2017-07-25 20:59:00+03	23200.00
76301F	2017-07-26 18:37:00+03	75300.00
76302F	2017-07-08 21:46:00+03	67600.00
763047	2017-07-21 03:37:00+03	139100.00
7630AA	2017-07-08 01:16:00+03	92800.00
7630C2	2017-07-21 09:36:00+03	46400.00
763135	2017-08-13 20:43:00+03	20600.00
76314C	2017-08-03 13:24:00+03	89600.00
763158	2017-07-23 15:44:00+03	35300.00
76317D	2017-07-28 10:57:00+03	133200.00
7631D8	2017-07-14 14:35:00+03	73600.00
7631E6	2017-07-20 19:06:00+03	53400.00
763267	2017-06-29 11:23:00+03	27200.00
7632CD	2017-08-11 04:09:00+03	426700.00
7632DE	2017-07-14 21:27:00+03	125400.00
7632FA	2017-08-08 07:22:00+03	23500.00
76333E	2017-08-14 02:58:00+03	15000.00
763347	2017-07-29 20:19:00+03	192200.00
7633C6	2017-08-15 11:54:00+03	799200.00
7633D5	2017-07-15 01:28:00+03	43000.00
7633DB	2017-07-03 14:12:00+03	31400.00
7633FE	2017-07-08 10:26:00+03	124900.00
763421	2017-07-17 10:24:00+03	50800.00
76342F	2017-07-26 20:36:00+03	29300.00
76345E	2017-07-28 21:56:00+03	38400.00
76347F	2017-07-10 10:19:00+03	57800.00
763523	2017-08-10 19:05:00+03	28800.00
763565	2017-08-13 01:59:00+03	25600.00
7635AA	2017-07-28 23:56:00+03	99200.00
7635AE	2017-06-30 23:20:00+03	86300.00
7635EF	2017-06-30 16:54:00+03	124200.00
763604	2017-07-23 04:49:00+03	115700.00
76367C	2017-07-02 01:54:00+03	101000.00
7636BA	2017-08-05 21:26:00+03	93900.00
7636C5	2017-07-07 12:31:00+03	27200.00
7636F0	2017-07-04 17:36:00+03	56000.00
76377D	2017-07-15 02:19:00+03	16800.00
763799	2017-08-04 20:17:00+03	93900.00
7637D4	2017-08-02 01:47:00+03	73900.00
7637E7	2017-08-03 10:22:00+03	75600.00
7637EE	2017-07-18 11:53:00+03	58000.00
763803	2017-07-31 22:06:00+03	28000.00
763818	2017-08-01 23:31:00+03	59300.00
76387B	2017-07-16 11:36:00+03	57600.00
763887	2017-07-11 23:20:00+03	31600.00
763891	2017-07-08 14:13:00+03	46800.00
7638AC	2017-07-23 20:09:00+03	81300.00
7638C2	2017-08-04 00:03:00+03	6700.00
7638D2	2017-08-07 00:05:00+03	69500.00
7638D7	2017-07-04 05:48:00+03	40600.00
7638EE	2017-07-06 13:40:00+03	49500.00
763945	2017-07-16 20:48:00+03	51000.00
763994	2017-07-20 13:51:00+03	31100.00
763A57	2017-06-28 18:58:00+03	43100.00
763A73	2017-07-04 16:41:00+03	17600.00
763A8A	2017-07-08 09:10:00+03	67700.00
763A91	2017-07-15 08:13:00+03	73500.00
763A9D	2017-08-09 01:58:00+03	8000.00
763AC4	2017-07-10 20:48:00+03	108500.00
763B32	2017-07-06 10:24:00+03	65900.00
763B94	2017-08-11 11:37:00+03	18900.00
763BA9	2017-08-08 02:23:00+03	735600.00
763BAC	2017-08-01 10:01:00+03	66300.00
763BE6	2017-07-07 04:55:00+03	82900.00
763C4B	2017-08-14 01:25:00+03	25100.00
763C89	2017-07-25 00:23:00+03	63000.00
763D14	2017-08-14 02:26:00+03	40800.00
763D67	2017-07-11 19:52:00+03	19600.00
763E01	2017-07-25 04:05:00+03	47000.00
763EAF	2017-07-05 10:54:00+03	12000.00
763ED2	2017-08-10 00:22:00+03	66600.00
763EFE	2017-08-01 00:40:00+03	23600.00
763F3E	2017-08-08 23:53:00+03	65000.00
763F49	2017-08-09 12:49:00+03	112000.00
763F77	2017-07-24 06:24:00+03	443000.00
763FB1	2017-06-29 00:41:00+03	89700.00
763FD5	2017-07-29 16:48:00+03	55800.00
76401A	2017-07-25 07:15:00+03	56000.00
764052	2017-07-02 16:47:00+03	190100.00
7640AD	2017-07-13 13:18:00+03	12000.00
76411D	2017-08-08 20:02:00+03	71900.00
7641DF	2017-08-06 10:41:00+03	50800.00
764260	2017-07-02 13:02:00+03	12600.00
764270	2017-07-20 10:08:00+03	27200.00
7642CD	2017-07-15 19:54:00+03	135000.00
764338	2017-07-27 18:47:00+03	266200.00
7643E2	2017-07-03 02:58:00+03	56000.00
764451	2017-08-05 00:45:00+03	119500.00
764456	2017-07-27 21:01:00+03	32900.00
764528	2017-07-30 21:01:00+03	266400.00
76453F	2017-07-09 16:52:00+03	25000.00
764580	2017-07-25 19:47:00+03	26800.00
7645CE	2017-08-06 00:06:00+03	52000.00
764699	2017-07-10 23:35:00+03	43200.00
7646E6	2017-08-01 12:23:00+03	18000.00
7646FA	2017-07-30 08:31:00+03	73500.00
764764	2017-08-08 19:37:00+03	69400.00
764772	2017-07-11 08:38:00+03	21800.00
764777	2017-07-29 22:53:00+03	13400.00
76479E	2017-08-14 17:05:00+03	23600.00
764807	2017-07-09 08:37:00+03	69600.00
764864	2017-07-09 00:54:00+03	44800.00
764879	2017-07-10 20:25:00+03	257600.00
7648F1	2017-07-27 13:21:00+03	43500.00
76490A	2017-08-09 06:18:00+03	199300.00
76490D	2017-07-16 15:42:00+03	127900.00
764916	2017-07-20 00:02:00+03	44600.00
764961	2017-07-04 11:24:00+03	23200.00
764A6B	2017-08-06 14:35:00+03	52800.00
764A89	2017-07-14 14:07:00+03	27300.00
764A95	2017-08-07 06:55:00+03	66700.00
764ACD	2017-08-13 03:09:00+03	44800.00
764AFA	2017-07-29 07:54:00+03	14400.00
764B0B	2017-07-02 11:53:00+03	19800.00
764B4A	2017-08-01 15:27:00+03	56800.00
764B62	2017-07-24 08:25:00+03	88100.00
764B8F	2017-07-05 06:44:00+03	133600.00
764BAF	2017-08-06 06:49:00+03	35200.00
764BBF	2017-08-11 03:23:00+03	64100.00
764BE3	2017-08-15 01:17:00+03	73400.00
764BE5	2017-07-20 20:45:00+03	92900.00
764C1E	2017-08-02 02:59:00+03	87000.00
764C3C	2017-08-07 12:25:00+03	37200.00
764C42	2017-07-16 20:58:00+03	55800.00
764C62	2017-07-02 03:12:00+03	47200.00
764CCF	2017-08-15 03:48:00+03	23200.00
764CF4	2017-07-27 18:31:00+03	81600.00
764D1C	2017-07-30 06:00:00+03	90800.00
764D1F	2017-07-28 14:16:00+03	54000.00
764D25	2017-07-04 07:20:00+03	124200.00
764D41	2017-07-23 06:51:00+03	32200.00
764D7E	2017-07-14 17:07:00+03	94800.00
764D90	2017-07-16 18:32:00+03	144700.00
764D96	2017-07-31 16:34:00+03	81600.00
764DE1	2017-08-04 05:40:00+03	13400.00
764DFB	2017-08-10 20:45:00+03	246000.00
764E0B	2017-07-01 17:23:00+03	75600.00
764E2D	2017-07-18 12:49:00+03	13200.00
764EBC	2017-08-14 05:45:00+03	93900.00
764EBF	2017-07-20 04:50:00+03	48000.00
764ECE	2017-08-10 13:11:00+03	129700.00
764EFD	2017-08-11 12:45:00+03	24400.00
764FA6	2017-07-12 18:16:00+03	28000.00
764FD3	2017-08-02 00:02:00+03	58900.00
765027	2017-07-06 22:35:00+03	62600.00
76502C	2017-08-10 21:05:00+03	47100.00
765066	2017-07-22 19:39:00+03	23200.00
7650B2	2017-07-03 00:08:00+03	56000.00
765119	2017-07-04 07:14:00+03	46400.00
765153	2017-08-11 15:48:00+03	23200.00
76519E	2017-08-15 05:16:00+03	49100.00
7651CC	2017-07-10 22:18:00+03	8000.00
765242	2017-08-13 04:21:00+03	69000.00
765259	2017-08-09 22:56:00+03	81600.00
7652BF	2017-08-14 17:06:00+03	33300.00
7652C7	2017-07-07 12:01:00+03	167900.00
765329	2017-07-07 21:55:00+03	23100.00
76532E	2017-08-03 01:26:00+03	84100.00
76533A	2017-08-12 16:38:00+03	33300.00
765398	2017-07-20 17:02:00+03	86600.00
7653B3	2017-07-15 14:30:00+03	46400.00
765408	2017-08-14 01:10:00+03	43900.00
7654B9	2017-07-05 11:30:00+03	368700.00
76557B	2017-07-27 03:06:00+03	406800.00
76557E	2017-07-02 17:59:00+03	78300.00
7655E1	2017-08-15 07:48:00+03	112000.00
765609	2017-08-10 06:57:00+03	71000.00
76561B	2017-07-25 07:12:00+03	11700.00
765633	2017-08-15 05:33:00+03	167400.00
76563D	2017-07-17 19:43:00+03	91100.00
76567A	2017-07-31 12:52:00+03	81700.00
76571E	2017-07-10 18:37:00+03	241600.00
7657E4	2017-07-06 22:38:00+03	31400.00
765801	2017-07-24 03:44:00+03	56600.00
76580C	2017-08-03 15:24:00+03	24400.00
765820	2017-07-06 02:59:00+03	64800.00
7658B1	2017-08-07 12:20:00+03	170700.00
7658BE	2017-08-03 20:45:00+03	25000.00
7658FC	2017-08-13 13:19:00+03	120700.00
765944	2017-07-09 02:00:00+03	399600.00
7659F2	2017-07-19 01:02:00+03	136200.00
765A64	2017-07-10 06:42:00+03	28000.00
765A76	2017-08-11 11:21:00+03	64900.00
765A87	2017-07-11 03:37:00+03	72500.00
765ACB	2017-08-01 11:34:00+03	207200.00
765ADB	2017-08-08 00:18:00+03	55800.00
765B14	2017-07-05 23:52:00+03	41600.00
765B86	2017-08-10 12:07:00+03	38400.00
765BD2	2017-08-09 17:31:00+03	53600.00
765BD8	2017-07-13 01:48:00+03	81200.00
765C0E	2017-07-27 10:43:00+03	271100.00
765C4D	2017-07-29 07:03:00+03	25400.00
765C5F	2017-07-24 02:59:00+03	6700.00
765C6E	2017-07-25 19:24:00+03	28000.00
765D50	2017-07-22 00:27:00+03	28800.00
765D5F	2017-07-23 09:03:00+03	79000.00
765D96	2017-08-01 18:42:00+03	128800.00
765DD8	2017-07-29 04:31:00+03	22600.00
765E02	2017-07-13 00:52:00+03	81900.00
765E29	2017-07-28 23:52:00+03	36200.00
765E9D	2017-07-10 15:24:00+03	254900.00
765EE0	2017-07-07 01:30:00+03	58200.00
765EEA	2017-07-01 13:27:00+03	19600.00
765F18	2017-07-14 21:15:00+03	39500.00
765F1B	2017-08-12 05:52:00+03	60700.00
766018	2017-08-06 05:40:00+03	23600.00
76606A	2017-07-10 12:08:00+03	79000.00
76609B	2017-08-14 06:00:00+03	45100.00
7660E7	2017-08-12 00:09:00+03	35200.00
766118	2017-06-30 23:31:00+03	23200.00
76613F	2017-07-20 17:51:00+03	13400.00
76617D	2017-07-24 22:27:00+03	44000.00
7661B2	2017-07-26 01:25:00+03	145700.00
7661F1	2017-06-28 08:40:00+03	32800.00
7661FA	2017-07-09 15:10:00+03	58800.00
766217	2017-08-13 20:25:00+03	70700.00
76623C	2017-07-10 08:45:00+03	59100.00
7662AF	2017-07-25 16:05:00+03	136200.00
7662B8	2017-08-10 20:11:00+03	56600.00
7662DE	2017-07-05 21:26:00+03	50400.00
7662F7	2017-07-07 01:11:00+03	85000.00
766314	2017-07-28 08:45:00+03	80000.00
766317	2017-07-02 18:02:00+03	70500.00
766366	2017-07-12 01:27:00+03	27400.00
766374	2017-07-08 02:43:00+03	129700.00
7663C4	2017-07-22 21:31:00+03	27800.00
766423	2017-07-09 06:51:00+03	98600.00
76643D	2017-07-29 04:44:00+03	132800.00
766448	2017-08-08 08:38:00+03	143200.00
7664B8	2017-07-03 00:10:00+03	70100.00
7664D3	2017-07-14 18:58:00+03	14800.00
7664FF	2017-07-23 18:05:00+03	56000.00
76652E	2017-07-13 16:48:00+03	17600.00
76655D	2017-08-07 04:27:00+03	36700.00
766573	2017-07-15 03:53:00+03	88800.00
76657B	2017-08-02 03:38:00+03	90700.00
766608	2017-07-11 18:33:00+03	24600.00
766609	2017-07-14 11:33:00+03	7200.00
766634	2017-07-23 11:45:00+03	30200.00
766643	2017-07-28 21:20:00+03	147600.00
766664	2017-07-21 22:42:00+03	70200.00
766670	2017-07-25 07:31:00+03	95600.00
7666E1	2017-07-14 00:15:00+03	67200.00
76672D	2017-08-08 22:19:00+03	23900.00
76676D	2017-07-23 00:18:00+03	13400.00
7667BA	2017-07-31 16:19:00+03	58300.00
76680E	2017-08-10 15:44:00+03	135000.00
76680F	2017-07-15 23:40:00+03	48100.00
76681E	2017-08-05 10:48:00+03	81300.00
76682B	2017-07-14 10:04:00+03	97700.00
76682C	2017-08-15 03:39:00+03	125200.00
766861	2017-07-14 10:06:00+03	6700.00
76690D	2017-08-11 19:33:00+03	57700.00
76691A	2017-08-05 14:30:00+03	77500.00
76697E	2017-07-07 23:00:00+03	71900.00
76698F	2017-08-05 13:04:00+03	98300.00
76699A	2017-08-14 04:29:00+03	67100.00
7669AE	2017-07-24 14:32:00+03	193200.00
7669C8	2017-07-16 19:05:00+03	32200.00
7669F0	2017-07-14 01:50:00+03	265700.00
766A2A	2017-08-04 19:46:00+03	27800.00
766ABE	2017-08-02 10:23:00+03	40200.00
766B3A	2017-07-13 17:30:00+03	187900.00
766B4A	2017-07-02 23:16:00+03	27900.00
766B6F	2017-07-19 13:02:00+03	73300.00
766B7F	2017-07-07 04:03:00+03	28800.00
766BA5	2017-06-26 21:16:00+03	99200.00
766C31	2017-07-19 11:28:00+03	28800.00
766C7A	2017-07-16 17:38:00+03	11800.00
766CE1	2017-08-13 12:18:00+03	34100.00
766D2A	2017-06-28 07:02:00+03	44200.00
766D2D	2017-07-17 04:01:00+03	57800.00
766D54	2017-08-10 23:06:00+03	102100.00
766D55	2017-07-26 03:14:00+03	19000.00
766DB2	2017-07-03 00:01:00+03	193700.00
766DCC	2017-07-16 07:32:00+03	23600.00
766DE7	2017-07-08 18:10:00+03	38400.00
766DF5	2017-08-03 06:35:00+03	15000.00
766E4A	2017-07-28 20:51:00+03	50000.00
766E54	2017-07-14 00:14:00+03	63200.00
766E57	2017-08-12 01:58:00+03	67600.00
766E8E	2017-07-05 04:51:00+03	94400.00
766EF2	2017-07-26 02:27:00+03	105600.00
766F1F	2017-07-25 09:04:00+03	108400.00
766FA5	2017-08-09 06:46:00+03	87000.00
766FEC	2017-07-14 16:18:00+03	12400.00
767003	2017-07-08 21:29:00+03	102100.00
767019	2017-07-06 07:37:00+03	12400.00
76701E	2017-08-12 20:37:00+03	118500.00
767052	2017-07-23 01:11:00+03	21800.00
76705A	2017-08-02 00:50:00+03	28800.00
76709B	2017-07-20 00:15:00+03	115700.00
7670AA	2017-08-07 17:34:00+03	47600.00
7670D0	2017-07-08 17:17:00+03	20200.00
767142	2017-08-09 01:45:00+03	109600.00
767193	2017-08-14 14:46:00+03	97700.00
767196	2017-07-02 00:12:00+03	28800.00
7671FB	2017-08-07 17:06:00+03	135200.00
767222	2017-08-11 12:46:00+03	26700.00
767315	2017-07-22 11:07:00+03	67600.00
7673BB	2017-06-27 05:15:00+03	26800.00
7673FF	2017-08-13 08:04:00+03	44800.00
767447	2017-07-29 20:25:00+03	129400.00
767457	2017-08-11 18:24:00+03	25400.00
767534	2017-08-04 05:53:00+03	20600.00
767554	2017-08-01 22:10:00+03	265700.00
767562	2017-07-06 00:24:00+03	72400.00
767586	2017-07-10 21:46:00+03	40800.00
7675BD	2017-07-09 01:41:00+03	44800.00
767608	2017-07-13 20:09:00+03	125200.00
76763D	2017-07-08 18:46:00+03	114300.00
76766C	2017-06-30 05:10:00+03	58600.00
7676C3	2017-08-02 18:33:00+03	26000.00
7677C0	2017-07-24 14:02:00+03	206400.00
7677C8	2017-07-15 21:33:00+03	27000.00
767823	2017-08-06 17:58:00+03	25100.00
76785C	2017-08-12 00:46:00+03	70600.00
76788C	2017-07-16 07:51:00+03	383300.00
76788D	2017-08-02 17:57:00+03	79000.00
76792B	2017-07-20 12:19:00+03	115900.00
767944	2017-07-16 08:21:00+03	109800.00
7679A1	2017-08-14 06:28:00+03	185800.00
767A2D	2017-07-30 21:28:00+03	43000.00
767A6F	2017-08-04 16:17:00+03	41600.00
767A8F	2017-08-11 14:58:00+03	44800.00
767A94	2017-08-03 16:30:00+03	8200.00
767AA4	2017-07-27 13:03:00+03	46000.00
767ABF	2017-08-15 13:31:00+03	270000.00
767AC3	2017-07-10 05:43:00+03	49200.00
767AF9	2017-07-20 09:11:00+03	90700.00
767B1C	2017-07-31 02:30:00+03	60400.00
767B26	2017-07-16 18:02:00+03	88600.00
767B30	2017-07-30 08:11:00+03	46000.00
767B45	2017-07-05 12:22:00+03	273600.00
767B56	2017-08-02 10:52:00+03	28700.00
767B89	2017-07-12 21:44:00+03	36000.00
767B94	2017-08-15 17:08:00+03	43200.00
767C55	2017-07-28 23:16:00+03	11100.00
767C5F	2017-07-17 05:05:00+03	410200.00
767C62	2017-08-10 14:15:00+03	193700.00
767D5A	2017-07-18 16:01:00+03	39800.00
767E52	2017-07-25 18:29:00+03	40200.00
767EE2	2017-08-04 12:46:00+03	12600.00
767F41	2017-08-03 03:33:00+03	45100.00
767F53	2017-08-13 20:42:00+03	100000.00
767F69	2017-07-24 08:08:00+03	31800.00
767F8D	2017-08-11 12:05:00+03	52300.00
767FA5	2017-07-23 11:57:00+03	47400.00
76801D	2017-08-05 01:08:00+03	107000.00
76803E	2017-08-07 16:55:00+03	95600.00
768040	2017-08-09 08:40:00+03	14400.00
76814E	2017-07-05 14:11:00+03	57600.00
76815D	2017-07-05 04:31:00+03	139400.00
768189	2017-07-23 21:10:00+03	32800.00
768225	2017-07-24 21:39:00+03	50200.00
768322	2017-08-15 16:01:00+03	64000.00
768326	2017-06-28 13:43:00+03	67200.00
768337	2017-08-10 09:16:00+03	31000.00
7683D6	2017-08-01 23:30:00+03	212800.00
7683F3	2017-07-17 03:51:00+03	117600.00
7683FA	2017-08-02 11:50:00+03	46400.00
768408	2017-07-06 12:16:00+03	14000.00
768413	2017-07-25 07:48:00+03	79000.00
768435	2017-07-09 03:50:00+03	71400.00
76843F	2017-07-20 18:24:00+03	184900.00
76845E	2017-07-14 18:26:00+03	36800.00
76853C	2017-07-04 17:39:00+03	33300.00
768544	2017-08-14 21:57:00+03	38800.00
76855B	2017-07-31 16:09:00+03	14800.00
768572	2017-07-07 17:00:00+03	369000.00
768591	2017-07-15 08:07:00+03	24400.00
76859D	2017-06-28 09:07:00+03	282300.00
7685A8	2017-07-15 12:26:00+03	13600.00
7685CD	2017-08-15 12:21:00+03	67400.00
768617	2017-07-24 22:20:00+03	22000.00
76862A	2017-07-09 18:37:00+03	64600.00
768637	2017-08-06 04:23:00+03	62600.00
7686C5	2017-07-31 02:24:00+03	30800.00
768721	2017-08-07 19:18:00+03	31700.00
76882A	2017-07-02 11:11:00+03	23200.00
76885E	2017-07-16 11:27:00+03	139400.00
76886D	2017-07-01 13:40:00+03	40600.00
7688DC	2017-07-23 12:40:00+03	46500.00
768930	2017-08-07 18:02:00+03	36800.00
7689DC	2017-07-23 13:54:00+03	40800.00
7689F3	2017-07-18 19:14:00+03	46400.00
7689FF	2017-08-05 10:26:00+03	21400.00
768A7C	2017-08-03 06:56:00+03	65900.00
768A9A	2017-07-15 12:51:00+03	139900.00
768AD0	2017-08-09 03:51:00+03	64500.00
768B01	2017-07-27 12:09:00+03	69600.00
768B3B	2017-08-08 00:11:00+03	156600.00
768B7F	2017-07-06 11:46:00+03	37100.00
768C11	2017-07-03 09:47:00+03	21800.00
768C39	2017-07-24 05:23:00+03	25200.00
768CBF	2017-07-07 09:13:00+03	186900.00
768CFD	2017-07-25 21:16:00+03	46500.00
768D6B	2017-07-16 08:42:00+03	58200.00
768DE9	2017-07-25 23:43:00+03	185000.00
768E00	2017-08-12 23:50:00+03	46100.00
768E04	2017-07-18 00:24:00+03	58000.00
768E5B	2017-08-05 03:30:00+03	73500.00
768E75	2017-08-09 00:58:00+03	44500.00
768EC4	2017-07-30 02:49:00+03	6700.00
768FA2	2017-07-19 04:10:00+03	28600.00
768FC3	2017-07-17 20:14:00+03	38200.00
768FD7	2017-07-20 18:07:00+03	58100.00
769001	2017-07-14 17:19:00+03	31600.00
76900A	2017-06-29 13:24:00+03	25800.00
76909A	2017-07-13 05:26:00+03	86500.00
769142	2017-07-06 19:57:00+03	84800.00
769156	2017-08-01 19:43:00+03	64500.00
76919C	2017-08-10 21:26:00+03	6000.00
7691DE	2017-07-19 00:22:00+03	37200.00
76925F	2017-07-28 07:28:00+03	96800.00
769279	2017-07-31 05:09:00+03	75600.00
7692A6	2017-07-11 04:58:00+03	134100.00
769323	2017-07-21 03:57:00+03	56000.00
769346	2017-07-24 20:27:00+03	154500.00
769376	2017-07-12 19:08:00+03	26000.00
76938D	2017-07-10 19:43:00+03	116400.00
7693BE	2017-07-10 09:00:00+03	102500.00
769453	2017-07-30 18:19:00+03	15400.00
7694EF	2017-08-05 08:24:00+03	27700.00
7694F3	2017-07-24 09:38:00+03	192400.00
7695A6	2017-07-28 15:09:00+03	103500.00
7695C5	2017-07-09 13:34:00+03	135400.00
7695EC	2017-08-13 08:33:00+03	27200.00
7695F3	2017-07-02 14:00:00+03	91500.00
76969E	2017-08-06 04:46:00+03	13200.00
7696DC	2017-07-18 19:57:00+03	47100.00
7696F0	2017-08-06 05:45:00+03	234100.00
769751	2017-07-27 11:42:00+03	42800.00
769753	2017-07-13 13:03:00+03	43900.00
76975E	2017-07-08 05:26:00+03	226200.00
769763	2017-07-05 16:17:00+03	11300.00
7697C5	2017-08-09 06:57:00+03	19300.00
769821	2017-08-06 05:03:00+03	23200.00
769825	2017-08-11 13:05:00+03	54400.00
769886	2017-07-25 21:35:00+03	8600.00
7698AB	2017-08-13 23:05:00+03	52900.00
7698B3	2017-06-29 01:58:00+03	56600.00
7698E1	2017-07-04 04:25:00+03	80000.00
7698F4	2017-07-03 03:52:00+03	26000.00
76992F	2017-08-15 12:30:00+03	13400.00
769978	2017-08-08 10:14:00+03	67600.00
76997A	2017-08-13 21:13:00+03	135600.00
7699C3	2017-06-26 15:30:00+03	71900.00
7699EF	2017-07-09 06:28:00+03	187900.00
769A56	2017-07-08 06:43:00+03	97600.00
769A69	2017-07-22 03:14:00+03	192400.00
769A79	2017-07-28 21:54:00+03	70700.00
769A90	2017-08-04 01:43:00+03	282300.00
769A93	2017-08-10 13:26:00+03	24400.00
769B05	2017-08-01 04:56:00+03	193700.00
769B13	2017-08-03 02:44:00+03	32600.00
769B18	2017-07-20 11:36:00+03	179500.00
769B2E	2017-08-12 04:45:00+03	37900.00
769B56	2017-07-27 16:40:00+03	399600.00
769B9E	2017-07-22 14:25:00+03	11800.00
769BE9	2017-07-07 22:42:00+03	12200.00
769BF6	2017-08-02 20:08:00+03	96800.00
769C00	2017-08-04 17:07:00+03	75600.00
769D21	2017-08-02 05:55:00+03	15400.00
769D6D	2017-07-06 04:47:00+03	26800.00
769D83	2017-07-25 13:45:00+03	56000.00
769D85	2017-06-26 11:31:00+03	203000.00
769D93	2017-08-08 09:26:00+03	42600.00
769DE8	2017-08-13 20:25:00+03	39500.00
769DEB	2017-07-11 02:55:00+03	70700.00
769DF2	2017-08-15 14:22:00+03	18000.00
769DFD	2017-08-11 20:48:00+03	38800.00
769E11	2017-07-27 08:57:00+03	52400.00
769E3D	2017-07-27 21:35:00+03	6600.00
769EBB	2017-07-14 05:45:00+03	249700.00
769EF5	2017-08-08 08:26:00+03	28000.00
769F20	2017-07-12 22:58:00+03	277800.00
769F96	2017-08-03 07:13:00+03	47000.00
76A040	2017-08-15 04:49:00+03	26700.00
76A078	2017-07-28 07:43:00+03	91800.00
76A085	2017-08-13 03:43:00+03	30900.00
76A08F	2017-08-04 16:51:00+03	19800.00
76A0D6	2017-07-16 08:28:00+03	39300.00
76A0F0	2017-07-07 16:52:00+03	43000.00
76A16A	2017-08-08 03:06:00+03	28300.00
76A19C	2017-08-10 21:10:00+03	39200.00
76A19E	2017-07-13 07:33:00+03	194300.00
76A1A8	2017-08-05 22:13:00+03	167400.00
76A1BA	2017-07-10 17:51:00+03	39300.00
76A1C5	2017-08-01 12:44:00+03	59800.00
76A21C	2017-08-13 12:01:00+03	34000.00
76A231	2017-07-13 11:09:00+03	113100.00
76A24E	2017-07-11 06:32:00+03	94000.00
76A26C	2017-07-27 00:27:00+03	76600.00
76A29C	2017-07-04 12:12:00+03	17600.00
76A2A2	2017-07-24 23:14:00+03	113700.00
76A30E	2017-07-11 04:09:00+03	167500.00
76A321	2017-07-05 09:05:00+03	8200.00
76A379	2017-08-04 09:49:00+03	7400.00
76A3F1	2017-07-19 11:16:00+03	15000.00
76A449	2017-07-16 17:09:00+03	60700.00
76A461	2017-07-06 20:51:00+03	55800.00
76A4A3	2017-07-07 07:54:00+03	61800.00
76A4ED	2017-07-21 05:30:00+03	38800.00
76A54E	2017-07-25 18:47:00+03	6200.00
76A61A	2017-07-17 00:25:00+03	66000.00
76A639	2017-07-20 23:55:00+03	62600.00
76A6BB	2017-07-25 03:57:00+03	13400.00
76A737	2017-07-01 19:18:00+03	8000.00
76A739	2017-08-14 16:34:00+03	81300.00
76A7EB	2017-08-12 18:24:00+03	110800.00
76A804	2017-07-10 15:30:00+03	68400.00
76A816	2017-08-03 19:59:00+03	6300.00
76A899	2017-08-12 08:43:00+03	100000.00
76A8B1	2017-08-05 06:59:00+03	25000.00
76A8C7	2017-08-12 00:16:00+03	92600.00
76A933	2017-07-24 20:23:00+03	32700.00
76A942	2017-08-02 19:49:00+03	191000.00
76A95C	2017-07-03 20:46:00+03	6000.00
76A981	2017-07-23 02:25:00+03	105300.00
76A99E	2017-07-07 13:32:00+03	46000.00
76A9AC	2017-07-16 08:07:00+03	33300.00
76AA21	2017-07-12 09:19:00+03	8200.00
76AA40	2017-08-08 02:32:00+03	93900.00
76AA99	2017-07-19 21:39:00+03	147700.00
76AAB8	2017-07-22 19:14:00+03	102700.00
76AAFF	2017-07-02 12:33:00+03	19600.00
76AB03	2017-07-22 08:02:00+03	106400.00
76AB92	2017-07-04 08:42:00+03	152500.00
76AC09	2017-08-11 17:10:00+03	93000.00
76AC46	2017-06-30 06:35:00+03	99100.00
76AC5C	2017-08-13 20:56:00+03	66300.00
76AC7C	2017-07-10 08:33:00+03	136600.00
76AC84	2017-07-30 03:19:00+03	112000.00
76ACD6	2017-07-04 00:01:00+03	266400.00
76AD30	2017-07-21 06:18:00+03	59400.00
76AD44	2017-08-06 15:15:00+03	86400.00
76AD50	2017-07-16 00:35:00+03	46000.00
76AD75	2017-07-25 10:21:00+03	104000.00
76ADB0	2017-07-27 15:52:00+03	66700.00
76ADD9	2017-08-03 10:33:00+03	6700.00
76AE32	2017-07-08 04:02:00+03	61500.00
76AE4E	2017-07-12 20:10:00+03	29600.00
76AE65	2017-08-04 23:51:00+03	10800.00
76AED4	2017-07-22 01:18:00+03	80400.00
76AF10	2017-07-17 23:12:00+03	32800.00
76AF2B	2017-08-06 19:07:00+03	70700.00
76AF45	2017-07-01 07:49:00+03	42800.00
76AF9A	2017-08-12 15:10:00+03	47000.00
76AFBB	2017-08-14 02:13:00+03	84700.00
76AFE9	2017-07-22 11:24:00+03	23200.00
76B016	2017-07-21 03:30:00+03	24800.00
76B022	2017-08-01 08:27:00+03	28800.00
76B08F	2017-08-13 06:49:00+03	75300.00
76B0A2	2017-07-10 02:36:00+03	234100.00
76B0A4	2017-08-03 04:12:00+03	34000.00
76B0B4	2017-07-23 08:45:00+03	28800.00
76B0F2	2017-07-20 06:12:00+03	88200.00
76B21D	2017-07-16 05:53:00+03	6800.00
76B266	2017-08-10 15:28:00+03	516800.00
76B328	2017-07-19 07:57:00+03	99300.00
76B3FA	2017-07-10 22:36:00+03	123000.00
76B40F	2017-08-11 22:03:00+03	8400.00
76B413	2017-07-12 03:11:00+03	542200.00
76B4AF	2017-07-09 14:31:00+03	22600.00
76B4CF	2017-07-15 07:26:00+03	46000.00
76B514	2017-07-05 03:27:00+03	119500.00
76B537	2017-07-27 22:11:00+03	73600.00
76B549	2017-07-03 00:35:00+03	57600.00
76B550	2017-07-13 23:19:00+03	40800.00
76B5A7	2017-07-27 16:26:00+03	56000.00
76B5CC	2017-07-28 11:40:00+03	89600.00
76B633	2017-07-31 11:03:00+03	56000.00
76B65C	2017-08-15 17:41:00+03	46400.00
76B6A3	2017-07-06 15:28:00+03	398600.00
76B6FC	2017-08-03 17:41:00+03	63400.00
76B72A	2017-07-28 07:08:00+03	81300.00
76B75C	2017-07-23 13:41:00+03	40000.00
76B75E	2017-07-23 20:51:00+03	23600.00
76B781	2017-07-24 18:11:00+03	53300.00
76B78F	2017-07-20 01:02:00+03	58200.00
76B819	2017-07-27 11:36:00+03	30800.00
76B87A	2017-08-04 02:14:00+03	382800.00
76B8BD	2017-07-18 18:44:00+03	81900.00
76B8E0	2017-07-09 01:10:00+03	23200.00
76B8ED	2017-07-28 03:51:00+03	246000.00
76B959	2017-07-26 12:47:00+03	87100.00
76B970	2017-08-12 01:15:00+03	406700.00
76B972	2017-07-15 03:09:00+03	45000.00
76B9B1	2017-07-21 20:54:00+03	76000.00
76BA0D	2017-08-10 04:37:00+03	81300.00
76BA68	2017-08-03 23:42:00+03	40600.00
76BAA0	2017-07-01 11:45:00+03	246000.00
76BAC1	2017-08-06 17:46:00+03	130100.00
76BAF2	2017-07-06 19:40:00+03	6700.00
76BB0A	2017-07-22 14:48:00+03	81300.00
76BB0E	2017-08-04 11:16:00+03	53200.00
76BB6C	2017-08-05 03:09:00+03	23600.00
76BBAE	2017-07-14 08:37:00+03	102900.00
76BC3A	2017-07-06 18:33:00+03	64800.00
76BC7B	2017-08-01 17:19:00+03	8000.00
76BC7D	2017-07-20 11:50:00+03	56000.00
76BCAD	2017-07-22 00:01:00+03	51800.00
76BCD6	2017-07-23 01:50:00+03	40100.00
76BCDF	2017-08-01 14:14:00+03	13400.00
76BD4A	2017-07-18 14:55:00+03	402400.00
76BD85	2017-07-23 00:12:00+03	87700.00
76BD89	2017-07-07 05:42:00+03	21400.00
76BD9B	2017-07-16 11:54:00+03	100600.00
76BE52	2017-07-08 02:07:00+03	226200.00
76BE65	2017-06-28 16:42:00+03	354400.00
76BED7	2017-07-12 22:48:00+03	55800.00
76BEDE	2017-08-14 09:23:00+03	83100.00
76BF2E	2017-08-13 14:30:00+03	246000.00
76BF5E	2017-07-10 22:47:00+03	8200.00
76BFA8	2017-08-08 21:18:00+03	98300.00
76BFF7	2017-07-02 21:14:00+03	179300.00
76C029	2017-08-09 05:02:00+03	36400.00
76C055	2017-08-03 13:52:00+03	6700.00
76C06D	2017-07-07 23:34:00+03	67200.00
76C0D2	2017-07-02 17:23:00+03	239000.00
76C181	2017-07-14 00:00:00+03	272400.00
76C1C4	2017-08-07 18:17:00+03	229900.00
76C314	2017-08-14 16:59:00+03	56600.00
76C318	2017-07-28 23:01:00+03	223200.00
76C353	2017-07-31 21:28:00+03	59400.00
76C383	2017-07-07 14:47:00+03	137600.00
76C393	2017-07-25 04:40:00+03	28800.00
76C3E9	2017-07-08 08:14:00+03	38800.00
76C475	2017-08-02 02:04:00+03	37200.00
76C480	2017-07-15 09:09:00+03	55800.00
76C4B6	2017-08-02 06:52:00+03	59200.00
76C4E8	2017-07-10 11:09:00+03	53600.00
76C533	2017-07-14 14:16:00+03	62600.00
76C58A	2017-07-13 17:15:00+03	135400.00
76C5AD	2017-06-24 01:21:00+03	100600.00
76C5DA	2017-06-30 11:28:00+03	24600.00
76C686	2017-08-06 08:55:00+03	12400.00
76C69B	2017-07-20 15:07:00+03	82900.00
76C737	2017-07-12 01:09:00+03	46400.00
76C7F7	2017-07-30 12:42:00+03	66600.00
76C85A	2017-07-16 19:58:00+03	111600.00
76C87C	2017-08-12 17:16:00+03	40000.00
76C8A1	2017-07-03 12:13:00+03	36800.00
76C8DD	2017-08-08 15:56:00+03	23900.00
76C8E6	2017-08-01 01:29:00+03	143200.00
76C91C	2017-07-11 00:02:00+03	64700.00
76C948	2017-08-10 12:01:00+03	34400.00
76C981	2017-07-30 15:15:00+03	184300.00
76CA4C	2017-07-30 22:44:00+03	63500.00
76CA68	2017-07-23 01:39:00+03	36200.00
76CA6F	2017-08-08 18:51:00+03	28800.00
76CA98	2017-07-10 04:23:00+03	8400.00
76CB11	2017-08-10 08:00:00+03	119600.00
76CB6F	2017-07-04 10:00:00+03	28800.00
76CBA6	2017-08-14 17:05:00+03	202800.00
76CBC3	2017-07-21 05:56:00+03	134800.00
76CBDB	2017-07-21 13:27:00+03	42900.00
76CC1A	2017-07-12 18:50:00+03	21800.00
76CC36	2017-07-23 21:04:00+03	258000.00
76CC6F	2017-07-16 06:27:00+03	70700.00
76CC7E	2017-08-04 09:47:00+03	34000.00
76CCE0	2017-08-10 15:12:00+03	23600.00
76CD16	2017-08-09 20:09:00+03	185800.00
76CD60	2017-07-16 20:00:00+03	53600.00
76CD98	2017-08-14 15:43:00+03	28800.00
76CDB7	2017-07-11 16:04:00+03	62600.00
76CDEF	2017-07-29 06:20:00+03	73500.00
76CE42	2017-07-29 16:55:00+03	152200.00
76CE4E	2017-07-24 07:27:00+03	57500.00
76CE88	2017-07-14 22:10:00+03	55800.00
76CEDF	2017-07-14 11:48:00+03	21600.00
76CEF7	2017-08-15 08:24:00+03	201200.00
76CF74	2017-08-03 11:34:00+03	67900.00
76CFC0	2017-08-10 10:29:00+03	134600.00
76D074	2017-08-01 09:40:00+03	67200.00
76D085	2017-07-07 17:15:00+03	14800.00
76D09E	2017-06-25 00:11:00+03	23600.00
76D0A2	2017-08-12 07:13:00+03	23400.00
76D0B5	2017-08-09 08:58:00+03	52000.00
76D0E3	2017-08-07 01:14:00+03	111600.00
76D122	2017-08-07 01:10:00+03	153300.00
76D12D	2017-07-26 09:28:00+03	54800.00
76D150	2017-07-09 14:28:00+03	27800.00
76D169	2017-08-13 10:53:00+03	23400.00
76D192	2017-07-15 16:33:00+03	108000.00
76D1D7	2017-08-04 20:38:00+03	35200.00
76D1E0	2017-08-03 02:41:00+03	64600.00
76D1E2	2017-08-01 09:42:00+03	103900.00
76D1E6	2017-07-09 18:52:00+03	56000.00
76D218	2017-07-09 22:16:00+03	202100.00
76D2B6	2017-08-01 12:28:00+03	39800.00
76D2C7	2017-07-29 13:00:00+03	155600.00
76D2CA	2017-08-15 14:46:00+03	52900.00
76D316	2017-07-30 00:58:00+03	34000.00
76D33F	2017-07-12 10:27:00+03	106400.00
76D388	2017-07-13 05:45:00+03	80800.00
76D3C7	2017-07-01 16:43:00+03	35800.00
76D3E6	2017-08-11 22:37:00+03	25400.00
76D40C	2017-08-12 01:42:00+03	273400.00
76D41C	2017-07-18 05:05:00+03	61800.00
76D427	2017-06-30 09:02:00+03	28000.00
76D461	2017-07-31 03:47:00+03	26600.00
76D46C	2017-07-16 09:05:00+03	169000.00
76D484	2017-06-27 14:13:00+03	25200.00
76D4A2	2017-07-01 09:20:00+03	50000.00
76D4CD	2017-07-30 08:32:00+03	99200.00
76D4EA	2017-08-15 13:02:00+03	101300.00
76D563	2017-07-24 09:43:00+03	177600.00
76D610	2017-08-13 19:13:00+03	48800.00
76D64A	2017-07-28 22:36:00+03	56000.00
76D68D	2017-07-13 17:24:00+03	111400.00
76D69C	2017-07-28 00:57:00+03	20400.00
76D6AC	2017-07-17 18:09:00+03	36000.00
76D6C1	2017-07-07 08:51:00+03	27200.00
76D6D3	2017-07-27 22:43:00+03	49100.00
76D6E9	2017-08-08 16:04:00+03	28800.00
76D728	2017-07-21 02:05:00+03	38200.00
76D742	2017-07-27 10:06:00+03	12400.00
76D760	2017-06-30 22:41:00+03	101200.00
76D7AF	2017-07-23 19:25:00+03	92000.00
76D7B3	2017-08-09 02:52:00+03	62400.00
76D7F8	2017-07-16 13:44:00+03	12400.00
76D80C	2017-08-13 04:00:00+03	149600.00
76D865	2017-07-23 01:02:00+03	70400.00
76D8B1	2017-07-18 06:34:00+03	217100.00
76D8DA	2017-07-20 09:56:00+03	39400.00
76D9B4	2017-07-23 23:29:00+03	38800.00
76D9F9	2017-07-27 22:40:00+03	46800.00
76DA09	2017-08-02 07:40:00+03	28000.00
76DA31	2017-07-05 06:21:00+03	199700.00
76DB09	2017-07-13 08:57:00+03	49200.00
76DB67	2017-07-26 09:26:00+03	58600.00
76DBA3	2017-07-29 20:35:00+03	38900.00
76DBB7	2017-07-18 01:43:00+03	38400.00
76DBC5	2017-07-30 18:19:00+03	120600.00
76DBC6	2017-08-06 06:25:00+03	27300.00
76DC3D	2017-07-26 20:35:00+03	29600.00
76DC51	2017-07-30 01:37:00+03	25100.00
76DC60	2017-07-20 00:19:00+03	41400.00
76DC77	2017-08-01 00:58:00+03	46400.00
76DC85	2017-07-19 21:55:00+03	111600.00
76DC9D	2017-07-22 11:15:00+03	31400.00
76DCDF	2017-07-03 20:07:00+03	21400.00
76DD01	2017-07-09 15:24:00+03	32700.00
76DD70	2017-08-03 22:42:00+03	47200.00
76DDB7	2017-07-31 03:50:00+03	12600.00
76DDD6	2017-07-12 10:17:00+03	73500.00
76DDE9	2017-07-26 07:58:00+03	69000.00
76DE04	2017-07-19 02:58:00+03	43000.00
76DE51	2017-08-06 02:11:00+03	92700.00
76DE5F	2017-08-09 15:05:00+03	36400.00
76DE65	2017-07-12 22:52:00+03	135400.00
76DEF6	2017-07-14 17:49:00+03	112600.00
76DF30	2017-07-30 07:14:00+03	136600.00
76DF4C	2017-07-29 04:10:00+03	163700.00
76DF65	2017-07-08 14:11:00+03	81600.00
76DF82	2017-07-14 22:49:00+03	29400.00
76DFCB	2017-08-13 15:00:00+03	133200.00
76E021	2017-08-06 20:54:00+03	66000.00
76E03B	2017-08-01 14:47:00+03	130900.00
76E068	2017-07-17 00:50:00+03	36700.00
76E0BC	2017-07-18 05:23:00+03	115600.00
76E0D7	2017-07-09 22:49:00+03	37900.00
76E17C	2017-08-12 10:38:00+03	49100.00
76E18B	2017-08-11 23:18:00+03	99200.00
76E1D4	2017-07-22 15:46:00+03	243600.00
76E21E	2017-07-09 11:01:00+03	28000.00
76E30C	2017-07-17 17:38:00+03	61900.00
76E368	2017-07-28 11:09:00+03	123000.00
76E3AF	2017-08-14 06:31:00+03	56900.00
76E3FE	2017-07-03 14:56:00+03	46400.00
76E40C	2017-08-04 08:28:00+03	24400.00
76E475	2017-08-06 18:33:00+03	58400.00
76E4D2	2017-07-16 18:43:00+03	26700.00
76E4E4	2017-08-06 16:17:00+03	158100.00
76E50A	2017-08-14 21:44:00+03	67200.00
76E565	2017-07-21 04:16:00+03	37700.00
76E574	2017-07-29 15:22:00+03	31400.00
76E602	2017-07-06 23:14:00+03	100000.00
76E63A	2017-07-26 19:20:00+03	18000.00
76E690	2017-07-05 16:27:00+03	90600.00
76E6E0	2017-07-05 05:51:00+03	118300.00
76E6F8	2017-07-27 19:24:00+03	28000.00
76E718	2017-08-09 16:24:00+03	88100.00
76E764	2017-07-04 13:39:00+03	179600.00
76E78F	2017-07-30 07:27:00+03	27400.00
76E79D	2017-08-08 09:06:00+03	49400.00
76E79E	2017-07-17 05:53:00+03	98000.00
76E7C9	2017-08-01 07:48:00+03	85000.00
76E7FC	2017-07-13 06:08:00+03	44000.00
76E807	2017-07-17 02:12:00+03	30300.00
76E854	2017-07-05 03:21:00+03	34000.00
76E85C	2017-07-09 16:40:00+03	23400.00
76E899	2017-08-05 10:40:00+03	173600.00
76E8E3	2017-08-06 19:42:00+03	15000.00
76E916	2017-07-10 19:10:00+03	43200.00
76E94A	2017-07-30 22:43:00+03	48800.00
76E950	2017-07-01 00:01:00+03	61800.00
76E959	2017-07-31 02:12:00+03	51600.00
76E96F	2017-07-23 07:11:00+03	73500.00
76E979	2017-07-10 13:20:00+03	32700.00
76E9D5	2017-07-30 01:34:00+03	202200.00
76E9DF	2017-07-12 11:07:00+03	37700.00
76EA19	2017-07-05 00:43:00+03	57200.00
76EA1B	2017-07-16 13:02:00+03	43800.00
76EA9A	2017-08-11 10:27:00+03	136200.00
76EB2D	2017-07-16 21:31:00+03	25100.00
76EB34	2017-07-15 17:14:00+03	23200.00
76EBFB	2017-07-19 02:27:00+03	40800.00
76EC65	2017-08-09 07:38:00+03	68400.00
76EC8B	2017-08-04 19:00:00+03	133100.00
76ECBA	2017-08-14 18:49:00+03	13400.00
76ECBD	2017-07-24 15:59:00+03	87400.00
76ECDF	2017-07-06 22:04:00+03	57500.00
76ED35	2017-08-14 23:24:00+03	106500.00
76ED38	2017-07-11 19:44:00+03	39800.00
76ED4E	2017-07-31 09:31:00+03	266400.00
76EDDD	2017-07-10 13:41:00+03	51900.00
76EDF1	2017-08-08 20:53:00+03	48500.00
76EE17	2017-08-03 23:19:00+03	46400.00
76EE9F	2017-07-09 20:55:00+03	26000.00
76EF00	2017-07-12 16:45:00+03	46400.00
76EF12	2017-08-04 15:24:00+03	91200.00
76EF3A	2017-07-10 23:24:00+03	6000.00
76EF41	2017-07-11 04:34:00+03	133100.00
76EF54	2017-07-15 05:38:00+03	56600.00
76EF67	2017-07-02 04:18:00+03	65200.00
76EFC1	2017-07-25 08:25:00+03	56000.00
76F012	2017-07-15 08:00:00+03	41600.00
76F055	2017-07-14 17:01:00+03	64000.00
76F0D3	2017-07-31 20:57:00+03	30800.00
76F0E7	2017-07-12 02:06:00+03	28000.00
76F132	2017-08-04 12:04:00+03	77900.00
76F143	2017-07-10 03:10:00+03	66600.00
76F162	2017-08-10 05:17:00+03	25000.00
76F17D	2017-07-27 20:05:00+03	56600.00
76F20D	2017-07-22 22:43:00+03	6700.00
76F212	2017-06-28 09:58:00+03	167400.00
76F23F	2017-08-08 17:58:00+03	21400.00
76F241	2017-07-24 05:51:00+03	28000.00
76F293	2017-07-28 19:51:00+03	189800.00
76F2BA	2017-08-11 15:52:00+03	103600.00
76F37B	2017-07-08 00:24:00+03	397100.00
76F39C	2017-08-08 02:58:00+03	188000.00
76F4BA	2017-07-05 15:53:00+03	61200.00
76F4BD	2017-07-15 07:32:00+03	35600.00
76F515	2017-08-04 01:20:00+03	110500.00
76F554	2017-08-03 22:46:00+03	72300.00
76F582	2017-07-29 09:27:00+03	59300.00
76F587	2017-07-25 10:12:00+03	40100.00
76F5D5	2017-08-11 04:39:00+03	199700.00
76F5E3	2017-07-09 03:19:00+03	25600.00
76F60B	2017-07-08 06:30:00+03	139400.00
76F6A5	2017-07-08 12:23:00+03	28000.00
76F6D5	2017-07-25 08:22:00+03	51600.00
76F6F0	2017-08-01 01:07:00+03	15700.00
76F875	2017-06-30 09:00:00+03	79900.00
76F896	2017-07-20 12:49:00+03	67900.00
76F8C9	2017-08-04 17:54:00+03	62600.00
76F8CF	2017-07-03 10:28:00+03	143100.00
76F941	2017-08-01 23:12:00+03	37200.00
76F94B	2017-07-23 06:15:00+03	306800.00
76F983	2017-08-09 14:12:00+03	110500.00
76F99E	2017-07-21 15:04:00+03	69500.00
76F9B6	2017-07-23 03:28:00+03	154800.00
76F9DF	2017-08-10 18:26:00+03	123000.00
76FA05	2017-08-09 21:55:00+03	133200.00
76FA14	2017-07-15 00:50:00+03	135400.00
76FA1C	2017-08-07 22:21:00+03	81900.00
76FB11	2017-08-06 23:05:00+03	13400.00
76FB3B	2017-07-03 16:43:00+03	31600.00
76FB47	2017-07-05 18:14:00+03	13400.00
76FB7F	2017-07-09 06:22:00+03	25800.00
76FB8F	2017-07-09 08:35:00+03	6700.00
76FC5C	2017-08-14 11:08:00+03	65500.00
76FC93	2017-07-03 12:11:00+03	6900.00
76FCAD	2017-08-06 08:39:00+03	123000.00
76FCF2	2017-08-14 04:02:00+03	68400.00
76FD0C	2017-07-09 07:01:00+03	47400.00
76FD5D	2017-07-17 05:56:00+03	70200.00
76FDFD	2017-08-08 04:43:00+03	98200.00
76FE1B	2017-07-23 21:42:00+03	408500.00
76FE5E	2017-08-05 14:20:00+03	372500.00
7700A3	2017-07-22 19:44:00+03	6700.00
7700B3	2017-07-07 00:24:00+03	89200.00
7700F1	2017-07-07 00:48:00+03	29200.00
770139	2017-07-23 21:27:00+03	60400.00
7701E9	2017-07-06 05:22:00+03	111600.00
770205	2017-07-31 13:36:00+03	32200.00
77020B	2017-07-18 13:30:00+03	52300.00
770249	2017-08-12 17:28:00+03	132800.00
77024E	2017-08-15 01:30:00+03	44200.00
7702E9	2017-07-27 02:57:00+03	37400.00
770306	2017-08-02 21:49:00+03	173400.00
770315	2017-07-31 09:40:00+03	26000.00
770320	2017-07-31 05:58:00+03	47400.00
770336	2017-07-16 11:56:00+03	32000.00
77037D	2017-07-16 07:07:00+03	260900.00
7703BC	2017-08-06 08:32:00+03	89600.00
7703BE	2017-07-26 03:21:00+03	22000.00
7703DC	2017-07-27 06:17:00+03	69000.00
770419	2017-07-21 23:26:00+03	37100.00
77043B	2017-07-12 03:12:00+03	67600.00
770493	2017-08-14 06:21:00+03	111600.00
7704F0	2017-08-14 22:32:00+03	8400.00
770544	2017-07-03 07:53:00+03	110500.00
7705F2	2017-07-08 03:58:00+03	125200.00
770673	2017-07-18 03:30:00+03	73400.00
77069D	2017-08-12 23:41:00+03	15900.00
7707B4	2017-07-30 09:55:00+03	119600.00
7707B8	2017-07-01 21:35:00+03	24300.00
77080E	2017-07-08 09:58:00+03	80000.00
770836	2017-06-30 20:06:00+03	25400.00
770880	2017-07-30 11:14:00+03	139200.00
7708F8	2017-07-23 13:06:00+03	84100.00
7708FB	2017-07-25 11:27:00+03	188000.00
770908	2017-07-30 19:11:00+03	131500.00
7709D3	2017-08-07 07:12:00+03	165500.00
7709D7	2017-07-24 20:46:00+03	54500.00
7709EC	2017-07-20 11:56:00+03	23400.00
7709F8	2017-07-08 12:57:00+03	135000.00
770A0F	2017-08-06 07:27:00+03	99200.00
770A1D	2017-08-10 04:43:00+03	62700.00
770A5B	2017-07-27 23:58:00+03	62000.00
770A93	2017-08-10 18:44:00+03	88100.00
770AB0	2017-08-10 01:21:00+03	30400.00
770AD3	2017-07-12 17:26:00+03	135400.00
770B43	2017-07-27 02:22:00+03	87200.00
770BF4	2017-08-09 00:20:00+03	20800.00
770C57	2017-07-03 23:24:00+03	168000.00
770CD2	2017-08-02 07:17:00+03	101500.00
770CE2	2017-08-15 17:57:00+03	265700.00
770CF9	2017-07-14 05:51:00+03	88800.00
770D2D	2017-07-24 23:23:00+03	201200.00
770D5E	2017-08-02 02:12:00+03	52600.00
770D5F	2017-08-01 10:43:00+03	260300.00
770E5A	2017-07-23 00:29:00+03	134600.00
770EC1	2017-07-15 10:42:00+03	36200.00
770F1A	2017-08-10 08:40:00+03	23200.00
770F2D	2017-07-15 01:26:00+03	25000.00
770F7A	2017-07-22 06:25:00+03	67300.00
770FB8	2017-07-23 09:55:00+03	67600.00
770FC1	2017-08-09 17:08:00+03	23200.00
771023	2017-07-19 04:47:00+03	13000.00
77107A	2017-07-17 15:45:00+03	172600.00
771082	2017-08-13 23:33:00+03	75600.00
7710E0	2017-08-08 15:45:00+03	334800.00
77117C	2017-07-14 02:41:00+03	89500.00
77118E	2017-07-13 18:37:00+03	240600.00
77119F	2017-08-04 13:57:00+03	105000.00
7711A6	2017-07-17 04:57:00+03	13200.00
77124E	2017-08-02 00:04:00+03	491000.00
7712C2	2017-07-19 02:18:00+03	145300.00
7712C3	2017-08-03 02:37:00+03	6800.00
7712CC	2017-07-29 01:28:00+03	74400.00
7712D7	2017-07-23 12:55:00+03	55800.00
771320	2017-07-09 15:37:00+03	131600.00
771340	2017-08-02 13:15:00+03	119600.00
77140F	2017-07-02 18:24:00+03	26000.00
771423	2017-07-21 22:51:00+03	46300.00
77147B	2017-07-18 08:51:00+03	126500.00
7714BC	2017-07-11 00:28:00+03	6800.00
7714C8	2017-06-28 02:31:00+03	23400.00
77153A	2017-07-28 03:57:00+03	138100.00
771565	2017-08-12 15:07:00+03	128300.00
77157D	2017-08-01 11:35:00+03	108000.00
7715A6	2017-07-31 02:04:00+03	67800.00
7715AC	2017-07-08 16:20:00+03	112600.00
7715B1	2017-07-25 23:43:00+03	21800.00
771651	2017-07-27 00:24:00+03	29100.00
771694	2017-07-20 14:51:00+03	182300.00
7716F5	2017-06-29 17:17:00+03	114800.00
771730	2017-08-02 14:22:00+03	111600.00
7717A2	2017-08-06 23:56:00+03	39400.00
7717AD	2017-07-24 14:47:00+03	94500.00
771836	2017-07-19 17:14:00+03	46000.00
7718A9	2017-08-15 03:28:00+03	57500.00
7718F3	2017-07-27 08:04:00+03	290400.00
771966	2017-07-12 13:01:00+03	381500.00
771A0D	2017-07-25 19:29:00+03	54800.00
771A18	2017-07-17 14:49:00+03	101200.00
771A1E	2017-08-10 09:26:00+03	26200.00
771A89	2017-06-27 02:50:00+03	17000.00
771AA2	2017-08-08 13:32:00+03	28800.00
771B3F	2017-08-09 03:09:00+03	199700.00
771B47	2017-08-06 16:33:00+03	29600.00
771B4D	2017-07-20 21:58:00+03	14800.00
771B56	2017-07-11 02:16:00+03	99200.00
771B8D	2017-08-06 12:42:00+03	62600.00
771BA7	2017-07-26 13:51:00+03	21400.00
771BB9	2017-07-08 08:37:00+03	58400.00
771BCC	2017-08-14 19:14:00+03	28000.00
771C04	2017-07-26 20:36:00+03	56000.00
771C08	2017-07-30 19:33:00+03	23600.00
771C4E	2017-07-31 01:14:00+03	154100.00
771C62	2017-07-30 16:05:00+03	178300.00
771C6F	2017-07-26 13:11:00+03	16400.00
771C99	2017-07-23 20:30:00+03	91100.00
771CA3	2017-08-04 03:52:00+03	521400.00
771CA6	2017-07-10 03:12:00+03	75300.00
771CD6	2017-07-28 17:15:00+03	28800.00
771CF5	2017-08-14 20:18:00+03	214900.00
771D08	2017-08-12 13:12:00+03	58600.00
771D2E	2017-08-13 10:08:00+03	62000.00
771D63	2017-07-24 09:22:00+03	22000.00
771DA0	2017-07-27 10:32:00+03	117500.00
771DAB	2017-07-06 06:40:00+03	55500.00
771DB2	2017-08-13 09:42:00+03	62600.00
771E29	2017-07-13 19:57:00+03	23100.00
77200E	2017-07-03 01:40:00+03	13600.00
772060	2017-08-15 10:51:00+03	129200.00
772084	2017-08-15 16:54:00+03	85000.00
7720C2	2017-07-21 05:47:00+03	164700.00
772111	2017-07-09 19:17:00+03	28000.00
772158	2017-08-02 05:08:00+03	80900.00
772179	2017-08-15 08:21:00+03	40400.00
77217D	2017-08-09 23:23:00+03	136000.00
772190	2017-07-27 23:29:00+03	391000.00
7721AE	2017-06-30 22:34:00+03	23200.00
7721B5	2017-08-08 08:27:00+03	20200.00
7721D6	2017-07-08 22:19:00+03	134900.00
7721E4	2017-07-14 08:46:00+03	48500.00
7721F4	2017-08-02 14:46:00+03	86600.00
772208	2017-08-13 06:04:00+03	121600.00
7723F2	2017-07-31 07:18:00+03	6000.00
772519	2017-07-09 21:15:00+03	67800.00
772547	2017-08-10 13:16:00+03	55800.00
7725C4	2017-07-14 11:05:00+03	78800.00
7725C7	2017-07-30 07:44:00+03	110500.00
7725CD	2017-07-29 00:46:00+03	47500.00
7725CE	2017-07-16 06:33:00+03	50600.00
7725DF	2017-07-25 18:05:00+03	28000.00
77261A	2017-08-06 04:44:00+03	170700.00
772620	2017-08-14 01:11:00+03	16800.00
772644	2017-08-12 15:05:00+03	57300.00
772650	2017-07-14 16:16:00+03	289800.00
7726CE	2017-08-04 23:21:00+03	96800.00
77271A	2017-08-15 00:07:00+03	25400.00
772747	2017-07-20 18:22:00+03	128800.00
772754	2017-07-01 22:26:00+03	95100.00
772785	2017-07-01 18:24:00+03	33400.00
772794	2017-07-07 04:54:00+03	170800.00
7728BC	2017-08-06 05:57:00+03	27000.00
7728C1	2017-07-05 03:38:00+03	54000.00
77294F	2017-07-01 17:50:00+03	95200.00
7729A0	2017-07-27 09:34:00+03	26000.00
7729AB	2017-08-08 00:09:00+03	43200.00
7729D6	2017-07-14 22:57:00+03	25100.00
7729E4	2017-07-12 18:43:00+03	101200.00
772A12	2017-08-07 19:43:00+03	83000.00
772A63	2017-07-28 07:42:00+03	61800.00
772A89	2017-07-28 13:06:00+03	97900.00
772ACB	2017-07-21 19:40:00+03	13600.00
772AD8	2017-08-03 16:25:00+03	80700.00
772B92	2017-08-14 00:19:00+03	28000.00
772BB7	2017-07-26 00:43:00+03	228700.00
772BB8	2017-07-11 05:39:00+03	72400.00
772BEE	2017-08-10 16:08:00+03	27200.00
772BF0	2017-08-02 17:16:00+03	29600.00
772BF9	2017-07-15 16:26:00+03	50600.00
772C0C	2017-08-15 13:11:00+03	24000.00
772C84	2017-07-04 07:50:00+03	27800.00
772C9C	2017-08-12 23:30:00+03	10800.00
772CA2	2017-06-29 19:49:00+03	168000.00
772CDE	2017-08-14 08:42:00+03	91200.00
772CF4	2017-07-02 18:31:00+03	14000.00
772CF7	2017-07-15 01:59:00+03	46400.00
772CF8	2017-07-03 09:42:00+03	61800.00
772D59	2017-07-03 15:53:00+03	60800.00
772D7A	2017-08-11 20:48:00+03	179400.00
772D8C	2017-07-08 12:55:00+03	26700.00
772E3F	2017-07-05 09:03:00+03	56100.00
772E6D	2017-07-03 15:41:00+03	138100.00
772E8A	2017-08-01 04:05:00+03	133100.00
772EF7	2017-08-02 11:58:00+03	130400.00
772F48	2017-07-25 15:36:00+03	46400.00
772F54	2017-07-02 21:37:00+03	40200.00
772F66	2017-08-11 17:40:00+03	56000.00
772FB1	2017-08-09 14:04:00+03	56100.00
77300F	2017-07-24 09:54:00+03	71600.00
77302F	2017-06-30 20:10:00+03	236300.00
7730B5	2017-08-11 20:31:00+03	123000.00
7730D4	2017-07-18 03:21:00+03	90000.00
773140	2017-07-09 17:20:00+03	85000.00
7731D8	2017-07-07 13:44:00+03	58600.00
773216	2017-07-24 05:56:00+03	174400.00
77321E	2017-07-10 15:14:00+03	43200.00
77322D	2017-08-10 11:42:00+03	8200.00
773253	2017-08-02 19:02:00+03	369000.00
77325D	2017-07-16 14:40:00+03	55800.00
773261	2017-07-14 12:45:00+03	75300.00
773263	2017-07-25 11:33:00+03	529200.00
773265	2017-07-01 11:17:00+03	40800.00
7732F1	2017-07-12 18:33:00+03	28800.00
77330B	2017-08-13 15:10:00+03	31100.00
773380	2017-07-05 11:46:00+03	56000.00
7733C6	2017-07-28 23:30:00+03	28300.00
7733F1	2017-08-13 13:54:00+03	57700.00
773420	2017-07-14 08:03:00+03	101200.00
773438	2017-08-03 00:06:00+03	17200.00
7734A5	2017-07-21 21:49:00+03	829100.00
7734BF	2017-07-26 16:50:00+03	14000.00
7734E4	2017-07-06 04:03:00+03	56000.00
7734F6	2017-07-07 08:21:00+03	27200.00
773575	2017-07-15 02:30:00+03	32200.00
7735A1	2017-07-17 16:58:00+03	106400.00
7735EC	2017-07-06 13:15:00+03	75300.00
773663	2017-07-03 06:00:00+03	13700.00
773669	2017-08-06 03:41:00+03	135300.00
773673	2017-07-01 20:28:00+03	23400.00
7736C2	2017-07-29 07:07:00+03	7400.00
7737AC	2017-08-02 11:32:00+03	180000.00
77380E	2017-08-14 03:08:00+03	137600.00
773841	2017-08-09 03:20:00+03	135400.00
773858	2017-07-25 10:57:00+03	69900.00
773949	2017-07-05 23:25:00+03	112000.00
773964	2017-07-02 14:37:00+03	25200.00
7739F2	2017-07-31 15:34:00+03	26700.00
773A0D	2017-08-12 17:02:00+03	42600.00
773AC0	2017-07-01 08:26:00+03	81600.00
773B52	2017-08-15 06:41:00+03	521800.00
773BA4	2017-07-14 11:22:00+03	73200.00
773BF2	2017-08-07 07:10:00+03	58600.00
773C8A	2017-07-04 11:46:00+03	23400.00
773C96	2017-07-13 09:19:00+03	27400.00
773CB3	2017-07-01 04:55:00+03	51300.00
773CDA	2017-07-03 05:09:00+03	33100.00
773CDF	2017-08-14 19:47:00+03	202900.00
773D3B	2017-07-20 10:18:00+03	73500.00
773D4C	2017-07-28 17:44:00+03	30900.00
773D6F	2017-06-30 21:45:00+03	111600.00
773DB3	2017-08-01 02:54:00+03	31000.00
773DD4	2017-08-12 10:01:00+03	29600.00
773DF5	2017-07-05 22:09:00+03	101200.00
773E18	2017-07-22 16:01:00+03	13600.00
773EBE	2017-07-07 00:18:00+03	26000.00
773EFC	2017-08-04 15:10:00+03	190400.00
773F43	2017-07-03 08:03:00+03	256700.00
774012	2017-07-06 21:01:00+03	46300.00
77403A	2017-07-07 12:55:00+03	12600.00
774078	2017-07-18 05:01:00+03	47200.00
77409D	2017-07-09 08:06:00+03	62700.00
774109	2017-07-13 23:56:00+03	46400.00
774246	2017-07-25 23:52:00+03	191200.00
77424B	2017-07-30 04:22:00+03	111700.00
774325	2017-08-03 03:21:00+03	73000.00
774334	2017-08-15 05:30:00+03	7400.00
774353	2017-07-04 20:06:00+03	56100.00
77436A	2017-07-20 16:55:00+03	64700.00
7744AA	2017-08-06 23:44:00+03	25000.00
774501	2017-07-07 03:58:00+03	99700.00
77450D	2017-07-07 13:58:00+03	204300.00
77453C	2017-07-28 21:39:00+03	255600.00
774542	2017-08-11 00:36:00+03	23900.00
774561	2017-08-10 00:47:00+03	55500.00
774595	2017-08-07 08:13:00+03	64100.00
7745C5	2017-07-27 13:47:00+03	66400.00
7745F0	2017-08-02 18:43:00+03	22000.00
7746AD	2017-08-06 08:05:00+03	46300.00
7746E2	2017-08-06 02:07:00+03	28000.00
7746EF	2017-07-12 18:29:00+03	67700.00
7746F7	2017-07-30 22:26:00+03	38600.00
77478F	2017-07-03 01:52:00+03	104100.00
774841	2017-06-30 22:59:00+03	49100.00
774848	2017-06-27 09:43:00+03	102100.00
7748E6	2017-08-08 18:17:00+03	111600.00
774925	2017-07-18 07:50:00+03	155600.00
774954	2017-07-24 19:31:00+03	55800.00
77495A	2017-08-09 09:36:00+03	54400.00
7749A4	2017-07-08 03:03:00+03	23400.00
774A48	2017-07-28 06:29:00+03	46000.00
774A50	2017-08-13 21:29:00+03	179400.00
774AE9	2017-08-12 11:25:00+03	17300.00
774B0E	2017-07-26 16:19:00+03	53600.00
774B1E	2017-07-05 17:21:00+03	22600.00
774B25	2017-07-15 19:45:00+03	141200.00
774B88	2017-07-22 22:11:00+03	148400.00
774B9B	2017-07-09 06:38:00+03	47000.00
774C4A	2017-07-28 17:30:00+03	12600.00
774C5C	2017-08-08 16:24:00+03	40600.00
774CC6	2017-08-06 10:55:00+03	199700.00
774CE6	2017-07-31 19:34:00+03	63400.00
774D0A	2017-07-20 15:02:00+03	39300.00
774D28	2017-07-21 02:06:00+03	65900.00
774D2A	2017-07-06 00:50:00+03	174400.00
774D34	2017-08-13 05:39:00+03	12400.00
774D43	2017-08-09 14:04:00+03	55800.00
774D60	2017-08-01 18:41:00+03	36200.00
774D7F	2017-07-24 15:12:00+03	94700.00
774DE6	2017-07-20 19:45:00+03	73500.00
774E47	2017-07-25 01:58:00+03	13700.00
774E6A	2017-07-09 22:43:00+03	30400.00
774E91	2017-07-26 19:17:00+03	273600.00
774EBA	2017-07-05 09:06:00+03	189000.00
774EC0	2017-07-28 18:58:00+03	4100.00
774EFC	2017-07-19 13:45:00+03	44000.00
774F2B	2017-08-13 02:58:00+03	38600.00
774F5C	2017-08-11 19:12:00+03	56000.00
774F6D	2017-07-22 13:12:00+03	155400.00
774FB2	2017-07-04 18:49:00+03	532600.00
774FE9	2017-08-02 05:36:00+03	17200.00
775055	2017-08-11 18:04:00+03	8000.00
775083	2017-07-26 20:20:00+03	170000.00
7750E1	2017-07-18 01:37:00+03	56600.00
775114	2017-07-25 15:32:00+03	116900.00
775157	2017-07-11 19:43:00+03	26000.00
7751D4	2017-06-28 23:27:00+03	13700.00
7751E4	2017-07-20 19:38:00+03	56000.00
775207	2017-08-04 00:02:00+03	25200.00
775220	2017-08-12 00:09:00+03	65500.00
775223	2017-07-07 19:40:00+03	21400.00
7752A2	2017-07-20 18:07:00+03	46200.00
7752BD	2017-08-04 15:55:00+03	60300.00
7752C4	2017-08-11 12:42:00+03	23200.00
7752E3	2017-07-17 23:12:00+03	140500.00
775311	2017-07-26 17:14:00+03	199700.00
77531B	2017-08-10 03:11:00+03	154700.00
775336	2017-07-18 02:21:00+03	56000.00
77535E	2017-08-15 11:47:00+03	27000.00
775366	2017-07-08 11:39:00+03	32800.00
77536B	2017-08-04 11:43:00+03	7400.00
775373	2017-08-09 00:26:00+03	57500.00
775387	2017-08-02 22:52:00+03	92400.00
7753FC	2017-07-08 06:55:00+03	34200.00
7754AB	2017-08-05 18:47:00+03	112200.00
77551B	2017-07-29 22:42:00+03	43200.00
775527	2017-08-05 07:28:00+03	24800.00
775529	2017-07-28 22:47:00+03	87200.00
775533	2017-07-28 19:51:00+03	56000.00
77556A	2017-07-27 13:52:00+03	62600.00
7755BC	2017-07-12 06:11:00+03	13000.00
775608	2017-08-01 21:06:00+03	270000.00
775679	2017-07-26 09:21:00+03	23200.00
7756DF	2017-07-25 14:54:00+03	35600.00
775712	2017-06-29 02:07:00+03	41600.00
775775	2017-07-09 09:37:00+03	41600.00
77577D	2017-07-18 18:26:00+03	43200.00
775793	2017-07-11 05:21:00+03	6200.00
77580E	2017-07-17 10:03:00+03	62000.00
77584A	2017-08-11 08:32:00+03	47100.00
775882	2017-07-07 14:15:00+03	62500.00
7758C2	2017-07-04 21:12:00+03	48300.00
775936	2017-07-29 09:09:00+03	32800.00
775955	2017-07-08 21:39:00+03	49600.00
7759C7	2017-08-09 14:06:00+03	147700.00
775A00	2017-07-20 23:12:00+03	24400.00
775A04	2017-07-26 10:07:00+03	37900.00
775A46	2017-07-09 08:43:00+03	48500.00
775A5E	2017-07-17 21:52:00+03	24400.00
775A7B	2017-07-11 11:48:00+03	47100.00
775AE8	2017-07-27 05:01:00+03	36200.00
775B06	2017-08-12 21:27:00+03	54000.00
775BC1	2017-07-24 16:44:00+03	129200.00
775C0A	2017-08-07 23:17:00+03	57500.00
775C40	2017-08-13 08:33:00+03	46400.00
775C44	2017-08-05 22:58:00+03	28800.00
775C6B	2017-07-28 15:58:00+03	50000.00
775C9D	2017-07-17 08:42:00+03	92700.00
775D41	2017-07-11 22:22:00+03	6000.00
775DC5	2017-08-09 22:07:00+03	153000.00
775DF9	2017-07-02 20:22:00+03	32900.00
775E61	2017-08-10 19:57:00+03	153300.00
775E71	2017-07-23 20:43:00+03	89600.00
775E9F	2017-07-11 01:45:00+03	12600.00
775EA4	2017-07-21 03:23:00+03	6600.00
775ED3	2017-07-21 19:07:00+03	23400.00
775EE6	2017-08-15 13:54:00+03	34000.00
775F6F	2017-07-21 05:36:00+03	23200.00
775FA0	2017-07-12 08:19:00+03	29600.00
775FA1	2017-07-21 23:56:00+03	146400.00
77604B	2017-07-11 05:31:00+03	246000.00
7760A7	2017-08-15 03:29:00+03	115700.00
7761AA	2017-08-05 13:48:00+03	90800.00
776204	2017-08-07 22:54:00+03	52000.00
77627A	2017-07-06 19:41:00+03	23400.00
7762B4	2017-08-07 15:13:00+03	53600.00
776314	2017-07-14 04:22:00+03	131900.00
776320	2017-07-13 17:14:00+03	20600.00
776359	2017-07-07 04:09:00+03	531400.00
77636E	2017-08-07 23:34:00+03	664100.00
776402	2017-08-09 04:13:00+03	89200.00
77643D	2017-08-08 22:28:00+03	202700.00
77653E	2017-08-04 04:59:00+03	40000.00
776551	2017-07-11 21:28:00+03	664200.00
776598	2017-08-06 09:08:00+03	46500.00
776607	2017-08-14 11:49:00+03	40800.00
776651	2017-07-14 00:31:00+03	289800.00
7766A3	2017-08-06 07:40:00+03	250600.00
776703	2017-07-05 11:06:00+03	10700.00
77671B	2017-07-19 03:24:00+03	49100.00
776743	2017-07-16 00:44:00+03	52800.00
77675B	2017-08-15 09:22:00+03	79900.00
776883	2017-08-15 16:25:00+03	100200.00
7768CC	2017-07-04 10:47:00+03	56900.00
776951	2017-07-09 14:37:00+03	56000.00
77696D	2017-07-27 10:27:00+03	122300.00
77697A	2017-07-09 09:12:00+03	114300.00
7769EA	2017-08-14 14:31:00+03	92000.00
7769F9	2017-08-08 20:54:00+03	87400.00
776A4D	2017-08-14 01:25:00+03	147200.00
776ABC	2017-07-28 03:58:00+03	95200.00
776B23	2017-07-17 06:23:00+03	20800.00
776B25	2017-07-23 22:42:00+03	67800.00
776B62	2017-08-15 03:24:00+03	75600.00
776C1B	2017-07-22 16:54:00+03	273400.00
776C3F	2017-08-07 12:50:00+03	31900.00
776C8E	2017-07-26 12:23:00+03	12400.00
776CEA	2017-08-12 14:40:00+03	23600.00
776D91	2017-08-02 07:46:00+03	111600.00
776DC8	2017-07-02 20:40:00+03	168300.00
776DFC	2017-07-16 01:41:00+03	56200.00
776E19	2017-08-03 06:47:00+03	73100.00
776EAD	2017-07-31 04:19:00+03	34000.00
776ECF	2017-08-10 18:39:00+03	12600.00
776EEC	2017-07-16 10:04:00+03	26700.00
776F05	2017-07-11 16:00:00+03	214100.00
776F89	2017-08-12 19:46:00+03	354200.00
776FB5	2017-08-04 00:17:00+03	75200.00
776FB6	2017-07-06 06:42:00+03	146900.00
776FBE	2017-07-22 03:21:00+03	15000.00
777044	2017-08-03 00:59:00+03	225800.00
777057	2017-08-08 23:18:00+03	184000.00
77705F	2017-07-09 13:53:00+03	42800.00
7770D1	2017-08-06 15:11:00+03	20200.00
777290	2017-08-07 07:27:00+03	34000.00
777297	2017-07-02 11:10:00+03	16400.00
77736A	2017-07-30 19:53:00+03	96800.00
77737A	2017-08-14 16:28:00+03	13400.00
77743F	2017-07-15 12:18:00+03	32100.00
777450	2017-07-12 09:12:00+03	8400.00
777458	2017-06-28 19:23:00+03	40400.00
777481	2017-07-28 05:32:00+03	135600.00
777500	2017-07-07 08:26:00+03	403300.00
777562	2017-08-15 09:56:00+03	46400.00
77759E	2017-08-04 02:53:00+03	56000.00
777601	2017-07-08 04:48:00+03	39400.00
77760C	2017-08-07 04:49:00+03	25400.00
777626	2017-07-30 08:23:00+03	38800.00
777752	2017-08-13 12:53:00+03	29300.00
777781	2017-08-14 09:40:00+03	68000.00
7777DD	2017-07-21 16:50:00+03	70600.00
7777EE	2017-07-20 02:45:00+03	7200.00
777880	2017-07-17 01:50:00+03	26000.00
77788A	2017-07-31 01:22:00+03	111600.00
7778B4	2017-08-09 14:26:00+03	432800.00
777956	2017-07-14 15:20:00+03	396500.00
777985	2017-07-13 07:47:00+03	129700.00
777993	2017-07-01 22:51:00+03	254500.00
777A2C	2017-07-29 13:39:00+03	48800.00
777A9C	2017-08-05 18:22:00+03	65000.00
777AD8	2017-07-24 02:31:00+03	53600.00
777AED	2017-07-21 22:47:00+03	25600.00
777B52	2017-07-29 11:31:00+03	48800.00
777B8E	2017-08-05 15:41:00+03	273300.00
777BEC	2017-07-03 17:20:00+03	72400.00
777C34	2017-08-14 05:46:00+03	12000.00
777CAC	2017-08-02 08:32:00+03	86600.00
777CFF	2017-07-29 01:22:00+03	112000.00
777D1B	2017-07-09 08:36:00+03	165500.00
777D1D	2017-07-30 17:33:00+03	66800.00
777D56	2017-07-10 18:23:00+03	264000.00
777E43	2017-08-11 11:36:00+03	226800.00
777E84	2017-07-11 08:40:00+03	26000.00
777EC0	2017-08-05 19:25:00+03	52000.00
777F17	2017-07-04 12:01:00+03	18000.00
777F94	2017-08-13 14:00:00+03	12600.00
777FF3	2017-08-06 08:26:00+03	51300.00
777FFE	2017-07-15 04:27:00+03	23600.00
77803F	2017-08-06 11:29:00+03	40400.00
778082	2017-07-29 08:36:00+03	114400.00
7780A8	2017-08-01 17:47:00+03	27300.00
7780EF	2017-07-25 01:45:00+03	406100.00
778159	2017-08-04 17:08:00+03	51600.00
778243	2017-07-16 13:40:00+03	21000.00
778264	2017-07-16 17:02:00+03	26000.00
77826C	2017-07-07 22:59:00+03	18100.00
778351	2017-07-29 16:26:00+03	246000.00
778391	2017-07-28 02:40:00+03	73300.00
7783CC	2017-07-09 06:08:00+03	44600.00
7783E9	2017-08-04 15:14:00+03	95200.00
7784BF	2017-07-01 03:59:00+03	37900.00
7784C4	2017-07-02 17:39:00+03	16400.00
7784E4	2017-07-05 04:56:00+03	23200.00
7784E7	2017-08-08 21:31:00+03	88900.00
77850C	2017-07-06 00:47:00+03	75800.00
778550	2017-07-19 19:17:00+03	24400.00
77855D	2017-07-03 13:04:00+03	16400.00
77856A	2017-07-10 14:05:00+03	53300.00
7785B3	2017-07-24 03:42:00+03	12600.00
7785B5	2017-08-11 17:59:00+03	65500.00
7785F9	2017-07-30 21:05:00+03	65100.00
77864E	2017-07-24 21:12:00+03	14800.00
778687	2017-07-13 14:52:00+03	30000.00
7786A7	2017-07-26 10:40:00+03	30400.00
7786F3	2017-08-05 01:30:00+03	40600.00
7786F6	2017-08-04 15:52:00+03	43200.00
77871D	2017-07-14 12:49:00+03	55800.00
77876C	2017-07-10 07:21:00+03	24400.00
7787A7	2017-08-13 03:40:00+03	32100.00
7787E2	2017-07-15 21:12:00+03	89600.00
778816	2017-08-02 03:45:00+03	30000.00
778853	2017-07-12 10:35:00+03	97500.00
778885	2017-07-25 21:31:00+03	53600.00
7788AC	2017-08-10 01:59:00+03	38600.00
7788BB	2017-07-04 12:44:00+03	46400.00
7788D6	2017-07-02 11:56:00+03	56000.00
7788F7	2017-08-12 03:27:00+03	18400.00
778925	2017-06-29 21:16:00+03	13600.00
778947	2017-07-12 12:26:00+03	266400.00
7789B8	2017-07-28 22:33:00+03	55600.00
7789CF	2017-07-07 16:45:00+03	46000.00
7789F8	2017-07-31 08:04:00+03	50000.00
778A0B	2017-08-11 20:35:00+03	69500.00
778A2F	2017-08-05 19:02:00+03	254600.00
778A44	2017-06-30 21:41:00+03	28800.00
778A8B	2017-07-30 04:15:00+03	139000.00
778AC1	2017-07-17 13:09:00+03	56600.00
778ACF	2017-07-14 15:40:00+03	7200.00
778AEC	2017-08-09 20:14:00+03	38800.00
778AF0	2017-07-07 00:42:00+03	103500.00
778B39	2017-07-19 18:26:00+03	92100.00
778B6B	2017-07-26 10:30:00+03	54500.00
778B7F	2017-07-23 07:30:00+03	13000.00
778BAF	2017-07-09 15:26:00+03	61500.00
778BBB	2017-08-10 21:32:00+03	58000.00
778BC7	2017-08-13 22:43:00+03	28000.00
778BC8	2017-07-07 02:20:00+03	190400.00
778C77	2017-07-11 13:22:00+03	28000.00
778C7E	2017-07-10 19:15:00+03	283100.00
778C8B	2017-08-02 12:15:00+03	397800.00
778CB4	2017-07-31 09:12:00+03	133100.00
778D06	2017-07-17 17:28:00+03	257600.00
778D29	2017-06-30 07:43:00+03	85000.00
778D78	2017-07-09 12:55:00+03	54400.00
778D93	2017-07-09 14:09:00+03	406700.00
778DE4	2017-07-19 23:27:00+03	16400.00
778E17	2017-07-30 09:07:00+03	48100.00
778E4A	2017-07-27 19:10:00+03	61800.00
778EE6	2017-07-10 21:25:00+03	21400.00
778EEA	2017-07-13 03:56:00+03	33300.00
778F21	2017-07-02 11:18:00+03	40000.00
778FF3	2017-07-17 19:07:00+03	21400.00
7790F7	2017-08-10 02:29:00+03	65200.00
77910E	2017-07-17 05:25:00+03	65800.00
779171	2017-07-24 14:54:00+03	18600.00
7791BD	2017-07-06 12:31:00+03	255000.00
7791C1	2017-08-09 11:54:00+03	71900.00
779276	2017-08-06 16:09:00+03	14000.00
7792F3	2017-07-08 23:01:00+03	149300.00
7792FA	2017-08-06 23:51:00+03	99600.00
77936B	2017-07-21 13:13:00+03	21200.00
7793A0	2017-08-14 02:04:00+03	6700.00
7794C0	2017-06-29 17:52:00+03	420500.00
7794D1	2017-06-25 19:24:00+03	150600.00
77957B	2017-07-20 13:18:00+03	111600.00
7795D4	2017-07-06 03:36:00+03	202100.00
77960B	2017-08-12 03:42:00+03	56000.00
779618	2017-06-26 17:15:00+03	26800.00
77961E	2017-08-14 11:37:00+03	57800.00
77961F	2017-07-15 03:34:00+03	274800.00
779624	2017-08-06 11:28:00+03	66600.00
779629	2017-07-31 15:08:00+03	78600.00
779671	2017-07-31 18:28:00+03	43900.00
77969C	2017-06-28 04:00:00+03	12400.00
7796CE	2017-07-14 11:33:00+03	51300.00
77977A	2017-07-25 05:47:00+03	135400.00
779794	2017-08-03 06:28:00+03	31600.00
77979C	2017-07-12 08:33:00+03	117600.00
7797CC	2017-08-15 03:11:00+03	38400.00
7797E4	2017-08-12 02:58:00+03	63200.00
7797FE	2017-07-25 20:09:00+03	6600.00
779836	2017-07-08 13:44:00+03	130900.00
77984E	2017-08-15 01:54:00+03	76800.00
779857	2017-07-10 06:37:00+03	62700.00
77989D	2017-07-03 17:59:00+03	167900.00
77989E	2017-08-15 01:02:00+03	24000.00
7798A1	2017-08-13 18:07:00+03	67300.00
7798C7	2017-07-12 12:48:00+03	148400.00
779945	2017-08-06 20:23:00+03	29200.00
779951	2017-08-01 22:36:00+03	66600.00
77996B	2017-07-19 23:01:00+03	28000.00
7799AF	2017-07-15 17:46:00+03	77700.00
7799EB	2017-07-24 05:42:00+03	39500.00
7799EE	2017-08-09 06:11:00+03	213200.00
779A28	2017-08-07 13:09:00+03	15000.00
779A72	2017-07-17 16:21:00+03	46000.00
779AB9	2017-07-28 21:11:00+03	47200.00
779ABB	2017-07-12 15:14:00+03	29400.00
779B48	2017-08-06 03:06:00+03	213200.00
779B82	2017-08-07 21:09:00+03	70700.00
779BF3	2017-07-25 01:54:00+03	66200.00
779CEA	2017-07-07 05:42:00+03	89700.00
779CEB	2017-07-14 03:24:00+03	48800.00
779CF2	2017-07-11 15:57:00+03	41800.00
779D55	2017-07-01 04:52:00+03	49100.00
779D70	2017-08-03 10:28:00+03	15800.00
779D81	2017-07-08 09:54:00+03	44800.00
779DC9	2017-07-07 20:38:00+03	57600.00
779E62	2017-08-08 10:15:00+03	94000.00
779EA7	2017-07-02 08:54:00+03	68400.00
779EB4	2017-07-05 11:54:00+03	97600.00
779F2C	2017-08-08 11:46:00+03	89200.00
779F4E	2017-07-18 16:40:00+03	43500.00
77A05D	2017-08-03 23:13:00+03	95900.00
77A07A	2017-08-05 17:35:00+03	32800.00
77A150	2017-08-05 15:22:00+03	59000.00
77A168	2017-08-02 10:06:00+03	46200.00
77A1AF	2017-07-14 06:30:00+03	149400.00
77A1BC	2017-08-04 20:23:00+03	150000.00
77A277	2017-07-05 15:49:00+03	12700.00
77A298	2017-07-12 11:18:00+03	7400.00
77A339	2017-08-05 19:19:00+03	24600.00
77A3A2	2017-07-23 06:59:00+03	46200.00
77A3F5	2017-08-06 17:26:00+03	24400.00
77A43A	2017-07-05 12:23:00+03	236000.00
77A46E	2017-07-21 15:50:00+03	139300.00
77A4AD	2017-07-16 16:53:00+03	14800.00
77A4D7	2017-07-13 02:11:00+03	40200.00
77A53F	2017-08-03 02:09:00+03	44000.00
77A588	2017-07-22 14:31:00+03	20200.00
77A5AC	2017-07-27 21:26:00+03	88500.00
77A615	2017-08-06 11:39:00+03	270600.00
77A623	2017-08-01 02:11:00+03	56900.00
77A626	2017-07-03 03:46:00+03	47100.00
77A653	2017-08-15 07:16:00+03	45200.00
77A6C2	2017-06-29 17:04:00+03	16800.00
77A6C9	2017-08-07 07:54:00+03	83500.00
77A6DC	2017-08-09 07:47:00+03	125000.00
77A711	2017-07-11 06:18:00+03	111600.00
77A793	2017-07-12 01:33:00+03	46400.00
77A7B1	2017-07-20 09:47:00+03	28400.00
77A886	2017-08-02 12:05:00+03	24200.00
77A909	2017-07-30 12:11:00+03	228900.00
77A930	2017-07-01 13:06:00+03	148200.00
77A982	2017-08-11 11:53:00+03	38400.00
77A9C4	2017-07-19 21:16:00+03	123000.00
77A9D3	2017-08-03 00:01:00+03	62600.00
77AAF3	2017-07-14 21:53:00+03	58800.00
77AB2F	2017-08-11 08:08:00+03	81300.00
77AB7A	2017-08-15 01:49:00+03	12600.00
77AB8B	2017-07-01 08:27:00+03	23200.00
77ABB6	2017-07-24 22:54:00+03	27700.00
77ABCF	2017-07-31 14:47:00+03	159800.00
77ABE2	2017-07-16 00:36:00+03	270200.00
77ABE7	2017-08-10 13:09:00+03	43200.00
77AC17	2017-07-28 03:16:00+03	38600.00
77AC2A	2017-07-08 08:07:00+03	9800.00
77AC69	2017-07-09 05:56:00+03	19600.00
77AC6C	2017-08-12 03:03:00+03	12600.00
77AC6E	2017-07-28 16:20:00+03	274200.00
77AC7D	2017-07-27 10:27:00+03	78600.00
77AD02	2017-07-10 03:05:00+03	27600.00
77AD0E	2017-07-25 10:38:00+03	94700.00
77AD13	2017-07-23 17:25:00+03	38600.00
77ADBA	2017-07-25 10:56:00+03	64500.00
77ADC9	2017-07-07 12:29:00+03	26000.00
77AE08	2017-07-19 09:26:00+03	22000.00
77AE12	2017-08-04 03:05:00+03	38600.00
77AE70	2017-08-04 04:52:00+03	31600.00
77AEB9	2017-07-08 01:04:00+03	55800.00
77AED5	2017-08-01 03:10:00+03	13400.00
77AF05	2017-07-12 14:25:00+03	33400.00
77AF16	2017-07-29 02:02:00+03	16400.00
77AF5A	2017-07-17 07:35:00+03	66600.00
77AF81	2017-07-05 17:41:00+03	136800.00
77AFBE	2017-07-24 23:46:00+03	103200.00
77AFC5	2017-07-10 00:05:00+03	153600.00
77AFCF	2017-08-04 11:45:00+03	55500.00
77AFD8	2017-07-13 17:50:00+03	67600.00
77AFE0	2017-07-02 09:08:00+03	19600.00
77B029	2017-07-27 04:01:00+03	138400.00
77B08D	2017-07-06 08:49:00+03	348100.00
77B09E	2017-07-31 20:27:00+03	25400.00
77B0FD	2017-08-09 03:59:00+03	23200.00
77B16E	2017-07-27 11:35:00+03	258400.00
77B237	2017-07-30 22:37:00+03	26800.00
77B269	2017-08-14 18:26:00+03	25200.00
77B27F	2017-08-05 03:35:00+03	66600.00
77B2A5	2017-07-16 12:11:00+03	26700.00
77B2DC	2017-07-25 15:37:00+03	21400.00
77B2F4	2017-08-11 01:03:00+03	46000.00
77B37F	2017-07-06 11:16:00+03	21400.00
77B390	2017-08-10 02:32:00+03	226400.00
77B392	2017-07-05 09:39:00+03	23200.00
77B3A2	2017-07-24 06:08:00+03	38200.00
77B3D0	2017-07-20 12:06:00+03	133200.00
77B4C5	2017-08-05 04:16:00+03	37200.00
77B4C7	2017-08-07 18:26:00+03	23200.00
77B4F2	2017-08-08 02:47:00+03	42400.00
77B4F3	2017-07-12 08:12:00+03	45100.00
77B513	2017-07-19 09:46:00+03	46300.00
77B527	2017-07-02 08:40:00+03	74100.00
77B554	2017-07-29 04:33:00+03	169200.00
77B598	2017-08-08 12:48:00+03	28300.00
77B5AB	2017-07-20 06:58:00+03	56000.00
77B635	2017-07-21 16:16:00+03	291100.00
77B638	2017-06-30 13:43:00+03	46200.00
77B664	2017-07-24 16:03:00+03	44600.00
77B669	2017-08-04 20:21:00+03	26800.00
77B67D	2017-07-25 03:04:00+03	249200.00
77B69A	2017-07-15 16:27:00+03	67100.00
77B6BD	2017-07-09 14:26:00+03	94800.00
77B729	2017-07-10 11:47:00+03	137600.00
77B777	2017-06-29 14:40:00+03	92800.00
77B813	2017-07-03 09:42:00+03	13400.00
77B835	2017-07-12 04:13:00+03	88900.00
77B869	2017-08-02 02:03:00+03	86800.00
77B87A	2017-07-12 21:18:00+03	18600.00
77B88C	2017-08-11 03:38:00+03	49700.00
77B892	2017-07-01 23:00:00+03	406700.00
77B8B0	2017-08-06 04:31:00+03	62600.00
77B914	2017-08-13 22:41:00+03	29400.00
77B91B	2017-08-07 11:21:00+03	23400.00
77B921	2017-07-08 03:30:00+03	69900.00
77B93C	2017-07-22 04:43:00+03	129700.00
77B97A	2017-07-03 01:39:00+03	40000.00
77BAC4	2017-08-07 08:29:00+03	59300.00
77BAE5	2017-07-30 16:03:00+03	136400.00
77BC0E	2017-08-10 17:32:00+03	93600.00
77BC8D	2017-08-13 20:30:00+03	13400.00
77BC91	2017-07-16 04:05:00+03	47200.00
77BCD3	2017-07-18 17:15:00+03	46300.00
77BCF2	2017-07-06 01:03:00+03	133200.00
77BCF4	2017-07-27 08:04:00+03	93500.00
77BD78	2017-07-20 12:05:00+03	135200.00
77BDC2	2017-08-01 20:51:00+03	43800.00
77BE6C	2017-07-10 13:39:00+03	139600.00
77BE9C	2017-07-12 09:34:00+03	139400.00
77BF23	2017-08-13 22:42:00+03	93800.00
77BF40	2017-07-17 20:17:00+03	201800.00
77BFEA	2017-07-29 13:28:00+03	124200.00
77BFF9	2017-07-03 05:50:00+03	46400.00
77C066	2017-07-14 11:02:00+03	51300.00
77C06D	2017-08-10 07:40:00+03	49200.00
77C080	2017-07-31 13:10:00+03	136800.00
77C08A	2017-07-21 09:01:00+03	92900.00
77C09F	2017-07-18 08:52:00+03	13400.00
77C0AA	2017-08-05 16:48:00+03	20900.00
77C0DD	2017-07-24 18:19:00+03	96800.00
77C147	2017-07-17 13:21:00+03	21800.00
77C148	2017-07-23 20:34:00+03	122300.00
77C173	2017-07-14 11:27:00+03	24600.00
77C1A1	2017-07-16 07:33:00+03	43600.00
77C24C	2017-08-10 09:47:00+03	18100.00
77C25D	2017-08-15 08:06:00+03	175200.00
77C277	2017-07-15 10:30:00+03	112000.00
77C287	2017-06-30 02:10:00+03	52000.00
77C2AA	2017-07-11 06:34:00+03	120700.00
77C2AD	2017-07-08 03:50:00+03	372000.00
77C2BD	2017-07-08 18:24:00+03	56600.00
77C342	2017-07-14 04:57:00+03	38600.00
77C390	2017-08-12 01:39:00+03	50700.00
77C394	2017-07-20 02:18:00+03	37700.00
77C3AB	2017-07-13 04:26:00+03	58900.00
77C4A8	2017-07-17 02:14:00+03	83000.00
77C4B2	2017-07-16 00:38:00+03	84100.00
77C50D	2017-07-22 20:49:00+03	20200.00
77C510	2017-07-04 19:46:00+03	11600.00
77C54C	2017-07-16 07:54:00+03	125400.00
77C564	2017-07-11 00:24:00+03	166000.00
77C5B3	2017-07-12 04:53:00+03	58000.00
77C5CA	2017-07-14 08:04:00+03	286100.00
77C5CE	2017-07-04 00:38:00+03	50400.00
77C6BD	2017-08-04 22:25:00+03	66600.00
77C6CC	2017-07-08 06:36:00+03	79200.00
77C6E3	2017-07-19 02:33:00+03	46400.00
77C71D	2017-07-21 11:03:00+03	257500.00
77C793	2017-07-05 07:31:00+03	48800.00
77C81C	2017-08-07 02:44:00+03	23200.00
77C8D5	2017-07-06 16:38:00+03	162600.00
77C903	2017-08-13 14:10:00+03	92000.00
77C923	2017-08-14 06:44:00+03	50800.00
77C924	2017-07-07 02:32:00+03	28000.00
77C92F	2017-07-15 05:53:00+03	7200.00
77C9DE	2017-08-03 19:27:00+03	123000.00
77CA0F	2017-07-06 20:25:00+03	22000.00
77CA31	2017-07-25 21:35:00+03	50600.00
77CA97	2017-07-02 13:28:00+03	46200.00
77CAA0	2017-08-10 08:28:00+03	65500.00
77CB2F	2017-08-13 17:09:00+03	81500.00
77CB8C	2017-07-21 09:17:00+03	56600.00
77CBA0	2017-07-13 00:26:00+03	12000.00
77CBEB	2017-07-28 00:52:00+03	131100.00
77CC26	2017-08-10 12:42:00+03	25600.00
77CC34	2017-06-29 22:47:00+03	157100.00
77CC60	2017-07-18 12:37:00+03	94200.00
77CC75	2017-07-29 06:45:00+03	48800.00
77CCA7	2017-07-12 16:46:00+03	47000.00
77CCE2	2017-08-08 17:36:00+03	119500.00
77CD15	2017-08-07 07:09:00+03	92400.00
77CD87	2017-08-12 05:32:00+03	150600.00
77CDF4	2017-07-24 22:25:00+03	185800.00
77CE09	2017-07-31 09:55:00+03	93500.00
77CE30	2017-07-09 20:18:00+03	226200.00
77CE62	2017-08-11 06:40:00+03	64700.00
77CEA3	2017-07-27 07:19:00+03	24400.00
77CEDA	2017-07-15 19:12:00+03	84700.00
77CEF9	2017-07-02 21:51:00+03	111900.00
77CF57	2017-07-05 23:42:00+03	135300.00
77CF61	2017-08-13 19:58:00+03	46300.00
77CF6D	2017-07-16 19:17:00+03	56100.00
77CFA1	2017-07-21 01:26:00+03	59000.00
77CFAF	2017-08-06 16:32:00+03	61800.00
77CFC3	2017-07-15 14:28:00+03	30900.00
77D011	2017-07-05 16:24:00+03	22000.00
77D036	2017-07-30 04:38:00+03	14400.00
77D04C	2017-07-22 04:18:00+03	29100.00
77D0D2	2017-07-22 20:54:00+03	31700.00
77D0FB	2017-08-12 13:01:00+03	20200.00
77D154	2017-08-01 23:59:00+03	37900.00
77D16C	2017-08-13 19:18:00+03	75300.00
77D1D1	2017-07-15 17:00:00+03	13800.00
77D1D4	2017-07-16 17:57:00+03	51900.00
77D2B7	2017-07-05 10:17:00+03	94000.00
77D350	2017-08-11 20:40:00+03	46300.00
77D356	2017-07-31 05:51:00+03	46000.00
77D363	2017-07-31 13:10:00+03	56100.00
77D3C1	2017-07-22 16:54:00+03	55800.00
77D3C6	2017-08-02 15:54:00+03	28000.00
77D3CD	2017-07-18 17:00:00+03	83000.00
77D3FA	2017-07-01 12:09:00+03	12400.00
77D422	2017-07-30 22:50:00+03	75900.00
77D4B2	2017-07-05 22:27:00+03	51300.00
77D4E1	2017-07-12 10:11:00+03	24400.00
77D4F3	2017-07-21 09:46:00+03	248300.00
77D54D	2017-07-10 01:48:00+03	79200.00
77D563	2017-07-11 06:02:00+03	85000.00
77D57F	2017-08-15 00:09:00+03	39700.00
77D595	2017-08-14 09:34:00+03	46000.00
77D5CE	2017-07-12 19:02:00+03	23600.00
77D6C7	2017-07-22 20:51:00+03	63500.00
77D6F8	2017-07-21 06:38:00+03	40300.00
77D70B	2017-07-30 17:28:00+03	40800.00
77D715	2017-07-01 06:29:00+03	31400.00
77D730	2017-08-11 18:54:00+03	93900.00
77D8DF	2017-07-09 19:01:00+03	34100.00
77D95E	2017-08-10 12:59:00+03	50800.00
77D99C	2017-07-14 15:31:00+03	125200.00
77D9D9	2017-07-25 10:50:00+03	27400.00
77DA20	2017-08-06 17:54:00+03	81300.00
77DA24	2017-07-02 10:57:00+03	99200.00
77DA41	2017-06-30 19:25:00+03	37200.00
77DA64	2017-07-14 10:46:00+03	118400.00
77DA6A	2017-07-21 23:22:00+03	37900.00
77DA96	2017-06-30 07:48:00+03	52000.00
77DAD9	2017-07-24 07:06:00+03	214000.00
77DC66	2017-07-07 11:20:00+03	12400.00
77DCF8	2017-08-07 05:25:00+03	75300.00
77DD1B	2017-07-26 06:35:00+03	19600.00
77DD29	2017-08-13 19:07:00+03	112000.00
77DD58	2017-08-09 08:06:00+03	491000.00
77DD93	2017-07-30 20:45:00+03	28800.00
77DDAC	2017-08-03 09:53:00+03	6300.00
77DDF7	2017-06-28 16:12:00+03	42800.00
77DDFC	2017-07-03 18:45:00+03	117700.00
77DE0C	2017-07-21 23:53:00+03	48800.00
77DE85	2017-07-23 17:39:00+03	65900.00
77DEB8	2017-07-17 16:32:00+03	47200.00
77DEFF	2017-07-20 01:35:00+03	96800.00
77DF2B	2017-07-11 19:51:00+03	14400.00
77DF32	2017-08-11 11:31:00+03	93900.00
77DF34	2017-07-09 06:42:00+03	84100.00
77DF38	2017-08-08 20:49:00+03	136600.00
77DF58	2017-07-28 17:24:00+03	50300.00
77DF5A	2017-07-24 16:42:00+03	115600.00
77DF76	2017-08-12 05:57:00+03	17200.00
77E022	2017-08-06 07:07:00+03	12400.00
77E03C	2017-07-11 15:29:00+03	214900.00
77E081	2017-07-19 16:52:00+03	60000.00
77E0CC	2017-08-06 10:44:00+03	172300.00
77E102	2017-07-05 02:33:00+03	31600.00
77E15B	2017-07-21 19:38:00+03	8400.00
77E166	2017-07-12 03:34:00+03	38600.00
77E241	2017-08-04 23:12:00+03	24400.00
77E275	2017-08-02 16:30:00+03	58600.00
77E277	2017-07-09 00:46:00+03	123000.00
77E2D0	2017-07-12 23:55:00+03	130400.00
77E2FF	2017-08-14 18:37:00+03	78100.00
77E340	2017-07-04 00:09:00+03	23200.00
77E341	2017-07-28 11:21:00+03	380200.00
77E351	2017-08-05 15:01:00+03	42600.00
77E36B	2017-07-15 21:19:00+03	43600.00
77E373	2017-08-12 07:11:00+03	35300.00
77E383	2017-07-01 10:59:00+03	93900.00
77E3DE	2017-08-08 15:24:00+03	166800.00
77E3FB	2017-08-07 19:33:00+03	114300.00
77E43F	2017-08-07 23:24:00+03	99300.00
77E490	2017-06-27 02:33:00+03	28000.00
77E513	2017-07-12 07:35:00+03	44400.00
77E528	2017-08-03 19:16:00+03	141200.00
77E56B	2017-07-14 20:38:00+03	26000.00
77E5F6	2017-08-01 01:47:00+03	28000.00
77E60F	2017-07-28 05:38:00+03	59800.00
77E696	2017-07-21 15:54:00+03	10100.00
77E6DE	2017-07-31 13:08:00+03	85000.00
77E741	2017-07-15 17:45:00+03	103500.00
77E758	2017-07-24 04:07:00+03	94700.00
77E7B4	2017-08-13 05:44:00+03	75300.00
77E828	2017-07-21 18:14:00+03	143800.00
77E8F1	2017-07-26 08:41:00+03	28800.00
77E915	2017-07-30 02:38:00+03	33300.00
77E94D	2017-08-12 06:46:00+03	278600.00
77E999	2017-07-18 15:39:00+03	24400.00
77E9B9	2017-08-13 12:24:00+03	106400.00
77EA23	2017-07-03 14:34:00+03	252200.00
77EA73	2017-08-07 02:01:00+03	96800.00
77EAD9	2017-08-01 10:31:00+03	19600.00
77EADF	2017-07-27 07:47:00+03	246000.00
77EB3A	2017-07-11 04:55:00+03	48800.00
77EC29	2017-07-20 04:00:00+03	111000.00
77EC6F	2017-07-27 11:43:00+03	22400.00
77ECF4	2017-07-04 21:59:00+03	111600.00
77ED07	2017-08-12 16:39:00+03	54800.00
77EDB7	2017-08-13 03:06:00+03	29800.00
77EDC6	2017-08-06 20:24:00+03	156500.00
77EDFB	2017-07-10 14:28:00+03	23600.00
77EE09	2017-08-03 23:09:00+03	166900.00
77EE36	2017-08-11 16:10:00+03	38400.00
77EEA8	2017-07-16 04:24:00+03	123000.00
77EEAE	2017-08-08 04:11:00+03	30400.00
77EEC4	2017-08-06 03:47:00+03	111600.00
77EF17	2017-07-07 01:03:00+03	35200.00
77EF39	2017-08-01 15:22:00+03	55800.00
77EF59	2017-07-18 20:57:00+03	6700.00
77EF68	2017-07-25 18:15:00+03	103100.00
77EF89	2017-08-03 10:00:00+03	30900.00
77EFFB	2017-08-05 05:01:00+03	25100.00
77F02D	2017-07-24 08:04:00+03	12000.00
77F0B2	2017-07-24 12:08:00+03	46000.00
77F0CD	2017-07-09 10:34:00+03	119500.00
77F0EF	2017-07-23 03:31:00+03	7400.00
77F0F7	2017-07-10 23:52:00+03	258000.00
77F102	2017-07-22 20:17:00+03	59800.00
77F106	2017-07-01 05:09:00+03	147700.00
77F10E	2017-07-15 14:07:00+03	78100.00
77F11C	2017-07-08 03:34:00+03	101100.00
77F19B	2017-07-14 12:29:00+03	31600.00
77F1B5	2017-07-25 23:39:00+03	80400.00
77F1B9	2017-07-19 23:34:00+03	42600.00
77F1D5	2017-07-23 11:23:00+03	56000.00
77F1E6	2017-07-22 08:28:00+03	56000.00
77F247	2017-08-01 11:18:00+03	28000.00
77F254	2017-07-14 15:14:00+03	13400.00
77F286	2017-07-04 06:54:00+03	173400.00
77F307	2017-08-14 01:38:00+03	103200.00
77F318	2017-07-12 02:37:00+03	36200.00
77F358	2017-08-03 10:25:00+03	27000.00
77F39C	2017-07-08 21:56:00+03	170700.00
77F3B9	2017-07-20 22:58:00+03	151300.00
77F3FC	2017-06-28 10:48:00+03	45200.00
77F4A6	2017-07-20 16:36:00+03	40000.00
77F4E4	2017-07-25 23:28:00+03	14800.00
77F50D	2017-07-08 09:50:00+03	89200.00
77F51B	2017-08-14 13:55:00+03	28200.00
77F54E	2017-07-17 08:30:00+03	12600.00
77F567	2017-07-19 01:50:00+03	40600.00
77F595	2017-07-08 16:43:00+03	94800.00
77F5A5	2017-07-09 16:41:00+03	61500.00
77F5AB	2017-07-07 16:33:00+03	48600.00
77F5DC	2017-07-21 07:40:00+03	126300.00
77F5DD	2017-07-31 15:27:00+03	121200.00
77F5E3	2017-07-26 22:39:00+03	24000.00
77F5EC	2017-07-12 09:09:00+03	135400.00
77F676	2017-07-01 02:28:00+03	55800.00
77F682	2017-07-06 01:51:00+03	24500.00
77F6FD	2017-07-09 07:18:00+03	33200.00
77F7A4	2017-06-26 07:26:00+03	146300.00
77F7B9	2017-07-05 01:47:00+03	62600.00
77F7DC	2017-07-11 13:02:00+03	91600.00
77F803	2017-07-18 05:34:00+03	27200.00
77F839	2017-08-11 11:06:00+03	70700.00
77F8E3	2017-07-23 07:01:00+03	43200.00
77F8EE	2017-07-01 03:58:00+03	86600.00
77F8F8	2017-07-24 08:43:00+03	89600.00
77F902	2017-07-02 12:13:00+03	28000.00
77F98F	2017-07-28 03:52:00+03	26000.00
77F997	2017-07-11 06:00:00+03	40600.00
77F9A6	2017-07-18 00:27:00+03	49100.00
77FA3C	2017-08-11 11:05:00+03	44000.00
77FA6C	2017-07-28 07:37:00+03	44000.00
77FA86	2017-07-19 13:09:00+03	28800.00
77FA9A	2017-07-25 05:16:00+03	289800.00
77FABD	2017-08-05 16:46:00+03	40800.00
77FAF4	2017-07-14 20:10:00+03	26800.00
77FB07	2017-07-28 03:49:00+03	46400.00
77FB54	2017-08-08 15:24:00+03	24400.00
77FC05	2017-08-12 23:38:00+03	83600.00
77FC7E	2017-07-13 07:21:00+03	14400.00
77FC82	2017-07-21 08:37:00+03	12600.00
77FC95	2017-08-04 11:04:00+03	62600.00
77FCEA	2017-07-16 17:40:00+03	61800.00
77FD20	2017-07-11 02:21:00+03	105000.00
77FD42	2017-08-12 21:28:00+03	39800.00
77FD45	2017-07-23 11:22:00+03	37700.00
77FDA8	2017-07-30 11:40:00+03	257600.00
77FE01	2017-07-14 05:08:00+03	58600.00
77FE28	2017-08-06 02:30:00+03	47200.00
77FE68	2017-08-15 16:49:00+03	6000.00
77FE8E	2017-08-04 01:44:00+03	46000.00
77FEEE	2017-07-24 11:51:00+03	64700.00
77FEF4	2017-07-24 07:10:00+03	28800.00
77FF5D	2017-07-30 20:15:00+03	29400.00
77FF73	2017-07-04 21:04:00+03	20600.00
77FFCE	2017-07-03 11:52:00+03	23200.00
780014	2017-07-10 23:37:00+03	49100.00
780042	2017-07-03 04:04:00+03	6700.00
780091	2017-07-26 09:37:00+03	41300.00
7800FB	2017-07-26 11:21:00+03	118400.00
7801C5	2017-07-19 13:55:00+03	65900.00
7801DA	2017-07-06 08:56:00+03	15000.00
780206	2017-07-04 10:28:00+03	53300.00
780209	2017-07-20 16:05:00+03	34000.00
78021B	2017-08-11 20:30:00+03	68900.00
780244	2017-08-12 09:24:00+03	27900.00
780245	2017-07-14 19:17:00+03	7400.00
78025A	2017-07-04 11:31:00+03	55800.00
7802B5	2017-07-09 17:52:00+03	58600.00
7802C5	2017-07-24 05:46:00+03	99300.00
780347	2017-08-12 03:02:00+03	21800.00
780350	2017-07-07 12:25:00+03	44800.00
780364	2017-08-07 20:58:00+03	89600.00
780375	2017-07-10 03:42:00+03	6800.00
780381	2017-07-27 07:00:00+03	112000.00
7803C2	2017-07-19 14:18:00+03	87200.00
780454	2017-07-27 13:58:00+03	65300.00
780478	2017-08-12 07:05:00+03	47200.00
780496	2017-07-06 05:15:00+03	187900.00
780581	2017-07-08 18:02:00+03	124200.00
780608	2017-07-26 03:03:00+03	15000.00
780639	2017-08-09 04:02:00+03	55400.00
78063F	2017-08-09 23:38:00+03	65900.00
780657	2017-07-28 08:04:00+03	131100.00
780662	2017-07-20 09:01:00+03	22000.00
780664	2017-08-15 01:10:00+03	6200.00
78066B	2017-07-04 18:57:00+03	44600.00
78069D	2017-08-10 01:52:00+03	39500.00
7806E8	2017-07-21 22:53:00+03	150600.00
7806F9	2017-07-29 03:57:00+03	32200.00
780708	2017-08-04 02:15:00+03	16400.00
78070D	2017-08-01 07:03:00+03	25900.00
78071E	2017-07-09 00:17:00+03	28800.00
780754	2017-08-09 14:56:00+03	73300.00
780758	2017-07-16 08:43:00+03	57600.00
780786	2017-07-12 07:06:00+03	49800.00
7807B9	2017-07-05 07:57:00+03	45400.00
7807C7	2017-07-19 00:52:00+03	136600.00
7807E7	2017-07-02 01:20:00+03	246000.00
780800	2017-07-25 00:28:00+03	172200.00
78080B	2017-08-09 22:35:00+03	41400.00
7808A6	2017-07-18 04:32:00+03	117200.00
7808EE	2017-07-06 01:21:00+03	46400.00
780904	2017-07-11 19:03:00+03	56600.00
7809B0	2017-08-15 01:05:00+03	67200.00
7809E6	2017-08-06 05:04:00+03	146500.00
780B11	2017-07-25 10:44:00+03	106100.00
780B5D	2017-07-31 20:06:00+03	67700.00
780B6A	2017-07-01 04:20:00+03	168000.00
780BD4	2017-06-28 20:02:00+03	66600.00
780C2B	2017-07-02 04:29:00+03	13400.00
780CA4	2017-08-11 09:06:00+03	29600.00
780D9F	2017-07-09 14:13:00+03	37200.00
780E5A	2017-07-01 21:12:00+03	51800.00
780E80	2017-07-11 22:19:00+03	26800.00
780EDF	2017-06-27 06:58:00+03	31900.00
780F1F	2017-07-25 02:51:00+03	37900.00
780F4D	2017-08-11 11:10:00+03	70800.00
780FB9	2017-08-03 00:47:00+03	111600.00
781016	2017-08-06 22:08:00+03	6800.00
781042	2017-07-27 00:24:00+03	79600.00
781064	2017-07-04 12:24:00+03	10600.00
7811F0	2017-07-06 21:54:00+03	97700.00
7812DD	2017-08-07 13:01:00+03	10800.00
7812F5	2017-07-29 16:12:00+03	58400.00
7812FF	2017-07-05 22:17:00+03	38400.00
781331	2017-07-06 11:07:00+03	46400.00
78134D	2017-08-02 16:54:00+03	375200.00
781369	2017-07-16 10:31:00+03	73500.00
78136F	2017-07-26 23:59:00+03	27200.00
78137E	2017-07-22 09:53:00+03	66600.00
781391	2017-07-03 04:19:00+03	37900.00
781408	2017-08-03 15:29:00+03	55800.00
781427	2017-07-13 11:02:00+03	37700.00
781453	2017-08-09 11:22:00+03	156300.00
781455	2017-07-13 15:06:00+03	55800.00
781477	2017-07-16 23:53:00+03	217000.00
7814CC	2017-08-07 20:27:00+03	271100.00
781511	2017-07-05 06:43:00+03	88600.00
781515	2017-08-05 14:18:00+03	56000.00
781519	2017-07-14 11:47:00+03	48700.00
78154D	2017-07-06 07:35:00+03	103000.00
781565	2017-07-11 00:11:00+03	88400.00
7815A9	2017-07-04 15:00:00+03	38200.00
78166B	2017-08-05 01:39:00+03	189200.00
781690	2017-07-29 10:00:00+03	169900.00
7816B3	2017-08-04 05:39:00+03	47500.00
7816EA	2017-07-13 05:14:00+03	14400.00
781723	2017-07-10 23:46:00+03	46400.00
781743	2017-07-18 23:50:00+03	6300.00
781753	2017-07-23 11:12:00+03	28800.00
78177F	2017-07-17 14:49:00+03	97500.00
781783	2017-07-12 21:08:00+03	75300.00
781799	2017-08-05 07:48:00+03	38600.00
7817AD	2017-07-09 04:55:00+03	28300.00
7817E5	2017-07-21 00:56:00+03	20000.00
7817FC	2017-08-13 11:02:00+03	62500.00
781802	2017-07-21 17:19:00+03	43600.00
781830	2017-07-15 16:31:00+03	26000.00
7818B1	2017-07-10 00:17:00+03	69600.00
781908	2017-08-12 19:15:00+03	288500.00
781912	2017-07-13 21:19:00+03	46300.00
781937	2017-07-09 19:58:00+03	66800.00
781945	2017-07-17 10:08:00+03	270800.00
781969	2017-07-28 02:53:00+03	6000.00
781991	2017-07-11 00:12:00+03	123000.00
781A11	2017-07-28 01:26:00+03	34000.00
781AAB	2017-07-25 07:01:00+03	23400.00
781ADB	2017-08-08 14:16:00+03	52000.00
781AFB	2017-07-15 06:38:00+03	77200.00
781B3A	2017-07-14 01:01:00+03	88500.00
781B56	2017-08-02 06:41:00+03	57800.00
781B58	2017-07-06 23:50:00+03	248300.00
781BBE	2017-07-09 17:29:00+03	26800.00
781C53	2017-07-05 21:33:00+03	137600.00
781CDE	2017-07-28 07:32:00+03	126200.00
781CE0	2017-07-12 09:08:00+03	100600.00
781CEC	2017-08-13 01:41:00+03	36200.00
781D20	2017-07-07 04:53:00+03	35800.00
781D2C	2017-07-26 03:40:00+03	102100.00
781D51	2017-07-02 20:26:00+03	56000.00
781E08	2017-07-11 04:18:00+03	54800.00
781E40	2017-08-06 00:19:00+03	55800.00
781E4F	2017-07-18 03:45:00+03	47000.00
781E6E	2017-07-10 16:04:00+03	25100.00
781EA7	2017-08-10 05:49:00+03	252200.00
781EBC	2017-07-12 23:50:00+03	153300.00
781ECA	2017-08-12 10:38:00+03	15000.00
781ED1	2017-07-31 17:52:00+03	136200.00
781F15	2017-08-06 21:15:00+03	55500.00
781F38	2017-08-10 17:55:00+03	100000.00
781F42	2017-07-21 15:46:00+03	28000.00
781F4D	2017-08-09 11:37:00+03	46300.00
781F5B	2017-07-06 03:17:00+03	14000.00
781FF3	2017-07-20 11:21:00+03	82900.00
782031	2017-08-06 16:40:00+03	10600.00
78203E	2017-07-09 04:13:00+03	24400.00
7820A4	2017-07-26 11:44:00+03	80200.00
7820A5	2017-08-12 13:26:00+03	56600.00
7820A6	2017-08-09 07:29:00+03	103500.00
782117	2017-07-30 14:40:00+03	100600.00
78214C	2017-08-15 06:19:00+03	44800.00
782150	2017-08-11 03:54:00+03	51900.00
7821E7	2017-08-10 15:16:00+03	36400.00
7821EC	2017-08-04 07:05:00+03	266400.00
78229B	2017-07-15 03:07:00+03	91200.00
7822E6	2017-07-05 19:34:00+03	246000.00
78237C	2017-08-12 04:03:00+03	22000.00
7823C8	2017-07-26 02:09:00+03	68400.00
7823F4	2017-07-22 19:35:00+03	9000.00
7824DC	2017-08-02 18:44:00+03	28000.00
782509	2017-07-09 23:20:00+03	93800.00
78252E	2017-07-26 05:30:00+03	8400.00
78256F	2017-07-13 08:20:00+03	32800.00
782577	2017-07-13 18:19:00+03	92800.00
78257D	2017-07-29 07:23:00+03	58100.00
7825BC	2017-07-06 13:51:00+03	406100.00
7825D0	2017-08-13 03:41:00+03	69500.00
7825D5	2017-07-13 11:38:00+03	23600.00
78262A	2017-07-18 22:01:00+03	28000.00
782673	2017-07-25 14:02:00+03	121800.00
782737	2017-07-02 23:01:00+03	46300.00
782754	2017-08-15 15:31:00+03	38400.00
78275E	2017-08-10 03:23:00+03	69500.00
782766	2017-07-24 01:00:00+03	48800.00
782774	2017-07-10 06:16:00+03	72400.00
782799	2017-07-02 11:06:00+03	40600.00
782838	2017-08-03 14:46:00+03	49000.00
782850	2017-07-06 12:20:00+03	94300.00
7828B0	2017-07-29 11:29:00+03	112000.00
7828C3	2017-08-08 14:54:00+03	51200.00
7828ED	2017-08-08 10:02:00+03	135600.00
78294F	2017-07-27 02:10:00+03	28800.00
7829C0	2017-08-14 21:08:00+03	41200.00
7829D6	2017-08-11 00:59:00+03	40100.00
7829DB	2017-07-05 17:20:00+03	44000.00
782A50	2017-07-29 22:56:00+03	92400.00
782AC3	2017-07-28 08:20:00+03	195900.00
782ACE	2017-07-08 03:57:00+03	155600.00
782AD5	2017-08-10 17:29:00+03	126300.00
782AF9	2017-07-18 09:16:00+03	49900.00
782B46	2017-07-11 17:22:00+03	167200.00
782BA2	2017-07-18 16:54:00+03	59700.00
782C2B	2017-06-28 07:43:00+03	26700.00
782C4A	2017-07-06 18:14:00+03	38800.00
782C8B	2017-08-07 16:23:00+03	250500.00
782CEA	2017-08-10 03:39:00+03	7400.00
782CF0	2017-07-29 10:48:00+03	38800.00
782D76	2017-08-14 21:09:00+03	199300.00
782DC4	2017-08-13 09:38:00+03	93900.00
782DD6	2017-07-13 11:59:00+03	58800.00
782DF6	2017-07-14 04:30:00+03	22100.00
782E23	2017-06-29 00:26:00+03	15200.00
782E2C	2017-07-24 03:50:00+03	132800.00
782EFF	2017-08-09 08:45:00+03	14800.00
782F8B	2017-07-27 19:14:00+03	43400.00
782FFB	2017-07-03 21:19:00+03	133200.00
78302A	2017-08-02 15:25:00+03	58800.00
7830C2	2017-07-30 19:36:00+03	26000.00
7830CB	2017-06-30 07:57:00+03	173600.00
783167	2017-07-04 05:53:00+03	271100.00
783198	2017-07-30 23:11:00+03	26800.00
7831E1	2017-07-10 06:55:00+03	136600.00
783209	2017-08-13 16:51:00+03	108000.00
783227	2017-08-04 02:00:00+03	15800.00
78326A	2017-07-29 22:50:00+03	123100.00
783282	2017-08-05 15:32:00+03	52700.00
7832A0	2017-08-05 15:41:00+03	59300.00
7832EE	2017-07-07 00:09:00+03	32200.00
783314	2017-07-12 15:42:00+03	55500.00
783368	2017-07-24 23:03:00+03	103900.00
78337A	2017-08-13 18:41:00+03	13700.00
783398	2017-07-24 12:23:00+03	26000.00
78340C	2017-07-30 05:45:00+03	54800.00
783498	2017-07-27 07:20:00+03	54400.00
78349A	2017-07-21 12:08:00+03	28800.00
7834E9	2017-07-22 15:46:00+03	42800.00
783510	2017-08-11 22:07:00+03	57700.00
783516	2017-07-02 21:07:00+03	45200.00
783526	2017-07-06 09:36:00+03	38600.00
783566	2017-08-10 07:21:00+03	79400.00
78360C	2017-08-05 20:32:00+03	57100.00
7836B2	2017-08-03 03:04:00+03	248300.00
7836D0	2017-07-27 10:02:00+03	53700.00
7836DE	2017-08-06 10:41:00+03	91800.00
7837BA	2017-07-23 19:33:00+03	31600.00
7837D7	2017-07-11 18:44:00+03	50100.00
78382E	2017-08-04 17:36:00+03	52300.00
783865	2017-07-03 17:48:00+03	11600.00
783875	2017-08-07 20:26:00+03	139500.00
7838A4	2017-08-08 01:49:00+03	42800.00
7838C2	2017-07-13 13:10:00+03	136800.00
7838F8	2017-08-03 00:02:00+03	52000.00
783902	2017-07-29 01:01:00+03	109600.00
783993	2017-08-09 20:40:00+03	56000.00
7839A7	2017-06-30 06:35:00+03	82900.00
7839AB	2017-06-28 05:49:00+03	26000.00
7839D4	2017-07-15 16:36:00+03	200400.00
7839DF	2017-08-07 01:52:00+03	141700.00
783ACA	2017-07-01 23:01:00+03	28800.00
783B81	2017-08-09 10:17:00+03	65900.00
783B91	2017-08-11 08:44:00+03	142400.00
783BB7	2017-07-06 10:04:00+03	42800.00
783BC0	2017-07-19 04:35:00+03	21000.00
783C11	2017-07-03 02:29:00+03	58600.00
783C6B	2017-07-30 13:30:00+03	66000.00
783C84	2017-07-27 00:23:00+03	172800.00
783CBB	2017-06-30 07:13:00+03	65900.00
783D17	2017-07-19 12:52:00+03	6700.00
783D67	2017-07-22 13:52:00+03	18800.00
783D8C	2017-08-07 15:18:00+03	75200.00
783DEE	2017-07-19 23:49:00+03	47100.00
783E16	2017-08-05 19:55:00+03	149300.00
783E80	2017-08-11 17:36:00+03	44100.00
783F80	2017-07-12 09:16:00+03	84100.00
783FE5	2017-08-04 02:03:00+03	22000.00
784039	2017-07-24 12:17:00+03	111600.00
7840EB	2017-08-10 15:48:00+03	52000.00
78413D	2017-07-25 03:54:00+03	32700.00
7841CC	2017-07-17 02:20:00+03	111600.00
784278	2017-07-29 12:43:00+03	26000.00
7842F2	2017-07-02 07:46:00+03	46400.00
784314	2017-07-07 00:12:00+03	219300.00
784368	2017-07-18 17:49:00+03	44000.00
784394	2017-07-13 20:45:00+03	20000.00
784416	2017-07-24 06:41:00+03	38500.00
78444A	2017-06-28 04:37:00+03	59800.00
784485	2017-08-02 18:58:00+03	130500.00
7844AE	2017-07-22 06:09:00+03	7300.00
7844E0	2017-06-30 01:20:00+03	14400.00
784512	2017-08-03 17:57:00+03	86200.00
784542	2017-07-10 16:07:00+03	135000.00
784547	2017-07-06 18:49:00+03	145900.00
78454E	2017-07-17 06:00:00+03	28000.00
78457A	2017-07-25 21:00:00+03	31000.00
7846BD	2017-07-12 07:51:00+03	135400.00
7846C2	2017-07-13 10:36:00+03	46400.00
784703	2017-07-11 14:19:00+03	50600.00
784745	2017-07-14 16:15:00+03	77400.00
78475D	2017-07-11 11:43:00+03	32800.00
7847A2	2017-07-04 13:30:00+03	21000.00
7847EC	2017-07-22 08:23:00+03	6000.00
78482B	2017-08-12 05:30:00+03	56000.00
78482D	2017-07-30 07:04:00+03	62000.00
78485D	2017-07-24 16:13:00+03	53700.00
78485F	2017-08-12 07:05:00+03	25800.00
78486F	2017-07-09 18:30:00+03	10600.00
784894	2017-08-13 09:05:00+03	13400.00
784963	2017-08-06 21:25:00+03	121400.00
784987	2017-08-12 19:26:00+03	58100.00
7849F7	2017-07-14 23:18:00+03	179400.00
7849FC	2017-07-21 18:21:00+03	20200.00
784A05	2017-07-20 22:51:00+03	54000.00
784A20	2017-07-05 11:25:00+03	151800.00
784A22	2017-07-27 03:02:00+03	20100.00
784A2E	2017-07-11 15:14:00+03	37900.00
784A46	2017-07-30 15:07:00+03	43900.00
784ABC	2017-08-15 16:13:00+03	120100.00
784BEF	2017-07-28 13:12:00+03	55800.00
784C78	2017-07-08 17:12:00+03	21800.00
784C9A	2017-08-03 04:14:00+03	60800.00
784C9B	2017-07-31 03:07:00+03	265700.00
784CFF	2017-08-01 22:12:00+03	37200.00
784D3F	2017-07-22 18:50:00+03	65400.00
784D6F	2017-08-13 01:34:00+03	47100.00
784DB5	2017-07-27 01:47:00+03	161400.00
784DD7	2017-07-28 18:19:00+03	26000.00
784E28	2017-07-04 00:04:00+03	43200.00
784E8F	2017-07-15 10:24:00+03	106400.00
784E90	2017-07-27 12:07:00+03	14000.00
784E98	2017-07-16 12:28:00+03	69500.00
784EE9	2017-08-01 10:26:00+03	309700.00
784EEF	2017-07-22 19:22:00+03	36800.00
784F0F	2017-07-12 15:33:00+03	44000.00
784F43	2017-07-30 16:00:00+03	23200.00
784F83	2017-08-04 18:21:00+03	93900.00
784F9D	2017-07-22 22:49:00+03	281500.00
784FBF	2017-07-31 07:58:00+03	44500.00
785001	2017-07-18 18:10:00+03	6700.00
78501B	2017-08-02 23:02:00+03	26700.00
78505D	2017-07-02 20:14:00+03	200700.00
785080	2017-07-26 02:10:00+03	55800.00
7850C1	2017-07-01 17:40:00+03	21800.00
7850C2	2017-07-21 13:41:00+03	12600.00
785156	2017-07-18 10:48:00+03	19600.00
785239	2017-08-12 19:12:00+03	58000.00
785273	2017-07-16 13:07:00+03	131100.00
78536B	2017-08-01 13:14:00+03	28000.00
785385	2017-07-13 21:30:00+03	15000.00
78539C	2017-08-07 09:58:00+03	48300.00
7853BB	2017-07-16 10:04:00+03	96200.00
785422	2017-07-09 05:12:00+03	88100.00
785425	2017-08-09 02:57:00+03	70600.00
78549D	2017-08-13 18:27:00+03	117200.00
78556C	2017-07-31 10:40:00+03	23200.00
7855B5	2017-08-01 05:59:00+03	24000.00
7855B6	2017-07-21 19:57:00+03	61800.00
7855C9	2017-07-21 13:08:00+03	68800.00
785622	2017-07-09 00:00:00+03	43900.00
78562E	2017-08-15 14:51:00+03	85000.00
785651	2017-07-28 16:28:00+03	123000.00
785691	2017-07-10 14:39:00+03	6700.00
785694	2017-07-23 11:44:00+03	116900.00
78578D	2017-07-29 10:40:00+03	72400.00
7857A7	2017-07-27 08:59:00+03	24800.00
7857B4	2017-07-30 13:16:00+03	6000.00
78581B	2017-08-07 18:00:00+03	123000.00
785866	2017-08-08 00:46:00+03	62600.00
78587E	2017-07-09 18:09:00+03	73000.00
78589B	2017-07-24 13:19:00+03	192400.00
7858AB	2017-07-28 18:35:00+03	29600.00
785927	2017-07-03 22:28:00+03	33300.00
78595D	2017-08-08 09:59:00+03	60700.00
785969	2017-08-12 23:20:00+03	44000.00
7859C2	2017-07-29 03:51:00+03	51600.00
7859EF	2017-08-02 02:46:00+03	85000.00
785A5F	2017-07-17 13:30:00+03	46400.00
785A6A	2017-08-11 19:00:00+03	7800.00
785A85	2017-07-28 03:46:00+03	22600.00
785AA8	2017-08-04 08:31:00+03	130400.00
785B9F	2017-07-02 18:52:00+03	87200.00
785BC4	2017-07-14 10:58:00+03	182100.00
785BF2	2017-08-10 08:50:00+03	21800.00
785C7B	2017-07-29 12:57:00+03	16400.00
785D11	2017-07-23 07:17:00+03	65500.00
785D2F	2017-07-29 21:53:00+03	92200.00
785D4B	2017-07-04 07:05:00+03	144000.00
785D63	2017-08-13 10:23:00+03	157600.00
785DB7	2017-08-10 11:23:00+03	73100.00
785E02	2017-07-11 02:08:00+03	22100.00
785E5C	2017-07-31 15:24:00+03	43200.00
785EC2	2017-07-19 08:53:00+03	56200.00
785F12	2017-08-06 04:58:00+03	119600.00
785F76	2017-08-07 17:47:00+03	71400.00
785F9C	2017-07-13 01:38:00+03	21800.00
78605F	2017-07-13 14:48:00+03	26800.00
786060	2017-07-08 20:27:00+03	62800.00
7860BA	2017-08-09 01:07:00+03	150600.00
7860F7	2017-07-11 12:12:00+03	123900.00
786118	2017-07-06 22:43:00+03	6000.00
78611E	2017-07-14 20:10:00+03	131600.00
78612E	2017-07-29 23:54:00+03	24400.00
786197	2017-08-04 19:11:00+03	73500.00
7861A9	2017-07-02 18:01:00+03	18600.00
7861CD	2017-08-05 02:12:00+03	266400.00
78626A	2017-07-27 18:04:00+03	233700.00
7862B7	2017-07-26 17:48:00+03	34000.00
7862C2	2017-08-13 10:21:00+03	50100.00
7862F2	2017-07-11 04:55:00+03	135600.00
786344	2017-07-25 19:09:00+03	40400.00
786353	2017-08-02 04:48:00+03	48700.00
7863BF	2017-07-21 10:57:00+03	55800.00
7863F6	2017-08-07 19:29:00+03	50600.00
786437	2017-07-10 20:21:00+03	76800.00
786506	2017-07-04 05:25:00+03	57600.00
786577	2017-07-21 23:26:00+03	61500.00
78658C	2017-07-17 20:08:00+03	42600.00
7865D0	2017-07-05 13:51:00+03	92800.00
78660E	2017-08-06 03:56:00+03	75300.00
78662D	2017-07-29 02:44:00+03	113000.00
78664F	2017-07-19 09:01:00+03	23600.00
78667F	2017-08-13 00:34:00+03	78400.00
7866C4	2017-07-26 11:53:00+03	162600.00
78677F	2017-07-02 08:20:00+03	167400.00
78678A	2017-07-06 20:14:00+03	68400.00
7867A4	2017-08-14 06:08:00+03	125200.00
7867B8	2017-08-06 14:51:00+03	65400.00
7867D8	2017-07-20 09:47:00+03	440500.00
786811	2017-07-07 00:40:00+03	12200.00
786875	2017-08-08 07:57:00+03	123000.00
78688A	2017-07-21 14:03:00+03	24800.00
7868A4	2017-08-05 11:43:00+03	13400.00
7869AF	2017-07-06 21:27:00+03	12000.00
786A14	2017-08-14 00:38:00+03	70600.00
786ADC	2017-07-13 20:16:00+03	170200.00
786AEB	2017-07-16 20:04:00+03	12600.00
786AFA	2017-07-22 03:44:00+03	151200.00
786B81	2017-07-09 03:38:00+03	54000.00
786B98	2017-08-03 16:48:00+03	42800.00
786BB3	2017-07-20 04:07:00+03	117200.00
786BD0	2017-08-13 20:22:00+03	91100.00
786C04	2017-08-13 03:58:00+03	52400.00
786C18	2017-07-11 16:37:00+03	73500.00
786C4E	2017-07-19 16:02:00+03	28300.00
786C5D	2017-07-29 13:15:00+03	12600.00
786C9D	2017-08-11 16:26:00+03	18000.00
786CB2	2017-08-12 00:59:00+03	40300.00
786CCE	2017-08-11 08:46:00+03	55000.00
786D08	2017-08-14 09:52:00+03	30200.00
786D37	2017-07-21 06:20:00+03	18900.00
786D49	2017-07-06 14:02:00+03	75300.00
786D8A	2017-08-05 04:24:00+03	73500.00
786D90	2017-07-09 20:50:00+03	10700.00
786DBC	2017-08-08 09:29:00+03	91500.00
786E1A	2017-08-07 21:45:00+03	123000.00
786E2D	2017-07-18 17:37:00+03	136600.00
786E84	2017-07-24 08:51:00+03	18700.00
786EF7	2017-08-14 12:20:00+03	115900.00
786F3E	2017-08-11 04:59:00+03	109800.00
786F86	2017-07-11 08:42:00+03	123000.00
786F9E	2017-07-09 20:43:00+03	20400.00
786FB7	2017-08-02 08:09:00+03	28000.00
78704E	2017-08-02 01:06:00+03	9800.00
7870BA	2017-08-12 04:15:00+03	32800.00
787156	2017-07-14 00:04:00+03	56000.00
787209	2017-08-12 05:46:00+03	51000.00
787242	2017-07-13 19:03:00+03	32700.00
787265	2017-07-29 14:11:00+03	152500.00
7872D0	2017-07-05 10:58:00+03	28000.00
7872FC	2017-07-17 14:22:00+03	254900.00
78731B	2017-07-05 10:57:00+03	70700.00
78736E	2017-07-16 05:13:00+03	55500.00
7873CB	2017-07-27 05:06:00+03	60100.00
7873D1	2017-08-15 06:47:00+03	12600.00
787488	2017-06-27 01:05:00+03	23600.00
787494	2017-07-12 23:53:00+03	56900.00
78749C	2017-08-02 16:32:00+03	14000.00
7874E0	2017-07-25 16:21:00+03	43100.00
787510	2017-07-17 19:09:00+03	6800.00
78753A	2017-08-12 12:36:00+03	24000.00
78753C	2017-07-17 01:28:00+03	112000.00
7875FB	2017-07-24 17:17:00+03	271200.00
787600	2017-06-28 10:27:00+03	26000.00
787620	2017-07-07 14:38:00+03	56100.00
787622	2017-08-02 20:09:00+03	14400.00
787624	2017-07-20 16:12:00+03	30000.00
787679	2017-07-16 12:19:00+03	44800.00
7876DE	2017-06-30 18:08:00+03	74900.00
787712	2017-07-07 20:51:00+03	73600.00
787789	2017-07-20 01:43:00+03	95200.00
787815	2017-07-08 02:10:00+03	35200.00
787823	2017-07-12 22:47:00+03	14000.00
78785E	2017-07-15 16:48:00+03	16400.00
787888	2017-07-24 04:14:00+03	88900.00
7878C5	2017-08-14 22:44:00+03	246000.00
7878E0	2017-07-05 10:02:00+03	57600.00
78791F	2017-08-05 01:49:00+03	46200.00
7879A0	2017-07-03 18:43:00+03	23200.00
787A2F	2017-07-11 05:27:00+03	44600.00
787A9F	2017-07-15 07:48:00+03	265600.00
787AFA	2017-07-29 05:17:00+03	56000.00
787B79	2017-07-06 08:22:00+03	38900.00
787C0F	2017-08-15 09:45:00+03	20200.00
787C48	2017-08-05 16:52:00+03	147700.00
787C58	2017-07-20 21:46:00+03	69600.00
787C6A	2017-08-13 20:39:00+03	81300.00
787D0F	2017-07-13 18:48:00+03	22000.00
787DBD	2017-08-12 02:28:00+03	72800.00
787DDC	2017-07-30 12:29:00+03	199800.00
787DED	2017-08-09 04:57:00+03	121500.00
787E66	2017-08-12 17:30:00+03	90100.00
787E6D	2017-07-24 21:12:00+03	224000.00
787E8A	2017-07-26 01:50:00+03	256100.00
787EA0	2017-07-12 18:19:00+03	28800.00
787EA9	2017-07-08 17:39:00+03	19800.00
787EB3	2017-07-05 16:59:00+03	50800.00
787EE2	2017-08-13 13:41:00+03	101700.00
787F59	2017-08-08 19:54:00+03	67600.00
787FB2	2017-07-01 17:00:00+03	26700.00
787FE1	2017-07-07 00:11:00+03	15000.00
788059	2017-07-13 09:00:00+03	69500.00
788081	2017-07-06 05:47:00+03	32900.00
7880A5	2017-08-07 11:34:00+03	46000.00
7880BB	2017-08-09 19:46:00+03	135400.00
7880DC	2017-08-03 22:09:00+03	101500.00
788137	2017-07-17 15:07:00+03	276700.00
788139	2017-08-10 18:12:00+03	38800.00
78817B	2017-07-04 04:59:00+03	56000.00
78822B	2017-08-12 12:01:00+03	21800.00
788238	2017-07-07 22:51:00+03	123000.00
788255	2017-07-25 15:51:00+03	40000.00
7882E2	2017-07-11 21:38:00+03	131600.00
7882EB	2017-08-13 17:11:00+03	6700.00
788320	2017-07-25 15:10:00+03	47400.00
788388	2017-07-16 20:23:00+03	23600.00
7883F3	2017-08-12 23:19:00+03	42800.00
78841A	2017-07-21 15:02:00+03	47100.00
7884DB	2017-07-05 06:17:00+03	135600.00
78850A	2017-07-27 14:25:00+03	82600.00
78852E	2017-08-07 18:12:00+03	28000.00
78856A	2017-07-19 12:34:00+03	46400.00
7885FB	2017-07-24 19:09:00+03	40800.00
788652	2017-07-04 08:22:00+03	61800.00
78865A	2017-08-03 12:02:00+03	64100.00
7886E9	2017-07-09 20:14:00+03	6000.00
7886F9	2017-08-11 04:18:00+03	69600.00
788731	2017-07-15 11:38:00+03	73400.00
788744	2017-07-27 17:01:00+03	325800.00
78880D	2017-07-24 02:57:00+03	271200.00
788897	2017-07-28 07:05:00+03	147100.00
7888EF	2017-07-12 17:45:00+03	23600.00
7888FF	2017-07-18 16:43:00+03	147700.00
7889BB	2017-08-13 23:38:00+03	28000.00
7889F2	2017-07-20 16:33:00+03	7400.00
788A40	2017-07-26 03:49:00+03	37000.00
788B2F	2017-08-10 22:17:00+03	46400.00
788B33	2017-07-16 06:08:00+03	517700.00
788B5A	2017-08-09 00:55:00+03	56100.00
788B5D	2017-08-14 00:48:00+03	38800.00
788BC8	2017-07-02 08:01:00+03	270700.00
788BDC	2017-07-12 20:40:00+03	60400.00
788C15	2017-07-03 07:46:00+03	6200.00
788C1E	2017-07-27 03:53:00+03	43700.00
788C2F	2017-08-11 03:14:00+03	36700.00
788D50	2017-08-07 15:27:00+03	252200.00
788D82	2017-07-16 02:03:00+03	133200.00
788DA9	2017-08-01 23:47:00+03	101200.00
788DC6	2017-08-11 05:34:00+03	8200.00
788E15	2017-07-25 20:07:00+03	30200.00
788E3B	2017-07-20 22:40:00+03	153200.00
788E68	2017-08-13 15:18:00+03	123600.00
788E6B	2017-08-05 13:37:00+03	275000.00
788EAA	2017-07-04 08:17:00+03	51000.00
788EB7	2017-07-26 02:27:00+03	131100.00
788FA7	2017-07-26 14:42:00+03	28000.00
789021	2017-08-08 21:59:00+03	54500.00
789042	2017-07-14 18:18:00+03	61900.00
7890B1	2017-08-06 11:24:00+03	229300.00
789186	2017-07-15 09:38:00+03	48800.00
7891B6	2017-08-10 17:15:00+03	127100.00
7891B8	2017-07-25 08:15:00+03	17200.00
7891FD	2017-07-08 10:44:00+03	12400.00
789201	2017-07-22 22:24:00+03	299200.00
78920E	2017-07-16 03:32:00+03	135600.00
789295	2017-07-01 05:05:00+03	50000.00
7892A4	2017-08-07 23:13:00+03	59300.00
7892CE	2017-07-17 22:22:00+03	173500.00
78931F	2017-07-06 18:57:00+03	265600.00
7893A1	2017-08-10 19:24:00+03	27200.00
7893EA	2017-07-10 10:28:00+03	94500.00
7893F1	2017-07-10 21:58:00+03	40000.00
789450	2017-07-18 05:41:00+03	31400.00
78947F	2017-08-09 05:50:00+03	20900.00
789490	2017-08-08 02:32:00+03	69500.00
78952C	2017-07-10 14:35:00+03	77600.00
789541	2017-08-08 15:19:00+03	8400.00
789543	2017-07-26 22:07:00+03	33100.00
7895B5	2017-08-15 06:42:00+03	31200.00
7895CA	2017-08-05 09:13:00+03	35200.00
78960F	2017-07-13 17:54:00+03	50800.00
789670	2017-08-12 12:15:00+03	12000.00
789686	2017-08-05 08:19:00+03	52900.00
789688	2017-07-22 21:29:00+03	73300.00
7896EC	2017-08-15 05:13:00+03	6000.00
7896ED	2017-08-05 12:43:00+03	56000.00
78972F	2017-07-11 07:39:00+03	75600.00
789780	2017-07-18 02:54:00+03	420600.00
7897FD	2017-07-21 11:01:00+03	52400.00
7897FF	2017-07-24 06:14:00+03	44100.00
78980A	2017-08-02 19:30:00+03	43800.00
789823	2017-07-24 10:15:00+03	137400.00
789855	2017-08-09 00:03:00+03	179300.00
7898DB	2017-07-23 06:04:00+03	21500.00
7898FC	2017-07-27 04:25:00+03	52400.00
78990F	2017-08-12 08:36:00+03	153700.00
789989	2017-07-20 02:54:00+03	410200.00
7899A9	2017-08-13 20:09:00+03	54400.00
7899CF	2017-07-12 02:26:00+03	37200.00
789A11	2017-07-26 13:10:00+03	56600.00
789A19	2017-07-25 04:19:00+03	55800.00
789A9A	2017-07-08 20:08:00+03	55800.00
789B43	2017-07-12 10:49:00+03	93900.00
789B72	2017-07-29 18:32:00+03	185300.00
789B8C	2017-08-10 12:13:00+03	38800.00
789BB1	2017-07-16 12:56:00+03	40000.00
789BD2	2017-07-19 15:29:00+03	23400.00
789C4F	2017-07-23 09:11:00+03	56600.00
789C72	2017-07-11 21:58:00+03	13000.00
789D20	2017-07-25 03:17:00+03	32900.00
789D50	2017-07-01 10:18:00+03	41200.00
789D88	2017-08-15 15:52:00+03	66000.00
789DE5	2017-07-15 03:20:00+03	92800.00
789E1C	2017-07-01 21:50:00+03	38200.00
789E94	2017-07-30 15:42:00+03	90400.00
789EF4	2017-07-04 15:33:00+03	29400.00
789F1F	2017-07-31 14:26:00+03	42800.00
789F34	2017-07-08 09:34:00+03	28800.00
789F44	2017-07-16 07:36:00+03	31600.00
789F5C	2017-07-29 13:11:00+03	100600.00
789FC4	2017-07-24 17:53:00+03	133700.00
789FC7	2017-07-14 02:13:00+03	532600.00
789FE6	2017-07-01 04:50:00+03	47800.00
78A072	2017-08-07 21:03:00+03	72800.00
78A0A5	2017-07-06 04:51:00+03	64000.00
78A0AD	2017-07-02 10:45:00+03	90400.00
78A0DD	2017-08-03 21:49:00+03	71900.00
78A10B	2017-07-08 14:15:00+03	257500.00
78A16F	2017-08-11 17:27:00+03	67900.00
78A1DA	2017-08-10 12:05:00+03	57500.00
78A1E2	2017-07-16 22:10:00+03	6600.00
78A279	2017-07-29 09:34:00+03	41800.00
78A2B1	2017-08-05 07:31:00+03	298500.00
78A30B	2017-08-02 05:57:00+03	55600.00
78A31B	2017-07-15 10:16:00+03	23400.00
78A389	2017-06-28 12:11:00+03	46300.00
78A39A	2017-08-12 11:36:00+03	16400.00
78A3B1	2017-07-09 22:30:00+03	144700.00
78A3C3	2017-07-27 05:55:00+03	46400.00
78A3DA	2017-07-12 03:58:00+03	36200.00
78A3DE	2017-07-10 11:01:00+03	138600.00
78A3E7	2017-07-09 09:54:00+03	24300.00
78A431	2017-06-28 02:43:00+03	58400.00
78A519	2017-08-11 16:09:00+03	26000.00
78A581	2017-07-18 04:14:00+03	76800.00
78A5EC	2017-07-11 14:14:00+03	68800.00
78A602	2017-07-11 22:46:00+03	128800.00
78A646	2017-07-09 21:31:00+03	70800.00
78A66A	2017-07-07 10:11:00+03	14000.00
78A677	2017-07-24 12:09:00+03	60300.00
78A690	2017-07-02 01:59:00+03	23200.00
78A6F4	2017-06-27 05:57:00+03	28800.00
78A6FF	2017-08-10 17:58:00+03	13700.00
78A71D	2017-07-31 19:28:00+03	290600.00
78A752	2017-07-09 00:58:00+03	23200.00
78A763	2017-07-30 20:45:00+03	55800.00
78A79B	2017-07-14 06:38:00+03	169900.00
78A7B7	2017-07-07 05:00:00+03	147000.00
78A7C5	2017-08-04 23:13:00+03	64600.00
78A7D8	2017-07-18 17:42:00+03	68400.00
78A82B	2017-07-09 08:21:00+03	6700.00
78A86C	2017-07-17 10:27:00+03	81600.00
78A96F	2017-07-02 11:53:00+03	10600.00
78A970	2017-07-23 19:11:00+03	159800.00
78A9B6	2017-07-06 05:38:00+03	6800.00
78A9F9	2017-07-27 19:57:00+03	24800.00
78AA01	2017-06-30 05:32:00+03	31000.00
78AA1C	2017-08-11 21:46:00+03	65900.00
78AA6F	2017-08-15 01:17:00+03	6300.00
78AABA	2017-08-08 08:04:00+03	94000.00
78AB26	2017-07-26 07:02:00+03	38800.00
78AB5A	2017-07-19 10:51:00+03	103000.00
78AB74	2017-07-27 02:31:00+03	130400.00
78AC19	2017-07-09 10:07:00+03	24400.00
78AC29	2017-08-04 21:26:00+03	84000.00
78AC4D	2017-08-14 02:11:00+03	93700.00
78AC51	2017-07-20 02:16:00+03	40800.00
78AC8E	2017-07-06 16:16:00+03	64800.00
78ACC9	2017-07-05 01:52:00+03	108500.00
78ACF1	2017-08-01 03:12:00+03	57400.00
78AD2E	2017-07-01 00:45:00+03	257500.00
78ADC3	2017-07-26 11:46:00+03	56600.00
78ADC4	2017-07-10 20:21:00+03	39200.00
78ADE5	2017-07-17 11:07:00+03	164200.00
78ADF9	2017-07-14 06:52:00+03	95200.00
78AE92	2017-08-04 02:50:00+03	236000.00
78AFA6	2017-08-15 17:34:00+03	62000.00
78B041	2017-07-12 19:07:00+03	220800.00
78B0AE	2017-07-11 16:21:00+03	28800.00
78B0B7	2017-07-19 20:33:00+03	32800.00
78B0E7	2017-07-05 19:17:00+03	169900.00
78B16D	2017-07-30 09:37:00+03	56000.00
78B187	2017-08-06 23:48:00+03	60400.00
78B1C6	2017-07-13 01:39:00+03	31800.00
78B24F	2017-07-21 14:27:00+03	67600.00
78B28F	2017-07-17 15:04:00+03	266400.00
78B29E	2017-08-03 03:46:00+03	24400.00
78B2D3	2017-08-07 17:49:00+03	101200.00
78B2F3	2017-07-03 11:23:00+03	52000.00
78B2F7	2017-07-02 22:39:00+03	98300.00
78B38A	2017-06-30 11:30:00+03	88800.00
78B3C0	2017-07-12 02:31:00+03	24400.00
78B3CD	2017-07-12 03:44:00+03	105600.00
78B3E7	2017-08-04 22:45:00+03	46200.00
78B417	2017-07-27 18:41:00+03	267800.00
78B424	2017-07-07 12:35:00+03	130900.00
78B426	2017-06-28 18:48:00+03	26500.00
78B4E2	2017-07-12 02:47:00+03	37100.00
78B53B	2017-07-12 02:03:00+03	13700.00
78B56C	2017-07-31 15:46:00+03	6000.00
78B578	2017-08-06 02:45:00+03	116600.00
78B57E	2017-07-22 18:52:00+03	75300.00
78B5B1	2017-07-28 17:54:00+03	47400.00
78B5DB	2017-08-06 21:36:00+03	92900.00
78B62B	2017-08-14 16:30:00+03	139100.00
78B656	2017-07-19 08:59:00+03	119700.00
78B689	2017-08-08 12:11:00+03	18400.00
78B6F5	2017-08-08 14:54:00+03	209500.00
78B713	2017-07-18 08:22:00+03	155600.00
78B7EA	2017-08-10 09:56:00+03	131600.00
78B862	2017-08-02 03:23:00+03	39300.00
78B908	2017-08-10 02:20:00+03	77700.00
78B91F	2017-07-07 13:02:00+03	12000.00
78B980	2017-07-30 09:24:00+03	37600.00
78B993	2017-07-18 06:39:00+03	23200.00
78B9CF	2017-08-05 22:34:00+03	203000.00
78B9EF	2017-07-13 15:40:00+03	47100.00
78BA0B	2017-08-06 18:32:00+03	25100.00
78BA50	2017-06-27 09:30:00+03	28800.00
78BAA9	2017-07-26 00:27:00+03	46500.00
78BAD3	2017-08-02 01:26:00+03	46400.00
78BB08	2017-07-27 05:12:00+03	36200.00
78BB36	2017-07-17 10:00:00+03	47200.00
78BB68	2017-07-01 11:59:00+03	74100.00
78BBAD	2017-08-01 03:11:00+03	55800.00
78BBE9	2017-08-07 03:41:00+03	17200.00
78BC15	2017-08-06 01:37:00+03	54000.00
78BC1F	2017-08-11 20:08:00+03	6300.00
78BC2C	2017-08-13 05:12:00+03	12600.00
78BC54	2017-08-05 04:12:00+03	29300.00
78BC5E	2017-07-27 05:22:00+03	29600.00
78BC97	2017-07-14 01:59:00+03	69500.00
78BCF1	2017-08-13 02:08:00+03	114800.00
78BD6E	2017-08-03 03:41:00+03	103200.00
78BDE7	2017-08-07 02:31:00+03	31100.00
78BE11	2017-07-21 02:30:00+03	42700.00
78BE28	2017-07-21 07:32:00+03	48500.00
78BE2F	2017-07-30 18:11:00+03	113000.00
78BE56	2017-07-22 02:23:00+03	67600.00
78BEEE	2017-07-11 01:51:00+03	7400.00
78BF03	2017-07-09 12:52:00+03	95200.00
78BF2C	2017-07-09 03:15:00+03	67800.00
78BF81	2017-08-01 23:16:00+03	36800.00
78BFB4	2017-07-06 23:13:00+03	70500.00
78BFD0	2017-08-11 17:18:00+03	68800.00
78BFDB	2017-07-31 23:29:00+03	24800.00
78C018	2017-08-02 19:25:00+03	86800.00
78C05C	2017-07-23 02:02:00+03	110200.00
78C081	2017-08-03 12:54:00+03	145300.00
78C0C3	2017-06-28 22:34:00+03	77200.00
78C0CF	2017-07-22 07:39:00+03	257600.00
78C0EB	2017-08-11 18:25:00+03	14000.00
78C123	2017-07-27 10:15:00+03	316600.00
78C1CB	2017-07-16 07:47:00+03	38600.00
78C23A	2017-08-10 14:52:00+03	23200.00
78C24E	2017-07-26 20:00:00+03	13400.00
78C290	2017-07-09 20:15:00+03	26000.00
78C294	2017-07-30 17:26:00+03	96900.00
78C2BC	2017-08-12 02:39:00+03	133100.00
78C2C5	2017-08-02 13:33:00+03	47400.00
78C2CA	2017-07-06 10:41:00+03	94200.00
78C316	2017-07-22 17:55:00+03	89600.00
78C35F	2017-07-23 15:47:00+03	23200.00
78C3E7	2017-07-23 00:23:00+03	62600.00
78C446	2017-08-04 14:20:00+03	93000.00
78C49A	2017-07-05 06:19:00+03	32400.00
78C4E0	2017-07-23 22:50:00+03	135200.00
78C4E1	2017-07-04 21:17:00+03	51900.00
78C4FF	2017-08-11 05:05:00+03	133200.00
78C535	2017-08-03 17:24:00+03	67600.00
78C5AC	2017-07-05 09:26:00+03	13200.00
78C5B1	2017-07-08 02:32:00+03	99200.00
78C5E3	2017-07-31 16:25:00+03	28700.00
78C637	2017-07-01 18:00:00+03	44700.00
78C645	2017-07-14 15:50:00+03	23200.00
78C653	2017-07-17 23:37:00+03	59800.00
78C671	2017-07-11 23:09:00+03	71100.00
78C6A1	2017-08-01 15:55:00+03	92000.00
78C6EA	2017-07-13 22:52:00+03	47500.00
78C70F	2017-08-04 09:57:00+03	260900.00
78C776	2017-07-13 08:14:00+03	143000.00
78C7C2	2017-08-10 15:00:00+03	135600.00
78C821	2017-07-01 05:09:00+03	21400.00
78C8AB	2017-07-02 10:50:00+03	33300.00
78C8C2	2017-07-11 08:47:00+03	77200.00
78C8D1	2017-08-07 09:09:00+03	66800.00
78C90C	2017-07-07 13:25:00+03	289800.00
78C910	2017-07-14 22:59:00+03	23200.00
78C923	2017-07-08 13:45:00+03	48800.00
78C964	2017-07-14 15:12:00+03	137600.00
78CA27	2017-08-03 04:35:00+03	96200.00
78CAC2	2017-08-11 16:31:00+03	398500.00
78CC25	2017-08-15 07:43:00+03	63500.00
78CC46	2017-07-24 12:28:00+03	139800.00
78CC7C	2017-07-14 18:23:00+03	26000.00
78CD53	2017-08-12 02:39:00+03	57700.00
78CD67	2017-07-16 01:39:00+03	182300.00
78CE72	2017-07-26 11:00:00+03	23400.00
78CE7C	2017-07-31 07:11:00+03	118100.00
78CE8C	2017-08-13 17:11:00+03	83700.00
78CECC	2017-07-07 11:59:00+03	123600.00
78CF27	2017-07-30 04:18:00+03	68800.00
78CF9E	2017-07-12 08:47:00+03	75600.00
78CFD4	2017-08-04 13:06:00+03	143100.00
78CFDE	2017-08-13 09:00:00+03	68800.00
78D084	2017-07-27 23:29:00+03	35200.00
78D0D0	2017-07-19 23:23:00+03	75300.00
78D156	2017-08-08 13:57:00+03	17200.00
78D176	2017-07-19 07:42:00+03	6700.00
78D1CA	2017-07-15 17:36:00+03	260300.00
78D1EB	2017-07-26 00:24:00+03	32800.00
78D230	2017-07-23 18:38:00+03	45500.00
78D28A	2017-07-13 12:40:00+03	25200.00
78D2DC	2017-07-30 01:21:00+03	43200.00
78D2E1	2017-07-03 17:11:00+03	20200.00
78D2E6	2017-07-19 09:19:00+03	53300.00
78D3C8	2017-08-03 12:34:00+03	111600.00
78D41D	2017-08-10 13:42:00+03	46500.00
78D446	2017-08-10 22:16:00+03	129700.00
78D455	2017-07-16 19:22:00+03	23400.00
78D464	2017-07-15 15:36:00+03	89600.00
78D47C	2017-07-19 19:51:00+03	95700.00
78D49F	2017-07-17 18:28:00+03	6800.00
78D4A0	2017-08-04 18:23:00+03	47600.00
78D4B0	2017-08-14 07:39:00+03	111600.00
78D4F7	2017-07-21 09:34:00+03	46200.00
78D508	2017-07-10 05:34:00+03	272400.00
78D536	2017-07-04 18:02:00+03	214900.00
78D539	2017-07-27 22:49:00+03	49900.00
78D579	2017-08-05 16:35:00+03	56600.00
78D5D7	2017-08-10 22:37:00+03	189100.00
78D5FB	2017-07-07 22:49:00+03	70600.00
78D644	2017-07-13 14:30:00+03	178800.00
78D689	2017-07-05 04:53:00+03	174000.00
78D6A0	2017-07-19 13:41:00+03	65300.00
78D6EA	2017-07-20 04:54:00+03	174400.00
78D6FC	2017-08-09 02:15:00+03	55800.00
78D73C	2017-07-07 20:27:00+03	94000.00
78D754	2017-07-23 02:21:00+03	93900.00
78D77B	2017-07-28 21:06:00+03	115700.00
78D7DF	2017-08-08 10:06:00+03	25600.00
78D7F5	2017-08-01 13:44:00+03	496600.00
78D81D	2017-08-15 04:17:00+03	40800.00
78D835	2017-07-30 19:00:00+03	149300.00
78D839	2017-07-01 01:48:00+03	13400.00
78D858	2017-07-10 11:30:00+03	81900.00
78D879	2017-08-10 13:12:00+03	28000.00
78D87D	2017-07-26 19:21:00+03	62600.00
78D8A4	2017-07-17 07:40:00+03	18400.00
78D8C0	2017-08-06 05:09:00+03	68800.00
78D8DC	2017-08-04 06:55:00+03	61800.00
78D90D	2017-07-20 21:59:00+03	136500.00
78D93C	2017-07-09 10:21:00+03	67900.00
78D999	2017-07-29 04:22:00+03	55800.00
78D9C6	2017-07-24 20:20:00+03	68400.00
78D9E7	2017-07-16 00:16:00+03	50600.00
78DA8A	2017-07-18 04:56:00+03	56600.00
78DB62	2017-07-27 08:26:00+03	129700.00
78DB6F	2017-07-06 21:56:00+03	55800.00
78DBA7	2017-07-16 19:16:00+03	13400.00
78DBB6	2017-07-06 13:24:00+03	57500.00
78DBFE	2017-07-18 09:49:00+03	24400.00
78DC87	2017-08-04 06:02:00+03	73400.00
78DD0A	2017-07-07 16:04:00+03	6600.00
78DD11	2017-07-14 12:24:00+03	52700.00
78DD98	2017-07-29 03:50:00+03	83600.00
78DDAB	2017-08-13 00:58:00+03	101100.00
78DDB5	2017-07-11 13:12:00+03	134700.00
78DDF0	2017-07-20 00:01:00+03	39500.00
78DDFE	2017-07-28 05:34:00+03	14000.00
78DE01	2017-07-19 07:07:00+03	50600.00
78DE27	2017-07-31 04:51:00+03	26000.00
78DE75	2017-07-30 04:48:00+03	28000.00
78DF0C	2017-08-15 16:03:00+03	46200.00
78DF26	2017-07-28 17:38:00+03	311200.00
78DF50	2017-07-04 11:52:00+03	28000.00
78E002	2017-07-11 06:57:00+03	24600.00
78E013	2017-07-26 00:48:00+03	49000.00
78E027	2017-07-16 19:49:00+03	57600.00
78E02B	2017-07-23 06:01:00+03	14400.00
78E058	2017-06-29 22:32:00+03	72200.00
78E0CC	2017-07-26 09:57:00+03	152800.00
78E115	2017-07-18 05:14:00+03	114900.00
78E178	2017-07-18 16:35:00+03	53600.00
78E179	2017-06-28 19:51:00+03	49600.00
78E1A2	2017-07-18 20:12:00+03	23200.00
78E1B2	2017-08-10 23:43:00+03	44600.00
78E250	2017-07-28 03:47:00+03	12600.00
78E299	2017-07-21 04:51:00+03	128800.00
78E2AB	2017-07-24 04:54:00+03	61800.00
78E30E	2017-07-03 07:14:00+03	30900.00
78E31A	2017-08-09 04:11:00+03	60700.00
78E31D	2017-08-03 06:42:00+03	19600.00
78E34A	2017-08-04 06:51:00+03	266400.00
78E388	2017-07-25 16:30:00+03	21200.00
78E390	2017-08-08 20:07:00+03	99000.00
78E3CB	2017-07-06 10:40:00+03	21200.00
78E401	2017-08-05 15:59:00+03	32800.00
78E4A9	2017-08-07 14:04:00+03	32800.00
78E4E2	2017-07-01 18:53:00+03	35500.00
78E507	2017-07-14 23:10:00+03	92900.00
78E520	2017-07-07 18:12:00+03	147700.00
78E5AD	2017-08-12 13:03:00+03	28800.00
78E5BC	2017-07-19 17:35:00+03	23200.00
78E5D5	2017-07-12 14:47:00+03	109600.00
78E674	2017-08-11 21:39:00+03	270800.00
78E690	2017-07-13 20:47:00+03	155500.00
78E6C6	2017-07-13 06:01:00+03	56000.00
78E6D8	2017-07-28 02:47:00+03	56600.00
78E6E2	2017-06-28 12:06:00+03	44700.00
78E77A	2017-08-15 13:56:00+03	134600.00
78E7AC	2017-08-05 08:11:00+03	75700.00
78E7BE	2017-07-20 15:24:00+03	46800.00
78E7CA	2017-07-15 10:03:00+03	64700.00
78E828	2017-07-27 16:49:00+03	44600.00
78E8CE	2017-08-08 14:47:00+03	36200.00
78E998	2017-08-13 22:11:00+03	25800.00
78E9AE	2017-08-04 20:07:00+03	39900.00
78E9DE	2017-07-25 11:46:00+03	28000.00
78EA66	2017-07-23 02:13:00+03	32800.00
78EA7D	2017-07-18 08:13:00+03	37900.00
78EA89	2017-08-03 04:25:00+03	94700.00
78EA90	2017-07-10 03:34:00+03	169900.00
78EAD3	2017-07-14 05:11:00+03	32400.00
78EADA	2017-07-12 23:56:00+03	86400.00
78EBCB	2017-08-02 15:15:00+03	51900.00
78EC74	2017-07-14 16:29:00+03	11800.00
78EC7F	2017-07-21 10:49:00+03	38400.00
78EC85	2017-08-15 05:37:00+03	72700.00
78EC8D	2017-08-10 12:48:00+03	92800.00
78ECEE	2017-08-10 01:06:00+03	19600.00
78ED48	2017-07-06 12:56:00+03	26700.00
78EDC9	2017-08-07 19:35:00+03	278400.00
78EDDC	2017-07-06 16:20:00+03	40100.00
78EDED	2017-07-22 01:00:00+03	84500.00
78EE02	2017-08-10 14:20:00+03	83700.00
78EE52	2017-07-15 15:06:00+03	37100.00
78EE8D	2017-07-30 00:33:00+03	44600.00
78EEF0	2017-07-04 18:57:00+03	80700.00
78EF17	2017-07-06 22:30:00+03	66200.00
78EF51	2017-07-28 03:17:00+03	21800.00
78EF55	2017-07-26 14:54:00+03	62800.00
78EF6B	2017-07-25 14:08:00+03	235200.00
78EFAE	2017-07-26 08:34:00+03	173200.00
78EFB9	2017-07-12 23:30:00+03	43300.00
78EFDE	2017-07-16 04:03:00+03	254900.00
78F04E	2017-08-06 18:23:00+03	93500.00
78F07E	2017-07-06 10:45:00+03	27700.00
78F0FF	2017-07-04 15:50:00+03	13600.00
78F148	2017-07-06 19:15:00+03	26000.00
78F1D8	2017-07-24 15:16:00+03	92400.00
78F1FC	2017-08-04 19:33:00+03	40300.00
78F236	2017-07-30 08:52:00+03	14400.00
78F24A	2017-08-13 19:50:00+03	47700.00
78F25B	2017-08-02 03:31:00+03	26000.00
78F25E	2017-08-07 04:22:00+03	66600.00
78F266	2017-07-17 08:45:00+03	94700.00
78F2DF	2017-07-13 21:06:00+03	25100.00
78F2F7	2017-07-09 09:07:00+03	40400.00
78F34B	2017-07-29 19:02:00+03	55800.00
78F376	2017-07-17 07:14:00+03	199800.00
78F399	2017-07-28 09:56:00+03	31600.00
78F3A1	2017-07-13 21:29:00+03	14000.00
78F3EB	2017-07-18 08:22:00+03	55600.00
78F500	2017-07-07 12:03:00+03	26800.00
78F507	2017-07-01 09:02:00+03	41400.00
78F5B2	2017-07-17 14:57:00+03	103800.00
78F5B7	2017-08-08 03:41:00+03	23900.00
78F645	2017-08-05 17:51:00+03	16400.00
78F68F	2017-07-27 16:04:00+03	113500.00
78F69D	2017-07-16 23:34:00+03	46700.00
78F71D	2017-07-23 06:05:00+03	185700.00
78F777	2017-07-05 04:56:00+03	14000.00
78F7A4	2017-07-19 19:39:00+03	110500.00
78F7AE	2017-07-18 21:23:00+03	18600.00
78F7E6	2017-07-22 11:52:00+03	28000.00
78F8A5	2017-07-27 11:50:00+03	32800.00
78F8A6	2017-07-25 19:41:00+03	99200.00
78F8EB	2017-07-05 13:07:00+03	81000.00
78F8FE	2017-07-22 03:30:00+03	28700.00
78F909	2017-06-26 14:10:00+03	97600.00
78FA20	2017-07-22 18:41:00+03	27200.00
78FA2B	2017-08-11 05:27:00+03	46400.00
78FA94	2017-07-25 20:42:00+03	9800.00
78FABF	2017-08-02 20:10:00+03	65900.00
78FAF5	2017-08-01 12:05:00+03	260900.00
78FB5B	2017-07-30 13:50:00+03	126300.00
78FBA7	2017-07-11 01:39:00+03	69200.00
78FBCB	2017-08-10 19:27:00+03	48800.00
78FC37	2017-08-09 06:59:00+03	40300.00
78FC52	2017-08-12 09:24:00+03	56800.00
78FC92	2017-07-30 11:53:00+03	88200.00
78FC97	2017-07-30 02:37:00+03	101200.00
78FCA2	2017-07-30 02:39:00+03	86400.00
78FCD6	2017-08-08 00:47:00+03	50800.00
78FCE9	2017-08-02 09:44:00+03	83200.00
78FD00	2017-08-13 08:42:00+03	36200.00
78FD06	2017-07-02 02:39:00+03	52400.00
78FD7E	2017-07-28 18:05:00+03	78800.00
78FDAC	2017-08-10 11:04:00+03	14400.00
78FDFA	2017-07-21 08:48:00+03	20600.00
78FE66	2017-08-14 02:04:00+03	139000.00
78FEB4	2017-08-11 12:12:00+03	59400.00
78FF32	2017-07-07 07:19:00+03	11000.00
78FF4F	2017-07-15 13:00:00+03	8200.00
78FF96	2017-07-04 00:31:00+03	91500.00
790027	2017-07-31 02:47:00+03	27600.00
790141	2017-07-12 14:35:00+03	263500.00
790177	2017-07-11 16:41:00+03	19600.00
79017A	2017-07-09 17:08:00+03	30700.00
79019F	2017-08-04 14:11:00+03	28700.00
7901A0	2017-08-04 16:11:00+03	12600.00
79021E	2017-07-15 05:38:00+03	28000.00
790233	2017-08-11 22:49:00+03	31200.00
790247	2017-07-05 12:02:00+03	51300.00
790269	2017-07-25 23:28:00+03	38400.00
790299	2017-07-22 00:05:00+03	58600.00
7902C1	2017-07-16 08:24:00+03	44000.00
790351	2017-07-24 11:26:00+03	149200.00
790359	2017-07-21 12:59:00+03	24400.00
790399	2017-07-22 12:53:00+03	131600.00
7903D6	2017-07-20 15:37:00+03	100600.00
7903EB	2017-08-05 01:23:00+03	28700.00
7904ED	2017-07-11 08:50:00+03	36400.00
790529	2017-07-28 17:18:00+03	51500.00
790542	2017-07-06 09:03:00+03	115000.00
79057E	2017-08-12 07:38:00+03	83700.00
790630	2017-07-31 04:18:00+03	154800.00
790644	2017-08-12 12:48:00+03	128800.00
79065D	2017-07-12 09:43:00+03	47000.00
7906D5	2017-07-31 20:06:00+03	56000.00
7906E3	2017-07-25 14:47:00+03	46400.00
790745	2017-07-16 12:41:00+03	199600.00
790780	2017-08-11 08:41:00+03	54000.00
7907D6	2017-07-08 21:39:00+03	70400.00
79083B	2017-08-09 03:39:00+03	185600.00
790846	2017-07-30 05:52:00+03	44000.00
790885	2017-08-03 21:29:00+03	59100.00
79092B	2017-07-25 20:31:00+03	49600.00
790961	2017-07-28 02:03:00+03	185000.00
79098A	2017-08-08 10:20:00+03	21500.00
790992	2017-08-13 17:59:00+03	16300.00
79099C	2017-07-11 07:10:00+03	20800.00
790A51	2017-07-21 02:48:00+03	37900.00
790A95	2017-08-07 09:14:00+03	194100.00
790BAB	2017-07-29 21:36:00+03	28800.00
790BAE	2017-07-30 05:20:00+03	54400.00
790BE1	2017-07-07 05:11:00+03	23100.00
790BEC	2017-07-11 00:57:00+03	30000.00
790C47	2017-07-04 11:17:00+03	100600.00
790C4B	2017-08-15 17:56:00+03	104400.00
790C96	2017-07-29 00:25:00+03	60400.00
790CBD	2017-07-25 11:57:00+03	260900.00
790D05	2017-07-23 17:22:00+03	124200.00
790D18	2017-07-02 02:46:00+03	54800.00
790D5B	2017-07-15 01:45:00+03	8400.00
790D66	2017-07-21 18:41:00+03	108900.00
790D72	2017-07-25 18:20:00+03	35200.00
790DC8	2017-07-27 06:42:00+03	66200.00
790E39	2017-07-19 19:37:00+03	130900.00
790E71	2017-07-14 08:12:00+03	297600.00
790E82	2017-08-15 17:54:00+03	91600.00
790EF7	2017-07-29 21:36:00+03	27200.00
790F5A	2017-07-04 06:18:00+03	18600.00
790F94	2017-07-31 06:02:00+03	165500.00
790F99	2017-07-15 23:17:00+03	26200.00
791024	2017-07-16 06:24:00+03	54500.00
79103E	2017-07-27 18:18:00+03	46000.00
791047	2017-08-11 18:43:00+03	12000.00
79104C	2017-08-15 09:47:00+03	18400.00
791083	2017-06-28 20:20:00+03	100800.00
7910A3	2017-08-02 19:14:00+03	14900.00
7910C9	2017-07-19 19:32:00+03	24400.00
7910EE	2017-07-31 13:47:00+03	111400.00
7910F5	2017-07-19 06:01:00+03	40800.00
791129	2017-07-18 02:03:00+03	16800.00
7911BC	2017-08-08 13:06:00+03	48800.00
7911E2	2017-07-11 05:28:00+03	173900.00
7911EE	2017-07-16 18:02:00+03	29600.00
791218	2017-07-15 09:51:00+03	7400.00
791231	2017-07-21 04:40:00+03	28000.00
79129F	2017-07-18 16:38:00+03	47900.00
7912B3	2017-08-13 22:02:00+03	272400.00
7912DD	2017-07-16 12:52:00+03	23600.00
791341	2017-07-26 00:19:00+03	58800.00
7913C8	2017-07-11 10:19:00+03	28000.00
791410	2017-07-05 06:02:00+03	27300.00
7914C7	2017-08-13 10:17:00+03	18800.00
79154E	2017-07-03 13:12:00+03	34000.00
79157F	2017-08-15 01:46:00+03	54500.00
7915BD	2017-07-30 14:37:00+03	149100.00
79160A	2017-08-08 09:46:00+03	62000.00
79160D	2017-08-03 08:13:00+03	28600.00
79169D	2017-07-14 04:55:00+03	71100.00
7916D7	2017-07-12 14:48:00+03	273600.00
7916FA	2017-07-28 12:37:00+03	7800.00
791711	2017-07-31 13:51:00+03	20400.00
791758	2017-08-06 05:55:00+03	13400.00
79176A	2017-08-03 23:41:00+03	22600.00
79178B	2017-07-31 21:01:00+03	73600.00
7917A9	2017-07-01 02:51:00+03	28800.00
7917C8	2017-07-28 02:31:00+03	26700.00
7917E8	2017-07-20 15:54:00+03	184300.00
791807	2017-07-07 09:29:00+03	9800.00
791841	2017-07-05 01:30:00+03	18600.00
79184A	2017-07-18 14:32:00+03	53800.00
791886	2017-07-26 17:46:00+03	50600.00
791894	2017-07-28 14:40:00+03	71700.00
7918F7	2017-07-30 10:33:00+03	31600.00
7918FF	2017-08-10 17:37:00+03	25600.00
791938	2017-07-13 06:37:00+03	144400.00
79193B	2017-07-10 21:34:00+03	92800.00
791960	2017-08-03 02:06:00+03	88200.00
7919FF	2017-08-14 13:32:00+03	72000.00
791A62	2017-07-25 04:48:00+03	50000.00
791A76	2017-06-30 17:19:00+03	133600.00
791B7E	2017-07-19 23:32:00+03	177200.00
791C96	2017-07-24 12:43:00+03	46000.00
791CA1	2017-07-31 07:48:00+03	28300.00
791D0A	2017-07-22 13:35:00+03	67700.00
791DAD	2017-07-14 03:42:00+03	29600.00
791DCC	2017-07-08 01:36:00+03	91500.00
791DD2	2017-07-01 12:32:00+03	40800.00
791DE6	2017-08-08 16:46:00+03	31400.00
791E24	2017-08-13 21:52:00+03	38600.00
791E5D	2017-08-07 09:16:00+03	57400.00
791E6F	2017-07-29 21:33:00+03	64800.00
791E81	2017-08-12 14:41:00+03	143800.00
791E9C	2017-07-12 18:28:00+03	42800.00
791EC4	2017-08-04 07:46:00+03	7400.00
791EE1	2017-07-14 19:03:00+03	8400.00
791F28	2017-07-17 21:18:00+03	49400.00
791F78	2017-08-11 11:50:00+03	39600.00
791F89	2017-08-15 09:26:00+03	32500.00
791FAF	2017-08-06 17:52:00+03	6700.00
791FE2	2017-07-16 10:50:00+03	88100.00
792044	2017-08-08 01:46:00+03	55800.00
792049	2017-07-25 20:07:00+03	27300.00
7920BB	2017-08-12 15:11:00+03	127100.00
792138	2017-08-12 04:13:00+03	30400.00
792181	2017-07-10 19:34:00+03	39800.00
792206	2017-07-16 09:37:00+03	19600.00
792248	2017-08-06 10:13:00+03	202300.00
79225C	2017-08-05 08:40:00+03	33000.00
79225D	2017-07-03 14:16:00+03	24800.00
7922B1	2017-07-30 03:42:00+03	81900.00
7922DD	2017-08-13 13:35:00+03	50000.00
7923C4	2017-07-11 03:05:00+03	50100.00
7923D2	2017-08-10 06:43:00+03	30200.00
792430	2017-08-15 15:02:00+03	28800.00
792447	2017-07-04 15:20:00+03	168900.00
79247E	2017-07-26 19:11:00+03	55800.00
7924CD	2017-07-27 17:35:00+03	25400.00
792545	2017-08-03 04:00:00+03	24000.00
792552	2017-07-09 18:03:00+03	529200.00
7925A0	2017-07-22 22:04:00+03	246000.00
7925EE	2017-08-04 12:24:00+03	169900.00
792605	2017-07-23 14:30:00+03	140900.00
79268F	2017-07-17 19:31:00+03	46200.00
7926A2	2017-08-04 20:17:00+03	30400.00
7926F1	2017-07-15 17:52:00+03	167400.00
7927CF	2017-08-14 23:01:00+03	115300.00
792846	2017-07-14 11:33:00+03	94000.00
792934	2017-07-27 16:49:00+03	29600.00
792999	2017-07-13 02:55:00+03	25000.00
7929C1	2017-07-21 00:49:00+03	111600.00
792A43	2017-07-15 06:44:00+03	7200.00
792A4E	2017-08-11 23:29:00+03	65600.00
792A5C	2017-07-08 16:34:00+03	56600.00
792A6E	2017-08-15 08:52:00+03	35300.00
792AAD	2017-08-03 01:41:00+03	182400.00
792AE0	2017-07-19 19:45:00+03	418500.00
792AEE	2017-07-03 00:11:00+03	66600.00
792B54	2017-07-20 01:06:00+03	62900.00
792B61	2017-07-19 22:41:00+03	104100.00
792B95	2017-06-30 21:38:00+03	20200.00
792B9F	2017-08-14 07:46:00+03	156000.00
792BA9	2017-07-22 04:22:00+03	89600.00
792C97	2017-07-10 12:59:00+03	202100.00
792D23	2017-07-10 08:34:00+03	24400.00
792D39	2017-07-30 04:30:00+03	23200.00
792D5F	2017-07-04 12:06:00+03	43000.00
792D69	2017-07-02 20:16:00+03	116400.00
792D8C	2017-07-15 14:57:00+03	45000.00
792DDE	2017-08-06 06:11:00+03	199700.00
792E98	2017-08-08 10:06:00+03	55800.00
792EB1	2017-07-05 21:07:00+03	23200.00
792EBF	2017-07-12 19:32:00+03	23600.00
792F04	2017-07-11 03:53:00+03	100600.00
792FE8	2017-07-04 15:53:00+03	55600.00
79300A	2017-08-09 22:27:00+03	131100.00
793048	2017-06-29 08:42:00+03	21800.00
793062	2017-07-20 22:48:00+03	92100.00
7930D0	2017-08-14 12:23:00+03	54800.00
7930EE	2017-08-12 20:38:00+03	173100.00
79315E	2017-08-10 17:37:00+03	30900.00
793164	2017-08-07 11:09:00+03	40600.00
793177	2017-08-02 05:20:00+03	38800.00
7931AD	2017-07-08 04:55:00+03	7400.00
793213	2017-06-28 18:51:00+03	43500.00
79323A	2017-08-05 05:55:00+03	298600.00
79328E	2017-07-01 11:33:00+03	23200.00
793290	2017-07-21 02:43:00+03	46400.00
793299	2017-08-12 21:46:00+03	207000.00
7932CC	2017-06-24 18:23:00+03	167400.00
7932D1	2017-08-04 16:48:00+03	131100.00
7932D8	2017-08-02 21:49:00+03	67600.00
79337D	2017-07-14 01:36:00+03	9800.00
793440	2017-07-20 15:41:00+03	85700.00
79349A	2017-07-27 03:37:00+03	36800.00
7934A9	2017-07-22 17:07:00+03	39800.00
7934EF	2017-08-04 00:36:00+03	28000.00
7934F3	2017-07-11 07:40:00+03	118500.00
7934F7	2017-07-25 22:52:00+03	25100.00
79351E	2017-07-28 18:04:00+03	50000.00
793524	2017-08-10 22:14:00+03	308500.00
79353A	2017-07-23 02:43:00+03	556700.00
793545	2017-08-06 02:29:00+03	111600.00
793579	2017-07-08 18:29:00+03	124200.00
79357F	2017-07-08 19:06:00+03	13400.00
7935A0	2017-06-29 02:26:00+03	76300.00
7935A1	2017-07-27 00:59:00+03	75300.00
79360F	2017-07-17 06:34:00+03	26700.00
793631	2017-07-25 06:06:00+03	93400.00
7936A2	2017-07-11 08:30:00+03	52400.00
7936B9	2017-08-01 06:29:00+03	156500.00
7936D7	2017-08-06 05:12:00+03	96100.00
793706	2017-08-15 09:54:00+03	42700.00
79370B	2017-07-23 16:13:00+03	66600.00
79376E	2017-07-30 07:35:00+03	65900.00
7937B3	2017-07-11 11:14:00+03	282800.00
793859	2017-08-12 10:12:00+03	88500.00
7938AF	2017-07-11 19:41:00+03	92800.00
7938F4	2017-07-03 15:04:00+03	34000.00
7938F7	2017-07-22 04:44:00+03	270600.00
7938F9	2017-07-22 12:33:00+03	41200.00
793904	2017-07-27 15:14:00+03	51600.00
7939A8	2017-07-10 05:25:00+03	64400.00
7939B9	2017-08-01 05:45:00+03	54400.00
793AAE	2017-08-09 06:01:00+03	189000.00
793B16	2017-07-14 04:12:00+03	59800.00
793B2D	2017-08-09 23:15:00+03	301800.00
793B97	2017-07-14 13:14:00+03	26500.00
793BBC	2017-07-27 03:28:00+03	75600.00
793C15	2017-08-13 15:51:00+03	14400.00
793C6A	2017-08-07 03:00:00+03	65500.00
793C74	2017-07-07 06:47:00+03	19600.00
793C79	2017-08-01 15:37:00+03	156000.00
793C8A	2017-07-27 20:06:00+03	18000.00
793CA1	2017-07-19 06:13:00+03	32200.00
793CC9	2017-07-05 18:25:00+03	101200.00
793CE4	2017-07-22 00:33:00+03	43800.00
793CF7	2017-08-07 17:50:00+03	26000.00
793DBA	2017-07-09 13:05:00+03	118600.00
793DFC	2017-07-26 23:05:00+03	35600.00
793E30	2017-07-27 12:04:00+03	67000.00
793E41	2017-07-27 12:24:00+03	123000.00
793E48	2017-07-14 10:59:00+03	184700.00
793E56	2017-07-14 09:36:00+03	46400.00
793E80	2017-07-20 05:09:00+03	75300.00
793E99	2017-07-26 10:45:00+03	62900.00
793F2D	2017-07-26 22:18:00+03	27300.00
793F4D	2017-06-29 14:12:00+03	67600.00
793FD3	2017-08-07 21:43:00+03	26000.00
79400A	2017-07-11 06:32:00+03	45500.00
794048	2017-08-12 00:09:00+03	68800.00
794049	2017-08-15 13:06:00+03	200500.00
794071	2017-07-24 12:15:00+03	65500.00
7940CE	2017-08-04 16:00:00+03	133200.00
79418E	2017-08-07 13:06:00+03	266400.00
7941A2	2017-07-11 22:12:00+03	26200.00
7941EE	2017-08-07 01:54:00+03	145600.00
794233	2017-07-01 14:59:00+03	114800.00
794283	2017-08-03 16:18:00+03	58800.00
7942BE	2017-07-20 09:03:00+03	167400.00
7942C5	2017-08-03 21:17:00+03	73500.00
7943CF	2017-07-11 20:28:00+03	135600.00
794522	2017-07-07 11:59:00+03	26800.00
79453F	2017-06-28 13:49:00+03	105000.00
794564	2017-08-06 20:57:00+03	85200.00
794581	2017-07-26 01:14:00+03	46400.00
79471B	2017-07-19 09:36:00+03	8400.00
794733	2017-08-13 05:35:00+03	40100.00
794766	2017-07-10 19:47:00+03	6000.00
794797	2017-07-23 10:08:00+03	48800.00
7947DE	2017-07-09 09:06:00+03	23200.00
7947F4	2017-08-02 10:52:00+03	21800.00
79486C	2017-08-07 06:10:00+03	51900.00
7948B7	2017-07-29 03:24:00+03	55000.00
7949F4	2017-08-05 12:44:00+03	23600.00
794AC8	2017-07-29 04:35:00+03	58800.00
794BA2	2017-07-13 03:50:00+03	95600.00
794BFA	2017-07-27 19:47:00+03	14300.00
794C55	2017-07-10 05:57:00+03	87100.00
794CC5	2017-07-15 23:05:00+03	38000.00
794D5D	2017-08-06 02:30:00+03	30200.00
794D97	2017-08-06 09:58:00+03	28800.00
794D98	2017-07-25 22:03:00+03	49100.00
794E0F	2017-07-22 00:03:00+03	45200.00
794E86	2017-07-25 20:02:00+03	10100.00
794EBE	2017-07-25 17:48:00+03	30700.00
794ECA	2017-07-20 00:59:00+03	135600.00
794FB9	2017-08-08 00:33:00+03	37200.00
795090	2017-07-14 23:38:00+03	47300.00
795093	2017-08-06 06:18:00+03	206400.00
7950B7	2017-07-29 17:17:00+03	43200.00
7950E5	2017-08-09 05:51:00+03	38400.00
795113	2017-06-30 19:04:00+03	54800.00
795152	2017-07-10 20:56:00+03	32700.00
79515F	2017-07-01 06:26:00+03	36600.00
7951C5	2017-07-08 07:03:00+03	39500.00
7951F3	2017-08-13 11:37:00+03	28000.00
79520C	2017-07-19 10:54:00+03	48800.00
79522D	2017-08-01 06:09:00+03	67200.00
79523D	2017-08-07 15:06:00+03	46400.00
795242	2017-07-11 20:44:00+03	26000.00
79525A	2017-07-11 06:00:00+03	28000.00
7952E6	2017-08-08 14:08:00+03	46900.00
7952E8	2017-08-05 06:03:00+03	658400.00
79533E	2017-07-20 22:17:00+03	6700.00
795364	2017-07-27 23:44:00+03	241300.00
79539E	2017-07-11 10:31:00+03	165500.00
7953A6	2017-07-22 07:47:00+03	81700.00
7953DD	2017-07-31 10:20:00+03	47200.00
79544E	2017-08-11 19:38:00+03	13400.00
79546C	2017-06-28 04:08:00+03	151900.00
7954EA	2017-07-04 21:28:00+03	94000.00
795509	2017-07-27 06:58:00+03	83000.00
7955B0	2017-08-03 09:07:00+03	123600.00
7955DD	2017-07-07 12:54:00+03	156300.00
795605	2017-07-22 22:27:00+03	115900.00
795615	2017-08-14 20:46:00+03	53600.00
795620	2017-08-07 01:24:00+03	16400.00
79564B	2017-07-06 03:49:00+03	41300.00
7956C1	2017-07-07 08:12:00+03	111600.00
7956E1	2017-07-10 20:43:00+03	246000.00
795743	2017-07-28 14:29:00+03	24400.00
795779	2017-07-12 09:11:00+03	18000.00
79579B	2017-07-27 16:21:00+03	28800.00
79580C	2017-07-17 10:37:00+03	40000.00
795876	2017-07-08 02:52:00+03	81300.00
79587B	2017-07-07 10:46:00+03	112800.00
795889	2017-07-09 05:27:00+03	26000.00
7958A9	2017-07-10 03:20:00+03	56900.00
795924	2017-07-17 09:57:00+03	52000.00
795929	2017-08-06 21:51:00+03	26000.00
79592A	2017-07-05 07:07:00+03	31600.00
795931	2017-08-12 05:36:00+03	81600.00
7959DB	2017-07-27 03:53:00+03	179200.00
7959F0	2017-08-13 07:58:00+03	56000.00
7959F5	2017-08-08 00:05:00+03	46200.00
795A57	2017-08-11 12:56:00+03	38800.00
795ADE	2017-08-14 05:52:00+03	34600.00
795AE9	2017-08-14 18:27:00+03	23200.00
795B5B	2017-07-30 14:50:00+03	21200.00
795C1C	2017-08-01 15:15:00+03	25200.00
795C70	2017-08-10 06:01:00+03	59000.00
795C80	2017-07-09 04:49:00+03	56000.00
795CC1	2017-07-18 12:36:00+03	241300.00
795CE1	2017-08-04 15:09:00+03	92600.00
795D06	2017-08-05 23:51:00+03	167400.00
795E25	2017-08-12 06:37:00+03	127300.00
795E65	2017-08-09 05:23:00+03	56600.00
795E6F	2017-08-08 08:19:00+03	21600.00
795F1B	2017-07-09 07:45:00+03	93900.00
795F21	2017-06-30 03:49:00+03	77600.00
795F60	2017-08-13 17:29:00+03	123000.00
795F71	2017-08-01 02:37:00+03	13600.00
795FD6	2017-07-04 05:47:00+03	89600.00
796013	2017-08-10 05:39:00+03	44800.00
796029	2017-08-10 07:34:00+03	24400.00
796073	2017-07-13 15:43:00+03	27200.00
7960BF	2017-07-22 17:50:00+03	14400.00
7960C8	2017-07-10 04:36:00+03	16400.00
796100	2017-08-11 13:14:00+03	59800.00
796282	2017-08-07 06:53:00+03	57500.00
796283	2017-07-24 14:48:00+03	56600.00
7962C5	2017-08-15 13:14:00+03	172000.00
7962C9	2017-08-13 03:06:00+03	38900.00
79630A	2017-07-04 20:12:00+03	13200.00
796321	2017-08-09 14:35:00+03	78900.00
796331	2017-08-15 05:51:00+03	26000.00
796366	2017-07-24 08:09:00+03	32800.00
796404	2017-07-30 19:21:00+03	21400.00
79645E	2017-07-25 09:40:00+03	6800.00
796468	2017-07-15 10:08:00+03	40700.00
79646E	2017-08-10 13:17:00+03	28000.00
796477	2017-07-19 18:06:00+03	49100.00
7964E6	2017-08-04 04:53:00+03	92800.00
796625	2017-08-10 15:53:00+03	46300.00
796641	2017-07-05 17:37:00+03	8000.00
796654	2017-07-21 07:27:00+03	34000.00
796670	2017-07-02 23:16:00+03	23200.00
796689	2017-07-06 09:19:00+03	31600.00
796777	2017-07-21 12:34:00+03	66000.00
7968A0	2017-07-02 19:45:00+03	44000.00
7968B7	2017-08-07 21:22:00+03	94000.00
7968E3	2017-08-02 01:08:00+03	273400.00
796A5A	2017-07-15 02:09:00+03	67600.00
796A96	2017-06-30 16:52:00+03	267400.00
796AEB	2017-07-22 06:37:00+03	37600.00
796AEC	2017-07-13 09:09:00+03	6400.00
796B5A	2017-07-04 19:55:00+03	81300.00
796BC2	2017-08-06 15:10:00+03	89200.00
796C41	2017-07-21 09:19:00+03	34700.00
796CBE	2017-08-15 14:23:00+03	270700.00
796CC1	2017-07-12 11:36:00+03	25800.00
796CDE	2017-07-12 21:18:00+03	135200.00
796CEB	2017-07-01 20:24:00+03	34400.00
796E0C	2017-07-30 10:13:00+03	76600.00
796E2F	2017-07-26 00:06:00+03	45100.00
796E38	2017-08-09 12:01:00+03	205900.00
796E5B	2017-08-09 00:45:00+03	59800.00
796E95	2017-07-13 04:59:00+03	106100.00
796ECE	2017-08-15 03:11:00+03	12600.00
796ED5	2017-07-29 04:24:00+03	258400.00
796F69	2017-07-24 01:48:00+03	34700.00
796F9F	2017-07-13 06:46:00+03	31700.00
796FB1	2017-08-04 04:48:00+03	29400.00
796FD1	2017-07-30 16:25:00+03	43200.00
796FEF	2017-08-07 12:26:00+03	29600.00
797005	2017-07-07 10:19:00+03	282100.00
797055	2017-07-07 14:53:00+03	28800.00
7970D9	2017-07-09 00:27:00+03	15000.00
797110	2017-07-02 14:50:00+03	84300.00
797171	2017-07-02 22:02:00+03	78100.00
797180	2017-08-01 03:54:00+03	76100.00
797277	2017-08-02 00:54:00+03	13400.00
7972B8	2017-08-02 10:13:00+03	66600.00
7972EB	2017-07-22 06:41:00+03	40400.00
79737E	2017-07-21 11:10:00+03	25200.00
79739C	2017-07-31 00:38:00+03	240500.00
7973A5	2017-07-20 00:22:00+03	39800.00
797488	2017-07-26 19:28:00+03	66600.00
79751A	2017-08-03 09:47:00+03	155200.00
79756F	2017-07-10 05:53:00+03	243700.00
79759C	2017-07-01 02:57:00+03	207200.00
7975E3	2017-07-16 01:54:00+03	11800.00
797658	2017-08-11 17:52:00+03	32800.00
79765E	2017-07-28 10:57:00+03	56000.00
79766E	2017-07-02 06:57:00+03	14000.00
79773A	2017-08-15 11:52:00+03	28000.00
797748	2017-07-07 17:58:00+03	10800.00
79775C	2017-08-14 13:46:00+03	23200.00
797792	2017-08-15 07:22:00+03	24900.00
79779A	2017-07-07 09:10:00+03	46400.00
79785C	2017-07-29 09:01:00+03	26000.00
797885	2017-07-01 21:09:00+03	542200.00
7978BB	2017-07-11 12:50:00+03	110300.00
7979AB	2017-07-14 04:42:00+03	101100.00
7979B9	2017-08-14 08:56:00+03	42000.00
797A65	2017-07-23 03:23:00+03	42800.00
797A8A	2017-07-23 08:04:00+03	8000.00
797AC0	2017-07-02 11:56:00+03	128800.00
797B42	2017-07-11 04:41:00+03	68800.00
797BBD	2017-07-20 14:22:00+03	123000.00
797BC9	2017-06-27 17:42:00+03	39200.00
797C0F	2017-08-09 19:01:00+03	14300.00
797CF4	2017-07-14 12:25:00+03	144500.00
797D30	2017-07-07 05:23:00+03	19600.00
797DC3	2017-07-08 13:37:00+03	167500.00
797E09	2017-07-09 01:59:00+03	154100.00
797E35	2017-07-31 03:10:00+03	26800.00
797E99	2017-07-03 10:54:00+03	37100.00
797ED6	2017-07-21 21:51:00+03	62600.00
797F2A	2017-08-11 21:57:00+03	55800.00
797FF6	2017-06-29 19:44:00+03	122800.00
798025	2017-07-08 05:02:00+03	36200.00
79805F	2017-07-08 08:10:00+03	124200.00
79806D	2017-07-13 10:21:00+03	132800.00
79807B	2017-07-22 01:19:00+03	131600.00
7980B7	2017-07-21 16:09:00+03	170900.00
7980CE	2017-08-04 21:08:00+03	229500.00
798106	2017-07-20 18:22:00+03	542200.00
7981D1	2017-08-04 02:40:00+03	31300.00
7981FA	2017-08-01 07:03:00+03	6800.00
798220	2017-08-04 04:05:00+03	78200.00
7982AF	2017-08-01 13:49:00+03	252200.00
7982CD	2017-06-27 14:43:00+03	81300.00
7982E0	2017-07-04 20:03:00+03	32100.00
79832D	2017-08-15 00:27:00+03	54400.00
798340	2017-08-06 17:02:00+03	199700.00
798365	2017-07-25 11:23:00+03	58000.00
798366	2017-07-12 18:23:00+03	67600.00
798391	2017-07-13 00:22:00+03	106400.00
7983A3	2017-07-12 12:34:00+03	20200.00
798411	2017-08-10 14:11:00+03	56000.00
7984FA	2017-08-03 16:57:00+03	52000.00
798503	2017-07-08 01:02:00+03	151200.00
798511	2017-07-19 16:26:00+03	19100.00
798524	2017-08-15 02:25:00+03	27800.00
798531	2017-07-10 13:08:00+03	56100.00
798534	2017-08-10 15:38:00+03	135400.00
79855F	2017-07-20 04:26:00+03	212700.00
7985C4	2017-07-14 02:34:00+03	37900.00
798609	2017-07-12 08:42:00+03	25100.00
79868D	2017-07-15 19:14:00+03	372500.00
7986E3	2017-07-18 16:22:00+03	275700.00
798761	2017-07-07 09:00:00+03	112000.00
7987FB	2017-07-30 12:17:00+03	139300.00
798880	2017-07-09 09:28:00+03	56100.00
7988D8	2017-08-12 12:00:00+03	109800.00
7988E8	2017-07-08 12:07:00+03	36700.00
798912	2017-07-24 12:39:00+03	44800.00
7989C5	2017-07-28 11:18:00+03	58400.00
7989DA	2017-07-07 23:33:00+03	98200.00
798AA9	2017-07-04 22:20:00+03	23200.00
798B21	2017-08-14 17:44:00+03	47400.00
798BB0	2017-07-10 05:57:00+03	65400.00
798BBD	2017-07-08 14:39:00+03	54500.00
798C81	2017-07-15 17:00:00+03	21800.00
798CA1	2017-07-24 03:03:00+03	6400.00
798CAC	2017-06-29 18:54:00+03	40100.00
798CDA	2017-07-28 17:28:00+03	67100.00
798D1B	2017-07-11 06:55:00+03	28000.00
798DD8	2017-08-01 22:46:00+03	44600.00
798DDB	2017-07-02 18:48:00+03	53900.00
798E19	2017-08-03 08:58:00+03	34200.00
798E43	2017-07-14 01:08:00+03	28000.00
798EFA	2017-07-19 05:07:00+03	77900.00
798EFE	2017-07-13 16:08:00+03	57500.00
798F53	2017-08-05 17:57:00+03	272400.00
798F72	2017-08-02 06:43:00+03	112600.00
798FD8	2017-07-29 04:42:00+03	211300.00
79904F	2017-07-30 18:12:00+03	85000.00
7990C4	2017-07-29 09:15:00+03	14000.00
79914C	2017-07-05 01:59:00+03	55800.00
799155	2017-07-25 02:33:00+03	21800.00
799169	2017-08-11 11:52:00+03	266400.00
7991B0	2017-07-30 10:01:00+03	41600.00
7991D6	2017-07-18 15:54:00+03	46300.00
79920B	2017-08-04 20:51:00+03	139400.00
799236	2017-07-09 11:06:00+03	332800.00
799286	2017-08-02 20:08:00+03	95700.00
799292	2017-08-13 20:42:00+03	26700.00
7992F0	2017-07-08 01:30:00+03	229900.00
799305	2017-07-10 02:50:00+03	46200.00
79931F	2017-07-03 09:10:00+03	22000.00
799325	2017-08-09 03:16:00+03	31200.00
799328	2017-07-13 11:55:00+03	62700.00
79933A	2017-08-09 00:55:00+03	405100.00
7993AE	2017-08-03 20:38:00+03	46200.00
7993B7	2017-07-24 11:36:00+03	56000.00
79940A	2017-08-07 05:40:00+03	41600.00
799460	2017-08-03 19:16:00+03	101200.00
79947C	2017-07-30 04:59:00+03	98400.00
7994B3	2017-07-06 05:56:00+03	97000.00
799533	2017-07-09 00:19:00+03	53300.00
799538	2017-08-04 19:55:00+03	71600.00
799540	2017-08-06 10:35:00+03	12600.00
7995C7	2017-07-19 03:34:00+03	21400.00
799680	2017-07-26 13:18:00+03	79800.00
7996A9	2017-08-07 14:28:00+03	187800.00
799761	2017-07-28 04:34:00+03	332800.00
7997F9	2017-08-12 04:29:00+03	83600.00
79980C	2017-07-14 18:28:00+03	98400.00
799820	2017-08-11 13:12:00+03	118100.00
79983C	2017-07-07 19:52:00+03	28700.00
7998C0	2017-07-09 09:17:00+03	35600.00
7998D2	2017-08-05 11:25:00+03	81200.00
799927	2017-08-01 07:46:00+03	55800.00
79997F	2017-07-13 12:17:00+03	43200.00
7999D6	2017-08-08 03:20:00+03	6600.00
799A10	2017-07-14 13:31:00+03	48500.00
799A53	2017-06-30 03:45:00+03	259000.00
799A71	2017-07-16 19:29:00+03	77500.00
799A91	2017-08-05 06:07:00+03	148800.00
799AA4	2017-07-10 19:01:00+03	73300.00
799ADF	2017-07-06 15:11:00+03	32700.00
799B2A	2017-07-06 16:31:00+03	51800.00
799B76	2017-08-05 20:24:00+03	37200.00
799C2B	2017-07-30 22:42:00+03	156000.00
799C3F	2017-08-04 12:39:00+03	150600.00
799C47	2017-07-27 04:14:00+03	38800.00
799C62	2017-07-27 05:26:00+03	89200.00
799C85	2017-07-03 02:03:00+03	66000.00
799CA8	2017-07-16 02:40:00+03	59100.00
799CFC	2017-07-07 04:52:00+03	47000.00
799D30	2017-07-25 08:52:00+03	169300.00
799E3E	2017-08-13 01:35:00+03	31600.00
799E42	2017-07-27 22:36:00+03	42800.00
799E48	2017-07-10 15:52:00+03	44000.00
799EF3	2017-07-10 10:01:00+03	28800.00
799F90	2017-08-04 08:38:00+03	23200.00
799F94	2017-07-17 21:05:00+03	199200.00
799FCB	2017-07-01 19:50:00+03	271100.00
79A020	2017-07-31 04:15:00+03	11600.00
79A025	2017-07-30 10:46:00+03	26800.00
79A063	2017-07-24 01:06:00+03	46000.00
79A0A6	2017-06-30 02:36:00+03	38800.00
79A0C2	2017-08-13 02:29:00+03	386300.00
79A107	2017-07-15 23:25:00+03	75300.00
79A13F	2017-07-13 05:17:00+03	37000.00
79A15C	2017-07-10 11:11:00+03	133100.00
79A18C	2017-08-10 13:25:00+03	40400.00
79A1FF	2017-07-12 19:56:00+03	199200.00
79A218	2017-07-19 21:46:00+03	66900.00
79A2DE	2017-07-30 12:53:00+03	6000.00
79A361	2017-07-28 19:50:00+03	58400.00
79A3C4	2017-08-11 03:53:00+03	30200.00
79A423	2017-08-11 04:03:00+03	53500.00
79A437	2017-07-27 04:28:00+03	57500.00
79A446	2017-06-28 22:38:00+03	133200.00
79A47A	2017-07-25 20:58:00+03	39600.00
79A481	2017-07-26 16:54:00+03	124200.00
79A4FE	2017-07-03 05:26:00+03	112000.00
79A502	2017-07-17 02:23:00+03	23200.00
79A525	2017-07-19 15:51:00+03	40800.00
79A54E	2017-07-29 18:41:00+03	55800.00
79A577	2017-07-25 22:54:00+03	24600.00
79A5C0	2017-08-03 04:53:00+03	70700.00
79A5CB	2017-06-27 12:35:00+03	66600.00
79A615	2017-08-14 14:47:00+03	56600.00
79A618	2017-07-02 08:31:00+03	21800.00
79A619	2017-08-03 22:55:00+03	26200.00
79A70A	2017-07-13 19:31:00+03	531300.00
79A7B8	2017-08-14 14:39:00+03	36800.00
79A836	2017-07-04 15:48:00+03	49600.00
79A87F	2017-07-20 01:54:00+03	154500.00
79A886	2017-07-03 18:07:00+03	114200.00
79A89F	2017-07-06 06:23:00+03	28800.00
79A8CE	2017-08-04 22:24:00+03	111600.00
79A8E0	2017-08-12 20:40:00+03	43900.00
79A8FF	2017-07-21 09:39:00+03	48800.00
79A932	2017-08-14 20:36:00+03	135600.00
79A986	2017-08-08 11:15:00+03	184000.00
79A9A1	2017-07-21 06:20:00+03	25200.00
79A9DB	2017-07-05 21:51:00+03	332800.00
79AA6E	2017-07-04 10:30:00+03	199500.00
79AAA8	2017-07-22 05:42:00+03	159200.00
79AADC	2017-07-19 22:17:00+03	159200.00
79AB0D	2017-07-05 01:36:00+03	179400.00
79AC1A	2017-08-07 09:19:00+03	67700.00
79ACCC	2017-08-04 07:41:00+03	7400.00
79AD24	2017-07-03 06:19:00+03	23200.00
79AD49	2017-08-04 18:34:00+03	27900.00
79ADAA	2017-06-30 18:44:00+03	96200.00
79ADC5	2017-08-02 18:38:00+03	56000.00
79ADE0	2017-07-03 09:06:00+03	36200.00
79AE62	2017-07-20 18:02:00+03	94200.00
79AEC1	2017-08-04 17:44:00+03	75600.00
79AED1	2017-07-15 06:41:00+03	22000.00
79AEDE	2017-07-03 05:02:00+03	57600.00
79AF26	2017-07-21 16:27:00+03	238600.00
79AF36	2017-07-29 11:41:00+03	57500.00
79AF93	2017-07-16 18:52:00+03	54000.00
79AF9C	2017-07-19 04:19:00+03	86800.00
79AFB2	2017-07-21 22:25:00+03	52000.00
79AFBB	2017-07-02 18:24:00+03	67600.00
79AFDC	2017-07-02 13:58:00+03	56600.00
79AFE5	2017-07-16 17:08:00+03	37700.00
79AFF6	2017-07-18 12:20:00+03	55800.00
79B00D	2017-08-12 13:37:00+03	28800.00
79B05B	2017-07-07 01:01:00+03	112000.00
79B11F	2017-08-02 22:38:00+03	369000.00
79B122	2017-08-03 18:14:00+03	7400.00
79B126	2017-07-03 06:24:00+03	14000.00
79B157	2017-08-05 06:30:00+03	133200.00
79B174	2017-07-27 18:27:00+03	29500.00
79B185	2017-07-16 10:22:00+03	139800.00
79B1C1	2017-07-18 02:22:00+03	56000.00
79B1F9	2017-07-03 14:22:00+03	26000.00
79B248	2017-07-07 14:03:00+03	211100.00
79B2C5	2017-07-06 17:31:00+03	19600.00
79B2E8	2017-08-10 11:47:00+03	46300.00
79B337	2017-07-21 05:15:00+03	192900.00
79B397	2017-08-12 17:41:00+03	23200.00
79B3AD	2017-07-14 00:32:00+03	166100.00
79B3EB	2017-07-06 17:50:00+03	52700.00
79B473	2017-07-29 02:51:00+03	120900.00
79B4A2	2017-07-21 23:42:00+03	290600.00
79B54D	2017-08-06 18:06:00+03	265800.00
79B5D1	2017-07-23 16:56:00+03	43300.00
79B619	2017-08-10 13:47:00+03	231500.00
79B623	2017-07-29 00:30:00+03	28000.00
79B63D	2017-07-02 22:16:00+03	182300.00
79B650	2017-07-10 15:31:00+03	39400.00
79B684	2017-06-26 21:43:00+03	492000.00
79B69D	2017-07-16 07:23:00+03	55800.00
79B6A7	2017-07-07 10:12:00+03	37900.00
79B708	2017-07-07 19:39:00+03	272400.00
79B726	2017-07-27 04:15:00+03	28600.00
79B761	2017-07-13 06:13:00+03	87200.00
79B76F	2017-07-17 04:53:00+03	28800.00
79B7A1	2017-07-06 00:23:00+03	27200.00
79B7C9	2017-07-10 20:40:00+03	273000.00
79B831	2017-08-05 14:46:00+03	90800.00
79B869	2017-07-30 21:31:00+03	26000.00
79B874	2017-07-08 01:21:00+03	111600.00
79B8BA	2017-07-08 09:51:00+03	13200.00
79B92C	2017-07-07 20:39:00+03	24400.00
79B93B	2017-07-27 23:14:00+03	30200.00
79B96E	2017-07-04 06:10:00+03	28000.00
79B97E	2017-08-11 06:31:00+03	19600.00
79B9C9	2017-08-09 18:20:00+03	43900.00
79BA96	2017-07-07 02:34:00+03	133200.00
79BA99	2017-07-15 00:28:00+03	57800.00
79BAF1	2017-07-24 09:30:00+03	46000.00
79BBD4	2017-08-08 07:40:00+03	8200.00
79BBF7	2017-08-09 09:56:00+03	58900.00
79BC03	2017-08-02 14:36:00+03	115900.00
79BC1A	2017-07-29 16:27:00+03	33800.00
79BC1F	2017-08-15 06:34:00+03	199200.00
79BC40	2017-07-17 05:06:00+03	35600.00
79BC77	2017-07-29 21:05:00+03	59800.00
79BC8F	2017-07-21 12:54:00+03	23600.00
79BCB5	2017-08-08 07:05:00+03	92800.00
79BCCE	2017-07-21 14:22:00+03	10800.00
79BD9E	2017-07-29 10:10:00+03	61800.00
79BDB4	2017-07-13 18:53:00+03	23600.00
79BDEA	2017-08-02 16:44:00+03	56000.00
79BE59	2017-07-28 06:57:00+03	92800.00
79BE67	2017-07-20 21:03:00+03	57600.00
79BE8A	2017-08-02 11:35:00+03	102600.00
79BEB0	2017-07-10 00:29:00+03	32700.00
79BF04	2017-07-04 18:04:00+03	46000.00
79BF2B	2017-07-26 12:01:00+03	36200.00
79BF6C	2017-07-17 23:19:00+03	26000.00
79BF70	2017-07-18 04:03:00+03	95600.00
79BFE8	2017-08-12 22:06:00+03	20200.00
79C059	2017-07-07 19:11:00+03	553900.00
79C075	2017-08-14 05:01:00+03	55100.00
79C078	2017-07-14 00:29:00+03	94200.00
79C0D0	2017-08-09 02:54:00+03	123700.00
79C12A	2017-08-10 23:34:00+03	133900.00
79C139	2017-07-16 12:26:00+03	98200.00
79C13E	2017-07-08 19:47:00+03	9200.00
79C222	2017-07-13 07:09:00+03	57500.00
79C27A	2017-07-02 03:58:00+03	57600.00
79C2C1	2017-07-08 15:13:00+03	99700.00
79C2D2	2017-08-06 07:02:00+03	73600.00
79C2F2	2017-07-21 16:35:00+03	12600.00
79C303	2017-07-09 14:39:00+03	162200.00
79C336	2017-07-23 17:16:00+03	42800.00
79C354	2017-08-11 11:23:00+03	46000.00
79C35D	2017-07-23 23:02:00+03	64800.00
79C404	2017-08-03 03:34:00+03	58400.00
79C42E	2017-07-27 06:33:00+03	27200.00
79C47B	2017-07-20 02:51:00+03	123000.00
79C4E6	2017-07-07 18:12:00+03	70700.00
79C519	2017-08-11 21:16:00+03	14400.00
79C524	2017-08-11 20:53:00+03	158500.00
79C530	2017-07-15 10:32:00+03	75600.00
79C531	2017-07-03 18:11:00+03	136200.00
79C606	2017-08-03 11:26:00+03	254600.00
79C60C	2017-07-17 08:39:00+03	101200.00
79C64B	2017-07-22 16:29:00+03	130800.00
79C669	2017-08-15 03:46:00+03	61100.00
79C67D	2017-06-30 11:52:00+03	26000.00
79C68F	2017-07-06 20:10:00+03	25000.00
79C697	2017-08-12 16:29:00+03	12100.00
79C6BD	2017-07-05 23:11:00+03	664500.00
79C6FC	2017-08-10 17:22:00+03	123600.00
79C744	2017-07-25 10:41:00+03	72400.00
79C746	2017-07-28 03:11:00+03	65900.00
79C764	2017-07-26 23:45:00+03	56000.00
79C76C	2017-07-18 00:45:00+03	153300.00
79C78B	2017-07-26 10:10:00+03	47000.00
79C792	2017-08-12 06:25:00+03	26700.00
79C7B2	2017-08-03 21:06:00+03	138800.00
79C7FF	2017-08-03 15:02:00+03	55800.00
79C84A	2017-07-13 08:23:00+03	36200.00
79C8B4	2017-07-06 03:19:00+03	101500.00
79C8EC	2017-07-07 17:12:00+03	264600.00
79C8F4	2017-07-13 22:27:00+03	46700.00
79C8FA	2017-08-12 17:50:00+03	136800.00
79C947	2017-07-30 14:03:00+03	38800.00
79C95F	2017-07-08 16:09:00+03	42800.00
79C9AF	2017-07-21 14:50:00+03	76800.00
79CA7C	2017-07-06 07:15:00+03	23200.00
79CA8E	2017-07-03 12:13:00+03	294400.00
79CABE	2017-08-12 06:09:00+03	166000.00
79CADC	2017-07-15 07:16:00+03	54400.00
79CAF4	2017-08-10 23:31:00+03	135600.00
79CB72	2017-07-27 08:43:00+03	40200.00
79CC32	2017-07-13 07:28:00+03	26000.00
79CC87	2017-07-31 20:06:00+03	290500.00
79CCCF	2017-07-02 15:01:00+03	82300.00
79CD3C	2017-08-04 12:04:00+03	154800.00
79CD69	2017-08-03 18:32:00+03	14000.00
79CDE5	2017-08-13 11:50:00+03	56000.00
79CE05	2017-07-16 21:20:00+03	58400.00
79CE08	2017-08-13 09:11:00+03	372500.00
79CEE1	2017-08-07 08:52:00+03	224000.00
79CFAB	2017-07-03 16:54:00+03	43000.00
79CFBE	2017-07-25 17:55:00+03	102200.00
79CFDD	2017-07-21 07:02:00+03	82900.00
79D04C	2017-08-13 08:31:00+03	76100.00
79D08A	2017-07-04 08:25:00+03	23600.00
79D0F7	2017-08-15 17:20:00+03	63700.00
79D134	2017-08-02 09:38:00+03	56100.00
79D14F	2017-08-08 03:10:00+03	52300.00
79D154	2017-08-07 07:20:00+03	14700.00
79D1CB	2017-07-01 06:11:00+03	88000.00
79D1FD	2017-08-05 15:13:00+03	19600.00
79D279	2017-08-11 04:48:00+03	61400.00
79D286	2017-07-14 09:31:00+03	14400.00
79D3B5	2017-08-12 21:45:00+03	28700.00
79D3E1	2017-08-14 13:37:00+03	151000.00
79D481	2017-07-16 23:11:00+03	36200.00
79D4AF	2017-07-12 08:47:00+03	137600.00
79D4C9	2017-08-13 15:30:00+03	46000.00
79D503	2017-08-13 11:57:00+03	166100.00
79D529	2017-07-12 01:40:00+03	69500.00
79D552	2017-08-14 12:32:00+03	23600.00
79D580	2017-07-01 11:27:00+03	377600.00
79D58E	2017-08-12 09:26:00+03	284400.00
79D5AB	2017-07-21 20:30:00+03	135600.00
79D5C6	2017-07-09 09:19:00+03	55800.00
79D5E7	2017-08-03 03:19:00+03	114100.00
79D614	2017-08-06 15:24:00+03	80500.00
79D649	2017-07-26 17:03:00+03	366600.00
79D6A3	2017-07-15 12:10:00+03	54500.00
79D6BA	2017-06-27 09:05:00+03	110300.00
79D75F	2017-08-01 13:00:00+03	47600.00
79D763	2017-07-04 22:33:00+03	70500.00
79D76B	2017-07-17 14:02:00+03	12400.00
79D76D	2017-07-31 16:16:00+03	260300.00
79D7AA	2017-07-05 05:42:00+03	241300.00
79D7E2	2017-07-18 10:00:00+03	182500.00
79D806	2017-07-12 11:03:00+03	67600.00
79D831	2017-06-30 03:03:00+03	44000.00
79D8BC	2017-08-06 15:48:00+03	6700.00
79D922	2017-07-26 05:47:00+03	67700.00
79D94D	2017-07-18 21:02:00+03	39400.00
79D956	2017-08-08 09:44:00+03	100600.00
79D96D	2017-07-31 18:52:00+03	24400.00
79D979	2017-07-05 03:08:00+03	30000.00
79D98E	2017-07-06 09:16:00+03	201200.00
79D9F0	2017-07-09 09:49:00+03	30000.00
79DAB8	2017-08-12 18:15:00+03	44600.00
79DAD8	2017-08-04 05:23:00+03	30000.00
79DB2A	2017-06-30 00:58:00+03	100300.00
79DB2E	2017-07-04 09:49:00+03	59800.00
79DB61	2017-07-26 00:44:00+03	59200.00
79DC08	2017-07-05 06:55:00+03	44800.00
79DCA2	2017-07-08 09:54:00+03	259400.00
79DCBF	2017-08-08 01:51:00+03	61800.00
79DCC6	2017-08-04 16:53:00+03	58600.00
79DCC7	2017-08-03 11:05:00+03	28800.00
79DCDF	2017-07-08 22:34:00+03	43100.00
79DD21	2017-07-06 16:13:00+03	55800.00
79DD2E	2017-07-10 03:38:00+03	102100.00
79DD2F	2017-07-17 20:38:00+03	85700.00
79DD61	2017-08-06 02:55:00+03	257500.00
79DD89	2017-07-05 12:21:00+03	39300.00
79DDF9	2017-07-05 02:41:00+03	123600.00
79DE4D	2017-08-13 21:38:00+03	30900.00
79DE6F	2017-07-30 03:10:00+03	131100.00
79DE86	2017-07-16 07:13:00+03	210000.00
79DF0D	2017-07-31 10:16:00+03	12400.00
79DF63	2017-07-03 12:19:00+03	15000.00
79DF86	2017-07-29 05:44:00+03	32800.00
79DFBA	2017-07-16 17:06:00+03	12400.00
79DFE3	2017-08-15 09:51:00+03	43900.00
79DFF5	2017-07-31 21:49:00+03	48400.00
79DFF7	2017-07-26 17:36:00+03	29400.00
79E005	2017-08-12 11:26:00+03	49400.00
79E07B	2017-07-24 21:18:00+03	25600.00
79E0B8	2017-08-15 17:59:00+03	99300.00
79E0C6	2017-07-01 13:31:00+03	43200.00
79E0F7	2017-07-29 17:20:00+03	81300.00
79E102	2017-07-21 23:15:00+03	40000.00
79E11C	2017-08-06 07:07:00+03	86500.00
79E159	2017-07-30 08:22:00+03	12600.00
79E15A	2017-07-18 00:14:00+03	62600.00
79E16E	2017-08-13 00:16:00+03	25800.00
79E182	2017-07-11 07:10:00+03	65900.00
79E1F3	2017-07-11 00:58:00+03	22000.00
79E1F4	2017-08-05 03:36:00+03	25600.00
79E258	2017-06-28 06:06:00+03	46400.00
79E259	2017-08-07 16:00:00+03	46700.00
79E2A1	2017-08-02 00:44:00+03	143200.00
79E2C0	2017-07-21 15:41:00+03	54800.00
79E321	2017-07-10 00:12:00+03	86800.00
79E339	2017-08-12 06:28:00+03	21400.00
79E34E	2017-06-30 05:49:00+03	47200.00
79E3A7	2017-08-11 14:16:00+03	78600.00
79E3DE	2017-08-09 22:31:00+03	86800.00
79E3ED	2017-07-23 12:25:00+03	27700.00
79E41F	2017-07-31 01:38:00+03	89600.00
79E42E	2017-08-13 02:56:00+03	58000.00
79E4C0	2017-07-03 19:04:00+03	161600.00
79E4C4	2017-08-09 07:49:00+03	68000.00
79E4E6	2017-07-05 12:18:00+03	88100.00
79E57C	2017-07-09 18:34:00+03	14000.00
79E58F	2017-07-02 21:58:00+03	34000.00
79E5C8	2017-07-26 23:06:00+03	8400.00
79E5D8	2017-07-05 11:49:00+03	15400.00
79E5E5	2017-07-14 17:04:00+03	68800.00
79E5F3	2017-07-15 14:23:00+03	25800.00
79E66F	2017-07-31 15:26:00+03	57400.00
79E6E6	2017-08-14 17:31:00+03	28800.00
79E77B	2017-08-11 02:48:00+03	43600.00
79E7B7	2017-07-14 16:49:00+03	199300.00
79E7D2	2017-07-20 00:25:00+03	12400.00
79E7E7	2017-08-09 03:44:00+03	73300.00
79E819	2017-07-11 11:57:00+03	52000.00
79E89B	2017-07-20 11:10:00+03	105800.00
79E931	2017-08-13 21:23:00+03	93600.00
79E94A	2017-07-02 16:41:00+03	49800.00
79E964	2017-08-02 11:27:00+03	60700.00
79E9B2	2017-07-28 01:08:00+03	44400.00
79EB0F	2017-07-26 06:49:00+03	35600.00
79EB45	2017-07-10 02:10:00+03	40800.00
79EB85	2017-07-06 20:49:00+03	654100.00
79EB88	2017-07-08 07:15:00+03	71400.00
79EBD8	2017-07-10 23:11:00+03	92600.00
79EC17	2017-08-03 12:23:00+03	50300.00
79EC7F	2017-07-13 09:19:00+03	26800.00
79ECBE	2017-07-10 17:24:00+03	169400.00
79ECD1	2017-08-01 08:24:00+03	30200.00
79ED5F	2017-07-28 22:08:00+03	30800.00
79ED8F	2017-07-27 09:22:00+03	26000.00
79EDBD	2017-07-24 00:09:00+03	23200.00
79EDE3	2017-07-08 05:37:00+03	47100.00
79EDF7	2017-07-04 06:14:00+03	369000.00
79EE3E	2017-07-17 00:33:00+03	21800.00
79EE70	2017-07-23 15:15:00+03	100600.00
79EE9C	2017-06-27 04:46:00+03	277900.00
79EF5A	2017-08-13 17:30:00+03	56800.00
79EF8A	2017-08-10 15:27:00+03	37900.00
79F034	2017-07-30 22:05:00+03	34000.00
79F059	2017-07-16 08:56:00+03	54300.00
79F073	2017-07-15 12:47:00+03	46400.00
79F0CA	2017-08-04 07:34:00+03	192500.00
79F136	2017-07-25 07:27:00+03	47500.00
79F186	2017-07-21 13:06:00+03	62700.00
79F190	2017-08-04 21:28:00+03	177200.00
79F198	2017-08-09 15:20:00+03	10700.00
79F19F	2017-08-04 07:04:00+03	89600.00
79F20A	2017-07-20 14:05:00+03	28000.00
79F275	2017-07-30 22:17:00+03	49800.00
79F29D	2017-07-27 23:04:00+03	128800.00
79F308	2017-07-25 06:53:00+03	103500.00
79F314	2017-08-14 12:58:00+03	70400.00
79F37A	2017-07-27 01:38:00+03	131100.00
79F392	2017-08-12 05:41:00+03	94800.00
79F3CD	2017-08-10 07:04:00+03	12600.00
79F3DE	2017-08-05 22:37:00+03	55800.00
79F3EB	2017-06-26 13:17:00+03	18600.00
79F40F	2017-08-08 03:48:00+03	65900.00
79F44E	2017-07-25 22:48:00+03	10700.00
79F44F	2017-08-03 06:29:00+03	114400.00
79F526	2017-08-14 16:19:00+03	37900.00
79F55B	2017-07-15 04:52:00+03	111600.00
79F5A5	2017-07-16 22:13:00+03	78100.00
79F5D8	2017-08-11 18:24:00+03	51800.00
79F712	2017-08-12 04:18:00+03	26000.00
79F722	2017-08-01 09:00:00+03	79900.00
79F78B	2017-08-11 19:28:00+03	73600.00
79F7A1	2017-07-02 05:17:00+03	58600.00
79F7DC	2017-07-16 10:36:00+03	34000.00
79F7E0	2017-07-27 19:40:00+03	12200.00
79F80E	2017-07-20 12:46:00+03	20800.00
79F86F	2017-08-06 10:47:00+03	57600.00
79F89E	2017-07-24 16:06:00+03	132800.00
79F96F	2017-07-10 11:00:00+03	40600.00
79FA92	2017-07-25 17:57:00+03	72800.00
79FACE	2017-07-23 04:39:00+03	131100.00
79FAFE	2017-07-24 23:43:00+03	32700.00
79FB01	2017-07-09 06:02:00+03	114200.00
79FB19	2017-07-22 21:23:00+03	10700.00
79FB39	2017-07-04 21:40:00+03	51800.00
79FB66	2017-07-10 12:22:00+03	25600.00
79FBA5	2017-07-16 23:07:00+03	36800.00
79FBEA	2017-07-27 01:20:00+03	47200.00
79FC55	2017-08-02 23:44:00+03	123000.00
79FCB1	2017-08-06 20:48:00+03	63000.00
79FCD3	2017-07-15 23:02:00+03	9800.00
79FCE9	2017-07-01 00:20:00+03	26700.00
79FCFA	2017-07-24 07:35:00+03	61800.00
79FD14	2017-08-09 13:18:00+03	39300.00
79FD36	2017-08-15 09:43:00+03	77200.00
79FD5A	2017-07-09 08:34:00+03	15100.00
79FD93	2017-07-02 09:05:00+03	90800.00
79FDB7	2017-08-05 10:35:00+03	398500.00
79FDC9	2017-08-07 17:13:00+03	58600.00
79FDE8	2017-07-12 09:13:00+03	7400.00
79FE5C	2017-08-06 20:15:00+03	67600.00
79FE77	2017-07-04 16:04:00+03	23200.00
79FEE3	2017-08-14 23:29:00+03	12000.00
79FF3A	2017-08-11 15:59:00+03	19600.00
79FF3C	2017-08-11 18:07:00+03	14000.00
79FF75	2017-07-21 19:11:00+03	125100.00
79FFF7	2017-08-12 23:40:00+03	16800.00
7A0042	2017-08-09 00:37:00+03	266400.00
7A00E8	2017-07-05 18:24:00+03	81700.00
7A00FC	2017-08-05 19:12:00+03	64500.00
7A0165	2017-08-05 16:15:00+03	10800.00
7A0193	2017-08-07 22:54:00+03	46400.00
7A0194	2017-07-08 15:04:00+03	26000.00
7A01B6	2017-07-20 21:15:00+03	22000.00
7A0218	2017-08-15 02:00:00+03	24400.00
7A027F	2017-08-01 13:39:00+03	46300.00
7A02A7	2017-07-16 13:53:00+03	149800.00
7A02AB	2017-07-01 09:40:00+03	14400.00
7A02B2	2017-08-05 13:07:00+03	24400.00
7A02C5	2017-07-01 03:06:00+03	14400.00
7A02F1	2017-08-13 16:57:00+03	96300.00
7A0318	2017-07-18 18:29:00+03	86800.00
7A0320	2017-08-07 17:59:00+03	15400.00
7A035F	2017-07-23 00:36:00+03	44000.00
7A03F7	2017-08-02 15:51:00+03	115100.00
7A0409	2017-06-28 11:01:00+03	56000.00
7A0425	2017-08-07 19:48:00+03	11800.00
7A048F	2017-07-11 21:30:00+03	64400.00
7A04B5	2017-06-30 18:45:00+03	54100.00
7A04C3	2017-07-11 11:43:00+03	20600.00
7A04EC	2017-07-03 10:57:00+03	205600.00
7A0535	2017-07-11 09:16:00+03	69900.00
7A0536	2017-07-04 17:57:00+03	100600.00
7A0538	2017-07-04 10:51:00+03	136800.00
7A057B	2017-07-30 04:58:00+03	9800.00
7A05B5	2017-08-06 07:37:00+03	28000.00
7A05EC	2017-08-04 06:20:00+03	59800.00
7A05ED	2017-06-30 14:32:00+03	151200.00
7A0606	2017-07-11 20:13:00+03	6700.00
7A061A	2017-07-02 04:07:00+03	123600.00
7A0685	2017-07-14 01:28:00+03	13400.00
7A069F	2017-08-11 21:59:00+03	27900.00
7A06A3	2017-08-05 18:50:00+03	67600.00
7A06D7	2017-07-10 22:18:00+03	27900.00
7A06F9	2017-08-06 04:05:00+03	31200.00
7A070E	2017-07-09 13:48:00+03	79700.00
7A076C	2017-07-22 07:44:00+03	73300.00
7A076F	2017-07-30 11:57:00+03	39600.00
7A0780	2017-06-30 19:13:00+03	148200.00
7A07FF	2017-07-06 18:44:00+03	67600.00
7A0863	2017-08-10 03:25:00+03	23200.00
7A0889	2017-07-15 13:28:00+03	65800.00
7A08AB	2017-07-01 06:53:00+03	52100.00
7A08DA	2017-07-05 12:38:00+03	87600.00
7A08E5	2017-07-26 16:01:00+03	107300.00
7A0926	2017-08-13 13:28:00+03	38300.00
7A097E	2017-07-05 09:08:00+03	52300.00
7A09CE	2017-07-13 01:33:00+03	91600.00
7A09FB	2017-07-14 21:58:00+03	78300.00
7A0A06	2017-08-03 11:40:00+03	29200.00
7A0A5E	2017-08-15 08:10:00+03	78300.00
7A0A6B	2017-07-15 11:46:00+03	26200.00
7A0A88	2017-08-15 00:40:00+03	48800.00
7A0ACA	2017-06-28 12:25:00+03	116800.00
7A0B0C	2017-07-28 13:17:00+03	131600.00
7A0B36	2017-07-25 18:05:00+03	28000.00
7A0B75	2017-07-31 21:38:00+03	112600.00
7A0B99	2017-08-12 16:32:00+03	12600.00
7A0BAA	2017-07-21 16:05:00+03	28000.00
7A0C41	2017-07-10 23:29:00+03	56900.00
7A0C6A	2017-07-28 22:32:00+03	145200.00
7A0C85	2017-07-30 07:00:00+03	25100.00
7A0DC8	2017-07-11 07:02:00+03	14000.00
7A0E52	2017-07-10 19:45:00+03	54000.00
7A0E57	2017-08-01 21:51:00+03	75600.00
7A0EA7	2017-06-29 20:21:00+03	22000.00
7A0F88	2017-08-02 11:52:00+03	11800.00
7A0F98	2017-07-27 01:53:00+03	96400.00
7A0FFD	2017-07-28 09:38:00+03	175300.00
7A106C	2017-07-28 23:47:00+03	99700.00
7A10AB	2017-07-10 07:28:00+03	142800.00
7A10C7	2017-07-10 09:29:00+03	30400.00
7A1185	2017-07-11 09:52:00+03	41800.00
7A11A4	2017-07-25 20:06:00+03	229300.00
7A11D4	2017-07-23 19:58:00+03	110500.00
7A122B	2017-08-06 11:32:00+03	114800.00
7A1233	2017-08-13 07:19:00+03	31600.00
7A1288	2017-07-20 07:11:00+03	193700.00
7A1296	2017-08-15 05:58:00+03	49700.00
7A1324	2017-07-24 17:50:00+03	399600.00
7A1372	2017-07-25 06:37:00+03	103200.00
7A13C8	2017-08-10 14:06:00+03	18300.00
7A13E6	2017-07-11 16:36:00+03	27900.00
7A1417	2017-07-30 03:34:00+03	243600.00
7A145E	2017-07-05 08:39:00+03	44000.00
7A146C	2017-08-14 16:26:00+03	43200.00
7A1482	2017-07-11 03:36:00+03	73100.00
7A1495	2017-08-15 07:25:00+03	24800.00
7A149E	2017-07-13 19:54:00+03	23600.00
7A14D2	2017-07-31 23:38:00+03	109600.00
7A15E9	2017-07-22 12:53:00+03	99300.00
7A15F1	2017-07-16 09:30:00+03	67600.00
7A1602	2017-07-03 01:58:00+03	55800.00
7A1607	2017-08-03 11:11:00+03	34000.00
7A161B	2017-08-09 00:16:00+03	114800.00
7A1624	2017-07-20 07:26:00+03	23400.00
7A163F	2017-07-31 19:18:00+03	125200.00
7A164E	2017-07-05 11:51:00+03	67600.00
7A16B6	2017-08-10 11:20:00+03	14000.00
7A1729	2017-07-21 21:44:00+03	75600.00
7A1731	2017-07-21 08:16:00+03	19600.00
7A175A	2017-07-25 20:06:00+03	21800.00
7A179A	2017-07-28 22:38:00+03	36200.00
7A1826	2017-07-02 05:25:00+03	60400.00
7A1833	2017-07-14 14:16:00+03	57700.00
7A1860	2017-08-08 10:16:00+03	47300.00
7A186E	2017-07-15 08:21:00+03	26600.00
7A1882	2017-07-10 07:00:00+03	140900.00
7A18BF	2017-07-20 13:52:00+03	45200.00
7A1905	2017-07-08 02:14:00+03	35700.00
7A1917	2017-06-29 13:40:00+03	23200.00
7A19B2	2017-08-04 13:05:00+03	136500.00
7A1AD7	2017-08-10 04:08:00+03	180200.00
7A1B18	2017-07-24 23:56:00+03	25000.00
7A1B44	2017-07-20 07:04:00+03	62000.00
7A1B62	2017-08-14 09:14:00+03	52700.00
7A1B6B	2017-07-11 22:19:00+03	19600.00
7A1BA1	2017-07-19 08:31:00+03	9800.00
7A1BBD	2017-07-11 17:58:00+03	26000.00
7A1BE1	2017-07-08 05:48:00+03	67400.00
7A1BE8	2017-07-27 07:49:00+03	26200.00
7A1C37	2017-07-12 18:25:00+03	135400.00
7A1C6B	2017-07-14 08:27:00+03	57500.00
7A1C85	2017-07-31 21:31:00+03	75100.00
7A1C93	2017-08-07 03:42:00+03	33100.00
7A1C96	2017-07-11 22:54:00+03	122100.00
7A1CCE	2017-08-15 02:27:00+03	24000.00
7A1CFD	2017-07-12 03:56:00+03	8200.00
7A1D0D	2017-07-09 21:52:00+03	13600.00
7A1D34	2017-08-11 22:34:00+03	246200.00
7A1D97	2017-07-14 16:59:00+03	57400.00
7A1E37	2017-07-27 07:40:00+03	23200.00
7A1E4C	2017-07-20 03:43:00+03	26800.00
7A1E61	2017-08-07 12:32:00+03	30400.00
7A1E6C	2017-08-07 18:20:00+03	112600.00
7A1F02	2017-07-03 21:06:00+03	38800.00
7A1F05	2017-07-14 16:22:00+03	99200.00
7A1F29	2017-07-06 19:22:00+03	31600.00
7A1F9A	2017-07-12 00:07:00+03	49200.00
7A200E	2017-07-16 11:44:00+03	111600.00
7A2034	2017-07-20 18:46:00+03	28000.00
7A2075	2017-07-07 06:12:00+03	100600.00
7A212B	2017-07-16 03:30:00+03	89700.00
7A2181	2017-07-02 00:08:00+03	85000.00
7A21D6	2017-08-03 12:18:00+03	46000.00
7A21E3	2017-07-08 14:49:00+03	51900.00
7A21F7	2017-07-28 21:18:00+03	27200.00
7A2294	2017-07-18 17:50:00+03	56000.00
7A22A7	2017-07-19 14:21:00+03	18000.00
7A22B1	2017-07-08 14:40:00+03	270800.00
7A22BA	2017-07-01 09:07:00+03	56100.00
7A2484	2017-07-11 17:13:00+03	14400.00
7A24BB	2017-08-05 15:24:00+03	181600.00
7A24F7	2017-07-22 22:18:00+03	89600.00
7A2512	2017-08-05 17:45:00+03	129000.00
7A251F	2017-07-17 05:57:00+03	64600.00
7A2581	2017-07-17 03:53:00+03	201200.00
7A25BD	2017-07-04 18:04:00+03	32800.00
7A25E3	2017-07-26 02:18:00+03	112000.00
7A25F8	2017-08-15 09:54:00+03	75300.00
7A261C	2017-07-08 22:39:00+03	52300.00
7A2642	2017-08-04 13:27:00+03	21400.00
7A2660	2017-07-16 10:34:00+03	81700.00
7A269A	2017-08-07 05:52:00+03	54500.00
7A2727	2017-08-10 03:48:00+03	12600.00
7A2743	2017-08-06 20:28:00+03	23200.00
7A27AD	2017-08-15 14:48:00+03	4000.00
7A27CD	2017-08-07 05:28:00+03	51600.00
7A27E0	2017-07-31 22:30:00+03	23200.00
7A27EB	2017-06-29 03:01:00+03	199300.00
7A27FB	2017-07-09 05:52:00+03	114800.00
7A284C	2017-08-03 18:19:00+03	123000.00
7A286F	2017-07-31 11:04:00+03	216100.00
7A28C3	2017-07-17 07:29:00+03	369000.00
7A294A	2017-07-07 00:31:00+03	116800.00
7A294E	2017-07-26 14:51:00+03	170800.00
7A299C	2017-08-15 02:29:00+03	199700.00
7A29AA	2017-08-01 09:59:00+03	41600.00
7A2A81	2017-08-10 21:47:00+03	211500.00
7A2A94	2017-08-09 09:34:00+03	147600.00
7A2B17	2017-07-11 09:41:00+03	24800.00
7A2C38	2017-07-06 22:44:00+03	28800.00
7A2C69	2017-07-04 03:09:00+03	32800.00
7A2C80	2017-08-10 00:34:00+03	189200.00
7A2C81	2017-08-08 02:16:00+03	16400.00
7A2CB3	2017-07-19 12:01:00+03	99200.00
7A2D51	2017-08-10 16:53:00+03	31800.00
7A2D87	2017-07-01 07:52:00+03	81600.00
7A2DAC	2017-07-16 22:02:00+03	47000.00
7A2DC2	2017-07-17 14:28:00+03	98200.00
7A2E9B	2017-07-03 09:12:00+03	105600.00
7A2EBD	2017-07-27 03:02:00+03	81600.00
7A2F33	2017-07-02 12:41:00+03	40600.00
7A2FD5	2017-07-06 14:23:00+03	23200.00
7A3011	2017-07-19 13:12:00+03	100600.00
7A304B	2017-07-28 12:11:00+03	42700.00
7A306A	2017-08-06 23:43:00+03	67600.00
7A307C	2017-08-11 00:15:00+03	102100.00
7A30B4	2017-08-08 09:41:00+03	56100.00
7A30B7	2017-08-03 17:10:00+03	133200.00
7A30F7	2017-08-07 03:35:00+03	38600.00
7A3101	2017-08-04 05:23:00+03	73600.00
7A3140	2017-08-12 14:23:00+03	38400.00
7A31E8	2017-07-27 12:51:00+03	24400.00
7A321E	2017-07-11 06:30:00+03	26000.00
7A324C	2017-07-26 13:32:00+03	59800.00
7A335B	2017-07-09 01:10:00+03	94400.00
7A336B	2017-08-02 22:06:00+03	59200.00
7A3395	2017-07-29 11:01:00+03	87100.00
7A339C	2017-07-14 19:56:00+03	170200.00
7A3455	2017-07-13 14:06:00+03	288300.00
7A3458	2017-08-13 19:06:00+03	175200.00
7A34A0	2017-07-23 03:04:00+03	13200.00
7A356A	2017-08-12 18:32:00+03	58400.00
7A358A	2017-08-12 22:07:00+03	28800.00
7A35AA	2017-08-05 15:09:00+03	28000.00
7A35DA	2017-07-25 15:20:00+03	7400.00
7A35EC	2017-08-10 04:21:00+03	55800.00
7A35F6	2017-07-09 23:06:00+03	11800.00
7A362E	2017-08-05 20:15:00+03	66600.00
7A364C	2017-08-10 02:14:00+03	46400.00
7A36B5	2017-07-06 13:30:00+03	52800.00
7A36CB	2017-08-07 19:21:00+03	25100.00
7A36F3	2017-08-09 06:19:00+03	21200.00
7A377C	2017-07-13 14:51:00+03	71400.00
7A381A	2017-07-30 06:26:00+03	6200.00
7A38BE	2017-08-01 04:34:00+03	280000.00
7A38CB	2017-08-15 10:12:00+03	28700.00
7A3910	2017-08-05 15:52:00+03	61500.00
7A392D	2017-06-29 19:29:00+03	36200.00
7A3952	2017-07-17 02:53:00+03	99600.00
7A39C0	2017-07-03 17:26:00+03	46400.00
7A39CB	2017-08-13 07:22:00+03	59200.00
7A3A58	2017-07-09 07:24:00+03	60800.00
7A3A70	2017-07-03 19:00:00+03	46400.00
7A3ACF	2017-06-29 11:15:00+03	32400.00
7A3AEC	2017-08-13 08:36:00+03	133200.00
7A3B06	2017-07-20 16:50:00+03	52800.00
7A3B13	2017-07-23 09:06:00+03	20000.00
7A3B51	2017-08-10 23:24:00+03	88100.00
7A3B87	2017-07-11 22:45:00+03	35800.00
7A3BC8	2017-08-10 21:15:00+03	12400.00
7A3C02	2017-07-31 17:18:00+03	47600.00
7A3C12	2017-07-07 07:12:00+03	49600.00
7A3C37	2017-08-14 09:13:00+03	94000.00
7A3C77	2017-07-19 10:44:00+03	66000.00
7A3C9F	2017-07-06 13:11:00+03	61800.00
7A3CA2	2017-07-05 05:43:00+03	34200.00
7A3CB2	2017-07-26 20:58:00+03	54000.00
7A3CE2	2017-08-11 07:51:00+03	53500.00
7A3CF5	2017-07-18 13:03:00+03	19600.00
7A3DB0	2017-08-14 20:22:00+03	17700.00
7A3E53	2017-08-03 01:00:00+03	28300.00
7A3E96	2017-08-15 05:42:00+03	32600.00
7A3F71	2017-07-18 15:56:00+03	40600.00
7A3FEA	2017-07-07 19:35:00+03	48800.00
7A4009	2017-07-16 20:29:00+03	147200.00
7A401B	2017-08-13 16:27:00+03	75900.00
7A4095	2017-07-20 05:43:00+03	6700.00
7A40C6	2017-08-12 13:14:00+03	6800.00
7A40D0	2017-08-09 14:05:00+03	27800.00
7A40F4	2017-07-13 21:10:00+03	44000.00
7A42BB	2017-08-13 01:11:00+03	44000.00
7A4305	2017-07-16 15:43:00+03	37500.00
7A431A	2017-07-27 11:06:00+03	133100.00
7A4332	2017-07-26 10:37:00+03	46000.00
7A4357	2017-07-24 23:12:00+03	119300.00
7A4395	2017-07-16 05:28:00+03	13400.00
7A439A	2017-08-12 13:17:00+03	25200.00
7A442E	2017-08-09 01:04:00+03	21400.00
7A4433	2017-07-24 16:29:00+03	92700.00
7A447C	2017-07-22 17:09:00+03	40000.00
7A44B7	2017-08-01 02:56:00+03	88200.00
7A458F	2017-08-08 05:35:00+03	54800.00
7A45B4	2017-07-10 03:01:00+03	30200.00
7A4615	2017-08-11 12:53:00+03	18800.00
7A461F	2017-07-26 15:57:00+03	96300.00
7A4620	2017-07-18 23:45:00+03	25200.00
7A465C	2017-08-01 16:51:00+03	51200.00
7A46C7	2017-08-08 08:10:00+03	151200.00
7A474E	2017-07-07 04:42:00+03	28000.00
7A47AA	2017-07-22 07:00:00+03	144300.00
7A47CE	2017-07-23 02:57:00+03	184600.00
7A4834	2017-07-23 19:36:00+03	131100.00
7A483B	2017-07-22 06:14:00+03	7200.00
7A48BA	2017-08-05 04:50:00+03	35200.00
7A48E1	2017-07-08 00:33:00+03	40600.00
7A4930	2017-08-13 02:34:00+03	62000.00
7A4959	2017-08-11 20:45:00+03	68000.00
7A49D7	2017-07-10 17:31:00+03	46000.00
7A4A07	2017-07-15 01:57:00+03	31600.00
7A4AA6	2017-08-15 11:03:00+03	31700.00
7A4ACF	2017-07-02 19:37:00+03	39700.00
7A4AE6	2017-07-26 22:38:00+03	36000.00
7A4AEF	2017-08-10 01:20:00+03	24200.00
7A4B30	2017-07-23 00:23:00+03	60300.00
7A4B3F	2017-07-21 01:40:00+03	18800.00
7A4BCC	2017-07-08 05:25:00+03	270700.00
7A4C52	2017-07-16 01:10:00+03	136000.00
7A4C54	2017-07-05 02:51:00+03	67800.00
7A4C72	2017-07-19 01:00:00+03	55600.00
7A4C73	2017-08-03 11:26:00+03	62000.00
7A4C76	2017-07-28 21:09:00+03	76600.00
7A4CBC	2017-07-28 00:23:00+03	119400.00
7A4CE4	2017-07-12 00:17:00+03	20500.00
7A4D33	2017-07-25 07:22:00+03	115000.00
7A4D6F	2017-08-11 09:14:00+03	86300.00
7A4DD4	2017-07-22 16:57:00+03	26800.00
7A4E0A	2017-08-13 03:57:00+03	46200.00
7A4E11	2017-07-27 04:28:00+03	76600.00
7A4E83	2017-07-16 22:47:00+03	260900.00
7A4EE7	2017-07-21 02:38:00+03	119700.00
7A4F0C	2017-07-19 10:47:00+03	14000.00
7A4F41	2017-07-19 23:58:00+03	11800.00
7A4F99	2017-08-01 22:54:00+03	369000.00
7A4FED	2017-08-04 12:25:00+03	159800.00
7A4FFD	2017-07-06 11:39:00+03	199700.00
7A5006	2017-08-12 21:49:00+03	27400.00
7A5011	2017-07-18 09:31:00+03	105900.00
7A5054	2017-08-03 02:01:00+03	54800.00
7A5069	2017-07-25 19:23:00+03	46400.00
7A5072	2017-07-15 16:41:00+03	56000.00
7A50BE	2017-07-19 14:44:00+03	26000.00
7A5116	2017-07-15 04:37:00+03	57700.00
7A514F	2017-07-30 19:30:00+03	16400.00
7A515A	2017-08-13 18:24:00+03	48000.00
7A51CB	2017-07-21 19:38:00+03	8200.00
7A51DE	2017-08-06 12:22:00+03	88800.00
7A5217	2017-08-09 13:20:00+03	81700.00
7A526A	2017-07-07 03:44:00+03	183100.00
7A5296	2017-07-02 14:13:00+03	35800.00
7A52A6	2017-08-14 19:01:00+03	78600.00
7A532B	2017-07-22 09:25:00+03	32800.00
7A53BF	2017-08-07 09:48:00+03	92000.00
7A53CA	2017-08-14 23:19:00+03	27000.00
7A5405	2017-07-24 02:29:00+03	135000.00
7A5471	2017-07-14 01:14:00+03	52000.00
7A555E	2017-07-13 02:57:00+03	54500.00
7A55B2	2017-08-07 02:53:00+03	67600.00
7A55FE	2017-07-20 22:28:00+03	30400.00
7A560A	2017-08-03 07:51:00+03	89600.00
7A5628	2017-08-04 00:25:00+03	6300.00
7A5662	2017-07-05 21:58:00+03	135400.00
7A56DE	2017-07-28 03:35:00+03	36500.00
7A56F6	2017-08-04 05:12:00+03	26000.00
7A5711	2017-07-09 18:10:00+03	55800.00
7A5754	2017-07-13 13:28:00+03	56000.00
7A575E	2017-07-24 00:36:00+03	95200.00
7A5762	2017-07-29 22:05:00+03	223200.00
7A577E	2017-07-29 11:57:00+03	72200.00
7A57B7	2017-08-06 14:05:00+03	38600.00
7A57DE	2017-07-12 01:21:00+03	90600.00
7A57F7	2017-07-11 19:43:00+03	269200.00
7A5888	2017-07-19 02:12:00+03	112600.00
7A5898	2017-07-27 10:27:00+03	89600.00
7A58A7	2017-07-21 15:41:00+03	129200.00
7A5948	2017-08-03 04:36:00+03	16400.00
7A5969	2017-07-01 13:12:00+03	38800.00
7A59E7	2017-07-28 10:58:00+03	37900.00
7A59F6	2017-08-10 13:46:00+03	26600.00
7A5B0B	2017-07-30 02:50:00+03	40000.00
7A5B23	2017-07-13 13:33:00+03	80000.00
7A5B29	2017-07-29 02:08:00+03	22000.00
7A5B79	2017-07-05 17:29:00+03	25200.00
7A5BF7	2017-06-29 13:10:00+03	72000.00
7A5BFC	2017-07-21 19:10:00+03	11800.00
7A5C36	2017-07-13 07:35:00+03	77000.00
7A5C3F	2017-07-03 11:10:00+03	24400.00
7A5C4A	2017-07-08 15:44:00+03	82900.00
7A5C79	2017-07-03 23:25:00+03	33300.00
7A5C96	2017-07-05 23:55:00+03	74600.00
7A5CD8	2017-07-20 22:42:00+03	34600.00
7A5D14	2017-08-11 11:04:00+03	32700.00
7A5D35	2017-08-09 06:48:00+03	50800.00
7A5D46	2017-07-25 21:22:00+03	25800.00
7A5D86	2017-08-01 01:04:00+03	41800.00
7A5D8F	2017-07-22 08:01:00+03	192400.00
7A5DD4	2017-07-02 17:05:00+03	91100.00
7A5E1A	2017-08-07 04:27:00+03	84100.00
7A5E3A	2017-08-08 03:24:00+03	93900.00
7A5E58	2017-07-23 23:14:00+03	154000.00
7A5F0F	2017-08-14 23:32:00+03	27700.00
7A5F2A	2017-08-03 02:50:00+03	68800.00
7A5FF0	2017-06-30 15:31:00+03	143000.00
7A602F	2017-08-06 03:44:00+03	419100.00
7A6096	2017-07-26 15:51:00+03	10600.00
7A6098	2017-07-09 14:14:00+03	32800.00
7A609B	2017-07-07 23:22:00+03	248400.00
7A60CF	2017-07-29 01:16:00+03	24000.00
7A60D2	2017-06-30 16:00:00+03	51300.00
7A60E2	2017-07-05 04:34:00+03	135200.00
7A6131	2017-08-05 13:25:00+03	83000.00
7A6149	2017-07-25 20:12:00+03	100600.00
7A617D	2017-08-07 10:23:00+03	130600.00
7A61B5	2017-08-14 19:45:00+03	84800.00
7A61F4	2017-08-14 02:34:00+03	106200.00
7A6262	2017-08-07 16:34:00+03	193700.00
7A62F8	2017-07-21 13:30:00+03	36200.00
7A637F	2017-07-25 03:54:00+03	47400.00
7A6389	2017-07-08 05:22:00+03	167400.00
7A63E1	2017-08-07 02:54:00+03	169600.00
7A63FA	2017-07-06 13:13:00+03	140600.00
7A641A	2017-07-15 07:06:00+03	86600.00
7A6427	2017-07-07 06:31:00+03	44800.00
7A64B0	2017-07-29 09:16:00+03	54800.00
7A64BF	2017-08-11 08:12:00+03	14000.00
7A657F	2017-08-05 18:55:00+03	166900.00
7A65F7	2017-08-03 23:39:00+03	38200.00
7A65FC	2017-07-10 00:58:00+03	28800.00
7A6617	2017-07-17 08:37:00+03	6800.00
7A665D	2017-07-17 09:48:00+03	148300.00
7A66B4	2017-07-09 02:16:00+03	135600.00
7A66B9	2017-07-20 20:57:00+03	40800.00
7A66D7	2017-08-14 02:52:00+03	111600.00
7A66E4	2017-07-13 02:06:00+03	26800.00
7A66E8	2017-08-03 14:16:00+03	55800.00
7A67A8	2017-08-15 06:40:00+03	93900.00
7A67B8	2017-07-23 09:44:00+03	43400.00
7A6804	2017-07-26 13:54:00+03	58200.00
7A680E	2017-07-21 15:11:00+03	174600.00
7A68C6	2017-07-27 13:34:00+03	45500.00
7A68F7	2017-08-11 17:43:00+03	86900.00
7A6927	2017-07-16 02:21:00+03	52100.00
7A69A0	2017-07-27 21:31:00+03	13600.00
7A69C1	2017-07-13 11:00:00+03	22100.00
7A6AB2	2017-07-14 18:56:00+03	136200.00
7A6AB9	2017-07-16 19:41:00+03	262400.00
7A6ADD	2017-07-19 02:46:00+03	21000.00
7A6B39	2017-08-07 02:57:00+03	28000.00
7A6B58	2017-07-23 11:11:00+03	28800.00
7A6B65	2017-08-01 09:15:00+03	14700.00
7A6BBB	2017-07-14 00:18:00+03	21800.00
7A6BF0	2017-08-02 01:25:00+03	113800.00
7A6C7B	2017-07-25 17:17:00+03	26000.00
7A6C8B	2017-08-06 17:51:00+03	38600.00
7A6CC7	2017-07-05 06:39:00+03	20200.00
7A6D30	2017-08-01 11:04:00+03	75600.00
7A6DBF	2017-08-11 14:05:00+03	84500.00
7A6DDA	2017-07-14 21:18:00+03	189200.00
7A6DFA	2017-07-08 22:05:00+03	255000.00
7A6E0C	2017-07-05 14:23:00+03	180000.00
7A6E20	2017-07-27 18:35:00+03	36400.00
7A6E3D	2017-06-30 18:18:00+03	246000.00
7A6E4A	2017-06-27 01:46:00+03	47400.00
7A6EB3	2017-07-07 19:37:00+03	14000.00
7A6ECF	2017-07-28 18:07:00+03	28800.00
7A6F0B	2017-07-01 17:58:00+03	37900.00
7A6F26	2017-07-06 09:22:00+03	112000.00
7A6F56	2017-06-30 01:02:00+03	13400.00
7A6F88	2017-08-08 19:09:00+03	100600.00
7A6F8C	2017-07-04 19:57:00+03	29600.00
7A6F91	2017-07-28 10:45:00+03	46000.00
7A7056	2017-08-07 23:46:00+03	40600.00
7A706F	2017-08-02 00:34:00+03	67600.00
7A70AE	2017-08-10 08:53:00+03	78800.00
7A70DB	2017-08-13 12:18:00+03	27200.00
7A7123	2017-07-31 15:46:00+03	52000.00
7A71BE	2017-07-30 03:16:00+03	24800.00
7A71D6	2017-08-14 09:50:00+03	54800.00
7A7219	2017-08-08 12:57:00+03	52300.00
7A7266	2017-07-15 19:34:00+03	38800.00
7A7337	2017-08-11 23:59:00+03	270000.00
7A7395	2017-07-21 02:06:00+03	36200.00
7A73BC	2017-07-30 00:34:00+03	31400.00
7A73DB	2017-07-14 19:50:00+03	86100.00
7A7425	2017-07-25 18:37:00+03	265700.00
7A74C0	2017-07-10 10:29:00+03	181500.00
7A74D2	2017-07-18 14:11:00+03	44600.00
7A7524	2017-07-30 11:13:00+03	52400.00
7A755A	2017-07-11 00:52:00+03	33100.00
7A7575	2017-07-02 12:08:00+03	44000.00
7A7579	2017-08-02 23:10:00+03	10800.00
7A75A5	2017-07-24 05:44:00+03	187600.00
7A75E7	2017-08-06 05:14:00+03	33400.00
7A7665	2017-08-10 02:40:00+03	58000.00
7A77AC	2017-08-11 17:20:00+03	68600.00
7A77E1	2017-07-16 17:02:00+03	39800.00
7A781A	2017-07-25 17:59:00+03	152700.00
7A7856	2017-07-13 08:16:00+03	12400.00
7A78BC	2017-07-31 18:12:00+03	26200.00
7A78EA	2017-07-27 21:03:00+03	61800.00
7A7946	2017-07-29 02:31:00+03	24400.00
7A7968	2017-07-21 22:08:00+03	112300.00
7A79C1	2017-07-14 14:07:00+03	50600.00
7A7A0F	2017-07-25 03:26:00+03	57700.00
7A7A1F	2017-07-13 17:34:00+03	45100.00
7A7A23	2017-08-10 20:32:00+03	13400.00
7A7A8B	2017-08-08 03:21:00+03	26000.00
7A7A9B	2017-07-12 04:37:00+03	332800.00
7A7AE8	2017-07-05 22:48:00+03	24500.00
7A7B29	2017-07-22 01:07:00+03	148200.00
7A7B41	2017-08-06 06:32:00+03	58200.00
7A7B6F	2017-07-26 12:55:00+03	22000.00
7A7BBC	2017-07-01 05:42:00+03	58600.00
7A7BE3	2017-08-04 21:57:00+03	53900.00
7A7BF1	2017-07-21 08:46:00+03	31100.00
7A7CF4	2017-07-26 01:45:00+03	56000.00
7A7D01	2017-08-10 11:53:00+03	24400.00
7A7D63	2017-07-31 00:58:00+03	92800.00
7A7DC0	2017-08-15 13:52:00+03	182300.00
7A7E01	2017-08-05 11:28:00+03	75600.00
7A7E21	2017-08-08 17:40:00+03	54800.00
7A7E31	2017-07-02 14:02:00+03	47200.00
7A7E36	2017-07-22 07:53:00+03	24400.00
7A7E6E	2017-08-06 17:43:00+03	260300.00
7A7EAC	2017-07-11 17:29:00+03	46400.00
7A7EF5	2017-07-30 08:58:00+03	14000.00
7A7FF0	2017-07-29 19:47:00+03	39600.00
7A8007	2017-07-16 00:02:00+03	119900.00
7A801B	2017-08-09 05:01:00+03	26600.00
7A805A	2017-07-08 00:26:00+03	196800.00
7A8097	2017-07-24 13:17:00+03	48800.00
7A80D6	2017-08-10 03:27:00+03	111600.00
7A810D	2017-08-08 14:32:00+03	21200.00
7A8122	2017-07-25 00:25:00+03	19600.00
7A812A	2017-07-12 22:19:00+03	12400.00
7A8139	2017-08-11 18:22:00+03	16800.00
7A8163	2017-07-10 02:36:00+03	244300.00
7A81DF	2017-07-09 11:06:00+03	115100.00
7A81E2	2017-08-05 00:59:00+03	63700.00
7A82DA	2017-07-03 09:13:00+03	62900.00
7A82E1	2017-08-03 07:57:00+03	20200.00
7A8311	2017-07-15 06:50:00+03	23400.00
7A8358	2017-08-03 12:37:00+03	95000.00
7A836F	2017-07-07 09:55:00+03	50600.00
7A8389	2017-07-28 17:52:00+03	24700.00
7A839E	2017-07-05 11:08:00+03	13600.00
7A83D0	2017-08-13 11:53:00+03	27400.00
7A8447	2017-07-06 05:02:00+03	12600.00
7A8452	2017-06-29 19:05:00+03	65200.00
7A848F	2017-07-25 12:54:00+03	257500.00
7A8492	2017-07-10 10:03:00+03	71900.00
7A849A	2017-08-04 21:42:00+03	27300.00
7A852F	2017-07-18 18:43:00+03	58600.00
7A8532	2017-08-06 05:57:00+03	115900.00
7A853B	2017-08-07 04:55:00+03	189200.00
7A8551	2017-08-03 01:13:00+03	44000.00
7A859C	2017-07-10 22:12:00+03	48800.00
7A85AD	2017-07-22 14:01:00+03	86300.00
7A85CC	2017-07-17 13:13:00+03	107200.00
7A85CE	2017-07-02 22:29:00+03	101200.00
7A85D3	2017-07-28 09:46:00+03	67600.00
7A85DF	2017-08-10 03:13:00+03	12600.00
7A8644	2017-07-15 16:50:00+03	47700.00
7A8645	2017-06-30 11:48:00+03	67600.00
7A8674	2017-08-09 13:02:00+03	38600.00
7A86AE	2017-07-22 12:09:00+03	163700.00
7A86D5	2017-08-06 13:36:00+03	46000.00
7A86D8	2017-08-03 08:38:00+03	124200.00
7A86DC	2017-07-13 10:04:00+03	6800.00
7A8720	2017-08-04 02:37:00+03	24400.00
7A872A	2017-08-07 21:57:00+03	74800.00
7A8745	2017-07-13 04:33:00+03	311200.00
7A874D	2017-08-02 23:12:00+03	39800.00
7A8768	2017-07-18 15:02:00+03	62600.00
7A876B	2017-08-07 17:25:00+03	77800.00
7A8791	2017-07-19 22:28:00+03	28800.00
7A87BA	2017-07-25 12:23:00+03	21800.00
7A8814	2017-07-23 18:28:00+03	61400.00
7A8838	2017-07-29 20:07:00+03	89600.00
7A8850	2017-08-07 18:50:00+03	27900.00
7A885F	2017-07-15 06:24:00+03	32300.00
7A8880	2017-08-11 15:11:00+03	77900.00
7A88AF	2017-07-24 13:13:00+03	136500.00
7A88BC	2017-07-21 10:36:00+03	40000.00
7A88BD	2017-07-31 22:46:00+03	48500.00
7A88F3	2017-08-08 18:02:00+03	140000.00
7A8951	2017-08-14 07:14:00+03	135600.00
7A8981	2017-07-05 06:11:00+03	150600.00
7A89B9	2017-07-05 13:14:00+03	66600.00
7A89C6	2017-07-28 06:51:00+03	47000.00
7A8A93	2017-07-20 03:46:00+03	79600.00
7A8A97	2017-07-13 00:04:00+03	112600.00
7A8B17	2017-08-08 20:53:00+03	7400.00
7A8BFD	2017-08-11 02:11:00+03	173900.00
7A8C0E	2017-07-12 19:11:00+03	31600.00
7A8C1A	2017-07-05 10:02:00+03	47200.00
7A8C60	2017-08-01 18:10:00+03	105700.00
7A8C7D	2017-07-07 14:12:00+03	16400.00
7A8C86	2017-07-08 14:59:00+03	75300.00
7A8CD9	2017-07-09 00:52:00+03	8400.00
7A8D17	2017-08-04 12:22:00+03	36200.00
7A8D3C	2017-07-11 17:18:00+03	25800.00
7A8D5F	2017-07-19 06:01:00+03	169000.00
7A8D97	2017-07-17 06:47:00+03	55800.00
7A8D9C	2017-07-31 07:43:00+03	68100.00
7A8DAF	2017-07-01 20:02:00+03	90400.00
7A8DC9	2017-06-29 09:03:00+03	64700.00
7A8DD1	2017-07-06 14:26:00+03	62900.00
7A8E0B	2017-07-02 10:41:00+03	93700.00
7A8E1F	2017-07-25 22:15:00+03	28000.00
7A8E76	2017-08-11 13:05:00+03	19600.00
7A8E94	2017-06-29 15:28:00+03	23600.00
7A8ED8	2017-07-25 15:46:00+03	138000.00
7A8EDA	2017-07-12 23:06:00+03	31600.00
7A8EF0	2017-07-16 11:52:00+03	9200.00
7A8EF9	2017-07-26 07:28:00+03	24700.00
7A8EFB	2017-07-09 04:39:00+03	119500.00
7A8FFD	2017-07-13 13:56:00+03	39800.00
7A9051	2017-07-13 06:50:00+03	89700.00
7A9057	2017-08-02 14:19:00+03	67300.00
7A9090	2017-08-05 06:39:00+03	399800.00
7A90B8	2017-07-11 13:17:00+03	39600.00
7A9163	2017-08-08 18:40:00+03	78800.00
7A9191	2017-07-10 00:12:00+03	155600.00
7A91AF	2017-08-12 18:30:00+03	27800.00
7A925C	2017-08-06 12:37:00+03	99200.00
7A92BD	2017-07-15 21:07:00+03	19600.00
7A9355	2017-07-10 22:56:00+03	47200.00
7A939D	2017-07-01 18:06:00+03	24400.00
7A93BB	2017-07-20 13:26:00+03	32700.00
7A9422	2017-07-27 09:47:00+03	23200.00
7A9434	2017-07-06 05:16:00+03	69000.00
7A9445	2017-07-29 04:37:00+03	31400.00
7A9482	2017-07-05 01:00:00+03	12400.00
7A948A	2017-07-18 10:32:00+03	103900.00
7A94B5	2017-08-01 20:57:00+03	58900.00
7A952B	2017-07-20 22:45:00+03	6800.00
7A9553	2017-07-20 06:08:00+03	46800.00
7A9577	2017-07-02 20:58:00+03	25400.00
7A95D6	2017-07-21 20:06:00+03	23200.00
7A95F6	2017-08-12 14:03:00+03	96300.00
7A9653	2017-07-23 19:49:00+03	493900.00
7A96B8	2017-07-14 17:24:00+03	13400.00
7A96BF	2017-07-14 01:54:00+03	16400.00
7A96D3	2017-07-13 10:49:00+03	25900.00
7A96DA	2017-08-04 05:47:00+03	15400.00
7A972A	2017-07-12 05:06:00+03	44600.00
7A97B3	2017-07-20 17:33:00+03	56600.00
7A97B7	2017-06-30 05:33:00+03	28000.00
7A97C0	2017-08-12 10:33:00+03	18600.00
7A97C2	2017-08-01 18:46:00+03	70200.00
7A9821	2017-07-19 17:32:00+03	38400.00
7A9870	2017-07-30 10:37:00+03	56000.00
7A9871	2017-08-01 08:11:00+03	167400.00
7A98B0	2017-07-18 16:06:00+03	93000.00
7A98D6	2017-08-01 14:57:00+03	47200.00
7A99E2	2017-08-13 05:40:00+03	71600.00
7A99FB	2017-07-17 18:30:00+03	136100.00
7A9A09	2017-08-08 03:40:00+03	559500.00
7A9ADA	2017-08-02 05:12:00+03	12400.00
7A9B27	2017-07-09 05:08:00+03	99600.00
7A9B53	2017-07-04 15:17:00+03	29600.00
7A9C79	2017-08-01 04:14:00+03	54100.00
7A9CA0	2017-07-28 05:50:00+03	258400.00
7A9CBC	2017-07-09 23:58:00+03	101900.00
7A9DA2	2017-08-01 23:45:00+03	39800.00
7A9DE9	2017-07-21 00:18:00+03	133200.00
7A9E21	2017-08-04 12:16:00+03	28000.00
7A9E28	2017-08-02 07:38:00+03	114800.00
7A9E78	2017-07-09 00:24:00+03	24200.00
7A9ECC	2017-06-29 20:06:00+03	50800.00
7A9ED0	2017-08-12 04:48:00+03	30200.00
7A9F75	2017-07-08 12:18:00+03	92400.00
7AA030	2017-07-07 13:41:00+03	47400.00
7AA033	2017-07-07 19:40:00+03	92800.00
7AA050	2017-07-15 14:21:00+03	79900.00
7AA070	2017-07-31 06:44:00+03	119500.00
7AA0A1	2017-07-22 05:56:00+03	151200.00
7AA0E3	2017-07-08 23:19:00+03	71900.00
7AA16A	2017-08-03 17:39:00+03	26500.00
7AA171	2017-07-29 04:25:00+03	99200.00
7AA1BC	2017-08-07 20:25:00+03	116000.00
7AA213	2017-08-04 15:19:00+03	271100.00
7AA279	2017-07-25 00:29:00+03	36200.00
7AA2D2	2017-08-14 21:29:00+03	8400.00
7AA3A9	2017-08-06 21:15:00+03	40000.00
7AA43A	2017-07-18 17:06:00+03	128800.00
7AA50D	2017-07-08 16:53:00+03	8200.00
7AA53F	2017-07-02 09:21:00+03	66600.00
7AA614	2017-06-28 15:41:00+03	56000.00
7AA689	2017-08-11 03:23:00+03	73900.00
7AA6D9	2017-08-08 05:45:00+03	177800.00
7AA6FB	2017-07-30 19:25:00+03	94000.00
7AA716	2017-07-24 03:29:00+03	105600.00
7AA7AA	2017-07-22 21:57:00+03	19600.00
7AA7C9	2017-07-24 14:00:00+03	11700.00
7AA7FE	2017-07-03 00:43:00+03	31600.00
7AA865	2017-07-05 16:32:00+03	79600.00
7AA89E	2017-07-16 03:30:00+03	48700.00
7AA8AD	2017-07-09 20:32:00+03	182600.00
7AA8CB	2017-07-25 16:12:00+03	152500.00
7AA900	2017-07-08 05:51:00+03	112000.00
7AA919	2017-08-03 23:45:00+03	64800.00
7AAA35	2017-07-02 16:47:00+03	55800.00
7AAA78	2017-07-29 15:15:00+03	248300.00
7AAA94	2017-08-11 04:23:00+03	34000.00
7AAAFC	2017-07-14 02:34:00+03	50200.00
7AAB0F	2017-07-10 06:17:00+03	153300.00
7AAB3E	2017-07-02 22:10:00+03	8400.00
7AAB74	2017-07-18 01:56:00+03	22000.00
7AABB4	2017-07-30 17:39:00+03	35300.00
7AABE3	2017-07-14 02:27:00+03	96800.00
7AACB3	2017-07-22 08:49:00+03	26000.00
7AACDD	2017-07-12 13:38:00+03	47000.00
7AAD66	2017-08-05 02:21:00+03	6700.00
7AADAA	2017-07-16 06:08:00+03	14000.00
7AADB2	2017-07-24 00:51:00+03	23200.00
7AADE1	2017-07-09 19:35:00+03	75300.00
7AAE0D	2017-07-03 21:07:00+03	21400.00
7AAE8E	2017-08-03 02:55:00+03	114400.00
7AAF61	2017-08-08 17:30:00+03	146700.00
7AAF91	2017-08-13 16:06:00+03	14000.00
7AAFC9	2017-08-14 01:20:00+03	136500.00
7AAFD2	2017-07-18 01:06:00+03	46000.00
7AB073	2017-08-08 22:17:00+03	265700.00
7AB086	2017-07-07 21:42:00+03	56200.00
7AB088	2017-08-10 07:38:00+03	243400.00
7AB094	2017-07-09 08:09:00+03	145700.00
7AB09E	2017-08-09 14:28:00+03	202800.00
7AB09F	2017-07-07 16:19:00+03	213000.00
7AB0CD	2017-07-10 16:53:00+03	37900.00
7AB0EE	2017-08-14 14:04:00+03	59800.00
7AB124	2017-07-06 17:18:00+03	39600.00
7AB130	2017-06-29 03:22:00+03	56000.00
7AB14F	2017-07-29 03:35:00+03	43000.00
7AB18F	2017-07-05 21:38:00+03	266400.00
7AB1A4	2017-07-21 00:12:00+03	246000.00
7AB1DF	2017-07-24 07:46:00+03	19600.00
7AB20B	2017-07-30 21:56:00+03	90400.00
7AB240	2017-07-16 04:05:00+03	102100.00
7AB255	2017-07-20 12:25:00+03	28800.00
7AB2A5	2017-07-26 04:03:00+03	71200.00
7AB2BF	2017-08-11 12:00:00+03	19600.00
7AB2C9	2017-07-17 12:30:00+03	58700.00
7AB333	2017-08-10 18:46:00+03	56000.00
7AB339	2017-08-12 09:03:00+03	40000.00
7AB361	2017-08-04 07:06:00+03	260300.00
7AB3FB	2017-07-24 07:47:00+03	10700.00
7AB433	2017-07-26 02:36:00+03	193200.00
7AB45F	2017-07-25 07:09:00+03	78400.00
7AB47B	2017-07-07 14:57:00+03	21800.00
7AB485	2017-07-02 20:36:00+03	81700.00
7AB494	2017-07-22 14:11:00+03	133200.00
7AB4BC	2017-08-05 18:15:00+03	25400.00
7AB534	2017-08-08 02:57:00+03	6000.00
7AB54D	2017-07-26 22:29:00+03	45100.00
7AB57A	2017-07-06 22:08:00+03	163600.00
7AB58A	2017-07-29 09:28:00+03	16400.00
7AB59B	2017-07-05 09:17:00+03	6800.00
7AB59E	2017-07-20 22:22:00+03	90100.00
7AB644	2017-08-02 20:48:00+03	54500.00
7AB648	2017-07-19 23:04:00+03	6700.00
7AB6F2	2017-07-26 05:40:00+03	20600.00
7AB6FE	2017-07-22 18:42:00+03	157300.00
7AB73D	2017-06-28 23:11:00+03	92900.00
7AB748	2017-07-04 10:34:00+03	21600.00
7AB75B	2017-08-02 23:57:00+03	46000.00
7AB7B4	2017-07-19 19:51:00+03	58800.00
7AB7ED	2017-07-23 08:39:00+03	56000.00
7AB7F3	2017-07-14 06:31:00+03	134400.00
7AB7F6	2017-08-09 07:04:00+03	140100.00
7AB839	2017-07-29 14:18:00+03	140900.00
7AB8C5	2017-08-02 14:37:00+03	36200.00
7AB98B	2017-07-25 09:00:00+03	81600.00
7AB9D4	2017-08-08 19:42:00+03	56600.00
7AB9F0	2017-07-12 17:38:00+03	14000.00
7ABA0F	2017-07-19 14:21:00+03	234100.00
7ABA92	2017-08-10 12:59:00+03	23600.00
7ABAE0	2017-07-19 23:57:00+03	55800.00
7ABB28	2017-08-12 07:31:00+03	36800.00
7ABB69	2017-08-15 09:16:00+03	52000.00
7ABB81	2017-08-05 21:02:00+03	42800.00
7ABB8B	2017-07-03 11:42:00+03	54000.00
7ABB9D	2017-06-29 18:59:00+03	28000.00
7ABC03	2017-08-06 20:53:00+03	42700.00
7ABC42	2017-08-01 14:52:00+03	44800.00
7ABC7A	2017-07-21 12:38:00+03	41200.00
7ABD27	2017-07-11 02:19:00+03	40800.00
7ABD91	2017-07-15 20:35:00+03	120700.00
7ABE1C	2017-07-25 16:02:00+03	257500.00
7ABE62	2017-08-05 19:59:00+03	387300.00
7ABE68	2017-08-01 17:14:00+03	32800.00
7ABEB4	2017-07-19 14:54:00+03	45200.00
7ABEF5	2017-07-27 04:08:00+03	25600.00
7ABEFF	2017-07-28 20:59:00+03	12000.00
7ABF33	2017-08-14 22:17:00+03	47200.00
7ABF44	2017-07-03 20:36:00+03	272900.00
7ABF4C	2017-07-06 06:00:00+03	61800.00
7AC051	2017-07-28 13:39:00+03	287300.00
7AC06B	2017-07-26 18:42:00+03	6000.00
7AC0EA	2017-08-06 23:15:00+03	107100.00
7AC129	2017-07-07 15:10:00+03	93900.00
7AC192	2017-07-06 12:14:00+03	9200.00
7AC267	2017-07-07 03:59:00+03	246000.00
7AC26E	2017-08-11 20:44:00+03	31200.00
7AC280	2017-07-18 16:28:00+03	61800.00
7AC309	2017-07-24 06:06:00+03	131600.00
7AC358	2017-07-30 23:12:00+03	27900.00
7AC36F	2017-07-30 11:44:00+03	83400.00
7AC378	2017-07-11 02:46:00+03	144200.00
7AC38A	2017-08-14 10:59:00+03	13400.00
7AC3E6	2017-08-02 01:57:00+03	34000.00
7AC43C	2017-07-06 05:08:00+03	32700.00
7AC44D	2017-07-05 04:02:00+03	131800.00
7AC469	2017-07-07 16:14:00+03	23600.00
7AC4A3	2017-07-20 22:10:00+03	66300.00
7AC4A6	2017-08-08 20:44:00+03	182100.00
7AC4A8	2017-07-09 02:16:00+03	12600.00
7AC4D6	2017-07-20 01:00:00+03	26000.00
7AC50B	2017-07-06 22:22:00+03	15400.00
7AC552	2017-07-05 11:51:00+03	94900.00
7AC584	2017-07-04 13:01:00+03	105600.00
7AC5A7	2017-07-08 14:08:00+03	19500.00
7AC5D0	2017-08-07 05:43:00+03	179300.00
7AC659	2017-07-20 04:52:00+03	99300.00
7AC666	2017-07-23 09:51:00+03	90800.00
7AC66C	2017-07-31 07:24:00+03	8000.00
7AC6E3	2017-07-16 08:27:00+03	52800.00
7AC6E9	2017-08-04 08:45:00+03	65500.00
7AC74C	2017-07-16 17:11:00+03	74200.00
7AC7E5	2017-07-11 06:07:00+03	385000.00
7AC7ED	2017-08-14 09:23:00+03	38800.00
7AC807	2017-07-23 01:51:00+03	109300.00
7AC82E	2017-07-25 22:09:00+03	15200.00
7AC869	2017-07-08 14:59:00+03	59300.00
7AC86C	2017-07-10 12:02:00+03	23200.00
7AC8BD	2017-07-10 06:34:00+03	68100.00
7AC8C6	2017-08-05 10:23:00+03	60600.00
7AC8CE	2017-07-11 10:57:00+03	20800.00
7AC910	2017-07-01 00:42:00+03	38400.00
7AC939	2017-07-31 15:02:00+03	24800.00
7AC954	2017-07-24 15:34:00+03	121700.00
7AC967	2017-08-11 02:50:00+03	67200.00
7AC97C	2017-07-27 06:35:00+03	23600.00
7AC99B	2017-07-21 23:17:00+03	135400.00
7ACA46	2017-08-15 00:32:00+03	75300.00
7ACAE6	2017-07-22 23:42:00+03	36200.00
7ACB0A	2017-08-05 08:03:00+03	68800.00
7ACBBC	2017-08-10 01:51:00+03	212800.00
7ACBF1	2017-07-31 22:34:00+03	23200.00
7ACC05	2017-07-13 19:04:00+03	28000.00
7ACC26	2017-07-19 23:35:00+03	23400.00
7ACC81	2017-07-11 03:59:00+03	134300.00
7ACC89	2017-07-31 04:05:00+03	41300.00
7ACCB1	2017-07-29 22:03:00+03	201800.00
7ACD4E	2017-08-14 08:07:00+03	25600.00
7ACD58	2017-08-04 02:16:00+03	124200.00
7ACD5B	2017-07-22 21:05:00+03	386200.00
7ACD64	2017-08-06 06:05:00+03	46400.00
7ACD8A	2017-07-07 13:09:00+03	20200.00
7ACDA4	2017-07-27 07:14:00+03	40000.00
7ACDCF	2017-07-04 09:33:00+03	68400.00
7ACDF6	2017-07-09 19:37:00+03	49600.00
7ACE09	2017-07-29 23:19:00+03	110400.00
7ACE95	2017-08-09 18:07:00+03	124200.00
7ACEC9	2017-07-13 08:53:00+03	32800.00
7ACEF5	2017-07-03 16:39:00+03	53300.00
7ACF16	2017-07-13 12:22:00+03	53600.00
7ACF1C	2017-07-16 13:57:00+03	116400.00
7ACF27	2017-07-31 10:25:00+03	31600.00
7ACF29	2017-07-08 20:46:00+03	23200.00
7AD088	2017-07-27 11:11:00+03	52000.00
7AD090	2017-08-01 01:23:00+03	66600.00
7AD09B	2017-07-18 20:29:00+03	173100.00
7AD0A9	2017-07-06 04:13:00+03	94200.00
7AD0B2	2017-07-06 05:13:00+03	356500.00
7AD0CE	2017-07-26 11:54:00+03	56600.00
7AD110	2017-07-13 10:09:00+03	450700.00
7AD17D	2017-06-30 10:22:00+03	40800.00
7AD1BC	2017-07-16 08:05:00+03	21400.00
7AD1FD	2017-08-07 14:48:00+03	55800.00
7AD226	2017-08-07 18:06:00+03	139700.00
7AD22A	2017-07-20 00:58:00+03	24400.00
7AD25A	2017-08-09 13:38:00+03	88100.00
7AD26A	2017-07-16 02:48:00+03	40000.00
7AD27C	2017-08-14 05:15:00+03	112000.00
7AD2C6	2017-07-03 01:05:00+03	117600.00
7AD344	2017-07-06 16:31:00+03	52700.00
7AD35E	2017-08-04 17:54:00+03	13400.00
7AD36A	2017-07-05 08:07:00+03	42800.00
7AD373	2017-07-17 01:39:00+03	7400.00
7AD393	2017-08-08 08:09:00+03	94000.00
7AD3B3	2017-06-27 07:53:00+03	67600.00
7AD3E2	2017-07-05 16:07:00+03	86500.00
7AD40F	2017-07-15 10:10:00+03	18000.00
7AD422	2017-07-04 12:35:00+03	67600.00
7AD44F	2017-08-09 23:51:00+03	129000.00
7AD453	2017-07-31 17:17:00+03	46200.00
7AD45C	2017-07-25 02:04:00+03	135600.00
7AD46E	2017-07-22 08:00:00+03	69500.00
7AD541	2017-07-21 22:55:00+03	86800.00
7AD55E	2017-08-03 07:58:00+03	53600.00
7AD58D	2017-08-13 09:26:00+03	136200.00
7AD5A2	2017-07-04 17:41:00+03	11600.00
7AD5DB	2017-08-10 12:52:00+03	29600.00
7AD645	2017-07-03 11:43:00+03	52400.00
7AD671	2017-07-06 04:33:00+03	229600.00
7AD6D0	2017-07-04 00:07:00+03	88600.00
7AD6E2	2017-07-12 03:33:00+03	23400.00
7AD77F	2017-07-12 18:43:00+03	111600.00
7AD798	2017-07-02 21:05:00+03	6300.00
7AD79B	2017-08-12 16:50:00+03	13400.00
7AD7C5	2017-07-24 16:46:00+03	146300.00
7AD863	2017-07-01 01:04:00+03	84000.00
7AD91F	2017-08-01 15:15:00+03	62600.00
7AD92A	2017-07-11 00:12:00+03	14400.00
7AD953	2017-07-07 12:25:00+03	112000.00
7AD995	2017-07-27 11:08:00+03	50400.00
7AD9A4	2017-08-02 04:50:00+03	54800.00
7AD9C0	2017-06-29 07:05:00+03	26200.00
7ADA9C	2017-07-03 10:28:00+03	62900.00
7ADBC7	2017-07-05 03:21:00+03	59300.00
7ADBD9	2017-08-03 06:03:00+03	14000.00
7ADC1F	2017-07-31 18:08:00+03	21800.00
7ADC25	2017-07-08 22:33:00+03	23900.00
7ADC2E	2017-07-15 14:46:00+03	270800.00
7ADC45	2017-08-04 00:38:00+03	17000.00
7ADC4B	2017-07-04 16:49:00+03	393000.00
7ADC4D	2017-07-04 01:29:00+03	24400.00
7ADC87	2017-07-08 01:20:00+03	90100.00
7ADC9C	2017-07-03 21:46:00+03	40800.00
7ADCA4	2017-07-31 15:18:00+03	28800.00
7ADD0D	2017-07-20 09:43:00+03	11600.00
7ADD46	2017-07-21 22:25:00+03	57800.00
7ADD99	2017-07-03 06:12:00+03	112100.00
7ADE77	2017-07-02 06:46:00+03	39300.00
7ADF28	2017-07-05 07:56:00+03	8200.00
7ADF40	2017-07-05 10:42:00+03	115000.00
7ADF70	2017-06-30 17:19:00+03	70700.00
7ADF7F	2017-07-27 17:20:00+03	8600.00
7ADFA0	2017-07-11 12:17:00+03	38600.00
7ADFF0	2017-08-11 00:39:00+03	33700.00
7AE06D	2017-07-22 06:22:00+03	29600.00
7AE0FA	2017-07-07 11:08:00+03	321300.00
7AE0FC	2017-08-06 16:19:00+03	30400.00
7AE109	2017-07-07 16:42:00+03	20400.00
7AE112	2017-07-24 20:16:00+03	13600.00
7AE147	2017-08-03 10:05:00+03	68100.00
7AE1EC	2017-07-13 23:52:00+03	43200.00
7AE218	2017-07-26 14:40:00+03	51600.00
7AE292	2017-07-18 17:57:00+03	16800.00
7AE29E	2017-07-26 15:52:00+03	6000.00
7AE2B1	2017-07-18 09:48:00+03	99600.00
7AE2B9	2017-07-10 16:22:00+03	26000.00
7AE2DB	2017-07-14 11:44:00+03	93500.00
7AE317	2017-07-11 02:09:00+03	176800.00
7AE387	2017-07-15 20:55:00+03	25100.00
7AE39C	2017-08-11 02:27:00+03	21400.00
7AE3D0	2017-07-27 21:24:00+03	6700.00
7AE412	2017-07-18 01:26:00+03	135400.00
7AE426	2017-07-16 03:23:00+03	35700.00
7AE429	2017-07-12 15:25:00+03	25000.00
7AE43F	2017-07-23 02:30:00+03	26700.00
7AE483	2017-07-13 06:26:00+03	156500.00
7AE489	2017-07-05 03:20:00+03	13400.00
7AE4FE	2017-07-18 02:48:00+03	13400.00
7AE50F	2017-07-15 16:28:00+03	207000.00
7AE551	2017-08-15 12:29:00+03	53100.00
7AE58F	2017-07-11 06:33:00+03	25800.00
7AE593	2017-07-21 20:18:00+03	6000.00
7AE5AC	2017-08-11 22:31:00+03	31400.00
7AE61E	2017-07-15 11:59:00+03	369000.00
7AE68F	2017-07-04 00:40:00+03	14000.00
7AE6AA	2017-08-12 20:20:00+03	54000.00
7AE6C4	2017-08-07 15:59:00+03	22000.00
7AE722	2017-08-13 08:53:00+03	16400.00
7AE764	2017-07-23 03:56:00+03	25800.00
7AE786	2017-07-22 04:21:00+03	71800.00
7AE78F	2017-08-11 23:52:00+03	186900.00
7AE7B1	2017-08-09 22:08:00+03	112200.00
7AE80B	2017-07-20 07:04:00+03	24300.00
7AE81F	2017-07-22 19:32:00+03	25600.00
7AE833	2017-07-04 06:51:00+03	6300.00
7AE874	2017-08-08 21:41:00+03	81600.00
7AE881	2017-07-23 14:26:00+03	62200.00
7AE89A	2017-08-14 07:37:00+03	38800.00
7AE8C6	2017-07-09 00:55:00+03	54000.00
7AE8D4	2017-07-24 05:58:00+03	35800.00
7AE8EE	2017-07-10 02:04:00+03	6700.00
7AE8F9	2017-08-07 20:09:00+03	64300.00
7AE925	2017-08-10 07:59:00+03	39400.00
7AE93D	2017-07-23 17:55:00+03	117600.00
7AE9A2	2017-07-07 16:47:00+03	6300.00
7AE9AF	2017-07-02 20:06:00+03	232800.00
7AE9E8	2017-08-07 21:55:00+03	30200.00
7AE9EE	2017-08-11 04:24:00+03	86600.00
7AEA3C	2017-08-14 07:28:00+03	24600.00
7AEAAC	2017-07-06 12:56:00+03	54800.00
7AEAF0	2017-07-08 22:19:00+03	270800.00
7AEC34	2017-07-27 02:02:00+03	13400.00
7AEC61	2017-08-15 08:51:00+03	7400.00
7AEC88	2017-07-15 19:22:00+03	48800.00
7AEC8E	2017-08-12 22:02:00+03	125200.00
7AECE2	2017-08-15 09:20:00+03	14000.00
7AECE9	2017-08-04 21:40:00+03	8000.00
7AED64	2017-07-09 03:58:00+03	244100.00
7AEDDB	2017-08-11 20:01:00+03	55800.00
7AEE0D	2017-07-23 08:32:00+03	20800.00
7AEE21	2017-07-26 09:37:00+03	87100.00
7AEE45	2017-07-22 10:37:00+03	59700.00
7AEEBB	2017-07-08 18:55:00+03	28700.00
7AEF1C	2017-07-04 12:53:00+03	44600.00
7AEF2A	2017-07-28 19:10:00+03	56000.00
7AEFA3	2017-07-24 07:07:00+03	34100.00
7AEFB0	2017-08-12 05:24:00+03	138500.00
7AEFC3	2017-07-28 15:46:00+03	11700.00
7AF02A	2017-06-29 11:01:00+03	316400.00
7AF06A	2017-07-07 14:47:00+03	38400.00
7AF081	2017-07-04 08:18:00+03	134200.00
7AF0CD	2017-07-31 18:30:00+03	69600.00
7AF130	2017-07-05 16:40:00+03	64700.00
7AF160	2017-07-27 23:06:00+03	28000.00
7AF17C	2017-08-14 10:03:00+03	111000.00
7AF1CD	2017-07-25 19:12:00+03	288700.00
7AF1F9	2017-08-14 21:00:00+03	149300.00
7AF219	2017-07-27 04:29:00+03	85000.00
7AF317	2017-07-25 07:58:00+03	58800.00
7AF39B	2017-08-13 06:07:00+03	115200.00
7AF423	2017-07-31 09:55:00+03	67800.00
7AF451	2017-07-22 19:51:00+03	26000.00
7AF493	2017-07-19 09:34:00+03	94000.00
7AF4EF	2017-07-11 11:35:00+03	115400.00
7AF4FD	2017-08-03 00:21:00+03	19800.00
7AF5D2	2017-07-28 15:57:00+03	14900.00
7AF607	2017-07-09 10:50:00+03	68800.00
7AF63A	2017-07-02 01:33:00+03	15400.00
7AF67B	2017-07-19 04:06:00+03	62900.00
7AF6B5	2017-08-08 09:18:00+03	105100.00
7AF6E9	2017-07-25 12:31:00+03	31600.00
7AF77B	2017-07-24 17:44:00+03	77200.00
7AF803	2017-07-22 10:22:00+03	37900.00
7AF874	2017-07-05 21:04:00+03	203300.00
7AF90E	2017-07-16 11:49:00+03	178200.00
7AF955	2017-07-02 00:06:00+03	16400.00
7AF999	2017-07-22 22:12:00+03	27800.00
7AF9A7	2017-07-24 01:19:00+03	95200.00
7AF9C2	2017-07-11 16:46:00+03	47800.00
7AFA1B	2017-07-25 15:44:00+03	55800.00
7AFA63	2017-07-28 17:09:00+03	56900.00
7AFA73	2017-07-04 13:47:00+03	46400.00
7AFB16	2017-07-05 11:18:00+03	28000.00
7AFB2F	2017-07-28 09:42:00+03	84000.00
7AFB42	2017-07-05 21:38:00+03	7200.00
7AFB7D	2017-07-13 06:46:00+03	59800.00
7AFBC7	2017-08-08 15:28:00+03	26800.00
7AFC47	2017-07-10 15:19:00+03	94000.00
7AFC63	2017-08-15 03:41:00+03	26000.00
7AFC77	2017-07-10 01:18:00+03	109600.00
7AFD0E	2017-08-08 10:02:00+03	33300.00
7AFD14	2017-08-14 03:18:00+03	59400.00
7AFE8B	2017-07-06 14:52:00+03	92800.00
7AFECF	2017-07-20 17:19:00+03	14000.00
7AFF64	2017-07-09 06:50:00+03	7400.00
7AFF6D	2017-08-13 03:53:00+03	76800.00
7AFF8D	2017-07-10 01:11:00+03	92800.00
7AFF91	2017-07-23 15:37:00+03	67000.00
7B000A	2017-08-07 18:01:00+03	229900.00
7B00F7	2017-08-15 08:52:00+03	34000.00
7B012C	2017-08-06 06:33:00+03	86500.00
7B014C	2017-07-27 03:33:00+03	43200.00
7B0182	2017-06-27 22:15:00+03	89600.00
7B01AD	2017-07-12 04:57:00+03	51200.00
7B01AF	2017-07-14 08:23:00+03	66000.00
7B01E5	2017-07-30 19:51:00+03	44500.00
7B01FB	2017-08-06 14:03:00+03	75300.00
7B0247	2017-08-14 06:26:00+03	19600.00
7B024C	2017-08-09 07:38:00+03	43200.00
7B0259	2017-07-30 17:17:00+03	37800.00
7B0284	2017-07-24 07:00:00+03	87000.00
7B0288	2017-07-31 21:32:00+03	81700.00
7B02D8	2017-07-20 14:45:00+03	31900.00
7B02E5	2017-08-12 23:32:00+03	101200.00
7B0343	2017-08-06 07:00:00+03	53300.00
7B034C	2017-08-11 20:15:00+03	229000.00
7B038F	2017-08-14 13:58:00+03	75600.00
7B03C1	2017-08-08 15:21:00+03	17600.00
7B03F7	2017-08-11 16:25:00+03	158500.00
7B04CF	2017-07-09 02:31:00+03	246000.00
7B04DC	2017-08-05 21:23:00+03	129200.00
7B0570	2017-07-10 17:44:00+03	79300.00
7B0582	2017-07-15 07:44:00+03	57600.00
7B05D5	2017-07-29 14:42:00+03	56000.00
7B060C	2017-07-14 11:04:00+03	65500.00
7B0658	2017-07-30 15:56:00+03	22000.00
7B06CC	2017-08-11 13:47:00+03	6800.00
7B071C	2017-08-07 15:49:00+03	28800.00
7B0749	2017-07-09 22:37:00+03	66600.00
7B075F	2017-07-20 19:27:00+03	52400.00
7B076E	2017-07-20 14:30:00+03	26800.00
7B07A9	2017-07-10 13:31:00+03	14800.00
7B07CB	2017-08-08 18:22:00+03	6000.00
7B07DB	2017-07-18 13:21:00+03	127100.00
7B0836	2017-07-25 14:16:00+03	75100.00
7B084D	2017-07-11 13:49:00+03	112000.00
7B0886	2017-07-14 15:38:00+03	18600.00
7B08C9	2017-08-01 01:47:00+03	37100.00
7B0901	2017-08-13 23:01:00+03	6700.00
7B095B	2017-08-13 18:36:00+03	26200.00
7B0976	2017-08-02 17:06:00+03	29400.00
7B0A3A	2017-06-25 08:21:00+03	51000.00
7B0A4E	2017-06-30 06:13:00+03	113800.00
7B0B9B	2017-06-28 03:58:00+03	56000.00
7B0C28	2017-07-25 21:48:00+03	23200.00
7B0CF1	2017-08-11 16:16:00+03	23200.00
7B0CF7	2017-07-27 00:10:00+03	64400.00
7B0D1F	2017-07-25 10:28:00+03	26800.00
7B0D4A	2017-07-28 02:59:00+03	26000.00
7B0D68	2017-07-21 18:38:00+03	34000.00
7B0D72	2017-07-30 20:34:00+03	111600.00
7B0D90	2017-07-08 09:26:00+03	24400.00
7B0DB2	2017-07-19 00:28:00+03	25600.00
7B0DC6	2017-07-03 07:25:00+03	51300.00
7B0E31	2017-07-14 10:44:00+03	56900.00
7B0E65	2017-08-13 13:27:00+03	128900.00
7B0EA9	2017-07-27 16:01:00+03	46400.00
7B0ECA	2017-07-03 05:04:00+03	232800.00
7B0F03	2017-08-04 05:23:00+03	46000.00
7B0F2E	2017-07-01 14:48:00+03	36200.00
7B0FA2	2017-08-11 20:39:00+03	533900.00
7B0FF1	2017-07-19 14:28:00+03	135600.00
7B1011	2017-08-03 06:30:00+03	42700.00
7B1039	2017-07-29 08:41:00+03	51000.00
7B1066	2017-08-02 12:59:00+03	357600.00
7B10B9	2017-08-10 14:04:00+03	65900.00
7B1166	2017-07-16 15:32:00+03	47300.00
7B116E	2017-07-31 09:16:00+03	260900.00
7B1173	2017-07-04 22:07:00+03	47100.00
7B118E	2017-08-14 02:06:00+03	104700.00
7B11CE	2017-08-12 20:34:00+03	11300.00
7B11DC	2017-07-22 01:35:00+03	102000.00
7B120D	2017-08-02 01:36:00+03	52800.00
7B1227	2017-08-11 02:16:00+03	23200.00
7B1296	2017-07-27 23:00:00+03	155300.00
7B131E	2017-08-03 20:40:00+03	92000.00
7B135E	2017-07-24 04:44:00+03	46300.00
7B135F	2017-08-11 20:10:00+03	155600.00
7B137B	2017-07-05 21:00:00+03	84100.00
7B13E4	2017-08-08 04:52:00+03	369000.00
7B13EF	2017-07-01 02:41:00+03	46300.00
7B1444	2017-07-11 16:39:00+03	43600.00
7B14B5	2017-08-11 17:53:00+03	31200.00
7B14FF	2017-08-02 19:02:00+03	67600.00
7B155B	2017-07-18 19:23:00+03	27200.00
7B1577	2017-07-26 15:12:00+03	28000.00
7B157E	2017-07-22 17:55:00+03	26000.00
7B160B	2017-07-18 10:58:00+03	46200.00
7B1632	2017-07-11 22:12:00+03	11600.00
7B163B	2017-08-07 06:01:00+03	57700.00
7B1656	2017-07-05 04:42:00+03	57800.00
7B1668	2017-07-08 06:02:00+03	37100.00
7B166E	2017-07-23 15:31:00+03	26000.00
7B167A	2017-07-28 21:14:00+03	38600.00
7B1682	2017-08-05 22:15:00+03	67200.00
7B16AA	2017-07-19 10:56:00+03	31500.00
7B17BF	2017-08-07 22:45:00+03	185300.00
7B17CD	2017-07-31 03:25:00+03	126700.00
7B17CF	2017-07-09 07:28:00+03	32200.00
7B17F0	2017-08-12 04:48:00+03	259000.00
7B1854	2017-07-13 00:48:00+03	6300.00
7B18A5	2017-07-11 00:20:00+03	166000.00
7B18CF	2017-07-29 18:40:00+03	51300.00
7B198A	2017-07-23 02:57:00+03	271200.00
7B19E6	2017-07-28 22:49:00+03	15000.00
7B19E8	2017-08-03 02:19:00+03	29600.00
7B19F8	2017-07-12 16:36:00+03	23900.00
7B1A12	2017-08-08 18:03:00+03	67300.00
7B1A79	2017-08-04 02:36:00+03	26000.00
7B1A8C	2017-08-14 20:28:00+03	13700.00
7B1A8D	2017-08-13 09:18:00+03	16000.00
7B1A99	2017-08-08 02:06:00+03	88400.00
7B1AC0	2017-08-02 10:22:00+03	136800.00
7B1AE5	2017-08-05 13:26:00+03	88900.00
7B1B5C	2017-07-13 07:47:00+03	57400.00
7B1B91	2017-07-24 19:26:00+03	20200.00
7B1BD4	2017-07-08 14:21:00+03	67600.00
7B1BD5	2017-07-20 02:54:00+03	47700.00
7B1C06	2017-07-01 11:40:00+03	23400.00
7B1C2A	2017-07-08 13:05:00+03	114300.00
7B1C79	2017-08-01 17:32:00+03	185500.00
7B1D03	2017-08-13 05:55:00+03	44000.00
7B1D9F	2017-07-06 11:48:00+03	145200.00
7B1DA0	2017-08-03 05:58:00+03	65900.00
7B1DC1	2017-07-07 14:28:00+03	14000.00
7B1EC4	2017-07-01 02:31:00+03	89700.00
7B1EC9	2017-07-18 13:11:00+03	68800.00
7B1EE8	2017-07-19 05:06:00+03	135400.00
7B2006	2017-07-29 13:17:00+03	26000.00
7B20DE	2017-07-16 09:43:00+03	6700.00
7B20E6	2017-07-08 02:31:00+03	23900.00
7B210F	2017-07-05 19:52:00+03	112000.00
7B2161	2017-07-26 21:44:00+03	46300.00
7B2202	2017-08-04 10:39:00+03	22000.00
7B222B	2017-08-05 18:49:00+03	101100.00
7B2280	2017-08-07 07:59:00+03	20400.00
7B229E	2017-08-14 12:19:00+03	76600.00
7B22DF	2017-07-11 16:18:00+03	23200.00
7B22ED	2017-08-14 18:11:00+03	58600.00
7B2384	2017-07-16 22:29:00+03	24700.00
7B23CD	2017-07-28 07:22:00+03	47400.00
7B23FB	2017-08-14 00:29:00+03	32800.00
7B241A	2017-07-06 17:54:00+03	90600.00
7B2470	2017-08-01 22:29:00+03	13400.00
7B2474	2017-07-13 10:54:00+03	73900.00
7B2481	2017-07-04 16:44:00+03	422700.00
7B2564	2017-07-29 12:12:00+03	100200.00
7B258A	2017-07-14 23:48:00+03	57500.00
7B2598	2017-07-01 22:59:00+03	538000.00
7B263A	2017-08-04 02:38:00+03	77000.00
7B2663	2017-07-26 08:35:00+03	20500.00
7B2674	2017-06-30 03:34:00+03	52800.00
7B267A	2017-08-09 00:40:00+03	66600.00
7B2687	2017-07-22 13:07:00+03	68000.00
7B26B4	2017-07-18 09:49:00+03	35800.00
7B26B7	2017-07-28 16:19:00+03	23200.00
7B2710	2017-07-27 05:45:00+03	127300.00
7B273D	2017-08-07 03:14:00+03	121200.00
7B2832	2017-07-19 19:44:00+03	59200.00
7B2870	2017-07-14 19:14:00+03	23600.00
7B289B	2017-07-21 19:37:00+03	114400.00
7B291F	2017-07-02 15:39:00+03	142700.00
7B295D	2017-08-13 05:36:00+03	36800.00
7B29B5	2017-08-13 00:12:00+03	117500.00
7B29EB	2017-07-24 02:39:00+03	38600.00
7B2AD4	2017-07-15 01:38:00+03	87600.00
7B2AEE	2017-08-12 14:03:00+03	179200.00
7B2B1D	2017-07-21 22:43:00+03	95600.00
7B2B25	2017-08-06 11:43:00+03	26800.00
7B2B42	2017-08-04 08:07:00+03	115700.00
7B2BA9	2017-08-08 10:40:00+03	54000.00
7B2BCC	2017-07-04 14:59:00+03	71000.00
7B2BEA	2017-08-02 02:04:00+03	62800.00
7B2C1A	2017-07-07 08:23:00+03	62000.00
7B2C26	2017-08-13 10:36:00+03	29300.00
7B2C34	2017-07-22 06:38:00+03	32800.00
7B2C4D	2017-07-09 21:44:00+03	73500.00
7B2C52	2017-08-02 02:12:00+03	57600.00
7B2C5E	2017-07-23 13:24:00+03	113700.00
7B2D21	2017-08-12 04:05:00+03	28000.00
7B2D44	2017-07-05 04:17:00+03	45500.00
7B2D54	2017-08-01 11:48:00+03	36200.00
7B2D64	2017-08-09 20:31:00+03	101100.00
7B2E84	2017-07-17 15:46:00+03	246000.00
7B2ED7	2017-08-14 04:21:00+03	55800.00
7B2F53	2017-07-15 05:21:00+03	18000.00
7B2F67	2017-07-05 05:06:00+03	14400.00
7B2F81	2017-08-12 16:29:00+03	174300.00
7B3003	2017-07-10 13:41:00+03	87500.00
7B300B	2017-07-12 20:57:00+03	24800.00
7B303F	2017-08-04 00:50:00+03	9200.00
7B305D	2017-07-08 18:40:00+03	437600.00
7B3079	2017-07-06 05:31:00+03	51800.00
7B30B5	2017-08-11 14:05:00+03	92000.00
7B3115	2017-07-20 12:13:00+03	100300.00
7B3167	2017-07-12 14:15:00+03	36400.00
7B31CE	2017-07-21 23:50:00+03	234800.00
7B31DE	2017-07-19 11:43:00+03	112600.00
7B322D	2017-08-07 18:19:00+03	25600.00
7B323C	2017-08-12 06:49:00+03	46000.00
7B3256	2017-08-03 02:26:00+03	36400.00
7B325C	2017-08-12 02:06:00+03	53900.00
7B3268	2017-08-09 06:36:00+03	111900.00
7B32AB	2017-07-10 16:25:00+03	35200.00
7B3357	2017-07-22 01:56:00+03	34000.00
7B3375	2017-07-30 08:59:00+03	60000.00
7B33E9	2017-08-11 19:59:00+03	41600.00
7B3409	2017-08-04 10:56:00+03	15000.00
7B348F	2017-08-02 03:25:00+03	28000.00
7B34A4	2017-07-10 23:03:00+03	100600.00
7B34E1	2017-07-11 21:46:00+03	95200.00
7B356F	2017-08-01 20:45:00+03	44000.00
7B35A7	2017-07-23 12:44:00+03	46000.00
7B3631	2017-08-06 17:19:00+03	10700.00
7B3663	2017-07-25 11:31:00+03	28000.00
7B3699	2017-07-11 11:54:00+03	130100.00
7B36A2	2017-07-12 22:55:00+03	53400.00
7B3730	2017-08-06 21:29:00+03	26800.00
7B37AD	2017-07-10 08:33:00+03	27200.00
7B3823	2017-08-15 14:40:00+03	527900.00
7B3850	2017-07-04 08:59:00+03	43600.00
7B386B	2017-06-29 18:45:00+03	70600.00
7B392A	2017-07-22 01:31:00+03	46400.00
7B3957	2017-08-07 22:18:00+03	69800.00
7B3978	2017-08-07 20:55:00+03	45200.00
7B3A65	2017-07-21 23:53:00+03	102100.00
7B3A98	2017-08-01 09:44:00+03	44600.00
7B3AD0	2017-07-10 03:05:00+03	116300.00
7B3B12	2017-07-13 14:18:00+03	23200.00
7B3B7A	2017-08-13 14:21:00+03	292900.00
7B3B86	2017-07-06 16:28:00+03	87000.00
7B3BBD	2017-08-14 20:27:00+03	20500.00
7B3BEC	2017-07-15 21:01:00+03	10800.00
7B3C23	2017-07-19 08:38:00+03	14400.00
7B3C75	2017-07-08 07:35:00+03	58000.00
7B3CB6	2017-07-06 13:06:00+03	59000.00
7B3CED	2017-07-28 00:04:00+03	25600.00
7B3CFB	2017-08-14 14:44:00+03	277800.00
7B3D4C	2017-08-12 17:03:00+03	45200.00
7B3D4F	2017-07-14 22:47:00+03	134700.00
7B3DBA	2017-08-15 14:17:00+03	45100.00
7B3E3C	2017-07-30 09:08:00+03	54500.00
7B3E49	2017-08-05 18:15:00+03	115900.00
7B3E4A	2017-08-09 04:26:00+03	151200.00
7B3E74	2017-08-12 01:33:00+03	31600.00
7B3EB8	2017-07-01 07:57:00+03	117600.00
7B3F03	2017-08-14 13:19:00+03	19600.00
7B3F8A	2017-07-24 09:22:00+03	62700.00
7B3F8C	2017-07-10 09:39:00+03	47100.00
7B3FA4	2017-08-13 16:02:00+03	62600.00
7B3FE0	2017-08-12 15:09:00+03	82000.00
7B4002	2017-07-24 17:13:00+03	20600.00
7B400B	2017-07-01 06:59:00+03	58600.00
7B408A	2017-07-08 16:06:00+03	87000.00
7B408B	2017-08-14 02:29:00+03	6700.00
7B4096	2017-07-18 15:58:00+03	114600.00
7B40B9	2017-07-12 01:52:00+03	26600.00
7B40BF	2017-08-12 07:57:00+03	24600.00
7B4119	2017-07-22 10:11:00+03	15000.00
7B4120	2017-07-03 05:50:00+03	91700.00
7B4121	2017-08-06 08:48:00+03	36200.00
7B416E	2017-08-06 07:07:00+03	10800.00
7B418C	2017-08-02 04:38:00+03	178800.00
7B41F5	2017-07-30 02:26:00+03	40900.00
7B4240	2017-07-01 04:05:00+03	27300.00
7B427A	2017-07-15 06:44:00+03	272400.00
7B4283	2017-07-31 20:35:00+03	400000.00
7B42A3	2017-07-13 05:33:00+03	6000.00
7B432A	2017-07-07 08:06:00+03	149300.00
7B4354	2017-07-06 18:21:00+03	270800.00
7B43CE	2017-08-08 13:53:00+03	25600.00
7B43FF	2017-08-05 07:59:00+03	36800.00
7B4490	2017-07-04 22:34:00+03	94300.00
7B449C	2017-08-04 08:37:00+03	57500.00
7B44CE	2017-07-05 21:35:00+03	23600.00
7B44EE	2017-07-18 21:51:00+03	162600.00
7B44FE	2017-08-10 09:44:00+03	16000.00
7B456D	2017-07-18 16:20:00+03	166100.00
7B45DE	2017-07-30 20:47:00+03	117600.00
7B4610	2017-07-31 05:32:00+03	38600.00
7B4613	2017-08-02 23:07:00+03	12400.00
7B4620	2017-08-11 16:05:00+03	6200.00
7B466D	2017-08-03 03:10:00+03	55800.00
7B46D2	2017-08-05 19:15:00+03	20200.00
7B4706	2017-08-10 23:50:00+03	36200.00
7B470B	2017-06-27 02:08:00+03	27800.00
7B4727	2017-07-23 13:44:00+03	193600.00
7B4743	2017-08-11 08:29:00+03	27200.00
7B4760	2017-07-12 18:02:00+03	30200.00
7B47B5	2017-07-09 06:54:00+03	17200.00
7B485E	2017-07-19 00:53:00+03	73100.00
7B487A	2017-07-24 16:20:00+03	33400.00
7B48CD	2017-08-12 06:08:00+03	281500.00
7B48F7	2017-07-25 17:36:00+03	177200.00
7B4921	2017-07-22 00:48:00+03	71600.00
7B49B0	2017-07-11 21:58:00+03	179400.00
7B49DE	2017-07-17 12:44:00+03	19800.00
7B49E1	2017-07-25 06:14:00+03	45600.00
7B49EC	2017-07-25 05:28:00+03	56100.00
7B49FB	2017-07-11 18:42:00+03	44000.00
7B4A16	2017-07-15 03:42:00+03	18000.00
7B4A18	2017-07-15 15:11:00+03	54400.00
7B4A40	2017-07-29 23:28:00+03	40000.00
7B4AFD	2017-08-01 04:05:00+03	65900.00
7B4BC0	2017-07-28 04:14:00+03	69100.00
7B4BC9	2017-07-24 07:46:00+03	35800.00
7B4BD5	2017-08-04 14:20:00+03	112000.00
7B4BE8	2017-08-08 02:21:00+03	64300.00
7B4C1E	2017-07-02 05:27:00+03	47100.00
7B4C3B	2017-07-10 17:18:00+03	36800.00
7B4C9B	2017-08-12 16:12:00+03	26000.00
7B4CEE	2017-07-13 20:00:00+03	66000.00
7B4CF2	2017-07-06 01:38:00+03	23200.00
7B4D85	2017-07-08 07:09:00+03	38400.00
7B4DEC	2017-07-11 15:07:00+03	193100.00
7B4E05	2017-07-27 20:06:00+03	28800.00
7B4E13	2017-08-05 00:17:00+03	105600.00
7B4E29	2017-08-09 11:12:00+03	27200.00
7B4E61	2017-07-07 10:29:00+03	111600.00
7B4E7C	2017-06-30 19:32:00+03	52700.00
7B4E9A	2017-07-14 14:11:00+03	118000.00
7B4EBE	2017-07-31 20:11:00+03	420500.00
7B4EE1	2017-07-30 03:15:00+03	71800.00
7B4F38	2017-08-10 11:03:00+03	56000.00
7B4F3F	2017-07-01 20:08:00+03	19600.00
7B4F9A	2017-07-20 20:48:00+03	92000.00
7B4FA3	2017-08-04 00:34:00+03	16400.00
7B4FD0	2017-07-27 18:57:00+03	70800.00
7B5042	2017-07-10 17:39:00+03	25600.00
7B506C	2017-07-01 02:54:00+03	66600.00
7B50F9	2017-07-28 09:57:00+03	25400.00
7B511A	2017-07-29 01:03:00+03	161600.00
7B5129	2017-08-01 23:43:00+03	37900.00
7B5160	2017-07-18 04:14:00+03	84300.00
7B51F6	2017-07-20 20:26:00+03	68100.00
7B5243	2017-07-08 06:31:00+03	106400.00
7B52FD	2017-07-23 03:06:00+03	6000.00
7B5301	2017-07-31 10:56:00+03	26000.00
7B530F	2017-07-11 08:02:00+03	100600.00
7B532C	2017-07-09 20:54:00+03	101200.00
7B532F	2017-07-23 20:12:00+03	22600.00
7B53AC	2017-08-03 09:58:00+03	112600.00
7B53BB	2017-07-08 02:51:00+03	7400.00
7B53DC	2017-07-03 12:45:00+03	73900.00
7B5431	2017-07-10 13:13:00+03	86900.00
7B5438	2017-06-29 07:44:00+03	75600.00
7B544D	2017-08-11 11:54:00+03	20000.00
7B5525	2017-08-03 14:10:00+03	131600.00
7B5544	2017-07-07 05:38:00+03	29400.00
7B5545	2017-08-12 00:39:00+03	83000.00
7B5595	2017-07-27 13:34:00+03	40000.00
7B561A	2017-08-09 08:44:00+03	40800.00
7B5665	2017-07-06 20:14:00+03	92400.00
7B5670	2017-07-13 22:06:00+03	45200.00
7B567C	2017-07-18 15:47:00+03	167400.00
7B5685	2017-07-30 03:52:00+03	266300.00
7B5694	2017-07-30 12:16:00+03	11600.00
7B56C9	2017-07-20 09:26:00+03	92000.00
7B56E6	2017-07-08 19:29:00+03	105600.00
7B578A	2017-08-01 22:43:00+03	55500.00
7B57B4	2017-07-15 10:50:00+03	27200.00
7B5853	2017-08-14 00:24:00+03	188900.00
7B5881	2017-08-04 07:11:00+03	59800.00
7B58D0	2017-07-13 01:33:00+03	248300.00
7B58EF	2017-07-21 17:38:00+03	31400.00
7B58FF	2017-08-01 07:25:00+03	166100.00
7B5933	2017-08-07 09:10:00+03	227600.00
7B5972	2017-07-18 19:30:00+03	40400.00
7B5988	2017-08-04 14:15:00+03	7400.00
7B59C7	2017-07-11 12:32:00+03	135600.00
7B5B47	2017-08-07 11:39:00+03	147200.00
7B5B4F	2017-07-09 10:58:00+03	69000.00
7B5B7D	2017-07-26 05:57:00+03	23600.00
7B5BE9	2017-07-09 02:48:00+03	91100.00
7B5C45	2017-08-01 22:46:00+03	52400.00
7B5C51	2017-07-08 17:30:00+03	54500.00
7B5C54	2017-08-05 06:20:00+03	114800.00
7B5C70	2017-07-10 05:00:00+03	65100.00
7B5CA5	2017-07-07 01:10:00+03	86500.00
7B5CAD	2017-07-16 19:25:00+03	32800.00
7B5CAE	2017-07-20 17:53:00+03	153200.00
7B5CDF	2017-08-01 10:37:00+03	44800.00
7B5CEA	2017-06-30 05:04:00+03	122300.00
7B5CEF	2017-08-01 04:49:00+03	61800.00
7B5DC6	2017-08-08 22:38:00+03	24200.00
7B5DE8	2017-08-07 03:19:00+03	6000.00
7B5E1D	2017-08-08 04:07:00+03	78600.00
7B5E3F	2017-08-06 20:25:00+03	23200.00
7B5E40	2017-07-09 01:06:00+03	223200.00
7B5EF8	2017-07-10 02:26:00+03	228700.00
7B5FA2	2017-07-09 23:33:00+03	34800.00
7B6036	2017-07-19 15:54:00+03	100600.00
7B60B0	2017-07-03 17:30:00+03	117000.00
7B6160	2017-07-05 20:32:00+03	88800.00
7B6206	2017-07-04 22:36:00+03	129700.00
7B627E	2017-08-06 16:11:00+03	26800.00
7B632F	2017-07-20 09:20:00+03	23200.00
7B6334	2017-08-10 01:46:00+03	118900.00
7B639C	2017-07-07 20:55:00+03	25800.00
7B63BE	2017-07-12 00:47:00+03	135600.00
7B63E4	2017-06-29 16:29:00+03	56000.00
7B6401	2017-08-07 04:48:00+03	32800.00
7B642C	2017-08-03 23:29:00+03	76800.00
7B646B	2017-07-12 18:57:00+03	112000.00
7B6519	2017-07-22 15:53:00+03	57600.00
7B655B	2017-07-31 23:09:00+03	56600.00
7B6589	2017-07-31 22:27:00+03	16000.00
7B65C2	2017-08-06 14:28:00+03	6400.00
7B65DA	2017-07-05 06:55:00+03	139800.00
7B65E3	2017-08-01 05:46:00+03	70800.00
7B65F0	2017-07-14 06:54:00+03	21400.00
7B6629	2017-08-09 04:40:00+03	19600.00
7B6638	2017-08-14 16:30:00+03	70700.00
7B6657	2017-08-11 21:41:00+03	54700.00
7B667D	2017-08-14 23:47:00+03	19600.00
7B669D	2017-08-14 04:43:00+03	42700.00
7B66B7	2017-06-28 13:17:00+03	67100.00
7B66C4	2017-08-01 17:51:00+03	46200.00
7B670B	2017-07-20 14:12:00+03	16400.00
7B6830	2017-07-06 11:36:00+03	40800.00
7B6877	2017-07-02 22:18:00+03	43600.00
7B687A	2017-07-03 01:21:00+03	133600.00
7B6893	2017-07-12 06:31:00+03	80300.00
7B68A5	2017-07-16 08:32:00+03	27700.00
7B6911	2017-07-21 00:36:00+03	44800.00
7B693D	2017-08-11 07:05:00+03	7400.00
7B696F	2017-07-16 17:10:00+03	46400.00
7B6972	2017-08-12 14:04:00+03	186900.00
7B6A1E	2017-08-15 11:13:00+03	58000.00
7B6A53	2017-08-15 15:54:00+03	219400.00
7B6A80	2017-07-22 07:20:00+03	92600.00
7B6B7E	2017-07-05 01:14:00+03	400000.00
7B6C0E	2017-07-12 22:48:00+03	187600.00
7B6C4F	2017-08-11 23:24:00+03	43900.00
7B6D7B	2017-08-02 11:14:00+03	36200.00
7B6DC3	2017-07-10 07:07:00+03	136200.00
7B6DE1	2017-07-31 18:41:00+03	102000.00
7B6E16	2017-07-28 19:52:00+03	46900.00
7B6E5C	2017-07-05 08:43:00+03	261300.00
7B6EE2	2017-07-04 05:58:00+03	147700.00
7B6F10	2017-07-22 04:57:00+03	108500.00
7B6F86	2017-08-11 02:13:00+03	26000.00
7B6FBF	2017-07-19 11:13:00+03	78300.00
7B6FD9	2017-07-03 19:05:00+03	49200.00
7B6FED	2017-08-11 16:51:00+03	46400.00
7B7011	2017-07-06 10:46:00+03	89700.00
7B704D	2017-08-12 19:30:00+03	35600.00
7B7081	2017-07-05 04:36:00+03	198100.00
7B7096	2017-07-21 12:12:00+03	69100.00
7B7107	2017-08-01 20:36:00+03	56000.00
7B7119	2017-08-03 06:26:00+03	19600.00
7B7141	2017-08-13 09:53:00+03	223200.00
7B7149	2017-07-20 03:25:00+03	117000.00
7B71A4	2017-07-24 02:39:00+03	13400.00
7B71D6	2017-07-10 03:10:00+03	62000.00
7B7207	2017-08-02 15:50:00+03	49100.00
7B7248	2017-07-03 21:08:00+03	9800.00
7B72B3	2017-07-25 11:27:00+03	155600.00
7B72E4	2017-07-09 23:33:00+03	25700.00
7B72F1	2017-08-07 20:33:00+03	532800.00
7B7322	2017-07-16 10:25:00+03	139200.00
7B732C	2017-08-05 02:17:00+03	23600.00
7B73AF	2017-07-23 07:02:00+03	136000.00
7B73DF	2017-07-31 11:58:00+03	128800.00
7B7404	2017-08-12 10:11:00+03	7400.00
7B740D	2017-08-01 03:05:00+03	271100.00
7B742A	2017-07-29 03:07:00+03	34000.00
7B743F	2017-08-09 10:02:00+03	26200.00
7B745B	2017-07-28 02:08:00+03	29600.00
7B748B	2017-08-03 01:24:00+03	39500.00
7B74C1	2017-07-29 18:03:00+03	88900.00
7B754A	2017-07-26 17:41:00+03	24800.00
7B758C	2017-07-04 20:27:00+03	17000.00
7B7598	2017-07-10 07:58:00+03	6800.00
7B75D3	2017-08-06 01:04:00+03	51900.00
7B75DC	2017-07-15 23:32:00+03	241200.00
7B765F	2017-07-09 18:27:00+03	6000.00
7B7680	2017-07-15 08:42:00+03	116400.00
7B76D9	2017-07-24 22:12:00+03	206400.00
7B76EE	2017-08-03 11:10:00+03	134400.00
7B7720	2017-07-17 22:26:00+03	43700.00
7B7782	2017-07-29 03:04:00+03	23600.00
7B77D9	2017-06-29 21:19:00+03	40800.00
7B781B	2017-07-27 12:51:00+03	77000.00
7B7850	2017-08-05 11:55:00+03	56000.00
7B7872	2017-07-29 03:11:00+03	99600.00
7B787A	2017-07-01 23:57:00+03	28000.00
7B78BF	2017-08-01 09:31:00+03	222000.00
7B78D9	2017-07-10 20:54:00+03	50800.00
7B79A2	2017-07-15 00:33:00+03	24700.00
7B79B2	2017-07-10 04:38:00+03	98400.00
7B7A33	2017-08-14 05:33:00+03	257500.00
7B7A49	2017-08-13 18:26:00+03	34200.00
7B7A8F	2017-07-18 22:47:00+03	131600.00
7B7A9F	2017-07-10 22:20:00+03	46700.00
7B7AAA	2017-07-09 15:18:00+03	10800.00
7B7B6F	2017-07-29 01:44:00+03	12600.00
7B7BA5	2017-07-16 01:09:00+03	41800.00
7B7BB5	2017-06-30 22:08:00+03	68800.00
7B7BDC	2017-07-13 16:50:00+03	149400.00
7B7BF7	2017-07-25 05:41:00+03	57600.00
7B7C37	2017-08-10 11:28:00+03	119500.00
7B7C5E	2017-07-08 01:43:00+03	29200.00
7B7D16	2017-07-12 10:16:00+03	49900.00
7B7DCB	2017-07-22 23:00:00+03	38400.00
7B7DFC	2017-07-25 19:15:00+03	92000.00
7B7DFE	2017-08-03 17:21:00+03	25400.00
7B7E3A	2017-08-09 11:37:00+03	56000.00
7B7E45	2017-07-28 04:25:00+03	56000.00
7B7E84	2017-08-14 17:05:00+03	26800.00
7B7E86	2017-07-07 00:49:00+03	24000.00
7B7E89	2017-08-12 17:19:00+03	24400.00
7B7EA5	2017-07-15 05:45:00+03	64700.00
7B7F2A	2017-07-09 06:15:00+03	26700.00
7B7F6B	2017-07-06 08:58:00+03	81700.00
7B7FC9	2017-08-04 13:10:00+03	34100.00
7B7FFA	2017-07-20 01:28:00+03	61500.00
7B8028	2017-07-07 02:05:00+03	36200.00
7B8087	2017-07-23 14:03:00+03	55800.00
7B80E4	2017-08-14 15:03:00+03	71000.00
7B80E9	2017-08-15 08:20:00+03	32700.00
7B80F6	2017-07-26 08:17:00+03	40900.00
7B8146	2017-08-03 07:58:00+03	26000.00
7B81AB	2017-07-06 11:40:00+03	83300.00
7B81B0	2017-08-04 01:00:00+03	123000.00
7B8212	2017-08-13 09:49:00+03	90800.00
7B834D	2017-08-07 15:37:00+03	56000.00
7B8364	2017-08-07 19:52:00+03	193700.00
7B836D	2017-07-18 19:59:00+03	94900.00
7B83C2	2017-07-01 07:16:00+03	99200.00
7B8426	2017-07-21 21:35:00+03	185500.00
7B843B	2017-07-18 15:03:00+03	28000.00
7B8465	2017-07-28 01:25:00+03	40000.00
7B84CB	2017-07-29 11:17:00+03	32800.00
7B8517	2017-07-11 11:53:00+03	37900.00
7B85F0	2017-07-16 21:55:00+03	50400.00
7B85FB	2017-07-09 01:29:00+03	54500.00
7B8604	2017-07-31 16:57:00+03	55800.00
7B86B3	2017-08-10 12:31:00+03	38400.00
7B86B7	2017-08-03 02:27:00+03	49100.00
7B86BA	2017-08-03 18:53:00+03	64400.00
7B8773	2017-07-02 03:43:00+03	257500.00
7B8793	2017-07-23 06:49:00+03	48800.00
7B87B1	2017-07-20 23:09:00+03	52300.00
7B87BC	2017-08-13 18:05:00+03	84500.00
7B885F	2017-07-25 02:08:00+03	34100.00
7B8865	2017-07-06 09:34:00+03	35800.00
7B8872	2017-08-15 04:11:00+03	37200.00
7B88D1	2017-07-19 02:56:00+03	75600.00
7B8960	2017-07-21 05:25:00+03	88800.00
7B8971	2017-08-09 05:30:00+03	92600.00
7B897B	2017-07-23 02:02:00+03	45100.00
7B8984	2017-07-17 03:33:00+03	95000.00
7B898B	2017-07-18 02:08:00+03	38600.00
7B8996	2017-07-18 22:14:00+03	103100.00
7B89B9	2017-08-02 02:40:00+03	23900.00
7B89C9	2017-08-08 08:59:00+03	11600.00
7B89E1	2017-07-25 20:50:00+03	75600.00
7B89F8	2017-08-11 20:31:00+03	12400.00
7B8AF3	2017-08-09 05:13:00+03	131600.00
7B8B06	2017-07-14 06:00:00+03	26700.00
7B8B21	2017-07-04 13:05:00+03	67600.00
7B8B2B	2017-06-29 15:12:00+03	24000.00
7B8BB8	2017-08-04 18:08:00+03	15200.00
7B8C05	2017-07-23 03:04:00+03	73200.00
7B8C90	2017-07-06 10:52:00+03	37200.00
7B8CCE	2017-07-24 05:28:00+03	147200.00
7B8CD2	2017-08-03 09:18:00+03	59100.00
7B8CDE	2017-08-09 16:27:00+03	83000.00
7B8CF7	2017-08-04 22:07:00+03	31400.00
7B8D5A	2017-07-14 15:17:00+03	31400.00
7B8D62	2017-07-19 02:05:00+03	56000.00
7B8D6F	2017-07-03 06:55:00+03	258400.00
7B8D85	2017-07-31 20:44:00+03	67700.00
7B8DDD	2017-08-01 22:53:00+03	29600.00
7B8DE8	2017-08-10 17:47:00+03	12600.00
7B8E04	2017-08-12 08:33:00+03	56600.00
7B8E94	2017-07-30 23:10:00+03	92800.00
7B8EBE	2017-07-30 08:01:00+03	179700.00
7B8EF4	2017-08-12 11:30:00+03	50600.00
7B8EF7	2017-07-06 15:48:00+03	47600.00
7B8F1D	2017-07-06 08:12:00+03	44000.00
7B8F28	2017-07-13 23:45:00+03	263200.00
7B8F35	2017-07-02 00:18:00+03	258400.00
7B8F80	2017-07-29 05:45:00+03	36400.00
7B8FDD	2017-07-13 07:58:00+03	69500.00
7B902D	2017-07-09 07:40:00+03	23200.00
7B902E	2017-08-05 10:51:00+03	64500.00
7B9058	2017-07-15 00:59:00+03	27800.00
7B907B	2017-07-25 06:08:00+03	25400.00
7B909A	2017-08-01 19:39:00+03	113300.00
7B9114	2017-07-05 06:06:00+03	46300.00
7B9153	2017-07-03 08:05:00+03	51900.00
7B91AA	2017-08-02 07:15:00+03	100600.00
7B91B0	2017-07-24 13:40:00+03	55800.00
7B91B9	2017-08-07 11:34:00+03	246000.00
7B91C5	2017-08-03 22:23:00+03	23600.00
7B91F3	2017-07-12 19:23:00+03	95600.00
7B91FE	2017-07-01 07:09:00+03	40400.00
7B9211	2017-08-14 16:12:00+03	58200.00
7B9229	2017-08-15 14:43:00+03	92400.00
7B9248	2017-08-13 04:12:00+03	39800.00
7B9274	2017-07-24 21:26:00+03	67000.00
7B92AF	2017-07-12 12:12:00+03	39400.00
7B92B1	2017-07-10 02:44:00+03	23600.00
7B92DC	2017-07-27 09:10:00+03	12600.00
7B92F1	2017-07-28 10:53:00+03	94000.00
7B92F2	2017-07-17 20:47:00+03	28000.00
7B938A	2017-08-09 07:15:00+03	168000.00
7B93A4	2017-07-31 03:34:00+03	49800.00
7B93E6	2017-06-29 08:06:00+03	99200.00
7B944A	2017-07-09 15:14:00+03	86200.00
7B94B7	2017-08-03 11:07:00+03	55800.00
7B94D8	2017-08-13 10:00:00+03	81700.00
7B94FA	2017-07-08 00:24:00+03	47500.00
7B9617	2017-08-05 06:43:00+03	39800.00
7B965D	2017-07-18 18:47:00+03	114400.00
7B96B9	2017-08-05 05:17:00+03	43600.00
7B96E3	2017-07-02 12:46:00+03	113600.00
7B96ED	2017-07-14 00:12:00+03	125000.00
7B97B8	2017-07-14 21:01:00+03	133200.00
7B97C8	2017-07-25 15:32:00+03	54200.00
7B9800	2017-08-11 16:47:00+03	117600.00
7B98BD	2017-07-09 02:06:00+03	81300.00
7B9941	2017-07-07 06:10:00+03	46400.00
7B9957	2017-07-09 18:27:00+03	111600.00
7B9971	2017-08-02 02:33:00+03	58600.00
7B99FF	2017-07-11 16:10:00+03	52100.00
7B9A17	2017-07-02 06:27:00+03	39900.00
7B9AA7	2017-07-27 10:09:00+03	119600.00
7B9B12	2017-07-18 14:22:00+03	36200.00
7B9B95	2017-08-11 07:32:00+03	55800.00
7B9C25	2017-08-03 22:55:00+03	82000.00
7B9C2A	2017-07-08 11:55:00+03	144000.00
7B9C2E	2017-07-28 10:52:00+03	55800.00
7B9D78	2017-07-17 00:42:00+03	41400.00
7B9DA7	2017-07-02 16:29:00+03	32700.00
7B9DC2	2017-07-17 02:28:00+03	56600.00
7B9DC5	2017-07-28 13:54:00+03	12600.00
7B9DF3	2017-08-15 12:55:00+03	15000.00
7B9E02	2017-07-24 18:23:00+03	30200.00
7B9E17	2017-08-08 12:36:00+03	149100.00
7B9E3E	2017-07-26 14:24:00+03	8000.00
7B9E97	2017-08-12 09:05:00+03	73400.00
7B9F48	2017-07-01 10:39:00+03	60900.00
7B9F6D	2017-08-06 16:43:00+03	118000.00
7B9F8E	2017-08-14 23:23:00+03	56000.00
7B9FAA	2017-08-08 04:47:00+03	7400.00
7B9FB3	2017-07-07 04:20:00+03	152900.00
7BA01D	2017-07-08 13:41:00+03	186900.00
7BA034	2017-07-01 10:53:00+03	32800.00
7BA0D2	2017-07-27 16:27:00+03	249100.00
7BA12A	2017-07-10 02:25:00+03	24000.00
7BA157	2017-07-24 16:20:00+03	258000.00
7BA16A	2017-07-18 10:17:00+03	100600.00
7BA2B1	2017-07-17 15:15:00+03	24400.00
7BA2E4	2017-07-16 12:21:00+03	24400.00
7BA305	2017-07-25 13:21:00+03	47800.00
7BA307	2017-07-20 15:37:00+03	46500.00
7BA380	2017-07-19 21:02:00+03	52000.00
7BA48A	2017-07-22 02:56:00+03	28000.00
7BA4A1	2017-07-22 18:37:00+03	52300.00
7BA59C	2017-07-29 19:11:00+03	24400.00
7BA5BA	2017-07-19 09:39:00+03	6700.00
7BA5F0	2017-07-15 01:26:00+03	119500.00
7BA617	2017-08-10 21:46:00+03	50600.00
7BA64C	2017-08-03 07:59:00+03	36000.00
7BA665	2017-08-13 19:56:00+03	26200.00
7BA6B2	2017-07-11 02:38:00+03	51200.00
7BA6BA	2017-08-12 03:02:00+03	28800.00
7BA6FC	2017-08-07 07:25:00+03	25200.00
7BA6FE	2017-08-15 17:55:00+03	63000.00
7BA77D	2017-08-01 09:53:00+03	27800.00
7BA77E	2017-07-16 03:26:00+03	224000.00
7BA78E	2017-07-17 06:23:00+03	131100.00
7BA8B2	2017-07-16 00:36:00+03	47200.00
7BA8CA	2017-07-24 10:41:00+03	46000.00
7BA91D	2017-08-09 00:04:00+03	54000.00
7BA92F	2017-08-04 15:42:00+03	26000.00
7BA94B	2017-07-17 21:38:00+03	56000.00
7BA995	2017-07-04 13:53:00+03	73600.00
7BA9F1	2017-07-16 23:34:00+03	35600.00
7BAA04	2017-08-12 00:12:00+03	21400.00
7BAA51	2017-08-12 19:20:00+03	23200.00
7BAA71	2017-08-15 10:31:00+03	174000.00
7BAA93	2017-08-13 16:54:00+03	94200.00
7BAAB0	2017-07-29 12:44:00+03	257700.00
7BAAC0	2017-08-13 01:19:00+03	138600.00
7BAB50	2017-07-04 11:01:00+03	123000.00
7BAB64	2017-07-14 01:29:00+03	67000.00
7BAB71	2017-08-12 18:23:00+03	20600.00
7BAB8F	2017-08-14 09:20:00+03	42400.00
7BABD4	2017-07-15 01:24:00+03	100900.00
7BABD8	2017-07-07 00:13:00+03	13400.00
7BABEC	2017-07-23 10:20:00+03	43200.00
7BAC0B	2017-07-04 00:47:00+03	85400.00
7BAC3A	2017-07-07 10:54:00+03	55800.00
7BAC7E	2017-07-11 13:53:00+03	45200.00
7BACCA	2017-07-06 03:23:00+03	67600.00
7BACCB	2017-07-10 11:11:00+03	29600.00
7BACCC	2017-07-08 05:40:00+03	66400.00
7BACF6	2017-07-06 11:43:00+03	34200.00
7BAD2C	2017-08-10 09:48:00+03	114700.00
7BAD31	2017-07-24 04:29:00+03	19800.00
7BAD5A	2017-07-16 05:56:00+03	21800.00
7BAD7B	2017-07-14 10:06:00+03	35200.00
7BADDF	2017-07-30 02:09:00+03	35200.00
7BAE25	2017-08-14 01:13:00+03	22100.00
7BAE40	2017-08-04 07:58:00+03	58400.00
7BAE56	2017-08-11 16:08:00+03	146300.00
7BAE64	2017-07-28 21:55:00+03	57600.00
7BAE91	2017-07-20 04:39:00+03	66800.00
7BAE9E	2017-07-28 05:53:00+03	187600.00
7BAED2	2017-08-06 00:54:00+03	123000.00
7BAEE3	2017-07-16 10:54:00+03	47700.00
7BAFBF	2017-08-07 21:53:00+03	26000.00
7BAFD9	2017-08-02 02:44:00+03	15100.00
7BAFDF	2017-07-22 00:14:00+03	30900.00
7BB095	2017-07-22 03:13:00+03	26000.00
7BB0B1	2017-08-05 03:09:00+03	58400.00
7BB0D4	2017-07-19 22:51:00+03	36200.00
7BB120	2017-07-11 20:34:00+03	131600.00
7BB170	2017-08-11 21:20:00+03	168000.00
7BB176	2017-07-07 05:50:00+03	133200.00
7BB194	2017-07-17 03:46:00+03	30700.00
7BB1E6	2017-07-11 06:33:00+03	50800.00
7BB205	2017-07-10 15:59:00+03	66600.00
7BB23C	2017-08-07 18:52:00+03	55800.00
7BB265	2017-07-28 08:19:00+03	272300.00
7BB278	2017-07-14 23:05:00+03	14400.00
7BB36C	2017-08-03 19:41:00+03	44600.00
7BB3B3	2017-07-24 15:21:00+03	29400.00
7BB456	2017-08-03 08:44:00+03	65500.00
7BB45A	2017-08-08 17:30:00+03	63400.00
7BB4B7	2017-08-09 20:37:00+03	42600.00
7BB4FD	2017-08-03 21:19:00+03	56000.00
7BB53F	2017-07-12 04:12:00+03	17800.00
7BB587	2017-07-17 19:10:00+03	54800.00
7BB5BE	2017-07-15 00:14:00+03	23600.00
7BB5F1	2017-08-03 18:08:00+03	28000.00
7BB62E	2017-07-14 01:36:00+03	21400.00
7BB671	2017-07-21 10:51:00+03	38000.00
7BB6B1	2017-08-01 19:41:00+03	544700.00
7BB6F9	2017-07-11 02:31:00+03	39500.00
7BB75D	2017-07-19 14:50:00+03	18600.00
7BB764	2017-07-16 05:29:00+03	34000.00
7BB7AA	2017-07-17 03:39:00+03	79000.00
7BB7D3	2017-07-25 09:40:00+03	38800.00
7BB801	2017-07-21 13:51:00+03	101200.00
7BB850	2017-07-19 21:16:00+03	88600.00
7BB88B	2017-07-06 05:53:00+03	533300.00
7BB89D	2017-07-03 13:00:00+03	187600.00
7BBA26	2017-07-10 10:44:00+03	56000.00
7BBA50	2017-07-18 01:23:00+03	85000.00
7BBA9A	2017-07-16 15:21:00+03	58900.00
7BBB3F	2017-08-06 19:17:00+03	28800.00
7BBB5F	2017-07-11 17:57:00+03	36200.00
7BBB6B	2017-07-05 12:51:00+03	28000.00
7BBB93	2017-08-12 15:34:00+03	16400.00
7BBC16	2017-08-01 17:16:00+03	202400.00
7BBC47	2017-07-18 04:40:00+03	70800.00
7BBC9E	2017-08-05 13:19:00+03	521800.00
7BBCB7	2017-08-14 20:10:00+03	87700.00
7BBD27	2017-08-05 20:38:00+03	22400.00
7BBD3F	2017-07-27 02:38:00+03	25000.00
7BBD83	2017-07-02 19:33:00+03	93900.00
7BBE08	2017-07-19 01:56:00+03	84000.00
7BBE52	2017-08-14 07:28:00+03	34200.00
7BBE99	2017-07-19 03:18:00+03	14400.00
7BBEF7	2017-08-09 08:50:00+03	55000.00
7BBF12	2017-08-10 09:57:00+03	86600.00
7BBF21	2017-07-20 23:04:00+03	88900.00
7BBFA8	2017-07-16 09:56:00+03	229900.00
7BBFB1	2017-07-23 11:14:00+03	20100.00
7BBFF2	2017-07-23 21:24:00+03	39100.00
7BBFF8	2017-07-14 12:45:00+03	68400.00
7BBFFC	2017-07-11 21:21:00+03	58500.00
7BC0BE	2017-08-09 14:10:00+03	27400.00
7BC11C	2017-08-04 04:55:00+03	25200.00
7BC162	2017-07-16 03:49:00+03	14800.00
7BC1F8	2017-08-03 13:49:00+03	126300.00
7BC316	2017-08-07 11:29:00+03	128800.00
7BC34B	2017-08-10 06:46:00+03	26700.00
7BC3D9	2017-07-20 10:44:00+03	48800.00
7BC401	2017-07-12 03:30:00+03	313100.00
7BC481	2017-08-01 00:09:00+03	85700.00
7BC4C7	2017-08-05 16:14:00+03	23400.00
7BC54B	2017-07-28 16:42:00+03	103900.00
7BC54E	2017-08-09 12:22:00+03	74800.00
7BC58E	2017-07-19 22:18:00+03	46400.00
7BC5C7	2017-07-02 05:35:00+03	46200.00
7BC5D2	2017-07-22 13:12:00+03	33100.00
7BC616	2017-08-12 20:35:00+03	137100.00
7BC62B	2017-06-30 16:53:00+03	143100.00
7BC63B	2017-07-22 15:09:00+03	135400.00
7BC64E	2017-08-14 15:13:00+03	306800.00
7BC667	2017-08-05 15:05:00+03	102100.00
7BC6B7	2017-07-04 16:14:00+03	123000.00
7BC746	2017-06-29 12:39:00+03	28800.00
7BC7ED	2017-08-09 04:13:00+03	18400.00
7BC843	2017-07-26 08:23:00+03	28800.00
7BC89A	2017-07-28 10:58:00+03	124200.00
7BC8B1	2017-08-13 15:56:00+03	50000.00
7BC92A	2017-07-07 19:19:00+03	203400.00
7BC947	2017-06-26 18:53:00+03	99200.00
7BC94E	2017-08-14 11:47:00+03	36000.00
7BC9C3	2017-08-10 12:42:00+03	118300.00
7BCA3E	2017-07-12 19:24:00+03	26000.00
7BCAD4	2017-08-12 08:30:00+03	85000.00
7BCBB5	2017-07-17 03:46:00+03	142900.00
7BCBFB	2017-07-18 16:03:00+03	75600.00
7BCC11	2017-07-07 20:25:00+03	101900.00
7BCC6C	2017-07-05 07:37:00+03	170200.00
7BCC8A	2017-07-16 08:54:00+03	29400.00
7BCCE2	2017-07-09 09:59:00+03	56000.00
7BCCF1	2017-08-14 21:08:00+03	66100.00
7BCD0A	2017-07-22 15:19:00+03	71800.00
7BCDD8	2017-07-14 06:27:00+03	28000.00
7BCDFC	2017-07-08 13:27:00+03	99300.00
7BCE49	2017-08-12 02:41:00+03	246000.00
7BCEA4	2017-07-10 17:02:00+03	67100.00
7BCEA7	2017-07-05 06:00:00+03	52000.00
7BCEAC	2017-07-30 00:37:00+03	40000.00
7BCF68	2017-07-06 02:55:00+03	21200.00
7BD040	2017-08-06 12:21:00+03	70700.00
7BD112	2017-07-27 18:41:00+03	113000.00
7BD129	2017-07-26 22:38:00+03	95000.00
7BD16B	2017-07-02 12:52:00+03	20200.00
7BD17F	2017-08-12 02:24:00+03	100400.00
7BD18D	2017-07-17 04:07:00+03	47500.00
7BD1B3	2017-07-06 03:22:00+03	202400.00
7BD2CF	2017-08-03 13:56:00+03	28000.00
7BD33C	2017-07-29 19:26:00+03	86600.00
7BD364	2017-08-07 00:18:00+03	138000.00
7BD382	2017-07-22 20:56:00+03	7300.00
7BD3B8	2017-07-12 06:12:00+03	13200.00
7BD3EC	2017-07-26 02:38:00+03	112000.00
7BD407	2017-07-31 08:22:00+03	7400.00
7BD4EF	2017-08-11 07:26:00+03	27800.00
7BD516	2017-07-15 01:45:00+03	35200.00
7BD603	2017-08-12 10:50:00+03	35300.00
7BD621	2017-07-03 10:55:00+03	291600.00
7BD6BC	2017-07-29 13:27:00+03	73200.00
7BD6CB	2017-08-09 02:15:00+03	20400.00
7BD6CF	2017-07-20 20:55:00+03	24000.00
7BD6D0	2017-08-01 11:35:00+03	22000.00
7BD6D6	2017-07-28 01:53:00+03	125400.00
7BD711	2017-08-07 04:19:00+03	21400.00
7BD71C	2017-08-02 18:19:00+03	106400.00
7BD725	2017-07-12 22:26:00+03	402400.00
7BD74A	2017-07-07 17:16:00+03	41400.00
7BD777	2017-07-16 17:16:00+03	34000.00
7BD79A	2017-07-24 02:56:00+03	175200.00
7BD7B7	2017-07-04 00:21:00+03	36400.00
7BD802	2017-08-01 08:51:00+03	67600.00
7BD804	2017-07-20 19:36:00+03	244400.00
7BD805	2017-08-12 20:51:00+03	23200.00
7BD812	2017-08-11 03:13:00+03	38800.00
7BD84D	2017-07-27 18:55:00+03	37600.00
7BD87D	2017-08-08 07:17:00+03	79600.00
7BD88D	2017-07-25 07:23:00+03	16300.00
7BD891	2017-07-15 20:57:00+03	29600.00
7BD8E9	2017-07-13 07:46:00+03	150600.00
7BD955	2017-07-27 21:31:00+03	28800.00
7BD95A	2017-07-23 18:17:00+03	136200.00
7BD969	2017-07-15 04:17:00+03	81300.00
7BD96B	2017-07-12 00:35:00+03	64700.00
7BDA15	2017-07-19 01:18:00+03	41200.00
7BDA2F	2017-08-03 18:09:00+03	166700.00
7BDA47	2017-07-17 07:45:00+03	36800.00
7BDA50	2017-07-28 02:10:00+03	199600.00
7BDA79	2017-08-12 13:34:00+03	74900.00
7BDAA8	2017-06-27 01:45:00+03	48300.00
7BDB15	2017-07-15 15:11:00+03	39300.00
7BDB44	2017-07-31 09:36:00+03	369000.00
7BDB4F	2017-07-30 22:27:00+03	67200.00
7BDB92	2017-07-12 00:40:00+03	32800.00
7BDB9D	2017-08-02 16:41:00+03	26000.00
7BDC07	2017-08-04 22:51:00+03	55600.00
7BDC0F	2017-08-01 04:36:00+03	52800.00
7BDC11	2017-07-28 04:31:00+03	184500.00
7BDCCE	2017-07-13 02:43:00+03	24400.00
7BDD29	2017-08-01 09:44:00+03	28000.00
7BDD7C	2017-08-04 04:28:00+03	38800.00
7BDD86	2017-08-12 09:48:00+03	90600.00
7BDDB5	2017-08-04 19:35:00+03	72400.00
7BDDD0	2017-07-28 03:26:00+03	10700.00
7BDDFD	2017-07-13 17:47:00+03	115900.00
7BDE69	2017-06-30 21:16:00+03	19800.00
7BDEB2	2017-07-02 19:14:00+03	58000.00
7BDEBD	2017-07-07 03:52:00+03	105000.00
7BDEC8	2017-07-09 10:26:00+03	136800.00
7BDED5	2017-08-13 08:11:00+03	333400.00
7BDF29	2017-07-17 15:11:00+03	144400.00
7BDF49	2017-07-04 12:46:00+03	139200.00
7BDF4C	2017-07-29 11:42:00+03	38800.00
7BDF8B	2017-07-04 16:02:00+03	13400.00
7BDFB3	2017-08-11 16:32:00+03	24400.00
7BDFF1	2017-07-25 13:39:00+03	108500.00
7BE040	2017-08-11 03:05:00+03	51800.00
7BE0AC	2017-07-15 23:06:00+03	61800.00
7BE0E2	2017-07-23 18:18:00+03	43100.00
7BE115	2017-07-31 06:21:00+03	227400.00
7BE19C	2017-08-04 19:13:00+03	63200.00
7BE1F6	2017-08-12 22:24:00+03	6300.00
7BE22F	2017-08-02 19:28:00+03	67400.00
7BE2E4	2017-07-31 17:22:00+03	13400.00
7BE339	2017-07-28 05:00:00+03	134200.00
7BE353	2017-07-14 04:07:00+03	34000.00
7BE383	2017-07-12 23:38:00+03	25200.00
7BE3E7	2017-07-13 20:01:00+03	154800.00
7BE3E8	2017-07-12 03:22:00+03	238600.00
7BE41E	2017-07-15 09:37:00+03	23600.00
7BE435	2017-07-20 15:28:00+03	75600.00
7BE46B	2017-08-11 03:56:00+03	16400.00
7BE497	2017-07-09 17:17:00+03	23600.00
7BE49C	2017-08-09 21:00:00+03	75600.00
7BE506	2017-08-10 12:38:00+03	8000.00
7BE528	2017-07-08 10:45:00+03	63200.00
7BE58A	2017-08-11 04:32:00+03	97400.00
7BE5BE	2017-07-21 16:26:00+03	26000.00
7BE5C4	2017-07-20 03:16:00+03	214800.00
7BE5D0	2017-08-11 08:57:00+03	34600.00
7BE626	2017-08-02 17:29:00+03	157400.00
7BE68C	2017-07-12 13:41:00+03	11700.00
7BE6FA	2017-06-28 17:01:00+03	45100.00
7BE723	2017-07-28 10:06:00+03	28800.00
7BE7C6	2017-07-16 08:56:00+03	23100.00
7BE7F0	2017-08-07 04:29:00+03	37200.00
7BE84A	2017-08-13 12:22:00+03	26000.00
7BE852	2017-07-31 05:40:00+03	43600.00
7BE859	2017-07-23 12:56:00+03	61200.00
7BE8B3	2017-07-09 22:35:00+03	9800.00
7BE90A	2017-07-03 07:51:00+03	49800.00
7BE93F	2017-08-08 12:43:00+03	246000.00
7BE949	2017-08-15 01:28:00+03	68400.00
7BE9BD	2017-07-16 01:30:00+03	123000.00
7BE9C2	2017-08-09 01:41:00+03	14000.00
7BE9DE	2017-07-11 07:51:00+03	69500.00
7BEA13	2017-07-05 19:55:00+03	246000.00
7BEA89	2017-06-27 05:39:00+03	56000.00
7BEA8C	2017-08-04 02:35:00+03	67600.00
7BEADE	2017-07-15 17:32:00+03	66800.00
7BEADF	2017-07-09 09:52:00+03	252200.00
7BEB09	2017-07-14 03:23:00+03	26000.00
7BEBA3	2017-07-06 12:07:00+03	147700.00
7BEBF3	2017-07-12 20:46:00+03	24400.00
7BEBFD	2017-07-26 10:12:00+03	46000.00
7BEC5B	2017-07-17 04:13:00+03	35200.00
7BEC75	2017-08-02 22:38:00+03	26000.00
7BEC8E	2017-07-31 22:53:00+03	94400.00
7BED17	2017-07-07 10:43:00+03	56000.00
7BED2A	2017-08-10 20:57:00+03	20400.00
7BED4B	2017-07-18 00:48:00+03	133200.00
7BED5A	2017-07-07 09:44:00+03	88400.00
7BEDD4	2017-07-06 14:35:00+03	88800.00
7BEDDC	2017-07-12 01:10:00+03	14400.00
7BEDEB	2017-08-04 00:38:00+03	72000.00
7BEDFE	2017-07-07 11:18:00+03	28800.00
7BEE05	2017-07-12 02:18:00+03	183300.00
7BEE0A	2017-07-17 23:18:00+03	85000.00
7BEE36	2017-07-03 01:44:00+03	6800.00
7BEE3A	2017-07-25 07:04:00+03	99300.00
7BEED1	2017-07-15 23:59:00+03	96200.00
7BEEE1	2017-07-17 09:01:00+03	240600.00
7BEF43	2017-07-24 05:11:00+03	36200.00
7BEFD7	2017-08-07 07:02:00+03	220400.00
7BEFE4	2017-07-16 18:21:00+03	406700.00
7BF05A	2017-08-05 09:51:00+03	60600.00
7BF07D	2017-08-09 17:40:00+03	155600.00
7BF09B	2017-08-07 22:43:00+03	24400.00
7BF09C	2017-08-13 07:17:00+03	23600.00
7BF0F2	2017-08-10 18:45:00+03	66600.00
7BF0FE	2017-07-28 08:09:00+03	29600.00
7BF116	2017-07-16 04:03:00+03	200400.00
7BF1B9	2017-07-22 16:56:00+03	84100.00
7BF1E0	2017-08-08 16:18:00+03	34300.00
7BF208	2017-07-26 11:43:00+03	6800.00
7BF245	2017-07-04 19:29:00+03	35900.00
7BF268	2017-07-12 23:47:00+03	103800.00
7BF279	2017-08-04 23:19:00+03	199700.00
7BF32B	2017-08-15 15:39:00+03	89600.00
7BF3C9	2017-08-14 12:46:00+03	48500.00
7BF428	2017-07-09 03:54:00+03	24400.00
7BF4A1	2017-08-10 02:01:00+03	81700.00
7BF4FB	2017-07-15 16:43:00+03	93900.00
7BF509	2017-07-31 12:54:00+03	24300.00
7BF51A	2017-08-06 02:10:00+03	26800.00
7BF544	2017-07-31 12:18:00+03	57600.00
7BF5B2	2017-07-31 09:55:00+03	56000.00
7BF5EB	2017-08-03 08:31:00+03	48800.00
7BF674	2017-08-05 14:06:00+03	140500.00
7BF6C5	2017-07-27 09:23:00+03	40800.00
7BF746	2017-08-01 19:25:00+03	61800.00
7BF76C	2017-07-12 02:36:00+03	198100.00
7BF785	2017-07-28 22:53:00+03	78600.00
7BF7B3	2017-07-18 12:26:00+03	12100.00
7BF7D5	2017-07-12 07:48:00+03	35800.00
7BF811	2017-08-06 03:38:00+03	54800.00
7BF825	2017-07-04 16:48:00+03	8200.00
7BF879	2017-07-28 02:01:00+03	72200.00
7BF87A	2017-07-31 23:22:00+03	54100.00
7BF8C7	2017-07-23 22:04:00+03	93900.00
7BF8CD	2017-07-11 22:53:00+03	9200.00
7BF952	2017-07-24 20:47:00+03	12000.00
7BF965	2017-07-29 22:35:00+03	102000.00
7BF9B7	2017-07-05 18:11:00+03	23200.00
7BF9FB	2017-07-07 11:17:00+03	60400.00
7BF9FF	2017-07-05 08:47:00+03	111600.00
7BFA78	2017-07-26 21:07:00+03	59000.00
7BFAB4	2017-08-06 16:59:00+03	27300.00
7BFABD	2017-08-02 15:44:00+03	111600.00
7BFAD2	2017-08-08 20:45:00+03	64600.00
7BFB19	2017-07-08 01:40:00+03	56900.00
7BFB39	2017-07-07 21:10:00+03	71600.00
7BFB5E	2017-07-01 10:56:00+03	110000.00
7BFB6F	2017-07-10 04:44:00+03	159200.00
7BFB81	2017-07-11 20:29:00+03	28800.00
7BFB8C	2017-08-02 21:06:00+03	74400.00
7BFC01	2017-07-09 03:45:00+03	146600.00
7BFC3C	2017-08-08 10:34:00+03	167400.00
7BFC3F	2017-07-16 11:32:00+03	154500.00
7BFCCD	2017-07-15 09:21:00+03	50600.00
7BFD47	2017-07-31 02:53:00+03	75300.00
7BFD4C	2017-07-12 17:20:00+03	271100.00
7BFD53	2017-07-13 23:06:00+03	332800.00
7BFD59	2017-07-27 19:46:00+03	112000.00
7BFDD2	2017-07-17 00:02:00+03	135400.00
7BFDE3	2017-08-08 03:04:00+03	38600.00
7BFE0A	2017-07-28 05:43:00+03	67700.00
7BFE1D	2017-08-14 04:12:00+03	87200.00
7BFE7F	2017-08-05 20:37:00+03	7400.00
7BFEF8	2017-08-08 03:27:00+03	6000.00
7BFF1E	2017-07-12 15:40:00+03	86600.00
7BFF5B	2017-08-11 06:20:00+03	32200.00
7BFF5C	2017-07-24 22:35:00+03	33200.00
7BFF6A	2017-07-02 15:33:00+03	141200.00
7C002E	2017-08-04 22:11:00+03	14400.00
7C0035	2017-08-10 02:15:00+03	48300.00
7C004E	2017-07-24 22:48:00+03	44600.00
7C00C6	2017-07-17 14:13:00+03	515000.00
7C00FE	2017-07-23 10:14:00+03	152000.00
7C0116	2017-07-25 13:59:00+03	28000.00
7C0177	2017-07-09 05:54:00+03	26800.00
7C017F	2017-08-15 15:18:00+03	31200.00
7C01A8	2017-08-14 23:25:00+03	127500.00
7C01C4	2017-08-10 00:39:00+03	60400.00
7C01FD	2017-07-26 10:50:00+03	67400.00
7C0221	2017-08-02 13:58:00+03	134800.00
7C0238	2017-07-25 10:20:00+03	16600.00
7C0298	2017-07-10 02:25:00+03	199300.00
7C02DE	2017-07-18 12:24:00+03	25600.00
7C02F4	2017-07-10 06:52:00+03	77200.00
7C0341	2017-07-11 04:13:00+03	66600.00
7C0391	2017-08-08 19:53:00+03	50600.00
7C03E0	2017-08-04 10:29:00+03	62000.00
7C041D	2017-08-09 05:02:00+03	26800.00
7C0429	2017-07-11 04:18:00+03	226200.00
7C042C	2017-07-06 15:44:00+03	246000.00
7C0477	2017-08-15 02:13:00+03	13400.00
7C0494	2017-08-05 18:40:00+03	131600.00
7C04D8	2017-08-15 08:26:00+03	28800.00
7C04FF	2017-08-02 10:47:00+03	26600.00
7C057B	2017-07-14 00:48:00+03	177600.00
7C05AD	2017-07-15 03:31:00+03	126500.00
7C05B7	2017-07-09 20:19:00+03	46000.00
7C05E2	2017-07-08 14:01:00+03	111600.00
7C05E7	2017-07-23 07:37:00+03	31100.00
7C0681	2017-08-09 00:44:00+03	28300.00
7C0693	2017-08-13 04:56:00+03	62600.00
7C06E9	2017-07-02 17:12:00+03	48400.00
7C0754	2017-07-18 15:22:00+03	28000.00
7C0874	2017-08-12 19:02:00+03	20400.00
7C0897	2017-07-16 08:06:00+03	286900.00
7C08A0	2017-07-14 15:02:00+03	110700.00
7C0931	2017-07-19 18:56:00+03	32800.00
7C095A	2017-07-27 08:31:00+03	42400.00
7C097E	2017-07-03 10:06:00+03	21800.00
7C0994	2017-07-24 20:37:00+03	19600.00
7C0B01	2017-08-10 16:44:00+03	74000.00
7C0C3A	2017-07-24 15:35:00+03	28800.00
7C0C4F	2017-07-22 16:53:00+03	28800.00
7C0CE6	2017-08-09 09:52:00+03	56600.00
7C0D6A	2017-08-10 19:38:00+03	107800.00
7C0DC2	2017-08-03 09:17:00+03	29600.00
7C0DD1	2017-07-18 11:47:00+03	28200.00
7C0E1C	2017-07-07 04:46:00+03	195000.00
7C0E3C	2017-07-01 05:49:00+03	6700.00
7C0E7B	2017-07-26 08:47:00+03	55800.00
7C0EDF	2017-08-13 18:27:00+03	240600.00
7C0F40	2017-08-06 05:11:00+03	196100.00
7C0F46	2017-07-08 14:06:00+03	29500.00
7C0F58	2017-08-09 02:27:00+03	516800.00
7C0F97	2017-08-02 11:07:00+03	80500.00
7C0FBC	2017-07-19 03:33:00+03	95400.00
7C10D8	2017-07-09 01:32:00+03	29600.00
7C1137	2017-08-04 07:56:00+03	34100.00
7C1168	2017-07-13 16:34:00+03	16400.00
7C1179	2017-07-31 04:30:00+03	8200.00
7C11A3	2017-07-15 11:57:00+03	28800.00
7C1233	2017-08-13 00:25:00+03	14400.00
7C1318	2017-07-19 01:04:00+03	24400.00
7C132C	2017-07-20 07:34:00+03	50800.00
7C136F	2017-07-17 17:14:00+03	135600.00
7C1394	2017-07-30 04:30:00+03	71800.00
7C13E4	2017-08-15 13:16:00+03	22000.00
7C141E	2017-08-14 02:15:00+03	49900.00
7C1440	2017-07-30 05:06:00+03	85000.00
7C14D8	2017-08-14 01:38:00+03	67600.00
7C157F	2017-07-25 17:10:00+03	386300.00
7C158F	2017-07-04 08:49:00+03	113200.00
7C1636	2017-08-12 02:15:00+03	29000.00
7C16F5	2017-06-30 05:33:00+03	12600.00
7C1717	2017-06-29 10:32:00+03	38500.00
7C1727	2017-08-15 15:38:00+03	169800.00
7C17A9	2017-08-10 12:29:00+03	190700.00
7C17AE	2017-07-20 09:12:00+03	37900.00
7C17BB	2017-07-03 07:49:00+03	106900.00
7C17D8	2017-07-21 05:52:00+03	201200.00
7C181C	2017-07-24 12:04:00+03	187500.00
7C189A	2017-08-10 17:06:00+03	14400.00
7C191A	2017-08-07 20:34:00+03	57500.00
7C192D	2017-07-02 23:12:00+03	52400.00
7C192E	2017-08-15 06:32:00+03	28300.00
7C19AB	2017-07-07 04:20:00+03	200400.00
7C19D2	2017-08-13 11:23:00+03	42600.00
7C1A18	2017-07-04 04:33:00+03	111700.00
7C1A50	2017-07-20 18:14:00+03	404300.00
7C1A83	2017-07-09 12:36:00+03	45200.00
7C1ACF	2017-07-14 18:06:00+03	31900.00
7C1B1A	2017-07-21 10:39:00+03	73100.00
7C1B32	2017-08-05 06:44:00+03	42800.00
7C1B51	2017-07-31 18:13:00+03	40400.00
7C1B67	2017-07-29 01:41:00+03	40800.00
7C1C51	2017-07-09 20:42:00+03	420500.00
7C1CB7	2017-07-14 17:38:00+03	139300.00
7C1CC9	2017-07-06 21:53:00+03	50600.00
7C1D03	2017-07-14 02:16:00+03	80900.00
7C1D7E	2017-07-01 00:21:00+03	156400.00
7C1DA5	2017-07-25 19:19:00+03	193600.00
7C1E4A	2017-07-18 06:44:00+03	56600.00
7C1E83	2017-07-18 00:17:00+03	21800.00
7C1E86	2017-07-20 00:01:00+03	159600.00
7C1E9F	2017-08-10 03:13:00+03	24400.00
7C1F4A	2017-07-17 10:42:00+03	66600.00
7C1F76	2017-08-08 05:21:00+03	47000.00
7C1FC6	2017-08-08 20:16:00+03	31400.00
7C1FE8	2017-07-03 19:54:00+03	79300.00
7C2059	2017-08-11 05:40:00+03	75600.00
7C2112	2017-07-20 21:18:00+03	21400.00
7C2122	2017-08-14 21:48:00+03	130000.00
7C2143	2017-08-01 23:48:00+03	118900.00
7C2157	2017-07-18 03:58:00+03	22000.00
7C217B	2017-07-28 16:55:00+03	273600.00
7C21AE	2017-07-13 08:49:00+03	12600.00
7C21B6	2017-07-21 07:59:00+03	26000.00
7C2225	2017-07-28 20:36:00+03	13400.00
7C2231	2017-08-12 16:22:00+03	41800.00
7C2235	2017-07-29 21:20:00+03	56000.00
7C2252	2017-08-08 10:27:00+03	38800.00
7C2257	2017-07-18 11:29:00+03	10100.00
7C2268	2017-07-01 14:23:00+03	393800.00
7C226C	2017-08-07 09:53:00+03	35800.00
7C2298	2017-07-10 02:24:00+03	28000.00
7C229C	2017-07-22 07:04:00+03	56600.00
7C22CB	2017-07-23 06:27:00+03	197200.00
7C235C	2017-07-29 22:16:00+03	61800.00
7C23C3	2017-07-09 19:59:00+03	23200.00
7C2423	2017-07-21 06:35:00+03	196800.00
7C250A	2017-07-24 22:04:00+03	116900.00
7C2569	2017-08-10 20:43:00+03	99200.00
7C256E	2017-07-06 04:26:00+03	13200.00
7C25BE	2017-08-10 02:44:00+03	19600.00
7C25C8	2017-08-08 07:59:00+03	217800.00
7C2711	2017-08-02 08:03:00+03	182700.00
7C2726	2017-07-18 22:03:00+03	266400.00
7C2744	2017-07-26 12:28:00+03	23200.00
7C27B2	2017-08-11 13:51:00+03	28000.00
7C2837	2017-07-26 17:15:00+03	77700.00
7C28F9	2017-08-04 09:33:00+03	12600.00
7C290D	2017-07-07 11:47:00+03	49600.00
7C292A	2017-08-09 02:04:00+03	91600.00
7C29F6	2017-07-25 11:42:00+03	12600.00
7C2A51	2017-07-28 17:49:00+03	46300.00
7C2A52	2017-07-16 21:20:00+03	26800.00
7C2B09	2017-07-27 17:25:00+03	9200.00
7C2B32	2017-07-19 13:15:00+03	29400.00
7C2B46	2017-07-31 09:56:00+03	47800.00
7C2B5A	2017-07-30 21:38:00+03	84300.00
7C2B64	2017-08-12 04:05:00+03	10600.00
7C2BB4	2017-07-03 22:58:00+03	41600.00
7C2C18	2017-07-03 16:35:00+03	23200.00
7C2C5C	2017-08-01 11:11:00+03	97600.00
7C2C7A	2017-07-06 08:59:00+03	109800.00
7C2C8A	2017-07-02 02:58:00+03	240600.00
7C2CA9	2017-08-10 12:13:00+03	86600.00
7C2CE0	2017-07-28 07:31:00+03	89700.00
7C2CED	2017-07-29 08:39:00+03	516800.00
7C2D2B	2017-07-30 13:27:00+03	202100.00
7C2D31	2017-08-10 17:30:00+03	31400.00
7C2D81	2017-07-30 22:38:00+03	168000.00
7C2DCE	2017-07-10 09:02:00+03	46800.00
7C2DE1	2017-07-30 20:55:00+03	52700.00
7C2E39	2017-08-12 16:34:00+03	87300.00
7C2E46	2017-08-14 02:21:00+03	45100.00
7C2EAA	2017-07-01 12:15:00+03	55800.00
7C2F9F	2017-07-18 10:44:00+03	31600.00
7C2FFD	2017-07-10 20:13:00+03	113700.00
7C302C	2017-07-20 21:44:00+03	50800.00
7C3070	2017-07-21 01:08:00+03	48500.00
7C3135	2017-07-01 10:09:00+03	538100.00
7C31E4	2017-07-28 08:57:00+03	90200.00
7C3268	2017-07-19 15:00:00+03	85000.00
7C32C9	2017-07-15 22:57:00+03	57400.00
7C32D4	2017-07-24 21:17:00+03	69500.00
7C3371	2017-08-12 17:48:00+03	36500.00
7C33C3	2017-07-28 03:51:00+03	56000.00
7C3410	2017-07-15 07:47:00+03	47400.00
7C3432	2017-08-04 15:11:00+03	33600.00
7C346C	2017-06-30 09:50:00+03	22000.00
7C34D0	2017-07-20 09:44:00+03	43800.00
7C34EE	2017-07-21 23:43:00+03	53800.00
7C3516	2017-07-08 19:05:00+03	23600.00
7C3551	2017-07-08 19:06:00+03	46200.00
7C3574	2017-07-22 14:55:00+03	67600.00
7C358B	2017-08-04 01:45:00+03	81900.00
7C359A	2017-07-20 12:47:00+03	27400.00
7C35D7	2017-07-28 11:37:00+03	49600.00
7C3603	2017-07-11 02:06:00+03	103200.00
7C360A	2017-08-08 21:20:00+03	21400.00
7C3650	2017-07-27 08:15:00+03	11200.00
7C36B3	2017-07-27 20:54:00+03	46700.00
7C36ED	2017-08-05 03:12:00+03	156500.00
7C3749	2017-07-13 04:49:00+03	21800.00
7C3783	2017-08-04 21:35:00+03	20800.00
7C37A0	2017-08-03 03:52:00+03	52000.00
7C37C0	2017-07-07 15:10:00+03	170500.00
7C37F2	2017-07-27 09:25:00+03	20200.00
7C380E	2017-07-07 18:59:00+03	64400.00
7C3812	2017-07-11 11:32:00+03	65100.00
7C3843	2017-07-29 02:26:00+03	57600.00
7C3849	2017-07-29 02:29:00+03	117600.00
7C3946	2017-07-30 12:21:00+03	48800.00
7C3960	2017-07-26 01:05:00+03	127300.00
7C3969	2017-07-25 17:28:00+03	15000.00
7C39D2	2017-08-03 13:17:00+03	94000.00
7C3A08	2017-07-11 19:17:00+03	14000.00
7C3A18	2017-07-31 08:53:00+03	66000.00
7C3A8D	2017-07-16 06:46:00+03	85000.00
7C3A90	2017-07-27 08:01:00+03	156500.00
7C3AA2	2017-08-03 18:03:00+03	154500.00
7C3ACB	2017-08-11 03:38:00+03	46400.00
7C3AF7	2017-08-08 16:58:00+03	27200.00
7C3B04	2017-07-26 19:35:00+03	75300.00
7C3B1D	2017-08-11 18:36:00+03	48800.00
7C3B99	2017-08-14 22:25:00+03	26000.00
7C3BD3	2017-07-30 12:14:00+03	160200.00
7C3C21	2017-08-05 01:39:00+03	13600.00
7C3C3C	2017-07-05 06:38:00+03	16400.00
7C3CA6	2017-08-02 22:08:00+03	75800.00
7C3CD6	2017-07-06 00:12:00+03	106400.00
7C3D5D	2017-07-08 22:05:00+03	31600.00
7C3D5E	2017-08-13 20:22:00+03	55300.00
7C3DF7	2017-08-15 03:26:00+03	23200.00
7C3E4C	2017-08-11 07:44:00+03	67600.00
7C3E7F	2017-07-12 09:23:00+03	27900.00
7C3E8D	2017-08-08 23:32:00+03	168000.00
7C3F32	2017-06-29 07:42:00+03	28000.00
7C3F67	2017-07-29 02:34:00+03	28000.00
7C3FC6	2017-08-02 05:55:00+03	66000.00
7C3FE8	2017-08-06 19:31:00+03	170800.00
7C3FFE	2017-07-16 23:17:00+03	101100.00
7C408C	2017-08-09 21:14:00+03	92700.00
7C40C2	2017-07-24 15:42:00+03	74900.00
7C40FE	2017-07-23 07:43:00+03	50800.00
7C4116	2017-07-31 11:21:00+03	26700.00
7C411F	2017-07-27 17:59:00+03	24400.00
7C4199	2017-07-05 23:51:00+03	138000.00
7C41A3	2017-07-23 01:55:00+03	66600.00
7C41B5	2017-07-04 23:38:00+03	112000.00
7C420E	2017-07-28 10:19:00+03	94700.00
7C4226	2017-07-04 16:54:00+03	28000.00
7C4259	2017-07-02 23:42:00+03	40000.00
7C4267	2017-08-12 09:39:00+03	73500.00
7C428F	2017-07-07 19:49:00+03	101800.00
7C42A5	2017-07-01 01:43:00+03	56000.00
7C431D	2017-07-21 23:46:00+03	58400.00
7C4336	2017-08-01 04:14:00+03	72200.00
7C43A0	2017-07-03 10:51:00+03	70700.00
7C43BD	2017-08-15 13:19:00+03	123000.00
7C441A	2017-08-08 19:55:00+03	61300.00
7C4442	2017-08-03 01:11:00+03	26000.00
7C44B4	2017-08-12 09:16:00+03	67000.00
7C44DA	2017-07-22 04:49:00+03	103600.00
7C452E	2017-07-12 09:01:00+03	13800.00
7C4564	2017-07-11 09:00:00+03	16400.00
7C457C	2017-07-10 02:34:00+03	22000.00
7C45D5	2017-07-30 23:55:00+03	22000.00
7C45E0	2017-08-08 01:13:00+03	24800.00
7C464C	2017-07-26 17:54:00+03	66600.00
7C466C	2017-08-05 13:09:00+03	46000.00
7C46C4	2017-08-02 14:31:00+03	34000.00
7C46D0	2017-08-05 10:21:00+03	41400.00
7C4736	2017-08-15 14:31:00+03	169900.00
7C474F	2017-07-01 06:25:00+03	101300.00
7C4773	2017-08-01 02:28:00+03	393000.00
7C47CC	2017-07-31 19:29:00+03	135400.00
7C4849	2017-08-07 01:43:00+03	108000.00
7C48C8	2017-08-02 15:34:00+03	16400.00
7C48DF	2017-08-10 15:36:00+03	28800.00
7C48FD	2017-07-25 14:29:00+03	88200.00
7C4937	2017-07-08 19:22:00+03	73800.00
7C49B3	2017-06-28 14:27:00+03	48400.00
7C4A54	2017-07-28 00:13:00+03	22000.00
7C4AEB	2017-07-27 03:49:00+03	40400.00
7C4AEF	2017-08-06 13:32:00+03	7400.00
7C4B13	2017-08-11 09:15:00+03	6000.00
7C4B4B	2017-08-07 02:38:00+03	27800.00
7C4BC4	2017-08-02 07:43:00+03	125000.00
7C4C13	2017-07-07 08:00:00+03	6000.00
7C4CBA	2017-07-28 09:16:00+03	18600.00
7C4CC8	2017-07-06 10:31:00+03	92800.00
7C4D59	2017-07-18 07:09:00+03	66800.00
7C4D9B	2017-07-15 16:29:00+03	123000.00
7C4E02	2017-07-09 14:06:00+03	44800.00
7C4E40	2017-08-02 08:11:00+03	29200.00
7C4EB0	2017-07-25 12:19:00+03	18500.00
7C4F2C	2017-08-06 11:16:00+03	199300.00
7C4F49	2017-07-17 16:18:00+03	177600.00
7C4F7A	2017-08-09 08:11:00+03	23200.00
7C4F9F	2017-07-29 17:03:00+03	211000.00
7C4FAC	2017-08-15 15:30:00+03	42400.00
7C4FB9	2017-07-09 15:39:00+03	85600.00
7C4FD2	2017-07-15 11:33:00+03	39600.00
7C4FD7	2017-07-16 00:34:00+03	220200.00
7C501B	2017-07-19 18:07:00+03	38400.00
7C50B2	2017-07-04 11:19:00+03	65600.00
7C50EF	2017-07-11 13:07:00+03	192400.00
7C5124	2017-07-02 02:10:00+03	48400.00
7C5180	2017-07-21 05:35:00+03	83200.00
7C51AF	2017-08-04 13:05:00+03	11800.00
7C51DA	2017-07-04 08:19:00+03	41200.00
7C5201	2017-07-17 18:42:00+03	56000.00
7C520E	2017-07-10 18:08:00+03	57200.00
7C529E	2017-07-09 22:25:00+03	109600.00
7C52F6	2017-08-07 01:28:00+03	115700.00
7C5324	2017-07-25 19:25:00+03	55800.00
7C5367	2017-07-08 09:02:00+03	81300.00
7C536A	2017-07-20 19:58:00+03	266400.00
7C5379	2017-07-19 22:35:00+03	151200.00
7C543B	2017-07-29 03:04:00+03	121200.00
7C544D	2017-06-30 15:53:00+03	58100.00
7C5519	2017-07-07 02:06:00+03	13000.00
7C5520	2017-08-06 19:15:00+03	95600.00
7C567D	2017-08-06 07:54:00+03	202900.00
7C56CE	2017-08-05 20:35:00+03	56100.00
7C573A	2017-07-07 07:54:00+03	95600.00
7C5751	2017-07-19 18:42:00+03	103900.00
7C57C1	2017-07-19 03:13:00+03	51000.00
7C58CD	2017-07-27 11:23:00+03	62700.00
7C58F0	2017-08-02 19:30:00+03	47200.00
7C5906	2017-07-05 02:53:00+03	42800.00
7C59C2	2017-07-22 10:01:00+03	19600.00
7C59D2	2017-07-25 04:15:00+03	14000.00
7C59D3	2017-07-19 15:24:00+03	68100.00
7C59D8	2017-08-09 16:56:00+03	16400.00
7C5A9C	2017-08-10 13:43:00+03	112000.00
7C5B49	2017-08-15 01:33:00+03	135300.00
7C5B4F	2017-07-09 10:16:00+03	24300.00
7C5B86	2017-07-21 18:43:00+03	26000.00
7C5B94	2017-07-20 21:19:00+03	11600.00
7C5BA0	2017-07-08 05:38:00+03	57800.00
7C5C46	2017-08-08 00:57:00+03	63200.00
7C5CAF	2017-07-10 17:12:00+03	56000.00
7C5CE8	2017-08-04 09:25:00+03	54800.00
7C5D90	2017-07-14 05:42:00+03	26000.00
7C5D94	2017-08-10 06:33:00+03	243500.00
7C5DD3	2017-07-28 05:11:00+03	29200.00
7C5DE2	2017-08-11 09:50:00+03	75500.00
7C5E1A	2017-08-05 03:45:00+03	56000.00
7C5E53	2017-07-27 18:09:00+03	48300.00
7C5EEB	2017-07-21 04:21:00+03	44600.00
7C5EFF	2017-07-31 10:46:00+03	133200.00
7C5F1B	2017-08-11 14:21:00+03	23200.00
7C5F26	2017-08-10 01:43:00+03	38400.00
7C5F3D	2017-07-05 09:01:00+03	26000.00
7C5F58	2017-08-11 15:12:00+03	114800.00
7C5F65	2017-07-13 05:19:00+03	41900.00
7C5F7C	2017-07-20 03:06:00+03	16400.00
7C5FA0	2017-07-01 14:08:00+03	55800.00
7C5FBC	2017-07-24 18:48:00+03	53700.00
7C5FE1	2017-07-31 03:53:00+03	46000.00
7C6066	2017-08-08 07:55:00+03	8000.00
7C60C6	2017-07-10 14:11:00+03	281900.00
7C60C9	2017-07-08 15:22:00+03	18300.00
7C60FD	2017-07-27 00:50:00+03	174000.00
7C6129	2017-06-29 09:27:00+03	40800.00
7C617F	2017-08-04 04:11:00+03	185500.00
7C6184	2017-08-08 00:16:00+03	51900.00
7C618A	2017-07-13 23:49:00+03	73300.00
7C61D5	2017-08-01 04:08:00+03	62100.00
7C62A1	2017-07-30 05:59:00+03	85400.00
7C62BB	2017-08-10 12:37:00+03	290600.00
7C62F3	2017-07-07 17:46:00+03	28000.00
7C632C	2017-07-30 15:33:00+03	99600.00
7C6371	2017-07-03 08:17:00+03	67600.00
7C638E	2017-06-28 00:09:00+03	131100.00
7C6396	2017-07-12 20:25:00+03	41600.00
7C63CA	2017-08-07 13:36:00+03	101200.00
7C63EB	2017-07-02 22:25:00+03	65500.00
7C63F2	2017-08-02 01:10:00+03	176600.00
7C64A2	2017-08-04 06:23:00+03	246000.00
7C6568	2017-07-23 11:39:00+03	109800.00
7C6576	2017-07-01 05:52:00+03	101500.00
7C6577	2017-08-03 04:38:00+03	294000.00
7C6581	2017-07-14 08:22:00+03	140000.00
7C659F	2017-07-26 13:43:00+03	34000.00
7C65CE	2017-08-13 16:36:00+03	64600.00
7C65D0	2017-07-29 13:08:00+03	56000.00
7C65DD	2017-07-19 23:23:00+03	50600.00
7C6613	2017-07-06 11:56:00+03	27200.00
7C6653	2017-07-21 02:11:00+03	167400.00
7C665C	2017-07-29 00:48:00+03	50000.00
7C66C1	2017-08-07 14:48:00+03	447400.00
7C66CC	2017-07-26 22:06:00+03	73600.00
7C66D5	2017-07-26 08:31:00+03	6000.00
7C66EC	2017-08-06 10:18:00+03	55800.00
7C67B2	2017-07-30 02:17:00+03	266400.00
7C67FA	2017-08-12 14:13:00+03	63400.00
7C682D	2017-07-27 16:58:00+03	16400.00
7C682E	2017-07-23 19:12:00+03	64600.00
7C6834	2017-07-29 08:28:00+03	29600.00
7C68FF	2017-07-13 12:16:00+03	37900.00
7C6929	2017-07-19 09:44:00+03	28800.00
7C693A	2017-08-03 08:12:00+03	27200.00
7C6951	2017-07-13 03:07:00+03	67600.00
7C6985	2017-08-07 14:00:00+03	176300.00
7C69BE	2017-07-14 17:42:00+03	468000.00
7C69D6	2017-08-10 21:36:00+03	60400.00
7C6A01	2017-08-05 16:26:00+03	89100.00
7C6AE5	2017-07-17 21:49:00+03	71300.00
7C6B4A	2017-08-06 02:49:00+03	92000.00
7C6BB4	2017-08-10 19:23:00+03	19600.00
7C6C2D	2017-07-09 02:33:00+03	32400.00
7C6C4A	2017-08-08 21:59:00+03	43600.00
7C6CB7	2017-07-04 15:18:00+03	102100.00
7C6CC9	2017-08-13 07:27:00+03	201200.00
7C6CCF	2017-08-01 06:58:00+03	93600.00
7C6CEF	2017-07-18 00:00:00+03	137700.00
7C6D5A	2017-07-19 17:52:00+03	53000.00
7C6D6A	2017-07-26 09:55:00+03	55700.00
7C6DB7	2017-07-06 02:45:00+03	73600.00
7C6E2A	2017-08-03 18:33:00+03	68100.00
7C6E3C	2017-07-08 09:49:00+03	56100.00
7C6E6F	2017-08-09 01:01:00+03	266400.00
7C6E80	2017-07-12 08:38:00+03	28800.00
7C6EC8	2017-07-30 04:54:00+03	51300.00
7C6F20	2017-07-05 18:06:00+03	13400.00
7C6F26	2017-07-17 22:25:00+03	26000.00
7C6FBB	2017-08-01 12:01:00+03	112600.00
7C6FC2	2017-08-15 05:32:00+03	55600.00
7C7026	2017-07-06 01:26:00+03	21400.00
7C7078	2017-07-08 09:09:00+03	37400.00
7C70D8	2017-08-04 00:31:00+03	36200.00
7C722A	2017-07-15 22:46:00+03	168000.00
7C7256	2017-08-05 14:46:00+03	89600.00
7C7281	2017-07-26 01:00:00+03	112000.00
7C7295	2017-07-27 03:40:00+03	26000.00
7C72D5	2017-08-07 05:18:00+03	30200.00
7C72DE	2017-07-27 08:54:00+03	14400.00
7C72E7	2017-07-01 19:37:00+03	147700.00
7C732D	2017-07-28 14:22:00+03	6800.00
7C7376	2017-07-23 08:37:00+03	40400.00
7C7385	2017-07-22 14:54:00+03	26000.00
7C73CB	2017-07-07 17:02:00+03	177200.00
7C73FF	2017-07-15 15:12:00+03	23600.00
7C744E	2017-07-21 10:06:00+03	6900.00
7C7456	2017-07-28 22:55:00+03	62800.00
7C74B7	2017-07-20 08:58:00+03	24700.00
7C74F1	2017-07-28 20:09:00+03	40000.00
7C75C6	2017-07-05 08:02:00+03	48800.00
7C75FA	2017-08-15 15:57:00+03	205200.00
7C760F	2017-08-09 08:20:00+03	47100.00
7C7667	2017-07-19 11:29:00+03	56000.00
7C767E	2017-07-17 06:52:00+03	20400.00
7C76A0	2017-08-11 21:14:00+03	89200.00
7C76B6	2017-07-02 16:32:00+03	246000.00
7C76F0	2017-08-12 06:54:00+03	23200.00
7C770E	2017-08-12 10:38:00+03	56000.00
7C7720	2017-07-05 16:37:00+03	141600.00
7C779E	2017-08-08 04:07:00+03	101200.00
7C7840	2017-07-31 23:46:00+03	54400.00
7C78A0	2017-08-15 17:51:00+03	133100.00
7C78A8	2017-07-24 08:45:00+03	60400.00
7C78C1	2017-08-13 20:17:00+03	6300.00
7C78E2	2017-07-10 05:12:00+03	99700.00
7C7935	2017-08-15 17:33:00+03	21800.00
7C794A	2017-08-11 03:38:00+03	136200.00
7C794B	2017-08-14 07:43:00+03	101500.00
7C796B	2017-08-14 18:47:00+03	7200.00
7C7973	2017-07-13 07:34:00+03	131100.00
7C79D9	2017-07-11 16:06:00+03	43600.00
7C7A40	2017-07-03 23:09:00+03	131100.00
7C7A65	2017-08-10 01:31:00+03	24800.00
7C7B0F	2017-08-14 19:26:00+03	117200.00
7C7B14	2017-08-06 04:48:00+03	271400.00
7C7B32	2017-08-01 14:27:00+03	68400.00
7C7B46	2017-07-21 16:53:00+03	100600.00
7C7B92	2017-07-07 03:29:00+03	83700.00
7C7B9E	2017-07-30 11:11:00+03	24400.00
7C7BFB	2017-08-03 07:13:00+03	85700.00
7C7C24	2017-08-10 10:14:00+03	61900.00
7C7C44	2017-07-15 02:40:00+03	28000.00
7C7C67	2017-08-01 12:35:00+03	27200.00
7C7CA0	2017-07-17 22:17:00+03	50200.00
7C7D52	2017-07-21 18:26:00+03	404600.00
7C7E6E	2017-07-27 19:11:00+03	28000.00
7C7E9F	2017-08-12 07:20:00+03	12000.00
7C7ED0	2017-08-06 19:29:00+03	86500.00
7C7EDA	2017-07-25 03:09:00+03	23200.00
7C7EEA	2017-07-25 05:08:00+03	24400.00
7C7EF2	2017-07-22 19:31:00+03	25000.00
7C7EF4	2017-07-10 12:20:00+03	54500.00
7C7F13	2017-08-08 14:43:00+03	75700.00
7C7F8A	2017-07-15 19:39:00+03	103500.00
7C800C	2017-07-21 09:53:00+03	44800.00
7C801B	2017-08-03 15:09:00+03	46300.00
7C8031	2017-07-02 02:14:00+03	42800.00
7C8041	2017-08-14 00:53:00+03	26800.00
7C807E	2017-08-02 21:32:00+03	269200.00
7C808C	2017-07-21 14:30:00+03	47400.00
7C8095	2017-08-06 23:31:00+03	35800.00
7C80E4	2017-08-03 08:00:00+03	38800.00
7C811A	2017-07-12 11:41:00+03	88600.00
7C8129	2017-07-24 15:41:00+03	19800.00
7C8134	2017-07-21 20:57:00+03	57600.00
7C8166	2017-07-24 02:15:00+03	141700.00
7C8201	2017-08-07 04:31:00+03	99200.00
7C8245	2017-08-04 22:12:00+03	59100.00
7C824A	2017-08-10 09:27:00+03	13400.00
7C828E	2017-08-05 20:11:00+03	56900.00
7C82CA	2017-07-23 06:37:00+03	64800.00
7C831B	2017-07-14 08:35:00+03	10100.00
7C833E	2017-07-02 09:56:00+03	133100.00
7C83F5	2017-07-16 02:01:00+03	47400.00
7C8406	2017-07-07 09:30:00+03	19600.00
7C8446	2017-08-14 04:39:00+03	75600.00
7C848F	2017-07-20 11:42:00+03	168000.00
7C8495	2017-07-18 10:46:00+03	47400.00
7C854D	2017-08-02 22:43:00+03	6700.00
7C855B	2017-08-13 05:59:00+03	85600.00
7C8598	2017-08-12 10:05:00+03	23200.00
7C85DA	2017-07-08 23:58:00+03	26700.00
7C85DE	2017-07-15 16:43:00+03	23400.00
7C85EE	2017-07-14 23:09:00+03	78800.00
7C86BE	2017-08-02 05:49:00+03	20400.00
7C86D8	2017-07-24 00:11:00+03	205500.00
7C86E8	2017-07-24 00:40:00+03	18000.00
7C86F1	2017-07-24 08:29:00+03	66600.00
7C8728	2017-08-12 11:45:00+03	23200.00
7C874B	2017-06-28 00:08:00+03	6000.00
7C876D	2017-08-06 15:12:00+03	12600.00
7C878C	2017-07-24 23:58:00+03	228900.00
7C87CA	2017-07-02 13:32:00+03	24400.00
7C8846	2017-08-02 22:44:00+03	229300.00
7C8854	2017-07-14 23:10:00+03	67200.00
7C8876	2017-08-11 19:05:00+03	32800.00
7C88A5	2017-07-29 00:51:00+03	15000.00
7C88AB	2017-07-26 16:08:00+03	46300.00
7C8965	2017-08-12 12:38:00+03	23200.00
7C8976	2017-07-24 17:26:00+03	15000.00
7C898B	2017-07-24 12:17:00+03	112000.00
7C89B3	2017-07-23 13:22:00+03	233800.00
7C89DF	2017-07-10 08:42:00+03	57500.00
7C8A14	2017-07-31 21:46:00+03	45500.00
7C8A43	2017-07-08 21:24:00+03	273600.00
7C8A55	2017-07-20 09:14:00+03	49900.00
7C8A70	2017-08-01 11:12:00+03	55800.00
7C8A8A	2017-07-07 10:40:00+03	99600.00
7C8AD1	2017-07-27 09:39:00+03	56000.00
7C8B0F	2017-08-10 12:54:00+03	6000.00
7C8B22	2017-07-16 14:59:00+03	46300.00
7C8B8D	2017-08-09 22:16:00+03	19600.00
7C8C06	2017-07-21 00:47:00+03	62600.00
7C8C30	2017-07-25 23:04:00+03	93900.00
7C8C6C	2017-07-20 13:01:00+03	46200.00
7C8C8A	2017-07-03 08:02:00+03	91800.00
7C8CC8	2017-07-19 14:15:00+03	65900.00
7C8CCB	2017-07-15 09:17:00+03	59800.00
7C8D1B	2017-06-27 15:27:00+03	135400.00
7C8DD3	2017-08-07 14:01:00+03	72700.00
7C8E99	2017-07-16 02:29:00+03	89700.00
7C8EA7	2017-08-03 22:26:00+03	45400.00
7C8F17	2017-07-22 07:43:00+03	46400.00
7C8F27	2017-07-31 10:44:00+03	37100.00
7C8F75	2017-08-04 23:30:00+03	70700.00
7C8F87	2017-07-22 16:40:00+03	89700.00
7C8FC4	2017-07-25 13:01:00+03	480700.00
7C8FD2	2017-07-31 08:58:00+03	67700.00
7C8FF2	2017-07-28 22:45:00+03	418500.00
7C901E	2017-08-08 16:16:00+03	88400.00
7C90F2	2017-08-04 20:36:00+03	136800.00
7C9146	2017-07-26 00:44:00+03	35800.00
7C91BE	2017-07-29 06:10:00+03	62000.00
7C91C2	2017-07-13 08:54:00+03	67000.00
7C91CE	2017-08-07 16:15:00+03	48400.00
7C9205	2017-07-06 13:40:00+03	81500.00
7C9273	2017-06-27 23:25:00+03	24400.00
7C9282	2017-07-26 06:01:00+03	76600.00
7C9289	2017-07-21 19:00:00+03	123600.00
7C9294	2017-07-23 18:18:00+03	60400.00
7C9298	2017-08-11 10:19:00+03	47200.00
7C92DB	2017-07-20 00:13:00+03	10800.00
7C9362	2017-08-07 23:40:00+03	92800.00
7C93AC	2017-07-20 10:43:00+03	29400.00
7C93D9	2017-07-25 03:33:00+03	15400.00
7C9410	2017-07-03 12:58:00+03	55800.00
7C9466	2017-07-24 16:27:00+03	73600.00
7C9537	2017-08-05 02:10:00+03	81700.00
7C95A2	2017-07-31 05:14:00+03	13400.00
7C95FA	2017-08-05 19:46:00+03	35300.00
7C9628	2017-07-17 01:32:00+03	31400.00
7C9640	2017-08-04 22:33:00+03	31600.00
7C965D	2017-08-06 08:01:00+03	92900.00
7C969E	2017-08-05 13:57:00+03	23600.00
7C96AE	2017-07-05 04:29:00+03	14000.00
7C96E2	2017-07-28 00:43:00+03	27900.00
7C9771	2017-07-17 08:19:00+03	32700.00
7C9772	2017-07-30 23:11:00+03	119600.00
7C9778	2017-07-06 13:33:00+03	119500.00
7C9784	2017-07-01 14:30:00+03	18000.00
7C97A3	2017-07-07 07:02:00+03	86600.00
7C97AB	2017-08-15 12:32:00+03	126600.00
7C97D3	2017-07-31 21:46:00+03	48500.00
7C97D5	2017-07-03 10:50:00+03	55800.00
7C9814	2017-07-24 15:14:00+03	15000.00
7C9827	2017-07-31 03:42:00+03	92600.00
7C9837	2017-08-07 16:46:00+03	125500.00
7C98B9	2017-07-12 10:52:00+03	6400.00
7C98C7	2017-08-03 11:40:00+03	36600.00
7C9950	2017-07-22 07:07:00+03	148100.00
7C9960	2017-08-15 03:18:00+03	100400.00
7C9A35	2017-07-27 06:02:00+03	53800.00
7C9B2E	2017-07-22 02:18:00+03	23600.00
7C9B41	2017-07-13 18:29:00+03	37300.00
7C9B54	2017-08-10 04:23:00+03	26000.00
7C9B86	2017-07-22 01:50:00+03	114800.00
7C9B99	2017-07-26 00:48:00+03	173600.00
7C9BCF	2017-06-29 22:25:00+03	46700.00
7C9BE5	2017-08-02 23:14:00+03	119500.00
7C9C19	2017-08-14 23:59:00+03	15300.00
7C9C37	2017-07-15 21:36:00+03	23200.00
7C9C40	2017-08-09 22:39:00+03	6000.00
7C9C44	2017-08-15 15:53:00+03	16400.00
7C9C70	2017-07-10 01:52:00+03	35900.00
7C9C77	2017-08-01 19:58:00+03	58000.00
7C9CAC	2017-08-04 22:24:00+03	22200.00
7C9D42	2017-07-19 02:22:00+03	44000.00
7C9D61	2017-08-11 05:56:00+03	12600.00
7C9DF3	2017-07-11 22:12:00+03	22600.00
7C9E7A	2017-08-13 02:57:00+03	48000.00
7C9E7B	2017-08-10 06:51:00+03	153900.00
7C9F55	2017-07-03 19:34:00+03	123000.00
7C9FA0	2017-07-30 22:51:00+03	111600.00
7C9FED	2017-08-08 07:18:00+03	56000.00
7CA01C	2017-08-08 21:52:00+03	64200.00
7CA09B	2017-07-23 18:12:00+03	36200.00
7CA0F8	2017-07-08 19:47:00+03	98400.00
7CA10A	2017-07-26 21:35:00+03	28000.00
7CA1D7	2017-08-01 14:42:00+03	14000.00
7CA1FC	2017-08-05 02:45:00+03	386700.00
7CA1FF	2017-08-01 14:11:00+03	56900.00
7CA222	2017-08-14 04:14:00+03	69400.00
7CA22E	2017-08-04 02:13:00+03	81800.00
7CA253	2017-07-23 10:16:00+03	70600.00
7CA262	2017-07-06 04:15:00+03	56000.00
7CA267	2017-08-15 10:19:00+03	26700.00
7CA293	2017-07-02 21:36:00+03	135600.00
7CA29C	2017-08-09 07:15:00+03	42400.00
7CA2A4	2017-07-11 08:31:00+03	8400.00
7CA31B	2017-07-23 09:23:00+03	68000.00
7CA36B	2017-07-04 03:05:00+03	14000.00
7CA388	2017-08-06 09:08:00+03	54000.00
7CA3CB	2017-08-04 13:10:00+03	21200.00
7CA3DA	2017-08-10 02:48:00+03	33300.00
7CA3E2	2017-08-09 11:45:00+03	94900.00
7CA414	2017-07-14 20:05:00+03	423200.00
7CA41D	2017-08-12 05:36:00+03	31600.00
7CA42C	2017-07-28 10:15:00+03	10800.00
7CA4BA	2017-07-05 17:30:00+03	187800.00
7CA4E3	2017-08-03 11:48:00+03	12600.00
7CA4F9	2017-08-05 03:32:00+03	442100.00
7CA534	2017-08-11 18:18:00+03	23600.00
7CA54F	2017-08-01 05:23:00+03	29600.00
7CA585	2017-08-06 14:27:00+03	26000.00
7CA5DC	2017-07-16 01:49:00+03	246000.00
7CA694	2017-07-22 07:28:00+03	98400.00
7CA695	2017-07-14 02:26:00+03	135400.00
7CA6FD	2017-07-23 19:18:00+03	6800.00
7CA704	2017-08-07 14:41:00+03	75300.00
7CA713	2017-06-26 02:11:00+03	30200.00
7CA726	2017-07-20 08:33:00+03	42800.00
7CA791	2017-08-11 22:04:00+03	23200.00
7CA7E7	2017-07-01 06:29:00+03	79600.00
7CA841	2017-08-09 18:35:00+03	12000.00
7CA8A0	2017-07-05 20:07:00+03	61800.00
7CA8C5	2017-08-14 15:36:00+03	85000.00
7CA8D8	2017-06-28 16:32:00+03	27800.00
7CA8E2	2017-08-10 14:03:00+03	46300.00
7CA8E7	2017-08-05 02:03:00+03	56000.00
7CA8F1	2017-08-01 02:12:00+03	76200.00
7CA921	2017-08-02 10:50:00+03	229600.00
7CA981	2017-07-28 01:24:00+03	27200.00
7CA9CF	2017-08-02 22:59:00+03	36200.00
7CA9D7	2017-07-30 13:41:00+03	30900.00
7CA9E1	2017-08-03 01:29:00+03	65200.00
7CAA37	2017-08-10 14:40:00+03	23600.00
7CAAC7	2017-07-31 14:27:00+03	66600.00
7CAB1D	2017-07-08 19:29:00+03	27300.00
7CAB96	2017-08-03 11:43:00+03	272600.00
7CABC1	2017-07-27 13:04:00+03	56600.00
7CABC2	2017-08-09 08:35:00+03	39400.00
7CAC2A	2017-08-14 05:01:00+03	166000.00
7CAC3C	2017-07-20 08:53:00+03	133100.00
7CAC56	2017-08-10 07:08:00+03	45500.00
7CACA3	2017-07-08 12:05:00+03	95200.00
7CACA5	2017-07-15 03:24:00+03	65900.00
7CACB3	2017-07-30 03:11:00+03	58900.00
7CACC3	2017-08-10 06:15:00+03	34100.00
7CAD04	2017-08-05 03:58:00+03	16800.00
7CAD54	2017-07-01 22:45:00+03	25600.00
7CAD5D	2017-07-23 16:21:00+03	38600.00
7CAD73	2017-07-31 05:28:00+03	43200.00
7CAD91	2017-07-15 17:04:00+03	56600.00
7CADD1	2017-08-12 00:30:00+03	447900.00
7CADD4	2017-07-27 22:09:00+03	15400.00
7CADF6	2017-07-20 03:10:00+03	59400.00
7CAE04	2017-07-13 01:15:00+03	80800.00
7CAE51	2017-08-11 16:06:00+03	28000.00
7CAE5B	2017-07-24 17:14:00+03	277600.00
7CAE8B	2017-07-19 22:59:00+03	14000.00
7CAEB9	2017-07-15 20:46:00+03	114300.00
7CAEF1	2017-07-13 10:13:00+03	177600.00
7CAF32	2017-07-22 07:41:00+03	12600.00
7CAF94	2017-08-08 15:05:00+03	18600.00
7CAFB4	2017-07-18 02:19:00+03	63700.00
7CAFD3	2017-07-12 01:16:00+03	406100.00
7CB02E	2017-07-05 17:49:00+03	55800.00
7CB098	2017-07-25 05:42:00+03	16400.00
7CB0CC	2017-07-01 12:25:00+03	120700.00
7CB0D4	2017-07-15 16:33:00+03	47800.00
7CB0E4	2017-07-11 07:17:00+03	114600.00
7CB0EE	2017-07-19 05:07:00+03	46200.00
7CB106	2017-07-25 03:01:00+03	56900.00
7CB17B	2017-08-06 06:00:00+03	79700.00
7CB2F3	2017-07-28 11:09:00+03	97700.00
7CB3FE	2017-07-12 17:18:00+03	69400.00
7CB473	2017-07-13 15:32:00+03	46300.00
7CB47A	2017-08-07 02:14:00+03	143200.00
7CB49A	2017-07-07 00:40:00+03	173800.00
7CB4A0	2017-08-15 13:49:00+03	27400.00
7CB4AA	2017-08-03 20:43:00+03	27200.00
7CB50A	2017-07-31 10:59:00+03	34200.00
7CB530	2017-08-10 04:31:00+03	6000.00
7CB57A	2017-07-28 01:59:00+03	92000.00
7CB58D	2017-07-18 06:13:00+03	151200.00
7CB59A	2017-08-07 17:33:00+03	56000.00
7CB5A4	2017-07-24 20:16:00+03	27200.00
7CB5F5	2017-07-31 18:27:00+03	115200.00
7CB609	2017-08-14 02:22:00+03	74800.00
7CB639	2017-08-11 18:55:00+03	38800.00
7CB66A	2017-07-09 18:15:00+03	272600.00
7CB68F	2017-07-13 09:09:00+03	16400.00
7CB6A3	2017-07-02 06:40:00+03	125000.00
7CB6D5	2017-08-11 18:20:00+03	49100.00
7CB6FD	2017-07-06 13:50:00+03	31600.00
7CB752	2017-07-07 19:28:00+03	66800.00
7CB771	2017-08-12 14:47:00+03	180500.00
7CB7A1	2017-07-25 14:40:00+03	108200.00
7CB7BD	2017-07-27 21:36:00+03	369000.00
7CB7C6	2017-06-28 08:00:00+03	28000.00
7CB83B	2017-08-05 16:20:00+03	161600.00
7CB8B4	2017-07-29 15:02:00+03	26000.00
7CB8E8	2017-07-06 16:35:00+03	65300.00
7CB918	2017-08-06 16:29:00+03	43900.00
7CB93D	2017-07-24 23:24:00+03	20600.00
7CB958	2017-07-23 18:50:00+03	44000.00
7CB95C	2017-08-14 21:53:00+03	25100.00
7CB996	2017-08-07 21:44:00+03	95200.00
7CB9D7	2017-08-07 22:49:00+03	34600.00
7CB9FF	2017-08-11 08:58:00+03	47200.00
7CBA04	2017-08-09 17:31:00+03	92400.00
7CBA4B	2017-07-04 19:06:00+03	38600.00
7CBA66	2017-07-27 15:25:00+03	9200.00
7CBABC	2017-08-08 07:09:00+03	43000.00
7CBAC8	2017-07-22 21:42:00+03	135800.00
7CBADC	2017-07-20 18:37:00+03	46200.00
7CBAFE	2017-07-02 08:09:00+03	119800.00
7CBB0F	2017-07-12 00:02:00+03	6700.00
7CBB23	2017-07-17 08:14:00+03	89700.00
7CBBBF	2017-07-24 03:42:00+03	14800.00
7CBBD9	2017-08-13 20:38:00+03	29600.00
7CBBF8	2017-07-15 20:32:00+03	70800.00
7CBC3A	2017-06-27 07:41:00+03	28000.00
7CBC50	2017-07-10 08:44:00+03	30700.00
7CBCD2	2017-07-04 14:46:00+03	26200.00
7CBD14	2017-08-15 01:10:00+03	125400.00
7CBD3C	2017-07-09 08:55:00+03	271200.00
7CBD85	2017-07-02 21:56:00+03	132800.00
7CBD92	2017-07-06 07:40:00+03	19600.00
7CBDCA	2017-07-04 03:19:00+03	56000.00
7CBE34	2017-07-16 01:38:00+03	269200.00
7CBF13	2017-07-04 16:06:00+03	23200.00
7CBF3E	2017-08-09 04:43:00+03	65300.00
7CBF40	2017-07-23 06:56:00+03	81600.00
7CBFA1	2017-07-29 07:46:00+03	64800.00
7CC005	2017-08-08 23:23:00+03	22600.00
7CC010	2017-07-12 00:15:00+03	31600.00
7CC014	2017-07-01 01:46:00+03	27900.00
7CC033	2017-07-02 05:54:00+03	206400.00
7CC086	2017-07-13 23:11:00+03	57500.00
7CC18D	2017-08-09 09:00:00+03	66600.00
7CC197	2017-08-06 01:48:00+03	283500.00
7CC205	2017-08-03 15:53:00+03	49000.00
7CC2F2	2017-07-13 00:00:00+03	95200.00
7CC2F6	2017-07-16 10:56:00+03	27800.00
7CC306	2017-07-06 11:43:00+03	68400.00
7CC38C	2017-07-06 07:20:00+03	57600.00
7CC3C5	2017-07-23 18:31:00+03	6700.00
7CC469	2017-07-21 13:21:00+03	54800.00
7CC4A6	2017-07-13 05:27:00+03	32200.00
7CC4AD	2017-08-12 11:40:00+03	23400.00
7CC4BE	2017-08-04 07:22:00+03	126300.00
7CC4D0	2017-07-10 18:00:00+03	36200.00
7CC4D6	2017-08-08 16:30:00+03	167900.00
7CC4E6	2017-07-01 18:38:00+03	138100.00
7CC51B	2017-07-17 15:28:00+03	34000.00
7CC59A	2017-07-28 20:57:00+03	33600.00
7CC59F	2017-07-26 12:02:00+03	114800.00
7CC5B4	2017-07-25 21:34:00+03	74800.00
7CC5F8	2017-07-06 15:40:00+03	49900.00
7CC63B	2017-07-01 07:18:00+03	68800.00
7CC66F	2017-07-21 04:30:00+03	109500.00
7CC69C	2017-07-11 08:28:00+03	16400.00
7CC69D	2017-07-31 01:57:00+03	65900.00
7CC6C5	2017-07-05 08:30:00+03	38800.00
7CC772	2017-07-06 10:49:00+03	26400.00
7CC81F	2017-07-01 07:35:00+03	277000.00
7CC87F	2017-07-13 01:58:00+03	272300.00
7CC904	2017-07-17 11:46:00+03	169900.00
7CC91B	2017-08-10 12:55:00+03	387400.00
7CC927	2017-07-05 23:00:00+03	14400.00
7CC945	2017-07-21 20:54:00+03	44000.00
7CC98E	2017-07-30 05:07:00+03	44600.00
7CC9E7	2017-07-24 06:02:00+03	46800.00
7CCA28	2017-08-11 08:44:00+03	123000.00
7CCA92	2017-08-12 18:54:00+03	73600.00
7CCA99	2017-07-04 19:10:00+03	58000.00
7CCAA4	2017-08-01 17:06:00+03	103900.00
7CCAAC	2017-08-14 15:11:00+03	86400.00
7CCABE	2017-07-11 16:33:00+03	57400.00
7CCABF	2017-08-11 00:19:00+03	133100.00
7CCAD7	2017-08-06 23:36:00+03	86800.00
7CCB30	2017-07-20 18:06:00+03	54400.00
7CCB77	2017-07-08 20:20:00+03	50800.00
7CCB89	2017-08-06 02:56:00+03	36500.00
7CCBB5	2017-07-03 10:38:00+03	24400.00
7CCBCF	2017-07-30 08:53:00+03	303100.00
7CCBD9	2017-08-05 04:37:00+03	43500.00
7CCBDA	2017-07-14 22:05:00+03	13800.00
7CCC2A	2017-08-13 09:38:00+03	41600.00
7CCC98	2017-08-10 16:11:00+03	59200.00
7CCCBE	2017-07-13 08:17:00+03	50000.00
7CCDAB	2017-07-03 05:15:00+03	106100.00
7CCDF1	2017-07-25 18:24:00+03	190400.00
7CCDFC	2017-06-29 21:45:00+03	29400.00
7CCE24	2017-07-21 02:01:00+03	46000.00
7CCF62	2017-07-29 22:16:00+03	120300.00
7CD03B	2017-08-11 19:01:00+03	23200.00
7CD04A	2017-07-05 00:59:00+03	40800.00
7CD082	2017-08-05 06:15:00+03	101800.00
7CD09F	2017-07-07 12:05:00+03	6000.00
7CD148	2017-06-27 01:44:00+03	111100.00
7CD23B	2017-08-07 21:41:00+03	260900.00
7CD282	2017-08-10 15:48:00+03	169600.00
7CD308	2017-07-27 02:06:00+03	51800.00
7CD399	2017-08-13 22:58:00+03	246000.00
7CD3D8	2017-08-12 13:58:00+03	7400.00
7CD435	2017-07-21 14:19:00+03	85000.00
7CD44B	2017-07-13 04:28:00+03	124200.00
7CD4D8	2017-07-22 16:12:00+03	290500.00
7CD4DF	2017-08-09 21:20:00+03	80500.00
7CD564	2017-07-08 06:13:00+03	135200.00
7CD57E	2017-08-05 15:07:00+03	47500.00
7CD5AF	2017-07-25 23:18:00+03	35700.00
7CD621	2017-08-12 14:45:00+03	30800.00
7CD64F	2017-08-05 13:39:00+03	61800.00
7CD720	2017-08-01 03:24:00+03	49100.00
7CD73E	2017-07-18 00:40:00+03	184200.00
7CD744	2017-08-04 07:32:00+03	46400.00
7CD75A	2017-07-16 06:29:00+03	85000.00
7CD881	2017-07-06 06:16:00+03	34000.00
7CD8E2	2017-08-12 03:35:00+03	130400.00
7CD8E7	2017-07-31 04:41:00+03	59800.00
7CD91C	2017-07-14 03:35:00+03	283700.00
7CD91F	2017-08-06 01:17:00+03	38900.00
7CD965	2017-07-31 07:38:00+03	55500.00
7CD98B	2017-07-02 15:12:00+03	405200.00
7CDA17	2017-07-31 16:37:00+03	112600.00
7CDA1B	2017-07-25 02:42:00+03	283900.00
7CDA35	2017-07-14 06:43:00+03	70700.00
7CDA46	2017-07-25 15:04:00+03	272300.00
7CDA50	2017-07-08 16:30:00+03	60400.00
7CDB5B	2017-07-13 11:39:00+03	38800.00
7CDBE3	2017-07-30 03:17:00+03	135200.00
7CDC3B	2017-07-16 04:58:00+03	106400.00
7CDC47	2017-07-13 20:06:00+03	38600.00
7CDC52	2017-08-13 21:16:00+03	42800.00
7CDC64	2017-07-08 11:19:00+03	36200.00
7CDCA3	2017-07-25 03:57:00+03	29600.00
7CDDAB	2017-08-02 11:21:00+03	172200.00
7CDE27	2017-07-18 16:23:00+03	35200.00
7CDE7B	2017-07-08 01:13:00+03	201800.00
7CDED4	2017-07-23 11:22:00+03	28000.00
7CDEDA	2017-07-10 00:41:00+03	175300.00
7CDEDB	2017-07-30 00:26:00+03	31600.00
7CDF2E	2017-07-15 04:05:00+03	31400.00
7CDF59	2017-07-24 23:22:00+03	14800.00
7CDFA8	2017-08-06 03:25:00+03	21800.00
7CDFED	2017-07-16 18:44:00+03	68800.00
7CE02A	2017-07-03 14:43:00+03	117000.00
7CE02B	2017-06-24 15:16:00+03	77000.00
7CE041	2017-08-03 09:41:00+03	82500.00
7CE093	2017-08-15 06:27:00+03	75600.00
7CE0D8	2017-08-01 04:14:00+03	118700.00
7CE0E2	2017-07-31 12:00:00+03	26800.00
7CE0E6	2017-07-27 12:16:00+03	66400.00
7CE125	2017-08-14 19:48:00+03	31400.00
7CE14C	2017-07-01 07:53:00+03	24200.00
7CE19D	2017-07-29 07:10:00+03	357600.00
7CE1D1	2017-08-11 12:58:00+03	392100.00
7CE243	2017-07-13 07:14:00+03	44000.00
7CE2BA	2017-07-29 18:40:00+03	90400.00
7CE2E5	2017-07-13 04:46:00+03	114400.00
7CE38D	2017-07-30 00:18:00+03	65900.00
7CE3F4	2017-08-09 23:37:00+03	67200.00
7CE43B	2017-07-11 01:46:00+03	35200.00
7CE454	2017-07-15 01:11:00+03	68800.00
7CE45F	2017-07-10 12:47:00+03	58600.00
7CE464	2017-08-01 13:26:00+03	44800.00
7CE48E	2017-08-10 17:25:00+03	229500.00
7CE4A7	2017-07-05 12:24:00+03	54500.00
7CE4D6	2017-07-23 21:54:00+03	37100.00
7CE4F9	2017-08-12 04:52:00+03	44000.00
7CE536	2017-07-15 17:09:00+03	398500.00
7CE576	2017-07-29 20:15:00+03	57800.00
7CE5AD	2017-07-02 07:58:00+03	52000.00
7CE5DD	2017-08-07 00:59:00+03	67700.00
7CE630	2017-07-14 06:04:00+03	66800.00
7CE679	2017-07-03 19:09:00+03	27900.00
7CE6C2	2017-08-13 17:29:00+03	128800.00
7CE6DF	2017-08-07 10:30:00+03	113800.00
7CE768	2017-06-29 13:58:00+03	75600.00
7CE836	2017-07-10 04:27:00+03	185600.00
7CE8BB	2017-07-24 20:30:00+03	73400.00
7CE8D6	2017-07-09 07:24:00+03	140900.00
7CE97D	2017-08-02 19:21:00+03	57400.00
7CE981	2017-08-01 06:35:00+03	75600.00
7CE9A5	2017-07-03 04:47:00+03	114900.00
7CE9B3	2017-07-27 07:52:00+03	46000.00
7CE9BB	2017-07-31 09:31:00+03	112000.00
7CEA2C	2017-07-12 23:44:00+03	44800.00
7CEA34	2017-07-12 11:27:00+03	81600.00
7CEA52	2017-07-15 01:37:00+03	58200.00
7CEA56	2017-08-05 06:37:00+03	123000.00
7CEA63	2017-07-04 19:14:00+03	147000.00
7CEA67	2017-07-08 15:34:00+03	75600.00
7CEA94	2017-07-23 10:28:00+03	6000.00
7CEBBF	2017-07-18 02:59:00+03	31000.00
7CECEC	2017-07-19 20:05:00+03	75600.00
7CECF3	2017-08-07 02:24:00+03	80100.00
7CECF6	2017-07-29 16:05:00+03	85400.00
7CECFF	2017-07-05 14:07:00+03	34000.00
7CED17	2017-08-04 17:49:00+03	54600.00
7CED69	2017-07-27 23:07:00+03	115800.00
7CED82	2017-06-23 08:31:00+03	12600.00
7CED88	2017-07-16 17:13:00+03	207000.00
7CEDF6	2017-07-09 04:49:00+03	37900.00
7CEE09	2017-08-03 10:43:00+03	61800.00
7CEE39	2017-06-30 22:37:00+03	182200.00
7CEE72	2017-07-25 11:07:00+03	16400.00
7CEF1A	2017-07-07 03:56:00+03	90800.00
7CEF1E	2017-07-10 14:31:00+03	26700.00
7CEF4C	2017-08-11 02:35:00+03	82000.00
7CEF60	2017-07-13 05:49:00+03	99800.00
7CEF9E	2017-08-07 02:36:00+03	46200.00
7CEFA1	2017-07-29 14:53:00+03	94000.00
7CF07C	2017-08-03 13:38:00+03	21400.00
7CF08E	2017-07-16 14:41:00+03	26600.00
7CF09B	2017-07-30 06:28:00+03	58800.00
7CF0A4	2017-07-11 10:31:00+03	28000.00
7CF128	2017-08-02 13:31:00+03	58200.00
7CF145	2017-07-06 04:42:00+03	47200.00
7CF1AE	2017-06-30 10:53:00+03	25400.00
7CF1D7	2017-08-09 13:11:00+03	53100.00
7CF1DE	2017-07-14 16:48:00+03	123200.00
7CF1E1	2017-08-05 00:06:00+03	58900.00
7CF203	2017-08-01 08:49:00+03	37300.00
7CF221	2017-08-08 06:17:00+03	45100.00
7CF233	2017-08-10 08:59:00+03	77200.00
7CF23A	2017-07-09 09:23:00+03	12700.00
7CF26B	2017-07-11 17:58:00+03	385000.00
7CF2F1	2017-08-14 22:30:00+03	94000.00
7CF322	2017-07-10 00:19:00+03	24400.00
7CF33B	2017-07-31 23:21:00+03	25600.00
7CF412	2017-08-10 06:28:00+03	105400.00
7CF480	2017-07-05 13:28:00+03	80900.00
7CF535	2017-07-07 14:44:00+03	56000.00
7CF53A	2017-07-22 09:59:00+03	147700.00
7CF557	2017-07-30 06:01:00+03	202100.00
7CF561	2017-07-02 00:27:00+03	6000.00
7CF580	2017-07-09 05:14:00+03	173200.00
7CF617	2017-07-06 09:59:00+03	32800.00
7CF68F	2017-08-10 02:36:00+03	50600.00
7CF720	2017-07-05 21:18:00+03	95000.00
7CF80D	2017-07-13 22:37:00+03	81300.00
7CF897	2017-07-16 01:09:00+03	13000.00
7CF8A1	2017-07-30 12:45:00+03	9800.00
7CF8AC	2017-07-31 08:06:00+03	75300.00
7CF8E9	2017-07-16 10:43:00+03	102200.00
7CF987	2017-07-27 09:27:00+03	428000.00
7CFA2F	2017-07-19 13:24:00+03	289800.00
7CFA47	2017-07-05 15:15:00+03	22000.00
7CFA55	2017-08-01 20:05:00+03	6800.00
7CFA58	2017-08-01 00:47:00+03	27200.00
7CFA87	2017-07-12 17:41:00+03	56000.00
7CFAB1	2017-07-28 02:22:00+03	26000.00
7CFB29	2017-07-10 16:04:00+03	23200.00
7CFB56	2017-07-11 01:33:00+03	16400.00
7CFBAA	2017-08-03 02:24:00+03	63700.00
7CFC1C	2017-07-10 07:12:00+03	67200.00
7CFC2B	2017-07-31 16:35:00+03	12600.00
7CFC31	2017-07-03 18:44:00+03	46800.00
7CFCB9	2017-08-04 04:44:00+03	136800.00
7CFCD4	2017-07-30 15:23:00+03	57600.00
7CFCEE	2017-07-04 06:46:00+03	147400.00
7CFCF5	2017-08-05 13:09:00+03	393000.00
7CFD0C	2017-08-07 20:34:00+03	87800.00
7CFD1F	2017-07-20 15:41:00+03	257500.00
7CFD4D	2017-07-08 23:50:00+03	75300.00
7CFD57	2017-08-10 14:23:00+03	92200.00
7CFDCD	2017-07-24 22:30:00+03	27700.00
7CFDD9	2017-07-10 12:29:00+03	132800.00
7CFE4A	2017-08-11 05:00:00+03	32400.00
7CFE9A	2017-06-28 09:31:00+03	12600.00
7CFEC7	2017-08-01 05:59:00+03	67100.00
7CFEDC	2017-08-15 04:29:00+03	26000.00
7CFF10	2017-07-13 13:16:00+03	57700.00
7CFF30	2017-07-15 02:57:00+03	16400.00
7CFFA6	2017-07-07 04:47:00+03	37900.00
7CFFFD	2017-08-14 07:35:00+03	31100.00
7D0005	2017-08-08 14:25:00+03	119500.00
7D0033	2017-08-15 06:12:00+03	62800.00
7D003B	2017-07-27 20:34:00+03	86500.00
7D0069	2017-08-03 01:25:00+03	168100.00
7D00EA	2017-07-05 14:13:00+03	19600.00
7D0106	2017-07-06 00:29:00+03	32600.00
7D0116	2017-08-01 00:15:00+03	14000.00
7D012F	2017-07-17 10:04:00+03	47400.00
7D013D	2017-08-15 05:30:00+03	14400.00
7D0174	2017-07-27 11:00:00+03	25200.00
7D0192	2017-08-05 11:55:00+03	27200.00
7D019E	2017-08-01 12:53:00+03	6600.00
7D01F2	2017-08-01 19:56:00+03	61800.00
7D0217	2017-08-06 08:47:00+03	25400.00
7D02D2	2017-07-01 15:54:00+03	70500.00
7D0313	2017-08-14 05:12:00+03	88900.00
7D0363	2017-08-15 08:47:00+03	38400.00
7D0364	2017-07-26 20:27:00+03	6700.00
7D037E	2017-08-10 08:03:00+03	108000.00
7D03AA	2017-07-29 09:39:00+03	40600.00
7D040B	2017-07-09 04:08:00+03	160100.00
7D04E3	2017-08-03 21:11:00+03	392000.00
7D0503	2017-08-12 01:12:00+03	51200.00
7D0507	2017-08-14 20:22:00+03	56000.00
7D051D	2017-08-08 16:08:00+03	56600.00
7D0545	2017-07-13 02:33:00+03	55800.00
7D057F	2017-07-06 12:18:00+03	70600.00
7D05BB	2017-08-05 18:42:00+03	34100.00
7D05CF	2017-07-30 17:19:00+03	75300.00
7D0623	2017-07-07 23:24:00+03	14000.00
7D06C8	2017-08-10 22:28:00+03	25900.00
7D0762	2017-08-14 11:31:00+03	136600.00
7D07F7	2017-07-20 19:19:00+03	13400.00
7D088C	2017-07-08 17:46:00+03	158500.00
7D08CA	2017-07-11 03:01:00+03	177200.00
7D0910	2017-07-04 21:36:00+03	23900.00
7D091F	2017-08-09 22:28:00+03	203800.00
7D0948	2017-07-09 23:29:00+03	62800.00
7D0B21	2017-06-28 06:59:00+03	31100.00
7D0B9D	2017-08-14 06:48:00+03	111600.00
7D0BC2	2017-08-12 21:59:00+03	119600.00
7D0BC5	2017-08-11 15:14:00+03	274200.00
7D0BDE	2017-08-09 09:37:00+03	141700.00
7D0BE8	2017-08-04 10:57:00+03	208000.00
7D0BEB	2017-07-03 02:37:00+03	14000.00
7D0C1C	2017-08-04 18:18:00+03	151000.00
7D0C78	2017-07-09 02:56:00+03	55800.00
7D0CB2	2017-07-28 04:33:00+03	31100.00
7D0D04	2017-07-22 06:50:00+03	542200.00
7D0D28	2017-07-28 23:36:00+03	97500.00
7D0D41	2017-07-13 09:50:00+03	284700.00
7D0D54	2017-07-24 16:10:00+03	29600.00
7D0D57	2017-07-19 18:24:00+03	94800.00
7D0D65	2017-08-07 06:56:00+03	66600.00
7D0D86	2017-08-15 01:59:00+03	50700.00
7D0DA3	2017-07-08 19:29:00+03	320400.00
7D0DD0	2017-07-09 09:05:00+03	56000.00
7D0DEE	2017-07-20 13:41:00+03	50400.00
7D0DF8	2017-07-04 10:27:00+03	40800.00
7D0E5C	2017-07-08 08:27:00+03	31600.00
7D0EA4	2017-07-03 08:33:00+03	26000.00
7D0EAD	2017-07-07 09:20:00+03	13800.00
7D0EBE	2017-07-13 00:56:00+03	66600.00
7D0EFB	2017-07-03 17:36:00+03	26000.00
7D0EFF	2017-08-02 21:46:00+03	53600.00
7D0F6C	2017-07-10 16:38:00+03	21200.00
7D0FC3	2017-07-02 06:21:00+03	12100.00
7D0FD8	2017-08-13 06:16:00+03	54400.00
7D0FFB	2017-08-10 16:33:00+03	534500.00
7D101A	2017-08-01 19:31:00+03	31600.00
7D1065	2017-07-27 22:19:00+03	16400.00
7D10D3	2017-07-29 13:59:00+03	26800.00
7D10EA	2017-07-15 00:27:00+03	12600.00
7D110A	2017-07-25 19:22:00+03	516800.00
7D1153	2017-07-06 02:50:00+03	50600.00
7D11A1	2017-07-17 11:05:00+03	135600.00
7D11CE	2017-08-11 22:20:00+03	77600.00
7D12D0	2017-07-10 23:32:00+03	17000.00
7D139F	2017-07-15 17:59:00+03	56000.00
7D1409	2017-08-11 22:47:00+03	67700.00
7D1419	2017-08-14 12:41:00+03	188000.00
7D141B	2017-08-05 14:06:00+03	59300.00
7D142D	2017-07-26 09:22:00+03	81900.00
7D1457	2017-07-05 02:57:00+03	29600.00
7D14C4	2017-07-31 03:25:00+03	29600.00
7D154A	2017-08-06 01:53:00+03	68400.00
7D158F	2017-07-29 00:32:00+03	123000.00
7D15EB	2017-07-04 02:30:00+03	92800.00
7D1604	2017-08-02 14:06:00+03	21400.00
7D1617	2017-07-09 20:14:00+03	54000.00
7D1660	2017-08-01 15:07:00+03	92800.00
7D170A	2017-07-21 16:21:00+03	62000.00
7D17B0	2017-07-19 05:19:00+03	28800.00
7D17F9	2017-08-15 03:50:00+03	65600.00
7D1826	2017-07-30 12:37:00+03	135400.00
7D1852	2017-08-10 10:05:00+03	258400.00
7D1880	2017-07-08 01:43:00+03	155600.00
7D18AE	2017-07-29 01:26:00+03	19600.00
7D18AF	2017-07-27 11:17:00+03	166000.00
7D18EB	2017-07-31 19:14:00+03	42800.00
7D1937	2017-07-14 12:05:00+03	32400.00
7D1943	2017-07-20 11:51:00+03	12600.00
7D197F	2017-08-14 10:19:00+03	39100.00
7D19D2	2017-07-28 14:12:00+03	53300.00
7D1A6A	2017-07-21 01:49:00+03	136200.00
7D1A78	2017-07-20 05:28:00+03	24600.00
7D1A93	2017-07-28 21:33:00+03	28000.00
7D1AA3	2017-07-23 18:41:00+03	67100.00
7D1AA9	2017-07-11 21:27:00+03	52900.00
7D1B03	2017-07-24 06:30:00+03	306000.00
7D1B49	2017-08-09 17:48:00+03	24400.00
7D1B9A	2017-08-03 00:10:00+03	102100.00
7D1BC4	2017-07-04 22:10:00+03	16400.00
7D1BE3	2017-07-10 16:44:00+03	50800.00
7D1C46	2017-08-06 10:00:00+03	217600.00
7D1C72	2017-07-23 11:13:00+03	90800.00
7D1CDE	2017-07-23 07:12:00+03	57800.00
7D1CFA	2017-08-07 04:53:00+03	28000.00
7D1D2B	2017-07-15 07:09:00+03	111600.00
7D1D3C	2017-08-08 05:23:00+03	248300.00
7D1D3D	2017-07-10 20:58:00+03	46400.00
7D1D7A	2017-07-14 08:28:00+03	67800.00
7D1D9A	2017-07-12 21:26:00+03	149300.00
7D1DE4	2017-08-14 12:44:00+03	15900.00
7D1DF4	2017-08-06 03:34:00+03	28000.00
7D1E4C	2017-07-21 02:45:00+03	32800.00
7D1E56	2017-07-06 05:38:00+03	36200.00
7D1E77	2017-08-14 22:38:00+03	28000.00
7D1ED1	2017-07-07 09:57:00+03	24000.00
7D1F78	2017-08-04 02:47:00+03	20200.00
7D2018	2017-07-26 05:55:00+03	213800.00
7D20D8	2017-07-17 04:53:00+03	29600.00
7D20E7	2017-07-07 14:02:00+03	123000.00
7D2105	2017-08-05 04:09:00+03	56000.00
7D210E	2017-07-28 13:51:00+03	23200.00
7D218B	2017-07-24 05:13:00+03	36600.00
7D21E3	2017-08-06 06:50:00+03	133200.00
7D221F	2017-08-14 07:46:00+03	114700.00
7D222F	2017-07-06 11:50:00+03	88600.00
7D2239	2017-07-15 21:04:00+03	76700.00
7D2270	2017-07-12 01:08:00+03	87000.00
7D22C3	2017-07-29 19:31:00+03	91600.00
7D2310	2017-07-14 03:36:00+03	28800.00
7D2315	2017-08-10 21:35:00+03	26100.00
7D2343	2017-07-14 02:57:00+03	119600.00
7D238D	2017-07-13 09:26:00+03	19600.00
7D2428	2017-07-09 07:20:00+03	21400.00
7D242F	2017-07-07 13:30:00+03	54400.00
7D243F	2017-07-08 04:37:00+03	14000.00
7D2446	2017-08-14 22:03:00+03	115700.00
7D244B	2017-08-14 11:45:00+03	59800.00
7D2492	2017-07-17 05:31:00+03	46400.00
7D2494	2017-07-19 23:40:00+03	123900.00
7D24A6	2017-08-15 17:41:00+03	13200.00
7D2559	2017-07-16 02:21:00+03	21400.00
7D2560	2017-07-30 13:43:00+03	102300.00
7D2595	2017-08-14 19:52:00+03	194200.00
7D25CA	2017-08-13 14:49:00+03	46200.00
7D25CD	2017-07-06 09:31:00+03	13700.00
7D262A	2017-07-05 07:01:00+03	53100.00
7D2703	2017-07-12 08:18:00+03	51500.00
7D2750	2017-07-20 17:13:00+03	92800.00
7D2783	2017-08-03 04:06:00+03	40800.00
7D2787	2017-07-03 03:03:00+03	38800.00
7D2794	2017-08-04 01:20:00+03	244100.00
7D279B	2017-07-06 11:47:00+03	26000.00
7D27A7	2017-07-18 11:35:00+03	167400.00
7D2881	2017-07-12 15:31:00+03	25900.00
7D2894	2017-08-13 22:20:00+03	42800.00
7D28D0	2017-08-14 21:23:00+03	6700.00
7D28FE	2017-07-08 03:45:00+03	99200.00
7D294C	2017-07-24 05:51:00+03	14400.00
7D2963	2017-07-04 12:30:00+03	43200.00
7D296B	2017-07-26 12:49:00+03	99300.00
7D2972	2017-08-12 08:44:00+03	24400.00
7D2984	2017-07-29 20:05:00+03	338200.00
7D29A5	2017-07-17 02:51:00+03	31400.00
7D29C1	2017-06-30 08:27:00+03	39200.00
7D2A2B	2017-07-29 17:30:00+03	12200.00
7D2A48	2017-08-07 17:44:00+03	52900.00
7D2A79	2017-08-01 20:16:00+03	59400.00
7D2A8E	2017-07-06 05:35:00+03	175000.00
7D2AA1	2017-08-08 23:38:00+03	248300.00
7D2B14	2017-08-14 13:34:00+03	147700.00
7D2B1D	2017-07-23 05:33:00+03	52700.00
7D2B4C	2017-07-07 06:01:00+03	117200.00
7D2B68	2017-07-07 09:23:00+03	50000.00
7D2B8D	2017-07-19 04:22:00+03	56000.00
7D2BB5	2017-07-17 05:32:00+03	81200.00
7D2BC3	2017-07-14 22:57:00+03	283100.00
7D2BE0	2017-07-08 17:24:00+03	37700.00
7D2BFE	2017-07-08 15:07:00+03	136200.00
7D2C4A	2017-07-28 02:52:00+03	246000.00
7D2C4D	2017-07-10 07:21:00+03	28000.00
7D2C6E	2017-07-13 15:13:00+03	95200.00
7D2CD6	2017-08-03 23:35:00+03	56200.00
7D2CFA	2017-07-21 06:58:00+03	72800.00
7D2D25	2017-07-03 19:32:00+03	37000.00
7D2D38	2017-07-05 04:06:00+03	22000.00
7D2D4D	2017-08-13 03:05:00+03	265600.00
7D2DD4	2017-08-15 17:35:00+03	14000.00
7D2DDF	2017-07-28 17:18:00+03	166100.00
7D2DF0	2017-08-11 14:54:00+03	62900.00
7D2DF7	2017-07-28 07:07:00+03	111600.00
7D2E00	2017-07-18 16:26:00+03	48400.00
7D2E29	2017-08-06 00:12:00+03	18600.00
7D2E42	2017-07-22 21:26:00+03	85000.00
7D2E58	2017-08-13 11:53:00+03	64700.00
7D2E92	2017-07-16 15:12:00+03	410200.00
7D2EA7	2017-07-26 03:54:00+03	13400.00
7D2EEC	2017-07-23 23:17:00+03	31000.00
7D2F36	2017-07-18 03:11:00+03	202100.00
7D2F45	2017-07-06 13:14:00+03	125400.00
7D2F7D	2017-07-07 21:10:00+03	44000.00
7D2FB7	2017-07-19 06:26:00+03	73600.00
7D3020	2017-08-07 12:49:00+03	6800.00
7D3033	2017-07-29 15:57:00+03	28000.00
7D3034	2017-07-13 06:45:00+03	136200.00
7D30D7	2017-07-24 03:16:00+03	28000.00
7D30DC	2017-07-01 20:43:00+03	24400.00
7D30F9	2017-07-02 08:37:00+03	83000.00
7D30FD	2017-07-20 16:57:00+03	14000.00
7D315E	2017-07-04 11:51:00+03	97900.00
7D3190	2017-08-02 22:02:00+03	6000.00
7D31E5	2017-07-20 17:38:00+03	155600.00
7D3251	2017-07-23 14:16:00+03	386300.00
7D3264	2017-07-11 23:56:00+03	111600.00
7D326A	2017-07-17 14:44:00+03	101000.00
7D32A0	2017-07-13 08:15:00+03	35600.00
7D32C8	2017-08-15 01:36:00+03	37900.00
7D32F3	2017-08-06 17:19:00+03	44100.00
7D3326	2017-08-07 14:42:00+03	12400.00
7D3335	2017-08-01 02:55:00+03	22400.00
7D3359	2017-07-24 09:34:00+03	57400.00
7D3390	2017-08-04 15:50:00+03	133100.00
7D3467	2017-08-14 14:11:00+03	50600.00
7D349C	2017-07-03 11:29:00+03	136000.00
7D3577	2017-08-08 23:17:00+03	84600.00
7D3622	2017-07-06 06:49:00+03	75300.00
7D362D	2017-07-08 04:49:00+03	7400.00
7D3637	2017-08-14 20:19:00+03	14000.00
7D3664	2017-07-30 11:54:00+03	22600.00
7D3666	2017-07-25 09:09:00+03	170800.00
7D36A3	2017-07-16 07:44:00+03	81900.00
7D36BC	2017-07-21 19:05:00+03	28000.00
7D3747	2017-08-13 10:08:00+03	39600.00
7D37D7	2017-07-07 17:11:00+03	67000.00
7D37D9	2017-07-05 02:14:00+03	23400.00
7D3820	2017-08-07 17:04:00+03	48300.00
7D3844	2017-07-27 02:19:00+03	17000.00
7D38D0	2017-07-19 21:22:00+03	62600.00
7D38D3	2017-07-18 10:29:00+03	56000.00
7D38E5	2017-08-04 13:33:00+03	29600.00
7D390B	2017-07-01 18:27:00+03	62100.00
7D3955	2017-08-02 17:37:00+03	67400.00
7D3B68	2017-07-05 00:38:00+03	83300.00
7D3BA7	2017-07-12 12:28:00+03	84100.00
7D3BD9	2017-08-01 00:23:00+03	201800.00
7D3BDA	2017-07-21 16:11:00+03	58200.00
7D3BEF	2017-07-20 12:08:00+03	199700.00
7D3BF3	2017-07-24 14:50:00+03	46200.00
7D3C41	2017-07-18 10:12:00+03	41500.00
7D3CD7	2017-08-08 05:13:00+03	28800.00
7D3CE2	2017-07-18 23:54:00+03	23200.00
7D3D3E	2017-07-14 23:47:00+03	23200.00
7D3D56	2017-08-06 14:35:00+03	74900.00
7D3DA9	2017-07-08 16:01:00+03	15900.00
7D3DF7	2017-07-29 15:08:00+03	47100.00
7D3E68	2017-07-08 00:37:00+03	25600.00
7D3E83	2017-07-20 01:18:00+03	143600.00
7D3ED7	2017-07-09 05:24:00+03	29600.00
7D3EEB	2017-07-12 18:29:00+03	32700.00
7D3F13	2017-07-04 06:24:00+03	71800.00
7D3F7E	2017-07-14 21:47:00+03	295400.00
7D3FA5	2017-08-02 10:17:00+03	8400.00
7D3FAC	2017-07-09 19:51:00+03	83900.00
7D3FC8	2017-08-08 09:02:00+03	29600.00
7D3FD3	2017-07-30 00:58:00+03	75500.00
7D3FD7	2017-07-03 14:25:00+03	196000.00
7D4035	2017-07-22 18:00:00+03	34100.00
7D407E	2017-07-15 12:42:00+03	67200.00
7D40EB	2017-07-14 18:05:00+03	93900.00
7D4132	2017-08-15 03:17:00+03	85000.00
7D41AB	2017-07-17 23:11:00+03	43600.00
7D41BF	2017-07-16 13:24:00+03	27300.00
7D421D	2017-07-04 01:06:00+03	37200.00
7D4229	2017-07-10 13:42:00+03	85000.00
7D424D	2017-08-10 19:53:00+03	61800.00
7D42A3	2017-08-03 13:24:00+03	61800.00
7D42CD	2017-07-23 18:25:00+03	13300.00
7D431E	2017-07-22 02:16:00+03	20000.00
7D432D	2017-06-29 04:07:00+03	130200.00
7D4360	2017-07-28 07:51:00+03	68100.00
7D4386	2017-07-13 22:15:00+03	37100.00
7D43AA	2017-08-15 17:36:00+03	58900.00
7D4415	2017-07-13 11:56:00+03	26000.00
7D4452	2017-08-06 01:26:00+03	21800.00
7D44C6	2017-07-18 18:53:00+03	115400.00
7D45AD	2017-08-08 12:07:00+03	50600.00
7D45F7	2017-07-14 21:44:00+03	200500.00
7D4622	2017-07-22 12:29:00+03	138000.00
7D4671	2017-07-13 14:56:00+03	162700.00
7D46A9	2017-07-31 19:46:00+03	26000.00
7D46AB	2017-06-30 03:28:00+03	187400.00
7D46B9	2017-07-20 00:12:00+03	92800.00
7D46E3	2017-08-09 06:31:00+03	148200.00
7D46F6	2017-07-26 16:27:00+03	21800.00
7D470E	2017-08-14 07:17:00+03	7400.00
7D4783	2017-08-08 08:21:00+03	13700.00
7D47B6	2017-07-28 22:44:00+03	85600.00
7D47E2	2017-07-06 12:43:00+03	55800.00
7D47E7	2017-08-15 09:53:00+03	38600.00
7D47F5	2017-07-14 23:42:00+03	73600.00
7D4804	2017-07-31 16:05:00+03	22100.00
7D483A	2017-08-13 22:05:00+03	24400.00
7D49A6	2017-07-06 17:34:00+03	42800.00
7D49BE	2017-07-17 19:55:00+03	270800.00
7D49D9	2017-07-18 19:06:00+03	7200.00
7D49F4	2017-07-31 08:15:00+03	103100.00
7D49F9	2017-07-20 22:02:00+03	71100.00
7D49FF	2017-07-16 07:41:00+03	61800.00
7D4B2E	2017-07-19 20:56:00+03	48800.00
7D4C17	2017-07-23 15:31:00+03	66200.00
7D4C28	2017-08-09 20:37:00+03	35600.00
7D4C3C	2017-07-04 01:43:00+03	81700.00
7D4C3F	2017-08-08 13:56:00+03	54800.00
7D4C58	2017-07-11 11:30:00+03	40800.00
7D4C8C	2017-08-10 03:32:00+03	112000.00
7D4C9D	2017-07-22 20:37:00+03	28000.00
7D4CF9	2017-07-03 14:58:00+03	136200.00
7D4DC2	2017-07-19 16:24:00+03	26000.00
7D4E31	2017-07-18 14:36:00+03	28000.00
7D4E34	2017-07-27 08:25:00+03	40600.00
7D4E38	2017-08-13 21:56:00+03	23200.00
7D4E54	2017-07-10 07:38:00+03	28000.00
7D4E59	2017-08-11 05:37:00+03	52400.00
7D4F82	2017-08-06 01:24:00+03	90400.00
7D4F8D	2017-08-11 04:02:00+03	437700.00
7D4F94	2017-07-11 19:47:00+03	45200.00
7D4FA9	2017-08-12 11:30:00+03	326200.00
7D4FC9	2017-08-06 07:17:00+03	92400.00
7D508C	2017-07-13 10:23:00+03	28000.00
7D50AA	2017-07-26 03:57:00+03	23200.00
7D50F6	2017-06-29 09:42:00+03	67600.00
7D512E	2017-08-04 11:58:00+03	39400.00
7D5174	2017-07-21 17:55:00+03	167400.00
7D517B	2017-07-19 06:55:00+03	54800.00
7D51E4	2017-08-15 12:35:00+03	83600.00
7D5221	2017-07-27 18:26:00+03	70800.00
7D52C7	2017-07-10 08:46:00+03	214300.00
7D531C	2017-08-11 15:31:00+03	46400.00
7D5389	2017-08-06 10:34:00+03	28800.00
7D53F1	2017-07-04 14:42:00+03	134400.00
7D5432	2017-07-17 10:33:00+03	147700.00
7D54B3	2017-07-21 16:00:00+03	98200.00
7D54E1	2017-07-16 19:49:00+03	26000.00
7D556C	2017-07-20 03:57:00+03	42000.00
7D55E9	2017-07-10 03:36:00+03	13400.00
7D5615	2017-07-12 01:46:00+03	14000.00
7D5626	2017-07-19 05:26:00+03	26000.00
7D563E	2017-08-14 08:23:00+03	6300.00
7D5645	2017-08-09 05:08:00+03	33600.00
7D5691	2017-07-31 21:04:00+03	47400.00
7D5693	2017-08-08 14:38:00+03	48400.00
7D569D	2017-07-02 03:13:00+03	29400.00
7D56C2	2017-07-07 05:09:00+03	56900.00
7D56ED	2017-07-24 09:37:00+03	23400.00
7D5714	2017-07-13 15:25:00+03	78600.00
7D5755	2017-07-15 17:38:00+03	16400.00
7D579C	2017-07-22 23:30:00+03	6700.00
7D57EF	2017-07-09 23:15:00+03	101900.00
7D581E	2017-07-09 13:21:00+03	6700.00
7D58BA	2017-07-04 02:45:00+03	55000.00
7D58CF	2017-08-03 05:23:00+03	20200.00
7D5901	2017-07-07 13:16:00+03	75300.00
7D5993	2017-07-05 06:38:00+03	26000.00
7D59CC	2017-07-14 16:22:00+03	101800.00
7D59D1	2017-06-30 20:48:00+03	18800.00
7D5A0F	2017-07-11 07:33:00+03	13600.00
7D5AC6	2017-08-14 22:45:00+03	9200.00
7D5AFC	2017-07-04 00:12:00+03	116000.00
7D5B2D	2017-06-26 22:49:00+03	32400.00
7D5B4B	2017-07-30 17:53:00+03	22200.00
7D5B86	2017-07-14 10:06:00+03	205600.00
7D5BB9	2017-07-14 15:19:00+03	25100.00
7D5BC5	2017-08-04 20:26:00+03	23200.00
7D5C66	2017-07-06 03:09:00+03	24400.00
7D5CF2	2017-08-07 08:40:00+03	35800.00
7D5D2B	2017-07-27 04:02:00+03	6700.00
7D5D3B	2017-07-07 10:48:00+03	28000.00
7D5D49	2017-08-13 16:36:00+03	211600.00
7D5D52	2017-07-20 04:35:00+03	6000.00
7D5D96	2017-07-28 06:25:00+03	56100.00
7D5D9D	2017-07-28 04:34:00+03	240600.00
7D5DC9	2017-07-18 12:38:00+03	67200.00
7D5DDE	2017-07-26 13:47:00+03	146400.00
7D5EC0	2017-07-20 08:07:00+03	119700.00
7D5F07	2017-06-29 11:27:00+03	290200.00
7D5F10	2017-08-10 11:49:00+03	177600.00
7D5F45	2017-07-29 13:02:00+03	55800.00
7D5F54	2017-07-28 06:16:00+03	13000.00
7D5FF9	2017-08-02 07:12:00+03	70500.00
7D602C	2017-07-05 00:52:00+03	194300.00
7D613C	2017-08-14 06:16:00+03	6700.00
7D6153	2017-07-26 18:47:00+03	61500.00
7D61AF	2017-08-14 05:32:00+03	25600.00
7D6216	2017-07-21 06:52:00+03	155600.00
7D6247	2017-07-05 19:48:00+03	58800.00
7D626A	2017-07-14 01:08:00+03	92800.00
7D62CE	2017-08-09 20:18:00+03	48500.00
7D62D2	2017-07-14 09:07:00+03	58200.00
7D62E0	2017-07-23 15:13:00+03	99300.00
7D6319	2017-08-14 06:14:00+03	265800.00
7D63B3	2017-07-14 03:56:00+03	625400.00
7D63EF	2017-07-07 22:34:00+03	81300.00
7D64F0	2017-08-13 18:39:00+03	62600.00
7D6549	2017-07-08 13:41:00+03	49800.00
7D6584	2017-08-13 23:08:00+03	50100.00
7D6595	2017-08-13 19:10:00+03	21400.00
7D65D3	2017-07-21 21:25:00+03	241300.00
7D6679	2017-07-22 10:28:00+03	166900.00
7D66CC	2017-08-14 11:24:00+03	34600.00
7D6732	2017-07-24 21:41:00+03	27500.00
7D6759	2017-07-28 17:24:00+03	124300.00
7D6764	2017-07-13 11:04:00+03	119500.00
7D67D2	2017-07-14 02:56:00+03	44600.00
7D6800	2017-07-11 09:22:00+03	133900.00
7D6840	2017-08-01 12:01:00+03	81600.00
7D68AE	2017-07-31 15:43:00+03	23200.00
7D6971	2017-07-26 21:22:00+03	90600.00
7D69BA	2017-07-11 13:44:00+03	50600.00
7D69DE	2017-07-31 07:20:00+03	25200.00
7D6A60	2017-07-14 09:17:00+03	67100.00
7D6ABA	2017-07-04 18:04:00+03	28000.00
7D6B1A	2017-07-31 04:08:00+03	119800.00
7D6B6A	2017-08-05 10:57:00+03	135600.00
7D6B77	2017-06-29 09:48:00+03	98400.00
7D6BB1	2017-07-24 08:34:00+03	52000.00
7D6BC9	2017-07-19 03:53:00+03	12400.00
7D6BD9	2017-07-11 12:36:00+03	72400.00
7D6C41	2017-07-19 10:26:00+03	59100.00
7D6CC4	2017-07-02 00:38:00+03	258400.00
7D6D88	2017-07-12 12:10:00+03	36800.00
7D6DAA	2017-07-01 07:42:00+03	24400.00
7D6DC5	2017-07-30 19:24:00+03	89000.00
7D6DCA	2017-08-13 12:23:00+03	254900.00
7D6DCB	2017-07-13 12:43:00+03	122100.00
7D6DD7	2017-07-19 11:38:00+03	56600.00
7D6DF2	2017-07-27 06:57:00+03	73300.00
7D6E17	2017-07-25 05:14:00+03	32800.00
7D6E2B	2017-07-07 11:36:00+03	468200.00
7D6E83	2017-08-04 09:36:00+03	36200.00
7D6E85	2017-08-10 18:38:00+03	19600.00
7D6ED3	2017-07-18 07:58:00+03	35800.00
7D6EF5	2017-07-17 09:50:00+03	49800.00
7D6F01	2017-08-10 14:53:00+03	24800.00
7D7036	2017-07-09 11:36:00+03	156500.00
7D7079	2017-08-11 15:12:00+03	20200.00
7D70C0	2017-07-16 14:10:00+03	31600.00
7D70F7	2017-07-14 01:37:00+03	16400.00
7D7155	2017-08-10 16:15:00+03	118100.00
7D715E	2017-07-26 22:53:00+03	102800.00
7D7166	2017-07-07 17:02:00+03	21200.00
7D71BB	2017-07-29 10:40:00+03	38200.00
7D71F6	2017-08-14 22:58:00+03	22000.00
7D7253	2017-08-04 06:10:00+03	23600.00
7D736F	2017-07-05 02:56:00+03	391300.00
7D743A	2017-08-04 18:27:00+03	129200.00
7D7451	2017-08-13 17:28:00+03	187600.00
7D7456	2017-07-02 23:06:00+03	134400.00
7D7465	2017-08-08 03:42:00+03	85000.00
7D74A2	2017-08-07 23:01:00+03	406700.00
7D74D5	2017-06-30 23:02:00+03	47000.00
7D7517	2017-08-01 08:25:00+03	28000.00
7D753A	2017-08-06 21:10:00+03	43400.00
7D756C	2017-08-05 19:59:00+03	27400.00
7D7570	2017-07-26 07:17:00+03	54300.00
7D7580	2017-07-22 20:33:00+03	386300.00
7D7609	2017-07-28 07:58:00+03	92400.00
7D7633	2017-07-10 04:27:00+03	27800.00
7D7641	2017-08-15 05:05:00+03	49200.00
7D768A	2017-07-26 13:43:00+03	46000.00
7D768E	2017-07-01 14:16:00+03	92900.00
7D769B	2017-07-15 03:56:00+03	73600.00
7D76F1	2017-07-09 13:01:00+03	54000.00
7D771D	2017-07-31 13:22:00+03	64800.00
7D7742	2017-08-04 06:30:00+03	28800.00
7D7758	2017-07-05 04:18:00+03	39600.00
7D777E	2017-07-16 00:44:00+03	64700.00
7D778D	2017-07-25 05:48:00+03	20200.00
7D77B3	2017-07-06 21:32:00+03	137600.00
7D77C7	2017-08-09 20:14:00+03	8400.00
7D77D8	2017-08-09 18:09:00+03	113800.00
7D77EF	2017-08-15 14:06:00+03	28800.00
7D78B8	2017-07-25 11:51:00+03	21200.00
7D796F	2017-07-04 18:50:00+03	128700.00
7D7978	2017-07-22 07:13:00+03	336800.00
7D79C3	2017-07-08 22:12:00+03	24600.00
7D79EA	2017-07-05 12:28:00+03	82200.00
7D79ED	2017-07-05 23:46:00+03	29400.00
7D79F3	2017-08-08 07:01:00+03	257500.00
7D7A70	2017-07-06 06:49:00+03	28000.00
7D7AA7	2017-07-12 06:48:00+03	10800.00
7D7AAB	2017-08-04 12:14:00+03	24800.00
7D7AE3	2017-08-07 22:45:00+03	28000.00
7D7AE4	2017-08-02 05:10:00+03	83600.00
7D7B23	2017-07-02 04:37:00+03	49100.00
7D7B70	2017-07-11 11:40:00+03	92800.00
7D7BD3	2017-07-09 12:59:00+03	29600.00
7D7BDD	2017-07-05 15:14:00+03	90400.00
7D7BEA	2017-07-05 06:27:00+03	42800.00
7D7C0C	2017-07-06 18:07:00+03	36200.00
7D7C46	2017-08-07 04:55:00+03	78400.00
7D7C56	2017-07-23 02:56:00+03	57600.00
7D7C68	2017-07-11 05:38:00+03	249600.00
7D7D06	2017-07-04 12:26:00+03	33600.00
7D7D3F	2017-08-05 19:05:00+03	35600.00
7D7D45	2017-07-06 08:36:00+03	113600.00
7D7D46	2017-08-10 05:32:00+03	33100.00
7D7D62	2017-07-11 12:23:00+03	28800.00
7D7DE0	2017-07-29 22:49:00+03	19800.00
7D7DE6	2017-08-04 18:39:00+03	6000.00
7D7DF5	2017-07-05 03:41:00+03	30900.00
7D7EAB	2017-07-12 06:31:00+03	21800.00
7D7ED8	2017-07-17 13:23:00+03	49600.00
7D7F3B	2017-07-21 07:50:00+03	26000.00
7D7F46	2017-07-30 16:39:00+03	92800.00
7D7FBB	2017-07-21 22:55:00+03	55900.00
7D7FC8	2017-07-10 07:31:00+03	8200.00
7D7FE6	2017-08-04 00:41:00+03	202100.00
7D800A	2017-07-21 22:22:00+03	47100.00
7D803B	2017-07-14 04:40:00+03	166100.00
7D803D	2017-08-10 08:40:00+03	56000.00
7D8093	2017-07-03 08:23:00+03	43500.00
7D80A2	2017-08-04 13:48:00+03	201300.00
7D80D0	2017-07-23 12:16:00+03	49000.00
7D8116	2017-07-10 10:22:00+03	153300.00
7D813F	2017-07-15 22:35:00+03	70800.00
7D8147	2017-08-03 15:14:00+03	23600.00
7D817B	2017-08-08 21:42:00+03	67200.00
7D8189	2017-08-06 21:36:00+03	6800.00
7D81C8	2017-07-22 19:37:00+03	108600.00
7D8204	2017-07-07 13:59:00+03	51900.00
7D820D	2017-08-14 21:50:00+03	369000.00
7D8216	2017-07-08 11:04:00+03	167400.00
7D82B0	2017-07-25 05:02:00+03	67600.00
7D82F0	2017-08-04 01:38:00+03	57800.00
7D8303	2017-07-13 18:35:00+03	123000.00
7D8346	2017-07-29 07:07:00+03	111600.00
7D8362	2017-08-03 04:58:00+03	123000.00
7D84DE	2017-07-15 18:39:00+03	83600.00
7D8589	2017-08-11 02:02:00+03	56000.00
7D8595	2017-08-02 09:55:00+03	26000.00
7D859C	2017-07-05 06:36:00+03	6300.00
7D85DE	2017-06-30 19:22:00+03	102100.00
7D85F9	2017-07-21 23:10:00+03	122300.00
7D868D	2017-07-09 12:49:00+03	67600.00
7D86ED	2017-07-23 07:35:00+03	36200.00
7D86F0	2017-07-23 21:40:00+03	27300.00
7D86F1	2017-07-01 13:12:00+03	131600.00
7D8731	2017-08-10 03:32:00+03	186300.00
7D8759	2017-07-10 18:55:00+03	45100.00
7D8807	2017-07-16 03:39:00+03	117200.00
7D881E	2017-08-06 12:05:00+03	22000.00
7D883A	2017-07-31 18:59:00+03	16400.00
7D8863	2017-08-07 00:16:00+03	111600.00
7D88AE	2017-08-11 00:16:00+03	96300.00
7D88EB	2017-08-03 02:33:00+03	130300.00
7D8909	2017-08-10 00:17:00+03	26700.00
7D89B1	2017-08-03 05:07:00+03	37200.00
7D89D7	2017-07-13 01:33:00+03	67600.00
7D89E5	2017-07-27 10:58:00+03	34600.00
7D89FA	2017-08-06 23:32:00+03	112300.00
7D8A37	2017-07-08 02:42:00+03	56200.00
7D8A4E	2017-07-13 07:22:00+03	32800.00
7D8A60	2017-07-28 20:06:00+03	151200.00
7D8B4A	2017-08-09 05:02:00+03	133200.00
7D8B5F	2017-08-09 02:11:00+03	64800.00
7D8B6E	2017-07-14 08:36:00+03	58400.00
7D8B9A	2017-07-07 09:04:00+03	120400.00
7D8BB7	2017-08-13 12:39:00+03	8400.00
7D8BEC	2017-07-20 11:59:00+03	48800.00
7D8C1A	2017-08-12 07:11:00+03	29600.00
7D8C70	2017-07-13 23:07:00+03	270800.00
7D8C72	2017-07-27 18:59:00+03	54800.00
7D8CBB	2017-07-06 02:48:00+03	18500.00
7D8CDC	2017-08-12 22:20:00+03	109600.00
7D8CF1	2017-07-09 15:50:00+03	153200.00
7D8D0F	2017-07-16 21:04:00+03	67400.00
7D8D96	2017-07-12 23:05:00+03	86600.00
7D8E3E	2017-08-04 18:03:00+03	12400.00
7D8E47	2017-07-03 12:17:00+03	75300.00
7D8E88	2017-07-31 10:29:00+03	181600.00
7D8E93	2017-08-13 14:12:00+03	102100.00
7D8EB0	2017-08-03 20:22:00+03	135400.00
7D8EF5	2017-08-11 04:46:00+03	46200.00
7D8F12	2017-07-26 16:45:00+03	42800.00
7D8F77	2017-08-06 10:20:00+03	43600.00
7D8F7B	2017-08-08 05:54:00+03	26000.00
7D9060	2017-08-14 23:49:00+03	53500.00
7D9084	2017-07-11 15:00:00+03	26000.00
7D9097	2017-07-05 14:24:00+03	61800.00
7D90D7	2017-07-10 13:28:00+03	143200.00
7D9174	2017-06-29 00:04:00+03	64400.00
7D9179	2017-07-08 10:54:00+03	31400.00
7D91BC	2017-07-13 00:53:00+03	99700.00
7D91D9	2017-07-08 06:07:00+03	112000.00
7D91E1	2017-07-16 17:35:00+03	56100.00
7D9245	2017-08-12 21:11:00+03	31500.00
7D92F3	2017-07-06 04:17:00+03	32800.00
7D9305	2017-08-10 06:32:00+03	27400.00
7D933F	2017-08-13 22:13:00+03	12000.00
7D93E5	2017-08-07 02:48:00+03	68800.00
7D93E7	2017-07-25 23:32:00+03	28000.00
7D9401	2017-06-28 21:25:00+03	134600.00
7D9405	2017-07-02 12:44:00+03	112000.00
7D945B	2017-08-12 14:55:00+03	23600.00
7D94B2	2017-08-11 16:54:00+03	119000.00
7D94B4	2017-08-15 05:21:00+03	34600.00
7D94BF	2017-07-09 07:42:00+03	12200.00
7D94DE	2017-08-01 14:59:00+03	51900.00
7D9522	2017-08-15 17:20:00+03	36600.00
7D95A5	2017-07-15 19:48:00+03	32800.00
7D95B5	2017-07-25 19:42:00+03	265700.00
7D95BC	2017-06-29 18:52:00+03	22600.00
7D9620	2017-08-05 02:51:00+03	93900.00
7D9692	2017-07-17 08:57:00+03	48800.00
7D96E7	2017-07-06 10:30:00+03	47100.00
7D96F6	2017-07-08 21:34:00+03	125200.00
7D9731	2017-07-07 12:49:00+03	27200.00
7D97AA	2017-08-04 23:41:00+03	24800.00
7D97FA	2017-07-27 14:47:00+03	61800.00
7D983D	2017-07-31 13:59:00+03	15000.00
7D9870	2017-08-11 20:33:00+03	62400.00
7D98EE	2017-08-10 22:00:00+03	13200.00
7D991E	2017-08-06 02:10:00+03	40800.00
7D9922	2017-08-02 05:04:00+03	56000.00
7D9939	2017-06-26 03:47:00+03	136800.00
7D9998	2017-07-08 10:59:00+03	19200.00
7D99AC	2017-07-23 22:28:00+03	42600.00
7D99BC	2017-08-03 18:56:00+03	40800.00
7D99E8	2017-07-25 02:03:00+03	25100.00
7D99F5	2017-08-10 12:06:00+03	99200.00
7D9A12	2017-06-30 18:23:00+03	79800.00
7D9A4D	2017-08-14 01:41:00+03	42600.00
7D9AA3	2017-07-05 18:44:00+03	37900.00
7D9ACE	2017-07-15 06:04:00+03	28800.00
7D9B55	2017-07-07 19:25:00+03	21400.00
7D9B75	2017-07-30 16:00:00+03	44000.00
7D9BA0	2017-07-18 15:00:00+03	125200.00
7D9C10	2017-07-11 17:22:00+03	67800.00
7D9C5A	2017-07-03 07:16:00+03	67200.00
7D9CD6	2017-07-13 09:39:00+03	47000.00
7D9CDB	2017-07-04 03:25:00+03	35200.00
7D9D0E	2017-07-16 09:33:00+03	24400.00
7D9D74	2017-07-21 19:34:00+03	28800.00
7D9DA4	2017-08-09 07:01:00+03	85000.00
7D9DAF	2017-08-14 04:34:00+03	182500.00
7D9DD9	2017-07-14 16:54:00+03	271100.00
7D9DE7	2017-08-12 00:30:00+03	31400.00
7D9E7F	2017-07-04 11:50:00+03	170800.00
7D9E87	2017-08-14 19:08:00+03	15500.00
7D9EC1	2017-06-30 22:17:00+03	24800.00
7D9F38	2017-07-02 00:36:00+03	46400.00
7D9F78	2017-08-05 00:21:00+03	21800.00
7D9F9B	2017-07-19 16:35:00+03	26700.00
7D9FAE	2017-07-22 13:36:00+03	23600.00
7D9FC7	2017-07-12 00:43:00+03	67200.00
7DA018	2017-07-15 06:19:00+03	58600.00
7DA050	2017-07-28 09:54:00+03	37600.00
7DA061	2017-07-24 07:07:00+03	85400.00
7DA078	2017-08-06 17:40:00+03	159800.00
7DA07A	2017-07-23 23:49:00+03	64800.00
7DA089	2017-07-27 17:14:00+03	38600.00
7DA08A	2017-07-24 13:53:00+03	36900.00
7DA090	2017-07-28 18:23:00+03	68400.00
7DA097	2017-07-04 03:42:00+03	24400.00
7DA0A0	2017-08-03 04:23:00+03	32400.00
7DA0C0	2017-07-02 19:50:00+03	66000.00
7DA240	2017-07-20 01:05:00+03	92000.00
7DA27C	2017-07-27 09:49:00+03	46300.00
7DA2E6	2017-07-20 10:38:00+03	67200.00
7DA2F6	2017-07-20 10:43:00+03	73200.00
7DA318	2017-07-05 14:04:00+03	23600.00
7DA321	2017-07-28 07:19:00+03	95200.00
7DA32B	2017-07-27 21:47:00+03	179400.00
7DA3B8	2017-07-15 15:56:00+03	56000.00
7DA3E2	2017-07-19 14:54:00+03	9300.00
7DA47D	2017-07-06 18:19:00+03	174300.00
7DA4FE	2017-07-22 08:41:00+03	64600.00
7DA520	2017-08-05 06:11:00+03	17200.00
7DA559	2017-08-14 10:32:00+03	45100.00
7DA57A	2017-07-23 02:37:00+03	9800.00
7DA596	2017-08-01 07:36:00+03	120600.00
7DA5A6	2017-07-24 09:05:00+03	46000.00
7DA5FE	2017-08-01 05:12:00+03	50800.00
7DA63E	2017-08-15 04:26:00+03	31400.00
7DA664	2017-07-03 14:27:00+03	59000.00
7DA6CA	2017-08-05 23:24:00+03	47500.00
7DA768	2017-07-14 04:21:00+03	205000.00
7DA799	2017-07-18 15:09:00+03	36200.00
7DA7B4	2017-08-13 21:00:00+03	138300.00
7DA7B7	2017-08-04 09:36:00+03	47200.00
7DA7C8	2017-07-10 11:24:00+03	59300.00
7DA7DD	2017-08-02 13:42:00+03	25100.00
7DA809	2017-08-14 08:06:00+03	146300.00
7DA80A	2017-07-18 07:42:00+03	27300.00
7DA80E	2017-07-20 18:48:00+03	47200.00
7DA84B	2017-07-06 17:14:00+03	8200.00
7DA968	2017-07-18 14:54:00+03	46000.00
7DA9A2	2017-07-24 02:58:00+03	28000.00
7DAAD2	2017-08-03 06:11:00+03	56000.00
7DAAF7	2017-08-02 12:03:00+03	56000.00
7DAC12	2017-07-01 01:15:00+03	50800.00
7DAC30	2017-07-28 05:06:00+03	103900.00
7DAC46	2017-08-09 00:40:00+03	90500.00
7DAC66	2017-08-06 21:12:00+03	65200.00
7DACAB	2017-07-05 09:51:00+03	246000.00
7DAE1A	2017-07-04 12:56:00+03	55800.00
7DAE1C	2017-07-19 11:02:00+03	31100.00
7DAE46	2017-07-23 13:20:00+03	88600.00
7DAF0C	2017-07-21 14:44:00+03	38800.00
7DAF0E	2017-08-05 14:45:00+03	79600.00
7DAF4E	2017-08-14 19:23:00+03	67600.00
7DAF81	2017-06-30 18:39:00+03	47100.00
7DAFBB	2017-07-06 15:17:00+03	31200.00
7DAFED	2017-07-13 01:18:00+03	203000.00
7DAFF7	2017-08-02 16:44:00+03	38600.00
7DB025	2017-07-27 03:26:00+03	136200.00
7DB051	2017-07-19 08:52:00+03	26000.00
7DB061	2017-08-06 23:05:00+03	12400.00
7DB0BB	2017-08-05 09:36:00+03	27000.00
7DB123	2017-07-06 06:01:00+03	19800.00
7DB170	2017-08-06 00:05:00+03	26000.00
7DB193	2017-07-14 23:11:00+03	75600.00
7DB1AF	2017-07-18 00:30:00+03	26800.00
7DB21A	2017-07-06 04:32:00+03	58700.00
7DB253	2017-07-17 14:28:00+03	134400.00
7DB299	2017-08-02 14:14:00+03	123900.00
7DB2CC	2017-07-04 19:39:00+03	173600.00
7DB2E9	2017-08-06 05:24:00+03	67200.00
7DB2EC	2017-06-25 14:22:00+03	14800.00
7DB300	2017-07-14 15:51:00+03	192600.00
7DB3C6	2017-08-08 22:29:00+03	96200.00
7DB427	2017-07-04 19:55:00+03	32800.00
7DB435	2017-08-01 01:44:00+03	32800.00
7DB4DA	2017-07-11 06:33:00+03	303900.00
7DB4F3	2017-07-25 15:22:00+03	147700.00
7DB4F8	2017-07-05 11:45:00+03	18600.00
7DB501	2017-08-12 10:38:00+03	41600.00
7DB5AD	2017-07-27 16:57:00+03	133200.00
7DB5BB	2017-07-30 04:08:00+03	81600.00
7DB5D1	2017-07-24 23:16:00+03	168700.00
7DB615	2017-07-16 00:08:00+03	90800.00
7DB61D	2017-07-01 20:07:00+03	114800.00
7DB660	2017-07-21 05:06:00+03	38600.00
7DB6A7	2017-06-30 07:30:00+03	101200.00
7DB6D0	2017-07-29 21:35:00+03	144300.00
7DB747	2017-07-27 13:47:00+03	29100.00
7DB786	2017-07-27 20:56:00+03	28800.00
7DB7B2	2017-06-30 12:21:00+03	56000.00
7DB7BB	2017-07-20 12:54:00+03	58800.00
7DB7E6	2017-07-08 07:30:00+03	271400.00
7DB7EE	2017-07-13 09:38:00+03	23600.00
7DB89D	2017-07-31 13:32:00+03	12400.00
7DB8CF	2017-07-28 13:14:00+03	29600.00
7DB902	2017-07-28 03:32:00+03	28000.00
7DB933	2017-07-18 00:24:00+03	23200.00
7DB94B	2017-07-08 21:30:00+03	114800.00
7DB97E	2017-07-07 03:21:00+03	45500.00
7DB9A3	2017-07-14 07:12:00+03	167500.00
7DB9FA	2017-07-14 10:49:00+03	24800.00
7DBA13	2017-07-29 22:17:00+03	46000.00
7DBA29	2017-06-30 14:31:00+03	40000.00
7DBA35	2017-08-03 08:53:00+03	52300.00
7DBA3A	2017-07-30 07:41:00+03	57500.00
7DBA4C	2017-07-19 08:16:00+03	64800.00
7DBA95	2017-07-25 16:07:00+03	21200.00
7DBAA6	2017-08-11 21:02:00+03	55800.00
7DBB01	2017-08-05 23:49:00+03	31600.00
7DBB26	2017-08-03 14:05:00+03	46000.00
7DBB47	2017-07-06 12:56:00+03	100600.00
7DBB5A	2017-08-10 12:45:00+03	66000.00
7DBB67	2017-07-25 11:03:00+03	135400.00
7DBB94	2017-08-14 22:45:00+03	57500.00
7DBBE1	2017-07-28 18:20:00+03	59800.00
7DBC90	2017-07-31 14:00:00+03	57400.00
7DBCB6	2017-08-06 07:12:00+03	406100.00
7DBCD3	2017-07-21 02:13:00+03	14400.00
7DBCD8	2017-07-10 08:31:00+03	94000.00
7DBD01	2017-08-14 07:37:00+03	664500.00
7DBD9A	2017-07-16 05:53:00+03	31600.00
7DBDA7	2017-08-03 07:00:00+03	75200.00
7DBDFC	2017-07-04 19:30:00+03	92400.00
7DBE14	2017-06-28 05:17:00+03	109600.00
7DBE44	2017-08-13 13:49:00+03	34100.00
7DBE4A	2017-07-15 18:51:00+03	38400.00
7DBE7C	2017-07-23 21:20:00+03	120900.00
7DBEA9	2017-07-28 22:56:00+03	43200.00
7DBEDC	2017-07-29 07:05:00+03	131100.00
7DBF34	2017-08-08 03:51:00+03	35500.00
7DBF35	2017-08-05 03:39:00+03	28000.00
7DBFB6	2017-07-19 14:51:00+03	56000.00
7DC010	2017-08-02 03:32:00+03	148800.00
7DC04A	2017-07-23 02:36:00+03	132800.00
7DC0F5	2017-08-14 22:19:00+03	28800.00
7DC117	2017-08-09 07:52:00+03	87300.00
7DC19A	2017-08-10 18:07:00+03	156100.00
7DC1DD	2017-07-07 08:10:00+03	62700.00
7DC1E5	2017-07-02 16:27:00+03	26000.00
7DC204	2017-07-31 23:24:00+03	36800.00
7DC23B	2017-07-21 15:27:00+03	18000.00
7DC270	2017-07-26 05:37:00+03	55800.00
7DC277	2017-08-04 14:14:00+03	16400.00
7DC29C	2017-07-03 21:43:00+03	36200.00
7DC2BE	2017-07-15 13:56:00+03	36200.00
7DC2E6	2017-08-09 21:59:00+03	56000.00
7DC2EB	2017-07-24 02:23:00+03	131000.00
7DC306	2017-07-10 06:45:00+03	43200.00
7DC313	2017-07-05 15:17:00+03	12400.00
7DC38E	2017-07-01 19:57:00+03	46500.00
7DC3AD	2017-08-01 00:19:00+03	265700.00
7DC3DE	2017-07-11 08:07:00+03	57800.00
7DC408	2017-07-18 08:53:00+03	13600.00
7DC438	2017-07-16 22:54:00+03	40800.00
7DC44D	2017-08-06 07:01:00+03	46000.00
7DC4BA	2017-07-30 06:02:00+03	212400.00
7DC4C2	2017-07-19 05:55:00+03	52000.00
7DC4F5	2017-07-15 08:57:00+03	56000.00
7DC584	2017-07-03 17:53:00+03	25200.00
7DC5DB	2017-08-10 21:38:00+03	12700.00
7DC5E1	2017-06-29 17:55:00+03	103800.00
7DC5E8	2017-07-27 20:34:00+03	31600.00
7DC674	2017-07-21 20:27:00+03	46300.00
7DC7C4	2017-07-18 23:50:00+03	24700.00
7DC7F1	2017-08-06 21:56:00+03	43900.00
7DC89F	2017-07-14 13:36:00+03	47200.00
7DC8EA	2017-08-14 14:48:00+03	12400.00
7DC8F0	2017-07-03 05:39:00+03	72400.00
7DC92D	2017-08-03 13:40:00+03	36400.00
7DC935	2017-07-19 12:10:00+03	159100.00
7DC93E	2017-07-26 11:05:00+03	59200.00
7DCA0C	2017-08-10 01:40:00+03	39200.00
7DCA10	2017-08-02 05:52:00+03	6000.00
7DCA59	2017-07-19 11:34:00+03	67200.00
7DCA6C	2017-08-06 15:16:00+03	176900.00
7DCA6E	2017-07-27 13:50:00+03	50800.00
7DCB01	2017-08-09 07:57:00+03	57600.00
7DCB5F	2017-07-30 05:20:00+03	57800.00
7DCBB8	2017-07-13 07:47:00+03	8000.00
7DCC32	2017-07-10 00:16:00+03	355600.00
7DCC4C	2017-07-30 19:57:00+03	32800.00
7DCC61	2017-07-26 20:28:00+03	8000.00
7DCC67	2017-07-27 06:36:00+03	10600.00
7DCCB3	2017-08-10 02:06:00+03	32400.00
7DCCF4	2017-07-01 18:43:00+03	40600.00
7DCCFE	2017-07-09 02:11:00+03	52700.00
7DCD5E	2017-07-30 02:58:00+03	173600.00
7DCDE0	2017-07-11 16:17:00+03	113900.00
7DCDE5	2017-06-28 11:48:00+03	139300.00
7DCE94	2017-07-24 18:53:00+03	64900.00
7DCEEB	2017-08-08 06:52:00+03	56600.00
7DCF40	2017-06-29 19:32:00+03	165400.00
7DCF58	2017-07-31 20:25:00+03	75300.00
7DCF6D	2017-08-02 16:02:00+03	29600.00
7DCF7B	2017-08-01 22:52:00+03	40100.00
7DCFA2	2017-07-01 04:08:00+03	75500.00
7DCFBE	2017-07-19 20:31:00+03	68100.00
7DCFC7	2017-07-31 07:08:00+03	11600.00
7DCFF2	2017-06-30 12:18:00+03	46800.00
7DD0A9	2017-08-12 03:34:00+03	27300.00
7DD0AC	2017-07-01 07:50:00+03	187800.00
7DD0BE	2017-08-04 15:30:00+03	36100.00
7DD159	2017-08-14 15:23:00+03	6300.00
7DD1E9	2017-07-26 16:46:00+03	23400.00
7DD1EC	2017-07-04 20:33:00+03	24000.00
7DD1F3	2017-07-24 19:37:00+03	47000.00
7DD1F7	2017-07-27 23:04:00+03	36100.00
7DD220	2017-07-21 03:16:00+03	112000.00
7DD22F	2017-07-05 11:19:00+03	125200.00
7DD284	2017-07-30 23:45:00+03	129200.00
7DD415	2017-07-29 21:45:00+03	44800.00
7DD4B8	2017-07-15 22:33:00+03	118100.00
7DD4BC	2017-08-14 09:15:00+03	40600.00
7DD526	2017-08-11 23:32:00+03	32200.00
7DD59B	2017-08-06 23:45:00+03	26000.00
7DD5F3	2017-06-30 05:42:00+03	123000.00
7DD614	2017-07-28 22:49:00+03	40700.00
7DD647	2017-07-25 17:09:00+03	34400.00
7DD6AB	2017-07-08 05:58:00+03	55600.00
7DD6D0	2017-08-14 23:27:00+03	100600.00
7DD7EB	2017-07-24 06:39:00+03	26000.00
7DD878	2017-07-05 13:27:00+03	189200.00
7DD894	2017-07-09 14:21:00+03	102100.00
7DD8B3	2017-07-27 16:30:00+03	186900.00
7DD975	2017-07-26 09:16:00+03	24800.00
7DD9D3	2017-08-14 07:03:00+03	47100.00
7DDA62	2017-07-29 23:26:00+03	203100.00
7DDA79	2017-07-27 07:39:00+03	270000.00
7DDA89	2017-07-06 06:46:00+03	11800.00
7DDA97	2017-07-26 22:05:00+03	29600.00
7DDAA0	2017-07-13 15:35:00+03	272300.00
7DDB05	2017-07-17 13:52:00+03	229900.00
7DDB16	2017-07-08 00:05:00+03	77800.00
7DDB97	2017-07-27 15:02:00+03	12000.00
7DDBB3	2017-08-09 00:40:00+03	35600.00
7DDBEF	2017-07-28 01:18:00+03	96800.00
7DDBF7	2017-07-24 14:14:00+03	31000.00
7DDC47	2017-08-13 10:00:00+03	434400.00
7DDC6B	2017-07-03 15:49:00+03	81300.00
7DDC74	2017-07-09 22:24:00+03	21800.00
7DDC7E	2017-07-26 01:56:00+03	26000.00
7DDCB4	2017-08-10 05:48:00+03	56000.00
7DDCF3	2017-08-14 02:42:00+03	57400.00
7DDD31	2017-07-03 07:47:00+03	84000.00
7DDD7F	2017-07-09 07:19:00+03	73900.00
7DDD8C	2017-07-16 09:06:00+03	28800.00
7DDDB9	2017-07-14 05:34:00+03	123000.00
7DDDCA	2017-08-15 03:41:00+03	26200.00
7DDDCF	2017-07-06 23:45:00+03	27900.00
7DDE0B	2017-07-14 05:06:00+03	44700.00
7DDE73	2017-08-15 16:19:00+03	325000.00
7DDF3D	2017-07-20 00:44:00+03	73200.00
7DDF4F	2017-06-25 05:55:00+03	67000.00
7DDF5F	2017-07-09 13:25:00+03	66000.00
7DDF64	2017-07-30 17:21:00+03	112000.00
7DE03D	2017-08-01 13:52:00+03	21400.00
7DE06C	2017-07-03 03:23:00+03	394800.00
7DE077	2017-07-10 21:37:00+03	259000.00
7DE087	2017-07-25 05:28:00+03	28000.00
7DE089	2017-07-19 20:13:00+03	132800.00
7DE09A	2017-07-14 02:07:00+03	28800.00
7DE09E	2017-08-13 16:52:00+03	28800.00
7DE0B1	2017-07-09 20:09:00+03	14400.00
7DE0ED	2017-07-31 05:22:00+03	25100.00
7DE107	2017-07-18 23:32:00+03	95200.00
7DE180	2017-07-07 07:35:00+03	42800.00
7DE1DD	2017-07-16 13:19:00+03	48500.00
7DE210	2017-08-15 04:53:00+03	73900.00
7DE22F	2017-08-03 05:40:00+03	60800.00
7DE237	2017-07-14 14:36:00+03	86800.00
7DE2B7	2017-07-09 03:30:00+03	119800.00
7DE351	2017-08-09 20:01:00+03	75600.00
7DE360	2017-08-07 20:48:00+03	23200.00
7DE379	2017-07-06 11:24:00+03	6000.00
7DE3AD	2017-07-18 15:02:00+03	27400.00
7DE3D8	2017-07-31 06:59:00+03	132800.00
7DE448	2017-08-14 21:11:00+03	10800.00
7DE450	2017-07-27 18:09:00+03	31600.00
7DE48E	2017-08-11 07:27:00+03	76600.00
7DE4CF	2017-08-03 01:09:00+03	25100.00
7DE535	2017-07-31 12:09:00+03	25400.00
7DE575	2017-07-29 10:33:00+03	33100.00
7DE5AC	2017-08-05 22:50:00+03	36200.00
7DE5EA	2017-08-12 03:17:00+03	28800.00
7DE60D	2017-06-29 03:20:00+03	223200.00
7DE637	2017-07-03 20:08:00+03	56000.00
7DE65B	2017-08-13 05:25:00+03	36000.00
7DE69F	2017-08-15 12:56:00+03	22000.00
7DE6B4	2017-08-05 07:56:00+03	130400.00
7DE6EF	2017-07-29 14:54:00+03	64600.00
7DE702	2017-08-06 01:33:00+03	28800.00
7DE720	2017-07-12 11:18:00+03	58400.00
7DE783	2017-08-13 07:06:00+03	34000.00
7DE7C9	2017-07-13 13:03:00+03	76300.00
7DE7E3	2017-08-06 20:56:00+03	8200.00
7DE7F4	2017-07-16 13:23:00+03	56900.00
7DE7FA	2017-07-07 10:42:00+03	51300.00
7DE810	2017-08-06 14:54:00+03	153300.00
7DE840	2017-08-14 20:50:00+03	13300.00
7DE892	2017-08-08 20:34:00+03	36200.00
7DE8AD	2017-07-02 02:07:00+03	420500.00
7DE8B1	2017-08-10 11:35:00+03	92800.00
7DE8F5	2017-07-03 10:20:00+03	54400.00
7DE911	2017-08-07 18:06:00+03	31100.00
7DE93E	2017-07-19 12:43:00+03	25100.00
7DE974	2017-08-12 07:42:00+03	102100.00
7DE97D	2017-07-22 02:05:00+03	30800.00
7DE981	2017-07-24 03:03:00+03	14800.00
7DE9C5	2017-07-20 22:50:00+03	38400.00
7DE9CE	2017-08-07 05:21:00+03	69500.00
7DEA3B	2017-07-26 15:51:00+03	23200.00
7DEA9D	2017-07-18 16:50:00+03	40300.00
7DEABD	2017-07-12 20:42:00+03	39200.00
7DEB69	2017-07-27 17:42:00+03	86300.00
7DEB72	2017-08-01 23:44:00+03	24200.00
7DEBB7	2017-07-24 01:58:00+03	153200.00
7DEBBF	2017-07-27 05:59:00+03	31800.00
7DEBFA	2017-07-19 12:28:00+03	61800.00
7DECC0	2017-07-12 22:01:00+03	52000.00
7DED1F	2017-07-27 17:45:00+03	20600.00
7DED5D	2017-07-09 17:22:00+03	26000.00
7DED5F	2017-07-11 17:12:00+03	47200.00
7DEDA8	2017-06-30 00:32:00+03	71900.00
7DEDB7	2017-06-30 14:21:00+03	17000.00
7DEDC6	2017-07-26 07:39:00+03	151800.00
7DEE4E	2017-07-13 04:49:00+03	77900.00
7DEEE0	2017-08-01 16:02:00+03	266400.00
7DEEF9	2017-08-10 13:38:00+03	47200.00
7DEF16	2017-08-08 12:07:00+03	6000.00
7DEF36	2017-08-15 03:13:00+03	13200.00
7DEF48	2017-07-16 00:09:00+03	27200.00
7DEF62	2017-08-09 02:00:00+03	13600.00
7DEFEB	2017-07-10 20:19:00+03	57400.00
7DEFF4	2017-08-09 23:17:00+03	73100.00
7DF060	2017-07-18 23:01:00+03	48800.00
7DF07E	2017-07-21 19:51:00+03	48800.00
7DF0CB	2017-08-08 09:27:00+03	28000.00
7DF0EB	2017-07-21 11:58:00+03	68000.00
7DF18A	2017-08-10 09:37:00+03	114400.00
7DF1A5	2017-08-10 09:36:00+03	59800.00
7DF218	2017-08-11 07:43:00+03	73200.00
7DF2B3	2017-07-08 22:09:00+03	55800.00
7DF321	2017-07-28 18:02:00+03	96100.00
7DF3AE	2017-07-20 14:53:00+03	8200.00
7DF3BE	2017-07-08 09:17:00+03	54100.00
7DF43B	2017-08-07 01:17:00+03	40700.00
7DF4BF	2017-07-31 07:06:00+03	58600.00
7DF536	2017-07-20 03:32:00+03	73600.00
7DF59D	2017-07-21 23:00:00+03	43600.00
7DF5C7	2017-08-08 01:37:00+03	246000.00
7DF5EE	2017-07-09 15:55:00+03	6000.00
7DF64A	2017-07-09 09:05:00+03	610600.00
7DF64B	2017-07-07 14:23:00+03	46300.00
7DF652	2017-07-29 11:06:00+03	119800.00
7DF6B9	2017-08-11 03:01:00+03	10700.00
7DF6D8	2017-07-23 22:13:00+03	50600.00
7DF76F	2017-07-29 14:14:00+03	25800.00
7DF781	2017-07-16 18:27:00+03	190400.00
7DF78E	2017-07-30 09:45:00+03	28000.00
7DF7A4	2017-08-15 01:21:00+03	125400.00
7DF92E	2017-07-24 16:01:00+03	70700.00
7DF96A	2017-08-13 06:31:00+03	69000.00
7DFA2B	2017-08-02 00:34:00+03	135200.00
7DFAA0	2017-07-09 02:44:00+03	75500.00
7DFBE1	2017-07-02 18:09:00+03	89700.00
7DFBFF	2017-07-15 10:11:00+03	24400.00
7DFC81	2017-08-09 18:15:00+03	40400.00
7DFD22	2017-07-15 13:06:00+03	70200.00
7DFD34	2017-07-11 02:31:00+03	72700.00
7DFD76	2017-08-10 18:19:00+03	26800.00
7DFD8B	2017-08-15 08:35:00+03	46000.00
7DFE18	2017-06-27 17:51:00+03	58800.00
7DFE4D	2017-07-13 18:35:00+03	31600.00
7DFF28	2017-07-08 14:46:00+03	92800.00
7DFF52	2017-07-03 17:13:00+03	129000.00
7DFF6B	2017-07-27 21:16:00+03	142000.00
7DFF89	2017-08-11 22:02:00+03	73500.00
7DFFA0	2017-07-23 15:58:00+03	10800.00
7DFFD8	2017-07-21 17:10:00+03	111600.00
7E0007	2017-07-22 05:47:00+03	30700.00
7E00B7	2017-07-21 10:11:00+03	71900.00
7E012D	2017-08-11 07:32:00+03	124200.00
7E01D8	2017-07-26 23:07:00+03	54500.00
7E020F	2017-07-12 11:24:00+03	101200.00
7E0227	2017-07-14 16:45:00+03	27200.00
7E025C	2017-07-07 09:47:00+03	18000.00
7E029E	2017-06-30 23:54:00+03	31400.00
7E02C9	2017-07-24 21:22:00+03	37900.00
7E02E5	2017-07-04 19:22:00+03	59100.00
7E031B	2017-07-24 09:39:00+03	49800.00
7E03B5	2017-07-08 06:17:00+03	139200.00
7E03CC	2017-07-10 23:24:00+03	151200.00
7E03DD	2017-07-02 21:07:00+03	57400.00
7E0409	2017-08-03 15:09:00+03	56100.00
7E0416	2017-07-27 19:58:00+03	258400.00
7E0424	2017-08-11 21:30:00+03	65900.00
7E044D	2017-08-15 08:17:00+03	39000.00
7E04C9	2017-07-29 16:46:00+03	81600.00
7E04D4	2017-07-04 19:08:00+03	69500.00
7E052C	2017-07-29 22:07:00+03	96200.00
7E0560	2017-07-16 20:13:00+03	55500.00
7E0621	2017-07-22 08:12:00+03	51600.00
7E0622	2017-08-01 12:29:00+03	39800.00
7E064F	2017-07-23 20:10:00+03	64100.00
7E065E	2017-07-15 05:31:00+03	100600.00
7E06D2	2017-07-21 09:13:00+03	8200.00
7E06FE	2017-08-13 06:16:00+03	51800.00
7E0741	2017-08-07 01:44:00+03	32700.00
7E0753	2017-08-06 13:32:00+03	61500.00
7E076D	2017-07-13 17:59:00+03	49800.00
7E07C4	2017-07-08 21:42:00+03	66000.00
7E07F7	2017-08-14 21:55:00+03	408500.00
7E082B	2017-08-08 08:19:00+03	136200.00
7E084D	2017-08-10 18:37:00+03	23600.00
7E086C	2017-08-08 23:35:00+03	282100.00
7E0890	2017-07-19 13:50:00+03	24400.00
7E08BD	2017-08-02 17:41:00+03	67600.00
7E08CF	2017-08-04 11:15:00+03	23600.00
7E08EB	2017-07-03 16:02:00+03	22000.00
7E0977	2017-08-03 12:15:00+03	140800.00
7E09B3	2017-08-11 00:19:00+03	34800.00
7E09B4	2017-07-20 02:14:00+03	191900.00
7E0A21	2017-07-01 16:34:00+03	21200.00
7E0A33	2017-08-02 01:13:00+03	169300.00
7E0A56	2017-08-12 20:43:00+03	73100.00
7E0A61	2017-07-09 07:26:00+03	112000.00
7E0A69	2017-07-04 05:30:00+03	31400.00
7E0A7A	2017-08-14 20:55:00+03	6700.00
7E0A87	2017-07-30 04:18:00+03	531300.00
7E0A9C	2017-07-23 06:21:00+03	36200.00
7E0A9D	2017-08-05 09:52:00+03	117100.00
7E0B24	2017-07-12 09:33:00+03	6200.00
7E0B9F	2017-07-04 18:46:00+03	14400.00
7E0CA6	2017-07-23 17:49:00+03	165800.00
7E0CD8	2017-07-07 10:44:00+03	58200.00
7E0CDA	2017-07-13 03:34:00+03	117600.00
7E0CEA	2017-07-15 12:12:00+03	48700.00
7E0D2F	2017-07-25 22:47:00+03	135600.00
7E0D63	2017-08-01 22:53:00+03	88500.00
7E0E1A	2017-08-08 16:08:00+03	131100.00
7E0E3B	2017-08-09 22:03:00+03	147700.00
7E0E6C	2017-07-25 23:46:00+03	40100.00
7E0E80	2017-07-30 01:09:00+03	20200.00
7E0E8A	2017-08-06 04:49:00+03	44000.00
7E0EA0	2017-07-05 21:37:00+03	94400.00
7E0F0D	2017-07-02 12:42:00+03	51000.00
7E0F12	2017-08-13 17:03:00+03	246000.00
7E0F14	2017-07-12 16:48:00+03	6200.00
7E0F83	2017-07-08 22:14:00+03	19800.00
7E0FA7	2017-07-15 12:50:00+03	27200.00
7E0FE1	2017-07-15 20:14:00+03	28800.00
7E0FE3	2017-07-28 14:18:00+03	29600.00
7E104B	2017-08-03 00:39:00+03	32800.00
7E1097	2017-07-23 16:19:00+03	28000.00
7E10A1	2017-08-07 05:58:00+03	58800.00
7E1141	2017-07-25 21:34:00+03	23200.00
7E11C3	2017-07-03 10:05:00+03	46300.00
7E11C9	2017-08-11 21:40:00+03	40200.00
7E11D1	2017-07-01 01:04:00+03	35200.00
7E11DC	2017-08-12 16:51:00+03	56000.00
7E120A	2017-08-05 12:11:00+03	170500.00
7E12DD	2017-07-19 00:05:00+03	18900.00
7E1367	2017-07-30 03:04:00+03	66600.00
7E13F9	2017-08-09 21:33:00+03	28800.00
7E13FB	2017-07-14 05:13:00+03	166100.00
7E143E	2017-07-09 19:23:00+03	56000.00
7E144C	2017-07-31 19:53:00+03	13200.00
7E1469	2017-07-03 02:40:00+03	31400.00
7E1473	2017-07-18 21:53:00+03	23400.00
7E1480	2017-07-08 04:14:00+03	31600.00
7E1510	2017-07-30 13:20:00+03	57500.00
7E1543	2017-07-25 00:11:00+03	15800.00
7E159C	2017-08-05 22:41:00+03	6700.00
7E15D6	2017-07-05 07:48:00+03	147000.00
7E1600	2017-07-25 15:16:00+03	41600.00
7E1617	2017-07-25 12:37:00+03	6700.00
7E164B	2017-07-23 04:56:00+03	137700.00
7E168A	2017-07-21 09:07:00+03	353600.00
7E16E9	2017-07-15 21:02:00+03	47500.00
7E1706	2017-08-12 10:51:00+03	22000.00
7E170E	2017-07-06 15:58:00+03	75600.00
7E175F	2017-08-07 03:09:00+03	103200.00
7E1785	2017-07-05 04:48:00+03	30000.00
7E17B2	2017-07-07 00:42:00+03	21400.00
7E17E9	2017-08-03 20:57:00+03	28000.00
7E17F3	2017-08-09 18:33:00+03	34200.00
7E17F6	2017-07-26 04:40:00+03	28800.00
7E184C	2017-07-29 15:14:00+03	39100.00
7E184D	2017-07-07 09:44:00+03	177600.00
7E18CC	2017-07-22 15:21:00+03	47800.00
7E195F	2017-07-14 06:55:00+03	10600.00
7E1991	2017-07-10 06:24:00+03	25800.00
7E1997	2017-08-11 22:28:00+03	140300.00
7E19C0	2017-07-31 22:41:00+03	16000.00
7E1A90	2017-08-01 04:41:00+03	44600.00
7E1B42	2017-06-29 20:33:00+03	56000.00
7E1B64	2017-08-08 22:22:00+03	73600.00
7E1B70	2017-08-11 23:55:00+03	106700.00
7E1B73	2017-07-19 16:06:00+03	24700.00
7E1BBB	2017-08-15 14:45:00+03	24500.00
7E1C19	2017-07-02 04:37:00+03	62600.00
7E1C9B	2017-07-01 07:57:00+03	123000.00
7E1C9D	2017-08-01 19:50:00+03	78800.00
7E1CA4	2017-07-17 21:07:00+03	28000.00
7E1CEC	2017-07-05 04:00:00+03	20200.00
7E1D56	2017-07-20 04:25:00+03	40800.00
7E1D8D	2017-07-02 11:28:00+03	192400.00
7E1DB1	2017-07-11 06:13:00+03	52800.00
7E1DDB	2017-07-17 03:13:00+03	72500.00
7E1E05	2017-08-15 10:44:00+03	36000.00
7E1E7B	2017-07-06 14:08:00+03	58800.00
7E1EBF	2017-08-02 01:56:00+03	109600.00
7E1EF1	2017-07-27 23:27:00+03	78200.00
7E1F24	2017-08-12 13:13:00+03	16400.00
7E1F55	2017-08-14 16:39:00+03	32800.00
7E1F7F	2017-08-13 08:47:00+03	46400.00
7E1FAA	2017-08-14 18:35:00+03	88900.00
7E2056	2017-08-06 22:03:00+03	47400.00
7E2066	2017-07-24 22:27:00+03	242100.00
7E20C7	2017-08-07 00:09:00+03	43500.00
7E2106	2017-08-12 02:02:00+03	23600.00
7E213B	2017-08-03 16:37:00+03	25600.00
7E2169	2017-07-28 14:05:00+03	36200.00
7E2196	2017-07-07 12:32:00+03	64500.00
7E21A6	2017-07-22 06:10:00+03	27400.00
7E21BB	2017-07-08 03:50:00+03	46800.00
7E21BF	2017-07-22 00:42:00+03	51300.00
7E21F2	2017-08-06 02:11:00+03	134400.00
7E2224	2017-08-05 16:24:00+03	42600.00
7E2273	2017-07-23 03:38:00+03	133100.00
7E228C	2017-08-11 14:33:00+03	32700.00
7E2299	2017-07-26 23:29:00+03	166100.00
7E22F5	2017-07-17 14:13:00+03	45200.00
7E22FD	2017-08-04 23:55:00+03	44800.00
7E2331	2017-07-08 03:10:00+03	55800.00
7E23C3	2017-08-05 11:55:00+03	131100.00
7E23D4	2017-08-15 16:29:00+03	136200.00
7E2432	2017-08-12 00:17:00+03	89700.00
7E2446	2017-08-01 20:46:00+03	34100.00
7E2453	2017-07-02 14:39:00+03	196000.00
7E247F	2017-08-03 04:06:00+03	72300.00
7E249B	2017-07-20 04:08:00+03	40400.00
7E249F	2017-07-04 12:17:00+03	38800.00
7E251B	2017-07-31 06:24:00+03	52000.00
7E25A4	2017-07-04 23:45:00+03	258400.00
7E2601	2017-07-24 08:02:00+03	32800.00
7E2635	2017-08-10 20:11:00+03	35200.00
7E2637	2017-07-10 13:52:00+03	111600.00
7E2661	2017-07-31 04:11:00+03	52700.00
7E266A	2017-07-31 02:27:00+03	46800.00
7E268F	2017-07-12 10:48:00+03	101500.00
7E276F	2017-08-13 11:44:00+03	125400.00
7E281E	2017-07-04 10:54:00+03	75300.00
7E287F	2017-07-23 16:26:00+03	36000.00
7E28D1	2017-08-10 13:13:00+03	31900.00
7E28D6	2017-07-19 00:51:00+03	55800.00
7E28E1	2017-06-29 19:37:00+03	306200.00
7E28FC	2017-07-27 17:15:00+03	13000.00
7E2959	2017-07-11 20:02:00+03	124300.00
7E2A1C	2017-08-07 06:39:00+03	56000.00
7E2A36	2017-08-02 20:03:00+03	6300.00
7E2B25	2017-07-22 20:15:00+03	23200.00
7E2B71	2017-07-15 13:00:00+03	49600.00
7E2BC7	2017-07-19 09:48:00+03	28700.00
7E2BDB	2017-07-28 06:52:00+03	24500.00
7E2BF3	2017-07-05 00:41:00+03	258300.00
7E2D04	2017-07-28 03:10:00+03	37200.00
7E2D22	2017-07-02 09:43:00+03	62900.00
7E2DC4	2017-07-24 15:54:00+03	54800.00
7E2DCE	2017-07-10 21:33:00+03	69500.00
7E2E3C	2017-07-06 19:48:00+03	6300.00
7E2E6B	2017-07-26 15:22:00+03	51000.00
7E2EBB	2017-08-04 04:54:00+03	27300.00
7E2F1C	2017-07-27 15:24:00+03	51200.00
7E2FC3	2017-07-18 02:32:00+03	57600.00
7E2FED	2017-08-05 13:27:00+03	29600.00
7E301D	2017-08-11 18:34:00+03	114800.00
7E304F	2017-08-01 04:51:00+03	146400.00
7E3053	2017-07-30 17:14:00+03	139600.00
7E30AB	2017-08-06 04:28:00+03	11000.00
7E30C9	2017-08-08 06:53:00+03	81900.00
7E3192	2017-07-26 13:58:00+03	116900.00
7E31B9	2017-07-12 19:56:00+03	79600.00
7E32C6	2017-07-22 16:46:00+03	199100.00
7E32C8	2017-06-25 12:14:00+03	88600.00
7E3349	2017-07-27 01:57:00+03	14000.00
7E3369	2017-07-12 06:27:00+03	68100.00
7E33A3	2017-08-04 04:08:00+03	6700.00
7E33A8	2017-08-03 12:33:00+03	59200.00
7E33D1	2017-08-11 09:35:00+03	33400.00
7E3413	2017-08-11 00:56:00+03	56000.00
7E3482	2017-07-16 06:48:00+03	47200.00
7E34AB	2017-07-25 13:57:00+03	12000.00
7E34CA	2017-07-26 02:25:00+03	37600.00
7E34DD	2017-06-29 11:55:00+03	38600.00
7E352B	2017-07-29 18:12:00+03	46400.00
7E353E	2017-07-12 10:13:00+03	24000.00
7E3576	2017-08-04 08:36:00+03	21800.00
7E35B1	2017-07-05 20:27:00+03	7400.00
7E35C0	2017-08-12 02:44:00+03	62000.00
7E35DE	2017-07-25 13:42:00+03	44800.00
7E364C	2017-07-24 09:48:00+03	37900.00
7E367C	2017-07-06 14:22:00+03	18600.00
7E3685	2017-07-04 21:22:00+03	56900.00
7E36BC	2017-07-08 01:54:00+03	61300.00
7E36DA	2017-07-09 05:13:00+03	62600.00
7E36FF	2017-07-01 18:12:00+03	13600.00
7E3776	2017-08-11 00:15:00+03	81600.00
7E3795	2017-07-05 13:10:00+03	100200.00
7E37B5	2017-07-23 02:46:00+03	57500.00
7E3805	2017-07-27 06:00:00+03	240600.00
7E3894	2017-07-10 15:32:00+03	76300.00
7E38D7	2017-07-21 05:38:00+03	80000.00
7E38FF	2017-07-02 17:38:00+03	80500.00
7E3A03	2017-08-09 23:10:00+03	77200.00
7E3A15	2017-07-11 10:32:00+03	61500.00
7E3A69	2017-08-13 08:47:00+03	29200.00
7E3A73	2017-07-27 21:09:00+03	39300.00
7E3ACB	2017-07-26 15:52:00+03	14400.00
7E3AE5	2017-07-14 08:00:00+03	23200.00
7E3B0C	2017-07-17 03:43:00+03	28000.00
7E3B64	2017-07-28 23:42:00+03	22600.00
7E3B78	2017-07-02 05:31:00+03	6300.00
7E3BA7	2017-07-16 10:09:00+03	24800.00
7E3BC0	2017-08-07 02:52:00+03	26600.00
7E3BEB	2017-07-28 00:55:00+03	58400.00
7E3C52	2017-08-02 11:37:00+03	46400.00
7E3CB3	2017-08-08 17:16:00+03	24400.00
7E3D36	2017-07-17 13:30:00+03	34200.00
7E3D5E	2017-07-15 20:12:00+03	57400.00
7E3DAF	2017-08-07 17:33:00+03	26000.00
7E3DE7	2017-07-22 20:34:00+03	32700.00
7E3E33	2017-07-01 07:31:00+03	114800.00
7E3ED1	2017-08-05 07:09:00+03	69500.00
7E3EEB	2017-08-01 15:23:00+03	413400.00
7E3F3F	2017-07-27 02:51:00+03	135200.00
7E3F47	2017-07-07 17:24:00+03	24700.00
7E4049	2017-07-06 00:16:00+03	34600.00
7E40B2	2017-07-10 06:36:00+03	52600.00
7E40CA	2017-08-01 18:31:00+03	25400.00
7E4176	2017-08-13 12:19:00+03	74400.00
7E41C3	2017-07-19 20:54:00+03	50600.00
7E41D6	2017-07-13 23:19:00+03	77700.00
7E41E6	2017-08-08 05:25:00+03	31400.00
7E4201	2017-08-06 14:59:00+03	41800.00
7E424D	2017-08-07 02:49:00+03	93900.00
7E4256	2017-07-02 07:57:00+03	68800.00
7E4332	2017-07-11 11:48:00+03	28800.00
7E434B	2017-08-15 05:29:00+03	27200.00
7E4351	2017-08-13 23:04:00+03	12600.00
7E4379	2017-07-31 14:25:00+03	269300.00
7E437C	2017-08-03 02:22:00+03	70900.00
7E438E	2017-08-02 16:41:00+03	193200.00
7E43F8	2017-07-03 23:32:00+03	152900.00
7E43FA	2017-08-04 10:11:00+03	100000.00
7E441D	2017-07-25 01:35:00+03	8200.00
7E4491	2017-07-03 19:04:00+03	126300.00
7E458F	2017-07-31 02:56:00+03	56000.00
7E459F	2017-07-02 23:12:00+03	178800.00
7E45BF	2017-07-17 21:58:00+03	40800.00
7E45D3	2017-07-28 19:38:00+03	181100.00
7E45E5	2017-08-01 20:17:00+03	88300.00
7E468E	2017-07-23 00:08:00+03	37200.00
7E46E6	2017-07-21 21:52:00+03	38400.00
7E46F1	2017-07-29 20:00:00+03	185600.00
7E476C	2017-07-17 10:43:00+03	66300.00
7E477E	2017-07-16 08:32:00+03	48500.00
7E47D8	2017-07-13 02:36:00+03	83200.00
7E4811	2017-07-18 04:31:00+03	23200.00
7E4820	2017-07-13 09:47:00+03	81200.00
7E4823	2017-07-19 16:23:00+03	111600.00
7E4829	2017-07-29 02:07:00+03	138000.00
7E4875	2017-07-25 06:26:00+03	67200.00
7E49E9	2017-08-04 06:14:00+03	272600.00
7E4ACB	2017-07-30 21:17:00+03	139000.00
7E4B6A	2017-07-28 06:11:00+03	94400.00
7E4B76	2017-07-27 03:50:00+03	70700.00
7E4CA7	2017-06-29 10:17:00+03	23200.00
7E4CB2	2017-07-22 02:39:00+03	71600.00
7E4DA4	2017-07-18 02:15:00+03	15000.00
7E4E00	2017-08-08 16:36:00+03	270700.00
7E4E02	2017-08-13 09:00:00+03	247600.00
7E4E6C	2017-08-03 22:59:00+03	56000.00
7E4EB3	2017-07-29 14:27:00+03	40800.00
7E4F72	2017-07-23 06:00:00+03	61500.00
7E4FF9	2017-07-18 19:19:00+03	65600.00
7E5032	2017-08-07 01:15:00+03	94800.00
7E50B5	2017-08-07 20:55:00+03	265700.00
7E50E9	2017-08-10 19:06:00+03	46200.00
7E50EE	2017-08-10 06:20:00+03	94900.00
7E515A	2017-08-10 12:05:00+03	31400.00
7E5188	2017-07-09 06:40:00+03	104000.00
7E51DB	2017-07-17 20:24:00+03	84500.00
7E51DD	2017-07-11 10:55:00+03	62800.00
7E51E7	2017-07-11 18:42:00+03	135400.00
7E51FA	2017-08-14 06:12:00+03	93900.00
7E5251	2017-07-21 11:19:00+03	31600.00
7E5257	2017-07-19 05:17:00+03	269600.00
7E5261	2017-07-06 03:17:00+03	54800.00
7E5264	2017-08-13 22:04:00+03	46800.00
7E5278	2017-07-21 22:16:00+03	201800.00
7E529A	2017-08-14 18:23:00+03	26700.00
7E52B1	2017-08-08 09:21:00+03	112000.00
7E52CD	2017-07-29 07:28:00+03	119600.00
7E52D5	2017-06-27 06:43:00+03	46300.00
7E532D	2017-07-01 03:14:00+03	112600.00
7E5403	2017-07-03 08:33:00+03	31400.00
7E5454	2017-07-26 05:33:00+03	39500.00
7E5484	2017-08-08 04:16:00+03	14000.00
7E54AA	2017-07-01 13:48:00+03	92000.00
7E54C2	2017-08-14 20:05:00+03	170000.00
7E5527	2017-07-27 00:19:00+03	38400.00
7E554B	2017-08-02 17:29:00+03	46300.00
7E55F2	2017-08-12 05:22:00+03	22000.00
7E55FE	2017-07-25 10:46:00+03	78000.00
7E560B	2017-07-25 08:44:00+03	282000.00
7E5628	2017-06-29 01:40:00+03	17800.00
7E569E	2017-07-09 14:20:00+03	57500.00
7E573E	2017-07-05 11:05:00+03	23200.00
7E5779	2017-07-23 17:59:00+03	111600.00
7E57C3	2017-07-29 12:33:00+03	10800.00
7E580B	2017-07-06 05:23:00+03	12600.00
7E581E	2017-07-08 19:23:00+03	47100.00
7E5831	2017-07-09 09:49:00+03	57600.00
7E589C	2017-08-04 16:43:00+03	46400.00
7E58E2	2017-07-29 06:02:00+03	73500.00
7E5906	2017-07-19 00:02:00+03	339900.00
7E598A	2017-07-25 02:36:00+03	82500.00
7E59A6	2017-07-14 17:23:00+03	135400.00
7E5A1A	2017-08-01 15:11:00+03	14400.00
7E5A1F	2017-07-15 19:22:00+03	107600.00
7E5A4A	2017-07-09 04:25:00+03	24400.00
7E5A9A	2017-08-03 19:31:00+03	136200.00
7E5AE3	2017-07-15 19:13:00+03	12600.00
7E5B4B	2017-08-06 03:22:00+03	81700.00
7E5B4C	2017-08-06 00:32:00+03	122000.00
7E5B58	2017-06-30 08:57:00+03	43000.00
7E5B74	2017-07-14 15:50:00+03	56600.00
7E5B81	2017-08-07 20:44:00+03	135100.00
7E5BA4	2017-08-15 05:59:00+03	40000.00
7E5BA8	2017-08-09 05:46:00+03	83000.00
7E5C0C	2017-07-30 03:32:00+03	26800.00
7E5C32	2017-08-01 11:17:00+03	47000.00
7E5C4E	2017-08-12 18:35:00+03	98400.00
7E5C74	2017-07-13 00:26:00+03	102100.00
7E5C85	2017-08-05 07:50:00+03	25000.00
7E5CDC	2017-07-19 14:43:00+03	23600.00
7E5D52	2017-07-29 10:13:00+03	135600.00
7E5DF6	2017-08-01 20:11:00+03	90800.00
7E5E10	2017-07-23 02:21:00+03	55800.00
7E5E1B	2017-07-13 04:49:00+03	58800.00
7E5E8B	2017-07-17 02:17:00+03	88900.00
7E5F1F	2017-07-30 05:48:00+03	56100.00
7E5F24	2017-07-21 06:49:00+03	75600.00
7E5F26	2017-08-05 07:21:00+03	21400.00
7E5F93	2017-08-12 16:09:00+03	138300.00
7E5FA1	2017-07-16 19:54:00+03	34200.00
7E5FC8	2017-08-15 17:48:00+03	24200.00
7E6026	2017-07-25 13:53:00+03	99300.00
7E6054	2017-07-05 02:11:00+03	59200.00
7E610E	2017-08-13 11:07:00+03	48000.00
7E613C	2017-07-14 06:56:00+03	71200.00
7E61D3	2017-07-06 11:13:00+03	38200.00
7E61F6	2017-07-24 11:42:00+03	58900.00
7E6253	2017-07-06 16:29:00+03	56100.00
7E6271	2017-07-05 01:51:00+03	82500.00
7E62AE	2017-07-29 02:19:00+03	123700.00
7E62BA	2017-07-06 00:16:00+03	309000.00
7E62EC	2017-08-10 11:23:00+03	46000.00
7E637B	2017-08-05 10:24:00+03	108600.00
7E63D4	2017-06-30 11:57:00+03	33100.00
7E6410	2017-08-14 08:40:00+03	76800.00
7E6433	2017-07-20 05:36:00+03	271100.00
7E6440	2017-08-10 06:57:00+03	51900.00
7E646A	2017-08-08 00:33:00+03	56000.00
7E6475	2017-08-06 18:21:00+03	229900.00
7E64B1	2017-08-12 06:43:00+03	295300.00
7E64BA	2017-07-29 14:14:00+03	114800.00
7E6551	2017-08-14 16:46:00+03	7200.00
7E65AC	2017-08-13 21:46:00+03	185300.00
7E6687	2017-07-25 03:05:00+03	23200.00
7E66A7	2017-08-14 08:44:00+03	141200.00
7E66C0	2017-06-30 09:34:00+03	28000.00
7E6710	2017-08-05 23:03:00+03	27200.00
7E6737	2017-07-07 14:17:00+03	59300.00
7E67E8	2017-07-19 17:04:00+03	168000.00
7E68D5	2017-08-13 22:47:00+03	57500.00
7E6915	2017-07-02 03:28:00+03	23600.00
7E694B	2017-08-15 15:17:00+03	35600.00
7E696B	2017-08-05 00:24:00+03	76600.00
7E69C4	2017-08-07 08:16:00+03	24400.00
7E6A45	2017-08-07 14:07:00+03	11700.00
7E6A4A	2017-08-02 17:40:00+03	57500.00
7E6A4B	2017-07-13 15:44:00+03	89200.00
7E6B2C	2017-07-21 04:31:00+03	37800.00
7E6B54	2017-08-09 09:35:00+03	39400.00
7E6C2D	2017-07-05 18:06:00+03	92900.00
7E6C6D	2017-07-03 13:36:00+03	86400.00
7E6C7C	2017-08-12 13:58:00+03	106700.00
7E6CA7	2017-08-07 07:02:00+03	28600.00
7E6CD8	2017-08-09 04:03:00+03	28000.00
7E6D24	2017-07-20 15:11:00+03	32700.00
7E6D50	2017-08-09 21:44:00+03	131100.00
7E6D63	2017-07-25 01:24:00+03	91200.00
7E6D6C	2017-08-05 08:24:00+03	155600.00
7E6D81	2017-07-27 12:08:00+03	123600.00
7E6DBF	2017-07-06 23:10:00+03	55800.00
7E6DE4	2017-07-02 13:38:00+03	55800.00
7E6ED9	2017-08-12 04:00:00+03	102100.00
7E6EE8	2017-07-28 05:32:00+03	26000.00
7E6F82	2017-07-23 19:15:00+03	28000.00
7E6FDB	2017-07-23 22:30:00+03	18000.00
7E6FF2	2017-06-28 07:45:00+03	18000.00
7E7035	2017-07-01 11:32:00+03	46000.00
7E707D	2017-07-29 07:08:00+03	53200.00
7E70A9	2017-07-27 06:02:00+03	47200.00
7E70AA	2017-08-10 04:19:00+03	55800.00
7E70AE	2017-08-13 07:53:00+03	38600.00
7E70DA	2017-07-23 16:04:00+03	25000.00
7E7105	2017-07-14 08:42:00+03	46400.00
7E7123	2017-07-06 01:07:00+03	102100.00
7E71C2	2017-07-28 13:33:00+03	23200.00
7E7232	2017-06-28 09:17:00+03	16400.00
7E7325	2017-08-08 00:37:00+03	36800.00
7E7374	2017-08-12 18:30:00+03	65600.00
7E7403	2017-08-05 05:39:00+03	105000.00
7E7436	2017-07-13 11:54:00+03	36200.00
7E74EE	2017-07-08 07:27:00+03	39100.00
7E750F	2017-07-12 22:18:00+03	32700.00
7E7511	2017-08-03 21:28:00+03	77200.00
7E753F	2017-07-17 14:47:00+03	14000.00
7E75A5	2017-07-05 15:31:00+03	28800.00
7E75C2	2017-08-15 06:42:00+03	26000.00
7E75DC	2017-07-29 22:15:00+03	199200.00
7E75EE	2017-08-05 01:05:00+03	68100.00
7E76A2	2017-07-04 20:14:00+03	68700.00
7E76A9	2017-08-02 04:08:00+03	6200.00
7E76B3	2017-07-04 04:40:00+03	110500.00
7E76C6	2017-07-23 08:50:00+03	67000.00
7E7711	2017-07-26 23:38:00+03	29600.00
7E7764	2017-08-09 07:01:00+03	85000.00
7E77DB	2017-07-14 14:53:00+03	48300.00
7E77E9	2017-07-10 01:10:00+03	65900.00
7E782C	2017-08-01 11:15:00+03	60600.00
7E78D4	2017-07-14 03:35:00+03	28000.00
7E78E6	2017-07-20 00:02:00+03	14400.00
7E791E	2017-07-29 01:53:00+03	43200.00
7E7927	2017-08-07 23:07:00+03	131600.00
7E7934	2017-07-10 10:48:00+03	46200.00
7E793A	2017-07-18 17:49:00+03	84000.00
7E7A1C	2017-07-19 11:18:00+03	24400.00
7E7A2E	2017-07-29 13:28:00+03	93900.00
7E7AED	2017-08-13 18:25:00+03	40200.00
7E7B21	2017-07-15 17:04:00+03	284300.00
7E7B67	2017-07-04 08:05:00+03	143800.00
7E7C23	2017-07-03 04:56:00+03	28000.00
7E7C44	2017-07-16 10:50:00+03	68400.00
7E7C68	2017-07-15 04:22:00+03	100200.00
7E7C75	2017-07-04 10:20:00+03	24400.00
7E7CCC	2017-08-06 08:39:00+03	48800.00
7E7CE7	2017-08-14 00:58:00+03	246000.00
7E7D0C	2017-07-07 18:13:00+03	113000.00
7E7D17	2017-07-26 07:27:00+03	32700.00
7E7D1B	2017-07-11 19:43:00+03	106800.00
7E7DA6	2017-08-14 08:55:00+03	67000.00
7E7E35	2017-08-01 22:56:00+03	26800.00
7E7E46	2017-07-31 20:26:00+03	22000.00
7E7E78	2017-07-09 13:00:00+03	23200.00
7E7E7B	2017-07-15 04:47:00+03	114300.00
7E7F09	2017-07-17 10:53:00+03	116100.00
7E7F0E	2017-08-14 22:15:00+03	47000.00
7E7FCA	2017-07-05 07:47:00+03	12000.00
7E7FFC	2017-07-08 15:27:00+03	17800.00
7E8002	2017-07-26 00:52:00+03	27500.00
7E8071	2017-07-03 16:24:00+03	75600.00
7E80B1	2017-07-12 21:36:00+03	193600.00
7E80D1	2017-07-08 18:26:00+03	133200.00
7E80EE	2017-08-05 06:58:00+03	26000.00
7E80F9	2017-07-25 02:46:00+03	123000.00
7E80FA	2017-07-06 00:29:00+03	31400.00
7E8117	2017-07-11 03:49:00+03	16800.00
7E812E	2017-08-01 05:12:00+03	94000.00
7E8138	2017-08-06 00:17:00+03	45500.00
7E813E	2017-07-27 17:08:00+03	114700.00
7E8158	2017-07-23 14:15:00+03	99300.00
7E816F	2017-08-04 14:41:00+03	38400.00
7E8170	2017-07-12 02:50:00+03	15000.00
7E81FD	2017-07-21 02:56:00+03	184700.00
7E82E4	2017-07-22 15:15:00+03	201200.00
7E82EB	2017-08-01 12:44:00+03	36100.00
7E8329	2017-08-12 18:33:00+03	127900.00
7E8353	2017-07-16 11:34:00+03	29600.00
7E83F3	2017-08-04 02:25:00+03	95700.00
7E83F9	2017-07-06 13:53:00+03	58400.00
7E8406	2017-07-23 18:30:00+03	47700.00
7E8412	2017-08-01 01:05:00+03	116800.00
7E8422	2017-08-10 05:21:00+03	386300.00
7E842A	2017-08-10 23:46:00+03	44800.00
7E8481	2017-07-29 03:11:00+03	36200.00
7E84BF	2017-08-07 14:20:00+03	29600.00
7E84C3	2017-07-20 01:36:00+03	92100.00
7E84EB	2017-07-15 04:52:00+03	25600.00
7E84F1	2017-07-19 05:07:00+03	31600.00
7E8537	2017-08-04 15:58:00+03	85500.00
7E8562	2017-07-18 03:16:00+03	202600.00
7E857B	2017-07-26 08:21:00+03	10100.00
7E85E3	2017-07-26 23:29:00+03	92800.00
7E8609	2017-07-10 22:23:00+03	18000.00
7E8634	2017-07-16 01:40:00+03	81600.00
7E8647	2017-07-11 23:53:00+03	33300.00
7E8679	2017-07-01 04:35:00+03	14400.00
7E86CD	2017-07-29 00:33:00+03	41600.00
7E86D9	2017-08-15 00:06:00+03	82900.00
7E86F1	2017-07-31 07:38:00+03	176800.00
7E8798	2017-08-06 02:33:00+03	42400.00
7E87AA	2017-08-15 01:04:00+03	47100.00
7E87B4	2017-08-15 16:11:00+03	28800.00
7E87D7	2017-08-08 08:18:00+03	56000.00
7E880A	2017-07-26 07:45:00+03	14400.00
7E888A	2017-08-01 03:54:00+03	12400.00
7E88B0	2017-08-01 19:14:00+03	68400.00
7E88B8	2017-07-17 03:53:00+03	60400.00
7E891B	2017-07-19 03:34:00+03	59800.00
7E893F	2017-07-06 13:22:00+03	198800.00
7E896C	2017-08-06 23:47:00+03	90300.00
7E89D6	2017-07-20 18:03:00+03	65900.00
7E89FA	2017-07-24 02:58:00+03	19600.00
7E8A12	2017-07-23 21:42:00+03	18600.00
7E8A16	2017-07-18 14:33:00+03	13700.00
7E8A45	2017-07-19 12:22:00+03	61800.00
7E8B69	2017-07-17 21:31:00+03	66600.00
7E8B83	2017-08-12 12:34:00+03	122400.00
7E8BF0	2017-07-27 11:16:00+03	136800.00
7E8BF4	2017-07-09 16:44:00+03	45200.00
7E8C38	2017-07-21 18:11:00+03	110200.00
7E8C4E	2017-07-15 23:13:00+03	167900.00
7E8C65	2017-07-21 02:40:00+03	14000.00
7E8C92	2017-07-06 04:49:00+03	265600.00
7E8C97	2017-07-15 13:33:00+03	56000.00
7E8CE3	2017-07-28 08:10:00+03	23600.00
7E8CF2	2017-08-14 02:59:00+03	28800.00
7E8DD3	2017-07-16 04:58:00+03	167500.00
7E8E20	2017-06-30 09:12:00+03	82900.00
7E8E23	2017-07-13 15:12:00+03	65400.00
7E8E4B	2017-08-14 23:05:00+03	39800.00
7E8FDF	2017-08-12 19:04:00+03	16400.00
7E8FEF	2017-07-05 18:59:00+03	135400.00
7E904F	2017-07-04 15:13:00+03	614800.00
7E9055	2017-06-27 11:53:00+03	18300.00
7E90C2	2017-07-08 19:57:00+03	86300.00
7E90E3	2017-08-15 06:09:00+03	26800.00
7E90FF	2017-07-17 05:20:00+03	46000.00
7E9105	2017-07-04 16:23:00+03	40800.00
7E914B	2017-07-18 01:15:00+03	137700.00
7E915C	2017-07-26 10:51:00+03	47100.00
7E91AB	2017-08-13 23:12:00+03	270200.00
7E921B	2017-07-12 03:34:00+03	71000.00
7E922A	2017-07-07 13:26:00+03	93800.00
7E9230	2017-08-07 09:34:00+03	123000.00
7E927A	2017-07-20 03:18:00+03	53500.00
7E9309	2017-08-15 00:28:00+03	56100.00
7E9318	2017-07-07 23:47:00+03	6000.00
7E9392	2017-07-04 10:16:00+03	75600.00
7E93FC	2017-07-14 01:09:00+03	14400.00
7E9485	2017-08-12 22:25:00+03	273000.00
7E9488	2017-07-26 12:13:00+03	179400.00
7E9499	2017-08-05 06:28:00+03	52400.00
7E94BE	2017-07-18 08:20:00+03	52000.00
7E94CA	2017-08-10 06:26:00+03	36200.00
7E94D4	2017-08-07 18:49:00+03	26800.00
7E9567	2017-07-19 08:06:00+03	149400.00
7E9596	2017-08-10 14:15:00+03	52600.00
7E960F	2017-07-25 21:11:00+03	134400.00
7E962A	2017-08-05 02:49:00+03	65900.00
7E9633	2017-08-10 05:13:00+03	123000.00
7E9641	2017-08-15 13:57:00+03	41600.00
7E9667	2017-07-19 01:15:00+03	24000.00
7E9699	2017-08-14 01:16:00+03	26800.00
7E96D2	2017-08-15 17:55:00+03	45900.00
7E96F6	2017-08-02 07:37:00+03	81600.00
7E9750	2017-07-22 04:54:00+03	40800.00
7E9772	2017-07-30 18:27:00+03	31200.00
7E9793	2017-08-08 08:01:00+03	117200.00
7E97B5	2017-08-07 07:46:00+03	59300.00
7E97E2	2017-07-03 03:02:00+03	8400.00
7E97E6	2017-07-19 02:02:00+03	26200.00
7E97E7	2017-08-06 20:22:00+03	24600.00
7E97F6	2017-08-02 20:46:00+03	94800.00
7E9830	2017-06-29 16:56:00+03	21400.00
7E983C	2017-07-15 09:22:00+03	162700.00
7E9871	2017-07-11 00:24:00+03	131100.00
7E98DB	2017-07-15 23:57:00+03	27200.00
7E98E1	2017-08-08 17:46:00+03	23200.00
7E9917	2017-08-13 06:24:00+03	119300.00
7E9A25	2017-08-02 18:22:00+03	74100.00
7E9A92	2017-07-19 15:05:00+03	60800.00
7E9AFE	2017-07-30 19:33:00+03	28800.00
7E9B19	2017-07-27 13:28:00+03	52600.00
7E9B2E	2017-07-29 00:07:00+03	62600.00
7E9B3B	2017-07-29 17:49:00+03	265600.00
7E9BB1	2017-07-14 20:49:00+03	26200.00
7E9BFC	2017-08-10 12:40:00+03	23200.00
7E9C12	2017-07-19 03:57:00+03	32700.00
7E9C64	2017-07-20 09:07:00+03	57700.00
7E9C83	2017-08-04 19:36:00+03	420500.00
7E9C97	2017-07-30 10:24:00+03	62900.00
7E9CA3	2017-08-07 16:24:00+03	119500.00
7E9CF2	2017-07-02 23:18:00+03	25600.00
7E9D2D	2017-07-14 11:17:00+03	65900.00
7E9D48	2017-08-15 05:22:00+03	107100.00
7E9D4E	2017-07-24 12:58:00+03	113500.00
7E9D8E	2017-08-13 08:27:00+03	99200.00
7E9D9F	2017-07-05 22:05:00+03	133100.00
7E9E2E	2017-07-26 09:31:00+03	32800.00
7E9E2F	2017-07-22 15:27:00+03	44800.00
7E9E3C	2017-07-13 04:50:00+03	38400.00
7E9E53	2017-08-02 07:47:00+03	156100.00
7E9E6F	2017-07-30 04:40:00+03	186900.00
7E9E8E	2017-07-03 00:55:00+03	48100.00
7E9E95	2017-07-01 18:41:00+03	87700.00
7E9EAC	2017-07-20 14:42:00+03	194400.00
7E9EFC	2017-07-10 19:34:00+03	39800.00
7E9F4E	2017-07-18 02:05:00+03	165500.00
7E9F76	2017-07-01 07:40:00+03	55800.00
7E9F7B	2017-07-25 20:18:00+03	111600.00
7E9FAA	2017-07-10 18:52:00+03	135600.00
7E9FB6	2017-07-02 05:22:00+03	70600.00
7E9FD5	2017-07-25 21:29:00+03	12400.00
7EA063	2017-07-03 10:13:00+03	68100.00
7EA066	2017-07-31 23:32:00+03	342100.00
7EA079	2017-07-03 04:38:00+03	42800.00
7EA0D0	2017-07-02 23:59:00+03	123000.00
7EA105	2017-07-31 16:45:00+03	21200.00
7EA1F1	2017-07-24 15:33:00+03	98600.00
7EA23D	2017-07-17 20:09:00+03	179200.00
7EA29B	2017-07-21 22:18:00+03	92600.00
7EA2D5	2017-08-04 20:18:00+03	265600.00
7EA325	2017-07-16 15:59:00+03	52000.00
7EA35F	2017-07-24 12:48:00+03	89700.00
7EA388	2017-07-25 19:44:00+03	52400.00
7EA3AA	2017-07-24 14:41:00+03	36200.00
7EA413	2017-08-02 19:07:00+03	128800.00
7EA416	2017-07-15 07:53:00+03	100600.00
7EA43B	2017-07-04 21:21:00+03	257500.00
7EA4EB	2017-07-08 12:47:00+03	46000.00
7EA4FA	2017-07-17 04:39:00+03	31400.00
7EA53F	2017-07-26 07:20:00+03	22000.00
7EA5A1	2017-07-13 23:09:00+03	147100.00
7EA5D6	2017-07-20 18:52:00+03	56000.00
7EA64A	2017-07-05 05:25:00+03	116000.00
7EA689	2017-07-06 02:21:00+03	16400.00
7EA6DE	2017-08-13 13:28:00+03	12000.00
7EA727	2017-07-06 01:54:00+03	131600.00
7EA729	2017-08-13 18:51:00+03	31400.00
7EA747	2017-07-23 02:05:00+03	46400.00
7EA773	2017-08-08 23:51:00+03	52700.00
7EA7CC	2017-08-06 15:41:00+03	38800.00
7EA85F	2017-07-19 17:38:00+03	11300.00
7EA879	2017-08-03 23:27:00+03	28000.00
7EA8CE	2017-07-18 01:53:00+03	20400.00
7EA918	2017-08-04 07:58:00+03	8000.00
7EA96B	2017-08-06 18:02:00+03	94800.00
7EAA4C	2017-08-07 02:12:00+03	56000.00
7EAA97	2017-07-05 15:33:00+03	6300.00
7EAAB8	2017-06-28 22:19:00+03	192400.00
7EAACC	2017-08-08 23:08:00+03	67500.00
7EAADC	2017-08-15 06:55:00+03	115600.00
7EAAEB	2017-08-13 00:58:00+03	87100.00
7EAB27	2017-08-05 07:58:00+03	82900.00
7EAB5A	2017-07-31 14:33:00+03	94000.00
7EAB78	2017-07-13 10:23:00+03	37000.00
7EAB92	2017-08-02 23:07:00+03	46000.00
7EAB94	2017-07-13 08:43:00+03	91900.00
7EAC16	2017-07-21 02:48:00+03	31000.00
7EAC2B	2017-08-09 21:43:00+03	9800.00
7EACE4	2017-07-01 10:19:00+03	54700.00
7EAD03	2017-08-06 01:19:00+03	31600.00
7EAD15	2017-08-05 01:23:00+03	56000.00
7EAD51	2017-08-02 17:56:00+03	99200.00
7EAD67	2017-07-14 18:08:00+03	277000.00
7EADED	2017-08-08 21:06:00+03	43000.00
7EAE1A	2017-07-17 19:31:00+03	51200.00
7EAEBE	2017-08-09 22:00:00+03	55000.00
7EAEF8	2017-08-03 13:14:00+03	17800.00
7EAFBE	2017-07-26 16:52:00+03	173000.00
7EAFDC	2017-07-09 01:34:00+03	56000.00
7EAFF2	2017-07-17 12:46:00+03	36200.00
7EB022	2017-07-09 14:33:00+03	20600.00
7EB04C	2017-07-29 03:45:00+03	75300.00
7EB05D	2017-07-29 22:17:00+03	86300.00
7EB0CC	2017-07-21 22:52:00+03	113300.00
7EB0E2	2017-07-27 23:12:00+03	37500.00
7EB10B	2017-07-08 17:09:00+03	103800.00
7EB122	2017-07-24 00:24:00+03	111600.00
7EB143	2017-08-05 12:49:00+03	115600.00
7EB19F	2017-08-09 07:59:00+03	75500.00
7EB1CE	2017-07-25 08:13:00+03	44600.00
7EB1D1	2017-08-12 07:57:00+03	102100.00
7EB1DC	2017-07-27 01:25:00+03	67200.00
7EB1DF	2017-07-03 22:13:00+03	124400.00
7EB1E6	2017-07-14 16:17:00+03	27200.00
7EB295	2017-08-06 01:54:00+03	26000.00
7EB2B2	2017-07-18 16:47:00+03	75000.00
7EB311	2017-07-24 02:11:00+03	55800.00
7EB329	2017-07-25 07:27:00+03	265700.00
7EB35D	2017-08-05 04:58:00+03	133200.00
7EB3A5	2017-08-05 21:28:00+03	44000.00
7EB3AD	2017-08-04 20:36:00+03	90800.00
7EB41C	2017-07-23 03:20:00+03	90800.00
7EB426	2017-08-12 16:56:00+03	33100.00
7EB458	2017-07-30 04:03:00+03	215200.00
7EB461	2017-08-09 22:23:00+03	93400.00
7EB4FD	2017-07-19 01:56:00+03	99800.00
7EB56F	2017-07-29 13:11:00+03	23400.00
7EB574	2017-07-21 22:21:00+03	14000.00
7EB597	2017-07-30 03:23:00+03	76800.00
7EB5B3	2017-07-06 08:16:00+03	14400.00
7EB5BE	2017-07-20 18:04:00+03	95200.00
7EB5C5	2017-07-01 08:30:00+03	75300.00
7EB684	2017-07-08 19:19:00+03	28800.00
7EB736	2017-08-08 02:38:00+03	160200.00
7EB7E3	2017-08-10 05:10:00+03	144400.00
7EB84F	2017-07-21 23:36:00+03	23200.00
7EB8B3	2017-07-04 16:26:00+03	196000.00
7EB8BF	2017-07-26 23:51:00+03	199700.00
7EB933	2017-07-10 08:52:00+03	44000.00
7EB936	2017-07-13 17:54:00+03	20400.00
7EB9C7	2017-07-23 15:07:00+03	99900.00
7EB9D4	2017-08-06 12:29:00+03	99700.00
7EB9D6	2017-07-31 00:44:00+03	52700.00
7EB9E5	2017-07-07 22:25:00+03	58100.00
7EB9FB	2017-07-31 08:39:00+03	131900.00
7EBA09	2017-07-11 09:37:00+03	28800.00
7EBA6C	2017-07-10 21:09:00+03	53300.00
7EBA82	2017-07-24 22:22:00+03	47600.00
7EBABE	2017-07-18 20:21:00+03	79600.00
7EBAC1	2017-07-24 19:02:00+03	67600.00
7EBAD5	2017-07-05 07:31:00+03	45200.00
7EBAEE	2017-07-02 06:27:00+03	469200.00
7EBB25	2017-06-29 19:30:00+03	44000.00
7EBB26	2017-07-16 20:14:00+03	52300.00
7EBBBD	2017-07-15 19:50:00+03	175300.00
7EBBFB	2017-07-21 13:40:00+03	22000.00
7EBC7F	2017-07-01 22:47:00+03	56000.00
7EBCBC	2017-08-10 08:10:00+03	47000.00
7EBCC5	2017-07-23 23:03:00+03	65600.00
7EBCCC	2017-08-01 12:03:00+03	87000.00
7EBCDF	2017-08-12 00:33:00+03	397700.00
7EBD0E	2017-08-10 13:00:00+03	86800.00
7EBD24	2017-08-07 07:47:00+03	6800.00
7EBDAB	2017-07-29 23:52:00+03	58400.00
7EBDC3	2017-07-05 13:55:00+03	171400.00
7EBDD2	2017-08-12 09:51:00+03	70700.00
7EBDF0	2017-07-07 00:46:00+03	3700.00
7EBE01	2017-07-07 00:41:00+03	121400.00
7EBE91	2017-07-08 19:24:00+03	36200.00
7EBFB9	2017-08-11 11:26:00+03	34900.00
7EBFDE	2017-08-09 23:55:00+03	38400.00
7EBFE2	2017-07-12 10:38:00+03	68000.00
7EC000	2017-08-10 07:13:00+03	18600.00
7EC010	2017-07-02 04:57:00+03	305900.00
7EC090	2017-07-07 15:19:00+03	93900.00
7EC094	2017-08-08 04:01:00+03	26700.00
7EC096	2017-07-25 13:29:00+03	8000.00
7EC0A5	2017-08-05 15:36:00+03	36200.00
7EC0A6	2017-07-31 03:16:00+03	179400.00
7EC0BE	2017-07-30 13:17:00+03	357200.00
7EC10F	2017-07-27 07:53:00+03	78800.00
7EC121	2017-07-12 08:49:00+03	16000.00
7EC129	2017-08-05 00:58:00+03	50000.00
7EC14B	2017-08-02 08:08:00+03	59400.00
7EC1E7	2017-07-10 23:58:00+03	166100.00
7EC1ED	2017-08-12 12:47:00+03	14800.00
7EC2BF	2017-07-12 14:53:00+03	35200.00
7EC2E2	2017-07-25 13:11:00+03	62000.00
7EC308	2017-07-15 10:13:00+03	61800.00
7EC316	2017-07-12 03:17:00+03	204500.00
7EC32E	2017-08-05 21:26:00+03	369000.00
7EC441	2017-08-03 02:49:00+03	73600.00
7EC48B	2017-07-25 19:14:00+03	38600.00
7EC57C	2017-07-13 04:36:00+03	53300.00
7EC591	2017-08-04 02:38:00+03	58200.00
7EC632	2017-07-28 16:32:00+03	75000.00
7EC6C4	2017-07-13 01:30:00+03	26000.00
7EC70E	2017-07-02 15:51:00+03	62800.00
7EC742	2017-08-01 19:08:00+03	6000.00
7EC753	2017-07-27 08:56:00+03	50600.00
7EC75E	2017-08-03 07:40:00+03	47000.00
7EC783	2017-07-30 13:51:00+03	58600.00
7EC787	2017-07-31 23:59:00+03	83500.00
7EC7D2	2017-08-14 16:22:00+03	56000.00
7EC7E7	2017-08-06 05:54:00+03	46700.00
7EC7EB	2017-08-02 17:18:00+03	84500.00
7EC825	2017-07-08 07:55:00+03	135200.00
7EC827	2017-07-01 12:55:00+03	6800.00
7EC888	2017-08-07 15:24:00+03	43900.00
7EC9A4	2017-07-04 03:01:00+03	32200.00
7EC9DF	2017-08-09 17:21:00+03	26800.00
7ECA17	2017-07-01 00:32:00+03	32700.00
7ECA1D	2017-08-14 03:02:00+03	191400.00
7ECAA2	2017-07-07 03:35:00+03	39800.00
7ECB24	2017-07-14 03:12:00+03	70700.00
7ECB2F	2017-07-12 07:44:00+03	37700.00
7ECBB2	2017-07-20 17:50:00+03	152400.00
7ECBDA	2017-08-06 02:23:00+03	18000.00
7ECBF9	2017-07-06 17:14:00+03	6600.00
7ECC1E	2017-08-02 02:42:00+03	29000.00
7ECC2D	2017-07-16 09:21:00+03	46400.00
7ECC39	2017-06-30 06:43:00+03	198600.00
7ECC72	2017-07-14 09:22:00+03	12400.00
7ECCEC	2017-08-02 22:27:00+03	47200.00
7ECD10	2017-08-13 23:09:00+03	47400.00
7ECD61	2017-07-12 07:21:00+03	57500.00
7ECDEF	2017-08-05 23:22:00+03	37100.00
7ECEE4	2017-08-07 01:43:00+03	111600.00
7ECF86	2017-08-08 01:33:00+03	81500.00
7ECF9F	2017-07-12 08:24:00+03	56600.00
7ECFF8	2017-08-12 08:56:00+03	55000.00
7ED010	2017-07-19 00:00:00+03	67600.00
7ED034	2017-06-29 05:30:00+03	29600.00
7ED035	2017-07-19 05:43:00+03	55800.00
7ED0BE	2017-07-15 15:44:00+03	99200.00
7ED128	2017-08-07 00:33:00+03	14900.00
7ED13B	2017-07-03 18:20:00+03	72300.00
7ED1BA	2017-07-13 07:53:00+03	35200.00
7ED1D5	2017-07-02 13:27:00+03	227200.00
7ED20D	2017-07-08 04:18:00+03	57800.00
7ED22F	2017-07-10 21:43:00+03	54600.00
7ED24E	2017-08-13 12:56:00+03	113700.00
7ED24F	2017-08-12 11:12:00+03	99300.00
7ED256	2017-08-06 22:14:00+03	228400.00
7ED28D	2017-08-04 05:04:00+03	43000.00
7ED2C4	2017-07-07 14:39:00+03	62800.00
7ED2D0	2017-07-06 18:29:00+03	26000.00
7ED308	2017-08-11 18:34:00+03	14400.00
7ED335	2017-07-12 09:34:00+03	34200.00
7ED33F	2017-08-04 05:17:00+03	135600.00
7ED36C	2017-07-31 03:21:00+03	265600.00
7ED39C	2017-08-14 20:56:00+03	187400.00
7ED3CD	2017-07-04 01:36:00+03	8200.00
7ED3FC	2017-08-10 12:21:00+03	141300.00
7ED474	2017-07-11 15:00:00+03	28000.00
7ED4BC	2017-06-28 06:18:00+03	135200.00
7ED4EB	2017-07-16 04:57:00+03	163200.00
7ED5A0	2017-07-24 07:42:00+03	13400.00
7ED5A3	2017-08-15 10:47:00+03	44000.00
7ED5D8	2017-08-02 14:47:00+03	66300.00
7ED5EB	2017-08-07 16:46:00+03	24600.00
7ED60F	2017-08-04 14:49:00+03	25900.00
7ED625	2017-06-29 18:51:00+03	92400.00
7ED6CE	2017-07-15 12:02:00+03	246000.00
7ED6DE	2017-07-07 22:27:00+03	103600.00
7ED732	2017-07-18 22:36:00+03	27000.00
7ED776	2017-08-14 20:20:00+03	28800.00
7ED79D	2017-08-10 01:03:00+03	15100.00
7ED8BA	2017-07-12 05:37:00+03	34600.00
7ED8F4	2017-07-05 18:56:00+03	84000.00
7EDA0F	2017-07-14 04:23:00+03	26700.00
7EDA34	2017-07-01 02:48:00+03	59400.00
7EDA5F	2017-07-11 04:28:00+03	27300.00
7EDA9D	2017-07-17 13:43:00+03	133200.00
7EDAAD	2017-07-09 07:21:00+03	90800.00
7EDACF	2017-07-14 09:35:00+03	65500.00
7EDAFE	2017-07-09 16:02:00+03	118900.00
7EDB61	2017-07-07 12:48:00+03	76600.00
7EDB63	2017-06-30 22:47:00+03	136200.00
7EDB99	2017-07-02 03:33:00+03	38400.00
7EDC2F	2017-08-04 02:13:00+03	30400.00
7EDC94	2017-07-02 09:36:00+03	94800.00
7EDC98	2017-08-04 13:40:00+03	54400.00
7EDCB0	2017-07-12 00:40:00+03	219300.00
7EDCD6	2017-08-08 13:41:00+03	97700.00
7EDCF8	2017-07-28 23:39:00+03	34000.00
7EDD08	2017-08-01 10:09:00+03	36000.00
7EDD16	2017-08-10 02:09:00+03	42600.00
7EDD27	2017-08-07 19:29:00+03	32800.00
7EDD44	2017-07-12 18:39:00+03	37500.00
7EDDB2	2017-07-14 11:42:00+03	105400.00
7EDDC3	2017-07-18 23:30:00+03	161600.00
7EDDD0	2017-08-13 14:40:00+03	14000.00
7EDDD8	2017-07-10 17:51:00+03	15000.00
7EDDDE	2017-08-07 16:56:00+03	137600.00
7EDE49	2017-07-13 15:50:00+03	198800.00
7EDE95	2017-08-01 18:45:00+03	66600.00
7EDEA5	2017-07-02 12:15:00+03	23100.00
7EDEA7	2017-08-09 17:31:00+03	179500.00
7EDECF	2017-07-28 20:49:00+03	48500.00
7EDED2	2017-07-18 08:02:00+03	21200.00
7EDEF1	2017-08-08 07:31:00+03	16400.00
7EDF04	2017-07-13 07:41:00+03	76400.00
7EDF63	2017-08-09 23:32:00+03	25100.00
7EDF76	2017-07-16 18:42:00+03	102100.00
7EE07B	2017-07-31 06:26:00+03	76600.00
7EE1B8	2017-08-14 16:52:00+03	53700.00
7EE1CA	2017-08-09 13:10:00+03	66600.00
7EE268	2017-08-02 18:13:00+03	32700.00
7EE2E1	2017-07-20 18:49:00+03	8800.00
7EE2EB	2017-07-10 23:55:00+03	103800.00
7EE300	2017-07-06 23:42:00+03	92800.00
7EE330	2017-07-02 18:48:00+03	30200.00
7EE34D	2017-08-11 03:52:00+03	111600.00
7EE352	2017-08-01 07:51:00+03	15000.00
7EE39E	2017-07-04 09:25:00+03	161400.00
7EE3DF	2017-07-23 22:51:00+03	135200.00
7EE40B	2017-08-03 05:54:00+03	219900.00
7EE414	2017-08-05 02:45:00+03	90800.00
7EE446	2017-08-06 10:58:00+03	85000.00
7EE448	2017-07-02 09:07:00+03	196100.00
7EE4A4	2017-08-06 09:45:00+03	40800.00
7EE4C2	2017-07-15 11:18:00+03	40400.00
7EE587	2017-08-10 23:29:00+03	54000.00
7EE5B0	2017-07-09 18:09:00+03	32800.00
7EE5CC	2017-07-24 18:23:00+03	24700.00
7EE5D4	2017-08-02 12:12:00+03	37200.00
7EE60C	2017-07-07 11:03:00+03	37100.00
7EE61E	2017-06-27 15:17:00+03	514900.00
7EE677	2017-08-14 05:23:00+03	75600.00
7EE6DE	2017-07-27 22:41:00+03	94800.00
7EE70B	2017-08-04 19:24:00+03	8400.00
7EE773	2017-07-07 13:12:00+03	12600.00
7EE7F9	2017-07-23 14:31:00+03	240600.00
7EE85D	2017-08-14 13:53:00+03	222000.00
7EE88E	2017-07-14 09:25:00+03	68800.00
7EE8CB	2017-07-19 23:51:00+03	63300.00
7EE8CC	2017-08-09 07:55:00+03	14400.00
7EE8EC	2017-07-07 11:31:00+03	43200.00
7EE937	2017-07-17 03:45:00+03	105100.00
7EE956	2017-08-03 09:10:00+03	84500.00
7EE965	2017-07-05 11:54:00+03	71800.00
7EE9C9	2017-07-10 03:07:00+03	65600.00
7EE9F7	2017-07-06 08:07:00+03	18000.00
7EEA58	2017-06-29 05:37:00+03	89600.00
7EEAA3	2017-07-10 14:41:00+03	32200.00
7EEACE	2017-08-14 21:03:00+03	10700.00
7EEB4A	2017-07-23 23:31:00+03	28800.00
7EEBC3	2017-07-22 16:48:00+03	192400.00
7EEBFD	2017-07-09 15:32:00+03	74900.00
7EEC1A	2017-07-14 05:08:00+03	269400.00
7EEC53	2017-07-03 10:26:00+03	72300.00
7EEC81	2017-08-06 06:18:00+03	11000.00
7EECB3	2017-07-26 18:09:00+03	80900.00
7EECBC	2017-08-08 01:22:00+03	25100.00
7EECBF	2017-07-11 08:10:00+03	50000.00
7EECCE	2017-08-15 03:17:00+03	42600.00
7EECE2	2017-07-20 06:33:00+03	82900.00
7EED27	2017-07-15 11:36:00+03	25600.00
7EED2B	2017-07-09 00:48:00+03	412300.00
7EED31	2017-07-14 16:44:00+03	23200.00
7EED4D	2017-07-03 13:25:00+03	78000.00
7EED5B	2017-08-10 23:55:00+03	56000.00
7EEDA7	2017-07-30 06:26:00+03	47500.00
7EEDBE	2017-06-28 13:14:00+03	80300.00
7EEDF0	2017-07-25 09:07:00+03	164600.00
7EEDFE	2017-08-10 09:10:00+03	114700.00
7EEE46	2017-07-29 03:51:00+03	88600.00
7EEEFC	2017-08-01 19:49:00+03	48700.00
7EEF39	2017-08-01 09:08:00+03	26800.00
7EEF4E	2017-07-11 16:04:00+03	55800.00
7EEFFF	2017-07-23 04:31:00+03	54800.00
7EF017	2017-08-06 09:54:00+03	90000.00
7EF04E	2017-07-31 18:39:00+03	61800.00
7EF082	2017-07-14 12:55:00+03	136800.00
7EF0AA	2017-07-11 17:56:00+03	64800.00
7EF0BA	2017-08-12 17:31:00+03	25600.00
7EF13E	2017-08-15 08:13:00+03	52300.00
7EF150	2017-08-13 03:10:00+03	136100.00
7EF15D	2017-07-18 04:18:00+03	34000.00
7EF194	2017-07-06 05:04:00+03	56000.00
7EF1E4	2017-08-01 10:00:00+03	147000.00
7EF1EA	2017-07-31 19:01:00+03	71500.00
7EF1FA	2017-08-03 23:40:00+03	66600.00
7EF235	2017-07-15 13:10:00+03	40400.00
7EF28B	2017-06-30 15:31:00+03	123000.00
7EF29A	2017-08-05 16:17:00+03	35800.00
7EF2A5	2017-07-24 05:50:00+03	92100.00
7EF2B9	2017-07-04 22:54:00+03	32700.00
7EF2D4	2017-07-07 10:31:00+03	294200.00
7EF330	2017-07-18 11:19:00+03	128800.00
7EF341	2017-08-12 01:36:00+03	24400.00
7EF36B	2017-08-04 16:15:00+03	16400.00
7EF38F	2017-07-23 00:52:00+03	35400.00
7EF399	2017-07-19 04:03:00+03	181600.00
7EF3C7	2017-08-14 12:30:00+03	36700.00
7EF3CB	2017-08-01 12:45:00+03	18000.00
7EF3EE	2017-08-12 06:10:00+03	42800.00
7EF3F6	2017-08-07 05:16:00+03	93900.00
7EF406	2017-08-09 13:32:00+03	49900.00
7EF48F	2017-08-12 08:25:00+03	37100.00
7EF4BA	2017-07-06 16:19:00+03	30200.00
7EF534	2017-07-25 15:03:00+03	130400.00
7EF538	2017-07-06 07:49:00+03	45200.00
7EF53E	2017-07-09 14:29:00+03	68800.00
7EF552	2017-07-12 10:14:00+03	99300.00
7EF5EE	2017-07-07 06:08:00+03	66000.00
7EF5F9	2017-07-13 10:00:00+03	58700.00
7EF6BC	2017-07-26 04:26:00+03	27200.00
7EF6BE	2017-07-13 10:49:00+03	39800.00
7EF73C	2017-08-05 13:06:00+03	115700.00
7EF759	2017-08-12 10:09:00+03	37900.00
7EF768	2017-07-31 04:19:00+03	31900.00
7EF782	2017-07-29 00:34:00+03	77000.00
7EF796	2017-07-12 08:19:00+03	16400.00
7EF7ED	2017-07-20 02:17:00+03	47600.00
7EF83A	2017-08-12 08:14:00+03	24400.00
7EF847	2017-07-08 02:00:00+03	57800.00
7EF84C	2017-08-06 21:54:00+03	36900.00
7EF853	2017-08-08 16:45:00+03	206800.00
7EF892	2017-07-21 08:02:00+03	14800.00
7EF936	2017-06-30 06:42:00+03	55800.00
7EF942	2017-07-09 16:12:00+03	34000.00
7EFA22	2017-08-07 13:17:00+03	44800.00
7EFA32	2017-07-22 21:02:00+03	73300.00
7EFA7A	2017-07-26 06:19:00+03	77200.00
7EFAC6	2017-07-06 12:59:00+03	47000.00
7EFAD1	2017-08-07 20:54:00+03	46000.00
7EFAF7	2017-08-02 22:06:00+03	282400.00
7EFAFD	2017-08-09 10:46:00+03	27900.00
7EFB75	2017-07-11 19:28:00+03	92400.00
7EFBDE	2017-08-01 18:26:00+03	89700.00
7EFC64	2017-07-12 16:11:00+03	68400.00
7EFCD9	2017-08-07 07:09:00+03	38800.00
7EFCE8	2017-07-05 23:05:00+03	390400.00
7EFD07	2017-07-19 21:01:00+03	44800.00
7EFD22	2017-08-07 14:58:00+03	58600.00
7EFD26	2017-07-27 13:54:00+03	68800.00
7EFD42	2017-08-08 01:57:00+03	96200.00
7EFD9C	2017-08-11 00:36:00+03	59000.00
7EFDD4	2017-07-03 13:29:00+03	52000.00
7EFE0E	2017-07-02 01:13:00+03	81300.00
7EFE32	2017-07-06 01:28:00+03	229500.00
7EFE42	2017-07-25 23:31:00+03	28000.00
7EFE4F	2017-07-15 02:47:00+03	69600.00
7EFE78	2017-07-07 00:29:00+03	166000.00
7EFE7E	2017-07-23 20:01:00+03	46200.00
7EFEB7	2017-08-14 21:09:00+03	46300.00
7EFEE3	2017-07-12 02:43:00+03	140300.00
7EFEE4	2017-07-21 13:09:00+03	32400.00
7EFF12	2017-08-02 07:10:00+03	79000.00
7EFF81	2017-06-29 01:19:00+03	81700.00
7EFFB4	2017-07-03 16:29:00+03	98200.00
7F00A6	2017-07-02 21:57:00+03	35200.00
7F00B2	2017-07-29 07:03:00+03	50300.00
7F00C3	2017-07-18 15:14:00+03	112000.00
7F00E3	2017-08-14 11:56:00+03	58500.00
7F00F4	2017-08-13 19:04:00+03	58000.00
7F011E	2017-08-07 12:49:00+03	20400.00
7F0132	2017-07-31 21:33:00+03	21200.00
7F016F	2017-07-05 02:48:00+03	13300.00
7F0192	2017-07-22 23:05:00+03	228700.00
7F0226	2017-07-21 09:33:00+03	87200.00
7F022B	2017-07-30 19:01:00+03	28700.00
7F0230	2017-07-28 23:31:00+03	65200.00
7F0250	2017-07-23 20:33:00+03	60400.00
7F02A6	2017-07-03 10:45:00+03	43100.00
7F02F9	2017-08-02 12:18:00+03	160800.00
7F02FE	2017-08-12 06:07:00+03	182200.00
7F037D	2017-08-05 10:04:00+03	86400.00
7F039B	2017-07-26 20:44:00+03	15800.00
7F03ED	2017-08-06 13:52:00+03	86400.00
7F0454	2017-07-07 19:04:00+03	70400.00
7F04B6	2017-08-06 12:09:00+03	101200.00
7F04C6	2017-08-04 15:14:00+03	46300.00
7F04D3	2017-07-23 15:58:00+03	44000.00
7F0521	2017-08-13 20:20:00+03	273000.00
7F056E	2017-08-10 18:09:00+03	89600.00
7F05A1	2017-07-26 23:50:00+03	36200.00
7F05C3	2017-07-22 08:52:00+03	66600.00
7F0612	2017-07-05 06:39:00+03	23200.00
7F06D0	2017-08-08 19:22:00+03	18400.00
7F06F4	2017-08-14 19:47:00+03	24400.00
7F0726	2017-07-01 05:24:00+03	8000.00
7F0738	2017-07-07 21:20:00+03	101800.00
7F079A	2017-07-23 01:24:00+03	31400.00
7F07CA	2017-07-28 23:03:00+03	56900.00
7F080A	2017-07-15 20:28:00+03	78100.00
7F0899	2017-07-09 01:11:00+03	6000.00
7F08EA	2017-08-12 09:50:00+03	22600.00
7F08F2	2017-07-14 12:12:00+03	135200.00
7F090A	2017-08-13 07:48:00+03	136200.00
7F091B	2017-07-12 04:47:00+03	13400.00
7F0982	2017-07-17 06:29:00+03	123000.00
7F09B5	2017-07-11 15:07:00+03	23600.00
7F09B7	2017-07-04 03:07:00+03	28200.00
7F09C0	2017-08-13 00:37:00+03	553900.00
7F09F8	2017-07-09 06:47:00+03	24400.00
7F0A07	2017-07-02 16:30:00+03	28800.00
7F0A37	2017-08-07 16:10:00+03	75300.00
7F0A49	2017-07-28 18:42:00+03	44000.00
7F0A6F	2017-07-17 13:06:00+03	24400.00
7F0A88	2017-07-10 10:51:00+03	24400.00
7F0B6A	2017-07-12 05:01:00+03	19600.00
7F0B7D	2017-07-15 17:49:00+03	92000.00
7F0B87	2017-07-14 12:45:00+03	14000.00
7F0BA7	2017-07-04 19:12:00+03	77900.00
7F0BC4	2017-07-09 04:50:00+03	39300.00
7F0BD8	2017-08-13 01:43:00+03	19600.00
7F0C09	2017-08-10 06:40:00+03	75300.00
7F0C22	2017-08-02 09:23:00+03	189200.00
7F0C2D	2017-07-07 03:52:00+03	110500.00
7F0CE2	2017-08-08 16:26:00+03	96100.00
7F0CFA	2017-07-27 15:50:00+03	59800.00
7F0D36	2017-07-17 09:21:00+03	56100.00
7F0D3E	2017-07-12 22:30:00+03	97600.00
7F0E0B	2017-08-06 17:31:00+03	207000.00
7F0E21	2017-07-02 03:06:00+03	70200.00
7F0E34	2017-08-13 16:00:00+03	144400.00
7F0E42	2017-07-30 07:26:00+03	102100.00
7F0EB2	2017-07-15 13:10:00+03	270200.00
7F0EC2	2017-07-06 12:58:00+03	40600.00
7F0EF5	2017-08-05 08:19:00+03	27700.00
7F0FF5	2017-07-25 00:04:00+03	57600.00
7F1019	2017-08-13 21:41:00+03	132800.00
7F10AF	2017-07-25 20:49:00+03	107500.00
7F10CA	2017-07-24 01:25:00+03	138000.00
7F10CC	2017-08-02 15:22:00+03	29100.00
7F10FA	2017-07-15 22:42:00+03	10800.00
7F110A	2017-07-09 23:04:00+03	23400.00
7F1119	2017-08-14 10:30:00+03	26800.00
7F111E	2017-07-02 00:03:00+03	6300.00
7F1128	2017-07-20 22:00:00+03	46300.00
7F115C	2017-08-03 23:55:00+03	404500.00
7F117F	2017-07-17 14:37:00+03	44800.00
7F11A9	2017-08-13 08:32:00+03	124200.00
7F11B4	2017-07-23 02:05:00+03	136000.00
7F11C0	2017-07-28 20:28:00+03	59200.00
7F11D5	2017-07-19 19:31:00+03	36800.00
7F124C	2017-07-27 08:02:00+03	22000.00
7F12C8	2017-08-10 06:22:00+03	111100.00
7F12EC	2017-08-10 03:18:00+03	38500.00
7F12F3	2017-07-29 01:19:00+03	38800.00
7F1302	2017-08-04 10:38:00+03	6700.00
7F130A	2017-08-05 03:57:00+03	34600.00
7F141A	2017-08-13 09:20:00+03	12000.00
7F1491	2017-07-02 19:57:00+03	20200.00
7F14CE	2017-07-01 09:39:00+03	21600.00
7F150C	2017-07-05 02:39:00+03	301800.00
7F1538	2017-08-12 17:31:00+03	45100.00
7F1573	2017-07-10 07:07:00+03	75600.00
7F15DC	2017-08-08 06:25:00+03	40600.00
7F1629	2017-07-16 06:32:00+03	23600.00
7F1649	2017-08-03 02:36:00+03	43900.00
7F165A	2017-07-31 08:33:00+03	57200.00
7F1685	2017-07-13 08:25:00+03	123600.00
7F16E0	2017-07-16 20:38:00+03	52400.00
7F16FD	2017-08-02 22:02:00+03	23600.00
7F1708	2017-07-08 01:26:00+03	44800.00
7F1725	2017-07-10 00:05:00+03	81300.00
7F1852	2017-07-22 04:15:00+03	129200.00
7F1964	2017-07-13 14:41:00+03	59200.00
7F198A	2017-07-15 03:21:00+03	46200.00
7F198F	2017-08-14 17:22:00+03	17000.00
7F19AF	2017-07-27 08:26:00+03	59000.00
7F19E0	2017-08-01 22:49:00+03	32700.00
7F1AC9	2017-07-09 05:12:00+03	37900.00
7F1B05	2017-07-23 04:15:00+03	14000.00
7F1B10	2017-08-15 01:52:00+03	39200.00
7F1B21	2017-07-21 08:34:00+03	46500.00
7F1B6C	2017-07-13 21:43:00+03	6600.00
7F1B8D	2017-07-19 03:58:00+03	92800.00
7F1B9B	2017-07-19 07:19:00+03	27200.00
7F1BD5	2017-07-27 12:36:00+03	88500.00
7F1BEC	2017-07-23 17:04:00+03	70400.00
7F1C46	2017-08-14 15:09:00+03	98300.00
7F1D0B	2017-08-11 02:07:00+03	25800.00
7F1D61	2017-07-27 09:52:00+03	98400.00
7F1D7A	2017-07-26 18:37:00+03	233800.00
7F1DC7	2017-07-18 06:29:00+03	170000.00
7F1DCE	2017-07-29 07:26:00+03	102300.00
7F1DCF	2017-08-03 14:17:00+03	38600.00
7F1E0E	2017-07-09 09:35:00+03	60400.00
7F1E23	2017-08-13 00:01:00+03	10800.00
7F1E6F	2017-08-08 00:48:00+03	36200.00
7F1E75	2017-07-19 03:15:00+03	281500.00
7F1E97	2017-07-11 09:14:00+03	111600.00
7F1EA1	2017-07-31 20:22:00+03	55800.00
7F1EAC	2017-07-23 15:11:00+03	142300.00
7F1ECB	2017-07-03 21:54:00+03	114400.00
7F1EE1	2017-08-02 03:21:00+03	40600.00
7F1F55	2017-07-21 08:39:00+03	47200.00
7F1F9B	2017-08-13 15:09:00+03	263200.00
7F1FAD	2017-07-12 09:20:00+03	270000.00
7F2015	2017-07-15 01:34:00+03	43200.00
7F209B	2017-08-03 16:17:00+03	40200.00
7F20A1	2017-07-18 19:52:00+03	44000.00
7F20B0	2017-07-07 12:33:00+03	13400.00
7F20CA	2017-08-02 23:14:00+03	46200.00
7F2175	2017-07-19 23:35:00+03	45100.00
7F21CE	2017-08-04 21:39:00+03	52900.00
7F21EC	2017-07-01 19:32:00+03	398300.00
7F223A	2017-07-07 03:01:00+03	249100.00
7F22D3	2017-08-10 21:37:00+03	28000.00
7F22EA	2017-07-06 05:34:00+03	188000.00
7F22FC	2017-07-13 11:52:00+03	96800.00
7F2346	2017-07-26 15:53:00+03	97000.00
7F234E	2017-07-25 06:09:00+03	57500.00
7F2368	2017-07-17 09:31:00+03	52000.00
7F23CF	2017-07-04 06:26:00+03	60400.00
7F2493	2017-07-22 21:05:00+03	15000.00
7F24B8	2017-07-13 18:57:00+03	102700.00
7F24E5	2017-07-05 00:33:00+03	45200.00
7F2534	2017-07-26 04:57:00+03	129000.00
7F2573	2017-07-18 05:14:00+03	92800.00
7F257C	2017-07-05 16:30:00+03	105000.00
7F258C	2017-08-15 16:15:00+03	67600.00
7F258D	2017-08-13 10:06:00+03	15400.00
7F25B5	2017-08-08 20:21:00+03	46800.00
7F25CD	2017-07-22 16:43:00+03	79600.00
7F2625	2017-08-05 20:47:00+03	31400.00
7F2660	2017-07-20 15:21:00+03	26000.00
7F2733	2017-08-01 12:33:00+03	88600.00
7F2772	2017-07-27 21:28:00+03	12600.00
7F27A5	2017-07-07 16:55:00+03	92800.00
7F27D1	2017-07-09 05:34:00+03	426600.00
7F27DA	2017-07-17 23:52:00+03	57600.00
7F2802	2017-08-14 19:54:00+03	39600.00
7F28C4	2017-07-24 04:56:00+03	155600.00
7F291A	2017-07-06 21:35:00+03	59600.00
7F299F	2017-07-02 06:18:00+03	106000.00
7F2A5F	2017-08-01 09:36:00+03	98400.00
7F2AC0	2017-08-04 03:36:00+03	35800.00
7F2ACF	2017-08-04 06:58:00+03	118000.00
7F2B29	2017-07-22 12:17:00+03	148200.00
7F2B7B	2017-08-03 12:21:00+03	86600.00
7F2BA2	2017-07-08 17:53:00+03	58600.00
7F2BDA	2017-07-29 14:04:00+03	110000.00
7F2C43	2017-07-18 00:09:00+03	86600.00
7F2C4D	2017-08-10 10:10:00+03	16400.00
7F2C51	2017-07-24 03:38:00+03	28000.00
7F2CE5	2017-07-02 16:12:00+03	123000.00
7F2DB9	2017-07-02 14:08:00+03	23600.00
7F2DCB	2017-08-15 09:07:00+03	56800.00
7F2DD1	2017-07-26 11:31:00+03	39800.00
7F2DF5	2017-07-18 22:14:00+03	111600.00
7F2E89	2017-07-03 13:30:00+03	119700.00
7F2E8E	2017-07-09 22:45:00+03	57400.00
7F2F21	2017-08-13 06:15:00+03	81300.00
7F2F28	2017-07-25 11:50:00+03	198400.00
7F2F63	2017-07-19 08:26:00+03	94700.00
7F2FBF	2017-07-13 11:52:00+03	64600.00
7F2FF9	2017-07-29 09:55:00+03	33200.00
7F302A	2017-07-09 17:13:00+03	136200.00
7F308F	2017-07-18 03:32:00+03	81600.00
7F313D	2017-07-16 21:04:00+03	53300.00
7F3153	2017-07-08 00:53:00+03	103200.00
7F31B2	2017-07-02 05:34:00+03	46000.00
7F32B7	2017-08-12 09:28:00+03	12000.00
7F336A	2017-07-31 11:58:00+03	45200.00
7F3391	2017-08-03 09:29:00+03	46700.00
7F33BD	2017-06-24 07:44:00+03	131100.00
7F33E6	2017-07-08 20:50:00+03	480600.00
7F34C5	2017-07-15 17:31:00+03	112000.00
7F352F	2017-08-11 22:56:00+03	97600.00
7F353A	2017-07-09 12:46:00+03	21400.00
7F35C4	2017-07-04 01:13:00+03	86300.00
7F3653	2017-08-08 09:39:00+03	166900.00
7F3682	2017-07-03 21:05:00+03	23100.00
7F3708	2017-08-01 13:40:00+03	43200.00
7F3742	2017-07-21 09:34:00+03	14300.00
7F379B	2017-08-06 04:03:00+03	43200.00
7F37C1	2017-08-12 10:27:00+03	42800.00
7F3801	2017-08-03 14:51:00+03	14000.00
7F3813	2017-08-04 00:05:00+03	52300.00
7F384C	2017-08-11 13:21:00+03	20400.00
7F3867	2017-07-30 08:31:00+03	53500.00
7F386F	2017-07-18 05:35:00+03	24400.00
7F38B5	2017-07-29 13:39:00+03	155600.00
7F3A39	2017-07-12 01:34:00+03	112000.00
7F3AB2	2017-08-15 09:16:00+03	26800.00
7F3AC1	2017-07-30 22:11:00+03	132800.00
7F3B49	2017-08-13 20:04:00+03	40200.00
7F3C63	2017-07-25 16:43:00+03	57800.00
7F3CFE	2017-08-05 00:22:00+03	11600.00
7F3D1A	2017-07-25 14:48:00+03	3800.00
7F3DBD	2017-07-10 16:52:00+03	61800.00
7F3E7D	2017-07-17 20:47:00+03	59900.00
7F3EA2	2017-08-04 20:08:00+03	44600.00
7F3EAE	2017-08-13 20:12:00+03	8400.00
7F3EAF	2017-07-13 00:54:00+03	13200.00
7F3EE0	2017-07-31 00:07:00+03	32800.00
7F3EEC	2017-07-02 06:00:00+03	26800.00
7F3F12	2017-07-23 20:00:00+03	32800.00
7F3F49	2017-07-16 13:38:00+03	69500.00
7F3F62	2017-06-30 14:13:00+03	92600.00
7F3F83	2017-07-26 16:35:00+03	46000.00
7F3F91	2017-08-10 11:39:00+03	16400.00
7F3FEC	2017-07-13 07:18:00+03	188100.00
7F4092	2017-08-04 06:03:00+03	135400.00
7F4117	2017-07-20 10:31:00+03	57500.00
7F4135	2017-08-09 18:07:00+03	22000.00
7F421C	2017-08-01 15:02:00+03	41600.00
7F425B	2017-07-09 16:25:00+03	53700.00
7F42A7	2017-07-04 13:22:00+03	233800.00
7F42BD	2017-07-04 12:12:00+03	24400.00
7F42D5	2017-08-12 11:57:00+03	14400.00
7F4314	2017-07-11 06:04:00+03	89700.00
7F4340	2017-07-14 02:53:00+03	35600.00
7F4386	2017-07-04 06:06:00+03	135600.00
7F43A8	2017-07-07 21:58:00+03	531300.00
7F43F0	2017-07-27 05:14:00+03	26600.00
7F4439	2017-07-23 01:14:00+03	194000.00
7F445E	2017-07-17 01:44:00+03	283200.00
7F4498	2017-07-24 00:55:00+03	67600.00
7F458F	2017-08-07 23:18:00+03	112000.00
7F45CB	2017-08-14 11:07:00+03	46800.00
7F45F2	2017-07-23 15:24:00+03	28000.00
7F4625	2017-08-04 04:24:00+03	671100.00
7F4662	2017-07-23 00:12:00+03	83000.00
7F4695	2017-07-28 05:02:00+03	59900.00
7F46D8	2017-08-03 18:53:00+03	124300.00
7F4725	2017-08-11 22:16:00+03	169900.00
7F477B	2017-08-15 10:52:00+03	14100.00
7F47E5	2017-07-24 10:57:00+03	56000.00
7F485A	2017-08-02 06:03:00+03	106400.00
7F486C	2017-08-14 13:10:00+03	25400.00
7F4891	2017-07-01 22:25:00+03	36600.00
7F48DD	2017-08-06 03:47:00+03	75600.00
7F4917	2017-08-12 09:11:00+03	28800.00
7F4960	2017-07-29 13:27:00+03	53600.00
7F49A1	2017-07-14 10:11:00+03	99200.00
7F49A7	2017-07-17 15:12:00+03	58200.00
7F49B1	2017-07-29 21:40:00+03	28000.00
7F4A55	2017-08-07 10:24:00+03	24800.00
7F4AFE	2017-07-13 02:26:00+03	136500.00
7F4B22	2017-07-23 20:03:00+03	17800.00
7F4B44	2017-08-02 17:28:00+03	73300.00
7F4B55	2017-07-29 10:21:00+03	56000.00
7F4B91	2017-07-05 05:16:00+03	28000.00
7F4BAE	2017-07-25 18:14:00+03	39300.00
7F4BD3	2017-08-09 19:01:00+03	65500.00
7F4BDD	2017-07-26 14:08:00+03	112000.00
7F4D6A	2017-07-29 08:16:00+03	22100.00
7F4D95	2017-07-27 08:42:00+03	13600.00
7F4DA9	2017-08-13 17:24:00+03	44000.00
7F4DF5	2017-07-19 11:06:00+03	58200.00
7F4EA0	2017-08-01 09:52:00+03	115700.00
7F4EAD	2017-06-27 19:04:00+03	12600.00
7F4EBB	2017-07-08 22:09:00+03	56000.00
7F4EE4	2017-07-13 22:27:00+03	156600.00
7F4EE8	2017-07-23 13:15:00+03	56600.00
7F4EFE	2017-07-06 11:00:00+03	131600.00
7F4F04	2017-07-20 15:46:00+03	52700.00
7F4F08	2017-08-08 16:27:00+03	109200.00
7F4F6D	2017-08-15 02:24:00+03	34000.00
7F4FB9	2017-07-24 04:13:00+03	20200.00
7F5014	2017-08-12 06:34:00+03	23400.00
7F5018	2017-08-05 11:06:00+03	170700.00
7F516F	2017-07-23 17:58:00+03	195600.00
7F5177	2017-08-09 03:34:00+03	26000.00
7F51AF	2017-07-03 12:05:00+03	37100.00
7F51F4	2017-07-20 20:53:00+03	15400.00
7F5217	2017-07-17 22:53:00+03	81600.00
7F521E	2017-07-09 10:05:00+03	27200.00
7F5229	2017-07-27 05:16:00+03	100000.00
7F5252	2017-07-28 07:24:00+03	130400.00
7F531A	2017-07-31 15:12:00+03	137600.00
7F532A	2017-07-17 13:15:00+03	206400.00
7F534A	2017-08-03 15:51:00+03	23400.00
7F5398	2017-08-04 07:24:00+03	67600.00
7F53CC	2017-07-21 07:46:00+03	50300.00
7F545A	2017-07-05 12:31:00+03	24800.00
7F54B0	2017-07-27 15:54:00+03	56000.00
7F5536	2017-07-23 21:07:00+03	34700.00
7F5545	2017-07-24 02:42:00+03	193100.00
7F5596	2017-06-29 11:11:00+03	92800.00
7F55AF	2017-07-01 09:44:00+03	345700.00
7F5680	2017-08-04 10:33:00+03	27300.00
7F56CA	2017-07-31 10:16:00+03	28600.00
7F56DD	2017-08-07 02:20:00+03	83200.00
7F56E2	2017-07-24 18:56:00+03	62600.00
7F572A	2017-07-24 03:50:00+03	50800.00
7F5779	2017-07-20 13:21:00+03	52300.00
7F5783	2017-08-12 12:05:00+03	134400.00
7F57AF	2017-07-18 15:42:00+03	135400.00
7F5820	2017-07-07 02:58:00+03	37900.00
7F5824	2017-08-12 07:15:00+03	33200.00
7F5837	2017-08-01 18:51:00+03	101200.00
7F5895	2017-07-25 05:24:00+03	75300.00
7F58C9	2017-07-10 23:36:00+03	70600.00
7F5917	2017-08-06 18:15:00+03	17800.00
7F591E	2017-08-14 19:00:00+03	18400.00
7F5939	2017-07-15 04:35:00+03	38800.00
7F5979	2017-07-18 16:48:00+03	28000.00
7F597E	2017-07-07 08:16:00+03	111700.00
7F598D	2017-07-30 07:23:00+03	152600.00
7F59CA	2017-07-29 13:09:00+03	61800.00
7F5A00	2017-08-04 02:16:00+03	70500.00
7F5A0C	2017-07-05 10:09:00+03	28000.00
7F5A0D	2017-08-14 14:42:00+03	76800.00
7F5A5E	2017-07-14 20:56:00+03	406100.00
7F5AAC	2017-07-12 08:34:00+03	23400.00
7F5ADC	2017-08-02 14:47:00+03	29600.00
7F5B2B	2017-07-10 22:18:00+03	6600.00
7F5B4B	2017-08-01 21:13:00+03	16400.00
7F5B4C	2017-07-02 01:11:00+03	23200.00
7F5B5D	2017-07-11 15:42:00+03	142800.00
7F5BD4	2017-07-16 02:53:00+03	103600.00
7F5C07	2017-07-23 06:16:00+03	12000.00
7F5C13	2017-07-07 12:17:00+03	249200.00
7F5C50	2017-07-04 08:01:00+03	13400.00
7F5C5E	2017-07-24 21:56:00+03	167400.00
7F5C8C	2017-07-18 12:43:00+03	242700.00
7F5CCB	2017-07-19 01:27:00+03	98800.00
7F5D36	2017-08-04 14:37:00+03	114900.00
7F5D68	2017-07-16 01:55:00+03	73200.00
7F5D7B	2017-08-04 21:31:00+03	7300.00
7F5D92	2017-08-04 16:09:00+03	47000.00
7F5D96	2017-07-31 16:05:00+03	13400.00
7F5D9E	2017-08-06 04:34:00+03	129200.00
7F5DE5	2017-07-14 14:43:00+03	80000.00
7F5E6C	2017-06-25 05:30:00+03	52100.00
7F5EA4	2017-07-13 15:24:00+03	84700.00
7F5EC7	2017-08-06 12:59:00+03	31600.00
7F5F31	2017-08-03 13:37:00+03	30900.00
7F5F54	2017-08-14 00:22:00+03	19600.00
7F5FBD	2017-08-01 04:21:00+03	86400.00
7F607F	2017-07-23 12:30:00+03	7400.00
7F6092	2017-08-07 12:02:00+03	34000.00
7F60B2	2017-07-16 07:00:00+03	57800.00
7F60BC	2017-07-08 14:29:00+03	113200.00
7F6100	2017-08-02 08:19:00+03	75300.00
7F61CB	2017-07-17 00:50:00+03	8400.00
7F61CE	2017-07-06 07:56:00+03	13400.00
7F61F1	2017-07-16 17:56:00+03	46400.00
7F620D	2017-08-11 14:55:00+03	48900.00
7F6271	2017-07-28 09:12:00+03	26800.00
7F6285	2017-08-09 02:55:00+03	14700.00
7F62AF	2017-07-29 02:02:00+03	68800.00
7F6307	2017-08-09 14:19:00+03	67600.00
7F6309	2017-07-26 03:08:00+03	35200.00
7F6332	2017-08-06 20:47:00+03	58900.00
7F633E	2017-08-06 12:03:00+03	19600.00
7F636B	2017-07-26 15:16:00+03	39200.00
7F6383	2017-07-08 02:37:00+03	56000.00
7F63A0	2017-08-10 03:24:00+03	83200.00
7F63C4	2017-07-24 11:29:00+03	112000.00
7F643A	2017-07-01 22:47:00+03	26000.00
7F64CF	2017-08-06 10:00:00+03	53600.00
7F6566	2017-08-10 16:49:00+03	8400.00
7F6587	2017-07-12 22:05:00+03	46400.00
7F65B6	2017-07-21 06:20:00+03	85000.00
7F65BB	2017-07-09 19:20:00+03	29600.00
7F65D8	2017-07-04 19:58:00+03	34200.00
7F6673	2017-08-14 09:52:00+03	61400.00
7F66AE	2017-08-14 15:46:00+03	62800.00
7F66DE	2017-07-12 21:18:00+03	44800.00
7F6722	2017-07-27 18:54:00+03	14000.00
7F676F	2017-08-02 22:50:00+03	12600.00
7F67C9	2017-08-04 15:10:00+03	54800.00
7F67F3	2017-07-20 05:36:00+03	55800.00
7F6869	2017-08-02 13:59:00+03	29800.00
7F6893	2017-08-13 13:58:00+03	118100.00
7F690B	2017-08-10 20:28:00+03	36200.00
7F691B	2017-07-01 13:32:00+03	92700.00
7F6948	2017-08-01 15:38:00+03	246000.00
7F6951	2017-08-01 07:24:00+03	28000.00
7F6988	2017-07-14 00:11:00+03	64600.00
7F69EE	2017-07-15 00:32:00+03	53900.00
7F6A2D	2017-07-17 07:20:00+03	103200.00
7F6A85	2017-08-12 08:25:00+03	26000.00
7F6A8C	2017-08-10 23:16:00+03	135600.00
7F6AED	2017-07-05 14:48:00+03	102800.00
7F6B14	2017-07-14 19:14:00+03	240600.00
7F6B29	2017-07-23 05:54:00+03	29600.00
7F6B4C	2017-07-31 10:21:00+03	23600.00
7F6B9C	2017-08-06 03:41:00+03	168000.00
7F6BC2	2017-07-19 23:50:00+03	56000.00
7F6C1A	2017-07-14 12:47:00+03	173900.00
7F6C79	2017-08-02 03:55:00+03	57400.00
7F6C83	2017-07-26 09:44:00+03	25100.00
7F6CBF	2017-08-11 12:07:00+03	82900.00
7F6D05	2017-08-11 13:59:00+03	12000.00
7F6D11	2017-07-29 17:57:00+03	46400.00
7F6D54	2017-07-13 08:26:00+03	143600.00
7F6D60	2017-08-06 18:50:00+03	22000.00
7F6DA4	2017-07-05 23:07:00+03	131300.00
7F6DD6	2017-07-31 19:36:00+03	28700.00
7F6DF0	2017-07-24 13:08:00+03	49600.00
7F6DFE	2017-07-17 02:49:00+03	109200.00
7F6E56	2017-07-30 17:59:00+03	27900.00
7F6E69	2017-07-09 06:29:00+03	198400.00
7F6E6E	2017-07-02 21:44:00+03	196000.00
7F6E79	2017-07-06 00:10:00+03	6600.00
7F6EE6	2017-08-02 08:19:00+03	56000.00
7F6EE9	2017-07-17 12:35:00+03	57600.00
7F6F1E	2017-07-03 21:33:00+03	35300.00
7F6F24	2017-08-12 16:09:00+03	28800.00
7F6F3D	2017-07-08 05:13:00+03	64200.00
7F6F45	2017-08-10 00:57:00+03	13600.00
7F6FE1	2017-07-02 06:32:00+03	38800.00
7F6FF2	2017-07-31 12:00:00+03	29600.00
7F6FF8	2017-08-11 10:58:00+03	19600.00
7F7001	2017-07-09 07:57:00+03	118900.00
7F7057	2017-07-27 22:41:00+03	31400.00
7F70A9	2017-08-11 08:09:00+03	6700.00
7F7104	2017-07-20 21:30:00+03	75600.00
7F7126	2017-07-10 06:13:00+03	38800.00
7F717D	2017-07-13 13:06:00+03	40800.00
7F71F6	2017-07-15 06:58:00+03	48800.00
7F71F9	2017-07-27 07:55:00+03	20200.00
7F7208	2017-08-05 14:49:00+03	57400.00
7F7246	2017-07-23 11:44:00+03	48800.00
7F726E	2017-08-15 01:56:00+03	122600.00
7F72B9	2017-06-29 18:23:00+03	36500.00
7F72FB	2017-07-10 12:40:00+03	212000.00
7F733E	2017-08-15 12:54:00+03	32800.00
7F7347	2017-08-03 12:30:00+03	61800.00
7F735F	2017-07-25 00:09:00+03	14000.00
7F73CD	2017-07-12 18:29:00+03	15400.00
7F73F1	2017-07-12 10:29:00+03	111600.00
7F73F6	2017-08-10 16:40:00+03	87200.00
7F7425	2017-07-14 20:14:00+03	28800.00
7F7448	2017-08-04 06:57:00+03	31400.00
7F748A	2017-07-14 22:23:00+03	34000.00
7F7549	2017-07-10 17:14:00+03	385000.00
7F756F	2017-07-29 06:10:00+03	56000.00
7F7618	2017-07-07 22:15:00+03	51900.00
7F7646	2017-07-10 07:44:00+03	100500.00
7F76FF	2017-07-05 07:16:00+03	30800.00
7F773F	2017-08-03 07:27:00+03	54600.00
7F77B6	2017-07-18 22:57:00+03	6000.00
7F77F6	2017-07-19 09:30:00+03	115900.00
7F788D	2017-07-23 12:51:00+03	369000.00
7F7896	2017-07-19 23:38:00+03	27800.00
7F789F	2017-08-05 06:37:00+03	114800.00
7F78ED	2017-07-13 19:32:00+03	117000.00
7F7901	2017-08-10 21:41:00+03	47400.00
7F794C	2017-08-02 17:27:00+03	91100.00
7F7956	2017-07-08 12:36:00+03	111600.00
7F7970	2017-08-03 15:07:00+03	108900.00
7F7984	2017-07-12 14:55:00+03	13600.00
7F79BC	2017-08-01 10:52:00+03	113300.00
7F79FF	2017-08-08 14:12:00+03	208100.00
7F7A86	2017-08-06 05:56:00+03	26200.00
7F7A90	2017-07-07 16:50:00+03	48800.00
7F7ACD	2017-07-27 13:30:00+03	112000.00
7F7AF4	2017-08-04 12:09:00+03	89600.00
7F7B3C	2017-07-14 03:33:00+03	21400.00
7F7B4A	2017-07-11 01:32:00+03	146300.00
7F7B66	2017-07-14 05:05:00+03	23200.00
7F7B99	2017-07-16 22:11:00+03	29600.00
7F7B9C	2017-07-02 16:54:00+03	31400.00
7F7BC2	2017-07-17 02:06:00+03	28800.00
7F7BDE	2017-08-08 04:02:00+03	30600.00
7F7C17	2017-08-02 15:57:00+03	47600.00
7F7C18	2017-08-09 02:59:00+03	201200.00
7F7C1E	2017-08-14 12:46:00+03	6700.00
7F7C45	2017-08-09 20:34:00+03	31600.00
7F7C62	2017-07-17 07:02:00+03	93900.00
7F7CE0	2017-07-02 16:14:00+03	92900.00
7F7D0D	2017-07-13 19:40:00+03	86500.00
7F7D17	2017-07-25 07:08:00+03	246000.00
7F7DBA	2017-07-28 03:17:00+03	13600.00
7F7E39	2017-07-10 12:37:00+03	92800.00
7F7E87	2017-08-12 15:52:00+03	47000.00
7F7E99	2017-07-24 06:49:00+03	31600.00
7F7ED4	2017-08-02 11:53:00+03	55800.00
7F7F02	2017-07-18 11:19:00+03	56000.00
7F7F2D	2017-07-29 07:31:00+03	44000.00
7F7F2F	2017-08-11 22:53:00+03	257500.00
7F7F52	2017-07-05 23:04:00+03	149200.00
7F7F6C	2017-07-25 04:17:00+03	40800.00
7F7F77	2017-07-10 16:37:00+03	42800.00
7F7F89	2017-07-16 21:34:00+03	188000.00
7F7FD0	2017-08-05 17:57:00+03	70800.00
7F8052	2017-07-21 19:41:00+03	11800.00
7F805D	2017-07-02 21:41:00+03	54500.00
7F808B	2017-08-07 04:55:00+03	26000.00
7F8093	2017-07-06 14:04:00+03	30000.00
7F8097	2017-07-22 07:59:00+03	21800.00
7F80AC	2017-07-07 11:46:00+03	28000.00
7F80B2	2017-07-03 11:07:00+03	46400.00
7F80B4	2017-07-30 16:33:00+03	92800.00
7F80DD	2017-08-15 08:05:00+03	110200.00
7F8153	2017-07-05 22:23:00+03	57800.00
7F81E6	2017-07-30 10:52:00+03	78800.00
7F821E	2017-07-22 19:45:00+03	169600.00
7F8286	2017-07-28 14:28:00+03	62800.00
7F8320	2017-07-12 08:30:00+03	55800.00
7F8376	2017-08-02 14:47:00+03	136200.00
7F83CC	2017-07-20 01:46:00+03	26600.00
7F83DC	2017-08-01 20:33:00+03	29400.00
7F8414	2017-07-26 02:21:00+03	38800.00
7F8487	2017-08-02 11:15:00+03	406200.00
7F84C1	2017-07-25 18:15:00+03	38800.00
7F8547	2017-07-19 15:20:00+03	201800.00
7F8550	2017-08-12 17:06:00+03	47400.00
7F85A3	2017-07-25 10:55:00+03	32800.00
7F85AE	2017-07-25 09:20:00+03	130400.00
7F85B0	2017-07-25 05:56:00+03	46400.00
7F85CC	2017-07-06 19:37:00+03	32800.00
7F85F8	2017-07-07 06:15:00+03	66600.00
7F8613	2017-06-29 17:38:00+03	42000.00
7F8648	2017-07-04 04:09:00+03	6000.00
7F8665	2017-07-10 14:28:00+03	124200.00
7F86A0	2017-07-11 09:05:00+03	25600.00
7F86E8	2017-08-14 08:17:00+03	100600.00
7F872E	2017-07-21 17:21:00+03	26000.00
7F8741	2017-08-12 21:26:00+03	75900.00
7F8775	2017-08-15 08:04:00+03	23200.00
7F87B4	2017-08-14 09:54:00+03	24000.00
7F87D6	2017-07-19 19:53:00+03	278200.00
7F87DF	2017-07-10 16:29:00+03	139300.00
7F87EB	2017-08-11 00:01:00+03	10800.00
7F87EC	2017-08-09 00:05:00+03	23400.00
7F87F5	2017-08-14 00:47:00+03	37100.00
7F8852	2017-08-12 06:28:00+03	45000.00
7F8879	2017-07-15 14:00:00+03	278600.00
7F887D	2017-07-19 19:33:00+03	59300.00
7F8972	2017-07-27 11:57:00+03	24400.00
7F89CB	2017-08-02 23:20:00+03	176300.00
7F8A2C	2017-08-01 05:37:00+03	14400.00
7F8A92	2017-07-06 21:29:00+03	25400.00
7F8AF9	2017-07-16 03:20:00+03	111600.00
7F8B22	2017-07-30 06:29:00+03	38400.00
7F8BE4	2017-07-04 12:51:00+03	123600.00
7F8BE8	2017-07-15 15:03:00+03	114400.00
7F8BF8	2017-07-28 21:18:00+03	99200.00
7F8BFD	2017-08-15 14:08:00+03	49500.00
7F8C28	2017-08-13 04:01:00+03	186900.00
7F8C4A	2017-07-27 19:08:00+03	26800.00
7F8C72	2017-07-05 00:29:00+03	136200.00
7F8CA1	2017-07-02 22:37:00+03	26000.00
7F8CC7	2017-07-20 07:44:00+03	95600.00
7F8CDF	2017-07-10 14:13:00+03	68400.00
7F8D52	2017-07-08 13:44:00+03	36800.00
7F8D89	2017-08-05 15:43:00+03	31600.00
7F8DAB	2017-07-17 10:42:00+03	24400.00
7F8DB0	2017-07-10 14:35:00+03	13400.00
7F8E2D	2017-07-07 13:01:00+03	23400.00
7F8E43	2017-07-17 21:14:00+03	46400.00
7F8EB9	2017-08-01 18:06:00+03	34700.00
7F8F16	2017-07-13 08:04:00+03	99200.00
7F8F65	2017-07-13 19:49:00+03	46800.00
7F8F78	2017-07-28 17:34:00+03	136000.00
7F90C8	2017-07-27 15:23:00+03	243600.00
7F90DC	2017-07-23 21:53:00+03	44800.00
7F9107	2017-08-13 02:51:00+03	55600.00
7F9149	2017-07-20 14:26:00+03	34000.00
7F91BE	2017-07-12 03:51:00+03	360400.00
7F91E2	2017-07-18 00:08:00+03	55800.00
7F91EC	2017-07-30 21:37:00+03	28800.00
7F91EE	2017-07-03 14:00:00+03	6000.00
7F91F5	2017-07-12 03:42:00+03	191200.00
7F921E	2017-08-07 19:01:00+03	26200.00
7F9250	2017-07-29 05:05:00+03	18900.00
7F92B2	2017-08-14 01:36:00+03	135400.00
7F92D7	2017-08-02 09:42:00+03	88100.00
7F930A	2017-08-01 23:26:00+03	27800.00
7F931E	2017-07-12 10:07:00+03	13400.00
7F9386	2017-08-13 00:02:00+03	56600.00
7F93B5	2017-08-07 20:53:00+03	71900.00
7F9421	2017-08-05 22:52:00+03	84500.00
7F9458	2017-07-23 14:01:00+03	69900.00
7F945E	2017-08-08 17:48:00+03	40800.00
7F949F	2017-08-12 21:51:00+03	119500.00
7F9524	2017-07-21 18:35:00+03	38600.00
7F952C	2017-08-04 07:37:00+03	32700.00
7F95E3	2017-07-17 21:35:00+03	166100.00
7F9613	2017-07-27 20:13:00+03	82900.00
7F965F	2017-07-16 01:14:00+03	36800.00
7F96CE	2017-07-07 17:31:00+03	132800.00
7F96F7	2017-07-10 05:03:00+03	242600.00
7F970F	2017-07-08 16:07:00+03	85000.00
7F9717	2017-07-25 21:38:00+03	13400.00
7F9794	2017-08-06 11:32:00+03	13400.00
7F97E0	2017-07-23 08:57:00+03	72300.00
7F97FB	2017-07-25 12:30:00+03	82900.00
7F9810	2017-07-05 06:18:00+03	258800.00
7F984A	2017-08-13 17:17:00+03	60400.00
7F984F	2017-07-06 03:39:00+03	27400.00
7F985E	2017-07-24 23:27:00+03	38200.00
7F987A	2017-07-29 11:34:00+03	76200.00
7F98C4	2017-07-20 04:17:00+03	139300.00
7F9990	2017-08-08 10:03:00+03	75200.00
7F9A61	2017-07-28 04:32:00+03	12600.00
7F9AF0	2017-07-02 20:42:00+03	21500.00
7F9AF4	2017-07-25 12:50:00+03	102200.00
7F9B8B	2017-08-08 23:39:00+03	26000.00
7F9BC3	2017-08-12 15:20:00+03	26300.00
7F9BEA	2017-07-23 06:24:00+03	41600.00
7F9BEC	2017-08-12 17:16:00+03	60000.00
7F9C20	2017-08-07 04:42:00+03	10800.00
7F9CD7	2017-08-10 17:38:00+03	199700.00
7F9CFF	2017-07-07 21:45:00+03	56600.00
7F9D31	2017-08-15 17:22:00+03	188000.00
7F9D6E	2017-08-13 17:08:00+03	21600.00
7F9D73	2017-06-30 17:01:00+03	14800.00
7F9D78	2017-07-07 07:50:00+03	80700.00
7F9DC6	2017-08-05 14:06:00+03	21800.00
7F9E00	2017-07-02 05:16:00+03	96300.00
7F9E56	2017-07-23 05:39:00+03	291200.00
7F9EBD	2017-07-12 02:13:00+03	70400.00
7F9EC0	2017-08-06 15:10:00+03	26700.00
7F9ECC	2017-07-07 04:24:00+03	168700.00
7F9F3E	2017-08-12 20:23:00+03	199400.00
7F9F4E	2017-08-02 20:31:00+03	26000.00
7F9F71	2017-08-02 20:54:00+03	18300.00
7F9FC9	2017-08-05 13:47:00+03	70500.00
7FA017	2017-07-10 01:38:00+03	29600.00
7FA03C	2017-07-18 00:56:00+03	27600.00
7FA0AB	2017-07-20 19:20:00+03	55800.00
7FA0E9	2017-07-03 09:44:00+03	12600.00
7FA26D	2017-07-01 03:47:00+03	71000.00
7FA282	2017-08-15 05:48:00+03	131100.00
7FA323	2017-07-23 20:50:00+03	254900.00
7FA34B	2017-06-30 09:47:00+03	119500.00
7FA39B	2017-06-29 11:36:00+03	21800.00
7FA3C5	2017-07-23 23:58:00+03	57600.00
7FA424	2017-07-24 20:36:00+03	72400.00
7FA425	2017-08-05 05:28:00+03	34000.00
7FA471	2017-07-14 14:14:00+03	25200.00
7FA4AB	2017-07-13 21:25:00+03	59100.00
7FA4C2	2017-08-12 14:51:00+03	42800.00
7FA50E	2017-07-09 08:57:00+03	62800.00
7FA545	2017-07-03 02:21:00+03	28700.00
7FA548	2017-06-28 12:58:00+03	20200.00
7FA5B3	2017-08-09 19:58:00+03	23200.00
7FA634	2017-07-11 20:02:00+03	56600.00
7FA6E4	2017-08-05 00:08:00+03	68800.00
7FA709	2017-07-22 20:58:00+03	19800.00
7FA72B	2017-07-09 19:35:00+03	120400.00
7FA73D	2017-07-12 09:13:00+03	58200.00
7FA742	2017-08-08 11:22:00+03	223200.00
7FA775	2017-08-14 12:53:00+03	42800.00
7FA7BC	2017-08-15 13:26:00+03	273400.00
7FA7CC	2017-07-19 23:00:00+03	246000.00
7FA80B	2017-07-23 07:13:00+03	54800.00
7FA81F	2017-08-10 13:58:00+03	393800.00
7FA922	2017-08-02 13:41:00+03	81900.00
7FA9F4	2017-07-21 19:56:00+03	31000.00
7FAA71	2017-07-26 22:45:00+03	38600.00
7FAABD	2017-08-04 07:51:00+03	18900.00
7FAB06	2017-07-27 23:55:00+03	125400.00
7FAB2B	2017-06-28 18:36:00+03	25000.00
7FAB37	2017-07-03 22:27:00+03	29400.00
7FAB56	2017-08-07 21:24:00+03	64100.00
7FAB58	2017-07-08 06:15:00+03	56000.00
7FAB9C	2017-07-06 20:02:00+03	131600.00
7FABB4	2017-07-24 04:02:00+03	73300.00
7FABB6	2017-08-07 01:37:00+03	569600.00
7FAC58	2017-07-19 10:06:00+03	106700.00
7FAC6F	2017-07-09 20:10:00+03	23200.00
7FAC84	2017-08-02 16:59:00+03	56100.00
7FAD71	2017-07-15 09:16:00+03	32800.00
7FAD86	2017-07-21 03:25:00+03	111600.00
7FAD8A	2017-08-15 17:00:00+03	25800.00
7FADB4	2017-07-07 17:32:00+03	38000.00
7FADD1	2017-07-20 08:29:00+03	103800.00
7FADDE	2017-07-22 14:44:00+03	66600.00
7FAE12	2017-08-15 05:35:00+03	6800.00
7FAE3D	2017-07-29 07:18:00+03	44500.00
7FAE77	2017-08-03 10:36:00+03	75200.00
7FAF25	2017-07-11 05:01:00+03	23600.00
7FAF47	2017-08-03 15:37:00+03	131100.00
7FAF93	2017-07-23 11:35:00+03	356500.00
7FAFAD	2017-08-02 05:13:00+03	28600.00
7FAFC8	2017-08-03 07:31:00+03	80900.00
7FAFE4	2017-08-01 09:34:00+03	278400.00
7FAFED	2017-08-06 14:13:00+03	38800.00
7FAFF5	2017-07-31 01:36:00+03	542200.00
7FB028	2017-07-26 07:35:00+03	54500.00
7FB0D9	2017-08-15 12:56:00+03	29400.00
7FB141	2017-07-05 11:45:00+03	29600.00
7FB25E	2017-07-09 11:35:00+03	46000.00
7FB2B8	2017-07-10 19:38:00+03	42700.00
7FB315	2017-06-30 07:20:00+03	56000.00
7FB35D	2017-07-26 18:25:00+03	15400.00
7FB391	2017-07-23 09:46:00+03	15400.00
7FB3CB	2017-08-08 04:45:00+03	40300.00
7FB3FD	2017-07-06 18:02:00+03	13600.00
7FB407	2017-07-11 04:56:00+03	42400.00
7FB43B	2017-08-04 03:14:00+03	44000.00
7FB43D	2017-08-01 17:51:00+03	16000.00
7FB491	2017-07-05 20:01:00+03	106400.00
7FB4E1	2017-08-08 13:35:00+03	54000.00
7FB4F6	2017-08-07 22:16:00+03	21800.00
7FB525	2017-07-06 10:08:00+03	131600.00
7FB52D	2017-07-04 07:22:00+03	59100.00
7FB567	2017-08-07 17:34:00+03	61200.00
7FB5A9	2017-08-11 09:56:00+03	94900.00
7FB68D	2017-07-08 15:15:00+03	79900.00
7FB745	2017-07-27 17:34:00+03	27900.00
7FB754	2017-07-21 00:09:00+03	83200.00
7FB801	2017-08-04 02:30:00+03	89600.00
7FB83F	2017-07-16 10:31:00+03	93900.00
7FB89A	2017-07-01 19:53:00+03	531400.00
7FB8B2	2017-07-30 14:52:00+03	33400.00
7FB8D3	2017-08-13 18:59:00+03	99700.00
7FB938	2017-07-19 09:46:00+03	51200.00
7FB97C	2017-07-21 06:22:00+03	51900.00
7FB98D	2017-07-11 13:03:00+03	191000.00
7FBA06	2017-07-30 02:08:00+03	14400.00
7FBA2D	2017-07-06 03:45:00+03	91500.00
7FBAC5	2017-07-22 21:42:00+03	47600.00
7FBB34	2017-08-04 17:44:00+03	72400.00
7FBB3B	2017-06-24 21:16:00+03	28000.00
7FBBA5	2017-07-11 17:54:00+03	135600.00
7FBC81	2017-07-02 05:06:00+03	201200.00
7FBCD6	2017-07-06 04:36:00+03	56000.00
7FBCED	2017-07-13 01:31:00+03	28800.00
7FBD2A	2017-07-07 18:21:00+03	62600.00
7FBD40	2017-07-05 09:33:00+03	27800.00
7FBD48	2017-07-05 10:16:00+03	34400.00
7FBD4C	2017-08-13 05:46:00+03	81200.00
7FBD5E	2017-08-10 06:52:00+03	38200.00
7FBD7C	2017-08-07 06:31:00+03	44800.00
7FBE0C	2017-08-10 19:24:00+03	111600.00
7FBEDE	2017-07-05 08:39:00+03	8400.00
7FBEF5	2017-07-28 05:00:00+03	75300.00
7FBF81	2017-07-16 14:29:00+03	199200.00
7FBFDF	2017-08-07 20:34:00+03	88600.00
7FBFFF	2017-07-22 22:19:00+03	40400.00
7FC00A	2017-07-17 03:42:00+03	6800.00
7FC041	2017-07-21 17:22:00+03	133900.00
7FC080	2017-07-20 10:18:00+03	70600.00
7FC08A	2017-08-08 17:30:00+03	67700.00
7FC0BB	2017-08-05 18:19:00+03	303100.00
7FC0FB	2017-07-10 23:40:00+03	44500.00
7FC174	2017-07-23 12:22:00+03	28800.00
7FC1A3	2017-08-10 23:29:00+03	102600.00
7FC1A8	2017-08-11 08:15:00+03	6000.00
7FC1EA	2017-07-11 06:12:00+03	398500.00
7FC27C	2017-07-01 07:17:00+03	28000.00
7FC2DE	2017-07-22 16:43:00+03	6000.00
7FC2E7	2017-07-10 13:33:00+03	75300.00
7FC2F0	2017-08-01 19:41:00+03	47000.00
7FC2FC	2017-07-26 21:31:00+03	57500.00
7FC308	2017-07-27 12:58:00+03	167400.00
7FC415	2017-08-14 04:39:00+03	68800.00
7FC473	2017-07-31 10:50:00+03	28200.00
7FC4BA	2017-08-08 12:07:00+03	64700.00
7FC53C	2017-07-19 13:59:00+03	168000.00
7FC541	2017-07-09 09:26:00+03	73300.00
7FC5E5	2017-07-18 05:37:00+03	44800.00
7FC5F9	2017-08-06 09:15:00+03	24000.00
7FC621	2017-07-10 16:15:00+03	34000.00
7FC646	2017-07-27 06:54:00+03	103500.00
7FC65E	2017-08-10 05:16:00+03	67800.00
7FC6A6	2017-07-26 12:43:00+03	23100.00
7FC6C0	2017-07-05 03:33:00+03	18600.00
7FC6FF	2017-07-24 05:33:00+03	138100.00
7FC728	2017-07-28 18:20:00+03	81600.00
7FC72D	2017-08-13 16:50:00+03	87700.00
7FC774	2017-08-15 14:11:00+03	36200.00
7FC78D	2017-07-01 08:03:00+03	71400.00
7FC7A1	2017-07-10 05:54:00+03	56000.00
7FC7C8	2017-07-22 04:12:00+03	117200.00
7FC87F	2017-07-18 12:49:00+03	7400.00
7FC8BE	2017-08-11 14:31:00+03	246000.00
7FC8D1	2017-08-10 03:36:00+03	135400.00
7FC8D6	2017-07-10 17:13:00+03	32700.00
7FC8F7	2017-07-14 18:28:00+03	26000.00
7FC94A	2017-07-30 21:56:00+03	51600.00
7FC997	2017-07-17 10:45:00+03	56000.00
7FCA05	2017-07-12 05:35:00+03	23200.00
7FCA82	2017-07-29 09:56:00+03	34400.00
7FCABD	2017-07-21 21:45:00+03	36800.00
7FCAC6	2017-07-31 19:42:00+03	44000.00
7FCB82	2017-07-28 12:07:00+03	98400.00
7FCBC1	2017-08-11 11:34:00+03	26800.00
7FCBDE	2017-07-15 20:15:00+03	54200.00
7FCC8D	2017-07-21 08:36:00+03	56000.00
7FCCD9	2017-07-30 21:46:00+03	40100.00
7FCCEB	2017-08-14 19:41:00+03	351000.00
7FCD22	2017-07-07 06:26:00+03	66600.00
7FCD64	2017-08-12 11:14:00+03	126300.00
7FCD77	2017-07-20 21:14:00+03	20200.00
7FCD98	2017-07-04 00:17:00+03	46400.00
7FCDA3	2017-07-09 07:31:00+03	43200.00
7FCDAA	2017-08-02 00:52:00+03	23200.00
7FCDAE	2017-07-28 14:55:00+03	32200.00
7FCDB4	2017-07-31 03:00:00+03	46400.00
7FCE02	2017-08-10 12:38:00+03	12600.00
7FCE7A	2017-07-29 04:58:00+03	134400.00
7FCED2	2017-08-01 21:40:00+03	160700.00
7FCED9	2017-07-02 21:39:00+03	22000.00
7FCF2C	2017-08-10 14:45:00+03	107000.00
7FCFAA	2017-08-14 20:10:00+03	77700.00
7FD018	2017-07-09 23:15:00+03	26000.00
7FD037	2017-08-12 19:07:00+03	51600.00
7FD0A1	2017-07-16 23:52:00+03	66600.00
7FD0C1	2017-08-09 05:19:00+03	6300.00
7FD0C8	2017-07-20 16:58:00+03	30200.00
7FD0CC	2017-07-30 12:46:00+03	136200.00
7FD10A	2017-07-29 19:02:00+03	18000.00
7FD117	2017-07-25 09:06:00+03	56100.00
7FD19C	2017-07-09 13:20:00+03	25400.00
7FD250	2017-08-13 00:07:00+03	58400.00
7FD259	2017-07-16 22:30:00+03	58200.00
7FD297	2017-08-11 23:34:00+03	90800.00
7FD2B5	2017-07-13 05:50:00+03	234300.00
7FD2B9	2017-07-08 15:00:00+03	20200.00
7FD2BE	2017-07-25 07:23:00+03	42800.00
7FD2C0	2017-08-15 17:03:00+03	100600.00
7FD2CC	2017-07-05 03:26:00+03	99700.00
7FD3DB	2017-07-27 07:53:00+03	174500.00
7FD3F0	2017-07-30 05:19:00+03	27900.00
7FD470	2017-08-09 10:20:00+03	88000.00
7FD4DB	2017-08-12 19:53:00+03	63500.00
7FD592	2017-08-04 22:37:00+03	52900.00
7FD5C0	2017-07-21 00:42:00+03	25400.00
7FD5D1	2017-07-12 16:29:00+03	85000.00
7FD5D5	2017-07-19 09:48:00+03	62700.00
7FD5D8	2017-07-21 16:29:00+03	44800.00
7FD5F9	2017-08-07 22:57:00+03	47400.00
7FD699	2017-07-25 22:40:00+03	38800.00
7FD6AD	2017-07-15 06:47:00+03	246000.00
7FD6C9	2017-08-12 09:14:00+03	124300.00
7FD71F	2017-08-07 04:40:00+03	55800.00
7FD726	2017-08-13 22:34:00+03	66800.00
7FD74F	2017-07-06 06:00:00+03	88800.00
7FD766	2017-07-22 11:34:00+03	58200.00
7FD7C1	2017-07-14 16:59:00+03	63800.00
7FD7EA	2017-07-18 05:24:00+03	37500.00
7FD7FE	2017-08-03 09:58:00+03	26000.00
7FD89D	2017-07-10 05:45:00+03	57500.00
7FD93A	2017-07-06 21:06:00+03	24300.00
7FD97E	2017-08-05 04:16:00+03	47600.00
7FDA5B	2017-07-03 02:55:00+03	38400.00
7FDA76	2017-07-11 03:08:00+03	254900.00
7FDA93	2017-08-09 03:48:00+03	100600.00
7FDAC7	2017-06-30 13:39:00+03	24000.00
7FDB0F	2017-08-13 19:51:00+03	67000.00
7FDC5D	2017-08-12 02:39:00+03	27600.00
7FDC5E	2017-07-11 00:47:00+03	86400.00
7FDCAA	2017-07-22 05:37:00+03	61200.00
7FDCE0	2017-07-26 11:21:00+03	37900.00
7FDCE1	2017-07-28 05:20:00+03	15000.00
7FDD00	2017-07-16 01:01:00+03	246000.00
7FDD01	2017-08-03 10:58:00+03	32700.00
7FDD6B	2017-07-26 19:41:00+03	224700.00
7FDD9E	2017-07-17 11:37:00+03	97000.00
7FDE16	2017-07-20 16:27:00+03	55800.00
7FDE36	2017-08-04 14:04:00+03	52000.00
7FDF3A	2017-08-13 10:19:00+03	20000.00
7FDF6F	2017-08-14 06:30:00+03	48800.00
7FE033	2017-08-10 17:20:00+03	39300.00
7FE038	2017-07-05 11:40:00+03	11800.00
7FE07F	2017-07-29 18:27:00+03	103500.00
7FE08A	2017-07-24 04:47:00+03	61800.00
7FE092	2017-08-05 21:29:00+03	58400.00
7FE0AD	2017-07-07 08:53:00+03	38200.00
7FE0B8	2017-07-23 03:39:00+03	78300.00
7FE0F4	2017-08-04 22:27:00+03	49800.00
7FE0FF	2017-07-25 16:02:00+03	19600.00
7FE14B	2017-06-29 22:28:00+03	21800.00
7FE22B	2017-07-05 17:44:00+03	61800.00
7FE25A	2017-07-06 04:33:00+03	55800.00
7FE32E	2017-07-10 21:16:00+03	89700.00
7FE389	2017-07-02 03:38:00+03	13200.00
7FE421	2017-07-01 22:26:00+03	35300.00
7FE46A	2017-07-30 04:52:00+03	30400.00
7FE4AA	2017-08-09 14:56:00+03	55800.00
7FE4B0	2017-07-09 00:28:00+03	73600.00
7FE4B4	2017-07-22 19:14:00+03	66000.00
7FE524	2017-07-16 15:48:00+03	46700.00
7FE547	2017-07-27 18:43:00+03	198900.00
7FE54B	2017-08-07 13:33:00+03	52200.00
7FE617	2017-07-24 16:30:00+03	59200.00
7FE627	2017-07-21 13:32:00+03	25600.00
7FE62F	2017-08-15 05:27:00+03	265700.00
7FE651	2017-07-13 13:44:00+03	43500.00
7FE68C	2017-08-11 21:46:00+03	57200.00
7FE6AD	2017-07-04 08:59:00+03	22000.00
7FE712	2017-07-29 21:49:00+03	34600.00
7FE732	2017-07-17 05:20:00+03	46200.00
7FE813	2017-07-31 22:59:00+03	64800.00
7FE834	2017-07-13 07:38:00+03	206400.00
7FE863	2017-07-24 18:07:00+03	26200.00
7FE884	2017-07-22 09:06:00+03	26500.00
7FE8B5	2017-08-06 22:59:00+03	246000.00
7FE8D8	2017-08-12 18:20:00+03	15300.00
7FE8E0	2017-08-02 17:42:00+03	7400.00
7FE8F7	2017-08-06 09:55:00+03	81500.00
7FE906	2017-07-10 09:45:00+03	75300.00
7FE907	2017-07-04 08:04:00+03	29600.00
7FE92D	2017-07-20 01:09:00+03	173500.00
7FE936	2017-07-14 07:22:00+03	10800.00
7FE94B	2017-07-22 13:01:00+03	21400.00
7FE959	2017-07-19 15:11:00+03	30000.00
7FE98B	2017-08-08 16:03:00+03	111600.00
7FE99C	2017-07-19 19:20:00+03	23600.00
7FE9D0	2017-07-25 10:23:00+03	40600.00
7FEA16	2017-07-07 05:50:00+03	46000.00
7FEA3B	2017-08-07 22:25:00+03	18800.00
7FEA6D	2017-07-09 10:07:00+03	72300.00
7FEAC1	2017-07-10 18:37:00+03	78600.00
7FEB08	2017-07-25 02:56:00+03	24400.00
7FEB22	2017-07-04 10:45:00+03	59700.00
7FEB4D	2017-07-06 20:31:00+03	67600.00
7FEBD7	2017-06-29 22:37:00+03	67200.00
7FEBEE	2017-07-24 20:33:00+03	55800.00
7FEC17	2017-07-13 11:24:00+03	126500.00
7FEC2E	2017-07-23 05:33:00+03	40000.00
7FEC3C	2017-06-29 09:22:00+03	23600.00
7FEC4A	2017-08-04 11:48:00+03	103400.00
7FEC75	2017-08-12 21:57:00+03	273000.00
7FEC80	2017-07-30 21:13:00+03	78800.00
7FEC99	2017-07-06 11:50:00+03	117600.00
7FED0C	2017-07-24 21:28:00+03	57800.00
7FEDCE	2017-07-18 10:30:00+03	26700.00
7FEE02	2017-07-14 15:18:00+03	27200.00
7FEE38	2017-07-19 10:05:00+03	43000.00
7FEE46	2017-07-29 08:39:00+03	131900.00
7FEE98	2017-06-29 10:42:00+03	135600.00
7FEF6D	2017-08-09 18:53:00+03	78500.00
7FF00E	2017-07-09 04:57:00+03	72200.00
7FF03E	2017-07-11 05:36:00+03	47400.00
7FF0E2	2017-08-12 04:57:00+03	52900.00
7FF115	2017-08-06 16:33:00+03	64800.00
7FF1E0	2017-08-13 11:49:00+03	17200.00
7FF1F2	2017-07-29 03:01:00+03	92700.00
7FF2EC	2017-08-06 03:57:00+03	51900.00
7FF2FF	2017-08-03 07:34:00+03	27900.00
7FF32F	2017-07-05 22:06:00+03	118600.00
7FF340	2017-08-07 22:42:00+03	56000.00
7FF372	2017-08-10 05:17:00+03	68400.00
7FF37F	2017-07-21 15:57:00+03	111600.00
7FF490	2017-07-31 19:56:00+03	32400.00
7FF4B6	2017-08-05 01:48:00+03	27800.00
7FF4BD	2017-07-15 02:04:00+03	38300.00
7FF4EA	2017-07-15 18:45:00+03	75800.00
7FF525	2017-07-03 12:20:00+03	140000.00
7FF540	2017-08-04 03:19:00+03	229000.00
7FF582	2017-07-04 08:47:00+03	147600.00
7FF592	2017-07-14 15:09:00+03	143100.00
7FF5F0	2017-07-15 12:36:00+03	12000.00
7FF607	2017-08-10 23:31:00+03	41400.00
7FF65A	2017-08-03 00:07:00+03	108200.00
7FF686	2017-08-14 12:35:00+03	92900.00
7FF722	2017-08-09 19:38:00+03	19800.00
7FF752	2017-07-24 18:45:00+03	103400.00
7FF794	2017-07-02 07:07:00+03	26000.00
7FF7BD	2017-07-11 02:43:00+03	52000.00
7FF7C4	2017-07-06 00:35:00+03	38400.00
7FF827	2017-07-30 07:30:00+03	40800.00
7FF841	2017-07-10 00:40:00+03	8400.00
7FF863	2017-08-10 17:22:00+03	89600.00
7FF8D7	2017-07-18 13:56:00+03	72800.00
7FF8E8	2017-07-08 10:56:00+03	246000.00
7FF990	2017-07-02 23:41:00+03	112000.00
7FF9F1	2017-07-01 08:28:00+03	28000.00
7FF9FE	2017-08-04 03:46:00+03	61800.00
7FFAA1	2017-07-19 09:12:00+03	46900.00
7FFAFB	2017-07-19 17:12:00+03	135400.00
7FFB1C	2017-07-21 11:55:00+03	40800.00
7FFB1E	2017-08-15 12:35:00+03	80400.00
7FFB33	2017-08-12 01:34:00+03	106900.00
7FFB77	2017-08-04 04:36:00+03	149100.00
7FFB7D	2017-07-31 01:37:00+03	35200.00
7FFB8B	2017-07-11 08:54:00+03	95200.00
7FFBCB	2017-07-13 21:16:00+03	36200.00
7FFBCD	2017-07-25 05:27:00+03	43200.00
7FFC17	2017-07-20 01:13:00+03	109000.00
7FFC43	2017-08-15 10:30:00+03	80100.00
7FFC60	2017-08-02 03:30:00+03	50600.00
7FFC65	2017-07-06 15:11:00+03	48400.00
7FFD12	2017-07-25 17:41:00+03	9800.00
7FFD20	2017-08-10 07:05:00+03	24300.00
7FFD74	2017-08-14 05:01:00+03	75600.00
7FFE5F	2017-08-09 23:57:00+03	55800.00
7FFE6F	2017-07-09 18:04:00+03	43600.00
7FFE86	2017-07-21 11:40:00+03	95600.00
7FFE93	2017-07-15 22:40:00+03	6900.00
7FFEB7	2017-07-31 09:48:00+03	34000.00
7FFFB5	2017-08-07 08:02:00+03	75300.00
800003	2017-07-24 08:42:00+03	21800.00
800005	2017-08-12 12:42:00+03	66300.00
800054	2017-07-31 01:24:00+03	27400.00
80009C	2017-08-07 21:29:00+03	44600.00
8000A3	2017-07-17 08:13:00+03	57500.00
8000BA	2017-07-18 09:59:00+03	38400.00
80017F	2017-08-12 08:37:00+03	59000.00
8001A0	2017-08-14 18:29:00+03	138700.00
8001AC	2017-07-08 15:34:00+03	48400.00
8001CE	2017-07-14 05:43:00+03	24300.00
8001D0	2017-08-05 19:44:00+03	16000.00
800227	2017-07-14 12:50:00+03	66600.00
800287	2017-07-03 18:50:00+03	85000.00
800288	2017-07-27 10:17:00+03	108000.00
8002A9	2017-07-17 04:58:00+03	38500.00
8002D9	2017-08-03 02:01:00+03	6700.00
800347	2017-07-14 16:29:00+03	116300.00
80036F	2017-07-31 14:01:00+03	6000.00
8003FC	2017-07-05 21:23:00+03	13400.00
800447	2017-07-22 19:26:00+03	89600.00
80048E	2017-07-03 18:59:00+03	58400.00
80050A	2017-08-05 10:48:00+03	31600.00
800528	2017-07-09 22:39:00+03	13400.00
800558	2017-07-28 13:47:00+03	542100.00
800574	2017-07-16 11:49:00+03	315600.00
8005D4	2017-08-05 06:39:00+03	100600.00
800662	2017-07-21 20:55:00+03	71200.00
80066A	2017-08-05 05:40:00+03	20600.00
800710	2017-07-26 01:29:00+03	137400.00
8007A6	2017-07-10 07:10:00+03	55800.00
8007FA	2017-06-30 20:10:00+03	46900.00
800876	2017-07-29 18:31:00+03	22000.00
8008C2	2017-07-25 22:08:00+03	199700.00
80099A	2017-07-07 16:47:00+03	10600.00
80099E	2017-07-15 06:59:00+03	34000.00
800A19	2017-07-02 13:21:00+03	37100.00
800A29	2017-08-14 06:46:00+03	28000.00
800A2C	2017-07-08 21:48:00+03	89700.00
800A34	2017-07-16 20:28:00+03	88600.00
800A6E	2017-08-12 01:15:00+03	23900.00
800AE1	2017-07-16 11:55:00+03	13600.00
800AF2	2017-07-19 09:10:00+03	30200.00
800B0E	2017-07-09 00:34:00+03	18000.00
800B30	2017-07-07 06:08:00+03	149200.00
800B3D	2017-07-08 20:27:00+03	21800.00
800B5D	2017-07-26 01:10:00+03	60200.00
800BD5	2017-07-16 16:44:00+03	55800.00
800BE5	2017-07-02 13:17:00+03	182900.00
800C46	2017-07-23 11:00:00+03	57800.00
800C8E	2017-07-25 18:32:00+03	53400.00
800CCC	2017-07-19 06:41:00+03	325500.00
800CE5	2017-07-14 06:17:00+03	19600.00
800D29	2017-08-06 09:08:00+03	54800.00
800D31	2017-07-29 15:10:00+03	49900.00
800D94	2017-08-05 00:55:00+03	111600.00
800D9F	2017-07-11 20:37:00+03	47500.00
800DB0	2017-07-22 09:34:00+03	6700.00
800E33	2017-07-21 09:59:00+03	51600.00
800E81	2017-07-13 02:28:00+03	73300.00
800EB3	2017-07-18 00:46:00+03	12600.00
800EC0	2017-07-11 17:29:00+03	56000.00
800EC7	2017-07-13 13:16:00+03	68100.00
800F03	2017-07-19 02:12:00+03	65900.00
800F0F	2017-07-15 12:23:00+03	235900.00
800F20	2017-07-15 05:58:00+03	98400.00
800F52	2017-08-03 17:53:00+03	24800.00
800F95	2017-08-12 04:58:00+03	49800.00
800FAF	2017-07-25 08:19:00+03	67800.00
800FC7	2017-07-06 18:58:00+03	53600.00
800FEB	2017-07-20 23:32:00+03	67200.00
80104E	2017-08-01 20:02:00+03	44000.00
801067	2017-07-28 18:40:00+03	53600.00
80107F	2017-08-15 01:49:00+03	53300.00
801095	2017-07-10 19:17:00+03	37400.00
8010B3	2017-07-03 16:18:00+03	31400.00
8010CB	2017-08-15 01:51:00+03	46300.00
8010CE	2017-07-22 07:52:00+03	87000.00
801139	2017-07-16 11:19:00+03	67200.00
801176	2017-08-07 23:22:00+03	31600.00
80117C	2017-08-09 07:50:00+03	28800.00
80118A	2017-07-24 21:24:00+03	8000.00
8011C1	2017-06-30 23:43:00+03	27200.00
801232	2017-07-28 03:30:00+03	46300.00
80125E	2017-07-07 22:58:00+03	168000.00
8012A0	2017-08-13 14:48:00+03	14000.00
8012C5	2017-08-08 15:00:00+03	94800.00
8012DB	2017-07-07 05:50:00+03	45100.00
801312	2017-08-13 23:24:00+03	66600.00
801339	2017-08-01 18:40:00+03	34800.00
80134F	2017-08-14 06:21:00+03	55800.00
8013E6	2017-06-30 17:28:00+03	135000.00
801400	2017-08-13 07:51:00+03	115000.00
80141D	2017-08-03 04:20:00+03	43600.00
801430	2017-08-02 00:04:00+03	83000.00
801437	2017-08-11 18:20:00+03	26700.00
801438	2017-07-16 02:06:00+03	149200.00
8014F6	2017-07-15 00:20:00+03	21400.00
80154F	2017-08-03 16:02:00+03	22000.00
80158B	2017-07-23 13:42:00+03	56000.00
8015E3	2017-07-28 05:47:00+03	210700.00
80172F	2017-08-10 18:50:00+03	26700.00
80175F	2017-07-07 20:13:00+03	136200.00
8017A9	2017-08-01 13:59:00+03	13600.00
8017DA	2017-08-11 14:28:00+03	116500.00
801832	2017-07-10 10:50:00+03	96300.00
801843	2017-08-03 18:04:00+03	24000.00
80187B	2017-07-16 01:21:00+03	132800.00
8018EB	2017-07-08 00:22:00+03	15100.00
80190D	2017-07-27 13:27:00+03	23400.00
80195D	2017-07-06 16:05:00+03	59300.00
80199E	2017-08-13 05:37:00+03	101500.00
8019E4	2017-07-02 10:44:00+03	16800.00
8019FD	2017-08-02 23:15:00+03	81600.00
801A1D	2017-08-13 08:03:00+03	40000.00
801A2A	2017-07-29 21:06:00+03	36800.00
801AFE	2017-07-16 13:37:00+03	99500.00
801B0B	2017-07-23 22:13:00+03	87100.00
801B18	2017-07-08 09:01:00+03	92300.00
801B32	2017-07-23 02:19:00+03	81700.00
801B42	2017-08-03 12:32:00+03	27600.00
801B99	2017-08-14 02:38:00+03	61800.00
801BC8	2017-08-01 21:18:00+03	406700.00
801BF2	2017-08-10 01:57:00+03	99700.00
801C1A	2017-07-01 20:29:00+03	27200.00
801D14	2017-07-30 02:44:00+03	136500.00
801D99	2017-08-06 01:22:00+03	52400.00
801E27	2017-07-10 09:24:00+03	95900.00
801E93	2017-07-04 22:45:00+03	179200.00
801E9E	2017-08-13 22:28:00+03	26800.00
801EB2	2017-07-16 04:20:00+03	398300.00
801F2A	2017-07-26 15:41:00+03	257500.00
801F7F	2017-08-03 20:55:00+03	40800.00
801F84	2017-07-15 04:30:00+03	24400.00
801F8E	2017-08-15 06:41:00+03	93900.00
801FBC	2017-07-07 19:18:00+03	119500.00
801FBD	2017-08-01 13:04:00+03	6300.00
801FC6	2017-07-30 12:03:00+03	190300.00
801FE0	2017-07-31 13:59:00+03	52000.00
8021FF	2017-07-07 07:50:00+03	117800.00
802247	2017-08-04 07:19:00+03	123200.00
802264	2017-08-05 23:38:00+03	103900.00
802298	2017-08-13 23:29:00+03	27700.00
8022B0	2017-07-24 06:51:00+03	22000.00
8022BC	2017-07-19 07:06:00+03	133200.00
802342	2017-08-12 05:21:00+03	70700.00
80235D	2017-08-07 07:21:00+03	46400.00
80236D	2017-07-18 01:51:00+03	111600.00
802385	2017-08-15 03:56:00+03	77200.00
802391	2017-08-07 17:58:00+03	28800.00
8023AB	2017-08-11 11:44:00+03	25600.00
802408	2017-08-14 14:09:00+03	46400.00
80241D	2017-07-27 05:38:00+03	45200.00
8024A6	2017-08-03 20:01:00+03	111000.00
8024E0	2017-07-19 09:53:00+03	382800.00
802538	2017-08-03 18:28:00+03	153300.00
802547	2017-07-30 11:06:00+03	46000.00
802554	2017-07-20 19:48:00+03	20500.00
802664	2017-07-15 03:17:00+03	96400.00
80268B	2017-07-05 22:59:00+03	56800.00
8026C6	2017-07-04 06:10:00+03	97900.00
8026FE	2017-07-08 17:37:00+03	69100.00
802731	2017-06-28 09:24:00+03	24400.00
802733	2017-07-05 10:24:00+03	21200.00
8027CF	2017-07-11 20:33:00+03	42700.00
8027FA	2017-08-11 16:09:00+03	136200.00
802803	2017-07-27 15:20:00+03	246000.00
802806	2017-08-04 13:44:00+03	20800.00
80280E	2017-07-07 05:48:00+03	54000.00
802811	2017-08-02 22:03:00+03	54400.00
802828	2017-06-30 07:24:00+03	70700.00
8028A1	2017-07-07 18:06:00+03	28000.00
8028E4	2017-07-11 20:47:00+03	39500.00
8028F5	2017-07-27 08:31:00+03	112000.00
80292F	2017-07-03 23:48:00+03	57200.00
802990	2017-07-04 11:59:00+03	119500.00
8029A3	2017-08-10 18:19:00+03	23600.00
802A08	2017-07-19 17:24:00+03	25600.00
802A13	2017-08-04 23:45:00+03	16400.00
802A9B	2017-07-07 16:07:00+03	12400.00
802AA7	2017-07-03 02:14:00+03	42400.00
802AB3	2017-07-09 19:56:00+03	68100.00
802AD1	2017-07-24 20:43:00+03	135600.00
802B0E	2017-07-19 11:21:00+03	52400.00
802B13	2017-08-11 22:04:00+03	26000.00
802B20	2017-08-08 01:11:00+03	23900.00
802B8A	2017-07-06 01:44:00+03	72700.00
802BBB	2017-07-02 05:59:00+03	89200.00
802C0F	2017-08-02 19:17:00+03	47200.00
802CA0	2017-08-11 03:13:00+03	21200.00
802CA5	2017-07-18 04:07:00+03	25000.00
802CB4	2017-07-25 15:34:00+03	13600.00
802CBF	2017-07-02 09:14:00+03	556700.00
802CE9	2017-07-15 19:17:00+03	88900.00
802D14	2017-07-30 22:29:00+03	103500.00
802D29	2017-08-12 20:31:00+03	314400.00
802DB9	2017-07-17 19:14:00+03	181600.00
802DE2	2017-08-15 05:57:00+03	28000.00
802DFB	2017-08-09 15:29:00+03	86600.00
802E28	2017-08-06 21:12:00+03	28800.00
802EA0	2017-08-03 11:23:00+03	26800.00
802EE0	2017-07-26 05:14:00+03	406100.00
802F01	2017-07-24 04:27:00+03	58900.00
802F24	2017-07-27 02:16:00+03	46000.00
802F35	2017-07-14 09:18:00+03	24200.00
802F37	2017-06-30 16:51:00+03	24400.00
802F6F	2017-07-16 10:13:00+03	38400.00
803029	2017-07-05 17:14:00+03	28000.00
80302A	2017-07-13 23:01:00+03	21600.00
803077	2017-08-08 16:49:00+03	90600.00
8030D5	2017-07-24 13:55:00+03	58200.00
803159	2017-07-04 22:23:00+03	135400.00
80316A	2017-07-29 16:36:00+03	84100.00
803184	2017-07-20 02:22:00+03	39000.00
80318C	2017-07-17 04:53:00+03	52100.00
8031E1	2017-07-27 03:02:00+03	85700.00
803275	2017-06-28 13:32:00+03	138100.00
803276	2017-08-14 16:51:00+03	75600.00
8032A1	2017-08-07 10:51:00+03	161500.00
803306	2017-07-04 02:22:00+03	58400.00
803309	2017-07-16 01:32:00+03	32700.00
80335C	2017-07-08 07:28:00+03	50600.00
80337D	2017-07-26 02:36:00+03	18000.00
8033D2	2017-06-25 14:41:00+03	136600.00
8033ED	2017-08-09 17:32:00+03	34000.00
803401	2017-07-16 05:34:00+03	106400.00
803402	2017-07-24 20:05:00+03	89700.00
803444	2017-07-21 07:14:00+03	216000.00
803477	2017-08-09 08:30:00+03	14400.00
8034A2	2017-07-23 10:38:00+03	84800.00
8034A4	2017-07-06 07:39:00+03	57900.00
8034C3	2017-08-06 05:35:00+03	135600.00
8034DD	2017-08-01 12:46:00+03	46400.00
8034DE	2017-07-21 07:09:00+03	143900.00
80354C	2017-08-02 11:53:00+03	49600.00
80355D	2017-08-07 12:15:00+03	25600.00
8035B8	2017-07-23 20:57:00+03	46400.00
8035C8	2017-07-06 08:38:00+03	48900.00
80365F	2017-07-16 01:33:00+03	99300.00
80368F	2017-07-10 01:54:00+03	101000.00
80369F	2017-06-28 15:27:00+03	63800.00
8036AA	2017-07-10 13:51:00+03	152900.00
803700	2017-08-13 13:34:00+03	257600.00
803705	2017-08-14 10:52:00+03	139800.00
80375A	2017-07-27 17:34:00+03	28800.00
80376A	2017-08-02 06:53:00+03	73600.00
80378E	2017-07-08 13:56:00+03	28800.00
8037C2	2017-07-10 20:15:00+03	26000.00
8037F4	2017-07-06 21:52:00+03	21400.00
80386A	2017-07-20 17:37:00+03	93900.00
803944	2017-07-15 03:43:00+03	8200.00
803974	2017-07-18 20:00:00+03	92800.00
803988	2017-07-31 16:48:00+03	71400.00
80399D	2017-07-13 09:35:00+03	76600.00
8039A8	2017-07-29 00:44:00+03	43200.00
803A56	2017-08-13 19:35:00+03	115900.00
803A8B	2017-07-05 20:20:00+03	26700.00
803A9F	2017-08-13 04:21:00+03	35500.00
803AB6	2017-08-01 15:49:00+03	174400.00
803ADB	2017-08-10 08:45:00+03	25000.00
803AEA	2017-07-10 13:43:00+03	28000.00
803B1A	2017-07-03 03:25:00+03	122700.00
803B5C	2017-07-13 08:52:00+03	393800.00
803BA5	2017-08-13 17:04:00+03	142300.00
803BE2	2017-07-21 01:19:00+03	117100.00
803BED	2017-07-25 22:06:00+03	32700.00
803C40	2017-07-30 16:33:00+03	143000.00
803C5D	2017-07-10 18:28:00+03	34000.00
803CC4	2017-07-06 21:13:00+03	46200.00
803D2B	2017-07-11 03:59:00+03	56000.00
803D38	2017-07-25 09:08:00+03	248500.00
803D88	2017-07-11 09:59:00+03	62800.00
803DEA	2017-08-14 15:51:00+03	60900.00
803DEC	2017-08-12 12:44:00+03	100700.00
803DF0	2017-07-29 04:07:00+03	64700.00
803E6A	2017-08-13 05:37:00+03	21800.00
803E9D	2017-07-23 11:04:00+03	398500.00
803EDF	2017-07-16 15:16:00+03	112600.00
803F23	2017-07-17 21:20:00+03	105100.00
803F41	2017-07-08 17:58:00+03	66600.00
804033	2017-07-13 22:04:00+03	28000.00
804078	2017-08-13 03:18:00+03	68400.00
8040B1	2017-07-07 14:36:00+03	99200.00
8040BB	2017-07-28 01:23:00+03	44500.00
8040CB	2017-07-16 15:48:00+03	60400.00
804127	2017-07-30 13:19:00+03	64500.00
80418F	2017-07-29 08:25:00+03	40000.00
8041C0	2017-08-05 19:56:00+03	28800.00
804222	2017-07-31 01:31:00+03	220200.00
80429C	2017-07-16 05:51:00+03	23200.00
8042BD	2017-07-03 22:25:00+03	26000.00
8042C0	2017-07-20 16:52:00+03	26000.00
8042C1	2017-08-04 13:33:00+03	134700.00
804303	2017-07-15 15:39:00+03	100600.00
8043EB	2017-07-26 09:25:00+03	86300.00
804407	2017-07-06 04:58:00+03	61800.00
80440D	2017-08-07 12:02:00+03	8000.00
804442	2017-08-06 01:58:00+03	18000.00
8044E3	2017-08-02 10:18:00+03	67000.00
80450D	2017-07-26 18:22:00+03	38200.00
804517	2017-08-14 22:57:00+03	29400.00
80451F	2017-07-08 17:20:00+03	57400.00
804558	2017-07-18 09:52:00+03	35700.00
804571	2017-07-02 01:04:00+03	60400.00
8045D0	2017-08-06 19:13:00+03	65600.00
804614	2017-07-03 07:27:00+03	44500.00
80470E	2017-06-30 04:45:00+03	81700.00
804748	2017-07-30 23:41:00+03	18600.00
80475A	2017-07-28 01:40:00+03	173900.00
80479F	2017-08-03 15:23:00+03	212300.00
8047D0	2017-07-25 17:32:00+03	49100.00
8047EC	2017-08-03 07:11:00+03	51600.00
80485D	2017-07-13 01:24:00+03	198200.00
804940	2017-08-15 14:33:00+03	13400.00
8049B2	2017-07-27 15:59:00+03	46500.00
804A4B	2017-07-23 08:31:00+03	346400.00
804A4E	2017-07-15 06:05:00+03	47000.00
804A8E	2017-07-25 15:03:00+03	67600.00
804AAF	2017-07-10 17:24:00+03	26200.00
804B27	2017-08-08 06:40:00+03	113700.00
804B48	2017-07-31 12:33:00+03	285200.00
804B8E	2017-07-26 07:39:00+03	28600.00
804BD8	2017-06-29 15:29:00+03	20500.00
804BF6	2017-08-15 01:10:00+03	133200.00
804C32	2017-07-12 08:29:00+03	258400.00
804C7C	2017-08-07 04:56:00+03	125200.00
804C9B	2017-07-07 06:38:00+03	23600.00
804D21	2017-07-21 16:49:00+03	369000.00
804D50	2017-07-05 00:57:00+03	24400.00
804D81	2017-08-14 04:01:00+03	42700.00
804D88	2017-08-13 09:45:00+03	14000.00
804D95	2017-07-12 19:16:00+03	186900.00
804D9F	2017-07-06 16:21:00+03	65400.00
804EED	2017-08-04 09:20:00+03	12800.00
804EF7	2017-07-08 14:48:00+03	136800.00
804F32	2017-07-15 00:14:00+03	277000.00
804F56	2017-07-05 12:13:00+03	119600.00
804F93	2017-07-23 04:31:00+03	47400.00
804FE1	2017-07-22 08:00:00+03	122600.00
80509A	2017-07-03 19:27:00+03	47100.00
80515C	2017-08-05 21:18:00+03	136500.00
80519A	2017-07-29 20:57:00+03	124300.00
8051A2	2017-08-08 11:28:00+03	10800.00
805218	2017-08-06 11:00:00+03	93700.00
805268	2017-08-12 03:11:00+03	65900.00
805269	2017-07-28 15:48:00+03	392100.00
805274	2017-07-30 10:58:00+03	47100.00
805284	2017-07-09 14:49:00+03	14400.00
8052BF	2017-08-04 05:13:00+03	16400.00
8052CF	2017-08-13 16:55:00+03	42900.00
805340	2017-08-15 06:51:00+03	41600.00
805363	2017-07-28 08:53:00+03	10800.00
8053D9	2017-07-25 20:02:00+03	44700.00
8053DB	2017-07-06 23:34:00+03	123000.00
805413	2017-08-05 06:18:00+03	15000.00
80543C	2017-07-25 13:46:00+03	25900.00
8054DA	2017-07-20 10:19:00+03	36100.00
805515	2017-08-14 13:14:00+03	8400.00
80552B	2017-07-07 12:51:00+03	135400.00
805570	2017-08-14 11:33:00+03	27900.00
80559A	2017-08-01 03:14:00+03	29100.00
80564F	2017-07-13 21:44:00+03	29600.00
80569B	2017-07-28 08:08:00+03	14000.00
8056E4	2017-07-08 14:56:00+03	32200.00
8056F1	2017-07-01 16:42:00+03	122400.00
80571F	2017-07-22 10:47:00+03	13400.00
80575D	2017-07-17 07:07:00+03	131100.00
8057B5	2017-08-06 21:45:00+03	100200.00
8057B8	2017-08-07 12:15:00+03	279600.00
80584D	2017-07-03 20:10:00+03	26000.00
805886	2017-08-09 22:27:00+03	92800.00
805897	2017-08-03 21:42:00+03	47200.00
805899	2017-07-09 17:38:00+03	56000.00
8058AF	2017-07-18 11:03:00+03	72300.00
8058C5	2017-07-02 19:19:00+03	65400.00
80592F	2017-07-15 01:42:00+03	117600.00
8059AC	2017-07-16 08:32:00+03	24600.00
805A19	2017-07-03 11:18:00+03	15900.00
805AA5	2017-08-11 21:48:00+03	26700.00
805B29	2017-07-05 23:38:00+03	26000.00
805B4D	2017-07-17 23:58:00+03	56000.00
805BD7	2017-08-12 02:40:00+03	27400.00
805BEF	2017-08-01 09:56:00+03	136500.00
805BFC	2017-07-11 12:28:00+03	40800.00
805C1F	2017-07-14 22:10:00+03	190400.00
805C59	2017-07-23 12:17:00+03	67200.00
805D0A	2017-07-28 13:14:00+03	115300.00
805D13	2017-08-11 09:21:00+03	50800.00
805D46	2017-08-05 17:18:00+03	111600.00
805D62	2017-08-11 03:51:00+03	67600.00
805D67	2017-07-16 08:17:00+03	29800.00
805D6B	2017-07-07 23:54:00+03	13400.00
805D71	2017-07-13 10:36:00+03	28000.00
805D79	2017-08-11 10:27:00+03	59800.00
805EC7	2017-08-06 11:05:00+03	53400.00
805EEE	2017-08-09 23:43:00+03	87900.00
805F0F	2017-07-09 13:32:00+03	31400.00
805F6D	2017-07-25 14:15:00+03	60700.00
805F80	2017-07-16 21:30:00+03	43900.00
805F87	2017-07-22 17:01:00+03	46500.00
80600E	2017-08-11 00:37:00+03	44800.00
80601E	2017-07-11 06:19:00+03	28600.00
806086	2017-08-13 22:39:00+03	54500.00
80609E	2017-07-12 10:20:00+03	112000.00
8060BD	2017-07-28 03:08:00+03	28000.00
8060E7	2017-07-13 07:28:00+03	67600.00
8060FC	2017-07-18 13:16:00+03	40800.00
806123	2017-07-14 22:51:00+03	68800.00
80612A	2017-07-04 01:05:00+03	109600.00
806135	2017-07-13 05:50:00+03	46800.00
806165	2017-07-21 06:35:00+03	31100.00
806177	2017-08-05 18:48:00+03	14800.00
8061F4	2017-07-30 06:07:00+03	51900.00
806215	2017-07-12 11:26:00+03	92600.00
80621B	2017-08-12 14:14:00+03	46200.00
80625E	2017-08-10 08:17:00+03	40400.00
80626A	2017-07-10 19:28:00+03	86600.00
806274	2017-07-07 07:34:00+03	246000.00
80629A	2017-07-04 01:35:00+03	189500.00
8062BF	2017-07-13 02:37:00+03	406100.00
8062D5	2017-07-23 03:37:00+03	67100.00
806318	2017-07-17 02:29:00+03	59800.00
806345	2017-07-28 16:37:00+03	128800.00
8063D2	2017-06-30 11:39:00+03	117600.00
80640E	2017-08-09 12:47:00+03	52600.00
8064DF	2017-07-16 11:30:00+03	12400.00
806530	2017-08-07 01:21:00+03	27200.00
806535	2017-08-01 22:03:00+03	189800.00
806640	2017-07-29 11:20:00+03	167400.00
806655	2017-07-21 07:50:00+03	16400.00
8066CE	2017-07-28 07:39:00+03	28000.00
8066F3	2017-07-01 23:37:00+03	177200.00
806730	2017-07-26 14:41:00+03	13400.00
806749	2017-07-01 12:43:00+03	40800.00
806785	2017-07-18 17:57:00+03	16400.00
8067BF	2017-07-04 02:11:00+03	48600.00
8067F7	2017-07-11 19:07:00+03	426700.00
806827	2017-08-04 19:56:00+03	59300.00
806864	2017-08-02 03:14:00+03	8800.00
8068DD	2017-07-11 11:32:00+03	43600.00
806906	2017-07-21 13:27:00+03	112400.00
806953	2017-07-15 06:29:00+03	79900.00
8069CB	2017-07-17 04:44:00+03	56900.00
806A18	2017-08-05 07:22:00+03	54800.00
806ACC	2017-07-29 20:10:00+03	125200.00
806ADD	2017-07-08 02:48:00+03	40100.00
806AEF	2017-07-13 21:18:00+03	65700.00
806B7C	2017-08-09 10:36:00+03	188200.00
806BC1	2017-07-10 16:00:00+03	37100.00
806BD4	2017-08-02 23:58:00+03	100600.00
806CC9	2017-08-06 21:09:00+03	88600.00
806D48	2017-07-16 22:41:00+03	33600.00
806D4F	2017-08-01 13:55:00+03	67800.00
806DCC	2017-07-09 11:36:00+03	178800.00
806DD2	2017-07-27 11:10:00+03	154400.00
806DE9	2017-07-03 19:14:00+03	61500.00
806E3C	2017-08-02 00:43:00+03	83700.00
806EC5	2017-08-13 15:01:00+03	81700.00
806ED4	2017-07-28 01:24:00+03	6300.00
806ED9	2017-08-06 06:39:00+03	57500.00
806F7D	2017-07-09 02:39:00+03	70100.00
806F9F	2017-07-19 23:24:00+03	46400.00
807018	2017-08-04 17:11:00+03	44800.00
807050	2017-07-08 08:21:00+03	19800.00
807069	2017-07-09 19:07:00+03	8200.00
80713E	2017-07-21 03:17:00+03	37900.00
80721B	2017-07-21 05:35:00+03	81500.00
80731C	2017-07-31 00:45:00+03	21400.00
80733E	2017-07-27 16:01:00+03	57400.00
80737D	2017-08-13 23:08:00+03	207200.00
8073CF	2017-08-11 04:27:00+03	39800.00
8073DF	2017-07-22 15:08:00+03	38600.00
807457	2017-08-12 20:16:00+03	88300.00
8074A8	2017-07-25 22:46:00+03	83000.00
8074AB	2017-07-27 11:15:00+03	46700.00
8074B0	2017-07-20 17:59:00+03	27300.00
8074D8	2017-07-17 02:25:00+03	53600.00
8074E1	2017-07-17 19:10:00+03	84100.00
80752F	2017-08-13 19:39:00+03	105100.00
807545	2017-07-30 00:45:00+03	6300.00
807587	2017-08-10 02:54:00+03	163900.00
8075C0	2017-07-01 02:22:00+03	23600.00
80766C	2017-07-16 22:47:00+03	31600.00
807733	2017-07-26 23:29:00+03	56100.00
807750	2017-08-14 00:45:00+03	38600.00
8077B4	2017-07-29 13:56:00+03	46400.00
8077DA	2017-07-09 04:53:00+03	27200.00
8077FC	2017-08-14 08:43:00+03	33000.00
80785E	2017-07-31 08:21:00+03	47700.00
8078C0	2017-08-03 06:24:00+03	16400.00
8078C3	2017-07-18 03:23:00+03	23900.00
807908	2017-07-16 07:17:00+03	23200.00
80794C	2017-08-02 17:21:00+03	63800.00
807952	2017-07-11 07:13:00+03	26600.00
807954	2017-07-16 20:57:00+03	71100.00
807956	2017-07-13 22:55:00+03	23200.00
807960	2017-08-11 00:50:00+03	57500.00
807980	2017-07-10 04:47:00+03	28800.00
807997	2017-06-30 06:06:00+03	12600.00
807A3B	2017-07-03 14:53:00+03	31600.00
807A71	2017-07-06 12:09:00+03	26800.00
807AF9	2017-08-06 14:01:00+03	27400.00
807B64	2017-07-25 17:29:00+03	46400.00
807BB1	2017-08-04 01:26:00+03	14000.00
807BD2	2017-07-02 08:10:00+03	67400.00
807BE7	2017-08-10 14:50:00+03	19600.00
807BF0	2017-08-08 00:26:00+03	48500.00
807C71	2017-07-09 05:08:00+03	131100.00
807C76	2017-07-29 21:13:00+03	97900.00
807C95	2017-06-30 20:28:00+03	201800.00
807CDD	2017-07-01 00:06:00+03	89600.00
807D1C	2017-07-24 11:42:00+03	131600.00
807D4D	2017-07-09 03:11:00+03	73500.00
807D92	2017-08-12 07:13:00+03	58800.00
807DF6	2017-07-11 19:59:00+03	28000.00
807E04	2017-07-17 03:22:00+03	68900.00
807E10	2017-08-12 19:03:00+03	47500.00
807E88	2017-07-20 15:34:00+03	80000.00
807E8F	2017-06-28 21:23:00+03	57700.00
807EF9	2017-07-18 03:19:00+03	112000.00
807F3E	2017-07-18 15:54:00+03	137600.00
807F5C	2017-07-20 17:31:00+03	31400.00
807FA0	2017-08-05 22:14:00+03	65900.00
807FAA	2017-07-02 14:06:00+03	28800.00
807FAC	2017-07-11 15:16:00+03	16400.00
807FBE	2017-07-15 16:51:00+03	170700.00
807FBF	2017-07-31 06:28:00+03	14000.00
807FC8	2017-07-26 01:26:00+03	155600.00
807FD0	2017-08-11 10:37:00+03	51800.00
808015	2017-07-11 19:00:00+03	75100.00
808030	2017-07-16 01:33:00+03	92400.00
808034	2017-07-09 18:34:00+03	145300.00
8080F9	2017-08-13 15:36:00+03	34000.00
80811B	2017-07-01 17:40:00+03	132800.00
808150	2017-07-30 13:44:00+03	13400.00
8081BD	2017-07-12 11:18:00+03	47000.00
8081D8	2017-07-23 10:26:00+03	38800.00
80822A	2017-07-09 15:46:00+03	84900.00
808236	2017-08-14 00:45:00+03	16800.00
808237	2017-07-12 08:57:00+03	396500.00
808281	2017-08-15 11:15:00+03	111600.00
8082C1	2017-07-18 00:54:00+03	28000.00
8082CE	2017-07-06 13:46:00+03	49800.00
80830C	2017-07-15 06:28:00+03	193900.00
808359	2017-08-01 18:26:00+03	135400.00
80836E	2017-07-28 21:49:00+03	40000.00
80839B	2017-07-21 21:57:00+03	20000.00
8083B4	2017-08-01 06:34:00+03	62700.00
8083CA	2017-08-13 20:02:00+03	51900.00
808401	2017-08-12 13:16:00+03	18400.00
808402	2017-07-31 18:16:00+03	57600.00
808427	2017-08-03 05:26:00+03	57800.00
8084AF	2017-08-07 03:49:00+03	398500.00
8084BC	2017-07-21 07:15:00+03	45200.00
80855D	2017-08-11 19:37:00+03	55100.00
808569	2017-07-16 01:45:00+03	16400.00
8085AD	2017-07-12 12:44:00+03	61800.00
8085C3	2017-07-11 07:56:00+03	40800.00
808654	2017-07-30 04:21:00+03	34000.00
808671	2017-08-15 15:47:00+03	31200.00
80869B	2017-07-18 23:14:00+03	70800.00
8086D2	2017-07-04 00:49:00+03	68400.00
8086DA	2017-07-04 13:39:00+03	116500.00
8086EB	2017-07-22 02:07:00+03	40800.00
808730	2017-07-17 08:24:00+03	25000.00
808793	2017-07-22 02:04:00+03	22000.00
8087FB	2017-08-08 19:27:00+03	51500.00
80882A	2017-07-18 06:57:00+03	15000.00
80883A	2017-07-01 15:59:00+03	81900.00
80883F	2017-08-02 01:50:00+03	273200.00
8088F3	2017-08-04 02:19:00+03	111200.00
80893F	2017-07-06 17:48:00+03	71600.00
8089CC	2017-07-24 07:10:00+03	75600.00
808A6A	2017-08-07 18:53:00+03	23400.00
808ABF	2017-08-14 01:40:00+03	52700.00
808B0E	2017-08-04 19:14:00+03	57400.00
808B4C	2017-08-03 21:59:00+03	62600.00
808BAB	2017-08-01 14:06:00+03	89600.00
808C39	2017-07-18 16:32:00+03	246000.00
808C70	2017-08-12 01:38:00+03	92800.00
808C8D	2017-07-27 18:46:00+03	45200.00
808CCB	2017-07-25 04:17:00+03	23200.00
808CF2	2017-07-05 08:41:00+03	26700.00
808D83	2017-07-28 13:49:00+03	46400.00
808D92	2017-07-20 22:50:00+03	66600.00
808DB4	2017-07-07 05:27:00+03	64100.00
808E1D	2017-07-14 23:00:00+03	138000.00
808E4E	2017-07-16 23:42:00+03	10600.00
808E69	2017-08-09 15:59:00+03	46200.00
808E95	2017-07-24 12:53:00+03	119600.00
808F63	2017-07-31 22:12:00+03	38800.00
808F72	2017-07-12 02:11:00+03	73300.00
808F7C	2017-07-07 22:07:00+03	27200.00
808F83	2017-08-15 13:33:00+03	147700.00
808F96	2017-07-12 05:41:00+03	28800.00
808FA7	2017-08-08 22:56:00+03	24700.00
808FCA	2017-08-13 20:54:00+03	38800.00
808FE6	2017-07-18 13:49:00+03	67600.00
809049	2017-07-02 21:57:00+03	8200.00
80904C	2017-07-24 18:45:00+03	56000.00
8090D2	2017-08-01 10:23:00+03	31200.00
80911D	2017-07-29 09:28:00+03	139800.00
809129	2017-07-24 00:44:00+03	95200.00
809142	2017-08-04 17:53:00+03	29400.00
809152	2017-07-06 19:47:00+03	25800.00
809181	2017-08-15 01:42:00+03	277800.00
80918C	2017-07-31 01:42:00+03	55800.00
8091CF	2017-07-19 02:06:00+03	332700.00
8091ED	2017-08-03 04:52:00+03	50400.00
80921B	2017-07-28 00:54:00+03	198400.00
809221	2017-07-14 20:44:00+03	22400.00
809257	2017-07-27 11:07:00+03	8200.00
809277	2017-07-30 16:53:00+03	22000.00
8092B8	2017-07-04 13:25:00+03	266400.00
8092CE	2017-07-01 03:12:00+03	14000.00
8092D8	2017-08-10 21:03:00+03	58600.00
8092E1	2017-07-21 05:56:00+03	26800.00
80937A	2017-07-12 11:17:00+03	174400.00
8093E6	2017-07-17 23:31:00+03	65000.00
8093FA	2017-08-02 05:16:00+03	16400.00
8093FB	2017-07-15 10:50:00+03	56000.00
80941F	2017-07-22 02:04:00+03	127200.00
80943A	2017-08-06 17:13:00+03	22600.00
809481	2017-07-20 20:01:00+03	57800.00
809491	2017-07-04 09:55:00+03	98200.00
8094A5	2017-08-08 17:03:00+03	20600.00
80950A	2017-08-05 09:11:00+03	39200.00
8095AE	2017-07-01 10:54:00+03	119300.00
809626	2017-07-28 23:00:00+03	48500.00
809656	2017-07-14 04:49:00+03	193600.00
809684	2017-07-31 15:08:00+03	44000.00
8096E1	2017-07-09 14:13:00+03	316000.00
809711	2017-07-12 10:46:00+03	26000.00
80975E	2017-07-20 13:11:00+03	58800.00
80977B	2017-08-09 18:48:00+03	34000.00
809792	2017-06-29 09:50:00+03	52000.00
8097FC	2017-07-11 13:16:00+03	57500.00
809819	2017-08-06 06:02:00+03	88800.00
809885	2017-08-13 11:18:00+03	210800.00
8098FE	2017-07-09 15:10:00+03	62400.00
809915	2017-07-04 22:34:00+03	144000.00
809918	2017-07-22 09:39:00+03	92900.00
8099B7	2017-08-13 18:17:00+03	99300.00
8099D4	2017-07-19 05:07:00+03	59100.00
809A10	2017-08-12 10:04:00+03	116400.00
809A1B	2017-07-01 04:34:00+03	26000.00
809A7D	2017-07-31 17:51:00+03	116000.00
809AA1	2017-08-12 07:23:00+03	18600.00
809B0B	2017-07-09 03:37:00+03	88100.00
809B30	2017-07-03 02:09:00+03	46400.00
809BB2	2017-08-14 14:46:00+03	25100.00
809BE3	2017-08-13 12:01:00+03	37900.00
809BE4	2017-07-10 20:02:00+03	152500.00
809BE5	2017-07-11 08:58:00+03	47000.00
809BFD	2017-07-31 13:17:00+03	76300.00
809C2F	2017-08-06 01:18:00+03	26700.00
809C4D	2017-07-22 11:21:00+03	101200.00
809CF2	2017-08-12 21:36:00+03	100600.00
809D46	2017-07-16 09:17:00+03	69500.00
809DC1	2017-07-11 01:09:00+03	176100.00
809DF8	2017-07-15 14:36:00+03	12200.00
809E91	2017-07-03 07:33:00+03	234800.00
809EFE	2017-07-07 23:20:00+03	23600.00
809F32	2017-07-11 07:07:00+03	40800.00
809FD6	2017-08-10 09:23:00+03	23600.00
80A004	2017-08-09 04:27:00+03	22000.00
80A047	2017-07-11 05:50:00+03	32900.00
80A07B	2017-07-26 21:08:00+03	369000.00
80A07F	2017-08-13 23:31:00+03	298000.00
80A131	2017-08-04 08:21:00+03	61800.00
80A159	2017-08-09 06:55:00+03	55800.00
80A15F	2017-07-28 01:24:00+03	48800.00
80A19D	2017-07-03 19:08:00+03	41600.00
80A21F	2017-07-13 18:51:00+03	43100.00
80A22B	2017-07-28 10:19:00+03	95600.00
80A253	2017-07-05 18:39:00+03	130900.00
80A276	2017-07-23 05:22:00+03	92100.00
80A2A0	2017-07-31 07:53:00+03	201200.00
80A31B	2017-07-31 16:32:00+03	354400.00
80A3E0	2017-07-28 16:24:00+03	10800.00
80A3EE	2017-07-18 04:52:00+03	91600.00
80A3F9	2017-08-06 19:31:00+03	16400.00
80A42B	2017-08-15 14:09:00+03	66600.00
80A461	2017-07-18 03:56:00+03	123000.00
80A525	2017-08-01 21:12:00+03	97600.00
80A55F	2017-07-25 21:55:00+03	52300.00
80A5A3	2017-08-08 11:51:00+03	20200.00
80A643	2017-07-03 20:41:00+03	129200.00
80A685	2017-07-25 09:04:00+03	56000.00
80A754	2017-07-17 07:33:00+03	248500.00
80A767	2017-07-27 00:46:00+03	111100.00
80A799	2017-07-30 13:38:00+03	21400.00
80A7C5	2017-07-03 13:02:00+03	99300.00
80A807	2017-07-07 23:48:00+03	28000.00
80A84B	2017-07-24 17:54:00+03	83000.00
80A8AD	2017-07-04 04:54:00+03	24400.00
80A8B5	2017-08-15 09:47:00+03	74100.00
80A8BF	2017-07-29 07:38:00+03	245300.00
80A931	2017-07-08 14:11:00+03	62700.00
80A986	2017-07-03 15:22:00+03	39300.00
80A9EA	2017-07-17 20:57:00+03	24000.00
80AA12	2017-07-28 19:40:00+03	19600.00
80AA58	2017-07-06 21:18:00+03	23200.00
80AACF	2017-07-30 17:40:00+03	26700.00
80AB0F	2017-07-19 06:00:00+03	13400.00
80AB90	2017-08-09 20:41:00+03	62900.00
80ABB9	2017-07-23 06:24:00+03	26000.00
80ABCF	2017-08-10 22:22:00+03	131600.00
80ABFB	2017-07-31 14:57:00+03	36200.00
80ACB0	2017-07-24 04:06:00+03	56600.00
80AD0B	2017-07-11 06:39:00+03	24800.00
80AD18	2017-07-07 17:48:00+03	46400.00
80AD3F	2017-07-07 10:41:00+03	189200.00
80AD4E	2017-07-14 03:36:00+03	28000.00
80ADA1	2017-08-06 10:06:00+03	67600.00
80AE44	2017-08-15 04:19:00+03	25800.00
80AF18	2017-07-04 15:47:00+03	83200.00
80AF91	2017-07-13 18:14:00+03	55600.00
80AFE2	2017-07-12 04:41:00+03	54800.00
80AFF2	2017-08-01 10:25:00+03	8000.00
80B000	2017-08-04 04:04:00+03	21400.00
80B036	2017-07-11 20:08:00+03	94000.00
80B09A	2017-08-13 15:54:00+03	57400.00
80B0E8	2017-07-14 14:34:00+03	26000.00
80B210	2017-07-05 02:19:00+03	41200.00
80B251	2017-08-05 01:07:00+03	196000.00
80B30A	2017-07-21 18:00:00+03	70600.00
80B317	2017-07-17 21:19:00+03	46900.00
80B33D	2017-07-16 14:00:00+03	112000.00
80B379	2017-08-11 08:03:00+03	62300.00
80B3A1	2017-07-31 08:16:00+03	56000.00
80B3DD	2017-08-09 02:11:00+03	67000.00
80B439	2017-07-18 07:52:00+03	88100.00
80B46A	2017-07-15 16:07:00+03	154800.00
80B49E	2017-07-15 12:15:00+03	28300.00
80B4CA	2017-08-01 01:03:00+03	19800.00
80B4E3	2017-07-29 16:08:00+03	79600.00
80B4F8	2017-08-01 00:58:00+03	19000.00
80B51A	2017-08-06 16:08:00+03	28000.00
80B537	2017-07-09 05:25:00+03	20400.00
80B598	2017-07-20 05:46:00+03	70800.00
80B68C	2017-08-06 14:38:00+03	134400.00
80B6AE	2017-07-05 13:22:00+03	38800.00
80B6E4	2017-07-29 16:08:00+03	66000.00
80B726	2017-08-08 07:24:00+03	90400.00
80B72A	2017-07-14 23:48:00+03	181600.00
80B76E	2017-07-21 16:39:00+03	53300.00
80B785	2017-07-22 08:40:00+03	53600.00
80B78F	2017-07-19 20:55:00+03	25200.00
80B7A3	2017-07-30 02:31:00+03	96800.00
80B7B2	2017-08-11 09:04:00+03	67100.00
80B838	2017-07-04 07:19:00+03	26800.00
80B85E	2017-08-13 12:37:00+03	173500.00
80B943	2017-08-01 23:57:00+03	54500.00
80B959	2017-08-06 13:53:00+03	55800.00
80B9A3	2017-08-08 19:46:00+03	23600.00
80B9A6	2017-07-06 09:20:00+03	410500.00
80B9FD	2017-08-08 01:09:00+03	116800.00
80BAE5	2017-07-14 01:37:00+03	11000.00
80BB6B	2017-07-27 06:33:00+03	241300.00
80BBDD	2017-07-24 10:06:00+03	16400.00
80BC24	2017-07-28 17:54:00+03	239400.00
80BC43	2017-08-09 07:01:00+03	46300.00
80BC7E	2017-07-29 02:55:00+03	45000.00
80BCE1	2017-08-09 18:54:00+03	60400.00
80BD2A	2017-08-06 17:48:00+03	85000.00
80BD75	2017-07-14 16:56:00+03	43200.00
80BDF1	2017-07-10 15:32:00+03	30400.00
80BE06	2017-07-06 18:56:00+03	99300.00
80BE6B	2017-07-17 15:34:00+03	24200.00
80BF48	2017-08-02 23:02:00+03	189200.00
80BF93	2017-08-10 15:25:00+03	103500.00
80BFBE	2017-06-29 07:25:00+03	73500.00
80BFD2	2017-07-09 04:57:00+03	58200.00
80BFF2	2017-08-03 00:33:00+03	106000.00
80C0B0	2017-07-22 10:09:00+03	63400.00
80C0CA	2017-07-15 03:05:00+03	98000.00
80C0CE	2017-07-10 05:52:00+03	260300.00
80C12E	2017-07-05 14:31:00+03	31400.00
80C1B0	2017-08-12 15:41:00+03	135400.00
80C1E1	2017-07-17 00:01:00+03	39100.00
80C214	2017-07-20 08:41:00+03	49600.00
80C230	2017-07-25 20:50:00+03	72400.00
80C23F	2017-07-21 08:53:00+03	80000.00
80C255	2017-07-19 23:52:00+03	36200.00
80C271	2017-07-28 15:27:00+03	11600.00
80C286	2017-07-24 17:28:00+03	24400.00
80C2A3	2017-07-23 17:05:00+03	10800.00
80C2EA	2017-08-15 00:49:00+03	111600.00
80C34A	2017-08-08 19:50:00+03	155600.00
80C3A1	2017-07-19 01:41:00+03	54100.00
80C43A	2017-08-04 21:48:00+03	16400.00
80C448	2017-07-03 15:39:00+03	55800.00
80C474	2017-07-05 07:40:00+03	51900.00
80C4CF	2017-07-13 15:03:00+03	47100.00
80C4D8	2017-07-05 13:00:00+03	139500.00
80C4F3	2017-07-18 05:53:00+03	56600.00
80C54C	2017-07-03 04:11:00+03	47600.00
80C54D	2017-07-30 15:10:00+03	133200.00
80C628	2017-07-10 22:15:00+03	58400.00
80C649	2017-07-04 09:41:00+03	20200.00
80C694	2017-07-25 17:14:00+03	49800.00
80C6AA	2017-07-11 23:14:00+03	399600.00
80C747	2017-07-15 14:37:00+03	26200.00
80C7D1	2017-07-14 11:31:00+03	198400.00
80C7D7	2017-07-04 14:23:00+03	6700.00
80C80C	2017-07-28 01:31:00+03	23200.00
80C812	2017-08-06 02:00:00+03	123000.00
80C83B	2017-08-09 16:39:00+03	48500.00
80C931	2017-06-28 16:45:00+03	51000.00
80C98C	2017-07-08 03:58:00+03	341000.00
80C996	2017-08-08 12:44:00+03	43200.00
80C998	2017-07-08 03:06:00+03	68000.00
80C9C5	2017-08-04 14:48:00+03	103200.00
80C9CC	2017-07-01 03:21:00+03	167400.00
80C9E8	2017-07-02 10:51:00+03	50800.00
80C9FC	2017-08-15 10:38:00+03	38800.00
80CA0C	2017-08-10 19:13:00+03	167400.00
80CA12	2017-07-25 12:16:00+03	117000.00
80CA2C	2017-07-15 13:03:00+03	30200.00
80CA6A	2017-07-19 11:29:00+03	105800.00
80CA92	2017-08-09 07:33:00+03	288900.00
80CAA1	2017-07-26 20:37:00+03	36200.00
80CB51	2017-07-26 02:19:00+03	93000.00
80CB65	2017-07-26 14:08:00+03	68800.00
80CBBA	2017-06-28 00:40:00+03	69000.00
80CC69	2017-08-02 07:36:00+03	18600.00
80CC81	2017-07-16 10:53:00+03	49900.00
80CD7A	2017-07-07 13:00:00+03	160400.00
80CDB7	2017-08-08 14:36:00+03	43800.00
80CE4C	2017-08-01 05:19:00+03	397100.00
80CED7	2017-08-09 08:50:00+03	26000.00
80CF86	2017-08-12 17:37:00+03	40600.00
80CF93	2017-07-27 10:05:00+03	67100.00
80CF97	2017-08-11 08:47:00+03	74100.00
80CFD1	2017-07-08 09:01:00+03	27300.00
80D01C	2017-07-09 14:59:00+03	28000.00
80D03B	2017-08-05 08:14:00+03	12600.00
80D06B	2017-08-09 14:19:00+03	6700.00
80D089	2017-07-13 06:14:00+03	44800.00
80D08D	2017-08-07 22:45:00+03	75300.00
80D0B0	2017-07-06 02:04:00+03	46300.00
80D11E	2017-08-02 00:09:00+03	89600.00
80D198	2017-07-23 10:57:00+03	202300.00
80D1C0	2017-07-28 08:05:00+03	13600.00
80D1DD	2017-08-05 13:41:00+03	6000.00
80D1E1	2017-07-26 11:23:00+03	112600.00
80D23D	2017-07-08 09:35:00+03	94900.00
80D271	2017-07-25 03:00:00+03	198900.00
80D313	2017-07-22 14:52:00+03	7300.00
80D32C	2017-07-28 09:17:00+03	14300.00
80D35A	2017-07-30 02:39:00+03	40000.00
80D376	2017-07-06 20:56:00+03	55800.00
80D3B4	2017-07-13 07:23:00+03	78000.00
80D48E	2017-07-28 11:20:00+03	21400.00
80D5BF	2017-08-12 09:06:00+03	30200.00
80D5F4	2017-08-14 05:23:00+03	123900.00
80D5F9	2017-08-13 18:53:00+03	200000.00
80D62E	2017-07-10 20:33:00+03	39400.00
80D6A2	2017-07-16 16:33:00+03	32800.00
80D6AA	2017-07-03 07:53:00+03	31100.00
80D6F9	2017-07-04 18:16:00+03	57500.00
80D763	2017-08-12 14:49:00+03	25200.00
80D7CD	2017-08-05 16:01:00+03	59200.00
80D7E2	2017-07-23 19:26:00+03	29600.00
80D827	2017-08-10 17:33:00+03	32800.00
80D83D	2017-08-11 12:26:00+03	134700.00
80D852	2017-07-03 15:00:00+03	67700.00
80D88A	2017-07-25 10:04:00+03	60700.00
80D896	2017-08-02 01:22:00+03	31100.00
80D90E	2017-07-19 16:32:00+03	133800.00
80D932	2017-06-27 10:45:00+03	181600.00
80D93B	2017-08-13 10:39:00+03	21500.00
80D96D	2017-08-06 05:39:00+03	12400.00
80D9A4	2017-08-14 06:22:00+03	91700.00
80D9B5	2017-08-05 21:08:00+03	26700.00
80D9E9	2017-07-23 20:58:00+03	66600.00
80DA37	2017-07-16 19:24:00+03	131100.00
80DA3C	2017-07-16 02:09:00+03	20600.00
80DABA	2017-07-22 04:59:00+03	25800.00
80DB65	2017-07-10 20:28:00+03	67000.00
80DB8C	2017-08-12 04:43:00+03	20500.00
80DC2B	2017-08-11 01:40:00+03	129700.00
80DC71	2017-08-14 10:16:00+03	14000.00
80DCC3	2017-07-23 07:27:00+03	45000.00
80DD35	2017-07-27 10:21:00+03	48800.00
80DD3A	2017-07-11 13:07:00+03	61800.00
80DD93	2017-08-08 08:24:00+03	23200.00
80DDCF	2017-07-07 16:18:00+03	112000.00
80DE2A	2017-07-20 07:45:00+03	118300.00
80DE60	2017-06-30 09:51:00+03	102100.00
80DE81	2017-07-16 17:58:00+03	86900.00
80DE93	2017-08-03 05:06:00+03	73100.00
80DEB2	2017-08-14 23:32:00+03	85600.00
80DED6	2017-07-29 19:00:00+03	25100.00
80DEF4	2017-07-30 23:20:00+03	28000.00
80DF0F	2017-08-07 18:57:00+03	64100.00
80DF56	2017-07-26 00:49:00+03	85500.00
80DF74	2017-07-27 23:58:00+03	28000.00
80DFC6	2017-07-31 05:28:00+03	139100.00
80DFD6	2017-07-17 23:47:00+03	31200.00
80DFE9	2017-08-08 17:18:00+03	6200.00
80DFF3	2017-07-06 08:45:00+03	46300.00
80E02B	2017-07-31 23:26:00+03	102400.00
80E067	2017-08-12 21:37:00+03	35300.00
80E0D5	2017-08-06 14:54:00+03	92400.00
80E0FB	2017-08-09 23:02:00+03	55800.00
80E169	2017-07-08 12:43:00+03	45100.00
80E261	2017-07-29 01:04:00+03	128800.00
80E2A8	2017-07-15 07:11:00+03	23900.00
80E2E0	2017-08-11 01:17:00+03	265600.00
80E2E8	2017-07-27 13:43:00+03	15000.00
80E369	2017-07-18 07:53:00+03	36100.00
80E3C2	2017-08-02 00:29:00+03	28000.00
80E40C	2017-07-28 22:21:00+03	90200.00
80E462	2017-07-04 12:43:00+03	27400.00
80E4A8	2017-07-24 04:17:00+03	69500.00
80E4AB	2017-07-20 19:08:00+03	55800.00
80E4BE	2017-07-15 02:11:00+03	228900.00
80E4C1	2017-08-13 03:40:00+03	113300.00
80E532	2017-07-15 02:09:00+03	38800.00
80E5AB	2017-07-21 17:28:00+03	43100.00
80E5BD	2017-06-30 11:41:00+03	272400.00
80E678	2017-07-11 11:07:00+03	12600.00
80E6A3	2017-07-15 01:30:00+03	422700.00
80E6C7	2017-08-07 00:21:00+03	492000.00
80E6D5	2017-07-07 00:40:00+03	28800.00
80E6E7	2017-07-25 13:59:00+03	80900.00
80E747	2017-07-08 09:46:00+03	58600.00
80E770	2017-07-16 11:01:00+03	35600.00
80E791	2017-08-03 00:56:00+03	246000.00
80E7D6	2017-08-11 00:29:00+03	55800.00
80E800	2017-07-18 16:28:00+03	56000.00
80E85D	2017-07-18 23:30:00+03	92400.00
80E8BE	2017-07-22 11:38:00+03	43700.00
80E8DC	2017-07-28 01:47:00+03	17200.00
80E940	2017-07-21 01:03:00+03	56900.00
80E950	2017-07-14 21:27:00+03	133200.00
80E99C	2017-07-24 13:37:00+03	14000.00
80E9E9	2017-07-11 23:02:00+03	40300.00
80EA03	2017-07-25 04:33:00+03	11100.00
80EA30	2017-07-31 22:56:00+03	269200.00
80EA33	2017-07-20 00:42:00+03	43200.00
80EA4A	2017-07-21 07:47:00+03	16400.00
80EAA9	2017-07-01 01:12:00+03	64800.00
80EAFA	2017-07-30 09:57:00+03	25800.00
80EB40	2017-07-25 07:26:00+03	50800.00
80EB42	2017-07-05 13:14:00+03	18600.00
80EB46	2017-08-12 15:45:00+03	48900.00
80EB8B	2017-08-12 20:09:00+03	41600.00
80EB96	2017-07-08 00:11:00+03	88900.00
80EC2D	2017-08-08 04:23:00+03	46400.00
80EC64	2017-07-28 19:07:00+03	30200.00
80EC72	2017-08-02 07:20:00+03	22200.00
80ED0F	2017-08-10 18:11:00+03	9300.00
80EEC9	2017-07-26 00:10:00+03	21000.00
80EED8	2017-08-02 09:00:00+03	17000.00
80EF15	2017-07-12 13:29:00+03	73500.00
80EF47	2017-07-01 21:37:00+03	112000.00
80EFBB	2017-08-14 20:30:00+03	32800.00
80EFE7	2017-07-06 13:51:00+03	23400.00
80F059	2017-08-07 23:22:00+03	13600.00
80F0EC	2017-08-02 05:52:00+03	75300.00
80F114	2017-07-12 16:19:00+03	142800.00
80F156	2017-07-12 09:20:00+03	53700.00
80F1F1	2017-07-19 05:53:00+03	27300.00
80F238	2017-08-09 14:10:00+03	46200.00
80F23E	2017-07-24 08:50:00+03	28000.00
80F268	2017-07-27 18:27:00+03	35500.00
80F28F	2017-08-08 13:39:00+03	43600.00
80F2AE	2017-07-03 17:26:00+03	132800.00
80F2B7	2017-07-18 19:21:00+03	28400.00
80F384	2017-07-28 08:58:00+03	131100.00
80F391	2017-07-19 09:36:00+03	30000.00
80F3EC	2017-08-04 05:58:00+03	39200.00
80F432	2017-08-11 19:44:00+03	37700.00
80F46B	2017-08-06 00:19:00+03	13400.00
80F485	2017-08-10 23:11:00+03	29600.00
80F4AA	2017-08-15 02:09:00+03	139400.00
80F535	2017-07-06 07:58:00+03	23200.00
80F53A	2017-08-03 05:05:00+03	48900.00
80F569	2017-07-07 04:32:00+03	81300.00
80F573	2017-07-19 14:15:00+03	103200.00
80F57A	2017-07-21 08:52:00+03	73700.00
80F5D2	2017-08-08 23:21:00+03	39200.00
80F5DF	2017-08-05 17:30:00+03	27200.00
80F627	2017-06-26 19:08:00+03	61500.00
80F6A3	2017-07-15 08:08:00+03	97400.00
80F6A6	2017-07-04 18:18:00+03	100000.00
80F6C9	2017-07-28 13:24:00+03	48700.00
80F6CB	2017-08-11 13:59:00+03	38600.00
80F73F	2017-07-24 01:49:00+03	24400.00
80F767	2017-08-05 19:28:00+03	28800.00
80F787	2017-07-27 22:20:00+03	86600.00
80F7D8	2017-08-07 02:09:00+03	235500.00
80F7E0	2017-07-14 07:05:00+03	7400.00
80F8D1	2017-07-24 09:23:00+03	7800.00
80F8F3	2017-07-19 15:17:00+03	113100.00
80F930	2017-07-23 14:26:00+03	170700.00
80F9A6	2017-08-05 17:05:00+03	75600.00
80F9CD	2017-07-16 06:00:00+03	51100.00
80F9F1	2017-07-03 21:25:00+03	72800.00
80FA38	2017-07-09 19:38:00+03	55000.00
80FA6E	2017-07-28 13:04:00+03	88600.00
80FAAA	2017-07-08 17:51:00+03	102100.00
80FAF4	2017-07-15 07:00:00+03	27200.00
80FAF8	2017-08-10 22:40:00+03	14000.00
80FAFD	2017-07-06 08:08:00+03	139700.00
80FB0B	2017-08-08 16:35:00+03	21800.00
80FB86	2017-07-21 06:26:00+03	56000.00
80FBB3	2017-07-27 08:17:00+03	85000.00
80FBDE	2017-07-23 12:36:00+03	49600.00
80FBDF	2017-07-25 03:28:00+03	13400.00
80FBE2	2017-07-26 23:55:00+03	92000.00
80FBEF	2017-07-20 17:36:00+03	158700.00
80FC8E	2017-07-05 09:29:00+03	87200.00
80FC9C	2017-07-19 22:06:00+03	170000.00
80FD09	2017-07-31 20:02:00+03	339900.00
80FD16	2017-07-22 06:15:00+03	266300.00
80FDC4	2017-07-13 21:11:00+03	24700.00
80FE05	2017-08-04 09:13:00+03	48900.00
80FE89	2017-08-15 05:52:00+03	34700.00
80FE93	2017-07-04 20:35:00+03	103100.00
80FEE3	2017-08-12 03:20:00+03	27200.00
80FF26	2017-07-27 11:54:00+03	22600.00
80FF44	2017-07-10 07:33:00+03	28000.00
80FF4D	2017-07-31 18:50:00+03	26000.00
80FF71	2017-08-06 05:30:00+03	180100.00
80FF97	2017-07-26 13:29:00+03	39600.00
80FFAD	2017-07-07 18:57:00+03	44600.00
80FFE1	2017-07-30 18:41:00+03	30800.00
80FFE2	2017-07-14 08:06:00+03	15000.00
80FFFB	2017-08-09 21:10:00+03	124300.00
80FFFE	2017-07-17 13:51:00+03	14400.00
810013	2017-07-05 04:00:00+03	40000.00
81001D	2017-06-29 08:37:00+03	92800.00
810079	2017-07-22 19:44:00+03	41600.00
8100BA	2017-08-08 20:14:00+03	56000.00
8100EA	2017-07-29 06:49:00+03	172300.00
8100FE	2017-08-04 02:28:00+03	99300.00
810139	2017-07-28 01:03:00+03	24600.00
81013B	2017-08-08 16:29:00+03	41400.00
8101E5	2017-06-30 02:45:00+03	73200.00
810204	2017-07-25 08:49:00+03	73300.00
81020B	2017-06-30 04:59:00+03	86300.00
810239	2017-07-06 19:23:00+03	131800.00
810258	2017-07-20 18:14:00+03	62800.00
810295	2017-08-15 01:18:00+03	25400.00
8102B3	2017-07-07 15:43:00+03	28600.00
8102D4	2017-07-04 13:13:00+03	15000.00
8102D8	2017-08-05 18:50:00+03	53900.00
810323	2017-07-23 03:45:00+03	99300.00
81036F	2017-08-08 12:50:00+03	106100.00
8103E7	2017-07-18 21:24:00+03	28800.00
81041C	2017-07-20 03:35:00+03	44000.00
81044C	2017-07-17 09:19:00+03	111600.00
8104AB	2017-07-14 21:11:00+03	199700.00
8104C6	2017-07-31 18:22:00+03	46400.00
8104D2	2017-06-26 01:21:00+03	37900.00
8104FC	2017-07-27 13:16:00+03	38700.00
810504	2017-07-26 16:37:00+03	134400.00
810506	2017-07-27 09:46:00+03	37100.00
81056D	2017-07-29 18:13:00+03	37200.00
81064E	2017-07-19 20:54:00+03	37700.00
81065B	2017-07-04 22:13:00+03	116700.00
810688	2017-07-16 10:59:00+03	105600.00
8106FC	2017-07-25 14:15:00+03	46400.00
81075A	2017-08-12 00:01:00+03	133100.00
810770	2017-07-21 11:57:00+03	222100.00
810896	2017-08-02 09:07:00+03	48400.00
810920	2017-07-16 20:58:00+03	23600.00
81094D	2017-07-21 08:56:00+03	25600.00
81096B	2017-07-30 14:51:00+03	43500.00
810984	2017-08-08 21:17:00+03	23600.00
81099D	2017-08-11 16:32:00+03	12200.00
8109E1	2017-07-22 15:30:00+03	36600.00
810A17	2017-07-09 07:42:00+03	266400.00
810A24	2017-07-07 03:27:00+03	69500.00
810A3A	2017-08-12 20:56:00+03	47400.00
810A4E	2017-06-29 01:46:00+03	16400.00
810AD3	2017-07-25 19:34:00+03	6300.00
810B0D	2017-07-20 20:18:00+03	73100.00
810B2E	2017-08-01 15:37:00+03	265700.00
810B2F	2017-07-04 10:03:00+03	124200.00
810B42	2017-08-13 01:24:00+03	28800.00
810B74	2017-07-19 10:06:00+03	62600.00
810BAB	2017-08-04 00:19:00+03	113200.00
810C1C	2017-07-09 08:01:00+03	35400.00
810C37	2017-07-06 02:29:00+03	30200.00
810C4E	2017-07-04 13:33:00+03	34000.00
810C54	2017-08-03 05:48:00+03	65500.00
810C5D	2017-06-30 16:13:00+03	101800.00
810CD1	2017-07-29 15:44:00+03	18000.00
810CEF	2017-08-05 14:26:00+03	51600.00
810D46	2017-07-21 11:02:00+03	116300.00
810D56	2017-07-12 19:09:00+03	21800.00
810D59	2017-08-07 10:11:00+03	96300.00
810DA5	2017-07-14 23:08:00+03	23500.00
810E2C	2017-07-16 11:04:00+03	66600.00
810E51	2017-07-08 10:33:00+03	55800.00
810E86	2017-07-22 11:34:00+03	36000.00
810EEC	2017-08-05 22:30:00+03	39100.00
810FD0	2017-07-02 00:41:00+03	64800.00
811049	2017-07-03 18:05:00+03	12600.00
81104C	2017-08-10 12:07:00+03	148200.00
811129	2017-06-29 09:51:00+03	105100.00
81117F	2017-07-24 15:07:00+03	76300.00
811193	2017-08-14 23:09:00+03	123000.00
8111C4	2017-08-10 16:16:00+03	75300.00
811206	2017-08-13 10:21:00+03	86500.00
811241	2017-08-03 03:30:00+03	67600.00
811273	2017-08-02 09:10:00+03	36200.00
811283	2017-07-29 09:42:00+03	48800.00
811293	2017-08-02 08:39:00+03	234600.00
811295	2017-07-06 16:39:00+03	6300.00
8112AB	2017-07-14 18:41:00+03	88500.00
8112AC	2017-08-02 16:47:00+03	45100.00
8112FC	2017-07-26 20:18:00+03	28800.00
81133E	2017-07-03 01:39:00+03	31100.00
811353	2017-07-07 08:48:00+03	6600.00
8113B1	2017-07-28 05:45:00+03	56900.00
81145F	2017-08-14 07:35:00+03	50300.00
8114CD	2017-07-19 01:46:00+03	23200.00
811536	2017-07-31 16:48:00+03	23200.00
81156A	2017-07-31 13:29:00+03	32600.00
8115D1	2017-07-10 11:37:00+03	24800.00
8116BD	2017-07-07 14:13:00+03	9800.00
81172A	2017-07-14 07:02:00+03	203000.00
81179D	2017-07-23 02:15:00+03	80900.00
811869	2017-07-27 10:53:00+03	23600.00
8118EB	2017-08-05 01:04:00+03	40600.00
8118EE	2017-07-28 19:29:00+03	35600.00
8118F9	2017-07-21 19:00:00+03	56000.00
8118FD	2017-06-30 08:54:00+03	74000.00
811941	2017-07-16 13:19:00+03	70700.00
8119CB	2017-07-01 19:05:00+03	173600.00
811A17	2017-07-31 16:54:00+03	23600.00
811A2D	2017-07-19 22:15:00+03	75300.00
811A8E	2017-07-31 14:53:00+03	49200.00
811A8F	2017-08-10 12:58:00+03	83200.00
811AA2	2017-07-14 16:15:00+03	29400.00
811AF2	2017-08-06 03:41:00+03	90700.00
811B1A	2017-07-05 00:25:00+03	33100.00
811B51	2017-07-22 15:44:00+03	21400.00
811B88	2017-07-15 09:06:00+03	199700.00
811C42	2017-07-18 03:18:00+03	129200.00
811C81	2017-08-08 23:28:00+03	115000.00
811CCF	2017-07-09 15:47:00+03	31900.00
811CF2	2017-08-07 19:22:00+03	26000.00
811D06	2017-07-08 21:51:00+03	27900.00
811D0D	2017-07-30 04:12:00+03	7400.00
811D13	2017-07-13 02:16:00+03	37000.00
811D2E	2017-07-28 03:26:00+03	12600.00
811D33	2017-07-01 18:25:00+03	82200.00
811D37	2017-08-05 18:06:00+03	85000.00
811DE7	2017-07-18 21:58:00+03	57600.00
811DF2	2017-07-04 09:18:00+03	32800.00
811E56	2017-07-02 13:37:00+03	62700.00
811E62	2017-08-12 09:11:00+03	100200.00
811E87	2017-07-02 02:19:00+03	16400.00
811EB4	2017-08-05 00:21:00+03	57600.00
811EC0	2017-08-02 06:29:00+03	109600.00
811F10	2017-07-12 19:42:00+03	123200.00
811F23	2017-08-06 08:33:00+03	304200.00
811F2C	2017-07-05 06:43:00+03	125200.00
811F35	2017-07-19 12:09:00+03	39700.00
811FA8	2017-07-17 23:58:00+03	56000.00
811FAC	2017-08-05 12:16:00+03	70400.00
811FBE	2017-08-07 09:27:00+03	8000.00
811FCE	2017-07-26 04:16:00+03	129000.00
812013	2017-07-14 21:42:00+03	54400.00
812019	2017-07-21 02:25:00+03	12400.00
812037	2017-06-29 06:50:00+03	44600.00
812043	2017-07-26 01:04:00+03	95200.00
812099	2017-08-03 12:36:00+03	34000.00
8120A6	2017-08-11 12:28:00+03	28000.00
81214D	2017-07-24 19:28:00+03	98400.00
8121A5	2017-07-06 10:14:00+03	83200.00
8121D3	2017-07-07 18:49:00+03	11300.00
8121D4	2017-07-09 06:25:00+03	58200.00
8121EA	2017-08-01 18:42:00+03	103500.00
812285	2017-07-30 16:20:00+03	74900.00
8122BE	2017-07-18 05:41:00+03	35600.00
8122F9	2017-07-06 20:49:00+03	55800.00
812310	2017-07-20 06:47:00+03	109600.00
812342	2017-07-21 19:12:00+03	52300.00
81239C	2017-07-27 13:18:00+03	20000.00
8123D3	2017-08-03 08:53:00+03	64400.00
812475	2017-08-05 08:46:00+03	55800.00
81247C	2017-07-05 18:09:00+03	46200.00
8124D2	2017-07-12 17:28:00+03	34000.00
81261E	2017-08-10 19:16:00+03	56600.00
812632	2017-08-06 21:40:00+03	38800.00
81269A	2017-07-18 18:38:00+03	94000.00
812720	2017-08-13 15:58:00+03	22000.00
812722	2017-07-01 20:27:00+03	55800.00
81274C	2017-07-03 00:16:00+03	13400.00
812797	2017-08-04 23:09:00+03	92100.00
8127A2	2017-07-17 04:27:00+03	26000.00
8127BB	2017-07-14 04:03:00+03	28000.00
812829	2017-07-08 05:58:00+03	20400.00
81283E	2017-08-06 19:02:00+03	59800.00
812849	2017-07-20 18:50:00+03	7900.00
812883	2017-07-02 08:08:00+03	16400.00
81289E	2017-08-04 08:17:00+03	15800.00
8128B3	2017-07-12 02:09:00+03	112000.00
8128DC	2017-08-11 17:07:00+03	67800.00
8128E1	2017-07-07 09:36:00+03	23600.00
8128F3	2017-08-04 19:18:00+03	56000.00
812901	2017-08-03 18:46:00+03	21800.00
81295E	2017-07-04 22:44:00+03	60700.00
81299A	2017-07-29 01:40:00+03	24400.00
8129FC	2017-07-27 11:14:00+03	93900.00
812A0D	2017-08-09 03:33:00+03	26000.00
812A0F	2017-08-05 03:11:00+03	138000.00
812A38	2017-08-03 16:33:00+03	70600.00
812A54	2017-07-27 10:20:00+03	27300.00
812A82	2017-07-19 05:24:00+03	63200.00
812A93	2017-07-23 14:09:00+03	46400.00
812ADA	2017-07-01 19:58:00+03	22000.00
812B1C	2017-08-11 02:04:00+03	36200.00
812B2C	2017-08-01 04:11:00+03	20400.00
812B52	2017-08-03 02:10:00+03	32800.00
812B69	2017-07-15 23:08:00+03	179500.00
812B6E	2017-08-15 09:40:00+03	123000.00
812B74	2017-07-31 17:35:00+03	195900.00
812B86	2017-07-22 15:24:00+03	159600.00
812BB9	2017-08-05 14:46:00+03	139400.00
812BBA	2017-07-22 09:17:00+03	111700.00
812BC6	2017-08-12 00:45:00+03	58600.00
812BDB	2017-07-19 12:55:00+03	62000.00
812BEE	2017-08-08 12:13:00+03	47500.00
812C34	2017-08-13 16:34:00+03	15800.00
812C3D	2017-07-10 07:42:00+03	66600.00
812C57	2017-07-08 16:50:00+03	6300.00
812C99	2017-08-12 11:12:00+03	40400.00
812CB1	2017-07-02 20:42:00+03	59000.00
812CD3	2017-07-07 03:42:00+03	266200.00
812D13	2017-08-10 12:16:00+03	25400.00
812D32	2017-07-04 14:56:00+03	152100.00
812D59	2017-07-31 07:58:00+03	53400.00
812D5B	2017-08-03 07:54:00+03	44800.00
812D81	2017-07-26 12:49:00+03	248400.00
812D93	2017-07-14 05:58:00+03	66100.00
812DA4	2017-08-13 23:22:00+03	46700.00
812DDB	2017-06-28 10:15:00+03	138100.00
812E58	2017-08-05 01:07:00+03	89700.00
812E5C	2017-08-02 06:53:00+03	20400.00
812E5F	2017-07-26 16:43:00+03	49300.00
812E6E	2017-07-28 07:06:00+03	62900.00
812E7A	2017-07-21 19:36:00+03	79800.00
812E96	2017-07-17 16:39:00+03	101900.00
812F08	2017-08-13 17:23:00+03	248300.00
812F2E	2017-08-01 00:00:00+03	46800.00
812F54	2017-07-25 09:42:00+03	58600.00
8130C1	2017-08-01 21:12:00+03	68800.00
813105	2017-08-03 12:42:00+03	59100.00
813134	2017-07-16 11:02:00+03	16400.00
813136	2017-08-05 04:43:00+03	27000.00
8131A1	2017-07-15 17:02:00+03	28000.00
813285	2017-07-09 02:17:00+03	31600.00
8132CE	2017-07-11 03:39:00+03	42700.00
8132EB	2017-06-29 02:36:00+03	11800.00
813372	2017-07-17 16:06:00+03	20400.00
81338C	2017-08-14 08:36:00+03	14800.00
8133CA	2017-08-04 09:55:00+03	56600.00
8133F6	2017-07-10 17:40:00+03	77900.00
813416	2017-08-09 00:12:00+03	25400.00
813433	2017-08-04 10:42:00+03	28000.00
81344C	2017-08-02 10:18:00+03	70500.00
81348C	2017-07-09 12:19:00+03	29600.00
8134A9	2017-07-04 03:11:00+03	221000.00
8134D1	2017-07-08 11:32:00+03	248300.00
8134EF	2017-07-14 03:28:00+03	27000.00
8134F4	2017-07-25 05:20:00+03	47600.00
81350C	2017-07-19 14:55:00+03	202600.00
813525	2017-07-06 12:20:00+03	12600.00
813534	2017-07-12 07:36:00+03	15000.00
813547	2017-08-01 07:47:00+03	28000.00
81357F	2017-07-07 12:02:00+03	52400.00
8135B3	2017-08-01 19:10:00+03	86400.00
8135DF	2017-07-18 13:28:00+03	73300.00
8135E5	2017-07-07 21:03:00+03	136100.00
813708	2017-08-09 22:59:00+03	44000.00
81372C	2017-07-01 03:14:00+03	24400.00
813788	2017-07-07 06:25:00+03	82600.00
8137AF	2017-07-18 06:20:00+03	40600.00
8137B0	2017-08-12 06:15:00+03	39800.00
813887	2017-08-06 04:35:00+03	34900.00
8138E2	2017-08-05 17:43:00+03	139700.00
8138F9	2017-08-13 03:44:00+03	88800.00
81392F	2017-08-03 21:16:00+03	26000.00
8139F3	2017-06-30 12:39:00+03	97900.00
8139F7	2017-08-09 18:07:00+03	82900.00
813A78	2017-07-24 22:03:00+03	62800.00
813AE0	2017-08-10 15:35:00+03	57600.00
813B69	2017-06-29 12:35:00+03	125400.00
813BAD	2017-07-31 00:08:00+03	85700.00
813BD6	2017-07-15 09:20:00+03	44000.00
813C06	2017-07-05 01:53:00+03	75100.00
813C4C	2017-07-07 00:36:00+03	46800.00
813C67	2017-07-08 20:12:00+03	50800.00
813C88	2017-08-09 02:30:00+03	13700.00
813CA9	2017-07-07 13:18:00+03	22800.00
813CAA	2017-07-29 06:47:00+03	212200.00
813CBE	2017-07-23 01:39:00+03	55800.00
813D68	2017-08-08 03:41:00+03	48800.00
813D73	2017-08-10 11:23:00+03	40800.00
813DFB	2017-07-10 00:22:00+03	38200.00
813F03	2017-07-08 02:58:00+03	92800.00
813F0A	2017-07-08 02:58:00+03	135000.00
813F56	2017-07-22 14:30:00+03	160100.00
813F9E	2017-08-12 15:22:00+03	40000.00
813FB9	2017-08-06 07:53:00+03	16400.00
813FC5	2017-07-28 21:28:00+03	150000.00
81400B	2017-07-26 02:26:00+03	28800.00
814018	2017-07-09 03:31:00+03	28000.00
81407A	2017-07-18 09:10:00+03	58600.00
81415B	2017-07-25 08:41:00+03	46000.00
81415D	2017-08-13 16:04:00+03	26500.00
814162	2017-08-05 08:52:00+03	246000.00
81419A	2017-07-10 14:48:00+03	19600.00
8141B5	2017-07-22 19:15:00+03	92400.00
8141FB	2017-07-18 05:29:00+03	69500.00
81422E	2017-07-17 07:14:00+03	64800.00
8142A3	2017-07-29 16:36:00+03	60700.00
814388	2017-07-10 22:53:00+03	71200.00
8143C3	2017-07-13 05:53:00+03	56000.00
8143D4	2017-07-18 20:24:00+03	10800.00
8143EA	2017-07-05 07:51:00+03	45200.00
814425	2017-06-30 13:01:00+03	277800.00
8144E6	2017-07-29 07:50:00+03	12000.00
814506	2017-08-12 17:56:00+03	173000.00
814537	2017-07-06 07:19:00+03	97700.00
814546	2017-07-06 04:55:00+03	178200.00
81454B	2017-07-21 21:42:00+03	76300.00
814688	2017-08-02 22:19:00+03	406700.00
81468B	2017-07-09 14:01:00+03	72400.00
814712	2017-07-08 04:50:00+03	26800.00
814757	2017-07-21 13:23:00+03	13600.00
81475B	2017-08-08 02:31:00+03	69100.00
8147A5	2017-07-15 02:43:00+03	28800.00
81481A	2017-08-12 20:06:00+03	13400.00
814860	2017-07-13 09:36:00+03	62600.00
8148BC	2017-07-30 15:41:00+03	39600.00
8148BE	2017-07-22 07:19:00+03	51600.00
8148E7	2017-07-30 15:14:00+03	100600.00
814913	2017-07-26 00:30:00+03	28800.00
814932	2017-07-20 20:50:00+03	199700.00
81496A	2017-07-08 07:18:00+03	26000.00
8149AB	2017-06-26 18:40:00+03	99700.00
8149FC	2017-08-15 05:19:00+03	47200.00
814A36	2017-08-08 08:03:00+03	52000.00
814A37	2017-08-01 22:33:00+03	120400.00
814A49	2017-08-09 02:03:00+03	24400.00
814A76	2017-08-14 22:00:00+03	20800.00
814AAB	2017-07-18 03:36:00+03	113300.00
814AE6	2017-07-17 06:16:00+03	29800.00
814BC8	2017-07-08 12:48:00+03	76600.00
814BEB	2017-07-06 18:28:00+03	28000.00
814C3D	2017-08-05 02:25:00+03	55800.00
814C44	2017-08-01 22:03:00+03	92800.00
814C52	2017-07-07 18:07:00+03	73200.00
814C78	2017-08-12 22:35:00+03	40400.00
814C9E	2017-08-10 16:55:00+03	20200.00
814CA8	2017-08-12 22:20:00+03	75900.00
814CC4	2017-07-11 23:00:00+03	62100.00
814CCB	2017-07-05 16:14:00+03	63800.00
814CEE	2017-07-13 19:33:00+03	46400.00
814D0D	2017-07-06 20:48:00+03	392200.00
814DE4	2017-07-29 20:36:00+03	30200.00
814DF8	2017-07-16 00:17:00+03	25400.00
814E28	2017-08-14 20:14:00+03	108500.00
814E4E	2017-07-12 12:19:00+03	73600.00
814E70	2017-07-07 12:04:00+03	22000.00
814EF3	2017-08-06 11:30:00+03	10800.00
814F28	2017-07-28 02:18:00+03	24300.00
814F65	2017-07-31 00:48:00+03	123000.00
815031	2017-07-08 16:26:00+03	14000.00
81504C	2017-07-22 23:59:00+03	40800.00
81507C	2017-07-06 00:46:00+03	66700.00
815097	2017-08-11 01:57:00+03	122500.00
8150C0	2017-08-15 06:45:00+03	34800.00
815102	2017-08-14 21:45:00+03	258400.00
815114	2017-06-28 07:51:00+03	99300.00
815171	2017-06-29 12:47:00+03	170500.00
8151FA	2017-07-03 04:35:00+03	46800.00
815251	2017-07-10 05:03:00+03	16400.00
815255	2017-07-16 17:22:00+03	531000.00
815292	2017-08-13 22:48:00+03	29600.00
8153B9	2017-07-19 05:34:00+03	191000.00
8153F6	2017-08-15 13:13:00+03	68100.00
81540C	2017-08-15 00:02:00+03	40800.00
81540D	2017-08-06 01:33:00+03	24000.00
81543C	2017-07-17 05:15:00+03	183300.00
8154A5	2017-08-14 04:05:00+03	25800.00
8154B2	2017-07-12 05:59:00+03	6700.00
8154BD	2017-08-10 21:43:00+03	243600.00
8154DE	2017-07-04 05:03:00+03	213200.00
8154FF	2017-08-12 23:26:00+03	277600.00
815542	2017-07-12 01:13:00+03	96800.00
8155D5	2017-06-29 08:10:00+03	67600.00
81560C	2017-08-13 06:47:00+03	159500.00
81560F	2017-07-18 22:50:00+03	67200.00
815628	2017-08-02 04:33:00+03	124200.00
8156EB	2017-08-11 20:52:00+03	40600.00
8156F1	2017-06-22 10:03:00+03	224300.00
815793	2017-07-15 11:29:00+03	53600.00
8157A0	2017-07-23 23:26:00+03	120100.00
815802	2017-07-19 12:05:00+03	55800.00
81582B	2017-07-05 03:27:00+03	88300.00
815890	2017-08-09 06:35:00+03	6700.00
81599B	2017-07-15 08:02:00+03	30200.00
815A49	2017-08-06 06:38:00+03	61800.00
815AC3	2017-07-21 18:11:00+03	56600.00
815B23	2017-07-13 14:52:00+03	170700.00
815B29	2017-07-17 04:26:00+03	37700.00
815B54	2017-07-25 03:32:00+03	47400.00
815B95	2017-07-20 17:10:00+03	35600.00
815B96	2017-07-13 23:28:00+03	205700.00
815BC5	2017-07-20 03:49:00+03	113200.00
815BD8	2017-08-05 23:45:00+03	136200.00
815C79	2017-07-06 05:36:00+03	139500.00
815CA5	2017-07-26 15:27:00+03	85000.00
815CA9	2017-08-07 23:13:00+03	266200.00
815D00	2017-08-14 04:39:00+03	86900.00
815DD0	2017-07-09 08:21:00+03	187600.00
815DDD	2017-08-05 02:58:00+03	68800.00
815E56	2017-07-10 23:34:00+03	133200.00
815E74	2017-07-28 05:48:00+03	57400.00
815E82	2017-07-29 05:05:00+03	16000.00
815F7C	2017-08-10 13:44:00+03	131600.00
815FE8	2017-08-05 20:50:00+03	58800.00
815FFC	2017-08-09 02:38:00+03	102100.00
81602B	2017-07-27 07:42:00+03	43200.00
816079	2017-07-14 05:16:00+03	16400.00
81607C	2017-07-21 15:54:00+03	52400.00
8160E0	2017-07-23 04:46:00+03	58000.00
8160EF	2017-07-11 18:09:00+03	56600.00
816105	2017-08-14 13:06:00+03	27000.00
81614A	2017-07-09 10:58:00+03	168000.00
816184	2017-07-06 02:26:00+03	56000.00
816185	2017-07-09 15:52:00+03	105100.00
8161EC	2017-07-21 12:35:00+03	75600.00
81622D	2017-07-13 06:32:00+03	27200.00
816256	2017-07-24 14:45:00+03	56600.00
81625D	2017-08-03 12:32:00+03	135600.00
81626A	2017-08-15 10:03:00+03	86600.00
8162CE	2017-08-01 09:49:00+03	149300.00
8162FF	2017-07-21 15:03:00+03	111100.00
81639E	2017-07-04 15:54:00+03	101200.00
8163C8	2017-07-21 04:50:00+03	112100.00
816417	2017-07-05 13:26:00+03	28800.00
81642E	2017-07-06 11:06:00+03	59300.00
81646F	2017-07-01 08:22:00+03	62600.00
81647F	2017-08-05 07:16:00+03	21500.00
816497	2017-07-09 05:42:00+03	31000.00
81652B	2017-07-29 23:06:00+03	13400.00
8165A5	2017-07-22 00:16:00+03	12400.00
8165B4	2017-08-12 22:34:00+03	221800.00
8165D6	2017-08-08 00:26:00+03	47400.00
8165F2	2017-07-20 07:27:00+03	13600.00
8165F4	2017-07-04 04:51:00+03	258400.00
816637	2017-07-15 02:37:00+03	130900.00
81667B	2017-07-31 02:58:00+03	6800.00
816693	2017-07-25 19:54:00+03	112400.00
8166A1	2017-07-23 23:39:00+03	28800.00
8166A4	2017-08-07 02:37:00+03	28000.00
8166A8	2017-07-16 12:39:00+03	141000.00
8166E8	2017-07-16 13:45:00+03	83000.00
81671F	2017-07-12 21:55:00+03	68100.00
8167A9	2017-07-09 18:24:00+03	79600.00
8167AD	2017-08-03 09:56:00+03	32800.00
8167AF	2017-08-01 02:10:00+03	118200.00
8167E9	2017-07-13 12:04:00+03	135200.00
81684D	2017-07-03 11:32:00+03	72400.00
81686F	2017-07-08 13:49:00+03	22000.00
816904	2017-07-19 22:46:00+03	41800.00
81690A	2017-07-12 00:24:00+03	53400.00
816959	2017-07-11 23:21:00+03	28000.00
816975	2017-08-10 04:52:00+03	56000.00
816A8C	2017-07-24 21:55:00+03	10700.00
816AB9	2017-07-09 16:10:00+03	24700.00
816AE2	2017-07-30 09:33:00+03	125400.00
816B80	2017-07-12 05:30:00+03	246000.00
816B82	2017-08-13 17:23:00+03	31000.00
816C12	2017-08-15 00:54:00+03	38500.00
816C48	2017-08-05 06:10:00+03	26000.00
816CA7	2017-08-05 15:58:00+03	37200.00
816D3D	2017-07-13 22:08:00+03	46400.00
816D63	2017-07-21 11:58:00+03	47600.00
816DA6	2017-07-08 05:10:00+03	32700.00
816E1F	2017-06-30 10:47:00+03	70700.00
816E35	2017-07-18 18:37:00+03	52000.00
816E82	2017-08-06 19:24:00+03	19600.00
816E91	2017-07-24 07:13:00+03	29400.00
816EC8	2017-08-05 10:47:00+03	14400.00
816F0C	2017-07-01 11:14:00+03	124600.00
816F37	2017-07-04 10:03:00+03	101100.00
816F3B	2017-07-04 22:11:00+03	29400.00
816FC0	2017-07-16 11:35:00+03	60200.00
816FDC	2017-07-16 05:27:00+03	19600.00
816FF2	2017-08-11 11:26:00+03	68900.00
816FFB	2017-08-07 02:50:00+03	72000.00
81703F	2017-08-03 05:56:00+03	70700.00
817090	2017-07-13 16:37:00+03	23600.00
8170DD	2017-08-11 00:10:00+03	62000.00
817100	2017-07-30 08:17:00+03	56000.00
81710B	2017-08-09 13:35:00+03	116700.00
817129	2017-07-16 00:59:00+03	65000.00
817154	2017-08-02 13:55:00+03	54200.00
817170	2017-07-01 06:37:00+03	131600.00
817199	2017-08-10 16:29:00+03	56000.00
8171B2	2017-07-16 23:51:00+03	43400.00
8171CE	2017-07-15 12:50:00+03	88100.00
8171D5	2017-07-27 11:55:00+03	135200.00
817239	2017-07-17 09:00:00+03	272300.00
81729C	2017-07-26 11:10:00+03	179400.00
8172F2	2017-07-20 18:15:00+03	79200.00
8172F7	2017-07-18 06:22:00+03	79200.00
81733F	2017-07-04 08:58:00+03	105100.00
817384	2017-07-15 05:57:00+03	136200.00
81739D	2017-07-05 05:16:00+03	28000.00
8173A4	2017-07-11 03:32:00+03	26700.00
8173B3	2017-07-17 09:07:00+03	111600.00
81742F	2017-07-30 02:22:00+03	21400.00
817471	2017-08-04 20:15:00+03	38000.00
81748D	2017-08-07 02:22:00+03	130300.00
8174A1	2017-08-14 19:27:00+03	13400.00
8174BB	2017-08-12 02:55:00+03	6000.00
8174F7	2017-07-13 07:14:00+03	58800.00
81754F	2017-07-26 19:35:00+03	26000.00
8175C8	2017-07-01 12:04:00+03	48800.00
8175D3	2017-08-09 20:34:00+03	50000.00
81760E	2017-07-11 05:58:00+03	23200.00
81764E	2017-07-15 18:38:00+03	23600.00
817686	2017-07-13 12:43:00+03	173900.00
8176A7	2017-07-06 00:45:00+03	12000.00
8176C6	2017-07-18 04:40:00+03	66800.00
81772F	2017-08-06 20:48:00+03	32900.00
81776A	2017-07-27 11:12:00+03	6700.00
81778E	2017-07-21 18:11:00+03	63000.00
8177CA	2017-08-11 04:28:00+03	15400.00
8177FB	2017-07-14 08:22:00+03	62200.00
817819	2017-07-19 18:19:00+03	63200.00
81781D	2017-07-23 13:21:00+03	112000.00
817829	2017-08-02 22:12:00+03	140500.00
817847	2017-07-04 03:53:00+03	31400.00
817887	2017-07-15 04:05:00+03	21500.00
8178D2	2017-08-11 20:19:00+03	59800.00
8178F6	2017-08-04 16:45:00+03	131100.00
8178F9	2017-07-12 03:49:00+03	82900.00
817916	2017-08-13 05:55:00+03	32900.00
81796C	2017-07-13 04:35:00+03	291100.00
817994	2017-07-18 05:33:00+03	55800.00
817A01	2017-07-13 03:17:00+03	118600.00
817A46	2017-08-07 07:01:00+03	59900.00
817ACA	2017-08-09 04:08:00+03	101200.00
817B18	2017-08-09 06:00:00+03	55400.00
817B2D	2017-07-09 13:27:00+03	56000.00
817B31	2017-07-16 08:46:00+03	12600.00
817B75	2017-08-08 18:32:00+03	15000.00
817C50	2017-08-11 17:09:00+03	24000.00
817C71	2017-07-15 04:43:00+03	52400.00
817C77	2017-07-10 19:07:00+03	92900.00
817D1A	2017-07-19 10:31:00+03	32500.00
817D46	2017-07-05 04:34:00+03	23400.00
817D5A	2017-07-16 12:51:00+03	55400.00
817DAF	2017-08-01 09:21:00+03	62000.00
817DC5	2017-07-16 13:10:00+03	101800.00
817DDB	2017-07-31 04:15:00+03	65500.00
817E32	2017-07-31 14:35:00+03	38400.00
817E78	2017-07-23 11:28:00+03	199800.00
817ED3	2017-08-05 00:18:00+03	16400.00
817EE4	2017-07-31 13:44:00+03	39800.00
817EF1	2017-08-02 14:35:00+03	156600.00
817F0B	2017-07-20 16:47:00+03	51300.00
817F48	2017-08-06 16:11:00+03	57400.00
817F80	2017-06-29 09:08:00+03	31400.00
81801B	2017-08-15 16:53:00+03	28800.00
818050	2017-07-04 10:04:00+03	153300.00
81812D	2017-07-02 10:07:00+03	48800.00
81812F	2017-07-27 17:03:00+03	8400.00
81813D	2017-07-22 09:05:00+03	95000.00
818164	2017-08-12 21:55:00+03	19600.00
8181AD	2017-08-10 15:30:00+03	16800.00
8181C7	2017-07-23 23:31:00+03	25600.00
818256	2017-07-15 20:03:00+03	14400.00
81830C	2017-08-09 01:34:00+03	25200.00
818322	2017-07-25 17:34:00+03	92400.00
81833B	2017-06-29 05:45:00+03	258400.00
8183B1	2017-07-30 12:20:00+03	12400.00
8183D5	2017-08-11 07:23:00+03	139300.00
8183D6	2017-07-13 18:39:00+03	37200.00
8183DB	2017-07-21 22:14:00+03	37900.00
818402	2017-08-14 05:36:00+03	264600.00
818454	2017-07-04 21:19:00+03	78400.00
818493	2017-07-20 16:22:00+03	22000.00
8184A1	2017-07-03 13:28:00+03	24400.00
8184AA	2017-07-22 18:49:00+03	28000.00
8184AF	2017-08-05 06:08:00+03	48800.00
8184C7	2017-07-05 10:58:00+03	52000.00
8184EB	2017-07-20 07:18:00+03	40000.00
8184EF	2017-07-04 02:29:00+03	73600.00
81853A	2017-08-14 08:13:00+03	31800.00
8185A7	2017-08-03 00:57:00+03	28000.00
8185D2	2017-07-09 14:35:00+03	13400.00
8185FC	2017-08-07 02:04:00+03	54600.00
818608	2017-08-13 09:58:00+03	89700.00
818622	2017-07-01 01:22:00+03	25200.00
81873C	2017-07-11 20:58:00+03	73000.00
818767	2017-08-04 17:54:00+03	65200.00
8187BA	2017-08-03 06:13:00+03	187800.00
8187EC	2017-08-10 15:04:00+03	19800.00
8188C9	2017-07-24 06:24:00+03	104000.00
8188E7	2017-07-14 10:10:00+03	67500.00
818A7D	2017-07-14 02:37:00+03	32800.00
818ACB	2017-07-10 21:14:00+03	103200.00
818AE3	2017-07-02 08:30:00+03	50600.00
818B3B	2017-07-07 07:16:00+03	22000.00
818BFB	2017-08-10 11:42:00+03	26200.00
818C22	2017-08-03 14:29:00+03	65400.00
818CDA	2017-08-10 09:12:00+03	28800.00
818D42	2017-07-12 00:11:00+03	62100.00
818D6C	2017-07-26 21:47:00+03	23400.00
818DD9	2017-07-29 04:32:00+03	43500.00
818E9B	2017-07-07 20:04:00+03	24300.00
818EA9	2017-07-11 06:02:00+03	24400.00
818F44	2017-07-01 02:41:00+03	23600.00
818FE6	2017-08-13 11:17:00+03	155600.00
819000	2017-07-20 21:50:00+03	81700.00
81907A	2017-08-02 20:18:00+03	86500.00
8190C3	2017-07-17 15:26:00+03	54000.00
8190D4	2017-08-05 11:23:00+03	27800.00
81916B	2017-08-10 22:01:00+03	33300.00
819192	2017-08-06 18:26:00+03	140900.00
819231	2017-08-05 18:00:00+03	54800.00
81925D	2017-07-24 00:17:00+03	31800.00
819275	2017-07-07 02:07:00+03	86300.00
8192E3	2017-07-22 13:59:00+03	138500.00
81932B	2017-07-04 05:57:00+03	94000.00
81933F	2017-08-08 19:27:00+03	111600.00
819383	2017-07-30 09:04:00+03	24400.00
819396	2017-07-04 05:21:00+03	73100.00
8193FC	2017-07-27 11:03:00+03	42000.00
819417	2017-08-11 07:58:00+03	6700.00
819467	2017-07-31 19:07:00+03	113300.00
819474	2017-07-27 14:10:00+03	49100.00
819478	2017-08-13 17:53:00+03	55800.00
8194B5	2017-08-10 22:15:00+03	31400.00
8194CB	2017-07-05 17:34:00+03	117600.00
81951D	2017-07-11 15:35:00+03	56600.00
819567	2017-07-06 21:03:00+03	13400.00
819598	2017-07-06 06:32:00+03	33100.00
8195D1	2017-07-25 12:35:00+03	117200.00
819612	2017-08-02 16:30:00+03	75800.00
819653	2017-08-11 09:04:00+03	168200.00
81965D	2017-08-14 05:55:00+03	97800.00
81966E	2017-07-21 18:11:00+03	59800.00
819696	2017-07-04 21:07:00+03	8000.00
8196B0	2017-08-14 16:42:00+03	20200.00
81970B	2017-07-19 00:48:00+03	81300.00
819760	2017-07-14 10:51:00+03	24700.00
8197E6	2017-07-14 06:34:00+03	39500.00
81982A	2017-08-03 07:48:00+03	47200.00
81984B	2017-07-03 23:04:00+03	67600.00
819873	2017-07-04 07:35:00+03	56000.00
819890	2017-07-29 01:22:00+03	124200.00
819891	2017-07-24 14:52:00+03	14000.00
81991D	2017-08-08 16:46:00+03	26000.00
819926	2017-08-08 07:36:00+03	109600.00
819942	2017-07-16 02:57:00+03	162700.00
819970	2017-08-02 17:00:00+03	80000.00
81998D	2017-07-30 23:06:00+03	21400.00
8199BB	2017-07-28 19:05:00+03	175200.00
8199E4	2017-08-07 14:14:00+03	47100.00
819A17	2017-07-04 14:02:00+03	168000.00
819A26	2017-08-08 12:18:00+03	31000.00
819A2E	2017-08-04 02:52:00+03	46000.00
819A3E	2017-08-12 05:41:00+03	131000.00
819A51	2017-07-25 19:13:00+03	185700.00
819A90	2017-07-29 17:19:00+03	42700.00
819A9C	2017-07-15 23:42:00+03	25100.00
819ADC	2017-07-16 06:10:00+03	57800.00
819B10	2017-08-08 15:00:00+03	34000.00
819B45	2017-06-29 05:15:00+03	187600.00
819B53	2017-07-14 03:46:00+03	72200.00
819BBD	2017-07-18 07:47:00+03	40400.00
819BFC	2017-08-05 13:23:00+03	89700.00
819C5B	2017-07-29 11:16:00+03	12000.00
819CEC	2017-08-09 04:46:00+03	40200.00
819D2F	2017-07-09 13:20:00+03	40300.00
819D76	2017-07-11 07:26:00+03	410200.00
819DEA	2017-08-14 21:59:00+03	50000.00
819E25	2017-07-18 18:12:00+03	54500.00
819E4C	2017-07-21 03:33:00+03	209700.00
819E77	2017-07-18 18:51:00+03	43900.00
819EDB	2017-07-30 07:52:00+03	46400.00
819F03	2017-07-08 23:25:00+03	15700.00
819F23	2017-07-14 23:39:00+03	78200.00
81A053	2017-07-24 07:29:00+03	25100.00
81A078	2017-08-12 15:49:00+03	48400.00
81A07B	2017-08-01 14:38:00+03	42800.00
81A087	2017-07-30 04:06:00+03	103100.00
81A0E0	2017-08-02 06:23:00+03	211600.00
81A10B	2017-07-11 15:26:00+03	68000.00
81A176	2017-08-01 08:23:00+03	131100.00
81A197	2017-07-18 20:27:00+03	99800.00
81A1AB	2017-07-08 07:52:00+03	89000.00
81A22C	2017-07-14 20:49:00+03	57400.00
81A29C	2017-08-12 11:34:00+03	29600.00
81A2AA	2017-07-07 10:13:00+03	31400.00
81A2E9	2017-07-20 11:13:00+03	86800.00
81A2F2	2017-07-12 17:43:00+03	31400.00
81A361	2017-07-04 04:22:00+03	36700.00
81A397	2017-07-31 17:06:00+03	15700.00
81A3A3	2017-06-29 15:42:00+03	112000.00
81A3B3	2017-08-07 15:53:00+03	47500.00
81A3CD	2017-07-24 15:41:00+03	54800.00
81A3EB	2017-08-08 05:46:00+03	30200.00
81A3FA	2017-08-14 17:47:00+03	6000.00
81A408	2017-08-01 04:30:00+03	57800.00
81A488	2017-07-21 18:52:00+03	70800.00
81A512	2017-08-07 07:12:00+03	174000.00
81A51F	2017-07-10 21:50:00+03	26000.00
81A54D	2017-07-05 17:43:00+03	42000.00
81A56A	2017-08-12 10:15:00+03	71600.00
81A66A	2017-08-14 07:31:00+03	65900.00
81A66E	2017-08-14 08:09:00+03	185600.00
81A6E0	2017-08-11 01:30:00+03	124200.00
81A764	2017-07-23 08:51:00+03	22000.00
81A776	2017-08-07 12:49:00+03	56000.00
81A779	2017-08-08 01:40:00+03	72700.00
81A783	2017-07-19 22:00:00+03	13400.00
81A822	2017-08-02 18:15:00+03	6000.00
81A964	2017-08-13 03:40:00+03	55800.00
81A965	2017-07-26 22:03:00+03	75000.00
81A9C0	2017-07-22 14:42:00+03	57600.00
81A9D7	2017-08-06 22:11:00+03	128800.00
81A9EA	2017-08-12 02:57:00+03	27300.00
81AA41	2017-08-14 09:07:00+03	55800.00
81AA83	2017-08-01 02:11:00+03	37900.00
81AAE4	2017-07-17 14:30:00+03	28800.00
81AB0F	2017-06-30 08:53:00+03	168300.00
81AB2A	2017-08-12 15:54:00+03	13400.00
81AB38	2017-08-02 03:43:00+03	25200.00
81AB3B	2017-08-02 14:31:00+03	58700.00
81AB6B	2017-08-13 20:57:00+03	43900.00
81AB83	2017-07-25 15:56:00+03	38200.00
81ABF2	2017-08-09 20:09:00+03	13400.00
81AC1C	2017-07-25 18:14:00+03	529200.00
81AC2C	2017-07-09 22:28:00+03	20200.00
81AC92	2017-07-02 12:43:00+03	290400.00
81ACC1	2017-07-21 14:35:00+03	119500.00
81ACE7	2017-07-12 07:58:00+03	101800.00
81AD18	2017-07-11 17:46:00+03	18900.00
81AD2A	2017-07-26 23:36:00+03	169800.00
81AE07	2017-08-08 19:50:00+03	51300.00
81AE59	2017-07-20 09:51:00+03	143600.00
81AEAB	2017-07-19 05:26:00+03	72800.00
81AEB0	2017-07-05 12:40:00+03	46200.00
81AED1	2017-07-18 08:07:00+03	202600.00
81AEF9	2017-08-10 23:06:00+03	193100.00
81AF08	2017-07-20 19:02:00+03	116900.00
81AF0F	2017-08-10 04:08:00+03	130300.00
81AF71	2017-07-25 11:32:00+03	246000.00
81AF7E	2017-08-05 10:59:00+03	8200.00
81AFA7	2017-07-09 22:41:00+03	23600.00
81AFAC	2017-08-12 10:43:00+03	16400.00
81B00B	2017-08-12 21:26:00+03	86400.00
81B040	2017-08-10 10:55:00+03	90000.00
81B0A8	2017-08-08 20:22:00+03	57400.00
81B0F5	2017-07-29 14:35:00+03	93900.00
81B107	2017-07-09 20:35:00+03	23600.00
81B2D6	2017-07-16 23:25:00+03	28000.00
81B338	2017-08-13 23:06:00+03	65800.00
81B34C	2017-08-12 14:06:00+03	19800.00
81B3D1	2017-08-10 21:08:00+03	14600.00
81B3D5	2017-08-02 18:14:00+03	27400.00
81B3DC	2017-07-16 09:44:00+03	152500.00
81B44A	2017-07-30 12:00:00+03	24200.00
81B45A	2017-07-27 23:06:00+03	6700.00
81B477	2017-07-30 21:26:00+03	6300.00
81B487	2017-07-04 11:31:00+03	7400.00
81B49B	2017-06-29 06:48:00+03	99200.00
81B4BD	2017-07-18 21:04:00+03	32500.00
81B4C5	2017-07-21 22:25:00+03	14000.00
81B4E1	2017-07-10 07:34:00+03	24200.00
81B525	2017-08-14 05:13:00+03	50800.00
81B536	2017-07-24 18:41:00+03	46400.00
81B611	2017-07-28 16:16:00+03	118600.00
81B628	2017-07-28 12:44:00+03	31600.00
81B629	2017-07-27 23:14:00+03	106400.00
81B653	2017-07-06 05:21:00+03	55800.00
81B69C	2017-08-03 16:32:00+03	64800.00
81B72B	2017-07-25 12:45:00+03	64800.00
81B73D	2017-08-14 08:50:00+03	6900.00
81B776	2017-08-14 11:45:00+03	133600.00
81B7C0	2017-07-12 13:19:00+03	46400.00
81B7C1	2017-08-13 09:24:00+03	135000.00
81B825	2017-08-11 17:31:00+03	111700.00
81B884	2017-08-11 05:36:00+03	50600.00
81B897	2017-08-10 10:23:00+03	96400.00
81B95F	2017-07-04 08:39:00+03	129200.00
81B994	2017-07-11 03:04:00+03	119800.00
81B9F0	2017-08-13 03:31:00+03	15000.00
81BA0D	2017-07-31 23:13:00+03	171000.00
81BA36	2017-07-03 18:45:00+03	19600.00
81BA55	2017-07-06 16:37:00+03	56000.00
81BA58	2017-07-23 01:17:00+03	38800.00
81BA8D	2017-07-23 22:01:00+03	50600.00
81BB53	2017-08-01 19:58:00+03	135600.00
81BB5F	2017-07-18 16:11:00+03	12700.00
81BB77	2017-08-08 06:32:00+03	113200.00
81BC7A	2017-07-11 13:23:00+03	47000.00
81BC91	2017-08-10 06:35:00+03	46200.00
81BCA4	2017-07-11 09:03:00+03	135400.00
81BDB0	2017-07-19 23:17:00+03	539400.00
81BE0D	2017-07-14 15:10:00+03	7200.00
81BE10	2017-07-29 18:29:00+03	26000.00
81BE17	2017-07-28 11:41:00+03	25800.00
81BE59	2017-07-13 06:43:00+03	264000.00
81BE70	2017-07-11 23:38:00+03	72300.00
81BE87	2017-07-19 08:58:00+03	65500.00
81BEB1	2017-08-10 08:04:00+03	38600.00
81BECC	2017-07-23 11:34:00+03	225300.00
81BED1	2017-07-08 16:19:00+03	16400.00
81BF27	2017-07-31 11:30:00+03	367600.00
81BF2C	2017-07-24 20:34:00+03	35600.00
81BF65	2017-08-10 23:03:00+03	75600.00
81BF85	2017-07-09 12:24:00+03	114300.00
81BF89	2017-07-14 07:04:00+03	123000.00
81BFD6	2017-07-06 14:48:00+03	44600.00
81C015	2017-07-18 22:22:00+03	83000.00
81C065	2017-08-09 22:49:00+03	26700.00
81C09D	2017-08-11 07:11:00+03	44600.00
81C0AB	2017-07-29 12:40:00+03	98100.00
81C0D9	2017-08-02 10:43:00+03	88300.00
81C16C	2017-07-19 18:09:00+03	39800.00
81C18E	2017-07-25 16:56:00+03	29600.00
81C19A	2017-07-23 08:02:00+03	62600.00
81C1C8	2017-07-31 10:54:00+03	183500.00
81C1C9	2017-08-15 04:55:00+03	20600.00
81C20E	2017-07-13 13:40:00+03	36800.00
81C22C	2017-08-01 15:17:00+03	62600.00
81C232	2017-07-05 21:02:00+03	496800.00
81C279	2017-07-12 15:58:00+03	59700.00
81C2E3	2017-07-02 18:37:00+03	96800.00
81C2E8	2017-07-26 19:30:00+03	7400.00
81C30F	2017-07-13 23:40:00+03	12600.00
81C356	2017-07-26 12:53:00+03	83000.00
81C37F	2017-08-11 15:09:00+03	26000.00
81C38F	2017-08-02 05:09:00+03	123600.00
81C39F	2017-07-05 02:50:00+03	63500.00
81C435	2017-07-02 11:15:00+03	16400.00
81C492	2017-08-10 02:54:00+03	44600.00
81C4DD	2017-07-01 12:55:00+03	86400.00
81C535	2017-07-20 07:52:00+03	46300.00
81C568	2017-08-15 10:52:00+03	147800.00
81C578	2017-07-31 02:47:00+03	17200.00
81C595	2017-07-19 23:57:00+03	7200.00
81C59C	2017-07-14 02:46:00+03	98400.00
81C5B3	2017-07-12 15:16:00+03	37200.00
81C5B5	2017-07-09 04:13:00+03	44000.00
81C610	2017-08-10 03:26:00+03	23600.00
81C6D5	2017-08-10 15:23:00+03	46000.00
81C71D	2017-08-04 14:43:00+03	80000.00
81C728	2017-07-03 16:33:00+03	23100.00
81C74A	2017-08-09 14:20:00+03	234600.00
81C74F	2017-07-13 08:21:00+03	186900.00
81C759	2017-07-07 18:36:00+03	112000.00
81C769	2017-08-05 06:03:00+03	37900.00
81C777	2017-07-18 13:09:00+03	27200.00
81C796	2017-07-27 00:30:00+03	75600.00
81C7B0	2017-08-01 14:48:00+03	26800.00
81C7D6	2017-07-14 19:45:00+03	101600.00
81C7DA	2017-08-15 09:47:00+03	157100.00
81C827	2017-08-07 04:45:00+03	135400.00
81C8A0	2017-08-06 17:16:00+03	73300.00
81C8AA	2017-07-15 11:15:00+03	65600.00
81C8C6	2017-08-13 18:00:00+03	43900.00
81C90C	2017-07-03 02:10:00+03	56000.00
81CA52	2017-07-16 07:07:00+03	44600.00
81CBAE	2017-07-01 03:05:00+03	47200.00
81CBFD	2017-07-06 13:54:00+03	55600.00
81CC1F	2017-07-03 05:22:00+03	44800.00
81CC39	2017-07-01 09:06:00+03	14000.00
81CC68	2017-07-22 03:37:00+03	29600.00
81CC75	2017-07-05 05:47:00+03	167400.00
81CCA1	2017-07-19 18:21:00+03	29600.00
81CCC3	2017-07-07 15:40:00+03	40000.00
81CCC4	2017-07-29 15:13:00+03	27800.00
81CD12	2017-07-08 05:32:00+03	119600.00
81CD91	2017-07-24 00:52:00+03	28000.00
81CD93	2017-07-23 08:14:00+03	85000.00
81CE9D	2017-07-23 21:54:00+03	24800.00
81CEA5	2017-07-30 21:15:00+03	22200.00
81CEA9	2017-07-14 14:03:00+03	51300.00
81CEBD	2017-08-04 21:06:00+03	87900.00
81CF22	2017-08-05 13:09:00+03	48600.00
81CF7A	2017-07-06 05:01:00+03	13800.00
81CFE1	2017-07-11 08:54:00+03	48900.00
81D001	2017-07-03 06:25:00+03	54000.00
81D07F	2017-08-06 10:41:00+03	406200.00
81D0A8	2017-07-27 13:25:00+03	34800.00
81D0F8	2017-07-21 10:03:00+03	19600.00
81D12D	2017-07-30 05:15:00+03	38800.00
81D15D	2017-07-14 07:10:00+03	132800.00
81D16F	2017-08-08 12:35:00+03	246000.00
81D1CB	2017-07-14 07:38:00+03	186900.00
81D1EB	2017-07-15 08:15:00+03	34800.00
81D279	2017-08-03 22:47:00+03	39100.00
81D37F	2017-08-09 06:43:00+03	21400.00
81D386	2017-07-28 15:04:00+03	236000.00
81D3C1	2017-07-11 13:57:00+03	37900.00
81D429	2017-08-15 15:35:00+03	135400.00
81D48F	2017-07-31 03:14:00+03	738000.00
81D4B3	2017-07-24 23:06:00+03	115100.00
81D529	2017-08-02 14:37:00+03	56000.00
81D594	2017-07-22 22:23:00+03	47000.00
81D662	2017-07-10 21:19:00+03	38400.00
81D66E	2017-07-24 12:59:00+03	72800.00
81D717	2017-07-15 15:03:00+03	81700.00
81D748	2017-07-15 15:31:00+03	77900.00
81D762	2017-07-30 21:41:00+03	97600.00
81D777	2017-07-24 16:25:00+03	28800.00
81D7CB	2017-07-06 12:32:00+03	142400.00
81D83E	2017-08-11 13:17:00+03	59400.00
81D89F	2017-08-07 11:55:00+03	133100.00
81D8AD	2017-08-11 08:31:00+03	55800.00
81D8AF	2017-06-27 06:22:00+03	35200.00
81D8D3	2017-08-11 11:37:00+03	18600.00
81D91A	2017-07-05 19:10:00+03	73200.00
81DA0C	2017-07-28 15:36:00+03	393800.00
81DA1B	2017-06-27 18:30:00+03	47400.00
81DA23	2017-07-03 12:40:00+03	46000.00
81DA6A	2017-07-11 01:02:00+03	103200.00
81DA72	2017-07-27 19:33:00+03	23400.00
81DA79	2017-07-04 06:54:00+03	49200.00
81DA9D	2017-08-13 21:35:00+03	73200.00
81DAB1	2017-07-31 10:59:00+03	258400.00
81DB68	2017-07-27 23:27:00+03	64600.00
81DB76	2017-07-28 07:29:00+03	62400.00
81DBBD	2017-07-11 05:13:00+03	16400.00
81DBCB	2017-07-19 02:11:00+03	14000.00
81DC07	2017-07-04 14:07:00+03	32400.00
81DC2E	2017-07-24 14:32:00+03	45200.00
81DC3D	2017-07-19 01:31:00+03	56100.00
81DD0D	2017-07-25 14:22:00+03	310800.00
81DDBC	2017-07-25 02:20:00+03	23200.00
81DDE3	2017-07-07 10:55:00+03	105400.00
81DE00	2017-07-19 17:32:00+03	26000.00
81DE20	2017-07-06 23:58:00+03	15000.00
81DE4E	2017-07-15 02:57:00+03	28000.00
81DEC9	2017-07-07 13:21:00+03	45100.00
81DF78	2017-07-04 10:23:00+03	43200.00
81DF7C	2017-07-20 12:11:00+03	42800.00
81DF87	2017-08-13 13:19:00+03	143200.00
81DF99	2017-07-30 22:18:00+03	372500.00
81DFBA	2017-07-18 11:13:00+03	79800.00
81E01B	2017-08-14 21:50:00+03	56200.00
81E063	2017-08-03 09:01:00+03	64700.00
81E192	2017-07-26 20:10:00+03	16400.00
81E1A6	2017-08-08 00:54:00+03	130100.00
81E1F9	2017-08-02 00:59:00+03	79000.00
81E227	2017-07-25 11:06:00+03	78200.00
81E229	2017-08-07 10:54:00+03	28000.00
81E245	2017-07-24 23:12:00+03	17600.00
81E2D8	2017-07-29 22:20:00+03	39600.00
81E340	2017-08-11 06:57:00+03	112100.00
81E3D5	2017-07-13 18:21:00+03	92900.00
81E3FD	2017-08-11 14:01:00+03	279800.00
81E3FF	2017-08-14 23:46:00+03	99700.00
81E41A	2017-08-11 20:29:00+03	19100.00
81E49E	2017-07-23 18:24:00+03	23600.00
81E537	2017-08-04 10:18:00+03	112000.00
81E56C	2017-07-29 15:18:00+03	148700.00
81E571	2017-07-12 19:52:00+03	51300.00
81E59A	2017-07-25 03:50:00+03	71400.00
81E5B0	2017-07-16 09:29:00+03	147500.00
81E636	2017-07-27 09:18:00+03	59900.00
81E637	2017-07-10 21:59:00+03	266400.00
81E699	2017-07-07 21:06:00+03	141300.00
81E6C9	2017-07-24 03:02:00+03	59400.00
81E6FD	2017-08-05 10:41:00+03	111600.00
81E763	2017-07-10 11:17:00+03	120900.00
81E7F4	2017-07-22 14:35:00+03	168000.00
81E822	2017-07-11 01:58:00+03	223400.00
81E85C	2017-07-12 22:10:00+03	266400.00
81E8E7	2017-06-27 10:43:00+03	47100.00
81E919	2017-08-10 16:35:00+03	133200.00
81E948	2017-08-04 22:00:00+03	23900.00
81E9AC	2017-08-01 00:47:00+03	179400.00
81E9C7	2017-08-13 11:57:00+03	94800.00
81E9D6	2017-06-29 20:11:00+03	138400.00
81EA24	2017-08-03 14:21:00+03	131600.00
81EB0E	2017-07-30 19:56:00+03	12400.00
81EB16	2017-07-22 06:59:00+03	42700.00
81EB18	2017-07-16 18:19:00+03	30000.00
81EB3A	2017-07-10 12:08:00+03	23200.00
81EB5C	2017-07-02 12:16:00+03	75000.00
81EBC0	2017-07-11 05:56:00+03	56000.00
81EBF6	2017-08-03 19:27:00+03	24800.00
81EC13	2017-08-13 13:18:00+03	115600.00
81EC8B	2017-07-05 23:45:00+03	66600.00
81EC9B	2017-07-26 16:35:00+03	15000.00
81ECA5	2017-07-03 03:05:00+03	399600.00
81ED04	2017-07-20 17:17:00+03	155900.00
81ED0A	2017-08-14 16:37:00+03	27300.00
81ED6B	2017-07-05 16:41:00+03	219500.00
81ED80	2017-08-10 14:50:00+03	32800.00
81EDAF	2017-07-17 05:24:00+03	97100.00
81EDF9	2017-07-23 10:05:00+03	14000.00
81EE9B	2017-08-07 03:50:00+03	73500.00
81EEAC	2017-07-15 20:50:00+03	32700.00
81EECE	2017-08-14 15:01:00+03	23400.00
81EEE6	2017-08-03 18:33:00+03	14400.00
81EF28	2017-07-16 04:43:00+03	62600.00
81EF43	2017-07-26 00:18:00+03	44800.00
81EF62	2017-07-20 18:40:00+03	133900.00
81EF94	2017-07-15 08:57:00+03	47200.00
81EFC4	2017-08-07 02:15:00+03	112000.00
81F04E	2017-08-07 03:00:00+03	145500.00
81F0A5	2017-07-02 15:33:00+03	6600.00
81F0A8	2017-08-03 16:50:00+03	84700.00
81F0E5	2017-07-25 07:48:00+03	136800.00
81F11A	2017-08-11 10:41:00+03	118000.00
81F161	2017-08-03 07:50:00+03	84500.00
81F17E	2017-07-20 22:14:00+03	529100.00
81F199	2017-08-08 15:04:00+03	13200.00
81F228	2017-07-26 20:45:00+03	66600.00
81F22C	2017-07-29 00:27:00+03	199600.00
81F230	2017-08-01 13:33:00+03	81200.00
81F2ED	2017-08-11 13:24:00+03	44100.00
81F331	2017-07-17 12:52:00+03	15900.00
81F3A5	2017-07-15 19:02:00+03	54000.00
81F42E	2017-07-16 07:51:00+03	170000.00
81F44F	2017-07-05 01:14:00+03	17800.00
81F456	2017-07-28 04:30:00+03	24700.00
81F47C	2017-07-16 20:35:00+03	92000.00
81F4C1	2017-07-13 11:19:00+03	32800.00
81F4FD	2017-08-15 07:35:00+03	93900.00
81F536	2017-08-01 07:12:00+03	271200.00
81F556	2017-07-09 21:00:00+03	48400.00
81F56C	2017-07-04 15:50:00+03	64100.00
81F5CB	2017-07-27 18:15:00+03	28000.00
81F65C	2017-07-09 14:36:00+03	54100.00
81F698	2017-06-29 14:10:00+03	183100.00
81F69D	2017-07-08 10:41:00+03	81500.00
81F6E3	2017-08-13 13:49:00+03	37200.00
81F714	2017-07-13 03:08:00+03	28000.00
81F79A	2017-08-11 14:07:00+03	399900.00
81F7B2	2017-08-12 08:51:00+03	23600.00
81F7BC	2017-07-01 01:41:00+03	233800.00
81F7C4	2017-08-06 03:28:00+03	50700.00
81F84C	2017-07-18 23:19:00+03	32800.00
81F86D	2017-07-25 23:57:00+03	73500.00
81F87B	2017-08-08 07:06:00+03	23200.00
81F8FD	2017-07-15 10:30:00+03	28000.00
81F907	2017-07-06 12:04:00+03	40600.00
81F920	2017-08-02 17:49:00+03	23400.00
81F921	2017-07-29 05:17:00+03	43600.00
81F936	2017-08-01 01:31:00+03	57300.00
81F991	2017-07-13 10:40:00+03	60400.00
81F9A5	2017-07-30 08:19:00+03	73500.00
81FA2C	2017-07-11 15:32:00+03	69500.00
81FA48	2017-07-26 08:02:00+03	77200.00
81FA94	2017-08-08 20:35:00+03	254900.00
81FAA2	2017-06-29 13:30:00+03	271100.00
81FAB9	2017-07-13 06:11:00+03	22600.00
81FAD1	2017-07-05 19:47:00+03	186900.00
81FAEF	2017-08-11 07:17:00+03	26700.00
81FAF4	2017-07-11 02:49:00+03	25200.00
81FAFF	2017-07-03 03:29:00+03	515100.00
81FBD7	2017-08-10 13:01:00+03	57500.00
81FBDC	2017-07-09 17:01:00+03	50200.00
81FBFB	2017-07-16 10:44:00+03	99200.00
81FC0B	2017-08-05 20:57:00+03	123900.00
81FC14	2017-07-30 02:53:00+03	84000.00
81FCBE	2017-07-28 19:48:00+03	132800.00
81FCF0	2017-07-09 01:17:00+03	41300.00
81FCF5	2017-08-09 16:53:00+03	258700.00
81FDBB	2017-07-26 19:52:00+03	55500.00
81FDDE	2017-07-15 09:35:00+03	30000.00
81FDF2	2017-08-15 05:47:00+03	10800.00
81FDF9	2017-07-23 01:38:00+03	64800.00
81FE82	2017-07-07 16:41:00+03	16800.00
81FEA6	2017-08-07 15:41:00+03	26800.00
81FF05	2017-07-02 03:51:00+03	93900.00
81FF14	2017-08-07 05:57:00+03	22000.00
81FF28	2017-07-14 14:10:00+03	48400.00
81FF4F	2017-07-28 07:15:00+03	156400.00
81FF6A	2017-07-16 01:08:00+03	136800.00
81FF71	2017-07-06 14:09:00+03	24700.00
81FF88	2017-07-10 09:56:00+03	58800.00
81FFE6	2017-07-07 06:55:00+03	60700.00
82010A	2017-07-22 05:50:00+03	56900.00
82010B	2017-07-10 18:31:00+03	98300.00
82011D	2017-07-27 09:42:00+03	38600.00
820120	2017-08-01 18:47:00+03	66600.00
8201B7	2017-08-02 09:22:00+03	25600.00
820263	2017-06-29 16:39:00+03	23900.00
820276	2017-07-28 22:24:00+03	20400.00
820280	2017-07-23 07:27:00+03	15000.00
820295	2017-08-01 10:06:00+03	65100.00
8202DE	2017-08-05 14:56:00+03	14400.00
8203BE	2017-07-26 08:07:00+03	233800.00
820456	2017-07-09 12:51:00+03	28800.00
82046A	2017-07-06 16:03:00+03	28800.00
820473	2017-07-28 08:49:00+03	18000.00
8204E0	2017-07-15 09:06:00+03	6000.00
82050D	2017-07-10 08:19:00+03	58600.00
820510	2017-07-14 13:42:00+03	88800.00
820585	2017-07-19 23:33:00+03	24800.00
8205AC	2017-07-21 00:58:00+03	29600.00
82067C	2017-07-20 05:10:00+03	98600.00
82068D	2017-07-14 17:08:00+03	43900.00
820698	2017-07-21 09:17:00+03	34000.00
8206EA	2017-07-30 03:04:00+03	135400.00
8206EF	2017-08-03 09:30:00+03	133200.00
820714	2017-07-10 09:52:00+03	160000.00
82074C	2017-07-09 15:12:00+03	16400.00
8207C4	2017-08-13 01:12:00+03	61800.00
8207E6	2017-08-09 23:54:00+03	167400.00
820806	2017-07-20 08:49:00+03	89600.00
8208B7	2017-07-31 01:09:00+03	11800.00
8208D7	2017-07-10 18:01:00+03	99700.00
8208E3	2017-07-09 01:44:00+03	23600.00
820920	2017-08-14 23:13:00+03	20000.00
820978	2017-08-09 20:37:00+03	57400.00
820984	2017-07-03 20:26:00+03	133200.00
820995	2017-07-29 18:39:00+03	72000.00
820A94	2017-07-25 14:55:00+03	73200.00
820AA1	2017-07-25 23:24:00+03	86600.00
820AA2	2017-08-08 22:22:00+03	30800.00
820ACF	2017-07-27 03:48:00+03	45200.00
820ADC	2017-07-14 00:55:00+03	61500.00
820AE2	2017-07-05 15:17:00+03	9800.00
820B4F	2017-07-16 12:54:00+03	19600.00
820BAF	2017-07-24 07:28:00+03	148700.00
820BFC	2017-07-03 00:13:00+03	36800.00
820C2D	2017-08-04 03:55:00+03	43900.00
820C45	2017-08-15 09:19:00+03	62000.00
820CB4	2017-08-04 00:49:00+03	52400.00
820CED	2017-07-09 09:00:00+03	265600.00
820D30	2017-08-03 23:47:00+03	79900.00
820D86	2017-07-30 23:34:00+03	118800.00
820DCC	2017-08-05 07:48:00+03	10600.00
820DD6	2017-08-02 20:55:00+03	46000.00
820DEB	2017-07-13 10:06:00+03	29600.00
820E36	2017-07-28 12:31:00+03	62800.00
820E6D	2017-06-30 02:43:00+03	53400.00
820E88	2017-07-08 03:24:00+03	47600.00
820E96	2017-07-27 08:04:00+03	57500.00
820EDB	2017-07-05 09:09:00+03	31600.00
820EF4	2017-07-11 02:24:00+03	531400.00
820EFF	2017-06-30 17:31:00+03	133100.00
820F16	2017-08-10 15:46:00+03	54000.00
820F23	2017-07-17 11:45:00+03	14000.00
820F44	2017-08-01 19:21:00+03	118500.00
820F4D	2017-08-01 15:31:00+03	40300.00
820F4F	2017-07-17 12:26:00+03	228500.00
82100F	2017-08-08 17:33:00+03	13400.00
821083	2017-08-15 06:45:00+03	46500.00
82108C	2017-07-26 16:38:00+03	67000.00
821094	2017-07-25 18:31:00+03	103500.00
8210F5	2017-08-11 22:57:00+03	58000.00
821101	2017-07-08 01:38:00+03	48800.00
821125	2017-08-10 04:09:00+03	401000.00
821155	2017-07-25 00:26:00+03	18500.00
82116B	2017-07-12 13:52:00+03	90600.00
82116F	2017-08-10 11:37:00+03	18400.00
8211F6	2017-08-02 22:16:00+03	59300.00
821210	2017-08-01 16:25:00+03	88300.00
82123A	2017-07-25 06:31:00+03	26700.00
821278	2017-06-29 22:35:00+03	59900.00
821387	2017-07-12 17:49:00+03	47200.00
82149F	2017-08-09 22:41:00+03	56400.00
8214BB	2017-07-15 15:09:00+03	47000.00
82152A	2017-07-23 16:24:00+03	12700.00
82155B	2017-06-29 01:53:00+03	92800.00
82155C	2017-07-31 21:23:00+03	47100.00
82156F	2017-07-30 23:23:00+03	153900.00
8215C2	2017-08-06 16:44:00+03	40800.00
8215F0	2017-07-30 05:43:00+03	122500.00
82165E	2017-08-05 21:40:00+03	128800.00
8216A8	2017-07-18 17:54:00+03	17600.00
8216B0	2017-08-05 23:45:00+03	65500.00
8216BD	2017-07-21 20:39:00+03	19000.00
8216D6	2017-08-02 12:29:00+03	37200.00
821719	2017-07-29 04:44:00+03	47000.00
82172C	2017-08-02 12:48:00+03	6700.00
821750	2017-08-11 09:25:00+03	372500.00
821760	2017-07-20 21:29:00+03	24600.00
8217FE	2017-08-15 10:41:00+03	59600.00
821836	2017-08-15 09:31:00+03	21400.00
8218AD	2017-07-07 14:20:00+03	111600.00
8218BE	2017-07-08 09:38:00+03	63700.00
8218C2	2017-07-27 13:55:00+03	56900.00
82191D	2017-07-10 16:27:00+03	46300.00
821975	2017-07-30 21:38:00+03	81600.00
821987	2017-08-10 05:46:00+03	25200.00
821A07	2017-07-12 15:02:00+03	12000.00
821A24	2017-06-28 11:12:00+03	111600.00
821A2C	2017-07-22 23:33:00+03	123000.00
821A34	2017-07-17 15:01:00+03	27400.00
821A60	2017-07-12 08:44:00+03	75300.00
821AC6	2017-08-07 15:33:00+03	135600.00
821AD3	2017-07-26 12:20:00+03	492000.00
821ADE	2017-07-19 20:14:00+03	65500.00
821B2B	2017-08-02 22:53:00+03	409100.00
821B2F	2017-08-14 18:41:00+03	35800.00
821B3D	2017-07-13 13:17:00+03	124300.00
821B40	2017-07-11 05:31:00+03	135000.00
821B63	2017-08-05 13:21:00+03	79600.00
821BA2	2017-06-29 03:47:00+03	43100.00
821C5C	2017-07-11 15:00:00+03	131600.00
821CA9	2017-07-17 22:19:00+03	57600.00
821D07	2017-07-31 08:02:00+03	7300.00
821D16	2017-07-27 20:24:00+03	410200.00
821D47	2017-07-08 03:26:00+03	38400.00
821D87	2017-07-24 19:27:00+03	14000.00
821D9A	2017-08-14 05:57:00+03	26800.00
821E04	2017-07-14 00:37:00+03	68400.00
821E35	2017-08-12 04:29:00+03	46500.00
821E63	2017-06-25 01:44:00+03	81300.00
821FAE	2017-08-12 14:58:00+03	48100.00
821FDD	2017-07-29 03:38:00+03	23600.00
821FE4	2017-08-04 02:53:00+03	113500.00
82200E	2017-07-04 15:45:00+03	190100.00
82206B	2017-07-09 00:37:00+03	120600.00
82206D	2017-07-28 07:32:00+03	23200.00
822076	2017-07-29 08:10:00+03	27200.00
8220BA	2017-07-30 11:33:00+03	52400.00
8220E4	2017-07-23 12:11:00+03	12600.00
8220F0	2017-07-14 17:12:00+03	136000.00
822114	2017-07-16 09:09:00+03	51600.00
822140	2017-07-12 14:26:00+03	70600.00
822191	2017-07-01 19:18:00+03	67700.00
8221E3	2017-08-02 06:38:00+03	65900.00
8222A5	2017-08-12 13:58:00+03	60700.00
822301	2017-08-07 01:02:00+03	46000.00
822310	2017-07-05 20:20:00+03	6700.00
822317	2017-07-01 00:56:00+03	54400.00
822368	2017-08-01 02:23:00+03	24000.00
822396	2017-07-11 02:16:00+03	54400.00
82239D	2017-07-06 17:27:00+03	56600.00
8223D7	2017-07-24 18:08:00+03	40800.00
822412	2017-08-08 10:48:00+03	28600.00
82259B	2017-07-26 21:51:00+03	15900.00
822632	2017-07-28 07:46:00+03	118100.00
82265F	2017-08-11 11:53:00+03	40200.00
822697	2017-08-11 09:21:00+03	95600.00
82283F	2017-08-06 15:08:00+03	15000.00
822841	2017-07-05 01:41:00+03	398600.00
822856	2017-08-09 16:38:00+03	31400.00
8228A2	2017-07-23 03:50:00+03	20600.00
8228A5	2017-08-01 21:24:00+03	27400.00
8228F3	2017-08-04 08:59:00+03	62600.00
8228FB	2017-08-12 14:00:00+03	117500.00
8229AF	2017-08-10 20:22:00+03	22600.00
8229B1	2017-07-25 16:17:00+03	66600.00
8229C1	2017-08-08 13:38:00+03	36800.00
822A2B	2017-07-06 14:40:00+03	111600.00
822A31	2017-07-31 07:55:00+03	23600.00
822A83	2017-07-17 11:52:00+03	175600.00
822A9E	2017-08-09 04:23:00+03	142800.00
822AA0	2017-08-06 19:32:00+03	56000.00
822AAF	2017-07-20 03:52:00+03	62000.00
822ADE	2017-06-28 04:31:00+03	21600.00
822B14	2017-07-15 03:17:00+03	81200.00
822BAF	2017-08-15 12:13:00+03	39300.00
822BB3	2017-07-15 00:20:00+03	128800.00
822BE7	2017-08-05 08:11:00+03	26000.00
822C7D	2017-07-20 01:04:00+03	28800.00
822C9B	2017-08-13 15:58:00+03	112600.00
822CFF	2017-07-13 15:11:00+03	51200.00
822D22	2017-08-12 10:47:00+03	27400.00
822D3F	2017-07-31 05:13:00+03	30900.00
822D45	2017-07-27 15:51:00+03	167400.00
822E15	2017-08-14 00:59:00+03	31600.00
822E55	2017-07-22 12:27:00+03	77200.00
822E73	2017-07-30 08:22:00+03	94300.00
822E87	2017-07-24 07:25:00+03	82000.00
822E96	2017-07-27 06:13:00+03	56600.00
822EB9	2017-08-11 14:31:00+03	27200.00
822EEB	2017-08-10 12:35:00+03	28000.00
822FB9	2017-07-20 10:10:00+03	3400.00
822FC9	2017-07-29 16:08:00+03	40800.00
822FEC	2017-07-23 21:37:00+03	49100.00
823103	2017-06-27 07:20:00+03	25100.00
82313F	2017-07-29 14:23:00+03	57500.00
82316A	2017-08-12 16:49:00+03	316800.00
8231A7	2017-08-08 23:11:00+03	148700.00
8231C9	2017-07-27 11:31:00+03	165100.00
8231F8	2017-08-07 12:56:00+03	27000.00
823274	2017-07-11 04:40:00+03	30200.00
8232D7	2017-07-27 05:35:00+03	8200.00
82335B	2017-08-09 20:02:00+03	91000.00
82338A	2017-07-11 06:41:00+03	56000.00
82339D	2017-07-05 06:32:00+03	42900.00
8233E8	2017-07-25 02:45:00+03	156300.00
8233EC	2017-07-24 18:02:00+03	38600.00
823433	2017-07-31 00:06:00+03	36200.00
823472	2017-07-06 15:07:00+03	16800.00
8234AD	2017-08-14 10:02:00+03	59200.00
8234BB	2017-07-07 05:25:00+03	66000.00
823516	2017-08-05 15:52:00+03	109800.00
823529	2017-08-09 12:25:00+03	67200.00
8235E8	2017-07-27 13:33:00+03	70600.00
82360B	2017-07-03 03:42:00+03	92900.00
823668	2017-07-31 11:19:00+03	18600.00
8236AC	2017-06-30 20:25:00+03	53700.00
823747	2017-07-13 22:47:00+03	95400.00
823775	2017-08-04 04:50:00+03	215600.00
823797	2017-08-12 16:10:00+03	13000.00
82381A	2017-07-16 13:25:00+03	271100.00
82381D	2017-07-25 00:26:00+03	135200.00
823843	2017-07-22 18:15:00+03	94300.00
82386A	2017-07-20 08:15:00+03	62000.00
8238C6	2017-07-27 22:33:00+03	57600.00
8238DD	2017-08-07 20:18:00+03	46000.00
82395D	2017-07-17 11:52:00+03	208200.00
8239A5	2017-07-16 01:09:00+03	28800.00
8239B4	2017-07-12 03:12:00+03	56900.00
8239B9	2017-08-15 16:28:00+03	36600.00
8239C9	2017-08-08 17:22:00+03	99300.00
823A23	2017-06-28 11:10:00+03	44500.00
823A55	2017-08-13 14:48:00+03	37200.00
823AA9	2017-08-06 11:31:00+03	73600.00
823AEB	2017-07-01 20:01:00+03	79900.00
823AEC	2017-07-28 03:26:00+03	26000.00
823AFE	2017-07-28 19:45:00+03	100900.00
823B26	2017-07-09 03:57:00+03	13200.00
823B68	2017-07-20 05:25:00+03	152900.00
823BC4	2017-08-02 02:58:00+03	46800.00
823BF4	2017-07-09 10:28:00+03	23600.00
823CC9	2017-08-14 06:08:00+03	135300.00
823CCF	2017-07-18 01:50:00+03	269200.00
823CF8	2017-07-06 04:38:00+03	99700.00
823D41	2017-08-07 17:57:00+03	202300.00
823DBB	2017-07-21 15:10:00+03	92800.00
823E69	2017-07-15 01:33:00+03	16800.00
823E6F	2017-07-11 03:15:00+03	67700.00
823E8E	2017-07-21 22:49:00+03	85000.00
823F8A	2017-07-08 19:26:00+03	19600.00
823FD1	2017-08-01 04:00:00+03	55800.00
82405A	2017-07-26 13:07:00+03	47500.00
824075	2017-08-06 04:11:00+03	64500.00
8240F1	2017-07-21 17:08:00+03	75600.00
824105	2017-08-04 07:14:00+03	63200.00
824117	2017-07-20 08:13:00+03	68100.00
824125	2017-07-16 05:56:00+03	25600.00
82416A	2017-07-10 09:33:00+03	92700.00
824182	2017-07-24 23:55:00+03	52900.00
8241D1	2017-07-03 05:21:00+03	44500.00
8241E7	2017-07-02 05:35:00+03	70100.00
82426F	2017-07-30 16:06:00+03	119600.00
8242BE	2017-07-08 08:35:00+03	13400.00
8242EF	2017-08-11 03:45:00+03	44600.00
824306	2017-07-31 16:26:00+03	59200.00
82435A	2017-07-30 22:22:00+03	134800.00
82435E	2017-07-12 10:04:00+03	23400.00
824385	2017-08-03 09:12:00+03	58400.00
8243DA	2017-07-10 08:17:00+03	46400.00
824441	2017-08-14 03:09:00+03	80000.00
824487	2017-07-17 14:13:00+03	54000.00
8244C8	2017-07-10 02:52:00+03	79900.00
824528	2017-08-13 04:56:00+03	14800.00
824533	2017-06-29 01:55:00+03	21800.00
82457F	2017-07-31 04:01:00+03	24300.00
82459A	2017-07-13 03:30:00+03	136800.00
82459F	2017-08-03 03:27:00+03	23600.00
824628	2017-07-23 13:16:00+03	40600.00
824640	2017-07-21 11:57:00+03	90400.00
824714	2017-07-28 21:26:00+03	36000.00
82478B	2017-07-24 09:20:00+03	23600.00
8247D9	2017-08-06 07:03:00+03	136800.00
82482C	2017-08-06 00:08:00+03	58700.00
82486B	2017-08-04 02:24:00+03	397100.00
82486E	2017-07-29 06:48:00+03	133600.00
82487F	2017-07-20 05:48:00+03	31000.00
824900	2017-08-01 10:39:00+03	47100.00
824967	2017-07-28 15:21:00+03	58900.00
8249EC	2017-07-28 07:25:00+03	46400.00
824A08	2017-07-26 08:28:00+03	135600.00
824A3A	2017-08-03 14:58:00+03	88600.00
824A4E	2017-08-05 22:55:00+03	14000.00
824A68	2017-07-03 13:49:00+03	154500.00
824AC3	2017-07-10 22:49:00+03	53700.00
824B01	2017-07-30 21:57:00+03	26000.00
824B08	2017-07-08 22:21:00+03	18000.00
824B9D	2017-07-07 04:08:00+03	15700.00
824C59	2017-07-10 15:07:00+03	56000.00
824C77	2017-07-27 14:59:00+03	19600.00
824CB6	2017-07-01 16:17:00+03	64600.00
824CD5	2017-07-14 01:21:00+03	147200.00
824CF2	2017-07-24 10:30:00+03	41600.00
824CFA	2017-07-14 04:15:00+03	26200.00
824D03	2017-07-14 20:45:00+03	28000.00
824D71	2017-07-09 09:09:00+03	27800.00
824DDB	2017-08-15 04:14:00+03	36200.00
824E11	2017-07-18 12:28:00+03	103300.00
824E6C	2017-08-12 11:50:00+03	36200.00
824F23	2017-08-10 04:37:00+03	45500.00
824F2D	2017-07-10 04:14:00+03	90700.00
82507C	2017-07-20 00:22:00+03	25600.00
8250AD	2017-07-25 05:57:00+03	30800.00
8250DF	2017-07-03 23:26:00+03	23200.00
8250E6	2017-07-10 22:10:00+03	116900.00
825126	2017-07-02 15:37:00+03	71400.00
825159	2017-08-13 03:35:00+03	57600.00
82515E	2017-07-18 00:52:00+03	100600.00
82519B	2017-07-19 06:40:00+03	52000.00
8251BE	2017-08-08 04:25:00+03	56600.00
8251D9	2017-07-18 18:27:00+03	92000.00
825247	2017-08-12 14:27:00+03	77800.00
825253	2017-07-22 23:38:00+03	273000.00
8252C5	2017-07-13 11:18:00+03	99300.00
825302	2017-07-26 11:33:00+03	37000.00
82530F	2017-07-26 09:15:00+03	99200.00
82531C	2017-08-05 19:02:00+03	85000.00
825333	2017-08-01 13:29:00+03	206700.00
82536D	2017-08-07 22:12:00+03	66600.00
8253A7	2017-07-27 08:20:00+03	10600.00
825401	2017-07-27 02:11:00+03	67900.00
825441	2017-07-21 00:16:00+03	46200.00
825478	2017-08-06 17:29:00+03	26000.00
82547D	2017-07-26 07:09:00+03	58000.00
825488	2017-07-12 17:48:00+03	46000.00
8254A4	2017-07-14 18:22:00+03	187600.00
8254A6	2017-07-19 22:51:00+03	58000.00
825569	2017-07-06 19:28:00+03	84100.00
825664	2017-08-03 15:37:00+03	28300.00
825695	2017-08-01 10:53:00+03	99200.00
8256A2	2017-07-08 09:56:00+03	7200.00
82572E	2017-08-10 13:55:00+03	19000.00
82573D	2017-07-15 01:59:00+03	130800.00
825770	2017-08-06 17:27:00+03	47000.00
825790	2017-07-17 09:40:00+03	68100.00
825808	2017-08-01 18:14:00+03	48800.00
82581B	2017-07-17 21:03:00+03	28000.00
825829	2017-07-13 18:36:00+03	28800.00
82587C	2017-07-07 04:39:00+03	84500.00
82587D	2017-07-25 19:30:00+03	23900.00
825883	2017-07-07 18:15:00+03	56000.00
8258A4	2017-07-13 01:01:00+03	46200.00
8258A8	2017-06-28 12:09:00+03	140400.00
82599F	2017-08-05 06:14:00+03	20200.00
8259C8	2017-08-13 02:07:00+03	92800.00
8259D9	2017-07-21 11:07:00+03	47000.00
825A44	2017-07-09 01:58:00+03	146600.00
825A78	2017-08-08 11:53:00+03	21400.00
825A82	2017-08-11 11:21:00+03	83000.00
825A9B	2017-07-19 08:01:00+03	111600.00
825AC2	2017-07-14 09:35:00+03	48800.00
825B03	2017-07-20 12:06:00+03	17600.00
825B19	2017-07-23 18:37:00+03	52700.00
825B60	2017-07-28 16:49:00+03	67800.00
825B75	2017-07-08 13:21:00+03	36700.00
825C06	2017-07-26 19:33:00+03	44000.00
825C79	2017-07-08 18:07:00+03	58400.00
825CF3	2017-07-24 19:01:00+03	57800.00
825D06	2017-07-06 20:19:00+03	47200.00
825D56	2017-08-05 02:05:00+03	12000.00
825D8A	2017-07-07 00:15:00+03	43200.00
825DD3	2017-08-14 05:12:00+03	34000.00
825DFC	2017-07-19 03:50:00+03	44800.00
825E24	2017-07-09 00:36:00+03	270000.00
825E39	2017-07-25 14:35:00+03	31400.00
825E6B	2017-08-06 19:42:00+03	124100.00
825E8C	2017-07-01 15:47:00+03	64800.00
825E96	2017-07-31 09:15:00+03	12600.00
825EA4	2017-08-08 23:05:00+03	92800.00
825EC7	2017-07-07 22:41:00+03	95600.00
825EDE	2017-08-05 14:31:00+03	147700.00
825F09	2017-07-08 05:06:00+03	25200.00
825F55	2017-08-14 06:03:00+03	51700.00
825FA6	2017-07-17 13:08:00+03	46000.00
82602C	2017-08-12 22:02:00+03	28800.00
82606B	2017-07-15 06:21:00+03	63300.00
82606E	2017-07-27 02:34:00+03	29600.00
8260CA	2017-07-02 09:14:00+03	81300.00
826102	2017-07-11 11:51:00+03	111000.00
826120	2017-07-28 06:46:00+03	21800.00
826150	2017-07-27 20:10:00+03	56000.00
826163	2017-07-01 18:52:00+03	100600.00
82618E	2017-07-25 08:16:00+03	56100.00
8262B0	2017-07-27 11:59:00+03	28800.00
8262BC	2017-07-04 00:40:00+03	21000.00
8262F3	2017-07-27 10:55:00+03	24400.00
8262F4	2017-07-25 17:49:00+03	133200.00
82636C	2017-08-08 02:39:00+03	210800.00
82638D	2017-07-26 14:40:00+03	49600.00
8263AA	2017-07-05 16:45:00+03	77900.00
8263C3	2017-07-23 02:06:00+03	16400.00
8263CB	2017-07-04 12:07:00+03	72400.00
8263EC	2017-07-26 20:15:00+03	68400.00
8263FC	2017-08-11 13:49:00+03	119500.00
826468	2017-07-22 09:47:00+03	206800.00
8264AF	2017-08-15 05:36:00+03	39800.00
826576	2017-07-16 04:38:00+03	216000.00
826596	2017-07-24 22:19:00+03	16800.00
8265CD	2017-08-06 03:40:00+03	86800.00
826610	2017-08-03 23:53:00+03	8000.00
826654	2017-07-27 23:16:00+03	28000.00
826667	2017-08-01 12:22:00+03	108900.00
82669D	2017-07-23 21:30:00+03	75300.00
82676A	2017-07-22 16:43:00+03	67600.00
826771	2017-07-21 13:35:00+03	55800.00
82678C	2017-07-12 23:26:00+03	58400.00
826792	2017-07-07 17:05:00+03	40000.00
82679B	2017-08-13 21:37:00+03	236000.00
8267A7	2017-07-12 09:45:00+03	35200.00
8267B1	2017-07-12 07:12:00+03	85000.00
8267D1	2017-07-14 05:53:00+03	54500.00
8267D9	2017-07-18 01:31:00+03	22000.00
8267E6	2017-07-15 17:29:00+03	27900.00
8267F6	2017-08-02 15:15:00+03	56000.00
826831	2017-08-01 02:07:00+03	6000.00
8268D4	2017-07-24 13:06:00+03	40800.00
8268D8	2017-07-20 00:42:00+03	15000.00
82696A	2017-08-05 02:06:00+03	50400.00
82698F	2017-08-02 04:23:00+03	114800.00
8269A1	2017-07-13 02:46:00+03	29600.00
8269CD	2017-07-14 00:03:00+03	138500.00
8269D0	2017-08-15 14:30:00+03	273000.00
826A1E	2017-08-08 08:09:00+03	23200.00
826A84	2017-07-06 21:06:00+03	64500.00
826A9B	2017-07-12 13:05:00+03	136800.00
826ADD	2017-07-12 05:55:00+03	54000.00
826B46	2017-08-10 13:15:00+03	169800.00
826B49	2017-07-27 17:04:00+03	273600.00
826B63	2017-08-05 20:11:00+03	131600.00
826B9C	2017-08-07 13:29:00+03	12200.00
826BC2	2017-07-25 11:30:00+03	55800.00
826BCD	2017-08-05 10:54:00+03	83000.00
826BF6	2017-08-08 03:20:00+03	269300.00
826C05	2017-07-15 20:56:00+03	84500.00
826C30	2017-07-25 16:50:00+03	25600.00
826CFD	2017-08-01 17:08:00+03	46800.00
826D48	2017-08-04 21:23:00+03	10600.00
826D6F	2017-08-06 15:27:00+03	16400.00
826D9C	2017-07-15 06:36:00+03	37700.00
826DC0	2017-07-19 09:01:00+03	43400.00
826E07	2017-08-05 10:28:00+03	270000.00
826E3B	2017-07-30 06:49:00+03	19600.00
826E7D	2017-07-21 11:11:00+03	68400.00
826EE5	2017-07-14 06:17:00+03	135400.00
826EF3	2017-07-30 16:27:00+03	73600.00
826F37	2017-07-23 22:16:00+03	131100.00
826F3D	2017-07-16 05:29:00+03	110700.00
826F76	2017-07-06 01:15:00+03	28800.00
826F96	2017-07-25 10:26:00+03	80300.00
826F9F	2017-08-04 18:55:00+03	262200.00
826FDF	2017-07-14 21:46:00+03	29600.00
826FE2	2017-08-02 18:01:00+03	67200.00
82701B	2017-08-10 00:13:00+03	136700.00
827025	2017-07-25 12:15:00+03	34800.00
8270D2	2017-07-15 17:58:00+03	78800.00
82712F	2017-07-11 01:30:00+03	129200.00
827137	2017-07-06 10:04:00+03	161100.00
827170	2017-07-20 06:17:00+03	22000.00
82719B	2017-07-14 18:40:00+03	92000.00
82722B	2017-07-21 20:43:00+03	28800.00
827238	2017-07-21 10:25:00+03	337400.00
82729C	2017-07-21 19:04:00+03	38600.00
8272A9	2017-07-11 13:44:00+03	133200.00
8272B2	2017-07-25 14:03:00+03	23200.00
8272E9	2017-07-15 22:00:00+03	91600.00
827303	2017-08-02 18:21:00+03	48200.00
827385	2017-08-04 14:05:00+03	58800.00
8273A2	2017-07-30 13:02:00+03	46300.00
8273D5	2017-08-08 08:30:00+03	50400.00
827407	2017-07-13 03:25:00+03	65200.00
827416	2017-08-05 21:06:00+03	46000.00
8274C6	2017-08-14 16:16:00+03	92800.00
8274CB	2017-07-22 07:04:00+03	138400.00
8274DB	2017-07-15 17:24:00+03	62100.00
8274DD	2017-07-22 23:52:00+03	47100.00
8274E0	2017-07-27 11:30:00+03	28800.00
8274FD	2017-07-17 21:57:00+03	24000.00
827579	2017-08-10 10:23:00+03	37700.00
8275B4	2017-07-07 13:18:00+03	22600.00
8275CE	2017-07-28 21:56:00+03	116400.00
827645	2017-08-13 15:43:00+03	149300.00
827660	2017-08-02 19:26:00+03	135600.00
827686	2017-07-09 02:10:00+03	51900.00
8276C4	2017-07-28 23:13:00+03	65500.00
8276CF	2017-07-02 16:50:00+03	37900.00
8276E9	2017-07-29 20:32:00+03	46900.00
82770A	2017-07-31 17:02:00+03	40000.00
827744	2017-08-01 23:41:00+03	28800.00
827763	2017-08-10 11:24:00+03	56000.00
8278C1	2017-08-09 03:08:00+03	32700.00
8278D9	2017-07-29 13:03:00+03	67700.00
8278F7	2017-07-01 20:43:00+03	42600.00
827929	2017-08-07 03:11:00+03	81600.00
8279A0	2017-07-26 11:10:00+03	529200.00
8279C6	2017-08-15 00:23:00+03	113000.00
827A09	2017-07-07 04:29:00+03	29600.00
827A34	2017-07-22 13:47:00+03	29500.00
827A66	2017-07-21 12:28:00+03	46000.00
827ADE	2017-06-26 03:46:00+03	42800.00
827AFF	2017-08-11 15:54:00+03	12000.00
827B76	2017-07-06 03:04:00+03	48300.00
827BFD	2017-07-09 11:08:00+03	35300.00
827C5D	2017-08-10 23:06:00+03	28800.00
827CF4	2017-08-13 02:36:00+03	28300.00
827D3F	2017-07-11 20:07:00+03	197200.00
827D58	2017-07-05 18:08:00+03	148200.00
827D66	2017-08-12 23:42:00+03	47100.00
827DC0	2017-07-12 03:56:00+03	9200.00
827E00	2017-07-31 22:57:00+03	189200.00
827E57	2017-07-04 09:52:00+03	72300.00
827E9F	2017-08-12 15:39:00+03	58200.00
827EA8	2017-08-09 08:15:00+03	42800.00
827F4C	2017-08-12 07:54:00+03	6700.00
827F72	2017-07-18 16:18:00+03	25600.00
828025	2017-06-29 22:46:00+03	62000.00
8280AB	2017-08-08 18:48:00+03	34000.00
8280D9	2017-08-01 07:57:00+03	46000.00
8280FE	2017-07-24 11:21:00+03	155600.00
82810A	2017-07-29 23:18:00+03	22000.00
8281B1	2017-07-21 23:32:00+03	38600.00
8281FB	2017-07-25 16:29:00+03	56600.00
828210	2017-07-27 23:34:00+03	32800.00
828231	2017-07-25 22:47:00+03	101200.00
828271	2017-07-05 02:40:00+03	84100.00
828282	2017-08-13 15:35:00+03	92800.00
8282C2	2017-07-04 19:20:00+03	120800.00
8282DA	2017-08-14 09:16:00+03	32700.00
8282DB	2017-07-09 01:15:00+03	43200.00
8282F6	2017-07-25 16:39:00+03	57500.00
828356	2017-07-19 21:47:00+03	32800.00
82835F	2017-08-02 00:02:00+03	36000.00
828393	2017-07-12 01:45:00+03	46200.00
828396	2017-07-27 03:25:00+03	28800.00
8283BC	2017-08-11 05:26:00+03	205300.00
8283D5	2017-08-01 01:33:00+03	67400.00
8283EE	2017-07-19 18:10:00+03	136800.00
828402	2017-07-19 15:33:00+03	111700.00
8284A1	2017-07-03 12:33:00+03	101200.00
828501	2017-07-16 02:11:00+03	23900.00
828510	2017-07-03 21:32:00+03	56000.00
828517	2017-08-14 23:12:00+03	83600.00
828519	2017-08-11 08:24:00+03	46400.00
8285C2	2017-07-15 15:23:00+03	30200.00
8285E8	2017-07-20 14:19:00+03	135600.00
828625	2017-08-13 06:53:00+03	27200.00
82867B	2017-07-05 08:37:00+03	68800.00
82867E	2017-08-10 20:47:00+03	23200.00
8286AA	2017-07-30 00:15:00+03	57600.00
828739	2017-07-28 04:59:00+03	64500.00
82873F	2017-07-01 04:49:00+03	38000.00
828761	2017-07-18 09:42:00+03	129200.00
828808	2017-07-08 20:21:00+03	23400.00
828834	2017-07-08 23:39:00+03	12400.00
82887D	2017-07-19 17:16:00+03	49100.00
8288D3	2017-07-24 23:14:00+03	12400.00
8288E4	2017-07-16 08:18:00+03	29200.00
828901	2017-08-10 18:45:00+03	22000.00
8289AA	2017-08-01 08:49:00+03	30600.00
8289E3	2017-07-12 14:38:00+03	167400.00
828ACC	2017-08-15 12:53:00+03	45200.00
828AEB	2017-07-27 13:31:00+03	23200.00
828B53	2017-07-24 23:16:00+03	23600.00
828B7A	2017-07-31 19:13:00+03	48500.00
828B89	2017-07-24 09:32:00+03	55600.00
828BD8	2017-07-08 23:37:00+03	46000.00
828C84	2017-07-20 11:12:00+03	67300.00
828D03	2017-08-04 07:01:00+03	73200.00
828D16	2017-08-11 19:06:00+03	386300.00
828D66	2017-08-11 17:08:00+03	31100.00
828D76	2017-08-02 07:28:00+03	166100.00
828DB0	2017-07-08 06:22:00+03	147900.00
828DE9	2017-07-15 07:57:00+03	79600.00
828E01	2017-07-03 06:07:00+03	91500.00
828EB5	2017-07-19 16:06:00+03	46400.00
828EE2	2017-07-08 02:06:00+03	72300.00
828EF7	2017-07-14 08:43:00+03	23200.00
828F17	2017-08-01 09:21:00+03	25200.00
828F7E	2017-07-24 11:36:00+03	7400.00
828FE5	2017-07-01 05:58:00+03	192100.00
829005	2017-07-03 01:04:00+03	133200.00
829021	2017-08-15 10:24:00+03	48800.00
829040	2017-08-02 20:36:00+03	58900.00
829050	2017-07-01 09:17:00+03	53700.00
829075	2017-08-13 15:15:00+03	6700.00
8290C3	2017-08-02 01:38:00+03	8200.00
829143	2017-08-14 09:33:00+03	89700.00
82916A	2017-07-06 09:14:00+03	139300.00
8291B6	2017-08-02 00:44:00+03	7200.00
82920F	2017-07-06 04:40:00+03	196300.00
829218	2017-07-19 11:52:00+03	53600.00
829267	2017-07-12 13:47:00+03	21800.00
8292F2	2017-07-28 04:53:00+03	67400.00
829392	2017-07-05 18:49:00+03	95600.00
8293BA	2017-07-06 04:09:00+03	12600.00
8293C9	2017-08-14 04:15:00+03	257600.00
82941D	2017-08-15 13:07:00+03	19600.00
829458	2017-07-25 06:06:00+03	37200.00
829464	2017-07-13 06:29:00+03	178300.00
829473	2017-07-01 08:33:00+03	49100.00
8294BA	2017-07-04 14:33:00+03	72400.00
829530	2017-07-24 07:33:00+03	23200.00
829575	2017-08-08 12:53:00+03	6700.00
82958A	2017-07-20 01:23:00+03	111600.00
8295B3	2017-08-01 00:06:00+03	44800.00
8295E6	2017-08-01 20:04:00+03	139300.00
8295FE	2017-08-15 00:27:00+03	88800.00
829635	2017-07-05 12:30:00+03	34000.00
829672	2017-08-13 08:58:00+03	135400.00
829686	2017-08-14 15:07:00+03	55800.00
8296B0	2017-08-07 11:06:00+03	196800.00
8296B2	2017-07-03 14:22:00+03	112000.00
829745	2017-07-21 02:09:00+03	85000.00
82974C	2017-07-15 06:16:00+03	34700.00
82977E	2017-07-23 20:07:00+03	31600.00
8297B3	2017-07-19 20:25:00+03	56600.00
8297E4	2017-08-05 17:48:00+03	66600.00
829860	2017-08-03 17:00:00+03	60400.00
829887	2017-08-04 10:44:00+03	219300.00
8298EA	2017-08-14 20:12:00+03	97600.00
8298F1	2017-07-02 04:59:00+03	156500.00
82995F	2017-08-03 01:31:00+03	40000.00
82996E	2017-07-15 17:43:00+03	81400.00
8299B4	2017-07-22 00:58:00+03	129400.00
829A2B	2017-07-25 19:44:00+03	31400.00
829A46	2017-07-17 12:40:00+03	28300.00
829AD7	2017-08-15 05:22:00+03	26000.00
829B83	2017-07-19 18:25:00+03	66800.00
829BAC	2017-07-23 23:31:00+03	40800.00
829BBF	2017-07-19 18:17:00+03	27300.00
829BD2	2017-07-21 02:03:00+03	62800.00
829C01	2017-08-13 19:18:00+03	65900.00
829CD5	2017-08-03 11:54:00+03	37200.00
829D24	2017-08-09 07:20:00+03	112000.00
829D2D	2017-07-22 13:29:00+03	130800.00
829D5B	2017-08-05 15:13:00+03	106000.00
829DC7	2017-07-05 11:55:00+03	164400.00
829DF1	2017-08-15 01:00:00+03	101200.00
829E05	2017-07-28 04:53:00+03	49800.00
829E16	2017-07-30 05:04:00+03	46400.00
829E2C	2017-07-18 10:53:00+03	64100.00
829E7F	2017-08-05 00:17:00+03	48500.00
829F16	2017-07-30 11:52:00+03	29400.00
829F70	2017-08-13 01:56:00+03	49100.00
82A049	2017-06-28 01:24:00+03	57800.00
82A0F1	2017-08-07 14:46:00+03	39800.00
82A153	2017-07-19 06:10:00+03	492000.00
82A17F	2017-07-27 17:32:00+03	37500.00
82A1DD	2017-07-10 09:26:00+03	399600.00
82A21B	2017-07-11 15:52:00+03	58800.00
82A21D	2017-08-15 09:30:00+03	41900.00
82A229	2017-07-18 10:39:00+03	26700.00
82A290	2017-07-07 10:22:00+03	62600.00
82A2B8	2017-07-10 10:57:00+03	48500.00
82A2CB	2017-06-30 03:46:00+03	28000.00
82A337	2017-07-10 09:45:00+03	62600.00
82A359	2017-08-11 20:43:00+03	90300.00
82A3CA	2017-07-24 02:22:00+03	12600.00
82A3EB	2017-08-02 06:52:00+03	33400.00
82A473	2017-07-03 20:32:00+03	36200.00
82A4F3	2017-07-31 10:07:00+03	28000.00
82A532	2017-07-23 08:05:00+03	17800.00
82A589	2017-07-05 22:52:00+03	101100.00
82A5C4	2017-07-02 16:18:00+03	29600.00
82A5CD	2017-07-12 01:19:00+03	91100.00
82A5FD	2017-08-09 16:50:00+03	18000.00
82A61D	2017-07-21 19:18:00+03	39800.00
82A661	2017-08-14 06:38:00+03	162200.00
82A6D9	2017-08-07 14:22:00+03	122300.00
82A6FB	2017-07-24 06:22:00+03	28000.00
82A794	2017-07-14 22:26:00+03	55800.00
82A7B1	2017-07-11 08:15:00+03	136300.00
82A7B2	2017-07-28 12:46:00+03	67200.00
82A7C6	2017-08-13 01:49:00+03	10800.00
82A7FA	2017-07-05 03:44:00+03	41400.00
82A81A	2017-07-22 08:54:00+03	58600.00
82A847	2017-08-07 02:28:00+03	10800.00
82A85D	2017-08-11 14:28:00+03	56900.00
82A934	2017-08-01 00:05:00+03	58800.00
82A976	2017-08-10 14:40:00+03	60800.00
82A997	2017-07-20 18:53:00+03	37600.00
82AA57	2017-08-07 00:28:00+03	6000.00
82AA82	2017-07-13 20:52:00+03	14400.00
82AABC	2017-07-15 14:36:00+03	284400.00
82AADC	2017-07-03 10:12:00+03	28000.00
82AB0D	2017-07-29 08:41:00+03	182300.00
82AB66	2017-07-31 16:45:00+03	46400.00
82AB85	2017-07-23 09:53:00+03	56000.00
82AB9A	2017-08-04 20:26:00+03	68600.00
82AB9B	2017-07-16 20:11:00+03	6600.00
82ABA3	2017-08-09 19:01:00+03	139800.00
82ABBC	2017-07-24 18:55:00+03	113600.00
82ABBD	2017-07-05 09:52:00+03	24200.00
82ABCD	2017-08-01 11:26:00+03	143300.00
82AC7D	2017-07-05 12:10:00+03	182200.00
82ACC3	2017-07-19 09:47:00+03	24800.00
82ACD1	2017-07-20 00:53:00+03	46000.00
82AD05	2017-08-09 05:02:00+03	81900.00
82ADA4	2017-07-16 00:27:00+03	112600.00
82ADAF	2017-07-16 15:15:00+03	260300.00
82AE53	2017-07-05 21:55:00+03	133100.00
82AE7B	2017-08-05 07:09:00+03	293700.00
82AEC6	2017-07-27 11:08:00+03	26000.00
82AF90	2017-07-07 21:04:00+03	48800.00
82AF94	2017-07-27 17:45:00+03	101800.00
82AFB9	2017-07-16 14:23:00+03	40400.00
82AFF3	2017-07-21 10:48:00+03	50200.00
82B041	2017-07-11 19:14:00+03	40800.00
82B064	2017-07-12 15:07:00+03	98300.00
82B06B	2017-07-16 17:32:00+03	38400.00
82B0DF	2017-07-11 06:08:00+03	115700.00
82B125	2017-07-14 13:42:00+03	32400.00
82B142	2017-08-01 01:39:00+03	54600.00
82B16D	2017-07-19 21:27:00+03	25800.00
82B221	2017-07-03 19:09:00+03	40400.00
82B248	2017-07-08 19:22:00+03	70600.00
82B2C9	2017-07-14 09:20:00+03	38400.00
82B2D6	2017-07-06 16:03:00+03	29600.00
82B364	2017-07-18 01:10:00+03	69500.00
82B393	2017-08-08 20:04:00+03	48500.00
82B3BB	2017-08-04 07:42:00+03	87000.00
82B40A	2017-07-22 11:10:00+03	25800.00
82B4CC	2017-07-05 14:13:00+03	146300.00
82B4D6	2017-07-31 13:31:00+03	498200.00
82B4DC	2017-08-02 20:35:00+03	40800.00
82B4EF	2017-07-10 22:25:00+03	18600.00
82B4F6	2017-07-17 21:23:00+03	79500.00
82B518	2017-07-11 13:12:00+03	133100.00
82B54F	2017-08-11 01:57:00+03	64500.00
82B59A	2017-07-25 21:46:00+03	28700.00
82B5A1	2017-07-03 02:03:00+03	81000.00
82B5A7	2017-07-21 04:43:00+03	26000.00
82B5E6	2017-06-29 22:40:00+03	41900.00
82B625	2017-07-14 14:02:00+03	133200.00
82B647	2017-08-02 11:49:00+03	26600.00
82B64E	2017-08-10 15:35:00+03	6300.00
82B683	2017-08-11 22:39:00+03	64500.00
82B712	2017-07-23 22:34:00+03	24400.00
82B73D	2017-07-17 09:29:00+03	100200.00
82B7B7	2017-08-12 10:00:00+03	195600.00
82B810	2017-07-31 08:51:00+03	100600.00
82B82C	2017-07-12 13:58:00+03	73600.00
82B849	2017-07-17 21:10:00+03	6300.00
82B879	2017-08-09 11:18:00+03	29600.00
82B8C1	2017-08-11 12:07:00+03	92100.00
82B984	2017-08-05 02:27:00+03	57400.00
82B99B	2017-06-30 20:51:00+03	127200.00
82B9D3	2017-07-07 14:20:00+03	36200.00
82BA4F	2017-08-12 10:51:00+03	164600.00
82BAC0	2017-07-22 03:44:00+03	49100.00
82BADE	2017-08-01 22:18:00+03	65900.00
82BB2A	2017-08-10 15:48:00+03	68800.00
82BC3A	2017-07-29 18:15:00+03	42700.00
82BCB8	2017-07-09 12:56:00+03	89400.00
82BCDE	2017-07-04 12:36:00+03	75500.00
82BD3C	2017-07-08 18:45:00+03	797100.00
82BDD7	2017-08-01 04:54:00+03	54800.00
82BE0D	2017-07-01 02:23:00+03	14000.00
82BE3B	2017-06-30 04:55:00+03	35600.00
82BE69	2017-07-18 22:59:00+03	86400.00
82BE6A	2017-07-29 12:51:00+03	47200.00
82BE6D	2017-07-08 20:31:00+03	32800.00
82BEC9	2017-08-13 08:42:00+03	199200.00
82BFA8	2017-07-18 18:03:00+03	224000.00
82BFAF	2017-08-08 06:31:00+03	51600.00
82BFD3	2017-07-04 04:16:00+03	23600.00
82BFEE	2017-07-10 17:09:00+03	113700.00
82C054	2017-07-15 06:11:00+03	6000.00
82C067	2017-08-01 20:33:00+03	191200.00
82C0CD	2017-08-03 06:53:00+03	105100.00
82C0EE	2017-08-08 02:27:00+03	86100.00
82C13A	2017-08-13 17:06:00+03	145100.00
82C149	2017-08-04 20:55:00+03	52300.00
82C1C7	2017-07-14 13:44:00+03	56000.00
82C200	2017-07-01 14:07:00+03	173900.00
82C2C5	2017-08-06 13:11:00+03	66600.00
82C2FB	2017-08-05 12:15:00+03	7400.00
82C305	2017-07-08 17:30:00+03	31600.00
82C306	2017-08-07 21:15:00+03	36200.00
82C30C	2017-07-10 16:17:00+03	118000.00
82C312	2017-07-18 14:29:00+03	92800.00
82C33E	2017-07-30 20:13:00+03	63200.00
82C378	2017-07-29 07:54:00+03	55800.00
82C391	2017-07-15 11:55:00+03	21800.00
82C3D0	2017-07-19 05:53:00+03	30200.00
82C3FD	2017-07-13 06:05:00+03	30400.00
82C424	2017-07-13 16:30:00+03	6800.00
82C43C	2017-07-21 17:44:00+03	83100.00
82C45E	2017-08-02 19:16:00+03	46000.00
82C49D	2017-06-29 18:08:00+03	28300.00
82C502	2017-07-27 14:22:00+03	56400.00
82C552	2017-07-29 10:34:00+03	71200.00
82C55C	2017-07-15 22:50:00+03	55800.00
82C56E	2017-08-13 04:37:00+03	40200.00
82C5D9	2017-08-14 23:25:00+03	131100.00
82C5EC	2017-07-15 04:21:00+03	55800.00
82C602	2017-07-31 22:39:00+03	19800.00
82C60F	2017-07-13 12:53:00+03	9200.00
82C6B1	2017-07-17 00:19:00+03	21800.00
82C6FB	2017-07-30 10:47:00+03	36400.00
82C756	2017-07-22 03:16:00+03	40800.00
82C778	2017-08-11 00:55:00+03	27200.00
82C7CB	2017-08-01 12:30:00+03	60500.00
82C7E5	2017-07-09 18:58:00+03	76000.00
82C86C	2017-08-12 06:40:00+03	128800.00
82C8DF	2017-08-09 04:41:00+03	46300.00
82C901	2017-08-01 23:45:00+03	18000.00
82C99B	2017-07-01 15:05:00+03	29400.00
82CA3C	2017-07-29 12:47:00+03	54800.00
82CA52	2017-08-02 22:16:00+03	38400.00
82CA5F	2017-08-08 23:31:00+03	24000.00
82CA78	2017-08-13 21:20:00+03	67200.00
82CA84	2017-07-31 21:22:00+03	27300.00
82CB11	2017-08-02 08:31:00+03	31400.00
82CB32	2017-07-21 22:26:00+03	51900.00
82CBD8	2017-08-13 05:44:00+03	104100.00
82CBDE	2017-07-01 01:49:00+03	87100.00
82CBFC	2017-07-14 06:01:00+03	60400.00
82CC09	2017-07-30 15:40:00+03	36400.00
82CC2A	2017-07-30 07:45:00+03	36200.00
82CC4D	2017-08-06 11:31:00+03	106400.00
82CC98	2017-08-03 08:31:00+03	59900.00
82CD23	2017-07-03 13:23:00+03	60300.00
82CD4D	2017-08-11 19:28:00+03	799400.00
82CD73	2017-07-30 04:14:00+03	23600.00
82CDF6	2017-07-11 14:33:00+03	22000.00
82CE1C	2017-08-05 07:30:00+03	65400.00
82CE3B	2017-08-02 02:27:00+03	81300.00
82CE3D	2017-07-07 21:30:00+03	12200.00
82CEFB	2017-08-13 19:19:00+03	135400.00
82CFBA	2017-08-12 00:31:00+03	59200.00
82CFDE	2017-06-29 09:34:00+03	155600.00
82D049	2017-07-12 19:00:00+03	135400.00
82D05E	2017-07-03 04:13:00+03	32800.00
82D0AF	2017-07-31 02:05:00+03	47400.00
82D0B5	2017-07-23 07:22:00+03	25100.00
82D177	2017-07-19 05:22:00+03	70500.00
82D183	2017-07-14 14:41:00+03	67700.00
82D223	2017-07-07 02:12:00+03	57800.00
82D260	2017-08-07 18:40:00+03	32900.00
82D292	2017-08-03 09:49:00+03	35700.00
82D2B2	2017-07-24 18:24:00+03	22200.00
82D2E0	2017-06-25 21:44:00+03	152900.00
82D2EF	2017-08-04 16:43:00+03	32600.00
82D30F	2017-07-25 11:20:00+03	23200.00
82D318	2017-07-17 16:02:00+03	13200.00
82D31C	2017-07-06 14:22:00+03	101200.00
82D36A	2017-07-27 15:22:00+03	90000.00
82D435	2017-07-23 03:49:00+03	101200.00
82D44A	2017-08-03 21:28:00+03	66200.00
82D468	2017-08-04 07:18:00+03	25400.00
82D46E	2017-08-03 04:27:00+03	37000.00
82D4BD	2017-07-17 04:05:00+03	67600.00
82D4D0	2017-08-10 10:34:00+03	184000.00
82D4EF	2017-07-24 20:27:00+03	81900.00
82D4FE	2017-07-16 21:10:00+03	19600.00
82D502	2017-07-05 01:14:00+03	135400.00
82D568	2017-06-29 05:00:00+03	30200.00
82D590	2017-07-03 09:57:00+03	111600.00
82D597	2017-08-03 10:39:00+03	68800.00
82D5FC	2017-06-27 16:36:00+03	176500.00
82D6B5	2017-07-24 17:00:00+03	191000.00
82D744	2017-07-13 10:48:00+03	15000.00
82D747	2017-08-05 00:40:00+03	92400.00
82D76C	2017-08-13 23:38:00+03	24400.00
82D795	2017-07-21 14:56:00+03	111600.00
82D7B7	2017-08-03 02:10:00+03	100600.00
82D7BD	2017-07-29 21:40:00+03	83000.00
82D7D4	2017-07-08 09:26:00+03	49800.00
82D806	2017-07-20 02:20:00+03	31100.00
82D84D	2017-07-01 14:31:00+03	23400.00
82D85E	2017-08-07 12:00:00+03	75600.00
82D89D	2017-08-04 02:39:00+03	65900.00
82D8DC	2017-07-10 15:55:00+03	13400.00
82D900	2017-08-06 13:31:00+03	272500.00
82D937	2017-08-06 23:44:00+03	65500.00
82D961	2017-08-14 18:28:00+03	112000.00
82DA26	2017-07-07 06:28:00+03	28300.00
82DA52	2017-07-23 15:58:00+03	369000.00
82DAF5	2017-07-29 05:04:00+03	26000.00
82DAF6	2017-08-06 04:25:00+03	36500.00
82DB02	2017-07-12 00:55:00+03	13000.00
82DB20	2017-07-23 22:31:00+03	43200.00
82DB62	2017-08-09 14:11:00+03	62500.00
82DBC1	2017-08-03 09:23:00+03	31200.00
82DBF2	2017-07-24 00:05:00+03	28800.00
82DC00	2017-07-25 00:55:00+03	83300.00
82DC10	2017-07-23 01:30:00+03	97800.00
82DC78	2017-07-12 14:12:00+03	56000.00
82DC8F	2017-08-13 07:01:00+03	61300.00
82DC9B	2017-07-15 12:47:00+03	31600.00
82DC9C	2017-07-15 05:04:00+03	69500.00
82DCBC	2017-08-07 11:35:00+03	119700.00
82DCEB	2017-07-06 10:04:00+03	21800.00
82DD11	2017-08-15 02:25:00+03	84700.00
82DDC6	2017-08-08 11:06:00+03	52400.00
82DDDE	2017-07-26 08:51:00+03	64800.00
82DE1C	2017-08-06 05:10:00+03	27500.00
82DEAE	2017-07-13 18:50:00+03	49800.00
82DEC6	2017-08-05 08:49:00+03	38600.00
82DEC8	2017-07-14 23:23:00+03	46400.00
82DEFA	2017-08-07 14:25:00+03	109600.00
82DF15	2017-07-30 06:09:00+03	49800.00
82DF60	2017-08-09 18:44:00+03	51900.00
82DF87	2017-08-13 08:49:00+03	43200.00
82DF9F	2017-07-21 21:36:00+03	30000.00
82DFB1	2017-07-23 19:29:00+03	27200.00
82DFC6	2017-08-01 21:09:00+03	66000.00
82DFDD	2017-08-09 16:39:00+03	10600.00
82DFF3	2017-07-10 00:09:00+03	22000.00
82DFF4	2017-08-14 23:56:00+03	153600.00
82E038	2017-07-23 15:50:00+03	38600.00
82E055	2017-07-15 22:20:00+03	200500.00
82E06B	2017-07-29 12:29:00+03	24400.00
82E0B0	2017-07-04 04:01:00+03	142800.00
82E0C3	2017-08-12 11:16:00+03	258400.00
82E0D6	2017-07-25 14:38:00+03	133200.00
82E0DD	2017-07-04 21:05:00+03	173900.00
82E0E6	2017-07-17 00:49:00+03	36200.00
82E108	2017-07-12 23:37:00+03	54100.00
82E11A	2017-07-29 03:10:00+03	202100.00
82E122	2017-08-07 11:30:00+03	132800.00
82E192	2017-07-24 22:43:00+03	55800.00
82E193	2017-07-22 10:08:00+03	29800.00
82E197	2017-07-11 12:49:00+03	252200.00
82E1BA	2017-07-07 01:05:00+03	167500.00
82E1D3	2017-07-09 23:06:00+03	37100.00
82E22C	2017-07-24 08:35:00+03	34800.00
82E28A	2017-08-07 11:26:00+03	36000.00
82E28E	2017-07-29 07:06:00+03	174000.00
82E2A1	2017-07-28 02:03:00+03	14000.00
82E306	2017-08-13 14:54:00+03	40800.00
82E32A	2017-07-31 10:13:00+03	136800.00
82E391	2017-08-04 22:37:00+03	6000.00
82E3AE	2017-07-10 14:56:00+03	22000.00
82E3FC	2017-07-12 17:09:00+03	40800.00
82E40C	2017-07-23 23:28:00+03	312000.00
82E41C	2017-08-10 05:04:00+03	51900.00
82E42E	2017-06-30 12:12:00+03	10600.00
82E504	2017-07-26 18:03:00+03	156500.00
82E517	2017-08-10 13:42:00+03	53600.00
82E5B9	2017-07-31 04:39:00+03	6800.00
82E5DE	2017-07-04 10:04:00+03	28000.00
82E716	2017-08-09 12:52:00+03	29600.00
82E71A	2017-08-02 16:49:00+03	6300.00
82E71B	2017-08-14 13:32:00+03	36200.00
82E7A5	2017-08-08 21:46:00+03	40300.00
82E7E7	2017-07-31 19:26:00+03	56600.00
82E7EF	2017-07-10 13:59:00+03	46300.00
82E80B	2017-07-10 19:42:00+03	31400.00
82E8A8	2017-07-16 13:57:00+03	7200.00
82E925	2017-07-18 02:34:00+03	136600.00
82E937	2017-07-11 00:43:00+03	115900.00
82E9E9	2017-08-08 21:52:00+03	68000.00
82E9FA	2017-07-27 16:43:00+03	20200.00
82EA83	2017-07-01 07:40:00+03	118500.00
82EAAE	2017-07-04 19:52:00+03	393000.00
82EB1A	2017-07-25 03:50:00+03	39700.00
82EB63	2017-08-04 15:38:00+03	8000.00
82EB64	2017-06-30 04:53:00+03	58900.00
82EBD6	2017-07-29 15:25:00+03	96400.00
82ED19	2017-07-09 16:29:00+03	46000.00
82ED38	2017-07-23 20:30:00+03	46400.00
82ED82	2017-08-05 12:57:00+03	105000.00
82EDC8	2017-08-14 15:48:00+03	29400.00
82EE3E	2017-08-10 15:30:00+03	147300.00
82EE41	2017-08-06 19:51:00+03	46000.00
82EE5E	2017-08-02 03:07:00+03	7400.00
82EE9D	2017-08-08 02:09:00+03	23200.00
82EF02	2017-07-05 12:51:00+03	43100.00
82EF3F	2017-07-03 01:43:00+03	182800.00
82EF9C	2017-08-04 18:26:00+03	100600.00
82EFED	2017-06-30 23:19:00+03	21400.00
82F028	2017-07-29 13:12:00+03	27900.00
82F09D	2017-07-08 03:36:00+03	43600.00
82F09E	2017-07-03 20:35:00+03	64600.00
82F153	2017-07-04 15:53:00+03	24400.00
82F189	2017-08-07 12:21:00+03	33100.00
82F21A	2017-08-04 04:21:00+03	266400.00
82F268	2017-07-28 06:53:00+03	111700.00
82F284	2017-07-07 15:33:00+03	11900.00
82F2B6	2017-07-31 09:55:00+03	26700.00
82F2BB	2017-07-05 00:26:00+03	57700.00
82F2CA	2017-07-09 19:20:00+03	104600.00
82F368	2017-07-14 23:45:00+03	54400.00
82F397	2017-07-28 13:08:00+03	86600.00
82F3F3	2017-07-27 08:00:00+03	269200.00
82F429	2017-06-29 18:47:00+03	90000.00
82F44F	2017-08-09 09:15:00+03	88000.00
82F458	2017-07-24 14:37:00+03	32700.00
82F470	2017-07-01 18:48:00+03	398500.00
82F4C8	2017-07-24 19:57:00+03	95300.00
82F6AC	2017-08-03 03:21:00+03	59800.00
82F833	2017-07-30 14:44:00+03	58600.00
82F89B	2017-07-20 08:16:00+03	38400.00
82F93A	2017-07-19 19:52:00+03	12200.00
82F944	2017-07-30 00:29:00+03	92800.00
82F9AA	2017-06-28 21:11:00+03	24800.00
82F9BE	2017-08-05 12:45:00+03	47000.00
82F9EC	2017-07-07 16:52:00+03	51600.00
82FA5F	2017-07-29 19:22:00+03	97900.00
82FA6C	2017-07-15 15:40:00+03	21400.00
82FA8B	2017-08-07 17:06:00+03	59600.00
82FAB9	2017-08-03 11:28:00+03	95200.00
82FB1F	2017-08-12 08:40:00+03	49100.00
82FB20	2017-07-05 21:13:00+03	516800.00
82FB4F	2017-08-05 18:14:00+03	90800.00
82FB57	2017-07-22 12:32:00+03	24400.00
82FB5B	2017-07-15 01:59:00+03	36200.00
82FB9E	2017-07-04 22:07:00+03	26000.00
82FC0E	2017-07-18 07:29:00+03	36000.00
82FC0F	2017-07-12 13:10:00+03	241300.00
82FC22	2017-07-24 10:56:00+03	136200.00
82FC4E	2017-07-13 02:03:00+03	53300.00
82FC59	2017-07-04 18:25:00+03	23900.00
82FC84	2017-08-11 09:17:00+03	42800.00
82FCE5	2017-07-02 12:20:00+03	89600.00
82FCEC	2017-07-15 14:53:00+03	73200.00
82FD26	2017-07-13 10:52:00+03	55000.00
82FD2C	2017-07-04 19:29:00+03	81600.00
82FD3C	2017-07-11 14:46:00+03	192200.00
82FD42	2017-07-01 03:50:00+03	58000.00
82FE2B	2017-07-18 10:35:00+03	123000.00
82FE6F	2017-07-31 13:41:00+03	22000.00
82FEDD	2017-07-05 23:53:00+03	83000.00
82FF01	2017-07-13 11:56:00+03	32200.00
82FF74	2017-07-10 06:51:00+03	36800.00
82FF84	2017-07-29 23:20:00+03	23200.00
82FFA9	2017-08-13 19:32:00+03	57600.00
82FFE4	2017-07-08 20:17:00+03	77000.00
82FFF0	2017-08-10 06:36:00+03	56000.00
830090	2017-07-19 18:57:00+03	99200.00
830093	2017-07-03 04:59:00+03	12600.00
8300F6	2017-07-21 11:15:00+03	22100.00
830156	2017-08-11 10:34:00+03	71900.00
830169	2017-07-26 11:09:00+03	40000.00
830199	2017-08-14 21:17:00+03	6700.00
8301BC	2017-07-27 15:18:00+03	46400.00
8301DE	2017-07-15 21:19:00+03	68800.00
8301E7	2017-08-13 10:15:00+03	135600.00
8301ED	2017-07-27 00:26:00+03	88100.00
830285	2017-07-01 04:07:00+03	85000.00
8302BD	2017-08-03 02:32:00+03	53200.00
8302E3	2017-07-02 18:25:00+03	46800.00
8302F2	2017-07-30 01:44:00+03	38800.00
830307	2017-07-27 21:14:00+03	49200.00
83034D	2017-08-03 07:27:00+03	46200.00
830368	2017-07-17 17:20:00+03	112600.00
8303D7	2017-07-17 08:26:00+03	136800.00
8303DA	2017-07-26 01:11:00+03	61800.00
8303E6	2017-08-04 07:38:00+03	88200.00
83045B	2017-07-21 10:37:00+03	86600.00
8304B0	2017-07-13 14:06:00+03	92800.00
8304E4	2017-06-30 05:05:00+03	45400.00
830516	2017-08-05 14:16:00+03	98500.00
83052C	2017-08-15 17:45:00+03	6800.00
830556	2017-08-01 13:58:00+03	41200.00
830599	2017-07-04 00:30:00+03	13400.00
8305EC	2017-08-06 14:35:00+03	124200.00
830651	2017-08-05 05:41:00+03	90800.00
830653	2017-07-09 20:04:00+03	141000.00
830672	2017-08-06 00:53:00+03	169000.00
8306E6	2017-07-06 07:50:00+03	202600.00
830710	2017-07-04 06:07:00+03	70100.00
830722	2017-08-14 00:09:00+03	21800.00
83073A	2017-07-11 14:40:00+03	14800.00
83074F	2017-07-18 10:21:00+03	26000.00
830760	2017-07-03 15:43:00+03	56000.00
8307B3	2017-08-10 21:49:00+03	49600.00
830970	2017-07-03 13:02:00+03	111600.00
8309AF	2017-07-25 10:29:00+03	56000.00
8309C3	2017-08-01 20:14:00+03	174500.00
8309D5	2017-07-14 01:42:00+03	190400.00
830A93	2017-07-21 16:58:00+03	18600.00
830AAF	2017-08-15 04:35:00+03	24000.00
830AD7	2017-08-04 21:49:00+03	136800.00
830AEA	2017-07-01 10:29:00+03	68100.00
830AF4	2017-07-12 09:54:00+03	89000.00
830B1B	2017-07-29 01:11:00+03	68100.00
830B1C	2017-08-01 17:15:00+03	23600.00
830B26	2017-07-24 01:55:00+03	38800.00
830B6E	2017-07-31 09:50:00+03	79800.00
830BA4	2017-08-11 21:13:00+03	11600.00
830BB6	2017-07-30 12:26:00+03	38800.00
830C1E	2017-08-11 22:26:00+03	129700.00
830C25	2017-07-11 14:28:00+03	25600.00
830C3D	2017-08-08 20:40:00+03	47000.00
830C59	2017-08-15 06:02:00+03	229600.00
830CD6	2017-07-24 09:03:00+03	23400.00
830D64	2017-07-23 17:33:00+03	46700.00
830DB6	2017-08-12 22:03:00+03	50600.00
830E0A	2017-06-30 13:02:00+03	14400.00
830E38	2017-07-23 20:32:00+03	184300.00
830E45	2017-07-15 20:21:00+03	26700.00
830E66	2017-07-14 05:20:00+03	89700.00
830E68	2017-07-15 08:43:00+03	36400.00
830E85	2017-07-13 06:21:00+03	61800.00
830EB7	2017-07-25 00:04:00+03	14400.00
830EBA	2017-08-09 12:59:00+03	89700.00
830EE7	2017-07-21 02:08:00+03	12600.00
830EFE	2017-07-02 05:29:00+03	31600.00
830F06	2017-07-09 07:43:00+03	13400.00
830F24	2017-07-09 05:36:00+03	170200.00
830F4D	2017-08-05 04:36:00+03	22000.00
830F82	2017-07-18 09:25:00+03	95600.00
830FF6	2017-08-07 16:16:00+03	66000.00
83103B	2017-08-15 06:37:00+03	55800.00
8310DA	2017-07-20 06:56:00+03	16400.00
8310FC	2017-07-22 13:46:00+03	12600.00
831145	2017-07-15 21:34:00+03	182900.00
831147	2017-08-13 12:49:00+03	38800.00
83118B	2017-07-22 15:20:00+03	31900.00
8311A2	2017-08-13 06:06:00+03	97900.00
8311A8	2017-07-19 11:51:00+03	110300.00
8311BB	2017-07-02 22:46:00+03	127400.00
83121D	2017-07-06 15:57:00+03	86500.00
8312CD	2017-07-10 21:40:00+03	257500.00
831325	2017-08-15 00:47:00+03	123700.00
831326	2017-07-16 11:33:00+03	22000.00
831343	2017-07-27 17:30:00+03	45200.00
831354	2017-07-18 05:55:00+03	95700.00
83139B	2017-07-18 03:07:00+03	13600.00
8313AE	2017-08-02 13:30:00+03	46300.00
8313DD	2017-07-28 12:57:00+03	44600.00
83142F	2017-07-30 18:16:00+03	10700.00
831437	2017-07-30 21:47:00+03	79600.00
83145B	2017-07-19 09:40:00+03	86800.00
83146F	2017-08-13 16:20:00+03	57600.00
831488	2017-08-01 07:17:00+03	122500.00
831492	2017-07-23 09:33:00+03	53600.00
83157B	2017-07-21 10:45:00+03	117500.00
831581	2017-07-27 06:20:00+03	135600.00
8315D6	2017-08-02 14:09:00+03	178800.00
8316BD	2017-07-18 06:52:00+03	54100.00
8316F8	2017-08-12 10:51:00+03	38300.00
831725	2017-08-10 10:49:00+03	67000.00
831735	2017-07-12 04:23:00+03	40200.00
831759	2017-07-28 01:57:00+03	126800.00
83177D	2017-08-11 14:24:00+03	145100.00
83179F	2017-08-15 08:48:00+03	28700.00
8317A4	2017-08-10 21:04:00+03	28800.00
831817	2017-07-29 19:13:00+03	6000.00
831856	2017-08-04 10:29:00+03	43500.00
83185A	2017-07-17 21:27:00+03	81200.00
831878	2017-07-04 23:41:00+03	78800.00
8318C5	2017-07-07 21:51:00+03	100000.00
831946	2017-07-27 23:17:00+03	43200.00
83194A	2017-07-23 20:09:00+03	58800.00
8319E1	2017-08-12 07:43:00+03	260300.00
8319F3	2017-08-14 01:27:00+03	64400.00
831A57	2017-08-07 15:35:00+03	103500.00
831A79	2017-07-23 05:57:00+03	24700.00
831A7B	2017-08-09 03:18:00+03	189800.00
831B5D	2017-08-07 19:17:00+03	36900.00
831C26	2017-07-25 20:09:00+03	51300.00
831C9A	2017-08-15 10:25:00+03	270700.00
831D35	2017-07-07 20:15:00+03	28000.00
831D47	2017-07-22 05:01:00+03	14000.00
831D50	2017-07-31 04:46:00+03	32700.00
831D6C	2017-08-15 01:44:00+03	134400.00
831DBC	2017-07-19 14:57:00+03	139500.00
831E64	2017-07-03 09:19:00+03	194800.00
831F11	2017-08-04 04:48:00+03	86400.00
831F16	2017-07-14 09:41:00+03	6600.00
831FDF	2017-08-12 23:43:00+03	92400.00
831FF6	2017-07-14 04:10:00+03	99700.00
83208F	2017-07-08 04:37:00+03	21600.00
8320AB	2017-08-15 07:58:00+03	23400.00
832110	2017-08-11 20:37:00+03	46000.00
8321BA	2017-08-08 17:00:00+03	69000.00
8321E3	2017-07-14 20:39:00+03	12400.00
83221B	2017-07-04 06:54:00+03	135600.00
83221C	2017-06-30 23:33:00+03	31200.00
83223F	2017-08-11 19:15:00+03	15700.00
8322C3	2017-07-19 18:38:00+03	31000.00
8322CC	2017-07-09 21:21:00+03	46200.00
832407	2017-08-07 00:55:00+03	6300.00
83244C	2017-08-10 18:33:00+03	28800.00
83245A	2017-07-22 08:47:00+03	15400.00
83249D	2017-08-09 02:58:00+03	64700.00
8324B9	2017-07-22 23:45:00+03	14000.00
8324C5	2017-08-02 15:30:00+03	78300.00
832514	2017-07-14 06:46:00+03	25000.00
83254F	2017-07-26 04:40:00+03	45300.00
832581	2017-07-17 22:16:00+03	73100.00
8325E7	2017-07-17 04:19:00+03	19500.00
8325FB	2017-08-12 13:32:00+03	55800.00
832607	2017-07-16 12:10:00+03	70700.00
832644	2017-07-05 07:26:00+03	27800.00
83268C	2017-08-12 09:40:00+03	87800.00
8326CF	2017-08-13 00:50:00+03	124200.00
8326EF	2017-07-28 11:22:00+03	101200.00
832714	2017-07-11 13:46:00+03	46400.00
832716	2017-07-06 14:00:00+03	81900.00
83272F	2017-08-15 04:39:00+03	36600.00
832736	2017-08-06 15:54:00+03	58900.00
832756	2017-08-01 13:03:00+03	81700.00
83276C	2017-07-14 13:57:00+03	28800.00
83277A	2017-07-15 19:18:00+03	106400.00
83277B	2017-07-08 14:39:00+03	182300.00
8327F3	2017-07-12 07:10:00+03	528600.00
8327FC	2017-07-01 05:45:00+03	73900.00
832807	2017-07-12 18:12:00+03	43600.00
832862	2017-07-24 06:47:00+03	131100.00
832963	2017-08-11 02:00:00+03	61800.00
83297C	2017-07-29 01:41:00+03	82900.00
832992	2017-08-11 04:35:00+03	23400.00
832A55	2017-07-11 06:14:00+03	384600.00
832AA6	2017-08-11 22:42:00+03	103500.00
832AAD	2017-07-14 15:32:00+03	86800.00
832B03	2017-07-08 10:35:00+03	23200.00
832B48	2017-07-30 01:15:00+03	132800.00
832B5E	2017-07-12 20:26:00+03	67200.00
832B7E	2017-07-09 00:39:00+03	53400.00
832B86	2017-08-03 00:34:00+03	70800.00
832B87	2017-07-09 00:02:00+03	258400.00
832BA9	2017-08-06 16:26:00+03	38800.00
832CD6	2017-08-03 22:20:00+03	80800.00
832CDC	2017-07-27 17:12:00+03	62000.00
832D02	2017-06-29 22:08:00+03	112600.00
832D0B	2017-08-02 04:57:00+03	116800.00
832D4C	2017-08-09 15:03:00+03	50000.00
832D6C	2017-08-15 07:54:00+03	43600.00
832D95	2017-08-09 04:41:00+03	122300.00
832DF3	2017-07-02 15:01:00+03	101200.00
832E32	2017-07-26 07:52:00+03	6000.00
832E3A	2017-07-29 09:34:00+03	68200.00
832E4E	2017-08-11 21:54:00+03	44800.00
832E8A	2017-08-01 19:57:00+03	37900.00
832EF8	2017-07-19 09:12:00+03	13600.00
832F0A	2017-06-28 16:23:00+03	39900.00
832F32	2017-06-29 17:28:00+03	96800.00
832F6D	2017-08-12 03:33:00+03	14000.00
832F72	2017-07-10 04:20:00+03	31600.00
832F80	2017-07-06 08:25:00+03	20800.00
832F9A	2017-08-12 09:47:00+03	96800.00
833059	2017-08-10 15:03:00+03	57500.00
83305E	2017-07-18 18:02:00+03	146300.00
83306A	2017-07-19 03:14:00+03	54800.00
8330E1	2017-07-18 21:51:00+03	23200.00
833148	2017-07-17 19:27:00+03	46400.00
833184	2017-08-15 15:27:00+03	54100.00
8331C8	2017-07-19 06:36:00+03	108600.00
8331D6	2017-08-14 23:11:00+03	196800.00
833222	2017-07-04 10:27:00+03	137800.00
833280	2017-08-13 14:54:00+03	10800.00
83329C	2017-08-09 14:15:00+03	105600.00
833327	2017-08-11 11:47:00+03	169600.00
83339E	2017-07-30 12:57:00+03	48800.00
833419	2017-07-29 07:37:00+03	206400.00
83344F	2017-07-07 02:16:00+03	28000.00
833557	2017-08-01 07:31:00+03	42800.00
833563	2017-08-04 23:13:00+03	28000.00
83357C	2017-07-31 13:15:00+03	78300.00
8335A0	2017-06-30 15:59:00+03	35300.00
8335A2	2017-07-27 22:26:00+03	68000.00
8335A3	2017-08-13 12:28:00+03	55600.00
8335C8	2017-07-04 10:08:00+03	16400.00
8335EB	2017-07-08 12:05:00+03	93000.00
8335EC	2017-07-10 07:51:00+03	48400.00
833620	2017-08-03 21:46:00+03	52400.00
8336C8	2017-08-08 12:38:00+03	75300.00
8336E1	2017-08-12 17:56:00+03	36200.00
8336F1	2017-07-02 18:42:00+03	139700.00
833795	2017-07-21 23:59:00+03	119600.00
833819	2017-08-12 18:59:00+03	19800.00
83386B	2017-08-03 08:03:00+03	21800.00
833872	2017-07-01 15:18:00+03	131600.00
8338B8	2017-07-07 07:23:00+03	54000.00
8338E0	2017-07-17 10:39:00+03	67200.00
8339C2	2017-08-05 19:32:00+03	28000.00
8339F6	2017-07-10 23:38:00+03	44600.00
833A06	2017-07-31 22:47:00+03	6700.00
833A1A	2017-07-28 09:48:00+03	68800.00
833A46	2017-07-16 21:57:00+03	406800.00
833A7E	2017-08-09 23:29:00+03	6700.00
833AE7	2017-07-16 19:18:00+03	49200.00
833C12	2017-07-05 17:26:00+03	281500.00
833C14	2017-07-19 09:18:00+03	64100.00
833C22	2017-08-03 08:48:00+03	50600.00
833C7C	2017-07-30 05:43:00+03	28000.00
833CCA	2017-08-11 03:01:00+03	14000.00
833CD3	2017-07-16 21:57:00+03	57500.00
833DE6	2017-08-15 01:17:00+03	80100.00
833DFE	2017-08-14 21:42:00+03	246000.00
833E18	2017-07-01 14:40:00+03	226000.00
833E1A	2017-08-12 00:52:00+03	104000.00
833E6B	2017-07-20 13:11:00+03	28000.00
833E6C	2017-07-05 03:07:00+03	101100.00
833E8A	2017-08-03 07:10:00+03	137700.00
833EB3	2017-07-25 16:01:00+03	40800.00
833ECF	2017-07-17 11:43:00+03	105100.00
833EF7	2017-07-19 08:08:00+03	55800.00
833FA4	2017-08-13 00:35:00+03	116900.00
834144	2017-08-05 01:27:00+03	133200.00
834152	2017-07-18 05:13:00+03	39300.00
834181	2017-08-02 11:41:00+03	397100.00
83418A	2017-08-07 06:59:00+03	21000.00
83419C	2017-07-11 18:52:00+03	66600.00
8341DF	2017-08-14 13:01:00+03	42000.00
834223	2017-08-14 04:28:00+03	10800.00
834237	2017-07-24 13:30:00+03	25600.00
834266	2017-08-02 00:51:00+03	167500.00
8342C5	2017-07-18 02:17:00+03	100600.00
8342D0	2017-07-15 20:47:00+03	86600.00
8342D3	2017-08-14 22:33:00+03	128400.00
8342F7	2017-07-19 16:59:00+03	55000.00
83434E	2017-08-14 15:49:00+03	14400.00
83436A	2017-08-11 00:19:00+03	67900.00
83441C	2017-08-10 16:59:00+03	57600.00
83448A	2017-08-05 06:55:00+03	37900.00
8344F0	2017-07-01 13:51:00+03	61800.00
8344F7	2017-07-05 23:29:00+03	48800.00
8344FB	2017-07-19 13:36:00+03	29200.00
834544	2017-07-30 17:56:00+03	103800.00
83455D	2017-07-11 10:10:00+03	32800.00
83460E	2017-07-10 01:17:00+03	63300.00
834613	2017-07-22 11:31:00+03	125700.00
834622	2017-08-07 04:08:00+03	6700.00
83466B	2017-07-20 23:59:00+03	14000.00
83467B	2017-07-15 22:24:00+03	16400.00
8346CF	2017-07-25 03:45:00+03	10800.00
8346D2	2017-08-05 00:48:00+03	186900.00
8346E0	2017-08-02 12:20:00+03	28000.00
834722	2017-08-07 00:54:00+03	112000.00
834818	2017-07-20 12:17:00+03	38600.00
83489E	2017-07-30 05:22:00+03	80700.00
8348B8	2017-07-20 18:58:00+03	117800.00
834952	2017-07-06 23:40:00+03	66000.00
8349B8	2017-07-12 21:57:00+03	36000.00
834A59	2017-07-08 10:20:00+03	112600.00
834A81	2017-07-29 07:08:00+03	46000.00
834ACD	2017-07-26 12:30:00+03	134700.00
834B22	2017-07-09 00:26:00+03	31000.00
834B33	2017-07-27 02:58:00+03	21400.00
834B44	2017-08-08 02:17:00+03	57500.00
834BF0	2017-07-27 18:44:00+03	24600.00
834BF4	2017-07-24 13:16:00+03	26800.00
834BFC	2017-07-28 20:41:00+03	92900.00
834C11	2017-07-23 06:45:00+03	58600.00
834C12	2017-07-28 17:18:00+03	26700.00
834C19	2017-07-04 22:42:00+03	56000.00
834D52	2017-07-20 09:22:00+03	135400.00
834D54	2017-07-01 17:18:00+03	117200.00
834D6F	2017-07-03 13:29:00+03	316000.00
834DA9	2017-07-18 00:23:00+03	74300.00
834DD7	2017-07-23 11:57:00+03	29600.00
834E26	2017-07-25 23:37:00+03	272400.00
834E98	2017-08-14 12:04:00+03	69300.00
834E9B	2017-08-14 22:13:00+03	71700.00
834EC0	2017-07-14 01:39:00+03	53700.00
834EFA	2017-07-28 04:53:00+03	19800.00
834F00	2017-08-09 21:31:00+03	54000.00
834F3E	2017-07-07 02:56:00+03	67600.00
834F71	2017-07-21 05:49:00+03	124200.00
834F82	2017-07-05 12:24:00+03	65900.00
834FA9	2017-07-11 23:38:00+03	28000.00
834FD7	2017-08-15 00:11:00+03	72200.00
835102	2017-06-26 14:22:00+03	243600.00
835103	2017-07-28 19:52:00+03	30200.00
835161	2017-07-14 10:50:00+03	115600.00
83518D	2017-08-06 10:16:00+03	51900.00
8351A3	2017-07-16 13:35:00+03	118500.00
8351EF	2017-08-09 00:33:00+03	101200.00
8351F5	2017-07-31 21:30:00+03	6700.00
83520E	2017-08-06 18:49:00+03	14400.00
835213	2017-07-25 22:26:00+03	24400.00
83527D	2017-08-13 20:23:00+03	18700.00
835282	2017-07-05 16:55:00+03	28800.00
835331	2017-07-07 18:55:00+03	22000.00
8353A6	2017-08-02 18:21:00+03	56000.00
8353CB	2017-07-08 07:15:00+03	173900.00
8353D9	2017-08-04 03:43:00+03	44800.00
835440	2017-07-21 07:38:00+03	108600.00
83547E	2017-07-07 03:15:00+03	38800.00
83548F	2017-07-20 10:42:00+03	78000.00
8354C2	2017-08-10 20:16:00+03	6000.00
835510	2017-07-26 03:36:00+03	155600.00
835523	2017-07-28 07:06:00+03	12200.00
835531	2017-06-28 08:11:00+03	29300.00
835548	2017-08-06 14:23:00+03	51900.00
8355F3	2017-07-29 02:38:00+03	50600.00
835667	2017-07-20 22:33:00+03	68800.00
835675	2017-07-20 00:56:00+03	47100.00
8356BC	2017-08-05 04:02:00+03	67600.00
83573D	2017-07-15 10:48:00+03	25100.00
8357BB	2017-07-08 09:35:00+03	67600.00
83584C	2017-08-07 15:01:00+03	94300.00
835861	2017-07-09 19:34:00+03	169600.00
8358FF	2017-07-15 19:49:00+03	125200.00
835945	2017-07-15 02:09:00+03	142400.00
835973	2017-07-28 18:56:00+03	236900.00
8359AE	2017-08-03 15:50:00+03	26800.00
8359EB	2017-07-25 11:56:00+03	798800.00
835B3F	2017-07-07 06:26:00+03	26700.00
835B89	2017-06-30 03:56:00+03	67300.00
835B9B	2017-07-09 16:09:00+03	60800.00
835BBD	2017-08-09 02:52:00+03	57500.00
835BF9	2017-07-11 16:32:00+03	193600.00
835BFA	2017-08-13 16:20:00+03	85600.00
835C06	2017-08-15 10:17:00+03	18600.00
835C1C	2017-08-07 04:16:00+03	48800.00
835C2F	2017-08-03 09:55:00+03	87400.00
835C35	2017-08-08 14:02:00+03	246000.00
835C51	2017-07-17 02:25:00+03	112000.00
835C53	2017-07-08 22:30:00+03	46400.00
835D1C	2017-07-08 12:24:00+03	24200.00
835D56	2017-07-15 02:27:00+03	77000.00
835D5A	2017-08-08 15:21:00+03	99200.00
835D79	2017-08-09 03:04:00+03	15900.00
835D7B	2017-08-02 16:23:00+03	14400.00
835D9D	2017-07-28 09:16:00+03	9800.00
835E6F	2017-06-28 12:27:00+03	8000.00
835F34	2017-07-19 10:20:00+03	72200.00
835F36	2017-07-09 17:11:00+03	70600.00
835F7F	2017-07-13 01:07:00+03	139400.00
835F8D	2017-07-03 08:41:00+03	53600.00
835FAB	2017-07-20 18:52:00+03	69500.00
83607A	2017-07-13 22:50:00+03	121200.00
8360A5	2017-07-07 10:15:00+03	23200.00
8360DB	2017-08-11 23:05:00+03	200400.00
8360ED	2017-07-20 22:23:00+03	294400.00
836167	2017-07-28 10:44:00+03	142400.00
836191	2017-07-11 18:00:00+03	44000.00
836261	2017-07-05 18:49:00+03	155600.00
836286	2017-07-14 01:56:00+03	81600.00
8362BE	2017-08-05 10:31:00+03	26700.00
8362DA	2017-08-15 07:58:00+03	13400.00
83630A	2017-07-30 01:25:00+03	13000.00
836336	2017-08-03 17:31:00+03	55800.00
83634F	2017-07-08 14:12:00+03	81300.00
836360	2017-07-31 04:31:00+03	12600.00
8363A8	2017-07-25 18:22:00+03	125700.00
8363BC	2017-07-17 22:29:00+03	130000.00
8363C1	2017-08-06 03:02:00+03	266400.00
8363E5	2017-07-01 05:39:00+03	178800.00
8363EE	2017-07-12 08:00:00+03	78300.00
836476	2017-07-27 01:51:00+03	43600.00
8364AD	2017-08-02 10:53:00+03	49700.00
8364B5	2017-07-06 11:08:00+03	106400.00
8364C6	2017-07-31 12:28:00+03	33000.00
836504	2017-07-03 03:44:00+03	27800.00
83651C	2017-08-13 21:40:00+03	29600.00
836531	2017-08-08 20:54:00+03	270800.00
83654D	2017-07-12 08:16:00+03	59000.00
83656C	2017-08-11 18:28:00+03	21800.00
836613	2017-07-06 00:57:00+03	186900.00
83667E	2017-08-11 21:17:00+03	32700.00
8366D0	2017-08-10 00:54:00+03	68600.00
8366DB	2017-08-12 23:09:00+03	14000.00
83670A	2017-07-03 01:58:00+03	43500.00
836719	2017-07-17 11:26:00+03	172700.00
83675F	2017-08-15 09:49:00+03	9800.00
836784	2017-08-04 13:54:00+03	55800.00
836805	2017-07-20 18:52:00+03	139300.00
836830	2017-07-17 06:42:00+03	79900.00
836857	2017-08-13 18:27:00+03	56000.00
83688B	2017-08-06 12:18:00+03	174000.00
8368C7	2017-08-02 18:53:00+03	35200.00
8368CC	2017-07-04 19:07:00+03	20400.00
836920	2017-07-09 08:34:00+03	148800.00
836928	2017-07-25 14:58:00+03	52300.00
83694A	2017-07-04 18:57:00+03	103400.00
83694E	2017-08-15 15:52:00+03	143100.00
83696D	2017-07-27 03:50:00+03	32800.00
836985	2017-06-27 09:38:00+03	67300.00
8369A3	2017-08-01 16:51:00+03	56000.00
8369EE	2017-08-02 18:41:00+03	139200.00
836A00	2017-08-01 00:25:00+03	72800.00
836A44	2017-07-05 01:21:00+03	401000.00
836A4E	2017-08-12 14:53:00+03	137700.00
836A53	2017-07-24 15:04:00+03	269500.00
836A5C	2017-08-01 04:21:00+03	23400.00
836A88	2017-07-23 15:38:00+03	24400.00
836AB9	2017-07-19 14:59:00+03	8200.00
836AE4	2017-07-12 18:55:00+03	68400.00
836B0B	2017-07-20 01:39:00+03	20200.00
836B0E	2017-07-26 20:16:00+03	31600.00
836B2F	2017-07-29 10:05:00+03	85000.00
836B9A	2017-07-16 19:27:00+03	28000.00
836C96	2017-07-30 01:13:00+03	35800.00
836CEC	2017-07-06 08:40:00+03	13400.00
836CED	2017-07-13 07:56:00+03	80000.00
836D1E	2017-08-06 12:05:00+03	56000.00
836D34	2017-08-02 00:14:00+03	329000.00
836E0C	2017-07-19 07:00:00+03	111600.00
836E15	2017-07-15 16:54:00+03	51300.00
836E32	2017-07-14 06:41:00+03	177200.00
836E33	2017-07-16 00:45:00+03	47400.00
836E92	2017-07-01 17:08:00+03	202600.00
836EA3	2017-07-05 12:26:00+03	164400.00
836EB5	2017-07-03 15:29:00+03	39300.00
836EB8	2017-08-11 03:10:00+03	19600.00
836EBD	2017-07-13 01:42:00+03	47100.00
836F96	2017-07-23 03:06:00+03	43100.00
836FBC	2017-08-03 18:08:00+03	123600.00
836FC8	2017-07-23 03:45:00+03	76800.00
83704C	2017-07-24 17:46:00+03	123000.00
837089	2017-07-06 13:24:00+03	26000.00
837125	2017-07-14 12:20:00+03	47500.00
83712D	2017-07-24 10:41:00+03	246000.00
8371C7	2017-08-09 07:47:00+03	27200.00
837206	2017-07-20 05:12:00+03	20200.00
837226	2017-07-29 18:57:00+03	209900.00
8372CE	2017-07-04 13:06:00+03	541500.00
837336	2017-07-20 16:54:00+03	26000.00
83733B	2017-07-09 06:42:00+03	29200.00
837356	2017-07-11 03:09:00+03	56000.00
83735A	2017-08-05 06:14:00+03	100600.00
8373A7	2017-07-15 18:12:00+03	199700.00
837468	2017-07-03 17:58:00+03	42400.00
83746E	2017-08-07 19:47:00+03	81700.00
837474	2017-07-27 13:17:00+03	87800.00
83747F	2017-07-22 13:52:00+03	25400.00
8374CC	2017-07-09 01:59:00+03	45200.00
8374DF	2017-07-30 04:11:00+03	136800.00
837561	2017-07-23 23:59:00+03	39200.00
837571	2017-08-11 13:20:00+03	133600.00
8375B5	2017-07-12 00:55:00+03	133100.00
8375BF	2017-08-07 14:10:00+03	23200.00
837636	2017-07-12 00:25:00+03	34000.00
837694	2017-07-20 11:16:00+03	81600.00
8376C0	2017-08-15 09:32:00+03	10700.00
8376C1	2017-08-12 13:26:00+03	147900.00
8376C6	2017-08-07 02:24:00+03	43000.00
837703	2017-07-18 04:37:00+03	44500.00
83771C	2017-07-23 00:40:00+03	75600.00
83776F	2017-07-29 03:51:00+03	529800.00
837782	2017-07-25 17:51:00+03	6700.00
8377CA	2017-07-17 16:09:00+03	66000.00
8377FB	2017-07-26 00:26:00+03	19600.00
837837	2017-08-08 01:43:00+03	26000.00
837838	2017-07-27 21:32:00+03	269600.00
83784D	2017-07-04 23:48:00+03	131100.00
8378C0	2017-07-17 04:45:00+03	72300.00
8378D3	2017-08-08 12:13:00+03	48800.00
837956	2017-07-22 05:38:00+03	6700.00
83796E	2017-07-05 23:28:00+03	25400.00
837A21	2017-08-10 18:08:00+03	28800.00
837B19	2017-07-27 00:09:00+03	76600.00
837B34	2017-08-05 12:17:00+03	26400.00
837C27	2017-07-19 05:57:00+03	46400.00
837C3B	2017-07-17 08:45:00+03	53100.00
837C5D	2017-08-10 20:25:00+03	29600.00
837D36	2017-08-09 10:22:00+03	117600.00
837D7B	2017-07-12 22:03:00+03	40800.00
837D86	2017-07-11 01:58:00+03	66600.00
837E00	2017-07-31 10:36:00+03	61500.00
837F13	2017-08-07 20:38:00+03	13400.00
837F68	2017-07-30 18:48:00+03	45600.00
837FAC	2017-08-07 19:33:00+03	516000.00
837FC5	2017-07-30 07:53:00+03	57700.00
837FD7	2017-07-08 03:01:00+03	7400.00
83805C	2017-07-19 04:10:00+03	48800.00
838067	2017-07-16 12:10:00+03	94700.00
8380FE	2017-08-06 06:28:00+03	69700.00
83816C	2017-07-05 02:04:00+03	50800.00
83817D	2017-08-05 10:41:00+03	87000.00
838195	2017-07-07 14:47:00+03	135600.00
8381A3	2017-08-05 01:57:00+03	111300.00
8381A4	2017-07-16 15:27:00+03	40700.00
8381F6	2017-08-03 07:52:00+03	21500.00
83821B	2017-07-15 21:00:00+03	45100.00
838230	2017-08-02 20:19:00+03	378400.00
8382CE	2017-07-27 05:35:00+03	112000.00
8383B9	2017-07-19 18:37:00+03	136000.00
838443	2017-08-01 16:46:00+03	58900.00
838446	2017-07-27 17:17:00+03	26900.00
83849F	2017-07-17 16:52:00+03	25600.00
8384F0	2017-07-11 13:18:00+03	120100.00
83850F	2017-08-01 21:42:00+03	18000.00
83855D	2017-07-22 22:19:00+03	240600.00
838581	2017-07-21 07:53:00+03	8000.00
8385B9	2017-08-11 12:56:00+03	301600.00
8385D4	2017-07-08 13:18:00+03	24600.00
8385DD	2017-07-26 00:44:00+03	14000.00
838610	2017-08-10 14:47:00+03	52900.00
83861A	2017-08-12 11:34:00+03	103500.00
8386CE	2017-07-21 06:17:00+03	46400.00
83872C	2017-07-27 06:00:00+03	28800.00
838780	2017-07-30 07:19:00+03	26000.00
8387BB	2017-07-05 03:02:00+03	26000.00
838822	2017-07-30 10:40:00+03	31600.00
83883B	2017-08-05 05:57:00+03	59200.00
8388FF	2017-07-04 19:05:00+03	106000.00
838955	2017-08-08 15:26:00+03	64500.00
83899F	2017-08-09 06:05:00+03	16000.00
8389A9	2017-07-24 18:38:00+03	28000.00
8389C4	2017-08-07 15:19:00+03	55800.00
8389DD	2017-08-04 12:35:00+03	75600.00
838A28	2017-07-05 01:08:00+03	14400.00
838A3C	2017-08-09 18:17:00+03	136200.00
838A3D	2017-08-04 12:48:00+03	58200.00
838A69	2017-07-07 08:27:00+03	144000.00
838BD4	2017-07-22 01:49:00+03	36200.00
838C2E	2017-08-14 21:13:00+03	61300.00
838C4C	2017-07-28 18:08:00+03	140800.00
838C63	2017-07-19 01:42:00+03	136200.00
838C7D	2017-06-30 16:49:00+03	177600.00
838C95	2017-07-11 01:29:00+03	52000.00
838D30	2017-07-08 16:28:00+03	26000.00
838D43	2017-07-16 07:32:00+03	228900.00
838DA0	2017-07-03 06:02:00+03	69400.00
838DB4	2017-07-07 03:25:00+03	92000.00
838DC5	2017-08-05 21:26:00+03	54800.00
838E1B	2017-07-22 05:12:00+03	103800.00
838E4B	2017-07-30 21:46:00+03	100600.00
838E57	2017-08-06 17:07:00+03	281500.00
838E68	2017-07-07 12:30:00+03	168000.00
838EA5	2017-07-28 21:08:00+03	91500.00
838F3F	2017-07-31 20:32:00+03	147800.00
838FB1	2017-07-28 11:48:00+03	254600.00
838FC9	2017-08-05 03:30:00+03	27900.00
838FDF	2017-08-02 13:29:00+03	189200.00
838FF4	2017-07-25 00:05:00+03	64800.00
838FFC	2017-08-12 18:52:00+03	21500.00
83903A	2017-08-09 23:25:00+03	57600.00
839079	2017-08-04 17:35:00+03	55800.00
83908C	2017-08-01 18:59:00+03	28000.00
839092	2017-08-11 03:53:00+03	54500.00
8390A3	2017-08-13 11:41:00+03	6700.00
8390C3	2017-07-19 20:56:00+03	84300.00
83910A	2017-08-15 08:14:00+03	93000.00
83917D	2017-07-23 00:26:00+03	56000.00
8391B9	2017-07-22 08:04:00+03	120300.00
8391EE	2017-07-16 12:07:00+03	29600.00
839204	2017-07-18 19:25:00+03	56200.00
8392ED	2017-08-09 23:21:00+03	194200.00
839339	2017-08-01 19:10:00+03	56000.00
8393BF	2017-07-19 17:15:00+03	386300.00
83946E	2017-07-14 07:47:00+03	55800.00
839483	2017-07-25 04:37:00+03	134400.00
839496	2017-07-07 08:48:00+03	92400.00
8394AD	2017-07-04 17:20:00+03	246000.00
8394B8	2017-07-29 09:23:00+03	101500.00
8394BA	2017-08-03 19:43:00+03	69100.00
8394DB	2017-07-29 16:22:00+03	136600.00
8394EB	2017-07-01 22:54:00+03	67600.00
839573	2017-07-25 10:55:00+03	103800.00
839658	2017-08-07 07:56:00+03	157100.00
8396B2	2017-08-10 10:55:00+03	102100.00
8396C3	2017-08-13 08:56:00+03	92900.00
83973C	2017-07-03 22:50:00+03	9300.00
83973E	2017-08-07 04:39:00+03	46200.00
839766	2017-08-03 19:45:00+03	181600.00
8397C9	2017-08-13 10:38:00+03	139500.00
8397F3	2017-07-12 18:53:00+03	35600.00
839845	2017-07-15 09:44:00+03	62600.00
839877	2017-08-13 15:26:00+03	48200.00
8398B9	2017-08-12 21:01:00+03	59800.00
839944	2017-08-13 00:43:00+03	72200.00
839951	2017-08-14 07:30:00+03	158400.00
839987	2017-07-04 04:08:00+03	19600.00
839988	2017-07-30 07:22:00+03	24400.00
83998B	2017-07-04 06:58:00+03	46200.00
839A54	2017-07-05 21:37:00+03	87900.00
839A73	2017-08-05 18:46:00+03	59300.00
839B85	2017-08-12 01:15:00+03	28000.00
839BF6	2017-07-23 23:39:00+03	83600.00
839C30	2017-07-22 11:44:00+03	46000.00
839C4B	2017-08-04 03:45:00+03	39500.00
839C9C	2017-06-30 08:35:00+03	159800.00
839CC3	2017-07-22 18:37:00+03	57600.00
839D5F	2017-07-08 19:56:00+03	26200.00
839DA9	2017-07-19 22:24:00+03	29600.00
839E1C	2017-07-01 13:44:00+03	37100.00
839E4F	2017-07-03 19:54:00+03	13600.00
839EAB	2017-07-21 02:36:00+03	26400.00
839EBF	2017-07-15 03:07:00+03	147900.00
839ED5	2017-07-12 07:48:00+03	92800.00
839EDF	2017-07-18 00:15:00+03	44000.00
839EFE	2017-07-24 08:41:00+03	75300.00
839F9A	2017-08-13 04:00:00+03	78100.00
83A000	2017-08-06 18:09:00+03	266200.00
83A003	2017-08-15 15:39:00+03	8000.00
83A042	2017-07-28 16:02:00+03	89700.00
83A06A	2017-08-08 15:59:00+03	37200.00
83A07B	2017-07-11 23:11:00+03	13400.00
83A09B	2017-07-08 21:39:00+03	146300.00
83A0B8	2017-06-30 21:42:00+03	57400.00
83A167	2017-07-22 09:52:00+03	39500.00
83A178	2017-07-20 23:37:00+03	57400.00
83A187	2017-07-17 18:54:00+03	34000.00
83A1E8	2017-07-16 05:21:00+03	167500.00
83A256	2017-07-10 14:17:00+03	98300.00
83A2D0	2017-08-10 14:44:00+03	25600.00
83A399	2017-08-10 23:26:00+03	62000.00
83A3AE	2017-08-15 16:49:00+03	199200.00
83A47E	2017-07-03 10:51:00+03	29800.00
83A4AF	2017-08-08 09:54:00+03	13200.00
83A4F3	2017-08-08 16:54:00+03	57500.00
83A56A	2017-07-21 18:31:00+03	6600.00
83A571	2017-07-07 19:25:00+03	24400.00
83A5B9	2017-07-03 00:00:00+03	36400.00
83A609	2017-07-31 00:28:00+03	81300.00
83A626	2017-07-08 21:17:00+03	31400.00
83A632	2017-08-10 19:54:00+03	128800.00
83A654	2017-07-20 08:56:00+03	27000.00
83A670	2017-07-26 21:34:00+03	77200.00
83A687	2017-07-09 07:07:00+03	20200.00
83A6C7	2017-07-08 14:17:00+03	7400.00
83A6FF	2017-08-10 14:51:00+03	31000.00
83A75F	2017-07-15 00:49:00+03	123000.00
83A7AE	2017-07-28 08:25:00+03	102600.00
83A7F1	2017-07-02 10:00:00+03	199700.00
83A8C7	2017-08-08 21:30:00+03	46000.00
83A8CB	2017-07-24 21:17:00+03	28800.00
83A8D1	2017-08-08 13:50:00+03	42600.00
83A90B	2017-08-14 22:13:00+03	23200.00
83A934	2017-08-13 11:27:00+03	8400.00
83A974	2017-07-13 23:04:00+03	77900.00
83AAA5	2017-07-27 17:17:00+03	48800.00
83AABB	2017-06-30 09:00:00+03	212900.00
83AAD2	2017-07-25 00:46:00+03	44800.00
83AB14	2017-08-09 16:27:00+03	23400.00
83AB23	2017-07-08 17:00:00+03	168000.00
83AB26	2017-07-18 00:53:00+03	57400.00
83AB39	2017-07-15 10:55:00+03	72400.00
83AB53	2017-08-02 00:58:00+03	42600.00
83AB64	2017-08-05 01:53:00+03	406100.00
83AC16	2017-07-02 20:59:00+03	47100.00
83AC45	2017-08-11 17:25:00+03	28800.00
83ACB8	2017-08-09 04:46:00+03	246000.00
83AD21	2017-07-10 21:52:00+03	231400.00
83AD3D	2017-07-11 22:25:00+03	26100.00
83AD5A	2017-07-21 05:45:00+03	171100.00
83AD69	2017-08-05 23:57:00+03	21400.00
83AD6A	2017-08-12 20:13:00+03	123000.00
83AD94	2017-08-04 16:17:00+03	55800.00
83ADE2	2017-07-16 10:36:00+03	10800.00
83AE54	2017-08-04 12:24:00+03	53600.00
83AE86	2017-07-31 04:51:00+03	72200.00
83AF24	2017-07-28 19:34:00+03	30800.00
83AF61	2017-07-18 16:46:00+03	46400.00
83AF81	2017-07-25 11:25:00+03	101900.00
83AF87	2017-07-25 09:19:00+03	172100.00
83AF89	2017-08-12 16:14:00+03	37700.00
83AFAD	2017-07-25 13:29:00+03	120900.00
83AFB5	2017-07-05 15:11:00+03	204700.00
83B018	2017-07-30 05:30:00+03	75600.00
83B02D	2017-07-09 00:08:00+03	43300.00
83B072	2017-08-10 08:08:00+03	38600.00
83B0C5	2017-08-09 17:07:00+03	6300.00
83B144	2017-08-02 04:37:00+03	53300.00
83B14F	2017-07-06 07:44:00+03	56000.00
83B161	2017-07-11 19:51:00+03	23200.00
83B19A	2017-07-27 22:00:00+03	57400.00
83B1A3	2017-07-21 17:11:00+03	28800.00
83B1B6	2017-08-13 08:10:00+03	61800.00
83B20C	2017-08-02 00:35:00+03	8600.00
83B215	2017-07-31 03:35:00+03	20200.00
83B217	2017-07-30 12:17:00+03	28000.00
83B227	2017-08-11 12:42:00+03	135600.00
83B269	2017-08-12 04:12:00+03	46000.00
83B294	2017-08-11 07:22:00+03	75000.00
83B2FF	2017-07-01 13:00:00+03	58900.00
83B336	2017-08-12 10:33:00+03	39200.00
83B353	2017-07-21 19:36:00+03	115900.00
83B384	2017-07-18 07:36:00+03	84800.00
83B386	2017-08-11 12:40:00+03	21800.00
83B3D4	2017-07-04 08:40:00+03	23600.00
83B42B	2017-08-06 04:13:00+03	15100.00
83B433	2017-08-11 11:08:00+03	23600.00
83B44E	2017-07-31 12:23:00+03	266400.00
83B458	2017-08-01 17:47:00+03	47400.00
83B45A	2017-08-12 08:39:00+03	43200.00
83B486	2017-07-22 17:40:00+03	93000.00
83B51C	2017-08-12 10:37:00+03	117800.00
83B53C	2017-08-07 16:20:00+03	246000.00
83B562	2017-08-04 07:21:00+03	13000.00
83B5A6	2017-08-06 18:20:00+03	394400.00
83B5C5	2017-08-05 21:36:00+03	30000.00
83B5ED	2017-07-19 13:44:00+03	224000.00
83B5FC	2017-07-01 06:53:00+03	75100.00
83B63E	2017-07-18 15:38:00+03	38800.00
83B64E	2017-07-10 09:33:00+03	71600.00
83B66E	2017-07-26 15:42:00+03	120900.00
83B6AC	2017-07-26 15:02:00+03	26800.00
83B78A	2017-07-08 13:22:00+03	43200.00
83B7DD	2017-07-31 14:15:00+03	26600.00
83B7F9	2017-07-09 11:05:00+03	115100.00
83B805	2017-08-03 10:18:00+03	28000.00
83B86F	2017-08-01 15:04:00+03	36200.00
83B895	2017-07-30 01:15:00+03	25600.00
83B8F1	2017-08-04 04:53:00+03	46400.00
83B92B	2017-07-20 00:24:00+03	31400.00
83B930	2017-08-07 11:13:00+03	75200.00
83B96E	2017-08-13 19:47:00+03	42800.00
83B9CC	2017-07-04 07:17:00+03	24400.00
83BA0F	2017-07-16 10:03:00+03	27300.00
83BA63	2017-07-18 22:45:00+03	92800.00
83BA6B	2017-07-21 10:07:00+03	43200.00
83BADB	2017-08-03 22:02:00+03	6600.00
83BB38	2017-08-14 10:33:00+03	6000.00
83BB42	2017-08-06 22:22:00+03	245300.00
83BB51	2017-07-23 09:54:00+03	118700.00
83BB8C	2017-08-01 14:03:00+03	75600.00
83BBA1	2017-07-09 17:21:00+03	179600.00
83BBA4	2017-07-04 23:57:00+03	77900.00
83BC7E	2017-08-04 19:33:00+03	83000.00
83BC89	2017-07-12 21:37:00+03	97900.00
83BC8A	2017-08-08 07:32:00+03	55800.00
83BCAA	2017-06-26 20:38:00+03	64600.00
83BD1A	2017-08-07 22:39:00+03	224300.00
83BD5D	2017-07-23 19:53:00+03	45100.00
83BDBD	2017-07-19 22:57:00+03	43900.00
83BDD4	2017-08-02 07:43:00+03	46300.00
83BE4C	2017-08-05 20:33:00+03	16400.00
83BE84	2017-08-07 19:54:00+03	40800.00
83BEA6	2017-07-12 00:27:00+03	236300.00
83BECC	2017-07-17 00:40:00+03	14400.00
83BEE4	2017-07-20 17:46:00+03	58200.00
83BEF8	2017-07-31 11:00:00+03	23200.00
83BF2B	2017-08-12 16:46:00+03	12400.00
83BF51	2017-08-12 22:18:00+03	64600.00
83BF52	2017-07-07 04:32:00+03	36800.00
83BF71	2017-08-06 11:59:00+03	92400.00
83C007	2017-07-27 15:08:00+03	35600.00
83C019	2017-07-30 17:04:00+03	348800.00
83C0A1	2017-07-03 06:56:00+03	239100.00
83C0B7	2017-08-03 02:39:00+03	174600.00
83C10E	2017-07-13 03:35:00+03	19600.00
83C137	2017-07-08 23:22:00+03	56600.00
83C13A	2017-08-04 10:50:00+03	7400.00
83C183	2017-07-03 14:44:00+03	31600.00
83C28B	2017-08-07 16:01:00+03	55800.00
83C292	2017-08-13 18:55:00+03	36800.00
83C308	2017-08-08 07:16:00+03	93600.00
83C398	2017-07-23 20:23:00+03	36200.00
83C3F6	2017-07-06 13:31:00+03	190700.00
83C49D	2017-07-22 18:53:00+03	19600.00
83C50F	2017-07-10 13:59:00+03	56600.00
83C533	2017-08-09 15:58:00+03	114400.00
83C56C	2017-07-30 01:56:00+03	24000.00
83C57C	2017-07-12 11:45:00+03	372500.00
83C59B	2017-07-08 00:27:00+03	306600.00
83C59F	2017-08-03 08:29:00+03	44800.00
83C612	2017-07-19 21:27:00+03	114100.00
83C62C	2017-07-24 19:24:00+03	69500.00
83C630	2017-07-31 01:57:00+03	38600.00
83C648	2017-07-07 15:31:00+03	266400.00
83C66D	2017-08-13 02:07:00+03	27200.00
83C673	2017-07-07 05:36:00+03	64700.00
83C6A2	2017-07-19 14:41:00+03	34000.00
83C6B1	2017-07-11 17:41:00+03	44800.00
83C744	2017-08-01 23:16:00+03	6300.00
83C7C4	2017-07-22 02:54:00+03	301100.00
83C7E4	2017-07-26 22:03:00+03	39800.00
83C81E	2017-08-13 17:40:00+03	67000.00
83C824	2017-07-19 12:13:00+03	203000.00
83C8A6	2017-07-06 02:37:00+03	43900.00
83C972	2017-08-05 23:02:00+03	67200.00
83C9EB	2017-08-13 10:44:00+03	44800.00
83CA16	2017-07-29 06:06:00+03	122300.00
83CA19	2017-08-06 15:33:00+03	40200.00
83CA20	2017-07-16 16:54:00+03	31700.00
83CA40	2017-08-12 20:34:00+03	136700.00
83CA64	2017-08-07 21:08:00+03	46300.00
83CA76	2017-08-15 13:19:00+03	31300.00
83CA8C	2017-07-12 06:25:00+03	149300.00
83CAEC	2017-08-11 01:49:00+03	65700.00
83CB80	2017-07-03 18:13:00+03	359100.00
83CB82	2017-08-14 19:31:00+03	236000.00
83CB9F	2017-07-30 21:51:00+03	24400.00
83CC02	2017-07-11 03:46:00+03	28000.00
83CC0A	2017-08-13 05:19:00+03	31800.00
83CC10	2017-07-18 23:57:00+03	84500.00
83CC2A	2017-07-16 21:00:00+03	47500.00
83CC54	2017-07-07 07:08:00+03	52700.00
83CC8A	2017-08-14 11:09:00+03	10600.00
83CC9E	2017-08-11 03:01:00+03	47000.00
83CCA1	2017-07-04 14:56:00+03	96800.00
83CCA2	2017-08-12 18:25:00+03	265800.00
83CCD8	2017-07-25 10:38:00+03	459900.00
83CD0A	2017-07-02 11:44:00+03	9000.00
83CD1C	2017-08-06 01:18:00+03	69000.00
83CD5A	2017-06-29 14:22:00+03	48500.00
83CD75	2017-08-09 16:21:00+03	28000.00
83CE16	2017-07-26 16:22:00+03	58600.00
83CE51	2017-07-10 08:16:00+03	59400.00
83CE55	2017-07-28 21:39:00+03	156500.00
83CE63	2017-07-21 06:07:00+03	254900.00
83CE92	2017-07-09 15:36:00+03	56100.00
83CEC0	2017-07-29 07:28:00+03	68100.00
83CF0F	2017-07-24 11:01:00+03	47200.00
83CF33	2017-06-29 09:22:00+03	8600.00
83CF75	2017-08-03 04:32:00+03	83700.00
83CF99	2017-07-09 04:25:00+03	23600.00
83D020	2017-06-27 20:43:00+03	133200.00
83D036	2017-07-17 13:49:00+03	75600.00
83D0AF	2017-08-15 12:57:00+03	65100.00
83D0EC	2017-07-07 01:50:00+03	6700.00
83D113	2017-08-04 17:30:00+03	198600.00
83D114	2017-08-07 21:41:00+03	137800.00
83D120	2017-07-21 05:46:00+03	128300.00
83D234	2017-07-25 21:08:00+03	185700.00
83D256	2017-07-14 06:02:00+03	26100.00
83D3D2	2017-07-01 17:24:00+03	131100.00
83D3D6	2017-07-17 04:59:00+03	80000.00
83D433	2017-07-08 08:59:00+03	36500.00
83D452	2017-08-11 03:00:00+03	40600.00
83D485	2017-08-01 14:50:00+03	80200.00
83D4A7	2017-08-03 06:48:00+03	49600.00
83D4C7	2017-08-09 02:18:00+03	115000.00
83D4FC	2017-07-18 01:56:00+03	25800.00
83D51C	2017-07-31 10:02:00+03	75600.00
83D534	2017-07-21 19:34:00+03	6000.00
83D54E	2017-07-31 17:13:00+03	46000.00
83D582	2017-07-09 21:36:00+03	46000.00
83D5AB	2017-08-04 15:35:00+03	38400.00
83D5AE	2017-07-25 08:22:00+03	58000.00
83D5CE	2017-08-14 23:52:00+03	17000.00
83D5E3	2017-08-04 21:26:00+03	37200.00
83D60F	2017-08-06 06:05:00+03	64200.00
83D63C	2017-07-22 01:51:00+03	126400.00
83D6BF	2017-08-01 12:10:00+03	147700.00
83D70A	2017-07-30 04:54:00+03	46000.00
83D748	2017-07-01 22:01:00+03	81600.00
83D753	2017-07-22 05:00:00+03	652200.00
83D756	2017-07-21 18:32:00+03	35200.00
83D759	2017-07-09 01:05:00+03	25800.00
83D816	2017-08-14 05:11:00+03	136800.00
83D81E	2017-07-23 23:57:00+03	23200.00
83D82E	2017-08-11 15:20:00+03	45100.00
83D8AC	2017-07-06 19:02:00+03	248300.00
83D8E5	2017-08-14 18:31:00+03	26700.00
83D988	2017-08-11 14:54:00+03	40400.00
83D9A9	2017-08-05 10:26:00+03	56000.00
83DA72	2017-06-30 14:17:00+03	28800.00
83DAD9	2017-07-04 22:43:00+03	135400.00
83DB38	2017-07-04 06:53:00+03	46400.00
83DB51	2017-08-01 03:53:00+03	18600.00
83DB57	2017-07-30 03:38:00+03	134600.00
83DBB6	2017-08-15 15:39:00+03	28000.00
83DC12	2017-08-01 08:54:00+03	29600.00
83DC3E	2017-07-09 20:00:00+03	12600.00
83DC8D	2017-08-13 13:46:00+03	260300.00
83DC97	2017-07-17 07:19:00+03	6800.00
83DCB9	2017-07-22 10:50:00+03	46400.00
83DD07	2017-07-24 16:11:00+03	62600.00
83DD13	2017-07-29 18:59:00+03	75600.00
83DD44	2017-07-08 21:11:00+03	42800.00
83DD7E	2017-07-24 07:17:00+03	21400.00
83DE05	2017-07-16 08:17:00+03	47000.00
83DE0F	2017-07-19 21:58:00+03	29400.00
83DEA8	2017-07-13 05:29:00+03	43200.00
83DEC3	2017-08-06 01:09:00+03	58000.00
83DECC	2017-07-20 15:08:00+03	115400.00
83DF20	2017-08-01 06:08:00+03	32800.00
83DF38	2017-08-13 20:07:00+03	69500.00
83E065	2017-07-27 17:26:00+03	136200.00
83E0C4	2017-07-19 21:35:00+03	75800.00
83E153	2017-07-05 18:44:00+03	40000.00
83E211	2017-07-07 20:23:00+03	40000.00
83E227	2017-08-02 09:59:00+03	65900.00
83E260	2017-07-07 02:55:00+03	29200.00
83E2B2	2017-07-06 20:09:00+03	44600.00
83E3D2	2017-08-03 06:19:00+03	62000.00
83E3E1	2017-07-01 01:34:00+03	119500.00
83E3E6	2017-07-03 22:44:00+03	59200.00
83E411	2017-07-25 23:21:00+03	24400.00
83E415	2017-07-07 00:06:00+03	8400.00
83E43E	2017-08-02 17:17:00+03	135400.00
83E452	2017-07-06 13:27:00+03	71800.00
83E466	2017-06-29 09:29:00+03	218000.00
83E4A4	2017-08-04 02:23:00+03	78300.00
83E4EB	2017-07-26 11:27:00+03	119600.00
83E4EE	2017-08-12 22:53:00+03	23200.00
83E502	2017-08-03 22:59:00+03	39800.00
83E505	2017-06-27 16:10:00+03	26800.00
83E51E	2017-07-20 07:42:00+03	43400.00
83E540	2017-06-30 08:53:00+03	24400.00
83E544	2017-07-08 09:35:00+03	57500.00
83E57A	2017-07-16 17:23:00+03	44800.00
83E5E5	2017-07-03 06:34:00+03	40000.00
83E616	2017-07-24 10:48:00+03	111000.00
83E677	2017-08-09 14:47:00+03	20400.00
83E726	2017-07-03 23:07:00+03	26000.00
83E743	2017-08-05 17:46:00+03	38800.00
83E74D	2017-08-10 16:55:00+03	7400.00
83E781	2017-08-14 16:59:00+03	7300.00
83E79E	2017-08-11 17:46:00+03	40200.00
83E7A5	2017-08-05 15:42:00+03	21800.00
83E7CC	2017-07-07 15:50:00+03	124200.00
83E8E8	2017-07-31 23:35:00+03	99500.00
83E8ED	2017-07-09 18:24:00+03	56000.00
83E8F6	2017-07-03 08:10:00+03	26800.00
83E980	2017-08-08 17:43:00+03	299900.00
83E981	2017-07-31 01:21:00+03	56000.00
83EA60	2017-08-15 12:48:00+03	26000.00
83EA7C	2017-07-11 07:12:00+03	108600.00
83EAAB	2017-07-17 01:23:00+03	28000.00
83EAC3	2017-07-22 11:13:00+03	57400.00
83EAE3	2017-07-07 14:00:00+03	19800.00
83EAF4	2017-08-05 08:46:00+03	7200.00
83EB02	2017-08-08 14:33:00+03	12600.00
83EB05	2017-08-13 04:53:00+03	64700.00
83EBAB	2017-07-24 11:28:00+03	140900.00
83EBE6	2017-08-05 19:49:00+03	111600.00
83EC62	2017-08-06 02:14:00+03	46400.00
83EC6A	2017-07-18 19:06:00+03	164900.00
83ED3B	2017-07-08 04:26:00+03	78200.00
83ED4A	2017-07-03 01:25:00+03	64500.00
83EDEE	2017-07-22 11:28:00+03	26600.00
83EE0F	2017-07-09 12:59:00+03	52000.00
83EE3D	2017-07-11 05:39:00+03	46400.00
83EE61	2017-07-27 21:23:00+03	26800.00
83EF2A	2017-08-01 18:20:00+03	44600.00
83EF3C	2017-08-06 09:01:00+03	121200.00
83EF6D	2017-07-02 16:00:00+03	56100.00
83EFBA	2017-07-30 18:09:00+03	131900.00
83EFBF	2017-07-14 17:40:00+03	27900.00
83F092	2017-07-13 05:08:00+03	59300.00
83F09A	2017-07-24 15:31:00+03	155400.00
83F106	2017-08-08 10:45:00+03	108800.00
83F128	2017-07-30 00:08:00+03	46700.00
83F179	2017-07-15 22:50:00+03	92000.00
83F1D5	2017-07-19 10:21:00+03	43300.00
83F1FF	2017-07-10 11:32:00+03	168000.00
83F22D	2017-07-13 03:58:00+03	223200.00
83F295	2017-07-12 14:43:00+03	112000.00
83F29C	2017-07-09 17:55:00+03	23200.00
83F2F1	2017-08-09 01:00:00+03	46300.00
83F30E	2017-07-20 23:30:00+03	57600.00
83F341	2017-08-06 20:50:00+03	23200.00
83F379	2017-08-07 22:42:00+03	56900.00
83F38D	2017-07-09 07:33:00+03	155600.00
83F395	2017-07-28 04:00:00+03	28000.00
83F42C	2017-07-13 02:58:00+03	49700.00
83F44D	2017-07-20 20:09:00+03	73500.00
83F47E	2017-07-10 10:18:00+03	70700.00
83F4A8	2017-07-19 02:57:00+03	68800.00
83F4CF	2017-07-20 00:40:00+03	54600.00
83F643	2017-07-06 16:53:00+03	234400.00
83F647	2017-07-27 08:07:00+03	78200.00
83F65C	2017-08-11 20:59:00+03	119300.00
83F680	2017-07-10 01:47:00+03	192700.00
83F6AB	2017-08-14 04:00:00+03	184500.00
83F6D5	2017-07-05 15:39:00+03	27200.00
83F702	2017-08-15 05:44:00+03	13400.00
83F71F	2017-08-02 03:36:00+03	150600.00
83F733	2017-08-06 05:02:00+03	335500.00
83F73B	2017-07-06 05:30:00+03	58600.00
83F748	2017-07-04 21:52:00+03	64800.00
83F780	2017-08-14 15:58:00+03	226800.00
83F83D	2017-08-11 03:04:00+03	55000.00
83F85E	2017-08-09 00:38:00+03	40200.00
83F870	2017-08-13 10:56:00+03	137100.00
83F881	2017-07-17 21:38:00+03	56000.00
83F8E4	2017-08-06 12:42:00+03	408500.00
83F8FB	2017-07-17 01:22:00+03	66900.00
83F8FD	2017-08-12 02:33:00+03	114300.00
83F902	2017-07-09 13:10:00+03	71300.00
83F940	2017-07-01 21:18:00+03	25600.00
83F960	2017-08-13 04:03:00+03	112000.00
83FA9F	2017-07-30 16:40:00+03	28000.00
83FAA5	2017-08-03 11:13:00+03	56900.00
83FB40	2017-07-14 11:30:00+03	133200.00
83FB47	2017-07-03 03:12:00+03	56000.00
83FB57	2017-08-06 22:23:00+03	15800.00
83FC61	2017-08-06 10:05:00+03	134400.00
83FC6C	2017-07-21 23:39:00+03	38400.00
83FD28	2017-08-01 01:27:00+03	133200.00
83FD5F	2017-07-23 03:09:00+03	103500.00
83FD6C	2017-07-14 07:37:00+03	118800.00
83FDA4	2017-07-27 13:14:00+03	211000.00
83FE02	2017-07-22 10:35:00+03	59800.00
83FE67	2017-07-25 13:25:00+03	133100.00
83FE7D	2017-07-29 22:08:00+03	44600.00
83FE9D	2017-08-04 19:30:00+03	115300.00
83FEC5	2017-07-10 11:26:00+03	492000.00
83FEE5	2017-07-10 13:54:00+03	124200.00
83FF13	2017-07-16 22:51:00+03	36200.00
83FF27	2017-07-30 05:02:00+03	57700.00
83FF4A	2017-07-03 12:09:00+03	57600.00
83FFA9	2017-07-13 05:02:00+03	16800.00
83FFB9	2017-06-29 20:39:00+03	37900.00
83FFFC	2017-08-15 16:24:00+03	66600.00
840024	2017-07-19 23:20:00+03	29600.00
840031	2017-07-08 22:13:00+03	83000.00
84006F	2017-07-05 19:49:00+03	65500.00
840081	2017-07-02 03:03:00+03	111600.00
8400A0	2017-07-14 18:37:00+03	143200.00
84012E	2017-07-23 05:03:00+03	145300.00
840175	2017-07-23 09:29:00+03	6000.00
84018C	2017-07-16 20:09:00+03	38600.00
8401DA	2017-07-15 18:51:00+03	14400.00
840201	2017-07-11 18:05:00+03	43000.00
84020C	2017-07-14 03:49:00+03	85000.00
840254	2017-07-14 18:33:00+03	52800.00
84025C	2017-07-21 02:58:00+03	59100.00
840263	2017-07-23 17:44:00+03	6300.00
840264	2017-07-16 20:46:00+03	127400.00
8402C1	2017-07-23 20:15:00+03	38800.00
8402D7	2017-06-30 14:19:00+03	57500.00
8402FA	2017-07-07 15:35:00+03	47200.00
8402FB	2017-06-29 11:05:00+03	28000.00
84036D	2017-08-12 01:08:00+03	149000.00
8403CA	2017-07-16 02:23:00+03	67200.00
8403F4	2017-08-04 07:33:00+03	208100.00
840486	2017-06-28 16:29:00+03	20400.00
84048A	2017-08-14 15:33:00+03	272500.00
8404E0	2017-08-11 01:41:00+03	160700.00
8404FE	2017-07-28 07:34:00+03	97900.00
840576	2017-07-14 18:16:00+03	77000.00
840591	2017-07-18 11:52:00+03	93600.00
84062C	2017-07-13 00:59:00+03	60400.00
84066A	2017-08-15 13:31:00+03	176300.00
8406BA	2017-07-20 20:44:00+03	21400.00
8406DC	2017-07-04 02:31:00+03	26000.00
8406E0	2017-07-29 17:07:00+03	75300.00
8406E9	2017-07-17 12:41:00+03	28600.00
84078E	2017-07-25 13:41:00+03	10600.00
8408FC	2017-08-02 22:55:00+03	27200.00
840920	2017-07-23 08:43:00+03	12600.00
84093D	2017-08-06 04:09:00+03	36200.00
84099A	2017-07-17 10:23:00+03	54000.00
8409EA	2017-08-10 21:13:00+03	59800.00
840A6D	2017-08-03 15:07:00+03	116700.00
840AE2	2017-07-14 12:54:00+03	29800.00
840B0E	2017-07-21 04:31:00+03	35600.00
840B63	2017-08-15 07:47:00+03	186500.00
840B6F	2017-08-12 10:56:00+03	55800.00
840B8B	2017-07-13 22:04:00+03	46200.00
840C28	2017-08-14 00:29:00+03	22000.00
840CA7	2017-07-15 10:24:00+03	48500.00
840CC5	2017-07-09 00:50:00+03	31400.00
840CD2	2017-07-26 10:32:00+03	29800.00
840D2D	2017-07-25 12:56:00+03	46000.00
840D62	2017-06-30 15:26:00+03	49200.00
840D6E	2017-08-05 18:43:00+03	57800.00
840D81	2017-07-11 21:06:00+03	60400.00
840D87	2017-07-18 13:31:00+03	56000.00
840DC5	2017-07-17 09:15:00+03	67400.00
840DF7	2017-08-07 19:05:00+03	177200.00
840E18	2017-07-25 23:40:00+03	87200.00
840EFC	2017-07-14 03:36:00+03	26000.00
840F35	2017-07-20 21:17:00+03	23400.00
840F3D	2017-07-22 02:54:00+03	28800.00
840F54	2017-07-12 18:49:00+03	204700.00
840FE2	2017-07-26 20:18:00+03	16400.00
841046	2017-06-30 01:57:00+03	39200.00
841069	2017-07-31 07:19:00+03	105800.00
841084	2017-07-17 00:43:00+03	23200.00
8410B9	2017-07-25 16:33:00+03	26000.00
8410BB	2017-08-04 19:29:00+03	132800.00
841148	2017-07-07 21:58:00+03	128400.00
841174	2017-07-31 01:03:00+03	120000.00
8411B0	2017-08-13 11:21:00+03	96400.00
8411CA	2017-07-22 11:59:00+03	29100.00
841288	2017-08-14 03:56:00+03	206400.00
841291	2017-07-14 00:38:00+03	54500.00
8412B6	2017-07-20 11:22:00+03	56000.00
841327	2017-07-26 13:03:00+03	58000.00
84135B	2017-07-20 07:01:00+03	56600.00
841378	2017-07-05 00:45:00+03	77900.00
841399	2017-08-11 22:38:00+03	12600.00
8413BB	2017-07-04 01:54:00+03	94200.00
84151D	2017-07-05 16:38:00+03	67900.00
84155C	2017-08-06 22:24:00+03	207000.00
84155E	2017-07-19 00:19:00+03	43500.00
841592	2017-07-27 23:02:00+03	26700.00
8415E3	2017-07-19 19:47:00+03	47700.00
841604	2017-07-15 20:06:00+03	43200.00
84162A	2017-08-04 08:43:00+03	122300.00
841704	2017-07-20 16:39:00+03	46300.00
841705	2017-07-28 12:30:00+03	40400.00
84172E	2017-08-13 01:10:00+03	224000.00
841780	2017-07-20 20:33:00+03	42700.00
8417B5	2017-07-25 19:50:00+03	418400.00
8417D3	2017-08-06 17:49:00+03	65900.00
841833	2017-08-07 11:39:00+03	28800.00
84185D	2017-07-07 20:52:00+03	226200.00
84188A	2017-07-10 04:21:00+03	144000.00
841918	2017-07-30 08:10:00+03	281500.00
841956	2017-07-12 13:01:00+03	45400.00
841957	2017-07-23 18:26:00+03	246000.00
84199C	2017-07-10 21:36:00+03	12200.00
8419BC	2017-07-26 10:45:00+03	136600.00
8419F7	2017-07-13 18:35:00+03	66100.00
841A03	2017-08-07 16:30:00+03	55800.00
841A54	2017-07-19 17:35:00+03	213800.00
841B2E	2017-07-08 23:26:00+03	26000.00
841B6E	2017-07-11 22:22:00+03	26600.00
841BFD	2017-08-04 07:24:00+03	23600.00
841C01	2017-07-28 17:21:00+03	23200.00
841C39	2017-07-06 12:34:00+03	81500.00
841C51	2017-07-14 04:17:00+03	6800.00
841C62	2017-08-10 12:23:00+03	26200.00
841C92	2017-07-01 14:38:00+03	124200.00
841CCE	2017-07-29 07:24:00+03	60200.00
841CF0	2017-07-12 22:31:00+03	92400.00
841D06	2017-07-22 15:37:00+03	100600.00
841D2D	2017-07-08 04:18:00+03	46400.00
841D93	2017-07-02 08:46:00+03	51900.00
841D9B	2017-07-15 19:33:00+03	34600.00
841DF3	2017-08-04 16:01:00+03	150600.00
841E9E	2017-08-01 10:02:00+03	56900.00
841EB0	2017-07-06 10:56:00+03	171000.00
841EB3	2017-07-12 02:08:00+03	27200.00
841F49	2017-07-09 07:26:00+03	32800.00
841F50	2017-07-30 06:20:00+03	73500.00
841F69	2017-07-18 21:20:00+03	56900.00
841F8D	2017-07-15 12:35:00+03	112000.00
841FB3	2017-08-04 23:38:00+03	192900.00
841FBA	2017-08-06 12:19:00+03	34000.00
841FED	2017-07-09 14:36:00+03	166100.00
841FEF	2017-08-01 21:41:00+03	130200.00
842007	2017-07-18 21:44:00+03	28800.00
842043	2017-07-14 09:07:00+03	139800.00
842148	2017-07-05 16:12:00+03	63200.00
8421CC	2017-08-02 12:44:00+03	29600.00
842201	2017-07-01 08:06:00+03	25100.00
84222A	2017-07-19 23:17:00+03	108500.00
842342	2017-07-03 05:36:00+03	44800.00
8423C3	2017-08-11 12:23:00+03	27800.00
8423D0	2017-07-17 17:22:00+03	199200.00
8424F0	2017-07-16 11:42:00+03	61400.00
842508	2017-07-10 06:13:00+03	35800.00
842572	2017-07-29 09:58:00+03	24400.00
84258B	2017-07-24 14:38:00+03	100200.00
8425B1	2017-08-07 09:59:00+03	174100.00
8425FA	2017-08-07 01:29:00+03	100600.00
84260D	2017-07-24 03:19:00+03	233400.00
84268B	2017-08-13 18:36:00+03	37700.00
8426E9	2017-07-12 14:18:00+03	25100.00
842716	2017-08-10 10:31:00+03	100600.00
84275F	2017-07-16 03:00:00+03	32700.00
8427F0	2017-07-03 17:44:00+03	37900.00
842845	2017-07-16 11:46:00+03	135200.00
84289E	2017-07-04 14:43:00+03	59300.00
8428AB	2017-08-14 20:41:00+03	77000.00
8428B2	2017-08-11 14:04:00+03	111600.00
84292B	2017-08-07 21:13:00+03	117200.00
84294D	2017-07-30 07:51:00+03	67700.00
842951	2017-07-18 09:19:00+03	13200.00
842956	2017-07-22 03:47:00+03	57300.00
842958	2017-07-29 01:35:00+03	120900.00
8429CC	2017-08-10 11:45:00+03	38600.00
842A15	2017-07-08 17:32:00+03	88900.00
842A4C	2017-07-26 02:50:00+03	25600.00
842A7C	2017-08-04 08:03:00+03	83400.00
842B77	2017-07-07 03:34:00+03	100700.00
842B9D	2017-07-08 21:19:00+03	26800.00
842BD5	2017-07-26 04:37:00+03	77200.00
842BE9	2017-08-09 21:29:00+03	14900.00
842C21	2017-07-20 12:14:00+03	70800.00
842C24	2017-08-04 18:48:00+03	38600.00
842D29	2017-07-26 15:39:00+03	25600.00
842D32	2017-07-03 13:58:00+03	137400.00
842D42	2017-08-10 01:19:00+03	123000.00
842D54	2017-07-25 06:58:00+03	25200.00
842DBE	2017-07-14 16:10:00+03	327500.00
842E12	2017-08-14 16:07:00+03	24000.00
842E16	2017-07-17 12:28:00+03	19800.00
842E5F	2017-07-19 05:34:00+03	92100.00
842E60	2017-07-07 00:11:00+03	260300.00
842E69	2017-08-07 13:06:00+03	96800.00
842E94	2017-07-04 01:31:00+03	46200.00
842E9F	2017-08-14 17:55:00+03	67600.00
842EDA	2017-07-19 22:23:00+03	65600.00
843044	2017-07-17 12:36:00+03	13400.00
843094	2017-08-11 14:18:00+03	58900.00
8430ED	2017-07-10 15:44:00+03	46300.00
8430F6	2017-07-15 09:16:00+03	82900.00
84313B	2017-08-05 02:39:00+03	23200.00
84314A	2017-07-04 13:53:00+03	115900.00
843152	2017-07-23 14:27:00+03	16400.00
8431A2	2017-07-02 09:48:00+03	46400.00
843233	2017-08-04 03:24:00+03	28800.00
843237	2017-08-13 08:33:00+03	170300.00
84323A	2017-07-06 08:03:00+03	321300.00
843258	2017-07-13 10:20:00+03	56000.00
84329A	2017-07-19 03:12:00+03	134900.00
8432FE	2017-07-25 16:27:00+03	40000.00
84333F	2017-07-22 08:56:00+03	54400.00
8433E8	2017-07-24 13:40:00+03	109300.00
843414	2017-08-11 12:39:00+03	44000.00
843443	2017-08-02 08:59:00+03	167400.00
843478	2017-07-08 14:03:00+03	25600.00
8434B8	2017-06-30 19:52:00+03	66600.00
8434DA	2017-07-15 02:21:00+03	94700.00
8435F4	2017-07-18 16:17:00+03	76400.00
8435FD	2017-08-06 12:52:00+03	13700.00
843642	2017-07-25 07:19:00+03	55800.00
843652	2017-07-28 21:33:00+03	130400.00
84366D	2017-07-11 13:09:00+03	25600.00
843679	2017-07-15 02:38:00+03	13400.00
8436D0	2017-07-06 01:27:00+03	135400.00
8436F7	2017-07-08 20:22:00+03	53600.00
843718	2017-07-04 23:17:00+03	135600.00
843744	2017-08-06 02:02:00+03	62600.00
8437A9	2017-07-26 09:38:00+03	39300.00
843898	2017-06-29 16:40:00+03	43200.00
8438B8	2017-07-12 03:33:00+03	49100.00
8439B7	2017-07-01 12:34:00+03	24400.00
843A58	2017-07-16 13:53:00+03	65500.00
843A71	2017-07-04 03:30:00+03	34000.00
843B0E	2017-08-01 20:04:00+03	65500.00
843B26	2017-08-06 11:20:00+03	246000.00
843B2F	2017-07-29 11:57:00+03	49800.00
843BAA	2017-08-03 20:59:00+03	40100.00
843C19	2017-08-01 16:34:00+03	96800.00
843C53	2017-08-11 19:08:00+03	189200.00
843C9F	2017-07-08 13:55:00+03	23600.00
843CC5	2017-07-17 19:17:00+03	58500.00
843D16	2017-07-05 09:28:00+03	162700.00
843D2A	2017-07-30 05:06:00+03	61800.00
843D2E	2017-07-07 01:02:00+03	210200.00
843D3E	2017-07-28 03:02:00+03	257500.00
843E14	2017-07-07 01:20:00+03	21600.00
843E64	2017-08-05 11:34:00+03	85000.00
843E6C	2017-08-13 07:26:00+03	75500.00
843E96	2017-07-22 21:37:00+03	89600.00
843EFB	2017-08-06 10:43:00+03	12600.00
843FE7	2017-07-11 00:04:00+03	59800.00
844033	2017-07-22 10:07:00+03	48700.00
84403B	2017-07-07 04:47:00+03	113600.00
844080	2017-07-23 11:25:00+03	8400.00
8440EA	2017-07-09 11:34:00+03	6000.00
844151	2017-07-25 03:16:00+03	30000.00
84421B	2017-08-11 21:00:00+03	26700.00
84424A	2017-07-06 05:21:00+03	19800.00
84428C	2017-07-29 14:06:00+03	13600.00
8442A0	2017-07-17 08:01:00+03	37900.00
8442C3	2017-08-02 16:06:00+03	50600.00
8442ED	2017-07-29 00:40:00+03	38400.00
844375	2017-08-08 16:06:00+03	116400.00
844382	2017-07-01 23:55:00+03	48800.00
8443E9	2017-07-08 10:39:00+03	47400.00
84444F	2017-07-01 01:24:00+03	118400.00
844459	2017-07-21 09:02:00+03	169900.00
844493	2017-07-23 13:54:00+03	12400.00
8444AD	2017-08-12 07:23:00+03	28800.00
8444D7	2017-08-05 02:28:00+03	31600.00
844509	2017-08-07 09:16:00+03	133100.00
844545	2017-07-26 21:57:00+03	64500.00
84454D	2017-07-15 09:14:00+03	7400.00
844552	2017-07-07 23:49:00+03	135600.00
844569	2017-08-04 06:24:00+03	136500.00
84459E	2017-07-14 07:21:00+03	95200.00
844604	2017-07-11 15:59:00+03	76600.00
844612	2017-07-25 08:35:00+03	37000.00
844643	2017-08-01 18:05:00+03	34000.00
844686	2017-07-24 13:36:00+03	105000.00
844691	2017-08-04 18:29:00+03	26000.00
8446CC	2017-08-13 00:57:00+03	69100.00
8446F6	2017-08-10 11:26:00+03	23200.00
844776	2017-07-29 08:21:00+03	121200.00
84477D	2017-07-04 14:23:00+03	51800.00
844799	2017-08-07 21:43:00+03	21200.00
8447DC	2017-07-20 13:32:00+03	24400.00
844801	2017-07-23 20:06:00+03	81700.00
8448A7	2017-08-05 02:28:00+03	71400.00
844939	2017-07-28 16:36:00+03	52000.00
84499E	2017-07-22 17:33:00+03	199800.00
844A31	2017-07-30 06:04:00+03	14000.00
844A3E	2017-07-29 04:50:00+03	59000.00
844A5A	2017-08-12 23:13:00+03	133700.00
844A64	2017-07-08 06:52:00+03	149200.00
844A8F	2017-08-06 16:58:00+03	22000.00
844AF2	2017-07-12 05:41:00+03	135400.00
844B3F	2017-07-18 05:33:00+03	64700.00
844BAE	2017-07-26 14:39:00+03	83800.00
844BE9	2017-07-05 06:50:00+03	24400.00
844C08	2017-07-19 03:51:00+03	201200.00
844C19	2017-07-20 02:04:00+03	81300.00
844C5D	2017-07-29 02:27:00+03	38600.00
844CE2	2017-07-10 00:01:00+03	6000.00
844D42	2017-07-06 13:40:00+03	25600.00
844D6A	2017-07-28 09:58:00+03	170000.00
844DCF	2017-07-10 14:19:00+03	296000.00
844DFD	2017-07-17 10:04:00+03	106800.00
844E0A	2017-07-04 05:10:00+03	111600.00
844EC5	2017-07-04 22:54:00+03	155100.00
844EF3	2017-08-13 23:20:00+03	56600.00
844F00	2017-07-22 14:37:00+03	71900.00
844F13	2017-08-15 00:38:00+03	27800.00
844F18	2017-07-16 02:29:00+03	175400.00
844F8F	2017-07-17 03:14:00+03	49600.00
8451C9	2017-07-13 07:42:00+03	59300.00
8451EA	2017-07-27 16:08:00+03	56000.00
8451EE	2017-07-29 21:16:00+03	105000.00
845208	2017-07-13 13:53:00+03	270800.00
845211	2017-06-30 18:10:00+03	213800.00
84527D	2017-08-05 08:51:00+03	42800.00
8452CC	2017-07-22 19:49:00+03	151200.00
845415	2017-07-08 08:15:00+03	43900.00
845494	2017-07-07 08:17:00+03	85000.00
8455A9	2017-07-25 17:49:00+03	96800.00
8455AF	2017-07-23 01:27:00+03	369000.00
8455C1	2017-08-14 01:51:00+03	28000.00
845615	2017-08-07 10:30:00+03	35600.00
845675	2017-08-12 19:34:00+03	21800.00
8456C5	2017-07-26 16:55:00+03	109600.00
84570F	2017-07-05 18:56:00+03	199700.00
845710	2017-07-26 02:19:00+03	50600.00
84575B	2017-08-01 02:18:00+03	88100.00
84575D	2017-07-19 00:38:00+03	127100.00
845773	2017-08-07 03:02:00+03	27800.00
8457B0	2017-07-03 00:13:00+03	109400.00
8457F2	2017-07-15 11:00:00+03	62000.00
84582F	2017-08-13 08:47:00+03	47000.00
845845	2017-07-14 20:12:00+03	47200.00
845903	2017-08-14 09:16:00+03	199300.00
8459C6	2017-08-06 20:41:00+03	56100.00
845A3A	2017-07-28 11:51:00+03	20700.00
845A43	2017-07-02 08:21:00+03	173100.00
845A4D	2017-07-12 21:08:00+03	55600.00
845AAE	2017-07-19 16:15:00+03	38200.00
845AD9	2017-08-13 04:24:00+03	214800.00
845B07	2017-07-20 01:22:00+03	24400.00
845B13	2017-08-03 09:15:00+03	26000.00
845B7B	2017-07-14 17:09:00+03	30200.00
845BA7	2017-08-07 20:36:00+03	106900.00
845BC7	2017-07-21 00:01:00+03	22000.00
845CC7	2017-07-28 03:56:00+03	81600.00
845CC9	2017-07-04 07:37:00+03	150300.00
845CEF	2017-08-09 02:58:00+03	63500.00
845D03	2017-08-14 23:06:00+03	396500.00
845D44	2017-08-10 02:08:00+03	6800.00
845D48	2017-07-18 12:01:00+03	31000.00
845E1A	2017-07-27 14:55:00+03	75300.00
845E5C	2017-07-08 11:26:00+03	68800.00
845EF5	2017-08-12 21:01:00+03	56000.00
845F31	2017-07-16 16:23:00+03	184300.00
845F36	2017-07-21 01:32:00+03	220900.00
845F42	2017-08-07 00:22:00+03	92000.00
845F97	2017-07-03 16:25:00+03	8200.00
845FC4	2017-07-02 08:00:00+03	246000.00
84606A	2017-07-22 14:07:00+03	11600.00
846113	2017-07-31 15:54:00+03	67700.00
84612D	2017-08-10 00:44:00+03	24400.00
846179	2017-07-15 11:19:00+03	23200.00
8461C8	2017-08-12 01:07:00+03	46400.00
8461F8	2017-08-07 00:40:00+03	85900.00
84621B	2017-07-05 04:04:00+03	53700.00
846276	2017-07-02 18:17:00+03	66600.00
8462CD	2017-07-08 22:06:00+03	12400.00
8462D1	2017-07-17 01:43:00+03	12400.00
8462F0	2017-08-02 21:13:00+03	34000.00
846335	2017-07-25 12:16:00+03	17800.00
846363	2017-07-15 21:46:00+03	66600.00
8463A7	2017-08-04 14:08:00+03	246000.00
8463DC	2017-08-02 17:10:00+03	186000.00
8463EE	2017-07-28 07:54:00+03	14000.00
846429	2017-08-14 22:46:00+03	14400.00
8464E6	2017-08-04 17:15:00+03	23600.00
846509	2017-07-12 00:19:00+03	64100.00
846512	2017-08-10 03:24:00+03	43800.00
846567	2017-07-22 03:18:00+03	59300.00
8465A4	2017-07-21 11:49:00+03	43100.00
8465E6	2017-07-09 06:48:00+03	91600.00
8465EB	2017-07-04 00:53:00+03	57600.00
84663D	2017-08-02 02:38:00+03	411800.00
84664A	2017-07-20 06:13:00+03	62400.00
84664B	2017-07-18 02:59:00+03	12400.00
8466A2	2017-07-19 18:24:00+03	113700.00
846843	2017-07-08 04:52:00+03	142300.00
84685B	2017-07-18 18:49:00+03	51300.00
846862	2017-08-05 10:07:00+03	187600.00
846864	2017-08-03 17:21:00+03	180600.00
84686C	2017-07-27 00:49:00+03	50300.00
846899	2017-07-03 13:23:00+03	71500.00
8468C1	2017-07-18 09:48:00+03	6800.00
8468D4	2017-08-06 19:50:00+03	53300.00
8468F5	2017-07-26 22:01:00+03	45200.00
846908	2017-08-12 03:18:00+03	130100.00
8469CB	2017-07-18 04:55:00+03	69500.00
8469CF	2017-06-28 04:35:00+03	246000.00
846A6F	2017-07-05 18:21:00+03	9800.00
846AE5	2017-07-19 19:26:00+03	402700.00
846B30	2017-08-13 19:46:00+03	55800.00
846B4C	2017-07-18 09:30:00+03	79800.00
846BAF	2017-07-20 06:40:00+03	286100.00
846BBC	2017-08-12 09:41:00+03	44500.00
846BE6	2017-08-08 08:29:00+03	151200.00
846CBB	2017-07-08 01:24:00+03	6200.00
846CBD	2017-08-06 15:57:00+03	21800.00
846CD3	2017-08-15 16:47:00+03	22600.00
846CD7	2017-07-24 18:58:00+03	147700.00
846CF1	2017-07-30 13:19:00+03	61800.00
846CFB	2017-08-05 09:07:00+03	14000.00
846D46	2017-08-10 21:03:00+03	29600.00
846D5A	2017-07-19 09:20:00+03	169200.00
846DA0	2017-07-01 13:20:00+03	88600.00
846DF5	2017-07-18 20:05:00+03	26000.00
846E1F	2017-08-14 01:26:00+03	54800.00
846E72	2017-08-10 09:10:00+03	38800.00
846E91	2017-07-30 18:32:00+03	87000.00
846EA2	2017-08-05 08:22:00+03	47400.00
846EA3	2017-07-03 01:48:00+03	43100.00
846EA5	2017-07-02 17:03:00+03	19800.00
846EE1	2017-08-03 06:43:00+03	45200.00
846F83	2017-07-21 07:55:00+03	96800.00
846F8F	2017-07-30 08:56:00+03	54200.00
846FB1	2017-08-09 03:36:00+03	198400.00
847056	2017-07-10 17:03:00+03	123700.00
84705F	2017-08-01 19:37:00+03	67600.00
847070	2017-07-21 01:20:00+03	169300.00
847084	2017-08-14 19:36:00+03	62600.00
847090	2017-07-04 02:00:00+03	89600.00
8470B4	2017-07-08 11:46:00+03	103500.00
8470B7	2017-08-14 02:27:00+03	31300.00
8470DA	2017-07-08 10:27:00+03	27200.00
8470E3	2017-07-16 22:35:00+03	48800.00
8470FA	2017-08-01 02:42:00+03	28800.00
847107	2017-07-19 11:06:00+03	28000.00
847154	2017-07-24 12:12:00+03	80000.00
847172	2017-07-06 06:39:00+03	81600.00
847186	2017-08-12 16:41:00+03	64600.00
847223	2017-07-25 06:24:00+03	84100.00
847279	2017-07-03 16:22:00+03	132200.00
847285	2017-07-03 09:49:00+03	29600.00
8472A6	2017-07-22 19:20:00+03	314400.00
8472F5	2017-07-12 22:21:00+03	109000.00
8472FE	2017-07-03 04:53:00+03	11600.00
847305	2017-08-15 07:16:00+03	99200.00
84730D	2017-07-16 07:59:00+03	25700.00
84734F	2017-07-09 23:46:00+03	131100.00
84735D	2017-07-21 10:24:00+03	28700.00
8473B3	2017-07-14 20:35:00+03	58200.00
8473F1	2017-08-02 15:37:00+03	184000.00
8473FC	2017-08-15 12:18:00+03	86400.00
847419	2017-08-09 09:28:00+03	677800.00
847441	2017-07-18 08:47:00+03	31000.00
84747F	2017-07-04 06:24:00+03	14000.00
84749E	2017-07-22 23:13:00+03	176900.00
84749F	2017-07-01 06:15:00+03	52300.00
8474D5	2017-08-09 11:15:00+03	39300.00
847572	2017-07-05 19:06:00+03	31400.00
8475DA	2017-07-17 14:22:00+03	21800.00
84763A	2017-07-27 16:58:00+03	75300.00
847669	2017-07-09 16:20:00+03	40800.00
84770D	2017-08-05 05:05:00+03	107400.00
8477DD	2017-08-11 15:04:00+03	92700.00
8477E5	2017-08-14 16:53:00+03	37200.00
84787A	2017-08-06 06:27:00+03	49800.00
8478AA	2017-08-07 05:29:00+03	168000.00
8478C6	2017-07-27 21:48:00+03	37900.00
8478D6	2017-07-04 03:08:00+03	70400.00
84791B	2017-08-01 07:31:00+03	35600.00
84791C	2017-07-06 13:20:00+03	28000.00
84799F	2017-07-21 19:04:00+03	56000.00
8479BD	2017-07-21 12:55:00+03	35200.00
847A0B	2017-07-01 02:00:00+03	60600.00
847B18	2017-07-10 14:43:00+03	40600.00
847B8B	2017-08-14 08:16:00+03	8400.00
847BA9	2017-08-12 12:23:00+03	55800.00
847BC4	2017-08-01 01:48:00+03	37200.00
847C01	2017-07-29 13:33:00+03	26000.00
847C22	2017-07-15 12:38:00+03	55800.00
847C4A	2017-07-12 02:24:00+03	11100.00
847C73	2017-08-05 23:27:00+03	84100.00
847C89	2017-08-08 18:48:00+03	55800.00
847C8A	2017-08-10 19:42:00+03	43000.00
847C98	2017-07-01 02:50:00+03	56000.00
847CEF	2017-07-29 20:34:00+03	399600.00
847D02	2017-07-18 03:48:00+03	59600.00
847D20	2017-08-14 19:57:00+03	386200.00
847D3F	2017-08-06 05:23:00+03	23400.00
847D66	2017-08-13 11:01:00+03	26000.00
847DCF	2017-07-24 12:51:00+03	107400.00
847DDC	2017-07-08 02:02:00+03	69600.00
847DE6	2017-07-03 16:41:00+03	13600.00
847E22	2017-07-31 23:50:00+03	265600.00
847E3B	2017-08-05 23:30:00+03	75800.00
847E78	2017-07-07 11:54:00+03	22000.00
847E89	2017-08-10 09:11:00+03	24600.00
847E91	2017-07-27 22:03:00+03	28000.00
847EBE	2017-07-06 05:03:00+03	34100.00
847EC7	2017-07-16 00:32:00+03	21800.00
847EF1	2017-07-17 08:55:00+03	38000.00
847F03	2017-08-07 20:52:00+03	28000.00
847F55	2017-07-02 22:20:00+03	3800.00
847FA6	2017-07-06 05:36:00+03	13400.00
847FF9	2017-08-03 03:08:00+03	57600.00
848013	2017-07-22 05:08:00+03	52800.00
8480BB	2017-07-15 06:35:00+03	31400.00
8480E8	2017-07-24 07:51:00+03	62600.00
848181	2017-08-06 14:49:00+03	40400.00
84818E	2017-07-16 16:41:00+03	23200.00
848231	2017-07-28 22:46:00+03	65900.00
84838E	2017-08-09 15:10:00+03	174600.00
8483A9	2017-08-13 02:40:00+03	135600.00
8483C2	2017-07-09 01:48:00+03	130800.00
8483D4	2017-08-07 18:36:00+03	50000.00
84841C	2017-07-16 05:45:00+03	40700.00
848420	2017-07-10 20:37:00+03	19600.00
84843E	2017-07-21 08:23:00+03	50000.00
8484A6	2017-07-18 01:36:00+03	8000.00
8484D5	2017-08-04 17:38:00+03	12000.00
8484EB	2017-07-06 22:16:00+03	25400.00
84852E	2017-07-26 15:38:00+03	68200.00
84856C	2017-07-27 17:45:00+03	16400.00
8485A3	2017-08-01 05:12:00+03	55800.00
8485AA	2017-07-30 11:01:00+03	28000.00
8485AF	2017-08-13 07:06:00+03	21800.00
8485B2	2017-07-05 14:36:00+03	79600.00
848601	2017-07-02 18:17:00+03	89700.00
84867E	2017-07-16 07:04:00+03	57600.00
8486B2	2017-07-29 17:22:00+03	28000.00
8486BC	2017-06-28 08:01:00+03	136800.00
8486EB	2017-07-03 23:31:00+03	160200.00
8486F8	2017-08-12 20:34:00+03	44000.00
84872B	2017-07-15 11:00:00+03	68800.00
848778	2017-08-02 21:58:00+03	24800.00
84879B	2017-07-20 06:00:00+03	6900.00
84879E	2017-07-05 04:38:00+03	20200.00
8487A7	2017-07-07 22:21:00+03	62700.00
8487A8	2017-07-28 14:13:00+03	272900.00
8487DA	2017-08-12 23:06:00+03	22000.00
84887A	2017-08-11 10:37:00+03	51900.00
848912	2017-07-15 01:19:00+03	67200.00
848919	2017-08-11 23:27:00+03	31000.00
848947	2017-07-15 12:07:00+03	44600.00
848982	2017-08-09 10:51:00+03	50600.00
84898B	2017-07-24 07:23:00+03	16400.00
848A42	2017-08-04 14:50:00+03	75600.00
848A70	2017-08-04 23:13:00+03	22000.00
848AAB	2017-08-07 01:42:00+03	53300.00
848AD2	2017-07-04 00:40:00+03	109300.00
848B04	2017-07-05 07:32:00+03	47100.00
848B1C	2017-08-03 10:27:00+03	19800.00
848B4C	2017-07-25 22:56:00+03	42900.00
848B56	2017-07-30 02:50:00+03	165500.00
848B5B	2017-08-12 03:40:00+03	85000.00
848B6E	2017-07-19 02:20:00+03	7400.00
848B7A	2017-07-02 09:21:00+03	23200.00
848BCA	2017-07-29 20:40:00+03	122000.00
848C75	2017-07-22 17:57:00+03	35700.00
848C78	2017-07-25 16:14:00+03	273600.00
848C85	2017-07-13 14:33:00+03	180100.00
848D2B	2017-07-21 13:19:00+03	119600.00
848DA3	2017-07-20 10:58:00+03	56600.00
848EBE	2017-06-28 06:14:00+03	12000.00
848ED4	2017-08-01 01:05:00+03	117800.00
848F86	2017-07-04 11:34:00+03	69000.00
848FA5	2017-08-06 01:26:00+03	178000.00
848FAC	2017-08-11 11:22:00+03	36200.00
848FE5	2017-07-05 16:31:00+03	37200.00
849040	2017-07-17 01:36:00+03	19600.00
84906F	2017-07-21 10:56:00+03	50000.00
849084	2017-07-02 15:32:00+03	19600.00
8490A5	2017-07-26 15:44:00+03	65900.00
8491C2	2017-08-09 17:19:00+03	42700.00
8491FC	2017-08-01 01:26:00+03	124200.00
849218	2017-07-15 16:52:00+03	137600.00
8492A6	2017-07-31 02:31:00+03	284100.00
84930A	2017-07-12 08:23:00+03	56600.00
8493DF	2017-08-14 20:47:00+03	51000.00
84941E	2017-07-20 09:51:00+03	71600.00
849444	2017-07-30 10:14:00+03	28000.00
849472	2017-08-11 09:00:00+03	92100.00
8494A1	2017-08-08 19:28:00+03	6700.00
8494A6	2017-07-28 06:22:00+03	80000.00
8494B0	2017-07-27 07:22:00+03	56000.00
84951A	2017-07-09 00:26:00+03	21400.00
84952E	2017-07-31 16:36:00+03	90000.00
849621	2017-08-11 12:03:00+03	62700.00
849642	2017-07-31 15:04:00+03	198400.00
84964A	2017-07-12 00:56:00+03	54800.00
849682	2017-08-07 20:14:00+03	39800.00
8496A0	2017-08-01 16:48:00+03	53400.00
8496EE	2017-08-13 20:27:00+03	73200.00
84974D	2017-08-14 00:11:00+03	36200.00
849757	2017-07-08 22:01:00+03	32800.00
8497B9	2017-07-20 01:26:00+03	34200.00
8497D3	2017-07-10 19:05:00+03	81200.00
8498A1	2017-07-20 21:56:00+03	151600.00
8498AF	2017-07-25 05:08:00+03	99200.00
849907	2017-07-09 08:51:00+03	92800.00
849997	2017-08-04 10:19:00+03	288600.00
8499BD	2017-08-08 04:21:00+03	12600.00
849A5D	2017-08-09 06:36:00+03	19600.00
849AA7	2017-07-10 16:15:00+03	57600.00
849ABD	2017-08-05 05:31:00+03	27300.00
849AC2	2017-07-24 21:30:00+03	39600.00
849ADE	2017-08-03 00:14:00+03	10600.00
849B26	2017-08-02 23:52:00+03	75300.00
849CB4	2017-07-28 05:51:00+03	89700.00
849D14	2017-08-04 20:25:00+03	492000.00
849D28	2017-07-16 19:24:00+03	99300.00
849D5A	2017-07-11 12:19:00+03	167400.00
849D7B	2017-07-19 11:08:00+03	26700.00
849E0C	2017-07-03 15:10:00+03	29600.00
849E1E	2017-07-31 17:31:00+03	114700.00
849E27	2017-08-10 22:34:00+03	24200.00
849EE9	2017-08-03 23:33:00+03	60800.00
849F05	2017-07-29 20:34:00+03	111600.00
849F63	2017-07-30 20:42:00+03	85700.00
849FD2	2017-07-06 06:05:00+03	187600.00
84A035	2017-07-05 21:18:00+03	28000.00
84A05D	2017-07-21 22:13:00+03	119800.00
84A0AD	2017-07-09 03:14:00+03	47000.00
84A0BD	2017-07-12 07:55:00+03	30600.00
84A0CD	2017-08-03 06:56:00+03	83500.00
84A116	2017-08-11 09:14:00+03	83000.00
84A11C	2017-07-05 15:52:00+03	27400.00
84A147	2017-08-09 15:36:00+03	73600.00
84A153	2017-08-02 10:40:00+03	40600.00
84A184	2017-08-07 10:47:00+03	57400.00
84A19B	2017-08-11 20:57:00+03	155600.00
84A19D	2017-08-14 05:21:00+03	94400.00
84A1B8	2017-08-15 03:05:00+03	92800.00
84A1C4	2017-07-05 10:57:00+03	57500.00
84A1CD	2017-07-26 01:09:00+03	58000.00
84A1CE	2017-07-03 12:40:00+03	214000.00
84A1D1	2017-07-28 21:14:00+03	48700.00
84A1DB	2017-07-05 07:39:00+03	31000.00
84A226	2017-07-09 07:13:00+03	123200.00
84A228	2017-07-26 16:01:00+03	131600.00
84A23E	2017-08-11 12:02:00+03	266400.00
84A271	2017-07-26 04:17:00+03	25600.00
84A297	2017-08-06 12:27:00+03	112000.00
84A2C4	2017-08-10 02:25:00+03	418400.00
84A2C8	2017-08-11 02:37:00+03	136800.00
84A2F0	2017-07-30 01:46:00+03	99300.00
84A316	2017-07-04 16:06:00+03	189200.00
84A324	2017-07-29 15:52:00+03	46400.00
84A346	2017-07-14 19:06:00+03	131600.00
84A34D	2017-08-04 11:26:00+03	105500.00
84A358	2017-07-22 18:42:00+03	24800.00
84A365	2017-08-03 19:45:00+03	34000.00
84A43F	2017-07-09 00:22:00+03	27200.00
84A442	2017-07-25 22:08:00+03	150600.00
84A4C3	2017-07-04 03:18:00+03	82900.00
84A506	2017-07-29 14:10:00+03	91200.00
84A531	2017-08-08 02:17:00+03	170500.00
84A5AA	2017-07-14 20:10:00+03	20600.00
84A5D7	2017-07-31 22:20:00+03	36200.00
84A5DD	2017-07-27 05:17:00+03	40800.00
84A64A	2017-07-23 03:34:00+03	49100.00
84A694	2017-07-16 23:23:00+03	496700.00
84A6AB	2017-07-09 13:36:00+03	46500.00
84A6DA	2017-07-04 14:36:00+03	32800.00
84A748	2017-08-13 02:22:00+03	56100.00
84A765	2017-08-10 16:16:00+03	55600.00
84A776	2017-07-26 04:08:00+03	83000.00
84A7A2	2017-06-28 23:32:00+03	46400.00
84A822	2017-08-06 11:43:00+03	24700.00
84A82D	2017-08-02 05:48:00+03	27200.00
84A837	2017-08-06 07:59:00+03	59300.00
84A8A0	2017-07-21 17:57:00+03	196100.00
84A8C4	2017-06-28 05:23:00+03	46500.00
84A8D6	2017-07-27 16:21:00+03	24400.00
84A8D7	2017-06-30 04:58:00+03	58800.00
84A8DA	2017-08-09 02:43:00+03	59800.00
84A8DF	2017-07-19 03:36:00+03	14400.00
84A8E5	2017-08-14 23:09:00+03	139300.00
84A96D	2017-07-03 15:57:00+03	23900.00
84A983	2017-07-02 00:05:00+03	69900.00
84A9A8	2017-07-21 10:21:00+03	26700.00
84AA07	2017-08-06 04:01:00+03	123000.00
84AA66	2017-07-26 15:18:00+03	67500.00
84AA81	2017-07-16 00:16:00+03	44800.00
84AAA1	2017-07-16 12:04:00+03	16400.00
84AAA8	2017-07-05 21:13:00+03	31400.00
84AAD3	2017-07-13 10:41:00+03	34400.00
84AAE5	2017-07-24 15:40:00+03	138000.00
84AB12	2017-07-14 09:42:00+03	14400.00
84AB63	2017-07-21 13:21:00+03	45200.00
84ABA1	2017-07-01 14:03:00+03	353600.00
84ABAC	2017-07-14 08:12:00+03	65900.00
84AC60	2017-07-22 23:56:00+03	131900.00
84AC63	2017-07-22 12:10:00+03	99900.00
84AC89	2017-07-12 09:11:00+03	101200.00
84ACDB	2017-08-06 02:42:00+03	42800.00
84AD78	2017-08-12 13:31:00+03	33100.00
84ADD3	2017-07-06 23:39:00+03	125500.00
84ADF6	2017-07-28 16:04:00+03	12600.00
84AE10	2017-07-20 08:49:00+03	12400.00
84AE13	2017-07-22 14:47:00+03	36200.00
84AF30	2017-08-12 19:27:00+03	19600.00
84AF9E	2017-08-11 20:33:00+03	25100.00
84B004	2017-07-03 14:44:00+03	111600.00
84B0A0	2017-07-07 01:13:00+03	64700.00
84B110	2017-07-09 08:24:00+03	193600.00
84B12C	2017-07-03 14:40:00+03	124100.00
84B17E	2017-08-08 19:30:00+03	100600.00
84B18E	2017-07-29 04:36:00+03	93400.00
84B1C5	2017-08-07 19:57:00+03	24400.00
84B21A	2017-07-09 15:44:00+03	116400.00
84B229	2017-07-12 19:23:00+03	133900.00
84B244	2017-07-28 15:48:00+03	60900.00
84B284	2017-08-14 00:14:00+03	13400.00
84B299	2017-07-13 13:26:00+03	69000.00
84B3C1	2017-07-19 09:41:00+03	56000.00
84B40D	2017-08-02 11:23:00+03	38600.00
84B441	2017-07-20 11:24:00+03	19600.00
84B45F	2017-08-09 01:45:00+03	257500.00
84B4B8	2017-08-08 15:29:00+03	38400.00
84B4EA	2017-08-06 03:50:00+03	70200.00
84B508	2017-07-08 19:11:00+03	54400.00
84B64C	2017-08-07 15:10:00+03	296700.00
84B66E	2017-07-07 02:12:00+03	15900.00
84B6AE	2017-07-13 06:34:00+03	28000.00
84B6FA	2017-07-20 18:49:00+03	123000.00
84B73E	2017-07-13 16:40:00+03	6700.00
84B747	2017-08-11 02:44:00+03	63000.00
84B76D	2017-07-09 10:12:00+03	39400.00
84B798	2017-07-09 03:57:00+03	84100.00
84B7B6	2017-07-21 21:25:00+03	37900.00
84B817	2017-07-10 03:18:00+03	59200.00
84B81E	2017-07-20 05:07:00+03	6700.00
84B82C	2017-07-05 23:29:00+03	26200.00
84B836	2017-07-26 18:29:00+03	14000.00
84B850	2017-07-24 07:57:00+03	59300.00
84B887	2017-08-12 13:14:00+03	91500.00
84B959	2017-07-26 09:10:00+03	21800.00
84B95B	2017-07-16 02:29:00+03	92800.00
84B967	2017-07-11 23:09:00+03	41200.00
84B980	2017-07-30 00:04:00+03	62600.00
84B9D0	2017-07-04 14:01:00+03	372500.00
84BB7A	2017-08-06 15:29:00+03	50400.00
84BBD0	2017-07-04 22:38:00+03	38500.00
84BD3F	2017-06-30 15:20:00+03	271400.00
84BD4C	2017-07-23 04:14:00+03	26000.00
84BD8F	2017-07-08 04:21:00+03	7200.00
84BDC7	2017-06-28 16:23:00+03	7400.00
84BE3E	2017-07-29 01:05:00+03	31600.00
84BE49	2017-08-12 22:19:00+03	65900.00
84BE4B	2017-07-12 10:38:00+03	24400.00
84BEC0	2017-07-08 21:49:00+03	88600.00
84BED4	2017-07-25 03:13:00+03	9000.00
84BEE4	2017-08-08 09:22:00+03	58600.00
84BF26	2017-07-20 00:54:00+03	54800.00
84BF60	2017-07-21 20:01:00+03	68800.00
84BF73	2017-07-30 12:44:00+03	29800.00
84BFD7	2017-08-10 01:48:00+03	19600.00
84C058	2017-08-13 16:03:00+03	64300.00
84C062	2017-08-10 07:46:00+03	24700.00
84C078	2017-08-14 10:41:00+03	10600.00
84C08F	2017-07-27 17:25:00+03	43500.00
84C091	2017-07-27 18:47:00+03	13400.00
84C0C4	2017-07-20 17:15:00+03	399600.00
84C126	2017-07-06 00:29:00+03	47100.00
84C176	2017-07-02 11:05:00+03	112000.00
84C318	2017-07-05 10:34:00+03	135600.00
84C334	2017-07-12 02:21:00+03	136400.00
84C373	2017-07-09 07:46:00+03	387400.00
84C398	2017-07-06 10:23:00+03	134800.00
84C3B5	2017-08-03 19:35:00+03	12600.00
84C3F5	2017-07-17 08:59:00+03	137400.00
84C400	2017-07-30 17:33:00+03	18000.00
84C402	2017-07-25 18:01:00+03	7400.00
84C424	2017-07-18 15:22:00+03	136200.00
84C480	2017-07-29 08:49:00+03	25600.00
84C487	2017-07-02 18:49:00+03	406000.00
84C4A3	2017-07-22 04:45:00+03	45100.00
84C4BF	2017-07-04 23:56:00+03	6000.00
84C4CC	2017-07-07 12:58:00+03	26700.00
84C517	2017-07-25 21:05:00+03	65900.00
84C52E	2017-06-27 07:33:00+03	3700.00
84C59F	2017-08-15 11:00:00+03	132800.00
84C627	2017-08-11 18:25:00+03	69500.00
84C643	2017-07-18 06:51:00+03	46000.00
84C650	2017-07-19 18:32:00+03	14400.00
84C6B1	2017-06-29 20:34:00+03	19600.00
84C6C1	2017-07-24 15:50:00+03	156500.00
84C707	2017-08-10 20:51:00+03	56600.00
84C709	2017-07-25 17:11:00+03	34000.00
84C710	2017-07-07 13:55:00+03	90400.00
84C792	2017-07-23 23:37:00+03	49200.00
84C793	2017-06-28 21:19:00+03	23600.00
84C7BB	2017-07-27 20:20:00+03	58900.00
84C7CA	2017-07-01 08:04:00+03	65500.00
84C835	2017-07-22 12:14:00+03	81200.00
84C844	2017-08-10 02:02:00+03	24700.00
84C8D8	2017-07-16 17:08:00+03	6700.00
84C972	2017-07-11 21:08:00+03	88400.00
84C982	2017-08-07 05:56:00+03	28800.00
84C9D9	2017-07-02 17:44:00+03	61600.00
84C9FF	2017-08-14 05:59:00+03	34000.00
84CA2B	2017-07-12 11:47:00+03	23600.00
84CA36	2017-08-14 13:51:00+03	45200.00
84CA67	2017-07-23 22:42:00+03	369000.00
84CA87	2017-07-30 18:54:00+03	59800.00
84CAAA	2017-07-14 03:13:00+03	271200.00
84CB7D	2017-08-11 16:11:00+03	123000.00
84CBB0	2017-06-29 05:51:00+03	252200.00
84CBCF	2017-07-26 18:48:00+03	31400.00
84CC3B	2017-07-22 20:21:00+03	36200.00
84CC96	2017-07-26 06:19:00+03	118100.00
84CCA2	2017-07-21 04:39:00+03	93500.00
84CCCB	2017-07-08 06:51:00+03	112200.00
84CDAE	2017-08-05 03:34:00+03	37700.00
84CDDB	2017-07-09 13:21:00+03	88900.00
84CE09	2017-07-23 08:01:00+03	52800.00
84CE3A	2017-07-05 22:23:00+03	73600.00
84CE46	2017-08-14 20:59:00+03	12000.00
84CE79	2017-08-13 11:35:00+03	39200.00
84CEE0	2017-07-03 12:43:00+03	313400.00
84CF04	2017-07-24 21:57:00+03	23400.00
84CF0A	2017-08-09 07:34:00+03	27200.00
84CF42	2017-07-20 09:12:00+03	86400.00
84CF4A	2017-08-15 07:51:00+03	13400.00
84CF8D	2017-07-08 23:46:00+03	35200.00
84CF99	2017-07-13 23:45:00+03	51200.00
84CFA8	2017-07-21 06:20:00+03	23200.00
84D00A	2017-07-21 02:38:00+03	45200.00
84D02A	2017-07-16 14:34:00+03	6700.00
84D0B3	2017-07-30 17:41:00+03	26800.00
84D23F	2017-07-26 10:15:00+03	258600.00
84D241	2017-07-19 13:41:00+03	38600.00
84D261	2017-08-11 07:18:00+03	48500.00
84D279	2017-08-12 13:41:00+03	31100.00
84D290	2017-08-07 10:53:00+03	66600.00
84D29A	2017-08-07 13:26:00+03	11600.00
84D346	2017-07-13 23:17:00+03	95900.00
84D3C2	2017-07-20 09:24:00+03	146300.00
84D429	2017-06-29 03:59:00+03	58000.00
84D46A	2017-06-30 23:43:00+03	66600.00
84D46D	2017-07-12 11:05:00+03	67400.00
84D481	2017-08-04 23:25:00+03	28000.00
84D485	2017-07-17 06:44:00+03	31600.00
84D4B4	2017-08-03 14:40:00+03	53700.00
84D4D1	2017-07-09 04:13:00+03	132300.00
84D4F3	2017-07-30 07:54:00+03	122300.00
84D52F	2017-08-01 03:55:00+03	70700.00
84D56E	2017-07-06 18:13:00+03	162600.00
84D5B3	2017-07-14 11:41:00+03	67200.00
84D5E1	2017-07-10 00:44:00+03	270800.00
84D616	2017-07-12 18:31:00+03	167400.00
84D71C	2017-08-10 20:11:00+03	89600.00
84D762	2017-08-14 17:43:00+03	50600.00
84D770	2017-07-09 23:19:00+03	103600.00
84D7B4	2017-08-06 17:18:00+03	56000.00
84D7DD	2017-08-09 23:18:00+03	120200.00
84D7F2	2017-07-16 10:17:00+03	133200.00
84D9CF	2017-07-22 03:09:00+03	99300.00
84DA03	2017-08-10 04:59:00+03	124200.00
84DA3D	2017-08-02 21:23:00+03	67600.00
84DA5A	2017-07-30 01:03:00+03	52300.00
84DA8C	2017-07-21 15:57:00+03	206400.00
84DB48	2017-07-15 22:45:00+03	53300.00
84DBD0	2017-07-28 00:51:00+03	47600.00
84DC05	2017-07-23 04:18:00+03	56600.00
84DCB5	2017-08-14 11:02:00+03	47600.00
84DCCB	2017-07-23 12:03:00+03	46400.00
84DCD1	2017-07-09 16:17:00+03	189200.00
84DD0C	2017-08-02 13:32:00+03	111600.00
84DD38	2017-07-27 19:34:00+03	303900.00
84DD49	2017-07-27 09:36:00+03	75800.00
84DD9C	2017-07-22 20:59:00+03	43200.00
84DE05	2017-08-03 08:22:00+03	167400.00
84DE5B	2017-07-11 14:46:00+03	29100.00
84DF2F	2017-07-10 09:39:00+03	21400.00
84DF99	2017-07-23 11:34:00+03	166100.00
84DFAA	2017-07-03 19:45:00+03	121400.00
84E031	2017-07-02 12:05:00+03	46000.00
84E053	2017-07-24 20:28:00+03	66600.00
84E05D	2017-07-03 12:47:00+03	369000.00
84E0D6	2017-08-12 23:45:00+03	21600.00
84E0F0	2017-07-12 09:37:00+03	215200.00
84E14F	2017-07-16 13:34:00+03	14000.00
84E1C1	2017-07-02 02:57:00+03	36200.00
84E1EE	2017-07-30 20:38:00+03	89600.00
84E21C	2017-08-01 09:25:00+03	49100.00
84E26C	2017-07-09 02:32:00+03	57600.00
84E284	2017-07-09 02:58:00+03	62500.00
84E2BE	2017-07-30 19:23:00+03	257500.00
84E317	2017-08-01 11:42:00+03	272400.00
84E36E	2017-07-10 14:28:00+03	186900.00
84E3C0	2017-07-09 10:52:00+03	12600.00
84E404	2017-07-02 08:14:00+03	32700.00
84E432	2017-07-14 16:39:00+03	86300.00
84E45D	2017-06-30 16:39:00+03	76800.00
84E47E	2017-08-04 15:21:00+03	14800.00
84E484	2017-08-10 23:41:00+03	131100.00
84E489	2017-07-29 08:02:00+03	38800.00
84E4A1	2017-08-14 18:18:00+03	46400.00
84E515	2017-08-06 22:53:00+03	21800.00
84E530	2017-07-15 20:05:00+03	96800.00
84E548	2017-07-27 23:30:00+03	27200.00
84E54D	2017-08-11 08:52:00+03	16400.00
84E600	2017-07-12 09:41:00+03	166000.00
84E69A	2017-08-03 05:16:00+03	32200.00
84E6A5	2017-08-07 16:34:00+03	23600.00
84E732	2017-07-16 01:18:00+03	88600.00
84E74E	2017-08-15 11:50:00+03	121100.00
84E7AD	2017-07-13 21:17:00+03	24200.00
84E7E2	2017-08-03 14:42:00+03	139100.00
84E822	2017-08-02 12:25:00+03	75600.00
84E8A1	2017-07-30 05:01:00+03	96200.00
84E8C5	2017-08-02 13:20:00+03	81300.00
84E902	2017-08-09 08:27:00+03	14400.00
84E990	2017-08-01 14:32:00+03	44700.00
84E9AB	2017-07-08 08:12:00+03	46400.00
84E9B6	2017-08-04 06:11:00+03	28800.00
84EA1D	2017-07-25 12:21:00+03	246000.00
84EA98	2017-08-15 11:02:00+03	115900.00
84EAF1	2017-08-02 06:12:00+03	91700.00
84EB3D	2017-07-15 17:14:00+03	36200.00
84EB47	2017-07-22 11:53:00+03	196800.00
84EB5B	2017-06-30 04:40:00+03	132000.00
84EBFA	2017-07-31 00:12:00+03	23200.00
84EC07	2017-07-01 00:47:00+03	129200.00
84EC09	2017-07-17 14:37:00+03	80500.00
84EC48	2017-08-02 18:38:00+03	56900.00
84ECD5	2017-08-15 16:43:00+03	84500.00
84ED70	2017-08-13 08:52:00+03	28300.00
84EDF7	2017-07-25 10:13:00+03	46400.00
84EE02	2017-07-25 16:09:00+03	52700.00
84EE0F	2017-07-11 20:19:00+03	36400.00
84EE62	2017-07-17 05:06:00+03	38600.00
84EEE6	2017-07-27 15:37:00+03	52200.00
84EF16	2017-07-02 01:50:00+03	273600.00
84EF41	2017-08-11 06:18:00+03	179500.00
84EF48	2017-07-25 04:51:00+03	35700.00
84F002	2017-07-10 08:13:00+03	14400.00
84F01F	2017-06-30 03:25:00+03	39200.00
84F03F	2017-07-01 08:52:00+03	22000.00
84F0F6	2017-07-09 05:12:00+03	120100.00
84F10F	2017-08-12 04:58:00+03	42700.00
84F18B	2017-07-12 13:21:00+03	89600.00
84F190	2017-07-13 17:39:00+03	14800.00
84F1A1	2017-07-08 20:22:00+03	113800.00
84F252	2017-07-11 03:27:00+03	31600.00
84F259	2017-08-15 15:52:00+03	18600.00
84F2B5	2017-07-27 04:00:00+03	240500.00
84F2D0	2017-07-09 06:03:00+03	16400.00
84F2D5	2017-08-14 03:06:00+03	112600.00
84F31B	2017-08-09 23:12:00+03	80000.00
84F389	2017-07-15 05:42:00+03	28800.00
84F419	2017-08-12 22:17:00+03	29600.00
84F4D8	2017-08-11 07:28:00+03	22000.00
84F4EA	2017-07-20 08:01:00+03	47100.00
84F50B	2017-07-29 09:09:00+03	88100.00
84F518	2017-07-05 01:04:00+03	102800.00
84F598	2017-08-15 13:10:00+03	81200.00
84F5A3	2017-07-15 16:49:00+03	16400.00
84F5D0	2017-07-31 23:03:00+03	95700.00
84F5D3	2017-07-09 18:32:00+03	22600.00
84F61E	2017-07-17 17:56:00+03	28000.00
84F674	2017-08-07 20:15:00+03	133200.00
84F703	2017-07-08 03:45:00+03	48400.00
84F70F	2017-07-04 02:35:00+03	56000.00
84F716	2017-08-15 16:31:00+03	114300.00
84F742	2017-07-29 04:29:00+03	419800.00
84F7F5	2017-07-02 18:14:00+03	93000.00
84F7FA	2017-07-27 07:28:00+03	58600.00
84F868	2017-07-20 23:41:00+03	147100.00
84F8E3	2017-07-26 12:25:00+03	67400.00
84F917	2017-07-07 04:51:00+03	50800.00
84F934	2017-07-10 00:47:00+03	98300.00
84F9CF	2017-07-31 03:50:00+03	13700.00
84F9D0	2017-08-02 05:00:00+03	315200.00
84FA71	2017-07-19 11:08:00+03	26800.00
84FA75	2017-07-07 12:53:00+03	18800.00
84FA95	2017-08-12 18:54:00+03	86600.00
84FAC0	2017-07-14 20:48:00+03	53700.00
84FB2C	2017-08-14 10:54:00+03	62800.00
84FB48	2017-07-04 21:05:00+03	34800.00
84FB78	2017-08-09 10:25:00+03	28800.00
84FBF0	2017-07-26 14:20:00+03	43000.00
84FC18	2017-07-28 02:30:00+03	55800.00
84FC29	2017-07-10 15:18:00+03	66800.00
84FC64	2017-07-21 04:33:00+03	29600.00
84FC74	2017-07-02 16:52:00+03	101100.00
84FC82	2017-07-15 21:03:00+03	199700.00
84FC91	2017-07-28 23:49:00+03	15700.00
84FCB1	2017-08-06 18:07:00+03	60200.00
84FCED	2017-08-04 17:03:00+03	74300.00
84FD1C	2017-06-30 23:22:00+03	16400.00
84FD42	2017-07-31 06:56:00+03	79600.00
84FD81	2017-06-30 11:33:00+03	254900.00
84FDB2	2017-07-05 07:43:00+03	273600.00
84FE31	2017-07-18 08:50:00+03	12400.00
84FE5A	2017-07-13 15:29:00+03	26000.00
84FE9F	2017-07-12 03:45:00+03	206400.00
84FEDA	2017-07-29 05:40:00+03	48900.00
84FEDF	2017-07-30 20:52:00+03	70600.00
84FEE7	2017-07-04 15:30:00+03	64800.00
84FF51	2017-07-24 00:39:00+03	115300.00
850037	2017-08-02 05:18:00+03	23200.00
85008A	2017-08-11 07:27:00+03	8400.00
850098	2017-07-20 22:21:00+03	128100.00
8500AE	2017-07-21 17:56:00+03	117200.00
8500C8	2017-07-02 14:20:00+03	70700.00
8500E1	2017-08-06 11:15:00+03	38600.00
85010D	2017-07-16 16:44:00+03	28000.00
850138	2017-07-31 13:54:00+03	29800.00
850172	2017-08-06 03:43:00+03	37700.00
85017A	2017-07-13 07:02:00+03	18000.00
85019B	2017-07-29 23:27:00+03	12400.00
8501C0	2017-08-04 06:48:00+03	36100.00
8501F9	2017-07-20 23:45:00+03	23200.00
850245	2017-08-11 13:29:00+03	10800.00
850277	2017-07-06 15:54:00+03	75300.00
85027B	2017-08-06 20:52:00+03	46300.00
85027D	2017-07-01 15:00:00+03	59300.00
85029F	2017-08-09 18:45:00+03	73800.00
8502A7	2017-07-18 12:36:00+03	139400.00
8502EE	2017-07-29 01:15:00+03	42800.00
8502F7	2017-07-29 11:33:00+03	55800.00
850316	2017-07-05 22:50:00+03	65900.00
850325	2017-07-30 02:32:00+03	28800.00
85032B	2017-08-15 04:19:00+03	26000.00
850352	2017-07-07 08:59:00+03	113800.00
850361	2017-08-06 03:32:00+03	83000.00
850367	2017-08-11 23:46:00+03	25100.00
85040F	2017-07-28 22:24:00+03	46000.00
85048D	2017-07-28 06:21:00+03	174400.00
850532	2017-07-04 23:35:00+03	67600.00
850599	2017-08-11 07:15:00+03	51800.00
8505B9	2017-08-05 22:01:00+03	21400.00
8505CC	2017-07-24 16:08:00+03	47100.00
850629	2017-07-13 03:50:00+03	26200.00
85063A	2017-07-08 22:32:00+03	35400.00
850683	2017-07-06 15:02:00+03	94800.00
8506C2	2017-07-10 04:11:00+03	118100.00
8506C8	2017-07-28 13:50:00+03	31600.00
850706	2017-07-11 23:53:00+03	117900.00
85070C	2017-08-08 09:24:00+03	78300.00
850735	2017-08-08 22:27:00+03	28000.00
85078E	2017-07-08 08:46:00+03	156500.00
850795	2017-06-29 15:05:00+03	24400.00
8507B1	2017-07-31 14:06:00+03	16400.00
8507FB	2017-06-30 11:34:00+03	46000.00
850814	2017-08-14 21:15:00+03	119800.00
8508F6	2017-07-31 16:12:00+03	73600.00
850908	2017-07-29 01:27:00+03	33800.00
850932	2017-07-18 18:11:00+03	46900.00
85096D	2017-07-08 18:50:00+03	11600.00
850984	2017-08-09 02:06:00+03	29800.00
85099E	2017-07-26 18:00:00+03	271100.00
850A07	2017-08-10 12:39:00+03	15000.00
850A77	2017-07-25 21:17:00+03	48800.00
850AB4	2017-07-06 06:56:00+03	167400.00
850AC8	2017-08-09 00:27:00+03	178800.00
850AD7	2017-08-12 06:52:00+03	26600.00
850B96	2017-06-30 03:04:00+03	270000.00
850BF1	2017-08-01 22:16:00+03	94700.00
850BF2	2017-07-22 06:39:00+03	171900.00
850C97	2017-07-05 05:33:00+03	111700.00
850CAD	2017-08-08 05:30:00+03	57300.00
850CB8	2017-07-16 19:15:00+03	35200.00
850CFE	2017-08-13 05:43:00+03	92000.00
850D12	2017-08-03 03:55:00+03	46400.00
850D34	2017-08-13 07:12:00+03	77000.00
850D3A	2017-07-15 04:30:00+03	55800.00
850D9A	2017-07-03 08:46:00+03	48800.00
850DC3	2017-07-28 06:44:00+03	394000.00
850E44	2017-08-12 07:18:00+03	75800.00
850E77	2017-07-30 12:28:00+03	23600.00
850EC6	2017-08-01 13:52:00+03	25600.00
850EDF	2017-07-14 00:00:00+03	175300.00
850F37	2017-08-12 21:20:00+03	12600.00
850F54	2017-08-07 15:07:00+03	75300.00
850F9A	2017-07-27 01:28:00+03	66600.00
850FC7	2017-07-17 23:38:00+03	58800.00
85106C	2017-07-29 15:01:00+03	58200.00
851097	2017-08-11 04:48:00+03	9200.00
851105	2017-07-17 04:31:00+03	50200.00
851114	2017-07-20 22:46:00+03	75600.00
85115F	2017-08-10 01:00:00+03	38800.00
851167	2017-07-08 20:06:00+03	48300.00
8511B5	2017-07-24 05:23:00+03	60400.00
8511D7	2017-07-10 03:43:00+03	118300.00
8511EF	2017-07-06 10:10:00+03	270000.00
8511F2	2017-07-05 23:12:00+03	45200.00
8511F8	2017-07-14 07:37:00+03	89600.00
851259	2017-07-28 14:27:00+03	433400.00
85128A	2017-07-10 04:00:00+03	154800.00
85128D	2017-06-27 06:12:00+03	17800.00
8512AD	2017-07-24 20:26:00+03	88600.00
8512D3	2017-07-29 17:14:00+03	27800.00
851309	2017-07-22 06:08:00+03	20400.00
85131C	2017-07-17 04:32:00+03	57900.00
85136D	2017-07-17 13:00:00+03	39800.00
851419	2017-08-10 05:37:00+03	57100.00
85142E	2017-06-27 02:23:00+03	71900.00
851433	2017-07-11 04:45:00+03	11700.00
85145C	2017-08-13 07:56:00+03	167400.00
851488	2017-08-01 06:48:00+03	46400.00
8514EF	2017-07-28 03:26:00+03	59800.00
851502	2017-07-10 07:01:00+03	22000.00
85150F	2017-07-24 08:40:00+03	43900.00
85151D	2017-07-05 23:29:00+03	114500.00
851542	2017-08-05 14:17:00+03	6300.00
851553	2017-08-13 10:40:00+03	79000.00
851594	2017-07-19 15:52:00+03	135000.00
8515C5	2017-07-24 04:15:00+03	12900.00
851614	2017-07-24 11:35:00+03	56000.00
851616	2017-07-19 06:17:00+03	97900.00
85162D	2017-07-18 10:27:00+03	31400.00
8516C7	2017-07-22 10:09:00+03	136100.00
8516D5	2017-07-25 00:31:00+03	30200.00
851705	2017-08-04 12:18:00+03	62600.00
8517F2	2017-08-03 05:28:00+03	26700.00
85183A	2017-08-13 07:41:00+03	243300.00
851864	2017-07-07 13:04:00+03	96800.00
851875	2017-07-16 03:47:00+03	24800.00
851878	2017-08-04 02:01:00+03	15000.00
851889	2017-07-09 12:07:00+03	10600.00
8518DE	2017-07-27 20:38:00+03	332200.00
8518F4	2017-08-04 19:36:00+03	109600.00
8518F5	2017-07-18 00:57:00+03	82000.00
851934	2017-07-02 12:27:00+03	61800.00
851974	2017-07-05 21:12:00+03	32700.00
851A0F	2017-06-29 19:51:00+03	30400.00
851A54	2017-07-09 04:24:00+03	26000.00
851A5A	2017-08-13 15:00:00+03	218800.00
851AAE	2017-07-22 16:30:00+03	114500.00
851ABE	2017-08-12 16:41:00+03	24400.00
851B1C	2017-07-31 17:53:00+03	199700.00
851B52	2017-07-30 12:45:00+03	31000.00
851B8F	2017-07-30 23:49:00+03	46000.00
851D74	2017-07-09 08:19:00+03	36400.00
851D93	2017-07-18 18:06:00+03	29600.00
851DA2	2017-07-07 19:42:00+03	7400.00
851DBE	2017-07-13 03:04:00+03	94000.00
851E20	2017-08-03 06:57:00+03	406800.00
851E84	2017-08-14 20:49:00+03	58400.00
851E8D	2017-07-22 16:29:00+03	77200.00
851E8F	2017-06-29 14:41:00+03	102100.00
851EDE	2017-07-03 05:43:00+03	113200.00
851EE4	2017-07-28 06:11:00+03	9200.00
851F0A	2017-08-09 21:40:00+03	79600.00
851F63	2017-07-03 23:28:00+03	92100.00
851F84	2017-07-23 07:14:00+03	282100.00
851F88	2017-08-12 18:24:00+03	13400.00
851F8D	2017-08-02 09:09:00+03	270800.00
851F9C	2017-07-16 07:21:00+03	46200.00
851FB6	2017-07-01 12:35:00+03	48300.00
8520A4	2017-07-12 05:39:00+03	72800.00
85216A	2017-07-22 07:06:00+03	218400.00
8521D5	2017-07-17 01:31:00+03	123000.00
8521EB	2017-07-30 04:31:00+03	75600.00
8521F6	2017-08-13 06:37:00+03	56000.00
852260	2017-07-17 11:01:00+03	52100.00
852266	2017-07-23 07:18:00+03	52700.00
852287	2017-06-30 20:22:00+03	47200.00
8522DF	2017-07-17 07:25:00+03	11800.00
8522FB	2017-08-03 06:19:00+03	147100.00
852305	2017-07-10 20:05:00+03	114800.00
85232A	2017-07-06 21:57:00+03	14400.00
852334	2017-07-06 12:36:00+03	181600.00
85237E	2017-07-05 09:52:00+03	134700.00
8523DE	2017-07-12 13:57:00+03	6700.00
85240F	2017-08-12 16:24:00+03	53100.00
852473	2017-07-18 19:02:00+03	23200.00
852492	2017-06-30 15:06:00+03	86500.00
8524B8	2017-07-12 19:26:00+03	28800.00
8524D1	2017-07-17 10:43:00+03	166400.00
852521	2017-07-21 22:09:00+03	44600.00
8525B1	2017-07-16 18:18:00+03	43900.00
8525F3	2017-07-29 20:45:00+03	33300.00
852602	2017-07-25 03:06:00+03	40800.00
85264C	2017-07-22 10:14:00+03	39200.00
852656	2017-07-03 15:14:00+03	193600.00
8526FC	2017-08-03 17:21:00+03	348800.00
8526FE	2017-07-20 13:20:00+03	55800.00
85271D	2017-06-30 00:12:00+03	59900.00
8527A3	2017-07-29 05:04:00+03	114400.00
852817	2017-08-06 13:19:00+03	122800.00
852870	2017-07-07 11:03:00+03	89600.00
8528A7	2017-08-07 11:38:00+03	28800.00
8528C5	2017-07-15 22:54:00+03	40300.00
8528EC	2017-07-05 07:19:00+03	257500.00
852913	2017-07-02 22:02:00+03	89700.00
852974	2017-08-05 19:49:00+03	68000.00
8529AD	2017-07-25 18:42:00+03	56000.00
852A8D	2017-07-03 10:28:00+03	66600.00
852B1C	2017-07-05 13:51:00+03	33100.00
852B36	2017-07-20 17:30:00+03	112000.00
852B5E	2017-07-08 08:16:00+03	31000.00
852BA6	2017-07-01 22:05:00+03	46800.00
852C15	2017-07-01 02:24:00+03	41800.00
852C1F	2017-07-16 21:42:00+03	56000.00
852CA4	2017-07-11 05:17:00+03	29600.00
852D24	2017-07-03 13:54:00+03	6700.00
852D5F	2017-08-11 14:00:00+03	160800.00
852D7E	2017-07-31 18:01:00+03	46000.00
852DB4	2017-07-08 07:44:00+03	50100.00
852E5F	2017-08-09 01:07:00+03	30000.00
852E63	2017-07-09 22:08:00+03	43500.00
852E81	2017-07-04 21:00:00+03	23600.00
852F23	2017-07-06 19:00:00+03	12400.00
852FB0	2017-08-08 16:16:00+03	113700.00
852FC9	2017-07-12 06:29:00+03	55600.00
853062	2017-07-24 20:27:00+03	6800.00
853103	2017-08-09 12:45:00+03	25600.00
85313E	2017-07-06 06:22:00+03	53300.00
85317F	2017-07-13 13:56:00+03	19600.00
853189	2017-07-13 19:05:00+03	83300.00
8531AC	2017-07-27 06:27:00+03	43200.00
8531AD	2017-07-11 03:05:00+03	41600.00
85324C	2017-08-15 16:13:00+03	12400.00
85328F	2017-08-10 20:05:00+03	73900.00
85329C	2017-07-06 11:21:00+03	44000.00
8532AC	2017-07-22 03:36:00+03	47000.00
8532B3	2017-08-15 14:32:00+03	13400.00
8532BF	2017-07-02 11:25:00+03	39800.00
853307	2017-07-26 15:42:00+03	79900.00
853314	2017-07-08 06:32:00+03	47000.00
8533A2	2017-07-08 07:45:00+03	48400.00
8533D5	2017-08-09 20:58:00+03	66600.00
853466	2017-07-22 16:25:00+03	29200.00
853483	2017-07-23 16:25:00+03	40800.00
853499	2017-07-27 23:32:00+03	179200.00
8534B1	2017-06-27 20:11:00+03	89600.00
8534E8	2017-07-19 09:10:00+03	24800.00
8534FA	2017-08-03 13:28:00+03	406700.00
85359C	2017-07-03 04:22:00+03	105000.00
853615	2017-07-27 00:21:00+03	21400.00
85364F	2017-08-05 22:34:00+03	185000.00
8536B1	2017-07-09 11:13:00+03	28800.00
8536CB	2017-08-11 05:33:00+03	75300.00
853707	2017-07-06 01:23:00+03	91500.00
853761	2017-07-04 11:34:00+03	84800.00
85376D	2017-07-30 17:57:00+03	94000.00
8537B7	2017-08-01 08:57:00+03	93600.00
8537C7	2017-07-26 16:20:00+03	50600.00
8537C9	2017-07-08 04:38:00+03	184500.00
85382F	2017-07-16 22:36:00+03	46800.00
853838	2017-07-21 00:08:00+03	541500.00
853841	2017-07-25 09:29:00+03	28000.00
853879	2017-07-15 04:09:00+03	20200.00
85388C	2017-08-04 08:52:00+03	56000.00
8538DA	2017-07-31 17:56:00+03	6000.00
8538DD	2017-07-21 23:23:00+03	202400.00
8538FA	2017-08-06 08:33:00+03	28000.00
853934	2017-08-10 00:28:00+03	170000.00
853968	2017-08-07 07:27:00+03	10800.00
853979	2017-07-21 10:38:00+03	62000.00
8539C6	2017-07-24 01:03:00+03	79000.00
853A0C	2017-08-04 02:32:00+03	76700.00
853A2A	2017-07-13 07:14:00+03	27200.00
853ABC	2017-08-04 05:38:00+03	96100.00
853B1C	2017-08-15 13:04:00+03	52000.00
853B28	2017-06-29 06:56:00+03	258000.00
853B3B	2017-08-14 08:54:00+03	24400.00
853BD3	2017-08-04 10:03:00+03	119700.00
853BE9	2017-07-13 00:28:00+03	38800.00
853C90	2017-07-24 02:35:00+03	44500.00
853CBD	2017-08-10 12:13:00+03	48700.00
853CC4	2017-07-03 07:58:00+03	15000.00
853CE5	2017-07-15 23:02:00+03	6300.00
853D04	2017-07-30 15:35:00+03	97600.00
853D31	2017-08-11 03:40:00+03	142800.00
853D92	2017-07-18 15:25:00+03	12600.00
853DDE	2017-08-06 00:46:00+03	125700.00
853E28	2017-07-30 14:09:00+03	21400.00
853E78	2017-07-13 16:53:00+03	39800.00
853E7F	2017-08-10 20:28:00+03	85000.00
853F12	2017-08-03 15:46:00+03	41600.00
853F43	2017-07-19 14:16:00+03	32800.00
853F8B	2017-07-11 21:40:00+03	219300.00
853FA8	2017-07-15 22:05:00+03	142400.00
853FD7	2017-07-15 19:13:00+03	129500.00
854091	2017-08-11 12:12:00+03	38400.00
8540EA	2017-07-23 09:14:00+03	122400.00
8540FB	2017-07-19 20:46:00+03	23400.00
85414B	2017-08-05 14:45:00+03	44500.00
854154	2017-08-02 06:28:00+03	109200.00
8541BD	2017-08-11 21:58:00+03	35200.00
85421A	2017-08-04 23:10:00+03	6000.00
854268	2017-08-03 11:29:00+03	66600.00
85428A	2017-08-08 06:33:00+03	28000.00
8543D7	2017-07-29 13:13:00+03	46400.00
8543FC	2017-07-20 06:45:00+03	246000.00
854413	2017-08-02 05:08:00+03	34000.00
854459	2017-07-24 19:02:00+03	8200.00
85450D	2017-07-19 16:26:00+03	26700.00
854576	2017-07-28 23:28:00+03	44600.00
854596	2017-08-13 21:46:00+03	45200.00
85461A	2017-08-09 10:11:00+03	78100.00
8546F8	2017-08-04 20:49:00+03	28800.00
854748	2017-08-13 05:50:00+03	66000.00
854782	2017-08-04 03:37:00+03	77200.00
8547BE	2017-06-30 18:55:00+03	18600.00
8547BF	2017-07-16 22:17:00+03	257600.00
8547C4	2017-07-23 07:26:00+03	20400.00
8547E7	2017-07-02 13:26:00+03	50200.00
8547EE	2017-07-25 02:41:00+03	59800.00
854846	2017-07-21 17:58:00+03	109600.00
8548D6	2017-07-06 05:48:00+03	100600.00
8548F8	2017-08-09 06:00:00+03	61800.00
854902	2017-08-11 22:40:00+03	40800.00
854936	2017-07-28 16:24:00+03	133100.00
854960	2017-07-14 01:11:00+03	66100.00
854991	2017-07-23 22:54:00+03	34800.00
8549C3	2017-08-15 13:45:00+03	46000.00
854A34	2017-07-13 14:17:00+03	65900.00
854A89	2017-07-18 23:14:00+03	27800.00
854ABF	2017-07-22 12:13:00+03	26700.00
854AF0	2017-07-17 10:10:00+03	61800.00
854B23	2017-08-12 01:27:00+03	128300.00
854BD7	2017-06-28 12:25:00+03	162500.00
854C4C	2017-06-26 06:52:00+03	46700.00
854C98	2017-07-07 21:13:00+03	17000.00
854CF0	2017-07-09 16:21:00+03	13200.00
854D02	2017-08-03 23:34:00+03	56000.00
854D7F	2017-07-29 18:17:00+03	100200.00
854E0A	2017-08-06 03:52:00+03	49900.00
854E24	2017-08-12 17:46:00+03	97900.00
854E2A	2017-08-15 13:45:00+03	36200.00
854E8B	2017-07-28 10:22:00+03	257600.00
854E9D	2017-07-25 00:28:00+03	16400.00
85502E	2017-06-30 15:41:00+03	75600.00
855066	2017-07-15 16:51:00+03	66800.00
85517C	2017-07-29 08:41:00+03	544600.00
8551D3	2017-07-05 15:37:00+03	20600.00
8551E8	2017-07-06 08:08:00+03	75800.00
85522D	2017-07-23 05:55:00+03	23200.00
85523B	2017-08-09 11:07:00+03	47400.00
855279	2017-08-10 19:38:00+03	23600.00
85528E	2017-07-08 15:33:00+03	105000.00
8552BB	2017-08-06 04:55:00+03	67600.00
8552D0	2017-07-13 16:26:00+03	124200.00
8553C7	2017-06-30 02:29:00+03	105600.00
85541A	2017-08-15 14:31:00+03	28800.00
85541F	2017-08-06 04:53:00+03	285700.00
855439	2017-08-09 13:58:00+03	111700.00
855449	2017-07-25 22:26:00+03	189800.00
855464	2017-08-01 11:28:00+03	38600.00
855480	2017-08-04 01:26:00+03	246000.00
8554DD	2017-08-03 12:43:00+03	108500.00
85553F	2017-06-25 14:29:00+03	55800.00
85555C	2017-08-08 05:54:00+03	55800.00
85558E	2017-08-14 10:38:00+03	35600.00
8555C3	2017-07-03 14:10:00+03	30700.00
8555E3	2017-07-20 10:15:00+03	108200.00
855606	2017-08-05 18:46:00+03	46000.00
855662	2017-06-28 20:57:00+03	27600.00
855665	2017-08-15 02:11:00+03	88100.00
85566D	2017-07-14 18:53:00+03	77400.00
855739	2017-07-18 11:59:00+03	37900.00
8557FE	2017-08-01 23:49:00+03	38800.00
855800	2017-07-27 10:38:00+03	65500.00
8558B1	2017-07-12 14:01:00+03	16400.00
8558C3	2017-07-02 20:26:00+03	61500.00
855989	2017-07-16 10:21:00+03	22000.00
8559D1	2017-08-08 23:48:00+03	136500.00
8559D6	2017-07-26 13:43:00+03	67700.00
855A1C	2017-08-10 19:47:00+03	25200.00
855A39	2017-07-29 00:11:00+03	123000.00
855A5B	2017-07-06 18:34:00+03	205600.00
855ACE	2017-07-08 04:32:00+03	46400.00
855AFB	2017-08-12 17:07:00+03	42800.00
855B34	2017-08-13 12:46:00+03	25100.00
855B46	2017-07-02 06:31:00+03	68100.00
855BB5	2017-07-30 20:38:00+03	86800.00
855C2D	2017-07-10 11:34:00+03	56000.00
855C39	2017-07-11 04:18:00+03	40600.00
855D5A	2017-07-02 10:11:00+03	432200.00
855D71	2017-07-02 11:44:00+03	56000.00
855D76	2017-07-08 05:59:00+03	47200.00
855DE2	2017-07-17 22:56:00+03	56000.00
855E34	2017-07-27 19:39:00+03	73100.00
855E43	2017-07-29 07:12:00+03	172800.00
855F32	2017-07-13 14:57:00+03	20200.00
855F67	2017-07-04 07:37:00+03	37900.00
856001	2017-08-09 11:29:00+03	22000.00
856024	2017-07-30 07:14:00+03	13600.00
856056	2017-07-05 21:46:00+03	90000.00
856069	2017-08-01 09:24:00+03	65900.00
856075	2017-08-03 02:33:00+03	25600.00
8560F7	2017-08-05 18:19:00+03	186900.00
8560FD	2017-08-15 10:48:00+03	45300.00
856108	2017-07-19 11:27:00+03	50600.00
856229	2017-07-31 02:06:00+03	31000.00
856285	2017-07-02 13:43:00+03	215500.00
8562FD	2017-08-05 23:45:00+03	173600.00
85630F	2017-08-01 00:06:00+03	305800.00
856362	2017-07-31 18:56:00+03	156300.00
856375	2017-07-27 18:29:00+03	53600.00
85639B	2017-07-10 05:35:00+03	60600.00
8563A8	2017-07-29 04:39:00+03	148900.00
8563D6	2017-08-03 00:44:00+03	12100.00
856475	2017-08-12 06:07:00+03	32700.00
8564FE	2017-07-07 22:38:00+03	28000.00
856573	2017-07-03 02:29:00+03	27000.00
8565B3	2017-08-06 02:36:00+03	23200.00
8565FC	2017-07-10 09:02:00+03	46000.00
856665	2017-07-16 19:21:00+03	56000.00
8566C1	2017-07-13 12:26:00+03	7400.00
8566F4	2017-07-17 13:25:00+03	366600.00
856726	2017-08-15 00:22:00+03	62000.00
85675F	2017-07-02 19:32:00+03	15100.00
856763	2017-08-09 16:11:00+03	62800.00
8567C8	2017-07-29 09:21:00+03	273000.00
8567E7	2017-07-31 23:41:00+03	22200.00
8567F7	2017-07-05 16:41:00+03	121300.00
85681D	2017-07-11 14:08:00+03	20000.00
856886	2017-07-28 01:54:00+03	246000.00
8568BD	2017-08-11 13:13:00+03	57600.00
85690D	2017-07-19 11:21:00+03	39500.00
85691F	2017-07-10 18:14:00+03	28000.00
856952	2017-08-13 22:13:00+03	32700.00
856997	2017-07-25 15:08:00+03	101200.00
856A01	2017-07-21 20:28:00+03	17200.00
856A05	2017-07-28 00:50:00+03	258400.00
856A27	2017-07-02 05:51:00+03	33600.00
856A29	2017-08-15 03:35:00+03	21400.00
856A67	2017-07-24 17:23:00+03	29000.00
856AC9	2017-07-04 08:52:00+03	77900.00
856B2D	2017-07-12 08:29:00+03	18600.00
856B3F	2017-08-11 03:54:00+03	34000.00
856B46	2017-07-18 08:59:00+03	393000.00
856B82	2017-07-31 20:58:00+03	7400.00
856B9D	2017-06-30 10:03:00+03	25400.00
856BB2	2017-07-02 01:38:00+03	135600.00
856C02	2017-07-08 13:52:00+03	78200.00
856CAC	2017-07-31 22:53:00+03	94100.00
856D58	2017-07-26 18:30:00+03	14400.00
856EEC	2017-08-15 04:24:00+03	46000.00
856EF4	2017-07-07 01:55:00+03	56000.00
856F81	2017-07-04 00:39:00+03	46200.00
85702D	2017-07-16 05:49:00+03	27400.00
857039	2017-07-11 23:39:00+03	7200.00
8570BF	2017-07-19 21:59:00+03	6300.00
8570DC	2017-07-31 21:44:00+03	290200.00
8570EE	2017-08-14 06:24:00+03	132800.00
8570F8	2017-08-05 02:58:00+03	70800.00
85717A	2017-06-30 06:01:00+03	26000.00
857186	2017-07-11 03:09:00+03	38500.00
8571AE	2017-07-19 09:35:00+03	38800.00
8571E8	2017-08-03 08:50:00+03	131600.00
857207	2017-08-12 01:02:00+03	45100.00
857212	2017-07-27 20:27:00+03	59000.00
857236	2017-07-14 08:08:00+03	30200.00
8572D5	2017-08-05 13:59:00+03	417000.00
8572D7	2017-07-29 21:36:00+03	111700.00
8572E3	2017-07-17 00:07:00+03	132800.00
8572FE	2017-07-31 22:03:00+03	12600.00
857327	2017-07-10 00:03:00+03	56600.00
857335	2017-07-17 09:37:00+03	16400.00
857369	2017-07-11 15:14:00+03	68800.00
857381	2017-07-17 09:40:00+03	59800.00
857384	2017-07-09 12:41:00+03	27200.00
85738D	2017-07-15 05:44:00+03	78100.00
8573F9	2017-07-25 08:06:00+03	246000.00
8574AC	2017-07-02 17:10:00+03	28000.00
8574C8	2017-07-26 14:02:00+03	246000.00
857566	2017-07-04 06:41:00+03	25000.00
857571	2017-08-03 16:08:00+03	23200.00
8575D5	2017-08-14 18:13:00+03	87100.00
857619	2017-08-08 11:52:00+03	23200.00
857678	2017-07-21 13:57:00+03	89600.00
85776F	2017-07-24 20:32:00+03	29600.00
857773	2017-08-11 10:22:00+03	190300.00
8577FE	2017-08-04 20:19:00+03	289800.00
857806	2017-07-30 14:31:00+03	13400.00
857826	2017-08-14 22:33:00+03	37200.00
85784B	2017-07-31 05:22:00+03	54800.00
857893	2017-07-17 18:53:00+03	52800.00
85789B	2017-07-21 04:45:00+03	25400.00
8578B7	2017-07-31 14:18:00+03	149300.00
8578F6	2017-07-12 18:10:00+03	40000.00
857908	2017-08-10 08:07:00+03	39200.00
857920	2017-08-11 00:41:00+03	6000.00
85796C	2017-07-17 07:06:00+03	48800.00
857998	2017-07-06 08:48:00+03	311200.00
8579C0	2017-07-07 22:46:00+03	43200.00
8579D8	2017-07-09 03:28:00+03	46400.00
857A5F	2017-07-11 11:47:00+03	86200.00
857A86	2017-08-03 08:19:00+03	266400.00
857A92	2017-08-07 20:20:00+03	147700.00
857A9A	2017-08-13 20:03:00+03	16800.00
857B02	2017-07-11 00:35:00+03	335400.00
857B14	2017-08-12 14:13:00+03	108600.00
857BAD	2017-07-21 21:11:00+03	38800.00
857C72	2017-07-08 05:08:00+03	28000.00
857D07	2017-08-15 00:12:00+03	39800.00
857D59	2017-07-20 08:32:00+03	46700.00
857D8B	2017-07-02 09:34:00+03	26000.00
857E28	2017-07-06 20:19:00+03	112600.00
857E29	2017-08-04 06:41:00+03	124200.00
857E2D	2017-07-23 12:55:00+03	20800.00
857E38	2017-08-07 14:01:00+03	133200.00
857E48	2017-07-14 02:57:00+03	60000.00
857E6C	2017-07-25 05:55:00+03	189800.00
857E94	2017-08-06 18:21:00+03	43600.00
857F07	2017-07-11 13:59:00+03	398500.00
857F12	2017-07-27 18:09:00+03	44700.00
857F54	2017-08-13 16:00:00+03	93600.00
857F5B	2017-07-26 05:58:00+03	55800.00
857FB2	2017-08-09 04:00:00+03	39500.00
857FEA	2017-07-12 22:35:00+03	232800.00
85803F	2017-07-04 12:24:00+03	40400.00
858099	2017-08-12 12:32:00+03	37900.00
8580CD	2017-07-14 12:47:00+03	94000.00
8580D6	2017-08-04 09:49:00+03	20200.00
8580E0	2017-07-27 11:56:00+03	37700.00
858131	2017-07-07 06:01:00+03	55800.00
858140	2017-07-01 01:12:00+03	297300.00
858150	2017-08-09 03:25:00+03	369000.00
85817D	2017-07-21 18:00:00+03	66000.00
858186	2017-07-13 05:19:00+03	14800.00
8581AF	2017-07-05 17:33:00+03	135400.00
8581C5	2017-08-14 04:48:00+03	85000.00
8581D6	2017-07-07 11:16:00+03	22000.00
858225	2017-08-01 07:15:00+03	289800.00
85825D	2017-08-13 10:15:00+03	73400.00
858271	2017-08-15 08:51:00+03	44600.00
858305	2017-07-29 06:17:00+03	271100.00
858358	2017-08-01 15:36:00+03	64700.00
85837A	2017-07-14 07:57:00+03	112600.00
85839A	2017-07-08 10:13:00+03	88600.00
8583E0	2017-07-14 11:29:00+03	492000.00
858416	2017-07-15 01:02:00+03	16400.00
85846B	2017-07-28 01:06:00+03	16400.00
8584D1	2017-08-05 10:52:00+03	28000.00
858554	2017-07-09 00:36:00+03	106400.00
8585AA	2017-07-25 02:56:00+03	73100.00
8585BE	2017-07-09 17:29:00+03	39500.00
8585CF	2017-07-21 00:20:00+03	29100.00
8585E0	2017-08-07 14:10:00+03	90600.00
8585F5	2017-08-10 09:15:00+03	19600.00
858618	2017-07-13 22:52:00+03	80200.00
85869F	2017-07-30 21:48:00+03	148800.00
8586E5	2017-08-08 19:46:00+03	25600.00
8587CF	2017-07-11 12:33:00+03	114800.00
8587D0	2017-07-23 18:22:00+03	114100.00
858867	2017-08-13 18:36:00+03	24700.00
8588AE	2017-07-17 17:17:00+03	271100.00
8588BF	2017-07-21 02:46:00+03	14000.00
858972	2017-07-21 12:37:00+03	21600.00
85898C	2017-07-11 15:29:00+03	26000.00
8589BD	2017-07-08 17:41:00+03	3400.00
858A45	2017-08-14 14:51:00+03	32800.00
858A7E	2017-07-09 09:35:00+03	136100.00
858AE1	2017-07-14 02:05:00+03	54800.00
858BC7	2017-07-28 11:36:00+03	106300.00
858C9E	2017-07-10 13:46:00+03	169900.00
858CD9	2017-07-30 03:45:00+03	44600.00
858DD4	2017-08-14 02:04:00+03	43200.00
858DE6	2017-07-21 19:33:00+03	56100.00
858E0D	2017-08-12 11:36:00+03	18600.00
858E12	2017-07-14 18:21:00+03	123000.00
858EC1	2017-07-17 23:12:00+03	44000.00
858F9F	2017-06-28 07:48:00+03	58200.00
859003	2017-07-19 00:26:00+03	191000.00
85906A	2017-07-28 13:57:00+03	35700.00
85908A	2017-07-01 04:28:00+03	398500.00
85908B	2017-08-15 14:17:00+03	75200.00
8590CD	2017-07-05 02:37:00+03	134400.00
8590D1	2017-07-27 19:47:00+03	6700.00
8590D8	2017-08-05 20:34:00+03	94000.00
8590E0	2017-07-10 18:09:00+03	8400.00
8590F6	2017-07-16 20:54:00+03	29400.00
859108	2017-07-07 00:25:00+03	72400.00
859112	2017-07-01 07:02:00+03	27500.00
859136	2017-08-04 02:45:00+03	44800.00
859157	2017-08-10 04:40:00+03	61800.00
85918B	2017-08-03 15:41:00+03	49600.00
859190	2017-07-14 00:31:00+03	81600.00
859199	2017-07-30 00:58:00+03	248900.00
8591C9	2017-08-15 00:20:00+03	24400.00
8591CE	2017-08-13 08:10:00+03	187600.00
8591DF	2017-07-01 05:47:00+03	70800.00
8591E4	2017-07-22 14:47:00+03	136700.00
8591F8	2017-07-15 10:55:00+03	133200.00
859244	2017-07-11 20:21:00+03	78400.00
859250	2017-08-08 11:38:00+03	67600.00
85927B	2017-07-24 09:29:00+03	248500.00
859283	2017-07-31 14:14:00+03	144400.00
8592B1	2017-08-04 00:40:00+03	139400.00
8592B8	2017-08-13 13:03:00+03	56100.00
8592BF	2017-07-13 14:11:00+03	6800.00
8592C4	2017-07-07 12:28:00+03	65600.00
859305	2017-07-27 22:22:00+03	67600.00
859338	2017-07-16 23:57:00+03	136800.00
859348	2017-07-19 00:10:00+03	126300.00
859372	2017-07-28 10:03:00+03	179500.00
85937E	2017-08-12 05:54:00+03	11800.00
859398	2017-07-27 06:22:00+03	122600.00
8593C0	2017-07-16 09:47:00+03	61800.00
8593CA	2017-07-18 01:29:00+03	6300.00
859469	2017-07-29 19:38:00+03	60600.00
85947A	2017-07-11 19:11:00+03	92800.00
859499	2017-07-16 17:34:00+03	18600.00
8594D5	2017-07-25 11:09:00+03	56000.00
85954D	2017-07-06 02:21:00+03	24400.00
8595F1	2017-07-06 23:24:00+03	73500.00
859652	2017-08-01 17:44:00+03	59600.00
8596A2	2017-07-05 02:10:00+03	155600.00
859703	2017-07-20 11:09:00+03	30200.00
85973A	2017-08-09 12:40:00+03	51900.00
8597DB	2017-08-03 02:41:00+03	34700.00
859824	2017-07-01 16:42:00+03	255600.00
85987B	2017-07-20 18:46:00+03	133100.00
85987F	2017-07-31 08:17:00+03	201200.00
859883	2017-08-03 11:32:00+03	46400.00
859885	2017-07-06 08:45:00+03	6000.00
8598D0	2017-07-11 15:46:00+03	51600.00
8598ED	2017-07-07 02:16:00+03	7800.00
8598F2	2017-08-12 10:53:00+03	75300.00
859929	2017-08-15 14:13:00+03	13600.00
859956	2017-07-18 18:19:00+03	70600.00
859964	2017-07-24 18:31:00+03	21800.00
859976	2017-07-06 09:36:00+03	75300.00
859992	2017-07-14 06:59:00+03	48300.00
8599BB	2017-08-14 11:08:00+03	24400.00
8599EB	2017-08-10 17:56:00+03	68800.00
8599FB	2017-07-19 17:06:00+03	36400.00
859A57	2017-08-13 22:31:00+03	28800.00
859B37	2017-08-03 02:51:00+03	109200.00
859B46	2017-08-11 15:57:00+03	130100.00
859B5C	2017-07-08 11:10:00+03	29200.00
859B6E	2017-07-14 07:52:00+03	28800.00
859C27	2017-08-05 05:26:00+03	46400.00
859C61	2017-08-03 15:48:00+03	115600.00
859CA1	2017-07-01 05:50:00+03	32800.00
859CAE	2017-07-16 17:07:00+03	35200.00
859D13	2017-07-22 23:03:00+03	73100.00
859D17	2017-07-16 14:47:00+03	94000.00
859D6C	2017-07-16 19:26:00+03	67900.00
859DED	2017-07-10 10:03:00+03	111600.00
859E60	2017-08-03 22:47:00+03	44600.00
859F4C	2017-07-09 15:46:00+03	86400.00
859F70	2017-06-27 23:14:00+03	30400.00
85A011	2017-07-15 14:43:00+03	49900.00
85A031	2017-07-29 23:09:00+03	22000.00
85A067	2017-07-28 10:55:00+03	56000.00
85A081	2017-07-14 18:38:00+03	26800.00
85A084	2017-08-12 12:04:00+03	42600.00
85A0B3	2017-07-19 07:15:00+03	96800.00
85A0B7	2017-07-16 11:46:00+03	40000.00
85A0E0	2017-08-14 01:29:00+03	56000.00
85A12E	2017-07-18 11:52:00+03	42800.00
85A140	2017-07-04 05:50:00+03	4000.00
85A19B	2017-08-06 20:27:00+03	46400.00
85A1AE	2017-07-28 03:12:00+03	23600.00
85A279	2017-08-04 13:11:00+03	39600.00
85A297	2017-07-16 08:57:00+03	46000.00
85A298	2017-08-09 17:26:00+03	28800.00
85A371	2017-07-08 18:46:00+03	68800.00
85A380	2017-07-24 02:29:00+03	61200.00
85A3B0	2017-07-26 09:50:00+03	182300.00
85A423	2017-07-11 23:01:00+03	85000.00
85A4A6	2017-07-26 19:30:00+03	12600.00
85A4BB	2017-07-19 16:49:00+03	398500.00
85A4CE	2017-07-18 01:37:00+03	56000.00
85A5DA	2017-07-04 17:33:00+03	57500.00
85A634	2017-08-09 19:49:00+03	26300.00
85A63E	2017-07-11 08:57:00+03	25300.00
85A673	2017-08-05 19:53:00+03	54500.00
85A692	2017-08-10 15:50:00+03	26300.00
85A6B6	2017-07-12 09:06:00+03	92100.00
85A6C7	2017-07-15 07:02:00+03	68400.00
85A79A	2017-07-04 05:22:00+03	22000.00
85A7C0	2017-08-13 05:43:00+03	28800.00
85A7CE	2017-07-28 18:36:00+03	22200.00
85A889	2017-07-21 00:02:00+03	588800.00
85A88E	2017-07-31 05:57:00+03	25400.00
85A8A6	2017-07-07 18:35:00+03	34000.00
85A8BA	2017-07-23 20:25:00+03	98400.00
85A8CE	2017-07-26 20:55:00+03	32200.00
85A932	2017-07-07 11:42:00+03	46400.00
85A958	2017-07-30 13:27:00+03	6800.00
85A95B	2017-06-30 02:16:00+03	55800.00
85A962	2017-08-05 19:53:00+03	254900.00
85A9A5	2017-07-31 20:58:00+03	49600.00
85A9E8	2017-07-26 13:46:00+03	189800.00
85AA0B	2017-08-10 18:25:00+03	58000.00
85AA1E	2017-07-06 07:12:00+03	270800.00
85AA71	2017-07-15 10:00:00+03	35100.00
85AAAE	2017-07-09 05:51:00+03	140000.00
85AB28	2017-07-16 15:21:00+03	102100.00
85AB2F	2017-07-22 18:46:00+03	60400.00
85AB32	2017-06-30 17:38:00+03	47000.00
85AB61	2017-08-01 20:41:00+03	316400.00
85AB6E	2017-07-29 16:44:00+03	20600.00
85AB79	2017-08-10 13:35:00+03	25200.00
85AB95	2017-08-05 18:29:00+03	21400.00
85AC01	2017-07-25 13:15:00+03	23600.00
85AC7D	2017-08-06 16:42:00+03	20200.00
85AD01	2017-08-13 08:13:00+03	31400.00
85AD44	2017-07-10 16:18:00+03	27800.00
85ADDA	2017-08-05 01:08:00+03	23400.00
85ADE4	2017-07-06 12:21:00+03	54800.00
85AE58	2017-07-14 21:15:00+03	10600.00
85AE84	2017-08-12 10:21:00+03	40000.00
85AE97	2017-07-08 04:12:00+03	6000.00
85AEAD	2017-07-28 06:35:00+03	73400.00
85AEB6	2017-07-18 12:23:00+03	23200.00
85AEEE	2017-07-28 12:33:00+03	101200.00
85AF22	2017-07-11 23:38:00+03	6000.00
85B019	2017-06-27 15:19:00+03	53600.00
85B06A	2017-08-11 22:46:00+03	62800.00
85B0AC	2017-07-09 06:22:00+03	28800.00
85B0B9	2017-07-17 20:33:00+03	26200.00
85B122	2017-07-22 17:29:00+03	62000.00
85B14D	2017-07-31 18:36:00+03	266300.00
85B18D	2017-07-16 16:15:00+03	26400.00
85B20B	2017-08-14 04:53:00+03	28800.00
85B25E	2017-08-03 14:13:00+03	102100.00
85B2B1	2017-07-27 01:42:00+03	25700.00
85B2D7	2017-07-05 01:25:00+03	270700.00
85B303	2017-07-16 10:38:00+03	22600.00
85B311	2017-07-31 12:30:00+03	83000.00
85B31D	2017-07-10 05:59:00+03	6000.00
85B330	2017-08-07 07:30:00+03	45300.00
85B351	2017-08-02 19:03:00+03	20400.00
85B481	2017-08-04 19:39:00+03	19600.00
85B584	2017-08-07 15:54:00+03	86300.00
85B600	2017-07-29 02:54:00+03	95700.00
85B630	2017-07-27 21:58:00+03	38200.00
85B654	2017-08-03 15:40:00+03	21800.00
85B741	2017-07-14 10:15:00+03	31100.00
85B75C	2017-07-24 14:21:00+03	93900.00
85B7A4	2017-07-14 22:59:00+03	29600.00
85B7B2	2017-08-03 23:54:00+03	67800.00
85B857	2017-07-19 13:37:00+03	50000.00
85B870	2017-07-31 04:18:00+03	8200.00
85B909	2017-07-01 11:44:00+03	45200.00
85B972	2017-08-09 15:04:00+03	54900.00
85B982	2017-07-21 10:48:00+03	12000.00
85B9CF	2017-07-20 12:01:00+03	57400.00
85B9F9	2017-08-01 21:07:00+03	44000.00
85BA6D	2017-07-17 03:44:00+03	69500.00
85BAA4	2017-07-08 22:24:00+03	136600.00
85BAA8	2017-08-12 21:59:00+03	108600.00
85BAD0	2017-07-03 17:01:00+03	40800.00
85BB00	2017-07-05 02:59:00+03	62100.00
85BB1F	2017-08-11 01:42:00+03	28800.00
85BB8E	2017-07-06 18:41:00+03	46400.00
85BC4F	2017-08-11 10:31:00+03	28000.00
85BC79	2017-06-27 15:25:00+03	67600.00
85BC82	2017-07-14 09:30:00+03	131100.00
85BC89	2017-07-12 00:22:00+03	27800.00
85BCBF	2017-07-09 00:38:00+03	102100.00
85BD79	2017-08-06 18:01:00+03	6800.00
85BD7C	2017-07-16 06:49:00+03	45200.00
85BDA0	2017-08-13 13:46:00+03	31100.00
85BDFC	2017-07-20 01:32:00+03	55800.00
85BE5B	2017-07-04 22:15:00+03	38800.00
85BE72	2017-08-07 09:09:00+03	40600.00
85BE7F	2017-07-18 19:29:00+03	122000.00
85BE99	2017-08-05 06:06:00+03	73500.00
85BEA6	2017-08-08 05:24:00+03	201200.00
85BF03	2017-07-26 10:47:00+03	46400.00
85BF1F	2017-07-10 17:10:00+03	28000.00
85BF40	2017-06-30 17:29:00+03	147200.00
85BF4D	2017-07-02 19:29:00+03	75300.00
85BF75	2017-07-15 14:39:00+03	46400.00
85BFB5	2017-07-20 06:35:00+03	359900.00
85BFDE	2017-06-30 11:45:00+03	133100.00
85BFE7	2017-07-25 11:39:00+03	28800.00
85C05C	2017-07-06 13:19:00+03	88900.00
85C0DA	2017-08-01 00:35:00+03	46800.00
85C0E7	2017-07-14 17:19:00+03	97900.00
85C10D	2017-07-01 21:15:00+03	195400.00
85C11F	2017-08-10 00:47:00+03	42600.00
85C134	2017-07-13 00:23:00+03	19600.00
85C143	2017-08-06 17:01:00+03	55800.00
85C1B9	2017-07-10 14:30:00+03	77200.00
85C281	2017-08-15 11:04:00+03	93900.00
85C29C	2017-07-16 17:57:00+03	70800.00
85C2DC	2017-07-31 04:02:00+03	263100.00
85C317	2017-08-12 13:54:00+03	246000.00
85C397	2017-07-26 18:41:00+03	51300.00
85C3B2	2017-08-13 19:23:00+03	75600.00
85C518	2017-07-20 16:03:00+03	34100.00
85C568	2017-08-03 19:16:00+03	21400.00
85C59B	2017-07-22 21:48:00+03	12600.00
85C5DD	2017-07-24 14:12:00+03	14400.00
85C690	2017-08-10 21:49:00+03	46900.00
85C753	2017-08-01 10:12:00+03	246000.00
85C760	2017-08-13 23:46:00+03	432600.00
85C778	2017-08-12 23:20:00+03	23200.00
85C812	2017-07-20 15:30:00+03	26000.00
85C822	2017-08-01 16:20:00+03	35200.00
85C828	2017-07-16 08:00:00+03	67200.00
85C869	2017-08-11 07:30:00+03	28800.00
85C8B6	2017-07-15 12:49:00+03	131100.00
85C8CB	2017-08-02 06:43:00+03	11600.00
85C8E1	2017-07-07 00:29:00+03	266200.00
85C90A	2017-07-11 04:13:00+03	69600.00
85C90B	2017-08-14 11:38:00+03	51900.00
85C9EE	2017-08-01 09:58:00+03	10600.00
85CA3E	2017-07-16 06:37:00+03	194200.00
85CA4E	2017-08-12 00:26:00+03	187600.00
85CA6E	2017-07-06 18:54:00+03	406100.00
85CA9F	2017-08-14 17:38:00+03	88100.00
85CADC	2017-07-14 17:44:00+03	75600.00
85CAE2	2017-08-03 06:25:00+03	109400.00
85CAE3	2017-07-17 13:20:00+03	103800.00
85CAFD	2017-07-10 03:37:00+03	67200.00
85CB3B	2017-07-14 13:48:00+03	55800.00
85CB83	2017-07-12 23:30:00+03	271200.00
85CB99	2017-08-09 19:26:00+03	13800.00
85CBB6	2017-07-14 13:40:00+03	31600.00
85CBC1	2017-07-29 03:35:00+03	65900.00
85CBDA	2017-07-26 08:42:00+03	99200.00
85CC32	2017-07-08 00:48:00+03	449500.00
85CC5D	2017-07-17 05:22:00+03	115700.00
85CD16	2017-07-29 04:38:00+03	72400.00
85CD21	2017-07-04 12:31:00+03	33200.00
85CD33	2017-07-01 09:25:00+03	40800.00
85CD6B	2017-08-07 08:07:00+03	26000.00
85CD8B	2017-07-29 13:37:00+03	38600.00
85CD8F	2017-07-08 06:24:00+03	31600.00
85CDE7	2017-08-15 01:03:00+03	39300.00
85CE0C	2017-08-12 01:51:00+03	36900.00
85CE59	2017-07-19 18:20:00+03	51800.00
85CF55	2017-07-15 07:15:00+03	49100.00
85CF6F	2017-08-12 16:17:00+03	26000.00
85CF8B	2017-08-09 06:40:00+03	202500.00
85CFD7	2017-07-09 09:17:00+03	60400.00
85D03E	2017-07-14 17:47:00+03	273400.00
85D06A	2017-08-08 20:46:00+03	23600.00
85D093	2017-07-02 01:35:00+03	139300.00
85D0B8	2017-08-12 09:27:00+03	248200.00
85D100	2017-07-04 08:55:00+03	29500.00
85D151	2017-08-11 03:23:00+03	148500.00
85D19D	2017-07-27 13:04:00+03	56100.00
85D1F1	2017-08-06 00:19:00+03	38400.00
85D235	2017-07-29 15:51:00+03	51900.00
85D24D	2017-08-06 20:30:00+03	25800.00
85D369	2017-07-16 12:35:00+03	50000.00
85D3AB	2017-07-05 19:02:00+03	137900.00
85D3C2	2017-06-30 14:40:00+03	136000.00
85D3DA	2017-07-05 02:49:00+03	55800.00
85D409	2017-07-15 22:59:00+03	73200.00
85D41F	2017-07-27 02:45:00+03	21400.00
85D470	2017-08-10 21:55:00+03	12600.00
85D4DB	2017-07-10 11:26:00+03	78700.00
85D55D	2017-07-10 00:42:00+03	42800.00
85D56A	2017-08-03 15:22:00+03	36600.00
85D5AE	2017-07-09 03:46:00+03	95600.00
85D5D7	2017-07-14 23:40:00+03	26400.00
85D5DD	2017-07-27 01:25:00+03	8000.00
85D5EA	2017-07-23 21:10:00+03	15200.00
85D6AF	2017-07-08 07:36:00+03	6700.00
85D6CE	2017-07-09 16:11:00+03	26000.00
85D6E6	2017-07-16 07:49:00+03	171500.00
85D6F9	2017-07-17 06:15:00+03	11800.00
85D73B	2017-08-07 18:40:00+03	91700.00
85D749	2017-07-29 18:35:00+03	19600.00
85D77A	2017-07-06 13:04:00+03	93900.00
85D7BF	2017-08-15 04:37:00+03	113200.00
85D81B	2017-07-26 07:19:00+03	26200.00
85D83B	2017-07-09 06:51:00+03	59800.00
85D85F	2017-08-06 02:42:00+03	26000.00
85D86E	2017-07-19 20:33:00+03	135600.00
85D8FA	2017-07-25 05:46:00+03	89700.00
85D900	2017-07-24 08:15:00+03	26700.00
85D931	2017-08-12 22:15:00+03	56000.00
85D940	2017-07-18 08:37:00+03	58700.00
85D94C	2017-07-03 16:13:00+03	37100.00
85D960	2017-07-21 21:58:00+03	92900.00
85D973	2017-08-07 22:03:00+03	19600.00
85D9C4	2017-08-12 17:25:00+03	23200.00
85DA0E	2017-07-14 18:01:00+03	69900.00
85DA2C	2017-07-08 08:01:00+03	6000.00
85DA4F	2017-07-21 04:12:00+03	21000.00
85DA62	2017-08-09 19:48:00+03	43800.00
85DAB0	2017-07-02 10:15:00+03	131100.00
85DAB4	2017-07-17 11:12:00+03	27900.00
85DAD6	2017-08-10 12:43:00+03	38800.00
85DAFB	2017-07-28 00:49:00+03	153300.00
85DB65	2017-07-10 02:36:00+03	135400.00
85DBA6	2017-07-06 01:02:00+03	58200.00
85DBD7	2017-07-16 18:44:00+03	108600.00
85DBDC	2017-07-16 19:42:00+03	98400.00
85DBE9	2017-07-15 01:29:00+03	21800.00
85DC25	2017-07-20 06:07:00+03	139300.00
85DC79	2017-08-11 18:42:00+03	56000.00
85DC9E	2017-07-21 15:11:00+03	42900.00
85DCC0	2017-07-24 01:53:00+03	39600.00
85DD23	2017-07-25 15:34:00+03	46000.00
85DD4B	2017-07-01 03:50:00+03	55800.00
85DD73	2017-07-25 19:44:00+03	87900.00
85DD99	2017-07-07 17:40:00+03	131100.00
85DDA6	2017-07-29 18:03:00+03	257600.00
85DDBA	2017-08-12 09:10:00+03	58900.00
85DDC6	2017-07-20 09:17:00+03	39300.00
85DDCB	2017-08-11 18:46:00+03	29600.00
85DDDA	2017-08-14 04:08:00+03	18600.00
85DDEA	2017-07-11 18:08:00+03	59200.00
85DE1B	2017-07-15 23:42:00+03	31600.00
85DE6B	2017-07-13 21:17:00+03	85000.00
85DE75	2017-07-22 22:54:00+03	100900.00
85DEAA	2017-08-15 01:19:00+03	92400.00
85DEB0	2017-07-01 01:33:00+03	18000.00
85DEB6	2017-07-14 11:57:00+03	99200.00
85DF16	2017-08-13 01:18:00+03	217100.00
85DF2A	2017-07-15 22:51:00+03	77900.00
85DF45	2017-07-20 10:37:00+03	44800.00
85DF79	2017-07-28 09:40:00+03	112000.00
85DF90	2017-08-06 01:22:00+03	70800.00
85E118	2017-07-25 18:47:00+03	36200.00
85E133	2017-08-03 00:56:00+03	49600.00
85E137	2017-07-18 14:45:00+03	49900.00
85E196	2017-07-24 14:10:00+03	92400.00
85E1B2	2017-08-09 03:16:00+03	62000.00
85E1BB	2017-07-16 19:52:00+03	45200.00
85E1BD	2017-07-06 16:06:00+03	22000.00
85E28A	2017-08-06 01:37:00+03	40800.00
85E2CD	2017-08-01 12:26:00+03	66400.00
85E317	2017-08-09 21:54:00+03	38400.00
85E34F	2017-07-27 20:32:00+03	43400.00
85E3DD	2017-07-13 06:32:00+03	30000.00
85E41B	2017-07-11 09:39:00+03	36200.00
85E44A	2017-07-09 10:37:00+03	43600.00
85E486	2017-08-07 01:06:00+03	257500.00
85E48F	2017-07-11 17:29:00+03	28800.00
85E4B7	2017-07-12 08:22:00+03	37200.00
85E592	2017-07-07 10:51:00+03	26600.00
85E644	2017-07-11 08:04:00+03	46400.00
85E64E	2017-07-11 17:21:00+03	246000.00
85E6D4	2017-08-06 08:39:00+03	93400.00
85E6D9	2017-08-09 01:09:00+03	22000.00
85E733	2017-07-25 15:13:00+03	232100.00
85E745	2017-07-31 17:59:00+03	7400.00
85E788	2017-07-29 01:28:00+03	39300.00
85E7AF	2017-07-14 19:05:00+03	31400.00
85E82F	2017-08-07 16:42:00+03	21800.00
85E84F	2017-07-16 06:28:00+03	69500.00
85E85E	2017-08-12 13:13:00+03	30200.00
85E910	2017-07-14 14:41:00+03	108600.00
85E935	2017-08-03 11:09:00+03	36200.00
85E959	2017-07-28 09:16:00+03	26000.00
85EA32	2017-08-10 09:33:00+03	81700.00
85EA3B	2017-07-05 06:45:00+03	46400.00
85EA51	2017-06-30 02:40:00+03	531400.00
85EA6D	2017-07-15 11:43:00+03	133100.00
85EA8F	2017-08-08 02:24:00+03	25600.00
85EAD1	2017-07-07 15:31:00+03	36200.00
85EB13	2017-07-16 12:26:00+03	20400.00
85EB2A	2017-07-26 16:06:00+03	136200.00
85EB73	2017-08-01 09:34:00+03	143200.00
85EB98	2017-06-28 23:03:00+03	67100.00
85EBAA	2017-07-30 07:56:00+03	60000.00
85EBB9	2017-08-14 10:55:00+03	22000.00
85EBCC	2017-07-05 12:45:00+03	28000.00
85EC2B	2017-08-13 18:52:00+03	26000.00
85EC3B	2017-07-28 23:26:00+03	20200.00
85EC5A	2017-07-13 19:58:00+03	98400.00
85EC8A	2017-07-16 10:44:00+03	27800.00
85ECD6	2017-07-03 08:02:00+03	30000.00
85ECFE	2017-07-31 08:48:00+03	32800.00
85ED71	2017-07-21 20:39:00+03	46400.00
85ED80	2017-07-28 16:43:00+03	112000.00
85EDD6	2017-08-09 03:12:00+03	56600.00
85EE20	2017-07-08 19:40:00+03	40400.00
85EE4F	2017-07-24 12:54:00+03	86600.00
85EED8	2017-07-02 12:25:00+03	118600.00
85EEF9	2017-08-11 14:11:00+03	24700.00
85EEFA	2017-07-30 09:19:00+03	40000.00
85EF28	2017-07-07 17:35:00+03	39400.00
85EF32	2017-07-12 08:33:00+03	81900.00
85EF65	2017-07-28 00:09:00+03	95700.00
85F0EB	2017-07-29 11:18:00+03	25400.00
85F0F6	2017-07-29 05:04:00+03	24400.00
85F101	2017-07-30 02:00:00+03	23600.00
85F10A	2017-07-09 16:22:00+03	56000.00
85F16C	2017-08-02 22:13:00+03	70800.00
85F185	2017-08-14 16:27:00+03	36600.00
85F18F	2017-08-13 00:10:00+03	112100.00
85F19E	2017-08-14 18:12:00+03	53600.00
85F205	2017-08-08 01:59:00+03	31900.00
85F24C	2017-07-28 10:06:00+03	144400.00
85F271	2017-07-20 04:51:00+03	80900.00
85F279	2017-07-07 12:57:00+03	37900.00
85F29C	2017-08-05 19:04:00+03	70800.00
85F2A9	2017-08-03 02:54:00+03	36900.00
85F2AA	2017-07-22 02:56:00+03	92000.00
85F2B2	2017-07-07 20:27:00+03	32800.00
85F2EF	2017-08-13 01:51:00+03	67600.00
85F32D	2017-07-14 20:44:00+03	28000.00
85F352	2017-07-04 16:17:00+03	85600.00
85F3C4	2017-07-30 07:14:00+03	89700.00
85F412	2017-07-30 17:39:00+03	158500.00
85F42B	2017-07-17 20:46:00+03	81700.00
85F433	2017-07-05 17:43:00+03	355200.00
85F49C	2017-07-23 13:36:00+03	23200.00
85F4CE	2017-07-21 23:28:00+03	6700.00
85F4DA	2017-08-03 16:28:00+03	229300.00
85F4EA	2017-08-07 10:33:00+03	88600.00
85F4FC	2017-07-09 04:37:00+03	81700.00
85F5A2	2017-07-15 03:36:00+03	114500.00
85F5C0	2017-07-29 18:27:00+03	40000.00
85F5E7	2017-07-19 08:23:00+03	56000.00
85F655	2017-08-05 11:02:00+03	81600.00
85F65A	2017-07-27 14:35:00+03	177900.00
85F6D6	2017-08-03 20:30:00+03	41200.00
85F793	2017-08-11 21:29:00+03	46300.00
85F7DA	2017-07-15 03:37:00+03	139200.00
85F877	2017-07-26 04:26:00+03	36900.00
85F89C	2017-07-05 16:46:00+03	201400.00
85F8A6	2017-07-27 10:44:00+03	61200.00
85F903	2017-07-15 10:28:00+03	53600.00
85F91B	2017-07-17 22:44:00+03	76300.00
85F924	2017-07-16 01:13:00+03	41600.00
85F938	2017-07-17 09:35:00+03	70900.00
85F944	2017-07-30 07:24:00+03	173500.00
85F9D9	2017-06-30 09:22:00+03	38600.00
85FA19	2017-07-19 03:13:00+03	26000.00
85FABA	2017-07-07 10:46:00+03	38400.00
85FB1C	2017-08-11 15:20:00+03	28000.00
85FB28	2017-08-14 22:18:00+03	18800.00
85FB8E	2017-07-01 00:38:00+03	23100.00
85FBA9	2017-07-15 14:07:00+03	28000.00
85FC0B	2017-07-10 17:36:00+03	10600.00
85FC31	2017-07-13 09:17:00+03	134400.00
85FC36	2017-08-06 18:20:00+03	56000.00
85FC72	2017-08-01 19:59:00+03	34000.00
85FC86	2017-08-12 10:47:00+03	54800.00
85FC9C	2017-08-10 13:47:00+03	67700.00
85FCA7	2017-08-02 10:05:00+03	140800.00
85FCB3	2017-07-25 13:31:00+03	31200.00
85FCE2	2017-06-30 20:43:00+03	125200.00
85FD25	2017-07-05 16:06:00+03	39400.00
85FD4F	2017-08-06 00:12:00+03	117000.00
85FD50	2017-07-03 06:23:00+03	205600.00
85FD81	2017-08-03 03:07:00+03	50600.00
85FD9F	2017-07-07 04:59:00+03	223200.00
85FDE6	2017-07-26 23:23:00+03	29800.00
85FE10	2017-08-12 05:28:00+03	43200.00
85FE9A	2017-07-25 12:47:00+03	23400.00
85FEB1	2017-07-11 01:17:00+03	43500.00
85FF20	2017-07-31 03:51:00+03	44000.00
85FF47	2017-07-29 09:03:00+03	40900.00
85FF4B	2017-07-21 18:02:00+03	46400.00
85FFC5	2017-08-01 01:12:00+03	83200.00
85FFF2	2017-07-20 09:28:00+03	56600.00
8600BB	2017-08-05 07:53:00+03	100200.00
860113	2017-07-04 17:52:00+03	22000.00
860124	2017-07-28 09:12:00+03	77000.00
86016D	2017-07-17 04:54:00+03	75600.00
86017B	2017-07-24 17:43:00+03	73300.00
8601BE	2017-07-06 07:26:00+03	26700.00
8601F7	2017-07-18 16:55:00+03	42800.00
860278	2017-07-19 20:06:00+03	46400.00
860355	2017-07-12 03:57:00+03	57500.00
86037D	2017-07-24 20:12:00+03	125900.00
8603A4	2017-08-12 17:30:00+03	43900.00
8603ED	2017-07-21 18:48:00+03	252200.00
860511	2017-06-29 15:01:00+03	27800.00
860527	2017-07-10 18:14:00+03	26000.00
860561	2017-07-05 23:06:00+03	38800.00
860570	2017-07-25 21:27:00+03	14800.00
8605B8	2017-07-22 23:54:00+03	25000.00
8605BA	2017-07-26 05:43:00+03	10100.00
860625	2017-08-12 03:44:00+03	24400.00
860638	2017-07-15 02:42:00+03	54000.00
860668	2017-08-07 01:38:00+03	12400.00
860678	2017-08-10 06:46:00+03	36200.00
8606C0	2017-07-17 07:28:00+03	248300.00
860725	2017-07-15 11:06:00+03	46400.00
860757	2017-08-08 04:34:00+03	24400.00
8607FB	2017-07-27 22:56:00+03	28800.00
86080C	2017-08-15 12:28:00+03	50100.00
860862	2017-07-07 06:38:00+03	24800.00
860872	2017-07-09 13:39:00+03	75600.00
8608DD	2017-08-14 04:11:00+03	29600.00
8608E0	2017-08-12 13:18:00+03	102100.00
86092A	2017-07-03 15:21:00+03	39000.00
86092D	2017-07-16 09:53:00+03	28000.00
860935	2017-07-21 09:40:00+03	62800.00
860971	2017-07-29 07:01:00+03	198600.00
86098B	2017-08-01 14:20:00+03	369000.00
860A0C	2017-08-12 13:05:00+03	38500.00
860A0D	2017-08-04 03:01:00+03	20600.00
860A21	2017-08-05 08:26:00+03	23400.00
860A8F	2017-07-29 04:45:00+03	111600.00
860AEA	2017-07-27 23:05:00+03	56100.00
860B05	2017-07-12 01:10:00+03	40800.00
860B7B	2017-07-18 03:32:00+03	77600.00
860BBA	2017-08-08 01:01:00+03	23400.00
860BEB	2017-08-10 12:46:00+03	56100.00
860BF0	2017-07-29 07:22:00+03	59300.00
860BFF	2017-08-05 18:38:00+03	58600.00
860C1C	2017-08-09 17:15:00+03	28000.00
860C8B	2017-07-07 17:46:00+03	21800.00
860C9D	2017-07-18 22:17:00+03	81700.00
860CCC	2017-07-28 08:10:00+03	188000.00
860CD0	2017-07-02 14:58:00+03	13700.00
860D03	2017-08-14 09:37:00+03	73600.00
860D06	2017-06-30 03:05:00+03	28800.00
860D0A	2017-07-13 05:38:00+03	64800.00
860D0D	2017-07-31 16:39:00+03	28800.00
860D10	2017-07-07 05:38:00+03	166100.00
860D1B	2017-07-29 21:26:00+03	246000.00
860D2B	2017-07-21 20:34:00+03	21400.00
860DBD	2017-08-06 16:58:00+03	35600.00
860E33	2017-08-09 04:53:00+03	46400.00
860E65	2017-08-02 04:26:00+03	23600.00
860EB1	2017-07-15 03:49:00+03	70700.00
860EE3	2017-07-06 17:27:00+03	58100.00
860F11	2017-07-20 12:42:00+03	22000.00
860F18	2017-07-06 19:35:00+03	81500.00
860F48	2017-08-04 00:20:00+03	57500.00
860F8F	2017-08-01 09:53:00+03	56000.00
860F9D	2017-08-12 15:48:00+03	67600.00
861040	2017-07-17 06:02:00+03	84800.00
861102	2017-07-22 04:41:00+03	117200.00
86112B	2017-07-14 00:08:00+03	119500.00
861131	2017-08-10 04:28:00+03	65100.00
861135	2017-07-14 12:44:00+03	42700.00
861187	2017-07-20 07:59:00+03	27200.00
8611AF	2017-07-13 16:08:00+03	46300.00
8611E2	2017-07-19 20:33:00+03	12600.00
861252	2017-07-09 22:57:00+03	34000.00
861268	2017-08-10 19:18:00+03	65500.00
8612B9	2017-08-03 20:33:00+03	16800.00
861334	2017-08-11 16:04:00+03	61500.00
861401	2017-07-17 16:43:00+03	165500.00
86148F	2017-07-30 03:33:00+03	60300.00
861494	2017-08-08 05:18:00+03	167200.00
8614E5	2017-08-04 17:00:00+03	14000.00
861540	2017-07-10 19:09:00+03	16800.00
861541	2017-07-12 13:53:00+03	123600.00
861548	2017-07-05 00:17:00+03	56600.00
861597	2017-07-21 05:22:00+03	57400.00
8615BB	2017-07-10 15:49:00+03	88200.00
8615E2	2017-07-25 03:19:00+03	123200.00
86160B	2017-07-28 10:52:00+03	35600.00
86164F	2017-08-08 11:45:00+03	26900.00
861686	2017-07-08 09:00:00+03	21400.00
861689	2017-08-12 21:13:00+03	78200.00
8616D8	2017-08-07 10:14:00+03	206700.00
86174B	2017-07-09 18:47:00+03	35800.00
861752	2017-07-31 04:05:00+03	75800.00
86179E	2017-08-05 00:34:00+03	85200.00
8617BF	2017-07-19 03:28:00+03	70800.00
86187B	2017-07-09 03:13:00+03	313800.00
86189B	2017-07-16 13:59:00+03	69100.00
8618A2	2017-07-17 01:16:00+03	7800.00
8619A6	2017-07-21 13:17:00+03	56000.00
861A82	2017-08-06 19:40:00+03	37900.00
861A9E	2017-07-27 03:59:00+03	115700.00
861B03	2017-08-01 23:06:00+03	25000.00
861BB6	2017-07-16 06:43:00+03	26700.00
861BB9	2017-07-27 12:51:00+03	113300.00
861BF6	2017-08-13 19:00:00+03	16400.00
861C18	2017-08-09 18:13:00+03	25400.00
861C62	2017-07-12 02:53:00+03	48300.00
861D15	2017-08-07 20:16:00+03	63500.00
861D4E	2017-07-12 08:41:00+03	57200.00
861D53	2017-07-13 16:14:00+03	254900.00
861D72	2017-07-21 10:59:00+03	56600.00
861DA9	2017-06-28 19:31:00+03	95000.00
861DD6	2017-07-05 04:11:00+03	24800.00
861E08	2017-07-14 02:01:00+03	26200.00
861E28	2017-08-13 13:09:00+03	26000.00
861E43	2017-08-15 07:57:00+03	118500.00
861E53	2017-08-06 02:04:00+03	55600.00
861E93	2017-08-11 02:00:00+03	80700.00
861ED6	2017-07-25 06:09:00+03	63600.00
861EEA	2017-07-30 11:25:00+03	84300.00
861F43	2017-07-23 16:31:00+03	25600.00
861F52	2017-07-13 10:28:00+03	127500.00
86203C	2017-07-12 08:06:00+03	86500.00
86205C	2017-08-04 02:33:00+03	103600.00
86208D	2017-07-28 23:58:00+03	123000.00
862275	2017-07-27 02:57:00+03	54800.00
8622C7	2017-08-06 15:44:00+03	269600.00
8622FB	2017-08-12 18:14:00+03	62600.00
8623CF	2017-07-08 03:41:00+03	25800.00
8623EA	2017-07-27 04:00:00+03	17600.00
86240D	2017-07-09 08:13:00+03	75600.00
862444	2017-07-06 19:03:00+03	56000.00
862458	2017-07-20 23:21:00+03	16000.00
86246C	2017-07-03 06:42:00+03	101900.00
862474	2017-07-20 22:51:00+03	153300.00
862479	2017-08-11 11:47:00+03	130300.00
8624C9	2017-08-13 10:44:00+03	56100.00
8624CB	2017-07-12 18:45:00+03	62600.00
862520	2017-08-12 13:02:00+03	46200.00
862522	2017-07-04 18:02:00+03	14400.00
862537	2017-07-11 18:27:00+03	408500.00
86253B	2017-07-05 23:16:00+03	34600.00
86258D	2017-07-01 06:00:00+03	35600.00
8625C0	2017-08-05 11:01:00+03	53600.00
86264A	2017-07-23 05:56:00+03	23200.00
862697	2017-07-30 16:39:00+03	37900.00
862726	2017-07-20 08:57:00+03	55800.00
862745	2017-08-08 03:26:00+03	301800.00
86276A	2017-08-15 01:54:00+03	256400.00
86276D	2017-07-29 15:06:00+03	26000.00
862784	2017-08-08 13:13:00+03	25000.00
86279E	2017-07-09 05:57:00+03	19600.00
8627A2	2017-08-09 11:24:00+03	43600.00
8627F4	2017-08-08 22:05:00+03	23900.00
86281E	2017-07-31 21:43:00+03	21800.00
86282F	2017-07-16 15:05:00+03	28700.00
86283E	2017-08-11 03:27:00+03	28000.00
862866	2017-07-03 02:37:00+03	28200.00
86290B	2017-07-05 23:43:00+03	16800.00
862961	2017-06-30 17:28:00+03	173900.00
8629C0	2017-07-16 01:41:00+03	20200.00
8629E2	2017-07-07 07:23:00+03	56100.00
8629EF	2017-07-21 22:55:00+03	615000.00
862A39	2017-07-26 09:58:00+03	76600.00
862A6F	2017-08-14 19:12:00+03	187800.00
862A74	2017-08-06 20:38:00+03	135000.00
862AB2	2017-07-26 05:05:00+03	111600.00
862AB5	2017-08-11 13:17:00+03	14400.00
862ADD	2017-07-14 05:26:00+03	266400.00
862B8A	2017-07-20 22:59:00+03	94000.00
862B8B	2017-07-06 13:01:00+03	168000.00
862BA8	2017-07-16 04:12:00+03	14000.00
862C21	2017-08-05 06:33:00+03	32900.00
862C49	2017-07-06 22:21:00+03	6700.00
862C5B	2017-07-07 10:02:00+03	325500.00
862C71	2017-08-04 23:59:00+03	54600.00
862D63	2017-08-11 16:45:00+03	112000.00
862D86	2017-07-09 00:35:00+03	13000.00
862E2E	2017-07-09 09:02:00+03	32700.00
862E54	2017-08-02 04:23:00+03	89600.00
862F2B	2017-07-08 01:42:00+03	121800.00
862F49	2017-06-29 10:05:00+03	61800.00
862F9B	2017-07-11 23:31:00+03	32800.00
862FB1	2017-08-07 09:26:00+03	20200.00
862FB5	2017-07-18 10:00:00+03	6700.00
862FDF	2017-07-26 13:15:00+03	25400.00
863006	2017-07-04 02:11:00+03	56000.00
863123	2017-07-06 15:21:00+03	78300.00
863165	2017-07-18 21:38:00+03	47200.00
863174	2017-07-27 18:25:00+03	89600.00
86318E	2017-07-21 23:40:00+03	211000.00
8631AB	2017-08-15 09:49:00+03	28000.00
8631D7	2017-07-18 09:11:00+03	27200.00
8631EB	2017-07-27 18:22:00+03	56000.00
863217	2017-08-12 01:07:00+03	257600.00
86322F	2017-07-24 05:45:00+03	44800.00
863244	2017-07-04 19:38:00+03	31100.00
863245	2017-08-15 06:36:00+03	85000.00
86333B	2017-08-13 10:07:00+03	14400.00
863361	2017-07-23 13:47:00+03	32800.00
8633BE	2017-07-11 20:26:00+03	133100.00
8633F5	2017-07-17 14:44:00+03	40400.00
86341B	2017-07-06 23:18:00+03	36000.00
86349A	2017-08-12 00:16:00+03	168000.00
8634AB	2017-08-04 09:24:00+03	46900.00
863531	2017-07-25 03:12:00+03	149400.00
8635B3	2017-08-05 03:30:00+03	25100.00
8635EA	2017-07-01 08:38:00+03	31900.00
863610	2017-07-29 17:19:00+03	31100.00
863649	2017-07-13 01:15:00+03	50300.00
86366C	2017-07-16 19:29:00+03	88600.00
8636D0	2017-07-21 04:23:00+03	17200.00
863704	2017-08-11 14:34:00+03	111600.00
863733	2017-08-09 21:27:00+03	131600.00
86383C	2017-07-17 14:41:00+03	100200.00
863878	2017-07-02 05:08:00+03	49100.00
86396B	2017-08-03 20:06:00+03	32800.00
8639AD	2017-08-07 21:34:00+03	47100.00
8639B7	2017-06-29 22:35:00+03	56600.00
863A38	2017-08-15 12:59:00+03	227200.00
863A57	2017-07-04 22:28:00+03	10800.00
863A58	2017-08-13 21:11:00+03	32900.00
863AA0	2017-07-06 02:38:00+03	137900.00
863B01	2017-07-06 05:08:00+03	31200.00
863B02	2017-07-24 06:35:00+03	87200.00
863B1F	2017-07-26 16:16:00+03	18800.00
863B2E	2017-08-14 10:06:00+03	40000.00
863B8B	2017-08-05 14:35:00+03	68100.00
863BB1	2017-08-07 04:04:00+03	33100.00
863BB7	2017-08-05 18:39:00+03	55800.00
863C29	2017-07-11 07:08:00+03	38200.00
863C67	2017-07-04 02:07:00+03	105600.00
863C90	2017-07-14 17:33:00+03	106400.00
863C91	2017-07-14 21:49:00+03	132800.00
863C9B	2017-07-13 16:02:00+03	13700.00
863D94	2017-07-09 14:10:00+03	24700.00
863DA4	2017-07-31 14:59:00+03	136200.00
863EEF	2017-07-18 11:22:00+03	71000.00
863FDC	2017-06-27 14:32:00+03	31000.00
863FE1	2017-08-12 00:21:00+03	426200.00
863FE4	2017-07-22 01:52:00+03	28800.00
86409D	2017-07-11 04:28:00+03	28600.00
8640A1	2017-07-12 05:23:00+03	139800.00
8640D0	2017-08-08 21:38:00+03	60400.00
8640ED	2017-07-31 06:58:00+03	12600.00
8640FC	2017-07-14 18:14:00+03	56000.00
864106	2017-08-11 12:56:00+03	72000.00
86411D	2017-07-13 13:00:00+03	25600.00
864133	2017-07-12 14:17:00+03	17200.00
86415D	2017-07-26 15:49:00+03	135200.00
86415F	2017-08-11 05:22:00+03	88100.00
86416B	2017-06-28 05:41:00+03	8000.00
864170	2017-07-14 02:28:00+03	26700.00
8641CC	2017-07-01 15:49:00+03	301800.00
8641E4	2017-07-23 23:41:00+03	46400.00
86422D	2017-08-07 08:42:00+03	93000.00
8642BC	2017-08-12 06:24:00+03	59800.00
864359	2017-07-19 20:17:00+03	49600.00
8643B5	2017-07-30 19:08:00+03	128800.00
8643BE	2017-07-05 15:53:00+03	42800.00
8643CA	2017-07-13 05:29:00+03	10200.00
8643CF	2017-07-24 20:37:00+03	152900.00
8643E7	2017-07-07 04:28:00+03	76800.00
86441A	2017-08-03 12:15:00+03	136800.00
86442B	2017-08-10 20:53:00+03	70800.00
86443A	2017-07-24 20:50:00+03	86000.00
8644A0	2017-07-02 16:26:00+03	73300.00
8644A4	2017-08-08 07:48:00+03	29600.00
8644D9	2017-08-13 10:18:00+03	246000.00
864585	2017-07-07 10:55:00+03	25800.00
864661	2017-07-09 18:02:00+03	28800.00
864670	2017-07-12 17:14:00+03	46300.00
8646A2	2017-08-11 01:32:00+03	88500.00
8646D3	2017-07-28 03:05:00+03	31400.00
864717	2017-07-01 06:01:00+03	54800.00
864724	2017-08-12 21:37:00+03	179900.00
864732	2017-07-30 11:49:00+03	26000.00
864739	2017-06-28 22:02:00+03	15000.00
86473F	2017-07-15 13:45:00+03	131600.00
864752	2017-08-12 12:44:00+03	27700.00
86477B	2017-07-27 14:44:00+03	36200.00
8647B9	2017-07-10 16:21:00+03	89600.00
864879	2017-06-30 11:33:00+03	165100.00
8648DD	2017-08-15 17:58:00+03	93000.00
8648F0	2017-07-29 12:52:00+03	77200.00
86493B	2017-07-05 02:02:00+03	36200.00
864945	2017-07-28 07:52:00+03	28600.00
864978	2017-07-15 23:30:00+03	60300.00
86497A	2017-08-15 16:19:00+03	56000.00
8649B6	2017-07-31 22:23:00+03	137100.00
8649DE	2017-08-11 18:36:00+03	31200.00
8649F0	2017-07-22 22:34:00+03	26000.00
864A13	2017-07-15 16:07:00+03	153300.00
864A1D	2017-07-23 08:52:00+03	131100.00
864A34	2017-08-12 18:43:00+03	66900.00
864A5B	2017-07-31 18:13:00+03	94700.00
864A99	2017-07-20 22:47:00+03	144400.00
864AD2	2017-08-09 23:29:00+03	28000.00
864AEC	2017-07-13 13:00:00+03	29000.00
864AFE	2017-07-29 16:38:00+03	26400.00
864B21	2017-07-27 05:53:00+03	37200.00
864B9F	2017-08-14 15:28:00+03	28200.00
864BC4	2017-08-15 12:53:00+03	40200.00
864BEC	2017-07-17 14:14:00+03	72200.00
864BF2	2017-07-10 04:27:00+03	133100.00
864C16	2017-07-21 02:38:00+03	87200.00
864C41	2017-07-10 06:22:00+03	78600.00
864C6C	2017-07-14 07:40:00+03	53600.00
864C7F	2017-07-31 14:36:00+03	246000.00
864D91	2017-07-21 01:21:00+03	21800.00
864E3D	2017-08-01 04:01:00+03	615000.00
864E7B	2017-08-11 06:50:00+03	112000.00
864EE7	2017-08-05 00:55:00+03	153900.00
864F5A	2017-07-11 13:11:00+03	39600.00
864F74	2017-07-06 07:35:00+03	20400.00
864F9A	2017-07-13 05:12:00+03	28000.00
864FBE	2017-07-28 22:43:00+03	121800.00
864FC4	2017-08-06 18:07:00+03	12400.00
8650AF	2017-07-28 16:05:00+03	43600.00
8650C4	2017-08-07 00:00:00+03	42400.00
865122	2017-06-29 14:37:00+03	23200.00
865317	2017-07-10 09:08:00+03	213800.00
86533A	2017-07-22 21:58:00+03	75300.00
865372	2017-08-03 17:42:00+03	21000.00
86537A	2017-08-07 13:50:00+03	43200.00
86538C	2017-08-14 16:47:00+03	12600.00
8653A5	2017-07-21 23:56:00+03	279600.00
8653B3	2017-07-06 11:06:00+03	156500.00
8653FB	2017-07-28 08:45:00+03	76900.00
865400	2017-08-14 12:49:00+03	22600.00
865403	2017-07-30 15:12:00+03	128800.00
86542F	2017-07-11 10:56:00+03	16400.00
865493	2017-07-09 12:10:00+03	24800.00
865496	2017-08-05 11:48:00+03	48800.00
865562	2017-08-04 05:45:00+03	13700.00
8655AF	2017-07-10 11:30:00+03	99200.00
8655C3	2017-07-06 08:28:00+03	23400.00
8655DE	2017-06-29 22:32:00+03	86800.00
86562A	2017-07-14 19:12:00+03	48400.00
8656B3	2017-08-08 21:04:00+03	26000.00
8656D3	2017-07-15 09:23:00+03	68400.00
8656D5	2017-07-18 11:43:00+03	22100.00
865755	2017-08-08 20:03:00+03	67200.00
865782	2017-07-18 13:28:00+03	177600.00
8657F0	2017-08-15 16:17:00+03	62900.00
86586D	2017-06-29 18:11:00+03	132800.00
8658B1	2017-07-22 05:45:00+03	25800.00
865956	2017-07-27 05:35:00+03	28800.00
86596E	2017-07-08 19:33:00+03	112000.00
865A29	2017-08-04 22:04:00+03	240600.00
865A78	2017-08-11 04:56:00+03	123000.00
865A80	2017-08-01 21:54:00+03	61800.00
865AA0	2017-06-28 04:19:00+03	47200.00
865ACE	2017-07-25 00:56:00+03	115800.00
865B5B	2017-07-09 08:42:00+03	91500.00
865B71	2017-07-15 23:55:00+03	36200.00
865BC2	2017-08-04 02:25:00+03	137600.00
865BEE	2017-07-14 12:21:00+03	56600.00
865BFF	2017-07-27 17:04:00+03	32700.00
865CD4	2017-08-13 01:04:00+03	20200.00
865E04	2017-07-16 14:01:00+03	215000.00
865E4C	2017-07-10 16:41:00+03	44600.00
865E4F	2017-06-26 10:23:00+03	32100.00
865E6E	2017-08-05 08:17:00+03	48500.00
865ED6	2017-07-23 02:00:00+03	33300.00
865EDD	2017-07-21 08:15:00+03	85000.00
865F16	2017-08-07 01:47:00+03	73600.00
865FCF	2017-07-14 06:21:00+03	42800.00
865FD7	2017-08-09 19:13:00+03	136200.00
866000	2017-07-06 11:02:00+03	18000.00
866004	2017-07-25 18:49:00+03	23200.00
86601B	2017-08-01 15:10:00+03	63500.00
86607C	2017-07-24 18:19:00+03	84000.00
866099	2017-07-02 03:38:00+03	25800.00
86609B	2017-08-12 20:59:00+03	206700.00
86609E	2017-08-11 12:01:00+03	94600.00
8660DD	2017-08-13 08:53:00+03	38600.00
866117	2017-07-10 11:21:00+03	185600.00
8661D0	2017-07-27 08:58:00+03	123000.00
8661FC	2017-07-21 17:44:00+03	68000.00
86624E	2017-07-20 09:48:00+03	36200.00
86625D	2017-08-12 03:17:00+03	75600.00
86626D	2017-07-18 21:03:00+03	54400.00
8662B1	2017-07-07 14:31:00+03	38800.00
8662F7	2017-07-03 07:48:00+03	86800.00
86634E	2017-07-10 08:33:00+03	156600.00
866387	2017-07-08 01:04:00+03	172000.00
866399	2017-07-21 01:04:00+03	37700.00
86639C	2017-07-16 12:26:00+03	79900.00
86640E	2017-08-09 17:52:00+03	40800.00
86644E	2017-07-05 07:02:00+03	25400.00
8664DB	2017-08-06 14:01:00+03	68400.00
8664E9	2017-08-15 17:34:00+03	51900.00
866526	2017-07-28 06:28:00+03	62800.00
86652E	2017-08-12 00:41:00+03	13700.00
866547	2017-07-16 15:06:00+03	81700.00
86660E	2017-08-02 20:54:00+03	27300.00
86661C	2017-08-15 12:47:00+03	29900.00
866629	2017-07-19 20:35:00+03	92900.00
86664D	2017-07-26 22:32:00+03	28800.00
86666D	2017-07-19 10:15:00+03	57300.00
866674	2017-07-16 00:01:00+03	166400.00
8666C1	2017-07-22 08:46:00+03	56000.00
86670F	2017-07-11 23:53:00+03	37500.00
866716	2017-07-04 05:46:00+03	66600.00
866744	2017-07-29 05:16:00+03	7400.00
866769	2017-07-09 16:43:00+03	56000.00
86678C	2017-07-17 15:44:00+03	25000.00
8667D8	2017-07-18 02:34:00+03	43500.00
866863	2017-07-11 20:06:00+03	123000.00
86687D	2017-08-02 22:03:00+03	52800.00
866918	2017-07-31 12:38:00+03	64700.00
866955	2017-08-11 10:48:00+03	32600.00
866993	2017-07-24 05:27:00+03	86600.00
866A14	2017-06-30 12:23:00+03	26000.00
866A25	2017-07-25 08:54:00+03	29600.00
866A58	2017-07-14 21:15:00+03	67200.00
866A62	2017-07-03 11:59:00+03	50800.00
866AA3	2017-07-27 07:28:00+03	108600.00
866B93	2017-08-11 20:53:00+03	28000.00
866BCB	2017-07-31 15:07:00+03	81700.00
866C17	2017-07-22 07:44:00+03	46400.00
866C25	2017-08-03 07:02:00+03	9800.00
866C3B	2017-08-14 02:52:00+03	21400.00
866C71	2017-08-01 05:38:00+03	35200.00
866C83	2017-07-07 08:25:00+03	37900.00
866C9D	2017-07-24 00:44:00+03	270800.00
866CDE	2017-07-20 08:02:00+03	48800.00
866CE5	2017-07-02 17:59:00+03	6700.00
866D1E	2017-08-10 12:15:00+03	28800.00
866D5A	2017-07-11 06:16:00+03	13700.00
866D78	2017-08-01 17:44:00+03	84000.00
866D93	2017-08-12 13:22:00+03	51100.00
866DD4	2017-08-09 15:42:00+03	46400.00
866DFA	2017-08-10 18:38:00+03	73300.00
866E31	2017-08-14 13:04:00+03	26800.00
866E49	2017-07-09 12:14:00+03	12600.00
866E93	2017-07-24 20:34:00+03	26200.00
866EA6	2017-08-05 21:53:00+03	14000.00
866EF8	2017-08-01 17:12:00+03	188000.00
866F0C	2017-07-22 19:36:00+03	118700.00
866F16	2017-07-30 09:30:00+03	46400.00
866F27	2017-07-29 08:08:00+03	52300.00
866FA5	2017-07-11 19:51:00+03	113800.00
866FBE	2017-08-02 17:44:00+03	57600.00
866FC0	2017-07-19 10:14:00+03	56000.00
866FF0	2017-08-01 16:51:00+03	101400.00
866FFF	2017-06-30 23:41:00+03	187900.00
86700B	2017-08-13 22:20:00+03	75600.00
86704B	2017-07-12 05:29:00+03	86300.00
867082	2017-07-22 15:15:00+03	58000.00
86711C	2017-07-15 18:44:00+03	184200.00
867135	2017-07-13 09:06:00+03	103500.00
86714A	2017-08-10 10:56:00+03	202000.00
867153	2017-07-18 04:30:00+03	8200.00
867173	2017-07-22 12:08:00+03	62600.00
86717B	2017-08-05 08:12:00+03	54800.00
867239	2017-07-25 15:15:00+03	24400.00
867241	2017-07-22 18:52:00+03	52000.00
867244	2017-07-06 09:17:00+03	167400.00
86725F	2017-08-09 20:48:00+03	21400.00
867285	2017-07-20 11:26:00+03	31600.00
8672BF	2017-07-13 07:59:00+03	46400.00
8672D7	2017-07-29 04:00:00+03	102100.00
8672D9	2017-07-01 12:17:00+03	94000.00
8673F5	2017-07-21 03:36:00+03	132800.00
867410	2017-08-14 08:29:00+03	40000.00
867504	2017-08-02 06:09:00+03	89600.00
867543	2017-08-09 03:24:00+03	137600.00
867554	2017-07-11 18:47:00+03	56600.00
867564	2017-08-11 16:13:00+03	21400.00
86757B	2017-07-23 18:48:00+03	20200.00
8675D0	2017-07-08 04:25:00+03	24400.00
86765B	2017-07-19 18:43:00+03	38800.00
867696	2017-06-30 05:12:00+03	19600.00
8676D5	2017-07-25 09:29:00+03	58800.00
867766	2017-08-12 20:38:00+03	31200.00
8677D0	2017-07-05 11:49:00+03	52400.00
867819	2017-06-27 02:56:00+03	271200.00
867858	2017-07-26 03:52:00+03	24000.00
8678A9	2017-07-22 03:13:00+03	21800.00
86791F	2017-07-02 01:08:00+03	39500.00
86795B	2017-07-20 15:53:00+03	81600.00
86796F	2017-08-15 13:48:00+03	26600.00
867972	2017-07-06 08:51:00+03	69500.00
867976	2017-07-27 21:56:00+03	6700.00
867998	2017-08-13 14:15:00+03	29600.00
8679E1	2017-08-13 22:25:00+03	47800.00
867A11	2017-07-10 02:40:00+03	47000.00
867A5D	2017-07-10 07:54:00+03	38200.00
867A5F	2017-07-13 11:17:00+03	17800.00
867A9F	2017-08-02 20:46:00+03	65900.00
867AA2	2017-07-17 17:31:00+03	23200.00
867AF8	2017-08-06 18:00:00+03	46000.00
867B10	2017-07-27 22:12:00+03	219900.00
867B46	2017-07-31 21:51:00+03	73600.00
867B75	2017-08-10 03:52:00+03	118100.00
867B96	2017-07-26 17:42:00+03	344100.00
867BC9	2017-08-05 03:04:00+03	44000.00
867BE9	2017-08-04 01:00:00+03	23200.00
867C06	2017-08-15 06:14:00+03	84500.00
867C0B	2017-08-04 15:16:00+03	8200.00
867C41	2017-07-26 17:05:00+03	68800.00
867CBE	2017-07-12 08:45:00+03	51600.00
867CC1	2017-08-10 23:52:00+03	24400.00
867D17	2017-07-11 23:03:00+03	35300.00
867D21	2017-08-15 01:12:00+03	19600.00
867E43	2017-07-10 22:06:00+03	109300.00
867ED6	2017-07-16 23:49:00+03	60400.00
867EF0	2017-07-27 05:44:00+03	280600.00
867F25	2017-07-01 09:39:00+03	23600.00
867F6A	2017-07-14 15:35:00+03	99300.00
867F8D	2017-07-26 12:04:00+03	62800.00
867FCD	2017-07-24 22:19:00+03	26800.00
867FF9	2017-07-11 07:04:00+03	135600.00
86800F	2017-07-28 06:55:00+03	69400.00
86801C	2017-07-22 10:49:00+03	65900.00
86805F	2017-07-25 17:11:00+03	112000.00
868094	2017-08-14 09:36:00+03	78300.00
8680A3	2017-08-07 22:48:00+03	77300.00
86812C	2017-07-10 17:11:00+03	141100.00
868137	2017-08-10 02:10:00+03	16400.00
8681C9	2017-07-24 05:14:00+03	29600.00
868247	2017-08-02 17:50:00+03	189200.00
868275	2017-07-12 10:05:00+03	69600.00
8682DF	2017-07-31 04:38:00+03	76100.00
868324	2017-07-27 19:56:00+03	87100.00
868375	2017-06-30 14:56:00+03	31600.00
86838E	2017-07-27 10:04:00+03	71900.00
868392	2017-08-03 20:20:00+03	62000.00
868393	2017-07-09 06:15:00+03	85000.00
868455	2017-08-11 02:38:00+03	23200.00
86848A	2017-07-13 21:03:00+03	26000.00
8684A2	2017-08-15 07:49:00+03	69500.00
8684A3	2017-08-12 01:56:00+03	13400.00
8684A8	2017-08-04 22:58:00+03	76400.00
8684FA	2017-07-08 19:36:00+03	19800.00
868538	2017-07-14 05:38:00+03	290400.00
86853A	2017-08-02 23:38:00+03	271200.00
868566	2017-08-01 04:38:00+03	25400.00
868591	2017-08-12 05:30:00+03	28000.00
8685C1	2017-07-06 10:51:00+03	40000.00
8686E4	2017-07-21 23:31:00+03	48800.00
86871F	2017-07-30 17:00:00+03	47100.00
868735	2017-07-28 00:28:00+03	26000.00
868790	2017-07-24 04:28:00+03	150300.00
8687F6	2017-08-12 20:58:00+03	62700.00
86886B	2017-07-09 04:28:00+03	23600.00
8688A1	2017-07-29 17:44:00+03	28000.00
8688D7	2017-08-06 08:49:00+03	38600.00
8688F6	2017-08-15 17:59:00+03	342300.00
8688FA	2017-07-12 13:36:00+03	45200.00
868914	2017-07-16 14:38:00+03	23200.00
86898C	2017-07-08 02:37:00+03	46800.00
868A13	2017-07-22 07:59:00+03	191700.00
868A64	2017-06-30 16:01:00+03	134400.00
868A78	2017-07-23 15:42:00+03	93900.00
868B1D	2017-07-28 10:16:00+03	64100.00
868BA1	2017-07-17 15:41:00+03	44800.00
868BAC	2017-08-08 12:06:00+03	90100.00
868BEA	2017-08-14 07:33:00+03	148200.00
868C0C	2017-07-01 04:56:00+03	32100.00
868C88	2017-07-22 12:41:00+03	102100.00
868CA4	2017-07-09 16:18:00+03	28000.00
868D37	2017-08-05 19:50:00+03	14800.00
868D62	2017-07-19 18:32:00+03	26700.00
868D71	2017-07-17 10:53:00+03	18000.00
868D89	2017-07-06 05:31:00+03	30000.00
868D94	2017-08-10 09:41:00+03	55800.00
868DE6	2017-07-03 09:05:00+03	36200.00
868DF1	2017-07-23 14:10:00+03	50600.00
868E02	2017-07-28 11:01:00+03	242700.00
868F00	2017-07-07 12:02:00+03	21400.00
868F03	2017-07-31 16:35:00+03	46000.00
868F21	2017-07-07 13:56:00+03	23200.00
868F61	2017-07-06 07:37:00+03	99300.00
868F96	2017-07-28 17:48:00+03	116000.00
868FAE	2017-07-24 18:31:00+03	61500.00
86903A	2017-08-02 03:43:00+03	49400.00
8690D1	2017-07-16 23:55:00+03	139200.00
8690E4	2017-07-27 19:24:00+03	119800.00
8690E5	2017-08-03 21:57:00+03	24800.00
869132	2017-08-10 11:22:00+03	278400.00
869171	2017-07-17 01:08:00+03	301800.00
869199	2017-07-31 01:22:00+03	27800.00
8691AB	2017-08-05 03:36:00+03	10700.00
8691B4	2017-07-31 02:43:00+03	52300.00
8691C7	2017-07-06 00:59:00+03	26200.00
86922C	2017-07-23 09:45:00+03	43200.00
8692A6	2017-07-07 03:48:00+03	12000.00
8692CE	2017-07-24 23:59:00+03	125200.00
869300	2017-07-12 22:55:00+03	13400.00
86931B	2017-07-25 06:59:00+03	139100.00
869330	2017-07-16 05:47:00+03	25800.00
869348	2017-07-28 21:19:00+03	31600.00
869363	2017-07-21 14:07:00+03	787500.00
8693FB	2017-08-14 07:03:00+03	53700.00
869427	2017-07-06 17:04:00+03	124200.00
8694AE	2017-07-05 16:14:00+03	14000.00
869535	2017-07-14 11:27:00+03	64600.00
869539	2017-07-23 13:42:00+03	38800.00
869549	2017-07-20 21:18:00+03	28000.00
86954C	2017-08-13 09:42:00+03	36400.00
869579	2017-07-06 06:06:00+03	56600.00
8695AA	2017-07-17 18:48:00+03	53600.00
8695BC	2017-08-09 17:49:00+03	25600.00
869625	2017-07-16 10:21:00+03	28200.00
86963A	2017-07-13 03:39:00+03	22000.00
869688	2017-07-09 15:33:00+03	84800.00
869689	2017-08-14 10:49:00+03	59800.00
8696A6	2017-07-10 11:18:00+03	73600.00
8696A9	2017-08-11 21:52:00+03	284300.00
869711	2017-08-04 03:07:00+03	51200.00
86971D	2017-07-06 05:58:00+03	147100.00
86972E	2017-08-02 14:56:00+03	28800.00
869755	2017-07-01 14:39:00+03	29400.00
869764	2017-07-09 11:42:00+03	34000.00
869785	2017-08-01 18:58:00+03	168000.00
86978F	2017-08-07 09:26:00+03	27300.00
8697AF	2017-08-13 15:34:00+03	28800.00
8697DD	2017-08-06 10:27:00+03	65900.00
86981C	2017-07-02 13:48:00+03	24300.00
8698FA	2017-07-08 08:28:00+03	57500.00
869910	2017-07-17 12:19:00+03	50700.00
8699A1	2017-06-30 18:56:00+03	36200.00
8699B4	2017-07-30 03:34:00+03	113800.00
869A7B	2017-08-01 09:56:00+03	33600.00
869ABE	2017-07-25 07:45:00+03	57400.00
869B0A	2017-07-06 21:47:00+03	16400.00
869C05	2017-07-12 07:55:00+03	91500.00
869C19	2017-08-12 07:28:00+03	56600.00
869C4B	2017-07-12 20:31:00+03	147700.00
869C99	2017-07-16 14:22:00+03	192700.00
869CA0	2017-07-20 21:16:00+03	111600.00
869CAF	2017-08-14 18:09:00+03	187800.00
869CE2	2017-07-13 03:19:00+03	153200.00
869D1F	2017-07-29 14:01:00+03	200200.00
869D28	2017-08-14 12:48:00+03	25100.00
869D4D	2017-06-26 22:22:00+03	67700.00
869E32	2017-07-23 21:50:00+03	81600.00
869F25	2017-06-26 20:50:00+03	48800.00
869F42	2017-07-28 02:50:00+03	182300.00
869F7D	2017-07-11 08:38:00+03	8000.00
869FAD	2017-07-10 22:03:00+03	6000.00
869FAF	2017-08-05 18:06:00+03	38600.00
869FC9	2017-08-06 08:04:00+03	55800.00
86A003	2017-07-22 21:04:00+03	16400.00
86A010	2017-08-15 16:37:00+03	53500.00
86A028	2017-07-05 05:38:00+03	36000.00
86A03C	2017-08-13 21:19:00+03	21400.00
86A0E5	2017-07-20 12:47:00+03	23600.00
86A14A	2017-08-10 05:22:00+03	76600.00
86A17E	2017-07-28 15:35:00+03	28000.00
86A1F0	2017-07-29 04:46:00+03	92600.00
86A247	2017-07-09 22:37:00+03	80000.00
86A2E8	2017-07-05 23:42:00+03	21200.00
86A349	2017-07-20 00:47:00+03	133100.00
86A380	2017-07-01 09:47:00+03	67400.00
86A39B	2017-07-05 15:11:00+03	73300.00
86A3B3	2017-07-30 15:37:00+03	109400.00
86A3B9	2017-07-18 21:42:00+03	14400.00
86A425	2017-08-10 14:58:00+03	110300.00
86A464	2017-07-29 02:52:00+03	23400.00
86A4E9	2017-07-28 02:02:00+03	27200.00
86A57E	2017-07-23 12:21:00+03	42800.00
86A57F	2017-08-13 22:35:00+03	95700.00
86A698	2017-07-21 01:17:00+03	29600.00
86A6BC	2017-07-27 11:02:00+03	126500.00
86A6D8	2017-07-06 22:37:00+03	86500.00
86A74F	2017-07-28 08:36:00+03	52000.00
86A751	2017-08-13 11:34:00+03	29800.00
86A7AE	2017-07-05 11:05:00+03	31400.00
86A7CA	2017-08-02 12:47:00+03	94000.00
86A7D2	2017-07-15 18:08:00+03	124400.00
86A802	2017-08-15 02:35:00+03	23600.00
86A886	2017-07-20 02:00:00+03	75300.00
86A8A7	2017-08-11 22:36:00+03	139000.00
86A8B3	2017-07-11 00:08:00+03	135400.00
86A943	2017-07-06 08:37:00+03	57800.00
86A95F	2017-08-12 11:37:00+03	39800.00
86A99C	2017-07-11 21:54:00+03	37900.00
86AA24	2017-07-25 09:01:00+03	35400.00
86AA3A	2017-07-22 05:36:00+03	23600.00
86AA59	2017-07-04 02:56:00+03	25900.00
86AA70	2017-08-01 18:17:00+03	54800.00
86AA7B	2017-07-16 00:34:00+03	13600.00
86AB37	2017-07-16 15:27:00+03	70700.00
86AB5B	2017-07-02 02:05:00+03	46300.00
86ABCB	2017-08-04 07:15:00+03	62600.00
86AC87	2017-07-20 00:38:00+03	32700.00
86ACA7	2017-08-13 09:45:00+03	61800.00
86ACBA	2017-08-04 21:54:00+03	13600.00
86ACD7	2017-07-16 00:31:00+03	12600.00
86ACEB	2017-07-08 16:14:00+03	47400.00
86AD26	2017-08-03 07:01:00+03	28800.00
86AD8C	2017-07-08 03:42:00+03	58600.00
86AE25	2017-07-24 10:30:00+03	48800.00
86AE49	2017-07-16 15:06:00+03	92000.00
86AE53	2017-07-24 21:14:00+03	16400.00
86AE70	2017-07-04 09:00:00+03	31700.00
86AECC	2017-08-13 17:39:00+03	89700.00
86AFBD	2017-06-30 17:29:00+03	59800.00
86B076	2017-08-04 21:03:00+03	86300.00
86B08F	2017-07-17 08:40:00+03	52700.00
86B0D3	2017-08-12 13:23:00+03	111000.00
86B0DF	2017-08-03 03:57:00+03	73500.00
86B118	2017-08-08 05:33:00+03	119600.00
86B122	2017-07-12 02:09:00+03	37600.00
86B17A	2017-07-22 08:51:00+03	103500.00
86B19E	2017-08-05 19:32:00+03	32200.00
86B1AF	2017-07-10 16:43:00+03	80900.00
86B1E9	2017-07-08 04:32:00+03	37600.00
86B203	2017-07-23 12:23:00+03	12600.00
86B207	2017-07-28 23:49:00+03	14000.00
86B214	2017-07-05 17:16:00+03	89600.00
86B25A	2017-08-02 08:16:00+03	20400.00
86B2C0	2017-07-06 19:48:00+03	35600.00
86B2CC	2017-07-31 01:38:00+03	32800.00
86B362	2017-08-10 01:09:00+03	99300.00
86B391	2017-07-06 22:34:00+03	75600.00
86B3A9	2017-07-01 04:53:00+03	136800.00
86B3B0	2017-08-15 01:15:00+03	13400.00
86B3FD	2017-07-16 16:58:00+03	615700.00
86B421	2017-08-02 12:35:00+03	14000.00
86B531	2017-08-06 20:01:00+03	82700.00
86B558	2017-07-02 01:11:00+03	81600.00
86B66F	2017-06-30 11:46:00+03	103200.00
86B691	2017-07-24 02:40:00+03	43200.00
86B6B3	2017-08-05 08:58:00+03	67700.00
86B6B6	2017-08-01 18:35:00+03	55800.00
86B6C4	2017-08-02 11:06:00+03	41200.00
86B6C9	2017-07-14 09:01:00+03	98400.00
86B6FD	2017-07-11 14:26:00+03	190400.00
86B72F	2017-08-03 13:15:00+03	92400.00
86B796	2017-06-28 00:15:00+03	47500.00
86B7A5	2017-07-07 12:20:00+03	66600.00
86B7B5	2017-07-24 04:08:00+03	60700.00
86B7C9	2017-07-09 02:14:00+03	38800.00
86B823	2017-07-27 22:59:00+03	61500.00
86B885	2017-07-04 10:20:00+03	24500.00
86B893	2017-08-08 05:15:00+03	99600.00
86B91D	2017-08-14 15:09:00+03	92800.00
86B977	2017-07-30 16:29:00+03	28800.00
86B9CF	2017-07-06 03:54:00+03	99800.00
86B9DD	2017-08-09 01:11:00+03	68000.00
86BA42	2017-08-15 17:56:00+03	76800.00
86BA70	2017-07-06 00:43:00+03	28000.00
86BACB	2017-07-03 13:46:00+03	124400.00
86BAF7	2017-08-12 08:51:00+03	135400.00
86BB6E	2017-07-31 08:51:00+03	13600.00
86BB94	2017-07-12 16:38:00+03	88600.00
86BBB6	2017-07-12 06:18:00+03	23400.00
86BBBD	2017-07-11 01:38:00+03	72100.00
86BC80	2017-07-09 04:14:00+03	20200.00
86BCF8	2017-07-03 20:20:00+03	115700.00
86BD23	2017-07-28 17:42:00+03	167500.00
86BD26	2017-08-11 03:02:00+03	32700.00
86BD30	2017-07-22 20:06:00+03	97600.00
86BD73	2017-08-05 10:22:00+03	194200.00
86BD7A	2017-08-09 11:26:00+03	31100.00
86BD8F	2017-07-13 03:53:00+03	73200.00
86BDDD	2017-07-11 12:27:00+03	6000.00
86BE27	2017-08-14 13:06:00+03	137100.00
86BE32	2017-07-05 09:41:00+03	136800.00
86BE58	2017-07-10 13:46:00+03	36000.00
86BE8F	2017-07-12 02:16:00+03	55800.00
86BF12	2017-07-18 05:47:00+03	103000.00
86BF1B	2017-08-12 21:23:00+03	162200.00
86BF27	2017-07-09 05:27:00+03	92200.00
86BF63	2017-07-23 16:47:00+03	88400.00
86BFD3	2017-07-02 19:31:00+03	111600.00
86BFF9	2017-08-14 08:28:00+03	31000.00
86C0BE	2017-07-07 18:19:00+03	6000.00
86C2B3	2017-08-09 22:12:00+03	43500.00
86C2BD	2017-08-15 16:28:00+03	15500.00
86C3DC	2017-07-29 12:17:00+03	30200.00
86C459	2017-07-09 01:13:00+03	33800.00
86C460	2017-08-03 14:33:00+03	110500.00
86C469	2017-06-27 07:51:00+03	50800.00
86C46F	2017-07-20 05:40:00+03	94400.00
86C50C	2017-08-02 04:06:00+03	88100.00
86C54E	2017-07-25 00:27:00+03	57600.00
86C587	2017-07-19 20:42:00+03	40000.00
86C5D7	2017-07-23 10:01:00+03	58600.00
86C5E0	2017-07-27 04:46:00+03	160000.00
86C613	2017-07-28 17:26:00+03	124300.00
86C63E	2017-07-01 06:41:00+03	23600.00
86C64A	2017-07-20 01:56:00+03	42800.00
86C651	2017-08-01 11:24:00+03	95200.00
86C657	2017-07-05 21:13:00+03	59300.00
86C6D1	2017-07-14 01:42:00+03	83800.00
86C6F6	2017-08-07 09:45:00+03	28000.00
86C6FF	2017-07-04 01:22:00+03	81300.00
86C72F	2017-08-08 11:27:00+03	59200.00
86C73B	2017-08-12 07:51:00+03	27200.00
86C741	2017-07-23 06:40:00+03	55600.00
86C7AB	2017-07-13 11:00:00+03	68400.00
86C7AF	2017-07-27 06:52:00+03	54800.00
86C7C0	2017-07-19 20:11:00+03	38600.00
86C7FF	2017-07-18 01:36:00+03	72400.00
86C87A	2017-08-10 18:25:00+03	59800.00
86C89A	2017-07-09 07:05:00+03	7400.00
86C8A0	2017-07-08 09:07:00+03	24300.00
86C8CC	2017-07-31 05:42:00+03	28000.00
86C99A	2017-07-26 05:44:00+03	31200.00
86CA03	2017-08-12 10:45:00+03	44800.00
86CA2A	2017-07-13 04:17:00+03	46500.00
86CA7C	2017-07-19 14:16:00+03	88800.00
86CB0A	2017-07-30 12:35:00+03	48800.00
86CB5D	2017-07-24 10:49:00+03	35700.00
86CB75	2017-08-03 01:47:00+03	16400.00
86CB96	2017-07-15 18:26:00+03	112000.00
86CBB3	2017-07-12 23:37:00+03	257500.00
86CBFF	2017-07-09 13:58:00+03	242600.00
86CC37	2017-08-06 16:21:00+03	39500.00
86CC45	2017-07-20 02:30:00+03	81600.00
86CCDA	2017-07-06 04:53:00+03	27200.00
86CD06	2017-08-03 01:30:00+03	134000.00
86CD15	2017-07-31 19:44:00+03	48800.00
86CDBA	2017-07-21 02:13:00+03	6800.00
86CDC5	2017-07-11 04:10:00+03	36800.00
86CDF7	2017-08-13 05:41:00+03	24200.00
86CE72	2017-07-26 22:53:00+03	27300.00
86CE79	2017-07-17 02:00:00+03	53700.00
86CF2D	2017-07-01 01:03:00+03	56000.00
86CF56	2017-07-07 23:19:00+03	146300.00
86CF97	2017-08-07 23:57:00+03	70700.00
86D023	2017-06-29 10:53:00+03	26000.00
86D028	2017-07-16 23:33:00+03	59100.00
86D03C	2017-06-30 22:23:00+03	84100.00
86D03F	2017-07-12 19:20:00+03	115100.00
86D07D	2017-06-29 10:54:00+03	40400.00
86D0F0	2017-08-07 00:41:00+03	62900.00
86D107	2017-08-13 04:38:00+03	24400.00
86D13C	2017-07-14 11:39:00+03	126300.00
86D150	2017-07-31 12:22:00+03	114800.00
86D161	2017-08-06 03:53:00+03	31200.00
86D1A4	2017-07-02 20:50:00+03	19600.00
86D1E8	2017-07-26 13:46:00+03	24700.00
86D1FC	2017-07-22 08:33:00+03	102100.00
86D212	2017-08-03 16:45:00+03	38800.00
86D287	2017-08-01 12:46:00+03	133200.00
86D29D	2017-07-09 01:24:00+03	398500.00
86D2A0	2017-08-04 02:56:00+03	24800.00
86D30B	2017-07-21 01:44:00+03	47200.00
86D348	2017-07-28 11:24:00+03	46000.00
86D38D	2017-07-15 08:13:00+03	39000.00
86D3D2	2017-07-20 14:39:00+03	35800.00
86D3EA	2017-07-28 21:30:00+03	15800.00
86D47A	2017-07-09 11:56:00+03	77600.00
86D4AE	2017-07-30 05:18:00+03	50800.00
86D576	2017-07-23 23:18:00+03	46400.00
86D57E	2017-07-24 09:56:00+03	515000.00
86D5B2	2017-07-14 18:14:00+03	65500.00
86D611	2017-07-29 06:05:00+03	134400.00
86D69D	2017-07-31 04:27:00+03	201200.00
86D69E	2017-07-29 13:17:00+03	44000.00
86D6D3	2017-07-12 00:12:00+03	103500.00
86D6F9	2017-06-30 16:31:00+03	32700.00
86D702	2017-08-01 02:12:00+03	7300.00
86D703	2017-07-19 03:21:00+03	24400.00
86D73C	2017-06-27 05:47:00+03	41600.00
86D741	2017-07-14 22:10:00+03	77500.00
86D749	2017-07-07 02:53:00+03	91500.00
86D780	2017-06-29 02:30:00+03	6000.00
86D7D3	2017-07-07 12:02:00+03	43200.00
86D7D6	2017-07-03 11:14:00+03	43200.00
86D826	2017-08-02 05:20:00+03	39800.00
86D852	2017-08-08 11:01:00+03	53600.00
86D85E	2017-07-30 08:50:00+03	8200.00
86D868	2017-08-06 16:29:00+03	14000.00
86D8D2	2017-08-09 18:45:00+03	18600.00
86D936	2017-07-20 04:40:00+03	58800.00
86D94E	2017-08-02 10:32:00+03	47700.00
86D9C2	2017-07-27 09:23:00+03	66000.00
86DA5A	2017-07-10 08:15:00+03	51000.00
86DAAC	2017-08-03 14:34:00+03	67700.00
86DAB0	2017-08-08 14:44:00+03	98400.00
86DAEE	2017-08-15 05:14:00+03	109000.00
86DB90	2017-07-18 07:44:00+03	300700.00
86DBB5	2017-08-02 08:06:00+03	47200.00
86DC0C	2017-08-01 22:33:00+03	26000.00
86DCAE	2017-07-26 10:08:00+03	6700.00
86DCC7	2017-07-27 20:32:00+03	73100.00
86DCDF	2017-08-06 22:49:00+03	135400.00
86DCF0	2017-07-09 23:07:00+03	18000.00
86DD25	2017-08-02 23:48:00+03	41800.00
86DD2D	2017-07-26 23:34:00+03	114400.00
86DD62	2017-08-14 10:35:00+03	17200.00
86DD71	2017-08-10 22:01:00+03	43200.00
86DDE6	2017-08-13 08:22:00+03	89700.00
86DE0C	2017-08-11 22:36:00+03	208200.00
86DE13	2017-07-27 01:55:00+03	93900.00
86DE4B	2017-07-17 11:38:00+03	89600.00
86DE6A	2017-07-16 16:37:00+03	71400.00
86DE77	2017-07-25 08:58:00+03	69000.00
86DE8F	2017-07-05 08:02:00+03	128800.00
86DE96	2017-08-07 02:47:00+03	174200.00
86DF04	2017-08-13 09:21:00+03	118600.00
86DF39	2017-07-16 05:12:00+03	46200.00
86DFA9	2017-08-08 23:07:00+03	75600.00
86DFF9	2017-07-25 00:54:00+03	28000.00
86E05E	2017-07-10 20:46:00+03	18000.00
86E092	2017-08-05 00:06:00+03	10700.00
86E0C7	2017-08-09 16:52:00+03	124200.00
86E0D2	2017-07-17 08:58:00+03	8200.00
86E13A	2017-07-13 14:34:00+03	21400.00
86E1E9	2017-07-15 14:54:00+03	133100.00
86E21B	2017-07-31 01:37:00+03	95700.00
86E22A	2017-07-08 16:48:00+03	466600.00
86E254	2017-08-07 14:04:00+03	66000.00
86E25C	2017-07-21 01:24:00+03	80800.00
86E272	2017-07-23 19:30:00+03	10600.00
86E2AC	2017-08-07 03:58:00+03	46400.00
86E2C5	2017-08-01 04:21:00+03	13600.00
86E2C9	2017-07-20 00:56:00+03	52000.00
86E2CD	2017-08-04 13:05:00+03	47200.00
86E343	2017-08-14 13:12:00+03	48800.00
86E37C	2017-07-16 16:29:00+03	67200.00
86E383	2017-06-30 09:19:00+03	40800.00
86E411	2017-07-02 05:34:00+03	6700.00
86E4C6	2017-07-24 07:49:00+03	62600.00
86E53F	2017-07-30 21:07:00+03	57400.00
86E5E9	2017-08-13 15:40:00+03	156700.00
86E60D	2017-08-04 02:02:00+03	51900.00
86E673	2017-08-04 22:57:00+03	54400.00
86E70A	2017-08-15 05:08:00+03	116400.00
86E71A	2017-07-01 07:36:00+03	66400.00
86E770	2017-07-25 19:42:00+03	24600.00
86E7C4	2017-07-15 22:53:00+03	405000.00
86E7CB	2017-07-04 19:41:00+03	24400.00
86E7D8	2017-08-10 12:24:00+03	155600.00
86E7E0	2017-08-03 09:51:00+03	69500.00
86E7EC	2017-07-05 03:20:00+03	135400.00
86E7F1	2017-07-29 18:54:00+03	56000.00
86E80E	2017-07-16 00:06:00+03	194000.00
86E839	2017-08-09 22:05:00+03	32800.00
86E87A	2017-07-08 18:20:00+03	136100.00
86E96F	2017-07-22 16:56:00+03	149200.00
86E976	2017-07-13 00:35:00+03	178800.00
86E984	2017-07-12 20:04:00+03	113300.00
86E993	2017-07-20 11:01:00+03	41200.00
86EA6E	2017-08-08 21:21:00+03	155600.00
86EA84	2017-08-12 21:41:00+03	8200.00
86EABC	2017-07-22 08:01:00+03	14400.00
86EAD7	2017-08-11 01:03:00+03	241400.00
86EB0C	2017-08-06 15:54:00+03	35200.00
86EB0F	2017-07-16 22:40:00+03	70700.00
86EB32	2017-08-05 01:56:00+03	56000.00
86EB7F	2017-08-06 18:54:00+03	38600.00
86EBAD	2017-08-09 06:14:00+03	102100.00
86EC21	2017-07-24 16:32:00+03	14000.00
86EC89	2017-07-10 19:58:00+03	10700.00
86ECED	2017-07-09 11:16:00+03	47000.00
86ECEE	2017-07-31 01:37:00+03	52600.00
86ECF3	2017-07-04 06:46:00+03	15400.00
86ED50	2017-07-17 15:38:00+03	34900.00
86ED83	2017-07-14 14:43:00+03	34000.00
86EDE0	2017-08-15 14:24:00+03	158000.00
86EDEA	2017-07-14 12:49:00+03	26000.00
86EE27	2017-07-20 10:17:00+03	40800.00
86EE5C	2017-07-06 15:54:00+03	119600.00
86EE63	2017-07-20 06:36:00+03	73300.00
86EEEC	2017-08-15 02:48:00+03	106900.00
86EF72	2017-08-13 15:55:00+03	36600.00
86EF95	2017-07-23 11:47:00+03	62700.00
86F0D2	2017-07-18 14:05:00+03	93400.00
86F0DA	2017-08-01 02:03:00+03	36200.00
86F13C	2017-07-07 18:58:00+03	59600.00
86F143	2017-07-14 22:56:00+03	18300.00
86F178	2017-08-01 21:04:00+03	36400.00
86F1DA	2017-07-09 12:02:00+03	81200.00
86F203	2017-08-11 13:40:00+03	14400.00
86F220	2017-07-06 20:13:00+03	21500.00
86F272	2017-07-10 00:01:00+03	100000.00
86F2F6	2017-08-15 06:40:00+03	39500.00
86F31B	2017-08-14 20:45:00+03	86800.00
86F32A	2017-08-14 04:41:00+03	18400.00
86F335	2017-08-03 05:24:00+03	26200.00
86F3A3	2017-08-14 17:08:00+03	26700.00
86F3CB	2017-07-30 20:09:00+03	6000.00
86F3CD	2017-07-02 06:32:00+03	31600.00
86F3D3	2017-08-15 15:42:00+03	18600.00
86F40E	2017-07-28 21:51:00+03	28600.00
86F48E	2017-07-10 07:04:00+03	150500.00
86F4B3	2017-07-21 01:52:00+03	6700.00
86F515	2017-07-09 22:52:00+03	86300.00
86F545	2017-07-29 11:00:00+03	46300.00
86F584	2017-07-26 06:36:00+03	99700.00
86F58C	2017-08-06 00:32:00+03	66600.00
86F5F7	2017-07-23 17:39:00+03	28000.00
86F630	2017-07-24 20:50:00+03	135400.00
86F649	2017-07-08 19:11:00+03	12600.00
86F679	2017-08-12 23:56:00+03	45200.00
86F6CA	2017-08-13 10:10:00+03	90000.00
86F81E	2017-07-13 06:46:00+03	6000.00
86F830	2017-07-16 06:22:00+03	40000.00
86F835	2017-07-24 00:07:00+03	40100.00
86F850	2017-07-13 09:40:00+03	136200.00
86F887	2017-07-13 20:46:00+03	22600.00
86F8B3	2017-07-17 18:23:00+03	79000.00
86F8E0	2017-08-15 03:49:00+03	58000.00
86F909	2017-07-15 00:06:00+03	48800.00
86F92A	2017-07-05 01:51:00+03	44100.00
86F93A	2017-08-06 13:19:00+03	53600.00
86F979	2017-08-12 21:57:00+03	23200.00
86F985	2017-08-01 08:40:00+03	155600.00
86F9BD	2017-07-02 18:29:00+03	95200.00
86F9F8	2017-08-15 00:42:00+03	27200.00
86FA99	2017-08-06 05:23:00+03	6000.00
86FAD5	2017-08-13 10:32:00+03	50600.00
86FADC	2017-07-14 18:47:00+03	47100.00
86FC1B	2017-07-12 23:40:00+03	46400.00
86FC29	2017-07-03 15:05:00+03	23200.00
86FC32	2017-07-10 06:21:00+03	27700.00
86FC6B	2017-07-14 07:28:00+03	32800.00
86FC9F	2017-07-17 00:59:00+03	40400.00
86FCA2	2017-08-01 07:57:00+03	30700.00
86FCA7	2017-07-24 06:46:00+03	20400.00
86FD6E	2017-07-19 17:55:00+03	142400.00
86FD89	2017-07-09 17:19:00+03	6700.00
86FDAC	2017-08-09 12:41:00+03	299900.00
86FDB6	2017-07-27 00:47:00+03	187600.00
86FDBB	2017-07-24 08:44:00+03	21800.00
86FE1A	2017-07-30 21:56:00+03	24400.00
86FE2D	2017-07-26 04:49:00+03	23600.00
86FE37	2017-08-04 08:40:00+03	270000.00
86FE42	2017-08-13 10:09:00+03	45000.00
86FE4D	2017-07-13 14:30:00+03	131600.00
86FE9B	2017-08-05 09:23:00+03	23100.00
86FECA	2017-07-04 01:28:00+03	55600.00
86FEFC	2017-08-15 16:58:00+03	58800.00
86FF01	2017-07-06 18:26:00+03	103100.00
86FF0F	2017-07-26 19:39:00+03	37700.00
86FF7E	2017-07-29 07:09:00+03	56600.00
86FF86	2017-08-13 17:15:00+03	146900.00
86FFB6	2017-08-12 20:34:00+03	31100.00
86FFB9	2017-08-05 15:20:00+03	81700.00
870007	2017-07-17 11:09:00+03	94300.00
870034	2017-07-08 23:06:00+03	50800.00
870043	2017-07-19 22:32:00+03	28000.00
870055	2017-07-05 07:18:00+03	23200.00
8700B7	2017-07-15 17:23:00+03	150600.00
87013A	2017-07-13 13:19:00+03	92100.00
8701D8	2017-08-05 03:33:00+03	95500.00
870219	2017-07-08 22:24:00+03	266400.00
87026B	2017-07-17 07:42:00+03	258400.00
8702E6	2017-07-12 04:28:00+03	60400.00
870317	2017-08-11 01:04:00+03	7400.00
87033E	2017-07-17 17:38:00+03	51200.00
870374	2017-07-16 04:12:00+03	139300.00
8703B6	2017-07-04 01:22:00+03	66400.00
8703CC	2017-08-10 07:26:00+03	56000.00
8703DC	2017-07-01 11:12:00+03	89700.00
8703FB	2017-07-18 02:03:00+03	14000.00
870436	2017-08-10 00:41:00+03	123600.00
870438	2017-08-15 07:47:00+03	46400.00
87043B	2017-07-15 12:26:00+03	28000.00
870447	2017-07-15 16:21:00+03	67600.00
870555	2017-07-06 13:28:00+03	53600.00
870579	2017-07-21 16:34:00+03	23600.00
8705B8	2017-07-04 20:27:00+03	90700.00
870625	2017-07-26 11:57:00+03	71600.00
870663	2017-08-12 14:18:00+03	229600.00
8706F5	2017-07-26 16:40:00+03	24400.00
870707	2017-07-19 10:23:00+03	74300.00
870711	2017-07-05 13:30:00+03	23200.00
870714	2017-07-23 21:24:00+03	56000.00
870729	2017-08-06 04:37:00+03	59800.00
870747	2017-08-02 09:34:00+03	113000.00
870759	2017-08-08 04:45:00+03	13200.00
8707DF	2017-07-13 07:40:00+03	100200.00
870828	2017-08-12 09:26:00+03	15400.00
870844	2017-07-07 17:06:00+03	51300.00
87086A	2017-07-07 06:55:00+03	101100.00
87087A	2017-07-30 16:13:00+03	46400.00
87089E	2017-07-27 13:47:00+03	29000.00
8709EB	2017-07-18 21:12:00+03	20200.00
8709EE	2017-07-01 01:04:00+03	102100.00
870A14	2017-08-07 10:42:00+03	14000.00
870A2C	2017-08-11 19:26:00+03	28000.00
870B17	2017-08-15 07:05:00+03	28000.00
870B32	2017-07-16 03:20:00+03	79900.00
870BAD	2017-08-14 10:11:00+03	52300.00
870BBD	2017-07-27 20:34:00+03	28800.00
870BF4	2017-07-05 05:19:00+03	13600.00
870BFB	2017-07-05 07:36:00+03	61800.00
870CB1	2017-08-15 04:30:00+03	135400.00
870CC7	2017-07-14 18:35:00+03	47200.00
870CFD	2017-08-02 01:43:00+03	26000.00
870D94	2017-07-02 23:34:00+03	17600.00
870E23	2017-08-03 10:09:00+03	56900.00
870E48	2017-07-29 06:37:00+03	8400.00
870E6B	2017-06-29 19:50:00+03	29200.00
870EBF	2017-07-04 03:17:00+03	79600.00
870ED8	2017-08-11 16:41:00+03	46000.00
870F0B	2017-07-24 04:01:00+03	139900.00
870F67	2017-07-06 01:33:00+03	160400.00
870F80	2017-08-02 21:41:00+03	38800.00
870FD3	2017-07-02 03:02:00+03	46400.00
87101D	2017-07-14 09:05:00+03	136200.00
871037	2017-07-09 15:48:00+03	40800.00
8710D6	2017-07-28 01:41:00+03	39500.00
8710F5	2017-07-20 21:55:00+03	25600.00
871181	2017-08-15 03:51:00+03	87200.00
871249	2017-07-05 15:31:00+03	47400.00
871265	2017-07-23 01:07:00+03	56000.00
871297	2017-08-12 01:33:00+03	16400.00
87134F	2017-07-20 12:29:00+03	71200.00
8713B6	2017-07-10 11:10:00+03	185700.00
8713DE	2017-08-01 15:11:00+03	56100.00
87140A	2017-07-01 07:36:00+03	123000.00
871472	2017-08-01 20:25:00+03	111600.00
871492	2017-08-08 04:47:00+03	83000.00
8714DA	2017-08-01 10:00:00+03	77900.00
8714DC	2017-07-05 06:56:00+03	50400.00
87152B	2017-08-13 18:31:00+03	20600.00
87159F	2017-07-26 16:47:00+03	91900.00
8715BD	2017-08-15 11:31:00+03	56600.00
871668	2017-07-08 11:27:00+03	90400.00
8716CC	2017-07-26 02:08:00+03	56000.00
87170B	2017-08-04 15:40:00+03	25100.00
871724	2017-07-04 15:43:00+03	83100.00
871741	2017-07-11 15:26:00+03	52800.00
8717B0	2017-07-29 18:34:00+03	65900.00
871823	2017-08-10 19:23:00+03	56000.00
871893	2017-08-04 13:24:00+03	84100.00
8718A1	2017-08-01 03:29:00+03	48800.00
87192C	2017-08-08 10:13:00+03	256700.00
87195B	2017-07-12 06:52:00+03	159700.00
8719C6	2017-08-15 10:53:00+03	156100.00
8719CE	2017-08-07 20:42:00+03	49100.00
871A1B	2017-07-07 07:02:00+03	94300.00
871A33	2017-08-05 23:02:00+03	39200.00
871A57	2017-08-12 06:52:00+03	12700.00
871A7C	2017-08-02 22:57:00+03	55800.00
871AB1	2017-07-27 03:09:00+03	111700.00
871AF5	2017-08-12 16:18:00+03	73900.00
871AFF	2017-07-12 10:32:00+03	25000.00
871B27	2017-07-25 22:03:00+03	11600.00
871B38	2017-07-18 01:58:00+03	113000.00
871B4A	2017-07-06 18:47:00+03	114400.00
871BD9	2017-07-25 08:53:00+03	53400.00
871BEA	2017-07-17 17:38:00+03	68000.00
871C20	2017-08-07 22:39:00+03	14800.00
871C31	2017-07-26 01:57:00+03	51900.00
871C81	2017-07-19 00:56:00+03	99100.00
871C8B	2017-07-17 22:55:00+03	23600.00
871CD3	2017-08-09 18:25:00+03	51300.00
871CD8	2017-07-29 11:57:00+03	65600.00
871D09	2017-08-06 15:00:00+03	14400.00
871D46	2017-07-26 21:43:00+03	21800.00
871D5C	2017-08-04 07:50:00+03	15000.00
871DAB	2017-07-22 17:32:00+03	92000.00
871DB4	2017-07-09 03:01:00+03	30000.00
871DF3	2017-07-03 09:01:00+03	31600.00
871E78	2017-07-16 16:54:00+03	130900.00
871EE7	2017-07-20 00:03:00+03	70700.00
871F5B	2017-07-07 18:27:00+03	36500.00
871F82	2017-07-15 09:25:00+03	23600.00
871FF0	2017-07-01 15:53:00+03	20600.00
872030	2017-06-29 09:21:00+03	103800.00
872076	2017-07-04 19:12:00+03	24400.00
87207F	2017-07-06 10:07:00+03	177200.00
872083	2017-08-06 00:10:00+03	39200.00
8720F1	2017-08-03 17:54:00+03	84500.00
87210A	2017-08-01 01:43:00+03	15100.00
87215B	2017-07-25 03:08:00+03	12000.00
872201	2017-07-25 19:10:00+03	81300.00
872203	2017-08-01 09:06:00+03	68800.00
87221B	2017-08-02 14:23:00+03	28800.00
872279	2017-08-12 12:18:00+03	39800.00
872297	2017-08-01 14:45:00+03	13400.00
87233C	2017-06-27 06:05:00+03	32700.00
872340	2017-07-18 05:14:00+03	119600.00
872381	2017-08-05 12:30:00+03	77100.00
8723EC	2017-07-02 04:39:00+03	50800.00
872452	2017-07-27 09:14:00+03	56000.00
8724B4	2017-08-15 16:03:00+03	56000.00
8724B7	2017-07-01 20:43:00+03	19800.00
8724DD	2017-07-09 05:35:00+03	239100.00
872582	2017-07-16 07:41:00+03	26000.00
8725A2	2017-08-04 06:39:00+03	26600.00
8725A3	2017-06-28 20:33:00+03	62000.00
8725DC	2017-07-17 16:37:00+03	75300.00
87264A	2017-08-15 14:25:00+03	379600.00
87265F	2017-08-12 04:09:00+03	62600.00
87270E	2017-07-24 16:03:00+03	30300.00
872741	2017-07-07 02:58:00+03	110300.00
872746	2017-07-24 20:21:00+03	40800.00
872747	2017-08-12 15:34:00+03	65900.00
872784	2017-08-05 06:01:00+03	50700.00
87288F	2017-07-08 06:33:00+03	81900.00
8728C1	2017-08-04 00:31:00+03	57700.00
8728F5	2017-07-19 16:34:00+03	105000.00
872984	2017-07-03 04:26:00+03	40600.00
8729CF	2017-08-03 06:38:00+03	43600.00
872A2C	2017-07-07 19:22:00+03	135600.00
872A30	2017-07-06 17:11:00+03	37500.00
872A39	2017-07-31 21:56:00+03	108000.00
872A3A	2017-07-14 05:36:00+03	105100.00
872A6F	2017-08-06 00:00:00+03	122500.00
872A97	2017-07-02 01:41:00+03	13400.00
872A9B	2017-07-31 02:33:00+03	238600.00
872AC2	2017-07-25 01:35:00+03	30800.00
872ACB	2017-07-03 02:45:00+03	16400.00
872B5A	2017-07-15 16:21:00+03	69200.00
872BC8	2017-07-17 19:24:00+03	137100.00
872BD7	2017-08-06 00:29:00+03	481800.00
872BFA	2017-07-29 05:55:00+03	92800.00
872C0B	2017-08-14 15:34:00+03	170800.00
872C7B	2017-07-07 07:02:00+03	35700.00
872C92	2017-07-21 14:41:00+03	92400.00
872CAA	2017-08-09 12:46:00+03	54000.00
872CB7	2017-07-13 03:35:00+03	229300.00
872CE5	2017-08-08 23:50:00+03	143100.00
872D56	2017-06-30 04:49:00+03	12600.00
872DA3	2017-08-08 01:15:00+03	62800.00
872DD5	2017-07-08 22:40:00+03	67600.00
872DF7	2017-08-06 15:43:00+03	50800.00
872E06	2017-07-05 13:08:00+03	9800.00
872E61	2017-08-06 13:40:00+03	18000.00
872E9C	2017-07-31 20:47:00+03	23400.00
872F1E	2017-07-16 14:45:00+03	44800.00
872F55	2017-08-05 03:22:00+03	12400.00
872F71	2017-07-22 06:32:00+03	229300.00
87301E	2017-07-29 16:11:00+03	128800.00
87305C	2017-08-01 00:37:00+03	66600.00
8730AE	2017-08-02 12:22:00+03	72300.00
873130	2017-08-12 05:46:00+03	40000.00
873189	2017-07-14 09:15:00+03	48200.00
8731E7	2017-08-15 14:47:00+03	18100.00
873209	2017-06-30 06:21:00+03	56200.00
873249	2017-08-09 22:52:00+03	105000.00
87324F	2017-08-07 22:22:00+03	67100.00
8732D1	2017-08-14 08:15:00+03	28000.00
8733C8	2017-07-30 13:33:00+03	28000.00
87341D	2017-08-15 09:36:00+03	16000.00
873436	2017-08-05 16:19:00+03	173900.00
87345E	2017-07-15 10:44:00+03	56000.00
87347C	2017-07-06 11:55:00+03	83000.00
8734CF	2017-07-22 09:24:00+03	16400.00
8735DE	2017-07-03 09:40:00+03	126200.00
873642	2017-08-10 12:32:00+03	69200.00
87368D	2017-08-02 20:03:00+03	46200.00
8736D1	2017-07-09 03:04:00+03	85400.00
87373B	2017-08-10 16:19:00+03	28000.00
87376A	2017-07-12 15:13:00+03	67200.00
873778	2017-07-14 04:07:00+03	39800.00
873787	2017-07-19 14:14:00+03	38400.00
8737F7	2017-07-15 13:40:00+03	81600.00
8737FD	2017-07-11 08:40:00+03	408500.00
873809	2017-08-04 16:43:00+03	22600.00
873821	2017-07-09 12:15:00+03	49600.00
873860	2017-07-27 21:04:00+03	246000.00
8738D5	2017-07-17 17:08:00+03	28000.00
87392E	2017-07-15 22:45:00+03	55600.00
87398D	2017-07-19 09:12:00+03	44500.00
873A44	2017-08-14 03:51:00+03	88000.00
873AB3	2017-07-05 01:36:00+03	394400.00
873B1D	2017-07-16 23:59:00+03	174600.00
873B56	2017-07-19 02:45:00+03	53600.00
873B5A	2017-07-27 07:30:00+03	6600.00
873B78	2017-07-12 16:32:00+03	155600.00
873B9C	2017-07-22 08:09:00+03	60700.00
873BD1	2017-08-03 09:39:00+03	28800.00
873BFE	2017-07-31 14:34:00+03	23200.00
873C1F	2017-08-11 13:01:00+03	19800.00
873C83	2017-08-07 16:57:00+03	101200.00
873CDD	2017-08-11 23:38:00+03	135200.00
873CFF	2017-08-11 21:08:00+03	6000.00
873D4E	2017-07-25 10:03:00+03	131600.00
873E43	2017-08-02 02:17:00+03	54000.00
873E4F	2017-07-21 10:48:00+03	49100.00
873E6A	2017-07-01 04:42:00+03	19600.00
873ED8	2017-07-11 03:45:00+03	67000.00
873EF9	2017-07-30 07:05:00+03	28300.00
873F51	2017-08-14 05:16:00+03	19800.00
873F58	2017-07-08 20:54:00+03	53600.00
873F6C	2017-07-09 21:08:00+03	40800.00
873F82	2017-07-04 04:25:00+03	52700.00
873FB8	2017-07-28 18:10:00+03	56000.00
87401D	2017-07-13 13:49:00+03	12600.00
874028	2017-08-11 01:12:00+03	19600.00
8740D5	2017-07-09 15:42:00+03	46400.00
874119	2017-07-07 01:09:00+03	77000.00
874168	2017-06-29 19:12:00+03	193500.00
874171	2017-07-08 21:45:00+03	92000.00
87418A	2017-08-06 08:49:00+03	12600.00
8741DC	2017-07-10 04:52:00+03	25400.00
874284	2017-08-13 13:23:00+03	51300.00
874292	2017-07-13 18:46:00+03	162700.00
874382	2017-07-29 21:13:00+03	25100.00
8743B4	2017-06-30 06:22:00+03	66000.00
8743C1	2017-07-16 16:46:00+03	37200.00
87442E	2017-07-10 07:09:00+03	68000.00
874434	2017-07-28 03:55:00+03	92800.00
874463	2017-08-06 21:29:00+03	28000.00
874484	2017-07-23 06:00:00+03	270800.00
874489	2017-08-06 04:39:00+03	52700.00
87448B	2017-07-16 19:14:00+03	136800.00
8744DC	2017-07-01 14:57:00+03	156300.00
874542	2017-07-04 11:42:00+03	48800.00
87459E	2017-08-02 17:17:00+03	56000.00
8745C5	2017-08-01 09:37:00+03	58800.00
87474A	2017-07-07 02:16:00+03	54900.00
874759	2017-07-11 15:31:00+03	67600.00
8747B3	2017-08-14 00:19:00+03	114700.00
874840	2017-07-24 15:10:00+03	48500.00
874868	2017-07-07 15:03:00+03	28000.00
8748B9	2017-07-16 12:07:00+03	90400.00
8748D4	2017-06-30 17:48:00+03	20400.00
87491E	2017-08-10 04:08:00+03	43100.00
87497F	2017-07-05 21:57:00+03	6300.00
8749C5	2017-08-13 07:09:00+03	39300.00
874A84	2017-07-26 03:52:00+03	39300.00
874AA3	2017-07-31 18:13:00+03	28800.00
874B55	2017-07-10 11:08:00+03	23600.00
874BE5	2017-07-12 03:00:00+03	81200.00
874BEF	2017-08-03 13:46:00+03	224000.00
874C05	2017-07-18 01:18:00+03	51300.00
874D56	2017-07-31 22:11:00+03	12600.00
874DA1	2017-07-13 16:32:00+03	266100.00
874E1D	2017-08-06 12:27:00+03	38400.00
874EE1	2017-08-02 21:59:00+03	66600.00
874F44	2017-07-07 03:27:00+03	19600.00
874F65	2017-08-07 01:00:00+03	84100.00
874F95	2017-07-15 03:16:00+03	23400.00
87504B	2017-07-06 07:58:00+03	75300.00
87512C	2017-07-04 02:57:00+03	112000.00
875185	2017-07-15 15:38:00+03	85000.00
8751D5	2017-08-04 05:28:00+03	76300.00
8751EC	2017-07-28 17:06:00+03	63200.00
87520E	2017-07-10 07:44:00+03	81900.00
875216	2017-07-16 10:13:00+03	92900.00
87522C	2017-07-25 16:11:00+03	205400.00
875252	2017-07-18 13:45:00+03	13600.00
875262	2017-08-03 21:07:00+03	12400.00
8752A3	2017-08-08 14:58:00+03	24400.00
87533C	2017-07-13 04:53:00+03	54800.00
8753E9	2017-08-07 10:17:00+03	26800.00
87546F	2017-08-09 23:32:00+03	70700.00
8754A7	2017-07-10 22:18:00+03	37900.00
8754C4	2017-08-05 16:15:00+03	31000.00
8754CE	2017-07-06 13:15:00+03	66600.00
8754D6	2017-07-07 03:11:00+03	66000.00
875530	2017-08-12 07:12:00+03	91300.00
875561	2017-08-07 23:07:00+03	30800.00
875600	2017-08-03 22:28:00+03	16400.00
87562E	2017-07-21 15:06:00+03	40800.00
875695	2017-07-08 15:35:00+03	265800.00
8756DC	2017-07-09 07:41:00+03	100600.00
875723	2017-07-07 02:06:00+03	43500.00
875762	2017-07-17 11:02:00+03	119500.00
8757F6	2017-08-03 19:33:00+03	60000.00
87580D	2017-07-15 08:12:00+03	13200.00
875815	2017-08-09 04:27:00+03	233700.00
875826	2017-06-30 17:31:00+03	62700.00
8758AA	2017-07-12 17:20:00+03	10800.00
8758F7	2017-07-17 09:26:00+03	133200.00
875927	2017-07-11 23:18:00+03	58200.00
875936	2017-08-06 05:44:00+03	16800.00
87597C	2017-08-15 00:44:00+03	46200.00
87599E	2017-07-11 16:16:00+03	12000.00
8759D8	2017-08-12 12:54:00+03	14000.00
8759F8	2017-07-04 00:00:00+03	23200.00
875A11	2017-07-02 22:26:00+03	57500.00
875A78	2017-08-04 16:04:00+03	22000.00
875BD4	2017-07-28 12:10:00+03	128800.00
875BE6	2017-07-24 22:53:00+03	36100.00
875BEB	2017-07-05 09:13:00+03	51900.00
875CCD	2017-07-31 11:10:00+03	36200.00
875CD3	2017-07-16 03:02:00+03	131800.00
875CDD	2017-07-06 09:07:00+03	47800.00
875D27	2017-08-07 09:20:00+03	96300.00
875D4C	2017-08-12 08:46:00+03	35700.00
875E4C	2017-07-05 04:08:00+03	58100.00
875EE8	2017-08-10 17:33:00+03	15400.00
875EF7	2017-07-18 23:30:00+03	103100.00
875F39	2017-07-10 13:21:00+03	23600.00
875F90	2017-08-13 22:32:00+03	120400.00
87606B	2017-07-12 16:35:00+03	28800.00
876082	2017-08-02 17:33:00+03	44600.00
8760C4	2017-07-06 15:08:00+03	33300.00
876113	2017-07-19 04:35:00+03	92900.00
876126	2017-07-18 22:13:00+03	19600.00
87614F	2017-07-27 12:59:00+03	58600.00
876156	2017-07-27 20:15:00+03	298800.00
8761B9	2017-07-29 03:05:00+03	65600.00
8761FF	2017-07-19 18:54:00+03	155600.00
876231	2017-08-05 03:40:00+03	174900.00
87623F	2017-07-31 17:30:00+03	12200.00
8762AC	2017-08-08 12:41:00+03	25200.00
8762BB	2017-08-09 02:43:00+03	73600.00
876352	2017-08-03 17:53:00+03	3400.00
876388	2017-07-05 03:25:00+03	664500.00
876395	2017-07-09 22:40:00+03	12400.00
8763C0	2017-08-05 16:47:00+03	25800.00
8763CC	2017-06-30 20:00:00+03	35200.00
8763E0	2017-07-30 23:45:00+03	35800.00
8763ED	2017-07-29 04:31:00+03	162600.00
876455	2017-07-25 07:11:00+03	83000.00
8764F3	2017-08-02 18:51:00+03	461500.00
876506	2017-07-14 12:56:00+03	37900.00
876544	2017-07-31 09:46:00+03	89100.00
87654D	2017-07-17 05:31:00+03	24800.00
876584	2017-07-02 10:27:00+03	28800.00
87659D	2017-08-10 10:04:00+03	135000.00
8765F0	2017-07-31 06:55:00+03	96300.00
876654	2017-07-27 14:35:00+03	57600.00
8766A9	2017-08-12 06:36:00+03	19800.00
8766C0	2017-07-18 11:37:00+03	182000.00
8766C7	2017-07-02 11:28:00+03	68800.00
876741	2017-07-07 20:15:00+03	93600.00
87674D	2017-07-12 01:51:00+03	6600.00
8767ED	2017-08-07 16:24:00+03	65900.00
8767FD	2017-07-26 10:25:00+03	89700.00
876815	2017-08-09 19:07:00+03	70000.00
8768A3	2017-08-02 00:39:00+03	205500.00
8768B7	2017-07-27 17:02:00+03	178800.00
8768D2	2017-07-16 00:49:00+03	7400.00
8768E9	2017-08-01 09:56:00+03	59800.00
876953	2017-08-01 10:35:00+03	23200.00
87697F	2017-08-15 15:38:00+03	46500.00
87699A	2017-07-03 15:52:00+03	87800.00
8769E7	2017-07-06 13:45:00+03	29400.00
876A44	2017-07-27 23:25:00+03	14400.00
876A87	2017-07-22 12:51:00+03	121400.00
876A95	2017-07-31 09:56:00+03	46400.00
876AFD	2017-07-07 00:09:00+03	74400.00
876B0F	2017-08-04 21:19:00+03	136100.00
876B2D	2017-08-12 23:24:00+03	52600.00
876B4B	2017-07-15 05:51:00+03	70700.00
876B75	2017-07-04 09:28:00+03	12600.00
876BB7	2017-07-22 04:24:00+03	49900.00
876BED	2017-07-20 19:57:00+03	31600.00
876C7F	2017-08-09 02:20:00+03	119500.00
876D05	2017-08-11 23:34:00+03	38600.00
876EA4	2017-08-11 18:30:00+03	125200.00
876EC2	2017-08-03 13:40:00+03	35600.00
876ECC	2017-07-24 14:21:00+03	266400.00
876ECD	2017-07-22 23:45:00+03	35900.00
876EF5	2017-07-26 15:29:00+03	147400.00
876F1B	2017-08-05 09:18:00+03	179400.00
876F32	2017-07-26 14:45:00+03	28800.00
876F72	2017-07-16 15:34:00+03	129200.00
876F76	2017-08-10 20:02:00+03	6000.00
876F86	2017-08-08 13:48:00+03	58700.00
876F8E	2017-08-10 10:54:00+03	111600.00
876F9C	2017-07-27 21:18:00+03	266200.00
876FBC	2017-07-02 05:32:00+03	14400.00
876FD0	2017-08-15 13:14:00+03	75300.00
876FF5	2017-08-03 12:47:00+03	6000.00
876FF9	2017-08-07 11:15:00+03	142400.00
8770CE	2017-08-02 18:01:00+03	67400.00
8770F5	2017-08-04 21:34:00+03	147100.00
877135	2017-07-08 03:54:00+03	26000.00
877161	2017-08-12 06:26:00+03	147700.00
877202	2017-08-13 19:56:00+03	12000.00
877245	2017-08-09 03:14:00+03	79800.00
877263	2017-06-30 00:12:00+03	66000.00
877272	2017-07-02 11:44:00+03	26600.00
877281	2017-07-30 12:06:00+03	119600.00
877299	2017-07-25 14:41:00+03	61800.00
8772CE	2017-07-06 08:51:00+03	26600.00
8772CF	2017-08-02 14:27:00+03	25000.00
87732C	2017-08-15 08:39:00+03	70700.00
877335	2017-07-19 00:03:00+03	28000.00
87734F	2017-08-05 11:06:00+03	59800.00
8773A5	2017-08-15 04:46:00+03	24000.00
8773C1	2017-07-07 01:00:00+03	84800.00
8773F8	2017-08-09 05:21:00+03	112000.00
877445	2017-07-06 23:18:00+03	59200.00
87746F	2017-07-16 03:33:00+03	26800.00
87750D	2017-07-07 17:28:00+03	12200.00
877529	2017-08-14 17:07:00+03	96800.00
87752C	2017-07-11 11:03:00+03	56200.00
877536	2017-07-07 16:32:00+03	65500.00
87753B	2017-08-13 10:15:00+03	269300.00
877575	2017-08-05 06:41:00+03	115800.00
877594	2017-07-31 17:50:00+03	6700.00
8775F3	2017-07-13 02:01:00+03	94200.00
8775FC	2017-08-12 07:59:00+03	19800.00
877636	2017-08-12 07:20:00+03	269400.00
877688	2017-07-13 12:51:00+03	57400.00
877704	2017-08-09 07:38:00+03	285600.00
877709	2017-08-07 19:49:00+03	26200.00
87773D	2017-06-30 19:08:00+03	72000.00
877752	2017-07-31 02:44:00+03	87200.00
8777A1	2017-07-19 19:37:00+03	128800.00
8777A7	2017-08-04 20:51:00+03	77500.00
8777C9	2017-07-17 10:41:00+03	139400.00
8777E8	2017-06-30 17:32:00+03	27800.00
877955	2017-07-29 01:13:00+03	106000.00
877977	2017-07-07 00:52:00+03	110600.00
87798C	2017-08-11 22:38:00+03	86600.00
87799F	2017-08-04 09:38:00+03	273600.00
877A3E	2017-07-27 20:11:00+03	26000.00
877A54	2017-08-09 12:03:00+03	24700.00
877A75	2017-07-04 04:00:00+03	31600.00
877AAB	2017-08-04 23:55:00+03	13700.00
877ABF	2017-08-10 10:56:00+03	64100.00
877AE9	2017-07-08 05:28:00+03	89600.00
877B41	2017-07-16 12:54:00+03	260900.00
877BB6	2017-07-18 15:45:00+03	156300.00
877CF8	2017-07-10 04:58:00+03	137600.00
877D0F	2017-07-06 06:49:00+03	369000.00
877D6A	2017-07-24 22:30:00+03	93900.00
877D93	2017-07-29 00:40:00+03	37800.00
877DE7	2017-08-09 02:34:00+03	393000.00
877E41	2017-08-05 12:02:00+03	51200.00
877E83	2017-07-23 21:39:00+03	14000.00
877EA4	2017-08-02 13:03:00+03	24400.00
877EB0	2017-07-10 09:52:00+03	48800.00
877EDB	2017-07-16 01:43:00+03	34800.00
877F1B	2017-07-15 13:42:00+03	117200.00
877F6B	2017-07-11 15:42:00+03	70600.00
877F71	2017-08-14 02:43:00+03	22200.00
878075	2017-07-26 05:41:00+03	52900.00
87809F	2017-08-01 16:01:00+03	46300.00
8780BF	2017-08-10 01:20:00+03	31600.00
878124	2017-07-06 07:50:00+03	19600.00
87818D	2017-07-21 15:59:00+03	39800.00
87819D	2017-07-10 04:45:00+03	19600.00
8781C3	2017-07-02 16:14:00+03	48800.00
8781E0	2017-08-14 10:59:00+03	199700.00
8781ED	2017-08-12 20:56:00+03	89700.00
878294	2017-07-11 20:19:00+03	99300.00
8782B7	2017-07-20 10:26:00+03	170200.00
8782F7	2017-07-29 23:03:00+03	75600.00
87831A	2017-08-03 06:42:00+03	418500.00
878474	2017-07-28 12:59:00+03	47100.00
878487	2017-07-14 07:01:00+03	92000.00
8784B0	2017-07-13 02:54:00+03	66600.00
8784BD	2017-07-06 12:55:00+03	271100.00
8784F2	2017-08-04 11:53:00+03	46000.00
8785B3	2017-08-02 12:56:00+03	20200.00
8785BF	2017-07-19 09:07:00+03	59800.00
8785E9	2017-08-03 21:14:00+03	286900.00
878642	2017-08-04 23:26:00+03	123000.00
87864A	2017-07-26 06:29:00+03	199700.00
87868E	2017-07-17 10:37:00+03	23600.00
878691	2017-08-02 21:30:00+03	129700.00
8786ED	2017-06-30 16:59:00+03	57600.00
87871B	2017-08-14 17:44:00+03	51900.00
87877F	2017-08-04 12:16:00+03	125400.00
8787AE	2017-07-09 21:01:00+03	22100.00
8787BD	2017-07-26 06:38:00+03	271100.00
8787C6	2017-07-01 00:53:00+03	49400.00
878806	2017-06-29 13:44:00+03	119400.00
87881D	2017-07-13 03:54:00+03	57600.00
878833	2017-07-23 05:33:00+03	100600.00
878845	2017-08-11 12:54:00+03	172700.00
878887	2017-07-23 16:13:00+03	58900.00
8788B4	2017-07-21 05:57:00+03	108500.00
8788E8	2017-07-07 17:48:00+03	93400.00
8789AE	2017-08-07 18:33:00+03	29600.00
8789B2	2017-07-15 21:42:00+03	67600.00
878A07	2017-07-28 07:08:00+03	6000.00
878A11	2017-08-08 21:06:00+03	64200.00
878A54	2017-07-21 03:49:00+03	87000.00
878B15	2017-07-08 05:08:00+03	68900.00
878B4B	2017-07-30 12:58:00+03	50300.00
878B55	2017-07-30 22:03:00+03	64900.00
878B6E	2017-07-14 06:40:00+03	139200.00
878B7E	2017-07-22 20:25:00+03	13600.00
878BF7	2017-07-10 15:42:00+03	56000.00
878C0F	2017-08-01 10:40:00+03	54400.00
878C2E	2017-08-12 06:59:00+03	28300.00
878CF8	2017-08-12 05:07:00+03	28800.00
878D18	2017-07-22 00:43:00+03	48500.00
878D3F	2017-08-10 21:22:00+03	31000.00
878D4C	2017-07-03 15:51:00+03	162700.00
878D7B	2017-07-16 06:00:00+03	20200.00
878D9D	2017-08-13 08:39:00+03	56600.00
878E03	2017-07-05 22:47:00+03	28800.00
878E84	2017-08-06 12:23:00+03	19600.00
878E91	2017-08-07 12:36:00+03	12600.00
878EE0	2017-07-19 06:14:00+03	56000.00
878F37	2017-08-12 04:47:00+03	96200.00
878F56	2017-08-11 18:06:00+03	9200.00
878F7C	2017-07-16 16:47:00+03	122300.00
878FB0	2017-07-22 23:57:00+03	101500.00
878FF6	2017-07-28 12:39:00+03	86500.00
87906D	2017-07-16 07:32:00+03	45500.00
8790F3	2017-07-22 17:31:00+03	38800.00
879119	2017-07-12 20:01:00+03	11600.00
87913E	2017-07-07 12:30:00+03	14000.00
87914D	2017-07-06 01:10:00+03	36200.00
879175	2017-07-20 23:01:00+03	34000.00
8791BA	2017-07-16 09:52:00+03	23400.00
8791D0	2017-08-04 15:40:00+03	40100.00
8791D7	2017-08-08 23:18:00+03	32700.00
8791E3	2017-07-30 00:42:00+03	75600.00
8791FE	2017-07-25 01:42:00+03	148200.00
879222	2017-07-23 12:30:00+03	37900.00
879244	2017-08-12 19:27:00+03	23600.00
879280	2017-07-18 02:16:00+03	27600.00
8792D5	2017-07-11 10:39:00+03	132800.00
879318	2017-07-24 17:44:00+03	48800.00
879365	2017-07-12 17:00:00+03	46000.00
879373	2017-08-04 11:45:00+03	13600.00
87942A	2017-08-11 09:33:00+03	49100.00
879430	2017-07-09 17:08:00+03	28800.00
87944D	2017-07-01 13:45:00+03	96800.00
879455	2017-07-10 05:38:00+03	14800.00
879487	2017-07-13 01:31:00+03	50600.00
8794AB	2017-08-07 03:11:00+03	69200.00
8794E1	2017-07-15 20:37:00+03	57800.00
879511	2017-07-04 13:58:00+03	315400.00
87953D	2017-07-11 04:37:00+03	62000.00
879561	2017-07-05 04:49:00+03	41600.00
8795CF	2017-07-17 03:45:00+03	130100.00
8795D7	2017-08-02 00:21:00+03	246000.00
8795DF	2017-07-27 01:58:00+03	47400.00
8795F3	2017-07-14 21:19:00+03	99300.00
879606	2017-07-26 15:04:00+03	278600.00
87962C	2017-07-21 21:15:00+03	14000.00
879694	2017-07-30 11:26:00+03	142600.00
8796F1	2017-07-07 16:07:00+03	55800.00
879783	2017-07-12 18:29:00+03	13500.00
8797A0	2017-07-08 08:35:00+03	69900.00
879801	2017-07-07 12:31:00+03	28800.00
87986D	2017-08-09 16:41:00+03	91800.00
87990F	2017-07-20 12:57:00+03	27300.00
879934	2017-08-14 08:21:00+03	143200.00
87996E	2017-07-11 09:30:00+03	112000.00
879972	2017-07-06 15:01:00+03	39200.00
879987	2017-07-12 18:56:00+03	133200.00
879999	2017-07-25 04:44:00+03	77600.00
87999E	2017-07-24 02:47:00+03	66600.00
8799C8	2017-07-02 13:03:00+03	155600.00
879A26	2017-07-20 11:32:00+03	61800.00
879A36	2017-07-19 00:37:00+03	48800.00
879A62	2017-07-10 00:26:00+03	81600.00
879A99	2017-07-17 14:06:00+03	58600.00
879B2D	2017-07-08 15:42:00+03	50200.00
879B40	2017-07-01 06:34:00+03	307700.00
879B59	2017-07-28 00:45:00+03	136200.00
879B9B	2017-07-23 19:35:00+03	81300.00
879BB8	2017-08-10 12:23:00+03	56700.00
879BD8	2017-07-14 08:56:00+03	167100.00
879C49	2017-07-21 04:14:00+03	28000.00
879CAA	2017-08-02 02:20:00+03	12400.00
879CB4	2017-07-24 23:16:00+03	173200.00
879CE4	2017-08-02 08:22:00+03	23200.00
879CE8	2017-08-04 01:09:00+03	8400.00
879CE9	2017-06-30 08:25:00+03	28000.00
879D4D	2017-08-11 06:46:00+03	28000.00
879D76	2017-07-07 03:13:00+03	21400.00
879DCB	2017-08-08 00:59:00+03	89600.00
879E0B	2017-07-26 22:08:00+03	30900.00
879E39	2017-07-01 19:16:00+03	36900.00
879E3C	2017-07-24 09:52:00+03	43200.00
879E89	2017-07-11 04:56:00+03	32200.00
879EA9	2017-07-17 22:43:00+03	13300.00
879ECA	2017-08-05 01:20:00+03	85800.00
879EE7	2017-07-17 13:56:00+03	56000.00
879F16	2017-07-08 08:56:00+03	32200.00
879F1F	2017-07-08 00:47:00+03	48900.00
879F22	2017-08-05 14:41:00+03	265800.00
879F24	2017-07-07 20:34:00+03	103500.00
879F6C	2017-08-03 14:48:00+03	73500.00
879F78	2017-07-31 10:21:00+03	46000.00
879F7C	2017-07-13 08:36:00+03	108000.00
879F84	2017-08-01 20:38:00+03	146400.00
879FD8	2017-07-21 00:29:00+03	93400.00
879FF3	2017-07-10 11:18:00+03	28000.00
87A010	2017-08-05 03:36:00+03	72600.00
87A047	2017-07-13 22:14:00+03	14800.00
87A11B	2017-07-12 14:34:00+03	29600.00
87A13C	2017-08-15 06:59:00+03	13000.00
87A147	2017-07-29 15:40:00+03	61500.00
87A165	2017-08-04 00:23:00+03	32800.00
87A1CC	2017-06-26 13:26:00+03	92800.00
87A213	2017-07-07 21:44:00+03	6000.00
87A241	2017-07-18 02:02:00+03	13000.00
87A27A	2017-07-09 12:06:00+03	26500.00
87A2F6	2017-07-06 04:52:00+03	46200.00
87A301	2017-07-29 06:59:00+03	6000.00
87A308	2017-07-21 16:25:00+03	56000.00
87A315	2017-08-10 20:57:00+03	162400.00
87A338	2017-07-11 00:36:00+03	23600.00
87A38C	2017-08-15 08:20:00+03	178800.00
87A3E2	2017-08-11 14:44:00+03	11600.00
87A431	2017-08-14 04:51:00+03	73300.00
87A439	2017-07-21 03:36:00+03	97500.00
87A452	2017-07-24 23:57:00+03	27200.00
87A4E4	2017-07-02 13:06:00+03	67800.00
87A52B	2017-07-03 03:51:00+03	48800.00
87A562	2017-07-11 15:14:00+03	21600.00
87A5EF	2017-07-24 00:01:00+03	14400.00
87A61E	2017-07-27 00:31:00+03	59800.00
87A62A	2017-08-05 12:41:00+03	22000.00
87A6EC	2017-07-28 11:52:00+03	12400.00
87A731	2017-08-13 21:30:00+03	27900.00
87A756	2017-07-26 11:42:00+03	61800.00
87A75A	2017-08-02 03:05:00+03	32700.00
87A7D9	2017-07-26 21:11:00+03	115800.00
87A865	2017-08-11 23:32:00+03	88500.00
87A891	2017-07-23 11:23:00+03	132800.00
87A892	2017-08-02 02:10:00+03	16400.00
87A89A	2017-07-03 06:09:00+03	28000.00
87A8CB	2017-08-14 00:32:00+03	166100.00
87A8D4	2017-08-14 13:26:00+03	113100.00
87A8DE	2017-08-01 12:36:00+03	52000.00
87A907	2017-08-01 09:04:00+03	27800.00
87A92F	2017-07-22 06:18:00+03	86300.00
87A951	2017-08-12 22:51:00+03	6000.00
87A973	2017-07-06 00:58:00+03	20000.00
87A980	2017-07-28 18:57:00+03	260300.00
87A9AF	2017-08-13 00:12:00+03	13800.00
87A9F0	2017-08-13 17:19:00+03	67300.00
87A9FC	2017-07-08 03:46:00+03	123000.00
87AA25	2017-07-23 06:56:00+03	129700.00
87AAAF	2017-08-02 11:33:00+03	61500.00
87AB12	2017-07-19 03:27:00+03	46000.00
87AB17	2017-08-15 14:19:00+03	138000.00
87ABE8	2017-07-24 07:14:00+03	15000.00
87AC21	2017-07-25 06:01:00+03	55800.00
87AC4F	2017-07-08 22:00:00+03	62800.00
87AC52	2017-07-28 07:04:00+03	23400.00
87ACD7	2017-06-29 23:26:00+03	169900.00
87AD1B	2017-07-08 15:42:00+03	20900.00
87AD56	2017-07-26 14:22:00+03	136800.00
87AD9F	2017-07-01 17:46:00+03	155600.00
87ADF8	2017-07-07 12:19:00+03	87000.00
87AE29	2017-08-11 04:10:00+03	43500.00
87AE50	2017-07-10 07:15:00+03	75600.00
87AE58	2017-07-23 11:19:00+03	73500.00
87AE63	2017-07-30 21:40:00+03	44000.00
87AF04	2017-07-15 08:07:00+03	59800.00
87AF24	2017-07-29 01:42:00+03	91500.00
87AF2B	2017-08-05 00:05:00+03	23200.00
87AF36	2017-07-20 09:51:00+03	21800.00
87AF5E	2017-07-18 02:41:00+03	170200.00
87AF7A	2017-07-20 20:48:00+03	51900.00
87AF7D	2017-08-12 14:45:00+03	61800.00
87AFC4	2017-08-06 02:21:00+03	52400.00
87AFE5	2017-07-09 08:08:00+03	56000.00
87AFED	2017-07-26 02:50:00+03	177200.00
87B031	2017-08-07 19:04:00+03	45200.00
87B0CA	2017-08-10 07:27:00+03	47100.00
87B10E	2017-07-08 17:06:00+03	59200.00
87B140	2017-08-10 09:09:00+03	118100.00
87B162	2017-08-05 15:26:00+03	34600.00
87B1C2	2017-06-30 08:19:00+03	116900.00
87B271	2017-07-16 14:47:00+03	27900.00
87B280	2017-08-11 12:57:00+03	26000.00
87B2D6	2017-06-28 17:59:00+03	40800.00
87B2E0	2017-07-10 17:41:00+03	16400.00
87B2F9	2017-07-26 19:05:00+03	31600.00
87B310	2017-08-08 03:17:00+03	136200.00
87B377	2017-07-29 07:20:00+03	33300.00
87B389	2017-08-02 14:07:00+03	58800.00
87B3F2	2017-07-28 10:18:00+03	47900.00
87B404	2017-08-08 02:26:00+03	8800.00
87B40E	2017-08-08 16:04:00+03	45100.00
87B50B	2017-07-09 03:16:00+03	6800.00
87B51F	2017-07-26 15:46:00+03	20400.00
87B52A	2017-07-18 21:26:00+03	302800.00
87B5F4	2017-07-16 00:07:00+03	33300.00
87B642	2017-07-11 13:43:00+03	6700.00
87B64F	2017-08-01 10:36:00+03	40800.00
87B6A4	2017-07-08 09:40:00+03	254600.00
87B795	2017-07-14 07:09:00+03	78300.00
87B7CC	2017-07-03 21:25:00+03	46900.00
87B7F7	2017-08-11 14:52:00+03	67200.00
87B845	2017-08-12 12:27:00+03	189200.00
87B879	2017-08-08 22:15:00+03	28800.00
87B970	2017-08-13 03:14:00+03	86600.00
87B971	2017-07-27 10:38:00+03	55800.00
87B9AA	2017-08-08 00:33:00+03	28800.00
87B9B4	2017-07-11 12:05:00+03	272400.00
87B9D6	2017-07-04 11:23:00+03	67600.00
87B9FA	2017-06-28 23:17:00+03	14800.00
87BA18	2017-07-29 04:24:00+03	55800.00
87BA73	2017-07-22 07:33:00+03	87200.00
87BA7F	2017-07-22 01:48:00+03	55800.00
87BAAE	2017-08-09 06:58:00+03	83300.00
87BAB4	2017-08-04 15:10:00+03	83500.00
87BABA	2017-07-25 10:51:00+03	56900.00
87BAFE	2017-07-29 12:37:00+03	55800.00
87BB01	2017-08-04 21:42:00+03	26800.00
87BB0C	2017-07-01 20:58:00+03	58000.00
87BB1F	2017-07-31 06:26:00+03	81600.00
87BBCF	2017-07-12 21:17:00+03	8000.00
87BBD1	2017-07-28 03:57:00+03	185600.00
87BBF6	2017-07-27 17:17:00+03	50000.00
87BC15	2017-06-27 16:42:00+03	67200.00
87BC65	2017-07-13 19:04:00+03	118500.00
87BC8A	2017-08-02 00:43:00+03	181700.00
87BC97	2017-07-08 15:57:00+03	229800.00
87BCD5	2017-07-15 22:11:00+03	51900.00
87BCDC	2017-08-08 01:19:00+03	83000.00
87BD72	2017-08-04 21:19:00+03	234700.00
87BDC8	2017-08-09 05:03:00+03	135300.00
87BDCE	2017-07-19 00:31:00+03	265700.00
87BDD6	2017-08-04 00:25:00+03	46400.00
87BE0F	2017-07-07 15:33:00+03	286700.00
87BE3E	2017-08-03 01:44:00+03	6300.00
87BE7E	2017-08-15 13:13:00+03	134400.00
87BEA6	2017-07-28 23:53:00+03	123000.00
87BEB0	2017-07-29 15:19:00+03	51600.00
87BEB8	2017-07-18 23:20:00+03	23200.00
87BF1A	2017-07-23 13:43:00+03	258400.00
87BF35	2017-07-02 09:01:00+03	14700.00
87BF72	2017-07-19 13:15:00+03	56000.00
87BFCA	2017-08-05 20:21:00+03	27800.00
87BFD1	2017-07-17 22:23:00+03	56900.00
87C022	2017-07-10 18:23:00+03	24200.00
87C0B7	2017-08-03 23:44:00+03	19600.00
87C0CA	2017-07-20 09:55:00+03	92800.00
87C110	2017-08-04 13:01:00+03	90400.00
87C128	2017-07-19 04:55:00+03	26400.00
87C137	2017-07-29 17:06:00+03	96800.00
87C1D1	2017-08-04 00:14:00+03	17200.00
87C239	2017-06-29 10:48:00+03	29600.00
87C247	2017-07-07 14:08:00+03	47600.00
87C255	2017-08-12 02:58:00+03	37100.00
87C2B0	2017-08-14 02:17:00+03	8200.00
87C2C8	2017-08-04 22:26:00+03	147100.00
87C2DB	2017-08-15 03:30:00+03	53700.00
87C2ED	2017-08-15 08:40:00+03	136600.00
87C2EF	2017-07-07 23:11:00+03	20500.00
87C38B	2017-07-18 06:46:00+03	83000.00
87C3AA	2017-07-17 15:14:00+03	8200.00
87C3E7	2017-07-24 11:51:00+03	265700.00
87C4FB	2017-08-12 07:04:00+03	6800.00
87C550	2017-07-01 03:36:00+03	24700.00
87C56C	2017-07-14 04:58:00+03	28700.00
87C572	2017-08-13 13:53:00+03	76600.00
87C581	2017-08-08 22:04:00+03	40000.00
87C5C6	2017-07-04 06:45:00+03	83000.00
87C5D5	2017-07-29 00:33:00+03	132800.00
87C5F7	2017-08-13 22:46:00+03	133700.00
87C686	2017-07-20 13:00:00+03	32700.00
87C698	2017-08-04 09:53:00+03	136200.00
87C71E	2017-08-11 14:16:00+03	79900.00
87C7B9	2017-07-09 13:20:00+03	24800.00
87C7E8	2017-08-13 00:03:00+03	21600.00
87C7ED	2017-07-25 03:59:00+03	85700.00
87C7F6	2017-08-12 03:07:00+03	387300.00
87C809	2017-08-02 03:45:00+03	96800.00
87C81F	2017-07-29 19:32:00+03	16400.00
87C885	2017-07-14 13:19:00+03	179400.00
87C8A5	2017-07-16 05:07:00+03	28800.00
87C8CA	2017-07-07 13:55:00+03	39500.00
87C8CB	2017-08-01 08:29:00+03	131100.00
87C8F3	2017-07-31 07:58:00+03	258400.00
87C959	2017-07-01 19:16:00+03	68800.00
87C95C	2017-07-27 00:28:00+03	44100.00
87C9D8	2017-07-13 01:38:00+03	37900.00
87C9E3	2017-08-07 00:59:00+03	49700.00
87CA07	2017-08-14 21:44:00+03	42400.00
87CA39	2017-07-08 07:36:00+03	67600.00
87CA55	2017-08-06 10:08:00+03	246000.00
87CA5B	2017-07-19 23:28:00+03	79000.00
87CB03	2017-08-03 11:35:00+03	64600.00
87CB68	2017-06-30 19:38:00+03	59300.00
87CC27	2017-07-29 00:31:00+03	25000.00
87CC35	2017-07-27 10:07:00+03	37100.00
87CC37	2017-07-20 03:23:00+03	6800.00
87CC40	2017-07-16 03:37:00+03	64100.00
87CC6A	2017-07-25 00:39:00+03	410400.00
87CCDC	2017-07-22 04:29:00+03	28800.00
87CD54	2017-07-15 22:03:00+03	30900.00
87CDF2	2017-07-07 05:59:00+03	31000.00
87CE15	2017-07-22 14:10:00+03	35700.00
87CE52	2017-07-15 06:58:00+03	37900.00
87CE6A	2017-08-08 06:05:00+03	12400.00
87CED3	2017-08-05 05:47:00+03	83000.00
87CF2B	2017-07-17 12:22:00+03	7400.00
87CFC4	2017-07-20 19:39:00+03	16400.00
87CFD7	2017-07-26 22:31:00+03	38400.00
87CFE5	2017-07-20 23:01:00+03	65400.00
87CFF3	2017-07-28 05:37:00+03	55800.00
87D02A	2017-07-03 10:22:00+03	46000.00
87D0AD	2017-07-29 06:04:00+03	861000.00
87D129	2017-07-22 14:35:00+03	108600.00
87D161	2017-08-05 23:01:00+03	84300.00
87D1FA	2017-07-12 02:38:00+03	115100.00
87D212	2017-08-04 17:53:00+03	47400.00
87D2C8	2017-07-07 12:51:00+03	290400.00
87D2C9	2017-07-13 04:25:00+03	69100.00
87D2EC	2017-07-24 15:57:00+03	116800.00
87D372	2017-07-16 21:41:00+03	103500.00
87D39F	2017-07-22 15:42:00+03	22000.00
87D3C8	2017-07-24 22:56:00+03	46200.00
87D463	2017-08-10 16:53:00+03	34000.00
87D484	2017-08-06 17:01:00+03	46300.00
87D504	2017-07-15 11:53:00+03	70600.00
87D54C	2017-08-10 22:21:00+03	17800.00
87D584	2017-07-25 02:10:00+03	39500.00
87D5C8	2017-07-01 17:29:00+03	118100.00
87D603	2017-07-06 20:27:00+03	30200.00
87D6D4	2017-08-14 00:05:00+03	14000.00
87D7B0	2017-07-25 09:58:00+03	129700.00
87D7D2	2017-07-02 18:06:00+03	49800.00
87D802	2017-07-29 13:52:00+03	34100.00
87D829	2017-08-02 00:43:00+03	292700.00
87D895	2017-07-25 15:21:00+03	12600.00
87D89A	2017-08-13 02:59:00+03	61400.00
87D9B4	2017-07-01 08:38:00+03	51600.00
87DA79	2017-07-20 12:04:00+03	36000.00
87DA7B	2017-08-05 04:47:00+03	149000.00
87DADB	2017-08-14 02:12:00+03	130900.00
87DB0E	2017-08-05 17:26:00+03	42800.00
87DB29	2017-07-02 10:27:00+03	65200.00
87DB92	2017-07-09 02:00:00+03	66100.00
87DC48	2017-07-19 12:58:00+03	86600.00
87DC58	2017-07-27 22:20:00+03	57700.00
87DC97	2017-08-06 11:04:00+03	46200.00
87DCC0	2017-07-05 04:58:00+03	29600.00
87DCEF	2017-07-15 04:09:00+03	22600.00
87DD00	2017-07-15 16:05:00+03	20600.00
87DD3F	2017-07-09 22:04:00+03	44800.00
87DD48	2017-07-16 11:31:00+03	43200.00
87DD66	2017-07-16 09:10:00+03	118000.00
87DD90	2017-07-14 05:33:00+03	25200.00
87DDF3	2017-08-05 23:11:00+03	202800.00
87DE4B	2017-07-24 17:50:00+03	19000.00
87DE86	2017-07-28 19:42:00+03	27400.00
87DE88	2017-07-25 09:12:00+03	33800.00
87DEAB	2017-08-08 02:18:00+03	124400.00
87DED2	2017-07-25 21:02:00+03	12400.00
87DF07	2017-07-09 03:51:00+03	92800.00
87DF53	2017-07-21 16:34:00+03	68400.00
87DF8E	2017-07-19 21:01:00+03	41400.00
87DF96	2017-07-10 18:36:00+03	16400.00
87DFA5	2017-08-08 05:20:00+03	29300.00
87DFB5	2017-08-08 04:08:00+03	399600.00
87DFCC	2017-07-31 11:34:00+03	46900.00
87E00D	2017-07-30 05:05:00+03	133100.00
87E026	2017-07-28 12:52:00+03	49200.00
87E078	2017-07-09 22:23:00+03	65900.00
87E0A2	2017-07-27 20:49:00+03	50100.00
87E0EC	2017-08-15 15:55:00+03	33300.00
87E0FC	2017-07-29 07:08:00+03	28600.00
87E159	2017-07-12 01:28:00+03	109400.00
87E167	2017-07-20 00:13:00+03	74800.00
87E17E	2017-07-11 15:41:00+03	115600.00
87E19C	2017-07-14 02:31:00+03	186900.00
87E1C6	2017-08-02 11:42:00+03	66600.00
87E20E	2017-07-31 15:07:00+03	92000.00
87E251	2017-08-01 05:04:00+03	92900.00
87E30E	2017-08-03 00:25:00+03	135000.00
87E323	2017-07-04 16:55:00+03	32800.00
87E3A9	2017-08-12 10:18:00+03	58400.00
87E3AE	2017-08-13 11:24:00+03	39700.00
87E43C	2017-08-06 21:25:00+03	12000.00
87E475	2017-07-06 02:22:00+03	21400.00
87E49D	2017-08-12 01:02:00+03	122300.00
87E530	2017-07-13 05:21:00+03	28800.00
87E592	2017-07-06 03:02:00+03	52700.00
87E5AD	2017-07-23 00:03:00+03	26600.00
87E5B8	2017-08-12 04:19:00+03	111600.00
87E5CD	2017-07-10 00:57:00+03	12000.00
87E61E	2017-08-14 11:19:00+03	47400.00
87E637	2017-08-08 17:29:00+03	58600.00
87E683	2017-07-24 03:08:00+03	21000.00
87E6D4	2017-08-09 05:41:00+03	27600.00
87E72A	2017-08-12 17:10:00+03	185800.00
87E72F	2017-08-08 15:17:00+03	56900.00
87E79E	2017-08-07 07:57:00+03	42800.00
87E8BE	2017-07-09 04:23:00+03	115800.00
87E90D	2017-07-15 18:00:00+03	111600.00
87E921	2017-08-12 17:14:00+03	31600.00
87E98D	2017-07-05 01:12:00+03	23400.00
87E991	2017-07-03 15:38:00+03	53300.00
87E9C2	2017-07-28 05:32:00+03	97600.00
87EA0D	2017-07-06 09:38:00+03	42000.00
87EA1E	2017-07-06 11:46:00+03	27800.00
87EA33	2017-08-08 03:17:00+03	81600.00
87EA86	2017-08-02 04:06:00+03	28000.00
87EA93	2017-07-21 20:31:00+03	15100.00
87EB43	2017-07-13 20:00:00+03	12400.00
87EB72	2017-07-21 05:15:00+03	48800.00
87EBCB	2017-07-27 01:36:00+03	49100.00
87EBE9	2017-08-04 00:27:00+03	46000.00
87ED10	2017-07-16 19:31:00+03	246000.00
87ED62	2017-08-07 19:55:00+03	288800.00
87ED67	2017-07-02 12:27:00+03	30000.00
87EDB9	2017-07-14 06:31:00+03	92000.00
87EE40	2017-08-13 09:42:00+03	46400.00
87EE67	2017-07-24 23:19:00+03	22600.00
87EE6D	2017-08-02 19:16:00+03	119500.00
87EEB2	2017-08-06 01:59:00+03	18200.00
87EFF1	2017-07-14 20:18:00+03	16400.00
87EFF3	2017-08-09 18:29:00+03	96600.00
87F004	2017-07-30 17:52:00+03	92000.00
87F024	2017-08-03 13:34:00+03	72400.00
87F039	2017-08-12 08:55:00+03	155200.00
87F18C	2017-07-15 22:39:00+03	258400.00
87F18D	2017-08-07 22:44:00+03	58600.00
87F1F3	2017-07-31 06:59:00+03	76600.00
87F259	2017-08-08 08:18:00+03	101200.00
87F2BE	2017-07-29 07:38:00+03	232900.00
87F2E8	2017-07-22 19:07:00+03	125400.00
87F355	2017-07-15 15:44:00+03	21400.00
87F35B	2017-07-08 16:38:00+03	62900.00
87F364	2017-08-08 00:48:00+03	110500.00
87F367	2017-07-22 23:34:00+03	63200.00
87F36B	2017-07-10 22:35:00+03	94700.00
87F383	2017-07-22 18:17:00+03	33100.00
87F3AC	2017-07-15 01:43:00+03	56000.00
87F3BE	2017-08-05 19:03:00+03	6700.00
87F3CF	2017-07-08 05:30:00+03	149300.00
87F412	2017-08-05 12:24:00+03	59700.00
87F457	2017-07-28 06:24:00+03	31100.00
87F489	2017-07-12 15:41:00+03	81600.00
87F53E	2017-08-14 03:12:00+03	24000.00
87F571	2017-08-14 20:39:00+03	50400.00
87F59D	2017-08-07 22:20:00+03	40600.00
87F642	2017-07-20 13:53:00+03	65900.00
87F65C	2017-07-08 09:44:00+03	476000.00
87F66A	2017-08-05 14:19:00+03	8200.00
87F687	2017-07-29 14:17:00+03	23400.00
87F6AA	2017-07-12 03:28:00+03	48800.00
87F729	2017-07-05 04:26:00+03	56100.00
87F78A	2017-08-12 21:43:00+03	13700.00
87F7AB	2017-08-07 19:34:00+03	112000.00
87F8E8	2017-07-10 04:07:00+03	62600.00
87F913	2017-08-03 02:41:00+03	50100.00
87F914	2017-08-14 22:08:00+03	23900.00
87F932	2017-07-20 15:57:00+03	182300.00
87F991	2017-07-04 14:23:00+03	31600.00
87F9A8	2017-08-10 07:32:00+03	61800.00
87FA12	2017-07-26 23:04:00+03	25100.00
87FA35	2017-08-15 15:00:00+03	65200.00
87FA73	2017-08-02 12:20:00+03	114700.00
87FA95	2017-07-29 00:10:00+03	16400.00
87FAC3	2017-08-12 12:28:00+03	51200.00
87FAC6	2017-07-11 18:42:00+03	6700.00
87FAE9	2017-07-26 06:36:00+03	55800.00
87FB19	2017-08-03 07:30:00+03	76800.00
87FB69	2017-07-07 10:53:00+03	52400.00
87FB98	2017-07-06 15:44:00+03	12000.00
87FBD5	2017-07-19 07:57:00+03	26800.00
87FBF0	2017-07-22 11:07:00+03	95600.00
87FC2A	2017-08-15 14:13:00+03	19600.00
87FC38	2017-07-15 11:42:00+03	6000.00
87FC62	2017-08-12 02:44:00+03	119600.00
87FCC6	2017-08-01 06:36:00+03	29500.00
87FCD5	2017-08-02 06:36:00+03	56600.00
87FCDC	2017-08-02 21:05:00+03	24400.00
87FD01	2017-07-23 00:05:00+03	28800.00
87FD13	2017-07-28 08:01:00+03	51200.00
87FD49	2017-08-11 17:58:00+03	12400.00
87FD80	2017-07-07 23:18:00+03	28800.00
87FEE4	2017-06-25 08:23:00+03	399600.00
87FEEF	2017-07-15 00:29:00+03	6000.00
87FFC5	2017-07-30 10:22:00+03	23400.00
87FFE5	2017-07-18 18:49:00+03	22000.00
880013	2017-08-12 20:54:00+03	4000.00
880063	2017-08-09 21:25:00+03	28800.00
880073	2017-08-14 18:19:00+03	137700.00
880097	2017-07-08 08:44:00+03	51600.00
88009C	2017-07-16 19:39:00+03	132500.00
8800AE	2017-07-22 16:05:00+03	108000.00
8800B0	2017-07-22 03:14:00+03	310500.00
8802C1	2017-07-22 04:45:00+03	48800.00
8802DC	2017-07-18 08:15:00+03	56000.00
880378	2017-07-05 22:48:00+03	174900.00
880399	2017-07-27 02:19:00+03	133200.00
8803CC	2017-07-11 04:38:00+03	29600.00
8803CF	2017-08-09 00:09:00+03	36200.00
8803E1	2017-07-19 10:45:00+03	88900.00
8803F0	2017-07-16 11:14:00+03	122300.00
880455	2017-07-13 19:42:00+03	24700.00
880481	2017-07-07 14:04:00+03	42600.00
8804A1	2017-08-15 03:30:00+03	75600.00
8804B6	2017-07-02 10:35:00+03	93900.00
880536	2017-08-09 08:49:00+03	95600.00
8805B2	2017-07-31 14:40:00+03	12600.00
8805BD	2017-07-04 18:41:00+03	62600.00
8805ED	2017-07-31 16:35:00+03	28800.00
8805F8	2017-07-27 03:38:00+03	23200.00
880652	2017-07-29 08:49:00+03	135600.00
880670	2017-07-24 08:35:00+03	55400.00
8806EB	2017-07-14 14:44:00+03	56000.00
88070E	2017-08-10 02:24:00+03	46400.00
8807B5	2017-07-14 09:22:00+03	99300.00
8807E4	2017-08-02 17:16:00+03	38600.00
88085E	2017-08-06 00:53:00+03	86500.00
88086C	2017-07-19 18:35:00+03	27200.00
8808FE	2017-08-09 18:53:00+03	57700.00
88092F	2017-08-13 22:10:00+03	87000.00
880944	2017-07-14 10:14:00+03	31000.00
880A4A	2017-07-29 02:58:00+03	135600.00
880B61	2017-07-31 14:14:00+03	27200.00
880B63	2017-07-26 19:48:00+03	21800.00
880B7B	2017-08-03 02:31:00+03	37100.00
880BAE	2017-07-30 14:59:00+03	96800.00
880BF7	2017-07-06 16:28:00+03	61800.00
880C1B	2017-08-03 05:05:00+03	31600.00
880C69	2017-07-07 16:02:00+03	33400.00
880CEF	2017-07-25 13:31:00+03	46800.00
880D12	2017-07-25 19:58:00+03	75300.00
880D15	2017-07-17 02:41:00+03	110400.00
880D16	2017-07-06 02:10:00+03	266400.00
880D8B	2017-08-07 08:07:00+03	44700.00
880DC9	2017-08-13 01:27:00+03	79600.00
880DCD	2017-08-13 08:14:00+03	284400.00
880DD8	2017-07-31 06:13:00+03	80000.00
880DEB	2017-08-01 21:33:00+03	92800.00
880E21	2017-07-30 11:31:00+03	142800.00
880E41	2017-08-07 03:31:00+03	49800.00
880EA3	2017-07-07 20:11:00+03	16400.00
880EBA	2017-07-21 23:36:00+03	282100.00
880ED0	2017-07-21 19:39:00+03	6400.00
880F01	2017-07-03 15:02:00+03	29200.00
880F21	2017-08-06 17:33:00+03	40300.00
880FB4	2017-07-11 02:27:00+03	58200.00
880FE4	2017-07-06 18:07:00+03	47000.00
880FE8	2017-08-01 04:59:00+03	25800.00
881002	2017-07-29 12:03:00+03	27200.00
88100C	2017-08-12 03:07:00+03	20200.00
88100F	2017-08-11 14:23:00+03	541500.00
881048	2017-07-19 11:13:00+03	41600.00
881056	2017-08-08 00:26:00+03	66600.00
8810AC	2017-07-09 00:53:00+03	27800.00
8810E5	2017-08-10 21:10:00+03	115600.00
8810F1	2017-07-14 00:37:00+03	130000.00
881135	2017-07-04 09:18:00+03	62600.00
8811A4	2017-08-13 19:42:00+03	59300.00
88122F	2017-07-07 16:38:00+03	43600.00
88123F	2017-08-09 22:38:00+03	124200.00
8812B9	2017-07-28 10:33:00+03	232200.00
8812ED	2017-08-11 21:20:00+03	24700.00
881384	2017-07-19 05:42:00+03	50200.00
8813A5	2017-08-05 09:15:00+03	39200.00
8813AB	2017-07-26 23:51:00+03	22000.00
8813BD	2017-08-05 22:05:00+03	33100.00
881404	2017-08-09 08:24:00+03	14800.00
881407	2017-07-28 09:25:00+03	24400.00
88141C	2017-07-14 19:06:00+03	50600.00
8814C6	2017-08-13 14:35:00+03	28800.00
8814F0	2017-07-26 12:02:00+03	500100.00
881505	2017-08-07 13:05:00+03	37200.00
881509	2017-07-14 23:49:00+03	62600.00
881533	2017-07-23 06:42:00+03	37900.00
88154E	2017-08-05 19:08:00+03	141600.00
881556	2017-08-05 22:20:00+03	26800.00
8815BB	2017-07-21 02:54:00+03	34000.00
8815EB	2017-08-09 00:11:00+03	60400.00
881674	2017-07-09 13:41:00+03	112600.00
88169A	2017-07-03 23:01:00+03	40000.00
88169E	2017-07-07 18:44:00+03	26800.00
88169F	2017-07-14 18:45:00+03	106800.00
881718	2017-07-17 14:14:00+03	34000.00
881741	2017-07-26 04:52:00+03	139200.00
88175F	2017-07-15 17:46:00+03	17600.00
881824	2017-07-05 05:03:00+03	366600.00
88182D	2017-08-15 03:54:00+03	98400.00
8818B4	2017-07-27 12:15:00+03	97600.00
8818CB	2017-07-19 07:32:00+03	92100.00
881913	2017-07-30 07:44:00+03	12400.00
881922	2017-08-08 09:20:00+03	41200.00
881970	2017-07-17 13:20:00+03	135400.00
88197E	2017-07-09 11:26:00+03	57100.00
8819D5	2017-08-14 13:43:00+03	28200.00
881A63	2017-08-01 10:53:00+03	150600.00
881ABC	2017-07-22 09:12:00+03	36800.00
881AD5	2017-07-21 10:12:00+03	96200.00
881AE1	2017-07-02 16:53:00+03	26000.00
881B3C	2017-08-02 15:03:00+03	30000.00
881B52	2017-07-06 22:47:00+03	75300.00
881BCC	2017-07-31 06:28:00+03	12600.00
881BD4	2017-07-03 09:31:00+03	57400.00
881C5D	2017-08-13 01:06:00+03	94900.00
881C78	2017-08-06 11:45:00+03	47200.00
881CBA	2017-07-22 19:12:00+03	65400.00
881CCD	2017-07-03 20:34:00+03	28000.00
881D74	2017-08-06 15:11:00+03	76400.00
881DDE	2017-08-06 13:34:00+03	66600.00
881E0F	2017-07-19 13:00:00+03	266400.00
881E18	2017-07-12 00:11:00+03	271200.00
881EAA	2017-07-08 01:06:00+03	16400.00
881EBF	2017-07-20 09:08:00+03	46000.00
881EE8	2017-07-07 05:37:00+03	70800.00
881F66	2017-07-10 17:52:00+03	101200.00
881F95	2017-07-14 14:04:00+03	17600.00
881FCD	2017-07-14 20:21:00+03	56000.00
882091	2017-08-15 15:10:00+03	32700.00
882096	2017-07-15 13:37:00+03	89600.00
8820B0	2017-07-26 01:34:00+03	28000.00
8820C0	2017-07-20 12:25:00+03	215500.00
8820D3	2017-08-13 13:09:00+03	28000.00
882121	2017-07-16 13:57:00+03	102100.00
88212D	2017-08-05 10:36:00+03	245400.00
88214D	2017-07-31 16:34:00+03	55800.00
88215B	2017-07-08 16:43:00+03	78000.00
8821CE	2017-07-31 21:21:00+03	28800.00
8821F8	2017-08-05 22:29:00+03	56000.00
88226D	2017-07-10 13:50:00+03	25800.00
88228B	2017-08-02 19:32:00+03	149600.00
882357	2017-08-12 08:11:00+03	136200.00
8823E3	2017-08-08 14:14:00+03	77000.00
882429	2017-08-14 17:57:00+03	18600.00
882448	2017-08-10 06:05:00+03	112000.00
882537	2017-06-25 19:39:00+03	43800.00
88253E	2017-07-04 22:34:00+03	26200.00
8825DE	2017-08-07 00:36:00+03	65500.00
8825E0	2017-06-26 20:39:00+03	63500.00
88260D	2017-07-16 16:06:00+03	46000.00
882615	2017-07-18 03:17:00+03	46400.00
882689	2017-08-13 07:04:00+03	89600.00
8827D8	2017-07-13 22:17:00+03	52400.00
8827D9	2017-08-01 07:24:00+03	46200.00
882880	2017-07-04 02:52:00+03	31700.00
8828F4	2017-07-21 08:49:00+03	36200.00
882947	2017-07-26 17:29:00+03	18100.00
882975	2017-07-28 20:55:00+03	55800.00
882977	2017-07-28 13:42:00+03	53600.00
882999	2017-08-06 05:16:00+03	59900.00
882A21	2017-07-23 14:57:00+03	29600.00
882A36	2017-07-25 06:28:00+03	46300.00
882A3E	2017-07-09 12:09:00+03	51200.00
882A7F	2017-07-02 22:27:00+03	18600.00
882ADA	2017-08-14 10:05:00+03	108100.00
882ADF	2017-06-30 12:50:00+03	246000.00
882AF4	2017-07-22 04:25:00+03	37900.00
882B3A	2017-07-16 00:42:00+03	70700.00
882B58	2017-07-28 23:29:00+03	6000.00
882C40	2017-07-06 13:02:00+03	26200.00
882C51	2017-07-26 15:28:00+03	28800.00
882CB0	2017-06-25 01:26:00+03	17000.00
882D15	2017-07-11 08:53:00+03	131600.00
882D23	2017-07-14 18:04:00+03	37200.00
882D6B	2017-07-20 06:48:00+03	13600.00
882DD7	2017-08-05 06:33:00+03	664200.00
882DF4	2017-07-20 10:08:00+03	170700.00
882DF7	2017-08-12 21:10:00+03	173500.00
882E0C	2017-07-13 05:32:00+03	51600.00
882EF6	2017-08-02 21:20:00+03	16400.00
882F3A	2017-08-14 12:29:00+03	26000.00
882FD3	2017-08-03 19:57:00+03	69700.00
883003	2017-08-10 04:00:00+03	74800.00
88300B	2017-07-03 03:09:00+03	27800.00
883067	2017-08-06 06:59:00+03	92800.00
883075	2017-08-09 23:24:00+03	25000.00
883089	2017-07-31 03:08:00+03	86600.00
8830D9	2017-07-24 11:52:00+03	38600.00
883139	2017-07-19 08:27:00+03	12600.00
88315D	2017-07-24 16:40:00+03	14000.00
88317C	2017-08-10 01:12:00+03	35800.00
883227	2017-07-07 17:58:00+03	23200.00
8832B4	2017-08-03 07:02:00+03	64300.00
883370	2017-08-01 23:20:00+03	86400.00
88339D	2017-07-28 20:47:00+03	24700.00
8833C3	2017-07-12 13:43:00+03	29400.00
8833E1	2017-07-22 10:06:00+03	140900.00
883435	2017-07-25 04:57:00+03	96800.00
8834C7	2017-07-19 16:35:00+03	103500.00
88357D	2017-08-10 17:02:00+03	68800.00
883583	2017-07-28 02:32:00+03	26000.00
8835CA	2017-07-18 09:45:00+03	70600.00
8835DD	2017-08-12 05:26:00+03	165800.00
8835E0	2017-08-08 02:20:00+03	22000.00
8835EB	2017-07-24 17:08:00+03	54800.00
883604	2017-07-27 21:16:00+03	56600.00
8836D8	2017-07-03 00:21:00+03	55800.00
8836FC	2017-07-26 22:40:00+03	56000.00
88375A	2017-07-27 17:24:00+03	23400.00
883761	2017-08-15 17:01:00+03	76600.00
883777	2017-08-04 05:33:00+03	94000.00
883784	2017-08-05 20:08:00+03	132300.00
8837BE	2017-07-04 00:52:00+03	13400.00
8837E5	2017-08-03 18:50:00+03	59800.00
883812	2017-07-24 04:47:00+03	140800.00
883835	2017-07-17 09:57:00+03	294800.00
883878	2017-08-11 03:16:00+03	116900.00
8838A4	2017-08-12 10:33:00+03	28000.00
8838D4	2017-07-13 02:37:00+03	27200.00
8838D9	2017-07-31 20:18:00+03	67400.00
883977	2017-07-02 02:25:00+03	57600.00
88397F	2017-07-06 16:41:00+03	193700.00
883997	2017-07-14 14:03:00+03	66600.00
883A12	2017-08-15 16:29:00+03	91600.00
883A34	2017-07-23 18:23:00+03	53200.00
883A8D	2017-07-29 18:44:00+03	54800.00
883AEF	2017-07-06 03:37:00+03	17000.00
883BB6	2017-07-17 08:47:00+03	64600.00
883BD3	2017-07-17 05:37:00+03	80000.00
883BED	2017-07-16 02:08:00+03	44800.00
883BFE	2017-07-07 08:57:00+03	46000.00
883C0B	2017-08-11 10:44:00+03	26200.00
883CBA	2017-07-26 02:25:00+03	28000.00
883CE1	2017-07-12 08:31:00+03	83700.00
883D12	2017-08-11 23:05:00+03	13400.00
883D5C	2017-07-17 17:25:00+03	28800.00
883E80	2017-07-13 08:33:00+03	113200.00
883EE2	2017-08-06 18:36:00+03	62000.00
883F49	2017-08-13 09:17:00+03	111600.00
884002	2017-07-22 20:43:00+03	17800.00
88402C	2017-08-09 02:11:00+03	64800.00
88404E	2017-07-18 14:47:00+03	379600.00
884073	2017-07-02 14:36:00+03	89600.00
8840AC	2017-08-01 01:31:00+03	87200.00
88411C	2017-08-05 02:04:00+03	6200.00
88416D	2017-07-05 12:16:00+03	78100.00
884170	2017-08-14 07:51:00+03	12400.00
8841B4	2017-07-30 12:20:00+03	26200.00
8841F2	2017-07-10 06:36:00+03	98400.00
8842A0	2017-07-27 02:18:00+03	26000.00
8842FA	2017-07-20 19:53:00+03	16400.00
8843A2	2017-07-04 20:07:00+03	248500.00
8843DF	2017-08-12 12:08:00+03	60400.00
88443F	2017-07-28 14:28:00+03	48800.00
884442	2017-07-16 13:40:00+03	65000.00
884451	2017-08-01 12:01:00+03	94000.00
884496	2017-07-20 16:51:00+03	296700.00
8844E8	2017-08-04 16:06:00+03	137600.00
88452D	2017-08-11 12:18:00+03	62300.00
8845E5	2017-07-22 06:51:00+03	100600.00
884603	2017-07-13 22:31:00+03	88800.00
8846E5	2017-07-29 03:05:00+03	123600.00
8846FF	2017-07-27 05:00:00+03	45200.00
88473D	2017-07-28 13:19:00+03	43200.00
884876	2017-08-12 15:08:00+03	87800.00
884897	2017-08-11 00:55:00+03	46400.00
884929	2017-07-04 23:10:00+03	51900.00
884932	2017-07-04 21:26:00+03	35800.00
884982	2017-06-26 22:50:00+03	10800.00
8849BB	2017-07-28 19:13:00+03	77200.00
8849CC	2017-08-14 07:05:00+03	13400.00
8849CE	2017-08-04 00:37:00+03	315200.00
8849E2	2017-08-13 16:30:00+03	298500.00
884A30	2017-07-21 07:08:00+03	136800.00
884A35	2017-08-09 19:41:00+03	28800.00
884AC1	2017-08-07 10:55:00+03	67500.00
884B36	2017-07-01 05:22:00+03	23400.00
884B4B	2017-07-31 23:47:00+03	265700.00
884B6F	2017-07-02 13:31:00+03	77700.00
884B7E	2017-07-12 13:03:00+03	92800.00
884BCA	2017-07-25 06:24:00+03	23400.00
884C44	2017-08-03 06:57:00+03	48100.00
884C65	2017-08-08 17:08:00+03	101100.00
884CC3	2017-08-02 07:30:00+03	67200.00
884CEE	2017-07-26 22:19:00+03	270800.00
884CF7	2017-07-29 03:48:00+03	264000.00
884E08	2017-08-10 17:33:00+03	12000.00
884E36	2017-08-09 08:26:00+03	123200.00
884E66	2017-08-12 13:23:00+03	38200.00
884E71	2017-08-03 09:01:00+03	32800.00
884E8A	2017-07-16 15:25:00+03	52000.00
884E8F	2017-07-11 20:09:00+03	24400.00
884EA4	2017-07-07 12:29:00+03	48600.00
884EAD	2017-07-23 10:25:00+03	105100.00
884EB1	2017-07-23 01:55:00+03	48800.00
884F0C	2017-08-09 23:04:00+03	92700.00
884F40	2017-08-10 14:07:00+03	96400.00
884FDB	2017-07-10 14:08:00+03	313800.00
884FE4	2017-07-09 20:13:00+03	75600.00
88500A	2017-07-25 08:30:00+03	47200.00
885051	2017-07-15 23:29:00+03	52700.00
885056	2017-07-14 21:00:00+03	281500.00
88506D	2017-08-03 09:32:00+03	185600.00
8850B4	2017-08-04 22:56:00+03	155600.00
8850C5	2017-07-12 15:04:00+03	100000.00
885137	2017-07-05 01:50:00+03	114800.00
885187	2017-07-04 20:26:00+03	28000.00
8851EB	2017-07-20 18:27:00+03	20400.00
8851FB	2017-08-13 10:10:00+03	61800.00
88524C	2017-07-03 06:46:00+03	66600.00
885250	2017-08-10 01:34:00+03	20200.00
88527F	2017-07-02 20:47:00+03	46000.00
8852DE	2017-08-06 10:44:00+03	28000.00
8852EE	2017-06-30 21:42:00+03	47000.00
88531F	2017-07-08 19:51:00+03	147700.00
88534D	2017-08-10 00:37:00+03	66600.00
88535E	2017-08-07 19:46:00+03	108000.00
885383	2017-07-18 15:45:00+03	59400.00
88539D	2017-08-08 11:21:00+03	19600.00
885410	2017-08-04 09:34:00+03	47100.00
88543E	2017-07-30 10:36:00+03	67700.00
885470	2017-08-06 23:39:00+03	204100.00
8854A5	2017-07-17 17:03:00+03	20800.00
8854CB	2017-07-22 14:47:00+03	27600.00
885590	2017-08-03 12:15:00+03	25700.00
885598	2017-08-15 16:44:00+03	28000.00
885599	2017-07-30 22:17:00+03	37600.00
8855E0	2017-07-10 13:31:00+03	107600.00
8855EE	2017-08-09 05:57:00+03	37200.00
885609	2017-07-21 21:20:00+03	12000.00
885614	2017-07-21 05:47:00+03	52000.00
885621	2017-07-05 11:09:00+03	81300.00
885631	2017-06-29 02:28:00+03	22400.00
88570C	2017-07-09 18:19:00+03	148200.00
885731	2017-07-23 18:40:00+03	57800.00
88574C	2017-08-15 08:27:00+03	34000.00
885760	2017-07-26 15:24:00+03	36900.00
8857B1	2017-08-03 15:55:00+03	166100.00
8857C1	2017-07-04 21:51:00+03	65200.00
885854	2017-07-03 16:54:00+03	47200.00
8858BF	2017-07-08 21:14:00+03	43200.00
8858D1	2017-07-06 10:37:00+03	18800.00
8858E9	2017-07-11 03:19:00+03	107700.00
885972	2017-06-29 00:05:00+03	40800.00
8859AD	2017-06-29 01:40:00+03	24800.00
8859E2	2017-07-20 22:27:00+03	71800.00
885A82	2017-08-10 17:38:00+03	10800.00
885AB5	2017-07-05 10:39:00+03	139400.00
885ABA	2017-07-27 14:18:00+03	31400.00
885B41	2017-08-03 17:13:00+03	14000.00
885B4A	2017-08-01 18:49:00+03	16400.00
885BAA	2017-07-12 13:54:00+03	56000.00
885BB0	2017-08-04 20:41:00+03	22000.00
885BE4	2017-07-20 11:08:00+03	71600.00
885BF7	2017-08-07 05:15:00+03	42800.00
885C39	2017-08-12 01:50:00+03	12900.00
885C3A	2017-07-18 20:01:00+03	50600.00
885C3C	2017-06-29 11:23:00+03	167400.00
885C5C	2017-07-26 19:40:00+03	146700.00
885CB1	2017-07-11 10:16:00+03	68000.00
885CE8	2017-08-03 18:31:00+03	61800.00
885D1A	2017-08-02 03:30:00+03	46400.00
885D2E	2017-07-11 04:56:00+03	59300.00
885D5D	2017-08-03 01:15:00+03	58000.00
885E05	2017-07-05 06:02:00+03	112000.00
885E68	2017-08-11 07:22:00+03	61500.00
885F0D	2017-08-15 00:02:00+03	46500.00
885F43	2017-07-04 13:21:00+03	71000.00
885F52	2017-07-18 10:41:00+03	116100.00
885F63	2017-07-31 08:56:00+03	139300.00
88600C	2017-07-09 19:58:00+03	31900.00
886082	2017-08-07 03:50:00+03	77500.00
886162	2017-07-16 18:00:00+03	127400.00
886180	2017-07-24 23:04:00+03	68100.00
8861FA	2017-07-19 16:27:00+03	146700.00
886269	2017-07-29 22:40:00+03	56000.00
8862C5	2017-07-12 17:01:00+03	29600.00
886327	2017-08-04 00:11:00+03	61800.00
88637C	2017-08-02 12:30:00+03	44500.00
886383	2017-07-08 10:02:00+03	129700.00
886417	2017-08-13 04:44:00+03	7400.00
886452	2017-07-20 08:50:00+03	53800.00
88647C	2017-07-24 16:00:00+03	39700.00
88651B	2017-07-19 01:24:00+03	52300.00
886575	2017-08-14 06:39:00+03	25600.00
8865DB	2017-07-03 00:36:00+03	185600.00
8865E9	2017-07-31 23:29:00+03	28000.00
8865FF	2017-07-08 16:41:00+03	6700.00
886661	2017-07-15 16:11:00+03	28300.00
8866BE	2017-07-01 11:00:00+03	129400.00
88670B	2017-07-29 02:45:00+03	35200.00
88675E	2017-08-07 23:43:00+03	46700.00
886779	2017-07-09 18:04:00+03	64500.00
8867B1	2017-06-29 12:41:00+03	23900.00
88684C	2017-08-14 18:34:00+03	56000.00
8868B8	2017-07-26 11:35:00+03	62000.00
88690C	2017-07-06 02:49:00+03	21600.00
88691D	2017-07-04 18:40:00+03	54800.00
886946	2017-07-19 20:56:00+03	11000.00
886950	2017-07-31 00:13:00+03	44300.00
88696F	2017-07-03 11:45:00+03	93600.00
8869B9	2017-07-03 22:28:00+03	27000.00
8869BF	2017-07-25 21:04:00+03	86800.00
8869C6	2017-07-10 07:19:00+03	44800.00
8869CB	2017-07-25 07:21:00+03	23200.00
886A1D	2017-07-07 21:21:00+03	52800.00
886A7E	2017-07-03 06:41:00+03	80400.00
886A8A	2017-07-24 05:08:00+03	15700.00
886AD7	2017-08-09 05:29:00+03	99200.00
886B18	2017-08-14 13:28:00+03	27200.00
886B4B	2017-08-06 13:25:00+03	66000.00
886BA1	2017-07-26 06:31:00+03	189100.00
886C1F	2017-08-02 10:14:00+03	58000.00
886C68	2017-07-23 01:49:00+03	149300.00
886C74	2017-07-30 19:25:00+03	129700.00
886DAA	2017-08-08 02:29:00+03	40800.00
886E60	2017-08-04 00:54:00+03	16400.00
886E8F	2017-08-12 18:50:00+03	67800.00
886E93	2017-07-24 23:56:00+03	8000.00
886EB5	2017-07-27 14:52:00+03	15800.00
886F43	2017-08-03 21:30:00+03	96100.00
886FA2	2017-07-28 02:13:00+03	73900.00
887110	2017-07-05 22:49:00+03	246000.00
887191	2017-07-14 00:25:00+03	12400.00
887193	2017-07-04 17:45:00+03	122500.00
8871F8	2017-08-07 09:57:00+03	100600.00
887281	2017-07-30 20:10:00+03	10600.00
887296	2017-07-26 10:35:00+03	112000.00
88733C	2017-07-07 06:27:00+03	67400.00
887349	2017-08-11 03:05:00+03	75300.00
887431	2017-07-22 02:19:00+03	32800.00
88755D	2017-07-30 20:03:00+03	68000.00
887595	2017-08-10 04:08:00+03	23200.00
887611	2017-07-09 08:13:00+03	531400.00
887634	2017-08-04 13:52:00+03	62600.00
8876E3	2017-07-10 10:32:00+03	26000.00
887709	2017-07-04 03:53:00+03	40800.00
887725	2017-07-23 08:03:00+03	133200.00
887772	2017-08-01 23:26:00+03	70700.00
887797	2017-07-09 15:30:00+03	36800.00
887864	2017-07-19 15:12:00+03	73200.00
88789D	2017-07-19 22:32:00+03	123000.00
88795D	2017-08-02 06:14:00+03	68100.00
887986	2017-07-04 17:46:00+03	62800.00
887998	2017-07-01 08:04:00+03	56000.00
8879CC	2017-08-11 18:03:00+03	59800.00
8879DF	2017-07-28 05:03:00+03	126500.00
8879EB	2017-08-15 14:47:00+03	148200.00
887A15	2017-08-03 07:20:00+03	199700.00
887A5F	2017-07-15 20:26:00+03	71000.00
887A66	2017-07-22 17:52:00+03	81500.00
887AA9	2017-08-07 21:30:00+03	39800.00
887AC8	2017-08-12 20:53:00+03	200400.00
887AE4	2017-07-04 20:59:00+03	132800.00
887AFB	2017-07-02 16:17:00+03	67100.00
887B75	2017-07-22 05:06:00+03	28000.00
887B87	2017-07-16 07:52:00+03	65500.00
887BD7	2017-07-15 13:21:00+03	354200.00
887C2E	2017-07-01 22:58:00+03	23600.00
887C5A	2017-07-07 16:36:00+03	56000.00
887C88	2017-07-30 05:34:00+03	55800.00
887C99	2017-07-03 06:37:00+03	59600.00
887CA7	2017-08-04 14:10:00+03	78800.00
887CE6	2017-07-17 19:23:00+03	34000.00
887CF7	2017-07-05 19:38:00+03	63200.00
887DC9	2017-07-21 22:57:00+03	116800.00
887DF5	2017-07-18 17:02:00+03	74400.00
887EB0	2017-07-25 13:19:00+03	42900.00
887F1A	2017-07-01 20:31:00+03	75600.00
887F42	2017-08-06 09:02:00+03	45200.00
887F50	2017-07-27 18:47:00+03	45200.00
887F58	2017-08-11 05:22:00+03	54500.00
887F66	2017-06-29 12:09:00+03	32800.00
887F70	2017-08-09 01:20:00+03	75800.00
887F84	2017-07-01 12:05:00+03	27200.00
888058	2017-07-27 03:58:00+03	369000.00
888096	2017-07-26 12:25:00+03	6700.00
88814D	2017-07-08 08:46:00+03	237500.00
888226	2017-07-29 03:19:00+03	66800.00
88827E	2017-07-30 07:18:00+03	8000.00
88828D	2017-07-09 18:18:00+03	28800.00
8882A5	2017-08-04 02:53:00+03	55800.00
8882A7	2017-07-28 18:04:00+03	58800.00
8882DC	2017-08-15 08:09:00+03	67200.00
888301	2017-07-20 19:26:00+03	155600.00
888323	2017-08-15 10:13:00+03	88100.00
8883D3	2017-07-25 12:45:00+03	52000.00
88842A	2017-08-15 11:19:00+03	57100.00
888471	2017-07-04 01:07:00+03	25200.00
888622	2017-07-28 21:27:00+03	144400.00
888643	2017-07-28 06:45:00+03	19600.00
888665	2017-07-03 07:35:00+03	24200.00
8886B3	2017-07-21 00:43:00+03	124000.00
888718	2017-08-10 07:14:00+03	114300.00
888726	2017-07-05 05:52:00+03	26000.00
888730	2017-08-10 16:37:00+03	62600.00
888746	2017-08-10 13:07:00+03	23200.00
888769	2017-08-01 08:42:00+03	24300.00
888788	2017-07-07 17:36:00+03	48800.00
8887D3	2017-06-30 06:24:00+03	84200.00
888843	2017-07-08 13:26:00+03	131600.00
88885F	2017-08-06 00:04:00+03	88100.00
888879	2017-07-22 00:34:00+03	57600.00
8888B4	2017-08-10 09:39:00+03	58500.00
8888F6	2017-08-02 07:56:00+03	37300.00
888910	2017-08-03 20:46:00+03	53700.00
888951	2017-07-18 21:13:00+03	24400.00
888959	2017-07-19 23:04:00+03	100200.00
8889D1	2017-07-20 11:27:00+03	28000.00
888AB0	2017-07-26 09:00:00+03	81600.00
888AB5	2017-07-08 15:41:00+03	6000.00
888B22	2017-07-03 10:19:00+03	47200.00
888C61	2017-07-07 18:36:00+03	55800.00
888CA5	2017-07-24 14:04:00+03	30300.00
888CC7	2017-07-24 23:52:00+03	32800.00
888CF2	2017-08-10 10:15:00+03	420500.00
888CFE	2017-07-19 00:23:00+03	28000.00
888D17	2017-08-10 03:13:00+03	38800.00
888D67	2017-07-31 22:11:00+03	56600.00
888D6E	2017-07-19 06:21:00+03	7200.00
888E11	2017-07-25 06:03:00+03	32800.00
888E70	2017-08-01 15:34:00+03	31400.00
888EB9	2017-08-06 23:10:00+03	77900.00
888EFF	2017-07-19 18:06:00+03	139100.00
888F3E	2017-08-01 05:04:00+03	38700.00
888FA9	2017-07-17 21:33:00+03	131100.00
888FD1	2017-07-06 23:12:00+03	6700.00
889025	2017-07-11 06:21:00+03	95200.00
88902A	2017-08-15 09:26:00+03	137600.00
88903F	2017-07-02 20:34:00+03	95200.00
889085	2017-08-10 11:34:00+03	173300.00
8890B7	2017-07-20 18:04:00+03	12400.00
8890CF	2017-08-03 15:15:00+03	120700.00
889165	2017-07-31 23:31:00+03	13600.00
88916C	2017-08-01 01:17:00+03	12600.00
8891D6	2017-07-06 10:04:00+03	88300.00
8891DA	2017-08-07 01:53:00+03	13600.00
8891F3	2017-07-25 02:41:00+03	56600.00
88925C	2017-07-11 13:59:00+03	123000.00
88925F	2017-07-22 00:02:00+03	271100.00
88928B	2017-07-25 02:11:00+03	48700.00
889304	2017-07-26 19:11:00+03	246000.00
88932E	2017-08-03 18:22:00+03	29400.00
8893BA	2017-07-08 11:13:00+03	12600.00
889456	2017-07-26 04:22:00+03	19800.00
889467	2017-08-02 11:49:00+03	64200.00
8894FE	2017-08-04 18:55:00+03	30200.00
8894FF	2017-07-19 21:51:00+03	64500.00
88952A	2017-08-04 15:11:00+03	106400.00
8895E4	2017-07-09 13:06:00+03	56000.00
88968A	2017-08-06 01:43:00+03	59800.00
889750	2017-07-08 06:00:00+03	131100.00
889798	2017-07-19 16:59:00+03	13600.00
889822	2017-07-11 06:11:00+03	257500.00
889846	2017-07-04 20:54:00+03	71900.00
88986D	2017-08-08 23:55:00+03	406700.00
8898A3	2017-08-05 13:20:00+03	46400.00
8898AE	2017-08-09 11:50:00+03	117600.00
8898B1	2017-07-06 13:34:00+03	257500.00
889932	2017-07-24 23:52:00+03	43600.00
8899AF	2017-07-14 20:23:00+03	62100.00
8899E5	2017-07-02 12:38:00+03	73500.00
8899F9	2017-07-07 17:26:00+03	112000.00
8899FB	2017-07-10 01:50:00+03	118200.00
889A31	2017-07-22 14:00:00+03	67600.00
889A33	2017-08-11 17:02:00+03	12600.00
889A5D	2017-07-08 07:53:00+03	170800.00
889B51	2017-07-09 00:56:00+03	79600.00
889B5E	2017-07-04 08:07:00+03	55600.00
889B62	2017-06-30 16:12:00+03	42400.00
889BA5	2017-07-10 18:47:00+03	28800.00
889BA9	2017-07-26 05:49:00+03	219200.00
889C0A	2017-07-18 14:03:00+03	67100.00
889C19	2017-07-13 12:05:00+03	56100.00
889C2F	2017-08-06 06:04:00+03	94100.00
889C3F	2017-08-12 17:01:00+03	32200.00
889D0B	2017-07-05 06:37:00+03	65200.00
889D11	2017-07-31 00:19:00+03	86800.00
889D8B	2017-07-03 23:43:00+03	85600.00
889DDE	2017-07-25 10:20:00+03	28000.00
889F43	2017-06-27 14:27:00+03	25600.00
889F67	2017-08-05 22:45:00+03	12000.00
889F6D	2017-07-04 22:55:00+03	87600.00
889F77	2017-07-23 22:48:00+03	532600.00
889FD6	2017-07-11 21:39:00+03	66800.00
88A009	2017-08-09 22:53:00+03	21400.00
88A018	2017-07-26 03:40:00+03	26000.00
88A03C	2017-06-30 13:49:00+03	136200.00
88A0F6	2017-08-12 13:59:00+03	54800.00
88A11B	2017-08-04 18:38:00+03	66000.00
88A150	2017-08-04 19:23:00+03	8000.00
88A16F	2017-07-12 19:03:00+03	94900.00
88A1CC	2017-07-03 15:56:00+03	36200.00
88A1DB	2017-07-29 10:57:00+03	51900.00
88A1FF	2017-08-15 03:52:00+03	26000.00
88A211	2017-08-12 17:27:00+03	26700.00
88A222	2017-07-11 11:00:00+03	28000.00
88A254	2017-07-04 23:19:00+03	49100.00
88A27D	2017-08-03 08:11:00+03	134400.00
88A2B7	2017-07-24 00:32:00+03	32700.00
88A321	2017-07-24 05:26:00+03	64700.00
88A3E3	2017-07-23 00:38:00+03	54500.00
88A513	2017-07-11 19:54:00+03	43800.00
88A592	2017-07-08 11:17:00+03	8000.00
88A657	2017-08-11 04:04:00+03	35300.00
88A66D	2017-07-07 09:43:00+03	12000.00
88A6A8	2017-07-21 07:53:00+03	6000.00
88A726	2017-08-11 04:36:00+03	28800.00
88A746	2017-07-23 23:58:00+03	13700.00
88A760	2017-08-07 05:51:00+03	43600.00
88A821	2017-07-12 17:45:00+03	20100.00
88A827	2017-07-08 20:41:00+03	54000.00
88A86B	2017-08-09 19:22:00+03	95200.00
88A90C	2017-07-27 03:36:00+03	101200.00
88A910	2017-07-26 22:08:00+03	323900.00
88A917	2017-08-05 02:08:00+03	32200.00
88A9F1	2017-08-01 02:52:00+03	136200.00
88A9F6	2017-08-13 20:42:00+03	19100.00
88AA02	2017-07-08 15:06:00+03	23600.00
88AA05	2017-07-30 03:58:00+03	28000.00
88AA1E	2017-07-15 00:30:00+03	56100.00
88AA93	2017-07-19 13:49:00+03	444000.00
88AAE8	2017-07-07 19:37:00+03	25000.00
88AB14	2017-07-14 03:07:00+03	39300.00
88ABF0	2017-07-27 19:03:00+03	37900.00
88AC43	2017-07-08 23:42:00+03	201200.00
88ACBB	2017-08-06 03:23:00+03	198400.00
88AD18	2017-08-14 07:04:00+03	59800.00
88AD29	2017-08-07 04:17:00+03	182300.00
88AD81	2017-07-29 16:51:00+03	12000.00
88ADF5	2017-07-01 03:43:00+03	13800.00
88AE43	2017-07-26 13:51:00+03	472900.00
88AE8D	2017-08-11 06:37:00+03	159800.00
88AED5	2017-07-03 08:39:00+03	95300.00
88AF7D	2017-07-22 08:34:00+03	17600.00
88B00E	2017-07-28 20:17:00+03	39000.00
88B038	2017-07-27 04:40:00+03	35500.00
88B0B6	2017-08-15 12:30:00+03	43100.00
88B0DC	2017-08-03 11:16:00+03	38400.00
88B119	2017-07-10 15:23:00+03	135400.00
88B146	2017-08-11 09:30:00+03	23900.00
88B147	2017-08-05 00:25:00+03	335100.00
88B15F	2017-07-02 09:58:00+03	43500.00
88B1A5	2017-07-07 00:59:00+03	22000.00
88B1C1	2017-08-05 06:42:00+03	150600.00
88B1EB	2017-08-01 08:40:00+03	24400.00
88B1EC	2017-07-29 12:47:00+03	16800.00
88B283	2017-08-12 09:17:00+03	23400.00
88B2A6	2017-08-02 16:28:00+03	207200.00
88B2BD	2017-07-07 03:51:00+03	90400.00
88B2DE	2017-08-05 03:48:00+03	32200.00
88B2E6	2017-07-04 02:47:00+03	36200.00
88B319	2017-07-08 12:03:00+03	170700.00
88B33E	2017-07-17 21:11:00+03	294200.00
88B4A3	2017-08-08 10:03:00+03	67600.00
88B4BE	2017-07-27 23:15:00+03	6000.00
88B4CF	2017-08-08 01:27:00+03	23800.00
88B4F4	2017-07-25 13:48:00+03	25800.00
88B53A	2017-07-27 10:22:00+03	8600.00
88B567	2017-07-12 18:31:00+03	12200.00
88B56B	2017-07-07 19:18:00+03	66000.00
88B582	2017-07-01 02:03:00+03	138900.00
88B58A	2017-06-30 20:21:00+03	69500.00
88B5A3	2017-08-10 07:23:00+03	182000.00
88B5E6	2017-07-07 18:45:00+03	56000.00
88B63E	2017-08-14 13:35:00+03	98400.00
88B649	2017-07-14 16:39:00+03	28800.00
88B6DB	2017-07-26 06:53:00+03	27200.00
88B6E5	2017-07-26 16:14:00+03	91900.00
88B6F8	2017-07-06 13:16:00+03	26000.00
88B713	2017-07-19 15:44:00+03	89600.00
88B715	2017-07-23 00:17:00+03	117600.00
88B852	2017-07-29 13:00:00+03	479000.00
88B854	2017-07-18 09:00:00+03	70400.00
88B8CB	2017-08-01 23:13:00+03	40400.00
88B8E0	2017-07-20 09:43:00+03	24400.00
88B963	2017-07-26 07:51:00+03	18800.00
88B964	2017-07-23 17:42:00+03	26000.00
88B981	2017-08-10 09:24:00+03	31400.00
88BA01	2017-07-21 11:12:00+03	94300.00
88BA1F	2017-07-10 23:08:00+03	23200.00
88BA20	2017-07-03 07:43:00+03	26400.00
88BA53	2017-08-14 09:52:00+03	10600.00
88BAEB	2017-07-14 00:22:00+03	44600.00
88BAF3	2017-07-11 09:09:00+03	133100.00
88BB6B	2017-07-03 07:09:00+03	113600.00
88BBA2	2017-07-04 11:56:00+03	119600.00
88BC00	2017-07-06 09:37:00+03	65900.00
88BC02	2017-07-31 06:51:00+03	84100.00
88BC3F	2017-06-27 03:14:00+03	56000.00
88BC73	2017-07-24 21:08:00+03	46400.00
88BCE3	2017-07-05 02:09:00+03	8200.00
88BCF2	2017-07-25 16:30:00+03	87100.00
88BD80	2017-07-05 06:24:00+03	58000.00
88BDFB	2017-07-15 12:20:00+03	40000.00
88BE09	2017-07-31 11:14:00+03	43700.00
88BE35	2017-07-04 22:44:00+03	21800.00
88BE44	2017-08-12 01:52:00+03	135600.00
88BE4F	2017-07-20 23:52:00+03	266400.00
88BEF3	2017-07-23 19:44:00+03	322100.00
88BF20	2017-07-31 11:38:00+03	60400.00
88BF87	2017-07-08 18:51:00+03	46000.00
88BFA0	2017-07-19 06:53:00+03	36000.00
88BFFB	2017-07-31 19:19:00+03	27300.00
88C121	2017-08-05 15:00:00+03	62800.00
88C1A7	2017-07-17 18:13:00+03	67600.00
88C1BC	2017-07-21 12:43:00+03	30800.00
88C20F	2017-07-23 19:40:00+03	119500.00
88C22C	2017-07-12 14:08:00+03	264000.00
88C256	2017-08-11 15:16:00+03	99300.00
88C277	2017-07-22 03:38:00+03	56000.00
88C283	2017-07-18 00:14:00+03	38800.00
88C31F	2017-07-24 19:24:00+03	40000.00
88C367	2017-08-08 08:32:00+03	75600.00
88C46C	2017-08-11 14:50:00+03	113200.00
88C476	2017-08-06 18:54:00+03	17000.00
88C494	2017-08-12 05:12:00+03	28800.00
88C5FD	2017-07-26 23:03:00+03	28300.00
88C617	2017-07-14 09:26:00+03	88400.00
88C666	2017-07-29 14:21:00+03	53200.00
88C69A	2017-08-13 14:57:00+03	55400.00
88C6D9	2017-06-27 12:26:00+03	41400.00
88C6E9	2017-07-10 18:08:00+03	56600.00
88C6EA	2017-08-09 17:10:00+03	59200.00
88C72D	2017-07-15 05:28:00+03	32800.00
88C7EA	2017-08-01 19:44:00+03	32800.00
88C832	2017-07-13 04:26:00+03	141500.00
88C849	2017-07-27 19:43:00+03	65500.00
88C84A	2017-07-06 21:10:00+03	29400.00
88C874	2017-07-03 06:05:00+03	123000.00
88C87C	2017-07-19 19:49:00+03	40400.00
88C87F	2017-08-04 08:57:00+03	22600.00
88C8A3	2017-08-09 08:06:00+03	36900.00
88C8AD	2017-07-29 12:33:00+03	114700.00
88C8FB	2017-07-08 23:24:00+03	235400.00
88C976	2017-08-13 21:35:00+03	56300.00
88C98D	2017-07-02 07:45:00+03	61200.00
88CA29	2017-08-15 07:57:00+03	179300.00
88CA2A	2017-07-19 01:11:00+03	44000.00
88CA76	2017-08-08 12:47:00+03	29200.00
88CAE5	2017-07-01 06:37:00+03	147800.00
88CAF9	2017-07-14 14:53:00+03	10800.00
88CB00	2017-07-25 09:16:00+03	258400.00
88CB3C	2017-07-18 05:43:00+03	28000.00
88CB3F	2017-07-02 00:04:00+03	168300.00
88CB60	2017-07-09 22:32:00+03	135100.00
88CBA1	2017-07-17 08:27:00+03	193600.00
88CBD9	2017-07-31 02:49:00+03	70600.00
88CBE7	2017-07-31 20:07:00+03	27900.00
88CC0C	2017-07-23 13:48:00+03	35700.00
88CC21	2017-07-27 00:11:00+03	12000.00
88CC56	2017-08-03 01:42:00+03	72200.00
88CCA9	2017-07-05 05:51:00+03	28000.00
88CD4E	2017-07-02 08:25:00+03	6300.00
88CD67	2017-07-24 22:07:00+03	15000.00
88CDE6	2017-08-05 00:31:00+03	75600.00
88CE14	2017-08-05 11:16:00+03	22000.00
88CE21	2017-08-10 03:59:00+03	135400.00
88CE29	2017-07-06 17:53:00+03	43800.00
88CE4C	2017-08-15 01:43:00+03	53000.00
88CE51	2017-08-01 04:51:00+03	135200.00
88CE6D	2017-06-30 17:42:00+03	124200.00
88CE6F	2017-07-15 16:43:00+03	62600.00
88CE8D	2017-07-11 23:16:00+03	84100.00
88CEA0	2017-07-05 01:42:00+03	25200.00
88CF17	2017-08-08 15:41:00+03	30400.00
88CF49	2017-08-14 11:09:00+03	66600.00
88CF9C	2017-08-09 22:46:00+03	63700.00
88CFD9	2017-08-13 01:03:00+03	67600.00
88D02D	2017-08-05 19:51:00+03	100000.00
88D03B	2017-07-12 03:16:00+03	171100.00
88D0B3	2017-07-04 08:29:00+03	182500.00
88D10E	2017-08-15 06:51:00+03	21800.00
88D136	2017-07-11 09:20:00+03	48500.00
88D192	2017-06-30 08:28:00+03	42300.00
88D1B2	2017-08-04 09:34:00+03	50000.00
88D1EA	2017-07-05 21:03:00+03	65200.00
88D1EB	2017-07-31 18:45:00+03	64800.00
88D265	2017-07-31 01:59:00+03	92700.00
88D282	2017-08-01 04:12:00+03	56000.00
88D315	2017-08-04 13:29:00+03	28000.00
88D39A	2017-08-10 00:57:00+03	26800.00
88D425	2017-07-11 13:00:00+03	56100.00
88D454	2017-08-05 07:45:00+03	10700.00
88D463	2017-08-09 20:12:00+03	76800.00
88D4B9	2017-08-14 17:58:00+03	8400.00
88D51A	2017-07-03 23:27:00+03	246000.00
88D57C	2017-07-27 06:24:00+03	51900.00
88D5DA	2017-07-02 18:51:00+03	20000.00
88D605	2017-08-05 23:37:00+03	133200.00
88D61F	2017-08-10 13:18:00+03	40800.00
88D67D	2017-07-27 08:50:00+03	46400.00
88D685	2017-07-18 08:46:00+03	13400.00
88D6BB	2017-07-23 05:10:00+03	44400.00
88D6E8	2017-07-16 05:59:00+03	73200.00
88D72D	2017-08-13 08:42:00+03	65900.00
88D74D	2017-07-01 04:30:00+03	67700.00
88D7E1	2017-08-08 18:39:00+03	266400.00
88D839	2017-07-13 10:00:00+03	73300.00
88D847	2017-07-29 11:46:00+03	36200.00
88D8CB	2017-07-02 22:33:00+03	46300.00
88D99F	2017-07-28 15:50:00+03	52000.00
88D9FD	2017-07-16 13:13:00+03	128000.00
88DA3B	2017-07-26 05:59:00+03	80300.00
88DA69	2017-07-23 03:31:00+03	111600.00
88DAB2	2017-08-13 06:45:00+03	22000.00
88DABD	2017-07-03 10:51:00+03	6000.00
88DAE0	2017-07-13 01:06:00+03	84800.00
88DAEC	2017-08-08 20:29:00+03	258400.00
88DB9C	2017-07-03 20:57:00+03	124200.00
88DBB1	2017-07-19 04:22:00+03	185600.00
88DBB6	2017-07-08 12:00:00+03	59100.00
88DBB9	2017-08-07 13:00:00+03	117200.00
88DC72	2017-07-13 06:54:00+03	48800.00
88DC75	2017-07-01 00:54:00+03	136200.00
88DCD3	2017-08-04 22:22:00+03	26800.00
88DD24	2017-07-28 06:32:00+03	139300.00
88DD82	2017-08-02 06:58:00+03	75300.00
88DDAF	2017-07-25 23:57:00+03	78800.00
88DDBA	2017-08-04 10:02:00+03	65600.00
88DE13	2017-07-29 21:41:00+03	42600.00
88DE1F	2017-08-12 09:02:00+03	260300.00
88DE8B	2017-07-14 21:08:00+03	271200.00
88DEC8	2017-06-30 12:05:00+03	6000.00
88DEEB	2017-07-29 07:55:00+03	46400.00
88DF9E	2017-07-21 22:59:00+03	46300.00
88DFD8	2017-06-29 20:02:00+03	68800.00
88DFF8	2017-07-05 05:05:00+03	24400.00
88E021	2017-07-15 17:16:00+03	85000.00
88E038	2017-08-14 03:15:00+03	13600.00
88E070	2017-07-12 00:20:00+03	153300.00
88E09C	2017-08-10 22:22:00+03	36200.00
88E104	2017-08-10 04:49:00+03	67600.00
88E177	2017-08-10 13:55:00+03	46300.00
88E1A1	2017-07-23 02:29:00+03	61500.00
88E213	2017-08-02 01:37:00+03	215600.00
88E217	2017-07-30 11:17:00+03	13600.00
88E21A	2017-08-06 18:20:00+03	48000.00
88E230	2017-07-20 06:09:00+03	30200.00
88E257	2017-07-15 18:04:00+03	38800.00
88E269	2017-08-06 16:38:00+03	229900.00
88E2A7	2017-07-29 00:41:00+03	17600.00
88E2C0	2017-07-09 09:59:00+03	99200.00
88E317	2017-08-14 13:29:00+03	103600.00
88E409	2017-07-18 08:34:00+03	61200.00
88E46F	2017-07-04 06:39:00+03	46500.00
88E48F	2017-08-01 23:25:00+03	12600.00
88E49D	2017-07-31 18:30:00+03	57500.00
88E4E5	2017-07-25 23:32:00+03	16400.00
88E4FE	2017-07-12 18:24:00+03	128800.00
88E536	2017-07-31 15:54:00+03	173900.00
88E5BE	2017-07-21 20:10:00+03	57800.00
88E601	2017-07-13 23:14:00+03	10800.00
88E627	2017-08-10 21:35:00+03	65900.00
88E63D	2017-07-27 06:18:00+03	28000.00
88E661	2017-08-08 00:38:00+03	51900.00
88E668	2017-07-02 09:52:00+03	199800.00
88E6CA	2017-08-13 22:05:00+03	89700.00
88E6F8	2017-07-25 13:36:00+03	3700.00
88E775	2017-07-02 06:19:00+03	31200.00
88E86B	2017-07-20 21:05:00+03	60800.00
88E87A	2017-08-10 21:33:00+03	14400.00
88E88B	2017-07-19 10:10:00+03	61900.00
88E8F0	2017-08-03 12:30:00+03	26800.00
88E9B3	2017-08-13 03:21:00+03	271100.00
88E9B4	2017-07-04 05:37:00+03	86800.00
88EA33	2017-07-19 05:05:00+03	78600.00
88EA7C	2017-07-01 19:58:00+03	39300.00
88EAFF	2017-07-27 02:08:00+03	50800.00
88EB02	2017-08-08 14:19:00+03	147600.00
88EB10	2017-07-05 12:57:00+03	51200.00
88EBE4	2017-08-05 03:05:00+03	25400.00
88EBF9	2017-07-07 23:57:00+03	135400.00
88EC03	2017-07-22 20:34:00+03	67500.00
88EC8F	2017-08-03 20:57:00+03	99200.00
88ECC6	2017-08-02 09:18:00+03	84500.00
88ED8E	2017-07-15 04:37:00+03	23200.00
88EE78	2017-07-21 18:16:00+03	112000.00
88EEB3	2017-07-25 04:05:00+03	168000.00
88F00A	2017-07-05 09:40:00+03	59000.00
88F013	2017-07-18 20:04:00+03	26500.00
88F01A	2017-08-07 01:01:00+03	99700.00
88F01B	2017-07-20 20:23:00+03	101200.00
88F034	2017-07-08 08:18:00+03	23200.00
88F047	2017-07-26 14:03:00+03	55800.00
88F050	2017-08-03 14:05:00+03	225200.00
88F072	2017-07-04 10:47:00+03	43900.00
88F07A	2017-08-07 09:42:00+03	55800.00
88F090	2017-08-02 20:22:00+03	119500.00
88F0B2	2017-07-26 20:35:00+03	6700.00
88F0BD	2017-07-28 18:48:00+03	147200.00
88F0C2	2017-07-24 15:45:00+03	66600.00
88F142	2017-08-15 15:04:00+03	34400.00
88F14E	2017-07-14 07:14:00+03	28000.00
88F1ED	2017-08-13 05:49:00+03	65500.00
88F1F0	2017-07-06 04:45:00+03	95200.00
88F1F7	2017-07-17 17:18:00+03	11700.00
88F205	2017-06-28 08:01:00+03	114800.00
88F29A	2017-07-11 15:20:00+03	10800.00
88F2C8	2017-08-14 20:55:00+03	19300.00
88F2EA	2017-07-17 08:24:00+03	15000.00
88F3D8	2017-07-10 23:07:00+03	14400.00
88F4AB	2017-07-21 02:20:00+03	53700.00
88F4AC	2017-07-26 08:52:00+03	93700.00
88F503	2017-07-19 23:08:00+03	32700.00
88F519	2017-08-13 20:50:00+03	23600.00
88F544	2017-07-07 19:08:00+03	66600.00
88F56C	2017-07-01 15:21:00+03	45400.00
88F582	2017-08-11 02:04:00+03	92800.00
88F5AA	2017-08-04 14:57:00+03	59400.00
88F66F	2017-07-28 12:03:00+03	67600.00
88F696	2017-07-19 23:12:00+03	228900.00
88F6C2	2017-08-13 08:15:00+03	51300.00
88F6DD	2017-07-12 12:38:00+03	68400.00
88F755	2017-08-11 06:58:00+03	23400.00
88F79A	2017-08-02 19:43:00+03	94000.00
88F7AD	2017-07-28 04:05:00+03	133100.00
88F7C2	2017-08-01 16:14:00+03	393800.00
88F840	2017-07-09 11:24:00+03	84000.00
88F86E	2017-08-10 09:04:00+03	10100.00
88F8EF	2017-07-04 15:59:00+03	303100.00
88F8F6	2017-08-12 07:40:00+03	31900.00
88F9BE	2017-07-17 09:03:00+03	23600.00
88F9C6	2017-08-08 00:20:00+03	135400.00
88FA07	2017-07-02 05:21:00+03	40800.00
88FB76	2017-07-09 17:22:00+03	65500.00
88FB88	2017-07-03 19:54:00+03	77900.00
88FC28	2017-08-08 08:20:00+03	38600.00
88FC45	2017-07-26 09:49:00+03	36200.00
88FC4C	2017-08-11 04:30:00+03	136100.00
88FC68	2017-08-10 23:47:00+03	115900.00
88FC8B	2017-07-10 06:32:00+03	506500.00
88FD0C	2017-08-15 12:49:00+03	55800.00
88FD9C	2017-08-07 11:40:00+03	28800.00
88FD9D	2017-07-22 12:30:00+03	56900.00
88FDB0	2017-08-13 16:45:00+03	131100.00
88FE95	2017-07-30 12:01:00+03	187800.00
88FEC2	2017-07-18 14:05:00+03	179400.00
88FF8E	2017-08-13 11:45:00+03	403900.00
88FFA0	2017-07-21 02:53:00+03	51000.00
8900A3	2017-07-06 10:22:00+03	53500.00
89011B	2017-07-19 14:54:00+03	29600.00
890177	2017-07-06 19:11:00+03	38400.00
8901A1	2017-08-11 04:35:00+03	21800.00
8901A7	2017-07-28 09:03:00+03	131100.00
8901BA	2017-07-14 13:00:00+03	178800.00
890221	2017-07-31 06:03:00+03	532700.00
890254	2017-07-11 01:24:00+03	51200.00
89028C	2017-08-05 23:01:00+03	76400.00
8902C8	2017-07-18 18:55:00+03	85000.00
89034F	2017-07-29 17:03:00+03	80400.00
890363	2017-08-04 13:25:00+03	179900.00
890369	2017-07-13 05:22:00+03	61800.00
890378	2017-07-18 17:28:00+03	23200.00
8903D0	2017-08-09 00:30:00+03	38600.00
8903D9	2017-07-04 10:42:00+03	133700.00
890476	2017-07-28 00:33:00+03	72000.00
890487	2017-07-14 13:20:00+03	136800.00
890489	2017-07-24 09:00:00+03	29300.00
8904B6	2017-07-08 14:32:00+03	20200.00
8904E0	2017-07-15 14:43:00+03	167400.00
890507	2017-07-24 14:16:00+03	24400.00
89052A	2017-07-09 08:56:00+03	165800.00
89056E	2017-07-03 08:21:00+03	26800.00
8905A4	2017-08-08 13:36:00+03	130000.00
89060D	2017-07-29 19:59:00+03	39800.00
8906B1	2017-08-05 22:02:00+03	20100.00
890741	2017-08-11 08:17:00+03	89200.00
890750	2017-08-02 17:43:00+03	12400.00
890774	2017-07-29 13:32:00+03	67300.00
890790	2017-08-13 07:01:00+03	42000.00
8907C0	2017-07-20 02:12:00+03	114300.00
890859	2017-06-27 07:53:00+03	65300.00
8908BB	2017-07-27 04:12:00+03	98000.00
89090E	2017-07-10 11:37:00+03	100600.00
890928	2017-08-12 06:00:00+03	57300.00
890954	2017-08-01 11:30:00+03	137600.00
89096A	2017-07-21 22:43:00+03	101200.00
8909AA	2017-07-24 10:23:00+03	22000.00
8909F0	2017-08-11 10:55:00+03	52700.00
890A35	2017-06-30 02:32:00+03	28800.00
890A47	2017-07-06 17:40:00+03	123000.00
890A48	2017-07-08 12:08:00+03	30700.00
890A89	2017-06-28 20:15:00+03	24400.00
890A9C	2017-07-25 06:04:00+03	112200.00
890AB8	2017-07-30 04:15:00+03	266200.00
890B05	2017-08-14 06:04:00+03	16400.00
890B43	2017-07-05 12:54:00+03	12600.00
890BAC	2017-07-09 15:40:00+03	25200.00
890BCE	2017-07-23 08:59:00+03	83900.00
890BD1	2017-07-31 20:40:00+03	139100.00
890C3F	2017-08-08 12:17:00+03	123000.00
890C5E	2017-07-29 00:38:00+03	23400.00
890C72	2017-08-02 10:41:00+03	70400.00
890C76	2017-08-15 17:38:00+03	29600.00
890CD9	2017-07-17 01:18:00+03	378400.00
890CF7	2017-07-25 03:14:00+03	111600.00
890CFF	2017-08-12 04:26:00+03	240600.00
890D36	2017-07-27 10:15:00+03	21200.00
890D39	2017-07-03 06:09:00+03	48800.00
890D3B	2017-07-20 02:26:00+03	60400.00
890D6D	2017-07-07 01:03:00+03	113100.00
890DDE	2017-07-27 01:27:00+03	37800.00
890E19	2017-07-16 12:53:00+03	37200.00
890E23	2017-07-24 13:38:00+03	65900.00
890E4E	2017-07-28 21:43:00+03	26000.00
890E64	2017-07-18 00:22:00+03	13000.00
890ED5	2017-08-12 23:24:00+03	152900.00
89108B	2017-08-04 12:09:00+03	169900.00
8910C8	2017-08-04 13:11:00+03	50600.00
8910EF	2017-07-01 18:50:00+03	16400.00
89111F	2017-07-29 06:03:00+03	36200.00
891190	2017-07-18 00:52:00+03	148200.00
891212	2017-08-14 12:16:00+03	96800.00
891233	2017-08-08 05:48:00+03	59200.00
891299	2017-07-23 22:28:00+03	393800.00
8912A8	2017-07-07 06:50:00+03	133900.00
8912AE	2017-08-05 14:40:00+03	67600.00
8912E3	2017-08-12 12:26:00+03	99100.00
891303	2017-07-31 05:11:00+03	75600.00
891319	2017-08-06 12:42:00+03	28800.00
89132B	2017-07-18 20:17:00+03	14800.00
891338	2017-07-27 08:58:00+03	39800.00
891379	2017-07-08 08:32:00+03	47500.00
89138E	2017-08-10 02:39:00+03	53100.00
89139F	2017-07-06 13:34:00+03	10800.00
8913C1	2017-08-11 19:45:00+03	52800.00
8913DA	2017-07-27 22:15:00+03	67600.00
891423	2017-07-19 21:10:00+03	40100.00
891449	2017-07-21 06:24:00+03	62600.00
891450	2017-08-10 11:48:00+03	13400.00
891475	2017-07-18 06:38:00+03	81300.00
891491	2017-07-02 11:38:00+03	37900.00
89149C	2017-08-05 00:56:00+03	14000.00
8914A3	2017-08-14 17:18:00+03	28800.00
8914BA	2017-07-11 12:31:00+03	31400.00
89153A	2017-08-15 06:52:00+03	48100.00
8915DB	2017-08-14 00:42:00+03	54400.00
8915ED	2017-07-12 11:50:00+03	97900.00
89166D	2017-07-27 21:52:00+03	36200.00
8916FF	2017-07-18 19:15:00+03	23600.00
891715	2017-08-09 06:55:00+03	14800.00
891736	2017-07-19 19:40:00+03	11800.00
89175C	2017-07-29 00:48:00+03	46800.00
8917BF	2017-08-05 14:24:00+03	125000.00
891804	2017-07-30 15:57:00+03	73200.00
891893	2017-08-04 19:59:00+03	91500.00
891952	2017-08-04 00:33:00+03	15000.00
891982	2017-08-10 04:45:00+03	43100.00
891A06	2017-07-30 04:49:00+03	28000.00
891A2F	2017-08-02 23:50:00+03	60800.00
891A7B	2017-08-05 06:33:00+03	85000.00
891ACE	2017-07-05 15:39:00+03	260300.00
891B73	2017-08-01 01:00:00+03	22400.00
891BBB	2017-07-21 11:13:00+03	26600.00
891C44	2017-07-12 01:19:00+03	43200.00
891C51	2017-07-10 08:12:00+03	93900.00
891C52	2017-07-21 16:27:00+03	40800.00
891C8A	2017-07-11 16:27:00+03	24300.00
891CCF	2017-07-01 21:29:00+03	15000.00
891E0D	2017-06-30 21:46:00+03	119500.00
891E72	2017-08-02 19:40:00+03	58800.00
891E91	2017-07-24 10:11:00+03	50800.00
891ED8	2017-07-28 21:51:00+03	34400.00
891EE3	2017-07-16 20:09:00+03	56000.00
891F4F	2017-08-04 13:24:00+03	26200.00
891FB7	2017-07-17 18:27:00+03	21400.00
892061	2017-07-23 21:11:00+03	7200.00
89207E	2017-07-27 15:39:00+03	122500.00
892088	2017-07-08 03:59:00+03	146300.00
892091	2017-07-16 08:35:00+03	92400.00
8920C3	2017-07-21 06:22:00+03	75600.00
892117	2017-07-16 23:53:00+03	44800.00
8921B4	2017-07-07 12:26:00+03	121400.00
8921EB	2017-08-06 21:51:00+03	13000.00
8922AF	2017-07-06 02:37:00+03	25600.00
8922BA	2017-08-09 22:56:00+03	144400.00
8922E1	2017-08-13 16:42:00+03	47000.00
8922EC	2017-08-02 17:09:00+03	59000.00
892321	2017-07-14 20:16:00+03	84400.00
892369	2017-08-04 20:20:00+03	8200.00
89237D	2017-07-03 08:09:00+03	77200.00
8923B2	2017-07-15 13:02:00+03	136500.00
8923E8	2017-07-17 05:43:00+03	23400.00
892463	2017-07-15 01:40:00+03	55800.00
8924AE	2017-07-22 22:40:00+03	66000.00
8924E0	2017-08-06 22:24:00+03	193500.00
8924E9	2017-07-02 13:42:00+03	168000.00
89250A	2017-07-20 07:10:00+03	40800.00
892510	2017-07-09 17:23:00+03	102100.00
892511	2017-08-11 01:39:00+03	18600.00
89257B	2017-07-13 23:58:00+03	62900.00
8925A2	2017-07-03 12:16:00+03	45200.00
8926A3	2017-07-31 17:15:00+03	36900.00
8926BE	2017-07-31 21:02:00+03	89700.00
892766	2017-07-05 05:15:00+03	82900.00
892793	2017-07-23 14:38:00+03	171100.00
89281B	2017-07-06 03:02:00+03	13800.00
892841	2017-07-07 22:11:00+03	8200.00
892855	2017-07-15 11:18:00+03	59800.00
8928A3	2017-07-16 18:25:00+03	108000.00
8928BE	2017-07-11 07:27:00+03	67800.00
892972	2017-07-03 16:40:00+03	37900.00
892986	2017-08-11 22:54:00+03	100600.00
8929E6	2017-08-07 01:41:00+03	10600.00
8929FB	2017-07-28 21:51:00+03	131100.00
892A49	2017-07-30 04:34:00+03	68400.00
892AE5	2017-08-06 22:40:00+03	43200.00
892B5D	2017-07-25 12:33:00+03	20200.00
892B84	2017-07-02 03:54:00+03	116400.00
892B8F	2017-08-01 07:09:00+03	156600.00
892C0A	2017-07-31 05:07:00+03	27200.00
892C65	2017-08-12 08:42:00+03	46200.00
892D40	2017-07-11 00:59:00+03	92800.00
892D60	2017-07-10 09:58:00+03	272800.00
892DBB	2017-08-07 02:30:00+03	91500.00
892DD8	2017-07-09 21:51:00+03	37200.00
892E04	2017-08-06 06:45:00+03	96300.00
892E05	2017-06-29 05:10:00+03	36200.00
892E18	2017-07-04 08:26:00+03	92700.00
892E2D	2017-08-05 15:54:00+03	135400.00
892E4E	2017-07-12 12:54:00+03	11900.00
892E8A	2017-08-08 04:41:00+03	184300.00
892EB2	2017-07-10 07:16:00+03	135600.00
892EBD	2017-08-12 04:15:00+03	44000.00
892F22	2017-07-06 10:02:00+03	6600.00
892F25	2017-07-27 18:11:00+03	27200.00
892F48	2017-08-06 17:26:00+03	39800.00
892FCB	2017-08-14 18:16:00+03	116800.00
89302B	2017-07-19 09:49:00+03	133100.00
89302E	2017-06-30 20:18:00+03	24700.00
8930F4	2017-08-13 08:06:00+03	77000.00
89310C	2017-07-11 09:56:00+03	70100.00
893112	2017-07-12 06:47:00+03	42700.00
893185	2017-07-15 23:44:00+03	34000.00
8931E1	2017-07-25 07:33:00+03	24400.00
893291	2017-06-30 04:55:00+03	56000.00
89331C	2017-08-13 08:54:00+03	23200.00
893357	2017-07-02 16:26:00+03	8200.00
89338F	2017-08-02 07:36:00+03	59600.00
8933BA	2017-08-04 13:48:00+03	138300.00
89343E	2017-07-20 20:44:00+03	66600.00
89345B	2017-07-18 03:10:00+03	126500.00
8934B1	2017-07-02 15:43:00+03	97500.00
8934BA	2017-08-09 07:43:00+03	404600.00
893528	2017-07-04 07:13:00+03	38600.00
89353D	2017-07-08 10:04:00+03	37500.00
8935A2	2017-08-11 08:00:00+03	40000.00
8935AB	2017-07-03 02:49:00+03	123000.00
8935AD	2017-07-29 02:36:00+03	58000.00
893606	2017-07-25 00:04:00+03	129600.00
893612	2017-07-02 01:13:00+03	39000.00
89361C	2017-07-28 09:43:00+03	34400.00
89365F	2017-07-19 10:01:00+03	59000.00
8936A2	2017-08-07 19:22:00+03	46000.00
8936C9	2017-08-13 18:39:00+03	23600.00
893726	2017-08-02 16:49:00+03	65900.00
89373D	2017-07-15 09:45:00+03	330200.00
893815	2017-08-06 07:28:00+03	23600.00
89386B	2017-07-25 19:48:00+03	28800.00
893890	2017-08-03 21:32:00+03	24400.00
8938D7	2017-08-03 09:31:00+03	33300.00
8938E0	2017-08-06 20:31:00+03	11700.00
8938F4	2017-06-30 22:49:00+03	25600.00
893912	2017-08-01 00:56:00+03	173500.00
89393A	2017-08-03 11:14:00+03	36100.00
89395E	2017-08-12 00:57:00+03	33100.00
893997	2017-08-09 16:32:00+03	32800.00
8939BF	2017-08-15 06:43:00+03	53200.00
893A7E	2017-07-10 06:00:00+03	55800.00
893ABE	2017-07-29 19:11:00+03	25800.00
893AE5	2017-07-31 08:38:00+03	81600.00
893AE7	2017-08-14 07:21:00+03	28800.00
893B47	2017-07-15 00:01:00+03	121600.00
893B8D	2017-07-16 10:57:00+03	137400.00
893BC7	2017-07-15 13:08:00+03	186400.00
893BD9	2017-06-26 04:26:00+03	13600.00
893C1C	2017-07-21 16:05:00+03	162400.00
893C76	2017-07-09 13:10:00+03	56000.00
893C8C	2017-08-11 15:34:00+03	38500.00
893CEE	2017-07-29 11:09:00+03	94800.00
893CFE	2017-08-06 13:48:00+03	17800.00
893D60	2017-07-19 05:58:00+03	83400.00
893DDE	2017-07-04 20:29:00+03	44000.00
893DFB	2017-08-05 05:29:00+03	23200.00
893E1E	2017-08-13 03:51:00+03	139400.00
893EC5	2017-07-12 03:42:00+03	292900.00
893ECD	2017-08-10 03:11:00+03	57500.00
893EF6	2017-07-11 06:12:00+03	167400.00
893F2C	2017-07-06 07:33:00+03	147000.00
893F6F	2017-07-28 13:10:00+03	99200.00
893F81	2017-08-06 12:03:00+03	39200.00
893F90	2017-07-02 08:16:00+03	43200.00
893FAD	2017-08-10 00:10:00+03	91300.00
893FBD	2017-07-24 10:45:00+03	14300.00
89404D	2017-07-14 11:40:00+03	50800.00
89405B	2017-06-30 12:11:00+03	58900.00
894072	2017-07-06 07:25:00+03	33100.00
894086	2017-07-16 16:55:00+03	23200.00
8940B2	2017-08-03 08:09:00+03	49200.00
8940B3	2017-07-16 01:13:00+03	57800.00
8940F5	2017-08-07 11:52:00+03	60700.00
894142	2017-08-01 06:56:00+03	40800.00
894182	2017-06-26 22:38:00+03	58900.00
8941A1	2017-07-26 10:24:00+03	133100.00
8941AB	2017-08-13 12:10:00+03	99700.00
894225	2017-08-12 21:16:00+03	47200.00
894294	2017-07-28 17:49:00+03	22000.00
89429F	2017-07-09 00:06:00+03	28000.00
8942F6	2017-07-29 00:59:00+03	106600.00
894305	2017-07-04 14:58:00+03	114800.00
894348	2017-08-04 08:50:00+03	33200.00
89437D	2017-06-28 22:52:00+03	94700.00
8943A2	2017-07-17 15:26:00+03	240600.00
8943C1	2017-07-27 02:06:00+03	265600.00
894469	2017-07-26 23:41:00+03	27200.00
8944A3	2017-08-04 12:36:00+03	65000.00
894500	2017-07-30 15:12:00+03	28000.00
894536	2017-08-14 01:29:00+03	43500.00
89454E	2017-08-05 22:15:00+03	26000.00
89458D	2017-08-10 15:41:00+03	170200.00
8945E8	2017-07-27 23:19:00+03	67600.00
894670	2017-08-12 16:55:00+03	46400.00
894723	2017-07-15 16:37:00+03	65900.00
89479E	2017-08-14 09:17:00+03	23100.00
8947F7	2017-08-13 12:02:00+03	67600.00
894914	2017-08-06 02:52:00+03	174200.00
894939	2017-07-25 12:34:00+03	14000.00
894969	2017-08-02 21:29:00+03	46400.00
8949D0	2017-07-27 21:05:00+03	44700.00
894A14	2017-06-30 02:54:00+03	115600.00
894A18	2017-08-01 09:57:00+03	90800.00
894A2C	2017-07-07 23:52:00+03	20400.00
894AA3	2017-07-19 23:35:00+03	24200.00
894AA6	2017-08-03 23:07:00+03	182700.00
894B08	2017-07-31 20:41:00+03	112000.00
894B31	2017-08-08 19:32:00+03	32800.00
894BA3	2017-07-05 21:32:00+03	18600.00
894BC7	2017-08-03 03:14:00+03	85000.00
894C13	2017-08-12 14:00:00+03	161200.00
894C36	2017-08-14 15:04:00+03	126100.00
894C59	2017-08-13 09:47:00+03	26600.00
894C5E	2017-07-04 07:51:00+03	66000.00
894CA5	2017-07-06 04:52:00+03	12600.00
894D16	2017-07-24 03:14:00+03	44600.00
894D1D	2017-07-12 02:23:00+03	38400.00
894D70	2017-07-20 20:21:00+03	44800.00
894DF9	2017-07-26 12:25:00+03	71900.00
894E0B	2017-07-04 02:24:00+03	109000.00
894E4D	2017-08-06 15:48:00+03	147000.00
894E63	2017-08-06 04:30:00+03	48800.00
894EC0	2017-08-12 10:09:00+03	84300.00
894EE0	2017-08-14 16:02:00+03	58800.00
894EF7	2017-07-20 03:07:00+03	54800.00
894F8B	2017-08-04 18:47:00+03	167500.00
894F8C	2017-07-31 07:51:00+03	53300.00
894FCB	2017-07-15 19:14:00+03	55800.00
894FCE	2017-08-12 17:57:00+03	26200.00
894FD1	2017-06-30 14:09:00+03	59700.00
895007	2017-07-13 13:54:00+03	146600.00
89509C	2017-08-03 18:51:00+03	101200.00
8950EF	2017-07-19 17:26:00+03	34700.00
89516B	2017-08-11 22:52:00+03	40000.00
8951C5	2017-08-15 13:19:00+03	13400.00
8951F6	2017-07-17 11:02:00+03	120000.00
895237	2017-06-29 23:41:00+03	54500.00
895283	2017-07-07 03:51:00+03	46400.00
8952D5	2017-08-08 20:13:00+03	121400.00
895329	2017-07-01 21:54:00+03	58900.00
895420	2017-06-25 17:09:00+03	149300.00
89543C	2017-08-15 09:29:00+03	28800.00
89546C	2017-07-25 17:38:00+03	40000.00
895477	2017-07-28 09:23:00+03	37200.00
8954A4	2017-07-24 03:36:00+03	29200.00
8954CA	2017-08-14 18:33:00+03	83100.00
895521	2017-08-12 13:10:00+03	31600.00
895548	2017-08-03 17:49:00+03	71900.00
8955B0	2017-08-05 16:23:00+03	23200.00
8955C6	2017-08-02 06:45:00+03	71800.00
8956B9	2017-07-01 11:52:00+03	16400.00
8956D7	2017-07-30 15:23:00+03	48800.00
89570E	2017-07-28 19:56:00+03	32800.00
89578C	2017-07-06 11:43:00+03	18700.00
89579D	2017-07-21 00:41:00+03	23200.00
8957AA	2017-06-25 03:10:00+03	132800.00
8957AC	2017-08-08 00:20:00+03	19600.00
8957DB	2017-08-10 08:47:00+03	53200.00
895819	2017-08-11 20:12:00+03	68000.00
895823	2017-07-01 11:41:00+03	36200.00
895836	2017-07-11 00:58:00+03	113200.00
895845	2017-07-02 21:28:00+03	31600.00
895849	2017-07-06 18:40:00+03	123000.00
8958F9	2017-08-13 18:48:00+03	236000.00
895969	2017-07-26 09:43:00+03	12600.00
89599C	2017-06-30 16:59:00+03	19500.00
895A08	2017-07-26 19:41:00+03	36200.00
895A3B	2017-07-28 15:59:00+03	75300.00
895A3C	2017-07-05 03:13:00+03	115700.00
895A8A	2017-07-20 18:14:00+03	47400.00
895A96	2017-07-30 04:17:00+03	26600.00
895AB0	2017-07-02 12:18:00+03	101100.00
895AD3	2017-08-01 16:48:00+03	62800.00
895AE9	2017-06-29 08:16:00+03	26700.00
895AEE	2017-07-17 11:20:00+03	6000.00
895C34	2017-07-15 22:49:00+03	58400.00
895C44	2017-07-07 11:46:00+03	272300.00
895C67	2017-07-06 20:07:00+03	61800.00
895CD9	2017-08-01 21:34:00+03	12600.00
895CDC	2017-08-11 23:03:00+03	167400.00
895CFF	2017-07-06 12:39:00+03	16400.00
895D18	2017-08-07 17:59:00+03	124000.00
895D44	2017-07-02 07:54:00+03	103500.00
895D5B	2017-07-10 09:40:00+03	115100.00
895D8D	2017-07-15 16:03:00+03	303500.00
895EA0	2017-08-04 18:36:00+03	48800.00
895F08	2017-07-20 06:55:00+03	37100.00
895F37	2017-07-25 17:37:00+03	30200.00
895F88	2017-07-13 16:43:00+03	29600.00
895F96	2017-08-09 03:49:00+03	181100.00
895FA2	2017-07-26 12:02:00+03	6700.00
895FBA	2017-08-12 15:00:00+03	49800.00
895FE9	2017-08-06 02:50:00+03	70700.00
896058	2017-07-24 00:59:00+03	99200.00
8960A1	2017-08-01 23:55:00+03	56000.00
8960BD	2017-08-14 00:25:00+03	73600.00
8960CF	2017-07-28 18:52:00+03	28000.00
8960F8	2017-07-30 19:15:00+03	72400.00
8961D3	2017-07-06 14:36:00+03	20200.00
896298	2017-08-13 01:22:00+03	68800.00
8962CE	2017-07-07 18:20:00+03	61500.00
89630D	2017-06-28 13:49:00+03	84500.00
896336	2017-07-19 07:31:00+03	69100.00
896348	2017-07-29 19:40:00+03	49600.00
896369	2017-08-09 15:59:00+03	138100.00
896398	2017-07-16 14:03:00+03	37100.00
8963A8	2017-07-13 14:11:00+03	18000.00
896420	2017-07-04 04:22:00+03	101200.00
896435	2017-08-10 20:00:00+03	50600.00
896478	2017-06-29 15:37:00+03	28000.00
896484	2017-08-01 09:49:00+03	40000.00
896495	2017-07-07 20:21:00+03	33100.00
8964E2	2017-08-10 14:47:00+03	56600.00
8964FB	2017-07-08 20:07:00+03	55800.00
896524	2017-08-03 13:48:00+03	72300.00
89659A	2017-08-04 09:11:00+03	30400.00
89660E	2017-07-18 02:13:00+03	32200.00
896628	2017-07-29 11:48:00+03	58600.00
89668C	2017-07-12 13:59:00+03	29600.00
8966AD	2017-07-11 06:39:00+03	6800.00
896718	2017-07-12 02:44:00+03	68000.00
89672E	2017-08-12 17:01:00+03	37000.00
896784	2017-08-11 21:37:00+03	53400.00
896833	2017-07-12 07:07:00+03	89600.00
89683D	2017-07-20 17:10:00+03	24300.00
89686E	2017-08-13 22:36:00+03	68600.00
896892	2017-07-08 03:50:00+03	59800.00
8968F2	2017-07-26 07:59:00+03	100300.00
8968FF	2017-07-04 11:24:00+03	57500.00
896950	2017-07-22 09:06:00+03	49900.00
896967	2017-07-04 09:16:00+03	74100.00
8969FB	2017-08-15 05:49:00+03	136200.00
896A31	2017-07-02 16:50:00+03	67200.00
896A5F	2017-07-25 18:37:00+03	26000.00
896A7E	2017-07-21 15:19:00+03	39400.00
896AB5	2017-07-04 07:19:00+03	273400.00
896B50	2017-08-07 18:12:00+03	24400.00
896B8A	2017-07-08 16:13:00+03	37600.00
896BA9	2017-08-11 20:58:00+03	51400.00
896BCC	2017-08-09 22:14:00+03	32800.00
896C0D	2017-07-27 19:54:00+03	143600.00
896C2D	2017-07-29 23:32:00+03	23600.00
896C5A	2017-07-23 15:15:00+03	46400.00
896CDA	2017-07-14 17:43:00+03	24400.00
896CE2	2017-06-30 21:02:00+03	27300.00
896CFB	2017-08-10 10:22:00+03	46200.00
896D21	2017-07-23 04:07:00+03	37600.00
896D5F	2017-07-11 13:01:00+03	94000.00
896DBD	2017-07-31 03:01:00+03	6700.00
896DD2	2017-08-09 22:08:00+03	29600.00
896DF6	2017-06-28 09:15:00+03	28000.00
896E52	2017-08-11 09:36:00+03	71200.00
896E57	2017-07-22 10:29:00+03	111600.00
896E63	2017-08-05 01:53:00+03	29200.00
896F15	2017-07-10 12:28:00+03	53600.00
896F4B	2017-07-09 05:07:00+03	34000.00
896F6C	2017-07-22 17:49:00+03	10100.00
896F70	2017-06-30 15:24:00+03	81800.00
896F99	2017-08-14 05:07:00+03	96600.00
896FAC	2017-07-17 12:31:00+03	273000.00
896FE2	2017-07-04 13:42:00+03	199700.00
896FF4	2017-08-15 15:45:00+03	58900.00
897004	2017-07-18 02:31:00+03	108600.00
8970BB	2017-07-06 07:51:00+03	57500.00
8970DE	2017-07-24 17:26:00+03	41400.00
8970DF	2017-08-14 12:35:00+03	136800.00
8970EB	2017-06-30 15:30:00+03	155600.00
897100	2017-07-13 23:48:00+03	15400.00
897119	2017-08-11 10:27:00+03	402700.00
897121	2017-07-08 19:48:00+03	65600.00
897179	2017-08-06 14:59:00+03	28800.00
8971B6	2017-07-27 00:06:00+03	111600.00
8971C0	2017-08-14 22:08:00+03	260700.00
897244	2017-07-26 20:20:00+03	136800.00
897248	2017-08-08 13:08:00+03	8000.00
89725A	2017-08-08 17:05:00+03	103900.00
8972C3	2017-07-20 18:34:00+03	22000.00
8972D3	2017-08-10 17:51:00+03	55800.00
89734C	2017-06-27 17:59:00+03	16400.00
897427	2017-07-18 16:22:00+03	14400.00
89744A	2017-07-01 18:50:00+03	24400.00
897480	2017-08-11 07:19:00+03	127700.00
897481	2017-08-03 09:00:00+03	36900.00
8974F9	2017-07-21 00:30:00+03	67300.00
897575	2017-08-14 06:37:00+03	48500.00
897576	2017-08-05 21:49:00+03	87300.00
897593	2017-07-08 18:21:00+03	58200.00
8975AA	2017-07-16 08:05:00+03	199800.00
89760E	2017-08-14 12:56:00+03	7200.00
897667	2017-08-08 19:52:00+03	43300.00
8976B5	2017-07-10 04:02:00+03	94000.00
8976B8	2017-06-30 04:49:00+03	50600.00
8976CA	2017-07-17 01:16:00+03	56000.00
8976F7	2017-07-12 05:03:00+03	92700.00
897709	2017-07-22 14:23:00+03	23400.00
89772D	2017-08-03 19:14:00+03	199700.00
89774D	2017-07-04 23:38:00+03	13400.00
897761	2017-07-06 13:41:00+03	141600.00
897786	2017-07-21 17:28:00+03	27600.00
8977BA	2017-07-04 22:56:00+03	106400.00
89786B	2017-07-01 15:15:00+03	28000.00
897898	2017-07-14 20:13:00+03	23600.00
89789B	2017-07-27 06:55:00+03	55800.00
8978AB	2017-07-07 10:05:00+03	43000.00
8978F6	2017-07-13 01:55:00+03	67900.00
897926	2017-08-08 19:19:00+03	173500.00
897953	2017-07-21 10:52:00+03	152400.00
89796E	2017-07-05 22:19:00+03	55800.00
897994	2017-07-13 06:14:00+03	27200.00
8979A3	2017-08-13 07:49:00+03	76800.00
8979A9	2017-07-25 23:03:00+03	22000.00
8979BD	2017-07-02 10:14:00+03	44000.00
8979E3	2017-07-10 14:11:00+03	133200.00
8979EF	2017-08-04 15:19:00+03	40100.00
897AC9	2017-08-10 05:58:00+03	52400.00
897B2F	2017-08-12 23:29:00+03	67100.00
897B45	2017-08-05 16:33:00+03	26800.00
897B70	2017-07-18 08:06:00+03	99200.00
897B7F	2017-07-27 23:45:00+03	43500.00
897BDE	2017-07-12 19:24:00+03	45100.00
897BE7	2017-08-12 02:52:00+03	29000.00
897C00	2017-07-25 21:23:00+03	130000.00
897C25	2017-07-09 20:31:00+03	59200.00
897C39	2017-08-09 16:03:00+03	38500.00
897C68	2017-08-10 11:28:00+03	17000.00
897C73	2017-07-16 00:14:00+03	12600.00
897C88	2017-07-08 02:23:00+03	8000.00
897CD7	2017-08-02 14:33:00+03	49200.00
897D72	2017-08-03 12:27:00+03	36800.00
897E69	2017-07-06 22:49:00+03	10800.00
897E6B	2017-07-11 01:19:00+03	13400.00
897EBB	2017-08-03 10:50:00+03	68300.00
897EC9	2017-08-15 00:39:00+03	58600.00
897F08	2017-07-01 18:52:00+03	173500.00
897F46	2017-07-21 16:53:00+03	53600.00
897F59	2017-07-11 02:09:00+03	19800.00
897F90	2017-07-26 04:45:00+03	39500.00
897F99	2017-08-11 16:45:00+03	149600.00
897FAD	2017-06-28 03:30:00+03	239200.00
897FD2	2017-07-13 10:48:00+03	48800.00
89808F	2017-07-03 03:52:00+03	69000.00
89809E	2017-07-14 18:58:00+03	75300.00
8980A5	2017-08-09 00:05:00+03	615000.00
8980ED	2017-07-06 18:24:00+03	529200.00
89811E	2017-07-19 19:20:00+03	66600.00
89813F	2017-07-04 21:32:00+03	112000.00
898180	2017-07-28 05:22:00+03	42600.00
898181	2017-07-22 17:38:00+03	65900.00
898186	2017-07-04 11:56:00+03	27200.00
8981A0	2017-08-02 18:24:00+03	60000.00
8981C4	2017-08-05 21:08:00+03	62900.00
8981C6	2017-07-09 10:30:00+03	246000.00
898220	2017-07-10 01:42:00+03	72200.00
898248	2017-07-08 21:48:00+03	207200.00
898359	2017-08-14 13:28:00+03	44600.00
8983E1	2017-08-04 14:45:00+03	40800.00
8984A6	2017-07-22 11:39:00+03	6000.00
8984D2	2017-08-07 06:33:00+03	26000.00
898526	2017-07-08 11:47:00+03	57600.00
898564	2017-07-13 00:29:00+03	26700.00
89858B	2017-07-25 17:09:00+03	26200.00
89865C	2017-08-10 16:19:00+03	56200.00
89865F	2017-08-02 04:58:00+03	40000.00
8986FB	2017-08-01 01:38:00+03	38400.00
898709	2017-07-07 05:33:00+03	16400.00
898713	2017-07-21 15:24:00+03	43200.00
898736	2017-07-18 19:03:00+03	51600.00
89877A	2017-08-12 12:18:00+03	46900.00
8987B1	2017-07-31 20:53:00+03	266400.00
8987DA	2017-07-03 03:22:00+03	62600.00
898801	2017-07-21 14:29:00+03	206400.00
89882D	2017-07-12 19:54:00+03	37100.00
898849	2017-07-21 20:36:00+03	200500.00
89886D	2017-07-20 13:00:00+03	8000.00
89895C	2017-08-02 03:10:00+03	23200.00
8989C4	2017-06-30 05:28:00+03	64700.00
8989D2	2017-07-14 05:47:00+03	207000.00
898A0B	2017-07-08 16:42:00+03	136800.00
898A2B	2017-07-02 00:34:00+03	23100.00
898A30	2017-07-23 21:15:00+03	23200.00
898A9E	2017-07-10 01:46:00+03	55800.00
898ABF	2017-08-15 16:03:00+03	97500.00
898B10	2017-07-15 05:03:00+03	19600.00
898B2D	2017-07-15 12:01:00+03	147500.00
898B4D	2017-07-22 23:39:00+03	23200.00
898BCD	2017-08-15 05:23:00+03	67200.00
898C00	2017-06-30 14:26:00+03	118500.00
898C67	2017-07-23 15:16:00+03	25400.00
898C82	2017-07-10 04:52:00+03	33300.00
898C86	2017-07-07 11:36:00+03	92800.00
898CA0	2017-07-03 12:26:00+03	16400.00
898CF0	2017-08-13 11:55:00+03	30800.00
898D06	2017-08-07 15:47:00+03	13400.00
898D75	2017-07-30 23:04:00+03	212100.00
898DAF	2017-07-29 00:06:00+03	62100.00
898E07	2017-08-07 21:53:00+03	66000.00
898E42	2017-07-28 08:54:00+03	50600.00
898E7C	2017-07-15 09:05:00+03	20500.00
898EA5	2017-07-29 17:03:00+03	46400.00
898EB6	2017-07-11 17:22:00+03	122800.00
898EBA	2017-07-14 00:33:00+03	14800.00
898F27	2017-07-31 23:13:00+03	28000.00
898F41	2017-07-30 20:40:00+03	94200.00
898F49	2017-07-30 12:20:00+03	29400.00
898F50	2017-06-29 08:31:00+03	27300.00
89901E	2017-07-01 17:29:00+03	6700.00
89902F	2017-07-22 13:38:00+03	56000.00
8990A9	2017-07-22 01:19:00+03	19000.00
8990AA	2017-07-06 05:43:00+03	30200.00
899100	2017-07-28 06:50:00+03	174200.00
89910D	2017-07-02 15:20:00+03	58400.00
899142	2017-07-16 09:39:00+03	54000.00
89914A	2017-07-09 21:36:00+03	50600.00
89916D	2017-07-16 18:15:00+03	54000.00
89917D	2017-07-15 02:00:00+03	21400.00
89918F	2017-07-31 16:16:00+03	136200.00
8991AB	2017-07-21 17:07:00+03	109400.00
8991BE	2017-07-21 19:58:00+03	16800.00
8991D0	2017-08-05 13:16:00+03	137600.00
8991ED	2017-08-14 06:29:00+03	136200.00
899247	2017-07-22 16:31:00+03	25800.00
899259	2017-07-21 15:57:00+03	135200.00
8992BC	2017-08-05 06:29:00+03	56000.00
8992F6	2017-07-23 16:01:00+03	92800.00
89935D	2017-07-05 13:22:00+03	50600.00
8993B0	2017-07-01 06:30:00+03	39600.00
8993D1	2017-08-11 09:11:00+03	85000.00
899420	2017-06-29 07:36:00+03	50400.00
89945C	2017-07-18 08:58:00+03	266400.00
89945D	2017-07-22 06:19:00+03	59300.00
899484	2017-07-11 02:36:00+03	66600.00
89948F	2017-08-04 06:21:00+03	97900.00
8994A5	2017-07-29 18:08:00+03	88500.00
89950A	2017-07-12 07:55:00+03	56100.00
89955D	2017-07-07 21:16:00+03	116400.00
899601	2017-08-05 04:11:00+03	46800.00
89965C	2017-07-13 06:04:00+03	40800.00
899665	2017-07-12 22:28:00+03	246000.00
899679	2017-08-13 08:29:00+03	14400.00
8996BF	2017-08-01 19:12:00+03	47600.00
8996D8	2017-08-13 13:30:00+03	89700.00
89971D	2017-08-01 11:43:00+03	56000.00
899725	2017-08-14 04:47:00+03	6000.00
89973F	2017-07-02 03:08:00+03	8200.00
899740	2017-07-07 05:12:00+03	31400.00
899781	2017-07-20 20:31:00+03	207600.00
899785	2017-07-31 09:05:00+03	62700.00
899797	2017-07-17 12:30:00+03	37200.00
8997DB	2017-07-03 16:53:00+03	64500.00
8997EF	2017-08-01 10:16:00+03	123000.00
899883	2017-08-02 00:59:00+03	20100.00
899887	2017-07-03 14:17:00+03	57600.00
899899	2017-08-12 10:50:00+03	61400.00
8998C3	2017-07-28 18:05:00+03	153300.00
8998F1	2017-08-15 04:08:00+03	36400.00
899954	2017-07-13 00:39:00+03	115700.00
89995F	2017-07-25 03:15:00+03	46700.00
899976	2017-08-13 01:50:00+03	47200.00
899A26	2017-07-18 11:40:00+03	28000.00
899A2B	2017-07-08 23:43:00+03	22000.00
899AE0	2017-07-02 19:23:00+03	36900.00
899B13	2017-07-25 20:21:00+03	149600.00
899B37	2017-07-07 12:50:00+03	14400.00
899B47	2017-07-04 20:30:00+03	61800.00
899B48	2017-08-02 01:43:00+03	51900.00
899B4C	2017-07-14 05:42:00+03	68000.00
899B63	2017-08-06 03:47:00+03	70600.00
899B64	2017-08-13 05:39:00+03	111600.00
899BB1	2017-07-27 19:42:00+03	132800.00
899C15	2017-07-14 13:51:00+03	42800.00
899C71	2017-07-03 20:38:00+03	18000.00
899CCF	2017-08-02 14:10:00+03	27200.00
899D28	2017-07-11 04:13:00+03	48500.00
899D50	2017-08-05 12:41:00+03	135300.00
899DF8	2017-08-06 22:01:00+03	94800.00
899E52	2017-07-14 12:14:00+03	68800.00
899E87	2017-07-14 13:33:00+03	38800.00
899EC9	2017-08-07 08:24:00+03	57600.00
899ED5	2017-07-05 11:43:00+03	92800.00
899EF2	2017-07-04 18:26:00+03	109200.00
899F93	2017-08-15 08:50:00+03	19700.00
899FC1	2017-07-26 21:58:00+03	73400.00
899FDB	2017-08-04 02:13:00+03	41300.00
899FED	2017-07-30 16:34:00+03	34600.00
89A03D	2017-07-03 12:08:00+03	229900.00
89A09F	2017-07-07 05:07:00+03	12600.00
89A0D2	2017-08-10 10:07:00+03	23400.00
89A0E3	2017-08-12 13:18:00+03	38600.00
89A1B3	2017-07-03 16:52:00+03	46400.00
89A1C0	2017-08-15 10:18:00+03	88000.00
89A1D4	2017-07-02 03:00:00+03	102300.00
89A1FE	2017-08-13 22:26:00+03	124600.00
89A239	2017-08-12 01:46:00+03	155600.00
89A289	2017-07-09 02:51:00+03	246000.00
89A292	2017-08-12 08:21:00+03	47000.00
89A339	2017-07-18 22:39:00+03	142600.00
89A385	2017-07-29 13:21:00+03	47100.00
89A3E6	2017-07-17 14:55:00+03	41200.00
89A3EF	2017-08-02 14:58:00+03	119600.00
89A40E	2017-07-19 22:01:00+03	6000.00
89A43A	2017-07-26 10:04:00+03	26200.00
89A4B0	2017-08-03 18:49:00+03	25400.00
89A4EF	2017-07-21 21:08:00+03	46400.00
89A595	2017-07-08 01:51:00+03	11600.00
89A5A3	2017-07-31 18:39:00+03	6800.00
89A5BC	2017-07-02 16:50:00+03	119700.00
89A643	2017-07-17 19:31:00+03	26700.00
89A6BC	2017-07-21 21:55:00+03	167400.00
89A6CD	2017-07-03 04:49:00+03	257500.00
89A777	2017-07-19 10:11:00+03	364600.00
89A7EF	2017-07-05 14:43:00+03	30100.00
89A882	2017-07-27 02:39:00+03	131600.00
89A8B2	2017-07-27 07:48:00+03	96800.00
89A8BC	2017-08-02 21:08:00+03	37900.00
89A8DA	2017-07-24 18:29:00+03	60800.00
89A91C	2017-07-19 00:30:00+03	47000.00
89A95E	2017-08-13 15:26:00+03	59100.00
89A96D	2017-07-03 14:06:00+03	135600.00
89A9C4	2017-07-22 15:01:00+03	13200.00
89AA08	2017-08-13 11:35:00+03	31600.00
89AA34	2017-08-02 14:31:00+03	27000.00
89AA85	2017-07-14 01:44:00+03	24700.00
89AAC8	2017-08-10 02:39:00+03	148200.00
89AAE5	2017-07-14 17:25:00+03	97600.00
89AAFF	2017-07-07 14:46:00+03	265700.00
89ABC2	2017-07-19 02:43:00+03	166000.00
89ABE1	2017-07-31 10:09:00+03	202400.00
89AC03	2017-06-29 05:35:00+03	6600.00
89ACD4	2017-07-15 02:36:00+03	46300.00
89AD0D	2017-07-13 07:04:00+03	153200.00
89AD12	2017-07-20 17:38:00+03	37100.00
89AD61	2017-08-11 06:36:00+03	79300.00
89AD68	2017-07-22 13:56:00+03	23400.00
89ADF2	2017-08-04 20:38:00+03	85000.00
89AE30	2017-07-31 08:56:00+03	23600.00
89AE4C	2017-08-15 15:29:00+03	128000.00
89AEDF	2017-07-26 10:33:00+03	65600.00
89AF15	2017-07-11 22:37:00+03	66300.00
89AFDF	2017-07-04 06:05:00+03	63700.00
89AFE0	2017-08-10 19:15:00+03	26000.00
89AFFB	2017-07-15 04:07:00+03	6700.00
89B052	2017-07-28 00:36:00+03	58600.00
89B0FC	2017-07-19 17:19:00+03	386300.00
89B103	2017-08-01 23:51:00+03	101500.00
89B14A	2017-07-11 10:21:00+03	198300.00
89B1F8	2017-06-30 16:59:00+03	63400.00
89B249	2017-07-16 08:07:00+03	81700.00
89B2B0	2017-07-09 23:47:00+03	95200.00
89B2C1	2017-07-01 23:59:00+03	20200.00
89B2E6	2017-07-18 21:40:00+03	23900.00
89B331	2017-07-28 23:54:00+03	58200.00
89B36E	2017-08-12 00:19:00+03	321300.00
89B393	2017-08-10 22:22:00+03	12600.00
89B3F3	2017-08-10 05:05:00+03	26000.00
89B45A	2017-08-11 09:28:00+03	62900.00
89B46D	2017-08-14 18:11:00+03	223400.00
89B497	2017-07-29 09:33:00+03	26800.00
89B519	2017-08-07 03:09:00+03	59200.00
89B52A	2017-07-27 20:11:00+03	65300.00
89B535	2017-07-14 21:59:00+03	55800.00
89B549	2017-08-10 09:25:00+03	148500.00
89B563	2017-07-14 03:43:00+03	63800.00
89B5C7	2017-07-11 12:13:00+03	58200.00
89B623	2017-08-02 22:29:00+03	16400.00
89B655	2017-08-10 00:15:00+03	189200.00
89B68A	2017-08-08 08:50:00+03	14400.00
89B6C2	2017-08-06 18:54:00+03	87900.00
89B71E	2017-07-25 17:08:00+03	152900.00
89B76C	2017-07-07 18:39:00+03	35600.00
89B788	2017-07-17 17:34:00+03	59700.00
89B7BC	2017-07-26 22:08:00+03	65900.00
89B804	2017-07-03 16:18:00+03	69500.00
89B80A	2017-08-14 11:16:00+03	28800.00
89B882	2017-08-07 08:22:00+03	57400.00
89B8A0	2017-07-27 02:27:00+03	226200.00
89B8C9	2017-07-09 22:00:00+03	25000.00
89B971	2017-08-14 21:29:00+03	53100.00
89B975	2017-08-10 17:26:00+03	72400.00
89B9CC	2017-07-27 09:45:00+03	38800.00
89BA1E	2017-07-16 16:30:00+03	112000.00
89BA75	2017-07-25 00:24:00+03	38600.00
89BB74	2017-07-19 16:13:00+03	6300.00
89BC2E	2017-08-12 11:06:00+03	55800.00
89BC61	2017-08-02 16:43:00+03	119900.00
89BC77	2017-07-21 17:09:00+03	43500.00
89BC9C	2017-07-28 02:10:00+03	62600.00
89BD1D	2017-07-13 06:47:00+03	59800.00
89BD5D	2017-07-24 05:01:00+03	25200.00
89BD85	2017-08-10 19:45:00+03	52100.00
89BDB7	2017-07-11 11:32:00+03	71900.00
89BDC2	2017-07-09 16:08:00+03	24400.00
89BE11	2017-07-16 17:01:00+03	65600.00
89BE16	2017-08-12 03:50:00+03	21800.00
89BF0E	2017-07-08 04:55:00+03	133100.00
89BFA8	2017-08-06 15:28:00+03	114600.00
89BFCE	2017-08-02 12:31:00+03	112600.00
89C011	2017-07-08 20:54:00+03	22600.00
89C015	2017-06-26 23:17:00+03	55800.00
89C018	2017-07-11 08:29:00+03	25400.00
89C03F	2017-08-12 01:07:00+03	192500.00
89C074	2017-08-01 14:15:00+03	117200.00
89C07D	2017-08-12 15:52:00+03	95700.00
89C081	2017-07-01 22:17:00+03	249100.00
89C098	2017-08-09 20:27:00+03	50100.00
89C0E5	2017-07-15 22:15:00+03	167400.00
89C0EF	2017-06-29 17:29:00+03	23200.00
89C105	2017-08-04 15:02:00+03	224600.00
89C12B	2017-08-14 07:08:00+03	132200.00
89C13A	2017-08-12 06:41:00+03	67700.00
89C150	2017-07-08 23:39:00+03	419100.00
89C165	2017-07-25 14:16:00+03	53000.00
89C197	2017-07-03 22:58:00+03	6700.00
89C1A9	2017-07-29 02:05:00+03	96800.00
89C1C7	2017-08-15 06:25:00+03	34100.00
89C1D5	2017-08-09 21:06:00+03	399600.00
89C1F3	2017-08-09 21:03:00+03	157300.00
89C1F5	2017-07-26 10:44:00+03	24700.00
89C233	2017-07-19 22:27:00+03	32700.00
89C2B6	2017-08-13 20:32:00+03	46400.00
89C2E6	2017-08-09 09:57:00+03	45600.00
89C2EC	2017-08-03 06:52:00+03	22000.00
89C36C	2017-07-22 06:08:00+03	51800.00
89C395	2017-08-13 21:22:00+03	28800.00
89C3A3	2017-08-05 20:32:00+03	30200.00
89C437	2017-07-15 04:53:00+03	25400.00
89C461	2017-08-13 23:55:00+03	76600.00
89C500	2017-08-03 10:13:00+03	23200.00
89C526	2017-08-03 05:30:00+03	51900.00
89C565	2017-07-16 04:07:00+03	65100.00
89C5B2	2017-08-15 10:32:00+03	100600.00
89C603	2017-07-01 18:54:00+03	56000.00
89C615	2017-07-19 17:47:00+03	55500.00
89C635	2017-07-21 20:36:00+03	39800.00
89C653	2017-07-10 11:51:00+03	104000.00
89C659	2017-07-17 04:55:00+03	112000.00
89C663	2017-07-29 10:10:00+03	38800.00
89C675	2017-07-30 23:54:00+03	266400.00
89C690	2017-08-13 23:10:00+03	6700.00
89C69D	2017-07-04 06:35:00+03	148200.00
89C6B7	2017-07-23 14:12:00+03	226800.00
89C732	2017-07-09 04:23:00+03	130400.00
89C7C2	2017-07-02 22:38:00+03	40000.00
89C7DF	2017-08-12 04:30:00+03	85000.00
89C7E0	2017-08-14 05:32:00+03	57100.00
89C82E	2017-07-21 03:21:00+03	22000.00
89C87E	2017-07-06 14:08:00+03	62600.00
89C894	2017-07-16 20:26:00+03	19600.00
89C8A8	2017-08-07 19:55:00+03	66000.00
89C8A9	2017-08-06 09:24:00+03	45000.00
89C90B	2017-07-16 19:48:00+03	86800.00
89C917	2017-07-07 19:42:00+03	30200.00
89C923	2017-07-06 05:27:00+03	86800.00
89C93F	2017-07-14 13:46:00+03	48800.00
89C9AC	2017-07-24 18:22:00+03	39600.00
89C9CB	2017-07-20 13:00:00+03	45200.00
89CA02	2017-07-28 06:22:00+03	67600.00
89CA30	2017-07-10 10:09:00+03	22400.00
89CA3F	2017-08-04 08:58:00+03	61800.00
89CA95	2017-07-04 18:49:00+03	24800.00
89CB5D	2017-07-26 21:40:00+03	61800.00
89CB90	2017-07-14 16:26:00+03	21800.00
89CB9A	2017-08-15 14:07:00+03	26000.00
89CBC1	2017-07-31 04:20:00+03	57400.00
89CC05	2017-07-16 05:39:00+03	123000.00
89CC0D	2017-08-05 10:48:00+03	151500.00
89CC0F	2017-07-27 06:23:00+03	48500.00
89CC47	2017-08-13 19:21:00+03	31900.00
89CC4E	2017-08-02 19:08:00+03	54500.00
89CC77	2017-08-14 01:03:00+03	229900.00
89CCA7	2017-07-05 20:17:00+03	154500.00
89CCF2	2017-07-19 20:23:00+03	86600.00
89CD55	2017-06-30 18:27:00+03	70700.00
89CD5A	2017-07-03 18:11:00+03	123000.00
89CE91	2017-07-28 06:52:00+03	12400.00
89CECB	2017-08-11 01:10:00+03	119600.00
89CF1C	2017-08-13 18:30:00+03	79500.00
89CF4C	2017-08-05 22:25:00+03	85000.00
89CF5E	2017-08-12 16:27:00+03	258400.00
89CF7B	2017-07-26 13:46:00+03	75600.00
89CF97	2017-08-03 01:43:00+03	56000.00
89CFBA	2017-07-26 07:12:00+03	6000.00
89D0A4	2017-07-30 16:09:00+03	115600.00
89D0A6	2017-08-08 22:50:00+03	28000.00
89D10E	2017-08-13 23:34:00+03	37900.00
89D171	2017-08-06 08:29:00+03	14400.00
89D178	2017-07-20 14:54:00+03	369000.00
89D1E4	2017-08-04 22:57:00+03	372600.00
89D237	2017-07-20 02:39:00+03	23200.00
89D241	2017-07-06 01:50:00+03	26800.00
89D25F	2017-07-21 23:19:00+03	13400.00
89D261	2017-08-05 14:25:00+03	74800.00
89D275	2017-08-15 05:27:00+03	57600.00
89D2D0	2017-07-17 12:02:00+03	7400.00
89D31B	2017-07-25 14:27:00+03	62000.00
89D333	2017-07-15 21:21:00+03	95600.00
89D343	2017-08-11 04:55:00+03	25400.00
89D355	2017-07-11 23:50:00+03	237700.00
89D3B1	2017-07-01 11:25:00+03	20200.00
89D3D3	2017-07-19 05:11:00+03	88600.00
89D3D6	2017-07-14 03:20:00+03	34000.00
89D3F7	2017-07-18 15:23:00+03	75600.00
89D418	2017-08-14 17:52:00+03	28800.00
89D44B	2017-07-28 09:34:00+03	56600.00
89D476	2017-08-12 04:14:00+03	86600.00
89D4C4	2017-08-03 09:32:00+03	105000.00
89D4CE	2017-08-13 01:57:00+03	266400.00
89D523	2017-07-15 12:40:00+03	47400.00
89D565	2017-08-14 10:19:00+03	132800.00
89D599	2017-08-12 13:41:00+03	39700.00
89D5E4	2017-07-28 00:17:00+03	25600.00
89D639	2017-08-01 09:22:00+03	21400.00
89D645	2017-08-02 23:17:00+03	19600.00
89D68D	2017-07-12 19:10:00+03	32800.00
89D69F	2017-08-11 19:45:00+03	13600.00
89D6AD	2017-07-24 10:21:00+03	67000.00
89D71E	2017-07-21 08:17:00+03	102000.00
89D787	2017-07-05 06:23:00+03	97900.00
89D7B1	2017-07-27 10:26:00+03	134400.00
89D7C6	2017-08-07 01:10:00+03	52300.00
89D8AC	2017-07-07 03:08:00+03	87300.00
89D8BF	2017-08-05 23:04:00+03	92800.00
89D8C8	2017-08-07 09:10:00+03	61800.00
89D9F0	2017-08-08 01:38:00+03	19600.00
89DA5D	2017-07-20 01:51:00+03	49800.00
89DA86	2017-07-03 23:36:00+03	28800.00
89DAA3	2017-07-16 13:27:00+03	67900.00
89DAD0	2017-07-04 11:34:00+03	130400.00
89DAE8	2017-08-10 10:32:00+03	58600.00
89DB0D	2017-07-23 02:07:00+03	87100.00
89DB54	2017-07-25 14:44:00+03	146600.00
89DBCB	2017-07-09 14:08:00+03	100600.00
89DBD3	2017-07-29 21:54:00+03	43200.00
89DBFF	2017-07-31 13:35:00+03	30200.00
89DE4D	2017-07-13 09:54:00+03	92000.00
89DE4E	2017-08-05 02:49:00+03	23600.00
89DE55	2017-07-03 04:32:00+03	20800.00
89DEBA	2017-07-22 05:55:00+03	112100.00
89DF49	2017-07-09 05:06:00+03	50000.00
89DF7D	2017-07-07 23:24:00+03	55600.00
89DFDC	2017-07-24 23:20:00+03	40000.00
89E008	2017-07-06 21:14:00+03	192700.00
89E021	2017-07-02 02:23:00+03	116400.00
89E04C	2017-08-15 17:41:00+03	182100.00
89E051	2017-07-14 04:28:00+03	6700.00
89E0D5	2017-08-12 12:35:00+03	6700.00
89E14A	2017-08-07 21:41:00+03	109600.00
89E15C	2017-07-15 13:47:00+03	58400.00
89E169	2017-07-28 02:30:00+03	92800.00
89E17A	2017-07-30 07:40:00+03	35200.00
89E183	2017-08-01 04:27:00+03	32800.00
89E185	2017-06-29 22:13:00+03	92100.00
89E186	2017-07-22 04:12:00+03	75800.00
89E18B	2017-07-21 03:37:00+03	98300.00
89E1A4	2017-07-14 02:54:00+03	11600.00
89E1D3	2017-08-01 22:17:00+03	24400.00
89E243	2017-08-11 04:58:00+03	53600.00
89E266	2017-08-07 11:20:00+03	57600.00
89E284	2017-08-13 17:52:00+03	55800.00
89E287	2017-07-11 03:22:00+03	67200.00
89E2D4	2017-07-20 19:22:00+03	43700.00
89E2E8	2017-08-13 09:57:00+03	24800.00
89E2F8	2017-08-10 18:13:00+03	35200.00
89E324	2017-07-28 03:36:00+03	66400.00
89E384	2017-07-06 03:11:00+03	49200.00
89E3B2	2017-06-30 02:15:00+03	26000.00
89E3C6	2017-06-28 21:01:00+03	283100.00
89E3C7	2017-07-04 13:51:00+03	34400.00
89E3E0	2017-07-07 02:31:00+03	8400.00
89E45D	2017-07-30 17:38:00+03	14400.00
89E47B	2017-07-07 23:56:00+03	58600.00
89E481	2017-08-13 23:56:00+03	28700.00
89E48B	2017-07-19 11:31:00+03	61500.00
89E4A2	2017-08-06 19:53:00+03	23200.00
89E4B1	2017-07-11 01:30:00+03	54800.00
89E4CC	2017-08-02 23:20:00+03	139400.00
89E533	2017-07-16 20:53:00+03	265600.00
89E546	2017-07-23 21:12:00+03	41200.00
89E573	2017-07-08 15:28:00+03	46200.00
89E58E	2017-08-01 17:39:00+03	138600.00
89E5A7	2017-08-02 04:41:00+03	8200.00
89E5F0	2017-08-07 22:42:00+03	308500.00
89E672	2017-07-23 09:50:00+03	30200.00
89E6DF	2017-08-08 00:16:00+03	22100.00
89E6F9	2017-07-22 06:25:00+03	31000.00
89E6FB	2017-08-12 08:03:00+03	69400.00
89E6FC	2017-07-15 04:23:00+03	28000.00
89E781	2017-08-08 20:59:00+03	21200.00
89E786	2017-07-12 22:26:00+03	48800.00
89E7BA	2017-07-23 12:02:00+03	6000.00
89E7DF	2017-07-31 21:03:00+03	36200.00
89E7E9	2017-06-27 07:59:00+03	26000.00
89E843	2017-08-01 07:18:00+03	496600.00
89E846	2017-08-12 14:55:00+03	75600.00
89E85B	2017-07-20 20:15:00+03	36400.00
89E87F	2017-08-03 09:31:00+03	39800.00
89E8B8	2017-07-01 16:01:00+03	73600.00
89E8DE	2017-07-13 06:57:00+03	46000.00
89E943	2017-08-09 10:31:00+03	28800.00
89E976	2017-07-27 00:46:00+03	32800.00
89E992	2017-07-28 05:54:00+03	56100.00
89EA1E	2017-08-01 23:30:00+03	70700.00
89EA3F	2017-07-20 06:03:00+03	28000.00
89EAD9	2017-07-17 05:12:00+03	23600.00
89EB10	2017-07-14 20:44:00+03	87800.00
89EB3A	2017-08-07 20:05:00+03	13400.00
89EB76	2017-08-05 23:15:00+03	210000.00
89EBF7	2017-07-13 20:13:00+03	40000.00
89EC0C	2017-08-04 11:35:00+03	16400.00
89EC41	2017-07-16 08:11:00+03	16400.00
89ECDE	2017-06-29 01:35:00+03	71600.00
89ED00	2017-08-08 00:41:00+03	70700.00
89ED11	2017-07-28 15:26:00+03	30200.00
89ED53	2017-08-10 23:08:00+03	51800.00
89ED6B	2017-07-28 06:26:00+03	82600.00
89ED6E	2017-07-31 13:59:00+03	12200.00
89ED7B	2017-07-27 21:32:00+03	80400.00
89EDCD	2017-08-02 23:21:00+03	27500.00
89EE5B	2017-08-07 05:08:00+03	12700.00
89EE5C	2017-07-28 10:49:00+03	201200.00
89EEC6	2017-08-15 00:23:00+03	15700.00
89EED2	2017-08-06 17:49:00+03	11800.00
89EF66	2017-07-28 18:16:00+03	124200.00
89EF7F	2017-07-01 20:21:00+03	27400.00
89EF95	2017-07-24 08:27:00+03	168700.00
89F04A	2017-07-15 16:43:00+03	266400.00
89F0B0	2017-07-09 00:29:00+03	187600.00
89F14E	2017-07-26 15:47:00+03	55000.00
89F17A	2017-08-01 11:47:00+03	16400.00
89F1A8	2017-08-11 05:41:00+03	68100.00
89F1CF	2017-07-11 05:23:00+03	63200.00
89F2AA	2017-07-24 06:05:00+03	73400.00
89F2CE	2017-08-07 23:31:00+03	55800.00
89F2E4	2017-07-18 08:47:00+03	30800.00
89F2E7	2017-08-12 10:20:00+03	123400.00
89F3F7	2017-07-22 10:16:00+03	40000.00
89F3FA	2017-07-12 21:46:00+03	8400.00
89F44E	2017-07-15 01:54:00+03	105600.00
89F45D	2017-08-08 16:34:00+03	39300.00
89F45E	2017-08-13 08:02:00+03	131600.00
89F4EE	2017-07-15 12:01:00+03	91100.00
89F53B	2017-07-13 02:20:00+03	58800.00
89F597	2017-08-13 00:45:00+03	53400.00
89F5C4	2017-08-13 12:32:00+03	25200.00
89F5D7	2017-08-10 05:30:00+03	19600.00
89F5FA	2017-07-02 07:17:00+03	52000.00
89F61F	2017-07-27 01:13:00+03	73600.00
89F647	2017-07-19 18:35:00+03	24700.00
89F673	2017-08-10 09:46:00+03	14000.00
89F69C	2017-07-19 11:59:00+03	23600.00
89F6E0	2017-07-06 07:22:00+03	37200.00
89F6F3	2017-07-05 13:49:00+03	19000.00
89F70E	2017-07-17 06:15:00+03	84500.00
89F713	2017-07-23 09:25:00+03	14400.00
89F72E	2017-07-18 05:41:00+03	147100.00
89F789	2017-07-11 01:31:00+03	186500.00
89F7B7	2017-07-16 16:24:00+03	55800.00
89F7C8	2017-08-09 03:22:00+03	152400.00
89F817	2017-07-21 14:27:00+03	27600.00
89F87F	2017-07-24 08:21:00+03	53200.00
89F8A7	2017-07-20 14:03:00+03	123000.00
89F900	2017-08-04 06:09:00+03	85000.00
89F911	2017-07-16 22:42:00+03	149100.00
89F93C	2017-08-11 03:38:00+03	129700.00
89F9A1	2017-07-30 11:09:00+03	81600.00
89F9A2	2017-07-17 09:40:00+03	24300.00
89F9BE	2017-08-09 11:04:00+03	46500.00
89F9FD	2017-07-31 00:19:00+03	235400.00
89FA42	2017-07-25 07:53:00+03	26000.00
89FA8D	2017-07-16 08:02:00+03	103900.00
89FAD0	2017-07-10 08:06:00+03	6700.00
89FB6C	2017-07-08 21:02:00+03	132800.00
89FB76	2017-08-01 11:46:00+03	21400.00
89FB79	2017-07-19 05:26:00+03	296400.00
89FB8C	2017-08-03 02:16:00+03	56000.00
89FBC1	2017-08-01 08:24:00+03	49800.00
89FBF1	2017-08-05 13:22:00+03	84100.00
89FCD0	2017-07-31 04:18:00+03	28000.00
89FD68	2017-08-05 05:23:00+03	20000.00
89FD8A	2017-08-13 02:48:00+03	46800.00
89FDBB	2017-07-18 12:25:00+03	27400.00
89FDD8	2017-08-15 08:56:00+03	243300.00
89FE3D	2017-08-05 10:17:00+03	29300.00
89FE68	2017-07-25 01:03:00+03	25200.00
89FEC7	2017-06-30 15:28:00+03	46400.00
89FF42	2017-08-09 14:56:00+03	231900.00
89FF4B	2017-08-07 09:05:00+03	44600.00
89FFA8	2017-07-24 11:12:00+03	23200.00
89FFC3	2017-06-29 04:09:00+03	52400.00
8A0031	2017-07-25 19:11:00+03	46400.00
8A003A	2017-07-15 10:16:00+03	92800.00
8A007D	2017-07-07 00:01:00+03	36200.00
8A0093	2017-08-12 17:34:00+03	48800.00
8A0095	2017-08-02 00:22:00+03	136200.00
8A0168	2017-07-20 17:14:00+03	123000.00
8A01AA	2017-07-02 06:00:00+03	30200.00
8A020C	2017-07-29 22:11:00+03	30200.00
8A028A	2017-08-04 22:37:00+03	155600.00
8A02C8	2017-07-02 22:53:00+03	542300.00
8A02FA	2017-06-28 04:44:00+03	76900.00
8A0351	2017-07-19 10:46:00+03	19600.00
8A03C6	2017-08-11 19:53:00+03	81600.00
8A0424	2017-08-05 17:00:00+03	74900.00
8A048F	2017-07-15 06:32:00+03	38800.00
8A049D	2017-08-11 21:01:00+03	30200.00
8A04AA	2017-08-14 10:29:00+03	31000.00
8A04DC	2017-07-15 17:13:00+03	47000.00
8A05EC	2017-07-06 19:50:00+03	93700.00
8A0698	2017-08-13 16:23:00+03	46000.00
8A069F	2017-08-09 01:52:00+03	26100.00
8A06E4	2017-07-28 14:30:00+03	56100.00
8A0775	2017-08-15 09:33:00+03	110800.00
8A07A2	2017-07-05 15:16:00+03	120700.00
8A07B8	2017-07-25 11:21:00+03	14000.00
8A0818	2017-07-03 02:33:00+03	203100.00
8A082A	2017-07-01 02:41:00+03	184100.00
8A0882	2017-07-27 03:41:00+03	37900.00
8A08B2	2017-07-18 20:40:00+03	246000.00
8A08FF	2017-06-29 14:06:00+03	26800.00
8A091E	2017-08-13 13:41:00+03	34000.00
8A0963	2017-07-08 06:36:00+03	189700.00
8A096B	2017-07-29 05:50:00+03	25900.00
8A09A0	2017-07-10 06:19:00+03	57800.00
8A09D1	2017-07-19 20:46:00+03	28000.00
8A0A5E	2017-07-23 11:59:00+03	29600.00
8A0A7F	2017-07-10 14:23:00+03	259500.00
8A0AB8	2017-07-27 19:02:00+03	189200.00
8A0B73	2017-08-13 05:05:00+03	41200.00
8A0BB1	2017-08-09 16:01:00+03	46300.00
8A0C0A	2017-07-06 01:17:00+03	51800.00
8A0C43	2017-08-11 13:23:00+03	124200.00
8A0C86	2017-07-20 03:19:00+03	14000.00
8A0CBD	2017-07-15 11:45:00+03	44100.00
8A0D24	2017-07-12 22:05:00+03	56100.00
8A0D7D	2017-07-11 21:53:00+03	19100.00
8A0DCC	2017-08-01 14:55:00+03	135400.00
8A0DE8	2017-07-01 12:04:00+03	139200.00
8A0E98	2017-07-24 11:42:00+03	24800.00
8A0EE1	2017-07-16 21:42:00+03	25200.00
8A0EF4	2017-08-13 01:01:00+03	18000.00
8A0F62	2017-08-06 04:44:00+03	10800.00
8A0FA4	2017-07-22 21:13:00+03	372500.00
8A0FC1	2017-07-06 22:17:00+03	15000.00
8A0FCA	2017-08-08 08:32:00+03	123000.00
8A1020	2017-07-01 14:08:00+03	21400.00
8A1040	2017-08-09 23:44:00+03	56000.00
8A10D0	2017-07-19 22:22:00+03	37600.00
8A10EA	2017-08-10 11:08:00+03	38400.00
8A10F9	2017-07-16 08:34:00+03	59800.00
8A10FC	2017-07-08 21:39:00+03	147700.00
8A111F	2017-08-04 06:20:00+03	59200.00
8A1125	2017-08-01 01:45:00+03	49800.00
8A114F	2017-07-03 20:35:00+03	76300.00
8A1190	2017-07-06 09:23:00+03	26000.00
8A119E	2017-07-26 09:32:00+03	28000.00
8A11B6	2017-07-08 06:46:00+03	25800.00
8A11DA	2017-06-28 07:05:00+03	73600.00
8A11E2	2017-07-13 21:33:00+03	56100.00
8A11FF	2017-07-29 22:46:00+03	79700.00
8A1234	2017-07-09 11:57:00+03	48700.00
8A1273	2017-08-12 05:46:00+03	70600.00
8A1277	2017-08-13 19:06:00+03	27300.00
8A12C6	2017-08-06 23:33:00+03	170000.00
8A130D	2017-08-10 12:24:00+03	101700.00
8A13B5	2017-07-13 05:06:00+03	22600.00
8A13E5	2017-07-10 16:45:00+03	62100.00
8A1431	2017-07-30 15:07:00+03	89600.00
8A14D7	2017-08-14 09:49:00+03	62000.00
8A1516	2017-07-06 01:52:00+03	56000.00
8A1533	2017-07-28 21:12:00+03	69500.00
8A1565	2017-07-17 20:47:00+03	36200.00
8A158E	2017-07-28 00:34:00+03	61800.00
8A159C	2017-07-08 17:59:00+03	28000.00
8A1628	2017-07-12 02:29:00+03	97900.00
8A167E	2017-08-03 05:33:00+03	23200.00
8A170A	2017-08-12 17:32:00+03	58400.00
8A1765	2017-07-21 17:07:00+03	37100.00
8A177A	2017-07-13 22:37:00+03	114600.00
8A178D	2017-08-03 16:16:00+03	265700.00
8A1796	2017-06-30 05:12:00+03	44800.00
8A17AC	2017-07-09 07:32:00+03	54800.00
8A17B4	2017-07-11 04:24:00+03	118500.00
8A17E3	2017-07-22 02:15:00+03	28000.00
8A17EF	2017-07-23 08:02:00+03	43900.00
8A1837	2017-07-15 03:23:00+03	6000.00
8A18AE	2017-07-05 08:55:00+03	77600.00
8A18D6	2017-07-14 04:30:00+03	29400.00
8A191B	2017-08-14 18:38:00+03	162200.00
8A1981	2017-07-14 03:53:00+03	155600.00
8A19B5	2017-07-19 20:06:00+03	51800.00
8A1A05	2017-07-22 22:39:00+03	22000.00
8A1A1F	2017-07-23 15:47:00+03	77300.00
8A1A23	2017-08-02 06:01:00+03	58900.00
8A1A3A	2017-08-01 07:12:00+03	85000.00
8A1B1D	2017-08-10 01:38:00+03	46400.00
8A1B25	2017-07-31 04:02:00+03	92800.00
8A1B3C	2017-07-10 14:53:00+03	12700.00
8A1B68	2017-07-03 23:46:00+03	51200.00
8A1B8D	2017-08-05 03:06:00+03	13400.00
8A1B8F	2017-07-11 22:17:00+03	140500.00
8A1BFA	2017-07-08 18:17:00+03	28000.00
8A1C27	2017-07-27 11:40:00+03	46400.00
8A1C2E	2017-07-25 17:12:00+03	83000.00
8A1CBA	2017-07-23 04:01:00+03	59200.00
8A1CE7	2017-07-10 14:58:00+03	52000.00
8A1CF4	2017-07-03 09:17:00+03	94700.00
8A1D73	2017-08-15 10:30:00+03	44800.00
8A1D7C	2017-07-06 07:26:00+03	40400.00
8A1DAC	2017-08-01 21:22:00+03	93900.00
8A1E0B	2017-07-03 18:44:00+03	81200.00
8A1E2A	2017-07-19 17:09:00+03	83600.00
8A1E92	2017-07-27 01:28:00+03	112000.00
8A1ED0	2017-08-10 19:36:00+03	112000.00
8A1EE8	2017-07-14 21:29:00+03	24300.00
8A1EE9	2017-07-21 07:44:00+03	32200.00
8A1F6D	2017-07-02 01:45:00+03	93700.00
8A1F79	2017-08-14 02:46:00+03	28000.00
8A2014	2017-07-16 20:25:00+03	37200.00
8A2056	2017-07-18 17:48:00+03	128800.00
8A2090	2017-07-29 19:43:00+03	30200.00
8A20A5	2017-07-24 02:42:00+03	55800.00
8A20D5	2017-07-29 16:25:00+03	28000.00
8A2111	2017-07-22 13:53:00+03	75000.00
8A213F	2017-08-13 10:35:00+03	76600.00
8A2176	2017-08-05 11:26:00+03	26800.00
8A21F5	2017-08-09 15:37:00+03	400900.00
8A2224	2017-08-13 06:08:00+03	73200.00
8A2276	2017-08-08 14:18:00+03	27800.00
8A22F6	2017-07-08 23:05:00+03	20400.00
8A2326	2017-07-22 07:17:00+03	36200.00
8A2354	2017-07-14 23:58:00+03	115800.00
8A23AC	2017-08-01 00:25:00+03	21400.00
8A23F6	2017-07-29 17:46:00+03	11700.00
8A2482	2017-08-12 17:44:00+03	42000.00
8A24D4	2017-07-11 05:21:00+03	59200.00
8A24E4	2017-07-29 12:31:00+03	36100.00
8A24F3	2017-07-13 16:53:00+03	25600.00
8A2500	2017-08-03 19:48:00+03	111600.00
8A2501	2017-07-26 17:18:00+03	24400.00
8A251E	2017-07-20 13:31:00+03	54800.00
8A2552	2017-07-26 21:17:00+03	23200.00
8A2561	2017-07-14 09:54:00+03	76200.00
8A25DC	2017-08-06 12:20:00+03	78800.00
8A25EE	2017-07-30 02:32:00+03	6900.00
8A260C	2017-07-20 23:02:00+03	133100.00
8A262D	2017-07-04 20:26:00+03	6700.00
8A2670	2017-07-03 08:45:00+03	32700.00
8A2680	2017-07-28 21:48:00+03	16400.00
8A26A9	2017-07-26 15:10:00+03	181600.00
8A26C5	2017-08-15 09:48:00+03	111600.00
8A271E	2017-07-17 07:36:00+03	133100.00
8A2720	2017-07-19 11:50:00+03	56000.00
8A2736	2017-08-06 05:45:00+03	12400.00
8A2753	2017-07-18 23:48:00+03	14000.00
8A2767	2017-07-03 05:39:00+03	47000.00
8A278F	2017-07-07 04:58:00+03	24800.00
8A279E	2017-07-20 02:05:00+03	98400.00
8A27F7	2017-07-07 14:06:00+03	28800.00
8A2804	2017-07-08 14:08:00+03	11600.00
8A2814	2017-08-05 21:03:00+03	48500.00
8A2882	2017-07-30 07:42:00+03	67600.00
8A2900	2017-08-08 15:32:00+03	13600.00
8A296F	2017-07-09 08:21:00+03	40800.00
8A29A5	2017-08-09 17:51:00+03	190700.00
8A29D6	2017-07-26 03:34:00+03	14400.00
8A2A21	2017-08-11 16:24:00+03	32800.00
8A2A4D	2017-07-14 09:15:00+03	28300.00
8A2ABB	2017-07-14 07:30:00+03	58000.00
8A2ADD	2017-08-05 20:21:00+03	23600.00
8A2B14	2017-07-11 06:42:00+03	20400.00
8A2B7A	2017-07-28 19:39:00+03	40700.00
8A2B8B	2017-07-29 16:50:00+03	27800.00
8A2B9D	2017-07-17 05:51:00+03	56000.00
8A2BF5	2017-07-14 07:39:00+03	53700.00
8A2BF6	2017-07-10 14:46:00+03	57600.00
8A2C5A	2017-07-12 08:26:00+03	61800.00
8A2C9B	2017-07-12 16:45:00+03	31000.00
8A2CB6	2017-07-30 17:56:00+03	59200.00
8A2CC1	2017-08-14 18:59:00+03	48100.00
8A2D1E	2017-08-01 16:31:00+03	28600.00
8A2DBF	2017-08-15 09:02:00+03	37800.00
8A2DD9	2017-08-11 18:00:00+03	24500.00
8A2DFA	2017-07-28 18:48:00+03	23200.00
8A2E39	2017-07-05 18:06:00+03	135600.00
8A2E58	2017-08-10 10:44:00+03	14800.00
8A2E9B	2017-08-14 07:23:00+03	6000.00
8A2EC1	2017-07-31 01:24:00+03	28800.00
8A2F5A	2017-08-01 03:43:00+03	25800.00
8A2FDA	2017-07-27 06:57:00+03	14400.00
8A3001	2017-08-02 03:16:00+03	107400.00
8A3024	2017-07-06 21:40:00+03	75300.00
8A3045	2017-07-01 02:45:00+03	109300.00
8A3073	2017-07-13 11:28:00+03	15000.00
8A3077	2017-07-19 10:19:00+03	62700.00
8A316E	2017-08-02 05:49:00+03	19600.00
8A3193	2017-07-27 21:32:00+03	8000.00
8A3205	2017-08-06 01:02:00+03	16400.00
8A3284	2017-07-30 05:48:00+03	32800.00
8A329F	2017-07-03 18:57:00+03	265700.00
8A32C9	2017-07-30 08:43:00+03	29600.00
8A32D2	2017-07-30 23:04:00+03	381400.00
8A3306	2017-07-21 16:08:00+03	62000.00
8A332B	2017-08-09 04:59:00+03	23200.00
8A3341	2017-08-12 03:36:00+03	48800.00
8A33DE	2017-08-14 16:28:00+03	116400.00
8A3474	2017-08-09 07:00:00+03	120700.00
8A351A	2017-07-23 07:33:00+03	27200.00
8A356A	2017-07-28 11:59:00+03	24400.00
8A3596	2017-08-06 18:03:00+03	131800.00
8A3605	2017-06-29 16:09:00+03	81600.00
8A361D	2017-07-26 17:04:00+03	132800.00
8A366D	2017-07-29 14:29:00+03	101200.00
8A3692	2017-08-04 17:17:00+03	99700.00
8A369C	2017-08-10 02:04:00+03	88100.00
8A36A4	2017-08-09 01:28:00+03	28000.00
8A3773	2017-07-22 03:43:00+03	30800.00
8A3862	2017-07-21 12:15:00+03	21800.00
8A388A	2017-06-29 13:48:00+03	261200.00
8A38D5	2017-07-05 15:25:00+03	28800.00
8A396A	2017-07-02 20:42:00+03	26800.00
8A39C8	2017-07-22 02:59:00+03	110300.00
8A3AD7	2017-07-17 23:52:00+03	68800.00
8A3B36	2017-07-26 22:23:00+03	24400.00
8A3B93	2017-07-14 19:32:00+03	70600.00
8A3BA6	2017-08-02 02:57:00+03	49200.00
8A3BC0	2017-07-12 01:08:00+03	90000.00
8A3CB4	2017-07-02 20:33:00+03	16400.00
8A3D0B	2017-07-29 19:41:00+03	19200.00
8A3D2B	2017-08-08 07:04:00+03	38800.00
8A3D30	2017-08-09 17:14:00+03	136800.00
8A3D51	2017-08-04 18:33:00+03	75600.00
8A3E2B	2017-07-28 06:12:00+03	39100.00
8A3E39	2017-07-21 10:16:00+03	46400.00
8A3E4C	2017-08-03 05:34:00+03	111700.00
8A3E69	2017-08-12 19:38:00+03	6700.00
8A3E7D	2017-08-04 22:25:00+03	22000.00
8A3F0D	2017-07-24 07:29:00+03	25900.00
8A3F56	2017-08-03 02:58:00+03	79600.00
8A3F5E	2017-07-22 07:49:00+03	46000.00
8A3F63	2017-07-14 08:53:00+03	23500.00
8A3FE7	2017-08-07 03:50:00+03	246000.00
8A403D	2017-08-14 23:17:00+03	38800.00
8A4050	2017-07-25 04:46:00+03	99200.00
8A4125	2017-07-14 11:26:00+03	106400.00
8A41AF	2017-07-23 02:51:00+03	80900.00
8A41D9	2017-07-22 23:19:00+03	41800.00
8A41FA	2017-07-22 13:33:00+03	46400.00
8A4222	2017-07-19 18:47:00+03	249000.00
8A4242	2017-08-13 06:27:00+03	99200.00
8A42EE	2017-07-08 07:24:00+03	108500.00
8A4312	2017-08-01 20:03:00+03	651900.00
8A431F	2017-07-29 12:09:00+03	34000.00
8A435A	2017-08-01 14:14:00+03	57500.00
8A43DA	2017-07-09 23:17:00+03	19600.00
8A4404	2017-07-04 14:20:00+03	128800.00
8A4423	2017-08-03 07:38:00+03	61800.00
8A4431	2017-07-10 23:34:00+03	246000.00
8A445D	2017-07-26 14:10:00+03	43700.00
8A4486	2017-07-26 21:28:00+03	59800.00
8A450F	2017-07-20 16:29:00+03	84300.00
8A4521	2017-07-24 18:39:00+03	289800.00
8A4525	2017-07-04 11:00:00+03	36200.00
8A4555	2017-08-10 03:59:00+03	23200.00
8A45DA	2017-07-03 06:55:00+03	415100.00
8A4607	2017-07-26 02:15:00+03	34100.00
8A4631	2017-08-14 08:31:00+03	44000.00
8A46BF	2017-07-14 00:42:00+03	54500.00
8A46D4	2017-07-14 14:43:00+03	21200.00
8A4714	2017-07-11 19:06:00+03	28000.00
8A4821	2017-07-06 03:52:00+03	23600.00
8A4834	2017-07-11 03:26:00+03	73100.00
8A4856	2017-07-10 17:28:00+03	46400.00
8A485D	2017-07-01 09:15:00+03	56000.00
8A48BC	2017-07-22 10:36:00+03	60400.00
8A48C5	2017-08-01 04:32:00+03	64800.00
8A48D8	2017-08-02 04:48:00+03	115600.00
8A491D	2017-07-09 18:05:00+03	193100.00
8A49A9	2017-08-09 01:13:00+03	4000.00
8A49E7	2017-07-29 09:34:00+03	45200.00
8A4A1E	2017-08-13 03:55:00+03	66600.00
8A4A35	2017-08-09 11:29:00+03	45500.00
8A4A60	2017-06-30 09:50:00+03	23600.00
8A4B28	2017-07-30 06:45:00+03	57700.00
8A4B3A	2017-07-17 18:13:00+03	50200.00
8A4BFA	2017-07-03 17:01:00+03	108500.00
8A4C46	2017-08-15 16:57:00+03	31200.00
8A4CB9	2017-07-21 03:42:00+03	26600.00
8A4CD1	2017-08-12 08:50:00+03	12000.00
8A4CDC	2017-08-03 11:05:00+03	52900.00
8A4CE3	2017-07-11 12:08:00+03	49800.00
8A4CFA	2017-07-08 05:39:00+03	24700.00
8A4D2D	2017-07-10 20:08:00+03	24400.00
8A4D2E	2017-07-29 15:07:00+03	44400.00
8A4D73	2017-08-14 19:11:00+03	6400.00
8A4D76	2017-07-13 20:56:00+03	81600.00
8A4E38	2017-08-05 18:30:00+03	25900.00
8A4E8C	2017-08-15 02:28:00+03	61200.00
8A4EBA	2017-08-04 10:07:00+03	46800.00
8A4EBE	2017-07-02 22:58:00+03	103800.00
8A4F15	2017-07-19 11:19:00+03	28000.00
8A4FAB	2017-07-18 22:00:00+03	101300.00
8A502B	2017-08-13 20:32:00+03	92900.00
8A5056	2017-07-31 05:45:00+03	41600.00
8A5115	2017-08-04 23:57:00+03	31600.00
8A5186	2017-07-17 16:59:00+03	54500.00
8A51C2	2017-07-22 19:17:00+03	46000.00
8A5317	2017-08-15 17:24:00+03	68400.00
8A5385	2017-07-03 22:10:00+03	124200.00
8A53A9	2017-07-28 12:25:00+03	72800.00
8A53B7	2017-07-20 13:31:00+03	55800.00
8A53FE	2017-07-28 08:10:00+03	53200.00
8A5410	2017-08-08 22:24:00+03	92900.00
8A541D	2017-08-03 10:31:00+03	17600.00
8A547E	2017-07-01 20:53:00+03	522400.00
8A553A	2017-08-14 12:19:00+03	55800.00
8A5540	2017-08-08 07:38:00+03	28800.00
8A56D3	2017-07-13 14:36:00+03	46000.00
8A56F2	2017-08-11 21:52:00+03	28300.00
8A575D	2017-07-15 03:01:00+03	70600.00
8A5798	2017-08-11 02:19:00+03	15100.00
8A57CB	2017-07-30 10:35:00+03	40100.00
8A5842	2017-07-02 20:57:00+03	128800.00
8A586E	2017-07-31 08:54:00+03	31400.00
8A5870	2017-08-05 22:40:00+03	109600.00
8A5898	2017-07-06 11:45:00+03	35400.00
8A58F8	2017-08-12 21:30:00+03	36900.00
8A590F	2017-07-24 06:54:00+03	89600.00
8A5964	2017-07-17 20:04:00+03	59200.00
8A596E	2017-07-28 14:05:00+03	14000.00
8A5998	2017-07-22 16:40:00+03	89600.00
8A599C	2017-07-16 02:16:00+03	56100.00
8A5A1F	2017-08-06 09:51:00+03	40800.00
8A5A2E	2017-06-27 21:57:00+03	24200.00
8A5A33	2017-08-08 01:53:00+03	20200.00
8A5AB4	2017-07-05 19:13:00+03	62600.00
8A5B17	2017-06-30 14:37:00+03	147000.00
8A5B26	2017-07-11 11:00:00+03	35600.00
8A5B62	2017-06-29 04:48:00+03	312500.00
8A5B7D	2017-06-30 15:47:00+03	156000.00
8A5C40	2017-07-12 09:10:00+03	31600.00
8A5C88	2017-07-11 09:28:00+03	31600.00
8A5C9D	2017-08-01 11:17:00+03	81600.00
8A5CCD	2017-07-29 04:00:00+03	21400.00
8A5D0C	2017-07-04 15:05:00+03	99700.00
8A5D1F	2017-07-05 06:06:00+03	63100.00
8A5DE6	2017-08-13 10:44:00+03	92800.00
8A5E01	2017-07-20 09:49:00+03	35800.00
8A5F6F	2017-08-11 12:48:00+03	24300.00
8A5FC4	2017-07-29 11:54:00+03	39300.00
8A6015	2017-07-26 20:52:00+03	179300.00
8A604D	2017-07-27 21:04:00+03	47200.00
8A605E	2017-06-30 17:15:00+03	69500.00
8A60D7	2017-08-14 23:59:00+03	56000.00
8A60EF	2017-06-30 15:03:00+03	27400.00
8A6127	2017-08-15 17:40:00+03	7200.00
8A612B	2017-08-09 01:45:00+03	12600.00
8A613B	2017-07-04 16:29:00+03	14000.00
8A614F	2017-07-17 12:31:00+03	46400.00
8A6155	2017-07-23 17:54:00+03	112000.00
8A623B	2017-08-14 15:08:00+03	65800.00
8A6298	2017-07-05 12:46:00+03	66000.00
8A62B6	2017-08-07 08:40:00+03	58400.00
8A630A	2017-08-08 06:26:00+03	45100.00
8A6367	2017-07-14 17:21:00+03	23200.00
8A63D2	2017-07-08 23:54:00+03	288600.00
8A63DE	2017-07-21 13:26:00+03	92800.00
8A63F5	2017-08-07 12:52:00+03	25200.00
8A63FA	2017-07-22 18:20:00+03	81800.00
8A6406	2017-07-24 09:10:00+03	23200.00
8A641D	2017-07-24 08:13:00+03	14400.00
8A6424	2017-07-17 05:01:00+03	52900.00
8A6430	2017-08-06 22:22:00+03	42000.00
8A6431	2017-07-28 02:32:00+03	78200.00
8A6444	2017-07-11 00:36:00+03	16000.00
8A64F7	2017-07-02 01:14:00+03	27200.00
8A6500	2017-07-02 04:13:00+03	14800.00
8A65EB	2017-07-29 19:48:00+03	66600.00
8A6632	2017-08-12 01:17:00+03	53600.00
8A6643	2017-07-31 00:13:00+03	26800.00
8A6644	2017-08-07 09:54:00+03	266400.00
8A669E	2017-07-09 19:23:00+03	21400.00
8A669F	2017-07-25 07:45:00+03	46000.00
8A66DF	2017-07-19 02:54:00+03	43800.00
8A66E4	2017-07-24 08:46:00+03	114300.00
8A672F	2017-07-16 09:45:00+03	93800.00
8A6741	2017-07-26 01:29:00+03	560000.00
8A6747	2017-07-28 20:56:00+03	67100.00
8A6764	2017-07-01 15:27:00+03	369000.00
8A677C	2017-07-21 17:04:00+03	12600.00
8A678A	2017-07-06 20:07:00+03	13400.00
8A678F	2017-07-23 18:03:00+03	6600.00
8A67BA	2017-07-11 18:15:00+03	28000.00
8A6849	2017-08-10 12:01:00+03	199600.00
8A6850	2017-08-12 04:02:00+03	73600.00
8A689A	2017-07-28 17:15:00+03	89700.00
8A6963	2017-08-14 19:22:00+03	8200.00
8A6B11	2017-07-12 00:44:00+03	643800.00
8A6B1E	2017-07-24 20:35:00+03	64700.00
8A6B2F	2017-08-03 03:21:00+03	102100.00
8A6B47	2017-08-02 10:41:00+03	90700.00
8A6B81	2017-08-13 04:48:00+03	46400.00
8A6C1C	2017-07-25 02:43:00+03	47000.00
8A6CA6	2017-07-09 16:54:00+03	38400.00
8A6CD1	2017-08-02 10:11:00+03	76400.00
8A6CD7	2017-07-13 06:45:00+03	26000.00
8A6D2D	2017-07-05 01:13:00+03	12000.00
8A6DBC	2017-07-21 21:50:00+03	84000.00
8A6E24	2017-07-04 19:22:00+03	39200.00
8A6E33	2017-08-06 16:43:00+03	111600.00
8A6E67	2017-07-09 22:03:00+03	25200.00
8A6EDB	2017-07-18 06:18:00+03	65500.00
8A6EEA	2017-07-30 16:44:00+03	40000.00
8A6F65	2017-07-28 02:54:00+03	33300.00
8A6F8C	2017-07-26 10:43:00+03	38400.00
8A6FB8	2017-07-08 14:40:00+03	86400.00
8A6FDF	2017-08-11 07:02:00+03	47100.00
8A6FE2	2017-08-05 02:19:00+03	151200.00
8A7027	2017-08-03 05:06:00+03	16800.00
8A705B	2017-07-27 16:01:00+03	48800.00
8A7061	2017-07-24 10:58:00+03	20400.00
8A7066	2017-07-13 00:27:00+03	110000.00
8A70CB	2017-07-04 23:45:00+03	28000.00
8A7109	2017-07-12 08:30:00+03	413400.00
8A711B	2017-08-06 17:11:00+03	265600.00
8A7126	2017-07-23 20:16:00+03	152900.00
8A713C	2017-07-04 08:50:00+03	84500.00
8A7182	2017-07-19 02:41:00+03	114800.00
8A71EC	2017-07-25 01:49:00+03	31400.00
8A729D	2017-07-08 20:19:00+03	23500.00
8A72A7	2017-08-15 17:46:00+03	229900.00
8A73A3	2017-07-30 10:26:00+03	23200.00
8A7439	2017-07-25 22:05:00+03	56000.00
8A745F	2017-07-14 18:30:00+03	75600.00
8A7485	2017-07-01 22:04:00+03	28000.00
8A7493	2017-07-29 08:36:00+03	59800.00
8A74A0	2017-07-26 11:02:00+03	56000.00
8A74E6	2017-07-10 10:51:00+03	62000.00
8A74EC	2017-07-22 12:14:00+03	75300.00
8A754D	2017-08-08 21:56:00+03	14400.00
8A758A	2017-07-18 23:31:00+03	6700.00
8A75AD	2017-08-12 13:44:00+03	20600.00
8A75AE	2017-07-13 05:57:00+03	47000.00
8A7603	2017-08-08 15:01:00+03	64800.00
8A763A	2017-08-06 12:19:00+03	50600.00
8A763B	2017-07-11 15:47:00+03	36200.00
8A7645	2017-08-13 16:33:00+03	24800.00
8A7656	2017-07-17 19:36:00+03	78600.00
8A766C	2017-07-11 09:33:00+03	19800.00
8A7679	2017-07-06 06:58:00+03	21500.00
8A76AF	2017-07-30 23:38:00+03	144000.00
8A76FB	2017-07-20 12:20:00+03	173400.00
8A7727	2017-07-06 23:06:00+03	57300.00
8A7772	2017-08-04 19:04:00+03	34000.00
8A77A4	2017-07-29 17:40:00+03	46200.00
8A7850	2017-07-12 11:28:00+03	37200.00
8A78AB	2017-07-24 00:50:00+03	26200.00
8A78CC	2017-08-09 14:17:00+03	14000.00
8A78FE	2017-08-13 10:21:00+03	48400.00
8A7916	2017-07-18 10:29:00+03	68400.00
8A7917	2017-08-07 05:13:00+03	58400.00
8A792A	2017-08-05 13:08:00+03	80000.00
8A793F	2017-07-17 13:05:00+03	32700.00
8A797F	2017-07-28 18:18:00+03	20400.00
8A79DC	2017-08-14 05:13:00+03	55800.00
8A79E6	2017-07-28 15:51:00+03	271200.00
8A79F5	2017-07-25 00:39:00+03	26800.00
8A7A3E	2017-08-15 01:03:00+03	39100.00
8A7AB4	2017-06-29 08:28:00+03	30200.00
8A7AE5	2017-08-03 04:34:00+03	136800.00
8A7AFE	2017-07-11 22:12:00+03	47700.00
8A7B1F	2017-08-14 22:35:00+03	98300.00
8A7B69	2017-08-12 06:03:00+03	10700.00
8A7B8E	2017-08-12 02:14:00+03	85000.00
8A7BBE	2017-08-04 18:32:00+03	17800.00
8A7C12	2017-08-14 19:48:00+03	105600.00
8A7C48	2017-07-22 05:08:00+03	32400.00
8A7C64	2017-08-10 06:48:00+03	301800.00
8A7CD5	2017-08-09 03:02:00+03	156300.00
8A7CD8	2017-07-08 18:54:00+03	81200.00
8A7D63	2017-07-08 01:53:00+03	24800.00
8A7D65	2017-07-11 23:50:00+03	47600.00
8A7D9D	2017-08-01 17:45:00+03	40800.00
8A7E32	2017-08-07 20:23:00+03	89700.00
8A7ECD	2017-07-11 01:42:00+03	43500.00
8A7EDF	2017-07-07 05:53:00+03	24400.00
8A7F0A	2017-08-03 13:03:00+03	96300.00
8A7F26	2017-07-04 09:38:00+03	55800.00
8A8015	2017-08-14 15:57:00+03	152700.00
8A8025	2017-07-27 11:47:00+03	23200.00
8A802B	2017-07-07 11:27:00+03	106100.00
8A803A	2017-07-07 04:42:00+03	64800.00
8A8062	2017-07-17 21:44:00+03	23600.00
8A8081	2017-07-19 06:46:00+03	15000.00
8A80B3	2017-07-29 03:03:00+03	25200.00
8A80EC	2017-07-17 02:18:00+03	196600.00
8A8104	2017-07-22 21:28:00+03	51200.00
8A8111	2017-08-03 02:19:00+03	113300.00
8A817C	2017-08-06 10:29:00+03	190700.00
8A81BA	2017-07-10 01:20:00+03	84000.00
8A81C0	2017-08-03 02:31:00+03	57300.00
8A81E3	2017-08-08 11:17:00+03	56000.00
8A81E5	2017-07-12 16:45:00+03	81900.00
8A81EA	2017-08-10 05:53:00+03	133100.00
8A81EB	2017-08-04 22:05:00+03	60800.00
8A8204	2017-07-20 14:12:00+03	246000.00
8A821D	2017-08-11 05:39:00+03	56000.00
8A8235	2017-07-09 20:02:00+03	265700.00
8A8262	2017-07-20 12:43:00+03	64800.00
8A829B	2017-08-04 12:19:00+03	28800.00
8A82B5	2017-07-09 03:44:00+03	78200.00
8A82C9	2017-07-07 22:20:00+03	114600.00
8A8306	2017-07-29 20:55:00+03	142400.00
8A832C	2017-06-29 00:20:00+03	141000.00
8A8352	2017-08-14 10:44:00+03	47200.00
8A836D	2017-08-07 12:19:00+03	139200.00
8A840E	2017-07-25 13:25:00+03	69500.00
8A842F	2017-08-13 08:59:00+03	14400.00
8A845F	2017-07-14 14:01:00+03	179900.00
8A8472	2017-08-13 18:18:00+03	38400.00
8A85E6	2017-08-09 12:14:00+03	40800.00
8A85E8	2017-07-20 11:04:00+03	26000.00
8A85FB	2017-08-11 05:17:00+03	167400.00
8A8663	2017-07-09 02:34:00+03	57500.00
8A868B	2017-07-29 14:11:00+03	29600.00
8A871E	2017-06-24 07:19:00+03	481800.00
8A872F	2017-07-31 00:50:00+03	56000.00
8A8771	2017-07-27 11:57:00+03	29600.00
8A87B2	2017-07-06 12:15:00+03	23400.00
8A880A	2017-08-01 17:13:00+03	23600.00
8A88B8	2017-07-17 05:05:00+03	103500.00
8A88D2	2017-07-16 01:21:00+03	76600.00
8A88FF	2017-07-14 15:26:00+03	47400.00
8A89DF	2017-08-11 22:58:00+03	16400.00
8A8A40	2017-08-05 08:40:00+03	49800.00
8A8A6B	2017-08-04 06:38:00+03	28800.00
8A8A79	2017-08-04 00:40:00+03	45200.00
8A8B26	2017-08-07 16:38:00+03	61800.00
8A8B59	2017-07-23 22:33:00+03	51300.00
8A8B79	2017-07-08 16:07:00+03	67600.00
8A8C18	2017-07-05 10:21:00+03	38300.00
8A8C55	2017-08-06 02:58:00+03	38600.00
8A8C95	2017-08-08 12:33:00+03	76600.00
8A8CC8	2017-07-18 07:49:00+03	28000.00
8A8D11	2017-08-02 11:06:00+03	42700.00
8A8D37	2017-08-04 20:37:00+03	60700.00
8A8D61	2017-08-03 12:11:00+03	30200.00
8A8D93	2017-07-09 21:27:00+03	48100.00
8A8DDF	2017-07-08 23:32:00+03	6000.00
8A8DF8	2017-07-20 21:57:00+03	28000.00
8A8E27	2017-08-08 21:01:00+03	145700.00
8A8E67	2017-07-14 00:24:00+03	28800.00
8A8E76	2017-07-21 02:01:00+03	143100.00
8A8F7B	2017-07-07 03:46:00+03	133200.00
8A8FB3	2017-07-06 15:32:00+03	8200.00
8A9028	2017-07-31 09:24:00+03	21800.00
8A904E	2017-07-06 06:20:00+03	123000.00
8A90EF	2017-07-16 03:26:00+03	50800.00
8A911C	2017-07-13 16:39:00+03	98400.00
8A9193	2017-08-14 19:14:00+03	46400.00
8A91E3	2017-08-12 00:46:00+03	67100.00
8A91E6	2017-07-16 09:01:00+03	20600.00
8A925B	2017-07-24 03:01:00+03	131800.00
8A926A	2017-07-16 09:44:00+03	47100.00
8A926B	2017-07-07 21:46:00+03	35600.00
8A927E	2017-07-23 08:31:00+03	13400.00
8A92D7	2017-07-25 15:34:00+03	23600.00
8A92DF	2017-08-08 16:22:00+03	22400.00
8A9310	2017-07-01 01:19:00+03	104600.00
8A933C	2017-07-02 01:30:00+03	50300.00
8A9340	2017-07-05 03:50:00+03	67600.00
8A93CF	2017-08-09 17:14:00+03	77200.00
8A93FF	2017-07-22 08:01:00+03	579800.00
8A940A	2017-07-22 19:56:00+03	99300.00
8A942A	2017-07-06 05:04:00+03	6700.00
8A942B	2017-08-15 01:47:00+03	18900.00
8A94CE	2017-07-12 16:04:00+03	47600.00
8A9544	2017-07-25 10:48:00+03	90800.00
8A95A6	2017-07-20 14:42:00+03	80000.00
8A95CA	2017-07-27 14:20:00+03	37100.00
8A95DA	2017-08-06 21:40:00+03	47700.00
8A965E	2017-07-26 19:02:00+03	25600.00
8A968C	2017-08-04 16:03:00+03	116400.00
8A96D8	2017-07-29 05:47:00+03	336700.00
8A970D	2017-08-10 15:29:00+03	73600.00
8A9832	2017-07-10 04:04:00+03	16400.00
8A9868	2017-07-15 20:49:00+03	7800.00
8A989C	2017-07-19 00:57:00+03	115600.00
8A98D8	2017-08-03 19:11:00+03	23600.00
8A98DD	2017-07-12 18:30:00+03	54400.00
8A98E9	2017-07-09 09:29:00+03	19600.00
8A98F4	2017-07-27 07:23:00+03	57600.00
8A9913	2017-07-12 03:48:00+03	160800.00
8A996F	2017-07-15 00:56:00+03	38600.00
8A999D	2017-07-14 19:44:00+03	133200.00
8A99AA	2017-07-13 06:58:00+03	44100.00
8A99F9	2017-08-10 16:20:00+03	162700.00
8A9A25	2017-07-20 21:14:00+03	68800.00
8A9A47	2017-08-10 02:33:00+03	12000.00
8A9A74	2017-08-04 11:39:00+03	22600.00
8A9B0E	2017-07-18 20:36:00+03	172100.00
8A9B17	2017-08-10 06:09:00+03	46200.00
8A9BAB	2017-07-07 07:46:00+03	28800.00
8A9BFA	2017-07-08 06:27:00+03	51900.00
8A9C2C	2017-08-06 02:50:00+03	136200.00
8A9D50	2017-07-05 11:03:00+03	46400.00
8A9D69	2017-07-17 17:14:00+03	19600.00
8A9DC4	2017-08-15 11:25:00+03	40600.00
8A9E4D	2017-08-04 13:15:00+03	55800.00
8A9EDA	2017-07-30 01:56:00+03	6300.00
8A9F2B	2017-08-04 06:16:00+03	31000.00
8A9F51	2017-07-17 02:27:00+03	22000.00
8A9FBD	2017-07-21 05:37:00+03	78600.00
8AA05A	2017-07-05 13:47:00+03	87200.00
8AA066	2017-07-28 01:19:00+03	24000.00
8AA0A0	2017-08-13 12:16:00+03	60700.00
8AA182	2017-06-27 08:31:00+03	363800.00
8AA18A	2017-07-16 06:57:00+03	28000.00
8AA18B	2017-07-03 15:34:00+03	266200.00
8AA1AF	2017-07-02 20:40:00+03	60300.00
8AA1CA	2017-07-22 16:05:00+03	75000.00
8AA22D	2017-07-03 00:49:00+03	76800.00
8AA236	2017-07-15 01:50:00+03	118600.00
8AA24A	2017-08-14 15:05:00+03	26200.00
8AA2A0	2017-07-21 17:05:00+03	34800.00
8AA2A3	2017-07-21 00:15:00+03	100000.00
8AA2D0	2017-08-15 08:53:00+03	171900.00
8AA2FD	2017-08-09 07:24:00+03	34000.00
8AA450	2017-07-09 16:40:00+03	51800.00
8AA4D2	2017-08-13 12:28:00+03	62600.00
8AA50F	2017-07-30 06:16:00+03	154400.00
8AA517	2017-08-05 06:38:00+03	76400.00
8AA548	2017-08-08 15:47:00+03	12600.00
8AA666	2017-07-29 04:28:00+03	51600.00
8AA805	2017-07-14 09:36:00+03	27200.00
8AA80E	2017-08-14 13:33:00+03	241800.00
8AA88B	2017-08-02 15:33:00+03	22600.00
8AA8BF	2017-07-09 11:38:00+03	53300.00
8AA934	2017-08-13 17:49:00+03	51600.00
8AA937	2017-08-05 02:20:00+03	48600.00
8AA996	2017-07-05 01:04:00+03	56900.00
8AA997	2017-07-15 11:15:00+03	6700.00
8AA9FC	2017-08-03 10:04:00+03	15100.00
8AAA40	2017-07-07 04:40:00+03	56900.00
8AAA5E	2017-08-14 03:47:00+03	50000.00
8AAAC1	2017-08-12 19:09:00+03	134400.00
8AAADC	2017-08-05 00:44:00+03	48800.00
8AAAF1	2017-07-21 03:38:00+03	13600.00
8AAB3A	2017-07-23 22:03:00+03	26000.00
8AAB70	2017-08-06 13:21:00+03	138100.00
8AABA5	2017-06-30 11:59:00+03	55600.00
8AABBC	2017-07-27 05:24:00+03	52000.00
8AAC10	2017-07-09 14:23:00+03	28000.00
8AAC13	2017-07-19 17:03:00+03	66600.00
8AAC2A	2017-08-04 11:02:00+03	12600.00
8AACDD	2017-07-03 09:01:00+03	12000.00
8AAD2C	2017-07-05 07:55:00+03	19600.00
8AAD52	2017-08-09 10:06:00+03	179300.00
8AAD57	2017-07-04 13:37:00+03	99300.00
8AAD87	2017-07-31 17:41:00+03	15400.00
8AAE06	2017-08-10 09:16:00+03	91800.00
8AAE33	2017-07-05 00:41:00+03	39500.00
8AAE5D	2017-07-14 19:18:00+03	370800.00
8AAE8A	2017-07-10 02:43:00+03	36400.00
8AAE92	2017-08-11 14:55:00+03	135400.00
8AAF0E	2017-07-17 10:24:00+03	24400.00
8AB08F	2017-07-24 11:26:00+03	15400.00
8AB0A1	2017-08-14 05:09:00+03	6700.00
8AB0EA	2017-07-11 14:40:00+03	29400.00
8AB15E	2017-08-06 19:12:00+03	23200.00
8AB16D	2017-07-09 08:04:00+03	14800.00
8AB191	2017-07-09 09:48:00+03	46400.00
8AB192	2017-07-14 16:13:00+03	92800.00
8AB215	2017-07-14 16:41:00+03	136800.00
8AB239	2017-08-11 08:02:00+03	139300.00
8AB2C4	2017-07-30 01:54:00+03	32700.00
8AB2F0	2017-07-27 11:06:00+03	26000.00
8AB308	2017-08-09 17:44:00+03	137800.00
8AB335	2017-07-10 01:15:00+03	260900.00
8AB338	2017-07-29 17:14:00+03	77200.00
8AB41D	2017-08-15 08:49:00+03	47000.00
8AB45B	2017-08-03 11:47:00+03	122300.00
8AB4AF	2017-07-12 06:16:00+03	11200.00
8AB522	2017-07-09 13:59:00+03	81600.00
8AB615	2017-08-08 10:55:00+03	53500.00
8AB669	2017-07-14 11:50:00+03	70600.00
8AB68D	2017-07-21 00:33:00+03	183100.00
8AB716	2017-07-02 01:57:00+03	88100.00
8AB7F1	2017-07-05 10:14:00+03	143100.00
8AB989	2017-07-06 19:32:00+03	24400.00
8AB9A4	2017-08-11 19:38:00+03	156000.00
8AB9D2	2017-08-06 16:28:00+03	36200.00
8ABA3E	2017-07-25 14:45:00+03	29400.00
8ABA80	2017-08-04 19:16:00+03	432600.00
8ABAAC	2017-07-27 14:59:00+03	67200.00
8ABAE1	2017-07-23 18:24:00+03	57500.00
8ABB84	2017-07-28 01:37:00+03	36200.00
8ABBDD	2017-07-18 12:19:00+03	167500.00
8ABBF5	2017-07-29 21:01:00+03	24400.00
8ABC16	2017-07-19 09:53:00+03	86300.00
8ABC42	2017-07-23 05:21:00+03	111600.00
8ABC4F	2017-07-30 04:34:00+03	27200.00
8ABC5F	2017-08-14 00:01:00+03	22400.00
8ABC6F	2017-07-03 05:20:00+03	47400.00
8ABC8A	2017-07-28 09:23:00+03	46300.00
8ABCA6	2017-08-04 20:23:00+03	36200.00
8ABCAC	2017-08-13 23:02:00+03	65900.00
8ABD5E	2017-07-04 14:27:00+03	38000.00
8ABDB8	2017-07-18 17:19:00+03	21400.00
8ABDD8	2017-07-22 19:54:00+03	291500.00
8ABE04	2017-07-04 18:40:00+03	30400.00
8ABE25	2017-08-02 12:36:00+03	265700.00
8ABE53	2017-07-10 00:35:00+03	136600.00
8ABE73	2017-07-17 14:30:00+03	32800.00
8ABF05	2017-07-10 19:01:00+03	31400.00
8ABF5F	2017-07-04 20:14:00+03	50800.00
8ABF85	2017-08-02 02:32:00+03	8400.00
8ABFAF	2017-08-13 11:06:00+03	67600.00
8ABFC0	2017-07-04 18:15:00+03	68100.00
8ABFF6	2017-07-10 05:32:00+03	19600.00
8AC06F	2017-08-08 12:32:00+03	643700.00
8AC098	2017-07-06 05:00:00+03	85000.00
8AC0F7	2017-07-30 16:09:00+03	6600.00
8AC114	2017-06-28 06:31:00+03	33100.00
8AC116	2017-07-28 08:38:00+03	36200.00
8AC124	2017-07-17 10:33:00+03	209100.00
8AC279	2017-08-10 04:27:00+03	59800.00
8AC2D2	2017-07-19 16:42:00+03	6000.00
8AC2FD	2017-08-05 17:21:00+03	93000.00
8AC305	2017-07-04 06:56:00+03	156000.00
8AC331	2017-08-14 11:10:00+03	290400.00
8AC3C6	2017-08-09 07:06:00+03	6000.00
8AC432	2017-07-24 05:20:00+03	115400.00
8AC475	2017-07-17 10:43:00+03	50400.00
8AC489	2017-08-13 09:22:00+03	40800.00
8AC4A1	2017-06-29 12:49:00+03	81600.00
8AC50B	2017-08-04 10:46:00+03	74400.00
8AC594	2017-07-09 14:37:00+03	100600.00
8AC5F9	2017-07-18 14:33:00+03	18600.00
8AC612	2017-07-25 20:50:00+03	40000.00
8AC643	2017-07-30 14:15:00+03	84500.00
8AC64B	2017-07-11 21:48:00+03	152900.00
8AC662	2017-07-11 09:49:00+03	55800.00
8AC695	2017-08-13 09:22:00+03	133200.00
8AC699	2017-07-10 09:58:00+03	192700.00
8AC6C7	2017-07-13 07:57:00+03	88200.00
8AC736	2017-07-05 16:10:00+03	6000.00
8AC758	2017-07-24 16:17:00+03	37300.00
8AC763	2017-07-12 00:11:00+03	70700.00
8AC76D	2017-07-30 05:04:00+03	133200.00
8AC7D0	2017-08-10 17:18:00+03	6000.00
8AC8B3	2017-08-06 17:03:00+03	24400.00
8AC8BC	2017-08-04 23:37:00+03	31200.00
8AC8CD	2017-07-14 09:15:00+03	47400.00
8AC901	2017-07-21 22:04:00+03	58600.00
8AC941	2017-08-08 01:26:00+03	28700.00
8AC96A	2017-07-13 17:54:00+03	56000.00
8AC994	2017-07-03 15:53:00+03	25600.00
8AC998	2017-07-03 01:39:00+03	151200.00
8AC9AB	2017-08-14 19:31:00+03	40000.00
8AC9AF	2017-08-11 06:09:00+03	62400.00
8ACA3F	2017-07-26 20:52:00+03	92800.00
8ACAD3	2017-07-25 14:05:00+03	6700.00
8ACBEF	2017-06-30 00:29:00+03	61800.00
8ACC06	2017-08-02 23:15:00+03	47900.00
8ACC32	2017-08-06 03:19:00+03	85200.00
8ACC4B	2017-07-02 21:52:00+03	246200.00
8ACC86	2017-08-01 20:05:00+03	34000.00
8ACC8A	2017-08-04 14:33:00+03	81700.00
8ACCEC	2017-08-06 14:50:00+03	34600.00
8ACD8E	2017-07-24 19:20:00+03	73600.00
8ACE0E	2017-08-09 18:50:00+03	92800.00
8ACE1F	2017-07-02 11:02:00+03	11700.00
8ACE23	2017-07-28 15:32:00+03	75300.00
8ACE38	2017-07-19 11:19:00+03	95600.00
8ACE67	2017-07-31 00:11:00+03	48800.00
8ACE69	2017-08-01 06:11:00+03	53700.00
8ACE87	2017-07-18 04:07:00+03	195800.00
8ACEB9	2017-07-20 16:08:00+03	19800.00
8ACED9	2017-08-09 16:39:00+03	86600.00
8ACF19	2017-08-06 08:13:00+03	167400.00
8ACF66	2017-07-31 09:55:00+03	270800.00
8AD013	2017-07-08 12:00:00+03	28700.00
8AD039	2017-07-19 23:40:00+03	326300.00
8AD058	2017-07-25 10:32:00+03	123000.00
8AD07C	2017-07-06 13:34:00+03	56000.00
8AD08F	2017-07-20 11:42:00+03	27200.00
8AD0B8	2017-07-28 12:26:00+03	14000.00
8AD15A	2017-07-25 18:09:00+03	157000.00
8AD1CB	2017-07-13 17:18:00+03	6000.00
8AD1CD	2017-07-02 12:48:00+03	28800.00
8AD212	2017-07-18 18:54:00+03	607600.00
8AD218	2017-07-27 23:50:00+03	19600.00
8AD29E	2017-07-05 22:38:00+03	111600.00
8AD2D1	2017-07-04 06:24:00+03	230500.00
8AD2DB	2017-07-23 02:23:00+03	60200.00
8AD345	2017-07-09 04:45:00+03	6700.00
8AD3FC	2017-07-20 01:32:00+03	260300.00
8AD400	2017-07-17 23:38:00+03	118000.00
8AD417	2017-07-04 21:34:00+03	16400.00
8AD460	2017-07-28 13:28:00+03	66800.00
8AD462	2017-08-12 09:22:00+03	19800.00
8AD482	2017-07-19 10:59:00+03	28000.00
8AD4A0	2017-07-09 01:33:00+03	24800.00
8AD4B1	2017-07-14 14:16:00+03	40800.00
8AD503	2017-07-29 14:26:00+03	62000.00
8AD52B	2017-07-03 08:41:00+03	31600.00
8AD6AA	2017-07-18 12:15:00+03	45200.00
8AD6C9	2017-07-16 07:59:00+03	40800.00
8AD6E1	2017-07-22 15:20:00+03	133700.00
8AD6FB	2017-08-10 12:29:00+03	147700.00
8AD7B3	2017-08-11 00:58:00+03	111600.00
8AD7DF	2017-07-14 18:58:00+03	162400.00
8AD848	2017-07-18 13:10:00+03	23200.00
8AD86C	2017-07-22 09:14:00+03	52000.00
8AD8A4	2017-08-01 14:28:00+03	76000.00
8AD8BE	2017-07-03 15:31:00+03	32800.00
8AD91A	2017-08-06 00:34:00+03	62800.00
8AD998	2017-08-12 04:04:00+03	66900.00
8ADA24	2017-07-01 17:35:00+03	13400.00
8ADA57	2017-08-15 10:33:00+03	31200.00
8ADACC	2017-07-05 19:32:00+03	28000.00
8ADACE	2017-07-09 05:53:00+03	28800.00
8ADAD0	2017-08-13 08:42:00+03	46700.00
8ADB22	2017-07-12 12:10:00+03	48900.00
8ADB3C	2017-07-22 22:16:00+03	94700.00
8ADB40	2017-07-20 15:52:00+03	199700.00
8ADBDC	2017-07-04 09:41:00+03	37200.00
8ADC7D	2017-07-17 10:22:00+03	90800.00
8ADD90	2017-06-30 19:36:00+03	116000.00
8ADEC5	2017-08-04 15:49:00+03	64100.00
8ADF38	2017-07-16 01:55:00+03	12000.00
8ADF3C	2017-06-30 03:35:00+03	47800.00
8ADF5F	2017-06-26 09:04:00+03	13200.00
8ADF83	2017-07-11 15:00:00+03	98400.00
8ADFE3	2017-07-19 14:54:00+03	22600.00
8AE0E4	2017-07-10 13:44:00+03	57100.00
8AE0EA	2017-08-01 23:23:00+03	21600.00
8AE0F6	2017-07-14 14:31:00+03	46400.00
8AE1A2	2017-07-25 20:46:00+03	115800.00
8AE1BA	2017-07-24 08:54:00+03	99200.00
8AE1FF	2017-08-01 03:59:00+03	80700.00
8AE235	2017-07-11 02:35:00+03	187600.00
8AE294	2017-07-04 10:02:00+03	30200.00
8AE2D9	2017-07-30 01:49:00+03	56600.00
8AE317	2017-07-17 13:33:00+03	11600.00
8AE33A	2017-06-29 08:55:00+03	49900.00
8AE355	2017-08-08 20:16:00+03	112000.00
8AE3A1	2017-07-29 13:37:00+03	123000.00
8AE3D1	2017-07-24 01:13:00+03	152200.00
8AE3E2	2017-07-19 23:54:00+03	40900.00
8AE3FA	2017-08-03 17:21:00+03	37600.00
8AE438	2017-07-14 16:37:00+03	146300.00
8AE486	2017-07-08 09:57:00+03	56000.00
8AE4AC	2017-08-14 04:10:00+03	48100.00
8AE4AD	2017-07-18 02:31:00+03	59800.00
8AE4E2	2017-07-12 17:43:00+03	75800.00
8AE566	2017-07-02 05:07:00+03	492000.00
8AE619	2017-08-05 09:55:00+03	43800.00
8AE622	2017-07-12 19:56:00+03	67500.00
8AE65C	2017-07-05 06:57:00+03	64600.00
8AE6E8	2017-08-02 11:06:00+03	28000.00
8AE79F	2017-07-30 04:28:00+03	36800.00
8AE7B3	2017-08-03 09:39:00+03	56000.00
8AE7CE	2017-07-24 02:41:00+03	149300.00
8AE82B	2017-07-19 22:39:00+03	141600.00
8AE85C	2017-07-09 12:57:00+03	41400.00
8AE8CF	2017-08-04 00:50:00+03	170600.00
8AE916	2017-08-05 11:07:00+03	87000.00
8AE91B	2017-08-10 21:07:00+03	114700.00
8AE92E	2017-07-26 09:56:00+03	19600.00
8AE994	2017-07-02 02:30:00+03	85000.00
8AE9A2	2017-07-02 22:57:00+03	23200.00
8AE9C7	2017-07-17 12:23:00+03	118900.00
8AE9EC	2017-08-05 09:56:00+03	16400.00
8AEA27	2017-08-10 02:37:00+03	521800.00
8AEA47	2017-08-13 06:27:00+03	32800.00
8AEA49	2017-08-14 06:25:00+03	23100.00
8AEA4A	2017-06-29 23:53:00+03	179400.00
8AEAA5	2017-07-27 16:15:00+03	14400.00
8AEAA8	2017-07-15 06:01:00+03	22100.00
8AEAB2	2017-08-01 15:30:00+03	199100.00
8AEAD5	2017-07-17 16:14:00+03	21700.00
8AEADE	2017-07-04 10:42:00+03	40400.00
8AEB4D	2017-08-11 01:32:00+03	6000.00
8AEB99	2017-08-06 23:35:00+03	12600.00
8AEBBA	2017-07-10 18:48:00+03	22000.00
8AEBD6	2017-07-17 01:25:00+03	124200.00
8AEC45	2017-07-09 15:01:00+03	131100.00
8AEC8A	2017-08-01 12:37:00+03	26000.00
8AECC3	2017-08-09 06:29:00+03	62100.00
8AECDE	2017-08-12 05:32:00+03	79000.00
8AED1A	2017-07-27 13:55:00+03	98100.00
8AED38	2017-07-03 21:49:00+03	46800.00
8AEDA2	2017-07-12 12:04:00+03	100600.00
8AEDA9	2017-08-01 03:09:00+03	29300.00
8AEE23	2017-08-14 19:13:00+03	30200.00
8AEE7D	2017-07-06 09:31:00+03	106400.00
8AEE96	2017-07-21 18:48:00+03	81700.00
8AEEA9	2017-08-15 09:47:00+03	36200.00
8AEF62	2017-08-04 21:04:00+03	62800.00
8AEFAC	2017-07-10 18:33:00+03	67500.00
8AF01B	2017-07-05 01:39:00+03	29600.00
8AF034	2017-07-17 09:37:00+03	45200.00
8AF03D	2017-08-02 11:41:00+03	37900.00
8AF08A	2017-08-01 23:11:00+03	92900.00
8AF0BD	2017-08-11 10:27:00+03	85700.00
8AF0C2	2017-07-06 13:46:00+03	13600.00
8AF208	2017-08-14 20:30:00+03	34000.00
8AF2AA	2017-06-29 00:52:00+03	23200.00
8AF305	2017-08-07 15:52:00+03	111700.00
8AF306	2017-08-06 17:28:00+03	73200.00
8AF30B	2017-07-31 06:22:00+03	36200.00
8AF316	2017-07-12 00:24:00+03	69000.00
8AF322	2017-08-07 15:09:00+03	99200.00
8AF3E1	2017-08-12 08:12:00+03	25600.00
8AF423	2017-07-17 17:56:00+03	46500.00
8AF472	2017-06-30 07:49:00+03	11800.00
8AF49C	2017-07-21 07:55:00+03	84500.00
8AF4FF	2017-07-07 17:45:00+03	123000.00
8AF521	2017-08-05 03:42:00+03	55800.00
8AF598	2017-07-06 12:43:00+03	210000.00
8AF615	2017-06-30 18:57:00+03	27200.00
8AF625	2017-08-12 07:53:00+03	14000.00
8AF663	2017-08-08 21:31:00+03	33600.00
8AF69E	2017-08-07 18:15:00+03	21200.00
8AF6B0	2017-07-06 21:39:00+03	23200.00
8AF6C3	2017-07-13 12:43:00+03	26800.00
8AF709	2017-08-10 13:08:00+03	84500.00
8AF72B	2017-07-24 20:07:00+03	105400.00
8AF740	2017-06-29 23:08:00+03	175800.00
8AF768	2017-07-29 05:29:00+03	72300.00
8AF7FF	2017-08-12 04:30:00+03	69100.00
8AF859	2017-07-15 12:26:00+03	73300.00
8AF8AA	2017-08-05 11:57:00+03	20500.00
8AF9CF	2017-08-13 15:00:00+03	103200.00
8AF9EF	2017-08-15 15:45:00+03	92100.00
8AF9FE	2017-07-21 18:57:00+03	124200.00
8AFA06	2017-08-05 03:04:00+03	34300.00
8AFA1F	2017-07-20 01:20:00+03	69500.00
8AFAB9	2017-08-12 03:24:00+03	67200.00
8AFB57	2017-07-06 04:21:00+03	49200.00
8AFC3F	2017-07-19 17:32:00+03	141300.00
8AFCA8	2017-08-03 23:36:00+03	83000.00
8AFCA9	2017-07-13 15:07:00+03	187800.00
8AFCBD	2017-07-12 09:18:00+03	38800.00
8AFCD5	2017-08-01 18:26:00+03	99800.00
8AFD12	2017-08-15 09:34:00+03	49800.00
8AFD17	2017-07-21 14:34:00+03	240800.00
8AFD54	2017-08-13 19:08:00+03	16400.00
8AFD9E	2017-07-25 16:19:00+03	66100.00
8AFDFF	2017-07-21 01:20:00+03	63500.00
8AFE43	2017-07-31 06:23:00+03	116000.00
8AFE75	2017-07-07 07:58:00+03	57500.00
8AFE83	2017-07-26 07:09:00+03	13600.00
8AFE92	2017-07-20 20:04:00+03	29000.00
8AFEB3	2017-08-06 18:16:00+03	92800.00
8AFEC8	2017-07-25 22:34:00+03	34000.00
8AFEEB	2017-07-03 03:35:00+03	393800.00
8AFF0E	2017-08-02 15:18:00+03	11800.00
8AFF32	2017-07-08 16:22:00+03	193700.00
8AFF65	2017-07-19 09:42:00+03	56600.00
8AFF7C	2017-07-16 12:47:00+03	6700.00
8AFFA7	2017-07-05 22:58:00+03	101500.00
8AFFFA	2017-07-11 09:36:00+03	125600.00
8B002C	2017-08-06 13:35:00+03	67600.00
8B008D	2017-07-06 14:13:00+03	89600.00
8B00BE	2017-07-21 02:22:00+03	101200.00
8B00F8	2017-07-31 17:38:00+03	85000.00
8B0106	2017-07-27 10:50:00+03	203000.00
8B0113	2017-07-24 13:38:00+03	57600.00
8B0148	2017-07-27 17:04:00+03	47100.00
8B0192	2017-07-02 19:48:00+03	94900.00
8B01A9	2017-07-11 17:06:00+03	28800.00
8B01EA	2017-07-20 00:55:00+03	94700.00
8B0236	2017-08-13 15:28:00+03	56000.00
8B0246	2017-07-21 23:42:00+03	6800.00
8B0250	2017-08-06 23:20:00+03	136200.00
8B02BB	2017-07-01 09:47:00+03	60600.00
8B02D7	2017-07-20 13:29:00+03	56000.00
8B032F	2017-07-12 13:01:00+03	38800.00
8B0335	2017-07-10 09:09:00+03	42700.00
8B0393	2017-07-09 21:40:00+03	56000.00
8B0397	2017-08-12 18:04:00+03	79200.00
8B059C	2017-07-08 14:35:00+03	68400.00
8B05A6	2017-07-15 22:12:00+03	46400.00
8B05B7	2017-07-19 18:42:00+03	20100.00
8B05D4	2017-07-26 10:42:00+03	98000.00
8B0642	2017-07-21 15:10:00+03	23600.00
8B0649	2017-07-11 15:57:00+03	195800.00
8B0690	2017-08-01 02:05:00+03	44600.00
8B070E	2017-07-23 00:57:00+03	269500.00
8B0771	2017-08-04 09:59:00+03	265700.00
8B07A0	2017-07-17 06:43:00+03	24800.00
8B07B3	2017-07-03 07:18:00+03	138000.00
8B07FF	2017-08-13 01:55:00+03	75300.00
8B081E	2017-08-13 23:31:00+03	60400.00
8B086C	2017-07-02 07:25:00+03	146300.00
8B0891	2017-07-08 13:11:00+03	134400.00
8B08D8	2017-07-22 07:27:00+03	6700.00
8B0935	2017-07-31 01:39:00+03	47400.00
8B0970	2017-08-09 13:50:00+03	67400.00
8B0982	2017-07-11 21:39:00+03	6000.00
8B09AF	2017-07-26 14:02:00+03	112000.00
8B09B7	2017-07-30 16:19:00+03	30200.00
8B09CB	2017-07-31 03:00:00+03	131100.00
8B09DF	2017-07-27 08:15:00+03	14700.00
8B0A85	2017-08-07 22:42:00+03	13600.00
8B0B82	2017-08-14 18:16:00+03	11000.00
8B0B9B	2017-08-11 14:22:00+03	25100.00
8B0BBB	2017-07-23 19:53:00+03	93400.00
8B0C3A	2017-08-15 06:51:00+03	63700.00
8B0C50	2017-08-05 08:31:00+03	98400.00
8B0C7D	2017-07-31 21:57:00+03	23400.00
8B0C93	2017-08-07 07:59:00+03	17000.00
8B0D21	2017-06-30 17:08:00+03	68800.00
8B0D66	2017-08-06 18:14:00+03	34100.00
8B0D6F	2017-07-16 20:59:00+03	82200.00
8B0D91	2017-07-17 03:57:00+03	20000.00
8B0DE2	2017-07-02 01:33:00+03	172400.00
8B0DEA	2017-07-30 12:09:00+03	48800.00
8B0E39	2017-07-13 14:35:00+03	32400.00
8B0E67	2017-07-31 23:52:00+03	81000.00
8B0EA1	2017-07-25 09:13:00+03	11600.00
8B0EB8	2017-07-31 23:25:00+03	8200.00
8B0F4A	2017-08-04 08:20:00+03	23600.00
8B0F8B	2017-07-18 03:45:00+03	61500.00
8B0F99	2017-08-13 20:56:00+03	129700.00
8B0FA9	2017-07-30 16:32:00+03	45200.00
8B0FE9	2017-07-12 15:58:00+03	196100.00
8B0FF4	2017-07-14 11:54:00+03	20400.00
8B103D	2017-07-11 21:16:00+03	174800.00
8B1095	2017-07-25 07:41:00+03	123000.00
8B109D	2017-08-07 19:53:00+03	135400.00
8B10F0	2017-07-16 05:40:00+03	3400.00
8B111E	2017-07-09 20:09:00+03	38200.00
8B1147	2017-08-08 22:34:00+03	15000.00
8B11B6	2017-07-22 10:42:00+03	62800.00
8B11BA	2017-07-09 10:17:00+03	67600.00
8B11C0	2017-07-15 23:15:00+03	26000.00
8B11F5	2017-07-26 02:14:00+03	35300.00
8B1298	2017-07-07 14:22:00+03	168000.00
8B12C8	2017-08-13 23:53:00+03	58800.00
8B12D3	2017-06-29 08:18:00+03	8000.00
8B12F6	2017-07-09 22:37:00+03	130100.00
8B1322	2017-08-06 12:35:00+03	131200.00
8B1323	2017-07-31 17:44:00+03	58200.00
8B1338	2017-07-15 09:25:00+03	43500.00
8B13C9	2017-07-16 20:25:00+03	73100.00
8B140C	2017-07-13 20:24:00+03	113800.00
8B1441	2017-07-06 04:31:00+03	32200.00
8B14FE	2017-07-18 23:40:00+03	8000.00
8B1502	2017-07-13 14:48:00+03	332100.00
8B151C	2017-07-26 11:20:00+03	20600.00
8B1520	2017-08-06 02:18:00+03	75300.00
8B15A1	2017-07-12 17:27:00+03	12600.00
8B15AA	2017-08-09 10:28:00+03	24000.00
8B1618	2017-07-15 09:19:00+03	130800.00
8B1625	2017-07-07 04:22:00+03	26000.00
8B1685	2017-07-22 11:55:00+03	79900.00
8B16C9	2017-08-12 08:48:00+03	86600.00
8B16D3	2017-07-07 07:56:00+03	12400.00
8B171B	2017-07-07 16:23:00+03	23600.00
8B17C2	2017-08-14 11:22:00+03	6700.00
8B17D2	2017-07-15 09:31:00+03	89400.00
8B17F1	2017-08-11 14:36:00+03	32400.00
8B17F6	2017-08-09 13:27:00+03	21800.00
8B180E	2017-07-05 00:46:00+03	66400.00
8B187E	2017-08-02 01:31:00+03	70700.00
8B18AC	2017-07-31 16:56:00+03	21800.00
8B18BE	2017-07-15 15:23:00+03	31000.00
8B1906	2017-08-10 07:27:00+03	47000.00
8B1934	2017-07-17 16:46:00+03	249100.00
8B1950	2017-08-15 04:03:00+03	31600.00
8B1999	2017-08-14 16:27:00+03	18400.00
8B19AB	2017-07-22 01:42:00+03	19600.00
8B19D8	2017-07-19 08:11:00+03	28300.00
8B1A0B	2017-07-01 23:11:00+03	78600.00
8B1A0D	2017-07-07 22:13:00+03	6000.00
8B1A46	2017-07-18 23:10:00+03	51800.00
8B1AB2	2017-08-07 15:23:00+03	84100.00
8B1ACA	2017-07-19 05:48:00+03	139200.00
8B1B29	2017-07-10 09:24:00+03	139500.00
8B1B2E	2017-07-21 00:12:00+03	28000.00
8B1B3C	2017-07-27 02:00:00+03	113800.00
8B1B42	2017-08-01 04:07:00+03	23400.00
8B1B58	2017-07-07 20:16:00+03	78100.00
8B1B73	2017-07-04 08:41:00+03	14400.00
8B1BA3	2017-08-11 07:46:00+03	80300.00
8B1BC1	2017-07-03 12:07:00+03	6000.00
8B1C24	2017-08-04 07:45:00+03	42000.00
8B1C2C	2017-07-01 09:40:00+03	59400.00
8B1CB8	2017-07-01 22:22:00+03	199700.00
8B1CE1	2017-07-15 09:31:00+03	6700.00
8B1D02	2017-07-22 07:32:00+03	123000.00
8B1D05	2017-07-09 04:26:00+03	100600.00
8B1DAE	2017-08-09 18:23:00+03	86400.00
8B1DD9	2017-07-08 13:03:00+03	31000.00
8B1DE8	2017-07-21 12:13:00+03	235500.00
8B1E67	2017-08-07 12:23:00+03	22000.00
8B1E9E	2017-08-03 03:43:00+03	28800.00
8B1F52	2017-08-13 02:10:00+03	26000.00
8B1F56	2017-07-08 05:54:00+03	24400.00
8B1F83	2017-07-12 21:44:00+03	79600.00
8B1FA1	2017-08-15 02:57:00+03	26000.00
8B1FB6	2017-07-03 03:12:00+03	24400.00
8B1FF5	2017-07-29 21:36:00+03	58400.00
8B202F	2017-07-23 23:37:00+03	87100.00
8B2092	2017-07-27 00:26:00+03	49800.00
8B209C	2017-07-26 05:46:00+03	13600.00
8B20D9	2017-08-07 23:40:00+03	406700.00
8B211E	2017-08-03 06:57:00+03	231300.00
8B2164	2017-07-18 22:04:00+03	27600.00
8B21A1	2017-07-27 18:47:00+03	153900.00
8B225B	2017-07-06 02:13:00+03	57600.00
8B226D	2017-07-26 12:01:00+03	44800.00
8B2274	2017-08-02 14:43:00+03	136400.00
8B22B5	2017-07-02 04:28:00+03	27200.00
8B22EB	2017-07-21 17:56:00+03	101800.00
8B22F6	2017-07-25 21:14:00+03	123000.00
8B2334	2017-07-10 19:48:00+03	52700.00
8B237E	2017-08-04 11:48:00+03	39800.00
8B23A4	2017-07-16 05:25:00+03	85500.00
8B23F0	2017-07-04 14:18:00+03	38400.00
8B2422	2017-07-01 06:02:00+03	23200.00
8B2441	2017-07-20 13:29:00+03	55800.00
8B24AC	2017-07-06 03:54:00+03	45200.00
8B251D	2017-06-25 15:48:00+03	85200.00
8B262B	2017-07-15 09:17:00+03	51000.00
8B26DD	2017-07-18 21:02:00+03	14400.00
8B26F1	2017-08-12 07:41:00+03	6000.00
8B26F3	2017-08-09 10:06:00+03	67600.00
8B26F8	2017-07-25 17:03:00+03	62800.00
8B27BC	2017-07-16 06:55:00+03	86700.00
8B284D	2017-07-24 01:18:00+03	64400.00
8B286E	2017-08-13 23:42:00+03	58800.00
8B2892	2017-08-12 01:32:00+03	12700.00
8B28BB	2017-07-17 00:44:00+03	105100.00
8B28CB	2017-08-12 10:10:00+03	25100.00
8B28DD	2017-07-21 07:01:00+03	155600.00
8B29B0	2017-07-23 16:50:00+03	92800.00
8B29CD	2017-07-26 01:49:00+03	29800.00
8B2A95	2017-07-20 12:52:00+03	63700.00
8B2ABF	2017-07-15 20:37:00+03	65900.00
8B2BB9	2017-07-04 06:44:00+03	55700.00
8B2D89	2017-06-29 21:09:00+03	82900.00
8B2DC8	2017-08-02 16:47:00+03	33500.00
8B2DDA	2017-06-29 12:18:00+03	26000.00
8B2E40	2017-07-28 02:00:00+03	58600.00
8B2E7E	2017-08-06 01:13:00+03	47400.00
8B2FF1	2017-07-20 00:13:00+03	34000.00
8B302E	2017-08-09 18:27:00+03	50600.00
8B3050	2017-07-20 02:08:00+03	182300.00
8B3053	2017-08-11 21:57:00+03	39400.00
8B308A	2017-07-09 22:01:00+03	32200.00
8B3100	2017-07-19 14:47:00+03	33300.00
8B3115	2017-07-11 18:50:00+03	134900.00
8B3132	2017-07-23 11:33:00+03	23900.00
8B3199	2017-08-11 14:01:00+03	42800.00
8B31E4	2017-07-03 14:15:00+03	56900.00
8B3235	2017-08-02 14:22:00+03	64700.00
8B3236	2017-08-14 18:10:00+03	43900.00
8B3291	2017-08-10 08:15:00+03	64500.00
8B3316	2017-07-03 09:06:00+03	23200.00
8B332F	2017-07-14 15:50:00+03	12000.00
8B333F	2017-08-09 16:44:00+03	20400.00
8B33AD	2017-08-09 10:18:00+03	24400.00
8B33F9	2017-07-19 00:37:00+03	14000.00
8B33FD	2017-07-03 19:14:00+03	53400.00
8B341C	2017-07-17 17:43:00+03	31600.00
8B34B0	2017-08-13 08:42:00+03	153100.00
8B34E3	2017-08-14 01:37:00+03	66600.00
8B34EB	2017-07-15 04:44:00+03	45200.00
8B350C	2017-08-12 20:24:00+03	60400.00
8B3517	2017-07-23 20:54:00+03	52400.00
8B352E	2017-07-01 02:36:00+03	26000.00
8B3539	2017-07-24 12:29:00+03	112000.00
8B3556	2017-07-22 12:27:00+03	137100.00
8B3594	2017-07-25 17:43:00+03	126300.00
8B3622	2017-07-11 13:37:00+03	88600.00
8B362D	2017-07-23 15:47:00+03	36400.00
8B3697	2017-08-15 09:11:00+03	25100.00
8B3699	2017-08-09 05:42:00+03	14400.00
8B36BF	2017-07-24 14:13:00+03	11700.00
8B36C9	2017-08-07 18:23:00+03	47100.00
8B36E5	2017-08-11 23:06:00+03	25100.00
8B36FA	2017-07-22 07:50:00+03	133200.00
8B3707	2017-07-10 09:58:00+03	47100.00
8B3708	2017-07-23 00:11:00+03	13200.00
8B370B	2017-06-30 21:08:00+03	17600.00
8B3734	2017-08-06 10:59:00+03	191200.00
8B3744	2017-08-07 07:54:00+03	123000.00
8B37B3	2017-07-13 15:10:00+03	94000.00
8B37C0	2017-07-26 06:52:00+03	14400.00
8B381D	2017-07-16 23:17:00+03	89200.00
8B381E	2017-07-31 05:41:00+03	32800.00
8B3864	2017-07-13 11:20:00+03	12400.00
8B3923	2017-07-30 09:54:00+03	379000.00
8B39A4	2017-08-09 18:30:00+03	46000.00
8B39EA	2017-08-08 00:12:00+03	113800.00
8B39F9	2017-07-06 03:52:00+03	135600.00
8B3A21	2017-07-26 06:09:00+03	66600.00
8B3A42	2017-07-03 00:47:00+03	45500.00
8B3A5C	2017-07-31 04:55:00+03	105000.00
8B3AAD	2017-07-07 03:34:00+03	6000.00
8B3ABA	2017-08-04 21:16:00+03	31400.00
8B3ABF	2017-07-31 08:37:00+03	18000.00
8B3AC7	2017-07-06 06:03:00+03	142400.00
8B3AD3	2017-07-09 19:41:00+03	58900.00
8B3AF8	2017-07-22 08:32:00+03	58900.00
8B3B1F	2017-07-14 22:22:00+03	31400.00
8B3B70	2017-07-05 07:11:00+03	187600.00
8B3B87	2017-08-11 04:15:00+03	46300.00
8B3BE0	2017-07-02 21:50:00+03	190400.00
8B3C0E	2017-08-06 14:28:00+03	20600.00
8B3C41	2017-07-15 19:20:00+03	46300.00
8B3C56	2017-08-03 05:34:00+03	69500.00
8B3D5F	2017-07-22 01:39:00+03	30800.00
8B3D6F	2017-08-09 23:07:00+03	30900.00
8B3DBD	2017-08-10 01:57:00+03	386300.00
8B3DE4	2017-07-20 08:34:00+03	30200.00
8B3DFE	2017-07-30 03:28:00+03	111600.00
8B3E17	2017-08-11 05:53:00+03	246000.00
8B3E1F	2017-07-23 11:33:00+03	67000.00
8B3E57	2017-07-21 20:12:00+03	109500.00
8B3EAD	2017-07-25 16:51:00+03	65600.00
8B3EB5	2017-08-14 21:14:00+03	44600.00
8B3EBB	2017-07-14 20:29:00+03	69500.00
8B3EFA	2017-06-30 06:42:00+03	42800.00
8B3F15	2017-08-02 07:18:00+03	26000.00
8B3F45	2017-07-04 02:12:00+03	41600.00
8B4005	2017-07-24 19:35:00+03	226000.00
8B403B	2017-07-23 18:33:00+03	105000.00
8B40DE	2017-07-25 16:05:00+03	258400.00
8B40E6	2017-08-09 19:02:00+03	61700.00
8B4112	2017-08-04 06:55:00+03	94800.00
8B4115	2017-06-27 07:27:00+03	231400.00
8B4188	2017-08-07 14:25:00+03	90600.00
8B41BD	2017-07-22 18:33:00+03	27200.00
8B42B9	2017-07-05 07:46:00+03	105600.00
8B42DA	2017-07-09 13:41:00+03	54700.00
8B42DB	2017-08-08 01:31:00+03	87900.00
8B42E9	2017-07-30 06:34:00+03	57400.00
8B42F5	2017-07-10 15:39:00+03	23400.00
8B4321	2017-07-11 00:22:00+03	56000.00
8B434B	2017-07-14 06:56:00+03	39300.00
8B4364	2017-07-16 20:50:00+03	31600.00
8B43A2	2017-07-04 20:41:00+03	24700.00
8B43B5	2017-07-15 05:26:00+03	24400.00
8B441B	2017-07-02 22:16:00+03	55400.00
8B4436	2017-07-16 23:09:00+03	100000.00
8B4469	2017-08-05 01:46:00+03	8400.00
8B4487	2017-08-11 17:26:00+03	116400.00
8B44BF	2017-07-15 21:12:00+03	144300.00
8B44DF	2017-07-17 04:19:00+03	257500.00
8B44F2	2017-07-22 23:23:00+03	50600.00
8B4530	2017-07-20 10:35:00+03	69100.00
8B4575	2017-07-09 08:01:00+03	82700.00
8B457A	2017-08-10 01:41:00+03	72600.00
8B45DD	2017-07-05 05:44:00+03	135600.00
8B461F	2017-08-14 08:31:00+03	43200.00
8B4629	2017-07-27 05:34:00+03	58600.00
8B464C	2017-07-22 22:15:00+03	56000.00
8B46C4	2017-06-29 13:40:00+03	75600.00
8B479E	2017-07-05 10:29:00+03	27200.00
8B47A6	2017-08-03 06:50:00+03	53700.00
8B47B0	2017-07-08 07:39:00+03	24400.00
8B47F4	2017-07-09 20:38:00+03	51900.00
8B4834	2017-06-29 10:37:00+03	186100.00
8B4885	2017-08-12 23:42:00+03	46400.00
8B48BD	2017-07-24 02:12:00+03	12400.00
8B490E	2017-08-10 04:11:00+03	155600.00
8B492F	2017-07-13 13:01:00+03	96200.00
8B4939	2017-08-14 08:19:00+03	56900.00
8B4940	2017-07-08 18:17:00+03	25400.00
8B4978	2017-08-13 00:44:00+03	20200.00
8B498B	2017-07-10 18:26:00+03	25100.00
8B49D0	2017-07-02 18:40:00+03	57300.00
8B49D3	2017-08-02 13:33:00+03	52800.00
8B49EE	2017-07-26 17:44:00+03	88000.00
8B4AD1	2017-07-02 19:19:00+03	52700.00
8B4BA5	2017-07-26 22:58:00+03	43600.00
8B4BC4	2017-07-06 19:06:00+03	103500.00
8B4C05	2017-07-23 03:38:00+03	40800.00
8B4C0D	2017-07-31 08:14:00+03	14000.00
8B4C20	2017-08-10 01:41:00+03	14300.00
8B4C3A	2017-08-11 11:39:00+03	224000.00
8B4C81	2017-07-23 05:59:00+03	71900.00
8B4CAF	2017-07-04 10:31:00+03	265800.00
8B4CFF	2017-07-29 05:01:00+03	23400.00
8B4D92	2017-07-03 12:12:00+03	266400.00
8B4DBC	2017-06-27 09:23:00+03	12000.00
8B4DFC	2017-07-22 22:27:00+03	131900.00
8B4EEA	2017-07-27 19:15:00+03	89200.00
8B4EFB	2017-07-06 03:15:00+03	14000.00
8B4F26	2017-07-21 11:13:00+03	64300.00
8B4FA7	2017-07-08 02:51:00+03	87000.00
8B4FDD	2017-08-14 20:10:00+03	178800.00
8B5093	2017-06-30 08:42:00+03	48800.00
8B50D8	2017-07-28 19:55:00+03	66600.00
8B518A	2017-07-23 18:43:00+03	28800.00
8B51D8	2017-08-09 15:32:00+03	283100.00
8B5221	2017-07-31 09:53:00+03	14800.00
8B5275	2017-07-30 04:22:00+03	54500.00
8B52A5	2017-08-12 09:55:00+03	64300.00
8B52DA	2017-08-12 07:14:00+03	98400.00
8B5314	2017-06-27 02:57:00+03	229300.00
8B533E	2017-07-20 16:36:00+03	265600.00
8B53AF	2017-08-03 12:08:00+03	103500.00
8B53CA	2017-08-01 01:25:00+03	187200.00
8B53F5	2017-07-12 03:43:00+03	13800.00
8B545B	2017-07-11 20:26:00+03	81300.00
8B547A	2017-07-04 10:47:00+03	86900.00
8B549B	2017-07-09 12:05:00+03	31000.00
8B5507	2017-08-15 09:43:00+03	8000.00
8B5512	2017-08-14 16:53:00+03	24400.00
8B552D	2017-07-21 00:03:00+03	94400.00
8B5544	2017-08-07 14:02:00+03	22000.00
8B5584	2017-08-11 17:15:00+03	55800.00
8B56D5	2017-06-30 06:59:00+03	26000.00
8B571F	2017-07-23 15:17:00+03	7400.00
8B579E	2017-07-01 17:20:00+03	62700.00
8B57DE	2017-07-12 15:55:00+03	246000.00
8B57F5	2017-07-24 01:10:00+03	26000.00
8B582A	2017-07-29 04:44:00+03	28000.00
8B5838	2017-07-26 17:46:00+03	13700.00
8B58C9	2017-07-31 21:11:00+03	62400.00
8B5916	2017-06-30 00:29:00+03	41600.00
8B5924	2017-07-27 06:24:00+03	20500.00
8B5967	2017-07-19 01:49:00+03	26000.00
8B59B8	2017-07-28 00:37:00+03	69000.00
8B59CE	2017-07-24 12:57:00+03	72400.00
8B59ED	2017-08-14 06:29:00+03	34000.00
8B5A77	2017-06-30 10:56:00+03	28000.00
8B5AC4	2017-07-04 15:54:00+03	31400.00
8B5ACC	2017-07-22 01:20:00+03	47400.00
8B5AE5	2017-07-15 01:36:00+03	134600.00
8B5B12	2017-06-29 05:02:00+03	61700.00
8B5B33	2017-07-30 23:23:00+03	123000.00
8B5B75	2017-07-19 20:36:00+03	6700.00
8B5BDE	2017-08-05 06:04:00+03	70800.00
8B5BFA	2017-08-06 10:57:00+03	62600.00
8B5C6F	2017-08-08 17:30:00+03	147200.00
8B5DF9	2017-07-03 14:54:00+03	25800.00
8B5EEF	2017-08-13 01:34:00+03	21800.00
8B5F0C	2017-07-19 13:14:00+03	84500.00
8B5F50	2017-07-19 04:52:00+03	24700.00
8B5F51	2017-08-07 23:47:00+03	114400.00
8B5F64	2017-07-28 00:04:00+03	55800.00
8B5FA1	2017-07-22 22:19:00+03	51300.00
8B6061	2017-07-21 09:43:00+03	112000.00
8B606A	2017-08-10 12:09:00+03	119700.00
8B60D7	2017-07-18 20:07:00+03	66600.00
8B60F6	2017-08-09 14:24:00+03	135600.00
8B6109	2017-07-30 02:45:00+03	93900.00
8B610D	2017-08-14 10:48:00+03	56000.00
8B6118	2017-08-01 02:53:00+03	47700.00
8B6139	2017-07-04 13:34:00+03	19600.00
8B617A	2017-08-01 00:22:00+03	235600.00
8B6181	2017-07-06 14:08:00+03	102100.00
8B618B	2017-07-11 11:58:00+03	44000.00
8B61A8	2017-07-25 08:53:00+03	119600.00
8B6238	2017-07-17 09:01:00+03	140300.00
8B626B	2017-08-11 17:11:00+03	64800.00
8B6293	2017-08-05 09:31:00+03	101500.00
8B629C	2017-06-26 05:37:00+03	9200.00
8B62E4	2017-07-22 11:04:00+03	12600.00
8B63A6	2017-07-06 06:08:00+03	73200.00
8B645B	2017-08-04 07:07:00+03	29600.00
8B6466	2017-07-09 17:56:00+03	63500.00
8B6471	2017-07-16 07:41:00+03	66600.00
8B6493	2017-07-10 15:07:00+03	113000.00
8B6593	2017-07-01 07:44:00+03	34000.00
8B65D4	2017-07-02 11:02:00+03	108500.00
8B65EF	2017-07-31 05:55:00+03	66000.00
8B6607	2017-08-11 07:01:00+03	21800.00
8B6614	2017-08-01 11:47:00+03	313800.00
8B66A7	2017-08-03 20:57:00+03	75300.00
8B66AE	2017-07-28 07:01:00+03	227200.00
8B66B1	2017-07-13 19:12:00+03	16300.00
8B6719	2017-07-23 22:05:00+03	16400.00
8B676F	2017-07-07 06:29:00+03	62400.00
8B6796	2017-07-04 09:24:00+03	24400.00
8B679D	2017-07-18 07:53:00+03	59300.00
8B67B8	2017-07-27 17:46:00+03	122600.00
8B67FD	2017-07-22 16:56:00+03	26800.00
8B6824	2017-07-28 04:33:00+03	55800.00
8B6868	2017-07-17 17:30:00+03	44000.00
8B689E	2017-07-07 22:42:00+03	10800.00
8B68F4	2017-07-03 13:17:00+03	63700.00
8B69D6	2017-07-13 08:15:00+03	53300.00
8B69FA	2017-08-15 09:25:00+03	88100.00
8B6A6E	2017-08-03 12:52:00+03	99200.00
8B6A8F	2017-07-20 10:54:00+03	55800.00
8B6AA3	2017-07-29 12:23:00+03	123000.00
8B6AA8	2017-07-12 18:32:00+03	192400.00
8B6AD8	2017-07-05 22:03:00+03	58800.00
8B6B3D	2017-07-06 06:45:00+03	100600.00
8B6B89	2017-08-14 17:55:00+03	29300.00
8B6BC9	2017-08-04 20:31:00+03	103500.00
8B6BD7	2017-07-19 21:14:00+03	37200.00
8B6BDB	2017-07-26 19:13:00+03	67200.00
8B6BF3	2017-07-24 05:29:00+03	42400.00
8B6C0B	2017-07-26 18:34:00+03	89700.00
8B6C15	2017-07-27 06:55:00+03	43900.00
8B6C35	2017-07-19 03:32:00+03	57600.00
8B6CBC	2017-08-10 11:13:00+03	54300.00
8B6CC6	2017-08-11 02:19:00+03	136800.00
8B6D2B	2017-07-02 03:09:00+03	45300.00
8B6D2F	2017-08-12 06:56:00+03	60700.00
8B6D5E	2017-07-17 18:02:00+03	88500.00
8B6D6E	2017-07-19 01:35:00+03	69500.00
8B6D7F	2017-07-27 00:21:00+03	123000.00
8B6DE5	2017-07-13 09:51:00+03	46000.00
8B6DE7	2017-07-26 17:59:00+03	393800.00
8B6DE8	2017-08-06 16:37:00+03	53400.00
8B6E5D	2017-08-05 14:21:00+03	56000.00
8B6EAB	2017-08-11 06:58:00+03	78600.00
8B6F86	2017-07-25 07:25:00+03	51900.00
8B700C	2017-08-07 04:53:00+03	50600.00
8B706A	2017-07-23 10:33:00+03	26800.00
8B70C9	2017-07-12 16:15:00+03	18500.00
8B7137	2017-07-03 12:03:00+03	32100.00
8B713B	2017-07-20 20:57:00+03	23600.00
8B71C2	2017-07-20 18:35:00+03	412400.00
8B7226	2017-08-07 16:54:00+03	11800.00
8B722B	2017-07-11 19:55:00+03	265700.00
8B734A	2017-08-10 17:45:00+03	31600.00
8B7390	2017-07-14 17:16:00+03	39300.00
8B7394	2017-07-21 07:10:00+03	73500.00
8B7428	2017-08-09 06:01:00+03	11800.00
8B745E	2017-08-07 10:49:00+03	89200.00
8B7460	2017-08-15 16:11:00+03	105600.00
8B7568	2017-07-13 12:59:00+03	8400.00
8B758C	2017-07-07 04:58:00+03	98400.00
8B75C7	2017-08-10 16:10:00+03	69600.00
8B7638	2017-07-20 07:57:00+03	112000.00
8B76B5	2017-07-20 23:50:00+03	12600.00
8B76E6	2017-07-27 23:03:00+03	148200.00
8B771C	2017-07-24 13:50:00+03	15200.00
8B7790	2017-07-02 08:47:00+03	410200.00
8B77F2	2017-07-05 16:39:00+03	69500.00
8B789E	2017-07-09 06:50:00+03	66600.00
8B78AE	2017-07-08 17:33:00+03	34000.00
8B7909	2017-08-03 22:51:00+03	23600.00
8B799B	2017-07-18 19:38:00+03	123000.00
8B7A09	2017-07-01 11:42:00+03	39600.00
8B7A2E	2017-08-05 04:23:00+03	83600.00
8B7AA8	2017-07-08 10:24:00+03	53800.00
8B7AEE	2017-08-06 06:18:00+03	26800.00
8B7B11	2017-07-04 11:15:00+03	85000.00
8B7B20	2017-07-27 19:10:00+03	123900.00
8B7B30	2017-07-07 12:08:00+03	99200.00
8B7B35	2017-07-24 14:37:00+03	27200.00
8B7BAD	2017-07-28 11:25:00+03	87900.00
8B7BAF	2017-07-06 14:48:00+03	100600.00
8B7BE8	2017-07-02 08:00:00+03	13800.00
8B7C34	2017-07-31 19:22:00+03	124200.00
8B7CA9	2017-07-31 23:03:00+03	66600.00
8B7CEE	2017-07-28 04:12:00+03	45200.00
8B7CF5	2017-08-09 09:45:00+03	32700.00
8B7D0D	2017-07-02 12:18:00+03	47200.00
8B7D41	2017-07-17 00:09:00+03	381000.00
8B7D55	2017-07-25 23:14:00+03	51400.00
8B7D7D	2017-07-23 10:53:00+03	56600.00
8B7DB3	2017-07-04 15:27:00+03	398500.00
8B7DD3	2017-07-11 00:30:00+03	28800.00
8B7DE3	2017-08-13 22:20:00+03	125200.00
8B7E3D	2017-08-09 03:36:00+03	37000.00
8B7E64	2017-07-15 19:12:00+03	68400.00
8B7EAB	2017-07-29 15:30:00+03	6000.00
8B7EC5	2017-07-02 08:43:00+03	21400.00
8B7EFA	2017-07-22 23:26:00+03	28600.00
8B7F00	2017-07-02 05:26:00+03	183000.00
8B7F10	2017-08-04 07:33:00+03	95600.00
8B7FF9	2017-07-20 08:07:00+03	66600.00
8B80BB	2017-07-08 03:35:00+03	112000.00
8B80BC	2017-07-14 07:35:00+03	313200.00
8B8100	2017-07-15 13:07:00+03	61500.00
8B8127	2017-08-09 16:17:00+03	88800.00
8B8129	2017-07-29 02:13:00+03	12600.00
8B812E	2017-07-13 02:41:00+03	11000.00
8B8160	2017-08-02 22:23:00+03	369000.00
8B8188	2017-07-23 20:38:00+03	58600.00
8B81D3	2017-07-16 11:46:00+03	10600.00
8B824F	2017-08-10 15:26:00+03	14400.00
8B8297	2017-08-14 01:46:00+03	92800.00
8B82E3	2017-08-08 06:57:00+03	46200.00
8B82E7	2017-06-29 21:05:00+03	12600.00
8B82EF	2017-07-04 12:29:00+03	16400.00
8B8355	2017-08-02 20:47:00+03	133100.00
8B8363	2017-08-11 04:51:00+03	27200.00
8B83E0	2017-08-02 14:00:00+03	155600.00
8B842F	2017-07-16 15:34:00+03	12600.00
8B8438	2017-08-02 08:03:00+03	28000.00
8B843D	2017-08-15 14:11:00+03	67000.00
8B8446	2017-07-31 21:04:00+03	152500.00
8B8479	2017-07-17 01:03:00+03	93900.00
8B8530	2017-07-21 16:07:00+03	93900.00
8B8544	2017-07-16 06:41:00+03	103000.00
8B8668	2017-07-05 04:36:00+03	36000.00
8B8699	2017-07-09 12:44:00+03	38600.00
8B86C9	2017-07-07 22:56:00+03	73600.00
8B86E6	2017-08-12 19:14:00+03	85000.00
8B86F1	2017-08-13 02:57:00+03	111600.00
8B86F8	2017-07-01 19:26:00+03	148200.00
8B86FE	2017-07-05 02:26:00+03	19600.00
8B8724	2017-07-22 12:47:00+03	44800.00
8B87F9	2017-07-08 02:02:00+03	68800.00
8B8823	2017-07-20 03:03:00+03	82200.00
8B8850	2017-08-08 03:36:00+03	90800.00
8B8853	2017-06-28 22:23:00+03	79600.00
8B8880	2017-08-02 22:34:00+03	132800.00
8B889E	2017-07-25 20:11:00+03	117600.00
8B88B4	2017-07-04 06:44:00+03	13400.00
8B893F	2017-07-16 09:45:00+03	159300.00
8B8955	2017-08-14 08:37:00+03	26700.00
8B897A	2017-07-22 08:32:00+03	91100.00
8B89E3	2017-07-03 22:10:00+03	14000.00
8B8A8F	2017-07-15 17:13:00+03	78200.00
8B8AA5	2017-08-07 14:28:00+03	111600.00
8B8ABE	2017-08-04 20:19:00+03	114700.00
8B8ADC	2017-07-26 03:39:00+03	42800.00
8B8B44	2017-07-20 23:14:00+03	44000.00
8B8B5F	2017-07-19 21:07:00+03	26800.00
8B8B69	2017-07-04 14:00:00+03	106100.00
8B8B76	2017-07-29 03:33:00+03	32800.00
8B8B7A	2017-08-01 16:32:00+03	68400.00
8B8B7C	2017-07-05 07:05:00+03	13600.00
8B8B87	2017-08-06 04:43:00+03	28000.00
8B8BAF	2017-07-18 09:42:00+03	90400.00
8B8C09	2017-07-13 01:05:00+03	99200.00
8B8C40	2017-06-28 15:59:00+03	61500.00
8B8C8B	2017-07-19 02:54:00+03	220600.00
8B8CD2	2017-08-14 13:24:00+03	40800.00
8B8D03	2017-07-16 15:52:00+03	36800.00
8B8D0A	2017-08-09 05:21:00+03	62100.00
8B8D14	2017-08-12 16:11:00+03	76600.00
8B8D29	2017-08-15 00:07:00+03	55800.00
8B8D6A	2017-07-19 12:23:00+03	12600.00
8B8D71	2017-07-08 16:27:00+03	54300.00
8B8E24	2017-08-11 02:52:00+03	65800.00
8B8E48	2017-07-20 03:23:00+03	42800.00
8B8E7B	2017-07-17 22:21:00+03	53300.00
8B8F18	2017-08-04 07:02:00+03	7200.00
8B8F39	2017-08-06 10:00:00+03	13200.00
8B8F44	2017-08-13 06:11:00+03	132800.00
8B8F7F	2017-07-17 17:12:00+03	153400.00
8B8F99	2017-07-07 03:08:00+03	12600.00
8B8FD8	2017-07-23 16:41:00+03	116700.00
8B8FDF	2017-07-30 12:50:00+03	57500.00
8B8FF6	2017-08-10 04:11:00+03	90400.00
8B9030	2017-07-22 22:27:00+03	133200.00
8B90E1	2017-08-04 18:48:00+03	260300.00
8B9121	2017-08-14 17:07:00+03	36200.00
8B9130	2017-07-14 20:54:00+03	110500.00
8B9148	2017-08-10 16:29:00+03	55800.00
8B91C7	2017-08-12 11:49:00+03	184500.00
8B91DB	2017-08-14 15:57:00+03	23100.00
8B91E9	2017-07-11 19:09:00+03	28000.00
8B91F4	2017-07-11 11:49:00+03	6600.00
8B9261	2017-07-26 13:26:00+03	15000.00
8B9271	2017-07-09 00:36:00+03	57700.00
8B92CD	2017-08-04 09:42:00+03	22000.00
8B92D6	2017-07-09 14:15:00+03	258700.00
8B92FF	2017-07-23 07:03:00+03	13600.00
8B9301	2017-08-06 17:58:00+03	59800.00
8B9304	2017-07-26 08:32:00+03	173400.00
8B938D	2017-07-25 17:00:00+03	6700.00
8B93D1	2017-07-23 19:34:00+03	92700.00
8B94F3	2017-07-18 06:16:00+03	131600.00
8B9578	2017-07-01 20:30:00+03	36200.00
8B961C	2017-08-09 19:52:00+03	88800.00
8B96B3	2017-07-20 17:14:00+03	62600.00
8B96CE	2017-07-04 12:14:00+03	23600.00
8B9730	2017-07-07 21:02:00+03	58000.00
8B9753	2017-08-04 02:31:00+03	87400.00
8B977C	2017-07-14 18:05:00+03	272400.00
8B97A9	2017-07-21 20:28:00+03	53600.00
8B9839	2017-08-06 05:56:00+03	27300.00
8B9876	2017-07-20 06:59:00+03	147700.00
8B98B5	2017-07-07 06:31:00+03	104000.00
8B9979	2017-07-17 11:59:00+03	52800.00
8B9981	2017-08-15 05:14:00+03	28600.00
8B99AD	2017-07-13 09:39:00+03	59800.00
8B99B2	2017-08-11 06:24:00+03	133200.00
8B9A0C	2017-07-16 10:48:00+03	49800.00
8B9A2F	2017-07-21 03:49:00+03	369600.00
8B9A57	2017-07-13 23:06:00+03	54800.00
8B9A78	2017-08-14 12:09:00+03	259300.00
8B9A8B	2017-08-14 10:04:00+03	63200.00
8B9AEA	2017-07-09 13:48:00+03	6600.00
8B9B48	2017-08-06 02:27:00+03	167400.00
8B9B62	2017-08-03 14:14:00+03	12600.00
8B9B9F	2017-07-30 15:42:00+03	177600.00
8B9BA9	2017-07-05 09:15:00+03	99200.00
8B9BD9	2017-08-01 08:02:00+03	38500.00
8B9C05	2017-07-15 04:29:00+03	52400.00
8B9C82	2017-07-03 05:55:00+03	73500.00
8B9D39	2017-07-26 16:06:00+03	57000.00
8B9D5D	2017-07-12 13:38:00+03	27300.00
8B9D6F	2017-08-13 03:54:00+03	89600.00
8B9DCF	2017-08-12 04:14:00+03	145200.00
8B9E73	2017-07-25 06:46:00+03	56600.00
8B9E7E	2017-07-28 06:07:00+03	73100.00
8B9E80	2017-07-13 13:01:00+03	56000.00
8B9ED0	2017-08-14 23:11:00+03	46300.00
8B9F0A	2017-08-03 21:38:00+03	9800.00
8B9F59	2017-07-23 19:37:00+03	12600.00
8B9FCF	2017-07-22 22:30:00+03	60800.00
8B9FEB	2017-06-29 16:14:00+03	27600.00
8B9FF0	2017-08-04 15:25:00+03	42700.00
8BA09A	2017-07-17 04:13:00+03	55800.00
8BA0DA	2017-07-25 18:35:00+03	6700.00
8BA106	2017-07-28 13:21:00+03	88600.00
8BA10C	2017-07-09 18:36:00+03	92900.00
8BA13D	2017-07-04 17:49:00+03	166100.00
8BA14A	2017-07-25 09:52:00+03	66000.00
8BA207	2017-08-13 20:57:00+03	42600.00
8BA22D	2017-07-04 22:37:00+03	66600.00
8BA27E	2017-07-26 04:53:00+03	16800.00
8BA295	2017-08-02 10:38:00+03	106700.00
8BA2C8	2017-08-01 23:16:00+03	46400.00
8BA2D4	2017-08-06 14:02:00+03	101100.00
8BA30C	2017-08-12 16:26:00+03	30900.00
8BA34E	2017-08-14 10:32:00+03	21400.00
8BA377	2017-07-10 00:00:00+03	35700.00
8BA40E	2017-07-09 00:23:00+03	24400.00
8BA449	2017-07-22 14:59:00+03	46000.00
8BA48B	2017-07-12 16:41:00+03	48800.00
8BA490	2017-08-11 02:38:00+03	484300.00
8BA4CE	2017-08-09 14:22:00+03	48800.00
8BA4FD	2017-07-08 23:27:00+03	42400.00
8BA501	2017-07-26 20:03:00+03	12600.00
8BA556	2017-07-22 22:07:00+03	91300.00
8BA611	2017-07-20 08:10:00+03	127500.00
8BA652	2017-07-25 04:36:00+03	137600.00
8BA695	2017-08-13 14:16:00+03	54100.00
8BA760	2017-07-22 07:40:00+03	114900.00
8BA767	2017-07-29 15:45:00+03	47500.00
8BA7B7	2017-07-22 20:29:00+03	55800.00
8BA7D2	2017-07-06 05:43:00+03	133100.00
8BA7D5	2017-07-24 21:24:00+03	34000.00
8BA7DE	2017-07-28 12:59:00+03	174600.00
8BA8A7	2017-07-17 23:15:00+03	39300.00
8BA8A8	2017-08-08 18:39:00+03	139100.00
8BA8E3	2017-07-01 22:20:00+03	17000.00
8BA8F8	2017-07-30 10:45:00+03	80900.00
8BA907	2017-07-27 11:18:00+03	48700.00
8BA90F	2017-07-08 08:58:00+03	94700.00
8BA953	2017-07-07 16:24:00+03	21400.00
8BA965	2017-07-29 12:28:00+03	115100.00
8BA97C	2017-08-13 00:01:00+03	93700.00
8BA9A7	2017-07-17 18:00:00+03	72400.00
8BA9DB	2017-07-11 00:45:00+03	154400.00
8BA9F2	2017-08-05 08:22:00+03	124000.00
8BA9FC	2017-08-12 06:23:00+03	29000.00
8BAA1E	2017-07-22 08:31:00+03	28800.00
8BAA48	2017-08-14 10:08:00+03	34000.00
8BAA6C	2017-07-17 17:12:00+03	79300.00
8BAB02	2017-07-12 09:38:00+03	56000.00
8BAB10	2017-07-04 23:25:00+03	133200.00
8BAB52	2017-07-09 10:34:00+03	24400.00
8BABC0	2017-07-27 08:14:00+03	133200.00
8BAC68	2017-07-18 16:43:00+03	29400.00
8BAC83	2017-08-03 20:44:00+03	36200.00
8BAC9F	2017-07-18 11:40:00+03	258400.00
8BAD52	2017-06-29 08:55:00+03	63100.00
8BAD95	2017-07-12 00:47:00+03	26000.00
8BADEC	2017-08-03 05:37:00+03	54000.00
8BAE20	2017-08-10 02:46:00+03	89200.00
8BAE63	2017-06-29 17:35:00+03	92600.00
8BAE65	2017-08-04 16:07:00+03	103500.00
8BAE84	2017-07-15 04:44:00+03	7400.00
8BAE8A	2017-08-10 20:36:00+03	125400.00
8BAEFE	2017-08-08 20:22:00+03	34700.00
8BAEFF	2017-07-08 23:33:00+03	92900.00
8BAF00	2017-07-10 07:04:00+03	111600.00
8BAF47	2017-06-30 03:57:00+03	42800.00
8BAF4A	2017-07-11 06:11:00+03	99700.00
8BAF4C	2017-07-28 15:41:00+03	25400.00
8BB027	2017-07-26 08:39:00+03	46200.00
8BB03D	2017-07-15 02:56:00+03	26000.00
8BB06E	2017-07-08 00:42:00+03	97900.00
8BB07D	2017-08-09 15:26:00+03	125000.00
8BB108	2017-08-02 10:50:00+03	47100.00
8BB16F	2017-07-22 13:26:00+03	55800.00
8BB1A3	2017-08-05 01:51:00+03	61800.00
8BB1F1	2017-07-29 19:00:00+03	230500.00
8BB20E	2017-07-30 12:18:00+03	30300.00
8BB259	2017-08-01 07:10:00+03	8200.00
8BB273	2017-07-06 03:56:00+03	52000.00
8BB320	2017-07-12 04:44:00+03	51300.00
8BB339	2017-08-14 11:41:00+03	104800.00
8BB3B1	2017-08-04 17:44:00+03	16400.00
8BB3CA	2017-07-28 05:53:00+03	40600.00
8BB3F1	2017-07-27 20:45:00+03	91800.00
8BB3F9	2017-07-07 12:07:00+03	67700.00
8BB49E	2017-07-21 10:20:00+03	12400.00
8BB4C5	2017-07-19 16:13:00+03	270700.00
8BB518	2017-08-01 06:24:00+03	23200.00
8BB520	2017-07-20 06:19:00+03	310600.00
8BB574	2017-07-13 20:28:00+03	68400.00
8BB5AA	2017-08-11 14:31:00+03	81700.00
8BB60D	2017-08-06 04:32:00+03	100000.00
8BB674	2017-07-03 07:01:00+03	26000.00
8BB68B	2017-06-29 20:45:00+03	44500.00
8BB6E1	2017-07-22 17:35:00+03	70700.00
8BB6EE	2017-08-06 12:08:00+03	200400.00
8BB772	2017-07-08 15:56:00+03	27200.00
8BB7FF	2017-07-12 15:08:00+03	25400.00
8BB80E	2017-07-21 18:25:00+03	31900.00
8BB813	2017-07-27 18:38:00+03	40000.00
8BB834	2017-07-29 05:29:00+03	23200.00
8BB912	2017-08-09 19:03:00+03	6800.00
8BB932	2017-07-29 14:41:00+03	51900.00
8BB98F	2017-07-19 17:09:00+03	31900.00
8BB997	2017-07-29 13:38:00+03	72200.00
8BB9B6	2017-07-29 22:17:00+03	31600.00
8BBA48	2017-07-18 20:53:00+03	29100.00
8BBA8C	2017-07-21 22:12:00+03	26800.00
8BBA9B	2017-07-14 19:59:00+03	65100.00
8BBAB5	2017-07-06 18:46:00+03	79600.00
8BBAD8	2017-08-05 09:42:00+03	77900.00
8BBAEF	2017-08-13 22:40:00+03	27400.00
8BBB19	2017-08-04 11:18:00+03	110000.00
8BBB5B	2017-08-11 23:36:00+03	25100.00
8BBBDA	2017-08-12 18:11:00+03	212900.00
8BBC42	2017-07-10 08:34:00+03	64700.00
8BBCC3	2017-07-11 09:26:00+03	24600.00
8BBD1D	2017-07-01 00:36:00+03	12400.00
8BBD40	2017-07-01 11:16:00+03	49400.00
8BBDF5	2017-07-11 06:17:00+03	22000.00
8BBE13	2017-07-11 00:15:00+03	40400.00
8BBE9A	2017-07-30 00:05:00+03	13200.00
8BBEAE	2017-08-07 15:43:00+03	37400.00
8BBF53	2017-07-05 20:25:00+03	12600.00
8BBF7B	2017-07-01 22:43:00+03	27200.00
8BBFDC	2017-08-06 21:48:00+03	112000.00
8BC01B	2017-07-06 13:45:00+03	56000.00
8BC145	2017-07-24 17:57:00+03	49500.00
8BC21C	2017-08-15 01:31:00+03	38000.00
8BC220	2017-07-19 13:18:00+03	226200.00
8BC243	2017-08-09 17:05:00+03	130900.00
8BC2F2	2017-07-05 04:46:00+03	24700.00
8BC2F4	2017-07-29 17:21:00+03	61400.00
8BC30A	2017-07-28 22:43:00+03	39300.00
8BC30F	2017-08-12 00:34:00+03	10600.00
8BC386	2017-07-19 13:13:00+03	37200.00
8BC3C8	2017-06-29 11:14:00+03	240600.00
8BC3CC	2017-07-05 07:52:00+03	492000.00
8BC43B	2017-08-06 10:05:00+03	128000.00
8BC4C3	2017-07-17 14:39:00+03	55800.00
8BC4DE	2017-07-16 18:55:00+03	26700.00
8BC567	2017-07-23 14:19:00+03	62700.00
8BC5A8	2017-08-07 05:25:00+03	32700.00
8BC5C0	2017-07-12 20:19:00+03	45200.00
8BC5F8	2017-07-05 21:45:00+03	42800.00
8BC608	2017-08-15 14:31:00+03	43000.00
8BC64A	2017-08-03 10:53:00+03	103200.00
8BC659	2017-07-05 16:14:00+03	133200.00
8BC6F7	2017-07-07 01:25:00+03	8400.00
8BC71F	2017-07-26 02:25:00+03	15000.00
8BC742	2017-07-02 22:47:00+03	165500.00
8BC7A3	2017-07-02 19:42:00+03	99700.00
8BC7B7	2017-08-01 16:21:00+03	68100.00
8BC7D8	2017-07-28 09:00:00+03	67600.00
8BC7DF	2017-07-01 01:26:00+03	135300.00
8BC8A4	2017-06-30 15:45:00+03	78800.00
8BC8DF	2017-07-24 09:50:00+03	31600.00
8BC905	2017-07-01 20:19:00+03	384900.00
8BC917	2017-07-01 11:34:00+03	56000.00
8BC9A6	2017-07-06 15:10:00+03	28800.00
8BC9BF	2017-07-22 17:26:00+03	6000.00
8BC9FE	2017-08-08 11:52:00+03	57600.00
8BCA11	2017-07-23 12:19:00+03	59800.00
8BCA25	2017-07-20 08:28:00+03	136800.00
8BCB1C	2017-07-31 15:07:00+03	131600.00
8BCB22	2017-07-31 05:36:00+03	69500.00
8BCB2B	2017-07-24 03:07:00+03	27400.00
8BCB43	2017-07-26 11:37:00+03	50800.00
8BCB4C	2017-07-14 04:31:00+03	47200.00
8BCB4E	2017-07-04 11:46:00+03	25400.00
8BCB7C	2017-08-10 09:33:00+03	39800.00
8BCB96	2017-08-02 17:17:00+03	14900.00
8BCBD6	2017-07-27 00:27:00+03	273600.00
8BCC13	2017-07-15 21:34:00+03	140500.00
8BCC2B	2017-07-20 13:52:00+03	37200.00
8BCC52	2017-07-10 22:48:00+03	52000.00
8BCCAB	2017-07-24 07:34:00+03	21800.00
8BCD8B	2017-08-13 11:00:00+03	133200.00
8BCDA3	2017-07-02 00:30:00+03	83100.00
8BCE24	2017-08-13 02:25:00+03	53000.00
8BCE61	2017-07-05 04:20:00+03	113200.00
8BCEA0	2017-07-06 07:33:00+03	99200.00
8BCEC7	2017-07-08 01:47:00+03	23200.00
8BCEDC	2017-08-12 05:25:00+03	24400.00
8BCEF2	2017-08-08 11:07:00+03	40600.00
8BCF2F	2017-07-03 03:03:00+03	52700.00
8BD013	2017-07-09 18:36:00+03	133600.00
8BD03F	2017-07-16 05:23:00+03	260900.00
8BD079	2017-07-04 07:48:00+03	49000.00
8BD0D7	2017-07-16 08:24:00+03	67100.00
8BD0EA	2017-08-04 22:28:00+03	119700.00
8BD0FA	2017-08-02 04:20:00+03	202400.00
8BD120	2017-07-24 19:17:00+03	135400.00
8BD12D	2017-07-05 00:09:00+03	74400.00
8BD225	2017-08-10 15:19:00+03	6000.00
8BD256	2017-08-07 00:03:00+03	38600.00
8BD2BE	2017-08-13 13:07:00+03	52000.00
8BD2EB	2017-06-28 12:55:00+03	32800.00
8BD2ED	2017-08-10 13:54:00+03	143100.00
8BD33F	2017-08-14 04:56:00+03	68800.00
8BD34A	2017-07-02 20:56:00+03	40800.00
8BD350	2017-08-05 11:21:00+03	19600.00
8BD36A	2017-07-11 04:57:00+03	99100.00
8BD371	2017-07-14 18:43:00+03	78800.00
8BD37A	2017-07-15 19:11:00+03	40600.00
8BD38D	2017-07-07 10:56:00+03	30700.00
8BD38E	2017-07-14 09:18:00+03	99700.00
8BD396	2017-07-06 03:19:00+03	260900.00
8BD3A2	2017-07-21 03:30:00+03	31000.00
8BD3BD	2017-08-02 12:36:00+03	126700.00
8BD3DE	2017-08-12 06:15:00+03	52000.00
8BD3E3	2017-07-07 13:50:00+03	20400.00
8BD3F9	2017-07-23 18:12:00+03	60400.00
8BD402	2017-07-23 13:56:00+03	28000.00
8BD406	2017-07-09 12:46:00+03	63200.00
8BD457	2017-06-26 22:49:00+03	13600.00
8BD464	2017-08-03 04:51:00+03	67600.00
8BD480	2017-08-12 22:44:00+03	16400.00
8BD4A3	2017-07-18 04:16:00+03	68000.00
8BD4E2	2017-07-11 11:20:00+03	26000.00
8BD50D	2017-07-11 08:42:00+03	7400.00
8BD551	2017-07-04 10:29:00+03	48800.00
8BD554	2017-07-24 15:39:00+03	32200.00
8BD5C1	2017-08-11 14:14:00+03	33100.00
8BD5EF	2017-07-19 12:01:00+03	177200.00
8BD6C3	2017-07-12 10:56:00+03	59800.00
8BD6F3	2017-07-17 11:20:00+03	134900.00
8BD706	2017-07-18 18:12:00+03	56000.00
8BD798	2017-08-06 21:52:00+03	169900.00
8BD7A7	2017-07-16 17:31:00+03	27200.00
8BD7B0	2017-07-22 17:57:00+03	27200.00
8BD7F5	2017-08-10 09:18:00+03	88900.00
8BD889	2017-07-26 23:44:00+03	88200.00
8BD8A1	2017-07-21 13:02:00+03	16400.00
8BD8B7	2017-08-14 04:38:00+03	99200.00
8BD8DF	2017-07-14 02:59:00+03	54000.00
8BD926	2017-07-11 20:41:00+03	76700.00
8BDA89	2017-07-20 18:11:00+03	28700.00
8BDA9F	2017-07-09 14:31:00+03	18800.00
8BDAA5	2017-08-02 06:10:00+03	111600.00
8BDAEF	2017-07-21 07:19:00+03	129000.00
8BDB2E	2017-07-11 04:19:00+03	56000.00
8BDB72	2017-07-16 08:53:00+03	23200.00
8BDB96	2017-08-14 06:06:00+03	77200.00
8BDBF9	2017-07-31 06:20:00+03	14800.00
8BDBFB	2017-08-15 12:10:00+03	44200.00
8BDC0B	2017-07-20 06:09:00+03	119500.00
8BDC2F	2017-07-29 19:58:00+03	26000.00
8BDC41	2017-07-28 03:12:00+03	83100.00
8BDC9F	2017-08-07 02:36:00+03	186500.00
8BDCB4	2017-08-03 13:32:00+03	24200.00
8BDD13	2017-07-26 20:11:00+03	93900.00
8BDD76	2017-08-02 08:30:00+03	59000.00
8BDD84	2017-07-14 07:54:00+03	165900.00
8BDE3F	2017-07-15 16:19:00+03	177200.00
8BDE40	2017-07-08 18:18:00+03	39200.00
8BDE52	2017-07-17 07:30:00+03	135600.00
8BDE7F	2017-08-04 01:51:00+03	103000.00
8BDE82	2017-07-18 18:08:00+03	27200.00
8BDEBD	2017-07-13 14:58:00+03	123700.00
8BDEF3	2017-07-28 11:25:00+03	25000.00
8BDF19	2017-07-23 17:42:00+03	165400.00
8BDF6F	2017-08-09 23:48:00+03	36400.00
8BDFCF	2017-08-07 20:04:00+03	67200.00
8BE004	2017-07-09 15:21:00+03	38400.00
8BE032	2017-07-10 17:16:00+03	135700.00
8BE057	2017-07-26 22:06:00+03	29200.00
8BE0D1	2017-07-18 05:23:00+03	58800.00
8BE1B4	2017-07-13 04:51:00+03	48800.00
8BE20B	2017-08-01 07:30:00+03	50100.00
8BE219	2017-07-19 11:59:00+03	61800.00
8BE21D	2017-08-10 19:29:00+03	69500.00
8BE236	2017-07-23 06:04:00+03	89700.00
8BE252	2017-07-29 02:21:00+03	47200.00
8BE26E	2017-08-10 02:13:00+03	25600.00
8BE275	2017-08-12 19:32:00+03	14000.00
8BE2A3	2017-08-15 04:33:00+03	17400.00
8BE2B4	2017-07-10 03:35:00+03	87000.00
8BE2D0	2017-08-02 00:18:00+03	56200.00
8BE318	2017-08-14 14:59:00+03	38000.00
8BE37A	2017-08-15 16:38:00+03	22100.00
8BE3A5	2017-07-13 17:35:00+03	23200.00
8BE3E5	2017-07-22 18:31:00+03	89700.00
8BE40A	2017-07-28 23:55:00+03	42800.00
8BE41C	2017-08-02 14:51:00+03	111600.00
8BE459	2017-07-24 21:46:00+03	40600.00
8BE4EB	2017-07-15 05:31:00+03	40700.00
8BE5B8	2017-07-22 02:20:00+03	20400.00
8BE633	2017-08-12 20:43:00+03	134800.00
8BE6A8	2017-07-26 07:26:00+03	95100.00
8BE6EA	2017-07-18 11:45:00+03	25800.00
8BE72A	2017-08-03 06:28:00+03	68800.00
8BE765	2017-07-10 18:43:00+03	406100.00
8BE7D7	2017-07-16 13:30:00+03	43200.00
8BE7E8	2017-07-03 06:12:00+03	23600.00
8BE83F	2017-07-31 07:27:00+03	105100.00
8BE882	2017-08-05 17:02:00+03	95600.00
8BE96C	2017-07-18 20:38:00+03	107800.00
8BE972	2017-08-01 01:45:00+03	67600.00
8BE9A7	2017-08-13 05:01:00+03	204700.00
8BE9CB	2017-07-29 08:41:00+03	25000.00
8BEA00	2017-07-03 00:21:00+03	13400.00
8BEA04	2017-07-24 13:01:00+03	56600.00
8BEA3A	2017-08-15 15:31:00+03	88900.00
8BEA61	2017-08-03 04:27:00+03	92400.00
8BEA77	2017-08-05 09:48:00+03	21400.00
8BEA98	2017-07-21 03:32:00+03	271200.00
8BEAA1	2017-07-26 06:33:00+03	42600.00
8BEACE	2017-07-11 08:28:00+03	263900.00
8BEAE1	2017-08-14 03:37:00+03	68000.00
8BEB2B	2017-07-15 07:53:00+03	99700.00
8BEB44	2017-08-07 18:27:00+03	28800.00
8BEB62	2017-07-10 06:29:00+03	54300.00
8BEB64	2017-07-30 05:39:00+03	56900.00
8BEB82	2017-07-15 02:24:00+03	117700.00
8BEC0B	2017-07-03 21:45:00+03	71200.00
8BEC7D	2017-07-15 14:03:00+03	289100.00
8BED74	2017-07-01 06:57:00+03	32400.00
8BEDFD	2017-08-11 17:12:00+03	23400.00
8BEE07	2017-08-15 01:30:00+03	139200.00
8BEE10	2017-07-16 14:16:00+03	70700.00
8BEE1E	2017-08-03 04:34:00+03	28000.00
8BEE4E	2017-07-27 23:03:00+03	63200.00
8BEE9D	2017-08-14 05:43:00+03	29800.00
8BEF01	2017-07-26 00:26:00+03	173500.00
8BEF29	2017-07-19 06:25:00+03	18000.00
8BEFAA	2017-07-21 12:33:00+03	21400.00
8BF04E	2017-07-04 15:00:00+03	52900.00
8BF052	2017-07-26 18:16:00+03	209800.00
8BF0A6	2017-08-13 04:53:00+03	101800.00
8BF156	2017-07-14 01:17:00+03	135700.00
8BF1BB	2017-08-02 21:05:00+03	147500.00
8BF1CC	2017-08-04 11:13:00+03	46000.00
8BF1D0	2017-07-22 17:37:00+03	83000.00
8BF1EC	2017-07-01 18:15:00+03	198400.00
8BF22F	2017-08-15 11:35:00+03	43500.00
8BF249	2017-07-30 07:21:00+03	12100.00
8BF2E4	2017-08-01 08:02:00+03	31000.00
8BF342	2017-07-18 06:52:00+03	33000.00
8BF359	2017-07-05 01:38:00+03	61800.00
8BF383	2017-07-26 01:01:00+03	56000.00
8BF3CF	2017-07-25 17:58:00+03	48600.00
8BF3DC	2017-08-14 04:17:00+03	38600.00
8BF44D	2017-08-15 02:39:00+03	73300.00
8BF488	2017-07-19 08:41:00+03	55800.00
8BF4A2	2017-08-14 02:09:00+03	188000.00
8BF4E1	2017-07-30 17:51:00+03	66800.00
8BF5AF	2017-08-12 18:05:00+03	56000.00
8BF5C0	2017-07-20 18:36:00+03	25200.00
8BF5C7	2017-07-27 02:28:00+03	85000.00
8BF5D4	2017-07-26 06:24:00+03	47100.00
8BF697	2017-07-15 08:39:00+03	56600.00
8BF6A6	2017-08-06 05:54:00+03	112000.00
8BF6AF	2017-07-10 23:19:00+03	6700.00
8BF6F4	2017-08-02 23:00:00+03	89700.00
8BF6FA	2017-08-01 05:36:00+03	248300.00
8BF724	2017-07-19 23:34:00+03	65900.00
8BF741	2017-07-07 07:20:00+03	10100.00
8BF789	2017-08-10 08:07:00+03	37700.00
8BF7B5	2017-08-06 12:43:00+03	393700.00
8BF7D4	2017-08-10 04:31:00+03	194200.00
8BF7EB	2017-07-15 09:28:00+03	246000.00
8BF801	2017-07-02 15:13:00+03	24400.00
8BF805	2017-08-15 02:56:00+03	69600.00
8BF833	2017-07-29 21:34:00+03	71900.00
8BF8AB	2017-07-23 01:01:00+03	73500.00
8BF936	2017-08-15 00:19:00+03	40200.00
8BF93A	2017-07-18 07:20:00+03	124300.00
8BF93B	2017-07-18 01:33:00+03	136200.00
8BF944	2017-07-06 02:41:00+03	170000.00
8BF97E	2017-08-03 18:00:00+03	43200.00
8BFA37	2017-07-10 00:41:00+03	31200.00
8BFAAE	2017-08-12 10:45:00+03	73500.00
8BFB07	2017-07-22 18:23:00+03	61800.00
8BFBDE	2017-07-18 22:58:00+03	26000.00
8BFBE3	2017-08-09 04:35:00+03	56600.00
8BFC0F	2017-06-30 06:08:00+03	28800.00
8BFC1B	2017-06-29 17:24:00+03	142400.00
8BFC24	2017-07-04 15:47:00+03	21600.00
8BFCC9	2017-08-07 21:25:00+03	60400.00
8BFCD4	2017-08-11 01:49:00+03	45400.00
8BFCD7	2017-07-09 19:27:00+03	106900.00
8BFCEC	2017-08-01 23:36:00+03	43000.00
8BFD02	2017-06-30 02:13:00+03	29300.00
8BFD48	2017-07-16 14:24:00+03	141000.00
8BFD9A	2017-07-07 08:54:00+03	134800.00
8BFE34	2017-07-08 10:23:00+03	28800.00
8BFE3C	2017-08-02 01:06:00+03	24400.00
8BFE6E	2017-07-20 01:49:00+03	14000.00
8BFE9E	2017-07-25 22:26:00+03	211800.00
8BFEFF	2017-07-15 08:00:00+03	28800.00
8BFF65	2017-07-13 03:26:00+03	254900.00
8BFF8F	2017-07-13 20:51:00+03	25700.00
8BFFB2	2017-07-19 19:30:00+03	70800.00
8C00C3	2017-08-13 03:10:00+03	65200.00
8C00C8	2017-07-11 18:40:00+03	135600.00
8C00E5	2017-07-06 04:47:00+03	346900.00
8C00F7	2017-07-26 20:07:00+03	36200.00
8C00FA	2017-07-28 09:56:00+03	92700.00
8C013D	2017-08-01 14:22:00+03	124000.00
8C019D	2017-08-09 23:03:00+03	47200.00
8C01C0	2017-07-08 10:37:00+03	59800.00
8C022A	2017-08-06 17:14:00+03	153200.00
8C0238	2017-07-03 06:37:00+03	18000.00
8C024B	2017-07-20 05:55:00+03	40400.00
8C024C	2017-07-28 03:11:00+03	62100.00
8C0281	2017-08-11 01:27:00+03	14400.00
8C0344	2017-07-14 13:31:00+03	14000.00
8C03D6	2017-08-06 14:13:00+03	47200.00
8C03EF	2017-07-18 17:43:00+03	32700.00
8C0405	2017-08-03 11:35:00+03	202300.00
8C0417	2017-07-31 00:23:00+03	48500.00
8C044C	2017-07-07 12:08:00+03	128800.00
8C0452	2017-08-04 23:33:00+03	70500.00
8C0469	2017-08-03 01:57:00+03	84100.00
8C04A1	2017-07-28 12:19:00+03	75300.00
8C04AE	2017-07-04 05:37:00+03	27200.00
8C0528	2017-07-18 03:26:00+03	85000.00
8C0532	2017-08-13 16:39:00+03	73400.00
8C057D	2017-07-10 16:18:00+03	87100.00
8C0591	2017-08-03 04:29:00+03	22400.00
8C059A	2017-07-26 21:29:00+03	28000.00
8C05A6	2017-08-14 21:49:00+03	40600.00
8C05EA	2017-07-22 05:13:00+03	131600.00
8C063F	2017-07-22 01:02:00+03	124200.00
8C065B	2017-07-17 22:27:00+03	81600.00
8C06ED	2017-07-13 09:22:00+03	39200.00
8C06F6	2017-08-11 03:11:00+03	159200.00
8C0777	2017-08-05 05:42:00+03	95600.00
8C0778	2017-07-26 18:12:00+03	43900.00
8C07BF	2017-07-06 04:49:00+03	22000.00
8C07FE	2017-08-13 03:25:00+03	22000.00
8C0819	2017-07-04 03:41:00+03	86800.00
8C086C	2017-07-09 04:14:00+03	26700.00
8C08A8	2017-07-16 16:56:00+03	13000.00
8C08ED	2017-08-07 06:45:00+03	67600.00
8C0949	2017-07-10 15:02:00+03	74900.00
8C094F	2017-07-31 07:23:00+03	69500.00
8C099F	2017-07-26 02:56:00+03	21500.00
8C09DC	2017-07-21 14:01:00+03	75300.00
8C0A22	2017-07-01 21:22:00+03	60400.00
8C0A48	2017-07-19 09:41:00+03	89400.00
8C0B4F	2017-08-06 18:23:00+03	137800.00
8C0B63	2017-07-22 19:32:00+03	49100.00
8C0B66	2017-07-12 11:23:00+03	69400.00
8C0B96	2017-08-06 06:05:00+03	246000.00
8C0BCC	2017-07-06 23:41:00+03	131600.00
8C0C0B	2017-06-29 03:26:00+03	75800.00
8C0C4C	2017-08-09 20:43:00+03	53200.00
8C0C7C	2017-07-30 03:05:00+03	132800.00
8C0D48	2017-08-06 15:57:00+03	45200.00
8C0D58	2017-07-13 12:36:00+03	28800.00
8C0D74	2017-07-30 19:48:00+03	138100.00
8C0DA6	2017-07-08 18:49:00+03	100900.00
8C0E15	2017-08-05 01:04:00+03	185600.00
8C0EB6	2017-08-03 13:03:00+03	40000.00
8C0ECD	2017-08-05 10:25:00+03	46800.00
8C0EED	2017-07-15 06:43:00+03	56000.00
8C0F09	2017-08-11 08:50:00+03	32800.00
8C0F0F	2017-07-19 03:02:00+03	136800.00
8C0F12	2017-07-16 04:11:00+03	84300.00
8C0F8A	2017-08-03 14:15:00+03	129600.00
8C0F8E	2017-07-25 01:15:00+03	57500.00
8C0FB8	2017-07-06 13:31:00+03	11600.00
8C0FE8	2017-07-10 13:16:00+03	26000.00
8C0FF3	2017-07-30 13:56:00+03	81300.00
8C1006	2017-07-17 01:38:00+03	89600.00
8C10CD	2017-07-08 17:22:00+03	137100.00
8C117B	2017-07-23 20:53:00+03	52300.00
8C121F	2017-08-12 14:50:00+03	66100.00
8C127B	2017-08-08 15:51:00+03	13200.00
8C12A6	2017-07-17 20:58:00+03	59200.00
8C138C	2017-08-07 06:53:00+03	62800.00
8C13C2	2017-07-20 19:31:00+03	26800.00
8C13C6	2017-07-23 05:23:00+03	41900.00
8C13EA	2017-07-10 20:31:00+03	136500.00
8C142D	2017-07-18 20:52:00+03	36200.00
8C1431	2017-07-13 12:11:00+03	25000.00
8C1494	2017-08-03 14:48:00+03	16000.00
8C14E9	2017-08-05 10:15:00+03	28800.00
8C14FC	2017-07-10 22:20:00+03	152700.00
8C156F	2017-08-14 22:36:00+03	28800.00
8C1588	2017-07-31 06:33:00+03	206200.00
8C1598	2017-08-03 09:15:00+03	14000.00
8C15FA	2017-07-07 10:27:00+03	21800.00
8C1638	2017-08-04 01:32:00+03	233200.00
8C163F	2017-07-14 08:44:00+03	44600.00
8C1657	2017-07-06 23:03:00+03	28000.00
8C168D	2017-07-18 17:09:00+03	84500.00
8C16BA	2017-07-29 04:45:00+03	123000.00
8C16CF	2017-07-16 22:10:00+03	55800.00
8C1705	2017-08-11 14:02:00+03	20400.00
8C1714	2017-08-04 18:01:00+03	34000.00
8C1719	2017-08-09 02:57:00+03	12400.00
8C184E	2017-08-03 23:34:00+03	236200.00
8C18A6	2017-08-04 13:11:00+03	174900.00
8C18C9	2017-06-30 04:16:00+03	56900.00
8C18D3	2017-07-17 15:26:00+03	44000.00
8C18F1	2017-06-28 10:20:00+03	46200.00
8C19B6	2017-08-12 20:31:00+03	20000.00
8C1A72	2017-07-08 06:45:00+03	40800.00
8C1A79	2017-07-25 02:25:00+03	187600.00
8C1A8E	2017-07-07 15:38:00+03	93900.00
8C1AB0	2017-08-11 00:25:00+03	67600.00
8C1AB9	2017-08-14 10:34:00+03	119500.00
8C1AE7	2017-07-21 22:44:00+03	28000.00
8C1B10	2017-08-01 15:27:00+03	109600.00
8C1B3C	2017-08-05 01:08:00+03	27900.00
8C1B5A	2017-07-26 22:54:00+03	272400.00
8C1C59	2017-06-29 13:15:00+03	6700.00
8C1CB6	2017-08-12 11:57:00+03	44800.00
8C1CC5	2017-07-12 15:57:00+03	73500.00
8C1CE7	2017-06-30 08:55:00+03	23200.00
8C1D07	2017-07-28 09:14:00+03	77900.00
8C1D38	2017-07-25 21:15:00+03	72400.00
8C1E0D	2017-07-25 04:05:00+03	24600.00
8C1E19	2017-07-29 04:05:00+03	27400.00
8C1E20	2017-07-24 03:31:00+03	55500.00
8C1E4C	2017-08-13 20:15:00+03	135400.00
8C1E52	2017-08-11 15:01:00+03	29600.00
8C1EB3	2017-08-01 15:29:00+03	32700.00
8C1EC9	2017-08-06 05:01:00+03	15100.00
8C1ECE	2017-08-08 20:32:00+03	243700.00
8C1F5D	2017-08-09 10:26:00+03	32200.00
8C1FCB	2017-08-14 03:02:00+03	11600.00
8C1FDE	2017-08-08 04:34:00+03	12400.00
8C201E	2017-07-16 22:23:00+03	26000.00
8C205B	2017-07-25 20:06:00+03	63300.00
8C2068	2017-07-26 17:39:00+03	119500.00
8C2081	2017-07-23 21:05:00+03	38400.00
8C2086	2017-07-24 14:26:00+03	142800.00
8C209A	2017-07-30 00:51:00+03	47000.00
8C20B2	2017-07-11 06:44:00+03	12600.00
8C2121	2017-08-06 18:49:00+03	13300.00
8C2199	2017-08-08 04:05:00+03	397700.00
8C2202	2017-08-15 07:21:00+03	129500.00
8C2210	2017-08-11 03:48:00+03	56600.00
8C222A	2017-07-24 07:24:00+03	187600.00
8C2289	2017-07-20 18:14:00+03	38800.00
8C22A8	2017-08-14 14:36:00+03	24400.00
8C22CF	2017-08-09 23:50:00+03	272400.00
8C22F0	2017-07-11 16:55:00+03	43600.00
8C2301	2017-07-05 22:42:00+03	46300.00
8C230C	2017-08-04 00:14:00+03	66600.00
8C234F	2017-07-30 17:09:00+03	246200.00
8C2370	2017-08-14 19:00:00+03	36000.00
8C23A8	2017-07-29 10:05:00+03	43400.00
8C2430	2017-07-21 10:39:00+03	39300.00
8C2495	2017-08-13 00:47:00+03	20600.00
8C24E6	2017-08-13 10:50:00+03	6000.00
8C2536	2017-07-03 22:34:00+03	40800.00
8C25A4	2017-07-27 05:36:00+03	99500.00
8C25D4	2017-07-01 04:14:00+03	144600.00
8C26BF	2017-07-18 04:11:00+03	24400.00
8C26C5	2017-08-10 15:42:00+03	48700.00
8C26EB	2017-08-09 00:54:00+03	37700.00
8C26FD	2017-07-06 16:27:00+03	124200.00
8C271B	2017-07-29 20:20:00+03	65400.00
8C2794	2017-08-06 15:12:00+03	70200.00
8C2849	2017-08-08 04:35:00+03	28800.00
8C28D1	2017-08-14 07:50:00+03	21800.00
8C290D	2017-08-08 22:07:00+03	60400.00
8C2981	2017-07-16 08:04:00+03	86200.00
8C298C	2017-06-29 14:47:00+03	16400.00
8C29BF	2017-07-16 17:40:00+03	91000.00
8C29C5	2017-07-16 01:38:00+03	75800.00
8C29CE	2017-08-12 17:34:00+03	125400.00
8C2A46	2017-07-14 10:26:00+03	53000.00
8C2A71	2017-07-15 05:44:00+03	39900.00
8C2A83	2017-07-13 08:32:00+03	17200.00
8C2AC7	2017-08-13 21:20:00+03	68800.00
8C2ACB	2017-07-31 05:22:00+03	66600.00
8C2ADB	2017-07-01 06:00:00+03	29600.00
8C2AE0	2017-07-11 18:12:00+03	70400.00
8C2B38	2017-07-02 07:40:00+03	25100.00
8C2CE7	2017-07-20 04:58:00+03	34000.00
8C2CFF	2017-08-12 12:04:00+03	311200.00
8C2D36	2017-07-17 22:55:00+03	27200.00
8C2D48	2017-08-14 04:44:00+03	184300.00
8C2E05	2017-07-13 14:57:00+03	124200.00
8C2E06	2017-06-29 07:08:00+03	56600.00
8C2E36	2017-08-14 08:38:00+03	10800.00
8C2E3A	2017-07-25 06:12:00+03	32900.00
8C2EB8	2017-07-14 23:57:00+03	12400.00
8C2F20	2017-07-15 06:22:00+03	135400.00
8C2FFF	2017-08-01 06:02:00+03	22200.00
8C3025	2017-08-01 20:36:00+03	44000.00
8C309D	2017-07-25 11:39:00+03	11800.00
8C30C1	2017-07-25 01:54:00+03	41200.00
8C30CD	2017-08-03 16:17:00+03	47100.00
8C310E	2017-08-03 14:05:00+03	74400.00
8C3119	2017-07-27 17:31:00+03	83000.00
8C31F2	2017-08-15 04:56:00+03	40000.00
8C3217	2017-07-24 15:19:00+03	67200.00
8C3254	2017-07-09 21:16:00+03	36200.00
8C325E	2017-07-04 15:24:00+03	43500.00
8C3268	2017-07-21 15:50:00+03	39200.00
8C32CA	2017-08-09 01:37:00+03	25200.00
8C32CC	2017-07-10 14:47:00+03	169300.00
8C3300	2017-07-19 10:01:00+03	6800.00
8C3364	2017-07-28 07:50:00+03	36200.00
8C33A5	2017-07-29 14:22:00+03	96800.00
8C33D3	2017-08-10 08:35:00+03	56600.00
8C33F2	2017-07-05 20:44:00+03	75600.00
8C3417	2017-07-19 13:02:00+03	56900.00
8C3420	2017-07-28 15:48:00+03	202700.00
8C3421	2017-08-14 12:14:00+03	40100.00
8C346B	2017-07-18 09:05:00+03	43200.00
8C3475	2017-08-03 12:32:00+03	41400.00
8C34FD	2017-08-07 20:53:00+03	14000.00
8C3527	2017-08-01 16:27:00+03	16400.00
8C358D	2017-08-08 09:15:00+03	24400.00
8C3617	2017-08-10 23:40:00+03	231800.00
8C366E	2017-07-23 17:13:00+03	94700.00
8C3750	2017-08-13 20:52:00+03	120400.00
8C375E	2017-08-11 05:05:00+03	53600.00
8C37DB	2017-07-04 05:13:00+03	12400.00
8C3824	2017-08-01 06:35:00+03	42600.00
8C3840	2017-07-20 00:29:00+03	68400.00
8C3867	2017-07-18 23:03:00+03	123000.00
8C3891	2017-07-22 09:15:00+03	26800.00
8C38BC	2017-07-23 11:00:00+03	254300.00
8C38CB	2017-07-12 18:03:00+03	102700.00
8C3921	2017-08-08 03:49:00+03	266000.00
8C399A	2017-07-05 12:35:00+03	126600.00
8C3A25	2017-07-25 19:57:00+03	68800.00
8C3A59	2017-08-08 23:46:00+03	23200.00
8C3A95	2017-08-15 10:53:00+03	111600.00
8C3AB4	2017-07-27 04:33:00+03	20600.00
8C3AEB	2017-07-31 02:58:00+03	86600.00
8C3B40	2017-08-06 20:10:00+03	76000.00
8C3B79	2017-07-09 22:31:00+03	36000.00
8C3B84	2017-07-24 15:54:00+03	9800.00
8C3C2B	2017-08-13 17:26:00+03	93900.00
8C3C84	2017-08-10 18:18:00+03	27200.00
8C3CA9	2017-07-24 01:51:00+03	23200.00
8C3D3C	2017-06-30 18:37:00+03	143400.00
8C3DE4	2017-08-03 14:26:00+03	139400.00
8C3E06	2017-07-13 20:46:00+03	39800.00
8C3E0A	2017-08-03 14:34:00+03	36200.00
8C3E2B	2017-08-15 08:59:00+03	135200.00
8C3E43	2017-07-03 13:40:00+03	25600.00
8C3EAB	2017-07-01 14:59:00+03	16400.00
8C3ED0	2017-07-21 11:08:00+03	59900.00
8C3EF5	2017-07-19 11:02:00+03	136000.00
8C3F5F	2017-08-15 07:39:00+03	188100.00
8C3FA2	2017-07-15 06:30:00+03	195000.00
8C4001	2017-07-22 08:30:00+03	25800.00
8C40B4	2017-08-15 06:02:00+03	95600.00
8C4188	2017-07-18 11:46:00+03	114300.00
8C41B6	2017-07-23 20:57:00+03	136500.00
8C41D1	2017-08-15 10:05:00+03	45800.00
8C4214	2017-07-07 14:35:00+03	369000.00
8C42A4	2017-07-28 09:55:00+03	23900.00
8C4315	2017-07-05 10:44:00+03	96800.00
8C4325	2017-07-29 05:06:00+03	8000.00
8C4340	2017-07-31 14:54:00+03	160700.00
8C43B1	2017-07-16 21:49:00+03	57500.00
8C43E0	2017-08-10 05:21:00+03	63300.00
8C440A	2017-07-20 05:03:00+03	28000.00
8C4488	2017-07-11 11:29:00+03	56000.00
8C4504	2017-07-29 18:38:00+03	20200.00
8C4531	2017-07-16 01:41:00+03	115300.00
8C4636	2017-07-29 07:24:00+03	14400.00
8C4637	2017-07-30 16:25:00+03	169200.00
8C4655	2017-08-01 21:51:00+03	92800.00
8C469A	2017-08-06 21:38:00+03	40800.00
8C4751	2017-07-31 19:57:00+03	13400.00
8C476A	2017-07-05 12:24:00+03	55800.00
8C4775	2017-08-05 12:55:00+03	38700.00
8C477B	2017-07-17 11:39:00+03	151500.00
8C47D9	2017-08-09 23:34:00+03	119600.00
8C4809	2017-08-14 05:06:00+03	54800.00
8C4813	2017-07-05 01:30:00+03	34000.00
8C482E	2017-08-13 14:14:00+03	116800.00
8C485A	2017-07-29 17:18:00+03	56000.00
8C48B9	2017-07-21 21:35:00+03	151200.00
8C48E8	2017-07-05 11:39:00+03	75000.00
8C4906	2017-07-19 08:17:00+03	133200.00
8C4922	2017-07-07 16:08:00+03	166700.00
8C4978	2017-07-04 18:00:00+03	40100.00
8C4980	2017-07-22 10:08:00+03	26700.00
8C4A08	2017-08-05 18:08:00+03	16400.00
8C4A15	2017-07-14 14:12:00+03	46300.00
8C4A94	2017-08-09 22:33:00+03	66600.00
8C4A9E	2017-07-13 00:55:00+03	89600.00
8C4AA1	2017-07-04 18:08:00+03	71200.00
8C4AD3	2017-07-20 08:57:00+03	33300.00
8C4B43	2017-08-15 13:08:00+03	18400.00
8C4B55	2017-07-02 07:39:00+03	66600.00
8C4BE3	2017-08-06 04:38:00+03	45200.00
8C4BEA	2017-07-24 08:30:00+03	6400.00
8C4C3F	2017-07-18 23:35:00+03	99200.00
8C4C68	2017-07-10 05:54:00+03	70300.00
8C4C81	2017-07-05 06:07:00+03	86300.00
8C4CC3	2017-07-29 07:49:00+03	97600.00
8C4D56	2017-07-12 13:59:00+03	65500.00
8C4D8C	2017-07-29 06:22:00+03	46400.00
8C4DBF	2017-07-13 15:15:00+03	111600.00
8C4DC4	2017-08-01 08:52:00+03	54300.00
8C4E3A	2017-08-09 02:29:00+03	99900.00
8C4E81	2017-08-08 12:28:00+03	60400.00
8C4EC7	2017-07-25 17:54:00+03	16400.00
8C4EDA	2017-07-12 14:05:00+03	40800.00
8C4EDB	2017-07-01 10:13:00+03	26000.00
8C4EE5	2017-07-08 10:01:00+03	115700.00
8C4EEF	2017-07-08 15:33:00+03	7400.00
8C4F84	2017-07-03 10:20:00+03	28800.00
8C4F91	2017-07-05 14:11:00+03	28800.00
8C4FD4	2017-08-15 01:25:00+03	6700.00
8C5017	2017-08-08 20:40:00+03	96200.00
8C5040	2017-07-20 15:15:00+03	21200.00
8C5057	2017-07-12 09:19:00+03	46300.00
8C5064	2017-07-25 10:43:00+03	241300.00
8C506A	2017-07-20 12:41:00+03	14400.00
8C5089	2017-07-15 07:52:00+03	29400.00
8C510D	2017-08-09 11:37:00+03	213600.00
8C5125	2017-08-01 20:12:00+03	13400.00
8C515C	2017-08-01 00:34:00+03	9200.00
8C5164	2017-08-12 23:21:00+03	63200.00
8C51F4	2017-07-14 02:09:00+03	32700.00
8C520A	2017-07-10 03:30:00+03	30000.00
8C522D	2017-07-25 09:00:00+03	25400.00
8C5286	2017-07-20 15:44:00+03	75600.00
8C531F	2017-08-04 08:05:00+03	65900.00
8C5357	2017-07-09 22:51:00+03	140000.00
8C539F	2017-07-31 09:56:00+03	8400.00
8C5509	2017-07-10 15:43:00+03	28600.00
8C5556	2017-07-16 04:56:00+03	13200.00
8C5598	2017-08-05 21:51:00+03	57600.00
8C55B1	2017-07-05 17:38:00+03	40600.00
8C5617	2017-07-12 06:20:00+03	114800.00
8C5626	2017-07-30 15:46:00+03	67600.00
8C5664	2017-07-28 07:41:00+03	103800.00
8C56A0	2017-07-02 21:08:00+03	6700.00
8C56B8	2017-07-24 09:16:00+03	46400.00
8C56CC	2017-07-17 03:21:00+03	67100.00
8C5789	2017-07-03 03:38:00+03	59800.00
8C580D	2017-07-06 06:10:00+03	57500.00
8C581C	2017-08-10 21:22:00+03	12400.00
8C58C3	2017-08-09 08:28:00+03	282000.00
8C5908	2017-07-28 03:31:00+03	56200.00
8C5941	2017-07-10 23:02:00+03	62200.00
8C5957	2017-07-07 10:37:00+03	190400.00
8C5981	2017-07-03 14:31:00+03	132800.00
8C59F4	2017-07-12 23:38:00+03	54400.00
8C5A33	2017-06-28 03:33:00+03	21800.00
8C5AA8	2017-08-03 15:11:00+03	26000.00
8C5AB9	2017-08-06 00:13:00+03	52000.00
8C5AE2	2017-07-29 08:26:00+03	68600.00
8C5B41	2017-07-05 13:50:00+03	96800.00
8C5B94	2017-07-24 04:48:00+03	35600.00
8C5BB6	2017-08-12 17:22:00+03	25100.00
8C5BFD	2017-08-12 05:35:00+03	111600.00
8C5C06	2017-07-25 12:19:00+03	98800.00
8C5C0E	2017-07-23 07:05:00+03	75600.00
8C5C42	2017-07-10 05:26:00+03	116400.00
8C5C72	2017-08-12 17:49:00+03	202500.00
8C5C87	2017-08-07 15:15:00+03	10100.00
8C5CB5	2017-08-03 01:34:00+03	55800.00
8C5CDB	2017-07-20 06:00:00+03	86300.00
8C5D1A	2017-08-06 05:21:00+03	242300.00
8C5D7A	2017-07-17 10:37:00+03	22000.00
8C5DDC	2017-07-16 19:19:00+03	46000.00
8C5DEA	2017-07-05 03:52:00+03	20400.00
8C5E43	2017-07-12 05:11:00+03	117600.00
8C5E4B	2017-08-10 06:03:00+03	23100.00
8C5E76	2017-07-02 20:36:00+03	124200.00
8C5EC1	2017-08-06 22:07:00+03	24400.00
8C5F09	2017-08-15 17:30:00+03	48300.00
8C5F8A	2017-07-27 13:32:00+03	107400.00
8C5FDA	2017-08-07 11:14:00+03	62900.00
8C600E	2017-07-05 05:18:00+03	53400.00
8C60F4	2017-07-02 20:17:00+03	37700.00
8C61A5	2017-07-17 04:25:00+03	188000.00
8C62B9	2017-08-08 19:38:00+03	6700.00
8C62C4	2017-08-05 11:15:00+03	56000.00
8C62DB	2017-07-21 02:45:00+03	50600.00
8C6316	2017-07-16 00:13:00+03	67600.00
8C6377	2017-06-26 14:01:00+03	35600.00
8C63EC	2017-06-24 08:37:00+03	55800.00
8C640D	2017-07-06 11:43:00+03	123000.00
8C649F	2017-08-06 00:03:00+03	124200.00
8C655C	2017-07-03 09:07:00+03	144400.00
8C657B	2017-07-15 23:39:00+03	82900.00
8C65FF	2017-06-27 00:30:00+03	21400.00
8C663A	2017-08-15 11:27:00+03	55600.00
8C6646	2017-06-30 17:57:00+03	104300.00
8C6695	2017-07-09 17:09:00+03	52000.00
8C66CC	2017-07-28 19:35:00+03	55800.00
8C6701	2017-07-14 23:28:00+03	49100.00
8C671B	2017-07-10 22:36:00+03	99900.00
8C6759	2017-08-04 20:24:00+03	47000.00
8C6774	2017-07-04 09:47:00+03	65300.00
8C6778	2017-08-11 11:12:00+03	18800.00
8C67A5	2017-08-06 22:40:00+03	26700.00
8C67D7	2017-06-30 18:18:00+03	38800.00
8C67DB	2017-07-04 09:03:00+03	71000.00
8C6817	2017-07-12 16:20:00+03	85700.00
8C6825	2017-08-04 17:29:00+03	28000.00
8C6855	2017-07-04 12:58:00+03	27500.00
8C6864	2017-07-27 06:29:00+03	14700.00
8C68D1	2017-08-12 22:55:00+03	31600.00
8C68FD	2017-07-06 16:34:00+03	45400.00
8C69BD	2017-07-14 08:08:00+03	110000.00
8C69F7	2017-08-01 23:02:00+03	31400.00
8C6A46	2017-07-20 21:18:00+03	87100.00
8C6AE9	2017-07-30 02:23:00+03	30000.00
8C6B52	2017-07-16 11:49:00+03	75300.00
8C6B88	2017-07-29 10:28:00+03	153800.00
8C6BF8	2017-07-16 07:27:00+03	38600.00
8C6C48	2017-07-24 22:08:00+03	307900.00
8C6C81	2017-08-11 14:38:00+03	49100.00
8C6C9C	2017-08-03 23:53:00+03	36200.00
8C6D1E	2017-07-04 01:57:00+03	38800.00
8C6D46	2017-08-03 00:31:00+03	50500.00
8C6D90	2017-08-01 22:02:00+03	97700.00
8C6D93	2017-06-28 01:06:00+03	133200.00
8C6DCD	2017-08-13 06:03:00+03	24800.00
8C6DED	2017-07-28 20:08:00+03	108900.00
8C6DF2	2017-08-09 07:40:00+03	199200.00
8C6DFC	2017-07-15 05:30:00+03	195800.00
8C6E0D	2017-08-07 22:01:00+03	88600.00
8C6E85	2017-07-22 04:56:00+03	213600.00
8C6E88	2017-08-14 12:26:00+03	7200.00
8C6E8F	2017-07-21 23:58:00+03	86400.00
8C6E92	2017-07-13 06:42:00+03	75200.00
8C6EF4	2017-08-06 19:39:00+03	28000.00
8C6F2B	2017-07-11 22:22:00+03	42800.00
8C6FC1	2017-08-05 22:57:00+03	24800.00
8C6FCC	2017-07-01 00:00:00+03	30200.00
8C703A	2017-08-09 02:28:00+03	298600.00
8C7069	2017-07-11 15:31:00+03	58900.00
8C70EA	2017-07-25 20:30:00+03	31100.00
8C7101	2017-07-28 04:11:00+03	191100.00
8C7103	2017-08-10 13:42:00+03	38700.00
8C7181	2017-07-08 11:34:00+03	260300.00
8C71BF	2017-08-03 19:17:00+03	105000.00
8C71F1	2017-07-08 02:57:00+03	81300.00
8C7218	2017-07-25 08:36:00+03	46400.00
8C724F	2017-08-13 13:44:00+03	146300.00
8C7255	2017-06-30 12:43:00+03	26700.00
8C7286	2017-08-07 20:22:00+03	83100.00
8C729A	2017-08-09 08:09:00+03	28800.00
8C72A5	2017-08-08 17:47:00+03	49900.00
8C7425	2017-07-03 09:15:00+03	36200.00
8C7444	2017-07-05 07:03:00+03	46400.00
8C74A6	2017-07-27 06:44:00+03	44600.00
8C74B0	2017-07-02 03:36:00+03	80300.00
8C7572	2017-08-03 15:05:00+03	76600.00
8C75B1	2017-08-10 08:38:00+03	156300.00
8C75DF	2017-07-20 15:07:00+03	167400.00
8C75E6	2017-08-03 08:12:00+03	55800.00
8C75FC	2017-07-19 04:25:00+03	78300.00
8C7637	2017-07-19 18:40:00+03	193600.00
8C7638	2017-07-31 12:08:00+03	33200.00
8C76B1	2017-06-27 22:44:00+03	56000.00
8C76C2	2017-08-14 08:12:00+03	12600.00
8C76F8	2017-07-10 18:19:00+03	27300.00
8C7759	2017-07-24 03:51:00+03	29400.00
8C77D5	2017-07-08 08:19:00+03	9800.00
8C77E8	2017-07-17 12:54:00+03	41400.00
8C7882	2017-07-01 12:53:00+03	98000.00
8C789D	2017-07-09 16:48:00+03	25600.00
8C78AE	2017-08-02 04:32:00+03	113700.00
8C78BC	2017-07-21 04:03:00+03	25800.00
8C7987	2017-08-05 08:11:00+03	65500.00
8C79C4	2017-07-11 00:36:00+03	86800.00
8C79D8	2017-08-03 01:03:00+03	97900.00
8C7A06	2017-07-15 07:04:00+03	54400.00
8C7A67	2017-08-15 12:01:00+03	53400.00
8C7A90	2017-07-21 20:59:00+03	28800.00
8C7AB5	2017-07-31 23:43:00+03	105300.00
8C7B40	2017-07-19 12:50:00+03	41600.00
8C7B50	2017-07-13 08:56:00+03	155600.00
8C7B65	2017-07-20 15:10:00+03	77200.00
8C7C4B	2017-07-20 19:07:00+03	25600.00
8C7C97	2017-08-03 19:50:00+03	59800.00
8C7CBB	2017-07-06 22:24:00+03	26000.00
8C7CD1	2017-07-23 15:29:00+03	28000.00
8C7CF6	2017-08-13 17:23:00+03	36200.00
8C7D10	2017-07-19 14:37:00+03	20500.00
8C7D12	2017-07-15 21:32:00+03	29200.00
8C7D27	2017-07-28 22:36:00+03	29600.00
8C7D56	2017-07-06 09:57:00+03	70800.00
8C7D9A	2017-08-15 00:04:00+03	162700.00
8C7DB9	2017-07-29 10:05:00+03	87400.00
8C7DE6	2017-07-18 15:23:00+03	39200.00
8C7E32	2017-07-28 12:19:00+03	77600.00
8C7E3A	2017-07-25 06:49:00+03	81700.00
8C7E98	2017-08-05 00:49:00+03	246000.00
8C7EE4	2017-07-08 19:02:00+03	14000.00
8C7F39	2017-07-05 17:44:00+03	23200.00
8C7F4A	2017-07-02 15:05:00+03	75600.00
8C7F68	2017-07-05 10:02:00+03	131600.00
8C8004	2017-08-06 12:01:00+03	51300.00
8C800C	2017-07-08 21:07:00+03	128000.00
8C803B	2017-07-08 13:48:00+03	89700.00
8C8060	2017-07-08 09:42:00+03	62800.00
8C807F	2017-07-15 20:44:00+03	28800.00
8C80B2	2017-07-27 12:26:00+03	112000.00
8C8202	2017-07-09 08:11:00+03	138000.00
8C8231	2017-07-31 22:38:00+03	72400.00
8C8307	2017-07-05 19:02:00+03	6800.00
8C8314	2017-07-16 17:10:00+03	260300.00
8C8339	2017-08-03 02:09:00+03	122100.00
8C8349	2017-08-04 18:02:00+03	39800.00
8C8356	2017-08-06 21:02:00+03	18200.00
8C8357	2017-07-18 03:16:00+03	74900.00
8C83B8	2017-08-01 16:13:00+03	72200.00
8C83D3	2017-07-27 03:48:00+03	37200.00
8C8413	2017-08-04 01:57:00+03	265600.00
8C8419	2017-07-27 16:44:00+03	147900.00
8C842D	2017-07-04 15:43:00+03	116400.00
8C8436	2017-08-12 04:55:00+03	78100.00
8C8532	2017-08-07 22:10:00+03	56600.00
8C8535	2017-07-26 14:13:00+03	31200.00
8C857B	2017-08-03 10:32:00+03	31400.00
8C859F	2017-08-13 12:59:00+03	154200.00
8C85DC	2017-07-23 16:23:00+03	34000.00
8C85E3	2017-07-18 22:52:00+03	187800.00
8C864B	2017-08-08 03:00:00+03	13400.00
8C8687	2017-07-20 09:37:00+03	55800.00
8C86A4	2017-08-12 06:54:00+03	73100.00
8C86F0	2017-08-04 05:34:00+03	15900.00
8C870A	2017-08-13 10:52:00+03	6000.00
8C8737	2017-08-08 07:50:00+03	70800.00
8C8795	2017-08-08 20:13:00+03	254900.00
8C8864	2017-06-28 16:13:00+03	99200.00
8C886C	2017-07-08 00:59:00+03	56000.00
8C88BF	2017-08-03 19:23:00+03	38800.00
8C88D8	2017-07-21 13:43:00+03	18000.00
8C88DE	2017-08-14 12:28:00+03	169600.00
8C892C	2017-07-25 18:24:00+03	55600.00
8C8A50	2017-08-03 07:19:00+03	56600.00
8C8A6A	2017-08-07 10:56:00+03	6700.00
8C8A71	2017-08-12 06:44:00+03	85200.00
8C8ACC	2017-08-04 16:07:00+03	26200.00
8C8AF9	2017-08-01 16:30:00+03	256000.00
8C8BFE	2017-07-12 06:33:00+03	185300.00
8C8C0C	2017-08-10 18:22:00+03	131100.00
8C8C7A	2017-08-10 09:51:00+03	83600.00
8C8C9C	2017-06-30 23:28:00+03	88800.00
8C8D10	2017-08-13 01:14:00+03	209000.00
8C8D59	2017-08-15 04:49:00+03	89700.00
8C8D8E	2017-07-04 17:55:00+03	42200.00
8C8D93	2017-08-14 06:12:00+03	67600.00
8C8DC5	2017-08-11 14:00:00+03	83000.00
8C8E18	2017-08-09 14:20:00+03	51300.00
8C8E25	2017-08-10 07:52:00+03	154800.00
8C8E2E	2017-08-13 16:31:00+03	32800.00
8C8E47	2017-08-06 04:27:00+03	32800.00
8C8E4C	2017-07-03 19:57:00+03	48100.00
8C8E4E	2017-08-01 00:02:00+03	397100.00
8C8E8D	2017-08-08 02:57:00+03	48500.00
8C8F79	2017-07-19 06:50:00+03	31600.00
8C8F91	2017-07-29 19:06:00+03	36200.00
8C8FA8	2017-07-09 20:02:00+03	48800.00
8C8FC1	2017-07-10 07:41:00+03	55800.00
8C9068	2017-08-14 08:07:00+03	53800.00
8C91FD	2017-07-08 18:21:00+03	135400.00
8C926E	2017-07-14 17:26:00+03	14400.00
8C9281	2017-07-03 04:38:00+03	40800.00
8C9285	2017-08-07 14:06:00+03	19600.00
8C92AF	2017-08-08 06:44:00+03	99300.00
8C92D5	2017-06-29 21:35:00+03	46700.00
8C931E	2017-07-11 01:18:00+03	56000.00
8C9324	2017-07-22 15:29:00+03	66600.00
8C9351	2017-07-17 09:22:00+03	39200.00
8C9359	2017-08-04 15:35:00+03	31400.00
8C935C	2017-07-22 22:26:00+03	66600.00
8C9399	2017-07-05 12:23:00+03	81600.00
8C93A5	2017-07-18 20:22:00+03	6000.00
8C93BC	2017-07-09 21:07:00+03	15400.00
8C93CF	2017-07-27 11:28:00+03	46500.00
8C9407	2017-06-28 10:06:00+03	47000.00
8C946A	2017-08-02 19:14:00+03	258400.00
8C946D	2017-07-17 18:16:00+03	177600.00
8C94D7	2017-07-28 13:22:00+03	27800.00
8C952B	2017-07-07 08:03:00+03	147700.00
8C95C7	2017-07-27 13:10:00+03	41900.00
8C963F	2017-07-28 20:48:00+03	83200.00
8C9644	2017-08-12 22:00:00+03	67600.00
8C96A7	2017-07-03 18:51:00+03	44600.00
8C96AA	2017-07-13 14:37:00+03	14800.00
8C974E	2017-06-27 23:49:00+03	34000.00
8C97E5	2017-07-20 10:50:00+03	23200.00
8C9817	2017-07-27 09:27:00+03	78100.00
8C984F	2017-07-19 19:51:00+03	170800.00
8C989F	2017-07-10 18:08:00+03	56000.00
8C98A0	2017-06-26 22:46:00+03	19600.00
8C98B7	2017-07-14 00:57:00+03	17800.00
8C98C6	2017-08-13 19:58:00+03	90000.00
8C993F	2017-07-22 18:20:00+03	14400.00
8C9942	2017-07-16 12:16:00+03	31600.00
8C9949	2017-08-04 19:54:00+03	49100.00
8C996A	2017-07-29 04:21:00+03	265600.00
8C99F8	2017-08-06 20:52:00+03	45100.00
8C9A56	2017-07-19 12:30:00+03	22200.00
8C9ADC	2017-08-13 04:06:00+03	17800.00
8C9AEB	2017-07-15 05:36:00+03	28800.00
8C9B40	2017-07-18 12:49:00+03	137600.00
8C9B4F	2017-07-24 07:37:00+03	58400.00
8C9BC5	2017-07-25 00:56:00+03	66600.00
8C9C77	2017-08-08 00:39:00+03	31200.00
8C9CED	2017-07-24 09:25:00+03	32800.00
8C9D4A	2017-07-09 01:11:00+03	16400.00
8C9D56	2017-07-05 15:49:00+03	124000.00
8C9E42	2017-07-08 11:29:00+03	6000.00
8C9E78	2017-07-07 10:03:00+03	24400.00
8C9E7C	2017-08-10 18:36:00+03	237900.00
8C9ECB	2017-07-05 02:04:00+03	105600.00
8C9EE2	2017-07-20 11:57:00+03	26000.00
8C9F10	2017-08-12 05:56:00+03	55800.00
8C9F17	2017-08-03 13:32:00+03	14800.00
8C9F24	2017-08-12 13:04:00+03	40700.00
8C9F5F	2017-07-01 08:57:00+03	47400.00
8C9F63	2017-07-14 12:01:00+03	55800.00
8C9F7D	2017-07-28 10:24:00+03	89600.00
8C9F82	2017-07-17 17:38:00+03	26800.00
8C9FA5	2017-07-21 04:58:00+03	50600.00
8CA05D	2017-07-14 04:11:00+03	23600.00
8CA0EC	2017-07-24 21:08:00+03	41300.00
8CA0F9	2017-07-24 19:54:00+03	51600.00
8CA182	2017-08-04 23:24:00+03	54800.00
8CA23E	2017-07-03 20:25:00+03	114900.00
8CA2D0	2017-08-06 21:22:00+03	81300.00
8CA2F1	2017-07-10 13:37:00+03	56000.00
8CA303	2017-08-11 19:53:00+03	43500.00
8CA340	2017-08-02 00:31:00+03	41600.00
8CA34D	2017-08-01 04:57:00+03	68400.00
8CA387	2017-08-15 14:12:00+03	54000.00
8CA3C2	2017-07-29 03:46:00+03	27200.00
8CA410	2017-07-26 21:23:00+03	271100.00
8CA4A1	2017-07-19 17:53:00+03	35600.00
8CA527	2017-07-27 17:12:00+03	135600.00
8CA646	2017-07-17 02:49:00+03	48800.00
8CA64B	2017-07-02 05:48:00+03	36200.00
8CA6C5	2017-07-29 08:24:00+03	15000.00
8CA6F8	2017-07-20 13:16:00+03	140400.00
8CA6FB	2017-07-15 07:50:00+03	94000.00
8CA726	2017-08-14 15:01:00+03	13400.00
8CA741	2017-08-09 13:25:00+03	25200.00
8CA762	2017-06-30 03:12:00+03	49100.00
8CA78A	2017-07-18 06:26:00+03	76600.00
8CA7CB	2017-07-03 22:56:00+03	123000.00
8CA7CD	2017-07-03 07:36:00+03	67600.00
8CA7D4	2017-07-01 22:56:00+03	146300.00
8CA7EF	2017-07-13 02:32:00+03	32500.00
8CA863	2017-07-07 15:10:00+03	266400.00
8CA8B2	2017-07-11 06:55:00+03	39200.00
8CA966	2017-06-28 04:05:00+03	34000.00
8CA973	2017-08-14 02:22:00+03	13600.00
8CA99A	2017-08-05 18:10:00+03	36200.00
8CA9F7	2017-07-30 15:17:00+03	92000.00
8CAA04	2017-07-12 03:20:00+03	196800.00
8CAA09	2017-07-14 01:09:00+03	246000.00
8CAA5B	2017-08-14 06:27:00+03	28000.00
8CAA65	2017-08-10 12:30:00+03	51900.00
8CAA96	2017-08-15 01:20:00+03	25100.00
8CAB1C	2017-07-25 05:51:00+03	72300.00
8CAB1E	2017-07-19 11:35:00+03	77900.00
8CABC6	2017-07-03 02:35:00+03	116800.00
8CAC03	2017-08-06 13:57:00+03	40800.00
8CAC79	2017-07-08 21:01:00+03	56600.00
8CACD7	2017-07-06 19:42:00+03	117200.00
8CACFB	2017-08-03 07:34:00+03	100600.00
8CACFD	2017-08-06 11:35:00+03	133200.00
8CAD08	2017-07-26 15:10:00+03	65900.00
8CAD1A	2017-08-12 16:18:00+03	67900.00
8CAD52	2017-08-07 11:39:00+03	13400.00
8CAD5F	2017-08-15 13:00:00+03	21800.00
8CAE43	2017-08-13 22:13:00+03	130900.00
8CAEE1	2017-08-15 06:05:00+03	395000.00
8CAF32	2017-06-29 07:05:00+03	271200.00
8CAF64	2017-07-02 09:50:00+03	9800.00
8CAFD9	2017-07-18 05:21:00+03	65900.00
8CB072	2017-07-23 18:09:00+03	72800.00
8CB08B	2017-07-13 22:25:00+03	12600.00
8CB0B6	2017-07-25 10:08:00+03	40000.00
8CB0E0	2017-08-14 12:53:00+03	12100.00
8CB0E8	2017-08-11 03:38:00+03	73600.00
8CB0F5	2017-07-17 04:50:00+03	65900.00
8CB10B	2017-07-05 04:51:00+03	81600.00
8CB13E	2017-07-31 16:56:00+03	54000.00
8CB156	2017-07-17 09:05:00+03	217600.00
8CB25C	2017-08-13 00:59:00+03	68100.00
8CB282	2017-07-28 12:51:00+03	136800.00
8CB2CE	2017-07-26 16:48:00+03	73100.00
8CB2E7	2017-07-11 23:44:00+03	58800.00
8CB39D	2017-08-05 07:12:00+03	56000.00
8CB3B0	2017-08-02 12:24:00+03	46200.00
8CB3B1	2017-08-07 14:43:00+03	125200.00
8CB3F2	2017-08-05 06:00:00+03	111600.00
8CB44A	2017-07-08 02:23:00+03	42700.00
8CB4B6	2017-07-25 22:30:00+03	23600.00
8CB4DA	2017-07-21 12:37:00+03	23200.00
8CB506	2017-07-08 17:08:00+03	85000.00
8CB513	2017-07-15 07:55:00+03	186000.00
8CB51A	2017-07-23 06:42:00+03	38600.00
8CB5DB	2017-06-29 20:01:00+03	155600.00
8CB5EB	2017-06-28 13:16:00+03	92100.00
8CB667	2017-07-20 14:19:00+03	23200.00
8CB6BA	2017-07-02 10:54:00+03	56900.00
8CB6F6	2017-07-08 11:33:00+03	257600.00
8CB6FA	2017-08-10 21:34:00+03	61800.00
8CB71C	2017-07-31 20:33:00+03	27900.00
8CB789	2017-07-26 11:48:00+03	27200.00
8CB7E4	2017-08-14 06:38:00+03	23200.00
8CB7F2	2017-07-27 04:31:00+03	112000.00
8CB848	2017-07-28 20:55:00+03	34200.00
8CB856	2017-07-24 18:19:00+03	30000.00
8CB8D5	2017-07-06 21:52:00+03	31600.00
8CB921	2017-07-05 13:25:00+03	136000.00
8CB92D	2017-08-06 02:22:00+03	31600.00
8CB9FF	2017-07-20 04:51:00+03	38800.00
8CBA1D	2017-08-07 13:01:00+03	58800.00
8CBA23	2017-07-18 23:15:00+03	69000.00
8CBA37	2017-07-31 16:16:00+03	112200.00
8CBAE1	2017-07-28 06:05:00+03	57500.00
8CBB38	2017-08-11 12:35:00+03	25600.00
8CBB39	2017-06-29 15:59:00+03	301900.00
8CBB3A	2017-07-29 07:17:00+03	49800.00
8CBB77	2017-07-16 13:23:00+03	170000.00
8CBC5C	2017-08-05 15:54:00+03	133700.00
8CBC66	2017-07-21 15:40:00+03	46000.00
8CBD05	2017-08-13 00:36:00+03	75600.00
8CBD73	2017-07-04 07:31:00+03	136000.00
8CBDA5	2017-06-30 13:23:00+03	53300.00
8CBDCC	2017-08-03 12:26:00+03	43300.00
8CBDD6	2017-08-10 05:03:00+03	51200.00
8CBE1B	2017-07-01 12:43:00+03	43000.00
8CBE1D	2017-07-03 11:18:00+03	21400.00
8CBEA0	2017-07-04 05:24:00+03	195800.00
8CBEB7	2017-07-17 20:02:00+03	12600.00
8CBECE	2017-08-13 16:52:00+03	78600.00
8CBF29	2017-08-11 08:46:00+03	123400.00
8CBF3B	2017-08-13 06:48:00+03	92400.00
8CBF45	2017-07-07 00:45:00+03	41600.00
8CBFA8	2017-07-04 11:30:00+03	19600.00
8CBFB4	2017-08-10 23:02:00+03	15000.00
8CBFCB	2017-07-25 04:04:00+03	43000.00
8CBFCF	2017-06-28 20:10:00+03	25000.00
8CC056	2017-07-19 00:16:00+03	223200.00
8CC07C	2017-07-11 08:02:00+03	25600.00
8CC08E	2017-07-16 18:23:00+03	104200.00
8CC0CD	2017-08-03 13:29:00+03	105100.00
8CC0D3	2017-08-13 21:43:00+03	159200.00
8CC0F5	2017-07-10 15:07:00+03	58000.00
8CC109	2017-07-30 04:36:00+03	46300.00
8CC154	2017-07-19 16:51:00+03	92900.00
8CC160	2017-08-15 00:38:00+03	28000.00
8CC171	2017-08-04 06:22:00+03	164800.00
8CC172	2017-08-04 01:51:00+03	77000.00
8CC1AE	2017-08-09 06:22:00+03	46400.00
8CC211	2017-07-09 23:57:00+03	120100.00
8CC223	2017-07-23 16:24:00+03	11000.00
8CC24D	2017-08-09 14:39:00+03	422700.00
8CC251	2017-07-27 09:10:00+03	37900.00
8CC26C	2017-07-26 17:23:00+03	129700.00
8CC27D	2017-07-28 22:17:00+03	73500.00
8CC288	2017-07-21 06:43:00+03	98800.00
8CC2CF	2017-07-16 01:06:00+03	25800.00
8CC2FF	2017-07-03 17:46:00+03	88300.00
8CC303	2017-07-06 03:51:00+03	22000.00
8CC33F	2017-07-26 10:48:00+03	102100.00
8CC35B	2017-07-26 09:53:00+03	54800.00
8CC365	2017-07-11 23:22:00+03	12600.00
8CC3E4	2017-08-05 15:09:00+03	64800.00
8CC44A	2017-07-10 17:46:00+03	43200.00
8CC472	2017-07-15 17:40:00+03	199700.00
8CC47D	2017-08-10 04:43:00+03	40600.00
8CC49D	2017-07-24 10:20:00+03	94600.00
8CC4F5	2017-07-31 14:57:00+03	398500.00
8CC573	2017-07-23 14:20:00+03	22000.00
8CC5B0	2017-07-26 16:45:00+03	56600.00
8CC5C1	2017-07-22 21:44:00+03	199700.00
8CC604	2017-08-09 19:29:00+03	59300.00
8CC606	2017-07-18 16:21:00+03	28000.00
8CC610	2017-08-03 19:06:00+03	24800.00
8CC63A	2017-07-30 15:45:00+03	303500.00
8CC65A	2017-07-20 16:00:00+03	42400.00
8CC681	2017-07-17 03:59:00+03	254900.00
8CC6D3	2017-08-12 00:59:00+03	56000.00
8CC6EE	2017-07-15 20:23:00+03	132800.00
8CC706	2017-07-03 01:22:00+03	28300.00
8CC719	2017-08-02 21:31:00+03	133200.00
8CC74F	2017-07-05 04:40:00+03	56000.00
8CC8AA	2017-07-31 20:26:00+03	10600.00
8CC916	2017-07-06 02:06:00+03	24200.00
8CC96F	2017-07-21 09:23:00+03	25800.00
8CC9AD	2017-07-26 13:57:00+03	126600.00
8CCAAE	2017-07-09 09:44:00+03	61200.00
8CCB98	2017-07-25 07:16:00+03	75100.00
8CCBD7	2017-08-13 15:52:00+03	136200.00
8CCBF2	2017-07-20 17:59:00+03	167400.00
8CCBF7	2017-07-05 12:32:00+03	138300.00
8CCC92	2017-07-07 01:39:00+03	44600.00
8CCD01	2017-07-20 06:57:00+03	155600.00
8CCD19	2017-07-30 15:57:00+03	59800.00
8CCD36	2017-07-31 15:57:00+03	78800.00
8CCD46	2017-08-03 19:36:00+03	176800.00
8CCD85	2017-08-08 05:09:00+03	112000.00
8CCDCF	2017-06-30 21:39:00+03	465900.00
8CCDDC	2017-07-03 21:54:00+03	20000.00
8CCE53	2017-08-13 00:54:00+03	46000.00
8CCE55	2017-07-15 04:51:00+03	119700.00
8CCE64	2017-07-14 05:13:00+03	31000.00
8CCECF	2017-08-02 21:37:00+03	95600.00
8CCEE0	2017-07-04 01:35:00+03	284400.00
8CCEFC	2017-08-07 17:47:00+03	32800.00
8CCF33	2017-07-25 22:04:00+03	198400.00
8CCF45	2017-07-11 19:59:00+03	78000.00
8CCF48	2017-07-16 11:06:00+03	27800.00
8CCFB2	2017-08-09 23:47:00+03	122800.00
8CCFEC	2017-07-14 06:41:00+03	163600.00
8CCFEF	2017-07-20 05:03:00+03	400600.00
8CD07E	2017-07-15 02:45:00+03	76100.00
8CD09C	2017-07-06 08:14:00+03	369000.00
8CD0EC	2017-07-24 18:09:00+03	134400.00
8CD174	2017-08-12 22:41:00+03	52200.00
8CD17A	2017-07-05 08:43:00+03	134800.00
8CD195	2017-06-30 18:29:00+03	13700.00
8CD243	2017-08-15 00:07:00+03	26200.00
8CD26C	2017-06-30 11:57:00+03	45100.00
8CD274	2017-07-28 07:17:00+03	70700.00
8CD2B7	2017-07-05 08:41:00+03	167200.00
8CD2C3	2017-07-08 00:12:00+03	42800.00
8CD2D7	2017-07-21 00:05:00+03	21400.00
8CD32E	2017-07-20 18:50:00+03	28800.00
8CD344	2017-07-14 08:07:00+03	59700.00
8CD44F	2017-07-10 05:48:00+03	6000.00
8CD564	2017-07-15 10:38:00+03	80500.00
8CD575	2017-08-11 16:02:00+03	24300.00
8CD5D8	2017-08-02 14:21:00+03	144000.00
8CD5F0	2017-07-13 01:47:00+03	123000.00
8CD644	2017-07-01 13:13:00+03	63200.00
8CD66E	2017-07-02 05:11:00+03	258400.00
8CD69C	2017-07-30 17:02:00+03	56000.00
8CD6D1	2017-08-08 21:15:00+03	89200.00
8CD702	2017-07-01 03:47:00+03	21500.00
8CD703	2017-07-20 22:19:00+03	62600.00
8CD722	2017-07-08 14:22:00+03	55700.00
8CD846	2017-08-11 14:27:00+03	40800.00
8CD889	2017-07-29 10:31:00+03	28000.00
8CD92E	2017-08-04 10:49:00+03	24400.00
8CD969	2017-07-18 07:00:00+03	418400.00
8CD987	2017-07-25 16:15:00+03	22000.00
8CD98E	2017-07-23 07:19:00+03	234600.00
8CD9CF	2017-07-30 16:06:00+03	166100.00
8CD9F0	2017-08-14 10:49:00+03	37400.00
8CD9FA	2017-07-06 08:33:00+03	23200.00
8CDA1D	2017-07-26 11:25:00+03	99800.00
8CDAC8	2017-07-19 22:58:00+03	144400.00
8CDAD4	2017-07-18 15:18:00+03	16400.00
8CDB36	2017-07-13 06:15:00+03	28800.00
8CDBAE	2017-08-03 18:25:00+03	20800.00
8CDBE6	2017-08-07 21:32:00+03	18600.00
8CDBE9	2017-08-12 14:13:00+03	40600.00
8CDC51	2017-08-05 06:50:00+03	23400.00
8CDCB9	2017-07-29 00:44:00+03	23200.00
8CDD35	2017-07-20 13:36:00+03	103800.00
8CDD36	2017-07-19 14:13:00+03	92800.00
8CDD4F	2017-07-14 10:59:00+03	99000.00
8CDD60	2017-07-11 18:01:00+03	11700.00
8CDDBB	2017-07-18 09:42:00+03	164400.00
8CDE17	2017-07-17 06:53:00+03	38800.00
8CDE23	2017-08-08 09:58:00+03	42600.00
8CDE3C	2017-08-10 02:06:00+03	56600.00
8CDE90	2017-08-13 14:22:00+03	283100.00
8CDE9F	2017-07-23 09:17:00+03	59800.00
8CDEC8	2017-06-28 08:02:00+03	32700.00
8CDF10	2017-07-06 00:15:00+03	6300.00
8CDF8C	2017-08-06 07:54:00+03	188200.00
8CDF90	2017-07-04 12:05:00+03	56600.00
8CDFE8	2017-08-04 01:01:00+03	14400.00
8CE00E	2017-07-03 09:49:00+03	113100.00
8CE066	2017-07-22 11:39:00+03	36200.00
8CE094	2017-08-13 22:10:00+03	49500.00
8CE0BC	2017-07-26 11:41:00+03	46400.00
8CE0D0	2017-07-28 11:28:00+03	48800.00
8CE167	2017-07-07 12:02:00+03	22400.00
8CE224	2017-07-26 21:34:00+03	155600.00
8CE232	2017-07-21 15:27:00+03	36200.00
8CE24B	2017-08-08 07:21:00+03	32200.00
8CE261	2017-08-03 16:25:00+03	23600.00
8CE295	2017-07-13 11:48:00+03	23900.00
8CE38F	2017-07-16 11:55:00+03	65900.00
8CE390	2017-07-31 13:07:00+03	73200.00
8CE396	2017-07-29 04:18:00+03	55000.00
8CE470	2017-08-05 19:54:00+03	75300.00
8CE496	2017-07-15 03:56:00+03	289800.00
8CE4C4	2017-07-10 14:18:00+03	26000.00
8CE4D4	2017-07-03 08:25:00+03	70600.00
8CE558	2017-07-26 08:59:00+03	66600.00
8CE589	2017-07-18 15:41:00+03	98400.00
8CE59C	2017-08-11 23:28:00+03	61800.00
8CE617	2017-08-08 12:52:00+03	194300.00
8CE662	2017-07-07 17:09:00+03	47000.00
8CE684	2017-07-25 00:55:00+03	16400.00
8CE6A6	2017-08-01 06:44:00+03	135400.00
8CE6E0	2017-07-28 05:19:00+03	92800.00
8CE6ED	2017-07-14 22:12:00+03	55800.00
8CE76E	2017-07-17 06:46:00+03	53600.00
8CE7E3	2017-07-17 20:11:00+03	118600.00
8CE7E9	2017-07-05 22:50:00+03	27200.00
8CE821	2017-07-05 08:33:00+03	40800.00
8CE837	2017-06-26 09:37:00+03	27800.00
8CE841	2017-08-14 07:23:00+03	87800.00
8CE912	2017-07-27 20:08:00+03	31800.00
8CE953	2017-07-28 01:26:00+03	38600.00
8CE95D	2017-08-06 23:13:00+03	92400.00
8CE96B	2017-07-09 03:32:00+03	31600.00
8CE9A6	2017-08-08 16:52:00+03	115700.00
8CE9AD	2017-07-23 23:02:00+03	136800.00
8CE9D2	2017-08-01 01:12:00+03	18000.00
8CEA4D	2017-07-11 02:55:00+03	46500.00
8CEA85	2017-07-07 09:18:00+03	31700.00
8CEA98	2017-08-08 23:40:00+03	60000.00
8CEAC8	2017-07-06 07:05:00+03	325500.00
8CEAE7	2017-08-14 19:05:00+03	18700.00
8CEB1E	2017-07-19 04:45:00+03	273500.00
8CEB20	2017-07-31 06:52:00+03	122300.00
8CEB23	2017-07-15 18:25:00+03	8400.00
8CEB36	2017-08-09 05:53:00+03	21800.00
8CEBCA	2017-07-28 05:06:00+03	39300.00
8CEC2F	2017-08-02 23:32:00+03	13400.00
8CEC3D	2017-07-30 20:59:00+03	67600.00
8CEC6A	2017-07-06 13:57:00+03	179300.00
8CEC74	2017-07-11 00:21:00+03	99500.00
8CEC8B	2017-07-18 23:01:00+03	59800.00
8CECA2	2017-07-27 14:42:00+03	52300.00
8CED4A	2017-07-25 01:44:00+03	70600.00
8CED70	2017-07-06 18:17:00+03	68800.00
8CED77	2017-07-25 18:27:00+03	22400.00
8CED86	2017-07-01 14:47:00+03	79000.00
8CEDC8	2017-07-08 07:29:00+03	11700.00
8CEDCA	2017-07-25 12:04:00+03	28700.00
8CEE21	2017-07-25 17:06:00+03	666000.00
8CEE39	2017-07-22 16:30:00+03	13800.00
8CEE5F	2017-07-11 10:01:00+03	12400.00
8CEE74	2017-08-10 19:03:00+03	69500.00
8CEE84	2017-07-11 01:26:00+03	136200.00
8CEEA3	2017-07-26 17:33:00+03	90000.00
8CEED7	2017-07-08 13:02:00+03	40400.00
8CEF5B	2017-08-03 13:55:00+03	65800.00
8CEF9A	2017-08-11 21:01:00+03	12600.00
8CEFE1	2017-07-25 09:01:00+03	357600.00
8CF06C	2017-07-30 02:28:00+03	23600.00
8CF105	2017-07-28 09:04:00+03	206400.00
8CF112	2017-08-05 03:02:00+03	17800.00
8CF118	2017-07-05 08:27:00+03	81900.00
8CF19F	2017-07-14 20:36:00+03	93600.00
8CF1B4	2017-08-05 20:55:00+03	70700.00
8CF1B6	2017-08-01 02:36:00+03	39600.00
8CF258	2017-07-05 09:36:00+03	213800.00
8CF267	2017-07-25 17:11:00+03	28000.00
8CF2BE	2017-07-19 07:30:00+03	267500.00
8CF318	2017-08-13 21:42:00+03	29000.00
8CF37A	2017-07-03 20:44:00+03	26600.00
8CF3C9	2017-08-11 14:32:00+03	123000.00
8CF3F2	2017-07-11 07:45:00+03	22000.00
8CF45D	2017-08-06 22:25:00+03	34600.00
8CF484	2017-08-10 03:58:00+03	29200.00
8CF4AB	2017-08-05 09:36:00+03	65900.00
8CF4AD	2017-07-08 01:39:00+03	79700.00
8CF4DF	2017-07-16 22:21:00+03	66700.00
8CF4EC	2017-07-20 00:50:00+03	558700.00
8CF631	2017-07-16 18:18:00+03	56200.00
8CF6FA	2017-07-26 06:40:00+03	112000.00
8CF764	2017-07-12 09:50:00+03	8400.00
8CF778	2017-07-07 02:28:00+03	544700.00
8CF81C	2017-07-06 02:08:00+03	447400.00
8CF896	2017-07-26 16:55:00+03	61500.00
8CF8B9	2017-07-14 13:59:00+03	67200.00
8CF8D9	2017-08-08 15:28:00+03	21400.00
8CF92E	2017-07-01 03:44:00+03	105800.00
8CF944	2017-07-09 04:29:00+03	406700.00
8CF9BD	2017-07-04 04:19:00+03	76600.00
8CF9C3	2017-07-24 16:19:00+03	56600.00
8CF9DB	2017-07-26 03:28:00+03	81500.00
8CFA0F	2017-08-06 19:26:00+03	135200.00
8CFA33	2017-07-04 05:09:00+03	49800.00
8CFA8F	2017-08-10 17:45:00+03	26000.00
8CFA94	2017-07-02 10:32:00+03	114800.00
8CFB3D	2017-08-13 11:12:00+03	12400.00
8CFBA4	2017-08-14 09:36:00+03	28700.00
8CFBD0	2017-07-04 03:05:00+03	270600.00
8CFBD4	2017-07-18 20:42:00+03	73200.00
8CFBE3	2017-07-27 11:50:00+03	11600.00
8CFC11	2017-07-08 23:05:00+03	125200.00
8CFCAD	2017-07-21 03:50:00+03	46300.00
8CFD16	2017-08-15 06:14:00+03	43600.00
8CFD31	2017-08-07 03:09:00+03	184500.00
8CFD3D	2017-08-12 00:15:00+03	18600.00
8CFD70	2017-07-04 19:32:00+03	146300.00
8CFDA9	2017-07-28 23:02:00+03	13800.00
8CFDCC	2017-07-07 13:38:00+03	97800.00
8CFDCF	2017-07-07 19:21:00+03	85000.00
8CFDE3	2017-07-02 23:02:00+03	46400.00
8CFE05	2017-07-06 09:27:00+03	112600.00
8CFE06	2017-07-22 06:56:00+03	131800.00
8CFE36	2017-07-22 19:44:00+03	92800.00
8CFE70	2017-07-27 04:46:00+03	26000.00
8CFE74	2017-07-13 18:18:00+03	32800.00
8CFEBD	2017-08-15 15:22:00+03	76000.00
8CFEDB	2017-07-04 18:08:00+03	111700.00
8CFF0F	2017-07-09 11:18:00+03	154800.00
8CFF39	2017-07-10 02:52:00+03	181500.00
8CFF84	2017-07-13 15:19:00+03	75600.00
8D002A	2017-07-26 06:28:00+03	26000.00
8D004E	2017-08-11 19:40:00+03	39300.00
8D00A8	2017-08-04 17:29:00+03	53600.00
8D00D1	2017-07-24 10:08:00+03	62700.00
8D0104	2017-07-06 10:21:00+03	38600.00
8D0134	2017-07-07 03:10:00+03	46000.00
8D01C6	2017-07-25 18:26:00+03	435800.00
8D0240	2017-08-08 21:19:00+03	28700.00
8D0281	2017-07-19 02:55:00+03	515100.00
8D0298	2017-07-31 22:39:00+03	68400.00
8D02A0	2017-08-15 17:15:00+03	49600.00
8D02C9	2017-07-14 06:37:00+03	12600.00
8D03E7	2017-07-25 04:16:00+03	139400.00
8D03F8	2017-07-29 19:01:00+03	270800.00
8D03FB	2017-08-05 17:18:00+03	26800.00
8D040E	2017-07-17 06:57:00+03	24700.00
8D045A	2017-08-09 17:17:00+03	47300.00
8D0470	2017-08-01 23:57:00+03	44600.00
8D04A0	2017-07-21 11:58:00+03	60200.00
8D04F1	2017-08-14 13:51:00+03	207200.00
8D0552	2017-07-16 23:03:00+03	42800.00
8D055F	2017-08-11 05:20:00+03	69600.00
8D059C	2017-08-11 23:02:00+03	39500.00
8D0618	2017-07-28 12:09:00+03	77200.00
8D069E	2017-07-09 04:46:00+03	64800.00
8D06B7	2017-07-19 07:37:00+03	56000.00
8D06C5	2017-07-02 21:12:00+03	34200.00
8D0708	2017-07-28 02:18:00+03	189800.00
8D0730	2017-07-01 21:19:00+03	24400.00
8D0742	2017-07-09 19:05:00+03	31400.00
8D074D	2017-08-12 09:07:00+03	89200.00
8D077C	2017-07-04 13:11:00+03	549000.00
8D07A9	2017-07-22 22:38:00+03	12000.00
8D07BA	2017-07-25 02:07:00+03	103500.00
8D0846	2017-07-26 19:41:00+03	40800.00
8D0854	2017-08-11 17:51:00+03	11900.00
8D08FE	2017-08-07 13:23:00+03	62500.00
8D092A	2017-07-22 01:46:00+03	43200.00
8D093F	2017-06-29 16:08:00+03	65400.00
8D0959	2017-07-09 22:57:00+03	28800.00
8D09D6	2017-08-15 00:46:00+03	167400.00
8D09F9	2017-07-10 16:44:00+03	238200.00
8D0A13	2017-07-20 03:39:00+03	57400.00
8D0A3B	2017-07-17 11:17:00+03	46000.00
8D0A85	2017-08-03 04:54:00+03	45300.00
8D0A99	2017-07-26 09:27:00+03	67000.00
8D0B1D	2017-07-16 09:54:00+03	22600.00
8D0B4D	2017-07-10 22:45:00+03	57800.00
8D0BE5	2017-07-11 07:17:00+03	111600.00
8D0C01	2017-07-26 14:23:00+03	62600.00
8D0CA9	2017-08-04 16:11:00+03	72400.00
8D0D07	2017-07-05 23:42:00+03	136000.00
8D0D0C	2017-08-04 02:28:00+03	28000.00
8D0D46	2017-07-30 21:56:00+03	372500.00
8D0D5D	2017-07-04 05:04:00+03	42800.00
8D0D8A	2017-07-28 10:42:00+03	57500.00
8D0DF0	2017-07-05 18:18:00+03	252200.00
8D0E05	2017-07-26 03:49:00+03	14400.00
8D0E30	2017-08-10 23:57:00+03	31600.00
8D0E6B	2017-07-20 16:39:00+03	199600.00
8D0E75	2017-08-08 00:32:00+03	132800.00
8D0EBB	2017-08-04 18:51:00+03	14000.00
8D0F01	2017-07-05 18:32:00+03	167400.00
8D0F0E	2017-08-12 04:16:00+03	22000.00
8D0F2B	2017-06-27 09:05:00+03	138600.00
8D105C	2017-07-15 11:38:00+03	80000.00
8D1072	2017-08-08 20:49:00+03	75300.00
8D1091	2017-07-15 05:48:00+03	133200.00
8D109A	2017-08-12 22:14:00+03	122500.00
8D10FC	2017-07-13 11:29:00+03	77200.00
8D1116	2017-07-16 03:37:00+03	65400.00
8D113E	2017-07-25 15:36:00+03	6700.00
8D1154	2017-07-26 00:12:00+03	38600.00
8D1182	2017-07-12 13:07:00+03	46400.00
8D11DF	2017-07-17 08:47:00+03	117200.00
8D11F2	2017-07-08 18:32:00+03	103000.00
8D1219	2017-07-22 09:04:00+03	56000.00
8D12E5	2017-07-24 03:05:00+03	58600.00
8D131B	2017-08-14 20:29:00+03	68800.00
8D136A	2017-08-07 18:43:00+03	64500.00
8D1388	2017-07-31 09:53:00+03	160200.00
8D13D8	2017-08-03 18:59:00+03	37700.00
8D1417	2017-07-18 14:05:00+03	47400.00
8D1446	2017-07-11 18:06:00+03	13600.00
8D14AB	2017-07-17 14:57:00+03	65900.00
8D14CD	2017-07-16 14:38:00+03	111600.00
8D14FF	2017-08-11 03:23:00+03	52000.00
8D1503	2017-07-12 21:12:00+03	186900.00
8D153B	2017-08-05 08:00:00+03	93700.00
8D155B	2017-07-17 01:09:00+03	8000.00
8D158A	2017-07-17 09:11:00+03	78000.00
8D15E3	2017-08-07 18:03:00+03	28800.00
8D15E7	2017-07-10 03:17:00+03	46400.00
8D161D	2017-07-14 11:03:00+03	92800.00
8D1701	2017-07-25 15:27:00+03	13400.00
8D178F	2017-07-08 22:29:00+03	13600.00
8D17C9	2017-07-05 06:27:00+03	81800.00
8D17E8	2017-07-10 23:54:00+03	66600.00
8D180C	2017-07-19 17:57:00+03	135400.00
8D18C0	2017-06-30 19:47:00+03	33800.00
8D18E4	2017-07-14 15:11:00+03	112600.00
8D18F8	2017-06-30 07:16:00+03	38600.00
8D1960	2017-08-12 15:30:00+03	30400.00
8D1973	2017-07-30 18:46:00+03	24400.00
8D19A7	2017-07-06 04:54:00+03	44800.00
8D19E5	2017-08-09 16:01:00+03	125400.00
8D19E7	2017-07-27 02:39:00+03	12600.00
8D19EF	2017-07-22 15:45:00+03	43600.00
8D1A31	2017-08-05 05:10:00+03	81700.00
8D1A46	2017-08-13 16:33:00+03	136800.00
8D1A6E	2017-07-29 22:35:00+03	139300.00
8D1A7E	2017-07-22 11:36:00+03	90800.00
8D1A97	2017-07-04 17:48:00+03	24400.00
8D1AB4	2017-07-18 17:56:00+03	56600.00
8D1B4B	2017-08-05 00:33:00+03	111600.00
8D1B85	2017-07-15 11:15:00+03	323900.00
8D1B99	2017-07-15 20:07:00+03	46300.00
8D1B9F	2017-07-25 22:01:00+03	86300.00
8D1BBF	2017-07-09 22:41:00+03	418400.00
8D1BC9	2017-07-07 04:35:00+03	70700.00
8D1BD2	2017-07-27 11:37:00+03	46500.00
8D1C00	2017-08-13 01:55:00+03	112600.00
8D1C1E	2017-07-08 11:55:00+03	28000.00
8D1C3E	2017-07-06 12:38:00+03	28000.00
8D1C56	2017-07-05 09:20:00+03	95700.00
8D1C79	2017-07-02 05:20:00+03	6300.00
8D1C98	2017-07-16 15:12:00+03	61200.00
8D1CB8	2017-07-22 08:32:00+03	28000.00
8D1CD9	2017-08-06 02:30:00+03	101200.00
8D1CE2	2017-07-15 15:37:00+03	58000.00
8D1CE7	2017-07-24 17:45:00+03	67600.00
8D1D30	2017-07-10 16:13:00+03	13400.00
8D1D86	2017-07-22 03:13:00+03	154000.00
8D1E1C	2017-07-31 20:57:00+03	47400.00
8D1EE5	2017-07-25 12:20:00+03	26600.00
8D1EEC	2017-08-12 22:12:00+03	48700.00
8D1EFE	2017-08-01 00:48:00+03	36800.00
8D1FBF	2017-07-16 16:23:00+03	124200.00
8D200C	2017-07-08 22:34:00+03	57600.00
8D2035	2017-08-14 00:44:00+03	226200.00
8D207E	2017-07-05 03:58:00+03	28000.00
8D20EB	2017-08-13 15:25:00+03	35700.00
8D20F3	2017-07-04 05:58:00+03	55800.00
8D210F	2017-07-04 00:24:00+03	56000.00
8D2110	2017-07-07 01:13:00+03	115400.00
8D2157	2017-08-06 07:16:00+03	28000.00
8D219A	2017-07-20 05:51:00+03	193100.00
8D21B3	2017-07-07 20:42:00+03	248400.00
8D2268	2017-07-06 03:59:00+03	23200.00
8D2283	2017-07-22 21:35:00+03	75600.00
8D22A3	2017-08-08 08:24:00+03	39600.00
8D22A6	2017-07-16 02:13:00+03	20200.00
8D22D5	2017-08-12 14:25:00+03	28000.00
8D2314	2017-08-11 08:46:00+03	12600.00
8D233B	2017-08-01 01:22:00+03	12600.00
8D2358	2017-07-26 02:43:00+03	111600.00
8D2385	2017-07-09 09:21:00+03	409200.00
8D23EB	2017-07-02 03:43:00+03	835600.00
8D241C	2017-08-01 04:06:00+03	46200.00
8D245D	2017-07-13 05:33:00+03	96300.00
8D24FA	2017-07-14 05:28:00+03	44800.00
8D2502	2017-07-19 23:09:00+03	117900.00
8D2540	2017-07-29 19:55:00+03	184300.00
8D2560	2017-08-04 09:33:00+03	40400.00
8D2565	2017-07-11 16:31:00+03	21200.00
8D256F	2017-07-09 04:01:00+03	52700.00
8D261C	2017-07-30 13:24:00+03	61800.00
8D261E	2017-08-04 06:09:00+03	36200.00
8D2649	2017-07-04 13:15:00+03	324400.00
8D2687	2017-07-25 18:57:00+03	38800.00
8D26A1	2017-07-24 19:06:00+03	59800.00
8D26CE	2017-06-29 19:50:00+03	174000.00
8D26E7	2017-08-10 06:01:00+03	29400.00
8D26F9	2017-08-11 06:03:00+03	394400.00
8D2704	2017-07-27 17:27:00+03	135400.00
8D273C	2017-07-04 07:45:00+03	136200.00
8D2792	2017-07-12 12:57:00+03	69500.00
8D27E6	2017-07-30 03:21:00+03	10800.00
8D27F7	2017-07-08 02:54:00+03	25200.00
8D28B7	2017-07-18 08:32:00+03	27200.00
8D28DB	2017-08-09 20:02:00+03	14000.00
8D28E8	2017-07-22 04:45:00+03	29400.00
8D28F3	2017-07-14 03:24:00+03	28000.00
8D2961	2017-07-13 09:28:00+03	202400.00
8D2982	2017-07-05 07:27:00+03	66600.00
8D2990	2017-08-05 15:38:00+03	98000.00
8D2A05	2017-08-15 04:42:00+03	28000.00
8D2A2A	2017-07-27 19:13:00+03	89600.00
8D2A46	2017-08-05 11:19:00+03	115900.00
8D2A4A	2017-07-17 15:11:00+03	55800.00
8D2A57	2017-08-09 00:38:00+03	40600.00
8D2A8D	2017-07-03 23:30:00+03	86600.00
8D2AB4	2017-07-05 11:07:00+03	62600.00
8D2ABE	2017-07-15 00:39:00+03	105600.00
8D2AC8	2017-08-08 13:37:00+03	27700.00
8D2AED	2017-06-28 13:36:00+03	240600.00
8D2B34	2017-07-28 17:41:00+03	40600.00
8D2B52	2017-08-12 01:04:00+03	6800.00
8D2BD4	2017-07-04 00:56:00+03	50100.00
8D2C75	2017-08-05 01:42:00+03	23200.00
8D2C96	2017-07-07 21:14:00+03	24700.00
8D2CF7	2017-07-03 22:09:00+03	25200.00
8D2D92	2017-08-13 08:07:00+03	32500.00
8D2D98	2017-08-06 11:14:00+03	6200.00
8D2DAA	2017-08-06 18:46:00+03	20800.00
8D2E0C	2017-07-04 00:34:00+03	24400.00
8D2E24	2017-07-24 14:04:00+03	8000.00
8D2E71	2017-08-01 21:00:00+03	46200.00
8D2E96	2017-07-22 12:22:00+03	81600.00
8D2EB7	2017-07-29 10:34:00+03	74000.00
8D2FBB	2017-07-22 08:31:00+03	23600.00
8D2FD1	2017-08-06 03:34:00+03	92800.00
8D2FD7	2017-07-16 22:54:00+03	58800.00
8D3019	2017-08-14 01:24:00+03	116900.00
8D3043	2017-08-11 19:20:00+03	55800.00
8D304A	2017-07-03 23:34:00+03	99600.00
8D307B	2017-07-16 14:32:00+03	20600.00
8D30FC	2017-08-09 11:58:00+03	75700.00
8D3134	2017-08-05 01:52:00+03	61900.00
8D316E	2017-07-13 19:34:00+03	23200.00
8D3268	2017-07-29 05:08:00+03	67900.00
8D32B7	2017-08-07 12:40:00+03	69000.00
8D3338	2017-08-06 05:27:00+03	284300.00
8D3343	2017-08-11 03:56:00+03	32800.00
8D339D	2017-08-14 19:26:00+03	74700.00
8D33D3	2017-07-07 11:49:00+03	61900.00
8D341D	2017-07-11 21:53:00+03	30200.00
8D344A	2017-07-08 18:06:00+03	29600.00
8D3455	2017-08-02 12:37:00+03	57400.00
8D3541	2017-07-31 20:20:00+03	38400.00
8D3549	2017-07-30 11:55:00+03	179200.00
8D35FE	2017-07-14 01:22:00+03	59100.00
8D3638	2017-08-02 12:41:00+03	28800.00
8D3670	2017-08-14 03:56:00+03	35300.00
8D3788	2017-07-05 09:32:00+03	64500.00
8D3790	2017-07-06 05:43:00+03	65900.00
8D379A	2017-07-24 05:32:00+03	24800.00
8D3800	2017-08-01 10:24:00+03	6000.00
8D385B	2017-08-13 21:26:00+03	119700.00
8D38DA	2017-07-31 06:18:00+03	27200.00
8D393E	2017-08-13 04:00:00+03	130400.00
8D3948	2017-08-14 12:34:00+03	135400.00
8D3B5C	2017-08-08 12:32:00+03	124200.00
8D3BD9	2017-07-21 21:14:00+03	55800.00
8D3C12	2017-07-24 16:42:00+03	9800.00
8D3CC0	2017-07-20 10:10:00+03	58600.00
8D3D25	2017-07-08 19:45:00+03	81900.00
8D3D45	2017-08-06 01:59:00+03	169900.00
8D3D84	2017-07-18 07:34:00+03	73400.00
8D3D96	2017-07-22 18:07:00+03	12400.00
8D3DE6	2017-07-30 19:20:00+03	131100.00
8D3E9E	2017-07-05 14:06:00+03	102100.00
8D3ED0	2017-08-08 06:31:00+03	12600.00
8D3F43	2017-07-13 15:18:00+03	56300.00
8D3F83	2017-07-30 07:36:00+03	114800.00
8D3FAC	2017-07-20 01:34:00+03	51200.00
8D3FD1	2017-07-03 05:25:00+03	8400.00
8D4024	2017-07-22 07:27:00+03	38400.00
8D406F	2017-07-31 22:11:00+03	27800.00
8D4083	2017-08-10 16:12:00+03	62600.00
8D40B5	2017-07-15 11:24:00+03	75300.00
8D4108	2017-08-15 10:34:00+03	62600.00
8D4117	2017-07-05 07:33:00+03	56000.00
8D4130	2017-07-22 20:23:00+03	48800.00
8D414A	2017-08-01 21:50:00+03	125400.00
8D4193	2017-07-14 22:43:00+03	134100.00
8D41F5	2017-07-20 11:30:00+03	176400.00
8D4273	2017-07-16 18:25:00+03	166100.00
8D4329	2017-08-09 01:44:00+03	92700.00
8D4339	2017-08-05 08:04:00+03	82500.00
8D43A4	2017-08-03 01:16:00+03	31600.00
8D4439	2017-07-06 10:53:00+03	260400.00
8D444A	2017-07-18 03:56:00+03	116400.00
8D445A	2017-08-11 10:26:00+03	85000.00
8D44A1	2017-07-31 22:59:00+03	26000.00
8D44F0	2017-08-13 16:59:00+03	112000.00
8D4504	2017-07-30 22:43:00+03	44000.00
8D4577	2017-06-29 06:04:00+03	149200.00
8D457B	2017-07-03 15:33:00+03	16400.00
8D45BC	2017-07-24 01:31:00+03	36200.00
8D45F7	2017-07-16 14:06:00+03	41200.00
8D4619	2017-07-16 11:33:00+03	34000.00
8D4653	2017-08-05 15:59:00+03	369000.00
8D4657	2017-07-27 23:02:00+03	42700.00
8D46AE	2017-07-21 00:39:00+03	124200.00
8D46B6	2017-07-29 18:21:00+03	170300.00
8D4789	2017-08-02 23:15:00+03	67600.00
8D4796	2017-07-11 19:18:00+03	28800.00
8D47A5	2017-08-15 07:05:00+03	6000.00
8D47B6	2017-08-05 03:14:00+03	55800.00
8D480C	2017-08-14 03:19:00+03	116500.00
8D4811	2017-07-06 00:37:00+03	112000.00
8D48CA	2017-07-08 22:47:00+03	125200.00
8D48CD	2017-07-04 22:25:00+03	57400.00
8D48F1	2017-06-28 10:57:00+03	8400.00
8D492D	2017-07-23 20:11:00+03	59800.00
8D49AE	2017-08-10 14:26:00+03	56000.00
8D49D4	2017-07-07 18:18:00+03	18300.00
8D4A00	2017-07-21 14:43:00+03	92400.00
8D4A0F	2017-07-02 22:57:00+03	266400.00
8D4A20	2017-07-25 05:59:00+03	176500.00
8D4A36	2017-07-16 03:39:00+03	189200.00
8D4A51	2017-07-24 04:15:00+03	54500.00
8D4A86	2017-06-28 18:40:00+03	48800.00
8D4AD9	2017-07-31 11:15:00+03	51900.00
8D4B04	2017-07-24 23:42:00+03	31900.00
8D4B4F	2017-08-09 14:02:00+03	33100.00
8D4B8F	2017-07-16 02:51:00+03	24400.00
8D4BC7	2017-07-16 15:23:00+03	141600.00
8D4BFA	2017-07-06 14:43:00+03	27200.00
8D4C25	2017-08-14 10:56:00+03	6000.00
8D4C2C	2017-07-21 13:21:00+03	83300.00
8D4C6F	2017-08-14 03:32:00+03	102100.00
8D4C98	2017-07-10 17:40:00+03	258400.00
8D4CF6	2017-08-08 13:01:00+03	56000.00
8D4DBD	2017-08-01 07:12:00+03	160800.00
8D4DED	2017-07-08 16:22:00+03	21400.00
8D4E55	2017-07-19 01:35:00+03	40000.00
8D4E62	2017-08-05 17:44:00+03	53400.00
8D4E8E	2017-07-26 01:11:00+03	152200.00
8D4EB0	2017-07-25 00:03:00+03	69500.00
8D4EB2	2017-08-01 06:20:00+03	16400.00
8D4F65	2017-08-10 10:18:00+03	59600.00
8D4F8E	2017-07-11 09:01:00+03	59300.00
8D4F94	2017-07-16 15:36:00+03	19600.00
8D4FA8	2017-07-30 22:50:00+03	56000.00
8D5003	2017-07-22 14:03:00+03	88600.00
8D5029	2017-07-25 18:48:00+03	114900.00
8D50F5	2017-07-26 22:02:00+03	12000.00
8D5132	2017-07-22 10:24:00+03	369000.00
8D5148	2017-07-29 10:29:00+03	43500.00
8D5163	2017-07-01 13:13:00+03	26800.00
8D517C	2017-07-07 03:59:00+03	369000.00
8D5191	2017-07-21 06:55:00+03	18900.00
8D51AD	2017-08-05 01:54:00+03	152600.00
8D51BA	2017-08-12 20:09:00+03	34700.00
8D51BD	2017-08-08 01:06:00+03	30000.00
8D51F0	2017-07-06 16:15:00+03	258400.00
8D52AF	2017-07-13 15:43:00+03	65200.00
8D5340	2017-08-11 01:03:00+03	14000.00
8D5373	2017-07-17 12:50:00+03	42400.00
8D53CF	2017-07-23 14:56:00+03	85400.00
8D53DA	2017-07-08 17:58:00+03	23600.00
8D53EF	2017-07-03 02:57:00+03	6700.00
8D543D	2017-07-19 19:12:00+03	39200.00
8D5586	2017-07-20 12:17:00+03	136100.00
8D55B3	2017-07-28 21:35:00+03	52400.00
8D55B8	2017-07-21 17:38:00+03	46700.00
8D55BD	2017-07-20 21:24:00+03	59200.00
8D5616	2017-07-15 21:40:00+03	70700.00
8D565A	2017-08-01 20:08:00+03	20800.00
8D56A2	2017-08-08 06:03:00+03	34200.00
8D571A	2017-07-21 09:24:00+03	29600.00
8D5766	2017-07-09 15:46:00+03	296400.00
8D576D	2017-08-07 15:54:00+03	69500.00
8D57A6	2017-08-14 03:26:00+03	9200.00
8D584B	2017-07-10 19:17:00+03	93900.00
8D58CB	2017-07-13 04:53:00+03	92000.00
8D58E7	2017-08-10 02:05:00+03	69400.00
8D58FA	2017-07-13 02:33:00+03	258300.00
8D5904	2017-07-22 13:15:00+03	112000.00
8D5930	2017-08-05 09:28:00+03	28000.00
8D59C2	2017-07-29 07:36:00+03	26000.00
8D5A0D	2017-08-02 08:22:00+03	21400.00
8D5A76	2017-07-07 10:52:00+03	69200.00
8D5AA0	2017-07-22 04:39:00+03	57600.00
8D5BA0	2017-07-24 12:46:00+03	22000.00
8D5BB0	2017-08-10 13:40:00+03	66600.00
8D5BD3	2017-07-15 18:12:00+03	66000.00
8D5BE4	2017-07-18 00:54:00+03	375200.00
8D5C75	2017-07-19 18:59:00+03	37700.00
8D5CA8	2017-08-13 21:40:00+03	28000.00
8D5CB0	2017-08-10 14:30:00+03	40100.00
8D5D02	2017-07-05 14:05:00+03	75800.00
8D5D53	2017-07-11 11:08:00+03	16400.00
8D5D70	2017-08-12 14:22:00+03	44400.00
8D5D8F	2017-08-08 00:34:00+03	62800.00
8D5E10	2017-07-10 09:22:00+03	53300.00
8D5E69	2017-07-07 09:23:00+03	115900.00
8D5FA4	2017-07-13 08:55:00+03	108600.00
8D5FA9	2017-07-07 07:39:00+03	73200.00
8D5FF9	2017-08-10 03:26:00+03	84000.00
8D602C	2017-08-04 10:24:00+03	160200.00
8D605B	2017-07-18 21:00:00+03	21400.00
8D6089	2017-08-14 17:14:00+03	117200.00
8D60BE	2017-07-03 23:19:00+03	58400.00
8D60E0	2017-08-04 22:55:00+03	90600.00
8D610C	2017-07-06 19:50:00+03	46400.00
8D6194	2017-08-07 07:11:00+03	31100.00
8D61D7	2017-08-13 08:25:00+03	51600.00
8D622A	2017-07-19 18:38:00+03	115900.00
8D6245	2017-07-09 02:48:00+03	46000.00
8D6267	2017-08-10 04:03:00+03	16800.00
8D62B1	2017-07-10 11:05:00+03	93600.00
8D6308	2017-07-18 16:43:00+03	104900.00
8D6320	2017-07-18 07:27:00+03	14400.00
8D6350	2017-08-01 23:23:00+03	26000.00
8D6368	2017-08-13 04:36:00+03	47200.00
8D6369	2017-08-09 17:22:00+03	38600.00
8D638B	2017-07-27 10:06:00+03	206400.00
8D6395	2017-07-29 19:50:00+03	51900.00
8D6415	2017-07-14 07:21:00+03	89200.00
8D64AE	2017-07-26 11:40:00+03	20400.00
8D6557	2017-08-11 04:57:00+03	119700.00
8D6576	2017-07-25 10:09:00+03	56000.00
8D6580	2017-07-28 02:47:00+03	116600.00
8D65B9	2017-07-15 07:57:00+03	84500.00
8D65BC	2017-08-09 11:56:00+03	81700.00
8D65FB	2017-08-08 19:37:00+03	40800.00
8D6630	2017-07-06 06:58:00+03	71400.00
8D66C9	2017-06-25 07:39:00+03	8200.00
8D6713	2017-07-12 00:40:00+03	65900.00
8D676F	2017-07-14 12:51:00+03	56000.00
8D67A1	2017-07-01 21:07:00+03	21500.00
8D67F5	2017-07-24 20:36:00+03	36700.00
8D67FA	2017-08-12 04:03:00+03	211900.00
8D6805	2017-07-07 13:41:00+03	86400.00
8D683A	2017-07-03 18:14:00+03	50400.00
8D6873	2017-07-03 13:09:00+03	6700.00
8D6955	2017-07-08 23:49:00+03	120700.00
8D6968	2017-08-09 20:57:00+03	64600.00
8D6981	2017-07-09 04:24:00+03	49800.00
8D69F6	2017-07-30 01:05:00+03	135600.00
8D6A13	2017-07-09 09:48:00+03	48900.00
8D6A15	2017-07-15 08:47:00+03	136500.00
8D6A5A	2017-07-21 19:13:00+03	59000.00
8D6A64	2017-07-02 23:31:00+03	64800.00
8D6A72	2017-07-27 22:45:00+03	135600.00
8D6B36	2017-07-21 07:45:00+03	63500.00
8D6B4B	2017-07-19 13:55:00+03	39400.00
8D6B4D	2017-07-30 11:46:00+03	135400.00
8D6BC6	2017-08-07 18:39:00+03	233800.00
8D6C67	2017-08-09 20:57:00+03	280000.00
8D6CC9	2017-07-16 05:14:00+03	59200.00
8D6CCC	2017-08-11 15:53:00+03	45200.00
8D6D3D	2017-07-03 13:51:00+03	28300.00
8D6DB7	2017-08-10 22:44:00+03	30200.00
8D6E3D	2017-07-26 03:19:00+03	46400.00
8D6E41	2017-07-22 08:26:00+03	75300.00
8D6E52	2017-08-08 01:45:00+03	179300.00
8D6E85	2017-07-25 10:03:00+03	61800.00
8D6EC3	2017-08-11 21:24:00+03	87700.00
8D6F02	2017-07-17 22:03:00+03	105000.00
8D6F19	2017-06-30 22:22:00+03	68200.00
8D6F96	2017-07-06 18:57:00+03	61800.00
8D6FB9	2017-07-09 07:56:00+03	47200.00
8D700A	2017-08-08 07:49:00+03	105600.00
8D702A	2017-07-06 13:00:00+03	28800.00
8D7038	2017-07-20 01:01:00+03	189200.00
8D712A	2017-07-16 00:27:00+03	163600.00
8D712F	2017-07-24 05:00:00+03	191500.00
8D717A	2017-08-14 14:26:00+03	13400.00
8D719F	2017-08-09 05:44:00+03	29600.00
8D71C6	2017-08-04 19:41:00+03	135400.00
8D7214	2017-08-04 01:07:00+03	66600.00
8D72A2	2017-08-08 11:42:00+03	31900.00
8D72B9	2017-07-22 03:36:00+03	93900.00
8D72C3	2017-07-20 18:45:00+03	21800.00
8D72FC	2017-08-06 20:46:00+03	28000.00
8D7349	2017-07-19 18:15:00+03	27900.00
8D73D5	2017-08-01 19:13:00+03	23200.00
8D73E5	2017-08-07 01:55:00+03	43200.00
8D74BA	2017-07-24 10:22:00+03	134700.00
8D74E2	2017-08-15 01:30:00+03	56200.00
8D751B	2017-07-18 03:36:00+03	79000.00
8D7535	2017-07-10 10:38:00+03	47200.00
8D758B	2017-08-09 04:04:00+03	66400.00
8D75D0	2017-06-28 13:21:00+03	273000.00
8D7641	2017-07-08 03:29:00+03	489100.00
8D766F	2017-07-06 09:52:00+03	26000.00
8D7692	2017-07-15 07:15:00+03	20400.00
8D76BF	2017-07-06 08:46:00+03	117900.00
8D76F1	2017-07-31 06:34:00+03	64700.00
8D76F4	2017-07-10 03:19:00+03	90400.00
8D77A5	2017-08-01 01:44:00+03	169400.00
8D77C3	2017-07-23 07:30:00+03	8400.00
8D784B	2017-08-05 08:00:00+03	62600.00
8D78D3	2017-07-26 07:32:00+03	228700.00
8D794D	2017-07-04 02:00:00+03	26000.00
8D7951	2017-07-12 13:46:00+03	57400.00
8D7994	2017-08-08 23:22:00+03	28800.00
8D7A16	2017-07-02 04:50:00+03	82000.00
8D7A33	2017-07-12 22:37:00+03	55600.00
8D7A59	2017-08-02 05:25:00+03	90800.00
8D7A63	2017-08-13 23:47:00+03	92700.00
8D7ABE	2017-07-30 07:06:00+03	40000.00
8D7AE6	2017-08-11 20:57:00+03	39200.00
8D7B0A	2017-07-09 03:00:00+03	39200.00
8D7B6B	2017-07-10 03:15:00+03	21200.00
8D7B81	2017-07-10 06:30:00+03	67000.00
8D7B89	2017-07-27 08:59:00+03	48800.00
8D7B92	2017-07-27 22:26:00+03	28600.00
8D7BA0	2017-08-13 08:05:00+03	135600.00
8D7C07	2017-07-03 23:31:00+03	133200.00
8D7C3E	2017-07-24 20:39:00+03	17000.00
8D7C43	2017-07-05 12:03:00+03	50000.00
8D7C68	2017-07-26 02:38:00+03	99700.00
8D7CBA	2017-07-21 21:18:00+03	46900.00
8D7CBE	2017-07-23 18:54:00+03	103600.00
8D7CF9	2017-08-01 03:23:00+03	64700.00
8D7D54	2017-08-13 02:45:00+03	59800.00
8D7DBC	2017-07-30 06:43:00+03	283100.00
8D7EB7	2017-08-15 04:04:00+03	25600.00
8D7EEE	2017-07-31 13:05:00+03	332800.00
8D7F5B	2017-07-27 15:28:00+03	48800.00
8D7F71	2017-07-30 03:14:00+03	169000.00
8D7FF3	2017-08-01 15:23:00+03	181600.00
8D804B	2017-07-09 03:42:00+03	28800.00
8D808A	2017-07-24 18:41:00+03	47400.00
8D80D2	2017-08-08 12:53:00+03	66600.00
8D8114	2017-08-14 01:07:00+03	515000.00
8D8136	2017-07-26 10:03:00+03	21600.00
8D819C	2017-07-16 19:50:00+03	24800.00
8D81EF	2017-07-15 08:57:00+03	49200.00
8D8241	2017-08-01 18:26:00+03	255600.00
8D8271	2017-07-09 06:34:00+03	83700.00
8D82A6	2017-07-14 13:06:00+03	12600.00
8D82AC	2017-07-26 21:47:00+03	123000.00
8D82CE	2017-08-13 03:12:00+03	39800.00
8D8339	2017-08-03 16:31:00+03	26700.00
8D837E	2017-08-07 16:17:00+03	24800.00
8D8458	2017-07-05 20:25:00+03	31200.00
8D847A	2017-07-21 12:04:00+03	47800.00
8D847D	2017-07-06 07:42:00+03	231800.00
8D8598	2017-07-19 21:28:00+03	47000.00
8D85AC	2017-08-01 04:42:00+03	55800.00
8D8607	2017-08-07 16:21:00+03	37900.00
8D860A	2017-07-03 04:49:00+03	36200.00
8D8668	2017-08-03 12:02:00+03	58600.00
8D8694	2017-07-30 23:28:00+03	272300.00
8D86FF	2017-08-14 22:39:00+03	130400.00
8D8723	2017-07-31 03:49:00+03	121200.00
8D8733	2017-07-27 12:13:00+03	61800.00
8D87E7	2017-08-10 06:11:00+03	406700.00
8D8824	2017-08-11 14:43:00+03	69500.00
8D8834	2017-07-25 01:38:00+03	26800.00
8D8860	2017-07-15 15:01:00+03	58800.00
8D8897	2017-07-08 01:41:00+03	114800.00
8D8960	2017-07-15 04:07:00+03	101200.00
8D897B	2017-07-13 16:38:00+03	14000.00
8D8A10	2017-07-07 09:20:00+03	81300.00
8D8A13	2017-08-12 21:35:00+03	100800.00
8D8AA1	2017-07-30 05:17:00+03	59200.00
8D8AD5	2017-07-06 17:08:00+03	75300.00
8D8BAF	2017-07-12 16:05:00+03	20200.00
8D8BE0	2017-08-04 08:28:00+03	73600.00
8D8C22	2017-07-16 06:16:00+03	42800.00
8D8C2A	2017-07-10 18:04:00+03	184300.00
8D8CDE	2017-08-14 03:40:00+03	46300.00
8D8DC4	2017-07-06 18:16:00+03	21400.00
8D8DCA	2017-07-16 05:53:00+03	11700.00
8D8DE5	2017-07-17 21:46:00+03	64100.00
8D8E08	2017-07-08 18:15:00+03	30900.00
8D8F46	2017-08-02 10:52:00+03	52800.00
8D8F4F	2017-08-09 02:43:00+03	14000.00
8D8F58	2017-07-11 01:06:00+03	196000.00
8D8F59	2017-07-12 14:31:00+03	86600.00
8D8F7E	2017-07-14 07:39:00+03	246000.00
8D906B	2017-08-09 00:36:00+03	29400.00
8D90C3	2017-07-28 08:50:00+03	62700.00
8D90FA	2017-08-08 16:12:00+03	406100.00
8D9108	2017-07-19 12:10:00+03	38800.00
8D9115	2017-07-18 01:42:00+03	7400.00
8D9177	2017-07-07 06:31:00+03	23200.00
8D9192	2017-08-14 08:56:00+03	29600.00
8D91D7	2017-07-06 19:33:00+03	40800.00
8D920D	2017-08-15 15:58:00+03	23600.00
8D9211	2017-07-13 15:04:00+03	67900.00
8D9280	2017-07-22 04:16:00+03	73900.00
8D92CA	2017-08-05 00:08:00+03	122700.00
8D92D6	2017-08-02 01:49:00+03	58900.00
8D930F	2017-08-06 13:09:00+03	105900.00
8D9386	2017-07-09 14:56:00+03	192400.00
8D93DB	2017-07-12 16:46:00+03	140300.00
8D943D	2017-07-05 10:30:00+03	23600.00
8D9447	2017-07-04 19:59:00+03	45200.00
8D95A3	2017-08-02 19:00:00+03	46700.00
8D9646	2017-07-25 16:59:00+03	40800.00
8D965C	2017-08-11 08:11:00+03	14000.00
8D9668	2017-07-07 21:26:00+03	11600.00
8D96AD	2017-07-30 17:12:00+03	29600.00
8D96B8	2017-08-05 03:45:00+03	100600.00
8D96D3	2017-06-30 15:19:00+03	137600.00
8D96EA	2017-07-19 09:41:00+03	37900.00
8D9791	2017-07-18 18:10:00+03	54800.00
8D97D4	2017-08-08 19:26:00+03	24500.00
8D97FD	2017-06-30 07:40:00+03	37200.00
8D9822	2017-07-18 19:51:00+03	41600.00
8D982E	2017-07-20 10:25:00+03	38800.00
8D9836	2017-08-05 09:10:00+03	131100.00
8D9856	2017-07-05 14:53:00+03	68000.00
8D98A8	2017-07-06 12:41:00+03	6000.00
8D9954	2017-07-22 17:44:00+03	100200.00
8D996F	2017-07-10 19:37:00+03	91600.00
8D99A5	2017-08-06 23:35:00+03	26000.00
8D9AEB	2017-08-10 06:35:00+03	12000.00
8D9B6F	2017-08-09 16:27:00+03	25100.00
8D9BD7	2017-08-09 22:38:00+03	69100.00
8D9BEF	2017-08-06 12:41:00+03	172300.00
8D9C21	2017-07-04 09:09:00+03	40800.00
8D9C3F	2017-08-07 05:20:00+03	16400.00
8D9C80	2017-08-09 12:31:00+03	123000.00
8D9CED	2017-08-13 16:03:00+03	96200.00
8D9D02	2017-07-05 01:40:00+03	76800.00
8D9D27	2017-07-09 15:26:00+03	44800.00
8D9DAA	2017-07-28 00:35:00+03	121100.00
8D9DDD	2017-08-04 03:42:00+03	39300.00
8D9E43	2017-07-21 03:00:00+03	26000.00
8D9EAD	2017-07-25 18:04:00+03	23600.00
8D9EC9	2017-07-20 13:26:00+03	29600.00
8D9F15	2017-07-27 17:03:00+03	169900.00
8D9F9D	2017-07-29 17:13:00+03	57500.00
8D9FBA	2017-07-19 00:56:00+03	48800.00
8D9FBB	2017-06-30 06:14:00+03	6700.00
8D9FD8	2017-08-12 23:46:00+03	39100.00
8DA017	2017-07-17 06:34:00+03	40000.00
8DA079	2017-07-08 20:38:00+03	44000.00
8DA112	2017-08-02 19:33:00+03	615000.00
8DA117	2017-07-15 11:31:00+03	14000.00
8DA175	2017-07-25 19:07:00+03	131100.00
8DA18D	2017-08-10 20:17:00+03	92900.00
8DA1A5	2017-08-10 16:55:00+03	56000.00
8DA1BB	2017-07-02 08:52:00+03	71900.00
8DA21D	2017-07-28 23:15:00+03	21500.00
8DA2A9	2017-08-11 07:53:00+03	22000.00
8DA2BB	2017-07-19 19:53:00+03	56600.00
8DA32F	2017-08-01 16:34:00+03	79900.00
8DA360	2017-07-22 01:17:00+03	46400.00
8DA392	2017-08-15 01:58:00+03	25600.00
8DA3A2	2017-08-04 13:06:00+03	32700.00
8DA3E0	2017-07-25 18:00:00+03	50800.00
8DA42A	2017-07-28 06:37:00+03	61300.00
8DA43B	2017-07-19 18:24:00+03	67000.00
8DA43F	2017-08-15 02:28:00+03	12000.00
8DA46D	2017-08-11 08:54:00+03	134200.00
8DA47D	2017-07-30 00:54:00+03	19600.00
8DA4AE	2017-08-01 08:32:00+03	8400.00
8DA536	2017-07-17 15:43:00+03	178800.00
8DA59B	2017-07-01 04:31:00+03	105600.00
8DA626	2017-07-21 21:37:00+03	54000.00
8DA649	2017-07-22 01:25:00+03	44200.00
8DA681	2017-07-10 09:56:00+03	203500.00
8DA690	2017-08-11 17:51:00+03	6200.00
8DA6A0	2017-08-03 06:23:00+03	91100.00
8DA6A8	2017-08-04 19:47:00+03	26000.00
8DA6C4	2017-07-15 20:30:00+03	36500.00
8DA6C8	2017-08-15 12:49:00+03	28600.00
8DA7C0	2017-08-15 17:14:00+03	106400.00
8DA7EC	2017-07-14 14:58:00+03	39800.00
8DA80F	2017-07-11 23:48:00+03	156500.00
8DA835	2017-08-13 04:28:00+03	46400.00
8DA8AA	2017-07-25 19:15:00+03	215300.00
8DA8E1	2017-08-07 04:26:00+03	10800.00
8DA8FE	2017-08-01 10:59:00+03	28000.00
8DA911	2017-08-06 00:14:00+03	30400.00
8DA928	2017-08-06 02:07:00+03	56000.00
8DA939	2017-07-05 11:38:00+03	25600.00
8DA95E	2017-08-10 15:39:00+03	23200.00
8DA987	2017-08-05 05:45:00+03	133100.00
8DA993	2017-08-06 20:32:00+03	199600.00
8DA9A8	2017-07-03 02:08:00+03	20200.00
8DA9CC	2017-08-05 09:47:00+03	56000.00
8DA9E4	2017-07-22 10:53:00+03	23600.00
8DAA4F	2017-08-13 13:27:00+03	99700.00
8DAAD0	2017-08-14 18:40:00+03	26600.00
8DAB14	2017-07-24 09:48:00+03	85000.00
8DAB52	2017-08-01 19:31:00+03	133200.00
8DABA8	2017-07-24 13:25:00+03	112600.00
8DABA9	2017-07-03 15:49:00+03	26800.00
8DAC28	2017-07-19 02:00:00+03	7200.00
8DACE2	2017-07-27 18:31:00+03	248300.00
8DACEC	2017-07-21 18:57:00+03	38600.00
8DAD71	2017-08-07 19:24:00+03	84500.00
8DADB3	2017-08-04 13:43:00+03	24000.00
8DAE30	2017-08-02 04:48:00+03	46000.00
8DAE4D	2017-07-24 04:42:00+03	65800.00
8DAEBC	2017-08-13 16:27:00+03	268000.00
8DAEF5	2017-06-30 13:12:00+03	28000.00
8DAF42	2017-07-30 08:05:00+03	40000.00
8DAF58	2017-08-15 08:34:00+03	38500.00
8DAFD7	2017-07-23 16:48:00+03	59200.00
8DB014	2017-08-10 03:19:00+03	130900.00
8DB064	2017-07-28 06:26:00+03	30400.00
8DB077	2017-08-03 00:40:00+03	102700.00
8DB0BD	2017-07-24 19:18:00+03	25400.00
8DB138	2017-07-08 00:16:00+03	12600.00
8DB166	2017-08-12 05:04:00+03	55800.00
8DB182	2017-07-07 14:11:00+03	66000.00
8DB19F	2017-08-09 04:32:00+03	24000.00
8DB1AB	2017-07-26 12:04:00+03	136800.00
8DB1B7	2017-07-30 06:47:00+03	85000.00
8DB264	2017-07-21 13:47:00+03	28800.00
8DB27D	2017-07-13 11:16:00+03	57500.00
8DB2D5	2017-07-20 10:18:00+03	135200.00
8DB2F9	2017-07-06 18:01:00+03	23600.00
8DB368	2017-07-31 05:50:00+03	40100.00
8DB36D	2017-07-13 15:20:00+03	79900.00
8DB3E3	2017-07-19 21:38:00+03	38600.00
8DB4E4	2017-07-18 19:12:00+03	189200.00
8DB4F2	2017-07-10 12:35:00+03	13400.00
8DB565	2017-08-04 06:53:00+03	68400.00
8DB595	2017-08-09 02:55:00+03	31400.00
8DB596	2017-08-05 12:53:00+03	27200.00
8DB68D	2017-07-26 12:02:00+03	168000.00
8DB6A0	2017-07-12 15:12:00+03	27900.00
8DB6AF	2017-08-11 08:31:00+03	64800.00
8DB750	2017-06-28 19:42:00+03	63600.00
8DB79D	2017-08-15 13:06:00+03	167400.00
8DB7B3	2017-07-02 06:56:00+03	79900.00
8DB7BF	2017-07-13 22:27:00+03	23600.00
8DB850	2017-07-05 23:52:00+03	24400.00
8DB881	2017-07-02 06:23:00+03	248500.00
8DB8EE	2017-08-05 06:31:00+03	6700.00
8DB8F4	2017-07-28 21:41:00+03	44000.00
8DB94A	2017-07-29 07:11:00+03	73300.00
8DB951	2017-08-14 04:00:00+03	36600.00
8DBA0B	2017-07-23 02:57:00+03	55800.00
8DBA16	2017-07-06 02:10:00+03	102300.00
8DBA29	2017-08-10 04:23:00+03	139800.00
8DBA84	2017-07-26 20:07:00+03	6700.00
8DBAA2	2017-07-25 09:06:00+03	21800.00
8DBACF	2017-07-12 06:48:00+03	67400.00
8DBB67	2017-08-02 11:01:00+03	19600.00
8DBB98	2017-08-08 17:32:00+03	64700.00
8DBBB0	2017-07-04 11:26:00+03	44800.00
8DBC05	2017-08-10 14:33:00+03	42800.00
8DBC29	2017-07-28 20:44:00+03	13400.00
8DBC37	2017-07-18 23:30:00+03	49100.00
8DBCBE	2017-07-03 18:39:00+03	31400.00
8DBCFD	2017-08-05 00:40:00+03	21800.00
8DBD07	2017-08-15 05:16:00+03	23300.00
8DBE25	2017-07-27 08:41:00+03	92800.00
8DBE29	2017-08-03 11:31:00+03	27200.00
8DBE4D	2017-07-15 06:34:00+03	48800.00
8DBE93	2017-08-14 04:21:00+03	62800.00
8DBEF8	2017-08-12 07:57:00+03	46200.00
8DBF01	2017-08-12 07:04:00+03	40600.00
8DBF21	2017-07-17 04:01:00+03	85700.00
8DBF40	2017-06-30 02:21:00+03	380700.00
8DBFAA	2017-07-18 23:34:00+03	398500.00
8DC000	2017-07-13 23:09:00+03	98100.00
8DC018	2017-08-11 05:00:00+03	23200.00
8DC04A	2017-07-20 09:48:00+03	202600.00
8DC09C	2017-07-14 07:40:00+03	67400.00
8DC0B8	2017-07-13 11:20:00+03	54800.00
8DC0BD	2017-07-26 16:01:00+03	64800.00
8DC0DB	2017-08-09 00:49:00+03	55800.00
8DC102	2017-06-30 05:45:00+03	52000.00
8DC14F	2017-08-12 22:07:00+03	67600.00
8DC173	2017-08-15 09:32:00+03	24600.00
8DC211	2017-07-28 14:03:00+03	67700.00
8DC3A2	2017-07-24 07:48:00+03	201200.00
8DC3F5	2017-08-03 07:06:00+03	33400.00
8DC3F7	2017-07-21 00:19:00+03	124300.00
8DC421	2017-07-31 09:43:00+03	23400.00
8DC440	2017-08-09 20:21:00+03	26000.00
8DC453	2017-08-05 22:07:00+03	6300.00
8DC48D	2017-08-12 09:22:00+03	40200.00
8DC494	2017-07-08 19:30:00+03	83000.00
8DC49B	2017-07-22 23:44:00+03	47400.00
8DC4BA	2017-08-04 22:23:00+03	112600.00
8DC4C4	2017-07-11 17:37:00+03	21500.00
8DC4E5	2017-07-19 15:15:00+03	46300.00
8DC4F4	2017-08-12 04:26:00+03	75600.00
8DC62B	2017-07-08 02:24:00+03	48700.00
8DC73A	2017-07-20 08:09:00+03	129800.00
8DC78C	2017-07-19 05:07:00+03	56600.00
8DC7C1	2017-08-12 10:50:00+03	50600.00
8DC7D4	2017-08-11 04:42:00+03	12400.00
8DC7FB	2017-07-15 04:18:00+03	37900.00
8DC855	2017-07-29 19:17:00+03	111600.00
8DC89B	2017-07-17 04:29:00+03	22000.00
8DC93D	2017-07-07 01:21:00+03	91500.00
8DC985	2017-07-17 15:29:00+03	135400.00
8DC9E7	2017-07-10 10:39:00+03	23600.00
8DCA31	2017-07-03 13:02:00+03	91100.00
8DCA87	2017-07-09 21:06:00+03	131600.00
8DCAC4	2017-08-06 14:42:00+03	67600.00
8DCACE	2017-07-10 00:46:00+03	187800.00
8DCADF	2017-07-19 23:08:00+03	28800.00
8DCB12	2017-08-05 16:36:00+03	38600.00
8DCB4C	2017-08-12 10:04:00+03	141000.00
8DCB93	2017-07-08 04:57:00+03	110400.00
8DCC6B	2017-07-30 21:41:00+03	34000.00
8DCCD5	2017-08-02 22:22:00+03	13400.00
8DCCD7	2017-07-17 08:45:00+03	272300.00
8DCCE5	2017-08-04 10:56:00+03	25600.00
8DCCEF	2017-07-28 23:54:00+03	26000.00
8DCDA7	2017-06-29 13:36:00+03	24400.00
8DCE52	2017-08-09 21:35:00+03	95600.00
8DCE5F	2017-08-05 04:43:00+03	23600.00
8DCEDB	2017-07-10 23:44:00+03	132800.00
8DCEF9	2017-08-11 01:11:00+03	95100.00
8DCF41	2017-07-11 04:15:00+03	133100.00
8DCF6C	2017-07-20 15:29:00+03	244000.00
8DCFAD	2017-08-07 11:17:00+03	31100.00
8DD012	2017-07-06 01:51:00+03	58400.00
8DD018	2017-07-10 19:07:00+03	61800.00
8DD026	2017-08-12 14:43:00+03	33300.00
8DD0E0	2017-08-04 13:40:00+03	139800.00
8DD113	2017-07-22 01:37:00+03	258400.00
8DD11E	2017-07-12 04:12:00+03	44000.00
8DD1D2	2017-07-01 20:39:00+03	16400.00
8DD20C	2017-07-11 16:38:00+03	81600.00
8DD2A5	2017-07-27 07:37:00+03	71900.00
8DD2FC	2017-07-18 21:08:00+03	124200.00
8DD305	2017-08-12 00:01:00+03	54800.00
8DD327	2017-07-12 01:24:00+03	46300.00
8DD386	2017-08-14 07:48:00+03	64500.00
8DD396	2017-07-24 17:32:00+03	270100.00
8DD3E4	2017-08-02 08:12:00+03	19600.00
8DD3F3	2017-07-08 10:20:00+03	44500.00
8DD3FB	2017-07-09 11:35:00+03	111700.00
8DD3FF	2017-06-29 19:28:00+03	109500.00
8DD438	2017-06-29 15:19:00+03	11600.00
8DD4C8	2017-07-29 08:58:00+03	13000.00
8DD56E	2017-07-25 15:22:00+03	37100.00
8DD685	2017-08-10 05:33:00+03	42700.00
8DD69A	2017-08-07 21:33:00+03	269200.00
8DD6C9	2017-07-06 19:22:00+03	48800.00
8DD719	2017-06-29 00:49:00+03	18400.00
8DD73E	2017-07-13 15:45:00+03	32400.00
8DD748	2017-07-11 09:15:00+03	38200.00
8DD773	2017-07-30 19:52:00+03	73600.00
8DD781	2017-07-13 03:39:00+03	28000.00
8DD799	2017-07-20 19:10:00+03	48800.00
8DD7C1	2017-08-01 03:45:00+03	58600.00
8DD7CF	2017-07-15 17:07:00+03	46700.00
8DD7DE	2017-08-14 14:04:00+03	59200.00
8DD81B	2017-08-13 03:43:00+03	264000.00
8DD855	2017-07-10 19:21:00+03	135400.00
8DD867	2017-08-15 13:49:00+03	85500.00
8DD8D7	2017-07-20 05:55:00+03	27600.00
8DD932	2017-07-14 04:36:00+03	23200.00
8DD93E	2017-07-29 17:33:00+03	56000.00
8DD96A	2017-07-04 11:11:00+03	73600.00
8DDA4F	2017-07-30 06:59:00+03	211000.00
8DDA5B	2017-07-04 10:28:00+03	48800.00
8DDA8D	2017-08-13 16:30:00+03	30200.00
8DDA99	2017-07-13 21:25:00+03	23600.00
8DDB27	2017-08-15 13:05:00+03	16400.00
8DDB5D	2017-07-30 16:13:00+03	23600.00
8DDB93	2017-07-06 09:42:00+03	17000.00
8DDBAF	2017-07-18 07:21:00+03	406600.00
8DDBE5	2017-07-11 06:59:00+03	52000.00
8DDC0A	2017-08-01 15:56:00+03	73600.00
8DDC32	2017-08-13 20:24:00+03	61800.00
8DDC61	2017-08-09 13:17:00+03	111600.00
8DDC98	2017-07-17 05:02:00+03	11000.00
8DDCD5	2017-07-05 23:24:00+03	23600.00
8DDCD7	2017-06-27 16:33:00+03	25300.00
8DDCDA	2017-07-31 16:32:00+03	64400.00
8DDD14	2017-07-24 17:38:00+03	139400.00
8DDD7A	2017-08-07 22:20:00+03	69400.00
8DDE39	2017-08-13 13:43:00+03	34000.00
8DDED5	2017-07-13 22:52:00+03	20800.00
8DDFBB	2017-07-24 07:26:00+03	83200.00
8DDFD7	2017-07-07 23:08:00+03	143400.00
8DDFE2	2017-07-10 01:43:00+03	266400.00
8DE06D	2017-08-10 22:32:00+03	202100.00
8DE0E1	2017-07-03 20:33:00+03	34000.00
8DE121	2017-08-13 14:32:00+03	92400.00
8DE12D	2017-08-01 19:16:00+03	26000.00
8DE1B3	2017-08-03 17:57:00+03	120900.00
8DE21D	2017-08-05 13:04:00+03	54500.00
8DE24D	2017-07-18 10:59:00+03	516000.00
8DE28A	2017-07-31 05:36:00+03	68400.00
8DE2AA	2017-07-21 02:20:00+03	56000.00
8DE302	2017-08-15 10:21:00+03	286700.00
8DE36F	2017-07-23 23:11:00+03	35200.00
8DE379	2017-08-05 20:22:00+03	86800.00
8DE3E6	2017-08-01 14:38:00+03	73200.00
8DE455	2017-06-30 14:49:00+03	68000.00
8DE4CA	2017-08-14 10:41:00+03	75000.00
8DE4DD	2017-07-24 00:35:00+03	64800.00
8DE4EE	2017-08-15 03:40:00+03	26700.00
8DE55E	2017-08-10 22:40:00+03	68800.00
8DE57E	2017-07-12 15:15:00+03	22000.00
8DE58F	2017-08-10 19:16:00+03	91000.00
8DE591	2017-07-17 01:28:00+03	38800.00
8DE5A1	2017-07-22 18:01:00+03	58000.00
8DE5C9	2017-07-15 10:14:00+03	148200.00
8DE5EC	2017-08-14 05:58:00+03	100600.00
8DE633	2017-07-03 14:27:00+03	52800.00
8DE68F	2017-07-07 06:02:00+03	133100.00
8DE6EA	2017-08-12 22:12:00+03	36400.00
8DE741	2017-08-14 07:55:00+03	62100.00
8DE75D	2017-08-05 11:54:00+03	46200.00
8DE75F	2017-07-15 05:21:00+03	91600.00
8DE76F	2017-08-07 21:07:00+03	111700.00
8DE775	2017-08-07 05:07:00+03	532800.00
8DE78E	2017-07-13 18:48:00+03	8800.00
8DE7A0	2017-07-22 10:03:00+03	14400.00
8DE7A7	2017-07-24 19:56:00+03	85000.00
8DE7ED	2017-07-04 14:14:00+03	62600.00
8DE845	2017-07-01 22:35:00+03	406200.00
8DE860	2017-07-10 15:37:00+03	21600.00
8DE889	2017-07-03 15:50:00+03	73500.00
8DE8B5	2017-07-12 16:15:00+03	25200.00
8DE8F1	2017-08-09 07:07:00+03	289800.00
8DE8F8	2017-07-12 20:17:00+03	124400.00
8DE91B	2017-07-26 10:00:00+03	32600.00
8DE950	2017-08-01 18:31:00+03	32400.00
8DEA13	2017-07-21 14:52:00+03	84500.00
8DEA81	2017-07-09 22:34:00+03	98300.00
8DEAC2	2017-07-23 12:47:00+03	54000.00
8DEB58	2017-07-24 11:55:00+03	357600.00
8DEBB3	2017-07-02 23:10:00+03	47100.00
8DEC01	2017-08-14 12:51:00+03	41400.00
8DEC2B	2017-06-29 02:11:00+03	119700.00
8DEC7D	2017-08-13 19:53:00+03	21800.00
8DECD8	2017-07-05 11:30:00+03	36200.00
8DED31	2017-08-15 14:35:00+03	72400.00
8DED55	2017-07-06 08:54:00+03	13700.00
8DED64	2017-07-20 09:11:00+03	111600.00
8DEDEA	2017-07-31 04:28:00+03	20600.00
8DEE2E	2017-08-12 19:12:00+03	12600.00
8DEE7B	2017-07-24 11:31:00+03	269200.00
8DEE99	2017-07-18 21:11:00+03	56000.00
8DEEFB	2017-07-10 19:24:00+03	246000.00
8DEF9B	2017-07-23 22:32:00+03	13600.00
8DEFE5	2017-08-07 22:36:00+03	8400.00
8DF02F	2017-07-02 18:23:00+03	83400.00
8DF061	2017-08-10 10:02:00+03	79400.00
8DF064	2017-07-31 09:39:00+03	10100.00
8DF0A5	2017-07-28 07:33:00+03	84500.00
8DF0D2	2017-07-03 00:56:00+03	193600.00
8DF12F	2017-08-12 12:18:00+03	26000.00
8DF13A	2017-06-30 06:05:00+03	44100.00
8DF175	2017-07-10 10:57:00+03	73200.00
8DF17F	2017-07-04 02:30:00+03	270700.00
8DF216	2017-07-19 11:36:00+03	72400.00
8DF22F	2017-07-18 21:49:00+03	26000.00
8DF261	2017-08-15 16:33:00+03	73500.00
8DF299	2017-07-20 01:50:00+03	615000.00
8DF2F4	2017-08-09 14:33:00+03	46300.00
8DF2FB	2017-07-24 04:25:00+03	46100.00
8DF334	2017-07-26 09:45:00+03	112600.00
8DF391	2017-08-01 17:53:00+03	52000.00
8DF41F	2017-07-10 22:19:00+03	81900.00
8DF486	2017-07-18 04:33:00+03	31100.00
8DF581	2017-08-02 17:02:00+03	47100.00
8DF591	2017-07-30 16:54:00+03	269200.00
8DF5B1	2017-08-11 08:28:00+03	29600.00
8DF5C1	2017-07-18 03:35:00+03	31400.00
8DF5CD	2017-08-15 00:16:00+03	131600.00
8DF692	2017-07-25 09:13:00+03	64100.00
8DF693	2017-07-12 11:22:00+03	104600.00
8DF69F	2017-07-09 03:02:00+03	133100.00
8DF6F2	2017-08-11 14:10:00+03	49200.00
8DF732	2017-07-28 12:14:00+03	92800.00
8DF7AD	2017-07-15 00:53:00+03	58800.00
8DF7D2	2017-07-06 04:58:00+03	171000.00
8DF7E8	2017-07-30 16:14:00+03	66600.00
8DF7EA	2017-07-27 03:33:00+03	170200.00
8DF836	2017-07-05 16:55:00+03	16400.00
8DF847	2017-06-28 20:56:00+03	57800.00
8DF85C	2017-07-02 12:09:00+03	128800.00
8DF87D	2017-08-12 15:44:00+03	124200.00
8DF8AC	2017-07-03 17:45:00+03	92800.00
8DF8B8	2017-07-19 13:43:00+03	40400.00
8DF8C1	2017-08-11 00:23:00+03	38800.00
8DF8D4	2017-07-24 21:23:00+03	25200.00
8DF949	2017-07-25 07:51:00+03	55800.00
8DF959	2017-08-02 03:59:00+03	14800.00
8DF961	2017-07-25 02:02:00+03	62600.00
8DF990	2017-08-05 14:57:00+03	84000.00
8DF9B9	2017-07-26 19:13:00+03	89600.00
8DFA6A	2017-08-14 01:03:00+03	132600.00
8DFA9A	2017-07-05 17:18:00+03	177200.00
8DFACF	2017-07-29 22:52:00+03	166700.00
8DFB45	2017-07-15 22:48:00+03	191900.00
8DFB46	2017-08-07 20:42:00+03	72200.00
8DFB56	2017-07-22 02:09:00+03	20500.00
8DFB83	2017-07-31 04:47:00+03	265600.00
8DFBC4	2017-08-06 16:38:00+03	28000.00
8DFC39	2017-07-30 15:39:00+03	8400.00
8DFD45	2017-07-02 07:10:00+03	42600.00
8DFD4B	2017-07-06 18:06:00+03	7400.00
8DFDA5	2017-07-11 12:54:00+03	41600.00
8DFDB7	2017-07-31 07:15:00+03	14000.00
8DFDFA	2017-08-08 01:13:00+03	31400.00
8DFE2F	2017-08-01 13:38:00+03	14000.00
8DFE57	2017-07-18 04:05:00+03	131100.00
8DFE8D	2017-08-01 09:08:00+03	132800.00
8DFF0E	2017-08-11 02:44:00+03	26600.00
8DFF1F	2017-07-19 07:07:00+03	70700.00
8DFF3D	2017-08-08 21:28:00+03	91600.00
8DFF95	2017-07-23 15:21:00+03	25800.00
8DFFE8	2017-07-21 23:32:00+03	120800.00
8E001F	2017-07-20 22:13:00+03	34800.00
8E005C	2017-07-21 21:38:00+03	167500.00
8E0087	2017-07-17 02:06:00+03	31600.00
8E00AB	2017-08-13 13:45:00+03	54400.00
8E00BF	2017-08-14 03:25:00+03	12600.00
8E00D3	2017-07-25 05:14:00+03	75600.00
8E0118	2017-07-21 06:03:00+03	20200.00
8E0140	2017-07-20 09:16:00+03	66000.00
8E0190	2017-07-08 17:38:00+03	6600.00
8E01B6	2017-07-02 22:53:00+03	12000.00
8E01C3	2017-07-17 16:21:00+03	122100.00
8E01D6	2017-07-22 17:51:00+03	24800.00
8E023A	2017-07-19 21:10:00+03	28000.00
8E024E	2017-07-30 08:28:00+03	40000.00
8E0272	2017-07-27 11:53:00+03	132800.00
8E02BD	2017-06-29 22:03:00+03	78100.00
8E030A	2017-07-08 08:46:00+03	11200.00
8E0316	2017-07-04 21:12:00+03	167400.00
8E031A	2017-08-15 01:52:00+03	126200.00
8E0384	2017-08-01 18:01:00+03	37200.00
8E0393	2017-07-25 20:00:00+03	37900.00
8E0456	2017-08-12 20:54:00+03	51600.00
8E04BA	2017-07-27 01:37:00+03	21400.00
8E04E5	2017-07-10 15:43:00+03	70800.00
8E04F7	2017-08-08 10:46:00+03	36400.00
8E0509	2017-07-17 00:57:00+03	136500.00
8E050D	2017-07-09 10:09:00+03	133200.00
8E0555	2017-07-30 05:15:00+03	56000.00
8E0571	2017-07-19 04:52:00+03	110400.00
8E05AB	2017-07-16 18:54:00+03	369000.00
8E064A	2017-06-30 08:06:00+03	118400.00
8E0685	2017-07-10 11:01:00+03	32200.00
8E06B1	2017-07-21 05:34:00+03	73500.00
8E06C5	2017-08-12 12:23:00+03	75600.00
8E06E6	2017-08-14 14:34:00+03	130100.00
8E0702	2017-07-05 23:29:00+03	58600.00
8E0715	2017-08-07 05:53:00+03	148300.00
8E072D	2017-07-02 06:04:00+03	54200.00
8E07BB	2017-08-05 06:53:00+03	246000.00
8E07CA	2017-07-12 15:51:00+03	91600.00
8E07D3	2017-07-10 23:32:00+03	75300.00
8E0848	2017-08-02 01:03:00+03	167400.00
8E0874	2017-08-04 13:11:00+03	13600.00
8E087F	2017-07-05 00:25:00+03	53700.00
8E0889	2017-08-14 07:43:00+03	100000.00
8E09A5	2017-07-08 08:08:00+03	58000.00
8E09BD	2017-07-31 21:59:00+03	189200.00
8E09C9	2017-08-02 03:58:00+03	12400.00
8E0AD3	2017-07-20 01:32:00+03	50800.00
8E0B53	2017-08-06 03:36:00+03	8200.00
8E0B7B	2017-07-25 21:26:00+03	7400.00
8E0B8A	2017-07-25 16:40:00+03	73600.00
8E0BEB	2017-08-06 07:32:00+03	37900.00
8E0C61	2017-08-13 13:22:00+03	6600.00
8E0C68	2017-07-26 08:02:00+03	92400.00
8E0C6E	2017-07-07 04:32:00+03	56600.00
8E0C83	2017-07-12 15:39:00+03	7400.00
8E0CAF	2017-07-10 00:05:00+03	71900.00
8E0CBC	2017-07-16 21:14:00+03	180000.00
8E0D05	2017-07-16 02:17:00+03	46000.00
8E0D20	2017-07-02 07:50:00+03	55800.00
8E0DAC	2017-07-28 05:10:00+03	73500.00
8E0DB0	2017-06-30 07:17:00+03	28000.00
8E0DB4	2017-07-11 10:01:00+03	37100.00
8E0DFF	2017-08-02 03:47:00+03	49200.00
8E0E03	2017-07-13 15:18:00+03	72000.00
8E0E2D	2017-07-12 14:23:00+03	29600.00
8E0E49	2017-08-12 17:45:00+03	25600.00
8E0E56	2017-07-07 14:27:00+03	43100.00
8E0EEA	2017-08-08 20:14:00+03	11800.00
8E0F10	2017-07-16 09:18:00+03	72200.00
8E0F15	2017-08-11 01:15:00+03	50000.00
8E0F52	2017-08-01 18:10:00+03	58800.00
8E0F84	2017-07-18 03:19:00+03	35700.00
8E0FB5	2017-08-01 07:39:00+03	26000.00
8E0FCE	2017-08-13 00:54:00+03	90300.00
8E0FD3	2017-08-15 00:25:00+03	20100.00
8E10DC	2017-07-05 10:37:00+03	70700.00
8E10FF	2017-07-03 23:21:00+03	151200.00
8E1114	2017-08-07 20:36:00+03	23200.00
8E11D9	2017-07-25 17:50:00+03	6400.00
8E122A	2017-07-12 07:43:00+03	73300.00
8E1244	2017-07-10 18:02:00+03	113700.00
8E124F	2017-07-20 23:36:00+03	37900.00
8E130A	2017-08-04 04:40:00+03	75300.00
8E1338	2017-07-06 09:10:00+03	40800.00
8E135E	2017-07-01 11:47:00+03	136100.00
8E1389	2017-07-29 21:52:00+03	24700.00
8E13FC	2017-07-23 01:15:00+03	75600.00
8E146B	2017-08-06 10:42:00+03	6700.00
8E1488	2017-07-17 23:09:00+03	46400.00
8E14B7	2017-07-28 15:54:00+03	50000.00
8E14C8	2017-07-07 18:55:00+03	38800.00
8E14EE	2017-07-29 08:18:00+03	26000.00
8E14FF	2017-07-10 20:23:00+03	67600.00
8E150B	2017-07-08 15:45:00+03	96200.00
8E1539	2017-07-04 04:20:00+03	123000.00
8E153C	2017-07-04 12:29:00+03	90400.00
8E153F	2017-07-19 04:18:00+03	67600.00
8E1540	2017-08-06 18:27:00+03	23200.00
8E1583	2017-08-05 21:24:00+03	183300.00
8E1604	2017-07-03 07:10:00+03	18000.00
8E160A	2017-07-18 03:35:00+03	133200.00
8E1619	2017-08-05 14:19:00+03	189600.00
8E161A	2017-08-11 06:16:00+03	28000.00
8E1642	2017-08-08 15:50:00+03	333200.00
8E169B	2017-08-05 13:04:00+03	10600.00
8E1704	2017-08-03 21:04:00+03	24400.00
8E1731	2017-07-24 00:26:00+03	24500.00
8E1781	2017-08-13 12:40:00+03	49200.00
8E17CD	2017-07-17 19:16:00+03	47300.00
8E1814	2017-08-01 13:31:00+03	25800.00
8E189E	2017-08-14 23:49:00+03	137600.00
8E18D2	2017-06-29 05:07:00+03	44000.00
8E193D	2017-08-09 06:07:00+03	23600.00
8E194E	2017-08-13 17:59:00+03	22400.00
8E199C	2017-08-06 06:50:00+03	46500.00
8E19E1	2017-08-10 15:35:00+03	78500.00
8E1A9A	2017-07-07 02:41:00+03	43100.00
8E1ACE	2017-07-18 22:51:00+03	266500.00
8E1ADE	2017-08-07 22:36:00+03	28000.00
8E1B36	2017-08-10 00:30:00+03	35800.00
8E1B3F	2017-07-03 21:05:00+03	166000.00
8E1BEB	2017-07-08 13:16:00+03	36600.00
8E1C47	2017-08-05 06:54:00+03	301800.00
8E1C53	2017-07-01 02:24:00+03	10800.00
8E1C69	2017-07-18 16:42:00+03	68900.00
8E1CAF	2017-07-12 02:28:00+03	23200.00
8E1D75	2017-08-11 12:46:00+03	55800.00
8E1D96	2017-07-27 11:28:00+03	178800.00
8E1DAB	2017-07-09 20:46:00+03	117900.00
8E1DB1	2017-08-03 04:19:00+03	170900.00
8E1DD0	2017-07-28 14:19:00+03	22000.00
8E1DFE	2017-08-08 08:56:00+03	37100.00
8E1DFF	2017-07-10 19:20:00+03	103400.00
8E1E29	2017-07-09 10:14:00+03	177600.00
8E1E8C	2017-07-04 18:47:00+03	167400.00
8E1F06	2017-08-14 10:19:00+03	189200.00
8E1F5C	2017-07-13 10:27:00+03	73200.00
8E1F61	2017-07-28 21:06:00+03	27200.00
8E2025	2017-07-31 12:47:00+03	9200.00
8E2028	2017-07-15 10:26:00+03	82900.00
8E2046	2017-07-30 19:32:00+03	26400.00
8E2113	2017-07-08 20:29:00+03	6600.00
8E211D	2017-08-12 06:52:00+03	54400.00
8E2153	2017-08-03 15:52:00+03	174000.00
8E21CB	2017-07-07 17:06:00+03	13400.00
8E2259	2017-07-01 16:26:00+03	84000.00
8E22D2	2017-08-11 05:08:00+03	58400.00
8E22D7	2017-07-25 12:15:00+03	229800.00
8E22DF	2017-08-09 00:47:00+03	8000.00
8E2300	2017-07-26 05:29:00+03	14800.00
8E2358	2017-08-08 03:59:00+03	36100.00
8E236F	2017-08-08 22:02:00+03	64500.00
8E2378	2017-08-07 23:13:00+03	64800.00
8E2399	2017-08-08 03:25:00+03	14400.00
8E23A4	2017-08-05 05:18:00+03	47000.00
8E23DF	2017-07-06 12:45:00+03	51300.00
8E23F8	2017-07-16 05:13:00+03	62800.00
8E241B	2017-07-10 14:00:00+03	21800.00
8E2448	2017-07-21 02:46:00+03	24800.00
8E2475	2017-07-16 19:14:00+03	26000.00
8E24B6	2017-08-03 06:54:00+03	23200.00
8E24BA	2017-07-28 07:04:00+03	6800.00
8E24E2	2017-07-31 07:19:00+03	62600.00
8E251C	2017-07-17 11:10:00+03	29600.00
8E251E	2017-08-01 21:36:00+03	94700.00
8E252D	2017-07-03 07:58:00+03	88400.00
8E2576	2017-08-01 01:54:00+03	216400.00
8E2584	2017-08-03 10:52:00+03	58200.00
8E259D	2017-08-06 13:56:00+03	206400.00
8E25A9	2017-08-06 21:12:00+03	101200.00
8E25C7	2017-07-26 04:11:00+03	32800.00
8E25DA	2017-08-04 12:02:00+03	46800.00
8E25F1	2017-08-03 07:13:00+03	23200.00
8E264E	2017-07-03 15:37:00+03	65500.00
8E265E	2017-08-01 15:24:00+03	103200.00
8E2678	2017-07-02 02:59:00+03	47200.00
8E26C5	2017-07-21 04:43:00+03	106900.00
8E26D1	2017-07-15 12:12:00+03	58800.00
8E26DC	2017-07-21 02:49:00+03	139100.00
8E2837	2017-07-31 09:39:00+03	59800.00
8E2875	2017-08-12 17:09:00+03	62600.00
8E2887	2017-08-14 05:58:00+03	111000.00
8E2891	2017-08-10 20:16:00+03	46400.00
8E2930	2017-08-12 12:06:00+03	15900.00
8E2942	2017-07-25 02:28:00+03	101000.00
8E2950	2017-07-30 09:58:00+03	43500.00
8E296C	2017-08-06 21:29:00+03	24400.00
8E2988	2017-07-04 06:16:00+03	55800.00
8E29CB	2017-08-06 09:03:00+03	131600.00
8E2A4E	2017-07-25 06:50:00+03	111600.00
8E2A54	2017-07-15 09:49:00+03	57300.00
8E2A82	2017-07-01 21:40:00+03	247500.00
8E2B24	2017-08-13 19:17:00+03	52900.00
8E2BFC	2017-07-22 20:26:00+03	117100.00
8E2C1D	2017-07-10 09:52:00+03	196600.00
8E2C55	2017-08-13 10:15:00+03	57900.00
8E2CB4	2017-07-24 06:11:00+03	92800.00
8E2CD5	2017-07-08 04:50:00+03	30700.00
8E2CD7	2017-07-14 15:54:00+03	189800.00
8E2CDC	2017-07-08 22:35:00+03	82700.00
8E2D1B	2017-08-15 13:47:00+03	58200.00
8E2D1E	2017-07-27 20:34:00+03	57500.00
8E2D3D	2017-07-31 01:08:00+03	98400.00
8E2D70	2017-07-21 14:55:00+03	51900.00
8E2D74	2017-07-11 09:54:00+03	56000.00
8E2DC5	2017-08-11 12:11:00+03	28000.00
8E2DD4	2017-07-02 11:12:00+03	243700.00
8E2E48	2017-07-26 09:39:00+03	73600.00
8E2E8C	2017-07-12 19:18:00+03	55800.00
8E2EDF	2017-08-09 08:51:00+03	39000.00
8E2EE1	2017-08-09 15:10:00+03	279600.00
8E2FA4	2017-07-19 07:33:00+03	244100.00
8E2FCF	2017-07-25 16:08:00+03	270000.00
8E2FE5	2017-08-09 00:30:00+03	21200.00
8E305F	2017-07-09 09:23:00+03	36400.00
8E3081	2017-07-16 06:24:00+03	22000.00
8E30D2	2017-07-06 21:53:00+03	47700.00
8E3171	2017-08-12 01:19:00+03	14400.00
8E31EA	2017-08-13 03:54:00+03	68700.00
8E31F5	2017-07-07 02:29:00+03	266400.00
8E31F6	2017-07-01 10:58:00+03	90600.00
8E3224	2017-07-02 21:12:00+03	288600.00
8E3234	2017-07-02 11:17:00+03	16400.00
8E323C	2017-07-07 22:48:00+03	98300.00
8E3246	2017-07-21 23:12:00+03	24000.00
8E3264	2017-08-03 01:18:00+03	269200.00
8E3297	2017-07-25 18:59:00+03	92400.00
8E32BF	2017-08-02 09:45:00+03	69900.00
8E32C4	2017-07-16 06:31:00+03	59800.00
8E32CA	2017-07-23 13:55:00+03	27700.00
8E339A	2017-07-28 19:30:00+03	56600.00
8E33C4	2017-06-29 22:34:00+03	34200.00
8E33F9	2017-07-18 12:26:00+03	119300.00
8E341E	2017-08-07 00:41:00+03	56000.00
8E3449	2017-08-10 12:42:00+03	44600.00
8E3466	2017-07-16 05:16:00+03	46000.00
8E3479	2017-07-01 05:21:00+03	169500.00
8E349F	2017-08-12 07:30:00+03	26000.00
8E34AB	2017-07-07 12:37:00+03	43000.00
8E34BB	2017-08-08 02:23:00+03	271200.00
8E34CE	2017-08-04 09:19:00+03	26800.00
8E3506	2017-08-03 00:37:00+03	67700.00
8E355A	2017-08-10 21:46:00+03	65900.00
8E3565	2017-07-27 23:51:00+03	61600.00
8E3576	2017-08-11 11:27:00+03	17200.00
8E3581	2017-07-17 09:24:00+03	12600.00
8E3597	2017-07-13 11:51:00+03	251700.00
8E35B2	2017-07-27 10:59:00+03	67100.00
8E362D	2017-07-03 21:27:00+03	115900.00
8E36C2	2017-07-02 00:30:00+03	26000.00
8E3703	2017-08-13 11:39:00+03	70800.00
8E370C	2017-07-04 02:36:00+03	101200.00
8E3753	2017-08-09 23:21:00+03	50200.00
8E3778	2017-08-03 09:23:00+03	66600.00
8E3795	2017-08-14 23:03:00+03	48400.00
8E37BB	2017-08-08 00:36:00+03	37200.00
8E3807	2017-07-11 17:11:00+03	31100.00
8E3868	2017-08-01 00:08:00+03	31000.00
8E3895	2017-08-09 18:15:00+03	114900.00
8E389A	2017-07-23 16:23:00+03	57400.00
8E38A3	2017-07-04 08:01:00+03	145300.00
8E390A	2017-08-02 02:44:00+03	398400.00
8E393D	2017-07-23 10:53:00+03	42800.00
8E3952	2017-08-10 06:08:00+03	52800.00
8E3959	2017-07-12 18:21:00+03	62800.00
8E395A	2017-07-11 07:29:00+03	23900.00
8E3969	2017-07-19 23:02:00+03	258400.00
8E3A6F	2017-07-27 01:21:00+03	14400.00
8E3AB3	2017-07-31 03:34:00+03	110500.00
8E3AB7	2017-07-22 17:08:00+03	80800.00
8E3B53	2017-07-13 08:49:00+03	46200.00
8E3B5F	2017-08-12 19:10:00+03	99600.00
8E3B7A	2017-07-21 13:46:00+03	8600.00
8E3BB4	2017-07-23 14:21:00+03	36800.00
8E3BB9	2017-07-03 08:45:00+03	24400.00
8E3C30	2017-08-06 22:23:00+03	59900.00
8E3C35	2017-08-13 04:40:00+03	98300.00
8E3C5A	2017-08-11 11:52:00+03	96800.00
8E3C77	2017-08-14 10:57:00+03	70000.00
8E3CF1	2017-07-02 13:43:00+03	50200.00
8E3D2D	2017-07-25 13:57:00+03	37200.00
8E3D5E	2017-07-05 20:32:00+03	369000.00
8E3D64	2017-07-29 04:16:00+03	38500.00
8E3DDB	2017-07-25 03:19:00+03	112000.00
8E3E97	2017-08-08 17:16:00+03	24800.00
8E3ED6	2017-07-14 17:00:00+03	56000.00
8E3EF0	2017-08-10 18:37:00+03	133600.00
8E3F38	2017-08-08 02:45:00+03	131600.00
8E3F8A	2017-07-01 00:40:00+03	25600.00
8E4012	2017-07-12 09:06:00+03	492000.00
8E401A	2017-07-16 22:29:00+03	61500.00
8E4023	2017-07-19 10:14:00+03	89700.00
8E4040	2017-07-11 15:42:00+03	31200.00
8E407D	2017-07-14 11:19:00+03	64400.00
8E40C9	2017-08-04 18:40:00+03	31600.00
8E40EB	2017-08-10 13:44:00+03	18800.00
8E412A	2017-08-09 01:59:00+03	79900.00
8E412C	2017-08-09 22:03:00+03	43100.00
8E414E	2017-08-01 08:50:00+03	26700.00
8E4163	2017-07-08 08:06:00+03	37800.00
8E4226	2017-07-22 04:27:00+03	185400.00
8E4246	2017-07-29 18:37:00+03	46700.00
8E429D	2017-07-15 17:33:00+03	54800.00
8E42CC	2017-08-02 11:13:00+03	54800.00
8E42E5	2017-07-10 12:21:00+03	48400.00
8E4342	2017-07-04 19:00:00+03	8200.00
8E4370	2017-07-28 02:04:00+03	945700.00
8E4389	2017-07-28 18:47:00+03	24400.00
8E4424	2017-07-28 09:13:00+03	15000.00
8E4427	2017-07-15 09:29:00+03	103800.00
8E4432	2017-07-06 03:38:00+03	153300.00
8E44F9	2017-08-14 19:25:00+03	54000.00
8E4507	2017-07-26 22:50:00+03	60200.00
8E453C	2017-06-29 10:52:00+03	38800.00
8E4574	2017-07-18 19:01:00+03	46000.00
8E45A4	2017-07-22 00:27:00+03	399600.00
8E45AD	2017-08-14 06:25:00+03	99200.00
8E45FD	2017-08-15 14:41:00+03	34800.00
8E4601	2017-08-07 18:13:00+03	28800.00
8E4652	2017-07-02 06:14:00+03	16800.00
8E46B7	2017-07-30 06:12:00+03	56100.00
8E46CE	2017-07-02 02:42:00+03	142000.00
8E481B	2017-07-15 05:16:00+03	99800.00
8E4887	2017-07-18 17:49:00+03	61400.00
8E48D5	2017-07-21 08:16:00+03	36200.00
8E4955	2017-07-12 19:24:00+03	39200.00
8E499D	2017-08-01 21:17:00+03	108600.00
8E49F4	2017-07-19 05:49:00+03	94000.00
8E4A00	2017-08-09 15:07:00+03	18800.00
8E4A04	2017-08-05 00:10:00+03	65900.00
8E4A33	2017-07-02 15:40:00+03	61500.00
8E4A8D	2017-06-27 02:05:00+03	8000.00
8E4B1C	2017-08-08 00:00:00+03	78300.00
8E4B1D	2017-06-30 14:30:00+03	52000.00
8E4B22	2017-08-11 00:17:00+03	46200.00
8E4B25	2017-07-23 13:45:00+03	115200.00
8E4B31	2017-08-10 20:43:00+03	47000.00
8E4B3C	2017-07-15 23:23:00+03	81700.00
8E4BB7	2017-08-11 06:21:00+03	111600.00
8E4BDC	2017-07-07 06:39:00+03	66600.00
8E4C07	2017-07-01 08:39:00+03	199300.00
8E4C1A	2017-07-24 13:16:00+03	8400.00
8E4C56	2017-08-09 11:41:00+03	37900.00
8E4C60	2017-07-23 01:43:00+03	20500.00
8E4CFF	2017-08-07 23:04:00+03	186900.00
8E4D3B	2017-08-06 16:24:00+03	67700.00
8E4DE0	2017-07-15 01:22:00+03	106800.00
8E4E7B	2017-08-08 06:01:00+03	173500.00
8E4EE8	2017-08-10 08:02:00+03	39800.00
8E4F02	2017-07-13 07:49:00+03	6300.00
8E4F29	2017-08-08 19:37:00+03	46400.00
8E4F61	2017-08-04 19:16:00+03	37900.00
8E4F80	2017-07-11 07:30:00+03	134600.00
8E509F	2017-07-30 09:23:00+03	298800.00
8E50A1	2017-07-08 21:18:00+03	67600.00
8E513D	2017-07-29 00:13:00+03	79600.00
8E515A	2017-07-26 12:45:00+03	46000.00
8E51AE	2017-07-25 12:43:00+03	26000.00
8E51C3	2017-07-17 10:21:00+03	24400.00
8E5225	2017-07-09 20:43:00+03	6800.00
8E5246	2017-08-08 21:53:00+03	16400.00
8E525E	2017-08-12 09:54:00+03	40800.00
8E5261	2017-07-07 16:15:00+03	110500.00
8E52DA	2017-08-11 10:57:00+03	68800.00
8E5314	2017-06-27 12:33:00+03	68400.00
8E5327	2017-07-26 17:59:00+03	273000.00
8E5352	2017-07-06 06:58:00+03	68900.00
8E5353	2017-08-07 23:00:00+03	75600.00
8E53E0	2017-07-25 02:52:00+03	369000.00
8E53F2	2017-08-06 01:35:00+03	22400.00
8E543C	2017-07-23 19:53:00+03	35800.00
8E5450	2017-07-22 13:53:00+03	37600.00
8E5476	2017-08-02 11:49:00+03	23200.00
8E5477	2017-08-15 17:33:00+03	76800.00
8E54EB	2017-06-29 10:17:00+03	75300.00
8E5515	2017-07-21 13:34:00+03	42400.00
8E5580	2017-07-23 02:14:00+03	16000.00
8E5689	2017-07-06 13:57:00+03	88900.00
8E5758	2017-07-28 17:55:00+03	22600.00
8E579B	2017-08-12 09:55:00+03	28800.00
8E587A	2017-07-19 18:51:00+03	61800.00
8E58C2	2017-07-06 22:07:00+03	211000.00
8E58E4	2017-07-19 06:18:00+03	40000.00
8E58F1	2017-08-04 00:02:00+03	73500.00
8E590A	2017-07-09 23:09:00+03	24000.00
8E5921	2017-08-11 03:06:00+03	26700.00
8E5936	2017-08-10 10:28:00+03	288600.00
8E59A7	2017-08-09 05:29:00+03	73300.00
8E59B1	2017-07-13 06:11:00+03	25200.00
8E5A79	2017-07-16 08:50:00+03	283100.00
8E5AF6	2017-07-29 01:52:00+03	18900.00
8E5B7A	2017-07-27 17:20:00+03	54800.00
8E5BA3	2017-07-23 18:18:00+03	18600.00
8E5BBC	2017-08-14 14:29:00+03	46400.00
8E5BD4	2017-07-15 08:00:00+03	27800.00
8E5BE2	2017-07-19 21:32:00+03	26000.00
8E5BF7	2017-07-28 17:53:00+03	29200.00
8E5C3A	2017-07-16 08:09:00+03	75600.00
8E5C7A	2017-08-14 01:49:00+03	177200.00
8E5CB2	2017-07-31 05:02:00+03	133700.00
8E5D52	2017-07-13 06:07:00+03	30400.00
8E5D58	2017-08-13 12:53:00+03	340500.00
8E5DA8	2017-07-02 02:42:00+03	67600.00
8E5DBC	2017-08-12 08:59:00+03	51900.00
8E5DC6	2017-08-10 15:04:00+03	12600.00
8E5DD6	2017-07-13 10:53:00+03	93700.00
8E5DD8	2017-08-04 09:38:00+03	96800.00
8E5DE8	2017-07-09 23:40:00+03	62700.00
8E5E2F	2017-08-09 22:06:00+03	123600.00
8E5F27	2017-08-15 00:12:00+03	81500.00
8E5F3A	2017-07-02 04:23:00+03	16400.00
8E5FA3	2017-07-21 17:48:00+03	132800.00
8E5FB1	2017-08-09 20:59:00+03	64800.00
8E5FB4	2017-07-11 13:08:00+03	26200.00
8E6020	2017-08-13 17:17:00+03	23600.00
8E6039	2017-08-13 06:03:00+03	27200.00
8E6053	2017-08-02 16:14:00+03	49500.00
8E6062	2017-08-12 09:07:00+03	55800.00
8E60A3	2017-07-22 19:26:00+03	79600.00
8E60EA	2017-07-20 03:52:00+03	144400.00
8E60EE	2017-07-08 17:42:00+03	23200.00
8E6157	2017-07-12 09:11:00+03	6000.00
8E617D	2017-07-15 16:08:00+03	26000.00
8E626C	2017-07-14 21:30:00+03	58400.00
8E6283	2017-08-10 04:32:00+03	59800.00
8E628C	2017-08-02 16:11:00+03	36900.00
8E62B9	2017-07-31 12:09:00+03	148800.00
8E6308	2017-07-23 00:35:00+03	6000.00
8E6379	2017-08-09 00:30:00+03	28800.00
8E6394	2017-07-24 07:51:00+03	57600.00
8E63D7	2017-08-14 21:49:00+03	7200.00
8E63EB	2017-07-31 13:25:00+03	27400.00
8E63F2	2017-07-29 17:48:00+03	48300.00
8E6434	2017-07-26 19:47:00+03	83200.00
8E6473	2017-07-25 23:16:00+03	202900.00
8E6477	2017-08-10 14:46:00+03	58700.00
8E64C8	2017-08-05 11:40:00+03	125400.00
8E64DB	2017-08-07 17:12:00+03	86600.00
8E64ED	2017-08-14 07:12:00+03	46400.00
8E64FE	2017-07-01 19:41:00+03	93900.00
8E6509	2017-07-30 21:58:00+03	27900.00
8E6577	2017-07-31 11:42:00+03	54800.00
8E6613	2017-08-15 05:33:00+03	97500.00
8E6618	2017-07-22 02:32:00+03	28800.00
8E66A4	2017-07-16 13:08:00+03	14800.00
8E66B2	2017-08-03 12:41:00+03	34000.00
8E67C0	2017-07-20 20:19:00+03	42800.00
8E6817	2017-07-20 19:51:00+03	62100.00
8E6831	2017-07-14 20:17:00+03	369000.00
8E684A	2017-07-05 23:01:00+03	31200.00
8E6982	2017-08-11 10:03:00+03	104000.00
8E6996	2017-07-27 22:36:00+03	46800.00
8E6A32	2017-07-07 21:48:00+03	43400.00
8E6A4E	2017-08-13 21:48:00+03	18600.00
8E6A5D	2017-08-14 03:49:00+03	12000.00
8E6A65	2017-07-16 23:15:00+03	114800.00
8E6A6D	2017-07-06 21:25:00+03	492000.00
8E6A94	2017-08-10 04:51:00+03	40600.00
8E6AB5	2017-06-29 21:23:00+03	6700.00
8E6ADE	2017-08-11 09:02:00+03	52000.00
8E6B26	2017-08-07 01:59:00+03	126400.00
8E6B2B	2017-07-26 10:50:00+03	65500.00
8E6B79	2017-08-11 01:47:00+03	36200.00
8E6B7D	2017-07-10 00:26:00+03	172600.00
8E6B95	2017-08-03 16:48:00+03	53200.00
8E6B9D	2017-07-08 13:32:00+03	28000.00
8E6BA6	2017-07-29 11:44:00+03	66000.00
8E6BB3	2017-08-05 03:50:00+03	13000.00
8E6C00	2017-08-05 07:46:00+03	23600.00
8E6C1D	2017-07-18 09:16:00+03	26700.00
8E6C37	2017-08-03 23:55:00+03	56000.00
8E6C4C	2017-07-10 06:03:00+03	37900.00
8E6D08	2017-06-29 23:15:00+03	78300.00
8E6D92	2017-07-27 18:45:00+03	32400.00
8E6DE8	2017-08-07 04:07:00+03	75600.00
8E6DF3	2017-08-13 14:15:00+03	12600.00
8E6F1F	2017-07-14 15:57:00+03	40100.00
8E6F27	2017-07-25 07:16:00+03	44000.00
8E6F68	2017-07-14 08:32:00+03	270400.00
8E6FA2	2017-07-17 09:12:00+03	47600.00
8E6FCD	2017-07-10 23:56:00+03	31200.00
8E6FDB	2017-07-08 06:37:00+03	29600.00
8E6FE1	2017-06-29 02:56:00+03	27900.00
8E7014	2017-07-26 11:37:00+03	22000.00
8E704A	2017-07-21 06:04:00+03	93000.00
8E70F5	2017-08-06 12:04:00+03	32200.00
8E719E	2017-07-21 07:31:00+03	41600.00
8E71A9	2017-07-21 12:20:00+03	40400.00
8E71E3	2017-07-17 04:43:00+03	65500.00
8E71F0	2017-07-10 19:48:00+03	38500.00
8E7228	2017-08-14 05:40:00+03	120700.00
8E7248	2017-07-27 15:57:00+03	101800.00
8E72BC	2017-08-12 04:14:00+03	12600.00
8E72E7	2017-07-11 03:25:00+03	55800.00
8E72FE	2017-07-18 14:00:00+03	33100.00
8E7304	2017-07-15 11:39:00+03	28800.00
8E732C	2017-07-08 02:12:00+03	68900.00
8E7346	2017-07-30 04:49:00+03	33200.00
8E7396	2017-07-31 12:28:00+03	56000.00
8E7418	2017-08-06 23:40:00+03	33600.00
8E7470	2017-07-14 05:56:00+03	56600.00
8E74E7	2017-07-24 06:08:00+03	25400.00
8E75BD	2017-08-08 21:58:00+03	89700.00
8E75C2	2017-08-07 23:18:00+03	13600.00
8E7664	2017-08-09 18:41:00+03	183300.00
8E771F	2017-07-19 09:55:00+03	87200.00
8E7720	2017-08-05 05:59:00+03	26800.00
8E7726	2017-07-19 19:57:00+03	65100.00
8E7821	2017-07-08 13:25:00+03	52000.00
8E7870	2017-06-30 13:38:00+03	26000.00
8E78D6	2017-07-10 14:26:00+03	38800.00
8E7914	2017-07-18 10:24:00+03	67600.00
8E79B2	2017-07-28 00:53:00+03	27300.00
8E79D9	2017-08-14 07:41:00+03	8200.00
8E79E9	2017-08-07 22:29:00+03	409200.00
8E7A32	2017-07-07 03:12:00+03	96800.00
8E7A6A	2017-08-08 04:51:00+03	64800.00
8E7A92	2017-08-07 08:45:00+03	56000.00
8E7AA5	2017-07-21 00:06:00+03	92800.00
8E7ACA	2017-07-08 16:46:00+03	44800.00
8E7B33	2017-08-10 23:56:00+03	73600.00
8E7B3C	2017-07-08 13:45:00+03	46200.00
8E7BEA	2017-07-28 07:11:00+03	23600.00
8E7BEB	2017-07-30 00:57:00+03	40800.00
8E7C00	2017-08-06 17:13:00+03	29800.00
8E7C75	2017-08-05 09:14:00+03	12600.00
8E7C7C	2017-08-02 05:31:00+03	58400.00
8E7CD8	2017-07-02 03:21:00+03	80000.00
8E7CD9	2017-08-04 14:27:00+03	265700.00
8E7D07	2017-07-01 14:26:00+03	103000.00
8E7D50	2017-07-07 00:18:00+03	74800.00
8E7DA3	2017-08-11 00:59:00+03	28000.00
8E7DA5	2017-07-10 11:52:00+03	36900.00
8E7DCE	2017-08-12 22:38:00+03	60200.00
8E7DEC	2017-08-06 01:45:00+03	23200.00
8E7E38	2017-08-01 08:54:00+03	135400.00
8E7E5D	2017-07-12 17:52:00+03	31400.00
8E7EB1	2017-07-28 03:51:00+03	132800.00
8E7EC4	2017-07-27 05:17:00+03	118500.00
8E7ED6	2017-08-03 12:58:00+03	48400.00
8E7F50	2017-08-06 06:38:00+03	137700.00
8E7F59	2017-07-12 12:42:00+03	29600.00
8E7F81	2017-07-24 00:47:00+03	11700.00
8E7F82	2017-07-11 14:02:00+03	17200.00
8E7F97	2017-07-15 04:41:00+03	147100.00
8E7FA5	2017-08-13 08:40:00+03	111600.00
8E7FE2	2017-07-23 05:23:00+03	89700.00
8E802A	2017-07-14 05:03:00+03	57600.00
8E8057	2017-08-10 12:29:00+03	6000.00
8E8062	2017-07-28 21:16:00+03	181100.00
8E8066	2017-08-10 06:25:00+03	28800.00
8E808B	2017-08-05 21:04:00+03	46000.00
8E8095	2017-07-28 13:45:00+03	22600.00
8E809C	2017-07-18 00:52:00+03	47400.00
8E80E3	2017-08-07 17:29:00+03	58500.00
8E813D	2017-08-11 04:06:00+03	55800.00
8E8174	2017-08-03 09:17:00+03	28000.00
8E81AC	2017-07-20 17:59:00+03	28000.00
8E81CB	2017-07-15 04:39:00+03	131100.00
8E82B0	2017-07-24 02:46:00+03	62600.00
8E82C8	2017-07-17 04:01:00+03	14000.00
8E8336	2017-08-07 20:12:00+03	94300.00
8E834E	2017-07-02 19:08:00+03	85000.00
8E83CF	2017-08-08 16:28:00+03	55800.00
8E83FE	2017-07-23 22:56:00+03	72400.00
8E8402	2017-07-14 05:59:00+03	80000.00
8E8413	2017-07-16 05:25:00+03	88600.00
8E84A7	2017-07-20 00:37:00+03	62600.00
8E852B	2017-08-03 21:11:00+03	46000.00
8E852C	2017-07-22 05:54:00+03	22600.00
8E8535	2017-08-14 13:20:00+03	31800.00
8E8562	2017-07-23 21:52:00+03	48300.00
8E8575	2017-08-12 18:12:00+03	14800.00
8E8586	2017-07-25 18:41:00+03	49100.00
8E859C	2017-08-02 15:26:00+03	141200.00
8E85E5	2017-07-28 08:24:00+03	46200.00
8E863C	2017-08-05 11:25:00+03	29600.00
8E863D	2017-08-14 13:08:00+03	46400.00
8E8680	2017-08-06 21:17:00+03	29400.00
8E86AA	2017-07-23 01:51:00+03	12400.00
8E86DB	2017-06-30 00:09:00+03	48800.00
8E8727	2017-07-23 20:51:00+03	113200.00
8E876F	2017-07-12 08:58:00+03	93900.00
8E87E7	2017-08-09 12:31:00+03	58800.00
8E87ED	2017-06-29 10:21:00+03	15700.00
8E87F9	2017-08-15 00:19:00+03	266400.00
8E8812	2017-08-15 09:10:00+03	22000.00
8E8819	2017-07-11 07:40:00+03	67700.00
8E883F	2017-06-28 04:29:00+03	28800.00
8E88E8	2017-07-01 08:04:00+03	115400.00
8E8906	2017-07-26 02:55:00+03	36200.00
8E89E3	2017-08-09 14:18:00+03	13400.00
8E8A95	2017-08-08 02:13:00+03	13600.00
8E8B2E	2017-07-20 23:23:00+03	16400.00
8E8B77	2017-07-20 08:55:00+03	135400.00
8E8B7F	2017-07-07 21:52:00+03	26000.00
8E8BC7	2017-07-12 05:38:00+03	52000.00
8E8BCF	2017-07-26 12:16:00+03	49300.00
8E8BD7	2017-07-21 03:30:00+03	156400.00
8E8C36	2017-07-19 20:37:00+03	6800.00
8E8C55	2017-07-30 11:58:00+03	289500.00
8E8C81	2017-07-01 17:56:00+03	122800.00
8E8CC5	2017-07-19 13:56:00+03	75600.00
8E8CED	2017-08-02 19:40:00+03	42800.00
8E8D3E	2017-08-09 06:35:00+03	60200.00
8E8D8A	2017-08-09 21:05:00+03	96800.00
8E8DC3	2017-08-01 19:51:00+03	85000.00
8E8E21	2017-08-05 23:55:00+03	252600.00
8E8E56	2017-07-17 22:15:00+03	166000.00
8E8EAA	2017-07-15 05:10:00+03	132800.00
8E8EB2	2017-08-06 13:10:00+03	271100.00
8E8ECF	2017-08-09 08:52:00+03	35400.00
8E8EE5	2017-07-26 00:04:00+03	194200.00
8E8F22	2017-07-13 05:12:00+03	46300.00
8E8F49	2017-07-20 07:01:00+03	47700.00
8E9045	2017-07-10 21:49:00+03	31000.00
8E909F	2017-07-31 07:30:00+03	229600.00
8E90D5	2017-08-07 01:10:00+03	56000.00
8E9112	2017-08-14 17:48:00+03	37600.00
8E91BC	2017-08-09 19:31:00+03	24800.00
8E91E3	2017-07-09 17:27:00+03	103500.00
8E9208	2017-07-21 03:40:00+03	112000.00
8E920A	2017-08-07 12:16:00+03	9800.00
8E920C	2017-07-15 06:11:00+03	75300.00
8E9268	2017-07-26 03:42:00+03	56000.00
8E9276	2017-07-29 07:57:00+03	27200.00
8E9287	2017-07-22 19:14:00+03	15000.00
8E929E	2017-08-09 23:49:00+03	86600.00
8E9306	2017-07-19 03:30:00+03	361400.00
8E930A	2017-07-12 17:56:00+03	155600.00
8E9313	2017-07-26 03:37:00+03	6400.00
8E931E	2017-07-08 05:15:00+03	136200.00
8E935D	2017-07-26 08:13:00+03	88800.00
8E9373	2017-07-01 01:43:00+03	65900.00
8E9374	2017-07-17 12:45:00+03	46800.00
8E93D1	2017-08-14 11:58:00+03	154400.00
8E93ED	2017-07-19 21:31:00+03	75600.00
8E947D	2017-07-18 21:30:00+03	98800.00
8E94DF	2017-08-05 05:00:00+03	6700.00
8E94F6	2017-08-03 15:01:00+03	15100.00
8E94FD	2017-07-08 15:40:00+03	84200.00
8E950A	2017-08-06 06:26:00+03	67700.00
8E9530	2017-07-15 15:47:00+03	78300.00
8E953A	2017-07-24 07:24:00+03	39600.00
8E957D	2017-07-11 01:37:00+03	33800.00
8E95CA	2017-08-04 05:43:00+03	14000.00
8E95F5	2017-07-26 12:00:00+03	51600.00
8E967B	2017-07-10 05:30:00+03	55800.00
8E968C	2017-06-30 14:39:00+03	31000.00
8E96A2	2017-07-03 22:36:00+03	23400.00
8E9756	2017-07-21 21:10:00+03	246000.00
8E97A5	2017-08-15 09:38:00+03	23200.00
8E97C8	2017-07-15 21:28:00+03	57600.00
8E981B	2017-07-10 07:16:00+03	211600.00
8E98C1	2017-08-07 17:08:00+03	70700.00
8E98C9	2017-07-20 13:18:00+03	133100.00
8E98F0	2017-08-15 01:36:00+03	33300.00
8E995D	2017-07-05 20:27:00+03	117000.00
8E9974	2017-08-04 05:04:00+03	26000.00
8E9988	2017-08-04 05:45:00+03	56000.00
8E9A49	2017-07-13 20:03:00+03	129700.00
8E9A52	2017-07-11 01:58:00+03	144400.00
8E9A76	2017-08-13 22:12:00+03	14400.00
8E9AE4	2017-07-05 22:36:00+03	65500.00
8E9B39	2017-08-13 02:30:00+03	27200.00
8E9BA7	2017-07-14 09:05:00+03	246000.00
8E9BCB	2017-07-11 18:51:00+03	129200.00
8E9BF3	2017-07-28 09:54:00+03	306600.00
8E9C75	2017-07-19 04:26:00+03	39000.00
8E9C9D	2017-07-21 19:17:00+03	77000.00
8E9D17	2017-08-12 16:05:00+03	49600.00
8E9D4F	2017-08-12 06:55:00+03	46300.00
8E9D6D	2017-08-05 08:27:00+03	98400.00
8E9D7E	2017-07-09 04:39:00+03	156300.00
8E9D82	2017-07-30 09:56:00+03	12600.00
8E9DA7	2017-07-22 02:19:00+03	88500.00
8E9E3F	2017-07-08 15:02:00+03	113200.00
8E9EB2	2017-07-24 08:20:00+03	94900.00
8E9EE4	2017-08-08 13:15:00+03	18000.00
8E9F12	2017-07-25 17:39:00+03	32800.00
8E9F26	2017-07-05 00:23:00+03	8400.00
8E9F2A	2017-07-30 10:16:00+03	38800.00
8E9F79	2017-07-02 06:10:00+03	38600.00
8E9FB0	2017-08-15 08:45:00+03	12000.00
8EA013	2017-07-30 20:58:00+03	35600.00
8EA0B1	2017-08-10 09:09:00+03	90000.00
8EA0B7	2017-08-13 21:35:00+03	189800.00
8EA0EB	2017-07-22 18:41:00+03	13400.00
8EA1D4	2017-07-19 17:28:00+03	39100.00
8EA1E2	2017-07-17 20:45:00+03	37100.00
8EA292	2017-07-01 17:16:00+03	101800.00
8EA35A	2017-08-12 13:37:00+03	141000.00
8EA42B	2017-07-22 17:35:00+03	6700.00
8EA495	2017-08-10 20:21:00+03	6000.00
8EA592	2017-08-09 00:27:00+03	119500.00
8EA5B5	2017-08-12 07:17:00+03	28200.00
8EA5E6	2017-07-12 16:56:00+03	32800.00
8EA63C	2017-08-12 13:52:00+03	168400.00
8EA715	2017-08-11 03:20:00+03	188900.00
8EA724	2017-07-23 14:35:00+03	131100.00
8EA729	2017-07-08 07:40:00+03	24400.00
8EA75F	2017-08-14 18:05:00+03	36800.00
8EA7C3	2017-08-10 12:49:00+03	65900.00
8EA8DD	2017-07-15 11:13:00+03	59200.00
8EA95E	2017-07-13 09:16:00+03	218100.00
8EA977	2017-07-25 14:58:00+03	50600.00
8EAA06	2017-07-26 05:27:00+03	70100.00
8EAA22	2017-07-28 08:25:00+03	41200.00
8EAA4A	2017-07-17 23:21:00+03	26800.00
8EAA4D	2017-07-22 17:51:00+03	23200.00
8EAA59	2017-07-13 13:05:00+03	16400.00
8EAA81	2017-07-26 02:38:00+03	229900.00
8EAA9F	2017-07-09 03:48:00+03	529100.00
8EAABE	2017-07-16 04:44:00+03	85000.00
8EAAEC	2017-07-26 06:57:00+03	75600.00
8EAB33	2017-08-06 19:02:00+03	26000.00
8EABC0	2017-07-07 00:46:00+03	51600.00
8EABDC	2017-07-09 07:44:00+03	21400.00
8EAC0F	2017-07-26 20:40:00+03	28800.00
8EAC31	2017-07-23 13:28:00+03	186900.00
8EAC43	2017-07-20 10:46:00+03	28800.00
8EACAA	2017-07-31 19:24:00+03	62100.00
8EACC6	2017-07-16 21:23:00+03	23600.00
8EACC8	2017-08-13 01:39:00+03	48800.00
8EACDD	2017-07-17 14:32:00+03	155400.00
8EAD26	2017-07-19 15:46:00+03	260700.00
8EAD67	2017-07-23 12:10:00+03	32900.00
8EAD6C	2017-08-14 10:11:00+03	26000.00
8EAD88	2017-07-29 03:04:00+03	32800.00
8EADA2	2017-07-23 20:40:00+03	73600.00
8EADD4	2017-08-13 15:20:00+03	101100.00
8EADD9	2017-08-12 02:34:00+03	115100.00
8EAE13	2017-08-01 18:25:00+03	96300.00
8EAE1C	2017-08-06 08:59:00+03	40600.00
8EAE6B	2017-07-22 05:58:00+03	65200.00
8EAEB0	2017-07-03 19:28:00+03	45500.00
8EAEF9	2017-07-28 03:56:00+03	62700.00
8EAF9B	2017-08-09 17:58:00+03	6800.00
8EAFC7	2017-07-27 16:38:00+03	87200.00
8EB04F	2017-08-12 10:37:00+03	20400.00
8EB0C1	2017-08-09 17:35:00+03	90000.00
8EB0C9	2017-08-11 18:28:00+03	273000.00
8EB0CC	2017-07-07 09:35:00+03	19600.00
8EB0D9	2017-06-28 16:28:00+03	243600.00
8EB0F2	2017-07-09 06:09:00+03	56100.00
8EB0FE	2017-07-25 20:20:00+03	232200.00
8EB15B	2017-07-25 08:25:00+03	119600.00
8EB1B9	2017-07-03 16:27:00+03	18800.00
8EB1D5	2017-08-04 01:09:00+03	132800.00
8EB1D8	2017-07-18 22:06:00+03	29600.00
8EB230	2017-08-12 07:40:00+03	151200.00
8EB245	2017-07-08 04:01:00+03	62600.00
8EB26C	2017-07-04 16:16:00+03	67600.00
8EB283	2017-07-12 06:57:00+03	55800.00
8EB2C5	2017-07-11 03:22:00+03	41200.00
8EB2E5	2017-07-25 06:16:00+03	22000.00
8EB2F1	2017-08-08 04:42:00+03	123000.00
8EB336	2017-07-06 11:06:00+03	174800.00
8EB365	2017-08-14 23:32:00+03	48500.00
8EB388	2017-08-04 06:17:00+03	48400.00
8EB3B7	2017-07-01 22:02:00+03	51900.00
8EB513	2017-07-03 01:48:00+03	6000.00
8EB57B	2017-08-01 07:06:00+03	252200.00
8EB645	2017-08-04 04:00:00+03	55800.00
8EB655	2017-07-25 18:05:00+03	58200.00
8EB6FD	2017-07-30 03:33:00+03	56000.00
8EB701	2017-08-14 03:17:00+03	57800.00
8EB72B	2017-07-26 10:29:00+03	47000.00
8EB73A	2017-07-04 02:28:00+03	70800.00
8EB754	2017-08-12 02:58:00+03	93500.00
8EB761	2017-07-29 14:54:00+03	180200.00
8EB7B4	2017-08-03 14:23:00+03	25100.00
8EB88D	2017-07-12 14:03:00+03	215500.00
8EB8D7	2017-07-19 21:51:00+03	64100.00
8EB8F8	2017-07-21 06:47:00+03	21400.00
8EB8FA	2017-07-14 21:20:00+03	38400.00
8EB925	2017-07-05 23:46:00+03	13300.00
8EB97F	2017-07-08 18:56:00+03	57600.00
8EB9B8	2017-07-23 12:49:00+03	12000.00
8EB9CB	2017-08-09 15:58:00+03	68800.00
8EBA7D	2017-07-04 04:32:00+03	89600.00
8EBAA0	2017-08-03 21:35:00+03	95600.00
8EBAAE	2017-08-13 19:06:00+03	27900.00
8EBAD4	2017-08-04 06:32:00+03	42500.00
8EBADD	2017-07-24 08:20:00+03	23400.00
8EBADF	2017-07-05 03:19:00+03	9200.00
8EBAED	2017-07-27 15:51:00+03	246000.00
8EBB48	2017-08-05 00:38:00+03	14800.00
8EBB50	2017-08-07 22:51:00+03	397700.00
8EBB5E	2017-07-19 17:19:00+03	102300.00
8EBB6C	2017-07-03 06:39:00+03	83700.00
8EBBA9	2017-07-22 11:42:00+03	31400.00
8EBC48	2017-07-21 23:25:00+03	67600.00
8EBD24	2017-07-17 10:45:00+03	66600.00
8EBD2F	2017-07-30 01:46:00+03	177200.00
8EBD3F	2017-08-14 06:33:00+03	147900.00
8EBD83	2017-08-03 23:29:00+03	55800.00
8EBDA0	2017-07-02 07:32:00+03	46400.00
8EBDB0	2017-07-08 15:45:00+03	52000.00
8EBE01	2017-08-07 17:25:00+03	29600.00
8EBE2D	2017-07-20 13:21:00+03	54800.00
8EBE5F	2017-07-11 22:33:00+03	114400.00
8EBE8E	2017-08-04 02:58:00+03	270700.00
8EBF13	2017-07-05 18:36:00+03	23200.00
8EBFC3	2017-06-29 16:22:00+03	123000.00
8EBFE3	2017-08-08 07:09:00+03	130900.00
8EC004	2017-07-16 18:10:00+03	20200.00
8EC02C	2017-06-29 00:48:00+03	69700.00
8EC0A7	2017-07-01 06:19:00+03	40400.00
8EC0A9	2017-08-12 07:24:00+03	136200.00
8EC110	2017-08-12 23:41:00+03	87200.00
8EC2A2	2017-07-09 04:47:00+03	187600.00
8EC2BA	2017-07-27 23:48:00+03	47400.00
8EC300	2017-08-13 00:04:00+03	23900.00
8EC301	2017-08-12 11:16:00+03	56000.00
8EC374	2017-07-09 05:33:00+03	61900.00
8EC39A	2017-07-21 04:09:00+03	38400.00
8EC39B	2017-07-03 10:14:00+03	85900.00
8EC3C2	2017-07-23 14:14:00+03	24800.00
8EC3FE	2017-07-30 20:33:00+03	13200.00
8EC407	2017-07-03 03:16:00+03	167400.00
8EC44D	2017-08-15 15:32:00+03	64600.00
8EC459	2017-08-11 06:41:00+03	28800.00
8EC48E	2017-07-06 09:43:00+03	27200.00
8EC49A	2017-08-02 10:57:00+03	51200.00
8EC4BB	2017-08-14 23:41:00+03	23600.00
8EC4BE	2017-07-21 19:14:00+03	133100.00
8EC4EA	2017-07-27 08:50:00+03	67600.00
8EC56D	2017-08-14 00:51:00+03	29600.00
8EC576	2017-07-03 19:14:00+03	56900.00
8EC58E	2017-07-17 06:47:00+03	155500.00
8EC5B9	2017-08-13 03:25:00+03	54500.00
8EC5CE	2017-07-12 20:15:00+03	28000.00
8EC5D9	2017-08-06 10:37:00+03	11600.00
8EC609	2017-07-10 23:48:00+03	91100.00
8EC62E	2017-06-29 13:19:00+03	106100.00
8EC636	2017-08-01 15:01:00+03	75800.00
8EC65A	2017-07-02 02:00:00+03	41600.00
8EC65C	2017-07-18 05:32:00+03	46000.00
8EC66D	2017-06-28 02:27:00+03	168000.00
8EC6AE	2017-08-12 14:53:00+03	13600.00
8EC6B8	2017-06-29 12:38:00+03	12400.00
8EC6C1	2017-07-10 03:00:00+03	134400.00
8EC6C9	2017-07-19 22:49:00+03	73100.00
8EC6EF	2017-08-02 21:57:00+03	28800.00
8EC6F7	2017-07-19 04:33:00+03	72800.00
8EC7C0	2017-08-09 07:18:00+03	67400.00
8EC834	2017-08-04 07:39:00+03	19600.00
8EC83E	2017-08-10 14:05:00+03	26000.00
8EC85A	2017-07-24 21:27:00+03	176500.00
8EC86C	2017-08-12 03:20:00+03	39800.00
8EC86E	2017-07-25 17:41:00+03	8400.00
8EC86F	2017-07-25 01:06:00+03	37700.00
8EC8D5	2017-08-07 19:07:00+03	25400.00
8EC914	2017-07-28 04:10:00+03	37200.00
8EC940	2017-08-07 02:04:00+03	56000.00
8EC952	2017-07-07 06:00:00+03	42800.00
8EC98A	2017-07-15 07:07:00+03	22400.00
8EC9B5	2017-08-04 00:23:00+03	67200.00
8ECB8A	2017-07-22 03:05:00+03	46400.00
8ECB96	2017-07-12 08:52:00+03	90800.00
8ECBB5	2017-07-19 18:34:00+03	64400.00
8ECBB9	2017-07-23 19:56:00+03	36200.00
8ECBBF	2017-08-01 05:32:00+03	47400.00
8ECBDA	2017-07-09 13:04:00+03	135400.00
8ECC82	2017-07-05 19:39:00+03	55800.00
8ECCCA	2017-07-08 12:38:00+03	78200.00
8ECCFD	2017-07-22 11:08:00+03	189800.00
8ECD68	2017-07-27 15:04:00+03	246000.00
8ECD91	2017-07-17 21:54:00+03	18600.00
8ECDE4	2017-08-02 07:01:00+03	45100.00
8ECDFD	2017-06-30 20:05:00+03	34000.00
8ECE2C	2017-07-26 21:32:00+03	64100.00
8ECE55	2017-07-19 05:36:00+03	12600.00
8ECE83	2017-08-15 07:45:00+03	136200.00
8ECF1A	2017-08-14 13:49:00+03	34400.00
8ECFA9	2017-07-09 18:01:00+03	15000.00
8ED02D	2017-07-07 14:16:00+03	39200.00
8ED076	2017-07-17 03:29:00+03	95200.00
8ED08A	2017-07-12 03:47:00+03	139300.00
8ED114	2017-07-25 18:36:00+03	50000.00
8ED137	2017-07-25 18:06:00+03	44800.00
8ED13E	2017-08-09 07:31:00+03	66900.00
8ED142	2017-08-03 23:31:00+03	81600.00
8ED14A	2017-08-08 14:07:00+03	405200.00
8ED1DA	2017-08-13 15:19:00+03	112000.00
8ED265	2017-07-28 00:43:00+03	38800.00
8ED2DC	2017-07-06 10:52:00+03	33100.00
8ED300	2017-07-23 14:08:00+03	94700.00
8ED318	2017-08-09 21:23:00+03	6700.00
8ED32D	2017-07-09 10:21:00+03	45200.00
8ED352	2017-07-07 11:10:00+03	25400.00
8ED3F3	2017-08-09 01:39:00+03	46300.00
8ED3F5	2017-07-20 04:56:00+03	29200.00
8ED489	2017-07-26 13:22:00+03	155400.00
8ED4AD	2017-06-29 02:26:00+03	31400.00
8ED5D8	2017-07-26 15:29:00+03	11800.00
8ED606	2017-07-01 10:37:00+03	45100.00
8ED739	2017-08-06 01:59:00+03	42700.00
8ED758	2017-08-13 10:56:00+03	26000.00
8ED7D0	2017-08-12 15:31:00+03	31600.00
8ED7D5	2017-07-13 12:58:00+03	112000.00
8ED7DF	2017-07-05 16:56:00+03	28800.00
8ED7FE	2017-07-13 15:17:00+03	89700.00
8ED81C	2017-08-04 08:56:00+03	36900.00
8ED86D	2017-07-18 03:51:00+03	124200.00
8ED8C4	2017-07-25 08:26:00+03	6600.00
8ED8F3	2017-08-14 09:17:00+03	97900.00
8ED979	2017-07-26 21:04:00+03	62700.00
8ED986	2017-07-20 22:06:00+03	21800.00
8ED9BA	2017-07-21 17:50:00+03	24800.00
8EDAAF	2017-07-09 11:35:00+03	54600.00
8EDABE	2017-08-11 08:52:00+03	96400.00
8EDB63	2017-08-07 02:39:00+03	23200.00
8EDB70	2017-08-12 06:58:00+03	62800.00
8EDC87	2017-07-18 02:21:00+03	94900.00
8EDC97	2017-07-17 07:58:00+03	49500.00
8EDCAB	2017-07-19 08:50:00+03	96800.00
8EDCC5	2017-08-06 11:43:00+03	26800.00
8EDCE6	2017-08-10 22:21:00+03	90400.00
8EDD2F	2017-07-10 20:50:00+03	132800.00
8EDD4B	2017-08-07 16:27:00+03	118200.00
8EDD92	2017-07-30 11:15:00+03	48800.00
8EDDAB	2017-06-29 02:40:00+03	74900.00
8EDE3D	2017-07-20 23:12:00+03	56000.00
8EDE60	2017-08-11 21:52:00+03	68800.00
8EDE67	2017-08-08 04:08:00+03	20600.00
8EDE7F	2017-07-15 18:23:00+03	35700.00
8EDEA8	2017-07-17 20:17:00+03	57500.00
8EDEC7	2017-08-10 14:52:00+03	44800.00
8EDEF0	2017-07-20 20:21:00+03	28000.00
8EDFB2	2017-08-04 04:01:00+03	69500.00
8EDFBE	2017-07-25 22:19:00+03	72300.00
8EDFFD	2017-08-04 17:42:00+03	56600.00
8EE000	2017-08-13 06:15:00+03	135200.00
8EE05C	2017-07-19 21:39:00+03	65900.00
8EE066	2017-07-25 20:56:00+03	49200.00
8EE085	2017-07-27 07:41:00+03	78200.00
8EE08B	2017-08-12 06:40:00+03	20200.00
8EE0C0	2017-07-18 07:31:00+03	40800.00
8EE15D	2017-07-06 09:34:00+03	11700.00
8EE1DF	2017-07-10 01:52:00+03	60400.00
8EE1E2	2017-06-30 20:46:00+03	137000.00
8EE1E8	2017-08-07 04:31:00+03	28000.00
8EE246	2017-07-26 14:10:00+03	54800.00
8EE253	2017-07-11 06:27:00+03	65600.00
8EE291	2017-07-10 14:32:00+03	28800.00
8EE2BC	2017-08-08 19:53:00+03	55800.00
8EE398	2017-07-24 21:52:00+03	54300.00
8EE3B3	2017-07-30 16:03:00+03	15400.00
8EE3D5	2017-08-09 00:14:00+03	19100.00
8EE447	2017-07-19 22:33:00+03	67200.00
8EE450	2017-07-30 13:56:00+03	56900.00
8EE476	2017-07-13 10:34:00+03	22600.00
8EE497	2017-07-28 06:01:00+03	23200.00
8EE4F5	2017-07-28 10:43:00+03	16400.00
8EE560	2017-07-29 21:23:00+03	254800.00
8EE579	2017-07-06 14:38:00+03	26000.00
8EE597	2017-08-10 00:23:00+03	124200.00
8EE5CB	2017-08-13 06:41:00+03	36600.00
8EE642	2017-07-07 04:37:00+03	135200.00
8EE6F5	2017-07-23 08:30:00+03	40200.00
8EE73A	2017-08-15 17:45:00+03	135400.00
8EE827	2017-07-13 20:03:00+03	58900.00
8EE831	2017-07-04 08:23:00+03	45200.00
8EE842	2017-07-22 10:36:00+03	7200.00
8EE86A	2017-07-08 08:23:00+03	92000.00
8EE874	2017-08-15 03:26:00+03	85000.00
8EE888	2017-08-08 21:14:00+03	136200.00
8EE8D9	2017-07-29 05:07:00+03	47500.00
8EE9D8	2017-08-04 12:56:00+03	103200.00
8EE9FC	2017-07-18 08:39:00+03	48500.00
8EEA43	2017-08-05 19:21:00+03	6800.00
8EEA50	2017-07-26 19:50:00+03	259000.00
8EEA5D	2017-08-04 14:02:00+03	248400.00
8EEA9B	2017-08-13 05:47:00+03	43900.00
8EEABC	2017-08-13 15:11:00+03	94000.00
8EEAD4	2017-08-02 04:09:00+03	16400.00
8EEB15	2017-07-04 13:36:00+03	54400.00
8EEB66	2017-08-02 10:46:00+03	44000.00
8EEBBA	2017-08-08 03:27:00+03	121800.00
8EEBF4	2017-08-09 05:52:00+03	116900.00
8EEBF6	2017-07-21 14:51:00+03	86400.00
8EEC73	2017-07-25 18:38:00+03	15000.00
8EECA1	2017-07-24 20:53:00+03	32800.00
8EECA4	2017-07-09 15:22:00+03	46300.00
8EECE7	2017-07-24 20:58:00+03	54400.00
8EED8B	2017-08-10 20:28:00+03	61800.00
8EEDB7	2017-07-10 13:40:00+03	58600.00
8EEE36	2017-07-20 01:24:00+03	82200.00
8EEE39	2017-08-11 15:24:00+03	46400.00
8EEF10	2017-08-03 08:19:00+03	58000.00
8EEF71	2017-07-24 04:43:00+03	67000.00
8EEFB2	2017-07-12 02:05:00+03	20400.00
8EEFB6	2017-07-13 15:57:00+03	13700.00
8EEFFF	2017-08-04 13:56:00+03	110500.00
8EF100	2017-07-10 17:13:00+03	55800.00
8EF187	2017-07-21 23:31:00+03	112000.00
8EF1D6	2017-08-04 16:43:00+03	47000.00
8EF285	2017-07-10 06:20:00+03	146300.00
8EF369	2017-08-01 06:31:00+03	24700.00
8EF376	2017-07-03 12:55:00+03	55800.00
8EF3B5	2017-07-11 10:10:00+03	16800.00
8EF40A	2017-07-21 05:21:00+03	32800.00
8EF469	2017-07-07 12:45:00+03	52700.00
8EF498	2017-07-27 08:10:00+03	205600.00
8EF4D7	2017-07-19 02:36:00+03	33600.00
8EF4E2	2017-07-21 09:37:00+03	36200.00
8EF510	2017-07-03 04:39:00+03	140900.00
8EF51B	2017-08-02 16:42:00+03	112000.00
8EF568	2017-08-15 16:05:00+03	68800.00
8EF583	2017-07-14 08:16:00+03	17600.00
8EF585	2017-07-30 07:50:00+03	178800.00
8EF5D1	2017-07-28 04:24:00+03	234100.00
8EF5D6	2017-07-29 11:28:00+03	99300.00
8EF609	2017-07-14 10:15:00+03	151900.00
8EF65C	2017-07-22 08:33:00+03	75600.00
8EF6AF	2017-07-19 12:58:00+03	13700.00
8EF6E2	2017-08-11 22:10:00+03	25600.00
8EF6E9	2017-08-08 21:04:00+03	43000.00
8EF7A4	2017-07-30 16:27:00+03	15000.00
8EF7CB	2017-07-28 10:20:00+03	68800.00
8EF810	2017-07-08 21:46:00+03	155700.00
8EF86A	2017-08-13 19:47:00+03	27200.00
8EF86C	2017-07-25 18:16:00+03	247100.00
8EF8F9	2017-07-02 04:33:00+03	23200.00
8EF920	2017-07-29 07:16:00+03	66600.00
8EF982	2017-07-06 05:21:00+03	202600.00
8EF998	2017-07-17 10:08:00+03	151600.00
8EF9DE	2017-07-15 01:12:00+03	156100.00
8EF9EB	2017-07-15 01:58:00+03	103500.00
8EFA8C	2017-07-24 20:50:00+03	85000.00
8EFB61	2017-07-07 03:34:00+03	42800.00
8EFBA3	2017-06-29 19:40:00+03	139300.00
8EFBF4	2017-08-15 05:31:00+03	136800.00
8EFC2D	2017-07-30 23:00:00+03	28000.00
8EFCF8	2017-07-08 15:19:00+03	46200.00
8EFD56	2017-07-08 16:50:00+03	66700.00
8EFDA7	2017-08-03 13:46:00+03	46400.00
8EFDF1	2017-08-10 08:16:00+03	15100.00
8EFE73	2017-07-02 17:39:00+03	40800.00
8EFEA4	2017-08-08 23:33:00+03	11100.00
8EFEC9	2017-07-24 02:02:00+03	11000.00
8EFF2D	2017-07-28 09:53:00+03	64100.00
8EFF3B	2017-07-19 20:42:00+03	198400.00
8EFF55	2017-07-17 23:20:00+03	100200.00
8EFFE9	2017-08-02 11:05:00+03	30000.00
8F0005	2017-07-19 21:33:00+03	23400.00
8F0068	2017-07-26 04:21:00+03	169900.00
8F008B	2017-08-05 14:35:00+03	38400.00
8F0095	2017-07-03 11:33:00+03	73300.00
8F00A1	2017-07-30 14:02:00+03	35600.00
8F00CB	2017-07-29 09:03:00+03	123000.00
8F00E0	2017-07-15 01:36:00+03	260300.00
8F0191	2017-07-10 07:28:00+03	100600.00
8F01E2	2017-07-15 14:47:00+03	49400.00
8F0200	2017-07-09 23:07:00+03	8000.00
8F0283	2017-07-05 15:53:00+03	124200.00
8F032B	2017-08-01 23:16:00+03	163500.00
8F0342	2017-08-04 08:03:00+03	56600.00
8F03A6	2017-08-04 23:49:00+03	21200.00
8F03B8	2017-07-30 03:12:00+03	160700.00
8F03C7	2017-07-06 07:01:00+03	10800.00
8F042C	2017-08-14 22:28:00+03	10100.00
8F0461	2017-07-12 17:29:00+03	6300.00
8F0490	2017-07-07 14:23:00+03	23200.00
8F04A5	2017-07-29 19:39:00+03	29600.00
8F04C8	2017-08-01 03:23:00+03	34000.00
8F04D4	2017-07-14 23:56:00+03	28000.00
8F0515	2017-08-09 11:12:00+03	47000.00
8F0517	2017-07-28 00:22:00+03	20600.00
8F052A	2017-08-13 17:22:00+03	75600.00
8F0565	2017-07-10 10:17:00+03	10800.00
8F058C	2017-08-07 12:23:00+03	30200.00
8F0602	2017-07-17 16:01:00+03	23200.00
8F0615	2017-07-26 12:33:00+03	62900.00
8F0643	2017-08-05 14:08:00+03	203500.00
8F067E	2017-07-26 22:49:00+03	56600.00
8F0691	2017-08-13 13:04:00+03	24300.00
8F06F1	2017-08-07 08:59:00+03	23600.00
8F06F5	2017-07-26 17:19:00+03	95300.00
8F0720	2017-07-22 16:58:00+03	47200.00
8F07E2	2017-08-02 04:51:00+03	28000.00
8F07F8	2017-07-05 08:02:00+03	58900.00
8F0831	2017-07-20 04:19:00+03	23200.00
8F0859	2017-07-25 16:24:00+03	78100.00
8F08FA	2017-07-10 11:41:00+03	296800.00
8F0925	2017-07-24 15:09:00+03	406100.00
8F0955	2017-07-14 08:45:00+03	226800.00
8F097D	2017-08-01 02:36:00+03	94000.00
8F0993	2017-07-10 08:47:00+03	46500.00
8F09D4	2017-08-13 08:49:00+03	53800.00
8F09E7	2017-07-17 04:29:00+03	50200.00
8F09FB	2017-07-11 13:16:00+03	66300.00
8F0A9B	2017-08-09 17:03:00+03	167400.00
8F0B95	2017-07-08 23:43:00+03	91600.00
8F0BC2	2017-07-14 01:12:00+03	80000.00
8F0BF5	2017-08-08 07:54:00+03	73200.00
8F0C32	2017-08-08 23:25:00+03	30000.00
8F0C67	2017-08-09 17:07:00+03	166900.00
8F0C93	2017-08-14 14:52:00+03	173500.00
8F0CD9	2017-07-14 20:59:00+03	75400.00
8F0D1B	2017-07-27 10:35:00+03	146300.00
8F0DEE	2017-07-30 04:19:00+03	6000.00
8F0E22	2017-07-28 10:16:00+03	270800.00
8F0E9B	2017-07-13 08:50:00+03	56900.00
8F0ED1	2017-08-09 01:56:00+03	27000.00
8F0F0C	2017-08-02 11:32:00+03	53600.00
8F0F34	2017-07-11 14:46:00+03	87100.00
8F0FA4	2017-08-15 06:55:00+03	25600.00
8F0FAC	2017-08-10 15:33:00+03	399600.00
8F0FAF	2017-07-13 20:54:00+03	135000.00
8F10CE	2017-07-25 11:36:00+03	59000.00
8F1135	2017-07-08 03:26:00+03	13400.00
8F1136	2017-08-14 18:13:00+03	47400.00
8F1159	2017-07-06 12:10:00+03	31600.00
8F1166	2017-07-26 19:23:00+03	47700.00
8F1176	2017-08-14 11:17:00+03	37400.00
8F11D0	2017-08-01 00:11:00+03	23200.00
8F11E7	2017-08-04 19:33:00+03	43000.00
8F1218	2017-08-05 07:15:00+03	83000.00
8F1236	2017-07-19 15:57:00+03	246000.00
8F1268	2017-07-08 23:03:00+03	6700.00
8F126D	2017-08-09 11:23:00+03	28000.00
8F127F	2017-06-28 06:47:00+03	40800.00
8F12AD	2017-08-06 08:45:00+03	31600.00
8F12AF	2017-07-14 06:30:00+03	11700.00
8F12EB	2017-07-09 09:35:00+03	59200.00
8F13B1	2017-07-12 16:34:00+03	14400.00
8F1408	2017-08-06 09:21:00+03	101100.00
8F1414	2017-08-06 07:08:00+03	295700.00
8F1415	2017-08-04 20:39:00+03	59600.00
8F1434	2017-08-07 19:04:00+03	146800.00
8F1503	2017-07-07 01:06:00+03	46200.00
8F15CC	2017-08-01 08:18:00+03	95400.00
8F160B	2017-08-06 10:13:00+03	132900.00
8F1630	2017-07-13 06:49:00+03	167400.00
8F16A2	2017-07-14 16:48:00+03	53100.00
8F16A4	2017-08-01 13:11:00+03	47000.00
8F16CD	2017-07-25 23:46:00+03	135600.00
8F16D2	2017-07-12 03:45:00+03	14800.00
8F16D4	2017-07-12 23:08:00+03	25800.00
8F16E5	2017-07-13 00:44:00+03	76100.00
8F172C	2017-07-18 20:01:00+03	10800.00
8F1739	2017-07-03 14:15:00+03	14000.00
8F173A	2017-08-14 07:04:00+03	65400.00
8F177F	2017-07-30 14:04:00+03	51900.00
8F178F	2017-07-15 11:25:00+03	92900.00
8F17BE	2017-07-23 00:45:00+03	161300.00
8F17D1	2017-08-09 03:37:00+03	40100.00
8F17E5	2017-07-15 14:16:00+03	257600.00
8F1815	2017-07-22 13:54:00+03	64700.00
8F181F	2017-08-03 17:25:00+03	20400.00
8F1820	2017-08-01 15:30:00+03	103200.00
8F1875	2017-07-09 02:13:00+03	27900.00
8F1896	2017-08-06 12:46:00+03	59800.00
8F18C7	2017-07-27 06:41:00+03	52000.00
8F18E2	2017-08-15 11:26:00+03	152300.00
8F18FD	2017-08-15 00:29:00+03	24200.00
8F1952	2017-07-25 09:42:00+03	58400.00
8F1955	2017-07-29 13:33:00+03	46900.00
8F199C	2017-08-05 04:47:00+03	67000.00
8F1B01	2017-08-10 03:28:00+03	12000.00
8F1B03	2017-07-25 18:31:00+03	39300.00
8F1B53	2017-07-06 08:45:00+03	266200.00
8F1BBD	2017-08-02 16:32:00+03	16800.00
8F1C2E	2017-07-24 08:01:00+03	11200.00
8F1C88	2017-07-12 12:40:00+03	46400.00
8F1CAE	2017-08-06 22:29:00+03	68100.00
8F1CC8	2017-07-03 16:33:00+03	21400.00
8F1D1B	2017-07-22 06:55:00+03	57600.00
8F1E1B	2017-07-07 01:56:00+03	14000.00
8F1E5D	2017-08-13 14:37:00+03	195400.00
8F1EC2	2017-08-08 19:29:00+03	276500.00
8F1ECE	2017-08-07 11:52:00+03	58200.00
8F1F70	2017-07-27 08:00:00+03	23200.00
8F2065	2017-07-24 15:52:00+03	34700.00
8F20FE	2017-07-03 07:37:00+03	26000.00
8F2160	2017-08-10 11:27:00+03	86500.00
8F21A6	2017-07-08 17:30:00+03	46000.00
8F21A9	2017-07-11 11:27:00+03	25000.00
8F2282	2017-07-16 03:22:00+03	29000.00
8F22A3	2017-08-15 12:43:00+03	72000.00
8F22EE	2017-07-28 10:08:00+03	31400.00
8F2347	2017-06-26 11:23:00+03	50200.00
8F2466	2017-08-08 22:46:00+03	28800.00
8F24CF	2017-07-09 06:08:00+03	55800.00
8F24E2	2017-07-30 08:01:00+03	113700.00
8F24F5	2017-07-17 11:32:00+03	102100.00
8F2521	2017-07-10 02:00:00+03	50900.00
8F253E	2017-07-24 22:37:00+03	75600.00
8F256B	2017-08-11 13:05:00+03	271100.00
8F25FA	2017-07-10 20:45:00+03	284400.00
8F264A	2017-08-06 09:04:00+03	47400.00
8F266D	2017-08-04 16:17:00+03	137700.00
8F2687	2017-07-06 23:15:00+03	23400.00
8F26BD	2017-08-14 03:01:00+03	28800.00
8F26F1	2017-08-13 23:51:00+03	37700.00
8F2711	2017-07-25 02:24:00+03	54000.00
8F275C	2017-07-11 03:57:00+03	314400.00
8F2777	2017-08-09 15:49:00+03	93900.00
8F27DF	2017-07-06 12:33:00+03	24400.00
8F27FC	2017-07-23 16:37:00+03	56000.00
8F27FE	2017-08-09 11:45:00+03	28000.00
8F2814	2017-07-05 19:07:00+03	131800.00
8F281F	2017-07-30 01:04:00+03	60600.00
8F2846	2017-07-13 16:39:00+03	28000.00
8F2874	2017-07-07 18:41:00+03	73500.00
8F28F2	2017-08-13 06:18:00+03	59800.00
8F297F	2017-07-23 16:27:00+03	40000.00
8F29A9	2017-08-09 21:01:00+03	73400.00
8F29EF	2017-08-04 22:26:00+03	127800.00
8F29F8	2017-07-12 16:09:00+03	38300.00
8F2A1E	2017-07-30 13:25:00+03	188500.00
8F2B10	2017-07-29 09:08:00+03	51800.00
8F2B2C	2017-07-26 13:50:00+03	6000.00
8F2B82	2017-07-21 14:24:00+03	24400.00
8F2BDE	2017-07-06 09:04:00+03	111600.00
8F2BEA	2017-08-11 03:55:00+03	59300.00
8F2C36	2017-07-01 21:20:00+03	29600.00
8F2C3C	2017-08-02 15:38:00+03	73600.00
8F2C4F	2017-07-24 13:16:00+03	24400.00
8F2D87	2017-08-08 09:55:00+03	44000.00
8F2DBB	2017-07-03 03:00:00+03	23200.00
8F2DCF	2017-08-05 11:46:00+03	28300.00
8F2DD6	2017-07-17 02:56:00+03	223200.00
8F2DDA	2017-07-28 14:25:00+03	40600.00
8F2E0C	2017-08-12 09:12:00+03	498200.00
8F2E99	2017-07-29 02:41:00+03	84800.00
8F2E9A	2017-08-15 15:21:00+03	26000.00
8F2E9B	2017-08-03 02:10:00+03	246000.00
8F2EEC	2017-07-29 09:21:00+03	28000.00
8F2F49	2017-07-11 20:11:00+03	8000.00
8F2F68	2017-07-29 03:32:00+03	25600.00
8F2F70	2017-07-09 13:28:00+03	28000.00
8F2F9E	2017-07-06 12:55:00+03	50900.00
8F3013	2017-07-12 11:53:00+03	231800.00
8F3034	2017-08-09 23:22:00+03	48800.00
8F305D	2017-06-29 16:41:00+03	44000.00
8F3108	2017-07-05 10:36:00+03	266400.00
8F311E	2017-08-14 07:10:00+03	148200.00
8F31DF	2017-07-23 06:57:00+03	87100.00
8F321E	2017-07-09 21:13:00+03	206400.00
8F32A6	2017-07-20 02:59:00+03	107200.00
8F32DB	2017-07-28 23:47:00+03	223200.00
8F333F	2017-07-20 22:03:00+03	47100.00
8F3398	2017-07-31 02:21:00+03	57600.00
8F33C6	2017-08-10 04:37:00+03	14000.00
8F33C8	2017-08-02 06:59:00+03	44000.00
8F33F3	2017-07-15 00:35:00+03	283100.00
8F3450	2017-08-11 19:30:00+03	6600.00
8F345D	2017-08-07 22:27:00+03	15100.00
8F348D	2017-08-02 03:51:00+03	93000.00
8F3498	2017-07-13 17:02:00+03	38400.00
8F34C2	2017-08-12 04:56:00+03	46000.00
8F34D3	2017-07-25 07:58:00+03	46500.00
8F352D	2017-07-07 12:45:00+03	89600.00
8F3560	2017-07-13 06:06:00+03	101200.00
8F3571	2017-08-01 22:33:00+03	92800.00
8F3578	2017-08-09 02:27:00+03	52700.00
8F35AC	2017-08-09 04:43:00+03	122800.00
8F35E6	2017-07-19 09:22:00+03	124600.00
8F35F4	2017-08-14 14:42:00+03	270800.00
8F363C	2017-08-14 15:39:00+03	59400.00
8F368A	2017-07-25 08:33:00+03	47000.00
8F36A6	2017-08-04 05:47:00+03	63600.00
8F36E8	2017-07-20 17:58:00+03	25900.00
8F370B	2017-07-04 11:26:00+03	38400.00
8F371F	2017-07-29 14:27:00+03	115800.00
8F3750	2017-07-13 10:44:00+03	101200.00
8F377F	2017-07-09 07:52:00+03	12100.00
8F3787	2017-07-02 09:20:00+03	69500.00
8F37B8	2017-08-14 14:23:00+03	57500.00
8F384A	2017-07-02 22:04:00+03	44700.00
8F389E	2017-07-24 03:33:00+03	64100.00
8F38F1	2017-07-13 04:55:00+03	25800.00
8F3915	2017-07-20 17:07:00+03	123000.00
8F3954	2017-08-06 18:19:00+03	125100.00
8F39D8	2017-07-21 12:39:00+03	43600.00
8F3A0E	2017-07-22 17:07:00+03	46000.00
8F3A93	2017-08-08 21:37:00+03	75500.00
8F3A96	2017-07-19 16:50:00+03	26800.00
8F3A9B	2017-08-14 23:21:00+03	32800.00
8F3AC6	2017-07-30 11:24:00+03	32700.00
8F3B1C	2017-07-29 10:38:00+03	57600.00
8F3B2D	2017-07-26 01:30:00+03	117200.00
8F3B64	2017-08-14 16:34:00+03	67100.00
8F3B7E	2017-07-10 22:46:00+03	116000.00
8F3B97	2017-07-11 04:50:00+03	83300.00
8F3BA1	2017-07-19 11:52:00+03	67600.00
8F3BFE	2017-07-12 18:01:00+03	62700.00
8F3C00	2017-07-13 00:36:00+03	40800.00
8F3C03	2017-07-06 00:16:00+03	54800.00
8F3C35	2017-08-14 01:05:00+03	62600.00
8F3C4C	2017-08-11 08:46:00+03	164100.00
8F3CB1	2017-07-14 17:06:00+03	28800.00
8F3CD0	2017-06-30 02:01:00+03	12400.00
8F3CDC	2017-07-09 03:55:00+03	48800.00
8F3DD9	2017-08-14 13:54:00+03	162200.00
8F3DE0	2017-08-09 18:19:00+03	81300.00
8F3DE2	2017-07-17 14:43:00+03	67400.00
8F3DF0	2017-07-23 18:24:00+03	136800.00
8F3E00	2017-08-10 00:14:00+03	277800.00
8F3E05	2017-07-04 22:09:00+03	129800.00
8F3E30	2017-07-07 12:09:00+03	127500.00
8F3E3B	2017-07-02 16:33:00+03	52900.00
8F3E4B	2017-07-25 06:38:00+03	16000.00
8F3E67	2017-07-11 07:46:00+03	26000.00
8F3F91	2017-07-18 12:51:00+03	46800.00
8F3FB7	2017-07-02 02:06:00+03	136800.00
8F3FFA	2017-06-30 19:09:00+03	38400.00
8F4010	2017-07-13 02:41:00+03	24400.00
8F402E	2017-07-08 14:35:00+03	8200.00
8F4049	2017-07-07 10:42:00+03	81300.00
8F405B	2017-08-15 17:46:00+03	57800.00
8F4098	2017-07-28 20:59:00+03	48800.00
8F40AF	2017-07-28 11:20:00+03	26000.00
8F4104	2017-07-07 21:03:00+03	50300.00
8F4194	2017-08-08 22:21:00+03	83500.00
8F4195	2017-07-08 23:56:00+03	15900.00
8F41CC	2017-07-26 15:26:00+03	28800.00
8F41E4	2017-08-08 17:51:00+03	57800.00
8F4267	2017-06-29 00:19:00+03	35100.00
8F427B	2017-08-12 17:51:00+03	406700.00
8F42B2	2017-07-03 01:00:00+03	56000.00
8F42E7	2017-08-13 22:45:00+03	110300.00
8F433F	2017-08-05 10:34:00+03	284700.00
8F4358	2017-07-05 10:16:00+03	69100.00
8F439C	2017-07-14 11:21:00+03	25100.00
8F43AA	2017-08-06 01:24:00+03	81300.00
8F43F6	2017-07-13 13:59:00+03	92600.00
8F4428	2017-08-04 20:48:00+03	99700.00
8F4440	2017-07-19 07:37:00+03	38000.00
8F4450	2017-07-21 21:16:00+03	25600.00
8F4484	2017-08-07 00:34:00+03	133100.00
8F44B1	2017-07-13 15:13:00+03	38800.00
8F450B	2017-07-30 11:24:00+03	26800.00
8F450D	2017-07-01 11:40:00+03	116400.00
8F4540	2017-08-09 05:54:00+03	36200.00
8F4542	2017-07-12 22:03:00+03	86300.00
8F4547	2017-07-31 21:03:00+03	48800.00
8F4548	2017-07-29 22:13:00+03	132800.00
8F45AB	2017-07-17 11:16:00+03	162600.00
8F45D1	2017-07-22 04:32:00+03	37900.00
8F460E	2017-08-13 05:44:00+03	98400.00
8F46A6	2017-08-12 23:37:00+03	100000.00
8F471B	2017-07-31 05:12:00+03	14800.00
8F4798	2017-07-31 20:05:00+03	66600.00
8F47AF	2017-07-17 06:50:00+03	29600.00
8F48AB	2017-07-04 13:48:00+03	67600.00
8F491E	2017-07-12 11:08:00+03	151200.00
8F4958	2017-08-04 18:49:00+03	112600.00
8F498B	2017-08-01 19:07:00+03	136500.00
8F4990	2017-07-01 12:07:00+03	56000.00
8F49E2	2017-07-30 21:42:00+03	63200.00
8F4A51	2017-08-09 15:36:00+03	190700.00
8F4A56	2017-07-26 16:59:00+03	21400.00
8F4AA8	2017-07-01 16:10:00+03	68800.00
8F4AAA	2017-07-08 11:11:00+03	7400.00
8F4B26	2017-08-01 12:09:00+03	122600.00
8F4B2F	2017-08-10 16:12:00+03	51800.00
8F4B51	2017-07-22 12:18:00+03	113300.00
8F4B88	2017-08-03 11:22:00+03	92800.00
8F4BE1	2017-08-03 12:36:00+03	285300.00
8F4C73	2017-07-09 22:29:00+03	30000.00
8F4CB6	2017-07-11 04:43:00+03	23600.00
8F4CC5	2017-07-29 08:59:00+03	20200.00
8F4D05	2017-08-11 05:31:00+03	76600.00
8F4D18	2017-07-12 15:11:00+03	23200.00
8F4DAD	2017-07-07 20:45:00+03	85700.00
8F4DC7	2017-08-03 04:07:00+03	67600.00
8F4DC9	2017-07-25 07:23:00+03	68800.00
8F4DD3	2017-08-02 21:46:00+03	135000.00
8F4DD4	2017-07-18 18:44:00+03	111600.00
8F4DE2	2017-07-07 08:04:00+03	69500.00
8F4E71	2017-07-15 08:20:00+03	68800.00
8F4F20	2017-07-30 23:25:00+03	44000.00
8F4F64	2017-07-26 22:52:00+03	44000.00
8F5020	2017-08-02 16:16:00+03	106400.00
8F5088	2017-07-17 05:51:00+03	147200.00
8F50A5	2017-07-12 11:24:00+03	18600.00
8F50EC	2017-08-15 08:14:00+03	40600.00
8F50EF	2017-07-27 23:37:00+03	6700.00
8F511D	2017-08-10 18:21:00+03	12000.00
8F513E	2017-07-28 01:04:00+03	43600.00
8F5195	2017-07-19 23:22:00+03	68800.00
8F51EA	2017-07-13 19:18:00+03	139100.00
8F522D	2017-07-02 19:52:00+03	68800.00
8F5278	2017-07-27 12:33:00+03	16400.00
8F53A6	2017-08-09 01:39:00+03	10800.00
8F5427	2017-07-10 05:51:00+03	45200.00
8F5589	2017-08-13 23:23:00+03	33400.00
8F55BB	2017-07-14 09:23:00+03	32700.00
8F55BF	2017-07-29 22:57:00+03	39100.00
8F55D6	2017-08-09 07:22:00+03	85200.00
8F55E7	2017-08-07 11:18:00+03	147300.00
8F55F5	2017-07-13 13:31:00+03	260300.00
8F5670	2017-08-11 17:53:00+03	129900.00
8F56B2	2017-07-16 05:54:00+03	8400.00
8F56CC	2017-07-12 08:19:00+03	28000.00
8F56F6	2017-07-19 05:53:00+03	193200.00
8F5709	2017-07-06 17:39:00+03	54000.00
8F571C	2017-07-07 11:53:00+03	8000.00
8F576B	2017-07-12 06:38:00+03	16400.00
8F578F	2017-07-24 22:21:00+03	145800.00
8F5792	2017-08-07 18:58:00+03	35800.00
8F57DE	2017-07-27 07:04:00+03	75300.00
8F57E4	2017-07-12 02:45:00+03	76600.00
8F5814	2017-07-04 02:43:00+03	25000.00
8F5842	2017-08-05 19:34:00+03	26000.00
8F591A	2017-07-28 13:47:00+03	61800.00
8F5954	2017-06-28 06:38:00+03	29600.00
8F597E	2017-07-13 04:02:00+03	38800.00
8F598B	2017-07-01 23:45:00+03	58900.00
8F59A2	2017-07-21 04:54:00+03	111600.00
8F59B3	2017-07-20 00:08:00+03	119300.00
8F5A74	2017-07-25 16:58:00+03	142400.00
8F5AAF	2017-08-06 17:46:00+03	88200.00
8F5B12	2017-07-01 17:49:00+03	184300.00
8F5B2D	2017-08-05 17:22:00+03	184300.00
8F5B40	2017-07-15 12:54:00+03	106400.00
8F5B43	2017-08-03 04:24:00+03	20000.00
8F5B7B	2017-07-03 00:27:00+03	26800.00
8F5B8C	2017-07-09 02:55:00+03	217900.00
8F5BA2	2017-06-29 13:19:00+03	56900.00
8F5BAA	2017-07-07 10:06:00+03	27800.00
8F5C23	2017-07-08 08:35:00+03	52900.00
8F5C4A	2017-08-11 03:04:00+03	98400.00
8F5C90	2017-07-11 13:33:00+03	86300.00
8F5CBF	2017-07-25 06:08:00+03	6700.00
8F5CF7	2017-08-01 19:45:00+03	105000.00
8F5D7A	2017-08-09 03:56:00+03	24400.00
8F5D7F	2017-08-02 08:23:00+03	148200.00
8F5D94	2017-08-05 22:05:00+03	171100.00
8F5E4A	2017-07-05 19:56:00+03	46500.00
8F5E70	2017-07-06 00:25:00+03	24200.00
8F5E7A	2017-07-03 07:45:00+03	79000.00
8F5E99	2017-07-10 14:31:00+03	40000.00
8F5EA8	2017-08-02 05:18:00+03	6700.00
8F5ECE	2017-07-24 23:21:00+03	203300.00
8F5EF4	2017-08-05 09:48:00+03	90900.00
8F5F19	2017-07-11 10:02:00+03	174400.00
8F5F40	2017-08-11 00:03:00+03	54100.00
8F5F7C	2017-08-10 05:54:00+03	62000.00
8F60E7	2017-08-13 08:24:00+03	54800.00
8F60FB	2017-08-01 08:09:00+03	24700.00
8F618C	2017-08-14 20:42:00+03	87700.00
8F61B0	2017-07-25 09:41:00+03	29600.00
8F61B5	2017-08-01 17:22:00+03	14000.00
8F61CA	2017-07-02 02:42:00+03	115300.00
8F621E	2017-08-15 03:23:00+03	67700.00
8F6233	2017-07-31 21:06:00+03	81700.00
8F6266	2017-07-03 06:23:00+03	56600.00
8F626D	2017-08-08 14:42:00+03	86800.00
8F629D	2017-07-03 15:56:00+03	26200.00
8F62A5	2017-07-21 10:47:00+03	110000.00
8F6336	2017-06-27 06:51:00+03	18000.00
8F63D3	2017-07-26 14:36:00+03	36800.00
8F6400	2017-07-02 14:46:00+03	43500.00
8F640F	2017-07-19 19:17:00+03	12400.00
8F64CD	2017-08-09 08:07:00+03	39800.00
8F64D6	2017-07-03 05:48:00+03	97600.00
8F6511	2017-07-14 08:15:00+03	52300.00
8F652D	2017-06-29 03:16:00+03	54000.00
8F659C	2017-07-05 09:13:00+03	80400.00
8F65C5	2017-07-25 08:00:00+03	135400.00
8F664E	2017-07-15 05:18:00+03	8200.00
8F66C9	2017-06-28 05:38:00+03	45200.00
8F66D3	2017-07-17 02:11:00+03	153300.00
8F66F0	2017-07-24 05:10:00+03	59200.00
8F66FB	2017-08-05 22:37:00+03	55800.00
8F67C0	2017-06-30 01:04:00+03	25000.00
8F67C9	2017-08-08 18:41:00+03	136200.00
8F6801	2017-07-18 01:34:00+03	37900.00
8F6819	2017-07-09 09:50:00+03	111600.00
8F6845	2017-08-10 21:37:00+03	54800.00
8F684E	2017-08-12 02:55:00+03	35600.00
8F6863	2017-06-27 05:10:00+03	213200.00
8F68E7	2017-07-09 00:05:00+03	65900.00
8F6911	2017-07-16 01:41:00+03	78000.00
8F6915	2017-08-04 15:25:00+03	34600.00
8F6920	2017-07-31 03:44:00+03	44500.00
8F6983	2017-07-15 16:26:00+03	100300.00
8F69E6	2017-07-04 16:28:00+03	81300.00
8F69F1	2017-07-11 14:27:00+03	34400.00
8F6A13	2017-07-15 19:50:00+03	203000.00
8F6A1E	2017-07-06 19:42:00+03	111600.00
8F6AE6	2017-07-09 17:03:00+03	260300.00
8F6B84	2017-07-03 20:00:00+03	21800.00
8F6BA1	2017-07-27 23:58:00+03	13200.00
8F6BCE	2017-07-21 19:30:00+03	31600.00
8F6BD1	2017-08-13 18:24:00+03	22000.00
8F6BDE	2017-07-30 17:30:00+03	133200.00
8F6BF4	2017-07-11 20:32:00+03	106100.00
8F6CCF	2017-07-24 02:47:00+03	77200.00
8F6D47	2017-07-20 19:00:00+03	185600.00
8F6D69	2017-08-03 21:53:00+03	46400.00
8F6DC0	2017-07-30 20:19:00+03	106600.00
8F6DDF	2017-08-08 15:05:00+03	33300.00
8F6DEC	2017-08-14 13:20:00+03	11600.00
8F6E17	2017-07-06 05:31:00+03	25600.00
8F6E35	2017-07-25 10:30:00+03	187600.00
8F6E84	2017-07-09 08:14:00+03	90800.00
8F6EE3	2017-07-14 11:34:00+03	103600.00
8F6F17	2017-08-04 19:21:00+03	38600.00
8F6F2C	2017-08-07 19:54:00+03	137400.00
8F6F7B	2017-08-05 09:06:00+03	81900.00
8F6FB3	2017-07-01 17:19:00+03	270800.00
8F6FBC	2017-07-30 05:53:00+03	7400.00
8F7032	2017-07-28 12:30:00+03	58600.00
8F705D	2017-07-29 15:21:00+03	75200.00
8F7117	2017-07-31 08:35:00+03	106400.00
8F714E	2017-06-27 02:45:00+03	45200.00
8F716E	2017-08-08 08:23:00+03	262200.00
8F716F	2017-07-13 23:15:00+03	136000.00
8F7198	2017-07-27 23:50:00+03	23200.00
8F71AE	2017-07-02 22:50:00+03	123000.00
8F722D	2017-07-13 09:02:00+03	36000.00
8F7289	2017-07-19 08:07:00+03	76800.00
8F72AB	2017-07-27 20:39:00+03	114100.00
8F72D6	2017-06-30 11:53:00+03	44300.00
8F72E5	2017-08-15 05:03:00+03	248300.00
8F732C	2017-08-10 12:48:00+03	271100.00
8F7383	2017-08-02 12:32:00+03	44600.00
8F73DC	2017-08-06 07:41:00+03	66600.00
8F73EA	2017-07-09 15:18:00+03	332800.00
8F742E	2017-07-13 01:42:00+03	75600.00
8F74A4	2017-08-13 01:15:00+03	100300.00
8F74B0	2017-07-25 09:50:00+03	38200.00
8F74D3	2017-07-09 19:37:00+03	86600.00
8F7504	2017-07-22 11:02:00+03	28000.00
8F75AE	2017-07-31 07:06:00+03	45200.00
8F75B9	2017-07-08 12:56:00+03	23600.00
8F75D2	2017-07-23 08:13:00+03	154500.00
8F76A2	2017-06-28 14:32:00+03	28000.00
8F77CB	2017-07-22 13:38:00+03	13400.00
8F77FA	2017-07-18 09:39:00+03	120400.00
8F7829	2017-07-15 18:00:00+03	52900.00
8F7859	2017-08-03 16:21:00+03	13300.00
8F7894	2017-07-10 17:12:00+03	13600.00
8F7960	2017-07-22 16:37:00+03	61200.00
8F7964	2017-08-13 08:35:00+03	42600.00
8F799D	2017-08-06 14:44:00+03	52000.00
8F7A09	2017-07-02 18:25:00+03	39800.00
8F7ADF	2017-08-06 15:55:00+03	16400.00
8F7AE6	2017-07-29 01:53:00+03	47400.00
8F7B2B	2017-07-25 13:20:00+03	135400.00
8F7B50	2017-07-05 15:18:00+03	66100.00
8F7B8A	2017-07-18 21:39:00+03	23200.00
8F7BB3	2017-08-13 19:40:00+03	65600.00
8F7BC5	2017-08-03 00:27:00+03	32800.00
8F7BCA	2017-08-11 19:10:00+03	190400.00
8F7BCF	2017-07-10 07:56:00+03	265700.00
8F7C92	2017-07-17 09:26:00+03	28000.00
8F7CE0	2017-07-11 17:29:00+03	75300.00
8F7D21	2017-08-03 09:35:00+03	85600.00
8F7D8D	2017-07-20 06:52:00+03	39100.00
8F7DC8	2017-07-23 06:08:00+03	73900.00
8F7E22	2017-07-30 10:56:00+03	26800.00
8F7E30	2017-07-14 11:42:00+03	13600.00
8F7E69	2017-07-30 20:14:00+03	13400.00
8F7EF4	2017-07-12 04:36:00+03	56000.00
8F7F3F	2017-07-10 18:34:00+03	81300.00
8F7F6B	2017-07-11 17:28:00+03	27200.00
8F7F7A	2017-07-15 00:34:00+03	89600.00
8F7F95	2017-08-01 13:13:00+03	160900.00
8F7FA5	2017-07-10 09:26:00+03	67700.00
8F7FB5	2017-08-07 16:55:00+03	37200.00
8F7FDC	2017-07-29 01:39:00+03	69000.00
8F8070	2017-07-10 20:44:00+03	56000.00
8F80E8	2017-06-29 06:40:00+03	48800.00
8F80F5	2017-07-06 21:41:00+03	34000.00
8F81D7	2017-07-13 03:21:00+03	42600.00
8F8228	2017-07-23 13:26:00+03	74900.00
8F826C	2017-07-27 05:21:00+03	67600.00
8F8286	2017-07-24 09:26:00+03	6600.00
8F8298	2017-07-21 18:11:00+03	223700.00
8F82B9	2017-08-05 06:25:00+03	57400.00
8F8307	2017-07-22 06:39:00+03	23200.00
8F8341	2017-07-07 06:49:00+03	67600.00
8F8383	2017-08-02 22:18:00+03	408500.00
8F8386	2017-08-03 19:20:00+03	46300.00
8F839A	2017-08-01 17:44:00+03	23100.00
8F8427	2017-08-10 08:03:00+03	111600.00
8F844A	2017-07-17 19:27:00+03	55800.00
8F8477	2017-07-06 00:37:00+03	23400.00
8F85A5	2017-08-01 06:43:00+03	22000.00
8F85C6	2017-08-14 16:21:00+03	246000.00
8F85F7	2017-08-03 04:17:00+03	68100.00
8F863B	2017-07-26 18:32:00+03	83300.00
8F864A	2017-07-14 11:24:00+03	99200.00
8F86A3	2017-08-07 06:56:00+03	223700.00
8F871D	2017-08-14 18:09:00+03	54000.00
8F8720	2017-07-31 05:28:00+03	23600.00
8F87BD	2017-07-16 18:59:00+03	123900.00
8F87E1	2017-07-15 23:54:00+03	78200.00
8F87EE	2017-07-25 00:34:00+03	66000.00
8F8999	2017-07-27 16:31:00+03	53600.00
8F89A9	2017-07-13 02:33:00+03	87700.00
8F89BF	2017-07-09 04:25:00+03	34800.00
8F89C8	2017-07-21 07:48:00+03	59600.00
8F8A3B	2017-08-05 15:26:00+03	138200.00
8F8A40	2017-07-22 12:35:00+03	26000.00
8F8A66	2017-07-08 12:52:00+03	123000.00
8F8A9B	2017-07-27 03:27:00+03	135200.00
8F8ABB	2017-08-04 15:29:00+03	150600.00
8F8C1C	2017-08-04 06:29:00+03	23600.00
8F8C26	2017-07-24 02:21:00+03	32700.00
8F8C2A	2017-08-04 15:53:00+03	223200.00
8F8C78	2017-07-01 03:43:00+03	91100.00
8F8C9D	2017-07-04 20:56:00+03	56100.00
8F8D45	2017-07-06 20:06:00+03	140900.00
8F8DD0	2017-07-08 10:27:00+03	399600.00
8F8E1C	2017-08-12 23:18:00+03	24000.00
8F8F6B	2017-07-16 20:31:00+03	76800.00
8F8F84	2017-07-25 18:31:00+03	269400.00
8F8FD6	2017-07-29 10:03:00+03	112000.00
8F9070	2017-07-17 01:03:00+03	88100.00
8F907B	2017-07-19 17:33:00+03	55800.00
8F90B9	2017-08-07 10:21:00+03	9200.00
8F912F	2017-08-04 11:11:00+03	132800.00
8F91D4	2017-08-10 05:32:00+03	48800.00
8F91E0	2017-07-27 11:53:00+03	400000.00
8F91F3	2017-07-26 23:28:00+03	58600.00
8F92AD	2017-08-13 21:20:00+03	34000.00
8F92AE	2017-07-25 08:02:00+03	67100.00
8F92ED	2017-07-09 12:09:00+03	206400.00
8F92F4	2017-07-29 15:48:00+03	86800.00
8F92FE	2017-07-10 23:56:00+03	6700.00
8F9363	2017-08-12 09:11:00+03	23200.00
8F93BC	2017-08-14 11:54:00+03	49300.00
8F93F2	2017-07-26 05:38:00+03	98000.00
8F9416	2017-07-20 02:24:00+03	76400.00
8F9459	2017-07-27 04:56:00+03	202400.00
8F948A	2017-07-27 14:18:00+03	26700.00
8F94DF	2017-06-29 08:58:00+03	8000.00
8F9501	2017-07-03 21:10:00+03	76200.00
8F9537	2017-07-24 12:38:00+03	86400.00
8F954E	2017-07-06 12:52:00+03	260300.00
8F95A0	2017-07-26 20:28:00+03	56000.00
8F95F1	2017-07-30 15:24:00+03	83000.00
8F964D	2017-06-26 10:03:00+03	14000.00
8F966B	2017-07-07 10:16:00+03	6600.00
8F9673	2017-07-07 14:06:00+03	56900.00
8F968C	2017-07-29 11:56:00+03	70800.00
8F9697	2017-08-15 12:43:00+03	58000.00
8F96AB	2017-07-27 04:56:00+03	44500.00
8F96C2	2017-07-12 16:59:00+03	100600.00
8F96D6	2017-07-18 20:23:00+03	78100.00
8F9730	2017-07-27 07:59:00+03	100600.00
8F974A	2017-07-02 02:34:00+03	132800.00
8F974E	2017-07-05 00:11:00+03	67600.00
8F979E	2017-07-29 01:17:00+03	143700.00
8F984E	2017-07-12 21:01:00+03	14400.00
8F98CA	2017-07-09 02:47:00+03	148200.00
8F990F	2017-07-27 07:23:00+03	116400.00
8F9920	2017-07-20 00:15:00+03	26800.00
8F9949	2017-07-25 19:11:00+03	85400.00
8F994D	2017-08-14 07:02:00+03	75600.00
8F99C5	2017-07-18 20:51:00+03	26800.00
8F9A0C	2017-07-13 23:26:00+03	24400.00
8F9A37	2017-07-19 00:20:00+03	37200.00
8F9A61	2017-07-11 21:09:00+03	25000.00
8F9AA6	2017-08-13 00:57:00+03	23200.00
8F9AC4	2017-08-13 07:34:00+03	89600.00
8F9B49	2017-07-05 22:13:00+03	80200.00
8F9B76	2017-08-07 20:45:00+03	78200.00
8F9B7F	2017-08-01 13:06:00+03	375200.00
8F9C75	2017-07-30 09:14:00+03	14900.00
8F9C86	2017-07-16 02:21:00+03	56600.00
8F9C99	2017-08-09 06:56:00+03	99600.00
8F9CB8	2017-08-14 16:32:00+03	55400.00
8F9D5E	2017-08-09 17:52:00+03	105100.00
8F9DBE	2017-07-29 15:20:00+03	136200.00
8F9DE8	2017-07-06 12:22:00+03	46000.00
8F9E06	2017-07-20 18:53:00+03	32700.00
8F9E33	2017-07-15 17:31:00+03	20400.00
8F9E36	2017-08-07 06:59:00+03	17200.00
8F9E45	2017-07-29 13:01:00+03	14000.00
8F9EA0	2017-07-21 19:28:00+03	86800.00
8F9EB8	2017-08-01 07:17:00+03	14900.00
8F9ECA	2017-07-13 11:32:00+03	18000.00
8F9EEE	2017-07-26 06:00:00+03	6700.00
8F9F60	2017-08-08 09:15:00+03	112000.00
8F9FC6	2017-08-09 03:43:00+03	116000.00
8F9FCC	2017-07-11 14:12:00+03	265700.00
8FA005	2017-07-10 01:24:00+03	60400.00
8FA024	2017-06-29 02:40:00+03	57500.00
8FA027	2017-08-13 23:59:00+03	132800.00
8FA05E	2017-07-26 11:37:00+03	123000.00
8FA093	2017-08-14 14:27:00+03	24800.00
8FA0BD	2017-07-21 18:48:00+03	19500.00
8FA0DA	2017-07-07 02:38:00+03	58600.00
8FA0DC	2017-08-06 22:21:00+03	67600.00
8FA102	2017-07-09 13:59:00+03	119200.00
8FA14D	2017-07-31 07:39:00+03	280600.00
8FA18D	2017-07-11 08:27:00+03	146600.00
8FA1E2	2017-07-10 00:01:00+03	58800.00
8FA29E	2017-07-20 17:42:00+03	52100.00
8FA2F5	2017-07-07 10:27:00+03	96300.00
8FA31B	2017-07-18 05:38:00+03	84500.00
8FA431	2017-08-04 17:03:00+03	291300.00
8FA454	2017-08-13 08:48:00+03	62000.00
8FA45C	2017-07-10 13:52:00+03	110500.00
8FA55F	2017-08-14 08:06:00+03	66600.00
8FA579	2017-07-13 05:51:00+03	37000.00
8FA5E0	2017-07-11 11:05:00+03	169900.00
8FA69D	2017-07-21 14:03:00+03	12600.00
8FA6D5	2017-08-01 00:27:00+03	8000.00
8FA726	2017-07-24 11:22:00+03	78600.00
8FA72A	2017-07-28 21:53:00+03	26000.00
8FA74C	2017-07-31 20:54:00+03	54500.00
8FA7B5	2017-07-18 01:35:00+03	90800.00
8FA85D	2017-07-09 22:44:00+03	75300.00
8FA898	2017-07-09 19:30:00+03	92600.00
8FA8BC	2017-07-11 08:23:00+03	85000.00
8FA8C1	2017-07-11 10:27:00+03	279200.00
8FA8E7	2017-07-21 20:27:00+03	174000.00
8FA8F5	2017-07-27 23:43:00+03	64500.00
8FA9B0	2017-08-06 04:06:00+03	25200.00
8FA9B3	2017-07-22 17:49:00+03	6900.00
8FA9D6	2017-08-02 08:18:00+03	6700.00
8FA9D7	2017-08-14 23:10:00+03	136800.00
8FAA20	2017-07-19 01:12:00+03	160800.00
8FAA31	2017-07-26 01:51:00+03	46800.00
8FAA77	2017-08-13 09:06:00+03	80400.00
8FAA85	2017-07-21 00:44:00+03	52700.00
8FAA9A	2017-07-18 04:13:00+03	125800.00
8FAAFF	2017-07-05 18:16:00+03	128800.00
8FAB6F	2017-07-22 06:53:00+03	75800.00
8FAB88	2017-07-05 06:18:00+03	193700.00
8FABD1	2017-08-01 06:16:00+03	42800.00
8FAC4B	2017-07-27 17:05:00+03	30200.00
8FAC9A	2017-07-28 17:18:00+03	70700.00
8FACBC	2017-08-09 00:30:00+03	26000.00
8FAD32	2017-08-06 06:41:00+03	13400.00
8FADA8	2017-08-09 11:26:00+03	31900.00
8FAE39	2017-07-08 16:14:00+03	54800.00
8FAEA0	2017-07-29 10:19:00+03	31900.00
8FAEB3	2017-07-25 05:13:00+03	115300.00
8FAF77	2017-06-30 19:01:00+03	8200.00
8FAF8D	2017-08-01 15:11:00+03	28800.00
8FAFCD	2017-07-27 21:56:00+03	27000.00
8FAFD8	2017-08-12 00:06:00+03	47500.00
8FAFE4	2017-07-23 10:45:00+03	62000.00
8FB041	2017-07-18 04:28:00+03	28700.00
8FB0B8	2017-08-10 11:24:00+03	88000.00
8FB11F	2017-08-08 18:30:00+03	46400.00
8FB122	2017-07-08 11:48:00+03	20600.00
8FB1BD	2017-07-17 22:11:00+03	133200.00
8FB232	2017-07-03 17:16:00+03	111600.00
8FB2EC	2017-07-21 18:15:00+03	101100.00
8FB30F	2017-07-16 03:16:00+03	73900.00
8FB3A7	2017-08-03 03:23:00+03	15400.00
8FB4A4	2017-08-01 10:23:00+03	48800.00
8FB50E	2017-07-13 05:57:00+03	13400.00
8FB523	2017-07-04 22:46:00+03	64700.00
8FB53D	2017-07-12 21:48:00+03	28800.00
8FB573	2017-07-08 13:05:00+03	288600.00
8FB59F	2017-08-07 04:27:00+03	57700.00
8FB627	2017-07-01 01:50:00+03	65500.00
8FB64F	2017-08-04 19:06:00+03	135600.00
8FB66F	2017-08-07 19:47:00+03	97900.00
8FB6A6	2017-07-20 10:38:00+03	92400.00
8FB6C1	2017-07-30 07:10:00+03	8800.00
8FB6E4	2017-07-08 22:18:00+03	24400.00
8FB79A	2017-08-15 05:28:00+03	62700.00
8FB7B7	2017-08-15 16:29:00+03	121400.00
8FB7BD	2017-08-04 11:00:00+03	38400.00
8FB7D0	2017-08-10 15:34:00+03	23600.00
8FB7F0	2017-07-26 14:42:00+03	178200.00
8FB879	2017-07-19 21:13:00+03	58200.00
8FB8A4	2017-08-03 14:14:00+03	23200.00
8FB8C3	2017-07-29 13:02:00+03	56000.00
8FB8E8	2017-07-04 04:04:00+03	38800.00
8FB9E0	2017-08-15 15:43:00+03	14000.00
8FBA05	2017-07-02 07:27:00+03	56000.00
8FBA44	2017-07-18 16:38:00+03	15100.00
8FBA52	2017-08-10 23:03:00+03	46400.00
8FBA65	2017-07-18 02:41:00+03	47200.00
8FBAA4	2017-07-03 17:25:00+03	150600.00
8FBAA6	2017-08-09 03:03:00+03	52100.00
8FBB67	2017-08-15 13:49:00+03	43800.00
8FBB83	2017-07-20 05:10:00+03	56000.00
8FBBAC	2017-07-26 11:07:00+03	123000.00
8FBC2D	2017-08-09 16:44:00+03	19600.00
8FBC2E	2017-07-11 21:51:00+03	26000.00
8FBC86	2017-08-09 13:40:00+03	89200.00
8FBE2B	2017-07-29 06:39:00+03	14400.00
8FBE5C	2017-07-27 10:45:00+03	34000.00
8FBE76	2017-08-06 18:22:00+03	26700.00
8FBE92	2017-07-08 14:52:00+03	56600.00
8FBF1B	2017-08-15 08:19:00+03	42800.00
8FBF1E	2017-07-07 08:15:00+03	37700.00
8FBF78	2017-07-17 16:08:00+03	75600.00
8FBFCD	2017-08-12 08:17:00+03	57800.00
8FC100	2017-08-12 21:05:00+03	86500.00
8FC11D	2017-07-18 12:54:00+03	17600.00
8FC133	2017-07-21 23:24:00+03	32800.00
8FC138	2017-08-05 06:20:00+03	84000.00
8FC141	2017-07-30 23:26:00+03	23600.00
8FC164	2017-08-06 08:35:00+03	43800.00
8FC198	2017-07-11 01:35:00+03	174400.00
8FC1E6	2017-07-19 06:43:00+03	55500.00
8FC263	2017-07-15 23:40:00+03	31000.00
8FC34A	2017-07-28 16:37:00+03	38800.00
8FC389	2017-07-13 00:47:00+03	115600.00
8FC3CE	2017-07-31 18:46:00+03	168000.00
8FC402	2017-08-14 19:24:00+03	34300.00
8FC434	2017-07-29 16:07:00+03	52700.00
8FC449	2017-07-23 01:50:00+03	14000.00
8FC495	2017-07-15 00:47:00+03	123000.00
8FC501	2017-08-09 21:59:00+03	112600.00
8FC56B	2017-08-15 05:20:00+03	57500.00
8FC5C9	2017-07-15 22:33:00+03	14400.00
8FC639	2017-08-09 18:41:00+03	147700.00
8FC668	2017-07-04 13:55:00+03	23600.00
8FC680	2017-07-03 07:57:00+03	28800.00
8FC690	2017-08-03 06:29:00+03	25800.00
8FC69B	2017-07-27 01:52:00+03	47500.00
8FC6D0	2017-08-01 02:32:00+03	81700.00
8FC71E	2017-06-27 06:47:00+03	143800.00
8FC7D3	2017-08-10 13:44:00+03	155600.00
8FC7FE	2017-07-14 07:30:00+03	11000.00
8FC863	2017-08-08 19:59:00+03	79900.00
8FC864	2017-07-17 22:26:00+03	22000.00
8FC8A1	2017-06-28 03:23:00+03	29200.00
8FC8B3	2017-07-21 03:06:00+03	85000.00
8FC8C6	2017-07-02 23:25:00+03	25800.00
8FC8CB	2017-07-31 12:54:00+03	11600.00
8FC8CD	2017-08-07 01:10:00+03	28000.00
8FC8D2	2017-07-19 18:50:00+03	28000.00
8FC8E1	2017-07-21 14:20:00+03	62600.00
8FC991	2017-08-13 06:54:00+03	78600.00
8FC9C3	2017-07-08 04:31:00+03	26000.00
8FCA0B	2017-06-30 08:51:00+03	32400.00
8FCA80	2017-07-29 13:59:00+03	59800.00
8FCA99	2017-07-12 02:04:00+03	136600.00
8FCACA	2017-07-05 17:32:00+03	269200.00
8FCB20	2017-07-21 04:36:00+03	50600.00
8FCB61	2017-08-11 02:10:00+03	75100.00
8FCBAE	2017-07-09 16:21:00+03	92700.00
8FCC21	2017-06-29 11:15:00+03	73600.00
8FCC3E	2017-07-11 06:57:00+03	13400.00
8FCC41	2017-07-17 18:02:00+03	112000.00
8FCC4D	2017-07-08 14:29:00+03	184000.00
8FCC8D	2017-07-19 17:00:00+03	50200.00
8FCCBB	2017-08-14 15:11:00+03	46800.00
8FCCDB	2017-07-04 22:32:00+03	24400.00
8FCD39	2017-07-01 08:00:00+03	75300.00
8FCD4A	2017-07-13 09:15:00+03	279000.00
8FCD65	2017-07-19 11:41:00+03	30000.00
8FCDC4	2017-08-05 18:13:00+03	27700.00
8FCDE1	2017-07-08 01:41:00+03	54400.00
8FCE16	2017-07-21 03:57:00+03	270800.00
8FCE6A	2017-08-09 17:41:00+03	99300.00
8FCECC	2017-07-03 10:38:00+03	37900.00
8FCF47	2017-07-19 16:36:00+03	13400.00
8FCF7B	2017-08-09 09:39:00+03	24700.00
8FCF7E	2017-08-01 02:53:00+03	6800.00
8FCF96	2017-08-01 03:30:00+03	9300.00
8FCFCB	2017-07-12 08:25:00+03	44000.00
8FD001	2017-08-02 01:40:00+03	82400.00
8FD038	2017-08-12 11:21:00+03	28800.00
8FD157	2017-08-09 01:58:00+03	34000.00
8FD199	2017-07-05 22:03:00+03	31600.00
8FD1F3	2017-07-06 23:19:00+03	76600.00
8FD26D	2017-07-11 23:44:00+03	26800.00
8FD27B	2017-08-10 04:58:00+03	27800.00
8FD2A0	2017-07-06 22:40:00+03	26000.00
8FD2C4	2017-06-28 21:22:00+03	10800.00
8FD32F	2017-08-06 22:25:00+03	47500.00
8FD38E	2017-07-22 09:10:00+03	100600.00
8FD3C8	2017-08-04 08:57:00+03	71200.00
8FD4A2	2017-08-10 03:51:00+03	125000.00
8FD4E7	2017-08-03 14:16:00+03	23600.00
8FD504	2017-07-18 22:25:00+03	13400.00
8FD5D9	2017-08-04 15:22:00+03	59000.00
8FD606	2017-07-03 12:54:00+03	65500.00
8FD631	2017-08-09 07:21:00+03	56000.00
8FD651	2017-07-21 02:09:00+03	40000.00
8FD6D5	2017-07-24 04:49:00+03	21500.00
8FD709	2017-07-26 10:06:00+03	55800.00
8FD723	2017-07-26 12:01:00+03	54400.00
8FD7A5	2017-07-29 20:02:00+03	117600.00
8FD7A7	2017-08-03 14:08:00+03	98400.00
8FD818	2017-08-09 21:57:00+03	95500.00
8FD843	2017-07-22 15:16:00+03	57300.00
8FD860	2017-07-07 20:02:00+03	23200.00
8FD90D	2017-07-13 00:02:00+03	54800.00
8FD99D	2017-08-10 07:51:00+03	26000.00
8FD9A1	2017-08-01 01:26:00+03	28000.00
8FD9A2	2017-07-11 11:18:00+03	59400.00
8FD9BB	2017-08-14 17:26:00+03	24400.00
8FD9C0	2017-07-24 04:42:00+03	358800.00
8FD9C3	2017-07-11 17:27:00+03	27900.00
8FD9D0	2017-08-13 03:45:00+03	80300.00
8FDA51	2017-07-19 16:34:00+03	8400.00
8FDA6B	2017-07-27 16:59:00+03	17800.00
8FDAD0	2017-07-08 16:50:00+03	189200.00
8FDB24	2017-08-13 07:55:00+03	99600.00
8FDB3E	2017-08-01 18:36:00+03	41800.00
8FDBCF	2017-08-11 00:43:00+03	35600.00
8FDBDC	2017-08-06 04:13:00+03	36200.00
8FDC8C	2017-07-03 03:08:00+03	58000.00
8FDC8F	2017-08-02 18:34:00+03	166100.00
8FDC9D	2017-08-10 14:43:00+03	42400.00
8FDCAF	2017-08-01 20:51:00+03	16400.00
8FDCC0	2017-06-29 17:25:00+03	106400.00
8FDD3F	2017-07-08 17:19:00+03	24700.00
8FDD64	2017-07-13 14:35:00+03	116500.00
8FDD9B	2017-07-22 04:00:00+03	115100.00
8FDDCA	2017-08-12 04:10:00+03	40800.00
8FDE0A	2017-07-26 20:12:00+03	57500.00
8FDE0F	2017-07-29 20:18:00+03	40400.00
8FDE91	2017-07-08 22:21:00+03	43000.00
8FDEA5	2017-07-20 14:19:00+03	37900.00
8FDF7F	2017-07-28 11:23:00+03	31000.00
8FDFF1	2017-08-03 22:59:00+03	297800.00
8FE008	2017-08-07 09:36:00+03	6000.00
8FE03E	2017-08-14 03:07:00+03	56000.00
8FE0D3	2017-07-13 09:01:00+03	67100.00
8FE10D	2017-07-13 04:45:00+03	131600.00
8FE177	2017-07-12 10:35:00+03	32700.00
8FE18E	2017-08-04 18:31:00+03	14400.00
8FE1C6	2017-07-07 17:37:00+03	52600.00
8FE1F7	2017-08-14 00:16:00+03	99300.00
8FE1F8	2017-08-09 11:41:00+03	167900.00
8FE200	2017-08-01 09:26:00+03	48800.00
8FE214	2017-07-15 21:39:00+03	63400.00
8FE24D	2017-08-10 10:17:00+03	7400.00
8FE25C	2017-07-07 04:28:00+03	56000.00
8FE2C6	2017-07-11 09:43:00+03	11000.00
8FE333	2017-07-25 06:38:00+03	72400.00
8FE3A0	2017-07-15 20:37:00+03	114300.00
8FE44A	2017-07-22 01:58:00+03	201800.00
8FE456	2017-07-11 22:24:00+03	14000.00
8FE4AA	2017-07-23 20:05:00+03	25000.00
8FE54E	2017-08-01 00:42:00+03	805800.00
8FE593	2017-07-02 22:34:00+03	103800.00
8FE5C6	2017-07-30 17:17:00+03	58400.00
8FE5C8	2017-08-08 13:01:00+03	73600.00
8FE5CA	2017-08-03 22:30:00+03	14000.00
8FE636	2017-08-15 12:46:00+03	17100.00
8FE64B	2017-08-02 02:46:00+03	43600.00
8FE664	2017-07-14 00:52:00+03	10700.00
8FE690	2017-07-21 12:00:00+03	25600.00
8FE767	2017-07-21 08:53:00+03	28200.00
8FE77D	2017-08-06 06:09:00+03	57400.00
8FE7BD	2017-07-30 09:11:00+03	110600.00
8FE7DB	2017-08-15 10:38:00+03	286600.00
8FE7F4	2017-07-12 01:30:00+03	12600.00
8FE829	2017-07-18 06:44:00+03	3400.00
8FE8B8	2017-07-03 00:02:00+03	59300.00
8FE8C4	2017-07-30 02:16:00+03	46300.00
8FE8C9	2017-08-06 22:00:00+03	29500.00
8FE8E1	2017-07-25 05:48:00+03	46200.00
8FE8F0	2017-08-10 09:11:00+03	68900.00
8FE91F	2017-08-02 14:14:00+03	100600.00
8FE93A	2017-08-12 04:56:00+03	63400.00
8FE9BA	2017-08-07 21:32:00+03	6300.00
8FE9EF	2017-07-19 07:24:00+03	16400.00
8FEA4D	2017-07-05 19:22:00+03	20600.00
8FEAA0	2017-08-03 01:42:00+03	39800.00
8FEAAA	2017-07-11 02:08:00+03	86500.00
8FEACB	2017-07-04 07:09:00+03	144400.00
8FEB3B	2017-07-14 06:58:00+03	23200.00
8FEB77	2017-07-12 23:18:00+03	90400.00
8FEC3B	2017-07-12 21:45:00+03	23200.00
8FEC44	2017-07-04 00:59:00+03	6600.00
8FEC5E	2017-07-30 15:15:00+03	90600.00
8FED40	2017-07-19 22:51:00+03	57400.00
8FEDA1	2017-07-25 04:19:00+03	47200.00
8FEDC1	2017-07-07 15:33:00+03	25400.00
8FEDCB	2017-08-07 19:19:00+03	23200.00
8FEE47	2017-08-15 08:41:00+03	111600.00
8FEE97	2017-07-21 04:47:00+03	26000.00
8FEEA5	2017-07-08 22:07:00+03	98400.00
8FEF03	2017-07-21 08:24:00+03	85000.00
8FEF71	2017-07-17 08:23:00+03	47600.00
8FEFDC	2017-08-02 08:25:00+03	44000.00
8FF011	2017-07-17 07:58:00+03	111600.00
8FF0C1	2017-08-03 23:31:00+03	45000.00
8FF0D2	2017-07-25 11:16:00+03	81900.00
8FF12B	2017-07-01 08:59:00+03	73600.00
8FF1B7	2017-07-03 15:59:00+03	90400.00
8FF1BA	2017-07-26 03:59:00+03	23400.00
8FF1BC	2017-07-13 07:53:00+03	87400.00
8FF1C0	2017-07-20 18:41:00+03	69900.00
8FF1D9	2017-07-22 14:01:00+03	40800.00
8FF204	2017-07-10 04:36:00+03	48800.00
8FF21D	2017-08-13 18:27:00+03	19600.00
8FF243	2017-07-20 01:39:00+03	492000.00
8FF245	2017-07-09 09:22:00+03	167400.00
8FF30D	2017-07-13 12:16:00+03	250800.00
8FF371	2017-07-30 17:45:00+03	73200.00
8FF37C	2017-08-11 11:49:00+03	47400.00
8FF3A5	2017-07-03 13:47:00+03	35600.00
8FF3B4	2017-08-06 22:08:00+03	67600.00
8FF3B7	2017-07-14 13:44:00+03	72800.00
8FF525	2017-07-24 14:24:00+03	31400.00
8FF53F	2017-07-15 22:16:00+03	46400.00
8FF55D	2017-07-29 04:53:00+03	89400.00
8FF560	2017-07-10 05:32:00+03	24400.00
8FF572	2017-08-13 05:58:00+03	160700.00
8FF586	2017-07-11 21:33:00+03	120400.00
8FF59C	2017-08-04 00:17:00+03	117200.00
8FF5AE	2017-07-30 23:04:00+03	47600.00
8FF5DC	2017-08-03 07:55:00+03	6700.00
8FF5FC	2017-07-08 07:26:00+03	152500.00
8FF657	2017-07-31 12:16:00+03	28000.00
8FF660	2017-08-07 03:44:00+03	26800.00
8FF668	2017-08-12 11:29:00+03	57800.00
8FF688	2017-08-10 06:49:00+03	35700.00
8FF697	2017-07-09 14:58:00+03	26000.00
8FF6C3	2017-07-17 12:14:00+03	218200.00
8FF744	2017-07-12 16:20:00+03	68100.00
8FF764	2017-07-21 21:01:00+03	67000.00
8FF7CD	2017-07-02 23:55:00+03	136800.00
8FF7F3	2017-07-23 11:03:00+03	26800.00
8FF80B	2017-08-08 05:42:00+03	24800.00
8FF829	2017-07-17 17:29:00+03	16800.00
8FF84D	2017-06-29 06:07:00+03	133100.00
8FF870	2017-07-13 18:25:00+03	26000.00
8FF880	2017-08-08 11:52:00+03	73300.00
8FF889	2017-08-14 17:41:00+03	64800.00
8FF899	2017-07-30 15:07:00+03	23600.00
8FF8DB	2017-08-07 20:24:00+03	39100.00
8FF901	2017-08-01 09:53:00+03	20400.00
8FF914	2017-07-20 04:48:00+03	123000.00
8FF990	2017-07-20 03:51:00+03	36200.00
8FF9AB	2017-08-10 19:06:00+03	55800.00
8FFA05	2017-07-27 06:07:00+03	47100.00
8FFA5B	2017-08-08 21:58:00+03	75700.00
8FFADE	2017-07-11 03:20:00+03	32600.00
8FFAEF	2017-08-14 16:59:00+03	52000.00
8FFBA5	2017-07-09 07:58:00+03	138900.00
8FFBEC	2017-07-16 04:55:00+03	6300.00
8FFC0B	2017-08-11 03:36:00+03	27200.00
8FFC4E	2017-07-06 14:04:00+03	95200.00
8FFC6A	2017-08-06 08:05:00+03	184300.00
8FFC70	2017-08-12 19:25:00+03	26200.00
8FFC7B	2017-08-10 17:41:00+03	112000.00
8FFCC2	2017-07-08 00:38:00+03	54000.00
8FFCF8	2017-07-24 19:46:00+03	28800.00
8FFD05	2017-07-06 19:26:00+03	47200.00
8FFD0A	2017-07-23 05:00:00+03	213800.00
8FFD76	2017-07-23 12:43:00+03	273100.00
8FFDA6	2017-08-13 14:20:00+03	112000.00
8FFDCF	2017-07-17 05:34:00+03	68800.00
8FFDE5	2017-07-27 00:57:00+03	19600.00
8FFEC3	2017-08-15 03:05:00+03	62200.00
8FFEC9	2017-07-11 03:07:00+03	172100.00
8FFED5	2017-08-08 01:24:00+03	182300.00
8FFEFB	2017-08-10 19:21:00+03	113800.00
8FFF1E	2017-08-11 05:06:00+03	37700.00
8FFF39	2017-07-05 18:26:00+03	16400.00
8FFF97	2017-08-09 10:29:00+03	44000.00
8FFFB6	2017-07-17 17:01:00+03	108000.00
90001F	2017-07-18 02:00:00+03	406200.00
900050	2017-08-03 15:00:00+03	73200.00
90007C	2017-07-06 00:22:00+03	112000.00
90010D	2017-07-11 17:35:00+03	40000.00
90015E	2017-07-28 16:49:00+03	23200.00
9002A3	2017-07-21 07:34:00+03	136200.00
900317	2017-07-20 11:41:00+03	139900.00
900355	2017-08-10 20:38:00+03	83900.00
90037C	2017-07-14 22:42:00+03	36900.00
9003BF	2017-08-10 04:11:00+03	62700.00
9003F4	2017-07-02 03:42:00+03	6800.00
90043B	2017-07-18 04:30:00+03	57600.00
900458	2017-07-12 16:42:00+03	28800.00
90049B	2017-07-02 13:50:00+03	100600.00
9004A8	2017-08-07 05:42:00+03	27200.00
9004B0	2017-07-17 22:43:00+03	49100.00
9004B4	2017-07-04 05:11:00+03	209500.00
9004C1	2017-08-07 02:14:00+03	33400.00
900507	2017-07-27 08:23:00+03	23100.00
900555	2017-08-13 05:04:00+03	27200.00
900574	2017-07-22 21:14:00+03	97900.00
9005CE	2017-08-05 17:38:00+03	31900.00
9005DB	2017-07-25 05:43:00+03	44500.00
9005FC	2017-07-15 00:27:00+03	76600.00
90066F	2017-07-08 14:25:00+03	46300.00
9006AC	2017-06-30 01:46:00+03	92800.00
9006DD	2017-08-05 22:49:00+03	102100.00
900717	2017-08-07 05:29:00+03	28800.00
90074F	2017-08-03 09:07:00+03	26000.00
900766	2017-07-15 03:43:00+03	85000.00
900774	2017-07-12 21:06:00+03	43500.00
900779	2017-08-04 11:49:00+03	44800.00
90079F	2017-08-12 19:29:00+03	28000.00
9007CC	2017-07-11 18:55:00+03	89000.00
9007D5	2017-07-20 09:32:00+03	6800.00
9007F2	2017-08-08 01:14:00+03	16800.00
90083E	2017-07-10 00:23:00+03	48800.00
900849	2017-08-14 22:21:00+03	192700.00
9008D5	2017-07-31 20:04:00+03	113000.00
9008E1	2017-08-06 14:55:00+03	282100.00
9008FC	2017-08-07 08:38:00+03	55600.00
90092A	2017-08-06 21:45:00+03	54000.00
9009BE	2017-07-05 21:45:00+03	13000.00
900A00	2017-08-02 11:40:00+03	102100.00
900AC8	2017-07-03 00:41:00+03	31600.00
900AD1	2017-07-16 02:02:00+03	84300.00
900AD5	2017-07-16 10:08:00+03	14000.00
900AD9	2017-07-14 21:39:00+03	53600.00
900ADA	2017-07-26 04:45:00+03	75700.00
900AE6	2017-07-06 10:44:00+03	406700.00
900B10	2017-06-30 04:33:00+03	24400.00
900B4F	2017-07-15 00:59:00+03	23100.00
900B54	2017-07-25 23:56:00+03	67600.00
900B58	2017-08-08 21:16:00+03	60600.00
900B6A	2017-07-24 01:22:00+03	68400.00
900BB3	2017-07-05 06:47:00+03	48800.00
900C13	2017-07-07 02:00:00+03	25600.00
900CFD	2017-07-06 11:08:00+03	59000.00
900DA8	2017-07-31 11:13:00+03	37900.00
900DC5	2017-07-22 08:54:00+03	26200.00
900DD0	2017-07-11 14:36:00+03	61900.00
900E66	2017-08-04 08:06:00+03	257600.00
900ED2	2017-08-08 17:09:00+03	35300.00
900F31	2017-07-05 03:41:00+03	25600.00
900F55	2017-07-04 05:05:00+03	12600.00
900F90	2017-07-28 05:54:00+03	85000.00
900FB6	2017-07-27 02:23:00+03	58800.00
901092	2017-08-06 14:17:00+03	135200.00
9010D1	2017-07-10 19:57:00+03	145100.00
901115	2017-07-09 16:37:00+03	15000.00
901165	2017-07-30 13:06:00+03	31500.00
9011A7	2017-07-25 07:35:00+03	103500.00
9011DB	2017-07-25 12:32:00+03	28800.00
9011F3	2017-07-29 17:57:00+03	109600.00
90123B	2017-07-20 16:16:00+03	40000.00
90124A	2017-07-26 12:02:00+03	22100.00
901259	2017-07-15 02:28:00+03	123600.00
9012A8	2017-08-06 06:03:00+03	6000.00
9012D1	2017-07-17 08:37:00+03	23100.00
9012D7	2017-07-15 21:13:00+03	55800.00
901311	2017-07-21 08:29:00+03	115600.00
901321	2017-08-09 14:10:00+03	565200.00
901346	2017-07-10 23:04:00+03	31600.00
9013B8	2017-07-19 23:02:00+03	65900.00
90140D	2017-06-29 18:09:00+03	21800.00
90141D	2017-08-14 19:01:00+03	31400.00
90144D	2017-07-02 09:48:00+03	19800.00
901459	2017-08-12 11:19:00+03	213200.00
901465	2017-07-23 09:51:00+03	82200.00
9015D4	2017-07-14 20:32:00+03	38400.00
9015F3	2017-07-16 12:51:00+03	26000.00
9015FE	2017-08-03 05:14:00+03	16800.00
901655	2017-07-27 01:46:00+03	24800.00
901671	2017-07-09 17:38:00+03	20200.00
9016E2	2017-07-18 01:36:00+03	86800.00
901707	2017-06-30 04:27:00+03	8200.00
901719	2017-07-03 20:17:00+03	62000.00
90172C	2017-07-02 11:23:00+03	27300.00
9017DC	2017-07-27 14:16:00+03	126400.00
9017FD	2017-08-15 13:26:00+03	133900.00
901856	2017-08-03 12:47:00+03	25200.00
9018F3	2017-07-20 01:18:00+03	77600.00
901934	2017-07-28 22:50:00+03	25000.00
90195A	2017-07-03 09:12:00+03	129200.00
901969	2017-08-02 00:29:00+03	173100.00
901985	2017-07-09 05:29:00+03	67600.00
90198D	2017-08-03 10:12:00+03	27200.00
9019C4	2017-08-04 00:06:00+03	46500.00
9019D6	2017-08-06 22:18:00+03	95600.00
901A26	2017-06-29 16:52:00+03	16400.00
901B1D	2017-08-05 08:51:00+03	17000.00
901B30	2017-06-30 09:42:00+03	20600.00
901B35	2017-08-15 06:18:00+03	240600.00
901B3A	2017-07-27 12:03:00+03	260300.00
901BD6	2017-08-10 16:42:00+03	42400.00
901BDC	2017-07-07 18:30:00+03	15000.00
901BE3	2017-07-16 11:46:00+03	124200.00
901BEF	2017-08-11 01:38:00+03	23200.00
901C98	2017-07-03 19:02:00+03	111600.00
901CCB	2017-08-14 23:36:00+03	39800.00
901D1C	2017-08-01 04:01:00+03	24400.00
901D26	2017-07-21 18:59:00+03	55800.00
901D34	2017-07-20 10:55:00+03	47000.00
901D3B	2017-08-14 11:42:00+03	124200.00
901D55	2017-07-17 22:32:00+03	226200.00
901D85	2017-07-11 07:17:00+03	6300.00
901E26	2017-06-30 07:48:00+03	60400.00
901E2B	2017-07-27 19:07:00+03	93500.00
901E3F	2017-07-03 15:29:00+03	16400.00
901E4A	2017-08-10 01:15:00+03	32200.00
901EA3	2017-07-01 11:49:00+03	22000.00
901EB4	2017-07-17 14:44:00+03	91100.00
901EC3	2017-08-02 20:12:00+03	31800.00
901ECF	2017-07-09 06:16:00+03	65900.00
901F3F	2017-07-25 16:44:00+03	26700.00
901FCB	2017-07-21 12:44:00+03	25600.00
901FF0	2017-08-05 14:53:00+03	399600.00
902045	2017-07-14 03:48:00+03	265700.00
90205E	2017-07-17 14:34:00+03	199700.00
902065	2017-08-12 09:04:00+03	6700.00
902086	2017-08-11 21:30:00+03	28800.00
90209D	2017-08-09 08:03:00+03	114800.00
9020D1	2017-07-26 14:48:00+03	7400.00
9020D6	2017-07-30 00:07:00+03	27900.00
902163	2017-07-15 10:20:00+03	23200.00
902166	2017-07-22 07:06:00+03	28800.00
90216D	2017-08-09 03:04:00+03	266400.00
90219C	2017-07-12 02:06:00+03	38800.00
9021CC	2017-08-12 03:42:00+03	28000.00
9021CD	2017-07-31 00:58:00+03	62600.00
9021E5	2017-08-13 19:30:00+03	43800.00
90222F	2017-08-10 09:16:00+03	49200.00
902284	2017-07-24 23:18:00+03	53100.00
9022A3	2017-07-11 17:18:00+03	105700.00
9022E1	2017-07-29 17:48:00+03	15000.00
902327	2017-07-05 06:16:00+03	40300.00
90235F	2017-08-07 17:27:00+03	48800.00
9023A2	2017-07-18 17:10:00+03	73600.00
902502	2017-07-16 07:20:00+03	52300.00
902503	2017-07-25 08:21:00+03	122700.00
902522	2017-07-24 12:50:00+03	38500.00
90258D	2017-06-28 09:03:00+03	56000.00
902607	2017-08-14 21:36:00+03	38400.00
902656	2017-08-11 15:20:00+03	86500.00
9026ED	2017-08-05 06:52:00+03	133100.00
90271E	2017-07-12 14:52:00+03	28800.00
90271F	2017-08-07 14:36:00+03	51900.00
902736	2017-07-29 16:16:00+03	56000.00
90276B	2017-07-30 12:55:00+03	67900.00
90276E	2017-08-08 12:11:00+03	29600.00
90278E	2017-07-01 23:29:00+03	155600.00
9027A4	2017-07-02 20:24:00+03	53000.00
9028CC	2017-08-06 23:23:00+03	106700.00
90295D	2017-06-29 08:06:00+03	67600.00
90296F	2017-06-27 22:48:00+03	13000.00
902975	2017-07-14 05:24:00+03	69500.00
902978	2017-07-24 18:21:00+03	8200.00
90299C	2017-07-05 04:28:00+03	112000.00
902A00	2017-08-04 22:11:00+03	147700.00
902A54	2017-07-17 23:16:00+03	27200.00
902A77	2017-08-10 16:59:00+03	64100.00
902A79	2017-07-31 23:11:00+03	132800.00
902AF0	2017-08-08 04:46:00+03	33300.00
902B2D	2017-08-09 08:50:00+03	28000.00
902B6B	2017-08-11 20:48:00+03	40800.00
902BA8	2017-08-12 14:35:00+03	23400.00
902BAD	2017-08-13 16:22:00+03	25600.00
902BCF	2017-07-26 16:33:00+03	73200.00
902C1F	2017-07-30 20:23:00+03	130000.00
902C23	2017-07-08 05:08:00+03	23200.00
902C4B	2017-07-10 07:06:00+03	167400.00
902CA2	2017-07-31 00:35:00+03	7400.00
902CA4	2017-07-24 23:11:00+03	131900.00
902CE7	2017-07-05 17:29:00+03	54800.00
902D01	2017-08-14 02:48:00+03	110500.00
902D94	2017-07-19 01:09:00+03	14000.00
902DAE	2017-07-03 20:42:00+03	22200.00
902DC9	2017-07-06 22:32:00+03	25000.00
902DD7	2017-06-26 19:58:00+03	92800.00
902EAF	2017-07-31 16:36:00+03	69500.00
902F1F	2017-08-03 21:19:00+03	72800.00
902F6C	2017-07-18 05:41:00+03	33800.00
902F8B	2017-07-05 07:24:00+03	39800.00
902FAE	2017-07-23 21:17:00+03	27200.00
90300C	2017-07-08 23:42:00+03	63400.00
903014	2017-07-10 03:52:00+03	55800.00
903041	2017-07-09 07:32:00+03	44500.00
90305B	2017-08-14 20:58:00+03	55800.00
9030BE	2017-08-04 01:01:00+03	206700.00
9030C3	2017-07-04 23:13:00+03	81600.00
90318C	2017-08-10 15:33:00+03	111600.00
9031BC	2017-08-02 02:20:00+03	92900.00
9031C8	2017-06-27 16:47:00+03	25200.00
9031E4	2017-07-09 21:35:00+03	23600.00
9031F2	2017-07-26 07:31:00+03	55800.00
90323C	2017-08-10 05:15:00+03	60400.00
903284	2017-08-05 09:11:00+03	46400.00
903291	2017-07-01 19:44:00+03	107700.00
9032B0	2017-07-29 08:00:00+03	47100.00
9032B3	2017-08-07 05:50:00+03	47400.00
9032F3	2017-08-01 13:03:00+03	89600.00
903321	2017-07-07 22:24:00+03	73500.00
90332F	2017-08-11 21:03:00+03	123000.00
90333A	2017-07-24 07:32:00+03	272400.00
90335B	2017-08-07 12:39:00+03	37700.00
9033C0	2017-07-24 23:49:00+03	80000.00
90340E	2017-07-07 13:03:00+03	42200.00
903433	2017-08-12 20:45:00+03	54800.00
903480	2017-07-19 12:30:00+03	137600.00
9034B2	2017-08-03 15:21:00+03	92800.00
9034CD	2017-08-10 13:11:00+03	202200.00
9035BB	2017-07-21 03:17:00+03	30000.00
9035DB	2017-07-23 21:10:00+03	28300.00
9036B6	2017-07-27 05:40:00+03	27000.00
903767	2017-08-15 08:42:00+03	6300.00
90376E	2017-08-13 18:41:00+03	77600.00
903780	2017-07-31 20:43:00+03	57500.00
9037DA	2017-07-09 22:21:00+03	62100.00
9037EE	2017-07-16 17:36:00+03	13000.00
903886	2017-07-25 17:45:00+03	88500.00
9038BE	2017-07-21 14:49:00+03	105600.00
903967	2017-07-04 14:23:00+03	69900.00
9039A9	2017-08-14 22:54:00+03	43500.00
903A06	2017-07-21 07:53:00+03	270000.00
903A10	2017-08-13 04:58:00+03	190700.00
903A27	2017-07-03 17:52:00+03	55800.00
903ACF	2017-07-28 17:18:00+03	44800.00
903B21	2017-07-31 19:26:00+03	72400.00
903B6E	2017-07-02 09:53:00+03	199300.00
903BB6	2017-07-22 06:23:00+03	46400.00
903C01	2017-07-24 12:11:00+03	400000.00
903C71	2017-06-27 06:30:00+03	58600.00
903CF8	2017-07-31 22:45:00+03	47000.00
903DD8	2017-07-25 14:17:00+03	293700.00
903E0D	2017-08-08 23:15:00+03	23400.00
903E11	2017-08-05 13:08:00+03	40000.00
903E8B	2017-08-05 12:00:00+03	53200.00
903E97	2017-07-10 11:04:00+03	113200.00
903EF0	2017-08-13 13:31:00+03	46200.00
903FBB	2017-07-04 05:46:00+03	6300.00
904036	2017-07-15 08:31:00+03	138000.00
9040AA	2017-08-04 09:35:00+03	75300.00
904118	2017-07-14 00:12:00+03	79300.00
904188	2017-07-15 19:54:00+03	85500.00
9041BD	2017-08-09 00:44:00+03	135200.00
9041D3	2017-07-26 08:44:00+03	176000.00
9041F6	2017-07-27 06:30:00+03	34000.00
904250	2017-08-12 17:17:00+03	67100.00
904288	2017-07-05 18:26:00+03	184300.00
9042F0	2017-07-17 21:27:00+03	74400.00
9042F7	2017-08-12 00:29:00+03	15000.00
904318	2017-07-17 21:55:00+03	28300.00
904346	2017-08-03 03:58:00+03	65200.00
904485	2017-08-08 14:57:00+03	86300.00
9044E4	2017-08-03 13:20:00+03	26400.00
90450C	2017-07-21 18:41:00+03	59100.00
904531	2017-07-05 07:30:00+03	70500.00
904532	2017-07-28 15:17:00+03	103500.00
904561	2017-08-05 07:18:00+03	73100.00
9045A3	2017-08-05 06:22:00+03	41400.00
904629	2017-07-12 01:27:00+03	62600.00
904641	2017-07-03 15:21:00+03	88300.00
9046EB	2017-07-05 22:53:00+03	19800.00
904728	2017-07-25 18:51:00+03	32800.00
904730	2017-07-27 00:22:00+03	6800.00
904749	2017-07-05 04:12:00+03	27200.00
9047AD	2017-07-05 12:40:00+03	226800.00
9047C9	2017-07-03 04:03:00+03	34800.00
904802	2017-07-22 04:21:00+03	32800.00
90485E	2017-07-09 18:51:00+03	42700.00
904862	2017-07-22 18:43:00+03	410200.00
904967	2017-07-07 03:28:00+03	56000.00
904A0D	2017-07-14 19:19:00+03	9200.00
904A49	2017-07-29 15:57:00+03	32200.00
904A6E	2017-08-14 18:03:00+03	47200.00
904AA2	2017-08-13 16:10:00+03	203000.00
904AEA	2017-06-28 16:48:00+03	97600.00
904B0B	2017-07-02 19:33:00+03	76600.00
904B58	2017-07-27 07:01:00+03	46300.00
904B8B	2017-08-15 15:53:00+03	19600.00
904C24	2017-08-05 20:30:00+03	70700.00
904C29	2017-08-10 13:49:00+03	6700.00
904C5D	2017-07-11 20:47:00+03	40000.00
904C89	2017-07-20 07:38:00+03	71600.00
904CC4	2017-08-12 18:31:00+03	8200.00
904D03	2017-08-04 06:13:00+03	7400.00
904DA6	2017-07-26 11:06:00+03	42800.00
904DC2	2017-07-19 01:59:00+03	271200.00
904E11	2017-07-25 23:48:00+03	257500.00
904E39	2017-07-14 19:05:00+03	28700.00
904EBB	2017-07-16 06:51:00+03	58000.00
904F23	2017-07-27 19:38:00+03	24400.00
904F58	2017-08-10 17:16:00+03	56900.00
904F83	2017-07-18 21:07:00+03	36200.00
904FF6	2017-07-15 23:17:00+03	266400.00
905012	2017-07-26 15:51:00+03	19800.00
905018	2017-07-20 09:35:00+03	80000.00
905029	2017-07-08 02:27:00+03	84000.00
9050BF	2017-07-28 07:22:00+03	369000.00
9050CB	2017-06-29 16:38:00+03	61500.00
9050CE	2017-08-05 00:34:00+03	95600.00
90510A	2017-07-21 12:08:00+03	46800.00
905161	2017-07-20 01:18:00+03	34400.00
905165	2017-07-21 16:47:00+03	87700.00
905207	2017-07-16 11:11:00+03	46400.00
90523E	2017-08-13 00:02:00+03	47000.00
9052DC	2017-08-08 18:51:00+03	107200.00
9052FA	2017-07-07 15:07:00+03	415400.00
905325	2017-07-28 01:16:00+03	119500.00
905359	2017-08-15 12:47:00+03	12600.00
90535F	2017-07-30 02:07:00+03	46000.00
90539B	2017-08-09 18:50:00+03	23200.00
9053F7	2017-07-24 01:06:00+03	31300.00
9053F8	2017-07-25 00:29:00+03	11600.00
9053FF	2017-08-06 15:50:00+03	28800.00
905428	2017-08-14 21:55:00+03	46200.00
905452	2017-08-02 04:47:00+03	29400.00
905456	2017-07-17 00:52:00+03	24400.00
90545A	2017-08-12 00:43:00+03	93400.00
905473	2017-07-25 12:33:00+03	177000.00
905487	2017-07-03 09:21:00+03	31000.00
9054D2	2017-08-10 09:45:00+03	19600.00
9054E1	2017-08-04 08:09:00+03	38600.00
9054FA	2017-07-28 19:05:00+03	89700.00
905530	2017-07-30 22:50:00+03	182300.00
905537	2017-07-17 05:24:00+03	73600.00
905544	2017-08-11 00:13:00+03	133200.00
90555A	2017-08-13 20:33:00+03	74000.00
9055FA	2017-08-05 08:00:00+03	75300.00
905642	2017-08-12 19:09:00+03	81300.00
9056C3	2017-08-06 11:53:00+03	6000.00
9056C6	2017-07-12 07:08:00+03	47200.00
90572A	2017-07-14 16:53:00+03	92700.00
90580F	2017-07-17 05:30:00+03	18600.00
905836	2017-07-13 13:52:00+03	46000.00
90583A	2017-07-10 18:27:00+03	191500.00
9058E2	2017-07-17 15:51:00+03	93000.00
9058ED	2017-06-28 13:31:00+03	26000.00
905956	2017-07-06 23:18:00+03	31100.00
9059F2	2017-07-19 06:21:00+03	12000.00
905A62	2017-07-30 08:00:00+03	190700.00
905A77	2017-07-27 00:08:00+03	28800.00
905A81	2017-07-17 09:12:00+03	86800.00
905AB7	2017-07-05 15:06:00+03	72300.00
905AC3	2017-07-26 12:04:00+03	132800.00
905AE4	2017-07-19 07:50:00+03	28800.00
905B19	2017-07-14 10:59:00+03	8200.00
905B35	2017-07-13 01:16:00+03	155600.00
905B8D	2017-07-15 20:18:00+03	24000.00
905BE5	2017-08-03 16:47:00+03	67200.00
905CE5	2017-07-28 21:37:00+03	202100.00
905CFE	2017-08-14 13:36:00+03	52400.00
905D5F	2017-06-29 04:10:00+03	212300.00
905D7F	2017-07-15 11:57:00+03	20600.00
905DC3	2017-08-10 02:35:00+03	78300.00
905E30	2017-06-30 09:04:00+03	15000.00
905E95	2017-07-24 13:42:00+03	16400.00
905EF8	2017-07-10 15:19:00+03	55800.00
905F51	2017-07-02 03:06:00+03	134400.00
905F77	2017-07-11 11:15:00+03	28800.00
905FC8	2017-07-29 18:13:00+03	31600.00
905FD7	2017-07-11 19:20:00+03	201800.00
905FE3	2017-07-12 06:54:00+03	6800.00
906002	2017-07-16 10:02:00+03	46400.00
906008	2017-07-20 18:39:00+03	26000.00
906088	2017-07-28 19:05:00+03	73100.00
9060E2	2017-07-27 11:33:00+03	391600.00
906115	2017-07-25 13:33:00+03	92800.00
906139	2017-07-27 12:57:00+03	46400.00
90615F	2017-08-08 15:02:00+03	12000.00
906169	2017-07-20 04:21:00+03	65500.00
90617E	2017-07-02 09:01:00+03	83000.00
90618C	2017-07-08 20:26:00+03	68000.00
9061D1	2017-07-22 08:15:00+03	37400.00
9061EF	2017-07-06 06:34:00+03	58800.00
906209	2017-07-30 18:23:00+03	55600.00
90620F	2017-08-04 11:41:00+03	28000.00
906226	2017-07-28 19:21:00+03	42000.00
9062A2	2017-07-01 02:57:00+03	111000.00
9062E0	2017-07-03 09:44:00+03	44800.00
9062EE	2017-07-18 04:22:00+03	55800.00
906302	2017-07-28 17:24:00+03	134400.00
90630D	2017-08-06 05:39:00+03	66600.00
906388	2017-07-25 18:24:00+03	27300.00
906423	2017-08-15 10:58:00+03	47200.00
9064C1	2017-08-10 16:31:00+03	26200.00
9064C9	2017-07-26 06:59:00+03	31600.00
906532	2017-07-08 11:26:00+03	44800.00
90653E	2017-07-21 11:56:00+03	28000.00
906549	2017-07-08 08:01:00+03	31000.00
906553	2017-07-22 17:39:00+03	55800.00
906584	2017-06-29 14:45:00+03	25400.00
9065AF	2017-07-15 22:08:00+03	49500.00
906671	2017-07-14 16:23:00+03	202300.00
906677	2017-07-24 08:47:00+03	92000.00
90668E	2017-07-20 15:43:00+03	7400.00
9066DF	2017-08-03 13:50:00+03	61800.00
9066ED	2017-07-17 01:13:00+03	11000.00
906758	2017-07-12 03:35:00+03	55800.00
906867	2017-07-08 02:10:00+03	212200.00
906871	2017-08-03 11:12:00+03	85000.00
9068A5	2017-07-15 07:00:00+03	42500.00
9068BD	2017-07-13 18:16:00+03	114200.00
9068F0	2017-07-28 20:07:00+03	119600.00
906913	2017-08-02 01:02:00+03	84500.00
906975	2017-07-18 17:24:00+03	85000.00
9069D2	2017-08-08 23:06:00+03	70700.00
9069FD	2017-07-28 18:40:00+03	53500.00
906A00	2017-08-08 10:55:00+03	47500.00
906A15	2017-07-08 14:49:00+03	48500.00
906A3D	2017-08-01 09:47:00+03	135600.00
906ADC	2017-07-04 09:11:00+03	12400.00
906B18	2017-07-13 06:41:00+03	35600.00
906B2C	2017-08-11 10:19:00+03	123000.00
906B8E	2017-07-14 10:22:00+03	189300.00
906BCD	2017-08-13 18:05:00+03	12400.00
906BD4	2017-07-05 03:57:00+03	65500.00
906CD4	2017-07-20 14:43:00+03	87100.00
906CD5	2017-07-15 19:29:00+03	21800.00
906D1E	2017-08-05 08:01:00+03	88100.00
906D3C	2017-07-12 22:24:00+03	167000.00
906D79	2017-07-04 00:30:00+03	225300.00
906D8C	2017-08-05 00:11:00+03	57300.00
906DCE	2017-08-10 22:25:00+03	38600.00
906DD6	2017-06-29 07:27:00+03	286000.00
906DE2	2017-07-18 11:30:00+03	139400.00
906DE7	2017-07-04 09:44:00+03	130300.00
906E1F	2017-08-01 03:51:00+03	160100.00
906E34	2017-08-02 05:41:00+03	74000.00
906E99	2017-07-08 14:36:00+03	172400.00
906EC3	2017-07-18 23:25:00+03	192900.00
906EDC	2017-07-18 16:07:00+03	41600.00
906F44	2017-08-01 13:16:00+03	305800.00
906F4A	2017-07-11 00:45:00+03	186500.00
906F4E	2017-08-10 06:09:00+03	20200.00
906F56	2017-08-13 12:35:00+03	55000.00
906F79	2017-08-03 03:45:00+03	23200.00
906FEE	2017-07-22 21:35:00+03	266400.00
90700C	2017-07-04 06:31:00+03	168200.00
9070A1	2017-08-13 03:01:00+03	8400.00
9070C2	2017-07-26 20:47:00+03	28000.00
9070FA	2017-07-10 15:22:00+03	53500.00
90713A	2017-07-11 20:12:00+03	46400.00
9071C5	2017-07-20 18:34:00+03	58900.00
907207	2017-08-05 06:23:00+03	37000.00
90723B	2017-07-16 03:09:00+03	23400.00
907291	2017-07-24 15:41:00+03	170800.00
9072CB	2017-07-14 12:20:00+03	92900.00
907305	2017-07-05 19:44:00+03	54000.00
907310	2017-07-08 04:12:00+03	21400.00
907335	2017-07-14 14:03:00+03	186600.00
90733C	2017-08-13 11:44:00+03	25800.00
9073AF	2017-07-18 21:27:00+03	67700.00
9073BE	2017-07-15 04:37:00+03	27400.00
907406	2017-07-30 05:23:00+03	27200.00
907418	2017-08-03 05:08:00+03	133200.00
907445	2017-08-06 01:52:00+03	111700.00
907485	2017-08-05 11:29:00+03	56000.00
907539	2017-07-04 13:49:00+03	12400.00
907569	2017-07-15 11:59:00+03	260900.00
90759A	2017-07-29 12:34:00+03	158200.00
9075EB	2017-07-20 23:38:00+03	88600.00
907626	2017-07-03 15:06:00+03	39100.00
907686	2017-08-03 06:12:00+03	55600.00
90768D	2017-08-03 17:47:00+03	8200.00
90775F	2017-08-10 16:31:00+03	124200.00
90776E	2017-07-01 13:49:00+03	36800.00
907775	2017-08-15 09:34:00+03	57400.00
9077B3	2017-07-20 09:47:00+03	28000.00
9077DD	2017-07-27 02:21:00+03	21200.00
907810	2017-07-21 01:09:00+03	111600.00
9078A3	2017-08-02 06:26:00+03	43300.00
9079EA	2017-07-12 12:13:00+03	90000.00
907A1F	2017-07-06 02:23:00+03	147700.00
907A8F	2017-08-08 02:24:00+03	12400.00
907ABD	2017-07-17 15:46:00+03	155200.00
907AC1	2017-07-07 08:00:00+03	89000.00
907ACA	2017-06-30 17:28:00+03	58900.00
907ADD	2017-07-19 10:51:00+03	11000.00
907B1C	2017-08-12 00:28:00+03	98400.00
907B24	2017-07-19 01:16:00+03	27500.00
907B36	2017-08-12 21:55:00+03	56600.00
907B52	2017-07-26 10:51:00+03	50100.00
907B7F	2017-07-19 09:08:00+03	23600.00
907BD8	2017-08-01 03:36:00+03	113200.00
907BE5	2017-07-29 21:27:00+03	99000.00
907BFD	2017-07-26 06:56:00+03	24800.00
907C07	2017-07-07 10:51:00+03	24700.00
907C36	2017-08-02 23:13:00+03	89600.00
907C56	2017-07-25 03:46:00+03	139100.00
907D4C	2017-07-02 09:11:00+03	25600.00
907E14	2017-08-03 01:24:00+03	31600.00
907E30	2017-07-18 14:52:00+03	393000.00
907E54	2017-07-05 00:46:00+03	56600.00
907E81	2017-07-19 14:03:00+03	131100.00
907F16	2017-08-10 14:06:00+03	38400.00
907F3E	2017-07-16 15:10:00+03	59800.00
907F60	2017-08-04 14:10:00+03	70100.00
907F83	2017-08-04 16:33:00+03	8400.00
90801B	2017-07-01 01:21:00+03	14000.00
90806D	2017-07-04 20:56:00+03	81300.00
90811D	2017-08-06 03:04:00+03	406100.00
908136	2017-08-04 22:14:00+03	23200.00
9081A1	2017-07-14 01:05:00+03	57800.00
9081FC	2017-07-22 21:21:00+03	8200.00
90823D	2017-07-07 17:30:00+03	92800.00
90825E	2017-07-16 17:14:00+03	22000.00
9082E0	2017-08-11 08:50:00+03	28000.00
90832F	2017-08-15 09:10:00+03	117200.00
9083CC	2017-08-01 20:13:00+03	67600.00
9083E6	2017-06-29 00:22:00+03	48800.00
9083F0	2017-08-12 23:24:00+03	113100.00
908423	2017-07-24 22:20:00+03	35300.00
908442	2017-07-05 19:27:00+03	31600.00
908468	2017-08-10 07:58:00+03	94700.00
9084B8	2017-07-03 14:20:00+03	92000.00
9085C7	2017-07-03 14:00:00+03	8200.00
9085CC	2017-07-23 16:46:00+03	39400.00
908604	2017-08-14 03:38:00+03	670800.00
9086BC	2017-07-15 08:40:00+03	39300.00
9086CE	2017-08-13 12:30:00+03	55900.00
9086FB	2017-07-26 11:10:00+03	138000.00
90875B	2017-07-12 05:31:00+03	46000.00
9087D8	2017-07-14 08:53:00+03	38400.00
9087E5	2017-07-07 10:53:00+03	29600.00
908807	2017-08-03 05:04:00+03	28000.00
908812	2017-08-07 03:06:00+03	62600.00
908815	2017-07-07 18:51:00+03	77200.00
908833	2017-07-20 08:58:00+03	21800.00
90886C	2017-08-13 20:08:00+03	88900.00
90892B	2017-07-18 03:54:00+03	38700.00
908978	2017-07-07 18:57:00+03	80100.00
90897F	2017-07-09 23:35:00+03	38600.00
9089BE	2017-08-13 01:18:00+03	138600.00
908A1B	2017-07-14 12:37:00+03	70600.00
908A62	2017-07-02 08:21:00+03	57500.00
908A69	2017-08-08 05:28:00+03	139100.00
908AAB	2017-08-11 02:29:00+03	59200.00
908ABA	2017-08-07 14:01:00+03	139500.00
908B28	2017-07-03 05:03:00+03	127700.00
908BAC	2017-07-26 01:02:00+03	44800.00
908BB9	2017-07-20 15:59:00+03	48800.00
908BC6	2017-07-09 19:27:00+03	37600.00
908BDF	2017-07-30 18:18:00+03	517400.00
908BEB	2017-08-15 13:34:00+03	153100.00
908C31	2017-07-08 19:54:00+03	42700.00
908C3A	2017-07-23 08:24:00+03	59900.00
908C59	2017-07-30 18:08:00+03	42800.00
908CBD	2017-07-15 01:56:00+03	114200.00
908CCE	2017-07-10 05:04:00+03	48400.00
908CF6	2017-07-22 23:53:00+03	29600.00
908D06	2017-07-20 07:56:00+03	160700.00
908E09	2017-07-18 22:54:00+03	68100.00
908E21	2017-07-24 11:50:00+03	47400.00
908E35	2017-08-13 19:01:00+03	25000.00
908E7A	2017-08-11 00:03:00+03	130800.00
908F4D	2017-07-05 07:24:00+03	73400.00
908F78	2017-07-21 03:07:00+03	64600.00
908F9B	2017-07-23 01:02:00+03	156500.00
908FAF	2017-08-13 21:32:00+03	31600.00
908FB3	2017-07-12 20:08:00+03	36200.00
908FBA	2017-07-16 23:30:00+03	114800.00
909191	2017-07-13 18:52:00+03	133200.00
9091B5	2017-08-15 14:19:00+03	57800.00
9091CE	2017-07-19 05:47:00+03	36400.00
9091EA	2017-07-07 14:00:00+03	11600.00
90924D	2017-07-30 20:42:00+03	26000.00
909260	2017-07-06 11:17:00+03	93700.00
909349	2017-07-29 21:34:00+03	20600.00
90934D	2017-08-13 14:24:00+03	76600.00
909353	2017-07-26 22:13:00+03	73400.00
90935B	2017-07-25 06:20:00+03	19800.00
90938D	2017-07-11 11:59:00+03	16400.00
9093EA	2017-08-02 10:25:00+03	63800.00
9094B2	2017-07-08 03:36:00+03	247000.00
90954C	2017-07-02 17:02:00+03	62700.00
909561	2017-08-09 18:20:00+03	123600.00
90957E	2017-08-12 23:38:00+03	282000.00
9095A6	2017-07-12 10:26:00+03	38200.00
9095AC	2017-07-05 18:07:00+03	25100.00
9095DE	2017-08-06 15:13:00+03	77600.00
9095E2	2017-08-04 07:30:00+03	29200.00
909650	2017-07-06 14:59:00+03	26700.00
9096DC	2017-06-30 03:27:00+03	295200.00
9096F5	2017-07-04 09:04:00+03	13200.00
90971F	2017-07-02 13:34:00+03	150600.00
909799	2017-08-02 08:11:00+03	66600.00
9097AB	2017-08-06 08:05:00+03	55800.00
9097C6	2017-08-07 07:09:00+03	65900.00
9097D0	2017-07-28 08:38:00+03	163400.00
90984A	2017-07-20 13:52:00+03	33800.00
90984E	2017-08-14 03:26:00+03	49000.00
909861	2017-07-05 11:23:00+03	114300.00
90987B	2017-07-12 17:57:00+03	28600.00
909891	2017-08-08 11:27:00+03	179500.00
9098EC	2017-07-27 07:20:00+03	28800.00
909948	2017-07-03 22:48:00+03	46800.00
9099A5	2017-07-05 06:31:00+03	69600.00
9099B0	2017-07-15 17:19:00+03	26000.00
9099D1	2017-08-04 00:49:00+03	31600.00
9099DC	2017-07-30 00:43:00+03	76200.00
909A12	2017-08-02 01:16:00+03	55800.00
909A3A	2017-07-15 10:46:00+03	86300.00
909AF2	2017-07-26 07:22:00+03	28000.00
909B0E	2017-07-21 08:42:00+03	14400.00
909B39	2017-07-18 04:09:00+03	44700.00
909B85	2017-08-11 17:10:00+03	46000.00
909BB0	2017-08-05 13:27:00+03	294400.00
909BED	2017-08-03 01:44:00+03	48500.00
909C9B	2017-08-04 07:01:00+03	58000.00
909CDC	2017-08-06 17:50:00+03	191600.00
909D10	2017-07-14 06:10:00+03	60200.00
909D13	2017-06-30 04:57:00+03	102100.00
909D78	2017-07-18 03:22:00+03	26800.00
909D94	2017-07-01 13:12:00+03	141000.00
909DB4	2017-07-27 22:55:00+03	32800.00
909E26	2017-07-16 12:05:00+03	37000.00
909E2F	2017-07-29 08:35:00+03	86600.00
909EC1	2017-07-08 10:26:00+03	135600.00
909F2D	2017-07-29 21:07:00+03	47100.00
909FAA	2017-07-04 12:17:00+03	46200.00
90A04C	2017-07-08 14:31:00+03	12200.00
90A079	2017-07-07 16:01:00+03	28000.00
90A173	2017-08-08 00:28:00+03	67600.00
90A174	2017-08-09 13:31:00+03	21400.00
90A184	2017-08-09 01:35:00+03	177600.00
90A1A6	2017-08-12 17:39:00+03	49900.00
90A1F2	2017-07-10 11:35:00+03	162600.00
90A20F	2017-08-02 18:54:00+03	75300.00
90A218	2017-07-25 01:56:00+03	13600.00
90A22D	2017-08-03 18:09:00+03	86300.00
90A252	2017-08-13 11:01:00+03	44000.00
90A269	2017-08-06 13:26:00+03	56600.00
90A26C	2017-07-04 14:55:00+03	28000.00
90A2D1	2017-07-04 12:01:00+03	38600.00
90A3E3	2017-07-16 09:09:00+03	48800.00
90A3F4	2017-07-21 15:39:00+03	28800.00
90A446	2017-08-15 02:17:00+03	27300.00
90A462	2017-07-04 05:06:00+03	36400.00
90A477	2017-07-24 04:08:00+03	133100.00
90A48F	2017-08-01 08:51:00+03	182300.00
90A4C1	2017-07-26 20:46:00+03	19600.00
90A4CF	2017-08-02 23:47:00+03	71500.00
90A4E2	2017-07-17 02:31:00+03	148700.00
90A4F4	2017-07-16 18:59:00+03	93700.00
90A506	2017-08-02 07:31:00+03	97600.00
90A508	2017-08-01 12:09:00+03	92700.00
90A553	2017-07-04 08:27:00+03	191000.00
90A58F	2017-07-25 00:25:00+03	73300.00
90A5E9	2017-07-07 10:24:00+03	96600.00
90A645	2017-07-25 10:36:00+03	62700.00
90A65F	2017-06-30 11:03:00+03	8000.00
90A686	2017-08-01 02:59:00+03	59800.00
90A6DE	2017-07-23 18:01:00+03	150600.00
90A737	2017-07-06 05:43:00+03	64600.00
90A749	2017-08-08 07:27:00+03	37200.00
90A777	2017-07-28 20:38:00+03	135400.00
90A782	2017-07-05 15:49:00+03	79600.00
90A7A3	2017-07-14 21:15:00+03	134700.00
90A7D9	2017-07-22 09:00:00+03	130400.00
90A7DD	2017-07-26 20:57:00+03	93900.00
90A8BD	2017-08-04 04:04:00+03	70600.00
90A8C1	2017-07-19 10:48:00+03	123000.00
90A911	2017-08-01 20:11:00+03	63900.00
90A9D7	2017-07-09 06:00:00+03	188900.00
90A9F6	2017-07-28 16:28:00+03	9300.00
90AA27	2017-08-10 20:32:00+03	88500.00
90AA83	2017-07-05 17:24:00+03	32800.00
90AAE3	2017-07-08 01:40:00+03	147200.00
90ABDE	2017-07-18 15:24:00+03	99700.00
90ABF7	2017-08-15 10:35:00+03	24000.00
90AC21	2017-07-16 15:41:00+03	138300.00
90AC6B	2017-07-18 06:18:00+03	378400.00
90AC98	2017-07-17 14:21:00+03	188900.00
90ACB7	2017-08-13 18:50:00+03	19800.00
90ACC1	2017-07-12 20:59:00+03	52000.00
90ACD3	2017-08-15 05:43:00+03	62000.00
90AD04	2017-08-14 11:08:00+03	26000.00
90AD05	2017-07-12 02:52:00+03	131100.00
90AD3A	2017-07-11 01:13:00+03	44000.00
90AD5A	2017-08-10 04:06:00+03	49100.00
90ADAD	2017-08-11 11:04:00+03	22200.00
90ADF0	2017-08-11 12:20:00+03	116400.00
90AE0B	2017-07-09 05:06:00+03	27800.00
90AE2D	2017-08-15 09:38:00+03	86400.00
90AE34	2017-07-17 06:17:00+03	71400.00
90AE51	2017-07-30 05:32:00+03	28000.00
90AE5C	2017-07-29 20:15:00+03	119600.00
90AEC4	2017-07-05 20:59:00+03	78600.00
90AECC	2017-07-19 14:02:00+03	114500.00
90AF08	2017-08-03 11:28:00+03	99200.00
90AF9F	2017-07-20 05:01:00+03	66600.00
90AFD1	2017-07-15 21:17:00+03	147200.00
90AFF4	2017-08-15 17:46:00+03	46400.00
90B02B	2017-07-12 15:08:00+03	60300.00
90B076	2017-08-07 01:10:00+03	8200.00
90B0B0	2017-08-06 03:49:00+03	199700.00
90B0D7	2017-08-05 04:37:00+03	57500.00
90B117	2017-07-18 12:48:00+03	55800.00
90B1ED	2017-07-29 06:48:00+03	73500.00
90B23C	2017-08-02 19:11:00+03	16400.00
90B281	2017-08-14 04:47:00+03	36400.00
90B2F3	2017-07-09 23:06:00+03	52000.00
90B31C	2017-07-30 16:52:00+03	73600.00
90B33B	2017-07-28 08:48:00+03	93900.00
90B363	2017-07-06 00:53:00+03	66600.00
90B372	2017-07-30 12:27:00+03	48800.00
90B465	2017-07-19 13:27:00+03	134400.00
90B4BC	2017-07-14 04:48:00+03	54800.00
90B4CA	2017-07-09 23:06:00+03	111600.00
90B500	2017-08-03 07:27:00+03	56000.00
90B599	2017-07-11 03:49:00+03	116400.00
90B5A2	2017-07-10 01:33:00+03	39500.00
90B5C4	2017-07-14 03:42:00+03	56600.00
90B623	2017-07-10 11:37:00+03	89200.00
90B69A	2017-07-14 18:48:00+03	16400.00
90B6F2	2017-08-04 09:10:00+03	133900.00
90B708	2017-08-01 18:43:00+03	288800.00
90B721	2017-07-19 22:53:00+03	106700.00
90B72F	2017-07-16 20:26:00+03	103500.00
90B730	2017-08-15 05:23:00+03	10800.00
90B8A8	2017-07-02 09:23:00+03	36200.00
90B8E7	2017-07-01 08:43:00+03	14800.00
90B918	2017-08-04 23:34:00+03	51800.00
90B977	2017-07-16 07:15:00+03	23400.00
90B994	2017-07-07 00:58:00+03	21200.00
90B9C9	2017-07-03 01:06:00+03	123000.00
90B9CC	2017-07-11 01:49:00+03	56000.00
90B9DF	2017-07-12 19:41:00+03	46000.00
90BA1E	2017-07-10 18:37:00+03	133200.00
90BAF3	2017-07-26 15:53:00+03	63000.00
90BB6A	2017-08-11 16:44:00+03	45800.00
90BBD3	2017-07-27 20:15:00+03	56000.00
90BBF2	2017-08-13 08:28:00+03	84800.00
90BC1F	2017-07-28 02:34:00+03	10800.00
90BC41	2017-08-01 23:15:00+03	64800.00
90BC60	2017-07-31 20:02:00+03	229900.00
90BC9D	2017-07-22 17:02:00+03	114800.00
90BCB3	2017-08-08 21:34:00+03	28000.00
90BCDE	2017-08-08 01:10:00+03	23600.00
90BCDF	2017-08-11 14:20:00+03	27200.00
90BD64	2017-07-25 07:53:00+03	51600.00
90BD68	2017-07-05 00:47:00+03	68600.00
90BD6E	2017-08-14 12:14:00+03	48800.00
90BD9E	2017-08-08 11:16:00+03	7200.00
90BE0E	2017-08-01 02:08:00+03	32800.00
90BE2C	2017-07-12 13:13:00+03	26000.00
90BE97	2017-07-21 17:29:00+03	47100.00
90BEE1	2017-08-07 22:15:00+03	41200.00
90BEFC	2017-07-22 02:31:00+03	100600.00
90BF20	2017-07-28 14:03:00+03	72400.00
90BFF6	2017-07-19 21:14:00+03	60700.00
90C017	2017-08-14 00:16:00+03	6800.00
90C028	2017-07-31 11:53:00+03	83900.00
90C031	2017-07-29 06:57:00+03	94000.00
90C070	2017-08-14 18:02:00+03	112000.00
90C073	2017-07-02 09:20:00+03	62000.00
90C0CA	2017-08-04 21:02:00+03	78500.00
90C0D2	2017-07-27 18:09:00+03	122700.00
90C0D5	2017-07-20 10:32:00+03	31600.00
90C0EA	2017-07-15 21:30:00+03	148500.00
90C110	2017-07-29 09:17:00+03	89600.00
90C195	2017-08-04 09:47:00+03	13600.00
90C19A	2017-08-01 08:20:00+03	302600.00
90C1B0	2017-07-31 21:42:00+03	103200.00
90C1C0	2017-07-14 00:19:00+03	23600.00
90C266	2017-07-12 21:05:00+03	21800.00
90C269	2017-07-09 08:25:00+03	137100.00
90C293	2017-07-20 12:55:00+03	6300.00
90C2B9	2017-08-14 08:24:00+03	18800.00
90C2CB	2017-08-03 23:58:00+03	26800.00
90C2F0	2017-08-11 13:20:00+03	19600.00
90C313	2017-08-02 05:35:00+03	46400.00
90C3E3	2017-07-13 21:18:00+03	38400.00
90C3F7	2017-06-29 15:36:00+03	110500.00
90C434	2017-07-30 06:08:00+03	134400.00
90C438	2017-07-07 23:03:00+03	30900.00
90C446	2017-08-12 12:39:00+03	67800.00
90C450	2017-07-03 20:39:00+03	128600.00
90C4C0	2017-08-10 08:22:00+03	100200.00
90C4DB	2017-08-15 00:37:00+03	13400.00
90C50B	2017-07-31 14:07:00+03	46400.00
90C52E	2017-07-14 13:16:00+03	48800.00
90C5DE	2017-07-17 14:48:00+03	56000.00
90C5F8	2017-07-25 05:00:00+03	15000.00
90C64B	2017-08-05 16:00:00+03	46000.00
90C6C7	2017-06-30 01:51:00+03	53000.00
90C727	2017-08-15 11:26:00+03	51200.00
90C739	2017-07-20 20:56:00+03	86500.00
90C796	2017-07-07 11:40:00+03	28800.00
90C85B	2017-07-27 02:13:00+03	38800.00
90C864	2017-08-11 00:33:00+03	11300.00
90C8B2	2017-07-02 17:24:00+03	46000.00
90C8DA	2017-08-10 15:58:00+03	49800.00
90C913	2017-08-03 22:51:00+03	132800.00
90C91F	2017-07-25 03:56:00+03	119900.00
90C934	2017-07-14 12:52:00+03	61900.00
90C97C	2017-08-02 03:14:00+03	35200.00
90CA49	2017-07-02 20:10:00+03	26000.00
90CA6A	2017-07-04 19:14:00+03	99200.00
90CA79	2017-07-29 17:34:00+03	30000.00
90CA82	2017-07-22 22:15:00+03	66600.00
90CAB6	2017-07-31 07:45:00+03	27400.00
90CAB8	2017-08-07 02:41:00+03	13400.00
90CACD	2017-07-27 06:57:00+03	38600.00
90CB3A	2017-07-06 20:53:00+03	153100.00
90CB66	2017-07-07 09:45:00+03	32900.00
90CB8B	2017-07-07 02:45:00+03	184300.00
90CBB1	2017-07-11 02:14:00+03	115900.00
90CBCF	2017-07-28 22:05:00+03	106600.00
90CBEB	2017-07-24 18:24:00+03	29400.00
90CBF2	2017-07-02 21:45:00+03	109600.00
90CC21	2017-07-10 10:43:00+03	48800.00
90CC51	2017-08-11 00:01:00+03	62000.00
90CD0A	2017-08-14 07:34:00+03	47200.00
90CD2A	2017-07-12 23:48:00+03	29400.00
90CD46	2017-07-16 01:06:00+03	100600.00
90CD93	2017-07-21 16:53:00+03	182300.00
90CDA4	2017-07-27 13:08:00+03	14000.00
90CE06	2017-07-09 06:55:00+03	92600.00
90CE14	2017-07-17 17:58:00+03	36200.00
90CE35	2017-07-07 07:06:00+03	186900.00
90CE99	2017-07-09 17:13:00+03	89700.00
90CEA3	2017-07-25 06:45:00+03	47600.00
90CED1	2017-07-05 16:36:00+03	99300.00
90CFF5	2017-07-30 14:21:00+03	291500.00
90D00B	2017-07-11 08:16:00+03	40800.00
90D03B	2017-07-14 07:31:00+03	32700.00
90D055	2017-08-08 00:04:00+03	55800.00
90D07B	2017-07-03 20:20:00+03	40800.00
90D0C1	2017-07-24 03:12:00+03	135400.00
90D124	2017-08-06 23:04:00+03	46700.00
90D148	2017-07-08 17:28:00+03	39800.00
90D19B	2017-08-13 23:39:00+03	54000.00
90D1AA	2017-07-09 17:25:00+03	25600.00
90D1E2	2017-07-24 13:04:00+03	57400.00
90D1E4	2017-08-12 15:37:00+03	25400.00
90D22A	2017-07-13 13:37:00+03	13700.00
90D261	2017-07-30 05:15:00+03	116900.00
90D27D	2017-07-10 04:39:00+03	166000.00
90D2AE	2017-08-14 16:06:00+03	29100.00
90D2B8	2017-07-20 08:32:00+03	47100.00
90D2D3	2017-08-03 21:16:00+03	97900.00
90D383	2017-07-24 13:01:00+03	28800.00
90D3AF	2017-07-26 22:50:00+03	101200.00
90D499	2017-07-05 05:24:00+03	156300.00
90D4D1	2017-08-09 13:24:00+03	21800.00
90D4F6	2017-07-26 02:57:00+03	203600.00
90D503	2017-07-23 13:47:00+03	15400.00
90D59C	2017-06-27 01:40:00+03	83000.00
90D5A6	2017-08-12 11:33:00+03	72000.00
90D5F9	2017-08-15 07:34:00+03	136000.00
90D798	2017-07-30 18:35:00+03	112000.00
90D7D7	2017-07-28 15:10:00+03	152500.00
90D7D8	2017-07-12 12:14:00+03	24800.00
90D7DD	2017-07-15 18:57:00+03	6300.00
90D814	2017-08-10 21:12:00+03	149800.00
90D81D	2017-08-14 16:17:00+03	12100.00
90D8C5	2017-08-08 00:35:00+03	6700.00
90D8D2	2017-08-12 04:58:00+03	147000.00
90D920	2017-07-06 03:50:00+03	52000.00
90D96E	2017-07-07 07:48:00+03	123600.00
90D973	2017-07-20 21:19:00+03	11300.00
90D9C2	2017-07-15 10:03:00+03	106500.00
90D9F4	2017-07-25 18:25:00+03	51900.00
90DA30	2017-07-10 19:39:00+03	54800.00
90DA44	2017-08-07 10:21:00+03	31200.00
90DA8A	2017-08-15 12:15:00+03	10900.00
90DAA8	2017-08-01 14:37:00+03	52700.00
90DAF1	2017-08-07 09:38:00+03	39500.00
90DB0F	2017-07-20 05:42:00+03	37200.00
90DB58	2017-07-01 13:30:00+03	260300.00
90DB63	2017-07-19 05:25:00+03	67800.00
90DBBD	2017-07-31 09:56:00+03	55800.00
90DC6B	2017-07-30 04:52:00+03	23200.00
90DCD3	2017-07-16 20:37:00+03	48800.00
90DD2E	2017-07-21 06:40:00+03	27900.00
90DD78	2017-07-12 00:04:00+03	20400.00
90DDAC	2017-07-20 06:50:00+03	229400.00
90DDB8	2017-08-03 23:11:00+03	53600.00
90DDDC	2017-07-22 15:57:00+03	31800.00
90DE34	2017-07-26 15:10:00+03	93600.00
90DE68	2017-07-07 19:15:00+03	20200.00
90DE7C	2017-08-03 05:12:00+03	133200.00
90DECA	2017-06-28 06:53:00+03	73600.00
90DED4	2017-08-08 14:20:00+03	12600.00
90DED7	2017-07-07 18:16:00+03	188900.00
90DEEB	2017-07-30 23:21:00+03	30200.00
90DF2A	2017-08-15 06:45:00+03	23600.00
90DF6F	2017-07-24 07:51:00+03	65900.00
90E024	2017-07-19 02:20:00+03	113000.00
90E0D7	2017-08-13 20:39:00+03	23400.00
90E157	2017-08-04 08:01:00+03	129200.00
90E198	2017-08-12 19:25:00+03	55800.00
90E19C	2017-07-24 09:40:00+03	569300.00
90E280	2017-08-05 18:13:00+03	49200.00
90E2BB	2017-08-05 06:08:00+03	125200.00
90E313	2017-07-12 22:50:00+03	67000.00
90E33E	2017-08-10 23:55:00+03	64300.00
90E371	2017-07-08 11:57:00+03	98000.00
90E379	2017-07-27 15:03:00+03	12400.00
90E3B6	2017-08-12 23:45:00+03	31200.00
90E482	2017-07-26 15:07:00+03	28000.00
90E528	2017-07-04 11:38:00+03	67900.00
90E55F	2017-08-14 06:02:00+03	119500.00
90E6EA	2017-07-02 21:49:00+03	153300.00
90E769	2017-07-19 23:49:00+03	58800.00
90E78D	2017-07-09 22:18:00+03	139800.00
90E7AC	2017-08-08 17:42:00+03	48800.00
90E7B6	2017-08-03 09:48:00+03	116900.00
90E7CE	2017-07-26 09:38:00+03	36200.00
90E7CF	2017-07-28 09:11:00+03	59100.00
90E810	2017-07-19 21:36:00+03	19600.00
90E954	2017-08-03 02:29:00+03	25000.00
90E975	2017-07-20 03:52:00+03	70900.00
90E982	2017-07-02 01:12:00+03	25400.00
90E9AF	2017-07-18 19:29:00+03	97800.00
90E9F2	2017-07-08 22:38:00+03	67500.00
90EA31	2017-08-05 22:58:00+03	26700.00
90EA3E	2017-06-29 16:02:00+03	114400.00
90EABC	2017-07-03 19:06:00+03	17200.00
90EAE1	2017-07-21 08:36:00+03	61500.00
90EAFA	2017-07-22 10:45:00+03	121600.00
90EB0B	2017-08-01 00:08:00+03	47200.00
90EB6D	2017-08-10 22:54:00+03	39300.00
90EBC6	2017-08-05 02:53:00+03	51000.00
90ECA2	2017-07-23 15:34:00+03	50600.00
90ED01	2017-07-21 06:44:00+03	31600.00
90ED18	2017-08-04 19:59:00+03	39300.00
90ED84	2017-07-27 21:48:00+03	54000.00
90ED8D	2017-08-13 18:21:00+03	63300.00
90EDD0	2017-07-09 09:51:00+03	75300.00
90EE1E	2017-08-07 03:59:00+03	195100.00
90EE50	2017-07-08 05:12:00+03	74000.00
90EE7B	2017-07-13 13:48:00+03	181200.00
90EE87	2017-07-24 00:31:00+03	19600.00
90EEF7	2017-07-10 02:19:00+03	28800.00
90EF5A	2017-07-15 03:12:00+03	44800.00
90EF65	2017-08-08 07:29:00+03	28800.00
90EF94	2017-07-09 03:28:00+03	17000.00
90EF97	2017-08-11 16:52:00+03	171600.00
90F16B	2017-07-28 20:29:00+03	38600.00
90F184	2017-08-06 22:50:00+03	106400.00
90F1C5	2017-08-04 22:48:00+03	33100.00
90F246	2017-07-14 11:43:00+03	28000.00
90F24D	2017-07-08 09:21:00+03	46300.00
90F2CD	2017-07-20 02:44:00+03	138900.00
90F342	2017-07-06 03:49:00+03	279500.00
90F39E	2017-08-14 18:21:00+03	32900.00
90F438	2017-08-13 09:11:00+03	135600.00
90F464	2017-07-18 06:48:00+03	22600.00
90F4AA	2017-08-11 17:24:00+03	61800.00
90F4CF	2017-07-16 00:06:00+03	141300.00
90F4DA	2017-07-27 17:27:00+03	133200.00
90F4E8	2017-07-27 08:23:00+03	28000.00
90F508	2017-07-25 07:14:00+03	96700.00
90F53B	2017-07-16 06:34:00+03	257600.00
90F557	2017-08-06 01:58:00+03	46000.00
90F639	2017-08-13 03:30:00+03	134400.00
90F669	2017-07-22 17:27:00+03	53500.00
90F6B8	2017-07-16 06:40:00+03	91800.00
90F6E7	2017-07-16 09:21:00+03	179400.00
90F704	2017-06-28 03:01:00+03	66600.00
90F749	2017-07-07 06:01:00+03	57600.00
90F799	2017-06-30 12:31:00+03	118800.00
90F850	2017-07-17 06:22:00+03	177200.00
90F856	2017-07-27 15:47:00+03	43200.00
90F88F	2017-08-10 22:23:00+03	53600.00
90F896	2017-07-06 13:14:00+03	61900.00
90F8AE	2017-07-28 02:26:00+03	8400.00
90F8DA	2017-07-09 09:20:00+03	124200.00
90F8FA	2017-08-05 21:16:00+03	57300.00
90F991	2017-07-20 14:40:00+03	69000.00
90F9E0	2017-08-08 03:46:00+03	52800.00
90FA0D	2017-07-03 23:15:00+03	56900.00
90FA67	2017-08-05 09:01:00+03	96200.00
90FB13	2017-08-13 22:26:00+03	188000.00
90FBBF	2017-07-28 22:40:00+03	50800.00
90FBC9	2017-08-06 22:26:00+03	28800.00
90FBF3	2017-08-14 18:28:00+03	38500.00
90FC0E	2017-07-08 08:32:00+03	88800.00
90FC1C	2017-07-27 20:38:00+03	153000.00
90FC4F	2017-07-20 12:26:00+03	179500.00
90FCEF	2017-08-08 09:31:00+03	15400.00
90FDE6	2017-08-09 06:02:00+03	40200.00
90FDEF	2017-07-25 22:14:00+03	12600.00
90FF45	2017-08-03 00:27:00+03	6200.00
90FFC7	2017-07-15 11:30:00+03	36500.00
90FFE8	2017-07-27 06:14:00+03	69500.00
910024	2017-07-26 02:51:00+03	42800.00
910053	2017-06-30 00:53:00+03	55600.00
91008A	2017-07-10 05:23:00+03	14400.00
9100B0	2017-08-07 03:22:00+03	8200.00
91011E	2017-07-16 10:20:00+03	140000.00
910131	2017-07-14 06:57:00+03	178800.00
91017E	2017-08-15 12:37:00+03	128400.00
910242	2017-08-14 22:55:00+03	17300.00
9102EE	2017-07-01 12:38:00+03	39800.00
910308	2017-07-20 00:57:00+03	26000.00
91039A	2017-07-05 09:05:00+03	28000.00
9103B8	2017-07-03 04:59:00+03	58200.00
9103E7	2017-08-13 07:40:00+03	397100.00
91043A	2017-07-08 06:43:00+03	18600.00
91043D	2017-08-01 15:42:00+03	23600.00
91047F	2017-07-14 19:52:00+03	57800.00
9104E3	2017-07-04 04:12:00+03	26000.00
91058D	2017-07-18 01:35:00+03	46400.00
910597	2017-07-28 16:52:00+03	56600.00
9105A1	2017-08-02 19:16:00+03	56100.00
91063C	2017-08-02 15:31:00+03	56000.00
910681	2017-07-30 16:10:00+03	68600.00
9106F3	2017-08-03 08:03:00+03	172100.00
91074C	2017-07-17 07:34:00+03	85000.00
910822	2017-07-08 13:39:00+03	114400.00
910835	2017-07-30 21:46:00+03	45200.00
910859	2017-08-05 06:59:00+03	55800.00
910899	2017-07-12 15:54:00+03	92900.00
9108A1	2017-08-07 09:12:00+03	136600.00
9108B9	2017-07-25 05:08:00+03	20400.00
910907	2017-07-07 22:15:00+03	96800.00
91095C	2017-07-21 19:54:00+03	135400.00
91097F	2017-08-09 20:18:00+03	39200.00
91099B	2017-08-06 07:00:00+03	92900.00
9109AD	2017-07-15 12:37:00+03	28600.00
9109B4	2017-07-08 03:36:00+03	99700.00
9109E0	2017-07-13 13:16:00+03	23600.00
910ACA	2017-08-08 01:41:00+03	13400.00
910AF3	2017-07-27 20:47:00+03	189000.00
910B0D	2017-07-08 09:33:00+03	528600.00
910B10	2017-07-01 00:56:00+03	52100.00
910B15	2017-07-05 11:15:00+03	27500.00
910B2A	2017-07-27 15:33:00+03	46000.00
910B35	2017-08-05 15:16:00+03	42800.00
910BBB	2017-08-07 07:07:00+03	61600.00
910BE0	2017-08-14 06:25:00+03	87400.00
910C15	2017-07-22 06:17:00+03	32200.00
910D2C	2017-08-04 08:40:00+03	81800.00
910D2F	2017-08-12 18:25:00+03	76600.00
910D67	2017-07-07 20:39:00+03	172100.00
910DCA	2017-07-10 08:35:00+03	26000.00
910DCB	2017-06-30 13:00:00+03	98400.00
910E73	2017-08-07 12:30:00+03	40000.00
910F95	2017-07-27 18:18:00+03	25800.00
910F99	2017-08-14 13:57:00+03	50600.00
910FB4	2017-08-07 09:03:00+03	86400.00
910FF5	2017-07-10 19:54:00+03	369000.00
910FF8	2017-08-02 17:13:00+03	496600.00
911012	2017-08-08 17:10:00+03	246000.00
911039	2017-07-19 19:40:00+03	117400.00
911081	2017-07-03 19:06:00+03	56600.00
9110C0	2017-07-29 11:10:00+03	40600.00
91114B	2017-07-24 05:15:00+03	240600.00
91118F	2017-08-10 05:10:00+03	65100.00
9111AF	2017-07-09 10:19:00+03	52900.00
9111BA	2017-07-01 14:38:00+03	86600.00
91121C	2017-07-28 06:09:00+03	44000.00
911227	2017-08-06 12:24:00+03	48800.00
91130C	2017-07-30 19:38:00+03	78400.00
911393	2017-08-02 15:20:00+03	58800.00
9113BB	2017-07-04 07:32:00+03	43800.00
911401	2017-07-08 01:47:00+03	135400.00
91141A	2017-07-15 05:13:00+03	76800.00
911432	2017-07-23 07:06:00+03	46300.00
91143D	2017-08-15 09:30:00+03	12600.00
911483	2017-08-03 12:55:00+03	52700.00
91148D	2017-07-14 07:20:00+03	38600.00
911493	2017-07-09 07:57:00+03	57600.00
911499	2017-07-01 12:52:00+03	38800.00
91154B	2017-08-15 03:24:00+03	86500.00
911555	2017-08-14 04:07:00+03	58800.00
9115F0	2017-08-09 22:00:00+03	191400.00
9116DB	2017-08-03 23:48:00+03	201800.00
9116EF	2017-07-31 23:25:00+03	289800.00
9116F2	2017-08-13 08:09:00+03	74300.00
91177D	2017-07-06 22:40:00+03	61600.00
9117C6	2017-07-18 02:53:00+03	24700.00
911915	2017-07-25 10:58:00+03	56600.00
91197F	2017-07-04 09:52:00+03	67600.00
911984	2017-08-09 11:06:00+03	136200.00
91199D	2017-08-06 07:06:00+03	85200.00
9119EC	2017-08-13 05:20:00+03	21800.00
9119F1	2017-07-15 13:00:00+03	51300.00
911A2F	2017-07-31 13:26:00+03	46400.00
911A48	2017-08-08 21:49:00+03	6800.00
911A59	2017-08-01 15:47:00+03	89600.00
911A5E	2017-08-11 08:06:00+03	31200.00
911A96	2017-07-16 15:04:00+03	24400.00
911ACF	2017-07-17 13:09:00+03	26000.00
911AD0	2017-08-09 04:57:00+03	30800.00
911AE4	2017-08-13 05:33:00+03	153300.00
911B07	2017-08-13 15:15:00+03	46300.00
911B4C	2017-08-02 03:29:00+03	26700.00
911B98	2017-08-03 22:50:00+03	73400.00
911BB3	2017-07-25 15:05:00+03	117700.00
911C78	2017-07-06 21:53:00+03	72400.00
911C91	2017-07-31 15:48:00+03	286100.00
911CBD	2017-08-12 12:43:00+03	28800.00
911D03	2017-08-04 16:02:00+03	138000.00
911D1B	2017-08-09 02:30:00+03	73600.00
911D1C	2017-07-29 07:03:00+03	98400.00
911D84	2017-07-31 10:38:00+03	39400.00
911E1E	2017-07-15 07:44:00+03	81300.00
911E84	2017-08-15 13:51:00+03	40000.00
911EBC	2017-08-06 22:21:00+03	90000.00
911EC5	2017-07-29 10:18:00+03	28000.00
911F83	2017-08-02 18:29:00+03	46400.00
91200C	2017-07-29 04:49:00+03	56100.00
912012	2017-07-19 03:26:00+03	136800.00
912031	2017-07-23 03:20:00+03	17600.00
91204C	2017-07-17 23:52:00+03	23600.00
912058	2017-06-29 07:10:00+03	55800.00
912104	2017-07-13 13:47:00+03	47100.00
91210F	2017-07-10 04:32:00+03	31400.00
912161	2017-07-05 17:14:00+03	117600.00
9121A9	2017-08-15 04:29:00+03	40000.00
91229B	2017-07-27 18:15:00+03	28000.00
9122AE	2017-08-02 01:40:00+03	55800.00
9122B9	2017-08-13 14:58:00+03	23200.00
91231E	2017-08-13 09:48:00+03	84100.00
912377	2017-08-07 14:30:00+03	39500.00
912385	2017-08-15 15:07:00+03	120800.00
9123BC	2017-07-26 01:39:00+03	72400.00
9123DB	2017-07-01 08:27:00+03	23400.00
9123F8	2017-08-10 16:28:00+03	123000.00
912402	2017-07-10 19:09:00+03	119400.00
912426	2017-07-13 09:55:00+03	6700.00
912427	2017-08-06 16:54:00+03	20800.00
91245F	2017-08-03 00:43:00+03	9200.00
9124B3	2017-07-25 11:02:00+03	38500.00
9124C6	2017-08-02 15:25:00+03	290500.00
9124D4	2017-08-10 02:08:00+03	16400.00
912510	2017-08-12 11:03:00+03	57500.00
912547	2017-07-08 08:35:00+03	199400.00
912641	2017-07-20 15:51:00+03	38800.00
912658	2017-07-11 13:32:00+03	25000.00
912662	2017-08-10 02:12:00+03	103900.00
9126A3	2017-07-28 17:25:00+03	96800.00
91272F	2017-08-15 17:16:00+03	223200.00
91273B	2017-07-18 18:56:00+03	26400.00
912774	2017-08-14 12:28:00+03	159200.00
9127A9	2017-07-16 07:58:00+03	57500.00
9127AD	2017-07-27 20:37:00+03	14800.00
9127B6	2017-07-08 07:09:00+03	28000.00
9127C3	2017-08-07 05:20:00+03	28800.00
9127C4	2017-07-27 00:26:00+03	40800.00
9127D9	2017-08-14 15:19:00+03	79800.00
912823	2017-07-31 06:47:00+03	301800.00
91282F	2017-07-19 11:34:00+03	8200.00
9128B4	2017-07-16 07:05:00+03	233800.00
91296A	2017-08-04 22:38:00+03	27400.00
91296D	2017-08-02 01:05:00+03	173600.00
912989	2017-08-15 13:09:00+03	10800.00
9129C2	2017-07-04 02:19:00+03	40800.00
9129CD	2017-07-04 04:06:00+03	81400.00
9129D3	2017-07-23 17:41:00+03	8400.00
9129FF	2017-08-10 17:35:00+03	206400.00
912A23	2017-07-22 19:44:00+03	64600.00
912A9D	2017-08-12 08:50:00+03	28800.00
912AD6	2017-07-18 03:52:00+03	28800.00
912AFA	2017-08-04 20:04:00+03	28800.00
912B7F	2017-08-13 08:05:00+03	28000.00
912C57	2017-07-04 17:38:00+03	77200.00
912CB0	2017-08-04 07:22:00+03	30200.00
912CDE	2017-08-05 03:46:00+03	26800.00
912D2E	2017-07-08 03:02:00+03	33100.00
912D8C	2017-07-29 13:38:00+03	161200.00
912DFF	2017-08-14 12:45:00+03	29800.00
912E45	2017-07-22 01:14:00+03	57600.00
912E51	2017-07-25 21:40:00+03	25800.00
912E87	2017-08-15 17:36:00+03	36100.00
912EA4	2017-06-27 02:08:00+03	172300.00
912EE0	2017-08-11 02:42:00+03	89600.00
912F17	2017-08-01 12:08:00+03	115900.00
912F5E	2017-08-06 07:41:00+03	46400.00
912FA1	2017-07-16 08:31:00+03	286100.00
913120	2017-08-03 10:50:00+03	122300.00
913138	2017-07-10 22:48:00+03	59000.00
913149	2017-07-02 15:36:00+03	28700.00
913165	2017-06-30 11:58:00+03	28000.00
913194	2017-07-19 04:58:00+03	25600.00
9131F3	2017-07-06 19:30:00+03	123000.00
9131F6	2017-07-26 06:32:00+03	246000.00
913202	2017-08-06 22:40:00+03	15700.00
913279	2017-08-15 01:50:00+03	509800.00
9132DA	2017-07-24 07:02:00+03	161200.00
9132F6	2017-07-24 02:21:00+03	94200.00
91331D	2017-08-04 03:16:00+03	123000.00
913374	2017-07-07 14:15:00+03	14000.00
9133AE	2017-07-31 06:49:00+03	60400.00
9133B8	2017-07-21 03:07:00+03	67200.00
913404	2017-07-28 23:14:00+03	14400.00
91342F	2017-07-18 11:45:00+03	123600.00
913431	2017-08-13 05:55:00+03	22000.00
913433	2017-07-02 05:47:00+03	24800.00
913497	2017-07-24 04:01:00+03	147400.00
9134FF	2017-07-18 08:02:00+03	48500.00
913510	2017-07-28 22:03:00+03	85000.00
9135D7	2017-07-07 18:34:00+03	29500.00
9135F5	2017-07-22 20:27:00+03	45200.00
91360F	2017-07-29 23:08:00+03	48800.00
913627	2017-08-08 09:09:00+03	53300.00
913676	2017-07-05 02:07:00+03	88800.00
91369D	2017-08-07 04:22:00+03	8200.00
9136BA	2017-06-30 19:50:00+03	140900.00
9136CF	2017-08-04 10:24:00+03	112600.00
9136E5	2017-07-27 18:18:00+03	47100.00
91370A	2017-07-19 18:32:00+03	134800.00
913740	2017-07-13 09:31:00+03	77000.00
913789	2017-08-03 16:34:00+03	88900.00
913792	2017-07-12 17:03:00+03	143000.00
9137C7	2017-07-09 06:58:00+03	123700.00
913809	2017-07-27 19:37:00+03	56100.00
913837	2017-08-11 22:12:00+03	78100.00
9138D2	2017-08-14 08:43:00+03	62700.00
9138DD	2017-07-26 07:29:00+03	132800.00
9138FC	2017-07-15 18:04:00+03	65900.00
91390D	2017-07-21 02:55:00+03	57400.00
913917	2017-07-02 06:58:00+03	166100.00
913959	2017-07-22 19:32:00+03	22400.00
9139CF	2017-07-29 21:36:00+03	92400.00
913A07	2017-07-16 07:36:00+03	13800.00
913A5A	2017-08-12 00:48:00+03	113700.00
913B18	2017-08-14 16:35:00+03	34000.00
913B3C	2017-07-10 06:00:00+03	20800.00
913B4B	2017-07-15 04:51:00+03	16400.00
913B51	2017-08-09 20:39:00+03	73300.00
913B5A	2017-08-03 06:17:00+03	39600.00
913B5C	2017-07-30 06:42:00+03	54400.00
913B63	2017-07-13 10:19:00+03	94200.00
913B90	2017-07-11 11:42:00+03	48400.00
913BA6	2017-06-30 15:29:00+03	18600.00
913BBE	2017-07-13 07:40:00+03	38800.00
913BDA	2017-07-13 18:28:00+03	89700.00
913C0C	2017-08-12 21:40:00+03	59800.00
913C1C	2017-08-05 23:16:00+03	25200.00
913C3A	2017-08-13 06:23:00+03	219200.00
913C41	2017-07-10 02:52:00+03	185600.00
913C81	2017-08-14 05:27:00+03	74000.00
913CC9	2017-07-25 14:55:00+03	81600.00
913CD5	2017-07-09 06:00:00+03	213200.00
913D06	2017-07-31 05:52:00+03	20600.00
913D12	2017-07-01 15:59:00+03	28800.00
913D41	2017-08-06 01:43:00+03	206400.00
913D4D	2017-08-10 10:04:00+03	67300.00
913D71	2017-07-14 09:54:00+03	43100.00
913DB9	2017-07-01 06:18:00+03	28800.00
913DBC	2017-07-14 13:10:00+03	152900.00
913DEC	2017-08-09 00:53:00+03	90000.00
913E31	2017-07-31 03:40:00+03	58400.00
913E34	2017-07-20 00:30:00+03	10600.00
913E6A	2017-08-15 10:55:00+03	61800.00
913E6F	2017-08-14 17:20:00+03	21400.00
913EC8	2017-07-29 15:02:00+03	46400.00
913ED9	2017-07-06 22:26:00+03	18800.00
913F2D	2017-07-06 15:40:00+03	120100.00
913F3F	2017-07-19 00:31:00+03	12600.00
913F57	2017-07-05 11:51:00+03	184600.00
913F89	2017-07-20 01:58:00+03	271100.00
913FBB	2017-07-22 05:47:00+03	123200.00
913FC0	2017-07-29 05:42:00+03	36200.00
913FE5	2017-08-14 19:28:00+03	59200.00
914002	2017-08-14 13:56:00+03	67600.00
914009	2017-08-01 17:06:00+03	8200.00
914021	2017-07-18 18:37:00+03	12400.00
914026	2017-07-15 23:50:00+03	51900.00
914044	2017-07-30 23:46:00+03	84000.00
914057	2017-07-10 04:21:00+03	101200.00
91411D	2017-08-02 22:40:00+03	26000.00
914138	2017-07-21 07:35:00+03	111600.00
914147	2017-07-26 06:21:00+03	131600.00
9141AA	2017-08-11 21:00:00+03	83600.00
9141D6	2017-08-10 08:55:00+03	18600.00
9141DA	2017-07-21 17:22:00+03	188000.00
91421E	2017-07-31 02:12:00+03	23600.00
91423E	2017-08-11 20:56:00+03	133200.00
91426F	2017-07-28 18:13:00+03	36200.00
9142B1	2017-08-04 02:40:00+03	8200.00
9142F4	2017-07-17 18:16:00+03	51600.00
91431E	2017-08-03 00:05:00+03	184300.00
91433C	2017-08-01 16:37:00+03	28000.00
91435A	2017-07-27 03:56:00+03	23600.00
914370	2017-07-30 21:19:00+03	65300.00
9143A3	2017-07-04 09:31:00+03	146000.00
91440C	2017-06-30 07:25:00+03	56000.00
91444B	2017-07-09 04:19:00+03	177600.00
91445B	2017-07-23 20:14:00+03	214200.00
9144A8	2017-07-01 13:34:00+03	99300.00
914510	2017-08-14 10:35:00+03	6700.00
914546	2017-08-12 20:25:00+03	64800.00
914597	2017-08-14 06:34:00+03	21300.00
914598	2017-07-31 20:19:00+03	59100.00
9145F1	2017-08-05 12:13:00+03	246000.00
914657	2017-08-15 07:59:00+03	37200.00
914693	2017-08-14 10:03:00+03	229400.00
9146AC	2017-07-23 05:14:00+03	55800.00
9146BD	2017-08-14 17:34:00+03	77800.00
914716	2017-07-21 00:13:00+03	37700.00
914725	2017-07-21 10:48:00+03	56100.00
91474A	2017-07-22 10:43:00+03	6300.00
914753	2017-08-07 07:43:00+03	38000.00
914777	2017-07-02 07:01:00+03	28000.00
914793	2017-07-15 13:03:00+03	120400.00
914803	2017-07-15 14:58:00+03	39200.00
914806	2017-08-13 14:44:00+03	195100.00
91490F	2017-06-30 00:10:00+03	101200.00
914971	2017-07-30 20:26:00+03	34000.00
914998	2017-08-14 12:01:00+03	46000.00
9149F7	2017-07-09 19:29:00+03	31400.00
914A54	2017-07-16 18:42:00+03	26000.00
914A81	2017-07-28 11:13:00+03	49700.00
914AAA	2017-07-13 23:29:00+03	112000.00
914ACD	2017-07-17 09:56:00+03	156500.00
914B13	2017-07-19 20:28:00+03	199400.00
914B3C	2017-07-31 23:04:00+03	53600.00
914B4A	2017-08-14 01:09:00+03	121500.00
914B6D	2017-07-05 09:57:00+03	10800.00
914B7A	2017-07-21 14:02:00+03	41200.00
914B7E	2017-07-03 01:02:00+03	173600.00
914C17	2017-06-29 12:48:00+03	38100.00
914C79	2017-08-14 14:41:00+03	49600.00
914CB2	2017-08-14 17:14:00+03	29600.00
914D32	2017-08-05 14:00:00+03	139800.00
914D9C	2017-07-22 02:15:00+03	40000.00
914DAC	2017-07-31 20:18:00+03	13600.00
914DAF	2017-07-09 09:27:00+03	16400.00
914DE6	2017-07-28 21:36:00+03	28000.00
914DE8	2017-07-31 23:43:00+03	28000.00
914E15	2017-08-07 01:28:00+03	123000.00
914E5F	2017-07-15 22:49:00+03	79000.00
914ED3	2017-07-12 21:27:00+03	46200.00
914EEC	2017-08-12 18:08:00+03	51900.00
914F03	2017-07-13 05:05:00+03	6700.00
914F7E	2017-07-03 08:28:00+03	6800.00
914FA4	2017-08-12 00:38:00+03	20200.00
914FDD	2017-08-08 12:55:00+03	14000.00
915005	2017-08-12 07:27:00+03	70600.00
915008	2017-07-10 20:12:00+03	131600.00
91503B	2017-07-07 17:04:00+03	135600.00
91507D	2017-08-15 07:36:00+03	16400.00
915095	2017-07-10 00:40:00+03	38600.00
91509A	2017-08-15 17:02:00+03	47200.00
915123	2017-08-13 11:12:00+03	260900.00
915176	2017-07-04 23:02:00+03	54800.00
9151C6	2017-08-09 01:36:00+03	170800.00
9151C7	2017-07-16 10:55:00+03	31700.00
9151DA	2017-07-27 02:47:00+03	61100.00
9151E6	2017-07-01 16:36:00+03	52000.00
9151FB	2017-07-08 00:43:00+03	68400.00
91525F	2017-08-13 01:52:00+03	14300.00
91534C	2017-07-21 16:30:00+03	44000.00
915356	2017-07-13 13:57:00+03	406100.00
915399	2017-08-04 13:44:00+03	23200.00
9153A7	2017-07-19 14:13:00+03	84100.00
9153C7	2017-07-10 10:04:00+03	46500.00
9153E4	2017-08-13 01:39:00+03	108000.00
91540E	2017-08-09 20:29:00+03	14800.00
915474	2017-07-05 01:03:00+03	129700.00
915495	2017-07-05 01:49:00+03	28000.00
9154C6	2017-08-01 19:47:00+03	39500.00
9154E6	2017-08-05 14:37:00+03	67400.00
91556A	2017-08-15 08:15:00+03	118600.00
915590	2017-07-10 21:55:00+03	24600.00
9155E9	2017-07-14 03:34:00+03	77500.00
91563A	2017-07-16 22:29:00+03	34800.00
9156B2	2017-07-30 07:48:00+03	64500.00
9156C5	2017-07-31 20:32:00+03	24000.00
915701	2017-08-10 18:35:00+03	56900.00
915713	2017-07-21 16:20:00+03	6700.00
915746	2017-07-26 11:39:00+03	133200.00
91574C	2017-08-10 17:23:00+03	14800.00
915793	2017-08-04 20:47:00+03	51800.00
915798	2017-08-15 10:15:00+03	17800.00
9157AA	2017-07-15 16:04:00+03	28800.00
9157D2	2017-08-06 16:48:00+03	26000.00
915813	2017-07-14 03:31:00+03	130100.00
91582D	2017-08-08 17:55:00+03	9800.00
915890	2017-07-10 20:07:00+03	130700.00
9158C3	2017-07-07 15:03:00+03	38200.00
915919	2017-07-20 15:39:00+03	39300.00
91591D	2017-06-28 06:21:00+03	92600.00
915922	2017-07-19 00:19:00+03	81800.00
9159AE	2017-07-04 19:07:00+03	288600.00
915A03	2017-07-14 07:58:00+03	70200.00
915A19	2017-07-29 03:57:00+03	115700.00
915A20	2017-07-23 19:34:00+03	63200.00
915A48	2017-07-18 03:31:00+03	27300.00
915A9E	2017-06-29 23:25:00+03	54000.00
915AF1	2017-08-15 02:07:00+03	86000.00
915B26	2017-07-28 04:38:00+03	126300.00
915B35	2017-07-08 22:34:00+03	46000.00
915B36	2017-08-06 01:32:00+03	20800.00
915B61	2017-06-30 06:00:00+03	35200.00
915BAF	2017-07-12 09:42:00+03	114700.00
915C1B	2017-07-10 23:42:00+03	58500.00
915C78	2017-08-04 12:55:00+03	51800.00
915CFC	2017-08-07 13:53:00+03	136600.00
915D47	2017-08-03 14:22:00+03	55800.00
915D68	2017-07-15 12:57:00+03	181600.00
915DA3	2017-07-11 08:39:00+03	52900.00
915DA5	2017-08-05 21:49:00+03	40400.00
915DB8	2017-07-11 19:55:00+03	47000.00
915DC8	2017-07-16 09:17:00+03	131300.00
915E31	2017-08-02 15:07:00+03	114800.00
915EE8	2017-08-11 07:52:00+03	61100.00
915EF0	2017-07-09 17:29:00+03	12000.00
915F83	2017-07-18 03:56:00+03	20100.00
915FA3	2017-07-14 11:54:00+03	33600.00
915FE3	2017-07-20 02:40:00+03	116700.00
91608E	2017-07-07 15:36:00+03	67200.00
9160C1	2017-08-03 08:01:00+03	47400.00
9160E0	2017-07-27 15:54:00+03	28800.00
916130	2017-08-04 05:04:00+03	48500.00
916172	2017-07-13 20:32:00+03	113200.00
916197	2017-07-09 11:48:00+03	30200.00
9161AA	2017-07-16 05:36:00+03	99300.00
9161E1	2017-07-31 04:08:00+03	135400.00
9161FD	2017-08-03 06:15:00+03	32700.00
91623A	2017-07-13 06:25:00+03	46000.00
91625F	2017-07-18 04:02:00+03	32700.00
916271	2017-07-20 07:07:00+03	116000.00
9162A3	2017-07-03 00:31:00+03	159000.00
9162AB	2017-07-02 19:13:00+03	89600.00
9162CC	2017-08-05 16:22:00+03	86400.00
9162E0	2017-07-28 04:59:00+03	96800.00
9162F5	2017-08-07 00:23:00+03	34000.00
91632D	2017-07-29 13:23:00+03	118200.00
916456	2017-08-12 07:10:00+03	33100.00
91647E	2017-08-04 11:47:00+03	372500.00
9164AD	2017-07-20 23:35:00+03	199700.00
9164B6	2017-08-14 02:43:00+03	139100.00
916503	2017-07-29 21:39:00+03	170500.00
91650D	2017-08-15 07:20:00+03	43200.00
916519	2017-07-18 02:03:00+03	30200.00
916530	2017-07-05 01:36:00+03	70500.00
916535	2017-08-03 06:19:00+03	80200.00
916542	2017-07-04 06:52:00+03	106900.00
916553	2017-08-08 10:49:00+03	13700.00
916567	2017-08-07 21:33:00+03	18000.00
916705	2017-07-30 20:24:00+03	43000.00
9167B6	2017-08-01 19:53:00+03	7400.00
9167C8	2017-07-22 14:49:00+03	35800.00
91687B	2017-07-21 11:13:00+03	12600.00
916883	2017-07-23 02:17:00+03	53500.00
916885	2017-07-30 16:58:00+03	43500.00
916889	2017-07-23 07:37:00+03	115900.00
91693C	2017-07-07 19:16:00+03	33300.00
916968	2017-07-28 09:23:00+03	67700.00
9169E2	2017-08-15 17:53:00+03	398500.00
9169E7	2017-08-06 03:02:00+03	8000.00
916A00	2017-08-06 06:01:00+03	53400.00
916A0C	2017-07-27 07:51:00+03	23600.00
916A39	2017-08-10 01:05:00+03	75600.00
916A69	2017-07-21 14:10:00+03	49100.00
916A8D	2017-08-09 17:46:00+03	21800.00
916A9C	2017-07-06 20:13:00+03	7900.00
916AFA	2017-08-02 09:34:00+03	156500.00
916B40	2017-07-07 21:29:00+03	56000.00
916B8C	2017-07-22 21:40:00+03	393800.00
916C20	2017-07-19 11:34:00+03	129700.00
916C2E	2017-08-13 21:37:00+03	66600.00
916C53	2017-07-06 00:57:00+03	28000.00
916C76	2017-07-24 23:07:00+03	39100.00
916C94	2017-07-20 21:05:00+03	73200.00
916C98	2017-08-06 21:49:00+03	23200.00
916CE7	2017-08-08 18:57:00+03	17200.00
916D1E	2017-08-15 08:32:00+03	52300.00
916D6A	2017-07-08 21:23:00+03	72600.00
916D71	2017-07-20 05:17:00+03	15400.00
916D98	2017-07-26 21:21:00+03	41200.00
916DB0	2017-07-15 13:24:00+03	31400.00
916DE9	2017-07-05 08:07:00+03	43200.00
916E42	2017-07-30 21:59:00+03	28800.00
916E9C	2017-07-01 04:04:00+03	94800.00
916EAB	2017-07-27 18:05:00+03	55600.00
916F32	2017-07-09 15:06:00+03	13400.00
916F5A	2017-07-09 03:31:00+03	40400.00
916F71	2017-07-05 18:04:00+03	53600.00
916FBE	2017-08-05 12:28:00+03	103800.00
916FF8	2017-07-18 00:59:00+03	51900.00
917078	2017-08-03 20:02:00+03	34100.00
9170AD	2017-08-12 07:32:00+03	56000.00
9170DC	2017-08-06 02:50:00+03	24000.00
917120	2017-07-06 06:31:00+03	98800.00
91713E	2017-08-03 18:21:00+03	29600.00
917187	2017-07-07 18:30:00+03	189800.00
91719B	2017-07-20 01:10:00+03	106400.00
9171A8	2017-07-29 11:34:00+03	92900.00
9171E0	2017-08-02 02:25:00+03	257600.00
917260	2017-07-02 08:16:00+03	28800.00
9173C7	2017-07-29 08:58:00+03	159100.00
917400	2017-08-04 06:53:00+03	20200.00
91741F	2017-07-23 18:27:00+03	25200.00
91743F	2017-08-15 03:45:00+03	42700.00
9174DA	2017-07-10 17:27:00+03	56000.00
917500	2017-07-23 17:05:00+03	14400.00
91752F	2017-07-25 02:54:00+03	67600.00
917595	2017-08-10 15:27:00+03	16000.00
9175A6	2017-07-25 19:18:00+03	335000.00
9175EA	2017-07-22 22:39:00+03	78200.00
9175FC	2017-07-02 14:53:00+03	49400.00
917627	2017-08-04 00:26:00+03	26000.00
917633	2017-07-16 19:11:00+03	61300.00
917650	2017-07-28 08:23:00+03	92600.00
9176E8	2017-07-15 09:26:00+03	73300.00
9176E9	2017-07-18 05:10:00+03	13400.00
917715	2017-08-10 14:24:00+03	26000.00
917734	2017-07-14 19:25:00+03	135400.00
91777B	2017-07-20 21:17:00+03	66600.00
917786	2017-08-10 15:40:00+03	57700.00
9177A2	2017-07-06 15:30:00+03	18000.00
9177F8	2017-07-13 06:00:00+03	66600.00
917823	2017-06-30 23:12:00+03	153600.00
917841	2017-07-04 15:51:00+03	14400.00
917842	2017-07-14 05:15:00+03	135200.00
917864	2017-07-27 07:00:00+03	94300.00
9178A0	2017-07-17 05:04:00+03	91200.00
9178E4	2017-07-17 22:55:00+03	24400.00
917989	2017-08-15 15:47:00+03	13700.00
9179F0	2017-07-25 15:21:00+03	291000.00
9179F7	2017-07-21 07:43:00+03	72200.00
917A11	2017-07-13 01:49:00+03	39500.00
917A21	2017-08-12 03:32:00+03	28300.00
917A2B	2017-08-09 10:20:00+03	31200.00
917A30	2017-07-28 02:31:00+03	38600.00
917A36	2017-07-03 03:29:00+03	40300.00
917AB5	2017-08-15 15:56:00+03	56000.00
917B49	2017-07-14 04:02:00+03	248400.00
917BA5	2017-08-02 16:03:00+03	134400.00
917BC8	2017-07-23 03:28:00+03	26800.00
917C1E	2017-07-28 15:57:00+03	97800.00
917C2F	2017-07-11 13:07:00+03	298600.00
917C76	2017-08-08 01:38:00+03	88500.00
917CFB	2017-08-13 04:23:00+03	70600.00
917D4E	2017-07-31 02:59:00+03	529100.00
917E25	2017-08-09 16:46:00+03	58200.00
917EBC	2017-08-02 16:10:00+03	248400.00
917EF5	2017-07-05 11:05:00+03	54000.00
917F24	2017-07-31 17:28:00+03	148200.00
917F29	2017-07-06 14:27:00+03	89600.00
917F8A	2017-07-14 01:42:00+03	15800.00
91807F	2017-07-16 13:56:00+03	15100.00
9180DB	2017-07-23 22:03:00+03	54500.00
9180F6	2017-07-26 03:42:00+03	521400.00
918105	2017-07-17 02:41:00+03	45100.00
918108	2017-08-14 07:14:00+03	28000.00
91811C	2017-08-04 21:57:00+03	20600.00
91819A	2017-08-04 00:08:00+03	100600.00
9181CF	2017-07-09 01:56:00+03	23600.00
9181E4	2017-07-06 23:59:00+03	190400.00
918255	2017-07-04 00:51:00+03	65300.00
91825B	2017-08-14 01:55:00+03	25200.00
91827C	2017-08-05 00:04:00+03	23400.00
918339	2017-07-27 19:18:00+03	38600.00
9183D1	2017-06-27 12:49:00+03	125400.00
91842F	2017-07-19 17:18:00+03	75600.00
91845F	2017-07-21 15:38:00+03	28800.00
91847D	2017-08-06 23:06:00+03	83500.00
918488	2017-07-16 10:59:00+03	42900.00
9184CC	2017-08-06 18:14:00+03	31100.00
9184DB	2017-08-02 12:18:00+03	29600.00
91850E	2017-07-15 19:48:00+03	88500.00
91853A	2017-07-15 12:55:00+03	14400.00
918582	2017-07-27 00:57:00+03	19200.00
9185A5	2017-07-05 08:05:00+03	43200.00
9185CA	2017-08-04 12:38:00+03	18700.00
9185D4	2017-07-24 18:45:00+03	37200.00
9185F5	2017-07-01 04:36:00+03	14900.00
9185F8	2017-08-14 01:22:00+03	23200.00
918640	2017-07-15 11:31:00+03	167400.00
9187A4	2017-07-26 12:59:00+03	234100.00
9187BE	2017-07-16 21:00:00+03	48300.00
9187EA	2017-07-23 18:55:00+03	39300.00
9187FD	2017-08-04 23:19:00+03	29600.00
918892	2017-07-24 05:42:00+03	36200.00
91892B	2017-07-22 14:03:00+03	142300.00
918973	2017-07-26 18:51:00+03	43900.00
918975	2017-07-26 08:11:00+03	16400.00
9189CF	2017-07-20 21:13:00+03	147100.00
9189D0	2017-07-29 03:35:00+03	96800.00
918A18	2017-08-05 10:49:00+03	66600.00
918A3D	2017-08-09 14:49:00+03	26000.00
918A5B	2017-08-04 05:21:00+03	99200.00
918A7B	2017-07-23 15:22:00+03	45100.00
918AED	2017-08-12 17:59:00+03	117000.00
918AF4	2017-07-22 12:52:00+03	9200.00
918B1A	2017-07-28 19:58:00+03	25200.00
918C39	2017-07-25 15:15:00+03	119700.00
918CAF	2017-07-24 15:01:00+03	410200.00
918CC1	2017-08-03 20:45:00+03	28000.00
918CC3	2017-07-31 14:10:00+03	10800.00
918CCC	2017-07-09 22:12:00+03	48800.00
918CDE	2017-08-01 17:59:00+03	89600.00
918DB9	2017-06-29 12:40:00+03	86500.00
918DC1	2017-07-17 02:39:00+03	24300.00
918E2A	2017-07-03 16:32:00+03	29000.00
918E3E	2017-07-27 20:57:00+03	16800.00
918E4A	2017-08-13 06:39:00+03	28300.00
918E6A	2017-08-08 19:23:00+03	33200.00
918E7E	2017-08-15 00:37:00+03	12600.00
918E95	2017-08-14 10:26:00+03	532800.00
918E9C	2017-07-15 07:48:00+03	24400.00
918F0F	2017-07-16 11:42:00+03	29600.00
918F46	2017-08-01 05:27:00+03	156600.00
918FAA	2017-07-14 09:45:00+03	168700.00
918FBB	2017-07-16 01:58:00+03	6000.00
91902A	2017-07-08 11:38:00+03	57600.00
91904C	2017-07-27 07:11:00+03	219300.00
919097	2017-08-05 06:53:00+03	20400.00
91910E	2017-07-05 22:35:00+03	40600.00
919182	2017-07-17 00:04:00+03	28800.00
919185	2017-08-01 10:54:00+03	136200.00
9191A7	2017-08-03 10:02:00+03	119500.00
9191C2	2017-06-30 11:25:00+03	26200.00
9191E6	2017-08-01 01:46:00+03	70600.00
9191FC	2017-07-08 12:56:00+03	109600.00
91923B	2017-07-03 10:10:00+03	73500.00
919292	2017-07-24 20:04:00+03	21800.00
919294	2017-08-07 08:43:00+03	84500.00
919383	2017-08-06 05:03:00+03	28000.00
919433	2017-07-27 14:01:00+03	131100.00
91945A	2017-07-08 11:54:00+03	135200.00
919486	2017-08-07 01:46:00+03	38600.00
919492	2017-07-09 03:52:00+03	85000.00
9194FA	2017-08-15 00:07:00+03	86300.00
91956F	2017-08-14 19:23:00+03	406700.00
919571	2017-08-12 19:23:00+03	14400.00
9195E1	2017-07-29 05:00:00+03	468500.00
9195E3	2017-08-10 22:01:00+03	40800.00
919600	2017-08-08 01:08:00+03	56000.00
9196C2	2017-07-21 08:37:00+03	186000.00
9196C5	2017-07-06 04:06:00+03	36100.00
91974C	2017-07-09 00:53:00+03	136500.00
919766	2017-07-19 19:42:00+03	28800.00
91977C	2017-07-07 23:25:00+03	42900.00
91978F	2017-08-01 08:11:00+03	13400.00
9197FC	2017-08-08 14:21:00+03	88600.00
919854	2017-08-10 15:53:00+03	26000.00
9198E1	2017-07-16 12:32:00+03	59800.00
9198FD	2017-08-06 03:30:00+03	86600.00
919985	2017-07-08 05:04:00+03	92000.00
9199C0	2017-08-08 08:52:00+03	13400.00
919A11	2017-08-05 20:58:00+03	57500.00
919AB5	2017-08-05 11:33:00+03	59000.00
919B20	2017-08-06 12:52:00+03	47200.00
919BA1	2017-08-13 04:42:00+03	266400.00
919C37	2017-07-19 17:07:00+03	62900.00
919C86	2017-07-20 12:04:00+03	73200.00
919C9C	2017-08-11 17:15:00+03	27200.00
919C9F	2017-07-25 00:08:00+03	15900.00
919CBA	2017-07-11 10:01:00+03	55900.00
919CF8	2017-07-16 09:21:00+03	135400.00
919D02	2017-08-03 06:28:00+03	167900.00
919D60	2017-08-12 03:38:00+03	34400.00
919D7E	2017-07-29 01:15:00+03	133200.00
919D82	2017-08-01 20:55:00+03	78500.00
919DDF	2017-08-02 19:12:00+03	21800.00
919E16	2017-07-20 12:26:00+03	46000.00
919E5F	2017-08-08 20:12:00+03	23200.00
919ED1	2017-07-02 22:56:00+03	96300.00
919F0B	2017-07-02 16:33:00+03	54300.00
919FAA	2017-08-04 11:43:00+03	19800.00
919FF6	2017-08-06 08:28:00+03	44000.00
91A062	2017-07-02 21:53:00+03	28800.00
91A092	2017-07-04 02:19:00+03	23200.00
91A094	2017-07-28 00:31:00+03	87000.00
91A0BC	2017-07-28 17:44:00+03	37300.00
91A0FF	2017-07-22 05:02:00+03	40800.00
91A108	2017-07-01 00:02:00+03	23200.00
91A136	2017-07-23 04:45:00+03	169600.00
91A165	2017-08-10 16:27:00+03	112600.00
91A1AD	2017-07-25 08:26:00+03	54500.00
91A1E2	2017-08-05 03:02:00+03	20200.00
91A1FA	2017-08-10 02:35:00+03	94800.00
91A218	2017-07-22 03:16:00+03	147200.00
91A2A8	2017-08-08 20:13:00+03	42000.00
91A2B3	2017-08-06 19:31:00+03	21000.00
91A409	2017-08-09 16:39:00+03	46200.00
91A414	2017-07-03 06:19:00+03	49800.00
91A41D	2017-07-10 21:51:00+03	141300.00
91A45D	2017-07-24 21:22:00+03	78800.00
91A4AE	2017-07-11 22:42:00+03	41400.00
91A4F1	2017-07-09 05:44:00+03	148800.00
91A4F2	2017-07-05 01:19:00+03	33300.00
91A524	2017-08-08 23:30:00+03	12600.00
91A529	2017-07-29 06:29:00+03	24400.00
91A552	2017-07-09 20:13:00+03	91100.00
91A586	2017-08-14 01:13:00+03	73600.00
91A623	2017-07-12 07:55:00+03	67700.00
91A65C	2017-07-03 17:15:00+03	54000.00
91A688	2017-07-08 19:40:00+03	46400.00
91A6D8	2017-07-11 01:08:00+03	89800.00
91A6E4	2017-07-23 04:35:00+03	116400.00
91A71E	2017-07-31 12:43:00+03	21400.00
91A75C	2017-07-28 05:53:00+03	44500.00
91A795	2017-07-23 07:41:00+03	51900.00
91A7E4	2017-07-03 11:22:00+03	21400.00
91A850	2017-07-24 11:45:00+03	161900.00
91A86F	2017-07-18 01:00:00+03	21800.00
91A87D	2017-07-24 20:11:00+03	27900.00
91A8BC	2017-08-04 14:43:00+03	167400.00
91A8BE	2017-07-05 00:27:00+03	118600.00
91A912	2017-07-22 12:30:00+03	47100.00
91A94E	2017-07-17 01:38:00+03	39500.00
91A98C	2017-07-25 10:07:00+03	43700.00
91A9EC	2017-07-31 09:53:00+03	28000.00
91AA19	2017-07-14 17:34:00+03	35600.00
91AAB2	2017-07-03 08:08:00+03	125800.00
91AAB9	2017-06-24 20:01:00+03	62600.00
91AAE2	2017-07-28 22:56:00+03	28800.00
91AC0F	2017-07-12 11:47:00+03	65900.00
91AC72	2017-07-23 16:21:00+03	23400.00
91AC9D	2017-07-16 23:05:00+03	93600.00
91ACD3	2017-08-15 15:22:00+03	77600.00
91AD4D	2017-07-04 19:20:00+03	100800.00
91ADCE	2017-07-22 14:12:00+03	55800.00
91ADD7	2017-07-23 15:33:00+03	31800.00
91ADF5	2017-08-01 00:44:00+03	19100.00
91AE1D	2017-07-07 02:38:00+03	27200.00
91AE98	2017-07-22 04:27:00+03	67600.00
91AEE2	2017-07-13 06:26:00+03	8400.00
91AF4C	2017-07-24 16:32:00+03	47000.00
91B030	2017-07-15 17:15:00+03	14000.00
91B044	2017-08-05 04:44:00+03	39300.00
91B0A7	2017-08-06 23:26:00+03	184200.00
91B0CC	2017-07-17 21:36:00+03	21400.00
91B148	2017-07-04 22:40:00+03	111600.00
91B15A	2017-07-25 01:15:00+03	50800.00
91B160	2017-07-10 10:58:00+03	28000.00
91B17D	2017-08-14 04:26:00+03	286700.00
91B1A6	2017-07-05 08:25:00+03	73900.00
91B1AA	2017-07-10 14:19:00+03	179300.00
91B1B9	2017-07-05 22:51:00+03	67600.00
91B1D6	2017-07-28 21:17:00+03	13700.00
91B276	2017-07-18 18:07:00+03	232200.00
91B2A2	2017-07-19 10:08:00+03	40800.00
91B2C5	2017-08-03 03:47:00+03	23100.00
91B2CA	2017-07-14 17:55:00+03	46800.00
91B2DC	2017-07-07 21:11:00+03	21400.00
91B30F	2017-07-17 14:00:00+03	56000.00
91B365	2017-07-16 14:52:00+03	24400.00
91B39D	2017-07-05 20:09:00+03	131200.00
91B3AB	2017-07-20 20:51:00+03	28000.00
91B3D5	2017-08-08 14:17:00+03	133700.00
91B3F0	2017-07-19 11:31:00+03	103500.00
91B455	2017-08-09 08:26:00+03	31600.00
91B479	2017-07-30 23:24:00+03	25100.00
91B48C	2017-07-04 12:42:00+03	39800.00
91B48E	2017-07-30 02:34:00+03	28700.00
91B4E2	2017-08-01 11:46:00+03	101100.00
91B4F5	2017-08-09 07:46:00+03	106000.00
91B552	2017-07-15 09:54:00+03	67100.00
91B57A	2017-07-30 09:28:00+03	14800.00
91B58B	2017-07-03 18:08:00+03	24200.00
91B5D8	2017-07-17 14:56:00+03	14400.00
91B602	2017-07-22 01:27:00+03	14000.00
91B691	2017-07-29 18:29:00+03	205700.00
91B6C5	2017-07-31 08:45:00+03	270000.00
91B75D	2017-07-29 03:20:00+03	118900.00
91B775	2017-08-06 07:51:00+03	23200.00
91B793	2017-07-13 19:52:00+03	30000.00
91B83E	2017-06-30 13:08:00+03	23600.00
91B85A	2017-08-01 16:39:00+03	135400.00
91B88F	2017-07-20 20:49:00+03	246000.00
91B8FD	2017-07-30 14:21:00+03	154500.00
91B92A	2017-07-28 02:53:00+03	72300.00
91B939	2017-07-05 05:17:00+03	83700.00
91B96E	2017-07-16 00:21:00+03	33100.00
91B987	2017-07-14 08:03:00+03	133200.00
91B9DD	2017-07-10 06:32:00+03	73300.00
91BA1B	2017-08-14 00:58:00+03	119300.00
91BA37	2017-08-08 01:43:00+03	406100.00
91BA3C	2017-07-09 01:54:00+03	149300.00
91BA9E	2017-07-16 16:16:00+03	40800.00
91BADF	2017-07-22 08:56:00+03	63200.00
91BAEE	2017-07-03 01:39:00+03	156600.00
91BB3D	2017-08-13 18:39:00+03	87100.00
91BB92	2017-07-11 16:16:00+03	52000.00
91BBCB	2017-07-19 17:10:00+03	43200.00
91BC5C	2017-08-09 01:37:00+03	809100.00
91BCE6	2017-07-01 17:39:00+03	89000.00
91BD01	2017-07-06 13:09:00+03	116400.00
91BDA5	2017-08-03 18:50:00+03	21800.00
91BE09	2017-07-17 11:42:00+03	14400.00
91BF1A	2017-08-13 15:56:00+03	7400.00
91BF1C	2017-07-25 14:01:00+03	272600.00
91BFAD	2017-08-04 17:12:00+03	191200.00
91BFBF	2017-07-11 14:21:00+03	49800.00
91C083	2017-07-08 20:23:00+03	88100.00
91C0B2	2017-08-04 00:47:00+03	23200.00
91C0D4	2017-08-12 03:10:00+03	15000.00
91C106	2017-07-07 17:56:00+03	14400.00
91C116	2017-07-20 07:40:00+03	246000.00
91C117	2017-08-02 21:49:00+03	29200.00
91C15F	2017-08-05 07:36:00+03	35600.00
91C1B6	2017-07-04 22:01:00+03	75300.00
91C1CE	2017-07-11 16:23:00+03	119700.00
91C1D9	2017-08-12 21:57:00+03	88500.00
91C266	2017-07-31 22:14:00+03	26000.00
91C2D7	2017-07-18 07:13:00+03	117700.00
91C31B	2017-07-24 19:42:00+03	13400.00
91C323	2017-08-13 15:48:00+03	66600.00
91C364	2017-07-15 12:57:00+03	26000.00
91C3BC	2017-08-06 02:38:00+03	45200.00
91C40A	2017-07-17 04:44:00+03	55800.00
91C44A	2017-07-13 22:10:00+03	57600.00
91C44F	2017-07-08 22:57:00+03	62600.00
91C460	2017-08-01 13:46:00+03	28800.00
91C46C	2017-08-14 15:50:00+03	149200.00
91C488	2017-07-14 01:16:00+03	99200.00
91C49A	2017-07-17 14:31:00+03	39200.00
91C4FD	2017-08-14 03:23:00+03	148200.00
91C534	2017-07-09 00:39:00+03	32800.00
91C5AE	2017-07-04 13:58:00+03	346700.00
91C5BE	2017-07-24 05:53:00+03	67600.00
91C5CF	2017-08-04 07:05:00+03	66600.00
91C63B	2017-07-27 01:33:00+03	45200.00
91C68D	2017-06-26 04:42:00+03	40800.00
91C695	2017-07-07 22:54:00+03	89600.00
91C6AB	2017-07-11 15:36:00+03	65500.00
91C749	2017-07-22 21:31:00+03	24000.00
91C772	2017-08-07 19:53:00+03	40800.00
91C786	2017-07-01 19:14:00+03	445100.00
91C822	2017-08-08 20:30:00+03	28000.00
91C8A0	2017-07-06 15:45:00+03	34000.00
91C923	2017-07-03 05:20:00+03	21400.00
91C93D	2017-08-01 01:39:00+03	11600.00
91C97E	2017-07-30 03:40:00+03	55400.00
91C98E	2017-08-01 06:05:00+03	86500.00
91C9F6	2017-07-24 19:29:00+03	184300.00
91CA0E	2017-07-19 13:47:00+03	61800.00
91CA36	2017-07-27 19:39:00+03	28000.00
91CA45	2017-07-30 00:26:00+03	81700.00
91CA77	2017-08-11 00:32:00+03	86600.00
91CAED	2017-07-04 22:19:00+03	24200.00
91CB22	2017-08-13 18:18:00+03	137400.00
91CB86	2017-07-21 15:18:00+03	152400.00
91CBB4	2017-07-10 17:23:00+03	26000.00
91CBB7	2017-07-21 08:20:00+03	88600.00
91CC1F	2017-07-27 21:04:00+03	266400.00
91CC6E	2017-07-28 23:03:00+03	133700.00
91CD0A	2017-07-07 18:07:00+03	11700.00
91CD42	2017-08-06 18:03:00+03	46200.00
91CD47	2017-07-26 02:24:00+03	12600.00
91CDC2	2017-08-02 10:46:00+03	92800.00
91CDE0	2017-08-13 02:41:00+03	80100.00
91CEC4	2017-07-27 04:49:00+03	135400.00
91CEC9	2017-08-05 22:05:00+03	24200.00
91CF26	2017-08-03 09:19:00+03	24300.00
91CF3B	2017-07-21 12:39:00+03	60700.00
91CF3C	2017-07-18 06:24:00+03	286100.00
91CFF5	2017-08-09 09:03:00+03	86800.00
91D07B	2017-07-15 19:30:00+03	12400.00
91D0B8	2017-08-06 18:46:00+03	18400.00
91D111	2017-07-17 01:33:00+03	61800.00
91D13B	2017-07-14 17:21:00+03	56000.00
91D13F	2017-07-14 16:22:00+03	21800.00
91D150	2017-07-26 14:06:00+03	54000.00
91D173	2017-08-13 23:48:00+03	39500.00
91D1A0	2017-07-31 18:24:00+03	7400.00
91D1AF	2017-08-13 05:43:00+03	81900.00
91D1CA	2017-07-27 21:30:00+03	113200.00
91D1EB	2017-07-30 05:50:00+03	135400.00
91D266	2017-07-11 00:38:00+03	73300.00
91D2AD	2017-07-16 11:02:00+03	39500.00
91D2E9	2017-07-16 06:23:00+03	53500.00
91D2FD	2017-07-10 17:14:00+03	38200.00
91D35B	2017-08-11 09:56:00+03	35400.00
91D377	2017-07-01 07:22:00+03	105600.00
91D3E6	2017-07-17 19:19:00+03	134800.00
91D40C	2017-07-20 22:34:00+03	89600.00
91D464	2017-07-03 05:57:00+03	45200.00
91D499	2017-07-30 21:57:00+03	47000.00
91D4C8	2017-07-19 11:05:00+03	43500.00
91D4D3	2017-07-02 21:04:00+03	201200.00
91D4EC	2017-07-03 18:23:00+03	24700.00
91D528	2017-07-22 22:07:00+03	19600.00
91D535	2017-07-20 22:55:00+03	64400.00
91D584	2017-08-12 23:32:00+03	173600.00
91D5E2	2017-08-02 01:10:00+03	242600.00
91D62E	2017-07-15 06:10:00+03	56900.00
91D67E	2017-07-26 06:41:00+03	46800.00
91D695	2017-07-12 00:47:00+03	111600.00
91D6E8	2017-08-15 09:25:00+03	50500.00
91D722	2017-08-01 14:53:00+03	12600.00
91D72A	2017-07-28 06:31:00+03	65800.00
91D73E	2017-07-02 20:35:00+03	23100.00
91D763	2017-07-09 07:23:00+03	83400.00
91D77F	2017-07-07 08:39:00+03	74100.00
91D7B1	2017-07-28 20:02:00+03	57500.00
91D82B	2017-07-30 23:33:00+03	23600.00
91D888	2017-07-22 22:28:00+03	30700.00
91D89F	2017-08-13 03:02:00+03	92600.00
91D8ED	2017-07-06 14:02:00+03	54800.00
91D932	2017-08-13 01:07:00+03	85600.00
91D950	2017-07-18 15:23:00+03	13400.00
91D954	2017-07-13 18:46:00+03	6200.00
91D97A	2017-08-09 13:04:00+03	66600.00
91D9F8	2017-08-08 00:19:00+03	25100.00
91DA86	2017-07-26 22:07:00+03	167400.00
91DAA6	2017-07-26 17:58:00+03	109800.00
91DAC3	2017-07-19 16:02:00+03	93800.00
91DAD0	2017-06-27 12:24:00+03	6000.00
91DAEA	2017-08-11 14:53:00+03	123000.00
91DB25	2017-08-09 04:39:00+03	20200.00
91DBC6	2017-08-03 06:22:00+03	119500.00
91DBEE	2017-07-24 20:35:00+03	300700.00
91DC16	2017-08-05 00:04:00+03	120400.00
91DC38	2017-07-28 06:18:00+03	156300.00
91DC41	2017-07-17 20:08:00+03	30200.00
91DC48	2017-08-12 20:56:00+03	86000.00
91DCFF	2017-07-11 04:21:00+03	34400.00
91DD09	2017-07-15 23:41:00+03	56000.00
91DD2C	2017-07-11 16:31:00+03	42800.00
91DD5E	2017-07-28 19:41:00+03	62600.00
91DDE0	2017-08-10 17:44:00+03	92100.00
91DDF3	2017-07-11 01:50:00+03	40000.00
91DE33	2017-08-15 04:16:00+03	21500.00
91DE55	2017-08-05 16:07:00+03	84500.00
91DEC2	2017-07-08 15:57:00+03	47600.00
91DEF6	2017-07-10 23:55:00+03	145100.00
91DF1E	2017-07-18 03:47:00+03	48800.00
91DF38	2017-07-07 04:19:00+03	189200.00
91DF5C	2017-07-27 21:37:00+03	6300.00
91DFA5	2017-07-18 21:28:00+03	59200.00
91E01E	2017-08-01 19:06:00+03	48100.00
91E065	2017-07-26 22:21:00+03	115800.00
91E0FF	2017-07-02 13:50:00+03	67000.00
91E1D6	2017-06-28 11:49:00+03	136200.00
91E1E2	2017-08-14 07:02:00+03	33400.00
91E22E	2017-07-08 20:44:00+03	118700.00
91E271	2017-07-18 03:01:00+03	121400.00
91E2C6	2017-08-07 08:16:00+03	70700.00
91E321	2017-08-02 17:54:00+03	12400.00
91E333	2017-07-01 02:40:00+03	10700.00
91E38E	2017-07-03 03:24:00+03	89200.00
91E460	2017-07-23 10:23:00+03	17800.00
91E474	2017-07-20 14:33:00+03	67800.00
91E4C6	2017-07-14 21:47:00+03	72400.00
91E4F7	2017-06-27 01:31:00+03	27200.00
91E57C	2017-07-07 13:02:00+03	7400.00
91E5A3	2017-06-30 16:15:00+03	56000.00
91E5B6	2017-07-15 00:55:00+03	13600.00
91E5E1	2017-07-18 19:53:00+03	8200.00
91E5F7	2017-07-04 15:05:00+03	123000.00
91E640	2017-07-22 22:38:00+03	26800.00
91E65F	2017-08-05 07:41:00+03	677700.00
91E687	2017-07-25 10:30:00+03	52800.00
91E69C	2017-08-13 08:08:00+03	56600.00
91E6B6	2017-07-09 11:16:00+03	369000.00
91E6B8	2017-07-21 11:56:00+03	28000.00
91E7BE	2017-07-14 13:07:00+03	123000.00
91E7FC	2017-08-15 01:25:00+03	28800.00
91E814	2017-07-24 13:00:00+03	6000.00
91E8B2	2017-07-09 02:38:00+03	139400.00
91E8D2	2017-08-08 15:07:00+03	46000.00
91E8FC	2017-07-03 22:15:00+03	136800.00
91E938	2017-08-09 12:19:00+03	21400.00
91E96E	2017-07-05 00:15:00+03	176800.00
91E9A4	2017-07-16 06:12:00+03	66000.00
91EAC0	2017-07-19 13:46:00+03	69500.00
91EB22	2017-08-04 10:04:00+03	83700.00
91EB32	2017-07-14 11:02:00+03	14800.00
91EBBC	2017-07-22 21:24:00+03	27200.00
91EBEC	2017-07-03 09:57:00+03	58200.00
91EBFB	2017-07-12 03:57:00+03	136700.00
91EC0A	2017-07-30 13:11:00+03	118500.00
91EC43	2017-07-02 15:53:00+03	135400.00
91EC48	2017-07-03 11:58:00+03	98000.00
91EC58	2017-07-02 22:45:00+03	58600.00
91EC8B	2017-08-10 23:04:00+03	189200.00
91ECF3	2017-07-29 21:31:00+03	55600.00
91ED3A	2017-08-11 17:48:00+03	92900.00
91EDA8	2017-07-15 02:16:00+03	194300.00
91EDBC	2017-07-18 15:49:00+03	52100.00
91EDE0	2017-07-20 14:34:00+03	179500.00
91EE04	2017-07-08 07:53:00+03	25400.00
91EE08	2017-08-06 00:51:00+03	231800.00
91EE3B	2017-08-14 01:22:00+03	62000.00
91EF2B	2017-07-05 12:47:00+03	40800.00
91EF3A	2017-07-15 21:07:00+03	28000.00
91EF50	2017-07-06 14:47:00+03	75300.00
91EF66	2017-07-14 06:54:00+03	99200.00
91EF6E	2017-07-18 16:49:00+03	14000.00
91EFA5	2017-07-13 12:23:00+03	23200.00
91F05A	2017-07-29 22:28:00+03	323900.00
91F070	2017-08-01 08:29:00+03	28300.00
91F0B1	2017-07-12 21:58:00+03	27800.00
91F232	2017-07-29 03:50:00+03	46300.00
91F2AC	2017-07-01 14:57:00+03	119600.00
91F2AE	2017-07-23 01:17:00+03	29600.00
91F2B4	2017-07-04 03:07:00+03	99200.00
91F2D0	2017-07-21 22:44:00+03	22400.00
91F373	2017-07-26 16:13:00+03	116400.00
91F394	2017-07-07 21:50:00+03	68800.00
91F41C	2017-07-19 20:03:00+03	24000.00
91F43F	2017-07-10 13:01:00+03	29400.00
91F447	2017-07-01 15:37:00+03	23200.00
91F45D	2017-07-19 05:34:00+03	37100.00
91F46B	2017-07-27 04:05:00+03	32900.00
91F48C	2017-08-05 01:04:00+03	177200.00
91F496	2017-07-17 08:47:00+03	40600.00
91F4FF	2017-08-07 10:41:00+03	103800.00
91F51F	2017-07-03 00:48:00+03	98100.00
91F520	2017-08-15 00:23:00+03	13400.00
91F54D	2017-07-29 12:39:00+03	12400.00
91F55C	2017-07-04 13:57:00+03	23200.00
91F587	2017-08-01 08:26:00+03	94400.00
91F5BC	2017-07-30 21:44:00+03	64500.00
91F5D3	2017-07-09 17:57:00+03	26000.00
91F5E5	2017-08-07 10:10:00+03	38600.00
91F71B	2017-07-13 19:59:00+03	103500.00
91F71D	2017-08-06 06:23:00+03	44100.00
91F7A7	2017-07-02 13:24:00+03	174900.00
91F7BD	2017-08-05 10:22:00+03	46800.00
91F844	2017-07-06 10:57:00+03	65500.00
91F881	2017-07-23 09:53:00+03	17000.00
91F89B	2017-08-05 20:06:00+03	91800.00
91F8A5	2017-08-11 17:18:00+03	13600.00
91F8DD	2017-07-17 06:24:00+03	55800.00
91F968	2017-08-07 23:37:00+03	82800.00
91F9CB	2017-08-06 03:41:00+03	55800.00
91F9EB	2017-07-09 08:52:00+03	98300.00
91FA0F	2017-07-03 17:01:00+03	137600.00
91FA84	2017-08-03 03:56:00+03	27200.00
91FA8E	2017-08-11 23:19:00+03	123000.00
91FAB0	2017-07-15 16:28:00+03	58800.00
91FACA	2017-07-29 07:04:00+03	31800.00
91FACB	2017-08-13 15:40:00+03	21500.00
91FAD3	2017-07-23 12:47:00+03	50800.00
91FB35	2017-07-14 00:14:00+03	12600.00
91FB7D	2017-07-19 15:34:00+03	28000.00
91FB94	2017-07-08 11:07:00+03	131300.00
91FBAB	2017-08-04 11:14:00+03	65100.00
91FBAD	2017-07-29 03:56:00+03	28200.00
91FBB5	2017-07-29 04:40:00+03	122300.00
91FC1B	2017-07-17 20:25:00+03	26000.00
91FC31	2017-07-26 13:14:00+03	95200.00
91FC67	2017-07-02 17:06:00+03	89700.00
91FC74	2017-07-08 18:02:00+03	38600.00
91FD16	2017-07-01 22:16:00+03	234800.00
91FDD5	2017-07-18 20:21:00+03	265700.00
91FE28	2017-08-10 14:15:00+03	88000.00
91FE2C	2017-08-01 01:08:00+03	77500.00
91FE67	2017-08-10 23:56:00+03	8000.00
91FE7A	2017-07-12 08:20:00+03	130300.00
91FEA8	2017-08-09 09:30:00+03	14800.00
91FEBB	2017-07-07 07:32:00+03	88900.00
91FEC7	2017-07-31 05:17:00+03	93000.00
91FEDB	2017-07-22 12:41:00+03	117600.00
91FEF5	2017-08-02 16:10:00+03	119800.00
91FF17	2017-08-05 04:36:00+03	54800.00
91FF5F	2017-07-14 10:08:00+03	19600.00
91FF6A	2017-07-18 22:09:00+03	28800.00
91FF80	2017-08-03 13:26:00+03	65900.00
91FFBF	2017-08-07 20:23:00+03	44800.00
91FFD1	2017-08-10 23:56:00+03	50000.00
91FFD7	2017-08-13 00:46:00+03	68400.00
92001B	2017-07-14 21:55:00+03	86300.00
920029	2017-08-10 21:16:00+03	41400.00
92002E	2017-07-18 03:28:00+03	174400.00
92005F	2017-08-15 03:27:00+03	73300.00
9200ED	2017-07-06 04:03:00+03	57400.00
920117	2017-07-24 16:31:00+03	46300.00
920161	2017-07-08 20:03:00+03	28000.00
9201E6	2017-08-02 21:06:00+03	160200.00
920269	2017-08-05 02:47:00+03	88900.00
92027C	2017-08-03 16:02:00+03	26700.00
9202B6	2017-07-08 19:20:00+03	6800.00
92033B	2017-08-09 06:11:00+03	23400.00
920354	2017-07-27 10:35:00+03	32800.00
92036B	2017-07-02 23:32:00+03	87100.00
920375	2017-06-28 13:38:00+03	40800.00
920389	2017-08-10 23:24:00+03	6000.00
9203B1	2017-07-20 11:13:00+03	91600.00
9203DB	2017-07-21 04:03:00+03	99200.00
920427	2017-06-29 13:51:00+03	13000.00
920436	2017-07-30 04:50:00+03	59800.00
920439	2017-07-28 03:21:00+03	61800.00
92043D	2017-07-14 06:29:00+03	88400.00
92044B	2017-06-30 05:35:00+03	92000.00
92046B	2017-07-06 01:41:00+03	41000.00
9204AE	2017-07-04 20:19:00+03	124800.00
9204C0	2017-08-14 14:17:00+03	59800.00
9204C8	2017-07-14 13:03:00+03	62600.00
9204E0	2017-08-12 12:51:00+03	65900.00
9204F8	2017-07-08 20:08:00+03	354500.00
920512	2017-07-26 01:02:00+03	83200.00
92051A	2017-08-08 00:14:00+03	56000.00
9205AA	2017-07-03 07:41:00+03	147200.00
9205C4	2017-07-31 10:44:00+03	89600.00
9205C8	2017-07-21 05:24:00+03	12400.00
9205CD	2017-08-08 01:33:00+03	266200.00
9205FA	2017-07-23 15:20:00+03	20400.00
92062A	2017-07-02 05:48:00+03	38800.00
920705	2017-08-10 17:42:00+03	85000.00
92075B	2017-08-04 10:29:00+03	52000.00
9207DF	2017-07-28 06:21:00+03	133100.00
9207FD	2017-07-31 04:55:00+03	82100.00
920841	2017-06-30 16:57:00+03	40600.00
920855	2017-07-18 09:18:00+03	49400.00
92088B	2017-08-02 23:32:00+03	28000.00
92089D	2017-07-14 20:51:00+03	131100.00
920922	2017-08-12 23:17:00+03	22000.00
920977	2017-07-27 19:49:00+03	111000.00
92099B	2017-07-08 02:35:00+03	24400.00
920A19	2017-07-18 12:18:00+03	89700.00
920A5B	2017-08-08 19:08:00+03	308400.00
920A7E	2017-07-01 21:00:00+03	58000.00
920A81	2017-07-19 05:43:00+03	26000.00
920AD9	2017-07-02 08:37:00+03	56000.00
920B33	2017-07-04 02:15:00+03	101200.00
920B41	2017-07-25 10:39:00+03	134700.00
920B5C	2017-08-10 23:31:00+03	94000.00
920B5D	2017-08-07 03:19:00+03	72400.00
920BAE	2017-07-15 06:54:00+03	29400.00
920BC9	2017-08-03 07:05:00+03	13500.00
920BFD	2017-07-05 17:07:00+03	27300.00
920BFF	2017-07-09 10:43:00+03	51300.00
920C36	2017-07-11 14:47:00+03	23200.00
920D2C	2017-08-12 16:35:00+03	539400.00
920D40	2017-08-11 18:02:00+03	8200.00
920D46	2017-07-26 07:30:00+03	25000.00
920D7D	2017-08-06 18:39:00+03	101200.00
920DBA	2017-07-10 02:17:00+03	24400.00
920DCB	2017-08-05 04:59:00+03	27600.00
920DEC	2017-08-08 16:39:00+03	46700.00
920E1B	2017-07-13 21:12:00+03	31400.00
920E52	2017-07-16 12:16:00+03	12600.00
920E6C	2017-07-01 04:53:00+03	8000.00
920E6D	2017-08-07 18:25:00+03	26600.00
920EB7	2017-08-13 00:43:00+03	6700.00
920EE7	2017-08-01 06:02:00+03	116400.00
920F17	2017-07-23 00:20:00+03	67100.00
920FBB	2017-07-20 21:26:00+03	23600.00
920FEE	2017-06-30 11:42:00+03	44000.00
921038	2017-07-05 04:07:00+03	27800.00
92103B	2017-07-17 18:33:00+03	744600.00
921044	2017-07-17 20:44:00+03	88800.00
92107D	2017-07-01 21:48:00+03	184300.00
9210CC	2017-08-11 14:07:00+03	25600.00
9210E4	2017-07-26 15:31:00+03	19000.00
921101	2017-08-12 17:27:00+03	24400.00
9212BD	2017-07-24 12:39:00+03	199600.00
921329	2017-07-28 14:02:00+03	47600.00
92132E	2017-07-07 04:41:00+03	92400.00
921367	2017-07-19 13:42:00+03	57500.00
921397	2017-08-05 23:09:00+03	226800.00
9213B4	2017-07-14 10:09:00+03	159500.00
921439	2017-08-05 13:52:00+03	66600.00
921491	2017-07-15 06:54:00+03	79300.00
921504	2017-07-06 15:21:00+03	26800.00
921536	2017-07-29 01:59:00+03	254900.00
921541	2017-07-24 01:57:00+03	45200.00
9215B8	2017-08-14 12:54:00+03	246000.00
92160E	2017-07-20 04:44:00+03	55800.00
921635	2017-07-12 14:26:00+03	48900.00
9216D4	2017-07-21 14:11:00+03	38800.00
9216DD	2017-07-07 12:19:00+03	303500.00
9216E0	2017-08-04 04:55:00+03	272900.00
9217B3	2017-07-17 08:34:00+03	18800.00
9217D2	2017-07-04 00:01:00+03	28000.00
9217DD	2017-07-12 19:31:00+03	56000.00
921813	2017-07-25 19:28:00+03	62800.00
921826	2017-07-16 14:08:00+03	31600.00
92188F	2017-08-10 12:39:00+03	80300.00
9218BA	2017-07-20 20:11:00+03	44800.00
9218CD	2017-08-03 13:50:00+03	48800.00
9218F8	2017-07-24 10:47:00+03	95200.00
921958	2017-08-10 11:45:00+03	88500.00
9219CB	2017-07-16 13:44:00+03	86400.00
9219CD	2017-07-26 10:58:00+03	16800.00
921A09	2017-07-02 10:27:00+03	123000.00
921A9C	2017-07-06 21:20:00+03	25600.00
921B8F	2017-07-22 06:23:00+03	20200.00
921BEA	2017-07-18 22:32:00+03	56000.00
921CE6	2017-07-06 17:53:00+03	62000.00
921D4F	2017-07-06 23:15:00+03	54800.00
921D8C	2017-08-14 11:57:00+03	26000.00
921DE9	2017-07-24 14:28:00+03	70500.00
921DF5	2017-07-09 02:03:00+03	37200.00
921E02	2017-07-06 12:59:00+03	39500.00
921E17	2017-07-30 12:23:00+03	37100.00
921E46	2017-07-12 11:19:00+03	61800.00
921EA7	2017-07-28 19:52:00+03	89200.00
921EAF	2017-08-08 09:40:00+03	55800.00
921F04	2017-07-24 00:13:00+03	40800.00
921F40	2017-08-15 07:06:00+03	240600.00
921F9F	2017-06-30 22:23:00+03	21600.00
921FC3	2017-07-27 22:20:00+03	34100.00
921FF9	2017-07-30 03:42:00+03	63200.00
922029	2017-07-09 21:55:00+03	37200.00
92203E	2017-07-24 15:11:00+03	64300.00
922099	2017-07-07 05:40:00+03	46200.00
92216A	2017-07-09 16:17:00+03	6000.00
9221A5	2017-08-02 11:03:00+03	167400.00
9221A9	2017-08-04 00:37:00+03	255600.00
922204	2017-08-13 18:43:00+03	46300.00
92228C	2017-07-05 16:54:00+03	15800.00
9222CF	2017-07-22 23:17:00+03	36200.00
9222F6	2017-08-13 13:47:00+03	132800.00
922322	2017-07-02 05:01:00+03	266400.00
922347	2017-08-09 13:26:00+03	35600.00
92234F	2017-08-08 09:41:00+03	46300.00
922356	2017-07-10 18:13:00+03	78300.00
922381	2017-08-08 18:55:00+03	56000.00
922386	2017-07-31 07:06:00+03	70700.00
9223F3	2017-08-10 17:34:00+03	38800.00
922490	2017-07-31 15:17:00+03	14000.00
922492	2017-07-22 19:55:00+03	143100.00
922598	2017-07-13 21:40:00+03	133200.00
9225A7	2017-07-28 10:53:00+03	11600.00
9225DE	2017-07-05 20:10:00+03	80700.00
922655	2017-07-30 13:42:00+03	260300.00
92267A	2017-06-29 14:53:00+03	123000.00
9226A6	2017-08-09 01:02:00+03	399600.00
9226D6	2017-07-18 12:02:00+03	58000.00
92273F	2017-07-24 16:33:00+03	78100.00
92275D	2017-07-16 18:49:00+03	55800.00
92280B	2017-07-31 20:42:00+03	23200.00
92281D	2017-07-14 08:05:00+03	100400.00
92286B	2017-07-07 08:21:00+03	34100.00
9228B6	2017-08-15 01:58:00+03	89200.00
9228EF	2017-07-19 20:22:00+03	56100.00
922910	2017-07-15 23:06:00+03	154500.00
92294C	2017-07-12 02:41:00+03	122500.00
9229D4	2017-07-10 01:53:00+03	14800.00
922A13	2017-07-18 16:25:00+03	47000.00
922A40	2017-07-05 12:13:00+03	136200.00
922A81	2017-07-18 03:15:00+03	123000.00
922B00	2017-08-02 13:49:00+03	46400.00
922B05	2017-07-06 23:35:00+03	47100.00
922B5E	2017-07-17 07:39:00+03	100000.00
922BD8	2017-07-02 04:14:00+03	70500.00
922BDB	2017-07-26 21:59:00+03	178000.00
922C1D	2017-07-30 05:51:00+03	69500.00
922DFB	2017-07-07 09:39:00+03	43500.00
922E4F	2017-07-11 20:44:00+03	16400.00
922F08	2017-07-16 19:55:00+03	94800.00
922F22	2017-07-07 03:50:00+03	170900.00
922F63	2017-07-10 19:53:00+03	40800.00
922FF3	2017-08-02 17:46:00+03	20200.00
923019	2017-07-08 02:04:00+03	369000.00
92309C	2017-07-08 00:09:00+03	54600.00
9230CB	2017-08-10 23:48:00+03	26400.00
9230D0	2017-08-10 00:15:00+03	166900.00
923108	2017-07-19 00:13:00+03	155900.00
92312D	2017-07-04 05:52:00+03	179400.00
9231DB	2017-07-17 22:58:00+03	88300.00
923251	2017-08-13 11:56:00+03	44800.00
9232E1	2017-07-08 21:24:00+03	88800.00
923342	2017-07-13 16:06:00+03	266400.00
923386	2017-08-12 06:56:00+03	55800.00
92339F	2017-07-29 18:45:00+03	89600.00
9233D5	2017-07-06 18:50:00+03	25100.00
923402	2017-07-15 22:51:00+03	43500.00
923415	2017-07-05 16:43:00+03	51900.00
923447	2017-07-03 03:19:00+03	28800.00
92344A	2017-07-21 08:33:00+03	123000.00
9234A1	2017-08-01 07:15:00+03	104600.00
9234A8	2017-07-24 13:31:00+03	21800.00
9234B6	2017-07-15 07:08:00+03	16300.00
923558	2017-07-21 11:44:00+03	133100.00
9235E2	2017-07-10 04:20:00+03	27200.00
9235E6	2017-08-07 19:40:00+03	26000.00
923605	2017-08-09 09:26:00+03	43500.00
923655	2017-07-21 17:56:00+03	40800.00
9236BA	2017-08-10 08:55:00+03	77500.00
9236FA	2017-07-25 20:35:00+03	57400.00
923703	2017-08-03 18:06:00+03	57500.00
92375E	2017-07-21 02:26:00+03	46000.00
92378D	2017-07-03 09:47:00+03	99600.00
9237B0	2017-08-07 06:46:00+03	12600.00
9237B3	2017-08-07 15:38:00+03	74800.00
9237C7	2017-07-21 07:51:00+03	68000.00
9237F4	2017-08-06 03:51:00+03	94200.00
923864	2017-08-14 10:36:00+03	420600.00
92387F	2017-07-03 19:06:00+03	6900.00
923893	2017-07-24 15:36:00+03	212300.00
92392C	2017-07-06 09:22:00+03	144400.00
92392D	2017-08-05 10:21:00+03	66600.00
923934	2017-07-23 01:11:00+03	74200.00
92394F	2017-07-26 03:13:00+03	47200.00
92395A	2017-07-12 10:20:00+03	32700.00
9239BE	2017-08-01 13:53:00+03	312000.00
9239CF	2017-07-02 10:50:00+03	588800.00
923A19	2017-08-04 10:29:00+03	100600.00
923A21	2017-08-13 05:47:00+03	29600.00
923A23	2017-07-11 16:03:00+03	23600.00
923A63	2017-07-30 02:48:00+03	39500.00
923A6D	2017-08-14 14:37:00+03	177600.00
923A77	2017-07-31 00:49:00+03	68800.00
923ADB	2017-08-01 14:36:00+03	20800.00
923B9F	2017-08-09 00:52:00+03	206800.00
923C03	2017-07-06 22:10:00+03	24400.00
923D25	2017-07-28 23:17:00+03	43200.00
923DD0	2017-07-29 06:37:00+03	73500.00
923E02	2017-07-02 13:34:00+03	88800.00
923E71	2017-08-09 11:11:00+03	28800.00
923E76	2017-08-01 11:20:00+03	36200.00
923E94	2017-07-30 10:18:00+03	141600.00
923EF5	2017-07-05 03:52:00+03	73600.00
923F06	2017-07-05 07:36:00+03	49800.00
923F0D	2017-08-06 17:31:00+03	95300.00
923F5B	2017-08-13 21:22:00+03	16000.00
923FB2	2017-07-21 21:27:00+03	195900.00
923FD7	2017-07-04 08:34:00+03	57600.00
923FE5	2017-07-16 15:56:00+03	56000.00
924010	2017-07-02 13:07:00+03	24400.00
92404B	2017-08-08 13:21:00+03	51800.00
924064	2017-07-22 08:50:00+03	36400.00
9240B6	2017-08-12 23:27:00+03	39800.00
9240EA	2017-07-04 12:03:00+03	51100.00
9240FE	2017-07-08 22:05:00+03	92700.00
924123	2017-07-25 21:09:00+03	174900.00
924135	2017-08-01 21:42:00+03	28000.00
924199	2017-08-04 00:46:00+03	14000.00
92427D	2017-06-29 21:28:00+03	6300.00
924288	2017-08-11 11:44:00+03	175200.00
924299	2017-07-13 13:07:00+03	66600.00
9242D3	2017-06-27 21:31:00+03	56000.00
9242E9	2017-07-14 05:00:00+03	178800.00
92434A	2017-08-08 00:13:00+03	203700.00
924370	2017-07-23 21:08:00+03	31000.00
924390	2017-08-02 08:06:00+03	153600.00
92439F	2017-07-27 18:40:00+03	16800.00
924482	2017-07-12 07:08:00+03	89600.00
924516	2017-07-09 16:25:00+03	17600.00
92452D	2017-07-17 07:48:00+03	25600.00
924581	2017-08-07 07:37:00+03	35200.00
9245B3	2017-07-15 00:41:00+03	52100.00
9245C8	2017-07-23 03:58:00+03	59200.00
924679	2017-08-05 11:41:00+03	47700.00
9246AF	2017-07-09 22:53:00+03	15000.00
9246C7	2017-08-12 02:35:00+03	87000.00
92475B	2017-08-15 02:29:00+03	14400.00
9247A4	2017-07-25 00:04:00+03	26000.00
9247E7	2017-08-02 00:21:00+03	119700.00
924895	2017-07-03 00:33:00+03	6300.00
9248AD	2017-07-14 22:36:00+03	451600.00
9248D1	2017-07-21 16:55:00+03	266400.00
9248F1	2017-07-16 15:04:00+03	54800.00
9248FF	2017-08-02 01:53:00+03	8200.00
92493E	2017-07-26 01:47:00+03	298500.00
924979	2017-08-11 14:51:00+03	28300.00
92498F	2017-07-06 08:20:00+03	154900.00
924ADC	2017-07-13 08:46:00+03	13700.00
924AEE	2017-07-22 21:48:00+03	106800.00
924B41	2017-07-28 23:31:00+03	23200.00
924B7D	2017-07-23 23:19:00+03	369000.00
924BFA	2017-07-02 11:58:00+03	56000.00
924D14	2017-07-25 01:15:00+03	35600.00
924D4B	2017-08-15 12:36:00+03	23200.00
924D6C	2017-07-06 17:15:00+03	57400.00
924DE4	2017-07-01 12:03:00+03	7400.00
924E23	2017-08-06 13:06:00+03	64200.00
924E3F	2017-07-30 00:54:00+03	47800.00
924E41	2017-07-26 02:33:00+03	24400.00
924ED7	2017-07-15 13:29:00+03	22000.00
924F07	2017-07-06 10:51:00+03	13400.00
924F37	2017-08-13 15:02:00+03	46500.00
924FE4	2017-07-23 10:07:00+03	6000.00
924FEE	2017-08-11 11:58:00+03	42700.00
924FF6	2017-07-29 02:53:00+03	24000.00
924FF7	2017-07-12 11:06:00+03	405000.00
92507B	2017-07-19 13:05:00+03	58000.00
925090	2017-08-13 00:06:00+03	258400.00
9250A6	2017-08-05 05:16:00+03	42700.00
9250B5	2017-07-15 09:13:00+03	70100.00
9250DC	2017-08-04 07:10:00+03	88900.00
9250F1	2017-07-25 19:01:00+03	60400.00
925103	2017-08-10 21:10:00+03	55800.00
925158	2017-07-16 05:39:00+03	129400.00
92516A	2017-07-03 23:07:00+03	271100.00
92516D	2017-08-15 08:26:00+03	128800.00
92524E	2017-07-29 18:30:00+03	131600.00
925266	2017-08-01 00:49:00+03	39200.00
92528E	2017-07-26 06:04:00+03	100600.00
925318	2017-06-27 07:51:00+03	22000.00
92533D	2017-07-23 06:18:00+03	18000.00
925355	2017-07-07 19:00:00+03	73200.00
9253AF	2017-08-14 03:19:00+03	39200.00
9253B9	2017-07-23 22:22:00+03	26000.00
9253C4	2017-07-14 17:51:00+03	34000.00
9253CF	2017-08-08 13:05:00+03	35800.00
9253E8	2017-08-02 23:26:00+03	38200.00
925402	2017-07-11 22:51:00+03	56900.00
92549B	2017-08-14 02:36:00+03	35700.00
9254B7	2017-07-08 14:45:00+03	16000.00
925548	2017-07-25 09:50:00+03	13400.00
9255AC	2017-07-12 18:55:00+03	136800.00
9255B6	2017-08-10 01:19:00+03	29400.00
9255EF	2017-08-10 19:45:00+03	23200.00
925614	2017-06-30 19:08:00+03	133300.00
92566E	2017-08-08 04:19:00+03	46900.00
925697	2017-08-05 02:16:00+03	66600.00
9256A5	2017-07-06 21:44:00+03	50600.00
925700	2017-07-23 07:08:00+03	28800.00
925715	2017-07-31 01:55:00+03	156000.00
92575C	2017-07-27 06:53:00+03	154800.00
925764	2017-08-02 08:12:00+03	19600.00
925782	2017-07-24 11:26:00+03	53300.00
9257F0	2017-07-13 23:12:00+03	29600.00
9257FF	2017-07-07 19:53:00+03	67200.00
925899	2017-07-18 01:26:00+03	56000.00
9258AE	2017-08-03 05:28:00+03	26700.00
9258C6	2017-07-23 02:49:00+03	55800.00
92593D	2017-08-15 04:37:00+03	146000.00
9259BC	2017-07-12 19:21:00+03	41200.00
925A08	2017-07-20 13:28:00+03	18000.00
925A26	2017-08-08 05:23:00+03	95600.00
925A49	2017-07-04 19:46:00+03	47400.00
925AC6	2017-08-09 20:06:00+03	127300.00
925AEA	2017-07-08 23:39:00+03	162100.00
925B43	2017-07-25 09:37:00+03	358800.00
925B85	2017-07-30 07:27:00+03	56400.00
925B9D	2017-07-23 16:44:00+03	13600.00
925BB5	2017-07-24 15:54:00+03	18000.00
925CB9	2017-07-22 08:43:00+03	143000.00
925CC7	2017-08-14 19:09:00+03	66600.00
925D41	2017-07-03 13:33:00+03	296700.00
925D67	2017-07-01 04:30:00+03	44000.00
925D68	2017-07-24 23:16:00+03	13200.00
925DAE	2017-07-07 22:18:00+03	177000.00
925DBB	2017-08-12 02:36:00+03	73600.00
925E12	2017-08-03 06:14:00+03	36200.00
925E70	2017-08-13 16:59:00+03	146300.00
925ED5	2017-08-10 17:42:00+03	10800.00
925ED8	2017-07-20 03:05:00+03	24800.00
925F24	2017-07-29 15:29:00+03	84100.00
925F26	2017-07-12 05:21:00+03	70800.00
925F74	2017-07-18 07:52:00+03	14000.00
925F8F	2017-07-26 02:37:00+03	85000.00
926048	2017-07-12 08:38:00+03	27800.00
92605C	2017-08-12 21:42:00+03	119000.00
9260A7	2017-07-30 03:34:00+03	21200.00
9260A9	2017-08-11 15:43:00+03	225300.00
9260FD	2017-08-06 13:20:00+03	113000.00
92614C	2017-07-19 04:45:00+03	6000.00
92618D	2017-07-22 04:32:00+03	46700.00
92623D	2017-08-09 09:20:00+03	97900.00
926299	2017-07-24 11:05:00+03	18600.00
9262C4	2017-07-17 10:42:00+03	54000.00
9262C8	2017-08-08 16:36:00+03	48800.00
9262F8	2017-08-14 15:34:00+03	44000.00
926304	2017-07-22 10:37:00+03	23200.00
926322	2017-07-15 20:16:00+03	57400.00
92634A	2017-07-10 09:31:00+03	24800.00
9263B0	2017-08-04 14:46:00+03	44600.00
9263C6	2017-08-08 22:42:00+03	443000.00
9263E4	2017-08-08 12:25:00+03	435800.00
9263FC	2017-08-02 17:32:00+03	16400.00
926443	2017-07-05 22:47:00+03	32300.00
926446	2017-07-21 09:10:00+03	46000.00
926451	2017-07-15 07:56:00+03	289800.00
926455	2017-07-19 11:36:00+03	72300.00
9264B7	2017-07-30 17:38:00+03	58900.00
9264B9	2017-07-23 18:22:00+03	29600.00
9264BE	2017-08-07 17:20:00+03	26800.00
9264FE	2017-07-11 14:02:00+03	21200.00
926575	2017-07-12 19:14:00+03	64700.00
92669E	2017-08-07 15:35:00+03	52100.00
926738	2017-08-08 21:24:00+03	13400.00
9267CD	2017-07-21 18:17:00+03	47200.00
926820	2017-07-16 18:27:00+03	25800.00
92686C	2017-08-06 07:21:00+03	22000.00
926875	2017-07-04 04:49:00+03	12600.00
9268A3	2017-06-28 14:08:00+03	135400.00
9268BF	2017-08-03 21:41:00+03	56100.00
926963	2017-07-25 10:53:00+03	6800.00
9269D3	2017-07-28 03:32:00+03	56600.00
9269DD	2017-07-23 00:13:00+03	241500.00
9269F9	2017-07-14 19:03:00+03	30200.00
926A0F	2017-07-23 01:45:00+03	26000.00
926A2E	2017-08-07 17:51:00+03	62200.00
926B6D	2017-07-26 06:56:00+03	52700.00
926BF1	2017-07-22 18:46:00+03	21800.00
926C4E	2017-07-19 00:26:00+03	29500.00
926C79	2017-07-02 14:09:00+03	46000.00
926CA3	2017-08-10 09:01:00+03	43200.00
926D47	2017-07-27 03:15:00+03	37100.00
926D64	2017-07-14 11:48:00+03	80600.00
926D69	2017-07-13 12:16:00+03	36200.00
926DE3	2017-07-02 11:04:00+03	26000.00
926E00	2017-07-15 18:15:00+03	13400.00
926E8E	2017-08-14 09:07:00+03	46000.00
926F40	2017-08-08 02:33:00+03	68400.00
926F9C	2017-08-05 11:18:00+03	28000.00
926FE0	2017-07-10 15:37:00+03	24400.00
927040	2017-07-02 07:05:00+03	49500.00
92708E	2017-07-20 04:45:00+03	54900.00
927096	2017-07-13 01:39:00+03	92800.00
9270C9	2017-07-13 23:02:00+03	182300.00
9270CC	2017-07-15 10:22:00+03	56000.00
9270CD	2017-07-16 19:27:00+03	24800.00
9270F7	2017-08-06 05:04:00+03	112000.00
927105	2017-08-07 09:00:00+03	71400.00
92711B	2017-07-05 03:47:00+03	136600.00
927140	2017-08-08 23:25:00+03	54800.00
927147	2017-08-13 06:32:00+03	62000.00
927161	2017-07-01 06:37:00+03	24400.00
92717D	2017-07-27 02:35:00+03	58600.00
9271AC	2017-07-29 16:54:00+03	158900.00
9271EC	2017-07-12 15:19:00+03	59800.00
92723F	2017-07-11 11:57:00+03	30100.00
927242	2017-08-06 23:34:00+03	58000.00
92724D	2017-06-26 20:16:00+03	13600.00
92725E	2017-07-27 12:56:00+03	89600.00
9272B1	2017-08-14 15:46:00+03	116900.00
9272CA	2017-07-26 12:51:00+03	115900.00
9272E7	2017-08-01 01:32:00+03	23200.00
927321	2017-08-13 16:45:00+03	98200.00
92732F	2017-08-05 10:17:00+03	30200.00
9273AD	2017-07-23 19:23:00+03	57600.00
9273EA	2017-07-21 07:10:00+03	59000.00
927405	2017-07-08 11:17:00+03	73300.00
927431	2017-07-06 22:02:00+03	37900.00
92744F	2017-07-29 11:06:00+03	25000.00
9274AB	2017-07-13 14:55:00+03	24400.00
9274B6	2017-08-10 17:11:00+03	492000.00
9274D1	2017-07-25 03:54:00+03	112000.00
92759C	2017-08-01 08:04:00+03	9800.00
9275FC	2017-07-09 08:35:00+03	136500.00
927612	2017-07-26 21:17:00+03	32400.00
92761D	2017-07-31 18:00:00+03	88500.00
927625	2017-07-19 03:18:00+03	73500.00
927641	2017-08-01 03:36:00+03	84100.00
9276B3	2017-07-15 09:14:00+03	89600.00
9276CF	2017-07-25 21:28:00+03	32700.00
9276D3	2017-07-10 07:39:00+03	136600.00
92776D	2017-07-11 22:05:00+03	111600.00
9277A8	2017-08-14 18:55:00+03	99200.00
9277F0	2017-08-07 13:47:00+03	46000.00
92781B	2017-07-17 09:16:00+03	145100.00
927837	2017-08-11 12:14:00+03	29300.00
927838	2017-07-02 11:15:00+03	213800.00
92787E	2017-08-07 02:03:00+03	49400.00
92788A	2017-08-15 03:41:00+03	13400.00
92791A	2017-08-14 21:38:00+03	69200.00
927971	2017-07-16 07:49:00+03	35200.00
9279D2	2017-07-23 06:22:00+03	20200.00
927A40	2017-07-19 05:34:00+03	70800.00
927A97	2017-07-05 11:17:00+03	105000.00
927AC1	2017-08-08 02:55:00+03	123000.00
927ACC	2017-08-03 19:59:00+03	140800.00
927ADE	2017-08-12 15:41:00+03	40100.00
927B22	2017-08-14 02:39:00+03	31100.00
927B26	2017-08-06 15:39:00+03	247900.00
927B4D	2017-07-26 03:39:00+03	46300.00
927B51	2017-07-25 22:04:00+03	14800.00
927B5B	2017-08-10 05:17:00+03	75300.00
927B81	2017-07-18 00:05:00+03	136200.00
927C10	2017-07-26 01:33:00+03	56000.00
927C35	2017-07-18 06:04:00+03	28000.00
927C9F	2017-07-12 01:39:00+03	30200.00
927CE9	2017-08-06 18:30:00+03	14000.00
927DF7	2017-07-19 19:25:00+03	112800.00
927E44	2017-08-04 15:24:00+03	154400.00
927E4D	2017-07-20 21:30:00+03	58000.00
927E50	2017-07-28 13:31:00+03	97400.00
927F0F	2017-08-08 12:51:00+03	27900.00
927FB8	2017-07-13 20:23:00+03	283100.00
927FC4	2017-07-07 15:49:00+03	35400.00
928062	2017-07-06 14:59:00+03	23600.00
9280CF	2017-07-04 06:46:00+03	266300.00
9280E6	2017-07-13 15:05:00+03	10100.00
9280F5	2017-07-17 08:58:00+03	55800.00
928123	2017-08-11 19:44:00+03	12600.00
92812D	2017-08-15 05:36:00+03	30200.00
928137	2017-08-08 02:58:00+03	24700.00
928179	2017-07-16 09:33:00+03	11300.00
9281B9	2017-08-01 11:55:00+03	37200.00
9281D0	2017-07-19 19:55:00+03	6300.00
928210	2017-07-30 06:58:00+03	58900.00
92826A	2017-07-05 03:41:00+03	37100.00
92834C	2017-07-22 11:24:00+03	48800.00
9283A4	2017-07-16 10:02:00+03	46100.00
928410	2017-08-05 23:26:00+03	137900.00
92843D	2017-07-26 05:25:00+03	108000.00
928467	2017-07-15 11:23:00+03	26700.00
92847F	2017-08-03 14:37:00+03	6700.00
9284ED	2017-07-28 10:29:00+03	71200.00
92850B	2017-08-11 03:11:00+03	123900.00
928528	2017-07-11 10:27:00+03	96800.00
9285AF	2017-07-16 17:36:00+03	81700.00
9285DF	2017-08-02 10:04:00+03	20200.00
928607	2017-06-30 08:48:00+03	25800.00
928685	2017-08-09 04:12:00+03	489000.00
928727	2017-07-25 14:29:00+03	199200.00
92874E	2017-07-17 08:38:00+03	101800.00
9287DE	2017-07-21 13:03:00+03	40600.00
9288AD	2017-08-04 23:21:00+03	31600.00
9288CE	2017-07-12 18:44:00+03	6700.00
928912	2017-07-25 02:44:00+03	12200.00
92895A	2017-07-22 16:23:00+03	198400.00
92897B	2017-07-22 01:58:00+03	73300.00
9289C4	2017-08-05 21:01:00+03	58000.00
9289F1	2017-08-02 03:51:00+03	14000.00
928A61	2017-08-09 15:53:00+03	143000.00
928ADE	2017-07-06 19:33:00+03	230000.00
928B1A	2017-07-17 22:49:00+03	643800.00
928B6D	2017-07-05 19:29:00+03	46400.00
928BAE	2017-08-04 23:47:00+03	92800.00
928BC2	2017-08-13 00:19:00+03	76200.00
928C0B	2017-08-07 01:26:00+03	18000.00
928C0F	2017-06-30 21:06:00+03	64500.00
928C13	2017-08-02 14:54:00+03	36200.00
928C5B	2017-07-01 05:49:00+03	26000.00
928D01	2017-08-05 15:03:00+03	29600.00
928D8D	2017-07-22 13:55:00+03	43600.00
928D9E	2017-07-17 14:33:00+03	44000.00
928E89	2017-07-20 17:32:00+03	68800.00
928EB4	2017-08-06 19:04:00+03	109200.00
928EDD	2017-08-13 07:51:00+03	15000.00
928EE3	2017-08-15 10:12:00+03	35800.00
928F2D	2017-08-12 06:09:00+03	140900.00
928F40	2017-07-30 17:47:00+03	8200.00
928F91	2017-08-04 06:21:00+03	48800.00
928FFB	2017-08-05 00:18:00+03	15000.00
92906D	2017-08-05 01:31:00+03	136600.00
929072	2017-08-05 11:05:00+03	48400.00
9290A7	2017-07-13 02:22:00+03	119900.00
9290B2	2017-08-06 13:50:00+03	116400.00
929102	2017-07-27 16:44:00+03	66000.00
929113	2017-07-22 22:32:00+03	112200.00
929134	2017-07-26 15:39:00+03	81300.00
92914C	2017-08-03 12:13:00+03	44000.00
929182	2017-07-19 21:08:00+03	18600.00
9291C0	2017-07-24 21:44:00+03	49100.00
929226	2017-07-31 08:19:00+03	615000.00
92922B	2017-06-30 04:35:00+03	79800.00
929233	2017-07-24 19:58:00+03	46800.00
929250	2017-08-14 09:48:00+03	77000.00
92926B	2017-07-02 14:56:00+03	23200.00
9292E0	2017-07-28 07:34:00+03	19600.00
929328	2017-07-11 03:33:00+03	210000.00
929346	2017-08-06 09:38:00+03	133100.00
9293C3	2017-08-12 20:12:00+03	107400.00
9293CE	2017-07-31 20:52:00+03	51900.00
9293D8	2017-07-09 19:31:00+03	38800.00
92942C	2017-07-07 23:59:00+03	28000.00
92946C	2017-07-14 17:20:00+03	78500.00
92954E	2017-07-18 14:46:00+03	88600.00
929554	2017-07-21 07:40:00+03	83100.00
929567	2017-08-11 13:33:00+03	16400.00
929575	2017-07-16 08:31:00+03	78800.00
9295A5	2017-07-24 09:20:00+03	48800.00
9295B5	2017-07-31 02:58:00+03	81300.00
9295F3	2017-08-15 06:27:00+03	398500.00
929613	2017-08-05 04:25:00+03	42600.00
929647	2017-07-14 23:11:00+03	14000.00
9296A0	2017-08-15 07:18:00+03	55800.00
92971C	2017-07-27 05:43:00+03	68000.00
92973F	2017-07-23 06:02:00+03	34400.00
92974A	2017-07-15 08:27:00+03	70400.00
929773	2017-07-14 17:12:00+03	13400.00
9297D8	2017-07-23 19:07:00+03	175300.00
929827	2017-07-26 06:11:00+03	116400.00
929836	2017-07-03 12:59:00+03	18600.00
929846	2017-07-22 09:49:00+03	92600.00
929860	2017-07-27 20:50:00+03	156300.00
929864	2017-07-23 13:03:00+03	37000.00
929866	2017-07-02 08:33:00+03	39200.00
9298D3	2017-07-14 20:25:00+03	38400.00
929999	2017-08-11 07:06:00+03	30000.00
9299A8	2017-07-08 06:27:00+03	124300.00
9299BA	2017-07-04 15:36:00+03	187800.00
9299BE	2017-07-30 10:25:00+03	69500.00
9299F2	2017-08-05 17:32:00+03	84900.00
929A02	2017-08-09 08:30:00+03	28800.00
929A18	2017-07-06 23:44:00+03	34100.00
929A6E	2017-07-10 11:50:00+03	337800.00
929A9A	2017-07-19 05:48:00+03	65000.00
929AB9	2017-08-15 10:23:00+03	28800.00
929ABE	2017-08-01 21:42:00+03	28800.00
929AC3	2017-07-24 01:06:00+03	31800.00
929B31	2017-07-05 02:10:00+03	44500.00
929B50	2017-07-06 16:31:00+03	44800.00
929BAC	2017-07-28 09:50:00+03	16800.00
929BBB	2017-07-14 05:36:00+03	103500.00
929C46	2017-08-05 22:17:00+03	21400.00
929C49	2017-08-06 17:20:00+03	45500.00
929C60	2017-07-25 17:29:00+03	51200.00
929C89	2017-07-21 01:46:00+03	47100.00
929CBA	2017-07-04 21:15:00+03	40100.00
929E50	2017-07-06 03:11:00+03	269100.00
929E95	2017-07-18 20:18:00+03	21200.00
929EFD	2017-07-16 02:34:00+03	46000.00
929F06	2017-07-22 08:59:00+03	24000.00
92A01E	2017-08-15 11:04:00+03	55800.00
92A084	2017-07-04 06:07:00+03	175900.00
92A0B7	2017-07-08 06:47:00+03	26000.00
92A117	2017-07-27 15:02:00+03	51600.00
92A15F	2017-07-06 16:01:00+03	28000.00
92A1D9	2017-08-07 03:35:00+03	88800.00
92A206	2017-07-31 04:50:00+03	50600.00
92A223	2017-07-24 17:48:00+03	47100.00
92A22B	2017-08-14 01:08:00+03	51800.00
92A22F	2017-07-13 23:23:00+03	46700.00
92A26B	2017-08-02 13:22:00+03	108900.00
92A2AD	2017-07-10 19:02:00+03	90800.00
92A2B1	2017-08-04 22:34:00+03	332700.00
92A33A	2017-08-07 11:26:00+03	28000.00
92A387	2017-07-02 05:40:00+03	170000.00
92A3A1	2017-07-29 11:00:00+03	173500.00
92A3BB	2017-08-09 19:01:00+03	38800.00
92A3E5	2017-07-22 16:14:00+03	135400.00
92A43D	2017-08-07 00:09:00+03	33300.00
92A45B	2017-08-11 19:22:00+03	24400.00
92A462	2017-07-20 18:21:00+03	120700.00
92A4AE	2017-08-02 05:08:00+03	56000.00
92A4B1	2017-08-10 12:42:00+03	26800.00
92A4E0	2017-07-12 10:06:00+03	47400.00
92A4F5	2017-08-13 01:23:00+03	46800.00
92A537	2017-08-11 13:53:00+03	107200.00
92A54E	2017-07-19 22:08:00+03	222400.00
92A58E	2017-08-14 23:36:00+03	36200.00
92A5B9	2017-07-28 04:54:00+03	16400.00
92A5C3	2017-07-22 18:39:00+03	12600.00
92A62E	2017-08-02 14:29:00+03	42400.00
92A64D	2017-07-19 06:44:00+03	111700.00
92A65C	2017-07-16 12:52:00+03	40000.00
92A711	2017-07-31 22:41:00+03	36200.00
92A78F	2017-08-09 23:06:00+03	50800.00
92A7C4	2017-07-23 11:41:00+03	185000.00
92A7E0	2017-07-27 19:14:00+03	8400.00
92A810	2017-07-19 12:41:00+03	36200.00
92A8DF	2017-07-28 08:35:00+03	6300.00
92A90B	2017-07-23 15:15:00+03	56600.00
92A919	2017-07-17 03:22:00+03	53400.00
92A96B	2017-07-09 17:06:00+03	19600.00
92A9A3	2017-08-11 16:40:00+03	12000.00
92A9B2	2017-07-16 20:16:00+03	81700.00
92AA24	2017-07-24 14:50:00+03	56000.00
92AB21	2017-07-20 14:14:00+03	23200.00
92AB72	2017-08-13 05:28:00+03	32200.00
92AB7B	2017-08-08 05:53:00+03	8200.00
92ABB9	2017-07-23 12:15:00+03	109600.00
92AC11	2017-08-15 06:36:00+03	62000.00
92AC15	2017-08-12 00:18:00+03	8200.00
92AC33	2017-07-23 05:16:00+03	96000.00
92AC50	2017-07-26 21:11:00+03	67600.00
92ACDF	2017-08-04 22:15:00+03	23600.00
92AD03	2017-08-13 05:01:00+03	47400.00
92AD85	2017-08-13 10:24:00+03	92700.00
92AD89	2017-07-02 05:31:00+03	174900.00
92ADC1	2017-07-09 07:23:00+03	40600.00
92ADCB	2017-08-02 06:33:00+03	6000.00
92AE13	2017-08-11 17:49:00+03	194100.00
92AE14	2017-07-18 17:37:00+03	405200.00
92AE6D	2017-08-03 21:29:00+03	29600.00
92AED6	2017-07-26 14:08:00+03	78600.00
92AEED	2017-07-27 16:40:00+03	27200.00
92AF3C	2017-07-21 22:42:00+03	38800.00
92AF7C	2017-08-02 08:03:00+03	46400.00
92AF8C	2017-07-26 16:13:00+03	60800.00
92AFCC	2017-08-13 23:04:00+03	14000.00
92B000	2017-07-14 08:09:00+03	23200.00
92B08E	2017-07-17 07:22:00+03	59800.00
92B09B	2017-07-17 07:44:00+03	31600.00
92B0F3	2017-07-11 00:04:00+03	46500.00
92B158	2017-08-14 12:16:00+03	48800.00
92B1BD	2017-07-17 06:59:00+03	47000.00
92B1CF	2017-07-27 14:44:00+03	67600.00
92B249	2017-07-15 07:18:00+03	136000.00
92B24A	2017-07-24 19:55:00+03	30200.00
92B25C	2017-07-22 11:02:00+03	92800.00
92B261	2017-07-20 20:32:00+03	40900.00
92B275	2017-07-14 19:14:00+03	48400.00
92B2BA	2017-07-14 20:26:00+03	123000.00
92B33E	2017-07-21 20:15:00+03	43600.00
92B362	2017-07-07 15:16:00+03	54800.00
92B3F1	2017-07-06 03:44:00+03	244100.00
92B40D	2017-07-25 19:25:00+03	13000.00
92B47A	2017-08-07 15:22:00+03	19600.00
92B487	2017-08-07 12:05:00+03	87100.00
92B4D8	2017-07-18 12:14:00+03	52000.00
92B4DB	2017-08-06 05:38:00+03	42000.00
92B50B	2017-08-06 15:46:00+03	95600.00
92B554	2017-07-21 07:24:00+03	95600.00
92B568	2017-07-25 11:46:00+03	139100.00
92B587	2017-07-28 09:29:00+03	79000.00
92B5A2	2017-07-20 21:38:00+03	65100.00
92B5BE	2017-08-09 15:55:00+03	23200.00
92B5CC	2017-06-30 04:57:00+03	46000.00
92B5F7	2017-08-01 17:03:00+03	160700.00
92B61D	2017-08-05 01:10:00+03	17600.00
92B696	2017-07-11 19:27:00+03	46400.00
92B6EB	2017-08-01 11:08:00+03	90700.00
92B6FC	2017-08-05 23:21:00+03	42800.00
92B7A6	2017-07-27 15:01:00+03	13000.00
92B7C5	2017-08-04 11:28:00+03	7200.00
92B8E1	2017-07-22 16:42:00+03	111700.00
92B93F	2017-07-20 12:02:00+03	59400.00
92B9E9	2017-08-09 14:33:00+03	18000.00
92BA32	2017-07-06 08:12:00+03	101200.00
92BA68	2017-07-19 20:38:00+03	28000.00
92BA81	2017-08-15 16:44:00+03	21800.00
92BA8F	2017-08-15 10:33:00+03	80000.00
92BABE	2017-07-05 15:21:00+03	99300.00
92BAE3	2017-08-04 16:55:00+03	53300.00
92BB2D	2017-07-01 03:07:00+03	142400.00
92BB6B	2017-06-29 18:02:00+03	108000.00
92BB89	2017-08-02 16:25:00+03	52300.00
92BB8F	2017-07-30 21:32:00+03	26000.00
92BBAB	2017-07-02 20:14:00+03	48800.00
92BBE1	2017-08-15 00:36:00+03	16800.00
92BBF8	2017-08-01 05:32:00+03	112000.00
92BC28	2017-07-10 17:13:00+03	44800.00
92BC35	2017-08-10 09:40:00+03	54100.00
92BC6C	2017-07-18 03:45:00+03	88200.00
92BCA7	2017-08-04 19:13:00+03	141800.00
92BCD9	2017-07-29 10:52:00+03	64600.00
92BCEA	2017-08-12 11:50:00+03	28000.00
92BD2D	2017-07-26 09:47:00+03	90000.00
92BD51	2017-06-29 16:30:00+03	115700.00
92BDD0	2017-08-07 07:03:00+03	130400.00
92BE0A	2017-07-11 02:06:00+03	8600.00
92BEB1	2017-07-26 23:50:00+03	103500.00
92BF3D	2017-08-11 04:44:00+03	21200.00
92BFCE	2017-08-02 09:27:00+03	168700.00
92BFDF	2017-06-28 04:13:00+03	28800.00
92C06E	2017-07-27 15:01:00+03	27400.00
92C077	2017-07-12 04:44:00+03	50400.00
92C08D	2017-07-04 02:44:00+03	66600.00
92C09B	2017-07-09 19:58:00+03	134600.00
92C169	2017-07-02 03:41:00+03	14800.00
92C171	2017-08-02 16:39:00+03	36200.00
92C198	2017-07-17 13:41:00+03	14000.00
92C1FB	2017-07-30 23:09:00+03	24400.00
92C254	2017-08-06 09:54:00+03	168000.00
92C2BD	2017-07-20 12:27:00+03	140400.00
92C2D1	2017-07-11 18:22:00+03	331500.00
92C2FC	2017-07-09 10:06:00+03	64700.00
92C364	2017-07-05 03:36:00+03	144400.00
92C366	2017-07-05 14:26:00+03	100600.00
92C37C	2017-07-18 08:38:00+03	28300.00
92C3A9	2017-08-09 13:00:00+03	31100.00
92C415	2017-07-26 06:19:00+03	40100.00
92C421	2017-07-26 07:24:00+03	143200.00
92C429	2017-08-05 20:44:00+03	128800.00
92C431	2017-07-02 12:44:00+03	99200.00
92C47A	2017-07-02 12:01:00+03	58800.00
92C480	2017-07-14 22:36:00+03	24800.00
92C498	2017-07-22 03:36:00+03	137900.00
92C4EF	2017-07-22 03:52:00+03	248400.00
92C511	2017-07-09 15:03:00+03	27000.00
92C59A	2017-07-06 07:46:00+03	24400.00
92C5D7	2017-08-01 09:00:00+03	76800.00
92C5F8	2017-08-01 18:11:00+03	52700.00
92C619	2017-06-28 17:51:00+03	56900.00
92C639	2017-08-11 15:03:00+03	56100.00
92C63C	2017-07-21 04:01:00+03	262500.00
92C649	2017-07-07 10:27:00+03	107400.00
92C6D6	2017-07-23 10:23:00+03	27200.00
92C700	2017-07-01 12:20:00+03	75300.00
92C740	2017-07-25 12:01:00+03	177800.00
92C748	2017-08-11 22:30:00+03	514400.00
92C80B	2017-07-25 08:16:00+03	136800.00
92C845	2017-08-06 09:25:00+03	32800.00
92C8FB	2017-07-07 11:46:00+03	47100.00
92C901	2017-08-13 05:16:00+03	60000.00
92C91C	2017-08-12 18:18:00+03	81200.00
92C95F	2017-08-15 02:26:00+03	62600.00
92C9A3	2017-07-11 05:08:00+03	34700.00
92CA76	2017-07-06 11:11:00+03	18000.00
92CAB3	2017-07-30 13:11:00+03	38800.00
92CABC	2017-08-09 09:28:00+03	114300.00
92CAE7	2017-08-02 09:09:00+03	62000.00
92CAF8	2017-08-09 10:12:00+03	135600.00
92CAFC	2017-07-03 14:41:00+03	85600.00
92CB1C	2017-07-09 21:45:00+03	46400.00
92CB54	2017-07-14 11:34:00+03	111100.00
92CB5E	2017-07-28 16:35:00+03	55800.00
92CB60	2017-07-25 12:02:00+03	116400.00
92CBB3	2017-08-08 01:35:00+03	23200.00
92CBC7	2017-07-13 17:21:00+03	134400.00
92CC07	2017-07-31 19:06:00+03	12400.00
92CC13	2017-07-26 08:27:00+03	38500.00
92CC95	2017-07-11 15:54:00+03	391200.00
92CCC2	2017-07-25 16:05:00+03	47200.00
92CD73	2017-07-19 15:26:00+03	26200.00
92CE2E	2017-08-01 18:32:00+03	32700.00
92CE3C	2017-07-29 23:54:00+03	49100.00
92CE4E	2017-07-11 21:26:00+03	34800.00
92CE78	2017-07-06 01:14:00+03	75600.00
92CF57	2017-07-21 03:28:00+03	13600.00
92CF5E	2017-07-04 10:15:00+03	21400.00
92CFAB	2017-07-12 22:52:00+03	59300.00
92CFD1	2017-08-02 10:49:00+03	45200.00
92CFE6	2017-07-27 12:43:00+03	200500.00
92D050	2017-07-11 11:24:00+03	283600.00
92D05B	2017-07-16 01:04:00+03	68000.00
92D091	2017-07-09 10:47:00+03	55800.00
92D12C	2017-08-02 12:38:00+03	46700.00
92D14B	2017-06-29 08:08:00+03	40400.00
92D166	2017-08-05 22:41:00+03	12400.00
92D186	2017-08-15 12:07:00+03	88800.00
92D1F7	2017-08-13 13:07:00+03	178800.00
92D248	2017-08-03 07:34:00+03	32800.00
92D2B8	2017-07-30 13:11:00+03	185600.00
92D2D0	2017-08-09 20:58:00+03	53800.00
92D2D1	2017-07-28 18:43:00+03	60400.00
92D329	2017-08-05 01:52:00+03	79000.00
92D339	2017-08-06 20:39:00+03	30000.00
92D344	2017-07-24 03:43:00+03	58200.00
92D39D	2017-07-05 06:02:00+03	47000.00
92D3AA	2017-07-07 08:55:00+03	53600.00
92D3B9	2017-07-13 11:10:00+03	28000.00
92D3C3	2017-07-09 02:10:00+03	23200.00
92D3F4	2017-08-07 02:13:00+03	67100.00
92D419	2017-08-01 20:45:00+03	162700.00
92D43A	2017-08-15 13:07:00+03	96300.00
92D474	2017-08-04 20:00:00+03	8000.00
92D47A	2017-07-28 09:30:00+03	168700.00
92D484	2017-07-23 04:52:00+03	257500.00
92D4A1	2017-07-27 15:14:00+03	25200.00
92D4AC	2017-07-05 08:27:00+03	62600.00
92D4C8	2017-08-05 12:39:00+03	190400.00
92D510	2017-07-26 20:01:00+03	23100.00
92D525	2017-07-10 16:20:00+03	97900.00
92D532	2017-07-22 23:36:00+03	12600.00
92D53A	2017-07-30 15:44:00+03	67400.00
92D54A	2017-07-09 22:03:00+03	285000.00
92D551	2017-07-01 08:02:00+03	105600.00
92D603	2017-08-08 01:12:00+03	28000.00
92D623	2017-07-30 07:13:00+03	32800.00
92D6A3	2017-08-01 18:37:00+03	48800.00
92D717	2017-08-15 05:20:00+03	29500.00
92D724	2017-07-21 04:30:00+03	90400.00
92D7D1	2017-07-15 15:19:00+03	39500.00
92D811	2017-07-20 00:19:00+03	8000.00
92D86C	2017-07-12 22:40:00+03	40800.00
92D8B3	2017-07-27 06:18:00+03	123000.00
92D8DD	2017-07-12 08:14:00+03	120100.00
92DAA5	2017-08-11 11:52:00+03	17000.00
92DB19	2017-08-01 18:41:00+03	29600.00
92DB3C	2017-07-04 23:23:00+03	85400.00
92DB49	2017-07-13 02:56:00+03	16400.00
92DB58	2017-07-21 19:48:00+03	32200.00
92DB5C	2017-08-10 14:34:00+03	62000.00
92DBC9	2017-08-11 15:41:00+03	155100.00
92DBF8	2017-08-08 10:48:00+03	213200.00
92DC06	2017-07-15 13:36:00+03	33400.00
92DC3C	2017-07-03 19:31:00+03	88100.00
92DC44	2017-07-02 01:48:00+03	24800.00
92DC65	2017-07-09 02:58:00+03	90400.00
92DDDE	2017-07-26 08:11:00+03	22000.00
92DE26	2017-07-30 00:27:00+03	36600.00
92DEAC	2017-07-18 03:17:00+03	66700.00
92DF7B	2017-07-10 19:14:00+03	130200.00
92DF91	2017-07-13 05:55:00+03	58400.00
92DF99	2017-08-14 17:57:00+03	75300.00
92DFC1	2017-07-27 02:13:00+03	18400.00
92DFC3	2017-07-12 10:09:00+03	58000.00
92DFE4	2017-07-24 17:49:00+03	58000.00
92E021	2017-08-06 16:34:00+03	175800.00
92E04B	2017-07-12 18:13:00+03	48800.00
92E062	2017-08-09 18:22:00+03	173600.00
92E0AA	2017-07-30 22:31:00+03	7200.00
92E0B0	2017-07-29 16:04:00+03	19800.00
92E164	2017-07-05 04:52:00+03	492000.00
92E186	2017-07-31 12:20:00+03	34000.00
92E1B7	2017-07-17 20:16:00+03	164600.00
92E1F9	2017-07-02 01:05:00+03	6000.00
92E235	2017-07-22 14:05:00+03	152800.00
92E3BD	2017-07-31 16:18:00+03	70700.00
92E3C8	2017-07-17 22:31:00+03	14400.00
92E3EB	2017-07-11 11:49:00+03	46400.00
92E4C0	2017-08-03 16:02:00+03	15000.00
92E57C	2017-08-08 22:29:00+03	19500.00
92E586	2017-07-04 00:41:00+03	125400.00
92E5E8	2017-07-28 05:15:00+03	85000.00
92E620	2017-07-19 22:51:00+03	52000.00
92E63E	2017-08-14 12:41:00+03	68400.00
92E65E	2017-07-17 00:56:00+03	56000.00
92E65F	2017-08-06 08:34:00+03	13200.00
92E673	2017-08-03 16:01:00+03	20200.00
92E6A6	2017-08-15 03:26:00+03	63500.00
92E74F	2017-07-20 01:09:00+03	73500.00
92E779	2017-08-10 06:29:00+03	23200.00
92E7AB	2017-07-14 19:45:00+03	19600.00
92E8D7	2017-08-13 04:40:00+03	35600.00
92E8D8	2017-07-11 16:52:00+03	89700.00
92E8E1	2017-07-01 20:45:00+03	105200.00
92E90C	2017-07-03 03:08:00+03	28700.00
92E971	2017-07-18 22:37:00+03	62600.00
92E98C	2017-07-24 20:40:00+03	30200.00
92E9A1	2017-07-20 07:37:00+03	71900.00
92E9E7	2017-07-18 18:05:00+03	98400.00
92E9E8	2017-08-14 20:23:00+03	265700.00
92EA68	2017-07-01 09:45:00+03	25400.00
92EA7F	2017-07-07 11:37:00+03	72200.00
92EAEC	2017-07-24 23:07:00+03	19600.00
92EC02	2017-07-27 05:59:00+03	32700.00
92EC3B	2017-07-08 12:29:00+03	27200.00
92EC42	2017-07-17 09:15:00+03	23600.00
92EC8B	2017-07-11 14:22:00+03	45200.00
92ECD9	2017-08-08 11:55:00+03	67700.00
92ECE5	2017-08-11 06:42:00+03	61400.00
92ED2B	2017-07-17 13:41:00+03	48800.00
92ED3F	2017-07-27 18:52:00+03	28800.00
92ED51	2017-07-11 04:43:00+03	87100.00
92EE66	2017-08-12 20:28:00+03	56000.00
92EE68	2017-07-11 03:50:00+03	128800.00
92EEC6	2017-07-30 00:37:00+03	66600.00
92EECE	2017-08-10 05:07:00+03	51600.00
92EF0B	2017-08-04 19:12:00+03	14400.00
92EF30	2017-07-26 19:49:00+03	136200.00
92EF3B	2017-07-31 08:06:00+03	56000.00
92EF4D	2017-06-30 18:44:00+03	8000.00
92EF56	2017-07-29 07:57:00+03	43200.00
92EFEC	2017-07-21 12:51:00+03	50900.00
92F009	2017-08-08 21:28:00+03	67600.00
92F01C	2017-08-12 04:30:00+03	123000.00
92F020	2017-08-11 02:18:00+03	56100.00
92F062	2017-07-30 10:57:00+03	46000.00
92F0D6	2017-08-03 10:33:00+03	48800.00
92F0DA	2017-08-01 00:14:00+03	11600.00
92F124	2017-07-17 03:08:00+03	18800.00
92F13F	2017-07-11 22:24:00+03	149600.00
92F151	2017-08-14 05:11:00+03	58200.00
92F194	2017-07-06 11:26:00+03	29600.00
92F227	2017-07-24 15:50:00+03	88900.00
92F253	2017-08-12 10:16:00+03	6000.00
92F276	2017-08-11 00:56:00+03	81900.00
92F31D	2017-07-31 13:14:00+03	46000.00
92F346	2017-07-05 23:44:00+03	40800.00
92F368	2017-07-23 07:29:00+03	67600.00
92F369	2017-07-22 22:25:00+03	25400.00
92F377	2017-08-15 10:03:00+03	91600.00
92F38D	2017-07-11 23:30:00+03	30200.00
92F391	2017-07-08 22:39:00+03	76600.00
92F3D2	2017-08-11 08:38:00+03	160800.00
92F3EB	2017-07-01 00:31:00+03	99300.00
92F3FD	2017-08-06 23:14:00+03	23200.00
92F421	2017-08-14 00:21:00+03	42900.00
92F482	2017-07-26 01:07:00+03	32800.00
92F57E	2017-07-09 22:03:00+03	139400.00
92F6C1	2017-08-05 10:57:00+03	24400.00
92F6FC	2017-08-03 07:06:00+03	57800.00
92F711	2017-06-28 17:34:00+03	14400.00
92F72E	2017-07-29 11:57:00+03	20200.00
92F7CC	2017-07-31 18:49:00+03	70900.00
92F80D	2017-07-26 06:40:00+03	166100.00
92F83F	2017-07-07 12:29:00+03	56600.00
92F905	2017-08-13 13:51:00+03	28000.00
92F913	2017-07-30 19:57:00+03	94800.00
92F919	2017-07-30 02:28:00+03	166900.00
92F950	2017-07-29 10:06:00+03	92400.00
92FA16	2017-07-22 10:32:00+03	135400.00
92FA68	2017-08-01 11:32:00+03	283700.00
92FAEB	2017-07-31 08:45:00+03	99300.00
92FB4E	2017-07-14 14:12:00+03	156300.00
92FB92	2017-08-06 00:12:00+03	19600.00
92FBB6	2017-07-04 23:49:00+03	39200.00
92FC35	2017-08-10 23:52:00+03	126400.00
92FC80	2017-08-13 01:31:00+03	14800.00
92FCC7	2017-07-11 17:14:00+03	77500.00
92FD36	2017-07-08 16:00:00+03	116800.00
92FD58	2017-07-08 03:55:00+03	36100.00
92FD79	2017-07-09 20:41:00+03	199700.00
92FD8D	2017-07-07 06:18:00+03	24200.00
92FDC2	2017-07-08 21:04:00+03	23400.00
92FDE4	2017-07-26 23:43:00+03	49600.00
92FE0F	2017-08-11 17:28:00+03	8000.00
92FE25	2017-07-22 10:49:00+03	82900.00
92FE56	2017-08-11 16:36:00+03	697600.00
92FF01	2017-08-05 23:23:00+03	66000.00
92FF42	2017-07-15 10:19:00+03	56000.00
92FF46	2017-08-09 06:32:00+03	166100.00
92FF64	2017-07-29 17:38:00+03	10800.00
92FF95	2017-07-23 16:09:00+03	111600.00
92FF9A	2017-07-21 17:37:00+03	147700.00
92FFAA	2017-07-13 19:38:00+03	55800.00
92FFE0	2017-07-16 00:38:00+03	6800.00
92FFE7	2017-07-30 22:19:00+03	28000.00
92FFEB	2017-07-24 11:45:00+03	173700.00
92FFFC	2017-07-30 01:06:00+03	63500.00
930011	2017-07-07 10:45:00+03	40400.00
93002A	2017-07-01 14:23:00+03	6000.00
930031	2017-08-04 16:40:00+03	166000.00
930088	2017-07-26 03:57:00+03	8000.00
9300AC	2017-08-13 11:39:00+03	64600.00
9300C4	2017-08-11 19:17:00+03	102100.00
93010D	2017-07-15 18:51:00+03	26000.00
930122	2017-07-22 06:49:00+03	28800.00
930188	2017-07-30 06:04:00+03	143100.00
9301DC	2017-07-07 18:55:00+03	103600.00
9302BD	2017-07-05 08:49:00+03	55800.00
9302C4	2017-08-07 14:53:00+03	81900.00
930355	2017-07-10 20:26:00+03	92800.00
93039C	2017-07-22 12:02:00+03	56000.00
9303CB	2017-08-06 08:59:00+03	36600.00
930420	2017-08-07 22:02:00+03	27200.00
930474	2017-08-11 17:36:00+03	26700.00
93048D	2017-06-27 07:06:00+03	56000.00
9304CD	2017-07-01 16:31:00+03	52000.00
930558	2017-07-06 11:52:00+03	23900.00
93056E	2017-08-09 08:43:00+03	26000.00
9305E0	2017-08-11 19:32:00+03	168700.00
930648	2017-08-01 05:54:00+03	26800.00
93064E	2017-08-04 02:41:00+03	31000.00
9306AE	2017-07-30 06:57:00+03	46300.00
9306C9	2017-07-25 15:03:00+03	42700.00
93070D	2017-08-05 17:50:00+03	29800.00
93077F	2017-07-09 07:06:00+03	114800.00
93082A	2017-07-12 23:40:00+03	153300.00
930887	2017-07-01 10:41:00+03	46000.00
9308E5	2017-07-24 16:38:00+03	44000.00
93092A	2017-08-04 20:41:00+03	80800.00
930A08	2017-08-11 15:36:00+03	137600.00
930AAA	2017-07-20 23:41:00+03	31800.00
930B58	2017-08-07 10:02:00+03	23400.00
930BF3	2017-07-26 08:10:00+03	118600.00
930C1F	2017-08-11 00:39:00+03	14700.00
930C85	2017-07-25 20:52:00+03	47600.00
930C8C	2017-08-06 16:30:00+03	51900.00
930CBD	2017-07-22 00:41:00+03	82200.00
930CE2	2017-07-10 11:22:00+03	76600.00
930D06	2017-07-31 17:22:00+03	100200.00
930D91	2017-08-11 17:39:00+03	80300.00
930E34	2017-07-22 00:43:00+03	100600.00
930E40	2017-07-19 05:17:00+03	146300.00
930E41	2017-07-22 11:23:00+03	100600.00
930E67	2017-07-29 07:23:00+03	31900.00
930E9D	2017-08-01 18:59:00+03	84500.00
930F01	2017-07-20 20:21:00+03	31400.00
930F60	2017-07-26 12:12:00+03	46300.00
930F83	2017-06-27 17:42:00+03	280000.00
930FB1	2017-07-19 12:09:00+03	30400.00
931015	2017-07-18 21:53:00+03	75700.00
93104A	2017-08-13 22:36:00+03	65000.00
931066	2017-08-09 13:25:00+03	32700.00
93109C	2017-08-08 20:40:00+03	46400.00
9310B2	2017-07-20 03:16:00+03	30800.00
931112	2017-08-09 18:03:00+03	137600.00
931170	2017-07-24 09:43:00+03	46300.00
93117F	2017-08-05 16:02:00+03	23200.00
9311E2	2017-08-09 19:56:00+03	69200.00
9311EE	2017-07-14 09:24:00+03	18600.00
931205	2017-08-05 16:48:00+03	56600.00
931218	2017-07-15 16:44:00+03	109600.00
931234	2017-08-15 08:18:00+03	33300.00
931236	2017-08-14 10:32:00+03	295600.00
93123F	2017-07-24 14:48:00+03	40400.00
931266	2017-08-08 17:40:00+03	77500.00
9312F2	2017-08-05 04:08:00+03	58000.00
931338	2017-08-11 23:40:00+03	125200.00
93133E	2017-08-15 14:58:00+03	6700.00
931344	2017-07-18 17:25:00+03	83100.00
931445	2017-07-31 08:09:00+03	18600.00
931516	2017-08-13 17:10:00+03	32200.00
9315EA	2017-07-10 03:14:00+03	14000.00
9315F7	2017-07-07 06:18:00+03	46400.00
931610	2017-07-13 23:07:00+03	32200.00
931672	2017-07-20 03:27:00+03	168300.00
93167A	2017-08-01 14:56:00+03	46300.00
931688	2017-08-12 22:25:00+03	52000.00
93168F	2017-08-05 12:22:00+03	89800.00
931750	2017-07-22 07:55:00+03	28800.00
931751	2017-07-06 17:03:00+03	135000.00
931767	2017-08-14 01:57:00+03	109500.00
9317F6	2017-07-06 05:23:00+03	90600.00
931815	2017-07-17 12:40:00+03	397100.00
931838	2017-07-24 13:23:00+03	75300.00
931891	2017-07-20 10:26:00+03	234100.00
931945	2017-07-31 03:10:00+03	211400.00
9319EF	2017-08-14 21:54:00+03	142600.00
931A09	2017-08-06 20:38:00+03	48800.00
931A29	2017-07-28 23:07:00+03	66600.00
931A52	2017-07-09 05:06:00+03	23200.00
931A55	2017-08-01 17:45:00+03	40600.00
931AA3	2017-07-19 11:11:00+03	73300.00
931ADE	2017-08-01 16:46:00+03	124200.00
931B48	2017-07-15 20:39:00+03	12600.00
931B92	2017-07-29 22:40:00+03	141100.00
931B9F	2017-08-03 08:40:00+03	100600.00
931BCF	2017-07-04 01:17:00+03	10800.00
931C90	2017-07-25 18:41:00+03	45200.00
931CF7	2017-07-11 15:01:00+03	37900.00
931D17	2017-08-10 02:46:00+03	32800.00
931D4C	2017-07-08 08:41:00+03	25100.00
931D87	2017-08-01 13:08:00+03	422200.00
931E2A	2017-07-15 00:27:00+03	68800.00
931E2D	2017-07-08 15:09:00+03	12600.00
931E8A	2017-07-24 20:08:00+03	54400.00
931EE3	2017-08-15 09:14:00+03	52600.00
931F51	2017-07-16 02:59:00+03	12400.00
93200F	2017-07-07 10:37:00+03	282000.00
932018	2017-08-14 07:35:00+03	137600.00
93207C	2017-07-26 23:28:00+03	28000.00
9320C6	2017-07-01 07:47:00+03	70800.00
9320CA	2017-07-10 08:25:00+03	47100.00
932160	2017-08-03 16:18:00+03	88900.00
9321CB	2017-07-25 09:44:00+03	95600.00
932226	2017-08-06 23:51:00+03	119500.00
932281	2017-07-23 21:31:00+03	32800.00
932359	2017-07-16 10:01:00+03	142300.00
932370	2017-08-04 15:03:00+03	6800.00
932389	2017-08-15 11:51:00+03	273400.00
9323C0	2017-07-13 04:05:00+03	72400.00
9323CA	2017-07-13 04:22:00+03	203000.00
9323D0	2017-07-04 04:15:00+03	17800.00
932424	2017-08-04 15:10:00+03	47500.00
932437	2017-07-30 08:30:00+03	43800.00
932449	2017-07-24 14:32:00+03	151300.00
9324B4	2017-07-01 21:59:00+03	199700.00
9324C3	2017-08-07 13:57:00+03	26000.00
932513	2017-07-06 23:56:00+03	46900.00
932581	2017-07-30 10:09:00+03	95000.00
9325A9	2017-07-11 09:54:00+03	29600.00
9325E1	2017-08-11 16:17:00+03	52900.00
932640	2017-07-05 07:37:00+03	167500.00
93268D	2017-08-09 20:03:00+03	36600.00
93269F	2017-08-04 20:00:00+03	133200.00
93272F	2017-08-02 17:20:00+03	38400.00
932822	2017-08-04 18:44:00+03	9200.00
93284D	2017-07-12 00:37:00+03	111600.00
93286E	2017-08-09 21:56:00+03	31400.00
932894	2017-07-19 15:07:00+03	55800.00
9328A8	2017-07-10 16:34:00+03	94000.00
9328FE	2017-07-17 05:01:00+03	69900.00
932919	2017-08-14 06:30:00+03	118900.00
9329DB	2017-07-30 04:31:00+03	37000.00
9329F4	2017-07-07 21:11:00+03	100600.00
932A1B	2017-07-15 05:54:00+03	75300.00
932A2E	2017-06-30 04:47:00+03	67600.00
932A52	2017-07-20 20:39:00+03	82300.00
932AEA	2017-07-19 16:11:00+03	135200.00
932B8F	2017-08-09 19:35:00+03	56600.00
932BB3	2017-07-15 03:52:00+03	26000.00
932C0D	2017-08-01 07:02:00+03	202100.00
932C8A	2017-07-14 02:34:00+03	167500.00
932CB4	2017-08-07 16:33:00+03	20000.00
932CD9	2017-07-21 04:00:00+03	55800.00
932CE5	2017-08-05 12:09:00+03	270700.00
932D45	2017-07-28 20:42:00+03	131600.00
932D58	2017-07-20 23:10:00+03	40800.00
932DA2	2017-08-15 03:21:00+03	17600.00
932DB0	2017-08-06 09:04:00+03	27200.00
932DB1	2017-07-31 21:00:00+03	55800.00
932DB5	2017-07-27 16:47:00+03	19500.00
932DC7	2017-08-14 23:02:00+03	226400.00
932E0C	2017-07-21 15:23:00+03	137600.00
932E1B	2017-07-21 07:19:00+03	70600.00
932E48	2017-07-13 03:35:00+03	31400.00
932E7B	2017-08-01 07:03:00+03	31200.00
932E8B	2017-07-16 08:58:00+03	31600.00
932E9C	2017-07-15 02:33:00+03	19600.00
932EAA	2017-07-09 08:40:00+03	47000.00
932EC3	2017-07-29 01:34:00+03	12000.00
932EEF	2017-07-10 21:27:00+03	12600.00
932EF9	2017-08-05 03:20:00+03	246000.00
932F26	2017-07-04 02:46:00+03	118200.00
932F2B	2017-08-15 11:28:00+03	133200.00
932F5A	2017-07-03 14:46:00+03	48700.00
932F62	2017-07-08 18:25:00+03	21000.00
932FC2	2017-07-09 16:22:00+03	57800.00
932FD3	2017-07-26 19:21:00+03	57700.00
932FDD	2017-07-24 01:09:00+03	223700.00
932FE7	2017-07-10 14:26:00+03	46300.00
93307F	2017-08-01 23:06:00+03	29600.00
9330C6	2017-07-07 06:48:00+03	43400.00
933132	2017-07-06 10:59:00+03	67700.00
933187	2017-07-18 12:57:00+03	49600.00
9331A3	2017-07-16 20:24:00+03	70700.00
933223	2017-08-02 08:43:00+03	78300.00
933275	2017-07-28 19:04:00+03	42700.00
933283	2017-07-05 07:01:00+03	40800.00
933317	2017-06-27 09:39:00+03	19600.00
933361	2017-08-08 14:47:00+03	39100.00
933373	2017-08-14 13:46:00+03	89700.00
9333D5	2017-07-03 00:06:00+03	6700.00
933428	2017-07-19 07:41:00+03	48400.00
933442	2017-07-23 22:01:00+03	125400.00
9334AC	2017-07-22 04:05:00+03	35600.00
933518	2017-07-01 16:19:00+03	104300.00
93351B	2017-08-07 14:55:00+03	52000.00
93354A	2017-07-23 20:23:00+03	26600.00
93356C	2017-07-08 18:32:00+03	21400.00
9335B6	2017-07-14 03:10:00+03	65500.00
9335CF	2017-08-04 07:20:00+03	85700.00
9335D6	2017-07-29 17:21:00+03	47200.00
933646	2017-07-30 05:14:00+03	90600.00
9336DB	2017-07-11 09:12:00+03	6700.00
93372A	2017-08-10 06:53:00+03	68800.00
93375A	2017-08-10 21:01:00+03	38500.00
933791	2017-08-14 12:10:00+03	81300.00
9337BF	2017-08-08 05:20:00+03	12400.00
93382B	2017-07-15 03:57:00+03	87400.00
933893	2017-08-03 13:15:00+03	64100.00
9338F7	2017-08-07 13:40:00+03	87600.00
933977	2017-07-30 20:05:00+03	57500.00
9339EF	2017-07-03 12:54:00+03	12600.00
933A93	2017-08-04 17:57:00+03	185600.00
933AE3	2017-08-07 16:50:00+03	120700.00
933AEF	2017-08-09 10:27:00+03	25900.00
933B4A	2017-07-29 18:45:00+03	14000.00
933BBB	2017-07-20 05:31:00+03	19300.00
933BD6	2017-07-31 07:37:00+03	39800.00
933CCA	2017-07-22 21:27:00+03	58800.00
933D23	2017-08-05 19:29:00+03	23200.00
933E46	2017-07-09 17:07:00+03	28700.00
933EA7	2017-08-12 13:40:00+03	48800.00
933F4B	2017-07-29 19:45:00+03	32800.00
933FB1	2017-07-01 02:19:00+03	153300.00
934087	2017-08-10 07:37:00+03	55800.00
9340EC	2017-08-04 08:26:00+03	56900.00
9341CB	2017-06-30 16:31:00+03	37900.00
934220	2017-07-25 19:45:00+03	31600.00
934253	2017-07-05 22:55:00+03	16400.00
934288	2017-07-10 23:37:00+03	118100.00
93429C	2017-07-19 22:54:00+03	57500.00
9342EB	2017-07-14 11:55:00+03	166100.00
934333	2017-08-08 09:25:00+03	58600.00
934343	2017-07-28 00:56:00+03	57800.00
934349	2017-07-12 04:21:00+03	38500.00
934364	2017-08-02 01:36:00+03	135400.00
934365	2017-07-30 01:39:00+03	47200.00
9343A1	2017-08-13 12:02:00+03	151500.00
934418	2017-08-07 07:13:00+03	55800.00
934429	2017-07-20 21:43:00+03	89200.00
93444F	2017-08-06 03:19:00+03	48100.00
934455	2017-07-10 09:52:00+03	6000.00
934466	2017-07-10 15:11:00+03	14400.00
93449A	2017-07-28 21:03:00+03	44000.00
934578	2017-07-25 23:26:00+03	62700.00
9345A6	2017-07-08 09:43:00+03	56200.00
9345AB	2017-06-27 22:25:00+03	18600.00
9345FF	2017-07-24 12:37:00+03	97500.00
93460E	2017-07-10 07:27:00+03	47400.00
934631	2017-08-02 23:40:00+03	23200.00
93465F	2017-07-30 05:14:00+03	97600.00
9346D5	2017-08-10 16:18:00+03	40800.00
9346DA	2017-07-08 05:10:00+03	51000.00
93470F	2017-07-29 01:39:00+03	31600.00
93471A	2017-07-06 09:30:00+03	189200.00
93472E	2017-08-05 06:25:00+03	54000.00
9347D9	2017-07-01 00:41:00+03	24000.00
9347E5	2017-07-06 10:22:00+03	123000.00
934839	2017-07-21 12:34:00+03	202800.00
93489A	2017-08-13 03:09:00+03	40800.00
9348AA	2017-08-13 18:45:00+03	24700.00
934975	2017-08-13 12:33:00+03	92800.00
934995	2017-07-25 08:56:00+03	408500.00
9349E7	2017-07-02 11:29:00+03	39000.00
934B22	2017-08-14 20:31:00+03	12600.00
934CDD	2017-08-08 17:06:00+03	149000.00
934CE2	2017-07-21 21:08:00+03	266400.00
934D1A	2017-07-05 03:45:00+03	173800.00
934D26	2017-07-07 21:58:00+03	116700.00
934D28	2017-08-14 22:16:00+03	80100.00
934D63	2017-07-20 17:22:00+03	34700.00
934D83	2017-07-21 05:56:00+03	105100.00
934D96	2017-07-29 02:58:00+03	78800.00
934DB3	2017-08-14 20:45:00+03	119500.00
934DEF	2017-07-31 08:43:00+03	58600.00
934E52	2017-07-01 17:17:00+03	50100.00
934E8A	2017-08-05 14:38:00+03	47100.00
934EEA	2017-07-23 21:13:00+03	38200.00
934EEE	2017-08-13 23:47:00+03	45100.00
934F28	2017-08-07 20:37:00+03	248400.00
93502F	2017-07-23 20:48:00+03	43600.00
93506C	2017-08-08 07:21:00+03	40000.00
9350DA	2017-08-02 08:35:00+03	174900.00
9350FA	2017-07-17 09:47:00+03	51900.00
93511B	2017-07-19 22:43:00+03	179200.00
93512A	2017-07-18 09:13:00+03	86300.00
935157	2017-08-10 12:55:00+03	28800.00
93515F	2017-07-23 20:12:00+03	23200.00
935168	2017-07-15 06:49:00+03	47000.00
935172	2017-08-15 07:22:00+03	93900.00
935255	2017-07-15 02:21:00+03	57800.00
9352B7	2017-07-05 01:38:00+03	55800.00
9352CC	2017-07-05 15:40:00+03	28800.00
93530B	2017-07-06 19:29:00+03	40600.00
935326	2017-07-03 02:59:00+03	142800.00
935335	2017-07-21 13:13:00+03	114800.00
9353B8	2017-07-18 06:33:00+03	12000.00
9353FA	2017-07-16 10:02:00+03	55600.00
93546A	2017-07-09 03:26:00+03	76400.00
93547F	2017-07-24 01:55:00+03	73600.00
9354F3	2017-07-11 23:08:00+03	62600.00
935514	2017-07-19 07:43:00+03	55800.00
93553C	2017-07-03 00:31:00+03	65400.00
935543	2017-07-16 20:44:00+03	21200.00
935686	2017-07-21 19:59:00+03	128800.00
9356A4	2017-07-28 01:15:00+03	199700.00
9356AE	2017-07-08 04:20:00+03	88800.00
93571D	2017-07-19 01:57:00+03	67000.00
93579D	2017-08-07 17:40:00+03	133100.00
935876	2017-07-17 19:45:00+03	66300.00
935899	2017-07-31 06:40:00+03	64700.00
93589C	2017-07-12 10:26:00+03	7400.00
9358BE	2017-08-10 06:03:00+03	115000.00
93598B	2017-08-06 09:00:00+03	74400.00
9359AC	2017-07-12 07:01:00+03	47100.00
935A04	2017-07-27 02:56:00+03	55800.00
935A54	2017-08-08 15:52:00+03	51600.00
935A59	2017-08-09 06:10:00+03	67600.00
935AC8	2017-08-05 04:50:00+03	6800.00
935AEE	2017-07-30 05:20:00+03	52300.00
935AFA	2017-08-01 12:23:00+03	37700.00
935B10	2017-07-24 00:03:00+03	30200.00
935B40	2017-08-05 02:03:00+03	8200.00
935B7E	2017-08-15 09:13:00+03	16400.00
935BC2	2017-06-30 10:23:00+03	57200.00
935BF1	2017-07-09 08:00:00+03	122300.00
935C66	2017-07-13 16:17:00+03	28000.00
935CC1	2017-08-06 23:24:00+03	43600.00
935CC3	2017-07-08 13:07:00+03	86500.00
935CE6	2017-07-06 01:03:00+03	111600.00
935D04	2017-07-13 13:15:00+03	92000.00
935DA1	2017-08-01 09:46:00+03	19600.00
935DB7	2017-07-21 07:24:00+03	36200.00
935DBD	2017-07-01 07:45:00+03	56000.00
935DCD	2017-07-06 22:47:00+03	59800.00
935DE7	2017-06-28 18:46:00+03	18500.00
935E61	2017-08-12 22:33:00+03	85000.00
935E6C	2017-07-22 16:23:00+03	117600.00
935EB0	2017-07-15 10:08:00+03	23600.00
935FC5	2017-08-08 02:02:00+03	27200.00
935FDF	2017-07-19 13:01:00+03	67000.00
935FFC	2017-08-08 02:27:00+03	25400.00
936005	2017-07-21 23:10:00+03	76600.00
936072	2017-07-29 05:22:00+03	9200.00
9360AB	2017-07-14 12:09:00+03	67600.00
9360D2	2017-07-30 13:48:00+03	44000.00
93612B	2017-08-03 02:04:00+03	44000.00
9361E5	2017-08-11 05:41:00+03	82300.00
9361F3	2017-07-17 16:47:00+03	37200.00
936247	2017-07-25 00:04:00+03	418400.00
936291	2017-07-14 23:33:00+03	169000.00
936337	2017-06-30 12:27:00+03	32800.00
93637E	2017-08-02 06:35:00+03	9800.00
9363BA	2017-07-26 23:44:00+03	27700.00
936436	2017-07-13 01:37:00+03	27200.00
936478	2017-08-08 15:31:00+03	12600.00
9364A7	2017-07-07 10:04:00+03	194200.00
936539	2017-07-03 18:59:00+03	23200.00
936573	2017-08-14 22:33:00+03	93900.00
936578	2017-08-13 20:11:00+03	52400.00
9365F8	2017-08-03 03:47:00+03	34800.00
9366CE	2017-08-10 09:42:00+03	29100.00
936709	2017-07-18 12:27:00+03	199200.00
9367BC	2017-08-05 10:22:00+03	62800.00
9367BE	2017-06-30 16:41:00+03	16400.00
9367C7	2017-07-01 19:08:00+03	280000.00
9367DD	2017-07-31 21:29:00+03	12600.00
93687B	2017-08-07 05:26:00+03	42900.00
93688E	2017-07-16 04:55:00+03	57600.00
93689C	2017-07-14 02:22:00+03	286600.00
9368C2	2017-07-22 15:01:00+03	66000.00
9368C5	2017-08-13 05:27:00+03	34000.00
936907	2017-07-22 11:53:00+03	62600.00
93690B	2017-07-16 20:32:00+03	39800.00
93691E	2017-08-02 12:25:00+03	88900.00
93694C	2017-07-28 09:52:00+03	123000.00
93699A	2017-07-12 11:57:00+03	54800.00
936AA1	2017-08-03 20:37:00+03	106600.00
936AD2	2017-08-08 19:42:00+03	73600.00
936AD8	2017-06-27 19:59:00+03	14900.00
936B89	2017-08-10 00:03:00+03	113700.00
936BAF	2017-08-11 04:54:00+03	136200.00
936C49	2017-07-17 19:35:00+03	38600.00
936C77	2017-06-30 13:34:00+03	83500.00
936C7F	2017-08-12 11:17:00+03	77900.00
936CD8	2017-07-29 11:52:00+03	31600.00
936CDD	2017-07-14 23:25:00+03	25000.00
936D83	2017-07-12 10:38:00+03	43600.00
936DC1	2017-07-05 12:13:00+03	133100.00
936DDA	2017-08-05 11:14:00+03	89600.00
936DFB	2017-07-26 08:02:00+03	55800.00
936E4D	2017-08-12 00:23:00+03	14400.00
936E93	2017-07-05 07:35:00+03	6700.00
936EAE	2017-08-04 15:35:00+03	36200.00
936EB1	2017-07-27 18:57:00+03	37900.00
936EC5	2017-07-31 19:32:00+03	61800.00
936EFC	2017-07-16 15:18:00+03	67500.00
936F06	2017-07-07 13:02:00+03	265700.00
936F17	2017-08-07 14:17:00+03	58100.00
936FEC	2017-07-08 03:22:00+03	14000.00
93705E	2017-08-03 03:22:00+03	119700.00
937082	2017-07-20 18:19:00+03	26000.00
9370B7	2017-08-02 15:30:00+03	81200.00
9370F1	2017-07-17 12:24:00+03	56000.00
9370F5	2017-08-09 09:45:00+03	84800.00
937172	2017-07-10 22:57:00+03	29100.00
9371A9	2017-08-06 18:50:00+03	21400.00
9371E4	2017-08-05 10:47:00+03	120800.00
937223	2017-08-01 02:27:00+03	114200.00
937246	2017-07-15 22:07:00+03	166000.00
937248	2017-08-13 06:54:00+03	135300.00
937270	2017-07-01 21:47:00+03	46300.00
937286	2017-07-25 23:55:00+03	167400.00
937293	2017-07-26 16:58:00+03	6000.00
9372C4	2017-07-13 05:36:00+03	75300.00
937303	2017-07-06 17:47:00+03	64900.00
937308	2017-07-18 22:26:00+03	70700.00
93731D	2017-08-13 17:22:00+03	61800.00
937321	2017-08-08 12:52:00+03	87000.00
937335	2017-08-14 12:48:00+03	42600.00
937341	2017-07-07 12:47:00+03	32300.00
93740E	2017-07-24 12:59:00+03	93600.00
9374E0	2017-07-02 09:45:00+03	18800.00
93752A	2017-07-31 20:06:00+03	90000.00
9375AB	2017-07-05 08:27:00+03	86200.00
9375CF	2017-07-09 15:30:00+03	68400.00
937665	2017-07-23 19:08:00+03	254900.00
93766C	2017-07-02 22:11:00+03	182300.00
93767E	2017-07-12 20:19:00+03	51800.00
937698	2017-07-12 05:19:00+03	133200.00
937728	2017-08-12 11:20:00+03	48800.00
937738	2017-08-15 16:29:00+03	129000.00
93779C	2017-07-12 05:40:00+03	78600.00
9377D3	2017-07-24 16:47:00+03	24800.00
9377FE	2017-08-13 12:05:00+03	135200.00
93783E	2017-08-15 06:44:00+03	37100.00
937858	2017-08-15 03:25:00+03	88100.00
93788C	2017-07-12 10:10:00+03	41200.00
9378A1	2017-08-13 08:03:00+03	37100.00
9378CE	2017-07-09 18:04:00+03	135200.00
937902	2017-08-05 13:17:00+03	52600.00
937912	2017-07-24 03:38:00+03	48800.00
9379A8	2017-07-07 07:03:00+03	91100.00
9379AC	2017-07-27 11:30:00+03	124000.00
9379E9	2017-07-06 07:59:00+03	23200.00
937A1A	2017-07-18 16:10:00+03	79000.00
937A21	2017-07-15 00:46:00+03	44600.00
937A37	2017-08-12 11:59:00+03	266400.00
937A5D	2017-06-30 17:38:00+03	167500.00
937A85	2017-07-21 05:17:00+03	74900.00
937A88	2017-07-29 02:12:00+03	69500.00
937AB6	2017-08-08 04:29:00+03	112000.00
937AC0	2017-08-11 02:29:00+03	40200.00
937ACE	2017-08-02 22:37:00+03	6000.00
937B0B	2017-08-07 17:41:00+03	57800.00
937B13	2017-08-15 13:33:00+03	62100.00
937B5D	2017-08-09 18:12:00+03	57700.00
937B74	2017-08-10 15:07:00+03	47800.00
937BD3	2017-08-09 21:28:00+03	218600.00
937BDE	2017-07-17 23:27:00+03	55800.00
937C49	2017-06-29 17:00:00+03	25100.00
937DAB	2017-07-21 10:24:00+03	96800.00
937DBA	2017-07-27 19:45:00+03	85000.00
937DE1	2017-08-05 13:13:00+03	128800.00
937DE4	2017-07-03 19:29:00+03	86500.00
937DF7	2017-07-04 14:06:00+03	133100.00
937E17	2017-07-23 22:02:00+03	40400.00
937E1F	2017-07-04 15:24:00+03	35100.00
937E23	2017-08-02 14:06:00+03	29600.00
937E61	2017-07-08 15:49:00+03	55800.00
937ECA	2017-07-08 23:00:00+03	52900.00
937EFE	2017-07-18 11:19:00+03	86600.00
937F0B	2017-08-11 23:30:00+03	30100.00
937F13	2017-07-23 12:31:00+03	19600.00
937F17	2017-07-03 06:12:00+03	36200.00
937F87	2017-08-03 16:12:00+03	69500.00
937FF4	2017-07-21 20:15:00+03	59800.00
93800E	2017-07-26 09:55:00+03	44300.00
938062	2017-07-04 17:14:00+03	101200.00
9380A0	2017-07-14 16:20:00+03	16400.00
9380C3	2017-07-06 10:06:00+03	41400.00
938160	2017-07-17 02:46:00+03	172100.00
9381E9	2017-08-13 16:53:00+03	113200.00
93820F	2017-07-17 20:22:00+03	14100.00
938227	2017-08-12 23:53:00+03	83200.00
93828D	2017-07-23 21:53:00+03	288700.00
9382AE	2017-07-06 12:59:00+03	70200.00
9382B0	2017-08-04 19:12:00+03	269200.00
9382B4	2017-08-02 12:50:00+03	36900.00
938331	2017-07-25 15:30:00+03	44800.00
938355	2017-07-08 02:12:00+03	53400.00
93839C	2017-08-13 09:41:00+03	134800.00
938412	2017-07-28 05:36:00+03	13000.00
9384B3	2017-08-06 10:25:00+03	15000.00
938582	2017-08-14 19:30:00+03	75300.00
938583	2017-07-19 07:08:00+03	14800.00
9385A9	2017-07-08 02:38:00+03	23400.00
9385BA	2017-07-27 15:13:00+03	68000.00
9385DF	2017-08-10 12:38:00+03	166100.00
938662	2017-07-28 04:38:00+03	67100.00
938693	2017-08-01 20:14:00+03	81300.00
9386FC	2017-07-21 12:47:00+03	49200.00
93871D	2017-08-04 11:14:00+03	56000.00
93874A	2017-07-06 03:00:00+03	87100.00
938780	2017-07-06 12:03:00+03	40800.00
9387A0	2017-07-02 14:02:00+03	17200.00
9387AC	2017-07-16 00:04:00+03	15800.00
9387CF	2017-07-27 06:42:00+03	38800.00
93886B	2017-07-29 13:42:00+03	22000.00
938899	2017-07-18 10:16:00+03	175800.00
9388E3	2017-07-09 11:04:00+03	134400.00
938A11	2017-07-11 12:44:00+03	112000.00
938A26	2017-07-27 06:14:00+03	32700.00
938A32	2017-07-06 19:43:00+03	184300.00
938A5A	2017-07-31 21:18:00+03	38800.00
938A5D	2017-07-07 00:39:00+03	45500.00
938A77	2017-07-15 17:37:00+03	22200.00
938A9E	2017-07-01 17:45:00+03	61800.00
938AC3	2017-07-09 12:37:00+03	161100.00
938AD5	2017-08-06 18:59:00+03	48800.00
938AD6	2017-08-01 03:39:00+03	75600.00
938B16	2017-07-17 06:57:00+03	29800.00
938B35	2017-07-11 13:47:00+03	224000.00
938BA9	2017-07-22 02:47:00+03	57400.00
938BB8	2017-07-09 00:43:00+03	369000.00
938C03	2017-07-10 17:08:00+03	101800.00
938C47	2017-07-01 22:14:00+03	56900.00
938C78	2017-07-31 06:18:00+03	96200.00
938CAA	2017-07-15 23:27:00+03	74300.00
938CDA	2017-08-11 18:59:00+03	31400.00
938D02	2017-07-07 14:02:00+03	47500.00
938D9B	2017-07-20 18:41:00+03	132800.00
938DCE	2017-06-28 21:56:00+03	59000.00
938E36	2017-08-14 03:38:00+03	270800.00
938E4C	2017-06-30 17:35:00+03	231800.00
938E52	2017-07-25 16:02:00+03	72200.00
938E8A	2017-08-15 14:35:00+03	40100.00
938E92	2017-07-04 02:55:00+03	51800.00
938ED3	2017-07-06 19:46:00+03	166000.00
938ED7	2017-07-06 13:37:00+03	58600.00
938EE6	2017-07-31 18:53:00+03	139400.00
938F57	2017-08-09 14:44:00+03	44600.00
938F89	2017-07-25 12:58:00+03	38800.00
938F9C	2017-07-19 10:36:00+03	46500.00
938FF3	2017-07-27 21:45:00+03	27200.00
939000	2017-07-20 23:28:00+03	229900.00
939037	2017-07-12 21:31:00+03	36200.00
939055	2017-07-20 03:04:00+03	38000.00
9390D5	2017-07-24 15:56:00+03	27800.00
93910D	2017-07-19 00:46:00+03	52400.00
93911E	2017-07-22 09:52:00+03	20600.00
939196	2017-07-05 13:27:00+03	27200.00
9391A4	2017-07-28 09:10:00+03	51900.00
9391CA	2017-07-19 08:16:00+03	20200.00
93920F	2017-07-29 10:24:00+03	96600.00
939319	2017-07-30 04:47:00+03	55800.00
93937F	2017-07-12 12:24:00+03	31400.00
939387	2017-07-30 02:55:00+03	27300.00
9393B0	2017-08-02 05:32:00+03	215500.00
9393D6	2017-07-28 18:09:00+03	130400.00
9393FB	2017-07-06 10:42:00+03	46300.00
93942F	2017-07-13 05:38:00+03	9800.00
9394CF	2017-07-16 02:00:00+03	300400.00
9394D8	2017-07-23 01:58:00+03	270800.00
93952B	2017-08-06 08:07:00+03	95600.00
939589	2017-07-06 10:08:00+03	60700.00
9395F3	2017-07-06 05:57:00+03	43200.00
9395FF	2017-08-11 07:04:00+03	67600.00
939604	2017-07-07 01:09:00+03	99200.00
939694	2017-07-18 15:25:00+03	155600.00
9396C6	2017-08-14 04:29:00+03	369000.00
9396CE	2017-08-11 12:20:00+03	20200.00
93970E	2017-07-27 14:25:00+03	23200.00
93972B	2017-08-12 08:28:00+03	51600.00
93978B	2017-07-20 14:19:00+03	55800.00
93981C	2017-07-14 22:36:00+03	89600.00
93984B	2017-08-09 14:46:00+03	58200.00
93988C	2017-07-27 05:24:00+03	31400.00
9398B0	2017-07-24 15:29:00+03	28800.00
93998C	2017-08-14 09:58:00+03	123000.00
93999C	2017-07-28 12:35:00+03	55800.00
9399B2	2017-08-11 22:03:00+03	76600.00
939A43	2017-07-03 12:49:00+03	67200.00
939A7D	2017-07-06 06:37:00+03	12000.00
939ACA	2017-08-14 21:46:00+03	145400.00
939AE1	2017-07-26 22:34:00+03	22600.00
939B24	2017-07-15 05:05:00+03	123000.00
939B5E	2017-08-13 01:58:00+03	56000.00
939B97	2017-08-03 18:05:00+03	23200.00
939BA3	2017-07-09 11:56:00+03	231800.00
939BDA	2017-08-08 02:47:00+03	115800.00
939C05	2017-07-13 14:39:00+03	64700.00
939C14	2017-07-29 02:33:00+03	54400.00
939C6E	2017-07-28 22:07:00+03	90400.00
939C8E	2017-08-14 17:09:00+03	83000.00
939CB7	2017-08-12 21:00:00+03	101200.00
939CEA	2017-07-01 13:44:00+03	86500.00
939D1E	2017-07-01 12:04:00+03	265600.00
939DB9	2017-07-13 20:22:00+03	133700.00
939E07	2017-08-08 18:15:00+03	56000.00
939E09	2017-07-28 17:42:00+03	78600.00
939E5B	2017-07-24 21:39:00+03	45000.00
939E9D	2017-08-09 01:53:00+03	20200.00
939EDC	2017-07-28 12:07:00+03	74900.00
939EE4	2017-08-10 20:56:00+03	24200.00
939F02	2017-07-31 19:18:00+03	96800.00
939F1A	2017-07-20 11:59:00+03	32800.00
939F90	2017-08-06 02:22:00+03	23200.00
939F96	2017-07-02 15:03:00+03	8400.00
93A06D	2017-06-30 17:46:00+03	34000.00
93A086	2017-07-16 20:46:00+03	141200.00
93A089	2017-07-21 12:29:00+03	57200.00
93A09E	2017-07-18 12:18:00+03	31900.00
93A120	2017-07-06 21:48:00+03	57800.00
93A1B2	2017-07-26 19:03:00+03	31900.00
93A284	2017-08-04 21:03:00+03	25400.00
93A2DB	2017-07-06 08:31:00+03	23400.00
93A2FA	2017-08-03 18:37:00+03	42700.00
93A320	2017-08-02 21:16:00+03	43400.00
93A326	2017-07-28 13:01:00+03	22000.00
93A3A9	2017-07-25 23:25:00+03	133200.00
93A3CB	2017-07-18 16:47:00+03	23200.00
93A3E8	2017-08-04 03:25:00+03	85400.00
93A406	2017-07-10 00:41:00+03	189200.00
93A45C	2017-07-24 06:06:00+03	241400.00
93A469	2017-07-07 07:54:00+03	70600.00
93A4AC	2017-07-27 07:27:00+03	46300.00
93A4EA	2017-07-13 02:48:00+03	8000.00
93A50C	2017-07-27 22:15:00+03	26600.00
93A5AE	2017-07-30 05:04:00+03	59800.00
93A5BB	2017-07-26 01:11:00+03	111700.00
93A5CD	2017-08-08 10:50:00+03	40000.00
93A615	2017-07-24 02:06:00+03	28000.00
93A63F	2017-07-17 14:10:00+03	36000.00
93A6ED	2017-07-02 01:37:00+03	30900.00
93A82B	2017-07-03 00:37:00+03	116400.00
93A89D	2017-07-11 02:29:00+03	131600.00
93A979	2017-08-08 19:22:00+03	81200.00
93A9BE	2017-08-15 05:48:00+03	29200.00
93A9E6	2017-08-05 17:52:00+03	81600.00
93AA0D	2017-07-09 19:28:00+03	40100.00
93AAC6	2017-07-05 20:43:00+03	32800.00
93AB3C	2017-08-09 10:51:00+03	94900.00
93AB3D	2017-08-10 04:50:00+03	166900.00
93AB43	2017-07-03 03:39:00+03	80000.00
93AB7F	2017-07-20 19:03:00+03	65600.00
93AB9E	2017-07-19 20:03:00+03	12400.00
93ABA0	2017-07-27 21:40:00+03	19600.00
93ABA9	2017-07-08 21:06:00+03	144700.00
93AC0F	2017-08-01 18:06:00+03	86600.00
93AC44	2017-08-08 23:44:00+03	57800.00
93AC47	2017-07-10 21:29:00+03	45100.00
93AC66	2017-07-26 12:19:00+03	21200.00
93ACA2	2017-08-03 13:19:00+03	8800.00
93ACA9	2017-07-31 22:43:00+03	39800.00
93ACB4	2017-07-25 05:41:00+03	8000.00
93ACED	2017-07-01 09:41:00+03	83200.00
93ACF2	2017-07-16 17:05:00+03	101200.00
93ACFD	2017-07-11 23:45:00+03	28000.00
93AD39	2017-07-18 09:22:00+03	93400.00
93AD4E	2017-07-20 08:58:00+03	78800.00
93AD83	2017-08-14 11:25:00+03	24000.00
93ADA7	2017-07-08 15:10:00+03	311600.00
93AE07	2017-07-16 15:52:00+03	23600.00
93AE20	2017-07-28 10:27:00+03	28000.00
93AE4D	2017-07-13 04:22:00+03	44800.00
93AE62	2017-07-08 19:26:00+03	21800.00
93AE6B	2017-07-11 15:47:00+03	46400.00
93AEC6	2017-07-30 02:23:00+03	19600.00
93AEC7	2017-07-28 08:27:00+03	42800.00
93AED8	2017-07-18 22:31:00+03	74400.00
93AF25	2017-08-02 20:35:00+03	316500.00
93AF4D	2017-07-04 18:04:00+03	57500.00
93AF54	2017-08-05 07:03:00+03	23200.00
93AF5E	2017-07-15 01:03:00+03	265700.00
93AFA2	2017-07-25 08:19:00+03	42000.00
93AFEA	2017-07-08 05:00:00+03	50000.00
93B05D	2017-07-18 13:29:00+03	167200.00
93B05E	2017-07-25 21:54:00+03	13400.00
93B0BB	2017-07-07 04:16:00+03	14400.00
93B156	2017-07-23 03:44:00+03	39500.00
93B16C	2017-07-19 21:53:00+03	170000.00
93B182	2017-07-12 05:58:00+03	10600.00
93B213	2017-07-22 20:15:00+03	89600.00
93B21B	2017-08-13 11:00:00+03	258400.00
93B230	2017-07-20 05:05:00+03	41800.00
93B253	2017-07-15 05:21:00+03	35200.00
93B25C	2017-07-06 07:42:00+03	264600.00
93B318	2017-08-04 17:28:00+03	28700.00
93B38A	2017-07-10 20:17:00+03	28000.00
93B3B2	2017-07-13 21:50:00+03	18600.00
93B3C6	2017-08-03 02:20:00+03	77900.00
93B3FC	2017-07-07 07:20:00+03	14400.00
93B510	2017-07-13 13:31:00+03	139800.00
93B54F	2017-07-31 04:05:00+03	21800.00
93B5D4	2017-06-30 23:18:00+03	54100.00
93B5FC	2017-07-27 17:02:00+03	74800.00
93B628	2017-07-08 03:53:00+03	23400.00
93B62A	2017-07-23 14:56:00+03	40000.00
93B63B	2017-07-05 07:39:00+03	664200.00
93B6B6	2017-08-03 19:45:00+03	27200.00
93B6E0	2017-07-23 02:59:00+03	14000.00
93B6EE	2017-08-11 15:44:00+03	62800.00
93B711	2017-08-07 22:20:00+03	21500.00
93B72D	2017-08-13 14:11:00+03	12000.00
93B739	2017-08-02 18:49:00+03	46400.00
93B745	2017-07-27 14:55:00+03	84800.00
93B813	2017-08-12 14:42:00+03	65500.00
93B82A	2017-07-11 19:06:00+03	11600.00
93B855	2017-08-03 17:24:00+03	10600.00
93B8B7	2017-07-09 23:08:00+03	59400.00
93B94E	2017-07-24 17:50:00+03	136800.00
93B966	2017-07-07 06:21:00+03	23200.00
93B970	2017-07-26 12:58:00+03	131600.00
93B985	2017-08-03 15:16:00+03	116000.00
93B9F2	2017-08-15 12:19:00+03	12600.00
93BA09	2017-07-07 14:47:00+03	37600.00
93BAF7	2017-08-08 03:31:00+03	48600.00
93BB01	2017-07-30 02:13:00+03	54800.00
93BB18	2017-08-06 22:25:00+03	6000.00
93BB22	2017-07-27 09:13:00+03	75600.00
93BB3D	2017-08-13 08:06:00+03	38400.00
93BB63	2017-08-12 14:57:00+03	17000.00
93BB78	2017-07-31 11:14:00+03	157400.00
93BB9F	2017-07-22 14:58:00+03	29600.00
93BBB8	2017-07-30 12:42:00+03	91600.00
93BBCF	2017-07-07 06:56:00+03	28000.00
93BBD7	2017-07-26 16:29:00+03	86300.00
93BBEC	2017-08-09 20:47:00+03	85800.00
93BC04	2017-08-14 14:35:00+03	72600.00
93BC73	2017-07-09 04:11:00+03	226200.00
93BC7F	2017-07-25 22:19:00+03	333200.00
93BCA6	2017-07-18 03:13:00+03	87100.00
93BCF9	2017-07-19 15:40:00+03	88600.00
93BD4F	2017-07-27 13:40:00+03	62000.00
93BD94	2017-07-01 20:31:00+03	134000.00
93BE2C	2017-08-14 05:34:00+03	79200.00
93BE46	2017-08-09 13:06:00+03	91200.00
93BEB4	2017-07-19 01:14:00+03	34000.00
93BECA	2017-07-12 23:51:00+03	19800.00
93BECF	2017-07-28 05:27:00+03	89600.00
93BEDD	2017-07-27 07:17:00+03	31600.00
93BEFA	2017-07-09 05:09:00+03	27300.00
93BEFE	2017-07-31 09:23:00+03	25600.00
93BF09	2017-07-09 18:52:00+03	33100.00
93BF78	2017-07-12 21:43:00+03	123700.00
93BFDA	2017-07-03 19:24:00+03	56100.00
93BFE2	2017-07-10 06:39:00+03	38400.00
93C049	2017-08-06 04:37:00+03	38400.00
93C062	2017-07-18 08:48:00+03	54200.00
93C07D	2017-07-01 04:55:00+03	54300.00
93C164	2017-07-31 08:33:00+03	95000.00
93C166	2017-07-28 13:37:00+03	29300.00
93C285	2017-07-18 11:50:00+03	6400.00
93C2DA	2017-07-07 06:05:00+03	11600.00
93C2F4	2017-06-30 08:41:00+03	92100.00
93C38D	2017-07-26 09:05:00+03	171100.00
93C3D1	2017-08-07 19:45:00+03	38200.00
93C3ED	2017-08-13 20:09:00+03	23400.00
93C3F8	2017-06-28 05:36:00+03	54100.00
93C3FC	2017-07-17 18:20:00+03	92800.00
93C46A	2017-06-29 06:34:00+03	72200.00
93C481	2017-08-05 23:19:00+03	94400.00
93C485	2017-08-03 17:52:00+03	25200.00
93C48B	2017-07-27 09:37:00+03	129200.00
93C4AC	2017-07-07 16:19:00+03	33000.00
93C50D	2017-07-23 17:17:00+03	91800.00
93C585	2017-07-10 12:44:00+03	283100.00
93C587	2017-07-05 03:04:00+03	78500.00
93C5BD	2017-07-23 17:29:00+03	8000.00
93C609	2017-08-14 07:33:00+03	59300.00
93C611	2017-07-29 20:54:00+03	79600.00
93C63F	2017-07-03 01:16:00+03	55800.00
93C64E	2017-07-11 00:27:00+03	46400.00
93C751	2017-07-29 04:59:00+03	21800.00
93C7A3	2017-08-15 01:08:00+03	32200.00
93C7B2	2017-08-10 18:03:00+03	131900.00
93C7C8	2017-08-02 00:43:00+03	123000.00
93C7D5	2017-07-27 12:45:00+03	80200.00
93C80F	2017-07-21 05:58:00+03	115900.00
93C84E	2017-08-09 09:39:00+03	29600.00
93C863	2017-08-12 13:08:00+03	61800.00
93C86B	2017-07-16 03:49:00+03	14400.00
93C877	2017-07-14 01:18:00+03	33100.00
93C8A0	2017-07-14 17:27:00+03	73100.00
93C8BE	2017-08-13 00:53:00+03	13400.00
93C8FC	2017-07-16 01:47:00+03	123900.00
93C997	2017-07-07 02:17:00+03	17800.00
93C9AF	2017-08-01 12:13:00+03	135400.00
93C9E2	2017-07-17 04:18:00+03	135000.00
93C9F1	2017-07-10 14:15:00+03	142800.00
93CA13	2017-07-20 20:45:00+03	147100.00
93CA56	2017-07-30 16:40:00+03	124300.00
93CABF	2017-07-29 14:25:00+03	28000.00
93CB06	2017-06-29 16:47:00+03	61200.00
93CB35	2017-07-04 23:09:00+03	36600.00
93CB53	2017-07-26 01:03:00+03	30800.00
93CBAC	2017-08-14 18:46:00+03	12800.00
93CBDD	2017-08-04 08:32:00+03	7400.00
93CBFB	2017-07-09 03:21:00+03	28000.00
93CC02	2017-06-30 23:08:00+03	119600.00
93CC28	2017-07-16 10:26:00+03	47100.00
93CC3C	2017-08-13 06:57:00+03	67400.00
93CC40	2017-07-17 15:34:00+03	40000.00
93CCA5	2017-07-26 01:12:00+03	13600.00
93CCBC	2017-07-10 21:21:00+03	56600.00
93CCCE	2017-07-20 11:17:00+03	73200.00
93CCE8	2017-07-25 03:37:00+03	32800.00
93CD0B	2017-07-16 09:15:00+03	13400.00
93CD47	2017-08-07 23:32:00+03	85000.00
93CDEE	2017-07-12 09:19:00+03	136200.00
93CE2E	2017-07-07 04:27:00+03	35200.00
93CE41	2017-07-14 08:16:00+03	68400.00
93CE66	2017-08-03 00:40:00+03	28800.00
93CF26	2017-07-08 15:49:00+03	43200.00
93CF56	2017-07-16 22:11:00+03	36800.00
93CF5D	2017-07-06 08:21:00+03	14400.00
93CFA7	2017-08-10 14:23:00+03	193600.00
93CFD1	2017-07-15 11:19:00+03	468000.00
93D048	2017-07-15 09:55:00+03	23200.00
93D08C	2017-07-26 06:45:00+03	55800.00
93D137	2017-07-16 04:57:00+03	406700.00
93D148	2017-07-05 01:09:00+03	183300.00
93D14E	2017-07-28 00:11:00+03	6800.00
93D162	2017-08-05 22:56:00+03	27200.00
93D180	2017-07-27 09:08:00+03	49100.00
93D197	2017-07-06 08:04:00+03	12600.00
93D219	2017-08-14 17:48:00+03	66700.00
93D25B	2017-07-21 16:11:00+03	155600.00
93D329	2017-07-08 12:28:00+03	151100.00
93D32C	2017-07-30 03:16:00+03	35200.00
93D345	2017-07-04 23:42:00+03	21400.00
93D352	2017-07-17 11:49:00+03	61800.00
93D38B	2017-07-24 05:29:00+03	75300.00
93D41F	2017-06-30 02:02:00+03	51900.00
93D42C	2017-08-06 03:47:00+03	38600.00
93D46B	2017-07-19 19:12:00+03	30200.00
93D4DF	2017-07-05 18:43:00+03	115900.00
93D50E	2017-07-26 09:50:00+03	273300.00
93D51A	2017-08-07 20:38:00+03	42200.00
93D52E	2017-07-18 21:06:00+03	38800.00
93D549	2017-07-25 06:42:00+03	40800.00
93D568	2017-07-17 12:56:00+03	42800.00
93D596	2017-08-12 23:28:00+03	88000.00
93D597	2017-07-08 00:03:00+03	44000.00
93D602	2017-07-12 20:30:00+03	54800.00
93D624	2017-08-14 20:16:00+03	23600.00
93D67A	2017-07-05 15:23:00+03	46400.00
93D6C1	2017-07-21 10:32:00+03	31600.00
93D723	2017-07-30 03:59:00+03	75600.00
93D738	2017-07-02 12:13:00+03	81300.00
93D753	2017-07-30 14:38:00+03	378400.00
93D776	2017-08-10 11:34:00+03	6600.00
93D7B2	2017-08-09 17:07:00+03	24400.00
93D7FB	2017-07-12 07:35:00+03	51300.00
93D857	2017-07-16 04:47:00+03	31400.00
93D85E	2017-08-09 21:01:00+03	153200.00
93D86C	2017-07-01 08:55:00+03	179500.00
93D88F	2017-07-24 16:00:00+03	492000.00
93D898	2017-07-25 21:52:00+03	64600.00
93D8C2	2017-07-10 06:23:00+03	26000.00
93D8D9	2017-08-12 01:40:00+03	50600.00
93D950	2017-08-07 09:12:00+03	53600.00
93D978	2017-08-10 07:07:00+03	81700.00
93D999	2017-08-12 11:50:00+03	135600.00
93D9DD	2017-07-11 10:05:00+03	28800.00
93DA7F	2017-07-21 15:59:00+03	67200.00
93DABF	2017-08-12 12:47:00+03	123000.00
93DAF5	2017-08-11 05:44:00+03	24000.00
93DB15	2017-06-29 05:10:00+03	48800.00
93DB50	2017-08-11 08:37:00+03	26000.00
93DB67	2017-08-07 17:23:00+03	26000.00
93DB99	2017-07-24 19:37:00+03	40600.00
93DBE5	2017-07-14 16:43:00+03	153200.00
93DC0A	2017-08-12 16:18:00+03	184200.00
93DC16	2017-07-30 18:59:00+03	246000.00
93DC45	2017-07-20 00:33:00+03	46800.00
93DC72	2017-08-15 05:54:00+03	16400.00
93DC7C	2017-07-31 13:25:00+03	174900.00
93DCE8	2017-07-19 18:42:00+03	26000.00
93DD56	2017-08-10 15:35:00+03	75300.00
93DDA0	2017-07-17 20:27:00+03	46300.00
93DE2C	2017-07-27 05:47:00+03	68100.00
93DE94	2017-07-08 09:18:00+03	23600.00
93DEA9	2017-07-19 09:48:00+03	12900.00
93DEDD	2017-07-23 00:02:00+03	18300.00
93DF0C	2017-07-11 22:03:00+03	46200.00
93DF72	2017-08-02 11:16:00+03	99200.00
93DFD1	2017-07-19 20:53:00+03	136800.00
93E028	2017-07-06 12:10:00+03	187600.00
93E0AD	2017-08-10 16:37:00+03	39200.00
93E0FE	2017-07-18 12:19:00+03	40000.00
93E113	2017-07-17 00:41:00+03	19600.00
93E115	2017-08-10 14:22:00+03	56600.00
93E14B	2017-08-08 21:53:00+03	54600.00
93E1C1	2017-08-10 22:51:00+03	6700.00
93E228	2017-08-03 09:52:00+03	42700.00
93E353	2017-08-07 22:40:00+03	26800.00
93E38C	2017-08-05 18:01:00+03	73300.00
93E3A4	2017-06-29 04:50:00+03	20400.00
93E3EB	2017-07-19 15:07:00+03	66600.00
93E456	2017-07-03 03:01:00+03	135000.00
93E476	2017-07-05 23:35:00+03	88500.00
93E4D8	2017-08-13 12:37:00+03	24400.00
93E4F1	2017-07-24 17:15:00+03	37700.00
93E4F8	2017-07-15 15:36:00+03	54800.00
93E501	2017-08-01 19:01:00+03	60200.00
93E51B	2017-07-16 08:28:00+03	233700.00
93E575	2017-07-28 15:20:00+03	39500.00
93E59B	2017-08-11 09:31:00+03	103800.00
93E5BF	2017-08-07 01:49:00+03	25400.00
93E5D5	2017-07-09 19:37:00+03	53800.00
93E5DA	2017-07-21 04:17:00+03	13400.00
93E60F	2017-07-24 15:24:00+03	246000.00
93E80B	2017-07-04 22:20:00+03	37600.00
93E85D	2017-07-21 12:30:00+03	49200.00
93E8A8	2017-08-01 23:18:00+03	80000.00
93E8C3	2017-07-04 18:51:00+03	82900.00
93E8E3	2017-08-08 23:01:00+03	134400.00
93E922	2017-07-24 20:16:00+03	21800.00
93E9F4	2017-08-03 19:11:00+03	66000.00
93EA27	2017-07-09 05:37:00+03	155600.00
93EAB0	2017-07-21 00:53:00+03	118600.00
93EB14	2017-07-10 06:26:00+03	65400.00
93EB50	2017-07-02 05:45:00+03	24400.00
93EBEA	2017-08-13 14:36:00+03	26000.00
93EBEC	2017-07-13 19:48:00+03	6000.00
93EC50	2017-07-16 14:18:00+03	93700.00
93ECD1	2017-07-21 11:24:00+03	223200.00
93EDF8	2017-08-04 22:06:00+03	13400.00
93EE69	2017-07-15 00:08:00+03	25600.00
93EE95	2017-07-20 16:09:00+03	36200.00
93EEDA	2017-07-14 20:30:00+03	25600.00
93EEE5	2017-08-10 19:36:00+03	28000.00
93EEFA	2017-08-05 23:05:00+03	85300.00
93EF9D	2017-07-10 22:33:00+03	28000.00
93EFC1	2017-07-04 23:38:00+03	52400.00
93F013	2017-08-14 12:10:00+03	177100.00
93F03E	2017-08-13 21:25:00+03	266400.00
93F047	2017-08-09 14:19:00+03	135000.00
93F07E	2017-07-30 08:25:00+03	79800.00
93F092	2017-07-06 08:32:00+03	31200.00
93F0B6	2017-08-11 02:30:00+03	50600.00
93F0BE	2017-08-08 06:08:00+03	42800.00
93F133	2017-07-06 10:31:00+03	55800.00
93F134	2017-07-28 03:54:00+03	20400.00
93F15D	2017-07-09 19:15:00+03	75300.00
93F176	2017-07-17 17:36:00+03	39800.00
93F178	2017-07-09 04:30:00+03	62900.00
93F1B4	2017-08-13 08:03:00+03	59100.00
93F24D	2017-08-13 07:39:00+03	22600.00
93F271	2017-08-10 01:05:00+03	56900.00
93F2C0	2017-07-29 00:42:00+03	114400.00
93F2C2	2017-07-24 22:00:00+03	61800.00
93F2E2	2017-07-13 04:37:00+03	20100.00
93F2EC	2017-07-29 06:24:00+03	111600.00
93F332	2017-08-04 01:44:00+03	102100.00
93F34F	2017-07-09 07:33:00+03	95600.00
93F3A6	2017-07-26 19:36:00+03	42800.00
93F3EE	2017-07-23 23:43:00+03	155600.00
93F3F5	2017-07-21 06:27:00+03	37100.00
93F401	2017-07-11 22:50:00+03	35200.00
93F405	2017-08-01 03:37:00+03	48800.00
93F486	2017-08-05 04:37:00+03	58100.00
93F4AD	2017-07-15 19:37:00+03	109600.00
93F4C9	2017-07-19 12:54:00+03	56000.00
93F517	2017-07-22 21:29:00+03	38400.00
93F57B	2017-07-11 12:06:00+03	69100.00
93F5DF	2017-07-24 03:00:00+03	96800.00
93F631	2017-07-26 21:19:00+03	156000.00
93F6DB	2017-07-29 16:56:00+03	26200.00
93F6EC	2017-07-25 17:12:00+03	94000.00
93F6F6	2017-08-11 12:50:00+03	73500.00
93F71C	2017-07-18 01:46:00+03	73500.00
93F789	2017-08-01 13:11:00+03	168000.00
93F7C1	2017-07-17 08:21:00+03	119800.00
93F81B	2017-08-14 03:41:00+03	78000.00
93F849	2017-07-11 04:03:00+03	19800.00
93F8B9	2017-07-07 11:11:00+03	135400.00
93F8D3	2017-07-14 16:34:00+03	78100.00
93F92A	2017-07-22 22:31:00+03	67500.00
93F93F	2017-07-22 05:41:00+03	26100.00
93F9AD	2017-08-11 18:27:00+03	49200.00
93F9F0	2017-08-10 23:53:00+03	66600.00
93FA10	2017-07-06 08:12:00+03	6000.00
93FA2E	2017-08-11 15:43:00+03	75600.00
93FA41	2017-08-05 02:57:00+03	55800.00
93FA43	2017-08-15 00:57:00+03	13400.00
93FAD0	2017-08-06 15:54:00+03	147200.00
93FAFF	2017-07-12 01:54:00+03	200100.00
93FB74	2017-07-13 03:29:00+03	13800.00
93FBB8	2017-07-08 21:05:00+03	76300.00
93FC58	2017-07-11 01:35:00+03	46400.00
93FC65	2017-07-25 09:51:00+03	24800.00
93FCC5	2017-07-24 10:40:00+03	133200.00
93FCD1	2017-07-25 00:55:00+03	43200.00
93FD75	2017-07-15 14:16:00+03	164600.00
93FD9C	2017-07-12 19:08:00+03	52000.00
93FDB3	2017-08-03 22:48:00+03	66600.00
93FDEF	2017-07-23 00:14:00+03	93000.00
93FDFC	2017-07-18 09:11:00+03	73500.00
93FE24	2017-07-12 18:02:00+03	95700.00
93FE6D	2017-07-05 07:05:00+03	169900.00
93FE80	2017-08-11 18:51:00+03	49600.00
93FE8C	2017-07-12 22:55:00+03	133100.00
93FF67	2017-07-10 19:09:00+03	12000.00
93FF6E	2017-07-30 14:04:00+03	97900.00
93FF7F	2017-08-09 19:12:00+03	24400.00
93FFC2	2017-07-20 07:35:00+03	23400.00
93FFF4	2017-07-19 13:06:00+03	615000.00
9400A2	2017-07-01 22:40:00+03	44000.00
9400D8	2017-07-10 07:55:00+03	75600.00
940101	2017-07-26 13:38:00+03	40800.00
940103	2017-07-19 03:55:00+03	32900.00
940152	2017-08-04 15:22:00+03	100600.00
9401C7	2017-08-04 21:51:00+03	16800.00
94022D	2017-07-22 09:05:00+03	75300.00
940230	2017-07-13 23:14:00+03	24700.00
940245	2017-07-11 23:35:00+03	115100.00
94024A	2017-07-28 23:55:00+03	50100.00
94024D	2017-07-20 05:44:00+03	6300.00
9402EF	2017-07-11 12:18:00+03	172000.00
940300	2017-07-16 21:20:00+03	23200.00
940323	2017-07-11 21:37:00+03	146600.00
94033E	2017-07-24 06:59:00+03	25200.00
940347	2017-07-03 17:24:00+03	106100.00
94035D	2017-07-29 14:40:00+03	136500.00
9403BA	2017-08-14 15:12:00+03	24000.00
94040F	2017-07-25 20:13:00+03	254900.00
94045A	2017-07-08 01:12:00+03	86400.00
940485	2017-08-12 02:16:00+03	154400.00
9404E7	2017-08-14 04:59:00+03	56000.00
9404EF	2017-07-26 14:48:00+03	55800.00
9404F6	2017-07-28 09:56:00+03	131100.00
9404FF	2017-06-30 21:03:00+03	65500.00
940529	2017-07-30 02:33:00+03	67600.00
94053F	2017-07-10 16:33:00+03	80900.00
9406D9	2017-07-21 18:38:00+03	96800.00
9406DA	2017-08-13 02:05:00+03	46200.00
940723	2017-08-13 05:39:00+03	133200.00
940790	2017-08-09 00:39:00+03	101100.00
9407CA	2017-07-12 20:31:00+03	25800.00
9407E1	2017-07-31 22:08:00+03	90400.00
940816	2017-07-26 22:36:00+03	153400.00
9408B9	2017-08-03 20:22:00+03	29400.00
9408CF	2017-08-02 06:41:00+03	43200.00
940913	2017-07-25 16:42:00+03	29100.00
940937	2017-07-27 06:36:00+03	6700.00
9409C7	2017-07-05 02:05:00+03	55800.00
9409D3	2017-07-11 06:54:00+03	16400.00
940A6A	2017-07-31 12:56:00+03	65500.00
940ABB	2017-08-03 11:43:00+03	196400.00
940AC7	2017-07-05 02:29:00+03	39200.00
940AF2	2017-07-10 06:08:00+03	31600.00
940AF5	2017-08-14 10:09:00+03	6000.00
940B2B	2017-07-10 01:15:00+03	28000.00
940B4C	2017-07-13 01:41:00+03	38400.00
940B82	2017-07-01 23:35:00+03	393800.00
940B9B	2017-06-29 23:12:00+03	193600.00
940C0A	2017-07-07 17:34:00+03	55200.00
940C0C	2017-08-12 22:59:00+03	47200.00
940C75	2017-07-05 11:20:00+03	36200.00
940CA2	2017-08-03 23:20:00+03	91600.00
940D61	2017-07-08 21:04:00+03	60000.00
940DBF	2017-08-07 21:25:00+03	44800.00
940E40	2017-08-08 12:24:00+03	12600.00
940F22	2017-07-27 15:07:00+03	80800.00
940F87	2017-08-04 03:36:00+03	116000.00
941039	2017-08-13 05:44:00+03	119200.00
9410AB	2017-07-24 04:42:00+03	134200.00
9410DB	2017-07-20 03:32:00+03	23200.00
941165	2017-08-15 01:10:00+03	23200.00
94118C	2017-08-15 15:28:00+03	112500.00
9411DD	2017-07-10 07:37:00+03	22400.00
94122E	2017-07-06 21:39:00+03	78600.00
941258	2017-08-12 09:48:00+03	24400.00
941261	2017-07-31 18:55:00+03	24600.00
9412D9	2017-08-12 03:47:00+03	23200.00
94131E	2017-06-30 21:37:00+03	56000.00
94133A	2017-07-21 12:20:00+03	99200.00
94137D	2017-07-01 08:19:00+03	94400.00
94139E	2017-07-29 00:12:00+03	135600.00
9413F3	2017-08-15 07:02:00+03	13800.00
941431	2017-07-29 00:45:00+03	103500.00
94146A	2017-08-05 13:42:00+03	25800.00
941480	2017-08-06 04:39:00+03	37900.00
94149F	2017-06-30 07:19:00+03	137600.00
9414A7	2017-07-29 06:26:00+03	42400.00
941572	2017-08-09 23:13:00+03	88900.00
9415A8	2017-08-09 17:35:00+03	130200.00
9415D1	2017-07-06 23:57:00+03	56000.00
9415E3	2017-07-06 08:55:00+03	23500.00
94164C	2017-07-12 22:16:00+03	48800.00
9417B4	2017-06-29 12:24:00+03	86300.00
94185C	2017-07-01 04:03:00+03	92900.00
941897	2017-07-25 15:23:00+03	45000.00
94191D	2017-08-10 22:39:00+03	7200.00
94192C	2017-07-11 16:37:00+03	46300.00
94195E	2017-07-15 08:44:00+03	88600.00
941987	2017-07-22 15:08:00+03	58000.00
9419FE	2017-08-13 22:07:00+03	28000.00
941A61	2017-07-29 07:57:00+03	19600.00
941A6C	2017-07-27 00:43:00+03	58400.00
941A6E	2017-07-15 02:51:00+03	69100.00
941A8A	2017-07-03 18:12:00+03	22000.00
941AA5	2017-07-23 19:54:00+03	12600.00
941AC0	2017-07-28 14:03:00+03	59900.00
941AD5	2017-07-11 23:01:00+03	36800.00
941AD8	2017-07-17 22:10:00+03	44700.00
941ADB	2017-07-11 18:59:00+03	98400.00
941B6B	2017-08-08 05:23:00+03	141100.00
941B9D	2017-08-08 11:15:00+03	58400.00
941BA9	2017-07-22 21:20:00+03	151200.00
941BF3	2017-07-23 12:19:00+03	60400.00
941CAF	2017-08-01 02:00:00+03	29200.00
941DEA	2017-08-01 10:24:00+03	109200.00
941E21	2017-08-13 06:30:00+03	137800.00
941E3E	2017-08-06 23:56:00+03	56000.00
941E5B	2017-07-12 21:12:00+03	6300.00
941E97	2017-08-03 20:24:00+03	40000.00
941E9A	2017-06-27 07:21:00+03	3400.00
941EC1	2017-07-08 21:56:00+03	67200.00
941EFC	2017-07-19 13:33:00+03	94000.00
941F08	2017-08-13 02:05:00+03	37700.00
941F48	2017-08-10 05:36:00+03	46400.00
941F66	2017-07-21 09:55:00+03	21200.00
941FB8	2017-08-13 10:49:00+03	34100.00
941FCF	2017-07-21 02:35:00+03	66600.00
941FFA	2017-07-03 00:33:00+03	81600.00
942108	2017-07-27 01:14:00+03	105600.00
942141	2017-07-08 00:46:00+03	109400.00
942181	2017-07-06 08:26:00+03	88800.00
9421A7	2017-07-28 18:47:00+03	58000.00
9421C0	2017-08-09 20:22:00+03	64800.00
9421F6	2017-07-23 23:01:00+03	56000.00
942270	2017-07-07 16:20:00+03	58000.00
94227C	2017-07-11 21:29:00+03	175700.00
94227E	2017-07-15 21:46:00+03	131600.00
942280	2017-06-30 10:25:00+03	499800.00
9422A4	2017-07-27 14:50:00+03	22000.00
9422AA	2017-07-06 00:30:00+03	69500.00
942310	2017-07-11 13:20:00+03	101200.00
942351	2017-07-03 23:02:00+03	11800.00
942382	2017-07-05 10:40:00+03	38800.00
9423B1	2017-07-05 08:30:00+03	217600.00
94249B	2017-07-28 04:05:00+03	26800.00
9424B6	2017-08-09 15:15:00+03	49800.00
9424F4	2017-08-11 23:59:00+03	42600.00
942598	2017-06-28 01:16:00+03	19600.00
9425A8	2017-07-14 21:03:00+03	13100.00
9425C6	2017-07-09 02:50:00+03	34100.00
9425E5	2017-07-10 04:30:00+03	123000.00
94260A	2017-07-28 07:37:00+03	161400.00
942692	2017-08-03 00:39:00+03	54800.00
9426BE	2017-07-31 08:55:00+03	58800.00
9426C4	2017-07-12 19:43:00+03	59100.00
942738	2017-07-22 20:35:00+03	62900.00
942848	2017-07-29 10:28:00+03	135600.00
94287B	2017-07-22 22:13:00+03	16400.00
9428C0	2017-07-26 18:02:00+03	33400.00
94290F	2017-07-22 15:06:00+03	28300.00
9429A5	2017-07-20 14:42:00+03	122000.00
9429B8	2017-07-31 04:34:00+03	14000.00
942A8A	2017-07-22 22:28:00+03	21800.00
942AB0	2017-07-05 22:36:00+03	86400.00
942ABE	2017-08-04 19:40:00+03	48800.00
942AD1	2017-08-10 22:23:00+03	72300.00
942B1D	2017-07-16 23:35:00+03	37100.00
942B87	2017-07-20 04:35:00+03	25400.00
942BBF	2017-07-10 17:45:00+03	43300.00
942BCF	2017-08-06 07:52:00+03	117200.00
942BEF	2017-07-05 14:00:00+03	33300.00
942C39	2017-08-12 08:58:00+03	56600.00
942C7A	2017-07-13 02:16:00+03	140800.00
942C7E	2017-06-29 10:20:00+03	46200.00
942CAA	2017-07-17 08:03:00+03	35600.00
942CB2	2017-07-09 07:55:00+03	14000.00
942CB9	2017-07-19 15:21:00+03	54300.00
942CFD	2017-07-05 06:43:00+03	188000.00
942D4F	2017-08-05 10:02:00+03	68800.00
942D63	2017-08-14 01:08:00+03	57600.00
942D85	2017-08-08 08:30:00+03	66200.00
942DCC	2017-08-12 23:10:00+03	32800.00
942E32	2017-07-03 23:06:00+03	158300.00
942F0D	2017-08-10 17:37:00+03	75300.00
942F7D	2017-08-08 05:44:00+03	42800.00
942F9F	2017-07-12 21:02:00+03	56000.00
942FC9	2017-08-03 22:02:00+03	47400.00
942FF0	2017-07-28 10:19:00+03	56000.00
942FFD	2017-07-04 00:53:00+03	273000.00
943030	2017-08-08 10:08:00+03	26100.00
943045	2017-07-14 06:11:00+03	47400.00
9430C1	2017-08-15 10:13:00+03	118700.00
9430C8	2017-07-05 22:45:00+03	32800.00
9430D2	2017-07-12 20:29:00+03	15100.00
9430D7	2017-08-06 17:20:00+03	54000.00
943107	2017-07-27 23:38:00+03	13000.00
943152	2017-07-20 22:21:00+03	48800.00
9431C7	2017-07-04 14:36:00+03	56000.00
94320D	2017-08-04 22:24:00+03	17200.00
943231	2017-08-07 04:24:00+03	28800.00
943260	2017-08-09 06:17:00+03	201200.00
943266	2017-06-27 15:53:00+03	88600.00
94328B	2017-08-09 06:57:00+03	106000.00
9432A7	2017-07-16 10:06:00+03	75100.00
9432F6	2017-08-12 20:56:00+03	59400.00
94331D	2017-07-30 22:27:00+03	26000.00
9433BD	2017-08-05 23:42:00+03	65900.00
94340D	2017-07-24 15:31:00+03	59200.00
943428	2017-08-03 03:26:00+03	47400.00
943484	2017-07-18 04:35:00+03	43100.00
943520	2017-07-28 03:51:00+03	274800.00
943523	2017-08-03 09:17:00+03	80800.00
943529	2017-07-25 02:42:00+03	271200.00
943565	2017-08-15 08:18:00+03	36800.00
94357E	2017-08-06 16:20:00+03	26000.00
943585	2017-07-22 05:10:00+03	51200.00
9435AE	2017-07-14 01:24:00+03	42600.00
94365B	2017-08-03 15:54:00+03	125800.00
943684	2017-08-15 02:56:00+03	55800.00
943687	2017-07-12 04:59:00+03	13400.00
9436AE	2017-07-09 05:54:00+03	73600.00
9436D1	2017-07-15 13:19:00+03	128800.00
94370E	2017-07-21 16:29:00+03	12600.00
94373E	2017-07-15 22:28:00+03	140600.00
9437D2	2017-07-14 17:46:00+03	126700.00
94383E	2017-06-30 22:05:00+03	24200.00
94384F	2017-07-31 00:38:00+03	40400.00
943898	2017-08-08 12:23:00+03	102100.00
9438D0	2017-07-10 03:35:00+03	36200.00
943912	2017-07-13 19:14:00+03	59300.00
943982	2017-07-12 19:20:00+03	154800.00
9439B4	2017-07-26 04:58:00+03	56000.00
943A12	2017-07-26 01:32:00+03	13600.00
943A70	2017-08-13 02:37:00+03	24400.00
943A72	2017-08-10 17:24:00+03	76600.00
943A9D	2017-07-08 17:10:00+03	56000.00
943B09	2017-07-22 11:23:00+03	246000.00
943B18	2017-08-10 14:10:00+03	57400.00
943B2F	2017-07-01 10:30:00+03	26000.00
943B4D	2017-08-06 16:06:00+03	47600.00
943BCF	2017-07-08 15:58:00+03	62600.00
943BD6	2017-07-25 17:44:00+03	270800.00
943BDA	2017-07-24 02:03:00+03	131100.00
943BE8	2017-07-28 17:47:00+03	20200.00
943C8F	2017-08-14 11:51:00+03	112200.00
943CCD	2017-08-03 20:53:00+03	81600.00
943CDC	2017-07-21 22:11:00+03	33800.00
943D3B	2017-07-17 07:50:00+03	152900.00
943DD0	2017-07-07 11:56:00+03	28800.00
943E18	2017-07-21 06:54:00+03	26000.00
943E25	2017-07-31 07:47:00+03	36000.00
943E42	2017-07-26 03:21:00+03	26000.00
943E49	2017-07-05 08:26:00+03	28800.00
943EC2	2017-07-22 14:41:00+03	28000.00
943F7D	2017-07-03 20:50:00+03	51600.00
943F8F	2017-06-29 05:10:00+03	107800.00
943FA5	2017-08-09 14:41:00+03	92800.00
943FB7	2017-06-28 12:21:00+03	20800.00
943FBA	2017-07-10 08:40:00+03	173600.00
943FD1	2017-07-27 04:33:00+03	52800.00
944009	2017-08-09 21:52:00+03	28300.00
944049	2017-08-05 18:17:00+03	131100.00
944078	2017-07-18 04:42:00+03	64800.00
94407A	2017-08-06 03:57:00+03	66600.00
944097	2017-07-05 20:16:00+03	102100.00
944175	2017-08-11 02:46:00+03	12000.00
94418B	2017-08-02 09:31:00+03	14400.00
9441BA	2017-08-06 10:10:00+03	83000.00
9441D4	2017-08-05 06:42:00+03	26800.00
9441EF	2017-07-05 11:10:00+03	17200.00
9441F5	2017-07-06 18:55:00+03	375200.00
944232	2017-08-09 10:20:00+03	100600.00
944234	2017-07-31 23:29:00+03	6800.00
944274	2017-08-03 05:55:00+03	141700.00
944294	2017-07-12 09:13:00+03	116800.00
9442CB	2017-07-09 16:28:00+03	38000.00
9442E8	2017-07-14 05:01:00+03	521200.00
944384	2017-07-11 06:40:00+03	136800.00
9443D2	2017-08-08 08:29:00+03	117600.00
9443E5	2017-07-12 09:50:00+03	26000.00
9443ED	2017-07-04 06:28:00+03	13600.00
94440D	2017-07-13 04:20:00+03	39400.00
94441A	2017-07-19 04:17:00+03	24200.00
94441C	2017-07-20 18:35:00+03	156500.00
94441D	2017-07-07 02:10:00+03	48800.00
944439	2017-08-08 17:27:00+03	135400.00
944465	2017-07-31 02:04:00+03	21800.00
944475	2017-07-05 23:34:00+03	103800.00
944487	2017-08-01 00:31:00+03	83600.00
944500	2017-07-17 13:39:00+03	135400.00
944509	2017-07-30 01:19:00+03	34000.00
944510	2017-07-20 16:44:00+03	63200.00
944511	2017-07-23 07:22:00+03	25200.00
94455B	2017-07-01 07:02:00+03	54400.00
944570	2017-08-01 09:31:00+03	31100.00
9445A8	2017-08-03 00:47:00+03	26200.00
9445F4	2017-07-15 14:23:00+03	64700.00
9445FF	2017-07-26 10:49:00+03	16400.00
94461C	2017-07-23 06:46:00+03	8600.00
944652	2017-07-24 15:54:00+03	28300.00
94468C	2017-08-03 19:17:00+03	24200.00
944694	2017-08-11 10:34:00+03	284700.00
944704	2017-07-17 20:33:00+03	40800.00
94472F	2017-07-12 02:16:00+03	23200.00
944771	2017-08-11 03:16:00+03	28800.00
9447AC	2017-07-10 11:19:00+03	137000.00
944817	2017-07-23 14:00:00+03	24400.00
944877	2017-08-08 23:39:00+03	11600.00
944889	2017-08-11 14:22:00+03	8200.00
9448F7	2017-07-10 10:08:00+03	367300.00
944927	2017-07-10 03:32:00+03	67800.00
944932	2017-08-15 13:47:00+03	28000.00
944948	2017-07-30 00:29:00+03	52600.00
944972	2017-07-05 01:04:00+03	57300.00
9449A1	2017-08-08 15:15:00+03	99200.00
9449AA	2017-07-28 01:39:00+03	93900.00
9449C3	2017-07-27 05:52:00+03	29100.00
9449F7	2017-07-20 14:45:00+03	67600.00
9449FC	2017-07-21 20:41:00+03	67600.00
944ADD	2017-07-21 09:21:00+03	28000.00
944B21	2017-07-11 19:02:00+03	24200.00
944CB6	2017-07-18 16:59:00+03	112000.00
944CCC	2017-08-14 00:22:00+03	71900.00
944CD5	2017-07-27 18:47:00+03	111600.00
944DC4	2017-08-15 04:52:00+03	29800.00
944DCE	2017-07-21 15:34:00+03	31600.00
944ED2	2017-07-05 00:37:00+03	271300.00
944ED5	2017-07-22 21:41:00+03	71100.00
944EE2	2017-07-06 05:35:00+03	136200.00
944F80	2017-07-17 08:28:00+03	56000.00
944FAF	2017-08-02 08:57:00+03	28000.00
944FB4	2017-07-21 15:47:00+03	8600.00
944FC8	2017-06-29 01:20:00+03	53600.00
944FF7	2017-08-05 14:45:00+03	72300.00
945005	2017-07-18 08:32:00+03	30200.00
94506E	2017-07-06 23:12:00+03	12600.00
945075	2017-07-24 15:34:00+03	31500.00
94507A	2017-08-07 15:56:00+03	48800.00
945117	2017-07-21 14:50:00+03	89200.00
945160	2017-08-10 10:36:00+03	54000.00
9451A6	2017-07-28 17:50:00+03	19600.00
9451AD	2017-08-04 22:50:00+03	62600.00
9451B0	2017-07-23 08:42:00+03	170800.00
9451BB	2017-07-03 15:02:00+03	37200.00
945282	2017-07-16 02:03:00+03	70400.00
9452A6	2017-08-08 09:12:00+03	37900.00
9452D1	2017-08-08 00:45:00+03	123000.00
94531D	2017-08-14 22:21:00+03	65000.00
945350	2017-08-11 01:46:00+03	56000.00
9453A7	2017-07-28 22:36:00+03	55600.00
9453C9	2017-07-29 09:49:00+03	11600.00
9453CA	2017-07-06 08:26:00+03	271100.00
9454E7	2017-07-07 06:20:00+03	289800.00
9454F8	2017-07-23 04:52:00+03	65500.00
945515	2017-06-30 07:40:00+03	67700.00
945562	2017-08-01 08:11:00+03	23600.00
9455BD	2017-07-05 01:19:00+03	48800.00
9455CC	2017-08-08 22:10:00+03	24300.00
9455E4	2017-07-25 16:11:00+03	531300.00
9455F0	2017-08-14 15:45:00+03	10600.00
945633	2017-08-11 16:04:00+03	205700.00
945657	2017-08-08 03:57:00+03	105600.00
945701	2017-07-01 12:18:00+03	111600.00
945708	2017-07-23 18:16:00+03	236900.00
945743	2017-08-01 21:20:00+03	123000.00
94575D	2017-07-27 21:56:00+03	271400.00
94577C	2017-08-02 16:27:00+03	31600.00
945799	2017-07-01 11:18:00+03	28800.00
94579A	2017-07-19 19:41:00+03	63800.00
9457B0	2017-08-03 19:22:00+03	89700.00
945856	2017-07-19 09:57:00+03	128800.00
945931	2017-07-24 11:14:00+03	54600.00
945941	2017-07-21 12:43:00+03	165100.00
94598D	2017-07-26 16:44:00+03	82800.00
9459D5	2017-07-26 05:58:00+03	65000.00
9459EF	2017-07-22 11:25:00+03	109200.00
9459F5	2017-07-07 21:52:00+03	32000.00
945A48	2017-07-24 01:33:00+03	81700.00
945A97	2017-08-04 01:13:00+03	135800.00
945B15	2017-07-18 21:46:00+03	113200.00
945BB1	2017-07-20 06:21:00+03	94800.00
945C2A	2017-07-27 00:12:00+03	85000.00
945CD7	2017-07-22 14:27:00+03	27200.00
945D03	2017-08-05 11:11:00+03	100600.00
945D56	2017-07-02 16:45:00+03	23100.00
945DA1	2017-07-16 19:49:00+03	51200.00
945E85	2017-08-07 06:00:00+03	40800.00
945E93	2017-07-07 01:15:00+03	105200.00
945FC3	2017-07-25 05:22:00+03	92800.00
94602E	2017-07-10 21:12:00+03	55800.00
946041	2017-07-11 18:44:00+03	77600.00
94610C	2017-07-02 16:33:00+03	38500.00
946155	2017-06-29 01:16:00+03	39300.00
946195	2017-07-23 19:36:00+03	71200.00
9461DE	2017-07-01 03:47:00+03	23200.00
94621D	2017-08-10 09:57:00+03	48500.00
946269	2017-07-16 05:12:00+03	290500.00
946278	2017-07-10 09:23:00+03	44600.00
9462ED	2017-07-08 13:19:00+03	28000.00
946335	2017-07-16 16:45:00+03	246000.00
946341	2017-08-12 01:04:00+03	203000.00
946362	2017-08-06 23:04:00+03	85000.00
9463A9	2017-07-21 20:48:00+03	88700.00
9463BA	2017-07-10 04:59:00+03	13800.00
946400	2017-08-08 18:31:00+03	38400.00
94642A	2017-07-20 14:20:00+03	54000.00
946435	2017-08-06 10:33:00+03	33100.00
946449	2017-07-19 09:48:00+03	12600.00
9464F1	2017-08-08 20:42:00+03	16400.00
9464FD	2017-07-06 01:11:00+03	66000.00
946536	2017-07-18 16:52:00+03	28000.00
94658B	2017-07-12 09:47:00+03	89700.00
946593	2017-08-07 09:10:00+03	151900.00
9465A9	2017-07-07 21:15:00+03	19600.00
9465FD	2017-07-15 21:04:00+03	23400.00
9465FE	2017-07-31 01:34:00+03	93900.00
94663F	2017-08-13 06:33:00+03	94200.00
9466F3	2017-07-28 07:34:00+03	93800.00
946740	2017-08-10 23:07:00+03	46400.00
946793	2017-08-11 08:25:00+03	40800.00
94679E	2017-07-13 15:54:00+03	46800.00
9467F7	2017-07-15 08:28:00+03	40000.00
9467F8	2017-07-23 23:39:00+03	48800.00
9467FA	2017-07-06 05:49:00+03	26700.00
946821	2017-07-04 14:19:00+03	32800.00
946830	2017-07-24 07:16:00+03	67900.00
946925	2017-07-20 12:59:00+03	111600.00
946964	2017-07-17 15:51:00+03	85600.00
9469E3	2017-08-01 08:42:00+03	38800.00
946A31	2017-07-31 00:47:00+03	13400.00
946A4B	2017-08-02 17:51:00+03	38600.00
946A8C	2017-06-30 10:17:00+03	6800.00
946AAB	2017-08-03 16:08:00+03	28900.00
946AF6	2017-07-04 02:05:00+03	47200.00
946B3E	2017-08-14 23:10:00+03	109300.00
946B64	2017-08-02 05:36:00+03	148200.00
946B86	2017-08-01 03:12:00+03	65600.00
946BCD	2017-08-10 02:43:00+03	56000.00
946C84	2017-08-03 08:44:00+03	41400.00
946CA1	2017-08-07 15:23:00+03	31000.00
946D09	2017-07-20 11:04:00+03	61100.00
946DF5	2017-08-09 12:11:00+03	78600.00
946E66	2017-07-11 21:44:00+03	133100.00
946ECC	2017-08-07 18:56:00+03	297600.00
946F2A	2017-07-21 08:07:00+03	27300.00
946F70	2017-07-06 20:29:00+03	30200.00
946FF6	2017-07-25 20:51:00+03	137900.00
947083	2017-08-02 20:23:00+03	69600.00
94708C	2017-07-04 23:05:00+03	31300.00
94715F	2017-08-07 17:07:00+03	28000.00
947160	2017-07-11 10:10:00+03	87600.00
947175	2017-08-11 07:09:00+03	40800.00
9471BC	2017-07-31 12:09:00+03	77200.00
947274	2017-07-12 03:29:00+03	105100.00
947289	2017-07-15 18:37:00+03	102600.00
94729F	2017-07-03 19:27:00+03	62600.00
9472F0	2017-07-12 10:40:00+03	399600.00
94735B	2017-08-10 20:35:00+03	7200.00
947368	2017-08-15 02:53:00+03	136200.00
947384	2017-08-04 09:57:00+03	133100.00
94738E	2017-08-07 09:46:00+03	66600.00
947400	2017-08-12 12:04:00+03	43600.00
947412	2017-07-16 10:18:00+03	38800.00
9474AC	2017-07-06 18:22:00+03	32800.00
94762A	2017-07-26 16:40:00+03	46800.00
947683	2017-07-04 19:13:00+03	28000.00
9476EA	2017-07-30 14:46:00+03	14800.00
947734	2017-08-02 06:26:00+03	23600.00
947742	2017-07-30 18:13:00+03	25400.00
94779D	2017-07-05 09:00:00+03	29600.00
9477A8	2017-08-09 02:44:00+03	83200.00
9477B4	2017-07-18 02:05:00+03	47000.00
9477D3	2017-07-02 17:49:00+03	272400.00
9478F8	2017-08-11 21:08:00+03	95200.00
94790F	2017-08-02 20:54:00+03	89700.00
947928	2017-07-16 11:19:00+03	65500.00
947929	2017-08-07 12:10:00+03	61600.00
947984	2017-08-04 01:58:00+03	48800.00
947A3B	2017-07-01 08:04:00+03	38400.00
947AAB	2017-07-11 06:29:00+03	175300.00
947AB8	2017-07-13 01:38:00+03	13400.00
947AFD	2017-07-31 09:07:00+03	156500.00
947B85	2017-08-02 19:57:00+03	46700.00
947B9B	2017-08-01 10:01:00+03	25100.00
947B9C	2017-07-13 01:54:00+03	14400.00
947BC4	2017-08-05 20:20:00+03	87900.00
947C3B	2017-08-02 10:45:00+03	28000.00
947C4F	2017-07-08 08:04:00+03	59800.00
947CA5	2017-08-07 11:38:00+03	56600.00
947CC8	2017-08-06 06:26:00+03	13000.00
947CF1	2017-08-01 18:44:00+03	133200.00
947CFD	2017-08-03 15:50:00+03	142800.00
947D16	2017-08-12 22:30:00+03	270700.00
947D5D	2017-08-02 08:04:00+03	179400.00
947E30	2017-07-07 07:00:00+03	65900.00
947E57	2017-07-10 19:22:00+03	28300.00
947E73	2017-07-26 19:03:00+03	74200.00
947E74	2017-07-26 20:32:00+03	205900.00
947EB4	2017-07-19 13:43:00+03	8200.00
947ECE	2017-08-12 06:49:00+03	82900.00
947F02	2017-07-04 20:04:00+03	25600.00
947F32	2017-07-30 06:27:00+03	125200.00
947F67	2017-07-18 11:26:00+03	16400.00
947FD5	2017-08-01 20:39:00+03	293500.00
947FEC	2017-08-15 14:19:00+03	12000.00
948026	2017-08-01 04:01:00+03	133200.00
94806D	2017-07-28 15:16:00+03	55800.00
9480CB	2017-08-12 20:15:00+03	55800.00
948181	2017-07-03 04:58:00+03	57800.00
94818A	2017-07-16 17:08:00+03	303300.00
948194	2017-08-02 10:16:00+03	745000.00
94819A	2017-07-25 09:09:00+03	110500.00
9481B2	2017-07-22 18:56:00+03	29400.00
94824A	2017-06-30 16:18:00+03	62000.00
948327	2017-07-12 05:01:00+03	8200.00
94833C	2017-07-21 15:33:00+03	64200.00
9483DD	2017-08-10 03:36:00+03	85000.00
948409	2017-08-06 07:54:00+03	66000.00
948421	2017-08-11 06:29:00+03	136200.00
9484FA	2017-07-26 01:59:00+03	25400.00
94852A	2017-08-03 11:39:00+03	28000.00
948586	2017-07-11 00:36:00+03	136200.00
9485D1	2017-07-15 23:56:00+03	98400.00
9485ED	2017-07-27 03:16:00+03	6000.00
9485F1	2017-07-03 17:35:00+03	231300.00
94864C	2017-07-14 09:38:00+03	123000.00
948667	2017-07-06 11:20:00+03	12600.00
9486EA	2017-07-29 18:53:00+03	75600.00
9486F3	2017-08-06 16:15:00+03	7400.00
94871C	2017-08-05 15:58:00+03	22400.00
948726	2017-07-28 07:42:00+03	49800.00
948731	2017-08-06 03:51:00+03	56000.00
948811	2017-07-30 16:05:00+03	57700.00
948855	2017-07-19 07:05:00+03	398600.00
948883	2017-08-11 22:14:00+03	31600.00
94889C	2017-06-30 18:10:00+03	52400.00
9488F4	2017-07-13 08:25:00+03	57600.00
948916	2017-07-26 22:12:00+03	23600.00
94895F	2017-08-04 06:37:00+03	76000.00
948985	2017-08-15 16:33:00+03	38600.00
9489B1	2017-07-02 09:44:00+03	89600.00
9489B4	2017-07-02 15:11:00+03	40400.00
9489D1	2017-07-20 03:02:00+03	38800.00
9489EF	2017-07-21 06:20:00+03	37900.00
948A17	2017-07-15 10:53:00+03	23200.00
948A31	2017-08-06 09:22:00+03	54400.00
948A3A	2017-07-06 18:52:00+03	56100.00
948A8C	2017-07-17 10:29:00+03	23200.00
948B06	2017-07-31 23:29:00+03	11600.00
948BE9	2017-08-06 19:47:00+03	6000.00
948BF3	2017-08-06 01:21:00+03	85000.00
948C25	2017-07-17 15:57:00+03	41800.00
948C7B	2017-07-06 03:40:00+03	55800.00
948CC9	2017-08-08 22:21:00+03	133100.00
948CE3	2017-07-12 13:36:00+03	27300.00
948CED	2017-07-08 15:30:00+03	100600.00
948E2C	2017-08-03 01:08:00+03	25400.00
948EC8	2017-08-12 17:22:00+03	57800.00
948F09	2017-07-25 22:40:00+03	168000.00
948F4A	2017-07-08 16:21:00+03	26800.00
948F4B	2017-07-12 15:56:00+03	135200.00
949015	2017-07-06 21:48:00+03	67600.00
94903B	2017-07-05 22:16:00+03	128600.00
949057	2017-07-31 03:17:00+03	42400.00
9490BE	2017-07-12 19:13:00+03	133200.00
94911B	2017-07-14 04:48:00+03	58700.00
949151	2017-07-04 00:21:00+03	28000.00
949187	2017-07-20 17:31:00+03	28800.00
94919D	2017-07-07 11:45:00+03	55600.00
9492A5	2017-08-08 00:14:00+03	13400.00
9492AA	2017-07-11 09:04:00+03	40000.00
9492AC	2017-07-11 01:55:00+03	91200.00
9492DB	2017-08-05 15:41:00+03	12600.00
9492FB	2017-07-12 03:56:00+03	25600.00
949317	2017-08-07 15:33:00+03	25100.00
94939A	2017-08-01 11:38:00+03	39600.00
9493CC	2017-08-02 16:28:00+03	46800.00
9493D6	2017-07-17 07:55:00+03	43200.00
949404	2017-08-13 01:25:00+03	348800.00
94945C	2017-08-11 14:44:00+03	47000.00
949484	2017-08-04 07:05:00+03	62900.00
9494AC	2017-08-15 00:33:00+03	51800.00
949516	2017-07-01 23:59:00+03	46400.00
94959F	2017-07-10 16:26:00+03	23200.00
9495BA	2017-08-14 10:12:00+03	47100.00
949625	2017-08-14 14:26:00+03	8200.00
94962B	2017-08-08 07:46:00+03	81600.00
949661	2017-07-10 09:09:00+03	58000.00
949697	2017-07-12 04:58:00+03	36800.00
9496ED	2017-08-14 02:29:00+03	130500.00
9496F0	2017-07-22 09:32:00+03	111600.00
949729	2017-07-19 02:09:00+03	136100.00
949736	2017-07-17 14:34:00+03	21000.00
9497B7	2017-07-26 14:50:00+03	56000.00
949808	2017-08-03 13:02:00+03	81700.00
949821	2017-07-08 18:10:00+03	259300.00
949849	2017-08-08 04:43:00+03	68800.00
9498B6	2017-07-04 01:11:00+03	32800.00
9498FA	2017-07-09 18:21:00+03	133200.00
9499FA	2017-07-07 12:55:00+03	73200.00
9499FB	2017-07-14 05:40:00+03	199700.00
949A05	2017-07-09 01:27:00+03	12000.00
949AB8	2017-07-26 01:52:00+03	28800.00
949B1C	2017-07-27 19:44:00+03	116000.00
949B23	2017-07-02 08:51:00+03	34600.00
949BC3	2017-07-06 01:09:00+03	119600.00
949BFE	2017-07-28 00:08:00+03	36500.00
949C6B	2017-07-01 09:09:00+03	51400.00
949CC2	2017-08-03 05:24:00+03	75600.00
949CF5	2017-08-13 01:41:00+03	93000.00
949D0C	2017-07-21 04:22:00+03	270800.00
949D31	2017-07-09 00:27:00+03	20200.00
949D4C	2017-07-01 02:02:00+03	112000.00
949DDA	2017-08-03 15:35:00+03	98200.00
949E04	2017-07-09 12:20:00+03	19600.00
949E06	2017-06-30 12:36:00+03	68800.00
949E28	2017-08-07 23:35:00+03	23900.00
949E48	2017-06-27 18:47:00+03	56000.00
949E53	2017-07-02 23:25:00+03	115600.00
949E5E	2017-08-04 08:22:00+03	31600.00
949E60	2017-07-06 19:34:00+03	44600.00
949E92	2017-07-12 21:14:00+03	113600.00
949EFB	2017-08-04 10:35:00+03	40600.00
949F0E	2017-07-21 08:19:00+03	10800.00
949F16	2017-06-30 18:13:00+03	44600.00
949F2D	2017-07-13 23:34:00+03	32200.00
949FEA	2017-07-23 14:09:00+03	47600.00
94A022	2017-07-13 11:34:00+03	66600.00
94A051	2017-07-29 07:55:00+03	27200.00
94A0E9	2017-07-29 21:55:00+03	178000.00
94A109	2017-07-20 18:25:00+03	67600.00
94A10F	2017-07-18 02:20:00+03	114800.00
94A126	2017-07-13 20:52:00+03	28000.00
94A13F	2017-07-20 18:07:00+03	53600.00
94A141	2017-08-13 05:10:00+03	34800.00
94A18C	2017-06-30 22:28:00+03	307700.00
94A1C0	2017-07-11 07:37:00+03	78500.00
94A22A	2017-08-10 08:11:00+03	103900.00
94A272	2017-08-02 14:39:00+03	206400.00
94A27A	2017-06-30 15:14:00+03	254900.00
94A28A	2017-07-02 12:05:00+03	46300.00
94A29B	2017-08-06 03:56:00+03	168000.00
94A2BB	2017-07-26 22:22:00+03	68000.00
94A2DF	2017-07-18 22:41:00+03	75300.00
94A385	2017-07-17 08:03:00+03	53800.00
94A39E	2017-07-26 16:27:00+03	52800.00
94A42F	2017-07-03 03:55:00+03	61900.00
94A438	2017-07-25 22:49:00+03	6200.00
94A47E	2017-07-20 22:30:00+03	65900.00
94A491	2017-08-12 01:59:00+03	3400.00
94A4C3	2017-08-05 23:40:00+03	47500.00
94A501	2017-07-10 10:00:00+03	60800.00
94A520	2017-08-02 02:41:00+03	31600.00
94A52D	2017-07-23 13:00:00+03	10800.00
94A64D	2017-08-12 15:57:00+03	10800.00
94A66C	2017-08-06 03:25:00+03	31900.00
94A68D	2017-07-28 08:55:00+03	67200.00
94A695	2017-08-09 08:04:00+03	74900.00
94A6AF	2017-07-30 23:52:00+03	95600.00
94A6C2	2017-08-06 00:18:00+03	62600.00
94A721	2017-07-06 14:54:00+03	57800.00
94A7A6	2017-08-09 09:10:00+03	79200.00
94A853	2017-07-24 14:00:00+03	30200.00
94A8B7	2017-07-09 10:28:00+03	87700.00
94A952	2017-07-15 23:29:00+03	39900.00
94A9C3	2017-08-10 16:29:00+03	36800.00
94A9DA	2017-08-12 06:48:00+03	615000.00
94AA37	2017-07-11 00:40:00+03	78900.00
94AA45	2017-07-25 07:24:00+03	7200.00
94AA56	2017-07-17 01:52:00+03	23200.00
94AA59	2017-07-24 20:28:00+03	13000.00
94AA97	2017-07-05 22:49:00+03	29600.00
94AA9E	2017-07-24 06:46:00+03	134000.00
94AB1F	2017-08-15 05:21:00+03	14000.00
94ABDC	2017-08-14 12:43:00+03	92600.00
94AD36	2017-07-06 08:04:00+03	34000.00
94AD46	2017-07-04 15:25:00+03	402700.00
94AED1	2017-08-04 23:29:00+03	39600.00
94AF02	2017-07-13 01:16:00+03	6000.00
94AF84	2017-06-29 17:38:00+03	34800.00
94AFC3	2017-06-29 11:29:00+03	6000.00
94AFE9	2017-07-27 11:35:00+03	96800.00
94B0B3	2017-07-18 04:45:00+03	68900.00
94B0FC	2017-07-26 18:49:00+03	30900.00
94B190	2017-07-28 20:23:00+03	62600.00
94B1EE	2017-06-29 08:05:00+03	25100.00
94B254	2017-07-16 09:49:00+03	6600.00
94B303	2017-08-02 06:54:00+03	28000.00
94B30B	2017-07-11 17:34:00+03	6000.00
94B377	2017-07-31 19:15:00+03	22100.00
94B3BF	2017-07-14 01:45:00+03	131100.00
94B3E0	2017-07-26 10:25:00+03	56000.00
94B442	2017-08-05 14:09:00+03	78500.00
94B508	2017-07-08 19:47:00+03	73200.00
94B53E	2017-07-18 13:41:00+03	26200.00
94B56B	2017-08-03 11:52:00+03	101500.00
94B57B	2017-07-25 17:31:00+03	94000.00
94B58B	2017-08-06 02:58:00+03	113300.00
94B602	2017-07-04 20:09:00+03	23600.00
94B62C	2017-07-30 12:47:00+03	13400.00
94B654	2017-07-22 13:29:00+03	61500.00
94B686	2017-07-20 20:52:00+03	46000.00
94B69F	2017-08-03 18:38:00+03	98400.00
94B6A4	2017-07-13 19:47:00+03	65900.00
94B6F6	2017-07-14 08:09:00+03	39500.00
94B743	2017-08-11 06:13:00+03	12600.00
94B755	2017-07-12 05:56:00+03	29600.00
94B794	2017-08-11 04:05:00+03	47800.00
94B80B	2017-07-07 22:09:00+03	139200.00
94B817	2017-07-11 01:51:00+03	42000.00
94B957	2017-07-04 07:44:00+03	34000.00
94B987	2017-07-27 00:18:00+03	147000.00
94B98F	2017-08-14 13:39:00+03	139300.00
94BA3F	2017-07-10 09:06:00+03	81600.00
94BA61	2017-08-10 05:30:00+03	31200.00
94BA7F	2017-07-16 16:43:00+03	57400.00
94BAA2	2017-07-07 03:51:00+03	32700.00
94BAB8	2017-07-23 13:41:00+03	43800.00
94BB28	2017-08-09 12:15:00+03	46400.00
94BB46	2017-07-10 02:45:00+03	13400.00
94BB53	2017-07-13 13:27:00+03	62200.00
94BBAB	2017-07-10 06:57:00+03	8000.00
94BBAE	2017-08-06 22:25:00+03	26000.00
94BC10	2017-07-17 23:58:00+03	73500.00
94BC65	2017-07-12 10:32:00+03	74400.00
94BCAE	2017-08-02 13:16:00+03	53600.00
94BCFF	2017-08-10 17:54:00+03	170500.00
94BDB9	2017-08-06 10:02:00+03	39500.00
94BDEB	2017-07-13 21:36:00+03	23200.00
94BE71	2017-08-02 08:15:00+03	38600.00
94BE82	2017-08-02 01:24:00+03	67000.00
94BE85	2017-08-02 18:14:00+03	135000.00
94BE91	2017-08-04 11:03:00+03	73200.00
94BEED	2017-08-02 03:41:00+03	88200.00
94BF80	2017-07-11 19:06:00+03	95200.00
94BFAE	2017-07-09 05:57:00+03	89600.00
94BFEA	2017-07-02 07:52:00+03	143100.00
94C048	2017-06-29 04:18:00+03	51900.00
94C0A7	2017-07-14 19:37:00+03	15400.00
94C0FA	2017-07-27 17:56:00+03	14000.00
94C104	2017-07-27 23:22:00+03	58400.00
94C19D	2017-08-12 02:02:00+03	73800.00
94C1AB	2017-07-07 09:40:00+03	54500.00
94C214	2017-08-11 16:28:00+03	131100.00
94C226	2017-07-31 21:50:00+03	67000.00
94C29C	2017-07-16 06:31:00+03	128800.00
94C2DF	2017-07-08 16:48:00+03	11600.00
94C316	2017-07-03 23:35:00+03	14800.00
94C353	2017-07-09 09:02:00+03	23200.00
94C358	2017-08-08 17:04:00+03	30000.00
94C3A8	2017-07-08 02:16:00+03	62900.00
94C411	2017-08-10 20:50:00+03	20200.00
94C434	2017-08-12 18:32:00+03	14600.00
94C470	2017-07-23 04:13:00+03	77900.00
94C4F3	2017-07-29 10:50:00+03	70500.00
94C504	2017-06-30 04:23:00+03	43800.00
94C538	2017-08-15 01:54:00+03	12100.00
94C576	2017-07-29 17:20:00+03	101800.00
94C5AA	2017-07-18 20:47:00+03	67600.00
94C5CB	2017-08-01 13:44:00+03	56000.00
94C5EF	2017-07-29 04:58:00+03	30800.00
94C65C	2017-08-14 01:03:00+03	206700.00
94C6C7	2017-07-10 11:04:00+03	136800.00
94C6D4	2017-07-23 21:51:00+03	111600.00
94C70B	2017-07-05 00:45:00+03	39700.00
94C70E	2017-08-06 02:01:00+03	89700.00
94C716	2017-07-04 13:36:00+03	57800.00
94C736	2017-08-06 19:00:00+03	68800.00
94C7AC	2017-07-23 03:37:00+03	27800.00
94C81B	2017-07-19 01:45:00+03	65900.00
94C870	2017-07-14 18:01:00+03	117000.00
94C871	2017-07-15 18:11:00+03	83000.00
94C8B5	2017-07-12 07:13:00+03	14000.00
94C924	2017-07-27 09:31:00+03	26000.00
94C945	2017-07-26 18:49:00+03	51300.00
94C982	2017-08-03 04:52:00+03	68800.00
94C9DB	2017-08-08 17:46:00+03	100600.00
94CA24	2017-07-17 00:12:00+03	246000.00
94CA38	2017-08-07 03:09:00+03	103800.00
94CB1B	2017-07-04 05:56:00+03	101200.00
94CB4D	2017-07-14 00:52:00+03	38000.00
94CB95	2017-07-29 13:26:00+03	273000.00
94CB96	2017-07-09 04:24:00+03	133200.00
94CC05	2017-08-15 09:54:00+03	186100.00
94CC2C	2017-08-07 23:06:00+03	58600.00
94CC43	2017-08-15 08:47:00+03	166100.00
94CC79	2017-07-20 13:54:00+03	160100.00
94CC89	2017-08-06 09:41:00+03	23200.00
94CD05	2017-07-29 21:22:00+03	27400.00
94CD14	2017-07-28 23:56:00+03	25600.00
94CDDF	2017-08-09 09:09:00+03	21400.00
94CE0E	2017-07-22 21:55:00+03	54000.00
94CE16	2017-08-12 17:02:00+03	34800.00
94CE3E	2017-08-02 00:04:00+03	22000.00
94CE41	2017-08-03 19:21:00+03	271100.00
94CE4A	2017-07-19 19:25:00+03	131600.00
94CE57	2017-07-29 18:52:00+03	75300.00
94CEDA	2017-08-11 01:18:00+03	60400.00
94CEF0	2017-08-06 23:22:00+03	232100.00
94CF0D	2017-08-04 05:22:00+03	38600.00
94CF40	2017-07-19 10:01:00+03	24400.00
94CF46	2017-07-11 20:27:00+03	28800.00
94CFC4	2017-07-24 08:41:00+03	6000.00
94D00F	2017-07-15 14:33:00+03	20200.00
94D01A	2017-07-26 03:05:00+03	65800.00
94D062	2017-07-15 03:36:00+03	56000.00
94D07F	2017-07-14 15:38:00+03	23200.00
94D0A4	2017-07-30 18:14:00+03	179300.00
94D195	2017-08-14 15:03:00+03	135400.00
94D1DC	2017-07-14 02:41:00+03	112000.00
94D1EB	2017-08-09 22:37:00+03	67000.00
94D23C	2017-08-13 16:57:00+03	54400.00
94D2D6	2017-07-18 02:30:00+03	133900.00
94D2DF	2017-07-18 22:45:00+03	12600.00
94D2FF	2017-07-21 01:43:00+03	152400.00
94D308	2017-07-26 09:11:00+03	123200.00
94D384	2017-08-01 18:37:00+03	39800.00
94D3F4	2017-07-05 13:53:00+03	26800.00
94D3FF	2017-07-25 01:23:00+03	75600.00
94D408	2017-08-10 18:48:00+03	202300.00
94D450	2017-08-14 03:46:00+03	68400.00
94D46A	2017-08-06 02:52:00+03	303200.00
94D4CB	2017-07-06 15:47:00+03	17600.00
94D523	2017-08-15 15:24:00+03	23200.00
94D534	2017-07-03 18:54:00+03	202100.00
94D5AA	2017-06-29 22:54:00+03	39500.00
94D5EB	2017-07-01 08:36:00+03	86800.00
94D63B	2017-07-17 07:04:00+03	86300.00
94D66E	2017-08-14 00:53:00+03	46400.00
94D672	2017-07-06 23:04:00+03	47000.00
94D727	2017-07-08 22:34:00+03	38800.00
94D746	2017-08-02 17:53:00+03	43400.00
94D7A2	2017-07-12 17:30:00+03	55000.00
94D7AB	2017-07-27 21:15:00+03	23200.00
94D7B1	2017-08-11 08:57:00+03	117700.00
94D7BA	2017-07-18 05:25:00+03	121800.00
94D7D8	2017-08-09 16:01:00+03	18600.00
94D802	2017-08-02 06:09:00+03	369000.00
94D86F	2017-07-07 08:28:00+03	187600.00
94D9A5	2017-07-05 17:49:00+03	257500.00
94DA43	2017-08-07 11:37:00+03	28800.00
94DA45	2017-07-15 21:30:00+03	23200.00
94DAC9	2017-07-04 21:17:00+03	56000.00
94DACF	2017-07-16 18:32:00+03	102100.00
94DAD4	2017-07-15 11:11:00+03	51800.00
94DAF1	2017-08-14 03:10:00+03	24400.00
94DBB6	2017-07-13 07:07:00+03	28800.00
94DC09	2017-07-18 23:43:00+03	68800.00
94DC9F	2017-08-07 12:15:00+03	22000.00
94DCC2	2017-07-12 01:15:00+03	17000.00
94DD62	2017-08-15 14:20:00+03	25600.00
94DD84	2017-08-13 17:29:00+03	226400.00
94DEEB	2017-08-02 20:47:00+03	339800.00
94DF05	2017-08-03 16:52:00+03	46200.00
94DF2A	2017-07-20 03:09:00+03	137600.00
94DF97	2017-08-07 13:29:00+03	125200.00
94E05C	2017-07-18 08:20:00+03	54800.00
94E088	2017-07-27 12:10:00+03	139400.00
94E0A5	2017-07-22 11:47:00+03	111600.00
94E0A6	2017-08-05 12:18:00+03	129000.00
94E0B1	2017-07-28 18:02:00+03	128800.00
94E0C5	2017-08-06 20:09:00+03	25200.00
94E106	2017-07-23 21:09:00+03	56000.00
94E112	2017-07-06 20:09:00+03	61800.00
94E142	2017-07-21 19:52:00+03	46300.00
94E239	2017-07-25 14:00:00+03	12000.00
94E25F	2017-08-13 08:06:00+03	49800.00
94E27E	2017-08-01 23:39:00+03	101200.00
94E2A9	2017-08-12 12:32:00+03	65000.00
94E2CD	2017-07-24 10:50:00+03	6700.00
94E343	2017-07-18 00:51:00+03	70700.00
94E365	2017-08-02 21:27:00+03	46000.00
94E372	2017-08-01 17:26:00+03	265800.00
94E3C3	2017-08-06 19:40:00+03	40500.00
94E3C8	2017-08-02 09:24:00+03	37900.00
94E3E5	2017-07-25 20:31:00+03	67600.00
94E3F2	2017-07-25 21:09:00+03	35600.00
94E453	2017-07-01 19:57:00+03	133200.00
94E463	2017-08-05 06:40:00+03	28800.00
94E51B	2017-07-10 01:26:00+03	76600.00
94E528	2017-07-08 04:48:00+03	13400.00
94E529	2017-08-01 13:16:00+03	15400.00
94E536	2017-07-02 01:45:00+03	26000.00
94E543	2017-08-04 14:57:00+03	32800.00
94E549	2017-07-12 00:14:00+03	13400.00
94E561	2017-07-30 12:12:00+03	148200.00
94E5A4	2017-08-05 07:57:00+03	102100.00
94E5FB	2017-08-12 15:08:00+03	6800.00
94E5FD	2017-07-20 22:28:00+03	88800.00
94E669	2017-07-21 21:54:00+03	66600.00
94E6E9	2017-08-10 21:05:00+03	44000.00
94E72E	2017-08-15 02:53:00+03	25400.00
94E763	2017-07-02 07:16:00+03	199700.00
94E774	2017-07-19 12:47:00+03	140300.00
94E785	2017-08-01 18:52:00+03	22000.00
94E7B7	2017-07-18 11:26:00+03	52000.00
94E808	2017-07-29 00:03:00+03	53500.00
94E818	2017-08-02 23:57:00+03	57200.00
94E840	2017-08-06 16:55:00+03	62600.00
94E843	2017-07-16 02:26:00+03	26000.00
94E87D	2017-07-04 02:19:00+03	67400.00
94E8E7	2017-07-14 19:01:00+03	13600.00
94E945	2017-07-06 19:28:00+03	167900.00
94E954	2017-07-30 19:36:00+03	67600.00
94E955	2017-07-22 08:42:00+03	56000.00
94E9B3	2017-07-25 06:18:00+03	30200.00
94E9F8	2017-07-23 05:35:00+03	40000.00
94EB1F	2017-07-13 22:33:00+03	294200.00
94EB2C	2017-07-15 18:14:00+03	42400.00
94EB33	2017-08-15 01:17:00+03	56000.00
94EB44	2017-07-13 18:57:00+03	47100.00
94EC19	2017-08-07 13:48:00+03	47100.00
94EC29	2017-07-31 10:36:00+03	19600.00
94EC7A	2017-08-03 00:35:00+03	45000.00
94ECD8	2017-07-25 14:54:00+03	56600.00
94ECF7	2017-07-14 05:55:00+03	26800.00
94ED75	2017-07-03 23:32:00+03	40200.00
94EE49	2017-08-14 03:46:00+03	286700.00
94EE68	2017-07-20 01:28:00+03	85000.00
94EE87	2017-08-09 12:09:00+03	186900.00
94EEB4	2017-07-15 03:20:00+03	119500.00
94EEB8	2017-07-09 11:16:00+03	13600.00
94EEC1	2017-07-19 13:37:00+03	152900.00
94EEF2	2017-07-28 09:37:00+03	23600.00
94EEFC	2017-08-15 10:58:00+03	31600.00
94EF7C	2017-06-27 18:59:00+03	18000.00
94EF93	2017-08-03 07:28:00+03	288500.00
94F042	2017-07-26 06:53:00+03	46400.00
94F084	2017-07-27 22:45:00+03	26000.00
94F150	2017-07-30 06:15:00+03	11700.00
94F186	2017-08-03 08:04:00+03	142300.00
94F1B3	2017-08-08 05:33:00+03	65900.00
94F210	2017-08-10 06:49:00+03	12200.00
94F273	2017-08-04 01:12:00+03	39100.00
94F2C2	2017-07-22 05:17:00+03	46900.00
94F2D3	2017-07-11 05:30:00+03	89200.00
94F31A	2017-07-14 21:30:00+03	90400.00
94F407	2017-07-21 08:12:00+03	101100.00
94F44C	2017-06-29 03:14:00+03	212600.00
94F48E	2017-07-15 01:52:00+03	65500.00
94F4A5	2017-07-02 22:07:00+03	40800.00
94F51A	2017-07-16 11:32:00+03	38400.00
94F535	2017-07-25 02:04:00+03	246000.00
94F536	2017-07-15 12:04:00+03	88100.00
94F595	2017-08-15 02:40:00+03	66600.00
94F5B8	2017-08-09 02:03:00+03	14400.00
94F5F3	2017-07-12 06:38:00+03	131600.00
94F60B	2017-08-12 00:38:00+03	52000.00
94F6B6	2017-08-10 16:09:00+03	84100.00
94F71D	2017-08-09 17:44:00+03	73500.00
94F786	2017-07-04 17:31:00+03	14400.00
94F873	2017-07-15 06:54:00+03	31600.00
94F92B	2017-07-19 06:30:00+03	119500.00
94F987	2017-07-08 21:36:00+03	12400.00
94F9B3	2017-08-04 09:32:00+03	137000.00
94F9EA	2017-08-12 19:09:00+03	73600.00
94FA04	2017-07-26 23:56:00+03	43000.00
94FA10	2017-07-07 20:20:00+03	64100.00
94FA67	2017-08-14 12:55:00+03	288600.00
94FB14	2017-07-21 13:08:00+03	184000.00
94FB48	2017-08-01 20:46:00+03	24000.00
94FB8C	2017-08-02 04:55:00+03	213200.00
94FCD0	2017-07-19 14:49:00+03	14400.00
94FCEB	2017-07-10 13:31:00+03	40800.00
94FD1D	2017-07-06 18:33:00+03	49600.00
94FD1E	2017-07-29 10:39:00+03	36200.00
94FD3D	2017-08-02 15:06:00+03	59800.00
94FD91	2017-07-20 14:36:00+03	24200.00
94FDD8	2017-08-07 16:33:00+03	28000.00
94FDFE	2017-07-03 21:01:00+03	58800.00
94FE42	2017-07-20 12:33:00+03	62600.00
94FE8E	2017-07-24 11:54:00+03	16400.00
94FED5	2017-07-21 18:14:00+03	54800.00
94FF4E	2017-07-11 01:29:00+03	56000.00
94FF5B	2017-07-25 23:59:00+03	31000.00
94FF77	2017-07-03 20:11:00+03	56600.00
94FFEF	2017-07-02 17:11:00+03	48600.00
94FFF1	2017-07-21 13:39:00+03	112000.00
950015	2017-07-18 19:21:00+03	369000.00
950027	2017-08-07 20:15:00+03	67600.00
95009B	2017-07-27 23:16:00+03	51900.00
9500EC	2017-07-23 03:15:00+03	14400.00
950105	2017-08-07 06:16:00+03	54000.00
950173	2017-07-30 22:24:00+03	50100.00
950184	2017-07-01 02:07:00+03	101200.00
950214	2017-07-20 04:41:00+03	99300.00
950241	2017-08-04 08:21:00+03	79000.00
950245	2017-07-06 20:35:00+03	111600.00
950280	2017-07-05 10:34:00+03	26200.00
9502D4	2017-08-09 08:05:00+03	50100.00
9502D5	2017-07-15 21:25:00+03	277900.00
950306	2017-07-24 21:13:00+03	200500.00
9503C3	2017-07-17 22:04:00+03	38600.00
950493	2017-07-19 09:22:00+03	18800.00
9504A9	2017-07-17 06:15:00+03	35200.00
9504AD	2017-07-21 03:56:00+03	21400.00
950515	2017-07-22 21:45:00+03	26000.00
950542	2017-07-25 19:03:00+03	23400.00
95058E	2017-07-26 22:28:00+03	135400.00
9505CA	2017-07-25 19:52:00+03	34000.00
9505FB	2017-07-03 11:14:00+03	44800.00
9505FF	2017-07-13 23:44:00+03	240600.00
950608	2017-08-05 11:39:00+03	521800.00
95063B	2017-07-29 18:20:00+03	8200.00
950645	2017-08-09 12:43:00+03	55800.00
9506A1	2017-07-24 11:36:00+03	67600.00
9506AC	2017-07-06 20:55:00+03	27900.00
950737	2017-07-14 17:13:00+03	67600.00
95075D	2017-08-08 01:45:00+03	123000.00
95083A	2017-07-03 10:06:00+03	25700.00
950841	2017-07-20 16:57:00+03	6800.00
95085C	2017-08-03 15:27:00+03	59300.00
950860	2017-08-14 19:06:00+03	35300.00
950884	2017-07-29 02:18:00+03	12000.00
950897	2017-08-03 19:30:00+03	100600.00
95089B	2017-07-29 02:11:00+03	210200.00
9508A3	2017-07-16 12:03:00+03	56000.00
9508F2	2017-08-09 22:46:00+03	123000.00
95093F	2017-07-19 10:57:00+03	266400.00
95094F	2017-07-06 06:53:00+03	58600.00
950955	2017-07-26 02:02:00+03	39700.00
950957	2017-07-01 08:55:00+03	246000.00
950963	2017-07-22 12:00:00+03	55800.00
950976	2017-07-01 12:09:00+03	34000.00
9509E8	2017-07-01 11:18:00+03	71900.00
9509F8	2017-08-11 04:02:00+03	129700.00
950A04	2017-07-17 02:42:00+03	115900.00
950A0D	2017-07-20 13:40:00+03	67600.00
950A15	2017-07-11 01:52:00+03	29600.00
950A37	2017-07-04 12:27:00+03	492000.00
950A38	2017-07-21 16:51:00+03	86400.00
950ACB	2017-07-04 16:17:00+03	25600.00
950AD0	2017-08-13 22:57:00+03	142800.00
950B3D	2017-08-13 02:17:00+03	15000.00
950B44	2017-08-14 16:52:00+03	25700.00
950B4E	2017-07-24 11:19:00+03	136600.00
950B80	2017-08-15 12:06:00+03	112000.00
950B8B	2017-07-08 12:56:00+03	69500.00
950BB4	2017-07-05 21:26:00+03	50700.00
950C1E	2017-07-13 06:52:00+03	29100.00
950C23	2017-08-07 01:08:00+03	36800.00
950C9B	2017-07-01 14:52:00+03	141600.00
950CA8	2017-08-01 22:39:00+03	81300.00
950CBD	2017-07-06 03:11:00+03	26000.00
950D0A	2017-07-18 21:19:00+03	46000.00
950D54	2017-07-18 17:09:00+03	167400.00
950D5E	2017-07-02 04:14:00+03	56600.00
950E14	2017-08-02 00:50:00+03	20000.00
950E7F	2017-08-01 00:13:00+03	130400.00
950E95	2017-07-25 15:14:00+03	70700.00
950EBF	2017-08-15 01:03:00+03	61000.00
950EF2	2017-06-30 18:00:00+03	40700.00
950EFD	2017-07-10 21:40:00+03	21800.00
950F64	2017-08-07 01:09:00+03	123000.00
950F88	2017-08-11 03:27:00+03	33400.00
950FA4	2017-07-17 18:42:00+03	56600.00
950FE8	2017-08-03 03:16:00+03	164800.00
95103F	2017-07-11 14:06:00+03	42800.00
9510F1	2017-07-07 04:50:00+03	27600.00
95112E	2017-08-02 17:39:00+03	88800.00
95114F	2017-07-01 02:19:00+03	14400.00
9511A1	2017-07-08 15:45:00+03	58400.00
9511DE	2017-06-30 13:37:00+03	301800.00
951269	2017-07-13 11:44:00+03	29600.00
9512A0	2017-08-07 17:39:00+03	46400.00
95130C	2017-07-06 23:22:00+03	55800.00
95131A	2017-08-09 08:18:00+03	58500.00
951360	2017-08-14 17:49:00+03	138100.00
951377	2017-07-12 15:12:00+03	58800.00
9513BE	2017-07-30 06:37:00+03	47100.00
951437	2017-08-02 09:11:00+03	28800.00
951460	2017-07-08 12:34:00+03	29600.00
95146F	2017-07-09 07:12:00+03	56200.00
951480	2017-08-15 03:15:00+03	37600.00
951525	2017-07-03 23:32:00+03	199700.00
95152F	2017-07-12 11:39:00+03	136200.00
951545	2017-07-22 02:01:00+03	16400.00
951554	2017-07-25 15:28:00+03	496600.00
95159E	2017-08-04 20:29:00+03	38800.00
9515AB	2017-08-06 02:45:00+03	115700.00
9515EB	2017-08-08 20:32:00+03	37000.00
951620	2017-07-16 02:37:00+03	24400.00
951636	2017-08-04 07:26:00+03	14000.00
95164C	2017-08-06 09:04:00+03	260300.00
951667	2017-08-15 02:18:00+03	40000.00
951733	2017-07-31 06:48:00+03	152200.00
95177F	2017-08-09 08:33:00+03	99200.00
9517A0	2017-07-18 13:43:00+03	169900.00
951828	2017-08-08 19:22:00+03	532800.00
951898	2017-07-29 12:09:00+03	66000.00
9518EF	2017-07-28 19:16:00+03	57800.00
95197C	2017-08-14 06:43:00+03	31400.00
95199F	2017-08-07 08:59:00+03	74800.00
9519B0	2017-07-10 15:34:00+03	6800.00
9519D6	2017-08-10 18:06:00+03	119600.00
951A0C	2017-07-20 00:47:00+03	102300.00
951A70	2017-08-10 07:15:00+03	52000.00
951A87	2017-08-06 17:36:00+03	31900.00
951B85	2017-07-02 04:04:00+03	57600.00
951B8E	2017-07-12 09:09:00+03	12400.00
951BBD	2017-07-16 15:23:00+03	73500.00
951BCD	2017-07-08 17:49:00+03	117600.00
951C26	2017-06-28 09:16:00+03	14000.00
951CC9	2017-07-14 03:24:00+03	177400.00
951CE6	2017-07-20 15:33:00+03	82900.00
951D02	2017-07-10 00:44:00+03	14000.00
951D36	2017-07-03 17:37:00+03	50800.00
951D7C	2017-07-29 13:50:00+03	32800.00
951D95	2017-07-15 00:38:00+03	35200.00
951E3E	2017-08-04 23:03:00+03	108900.00
951E6A	2017-07-18 08:33:00+03	58800.00
951EA5	2017-07-22 08:15:00+03	145500.00
951ECF	2017-07-30 09:29:00+03	27900.00
951EE4	2017-08-02 13:23:00+03	81600.00
951F1A	2017-07-06 07:38:00+03	153200.00
951F39	2017-07-09 06:37:00+03	62800.00
951F70	2017-07-08 15:04:00+03	46400.00
952032	2017-07-22 05:14:00+03	85000.00
95203D	2017-07-10 00:47:00+03	159200.00
95206B	2017-08-07 06:24:00+03	116400.00
952071	2017-07-07 14:22:00+03	14000.00
9520F2	2017-08-12 09:11:00+03	12600.00
9520FD	2017-07-10 18:31:00+03	114400.00
9521A2	2017-07-24 21:42:00+03	184300.00
952258	2017-06-29 22:03:00+03	16400.00
952267	2017-07-08 11:57:00+03	254600.00
952283	2017-08-03 20:28:00+03	39100.00
9522D6	2017-08-05 16:41:00+03	11600.00
95232C	2017-07-09 16:32:00+03	58600.00
95243E	2017-08-03 12:39:00+03	24400.00
95244E	2017-07-21 17:34:00+03	36400.00
9524AB	2017-07-24 15:24:00+03	86300.00
9524EB	2017-07-16 09:24:00+03	398500.00
9525CA	2017-07-23 12:01:00+03	55800.00
952619	2017-07-16 02:00:00+03	46300.00
952623	2017-07-13 07:52:00+03	49800.00
952643	2017-08-12 02:37:00+03	65900.00
95264E	2017-07-14 02:48:00+03	26000.00
9526E0	2017-07-26 18:05:00+03	59900.00
952713	2017-07-28 10:07:00+03	62800.00
952759	2017-07-30 10:42:00+03	133200.00
95276F	2017-07-13 22:28:00+03	93700.00
952788	2017-07-02 00:36:00+03	46400.00
9527F7	2017-07-03 08:03:00+03	29400.00
9527F9	2017-08-05 20:50:00+03	67600.00
952833	2017-08-08 16:03:00+03	38800.00
952873	2017-07-06 01:12:00+03	34100.00
952891	2017-07-11 17:12:00+03	26000.00
9528C2	2017-06-30 03:57:00+03	26000.00
9528D3	2017-07-30 22:50:00+03	272300.00
95292E	2017-07-25 11:02:00+03	92600.00
95292F	2017-08-06 20:43:00+03	99800.00
952964	2017-07-09 22:23:00+03	145100.00
952991	2017-07-04 23:47:00+03	87100.00
95299B	2017-08-11 17:43:00+03	31600.00
95299F	2017-07-21 13:53:00+03	20200.00
9529B8	2017-07-31 13:03:00+03	62600.00
9529FE	2017-07-02 15:18:00+03	71600.00
952A0D	2017-07-25 08:38:00+03	59800.00
952A7F	2017-07-08 01:17:00+03	79200.00
952ACA	2017-07-07 13:57:00+03	49600.00
952AF6	2017-07-16 10:47:00+03	68000.00
952B45	2017-07-09 05:27:00+03	6800.00
952B5A	2017-08-03 21:22:00+03	25400.00
952B5E	2017-08-11 17:09:00+03	56000.00
952BB9	2017-07-14 14:29:00+03	48100.00
952D76	2017-08-07 12:32:00+03	38600.00
952DD7	2017-07-12 18:02:00+03	19600.00
952E0B	2017-07-24 15:08:00+03	40600.00
952E0D	2017-08-02 15:38:00+03	31400.00
952E80	2017-07-02 09:45:00+03	63400.00
952E8E	2017-07-30 23:17:00+03	101600.00
952F7E	2017-07-10 17:12:00+03	135000.00
952FF4	2017-07-01 10:44:00+03	22000.00
953033	2017-08-14 20:36:00+03	41800.00
95305C	2017-08-12 06:59:00+03	23600.00
953064	2017-07-07 05:10:00+03	17200.00
953088	2017-07-13 19:39:00+03	94700.00
953090	2017-08-07 15:58:00+03	232400.00
9530E0	2017-08-01 17:20:00+03	56000.00
9530EF	2017-07-17 02:41:00+03	85000.00
953159	2017-07-16 19:18:00+03	27200.00
9531F0	2017-08-09 05:05:00+03	62600.00
953217	2017-07-17 15:35:00+03	23200.00
953345	2017-08-13 23:47:00+03	38600.00
95334B	2017-07-22 16:46:00+03	13400.00
95334C	2017-07-01 11:12:00+03	174400.00
953358	2017-07-01 14:28:00+03	106400.00
95341E	2017-08-15 14:20:00+03	42800.00
95343D	2017-07-27 05:48:00+03	26800.00
95343E	2017-08-07 01:19:00+03	131100.00
953456	2017-08-12 02:34:00+03	57300.00
95349B	2017-07-10 10:40:00+03	7200.00
9534A0	2017-08-09 07:01:00+03	116900.00
953533	2017-08-03 20:35:00+03	52000.00
95353B	2017-07-27 15:06:00+03	66600.00
953651	2017-07-18 19:37:00+03	21400.00
95365E	2017-07-03 21:02:00+03	266400.00
953681	2017-06-29 06:50:00+03	13000.00
9536B3	2017-08-07 20:46:00+03	43600.00
9536EF	2017-08-07 16:23:00+03	16400.00
953706	2017-08-09 15:35:00+03	13600.00
95373E	2017-08-06 12:35:00+03	246000.00
953755	2017-07-23 12:41:00+03	89400.00
9537AE	2017-07-31 23:16:00+03	80000.00
9537BD	2017-07-12 18:55:00+03	24400.00
9537C9	2017-08-10 15:10:00+03	141300.00
9537E3	2017-06-29 12:46:00+03	58600.00
953811	2017-08-07 17:13:00+03	123000.00
95383D	2017-07-11 17:47:00+03	56000.00
953871	2017-07-03 03:03:00+03	58200.00
9538F6	2017-08-07 12:48:00+03	36200.00
95391C	2017-07-06 06:45:00+03	119500.00
953947	2017-07-11 22:19:00+03	87400.00
953967	2017-07-21 17:43:00+03	130900.00
9539BC	2017-07-14 07:25:00+03	101100.00
953A04	2017-07-14 07:36:00+03	32800.00
953A9D	2017-07-10 02:47:00+03	28000.00
953AB1	2017-07-31 08:12:00+03	29600.00
953AE3	2017-08-10 23:34:00+03	137900.00
953B3B	2017-07-30 02:12:00+03	148200.00
953B6C	2017-08-14 21:56:00+03	129600.00
953B80	2017-07-08 00:44:00+03	266300.00
953C2E	2017-08-04 03:05:00+03	91200.00
953CBB	2017-07-29 12:30:00+03	66600.00
953CF5	2017-08-07 22:45:00+03	78200.00
953D9B	2017-08-01 02:34:00+03	48800.00
953E3A	2017-07-29 04:02:00+03	213200.00
953E50	2017-07-24 20:58:00+03	113000.00
953E56	2017-08-10 12:42:00+03	6700.00
953E86	2017-07-12 05:13:00+03	105600.00
953E98	2017-07-03 21:34:00+03	246000.00
953E9B	2017-07-26 02:05:00+03	23600.00
953EE5	2017-07-26 21:06:00+03	31900.00
953EF5	2017-07-30 09:51:00+03	112000.00
953F5F	2017-07-29 16:49:00+03	50000.00
953F72	2017-07-14 15:26:00+03	23200.00
953FC6	2017-07-05 19:11:00+03	366600.00
953FE8	2017-08-07 14:50:00+03	23200.00
954041	2017-07-22 08:07:00+03	43400.00
954057	2017-08-15 11:36:00+03	68100.00
9540F3	2017-07-24 04:35:00+03	27800.00
95411E	2017-08-10 04:23:00+03	30200.00
954130	2017-08-08 19:21:00+03	132800.00
954170	2017-08-07 18:08:00+03	20400.00
95417F	2017-07-26 10:02:00+03	23100.00
9541C1	2017-08-11 02:05:00+03	17200.00
9541FE	2017-07-09 04:24:00+03	16400.00
954219	2017-08-04 20:56:00+03	47000.00
954222	2017-08-01 17:01:00+03	133100.00
954246	2017-08-03 02:17:00+03	26000.00
95424C	2017-08-14 19:18:00+03	14800.00
954267	2017-08-05 15:38:00+03	27200.00
95426E	2017-07-12 04:19:00+03	16400.00
9542A1	2017-07-11 05:51:00+03	168000.00
9542D6	2017-07-14 13:23:00+03	127900.00
9542DE	2017-08-10 16:56:00+03	189100.00
9542EF	2017-07-01 14:32:00+03	183300.00
95433C	2017-07-11 00:43:00+03	18100.00
95433F	2017-07-10 01:03:00+03	53400.00
95434D	2017-08-08 13:28:00+03	68400.00
954383	2017-08-10 15:26:00+03	56000.00
9543F4	2017-08-07 23:43:00+03	66600.00
9543FA	2017-07-24 18:17:00+03	59400.00
954420	2017-08-02 13:56:00+03	24400.00
95442D	2017-07-09 09:44:00+03	135600.00
95443B	2017-08-12 13:40:00+03	103400.00
9544C6	2017-07-02 21:22:00+03	31200.00
95451B	2017-08-14 15:53:00+03	254900.00
95457B	2017-08-12 12:18:00+03	24700.00
9545B8	2017-08-09 23:06:00+03	40600.00
9545F1	2017-07-31 11:46:00+03	46300.00
954621	2017-07-26 10:57:00+03	20000.00
9546F5	2017-07-28 12:42:00+03	135600.00
9546F7	2017-08-08 08:47:00+03	115000.00
954721	2017-07-10 15:49:00+03	29400.00
954737	2017-08-04 02:48:00+03	36200.00
9547A8	2017-07-18 16:33:00+03	81500.00
9547DD	2017-07-22 22:34:00+03	56000.00
954813	2017-07-15 08:44:00+03	54000.00
954818	2017-08-02 00:54:00+03	136800.00
954829	2017-07-28 20:48:00+03	32800.00
954832	2017-08-05 22:33:00+03	46000.00
954886	2017-07-23 10:19:00+03	19800.00
954899	2017-07-06 05:21:00+03	119000.00
95489D	2017-07-04 23:49:00+03	68100.00
9548F3	2017-07-08 19:08:00+03	95200.00
954928	2017-07-06 14:51:00+03	192400.00
954933	2017-07-24 11:00:00+03	86300.00
954998	2017-07-24 01:45:00+03	47200.00
9549D4	2017-07-07 07:18:00+03	68800.00
954A8B	2017-07-23 22:10:00+03	25400.00
954AB3	2017-07-12 06:53:00+03	54500.00
954AF5	2017-08-08 20:05:00+03	133200.00
954B2D	2017-07-05 13:14:00+03	76300.00
954B4A	2017-07-10 10:59:00+03	12600.00
954B5C	2017-07-20 23:22:00+03	97900.00
954B6E	2017-07-20 18:15:00+03	26000.00
954B8A	2017-07-02 19:33:00+03	32800.00
954BC5	2017-08-15 01:17:00+03	119700.00
954BCB	2017-07-29 06:22:00+03	40100.00
954C70	2017-08-14 18:35:00+03	48800.00
954C7B	2017-06-28 05:05:00+03	51600.00
954D15	2017-07-13 21:02:00+03	79000.00
954D22	2017-08-07 15:37:00+03	41800.00
954D6B	2017-07-08 09:40:00+03	135300.00
954DE1	2017-07-03 15:31:00+03	119400.00
954E5D	2017-07-29 22:26:00+03	34000.00
954E72	2017-07-04 07:14:00+03	81700.00
954ED2	2017-07-23 17:23:00+03	31800.00
954EE7	2017-08-14 15:19:00+03	75800.00
954F18	2017-07-10 15:53:00+03	131100.00
954F32	2017-07-11 01:58:00+03	61800.00
954F48	2017-08-11 03:48:00+03	217300.00
954F56	2017-07-19 04:20:00+03	6000.00
955044	2017-08-11 01:40:00+03	89600.00
9550C0	2017-07-29 10:08:00+03	49200.00
9550C4	2017-07-05 08:35:00+03	62800.00
9550E2	2017-06-28 21:00:00+03	71400.00
9550F8	2017-08-09 14:25:00+03	133100.00
95512F	2017-08-11 00:49:00+03	123000.00
95513C	2017-07-10 04:15:00+03	44600.00
95515A	2017-07-28 09:10:00+03	20400.00
9551A2	2017-08-12 17:57:00+03	38200.00
955215	2017-07-14 00:41:00+03	32700.00
9552A3	2017-07-04 19:44:00+03	68100.00
9552B9	2017-07-12 21:50:00+03	40100.00
9553AA	2017-07-26 02:38:00+03	23200.00
9553AE	2017-08-14 07:08:00+03	89300.00
9553B9	2017-07-11 03:06:00+03	32800.00
9553BA	2017-06-29 02:22:00+03	291300.00
9553C0	2017-07-04 07:39:00+03	123000.00
9553CD	2017-07-17 05:24:00+03	59200.00
955402	2017-08-10 05:05:00+03	52300.00
955524	2017-08-15 05:37:00+03	12400.00
95552C	2017-08-12 13:37:00+03	24400.00
955586	2017-07-24 10:58:00+03	34400.00
95559F	2017-07-03 20:47:00+03	78300.00
95560E	2017-08-02 23:16:00+03	21200.00
955623	2017-08-10 01:07:00+03	17800.00
955674	2017-07-05 22:09:00+03	133500.00
955675	2017-07-30 06:31:00+03	14800.00
955682	2017-07-03 16:26:00+03	40400.00
9556AC	2017-08-06 13:27:00+03	18600.00
9556C2	2017-07-16 16:56:00+03	6300.00
9556F3	2017-08-04 04:32:00+03	49100.00
95572B	2017-07-15 01:04:00+03	270000.00
95573D	2017-07-09 22:12:00+03	532800.00
955754	2017-08-01 04:08:00+03	56600.00
9557A5	2017-07-19 22:10:00+03	92400.00
95581D	2017-07-06 08:40:00+03	167400.00
95585D	2017-07-16 18:07:00+03	53400.00
955899	2017-08-01 22:53:00+03	92800.00
955966	2017-08-10 08:34:00+03	64600.00
9559E0	2017-07-24 01:46:00+03	46700.00
955A11	2017-08-12 01:01:00+03	76600.00
955B2B	2017-07-23 01:23:00+03	131600.00
955B37	2017-07-24 22:24:00+03	40600.00
955B8D	2017-08-05 19:36:00+03	26000.00
955B8F	2017-07-31 13:11:00+03	21700.00
955C09	2017-08-03 18:48:00+03	56600.00
955C13	2017-08-13 07:13:00+03	265600.00
955CA9	2017-07-04 03:41:00+03	43200.00
955CAD	2017-07-02 17:40:00+03	25100.00
955D13	2017-07-25 21:40:00+03	56000.00
955D66	2017-07-21 03:54:00+03	190400.00
955D69	2017-07-05 20:00:00+03	55800.00
955DAA	2017-07-16 06:04:00+03	51200.00
955DD0	2017-08-11 01:02:00+03	115600.00
955DFA	2017-07-31 06:28:00+03	59800.00
955E80	2017-07-24 00:30:00+03	329800.00
955E93	2017-07-19 22:27:00+03	54800.00
955EE0	2017-07-31 13:53:00+03	68400.00
955EFE	2017-08-07 17:49:00+03	69000.00
955F0A	2017-07-13 02:34:00+03	26000.00
955F53	2017-08-09 11:42:00+03	34300.00
955F58	2017-07-07 08:25:00+03	86800.00
955F7A	2017-08-06 23:47:00+03	28800.00
955FA4	2017-07-19 20:51:00+03	24400.00
95601A	2017-06-24 20:03:00+03	198600.00
956042	2017-07-04 03:44:00+03	87100.00
9560B0	2017-07-24 03:46:00+03	36800.00
9560D7	2017-07-22 19:59:00+03	455500.00
9560FB	2017-08-05 12:32:00+03	132800.00
95610C	2017-07-11 22:35:00+03	27200.00
95612F	2017-07-27 23:45:00+03	18600.00
956141	2017-07-26 11:50:00+03	21600.00
9561E9	2017-08-15 11:05:00+03	534300.00
956263	2017-07-08 19:04:00+03	129700.00
95627F	2017-07-12 05:04:00+03	46000.00
95628A	2017-07-23 15:21:00+03	39500.00
95629F	2017-08-14 12:44:00+03	48800.00
9562AC	2017-06-28 02:27:00+03	111600.00
9562BC	2017-07-16 22:01:00+03	30400.00
956328	2017-07-31 12:57:00+03	311200.00
9563D8	2017-07-14 13:44:00+03	99200.00
9563E6	2017-07-11 19:48:00+03	266200.00
95641C	2017-08-07 14:16:00+03	52000.00
95645E	2017-07-26 19:58:00+03	168000.00
95647C	2017-08-08 08:47:00+03	165400.00
9564E0	2017-08-13 16:44:00+03	27800.00
9564E4	2017-07-04 15:23:00+03	67100.00
9564F2	2017-07-13 10:23:00+03	52400.00
95654C	2017-07-29 15:38:00+03	21800.00
9565BF	2017-07-03 04:53:00+03	56000.00
9565C0	2017-08-13 11:18:00+03	257600.00
9565F5	2017-07-28 10:34:00+03	176400.00
95665A	2017-08-05 12:19:00+03	40600.00
9566C6	2017-08-01 13:57:00+03	56600.00
9566D7	2017-07-02 12:16:00+03	102100.00
9566DE	2017-07-18 11:43:00+03	90000.00
95672F	2017-07-29 13:44:00+03	288600.00
9567AF	2017-07-24 09:48:00+03	50100.00
9567B4	2017-07-30 19:52:00+03	142300.00
9567D6	2017-08-06 02:46:00+03	86600.00
9567DC	2017-07-15 09:18:00+03	135600.00
95689A	2017-08-09 22:33:00+03	26700.00
9568DE	2017-06-26 05:01:00+03	47200.00
956923	2017-07-03 11:19:00+03	126200.00
956973	2017-07-29 00:09:00+03	136200.00
956975	2017-08-15 13:43:00+03	21400.00
956993	2017-08-03 09:50:00+03	132800.00
9569C2	2017-07-30 02:31:00+03	57500.00
956A0D	2017-08-12 17:44:00+03	44500.00
956A24	2017-08-01 04:17:00+03	36200.00
956A89	2017-07-06 13:32:00+03	131300.00
956B03	2017-07-31 10:06:00+03	46000.00
956B21	2017-08-02 06:50:00+03	29600.00
956BC9	2017-08-11 04:24:00+03	19800.00
956C45	2017-08-13 15:13:00+03	14000.00
956C73	2017-07-06 12:01:00+03	149000.00
956D84	2017-07-05 20:14:00+03	49800.00
956E04	2017-07-13 14:19:00+03	22000.00
956E30	2017-07-14 17:21:00+03	93500.00
956E5F	2017-08-14 16:55:00+03	403000.00
956E78	2017-08-13 02:33:00+03	38300.00
956E79	2017-07-05 20:24:00+03	142400.00
956E99	2017-07-09 00:25:00+03	47400.00
956E9D	2017-07-17 23:09:00+03	21400.00
956F09	2017-07-26 22:48:00+03	24400.00
956F41	2017-07-20 10:10:00+03	39800.00
956F80	2017-07-02 15:41:00+03	123900.00
956F83	2017-08-15 17:29:00+03	74900.00
956F84	2017-07-16 04:25:00+03	139500.00
956FA8	2017-07-06 15:11:00+03	101200.00
956FBD	2017-07-17 17:40:00+03	501200.00
956FD9	2017-08-06 23:58:00+03	35700.00
956FF2	2017-07-22 07:53:00+03	104000.00
956FFC	2017-07-09 23:08:00+03	100600.00
957025	2017-07-03 17:19:00+03	38800.00
957069	2017-08-03 17:07:00+03	72400.00
9570D7	2017-07-26 23:22:00+03	401000.00
9570E8	2017-07-21 14:31:00+03	27200.00
9570EB	2017-07-24 12:27:00+03	13800.00
9570F2	2017-07-06 22:57:00+03	184300.00
95710C	2017-06-27 13:49:00+03	94300.00
957112	2017-07-16 02:10:00+03	15100.00
957171	2017-07-02 10:40:00+03	26500.00
9571A5	2017-07-12 01:48:00+03	136000.00
9571FE	2017-07-24 00:31:00+03	258400.00
957273	2017-06-28 21:49:00+03	92800.00
9572E5	2017-08-02 13:22:00+03	84000.00
9572F2	2017-07-10 07:27:00+03	56000.00
957325	2017-07-20 17:57:00+03	141600.00
957379	2017-07-13 05:19:00+03	64700.00
9573F7	2017-07-13 01:05:00+03	123000.00
957451	2017-08-05 16:06:00+03	65600.00
95746F	2017-07-26 13:42:00+03	89200.00
9575BC	2017-07-19 04:09:00+03	20500.00
95760F	2017-06-30 15:10:00+03	6000.00
95763C	2017-08-11 02:41:00+03	36700.00
957640	2017-07-16 09:50:00+03	24800.00
957642	2017-08-15 14:44:00+03	56600.00
95765D	2017-08-07 05:07:00+03	234300.00
95768B	2017-07-20 15:44:00+03	159800.00
9576DF	2017-08-08 12:50:00+03	106400.00
9576FA	2017-08-10 11:44:00+03	28000.00
957700	2017-07-24 18:38:00+03	123000.00
957722	2017-07-21 23:25:00+03	10800.00
95773F	2017-06-27 07:21:00+03	160100.00
9577D4	2017-07-13 12:33:00+03	22400.00
957810	2017-08-10 22:16:00+03	131800.00
957846	2017-08-08 23:18:00+03	266400.00
95784E	2017-07-18 09:30:00+03	18500.00
95786F	2017-07-20 23:52:00+03	66600.00
95788F	2017-07-29 08:32:00+03	86500.00
9578A3	2017-07-09 00:22:00+03	39200.00
9578F9	2017-08-09 22:38:00+03	7400.00
957988	2017-07-15 14:33:00+03	122600.00
9579C3	2017-08-06 15:27:00+03	137900.00
957A24	2017-07-28 23:17:00+03	28800.00
957A6D	2017-08-12 11:58:00+03	45200.00
957A7C	2017-07-15 06:33:00+03	12400.00
957AAD	2017-07-06 16:54:00+03	77600.00
957B26	2017-07-07 04:03:00+03	399800.00
957B31	2017-07-09 21:25:00+03	23400.00
957B89	2017-08-02 08:14:00+03	31600.00
957C12	2017-07-15 22:06:00+03	149200.00
957C26	2017-08-08 09:41:00+03	62700.00
957C4E	2017-07-22 17:55:00+03	66800.00
957C5E	2017-08-06 01:50:00+03	117800.00
957C63	2017-07-11 12:30:00+03	118900.00
957C9A	2017-07-17 14:25:00+03	42800.00
957CCF	2017-07-05 01:49:00+03	151200.00
957D97	2017-08-12 01:22:00+03	29600.00
957DC6	2017-08-15 09:24:00+03	168000.00
957E0A	2017-08-01 18:04:00+03	73900.00
957E2C	2017-08-04 01:19:00+03	67900.00
957E71	2017-07-07 15:40:00+03	61800.00
957EFC	2017-07-25 15:54:00+03	28000.00
957FA2	2017-07-03 14:12:00+03	96300.00
957FC2	2017-08-07 22:17:00+03	25100.00
957FCD	2017-08-05 05:54:00+03	25600.00
957FFE	2017-07-23 08:32:00+03	42000.00
95801F	2017-07-20 20:27:00+03	13400.00
958030	2017-07-01 21:24:00+03	37500.00
958039	2017-07-10 11:43:00+03	75300.00
95803D	2017-07-29 16:11:00+03	173400.00
958049	2017-08-09 08:03:00+03	55800.00
9580C5	2017-08-09 06:35:00+03	8000.00
95810F	2017-08-06 23:35:00+03	169200.00
958137	2017-08-06 04:05:00+03	16800.00
9581FE	2017-08-14 21:31:00+03	58400.00
958340	2017-08-14 00:12:00+03	20200.00
9583AA	2017-07-07 08:52:00+03	28800.00
9583DE	2017-07-20 02:59:00+03	58200.00
9583E1	2017-08-05 08:00:00+03	23600.00
9583FF	2017-07-22 20:59:00+03	270000.00
958418	2017-07-19 10:52:00+03	131100.00
958489	2017-07-28 16:47:00+03	28000.00
9584B5	2017-07-07 22:25:00+03	35600.00
958597	2017-08-08 17:04:00+03	88000.00
95864B	2017-07-30 08:52:00+03	93000.00
9586B0	2017-08-04 00:09:00+03	66600.00
9586CA	2017-07-07 12:59:00+03	56600.00
9586F9	2017-07-04 16:41:00+03	579600.00
958709	2017-08-08 01:24:00+03	99200.00
9587FA	2017-08-13 13:06:00+03	94000.00
9588B4	2017-07-19 19:31:00+03	14000.00
958939	2017-08-06 05:57:00+03	35200.00
95897B	2017-07-17 10:29:00+03	39300.00
9589CE	2017-08-15 07:16:00+03	12600.00
958A22	2017-07-28 05:08:00+03	88100.00
958A4C	2017-07-01 13:21:00+03	384900.00
958A5F	2017-07-26 05:41:00+03	37200.00
958A98	2017-07-19 12:13:00+03	43800.00
958AD3	2017-07-04 00:40:00+03	168000.00
958B0B	2017-07-04 23:59:00+03	57700.00
958B3B	2017-07-26 03:37:00+03	12600.00
958B4F	2017-08-14 20:04:00+03	66600.00
958B76	2017-07-06 05:31:00+03	38800.00
958B8A	2017-07-23 17:35:00+03	66800.00
958B8C	2017-08-15 08:40:00+03	135400.00
958C5C	2017-07-02 19:57:00+03	137100.00
958C81	2017-08-10 11:21:00+03	60400.00
958CBE	2017-08-11 03:56:00+03	67200.00
958D6E	2017-07-19 11:36:00+03	92800.00
958D84	2017-07-07 14:45:00+03	271200.00
958DB7	2017-07-08 09:39:00+03	103400.00
958EF5	2017-07-09 01:22:00+03	41100.00
958EFA	2017-07-25 20:29:00+03	318200.00
958F22	2017-07-23 08:22:00+03	56100.00
958F38	2017-07-28 12:39:00+03	59900.00
958FA2	2017-08-06 03:49:00+03	27200.00
959004	2017-07-17 11:09:00+03	56000.00
959031	2017-07-18 08:51:00+03	18700.00
9590F9	2017-07-22 09:34:00+03	81900.00
959100	2017-08-07 01:20:00+03	108200.00
959107	2017-08-12 14:51:00+03	32800.00
959136	2017-08-13 18:33:00+03	12600.00
959140	2017-08-09 00:32:00+03	22000.00
95916B	2017-08-03 10:54:00+03	35600.00
959185	2017-07-25 12:59:00+03	27200.00
9591E4	2017-07-13 21:46:00+03	29400.00
959231	2017-07-13 08:13:00+03	114800.00
959253	2017-08-03 15:07:00+03	81300.00
9592AD	2017-08-01 10:52:00+03	272300.00
959330	2017-07-25 09:11:00+03	271200.00
959345	2017-08-05 16:03:00+03	31600.00
9594C0	2017-08-10 07:37:00+03	38500.00
9594D9	2017-07-05 17:47:00+03	15800.00
95959D	2017-07-10 16:48:00+03	28800.00
959611	2017-07-25 07:27:00+03	420900.00
959678	2017-08-05 20:41:00+03	47600.00
959686	2017-08-13 11:26:00+03	260300.00
959691	2017-08-08 06:53:00+03	52800.00
9596A2	2017-07-29 04:42:00+03	10800.00
9596A5	2017-07-16 15:42:00+03	54000.00
9596D6	2017-06-28 01:21:00+03	24400.00
9596D8	2017-07-28 16:33:00+03	136800.00
95971D	2017-07-21 03:37:00+03	40300.00
959729	2017-07-16 20:24:00+03	29400.00
95973C	2017-08-09 10:48:00+03	28800.00
959794	2017-07-14 15:59:00+03	39300.00
9597DD	2017-07-31 18:08:00+03	26200.00
95983D	2017-07-03 08:51:00+03	73500.00
95987F	2017-07-23 09:41:00+03	79800.00
9598B4	2017-08-08 00:55:00+03	395100.00
9598F5	2017-07-19 00:25:00+03	13400.00
95991A	2017-08-10 21:04:00+03	11600.00
95992D	2017-08-02 18:58:00+03	9800.00
959934	2017-07-13 05:19:00+03	56300.00
959945	2017-07-16 20:33:00+03	106800.00
959955	2017-07-11 08:15:00+03	12600.00
95996C	2017-07-06 03:22:00+03	58400.00
9599B3	2017-08-10 16:49:00+03	177200.00
9599EC	2017-07-08 19:04:00+03	129800.00
959A69	2017-07-19 17:02:00+03	146800.00
959A84	2017-08-13 16:58:00+03	40100.00
959AD1	2017-07-11 12:03:00+03	118800.00
959B26	2017-07-10 11:35:00+03	68100.00
959B72	2017-08-13 13:03:00+03	23200.00
959B84	2017-08-09 10:27:00+03	185800.00
959C21	2017-07-03 00:17:00+03	32800.00
959C69	2017-07-10 05:10:00+03	55800.00
959CAF	2017-07-21 01:20:00+03	46300.00
959CE3	2017-07-14 06:41:00+03	134700.00
959D21	2017-07-29 16:59:00+03	170700.00
959D6A	2017-08-12 00:15:00+03	38400.00
959E34	2017-08-13 09:21:00+03	13200.00
959E5F	2017-08-11 19:08:00+03	85200.00
959E78	2017-07-27 23:51:00+03	50600.00
959F20	2017-07-04 16:43:00+03	28000.00
959F80	2017-07-16 16:34:00+03	52000.00
959FDC	2017-07-22 18:00:00+03	58600.00
959FE8	2017-07-19 04:08:00+03	7400.00
95A004	2017-07-23 20:07:00+03	136800.00
95A028	2017-06-24 23:45:00+03	34000.00
95A05A	2017-07-22 12:04:00+03	332800.00
95A089	2017-07-08 20:45:00+03	6000.00
95A08D	2017-08-10 20:24:00+03	18600.00
95A0A4	2017-07-28 10:40:00+03	100600.00
95A0BB	2017-07-09 16:55:00+03	46000.00
95A129	2017-07-08 04:32:00+03	61800.00
95A135	2017-07-05 04:59:00+03	32200.00
95A15C	2017-07-07 20:44:00+03	38200.00
95A17B	2017-07-18 00:36:00+03	51900.00
95A19F	2017-07-29 06:35:00+03	22000.00
95A1E6	2017-08-15 07:34:00+03	46200.00
95A238	2017-08-01 11:55:00+03	28000.00
95A23F	2017-07-06 07:15:00+03	83600.00
95A268	2017-07-17 18:44:00+03	162600.00
95A27C	2017-07-12 00:58:00+03	26700.00
95A289	2017-08-14 16:11:00+03	51800.00
95A2A5	2017-07-18 03:29:00+03	56200.00
95A2CC	2017-07-12 06:59:00+03	26000.00
95A2E0	2017-07-02 15:12:00+03	16400.00
95A324	2017-07-11 03:00:00+03	36200.00
95A343	2017-08-03 09:32:00+03	93900.00
95A347	2017-07-28 18:33:00+03	47000.00
95A361	2017-07-25 23:18:00+03	28600.00
95A375	2017-07-10 19:23:00+03	20700.00
95A3B9	2017-08-12 15:04:00+03	40000.00
95A3C7	2017-07-06 12:20:00+03	42600.00
95A3DA	2017-07-28 12:37:00+03	24400.00
95A436	2017-08-09 00:30:00+03	27200.00
95A43B	2017-07-24 23:10:00+03	98400.00
95A463	2017-08-08 14:31:00+03	286100.00
95A4B2	2017-07-08 20:15:00+03	168000.00
95A4F5	2017-08-06 06:26:00+03	26200.00
95A4F9	2017-07-12 14:55:00+03	65900.00
95A65F	2017-07-23 20:32:00+03	26000.00
95A667	2017-08-08 01:57:00+03	135200.00
95A6EE	2017-08-01 11:57:00+03	12600.00
95A6F5	2017-07-03 08:21:00+03	199700.00
95A721	2017-07-03 11:59:00+03	124100.00
95A7C0	2017-06-30 03:35:00+03	29400.00
95A7D5	2017-07-28 22:26:00+03	59300.00
95A8CF	2017-08-06 11:44:00+03	52300.00
95A98C	2017-07-05 20:57:00+03	126300.00
95A9B8	2017-08-12 09:32:00+03	61500.00
95A9DC	2017-07-02 04:15:00+03	96800.00
95AA56	2017-07-20 04:26:00+03	135400.00
95AA6E	2017-07-21 18:16:00+03	664300.00
95AB45	2017-07-23 01:58:00+03	201100.00
95ABA2	2017-07-02 22:19:00+03	246000.00
95ABA4	2017-07-30 07:55:00+03	69500.00
95ABA7	2017-07-04 09:12:00+03	28000.00
95AC29	2017-08-01 00:32:00+03	131100.00
95AC4F	2017-07-19 01:40:00+03	66300.00
95AC85	2017-07-09 14:23:00+03	38400.00
95AC8F	2017-08-13 02:31:00+03	32700.00
95ACE4	2017-07-07 20:52:00+03	102100.00
95ACF5	2017-07-18 11:24:00+03	130200.00
95AD4B	2017-07-13 16:34:00+03	12600.00
95AD6D	2017-07-05 06:55:00+03	72400.00
95AD79	2017-08-11 00:59:00+03	155600.00
95ADB2	2017-07-19 16:12:00+03	73500.00
95ADB4	2017-07-08 21:05:00+03	119700.00
95AE21	2017-08-04 22:21:00+03	103800.00
95AE56	2017-08-01 02:11:00+03	23600.00
95AE5B	2017-07-30 01:26:00+03	50000.00
95AEBA	2017-08-06 19:00:00+03	121400.00
95AEF6	2017-08-01 01:14:00+03	56000.00
95AF0F	2017-07-28 02:30:00+03	56600.00
95AF34	2017-07-15 14:15:00+03	89600.00
95AF9B	2017-07-30 16:37:00+03	45200.00
95AF9F	2017-07-27 06:48:00+03	46200.00
95B051	2017-08-12 23:04:00+03	79600.00
95B056	2017-08-13 14:13:00+03	6000.00
95B06D	2017-07-02 18:21:00+03	21400.00
95B07E	2017-07-18 20:32:00+03	117200.00
95B089	2017-07-27 01:10:00+03	136700.00
95B108	2017-07-21 05:37:00+03	40800.00
95B109	2017-08-03 00:33:00+03	410200.00
95B126	2017-07-11 14:04:00+03	47200.00
95B193	2017-07-12 21:49:00+03	6800.00
95B1A3	2017-08-05 05:32:00+03	64400.00
95B1E4	2017-08-12 11:22:00+03	101400.00
95B241	2017-07-13 20:43:00+03	28800.00
95B279	2017-07-10 01:17:00+03	134200.00
95B29F	2017-08-02 04:50:00+03	75600.00
95B2AD	2017-08-01 09:17:00+03	23600.00
95B2F1	2017-08-13 12:59:00+03	123000.00
95B308	2017-08-14 23:07:00+03	136400.00
95B3D4	2017-07-02 05:48:00+03	44600.00
95B42E	2017-07-26 20:23:00+03	23600.00
95B462	2017-08-04 02:33:00+03	62800.00
95B4A7	2017-07-12 17:31:00+03	86600.00
95B4FF	2017-07-06 19:45:00+03	18400.00
95B520	2017-07-09 07:21:00+03	57600.00
95B523	2017-08-12 17:23:00+03	6000.00
95B544	2017-07-29 05:43:00+03	29600.00
95B55F	2017-07-23 08:49:00+03	246000.00
95B580	2017-07-07 07:21:00+03	135400.00
95B640	2017-08-14 11:37:00+03	27400.00
95B647	2017-07-20 21:37:00+03	160700.00
95B65E	2017-07-26 18:53:00+03	39500.00
95B6BD	2017-08-05 09:51:00+03	23200.00
95B6CB	2017-08-11 05:29:00+03	23600.00
95B70F	2017-07-17 01:18:00+03	56000.00
95B738	2017-07-06 19:04:00+03	15600.00
95B776	2017-07-07 22:52:00+03	20200.00
95B7B5	2017-07-25 13:22:00+03	14000.00
95B838	2017-07-09 06:36:00+03	21400.00
95B853	2017-08-01 05:57:00+03	16400.00
95B8DC	2017-07-04 19:55:00+03	30200.00
95B95B	2017-08-06 14:12:00+03	135600.00
95B9BC	2017-07-08 06:57:00+03	44800.00
95B9DE	2017-08-12 23:12:00+03	229600.00
95B9F7	2017-07-29 08:43:00+03	15400.00
95BA91	2017-07-17 03:53:00+03	29600.00
95BAE7	2017-07-30 19:11:00+03	23200.00
95BB24	2017-07-01 01:05:00+03	46300.00
95BB30	2017-07-12 18:43:00+03	67600.00
95BB40	2017-08-05 22:49:00+03	39400.00
95BB96	2017-08-10 05:23:00+03	47200.00
95BBA6	2017-07-11 04:29:00+03	39300.00
95BC1F	2017-08-14 12:01:00+03	101700.00
95BC40	2017-08-13 15:11:00+03	57600.00
95BC4A	2017-07-26 05:06:00+03	88000.00
95BCD0	2017-06-29 22:30:00+03	82200.00
95BCDF	2017-07-28 15:45:00+03	62600.00
95BCEB	2017-07-21 20:43:00+03	19000.00
95BDA0	2017-07-30 19:18:00+03	529800.00
95BDBD	2017-07-12 18:04:00+03	30700.00
95BDC3	2017-07-06 22:11:00+03	46400.00
95BE08	2017-07-07 21:35:00+03	12600.00
95BE26	2017-08-12 17:10:00+03	672600.00
95BE48	2017-07-13 11:54:00+03	21800.00
95BE5C	2017-08-03 15:39:00+03	26700.00
95BEB4	2017-08-01 21:55:00+03	154300.00
95BF19	2017-08-14 22:58:00+03	44000.00
95BF69	2017-08-15 12:16:00+03	40100.00
95BF88	2017-08-07 02:31:00+03	28800.00
95BFCD	2017-07-24 02:12:00+03	56100.00
95C033	2017-07-31 04:12:00+03	17800.00
95C08A	2017-07-08 05:39:00+03	70700.00
95C0D0	2017-07-11 16:40:00+03	85000.00
95C112	2017-07-21 16:21:00+03	46200.00
95C122	2017-08-08 14:36:00+03	163800.00
95C19B	2017-07-23 07:06:00+03	52000.00
95C204	2017-06-27 19:22:00+03	28000.00
95C23C	2017-08-05 11:53:00+03	55800.00
95C298	2017-07-26 22:56:00+03	92600.00
95C29C	2017-07-24 07:42:00+03	92900.00
95C2C4	2017-08-04 03:39:00+03	75200.00
95C33D	2017-08-04 22:25:00+03	20200.00
95C366	2017-07-17 16:32:00+03	101700.00
95C3F7	2017-07-08 01:31:00+03	23200.00
95C46D	2017-08-01 13:13:00+03	11600.00
95C49D	2017-08-11 10:40:00+03	56000.00
95C4A7	2017-07-20 18:08:00+03	70200.00
95C549	2017-08-09 02:19:00+03	60400.00
95C555	2017-07-05 18:53:00+03	99300.00
95C55B	2017-07-03 18:27:00+03	28800.00
95C583	2017-07-10 14:49:00+03	47000.00
95C591	2017-07-08 16:21:00+03	39500.00
95C5D8	2017-08-01 21:14:00+03	86300.00
95C5FE	2017-07-06 01:08:00+03	52000.00
95C63A	2017-08-11 01:13:00+03	104600.00
95C684	2017-08-12 01:59:00+03	81600.00
95C715	2017-08-10 03:51:00+03	40000.00
95C74F	2017-07-30 11:15:00+03	75300.00
95C782	2017-07-08 04:48:00+03	56000.00
95C7A3	2017-08-05 17:13:00+03	59200.00
95C7AA	2017-08-08 21:55:00+03	26000.00
95C7E9	2017-07-21 10:51:00+03	164700.00
95C850	2017-08-07 21:49:00+03	69100.00
95C88F	2017-07-25 03:27:00+03	28000.00
95C900	2017-07-28 00:57:00+03	92800.00
95C906	2017-07-22 22:01:00+03	394400.00
95C926	2017-08-09 18:46:00+03	28700.00
95C993	2017-07-18 20:10:00+03	12600.00
95C9C9	2017-07-15 02:53:00+03	152900.00
95C9F3	2017-07-09 20:16:00+03	26000.00
95CA06	2017-08-08 19:28:00+03	42700.00
95CA83	2017-07-19 15:04:00+03	363200.00
95CADF	2017-07-06 12:30:00+03	73500.00
95CB19	2017-07-20 00:22:00+03	36200.00
95CBE8	2017-08-12 07:17:00+03	175800.00
95CBFB	2017-08-07 15:47:00+03	46000.00
95CCA0	2017-07-22 05:47:00+03	10600.00
95CD14	2017-07-25 10:32:00+03	92900.00
95CDB2	2017-08-05 15:22:00+03	133900.00
95CEB2	2017-08-01 08:08:00+03	119600.00
95CEC7	2017-07-13 14:42:00+03	25600.00
95CEFB	2017-07-08 20:44:00+03	55800.00
95CF0A	2017-08-04 22:11:00+03	85000.00
95CF22	2017-08-04 17:36:00+03	75300.00
95CF7C	2017-08-11 18:17:00+03	133100.00
95CF91	2017-07-07 12:10:00+03	56000.00
95CFB9	2017-08-04 10:10:00+03	28000.00
95CFC2	2017-08-14 16:24:00+03	59800.00
95D031	2017-08-05 06:08:00+03	35300.00
95D046	2017-07-08 11:19:00+03	31400.00
95D050	2017-08-03 08:12:00+03	101200.00
95D052	2017-08-03 15:06:00+03	19600.00
95D05D	2017-07-24 06:08:00+03	55800.00
95D09C	2017-07-25 09:46:00+03	55800.00
95D0BF	2017-07-24 12:22:00+03	139500.00
95D10D	2017-07-02 07:09:00+03	40800.00
95D15C	2017-07-22 00:09:00+03	67700.00
95D163	2017-06-30 23:01:00+03	26800.00
95D167	2017-07-06 19:54:00+03	26000.00
95D1C9	2017-06-28 13:30:00+03	16400.00
95D1D0	2017-08-13 00:35:00+03	56100.00
95D26F	2017-08-11 04:11:00+03	123000.00
95D288	2017-07-09 00:24:00+03	29200.00
95D33E	2017-07-15 17:05:00+03	94000.00
95D37A	2017-08-02 19:26:00+03	8200.00
95D3B6	2017-07-24 00:49:00+03	37900.00
95D3C2	2017-08-09 08:58:00+03	23200.00
95D3FC	2017-07-17 08:32:00+03	61500.00
95D41B	2017-07-03 10:06:00+03	258300.00
95D42F	2017-07-14 16:32:00+03	492000.00
95D47C	2017-07-07 06:42:00+03	265700.00
95D486	2017-08-15 05:23:00+03	28000.00
95D4B1	2017-07-29 07:08:00+03	65500.00
95D535	2017-07-15 02:54:00+03	104100.00
95D562	2017-08-01 07:55:00+03	86200.00
95D63C	2017-07-11 04:09:00+03	81700.00
95D70A	2017-08-03 20:52:00+03	32800.00
95D75D	2017-07-17 23:54:00+03	33100.00
95D810	2017-07-26 10:28:00+03	65900.00
95D876	2017-08-09 02:46:00+03	103600.00
95D88E	2017-08-06 18:11:00+03	193300.00
95D8DF	2017-08-01 15:31:00+03	68200.00
95D90F	2017-07-31 04:02:00+03	91300.00
95D96D	2017-08-04 13:52:00+03	306600.00
95DAD6	2017-07-10 20:47:00+03	8600.00
95DB08	2017-07-05 20:57:00+03	58000.00
95DC27	2017-08-05 11:57:00+03	58800.00
95DD44	2017-07-26 18:13:00+03	28800.00
95DD5B	2017-07-19 01:55:00+03	93000.00
95DD83	2017-08-07 11:49:00+03	44500.00
95DE52	2017-07-21 19:36:00+03	67800.00
95DE6F	2017-08-06 01:56:00+03	125000.00
95DE7F	2017-07-22 13:04:00+03	56000.00
95DF3F	2017-08-12 23:37:00+03	56100.00
95DF99	2017-08-12 11:47:00+03	117200.00
95DFC4	2017-07-05 06:34:00+03	25400.00
95E03F	2017-07-15 22:24:00+03	62900.00
95E055	2017-08-04 01:00:00+03	8000.00
95E09C	2017-08-05 20:52:00+03	11800.00
95E0C8	2017-08-10 18:00:00+03	40800.00
95E108	2017-07-05 13:02:00+03	40800.00
95E140	2017-07-26 16:06:00+03	134400.00
95E151	2017-07-31 09:26:00+03	23600.00
95E19F	2017-07-21 08:58:00+03	23400.00
95E1C0	2017-08-01 13:00:00+03	60400.00
95E2D2	2017-08-01 02:17:00+03	48800.00
95E2E4	2017-08-09 20:56:00+03	6700.00
95E314	2017-07-09 14:25:00+03	67200.00
95E323	2017-07-18 16:55:00+03	13400.00
95E33A	2017-08-13 20:53:00+03	49100.00
95E36E	2017-08-11 09:54:00+03	87200.00
95E3AB	2017-07-03 09:41:00+03	134200.00
95E3AC	2017-07-17 08:05:00+03	29600.00
95E403	2017-08-12 21:08:00+03	38600.00
95E41C	2017-07-27 16:40:00+03	117600.00
95E423	2017-08-07 10:14:00+03	67700.00
95E428	2017-08-02 08:39:00+03	28000.00
95E45A	2017-07-12 05:43:00+03	59800.00
95E4BF	2017-07-23 09:36:00+03	14300.00
95E4ED	2017-07-09 00:27:00+03	28700.00
95E50D	2017-07-27 08:56:00+03	248300.00
95E583	2017-07-28 12:21:00+03	202300.00
95E5FC	2017-08-02 20:54:00+03	86600.00
95E6C9	2017-07-21 21:30:00+03	55800.00
95E70C	2017-08-14 10:47:00+03	28000.00
95E71C	2017-07-05 11:26:00+03	399600.00
95E743	2017-07-19 12:05:00+03	237400.00
95E77C	2017-07-23 19:52:00+03	87200.00
95E7AC	2017-08-14 12:46:00+03	68800.00
95E7EA	2017-06-30 19:53:00+03	44000.00
95E822	2017-07-17 19:15:00+03	133000.00
95E85A	2017-07-31 08:54:00+03	56900.00
95E8B0	2017-07-26 07:39:00+03	12400.00
95E914	2017-07-26 05:04:00+03	68800.00
95E92A	2017-07-28 23:06:00+03	22000.00
95E938	2017-08-11 16:32:00+03	103500.00
95EA04	2017-07-27 19:24:00+03	8000.00
95EA1D	2017-07-06 03:01:00+03	393800.00
95EA4A	2017-07-23 07:57:00+03	48800.00
95EA58	2017-08-13 16:09:00+03	25200.00
95EAFE	2017-08-15 00:18:00+03	51900.00
95EB4A	2017-08-04 14:27:00+03	19600.00
95EB78	2017-07-25 03:46:00+03	40800.00
95EB89	2017-08-02 08:07:00+03	61100.00
95EBA3	2017-07-28 17:29:00+03	56000.00
95EC11	2017-08-07 21:30:00+03	58400.00
95EC48	2017-07-14 16:24:00+03	92800.00
95EC63	2017-08-11 21:58:00+03	46900.00
95EC6E	2017-07-02 02:21:00+03	57100.00
95ED1B	2017-07-21 13:39:00+03	43600.00
95ED67	2017-08-14 15:42:00+03	28800.00
95ED9B	2017-07-09 17:26:00+03	135400.00
95EDB1	2017-08-07 01:30:00+03	64700.00
95EE22	2017-07-30 07:25:00+03	26300.00
95EE32	2017-07-27 09:02:00+03	14400.00
95EE55	2017-07-12 21:50:00+03	57600.00
95EE99	2017-07-19 00:51:00+03	72400.00
95EEAB	2017-07-22 20:26:00+03	398500.00
95EECD	2017-08-15 09:49:00+03	23400.00
95EEE2	2017-08-15 01:02:00+03	36400.00
95EF2D	2017-07-19 03:11:00+03	22100.00
95EF4D	2017-07-03 07:34:00+03	137600.00
95EF77	2017-07-13 08:38:00+03	28000.00
95EF97	2017-07-13 16:10:00+03	23600.00
95EFBF	2017-07-30 02:40:00+03	37900.00
95EFF6	2017-07-26 03:43:00+03	7400.00
95F008	2017-07-04 07:42:00+03	46400.00
95F012	2017-07-27 17:52:00+03	67800.00
95F01B	2017-08-05 08:18:00+03	94700.00
95F049	2017-07-18 17:11:00+03	263100.00
95F076	2017-08-01 22:41:00+03	135600.00
95F08D	2017-08-11 04:04:00+03	49600.00
95F0C7	2017-08-03 09:37:00+03	24400.00
95F0CC	2017-07-18 05:15:00+03	68800.00
95F138	2017-07-15 02:39:00+03	34000.00
95F162	2017-07-06 03:06:00+03	270500.00
95F1E2	2017-07-02 20:58:00+03	31400.00
95F1F3	2017-07-15 22:48:00+03	30000.00
95F210	2017-07-14 02:46:00+03	13600.00
95F23B	2017-07-14 15:25:00+03	43600.00
95F291	2017-07-06 23:38:00+03	32700.00
95F29D	2017-07-06 19:35:00+03	29800.00
95F2FA	2017-08-05 17:59:00+03	260600.00
95F330	2017-08-11 20:19:00+03	13400.00
95F364	2017-07-15 07:02:00+03	47000.00
95F371	2017-07-21 17:13:00+03	199700.00
95F39F	2017-08-11 03:13:00+03	25400.00
95F3AD	2017-07-02 02:32:00+03	62600.00
95F3C2	2017-07-17 19:08:00+03	66600.00
95F47F	2017-07-26 23:26:00+03	67600.00
95F4FC	2017-08-03 16:25:00+03	12200.00
95F4FF	2017-07-13 08:12:00+03	38400.00
95F50E	2017-08-07 09:27:00+03	23200.00
95F555	2017-08-02 13:23:00+03	41800.00
95F55D	2017-08-01 02:41:00+03	150000.00
95F56F	2017-08-06 15:35:00+03	43000.00
95F5DE	2017-07-29 22:09:00+03	26600.00
95F5EF	2017-08-14 18:33:00+03	10600.00
95F616	2017-08-12 02:05:00+03	32700.00
95F72E	2017-07-10 15:19:00+03	14400.00
95F7B8	2017-08-12 06:09:00+03	20400.00
95F7F0	2017-08-04 03:29:00+03	44000.00
95F828	2017-08-12 01:16:00+03	266300.00
95F8AB	2017-07-21 13:51:00+03	92800.00
95F90F	2017-08-14 06:57:00+03	25200.00
95F939	2017-06-30 15:29:00+03	31200.00
95F960	2017-07-11 13:15:00+03	74400.00
95F984	2017-07-19 17:49:00+03	10800.00
95F9B7	2017-08-05 16:33:00+03	66000.00
95F9B9	2017-08-12 11:43:00+03	46400.00
95F9D1	2017-07-29 01:34:00+03	46400.00
95F9DF	2017-08-03 22:33:00+03	14800.00
95FA13	2017-07-04 13:43:00+03	28000.00
95FA38	2017-07-03 11:41:00+03	106400.00
95FAC3	2017-08-09 04:44:00+03	38400.00
95FB5C	2017-07-03 08:22:00+03	66200.00
95FB91	2017-08-15 10:16:00+03	83000.00
95FBC4	2017-07-23 18:25:00+03	103800.00
95FC0E	2017-08-09 14:36:00+03	114800.00
95FC21	2017-07-20 21:24:00+03	27800.00
95FCC7	2017-08-03 17:31:00+03	26000.00
95FD41	2017-07-02 06:52:00+03	46400.00
95FD47	2017-07-23 09:16:00+03	12000.00
95FD52	2017-08-03 06:33:00+03	151200.00
95FD5B	2017-07-16 07:03:00+03	116700.00
95FD5C	2017-07-23 05:48:00+03	23200.00
95FD6B	2017-07-12 20:47:00+03	152400.00
95FDAB	2017-07-09 00:25:00+03	41600.00
95FDFF	2017-07-02 14:39:00+03	47500.00
95FE04	2017-07-25 09:22:00+03	20200.00
95FE0F	2017-07-20 02:34:00+03	46000.00
95FEAC	2017-07-25 00:59:00+03	127300.00
95FEAF	2017-07-22 14:43:00+03	270000.00
95FF14	2017-08-10 01:07:00+03	60400.00
95FF69	2017-07-13 13:36:00+03	56000.00
95FF8A	2017-07-27 06:32:00+03	85000.00
95FFE9	2017-07-11 04:08:00+03	57200.00
96003C	2017-07-26 22:00:00+03	28000.00
9600CD	2017-08-13 16:19:00+03	62800.00
9600D7	2017-08-05 09:58:00+03	23600.00
9600E5	2017-07-03 23:37:00+03	38400.00
960167	2017-08-15 15:39:00+03	18600.00
9601D5	2017-08-06 04:10:00+03	43600.00
960260	2017-08-04 11:54:00+03	81800.00
960278	2017-07-07 12:30:00+03	133200.00
960295	2017-07-21 19:02:00+03	154000.00
9602BE	2017-08-13 20:19:00+03	57500.00
960333	2017-06-27 07:14:00+03	23200.00
960356	2017-07-18 02:43:00+03	27900.00
9603D3	2017-07-22 07:35:00+03	77000.00
9603E5	2017-07-12 03:49:00+03	66600.00
960400	2017-08-06 06:20:00+03	16400.00
96049E	2017-07-28 04:39:00+03	105100.00
96051A	2017-07-02 21:19:00+03	137600.00
96056F	2017-07-20 10:28:00+03	86600.00
9605F8	2017-08-08 18:23:00+03	24400.00
960610	2017-07-06 16:47:00+03	28000.00
960618	2017-07-21 15:56:00+03	18000.00
96061E	2017-07-12 02:53:00+03	103200.00
9606C3	2017-07-09 20:19:00+03	61800.00
9606CB	2017-07-11 14:15:00+03	24200.00
96072F	2017-08-07 14:24:00+03	13000.00
960736	2017-08-04 09:46:00+03	95200.00
96077E	2017-08-13 14:01:00+03	143500.00
96079B	2017-08-01 08:11:00+03	54800.00
96082E	2017-07-17 09:06:00+03	58200.00
960843	2017-07-12 04:41:00+03	136200.00
960846	2017-07-22 18:46:00+03	13400.00
9608AD	2017-07-22 21:04:00+03	82100.00
9608F9	2017-07-22 23:30:00+03	102600.00
96092B	2017-08-05 12:32:00+03	20400.00
960939	2017-08-13 09:57:00+03	28200.00
960978	2017-07-14 18:32:00+03	138900.00
960986	2017-07-08 17:08:00+03	69500.00
96098B	2017-08-14 11:16:00+03	163200.00
9609AA	2017-07-16 23:41:00+03	129200.00
9609C5	2017-08-04 00:18:00+03	288600.00
960A17	2017-07-09 00:10:00+03	115400.00
960A2D	2017-08-01 08:50:00+03	101200.00
960A4C	2017-08-01 03:48:00+03	46200.00
960A66	2017-08-15 11:30:00+03	11600.00
960B51	2017-07-11 21:25:00+03	23400.00
960BD3	2017-07-09 17:34:00+03	75300.00
960C2C	2017-07-23 13:10:00+03	24400.00
960C45	2017-08-15 16:12:00+03	57500.00
960C98	2017-08-15 14:18:00+03	53500.00
960CA2	2017-07-08 15:51:00+03	86300.00
960CC9	2017-08-14 15:45:00+03	40800.00
960D6A	2017-08-15 05:19:00+03	99900.00
960DD9	2017-07-28 10:24:00+03	99200.00
960DFE	2017-07-20 05:14:00+03	122600.00
960E3C	2017-07-16 23:48:00+03	406700.00
960E7B	2017-07-18 11:35:00+03	8600.00
960F05	2017-07-25 12:56:00+03	21800.00
960FC8	2017-08-06 07:48:00+03	36200.00
960FFA	2017-07-09 12:11:00+03	240600.00
96102D	2017-08-05 19:21:00+03	27400.00
961080	2017-07-23 21:02:00+03	26800.00
9610C8	2017-08-11 06:49:00+03	34000.00
9610F5	2017-07-24 15:32:00+03	28800.00
9610FB	2017-08-06 17:03:00+03	130400.00
961143	2017-07-28 20:14:00+03	25400.00
9612AA	2017-07-24 18:07:00+03	279200.00
961316	2017-08-14 13:57:00+03	28800.00
961395	2017-07-30 08:00:00+03	52300.00
9613CA	2017-07-07 18:28:00+03	37700.00
9613D4	2017-07-03 06:14:00+03	24400.00
961457	2017-06-30 01:34:00+03	12600.00
9614D2	2017-07-06 13:57:00+03	50000.00
961521	2017-07-15 11:20:00+03	56000.00
96152F	2017-07-10 22:08:00+03	20200.00
961531	2017-07-29 17:52:00+03	88200.00
961532	2017-07-28 15:00:00+03	85000.00
961600	2017-08-04 23:45:00+03	59200.00
96162A	2017-07-27 04:17:00+03	11700.00
96165B	2017-07-25 07:35:00+03	444600.00
96165F	2017-06-30 05:55:00+03	57300.00
96169C	2017-08-12 03:28:00+03	39600.00
9616A2	2017-08-07 02:56:00+03	52700.00
9616F4	2017-07-25 04:37:00+03	56000.00
961705	2017-08-07 03:31:00+03	56900.00
96172B	2017-07-05 08:11:00+03	70500.00
961740	2017-07-08 10:22:00+03	62000.00
96177B	2017-07-07 03:56:00+03	23600.00
96180E	2017-07-07 06:58:00+03	68300.00
961815	2017-07-06 02:33:00+03	51600.00
96187B	2017-07-31 10:02:00+03	36200.00
9618B9	2017-08-01 04:42:00+03	22000.00
96190C	2017-07-02 20:05:00+03	62600.00
9619BE	2017-08-06 04:53:00+03	71900.00
9619C9	2017-08-05 16:12:00+03	67900.00
961A5C	2017-07-01 00:48:00+03	92000.00
961A61	2017-07-15 01:39:00+03	189100.00
961A6F	2017-07-28 02:15:00+03	83000.00
961A78	2017-07-23 08:02:00+03	24200.00
961A7C	2017-07-06 16:29:00+03	130300.00
961AD1	2017-07-24 18:08:00+03	172100.00
961B2A	2017-07-19 07:11:00+03	29600.00
961B52	2017-08-09 22:20:00+03	43600.00
961BB7	2017-08-11 21:35:00+03	56600.00
961C79	2017-07-28 12:34:00+03	6700.00
961CD0	2017-08-14 07:50:00+03	532800.00
961D3F	2017-07-22 15:06:00+03	16400.00
961D4D	2017-07-26 13:59:00+03	40100.00
961DD8	2017-06-30 00:24:00+03	15000.00
961DF1	2017-07-17 08:43:00+03	16400.00
961E15	2017-08-02 03:04:00+03	40000.00
961ED3	2017-07-10 11:28:00+03	10600.00
961EE1	2017-07-24 05:10:00+03	6800.00
961EE7	2017-07-08 16:56:00+03	146600.00
961EF8	2017-07-17 05:43:00+03	89600.00
961EFD	2017-07-01 13:10:00+03	137700.00
961FA7	2017-07-15 00:27:00+03	212700.00
961FBB	2017-06-28 23:41:00+03	25600.00
961FC6	2017-07-26 08:21:00+03	62600.00
961FD0	2017-08-01 14:13:00+03	154800.00
961FEC	2017-08-09 23:20:00+03	121400.00
962007	2017-07-14 15:34:00+03	28000.00
962042	2017-07-26 18:23:00+03	6800.00
96209F	2017-07-12 01:26:00+03	30000.00
9620A0	2017-07-27 02:17:00+03	114200.00
9620A6	2017-07-08 22:05:00+03	73600.00
9620B2	2017-07-11 04:39:00+03	44100.00
9620BA	2017-07-09 09:18:00+03	31900.00
9620CB	2017-08-02 05:23:00+03	36200.00
962123	2017-07-31 12:32:00+03	276200.00
962189	2017-08-06 12:11:00+03	33300.00
9622A3	2017-07-13 08:12:00+03	92400.00
9622F3	2017-08-10 06:08:00+03	41200.00
962335	2017-08-15 08:28:00+03	155600.00
962392	2017-07-09 14:16:00+03	88100.00
9623A6	2017-07-12 17:34:00+03	130100.00
962489	2017-07-18 21:52:00+03	25400.00
9624B6	2017-07-17 19:06:00+03	89700.00
96253B	2017-07-12 07:36:00+03	24700.00
962592	2017-07-12 20:37:00+03	73300.00
962594	2017-06-29 12:18:00+03	123000.00
9625DE	2017-07-31 22:45:00+03	13400.00
96260D	2017-08-13 21:05:00+03	7400.00
962670	2017-07-30 03:06:00+03	55800.00
9626A4	2017-07-25 06:09:00+03	79600.00
96271E	2017-07-04 04:17:00+03	111600.00
96274B	2017-07-19 17:51:00+03	39500.00
9627B8	2017-07-28 09:07:00+03	305400.00
9627D5	2017-06-30 15:42:00+03	31200.00
9627E2	2017-07-24 16:08:00+03	46900.00
96280F	2017-07-31 00:55:00+03	189800.00
962860	2017-08-11 05:21:00+03	53700.00
9628D9	2017-08-05 06:29:00+03	26800.00
9628DB	2017-08-02 13:27:00+03	56000.00
962976	2017-07-26 01:48:00+03	62000.00
962989	2017-07-25 12:19:00+03	19600.00
9629C8	2017-07-06 01:07:00+03	109400.00
9629DB	2017-08-09 09:01:00+03	77900.00
962A35	2017-08-14 01:04:00+03	166900.00
962A6B	2017-07-12 10:30:00+03	6800.00
962A9A	2017-07-07 14:53:00+03	128800.00
962AD2	2017-06-26 07:11:00+03	23600.00
962B53	2017-08-15 09:27:00+03	92400.00
962BF3	2017-07-22 02:29:00+03	39800.00
962C0A	2017-07-11 09:14:00+03	95300.00
962C21	2017-08-04 15:13:00+03	25600.00
962C6B	2017-07-27 10:19:00+03	49600.00
962C93	2017-07-26 13:10:00+03	23200.00
962CC2	2017-08-14 21:41:00+03	11600.00
962D18	2017-07-25 15:36:00+03	11000.00
962D4D	2017-08-07 15:09:00+03	59000.00
962D5B	2017-07-30 10:55:00+03	73300.00
962D6D	2017-07-15 14:19:00+03	59800.00
962D8B	2017-07-11 14:43:00+03	56000.00
962DF8	2017-07-05 08:32:00+03	60800.00
962E46	2017-07-05 20:43:00+03	191000.00
962E8E	2017-08-03 16:29:00+03	28000.00
962E99	2017-07-04 05:29:00+03	383000.00
962EC2	2017-08-12 19:39:00+03	115900.00
962F29	2017-07-03 19:59:00+03	114700.00
962F31	2017-08-05 01:01:00+03	24400.00
962F54	2017-07-05 03:49:00+03	68900.00
962FED	2017-07-23 17:36:00+03	70800.00
962FF0	2017-07-21 07:18:00+03	48800.00
963029	2017-08-11 20:38:00+03	89700.00
9630F0	2017-08-09 07:27:00+03	140900.00
9631AC	2017-07-17 13:20:00+03	266400.00
9631C1	2017-07-31 02:07:00+03	132500.00
9631E6	2017-07-19 14:54:00+03	85000.00
9631FF	2017-08-04 23:59:00+03	51600.00
963200	2017-08-03 23:45:00+03	54800.00
96320F	2017-07-25 22:47:00+03	62800.00
96324A	2017-08-09 17:47:00+03	27200.00
963263	2017-08-05 10:54:00+03	46000.00
9632D7	2017-08-08 05:41:00+03	28000.00
96334D	2017-07-14 17:33:00+03	28000.00
9633D8	2017-07-13 14:13:00+03	24800.00
963401	2017-07-08 10:58:00+03	20100.00
963461	2017-07-10 11:35:00+03	40800.00
963470	2017-07-06 16:37:00+03	192100.00
963480	2017-07-21 01:46:00+03	61900.00
9634A5	2017-07-07 03:08:00+03	66600.00
9634AD	2017-07-14 10:18:00+03	38200.00
9634BF	2017-07-30 14:37:00+03	28600.00
9634E9	2017-08-01 09:40:00+03	58800.00
963557	2017-08-11 06:11:00+03	106400.00
96359F	2017-06-25 20:56:00+03	111600.00
9635CC	2017-07-09 21:14:00+03	27200.00
9635E8	2017-08-09 18:19:00+03	386200.00
9635EC	2017-07-11 00:08:00+03	112300.00
963671	2017-07-27 17:25:00+03	135600.00
9636D4	2017-08-13 14:42:00+03	47400.00
963728	2017-07-31 17:32:00+03	131100.00
963767	2017-08-04 05:10:00+03	26000.00
96378A	2017-07-07 18:24:00+03	34000.00
963796	2017-06-28 09:15:00+03	196800.00
96379A	2017-07-27 08:30:00+03	54500.00
963828	2017-07-08 03:22:00+03	9300.00
96384D	2017-07-19 03:26:00+03	42800.00
963919	2017-08-09 19:56:00+03	41200.00
96391B	2017-07-27 22:59:00+03	22900.00
9639E5	2017-07-08 05:03:00+03	405000.00
963A09	2017-08-14 04:10:00+03	133200.00
963A15	2017-07-20 11:06:00+03	21000.00
963A5F	2017-07-11 03:55:00+03	72000.00
963A75	2017-06-28 17:07:00+03	56600.00
963A80	2017-07-28 06:32:00+03	51600.00
963ABB	2017-08-15 10:34:00+03	200800.00
963B1F	2017-07-09 08:53:00+03	18800.00
963B23	2017-08-03 13:46:00+03	161300.00
963B90	2017-07-05 21:14:00+03	266400.00
963BA6	2017-08-03 19:16:00+03	62800.00
963BE8	2017-07-17 08:53:00+03	135400.00
963BF0	2017-07-27 21:12:00+03	19600.00
963C34	2017-08-02 23:31:00+03	23600.00
963CC5	2017-07-14 17:47:00+03	32800.00
963D70	2017-07-06 11:39:00+03	112000.00
963D74	2017-08-13 14:55:00+03	54500.00
963DEA	2017-07-24 17:11:00+03	56300.00
963E3E	2017-07-20 02:18:00+03	125000.00
963E66	2017-08-02 08:34:00+03	91800.00
963EDB	2017-07-02 15:23:00+03	65900.00
963F35	2017-08-02 12:51:00+03	92400.00
963F4F	2017-07-18 01:52:00+03	41200.00
963F8E	2017-07-13 05:35:00+03	67600.00
963F96	2017-08-05 22:42:00+03	369000.00
963FA3	2017-07-13 15:06:00+03	24400.00
964033	2017-07-19 12:06:00+03	26800.00
96406E	2017-07-13 18:50:00+03	61800.00
9640A7	2017-07-25 20:15:00+03	30200.00
9640E3	2017-07-24 22:02:00+03	20800.00
96412F	2017-07-23 13:29:00+03	131900.00
964138	2017-08-06 19:51:00+03	82000.00
96417A	2017-07-17 10:50:00+03	52000.00
964186	2017-07-16 12:07:00+03	27200.00
96419F	2017-08-07 16:16:00+03	25600.00
9641D2	2017-07-30 15:01:00+03	260700.00
964206	2017-07-29 21:19:00+03	10800.00
964268	2017-07-26 22:48:00+03	46200.00
964345	2017-07-12 21:48:00+03	37900.00
9643BA	2017-07-28 12:29:00+03	114600.00
9643C9	2017-06-30 01:23:00+03	33500.00
96444B	2017-07-30 09:43:00+03	56000.00
964465	2017-08-13 09:56:00+03	23800.00
9644D3	2017-06-30 04:19:00+03	32200.00
9644F3	2017-07-16 13:00:00+03	20200.00
964515	2017-08-15 10:20:00+03	219600.00
964532	2017-08-06 15:22:00+03	46000.00
964561	2017-07-01 10:29:00+03	20200.00
964567	2017-07-07 08:44:00+03	70700.00
964597	2017-07-15 22:41:00+03	51800.00
9645D1	2017-07-16 05:58:00+03	54000.00
9645E1	2017-08-09 02:22:00+03	167200.00
96466B	2017-08-14 12:05:00+03	81700.00
9646A6	2017-07-15 10:49:00+03	84500.00
9646FC	2017-07-13 21:56:00+03	19600.00
964729	2017-07-17 03:24:00+03	89200.00
9647ED	2017-06-27 06:08:00+03	48500.00
964806	2017-07-22 11:17:00+03	187800.00
96489F	2017-08-14 18:35:00+03	28800.00
9648C0	2017-07-07 09:33:00+03	23200.00
9648EF	2017-08-02 07:07:00+03	31600.00
964912	2017-08-14 11:40:00+03	49300.00
964930	2017-07-16 06:38:00+03	69000.00
964995	2017-08-10 19:42:00+03	66800.00
9649B7	2017-07-29 20:53:00+03	32800.00
9649CA	2017-07-05 21:58:00+03	46900.00
9649F3	2017-08-14 20:01:00+03	248400.00
9649FC	2017-08-13 23:27:00+03	67000.00
964A13	2017-07-12 04:24:00+03	34200.00
964A4E	2017-08-03 13:26:00+03	106900.00
964BDC	2017-08-14 06:08:00+03	59400.00
964C16	2017-07-24 09:19:00+03	46200.00
964C1F	2017-07-10 20:00:00+03	23200.00
964C6E	2017-07-29 18:55:00+03	14800.00
964CA8	2017-07-16 22:19:00+03	131100.00
964CAD	2017-07-27 17:20:00+03	42100.00
964CDE	2017-07-14 11:28:00+03	246000.00
964D06	2017-07-10 21:49:00+03	28000.00
964D21	2017-07-19 17:30:00+03	240600.00
964D39	2017-07-05 22:14:00+03	386300.00
964D4F	2017-07-12 01:45:00+03	15700.00
964DB5	2017-07-12 19:08:00+03	8800.00
964DB7	2017-08-07 18:17:00+03	30900.00
964DEC	2017-08-04 11:19:00+03	33200.00
964E1F	2017-08-15 00:52:00+03	56600.00
964E72	2017-07-23 18:05:00+03	11300.00
964F07	2017-08-15 03:28:00+03	73600.00
964F14	2017-07-01 18:16:00+03	70400.00
964F36	2017-07-14 02:42:00+03	182300.00
964FB0	2017-08-14 14:55:00+03	18600.00
964FB4	2017-07-27 15:27:00+03	47400.00
965031	2017-07-06 02:30:00+03	62000.00
9650FD	2017-07-19 22:30:00+03	234000.00
965124	2017-08-04 23:46:00+03	117600.00
9651B0	2017-07-21 14:00:00+03	64600.00
9651C2	2017-07-10 22:33:00+03	393800.00
9651FB	2017-08-03 17:57:00+03	96300.00
965200	2017-07-03 06:23:00+03	105100.00
965253	2017-08-12 07:35:00+03	56000.00
96527E	2017-08-13 02:30:00+03	34600.00
965299	2017-08-14 16:38:00+03	25200.00
9652BE	2017-07-22 19:24:00+03	77200.00
96533F	2017-07-02 02:53:00+03	54800.00
96534B	2017-08-13 18:55:00+03	23200.00
96535F	2017-07-24 21:01:00+03	248300.00
965361	2017-06-27 05:18:00+03	131100.00
9653E4	2017-08-05 00:48:00+03	8400.00
965430	2017-07-20 02:26:00+03	49100.00
9654DD	2017-07-19 18:19:00+03	266400.00
9654FC	2017-07-21 02:48:00+03	51600.00
9654FE	2017-08-07 21:05:00+03	8200.00
965548	2017-07-28 20:07:00+03	139300.00
965558	2017-07-06 15:44:00+03	46400.00
96556C	2017-08-15 00:00:00+03	62600.00
965574	2017-08-12 15:31:00+03	111600.00
9655F1	2017-07-23 12:02:00+03	119500.00
9655F6	2017-07-15 15:52:00+03	37900.00
965606	2017-07-15 22:58:00+03	52100.00
96562E	2017-08-12 08:55:00+03	56000.00
965645	2017-07-01 02:41:00+03	7400.00
9656B4	2017-07-13 21:45:00+03	25600.00
9656E8	2017-08-11 09:23:00+03	31600.00
9656EC	2017-08-14 20:45:00+03	62200.00
965739	2017-07-30 08:01:00+03	28000.00
9657A0	2017-07-17 10:53:00+03	6000.00
9657A1	2017-07-16 18:06:00+03	89200.00
9657AD	2017-07-14 03:44:00+03	65900.00
9657BC	2017-08-14 17:19:00+03	14000.00
965863	2017-08-08 15:56:00+03	40800.00
96586A	2017-08-07 15:51:00+03	92400.00
9658B3	2017-07-07 06:41:00+03	14800.00
96593F	2017-07-07 13:17:00+03	219400.00
965970	2017-08-07 01:55:00+03	19600.00
965A9F	2017-07-24 10:05:00+03	24400.00
965AAC	2017-07-30 02:52:00+03	32700.00
965B4B	2017-08-10 00:07:00+03	43600.00
965B52	2017-08-03 18:28:00+03	26800.00
965B7A	2017-07-12 12:12:00+03	250600.00
965B84	2017-07-29 13:41:00+03	52000.00
965B93	2017-08-14 15:51:00+03	258000.00
965BA2	2017-07-29 15:25:00+03	92000.00
965BBE	2017-07-20 10:58:00+03	7400.00
965BE5	2017-07-13 10:23:00+03	6000.00
965BF5	2017-07-29 12:57:00+03	64500.00
965C45	2017-07-31 02:41:00+03	469200.00
965C8C	2017-08-14 23:23:00+03	88600.00
965CC0	2017-07-06 07:42:00+03	108900.00
965CDF	2017-07-23 05:11:00+03	6000.00
965CE6	2017-08-11 09:43:00+03	28000.00
965D47	2017-07-01 05:14:00+03	20400.00
965D84	2017-07-04 19:56:00+03	85700.00
965DCA	2017-07-26 21:46:00+03	135600.00
965DFD	2017-08-05 21:09:00+03	42800.00
965E30	2017-08-07 10:20:00+03	111600.00
965E45	2017-07-23 19:02:00+03	77600.00
965EC2	2017-08-08 19:02:00+03	77900.00
965EF4	2017-07-30 05:51:00+03	44000.00
965F49	2017-08-08 02:36:00+03	58600.00
965F63	2017-07-17 04:03:00+03	31600.00
965F96	2017-07-04 04:55:00+03	142000.00
965FC2	2017-07-22 04:30:00+03	28800.00
9660E8	2017-07-05 15:28:00+03	43600.00
966108	2017-08-08 10:38:00+03	92900.00
966147	2017-06-30 01:45:00+03	43100.00
96614E	2017-08-14 08:59:00+03	32800.00
966154	2017-07-05 17:46:00+03	28000.00
96615A	2017-08-15 00:48:00+03	38600.00
9661A7	2017-08-12 11:49:00+03	46000.00
9661F8	2017-08-12 14:54:00+03	186900.00
96624F	2017-07-19 17:46:00+03	170700.00
966297	2017-07-17 14:09:00+03	30200.00
9662D1	2017-07-05 08:04:00+03	26000.00
9662F3	2017-06-28 08:27:00+03	59800.00
966306	2017-07-06 13:35:00+03	11800.00
96631F	2017-08-13 21:58:00+03	24000.00
966364	2017-07-29 20:26:00+03	23600.00
9663AA	2017-07-03 14:10:00+03	99300.00
966418	2017-08-02 00:16:00+03	69400.00
966443	2017-07-09 07:44:00+03	12600.00
96644B	2017-07-28 22:39:00+03	79600.00
9664AC	2017-08-08 20:53:00+03	22600.00
9664B6	2017-07-28 09:39:00+03	36200.00
966505	2017-08-14 21:23:00+03	202700.00
9665EA	2017-07-25 14:26:00+03	29400.00
966644	2017-08-10 03:53:00+03	28800.00
966647	2017-07-17 20:04:00+03	24600.00
966665	2017-07-04 06:56:00+03	27800.00
96668D	2017-07-22 22:43:00+03	21400.00
9666A9	2017-07-12 12:14:00+03	61800.00
9666C5	2017-07-04 08:16:00+03	64500.00
96673A	2017-07-25 01:21:00+03	6700.00
96677C	2017-07-21 16:47:00+03	13400.00
9667C7	2017-07-01 14:50:00+03	43900.00
9667DD	2017-07-26 16:48:00+03	96200.00
966817	2017-07-04 17:21:00+03	65400.00
966871	2017-08-07 21:36:00+03	20600.00
96687A	2017-07-25 10:59:00+03	23200.00
966891	2017-08-14 21:57:00+03	101500.00
966960	2017-07-07 13:26:00+03	23600.00
96698C	2017-07-17 17:58:00+03	118000.00
96699A	2017-06-27 13:51:00+03	26700.00
966A0B	2017-07-16 00:23:00+03	60400.00
966A10	2017-07-12 09:11:00+03	28800.00
966A53	2017-08-10 12:10:00+03	46400.00
966A6A	2017-07-03 05:54:00+03	12600.00
966AAD	2017-07-05 11:31:00+03	56000.00
966ACE	2017-07-04 08:39:00+03	116000.00
966B13	2017-08-14 02:12:00+03	134400.00
966B4B	2017-07-24 06:57:00+03	99900.00
966B5C	2017-07-16 14:04:00+03	8000.00
966B7D	2017-08-03 10:56:00+03	6700.00
966B80	2017-07-12 10:03:00+03	57400.00
966B84	2017-07-20 17:41:00+03	185600.00
966B9E	2017-08-14 13:04:00+03	56300.00
966BF6	2017-08-08 05:55:00+03	19500.00
966C15	2017-07-20 22:03:00+03	52000.00
966CDF	2017-07-27 20:12:00+03	13400.00
966D11	2017-08-15 09:01:00+03	21200.00
966D29	2017-08-15 05:23:00+03	12600.00
966DB8	2017-07-06 13:18:00+03	134400.00
966DF6	2017-07-19 19:24:00+03	79600.00
966F93	2017-07-23 07:32:00+03	28800.00
967026	2017-08-05 06:23:00+03	14400.00
967059	2017-07-09 11:15:00+03	172100.00
967087	2017-07-15 18:44:00+03	12200.00
9670B3	2017-07-23 06:40:00+03	25600.00
96710F	2017-08-03 21:53:00+03	53400.00
967114	2017-08-10 20:26:00+03	30900.00
9671B2	2017-08-05 03:09:00+03	17200.00
967225	2017-07-15 19:04:00+03	83000.00
967242	2017-07-09 19:13:00+03	31700.00
967457	2017-07-31 10:30:00+03	36900.00
96746E	2017-08-02 05:49:00+03	46200.00
967483	2017-07-26 22:29:00+03	16400.00
967496	2017-07-20 19:38:00+03	75800.00
967515	2017-08-02 15:11:00+03	48800.00
967531	2017-07-16 21:54:00+03	111600.00
96753E	2017-07-08 07:49:00+03	40400.00
967558	2017-06-30 03:07:00+03	44800.00
967576	2017-07-20 12:54:00+03	19600.00
967580	2017-08-06 01:07:00+03	125200.00
967589	2017-08-15 04:09:00+03	90400.00
967615	2017-07-21 00:56:00+03	185000.00
9676F6	2017-07-19 09:08:00+03	95000.00
96770B	2017-07-14 06:11:00+03	201200.00
967765	2017-07-12 16:26:00+03	85000.00
967771	2017-07-13 14:25:00+03	149800.00
96778D	2017-07-04 15:21:00+03	6700.00
9677D9	2017-07-24 17:18:00+03	43200.00
96782A	2017-07-14 13:54:00+03	133200.00
967847	2017-07-26 20:35:00+03	90000.00
96786D	2017-08-11 00:44:00+03	86500.00
9678E2	2017-07-27 07:26:00+03	38500.00
967957	2017-08-09 04:40:00+03	25100.00
9679B8	2017-08-14 16:32:00+03	149000.00
9679E6	2017-08-03 03:13:00+03	123000.00
967A28	2017-07-23 01:13:00+03	46400.00
967A47	2017-07-19 11:01:00+03	14400.00
967A5F	2017-07-30 20:12:00+03	119700.00
967A9E	2017-07-05 02:21:00+03	35200.00
967B45	2017-07-22 19:03:00+03	44800.00
967B7F	2017-07-28 16:30:00+03	106700.00
967BA6	2017-08-03 20:01:00+03	46200.00
967BEE	2017-08-11 16:06:00+03	51900.00
967BF0	2017-08-12 01:25:00+03	86300.00
967C38	2017-08-12 09:34:00+03	125400.00
967CC2	2017-08-08 07:17:00+03	135400.00
967D2D	2017-07-07 05:56:00+03	85700.00
967DA2	2017-08-02 20:40:00+03	13400.00
967DB4	2017-08-06 21:58:00+03	166000.00
967E01	2017-07-08 22:19:00+03	24700.00
967ED1	2017-07-21 09:25:00+03	83600.00
967EDC	2017-08-13 18:43:00+03	65100.00
967EED	2017-07-28 15:56:00+03	81600.00
967FA2	2017-07-05 22:24:00+03	45500.00
96801F	2017-08-10 09:31:00+03	233000.00
968085	2017-08-02 09:57:00+03	47500.00
9680DB	2017-07-20 03:35:00+03	91000.00
9680F6	2017-07-30 13:29:00+03	47200.00
96812F	2017-08-12 06:28:00+03	83700.00
96818F	2017-08-14 01:26:00+03	54700.00
9681EA	2017-08-08 05:22:00+03	31600.00
9681F3	2017-06-29 13:56:00+03	489000.00
968204	2017-07-22 00:35:00+03	89700.00
968232	2017-08-13 18:22:00+03	115900.00
968237	2017-08-01 06:36:00+03	21400.00
96826E	2017-07-15 08:43:00+03	58100.00
9682B2	2017-07-04 02:17:00+03	12400.00
9682F2	2017-08-02 11:43:00+03	146800.00
96830C	2017-07-08 03:18:00+03	24800.00
96832B	2017-07-29 21:38:00+03	53600.00
968347	2017-07-15 18:47:00+03	12400.00
968395	2017-08-02 13:22:00+03	61800.00
9683B8	2017-07-06 04:20:00+03	118700.00
968415	2017-07-27 08:25:00+03	91600.00
9684ED	2017-07-25 05:03:00+03	271100.00
9684FC	2017-08-12 15:24:00+03	44100.00
96850B	2017-07-19 11:05:00+03	100600.00
968513	2017-07-19 20:18:00+03	83600.00
968558	2017-07-09 12:24:00+03	31100.00
9685AA	2017-06-28 18:00:00+03	16400.00
968600	2017-07-04 06:16:00+03	46300.00
968604	2017-08-08 14:01:00+03	62500.00
9686E7	2017-07-30 08:18:00+03	9200.00
968729	2017-07-31 00:20:00+03	246000.00
968812	2017-08-10 01:42:00+03	13400.00
968825	2017-07-08 17:47:00+03	147700.00
968833	2017-07-25 18:47:00+03	40000.00
968860	2017-07-09 19:18:00+03	71200.00
9688AA	2017-07-17 13:30:00+03	56600.00
9688B6	2017-07-26 16:07:00+03	13700.00
9688C4	2017-07-22 15:24:00+03	13300.00
968914	2017-07-15 23:11:00+03	185600.00
968926	2017-07-03 05:47:00+03	101100.00
968943	2017-07-09 11:31:00+03	78100.00
968972	2017-08-04 23:43:00+03	24700.00
968984	2017-07-01 06:26:00+03	18200.00
9689D0	2017-08-06 03:04:00+03	140900.00
9689F9	2017-07-15 02:00:00+03	57600.00
968A6C	2017-08-11 18:52:00+03	26000.00
968AAD	2017-08-09 14:21:00+03	226800.00
968B60	2017-07-29 16:21:00+03	12000.00
968B7C	2017-07-24 10:43:00+03	282300.00
968BDA	2017-07-18 01:06:00+03	35600.00
968C4C	2017-07-21 03:44:00+03	6700.00
968C56	2017-08-10 23:12:00+03	12000.00
968CA0	2017-06-30 23:40:00+03	12400.00
968CA3	2017-08-06 22:39:00+03	53600.00
968D36	2017-08-09 19:38:00+03	62600.00
968D47	2017-07-20 20:51:00+03	26800.00
968D52	2017-08-10 13:45:00+03	62700.00
968D9F	2017-08-05 20:50:00+03	72600.00
968DC7	2017-07-04 22:18:00+03	37900.00
968DE2	2017-07-17 07:29:00+03	100600.00
968E52	2017-07-02 20:58:00+03	58900.00
968E62	2017-07-16 15:18:00+03	37600.00
968EB0	2017-07-11 18:42:00+03	58600.00
968EC6	2017-07-25 01:40:00+03	6700.00
968ECB	2017-08-09 02:38:00+03	68400.00
968ED9	2017-07-15 03:02:00+03	47600.00
968EDE	2017-08-10 22:40:00+03	6900.00
968F38	2017-07-31 18:49:00+03	96300.00
968FC8	2017-07-14 18:20:00+03	45200.00
968FF5	2017-07-05 01:48:00+03	38600.00
969003	2017-07-15 11:33:00+03	49500.00
96905D	2017-08-12 22:55:00+03	12600.00
969079	2017-07-07 21:58:00+03	75300.00
969088	2017-08-14 03:33:00+03	21600.00
9690B8	2017-07-22 12:45:00+03	17800.00
969109	2017-07-17 20:40:00+03	58600.00
96911D	2017-07-23 23:34:00+03	44000.00
969191	2017-07-08 14:17:00+03	62600.00
9691C5	2017-07-14 04:16:00+03	46300.00
9691C6	2017-07-15 17:13:00+03	27700.00
96927B	2017-07-14 21:49:00+03	112400.00
9692EC	2017-07-29 06:13:00+03	57100.00
96934F	2017-07-25 00:45:00+03	31400.00
969353	2017-08-13 08:19:00+03	12400.00
9693E7	2017-07-10 21:10:00+03	142200.00
9693E8	2017-07-18 01:47:00+03	135400.00
96943D	2017-07-21 10:33:00+03	89000.00
969470	2017-07-27 03:28:00+03	62000.00
969477	2017-08-13 13:26:00+03	23100.00
9694C7	2017-08-11 10:48:00+03	48200.00
96950B	2017-07-14 13:26:00+03	26200.00
96950D	2017-07-07 06:13:00+03	12600.00
969513	2017-07-12 06:18:00+03	66000.00
969530	2017-08-02 14:33:00+03	46400.00
969557	2017-07-28 03:59:00+03	6600.00
9695B9	2017-07-22 09:53:00+03	98400.00
96960F	2017-08-01 19:02:00+03	46400.00
969622	2017-07-28 03:23:00+03	41400.00
96963B	2017-07-02 15:15:00+03	89200.00
969652	2017-07-21 14:40:00+03	26800.00
96965B	2017-08-04 03:19:00+03	86500.00
9696AF	2017-07-19 10:45:00+03	60400.00
9696E5	2017-07-10 18:18:00+03	43200.00
9696F3	2017-08-01 00:51:00+03	25600.00
969708	2017-07-03 02:52:00+03	62700.00
969712	2017-07-01 19:44:00+03	80000.00
969717	2017-07-22 07:17:00+03	22000.00
9697A4	2017-08-10 02:11:00+03	29200.00
9697C2	2017-07-30 06:07:00+03	99200.00
969817	2017-08-08 06:19:00+03	54000.00
969836	2017-07-19 13:43:00+03	28800.00
9698AC	2017-07-26 14:59:00+03	103500.00
9698EC	2017-08-13 04:20:00+03	26700.00
969965	2017-08-12 15:18:00+03	37200.00
9699C9	2017-07-22 19:46:00+03	12600.00
9699E3	2017-08-10 08:14:00+03	243700.00
969A0D	2017-07-10 09:41:00+03	124200.00
969AC7	2017-07-06 08:18:00+03	20100.00
969ACC	2017-07-25 01:04:00+03	7400.00
969CB1	2017-07-08 09:52:00+03	13400.00
969CB6	2017-08-05 23:05:00+03	57300.00
969CD5	2017-07-12 06:00:00+03	135200.00
969D6B	2017-07-14 04:02:00+03	125000.00
969E11	2017-08-04 16:25:00+03	206400.00
969E67	2017-07-04 22:43:00+03	61100.00
969E7F	2017-08-08 09:33:00+03	56100.00
969EC4	2017-08-13 13:50:00+03	26000.00
969ED0	2017-08-06 03:24:00+03	19600.00
969F67	2017-07-01 20:40:00+03	24600.00
969FB9	2017-07-23 22:18:00+03	24300.00
969FC3	2017-07-20 19:06:00+03	26800.00
969FF0	2017-07-09 23:33:00+03	100600.00
96A04F	2017-07-27 19:12:00+03	14000.00
96A0DF	2017-07-30 21:27:00+03	86600.00
96A0F4	2017-07-24 21:23:00+03	3400.00
96A139	2017-07-04 12:33:00+03	148200.00
96A181	2017-07-16 02:47:00+03	92000.00
96A18E	2017-07-02 00:20:00+03	43600.00
96A1E6	2017-07-23 08:44:00+03	95800.00
96A1EF	2017-07-31 22:03:00+03	113000.00
96A1F5	2017-07-29 17:58:00+03	54800.00
96A226	2017-08-07 03:21:00+03	15400.00
96A22E	2017-08-05 14:14:00+03	38600.00
96A24A	2017-08-11 16:45:00+03	27200.00
96A2C1	2017-08-04 15:30:00+03	6300.00
96A2DA	2017-07-26 14:00:00+03	75500.00
96A30F	2017-07-15 10:41:00+03	50000.00
96A3C2	2017-07-24 04:16:00+03	71900.00
96A3E0	2017-08-04 07:36:00+03	26800.00
96A42A	2017-07-16 15:15:00+03	64800.00
96A438	2017-07-15 10:56:00+03	87400.00
96A469	2017-08-15 16:49:00+03	51900.00
96A476	2017-07-12 12:24:00+03	370600.00
96A4A3	2017-07-23 12:33:00+03	55800.00
96A4FC	2017-07-14 09:09:00+03	103500.00
96A579	2017-07-13 11:55:00+03	31800.00
96A5E6	2017-07-30 14:11:00+03	13600.00
96A651	2017-08-07 23:56:00+03	62600.00
96A674	2017-08-11 14:45:00+03	42600.00
96A6B7	2017-06-30 23:24:00+03	92100.00
96A6EC	2017-07-30 10:29:00+03	28800.00
96A746	2017-08-12 04:30:00+03	19800.00
96A77C	2017-07-31 03:08:00+03	155600.00
96A7F3	2017-07-16 03:44:00+03	29400.00
96A8B1	2017-08-10 22:01:00+03	64700.00
96A8CC	2017-07-03 19:52:00+03	26000.00
96A8D4	2017-07-02 22:13:00+03	136200.00
96A8F9	2017-07-30 16:30:00+03	246000.00
96A92A	2017-07-13 20:52:00+03	32400.00
96A96C	2017-07-27 10:45:00+03	26800.00
96A98E	2017-08-04 14:32:00+03	26200.00
96A9C8	2017-07-31 08:30:00+03	397700.00
96AA09	2017-07-13 05:58:00+03	24400.00
96AA39	2017-07-10 22:28:00+03	47000.00
96AA3B	2017-07-22 02:30:00+03	64400.00
96AA9F	2017-08-05 06:41:00+03	28800.00
96AB10	2017-08-12 05:59:00+03	68900.00
96AB34	2017-07-25 14:23:00+03	273400.00
96AB74	2017-08-03 12:15:00+03	26800.00
96ABDB	2017-07-11 04:51:00+03	137600.00
96ABE1	2017-07-31 19:32:00+03	112000.00
96AC17	2017-07-30 08:40:00+03	138900.00
96AC34	2017-07-19 17:09:00+03	45200.00
96AC4A	2017-07-12 08:51:00+03	42300.00
96AD10	2017-07-18 22:40:00+03	117200.00
96AD16	2017-07-05 07:05:00+03	30200.00
96AD27	2017-07-01 04:50:00+03	39800.00
96AD54	2017-08-06 12:46:00+03	153200.00
96AD67	2017-07-26 03:35:00+03	56000.00
96ADBF	2017-08-04 18:41:00+03	28000.00
96ADFD	2017-07-25 22:53:00+03	41200.00
96ADFF	2017-07-11 22:58:00+03	123000.00
96AE09	2017-07-26 14:44:00+03	135300.00
96AE51	2017-07-03 14:36:00+03	31600.00
96AE6E	2017-07-27 08:52:00+03	46400.00
96AEBA	2017-08-01 11:12:00+03	258400.00
96AF04	2017-06-27 19:59:00+03	62000.00
96AF3F	2017-07-24 09:00:00+03	128800.00
96AF5C	2017-07-31 03:44:00+03	200500.00
96AF98	2017-07-07 07:22:00+03	32700.00
96AFAB	2017-08-06 00:59:00+03	129200.00
96AFB1	2017-07-20 15:24:00+03	91000.00
96AFFA	2017-08-07 13:17:00+03	22000.00
96B00B	2017-07-03 05:10:00+03	32900.00
96B0C0	2017-08-12 11:20:00+03	48800.00
96B0FF	2017-07-08 22:18:00+03	47200.00
96B129	2017-07-01 06:03:00+03	88200.00
96B12F	2017-08-13 04:36:00+03	12600.00
96B18E	2017-07-05 18:02:00+03	44100.00
96B25D	2017-07-24 12:15:00+03	27800.00
96B276	2017-07-02 09:24:00+03	49600.00
96B292	2017-07-31 02:34:00+03	145500.00
96B2BB	2017-08-13 21:33:00+03	11300.00
96B2BC	2017-08-10 16:39:00+03	6300.00
96B302	2017-08-09 00:53:00+03	120000.00
96B399	2017-07-15 11:29:00+03	139300.00
96B3C4	2017-07-27 12:42:00+03	99600.00
96B3F1	2017-08-11 02:42:00+03	206400.00
96B41D	2017-07-22 04:55:00+03	38000.00
96B468	2017-08-14 23:48:00+03	14400.00
96B4B9	2017-07-28 10:06:00+03	56000.00
96B502	2017-08-13 14:11:00+03	104600.00
96B50A	2017-07-10 12:19:00+03	53600.00
96B512	2017-07-14 05:19:00+03	8400.00
96B580	2017-08-04 00:02:00+03	51800.00
96B5B3	2017-07-13 00:27:00+03	86500.00
96B660	2017-07-18 00:30:00+03	273900.00
96B661	2017-08-10 07:41:00+03	56000.00
96B664	2017-07-17 02:42:00+03	75300.00
96B678	2017-07-15 15:00:00+03	133200.00
96B6F6	2017-08-03 11:35:00+03	176200.00
96B71C	2017-07-08 20:46:00+03	12100.00
96B721	2017-08-12 13:06:00+03	70100.00
96B73C	2017-07-12 18:21:00+03	100900.00
96B781	2017-07-11 20:38:00+03	47800.00
96B785	2017-07-09 09:11:00+03	6800.00
96B7FE	2017-07-10 09:07:00+03	66600.00
96B874	2017-07-31 13:16:00+03	23200.00
96B8F3	2017-08-05 02:03:00+03	46300.00
96B985	2017-07-25 00:15:00+03	76600.00
96BA67	2017-08-10 08:27:00+03	102100.00
96BA89	2017-08-11 11:48:00+03	6600.00
96BAC8	2017-07-24 09:32:00+03	95200.00
96BAD9	2017-07-23 12:31:00+03	30200.00
96BADD	2017-08-11 11:44:00+03	16400.00
96BB32	2017-07-10 10:37:00+03	393800.00
96BB8C	2017-08-14 16:34:00+03	76800.00
96BBD7	2017-07-20 15:51:00+03	199700.00
96BC16	2017-06-30 06:48:00+03	11800.00
96BC6D	2017-07-21 13:12:00+03	99200.00
96BC91	2017-07-12 08:26:00+03	111600.00
96BD00	2017-08-14 17:35:00+03	95200.00
96BDCB	2017-07-01 01:57:00+03	30400.00
96BDEB	2017-07-26 09:33:00+03	76400.00
96BE08	2017-07-06 14:38:00+03	123000.00
96BE0C	2017-07-22 23:35:00+03	14000.00
96BE1E	2017-08-11 23:00:00+03	135200.00
96BE2B	2017-07-26 23:01:00+03	86800.00
96BEB5	2017-08-03 05:03:00+03	257600.00
96BF6F	2017-07-18 19:15:00+03	152000.00
96BF80	2017-07-19 10:57:00+03	14800.00
96BFA9	2017-08-03 22:19:00+03	87000.00
96C04A	2017-07-11 08:12:00+03	258000.00
96C067	2017-08-09 08:24:00+03	66600.00
96C0A6	2017-08-05 17:22:00+03	75300.00
96C0B6	2017-07-22 14:11:00+03	84000.00
96C0E1	2017-07-20 17:07:00+03	56000.00
96C156	2017-07-25 01:44:00+03	123900.00
96C1EA	2017-07-05 20:36:00+03	94000.00
96C21D	2017-07-31 07:23:00+03	46400.00
96C220	2017-07-01 23:05:00+03	309300.00
96C2A0	2017-07-12 16:36:00+03	237900.00
96C2B6	2017-08-03 10:31:00+03	65500.00
96C307	2017-08-14 08:17:00+03	26800.00
96C30A	2017-07-19 18:29:00+03	254900.00
96C3E1	2017-08-11 08:46:00+03	24400.00
96C4AB	2017-08-08 18:09:00+03	28700.00
96C4D9	2017-08-10 09:21:00+03	137600.00
96C568	2017-07-18 20:05:00+03	13400.00
96C570	2017-08-02 02:16:00+03	26600.00
96C5C9	2017-07-26 08:15:00+03	65100.00
96C606	2017-07-21 20:22:00+03	192400.00
96C659	2017-07-12 22:53:00+03	193600.00
96C66B	2017-07-06 22:55:00+03	34000.00
96C66F	2017-07-11 06:02:00+03	19600.00
96C745	2017-08-14 20:47:00+03	149800.00
96C746	2017-08-07 08:28:00+03	32800.00
96C74E	2017-08-03 15:33:00+03	88600.00
96C7D3	2017-07-23 17:00:00+03	29100.00
96C7F9	2017-07-21 09:26:00+03	28000.00
96C827	2017-08-01 05:44:00+03	32800.00
96C8A7	2017-07-14 18:13:00+03	132600.00
96C8ED	2017-08-13 05:52:00+03	264800.00
96C8EF	2017-07-29 06:41:00+03	28000.00
96C8F6	2017-08-12 19:51:00+03	66000.00
96C98B	2017-07-08 13:56:00+03	53700.00
96C992	2017-08-04 01:53:00+03	73600.00
96C9B2	2017-07-24 06:46:00+03	283100.00
96C9B4	2017-07-25 01:52:00+03	67600.00
96C9C3	2017-07-07 19:00:00+03	46000.00
96CA49	2017-07-15 03:44:00+03	185300.00
96CA60	2017-07-16 17:06:00+03	13700.00
96CA6F	2017-07-05 10:59:00+03	103900.00
96CA83	2017-08-13 19:57:00+03	33700.00
96CB13	2017-07-11 23:46:00+03	173400.00
96CB55	2017-08-04 15:44:00+03	224000.00
96CB6F	2017-07-20 09:43:00+03	111600.00
96CB75	2017-07-03 14:34:00+03	66600.00
96CB7C	2017-07-17 03:08:00+03	89700.00
96CBA9	2017-07-16 13:08:00+03	58600.00
96CBD9	2017-08-04 23:12:00+03	42700.00
96CBE7	2017-07-19 07:59:00+03	35200.00
96CC9E	2017-08-12 21:37:00+03	37900.00
96CCA8	2017-07-15 06:24:00+03	44800.00
96CCE8	2017-07-28 05:50:00+03	21800.00
96CD36	2017-08-15 16:17:00+03	27300.00
96CD3D	2017-07-25 16:02:00+03	28300.00
96CD59	2017-07-19 23:50:00+03	55800.00
96CD67	2017-08-15 07:02:00+03	134400.00
96CD7B	2017-07-28 01:32:00+03	49100.00
96CD90	2017-07-22 01:31:00+03	23200.00
96CD9F	2017-07-23 14:30:00+03	54400.00
96CE99	2017-08-04 08:59:00+03	142400.00
96CF33	2017-07-12 23:40:00+03	31600.00
96CF5A	2017-07-13 07:39:00+03	116800.00
96CFAB	2017-07-19 23:27:00+03	56900.00
96D011	2017-08-04 09:27:00+03	24700.00
96D025	2017-08-05 09:48:00+03	92600.00
96D057	2017-07-22 19:36:00+03	32800.00
96D0BB	2017-07-21 02:19:00+03	59200.00
96D0E5	2017-08-05 11:20:00+03	118000.00
96D0F6	2017-07-02 08:51:00+03	99300.00
96D0F7	2017-07-23 07:14:00+03	130400.00
96D10F	2017-08-12 10:24:00+03	70800.00
96D1A7	2017-07-05 03:09:00+03	55800.00
96D1B3	2017-08-04 20:15:00+03	26800.00
96D1C0	2017-08-15 12:55:00+03	69500.00
96D1F7	2017-06-28 05:26:00+03	344000.00
96D22B	2017-08-05 09:22:00+03	58600.00
96D312	2017-07-04 23:10:00+03	200400.00
96D388	2017-07-30 14:03:00+03	45000.00
96D39B	2017-07-04 07:13:00+03	29600.00
96D3BC	2017-07-09 16:48:00+03	77900.00
96D439	2017-08-14 04:23:00+03	46400.00
96D44D	2017-07-12 12:59:00+03	44200.00
96D44F	2017-07-22 16:10:00+03	26200.00
96D4C6	2017-07-23 12:54:00+03	51300.00
96D4C9	2017-08-03 00:32:00+03	265600.00
96D521	2017-06-30 14:25:00+03	48800.00
96D530	2017-07-27 09:56:00+03	246000.00
96D553	2017-08-07 16:11:00+03	64800.00
96D5A7	2017-08-12 17:22:00+03	40600.00
96D694	2017-07-16 07:56:00+03	38400.00
96D6AF	2017-07-12 02:14:00+03	231600.00
96D6E3	2017-07-04 15:38:00+03	56000.00
96D6FC	2017-07-21 09:19:00+03	32700.00
96D706	2017-07-26 14:22:00+03	28000.00
96D7C7	2017-07-23 02:05:00+03	38800.00
96D7D2	2017-08-13 05:16:00+03	185600.00
96D83C	2017-07-04 15:24:00+03	50300.00
96D86C	2017-08-12 03:19:00+03	34200.00
96D8C7	2017-07-21 20:32:00+03	35300.00
96D995	2017-07-12 17:30:00+03	65300.00
96DA0A	2017-08-04 06:35:00+03	137400.00
96DA0E	2017-07-25 00:46:00+03	79900.00
96DA7E	2017-07-17 11:38:00+03	8000.00
96DA8E	2017-07-04 02:19:00+03	89600.00
96DAA2	2017-08-01 17:11:00+03	23600.00
96DAB8	2017-07-26 03:33:00+03	125100.00
96DAD4	2017-07-10 15:20:00+03	38600.00
96DAEC	2017-08-08 07:51:00+03	341400.00
96DB11	2017-08-13 03:36:00+03	249100.00
96DB78	2017-07-28 12:16:00+03	172100.00
96DB8B	2017-07-06 11:28:00+03	26600.00
96DBF2	2017-07-30 20:59:00+03	15700.00
96DC39	2017-08-10 03:11:00+03	278400.00
96DC3D	2017-08-07 03:00:00+03	57800.00
96DC77	2017-07-14 17:52:00+03	66600.00
96DC92	2017-07-04 00:05:00+03	69900.00
96DD47	2017-08-09 15:13:00+03	55600.00
96DDA9	2017-06-30 11:30:00+03	8000.00
96DDB1	2017-08-10 05:50:00+03	67600.00
96DDDF	2017-08-11 00:56:00+03	8000.00
96DE8E	2017-07-11 22:00:00+03	27800.00
96DF7A	2017-07-05 16:33:00+03	81300.00
96DF9C	2017-07-31 19:40:00+03	61800.00
96DFAF	2017-08-15 14:45:00+03	59300.00
96DFBA	2017-08-01 17:58:00+03	19800.00
96E006	2017-07-03 15:22:00+03	81700.00
96E013	2017-07-15 08:36:00+03	26000.00
96E06C	2017-07-22 04:56:00+03	6700.00
96E0B3	2017-08-02 22:55:00+03	57400.00
96E0D0	2017-07-12 17:20:00+03	6000.00
96E0E3	2017-07-08 15:42:00+03	134700.00
96E0E8	2017-08-08 22:10:00+03	128800.00
96E0F7	2017-08-04 06:02:00+03	36200.00
96E103	2017-07-05 11:42:00+03	39300.00
96E137	2017-07-17 01:54:00+03	34000.00
96E154	2017-07-08 19:50:00+03	48800.00
96E15D	2017-07-02 01:45:00+03	32700.00
96E1AA	2017-07-22 13:36:00+03	246000.00
96E228	2017-07-22 01:40:00+03	27400.00
96E2AE	2017-08-10 05:01:00+03	60900.00
96E2B2	2017-07-27 14:05:00+03	72800.00
96E2BB	2017-07-27 02:14:00+03	56600.00
96E371	2017-07-19 05:32:00+03	89700.00
96E3A2	2017-07-30 20:56:00+03	77700.00
96E3B0	2017-07-17 18:26:00+03	177200.00
96E3BA	2017-07-06 20:56:00+03	56600.00
96E46C	2017-07-31 19:47:00+03	14800.00
96E491	2017-07-08 23:48:00+03	81900.00
96E4CF	2017-06-30 19:52:00+03	155600.00
96E4DF	2017-07-23 20:46:00+03	664500.00
96E599	2017-07-23 12:15:00+03	14800.00
96E5A3	2017-06-28 13:11:00+03	53600.00
96E5BF	2017-08-07 11:07:00+03	148200.00
96E605	2017-06-30 00:34:00+03	24300.00
96E64C	2017-08-06 11:54:00+03	92900.00
96E663	2017-07-06 10:48:00+03	6000.00
96E67E	2017-07-28 10:19:00+03	443000.00
96E6F4	2017-08-03 00:54:00+03	26800.00
96E70B	2017-07-29 05:57:00+03	56000.00
96E717	2017-07-16 10:14:00+03	182300.00
96E71D	2017-07-27 03:48:00+03	14400.00
96E774	2017-07-24 05:18:00+03	27200.00
96E7FD	2017-08-05 10:20:00+03	118400.00
96E854	2017-08-11 00:40:00+03	116000.00
96E8AD	2017-07-28 10:17:00+03	70800.00
96E94D	2017-08-09 23:26:00+03	38400.00
96E95C	2017-07-06 05:44:00+03	25000.00
96E9CA	2017-08-02 22:41:00+03	134200.00
96E9F8	2017-07-14 04:05:00+03	92800.00
96EA2C	2017-07-10 21:04:00+03	24000.00
96EA5F	2017-07-05 09:45:00+03	12000.00
96EA7F	2017-07-19 07:41:00+03	404700.00
96EAD8	2017-08-14 10:08:00+03	244100.00
96EAFA	2017-07-26 08:35:00+03	47600.00
96EB12	2017-08-04 18:34:00+03	71200.00
96EBA6	2017-07-25 19:07:00+03	254600.00
96EBD6	2017-06-28 20:52:00+03	89100.00
96EBFC	2017-08-06 22:57:00+03	34600.00
96EC7B	2017-08-14 03:55:00+03	15000.00
96ECE1	2017-07-03 12:40:00+03	26000.00
96ED44	2017-07-18 20:53:00+03	16800.00
96ED6B	2017-07-07 18:06:00+03	34000.00
96ED92	2017-07-05 11:07:00+03	138600.00
96EDE3	2017-07-10 04:08:00+03	40800.00
96EDEF	2017-07-09 12:34:00+03	68900.00
96EE1D	2017-08-11 18:56:00+03	155600.00
96EE21	2017-08-08 06:06:00+03	113800.00
96EE27	2017-07-13 20:16:00+03	24300.00
96EE52	2017-08-05 04:01:00+03	139500.00
96EE5A	2017-07-17 03:43:00+03	149300.00
96EE86	2017-08-08 19:30:00+03	52700.00
96EEA2	2017-07-09 16:05:00+03	61500.00
96EEA5	2017-08-09 10:43:00+03	92400.00
96EEC8	2017-07-04 01:55:00+03	16400.00
96EED5	2017-07-09 14:03:00+03	45000.00
96EF3A	2017-07-15 11:15:00+03	39200.00
96EF41	2017-07-28 12:53:00+03	87300.00
96EF55	2017-07-03 04:44:00+03	99800.00
96EFA4	2017-07-10 18:43:00+03	246000.00
96EFCB	2017-08-04 15:22:00+03	199700.00
96EFD7	2017-07-16 06:06:00+03	58000.00
96EFFB	2017-08-07 17:20:00+03	182300.00
96F003	2017-07-17 20:03:00+03	46200.00
96F01A	2017-07-28 04:00:00+03	123900.00
96F0AF	2017-08-10 03:12:00+03	57800.00
96F0D1	2017-07-13 21:36:00+03	110400.00
96F0F8	2017-07-10 10:55:00+03	56200.00
96F115	2017-08-09 06:54:00+03	19600.00
96F15F	2017-07-16 02:25:00+03	46200.00
96F234	2017-08-08 10:17:00+03	81600.00
96F271	2017-08-09 01:49:00+03	98400.00
96F287	2017-07-07 15:46:00+03	102800.00
96F292	2017-08-13 16:00:00+03	56100.00
96F344	2017-07-05 15:00:00+03	26800.00
96F3C4	2017-07-14 01:16:00+03	35600.00
96F3D3	2017-08-07 09:29:00+03	76600.00
96F3EF	2017-07-27 09:03:00+03	431800.00
96F3FD	2017-08-11 07:33:00+03	6700.00
96F435	2017-07-25 00:34:00+03	8000.00
96F43C	2017-08-11 02:24:00+03	89700.00
96F455	2017-08-05 06:44:00+03	131900.00
96F46B	2017-08-14 16:35:00+03	46300.00
96F514	2017-08-05 11:20:00+03	103800.00
96F5DA	2017-08-12 21:11:00+03	405600.00
96F62A	2017-07-19 19:58:00+03	80900.00
96F64B	2017-07-21 15:53:00+03	59300.00
96F672	2017-06-30 02:42:00+03	23200.00
96F677	2017-08-11 19:43:00+03	69000.00
96F6B2	2017-07-22 14:39:00+03	292900.00
96F6D8	2017-07-08 08:59:00+03	24400.00
96F70A	2017-07-10 18:52:00+03	6700.00
96F715	2017-07-31 09:00:00+03	64600.00
96F72D	2017-07-13 08:32:00+03	186900.00
96F76B	2017-07-06 04:35:00+03	66600.00
96F7E0	2017-08-12 21:46:00+03	23200.00
96F7EC	2017-07-24 21:58:00+03	80300.00
96F863	2017-08-10 06:15:00+03	28800.00
96F868	2017-08-04 19:29:00+03	23200.00
96F888	2017-07-19 06:55:00+03	50000.00
96F889	2017-08-10 22:25:00+03	342400.00
96F8A1	2017-07-28 20:53:00+03	27200.00
96F8EF	2017-08-08 00:35:00+03	92800.00
96F8FE	2017-07-07 17:49:00+03	94000.00
96F9D6	2017-07-31 13:38:00+03	28200.00
96FA1A	2017-07-21 04:41:00+03	97600.00
96FA9F	2017-08-05 09:28:00+03	313100.00
96FAE5	2017-08-08 09:43:00+03	52700.00
96FAF5	2017-07-20 05:50:00+03	23200.00
96FB2B	2017-07-02 22:23:00+03	20400.00
96FB34	2017-07-28 17:51:00+03	23600.00
96FB72	2017-08-08 20:05:00+03	28000.00
96FB89	2017-08-10 03:51:00+03	26800.00
96FB8C	2017-07-19 04:33:00+03	24000.00
96FBB2	2017-08-11 17:12:00+03	46400.00
96FBCA	2017-07-01 08:48:00+03	103500.00
96FC31	2017-07-14 23:19:00+03	302800.00
96FC36	2017-08-07 02:39:00+03	246000.00
96FC6E	2017-08-05 22:18:00+03	67200.00
96FC99	2017-08-02 22:21:00+03	51600.00
96FCD9	2017-07-09 14:04:00+03	75800.00
96FCE9	2017-07-28 07:17:00+03	115200.00
96FCFF	2017-08-09 08:32:00+03	55800.00
96FD2D	2017-08-10 09:44:00+03	258400.00
96FE83	2017-07-31 20:11:00+03	26800.00
96FEB1	2017-07-23 15:41:00+03	66600.00
96FED4	2017-08-14 19:42:00+03	135600.00
96FEF0	2017-07-13 14:00:00+03	55800.00
96FF64	2017-08-07 17:08:00+03	175300.00
96FF96	2017-08-08 12:00:00+03	178200.00
96FFAC	2017-07-25 03:25:00+03	47200.00
96FFBF	2017-08-10 10:32:00+03	28800.00
96FFDB	2017-08-15 16:34:00+03	42000.00
970082	2017-07-25 17:50:00+03	27900.00
9700AE	2017-07-07 13:54:00+03	114800.00
9700D9	2017-07-19 18:12:00+03	64300.00
9700E0	2017-08-11 15:47:00+03	68400.00
97012A	2017-07-23 14:49:00+03	37200.00
97012E	2017-07-04 04:06:00+03	19600.00
970169	2017-07-20 18:27:00+03	24800.00
970180	2017-08-01 23:31:00+03	138200.00
970289	2017-06-29 10:27:00+03	43100.00
9702A9	2017-07-10 06:05:00+03	73100.00
970370	2017-07-12 17:19:00+03	70800.00
970389	2017-07-26 13:59:00+03	59000.00
970406	2017-08-05 19:57:00+03	42800.00
9704FF	2017-07-02 08:39:00+03	38400.00
97066A	2017-08-05 17:18:00+03	59800.00
970694	2017-08-13 00:09:00+03	26800.00
9706F4	2017-07-20 15:34:00+03	27600.00
970760	2017-07-29 12:57:00+03	31600.00
970761	2017-07-11 08:13:00+03	48300.00
970765	2017-08-02 12:56:00+03	24200.00
970773	2017-07-30 06:24:00+03	189800.00
9707CA	2017-07-21 19:12:00+03	36200.00
9707F7	2017-08-01 22:00:00+03	105800.00
97081A	2017-07-08 14:47:00+03	56000.00
970865	2017-07-24 02:01:00+03	83000.00
9708AB	2017-08-08 07:27:00+03	20000.00
9708D7	2017-07-23 14:02:00+03	25800.00
970900	2017-08-05 03:49:00+03	55600.00
97097E	2017-08-03 00:32:00+03	6700.00
9709F9	2017-07-05 18:13:00+03	28800.00
970A03	2017-07-12 02:52:00+03	53800.00
970A16	2017-07-16 13:56:00+03	24800.00
970A85	2017-07-03 08:58:00+03	66600.00
970AB7	2017-07-07 00:53:00+03	75200.00
970AC1	2017-08-15 17:59:00+03	33200.00
970ACD	2017-07-02 21:45:00+03	39800.00
970B31	2017-07-27 13:25:00+03	66800.00
970B71	2017-07-21 18:14:00+03	56000.00
970B9D	2017-07-21 03:37:00+03	27900.00
970BC8	2017-08-01 00:19:00+03	49400.00
970C78	2017-07-31 13:15:00+03	16400.00
970C9E	2017-07-20 04:10:00+03	86600.00
970CEA	2017-08-07 09:45:00+03	48800.00
970D23	2017-07-08 13:13:00+03	122200.00
970DBB	2017-07-02 07:07:00+03	240600.00
970E44	2017-08-07 03:04:00+03	28800.00
970E72	2017-07-22 03:23:00+03	135400.00
970EAE	2017-07-17 15:51:00+03	86600.00
970EC5	2017-07-07 04:17:00+03	86600.00
970F0A	2017-08-07 22:20:00+03	8000.00
970F58	2017-08-01 23:38:00+03	28000.00
970FF2	2017-07-31 16:05:00+03	68100.00
971026	2017-08-11 20:18:00+03	53900.00
971046	2017-07-24 14:38:00+03	112200.00
9710AA	2017-07-11 16:35:00+03	8000.00
9710C4	2017-07-26 19:51:00+03	40800.00
97112D	2017-07-18 14:15:00+03	26200.00
971192	2017-07-14 08:47:00+03	109800.00
971197	2017-08-14 19:51:00+03	24400.00
971269	2017-08-04 04:32:00+03	198800.00
9712A4	2017-07-12 13:12:00+03	141000.00
9712FB	2017-07-16 05:48:00+03	89200.00
9713C1	2017-07-26 18:21:00+03	61800.00
9713CB	2017-06-30 13:56:00+03	49100.00
971423	2017-07-07 01:57:00+03	43500.00
971468	2017-07-13 14:11:00+03	45100.00
971479	2017-08-11 01:13:00+03	79600.00
9714D8	2017-08-15 10:45:00+03	80000.00
9714E1	2017-08-10 09:36:00+03	54500.00
971537	2017-08-06 17:11:00+03	47100.00
971564	2017-08-07 02:23:00+03	270000.00
971595	2017-07-12 20:57:00+03	31800.00
9715BD	2017-06-29 10:21:00+03	83600.00
971628	2017-07-28 11:45:00+03	28000.00
971637	2017-07-06 11:32:00+03	192700.00
971663	2017-07-21 12:06:00+03	58400.00
97168D	2017-08-08 00:35:00+03	13400.00
9716A3	2017-07-30 07:37:00+03	127700.00
9716E1	2017-07-25 11:30:00+03	54800.00
971739	2017-08-11 23:44:00+03	50200.00
971752	2017-07-18 20:04:00+03	13600.00
9717A6	2017-08-04 17:08:00+03	86600.00
9717B3	2017-08-14 04:12:00+03	12600.00
9718EF	2017-07-07 00:20:00+03	65100.00
971921	2017-07-20 03:33:00+03	6700.00
971954	2017-08-12 22:30:00+03	25100.00
971956	2017-08-09 09:19:00+03	135400.00
971959	2017-07-07 22:17:00+03	37900.00
971A52	2017-07-31 06:39:00+03	270800.00
971A81	2017-07-11 14:54:00+03	101200.00
971AB2	2017-07-10 19:37:00+03	57600.00
971AF9	2017-08-12 19:10:00+03	46400.00
971AFD	2017-07-30 10:56:00+03	56000.00
971B0F	2017-07-12 21:50:00+03	55800.00
971B20	2017-07-16 13:50:00+03	122300.00
971B26	2017-07-28 20:12:00+03	16400.00
971B92	2017-07-06 02:02:00+03	24800.00
971BAC	2017-07-18 09:22:00+03	41600.00
971C62	2017-07-17 05:54:00+03	40400.00
971C75	2017-08-03 11:15:00+03	117600.00
971C7C	2017-07-16 16:53:00+03	65900.00
971C83	2017-07-25 19:53:00+03	70800.00
971C98	2017-08-14 14:53:00+03	25600.00
971CA0	2017-07-01 09:27:00+03	125700.00
971CC4	2017-07-15 20:32:00+03	176000.00
971CCF	2017-08-01 05:52:00+03	135600.00
971CE0	2017-07-24 00:38:00+03	37200.00
971CFA	2017-08-04 08:22:00+03	37900.00
971D66	2017-08-01 10:25:00+03	51600.00
971D6C	2017-07-01 12:31:00+03	53300.00
971D76	2017-07-02 05:56:00+03	189800.00
971DDB	2017-07-20 19:09:00+03	51300.00
971EBE	2017-07-21 09:05:00+03	76400.00
971EF1	2017-07-01 04:33:00+03	167400.00
971F42	2017-08-03 23:10:00+03	174800.00
971F46	2017-08-09 00:36:00+03	64400.00
971F48	2017-07-26 23:12:00+03	89600.00
971F89	2017-08-11 13:04:00+03	16000.00
971FD1	2017-07-15 14:48:00+03	46400.00
972032	2017-07-08 01:31:00+03	492000.00
972079	2017-08-01 01:33:00+03	117600.00
9720AC	2017-07-31 00:49:00+03	16400.00
972105	2017-07-09 00:22:00+03	27800.00
972184	2017-07-14 06:56:00+03	133200.00
9721DD	2017-07-05 02:49:00+03	147000.00
972238	2017-06-29 17:20:00+03	113600.00
972296	2017-08-08 15:20:00+03	166000.00
9722B5	2017-08-04 01:20:00+03	89600.00
9722FD	2017-08-15 05:46:00+03	64800.00
972354	2017-08-05 20:31:00+03	393800.00
97235F	2017-07-28 18:54:00+03	111600.00
972360	2017-08-02 18:10:00+03	87200.00
97238E	2017-07-04 20:46:00+03	22100.00
972395	2017-07-22 07:00:00+03	216100.00
97239B	2017-07-28 20:34:00+03	45100.00
9723B5	2017-07-24 12:22:00+03	27300.00
97241C	2017-08-05 23:01:00+03	40800.00
972454	2017-07-07 09:50:00+03	99200.00
972495	2017-08-05 06:30:00+03	67400.00
972519	2017-08-11 16:07:00+03	101200.00
97258C	2017-07-16 17:40:00+03	62500.00
97259B	2017-07-10 19:48:00+03	55400.00
9725D0	2017-07-10 10:47:00+03	32700.00
972618	2017-07-11 18:46:00+03	71900.00
972636	2017-07-11 08:00:00+03	27800.00
972684	2017-08-13 14:15:00+03	57600.00
972685	2017-07-28 03:48:00+03	37900.00
972711	2017-07-29 19:12:00+03	26000.00
972744	2017-07-07 20:28:00+03	63200.00
972782	2017-07-13 05:08:00+03	58200.00
97278F	2017-07-12 20:43:00+03	6000.00
9727BE	2017-08-12 10:50:00+03	131600.00
9727DB	2017-08-03 22:27:00+03	27400.00
972852	2017-07-12 17:24:00+03	38800.00
972861	2017-07-27 19:02:00+03	86300.00
97289B	2017-07-02 23:37:00+03	25200.00
9728A4	2017-08-13 11:13:00+03	20600.00
972905	2017-07-09 03:25:00+03	46400.00
972937	2017-07-15 21:27:00+03	148200.00
9729C2	2017-07-21 03:29:00+03	79800.00
9729CA	2017-08-09 17:50:00+03	100500.00
9729D6	2017-08-02 02:34:00+03	154500.00
972A03	2017-08-14 16:01:00+03	112600.00
972A15	2017-07-31 15:49:00+03	410800.00
972A4F	2017-08-10 07:39:00+03	31200.00
972A51	2017-07-18 04:58:00+03	24700.00
972A89	2017-07-26 19:07:00+03	56900.00
972AE5	2017-07-05 19:09:00+03	43600.00
972B0A	2017-07-06 11:28:00+03	67600.00
972B0F	2017-08-01 14:31:00+03	17800.00
972B39	2017-08-04 10:34:00+03	62600.00
972B52	2017-07-08 07:58:00+03	13000.00
972B7D	2017-07-16 07:12:00+03	192100.00
972BCB	2017-07-08 20:04:00+03	21400.00
972C0C	2017-08-03 09:55:00+03	392200.00
972C21	2017-08-02 18:22:00+03	43800.00
972C3E	2017-08-15 06:12:00+03	35200.00
972CA1	2017-07-06 16:49:00+03	369000.00
972CD3	2017-07-15 14:12:00+03	92100.00
972D49	2017-07-18 08:46:00+03	49600.00
972D4E	2017-07-10 02:03:00+03	73600.00
972D78	2017-07-01 05:29:00+03	151800.00
972DF4	2017-07-03 05:57:00+03	13400.00
972E15	2017-07-08 20:19:00+03	46400.00
972ED6	2017-07-29 22:09:00+03	49600.00
972F17	2017-07-11 09:49:00+03	16600.00
972F26	2017-08-12 06:46:00+03	34000.00
972F4B	2017-08-15 08:45:00+03	14400.00
972FAC	2017-07-28 23:48:00+03	152400.00
972FB0	2017-07-28 20:28:00+03	37700.00
972FDA	2017-07-16 09:35:00+03	16400.00
972FF4	2017-07-31 22:40:00+03	41100.00
973002	2017-07-29 10:39:00+03	29600.00
97301E	2017-06-30 08:48:00+03	40600.00
97313D	2017-07-29 13:56:00+03	162600.00
973147	2017-08-02 17:43:00+03	121100.00
9731ED	2017-08-11 17:47:00+03	76400.00
973236	2017-07-25 05:40:00+03	52600.00
973297	2017-08-15 12:28:00+03	46800.00
973362	2017-07-28 16:36:00+03	46200.00
9733A3	2017-07-27 08:37:00+03	19200.00
9733D6	2017-07-11 05:13:00+03	38000.00
9733F6	2017-07-07 01:49:00+03	70700.00
973450	2017-07-27 11:16:00+03	52400.00
97347C	2017-08-10 10:06:00+03	12400.00
973496	2017-07-19 18:24:00+03	38800.00
9734C5	2017-07-04 02:06:00+03	32500.00
973532	2017-08-09 08:35:00+03	13400.00
97357F	2017-08-14 23:52:00+03	17400.00
973599	2017-07-28 06:14:00+03	95000.00
9735D9	2017-07-16 00:03:00+03	23200.00
973614	2017-07-28 23:18:00+03	6300.00
973639	2017-08-15 08:22:00+03	53600.00
973658	2017-07-22 21:56:00+03	8400.00
973673	2017-07-16 10:56:00+03	244100.00
973696	2017-07-24 12:02:00+03	12400.00
9736B1	2017-07-30 23:33:00+03	30700.00
9736B5	2017-06-29 22:45:00+03	64700.00
9736F9	2017-07-16 06:12:00+03	35200.00
97371C	2017-07-09 16:58:00+03	73300.00
9737A4	2017-07-21 04:12:00+03	11600.00
9737B3	2017-08-10 08:47:00+03	18000.00
9737BB	2017-07-26 12:09:00+03	28800.00
9737C0	2017-08-05 06:18:00+03	12600.00
973845	2017-08-13 15:05:00+03	28300.00
973852	2017-08-02 07:22:00+03	28300.00
97385D	2017-08-13 06:57:00+03	12000.00
973877	2017-07-08 08:54:00+03	71900.00
9738AF	2017-07-13 15:26:00+03	113300.00
97390C	2017-07-23 02:20:00+03	117600.00
973921	2017-08-09 07:41:00+03	16000.00
97394E	2017-08-10 22:31:00+03	58800.00
9739E4	2017-07-09 16:49:00+03	39900.00
973A3D	2017-07-28 01:21:00+03	48500.00
973A99	2017-08-04 13:05:00+03	54000.00
973AA9	2017-07-29 13:46:00+03	25600.00
973AEE	2017-08-13 16:50:00+03	27200.00
973B84	2017-07-12 02:08:00+03	14000.00
973B87	2017-07-25 10:41:00+03	53700.00
973B90	2017-07-22 04:42:00+03	90400.00
973BB5	2017-08-14 16:43:00+03	216100.00
973BCB	2017-08-04 17:45:00+03	48900.00
973BED	2017-08-12 00:12:00+03	38400.00
973C28	2017-07-14 03:08:00+03	34100.00
973C34	2017-08-03 07:58:00+03	72600.00
973C3E	2017-07-13 20:51:00+03	60400.00
973C46	2017-08-07 18:58:00+03	37900.00
973C92	2017-07-03 08:58:00+03	155600.00
973C9A	2017-07-07 10:57:00+03	108900.00
973D1B	2017-07-29 17:57:00+03	86400.00
973D65	2017-08-07 17:35:00+03	258500.00
973D8B	2017-07-24 14:27:00+03	56000.00
973D8C	2017-07-18 14:52:00+03	50000.00
973DC8	2017-07-17 01:18:00+03	64700.00
973E19	2017-08-14 07:03:00+03	406200.00
973E41	2017-07-30 08:00:00+03	66600.00
973E4A	2017-08-02 03:27:00+03	56100.00
973E52	2017-07-01 10:10:00+03	39600.00
973E8A	2017-07-25 18:06:00+03	85600.00
973EC8	2017-08-01 13:53:00+03	40800.00
973ECC	2017-07-13 17:15:00+03	22000.00
973EE0	2017-07-11 04:12:00+03	53300.00
973EFF	2017-08-05 20:24:00+03	112000.00
973F6D	2017-08-13 02:35:00+03	184300.00
973F73	2017-08-02 10:29:00+03	91500.00
973FA5	2017-08-06 03:58:00+03	139100.00
974051	2017-07-04 11:23:00+03	31400.00
974085	2017-06-29 22:44:00+03	46200.00
9740B8	2017-07-06 11:20:00+03	103900.00
97412A	2017-08-02 06:31:00+03	75600.00
974155	2017-07-15 23:34:00+03	289300.00
974183	2017-07-03 22:31:00+03	39600.00
9741A2	2017-08-04 13:31:00+03	32100.00
9741AE	2017-07-20 06:31:00+03	38600.00
9741D0	2017-07-27 16:18:00+03	58600.00
97423F	2017-07-08 14:57:00+03	119700.00
974257	2017-07-19 19:35:00+03	96300.00
9742D1	2017-07-31 04:51:00+03	29600.00
97438B	2017-07-20 05:50:00+03	131100.00
9743BF	2017-08-10 12:32:00+03	24400.00
9743C8	2017-07-18 12:27:00+03	106100.00
9743E0	2017-08-05 08:55:00+03	53300.00
974415	2017-08-14 13:58:00+03	96400.00
97448C	2017-08-13 16:14:00+03	27200.00
97457B	2017-08-12 21:47:00+03	28800.00
9745C1	2017-07-20 06:12:00+03	56600.00
9745E3	2017-07-04 00:38:00+03	54300.00
97466D	2017-07-04 16:08:00+03	48500.00
9746A6	2017-07-13 10:12:00+03	25600.00
974771	2017-07-12 01:37:00+03	229900.00
97482D	2017-07-25 16:00:00+03	28000.00
97485E	2017-07-20 19:06:00+03	56000.00
974865	2017-07-02 07:31:00+03	56900.00
974875	2017-08-03 20:47:00+03	20000.00
9748C8	2017-07-25 12:42:00+03	36200.00
97491B	2017-07-29 11:13:00+03	14800.00
9749CB	2017-07-19 19:50:00+03	56000.00
974A6C	2017-07-30 08:36:00+03	26700.00
974AB2	2017-07-26 13:17:00+03	8800.00
974B14	2017-08-03 18:42:00+03	92100.00
974B1D	2017-08-12 12:32:00+03	80200.00
974B33	2017-07-20 05:49:00+03	89600.00
974B36	2017-08-08 22:07:00+03	81600.00
974BA9	2017-07-29 21:48:00+03	89700.00
974BE6	2017-07-22 14:14:00+03	36200.00
974BF5	2017-06-30 10:45:00+03	35700.00
974C24	2017-08-01 05:56:00+03	57600.00
974C84	2017-07-27 18:18:00+03	75200.00
974CB0	2017-07-12 22:39:00+03	21800.00
974CB2	2017-08-12 19:02:00+03	128800.00
974CC7	2017-07-10 01:17:00+03	136800.00
974D3F	2017-07-12 16:53:00+03	34000.00
974D63	2017-07-17 01:38:00+03	55000.00
974D84	2017-08-05 19:24:00+03	59000.00
974DA9	2017-07-06 21:52:00+03	42700.00
974DBA	2017-07-25 13:06:00+03	45100.00
974E06	2017-08-01 00:38:00+03	73300.00
974E0F	2017-08-08 01:27:00+03	61500.00
974E5F	2017-07-27 08:46:00+03	52300.00
974E65	2017-07-10 08:17:00+03	23200.00
974E77	2017-08-12 02:53:00+03	156300.00
974EA4	2017-07-21 07:28:00+03	7300.00
974ED2	2017-07-28 21:27:00+03	130300.00
974EEB	2017-07-07 17:30:00+03	14000.00
974F10	2017-08-06 22:57:00+03	162200.00
974F32	2017-07-04 20:36:00+03	44800.00
974F71	2017-07-25 09:40:00+03	112000.00
974F8C	2017-07-21 23:14:00+03	25100.00
974F9B	2017-07-29 00:18:00+03	24000.00
974FB1	2017-07-05 14:19:00+03	19600.00
974FC6	2017-07-27 08:02:00+03	40800.00
974FD1	2017-07-16 07:36:00+03	46400.00
974FD6	2017-07-19 01:36:00+03	23200.00
974FDC	2017-07-20 04:56:00+03	26000.00
974FEA	2017-08-04 11:24:00+03	70800.00
97503C	2017-08-14 21:08:00+03	25800.00
975059	2017-07-06 21:13:00+03	72400.00
9750EC	2017-08-10 11:41:00+03	50600.00
9751CA	2017-08-08 06:42:00+03	31600.00
97527D	2017-07-25 22:00:00+03	168200.00
97528F	2017-07-18 08:11:00+03	131800.00
9752AB	2017-07-15 15:06:00+03	18000.00
9752EF	2017-08-14 20:46:00+03	28800.00
975349	2017-07-28 17:31:00+03	103400.00
975397	2017-08-12 13:51:00+03	37100.00
97539A	2017-08-09 09:38:00+03	36200.00
9753AC	2017-07-20 13:12:00+03	36900.00
975484	2017-07-08 08:34:00+03	184600.00
97548B	2017-08-13 06:32:00+03	75800.00
9754B7	2017-07-17 00:11:00+03	614700.00
9754D4	2017-08-15 13:29:00+03	16400.00
975500	2017-08-12 08:02:00+03	48800.00
975516	2017-07-11 12:49:00+03	33300.00
97555F	2017-07-13 23:51:00+03	16400.00
975578	2017-07-11 00:14:00+03	32800.00
97558A	2017-08-09 23:18:00+03	58600.00
97565C	2017-07-06 22:38:00+03	57500.00
9756CF	2017-06-27 10:42:00+03	75600.00
975711	2017-07-15 17:09:00+03	26000.00
97575B	2017-08-03 19:54:00+03	84500.00
975788	2017-08-15 03:00:00+03	83300.00
9757ED	2017-08-09 00:53:00+03	112600.00
97587B	2017-07-29 17:54:00+03	21200.00
9758AE	2017-07-15 15:04:00+03	128800.00
975920	2017-08-05 16:44:00+03	111600.00
975924	2017-08-11 05:16:00+03	25400.00
975948	2017-07-12 18:55:00+03	182300.00
975972	2017-07-27 02:09:00+03	92800.00
975983	2017-07-19 04:05:00+03	28000.00
97599C	2017-07-15 15:43:00+03	29500.00
9759A7	2017-07-27 05:14:00+03	25400.00
9759B3	2017-07-07 16:45:00+03	149300.00
975AA0	2017-07-01 13:12:00+03	172600.00
975AAF	2017-07-08 20:33:00+03	8400.00
975AB0	2017-07-08 04:13:00+03	85000.00
975ACF	2017-07-09 04:09:00+03	26000.00
975AD4	2017-07-08 09:02:00+03	29600.00
975B3E	2017-08-13 20:41:00+03	12400.00
975B5F	2017-07-17 13:08:00+03	515100.00
975B65	2017-07-07 04:28:00+03	51300.00
975B68	2017-07-27 08:37:00+03	68000.00
975B80	2017-08-07 22:04:00+03	380700.00
975BED	2017-07-04 12:09:00+03	353600.00
975C24	2017-07-27 03:26:00+03	384900.00
975C78	2017-07-16 11:51:00+03	195800.00
975C9A	2017-07-13 04:00:00+03	196100.00
975CBC	2017-08-01 13:44:00+03	21800.00
975D35	2017-08-11 17:35:00+03	63700.00
975D48	2017-08-10 23:41:00+03	25900.00
975DB8	2017-08-13 21:22:00+03	47400.00
975DC3	2017-07-29 21:31:00+03	118000.00
975E48	2017-07-29 00:54:00+03	11800.00
975E52	2017-08-07 21:14:00+03	52700.00
975E7D	2017-07-16 22:21:00+03	100600.00
975ECA	2017-07-16 16:49:00+03	137400.00
975ED1	2017-07-25 05:48:00+03	86800.00
975F0A	2017-08-04 23:35:00+03	55800.00
976013	2017-08-11 00:29:00+03	11200.00
976015	2017-07-18 18:58:00+03	46000.00
976055	2017-08-11 10:49:00+03	48800.00
97607C	2017-08-07 14:57:00+03	88200.00
976093	2017-07-08 12:28:00+03	103500.00
97609A	2017-07-08 15:38:00+03	25000.00
9760A0	2017-07-28 14:04:00+03	63200.00
9760F0	2017-07-08 23:07:00+03	58200.00
976105	2017-08-06 04:20:00+03	13600.00
976108	2017-07-15 23:22:00+03	34700.00
976163	2017-07-21 08:20:00+03	6000.00
976169	2017-07-13 17:18:00+03	37700.00
9761C6	2017-08-09 20:39:00+03	22400.00
976392	2017-08-08 22:47:00+03	137900.00
9763B7	2017-07-07 05:44:00+03	76800.00
9763E4	2017-08-08 11:17:00+03	28300.00
976411	2017-07-29 06:20:00+03	23100.00
976414	2017-06-30 00:37:00+03	6300.00
9764CB	2017-07-11 18:30:00+03	41600.00
976506	2017-08-07 21:52:00+03	119500.00
976563	2017-07-05 06:53:00+03	128800.00
976580	2017-08-02 08:22:00+03	124200.00
976581	2017-07-29 06:49:00+03	54800.00
976585	2017-08-14 07:35:00+03	86400.00
976596	2017-07-12 05:27:00+03	28800.00
9765AF	2017-07-13 22:14:00+03	39700.00
97663F	2017-07-26 08:30:00+03	64300.00
97665C	2017-07-10 03:05:00+03	26800.00
976682	2017-08-09 07:45:00+03	47100.00
97668F	2017-08-04 09:01:00+03	62600.00
976691	2017-07-25 12:36:00+03	246000.00
97673E	2017-07-18 21:05:00+03	50600.00
97675D	2017-08-05 13:54:00+03	43200.00
976784	2017-07-20 05:49:00+03	134600.00
976803	2017-07-13 12:43:00+03	38800.00
97684D	2017-07-28 23:32:00+03	8400.00
9768F2	2017-08-08 02:28:00+03	67200.00
976945	2017-07-28 22:49:00+03	56000.00
97694B	2017-07-09 15:28:00+03	62900.00
9769BD	2017-08-04 09:07:00+03	28000.00
976A4F	2017-08-07 22:44:00+03	56000.00
976AA2	2017-07-24 07:20:00+03	93400.00
976AF0	2017-07-06 19:12:00+03	301800.00
976B3A	2017-07-15 16:48:00+03	52100.00
976B54	2017-07-19 19:22:00+03	29500.00
976B66	2017-07-02 12:18:00+03	168000.00
976B6C	2017-07-17 00:47:00+03	103900.00
976B7A	2017-08-11 20:04:00+03	38800.00
976B8B	2017-07-18 16:23:00+03	10800.00
976B99	2017-07-01 19:28:00+03	47600.00
976BCF	2017-07-04 10:43:00+03	67700.00
976C3E	2017-08-09 07:07:00+03	112000.00
976C61	2017-07-24 00:05:00+03	52300.00
976C7F	2017-07-02 20:39:00+03	40000.00
976CDE	2017-07-13 21:38:00+03	42800.00
976D5E	2017-08-06 13:26:00+03	49200.00
976D69	2017-08-03 03:45:00+03	71900.00
976D6E	2017-07-11 10:33:00+03	229100.00
976DBE	2017-07-11 18:32:00+03	211600.00
976E0E	2017-08-11 23:30:00+03	59000.00
976E27	2017-08-02 16:26:00+03	100600.00
976E5C	2017-07-13 03:16:00+03	67100.00
976EBC	2017-07-16 08:17:00+03	54800.00
976EDB	2017-08-04 03:02:00+03	314400.00
976EDE	2017-08-13 04:58:00+03	101200.00
976FCB	2017-07-20 19:30:00+03	198400.00
976FEF	2017-06-30 01:54:00+03	109000.00
977036	2017-07-20 05:53:00+03	30000.00
977041	2017-07-08 06:05:00+03	72200.00
9770DB	2017-07-28 20:40:00+03	101900.00
9770E1	2017-08-13 05:33:00+03	10800.00
9770FF	2017-07-17 22:34:00+03	32800.00
97713E	2017-07-07 16:31:00+03	12600.00
977185	2017-08-12 01:58:00+03	28800.00
9771F9	2017-07-29 04:12:00+03	52400.00
97722A	2017-07-13 15:31:00+03	49700.00
97723A	2017-07-14 14:44:00+03	181000.00
977266	2017-07-08 01:27:00+03	16400.00
97726A	2017-07-02 03:35:00+03	69500.00
9772A3	2017-08-13 07:27:00+03	114200.00
9772AF	2017-07-18 19:46:00+03	35600.00
9772C3	2017-07-17 10:26:00+03	45100.00
9772D7	2017-08-12 01:43:00+03	38800.00
9772DA	2017-08-08 06:35:00+03	73500.00
9772E3	2017-08-07 07:19:00+03	29200.00
977306	2017-08-11 12:53:00+03	38000.00
97731B	2017-07-25 16:05:00+03	55800.00
977343	2017-07-27 23:46:00+03	141900.00
97741F	2017-08-15 02:43:00+03	53100.00
977461	2017-07-12 23:36:00+03	147700.00
977487	2017-07-24 08:19:00+03	141600.00
97750B	2017-07-30 06:26:00+03	497700.00
9775AD	2017-07-14 06:22:00+03	24000.00
9775C9	2017-07-18 12:07:00+03	132800.00
9775D6	2017-07-10 20:41:00+03	333400.00
977602	2017-08-02 02:21:00+03	56100.00
97761C	2017-08-04 13:11:00+03	45000.00
977627	2017-07-20 16:26:00+03	55800.00
977668	2017-07-11 03:16:00+03	23400.00
97767C	2017-08-03 21:47:00+03	95600.00
9776BA	2017-08-14 18:03:00+03	12600.00
9776CE	2017-08-05 16:08:00+03	147100.00
9776F5	2017-07-17 19:48:00+03	10700.00
9776FE	2017-08-01 20:47:00+03	6800.00
97772C	2017-07-23 23:52:00+03	111600.00
977732	2017-06-28 04:25:00+03	106900.00
977737	2017-07-17 23:03:00+03	47000.00
97777D	2017-07-11 16:26:00+03	59200.00
9777C3	2017-07-14 17:58:00+03	135200.00
977819	2017-06-30 16:37:00+03	13200.00
977870	2017-08-05 21:24:00+03	67200.00
97797B	2017-07-02 21:58:00+03	47000.00
9779BC	2017-07-21 03:18:00+03	68100.00
9779CE	2017-07-17 06:51:00+03	103200.00
9779F4	2017-08-05 20:29:00+03	92800.00
977AAD	2017-07-11 13:48:00+03	22000.00
977AD9	2017-07-22 17:05:00+03	23600.00
977B08	2017-08-02 10:08:00+03	248300.00
977B0B	2017-08-10 23:17:00+03	26800.00
977C0B	2017-08-05 02:59:00+03	16400.00
977C0F	2017-07-10 22:56:00+03	116900.00
977C16	2017-08-07 13:45:00+03	32800.00
977C35	2017-07-11 15:05:00+03	174400.00
977C62	2017-08-15 04:18:00+03	40000.00
977D06	2017-07-13 14:03:00+03	19600.00
977D0F	2017-07-05 18:52:00+03	297600.00
977D1F	2017-07-22 08:27:00+03	38400.00
977D3E	2017-07-29 03:51:00+03	46300.00
977D66	2017-07-16 09:47:00+03	103400.00
977DD1	2017-08-06 05:40:00+03	30400.00
977E04	2017-07-20 19:11:00+03	55600.00
977E19	2017-07-11 10:57:00+03	120900.00
977E5A	2017-07-16 17:56:00+03	55800.00
977E74	2017-07-12 11:07:00+03	23100.00
977EA9	2017-07-09 00:56:00+03	106400.00
977EAA	2017-07-28 01:17:00+03	59300.00
977F84	2017-07-15 04:43:00+03	446700.00
977FBC	2017-07-07 07:15:00+03	28800.00
977FD2	2017-07-03 04:49:00+03	44000.00
977FD4	2017-07-24 05:12:00+03	75300.00
978008	2017-07-15 17:11:00+03	333600.00
97800A	2017-07-26 03:42:00+03	26000.00
978027	2017-08-01 12:54:00+03	55800.00
97803F	2017-07-15 00:38:00+03	56000.00
978050	2017-07-08 15:15:00+03	43500.00
978074	2017-07-22 11:09:00+03	80200.00
978112	2017-06-30 16:27:00+03	22600.00
978124	2017-08-12 11:55:00+03	37200.00
9781B7	2017-08-12 06:56:00+03	99200.00
9781D0	2017-07-29 08:28:00+03	46300.00
978233	2017-08-11 19:31:00+03	43500.00
97825E	2017-07-05 18:59:00+03	79000.00
97828B	2017-08-10 08:26:00+03	23200.00
9782B7	2017-08-01 17:24:00+03	37900.00
978305	2017-08-01 20:18:00+03	98400.00
978320	2017-07-11 21:19:00+03	43300.00
978352	2017-07-10 20:59:00+03	133200.00
97837A	2017-08-06 17:57:00+03	84500.00
978383	2017-07-22 06:08:00+03	227400.00
97839F	2017-08-15 06:07:00+03	48800.00
978419	2017-07-19 21:38:00+03	30200.00
978464	2017-07-08 04:02:00+03	12600.00
978467	2017-08-08 20:51:00+03	55600.00
9784B2	2017-08-01 02:00:00+03	4100.00
978525	2017-07-20 20:09:00+03	58400.00
97852C	2017-08-09 22:20:00+03	31000.00
97859D	2017-07-17 11:33:00+03	235300.00
9785A7	2017-07-06 20:10:00+03	71500.00
978603	2017-07-04 06:41:00+03	50400.00
97867A	2017-07-18 11:31:00+03	28000.00
9786A8	2017-08-03 19:51:00+03	21800.00
9786E4	2017-07-07 05:47:00+03	75600.00
97875A	2017-07-18 02:44:00+03	36800.00
97875E	2017-07-10 17:51:00+03	40600.00
978762	2017-07-20 05:13:00+03	152500.00
9787B1	2017-08-02 17:00:00+03	20000.00
9787D5	2017-08-13 15:51:00+03	46700.00
9787F3	2017-08-14 21:17:00+03	124300.00
978813	2017-07-30 23:00:00+03	199600.00
978855	2017-07-05 19:05:00+03	52700.00
978886	2017-07-06 06:06:00+03	20100.00
9788E9	2017-08-07 20:04:00+03	64500.00
97898A	2017-07-25 18:23:00+03	82000.00
978995	2017-08-12 18:35:00+03	43900.00
9789C2	2017-07-14 08:18:00+03	134400.00
9789DB	2017-07-18 20:01:00+03	147000.00
978A00	2017-07-13 14:13:00+03	36000.00
978A37	2017-07-19 12:09:00+03	31400.00
978AC8	2017-07-22 10:28:00+03	46400.00
978B33	2017-07-06 18:01:00+03	91500.00
978BBC	2017-07-30 16:38:00+03	86400.00
978C15	2017-07-18 20:41:00+03	6000.00
978C2B	2017-08-06 11:44:00+03	13400.00
978CC7	2017-07-23 11:13:00+03	25600.00
978CDA	2017-07-03 18:59:00+03	96800.00
978D1D	2017-07-30 17:26:00+03	92800.00
978D88	2017-07-05 16:41:00+03	57800.00
978DB5	2017-06-28 22:21:00+03	135400.00
978DBE	2017-07-29 18:58:00+03	92800.00
978DE9	2017-07-15 13:15:00+03	8400.00
978E72	2017-07-30 04:38:00+03	69600.00
978ED2	2017-07-25 22:01:00+03	60400.00
978F32	2017-07-22 14:44:00+03	8000.00
978F33	2017-07-30 16:16:00+03	19600.00
978F5B	2017-07-09 03:41:00+03	123000.00
979047	2017-07-18 18:44:00+03	6700.00
979075	2017-08-06 04:31:00+03	123000.00
9790BA	2017-08-11 14:34:00+03	24400.00
9790E7	2017-06-29 05:48:00+03	37200.00
979147	2017-06-30 15:24:00+03	37100.00
979189	2017-08-01 19:12:00+03	21400.00
9791C3	2017-07-30 22:36:00+03	121900.00
9791DC	2017-07-20 03:40:00+03	51000.00
9791E4	2017-07-12 04:04:00+03	8000.00
979330	2017-07-17 22:05:00+03	226000.00
97933E	2017-07-09 05:46:00+03	31100.00
979354	2017-06-28 04:01:00+03	277000.00
97944E	2017-08-08 01:59:00+03	62600.00
9794BB	2017-08-12 15:13:00+03	6700.00
9794BF	2017-07-22 22:34:00+03	133100.00
9794D0	2017-07-20 08:28:00+03	131100.00
9794ED	2017-07-25 22:45:00+03	56900.00
9794F3	2017-08-13 16:22:00+03	161100.00
979513	2017-08-14 12:11:00+03	92300.00
979539	2017-07-04 02:38:00+03	129400.00
97953C	2017-07-01 13:07:00+03	118200.00
9795BC	2017-08-12 06:24:00+03	55800.00
9795F0	2017-07-30 12:49:00+03	69000.00
97961D	2017-07-07 05:17:00+03	70100.00
9796A3	2017-07-21 08:37:00+03	62800.00
97970B	2017-08-01 08:09:00+03	75600.00
979712	2017-08-11 13:08:00+03	34000.00
97973B	2017-07-07 18:33:00+03	179200.00
979784	2017-07-27 18:24:00+03	55800.00
979793	2017-08-02 07:06:00+03	21400.00
9797D1	2017-08-07 06:12:00+03	117700.00
9797F6	2017-07-03 08:56:00+03	34000.00
97980D	2017-07-20 23:08:00+03	17200.00
979837	2017-07-11 17:43:00+03	60400.00
9798D6	2017-08-02 08:32:00+03	25100.00
9799DA	2017-07-19 13:24:00+03	196100.00
979A34	2017-06-28 07:18:00+03	112000.00
979A3D	2017-08-08 06:26:00+03	84700.00
979A67	2017-08-09 20:53:00+03	61800.00
979A99	2017-07-13 06:40:00+03	12600.00
979ABA	2017-07-31 17:42:00+03	26800.00
979B1C	2017-07-09 14:44:00+03	19600.00
979B20	2017-08-04 20:21:00+03	14800.00
979B56	2017-06-29 05:31:00+03	93000.00
979B71	2017-07-18 10:13:00+03	35800.00
979B81	2017-08-05 22:52:00+03	77400.00
979BB7	2017-08-06 07:31:00+03	102100.00
979C2F	2017-07-31 15:47:00+03	270800.00
979C59	2017-06-25 18:30:00+03	112600.00
979C8E	2017-07-15 05:38:00+03	93700.00
979C90	2017-08-13 01:44:00+03	84100.00
979CD5	2017-07-29 23:35:00+03	21400.00
979CE0	2017-07-24 02:19:00+03	105600.00
979CE3	2017-07-06 14:51:00+03	37200.00
979D2A	2017-07-31 14:55:00+03	56200.00
979D81	2017-07-01 15:56:00+03	118600.00
979D9A	2017-07-21 10:53:00+03	24700.00
979DB0	2017-08-07 14:02:00+03	58200.00
979E39	2017-08-03 14:02:00+03	102300.00
979E64	2017-08-05 17:55:00+03	123200.00
979F24	2017-08-14 20:31:00+03	11600.00
979F74	2017-07-28 18:27:00+03	23200.00
979F9D	2017-06-29 10:08:00+03	104800.00
979FAC	2017-08-04 06:56:00+03	65400.00
979FBB	2017-08-07 23:08:00+03	26200.00
979FC4	2017-07-09 12:21:00+03	13700.00
97A05D	2017-07-21 18:59:00+03	112000.00
97A0AF	2017-07-05 13:07:00+03	57600.00
97A109	2017-07-22 15:39:00+03	46200.00
97A163	2017-07-15 04:59:00+03	26800.00
97A1A3	2017-07-28 18:43:00+03	55400.00
97A28D	2017-08-05 23:47:00+03	56900.00
97A2B4	2017-07-28 23:15:00+03	20000.00
97A2D9	2017-07-28 02:57:00+03	8000.00
97A337	2017-07-11 22:44:00+03	41800.00
97A367	2017-08-05 19:39:00+03	50000.00
97A36A	2017-07-12 05:06:00+03	19600.00
97A380	2017-07-19 08:15:00+03	56200.00
97A401	2017-07-11 12:34:00+03	75000.00
97A4A9	2017-08-12 04:53:00+03	73300.00
97A4B4	2017-08-12 09:42:00+03	30800.00
97A4C4	2017-07-03 20:39:00+03	176400.00
97A501	2017-07-22 05:24:00+03	31400.00
97A509	2017-08-02 12:28:00+03	102800.00
97A52C	2017-07-27 10:29:00+03	123000.00
97A62A	2017-07-30 17:21:00+03	13200.00
97A656	2017-08-06 00:14:00+03	70800.00
97A70C	2017-07-30 03:41:00+03	28000.00
97A8C3	2017-07-29 14:24:00+03	10700.00
97A8E0	2017-07-29 18:05:00+03	26000.00
97A8EF	2017-08-01 16:21:00+03	184500.00
97A934	2017-08-04 21:25:00+03	78600.00
97AA18	2017-07-19 02:57:00+03	23200.00
97AAE1	2017-07-14 02:14:00+03	83000.00
97AAE3	2017-08-05 02:02:00+03	41200.00
97AB04	2017-07-22 23:43:00+03	136500.00
97AB0B	2017-07-16 20:33:00+03	102100.00
97AB16	2017-08-13 09:06:00+03	95600.00
97AB72	2017-06-27 02:03:00+03	88000.00
97ABA2	2017-08-03 10:32:00+03	66600.00
97ABAB	2017-08-08 12:27:00+03	43200.00
97ABD8	2017-07-11 06:13:00+03	92400.00
97AC0B	2017-07-23 13:24:00+03	14400.00
97AC28	2017-07-25 07:39:00+03	123000.00
97AC34	2017-07-31 19:08:00+03	66600.00
97AD8E	2017-08-10 19:53:00+03	64800.00
97ADC3	2017-07-18 19:35:00+03	55800.00
97AE02	2017-07-15 11:29:00+03	46400.00
97AE74	2017-07-21 21:02:00+03	14400.00
97AE97	2017-07-05 04:12:00+03	57700.00
97AF18	2017-08-09 20:25:00+03	56000.00
97AF63	2017-07-30 01:52:00+03	43100.00
97B03D	2017-07-09 23:37:00+03	136200.00
97B03F	2017-08-14 00:51:00+03	24000.00
97B052	2017-07-17 07:49:00+03	188000.00
97B060	2017-07-28 09:57:00+03	31100.00
97B06B	2017-07-21 13:59:00+03	169600.00
97B096	2017-07-15 03:36:00+03	82000.00
97B0DB	2017-08-15 00:50:00+03	26700.00
97B15A	2017-07-26 00:06:00+03	10100.00
97B169	2017-07-25 17:04:00+03	57400.00
97B181	2017-07-15 04:56:00+03	38600.00
97B1AA	2017-08-06 06:54:00+03	26800.00
97B1CD	2017-08-09 16:29:00+03	50700.00
97B348	2017-08-04 16:35:00+03	34400.00
97B3FE	2017-07-10 04:46:00+03	220600.00
97B44E	2017-07-17 19:59:00+03	111600.00
97B45A	2017-08-09 17:58:00+03	40000.00
97B4AF	2017-07-21 08:56:00+03	219700.00
97B517	2017-07-26 13:17:00+03	67700.00
97B578	2017-07-19 19:12:00+03	13400.00
97B5D9	2017-08-04 03:12:00+03	131100.00
97B5F2	2017-08-06 22:43:00+03	170500.00
97B621	2017-08-01 22:30:00+03	55600.00
97B643	2017-07-05 07:28:00+03	19600.00
97B64E	2017-07-07 17:27:00+03	78300.00
97B655	2017-07-21 01:00:00+03	26000.00
97B661	2017-08-09 10:02:00+03	32100.00
97B667	2017-08-07 10:02:00+03	100600.00
97B683	2017-07-04 07:37:00+03	101500.00
97B6A6	2017-07-09 03:34:00+03	66100.00
97B6B9	2017-07-26 01:21:00+03	28000.00
97B761	2017-08-07 20:56:00+03	86300.00
97B7EE	2017-07-31 17:59:00+03	154300.00
97B803	2017-08-12 21:15:00+03	67200.00
97B815	2017-08-02 19:54:00+03	306600.00
97B8F1	2017-07-29 16:35:00+03	6300.00
97B908	2017-07-19 19:17:00+03	133200.00
97B93B	2017-08-06 10:51:00+03	516800.00
97B96F	2017-08-14 02:28:00+03	68100.00
97B97E	2017-07-20 13:05:00+03	34200.00
97B9DB	2017-07-16 13:37:00+03	26000.00
97B9DC	2017-07-08 11:03:00+03	46200.00
97B9E0	2017-07-24 00:56:00+03	54500.00
97B9FE	2017-07-30 15:27:00+03	96200.00
97BA2D	2017-07-19 04:21:00+03	75300.00
97BAAF	2017-08-03 11:15:00+03	56200.00
97BB2E	2017-08-15 16:33:00+03	128800.00
97BB41	2017-07-11 07:43:00+03	179500.00
97BC4A	2017-08-12 13:07:00+03	250600.00
97BC72	2017-07-31 22:17:00+03	6700.00
97BCA7	2017-08-12 14:56:00+03	25800.00
97BCD7	2017-07-16 14:20:00+03	56900.00
97BCF7	2017-08-09 03:31:00+03	23200.00
97BD41	2017-07-09 02:52:00+03	34400.00
97BD71	2017-07-20 22:37:00+03	47100.00
97BE39	2017-07-03 10:11:00+03	111600.00
97BE8F	2017-07-23 08:48:00+03	28000.00
97BEA2	2017-08-06 14:34:00+03	46900.00
97BF41	2017-08-06 08:41:00+03	18600.00
97BF47	2017-08-14 08:10:00+03	94200.00
97BF4E	2017-08-15 12:58:00+03	77200.00
97BF52	2017-07-07 03:07:00+03	68000.00
97BFAA	2017-08-10 22:25:00+03	60700.00
97C07A	2017-07-15 22:02:00+03	19600.00
97C098	2017-07-03 06:05:00+03	47200.00
97C0A3	2017-07-22 23:06:00+03	40700.00
97C0D6	2017-08-14 07:15:00+03	26000.00
97C0E6	2017-07-07 12:00:00+03	67700.00
97C0FE	2017-07-11 20:05:00+03	59200.00
97C12F	2017-08-13 15:11:00+03	12000.00
97C13C	2017-08-03 09:57:00+03	24400.00
97C156	2017-08-13 03:08:00+03	28800.00
97C157	2017-06-27 12:50:00+03	40400.00
97C15C	2017-07-15 03:42:00+03	19600.00
97C181	2017-07-12 16:20:00+03	246000.00
97C1A0	2017-07-12 18:36:00+03	38600.00
97C1B9	2017-07-06 12:04:00+03	233800.00
97C218	2017-08-05 09:02:00+03	26000.00
97C24A	2017-07-12 17:16:00+03	283700.00
97C24B	2017-08-12 03:12:00+03	48200.00
97C266	2017-07-19 18:07:00+03	79900.00
97C294	2017-07-11 06:01:00+03	25800.00
97C2CD	2017-08-01 11:08:00+03	92100.00
97C2E2	2017-08-07 18:57:00+03	22000.00
97C2F3	2017-08-13 18:46:00+03	46200.00
97C31E	2017-06-27 23:58:00+03	386300.00
97C34B	2017-07-20 00:55:00+03	58200.00
97C35E	2017-08-09 19:05:00+03	126800.00
97C3AC	2017-07-24 00:38:00+03	49100.00
97C3D0	2017-07-26 07:21:00+03	89600.00
97C3E0	2017-07-11 05:46:00+03	92000.00
97C3FD	2017-07-02 10:40:00+03	39200.00
97C47D	2017-07-31 07:13:00+03	100600.00
97C492	2017-07-09 21:34:00+03	6000.00
97C4AA	2017-07-15 16:45:00+03	38500.00
97C4DC	2017-07-09 07:54:00+03	135400.00
97C503	2017-07-24 11:18:00+03	168000.00
97C58B	2017-07-21 22:24:00+03	191200.00
97C5B9	2017-07-06 17:21:00+03	45200.00
97C5BF	2017-07-11 00:29:00+03	19600.00
97C5F0	2017-07-08 07:26:00+03	51800.00
97C602	2017-07-08 23:10:00+03	184500.00
97C615	2017-08-02 11:55:00+03	25800.00
97C72F	2017-07-23 09:59:00+03	132800.00
97C7B4	2017-07-29 03:33:00+03	66600.00
97C7D0	2017-07-21 12:25:00+03	94500.00
97C892	2017-08-08 05:53:00+03	26700.00
97C945	2017-07-24 23:38:00+03	67600.00
97C977	2017-07-27 21:02:00+03	88000.00
97C97A	2017-07-20 06:29:00+03	72800.00
97C986	2017-07-20 15:05:00+03	170000.00
97C9D8	2017-07-06 05:26:00+03	24500.00
97C9E2	2017-08-15 13:48:00+03	31600.00
97CA4D	2017-08-14 01:49:00+03	27600.00
97CAA9	2017-08-04 18:44:00+03	14400.00
97CAB9	2017-07-02 23:42:00+03	26000.00
97CABB	2017-07-08 13:39:00+03	187600.00
97CAC2	2017-07-19 10:03:00+03	81700.00
97CB21	2017-08-04 16:56:00+03	71200.00
97CB30	2017-06-30 06:35:00+03	44500.00
97CB77	2017-07-22 03:01:00+03	58200.00
97CB89	2017-07-30 01:55:00+03	6800.00
97CBAD	2017-07-02 03:49:00+03	37200.00
97CBB1	2017-07-07 13:12:00+03	35200.00
97CBC9	2017-07-02 02:34:00+03	29600.00
97CC32	2017-08-11 00:33:00+03	55600.00
97CC6A	2017-07-05 12:08:00+03	167400.00
97CC71	2017-08-04 21:48:00+03	64500.00
97CC92	2017-07-30 03:51:00+03	69900.00
97CCA6	2017-07-01 09:28:00+03	167500.00
97CCC1	2017-08-06 14:43:00+03	153200.00
97CCEE	2017-07-07 00:12:00+03	58600.00
97CCF2	2017-06-30 06:21:00+03	35200.00
97CCF5	2017-07-28 05:11:00+03	84500.00
97CD0B	2017-07-22 07:51:00+03	244500.00
97CD30	2017-07-16 18:01:00+03	79000.00
97CD8E	2017-07-04 12:03:00+03	93900.00
97CDA7	2017-07-20 02:08:00+03	23600.00
97CDD5	2017-08-14 06:48:00+03	27400.00
97CDE7	2017-08-02 06:24:00+03	13700.00
97CE01	2017-07-16 03:03:00+03	66600.00
97CECD	2017-07-31 16:40:00+03	24400.00
97CEE3	2017-07-13 07:59:00+03	58900.00
97CEE6	2017-07-28 09:27:00+03	103200.00
97CEED	2017-07-14 13:18:00+03	85000.00
97CF22	2017-07-30 07:13:00+03	91600.00
97CF4F	2017-06-28 16:32:00+03	57200.00
97CF5A	2017-08-09 17:24:00+03	71900.00
97CF93	2017-08-08 19:37:00+03	45100.00
97CFA5	2017-07-21 05:58:00+03	62800.00
97CFD0	2017-07-26 15:04:00+03	56000.00
97CFD8	2017-08-10 08:23:00+03	54000.00
97D046	2017-07-10 22:10:00+03	56900.00
97D05B	2017-08-11 16:34:00+03	35700.00
97D066	2017-07-04 11:53:00+03	412400.00
97D0B9	2017-07-29 22:41:00+03	147200.00
97D0CA	2017-07-15 23:35:00+03	35400.00
97D0F0	2017-07-28 15:13:00+03	103500.00
97D12D	2017-08-09 14:33:00+03	24400.00
97D1B6	2017-07-24 05:34:00+03	77200.00
97D26A	2017-07-14 10:03:00+03	80400.00
97D282	2017-07-19 08:35:00+03	81300.00
97D28D	2017-07-13 08:00:00+03	138600.00
97D2FC	2017-08-04 15:55:00+03	64500.00
97D34E	2017-07-04 09:00:00+03	87400.00
97D34F	2017-08-08 22:40:00+03	133200.00
97D367	2017-07-20 10:48:00+03	95200.00
97D370	2017-08-09 21:42:00+03	45600.00
97D392	2017-07-30 14:50:00+03	106900.00
97D3BB	2017-07-06 00:55:00+03	13400.00
97D3FE	2017-08-11 05:26:00+03	30400.00
97D40A	2017-07-10 23:18:00+03	56000.00
97D427	2017-07-08 10:34:00+03	42800.00
97D42A	2017-08-01 21:06:00+03	92100.00
97D43E	2017-07-10 06:54:00+03	59900.00
97D443	2017-08-13 05:15:00+03	120400.00
97D46A	2017-07-29 22:18:00+03	32800.00
97D4AB	2017-07-13 05:07:00+03	34000.00
97D4DD	2017-08-13 23:06:00+03	37300.00
97D4EC	2017-07-13 19:56:00+03	48800.00
97D506	2017-07-08 05:51:00+03	37900.00
97D543	2017-07-03 07:58:00+03	67200.00
97D60A	2017-08-10 07:08:00+03	6800.00
97D63A	2017-08-08 22:55:00+03	24400.00
97D6C8	2017-08-13 00:48:00+03	126400.00
97D6CF	2017-08-11 05:45:00+03	26000.00
97D748	2017-08-15 13:07:00+03	123200.00
97D80C	2017-07-27 21:15:00+03	47200.00
97D812	2017-07-18 11:47:00+03	13400.00
97D82F	2017-07-09 01:21:00+03	28000.00
97D846	2017-08-08 09:19:00+03	29600.00
97D848	2017-07-18 00:04:00+03	410400.00
97D892	2017-08-05 08:25:00+03	56000.00
97D8C8	2017-08-08 20:47:00+03	62800.00
97D8D0	2017-07-02 00:55:00+03	98300.00
97D95F	2017-07-29 03:47:00+03	39800.00
97D971	2017-08-01 18:20:00+03	62600.00
97D9D5	2017-07-31 22:48:00+03	132800.00
97DA26	2017-07-13 16:30:00+03	52800.00
97DA36	2017-07-30 20:17:00+03	112000.00
97DB56	2017-07-25 19:50:00+03	28000.00
97DB6E	2017-07-25 19:00:00+03	13600.00
97DBFC	2017-07-19 17:16:00+03	43900.00
97DC03	2017-07-20 00:40:00+03	58600.00
97DC29	2017-08-08 16:57:00+03	64100.00
97DC95	2017-07-26 17:46:00+03	38600.00
97DCBD	2017-07-18 19:31:00+03	66800.00
97DCE2	2017-08-13 01:34:00+03	85500.00
97DCFD	2017-07-06 14:52:00+03	32800.00
97DD29	2017-07-06 20:22:00+03	56600.00
97DD43	2017-08-15 09:31:00+03	76100.00
97DDBB	2017-07-15 08:58:00+03	143100.00
97DDE7	2017-07-20 04:28:00+03	213200.00
97DE16	2017-07-27 20:38:00+03	64700.00
97DE6F	2017-07-15 11:51:00+03	95700.00
97DE74	2017-07-24 07:35:00+03	44000.00
97DEC7	2017-08-06 00:53:00+03	89600.00
97DEEF	2017-07-26 01:31:00+03	53600.00
97DF3A	2017-07-10 20:36:00+03	78800.00
97E03B	2017-07-12 03:56:00+03	137600.00
97E090	2017-08-09 15:32:00+03	24300.00
97E172	2017-08-05 08:27:00+03	26000.00
97E197	2017-07-29 00:55:00+03	148200.00
97E1C3	2017-08-07 05:49:00+03	113300.00
97E1F1	2017-07-22 10:19:00+03	27400.00
97E227	2017-07-11 09:35:00+03	387400.00
97E254	2017-08-13 07:03:00+03	60300.00
97E25B	2017-08-07 06:36:00+03	77400.00
97E279	2017-08-10 01:25:00+03	120100.00
97E2B7	2017-07-16 06:45:00+03	312000.00
97E318	2017-07-27 00:22:00+03	71900.00
97E338	2017-08-11 14:34:00+03	246000.00
97E33E	2017-08-15 00:11:00+03	188400.00
97E362	2017-08-05 11:25:00+03	58800.00
97E3F0	2017-07-26 01:52:00+03	106700.00
97E3F6	2017-08-14 09:51:00+03	56100.00
97E47A	2017-06-28 06:21:00+03	68000.00
97E4E7	2017-07-18 20:14:00+03	92000.00
97E57A	2017-07-20 17:33:00+03	32800.00
97E5CB	2017-06-30 09:56:00+03	25600.00
97E60F	2017-07-22 05:03:00+03	65900.00
97E666	2017-08-09 03:53:00+03	26800.00
97E6A7	2017-08-06 13:36:00+03	136400.00
97E7A4	2017-07-09 20:42:00+03	113000.00
97E7AC	2017-07-18 20:04:00+03	54800.00
97E7C6	2017-08-07 08:48:00+03	20400.00
97E814	2017-08-11 22:35:00+03	34000.00
97E823	2017-07-10 20:14:00+03	26000.00
97E882	2017-07-21 09:56:00+03	199700.00
97E8AA	2017-08-11 03:41:00+03	64800.00
97E8E2	2017-07-14 00:40:00+03	22100.00
97E966	2017-08-06 01:01:00+03	47400.00
97E9A7	2017-07-09 16:38:00+03	27900.00
97E9BF	2017-07-03 10:09:00+03	137600.00
97EA43	2017-07-27 03:08:00+03	8200.00
97EA51	2017-06-30 07:01:00+03	67600.00
97EABB	2017-07-21 07:47:00+03	59100.00
97EAE9	2017-07-13 12:03:00+03	70100.00
97EB95	2017-07-14 05:53:00+03	23600.00
97EBD1	2017-07-18 13:05:00+03	73600.00
97EBF2	2017-07-10 17:35:00+03	23400.00
97EC5A	2017-08-14 02:19:00+03	28000.00
97ED10	2017-07-06 01:35:00+03	30200.00
97ED66	2017-08-01 20:00:00+03	85000.00
97EDA0	2017-08-07 05:07:00+03	81200.00
97EDD4	2017-07-19 11:04:00+03	135400.00
97EDF5	2017-07-10 03:37:00+03	125200.00
97EEC5	2017-08-15 15:32:00+03	29900.00
97EF9B	2017-07-15 02:34:00+03	131600.00
97F006	2017-07-30 11:43:00+03	23600.00
97F02F	2017-07-26 15:57:00+03	111600.00
97F0D3	2017-08-05 10:01:00+03	31400.00
97F172	2017-07-20 01:41:00+03	29600.00
97F181	2017-07-17 23:54:00+03	90800.00
97F2DC	2017-07-05 18:18:00+03	13600.00
97F35B	2017-08-10 00:45:00+03	59400.00
97F361	2017-08-07 23:36:00+03	31600.00
97F3A0	2017-07-06 20:57:00+03	61800.00
97F3D5	2017-07-05 21:44:00+03	27400.00
97F4D5	2017-07-21 05:54:00+03	102100.00
97F4FD	2017-08-01 22:45:00+03	47000.00
97F5A4	2017-07-05 06:40:00+03	28000.00
97F609	2017-07-14 05:04:00+03	199700.00
97F60F	2017-07-20 23:57:00+03	12000.00
97F6E5	2017-07-23 19:06:00+03	56000.00
97F703	2017-07-28 17:38:00+03	28000.00
97F706	2017-08-12 14:21:00+03	73300.00
97F7B0	2017-08-13 01:38:00+03	11000.00
97F7C9	2017-07-04 01:55:00+03	26000.00
97F829	2017-07-28 20:24:00+03	26000.00
97F84C	2017-07-25 12:32:00+03	69100.00
97F890	2017-07-29 23:22:00+03	56000.00
97F8A3	2017-07-31 20:36:00+03	34000.00
97F8AB	2017-08-12 05:46:00+03	154500.00
97F8C7	2017-07-12 04:30:00+03	40000.00
97F8CE	2017-07-11 06:50:00+03	40600.00
97F8FA	2017-07-20 09:53:00+03	64700.00
97F916	2017-06-29 23:47:00+03	16400.00
97F918	2017-07-03 17:05:00+03	60200.00
97F97B	2017-07-23 15:58:00+03	59300.00
97F97F	2017-07-18 01:10:00+03	105000.00
97F9A0	2017-08-13 12:42:00+03	29800.00
97F9A5	2017-08-15 08:39:00+03	111600.00
97F9D0	2017-07-19 06:11:00+03	328800.00
97F9E4	2017-07-22 14:20:00+03	55400.00
97FA0A	2017-07-23 01:42:00+03	37800.00
97FA25	2017-07-02 05:15:00+03	65500.00
97FA31	2017-07-21 19:25:00+03	136200.00
97FA45	2017-08-02 04:48:00+03	17200.00
97FA79	2017-07-11 09:15:00+03	22600.00
97FAC0	2017-07-18 10:49:00+03	51000.00
97FAC4	2017-07-19 17:47:00+03	140100.00
97FB19	2017-07-22 01:30:00+03	531400.00
97FB58	2017-07-05 12:21:00+03	24400.00
97FBC6	2017-07-31 23:21:00+03	12200.00
97FBFE	2017-08-10 16:14:00+03	18000.00
97FC56	2017-07-03 19:16:00+03	59000.00
97FCC3	2017-08-05 18:42:00+03	21800.00
97FD18	2017-07-11 08:18:00+03	113800.00
97FD50	2017-07-27 00:47:00+03	93900.00
97FD6F	2017-08-15 05:49:00+03	14800.00
97FDCA	2017-07-13 07:55:00+03	41400.00
97FDCB	2017-08-09 23:49:00+03	26200.00
97FDDA	2017-08-10 13:37:00+03	28800.00
97FDEC	2017-07-08 18:21:00+03	14000.00
97FE1A	2017-07-28 22:47:00+03	16400.00
97FE81	2017-08-13 17:52:00+03	31400.00
97FE8B	2017-07-13 05:44:00+03	184200.00
97FEE6	2017-07-08 00:20:00+03	43000.00
97FF5A	2017-07-06 01:10:00+03	43600.00
97FF70	2017-07-20 14:29:00+03	124200.00
97FF96	2017-08-09 00:59:00+03	13800.00
97FFD5	2017-08-05 03:14:00+03	93600.00
98007B	2017-08-03 18:43:00+03	58200.00
980090	2017-07-04 18:28:00+03	104600.00
980094	2017-07-12 03:24:00+03	29300.00
9800ED	2017-08-15 05:28:00+03	49400.00
980103	2017-07-11 17:07:00+03	7400.00
980128	2017-07-01 17:29:00+03	46000.00
98015D	2017-07-05 06:49:00+03	42800.00
980175	2017-07-14 02:25:00+03	56000.00
980190	2017-07-12 17:48:00+03	14400.00
980193	2017-07-14 17:44:00+03	186900.00
980199	2017-06-29 01:25:00+03	41400.00
9801B6	2017-07-17 11:09:00+03	23200.00
9801DE	2017-07-14 00:26:00+03	123000.00
9801FB	2017-07-07 00:19:00+03	56000.00
980224	2017-07-09 12:10:00+03	39100.00
98025D	2017-08-01 21:49:00+03	68800.00
980260	2017-07-11 05:09:00+03	122000.00
9802B5	2017-07-28 18:34:00+03	32800.00
9802D0	2017-07-29 15:34:00+03	59800.00
9802D5	2017-08-15 15:55:00+03	6800.00
9802D8	2017-07-13 19:44:00+03	23200.00
9803B8	2017-07-14 04:16:00+03	85000.00
9803CB	2017-08-10 19:01:00+03	55600.00
98044F	2017-07-08 22:59:00+03	136800.00
980481	2017-07-15 17:12:00+03	96300.00
9804A4	2017-08-13 11:52:00+03	12000.00
9804C6	2017-08-09 18:28:00+03	63200.00
9804C7	2017-07-30 15:32:00+03	46400.00
980572	2017-08-08 13:43:00+03	75300.00
9805D0	2017-08-02 09:34:00+03	402100.00
980691	2017-07-01 19:55:00+03	11600.00
98069C	2017-08-12 08:22:00+03	55000.00
9806A2	2017-08-09 22:54:00+03	28800.00
9806AF	2017-07-16 00:07:00+03	94300.00
9806BA	2017-08-08 03:01:00+03	86600.00
980787	2017-08-06 04:47:00+03	394900.00
9807A4	2017-08-04 01:49:00+03	105600.00
9807B5	2017-07-03 07:23:00+03	81800.00
98081E	2017-08-04 21:14:00+03	58800.00
980827	2017-07-20 07:50:00+03	20000.00
980858	2017-07-30 06:43:00+03	49000.00
98085F	2017-08-15 09:55:00+03	22600.00
9808AB	2017-07-07 08:00:00+03	14000.00
980965	2017-08-10 22:46:00+03	116000.00
980999	2017-06-29 23:30:00+03	70800.00
9809AA	2017-08-10 15:59:00+03	28000.00
9809BE	2017-08-15 06:39:00+03	34300.00
9809CE	2017-07-21 12:43:00+03	46400.00
9809FC	2017-07-17 02:46:00+03	27800.00
980A73	2017-07-01 02:23:00+03	112000.00
980A90	2017-08-08 20:56:00+03	46400.00
980A94	2017-07-20 02:46:00+03	369000.00
980BA9	2017-07-06 18:57:00+03	28800.00
980BCC	2017-08-07 18:16:00+03	88900.00
980BDE	2017-07-07 13:25:00+03	98300.00
980C98	2017-07-24 16:36:00+03	26000.00
980C9E	2017-08-15 01:27:00+03	20400.00
980CBB	2017-08-09 20:56:00+03	62800.00
980CFF	2017-08-12 19:54:00+03	25600.00
980D6F	2017-07-11 17:07:00+03	12000.00
980DA3	2017-08-15 01:15:00+03	21800.00
980DB4	2017-07-21 20:42:00+03	94700.00
980DC8	2017-08-01 02:09:00+03	67100.00
980DE0	2017-06-26 06:40:00+03	65900.00
980DEC	2017-07-31 07:20:00+03	40400.00
980E29	2017-08-05 18:40:00+03	99200.00
980E34	2017-07-15 08:25:00+03	100000.00
980E6E	2017-07-08 13:15:00+03	265600.00
980EA0	2017-07-27 18:44:00+03	272600.00
980EA4	2017-07-12 07:16:00+03	225200.00
980FF8	2017-07-04 00:36:00+03	73500.00
980FFD	2017-08-02 09:48:00+03	136800.00
9810D0	2017-07-21 17:09:00+03	141600.00
9810EE	2017-07-10 07:37:00+03	31900.00
9810EF	2017-08-11 07:44:00+03	242300.00
9810F5	2017-07-25 22:32:00+03	84100.00
9810FF	2017-07-10 11:01:00+03	31800.00
981109	2017-08-11 08:44:00+03	32700.00
981188	2017-07-28 16:58:00+03	58700.00
981201	2017-07-10 08:40:00+03	292000.00
981209	2017-07-03 01:46:00+03	53600.00
98126B	2017-07-27 01:27:00+03	63600.00
981283	2017-07-14 03:23:00+03	24400.00
98129A	2017-07-25 04:15:00+03	70700.00
9812FC	2017-07-09 04:07:00+03	7400.00
981321	2017-07-04 02:06:00+03	57500.00
981324	2017-07-02 20:12:00+03	88600.00
98134C	2017-08-01 17:02:00+03	167400.00
98136C	2017-07-19 14:13:00+03	28800.00
9813A2	2017-07-03 22:16:00+03	25600.00
9813CA	2017-08-04 11:54:00+03	6300.00
981456	2017-07-18 08:54:00+03	58600.00
98149C	2017-08-11 06:31:00+03	206400.00
9814AD	2017-08-03 02:11:00+03	46000.00
9814BB	2017-07-13 16:15:00+03	60400.00
9814EE	2017-07-08 07:23:00+03	187600.00
9814F0	2017-07-14 14:21:00+03	289800.00
98153E	2017-07-27 15:17:00+03	25600.00
981548	2017-08-08 17:45:00+03	6000.00
981552	2017-08-03 23:13:00+03	141600.00
98159A	2017-07-21 19:12:00+03	6800.00
9815E4	2017-07-20 14:57:00+03	67400.00
981661	2017-07-06 19:17:00+03	28000.00
9816C6	2017-07-24 07:49:00+03	240600.00
9816D2	2017-07-06 08:52:00+03	23200.00
9816EF	2017-07-14 11:36:00+03	262200.00
981701	2017-07-02 14:15:00+03	81300.00
981720	2017-07-30 08:59:00+03	27800.00
98176C	2017-07-10 17:56:00+03	27900.00
981794	2017-08-03 06:52:00+03	61500.00
9817C4	2017-08-07 08:37:00+03	88700.00
9817D7	2017-08-09 13:47:00+03	26800.00
9818A8	2017-08-06 07:21:00+03	68800.00
9818CF	2017-07-01 08:07:00+03	32200.00
9818EB	2017-07-03 04:35:00+03	124200.00
9818FA	2017-06-30 22:57:00+03	92600.00
981919	2017-08-13 20:41:00+03	27800.00
9819D9	2017-07-29 03:20:00+03	138000.00
9819DC	2017-07-12 21:24:00+03	71900.00
981A18	2017-07-11 03:40:00+03	189200.00
981A26	2017-08-09 16:18:00+03	84500.00
981A7F	2017-08-12 23:41:00+03	76600.00
981A80	2017-07-03 18:55:00+03	235200.00
981B2A	2017-08-05 16:27:00+03	58000.00
981B74	2017-08-02 00:18:00+03	17000.00
981B98	2017-07-13 09:57:00+03	8200.00
981BDD	2017-07-16 18:21:00+03	100600.00
981BFB	2017-07-07 22:29:00+03	20400.00
981C50	2017-07-30 11:27:00+03	37900.00
981C6A	2017-08-13 14:34:00+03	40200.00
981CC9	2017-06-30 13:29:00+03	27800.00
981D0C	2017-08-06 16:35:00+03	40600.00
981D20	2017-06-24 19:16:00+03	240600.00
981D45	2017-07-24 11:44:00+03	231400.00
981D69	2017-06-28 11:11:00+03	89600.00
981DC5	2017-07-15 15:01:00+03	58800.00
981DD7	2017-07-28 02:43:00+03	252200.00
981E01	2017-07-29 16:34:00+03	8200.00
981E6D	2017-07-04 23:58:00+03	109800.00
981E78	2017-08-03 06:02:00+03	69100.00
981E9A	2017-08-15 13:55:00+03	186900.00
981EB1	2017-07-07 16:43:00+03	361600.00
981EDF	2017-07-26 17:49:00+03	40800.00
981F00	2017-07-02 10:46:00+03	98200.00
981FF2	2017-07-03 13:55:00+03	125600.00
982091	2017-07-28 20:45:00+03	32800.00
98209E	2017-08-05 21:26:00+03	92000.00
9820A5	2017-08-12 16:28:00+03	111600.00
982149	2017-08-05 07:02:00+03	56000.00
982156	2017-08-15 05:05:00+03	59000.00
98217B	2017-07-10 23:33:00+03	40600.00
982197	2017-07-21 17:01:00+03	48500.00
9821B5	2017-08-02 03:28:00+03	355000.00
982291	2017-07-22 05:26:00+03	189200.00
9822C9	2017-08-05 07:08:00+03	62800.00
9822DE	2017-07-24 00:16:00+03	97900.00
982302	2017-07-11 03:30:00+03	52300.00
98234A	2017-07-03 03:16:00+03	58900.00
9823A0	2017-08-07 02:51:00+03	46300.00
9823FC	2017-07-21 14:47:00+03	67000.00
982455	2017-08-11 07:35:00+03	106400.00
982466	2017-07-13 15:49:00+03	56600.00
982527	2017-07-13 10:11:00+03	165500.00
982576	2017-08-10 05:55:00+03	26800.00
98258B	2017-08-07 07:11:00+03	28800.00
9825B6	2017-08-11 17:31:00+03	27600.00
9825FC	2017-08-15 05:15:00+03	77400.00
982610	2017-08-13 12:37:00+03	178000.00
982640	2017-07-08 21:30:00+03	36900.00
98264D	2017-07-14 07:34:00+03	270800.00
98265F	2017-07-01 22:13:00+03	7300.00
98266C	2017-08-10 11:52:00+03	68800.00
98267B	2017-07-15 12:20:00+03	70600.00
982696	2017-07-24 00:33:00+03	26700.00
9826D4	2017-08-03 00:16:00+03	51300.00
982732	2017-08-02 13:31:00+03	21400.00
98275E	2017-08-10 14:25:00+03	42800.00
9827E2	2017-07-11 02:50:00+03	57000.00
9827FB	2017-08-13 18:30:00+03	38400.00
982858	2017-08-06 07:03:00+03	147200.00
9828B7	2017-07-17 15:37:00+03	178300.00
9828F2	2017-07-02 22:10:00+03	62600.00
9829A9	2017-07-27 06:36:00+03	90800.00
982A71	2017-08-12 07:41:00+03	38800.00
982A83	2017-07-29 20:36:00+03	47400.00
982AE1	2017-07-21 19:52:00+03	50400.00
982AE9	2017-07-12 20:12:00+03	31100.00
982B1A	2017-07-16 22:12:00+03	92800.00
982B62	2017-07-17 08:07:00+03	29600.00
982BC3	2017-07-23 13:32:00+03	15100.00
982C7D	2017-07-29 15:19:00+03	124200.00
982C81	2017-06-25 16:25:00+03	30200.00
982CBA	2017-08-13 04:34:00+03	96200.00
982D27	2017-07-28 00:16:00+03	111600.00
982D29	2017-08-13 22:32:00+03	39100.00
982E31	2017-07-02 03:11:00+03	30200.00
982E7D	2017-08-06 00:34:00+03	68900.00
982EF5	2017-08-14 06:49:00+03	125100.00
982F0F	2017-07-15 07:50:00+03	12600.00
982F1E	2017-08-15 03:29:00+03	199700.00
982F5B	2017-07-11 04:42:00+03	46400.00
982F8E	2017-07-15 04:47:00+03	140800.00
982F95	2017-07-22 10:19:00+03	28000.00
982FBE	2017-08-12 23:08:00+03	52700.00
983062	2017-07-16 12:09:00+03	87900.00
98313B	2017-07-22 20:53:00+03	265700.00
983142	2017-08-06 00:48:00+03	16400.00
9831B2	2017-08-04 07:59:00+03	257500.00
9831B3	2017-07-07 23:07:00+03	66600.00
983202	2017-07-23 21:39:00+03	9800.00
983214	2017-07-06 03:36:00+03	73500.00
9832A5	2017-08-02 22:25:00+03	54800.00
98339F	2017-08-04 23:04:00+03	100700.00
9833AD	2017-07-17 10:34:00+03	25400.00
9833D2	2017-08-15 01:49:00+03	133200.00
9833D7	2017-08-02 10:10:00+03	31200.00
983400	2017-07-18 06:24:00+03	143100.00
983411	2017-08-09 21:47:00+03	6700.00
98342E	2017-08-02 18:18:00+03	8000.00
98344B	2017-08-13 21:36:00+03	52300.00
9834AD	2017-07-14 14:30:00+03	480500.00
9834AE	2017-07-22 20:39:00+03	266400.00
9834B1	2017-07-24 18:15:00+03	119600.00
9834BE	2017-07-21 08:49:00+03	66800.00
983516	2017-08-04 01:26:00+03	86600.00
983589	2017-07-09 05:26:00+03	28000.00
98363C	2017-08-11 19:35:00+03	14800.00
9836AD	2017-08-06 11:10:00+03	23200.00
9836DB	2017-07-03 15:34:00+03	80600.00
9836E9	2017-08-12 01:23:00+03	66800.00
98370D	2017-07-19 15:29:00+03	35200.00
98372B	2017-07-31 21:30:00+03	32200.00
983759	2017-07-09 09:38:00+03	62600.00
983770	2017-07-09 12:08:00+03	47000.00
9837A5	2017-07-17 05:47:00+03	44000.00
9837AA	2017-08-02 07:12:00+03	76600.00
983820	2017-07-12 10:15:00+03	120800.00
983867	2017-07-07 05:19:00+03	532800.00
98387A	2017-07-15 08:14:00+03	38200.00
9838CA	2017-07-20 20:40:00+03	36000.00
9838CD	2017-07-05 08:07:00+03	181600.00
98393D	2017-08-08 19:48:00+03	399600.00
983945	2017-08-01 14:23:00+03	7400.00
983970	2017-08-11 09:48:00+03	7400.00
98399B	2017-07-18 09:20:00+03	40800.00
983A5B	2017-07-12 05:28:00+03	103000.00
983BB0	2017-07-14 02:27:00+03	73600.00
983BB1	2017-08-01 13:10:00+03	49000.00
983BE2	2017-07-05 02:38:00+03	65600.00
983C31	2017-07-13 11:43:00+03	111600.00
983D53	2017-07-25 11:08:00+03	119800.00
983D73	2017-06-29 03:30:00+03	246000.00
983D85	2017-07-30 04:04:00+03	55800.00
983D8F	2017-07-01 19:30:00+03	52000.00
983DBF	2017-08-01 07:54:00+03	13200.00
983DEA	2017-07-19 13:58:00+03	19600.00
983E76	2017-07-18 16:41:00+03	26800.00
983EA7	2017-07-30 18:11:00+03	27200.00
983EBC	2017-08-14 03:25:00+03	78100.00
983EC0	2017-08-02 09:57:00+03	25200.00
983EDD	2017-07-19 21:37:00+03	47100.00
983EF6	2017-07-17 17:44:00+03	258400.00
983F0E	2017-07-12 22:26:00+03	78000.00
983F5C	2017-07-20 17:36:00+03	12100.00
983F68	2017-07-23 11:57:00+03	52300.00
983F93	2017-07-21 14:03:00+03	86500.00
983FB5	2017-07-22 10:39:00+03	112000.00
98402C	2017-07-10 19:36:00+03	396400.00
98409F	2017-08-05 20:58:00+03	23600.00
9841AB	2017-07-10 05:29:00+03	62600.00
9841C7	2017-07-28 04:14:00+03	28000.00
9841E4	2017-07-03 06:38:00+03	28000.00
9841F4	2017-07-06 18:13:00+03	81600.00
9841FB	2017-07-15 16:08:00+03	23200.00
984236	2017-07-08 15:51:00+03	64500.00
984255	2017-07-24 17:34:00+03	14800.00
9842FC	2017-07-17 02:19:00+03	81300.00
98438B	2017-08-03 01:32:00+03	59300.00
984394	2017-08-13 14:03:00+03	12600.00
9843A8	2017-07-23 08:59:00+03	40200.00
98445B	2017-08-03 03:38:00+03	47000.00
9844DD	2017-07-31 18:18:00+03	42800.00
9844FB	2017-07-20 16:45:00+03	49100.00
98450E	2017-07-21 17:24:00+03	73600.00
984511	2017-08-11 14:21:00+03	184000.00
98453A	2017-08-02 08:31:00+03	30200.00
984540	2017-07-07 14:38:00+03	66600.00
9845B1	2017-06-29 21:31:00+03	46200.00
9845B2	2017-07-20 13:32:00+03	19800.00
984623	2017-08-01 15:20:00+03	314400.00
984680	2017-07-26 22:46:00+03	10800.00
98475C	2017-07-09 02:33:00+03	59800.00
984770	2017-07-28 10:36:00+03	286100.00
984789	2017-07-15 21:37:00+03	40600.00
9847AD	2017-08-02 06:26:00+03	17600.00
98480E	2017-07-04 02:58:00+03	6900.00
98481A	2017-08-01 08:41:00+03	384800.00
984829	2017-07-01 18:54:00+03	92700.00
984866	2017-08-14 19:45:00+03	41400.00
98486A	2017-07-16 16:16:00+03	41600.00
98487A	2017-07-04 01:36:00+03	43500.00
98494D	2017-08-09 17:20:00+03	42900.00
98495C	2017-08-13 11:55:00+03	70700.00
984963	2017-07-15 10:21:00+03	13200.00
98497E	2017-07-13 03:54:00+03	27800.00
98499C	2017-08-14 04:16:00+03	123000.00
9849A3	2017-07-10 14:58:00+03	56000.00
9849A4	2017-07-11 13:17:00+03	56000.00
9849C9	2017-07-10 16:48:00+03	75300.00
9849D4	2017-07-12 00:43:00+03	26100.00
984A5A	2017-07-31 22:55:00+03	62800.00
984AC8	2017-08-15 08:01:00+03	14800.00
984B59	2017-07-03 10:16:00+03	80900.00
984BD0	2017-07-03 07:58:00+03	11200.00
984BEA	2017-07-11 02:25:00+03	20400.00
984C16	2017-07-05 00:58:00+03	21800.00
984C58	2017-07-08 15:20:00+03	134400.00
984C8E	2017-08-12 08:47:00+03	42600.00
984D03	2017-08-04 18:22:00+03	66600.00
984D4F	2017-07-08 05:13:00+03	34000.00
984E27	2017-07-09 16:06:00+03	72800.00
984E30	2017-07-28 06:35:00+03	24800.00
984E67	2017-07-18 15:17:00+03	58800.00
984E93	2017-08-12 00:24:00+03	28800.00
984F95	2017-07-26 04:34:00+03	85000.00
984F99	2017-07-01 04:32:00+03	33100.00
985103	2017-07-10 18:36:00+03	101200.00
985118	2017-07-25 05:59:00+03	66600.00
985168	2017-08-04 01:26:00+03	125200.00
9851C3	2017-08-09 18:54:00+03	265600.00
985212	2017-07-06 10:43:00+03	81700.00
985214	2017-07-08 23:45:00+03	12600.00
98522B	2017-07-09 13:19:00+03	72800.00
985238	2017-07-13 02:09:00+03	27800.00
98524C	2017-07-31 08:14:00+03	20800.00
9852C3	2017-07-27 18:29:00+03	69000.00
98530C	2017-07-03 20:02:00+03	92800.00
98537E	2017-07-22 14:00:00+03	123000.00
9853CD	2017-07-08 10:01:00+03	19600.00
985436	2017-07-21 10:55:00+03	81600.00
985442	2017-07-27 16:02:00+03	69500.00
985446	2017-07-16 09:05:00+03	60700.00
985465	2017-07-16 01:50:00+03	199700.00
98546D	2017-07-14 13:30:00+03	19600.00
9854E2	2017-07-26 14:05:00+03	24000.00
98558B	2017-06-29 00:49:00+03	89300.00
98559C	2017-07-20 12:50:00+03	43500.00
9855C4	2017-07-06 17:05:00+03	49700.00
9855F8	2017-07-13 05:02:00+03	22000.00
985631	2017-07-11 00:25:00+03	56000.00
985648	2017-07-30 09:22:00+03	27200.00
985696	2017-07-17 05:26:00+03	11600.00
985729	2017-08-07 07:22:00+03	57500.00
985736	2017-08-10 09:59:00+03	67600.00
985761	2017-07-07 17:18:00+03	20400.00
985769	2017-07-09 08:10:00+03	46000.00
985797	2017-07-14 08:07:00+03	260900.00
9857A4	2017-07-18 16:13:00+03	23600.00
9857C5	2017-08-07 17:54:00+03	43700.00
9857CE	2017-08-02 22:46:00+03	236000.00
9857D5	2017-07-22 08:48:00+03	28800.00
985810	2017-08-13 13:20:00+03	51400.00
985836	2017-07-22 00:22:00+03	135600.00
98585B	2017-07-29 20:51:00+03	81200.00
985875	2017-08-07 12:55:00+03	19200.00
985898	2017-07-17 09:42:00+03	22000.00
9858B1	2017-07-12 22:22:00+03	10700.00
9858F2	2017-07-30 20:26:00+03	52300.00
985902	2017-07-29 18:14:00+03	48400.00
985912	2017-08-01 02:14:00+03	101900.00
985915	2017-07-14 03:28:00+03	64200.00
985991	2017-08-12 14:00:00+03	32800.00
9859E6	2017-08-14 01:02:00+03	128800.00
985A45	2017-08-12 17:51:00+03	65900.00
985A6A	2017-08-12 09:54:00+03	28000.00
985A88	2017-07-17 00:17:00+03	71700.00
985A92	2017-07-02 07:48:00+03	208100.00
985B5C	2017-07-24 20:36:00+03	48800.00
985B69	2017-08-09 09:41:00+03	79600.00
985B70	2017-07-27 13:35:00+03	24400.00
985BAE	2017-07-25 02:16:00+03	70600.00
985C02	2017-07-15 00:40:00+03	88100.00
985C05	2017-08-15 12:25:00+03	54500.00
985C19	2017-08-11 01:00:00+03	26000.00
985C69	2017-08-09 11:57:00+03	15900.00
985C9C	2017-07-05 13:53:00+03	26800.00
985D05	2017-08-14 22:45:00+03	67500.00
985D2A	2017-08-13 01:43:00+03	36200.00
985D98	2017-06-28 11:43:00+03	32700.00
985DAC	2017-07-27 21:53:00+03	148200.00
985DB8	2017-07-29 17:26:00+03	89600.00
985DC8	2017-08-07 08:24:00+03	99200.00
985DE8	2017-08-12 22:34:00+03	70700.00
985DF9	2017-08-05 19:29:00+03	24400.00
985DFF	2017-08-05 23:21:00+03	94000.00
985E60	2017-08-10 02:02:00+03	77200.00
985EB7	2017-08-06 02:35:00+03	17000.00
985ED7	2017-07-02 08:19:00+03	138500.00
985ED8	2017-07-24 14:48:00+03	27200.00
985EEC	2017-07-13 19:48:00+03	102100.00
985F5E	2017-07-06 20:25:00+03	40200.00
985F5F	2017-07-14 09:16:00+03	137600.00
985FF8	2017-07-03 18:07:00+03	61800.00
98603B	2017-08-02 05:50:00+03	484100.00
986042	2017-08-11 07:46:00+03	72400.00
98608E	2017-07-23 21:43:00+03	91200.00
9860C3	2017-07-12 21:22:00+03	66600.00
986116	2017-07-18 15:52:00+03	59300.00
986233	2017-07-26 20:53:00+03	69000.00
98636E	2017-07-12 02:00:00+03	133100.00
9863EE	2017-07-10 18:52:00+03	46400.00
986412	2017-08-15 17:26:00+03	37200.00
98651D	2017-08-03 06:40:00+03	24000.00
986564	2017-08-08 16:32:00+03	31600.00
986581	2017-07-03 17:28:00+03	36200.00
9865EF	2017-06-30 19:53:00+03	46000.00
98661B	2017-08-14 04:02:00+03	67600.00
986625	2017-06-30 14:42:00+03	40200.00
986629	2017-08-07 12:20:00+03	123200.00
9866D7	2017-08-05 22:39:00+03	57400.00
986717	2017-07-07 09:10:00+03	53700.00
98671C	2017-07-12 15:11:00+03	91500.00
986740	2017-07-05 11:20:00+03	47200.00
986754	2017-07-25 00:45:00+03	24400.00
986782	2017-07-22 10:18:00+03	56000.00
986868	2017-07-25 04:05:00+03	86600.00
9868DF	2017-07-31 15:45:00+03	21800.00
9868F6	2017-08-06 14:45:00+03	34000.00
986934	2017-07-19 14:35:00+03	75300.00
986A85	2017-07-27 21:18:00+03	83800.00
986ABB	2017-07-11 16:33:00+03	38200.00
986B39	2017-07-09 22:48:00+03	14000.00
986B3B	2017-07-06 02:03:00+03	26000.00
986B4C	2017-07-14 23:48:00+03	34800.00
986BAE	2017-07-22 07:19:00+03	46800.00
986BBE	2017-07-09 14:00:00+03	30000.00
986BFD	2017-07-11 03:25:00+03	88500.00
986CAA	2017-07-04 16:57:00+03	40800.00
986CB3	2017-08-15 00:04:00+03	99200.00
986CBD	2017-08-01 01:55:00+03	13400.00
986CDB	2017-06-25 00:49:00+03	28000.00
986D19	2017-08-07 04:13:00+03	28000.00
986D3F	2017-07-11 15:38:00+03	13600.00
986D40	2017-08-02 17:04:00+03	38300.00
986D86	2017-08-01 12:30:00+03	21800.00
986DCC	2017-06-28 00:58:00+03	33000.00
986E1B	2017-07-28 17:10:00+03	411300.00
986E36	2017-08-12 23:19:00+03	136200.00
986F04	2017-08-13 19:29:00+03	270800.00
986F48	2017-08-13 07:52:00+03	48800.00
986F53	2017-08-13 09:21:00+03	86400.00
986F74	2017-08-13 11:33:00+03	65900.00
986FB2	2017-08-01 14:46:00+03	125800.00
986FC5	2017-08-11 04:57:00+03	99600.00
986FD0	2017-07-07 08:03:00+03	36200.00
986FD6	2017-07-29 17:00:00+03	147700.00
986FDF	2017-07-27 19:03:00+03	40400.00
986FFE	2017-08-10 19:54:00+03	70800.00
987013	2017-07-14 05:11:00+03	123000.00
987084	2017-07-24 04:14:00+03	55800.00
9870F3	2017-08-08 03:16:00+03	75700.00
987148	2017-08-01 08:17:00+03	135600.00
98716D	2017-08-02 18:28:00+03	30000.00
9871A2	2017-08-08 18:21:00+03	67600.00
9871BA	2017-07-28 07:08:00+03	406700.00
9871C2	2017-08-04 00:50:00+03	118100.00
987240	2017-07-27 05:37:00+03	243700.00
98730B	2017-08-04 22:40:00+03	45200.00
98732C	2017-07-02 02:28:00+03	39900.00
987352	2017-07-24 05:31:00+03	134700.00
98735F	2017-07-10 21:59:00+03	52000.00
987395	2017-08-13 23:03:00+03	99400.00
9873AA	2017-07-25 23:31:00+03	99600.00
987425	2017-08-08 05:42:00+03	153600.00
987440	2017-07-12 05:54:00+03	56000.00
987478	2017-07-22 08:43:00+03	67700.00
987482	2017-08-14 09:54:00+03	86800.00
987492	2017-08-09 05:09:00+03	27800.00
98749A	2017-08-08 11:21:00+03	117200.00
9874A9	2017-08-08 17:42:00+03	114800.00
9874D3	2017-08-13 22:13:00+03	21400.00
9874E1	2017-08-06 19:55:00+03	132500.00
9874EC	2017-07-06 04:03:00+03	46400.00
98753C	2017-08-09 06:01:00+03	21800.00
9875A2	2017-08-04 14:34:00+03	179400.00
98763D	2017-08-09 11:24:00+03	48400.00
987680	2017-07-22 11:20:00+03	40000.00
9876A7	2017-07-08 01:19:00+03	58400.00
98773F	2017-08-08 05:54:00+03	56000.00
987764	2017-08-06 16:42:00+03	113600.00
98776D	2017-07-16 11:30:00+03	116500.00
98777E	2017-08-09 08:10:00+03	28000.00
9877B7	2017-08-08 12:54:00+03	193200.00
987808	2017-07-02 18:57:00+03	103400.00
98780E	2017-07-21 04:27:00+03	98400.00
987820	2017-07-14 23:34:00+03	63500.00
987855	2017-07-20 10:42:00+03	148200.00
987912	2017-07-26 01:54:00+03	52800.00
987922	2017-07-11 09:33:00+03	176800.00
9879B4	2017-07-08 13:50:00+03	36200.00
9879DE	2017-07-29 21:20:00+03	229600.00
987B33	2017-07-31 01:19:00+03	115700.00
987B3F	2017-07-22 14:46:00+03	19000.00
987B6B	2017-07-24 17:25:00+03	70500.00
987BC3	2017-07-25 21:23:00+03	81600.00
987C0B	2017-07-31 20:24:00+03	61800.00
987C0E	2017-07-09 11:08:00+03	86800.00
987C2F	2017-08-10 14:30:00+03	21000.00
987C55	2017-08-03 23:07:00+03	166700.00
987D0E	2017-07-10 04:56:00+03	43200.00
987D6D	2017-07-31 19:11:00+03	32800.00
987DBC	2017-07-16 11:42:00+03	229900.00
987DE6	2017-07-06 06:20:00+03	21800.00
987E0B	2017-08-09 06:39:00+03	66200.00
987E22	2017-07-08 17:39:00+03	67600.00
987E47	2017-07-10 17:42:00+03	23200.00
987E62	2017-08-07 14:59:00+03	266400.00
987E94	2017-07-21 13:26:00+03	65500.00
987EA8	2017-07-25 01:54:00+03	25200.00
987ED8	2017-07-19 23:36:00+03	56000.00
987EE9	2017-07-15 14:13:00+03	75600.00
987F71	2017-07-20 00:06:00+03	45100.00
987FDA	2017-07-12 19:47:00+03	8400.00
988026	2017-07-11 10:09:00+03	41400.00
988079	2017-07-04 02:18:00+03	26000.00
988089	2017-07-20 04:01:00+03	72400.00
988094	2017-07-10 16:48:00+03	15000.00
9880AB	2017-06-30 00:43:00+03	164500.00
9880D9	2017-08-09 10:22:00+03	26800.00
988126	2017-07-07 10:58:00+03	46400.00
98816D	2017-07-19 12:51:00+03	83000.00
9881C5	2017-07-17 02:09:00+03	65400.00
9881D0	2017-07-15 13:29:00+03	139500.00
9881D8	2017-07-02 22:38:00+03	66600.00
9882C0	2017-08-10 15:37:00+03	35300.00
9882D2	2017-07-17 10:35:00+03	11000.00
988302	2017-07-28 12:38:00+03	56600.00
988355	2017-07-25 01:08:00+03	46400.00
98848E	2017-07-09 09:33:00+03	79900.00
988499	2017-07-27 15:04:00+03	56000.00
9884FD	2017-07-20 07:37:00+03	44000.00
988545	2017-07-30 09:15:00+03	70600.00
988583	2017-07-28 19:23:00+03	36200.00
988585	2017-07-18 12:44:00+03	39800.00
9885F5	2017-08-14 07:14:00+03	44200.00
9885FC	2017-08-11 11:20:00+03	75600.00
98861F	2017-08-14 19:12:00+03	6800.00
988624	2017-07-20 16:18:00+03	85000.00
9886CF	2017-08-14 11:12:00+03	69500.00
988703	2017-07-31 02:55:00+03	61800.00
98870E	2017-07-13 15:07:00+03	136800.00
988744	2017-07-22 00:32:00+03	89700.00
98880E	2017-07-08 16:28:00+03	116000.00
98883C	2017-07-23 19:18:00+03	248300.00
9888FA	2017-07-24 08:19:00+03	24000.00
988917	2017-08-10 00:33:00+03	62600.00
98896A	2017-07-25 14:33:00+03	139200.00
98897F	2017-08-06 12:17:00+03	117500.00
988984	2017-08-15 01:08:00+03	162600.00
9889FF	2017-08-07 03:10:00+03	63300.00
988A06	2017-07-12 20:30:00+03	11700.00
988A14	2017-07-18 02:05:00+03	33400.00
988A74	2017-07-03 21:23:00+03	40800.00
988A7B	2017-08-09 11:42:00+03	223200.00
988B0A	2017-07-16 16:16:00+03	39800.00
988B25	2017-08-15 17:11:00+03	13400.00
988B41	2017-07-11 04:45:00+03	6000.00
988B94	2017-07-03 23:04:00+03	46400.00
988BBE	2017-07-11 22:32:00+03	80600.00
988BC8	2017-07-04 04:08:00+03	73200.00
988BFF	2017-07-18 04:57:00+03	26600.00
988C02	2017-08-13 15:33:00+03	170600.00
988C82	2017-08-15 06:32:00+03	27700.00
988C87	2017-07-25 07:22:00+03	86800.00
988CAF	2017-07-07 21:46:00+03	29400.00
988D2F	2017-08-08 16:45:00+03	116900.00
988DB7	2017-07-09 06:51:00+03	60400.00
988DB8	2017-07-13 14:44:00+03	50400.00
988DDD	2017-07-20 00:57:00+03	132800.00
988DF9	2017-07-18 07:15:00+03	81200.00
988EBB	2017-07-22 18:37:00+03	23600.00
988EE8	2017-07-10 10:24:00+03	80000.00
988EE9	2017-08-14 09:07:00+03	24400.00
988F12	2017-07-12 06:38:00+03	24700.00
988F23	2017-07-25 03:25:00+03	23200.00
988FC1	2017-08-07 10:04:00+03	75300.00
988FDC	2017-08-06 11:41:00+03	21800.00
988FE0	2017-08-08 20:45:00+03	58800.00
988FF2	2017-07-07 07:11:00+03	36200.00
989006	2017-07-16 00:24:00+03	59800.00
989026	2017-08-01 15:06:00+03	115900.00
989103	2017-08-06 21:53:00+03	112800.00
9891F1	2017-07-07 03:51:00+03	28000.00
98929D	2017-07-07 12:07:00+03	397100.00
989308	2017-07-22 21:58:00+03	22000.00
989334	2017-07-16 19:44:00+03	22100.00
9893A2	2017-08-12 20:24:00+03	23600.00
9893BE	2017-07-13 14:00:00+03	203400.00
9893EC	2017-07-25 05:19:00+03	111700.00
989411	2017-07-21 04:47:00+03	133200.00
98946C	2017-08-08 21:13:00+03	19600.00
98947D	2017-08-09 03:29:00+03	119300.00
9894C4	2017-07-29 10:15:00+03	62600.00
9894F6	2017-08-06 19:06:00+03	14100.00
98952F	2017-07-02 03:55:00+03	238300.00
98958A	2017-07-24 00:54:00+03	30200.00
9895B8	2017-07-13 23:05:00+03	25600.00
9895FE	2017-08-12 16:09:00+03	14000.00
989659	2017-06-29 09:33:00+03	125200.00
9896E7	2017-07-07 10:24:00+03	46300.00
98977E	2017-08-15 15:50:00+03	166400.00
989791	2017-07-02 03:00:00+03	72400.00
9897F6	2017-07-12 10:27:00+03	38600.00
989803	2017-07-15 08:47:00+03	28800.00
9898BC	2017-07-19 23:07:00+03	27800.00
989935	2017-07-03 05:45:00+03	51900.00
989948	2017-08-13 11:00:00+03	143800.00
98997D	2017-08-14 23:09:00+03	54800.00
9899A5	2017-08-12 02:11:00+03	271200.00
9899B1	2017-07-22 21:54:00+03	102000.00
9899DC	2017-07-29 02:37:00+03	15000.00
989A14	2017-08-01 17:39:00+03	37200.00
989A1A	2017-07-04 14:33:00+03	174500.00
989AA8	2017-07-03 23:43:00+03	98400.00
989AF1	2017-08-12 15:07:00+03	61500.00
989AFF	2017-07-31 19:26:00+03	92800.00
989B14	2017-08-05 00:58:00+03	45200.00
989B59	2017-07-29 18:19:00+03	10700.00
989BB8	2017-08-03 10:30:00+03	32700.00
989BFE	2017-07-15 19:57:00+03	105700.00
989C64	2017-06-29 04:49:00+03	23200.00
989CAD	2017-07-26 17:12:00+03	52000.00
989DBE	2017-07-09 01:59:00+03	23400.00
989DD5	2017-07-28 12:20:00+03	52400.00
989E04	2017-07-07 16:26:00+03	137600.00
989E06	2017-07-10 16:51:00+03	50600.00
989E44	2017-07-30 07:25:00+03	44600.00
989E45	2017-07-11 10:11:00+03	122500.00
989E60	2017-08-15 15:37:00+03	65900.00
989EA6	2017-08-05 15:34:00+03	37900.00
989F68	2017-06-28 10:04:00+03	113100.00
989F9B	2017-08-06 04:12:00+03	190800.00
98A019	2017-08-05 02:36:00+03	12000.00
98A02D	2017-07-30 23:18:00+03	81600.00
98A065	2017-06-21 15:48:00+03	211100.00
98A0C9	2017-07-28 04:20:00+03	62600.00
98A0D8	2017-08-03 03:13:00+03	21400.00
98A10C	2017-07-21 20:04:00+03	113200.00
98A12F	2017-07-13 19:57:00+03	37800.00
98A15B	2017-08-03 23:00:00+03	40800.00
98A1F4	2017-07-29 06:08:00+03	20600.00
98A24F	2017-08-07 04:56:00+03	22000.00
98A281	2017-07-19 04:21:00+03	46400.00
98A2C1	2017-07-09 23:08:00+03	112000.00
98A2C2	2017-07-30 09:55:00+03	162000.00
98A2EB	2017-07-28 13:23:00+03	60600.00
98A35C	2017-07-04 06:54:00+03	103500.00
98A364	2017-08-08 08:57:00+03	26000.00
98A387	2017-07-14 17:17:00+03	93700.00
98A3F6	2017-07-02 07:15:00+03	159200.00
98A40D	2017-07-29 20:16:00+03	271200.00
98A421	2017-07-15 00:38:00+03	30200.00
98A50C	2017-07-19 00:31:00+03	21500.00
98A585	2017-07-07 17:36:00+03	8000.00
98A5D8	2017-08-08 05:09:00+03	658400.00
98A5E5	2017-07-29 19:36:00+03	24400.00
98A608	2017-07-03 19:41:00+03	68100.00
98A612	2017-08-01 15:41:00+03	406600.00
98A642	2017-08-04 06:31:00+03	47700.00
98A653	2017-07-21 10:28:00+03	25600.00
98A782	2017-07-09 12:34:00+03	22000.00
98A7EA	2017-07-12 17:21:00+03	117200.00
98A7F7	2017-08-15 08:11:00+03	86900.00
98A861	2017-07-27 02:32:00+03	31600.00
98A880	2017-07-15 00:53:00+03	134400.00
98A8AD	2017-07-22 05:26:00+03	68000.00
98A8CD	2017-08-13 22:56:00+03	114400.00
98A96E	2017-07-05 07:52:00+03	26000.00
98A9F6	2017-07-19 07:19:00+03	184500.00
98AB8C	2017-07-25 06:17:00+03	48800.00
98ABE4	2017-08-02 07:43:00+03	89000.00
98AC2A	2017-07-25 13:19:00+03	163600.00
98AC46	2017-07-11 03:37:00+03	27200.00
98AC59	2017-08-12 15:28:00+03	61700.00
98AC90	2017-07-05 16:40:00+03	226200.00
98ACC7	2017-08-08 05:22:00+03	89600.00
98ADE8	2017-07-01 11:38:00+03	31600.00
98AE0D	2017-08-05 09:10:00+03	32400.00
98AE60	2017-07-14 00:01:00+03	45100.00
98AE6B	2017-08-11 16:40:00+03	130800.00
98AECB	2017-07-22 22:43:00+03	100300.00
98AEDE	2017-07-01 20:35:00+03	14000.00
98AF59	2017-07-18 19:26:00+03	148200.00
98AF7D	2017-07-01 01:20:00+03	258400.00
98AF89	2017-07-27 06:33:00+03	290600.00
98AF9B	2017-08-06 03:54:00+03	24400.00
98AFB9	2017-08-02 17:42:00+03	56000.00
98AFC7	2017-07-09 02:28:00+03	179200.00
98AFF8	2017-08-02 10:39:00+03	15000.00
98B04C	2017-08-07 00:54:00+03	85000.00
98B069	2017-07-11 05:17:00+03	276800.00
98B07F	2017-08-12 23:33:00+03	46200.00
98B0D7	2017-08-11 09:27:00+03	228600.00
98B10B	2017-08-09 22:51:00+03	56600.00
98B16F	2017-07-31 18:08:00+03	14400.00
98B1A4	2017-08-15 06:06:00+03	25600.00
98B228	2017-07-24 22:14:00+03	138100.00
98B23B	2017-08-06 15:32:00+03	103000.00
98B296	2017-07-14 11:59:00+03	49100.00
98B2DA	2017-07-16 23:40:00+03	83700.00
98B2E1	2017-08-07 15:19:00+03	44600.00
98B2FC	2017-07-24 16:46:00+03	8200.00
98B32B	2017-08-08 02:20:00+03	168000.00
98B3D0	2017-07-30 05:00:00+03	277400.00
98B3DD	2017-08-02 16:12:00+03	181600.00
98B45E	2017-08-15 14:24:00+03	40000.00
98B488	2017-07-04 17:50:00+03	28700.00
98B4AA	2017-08-05 15:05:00+03	40400.00
98B4BC	2017-07-19 11:42:00+03	22000.00
98B4C1	2017-07-25 02:42:00+03	103600.00
98B4FA	2017-07-23 22:23:00+03	179500.00
98B4FF	2017-08-09 09:29:00+03	24600.00
98B503	2017-07-20 00:01:00+03	28000.00
98B50B	2017-07-29 17:27:00+03	189200.00
98B527	2017-08-11 03:42:00+03	38800.00
98B534	2017-07-17 15:45:00+03	73300.00
98B551	2017-07-04 03:42:00+03	132800.00
98B640	2017-07-17 21:10:00+03	24400.00
98B698	2017-08-13 20:32:00+03	43000.00
98B6E2	2017-07-03 14:00:00+03	66600.00
98B6E6	2017-07-17 12:33:00+03	46200.00
98B716	2017-07-14 18:29:00+03	36400.00
98B71D	2017-08-13 23:16:00+03	19800.00
98B722	2017-07-16 13:58:00+03	28000.00
98B787	2017-08-12 04:13:00+03	13600.00
98B7AA	2017-08-01 06:09:00+03	22000.00
98B7CA	2017-07-27 15:09:00+03	18000.00
98B7CE	2017-07-30 21:04:00+03	32200.00
98B7F6	2017-08-01 17:40:00+03	136200.00
98B810	2017-08-15 12:02:00+03	18100.00
98B88F	2017-07-16 01:22:00+03	29600.00
98B967	2017-07-23 07:17:00+03	21200.00
98B9A4	2017-08-03 10:53:00+03	37100.00
98B9E9	2017-07-16 22:53:00+03	75600.00
98BA43	2017-08-10 21:37:00+03	175400.00
98BA54	2017-07-13 10:08:00+03	39500.00
98BA58	2017-08-05 16:29:00+03	23200.00
98BA86	2017-08-07 09:49:00+03	47000.00
98BAED	2017-07-07 14:09:00+03	6700.00
98BB0F	2017-08-09 07:00:00+03	28800.00
98BB33	2017-08-02 03:36:00+03	265600.00
98BB36	2017-06-29 13:37:00+03	23200.00
98BB86	2017-08-02 05:24:00+03	14800.00
98BB99	2017-08-12 15:24:00+03	25400.00
98BBAE	2017-07-23 08:35:00+03	13600.00
98BC4B	2017-07-23 00:01:00+03	55800.00
98BC64	2017-07-31 06:13:00+03	49600.00
98BC79	2017-07-18 17:35:00+03	72500.00
98BCEC	2017-07-07 04:47:00+03	34000.00
98BD0C	2017-07-02 17:00:00+03	45200.00
98BD0E	2017-07-27 21:46:00+03	61800.00
98BD16	2017-07-30 13:56:00+03	98700.00
98BD23	2017-06-29 18:28:00+03	128800.00
98BD3E	2017-07-14 00:14:00+03	95200.00
98BD7A	2017-07-20 06:29:00+03	172100.00
98BD8B	2017-08-07 10:31:00+03	75600.00
98BD93	2017-08-14 01:57:00+03	58200.00
98BDB3	2017-08-13 07:29:00+03	64800.00
98BDC8	2017-07-13 20:11:00+03	98600.00
98BE26	2017-08-01 20:10:00+03	217800.00
98BE59	2017-08-01 22:09:00+03	6600.00
98BEB3	2017-07-27 17:45:00+03	43600.00
98BEF9	2017-07-18 11:37:00+03	248300.00
98BF72	2017-07-22 23:33:00+03	92000.00
98BF8A	2017-07-02 02:50:00+03	29800.00
98BFCC	2017-08-11 01:32:00+03	56000.00
98BFE7	2017-07-17 06:45:00+03	120100.00
98C032	2017-08-12 15:59:00+03	23600.00
98C0A8	2017-06-28 04:47:00+03	28800.00
98C0B8	2017-08-13 16:56:00+03	131800.00
98C122	2017-08-01 07:50:00+03	47100.00
98C16B	2017-07-16 03:28:00+03	23200.00
98C188	2017-08-12 18:18:00+03	24400.00
98C227	2017-08-02 17:02:00+03	192400.00
98C24E	2017-07-08 20:01:00+03	36800.00
98C2B1	2017-07-02 16:29:00+03	112000.00
98C336	2017-07-05 05:44:00+03	142400.00
98C37D	2017-08-14 19:46:00+03	101500.00
98C3B3	2017-07-26 00:02:00+03	147800.00
98C429	2017-07-03 13:50:00+03	199200.00
98C46B	2017-08-10 23:19:00+03	46400.00
98C494	2017-07-06 10:09:00+03	76800.00
98C5A4	2017-08-14 23:57:00+03	106400.00
98C5F9	2017-07-16 11:53:00+03	42900.00
98C661	2017-08-09 08:08:00+03	22200.00
98C6A0	2017-07-26 02:45:00+03	46200.00
98C6A6	2017-07-15 23:20:00+03	76000.00
98C6BA	2017-07-23 15:39:00+03	92700.00
98C6D8	2017-07-05 15:12:00+03	105400.00
98C728	2017-07-21 10:34:00+03	140900.00
98C830	2017-08-12 02:36:00+03	21400.00
98C88C	2017-07-16 09:36:00+03	52300.00
98C901	2017-08-14 08:31:00+03	19200.00
98C928	2017-07-31 01:55:00+03	111600.00
98C935	2017-08-04 08:04:00+03	136800.00
98C94B	2017-07-11 00:20:00+03	27900.00
98C962	2017-08-07 03:23:00+03	38800.00
98C994	2017-07-05 01:32:00+03	71100.00
98C9D8	2017-07-05 16:12:00+03	84500.00
98C9E2	2017-08-04 11:25:00+03	16400.00
98CA7F	2017-08-13 20:01:00+03	42600.00
98CAAD	2017-07-26 04:23:00+03	265700.00
98CAC8	2017-08-07 17:02:00+03	26000.00
98CB06	2017-07-26 14:24:00+03	54700.00
98CB0F	2017-07-05 04:29:00+03	179400.00
98CB41	2017-07-21 11:09:00+03	32200.00
98CB89	2017-07-22 00:07:00+03	135400.00
98CC0E	2017-08-04 03:31:00+03	25600.00
98CC15	2017-07-05 00:05:00+03	124200.00
98CCD2	2017-07-18 20:40:00+03	179200.00
98CCFB	2017-07-05 02:34:00+03	67600.00
98CD00	2017-07-12 08:36:00+03	45100.00
98CD5F	2017-07-09 10:11:00+03	31200.00
98CD89	2017-07-03 10:54:00+03	132800.00
98CDAB	2017-07-17 06:23:00+03	87200.00
98CDC5	2017-08-05 21:10:00+03	44100.00
98CDE0	2017-08-01 23:10:00+03	25400.00
98CDF3	2017-08-04 00:31:00+03	21200.00
98CE56	2017-07-30 17:16:00+03	136000.00
98CE5B	2017-08-03 06:36:00+03	144000.00
98CECD	2017-08-08 06:18:00+03	92800.00
98CF07	2017-07-23 23:55:00+03	11600.00
98CF1F	2017-07-23 12:38:00+03	117200.00
98CF56	2017-07-12 17:56:00+03	54500.00
98CF92	2017-08-07 16:48:00+03	19600.00
98D049	2017-08-03 23:54:00+03	11800.00
98D079	2017-07-29 15:30:00+03	20400.00
98D080	2017-07-24 22:33:00+03	30200.00
98D0C2	2017-07-22 07:25:00+03	36700.00
98D0F8	2017-07-11 17:35:00+03	62600.00
98D0FC	2017-07-27 05:22:00+03	92000.00
98D12D	2017-08-15 09:12:00+03	47400.00
98D161	2017-08-05 09:19:00+03	39400.00
98D1D6	2017-07-02 15:58:00+03	39100.00
98D221	2017-07-14 02:48:00+03	34800.00
98D337	2017-07-03 10:37:00+03	111900.00
98D394	2017-08-12 12:27:00+03	201800.00
98D3C8	2017-07-22 10:53:00+03	64700.00
98D422	2017-07-06 01:10:00+03	28800.00
98D48C	2017-08-06 11:09:00+03	21800.00
98D4F7	2017-08-05 09:57:00+03	23900.00
98D539	2017-07-29 21:07:00+03	99600.00
98D54F	2017-08-04 06:50:00+03	54400.00
98D5C3	2017-08-06 01:23:00+03	49100.00
98D655	2017-08-12 15:00:00+03	28800.00
98D67E	2017-07-26 08:02:00+03	60400.00
98D6B3	2017-07-27 11:03:00+03	94700.00
98D6DD	2017-07-26 01:39:00+03	38400.00
98D6F1	2017-08-08 14:37:00+03	14800.00
98D703	2017-08-13 23:00:00+03	39800.00
98D70C	2017-08-05 00:26:00+03	37100.00
98D725	2017-08-12 15:00:00+03	25200.00
98D735	2017-07-26 22:33:00+03	29500.00
98D737	2017-08-03 07:45:00+03	13600.00
98D73C	2017-07-02 05:38:00+03	111600.00
98D770	2017-07-06 00:10:00+03	61800.00
98D7C3	2017-07-30 22:26:00+03	55600.00
98D898	2017-08-10 18:11:00+03	31200.00
98D92A	2017-07-30 03:38:00+03	53300.00
98D96D	2017-07-17 09:18:00+03	88600.00
98D99E	2017-07-03 16:29:00+03	65100.00
98D9D4	2017-06-30 20:55:00+03	16400.00
98DA08	2017-08-11 08:50:00+03	174000.00
98DA39	2017-08-06 19:34:00+03	189200.00
98DA68	2017-07-27 22:13:00+03	113600.00
98DAAD	2017-07-29 00:51:00+03	78300.00
98DAAF	2017-08-09 14:51:00+03	147600.00
98DB34	2017-07-11 20:39:00+03	25800.00
98DC9F	2017-07-12 06:13:00+03	113200.00
98DCA3	2017-06-25 02:35:00+03	36800.00
98DCE8	2017-07-04 16:21:00+03	118700.00
98DD24	2017-07-08 12:40:00+03	125000.00
98DD8A	2017-07-14 13:37:00+03	24800.00
98DE2B	2017-07-10 04:07:00+03	116400.00
98DE8F	2017-07-14 05:02:00+03	46200.00
98DEE3	2017-08-14 12:23:00+03	73400.00
98DF1B	2017-07-14 17:19:00+03	89200.00
98DF47	2017-08-05 20:48:00+03	6700.00
98DF9A	2017-07-09 21:23:00+03	23600.00
98DFAA	2017-08-01 01:24:00+03	121400.00
98DFE3	2017-08-03 20:18:00+03	193600.00
98DFE7	2017-07-31 13:03:00+03	40000.00
98E033	2017-08-13 05:09:00+03	113600.00
98E04E	2017-07-30 17:27:00+03	15000.00
98E072	2017-07-15 23:58:00+03	21200.00
98E0BC	2017-07-28 23:59:00+03	66200.00
98E0FC	2017-07-20 09:18:00+03	174400.00
98E116	2017-08-11 00:31:00+03	62300.00
98E185	2017-07-09 08:08:00+03	241300.00
98E187	2017-07-07 10:24:00+03	33100.00
98E22A	2017-08-06 05:46:00+03	153000.00
98E233	2017-08-06 08:04:00+03	23600.00
98E275	2017-07-20 08:10:00+03	43600.00
98E29D	2017-07-30 18:05:00+03	67600.00
98E35B	2017-07-28 00:17:00+03	99700.00
98E36F	2017-08-07 05:13:00+03	6000.00
98E372	2017-07-12 22:10:00+03	75600.00
98E3B5	2017-08-06 00:41:00+03	13400.00
98E3BC	2017-07-27 23:28:00+03	136600.00
98E3CF	2017-08-09 08:03:00+03	37200.00
98E445	2017-07-20 22:53:00+03	132800.00
98E48B	2017-07-29 06:41:00+03	145300.00
98E494	2017-07-24 20:17:00+03	31600.00
98E4CE	2017-07-30 06:27:00+03	12000.00
98E565	2017-07-13 17:36:00+03	56600.00
98E57A	2017-07-18 01:31:00+03	16400.00
98E5DE	2017-08-15 06:03:00+03	154800.00
98E610	2017-08-12 05:27:00+03	52600.00
98E636	2017-07-20 21:52:00+03	100300.00
98E645	2017-08-10 03:08:00+03	33300.00
98E719	2017-07-04 17:07:00+03	43000.00
98E75B	2017-07-20 04:09:00+03	87800.00
98E780	2017-07-24 03:58:00+03	29600.00
98E817	2017-07-21 22:39:00+03	43200.00
98E88C	2017-08-06 15:43:00+03	174400.00
98E8FA	2017-07-12 12:52:00+03	17200.00
98E906	2017-06-30 06:56:00+03	55800.00
98E909	2017-07-14 04:37:00+03	94700.00
98E927	2017-07-25 02:22:00+03	66600.00
98E97B	2017-07-15 11:39:00+03	27200.00
98E97F	2017-07-22 14:12:00+03	55800.00
98E9B0	2017-07-23 03:37:00+03	80600.00
98EA0F	2017-07-25 17:33:00+03	58700.00
98EA25	2017-08-13 20:08:00+03	48400.00
98EA5D	2017-07-16 04:28:00+03	797100.00
98EAD4	2017-08-10 01:02:00+03	136000.00
98EAEC	2017-08-14 12:08:00+03	14400.00
98EAF0	2017-07-20 08:45:00+03	75500.00
98EAF9	2017-07-02 12:32:00+03	55600.00
98EB8C	2017-07-31 00:21:00+03	24600.00
98EC19	2017-07-06 03:19:00+03	168000.00
98EC1F	2017-07-12 00:29:00+03	27200.00
98EC25	2017-07-24 16:01:00+03	6000.00
98EC7D	2017-07-10 08:07:00+03	23200.00
98ECC4	2017-07-22 02:30:00+03	147000.00
98ECC7	2017-07-26 03:06:00+03	109600.00
98ED12	2017-07-08 10:19:00+03	59300.00
98ED34	2017-07-19 05:51:00+03	202400.00
98ED45	2017-08-02 03:12:00+03	36200.00
98ED66	2017-08-09 02:56:00+03	8200.00
98EDD7	2017-07-13 22:19:00+03	26200.00
98EDF0	2017-07-09 12:23:00+03	51900.00
98EE19	2017-07-04 22:21:00+03	40400.00
98EE34	2017-07-22 09:03:00+03	28000.00
98EE93	2017-07-18 02:40:00+03	135600.00
98EF3D	2017-08-15 06:41:00+03	25300.00
98EF94	2017-08-08 15:06:00+03	27300.00
98EF9A	2017-07-13 02:53:00+03	136000.00
98EF9B	2017-08-09 17:01:00+03	35600.00
98F077	2017-07-25 03:16:00+03	539200.00
98F0DE	2017-08-08 14:24:00+03	43900.00
98F0E1	2017-07-06 01:23:00+03	23200.00
98F1E9	2017-07-10 16:18:00+03	123000.00
98F1F3	2017-08-09 16:00:00+03	133200.00
98F24E	2017-08-03 04:58:00+03	35200.00
98F27F	2017-07-08 13:12:00+03	68400.00
98F2D1	2017-07-03 04:00:00+03	28000.00
98F3B2	2017-08-12 05:25:00+03	36200.00
98F477	2017-07-29 08:15:00+03	23600.00
98F48C	2017-07-31 21:34:00+03	67600.00
98F4C2	2017-08-11 03:50:00+03	62600.00
98F525	2017-07-10 10:06:00+03	14400.00
98F645	2017-06-28 00:23:00+03	78500.00
98F650	2017-08-11 17:01:00+03	154800.00
98F69C	2017-07-29 11:32:00+03	298400.00
98F6CF	2017-08-02 14:49:00+03	12400.00
98F702	2017-08-01 14:32:00+03	36000.00
98F71A	2017-07-22 21:57:00+03	52700.00
98F7F2	2017-07-31 09:20:00+03	51800.00
98F7FE	2017-08-07 00:11:00+03	58900.00
98F80E	2017-08-14 17:16:00+03	46300.00
98F871	2017-07-18 09:47:00+03	19600.00
98F8AC	2017-07-02 14:49:00+03	117100.00
98F8AE	2017-07-11 12:44:00+03	112400.00
98F935	2017-07-24 07:44:00+03	25400.00
98F93A	2017-07-19 12:20:00+03	40000.00
98F960	2017-07-25 23:07:00+03	8400.00
98F963	2017-07-07 19:54:00+03	29600.00
98F9C8	2017-07-31 03:25:00+03	46900.00
98FACB	2017-08-15 00:52:00+03	74400.00
98FB18	2017-08-08 10:14:00+03	21400.00
98FB22	2017-08-06 06:10:00+03	75600.00
98FBE1	2017-07-08 11:28:00+03	63200.00
98FC59	2017-07-21 21:20:00+03	79600.00
98FC64	2017-08-10 04:40:00+03	77500.00
98FC6F	2017-07-31 00:49:00+03	61800.00
98FC92	2017-07-13 18:27:00+03	10600.00
98FCBE	2017-07-22 01:06:00+03	42900.00
98FD06	2017-07-09 21:17:00+03	31100.00
98FD24	2017-07-05 11:39:00+03	46800.00
98FD71	2017-07-13 18:24:00+03	106400.00
98FDBC	2017-07-14 08:21:00+03	133200.00
98FDFA	2017-08-06 05:12:00+03	38600.00
98FE01	2017-07-19 17:40:00+03	73600.00
98FE5C	2017-08-13 17:26:00+03	67700.00
98FF15	2017-07-09 01:17:00+03	34000.00
98FF7A	2017-07-08 23:25:00+03	98400.00
98FF86	2017-08-05 15:31:00+03	81700.00
98FFA4	2017-08-06 09:36:00+03	116400.00
98FFD0	2017-08-11 04:57:00+03	59200.00
99003F	2017-08-04 07:07:00+03	40800.00
99009D	2017-07-18 19:50:00+03	33800.00
9900A1	2017-07-10 01:41:00+03	41500.00
990139	2017-07-16 05:31:00+03	23200.00
990160	2017-08-12 05:02:00+03	198400.00
99019E	2017-07-29 15:32:00+03	6600.00
990234	2017-08-10 20:27:00+03	105900.00
990285	2017-07-16 12:38:00+03	248700.00
99029F	2017-07-22 13:43:00+03	32700.00
9902AE	2017-07-10 11:03:00+03	49400.00
990327	2017-07-01 23:57:00+03	74400.00
990336	2017-07-31 15:39:00+03	242000.00
990390	2017-07-31 09:22:00+03	67600.00
9903D6	2017-07-30 18:23:00+03	27200.00
9904A6	2017-08-10 04:10:00+03	29800.00
9904C4	2017-07-23 04:30:00+03	38400.00
9904FC	2017-07-06 14:15:00+03	72800.00
9905C2	2017-07-29 10:52:00+03	58900.00
9905CB	2017-07-04 20:13:00+03	62700.00
990608	2017-07-04 01:46:00+03	111600.00
990642	2017-08-01 04:01:00+03	42800.00
990660	2017-07-27 08:59:00+03	193200.00
990688	2017-07-14 05:15:00+03	54300.00
990727	2017-06-29 05:08:00+03	199300.00
990768	2017-07-21 18:10:00+03	56600.00
99076E	2017-07-07 13:03:00+03	289800.00
990801	2017-07-29 00:21:00+03	56000.00
9908B2	2017-07-12 16:03:00+03	97800.00
9908E2	2017-08-13 20:37:00+03	16400.00
990992	2017-08-15 10:27:00+03	35800.00
990A1A	2017-07-17 04:12:00+03	258400.00
990A87	2017-06-29 00:14:00+03	92800.00
990AA2	2017-08-14 04:58:00+03	83000.00
990BD1	2017-07-28 03:38:00+03	27200.00
990C06	2017-07-09 12:57:00+03	63300.00
990C99	2017-08-13 12:21:00+03	76300.00
990CD1	2017-07-19 07:11:00+03	110500.00
990CE3	2017-07-03 00:28:00+03	23500.00
990D5D	2017-07-25 15:34:00+03	55800.00
990D6F	2017-08-06 11:56:00+03	56000.00
990D78	2017-07-16 14:56:00+03	67900.00
990DCC	2017-07-17 03:54:00+03	289300.00
990DE3	2017-07-04 08:07:00+03	23200.00
990E52	2017-07-04 18:39:00+03	38600.00
990E7B	2017-07-25 03:47:00+03	239300.00
990EE7	2017-07-17 14:40:00+03	39600.00
990EEB	2017-07-04 05:53:00+03	38800.00
990F4A	2017-07-22 08:29:00+03	22000.00
990FA7	2017-07-16 20:35:00+03	86300.00
990FB7	2017-08-03 03:34:00+03	242700.00
990FEA	2017-08-05 07:54:00+03	135200.00
990FF0	2017-06-30 13:25:00+03	24400.00
99100C	2017-08-02 01:13:00+03	40000.00
99102D	2017-08-09 02:32:00+03	153200.00
9910F9	2017-07-26 13:29:00+03	31600.00
99110A	2017-08-12 06:57:00+03	200900.00
99111F	2017-07-12 08:59:00+03	289800.00
99115F	2017-08-12 11:33:00+03	15700.00
991176	2017-07-02 19:07:00+03	31400.00
991181	2017-07-27 13:50:00+03	6400.00
991230	2017-08-08 16:56:00+03	46000.00
991246	2017-07-27 00:08:00+03	135400.00
99124C	2017-07-26 14:00:00+03	28800.00
9912B5	2017-07-03 18:16:00+03	28000.00
9912B9	2017-08-06 02:11:00+03	90800.00
991312	2017-08-08 15:45:00+03	52900.00
991332	2017-07-14 09:57:00+03	14000.00
9913D3	2017-07-20 11:58:00+03	43500.00
9913DA	2017-07-13 04:24:00+03	23600.00
991413	2017-07-31 18:09:00+03	15100.00
991480	2017-07-23 18:28:00+03	135200.00
9914B3	2017-08-08 15:45:00+03	46300.00
99150B	2017-08-03 00:16:00+03	48700.00
991515	2017-08-05 03:26:00+03	67700.00
991593	2017-07-06 05:03:00+03	16000.00
991625	2017-07-27 08:30:00+03	64500.00
99162E	2017-08-07 16:16:00+03	73500.00
9916B1	2017-08-02 23:50:00+03	92700.00
9916C1	2017-07-08 00:46:00+03	75600.00
9916FA	2017-07-13 03:38:00+03	111600.00
991791	2017-08-01 11:31:00+03	34000.00
9917C8	2017-07-29 02:38:00+03	107200.00
9917DD	2017-07-10 08:00:00+03	24800.00
9917E3	2017-07-09 09:20:00+03	107300.00
991855	2017-08-02 06:13:00+03	29000.00
991858	2017-08-02 00:08:00+03	23600.00
991902	2017-07-23 00:38:00+03	13200.00
9919F3	2017-07-20 07:10:00+03	68500.00
9919F8	2017-07-06 14:38:00+03	23200.00
991A0D	2017-07-03 18:26:00+03	28800.00
991A15	2017-07-03 19:04:00+03	38800.00
991A1F	2017-08-11 23:57:00+03	192900.00
991A4B	2017-07-26 10:06:00+03	28800.00
991A8C	2017-08-13 03:25:00+03	170200.00
991AB1	2017-08-01 12:34:00+03	99800.00
991ACE	2017-07-30 08:42:00+03	24400.00
991AFD	2017-07-14 07:43:00+03	26000.00
991BE5	2017-07-01 10:06:00+03	39200.00
991C02	2017-07-18 11:03:00+03	35400.00
991C0F	2017-07-12 13:55:00+03	59800.00
991C5D	2017-07-18 05:56:00+03	264100.00
991CC4	2017-07-19 06:33:00+03	664200.00
991CD0	2017-08-01 06:03:00+03	70600.00
991CE5	2017-08-07 17:04:00+03	410800.00
991D02	2017-08-02 08:51:00+03	124200.00
991D70	2017-08-15 03:24:00+03	351000.00
991DB5	2017-07-12 14:58:00+03	23200.00
991DDA	2017-08-13 10:08:00+03	22600.00
991DFA	2017-08-11 18:07:00+03	47400.00
991E5C	2017-08-08 16:49:00+03	103500.00
991E71	2017-08-06 06:43:00+03	59200.00
991ECD	2017-07-31 19:34:00+03	135700.00
991F15	2017-08-02 15:02:00+03	12600.00
991F2D	2017-08-15 13:50:00+03	29800.00
991F49	2017-08-03 14:55:00+03	23600.00
991F83	2017-08-13 12:39:00+03	75600.00
991FBE	2017-07-11 13:54:00+03	123000.00
992047	2017-07-31 15:00:00+03	21800.00
992051	2017-07-23 22:14:00+03	246000.00
9920BF	2017-07-09 21:29:00+03	174400.00
9920CF	2017-08-04 15:57:00+03	13000.00
99214B	2017-07-22 23:25:00+03	226400.00
9921AB	2017-07-09 15:55:00+03	66600.00
9921BE	2017-07-12 16:13:00+03	133100.00
9921D3	2017-07-14 11:57:00+03	25000.00
9921D9	2017-07-22 08:36:00+03	28800.00
9921DA	2017-08-02 02:37:00+03	83000.00
992234	2017-08-04 13:46:00+03	6300.00
992237	2017-07-18 10:36:00+03	129200.00
9922BD	2017-07-09 02:25:00+03	132800.00
9922CC	2017-08-04 22:58:00+03	58600.00
992340	2017-07-11 05:04:00+03	149300.00
9923A5	2017-07-22 13:05:00+03	38400.00
992413	2017-08-01 12:34:00+03	231000.00
992468	2017-07-23 04:52:00+03	29100.00
9924AB	2017-08-04 12:04:00+03	282100.00
9924F8	2017-06-30 23:46:00+03	13600.00
99250F	2017-08-02 04:38:00+03	41800.00
992528	2017-08-05 09:10:00+03	59800.00
9925BA	2017-07-29 20:05:00+03	136800.00
992601	2017-08-01 18:58:00+03	135000.00
992604	2017-07-09 18:10:00+03	128400.00
99265E	2017-07-31 07:52:00+03	57400.00
99269B	2017-07-03 13:45:00+03	32800.00
9926AC	2017-07-31 06:53:00+03	114800.00
9926EE	2017-08-01 00:17:00+03	124000.00
992727	2017-07-21 13:01:00+03	23200.00
99282A	2017-07-24 11:43:00+03	29600.00
992830	2017-07-23 17:04:00+03	6300.00
9928C9	2017-07-12 02:26:00+03	12600.00
9928CC	2017-08-02 19:56:00+03	12000.00
9928EC	2017-07-29 00:23:00+03	103500.00
99290F	2017-08-10 13:03:00+03	44700.00
992925	2017-07-14 00:45:00+03	85500.00
992944	2017-07-18 11:28:00+03	49900.00
992965	2017-07-20 14:02:00+03	56600.00
9929AC	2017-07-14 03:34:00+03	24800.00
9929CB	2017-06-29 16:56:00+03	51900.00
9929F1	2017-07-23 19:06:00+03	248400.00
992A07	2017-07-04 01:18:00+03	74600.00
992A3A	2017-08-09 07:32:00+03	297600.00
992A47	2017-08-11 22:41:00+03	58200.00
992A4C	2017-07-05 21:35:00+03	295400.00
992A6A	2017-08-08 19:54:00+03	35600.00
992A8B	2017-07-11 01:38:00+03	28300.00
992AE6	2017-07-23 15:54:00+03	59100.00
992AFD	2017-07-22 07:29:00+03	11600.00
992B1F	2017-07-19 01:39:00+03	51600.00
992B73	2017-07-03 08:28:00+03	46000.00
992C3D	2017-07-07 13:07:00+03	48800.00
992C75	2017-06-29 22:24:00+03	397100.00
992D11	2017-07-22 16:30:00+03	29600.00
992D2D	2017-07-27 04:01:00+03	111600.00
992D40	2017-07-30 05:18:00+03	139200.00
992DAE	2017-07-16 22:05:00+03	151200.00
992DBB	2017-07-19 02:58:00+03	34000.00
992E6A	2017-07-24 01:57:00+03	125800.00
992E92	2017-07-05 21:43:00+03	48500.00
992EA0	2017-07-07 01:49:00+03	14000.00
992EE3	2017-07-31 05:30:00+03	25600.00
992EFF	2017-08-04 14:03:00+03	28800.00
992F61	2017-07-30 03:12:00+03	32800.00
992FA9	2017-07-22 16:43:00+03	60400.00
992FAB	2017-07-21 09:35:00+03	112000.00
992FBB	2017-08-15 03:06:00+03	167400.00
992FF2	2017-07-04 19:02:00+03	270000.00
99304B	2017-08-01 16:10:00+03	42700.00
993074	2017-07-23 13:31:00+03	122500.00
9930F4	2017-08-12 18:51:00+03	111600.00
9930F9	2017-08-09 06:22:00+03	44500.00
993101	2017-08-07 14:35:00+03	46400.00
993168	2017-07-17 08:33:00+03	92800.00
993191	2017-08-13 16:03:00+03	22000.00
9931A7	2017-07-10 06:37:00+03	26000.00
993223	2017-08-14 01:41:00+03	62000.00
993299	2017-07-03 10:40:00+03	14000.00
9932D8	2017-07-16 19:52:00+03	18600.00
9932DA	2017-08-01 04:08:00+03	26800.00
993321	2017-08-08 14:56:00+03	75800.00
9933C4	2017-08-14 08:30:00+03	100900.00
99340A	2017-08-13 19:16:00+03	13400.00
99340F	2017-07-14 16:36:00+03	131800.00
993415	2017-08-07 01:28:00+03	31100.00
99346F	2017-06-29 05:44:00+03	410200.00
993487	2017-07-07 11:23:00+03	121400.00
993529	2017-07-07 09:15:00+03	54800.00
99355E	2017-08-15 10:22:00+03	3700.00
993582	2017-07-07 07:46:00+03	60900.00
993593	2017-08-02 09:21:00+03	6000.00
9935FA	2017-07-29 02:57:00+03	20500.00
993697	2017-08-10 07:40:00+03	9200.00
993731	2017-07-09 03:00:00+03	36000.00
993778	2017-07-23 13:16:00+03	191200.00
9937A1	2017-07-10 19:46:00+03	263200.00
9937B7	2017-07-23 00:21:00+03	10600.00
9937BF	2017-07-22 11:05:00+03	29400.00
9937CB	2017-07-21 05:47:00+03	64700.00
9937E1	2017-07-10 09:04:00+03	73200.00
993800	2017-07-25 13:23:00+03	240600.00
9938ED	2017-08-12 09:14:00+03	31100.00
993904	2017-07-08 22:51:00+03	107300.00
993976	2017-08-07 08:39:00+03	30200.00
993A84	2017-08-02 23:20:00+03	136200.00
993AE6	2017-08-14 00:23:00+03	27200.00
993AF0	2017-07-18 01:46:00+03	24400.00
993B13	2017-07-18 01:26:00+03	103200.00
993B31	2017-08-02 03:07:00+03	24400.00
993B46	2017-07-03 08:05:00+03	69500.00
993B54	2017-07-26 06:40:00+03	83000.00
993BB8	2017-07-10 07:24:00+03	29100.00
993BC2	2017-07-29 12:42:00+03	46200.00
993C10	2017-07-24 21:25:00+03	25600.00
993C12	2017-07-11 19:46:00+03	44600.00
993C82	2017-07-21 20:41:00+03	75600.00
993CA2	2017-07-31 02:38:00+03	61900.00
993CCA	2017-07-12 07:43:00+03	28000.00
993CD9	2017-07-08 08:37:00+03	105100.00
993CDB	2017-08-11 09:43:00+03	16400.00
993CFA	2017-08-14 08:09:00+03	64400.00
993CFB	2017-07-21 17:29:00+03	21800.00
993D85	2017-07-02 03:43:00+03	83000.00
993DA9	2017-07-18 03:42:00+03	51900.00
993DEE	2017-07-12 19:03:00+03	133200.00
993E20	2017-06-30 01:42:00+03	36200.00
993E42	2017-07-18 06:30:00+03	34000.00
993EAA	2017-07-24 17:09:00+03	47200.00
993FA2	2017-07-10 16:48:00+03	53400.00
993FD2	2017-07-23 10:33:00+03	6900.00
9940B4	2017-08-03 07:07:00+03	169000.00
9940D6	2017-07-19 15:55:00+03	352500.00
994165	2017-07-19 13:38:00+03	27300.00
9942A7	2017-07-09 00:02:00+03	39500.00
9942B6	2017-07-15 19:49:00+03	38400.00
9942EC	2017-07-13 18:47:00+03	28000.00
9942EF	2017-07-29 12:25:00+03	28000.00
9942F4	2017-08-10 02:20:00+03	148200.00
994304	2017-07-15 14:01:00+03	140900.00
99434A	2017-07-09 11:21:00+03	6800.00
994353	2017-08-03 01:43:00+03	28000.00
994389	2017-07-24 11:00:00+03	34100.00
9943A9	2017-07-21 20:16:00+03	58200.00
9943DE	2017-07-28 01:11:00+03	132800.00
994409	2017-07-31 18:42:00+03	25200.00
994429	2017-07-25 15:21:00+03	29100.00
99447A	2017-08-15 04:57:00+03	58000.00
9944A9	2017-07-10 08:23:00+03	271200.00
9944E0	2017-06-27 05:00:00+03	29500.00
994506	2017-07-04 06:36:00+03	6300.00
99455B	2017-08-15 05:40:00+03	56000.00
994584	2017-07-23 01:34:00+03	133100.00
994636	2017-07-08 22:30:00+03	61800.00
994650	2017-07-06 07:28:00+03	98300.00
99467C	2017-07-19 15:38:00+03	132800.00
9946AD	2017-08-05 06:54:00+03	61700.00
9946D0	2017-06-29 13:52:00+03	176900.00
99471E	2017-08-05 07:39:00+03	44600.00
9947CA	2017-07-27 22:51:00+03	37000.00
9947DB	2017-08-03 06:55:00+03	84100.00
9947FF	2017-07-19 14:14:00+03	89600.00
994860	2017-07-14 12:34:00+03	26700.00
994864	2017-07-15 01:45:00+03	103800.00
994880	2017-07-01 10:16:00+03	13700.00
9948E6	2017-07-12 03:24:00+03	131100.00
994966	2017-08-08 08:23:00+03	121400.00
99497F	2017-07-22 05:28:00+03	55800.00
9949E2	2017-08-04 23:19:00+03	56000.00
994A4F	2017-08-02 08:48:00+03	55800.00
994AE8	2017-07-30 13:43:00+03	25800.00
994B1A	2017-08-15 00:58:00+03	136400.00
994B43	2017-07-16 04:48:00+03	128800.00
994B51	2017-07-17 10:59:00+03	64000.00
994B6A	2017-07-29 07:57:00+03	67600.00
994BB5	2017-08-13 10:47:00+03	270800.00
994BC9	2017-07-18 14:51:00+03	32800.00
994C31	2017-07-12 23:03:00+03	40800.00
994C61	2017-07-18 02:16:00+03	48800.00
994D4A	2017-08-14 08:23:00+03	56000.00
994D4B	2017-07-02 10:10:00+03	36800.00
994D7A	2017-07-19 08:59:00+03	68400.00
994DC8	2017-07-29 09:09:00+03	83300.00
994DCC	2017-07-26 00:02:00+03	35600.00
994DF9	2017-08-10 23:45:00+03	46400.00
994E16	2017-07-15 03:55:00+03	73500.00
994E2A	2017-07-11 04:45:00+03	73600.00
994E48	2017-07-01 20:12:00+03	45200.00
994E58	2017-08-14 00:38:00+03	110500.00
994E75	2017-07-13 05:07:00+03	51900.00
994E90	2017-07-06 12:46:00+03	135400.00
994EEC	2017-08-13 23:16:00+03	62600.00
994F07	2017-07-18 18:23:00+03	28800.00
994F4D	2017-07-09 19:51:00+03	28400.00
994F56	2017-07-05 05:43:00+03	142000.00
994F97	2017-08-02 23:56:00+03	136500.00
994FA6	2017-08-03 19:59:00+03	99200.00
995018	2017-07-29 19:25:00+03	241200.00
995036	2017-07-24 08:07:00+03	34000.00
9950EB	2017-07-21 12:03:00+03	35200.00
995132	2017-07-01 05:52:00+03	35200.00
99513B	2017-07-17 06:35:00+03	212100.00
995151	2017-07-18 09:23:00+03	56000.00
99515B	2017-08-04 08:32:00+03	167200.00
995192	2017-08-12 11:40:00+03	62800.00
9951AF	2017-07-20 00:15:00+03	213200.00
9951B0	2017-07-19 09:10:00+03	30200.00
9951D8	2017-07-30 19:28:00+03	70700.00
9951E5	2017-07-31 04:33:00+03	86800.00
995237	2017-07-18 16:04:00+03	45200.00
99526A	2017-07-08 17:19:00+03	43400.00
99526F	2017-08-11 18:56:00+03	136800.00
995306	2017-08-01 01:47:00+03	177200.00
995332	2017-08-02 16:37:00+03	291000.00
995347	2017-08-03 10:53:00+03	49800.00
9953A9	2017-07-10 22:30:00+03	290400.00
9953AD	2017-07-08 19:31:00+03	11600.00
9953B7	2017-07-03 10:20:00+03	7400.00
9953D5	2017-07-21 03:34:00+03	258400.00
995465	2017-07-15 05:16:00+03	85000.00
99547B	2017-07-24 02:38:00+03	7300.00
995481	2017-07-21 01:12:00+03	64800.00
9954A3	2017-07-12 16:18:00+03	12400.00
9954F2	2017-08-05 01:48:00+03	62600.00
99551A	2017-06-30 21:31:00+03	22600.00
9955B2	2017-08-15 15:23:00+03	12600.00
9955D5	2017-07-04 01:39:00+03	20200.00
9955E4	2017-07-16 11:01:00+03	70800.00
995645	2017-07-12 22:05:00+03	68400.00
99564F	2017-07-11 02:04:00+03	50100.00
995673	2017-08-05 01:39:00+03	28000.00
995691	2017-08-08 05:09:00+03	128800.00
9956D3	2017-08-07 19:02:00+03	36800.00
995715	2017-08-10 07:30:00+03	128800.00
99571D	2017-07-01 14:05:00+03	80200.00
995762	2017-07-02 10:16:00+03	37400.00
995795	2017-07-12 07:07:00+03	57500.00
995895	2017-08-13 22:05:00+03	10800.00
99596F	2017-07-29 06:36:00+03	67600.00
9959A4	2017-07-13 04:34:00+03	54800.00
9959D2	2017-07-07 19:10:00+03	79000.00
995A80	2017-07-04 01:25:00+03	280600.00
995AEF	2017-07-16 21:30:00+03	67400.00
995B0D	2017-07-12 23:16:00+03	125400.00
995B21	2017-07-29 01:55:00+03	22000.00
995B35	2017-07-04 21:46:00+03	47100.00
995B51	2017-07-19 13:06:00+03	229000.00
995B94	2017-07-19 04:15:00+03	288800.00
995C4C	2017-07-04 15:44:00+03	81300.00
995C6B	2017-07-22 17:16:00+03	137600.00
995C73	2017-07-05 11:13:00+03	99200.00
995CE6	2017-08-11 08:46:00+03	27300.00
995D7E	2017-08-01 21:14:00+03	17000.00
995DB6	2017-08-15 09:35:00+03	56000.00
995E65	2017-07-27 06:15:00+03	67600.00
995EAF	2017-07-21 04:19:00+03	36800.00
995F0F	2017-07-17 10:24:00+03	6300.00
995F86	2017-08-11 10:49:00+03	65400.00
9960C9	2017-08-05 12:45:00+03	112000.00
9960F7	2017-08-13 18:53:00+03	36000.00
996109	2017-08-09 21:14:00+03	12600.00
99613C	2017-07-05 22:47:00+03	83500.00
996223	2017-07-25 13:43:00+03	71400.00
99623B	2017-07-10 21:45:00+03	46000.00
99629A	2017-06-26 10:35:00+03	212900.00
9962E2	2017-07-27 21:54:00+03	47200.00
99644C	2017-07-02 00:13:00+03	6300.00
996460	2017-08-06 00:00:00+03	7300.00
996493	2017-07-20 05:33:00+03	12600.00
9964E8	2017-07-17 05:22:00+03	119300.00
996540	2017-07-26 01:16:00+03	116000.00
9965B0	2017-07-17 22:23:00+03	44000.00
996616	2017-07-21 08:13:00+03	118900.00
9966BE	2017-07-01 23:50:00+03	24600.00
996723	2017-07-02 14:23:00+03	57600.00
996763	2017-08-08 17:23:00+03	135400.00
996783	2017-08-11 00:50:00+03	342400.00
9967C5	2017-07-19 05:56:00+03	23200.00
99682D	2017-07-19 05:41:00+03	135100.00
996855	2017-07-03 02:25:00+03	392100.00
9968A4	2017-08-11 00:43:00+03	56100.00
9968BD	2017-07-07 00:31:00+03	39000.00
9968D5	2017-07-21 02:40:00+03	103500.00
9968FD	2017-08-13 09:38:00+03	24400.00
996905	2017-07-16 21:31:00+03	32800.00
996941	2017-08-05 12:43:00+03	149800.00
99694E	2017-08-14 11:14:00+03	136800.00
996959	2017-07-05 09:37:00+03	32300.00
9969A3	2017-07-24 18:01:00+03	31800.00
9969D9	2017-07-26 02:28:00+03	6000.00
996A23	2017-07-30 01:36:00+03	59800.00
996A48	2017-08-04 09:16:00+03	23200.00
996AD6	2017-08-14 09:16:00+03	31600.00
996AFF	2017-07-30 18:31:00+03	281500.00
996B0A	2017-07-16 20:45:00+03	46400.00
996BE6	2017-07-17 21:28:00+03	26000.00
996C16	2017-08-08 13:19:00+03	133100.00
996C71	2017-07-22 03:19:00+03	25800.00
996CBB	2017-07-05 19:04:00+03	28800.00
996CCB	2017-07-22 14:09:00+03	204900.00
996D09	2017-07-20 05:04:00+03	173400.00
996D31	2017-07-18 19:05:00+03	65500.00
996D80	2017-07-21 11:11:00+03	156400.00
996DD5	2017-07-31 22:36:00+03	95300.00
996E8F	2017-08-06 19:57:00+03	46000.00
996EC8	2017-06-30 09:24:00+03	25900.00
996F72	2017-07-25 18:46:00+03	26000.00
996F8F	2017-07-04 15:11:00+03	23600.00
996F9A	2017-07-07 22:40:00+03	119500.00
996FB3	2017-07-11 11:47:00+03	98800.00
997004	2017-07-13 04:31:00+03	94000.00
997024	2017-07-12 22:43:00+03	33600.00
997027	2017-07-19 19:28:00+03	28000.00
99704C	2017-08-07 12:53:00+03	135200.00
997076	2017-06-30 03:57:00+03	121400.00
9970B0	2017-08-04 05:09:00+03	38500.00
9970F7	2017-08-04 03:34:00+03	55500.00
997119	2017-07-30 00:06:00+03	60200.00
997128	2017-07-27 18:50:00+03	93200.00
99718E	2017-07-20 19:33:00+03	131600.00
99718F	2017-07-18 06:35:00+03	55900.00
9971A2	2017-08-08 03:44:00+03	93600.00
9971B8	2017-08-14 20:51:00+03	26800.00
9972A9	2017-08-08 05:01:00+03	230000.00
9972D6	2017-06-30 22:42:00+03	117700.00
9972E5	2017-07-21 17:29:00+03	36800.00
9972F0	2017-07-02 23:16:00+03	88000.00
99736A	2017-07-24 14:40:00+03	14800.00
9973A8	2017-07-13 06:43:00+03	16400.00
9973C5	2017-07-05 03:48:00+03	56000.00
9973DE	2017-08-07 00:09:00+03	21800.00
99740B	2017-08-12 08:09:00+03	32400.00
997423	2017-07-11 12:58:00+03	48500.00
99746F	2017-07-17 03:15:00+03	139300.00
9974B4	2017-07-23 08:18:00+03	67700.00
99751A	2017-07-31 10:20:00+03	119500.00
997561	2017-08-11 02:37:00+03	142400.00
9975DB	2017-07-18 16:09:00+03	93900.00
9975E5	2017-07-27 06:31:00+03	83000.00
9975F6	2017-07-18 17:29:00+03	46800.00
99762F	2017-08-12 06:03:00+03	43700.00
99763E	2017-08-02 00:41:00+03	54500.00
997642	2017-07-16 23:13:00+03	6000.00
997643	2017-07-23 07:35:00+03	109600.00
997688	2017-08-04 05:55:00+03	46000.00
997715	2017-08-11 14:43:00+03	136200.00
997716	2017-07-16 20:30:00+03	124200.00
997757	2017-08-11 10:03:00+03	56600.00
997778	2017-07-19 18:44:00+03	55800.00
997871	2017-08-03 01:21:00+03	40800.00
9979E0	2017-08-05 02:56:00+03	133200.00
997A1A	2017-07-05 15:27:00+03	14000.00
997B12	2017-07-12 05:05:00+03	59800.00
997B4D	2017-08-06 15:16:00+03	128800.00
997B4F	2017-08-13 20:42:00+03	124800.00
997B70	2017-07-06 19:22:00+03	43200.00
997B8A	2017-08-14 23:32:00+03	26800.00
997B8E	2017-07-11 00:31:00+03	28000.00
997BA4	2017-07-02 04:48:00+03	28000.00
997BD3	2017-08-08 05:54:00+03	156300.00
997BFC	2017-07-08 09:36:00+03	119300.00
997C50	2017-08-08 17:14:00+03	265700.00
997C53	2017-07-03 13:49:00+03	254900.00
997C62	2017-07-09 09:14:00+03	135600.00
997C7B	2017-07-21 00:22:00+03	38600.00
997D17	2017-07-30 14:51:00+03	79200.00
997D33	2017-07-22 06:55:00+03	32700.00
997D91	2017-08-10 17:31:00+03	20400.00
997DC3	2017-08-14 04:08:00+03	57600.00
997DCE	2017-07-31 11:31:00+03	58600.00
997DE8	2017-07-14 06:47:00+03	12600.00
997DE9	2017-07-13 16:45:00+03	167400.00
997DF1	2017-08-14 08:13:00+03	24400.00
997DFC	2017-08-05 01:29:00+03	13200.00
997E0A	2017-07-31 07:38:00+03	90800.00
997E15	2017-07-08 07:52:00+03	18200.00
997E47	2017-07-08 09:16:00+03	153900.00
997E68	2017-07-03 15:41:00+03	91600.00
997E86	2017-07-17 03:22:00+03	68100.00
997EC5	2017-07-22 02:46:00+03	27200.00
997ECC	2017-07-17 19:40:00+03	111600.00
997EFA	2017-08-02 21:44:00+03	174600.00
997F68	2017-07-03 17:07:00+03	67200.00
997F69	2017-07-03 17:07:00+03	209900.00
997FA0	2017-07-11 19:13:00+03	42000.00
998046	2017-07-28 06:19:00+03	81600.00
99806F	2017-07-30 15:56:00+03	76600.00
99814A	2017-07-30 02:36:00+03	19600.00
998165	2017-08-10 10:34:00+03	125200.00
9981AA	2017-08-05 01:38:00+03	59200.00
9981AF	2017-07-06 09:30:00+03	103500.00
9981C1	2017-08-14 06:53:00+03	151000.00
9981EB	2017-07-29 14:46:00+03	54400.00
9981F9	2017-07-14 22:57:00+03	57100.00
9981FF	2017-07-25 01:15:00+03	62200.00
998249	2017-08-13 17:16:00+03	270700.00
9982D4	2017-08-02 06:05:00+03	35900.00
9982E1	2017-07-26 14:47:00+03	143600.00
998301	2017-07-06 22:28:00+03	67900.00
998328	2017-07-25 23:17:00+03	75000.00
9983A5	2017-07-14 10:17:00+03	13500.00
9983EE	2017-07-12 07:05:00+03	76300.00
9983F9	2017-07-15 04:08:00+03	12600.00
99840B	2017-08-03 16:32:00+03	244800.00
99840D	2017-07-26 06:34:00+03	117600.00
998455	2017-07-20 17:49:00+03	56000.00
9984DD	2017-07-09 08:34:00+03	26800.00
9984E8	2017-08-04 09:43:00+03	88000.00
998512	2017-08-07 08:38:00+03	117600.00
99858F	2017-07-31 21:19:00+03	129600.00
9985B5	2017-07-10 23:02:00+03	143800.00
9985C4	2017-08-11 02:05:00+03	39800.00
9985C6	2017-08-12 09:44:00+03	111600.00
9985DF	2017-08-10 13:51:00+03	25800.00
9985EA	2017-08-14 21:40:00+03	131800.00
998600	2017-08-04 18:39:00+03	205600.00
998606	2017-07-25 04:08:00+03	26000.00
9986BC	2017-08-10 10:27:00+03	260900.00
998741	2017-07-19 17:19:00+03	47300.00
998742	2017-07-06 22:46:00+03	41600.00
998750	2017-07-01 16:09:00+03	9300.00
99875D	2017-08-07 18:43:00+03	55800.00
9987D0	2017-08-09 14:19:00+03	168000.00
998966	2017-08-10 21:40:00+03	270200.00
9989AE	2017-07-27 19:08:00+03	11700.00
998A22	2017-07-02 05:30:00+03	56900.00
998AB3	2017-08-02 05:08:00+03	67700.00
998AC4	2017-07-20 09:54:00+03	136800.00
998B01	2017-07-08 16:33:00+03	44800.00
998B23	2017-08-14 12:29:00+03	133200.00
998B5D	2017-07-26 09:41:00+03	26000.00
998C09	2017-07-19 08:38:00+03	265700.00
998C41	2017-07-30 00:11:00+03	64400.00
998C96	2017-07-21 02:32:00+03	46200.00
998CAF	2017-07-21 06:37:00+03	21400.00
998CCD	2017-07-31 04:13:00+03	57400.00
998DA2	2017-07-28 02:41:00+03	6000.00
998DAD	2017-08-14 04:39:00+03	66800.00
998E46	2017-07-01 14:07:00+03	40100.00
998E76	2017-08-03 20:55:00+03	743700.00
998E79	2017-08-11 05:51:00+03	86600.00
998F5F	2017-07-22 02:25:00+03	44600.00
999092	2017-08-12 01:44:00+03	32700.00
9990A4	2017-08-15 11:03:00+03	91800.00
999104	2017-07-03 14:29:00+03	198400.00
999147	2017-07-01 12:10:00+03	94800.00
9991B6	2017-07-21 11:17:00+03	148000.00
9991F0	2017-08-05 03:35:00+03	112000.00
999202	2017-07-07 09:58:00+03	153200.00
9992E4	2017-07-27 14:26:00+03	65600.00
999321	2017-07-27 04:19:00+03	163100.00
999340	2017-08-15 04:23:00+03	168000.00
999415	2017-07-24 01:44:00+03	12600.00
999420	2017-07-06 06:23:00+03	66600.00
999463	2017-08-10 11:32:00+03	24700.00
9994B0	2017-08-14 03:53:00+03	24700.00
999514	2017-07-24 04:08:00+03	124200.00
999548	2017-08-09 20:49:00+03	130800.00
999552	2017-07-07 10:23:00+03	501300.00
9995A2	2017-06-30 05:04:00+03	111600.00
9995DA	2017-06-29 09:04:00+03	79900.00
9996BD	2017-07-18 13:09:00+03	29400.00
9996D9	2017-08-03 03:52:00+03	75300.00
9996DC	2017-07-15 02:03:00+03	35200.00
9996ED	2017-08-08 22:43:00+03	53400.00
99975F	2017-07-24 10:48:00+03	46000.00
9997D2	2017-08-08 07:22:00+03	40600.00
9997DC	2017-08-12 15:01:00+03	122400.00
999813	2017-07-14 15:55:00+03	100600.00
999829	2017-08-01 10:17:00+03	23200.00
999857	2017-07-25 11:09:00+03	10600.00
999898	2017-07-04 10:50:00+03	46400.00
9998A0	2017-08-03 00:20:00+03	8000.00
9998B2	2017-08-13 04:43:00+03	168000.00
9998CF	2017-08-13 11:37:00+03	85000.00
9998D1	2017-07-23 23:26:00+03	17000.00
999911	2017-07-27 17:36:00+03	36700.00
999924	2017-07-24 22:21:00+03	39300.00
99995B	2017-07-07 10:39:00+03	68300.00
99995E	2017-07-07 04:06:00+03	41800.00
999972	2017-08-09 21:48:00+03	136900.00
9999F1	2017-07-23 01:33:00+03	75200.00
9999FE	2017-07-12 09:31:00+03	135800.00
999A05	2017-08-11 05:52:00+03	41200.00
999A28	2017-07-20 16:10:00+03	173800.00
999A54	2017-08-05 07:36:00+03	114700.00
999A85	2017-07-12 15:28:00+03	17600.00
999AE8	2017-08-08 15:16:00+03	98300.00
999AED	2017-08-04 20:06:00+03	14400.00
999AFE	2017-07-31 06:42:00+03	115900.00
999B1F	2017-08-11 12:26:00+03	23200.00
999B2B	2017-07-15 07:49:00+03	14800.00
999B2F	2017-07-03 10:17:00+03	34600.00
999B5A	2017-07-03 15:32:00+03	28800.00
999B67	2017-07-21 22:24:00+03	51800.00
999B72	2017-08-01 14:20:00+03	289400.00
999B87	2017-08-07 08:00:00+03	106900.00
999BC2	2017-07-25 16:06:00+03	46800.00
999C38	2017-08-03 05:01:00+03	52700.00
999C55	2017-07-11 09:33:00+03	44800.00
999CAD	2017-07-03 02:37:00+03	133100.00
999CE4	2017-07-19 02:20:00+03	78900.00
999DAB	2017-07-08 11:37:00+03	125200.00
999DE3	2017-07-22 04:27:00+03	56600.00
999E2B	2017-08-05 04:36:00+03	36200.00
999E3E	2017-07-03 09:39:00+03	25600.00
999E55	2017-07-24 17:31:00+03	46000.00
999E77	2017-07-21 04:49:00+03	25900.00
999E8D	2017-07-17 21:45:00+03	94900.00
999EB6	2017-07-31 00:46:00+03	439300.00
999ED1	2017-08-14 13:50:00+03	193200.00
999ED6	2017-07-08 23:58:00+03	78100.00
999F23	2017-08-02 15:38:00+03	71100.00
99A009	2017-07-02 21:24:00+03	88600.00
99A043	2017-07-30 21:59:00+03	53600.00
99A095	2017-07-20 18:06:00+03	234300.00
99A182	2017-08-09 15:55:00+03	38200.00
99A1A5	2017-06-29 19:04:00+03	93600.00
99A205	2017-07-03 20:09:00+03	28000.00
99A208	2017-07-30 01:42:00+03	23400.00
99A242	2017-07-21 03:57:00+03	40600.00
99A275	2017-07-08 01:22:00+03	59800.00
99A328	2017-08-12 11:17:00+03	128800.00
99A33D	2017-07-28 07:18:00+03	73300.00
99A33F	2017-07-23 12:22:00+03	38800.00
99A35F	2017-07-11 11:30:00+03	95000.00
99A372	2017-08-15 17:59:00+03	39200.00
99A3B8	2017-08-10 03:39:00+03	37400.00
99A3BF	2017-08-06 17:03:00+03	153300.00
99A3E0	2017-07-09 11:51:00+03	56000.00
99A42C	2017-07-23 16:42:00+03	47400.00
99A45F	2017-07-15 15:56:00+03	30900.00
99A4B6	2017-07-21 01:40:00+03	81300.00
99A4C1	2017-08-14 05:37:00+03	29600.00
99A52C	2017-07-15 23:18:00+03	42800.00
99A566	2017-07-05 07:38:00+03	202100.00
99A5D2	2017-07-01 04:50:00+03	45500.00
99A64E	2017-08-05 17:43:00+03	106300.00
99A656	2017-08-08 19:54:00+03	265700.00
99A6CC	2017-07-29 14:04:00+03	213200.00
99A6E4	2017-08-07 12:46:00+03	51800.00
99A6F7	2017-07-23 19:20:00+03	72200.00
99A70B	2017-07-05 17:05:00+03	31000.00
99A744	2017-07-09 22:10:00+03	101200.00
99A74E	2017-07-09 16:38:00+03	48700.00
99A76A	2017-07-09 17:34:00+03	26000.00
99A78D	2017-07-10 15:40:00+03	46000.00
99A796	2017-08-09 22:05:00+03	52100.00
99A79C	2017-08-02 00:13:00+03	15800.00
99A79F	2017-08-15 11:14:00+03	261000.00
99A7A6	2017-08-01 10:39:00+03	92400.00
99A7AD	2017-07-05 09:21:00+03	20400.00
99A7CD	2017-06-27 18:17:00+03	47400.00
99A837	2017-07-24 00:59:00+03	147700.00
99A83F	2017-07-14 14:42:00+03	21200.00
99A8C9	2017-08-04 08:42:00+03	22600.00
99A927	2017-08-15 13:41:00+03	115400.00
99A973	2017-07-13 03:51:00+03	35200.00
99A999	2017-08-11 18:50:00+03	532800.00
99AA3E	2017-07-17 20:28:00+03	124200.00
99AA41	2017-07-25 21:35:00+03	288600.00
99AA8C	2017-07-27 00:30:00+03	112100.00
99AB3C	2017-08-11 17:03:00+03	148200.00
99ABC2	2017-08-02 09:44:00+03	51900.00
99ABDD	2017-07-16 22:44:00+03	39100.00
99AC3B	2017-08-11 00:03:00+03	65500.00
99AC4C	2017-08-09 08:50:00+03	116800.00
99AC5D	2017-07-24 12:04:00+03	87600.00
99AC5E	2017-07-18 05:37:00+03	120900.00
99AC69	2017-08-09 23:13:00+03	63400.00
99ACC5	2017-07-29 10:01:00+03	24800.00
99ACD8	2017-07-12 16:11:00+03	37200.00
99ACD9	2017-08-11 14:55:00+03	60400.00
99ACEB	2017-07-14 12:00:00+03	6800.00
99AD0C	2017-07-10 23:53:00+03	139500.00
99AD30	2017-08-12 10:30:00+03	57400.00
99AD4B	2017-07-27 21:48:00+03	28000.00
99ADF4	2017-07-28 22:12:00+03	43100.00
99AE07	2017-07-31 00:47:00+03	57500.00
99AE73	2017-08-09 20:04:00+03	26900.00
99AEDC	2017-07-14 17:03:00+03	88000.00
99AF06	2017-07-24 05:23:00+03	34600.00
99AF17	2017-07-28 07:32:00+03	64500.00
99AF1B	2017-07-02 07:49:00+03	20600.00
99AF57	2017-08-02 03:49:00+03	67000.00
99AFA9	2017-07-19 02:29:00+03	102100.00
99AFB3	2017-07-17 10:41:00+03	28000.00
99B062	2017-07-18 23:51:00+03	59000.00
99B080	2017-08-09 19:40:00+03	13600.00
99B085	2017-08-15 17:51:00+03	112000.00
99B0CD	2017-07-29 15:36:00+03	70600.00
99B168	2017-07-19 12:59:00+03	167400.00
99B16A	2017-07-12 04:58:00+03	3400.00
99B1B3	2017-08-01 10:29:00+03	170800.00
99B23F	2017-07-09 08:35:00+03	117200.00
99B28D	2017-07-04 19:55:00+03	13800.00
99B292	2017-08-05 03:03:00+03	15000.00
99B2C8	2017-07-03 23:30:00+03	25400.00
99B2D8	2017-07-07 15:00:00+03	40000.00
99B313	2017-07-26 14:42:00+03	86400.00
99B34B	2017-07-06 13:28:00+03	6800.00
99B45D	2017-07-08 00:29:00+03	89100.00
99B46F	2017-07-19 00:05:00+03	332800.00
99B4B3	2017-07-10 16:46:00+03	74800.00
99B4B5	2017-07-03 03:03:00+03	63200.00
99B4C2	2017-08-06 17:37:00+03	67800.00
99B4D7	2017-07-18 19:21:00+03	66600.00
99B515	2017-07-21 16:41:00+03	116400.00
99B52F	2017-08-06 20:13:00+03	115900.00
99B545	2017-08-03 07:24:00+03	29400.00
99B59B	2017-07-12 06:15:00+03	38800.00
99B61C	2017-07-08 11:11:00+03	67000.00
99B6C9	2017-07-11 23:04:00+03	92900.00
99B72D	2017-08-14 09:54:00+03	101200.00
99B79C	2017-08-13 08:50:00+03	174900.00
99B7B9	2017-07-14 05:09:00+03	12600.00
99B7DA	2017-07-30 06:19:00+03	32400.00
99B7F8	2017-07-09 04:24:00+03	65900.00
99B86D	2017-08-13 05:07:00+03	147000.00
99B904	2017-08-08 23:55:00+03	80000.00
99B970	2017-08-13 10:10:00+03	37100.00
99B980	2017-07-28 14:20:00+03	32700.00
99B98D	2017-07-20 16:42:00+03	23600.00
99BA0A	2017-08-11 01:33:00+03	45200.00
99BAAD	2017-08-07 08:30:00+03	40600.00
99BB5E	2017-07-02 10:28:00+03	6000.00
99BC14	2017-07-22 03:17:00+03	131600.00
99BC1C	2017-08-04 14:55:00+03	24400.00
99BC99	2017-07-30 20:49:00+03	123000.00
99BC9C	2017-08-09 23:31:00+03	47200.00
99BD3B	2017-07-23 00:06:00+03	37900.00
99BD70	2017-06-27 02:52:00+03	93900.00
99BD93	2017-08-06 13:07:00+03	66600.00
99BE24	2017-08-09 18:20:00+03	56000.00
99BE44	2017-07-14 01:23:00+03	98400.00
99BE4A	2017-07-23 09:00:00+03	38600.00
99BE5C	2017-07-21 07:20:00+03	31700.00
99BE5F	2017-08-04 20:11:00+03	99200.00
99BE61	2017-07-13 09:27:00+03	47000.00
99BE9F	2017-07-29 20:04:00+03	64800.00
99BFB4	2017-08-07 19:07:00+03	88000.00
99C04C	2017-07-19 19:41:00+03	43000.00
99C064	2017-08-05 13:45:00+03	32800.00
99C109	2017-07-31 02:21:00+03	123000.00
99C176	2017-07-24 07:13:00+03	48600.00
99C184	2017-08-12 23:31:00+03	332100.00
99C1B2	2017-08-15 10:53:00+03	87000.00
99C1BE	2017-07-25 06:52:00+03	47000.00
99C1C6	2017-07-07 10:14:00+03	37500.00
99C245	2017-08-05 02:19:00+03	31700.00
99C258	2017-08-07 02:37:00+03	146300.00
99C269	2017-06-28 09:24:00+03	16400.00
99C271	2017-07-24 13:04:00+03	67400.00
99C2A4	2017-07-10 22:13:00+03	226400.00
99C2DF	2017-07-14 01:29:00+03	58600.00
99C3A7	2017-07-17 05:47:00+03	87400.00
99C43A	2017-08-14 05:26:00+03	104100.00
99C4C1	2017-07-28 09:50:00+03	113600.00
99C4FF	2017-08-03 21:42:00+03	90400.00
99C56A	2017-07-11 04:47:00+03	48700.00
99C6E6	2017-07-18 22:26:00+03	162600.00
99C6F1	2017-07-17 23:27:00+03	10800.00
99C7A3	2017-08-14 04:42:00+03	68800.00
99C7B0	2017-08-08 05:16:00+03	31400.00
99C7B6	2017-08-12 07:15:00+03	136200.00
99C818	2017-08-08 14:10:00+03	91600.00
99C830	2017-07-11 23:25:00+03	10800.00
99C861	2017-07-06 23:40:00+03	164400.00
99C890	2017-07-04 15:29:00+03	27200.00
99C908	2017-07-12 02:33:00+03	85000.00
99C94D	2017-08-02 05:09:00+03	38600.00
99C980	2017-07-27 16:44:00+03	82900.00
99C982	2017-08-08 01:23:00+03	44800.00
99C9D8	2017-07-23 10:42:00+03	70400.00
99CA24	2017-08-12 00:39:00+03	36200.00
99CA2B	2017-07-04 13:49:00+03	23200.00
99CA47	2017-07-19 09:08:00+03	192700.00
99CA60	2017-08-06 09:49:00+03	48500.00
99CAB3	2017-08-11 19:42:00+03	16400.00
99CAC1	2017-07-21 18:32:00+03	22900.00
99CAD2	2017-07-21 01:10:00+03	8200.00
99CADB	2017-07-21 13:30:00+03	149600.00
99CB01	2017-07-16 20:57:00+03	199500.00
99CB03	2017-07-25 15:41:00+03	312400.00
99CB32	2017-07-30 05:38:00+03	119800.00
99CB39	2017-08-03 12:26:00+03	12200.00
99CB60	2017-08-05 17:23:00+03	167400.00
99CB92	2017-08-13 15:32:00+03	68000.00
99CBA8	2017-08-06 10:06:00+03	47000.00
99CC15	2017-07-17 16:57:00+03	6800.00
99CC43	2017-07-07 12:21:00+03	26000.00
99CC7A	2017-08-14 21:52:00+03	189200.00
99CD32	2017-08-13 06:08:00+03	20600.00
99CD45	2017-07-05 14:55:00+03	155600.00
99CD7D	2017-07-18 14:31:00+03	179400.00
99CDB4	2017-07-28 00:18:00+03	44800.00
99CDBE	2017-07-29 23:27:00+03	23200.00
99CDE7	2017-08-10 16:18:00+03	23200.00
99CDE9	2017-07-16 11:11:00+03	168000.00
99CE1E	2017-08-09 10:01:00+03	246000.00
99CE40	2017-07-12 05:59:00+03	47000.00
99CE58	2017-08-15 08:27:00+03	107300.00
99CE5A	2017-08-09 13:02:00+03	26000.00
99CE98	2017-08-13 06:51:00+03	7200.00
99CEC4	2017-08-15 01:55:00+03	28000.00
99CF1A	2017-07-21 15:22:00+03	12400.00
99CF68	2017-07-31 04:33:00+03	117700.00
99CF98	2017-07-16 13:43:00+03	10800.00
99CFB2	2017-07-21 23:49:00+03	69600.00
99CFE4	2017-08-15 06:23:00+03	150600.00
99D024	2017-07-03 10:38:00+03	56100.00
99D028	2017-07-10 16:18:00+03	254900.00
99D065	2017-07-08 08:46:00+03	24400.00
99D066	2017-07-07 22:16:00+03	50200.00
99D06A	2017-07-21 14:30:00+03	45200.00
99D0AA	2017-06-29 15:54:00+03	63800.00
99D10B	2017-08-02 02:55:00+03	34100.00
99D13E	2017-07-21 23:34:00+03	59000.00
99D16C	2017-07-14 19:00:00+03	46700.00
99D188	2017-08-01 04:44:00+03	80700.00
99D1B4	2017-07-06 11:19:00+03	37200.00
99D24B	2017-07-24 17:04:00+03	54600.00
99D2BC	2017-07-22 16:43:00+03	47100.00
99D2E7	2017-08-12 17:38:00+03	24400.00
99D2EE	2017-07-19 00:27:00+03	189200.00
99D321	2017-08-03 19:37:00+03	52300.00
99D33A	2017-07-20 23:32:00+03	85700.00
99D35C	2017-08-12 09:30:00+03	40100.00
99D3BD	2017-07-31 18:25:00+03	40600.00
99D3E3	2017-07-03 17:19:00+03	6800.00
99D3EF	2017-07-19 09:20:00+03	95500.00
99D42D	2017-07-19 08:40:00+03	46300.00
99D43A	2017-08-05 20:44:00+03	26600.00
99D4EA	2017-07-11 11:10:00+03	46000.00
99D4F5	2017-07-28 14:32:00+03	120700.00
99D533	2017-07-27 09:34:00+03	26700.00
99D551	2017-07-25 19:49:00+03	246000.00
99D5A4	2017-08-10 04:35:00+03	17800.00
99D5B9	2017-08-03 18:58:00+03	148200.00
99D5FB	2017-07-14 18:27:00+03	43700.00
99D640	2017-08-09 04:40:00+03	41600.00
99D652	2017-07-24 13:28:00+03	143200.00
99D669	2017-06-30 13:22:00+03	51300.00
99D68F	2017-07-25 22:26:00+03	132800.00
99D73C	2017-07-26 16:25:00+03	61800.00
99D759	2017-08-08 07:28:00+03	22200.00
99D7D4	2017-07-30 00:28:00+03	19800.00
99D7DA	2017-07-02 13:16:00+03	37600.00
99D7FA	2017-07-26 10:56:00+03	8400.00
99D83D	2017-07-29 22:38:00+03	12600.00
99D87D	2017-07-04 21:50:00+03	37900.00
99D8BE	2017-07-17 15:29:00+03	392800.00
99D8FC	2017-08-12 13:42:00+03	63200.00
99D927	2017-08-05 13:03:00+03	168000.00
99D97B	2017-07-18 00:02:00+03	10600.00
99D9A7	2017-08-14 11:42:00+03	36200.00
99D9AF	2017-07-14 21:17:00+03	115700.00
99DA24	2017-07-26 21:09:00+03	137600.00
99DA38	2017-07-06 15:25:00+03	104600.00
99DA66	2017-07-26 18:39:00+03	42800.00
99DA69	2017-07-15 11:34:00+03	186900.00
99DAB6	2017-07-18 11:42:00+03	17600.00
99DB72	2017-07-19 11:08:00+03	41000.00
99DBC9	2017-08-04 01:33:00+03	21800.00
99DC35	2017-07-06 23:26:00+03	23200.00
99DC7E	2017-07-25 10:49:00+03	14800.00
99DCBA	2017-07-11 06:10:00+03	196800.00
99DCE0	2017-08-01 08:58:00+03	40300.00
99DD35	2017-07-27 02:54:00+03	253200.00
99DD45	2017-08-14 08:23:00+03	97800.00
99DDB2	2017-07-02 03:23:00+03	173600.00
99DDD3	2017-08-03 20:06:00+03	30000.00
99DDF6	2017-07-21 06:25:00+03	59200.00
99DDFE	2017-08-14 06:57:00+03	59300.00
99DED2	2017-07-26 06:12:00+03	22000.00
99DF38	2017-08-14 15:16:00+03	56000.00
99DF41	2017-08-02 02:48:00+03	174600.00
99DF56	2017-07-23 11:55:00+03	99200.00
99DF62	2017-08-06 21:25:00+03	23600.00
99E0E8	2017-07-16 13:06:00+03	12600.00
99E0E9	2017-07-31 12:12:00+03	55800.00
99E18F	2017-08-11 08:17:00+03	67600.00
99E24D	2017-07-25 04:38:00+03	19600.00
99E250	2017-07-06 09:52:00+03	37200.00
99E28B	2017-08-12 04:00:00+03	24400.00
99E2AE	2017-08-02 10:18:00+03	26000.00
99E2BD	2017-07-23 04:02:00+03	46200.00
99E329	2017-07-15 00:34:00+03	55800.00
99E3B2	2017-07-23 08:27:00+03	54600.00
99E3EC	2017-07-24 09:44:00+03	67200.00
99E421	2017-07-06 13:33:00+03	141100.00
99E423	2017-07-11 13:41:00+03	34100.00
99E4C7	2017-08-02 05:36:00+03	12400.00
99E506	2017-08-02 16:21:00+03	109600.00
99E5BC	2017-07-08 12:11:00+03	98400.00
99E5D4	2017-07-21 13:24:00+03	65900.00
99E5FF	2017-08-06 23:42:00+03	139800.00
99E610	2017-07-01 15:16:00+03	166200.00
99E648	2017-08-15 03:51:00+03	7200.00
99E687	2017-07-25 15:39:00+03	11800.00
99E6CA	2017-07-11 19:01:00+03	24400.00
99E6F9	2017-07-20 20:37:00+03	70700.00
99E7DD	2017-07-09 08:41:00+03	22400.00
99E7DF	2017-08-14 11:28:00+03	38100.00
99E831	2017-08-06 08:19:00+03	265700.00
99E853	2017-08-06 23:48:00+03	34200.00
99E875	2017-07-27 00:49:00+03	38800.00
99E8C4	2017-07-11 19:12:00+03	98200.00
99E8DA	2017-07-06 01:40:00+03	32700.00
99E901	2017-07-23 16:18:00+03	20200.00
99E921	2017-07-06 21:50:00+03	14400.00
99EA73	2017-07-10 11:59:00+03	91600.00
99EB33	2017-07-09 06:37:00+03	37900.00
99EB6B	2017-07-14 03:07:00+03	99600.00
99EB73	2017-08-05 23:47:00+03	114800.00
99EC8F	2017-07-06 17:11:00+03	66200.00
99ECB6	2017-08-01 13:23:00+03	203300.00
99EDE8	2017-08-07 13:54:00+03	31100.00
99EE7E	2017-07-23 06:44:00+03	24400.00
99EE9B	2017-07-08 03:57:00+03	125200.00
99EEA0	2017-08-15 09:00:00+03	13600.00
99EECE	2017-07-03 04:00:00+03	156300.00
99EEDE	2017-08-10 20:35:00+03	55800.00
99EEFF	2017-07-06 04:22:00+03	100000.00
99EF07	2017-08-02 04:00:00+03	39200.00
99EF49	2017-08-05 19:38:00+03	272400.00
99EF52	2017-07-03 18:28:00+03	32800.00
99EF90	2017-07-16 21:44:00+03	58400.00
99EFC1	2017-07-04 11:57:00+03	43000.00
99EFCD	2017-08-10 06:05:00+03	28000.00
99F027	2017-08-06 11:45:00+03	12600.00
99F081	2017-06-30 17:51:00+03	73500.00
99F098	2017-07-09 15:57:00+03	187600.00
99F0B1	2017-08-14 13:05:00+03	75600.00
99F0B4	2017-08-01 21:34:00+03	70400.00
99F0EF	2017-07-21 09:38:00+03	56000.00
99F12B	2017-07-03 04:13:00+03	22000.00
99F139	2017-07-22 16:02:00+03	89000.00
99F1B7	2017-08-08 22:33:00+03	58400.00
99F1BD	2017-08-15 11:33:00+03	40600.00
99F1E1	2017-08-04 23:29:00+03	58900.00
99F1F8	2017-07-15 10:58:00+03	78100.00
99F207	2017-07-16 20:04:00+03	76600.00
99F252	2017-07-09 00:26:00+03	46800.00
99F25D	2017-07-08 11:39:00+03	26000.00
99F287	2017-07-11 03:45:00+03	386300.00
99F38C	2017-08-12 10:47:00+03	111000.00
99F3ED	2017-07-26 14:29:00+03	72400.00
99F41F	2017-07-22 23:30:00+03	38800.00
99F52F	2017-08-03 02:07:00+03	379000.00
99F555	2017-08-10 08:59:00+03	106200.00
99F5C5	2017-08-14 16:58:00+03	99300.00
99F5D8	2017-08-02 11:16:00+03	56000.00
99F5EE	2017-07-25 12:33:00+03	235800.00
99F5F6	2017-08-10 19:22:00+03	27000.00
99F5F9	2017-07-05 15:29:00+03	58200.00
99F5FF	2017-06-30 23:39:00+03	47000.00
99F667	2017-07-01 07:55:00+03	135600.00
99F69A	2017-08-12 22:00:00+03	284400.00
99F725	2017-08-08 09:39:00+03	77000.00
99F726	2017-07-22 21:15:00+03	112000.00
99F804	2017-07-09 16:58:00+03	46000.00
99F847	2017-07-08 04:01:00+03	13400.00
99F87D	2017-08-10 05:35:00+03	14000.00
99F884	2017-08-02 08:58:00+03	46400.00
99F8AA	2017-07-10 01:48:00+03	246000.00
99F916	2017-07-07 01:52:00+03	40800.00
99F989	2017-06-30 12:59:00+03	143000.00
99F9C0	2017-07-01 07:20:00+03	96800.00
99F9D7	2017-07-19 09:52:00+03	386300.00
99F9FB	2017-07-16 07:48:00+03	103400.00
99FA05	2017-07-31 14:33:00+03	8200.00
99FA35	2017-07-14 16:32:00+03	57200.00
99FA55	2017-07-23 01:52:00+03	55800.00
99FA68	2017-08-08 12:56:00+03	19600.00
99FA6B	2017-08-05 01:37:00+03	23600.00
99FA7F	2017-07-08 18:18:00+03	73600.00
99FA85	2017-07-10 20:42:00+03	41200.00
99FB8B	2017-07-21 00:18:00+03	12400.00
99FBB1	2017-07-20 09:07:00+03	65000.00
99FBC4	2017-07-06 18:24:00+03	52400.00
99FC9A	2017-08-07 20:08:00+03	18400.00
99FC9E	2017-08-05 08:17:00+03	69800.00
99FE2F	2017-07-03 03:47:00+03	78300.00
99FE40	2017-07-29 21:32:00+03	339900.00
99FE5C	2017-07-11 13:03:00+03	93700.00
99FE84	2017-07-22 04:20:00+03	7400.00
99FF5E	2017-07-18 00:07:00+03	234800.00
99FF62	2017-06-29 02:01:00+03	65200.00
99FF7F	2017-08-07 21:28:00+03	38000.00
99FFD4	2017-07-24 15:39:00+03	69600.00
99FFFA	2017-08-04 00:09:00+03	62000.00
9A0076	2017-08-14 03:39:00+03	57500.00
9A010D	2017-07-09 16:54:00+03	66000.00
9A015A	2017-07-24 12:34:00+03	80200.00
9A019E	2017-06-27 23:17:00+03	38200.00
9A01AD	2017-07-20 11:50:00+03	76600.00
9A0237	2017-07-31 10:35:00+03	46400.00
9A02AB	2017-07-21 04:19:00+03	81700.00
9A02B7	2017-08-10 05:37:00+03	6300.00
9A02BA	2017-07-11 22:09:00+03	57400.00
9A032D	2017-08-03 04:21:00+03	226900.00
9A034C	2017-07-22 12:35:00+03	12000.00
9A0359	2017-07-29 09:31:00+03	27900.00
9A0368	2017-07-15 03:15:00+03	22000.00
9A0369	2017-08-09 08:35:00+03	50000.00
9A03EB	2017-08-04 00:41:00+03	105000.00
9A03FA	2017-08-09 08:35:00+03	26000.00
9A040B	2017-07-23 20:31:00+03	99200.00
9A0426	2017-07-05 00:18:00+03	20200.00
9A042D	2017-07-24 14:31:00+03	13400.00
9A0453	2017-08-09 04:30:00+03	18100.00
9A0473	2017-07-22 00:46:00+03	378400.00
9A04AA	2017-07-24 02:03:00+03	48800.00
9A04D1	2017-07-19 03:20:00+03	67800.00
9A0507	2017-07-06 06:27:00+03	14000.00
9A0518	2017-07-07 03:14:00+03	112000.00
9A05EA	2017-08-10 18:53:00+03	47000.00
9A05FD	2017-07-22 13:24:00+03	75600.00
9A0663	2017-07-25 00:59:00+03	37200.00
9A06C6	2017-07-27 21:38:00+03	81700.00
9A06EF	2017-07-21 23:31:00+03	419300.00
9A0757	2017-07-27 03:32:00+03	11600.00
9A076D	2017-07-29 13:46:00+03	50600.00
9A07D3	2017-06-30 21:03:00+03	369000.00
9A081E	2017-07-22 04:14:00+03	232800.00
9A0886	2017-06-29 16:33:00+03	23400.00
9A0889	2017-08-14 04:15:00+03	60700.00
9A08BE	2017-07-05 23:46:00+03	22000.00
9A093C	2017-07-04 08:08:00+03	46300.00
9A093D	2017-07-30 10:15:00+03	147700.00
9A093F	2017-07-10 18:48:00+03	38800.00
9A0951	2017-07-27 06:36:00+03	284400.00
9A0999	2017-07-03 23:38:00+03	119500.00
9A09A9	2017-08-13 19:06:00+03	31400.00
9A09BA	2017-07-01 05:35:00+03	25600.00
9A0A21	2017-08-03 14:30:00+03	64100.00
9A0A59	2017-07-01 10:08:00+03	21800.00
9A0A70	2017-07-01 20:15:00+03	44800.00
9A0B27	2017-07-18 14:57:00+03	54300.00
9A0B37	2017-07-25 11:31:00+03	12400.00
9A0B91	2017-06-30 20:29:00+03	42700.00
9A0BD6	2017-07-14 06:04:00+03	28000.00
9A0BEC	2017-07-17 19:02:00+03	29500.00
9A0CB2	2017-07-18 22:16:00+03	72200.00
9A0D7F	2017-07-21 08:04:00+03	31600.00
9A0D89	2017-08-05 16:40:00+03	78400.00
9A0DA9	2017-07-21 22:41:00+03	58200.00
9A0DBE	2017-07-06 03:49:00+03	147700.00
9A0DFC	2017-07-31 14:13:00+03	74400.00
9A0E78	2017-07-30 05:22:00+03	57500.00
9A0ECB	2017-08-09 00:58:00+03	92900.00
9A0EE7	2017-07-06 08:28:00+03	78000.00
9A0F19	2017-07-12 00:37:00+03	119700.00
9A0F2F	2017-07-13 01:30:00+03	67600.00
9A0F8E	2017-07-06 03:04:00+03	132800.00
9A1038	2017-07-21 18:50:00+03	57400.00
9A107D	2017-07-15 15:10:00+03	85000.00
9A1083	2017-08-11 11:52:00+03	28800.00
9A10BF	2017-08-08 19:39:00+03	38400.00
9A10EE	2017-08-10 04:30:00+03	61600.00
9A112D	2017-07-24 00:44:00+03	28800.00
9A11A3	2017-07-13 17:00:00+03	55500.00
9A120B	2017-08-03 00:34:00+03	31600.00
9A1226	2017-07-22 22:28:00+03	169000.00
9A1296	2017-07-23 04:25:00+03	24400.00
9A1345	2017-07-21 00:04:00+03	26700.00
9A13C5	2017-08-13 02:07:00+03	130400.00
9A1403	2017-08-09 04:51:00+03	83600.00
9A142A	2017-07-07 09:17:00+03	111600.00
9A14BF	2017-07-09 06:51:00+03	36900.00
9A1580	2017-08-14 19:05:00+03	153200.00
9A15FC	2017-08-15 13:04:00+03	73100.00
9A160C	2017-07-19 19:48:00+03	47100.00
9A166D	2017-08-04 07:39:00+03	22400.00
9A16DA	2017-07-05 02:41:00+03	156800.00
9A1760	2017-07-06 05:54:00+03	47000.00
9A17BF	2017-08-05 13:32:00+03	34100.00
9A17CF	2017-08-13 16:40:00+03	13400.00
9A180C	2017-07-18 15:22:00+03	47400.00
9A1847	2017-07-23 03:50:00+03	50000.00
9A188C	2017-07-10 17:36:00+03	76900.00
9A18C2	2017-08-13 06:15:00+03	13800.00
9A195A	2017-07-10 02:15:00+03	83700.00
9A197E	2017-07-14 02:36:00+03	124200.00
9A1A19	2017-07-14 13:55:00+03	12600.00
9A1A4A	2017-06-29 19:21:00+03	39000.00
9A1A53	2017-07-01 01:03:00+03	135600.00
9A1A99	2017-07-18 03:12:00+03	24400.00
9A1AAC	2017-08-13 05:26:00+03	54000.00
9A1B10	2017-08-09 16:14:00+03	23200.00
9A1B7F	2017-07-23 00:30:00+03	22000.00
9A1BA7	2017-07-12 01:31:00+03	318100.00
9A1BAC	2017-08-07 16:29:00+03	46400.00
9A1BD0	2017-08-11 15:16:00+03	85000.00
9A1BD5	2017-07-04 16:35:00+03	169300.00
9A1C32	2017-07-26 10:21:00+03	89600.00
9A1C83	2017-07-10 14:19:00+03	26000.00
9A1CC4	2017-07-12 01:55:00+03	78300.00
9A1D02	2017-07-28 02:01:00+03	59300.00
9A1D79	2017-07-23 14:04:00+03	28800.00
9A1D80	2017-07-30 19:36:00+03	97900.00
9A1D95	2017-08-09 11:09:00+03	133100.00
9A1E38	2017-08-03 02:56:00+03	6000.00
9A1E63	2017-07-08 18:09:00+03	124200.00
9A1E73	2017-07-17 17:40:00+03	192400.00
9A1EFA	2017-07-19 14:12:00+03	142800.00
9A1F02	2017-07-05 06:25:00+03	59200.00
9A1F10	2017-07-23 05:13:00+03	29600.00
9A1F34	2017-07-25 07:13:00+03	92000.00
9A1F56	2017-07-20 21:32:00+03	43600.00
9A1FE9	2017-07-08 20:03:00+03	65000.00
9A2039	2017-08-13 22:35:00+03	29600.00
9A2044	2017-07-11 00:56:00+03	46000.00
9A20A6	2017-08-12 13:29:00+03	26200.00
9A20ED	2017-06-29 03:42:00+03	50000.00
9A212A	2017-07-09 07:31:00+03	40800.00
9A2130	2017-07-05 16:41:00+03	24400.00
9A213D	2017-08-12 16:39:00+03	58900.00
9A21E0	2017-07-06 01:31:00+03	23200.00
9A21EB	2017-08-06 21:24:00+03	135400.00
9A21F6	2017-07-02 17:08:00+03	21800.00
9A2225	2017-07-08 03:09:00+03	50700.00
9A228C	2017-07-16 08:22:00+03	24400.00
9A231D	2017-07-23 01:14:00+03	126900.00
9A23A8	2017-08-13 14:38:00+03	56900.00
9A23BC	2017-08-02 09:19:00+03	12000.00
9A252B	2017-07-23 06:47:00+03	38400.00
9A2551	2017-07-07 17:57:00+03	131600.00
9A258E	2017-07-18 08:52:00+03	40000.00
9A259D	2017-07-14 19:32:00+03	35100.00
9A25B2	2017-07-18 07:30:00+03	118000.00
9A25C1	2017-07-20 07:05:00+03	51600.00
9A2678	2017-07-11 04:50:00+03	87700.00
9A26EF	2017-07-01 02:54:00+03	28600.00
9A2716	2017-08-05 10:22:00+03	23200.00
9A273E	2017-07-06 12:21:00+03	57400.00
9A27A1	2017-07-24 05:35:00+03	150600.00
9A27A4	2017-07-21 21:53:00+03	6700.00
9A27A9	2017-08-15 09:22:00+03	101100.00
9A27EB	2017-08-06 09:16:00+03	90400.00
9A2813	2017-07-25 18:44:00+03	50300.00
9A2881	2017-07-17 05:43:00+03	137400.00
9A288C	2017-08-01 14:21:00+03	406700.00
9A288E	2017-06-30 02:16:00+03	155000.00
9A2891	2017-08-15 13:21:00+03	77900.00
9A28F1	2017-07-14 18:57:00+03	74800.00
9A28FC	2017-07-20 01:55:00+03	132800.00
9A29B0	2017-07-06 05:33:00+03	12000.00
9A29ED	2017-08-06 01:59:00+03	217600.00
9A2A2D	2017-07-14 22:22:00+03	44700.00
9A2A75	2017-07-17 13:03:00+03	306600.00
9A2A7C	2017-07-07 08:54:00+03	142700.00
9A2AC6	2017-07-14 13:52:00+03	25600.00
9A2AC8	2017-08-05 14:28:00+03	61700.00
9A2AE3	2017-08-05 13:07:00+03	28000.00
9A2BBA	2017-07-13 19:35:00+03	70900.00
9A2BE7	2017-08-12 09:13:00+03	51900.00
9A2D00	2017-07-05 17:24:00+03	28800.00
9A2D3E	2017-07-05 13:03:00+03	94800.00
9A2DB7	2017-07-13 08:44:00+03	24200.00
9A2DC1	2017-06-29 12:15:00+03	128800.00
9A2E85	2017-08-12 06:45:00+03	24400.00
9A2EF9	2017-08-02 09:58:00+03	85000.00
9A2F0C	2017-08-03 09:44:00+03	119500.00
9A2F6A	2017-07-16 08:26:00+03	22000.00
9A2FD4	2017-08-14 03:52:00+03	40100.00
9A305C	2017-08-03 14:05:00+03	396200.00
9A30CA	2017-07-24 02:18:00+03	81600.00
9A30DD	2017-08-06 09:24:00+03	186900.00
9A30EB	2017-08-11 06:08:00+03	66700.00
9A31BF	2017-07-13 23:56:00+03	181600.00
9A3203	2017-07-20 03:28:00+03	70100.00
9A321A	2017-08-04 11:15:00+03	95600.00
9A32AA	2017-07-21 19:12:00+03	162600.00
9A33F4	2017-08-04 21:54:00+03	112000.00
9A3431	2017-07-12 01:23:00+03	12600.00
9A3442	2017-07-09 08:53:00+03	22400.00
9A3471	2017-08-04 16:41:00+03	196700.00
9A347B	2017-07-27 09:54:00+03	219700.00
9A34E8	2017-08-07 23:46:00+03	8200.00
9A34FA	2017-07-10 10:57:00+03	119600.00
9A3507	2017-07-23 11:06:00+03	101200.00
9A3573	2017-07-27 13:57:00+03	26200.00
9A35EA	2017-07-01 14:40:00+03	22600.00
9A360E	2017-08-01 15:29:00+03	66600.00
9A369F	2017-06-26 14:22:00+03	191800.00
9A36B3	2017-08-13 10:41:00+03	188500.00
9A36C9	2017-08-09 06:04:00+03	73400.00
9A36CC	2017-07-11 23:04:00+03	112200.00
9A373C	2017-07-05 14:36:00+03	83000.00
9A37D0	2017-07-20 03:05:00+03	104000.00
9A37EC	2017-08-07 02:17:00+03	37900.00
9A385D	2017-07-20 13:01:00+03	36200.00
9A3894	2017-08-03 09:01:00+03	73300.00
9A38DF	2017-07-07 19:34:00+03	6300.00
9A38E2	2017-07-26 15:57:00+03	3700.00
9A3905	2017-07-13 18:40:00+03	6000.00
9A3954	2017-08-07 01:05:00+03	77500.00
9A3956	2017-07-25 16:24:00+03	37600.00
9A395B	2017-08-03 09:32:00+03	406800.00
9A3977	2017-07-21 18:55:00+03	133200.00
9A3993	2017-08-01 01:46:00+03	68900.00
9A399C	2017-07-02 16:12:00+03	69700.00
9A39AF	2017-07-27 22:58:00+03	92400.00
9A3AD4	2017-08-09 12:10:00+03	55800.00
9A3AD5	2017-07-30 23:46:00+03	83600.00
9A3B18	2017-07-23 00:44:00+03	39800.00
9A3B88	2017-06-30 18:05:00+03	238700.00
9A3B8C	2017-07-15 13:04:00+03	58600.00
9A3BD7	2017-07-04 18:55:00+03	54600.00
9A3C0C	2017-07-23 09:53:00+03	28000.00
9A3C2F	2017-07-24 00:13:00+03	50100.00
9A3C32	2017-07-07 11:45:00+03	199700.00
9A3C81	2017-07-15 20:25:00+03	45200.00
9A3CCE	2017-08-15 02:39:00+03	56200.00
9A3CFD	2017-07-26 21:15:00+03	49600.00
9A3D6D	2017-08-08 11:42:00+03	190100.00
9A3DBA	2017-07-27 14:34:00+03	45100.00
9A3DCD	2017-07-12 14:45:00+03	75600.00
9A3DDB	2017-08-01 06:57:00+03	39200.00
9A3DDC	2017-07-15 00:38:00+03	21800.00
9A3DFB	2017-07-10 20:24:00+03	375200.00
9A3E0D	2017-06-28 20:35:00+03	26000.00
9A3E6B	2017-07-18 11:20:00+03	90400.00
9A3E73	2017-08-01 08:14:00+03	28700.00
9A3ECA	2017-08-14 15:00:00+03	133200.00
9A3EE2	2017-08-09 07:08:00+03	115600.00
9A3F04	2017-07-31 21:25:00+03	39500.00
9A3F15	2017-07-18 00:57:00+03	75300.00
9A3F1F	2017-07-14 23:32:00+03	41600.00
9A3FC1	2017-07-25 13:55:00+03	162600.00
9A3FC6	2017-07-20 15:47:00+03	42400.00
9A4034	2017-07-22 20:47:00+03	34000.00
9A4058	2017-08-09 16:26:00+03	35700.00
9A406B	2017-08-02 09:56:00+03	55800.00
9A40F6	2017-08-14 19:16:00+03	32700.00
9A411A	2017-07-04 15:43:00+03	56000.00
9A4136	2017-07-07 05:19:00+03	23600.00
9A4156	2017-07-20 06:32:00+03	54600.00
9A41BC	2017-07-12 03:33:00+03	27300.00
9A41F0	2017-07-05 15:33:00+03	132800.00
9A4222	2017-07-23 04:45:00+03	50800.00
9A428D	2017-08-07 22:39:00+03	25600.00
9A43CF	2017-07-27 17:58:00+03	67100.00
9A4445	2017-07-24 22:50:00+03	23400.00
9A4451	2017-08-10 14:15:00+03	31600.00
9A445D	2017-07-20 09:36:00+03	112000.00
9A446B	2017-08-05 01:47:00+03	12600.00
9A44CE	2017-08-03 15:20:00+03	19600.00
9A44D9	2017-07-17 09:21:00+03	38400.00
9A4515	2017-08-14 16:54:00+03	22400.00
9A4578	2017-08-12 23:22:00+03	44800.00
9A45D2	2017-08-13 09:43:00+03	16400.00
9A45ED	2017-08-15 08:12:00+03	27300.00
9A4633	2017-07-07 17:11:00+03	59800.00
9A465C	2017-08-03 14:50:00+03	13400.00
9A4675	2017-07-18 05:48:00+03	54400.00
9A470F	2017-07-23 14:04:00+03	89700.00
9A4731	2017-07-30 21:09:00+03	94500.00
9A4745	2017-07-29 23:13:00+03	48500.00
9A4893	2017-07-14 23:16:00+03	28000.00
9A4905	2017-07-24 11:30:00+03	22000.00
9A4928	2017-08-02 05:11:00+03	23600.00
9A4974	2017-07-11 19:05:00+03	38600.00
9A497D	2017-08-04 12:56:00+03	105000.00
9A49C7	2017-07-09 03:12:00+03	23200.00
9A49E3	2017-07-08 09:32:00+03	62600.00
9A4A60	2017-07-11 10:23:00+03	85000.00
9A4A8F	2017-07-10 14:25:00+03	116000.00
9A4B0E	2017-07-26 16:36:00+03	71600.00
9A4B47	2017-08-08 12:11:00+03	8000.00
9A4BD6	2017-07-13 06:05:00+03	201200.00
9A4C12	2017-07-19 13:43:00+03	277800.00
9A4C49	2017-08-14 19:25:00+03	52300.00
9A4CB8	2017-07-19 01:05:00+03	37900.00
9A4CD5	2017-07-25 04:17:00+03	200300.00
9A4CD6	2017-08-03 20:54:00+03	42700.00
9A4CE0	2017-07-26 19:55:00+03	40800.00
9A4CE9	2017-07-14 09:50:00+03	141600.00
9A4D0A	2017-07-30 20:35:00+03	117800.00
9A4DA3	2017-07-22 03:37:00+03	56600.00
9A4DB5	2017-08-03 06:08:00+03	57300.00
9A4DD1	2017-08-15 05:37:00+03	15000.00
9A4DE1	2017-07-29 18:17:00+03	32800.00
9A4E3E	2017-08-11 10:00:00+03	55600.00
9A4E49	2017-08-09 21:30:00+03	148200.00
9A4E88	2017-08-12 03:36:00+03	16400.00
9A4EC2	2017-07-28 10:38:00+03	167500.00
9A4F15	2017-07-29 19:35:00+03	80800.00
9A4F2A	2017-07-12 14:06:00+03	23200.00
9A4F2B	2017-08-08 07:13:00+03	368800.00
9A4F3D	2017-07-28 08:48:00+03	26000.00
9A4FC3	2017-08-14 17:16:00+03	6300.00
9A4FFD	2017-07-07 21:37:00+03	44800.00
9A4FFE	2017-07-18 19:06:00+03	46900.00
9A501F	2017-07-19 11:29:00+03	123000.00
9A5023	2017-07-04 09:14:00+03	25600.00
9A5043	2017-07-27 04:56:00+03	24800.00
9A5089	2017-06-28 00:12:00+03	28000.00
9A513F	2017-08-14 23:06:00+03	44800.00
9A51A4	2017-07-21 05:36:00+03	190400.00
9A51E0	2017-08-08 22:09:00+03	12600.00
9A5202	2017-07-06 05:39:00+03	70400.00
9A5213	2017-08-08 22:25:00+03	8400.00
9A5260	2017-07-23 01:50:00+03	78200.00
9A526A	2017-08-13 02:06:00+03	87300.00
9A52A0	2017-07-17 20:05:00+03	200700.00
9A52A4	2017-07-30 01:39:00+03	98300.00
9A52A6	2017-07-05 20:55:00+03	104600.00
9A52CB	2017-07-22 09:00:00+03	94000.00
9A5309	2017-08-01 20:27:00+03	29400.00
9A5364	2017-06-30 01:06:00+03	38800.00
9A53B3	2017-07-11 14:22:00+03	101100.00
9A540F	2017-07-03 17:49:00+03	28800.00
9A5414	2017-07-23 14:33:00+03	398500.00
9A5438	2017-07-11 14:59:00+03	78300.00
9A546B	2017-07-18 04:34:00+03	42800.00
9A5479	2017-08-09 13:55:00+03	69500.00
9A550F	2017-08-04 13:19:00+03	7400.00
9A5519	2017-08-06 21:35:00+03	59800.00
9A5592	2017-08-06 00:57:00+03	398600.00
9A55BB	2017-07-09 22:14:00+03	398300.00
9A55D3	2017-07-14 16:51:00+03	21500.00
9A55E4	2017-07-22 01:29:00+03	27800.00
9A5658	2017-07-04 00:04:00+03	493200.00
9A5717	2017-08-02 07:40:00+03	15400.00
9A5722	2017-06-27 16:05:00+03	53600.00
9A5726	2017-07-05 12:18:00+03	76000.00
9A5740	2017-06-29 11:27:00+03	14400.00
9A582D	2017-07-01 08:32:00+03	58600.00
9A587B	2017-07-15 18:34:00+03	61800.00
9A594B	2017-08-13 10:37:00+03	28800.00
9A5952	2017-07-09 13:36:00+03	52300.00
9A597A	2017-08-07 02:12:00+03	23600.00
9A5A1E	2017-07-25 05:37:00+03	19600.00
9A5A91	2017-08-13 01:55:00+03	98400.00
9A5AAE	2017-07-24 02:09:00+03	75300.00
9A5ABC	2017-08-08 02:15:00+03	65200.00
9A5B35	2017-07-22 18:07:00+03	59300.00
9A5B60	2017-08-05 15:24:00+03	12600.00
9A5B63	2017-07-27 17:38:00+03	65600.00
9A5BBF	2017-07-19 21:24:00+03	38200.00
9A5BEB	2017-07-06 09:51:00+03	31400.00
9A5C31	2017-07-31 12:03:00+03	47400.00
9A5D44	2017-07-05 08:48:00+03	23600.00
9A5D5E	2017-08-09 04:45:00+03	70200.00
9A5DE0	2017-07-16 12:02:00+03	73200.00
9A5DF5	2017-07-14 13:55:00+03	50800.00
9A5E19	2017-08-01 06:01:00+03	61900.00
9A5E1A	2017-07-19 02:13:00+03	28000.00
9A5E4A	2017-06-30 19:45:00+03	25000.00
9A5EB5	2017-08-03 00:35:00+03	11000.00
9A5F22	2017-07-03 20:46:00+03	26000.00
9A5F44	2017-08-01 07:53:00+03	47400.00
9A5F8A	2017-07-02 01:35:00+03	135200.00
9A5FEA	2017-07-19 11:07:00+03	68900.00
9A5FF8	2017-07-26 11:06:00+03	73900.00
9A600F	2017-07-24 00:26:00+03	132800.00
9A6065	2017-07-18 09:28:00+03	32200.00
9A60CD	2017-08-09 12:48:00+03	77200.00
9A60EC	2017-07-15 23:18:00+03	48800.00
9A610E	2017-08-02 09:18:00+03	28800.00
9A613C	2017-07-06 06:47:00+03	25900.00
9A6158	2017-08-10 10:45:00+03	182300.00
9A61D2	2017-07-17 17:53:00+03	105100.00
9A61F1	2017-07-04 22:40:00+03	6700.00
9A6220	2017-08-13 04:52:00+03	102800.00
9A6238	2017-07-11 15:19:00+03	266400.00
9A6286	2017-07-17 15:15:00+03	66000.00
9A62D2	2017-08-01 21:31:00+03	35700.00
9A6315	2017-08-06 18:39:00+03	27000.00
9A6373	2017-06-27 08:41:00+03	146300.00
9A6397	2017-07-04 02:23:00+03	68800.00
9A6399	2017-08-06 03:29:00+03	25800.00
9A64FA	2017-08-12 03:49:00+03	86400.00
9A6503	2017-08-08 03:33:00+03	91100.00
9A6563	2017-07-08 10:32:00+03	111600.00
9A658E	2017-08-11 02:05:00+03	52800.00
9A659B	2017-08-06 14:48:00+03	140900.00
9A65BF	2017-06-29 16:17:00+03	43000.00
9A65C6	2017-08-12 03:24:00+03	31400.00
9A65D1	2017-08-06 11:16:00+03	119600.00
9A6620	2017-07-30 18:38:00+03	35800.00
9A6691	2017-07-05 17:17:00+03	87300.00
9A66A8	2017-08-03 05:32:00+03	28800.00
9A66AB	2017-07-17 02:50:00+03	23400.00
9A66BC	2017-07-12 14:09:00+03	22100.00
9A66ED	2017-07-07 06:23:00+03	25300.00
9A673B	2017-07-02 00:22:00+03	105100.00
9A67AD	2017-07-12 07:45:00+03	86200.00
9A67DB	2017-07-06 15:54:00+03	38800.00
9A684E	2017-08-06 14:22:00+03	32700.00
9A687A	2017-08-08 11:22:00+03	15800.00
9A689C	2017-08-11 15:51:00+03	112000.00
9A6906	2017-08-06 12:51:00+03	40800.00
9A692E	2017-07-07 12:24:00+03	246000.00
9A6972	2017-08-14 13:40:00+03	7400.00
9A69BA	2017-07-28 10:34:00+03	81700.00
9A69ED	2017-08-03 21:33:00+03	21400.00
9A6A19	2017-07-08 17:09:00+03	44000.00
9A6A34	2017-08-14 18:28:00+03	61800.00
9A6A8D	2017-07-26 12:27:00+03	266400.00
9A6AB0	2017-07-03 09:38:00+03	84500.00
9A6B40	2017-08-03 09:06:00+03	64100.00
9A6BCF	2017-07-30 08:33:00+03	140900.00
9A6C04	2017-07-12 19:27:00+03	264000.00
9A6C0A	2017-07-10 21:15:00+03	89700.00
9A6C57	2017-08-02 17:27:00+03	43900.00
9A6C71	2017-07-23 11:44:00+03	58400.00
9A6C9E	2017-07-01 03:47:00+03	50600.00
9A6CA9	2017-06-28 01:03:00+03	99200.00
9A6CBA	2017-07-20 23:17:00+03	65500.00
9A6D0A	2017-07-02 04:03:00+03	200200.00
9A6D73	2017-07-01 17:06:00+03	97600.00
9A6DC4	2017-08-09 03:33:00+03	36200.00
9A6E2F	2017-08-02 00:04:00+03	86600.00
9A6E53	2017-07-09 10:04:00+03	86800.00
9A6E56	2017-08-08 09:02:00+03	91800.00
9A6E58	2017-07-23 05:24:00+03	26800.00
9A6E81	2017-07-14 10:42:00+03	99200.00
9A6ED7	2017-07-09 01:31:00+03	44200.00
9A6F3C	2017-07-11 14:51:00+03	84000.00
9A6F5B	2017-06-28 10:04:00+03	64400.00
9A6F71	2017-07-20 14:50:00+03	24700.00
9A6F7E	2017-07-05 21:42:00+03	44600.00
9A6F88	2017-08-15 16:42:00+03	102100.00
9A6FAA	2017-07-02 14:10:00+03	16400.00
9A7007	2017-07-08 02:34:00+03	40400.00
9A701B	2017-07-24 16:32:00+03	48500.00
9A701E	2017-07-14 22:05:00+03	83100.00
9A7042	2017-08-08 18:44:00+03	23600.00
9A705F	2017-08-01 00:09:00+03	28000.00
9A70C0	2017-08-10 19:13:00+03	93600.00
9A712B	2017-08-04 08:18:00+03	7400.00
9A7150	2017-07-19 05:00:00+03	254600.00
9A71A3	2017-07-24 15:33:00+03	11600.00
9A71A4	2017-07-28 02:55:00+03	117200.00
9A739E	2017-07-04 12:24:00+03	166100.00
9A73A9	2017-07-26 04:21:00+03	46400.00
9A73DE	2017-07-23 11:16:00+03	62000.00
9A7410	2017-08-03 09:02:00+03	39400.00
9A7485	2017-07-04 08:59:00+03	65300.00
9A749C	2017-08-04 02:41:00+03	82700.00
9A74CF	2017-07-25 02:25:00+03	88100.00
9A74FB	2017-08-09 00:47:00+03	23600.00
9A7524	2017-08-04 07:09:00+03	112000.00
9A75A2	2017-07-26 05:25:00+03	132800.00
9A75A6	2017-08-11 23:10:00+03	20400.00
9A7609	2017-08-08 12:49:00+03	120500.00
9A766A	2017-08-01 11:37:00+03	52100.00
9A769F	2017-07-11 21:02:00+03	27200.00
9A76B6	2017-08-13 20:15:00+03	11700.00
9A773B	2017-08-15 01:50:00+03	88900.00
9A7791	2017-07-19 06:36:00+03	58000.00
9A77C3	2017-07-11 03:52:00+03	48800.00
9A78FE	2017-08-11 23:18:00+03	58600.00
9A7992	2017-07-07 11:37:00+03	92400.00
9A79A2	2017-08-03 05:40:00+03	99300.00
9A7A1B	2017-07-17 16:52:00+03	24700.00
9A7A67	2017-07-03 20:24:00+03	134400.00
9A7B38	2017-07-20 18:17:00+03	88500.00
9A7B62	2017-07-29 10:55:00+03	103600.00
9A7B8C	2017-08-10 00:11:00+03	111000.00
9A7BA4	2017-07-08 04:14:00+03	21200.00
9A7BC0	2017-07-17 15:56:00+03	123000.00
9A7C93	2017-08-05 12:33:00+03	386300.00
9A7C9E	2017-07-31 12:10:00+03	35600.00
9A7C9F	2017-07-27 07:13:00+03	12000.00
9A7CBB	2017-07-18 02:05:00+03	46000.00
9A7D41	2017-07-16 00:05:00+03	64500.00
9A7D4D	2017-07-12 11:54:00+03	7800.00
9A7D53	2017-08-10 10:59:00+03	6300.00
9A7DB1	2017-07-29 17:17:00+03	105000.00
9A7DD8	2017-07-11 08:34:00+03	44800.00
9A7DF7	2017-08-02 14:28:00+03	66600.00
9A7DFF	2017-08-15 14:17:00+03	438800.00
9A7E86	2017-08-15 06:06:00+03	8200.00
9A7EE6	2017-08-08 21:06:00+03	67600.00
9A7F03	2017-07-25 15:10:00+03	24800.00
9A7F44	2017-07-24 02:18:00+03	37200.00
9A7F7C	2017-08-15 01:58:00+03	260300.00
9A7FA6	2017-07-03 15:10:00+03	45100.00
9A7FB6	2017-07-17 09:47:00+03	185800.00
9A8010	2017-07-09 19:30:00+03	101100.00
9A8036	2017-08-04 13:12:00+03	24400.00
9A806A	2017-08-09 17:39:00+03	270800.00
9A80B9	2017-07-23 20:15:00+03	144900.00
9A80BF	2017-07-11 13:50:00+03	80000.00
9A812F	2017-07-20 00:12:00+03	23600.00
9A817E	2017-08-05 07:11:00+03	28800.00
9A8182	2017-08-04 15:25:00+03	29400.00
9A8185	2017-08-08 08:00:00+03	86500.00
9A81AB	2017-08-08 23:03:00+03	16000.00
9A81C9	2017-07-20 09:52:00+03	48800.00
9A81D2	2017-08-01 04:37:00+03	14000.00
9A81DA	2017-07-22 19:28:00+03	92900.00
9A8266	2017-07-25 22:57:00+03	68800.00
9A8390	2017-08-12 02:58:00+03	147200.00
9A8451	2017-08-03 19:43:00+03	234600.00
9A8499	2017-07-31 11:25:00+03	21800.00
9A84C9	2017-08-09 15:10:00+03	44800.00
9A84F5	2017-06-29 16:16:00+03	25100.00
9A85D5	2017-07-03 17:17:00+03	131600.00
9A85E9	2017-07-27 00:07:00+03	121500.00
9A85F8	2017-08-15 10:53:00+03	54000.00
9A8674	2017-07-15 11:02:00+03	112000.00
9A867C	2017-08-05 06:38:00+03	231800.00
9A86F4	2017-07-10 22:26:00+03	46500.00
9A86FD	2017-07-29 01:31:00+03	54800.00
9A8731	2017-07-19 17:15:00+03	94000.00
9A874F	2017-08-05 13:52:00+03	75600.00
9A8754	2017-07-31 22:55:00+03	81900.00
9A8776	2017-07-16 13:00:00+03	6700.00
9A88B5	2017-07-04 10:42:00+03	56000.00
9A88BF	2017-07-10 04:35:00+03	243600.00
9A8913	2017-07-02 08:13:00+03	67600.00
9A89F8	2017-08-01 04:30:00+03	23200.00
9A8A42	2017-07-31 09:57:00+03	32700.00
9A8AFF	2017-07-15 15:38:00+03	517400.00
9A8BF0	2017-07-29 23:35:00+03	25000.00
9A8C26	2017-07-27 08:45:00+03	553800.00
9A8C69	2017-07-15 00:30:00+03	55800.00
9A8CD1	2017-07-11 10:55:00+03	116900.00
9A8D20	2017-07-06 12:45:00+03	60400.00
9A8DEB	2017-07-20 17:31:00+03	34000.00
9A8DFE	2017-06-27 03:08:00+03	27400.00
9A8E00	2017-08-05 06:23:00+03	12600.00
9A8E39	2017-07-28 03:47:00+03	25200.00
9A8E3D	2017-08-14 16:21:00+03	386400.00
9A8E69	2017-07-23 07:42:00+03	58900.00
9A8EB3	2017-07-04 22:13:00+03	40800.00
9A8EF6	2017-07-02 12:27:00+03	28000.00
9A8F5D	2017-07-01 14:21:00+03	107400.00
9A8FE3	2017-08-01 21:25:00+03	81200.00
9A9019	2017-07-06 16:17:00+03	92700.00
9A9035	2017-08-01 19:24:00+03	40200.00
9A908D	2017-07-17 07:45:00+03	168000.00
9A90A8	2017-08-05 14:56:00+03	40400.00
9A90FF	2017-07-01 01:24:00+03	115100.00
9A9104	2017-07-06 02:50:00+03	39300.00
9A910E	2017-07-11 22:32:00+03	118100.00
9A9145	2017-07-24 17:48:00+03	42800.00
9A915F	2017-08-09 08:27:00+03	32800.00
9A9176	2017-08-08 12:08:00+03	65600.00
9A91C5	2017-07-20 04:17:00+03	136800.00
9A9252	2017-07-27 10:38:00+03	29400.00
9A925E	2017-08-13 22:54:00+03	26700.00
9A92E1	2017-07-24 02:09:00+03	147200.00
9A9304	2017-07-16 02:53:00+03	67700.00
9A93A1	2017-08-07 15:20:00+03	53300.00
9A93AF	2017-07-29 02:38:00+03	152900.00
9A93FE	2017-07-27 06:11:00+03	22000.00
9A942F	2017-07-31 04:21:00+03	34000.00
9A9465	2017-08-03 03:44:00+03	46900.00
9A94BE	2017-08-12 16:50:00+03	115900.00
9A94F2	2017-07-13 20:02:00+03	6700.00
9A9508	2017-07-27 12:10:00+03	49000.00
9A955D	2017-07-26 14:26:00+03	47000.00
9A959C	2017-08-04 04:08:00+03	82000.00
9A95CC	2017-07-17 07:28:00+03	399600.00
9A95F3	2017-07-24 19:18:00+03	89600.00
9A961D	2017-08-08 13:58:00+03	7400.00
9A963A	2017-07-14 16:53:00+03	15700.00
9A9690	2017-07-19 10:38:00+03	100600.00
9A96A4	2017-07-12 05:54:00+03	46000.00
9A9744	2017-08-07 21:30:00+03	48800.00
9A975D	2017-07-17 16:48:00+03	52900.00
9A976A	2017-07-18 10:30:00+03	75800.00
9A9779	2017-08-09 11:51:00+03	22000.00
9A977A	2017-07-16 20:04:00+03	98000.00
9A97D4	2017-07-13 23:24:00+03	129700.00
9A97F4	2017-07-07 05:57:00+03	105100.00
9A9814	2017-07-28 20:07:00+03	54800.00
9A9818	2017-07-20 13:18:00+03	38600.00
9A989D	2017-07-28 15:32:00+03	19600.00
9A9905	2017-07-03 15:20:00+03	664200.00
9A993C	2017-07-05 01:13:00+03	83100.00
9A99E8	2017-07-03 03:51:00+03	103500.00
9A9A3B	2017-07-05 13:24:00+03	12600.00
9A9A71	2017-07-07 11:18:00+03	56000.00
9A9A79	2017-07-15 16:31:00+03	47100.00
9A9AA2	2017-07-28 20:16:00+03	6800.00
9A9B04	2017-08-02 08:49:00+03	70600.00
9A9B0D	2017-07-28 14:26:00+03	57800.00
9A9B1D	2017-08-10 12:02:00+03	24400.00
9A9B2E	2017-07-15 12:44:00+03	42800.00
9A9B73	2017-08-10 18:26:00+03	62000.00
9A9BBA	2017-07-02 01:08:00+03	73300.00
9A9C0A	2017-07-12 18:15:00+03	36200.00
9A9C16	2017-08-10 22:31:00+03	12600.00
9A9C1F	2017-08-09 03:30:00+03	307900.00
9A9C70	2017-07-07 07:04:00+03	369000.00
9A9CB6	2017-07-26 03:03:00+03	117500.00
9A9D84	2017-07-27 22:09:00+03	40000.00
9A9E6B	2017-08-05 17:34:00+03	26000.00
9A9E8A	2017-07-20 19:49:00+03	58200.00
9A9ECD	2017-07-18 22:35:00+03	23600.00
9A9ED4	2017-07-24 07:21:00+03	27000.00
9A9EE4	2017-07-30 05:08:00+03	46000.00
9A9EED	2017-08-05 11:26:00+03	92000.00
9A9F30	2017-08-10 22:46:00+03	27200.00
9A9F41	2017-07-09 12:23:00+03	11600.00
9A9F48	2017-07-13 21:51:00+03	38600.00
9A9F83	2017-07-04 06:40:00+03	105000.00
9A9F95	2017-07-16 06:01:00+03	18300.00
9A9F98	2017-07-09 05:41:00+03	23600.00
9A9FE6	2017-08-11 17:13:00+03	32300.00
9A9FE8	2017-07-27 06:59:00+03	8200.00
9AA04B	2017-07-16 22:17:00+03	32800.00
9AA07F	2017-08-06 06:41:00+03	44800.00
9AA098	2017-07-22 12:18:00+03	57600.00
9AA0B3	2017-07-10 01:07:00+03	54500.00
9AA0F5	2017-07-31 00:08:00+03	303100.00
9AA133	2017-08-09 19:07:00+03	42400.00
9AA149	2017-06-29 06:10:00+03	8400.00
9AA1AB	2017-07-23 21:05:00+03	143400.00
9AA1F4	2017-07-24 03:20:00+03	112000.00
9AA20E	2017-07-11 23:54:00+03	32700.00
9AA212	2017-07-13 15:53:00+03	119700.00
9AA2AD	2017-07-11 00:29:00+03	56600.00
9AA2CA	2017-07-25 14:52:00+03	111600.00
9AA2D5	2017-07-31 13:15:00+03	67600.00
9AA392	2017-08-08 22:18:00+03	56000.00
9AA3D0	2017-07-04 03:19:00+03	122000.00
9AA4A1	2017-07-04 16:46:00+03	9000.00
9AA4D6	2017-07-23 12:41:00+03	79900.00
9AA4FD	2017-08-11 03:34:00+03	85200.00
9AA504	2017-07-26 15:55:00+03	127500.00
9AA5A2	2017-07-13 23:53:00+03	42800.00
9AA5B7	2017-08-05 15:55:00+03	46400.00
9AA5DB	2017-07-24 08:19:00+03	399600.00
9AA5F6	2017-08-07 18:22:00+03	23200.00
9AA60A	2017-07-22 20:01:00+03	101500.00
9AA6A7	2017-07-01 04:22:00+03	147200.00
9AA75E	2017-08-09 02:43:00+03	71500.00
9AA769	2017-07-10 13:24:00+03	10600.00
9AA821	2017-06-27 05:31:00+03	28800.00
9AA8CD	2017-07-15 14:00:00+03	13600.00
9AA8D3	2017-07-27 07:54:00+03	134300.00
9AA956	2017-07-15 12:36:00+03	241500.00
9AA95E	2017-07-21 18:50:00+03	135000.00
9AA9B0	2017-08-05 23:11:00+03	177600.00
9AA9DE	2017-07-20 23:22:00+03	67200.00
9AA9E6	2017-07-12 01:05:00+03	75800.00
9AAA37	2017-07-07 19:55:00+03	16400.00
9AAA7D	2017-07-30 23:21:00+03	92900.00
9AAA87	2017-07-22 06:58:00+03	139300.00
9AAAE4	2017-07-12 08:25:00+03	28800.00
9AAB2D	2017-08-12 15:48:00+03	39800.00
9AAB7F	2017-07-17 07:10:00+03	8400.00
9AABE5	2017-07-10 10:15:00+03	39200.00
9AADA3	2017-07-06 22:59:00+03	55800.00
9AADB2	2017-07-18 09:00:00+03	149700.00
9AADCA	2017-07-15 18:51:00+03	48100.00
9AAE8D	2017-08-14 02:41:00+03	16800.00
9AAEC4	2017-08-10 06:58:00+03	46400.00
9AAEF7	2017-07-06 12:50:00+03	64800.00
9AAF1F	2017-07-17 14:36:00+03	56000.00
9AAF2D	2017-08-14 18:59:00+03	26000.00
9AAF4F	2017-07-09 10:26:00+03	51600.00
9AAF56	2017-07-03 14:09:00+03	46400.00
9AB079	2017-07-05 14:14:00+03	22000.00
9AB101	2017-07-09 14:36:00+03	120800.00
9AB1CC	2017-08-07 17:44:00+03	31600.00
9AB1E8	2017-06-28 18:49:00+03	6800.00
9AB20C	2017-08-14 16:55:00+03	47400.00
9AB217	2017-07-26 05:01:00+03	28000.00
9AB222	2017-08-05 18:13:00+03	29500.00
9AB239	2017-07-28 01:05:00+03	24400.00
9AB28A	2017-08-10 13:04:00+03	25600.00
9AB2B3	2017-07-07 01:32:00+03	78400.00
9AB2C5	2017-08-03 17:45:00+03	18600.00
9AB31D	2017-07-21 11:44:00+03	50000.00
9AB339	2017-07-18 03:15:00+03	23400.00
9AB364	2017-07-27 01:45:00+03	49400.00
9AB3D3	2017-08-15 15:14:00+03	64800.00
9AB3D9	2017-08-15 01:42:00+03	64100.00
9AB3FF	2017-07-09 04:15:00+03	163800.00
9AB4C2	2017-07-23 07:43:00+03	61400.00
9AB4E5	2017-07-12 02:34:00+03	111600.00
9AB4FA	2017-08-08 15:17:00+03	65500.00
9AB57D	2017-07-14 14:49:00+03	80300.00
9AB5D0	2017-08-02 21:01:00+03	131100.00
9AB684	2017-07-21 14:09:00+03	65900.00
9AB696	2017-08-11 09:47:00+03	177200.00
9AB69D	2017-07-26 06:42:00+03	131600.00
9AB6CC	2017-07-28 06:59:00+03	160700.00
9AB6E7	2017-06-26 05:54:00+03	265700.00
9AB6E8	2017-07-13 07:29:00+03	22000.00
9AB71A	2017-07-19 07:38:00+03	26000.00
9AB76F	2017-07-12 11:46:00+03	46300.00
9AB777	2017-08-05 00:01:00+03	62000.00
9AB7B7	2017-08-03 17:18:00+03	23600.00
9AB7C9	2017-08-02 10:16:00+03	46300.00
9AB83F	2017-07-25 04:19:00+03	113200.00
9AB88C	2017-08-13 07:20:00+03	43200.00
9AB8A0	2017-07-27 10:57:00+03	120700.00
9AB8B7	2017-07-28 02:55:00+03	13600.00
9AB907	2017-07-25 19:36:00+03	53200.00
9AB955	2017-07-16 19:39:00+03	73500.00
9AB97C	2017-07-04 06:49:00+03	57400.00
9AB9B9	2017-07-21 19:53:00+03	101200.00
9AB9F2	2017-07-08 07:50:00+03	11600.00
9AB9F3	2017-08-13 02:05:00+03	30400.00
9ABA0E	2017-08-15 06:41:00+03	27000.00
9ABA47	2017-08-08 02:37:00+03	28800.00
9ABA56	2017-07-21 19:01:00+03	35300.00
9ABA68	2017-08-05 00:41:00+03	120100.00
9ABA6E	2017-07-03 10:55:00+03	37200.00
9ABAAF	2017-07-18 17:16:00+03	213800.00
9ABACB	2017-07-22 14:38:00+03	88800.00
9ABB3C	2017-07-01 00:33:00+03	168600.00
9ABBCA	2017-08-10 00:25:00+03	33200.00
9ABC5E	2017-07-23 14:01:00+03	13000.00
9ABC74	2017-07-05 01:23:00+03	27800.00
9ABCB0	2017-08-05 13:02:00+03	39300.00
9ABCF6	2017-08-15 07:21:00+03	12000.00
9ABD1E	2017-07-31 05:48:00+03	270800.00
9ABD5B	2017-07-23 03:41:00+03	134700.00
9ABDCD	2017-07-19 01:59:00+03	31100.00
9ABDE9	2017-08-01 12:42:00+03	40800.00
9ABDEB	2017-07-28 23:54:00+03	23200.00
9ABE14	2017-07-28 03:20:00+03	191700.00
9ABE2F	2017-07-15 01:38:00+03	44000.00
9ABE62	2017-08-09 03:15:00+03	91900.00
9ABE92	2017-07-07 20:15:00+03	42600.00
9ABF32	2017-08-14 23:00:00+03	167800.00
9ABFA8	2017-08-13 03:19:00+03	8000.00
9AC037	2017-07-22 14:41:00+03	127800.00
9AC082	2017-08-05 09:24:00+03	369000.00
9AC0F3	2017-07-09 01:22:00+03	81200.00
9AC0F8	2017-07-01 06:05:00+03	14800.00
9AC14C	2017-08-05 20:04:00+03	55800.00
9AC161	2017-08-06 09:03:00+03	23200.00
9AC17D	2017-08-12 09:12:00+03	122400.00
9AC1A8	2017-07-09 06:26:00+03	78100.00
9AC1AF	2017-08-01 21:55:00+03	6300.00
9AC1BA	2017-07-30 18:33:00+03	47000.00
9AC234	2017-08-04 11:44:00+03	44000.00
9AC252	2017-07-02 23:15:00+03	119500.00
9AC32E	2017-08-12 17:11:00+03	92700.00
9AC420	2017-08-14 01:17:00+03	54000.00
9AC4AC	2017-07-02 07:13:00+03	230600.00
9AC54E	2017-08-09 18:02:00+03	67600.00
9AC643	2017-08-02 05:38:00+03	270800.00
9AC66F	2017-07-14 05:28:00+03	59200.00
9AC6AE	2017-07-10 17:02:00+03	75300.00
9AC6D2	2017-07-06 02:46:00+03	26000.00
9AC6F8	2017-07-19 05:00:00+03	27800.00
9AC6F9	2017-07-12 03:03:00+03	23100.00
9AC739	2017-06-29 21:21:00+03	89600.00
9AC73B	2017-08-05 07:15:00+03	24400.00
9AC79D	2017-07-21 16:28:00+03	21800.00
9AC7C8	2017-08-09 06:49:00+03	20400.00
9AC807	2017-07-13 10:55:00+03	6700.00
9AC83B	2017-07-28 22:19:00+03	68800.00
9AC862	2017-08-11 23:51:00+03	54000.00
9AC86E	2017-08-01 19:14:00+03	85000.00
9AC870	2017-07-14 09:53:00+03	6200.00
9AC873	2017-08-15 07:46:00+03	21800.00
9AC899	2017-07-05 07:31:00+03	136200.00
9AC8C2	2017-08-04 02:23:00+03	167400.00
9AC905	2017-07-16 03:47:00+03	184300.00
9AC92A	2017-07-02 20:19:00+03	154100.00
9AC945	2017-07-22 16:25:00+03	141300.00
9AC99E	2017-07-17 19:06:00+03	21400.00
9AC9B6	2017-07-18 17:25:00+03	30200.00
9ACADB	2017-07-05 01:08:00+03	55000.00
9ACAEB	2017-08-13 01:35:00+03	61400.00
9ACB1C	2017-07-14 07:45:00+03	51900.00
9ACB1F	2017-08-13 03:05:00+03	13600.00
9ACB36	2017-07-08 03:41:00+03	88900.00
9ACBB7	2017-07-07 00:48:00+03	41400.00
9ACBC8	2017-08-14 02:25:00+03	89700.00
9ACBEF	2017-07-23 03:05:00+03	14000.00
9ACC2A	2017-07-09 19:29:00+03	26700.00
9ACC38	2017-07-10 17:04:00+03	136200.00
9ACC4E	2017-07-30 02:38:00+03	25200.00
9ACC74	2017-07-28 21:00:00+03	12400.00
9ACDA4	2017-07-04 06:22:00+03	61800.00
9ACDB8	2017-08-06 09:13:00+03	30200.00
9ACDBE	2017-07-29 10:25:00+03	155600.00
9ACE09	2017-07-15 03:53:00+03	266300.00
9ACE10	2017-07-24 07:15:00+03	29600.00
9ACE23	2017-07-02 22:45:00+03	34100.00
9ACE97	2017-07-24 11:06:00+03	94300.00
9ACEBD	2017-07-28 10:10:00+03	168700.00
9ACEDB	2017-07-17 14:06:00+03	135400.00
9ACF01	2017-07-24 11:05:00+03	28800.00
9ACF5C	2017-08-01 03:50:00+03	24700.00
9AD004	2017-06-29 20:18:00+03	21200.00
9AD01D	2017-07-07 23:53:00+03	39500.00
9AD0B5	2017-08-07 09:58:00+03	67600.00
9AD0F8	2017-07-23 18:53:00+03	6300.00
9AD119	2017-07-21 10:41:00+03	10600.00
9AD121	2017-07-01 21:43:00+03	60400.00
9AD14E	2017-07-25 14:10:00+03	39800.00
9AD186	2017-07-21 15:36:00+03	198400.00
9AD18B	2017-07-05 09:07:00+03	246400.00
9AD1B5	2017-07-27 19:45:00+03	39200.00
9AD1B8	2017-07-02 13:19:00+03	271200.00
9AD26F	2017-06-28 16:48:00+03	106400.00
9AD29C	2017-07-05 04:49:00+03	78100.00
9AD2B4	2017-07-31 12:52:00+03	6700.00
9AD2B7	2017-07-14 03:06:00+03	94500.00
9AD2CB	2017-07-12 19:57:00+03	101800.00
9AD31C	2017-08-05 01:24:00+03	123000.00
9AD36D	2017-07-30 18:02:00+03	68100.00
9AD376	2017-07-19 12:17:00+03	246000.00
9AD3B0	2017-08-06 01:50:00+03	167400.00
9AD3DA	2017-07-30 15:20:00+03	26000.00
9AD412	2017-07-15 17:02:00+03	29400.00
9AD452	2017-07-09 10:29:00+03	23200.00
9AD470	2017-07-25 07:53:00+03	166100.00
9AD4B3	2017-07-09 17:41:00+03	67600.00
9AD4E1	2017-07-28 02:13:00+03	69700.00
9AD559	2017-07-10 03:14:00+03	115900.00
9AD5A4	2017-08-08 08:35:00+03	193100.00
9AD5FE	2017-07-05 20:15:00+03	123900.00
9AD666	2017-07-07 15:37:00+03	25200.00
9AD6C4	2017-07-11 10:50:00+03	123000.00
9AD77A	2017-08-08 21:51:00+03	193300.00
9AD7AE	2017-08-14 06:34:00+03	29200.00
9AD838	2017-07-15 23:17:00+03	12600.00
9AD882	2017-07-23 17:43:00+03	94500.00
9AD8CE	2017-08-06 01:18:00+03	10600.00
9AD92D	2017-08-14 23:49:00+03	46400.00
9AD93F	2017-08-05 21:26:00+03	36200.00
9AD9B9	2017-08-10 02:21:00+03	35800.00
9AD9D0	2017-08-14 08:42:00+03	124200.00
9AD9D6	2017-07-14 08:15:00+03	26000.00
9AD9F4	2017-08-03 19:12:00+03	12600.00
9ADA19	2017-07-13 05:40:00+03	9800.00
9ADA23	2017-08-08 06:09:00+03	40100.00
9ADA8C	2017-08-14 12:44:00+03	52000.00
9ADAC3	2017-08-14 20:26:00+03	26000.00
9ADB0D	2017-08-08 12:04:00+03	85200.00
9ADB13	2017-08-03 05:02:00+03	21800.00
9ADBA1	2017-07-24 11:56:00+03	190500.00
9ADBE2	2017-08-05 05:40:00+03	14000.00
9ADBE5	2017-07-13 14:09:00+03	273200.00
9ADBEE	2017-07-19 19:41:00+03	246200.00
9ADC12	2017-07-29 15:33:00+03	40400.00
9ADC39	2017-08-10 06:10:00+03	68800.00
9ADC55	2017-08-01 03:02:00+03	81000.00
9ADC62	2017-08-08 07:27:00+03	111600.00
9ADCBE	2017-07-27 09:51:00+03	47100.00
9ADCDE	2017-08-05 12:29:00+03	266400.00
9ADCEF	2017-08-13 18:20:00+03	243600.00
9ADD31	2017-07-01 19:01:00+03	39300.00
9ADD5E	2017-07-15 18:43:00+03	128100.00
9ADD83	2017-08-06 06:38:00+03	59300.00
9ADDB8	2017-07-26 22:13:00+03	79300.00
9ADE0D	2017-07-30 19:12:00+03	23200.00
9ADE3F	2017-08-12 13:57:00+03	30200.00
9ADF32	2017-08-01 11:02:00+03	16400.00
9ADF38	2017-08-09 03:49:00+03	25100.00
9ADF67	2017-08-15 15:22:00+03	42800.00
9ADF6E	2017-07-06 13:05:00+03	44600.00
9ADF77	2017-07-13 14:08:00+03	15000.00
9ADFA5	2017-08-07 23:03:00+03	131100.00
9ADFBD	2017-07-07 16:25:00+03	6000.00
9ADFC2	2017-07-01 16:59:00+03	7200.00
9ADFC7	2017-07-23 15:10:00+03	34000.00
9AE021	2017-08-12 04:15:00+03	144400.00
9AE02C	2017-07-26 20:44:00+03	45200.00
9AE086	2017-07-03 06:26:00+03	20200.00
9AE0CC	2017-07-08 21:15:00+03	19800.00
9AE0E5	2017-07-10 20:49:00+03	97900.00
9AE109	2017-07-12 19:46:00+03	32800.00
9AE184	2017-07-10 03:00:00+03	187600.00
9AE197	2017-07-02 00:55:00+03	61800.00
9AE1A5	2017-08-15 01:05:00+03	11800.00
9AE1AC	2017-07-22 05:18:00+03	152000.00
9AE1F9	2017-06-30 09:56:00+03	46400.00
9AE216	2017-08-05 04:56:00+03	50600.00
9AE31D	2017-07-14 18:08:00+03	26800.00
9AE382	2017-07-06 22:59:00+03	6000.00
9AE3AB	2017-07-05 15:51:00+03	81600.00
9AE40C	2017-07-14 12:15:00+03	135600.00
9AE419	2017-07-07 14:49:00+03	64700.00
9AE468	2017-07-03 15:14:00+03	174900.00
9AE4D8	2017-07-13 22:04:00+03	44000.00
9AE539	2017-08-03 04:00:00+03	48700.00
9AE566	2017-08-13 11:36:00+03	96800.00
9AE57A	2017-08-03 09:02:00+03	50800.00
9AE5B5	2017-07-06 11:18:00+03	14400.00
9AE63F	2017-07-28 04:39:00+03	71900.00
9AE661	2017-08-11 01:42:00+03	43900.00
9AE690	2017-08-06 02:29:00+03	16800.00
9AE695	2017-08-13 05:27:00+03	693400.00
9AE6BB	2017-07-18 07:52:00+03	19600.00
9AE731	2017-08-01 02:56:00+03	23600.00
9AE794	2017-07-14 21:01:00+03	75300.00
9AE7DE	2017-08-09 20:13:00+03	83000.00
9AE828	2017-07-07 21:05:00+03	40000.00
9AE831	2017-07-20 14:39:00+03	31600.00
9AE839	2017-08-07 12:10:00+03	11700.00
9AE87E	2017-07-23 07:01:00+03	266200.00
9AE892	2017-08-11 03:10:00+03	187300.00
9AE8D9	2017-07-08 14:17:00+03	8400.00
9AE92D	2017-07-10 22:11:00+03	26000.00
9AE930	2017-08-03 14:58:00+03	32300.00
9AE962	2017-07-24 14:14:00+03	114700.00
9AE970	2017-07-20 14:02:00+03	88600.00
9AE987	2017-07-22 12:33:00+03	10800.00
9AEA53	2017-07-24 09:30:00+03	101200.00
9AEAAA	2017-07-18 18:43:00+03	61600.00
9AEAB3	2017-07-27 19:12:00+03	40100.00
9AEAD3	2017-08-10 08:02:00+03	36800.00
9AEAEA	2017-07-21 07:41:00+03	58400.00
9AEBD1	2017-07-27 20:47:00+03	13400.00
9AEC31	2017-07-18 09:54:00+03	46800.00
9AEC65	2017-07-25 01:44:00+03	77600.00
9AECAB	2017-07-04 19:19:00+03	198900.00
9AECAF	2017-07-29 08:40:00+03	115600.00
9AECCA	2017-07-12 22:11:00+03	143100.00
9AED82	2017-06-30 07:05:00+03	169300.00
9AED89	2017-07-16 21:56:00+03	58800.00
9AED9A	2017-07-04 21:27:00+03	44000.00
9AEDAD	2017-07-10 10:36:00+03	110500.00
9AEE0A	2017-07-18 23:48:00+03	84100.00
9AEE0B	2017-08-09 19:25:00+03	23200.00
9AEF22	2017-07-20 10:42:00+03	123600.00
9AEF2B	2017-08-12 03:02:00+03	284400.00
9AEFD1	2017-07-19 22:26:00+03	22100.00
9AEFEB	2017-07-02 16:53:00+03	44100.00
9AF046	2017-07-26 17:23:00+03	7300.00
9AF05D	2017-08-03 02:29:00+03	20200.00
9AF0B5	2017-07-15 07:47:00+03	75300.00
9AF11C	2017-07-23 02:38:00+03	70800.00
9AF16D	2017-07-08 00:57:00+03	54400.00
9AF19F	2017-07-02 23:45:00+03	92800.00
9AF1B5	2017-07-17 04:10:00+03	30100.00
9AF1F0	2017-08-09 21:47:00+03	26000.00
9AF208	2017-07-01 15:19:00+03	26000.00
9AF292	2017-07-30 06:30:00+03	44000.00
9AF29F	2017-07-09 08:43:00+03	37100.00
9AF2CA	2017-08-04 02:21:00+03	43600.00
9AF2D7	2017-08-02 21:42:00+03	31400.00
9AF364	2017-07-03 05:55:00+03	12800.00
9AF3F9	2017-07-22 14:57:00+03	27800.00
9AF406	2017-07-30 17:04:00+03	36200.00
9AF41C	2017-08-06 12:00:00+03	42400.00
9AF43A	2017-07-21 17:44:00+03	48500.00
9AF46F	2017-07-02 02:32:00+03	12600.00
9AF50E	2017-07-13 11:27:00+03	14400.00
9AF511	2017-07-16 02:51:00+03	166000.00
9AF544	2017-07-12 01:35:00+03	61800.00
9AF591	2017-06-27 16:33:00+03	155600.00
9AF648	2017-07-17 13:42:00+03	248500.00
9AF66B	2017-08-14 06:17:00+03	88600.00
9AF680	2017-07-29 23:23:00+03	6000.00
9AF70E	2017-07-28 05:19:00+03	96300.00
9AF722	2017-07-22 11:21:00+03	92400.00
9AF74D	2017-08-11 15:31:00+03	34000.00
9AF76C	2017-07-11 21:18:00+03	70800.00
9AF76D	2017-07-26 01:24:00+03	133900.00
9AF776	2017-07-27 07:58:00+03	14000.00
9AF7CA	2017-07-16 12:22:00+03	7400.00
9AF7D7	2017-08-04 18:47:00+03	14800.00
9AF7DC	2017-08-15 00:54:00+03	30900.00
9AF851	2017-07-12 00:54:00+03	49900.00
9AF8A7	2017-07-30 20:32:00+03	246000.00
9AF94C	2017-08-08 19:33:00+03	58400.00
9AF9F9	2017-07-23 17:21:00+03	34000.00
9AFA63	2017-07-20 15:40:00+03	139400.00
9AFA7F	2017-07-10 10:24:00+03	76200.00
9AFA8C	2017-07-11 07:36:00+03	35800.00
9AFAC4	2017-07-27 00:52:00+03	84500.00
9AFADA	2017-07-30 13:17:00+03	201100.00
9AFAEF	2017-07-12 06:59:00+03	28000.00
9AFB49	2017-07-12 11:14:00+03	37100.00
9AFB9A	2017-07-04 17:58:00+03	16400.00
9AFBAD	2017-08-04 22:40:00+03	38400.00
9AFBEE	2017-07-30 07:09:00+03	136600.00
9AFBFC	2017-07-19 08:15:00+03	120100.00
9AFC27	2017-07-28 16:23:00+03	42800.00
9AFC34	2017-07-23 04:14:00+03	15100.00
9AFC4A	2017-07-07 22:03:00+03	37200.00
9AFC91	2017-07-06 06:49:00+03	201800.00
9AFC96	2017-08-01 17:53:00+03	189800.00
9AFC9B	2017-07-26 00:38:00+03	131600.00
9AFCB1	2017-08-07 05:47:00+03	46000.00
9AFE1E	2017-07-29 19:09:00+03	117600.00
9AFE7D	2017-08-10 16:37:00+03	26800.00
9AFE91	2017-07-17 02:00:00+03	44800.00
9AFEA1	2017-07-26 19:29:00+03	135400.00
9AFF72	2017-08-03 05:16:00+03	31200.00
9B003F	2017-07-01 18:24:00+03	85400.00
9B0113	2017-08-07 21:28:00+03	56000.00
9B0178	2017-07-20 07:14:00+03	89200.00
9B01E4	2017-07-06 20:27:00+03	29400.00
9B01F9	2017-07-12 16:15:00+03	58900.00
9B023B	2017-07-28 22:31:00+03	66400.00
9B02A9	2017-08-02 13:15:00+03	24800.00
9B02E6	2017-07-28 16:38:00+03	46400.00
9B0311	2017-08-11 14:38:00+03	24800.00
9B031D	2017-07-15 08:52:00+03	173900.00
9B0332	2017-08-04 19:18:00+03	67400.00
9B0349	2017-07-09 00:56:00+03	16400.00
9B0363	2017-07-15 07:58:00+03	652100.00
9B0379	2017-07-13 13:00:00+03	92600.00
9B0382	2017-07-08 16:31:00+03	20600.00
9B0391	2017-08-14 13:34:00+03	32800.00
9B039F	2017-08-06 14:31:00+03	218000.00
9B03CC	2017-08-03 18:34:00+03	106100.00
9B0415	2017-07-24 14:39:00+03	46800.00
9B041F	2017-07-16 20:48:00+03	23200.00
9B043D	2017-08-03 13:30:00+03	6700.00
9B044E	2017-07-15 02:10:00+03	15600.00
9B0464	2017-07-18 06:34:00+03	30000.00
9B04F0	2017-07-15 06:28:00+03	62000.00
9B0504	2017-08-08 14:34:00+03	136500.00
9B0507	2017-07-09 01:32:00+03	21400.00
9B05EB	2017-07-01 04:47:00+03	65400.00
9B0643	2017-07-26 18:17:00+03	23200.00
9B0654	2017-08-08 08:14:00+03	24200.00
9B06AF	2017-07-20 01:48:00+03	112000.00
9B0715	2017-07-27 08:18:00+03	48800.00
9B0758	2017-07-22 15:50:00+03	59800.00
9B079B	2017-08-15 03:50:00+03	29600.00
9B07C5	2017-07-09 17:52:00+03	21800.00
9B07C8	2017-08-12 21:11:00+03	46900.00
9B07DE	2017-07-18 08:07:00+03	32800.00
9B0800	2017-08-10 05:15:00+03	39200.00
9B08B8	2017-07-04 05:01:00+03	55800.00
9B08D1	2017-08-07 08:43:00+03	12600.00
9B0905	2017-07-10 08:32:00+03	117200.00
9B099C	2017-07-14 07:24:00+03	28800.00
9B09FA	2017-08-15 08:21:00+03	53400.00
9B09FC	2017-08-12 05:24:00+03	123000.00
9B0A56	2017-07-31 16:27:00+03	24500.00
9B0ACF	2017-07-09 21:40:00+03	246000.00
9B0B2F	2017-07-27 03:23:00+03	11800.00
9B0B4F	2017-08-08 04:45:00+03	24400.00
9B0B5D	2017-07-14 22:46:00+03	49200.00
9B0B79	2017-07-23 21:39:00+03	36100.00
9B0B89	2017-06-30 21:14:00+03	56000.00
9B0BCC	2017-08-08 21:49:00+03	61300.00
9B0BE9	2017-07-19 21:35:00+03	43300.00
9B0C24	2017-08-10 14:46:00+03	135400.00
9B0C96	2017-08-11 23:56:00+03	66600.00
9B0CCE	2017-07-04 11:08:00+03	18600.00
9B0D1B	2017-07-30 11:01:00+03	96300.00
9B0DC3	2017-07-15 21:44:00+03	75600.00
9B0DD3	2017-07-28 02:55:00+03	167400.00
9B0DEB	2017-07-24 11:45:00+03	31600.00
9B0E0C	2017-08-08 07:42:00+03	123000.00
9B0E0F	2017-07-18 07:55:00+03	34000.00
9B0E27	2017-07-29 14:49:00+03	28800.00
9B0E5B	2017-08-14 01:46:00+03	25100.00
9B0E93	2017-07-22 10:28:00+03	114700.00
9B0E9B	2017-07-23 11:29:00+03	13400.00
9B0EAC	2017-07-12 14:30:00+03	56200.00
9B0EE1	2017-07-28 03:11:00+03	169600.00
9B0F54	2017-06-28 13:11:00+03	48800.00
9B0F78	2017-08-11 22:33:00+03	6800.00
9B0F81	2017-07-11 03:20:00+03	23200.00
9B0FA8	2017-07-20 23:36:00+03	58000.00
9B0FB3	2017-07-07 21:53:00+03	21800.00
9B0FC7	2017-07-02 14:16:00+03	6700.00
9B1041	2017-06-30 05:45:00+03	142400.00
9B10B3	2017-08-12 12:42:00+03	25400.00
9B1135	2017-07-29 17:20:00+03	46000.00
9B1139	2017-08-04 17:06:00+03	58100.00
9B117F	2017-07-01 13:57:00+03	229900.00
9B118E	2017-07-13 02:34:00+03	51900.00
9B11B5	2017-06-28 11:57:00+03	56000.00
9B1209	2017-07-26 04:03:00+03	8200.00
9B1244	2017-07-13 02:02:00+03	24400.00
9B1271	2017-07-19 17:41:00+03	48800.00
9B1310	2017-07-23 21:02:00+03	92400.00
9B138A	2017-08-14 17:15:00+03	10800.00
9B138B	2017-07-07 12:47:00+03	60400.00
9B13B5	2017-08-01 13:52:00+03	40300.00
9B147B	2017-07-24 19:28:00+03	73600.00
9B14FB	2017-07-25 21:22:00+03	26000.00
9B1541	2017-07-09 15:42:00+03	29600.00
9B1551	2017-08-05 16:00:00+03	134400.00
9B157D	2017-07-06 02:37:00+03	9800.00
9B158A	2017-07-05 20:14:00+03	61500.00
9B1609	2017-07-08 06:32:00+03	283100.00
9B1636	2017-07-27 21:33:00+03	28800.00
9B1688	2017-07-18 15:29:00+03	134400.00
9B16F8	2017-07-12 01:19:00+03	258400.00
9B170A	2017-08-02 19:30:00+03	133200.00
9B172F	2017-07-20 02:53:00+03	28800.00
9B173D	2017-07-10 04:48:00+03	70700.00
9B1750	2017-08-05 23:02:00+03	55500.00
9B17AE	2017-07-21 13:58:00+03	88100.00
9B17E6	2017-07-21 06:23:00+03	44600.00
9B1864	2017-07-26 20:20:00+03	9200.00
9B1872	2017-07-10 13:40:00+03	34600.00
9B1884	2017-07-06 06:35:00+03	12600.00
9B1886	2017-08-01 05:56:00+03	48800.00
9B18EC	2017-08-10 03:38:00+03	12600.00
9B18ED	2017-07-14 22:51:00+03	118100.00
9B196A	2017-08-05 16:19:00+03	23200.00
9B19B7	2017-07-28 07:15:00+03	114800.00
9B19BF	2017-07-26 19:55:00+03	105600.00
9B19C9	2017-07-24 03:38:00+03	114500.00
9B19E1	2017-07-09 06:56:00+03	32200.00
9B1A76	2017-07-21 16:06:00+03	49600.00
9B1A8C	2017-07-21 18:32:00+03	413500.00
9B1AB6	2017-07-26 18:11:00+03	157200.00
9B1AFA	2017-08-02 06:24:00+03	6000.00
9B1B09	2017-07-03 18:58:00+03	113600.00
9B1B3C	2017-07-29 04:22:00+03	6700.00
9B1B58	2017-07-12 19:56:00+03	22000.00
9B1B9E	2017-08-09 16:59:00+03	139500.00
9B1BAD	2017-07-26 15:55:00+03	23200.00
9B1BD1	2017-07-05 03:05:00+03	92000.00
9B1C3D	2017-07-14 21:12:00+03	6300.00
9B1CA4	2017-08-14 04:48:00+03	77100.00
9B1CB4	2017-07-06 11:59:00+03	100600.00
9B1D6D	2017-07-03 01:07:00+03	52800.00
9B1E08	2017-07-10 23:49:00+03	6600.00
9B1E26	2017-07-16 18:36:00+03	64700.00
9B1E4B	2017-07-21 18:46:00+03	95800.00
9B1E5E	2017-07-26 22:39:00+03	59300.00
9B1E7E	2017-08-01 12:30:00+03	266800.00
9B1E8E	2017-07-15 10:18:00+03	67400.00
9B1F2B	2017-07-26 04:59:00+03	77500.00
9B1F55	2017-07-23 18:55:00+03	101800.00
9B1F73	2017-07-08 07:25:00+03	37900.00
9B1FDC	2017-07-06 01:02:00+03	12600.00
9B1FE6	2017-07-04 22:55:00+03	48800.00
9B2037	2017-07-19 13:36:00+03	26000.00
9B2067	2017-07-10 15:20:00+03	115700.00
9B2078	2017-07-25 22:44:00+03	27200.00
9B20C1	2017-07-30 20:24:00+03	100600.00
9B20F6	2017-06-30 15:04:00+03	321700.00
9B2177	2017-07-30 21:22:00+03	248400.00
9B219B	2017-08-11 14:22:00+03	13400.00
9B21B5	2017-07-12 13:01:00+03	189100.00
9B21F7	2017-07-26 06:51:00+03	26000.00
9B2294	2017-07-25 22:49:00+03	88900.00
9B22BD	2017-07-11 19:55:00+03	147700.00
9B22C6	2017-07-26 03:38:00+03	137400.00
9B24C8	2017-07-24 12:31:00+03	46200.00
9B2564	2017-07-21 09:37:00+03	47000.00
9B257D	2017-08-13 13:20:00+03	29600.00
9B25D3	2017-06-29 13:23:00+03	62000.00
9B25E0	2017-08-13 12:42:00+03	49100.00
9B2677	2017-07-22 03:51:00+03	12000.00
9B27B9	2017-07-09 14:00:00+03	46400.00
9B27E6	2017-06-29 17:04:00+03	146300.00
9B2820	2017-07-27 11:59:00+03	56100.00
9B289C	2017-08-13 22:56:00+03	265700.00
9B28C5	2017-07-26 11:30:00+03	258400.00
9B28D1	2017-08-03 15:08:00+03	273600.00
9B2910	2017-08-14 11:02:00+03	20600.00
9B294B	2017-08-09 08:35:00+03	357600.00
9B295E	2017-07-12 19:32:00+03	21800.00
9B297B	2017-07-15 00:38:00+03	24400.00
9B2990	2017-08-01 22:10:00+03	46500.00
9B29D3	2017-08-14 06:12:00+03	20200.00
9B29DC	2017-07-14 00:37:00+03	37700.00
9B2A03	2017-08-12 18:51:00+03	90000.00
9B2A5C	2017-08-13 06:40:00+03	55000.00
9B2A97	2017-08-10 04:23:00+03	123000.00
9B2AB8	2017-08-09 09:31:00+03	62600.00
9B2ACD	2017-08-02 20:59:00+03	62800.00
9B2B02	2017-08-06 06:43:00+03	10100.00
9B2B0C	2017-07-25 05:05:00+03	195500.00
9B2B2E	2017-07-12 13:53:00+03	19600.00
9B2B5E	2017-07-24 20:27:00+03	55800.00
9B2B61	2017-07-18 11:39:00+03	131100.00
9B2BAD	2017-07-25 23:25:00+03	123000.00
9B2BFF	2017-07-02 03:36:00+03	69900.00
9B2C3C	2017-08-10 14:22:00+03	28000.00
9B2C70	2017-08-09 05:06:00+03	48700.00
9B2CBB	2017-07-01 08:37:00+03	42600.00
9B2D07	2017-07-03 03:08:00+03	132800.00
9B2D2D	2017-07-28 08:12:00+03	24700.00
9B2D35	2017-08-10 23:55:00+03	13600.00
9B2D7E	2017-07-06 07:23:00+03	24400.00
9B2D81	2017-08-08 00:05:00+03	54400.00
9B2DC7	2017-07-21 03:48:00+03	8400.00
9B2E20	2017-07-15 14:21:00+03	47000.00
9B2E28	2017-07-22 12:49:00+03	65900.00
9B2E67	2017-07-24 06:07:00+03	62600.00
9B2E6D	2017-07-02 07:46:00+03	38600.00
9B2EC5	2017-07-04 06:15:00+03	57400.00
9B2F03	2017-08-09 11:49:00+03	124200.00
9B2F2A	2017-08-02 04:40:00+03	44100.00
9B2F8D	2017-08-11 16:11:00+03	23500.00
9B2FB5	2017-08-12 17:30:00+03	14900.00
9B2FC3	2017-08-04 04:33:00+03	29800.00
9B2FC8	2017-07-10 17:23:00+03	492000.00
9B3006	2017-08-05 02:44:00+03	128800.00
9B30BD	2017-07-13 20:54:00+03	271200.00
9B30C2	2017-07-01 08:23:00+03	48800.00
9B30DB	2017-07-23 00:36:00+03	28000.00
9B30F0	2017-07-24 00:43:00+03	12000.00
9B315D	2017-07-09 21:23:00+03	88600.00
9B31D3	2017-07-16 04:02:00+03	85000.00
9B31E9	2017-08-12 20:18:00+03	31600.00
9B323D	2017-07-22 04:41:00+03	23400.00
9B326E	2017-07-02 07:16:00+03	21800.00
9B32EA	2017-07-03 12:01:00+03	133200.00
9B3376	2017-07-23 01:07:00+03	102000.00
9B33CC	2017-07-14 07:35:00+03	61800.00
9B33DE	2017-07-29 19:08:00+03	50200.00
9B33F8	2017-08-09 19:37:00+03	144000.00
9B33F9	2017-08-01 06:11:00+03	35200.00
9B33FC	2017-08-09 02:27:00+03	50100.00
9B34C6	2017-06-28 16:40:00+03	72900.00
9B34DE	2017-07-26 03:36:00+03	55700.00
9B34F6	2017-08-01 07:38:00+03	131800.00
9B34FE	2017-07-13 23:41:00+03	412400.00
9B3528	2017-07-11 20:38:00+03	27800.00
9B35DB	2017-06-28 21:09:00+03	115000.00
9B35F3	2017-08-09 10:17:00+03	6000.00
9B3624	2017-08-05 10:51:00+03	28000.00
9B36E6	2017-07-01 20:28:00+03	51300.00
9B36ED	2017-07-09 17:00:00+03	35300.00
9B3703	2017-07-30 11:57:00+03	32800.00
9B374B	2017-08-11 15:37:00+03	76200.00
9B3769	2017-07-11 10:09:00+03	46000.00
9B37C8	2017-07-19 20:52:00+03	11600.00
9B3803	2017-07-02 19:04:00+03	165400.00
9B3901	2017-08-11 01:02:00+03	67400.00
9B391B	2017-07-08 11:50:00+03	123000.00
9B3928	2017-07-23 12:10:00+03	94700.00
9B3939	2017-07-27 01:41:00+03	23200.00
9B3A39	2017-07-20 16:32:00+03	22400.00
9B3A8F	2017-07-16 18:35:00+03	39300.00
9B3A96	2017-08-01 05:56:00+03	170800.00
9B3AB9	2017-08-01 16:50:00+03	8400.00
9B3AC5	2017-07-12 12:31:00+03	27800.00
9B3AC8	2017-08-07 14:35:00+03	38600.00
9B3B12	2017-08-14 01:20:00+03	46000.00
9B3B54	2017-07-02 11:26:00+03	145100.00
9B3B5B	2017-07-19 03:28:00+03	79600.00
9B3C3F	2017-07-05 13:16:00+03	75800.00
9B3C73	2017-07-13 12:46:00+03	182500.00
9B3C78	2017-07-02 12:16:00+03	150600.00
9B3D46	2017-07-27 16:14:00+03	32800.00
9B3D96	2017-08-05 14:53:00+03	76600.00
9B3DBA	2017-08-08 22:22:00+03	8400.00
9B3E4F	2017-07-27 10:33:00+03	23200.00
9B3EA5	2017-07-29 05:03:00+03	94000.00
9B3EC9	2017-07-18 06:14:00+03	56000.00
9B3EE6	2017-07-02 12:53:00+03	121400.00
9B3F48	2017-08-01 23:29:00+03	39100.00
9B3FE3	2017-08-08 17:47:00+03	101200.00
9B4056	2017-07-17 04:58:00+03	164700.00
9B4061	2017-08-02 06:24:00+03	117600.00
9B4087	2017-07-29 16:40:00+03	136800.00
9B40AA	2017-07-03 07:26:00+03	23600.00
9B40D3	2017-07-18 23:17:00+03	131100.00
9B40D9	2017-08-15 06:00:00+03	142400.00
9B4153	2017-08-10 22:08:00+03	190000.00
9B415C	2017-07-02 22:29:00+03	75900.00
9B4168	2017-07-03 08:20:00+03	34000.00
9B41BC	2017-08-07 01:09:00+03	66600.00
9B425B	2017-07-27 10:56:00+03	56000.00
9B435A	2017-07-21 23:03:00+03	77200.00
9B4362	2017-07-28 15:15:00+03	44800.00
9B438D	2017-07-26 01:22:00+03	427600.00
9B43CE	2017-08-13 01:56:00+03	680800.00
9B43E9	2017-08-07 17:25:00+03	39300.00
9B4513	2017-07-20 11:38:00+03	73200.00
9B4553	2017-07-28 04:06:00+03	46000.00
9B4559	2017-08-11 09:30:00+03	11600.00
9B4563	2017-07-09 21:38:00+03	46400.00
9B460B	2017-08-02 19:52:00+03	100600.00
9B46B2	2017-07-16 07:46:00+03	68400.00
9B46E6	2017-08-05 04:33:00+03	111600.00
9B471C	2017-07-06 13:49:00+03	58200.00
9B4738	2017-07-13 13:29:00+03	25200.00
9B4741	2017-08-14 06:42:00+03	58400.00
9B47A7	2017-07-27 19:08:00+03	26500.00
9B47FB	2017-07-14 05:42:00+03	73500.00
9B4816	2017-07-26 21:47:00+03	62800.00
9B4909	2017-07-07 11:56:00+03	48700.00
9B493E	2017-07-22 16:08:00+03	30400.00
9B496F	2017-07-11 09:22:00+03	16400.00
9B49A3	2017-07-14 01:07:00+03	60600.00
9B49D9	2017-07-16 08:43:00+03	136800.00
9B4A16	2017-08-03 21:56:00+03	21800.00
9B4A3D	2017-07-13 07:47:00+03	16400.00
9B4A54	2017-08-06 10:52:00+03	43400.00
9B4AB9	2017-07-12 02:20:00+03	47500.00
9B4AEE	2017-08-14 02:04:00+03	59300.00
9B4B17	2017-08-13 03:32:00+03	27200.00
9B4B37	2017-07-26 17:07:00+03	89600.00
9B4B41	2017-07-20 02:31:00+03	40000.00
9B4B4B	2017-07-15 08:47:00+03	83800.00
9B4BD2	2017-08-02 08:24:00+03	46000.00
9B4C02	2017-07-06 07:14:00+03	70600.00
9B4C08	2017-07-06 08:13:00+03	64200.00
9B4C54	2017-07-30 16:27:00+03	26700.00
9B4CBB	2017-08-10 09:59:00+03	25100.00
9B4CEF	2017-08-15 13:42:00+03	28800.00
9B4D02	2017-07-20 00:55:00+03	34700.00
9B4D97	2017-07-20 11:30:00+03	55800.00
9B4DCA	2017-08-03 03:54:00+03	28000.00
9B4E09	2017-07-24 02:02:00+03	65900.00
9B4E11	2017-07-19 12:08:00+03	46800.00
9B4E5F	2017-07-31 08:06:00+03	167400.00
9B4E65	2017-07-10 09:00:00+03	37500.00
9B4E7F	2017-07-06 11:41:00+03	320500.00
9B4F11	2017-08-13 15:28:00+03	51900.00
9B4F5D	2017-07-17 10:30:00+03	24000.00
9B4F71	2017-08-15 10:34:00+03	27200.00
9B5003	2017-08-09 12:41:00+03	48800.00
9B500E	2017-07-30 19:46:00+03	182300.00
9B502B	2017-07-01 05:46:00+03	94900.00
9B505C	2017-07-27 16:43:00+03	59200.00
9B5068	2017-07-09 06:45:00+03	52800.00
9B508E	2017-07-13 14:06:00+03	146300.00
9B5091	2017-08-05 21:39:00+03	70700.00
9B5092	2017-07-03 14:09:00+03	93000.00
9B509D	2017-07-19 06:19:00+03	26800.00
9B50D4	2017-07-10 22:38:00+03	23600.00
9B50EB	2017-07-20 23:57:00+03	12600.00
9B514D	2017-07-12 19:09:00+03	13400.00
9B515E	2017-07-16 17:50:00+03	31600.00
9B525B	2017-07-11 04:27:00+03	20200.00
9B527D	2017-07-19 02:27:00+03	23200.00
9B52AD	2017-07-01 06:08:00+03	32800.00
9B530B	2017-07-01 06:40:00+03	103400.00
9B533A	2017-08-15 11:06:00+03	71700.00
9B534E	2017-07-23 18:21:00+03	233700.00
9B5355	2017-07-03 03:37:00+03	40000.00
9B5481	2017-07-23 06:44:00+03	106600.00
9B54D3	2017-08-11 10:45:00+03	54800.00
9B5544	2017-08-01 20:39:00+03	531400.00
9B557D	2017-08-05 00:42:00+03	25600.00
9B559A	2017-07-02 19:04:00+03	55800.00
9B560E	2017-07-22 05:30:00+03	181600.00
9B5695	2017-07-12 09:03:00+03	56000.00
9B56B3	2017-07-12 11:16:00+03	258000.00
9B571D	2017-07-01 10:29:00+03	20000.00
9B574B	2017-07-20 12:20:00+03	160000.00
9B575D	2017-07-25 04:24:00+03	54800.00
9B5775	2017-07-29 10:38:00+03	43600.00
9B577C	2017-07-31 23:20:00+03	40800.00
9B57B0	2017-08-13 08:55:00+03	54800.00
9B57B8	2017-08-04 04:15:00+03	48800.00
9B57C7	2017-07-31 05:33:00+03	134600.00
9B57D7	2017-08-13 15:41:00+03	43100.00
9B57D9	2017-08-08 05:39:00+03	406600.00
9B5807	2017-07-24 04:37:00+03	27400.00
9B5810	2017-08-02 19:07:00+03	27300.00
9B585C	2017-07-24 07:00:00+03	8200.00
9B589C	2017-07-30 06:59:00+03	87900.00
9B58BF	2017-07-10 00:44:00+03	18400.00
9B5965	2017-07-19 12:28:00+03	91700.00
9B598B	2017-08-13 09:27:00+03	248500.00
9B598E	2017-07-27 21:41:00+03	55800.00
9B59B3	2017-07-12 13:45:00+03	40600.00
9B59D6	2017-08-09 21:49:00+03	13300.00
9B59F6	2017-08-11 09:52:00+03	28000.00
9B59FC	2017-08-01 14:57:00+03	92900.00
9B5A67	2017-07-18 18:01:00+03	59200.00
9B5AA2	2017-07-30 03:03:00+03	142700.00
9B5B22	2017-08-15 14:20:00+03	28800.00
9B5B38	2017-08-10 19:48:00+03	68800.00
9B5B53	2017-07-28 14:58:00+03	15800.00
9B5BBA	2017-08-03 21:41:00+03	154500.00
9B5C67	2017-08-14 09:01:00+03	6000.00
9B5C6F	2017-08-10 21:29:00+03	26000.00
9B5CB4	2017-07-07 06:12:00+03	33100.00
9B5CE4	2017-08-05 04:13:00+03	11800.00
9B5D3F	2017-08-05 20:34:00+03	6700.00
9B5D5B	2017-07-05 15:19:00+03	112000.00
9B5DAB	2017-07-07 13:43:00+03	59300.00
9B5DE3	2017-07-04 10:19:00+03	4000.00
9B5E7D	2017-07-22 02:28:00+03	82900.00
9B5EC8	2017-08-02 09:05:00+03	159100.00
9B5ED6	2017-07-12 09:00:00+03	27900.00
9B5EEA	2017-07-10 02:35:00+03	8200.00
9B5EFB	2017-08-04 23:23:00+03	19800.00
9B5F16	2017-07-11 05:48:00+03	98000.00
9B5F2A	2017-07-10 10:40:00+03	399600.00
9B5F43	2017-07-08 13:58:00+03	66000.00
9B5F9D	2017-07-12 23:21:00+03	15000.00
9B5FAF	2017-07-03 06:59:00+03	52300.00
9B5FC8	2017-07-11 15:34:00+03	23600.00
9B5FF5	2017-07-28 09:58:00+03	198400.00
9B6004	2017-08-14 15:53:00+03	86300.00
9B601B	2017-08-08 12:27:00+03	263200.00
9B6032	2017-08-03 05:33:00+03	85600.00
9B6071	2017-07-18 10:41:00+03	28800.00
9B6095	2017-07-06 07:34:00+03	115700.00
9B60E4	2017-08-06 08:17:00+03	38800.00
9B613B	2017-07-19 04:35:00+03	48900.00
9B6170	2017-07-12 06:58:00+03	63400.00
9B61D7	2017-07-19 16:28:00+03	110300.00
9B622F	2017-08-02 12:30:00+03	27200.00
9B6245	2017-07-25 16:42:00+03	137700.00
9B628B	2017-06-30 16:05:00+03	28000.00
9B62DC	2017-08-07 04:13:00+03	45000.00
9B631D	2017-07-15 01:58:00+03	39500.00
9B631E	2017-07-11 21:07:00+03	71100.00
9B633B	2017-07-28 00:34:00+03	10100.00
9B635B	2017-07-22 13:18:00+03	77200.00
9B636E	2017-07-15 15:19:00+03	369000.00
9B63FE	2017-08-11 16:54:00+03	55800.00
9B643F	2017-07-27 21:20:00+03	46400.00
9B64C4	2017-07-24 18:56:00+03	29600.00
9B64D1	2017-07-25 22:09:00+03	40800.00
9B64EB	2017-07-24 11:49:00+03	6700.00
9B6547	2017-08-08 23:10:00+03	112000.00
9B65A0	2017-07-23 23:20:00+03	529200.00
9B65EC	2017-07-27 21:33:00+03	354400.00
9B65FC	2017-08-03 16:11:00+03	301800.00
9B6677	2017-08-03 18:16:00+03	26000.00
9B667B	2017-07-11 23:07:00+03	54000.00
9B66F1	2017-07-03 22:23:00+03	46400.00
9B6704	2017-07-29 13:18:00+03	75300.00
9B671B	2017-08-06 01:28:00+03	45200.00
9B678D	2017-07-13 18:57:00+03	56000.00
9B67CA	2017-07-04 15:11:00+03	75300.00
9B6874	2017-08-07 12:02:00+03	56000.00
9B6893	2017-07-26 13:16:00+03	52300.00
9B68FE	2017-07-22 09:50:00+03	56000.00
9B6958	2017-07-12 04:22:00+03	29600.00
9B6962	2017-07-19 13:08:00+03	28000.00
9B69DF	2017-07-31 18:13:00+03	148800.00
9B69F9	2017-07-10 17:14:00+03	85000.00
9B6A3D	2017-08-07 01:14:00+03	124200.00
9B6A3F	2017-07-07 04:37:00+03	131600.00
9B6AC7	2017-07-22 20:31:00+03	13400.00
9B6B28	2017-07-10 22:01:00+03	31600.00
9B6B85	2017-08-02 18:58:00+03	67200.00
9B6BAB	2017-08-10 03:00:00+03	56600.00
9B6C84	2017-07-05 08:16:00+03	81900.00
9B6C95	2017-07-05 19:47:00+03	6700.00
9B6CBD	2017-07-07 17:41:00+03	26000.00
9B6D0E	2017-08-14 20:31:00+03	61800.00
9B6DAA	2017-08-12 00:02:00+03	55800.00
9B6DBC	2017-07-02 18:53:00+03	58800.00
9B6DDB	2017-07-01 00:07:00+03	165000.00
9B6E65	2017-08-05 08:18:00+03	129000.00
9B6E67	2017-08-07 16:25:00+03	241100.00
9B6E93	2017-08-14 14:57:00+03	376700.00
9B6EF3	2017-08-15 09:54:00+03	71900.00
9B6F81	2017-07-21 05:42:00+03	12000.00
9B6FB1	2017-07-16 20:30:00+03	34000.00
9B700A	2017-07-06 14:22:00+03	23200.00
9B7015	2017-08-14 11:08:00+03	33100.00
9B7033	2017-08-14 03:55:00+03	13600.00
9B70C2	2017-07-19 10:07:00+03	44400.00
9B710D	2017-08-08 15:00:00+03	32800.00
9B7110	2017-08-09 08:52:00+03	260300.00
9B7115	2017-07-04 14:23:00+03	58800.00
9B711E	2017-07-24 10:51:00+03	39800.00
9B7143	2017-07-22 22:25:00+03	24800.00
9B714D	2017-07-29 03:52:00+03	23600.00
9B71BE	2017-08-09 00:46:00+03	101600.00
9B7284	2017-06-30 19:03:00+03	31600.00
9B72C6	2017-07-30 02:09:00+03	36200.00
9B72E1	2017-08-10 23:16:00+03	16000.00
9B7376	2017-07-08 00:19:00+03	69500.00
9B73A8	2017-07-09 18:56:00+03	55800.00
9B73B4	2017-08-02 21:54:00+03	130400.00
9B744B	2017-07-29 12:18:00+03	97500.00
9B7490	2017-07-23 18:50:00+03	61900.00
9B74F8	2017-07-13 07:31:00+03	113000.00
9B74FA	2017-07-23 22:07:00+03	95400.00
9B751C	2017-07-08 00:24:00+03	40800.00
9B752B	2017-07-15 06:51:00+03	93700.00
9B7587	2017-08-05 03:38:00+03	130400.00
9B75BC	2017-08-02 11:05:00+03	119500.00
9B75D2	2017-08-15 08:36:00+03	75300.00
9B75E9	2017-07-30 18:52:00+03	80700.00
9B764C	2017-07-07 14:38:00+03	47000.00
9B766E	2017-08-06 19:31:00+03	15400.00
9B76BD	2017-08-01 14:33:00+03	38300.00
9B76D3	2017-07-15 18:38:00+03	28800.00
9B7773	2017-07-20 19:39:00+03	36800.00
9B77A6	2017-07-13 11:50:00+03	56100.00
9B77F0	2017-07-21 14:04:00+03	123000.00
9B782C	2017-08-15 03:17:00+03	22400.00
9B7843	2017-07-09 07:17:00+03	198900.00
9B784E	2017-08-14 20:21:00+03	152200.00
9B78B5	2017-07-11 01:15:00+03	44600.00
9B78B6	2017-07-28 23:49:00+03	70500.00
9B78B7	2017-07-31 19:21:00+03	28000.00
9B79D9	2017-08-01 03:24:00+03	27800.00
9B7A01	2017-08-07 04:53:00+03	58800.00
9B7A14	2017-08-03 15:01:00+03	35700.00
9B7A41	2017-07-07 19:21:00+03	14400.00
9B7ACA	2017-07-20 23:19:00+03	34100.00
9B7ACF	2017-07-08 15:06:00+03	46400.00
9B7B78	2017-07-08 07:26:00+03	29600.00
9B7BA9	2017-07-27 18:11:00+03	266400.00
9B7C13	2017-07-11 14:00:00+03	119500.00
9B7C3A	2017-07-04 06:50:00+03	326100.00
9B7C74	2017-07-15 01:21:00+03	125200.00
9B7CBF	2017-08-04 03:14:00+03	6800.00
9B7D31	2017-08-03 12:33:00+03	43200.00
9B7D32	2017-08-08 11:01:00+03	131100.00
9B7D6C	2017-08-13 21:48:00+03	56900.00
9B7D78	2017-08-07 11:30:00+03	46400.00
9B7D9E	2017-07-25 01:19:00+03	6000.00
9B7DFE	2017-07-05 09:54:00+03	98200.00
9B7E51	2017-06-26 09:01:00+03	207200.00
9B7E58	2017-07-16 12:17:00+03	126900.00
9B7EA7	2017-07-25 20:38:00+03	25400.00
9B7EE0	2017-08-06 01:09:00+03	179200.00
9B7F06	2017-07-22 05:03:00+03	37200.00
9B7FAF	2017-08-10 23:22:00+03	136000.00
9B7FCD	2017-08-03 07:25:00+03	67800.00
9B7FE6	2017-07-30 15:55:00+03	10800.00
9B8049	2017-07-03 04:03:00+03	13400.00
9B80E0	2017-07-27 21:43:00+03	38800.00
9B81C9	2017-08-02 07:29:00+03	45100.00
9B8266	2017-08-12 01:35:00+03	55800.00
9B8284	2017-07-15 07:24:00+03	88100.00
9B82BC	2017-07-16 10:57:00+03	53800.00
9B82F3	2017-07-11 06:41:00+03	10800.00
9B831D	2017-07-05 21:34:00+03	75800.00
9B834E	2017-07-15 14:04:00+03	67200.00
9B8360	2017-08-15 02:38:00+03	155800.00
9B837A	2017-07-06 23:51:00+03	179300.00
9B838C	2017-07-26 05:40:00+03	263200.00
9B839B	2017-07-08 15:12:00+03	65200.00
9B83E7	2017-07-18 09:27:00+03	25600.00
9B83FA	2017-07-20 20:10:00+03	133200.00
9B841D	2017-08-08 13:44:00+03	59600.00
9B843A	2017-08-09 03:41:00+03	103600.00
9B8469	2017-08-02 06:15:00+03	6300.00
9B8470	2017-07-04 11:16:00+03	59200.00
9B851F	2017-08-08 22:08:00+03	57500.00
9B8529	2017-06-28 22:32:00+03	152200.00
9B852A	2017-08-08 20:55:00+03	102200.00
9B8549	2017-07-19 04:56:00+03	25200.00
9B85A4	2017-07-17 23:52:00+03	26000.00
9B85DA	2017-07-29 16:26:00+03	67600.00
9B8652	2017-08-02 06:46:00+03	53200.00
9B8667	2017-07-14 14:45:00+03	106200.00
9B8699	2017-07-05 23:52:00+03	88200.00
9B86D3	2017-07-01 13:59:00+03	21800.00
9B8705	2017-07-27 13:06:00+03	28800.00
9B87CE	2017-08-01 07:59:00+03	54500.00
9B8812	2017-08-02 11:38:00+03	26000.00
9B883D	2017-07-20 03:35:00+03	258400.00
9B88E5	2017-06-30 16:16:00+03	23200.00
9B8914	2017-07-17 20:18:00+03	53600.00
9B8983	2017-08-10 02:56:00+03	23200.00
9B898B	2017-07-15 19:00:00+03	201200.00
9B8A22	2017-07-11 03:43:00+03	123000.00
9B8A53	2017-07-26 12:41:00+03	27400.00
9B8AC6	2017-07-30 11:05:00+03	148200.00
9B8B15	2017-07-31 20:13:00+03	86000.00
9B8B52	2017-06-29 01:46:00+03	6300.00
9B8B73	2017-07-26 04:05:00+03	116400.00
9B8BBB	2017-07-21 03:39:00+03	42700.00
9B8BF4	2017-07-21 23:16:00+03	76800.00
9B8C00	2017-07-17 06:42:00+03	44600.00
9B8C45	2017-08-09 12:00:00+03	38400.00
9B8C5C	2017-07-30 11:14:00+03	55800.00
9B8CCA	2017-08-05 06:10:00+03	51900.00
9B8CDD	2017-08-10 17:21:00+03	25600.00
9B8D75	2017-07-16 18:46:00+03	136200.00
9B8D78	2017-08-14 17:34:00+03	21400.00
9B8DAD	2017-06-30 05:25:00+03	77200.00
9B8DBF	2017-07-23 12:42:00+03	14800.00
9B8E49	2017-08-15 15:56:00+03	270700.00
9B8EA0	2017-08-14 21:37:00+03	27800.00
9B8EA3	2017-07-13 11:09:00+03	111600.00
9B8EB2	2017-07-21 05:47:00+03	27600.00
9B8EC9	2017-06-29 05:25:00+03	56000.00
9B8F4E	2017-08-09 17:08:00+03	111700.00
9B8F78	2017-08-05 16:05:00+03	88600.00
9B8FDF	2017-07-30 23:44:00+03	29000.00
9B8FE0	2017-07-28 14:13:00+03	26000.00
9B8FE1	2017-06-29 01:39:00+03	106400.00
9B8FEC	2017-08-06 20:20:00+03	25600.00
9B8FEF	2017-08-01 05:04:00+03	91500.00
9B9058	2017-07-04 02:00:00+03	203100.00
9B90AC	2017-07-19 08:12:00+03	14000.00
9B90F3	2017-07-17 19:04:00+03	18600.00
9B91C4	2017-07-15 05:02:00+03	179400.00
9B91F8	2017-06-28 02:47:00+03	29200.00
9B91FD	2017-07-10 19:50:00+03	56000.00
9B924B	2017-08-12 19:30:00+03	272300.00
9B926D	2017-06-28 02:29:00+03	88800.00
9B9293	2017-07-07 00:38:00+03	62700.00
9B929B	2017-08-02 15:38:00+03	62900.00
9B93F2	2017-07-22 07:09:00+03	28000.00
9B9405	2017-08-08 00:03:00+03	171000.00
9B941C	2017-07-27 15:25:00+03	62700.00
9B94BE	2017-07-13 19:19:00+03	38800.00
9B9532	2017-08-13 04:39:00+03	25100.00
9B9533	2017-08-03 14:55:00+03	13400.00
9B9557	2017-07-12 15:24:00+03	238200.00
9B959F	2017-07-01 19:23:00+03	26000.00
9B95C8	2017-08-01 02:58:00+03	266200.00
9B95EB	2017-07-12 23:56:00+03	15000.00
9B95FF	2017-08-12 21:17:00+03	23200.00
9B9600	2017-07-28 10:40:00+03	40800.00
9B9616	2017-07-12 02:46:00+03	27200.00
9B9632	2017-07-23 19:20:00+03	65000.00
9B965E	2017-07-22 05:20:00+03	99200.00
9B9678	2017-07-02 15:16:00+03	31600.00
9B970C	2017-07-14 14:57:00+03	75300.00
9B9735	2017-08-04 09:26:00+03	21200.00
9B97C3	2017-07-21 12:45:00+03	40600.00
9B97FC	2017-07-07 05:01:00+03	39400.00
9B987B	2017-08-03 18:41:00+03	406700.00
9B988B	2017-08-07 04:45:00+03	78400.00
9B98AF	2017-08-12 16:43:00+03	246000.00
9B98C0	2017-07-18 13:45:00+03	13400.00
9B9945	2017-08-01 02:58:00+03	6700.00
9B994D	2017-07-11 16:11:00+03	26800.00
9B99CA	2017-07-27 13:19:00+03	23200.00
9B99E4	2017-07-29 14:52:00+03	271400.00
9B99E5	2017-08-07 11:19:00+03	133200.00
9B99EA	2017-07-23 17:13:00+03	44600.00
9B9A02	2017-07-05 11:36:00+03	83200.00
9B9A20	2017-08-08 11:40:00+03	39200.00
9B9A34	2017-08-10 06:36:00+03	47400.00
9B9A87	2017-08-13 19:12:00+03	24300.00
9B9A96	2017-07-29 16:09:00+03	24400.00
9B9AAD	2017-07-09 13:47:00+03	26000.00
9B9ACD	2017-07-24 23:41:00+03	173600.00
9B9AEC	2017-07-01 16:46:00+03	46200.00
9B9B6B	2017-07-24 02:16:00+03	52000.00
9B9B8D	2017-07-22 06:52:00+03	28800.00
9B9BA2	2017-07-24 11:20:00+03	373400.00
9B9C44	2017-07-08 19:33:00+03	79200.00
9B9C5B	2017-08-06 08:12:00+03	67700.00
9B9C68	2017-07-28 01:04:00+03	31200.00
9B9CAB	2017-08-13 13:24:00+03	16000.00
9B9D20	2017-08-02 18:51:00+03	72300.00
9B9D4D	2017-07-29 11:49:00+03	56000.00
9B9DE3	2017-07-13 21:06:00+03	81300.00
9B9E02	2017-07-11 15:23:00+03	81200.00
9B9E4C	2017-07-04 16:42:00+03	47400.00
9B9E8D	2017-07-03 07:04:00+03	174400.00
9B9E9B	2017-07-30 15:42:00+03	176400.00
9B9EC2	2017-07-02 07:23:00+03	74100.00
9B9ECB	2017-08-07 02:11:00+03	19000.00
9B9F30	2017-08-07 04:06:00+03	93900.00
9B9F48	2017-07-16 23:38:00+03	51800.00
9B9FC1	2017-07-20 15:54:00+03	6000.00
9B9FDF	2017-07-12 20:09:00+03	54400.00
9BA000	2017-08-15 12:08:00+03	394400.00
9BA02F	2017-07-08 13:07:00+03	27800.00
9BA060	2017-07-25 21:12:00+03	271200.00
9BA0A5	2017-07-25 18:21:00+03	100000.00
9BA0C1	2017-08-10 20:56:00+03	6800.00
9BA0D4	2017-08-07 00:14:00+03	130400.00
9BA106	2017-07-30 03:49:00+03	6700.00
9BA108	2017-07-05 04:28:00+03	12600.00
9BA128	2017-07-28 00:17:00+03	133200.00
9BA158	2017-07-20 17:39:00+03	492000.00
9BA15B	2017-07-13 12:30:00+03	117600.00
9BA18A	2017-07-20 09:49:00+03	27200.00
9BA1A8	2017-07-08 07:31:00+03	11000.00
9BA1EC	2017-07-12 20:21:00+03	26000.00
9BA1FA	2017-07-03 14:12:00+03	7400.00
9BA25A	2017-08-11 20:04:00+03	125400.00
9BA273	2017-08-11 10:53:00+03	129700.00
9BA29B	2017-08-12 22:04:00+03	56000.00
9BA2C2	2017-07-19 15:21:00+03	46500.00
9BA302	2017-07-11 12:21:00+03	125000.00
9BA340	2017-08-08 06:13:00+03	59700.00
9BA404	2017-08-11 22:39:00+03	52800.00
9BA4D6	2017-07-29 15:22:00+03	62800.00
9BA4E4	2017-08-08 05:04:00+03	6000.00
9BA51B	2017-07-28 21:22:00+03	80900.00
9BA600	2017-08-10 11:45:00+03	46000.00
9BA602	2017-07-29 14:51:00+03	31800.00
9BA610	2017-07-21 13:21:00+03	75300.00
9BA648	2017-08-05 19:42:00+03	19500.00
9BA677	2017-08-12 22:33:00+03	90400.00
9BA6C5	2017-08-03 15:50:00+03	134200.00
9BA6DC	2017-07-15 19:11:00+03	29400.00
9BA76C	2017-08-04 19:11:00+03	6000.00
9BA790	2017-07-07 04:37:00+03	26800.00
9BA859	2017-07-23 17:13:00+03	48800.00
9BA869	2017-08-07 01:48:00+03	41400.00
9BA8D9	2017-08-07 23:36:00+03	23200.00
9BA921	2017-08-15 11:42:00+03	76600.00
9BA998	2017-08-14 13:05:00+03	85100.00
9BA9A4	2017-07-08 18:28:00+03	82000.00
9BAA61	2017-07-06 07:35:00+03	100100.00
9BAAAB	2017-07-01 12:24:00+03	278400.00
9BAADB	2017-08-08 11:05:00+03	55800.00
9BAB10	2017-07-30 15:30:00+03	39200.00
9BAB2D	2017-08-09 23:56:00+03	13700.00
9BAB72	2017-06-30 07:27:00+03	31400.00
9BAB82	2017-07-28 23:34:00+03	48800.00
9BAB9C	2017-08-04 12:56:00+03	26000.00
9BABA1	2017-07-25 16:32:00+03	147700.00
9BABB4	2017-07-13 18:19:00+03	270800.00
9BABBF	2017-07-17 20:09:00+03	52600.00
9BABEF	2017-07-09 18:16:00+03	112000.00
9BAC63	2017-08-09 21:52:00+03	40300.00
9BAC9B	2017-07-18 09:09:00+03	21000.00
9BACA7	2017-07-17 11:06:00+03	114700.00
9BACAC	2017-07-04 20:47:00+03	41400.00
9BACBD	2017-07-11 03:09:00+03	226900.00
9BACC9	2017-07-25 07:02:00+03	89400.00
9BACD3	2017-07-14 05:51:00+03	35200.00
9BAD19	2017-07-22 12:47:00+03	46400.00
9BAD1C	2017-07-11 01:06:00+03	73600.00
9BAD8E	2017-07-24 22:57:00+03	50600.00
9BADA1	2017-08-08 10:38:00+03	51900.00
9BADD8	2017-07-28 08:55:00+03	29400.00
9BADDE	2017-07-15 17:01:00+03	94900.00
9BADE0	2017-08-03 08:51:00+03	36200.00
9BADF4	2017-07-01 00:13:00+03	46300.00
9BAE39	2017-08-14 07:47:00+03	23100.00
9BAE4F	2017-08-02 18:20:00+03	40800.00
9BAEA4	2017-07-29 07:15:00+03	69400.00
9BAEC5	2017-08-11 11:02:00+03	88100.00
9BAF0C	2017-08-11 18:23:00+03	46400.00
9BAF39	2017-08-07 13:32:00+03	41200.00
9BAFD2	2017-08-04 13:22:00+03	130400.00
9BB042	2017-07-14 20:06:00+03	79900.00
9BB06B	2017-07-02 14:16:00+03	21400.00
9BB0A5	2017-07-12 11:34:00+03	24400.00
9BB103	2017-08-14 07:17:00+03	133800.00
9BB120	2017-07-22 10:22:00+03	28800.00
9BB16E	2017-07-29 07:58:00+03	27200.00
9BB1C1	2017-08-09 20:19:00+03	55000.00
9BB228	2017-08-15 14:05:00+03	42800.00
9BB236	2017-08-08 17:05:00+03	48400.00
9BB26E	2017-07-07 08:03:00+03	43000.00
9BB275	2017-07-10 22:39:00+03	30000.00
9BB347	2017-08-13 01:57:00+03	61800.00
9BB35A	2017-07-01 16:34:00+03	30200.00
9BB43F	2017-07-17 00:35:00+03	136800.00
9BB443	2017-08-08 04:04:00+03	188000.00
9BB471	2017-07-27 06:05:00+03	89700.00
9BB4B1	2017-07-12 03:49:00+03	184500.00
9BB4D7	2017-08-04 09:16:00+03	9200.00
9BB4DA	2017-07-09 06:41:00+03	56900.00
9BB57B	2017-08-12 23:00:00+03	15900.00
9BB5AE	2017-07-15 09:21:00+03	66300.00
9BB5D1	2017-08-03 22:33:00+03	18000.00
9BB613	2017-07-29 21:37:00+03	23900.00
9BB615	2017-07-13 09:10:00+03	95200.00
9BB723	2017-07-30 18:55:00+03	69700.00
9BB726	2017-08-10 05:30:00+03	56000.00
9BB761	2017-07-05 06:18:00+03	26400.00
9BB849	2017-07-19 12:25:00+03	79900.00
9BB867	2017-08-06 21:44:00+03	26800.00
9BB91C	2017-07-03 20:22:00+03	41400.00
9BB91F	2017-07-16 01:10:00+03	46400.00
9BB920	2017-07-21 03:57:00+03	85000.00
9BB938	2017-07-03 01:56:00+03	40700.00
9BB98E	2017-08-05 02:15:00+03	49900.00
9BBA1E	2017-07-26 02:42:00+03	6300.00
9BBA4A	2017-08-05 14:52:00+03	26700.00
9BBA55	2017-08-01 10:59:00+03	55800.00
9BBACC	2017-07-24 10:23:00+03	115900.00
9BBB0C	2017-07-20 20:57:00+03	99700.00
9BBB59	2017-07-10 17:29:00+03	75800.00
9BBB9A	2017-07-05 02:22:00+03	96300.00
9BBC2B	2017-07-24 03:16:00+03	33100.00
9BBD6F	2017-07-23 09:18:00+03	20200.00
9BBDB5	2017-07-06 22:15:00+03	6300.00
9BBDB8	2017-08-06 22:10:00+03	74900.00
9BBE42	2017-08-02 00:27:00+03	194200.00
9BBE43	2017-08-10 17:28:00+03	68400.00
9BBE5F	2017-07-08 19:33:00+03	19600.00
9BBEFB	2017-07-07 13:38:00+03	46000.00
9BBFF9	2017-08-02 00:09:00+03	59800.00
9BC05E	2017-07-07 21:45:00+03	28000.00
9BC07A	2017-08-09 05:16:00+03	43900.00
9BC0E2	2017-08-09 20:52:00+03	40800.00
9BC0EF	2017-07-27 16:55:00+03	56100.00
9BC0FB	2017-07-25 16:57:00+03	6400.00
9BC0FC	2017-07-11 12:27:00+03	56600.00
9BC132	2017-07-12 12:49:00+03	42600.00
9BC150	2017-07-30 07:09:00+03	57400.00
9BC172	2017-07-10 04:39:00+03	28800.00
9BC1D0	2017-07-14 09:55:00+03	121000.00
9BC211	2017-07-08 19:19:00+03	137600.00
9BC27A	2017-06-29 10:03:00+03	14700.00
9BC2E1	2017-07-14 18:22:00+03	72200.00
9BC31C	2017-08-13 21:12:00+03	7200.00
9BC333	2017-08-05 17:50:00+03	11600.00
9BC39F	2017-07-30 03:29:00+03	66600.00
9BC3A8	2017-08-07 15:49:00+03	28000.00
9BC3CB	2017-08-13 05:41:00+03	54000.00
9BC3DE	2017-08-09 01:12:00+03	67700.00
9BC3E3	2017-07-26 12:12:00+03	75200.00
9BC3EE	2017-08-09 10:05:00+03	37600.00
9BC40B	2017-08-13 02:47:00+03	26000.00
9BC420	2017-07-31 00:10:00+03	96300.00
9BC48D	2017-08-14 06:03:00+03	16400.00
9BC48F	2017-07-10 22:01:00+03	70800.00
9BC51D	2017-07-08 23:53:00+03	248400.00
9BC536	2017-07-03 06:06:00+03	240600.00
9BC56A	2017-07-08 02:20:00+03	492000.00
9BC58E	2017-08-08 03:19:00+03	104800.00
9BC66C	2017-07-09 07:01:00+03	99200.00
9BC679	2017-07-27 07:06:00+03	68100.00
9BC691	2017-07-28 01:18:00+03	37900.00
9BC6C8	2017-08-06 00:59:00+03	271200.00
9BC6E9	2017-08-04 03:30:00+03	48800.00
9BC752	2017-07-12 15:29:00+03	116400.00
9BC7A0	2017-07-13 10:49:00+03	115100.00
9BC7A5	2017-07-18 17:00:00+03	32400.00
9BC7E0	2017-07-17 22:41:00+03	23600.00
9BC866	2017-07-20 17:48:00+03	11700.00
9BC867	2017-08-09 02:31:00+03	105400.00
9BC8E9	2017-06-29 02:45:00+03	27900.00
9BC8F6	2017-08-14 16:06:00+03	31600.00
9BC910	2017-07-29 06:48:00+03	75300.00
9BC995	2017-08-08 00:34:00+03	47400.00
9BC9F8	2017-07-06 14:09:00+03	6400.00
9BCA61	2017-07-24 13:59:00+03	20200.00
9BCA65	2017-08-05 19:10:00+03	46000.00
9BCA70	2017-08-13 08:44:00+03	6300.00
9BCA9F	2017-07-30 22:56:00+03	79900.00
9BCAA7	2017-07-06 10:19:00+03	42700.00
9BCB65	2017-07-27 11:14:00+03	36000.00
9BCB6D	2017-07-08 00:06:00+03	516800.00
9BCBA4	2017-07-14 17:12:00+03	23400.00
9BCC0D	2017-06-28 01:38:00+03	57600.00
9BCC1A	2017-07-12 06:57:00+03	44500.00
9BCC1B	2017-07-06 19:22:00+03	132800.00
9BCCA0	2017-07-05 12:35:00+03	65900.00
9BCCA9	2017-08-13 14:43:00+03	154700.00
9BCCAD	2017-08-05 15:42:00+03	97800.00
9BCCEE	2017-06-30 07:54:00+03	47000.00
9BCD03	2017-07-22 13:55:00+03	132700.00
9BCD14	2017-08-01 16:25:00+03	248300.00
9BCD7F	2017-07-27 21:11:00+03	139400.00
9BCD89	2017-07-30 22:11:00+03	111600.00
9BCE0C	2017-08-07 17:40:00+03	44800.00
9BCEAC	2017-07-16 06:31:00+03	55800.00
9BCECD	2017-07-11 07:35:00+03	71100.00
9BCFA9	2017-07-18 06:42:00+03	20800.00
9BCFB9	2017-07-12 05:10:00+03	25200.00
9BCFC3	2017-07-03 15:08:00+03	65800.00
9BCFD7	2017-07-11 17:06:00+03	68000.00
9BD033	2017-07-13 04:15:00+03	35600.00
9BD083	2017-07-24 04:46:00+03	47200.00
9BD112	2017-07-19 02:37:00+03	46200.00
9BD14A	2017-06-30 13:59:00+03	7200.00
9BD168	2017-08-07 23:24:00+03	100600.00
9BD16B	2017-08-11 20:01:00+03	55800.00
9BD1EC	2017-07-22 21:41:00+03	168000.00
9BD237	2017-07-22 21:40:00+03	77500.00
9BD27E	2017-08-04 16:46:00+03	47600.00
9BD302	2017-07-18 07:56:00+03	100700.00
9BD310	2017-07-13 13:58:00+03	46300.00
9BD321	2017-07-12 09:54:00+03	28000.00
9BD340	2017-08-11 21:48:00+03	128800.00
9BD39C	2017-08-04 14:10:00+03	128900.00
9BD3AE	2017-07-14 14:13:00+03	123000.00
9BD40E	2017-07-24 01:56:00+03	116500.00
9BD453	2017-08-01 06:38:00+03	109000.00
9BD49E	2017-07-08 10:20:00+03	369000.00
9BD542	2017-07-22 10:18:00+03	21800.00
9BD54B	2017-08-04 07:34:00+03	88200.00
9BD5BC	2017-08-01 09:58:00+03	92000.00
9BD5E2	2017-07-30 12:55:00+03	86600.00
9BD5EC	2017-06-30 08:44:00+03	91500.00
9BD5EE	2017-08-11 08:23:00+03	266400.00
9BD696	2017-07-19 16:29:00+03	34000.00
9BD6AC	2017-08-06 14:26:00+03	88600.00
9BD6E9	2017-07-24 23:52:00+03	52100.00
9BD707	2017-07-11 23:55:00+03	13000.00
9BD711	2017-07-06 17:20:00+03	26800.00
9BD751	2017-08-09 01:55:00+03	70700.00
9BD80D	2017-08-04 09:19:00+03	31400.00
9BD872	2017-07-17 05:41:00+03	51800.00
9BD882	2017-07-03 04:00:00+03	112000.00
9BD884	2017-07-21 10:58:00+03	18600.00
9BD8A8	2017-08-13 09:45:00+03	79600.00
9BD8F4	2017-07-11 15:54:00+03	185300.00
9BD90F	2017-07-23 20:20:00+03	64800.00
9BD942	2017-08-05 22:05:00+03	8200.00
9BD97F	2017-07-08 09:39:00+03	112000.00
9BD9C3	2017-07-19 05:06:00+03	55800.00
9BDA80	2017-07-18 17:48:00+03	44800.00
9BDAAF	2017-07-18 16:36:00+03	37200.00
9BDAF4	2017-07-27 07:32:00+03	137600.00
9BDB0F	2017-07-27 18:16:00+03	140000.00
9BDB91	2017-07-17 10:21:00+03	154000.00
9BDC07	2017-07-22 01:33:00+03	23200.00
9BDC2B	2017-08-06 21:16:00+03	304800.00
9BDC60	2017-08-11 13:35:00+03	89200.00
9BDCB6	2017-08-07 01:02:00+03	41200.00
9BDCCB	2017-07-06 00:02:00+03	19600.00
9BDD3D	2017-08-14 08:36:00+03	167400.00
9BDD57	2017-07-24 20:40:00+03	65900.00
9BDDDF	2017-07-08 14:03:00+03	70700.00
9BDE0C	2017-07-31 23:14:00+03	89600.00
9BDE4E	2017-07-16 22:46:00+03	88900.00
9BDE87	2017-07-23 01:44:00+03	26800.00
9BDEBB	2017-07-07 18:08:00+03	92400.00
9BDEC9	2017-07-10 06:52:00+03	34000.00
9BDF6A	2017-07-28 01:59:00+03	23200.00
9BDF94	2017-08-01 06:55:00+03	36800.00
9BDFB1	2017-08-12 18:59:00+03	14700.00
9BE0BE	2017-07-16 04:18:00+03	51900.00
9BE0C5	2017-07-23 03:35:00+03	38500.00
9BE12A	2017-08-06 19:27:00+03	65900.00
9BE13B	2017-07-01 04:38:00+03	271100.00
9BE141	2017-07-30 17:35:00+03	29800.00
9BE162	2017-07-26 01:49:00+03	34000.00
9BE190	2017-07-11 14:38:00+03	189100.00
9BE27F	2017-06-30 01:48:00+03	111600.00
9BE31C	2017-07-12 19:03:00+03	49500.00
9BE369	2017-07-28 12:07:00+03	27600.00
9BE436	2017-07-27 21:32:00+03	26800.00
9BE4C0	2017-07-25 00:08:00+03	23200.00
9BE4C8	2017-07-11 02:46:00+03	36400.00
9BE500	2017-07-24 06:05:00+03	113000.00
9BE533	2017-07-08 22:04:00+03	57300.00
9BE542	2017-08-07 02:28:00+03	57300.00
9BE575	2017-07-31 21:31:00+03	139200.00
9BE60E	2017-07-06 08:31:00+03	266400.00
9BE638	2017-07-18 08:10:00+03	58600.00
9BE645	2017-07-28 09:29:00+03	55600.00
9BE68E	2017-07-07 11:17:00+03	68000.00
9BE6CB	2017-07-03 14:28:00+03	40000.00
9BE714	2017-07-13 13:28:00+03	135400.00
9BE729	2017-08-04 12:15:00+03	70400.00
9BE785	2017-07-10 15:11:00+03	541300.00
9BE7BA	2017-07-12 12:36:00+03	24400.00
9BE7E0	2017-07-06 07:14:00+03	77900.00
9BE7FF	2017-08-08 02:15:00+03	135400.00
9BE80A	2017-08-11 08:22:00+03	22000.00
9BE865	2017-08-15 17:34:00+03	123900.00
9BE871	2017-07-27 03:05:00+03	115600.00
9BE915	2017-08-05 22:44:00+03	66000.00
9BE927	2017-08-07 13:34:00+03	59200.00
9BE9CE	2017-08-06 19:13:00+03	24400.00
9BE9FC	2017-08-12 11:45:00+03	48400.00
9BEA05	2017-07-21 23:11:00+03	73300.00
9BEA24	2017-07-18 14:25:00+03	6800.00
9BEA2D	2017-07-14 07:25:00+03	23200.00
9BEA54	2017-08-04 18:54:00+03	272300.00
9BEACF	2017-07-25 06:31:00+03	57500.00
9BEAEF	2017-07-26 00:57:00+03	21800.00
9BEB33	2017-07-29 15:51:00+03	62100.00
9BEB44	2017-07-24 23:16:00+03	27600.00
9BEB63	2017-07-09 23:48:00+03	25600.00
9BEB6C	2017-07-08 20:33:00+03	34800.00
9BEBB7	2017-07-25 06:22:00+03	65000.00
9BEBC0	2017-08-13 09:25:00+03	189800.00
9BEBCE	2017-08-07 11:30:00+03	48400.00
9BEC8D	2017-08-01 02:43:00+03	260900.00
9BECB9	2017-08-05 02:27:00+03	53000.00
9BED09	2017-07-23 20:09:00+03	78300.00
9BED56	2017-07-14 11:26:00+03	28000.00
9BED6A	2017-07-17 07:04:00+03	66300.00
9BEDA8	2017-07-12 12:14:00+03	56000.00
9BEE01	2017-08-03 02:20:00+03	123000.00
9BEE7D	2017-07-31 11:50:00+03	29600.00
9BEEA7	2017-07-03 06:17:00+03	23400.00
9BEEBE	2017-08-08 05:17:00+03	69700.00
9BEEE5	2017-07-31 23:49:00+03	29600.00
9BEF01	2017-08-15 15:15:00+03	27200.00
9BEF3C	2017-07-27 10:01:00+03	31600.00
9BEF84	2017-07-01 23:37:00+03	67600.00
9BF058	2017-07-23 12:02:00+03	21400.00
9BF088	2017-07-08 11:54:00+03	376600.00
9BF08F	2017-08-10 03:40:00+03	147100.00
9BF0FC	2017-07-22 12:38:00+03	15900.00
9BF115	2017-07-19 03:32:00+03	14800.00
9BF14F	2017-08-05 11:09:00+03	23200.00
9BF173	2017-08-04 21:29:00+03	66600.00
9BF19D	2017-07-28 03:58:00+03	82900.00
9BF1A3	2017-07-22 03:56:00+03	64700.00
9BF1A6	2017-08-02 09:32:00+03	48800.00
9BF1E2	2017-07-20 11:58:00+03	298600.00
9BF241	2017-08-11 15:09:00+03	38600.00
9BF28D	2017-07-10 14:31:00+03	66600.00
9BF306	2017-08-04 06:03:00+03	199700.00
9BF315	2017-08-02 04:30:00+03	52000.00
9BF320	2017-07-20 00:10:00+03	91200.00
9BF3F0	2017-08-14 05:56:00+03	24400.00
9BF497	2017-08-10 19:55:00+03	65900.00
9BF4B9	2017-07-18 09:39:00+03	40400.00
9BF4CE	2017-08-13 09:19:00+03	83600.00
9BF50E	2017-07-04 00:51:00+03	136200.00
9BF534	2017-08-03 06:03:00+03	54500.00
9BF5BE	2017-08-07 19:14:00+03	38400.00
9BF5DE	2017-08-01 06:28:00+03	55800.00
9BF638	2017-08-01 04:24:00+03	62600.00
9BF661	2017-06-26 02:09:00+03	12200.00
9BF6C0	2017-06-28 23:20:00+03	30200.00
9BF6E3	2017-07-19 18:50:00+03	117200.00
9BF6EB	2017-08-14 18:18:00+03	186000.00
9BF7A4	2017-07-12 01:35:00+03	19600.00
9BF7AE	2017-07-03 04:19:00+03	42800.00
9BF805	2017-08-08 11:29:00+03	103500.00
9BF864	2017-07-30 03:54:00+03	58900.00
9BF8BB	2017-07-16 08:25:00+03	81800.00
9BF9AC	2017-07-18 21:23:00+03	15700.00
9BF9C6	2017-07-26 12:55:00+03	25600.00
9BF9F2	2017-07-21 12:42:00+03	58800.00
9BFA05	2017-08-04 03:43:00+03	135400.00
9BFA20	2017-07-04 18:37:00+03	55800.00
9BFAAB	2017-08-08 00:20:00+03	135400.00
9BFAAE	2017-08-06 13:44:00+03	50200.00
9BFAC3	2017-07-24 17:54:00+03	23600.00
9BFAC5	2017-08-06 22:14:00+03	103500.00
9BFADF	2017-07-15 22:11:00+03	19600.00
9BFB04	2017-07-18 10:47:00+03	199600.00
9BFB06	2017-07-28 04:25:00+03	620200.00
9BFB24	2017-07-29 05:50:00+03	229500.00
9BFBC9	2017-07-21 22:09:00+03	258300.00
9BFBF3	2017-07-24 02:57:00+03	80000.00
9BFC9E	2017-08-05 06:00:00+03	46200.00
9BFCC4	2017-07-09 13:53:00+03	189800.00
9BFCC6	2017-07-12 07:04:00+03	128800.00
9BFCD2	2017-07-05 00:24:00+03	21600.00
9BFCD8	2017-07-04 02:37:00+03	73600.00
9BFD38	2017-08-01 10:55:00+03	23200.00
9BFD55	2017-07-29 12:57:00+03	62800.00
9BFDC2	2017-07-17 03:31:00+03	40300.00
9BFE25	2017-08-07 20:35:00+03	67000.00
9BFE5F	2017-08-09 05:46:00+03	67800.00
9BFE93	2017-07-06 13:52:00+03	20400.00
9BFEBB	2017-08-14 13:57:00+03	149300.00
9BFF09	2017-07-19 14:23:00+03	55800.00
9BFF3A	2017-07-31 15:39:00+03	26000.00
9BFFC8	2017-07-29 01:52:00+03	28000.00
9C00FA	2017-07-23 17:41:00+03	23400.00
9C0126	2017-07-24 10:43:00+03	26200.00
9C0133	2017-07-12 06:42:00+03	76600.00
9C014C	2017-07-17 13:12:00+03	47000.00
9C0189	2017-08-10 09:53:00+03	63700.00
9C01B0	2017-07-21 20:47:00+03	33100.00
9C01CF	2017-07-27 09:54:00+03	293900.00
9C01DA	2017-08-06 22:32:00+03	51600.00
9C0248	2017-08-13 18:02:00+03	67200.00
9C0287	2017-08-14 10:55:00+03	19600.00
9C0292	2017-08-07 18:54:00+03	24400.00
9C02AA	2017-08-01 00:39:00+03	26200.00
9C02B5	2017-07-06 21:09:00+03	492000.00
9C02D2	2017-08-05 05:08:00+03	66600.00
9C02EC	2017-08-14 16:48:00+03	232100.00
9C02F2	2017-07-28 06:22:00+03	23200.00
9C040E	2017-07-18 03:58:00+03	84100.00
9C046E	2017-07-12 00:40:00+03	28800.00
9C04CF	2017-07-16 12:56:00+03	123600.00
9C0551	2017-07-23 02:35:00+03	16400.00
9C0586	2017-07-04 11:34:00+03	12400.00
9C059E	2017-07-09 04:55:00+03	56600.00
9C05D8	2017-08-11 04:34:00+03	123500.00
9C0617	2017-07-18 07:11:00+03	29600.00
9C069A	2017-07-14 02:52:00+03	57700.00
9C06A0	2017-07-28 19:09:00+03	66900.00
9C06A2	2017-08-11 20:46:00+03	24800.00
9C06C2	2017-08-10 18:50:00+03	79900.00
9C06F1	2017-08-10 05:08:00+03	102100.00
9C084B	2017-07-28 16:18:00+03	12600.00
9C091A	2017-07-13 17:35:00+03	56000.00
9C0984	2017-07-30 21:10:00+03	75300.00
9C09C4	2017-07-19 05:36:00+03	86300.00
9C09E5	2017-08-03 23:46:00+03	133100.00
9C0A0A	2017-08-02 01:02:00+03	39200.00
9C0A5B	2017-07-04 15:04:00+03	25800.00
9C0A65	2017-08-14 10:48:00+03	60400.00
9C0AE9	2017-07-11 18:05:00+03	254900.00
9C0B80	2017-07-10 12:00:00+03	12600.00
9C0B92	2017-07-01 14:03:00+03	62000.00
9C0BD8	2017-08-01 05:37:00+03	246000.00
9C0C3E	2017-07-19 01:59:00+03	173500.00
9C0CF9	2017-07-28 22:42:00+03	32700.00
9C0D51	2017-08-14 06:06:00+03	57600.00
9C0D65	2017-08-07 15:16:00+03	30200.00
9C0E65	2017-08-07 15:11:00+03	44000.00
9C0EA3	2017-08-11 16:37:00+03	140000.00
9C0EAD	2017-07-23 22:00:00+03	56000.00
9C0ED1	2017-08-14 02:22:00+03	111600.00
9C0F6F	2017-07-21 03:02:00+03	27200.00
9C10E8	2017-08-10 00:00:00+03	75600.00
9C10EE	2017-08-10 00:01:00+03	26000.00
9C1117	2017-07-31 03:31:00+03	28800.00
9C113A	2017-08-01 06:57:00+03	69800.00
9C116D	2017-08-10 08:23:00+03	131100.00
9C11CD	2017-08-07 19:03:00+03	289300.00
9C11D0	2017-07-17 10:41:00+03	119500.00
9C1218	2017-07-01 19:17:00+03	16400.00
9C1299	2017-07-03 20:50:00+03	43200.00
9C12B4	2017-07-20 22:25:00+03	32800.00
9C12C9	2017-07-21 11:44:00+03	254900.00
9C1387	2017-08-11 01:06:00+03	43100.00
9C1389	2017-08-08 11:06:00+03	25800.00
9C1398	2017-07-02 15:41:00+03	58800.00
9C13A8	2017-07-18 15:40:00+03	52800.00
9C13C0	2017-07-22 06:39:00+03	36400.00
9C140C	2017-07-18 11:48:00+03	369000.00
9C140E	2017-07-22 12:25:00+03	95900.00
9C145E	2017-07-20 22:31:00+03	59200.00
9C147D	2017-08-04 22:41:00+03	43500.00
9C14D9	2017-07-16 03:26:00+03	103800.00
9C1512	2017-08-10 07:21:00+03	56000.00
9C1529	2017-08-02 19:33:00+03	94000.00
9C152E	2017-06-30 14:35:00+03	67200.00
9C153D	2017-07-19 08:00:00+03	89200.00
9C1551	2017-07-03 17:52:00+03	56200.00
9C158A	2017-07-26 16:06:00+03	6700.00
9C15F4	2017-08-14 17:10:00+03	57300.00
9C1656	2017-07-16 02:21:00+03	152400.00
9C16D9	2017-07-22 16:17:00+03	144900.00
9C16EE	2017-07-20 03:26:00+03	136800.00
9C1737	2017-07-04 02:00:00+03	147700.00
9C1769	2017-07-26 13:54:00+03	90800.00
9C1771	2017-07-06 23:48:00+03	132800.00
9C178D	2017-07-12 16:34:00+03	75700.00
9C17B6	2017-08-06 10:07:00+03	25600.00
9C17F4	2017-08-04 18:53:00+03	282300.00
9C17FF	2017-06-28 03:24:00+03	47000.00
9C1842	2017-08-03 14:14:00+03	56600.00
9C1872	2017-07-02 23:00:00+03	28800.00
9C188D	2017-07-16 09:07:00+03	55800.00
9C18AD	2017-07-29 20:40:00+03	270800.00
9C18B0	2017-08-02 02:20:00+03	56000.00
9C194E	2017-07-28 02:15:00+03	62000.00
9C1966	2017-07-27 00:59:00+03	44500.00
9C19C4	2017-07-05 18:00:00+03	81700.00
9C1A82	2017-07-24 14:53:00+03	58400.00
9C1ABE	2017-07-11 15:08:00+03	56000.00
9C1AEA	2017-06-28 22:11:00+03	21400.00
9C1B29	2017-08-10 00:42:00+03	28000.00
9C1B3A	2017-07-22 10:10:00+03	72400.00
9C1B45	2017-07-11 06:43:00+03	51800.00
9C1B6E	2017-08-11 14:18:00+03	31700.00
9C1B99	2017-07-03 10:03:00+03	135400.00
9C1BA7	2017-07-11 06:11:00+03	123000.00
9C1C71	2017-07-06 11:27:00+03	115900.00
9C1CFC	2017-07-10 07:33:00+03	26100.00
9C1D06	2017-07-22 10:34:00+03	69500.00
9C1D7F	2017-07-03 23:49:00+03	332900.00
9C1DE1	2017-07-13 12:43:00+03	45200.00
9C1F47	2017-08-12 21:28:00+03	172100.00
9C1F78	2017-07-14 23:59:00+03	23600.00
9C1F7C	2017-07-30 19:36:00+03	66600.00
9C2023	2017-07-03 21:26:00+03	270800.00
9C2096	2017-08-11 12:22:00+03	119500.00
9C20B2	2017-07-04 11:08:00+03	166900.00
9C20D6	2017-07-20 02:34:00+03	6800.00
9C20DA	2017-07-07 07:19:00+03	23200.00
9C20EB	2017-07-11 12:01:00+03	68400.00
9C2182	2017-08-07 23:14:00+03	166400.00
9C219F	2017-07-15 14:08:00+03	44400.00
9C21BE	2017-08-12 07:57:00+03	11600.00
9C21CF	2017-08-14 11:31:00+03	26000.00
9C21E8	2017-07-30 14:39:00+03	144300.00
9C2223	2017-07-12 13:50:00+03	58200.00
9C2224	2017-07-29 13:28:00+03	316400.00
9C222A	2017-07-02 17:23:00+03	46000.00
9C2284	2017-07-24 01:49:00+03	34000.00
9C22AC	2017-07-14 11:55:00+03	21800.00
9C22BD	2017-08-10 14:13:00+03	23600.00
9C22DE	2017-07-15 23:29:00+03	13600.00
9C23C5	2017-07-01 16:54:00+03	258400.00
9C23FB	2017-08-08 19:18:00+03	22200.00
9C23FF	2017-08-05 03:23:00+03	41600.00
9C2412	2017-07-09 09:32:00+03	46000.00
9C242F	2017-07-29 15:30:00+03	47800.00
9C244D	2017-07-02 21:40:00+03	23200.00
9C2483	2017-08-13 17:21:00+03	52000.00
9C24A4	2017-07-24 14:00:00+03	406700.00
9C24D1	2017-07-18 04:50:00+03	58900.00
9C24E2	2017-07-22 08:56:00+03	250500.00
9C2539	2017-07-24 07:14:00+03	37900.00
9C2544	2017-07-04 11:23:00+03	53300.00
9C254A	2017-07-30 04:53:00+03	93100.00
9C25BD	2017-08-06 17:06:00+03	59200.00
9C261A	2017-07-02 14:22:00+03	59200.00
9C2639	2017-07-01 17:38:00+03	99300.00
9C263D	2017-07-14 21:08:00+03	203000.00
9C2684	2017-07-09 02:57:00+03	68800.00
9C2687	2017-06-29 11:07:00+03	58800.00
9C26FC	2017-07-05 19:25:00+03	28800.00
9C2701	2017-07-26 03:56:00+03	27200.00
9C275A	2017-07-16 08:39:00+03	133100.00
9C275F	2017-06-27 19:59:00+03	181800.00
9C2794	2017-08-01 13:25:00+03	36200.00
9C27E9	2017-07-03 17:33:00+03	16400.00
9C27F9	2017-08-04 13:56:00+03	100200.00
9C2856	2017-07-15 14:57:00+03	32800.00
9C285F	2017-07-10 06:57:00+03	6300.00
9C2895	2017-08-12 11:00:00+03	31600.00
9C28A1	2017-07-30 22:08:00+03	67700.00
9C28BF	2017-07-29 17:38:00+03	23400.00
9C2927	2017-07-26 13:45:00+03	68400.00
9C2930	2017-08-07 16:51:00+03	27200.00
9C2935	2017-07-20 23:18:00+03	19600.00
9C2962	2017-07-10 02:03:00+03	61800.00
9C29A9	2017-07-20 08:19:00+03	100800.00
9C29E3	2017-07-06 03:44:00+03	96300.00
9C2A1C	2017-08-09 20:33:00+03	25900.00
9C2A21	2017-07-02 17:13:00+03	62600.00
9C2AA3	2017-08-15 14:27:00+03	196300.00
9C2B0A	2017-07-20 15:19:00+03	72200.00
9C2B3A	2017-07-23 17:23:00+03	116200.00
9C2BCB	2017-07-29 19:07:00+03	47000.00
9C2C85	2017-08-15 14:28:00+03	145300.00
9C2CA9	2017-07-06 15:15:00+03	46400.00
9C2CDA	2017-08-09 02:41:00+03	40000.00
9C2D29	2017-08-13 09:52:00+03	202200.00
9C2D5C	2017-07-04 14:22:00+03	61600.00
9C2D9E	2017-07-20 20:54:00+03	52400.00
9C2DCA	2017-07-01 07:45:00+03	81600.00
9C2DCC	2017-07-28 15:37:00+03	166100.00
9C2DF3	2017-07-25 07:50:00+03	172600.00
9C2E0D	2017-08-03 10:29:00+03	24000.00
9C2E24	2017-08-10 13:20:00+03	121200.00
9C2E28	2017-07-19 22:33:00+03	158600.00
9C2E4F	2017-08-04 11:17:00+03	46400.00
9C2E56	2017-07-28 18:21:00+03	111600.00
9C2E66	2017-08-03 00:51:00+03	6700.00
9C2EAB	2017-08-05 17:27:00+03	62600.00
9C2EC0	2017-08-06 14:55:00+03	13000.00
9C2EC9	2017-07-25 15:10:00+03	203100.00
9C2ECA	2017-07-04 17:50:00+03	59300.00
9C2EDD	2017-07-17 09:43:00+03	165400.00
9C2F16	2017-07-08 09:54:00+03	51200.00
9C2FB8	2017-08-02 20:37:00+03	28000.00
9C2FFF	2017-08-12 22:16:00+03	240600.00
9C304C	2017-08-02 10:07:00+03	34000.00
9C3070	2017-07-14 06:45:00+03	135400.00
9C315C	2017-08-05 03:08:00+03	152600.00
9C319A	2017-07-05 01:44:00+03	30900.00
9C31C7	2017-08-13 04:44:00+03	54800.00
9C3230	2017-07-14 05:08:00+03	59300.00
9C3247	2017-07-25 23:19:00+03	24400.00
9C32CA	2017-08-12 11:20:00+03	46200.00
9C32FA	2017-08-14 00:55:00+03	27300.00
9C333D	2017-08-10 08:35:00+03	421000.00
9C3419	2017-07-13 03:07:00+03	73600.00
9C342B	2017-07-17 21:53:00+03	70700.00
9C3444	2017-07-01 06:45:00+03	56000.00
9C3471	2017-07-14 17:54:00+03	38800.00
9C3511	2017-07-05 23:08:00+03	95700.00
9C3520	2017-08-13 17:16:00+03	21800.00
9C3554	2017-06-29 11:34:00+03	114800.00
9C35BC	2017-08-13 11:31:00+03	131600.00
9C35D7	2017-08-15 05:41:00+03	23200.00
9C364D	2017-07-11 18:29:00+03	136400.00
9C370B	2017-07-16 20:03:00+03	23400.00
9C37A7	2017-08-11 12:34:00+03	53100.00
9C37BA	2017-07-03 05:18:00+03	32300.00
9C37CC	2017-07-27 14:07:00+03	55800.00
9C384D	2017-07-28 00:25:00+03	28800.00
9C3898	2017-07-17 16:42:00+03	26800.00
9C38E0	2017-07-07 19:46:00+03	88700.00
9C38E6	2017-07-05 20:27:00+03	112600.00
9C3991	2017-08-09 18:26:00+03	23200.00
9C39A4	2017-07-28 02:57:00+03	39200.00
9C39C1	2017-08-05 21:03:00+03	154800.00
9C39F5	2017-07-06 06:20:00+03	51300.00
9C3B2C	2017-07-17 02:15:00+03	173900.00
9C3B62	2017-07-01 21:21:00+03	44800.00
9C3B6A	2017-08-10 01:36:00+03	46300.00
9C3B91	2017-07-08 11:00:00+03	23200.00
9C3B9E	2017-08-13 22:24:00+03	272400.00
9C3BFE	2017-07-01 03:06:00+03	64900.00
9C3C8D	2017-07-09 16:05:00+03	54800.00
9C3D48	2017-08-14 02:49:00+03	8200.00
9C3D73	2017-07-19 16:14:00+03	94000.00
9C3DC8	2017-07-28 10:39:00+03	32800.00
9C3E29	2017-07-26 05:07:00+03	131600.00
9C3E3A	2017-08-06 13:36:00+03	153000.00
9C3EEA	2017-07-31 14:07:00+03	59800.00
9C3F38	2017-08-05 11:28:00+03	89700.00
9C3F79	2017-08-11 23:23:00+03	59800.00
9C3FBC	2017-08-03 21:11:00+03	35200.00
9C4021	2017-07-19 03:56:00+03	12000.00
9C40C6	2017-07-30 21:54:00+03	37900.00
9C40E9	2017-08-14 08:16:00+03	37000.00
9C412D	2017-07-14 10:02:00+03	38400.00
9C4157	2017-07-12 05:25:00+03	43100.00
9C4164	2017-07-19 22:01:00+03	387300.00
9C4169	2017-07-26 07:41:00+03	44800.00
9C4197	2017-08-15 16:59:00+03	23200.00
9C41BC	2017-07-10 23:51:00+03	25900.00
9C4323	2017-07-23 11:53:00+03	31400.00
9C433D	2017-08-14 20:38:00+03	36500.00
9C4391	2017-08-07 11:26:00+03	31600.00
9C43D3	2017-07-30 00:42:00+03	51800.00
9C4481	2017-07-05 21:21:00+03	6000.00
9C44AE	2017-08-04 11:12:00+03	82100.00
9C44B3	2017-08-02 10:43:00+03	31600.00
9C44C4	2017-08-14 13:43:00+03	37000.00
9C44D4	2017-07-13 20:12:00+03	12400.00
9C4502	2017-08-04 18:25:00+03	15400.00
9C4551	2017-07-13 15:46:00+03	151200.00
9C4626	2017-08-07 03:47:00+03	218000.00
9C4646	2017-07-31 12:45:00+03	129000.00
9C4663	2017-07-12 09:28:00+03	114300.00
9C46A1	2017-08-05 16:44:00+03	44400.00
9C4705	2017-07-13 07:45:00+03	23600.00
9C476A	2017-07-22 14:14:00+03	68800.00
9C4881	2017-06-30 03:28:00+03	88900.00
9C48F2	2017-08-04 07:40:00+03	35600.00
9C4971	2017-07-20 13:11:00+03	49000.00
9C499A	2017-07-17 09:03:00+03	123000.00
9C499C	2017-07-08 16:39:00+03	18600.00
9C4A0E	2017-07-04 11:10:00+03	57400.00
9C4A4F	2017-07-06 04:20:00+03	16400.00
9C4AC7	2017-07-10 05:04:00+03	27400.00
9C4AE0	2017-07-09 02:22:00+03	246000.00
9C4AED	2017-07-30 21:39:00+03	131200.00
9C4B72	2017-08-03 21:47:00+03	78100.00
9C4C2A	2017-07-02 18:40:00+03	84500.00
9C4C69	2017-08-02 17:53:00+03	118000.00
9C4C78	2017-07-26 07:19:00+03	160300.00
9C4C94	2017-07-07 00:26:00+03	51600.00
9C4C97	2017-07-09 21:29:00+03	57500.00
9C4CA6	2017-07-12 14:49:00+03	29400.00
9C4CEF	2017-07-08 14:13:00+03	86400.00
9C4D34	2017-08-14 10:38:00+03	265600.00
9C4DD7	2017-07-06 01:23:00+03	135600.00
9C4F0B	2017-08-07 04:28:00+03	75300.00
9C4F19	2017-08-11 23:04:00+03	112000.00
9C4F4C	2017-08-06 03:17:00+03	49200.00
9C4F5D	2017-07-24 12:21:00+03	201200.00
9C4FBA	2017-07-03 21:46:00+03	29400.00
9C4FCB	2017-08-08 15:57:00+03	78300.00
9C4FE9	2017-08-08 19:44:00+03	32800.00
9C4FF8	2017-08-12 07:42:00+03	24400.00
9C503C	2017-07-28 05:50:00+03	37800.00
9C506E	2017-08-02 01:11:00+03	43200.00
9C50A3	2017-08-02 06:42:00+03	61500.00
9C514F	2017-07-17 18:52:00+03	135300.00
9C515F	2017-07-16 14:26:00+03	290400.00
9C51D0	2017-07-23 08:21:00+03	266200.00
9C5219	2017-07-18 16:57:00+03	89500.00
9C52D5	2017-07-24 01:01:00+03	79500.00
9C53B6	2017-07-23 07:41:00+03	56600.00
9C53D7	2017-07-14 16:56:00+03	8000.00
9C540A	2017-07-30 08:46:00+03	74800.00
9C5441	2017-07-10 00:42:00+03	72800.00
9C5451	2017-07-31 17:57:00+03	59100.00
9C545C	2017-08-05 02:26:00+03	7400.00
9C5483	2017-07-18 06:09:00+03	67600.00
9C54A7	2017-07-07 02:01:00+03	102900.00
9C54DE	2017-07-10 16:48:00+03	68100.00
9C5514	2017-07-19 07:12:00+03	111600.00
9C5547	2017-07-12 13:38:00+03	133100.00
9C5551	2017-07-29 21:13:00+03	58600.00
9C55E9	2017-07-21 01:34:00+03	67600.00
9C55FF	2017-08-04 08:59:00+03	28800.00
9C566D	2017-07-11 22:13:00+03	64600.00
9C5683	2017-07-30 07:48:00+03	23600.00
9C56D7	2017-07-09 22:04:00+03	235500.00
9C56F2	2017-07-02 21:43:00+03	56100.00
9C56FE	2017-06-29 08:50:00+03	75600.00
9C573A	2017-07-30 09:31:00+03	6000.00
9C5756	2017-08-10 07:05:00+03	28700.00
9C5791	2017-07-14 14:53:00+03	21600.00
9C580F	2017-08-05 08:12:00+03	69500.00
9C5846	2017-07-16 12:12:00+03	279100.00
9C599B	2017-08-10 02:52:00+03	124200.00
9C599E	2017-07-20 18:33:00+03	128800.00
9C59C2	2017-07-15 01:55:00+03	27900.00
9C59DD	2017-07-31 11:48:00+03	225800.00
9C5A26	2017-07-05 16:18:00+03	134700.00
9C5AAB	2017-08-15 15:41:00+03	58800.00
9C5AB2	2017-08-04 05:18:00+03	43400.00
9C5AD9	2017-07-04 00:46:00+03	153300.00
9C5B24	2017-08-10 21:52:00+03	177800.00
9C5B36	2017-08-12 04:56:00+03	34000.00
9C5B39	2017-08-14 09:21:00+03	55800.00
9C5BD5	2017-08-03 22:05:00+03	25100.00
9C5BEE	2017-08-10 21:31:00+03	131100.00
9C5C0D	2017-07-27 14:28:00+03	74700.00
9C5C37	2017-07-17 04:15:00+03	58400.00
9C5C63	2017-08-06 11:58:00+03	136800.00
9C5C7A	2017-08-03 00:19:00+03	28800.00
9C5D78	2017-07-25 00:42:00+03	48800.00
9C5DAE	2017-07-27 08:42:00+03	33300.00
9C5EDC	2017-07-06 17:17:00+03	22000.00
9C5F03	2017-08-02 09:18:00+03	283500.00
9C5F3F	2017-08-07 00:47:00+03	25000.00
9C5F76	2017-07-28 09:51:00+03	124200.00
9C5FA1	2017-07-28 06:56:00+03	47200.00
9C6050	2017-08-08 05:05:00+03	28800.00
9C60F7	2017-07-20 23:40:00+03	67200.00
9C612A	2017-08-12 22:35:00+03	6300.00
9C612B	2017-07-20 00:42:00+03	121400.00
9C6148	2017-08-12 07:01:00+03	40800.00
9C6209	2017-08-01 00:50:00+03	53300.00
9C6223	2017-07-04 18:32:00+03	56000.00
9C6229	2017-07-13 05:49:00+03	805800.00
9C6247	2017-07-11 05:07:00+03	30400.00
9C6271	2017-08-08 11:43:00+03	119400.00
9C62EF	2017-08-07 08:01:00+03	35300.00
9C62F8	2017-07-22 05:20:00+03	128800.00
9C631F	2017-08-01 22:43:00+03	66600.00
9C632C	2017-07-22 22:04:00+03	23600.00
9C635B	2017-07-23 19:27:00+03	62600.00
9C63AF	2017-07-03 10:55:00+03	70700.00
9C63F3	2017-08-13 14:31:00+03	13400.00
9C6429	2017-08-15 13:14:00+03	66800.00
9C643C	2017-07-01 05:36:00+03	38800.00
9C647C	2017-08-13 12:27:00+03	75600.00
9C649D	2017-07-09 12:12:00+03	38500.00
9C6515	2017-06-29 15:50:00+03	26000.00
9C6530	2017-08-09 07:41:00+03	12400.00
9C65A9	2017-07-20 14:18:00+03	39300.00
9C6646	2017-08-14 00:44:00+03	30900.00
9C666F	2017-07-14 09:03:00+03	77200.00
9C669F	2017-07-15 13:32:00+03	48800.00
9C6749	2017-07-12 17:27:00+03	16400.00
9C674C	2017-08-06 21:55:00+03	37400.00
9C6776	2017-07-28 08:48:00+03	491000.00
9C67A8	2017-07-24 21:15:00+03	25400.00
9C67ED	2017-07-05 20:15:00+03	111600.00
9C67EF	2017-07-12 13:45:00+03	24200.00
9C6854	2017-06-29 20:30:00+03	64700.00
9C6890	2017-08-12 18:47:00+03	75800.00
9C68A6	2017-07-15 20:58:00+03	40000.00
9C6907	2017-08-11 02:46:00+03	133200.00
9C69D6	2017-07-06 16:44:00+03	148800.00
9C6A4A	2017-07-29 23:43:00+03	47500.00
9C6AA3	2017-07-18 06:23:00+03	58800.00
9C6AAC	2017-07-22 00:15:00+03	6000.00
9C6B20	2017-08-14 17:15:00+03	13000.00
9C6B6D	2017-07-15 09:27:00+03	62000.00
9C6B7E	2017-07-30 11:21:00+03	123000.00
9C6B8A	2017-08-09 23:21:00+03	46000.00
9C6CB2	2017-08-15 02:40:00+03	102100.00
9C6D35	2017-08-13 16:09:00+03	70700.00
9C6D7C	2017-07-25 16:22:00+03	26200.00
9C6D9B	2017-08-10 14:14:00+03	92800.00
9C6DDE	2017-07-04 10:14:00+03	181000.00
9C6E04	2017-07-01 21:39:00+03	30200.00
9C6E44	2017-07-28 16:56:00+03	94400.00
9C6E83	2017-07-29 15:48:00+03	92800.00
9C6E9B	2017-07-12 03:12:00+03	114800.00
9C6EF5	2017-07-03 13:42:00+03	26000.00
9C6F9A	2017-07-02 22:59:00+03	57600.00
9C7001	2017-08-09 00:39:00+03	90400.00
9C7077	2017-07-30 12:47:00+03	202600.00
9C70F7	2017-08-02 20:01:00+03	27400.00
9C7159	2017-08-03 19:46:00+03	12000.00
9C7177	2017-08-09 05:41:00+03	75600.00
9C7198	2017-07-30 16:34:00+03	95000.00
9C71C0	2017-07-29 18:51:00+03	36800.00
9C723B	2017-07-23 17:15:00+03	71700.00
9C7268	2017-07-08 03:05:00+03	9300.00
9C72F3	2017-08-03 05:37:00+03	406000.00
9C7332	2017-08-02 02:00:00+03	106100.00
9C73AD	2017-07-14 15:57:00+03	12600.00
9C7453	2017-08-05 04:23:00+03	58000.00
9C7558	2017-07-25 02:42:00+03	73900.00
9C75B4	2017-08-05 13:31:00+03	8000.00
9C761A	2017-07-20 15:24:00+03	50800.00
9C7694	2017-07-25 12:19:00+03	135400.00
9C769F	2017-07-31 20:57:00+03	118900.00
9C76B2	2017-07-02 17:34:00+03	54800.00
9C771E	2017-07-15 22:13:00+03	258400.00
9C7789	2017-07-03 00:14:00+03	311700.00
9C77D8	2017-07-17 10:31:00+03	123000.00
9C7983	2017-07-15 16:42:00+03	97800.00
9C7A7F	2017-07-28 07:57:00+03	133200.00
9C7AB2	2017-07-12 02:45:00+03	204700.00
9C7ABE	2017-06-27 03:31:00+03	32700.00
9C7ABF	2017-07-30 00:21:00+03	59300.00
9C7ACC	2017-07-28 01:27:00+03	153300.00
9C7B0E	2017-07-14 20:52:00+03	22400.00
9C7B18	2017-07-23 20:15:00+03	39200.00
9C7B6B	2017-06-29 13:11:00+03	67000.00
9C7BBC	2017-07-11 11:02:00+03	92000.00
9C7BD7	2017-06-30 05:35:00+03	62900.00
9C7BEE	2017-07-09 08:48:00+03	57500.00
9C7C04	2017-08-06 06:32:00+03	21400.00
9C7C8D	2017-08-15 04:58:00+03	81000.00
9C7CC5	2017-08-14 00:12:00+03	56000.00
9C7CFA	2017-07-05 00:36:00+03	48300.00
9C7D08	2017-07-30 19:48:00+03	252200.00
9C7D8F	2017-07-11 21:57:00+03	27400.00
9C7DD5	2017-07-09 11:39:00+03	43800.00
9C7E1A	2017-08-12 19:08:00+03	27200.00
9C7E61	2017-08-10 14:42:00+03	13600.00
9C7E68	2017-07-25 00:17:00+03	74400.00
9C7EC0	2017-07-13 00:57:00+03	133100.00
9C7F96	2017-08-07 04:12:00+03	86800.00
9C7FB4	2017-07-31 09:15:00+03	270000.00
9C7FB6	2017-07-10 10:49:00+03	26600.00
9C804D	2017-07-25 02:25:00+03	87900.00
9C8051	2017-07-26 15:23:00+03	106900.00
9C8060	2017-08-13 13:49:00+03	130200.00
9C80A4	2017-08-13 05:50:00+03	17200.00
9C80B1	2017-07-14 01:47:00+03	36000.00
9C80D0	2017-07-07 13:55:00+03	17800.00
9C8139	2017-07-13 18:02:00+03	45500.00
9C8150	2017-07-30 22:01:00+03	6000.00
9C8172	2017-07-03 23:15:00+03	13400.00
9C81C6	2017-08-15 10:33:00+03	40600.00
9C8211	2017-07-16 02:32:00+03	88600.00
9C8267	2017-07-28 21:07:00+03	67000.00
9C829B	2017-08-10 06:48:00+03	24000.00
9C8320	2017-07-27 10:34:00+03	99200.00
9C8325	2017-08-12 05:52:00+03	37800.00
9C8329	2017-08-01 15:55:00+03	43600.00
9C834C	2017-08-13 11:54:00+03	188200.00
9C835D	2017-07-08 10:49:00+03	133100.00
9C8370	2017-07-03 12:04:00+03	40800.00
9C837A	2017-07-09 02:42:00+03	58800.00
9C83CA	2017-08-05 18:41:00+03	26200.00
9C83FA	2017-07-23 12:07:00+03	62600.00
9C8431	2017-07-12 17:15:00+03	29600.00
9C8471	2017-08-12 08:28:00+03	40000.00
9C8480	2017-08-10 23:41:00+03	103700.00
9C856F	2017-07-12 07:59:00+03	18600.00
9C860E	2017-07-27 23:21:00+03	52400.00
9C8619	2017-07-21 18:20:00+03	21600.00
9C8652	2017-08-12 14:04:00+03	78300.00
9C86BA	2017-07-10 21:36:00+03	117600.00
9C86E7	2017-08-13 22:58:00+03	40800.00
9C870D	2017-07-14 14:59:00+03	70800.00
9C8740	2017-07-28 18:04:00+03	51900.00
9C8774	2017-07-16 07:40:00+03	51900.00
9C8775	2017-07-02 05:43:00+03	36100.00
9C877D	2017-07-30 11:30:00+03	34100.00
9C8819	2017-07-26 09:59:00+03	92900.00
9C88F3	2017-08-02 21:39:00+03	83000.00
9C897C	2017-07-26 19:16:00+03	29600.00
9C89D5	2017-07-08 20:38:00+03	24300.00
9C89DC	2017-07-29 02:55:00+03	54400.00
9C8A2A	2017-07-14 09:50:00+03	92400.00
9C8A4E	2017-07-26 20:44:00+03	119500.00
9C8A5A	2017-07-13 02:19:00+03	117800.00
9C8A6D	2017-07-20 01:00:00+03	86300.00
9C8AA4	2017-07-18 01:38:00+03	136800.00
9C8AB0	2017-08-07 12:58:00+03	26800.00
9C8AE6	2017-07-12 19:35:00+03	20000.00
9C8B25	2017-08-01 00:30:00+03	40800.00
9C8B32	2017-07-27 18:16:00+03	56200.00
9C8B4C	2017-07-02 02:46:00+03	80900.00
9C8B73	2017-07-28 06:43:00+03	52300.00
9C8B8C	2017-07-31 20:17:00+03	6800.00
9C8BD0	2017-07-11 06:38:00+03	27800.00
9C8C9A	2017-07-18 15:41:00+03	29600.00
9C8D15	2017-07-20 04:34:00+03	21800.00
9C8D28	2017-07-05 03:56:00+03	67200.00
9C8D42	2017-07-24 09:38:00+03	35700.00
9C8D6E	2017-08-02 22:56:00+03	75600.00
9C8D7F	2017-07-23 03:23:00+03	23400.00
9C8D8C	2017-08-02 19:30:00+03	256700.00
9C8D96	2017-08-01 22:35:00+03	26800.00
9C8DB7	2017-07-30 00:46:00+03	22200.00
9C8DBF	2017-07-26 09:17:00+03	6000.00
9C8E0E	2017-07-26 18:35:00+03	44000.00
9C8E7A	2017-08-14 15:36:00+03	28800.00
9C8E82	2017-07-05 01:10:00+03	58200.00
9C8EA5	2017-07-10 02:45:00+03	27400.00
9C8EAF	2017-07-19 07:48:00+03	139300.00
9C8F13	2017-08-06 16:36:00+03	31000.00
9C8F2B	2017-08-12 05:57:00+03	44800.00
9C8F88	2017-07-10 19:17:00+03	61600.00
9C8F9A	2017-08-04 00:29:00+03	23400.00
9C9006	2017-07-15 19:22:00+03	53600.00
9C9065	2017-07-13 17:20:00+03	159200.00
9C909D	2017-08-04 16:57:00+03	23400.00
9C90DD	2017-08-06 20:37:00+03	40600.00
9C912E	2017-08-13 06:18:00+03	258400.00
9C9215	2017-07-30 23:21:00+03	51300.00
9C922B	2017-07-15 16:19:00+03	114800.00
9C922F	2017-07-10 21:56:00+03	27300.00
9C924C	2017-08-05 14:54:00+03	97700.00
9C92BC	2017-08-12 17:35:00+03	46400.00
9C92C4	2017-08-03 22:19:00+03	249100.00
9C92EE	2017-07-28 06:40:00+03	43600.00
9C9320	2017-06-27 10:06:00+03	28800.00
9C9391	2017-07-26 02:32:00+03	56600.00
9C93AE	2017-08-04 22:46:00+03	31400.00
9C93B7	2017-07-14 14:36:00+03	55800.00
9C93C0	2017-07-26 17:16:00+03	138000.00
9C93E9	2017-07-25 04:14:00+03	42000.00
9C940F	2017-06-30 17:24:00+03	30200.00
9C945F	2017-08-14 10:45:00+03	29400.00
9C9482	2017-07-16 06:44:00+03	75300.00
9C948E	2017-07-21 00:38:00+03	84500.00
9C94BA	2017-07-04 14:52:00+03	123000.00
9C9506	2017-07-06 22:16:00+03	26000.00
9C9553	2017-07-20 11:01:00+03	13000.00
9C9557	2017-08-01 16:34:00+03	58800.00
9C9578	2017-08-08 03:49:00+03	147000.00
9C957D	2017-07-17 04:59:00+03	131100.00
9C959C	2017-07-06 17:07:00+03	169900.00
9C9620	2017-07-30 14:26:00+03	65800.00
9C9678	2017-07-25 11:51:00+03	46400.00
9C967D	2017-07-27 02:46:00+03	134900.00
9C970A	2017-07-22 08:14:00+03	166000.00
9C970C	2017-07-28 05:35:00+03	59200.00
9C9733	2017-08-13 22:46:00+03	207100.00
9C975F	2017-08-03 15:13:00+03	26000.00
9C977C	2017-08-07 03:46:00+03	89600.00
9C978C	2017-07-05 06:32:00+03	66200.00
9C97B4	2017-08-01 03:31:00+03	56100.00
9C97E5	2017-07-17 16:39:00+03	67600.00
9C9873	2017-07-07 16:56:00+03	81300.00
9C98D3	2017-07-27 15:07:00+03	175700.00
9C98D9	2017-07-08 20:16:00+03	21800.00
9C98DF	2017-07-26 12:12:00+03	6800.00
9C9986	2017-07-06 20:22:00+03	14000.00
9C99DE	2017-07-13 09:56:00+03	53100.00
9C99E6	2017-07-12 03:55:00+03	48800.00
9C9A1F	2017-07-06 23:20:00+03	28800.00
9C9A23	2017-08-15 16:13:00+03	92800.00
9C9A40	2017-07-11 19:57:00+03	117200.00
9C9A6E	2017-07-05 18:19:00+03	30900.00
9C9AA1	2017-07-20 15:37:00+03	132800.00
9C9B14	2017-07-17 01:56:00+03	23600.00
9C9B5D	2017-07-21 12:28:00+03	15400.00
9C9B96	2017-08-03 04:22:00+03	28000.00
9C9BC4	2017-08-11 23:31:00+03	206100.00
9C9BFC	2017-07-25 01:03:00+03	54400.00
9C9C27	2017-08-13 19:19:00+03	310800.00
9C9C77	2017-08-14 07:40:00+03	28800.00
9C9CF2	2017-08-10 16:28:00+03	124200.00
9C9D5E	2017-07-08 04:43:00+03	98400.00
9C9E6E	2017-07-07 10:10:00+03	88600.00
9C9F2C	2017-08-08 21:03:00+03	12600.00
9C9F39	2017-07-11 07:27:00+03	28000.00
9C9F3B	2017-07-18 06:18:00+03	24400.00
9C9F92	2017-07-04 04:59:00+03	62800.00
9C9FB0	2017-07-29 04:42:00+03	52900.00
9CA088	2017-07-05 08:31:00+03	542200.00
9CA098	2017-07-28 16:17:00+03	26000.00
9CA0A1	2017-07-17 10:20:00+03	50600.00
9CA0C9	2017-07-07 21:56:00+03	73200.00
9CA0F2	2017-07-18 23:28:00+03	31600.00
9CA11D	2017-07-19 15:54:00+03	69000.00
9CA12E	2017-07-03 05:02:00+03	72000.00
9CA187	2017-08-01 15:43:00+03	35800.00
9CA1D4	2017-07-27 08:50:00+03	59800.00
9CA20C	2017-07-07 16:37:00+03	492000.00
9CA227	2017-07-05 04:36:00+03	58600.00
9CA293	2017-07-04 16:59:00+03	146300.00
9CA2B3	2017-08-13 08:44:00+03	23600.00
9CA2CA	2017-08-15 13:35:00+03	99200.00
9CA2CB	2017-08-05 21:13:00+03	38800.00
9CA2DA	2017-07-09 18:46:00+03	25000.00
9CA307	2017-07-04 08:51:00+03	28600.00
9CA315	2017-07-10 04:45:00+03	49600.00
9CA32D	2017-08-05 10:20:00+03	52000.00
9CA368	2017-08-03 04:16:00+03	167200.00
9CA372	2017-07-15 06:34:00+03	55800.00
9CA390	2017-07-31 09:18:00+03	386300.00
9CA3BF	2017-07-30 15:57:00+03	32400.00
9CA3FD	2017-07-02 21:57:00+03	46000.00
9CA459	2017-07-04 08:48:00+03	38500.00
9CA46A	2017-08-06 23:24:00+03	66600.00
9CA47D	2017-07-22 01:40:00+03	47900.00
9CA4C6	2017-08-11 20:57:00+03	48800.00
9CA51D	2017-07-22 06:04:00+03	68900.00
9CA528	2017-07-08 22:02:00+03	30400.00
9CA52F	2017-08-12 12:24:00+03	116700.00
9CA592	2017-07-23 18:00:00+03	30200.00
9CA593	2017-08-07 07:22:00+03	258000.00
9CA5EF	2017-07-02 12:15:00+03	14300.00
9CA606	2017-07-14 02:40:00+03	149300.00
9CA62C	2017-08-14 03:15:00+03	81600.00
9CA653	2017-07-21 08:46:00+03	21400.00
9CA66B	2017-08-10 20:32:00+03	21600.00
9CA6BA	2017-07-17 13:21:00+03	23900.00
9CA6E8	2017-07-12 09:14:00+03	155600.00
9CA706	2017-07-05 07:34:00+03	29200.00
9CA760	2017-08-08 17:40:00+03	133200.00
9CA83A	2017-07-14 15:11:00+03	28800.00
9CA864	2017-08-06 13:41:00+03	25600.00
9CA8A4	2017-07-15 22:56:00+03	34000.00
9CA8F1	2017-07-08 14:51:00+03	45200.00
9CA903	2017-07-06 17:29:00+03	173500.00
9CA9B5	2017-07-30 09:46:00+03	293500.00
9CA9BB	2017-07-09 19:03:00+03	30200.00
9CAA2F	2017-07-31 13:03:00+03	6300.00
9CAA39	2017-08-12 06:45:00+03	70400.00
9CAA6B	2017-08-03 03:14:00+03	36200.00
9CAA90	2017-07-05 18:35:00+03	58600.00
9CAABA	2017-07-14 21:52:00+03	94700.00
9CAB69	2017-07-04 13:31:00+03	35600.00
9CAB6A	2017-08-01 04:23:00+03	60600.00
9CAB91	2017-08-13 16:27:00+03	114800.00
9CAC54	2017-07-15 07:50:00+03	47000.00
9CAC88	2017-07-19 14:34:00+03	78800.00
9CAD09	2017-07-07 11:05:00+03	25400.00
9CAD3B	2017-07-17 09:18:00+03	56900.00
9CAD52	2017-08-11 17:48:00+03	93700.00
9CAD6D	2017-07-04 09:23:00+03	62600.00
9CADA1	2017-07-02 12:09:00+03	248400.00
9CADF3	2017-08-02 21:27:00+03	21800.00
9CAE50	2017-07-27 07:38:00+03	254600.00
9CAF17	2017-07-05 09:49:00+03	44800.00
9CAFA5	2017-08-04 14:29:00+03	142000.00
9CAFB4	2017-08-09 04:29:00+03	14400.00
9CAFB7	2017-08-08 03:13:00+03	36200.00
9CAFC2	2017-07-15 14:55:00+03	128800.00
9CB0DB	2017-07-28 09:14:00+03	55800.00
9CB0E4	2017-07-02 15:38:00+03	86400.00
9CB102	2017-07-22 05:05:00+03	49000.00
9CB15B	2017-07-10 16:53:00+03	55800.00
9CB197	2017-07-05 23:18:00+03	131600.00
9CB277	2017-08-15 07:15:00+03	36800.00
9CB2E3	2017-07-18 18:25:00+03	28000.00
9CB2E6	2017-07-30 20:58:00+03	83200.00
9CB335	2017-08-07 20:03:00+03	84000.00
9CB3BC	2017-08-04 07:46:00+03	9800.00
9CB3E4	2017-07-24 12:06:00+03	69900.00
9CB449	2017-07-03 04:41:00+03	40800.00
9CB46B	2017-08-06 12:14:00+03	66600.00
9CB4B0	2017-07-06 07:43:00+03	111600.00
9CB4C2	2017-07-21 21:39:00+03	34400.00
9CB4DB	2017-07-16 15:06:00+03	12600.00
9CB4E1	2017-07-15 10:11:00+03	37300.00
9CB513	2017-07-02 23:00:00+03	107500.00
9CB60E	2017-07-24 02:15:00+03	22100.00
9CB60F	2017-07-30 01:00:00+03	23600.00
9CB635	2017-07-14 07:20:00+03	20400.00
9CB66A	2017-07-26 13:39:00+03	198400.00
9CB713	2017-07-10 23:01:00+03	22000.00
9CB71A	2017-07-07 19:17:00+03	246000.00
9CB7CB	2017-07-30 04:17:00+03	92000.00
9CB7E9	2017-08-15 07:54:00+03	49400.00
9CB7FF	2017-08-11 03:10:00+03	137400.00
9CB807	2017-08-04 08:43:00+03	14000.00
9CB81A	2017-07-28 03:40:00+03	71100.00
9CB834	2017-07-09 18:04:00+03	44000.00
9CB85B	2017-08-15 11:14:00+03	88600.00
9CB8A8	2017-07-30 12:28:00+03	34000.00
9CB8FD	2017-08-14 00:19:00+03	49800.00
9CB934	2017-08-02 00:41:00+03	146300.00
9CB9AE	2017-08-08 19:31:00+03	12600.00
9CBA6A	2017-07-01 01:43:00+03	82700.00
9CBAA6	2017-07-28 06:21:00+03	31600.00
9CBAC5	2017-07-12 06:57:00+03	139500.00
9CBAFF	2017-07-02 07:23:00+03	81900.00
9CBB6B	2017-08-01 07:30:00+03	130200.00
9CBB7C	2017-07-10 12:37:00+03	96300.00
9CBC63	2017-08-13 01:54:00+03	25200.00
9CBC6D	2017-07-18 07:12:00+03	246000.00
9CBC9E	2017-07-03 13:24:00+03	48800.00
9CBCD2	2017-07-31 17:59:00+03	92900.00
9CBD39	2017-07-25 00:32:00+03	266400.00
9CBD8D	2017-07-04 16:45:00+03	29600.00
9CBDD0	2017-08-12 23:06:00+03	20400.00
9CBE78	2017-07-18 13:50:00+03	8400.00
9CBE8A	2017-08-06 12:32:00+03	6000.00
9CBE98	2017-08-01 14:58:00+03	124300.00
9CBECB	2017-07-18 11:39:00+03	13400.00
9CBF25	2017-08-03 23:02:00+03	49400.00
9CBF37	2017-08-15 02:00:00+03	67600.00
9CBF4A	2017-08-04 00:24:00+03	95700.00
9CBF56	2017-07-18 19:30:00+03	86300.00
9CBF68	2017-08-13 05:17:00+03	77000.00
9CBFEE	2017-07-19 04:31:00+03	112000.00
9CC053	2017-06-28 07:26:00+03	26000.00
9CC0E3	2017-07-25 00:16:00+03	40200.00
9CC1AA	2017-07-16 02:28:00+03	112300.00
9CC1D0	2017-07-08 20:18:00+03	172800.00
9CC2C6	2017-07-03 07:23:00+03	49900.00
9CC2E6	2017-07-03 13:53:00+03	12600.00
9CC418	2017-08-15 13:29:00+03	151800.00
9CC419	2017-08-11 14:24:00+03	35400.00
9CC461	2017-07-04 01:32:00+03	29300.00
9CC489	2017-07-02 07:01:00+03	97900.00
9CC4D7	2017-08-01 10:25:00+03	120400.00
9CC4E2	2017-07-11 04:25:00+03	124400.00
9CC51F	2017-07-11 21:20:00+03	64800.00
9CC539	2017-07-14 00:46:00+03	24400.00
9CC566	2017-08-14 02:55:00+03	54100.00
9CC57E	2017-07-22 11:07:00+03	28800.00
9CC58A	2017-07-11 21:19:00+03	56000.00
9CC5AB	2017-08-01 22:05:00+03	136000.00
9CC5E4	2017-07-10 16:41:00+03	10800.00
9CC5FD	2017-07-14 14:42:00+03	277800.00
9CC610	2017-07-27 23:57:00+03	32700.00
9CC66B	2017-07-19 15:11:00+03	134400.00
9CC6B8	2017-07-01 16:02:00+03	75600.00
9CC6FB	2017-07-01 04:47:00+03	21400.00
9CC74F	2017-07-10 23:30:00+03	26800.00
9CC78E	2017-08-10 19:05:00+03	91100.00
9CC7B3	2017-07-03 05:37:00+03	199600.00
9CC7C8	2017-07-24 04:19:00+03	37900.00
9CC84A	2017-08-05 22:46:00+03	51900.00
9CC89A	2017-07-31 18:26:00+03	65900.00
9CC8A7	2017-08-15 09:30:00+03	48800.00
9CC8CE	2017-08-04 15:59:00+03	68800.00
9CC94B	2017-08-07 22:04:00+03	86600.00
9CC974	2017-07-05 23:14:00+03	46400.00
9CC97A	2017-07-24 06:11:00+03	43200.00
9CC97F	2017-07-28 16:38:00+03	40600.00
9CC993	2017-08-13 20:44:00+03	100600.00
9CC9A8	2017-06-29 10:13:00+03	38400.00
9CC9B3	2017-07-27 02:53:00+03	167400.00
9CCB3B	2017-08-03 05:07:00+03	50700.00
9CCB4A	2017-07-14 13:38:00+03	153900.00
9CCBD9	2017-07-03 04:08:00+03	23600.00
9CCC35	2017-07-09 13:08:00+03	46400.00
9CCC4A	2017-07-10 04:57:00+03	62200.00
9CCC6F	2017-07-08 15:22:00+03	51000.00
9CCC85	2017-07-25 02:11:00+03	28300.00
9CCCAB	2017-07-03 23:14:00+03	32200.00
9CCCC4	2017-07-24 20:33:00+03	128800.00
9CCCCB	2017-07-07 22:23:00+03	81300.00
9CCD0B	2017-08-14 04:49:00+03	89000.00
9CCD30	2017-07-01 05:36:00+03	12000.00
9CCD60	2017-07-07 07:34:00+03	23400.00
9CCDAC	2017-08-10 21:54:00+03	270800.00
9CCDBC	2017-08-09 20:57:00+03	57500.00
9CCDF6	2017-07-25 10:44:00+03	6000.00
9CCE70	2017-07-09 23:44:00+03	393800.00
9CCF1D	2017-08-14 18:44:00+03	89100.00
9CCF29	2017-07-07 14:16:00+03	92800.00
9CCF35	2017-07-12 18:55:00+03	200800.00
9CCFA5	2017-08-04 12:30:00+03	119500.00
9CCFEF	2017-07-11 05:27:00+03	18000.00
9CD003	2017-07-19 04:52:00+03	6000.00
9CD012	2017-07-04 04:49:00+03	48800.00
9CD05B	2017-08-02 18:48:00+03	67200.00
9CD064	2017-07-15 15:53:00+03	58400.00
9CD06E	2017-08-11 05:17:00+03	28000.00
9CD08E	2017-07-13 22:49:00+03	13300.00
9CD0AC	2017-08-11 11:51:00+03	99300.00
9CD0BE	2017-07-25 05:57:00+03	24400.00
9CD0BF	2017-08-08 23:48:00+03	33400.00
9CD0EC	2017-07-02 02:42:00+03	43500.00
9CD0ED	2017-08-02 02:47:00+03	68200.00
9CD10B	2017-08-13 20:16:00+03	19300.00
9CD12E	2017-07-11 15:12:00+03	28800.00
9CD18B	2017-07-16 03:11:00+03	133200.00
9CD18D	2017-07-08 10:30:00+03	31600.00
9CD1A9	2017-08-09 04:07:00+03	22600.00
9CD1FB	2017-08-05 12:48:00+03	25000.00
9CD210	2017-08-04 22:54:00+03	141400.00
9CD2AD	2017-07-22 15:10:00+03	93400.00
9CD2CC	2017-07-07 13:51:00+03	24800.00
9CD32E	2017-08-05 14:28:00+03	22000.00
9CD3D5	2017-07-25 00:06:00+03	64800.00
9CD412	2017-08-06 05:59:00+03	97900.00
9CD49C	2017-07-06 14:19:00+03	34800.00
9CD4DD	2017-08-03 06:35:00+03	39300.00
9CD4E5	2017-07-11 12:36:00+03	141700.00
9CD532	2017-08-03 06:34:00+03	37800.00
9CD565	2017-07-15 13:45:00+03	66600.00
9CD56F	2017-07-09 21:38:00+03	133200.00
9CD578	2017-06-27 02:00:00+03	89200.00
9CD5B3	2017-07-01 12:27:00+03	93900.00
9CD63A	2017-08-08 17:15:00+03	45200.00
9CD64E	2017-07-02 11:38:00+03	26000.00
9CD6CE	2017-08-06 02:36:00+03	47200.00
9CD6D8	2017-07-03 19:58:00+03	97100.00
9CD725	2017-07-06 11:42:00+03	25100.00
9CD785	2017-08-12 19:09:00+03	43600.00
9CD791	2017-07-20 18:50:00+03	23200.00
9CD798	2017-07-31 03:10:00+03	31600.00
9CD815	2017-07-06 05:06:00+03	28000.00
9CD831	2017-08-09 18:46:00+03	69500.00
9CD84D	2017-07-29 02:49:00+03	6000.00
9CD851	2017-07-01 17:59:00+03	205200.00
9CD876	2017-08-09 06:33:00+03	28800.00
9CD926	2017-08-15 15:47:00+03	14900.00
9CD938	2017-08-03 06:33:00+03	59800.00
9CD96B	2017-06-30 14:28:00+03	133100.00
9CD9A1	2017-08-13 05:56:00+03	28600.00
9CD9F4	2017-07-30 00:27:00+03	76600.00
9CDB2E	2017-07-22 14:44:00+03	103500.00
9CDB5C	2017-08-06 20:09:00+03	277900.00
9CDB92	2017-08-03 04:05:00+03	66800.00
9CDBB4	2017-07-19 10:16:00+03	75600.00
9CDBE1	2017-07-16 22:25:00+03	42000.00
9CDC06	2017-07-12 08:17:00+03	55000.00
9CDC12	2017-08-12 08:45:00+03	111600.00
9CDC2A	2017-08-09 11:48:00+03	21400.00
9CDC3C	2017-07-22 22:29:00+03	16400.00
9CDCCC	2017-07-29 10:01:00+03	88600.00
9CDCD0	2017-08-07 02:27:00+03	106100.00
9CDCD8	2017-08-05 08:23:00+03	13700.00
9CDD31	2017-07-25 18:41:00+03	78600.00
9CDD35	2017-07-14 17:46:00+03	96800.00
9CDD44	2017-07-19 15:43:00+03	8200.00
9CDE1B	2017-07-17 22:55:00+03	12600.00
9CDE9A	2017-07-22 01:38:00+03	263200.00
9CDECE	2017-08-04 08:15:00+03	189200.00
9CDF07	2017-07-16 18:26:00+03	67600.00
9CDF15	2017-07-04 02:30:00+03	28300.00
9CDF88	2017-06-30 09:00:00+03	6000.00
9CDFFF	2017-08-09 01:21:00+03	215600.00
9CE035	2017-07-31 14:41:00+03	30700.00
9CE03C	2017-07-09 22:33:00+03	40000.00
9CE07C	2017-08-06 03:44:00+03	56900.00
9CE0B3	2017-08-14 14:41:00+03	24000.00
9CE0DE	2017-07-29 10:00:00+03	118700.00
9CE11F	2017-07-08 11:36:00+03	28800.00
9CE177	2017-07-20 09:18:00+03	85000.00
9CE1BA	2017-07-10 18:56:00+03	15000.00
9CE248	2017-07-23 16:11:00+03	27400.00
9CE265	2017-07-04 06:08:00+03	151800.00
9CE2A6	2017-07-11 02:00:00+03	55800.00
9CE300	2017-08-11 11:57:00+03	6700.00
9CE311	2017-07-30 20:46:00+03	113600.00
9CE338	2017-08-09 23:31:00+03	290400.00
9CE3CB	2017-08-10 09:19:00+03	55800.00
9CE3CC	2017-08-03 00:25:00+03	51800.00
9CE3D8	2017-07-11 07:53:00+03	287300.00
9CE3F9	2017-08-10 19:22:00+03	86600.00
9CE482	2017-07-31 22:56:00+03	28800.00
9CE4B1	2017-08-14 04:47:00+03	273400.00
9CE4DB	2017-07-14 05:45:00+03	50400.00
9CE4E6	2017-07-19 01:30:00+03	103500.00
9CE57B	2017-08-07 10:13:00+03	177200.00
9CE5D1	2017-07-13 09:16:00+03	168000.00
9CE5D4	2017-07-27 23:16:00+03	65200.00
9CE5FD	2017-07-30 00:30:00+03	381500.00
9CE629	2017-07-06 21:36:00+03	21800.00
9CE688	2017-07-26 09:24:00+03	115100.00
9CE6ED	2017-07-01 17:43:00+03	16400.00
9CE702	2017-07-24 11:14:00+03	147700.00
9CE715	2017-07-18 09:15:00+03	55800.00
9CE737	2017-08-04 23:03:00+03	75500.00
9CE7C2	2017-08-08 08:39:00+03	11000.00
9CE7DC	2017-07-20 10:03:00+03	38800.00
9CE833	2017-08-12 14:12:00+03	30900.00
9CE89D	2017-07-29 17:02:00+03	16400.00
9CE8A1	2017-08-10 18:50:00+03	64400.00
9CE8DD	2017-07-23 04:56:00+03	84700.00
9CE911	2017-08-06 10:56:00+03	19600.00
9CE949	2017-07-03 19:42:00+03	56600.00
9CE974	2017-07-16 19:22:00+03	55800.00
9CE97F	2017-06-28 11:23:00+03	172300.00
9CE988	2017-07-10 00:58:00+03	13400.00
9CE9CE	2017-07-17 02:29:00+03	28800.00
9CE9E6	2017-07-09 01:39:00+03	58600.00
9CEA08	2017-08-06 21:33:00+03	26800.00
9CEA09	2017-07-09 17:56:00+03	36200.00
9CEB28	2017-07-30 19:19:00+03	147600.00
9CEB3E	2017-07-14 00:01:00+03	16800.00
9CEB48	2017-08-12 10:12:00+03	28800.00
9CEB4C	2017-07-16 06:24:00+03	26000.00
9CEB62	2017-07-12 06:55:00+03	47100.00
9CEB7A	2017-08-12 04:39:00+03	23900.00
9CEBBA	2017-08-12 08:45:00+03	90400.00
9CEBC6	2017-07-27 12:26:00+03	28800.00
9CEBE3	2017-07-25 14:55:00+03	92600.00
9CEBEB	2017-07-18 22:53:00+03	52000.00
9CEBF3	2017-07-31 16:25:00+03	65000.00
9CEBF5	2017-08-12 07:13:00+03	44800.00
9CEBFB	2017-06-28 02:05:00+03	177500.00
9CEC00	2017-07-07 16:31:00+03	202600.00
9CECBB	2017-07-30 04:34:00+03	53600.00
9CECBD	2017-07-29 13:46:00+03	31600.00
9CECC3	2017-08-07 03:07:00+03	55800.00
9CECEA	2017-08-02 21:35:00+03	170800.00
9CED01	2017-07-10 01:49:00+03	14000.00
9CED50	2017-08-09 20:07:00+03	57400.00
9CED96	2017-07-10 05:43:00+03	61900.00
9CEDC8	2017-07-17 03:46:00+03	170600.00
9CEDDC	2017-07-20 06:30:00+03	270000.00
9CEE28	2017-07-11 21:35:00+03	68400.00
9CEE5D	2017-07-29 12:34:00+03	70800.00
9CEED9	2017-07-23 14:38:00+03	57300.00
9CEF03	2017-07-20 23:52:00+03	83500.00
9CEF04	2017-07-19 08:32:00+03	61900.00
9CEF57	2017-07-22 06:15:00+03	29600.00
9CEF5F	2017-07-30 18:07:00+03	12600.00
9CF01B	2017-08-05 03:04:00+03	70800.00
9CF0B8	2017-07-23 23:10:00+03	197100.00
9CF1BF	2017-07-26 11:59:00+03	26000.00
9CF288	2017-07-10 12:46:00+03	87100.00
9CF2B1	2017-07-30 18:39:00+03	47200.00
9CF31A	2017-08-07 15:41:00+03	58600.00
9CF350	2017-07-06 22:25:00+03	265700.00
9CF367	2017-08-08 10:03:00+03	28800.00
9CF375	2017-07-07 14:24:00+03	135400.00
9CF377	2017-07-22 15:46:00+03	182300.00
9CF3BD	2017-07-30 11:49:00+03	29600.00
9CF4AE	2017-08-15 05:36:00+03	12600.00
9CF4F0	2017-07-31 02:44:00+03	26000.00
9CF558	2017-07-21 03:50:00+03	38400.00
9CF563	2017-07-07 14:22:00+03	100600.00
9CF59B	2017-07-16 14:18:00+03	31100.00
9CF5FA	2017-07-19 20:07:00+03	25200.00
9CF60D	2017-08-09 12:27:00+03	67000.00
9CF629	2017-08-08 00:22:00+03	12600.00
9CF695	2017-08-14 04:12:00+03	98200.00
9CF6AA	2017-07-03 07:49:00+03	199700.00
9CF6CC	2017-07-22 00:39:00+03	58600.00
9CF756	2017-08-06 14:57:00+03	34000.00
9CF764	2017-07-14 10:25:00+03	38800.00
9CF773	2017-07-16 04:35:00+03	90600.00
9CF7C4	2017-08-14 13:19:00+03	32800.00
9CF82F	2017-07-02 04:43:00+03	32800.00
9CF847	2017-07-19 22:19:00+03	142000.00
9CF84A	2017-07-08 14:04:00+03	36600.00
9CF872	2017-07-09 00:04:00+03	6300.00
9CF8BF	2017-07-31 19:31:00+03	64400.00
9CF95E	2017-07-19 12:49:00+03	112600.00
9CF964	2017-07-03 11:28:00+03	123000.00
9CF984	2017-07-12 07:42:00+03	98400.00
9CF9A2	2017-07-21 23:58:00+03	14800.00
9CF9A6	2017-07-11 22:19:00+03	295700.00
9CF9AF	2017-07-16 18:41:00+03	79900.00
9CF9B6	2017-07-07 17:22:00+03	174400.00
9CF9C1	2017-07-21 08:54:00+03	28000.00
9CF9C7	2017-07-20 07:25:00+03	25400.00
9CFA1E	2017-08-01 17:52:00+03	56600.00
9CFA30	2017-07-07 22:23:00+03	21800.00
9CFA42	2017-07-03 21:47:00+03	56000.00
9CFACF	2017-07-03 07:35:00+03	112000.00
9CFB8C	2017-07-31 03:27:00+03	136000.00
9CFBC1	2017-07-14 18:17:00+03	95200.00
9CFBCF	2017-07-23 17:27:00+03	38800.00
9CFBE6	2017-07-11 04:12:00+03	92800.00
9CFC2F	2017-07-03 13:38:00+03	46400.00
9CFD05	2017-07-21 15:50:00+03	155600.00
9CFD28	2017-07-24 18:35:00+03	99700.00
9CFD44	2017-07-05 02:07:00+03	26600.00
9CFDC1	2017-07-08 02:49:00+03	67200.00
9CFDDF	2017-08-14 03:48:00+03	68100.00
9CFDFE	2017-07-10 16:30:00+03	93700.00
9CFE59	2017-06-28 07:53:00+03	166000.00
9CFE90	2017-07-11 02:34:00+03	28800.00
9CFEBA	2017-08-05 07:07:00+03	10800.00
9CFEFC	2017-07-30 20:41:00+03	32700.00
9CFF2D	2017-08-11 03:51:00+03	66600.00
9CFF5A	2017-07-29 07:36:00+03	17200.00
9CFF6B	2017-08-12 02:38:00+03	115400.00
9CFF8D	2017-07-17 17:58:00+03	532600.00
9CFFC2	2017-07-04 01:01:00+03	82000.00
9D0015	2017-07-07 16:42:00+03	57000.00
9D004B	2017-07-07 20:20:00+03	108000.00
9D0074	2017-07-26 21:50:00+03	18000.00
9D00A8	2017-07-04 15:43:00+03	36200.00
9D00AF	2017-07-08 15:10:00+03	60400.00
9D00C6	2017-07-25 00:56:00+03	17600.00
9D0138	2017-07-01 06:44:00+03	26800.00
9D01CE	2017-07-04 00:28:00+03	325800.00
9D01E2	2017-07-27 16:04:00+03	55800.00
9D020C	2017-07-12 21:51:00+03	13800.00
9D0254	2017-08-13 21:37:00+03	79300.00
9D0283	2017-08-10 15:50:00+03	89700.00
9D02D4	2017-07-19 03:07:00+03	294400.00
9D0373	2017-06-30 08:48:00+03	23400.00
9D0385	2017-07-06 09:34:00+03	28600.00
9D0404	2017-08-15 07:55:00+03	45100.00
9D0427	2017-08-03 17:12:00+03	135400.00
9D042D	2017-07-31 23:38:00+03	16400.00
9D0435	2017-07-05 18:59:00+03	394000.00
9D0455	2017-07-13 22:28:00+03	38600.00
9D0481	2017-08-13 07:56:00+03	139200.00
9D0498	2017-08-05 00:16:00+03	48400.00
9D0530	2017-07-28 19:01:00+03	46300.00
9D054E	2017-07-15 11:56:00+03	91700.00
9D0583	2017-08-15 15:13:00+03	14700.00
9D05BA	2017-08-15 07:02:00+03	23200.00
9D0601	2017-08-01 13:14:00+03	46300.00
9D0635	2017-07-29 19:55:00+03	13300.00
9D064E	2017-07-18 02:14:00+03	93900.00
9D074E	2017-07-15 09:26:00+03	6800.00
9D0762	2017-06-30 18:07:00+03	34000.00
9D07FA	2017-07-30 16:52:00+03	86800.00
9D088B	2017-08-04 14:55:00+03	42000.00
9D0892	2017-07-23 21:40:00+03	65600.00
9D0960	2017-08-10 12:24:00+03	23600.00
9D0ACB	2017-08-04 13:34:00+03	65900.00
9D0AF5	2017-07-14 02:58:00+03	28000.00
9D0B74	2017-08-10 22:01:00+03	21400.00
9D0BA6	2017-07-14 21:46:00+03	47100.00
9D0BF4	2017-07-06 02:16:00+03	112700.00
9D0C20	2017-07-29 18:54:00+03	148200.00
9D0CC2	2017-07-25 11:16:00+03	75600.00
9D0CF6	2017-07-04 08:54:00+03	92900.00
9D0D14	2017-08-06 10:50:00+03	54800.00
9D0D35	2017-07-25 23:01:00+03	56600.00
9D0DA7	2017-07-17 10:36:00+03	94200.00
9D0DF2	2017-07-22 11:39:00+03	140000.00
9D0DF3	2017-08-06 23:21:00+03	76600.00
9D0DF4	2017-08-11 16:28:00+03	59800.00
9D0E53	2017-08-05 07:13:00+03	278500.00
9D0E68	2017-07-23 18:49:00+03	8200.00
9D0E7A	2017-07-16 14:29:00+03	46200.00
9D0E95	2017-07-17 05:47:00+03	139800.00
9D0EE7	2017-08-07 08:24:00+03	92800.00
9D0F00	2017-07-21 02:55:00+03	61200.00
9D0F2E	2017-08-07 16:01:00+03	167400.00
9D0F3E	2017-08-05 05:46:00+03	114800.00
9D0F53	2017-08-01 06:49:00+03	71200.00
9D0F80	2017-07-30 10:18:00+03	26600.00
9D0F8C	2017-07-14 00:42:00+03	23200.00
9D0F8F	2017-08-07 01:16:00+03	98200.00
9D0FAB	2017-07-04 23:48:00+03	139300.00
9D0FCF	2017-07-28 22:33:00+03	64700.00
9D0FDC	2017-07-30 16:52:00+03	27000.00
9D0FE8	2017-08-08 15:43:00+03	115800.00
9D1011	2017-07-09 17:54:00+03	70600.00
9D10E2	2017-07-22 02:04:00+03	300300.00
9D117D	2017-07-31 22:00:00+03	18600.00
9D11F8	2017-07-12 13:57:00+03	329100.00
9D120C	2017-07-29 01:03:00+03	29600.00
9D1212	2017-07-22 20:45:00+03	62600.00
9D122F	2017-08-05 23:49:00+03	6000.00
9D1278	2017-07-11 16:48:00+03	92400.00
9D129B	2017-08-09 00:51:00+03	31100.00
9D1306	2017-08-14 18:41:00+03	86400.00
9D1324	2017-07-09 15:15:00+03	8200.00
9D134F	2017-08-06 10:09:00+03	31100.00
9D135C	2017-07-21 08:04:00+03	203700.00
9D138E	2017-07-28 02:27:00+03	32700.00
9D13FE	2017-06-28 02:09:00+03	12000.00
9D1482	2017-07-25 07:02:00+03	65500.00
9D14CA	2017-07-28 08:56:00+03	55800.00
9D1565	2017-07-11 17:37:00+03	179400.00
9D157D	2017-08-01 11:22:00+03	46700.00
9D1597	2017-08-03 05:25:00+03	61700.00
9D15A7	2017-07-10 01:05:00+03	199700.00
9D15B4	2017-08-08 18:14:00+03	132800.00
9D160F	2017-07-24 13:34:00+03	72400.00
9D163B	2017-07-30 08:12:00+03	24600.00
9D164F	2017-08-14 07:47:00+03	39800.00
9D1699	2017-07-11 08:17:00+03	28800.00
9D16A9	2017-07-07 12:10:00+03	46200.00
9D16AE	2017-06-28 03:34:00+03	59900.00
9D16B9	2017-07-20 15:12:00+03	25600.00
9D16FA	2017-07-16 21:47:00+03	28800.00
9D1794	2017-07-19 08:26:00+03	20000.00
9D17C6	2017-08-09 17:30:00+03	6700.00
9D1812	2017-07-10 18:43:00+03	780900.00
9D1845	2017-07-06 00:08:00+03	8000.00
9D1866	2017-07-17 03:21:00+03	78900.00
9D1886	2017-08-06 14:12:00+03	13200.00
9D191F	2017-07-20 05:35:00+03	53800.00
9D1943	2017-07-16 23:03:00+03	57500.00
9D196E	2017-07-14 18:15:00+03	133100.00
9D19C1	2017-07-10 03:45:00+03	134200.00
9D19CE	2017-08-11 20:38:00+03	97700.00
9D19D4	2017-08-15 05:47:00+03	65400.00
9D19E8	2017-07-23 10:01:00+03	135400.00
9D1A0F	2017-08-08 04:04:00+03	85800.00
9D1A77	2017-07-10 12:40:00+03	77200.00
9D1ACA	2017-07-27 11:00:00+03	112000.00
9D1ACE	2017-08-05 20:42:00+03	56000.00
9D1B0C	2017-07-10 19:33:00+03	10100.00
9D1B91	2017-07-14 03:08:00+03	48400.00
9D1B98	2017-07-08 02:14:00+03	112100.00
9D1BCB	2017-07-04 18:07:00+03	42100.00
9D1BE4	2017-08-02 20:51:00+03	22000.00
9D1BEE	2017-07-22 18:12:00+03	28300.00
9D1C45	2017-08-10 02:27:00+03	79000.00
9D1C73	2017-08-03 12:13:00+03	10800.00
9D1C75	2017-08-12 15:39:00+03	48300.00
9D1C96	2017-07-19 11:07:00+03	44000.00
9D1D40	2017-06-28 19:13:00+03	26600.00
9D1DBC	2017-08-06 04:57:00+03	31400.00
9D1DF0	2017-07-16 06:03:00+03	37800.00
9D1E14	2017-07-14 12:15:00+03	188800.00
9D1E79	2017-08-04 03:26:00+03	65900.00
9D1E80	2017-06-30 21:49:00+03	6700.00
9D1EB5	2017-08-05 02:41:00+03	123000.00
9D2070	2017-07-05 10:59:00+03	16000.00
9D2123	2017-07-14 05:59:00+03	51900.00
9D212F	2017-07-18 12:12:00+03	152200.00
9D2130	2017-07-25 05:52:00+03	170700.00
9D2170	2017-08-12 19:27:00+03	135400.00
9D2178	2017-07-04 21:09:00+03	28000.00
9D2179	2017-07-14 05:19:00+03	56000.00
9D21D3	2017-08-01 08:15:00+03	26000.00
9D21D5	2017-07-25 14:38:00+03	75300.00
9D2229	2017-07-10 13:06:00+03	71400.00
9D2243	2017-08-02 16:17:00+03	89700.00
9D22F2	2017-07-21 15:14:00+03	60700.00
9D2345	2017-07-05 06:27:00+03	14800.00
9D234A	2017-07-05 13:28:00+03	155600.00
9D235E	2017-08-09 10:19:00+03	32900.00
9D2385	2017-07-07 22:29:00+03	114800.00
9D23C9	2017-08-05 01:01:00+03	36200.00
9D2453	2017-08-03 19:44:00+03	168700.00
9D24E3	2017-07-20 03:55:00+03	531400.00
9D256D	2017-08-13 16:11:00+03	38600.00
9D2580	2017-07-01 22:25:00+03	21500.00
9D25E8	2017-07-13 21:54:00+03	96300.00
9D2647	2017-07-11 22:46:00+03	133200.00
9D2648	2017-07-22 22:50:00+03	26800.00
9D2674	2017-08-02 22:36:00+03	6000.00
9D2689	2017-08-04 00:34:00+03	139800.00
9D269E	2017-07-06 13:54:00+03	14000.00
9D26AE	2017-07-24 08:46:00+03	14400.00
9D26D0	2017-08-06 06:47:00+03	111600.00
9D26E1	2017-07-29 00:10:00+03	33300.00
9D2746	2017-07-05 16:28:00+03	46700.00
9D277F	2017-08-02 13:12:00+03	46000.00
9D27D5	2017-07-22 21:46:00+03	54500.00
9D2806	2017-07-06 16:18:00+03	8200.00
9D289D	2017-07-04 03:15:00+03	53400.00
9D28B3	2017-06-27 18:59:00+03	134900.00
9D299F	2017-07-07 06:20:00+03	46300.00
9D29A8	2017-08-15 12:12:00+03	68800.00
9D29AE	2017-07-26 15:16:00+03	51600.00
9D29FB	2017-07-19 19:31:00+03	40400.00
9D29FF	2017-07-11 03:27:00+03	54000.00
9D2A23	2017-08-14 03:28:00+03	123000.00
9D2A35	2017-07-03 12:13:00+03	181200.00
9D2A4B	2017-07-17 15:08:00+03	38600.00
9D2A7B	2017-08-08 00:01:00+03	58800.00
9D2A93	2017-08-02 14:52:00+03	50400.00
9D2AC5	2017-07-21 07:24:00+03	284700.00
9D2B0E	2017-08-13 17:03:00+03	56700.00
9D2B33	2017-08-13 21:08:00+03	33100.00
9D2B45	2017-07-25 15:33:00+03	167400.00
9D2B4C	2017-07-10 21:10:00+03	68400.00
9D2B5F	2017-08-05 22:17:00+03	168000.00
9D2B81	2017-08-05 18:11:00+03	84000.00
9D2BE7	2017-08-10 07:04:00+03	643900.00
9D2C59	2017-07-02 09:25:00+03	112000.00
9D2C6E	2017-08-08 09:37:00+03	13400.00
9D2CA5	2017-07-06 10:31:00+03	6700.00
9D2CDB	2017-08-06 23:53:00+03	6000.00
9D2CE0	2017-07-20 19:19:00+03	177600.00
9D2CF5	2017-08-09 09:41:00+03	47000.00
9D2D08	2017-07-09 18:24:00+03	57800.00
9D2D21	2017-07-28 11:27:00+03	82200.00
9D2D39	2017-07-07 20:10:00+03	88500.00
9D2D62	2017-08-06 03:24:00+03	246000.00
9D2DE5	2017-08-04 04:56:00+03	15000.00
9D2DF0	2017-07-14 13:40:00+03	269500.00
9D2E6D	2017-08-14 02:06:00+03	72000.00
9D2E80	2017-07-28 00:23:00+03	205600.00
9D2E9B	2017-07-13 21:43:00+03	25600.00
9D2F00	2017-07-20 03:34:00+03	125400.00
9D2F0F	2017-07-11 18:54:00+03	81600.00
9D2F64	2017-07-19 09:22:00+03	93900.00
9D2FCF	2017-08-15 12:31:00+03	169300.00
9D3047	2017-07-29 15:12:00+03	307500.00
9D3077	2017-07-14 03:53:00+03	29600.00
9D30C3	2017-07-19 03:05:00+03	55800.00
9D30F7	2017-07-01 05:24:00+03	23100.00
9D3158	2017-07-17 19:07:00+03	147700.00
9D315E	2017-08-14 05:44:00+03	40700.00
9D3161	2017-07-05 08:15:00+03	84500.00
9D3163	2017-07-06 10:26:00+03	88900.00
9D31D9	2017-08-14 07:31:00+03	39600.00
9D321F	2017-07-25 21:44:00+03	131100.00
9D3236	2017-08-13 17:56:00+03	40000.00
9D3238	2017-07-23 14:14:00+03	11600.00
9D32DF	2017-07-07 23:42:00+03	135600.00
9D3303	2017-07-11 10:18:00+03	20400.00
9D330C	2017-07-19 01:31:00+03	266300.00
9D3345	2017-08-05 02:15:00+03	6000.00
9D3363	2017-07-22 02:27:00+03	214000.00
9D33C9	2017-08-05 07:00:00+03	43600.00
9D3458	2017-07-17 19:00:00+03	69500.00
9D348B	2017-08-08 08:40:00+03	26000.00
9D34B8	2017-08-04 18:56:00+03	39700.00
9D34D6	2017-06-29 07:07:00+03	16800.00
9D351F	2017-07-26 05:32:00+03	246000.00
9D352B	2017-08-04 21:56:00+03	65100.00
9D352D	2017-08-11 15:07:00+03	97100.00
9D353F	2017-07-03 02:04:00+03	108300.00
9D354C	2017-08-07 12:18:00+03	26000.00
9D358F	2017-07-26 16:10:00+03	132800.00
9D361D	2017-07-28 12:27:00+03	22600.00
9D3649	2017-07-23 13:38:00+03	91800.00
9D3691	2017-07-20 19:16:00+03	265600.00
9D372C	2017-07-15 23:24:00+03	24600.00
9D3785	2017-07-12 01:36:00+03	109600.00
9D37B0	2017-06-30 16:22:00+03	45500.00
9D37B7	2017-08-04 18:03:00+03	12600.00
9D381D	2017-08-11 07:24:00+03	25000.00
9D3868	2017-08-07 01:02:00+03	47100.00
9D38BC	2017-08-01 04:33:00+03	131100.00
9D397B	2017-07-13 07:33:00+03	198400.00
9D39BB	2017-08-08 02:33:00+03	14000.00
9D39C6	2017-08-13 13:10:00+03	55400.00
9D3A27	2017-07-13 04:23:00+03	23600.00
9D3A30	2017-07-27 11:19:00+03	29400.00
9D3A52	2017-08-11 09:47:00+03	32000.00
9D3A95	2017-07-26 10:50:00+03	19600.00
9D3B90	2017-07-26 14:26:00+03	179200.00
9D3B9B	2017-07-31 23:11:00+03	372500.00
9D3BEF	2017-07-16 05:46:00+03	13600.00
9D3C62	2017-08-13 10:52:00+03	13400.00
9D3CE2	2017-07-08 16:37:00+03	23400.00
9D3CF7	2017-07-12 16:28:00+03	93900.00
9D3D20	2017-08-09 13:59:00+03	23200.00
9D3D2D	2017-07-17 08:55:00+03	14400.00
9D3D7E	2017-08-03 17:32:00+03	64400.00
9D3E04	2017-07-23 04:06:00+03	86300.00
9D3E21	2017-08-03 11:00:00+03	111700.00
9D3E5D	2017-08-05 18:32:00+03	13200.00
9D3E8B	2017-07-05 19:22:00+03	32200.00
9D3EAC	2017-07-18 01:02:00+03	38600.00
9D3EBA	2017-08-06 15:38:00+03	38800.00
9D3F56	2017-07-09 07:33:00+03	199600.00
9D3F74	2017-08-05 04:49:00+03	15800.00
9D40D2	2017-07-10 12:26:00+03	31200.00
9D4129	2017-08-01 03:44:00+03	41000.00
9D412C	2017-07-05 20:28:00+03	161800.00
9D41AB	2017-06-30 18:25:00+03	13300.00
9D4242	2017-07-16 15:49:00+03	22000.00
9D428A	2017-07-12 17:05:00+03	85500.00
9D4294	2017-07-05 13:03:00+03	169900.00
9D42E0	2017-07-27 20:43:00+03	187800.00
9D42F5	2017-07-11 07:16:00+03	24400.00
9D42FA	2017-07-04 20:25:00+03	28000.00
9D4359	2017-07-12 09:14:00+03	68000.00
9D43E2	2017-07-27 17:46:00+03	62600.00
9D4491	2017-06-30 00:12:00+03	24400.00
9D4497	2017-07-07 02:23:00+03	50800.00
9D4546	2017-07-14 17:02:00+03	81700.00
9D4592	2017-08-15 06:20:00+03	43200.00
9D45BD	2017-08-08 08:13:00+03	58400.00
9D45D4	2017-08-06 01:22:00+03	147700.00
9D45EB	2017-07-09 18:59:00+03	106900.00
9D45FF	2017-07-28 02:31:00+03	155900.00
9D462E	2017-07-27 19:25:00+03	61900.00
9D4654	2017-07-03 18:42:00+03	66800.00
9D4661	2017-07-27 02:09:00+03	44700.00
9D46CD	2017-07-05 15:02:00+03	31200.00
9D46FC	2017-07-23 20:45:00+03	67700.00
9D476E	2017-08-02 15:21:00+03	51300.00
9D47B5	2017-07-29 23:35:00+03	26000.00
9D47F1	2017-07-24 14:48:00+03	136800.00
9D481A	2017-08-14 18:46:00+03	14400.00
9D4846	2017-07-06 03:42:00+03	65800.00
9D488E	2017-08-02 15:54:00+03	47800.00
9D48BE	2017-07-15 03:24:00+03	26000.00
9D4905	2017-07-21 21:29:00+03	30200.00
9D4988	2017-07-14 17:52:00+03	80200.00
9D4994	2017-08-06 05:38:00+03	59200.00
9D49DA	2017-08-15 13:58:00+03	127300.00
9D49E1	2017-08-01 05:36:00+03	44000.00
9D4A64	2017-07-02 12:50:00+03	16400.00
9D4ABD	2017-07-18 02:25:00+03	43000.00
9D4AC9	2017-07-28 00:37:00+03	34000.00
9D4C85	2017-07-07 14:57:00+03	55800.00
9D4C96	2017-07-04 08:47:00+03	38400.00
9D4D02	2017-07-08 02:45:00+03	40800.00
9D4D56	2017-08-09 01:30:00+03	23600.00
9D4D92	2017-07-27 07:14:00+03	145800.00
9D4E32	2017-07-16 08:22:00+03	21800.00
9D4E6E	2017-07-09 18:23:00+03	246000.00
9D4F2B	2017-07-12 19:43:00+03	49100.00
9D4F34	2017-07-02 23:07:00+03	129200.00
9D4F3F	2017-07-08 02:08:00+03	81900.00
9D4FD0	2017-07-28 13:59:00+03	34600.00
9D5012	2017-07-22 10:10:00+03	32800.00
9D506C	2017-08-10 15:45:00+03	60400.00
9D50E0	2017-08-08 14:09:00+03	24700.00
9D50E6	2017-07-19 15:41:00+03	68400.00
9D50FA	2017-07-08 08:09:00+03	53200.00
9D513F	2017-08-01 22:06:00+03	28700.00
9D521B	2017-07-05 13:41:00+03	24600.00
9D521C	2017-07-21 22:59:00+03	10100.00
9D524D	2017-07-24 13:39:00+03	46200.00
9D531B	2017-08-11 07:04:00+03	123000.00
9D5335	2017-07-20 17:36:00+03	36200.00
9D533E	2017-08-06 09:27:00+03	129200.00
9D5342	2017-08-14 17:10:00+03	10600.00
9D534E	2017-07-28 01:57:00+03	36200.00
9D538B	2017-07-28 01:01:00+03	62800.00
9D539F	2017-07-05 08:54:00+03	59800.00
9D53D8	2017-07-28 00:22:00+03	56000.00
9D53F8	2017-08-15 11:20:00+03	37600.00
9D5408	2017-07-26 18:37:00+03	24400.00
9D541B	2017-07-05 16:59:00+03	23200.00
9D5420	2017-08-01 22:34:00+03	13400.00
9D54FD	2017-07-25 06:51:00+03	29600.00
9D5511	2017-07-19 22:46:00+03	12600.00
9D551D	2017-07-21 18:31:00+03	144100.00
9D553E	2017-07-09 09:17:00+03	438300.00
9D55E5	2017-08-10 22:16:00+03	23400.00
9D562A	2017-08-08 10:30:00+03	56000.00
9D56F2	2017-07-27 08:11:00+03	6300.00
9D5775	2017-07-31 23:28:00+03	21800.00
9D578A	2017-07-14 10:02:00+03	28600.00
9D57F2	2017-07-19 21:35:00+03	111600.00
9D5870	2017-08-12 11:52:00+03	39200.00
9D58E7	2017-08-11 19:02:00+03	17200.00
9D5922	2017-07-24 23:29:00+03	369000.00
9D5997	2017-08-04 19:44:00+03	61500.00
9D59A9	2017-07-06 00:01:00+03	44600.00
9D59F7	2017-08-08 11:29:00+03	179500.00
9D5A2E	2017-07-30 19:05:00+03	24300.00
9D5A8D	2017-08-05 06:10:00+03	68800.00
9D5B1C	2017-07-04 10:05:00+03	12600.00
9D5B1D	2017-07-31 15:43:00+03	133800.00
9D5B22	2017-07-22 15:16:00+03	75300.00
9D5B30	2017-08-12 07:08:00+03	80000.00
9D5B34	2017-07-11 08:46:00+03	79000.00
9D5B95	2017-08-12 00:41:00+03	26000.00
9D5BFA	2017-07-03 09:16:00+03	229900.00
9D5C72	2017-07-22 07:27:00+03	148200.00
9D5CB5	2017-06-26 23:31:00+03	37600.00
9D5CE4	2017-07-27 06:59:00+03	50600.00
9D5CEE	2017-08-12 14:35:00+03	60700.00
9D5D08	2017-07-10 08:44:00+03	18000.00
9D5D17	2017-07-06 00:56:00+03	43500.00
9D5D79	2017-07-29 06:15:00+03	59300.00
9D5D8E	2017-08-01 02:48:00+03	99200.00
9D5D96	2017-08-11 14:01:00+03	7800.00
9D5DD9	2017-07-16 07:24:00+03	66900.00
9D5EDC	2017-07-12 17:51:00+03	58800.00
9D5EF2	2017-08-11 12:52:00+03	28800.00
9D5F0A	2017-07-26 16:35:00+03	13800.00
9D5F30	2017-08-15 17:09:00+03	3400.00
9D5F4B	2017-07-23 01:08:00+03	107000.00
9D5F70	2017-07-12 04:57:00+03	53400.00
9D60A2	2017-08-04 04:04:00+03	105000.00
9D60BC	2017-08-10 16:08:00+03	25600.00
9D613D	2017-07-02 20:43:00+03	246000.00
9D6154	2017-07-02 12:55:00+03	79800.00
9D6175	2017-07-27 11:49:00+03	67400.00
9D617C	2017-07-16 20:11:00+03	55800.00
9D61D6	2017-06-27 16:38:00+03	199700.00
9D61F9	2017-07-22 01:12:00+03	23200.00
9D6208	2017-07-15 00:12:00+03	66600.00
9D62F8	2017-08-11 14:44:00+03	270700.00
9D62F9	2017-07-20 19:32:00+03	60400.00
9D630A	2017-06-30 14:42:00+03	25900.00
9D638A	2017-07-21 13:26:00+03	112000.00
9D63B0	2017-08-08 04:13:00+03	56600.00
9D63C7	2017-08-07 23:16:00+03	28000.00
9D63CB	2017-08-14 22:43:00+03	37700.00
9D645F	2017-08-05 10:56:00+03	129700.00
9D6467	2017-07-30 22:14:00+03	25400.00
9D6489	2017-07-12 15:48:00+03	80200.00
9D648D	2017-06-27 14:57:00+03	12000.00
9D649A	2017-07-09 20:58:00+03	84100.00
9D64AA	2017-07-12 13:46:00+03	37100.00
9D64D7	2017-08-08 00:56:00+03	93800.00
9D64E3	2017-07-28 11:03:00+03	129200.00
9D650F	2017-08-05 02:31:00+03	59900.00
9D6541	2017-07-01 08:59:00+03	50600.00
9D6592	2017-08-07 23:34:00+03	73600.00
9D65CA	2017-07-19 11:25:00+03	81300.00
9D65E2	2017-07-22 21:49:00+03	55800.00
9D663F	2017-07-21 13:46:00+03	155200.00
9D6645	2017-07-07 12:56:00+03	31600.00
9D6656	2017-08-03 09:51:00+03	23600.00
9D6670	2017-07-16 00:32:00+03	57500.00
9D66B1	2017-07-29 12:16:00+03	41800.00
9D66E3	2017-08-04 21:27:00+03	12000.00
9D66FC	2017-08-08 14:21:00+03	69600.00
9D6794	2017-08-05 02:59:00+03	67500.00
9D67B1	2017-07-29 13:14:00+03	238200.00
9D6891	2017-07-02 07:42:00+03	90400.00
9D68B7	2017-07-21 01:03:00+03	56600.00
9D68EF	2017-07-27 19:41:00+03	24700.00
9D6901	2017-06-29 07:48:00+03	42800.00
9D6915	2017-07-31 18:28:00+03	46000.00
9D691E	2017-07-06 15:16:00+03	31400.00
9D699B	2017-07-25 23:42:00+03	55800.00
9D69B8	2017-07-07 08:30:00+03	187600.00
9D69F1	2017-07-22 19:12:00+03	13600.00
9D69FA	2017-07-27 08:41:00+03	73500.00
9D6A53	2017-08-13 05:42:00+03	26800.00
9D6AAD	2017-07-03 10:47:00+03	48800.00
9D6B10	2017-07-08 06:01:00+03	179500.00
9D6B7A	2017-07-05 13:55:00+03	123900.00
9D6C5C	2017-08-15 10:10:00+03	49500.00
9D6CB8	2017-07-22 09:54:00+03	65500.00
9D6CC7	2017-08-13 10:13:00+03	56900.00
9D6CF2	2017-07-15 04:10:00+03	90400.00
9D6D5E	2017-07-06 18:15:00+03	22000.00
9D6D68	2017-08-14 07:57:00+03	106700.00
9D6DAC	2017-07-26 15:24:00+03	124200.00
9D6DB9	2017-08-08 17:41:00+03	56100.00
9D6DE6	2017-07-05 16:17:00+03	28800.00
9D6E03	2017-08-13 04:48:00+03	29200.00
9D6E4D	2017-07-09 17:17:00+03	49000.00
9D6E57	2017-07-24 13:57:00+03	46800.00
9D6E69	2017-07-14 22:19:00+03	128800.00
9D6ECE	2017-07-23 01:34:00+03	26800.00
9D6EF5	2017-08-08 16:00:00+03	276200.00
9D6FF3	2017-08-04 13:28:00+03	23200.00
9D7143	2017-08-08 10:26:00+03	40600.00
9D7184	2017-08-10 03:22:00+03	101200.00
9D7191	2017-08-14 06:46:00+03	64200.00
9D719D	2017-07-02 03:26:00+03	35700.00
9D71F1	2017-08-15 12:03:00+03	11100.00
9D7221	2017-07-07 20:00:00+03	10600.00
9D7235	2017-07-07 05:11:00+03	55800.00
9D729C	2017-08-15 06:19:00+03	27200.00
9D72AE	2017-08-01 18:55:00+03	8600.00
9D72D8	2017-07-18 06:09:00+03	12600.00
9D733C	2017-07-01 00:48:00+03	67600.00
9D7352	2017-07-22 17:26:00+03	89400.00
9D7383	2017-07-29 09:00:00+03	111600.00
9D7385	2017-08-02 14:32:00+03	47100.00
9D73C1	2017-08-09 17:07:00+03	205700.00
9D7417	2017-08-14 23:42:00+03	74100.00
9D7420	2017-08-04 18:31:00+03	27800.00
9D7472	2017-08-10 18:52:00+03	120800.00
9D74E3	2017-07-29 04:31:00+03	103400.00
9D7504	2017-08-01 06:32:00+03	78100.00
9D7514	2017-06-29 05:20:00+03	66600.00
9D7524	2017-07-06 10:05:00+03	37900.00
9D75A4	2017-07-18 13:00:00+03	187600.00
9D75A8	2017-07-08 22:58:00+03	60400.00
9D75B7	2017-07-29 15:25:00+03	21600.00
9D75DB	2017-07-09 03:43:00+03	69500.00
9D75F2	2017-07-16 15:49:00+03	80900.00
9D7644	2017-08-05 11:43:00+03	146900.00
9D76D7	2017-08-10 02:25:00+03	139100.00
9D76DE	2017-07-25 21:04:00+03	112600.00
9D76E4	2017-07-12 15:05:00+03	52100.00
9D76FC	2017-08-01 05:00:00+03	75300.00
9D7708	2017-08-09 17:18:00+03	23200.00
9D7754	2017-07-24 19:49:00+03	35200.00
9D7760	2017-07-24 05:43:00+03	23600.00
9D7774	2017-07-30 01:45:00+03	147400.00
9D77C8	2017-07-28 19:30:00+03	103100.00
9D7810	2017-07-12 13:37:00+03	60400.00
9D7825	2017-08-08 00:59:00+03	26000.00
9D7936	2017-07-06 15:45:00+03	201600.00
9D7A39	2017-07-08 21:53:00+03	399600.00
9D7A62	2017-07-19 06:29:00+03	46400.00
9D7A9C	2017-08-12 03:31:00+03	54100.00
9D7A9F	2017-07-15 21:24:00+03	258000.00
9D7B0B	2017-07-11 15:03:00+03	31600.00
9D7B12	2017-07-15 17:48:00+03	27200.00
9D7B37	2017-07-04 04:56:00+03	75300.00
9D7B52	2017-07-09 07:05:00+03	246000.00
9D7B70	2017-07-11 17:04:00+03	23200.00
9D7B83	2017-07-07 18:12:00+03	39600.00
9D7B99	2017-07-04 18:11:00+03	14400.00
9D7B9B	2017-07-16 08:19:00+03	12400.00
9D7C0D	2017-08-02 00:00:00+03	56000.00
9D7C28	2017-07-18 14:07:00+03	88800.00
9D7C39	2017-08-11 11:59:00+03	185000.00
9D7C48	2017-07-05 01:48:00+03	40800.00
9D7C62	2017-07-15 14:33:00+03	91800.00
9D7C72	2017-08-11 09:11:00+03	43500.00
9D7CAD	2017-08-11 06:29:00+03	27800.00
9D7CE5	2017-07-23 13:35:00+03	39100.00
9D7D38	2017-08-05 06:06:00+03	46400.00
9D7D3B	2017-08-09 02:38:00+03	36800.00
9D7D75	2017-07-20 23:55:00+03	62600.00
9D7DA8	2017-07-20 08:14:00+03	9300.00
9D7DDD	2017-07-24 14:35:00+03	37600.00
9D7E25	2017-08-13 13:03:00+03	97600.00
9D7E3D	2017-07-28 13:01:00+03	67000.00
9D7EFB	2017-07-07 11:38:00+03	111600.00
9D7F21	2017-08-15 15:30:00+03	136200.00
9D7F39	2017-07-21 04:11:00+03	178800.00
9D7F57	2017-08-11 03:27:00+03	73300.00
9D8028	2017-07-20 11:16:00+03	85000.00
9D8060	2017-07-14 10:12:00+03	42800.00
9D80F2	2017-07-16 08:58:00+03	6600.00
9D80F4	2017-07-26 18:05:00+03	32100.00
9D8100	2017-07-17 06:04:00+03	78500.00
9D8174	2017-08-12 03:47:00+03	103500.00
9D8183	2017-08-13 05:19:00+03	45400.00
9D819F	2017-07-22 11:26:00+03	68800.00
9D81D5	2017-07-17 08:36:00+03	15000.00
9D82EB	2017-07-26 14:37:00+03	44000.00
9D82EC	2017-08-05 13:12:00+03	33100.00
9D8337	2017-07-10 11:22:00+03	99200.00
9D8344	2017-08-13 03:01:00+03	28000.00
9D8354	2017-07-25 23:31:00+03	28800.00
9D8379	2017-08-13 21:59:00+03	40000.00
9D8391	2017-08-15 16:22:00+03	398500.00
9D843E	2017-07-26 16:53:00+03	84500.00
9D846A	2017-07-30 20:26:00+03	19600.00
9D84AA	2017-08-11 10:32:00+03	36500.00
9D84AD	2017-07-26 20:51:00+03	13200.00
9D84AF	2017-07-16 23:49:00+03	56600.00
9D8563	2017-07-31 06:18:00+03	16400.00
9D85A1	2017-07-26 04:56:00+03	13400.00
9D8626	2017-08-13 02:53:00+03	43600.00
9D86B3	2017-07-27 17:13:00+03	12000.00
9D86DB	2017-07-15 01:20:00+03	34000.00
9D8718	2017-06-30 05:40:00+03	202100.00
9D874C	2017-08-14 14:55:00+03	46000.00
9D874E	2017-08-11 06:38:00+03	29800.00
9D878A	2017-08-05 05:41:00+03	55800.00
9D87B6	2017-07-30 14:52:00+03	89600.00
9D87FA	2017-07-31 05:36:00+03	73500.00
9D87FC	2017-08-05 05:51:00+03	23600.00
9D8869	2017-08-08 17:24:00+03	18100.00
9D8971	2017-07-14 16:29:00+03	50600.00
9D89EA	2017-07-29 03:32:00+03	70700.00
9D8A05	2017-07-18 18:11:00+03	180000.00
9D8A5B	2017-07-07 02:14:00+03	68800.00
9D8AD2	2017-07-31 01:59:00+03	28000.00
9D8B32	2017-08-02 23:33:00+03	15400.00
9D8B5C	2017-08-03 01:30:00+03	12600.00
9D8B81	2017-07-14 20:47:00+03	40100.00
9D8BB9	2017-07-31 07:14:00+03	135400.00
9D8BCC	2017-07-03 23:31:00+03	14400.00
9D8BFE	2017-07-06 15:45:00+03	124200.00
9D8C89	2017-07-29 23:08:00+03	44000.00
9D8CC8	2017-06-29 05:20:00+03	23600.00
9D8CFF	2017-07-04 13:57:00+03	173500.00
9D8D23	2017-07-06 09:47:00+03	139000.00
9D8D5D	2017-07-31 13:01:00+03	189800.00
9D8D77	2017-07-03 02:31:00+03	135200.00
9D8DD6	2017-07-09 05:55:00+03	4000.00
9D8DDC	2017-07-12 01:45:00+03	46000.00
9D8E61	2017-07-11 08:58:00+03	37200.00
9D8E63	2017-08-01 03:32:00+03	16400.00
9D8ED1	2017-07-07 22:17:00+03	133100.00
9D8EEF	2017-08-14 01:27:00+03	55400.00
9D8EFD	2017-08-11 02:57:00+03	369000.00
9D8F5E	2017-08-15 06:39:00+03	26600.00
9D8FDF	2017-07-29 18:40:00+03	65400.00
9D905C	2017-07-12 11:19:00+03	47100.00
9D9098	2017-08-08 20:22:00+03	86900.00
9D90B1	2017-08-06 10:52:00+03	246000.00
9D9105	2017-07-10 07:11:00+03	40000.00
9D9237	2017-07-18 12:49:00+03	41200.00
9D928A	2017-07-21 15:26:00+03	28000.00
9D928D	2017-08-09 05:36:00+03	88800.00
9D92C2	2017-07-30 00:28:00+03	56600.00
9D9355	2017-08-01 04:33:00+03	136500.00
9D9367	2017-07-28 13:28:00+03	34000.00
9D93CF	2017-07-24 03:43:00+03	146700.00
9D9419	2017-08-10 09:35:00+03	158500.00
9D9421	2017-07-03 21:01:00+03	40800.00
9D9435	2017-07-02 00:34:00+03	75600.00
9D947C	2017-08-08 15:09:00+03	68300.00
9D94AD	2017-07-27 15:31:00+03	58000.00
9D94C7	2017-08-11 01:37:00+03	26200.00
9D951B	2017-08-11 21:03:00+03	28800.00
9D9551	2017-07-01 04:42:00+03	58200.00
9D9571	2017-08-03 22:09:00+03	24400.00
9D95A4	2017-07-04 21:34:00+03	32800.00
9D95BD	2017-07-21 03:33:00+03	270000.00
9D95DC	2017-07-20 20:03:00+03	19600.00
9D9631	2017-07-22 14:43:00+03	43100.00
9D96C2	2017-08-14 01:55:00+03	15700.00
9D96F7	2017-07-07 06:37:00+03	91100.00
9D9716	2017-07-10 06:56:00+03	14400.00
9D9720	2017-07-09 14:16:00+03	68100.00
9D9786	2017-07-30 01:47:00+03	202800.00
9D97C9	2017-07-04 15:34:00+03	16400.00
9D97F2	2017-08-01 00:39:00+03	81900.00
9D9835	2017-07-18 21:10:00+03	285000.00
9D98F9	2017-07-10 04:25:00+03	246000.00
9D997D	2017-08-05 07:14:00+03	20600.00
9D9986	2017-07-02 08:09:00+03	46000.00
9D99D2	2017-07-07 17:56:00+03	137600.00
9D99DC	2017-07-20 02:31:00+03	67000.00
9D99EB	2017-08-10 05:12:00+03	31100.00
9D99EF	2017-07-13 17:43:00+03	121400.00
9D9A28	2017-07-08 15:04:00+03	96200.00
9D9A75	2017-07-22 16:11:00+03	263200.00
9D9A7C	2017-07-11 08:04:00+03	289800.00
9D9A99	2017-07-29 21:35:00+03	75600.00
9D9ABE	2017-07-18 08:49:00+03	46400.00
9D9B0C	2017-07-08 23:44:00+03	99000.00
9D9B6C	2017-08-05 16:42:00+03	6600.00
9D9B9F	2017-07-03 07:04:00+03	101200.00
9D9BED	2017-07-06 00:26:00+03	64200.00
9D9C72	2017-07-04 16:26:00+03	65000.00
9D9C83	2017-08-07 07:20:00+03	123000.00
9D9CD5	2017-08-13 01:26:00+03	100600.00
9D9CF4	2017-07-28 14:41:00+03	66100.00
9D9D35	2017-07-15 22:17:00+03	26000.00
9D9D3A	2017-07-04 10:11:00+03	56000.00
9D9D3D	2017-08-07 23:05:00+03	83000.00
9D9D3F	2017-07-06 17:21:00+03	28000.00
9D9DB6	2017-07-13 09:25:00+03	125300.00
9D9DCF	2017-07-09 22:12:00+03	94000.00
9D9E09	2017-08-11 04:23:00+03	248300.00
9D9E4A	2017-07-07 09:31:00+03	102100.00
9D9E4D	2017-07-05 05:45:00+03	112000.00
9D9E6E	2017-08-07 08:53:00+03	37800.00
9D9E71	2017-06-27 09:42:00+03	40200.00
9D9F04	2017-07-06 11:28:00+03	48300.00
9D9F0A	2017-07-10 15:15:00+03	42800.00
9D9F0C	2017-07-08 01:55:00+03	35600.00
9D9F1F	2017-07-30 10:45:00+03	43200.00
9D9F58	2017-08-07 10:33:00+03	405900.00
9D9F63	2017-07-12 22:17:00+03	104600.00
9D9F96	2017-07-28 14:04:00+03	25100.00
9D9FB8	2017-07-14 01:03:00+03	96800.00
9D9FC9	2017-07-22 18:44:00+03	46200.00
9D9FD7	2017-07-20 04:46:00+03	94700.00
9D9FDA	2017-07-21 18:59:00+03	28200.00
9DA057	2017-07-05 17:44:00+03	50000.00
9DA05C	2017-07-21 10:15:00+03	30900.00
9DA07D	2017-08-08 12:23:00+03	35200.00
9DA0B1	2017-07-30 16:20:00+03	116000.00
9DA0B5	2017-08-12 14:08:00+03	129600.00
9DA11C	2017-07-27 14:52:00+03	30200.00
9DA13F	2017-07-11 15:13:00+03	92900.00
9DA1CA	2017-07-09 04:38:00+03	105800.00
9DA1E0	2017-07-01 15:41:00+03	21800.00
9DA257	2017-07-06 02:51:00+03	86600.00
9DA486	2017-08-03 15:02:00+03	61800.00
9DA489	2017-07-11 07:59:00+03	85200.00
9DA540	2017-07-13 04:23:00+03	66600.00
9DA545	2017-07-05 05:09:00+03	73600.00
9DA59D	2017-07-24 03:11:00+03	56000.00
9DA5C7	2017-08-07 01:27:00+03	103200.00
9DA5D6	2017-08-05 14:02:00+03	66000.00
9DA5FA	2017-07-30 01:10:00+03	38600.00
9DA609	2017-07-13 03:23:00+03	25200.00
9DA67D	2017-07-01 10:35:00+03	20500.00
9DA6CB	2017-07-13 22:21:00+03	54400.00
9DA6F1	2017-07-04 02:34:00+03	7400.00
9DA77C	2017-07-12 07:03:00+03	117000.00
9DA797	2017-08-14 17:02:00+03	105400.00
9DA7AA	2017-08-12 04:38:00+03	113600.00
9DA7F8	2017-07-16 20:54:00+03	62700.00
9DA85F	2017-07-30 21:08:00+03	139400.00
9DA89D	2017-07-15 11:01:00+03	83000.00
9DA8DE	2017-07-08 03:56:00+03	50600.00
9DA923	2017-07-18 07:55:00+03	39200.00
9DA97E	2017-07-05 21:37:00+03	6000.00
9DA99F	2017-08-12 11:00:00+03	22000.00
9DA9BD	2017-07-24 17:55:00+03	74400.00
9DA9C6	2017-07-10 00:33:00+03	70700.00
9DA9E6	2017-06-30 19:39:00+03	149600.00
9DA9EC	2017-08-03 03:21:00+03	29600.00
9DAA27	2017-07-30 04:15:00+03	28000.00
9DAA5D	2017-07-23 18:16:00+03	92700.00
9DAA8D	2017-08-01 16:30:00+03	55700.00
9DAAF7	2017-07-03 15:17:00+03	31300.00
9DAB04	2017-07-25 03:38:00+03	88200.00
9DAB6A	2017-08-07 06:17:00+03	23200.00
9DAB97	2017-07-17 10:54:00+03	65200.00
9DABAD	2017-06-28 14:41:00+03	48100.00
9DABC2	2017-07-29 10:47:00+03	86400.00
9DABD3	2017-08-07 22:18:00+03	55800.00
9DAC3B	2017-08-10 17:50:00+03	8200.00
9DACE0	2017-07-06 09:03:00+03	46000.00
9DAD0B	2017-07-25 09:55:00+03	183300.00
9DAD19	2017-07-08 20:46:00+03	6000.00
9DAD26	2017-07-15 21:57:00+03	72200.00
9DAD2F	2017-07-12 07:50:00+03	62600.00
9DAD9F	2017-07-30 23:42:00+03	55800.00
9DADEF	2017-08-14 11:52:00+03	15000.00
9DADF8	2017-07-25 14:55:00+03	40800.00
9DAE15	2017-07-18 14:06:00+03	23600.00
9DAEC5	2017-08-10 15:35:00+03	23200.00
9DAECE	2017-07-22 19:24:00+03	85500.00
9DAF38	2017-08-09 08:34:00+03	80300.00
9DAF52	2017-07-06 07:43:00+03	28000.00
9DAF6C	2017-07-19 18:10:00+03	68400.00
9DAFE4	2017-08-14 18:32:00+03	36400.00
9DAFE7	2017-07-12 12:05:00+03	56000.00
9DB0AF	2017-08-06 18:17:00+03	116400.00
9DB0F5	2017-07-07 20:19:00+03	14000.00
9DB183	2017-07-21 13:13:00+03	56000.00
9DB22F	2017-08-08 19:46:00+03	101500.00
9DB24F	2017-07-27 21:26:00+03	7400.00
9DB258	2017-07-13 21:50:00+03	36000.00
9DB264	2017-08-05 10:53:00+03	32400.00
9DB2E4	2017-08-05 04:50:00+03	117600.00
9DB3BC	2017-07-16 14:55:00+03	8200.00
9DB3C8	2017-07-18 02:41:00+03	73900.00
9DB3CF	2017-08-04 02:28:00+03	167200.00
9DB3FD	2017-07-19 01:08:00+03	95600.00
9DB43A	2017-07-08 06:16:00+03	27900.00
9DB47E	2017-07-30 07:55:00+03	126300.00
9DB48A	2017-06-30 11:45:00+03	108700.00
9DB4BE	2017-08-01 19:41:00+03	91800.00
9DB4C6	2017-07-03 06:21:00+03	20700.00
9DB507	2017-08-13 09:21:00+03	91500.00
9DB572	2017-07-21 13:42:00+03	25000.00
9DB5C8	2017-08-10 12:04:00+03	111600.00
9DB630	2017-07-14 12:07:00+03	50600.00
9DB687	2017-08-12 13:54:00+03	111600.00
9DB68B	2017-08-15 11:19:00+03	116400.00
9DB696	2017-08-03 05:37:00+03	32800.00
9DB6A1	2017-07-11 21:48:00+03	23200.00
9DB6C0	2017-08-06 20:31:00+03	47200.00
9DB6D3	2017-08-11 22:29:00+03	32700.00
9DB6E6	2017-06-30 14:14:00+03	60400.00
9DB6F5	2017-07-04 12:36:00+03	6700.00
9DB736	2017-07-06 09:50:00+03	32300.00
9DB739	2017-08-03 08:21:00+03	12400.00
9DB73E	2017-08-15 13:53:00+03	42000.00
9DB77C	2017-07-13 23:53:00+03	13600.00
9DB78B	2017-08-15 15:16:00+03	59200.00
9DB7CD	2017-07-02 03:25:00+03	63200.00
9DB7FA	2017-07-29 01:49:00+03	185000.00
9DB83C	2017-07-18 04:52:00+03	119600.00
9DB853	2017-08-12 11:21:00+03	24600.00
9DB8DF	2017-07-11 11:22:00+03	130900.00
9DB919	2017-07-03 04:40:00+03	137600.00
9DB91E	2017-08-14 05:33:00+03	65900.00
9DB955	2017-08-12 13:08:00+03	48800.00
9DB9C5	2017-06-29 10:34:00+03	69100.00
9DBA66	2017-07-10 13:40:00+03	46400.00
9DBA69	2017-07-12 15:49:00+03	6000.00
9DBAF2	2017-07-26 14:10:00+03	6700.00
9DBB4B	2017-07-23 22:04:00+03	115600.00
9DBB51	2017-07-24 12:22:00+03	13800.00
9DBB92	2017-07-14 00:34:00+03	46900.00
9DBBFF	2017-07-13 14:05:00+03	152200.00
9DBC1A	2017-07-03 06:19:00+03	46400.00
9DBC25	2017-07-13 09:15:00+03	26200.00
9DBC45	2017-08-01 16:54:00+03	50600.00
9DBC49	2017-07-06 05:40:00+03	65600.00
9DBC74	2017-07-10 07:07:00+03	12000.00
9DBD8C	2017-07-19 22:11:00+03	67600.00
9DBE51	2017-07-18 15:17:00+03	73300.00
9DBE7B	2017-07-22 15:43:00+03	77200.00
9DBEAE	2017-08-14 04:41:00+03	7400.00
9DBEC6	2017-07-01 18:31:00+03	193700.00
9DBEF2	2017-08-03 22:46:00+03	400000.00
9DBF5B	2017-07-26 05:43:00+03	36200.00
9DBF6D	2017-08-05 11:19:00+03	101900.00
9DBFA2	2017-07-16 19:39:00+03	17800.00
9DBFB3	2017-07-07 11:46:00+03	56000.00
9DBFB9	2017-07-16 12:21:00+03	48800.00
9DC00E	2017-07-10 07:59:00+03	49200.00
9DC010	2017-08-01 07:45:00+03	20400.00
9DC064	2017-07-13 16:29:00+03	49800.00
9DC073	2017-07-14 03:00:00+03	125200.00
9DC07F	2017-08-02 01:15:00+03	56600.00
9DC0FD	2017-07-28 22:05:00+03	86500.00
9DC1AC	2017-07-19 22:44:00+03	43000.00
9DC1CF	2017-08-08 19:58:00+03	31600.00
9DC269	2017-07-26 16:48:00+03	29400.00
9DC2AF	2017-08-09 20:55:00+03	40800.00
9DC399	2017-07-06 09:59:00+03	516800.00
9DC3C9	2017-08-09 22:51:00+03	47400.00
9DC3D0	2017-08-10 20:00:00+03	16400.00
9DC4C8	2017-07-08 13:05:00+03	53500.00
9DC524	2017-08-04 18:38:00+03	17600.00
9DC544	2017-07-06 00:57:00+03	95700.00
9DC58D	2017-08-04 11:32:00+03	51900.00
9DC592	2017-07-17 00:36:00+03	48100.00
9DC634	2017-08-14 08:11:00+03	73300.00
9DC694	2017-08-04 13:04:00+03	13600.00
9DC695	2017-07-19 11:09:00+03	38100.00
9DC6E5	2017-07-15 13:49:00+03	136800.00
9DC70D	2017-07-31 21:52:00+03	116000.00
9DC721	2017-07-15 21:25:00+03	27200.00
9DC740	2017-07-12 03:53:00+03	27800.00
9DC750	2017-07-05 19:11:00+03	91700.00
9DC7DC	2017-07-05 00:08:00+03	8400.00
9DC7E4	2017-07-16 07:28:00+03	56000.00
9DC7E9	2017-07-12 23:28:00+03	62600.00
9DC7EE	2017-07-10 00:57:00+03	226200.00
9DC80D	2017-07-08 01:12:00+03	185700.00
9DC844	2017-08-11 11:43:00+03	13800.00
9DC84E	2017-07-18 11:51:00+03	283700.00
9DC856	2017-08-14 00:07:00+03	62600.00
9DC85E	2017-07-24 21:13:00+03	134400.00
9DC860	2017-07-16 13:07:00+03	57800.00
9DC8BC	2017-07-18 02:31:00+03	27800.00
9DC8CD	2017-07-26 14:43:00+03	136500.00
9DC8D0	2017-06-30 10:53:00+03	39500.00
9DC8DB	2017-07-21 05:56:00+03	12600.00
9DC8E3	2017-08-08 11:09:00+03	31900.00
9DC940	2017-07-25 18:22:00+03	21800.00
9DC995	2017-07-28 10:26:00+03	41600.00
9DC9B7	2017-07-21 18:28:00+03	67400.00
9DCA9D	2017-08-04 23:27:00+03	58100.00
9DCB3B	2017-07-04 11:43:00+03	405200.00
9DCB5B	2017-08-13 10:49:00+03	92800.00
9DCB6D	2017-07-20 18:47:00+03	67200.00
9DCBCD	2017-08-01 11:14:00+03	6600.00
9DCBD6	2017-08-01 19:54:00+03	47200.00
9DCC0C	2017-08-02 13:17:00+03	106000.00
9DCC1F	2017-08-08 12:38:00+03	53300.00
9DCC7C	2017-07-02 16:29:00+03	114300.00
9DCCA9	2017-08-10 03:40:00+03	28800.00
9DCCEB	2017-07-06 17:54:00+03	32700.00
9DCCEF	2017-07-30 18:34:00+03	24400.00
9DCDB9	2017-07-26 08:07:00+03	36800.00
9DCDC8	2017-07-10 18:29:00+03	47900.00
9DCE33	2017-08-08 05:20:00+03	35200.00
9DCE9F	2017-07-29 02:23:00+03	34000.00
9DCFF1	2017-07-27 02:41:00+03	66600.00
9DD024	2017-08-04 11:18:00+03	16400.00
9DD02F	2017-08-05 18:19:00+03	40000.00
9DD092	2017-07-27 12:52:00+03	62600.00
9DD0AC	2017-07-05 23:45:00+03	66000.00
9DD271	2017-07-30 22:31:00+03	93900.00
9DD2DF	2017-07-17 02:50:00+03	68800.00
9DD341	2017-07-10 05:28:00+03	78900.00
9DD396	2017-07-15 01:18:00+03	67200.00
9DD397	2017-07-26 02:11:00+03	46800.00
9DD39A	2017-08-11 06:23:00+03	94000.00
9DD39C	2017-07-14 09:48:00+03	67400.00
9DD3BB	2017-07-06 13:24:00+03	32800.00
9DD3EC	2017-08-04 10:08:00+03	150000.00
9DD46A	2017-07-05 10:20:00+03	26700.00
9DD4C9	2017-07-27 03:29:00+03	53700.00
9DD565	2017-07-06 14:14:00+03	266400.00
9DD5C6	2017-07-09 22:07:00+03	25800.00
9DD5DD	2017-07-18 16:07:00+03	239400.00
9DD5E1	2017-07-11 05:45:00+03	89600.00
9DD5E5	2017-07-21 08:06:00+03	47000.00
9DD60D	2017-07-13 01:36:00+03	12600.00
9DD60E	2017-07-27 17:02:00+03	33300.00
9DD623	2017-07-15 22:35:00+03	43400.00
9DD63E	2017-08-08 11:37:00+03	80800.00
9DD680	2017-07-02 14:51:00+03	50900.00
9DD74E	2017-08-09 15:54:00+03	57600.00
9DD772	2017-07-24 14:14:00+03	57600.00
9DD788	2017-07-29 12:55:00+03	67600.00
9DD7B8	2017-07-23 13:08:00+03	58200.00
9DD816	2017-07-17 03:31:00+03	14700.00
9DD849	2017-07-05 12:35:00+03	81200.00
9DD877	2017-08-07 09:50:00+03	47000.00
9DD8A9	2017-07-30 06:11:00+03	20400.00
9DD8B9	2017-07-29 12:20:00+03	12600.00
9DD8BB	2017-07-28 19:54:00+03	111600.00
9DD9D9	2017-07-21 09:04:00+03	81500.00
9DDA53	2017-07-03 20:49:00+03	155500.00
9DDA66	2017-07-23 12:25:00+03	351000.00
9DDABC	2017-06-26 19:47:00+03	228900.00
9DDABE	2017-08-14 02:20:00+03	47200.00
9DDB94	2017-08-11 22:39:00+03	76400.00
9DDBB2	2017-08-09 06:12:00+03	86300.00
9DDBC0	2017-07-14 13:09:00+03	72300.00
9DDBDB	2017-07-16 10:32:00+03	23400.00
9DDBEE	2017-08-09 09:56:00+03	41800.00
9DDC35	2017-07-21 11:18:00+03	66600.00
9DDC44	2017-08-12 16:59:00+03	97900.00
9DDC5A	2017-08-12 21:41:00+03	46200.00
9DDC5F	2017-07-23 06:10:00+03	133200.00
9DDC8C	2017-08-13 02:20:00+03	31700.00
9DDCD7	2017-07-22 01:35:00+03	316000.00
9DDCE0	2017-07-14 23:53:00+03	73100.00
9DDD59	2017-07-22 08:01:00+03	87000.00
9DDD64	2017-07-16 01:12:00+03	28000.00
9DDD77	2017-08-05 14:27:00+03	54600.00
9DDD90	2017-07-05 14:03:00+03	62700.00
9DDDA4	2017-08-09 23:28:00+03	57400.00
9DDDD0	2017-07-26 10:57:00+03	19600.00
9DDDEB	2017-07-05 17:38:00+03	12400.00
9DDE52	2017-08-15 16:09:00+03	36700.00
9DDECB	2017-07-04 00:27:00+03	48100.00
9DDEDA	2017-07-12 23:40:00+03	31100.00
9DDEF8	2017-07-05 18:56:00+03	135400.00
9DDFB9	2017-07-28 23:28:00+03	12400.00
9DDFBE	2017-07-18 15:31:00+03	113200.00
9DDFC7	2017-07-23 14:48:00+03	25400.00
9DDFF3	2017-07-17 09:52:00+03	203000.00
9DE03A	2017-07-15 19:37:00+03	86400.00
9DE0AD	2017-07-19 16:51:00+03	48500.00
9DE0D8	2017-07-18 15:13:00+03	40800.00
9DE0EB	2017-08-01 04:36:00+03	96300.00
9DE178	2017-07-29 12:34:00+03	79800.00
9DE267	2017-07-07 17:38:00+03	38600.00
9DE2A9	2017-07-09 21:30:00+03	49100.00
9DE392	2017-07-25 14:28:00+03	31900.00
9DE3E5	2017-08-14 19:04:00+03	13400.00
9DE3F4	2017-07-06 12:55:00+03	118900.00
9DE44E	2017-07-26 17:43:00+03	369000.00
9DE555	2017-07-17 19:43:00+03	41400.00
9DE56E	2017-08-06 04:34:00+03	6700.00
9DE5C4	2017-08-12 21:35:00+03	62700.00
9DE5E4	2017-07-09 00:47:00+03	17600.00
9DE67A	2017-08-10 18:59:00+03	393700.00
9DE6C9	2017-07-19 15:59:00+03	27800.00
9DE761	2017-08-04 10:51:00+03	167400.00
9DE76C	2017-06-28 21:28:00+03	69500.00
9DE786	2017-07-22 08:30:00+03	76600.00
9DE787	2017-07-08 20:11:00+03	30800.00
9DE795	2017-08-09 12:47:00+03	193700.00
9DE7B1	2017-07-12 11:36:00+03	296400.00
9DE7E2	2017-08-13 11:43:00+03	17800.00
9DE7EA	2017-07-09 21:51:00+03	119400.00
9DE83B	2017-07-03 13:43:00+03	29100.00
9DE8D6	2017-08-04 05:06:00+03	117600.00
9DE8F6	2017-07-21 22:11:00+03	38400.00
9DE9A0	2017-07-15 21:02:00+03	67800.00
9DE9B0	2017-07-26 03:25:00+03	24400.00
9DE9C5	2017-07-15 05:21:00+03	167900.00
9DE9CF	2017-07-18 19:35:00+03	76800.00
9DE9D9	2017-07-05 15:13:00+03	23400.00
9DEA38	2017-07-20 23:28:00+03	68000.00
9DEA6F	2017-08-12 23:48:00+03	164700.00
9DEAC6	2017-07-09 20:32:00+03	23200.00
9DEAFB	2017-07-16 22:16:00+03	59200.00
9DEB3C	2017-07-26 01:44:00+03	170700.00
9DEB81	2017-07-06 21:09:00+03	113000.00
9DEBE2	2017-07-04 01:36:00+03	7300.00
9DEC61	2017-07-22 08:34:00+03	257600.00
9DEC66	2017-07-11 19:37:00+03	179500.00
9DEC78	2017-07-26 06:11:00+03	104600.00
9DECA3	2017-08-05 02:29:00+03	39200.00
9DECE3	2017-07-22 21:11:00+03	88800.00
9DED68	2017-08-13 05:43:00+03	28800.00
9DEDBC	2017-08-11 18:27:00+03	26800.00
9DEE26	2017-07-09 05:54:00+03	114500.00
9DEE4D	2017-07-28 15:18:00+03	51600.00
9DEE57	2017-07-14 01:22:00+03	20400.00
9DEEAE	2017-07-13 12:12:00+03	41200.00
9DEEC2	2017-08-12 14:49:00+03	37100.00
9DEEED	2017-08-07 05:12:00+03	41200.00
9DEF1C	2017-08-06 21:36:00+03	29100.00
9DEF43	2017-07-29 12:30:00+03	52000.00
9DEFA1	2017-08-12 05:45:00+03	205000.00
9DF011	2017-07-16 05:36:00+03	119300.00
9DF05F	2017-07-08 04:45:00+03	46400.00
9DF0A2	2017-07-28 08:09:00+03	56000.00
9DF0C4	2017-07-23 04:44:00+03	119600.00
9DF0F1	2017-07-28 01:46:00+03	23600.00
9DF0F2	2017-07-22 22:40:00+03	12600.00
9DF150	2017-07-20 23:21:00+03	16400.00
9DF165	2017-08-11 06:06:00+03	34800.00
9DF1AE	2017-08-03 19:01:00+03	66600.00
9DF1CC	2017-07-26 21:34:00+03	167200.00
9DF224	2017-08-01 10:47:00+03	118400.00
9DF249	2017-07-08 16:03:00+03	124000.00
9DF25F	2017-07-17 13:12:00+03	13700.00
9DF2DB	2017-07-21 03:33:00+03	181600.00
9DF3E7	2017-07-08 01:17:00+03	45000.00
9DF426	2017-07-11 16:04:00+03	12400.00
9DF431	2017-07-29 01:54:00+03	23200.00
9DF442	2017-08-01 06:34:00+03	266400.00
9DF45F	2017-07-30 22:17:00+03	100900.00
9DF4AC	2017-08-10 03:04:00+03	42800.00
9DF4B2	2017-08-05 11:00:00+03	78000.00
9DF4D1	2017-08-04 10:51:00+03	25200.00
9DF5B8	2017-07-25 04:13:00+03	120400.00
9DF5D4	2017-07-24 08:14:00+03	58400.00
9DF5F9	2017-07-08 14:09:00+03	49600.00
9DF605	2017-08-12 15:58:00+03	48400.00
9DF60C	2017-08-04 11:09:00+03	257500.00
9DF614	2017-07-22 23:32:00+03	29300.00
9DF682	2017-07-14 23:21:00+03	125400.00
9DF6DA	2017-07-23 10:44:00+03	34000.00
9DF791	2017-07-25 22:39:00+03	84100.00
9DF7BB	2017-07-27 06:29:00+03	62000.00
9DF801	2017-07-01 14:44:00+03	153300.00
9DF85D	2017-08-13 15:58:00+03	14000.00
9DF873	2017-08-07 23:11:00+03	177200.00
9DF8B4	2017-07-15 08:00:00+03	83900.00
9DF8B5	2017-08-01 02:48:00+03	54400.00
9DF90B	2017-08-15 14:39:00+03	189700.00
9DF92D	2017-07-03 09:47:00+03	89600.00
9DF99C	2017-07-21 15:43:00+03	94000.00
9DF9C9	2017-08-01 11:01:00+03	29500.00
9DF9D3	2017-07-06 01:33:00+03	135400.00
9DF9EF	2017-08-14 00:39:00+03	36200.00
9DFA32	2017-07-09 06:50:00+03	28800.00
9DFAE4	2017-07-23 15:54:00+03	47000.00
9DFAE9	2017-08-01 07:40:00+03	29200.00
9DFBBF	2017-08-05 15:40:00+03	30200.00
9DFBE4	2017-07-03 03:31:00+03	135300.00
9DFBF1	2017-07-22 17:56:00+03	375200.00
9DFC35	2017-06-27 01:13:00+03	24800.00
9DFC7D	2017-07-09 06:33:00+03	40200.00
9DFCD2	2017-07-19 18:29:00+03	174400.00
9DFCDE	2017-07-18 16:33:00+03	15000.00
9DFCFA	2017-07-04 06:41:00+03	28000.00
9DFD2D	2017-07-31 12:42:00+03	170700.00
9DFD3C	2017-07-31 17:50:00+03	31100.00
9DFD4B	2017-07-04 20:16:00+03	115700.00
9DFE0D	2017-07-12 11:45:00+03	101200.00
9DFE6C	2017-08-13 01:26:00+03	92600.00
9DFE6E	2017-07-29 08:35:00+03	62600.00
9DFECF	2017-07-29 23:27:00+03	38200.00
9DFF3D	2017-08-09 00:31:00+03	15100.00
9DFF6B	2017-07-28 00:24:00+03	24800.00
9DFFDA	2017-08-06 20:55:00+03	92200.00
9E000F	2017-07-14 23:35:00+03	24800.00
9E0066	2017-07-04 14:21:00+03	41200.00
9E0076	2017-07-01 16:50:00+03	80000.00
9E0080	2017-07-20 12:45:00+03	149800.00
9E00CE	2017-08-11 14:27:00+03	53300.00
9E0127	2017-07-24 22:52:00+03	23600.00
9E012C	2017-06-27 12:20:00+03	30400.00
9E0197	2017-08-01 09:53:00+03	30600.00
9E01BA	2017-08-11 23:04:00+03	265700.00
9E01C0	2017-08-03 10:01:00+03	166400.00
9E01CC	2017-08-04 06:19:00+03	68000.00
9E01D6	2017-07-02 02:02:00+03	28800.00
9E020C	2017-07-08 22:38:00+03	22000.00
9E0218	2017-08-07 01:21:00+03	73200.00
9E0277	2017-07-14 01:51:00+03	78000.00
9E02C3	2017-07-31 01:50:00+03	22000.00
9E02CC	2017-08-05 13:22:00+03	38600.00
9E02EE	2017-08-06 03:21:00+03	67100.00
9E032A	2017-07-19 18:13:00+03	25800.00
9E039A	2017-07-06 07:18:00+03	28000.00
9E03AD	2017-07-07 20:31:00+03	42800.00
9E03F0	2017-07-31 23:57:00+03	15000.00
9E042F	2017-08-13 20:44:00+03	24700.00
9E0478	2017-07-29 05:36:00+03	22000.00
9E0485	2017-08-01 20:22:00+03	56200.00
9E0491	2017-08-04 18:09:00+03	59400.00
9E04CC	2017-08-01 20:19:00+03	75700.00
9E0551	2017-07-05 14:26:00+03	59800.00
9E05D0	2017-08-08 04:13:00+03	47100.00
9E061D	2017-07-24 18:50:00+03	6200.00
9E0640	2017-07-12 00:45:00+03	173500.00
9E0644	2017-06-30 13:09:00+03	193200.00
9E06A5	2017-07-03 20:14:00+03	79300.00
9E06FB	2017-07-17 17:27:00+03	136800.00
9E071E	2017-08-14 16:56:00+03	11800.00
9E07D0	2017-07-27 15:41:00+03	51200.00
9E07DD	2017-08-03 03:53:00+03	67800.00
9E080E	2017-07-04 02:51:00+03	302200.00
9E0867	2017-07-28 05:31:00+03	6000.00
9E0968	2017-07-24 06:21:00+03	542300.00
9E09A2	2017-07-01 17:42:00+03	284400.00
9E09AA	2017-07-12 01:06:00+03	60400.00
9E09B6	2017-07-30 16:05:00+03	125400.00
9E09D0	2017-07-17 19:21:00+03	166100.00
9E0A1B	2017-07-22 04:25:00+03	27800.00
9E0A29	2017-07-25 11:52:00+03	44600.00
9E0A69	2017-08-06 23:17:00+03	47000.00
9E0AD7	2017-06-28 06:20:00+03	102200.00
9E0B10	2017-07-08 05:20:00+03	23400.00
9E0B2E	2017-07-24 14:04:00+03	129700.00
9E0BA7	2017-07-16 02:48:00+03	199700.00
9E0C69	2017-07-07 10:48:00+03	47200.00
9E0C6F	2017-07-08 12:38:00+03	75300.00
9E0CCE	2017-07-01 19:02:00+03	406200.00
9E0D11	2017-07-02 12:18:00+03	27200.00
9E0D12	2017-08-15 04:02:00+03	40800.00
9E0D2F	2017-07-30 23:28:00+03	83000.00
9E0D71	2017-07-08 23:01:00+03	134400.00
9E0D81	2017-06-28 04:23:00+03	62100.00
9E0D82	2017-08-07 06:18:00+03	83000.00
9E0D8A	2017-08-02 21:02:00+03	114400.00
9E0DA5	2017-08-12 02:41:00+03	36600.00
9E0DB8	2017-07-10 14:27:00+03	15900.00
9E0DBA	2017-07-11 01:13:00+03	66600.00
9E0DE8	2017-08-12 18:49:00+03	56000.00
9E0E6B	2017-07-11 04:18:00+03	177200.00
9E0ECD	2017-08-06 21:37:00+03	53100.00
9E0F67	2017-07-02 03:15:00+03	30200.00
9E1003	2017-07-16 21:15:00+03	47000.00
9E103A	2017-07-20 18:18:00+03	24700.00
9E105C	2017-08-12 18:52:00+03	28800.00
9E108B	2017-07-22 08:59:00+03	90600.00
9E108D	2017-07-17 19:10:00+03	28000.00
9E10EA	2017-08-03 20:59:00+03	69100.00
9E117F	2017-08-02 00:05:00+03	30800.00
9E11A1	2017-08-09 11:11:00+03	73900.00
9E120A	2017-08-02 01:15:00+03	29200.00
9E125C	2017-08-08 16:19:00+03	62900.00
9E12E4	2017-08-15 17:15:00+03	46400.00
9E132F	2017-07-12 10:55:00+03	112200.00
9E139E	2017-07-08 07:39:00+03	95600.00
9E13F2	2017-08-07 18:10:00+03	91500.00
9E13F7	2017-08-01 08:03:00+03	32800.00
9E13F8	2017-07-20 23:52:00+03	45500.00
9E1424	2017-07-22 09:55:00+03	77000.00
9E1435	2017-07-31 10:13:00+03	67600.00
9E1457	2017-07-30 00:53:00+03	246000.00
9E1482	2017-06-26 19:49:00+03	25000.00
9E14A5	2017-08-05 23:57:00+03	12000.00
9E154D	2017-07-24 16:33:00+03	99700.00
9E15EA	2017-08-05 01:22:00+03	100600.00
9E1608	2017-08-08 20:42:00+03	46400.00
9E1621	2017-07-09 21:26:00+03	70500.00
9E1649	2017-07-13 13:52:00+03	88800.00
9E1653	2017-07-20 06:33:00+03	58600.00
9E16C1	2017-07-28 10:07:00+03	66600.00
9E1719	2017-08-12 07:26:00+03	26000.00
9E1774	2017-07-25 03:15:00+03	56000.00
9E178F	2017-08-06 06:50:00+03	54300.00
9E185B	2017-06-30 12:04:00+03	68100.00
9E1860	2017-07-21 10:02:00+03	43800.00
9E18EA	2017-08-01 12:37:00+03	168000.00
9E192F	2017-08-10 20:15:00+03	6300.00
9E19A3	2017-07-28 14:30:00+03	67600.00
9E19BF	2017-07-24 12:49:00+03	42800.00
9E19DB	2017-08-05 10:53:00+03	21400.00
9E1A3B	2017-07-22 21:57:00+03	36600.00
9E1A3D	2017-08-04 04:29:00+03	217600.00
9E1ABB	2017-06-29 15:56:00+03	55800.00
9E1AD8	2017-07-29 00:03:00+03	27800.00
9E1B3B	2017-07-16 14:21:00+03	36900.00
9E1BC0	2017-07-20 19:26:00+03	437700.00
9E1BC7	2017-08-03 11:11:00+03	51900.00
9E1BFF	2017-07-12 15:03:00+03	13700.00
9E1C26	2017-07-06 04:04:00+03	108900.00
9E1C49	2017-07-28 18:07:00+03	289500.00
9E1D19	2017-07-02 20:05:00+03	36200.00
9E1D3B	2017-07-04 05:37:00+03	37900.00
9E1D8A	2017-08-12 20:45:00+03	112400.00
9E1D9F	2017-07-11 23:27:00+03	52000.00
9E1DA1	2017-08-04 06:53:00+03	55800.00
9E1DDF	2017-07-05 22:32:00+03	137300.00
9E1E64	2017-07-21 14:50:00+03	6700.00
9E1E8B	2017-07-13 14:54:00+03	125200.00
9E1ED7	2017-07-18 22:33:00+03	26000.00
9E1EDE	2017-07-19 16:45:00+03	144300.00
9E1EF6	2017-07-01 14:33:00+03	27700.00
9E1F09	2017-07-12 18:47:00+03	56100.00
9E1FA4	2017-07-31 18:30:00+03	46400.00
9E1FBE	2017-07-06 17:34:00+03	174600.00
9E1FD1	2017-07-30 09:57:00+03	90800.00
9E2071	2017-07-10 06:27:00+03	21400.00
9E207B	2017-08-14 13:05:00+03	36700.00
9E2082	2017-07-07 16:11:00+03	6800.00
9E2085	2017-07-31 19:55:00+03	116400.00
9E20C9	2017-07-28 11:22:00+03	131100.00
9E2154	2017-08-15 04:12:00+03	19600.00
9E21A7	2017-07-23 09:23:00+03	46000.00
9E220B	2017-07-29 02:15:00+03	28800.00
9E2272	2017-07-28 15:46:00+03	32700.00
9E22E8	2017-08-03 18:21:00+03	89600.00
9E22EF	2017-08-12 03:20:00+03	106100.00
9E22FC	2017-07-15 06:38:00+03	254900.00
9E230A	2017-07-06 19:26:00+03	127200.00
9E2319	2017-08-09 18:14:00+03	15800.00
9E231C	2017-07-21 11:41:00+03	69500.00
9E2323	2017-07-31 21:34:00+03	399600.00
9E23B3	2017-08-07 06:44:00+03	45600.00
9E240A	2017-07-18 07:23:00+03	22000.00
9E2482	2017-08-11 14:06:00+03	136800.00
9E24B7	2017-07-22 06:14:00+03	113200.00
9E251C	2017-07-16 11:14:00+03	186600.00
9E2578	2017-07-06 05:43:00+03	21800.00
9E25E8	2017-08-01 16:47:00+03	64500.00
9E2613	2017-07-15 19:21:00+03	24400.00
9E2633	2017-07-27 15:21:00+03	20200.00
9E263F	2017-07-25 00:47:00+03	13400.00
9E2671	2017-07-13 14:05:00+03	132800.00
9E26D0	2017-07-22 21:47:00+03	49100.00
9E26E4	2017-07-04 21:49:00+03	12000.00
9E273F	2017-07-12 22:35:00+03	70400.00
9E2755	2017-08-02 17:14:00+03	75300.00
9E27D0	2017-08-01 12:32:00+03	133200.00
9E27E3	2017-07-10 11:23:00+03	109000.00
9E27F2	2017-07-14 15:56:00+03	94000.00
9E27F9	2017-07-13 04:57:00+03	23200.00
9E2876	2017-07-07 18:00:00+03	38400.00
9E28BA	2017-08-04 18:29:00+03	52700.00
9E28DC	2017-07-08 23:45:00+03	182300.00
9E28E2	2017-08-06 15:42:00+03	21000.00
9E28E4	2017-08-11 16:02:00+03	124300.00
9E2918	2017-07-14 12:25:00+03	44800.00
9E2937	2017-08-09 11:43:00+03	74400.00
9E2A23	2017-08-11 10:43:00+03	56100.00
9E2A2F	2017-07-26 21:15:00+03	177200.00
9E2A32	2017-07-26 20:51:00+03	206400.00
9E2ABC	2017-07-31 19:28:00+03	75800.00
9E2AD4	2017-07-05 21:57:00+03	27400.00
9E2AE7	2017-08-08 12:01:00+03	137600.00
9E2AF3	2017-07-15 18:21:00+03	123000.00
9E2BB6	2017-07-07 07:58:00+03	25900.00
9E2BE0	2017-07-10 13:39:00+03	31600.00
9E2BE1	2017-08-06 03:36:00+03	65200.00
9E2BF1	2017-07-31 07:37:00+03	15200.00
9E2BFA	2017-07-16 23:28:00+03	484200.00
9E2C3B	2017-08-15 14:34:00+03	147200.00
9E2CAE	2017-08-08 03:36:00+03	59800.00
9E2CD1	2017-07-08 14:18:00+03	90000.00
9E2CDC	2017-07-22 21:46:00+03	176800.00
9E2D08	2017-07-07 17:00:00+03	56600.00
9E2D31	2017-08-11 14:58:00+03	28800.00
9E2D34	2017-08-15 14:56:00+03	10600.00
9E2D55	2017-08-04 07:53:00+03	64600.00
9E2D84	2017-07-24 10:46:00+03	45100.00
9E2D93	2017-08-10 16:52:00+03	278600.00
9E2DC1	2017-07-29 10:12:00+03	45700.00
9E2DD1	2017-07-17 05:22:00+03	40000.00
9E2DFC	2017-07-10 23:43:00+03	77000.00
9E2F02	2017-07-31 07:52:00+03	25600.00
9E2F41	2017-07-18 08:57:00+03	51600.00
9E2F48	2017-08-07 15:45:00+03	46800.00
9E2F79	2017-08-15 13:20:00+03	23600.00
9E2FB1	2017-07-12 02:01:00+03	13400.00
9E2FFE	2017-08-02 06:07:00+03	46800.00
9E303A	2017-07-08 16:48:00+03	41200.00
9E3040	2017-07-26 13:16:00+03	74800.00
9E3067	2017-07-03 14:01:00+03	7400.00
9E30D1	2017-07-06 20:27:00+03	46400.00
9E3139	2017-07-04 04:05:00+03	56600.00
9E3152	2017-07-22 01:58:00+03	160700.00
9E318E	2017-07-05 09:23:00+03	36200.00
9E31AC	2017-07-18 11:10:00+03	96800.00
9E31AF	2017-07-26 01:42:00+03	119600.00
9E3230	2017-07-06 06:48:00+03	28000.00
9E324B	2017-07-21 17:39:00+03	67200.00
9E32A2	2017-07-21 07:31:00+03	23400.00
9E32B8	2017-08-10 20:04:00+03	88000.00
9E32D1	2017-07-17 19:40:00+03	24400.00
9E3309	2017-07-18 08:15:00+03	56000.00
9E3319	2017-07-19 06:00:00+03	37900.00
9E3339	2017-07-06 07:47:00+03	124200.00
9E3347	2017-07-08 16:21:00+03	13400.00
9E3394	2017-07-09 03:19:00+03	26000.00
9E33C1	2017-07-20 11:10:00+03	52700.00
9E33D5	2017-07-08 15:45:00+03	132800.00
9E34E6	2017-07-12 15:41:00+03	47500.00
9E34F5	2017-07-01 02:42:00+03	139400.00
9E3500	2017-07-08 10:32:00+03	10800.00
9E3542	2017-08-06 13:01:00+03	10800.00
9E3636	2017-07-10 18:48:00+03	27000.00
9E3639	2017-07-09 19:11:00+03	100600.00
9E36C8	2017-07-21 18:02:00+03	143800.00
9E3743	2017-08-12 08:48:00+03	23200.00
9E379E	2017-07-07 22:07:00+03	141700.00
9E37A6	2017-08-04 16:20:00+03	43200.00
9E37A8	2017-07-04 19:00:00+03	56000.00
9E385A	2017-07-02 03:18:00+03	124200.00
9E3884	2017-07-19 06:29:00+03	6700.00
9E38BB	2017-08-07 05:01:00+03	23100.00
9E390F	2017-07-28 14:21:00+03	17000.00
9E392F	2017-08-08 03:47:00+03	35700.00
9E3975	2017-07-30 22:29:00+03	28000.00
9E39AC	2017-07-28 14:03:00+03	38400.00
9E3A73	2017-07-20 20:20:00+03	61800.00
9E3BB4	2017-07-06 11:21:00+03	26000.00
9E3BC5	2017-08-14 21:57:00+03	131100.00
9E3C03	2017-07-05 21:47:00+03	62600.00
9E3C2D	2017-07-14 13:51:00+03	246000.00
9E3C71	2017-06-27 07:32:00+03	36200.00
9E3CEA	2017-08-08 13:36:00+03	52000.00
9E3D84	2017-07-22 12:34:00+03	246000.00
9E3D86	2017-07-26 02:35:00+03	38400.00
9E3E0B	2017-08-13 21:30:00+03	299200.00
9E3E44	2017-08-12 17:24:00+03	83000.00
9E3E47	2017-07-06 00:34:00+03	81700.00
9E3E87	2017-07-24 19:54:00+03	36200.00
9E3FB5	2017-08-08 14:49:00+03	115600.00
9E3FBC	2017-07-31 21:54:00+03	206400.00
9E3FC3	2017-07-14 07:52:00+03	66600.00
9E400C	2017-08-09 04:57:00+03	29400.00
9E4066	2017-07-03 18:55:00+03	46300.00
9E40EC	2017-07-22 04:50:00+03	67700.00
9E411A	2017-08-12 00:41:00+03	38600.00
9E4150	2017-08-05 09:54:00+03	155100.00
9E4161	2017-07-14 00:35:00+03	106900.00
9E4192	2017-07-17 08:34:00+03	59000.00
9E41BC	2017-06-29 16:35:00+03	6300.00
9E4202	2017-08-06 02:22:00+03	65600.00
9E4228	2017-08-03 22:02:00+03	94700.00
9E4244	2017-08-14 23:31:00+03	40600.00
9E426A	2017-07-29 17:49:00+03	32800.00
9E427C	2017-07-17 09:37:00+03	56000.00
9E42D8	2017-07-17 19:00:00+03	25800.00
9E42F8	2017-07-11 15:42:00+03	267200.00
9E4352	2017-07-23 05:45:00+03	14700.00
9E4462	2017-07-07 14:50:00+03	40600.00
9E45C4	2017-08-11 11:31:00+03	16400.00
9E45EC	2017-08-08 06:20:00+03	278400.00
9E4621	2017-08-05 17:09:00+03	47000.00
9E462F	2017-07-23 21:20:00+03	135400.00
9E463A	2017-07-19 03:21:00+03	56000.00
9E464D	2017-07-30 03:10:00+03	20600.00
9E467A	2017-08-07 18:20:00+03	58800.00
9E4684	2017-07-17 07:20:00+03	64100.00
9E47AF	2017-07-25 19:09:00+03	278600.00
9E4844	2017-07-14 20:37:00+03	32800.00
9E4852	2017-08-01 03:54:00+03	75300.00
9E488E	2017-07-03 17:45:00+03	236000.00
9E48AF	2017-07-20 00:39:00+03	44600.00
9E48EE	2017-07-24 08:42:00+03	43900.00
9E4918	2017-07-23 14:43:00+03	28800.00
9E4A9F	2017-07-22 17:20:00+03	89600.00
9E4B52	2017-08-13 19:27:00+03	29100.00
9E4B65	2017-07-31 00:17:00+03	95200.00
9E4B9C	2017-07-07 04:48:00+03	56000.00
9E4BF7	2017-07-04 10:22:00+03	69000.00
9E4C4E	2017-08-07 01:23:00+03	22400.00
9E4C82	2017-07-26 15:38:00+03	28000.00
9E4CAD	2017-07-31 20:46:00+03	153300.00
9E4CCF	2017-07-02 00:20:00+03	56000.00
9E4CD2	2017-07-26 04:45:00+03	111600.00
9E4CF3	2017-07-22 03:24:00+03	180000.00
9E4D23	2017-07-25 06:28:00+03	27800.00
9E4D28	2017-08-06 07:15:00+03	146400.00
9E4D4D	2017-07-02 23:06:00+03	103200.00
9E4D75	2017-07-10 05:28:00+03	40400.00
9E4E87	2017-08-04 01:12:00+03	31800.00
9E4E8C	2017-07-02 01:55:00+03	35200.00
9E4E91	2017-07-03 05:10:00+03	64500.00
9E4F87	2017-07-19 20:39:00+03	51900.00
9E4F88	2017-07-16 16:03:00+03	67200.00
9E4FED	2017-07-29 20:26:00+03	86300.00
9E5036	2017-08-08 03:34:00+03	46300.00
9E50BF	2017-07-16 05:59:00+03	58600.00
9E50D5	2017-08-05 22:44:00+03	6000.00
9E512F	2017-08-08 14:48:00+03	92800.00
9E5173	2017-07-27 13:18:00+03	23600.00
9E5184	2017-07-02 10:34:00+03	46800.00
9E51AC	2017-08-02 13:49:00+03	24400.00
9E51E3	2017-07-08 02:23:00+03	6000.00
9E523B	2017-08-09 06:11:00+03	112500.00
9E526E	2017-07-22 11:02:00+03	85400.00
9E5279	2017-07-09 21:23:00+03	46000.00
9E527E	2017-08-14 21:59:00+03	202800.00
9E52B2	2017-07-04 05:35:00+03	143100.00
9E52E0	2017-06-27 01:36:00+03	46800.00
9E5317	2017-08-08 05:31:00+03	88800.00
9E5388	2017-08-12 21:49:00+03	84500.00
9E542B	2017-07-18 18:27:00+03	397700.00
9E5435	2017-08-01 09:29:00+03	104900.00
9E5466	2017-07-17 19:23:00+03	43200.00
9E54C1	2017-08-14 10:34:00+03	47400.00
9E54C8	2017-08-02 15:40:00+03	29400.00
9E5510	2017-07-21 01:35:00+03	123000.00
9E5529	2017-07-16 10:05:00+03	68400.00
9E5557	2017-08-06 19:35:00+03	26800.00
9E5607	2017-08-04 10:14:00+03	16400.00
9E562B	2017-07-09 18:27:00+03	248400.00
9E562D	2017-07-17 11:53:00+03	30000.00
9E562F	2017-07-16 00:39:00+03	7200.00
9E5641	2017-07-26 04:36:00+03	98400.00
9E5648	2017-08-15 06:12:00+03	240600.00
9E56D7	2017-07-14 14:00:00+03	101200.00
9E572A	2017-07-29 12:54:00+03	24400.00
9E5742	2017-07-02 05:47:00+03	36200.00
9E578A	2017-07-14 01:39:00+03	31600.00
9E578B	2017-08-07 22:38:00+03	32600.00
9E579C	2017-07-09 16:29:00+03	12400.00
9E57AD	2017-07-04 06:31:00+03	62000.00
9E57F9	2017-07-05 11:56:00+03	23200.00
9E5839	2017-08-05 07:45:00+03	136800.00
9E5843	2017-07-04 11:09:00+03	40800.00
9E58CC	2017-07-23 14:10:00+03	15400.00
9E590C	2017-07-25 02:44:00+03	104600.00
9E5968	2017-08-14 12:09:00+03	24400.00
9E5970	2017-08-06 11:24:00+03	560000.00
9E5978	2017-07-10 07:42:00+03	8000.00
9E59FF	2017-08-03 07:43:00+03	25400.00
9E5A0B	2017-07-14 20:03:00+03	28800.00
9E5A24	2017-07-16 23:42:00+03	24000.00
9E5A5E	2017-08-14 08:19:00+03	123000.00
9E5AEF	2017-07-17 17:34:00+03	257500.00
9E5BF1	2017-07-20 02:45:00+03	199200.00
9E5C96	2017-06-29 16:00:00+03	265600.00
9E5CE9	2017-07-14 15:19:00+03	23200.00
9E5D12	2017-06-29 10:57:00+03	64700.00
9E5D61	2017-07-20 03:07:00+03	70100.00
9E5D9A	2017-07-07 15:05:00+03	44000.00
9E5DCC	2017-07-31 13:33:00+03	46000.00
9E5E20	2017-08-09 05:16:00+03	66600.00
9E5E4D	2017-08-01 21:25:00+03	123000.00
9E5E6A	2017-08-03 03:31:00+03	40000.00
9E5E80	2017-07-28 01:02:00+03	35700.00
9E5EA4	2017-07-10 23:25:00+03	10800.00
9E5EA5	2017-08-12 18:11:00+03	28800.00
9E5ED0	2017-07-31 16:40:00+03	100600.00
9E5EFE	2017-07-05 03:05:00+03	56600.00
9E5F26	2017-08-11 05:32:00+03	173500.00
9E5F75	2017-07-03 16:20:00+03	112000.00
9E5FA9	2017-07-22 18:19:00+03	133100.00
9E5FE1	2017-07-04 22:32:00+03	58000.00
9E608C	2017-07-13 11:18:00+03	116400.00
9E608E	2017-07-07 21:36:00+03	64600.00
9E60AA	2017-06-30 19:44:00+03	6200.00
9E60DE	2017-07-15 07:54:00+03	376900.00
9E6122	2017-08-06 05:02:00+03	6800.00
9E6163	2017-08-11 13:43:00+03	38400.00
9E616C	2017-07-16 13:58:00+03	40000.00
9E6193	2017-07-06 15:39:00+03	62900.00
9E61CF	2017-07-06 05:32:00+03	80000.00
9E621A	2017-07-22 22:25:00+03	43500.00
9E626D	2017-07-13 05:59:00+03	6000.00
9E627C	2017-08-14 21:17:00+03	140900.00
9E62A4	2017-08-04 22:23:00+03	202400.00
9E6326	2017-07-11 10:04:00+03	36900.00
9E6374	2017-08-15 15:19:00+03	34000.00
9E6459	2017-07-28 08:40:00+03	102100.00
9E64BE	2017-07-18 14:17:00+03	14000.00
9E64C4	2017-08-06 23:32:00+03	202400.00
9E65FC	2017-07-26 22:25:00+03	47200.00
9E6601	2017-08-02 20:08:00+03	258400.00
9E665D	2017-08-15 08:45:00+03	77000.00
9E66EC	2017-07-04 05:52:00+03	135600.00
9E66FD	2017-08-14 13:31:00+03	293900.00
9E6704	2017-07-19 06:48:00+03	128800.00
9E6721	2017-08-05 16:13:00+03	167400.00
9E678E	2017-08-15 10:38:00+03	179700.00
9E67AC	2017-07-20 22:47:00+03	23200.00
9E67B6	2017-07-19 19:00:00+03	89600.00
9E67BD	2017-07-14 12:21:00+03	137900.00
9E67CD	2017-08-11 05:52:00+03	111600.00
9E67F7	2017-08-14 19:13:00+03	120800.00
9E6849	2017-07-28 12:10:00+03	98400.00
9E687E	2017-07-12 13:23:00+03	7200.00
9E6885	2017-06-28 02:44:00+03	23400.00
9E68BA	2017-07-18 14:01:00+03	93900.00
9E68E5	2017-08-05 00:42:00+03	71400.00
9E68EF	2017-07-06 01:32:00+03	92800.00
9E6934	2017-07-23 04:30:00+03	30200.00
9E6938	2017-08-08 09:32:00+03	114800.00
9E693B	2017-07-27 04:40:00+03	27500.00
9E6959	2017-08-06 15:52:00+03	36200.00
9E6963	2017-07-25 10:48:00+03	46400.00
9E69A1	2017-07-25 22:20:00+03	83400.00
9E69E3	2017-08-15 16:33:00+03	6800.00
9E6A1A	2017-07-01 16:26:00+03	37900.00
9E6A26	2017-07-05 11:20:00+03	28000.00
9E6A9C	2017-06-28 21:09:00+03	92400.00
9E6AA2	2017-08-09 07:51:00+03	34100.00
9E6ADC	2017-07-12 08:04:00+03	266400.00
9E6B33	2017-08-14 21:47:00+03	80400.00
9E6B4E	2017-07-29 01:03:00+03	69000.00
9E6B58	2017-07-02 05:21:00+03	56000.00
9E6B73	2017-07-30 23:24:00+03	38800.00
9E6BB0	2017-08-03 19:01:00+03	112000.00
9E6BD9	2017-08-08 22:56:00+03	48800.00
9E6CA3	2017-07-21 13:08:00+03	49500.00
9E6D51	2017-08-14 01:54:00+03	20500.00
9E6DC6	2017-08-06 12:48:00+03	55800.00
9E6E29	2017-07-28 16:25:00+03	89600.00
9E6E42	2017-07-16 06:46:00+03	24400.00
9E6E68	2017-08-08 09:45:00+03	38500.00
9E6E7A	2017-07-13 11:26:00+03	12600.00
9E6EEE	2017-07-13 02:44:00+03	54400.00
9E6F11	2017-07-24 12:39:00+03	103500.00
9E6F2E	2017-07-09 09:02:00+03	88900.00
9E6F55	2017-08-10 02:39:00+03	29400.00
9E6F74	2017-07-09 02:35:00+03	23200.00
9E6F91	2017-07-24 21:52:00+03	14000.00
9E6FC2	2017-08-04 05:42:00+03	68500.00
9E7005	2017-07-02 22:17:00+03	111600.00
9E7035	2017-07-11 13:38:00+03	172800.00
9E704D	2017-07-20 18:05:00+03	132800.00
9E705C	2017-07-03 02:54:00+03	36800.00
9E7061	2017-08-03 14:13:00+03	157200.00
9E70C5	2017-07-07 19:15:00+03	58200.00
9E70CD	2017-07-10 03:05:00+03	27200.00
9E70DC	2017-08-05 10:26:00+03	16400.00
9E7109	2017-07-25 18:34:00+03	92800.00
9E7157	2017-07-09 10:41:00+03	47500.00
9E71A6	2017-07-02 02:24:00+03	12000.00
9E71EC	2017-07-10 13:05:00+03	148100.00
9E71EE	2017-07-24 10:14:00+03	32800.00
9E7200	2017-08-15 01:44:00+03	111600.00
9E722D	2017-07-17 14:45:00+03	192400.00
9E728E	2017-07-28 21:44:00+03	31200.00
9E72CE	2017-07-31 15:35:00+03	26000.00
9E72D7	2017-07-03 10:03:00+03	36200.00
9E730E	2017-07-31 22:01:00+03	42700.00
9E7346	2017-08-03 11:46:00+03	58400.00
9E7404	2017-07-22 00:13:00+03	67100.00
9E7467	2017-08-08 18:42:00+03	12400.00
9E7475	2017-08-15 13:39:00+03	148200.00
9E750F	2017-08-02 23:57:00+03	260300.00
9E7511	2017-07-23 14:30:00+03	26000.00
9E7539	2017-07-17 05:43:00+03	67200.00
9E758F	2017-07-11 22:59:00+03	86600.00
9E759C	2017-08-14 02:48:00+03	66600.00
9E75E1	2017-08-11 14:18:00+03	50700.00
9E7613	2017-07-18 00:52:00+03	187600.00
9E7631	2017-07-28 23:21:00+03	23200.00
9E764F	2017-08-01 16:04:00+03	398600.00
9E7672	2017-07-18 22:51:00+03	72600.00
9E767A	2017-07-01 07:11:00+03	84300.00
9E7791	2017-08-12 12:04:00+03	36200.00
9E77B7	2017-07-05 05:54:00+03	207600.00
9E77BD	2017-07-02 20:57:00+03	65500.00
9E77BF	2017-07-15 14:42:00+03	69400.00
9E77CA	2017-07-22 08:07:00+03	66600.00
9E77FF	2017-08-13 17:39:00+03	32700.00
9E7810	2017-07-06 21:08:00+03	51900.00
9E7842	2017-07-09 07:43:00+03	25100.00
9E784F	2017-07-30 10:27:00+03	13600.00
9E7882	2017-07-04 12:28:00+03	6300.00
9E788A	2017-08-13 17:58:00+03	52900.00
9E7890	2017-07-23 19:17:00+03	47000.00
9E793B	2017-07-01 01:20:00+03	66600.00
9E7AB0	2017-07-15 03:56:00+03	92600.00
9E7AFD	2017-08-09 05:05:00+03	114300.00
9E7B80	2017-07-17 23:45:00+03	59800.00
9E7B88	2017-07-28 16:34:00+03	223400.00
9E7B96	2017-08-10 03:36:00+03	24400.00
9E7BBA	2017-07-08 04:28:00+03	41200.00
9E7C37	2017-08-12 15:12:00+03	7400.00
9E7C69	2017-07-06 01:25:00+03	7200.00
9E7C86	2017-07-25 15:46:00+03	139800.00
9E7CE3	2017-07-22 04:32:00+03	35200.00
9E7CFF	2017-07-22 22:51:00+03	56000.00
9E7D07	2017-07-29 22:49:00+03	45200.00
9E7D0A	2017-07-22 02:08:00+03	27800.00
9E7DB3	2017-07-09 18:37:00+03	67900.00
9E7DF3	2017-07-07 06:07:00+03	55800.00
9E7DF8	2017-08-03 18:51:00+03	54800.00
9E7E0D	2017-08-01 05:55:00+03	26000.00
9E7E36	2017-07-09 16:52:00+03	105800.00
9E7E3C	2017-07-20 23:10:00+03	28800.00
9E7E4D	2017-07-19 22:52:00+03	30000.00
9E7E78	2017-07-22 11:55:00+03	57600.00
9E7EE7	2017-07-05 20:26:00+03	64800.00
9E7F16	2017-06-30 15:13:00+03	188500.00
9E7F94	2017-06-27 00:21:00+03	402700.00
9E7FBC	2017-08-08 17:27:00+03	102100.00
9E7FD6	2017-07-11 11:33:00+03	46400.00
9E7FFF	2017-07-23 07:23:00+03	57500.00
9E800F	2017-07-09 16:23:00+03	32800.00
9E804A	2017-08-13 22:14:00+03	52300.00
9E8063	2017-08-14 09:35:00+03	38600.00
9E8119	2017-07-11 12:33:00+03	290500.00
9E81C5	2017-08-02 21:29:00+03	18100.00
9E81DA	2017-08-12 03:36:00+03	45100.00
9E81E8	2017-08-07 09:25:00+03	133700.00
9E8229	2017-08-15 08:25:00+03	60300.00
9E8265	2017-08-10 19:49:00+03	38600.00
9E834D	2017-07-22 05:52:00+03	115700.00
9E839A	2017-07-14 21:59:00+03	15100.00
9E839D	2017-07-29 10:28:00+03	51900.00
9E83A2	2017-06-30 22:53:00+03	40600.00
9E83F0	2017-07-30 07:36:00+03	226200.00
9E8442	2017-07-20 09:21:00+03	86500.00
9E844F	2017-07-21 23:20:00+03	160900.00
9E8472	2017-08-05 10:41:00+03	45200.00
9E849A	2017-08-01 07:37:00+03	123200.00
9E84C8	2017-07-07 13:56:00+03	178100.00
9E84CF	2017-07-26 22:18:00+03	52400.00
9E84DD	2017-08-14 07:16:00+03	62700.00
9E8520	2017-08-10 00:37:00+03	99300.00
9E8529	2017-08-13 22:26:00+03	77000.00
9E85C6	2017-08-11 06:01:00+03	38800.00
9E862D	2017-07-28 03:29:00+03	31400.00
9E865A	2017-07-09 09:53:00+03	70700.00
9E8665	2017-08-14 11:27:00+03	170700.00
9E8686	2017-08-04 02:11:00+03	51600.00
9E86AA	2017-07-12 17:16:00+03	100600.00
9E86B1	2017-07-13 22:49:00+03	68300.00
9E86ED	2017-08-14 08:08:00+03	13700.00
9E8708	2017-08-12 01:59:00+03	93600.00
9E8756	2017-07-22 10:20:00+03	60400.00
9E87B1	2017-07-10 15:36:00+03	246000.00
9E87BE	2017-07-15 01:38:00+03	96800.00
9E87D9	2017-07-15 19:51:00+03	58800.00
9E87F6	2017-07-03 23:41:00+03	248300.00
9E8824	2017-07-02 15:21:00+03	136500.00
9E88A5	2017-07-16 22:01:00+03	25600.00
9E88D0	2017-07-18 19:58:00+03	27800.00
9E88F7	2017-07-27 17:58:00+03	100600.00
9E8901	2017-07-22 11:44:00+03	17600.00
9E891A	2017-06-27 13:55:00+03	8200.00
9E8959	2017-07-11 17:48:00+03	174400.00
9E8973	2017-08-05 21:58:00+03	31900.00
9E899C	2017-07-28 14:45:00+03	31400.00
9E89C9	2017-07-12 15:16:00+03	23200.00
9E8A67	2017-07-08 04:40:00+03	21400.00
9E8A7D	2017-08-11 05:19:00+03	144000.00
9E8AD0	2017-07-01 07:31:00+03	44600.00
9E8AD3	2017-06-29 02:10:00+03	87100.00
9E8B27	2017-07-07 05:08:00+03	44000.00
9E8B2E	2017-08-02 18:31:00+03	22000.00
9E8BA8	2017-08-08 01:51:00+03	47600.00
9E8BAE	2017-07-28 16:15:00+03	92100.00
9E8BBD	2017-08-11 21:28:00+03	57800.00
9E8BC8	2017-07-11 09:25:00+03	26000.00
9E8BF9	2017-07-29 01:01:00+03	66600.00
9E8C02	2017-08-08 17:57:00+03	26700.00
9E8C1C	2017-08-13 03:03:00+03	42200.00
9E8C82	2017-07-01 09:35:00+03	186900.00
9E8CE5	2017-07-06 15:33:00+03	18800.00
9E8D56	2017-07-14 21:52:00+03	19600.00
9E8DA5	2017-07-26 17:49:00+03	40100.00
9E8DEB	2017-07-16 10:10:00+03	61100.00
9E8E05	2017-07-11 21:43:00+03	38300.00
9E8E7C	2017-07-12 02:10:00+03	38600.00
9E8E90	2017-07-29 22:18:00+03	106700.00
9E8E99	2017-08-02 15:27:00+03	105100.00
9E8EAE	2017-07-06 11:48:00+03	19800.00
9E8EB6	2017-07-13 07:00:00+03	67000.00
9E8F62	2017-06-30 18:38:00+03	70500.00
9E8FAD	2017-07-18 00:14:00+03	398500.00
9E8FC1	2017-07-03 02:38:00+03	69500.00
9E905A	2017-08-10 03:22:00+03	75300.00
9E9084	2017-07-15 11:01:00+03	28000.00
9E90A7	2017-07-30 02:37:00+03	106800.00
9E9191	2017-07-15 17:57:00+03	150500.00
9E919D	2017-07-30 19:59:00+03	48800.00
9E91C4	2017-07-07 11:14:00+03	271100.00
9E91C6	2017-07-02 23:16:00+03	77900.00
9E91DC	2017-07-23 16:43:00+03	42600.00
9E9232	2017-08-03 08:51:00+03	98200.00
9E92F9	2017-07-30 02:49:00+03	59800.00
9E9310	2017-08-02 07:43:00+03	23200.00
9E9392	2017-08-01 23:51:00+03	44800.00
9E9395	2017-07-24 23:00:00+03	248400.00
9E9418	2017-07-03 04:03:00+03	46400.00
9E9466	2017-07-21 05:49:00+03	277900.00
9E9472	2017-08-10 03:05:00+03	17600.00
9E949F	2017-07-11 07:08:00+03	22000.00
9E94A1	2017-07-15 08:44:00+03	24800.00
9E9502	2017-08-12 14:29:00+03	23200.00
9E9530	2017-07-27 13:25:00+03	47800.00
9E9563	2017-07-28 20:46:00+03	16400.00
9E9573	2017-07-12 23:47:00+03	69500.00
9E95D9	2017-08-08 14:02:00+03	198400.00
9E95E5	2017-08-06 17:40:00+03	6800.00
9E961D	2017-07-04 05:04:00+03	95200.00
9E9638	2017-08-14 03:49:00+03	133300.00
9E9658	2017-07-27 15:35:00+03	134400.00
9E966A	2017-07-11 19:48:00+03	66000.00
9E96DD	2017-07-13 21:18:00+03	67600.00
9E96F1	2017-08-13 11:19:00+03	66600.00
9E97A4	2017-07-01 05:31:00+03	265600.00
9E982C	2017-08-04 21:26:00+03	32800.00
9E9916	2017-07-19 14:36:00+03	217200.00
9E991B	2017-07-20 19:21:00+03	92000.00
9E9998	2017-07-04 01:45:00+03	29000.00
9E9A19	2017-07-26 22:23:00+03	22000.00
9E9A2B	2017-08-12 05:29:00+03	31500.00
9E9A94	2017-06-30 08:15:00+03	274200.00
9E9A9B	2017-07-25 21:53:00+03	84100.00
9E9AB8	2017-07-28 17:17:00+03	26200.00
9E9B00	2017-08-10 12:33:00+03	52700.00
9E9B87	2017-07-06 07:17:00+03	67600.00
9E9B9B	2017-08-08 20:26:00+03	369000.00
9E9BA5	2017-07-21 02:12:00+03	23200.00
9E9C02	2017-08-01 20:25:00+03	137700.00
9E9C3C	2017-08-09 22:32:00+03	381400.00
9E9C58	2017-07-27 18:08:00+03	186900.00
9E9CAE	2017-07-19 05:32:00+03	46200.00
9E9CB0	2017-07-04 20:28:00+03	34000.00
9E9CB7	2017-08-14 23:33:00+03	58000.00
9E9CB8	2017-07-09 13:02:00+03	73600.00
9E9CCA	2017-07-06 11:08:00+03	38600.00
9E9CD0	2017-07-12 17:28:00+03	26300.00
9E9D21	2017-07-03 22:22:00+03	141600.00
9E9D56	2017-08-03 01:32:00+03	120400.00
9E9D6B	2017-08-04 10:30:00+03	28000.00
9E9DFA	2017-08-08 01:40:00+03	98200.00
9E9E37	2017-07-28 13:08:00+03	175200.00
9E9E4D	2017-08-02 08:39:00+03	46400.00
9E9E8E	2017-08-13 16:27:00+03	30000.00
9E9EA3	2017-08-13 15:41:00+03	75300.00
9E9EAA	2017-07-10 02:44:00+03	34000.00
9E9F24	2017-06-28 16:26:00+03	58400.00
9E9F29	2017-08-05 14:36:00+03	56000.00
9E9F95	2017-08-13 02:37:00+03	147700.00
9EA001	2017-08-11 17:52:00+03	92400.00
9EA05C	2017-07-05 19:28:00+03	53700.00
9EA0B5	2017-07-11 19:17:00+03	173900.00
9EA0DE	2017-07-17 14:54:00+03	42700.00
9EA100	2017-08-05 00:21:00+03	21200.00
9EA1F7	2017-08-07 08:55:00+03	8000.00
9EA216	2017-08-05 09:26:00+03	32700.00
9EA2E6	2017-07-29 10:30:00+03	56100.00
9EA3BB	2017-07-18 16:40:00+03	25200.00
9EA431	2017-08-13 09:21:00+03	260300.00
9EA43E	2017-07-25 00:59:00+03	40400.00
9EA4B0	2017-07-05 20:46:00+03	88600.00
9EA4D2	2017-07-26 04:52:00+03	103900.00
9EA4E1	2017-07-14 08:51:00+03	28800.00
9EA52C	2017-08-06 15:38:00+03	78800.00
9EA55D	2017-08-14 18:47:00+03	43500.00
9EA5A4	2017-07-29 06:30:00+03	53300.00
9EA5A9	2017-08-11 15:24:00+03	57400.00
9EA5AA	2017-07-26 07:13:00+03	133100.00
9EA5E6	2017-08-03 13:52:00+03	19600.00
9EA631	2017-06-30 15:55:00+03	49500.00
9EA67A	2017-07-03 06:53:00+03	73300.00
9EA6A5	2017-07-19 19:10:00+03	26800.00
9EA6E8	2017-08-08 17:48:00+03	6700.00
9EA754	2017-07-08 01:51:00+03	6800.00
9EA77D	2017-07-07 20:16:00+03	180000.00
9EA7DD	2017-08-11 00:09:00+03	10700.00
9EA7EE	2017-07-16 23:26:00+03	60400.00
9EA81B	2017-06-27 15:48:00+03	46800.00
9EA841	2017-07-11 19:36:00+03	24400.00
9EA8A9	2017-07-12 18:03:00+03	36200.00
9EA965	2017-08-11 18:54:00+03	108900.00
9EA987	2017-07-24 00:41:00+03	584000.00
9EA997	2017-07-22 07:47:00+03	19600.00
9EA999	2017-07-16 12:22:00+03	6800.00
9EAA27	2017-07-02 05:19:00+03	36800.00
9EAA2D	2017-08-03 04:00:00+03	6700.00
9EAB1C	2017-08-03 23:47:00+03	90600.00
9EAB49	2017-07-15 01:02:00+03	103800.00
9EABED	2017-08-06 14:48:00+03	117600.00
9EAC0D	2017-08-11 14:38:00+03	23200.00
9EAC4D	2017-07-26 01:28:00+03	38600.00
9EAC8B	2017-07-10 19:35:00+03	85000.00
9EAD2F	2017-07-20 23:47:00+03	116600.00
9EADE2	2017-07-30 17:05:00+03	111600.00
9EAE1E	2017-07-03 04:56:00+03	6800.00
9EAE39	2017-07-01 17:34:00+03	133200.00
9EAE5A	2017-07-29 11:04:00+03	139200.00
9EAE67	2017-07-07 08:47:00+03	13400.00
9EAE6E	2017-07-20 07:16:00+03	261500.00
9EAE93	2017-07-17 06:06:00+03	16800.00
9EAEAA	2017-07-28 14:43:00+03	38300.00
9EAED1	2017-07-23 11:24:00+03	46400.00
9EAF19	2017-07-17 10:41:00+03	24600.00
9EAF42	2017-07-28 12:15:00+03	47400.00
9EB057	2017-07-21 00:59:00+03	204200.00
9EB0FA	2017-07-24 07:27:00+03	56000.00
9EB1B0	2017-07-12 21:20:00+03	41200.00
9EB1C6	2017-07-22 22:09:00+03	198400.00
9EB213	2017-07-24 20:11:00+03	106400.00
9EB232	2017-07-10 05:17:00+03	26000.00
9EB283	2017-06-29 03:59:00+03	57600.00
9EB2C1	2017-06-27 01:45:00+03	37900.00
9EB357	2017-08-08 01:58:00+03	123000.00
9EB368	2017-07-08 05:56:00+03	14000.00
9EB392	2017-07-29 21:49:00+03	14400.00
9EB3CD	2017-07-15 13:27:00+03	167400.00
9EB3D0	2017-07-03 07:34:00+03	67200.00
9EB3EA	2017-07-07 23:16:00+03	410200.00
9EB49F	2017-07-18 01:53:00+03	20200.00
9EB531	2017-07-28 04:45:00+03	271200.00
9EB5E3	2017-07-09 07:20:00+03	151200.00
9EB628	2017-08-09 02:14:00+03	87200.00
9EB648	2017-07-18 00:11:00+03	27700.00
9EB671	2017-07-11 13:56:00+03	64700.00
9EB6D4	2017-07-05 11:51:00+03	36200.00
9EB6EC	2017-07-09 23:55:00+03	67100.00
9EB6F4	2017-08-06 00:04:00+03	46200.00
9EB704	2017-07-28 09:26:00+03	52400.00
9EB7B5	2017-07-15 00:01:00+03	86300.00
9EB7BB	2017-08-03 23:19:00+03	137800.00
9EB7BF	2017-07-06 21:46:00+03	22000.00
9EB7D5	2017-07-22 03:26:00+03	71900.00
9EB7FB	2017-07-24 03:33:00+03	27200.00
9EB819	2017-07-13 09:36:00+03	62100.00
9EB8A3	2017-08-10 08:12:00+03	37300.00
9EB906	2017-07-12 18:36:00+03	393800.00
9EB926	2017-08-14 22:07:00+03	95200.00
9EB95D	2017-07-31 20:37:00+03	207600.00
9EBA07	2017-08-03 19:26:00+03	190400.00
9EBA0E	2017-07-12 21:14:00+03	399600.00
9EBA5B	2017-07-21 16:54:00+03	46300.00
9EBB1A	2017-07-02 07:11:00+03	19200.00
9EBB92	2017-08-14 23:12:00+03	6600.00
9EBBEA	2017-07-18 05:01:00+03	99800.00
9EBC19	2017-07-03 15:35:00+03	65600.00
9EBC1C	2017-07-05 11:10:00+03	103900.00
9EBC24	2017-07-16 00:48:00+03	65100.00
9EBC2A	2017-08-01 02:41:00+03	56000.00
9EBC45	2017-08-13 22:08:00+03	56000.00
9EBC71	2017-08-05 21:25:00+03	30200.00
9EBCC0	2017-07-08 16:49:00+03	52100.00
9EBCD6	2017-07-29 13:59:00+03	28000.00
9EBD18	2017-07-28 23:11:00+03	47000.00
9EBD1A	2017-08-11 07:45:00+03	170800.00
9EBD33	2017-07-13 19:42:00+03	28000.00
9EBD8C	2017-07-11 07:41:00+03	77800.00
9EBDA2	2017-07-13 06:08:00+03	75300.00
9EBE33	2017-07-31 03:13:00+03	93200.00
9EBE55	2017-07-14 06:02:00+03	59500.00
9EBED8	2017-07-07 10:38:00+03	46800.00
9EBEE6	2017-08-02 10:29:00+03	58800.00
9EBEF1	2017-08-13 18:17:00+03	29600.00
9EBEFA	2017-08-10 23:41:00+03	57300.00
9EBFA8	2017-07-20 11:59:00+03	132800.00
9EBFC5	2017-08-14 22:46:00+03	36200.00
9EC03F	2017-08-09 16:34:00+03	39300.00
9EC044	2017-07-21 15:48:00+03	59000.00
9EC0C5	2017-08-02 01:21:00+03	92600.00
9EC1B2	2017-07-17 20:22:00+03	93000.00
9EC1D4	2017-07-30 22:06:00+03	123000.00
9EC1EA	2017-07-27 15:29:00+03	17800.00
9EC1FA	2017-07-19 22:11:00+03	26200.00
9EC20E	2017-07-21 03:32:00+03	114700.00
9EC2AE	2017-07-20 01:48:00+03	66600.00
9EC37B	2017-07-19 01:51:00+03	52000.00
9EC3BF	2017-07-06 13:50:00+03	50400.00
9EC3CD	2017-07-17 23:18:00+03	166100.00
9EC3DF	2017-07-25 18:23:00+03	81600.00
9EC413	2017-06-28 09:00:00+03	21400.00
9EC471	2017-08-08 09:07:00+03	32800.00
9EC4A0	2017-07-10 13:12:00+03	78200.00
9EC4B1	2017-07-02 23:45:00+03	177600.00
9EC4CB	2017-07-22 18:05:00+03	51900.00
9EC4FE	2017-07-31 17:44:00+03	112400.00
9EC586	2017-07-22 10:35:00+03	81700.00
9EC58F	2017-07-07 13:20:00+03	73300.00
9EC63E	2017-07-03 18:45:00+03	181900.00
9EC670	2017-07-10 15:27:00+03	31800.00
9EC67A	2017-07-07 06:17:00+03	61500.00
9EC682	2017-07-05 05:42:00+03	46400.00
9EC710	2017-08-05 16:47:00+03	27200.00
9EC715	2017-08-13 01:24:00+03	112000.00
9EC7A5	2017-08-03 00:02:00+03	50800.00
9EC7D7	2017-07-21 14:09:00+03	46800.00
9EC7E6	2017-08-08 05:18:00+03	38600.00
9EC81D	2017-08-06 19:48:00+03	51900.00
9EC82F	2017-07-31 19:45:00+03	25800.00
9EC860	2017-08-04 15:54:00+03	28800.00
9EC886	2017-08-04 02:37:00+03	266400.00
9EC8B7	2017-07-28 00:47:00+03	173800.00
9EC8C9	2017-07-28 06:00:00+03	133900.00
9EC9E0	2017-07-20 17:31:00+03	134200.00
9ECA2B	2017-07-17 16:53:00+03	47000.00
9ECA4D	2017-07-26 01:06:00+03	53300.00
9ECA50	2017-08-10 13:05:00+03	32800.00
9ECA61	2017-07-03 04:45:00+03	105000.00
9ECA6C	2017-07-07 12:54:00+03	12400.00
9ECAFB	2017-07-17 19:20:00+03	37100.00
9ECAFF	2017-08-06 11:58:00+03	66600.00
9ECB36	2017-08-08 07:53:00+03	6700.00
9ECB4E	2017-07-15 10:10:00+03	40700.00
9ECBEE	2017-08-05 09:27:00+03	100000.00
9ECC61	2017-07-27 17:51:00+03	23200.00
9ECC62	2017-07-19 11:34:00+03	37900.00
9ECC72	2017-07-07 03:46:00+03	35200.00
9ECC7A	2017-08-14 13:06:00+03	48400.00
9ECCBB	2017-07-25 11:53:00+03	147000.00
9ECCBE	2017-08-05 00:04:00+03	300700.00
9ECCF9	2017-06-29 12:52:00+03	60200.00
9ECDA4	2017-08-14 22:55:00+03	184200.00
9ECDD3	2017-07-23 08:53:00+03	145300.00
9ECDE9	2017-08-02 09:10:00+03	51900.00
9ECE5B	2017-07-07 00:59:00+03	148200.00
9ECE70	2017-07-16 01:40:00+03	113600.00
9ECEA7	2017-08-03 14:33:00+03	36800.00
9ECEA8	2017-07-10 17:05:00+03	50600.00
9ECEB9	2017-08-13 19:23:00+03	20100.00
9ECF0C	2017-08-07 18:07:00+03	43900.00
9ECF3E	2017-07-07 16:09:00+03	112600.00
9ECF51	2017-08-04 19:15:00+03	6700.00
9ECF60	2017-08-15 00:12:00+03	167000.00
9ECFA6	2017-07-28 11:32:00+03	35600.00
9ED01D	2017-07-18 16:51:00+03	47000.00
9ED044	2017-07-03 12:53:00+03	67700.00
9ED071	2017-08-11 10:06:00+03	61800.00
9ED098	2017-08-03 18:01:00+03	115900.00
9ED09B	2017-08-08 05:38:00+03	44000.00
9ED117	2017-08-15 01:30:00+03	196400.00
9ED135	2017-07-07 21:59:00+03	67900.00
9ED13D	2017-07-27 21:00:00+03	43200.00
9ED161	2017-08-05 00:44:00+03	8400.00
9ED176	2017-08-13 23:09:00+03	114600.00
9ED2BF	2017-07-14 14:50:00+03	52700.00
9ED2EF	2017-07-23 04:07:00+03	46000.00
9ED305	2017-07-29 22:49:00+03	23400.00
9ED337	2017-07-05 20:13:00+03	28000.00
9ED378	2017-08-04 18:48:00+03	28000.00
9ED385	2017-07-20 00:20:00+03	26500.00
9ED39D	2017-07-06 09:02:00+03	12200.00
9ED3A3	2017-07-23 06:44:00+03	96800.00
9ED3D4	2017-07-30 23:15:00+03	46300.00
9ED3EB	2017-08-06 16:23:00+03	26700.00
9ED40D	2017-07-02 18:45:00+03	40000.00
9ED438	2017-07-20 07:56:00+03	132800.00
9ED483	2017-08-15 14:44:00+03	38600.00
9ED493	2017-08-01 21:18:00+03	37900.00
9ED4C4	2017-07-28 04:39:00+03	28000.00
9ED4EB	2017-07-13 23:58:00+03	56600.00
9ED4F1	2017-07-22 03:57:00+03	37100.00
9ED517	2017-07-25 00:20:00+03	97900.00
9ED5B8	2017-07-28 12:12:00+03	12600.00
9ED5BF	2017-07-12 16:16:00+03	801900.00
9ED5DA	2017-07-11 03:05:00+03	97600.00
9ED5E6	2017-07-22 16:10:00+03	28800.00
9ED63F	2017-08-06 11:12:00+03	28000.00
9ED67F	2017-07-15 18:44:00+03	265600.00
9ED6B4	2017-07-13 19:44:00+03	93400.00
9ED76A	2017-08-07 08:44:00+03	134700.00
9ED8C8	2017-08-09 15:27:00+03	79300.00
9ED911	2017-06-30 10:17:00+03	66100.00
9ED95C	2017-07-26 06:44:00+03	56000.00
9ED9BF	2017-07-13 23:49:00+03	492000.00
9EDA5A	2017-07-19 20:50:00+03	62900.00
9EDAC9	2017-08-01 10:42:00+03	87600.00
9EDB30	2017-07-14 09:24:00+03	69500.00
9EDB46	2017-07-23 03:19:00+03	31600.00
9EDB7F	2017-07-08 12:38:00+03	147000.00
9EDB80	2017-07-08 08:19:00+03	46500.00
9EDBF0	2017-08-06 23:14:00+03	38800.00
9EDC0D	2017-08-05 07:18:00+03	104600.00
9EDC2D	2017-07-12 01:31:00+03	40300.00
9EDC50	2017-07-07 11:56:00+03	6300.00
9EDCF9	2017-07-12 15:52:00+03	74400.00
9EDD9F	2017-07-18 23:42:00+03	339900.00
9EDDA6	2017-07-03 21:38:00+03	46400.00
9EDDCF	2017-07-18 02:04:00+03	37900.00
9EDE05	2017-07-08 22:10:00+03	75300.00
9EDE3B	2017-07-17 07:45:00+03	143600.00
9EDE42	2017-07-02 09:42:00+03	27200.00
9EDE7D	2017-08-03 11:58:00+03	67600.00
9EDE94	2017-07-21 21:35:00+03	20200.00
9EDED1	2017-07-02 17:47:00+03	6700.00
9EDEF6	2017-08-10 12:06:00+03	56000.00
9EDF0F	2017-08-11 04:20:00+03	146300.00
9EDF3D	2017-07-23 22:39:00+03	38400.00
9EDF53	2017-08-03 13:53:00+03	62700.00
9EDF8E	2017-08-09 17:31:00+03	23200.00
9EDF97	2017-08-09 17:32:00+03	12600.00
9EDFC9	2017-07-27 10:49:00+03	115700.00
9EE01F	2017-07-07 16:40:00+03	39500.00
9EE072	2017-08-13 02:12:00+03	369000.00
9EE0C0	2017-07-18 11:24:00+03	129200.00
9EE0CE	2017-07-18 19:04:00+03	31600.00
9EE105	2017-07-18 02:51:00+03	36800.00
9EE144	2017-08-07 21:59:00+03	65200.00
9EE174	2017-07-26 16:10:00+03	135600.00
9EE176	2017-07-26 18:47:00+03	100000.00
9EE196	2017-07-30 03:00:00+03	100600.00
9EE1D3	2017-07-13 01:34:00+03	382200.00
9EE239	2017-07-11 23:09:00+03	236000.00
9EE2B9	2017-07-11 20:21:00+03	58600.00
9EE30F	2017-07-19 20:18:00+03	32800.00
9EE334	2017-08-12 00:30:00+03	55800.00
9EE33D	2017-07-14 06:41:00+03	78300.00
9EE3A5	2017-07-19 02:06:00+03	396500.00
9EE3AA	2017-07-07 06:15:00+03	196400.00
9EE40F	2017-07-20 15:20:00+03	57500.00
9EE577	2017-07-21 22:44:00+03	21800.00
9EE58A	2017-07-03 06:53:00+03	42700.00
9EE63F	2017-08-07 01:45:00+03	27200.00
9EE65E	2017-07-25 11:36:00+03	47200.00
9EE6FE	2017-07-08 03:13:00+03	36000.00
9EE727	2017-07-28 20:21:00+03	73600.00
9EE728	2017-08-03 13:11:00+03	135400.00
9EE72B	2017-08-02 23:22:00+03	103500.00
9EE775	2017-08-13 17:17:00+03	57500.00
9EE7FB	2017-07-05 13:14:00+03	92700.00
9EE8F0	2017-08-01 09:27:00+03	75300.00
9EE94C	2017-07-02 15:38:00+03	103200.00
9EE977	2017-08-05 20:56:00+03	60300.00
9EEA72	2017-07-07 21:21:00+03	59300.00
9EEA8A	2017-07-04 23:24:00+03	56000.00
9EEAFE	2017-07-25 14:41:00+03	6800.00
9EEB07	2017-08-10 10:25:00+03	46400.00
9EEB49	2017-08-05 16:11:00+03	59800.00
9EEB65	2017-08-14 11:06:00+03	68100.00
9EEB7C	2017-07-22 16:03:00+03	16400.00
9EEB7F	2017-08-03 22:03:00+03	38500.00
9EEBB5	2017-07-28 06:38:00+03	30900.00
9EEC54	2017-08-14 22:58:00+03	31300.00
9EEC73	2017-08-06 19:52:00+03	8200.00
9EEC76	2017-06-28 16:47:00+03	131600.00
9EECAB	2017-07-22 15:46:00+03	32700.00
9EECF9	2017-07-22 05:45:00+03	25700.00
9EED14	2017-07-21 07:38:00+03	67400.00
9EED40	2017-07-15 07:24:00+03	80100.00
9EED42	2017-07-14 22:48:00+03	46000.00
9EED55	2017-07-07 16:55:00+03	26000.00
9EEDA1	2017-07-05 01:32:00+03	541500.00
9EEE49	2017-07-27 17:31:00+03	53600.00
9EEE96	2017-08-07 19:36:00+03	51900.00
9EEED0	2017-07-21 01:04:00+03	9200.00
9EEF89	2017-08-13 01:41:00+03	291100.00
9EEFA5	2017-08-08 03:27:00+03	100000.00
9EF035	2017-07-23 19:07:00+03	72400.00
9EF051	2017-07-09 13:53:00+03	65900.00
9EF09C	2017-08-09 07:17:00+03	26700.00
9EF130	2017-07-05 20:06:00+03	88100.00
9EF133	2017-07-19 06:20:00+03	466000.00
9EF13B	2017-08-15 03:29:00+03	28800.00
9EF1D9	2017-07-25 12:53:00+03	95500.00
9EF200	2017-07-08 10:11:00+03	21800.00
9EF210	2017-07-26 14:55:00+03	68000.00
9EF249	2017-08-15 14:32:00+03	81300.00
9EF279	2017-08-04 02:35:00+03	65900.00
9EF285	2017-08-01 21:59:00+03	28800.00
9EF292	2017-08-10 03:45:00+03	101200.00
9EF2C1	2017-07-30 22:34:00+03	248300.00
9EF321	2017-08-09 00:24:00+03	38600.00
9EF33F	2017-07-20 22:22:00+03	136700.00
9EF350	2017-07-11 13:25:00+03	30000.00
9EF36C	2017-07-09 11:10:00+03	26800.00
9EF37C	2017-07-17 04:31:00+03	28800.00
9EF3BB	2017-07-06 23:33:00+03	44500.00
9EF3F1	2017-08-01 02:46:00+03	90400.00
9EF410	2017-07-15 00:02:00+03	88900.00
9EF43B	2017-07-08 01:06:00+03	44800.00
9EF43C	2017-07-04 06:12:00+03	28300.00
9EF443	2017-07-02 23:59:00+03	45200.00
9EF44C	2017-08-06 17:42:00+03	36700.00
9EF4AE	2017-07-26 01:17:00+03	76600.00
9EF4B4	2017-08-13 19:46:00+03	73300.00
9EF51E	2017-08-08 09:16:00+03	43200.00
9EF580	2017-07-27 08:18:00+03	28800.00
9EF58D	2017-07-13 14:45:00+03	36800.00
9EF597	2017-08-05 09:59:00+03	144000.00
9EF59C	2017-08-07 22:09:00+03	45200.00
9EF59F	2017-07-24 01:21:00+03	93400.00
9EF5AC	2017-08-08 19:38:00+03	54400.00
9EF5D1	2017-07-10 20:55:00+03	284400.00
9EF5F6	2017-07-14 09:17:00+03	248400.00
9EF60A	2017-08-04 18:02:00+03	75300.00
9EF61B	2017-08-15 10:13:00+03	38800.00
9EF6BA	2017-07-06 18:29:00+03	25300.00
9EF7D1	2017-07-16 09:22:00+03	49800.00
9EF84C	2017-08-12 10:10:00+03	33300.00
9EF84F	2017-07-09 12:25:00+03	69000.00
9EF877	2017-08-09 16:32:00+03	56000.00
9EF8C9	2017-07-06 04:43:00+03	141600.00
9EF8D7	2017-07-09 05:55:00+03	21800.00
9EF8D9	2017-07-26 08:17:00+03	26800.00
9EF92D	2017-07-03 10:20:00+03	242300.00
9EF99A	2017-07-20 18:34:00+03	210000.00
9EF9AE	2017-08-03 19:47:00+03	84300.00
9EFA4F	2017-08-09 19:49:00+03	59800.00
9EFABD	2017-08-13 15:22:00+03	58800.00
9EFAF4	2017-07-28 01:50:00+03	43800.00
9EFB54	2017-07-24 06:04:00+03	266400.00
9EFB58	2017-08-12 00:19:00+03	57400.00
9EFB5F	2017-08-02 18:43:00+03	12600.00
9EFB64	2017-07-25 14:42:00+03	186000.00
9EFB71	2017-07-16 09:14:00+03	61800.00
9EFB7A	2017-06-30 14:30:00+03	22000.00
9EFBA7	2017-08-06 22:09:00+03	23600.00
9EFBAC	2017-07-11 00:34:00+03	93800.00
9EFBD7	2017-07-28 21:31:00+03	52800.00
9EFC09	2017-07-26 16:38:00+03	68100.00
9EFC24	2017-07-20 15:11:00+03	133200.00
9EFC62	2017-07-22 21:08:00+03	21400.00
9EFC71	2017-08-14 19:59:00+03	61200.00
9EFCE1	2017-07-15 12:07:00+03	64800.00
9EFCEA	2017-07-26 01:24:00+03	94100.00
9EFD11	2017-07-06 13:20:00+03	14000.00
9EFD34	2017-07-07 19:36:00+03	44600.00
9EFD8A	2017-07-30 18:59:00+03	29200.00
9EFD90	2017-08-15 04:31:00+03	474800.00
9EFDA0	2017-08-11 02:08:00+03	103600.00
9EFDBE	2017-07-25 09:19:00+03	46000.00
9EFE47	2017-07-03 01:28:00+03	39800.00
9EFEEC	2017-07-09 19:31:00+03	28800.00
9EFEF7	2017-08-02 14:04:00+03	52400.00
9EFF3D	2017-07-22 08:29:00+03	44400.00
9EFF60	2017-07-17 13:13:00+03	62600.00
9EFFA3	2017-07-04 23:05:00+03	38400.00
9EFFB4	2017-08-08 08:16:00+03	37900.00
9F0071	2017-07-31 03:09:00+03	246000.00
9F00A0	2017-08-15 11:24:00+03	18600.00
9F0132	2017-07-09 08:45:00+03	55800.00
9F0151	2017-07-15 17:44:00+03	8200.00
9F01E0	2017-08-05 14:09:00+03	47300.00
9F01EB	2017-07-04 07:58:00+03	56000.00
9F021A	2017-08-14 20:25:00+03	68800.00
9F022D	2017-07-25 22:11:00+03	52100.00
9F0262	2017-08-12 21:22:00+03	6700.00
9F0294	2017-07-12 03:42:00+03	14400.00
9F0306	2017-08-04 16:48:00+03	37700.00
9F035A	2017-07-15 18:41:00+03	61900.00
9F0384	2017-07-08 00:04:00+03	39800.00
9F0386	2017-08-12 12:48:00+03	6300.00
9F03DD	2017-07-22 08:16:00+03	20200.00
9F0402	2017-07-18 01:08:00+03	69400.00
9F045C	2017-07-22 09:34:00+03	107200.00
9F048E	2017-08-11 19:49:00+03	410200.00
9F04E7	2017-08-01 07:30:00+03	62600.00
9F0515	2017-08-12 16:51:00+03	65500.00
9F051E	2017-08-10 05:53:00+03	193100.00
9F0542	2017-08-01 01:15:00+03	11600.00
9F059B	2017-08-10 14:13:00+03	278600.00
9F05AA	2017-07-12 22:17:00+03	36900.00
9F0741	2017-07-27 10:02:00+03	76300.00
9F0749	2017-07-30 20:10:00+03	34000.00
9F0753	2017-07-28 09:39:00+03	14000.00
9F0771	2017-07-24 03:01:00+03	92800.00
9F07B2	2017-07-19 03:15:00+03	14000.00
9F07BC	2017-08-12 03:50:00+03	52000.00
9F07E5	2017-07-07 12:13:00+03	7400.00
9F0858	2017-07-11 08:14:00+03	23200.00
9F085D	2017-06-30 05:11:00+03	128800.00
9F08BD	2017-08-12 11:56:00+03	87200.00
9F0925	2017-07-27 11:24:00+03	86600.00
9F096F	2017-07-21 10:23:00+03	101100.00
9F0995	2017-07-24 15:43:00+03	174500.00
9F09D7	2017-07-29 06:27:00+03	214300.00
9F0A19	2017-08-12 07:33:00+03	94000.00
9F0AF1	2017-08-13 03:38:00+03	28700.00
9F0B89	2017-07-06 13:19:00+03	34600.00
9F0C1E	2017-07-30 22:46:00+03	174800.00
9F0C1F	2017-07-03 10:31:00+03	13400.00
9F0C43	2017-08-04 10:56:00+03	75600.00
9F0C54	2017-07-30 04:33:00+03	52000.00
9F0CCD	2017-08-04 22:32:00+03	104600.00
9F0D16	2017-07-07 06:44:00+03	156500.00
9F0D98	2017-07-24 05:24:00+03	87100.00
9F0DB5	2017-07-11 23:20:00+03	14800.00
9F0DFA	2017-07-18 10:40:00+03	56000.00
9F0E67	2017-07-02 04:18:00+03	80700.00
9F0E69	2017-08-10 14:18:00+03	92900.00
9F0E80	2017-07-05 06:16:00+03	27500.00
9F0E8E	2017-07-13 14:11:00+03	72400.00
9F0ED8	2017-07-09 10:00:00+03	134800.00
9F0EF4	2017-07-15 00:16:00+03	70100.00
9F0F41	2017-07-22 05:50:00+03	28000.00
9F0F73	2017-07-25 04:42:00+03	37900.00
9F0FC4	2017-07-30 02:14:00+03	57800.00
9F10FB	2017-07-22 22:44:00+03	40800.00
9F1138	2017-07-04 18:11:00+03	48500.00
9F1143	2017-07-30 14:20:00+03	94700.00
9F115D	2017-07-12 22:39:00+03	28800.00
9F1160	2017-07-03 22:07:00+03	28800.00
9F1210	2017-07-10 22:48:00+03	270700.00
9F1227	2017-07-29 11:35:00+03	112000.00
9F1233	2017-08-14 08:06:00+03	36900.00
9F129E	2017-08-07 14:38:00+03	32300.00
9F12C4	2017-07-02 17:19:00+03	75300.00
9F133E	2017-08-12 21:20:00+03	34000.00
9F13BD	2017-07-04 22:58:00+03	108500.00
9F13C6	2017-07-08 15:31:00+03	42800.00
9F13C9	2017-08-13 23:25:00+03	54400.00
9F141D	2017-07-10 08:12:00+03	166100.00
9F142D	2017-07-02 14:50:00+03	15000.00
9F14AA	2017-07-21 07:25:00+03	47000.00
9F152B	2017-08-14 23:51:00+03	298500.00
9F153D	2017-08-10 17:32:00+03	122300.00
9F1585	2017-07-16 21:21:00+03	58800.00
9F1586	2017-08-08 07:32:00+03	81300.00
9F158F	2017-08-03 23:06:00+03	30600.00
9F1598	2017-07-18 06:34:00+03	87900.00
9F15ED	2017-08-03 07:55:00+03	23600.00
9F15FA	2017-07-15 06:29:00+03	56600.00
9F16A0	2017-07-11 06:38:00+03	6600.00
9F16A1	2017-07-18 04:26:00+03	28800.00
9F16E7	2017-07-16 14:14:00+03	99200.00
9F1758	2017-08-14 21:52:00+03	53500.00
9F175F	2017-08-10 04:09:00+03	81600.00
9F17B9	2017-07-15 15:41:00+03	54500.00
9F17BA	2017-08-14 07:18:00+03	29800.00
9F17DB	2017-07-05 10:57:00+03	35200.00
9F17F0	2017-08-11 09:30:00+03	49300.00
9F1806	2017-07-13 20:27:00+03	55800.00
9F1837	2017-08-04 10:25:00+03	125600.00
9F1858	2017-07-06 22:23:00+03	26000.00
9F18B5	2017-07-04 04:56:00+03	46300.00
9F18BF	2017-08-12 02:18:00+03	112000.00
9F19BC	2017-08-14 02:31:00+03	121300.00
9F19FA	2017-07-05 01:33:00+03	68800.00
9F1A25	2017-07-10 19:39:00+03	72400.00
9F1A64	2017-08-14 11:09:00+03	40800.00
9F1A6E	2017-08-08 21:33:00+03	35300.00
9F1A9A	2017-07-14 01:43:00+03	14400.00
9F1AD7	2017-07-21 01:26:00+03	99200.00
9F1B66	2017-08-09 03:20:00+03	12200.00
9F1B75	2017-08-13 15:26:00+03	28000.00
9F1B7A	2017-07-07 13:49:00+03	75600.00
9F1BC3	2017-08-10 07:02:00+03	58900.00
9F1BE3	2017-07-09 01:42:00+03	46200.00
9F1CCA	2017-08-15 15:02:00+03	114800.00
9F1CDD	2017-08-07 05:56:00+03	44800.00
9F1D39	2017-08-04 00:30:00+03	257600.00
9F1DA2	2017-07-31 21:07:00+03	10600.00
9F1DBE	2017-07-04 11:14:00+03	22100.00
9F1DEA	2017-07-06 09:25:00+03	16400.00
9F1DEB	2017-07-25 13:52:00+03	140300.00
9F1DFB	2017-07-14 06:37:00+03	46200.00
9F1E34	2017-08-15 17:11:00+03	26000.00
9F1E37	2017-07-27 23:16:00+03	39500.00
9F1E3B	2017-07-28 22:23:00+03	46000.00
9F1E59	2017-07-19 13:20:00+03	73100.00
9F1E63	2017-08-15 16:15:00+03	12300.00
9F1E82	2017-07-24 14:25:00+03	165500.00
9F1ED1	2017-08-10 02:30:00+03	103800.00
9F1EE3	2017-07-04 02:27:00+03	46400.00
9F1F4A	2017-07-07 13:46:00+03	56000.00
9F1F68	2017-08-14 14:24:00+03	128900.00
9F1F7B	2017-07-18 13:16:00+03	43200.00
9F1FAE	2017-08-03 02:26:00+03	92100.00
9F1FCC	2017-07-05 12:01:00+03	56100.00
9F1FDF	2017-07-05 13:32:00+03	38700.00
9F203F	2017-07-21 21:41:00+03	25600.00
9F2093	2017-07-28 12:26:00+03	51300.00
9F20C6	2017-07-04 15:29:00+03	95200.00
9F20DA	2017-07-26 21:26:00+03	92800.00
9F20DD	2017-07-25 02:40:00+03	22100.00
9F20F1	2017-08-14 02:52:00+03	135400.00
9F2139	2017-07-11 18:29:00+03	56900.00
9F2147	2017-07-28 08:41:00+03	9000.00
9F21E8	2017-07-13 07:06:00+03	143000.00
9F2222	2017-07-31 19:17:00+03	266400.00
9F2258	2017-08-14 18:36:00+03	45400.00
9F227D	2017-07-19 19:33:00+03	74100.00
9F22B7	2017-07-19 14:39:00+03	78200.00
9F2397	2017-07-14 13:26:00+03	101800.00
9F23CF	2017-07-30 11:40:00+03	112300.00
9F242B	2017-07-24 08:42:00+03	65000.00
9F2454	2017-07-29 12:20:00+03	34600.00
9F246C	2017-08-15 11:42:00+03	43600.00
9F24DA	2017-08-01 06:26:00+03	36100.00
9F24DE	2017-07-19 18:09:00+03	23600.00
9F24F9	2017-08-11 00:19:00+03	149500.00
9F2513	2017-07-17 08:11:00+03	28300.00
9F256F	2017-07-17 02:45:00+03	134800.00
9F25D9	2017-07-08 21:36:00+03	27200.00
9F2625	2017-07-03 03:31:00+03	31200.00
9F264D	2017-07-19 03:08:00+03	134400.00
9F26DE	2017-07-12 18:36:00+03	32200.00
9F26F1	2017-08-02 18:54:00+03	59800.00
9F26FF	2017-07-05 14:59:00+03	70600.00
9F2708	2017-07-21 12:42:00+03	55800.00
9F2799	2017-08-02 12:58:00+03	62800.00
9F27AF	2017-08-12 05:32:00+03	47100.00
9F27F5	2017-07-06 00:09:00+03	32800.00
9F281D	2017-08-03 02:28:00+03	138200.00
9F283E	2017-08-03 23:45:00+03	86400.00
9F2880	2017-08-10 17:48:00+03	58600.00
9F2898	2017-07-02 10:31:00+03	61500.00
9F28A2	2017-07-25 18:07:00+03	17200.00
9F2911	2017-08-13 10:27:00+03	38000.00
9F2928	2017-07-11 07:11:00+03	13400.00
9F2952	2017-07-15 03:51:00+03	38600.00
9F29FE	2017-07-31 02:18:00+03	20500.00
9F2A17	2017-07-21 07:28:00+03	99200.00
9F2A8B	2017-07-15 05:36:00+03	7300.00
9F2AEA	2017-07-11 02:15:00+03	16000.00
9F2B2B	2017-08-02 21:14:00+03	30200.00
9F2B62	2017-08-12 13:36:00+03	67200.00
9F2BCA	2017-07-25 17:22:00+03	199300.00
9F2BF4	2017-08-11 07:54:00+03	95600.00
9F2D01	2017-07-13 19:13:00+03	48500.00
9F2D0B	2017-06-29 10:21:00+03	29800.00
9F2D2C	2017-07-03 18:43:00+03	76600.00
9F2D6E	2017-07-11 18:07:00+03	15100.00
9F2E72	2017-07-15 08:23:00+03	123000.00
9F2E7D	2017-07-24 17:31:00+03	99500.00
9F2ED5	2017-08-02 02:41:00+03	27400.00
9F2EE5	2017-07-18 08:59:00+03	14000.00
9F2F8B	2017-07-02 17:38:00+03	132800.00
9F2F99	2017-08-09 03:31:00+03	75300.00
9F2FE6	2017-08-03 07:44:00+03	112000.00
9F2FED	2017-08-09 00:46:00+03	56000.00
9F3007	2017-07-23 00:51:00+03	193700.00
9F3013	2017-08-13 16:55:00+03	56000.00
9F3017	2017-08-10 01:36:00+03	187600.00
9F3045	2017-07-08 00:31:00+03	8200.00
9F309B	2017-08-12 08:33:00+03	11600.00
9F30ED	2017-07-15 22:57:00+03	167400.00
9F313B	2017-07-17 00:54:00+03	84500.00
9F31AF	2017-07-15 19:55:00+03	93700.00
9F31CD	2017-07-14 05:53:00+03	31400.00
9F321D	2017-07-01 22:18:00+03	16800.00
9F321F	2017-07-20 16:52:00+03	6700.00
9F3272	2017-08-07 02:53:00+03	23600.00
9F32AC	2017-07-05 14:29:00+03	25100.00
9F32BD	2017-07-26 00:02:00+03	60200.00
9F33A1	2017-07-27 04:08:00+03	58600.00
9F3465	2017-08-10 18:24:00+03	36200.00
9F34A1	2017-07-11 10:26:00+03	16400.00
9F34B8	2017-07-30 03:10:00+03	92800.00
9F34F8	2017-07-08 10:29:00+03	110500.00
9F352D	2017-07-11 16:03:00+03	19600.00
9F35DC	2017-07-18 09:56:00+03	88800.00
9F3637	2017-07-16 05:13:00+03	81800.00
9F365E	2017-07-08 18:08:00+03	34000.00
9F3691	2017-07-15 02:37:00+03	77200.00
9F3696	2017-07-09 17:02:00+03	18600.00
9F36EB	2017-07-09 20:29:00+03	24200.00
9F3704	2017-07-08 21:49:00+03	58000.00
9F372D	2017-07-27 03:42:00+03	40400.00
9F3771	2017-07-12 22:02:00+03	6000.00
9F3783	2017-08-04 14:23:00+03	75300.00
9F37E6	2017-07-07 00:31:00+03	121900.00
9F380B	2017-07-25 16:47:00+03	47400.00
9F380C	2017-07-03 11:53:00+03	136600.00
9F382F	2017-07-17 03:18:00+03	139300.00
9F384E	2017-08-13 22:07:00+03	70500.00
9F3897	2017-08-06 19:47:00+03	70600.00
9F38D3	2017-07-16 03:34:00+03	109800.00
9F38D6	2017-07-14 21:46:00+03	28000.00
9F38DB	2017-07-16 18:37:00+03	13600.00
9F38E4	2017-08-03 19:00:00+03	43600.00
9F3919	2017-07-13 06:02:00+03	23200.00
9F391B	2017-07-30 09:12:00+03	92800.00
9F3927	2017-07-06 08:41:00+03	24300.00
9F3929	2017-07-24 23:56:00+03	32500.00
9F3931	2017-08-13 03:44:00+03	29600.00
9F3934	2017-07-14 20:03:00+03	101300.00
9F3938	2017-07-14 07:33:00+03	272400.00
9F393F	2017-07-10 05:58:00+03	75100.00
9F39E9	2017-07-22 22:36:00+03	78100.00
9F3A28	2017-08-08 09:17:00+03	23600.00
9F3A78	2017-07-06 16:13:00+03	39300.00
9F3A9E	2017-08-12 19:29:00+03	106200.00
9F3AA7	2017-06-27 23:34:00+03	148200.00
9F3ACE	2017-08-07 19:25:00+03	304600.00
9F3B71	2017-08-03 20:32:00+03	95200.00
9F3CE0	2017-07-26 16:32:00+03	29100.00
9F3D7C	2017-08-03 19:55:00+03	30900.00
9F3E5E	2017-07-02 06:23:00+03	60600.00
9F3E78	2017-07-14 12:28:00+03	111600.00
9F3EA4	2017-07-27 13:56:00+03	25400.00
9F3EB1	2017-07-10 19:21:00+03	146300.00
9F3F55	2017-08-13 08:03:00+03	51300.00
9F3F5A	2017-08-12 07:01:00+03	6300.00
9F3FAF	2017-08-14 01:17:00+03	12600.00
9F4031	2017-07-14 11:03:00+03	33200.00
9F4038	2017-07-25 00:01:00+03	164600.00
9F404A	2017-07-24 09:28:00+03	136200.00
9F40B3	2017-08-14 12:50:00+03	135400.00
9F40F7	2017-08-06 03:55:00+03	24200.00
9F4130	2017-07-17 08:13:00+03	112600.00
9F4165	2017-07-20 01:38:00+03	13400.00
9F41AE	2017-07-08 06:17:00+03	132800.00
9F41F8	2017-07-12 13:08:00+03	51900.00
9F4215	2017-07-15 00:31:00+03	51300.00
9F423D	2017-07-14 14:04:00+03	58200.00
9F42CE	2017-08-15 04:56:00+03	24000.00
9F42DB	2017-07-05 03:37:00+03	32700.00
9F42F6	2017-07-07 22:15:00+03	54000.00
9F430F	2017-08-09 22:19:00+03	40900.00
9F4338	2017-07-26 18:38:00+03	58900.00
9F434D	2017-07-21 03:32:00+03	112000.00
9F4359	2017-07-20 07:02:00+03	12000.00
9F437B	2017-07-15 13:25:00+03	95000.00
9F439B	2017-07-27 21:45:00+03	30400.00
9F4419	2017-07-18 19:52:00+03	41400.00
9F44D7	2017-07-08 19:54:00+03	67600.00
9F452D	2017-08-14 13:59:00+03	16400.00
9F4538	2017-07-17 07:31:00+03	30200.00
9F4562	2017-06-28 19:40:00+03	69700.00
9F46A1	2017-07-29 02:07:00+03	19600.00
9F46F0	2017-07-06 16:58:00+03	25100.00
9F472D	2017-07-30 17:04:00+03	21800.00
9F473D	2017-07-08 11:46:00+03	257600.00
9F47B3	2017-07-19 11:46:00+03	21800.00
9F47D0	2017-07-15 01:15:00+03	204200.00
9F47D1	2017-08-12 06:04:00+03	99200.00
9F48AF	2017-07-16 21:57:00+03	68800.00
9F48B3	2017-07-06 02:06:00+03	76600.00
9F48D4	2017-08-03 20:27:00+03	115100.00
9F4917	2017-08-01 18:39:00+03	88900.00
9F4924	2017-08-01 00:58:00+03	297600.00
9F4928	2017-07-20 06:01:00+03	188200.00
9F4955	2017-07-20 06:46:00+03	55600.00
9F4962	2017-07-18 10:02:00+03	28800.00
9F4963	2017-08-03 06:24:00+03	55800.00
9F498B	2017-08-01 02:42:00+03	265700.00
9F4A0E	2017-07-29 22:39:00+03	258400.00
9F4A4D	2017-07-16 11:46:00+03	58400.00
9F4A8B	2017-07-17 07:55:00+03	46400.00
9F4A91	2017-07-18 18:07:00+03	36200.00
9F4AEF	2017-07-07 10:11:00+03	14000.00
9F4B2F	2017-07-03 00:50:00+03	55800.00
9F4B4C	2017-07-05 18:57:00+03	218400.00
9F4B51	2017-07-20 08:14:00+03	83600.00
9F4B52	2017-07-11 15:36:00+03	48800.00
9F4B61	2017-07-03 04:30:00+03	59800.00
9F4BCA	2017-07-27 15:05:00+03	145900.00
9F4C00	2017-07-20 09:05:00+03	96400.00
9F4C01	2017-07-06 07:05:00+03	88200.00
9F4C02	2017-08-02 05:13:00+03	135400.00
9F4C2C	2017-08-10 20:22:00+03	26000.00
9F4C3D	2017-07-17 13:36:00+03	35600.00
9F4C67	2017-07-20 16:08:00+03	19600.00
9F4CB8	2017-07-18 18:09:00+03	12600.00
9F4CCE	2017-08-02 08:24:00+03	38800.00
9F4CDA	2017-07-12 12:35:00+03	83600.00
9F4D61	2017-07-19 04:55:00+03	22000.00
9F4D62	2017-07-28 04:22:00+03	56000.00
9F4D6D	2017-06-29 06:27:00+03	62700.00
9F4D8A	2017-07-09 19:52:00+03	399600.00
9F4DF3	2017-08-06 16:57:00+03	6800.00
9F4E07	2017-08-05 11:06:00+03	44800.00
9F4E19	2017-08-13 15:41:00+03	26000.00
9F4E4E	2017-07-07 08:58:00+03	12600.00
9F4E63	2017-07-07 00:49:00+03	62500.00
9F4EAB	2017-07-20 18:10:00+03	13400.00
9F4F5D	2017-08-07 12:16:00+03	135000.00
9F4F5F	2017-07-12 16:09:00+03	220500.00
9F4F79	2017-08-06 11:36:00+03	23200.00
9F4F81	2017-08-04 16:33:00+03	248400.00
9F4FFF	2017-07-27 02:52:00+03	23200.00
9F502A	2017-08-14 11:36:00+03	36400.00
9F5052	2017-07-05 08:03:00+03	84100.00
9F50CC	2017-07-16 10:43:00+03	135200.00
9F50E8	2017-07-27 21:47:00+03	92000.00
9F5109	2017-07-20 05:55:00+03	67200.00
9F5152	2017-08-13 14:42:00+03	95600.00
9F51C3	2017-08-08 21:09:00+03	48400.00
9F51EF	2017-08-12 07:32:00+03	96400.00
9F5253	2017-08-08 18:43:00+03	199200.00
9F527F	2017-08-04 17:53:00+03	68100.00
9F52D4	2017-08-14 06:16:00+03	131600.00
9F52EF	2017-08-02 19:21:00+03	99600.00
9F5317	2017-07-09 12:44:00+03	38400.00
9F53BA	2017-07-14 21:42:00+03	25900.00
9F53C5	2017-08-01 08:52:00+03	58900.00
9F53DE	2017-07-11 16:21:00+03	4000.00
9F53F7	2017-07-16 15:43:00+03	85400.00
9F542A	2017-08-07 04:33:00+03	72800.00
9F5440	2017-07-27 17:41:00+03	75600.00
9F5451	2017-08-06 21:57:00+03	199300.00
9F54DA	2017-07-22 04:17:00+03	133200.00
9F54E9	2017-07-04 14:35:00+03	12600.00
9F556A	2017-07-21 00:40:00+03	45800.00
9F55A2	2017-07-15 19:07:00+03	28800.00
9F55B1	2017-07-26 11:53:00+03	77600.00
9F55F6	2017-08-01 08:28:00+03	62800.00
9F5638	2017-08-10 12:54:00+03	68500.00
9F563A	2017-07-10 18:13:00+03	112000.00
9F5643	2017-07-11 21:51:00+03	6700.00
9F565E	2017-07-07 22:30:00+03	131100.00
9F56AA	2017-07-28 07:01:00+03	26000.00
9F56E2	2017-07-26 15:04:00+03	113200.00
9F5755	2017-08-05 04:45:00+03	32000.00
9F5766	2017-07-20 10:26:00+03	246000.00
9F57A1	2017-07-18 16:02:00+03	230000.00
9F57A4	2017-07-18 08:59:00+03	56000.00
9F57B7	2017-07-14 22:31:00+03	220600.00
9F57D9	2017-08-01 21:00:00+03	61800.00
9F57EA	2017-08-13 23:29:00+03	8200.00
9F57F1	2017-08-06 13:07:00+03	7400.00
9F586D	2017-07-25 08:34:00+03	23200.00
9F588E	2017-07-04 20:58:00+03	103600.00
9F58E2	2017-08-15 00:10:00+03	56600.00
9F592A	2017-06-29 13:42:00+03	62100.00
9F59B6	2017-08-10 18:58:00+03	46400.00
9F5A0C	2017-07-14 17:31:00+03	99200.00
9F5A98	2017-07-29 12:05:00+03	25200.00
9F5AE1	2017-07-31 05:45:00+03	24400.00
9F5AE5	2017-07-22 04:37:00+03	24400.00
9F5AFD	2017-07-04 03:54:00+03	70800.00
9F5B10	2017-07-09 07:14:00+03	56600.00
9F5B13	2017-08-01 11:08:00+03	52800.00
9F5B31	2017-07-23 13:27:00+03	20200.00
9F5B4D	2017-08-07 01:57:00+03	21400.00
9F5B5A	2017-07-12 22:15:00+03	55800.00
9F5B8D	2017-07-05 22:38:00+03	46400.00
9F5B95	2017-07-01 03:25:00+03	139300.00
9F5B96	2017-07-17 02:32:00+03	58200.00
9F5BAC	2017-07-15 23:17:00+03	25600.00
9F5BEC	2017-07-12 14:51:00+03	28800.00
9F5BFD	2017-08-01 14:22:00+03	131600.00
9F5C7D	2017-08-06 03:50:00+03	669400.00
9F5CBC	2017-07-04 06:08:00+03	86800.00
9F5CCF	2017-07-12 16:29:00+03	38500.00
9F5D39	2017-07-07 01:09:00+03	101800.00
9F5D72	2017-08-09 06:47:00+03	136200.00
9F5D74	2017-07-20 06:46:00+03	94000.00
9F5DB0	2017-08-05 11:44:00+03	56000.00
9F5DB1	2017-07-24 00:18:00+03	51300.00
9F5DB4	2017-08-05 00:23:00+03	30200.00
9F5E0C	2017-08-08 21:02:00+03	63700.00
9F5E11	2017-07-12 09:22:00+03	39800.00
9F5E4E	2017-07-08 21:19:00+03	116800.00
9F5E5D	2017-07-27 12:11:00+03	115800.00
9F5E9E	2017-07-05 13:33:00+03	78600.00
9F5EAD	2017-08-06 21:38:00+03	55800.00
9F5EBB	2017-07-12 12:58:00+03	49200.00
9F5EC4	2017-08-15 10:24:00+03	6300.00
9F5F16	2017-08-09 05:04:00+03	46200.00
9F5F91	2017-08-02 15:39:00+03	76600.00
9F5F9C	2017-07-29 09:11:00+03	38600.00
9F5FA8	2017-08-14 16:22:00+03	29600.00
9F5FB2	2017-07-15 01:31:00+03	207000.00
9F6017	2017-07-13 14:25:00+03	123000.00
9F6070	2017-06-29 10:56:00+03	14800.00
9F609A	2017-08-01 11:30:00+03	126300.00
9F60D7	2017-08-05 08:14:00+03	28800.00
9F60EF	2017-08-07 16:42:00+03	135400.00
9F6133	2017-07-20 19:54:00+03	47500.00
9F61B3	2017-07-10 12:12:00+03	144400.00
9F6200	2017-07-01 01:09:00+03	59800.00
9F622C	2017-07-25 08:55:00+03	40000.00
9F62AA	2017-07-06 12:27:00+03	23400.00
9F62E0	2017-08-15 07:04:00+03	25000.00
9F6306	2017-07-29 16:56:00+03	133200.00
9F63F3	2017-07-29 22:15:00+03	44600.00
9F6431	2017-08-09 09:41:00+03	46200.00
9F6467	2017-07-22 09:27:00+03	52000.00
9F6487	2017-08-09 17:42:00+03	22000.00
9F649D	2017-08-01 09:50:00+03	6700.00
9F64B4	2017-07-19 21:33:00+03	75300.00
9F6579	2017-07-15 03:15:00+03	61800.00
9F6595	2017-07-31 20:00:00+03	21400.00
9F66F3	2017-07-24 17:49:00+03	55800.00
9F66FB	2017-07-20 15:29:00+03	103800.00
9F6777	2017-07-20 13:42:00+03	52000.00
9F6786	2017-07-24 09:28:00+03	14000.00
9F67E2	2017-07-08 02:56:00+03	28800.00
9F680E	2017-08-10 13:16:00+03	273600.00
9F6826	2017-07-03 11:05:00+03	29600.00
9F682C	2017-07-02 10:01:00+03	13000.00
9F6831	2017-08-01 07:03:00+03	14400.00
9F6846	2017-07-29 04:03:00+03	32200.00
9F6930	2017-08-09 05:25:00+03	26800.00
9F693A	2017-08-11 17:19:00+03	132500.00
9F6942	2017-07-03 02:18:00+03	12600.00
9F696A	2017-07-07 12:20:00+03	31600.00
9F69CA	2017-07-23 00:05:00+03	51600.00
9F69E7	2017-07-06 13:07:00+03	23200.00
9F69E9	2017-07-17 08:13:00+03	18000.00
9F6A06	2017-08-12 08:11:00+03	29800.00
9F6AA7	2017-07-23 13:37:00+03	44800.00
9F6B9D	2017-07-29 15:30:00+03	50600.00
9F6C02	2017-08-06 10:31:00+03	13800.00
9F6C15	2017-07-15 17:46:00+03	99800.00
9F6C25	2017-07-08 12:01:00+03	84100.00
9F6D07	2017-07-28 06:08:00+03	27200.00
9F6D0F	2017-07-27 00:53:00+03	24400.00
9F6D56	2017-07-05 02:11:00+03	47500.00
9F6D5D	2017-08-13 20:36:00+03	37100.00
9F6D98	2017-08-12 01:46:00+03	34600.00
9F6D9B	2017-07-10 03:54:00+03	22600.00
9F6DBB	2017-08-01 22:33:00+03	27200.00
9F6E37	2017-07-03 02:01:00+03	106800.00
9F6E67	2017-08-01 12:28:00+03	23200.00
9F6E6E	2017-08-06 15:26:00+03	59800.00
9F6E7F	2017-08-15 11:36:00+03	53300.00
9F6E89	2017-07-17 06:19:00+03	46400.00
9F6F1A	2017-08-13 19:59:00+03	92100.00
9F6FC2	2017-08-10 15:35:00+03	62900.00
9F7014	2017-08-10 09:57:00+03	200500.00
9F702F	2017-07-12 22:14:00+03	40000.00
9F705F	2017-08-03 06:46:00+03	136200.00
9F7092	2017-07-14 10:25:00+03	75600.00
9F7178	2017-08-13 19:07:00+03	54800.00
9F7194	2017-07-04 17:59:00+03	266400.00
9F71AF	2017-07-27 03:38:00+03	107400.00
9F729F	2017-07-02 18:15:00+03	3400.00
9F7377	2017-08-02 14:35:00+03	70500.00
9F738C	2017-08-10 06:06:00+03	58700.00
9F746F	2017-06-30 07:53:00+03	189800.00
9F7485	2017-07-13 15:07:00+03	152500.00
9F74DD	2017-07-13 23:25:00+03	43600.00
9F74DF	2017-08-15 07:16:00+03	13400.00
9F74FB	2017-07-24 10:42:00+03	100600.00
9F75B0	2017-07-05 01:46:00+03	28800.00
9F75B2	2017-07-11 13:33:00+03	106900.00
9F7624	2017-08-10 08:12:00+03	64700.00
9F7641	2017-07-17 09:53:00+03	76600.00
9F7668	2017-07-18 10:31:00+03	124200.00
9F76CC	2017-06-29 19:23:00+03	46000.00
9F7762	2017-07-20 11:05:00+03	53600.00
9F77AD	2017-08-13 18:44:00+03	36200.00
9F77D8	2017-08-04 20:11:00+03	115900.00
9F77E0	2017-08-08 00:55:00+03	60400.00
9F780A	2017-07-28 11:17:00+03	43000.00
9F7835	2017-07-20 23:27:00+03	43600.00
9F7856	2017-08-10 02:39:00+03	269500.00
9F786A	2017-07-17 17:22:00+03	43600.00
9F78F3	2017-07-21 21:03:00+03	52000.00
9F791C	2017-07-28 02:32:00+03	26000.00
9F79E8	2017-08-09 09:09:00+03	40000.00
9F79F8	2017-07-30 08:45:00+03	97700.00
9F7A92	2017-06-30 04:33:00+03	28000.00
9F7AA2	2017-07-26 17:47:00+03	86600.00
9F7AE8	2017-07-09 12:42:00+03	95700.00
9F7B99	2017-07-17 14:25:00+03	27800.00
9F7BEF	2017-07-11 09:35:00+03	24400.00
9F7BF9	2017-07-28 13:46:00+03	23100.00
9F7C07	2017-07-18 20:44:00+03	68800.00
9F7C11	2017-08-10 17:54:00+03	302400.00
9F7C27	2017-07-09 16:41:00+03	179300.00
9F7C68	2017-08-14 18:22:00+03	94700.00
9F7D1C	2017-08-03 05:45:00+03	266500.00
9F7D27	2017-07-15 09:23:00+03	123000.00
9F7D2D	2017-07-09 21:58:00+03	343900.00
9F7D41	2017-08-01 20:05:00+03	43200.00
9F7D69	2017-07-09 20:24:00+03	31100.00
9F7DAC	2017-07-13 21:51:00+03	11300.00
9F7DEE	2017-06-28 01:45:00+03	36200.00
9F7E10	2017-07-19 13:05:00+03	14400.00
9F7E1A	2017-07-02 03:10:00+03	87100.00
9F7E63	2017-06-30 14:07:00+03	135400.00
9F7E7E	2017-07-25 04:56:00+03	47200.00
9F7EAA	2017-07-09 01:12:00+03	8000.00
9F7ED0	2017-07-03 22:48:00+03	24700.00
9F7F1D	2017-08-12 21:21:00+03	37200.00
9F7FA5	2017-07-14 14:52:00+03	36200.00
9F806E	2017-08-06 13:47:00+03	70400.00
9F8087	2017-07-02 10:01:00+03	26000.00
9F80D3	2017-07-17 18:47:00+03	55800.00
9F8131	2017-07-15 18:19:00+03	57400.00
9F8162	2017-08-12 05:07:00+03	33300.00
9F81A5	2017-08-10 21:50:00+03	30400.00
9F81FD	2017-07-25 16:57:00+03	12400.00
9F8262	2017-07-02 22:23:00+03	21200.00
9F82BB	2017-07-23 03:17:00+03	112000.00
9F82BF	2017-07-31 16:21:00+03	69100.00
9F82CF	2017-07-29 13:22:00+03	83000.00
9F82EA	2017-07-22 00:24:00+03	25800.00
9F832A	2017-07-16 12:15:00+03	92800.00
9F8339	2017-08-09 04:26:00+03	58000.00
9F838C	2017-07-23 06:09:00+03	100600.00
9F8420	2017-07-19 09:21:00+03	27400.00
9F8424	2017-08-15 14:54:00+03	47400.00
9F849A	2017-07-23 14:03:00+03	20400.00
9F84A1	2017-06-29 12:55:00+03	31700.00
9F84CA	2017-07-13 05:49:00+03	38800.00
9F856C	2017-08-10 15:13:00+03	117100.00
9F8623	2017-08-03 21:26:00+03	28000.00
9F8636	2017-08-07 15:53:00+03	40400.00
9F867D	2017-06-30 10:26:00+03	86600.00
9F8684	2017-08-05 12:22:00+03	23200.00
9F86AB	2017-07-25 10:37:00+03	131600.00
9F86AF	2017-07-28 20:29:00+03	38600.00
9F873F	2017-07-25 16:37:00+03	88900.00
9F8759	2017-07-06 21:36:00+03	21800.00
9F8774	2017-08-01 04:59:00+03	297500.00
9F878D	2017-08-10 09:03:00+03	21400.00
9F87BE	2017-07-29 01:22:00+03	88600.00
9F87D8	2017-07-02 18:29:00+03	131000.00
9F88AD	2017-08-02 01:42:00+03	6300.00
9F88B0	2017-08-07 07:33:00+03	120900.00
9F8904	2017-06-30 10:44:00+03	49600.00
9F890A	2017-07-30 11:25:00+03	258400.00
9F8922	2017-08-06 05:14:00+03	40000.00
9F8983	2017-08-15 02:35:00+03	44800.00
9F89B3	2017-08-10 13:32:00+03	46400.00
9F89C7	2017-07-21 02:20:00+03	47000.00
9F89F7	2017-07-13 22:58:00+03	33300.00
9F89F9	2017-07-04 03:08:00+03	53300.00
9F8A02	2017-08-11 07:27:00+03	70700.00
9F8A7A	2017-08-03 05:47:00+03	187600.00
9F8AE4	2017-08-11 06:23:00+03	52900.00
9F8B68	2017-08-10 05:28:00+03	31400.00
9F8B86	2017-07-20 05:16:00+03	49200.00
9F8C2D	2017-06-29 05:07:00+03	29600.00
9F8CD3	2017-07-11 17:49:00+03	66200.00
9F8CF9	2017-07-20 13:18:00+03	37600.00
9F8D7E	2017-07-07 18:59:00+03	19500.00
9F8D93	2017-07-14 03:55:00+03	246000.00
9F8DBB	2017-07-28 09:20:00+03	44700.00
9F8DBC	2017-07-01 03:15:00+03	33600.00
9F8DBF	2017-07-30 14:40:00+03	88800.00
9F8DFB	2017-06-28 06:40:00+03	69600.00
9F8E24	2017-07-16 00:32:00+03	31600.00
9F8E77	2017-08-08 15:47:00+03	21200.00
9F8EE3	2017-07-04 23:18:00+03	59200.00
9F8EED	2017-08-15 04:01:00+03	13400.00
9F8FB2	2017-07-20 05:40:00+03	137600.00
9F8FCC	2017-07-08 11:49:00+03	32800.00
9F8FEF	2017-07-07 19:26:00+03	171800.00
9F90FD	2017-07-19 06:13:00+03	100200.00
9F9122	2017-07-17 11:51:00+03	53600.00
9F9176	2017-07-31 21:56:00+03	59300.00
9F91A3	2017-07-31 03:18:00+03	83200.00
9F91A7	2017-07-10 17:39:00+03	12600.00
9F91C4	2017-07-17 22:10:00+03	100700.00
9F92A0	2017-08-01 12:45:00+03	23600.00
9F933A	2017-07-17 07:47:00+03	44000.00
9F934A	2017-07-09 00:38:00+03	28700.00
9F936F	2017-07-13 11:18:00+03	12600.00
9F9371	2017-08-01 20:33:00+03	52000.00
9F93C3	2017-07-30 18:54:00+03	51300.00
9F93E2	2017-07-18 22:02:00+03	6800.00
9F943A	2017-08-11 17:11:00+03	79900.00
9F9445	2017-08-07 08:56:00+03	84400.00
9F944D	2017-07-23 05:36:00+03	26000.00
9F9481	2017-07-22 05:46:00+03	28700.00
9F94AF	2017-08-09 12:47:00+03	26700.00
9F94BF	2017-07-28 19:10:00+03	121400.00
9F94C2	2017-08-15 09:33:00+03	27400.00
9F94FD	2017-07-25 21:08:00+03	113200.00
9F9562	2017-07-15 06:41:00+03	174000.00
9F9579	2017-07-09 04:18:00+03	24700.00
9F95C1	2017-08-04 02:50:00+03	393800.00
9F95D2	2017-08-02 15:40:00+03	59200.00
9F95DF	2017-08-12 01:48:00+03	72300.00
9F95F5	2017-07-15 00:52:00+03	31400.00
9F9664	2017-07-27 23:21:00+03	74400.00
9F96D8	2017-07-26 20:32:00+03	47100.00
9F971C	2017-07-28 15:52:00+03	267100.00
9F9756	2017-07-29 08:04:00+03	83000.00
9F977A	2017-08-14 14:35:00+03	133900.00
9F9845	2017-07-22 03:03:00+03	38600.00
9F9863	2017-08-02 22:34:00+03	19800.00
9F98C4	2017-08-11 14:39:00+03	396500.00
9F994E	2017-08-14 03:38:00+03	27400.00
9F9992	2017-07-12 14:50:00+03	29200.00
9F999D	2017-07-30 04:02:00+03	43000.00
9F99AA	2017-07-17 11:45:00+03	163000.00
9F99E0	2017-07-09 22:51:00+03	36200.00
9F9A31	2017-07-02 12:03:00+03	31600.00
9F9A38	2017-07-19 16:29:00+03	42700.00
9F9A77	2017-07-09 16:24:00+03	266200.00
9F9A93	2017-07-06 08:21:00+03	55800.00
9F9B36	2017-07-30 21:16:00+03	123000.00
9F9B39	2017-08-11 01:58:00+03	24000.00
9F9B59	2017-08-14 03:42:00+03	62800.00
9F9B63	2017-07-29 02:02:00+03	40800.00
9F9B8A	2017-07-06 21:32:00+03	135200.00
9F9BE2	2017-08-06 18:41:00+03	99200.00
9F9C29	2017-07-01 17:32:00+03	65900.00
9F9C2A	2017-07-15 00:59:00+03	31400.00
9F9C43	2017-08-09 13:24:00+03	19600.00
9F9C69	2017-08-11 18:28:00+03	139300.00
9F9CD6	2017-07-28 07:51:00+03	57300.00
9F9DBB	2017-07-13 05:03:00+03	23200.00
9F9E25	2017-07-22 01:14:00+03	132800.00
9F9E66	2017-07-29 17:26:00+03	88500.00
9F9E7D	2017-07-31 02:39:00+03	67600.00
9F9F03	2017-07-09 09:59:00+03	38400.00
9F9F07	2017-07-15 23:16:00+03	100600.00
9F9F4E	2017-07-12 08:20:00+03	26500.00
9F9F5E	2017-08-12 15:20:00+03	62900.00
9F9FFD	2017-07-03 20:09:00+03	54000.00
9FA010	2017-08-13 15:38:00+03	191200.00
9FA027	2017-07-12 05:50:00+03	52400.00
9FA0D3	2017-08-08 08:23:00+03	66800.00
9FA117	2017-07-29 10:49:00+03	89700.00
9FA16B	2017-07-20 06:54:00+03	57600.00
9FA174	2017-08-03 09:59:00+03	56100.00
9FA176	2017-08-13 20:05:00+03	6800.00
9FA1CD	2017-08-11 23:01:00+03	73600.00
9FA1DD	2017-07-27 06:59:00+03	313800.00
9FA214	2017-07-11 21:09:00+03	60400.00
9FA238	2017-07-12 06:17:00+03	125000.00
9FA24B	2017-07-11 13:57:00+03	66600.00
9FA257	2017-08-05 07:19:00+03	42000.00
9FA31E	2017-07-22 17:51:00+03	221500.00
9FA3AF	2017-08-12 18:25:00+03	64300.00
9FA589	2017-06-30 12:16:00+03	24800.00
9FA6E8	2017-08-09 18:40:00+03	67000.00
9FA729	2017-07-28 04:05:00+03	136000.00
9FA736	2017-07-31 19:44:00+03	35200.00
9FA73E	2017-08-15 15:53:00+03	71800.00
9FA7CF	2017-08-05 10:00:00+03	171100.00
9FA7E4	2017-08-10 18:44:00+03	31000.00
9FA800	2017-07-23 15:29:00+03	49400.00
9FA807	2017-07-27 19:41:00+03	35300.00
9FA863	2017-07-11 13:47:00+03	39500.00
9FA8B3	2017-07-10 10:04:00+03	33100.00
9FA8D3	2017-07-27 04:24:00+03	17000.00
9FA8EE	2017-07-03 15:06:00+03	75300.00
9FA8F6	2017-07-20 09:17:00+03	6800.00
9FA92D	2017-08-04 19:34:00+03	20200.00
9FA930	2017-07-23 04:25:00+03	132800.00
9FA93A	2017-07-31 11:20:00+03	234700.00
9FA985	2017-07-09 04:57:00+03	69500.00
9FA9D5	2017-07-22 05:16:00+03	28000.00
9FA9E0	2017-07-15 04:39:00+03	92200.00
9FAA61	2017-07-07 11:19:00+03	114700.00
9FAAA3	2017-07-20 17:38:00+03	16800.00
9FAADC	2017-07-17 07:48:00+03	99200.00
9FAC04	2017-07-12 12:49:00+03	335800.00
9FAC32	2017-07-28 22:10:00+03	26800.00
9FAC36	2017-08-10 20:20:00+03	36200.00
9FAC95	2017-08-01 13:17:00+03	84600.00
9FACC7	2017-07-19 13:00:00+03	62600.00
9FAD15	2017-07-28 07:59:00+03	218400.00
9FAD35	2017-07-04 01:56:00+03	14800.00
9FAD51	2017-07-26 17:52:00+03	6000.00
9FAD6E	2017-08-09 20:10:00+03	58800.00
9FAD76	2017-07-15 03:46:00+03	37300.00
9FADC2	2017-07-20 16:40:00+03	372500.00
9FAEC6	2017-07-07 17:16:00+03	32500.00
9FAED1	2017-07-14 19:03:00+03	40000.00
9FAF07	2017-08-07 10:59:00+03	34100.00
9FAF09	2017-08-01 14:19:00+03	15000.00
9FAF40	2017-07-07 14:32:00+03	27200.00
9FAF72	2017-08-12 19:45:00+03	57600.00
9FAFDA	2017-07-18 06:29:00+03	118100.00
9FB01B	2017-07-15 20:24:00+03	105400.00
9FB042	2017-07-10 05:09:00+03	32700.00
9FB058	2017-07-01 04:10:00+03	49000.00
9FB0A4	2017-07-23 14:23:00+03	86600.00
9FB0F5	2017-08-12 02:47:00+03	30800.00
9FB126	2017-07-11 17:47:00+03	55800.00
9FB199	2017-08-05 06:47:00+03	58000.00
9FB19A	2017-07-28 18:58:00+03	105600.00
9FB1CE	2017-08-10 05:56:00+03	72000.00
9FB243	2017-07-22 10:54:00+03	23400.00
9FB263	2017-07-04 02:36:00+03	28000.00
9FB2AB	2017-06-29 16:50:00+03	124200.00
9FB2C3	2017-08-13 15:08:00+03	174600.00
9FB2D2	2017-07-28 19:50:00+03	117000.00
9FB331	2017-08-12 09:31:00+03	43900.00
9FB34E	2017-07-31 07:27:00+03	13600.00
9FB393	2017-08-02 03:26:00+03	151200.00
9FB398	2017-08-01 12:01:00+03	106400.00
9FB3E0	2017-07-24 12:00:00+03	16800.00
9FB430	2017-07-02 15:07:00+03	24700.00
9FB4CF	2017-07-16 11:37:00+03	23200.00
9FB5DC	2017-07-08 03:21:00+03	6300.00
9FB613	2017-08-10 21:06:00+03	57600.00
9FB647	2017-08-11 14:24:00+03	46000.00
9FB64F	2017-07-25 00:05:00+03	20400.00
9FB682	2017-08-09 14:33:00+03	111600.00
9FB6B0	2017-08-08 11:09:00+03	138000.00
9FB6BC	2017-08-08 14:42:00+03	53300.00
9FB721	2017-07-30 00:29:00+03	14000.00
9FB74A	2017-08-10 06:13:00+03	189200.00
9FB7E5	2017-08-15 05:02:00+03	62000.00
9FB801	2017-07-31 07:49:00+03	27300.00
9FB835	2017-08-13 06:10:00+03	67200.00
9FB905	2017-07-23 22:11:00+03	41400.00
9FB918	2017-07-05 00:48:00+03	250500.00
9FB92C	2017-07-28 08:07:00+03	17200.00
9FB948	2017-07-07 03:27:00+03	32200.00
9FB9BB	2017-07-05 09:44:00+03	51600.00
9FB9CF	2017-07-07 20:01:00+03	196800.00
9FBAA2	2017-07-06 21:25:00+03	36200.00
9FBACA	2017-08-13 14:35:00+03	14800.00
9FBB43	2017-07-16 14:27:00+03	133200.00
9FBB5F	2017-08-11 02:27:00+03	112000.00
9FBBCF	2017-07-22 03:23:00+03	63700.00
9FBBD9	2017-07-14 03:11:00+03	65600.00
9FBCB8	2017-08-13 18:30:00+03	38400.00
9FBD1E	2017-07-24 00:43:00+03	48800.00
9FBD8D	2017-07-12 10:18:00+03	94800.00
9FBDBA	2017-07-12 20:58:00+03	54800.00
9FBE03	2017-07-27 17:54:00+03	578200.00
9FBE0B	2017-07-19 20:14:00+03	109600.00
9FBEA0	2017-08-07 18:35:00+03	49200.00
9FBEB5	2017-08-14 01:07:00+03	18900.00
9FBEB8	2017-07-31 00:53:00+03	27200.00
9FBEC9	2017-07-17 02:58:00+03	14400.00
9FBED9	2017-07-06 02:29:00+03	138400.00
9FBF4C	2017-07-08 03:02:00+03	207300.00
9FBF54	2017-07-10 22:30:00+03	67600.00
9FBFD6	2017-07-26 19:02:00+03	31600.00
9FBFD7	2017-07-31 00:19:00+03	85400.00
9FBFE7	2017-08-12 23:32:00+03	112000.00
9FBFFC	2017-07-11 17:02:00+03	113200.00
9FC031	2017-08-03 04:43:00+03	58900.00
9FC0D0	2017-08-04 10:21:00+03	12600.00
9FC0D2	2017-08-13 06:43:00+03	86400.00
9FC14E	2017-08-13 21:05:00+03	32800.00
9FC195	2017-07-18 05:28:00+03	168000.00
9FC1DD	2017-08-04 14:16:00+03	28000.00
9FC1ED	2017-08-15 02:06:00+03	103000.00
9FC231	2017-07-24 13:01:00+03	14800.00
9FC2D4	2017-07-07 16:20:00+03	56600.00
9FC2E2	2017-07-29 20:34:00+03	14000.00
9FC2E5	2017-07-20 06:54:00+03	16400.00
9FC322	2017-07-03 20:43:00+03	101400.00
9FC40A	2017-07-08 23:47:00+03	56000.00
9FC478	2017-07-30 01:16:00+03	33800.00
9FC4DD	2017-08-15 07:40:00+03	135400.00
9FC537	2017-07-23 23:33:00+03	92400.00
9FC564	2017-08-01 12:42:00+03	18000.00
9FC5DA	2017-06-30 01:29:00+03	460000.00
9FC5ED	2017-07-28 18:11:00+03	52800.00
9FC5F3	2017-07-22 01:59:00+03	10800.00
9FC680	2017-08-10 07:39:00+03	10800.00
9FC6B0	2017-07-26 14:37:00+03	545500.00
9FC6F5	2017-06-29 06:01:00+03	84000.00
9FC76C	2017-07-29 19:19:00+03	69600.00
9FC785	2017-07-22 16:05:00+03	21800.00
9FC7E7	2017-08-11 09:52:00+03	49100.00
9FC844	2017-07-04 23:31:00+03	57600.00
9FC84A	2017-08-14 00:39:00+03	20400.00
9FC8B8	2017-07-02 12:14:00+03	133100.00
9FC937	2017-07-06 21:42:00+03	32200.00
9FC93D	2017-06-29 17:31:00+03	64700.00
9FC950	2017-08-05 20:09:00+03	56000.00
9FC954	2017-07-18 03:36:00+03	27700.00
9FC971	2017-08-08 07:30:00+03	35600.00
9FC9AF	2017-07-19 20:27:00+03	52000.00
9FCA99	2017-08-01 19:44:00+03	405600.00
9FCACF	2017-07-18 16:30:00+03	24800.00
9FCAFF	2017-08-08 08:54:00+03	199700.00
9FCB0B	2017-07-09 16:43:00+03	29400.00
9FCB84	2017-07-13 23:11:00+03	168700.00
9FCC58	2017-07-31 22:33:00+03	194800.00
9FCD8D	2017-08-05 13:32:00+03	73300.00
9FCDA5	2017-08-01 20:11:00+03	369000.00
9FCDB2	2017-08-11 00:07:00+03	152300.00
9FCEDD	2017-08-14 20:52:00+03	28800.00
9FCF64	2017-07-16 02:07:00+03	15400.00
9FCFA0	2017-07-03 00:02:00+03	101200.00
9FD002	2017-07-07 14:40:00+03	27900.00
9FD087	2017-07-20 07:48:00+03	154400.00
9FD1D7	2017-08-07 17:43:00+03	28300.00
9FD23C	2017-07-15 08:28:00+03	75200.00
9FD2F2	2017-08-04 21:14:00+03	166000.00
9FD32D	2017-07-04 11:09:00+03	35600.00
9FD333	2017-07-07 06:49:00+03	78900.00
9FD35B	2017-07-15 00:30:00+03	39800.00
9FD35C	2017-08-05 08:33:00+03	20400.00
9FD3B6	2017-07-28 05:45:00+03	149800.00
9FD3ED	2017-07-23 13:00:00+03	51900.00
9FD3FE	2017-08-07 23:00:00+03	19600.00
9FD421	2017-08-06 04:43:00+03	56000.00
9FD464	2017-08-11 14:28:00+03	17800.00
9FD4AD	2017-07-23 06:38:00+03	62600.00
9FD509	2017-08-09 05:57:00+03	26700.00
9FD52B	2017-07-30 10:31:00+03	43200.00
9FD54A	2017-07-07 17:17:00+03	20400.00
9FD575	2017-07-31 23:23:00+03	413400.00
9FD584	2017-08-12 03:09:00+03	95600.00
9FD5D5	2017-07-01 00:36:00+03	72400.00
9FD656	2017-08-11 14:12:00+03	74900.00
9FD65E	2017-07-19 03:09:00+03	46300.00
9FD68D	2017-08-03 18:33:00+03	115800.00
9FD698	2017-07-30 06:14:00+03	13600.00
9FD6AD	2017-07-17 09:09:00+03	58700.00
9FD6B7	2017-07-09 11:46:00+03	175700.00
9FD6D7	2017-07-26 22:15:00+03	19100.00
9FD70E	2017-08-04 07:32:00+03	13800.00
9FD723	2017-07-25 23:05:00+03	46700.00
9FD74F	2017-08-10 00:41:00+03	105600.00
9FD795	2017-07-17 00:20:00+03	55400.00
9FD798	2017-07-14 21:36:00+03	74000.00
9FD7A6	2017-07-27 23:31:00+03	13700.00
9FD7AB	2017-07-09 19:33:00+03	16800.00
9FD7B0	2017-08-09 09:36:00+03	131100.00
9FD833	2017-07-31 13:31:00+03	13600.00
9FD8FC	2017-07-04 19:32:00+03	23400.00
9FD901	2017-08-14 22:32:00+03	30200.00
9FD961	2017-07-26 21:20:00+03	256300.00
9FD9D1	2017-08-07 16:40:00+03	62800.00
9FDA62	2017-06-27 08:21:00+03	55800.00
9FDA95	2017-07-13 02:07:00+03	72400.00
9FDAB7	2017-07-04 21:58:00+03	48500.00
9FDAB8	2017-07-31 15:43:00+03	36200.00
9FDB16	2017-08-02 17:11:00+03	103400.00
9FDB25	2017-07-12 18:09:00+03	76200.00
9FDB3C	2017-07-24 19:18:00+03	86600.00
9FDB82	2017-07-21 05:48:00+03	46900.00
9FDB83	2017-07-25 11:49:00+03	165000.00
9FDBF8	2017-08-01 01:15:00+03	169900.00
9FDC15	2017-07-06 16:52:00+03	73200.00
9FDC1D	2017-08-06 22:43:00+03	31400.00
9FDC70	2017-07-28 01:27:00+03	71400.00
9FDD88	2017-08-02 09:58:00+03	97400.00
9FDDB6	2017-08-05 06:38:00+03	57600.00
9FDDE6	2017-07-16 11:12:00+03	29600.00
9FDDF9	2017-08-08 01:18:00+03	42800.00
9FDEB8	2017-08-06 10:43:00+03	88100.00
9FDF12	2017-07-07 13:59:00+03	40400.00
9FDF85	2017-07-02 11:48:00+03	68200.00
9FDF8A	2017-07-14 22:40:00+03	62000.00
9FDFCA	2017-07-18 22:44:00+03	25600.00
9FDFD1	2017-07-06 00:29:00+03	396200.00
9FE0A1	2017-08-11 14:20:00+03	88500.00
9FE0B7	2017-07-20 22:36:00+03	111900.00
9FE0C7	2017-07-22 16:26:00+03	12600.00
9FE0DC	2017-08-05 17:50:00+03	56000.00
9FE0FF	2017-08-07 07:20:00+03	79200.00
9FE144	2017-07-12 18:59:00+03	63200.00
9FE1AD	2017-07-22 17:42:00+03	68100.00
9FE1FA	2017-08-02 04:39:00+03	86300.00
9FE20C	2017-07-18 05:44:00+03	88900.00
9FE27C	2017-07-23 04:48:00+03	21400.00
9FE303	2017-07-31 05:08:00+03	47200.00
9FE304	2017-07-26 22:54:00+03	56600.00
9FE33F	2017-08-02 01:58:00+03	56000.00
9FE362	2017-07-07 09:41:00+03	32800.00
9FE371	2017-07-04 23:34:00+03	86400.00
9FE381	2017-08-09 07:21:00+03	119700.00
9FE38A	2017-07-14 00:16:00+03	58000.00
9FE3D1	2017-08-14 17:03:00+03	20600.00
9FE417	2017-07-15 08:02:00+03	81300.00
9FE42E	2017-08-10 09:28:00+03	201100.00
9FE460	2017-06-29 16:34:00+03	47100.00
9FE56B	2017-07-01 01:17:00+03	28000.00
9FE59E	2017-08-02 06:10:00+03	202700.00
9FE5A5	2017-07-27 20:09:00+03	126600.00
9FE5B6	2017-08-14 12:23:00+03	108800.00
9FE5DE	2017-07-29 03:33:00+03	6000.00
9FE5E8	2017-07-30 13:40:00+03	16400.00
9FE655	2017-08-04 20:45:00+03	23600.00
9FE66A	2017-07-21 21:41:00+03	271100.00
9FE6CA	2017-08-02 21:14:00+03	14400.00
9FE6D4	2017-08-10 06:27:00+03	97900.00
9FE700	2017-06-27 06:31:00+03	28000.00
9FE702	2017-07-07 06:04:00+03	56000.00
9FE72C	2017-08-01 09:31:00+03	171300.00
9FE81B	2017-07-10 04:26:00+03	7200.00
9FE81F	2017-07-07 06:32:00+03	8200.00
9FE8CB	2017-07-08 14:23:00+03	119800.00
9FE912	2017-08-03 11:28:00+03	266400.00
9FE934	2017-08-01 09:24:00+03	6300.00
9FE961	2017-07-20 23:16:00+03	81300.00
9FE988	2017-07-05 23:48:00+03	28800.00
9FE9ED	2017-08-14 11:18:00+03	35400.00
9FEA25	2017-07-06 21:09:00+03	24400.00
9FEA34	2017-07-07 13:36:00+03	87200.00
9FEA48	2017-08-08 17:28:00+03	48800.00
9FEA71	2017-08-02 12:20:00+03	273200.00
9FEAB2	2017-08-07 18:56:00+03	45600.00
9FEBBD	2017-07-14 10:28:00+03	140100.00
9FEBF4	2017-07-21 08:09:00+03	84100.00
9FEC06	2017-07-12 07:59:00+03	37700.00
9FEC18	2017-07-12 21:03:00+03	99200.00
9FEC20	2017-08-05 17:49:00+03	44600.00
9FEC2C	2017-08-01 12:35:00+03	21800.00
9FECEA	2017-08-13 17:05:00+03	67600.00
9FED04	2017-08-02 08:47:00+03	274200.00
9FED42	2017-07-30 05:35:00+03	56000.00
9FED48	2017-08-01 12:20:00+03	63200.00
9FED80	2017-07-20 03:42:00+03	28200.00
9FEDBB	2017-08-10 10:07:00+03	44500.00
9FEDD0	2017-07-04 08:34:00+03	46700.00
9FEE02	2017-07-12 02:35:00+03	23600.00
9FEE7B	2017-08-06 12:31:00+03	10800.00
9FEEEA	2017-08-09 06:00:00+03	46200.00
9FEF65	2017-07-24 20:05:00+03	13600.00
9FEF8A	2017-07-13 15:07:00+03	67600.00
9FEFCC	2017-07-03 01:32:00+03	40600.00
9FEFFE	2017-07-18 23:50:00+03	56600.00
9FF041	2017-08-14 11:49:00+03	49200.00
9FF0AB	2017-08-11 18:47:00+03	131000.00
9FF0CE	2017-08-12 11:01:00+03	16000.00
9FF0D0	2017-08-11 08:08:00+03	133100.00
9FF145	2017-07-11 13:38:00+03	123000.00
9FF157	2017-07-04 00:31:00+03	6600.00
9FF161	2017-07-12 10:01:00+03	92400.00
9FF179	2017-07-06 03:22:00+03	17000.00
9FF250	2017-08-06 19:23:00+03	44400.00
9FF296	2017-08-09 04:27:00+03	28000.00
9FF298	2017-07-14 20:24:00+03	119600.00
9FF2A3	2017-07-19 16:56:00+03	69500.00
9FF316	2017-07-20 21:07:00+03	131100.00
9FF362	2017-07-20 19:19:00+03	43200.00
9FF367	2017-07-26 22:12:00+03	67600.00
9FF37A	2017-08-12 12:59:00+03	45200.00
9FF38E	2017-08-11 20:40:00+03	30200.00
9FF391	2017-08-01 10:22:00+03	410500.00
9FF3B0	2017-07-06 00:28:00+03	56000.00
9FF3D3	2017-07-22 02:46:00+03	79900.00
9FF40A	2017-07-23 16:06:00+03	42800.00
9FF445	2017-07-09 15:22:00+03	136800.00
9FF44F	2017-07-30 04:42:00+03	271100.00
9FF577	2017-07-05 04:39:00+03	73500.00
9FF5C1	2017-07-02 13:15:00+03	78300.00
9FF60C	2017-08-03 09:18:00+03	31100.00
9FF634	2017-07-07 00:48:00+03	43100.00
9FF656	2017-08-07 15:41:00+03	112000.00
9FF659	2017-07-09 13:12:00+03	122200.00
9FF693	2017-07-15 08:18:00+03	14000.00
9FF739	2017-06-29 12:01:00+03	31600.00
9FF73E	2017-07-09 01:27:00+03	51800.00
9FF7EA	2017-08-03 16:23:00+03	148200.00
9FF807	2017-07-07 07:45:00+03	90000.00
9FF818	2017-07-04 03:29:00+03	21400.00
9FF87A	2017-07-30 17:10:00+03	59600.00
9FF8ED	2017-08-05 17:08:00+03	34800.00
9FF9C0	2017-08-12 00:05:00+03	55400.00
9FFA35	2017-08-08 16:39:00+03	81600.00
9FFA54	2017-07-09 16:27:00+03	246000.00
9FFAA9	2017-08-15 13:20:00+03	289800.00
9FFB59	2017-08-09 04:22:00+03	36200.00
9FFB60	2017-07-03 23:45:00+03	61700.00
9FFB73	2017-07-11 01:47:00+03	55800.00
9FFBB2	2017-08-04 17:43:00+03	95400.00
9FFBCD	2017-08-12 09:34:00+03	170600.00
9FFBFB	2017-07-14 09:43:00+03	14900.00
9FFC31	2017-07-13 07:18:00+03	85000.00
9FFC37	2017-07-14 20:27:00+03	101100.00
9FFC5E	2017-08-14 19:23:00+03	123000.00
9FFCBE	2017-07-01 13:31:00+03	67200.00
9FFCCE	2017-07-26 23:46:00+03	88600.00
9FFD6A	2017-07-07 10:59:00+03	146500.00
9FFDFF	2017-08-10 06:07:00+03	135600.00
9FFE8A	2017-07-11 18:14:00+03	25100.00
9FFE9A	2017-07-06 16:48:00+03	24400.00
9FFF0D	2017-07-11 19:19:00+03	51200.00
9FFF13	2017-07-17 11:08:00+03	40000.00
9FFF3B	2017-08-01 09:49:00+03	113700.00
9FFF67	2017-08-09 08:18:00+03	75300.00
9FFF98	2017-07-17 07:33:00+03	6300.00
9FFFBC	2017-08-12 17:52:00+03	79500.00
A00070	2017-07-19 11:53:00+03	23100.00
A00083	2017-07-31 06:06:00+03	86800.00
A0008F	2017-08-07 21:01:00+03	43200.00
A000F3	2017-07-23 10:37:00+03	124200.00
A000F8	2017-08-04 10:06:00+03	59200.00
A001F5	2017-07-20 04:15:00+03	40000.00
A0022B	2017-07-14 21:29:00+03	37900.00
A0025F	2017-07-06 03:49:00+03	99200.00
A0028B	2017-08-06 05:45:00+03	13600.00
A002E7	2017-08-13 06:11:00+03	25800.00
A00378	2017-07-14 23:04:00+03	63200.00
A003D6	2017-07-25 18:44:00+03	62800.00
A003E9	2017-08-04 12:37:00+03	21400.00
A00435	2017-07-21 22:57:00+03	46000.00
A00449	2017-07-18 20:11:00+03	55500.00
A004BC	2017-07-20 21:45:00+03	102100.00
A004F4	2017-08-01 15:56:00+03	52400.00
A00525	2017-07-20 05:47:00+03	40000.00
A00551	2017-07-09 00:48:00+03	45100.00
A00619	2017-07-06 05:18:00+03	62800.00
A00621	2017-08-06 09:25:00+03	16400.00
A0062D	2017-07-22 05:13:00+03	101200.00
A0063D	2017-08-04 10:17:00+03	37200.00
A00687	2017-08-08 03:53:00+03	93400.00
A006B7	2017-07-18 05:05:00+03	26600.00
A006DE	2017-08-11 17:21:00+03	166900.00
A006EF	2017-08-04 02:01:00+03	135600.00
A006FE	2017-08-09 21:49:00+03	31200.00
A0072F	2017-08-05 14:34:00+03	75600.00
A00740	2017-07-12 10:02:00+03	23400.00
A00755	2017-07-30 22:10:00+03	398600.00
A0075D	2017-07-05 13:36:00+03	131600.00
A007D0	2017-07-21 10:25:00+03	28000.00
A007E0	2017-08-13 17:03:00+03	27900.00
A00822	2017-07-24 19:24:00+03	46500.00
A0083E	2017-07-23 14:01:00+03	15000.00
A00930	2017-07-13 11:09:00+03	64500.00
A00994	2017-07-12 21:08:00+03	86400.00
A00999	2017-08-02 09:47:00+03	55600.00
A00A4C	2017-07-05 05:54:00+03	40000.00
A00A69	2017-07-20 10:12:00+03	79600.00
A00A98	2017-08-15 07:42:00+03	13400.00
A00B59	2017-07-08 13:58:00+03	34000.00
A00B70	2017-08-09 14:01:00+03	55800.00
A00BCB	2017-08-09 03:57:00+03	286700.00
A00BDF	2017-07-08 09:31:00+03	78300.00
A00BE6	2017-07-18 09:46:00+03	56000.00
A00BF6	2017-07-29 19:17:00+03	25600.00
A00C0B	2017-07-18 19:14:00+03	16000.00
A00C1A	2017-08-09 00:40:00+03	25200.00
A00C45	2017-07-20 21:34:00+03	136800.00
A00CBC	2017-07-01 21:48:00+03	27200.00
A00CD7	2017-08-09 06:22:00+03	37500.00
A00D26	2017-07-20 12:06:00+03	34000.00
A00D4E	2017-07-06 20:09:00+03	53600.00
A00D7F	2017-08-08 06:37:00+03	60700.00
A00D81	2017-08-11 18:05:00+03	37700.00
A00DCD	2017-07-11 19:27:00+03	41200.00
A00E6B	2017-07-02 23:03:00+03	46400.00
A00F38	2017-07-30 23:14:00+03	52000.00
A00FA1	2017-08-11 03:38:00+03	12200.00
A00FB0	2017-07-14 15:52:00+03	132800.00
A00FC9	2017-07-11 09:13:00+03	28000.00
A0101C	2017-07-23 03:31:00+03	23200.00
A01091	2017-08-04 03:19:00+03	29400.00
A0111F	2017-08-08 02:10:00+03	12600.00
A01125	2017-08-13 17:59:00+03	30200.00
A01145	2017-07-14 23:21:00+03	85800.00
A01163	2017-08-08 09:54:00+03	24300.00
A01202	2017-08-11 00:13:00+03	57500.00
A0124A	2017-07-22 16:00:00+03	191200.00
A012A0	2017-07-31 11:31:00+03	93500.00
A012A7	2017-08-12 11:37:00+03	148200.00
A012C5	2017-08-13 22:16:00+03	6300.00
A013AF	2017-07-01 16:52:00+03	21800.00
A013CB	2017-07-25 17:27:00+03	40800.00
A0145F	2017-08-12 03:30:00+03	136500.00
A0148C	2017-07-26 19:55:00+03	155600.00
A014B8	2017-08-11 13:57:00+03	67600.00
A014BA	2017-07-21 14:30:00+03	28000.00
A014CA	2017-07-04 17:31:00+03	20400.00
A01509	2017-07-30 11:53:00+03	40000.00
A01529	2017-07-25 01:20:00+03	26800.00
A01548	2017-07-17 06:26:00+03	46300.00
A0154F	2017-08-02 11:19:00+03	40700.00
A01558	2017-08-04 05:41:00+03	75300.00
A01569	2017-07-07 13:54:00+03	48200.00
A015C5	2017-08-01 07:11:00+03	6000.00
A015DA	2017-08-03 04:40:00+03	55800.00
A01633	2017-06-29 09:52:00+03	122400.00
A0165E	2017-07-15 05:58:00+03	306600.00
A01665	2017-08-11 22:14:00+03	113600.00
A01681	2017-08-09 07:54:00+03	23600.00
A01682	2017-08-04 20:53:00+03	86300.00
A0172D	2017-07-25 04:51:00+03	32700.00
A01747	2017-07-24 20:16:00+03	28800.00
A01752	2017-07-09 20:30:00+03	31300.00
A01772	2017-07-14 13:22:00+03	62600.00
A01775	2017-08-02 19:57:00+03	114700.00
A017FD	2017-08-08 21:36:00+03	25600.00
A0183C	2017-07-25 19:23:00+03	170700.00
A0184E	2017-07-13 01:20:00+03	131100.00
A0187C	2017-07-26 09:33:00+03	44000.00
A01917	2017-07-25 08:32:00+03	289300.00
A01997	2017-07-26 04:22:00+03	52400.00
A019A7	2017-07-31 12:49:00+03	71900.00
A019C8	2017-07-17 14:32:00+03	256700.00
A019D3	2017-07-09 07:09:00+03	36000.00
A019DD	2017-07-19 17:24:00+03	150600.00
A01A00	2017-07-30 09:35:00+03	30400.00
A01A08	2017-08-13 12:42:00+03	139500.00
A01A19	2017-07-25 20:51:00+03	66800.00
A01A3B	2017-07-13 23:23:00+03	71900.00
A01A3D	2017-07-15 17:15:00+03	73500.00
A01A43	2017-07-27 17:36:00+03	56000.00
A01AE0	2017-07-05 21:34:00+03	62600.00
A01B19	2017-08-06 20:25:00+03	43600.00
A01B22	2017-07-07 18:07:00+03	14400.00
A01B75	2017-08-01 02:15:00+03	30800.00
A01C35	2017-08-01 09:30:00+03	31600.00
A01D4B	2017-08-10 04:23:00+03	291700.00
A01DDE	2017-07-23 00:04:00+03	86800.00
A01E4C	2017-07-18 08:02:00+03	94000.00
A01E76	2017-07-08 06:53:00+03	50600.00
A01EA8	2017-07-31 09:55:00+03	92400.00
A01F45	2017-07-24 09:35:00+03	186900.00
A01F67	2017-07-13 08:35:00+03	27400.00
A01F74	2017-07-09 18:29:00+03	25800.00
A01FA3	2017-07-01 22:05:00+03	68800.00
A0202D	2017-07-09 02:04:00+03	154500.00
A0205A	2017-07-10 12:33:00+03	35600.00
A02098	2017-07-04 19:11:00+03	31400.00
A020A0	2017-07-30 22:41:00+03	134200.00
A020CC	2017-07-04 14:18:00+03	198600.00
A020DC	2017-07-15 11:33:00+03	14400.00
A02145	2017-07-13 00:03:00+03	168000.00
A0215A	2017-08-12 16:18:00+03	18700.00
A021E0	2017-07-23 02:32:00+03	34000.00
A02231	2017-07-26 14:14:00+03	386300.00
A0228F	2017-07-24 13:52:00+03	63200.00
A0229B	2017-08-10 17:36:00+03	14400.00
A022D1	2017-07-03 06:33:00+03	42800.00
A023AC	2017-08-12 11:17:00+03	149200.00
A02478	2017-07-10 01:43:00+03	49600.00
A02493	2017-07-17 05:18:00+03	39000.00
A0249D	2017-07-23 18:23:00+03	18800.00
A024BD	2017-08-01 13:08:00+03	123000.00
A024C4	2017-07-11 16:15:00+03	115700.00
A024FA	2017-08-07 12:51:00+03	38800.00
A02538	2017-07-15 18:03:00+03	170700.00
A0256D	2017-08-12 16:54:00+03	24000.00
A025EF	2017-07-22 12:06:00+03	20400.00
A025F3	2017-07-20 19:00:00+03	291500.00
A02628	2017-07-28 10:47:00+03	6000.00
A02633	2017-08-09 22:17:00+03	69900.00
A0263A	2017-08-07 16:13:00+03	22000.00
A02665	2017-07-04 05:01:00+03	57500.00
A02671	2017-07-21 08:24:00+03	43600.00
A026C2	2017-08-10 13:48:00+03	246000.00
A026F2	2017-07-17 00:02:00+03	21800.00
A02787	2017-07-30 08:42:00+03	119500.00
A027E9	2017-07-06 03:46:00+03	170800.00
A02838	2017-07-09 07:54:00+03	125700.00
A0289E	2017-07-18 02:31:00+03	14000.00
A02911	2017-08-12 05:53:00+03	86600.00
A02949	2017-08-15 04:53:00+03	50200.00
A02961	2017-07-11 07:45:00+03	118600.00
A02A15	2017-07-24 15:44:00+03	375200.00
A02A63	2017-07-14 03:45:00+03	23600.00
A02AC0	2017-08-04 15:00:00+03	38800.00
A02AC4	2017-07-23 05:33:00+03	89600.00
A02ACF	2017-07-05 10:22:00+03	48500.00
A02B0D	2017-08-13 06:09:00+03	28800.00
A02B14	2017-07-18 17:57:00+03	88500.00
A02B1B	2017-08-09 21:28:00+03	54500.00
A02B29	2017-07-05 07:49:00+03	39200.00
A02B99	2017-07-18 03:52:00+03	109500.00
A02C16	2017-08-06 04:05:00+03	24300.00
A02C8D	2017-07-19 08:07:00+03	89600.00
A02CE6	2017-08-12 01:30:00+03	75300.00
A02D17	2017-08-11 23:58:00+03	26000.00
A02D9F	2017-07-13 05:58:00+03	38800.00
A02E30	2017-07-30 01:21:00+03	26800.00
A02E5D	2017-07-03 22:16:00+03	26800.00
A02EAF	2017-07-30 07:47:00+03	70800.00
A02F81	2017-07-09 12:33:00+03	64700.00
A02FBA	2017-08-14 21:09:00+03	59800.00
A02FF3	2017-08-10 17:27:00+03	99200.00
A02FF4	2017-08-14 07:00:00+03	25200.00
A02FF9	2017-08-12 22:20:00+03	67700.00
A03014	2017-08-15 11:50:00+03	43500.00
A0302F	2017-07-07 00:06:00+03	13000.00
A0309F	2017-08-03 12:45:00+03	14000.00
A0310E	2017-07-20 07:07:00+03	38900.00
A03130	2017-07-12 06:48:00+03	56000.00
A03137	2017-08-06 16:05:00+03	37700.00
A0318A	2017-07-09 16:52:00+03	28000.00
A031E3	2017-07-01 05:42:00+03	16000.00
A03205	2017-07-03 00:52:00+03	44800.00
A03244	2017-08-06 05:06:00+03	63200.00
A03316	2017-08-05 02:32:00+03	50600.00
A0332C	2017-07-27 12:38:00+03	246000.00
A033E5	2017-07-19 01:16:00+03	6000.00
A033F2	2017-08-04 15:13:00+03	54800.00
A03429	2017-08-02 03:56:00+03	124200.00
A0342B	2017-07-13 13:09:00+03	128800.00
A0345A	2017-07-13 08:19:00+03	29200.00
A0351E	2017-07-03 13:44:00+03	48300.00
A03587	2017-07-12 08:37:00+03	23200.00
A03595	2017-07-21 06:39:00+03	75300.00
A035B6	2017-07-02 13:44:00+03	46300.00
A035CD	2017-08-03 15:18:00+03	39200.00
A03710	2017-07-08 07:07:00+03	23400.00
A03712	2017-07-20 07:22:00+03	123000.00
A0371B	2017-07-22 19:49:00+03	67000.00
A03775	2017-07-09 18:41:00+03	96200.00
A03797	2017-07-18 20:43:00+03	148800.00
A037F1	2017-08-14 04:23:00+03	23600.00
A037F7	2017-08-08 01:49:00+03	369000.00
A03862	2017-08-04 22:05:00+03	139400.00
A0387A	2017-07-12 19:56:00+03	187600.00
A038A5	2017-07-13 23:55:00+03	31100.00
A038E6	2017-08-08 02:36:00+03	46300.00
A03912	2017-07-03 22:39:00+03	32200.00
A0391E	2017-07-10 17:42:00+03	111600.00
A03928	2017-08-06 20:19:00+03	137700.00
A03968	2017-07-12 11:18:00+03	86800.00
A039A6	2017-08-03 10:04:00+03	208000.00
A039C1	2017-06-30 07:22:00+03	52000.00
A03A01	2017-07-18 06:06:00+03	30200.00
A03A1A	2017-07-07 21:28:00+03	54400.00
A03A4B	2017-07-20 11:29:00+03	79000.00
A03A70	2017-08-11 07:53:00+03	6800.00
A03B04	2017-07-21 20:29:00+03	67200.00
A03B19	2017-08-11 09:57:00+03	162000.00
A03B9A	2017-08-09 02:06:00+03	31000.00
A03BA7	2017-07-09 08:53:00+03	26200.00
A03BFE	2017-06-29 02:59:00+03	50000.00
A03C19	2017-07-07 11:25:00+03	81700.00
A03C6E	2017-07-31 20:32:00+03	56000.00
A03C7F	2017-06-29 02:01:00+03	323900.00
A03C81	2017-08-08 08:05:00+03	13400.00
A03CB9	2017-07-05 11:34:00+03	192900.00
A03CD2	2017-07-05 19:13:00+03	69000.00
A03D26	2017-07-17 10:05:00+03	57400.00
A03D50	2017-07-11 19:56:00+03	78800.00
A03DC7	2017-07-30 21:36:00+03	89700.00
A03DC9	2017-08-10 05:18:00+03	20400.00
A03DCC	2017-08-02 03:57:00+03	151200.00
A03DE9	2017-06-30 14:43:00+03	211600.00
A03DEB	2017-07-16 07:53:00+03	62800.00
A03DF7	2017-08-11 22:10:00+03	75300.00
A03E33	2017-07-13 11:44:00+03	43600.00
A03E49	2017-07-15 23:49:00+03	79000.00
A03E69	2017-07-27 05:46:00+03	60800.00
A03E98	2017-07-06 09:16:00+03	127400.00
A03EB5	2017-07-20 22:11:00+03	498200.00
A03F9B	2017-07-21 00:45:00+03	14400.00
A03FF7	2017-07-25 05:01:00+03	181600.00
A03FFC	2017-08-05 19:38:00+03	38800.00
A04071	2017-07-23 07:49:00+03	36800.00
A04089	2017-07-02 09:17:00+03	41600.00
A040B3	2017-07-19 22:52:00+03	28800.00
A040BB	2017-08-07 18:45:00+03	57500.00
A0410E	2017-07-07 06:55:00+03	141700.00
A0413C	2017-08-04 12:43:00+03	188000.00
A041DC	2017-07-12 01:09:00+03	26800.00
A041F2	2017-07-04 16:29:00+03	6000.00
A0423C	2017-07-27 12:32:00+03	110500.00
A0425C	2017-08-05 16:11:00+03	138500.00
A04288	2017-08-10 18:48:00+03	139300.00
A0428D	2017-07-08 18:20:00+03	133200.00
A042A3	2017-07-22 21:08:00+03	378400.00
A042BE	2017-08-06 15:44:00+03	58400.00
A042CB	2017-08-03 00:05:00+03	210600.00
A042DD	2017-07-09 03:13:00+03	65100.00
A04346	2017-08-06 19:45:00+03	422700.00
A0437C	2017-07-28 21:42:00+03	14800.00
A0443F	2017-08-11 20:51:00+03	8000.00
A044A3	2017-08-02 02:34:00+03	29600.00
A044D0	2017-07-08 01:39:00+03	70700.00
A04524	2017-08-07 11:54:00+03	199600.00
A04556	2017-07-28 13:40:00+03	19600.00
A04561	2017-07-20 05:23:00+03	14000.00
A04564	2017-07-29 12:51:00+03	36000.00
A045EE	2017-07-15 14:01:00+03	23400.00
A04673	2017-07-03 01:48:00+03	22000.00
A0469F	2017-07-27 08:37:00+03	41200.00
A046B8	2017-07-05 06:22:00+03	11100.00
A0474B	2017-08-02 20:54:00+03	28000.00
A04751	2017-07-22 19:23:00+03	23400.00
A04756	2017-07-23 03:36:00+03	92800.00
A04829	2017-08-05 07:51:00+03	37500.00
A0487C	2017-07-29 21:57:00+03	57400.00
A048FE	2017-07-09 19:46:00+03	109200.00
A04902	2017-08-11 20:00:00+03	243600.00
A04922	2017-07-04 04:07:00+03	11800.00
A04934	2017-07-11 03:52:00+03	75800.00
A04999	2017-08-05 00:20:00+03	27400.00
A049AF	2017-08-03 02:27:00+03	49300.00
A049DF	2017-07-27 08:26:00+03	135400.00
A04AC1	2017-07-16 23:22:00+03	6800.00
A04B6C	2017-08-08 23:15:00+03	147800.00
A04BBD	2017-08-04 20:12:00+03	71900.00
A04BF1	2017-07-06 10:37:00+03	71900.00
A04BF2	2017-07-01 14:15:00+03	153300.00
A04C48	2017-07-18 03:21:00+03	46000.00
A04CD3	2017-07-24 07:51:00+03	51900.00
A04D9C	2017-08-08 06:14:00+03	134700.00
A04DDC	2017-07-30 13:44:00+03	168000.00
A04E72	2017-07-04 08:01:00+03	63200.00
A04ED0	2017-07-05 17:11:00+03	6300.00
A04F3A	2017-08-10 07:40:00+03	43400.00
A05001	2017-08-06 17:45:00+03	37900.00
A05050	2017-07-13 23:47:00+03	52600.00
A05074	2017-07-09 13:28:00+03	37700.00
A05086	2017-07-25 18:27:00+03	44600.00
A050B7	2017-07-06 05:31:00+03	55800.00
A05136	2017-07-28 21:30:00+03	99200.00
A05139	2017-07-05 23:21:00+03	32200.00
A05206	2017-07-13 02:38:00+03	89600.00
A05217	2017-08-11 18:03:00+03	40800.00
A052C9	2017-08-15 05:05:00+03	86500.00
A052FC	2017-06-30 00:42:00+03	70700.00
A05301	2017-07-15 11:31:00+03	40400.00
A053C8	2017-07-06 09:42:00+03	101800.00
A0543A	2017-07-28 07:48:00+03	43500.00
A05523	2017-07-26 03:54:00+03	140900.00
A05541	2017-08-05 01:42:00+03	39400.00
A05542	2017-07-14 05:48:00+03	85000.00
A055AF	2017-07-30 08:52:00+03	64800.00
A0562A	2017-07-24 00:30:00+03	43500.00
A0564A	2017-07-05 02:10:00+03	89600.00
A05731	2017-07-29 08:19:00+03	93900.00
A05736	2017-08-11 11:09:00+03	21800.00
A05789	2017-07-13 15:12:00+03	18000.00
A057E6	2017-07-09 07:00:00+03	3400.00
A05807	2017-08-09 13:27:00+03	111000.00
A05811	2017-07-20 14:37:00+03	44000.00
A05816	2017-08-09 16:40:00+03	43200.00
A05823	2017-08-08 03:04:00+03	64300.00
A05826	2017-08-09 08:15:00+03	27200.00
A05828	2017-07-01 01:47:00+03	48700.00
A0582E	2017-08-06 06:16:00+03	41800.00
A0584F	2017-07-05 04:21:00+03	134400.00
A05869	2017-07-31 08:03:00+03	43000.00
A05884	2017-07-06 22:47:00+03	46200.00
A0588A	2017-07-06 04:51:00+03	17800.00
A05892	2017-07-08 10:03:00+03	95200.00
A058CC	2017-08-10 01:37:00+03	26000.00
A058EB	2017-08-09 00:20:00+03	46400.00
A058EE	2017-07-12 06:53:00+03	38200.00
A05919	2017-07-31 20:10:00+03	95700.00
A0599E	2017-08-15 12:32:00+03	26700.00
A059A6	2017-07-11 07:17:00+03	30200.00
A05A70	2017-08-05 03:37:00+03	20400.00
A05A73	2017-07-21 06:27:00+03	65900.00
A05A8D	2017-08-15 07:27:00+03	26000.00
A05AA6	2017-08-04 23:55:00+03	77200.00
A05B45	2017-08-02 00:07:00+03	6000.00
A05B6F	2017-07-19 18:49:00+03	46300.00
A05BD0	2017-08-09 17:53:00+03	80200.00
A05C07	2017-07-11 01:37:00+03	61800.00
A05C7D	2017-07-24 01:21:00+03	160700.00
A05CB4	2017-07-02 09:58:00+03	46400.00
A05D0E	2017-08-08 04:35:00+03	61500.00
A05D3B	2017-08-09 23:08:00+03	63200.00
A05D70	2017-08-02 01:43:00+03	28800.00
A05E53	2017-07-14 04:05:00+03	29600.00
A05E72	2017-08-08 18:39:00+03	13400.00
A05F45	2017-07-22 19:38:00+03	155200.00
A05F4C	2017-07-14 04:57:00+03	173900.00
A05FFF	2017-07-07 02:07:00+03	23600.00
A06042	2017-08-01 05:28:00+03	26700.00
A060A3	2017-07-28 09:33:00+03	16800.00
A060D1	2017-07-02 03:16:00+03	399600.00
A06157	2017-07-05 05:03:00+03	48800.00
A06168	2017-08-15 16:27:00+03	67600.00
A06189	2017-07-06 07:44:00+03	40300.00
A06229	2017-07-11 22:35:00+03	25000.00
A06259	2017-07-04 20:26:00+03	46900.00
A062E5	2017-08-14 17:24:00+03	24000.00
A062EB	2017-07-13 09:19:00+03	23600.00
A0633B	2017-07-14 13:28:00+03	197100.00
A06366	2017-07-25 20:40:00+03	34000.00
A063CB	2017-08-13 00:35:00+03	37900.00
A06421	2017-06-24 02:01:00+03	26000.00
A06454	2017-08-09 06:36:00+03	29600.00
A064DE	2017-08-10 13:26:00+03	12000.00
A064F4	2017-07-12 09:56:00+03	69900.00
A0652F	2017-08-07 02:00:00+03	17000.00
A0654E	2017-07-21 05:41:00+03	27200.00
A06561	2017-07-04 03:46:00+03	8200.00
A065CC	2017-07-21 11:26:00+03	12600.00
A06621	2017-08-06 11:52:00+03	423100.00
A06631	2017-08-10 21:18:00+03	80200.00
A06640	2017-08-02 21:05:00+03	202400.00
A0664B	2017-07-10 23:40:00+03	25600.00
A06693	2017-07-07 02:06:00+03	259100.00
A066B5	2017-07-20 12:51:00+03	28800.00
A066F2	2017-07-25 15:55:00+03	50100.00
A06820	2017-08-08 01:28:00+03	64600.00
A06861	2017-08-09 06:25:00+03	54300.00
A06870	2017-07-03 20:22:00+03	55900.00
A06886	2017-07-28 04:33:00+03	58000.00
A068A7	2017-07-01 19:49:00+03	167200.00
A068FA	2017-08-14 11:33:00+03	22000.00
A06937	2017-08-15 09:04:00+03	18400.00
A0693D	2017-08-14 20:38:00+03	19600.00
A06980	2017-07-17 20:27:00+03	42800.00
A0698D	2017-07-17 10:28:00+03	99300.00
A0699E	2017-07-18 20:29:00+03	125400.00
A069B2	2017-07-29 17:34:00+03	27600.00
A069C5	2017-07-21 03:45:00+03	31400.00
A069D4	2017-07-22 15:19:00+03	139100.00
A069DB	2017-08-15 15:04:00+03	25100.00
A06A04	2017-07-02 11:49:00+03	27300.00
A06A10	2017-08-11 13:20:00+03	31400.00
A06A15	2017-08-09 22:11:00+03	23200.00
A06A2A	2017-06-28 01:06:00+03	129600.00
A06A4A	2017-07-01 07:01:00+03	16800.00
A06A56	2017-07-22 22:34:00+03	24200.00
A06A6C	2017-07-22 19:35:00+03	57600.00
A06A9F	2017-06-28 14:08:00+03	140800.00
A06AFA	2017-07-16 02:20:00+03	55800.00
A06B3C	2017-07-24 10:37:00+03	56900.00
A06B66	2017-08-13 06:32:00+03	254900.00
A06B9D	2017-07-30 19:30:00+03	46400.00
A06BCC	2017-07-18 02:28:00+03	266400.00
A06BEA	2017-07-19 07:46:00+03	43000.00
A06BEF	2017-07-27 14:26:00+03	30300.00
A06C7C	2017-07-11 09:01:00+03	44800.00
A06D1B	2017-07-23 12:25:00+03	20400.00
A06D54	2017-07-28 14:17:00+03	136200.00
A06D67	2017-07-29 07:07:00+03	30600.00
A06D6E	2017-07-17 21:20:00+03	6800.00
A06DAB	2017-08-04 07:37:00+03	131100.00
A06DB8	2017-07-20 04:50:00+03	100500.00
A06E20	2017-08-15 08:59:00+03	135400.00
A06E60	2017-07-19 20:23:00+03	61800.00
A06E72	2017-07-06 21:38:00+03	92000.00
A06E98	2017-08-14 07:00:00+03	12000.00
A06EFA	2017-08-02 19:30:00+03	6000.00
A06F01	2017-08-04 21:20:00+03	75600.00
A06F05	2017-07-03 02:16:00+03	48800.00
A06F51	2017-07-17 11:19:00+03	42800.00
A06F70	2017-07-27 19:38:00+03	57600.00
A07058	2017-08-11 09:24:00+03	10800.00
A070FE	2017-08-04 12:31:00+03	229000.00
A0711C	2017-07-19 07:58:00+03	48500.00
A0712E	2017-08-15 13:46:00+03	85000.00
A07168	2017-07-01 03:12:00+03	267400.00
A071A5	2017-07-16 09:17:00+03	13400.00
A071AC	2017-07-24 18:26:00+03	108900.00
A071E4	2017-07-22 19:19:00+03	152700.00
A0720C	2017-07-13 08:34:00+03	208200.00
A07213	2017-07-05 05:22:00+03	44800.00
A07231	2017-07-05 09:43:00+03	7400.00
A07286	2017-07-30 03:17:00+03	26800.00
A072FC	2017-07-04 11:18:00+03	28800.00
A07303	2017-07-09 16:59:00+03	73600.00
A07304	2017-07-25 17:44:00+03	31800.00
A0733D	2017-07-17 14:35:00+03	92800.00
A07355	2017-07-16 03:42:00+03	147700.00
A07379	2017-07-23 12:47:00+03	9300.00
A073A5	2017-07-20 17:36:00+03	42800.00
A073B0	2017-07-22 04:51:00+03	99200.00
A07484	2017-08-10 07:32:00+03	56900.00
A074DC	2017-08-07 08:44:00+03	38400.00
A07526	2017-08-14 23:25:00+03	353600.00
A07613	2017-08-05 14:30:00+03	46800.00
A07637	2017-07-21 21:47:00+03	24700.00
A0767A	2017-06-29 23:58:00+03	29400.00
A076C2	2017-07-08 04:12:00+03	35800.00
A076C9	2017-08-10 18:12:00+03	538300.00
A07758	2017-07-22 13:43:00+03	150000.00
A0785F	2017-08-09 21:32:00+03	55700.00
A0788E	2017-07-27 07:13:00+03	111600.00
A078D0	2017-08-05 09:25:00+03	668700.00
A078D5	2017-07-23 22:21:00+03	136800.00
A0793C	2017-07-04 08:33:00+03	95600.00
A07947	2017-07-24 15:51:00+03	25000.00
A079A7	2017-07-13 03:00:00+03	55800.00
A079DC	2017-07-11 12:47:00+03	101800.00
A079F6	2017-07-21 13:00:00+03	12600.00
A07A34	2017-08-05 05:56:00+03	28800.00
A07A43	2017-08-11 01:46:00+03	34300.00
A07A4E	2017-07-24 23:28:00+03	99300.00
A07A8F	2017-07-10 21:52:00+03	49100.00
A07B16	2017-07-11 07:15:00+03	138000.00
A07B50	2017-07-13 01:13:00+03	101200.00
A07B8A	2017-08-06 19:53:00+03	112000.00
A07B9A	2017-07-07 22:32:00+03	29400.00
A07B9C	2017-07-04 11:23:00+03	119500.00
A07C91	2017-07-17 11:21:00+03	53200.00
A07CAC	2017-08-07 21:45:00+03	188500.00
A07CE4	2017-07-10 23:32:00+03	16400.00
A07CFC	2017-07-22 16:32:00+03	46300.00
A07D3D	2017-07-05 23:51:00+03	19600.00
A07D6D	2017-07-06 01:22:00+03	23200.00
A07D70	2017-07-11 17:22:00+03	48600.00
A07DA3	2017-07-25 18:42:00+03	22600.00
A07DCE	2017-07-26 20:08:00+03	70400.00
A07DF1	2017-07-15 02:16:00+03	45100.00
A07E05	2017-07-20 05:03:00+03	31600.00
A07E18	2017-08-11 07:49:00+03	39500.00
A07E7A	2017-07-06 02:07:00+03	170000.00
A07EAD	2017-08-08 13:12:00+03	66200.00
A07EF3	2017-07-09 13:21:00+03	76100.00
A07F24	2017-08-15 04:09:00+03	86400.00
A07F2C	2017-07-11 09:30:00+03	15000.00
A07F6E	2017-07-24 21:26:00+03	123000.00
A08027	2017-07-05 16:33:00+03	112000.00
A080FC	2017-08-15 02:39:00+03	56000.00
A08114	2017-07-25 15:07:00+03	48400.00
A0811B	2017-08-08 02:40:00+03	148200.00
A081A1	2017-08-13 22:35:00+03	55100.00
A081B3	2017-07-08 11:29:00+03	7300.00
A081CC	2017-07-18 02:14:00+03	41200.00
A08239	2017-07-28 15:02:00+03	50200.00
A08250	2017-07-27 17:16:00+03	56000.00
A082F5	2017-07-03 09:22:00+03	60200.00
A08336	2017-07-04 10:25:00+03	23100.00
A083C2	2017-07-24 09:05:00+03	89700.00
A083E7	2017-07-06 06:43:00+03	51900.00
A0846B	2017-07-21 17:34:00+03	101200.00
A084EA	2017-08-03 00:50:00+03	47600.00
A0852E	2017-07-02 11:04:00+03	38800.00
A08554	2017-07-04 21:42:00+03	47700.00
A085B1	2017-07-17 20:29:00+03	25400.00
A085CE	2017-08-13 15:25:00+03	26000.00
A085E1	2017-07-31 04:11:00+03	74300.00
A08624	2017-07-13 20:31:00+03	109600.00
A0869A	2017-07-21 13:03:00+03	56000.00
A086BC	2017-07-01 23:03:00+03	13400.00
A086BE	2017-08-02 07:01:00+03	46300.00
A086E4	2017-08-12 16:42:00+03	73100.00
A0872E	2017-07-13 20:22:00+03	36800.00
A08731	2017-07-10 09:02:00+03	47600.00
A087A2	2017-07-18 23:01:00+03	26800.00
A087BC	2017-07-28 23:22:00+03	99300.00
A0882C	2017-07-21 12:11:00+03	73500.00
A08841	2017-08-01 12:51:00+03	40600.00
A08842	2017-08-11 22:25:00+03	22600.00
A08873	2017-07-21 22:54:00+03	78600.00
A08880	2017-08-01 03:13:00+03	226200.00
A08898	2017-07-18 12:24:00+03	135400.00
A088C0	2017-08-02 15:23:00+03	51300.00
A088C2	2017-07-13 22:59:00+03	38800.00
A0895C	2017-08-04 14:15:00+03	98400.00
A0899C	2017-07-25 08:54:00+03	27900.00
A089C6	2017-07-05 02:02:00+03	128800.00
A08A26	2017-08-13 20:56:00+03	56000.00
A08A2C	2017-07-16 16:13:00+03	29600.00
A08A64	2017-07-14 20:54:00+03	137700.00
A08ABF	2017-06-30 19:38:00+03	40600.00
A08ACF	2017-08-06 15:30:00+03	55900.00
A08B08	2017-07-22 22:23:00+03	28800.00
A08B19	2017-07-11 02:34:00+03	23600.00
A08B24	2017-07-10 19:35:00+03	54800.00
A08BB2	2017-07-12 02:57:00+03	40800.00
A08BCB	2017-07-12 15:34:00+03	55800.00
A08BD9	2017-07-22 01:18:00+03	28800.00
A08BF2	2017-07-09 13:41:00+03	62200.00
A08C22	2017-07-01 20:30:00+03	93800.00
A08C3E	2017-07-28 10:30:00+03	25600.00
A08C60	2017-08-09 21:37:00+03	14000.00
A08C99	2017-07-03 21:41:00+03	51600.00
A08E14	2017-07-29 00:03:00+03	36200.00
A08E30	2017-07-30 22:56:00+03	99200.00
A08E3F	2017-07-21 11:26:00+03	6600.00
A08F50	2017-07-14 13:57:00+03	90200.00
A08FF4	2017-07-25 00:07:00+03	48800.00
A090C9	2017-07-14 19:20:00+03	46400.00
A090D4	2017-07-05 16:50:00+03	92800.00
A09126	2017-08-02 01:02:00+03	123000.00
A0912E	2017-08-04 23:43:00+03	6000.00
A0915C	2017-07-27 02:12:00+03	29600.00
A09186	2017-07-06 16:40:00+03	8200.00
A091C4	2017-07-18 05:24:00+03	20600.00
A091DA	2017-07-12 16:14:00+03	52700.00
A091DD	2017-07-10 04:43:00+03	56900.00
A09207	2017-07-15 19:18:00+03	288500.00
A0920C	2017-08-03 20:19:00+03	258400.00
A0922A	2017-07-03 01:18:00+03	107400.00
A09254	2017-06-28 02:22:00+03	12600.00
A09288	2017-08-10 20:22:00+03	36200.00
A0929E	2017-07-17 07:01:00+03	99300.00
A09316	2017-07-06 22:55:00+03	137600.00
A0936E	2017-07-07 06:42:00+03	39500.00
A0938D	2017-07-08 21:50:00+03	44500.00
A09390	2017-08-13 04:37:00+03	21800.00
A093BB	2017-08-15 18:00:00+03	13000.00
A093EF	2017-07-13 19:59:00+03	34600.00
A09408	2017-07-22 13:18:00+03	21400.00
A09454	2017-08-08 05:40:00+03	20000.00
A094FB	2017-08-08 08:16:00+03	22000.00
A09561	2017-08-10 07:08:00+03	16000.00
A095E5	2017-07-31 10:12:00+03	23200.00
A0960A	2017-07-12 22:31:00+03	97500.00
A0961D	2017-07-16 00:56:00+03	48800.00
A0964A	2017-07-08 19:05:00+03	23200.00
A09656	2017-07-13 21:58:00+03	18700.00
A096DF	2017-08-07 06:49:00+03	16400.00
A096EE	2017-07-05 09:22:00+03	31600.00
A09747	2017-07-06 05:37:00+03	32800.00
A0978F	2017-07-12 11:35:00+03	272600.00
A09792	2017-07-14 04:49:00+03	131600.00
A097F1	2017-08-09 13:07:00+03	51200.00
A09826	2017-08-15 14:44:00+03	25600.00
A09838	2017-07-01 13:16:00+03	25800.00
A09840	2017-07-26 03:04:00+03	11000.00
A09853	2017-08-08 02:44:00+03	172800.00
A0985C	2017-07-24 23:40:00+03	114800.00
A09893	2017-08-07 23:46:00+03	7400.00
A09926	2017-07-13 01:51:00+03	44000.00
A09983	2017-08-06 14:02:00+03	112000.00
A0998B	2017-08-15 07:45:00+03	52800.00
A09990	2017-08-07 13:26:00+03	73500.00
A099AD	2017-07-18 19:38:00+03	28800.00
A09A39	2017-07-28 02:12:00+03	103100.00
A09A68	2017-07-11 13:16:00+03	56000.00
A09ABD	2017-07-15 15:03:00+03	58000.00
A09AD3	2017-07-23 10:52:00+03	38600.00
A09B06	2017-07-17 13:00:00+03	48800.00
A09B3D	2017-07-05 06:36:00+03	55800.00
A09C33	2017-07-27 13:15:00+03	58600.00
A09D21	2017-07-08 10:42:00+03	42800.00
A09DCB	2017-07-01 13:03:00+03	19600.00
A09E39	2017-07-09 04:25:00+03	176000.00
A09E7E	2017-08-01 07:49:00+03	45200.00
A09E91	2017-07-01 06:22:00+03	156500.00
A09EBB	2017-07-08 15:51:00+03	246000.00
A09EC2	2017-07-16 15:45:00+03	26000.00
A09F50	2017-07-21 09:51:00+03	45200.00
A0A0CE	2017-06-27 08:43:00+03	119600.00
A0A173	2017-07-05 15:32:00+03	46300.00
A0A1AC	2017-07-09 01:42:00+03	81700.00
A0A1F6	2017-07-05 18:16:00+03	66000.00
A0A262	2017-08-09 17:53:00+03	56000.00
A0A265	2017-07-04 02:25:00+03	102600.00
A0A28E	2017-07-04 00:33:00+03	399600.00
A0A2C3	2017-08-04 08:46:00+03	130900.00
A0A2C4	2017-07-04 01:56:00+03	167400.00
A0A2CE	2017-08-04 02:57:00+03	8200.00
A0A331	2017-06-27 14:52:00+03	11800.00
A0A332	2017-08-07 11:52:00+03	56600.00
A0A369	2017-08-01 22:21:00+03	19600.00
A0A375	2017-08-12 07:02:00+03	42700.00
A0A3CC	2017-08-13 17:18:00+03	6600.00
A0A3D6	2017-08-10 20:21:00+03	46000.00
A0A3E3	2017-08-09 16:19:00+03	49700.00
A0A41C	2017-08-07 12:38:00+03	37300.00
A0A49B	2017-08-15 16:07:00+03	131100.00
A0A4B7	2017-07-07 20:02:00+03	212200.00
A0A4BF	2017-07-04 13:08:00+03	25800.00
A0A4D7	2017-07-18 18:06:00+03	516800.00
A0A5E7	2017-07-26 11:39:00+03	40300.00
A0A5FC	2017-07-17 16:59:00+03	170000.00
A0A617	2017-08-14 01:38:00+03	32800.00
A0A62C	2017-07-04 22:11:00+03	86600.00
A0A696	2017-08-05 17:23:00+03	46000.00
A0A6C2	2017-07-24 01:45:00+03	117000.00
A0A6E6	2017-07-04 03:13:00+03	60700.00
A0A83D	2017-07-16 09:31:00+03	23600.00
A0A8A6	2017-07-30 13:48:00+03	13600.00
A0A8CA	2017-08-07 17:26:00+03	128800.00
A0A8D7	2017-07-12 02:06:00+03	32300.00
A0A961	2017-07-25 12:32:00+03	96800.00
A0A967	2017-08-10 06:17:00+03	79400.00
A0A968	2017-07-04 15:24:00+03	201600.00
A0AA6F	2017-07-09 18:19:00+03	25200.00
A0AA7D	2017-08-04 09:53:00+03	265700.00
A0AA80	2017-06-30 03:56:00+03	42600.00
A0ABEB	2017-08-06 15:11:00+03	51900.00
A0ABEC	2017-08-04 16:55:00+03	54400.00
A0AC68	2017-08-02 20:45:00+03	25200.00
A0ADDD	2017-07-11 23:08:00+03	117600.00
A0AE1E	2017-07-19 18:05:00+03	47400.00
A0AE22	2017-07-27 07:55:00+03	83100.00
A0AE7A	2017-07-21 17:35:00+03	58800.00
A0AE9B	2017-08-03 19:53:00+03	40400.00
A0AEA6	2017-08-06 06:37:00+03	106400.00
A0AEFA	2017-08-07 10:21:00+03	30000.00
A0AF4D	2017-08-01 11:33:00+03	266400.00
A0AF73	2017-08-02 12:21:00+03	81000.00
A0AFC0	2017-07-24 19:19:00+03	16400.00
A0AFE3	2017-08-08 20:14:00+03	59300.00
A0B02B	2017-07-26 16:53:00+03	46400.00
A0B031	2017-08-08 15:05:00+03	265600.00
A0B058	2017-07-19 22:31:00+03	70200.00
A0B063	2017-06-30 13:56:00+03	111600.00
A0B089	2017-07-05 14:29:00+03	12600.00
A0B099	2017-07-19 07:59:00+03	48800.00
A0B0A5	2017-07-16 12:51:00+03	31900.00
A0B0CE	2017-07-07 12:46:00+03	23200.00
A0B0D2	2017-07-11 20:24:00+03	89100.00
A0B0D7	2017-08-06 16:47:00+03	265700.00
A0B160	2017-07-25 15:13:00+03	14800.00
A0B17F	2017-07-01 14:03:00+03	45200.00
A0B1AF	2017-07-30 05:39:00+03	293200.00
A0B209	2017-07-09 06:28:00+03	61800.00
A0B20C	2017-07-04 10:40:00+03	46400.00
A0B211	2017-08-14 14:31:00+03	25400.00
A0B255	2017-07-18 03:30:00+03	61900.00
A0B2C1	2017-08-12 21:08:00+03	68400.00
A0B352	2017-07-16 01:41:00+03	117600.00
A0B375	2017-07-19 19:37:00+03	21800.00
A0B392	2017-07-31 12:22:00+03	77900.00
A0B394	2017-08-03 17:55:00+03	46900.00
A0B41B	2017-07-20 19:34:00+03	43600.00
A0B420	2017-07-20 01:35:00+03	25400.00
A0B423	2017-07-29 23:48:00+03	207000.00
A0B4CB	2017-07-01 15:53:00+03	57500.00
A0B525	2017-07-25 16:31:00+03	474800.00
A0B526	2017-07-22 21:47:00+03	25200.00
A0B604	2017-08-11 07:07:00+03	63400.00
A0B613	2017-07-03 21:06:00+03	49100.00
A0B66C	2017-08-12 09:30:00+03	35200.00
A0B6A3	2017-07-17 20:38:00+03	15000.00
A0B6CA	2017-08-06 11:34:00+03	339300.00
A0B6CE	2017-08-08 03:43:00+03	55800.00
A0B6E2	2017-07-16 02:14:00+03	42800.00
A0B706	2017-07-10 20:04:00+03	136200.00
A0B75B	2017-07-09 22:44:00+03	14400.00
A0B760	2017-08-04 05:02:00+03	49600.00
A0B76A	2017-07-21 01:32:00+03	133100.00
A0B7A2	2017-07-27 03:41:00+03	398500.00
A0B7D7	2017-07-16 07:16:00+03	73200.00
A0B7FB	2017-07-19 03:42:00+03	20400.00
A0B86B	2017-07-10 09:59:00+03	52400.00
A0B871	2017-07-16 02:16:00+03	154500.00
A0B887	2017-07-06 00:15:00+03	144400.00
A0B975	2017-08-11 12:54:00+03	77200.00
A0B995	2017-06-29 23:16:00+03	30200.00
A0B9BB	2017-08-01 20:46:00+03	20200.00
A0B9BE	2017-06-29 23:30:00+03	154800.00
A0B9D9	2017-08-02 13:43:00+03	138000.00
A0BA1A	2017-07-29 23:32:00+03	67600.00
A0BA1F	2017-08-09 04:58:00+03	51900.00
A0BAC9	2017-08-10 20:40:00+03	29600.00
A0BAD0	2017-07-02 02:45:00+03	25400.00
A0BB07	2017-07-05 11:34:00+03	14000.00
A0BB23	2017-07-16 04:02:00+03	57800.00
A0BB53	2017-07-25 15:46:00+03	62000.00
A0BB75	2017-08-02 16:35:00+03	23600.00
A0BBA2	2017-07-01 11:54:00+03	20400.00
A0BBC5	2017-07-29 15:40:00+03	139100.00
A0BCCB	2017-07-12 22:32:00+03	98200.00
A0BCF2	2017-08-10 04:10:00+03	67200.00
A0BD93	2017-08-08 22:26:00+03	59800.00
A0BE2F	2017-08-13 13:03:00+03	137100.00
A0BEC3	2017-07-08 13:33:00+03	75300.00
A0BF4F	2017-07-28 07:01:00+03	106400.00
A0BF60	2017-08-13 08:43:00+03	53300.00
A0BF7D	2017-08-08 03:36:00+03	69000.00
A0BFAF	2017-08-09 19:26:00+03	13600.00
A0BFCE	2017-08-07 14:07:00+03	31700.00
A0BFF5	2017-08-06 04:10:00+03	24400.00
A0C083	2017-07-10 13:42:00+03	103700.00
A0C099	2017-08-04 10:13:00+03	50000.00
A0C0BD	2017-08-07 14:35:00+03	131600.00
A0C0C2	2017-07-08 21:19:00+03	26700.00
A0C104	2017-07-10 14:56:00+03	27200.00
A0C143	2017-07-02 22:00:00+03	50800.00
A0C15E	2017-07-04 14:58:00+03	67600.00
A0C1DF	2017-07-18 16:43:00+03	131100.00
A0C1F2	2017-07-31 16:24:00+03	111600.00
A0C202	2017-08-08 20:06:00+03	27200.00
A0C247	2017-07-08 07:16:00+03	52800.00
A0C294	2017-07-15 17:26:00+03	134600.00
A0C2DE	2017-08-06 19:36:00+03	97600.00
A0C2E2	2017-08-05 14:09:00+03	133200.00
A0C3D8	2017-08-15 10:28:00+03	26000.00
A0C3FE	2017-08-12 01:53:00+03	21400.00
A0C44A	2017-08-05 08:56:00+03	27200.00
A0C466	2017-07-10 11:13:00+03	25600.00
A0C4CB	2017-08-08 01:07:00+03	44600.00
A0C4DA	2017-07-17 15:37:00+03	79000.00
A0C533	2017-07-06 23:18:00+03	38600.00
A0C5C3	2017-08-13 18:25:00+03	96800.00
A0C5D0	2017-07-26 22:18:00+03	22000.00
A0C5D8	2017-07-12 04:48:00+03	21800.00
A0C64B	2017-07-08 23:05:00+03	100600.00
A0C693	2017-07-03 22:36:00+03	24400.00
A0C6A4	2017-07-12 02:37:00+03	170800.00
A0C6DB	2017-07-14 15:39:00+03	66600.00
A0C6E3	2017-07-19 12:41:00+03	108400.00
A0C71A	2017-07-21 05:51:00+03	93900.00
A0C73C	2017-07-13 04:34:00+03	66000.00
A0C795	2017-08-09 10:09:00+03	59200.00
A0C7C2	2017-08-15 10:44:00+03	189700.00
A0C7D4	2017-07-17 23:25:00+03	30400.00
A0C7E8	2017-07-10 06:41:00+03	21400.00
A0C889	2017-07-24 17:18:00+03	206800.00
A0C949	2017-07-22 21:34:00+03	148200.00
A0C969	2017-08-15 17:52:00+03	14800.00
A0C99E	2017-08-05 12:21:00+03	28000.00
A0C9D9	2017-07-30 05:24:00+03	12600.00
A0C9DB	2017-07-29 23:17:00+03	241500.00
A0CA29	2017-07-27 15:01:00+03	23600.00
A0CA4E	2017-07-20 09:57:00+03	175200.00
A0CA65	2017-08-05 12:51:00+03	68100.00
A0CAAA	2017-07-24 07:27:00+03	286700.00
A0CAD6	2017-07-27 13:45:00+03	14000.00
A0CB0A	2017-07-25 22:56:00+03	31100.00
A0CB7C	2017-07-29 22:21:00+03	39000.00
A0CBD0	2017-07-18 08:57:00+03	136400.00
A0CBD9	2017-07-10 10:55:00+03	103200.00
A0CBFB	2017-07-13 04:04:00+03	64200.00
A0CC10	2017-07-15 00:42:00+03	111600.00
A0CC1E	2017-07-28 01:51:00+03	28000.00
A0CC40	2017-08-04 11:30:00+03	24400.00
A0CC47	2017-07-30 02:55:00+03	55800.00
A0CCE8	2017-07-30 11:53:00+03	16000.00
A0CD1D	2017-08-09 17:35:00+03	131600.00
A0CD47	2017-07-15 23:03:00+03	81600.00
A0CD62	2017-07-25 07:13:00+03	56100.00
A0CD97	2017-08-03 21:47:00+03	47500.00
A0CD9C	2017-07-31 22:10:00+03	46200.00
A0CDAC	2017-08-13 23:26:00+03	57800.00
A0CDB4	2017-07-17 07:52:00+03	142800.00
A0CDC6	2017-07-26 15:28:00+03	138200.00
A0CE4F	2017-08-01 21:25:00+03	286100.00
A0CE88	2017-07-04 13:36:00+03	14900.00
A0CE98	2017-08-13 11:59:00+03	49600.00
A0CEFA	2017-07-15 19:50:00+03	175300.00
A0CF1A	2017-08-01 15:42:00+03	25900.00
A0CF3A	2017-07-29 14:42:00+03	16400.00
A0CF71	2017-07-23 16:39:00+03	62600.00
A0CF7D	2017-07-03 15:48:00+03	6800.00
A0D007	2017-07-28 19:06:00+03	98700.00
A0D008	2017-08-08 02:54:00+03	235400.00
A0D034	2017-07-26 13:58:00+03	91500.00
A0D072	2017-08-15 17:35:00+03	59800.00
A0D104	2017-07-01 02:44:00+03	39300.00
A0D129	2017-07-27 10:21:00+03	24400.00
A0D132	2017-07-30 03:13:00+03	42400.00
A0D1F4	2017-08-12 08:39:00+03	68100.00
A0D2C0	2017-07-29 15:07:00+03	295700.00
A0D2E7	2017-07-24 19:40:00+03	42800.00
A0D2E8	2017-07-08 09:42:00+03	88600.00
A0D2EB	2017-07-31 02:05:00+03	55800.00
A0D2F1	2017-07-28 14:31:00+03	112000.00
A0D3FA	2017-08-01 17:31:00+03	17800.00
A0D40C	2017-07-26 06:06:00+03	119500.00
A0D41E	2017-08-15 04:05:00+03	23200.00
A0D425	2017-08-13 16:46:00+03	14400.00
A0D45E	2017-07-08 10:01:00+03	39200.00
A0D49F	2017-07-30 14:31:00+03	47500.00
A0D4B0	2017-07-03 23:44:00+03	44600.00
A0D4EA	2017-07-15 12:52:00+03	7300.00
A0D56D	2017-06-28 17:35:00+03	128800.00
A0D5C7	2017-07-08 23:58:00+03	26000.00
A0D5F5	2017-07-03 09:46:00+03	16400.00
A0D609	2017-08-11 07:51:00+03	28800.00
A0D61D	2017-08-14 15:11:00+03	38600.00
A0D621	2017-07-03 08:52:00+03	23600.00
A0D659	2017-07-28 00:30:00+03	123000.00
A0D666	2017-07-24 13:07:00+03	18800.00
A0D672	2017-07-25 19:35:00+03	155600.00
A0D696	2017-08-10 11:21:00+03	137500.00
A0D701	2017-07-13 09:32:00+03	42100.00
A0D730	2017-07-02 12:58:00+03	89600.00
A0D7A9	2017-08-04 18:17:00+03	49400.00
A0D7D6	2017-07-29 15:23:00+03	60700.00
A0D7E6	2017-07-16 22:54:00+03	17800.00
A0D82B	2017-08-02 02:46:00+03	195800.00
A0D83C	2017-07-31 06:38:00+03	57600.00
A0D95C	2017-08-04 08:55:00+03	113800.00
A0D9E9	2017-07-09 15:57:00+03	81600.00
A0D9F8	2017-08-01 03:47:00+03	84500.00
A0DA24	2017-08-02 03:42:00+03	32700.00
A0DA26	2017-07-10 18:13:00+03	21400.00
A0DA7C	2017-08-13 04:06:00+03	6700.00
A0DA9D	2017-07-27 02:01:00+03	96300.00
A0DAED	2017-08-15 16:14:00+03	170800.00
A0DB03	2017-07-06 07:41:00+03	26800.00
A0DB95	2017-08-11 00:50:00+03	24600.00
A0DBF8	2017-08-10 14:04:00+03	26200.00
A0DC0F	2017-08-13 00:57:00+03	38800.00
A0DC23	2017-06-30 02:06:00+03	55500.00
A0DC6E	2017-07-27 14:58:00+03	65900.00
A0DCBB	2017-07-17 20:01:00+03	46000.00
A0DD2A	2017-07-28 11:07:00+03	35200.00
A0DDDC	2017-07-25 02:17:00+03	282000.00
A0DE71	2017-07-07 05:22:00+03	44600.00
A0DE9C	2017-07-05 21:32:00+03	6000.00
A0DECA	2017-08-01 09:24:00+03	62800.00
A0DED8	2017-07-05 08:02:00+03	111600.00
A0DF24	2017-08-03 18:16:00+03	133100.00
A0DF9F	2017-07-13 04:21:00+03	139400.00
A0DFFC	2017-07-12 07:19:00+03	16400.00
A0E022	2017-06-24 10:31:00+03	167400.00
A0E02D	2017-07-29 22:46:00+03	90000.00
A0E08B	2017-08-13 13:39:00+03	43800.00
A0E08E	2017-07-12 13:17:00+03	6000.00
A0E0A0	2017-07-31 18:43:00+03	135600.00
A0E0D7	2017-07-14 03:52:00+03	50400.00
A0E13A	2017-07-03 14:21:00+03	28800.00
A0E149	2017-07-15 05:04:00+03	46000.00
A0E19D	2017-08-05 15:48:00+03	89700.00
A0E211	2017-07-12 03:35:00+03	21800.00
A0E2C2	2017-07-18 03:38:00+03	48800.00
A0E2DB	2017-07-01 14:31:00+03	27600.00
A0E32D	2017-06-30 08:28:00+03	93900.00
A0E38C	2017-07-13 09:07:00+03	179500.00
A0E395	2017-07-17 10:00:00+03	21800.00
A0E3E4	2017-07-26 08:48:00+03	22900.00
A0E3E9	2017-07-03 03:08:00+03	153200.00
A0E3EB	2017-06-30 18:40:00+03	77000.00
A0E419	2017-07-05 12:51:00+03	55800.00
A0E44C	2017-07-21 07:12:00+03	58700.00
A0E454	2017-07-18 05:29:00+03	135600.00
A0E461	2017-08-08 10:39:00+03	70700.00
A0E46D	2017-07-06 00:45:00+03	98200.00
A0E4AD	2017-07-14 04:22:00+03	40800.00
A0E4F8	2017-07-19 10:24:00+03	393000.00
A0E538	2017-08-09 08:08:00+03	51900.00
A0E589	2017-08-09 23:55:00+03	56600.00
A0E5A8	2017-07-17 06:57:00+03	281500.00
A0E5B8	2017-07-11 16:07:00+03	112000.00
A0E5D4	2017-07-06 01:12:00+03	44600.00
A0E606	2017-07-25 02:36:00+03	46400.00
A0E62F	2017-08-15 16:01:00+03	55800.00
A0E6E9	2017-07-11 05:40:00+03	11600.00
A0E82B	2017-08-03 14:23:00+03	35800.00
A0E846	2017-08-05 19:48:00+03	168700.00
A0E869	2017-07-24 16:41:00+03	46400.00
A0E8B7	2017-07-19 22:42:00+03	25200.00
A0E8CC	2017-08-15 02:07:00+03	89700.00
A0E900	2017-07-29 12:41:00+03	58600.00
A0E922	2017-07-02 21:40:00+03	37900.00
A0E92C	2017-07-02 12:43:00+03	35600.00
A0E974	2017-07-06 17:39:00+03	95300.00
A0E9FD	2017-08-05 18:20:00+03	136400.00
A0EA03	2017-07-13 15:16:00+03	20000.00
A0EA0B	2017-07-19 13:35:00+03	28000.00
A0EA31	2017-07-22 12:12:00+03	6600.00
A0EA3F	2017-07-21 00:49:00+03	102100.00
A0EA46	2017-08-03 12:05:00+03	113300.00
A0EA72	2017-07-12 21:29:00+03	26800.00
A0EAB2	2017-08-05 21:51:00+03	160400.00
A0EAC3	2017-08-09 01:14:00+03	93900.00
A0EB07	2017-08-13 23:15:00+03	53100.00
A0EB29	2017-07-23 06:30:00+03	14800.00
A0EB54	2017-07-23 00:53:00+03	28000.00
A0EB76	2017-08-08 19:31:00+03	196000.00
A0EBB2	2017-08-11 12:09:00+03	111600.00
A0EBF1	2017-08-13 12:33:00+03	45200.00
A0EC74	2017-07-10 01:31:00+03	89600.00
A0EC99	2017-08-02 15:55:00+03	280400.00
A0ECA8	2017-07-03 06:31:00+03	32200.00
A0ECD0	2017-08-11 00:08:00+03	231300.00
A0ED3F	2017-07-03 15:22:00+03	123000.00
A0ED52	2017-08-01 06:09:00+03	129700.00
A0ED65	2017-08-14 17:57:00+03	40400.00
A0ED85	2017-07-31 20:25:00+03	25600.00
A0ED87	2017-08-01 11:22:00+03	257600.00
A0EDBC	2017-08-05 07:44:00+03	38600.00
A0EDC7	2017-08-13 05:07:00+03	91600.00
A0EDD1	2017-08-06 11:07:00+03	31200.00
A0EE2C	2017-07-28 12:15:00+03	31600.00
A0EE91	2017-07-16 23:39:00+03	61500.00
A0EF70	2017-08-02 05:20:00+03	29600.00
A0EFBF	2017-06-24 03:14:00+03	131600.00
A0EFD2	2017-07-09 23:45:00+03	55800.00
A0EFEC	2017-07-03 12:21:00+03	99700.00
A0F089	2017-07-20 00:55:00+03	53600.00
A0F0B4	2017-08-05 18:20:00+03	26000.00
A0F11E	2017-07-25 16:21:00+03	151100.00
A0F182	2017-07-30 15:20:00+03	6700.00
A0F191	2017-07-08 04:12:00+03	21500.00
A0F1AC	2017-08-05 23:35:00+03	103500.00
A0F22A	2017-07-14 23:09:00+03	78300.00
A0F28D	2017-07-03 08:34:00+03	25100.00
A0F2A5	2017-08-12 23:33:00+03	20600.00
A0F2D5	2017-07-31 00:02:00+03	57400.00
A0F303	2017-07-06 22:51:00+03	28800.00
A0F364	2017-08-01 01:59:00+03	69000.00
A0F37A	2017-07-26 13:11:00+03	190400.00
A0F3B6	2017-08-03 14:59:00+03	44500.00
A0F3F6	2017-08-04 21:14:00+03	96300.00
A0F413	2017-07-31 08:57:00+03	43100.00
A0F441	2017-07-09 01:25:00+03	37600.00
A0F443	2017-08-01 09:20:00+03	169000.00
A0F476	2017-07-29 15:15:00+03	13200.00
A0F4A3	2017-08-13 23:06:00+03	418800.00
A0F4E8	2017-07-04 02:30:00+03	38800.00
A0F4EE	2017-08-01 17:29:00+03	196600.00
A0F55D	2017-07-30 13:36:00+03	35700.00
A0F566	2017-07-03 05:07:00+03	161200.00
A0F59F	2017-08-07 12:09:00+03	46400.00
A0F5D1	2017-07-25 22:06:00+03	72000.00
A0F628	2017-08-04 11:58:00+03	58800.00
A0F631	2017-08-11 19:53:00+03	6000.00
A0F6A0	2017-08-03 21:56:00+03	60900.00
A0F6CE	2017-08-10 12:03:00+03	53300.00
A0F6D6	2017-08-12 04:39:00+03	117200.00
A0F721	2017-08-07 00:07:00+03	257600.00
A0F76E	2017-07-30 09:45:00+03	15000.00
A0F82B	2017-08-15 13:44:00+03	69500.00
A0F82F	2017-07-27 03:47:00+03	42800.00
A0F89E	2017-07-03 17:34:00+03	46000.00
A0F8BC	2017-08-09 20:25:00+03	24300.00
A0F8E0	2017-07-05 02:27:00+03	92800.00
A0F8F5	2017-07-15 18:16:00+03	62600.00
A0F91D	2017-08-10 21:37:00+03	55800.00
A0F937	2017-07-09 00:46:00+03	14000.00
A0F948	2017-07-04 06:49:00+03	184600.00
A0F973	2017-08-07 15:12:00+03	42800.00
A0F974	2017-08-07 05:10:00+03	39800.00
A0F992	2017-07-04 04:25:00+03	79200.00
A0F996	2017-07-09 06:57:00+03	170200.00
A0F99D	2017-07-09 03:56:00+03	123000.00
A0F9C9	2017-07-30 07:45:00+03	72400.00
A0F9CF	2017-07-19 05:42:00+03	32700.00
A0F9FC	2017-07-06 18:41:00+03	13600.00
A0FA0F	2017-07-05 07:04:00+03	16400.00
A0FABA	2017-08-02 09:50:00+03	111600.00
A0FAD0	2017-08-03 07:45:00+03	28800.00
A0FB1B	2017-07-25 03:09:00+03	24800.00
A0FB26	2017-07-28 20:34:00+03	33200.00
A0FB6D	2017-07-21 01:45:00+03	56600.00
A0FC12	2017-07-31 00:37:00+03	28800.00
A0FC46	2017-07-11 00:52:00+03	31600.00
A0FC4D	2017-08-01 02:02:00+03	23200.00
A0FC76	2017-07-19 18:02:00+03	92800.00
A0FC8F	2017-07-27 10:59:00+03	133200.00
A0FCA4	2017-08-11 19:23:00+03	271200.00
A0FCF6	2017-07-06 17:34:00+03	36600.00
A0FD07	2017-07-05 11:27:00+03	46300.00
A0FD6B	2017-07-31 01:05:00+03	52900.00
A0FDA4	2017-07-15 13:40:00+03	8000.00
A0FDC7	2017-07-27 23:42:00+03	148800.00
A0FDDC	2017-07-08 03:19:00+03	26800.00
A0FE5B	2017-08-01 06:28:00+03	95600.00
A0FE9D	2017-08-13 22:13:00+03	104200.00
A0FF5C	2017-08-01 02:01:00+03	27200.00
A0FFB1	2017-07-15 14:40:00+03	36200.00
A0FFC5	2017-07-25 20:16:00+03	80000.00
A1008E	2017-08-13 04:49:00+03	39100.00
A10094	2017-07-04 01:27:00+03	12000.00
A10095	2017-07-17 18:07:00+03	55500.00
A100A6	2017-08-09 06:24:00+03	23200.00
A100D7	2017-08-13 01:16:00+03	76800.00
A10112	2017-08-13 11:53:00+03	40100.00
A1015F	2017-07-05 00:37:00+03	78100.00
A10190	2017-07-19 05:39:00+03	131900.00
A10192	2017-07-25 01:03:00+03	93900.00
A101A0	2017-07-21 21:58:00+03	47100.00
A101F1	2017-07-08 20:21:00+03	39200.00
A101F6	2017-08-12 21:08:00+03	107600.00
A10242	2017-06-26 13:44:00+03	110500.00
A10280	2017-07-25 07:32:00+03	167400.00
A102A0	2017-07-14 18:17:00+03	76800.00
A102B5	2017-07-07 09:00:00+03	27000.00
A1034C	2017-07-20 22:17:00+03	26800.00
A103A0	2017-07-30 14:50:00+03	135200.00
A1041B	2017-07-17 16:01:00+03	136200.00
A10426	2017-07-02 19:11:00+03	15000.00
A1042F	2017-07-28 08:43:00+03	235200.00
A1047B	2017-07-05 00:38:00+03	57800.00
A1049C	2017-07-06 20:21:00+03	26400.00
A104E5	2017-07-04 17:57:00+03	34000.00
A104EA	2017-07-18 17:17:00+03	78600.00
A10511	2017-07-25 14:57:00+03	53400.00
A10541	2017-07-23 03:12:00+03	7300.00
A10592	2017-07-16 22:32:00+03	107200.00
A105C7	2017-07-25 15:52:00+03	271100.00
A105EB	2017-08-02 16:47:00+03	81200.00
A106B0	2017-07-26 19:47:00+03	13400.00
A106C7	2017-07-08 08:42:00+03	75300.00
A1070E	2017-06-26 05:49:00+03	115900.00
A10714	2017-07-13 14:53:00+03	35600.00
A10734	2017-07-03 11:40:00+03	40800.00
A10737	2017-07-31 12:07:00+03	6600.00
A107BD	2017-07-12 00:02:00+03	189200.00
A107CD	2017-07-10 12:49:00+03	135400.00
A107D7	2017-07-22 23:10:00+03	82600.00
A10825	2017-07-26 11:11:00+03	42400.00
A10850	2017-08-01 14:11:00+03	17800.00
A10882	2017-08-03 17:49:00+03	23400.00
A108DB	2017-08-12 03:50:00+03	23200.00
A10932	2017-07-09 06:46:00+03	25400.00
A10944	2017-08-14 23:52:00+03	9200.00
A10968	2017-08-14 18:31:00+03	65900.00
A109F6	2017-07-02 23:46:00+03	66600.00
A10A4C	2017-07-28 00:33:00+03	125600.00
A10A60	2017-08-03 02:50:00+03	34000.00
A10A99	2017-07-17 11:48:00+03	117100.00
A10B26	2017-07-07 12:00:00+03	98400.00
A10B57	2017-07-21 00:23:00+03	56200.00
A10B9B	2017-08-05 18:21:00+03	23200.00
A10B9F	2017-08-04 17:02:00+03	26000.00
A10BD4	2017-07-09 18:59:00+03	115800.00
A10BE5	2017-08-12 22:03:00+03	48800.00
A10C2D	2017-08-13 13:04:00+03	89600.00
A10CBD	2017-07-14 12:05:00+03	106400.00
A10CDF	2017-07-21 07:12:00+03	81700.00
A10DAE	2017-06-24 10:53:00+03	137200.00
A10DC4	2017-08-13 11:17:00+03	118000.00
A10DD2	2017-08-12 12:56:00+03	79600.00
A10E46	2017-08-02 00:07:00+03	153900.00
A10E94	2017-07-28 22:27:00+03	47000.00
A10EDB	2017-08-07 19:53:00+03	125400.00
A10F15	2017-07-08 11:13:00+03	146400.00
A10F1B	2017-07-16 20:05:00+03	266400.00
A10F3E	2017-07-24 04:32:00+03	201800.00
A10F4F	2017-07-28 19:51:00+03	155600.00
A10FD8	2017-07-03 06:27:00+03	75300.00
A10FF0	2017-08-11 01:25:00+03	58600.00
A1101E	2017-08-09 21:13:00+03	282100.00
A1102F	2017-07-24 22:04:00+03	84100.00
A11046	2017-07-10 00:43:00+03	36200.00
A1107D	2017-07-20 11:17:00+03	539400.00
A110B8	2017-07-11 05:18:00+03	93900.00
A1111B	2017-07-27 23:29:00+03	31600.00
A11229	2017-08-05 04:22:00+03	111700.00
A11262	2017-06-29 22:57:00+03	81600.00
A113BD	2017-07-16 01:38:00+03	14000.00
A11411	2017-07-16 09:58:00+03	80900.00
A114A1	2017-07-26 20:16:00+03	43200.00
A115C2	2017-07-22 08:40:00+03	123000.00
A115DC	2017-07-26 01:37:00+03	49800.00
A11671	2017-07-22 20:15:00+03	24400.00
A116BE	2017-07-09 02:45:00+03	58000.00
A11736	2017-07-24 13:44:00+03	182200.00
A1173F	2017-07-17 05:57:00+03	40000.00
A11743	2017-06-30 17:14:00+03	26000.00
A1175F	2017-07-15 11:01:00+03	77900.00
A11779	2017-07-19 14:09:00+03	98300.00
A1177B	2017-08-14 17:04:00+03	114700.00
A11787	2017-07-14 16:21:00+03	8200.00
A11794	2017-08-13 14:06:00+03	55800.00
A117AC	2017-08-12 02:14:00+03	54800.00
A117E2	2017-07-25 04:48:00+03	173500.00
A1186B	2017-07-29 11:10:00+03	89600.00
A118A2	2017-07-15 17:08:00+03	25100.00
A118B5	2017-07-16 11:56:00+03	56000.00
A118D5	2017-08-05 03:47:00+03	62800.00
A118D8	2017-07-28 08:29:00+03	46200.00
A11931	2017-08-07 20:43:00+03	22600.00
A1196D	2017-08-14 23:39:00+03	47100.00
A119AA	2017-08-09 15:37:00+03	88500.00
A11A59	2017-07-09 07:49:00+03	246000.00
A11A9F	2017-07-11 23:33:00+03	23600.00
A11AC5	2017-08-11 22:37:00+03	37100.00
A11AD1	2017-07-11 21:04:00+03	46200.00
A11AE6	2017-07-22 17:07:00+03	94900.00
A11B11	2017-07-05 16:00:00+03	22000.00
A11B3F	2017-07-22 14:30:00+03	23200.00
A11BB6	2017-07-31 04:18:00+03	113400.00
A11BC8	2017-06-30 20:17:00+03	200000.00
A11BD8	2017-08-04 06:58:00+03	23200.00
A11BF9	2017-08-12 09:40:00+03	50600.00
A11C54	2017-08-01 08:44:00+03	12600.00
A11D9A	2017-08-05 10:30:00+03	10700.00
A11DEB	2017-07-15 17:22:00+03	7400.00
A11E74	2017-08-05 22:02:00+03	55400.00
A11EC1	2017-08-05 10:31:00+03	27200.00
A11F0E	2017-07-19 01:09:00+03	89700.00
A11F3B	2017-08-03 18:12:00+03	40100.00
A11F45	2017-08-06 07:30:00+03	48500.00
A12006	2017-07-06 14:04:00+03	147900.00
A1209C	2017-07-13 17:45:00+03	128900.00
A120AF	2017-07-09 05:48:00+03	30900.00
A120B1	2017-07-04 21:06:00+03	56600.00
A120D8	2017-07-24 18:49:00+03	91800.00
A12186	2017-07-13 13:50:00+03	106700.00
A121BF	2017-07-12 19:23:00+03	44800.00
A121C3	2017-07-06 20:00:00+03	23600.00
A121C8	2017-08-04 16:26:00+03	75600.00
A121FD	2017-07-08 03:16:00+03	26000.00
A12214	2017-07-02 13:03:00+03	57800.00
A12258	2017-08-13 23:38:00+03	136200.00
A1225A	2017-08-06 11:19:00+03	77200.00
A12284	2017-08-09 02:42:00+03	69700.00
A122A3	2017-07-28 10:35:00+03	137600.00
A122BF	2017-07-30 12:16:00+03	142400.00
A122EA	2017-07-14 14:32:00+03	92800.00
A12391	2017-08-13 18:20:00+03	46500.00
A123A6	2017-07-13 08:22:00+03	259300.00
A123BD	2017-08-13 06:43:00+03	15700.00
A123D5	2017-07-14 07:53:00+03	202100.00
A1241F	2017-08-11 18:25:00+03	27200.00
A12437	2017-08-14 14:41:00+03	23100.00
A12481	2017-07-15 17:20:00+03	73600.00
A124FF	2017-07-17 04:55:00+03	51900.00
A12518	2017-07-12 21:00:00+03	58000.00
A12522	2017-07-12 00:05:00+03	67000.00
A1253E	2017-08-02 17:29:00+03	34000.00
A12623	2017-08-15 02:56:00+03	73500.00
A12637	2017-07-07 23:12:00+03	408400.00
A12746	2017-07-13 21:39:00+03	118500.00
A12772	2017-08-15 05:16:00+03	28000.00
A127A6	2017-06-30 07:54:00+03	56100.00
A127B2	2017-08-01 00:12:00+03	64400.00
A127E8	2017-07-28 10:58:00+03	369000.00
A1283B	2017-06-28 02:13:00+03	135600.00
A12869	2017-08-09 20:23:00+03	38400.00
A12892	2017-07-31 06:46:00+03	135000.00
A1290C	2017-08-07 23:59:00+03	56900.00
A12945	2017-07-23 03:41:00+03	123000.00
A12990	2017-07-17 04:01:00+03	23200.00
A129A1	2017-07-24 02:24:00+03	124200.00
A129AA	2017-07-15 03:06:00+03	84500.00
A129AF	2017-08-13 23:22:00+03	25600.00
A129D2	2017-08-08 00:00:00+03	159100.00
A129E1	2017-07-30 01:01:00+03	30800.00
A129F4	2017-08-13 12:07:00+03	53400.00
A129F8	2017-07-31 00:42:00+03	290400.00
A12A40	2017-08-14 20:03:00+03	115200.00
A12A87	2017-07-23 22:54:00+03	147200.00
A12ABD	2017-07-16 17:01:00+03	28800.00
A12ACC	2017-08-10 06:03:00+03	67200.00
A12B6A	2017-07-28 17:25:00+03	13800.00
A12B78	2017-08-07 17:21:00+03	77600.00
A12B85	2017-07-28 09:46:00+03	43600.00
A12BA3	2017-07-05 13:18:00+03	132800.00
A12C42	2017-07-19 23:11:00+03	136000.00
A12C92	2017-08-09 04:53:00+03	12400.00
A12CFB	2017-07-12 07:41:00+03	254600.00
A12D5C	2017-07-30 19:21:00+03	40800.00
A12D7D	2017-07-07 22:06:00+03	6000.00
A12DD5	2017-07-21 08:50:00+03	325500.00
A12DD9	2017-07-28 17:11:00+03	26200.00
A12DDB	2017-08-05 01:01:00+03	36000.00
A12E94	2017-06-29 21:52:00+03	135400.00
A12E97	2017-08-05 00:42:00+03	24700.00
A12EDA	2017-08-08 08:24:00+03	54800.00
A12EE7	2017-08-12 03:50:00+03	133100.00
A12EEA	2017-07-05 00:18:00+03	269600.00
A12F0F	2017-07-23 00:56:00+03	49400.00
A12F5A	2017-07-05 08:03:00+03	96800.00
A13181	2017-07-18 01:36:00+03	28000.00
A131DB	2017-07-24 03:04:00+03	213200.00
A13238	2017-08-13 01:41:00+03	94800.00
A13246	2017-07-26 18:54:00+03	23200.00
A132A0	2017-07-19 14:05:00+03	40900.00
A132E2	2017-08-06 19:16:00+03	78800.00
A1333E	2017-08-12 02:27:00+03	47000.00
A133B6	2017-07-06 00:25:00+03	417400.00
A133E9	2017-07-25 08:27:00+03	18300.00
A13436	2017-07-25 10:28:00+03	12200.00
A13474	2017-07-14 13:39:00+03	106100.00
A13519	2017-07-25 06:40:00+03	135400.00
A13537	2017-07-31 12:55:00+03	14000.00
A1355C	2017-07-23 10:46:00+03	103500.00
A135D3	2017-07-09 08:52:00+03	196000.00
A135F8	2017-07-28 15:48:00+03	69600.00
A13618	2017-08-04 05:59:00+03	54800.00
A13627	2017-07-04 04:23:00+03	56200.00
A13649	2017-07-13 03:23:00+03	62100.00
A1364B	2017-07-13 20:00:00+03	57600.00
A1364E	2017-08-10 04:04:00+03	28000.00
A1366E	2017-06-26 16:20:00+03	34600.00
A13687	2017-07-27 15:19:00+03	71600.00
A13692	2017-07-20 01:22:00+03	42400.00
A136A0	2017-07-17 09:13:00+03	135200.00
A136F3	2017-07-17 22:19:00+03	20200.00
A13700	2017-07-12 13:22:00+03	28000.00
A13743	2017-07-17 01:17:00+03	106800.00
A13869	2017-08-01 03:31:00+03	318300.00
A13873	2017-08-15 05:28:00+03	6600.00
A1389A	2017-07-29 06:42:00+03	34000.00
A138C2	2017-07-28 03:34:00+03	64800.00
A139C7	2017-07-17 21:36:00+03	97900.00
A139D4	2017-07-30 16:45:00+03	26800.00
A139DF	2017-07-02 12:06:00+03	85800.00
A13A0C	2017-08-15 01:57:00+03	100700.00
A13A5A	2017-07-15 08:06:00+03	419000.00
A13A9C	2017-08-02 01:35:00+03	73100.00
A13B36	2017-07-02 07:29:00+03	73300.00
A13B71	2017-07-17 08:51:00+03	46800.00
A13BB2	2017-08-05 10:39:00+03	131100.00
A13C02	2017-07-10 15:10:00+03	87700.00
A13C17	2017-07-22 05:53:00+03	41400.00
A13C52	2017-07-02 01:51:00+03	135400.00
A13D08	2017-07-26 17:42:00+03	67700.00
A13D45	2017-07-06 16:48:00+03	64600.00
A13E0F	2017-07-10 14:01:00+03	34000.00
A13E1B	2017-07-19 01:54:00+03	57500.00
A13E2C	2017-07-22 19:12:00+03	39800.00
A13E36	2017-08-02 02:24:00+03	72000.00
A13EA4	2017-07-10 09:30:00+03	20000.00
A13F79	2017-08-05 22:44:00+03	81700.00
A13F85	2017-07-06 16:11:00+03	97800.00
A13F9B	2017-07-03 03:36:00+03	22000.00
A13FB0	2017-08-12 00:35:00+03	23600.00
A13FC4	2017-07-21 08:54:00+03	40000.00
A14010	2017-07-03 23:50:00+03	70700.00
A1403D	2017-07-17 21:04:00+03	16400.00
A140A8	2017-07-10 15:07:00+03	191000.00
A140FE	2017-08-08 12:04:00+03	51600.00
A1410C	2017-07-03 01:26:00+03	34700.00
A14169	2017-07-14 10:59:00+03	69500.00
A14171	2017-07-05 08:29:00+03	48800.00
A14184	2017-08-14 00:24:00+03	48200.00
A141C6	2017-07-27 23:10:00+03	19800.00
A14266	2017-07-11 12:53:00+03	198400.00
A1428D	2017-07-13 23:09:00+03	26600.00
A142BA	2017-07-09 00:32:00+03	16400.00
A142DE	2017-08-05 03:21:00+03	23600.00
A14364	2017-08-15 15:05:00+03	53600.00
A143B5	2017-07-07 00:18:00+03	50900.00
A143F4	2017-08-11 14:26:00+03	80000.00
A1444B	2017-08-03 10:37:00+03	54500.00
A14505	2017-07-07 13:48:00+03	185300.00
A14514	2017-07-16 21:00:00+03	85000.00
A145FC	2017-07-18 03:42:00+03	47100.00
A1466B	2017-07-10 08:19:00+03	155600.00
A14674	2017-08-02 16:05:00+03	139000.00
A14687	2017-08-08 08:02:00+03	28800.00
A14794	2017-07-12 19:52:00+03	26800.00
A147AF	2017-07-08 02:45:00+03	50800.00
A1480C	2017-08-05 09:25:00+03	28800.00
A14831	2017-07-10 01:44:00+03	46300.00
A148C7	2017-06-30 02:33:00+03	183100.00
A1492A	2017-07-11 17:05:00+03	14000.00
A1496A	2017-07-29 15:01:00+03	99700.00
A14AA5	2017-08-13 20:26:00+03	11800.00
A14B1C	2017-07-06 06:42:00+03	141100.00
A14B2B	2017-07-22 10:55:00+03	39200.00
A14B53	2017-07-21 01:26:00+03	44800.00
A14BD0	2017-07-18 10:42:00+03	153200.00
A14BD9	2017-07-05 00:15:00+03	69400.00
A14BFA	2017-08-09 05:22:00+03	132600.00
A14C03	2017-08-11 17:18:00+03	166900.00
A14CB5	2017-08-13 03:07:00+03	52800.00
A14CCC	2017-07-16 11:10:00+03	30900.00
A14D4E	2017-07-29 09:16:00+03	135400.00
A14D7B	2017-08-03 09:20:00+03	132800.00
A14E69	2017-07-07 23:58:00+03	118500.00
A14EBD	2017-07-30 03:42:00+03	55800.00
A14F34	2017-07-24 22:49:00+03	19600.00
A14F63	2017-07-16 11:19:00+03	24000.00
A14F67	2017-07-30 02:57:00+03	154500.00
A1501D	2017-08-12 21:57:00+03	144300.00
A15038	2017-08-14 22:25:00+03	111600.00
A1506D	2017-08-08 05:35:00+03	46000.00
A1507A	2017-07-11 16:04:00+03	28000.00
A150CC	2017-08-10 00:20:00+03	174400.00
A150FA	2017-07-21 09:25:00+03	28800.00
A1514B	2017-07-07 02:03:00+03	24400.00
A15169	2017-07-15 21:39:00+03	57600.00
A15255	2017-07-12 14:08:00+03	106200.00
A1526B	2017-07-03 04:05:00+03	99200.00
A15285	2017-08-03 06:01:00+03	176100.00
A152EE	2017-07-14 00:35:00+03	18600.00
A15336	2017-07-20 12:41:00+03	46400.00
A15366	2017-07-25 08:25:00+03	12000.00
A1536E	2017-08-12 04:36:00+03	55800.00
A1538B	2017-07-26 13:15:00+03	35900.00
A153AC	2017-07-27 05:07:00+03	64700.00
A153F5	2017-08-13 11:17:00+03	123000.00
A15469	2017-07-01 21:58:00+03	59300.00
A15470	2017-08-06 04:29:00+03	7300.00
A154AA	2017-08-09 20:00:00+03	315600.00
A154B0	2017-07-15 18:39:00+03	66600.00
A15535	2017-07-01 15:23:00+03	83600.00
A15583	2017-07-12 19:03:00+03	25200.00
A155C0	2017-07-31 20:33:00+03	132800.00
A155C4	2017-07-25 14:34:00+03	40800.00
A15602	2017-08-04 02:32:00+03	38400.00
A1562E	2017-07-13 15:40:00+03	99200.00
A1567B	2017-06-25 02:22:00+03	46000.00
A1569D	2017-08-06 17:47:00+03	55800.00
A156C0	2017-07-08 14:57:00+03	41600.00
A156E5	2017-08-11 21:18:00+03	23200.00
A15732	2017-08-10 06:10:00+03	56000.00
A1577E	2017-07-14 07:16:00+03	72000.00
A15787	2017-08-15 12:12:00+03	65600.00
A15797	2017-07-06 15:58:00+03	19600.00
A157B7	2017-07-03 14:31:00+03	66600.00
A15810	2017-08-01 13:45:00+03	266400.00
A15818	2017-07-27 11:23:00+03	99300.00
A15835	2017-07-08 08:43:00+03	20200.00
A158DE	2017-07-11 19:47:00+03	56000.00
A158E5	2017-06-30 22:04:00+03	116000.00
A15910	2017-07-20 02:38:00+03	69900.00
A15926	2017-08-07 03:49:00+03	59200.00
A1593F	2017-08-13 19:01:00+03	46000.00
A1594D	2017-07-19 18:49:00+03	67600.00
A159B0	2017-08-11 10:11:00+03	37000.00
A159C5	2017-08-01 07:02:00+03	62000.00
A159E3	2017-08-03 15:12:00+03	26600.00
A159F1	2017-07-28 19:28:00+03	258400.00
A15A25	2017-08-09 20:41:00+03	66600.00
A15A28	2017-07-29 06:51:00+03	22000.00
A15A58	2017-07-03 13:26:00+03	111600.00
A15A61	2017-07-16 11:07:00+03	36000.00
A15AFD	2017-07-08 10:47:00+03	43400.00
A15B2B	2017-07-19 07:18:00+03	27800.00
A15BE8	2017-07-15 13:20:00+03	40000.00
A15C25	2017-08-07 14:40:00+03	184000.00
A15C6E	2017-07-18 19:30:00+03	36500.00
A15C85	2017-07-20 06:54:00+03	205200.00
A15CAA	2017-07-21 16:38:00+03	92800.00
A15CF2	2017-08-08 04:45:00+03	332700.00
A15D1B	2017-07-17 12:04:00+03	44600.00
A15D1E	2017-06-30 11:34:00+03	39800.00
A15E7D	2017-07-14 02:09:00+03	77200.00
A15EB4	2017-07-22 07:14:00+03	94000.00
A15F37	2017-07-29 08:42:00+03	399600.00
A15F9C	2017-08-07 17:53:00+03	92700.00
A15FD8	2017-07-07 20:56:00+03	90200.00
A16079	2017-08-02 01:19:00+03	113600.00
A160A4	2017-08-06 07:32:00+03	89700.00
A160B3	2017-07-30 13:03:00+03	142400.00
A160BD	2017-07-22 21:07:00+03	86600.00
A160CC	2017-06-27 07:34:00+03	28000.00
A160DA	2017-08-06 20:26:00+03	49100.00
A16120	2017-07-19 15:43:00+03	129700.00
A1614A	2017-08-02 01:03:00+03	86600.00
A161BB	2017-08-03 16:36:00+03	58700.00
A161DF	2017-07-04 23:29:00+03	32800.00
A161EE	2017-08-04 13:39:00+03	86400.00
A16216	2017-07-07 14:39:00+03	161900.00
A1624E	2017-07-09 07:40:00+03	30200.00
A16287	2017-07-15 08:52:00+03	104600.00
A162FA	2017-08-05 08:31:00+03	43200.00
A1636A	2017-07-05 14:10:00+03	44800.00
A1636C	2017-07-10 18:18:00+03	174900.00
A1638C	2017-08-08 17:23:00+03	23400.00
A1639A	2017-08-09 23:43:00+03	203000.00
A1641A	2017-07-11 10:39:00+03	63500.00
A1644C	2017-08-11 02:17:00+03	126200.00
A1645A	2017-07-07 04:14:00+03	73300.00
A16594	2017-08-08 20:49:00+03	203500.00
A1660A	2017-07-13 13:02:00+03	97900.00
A16621	2017-08-03 01:14:00+03	13000.00
A1662A	2017-07-17 05:43:00+03	393800.00
A16651	2017-07-01 17:20:00+03	24400.00
A16668	2017-08-05 18:31:00+03	28800.00
A1667D	2017-08-05 01:39:00+03	59800.00
A16692	2017-08-14 03:24:00+03	20800.00
A166BB	2017-08-12 22:31:00+03	206100.00
A166C4	2017-07-22 12:20:00+03	37400.00
A166C8	2017-07-04 12:35:00+03	108000.00
A166DB	2017-07-25 10:36:00+03	25400.00
A166E0	2017-08-07 07:58:00+03	43200.00
A16761	2017-07-26 08:01:00+03	178800.00
A167BB	2017-07-03 00:52:00+03	111600.00
A167F3	2017-07-14 02:58:00+03	62700.00
A16813	2017-07-29 15:39:00+03	23400.00
A16868	2017-07-13 21:09:00+03	29600.00
A16878	2017-08-14 14:52:00+03	112000.00
A1688B	2017-07-02 19:19:00+03	23200.00
A168E8	2017-07-27 00:12:00+03	41200.00
A16941	2017-07-06 16:19:00+03	86200.00
A16947	2017-07-26 01:49:00+03	21000.00
A1696E	2017-08-08 20:04:00+03	54800.00
A16A97	2017-07-12 05:10:00+03	34100.00
A16AA7	2017-07-25 19:29:00+03	65500.00
A16AD7	2017-08-08 16:25:00+03	43200.00
A16AE7	2017-08-15 10:36:00+03	42800.00
A16AEA	2017-08-03 11:23:00+03	44800.00
A16B13	2017-08-11 18:45:00+03	37100.00
A16B46	2017-08-09 09:32:00+03	190300.00
A16B4F	2017-07-10 12:49:00+03	41900.00
A16BD9	2017-08-04 09:47:00+03	46400.00
A16BEC	2017-07-23 10:11:00+03	29600.00
A16C25	2017-08-11 22:18:00+03	76100.00
A16C30	2017-07-28 12:58:00+03	4000.00
A16C31	2017-07-05 16:11:00+03	77000.00
A16C33	2017-07-10 20:05:00+03	26500.00
A16C38	2017-08-08 21:25:00+03	147300.00
A16C57	2017-08-03 17:02:00+03	135200.00
A16C98	2017-07-03 18:36:00+03	32800.00
A16D2A	2017-07-31 04:03:00+03	42800.00
A16DDB	2017-07-27 14:20:00+03	43200.00
A16DF3	2017-07-05 09:54:00+03	52200.00
A16DF9	2017-07-23 20:31:00+03	136500.00
A16E0C	2017-07-23 11:05:00+03	13400.00
A16E45	2017-07-23 22:01:00+03	35600.00
A16E82	2017-07-23 21:42:00+03	49100.00
A16F13	2017-07-03 04:31:00+03	96300.00
A16F18	2017-08-11 22:40:00+03	37000.00
A16F1C	2017-07-28 07:46:00+03	59800.00
A16F4E	2017-08-07 21:39:00+03	54000.00
A16F72	2017-08-06 07:22:00+03	301800.00
A16F84	2017-08-08 16:15:00+03	72800.00
A16FEB	2017-08-12 05:20:00+03	27900.00
A1702A	2017-07-02 17:08:00+03	186900.00
A17034	2017-07-29 16:12:00+03	265600.00
A17044	2017-07-27 06:26:00+03	48000.00
A170A9	2017-07-24 12:09:00+03	260300.00
A170C9	2017-07-11 00:05:00+03	43200.00
A1713A	2017-07-25 09:39:00+03	56900.00
A17220	2017-07-06 05:18:00+03	56000.00
A17259	2017-07-07 14:22:00+03	29600.00
A172A5	2017-07-14 02:34:00+03	137600.00
A172CE	2017-07-14 20:08:00+03	28000.00
A17365	2017-07-15 21:30:00+03	60000.00
A17366	2017-07-09 15:51:00+03	70600.00
A1737B	2017-08-02 10:30:00+03	46000.00
A1737F	2017-07-22 13:42:00+03	229800.00
A173DF	2017-07-11 23:50:00+03	67600.00
A1741D	2017-07-09 17:52:00+03	58200.00
A17458	2017-08-01 19:06:00+03	132800.00
A1748D	2017-08-11 21:40:00+03	22000.00
A174AA	2017-07-28 13:13:00+03	81300.00
A174C3	2017-08-10 20:39:00+03	29000.00
A1751C	2017-08-10 17:58:00+03	7200.00
A1756A	2017-07-02 10:34:00+03	43900.00
A1758B	2017-08-10 18:52:00+03	33300.00
A175C3	2017-08-01 07:55:00+03	44200.00
A17610	2017-07-29 22:39:00+03	26000.00
A1767F	2017-07-22 09:08:00+03	123000.00
A176B7	2017-07-22 11:33:00+03	49100.00
A17745	2017-07-16 17:32:00+03	86500.00
A1776D	2017-08-07 06:26:00+03	136200.00
A17784	2017-07-31 15:42:00+03	40000.00
A1778A	2017-07-13 05:18:00+03	24400.00
A177A4	2017-07-21 14:09:00+03	77900.00
A177CE	2017-08-03 20:31:00+03	47100.00
A177D9	2017-07-08 14:05:00+03	16400.00
A177EF	2017-08-11 18:18:00+03	24400.00
A177F6	2017-08-06 16:18:00+03	53300.00
A1782F	2017-07-16 04:58:00+03	111600.00
A17891	2017-08-04 18:02:00+03	406700.00
A1789C	2017-07-06 13:49:00+03	6800.00
A17975	2017-07-21 16:00:00+03	57500.00
A17976	2017-07-11 11:00:00+03	92800.00
A1799F	2017-07-12 06:50:00+03	23400.00
A179AF	2017-07-06 04:40:00+03	66000.00
A179F6	2017-07-05 11:58:00+03	25600.00
A17A08	2017-07-12 01:12:00+03	92400.00
A17ADB	2017-08-11 06:02:00+03	144000.00
A17B3B	2017-07-26 04:12:00+03	56000.00
A17B9D	2017-07-12 14:56:00+03	52700.00
A17BF1	2017-08-04 09:20:00+03	75600.00
A17C05	2017-07-09 12:06:00+03	44500.00
A17C3B	2017-07-04 19:07:00+03	169300.00
A17C9C	2017-08-04 00:30:00+03	58600.00
A17D95	2017-07-19 22:39:00+03	289800.00
A17DAE	2017-08-12 05:32:00+03	188000.00
A17DBB	2017-07-11 19:54:00+03	246000.00
A17DE5	2017-08-08 03:44:00+03	58600.00
A17E74	2017-07-02 02:53:00+03	55800.00
A17E76	2017-07-25 18:06:00+03	131600.00
A17EAD	2017-07-27 07:15:00+03	282000.00
A17EC4	2017-08-08 16:35:00+03	13200.00
A17F52	2017-07-15 10:54:00+03	64100.00
A17F58	2017-08-13 14:37:00+03	186500.00
A17FAA	2017-08-13 18:35:00+03	45200.00
A17FE9	2017-07-08 09:34:00+03	17200.00
A17FF2	2017-07-06 04:37:00+03	101200.00
A18031	2017-07-23 01:32:00+03	23200.00
A18045	2017-07-22 03:46:00+03	92000.00
A18054	2017-07-21 06:00:00+03	111600.00
A18091	2017-07-04 21:43:00+03	12600.00
A180DE	2017-07-02 18:31:00+03	119500.00
A18165	2017-07-14 07:04:00+03	70400.00
A181AF	2017-07-04 08:48:00+03	16400.00
A181B1	2017-08-05 08:08:00+03	66600.00
A181B3	2017-07-26 12:58:00+03	71600.00
A18241	2017-08-11 05:13:00+03	45100.00
A182C6	2017-07-09 13:26:00+03	55800.00
A1831A	2017-07-16 15:18:00+03	43400.00
A18329	2017-07-03 10:20:00+03	25200.00
A1833C	2017-07-03 04:03:00+03	27800.00
A183C4	2017-08-04 12:41:00+03	26000.00
A183F7	2017-07-27 09:35:00+03	135200.00
A1842B	2017-08-13 23:37:00+03	13600.00
A18447	2017-07-03 22:26:00+03	78600.00
A1848D	2017-07-13 09:15:00+03	56600.00
A184A0	2017-08-15 12:19:00+03	85200.00
A184AD	2017-07-03 00:07:00+03	54700.00
A184BD	2017-08-14 05:17:00+03	101200.00
A184EE	2017-07-04 09:06:00+03	23600.00
A184F4	2017-07-02 09:54:00+03	113600.00
A18515	2017-08-15 00:53:00+03	193300.00
A18517	2017-07-30 17:35:00+03	31400.00
A1854F	2017-08-07 22:07:00+03	28800.00
A185B8	2017-07-16 06:07:00+03	76800.00
A185D1	2017-07-10 14:36:00+03	39300.00
A185D7	2017-07-09 00:11:00+03	25400.00
A1860B	2017-07-27 17:58:00+03	59800.00
A1860F	2017-08-07 12:13:00+03	55800.00
A18610	2017-07-31 13:12:00+03	99200.00
A18664	2017-07-27 00:57:00+03	154800.00
A18670	2017-07-04 03:17:00+03	28000.00
A186B1	2017-08-12 16:36:00+03	24400.00
A186C8	2017-07-01 04:04:00+03	82900.00
A1877D	2017-07-27 07:00:00+03	26000.00
A18803	2017-07-22 10:47:00+03	34000.00
A18828	2017-07-23 01:42:00+03	27200.00
A188BE	2017-06-28 04:20:00+03	66600.00
A1893D	2017-07-18 13:40:00+03	131600.00
A18970	2017-07-19 14:56:00+03	221100.00
A189C8	2017-07-06 22:30:00+03	135000.00
A189FF	2017-07-24 06:42:00+03	28000.00
A18A4D	2017-07-28 21:22:00+03	92800.00
A18A71	2017-07-28 18:16:00+03	145700.00
A18A95	2017-07-04 06:56:00+03	144400.00
A18AB4	2017-07-26 11:31:00+03	21400.00
A18B43	2017-07-14 09:16:00+03	67600.00
A18B5D	2017-08-14 01:11:00+03	40100.00
A18BD1	2017-08-13 15:38:00+03	27400.00
A18C7E	2017-07-19 04:00:00+03	19600.00
A18C95	2017-08-10 13:29:00+03	82900.00
A18CAB	2017-07-16 13:04:00+03	31400.00
A18D18	2017-07-31 21:35:00+03	174400.00
A18D26	2017-07-24 16:27:00+03	64700.00
A18D5E	2017-07-18 00:41:00+03	28000.00
A18D99	2017-07-18 19:59:00+03	56600.00
A18DD5	2017-08-11 07:08:00+03	117700.00
A18E58	2017-07-17 10:45:00+03	44000.00
A18ED9	2017-07-19 10:45:00+03	59200.00
A18EDF	2017-07-21 03:13:00+03	33300.00
A18F06	2017-07-01 12:03:00+03	265600.00
A18F0F	2017-07-07 08:38:00+03	80900.00
A18F6F	2017-08-12 19:03:00+03	59800.00
A18F8A	2017-07-05 10:34:00+03	36200.00
A19010	2017-07-12 00:52:00+03	131600.00
A19070	2017-08-01 10:24:00+03	28000.00
A190B9	2017-07-25 13:25:00+03	28300.00
A19101	2017-08-12 16:11:00+03	58200.00
A1916B	2017-07-20 11:17:00+03	47100.00
A191AE	2017-08-05 17:08:00+03	28800.00
A1922A	2017-08-02 06:31:00+03	40800.00
A19243	2017-08-11 03:43:00+03	113200.00
A192EF	2017-07-19 21:45:00+03	73600.00
A19330	2017-07-15 02:45:00+03	67600.00
A19372	2017-07-17 17:52:00+03	6300.00
A19377	2017-08-06 00:50:00+03	39400.00
A1943F	2017-07-23 07:29:00+03	40100.00
A19466	2017-07-21 03:26:00+03	97100.00
A194E1	2017-07-23 15:30:00+03	135400.00
A194ED	2017-07-17 02:37:00+03	56000.00
A19521	2017-07-28 14:41:00+03	98200.00
A1958E	2017-08-06 23:01:00+03	27800.00
A1959E	2017-07-05 06:21:00+03	133200.00
A195B5	2017-08-09 07:45:00+03	248300.00
A195CA	2017-08-06 11:30:00+03	41400.00
A1962F	2017-07-06 15:12:00+03	56000.00
A19674	2017-07-19 00:13:00+03	24400.00
A196D5	2017-07-08 17:30:00+03	32900.00
A19735	2017-07-24 08:43:00+03	56000.00
A197C5	2017-07-04 17:30:00+03	121400.00
A1980F	2017-08-08 11:50:00+03	43800.00
A19820	2017-08-14 06:03:00+03	15000.00
A19888	2017-07-31 09:31:00+03	133100.00
A198ED	2017-08-05 06:34:00+03	64700.00
A19909	2017-08-07 04:12:00+03	6800.00
A1997B	2017-07-26 15:39:00+03	52900.00
A199A7	2017-08-15 01:09:00+03	47800.00
A199D2	2017-07-16 00:03:00+03	56000.00
A199E1	2017-07-20 23:36:00+03	26800.00
A19A29	2017-07-07 16:05:00+03	48900.00
A19A39	2017-07-13 06:46:00+03	15400.00
A19ABF	2017-08-03 09:50:00+03	46400.00
A19AC0	2017-08-07 23:08:00+03	66600.00
A19B16	2017-07-05 18:57:00+03	49200.00
A19B67	2017-07-30 03:35:00+03	27800.00
A19BB2	2017-07-02 07:24:00+03	15900.00
A19BBD	2017-08-08 04:40:00+03	88800.00
A19C0B	2017-07-07 06:01:00+03	93900.00
A19C23	2017-07-05 13:19:00+03	133100.00
A19D09	2017-07-21 07:10:00+03	46400.00
A19D3C	2017-08-07 08:17:00+03	54800.00
A19D50	2017-07-15 23:29:00+03	61800.00
A19D64	2017-08-07 18:18:00+03	44000.00
A19DA5	2017-07-23 14:52:00+03	182200.00
A19DB9	2017-06-30 22:46:00+03	10800.00
A19E44	2017-08-10 10:48:00+03	20000.00
A19ED3	2017-07-25 17:48:00+03	14400.00
A19EE3	2017-07-16 18:58:00+03	13400.00
A19F1C	2017-07-02 03:36:00+03	6800.00
A19F58	2017-08-07 20:35:00+03	229900.00
A19F77	2017-08-14 08:34:00+03	25100.00
A19FE2	2017-08-15 03:17:00+03	12600.00
A19FF6	2017-07-19 03:10:00+03	22000.00
A1A0DC	2017-08-11 17:10:00+03	62600.00
A1A0FC	2017-08-03 13:15:00+03	22000.00
A1A11F	2017-07-15 18:36:00+03	23200.00
A1A1EC	2017-08-02 05:24:00+03	66600.00
A1A20A	2017-08-10 17:43:00+03	286800.00
A1A239	2017-08-06 04:57:00+03	50200.00
A1A25A	2017-07-21 21:09:00+03	80500.00
A1A284	2017-07-20 19:48:00+03	6000.00
A1A2B7	2017-08-07 00:10:00+03	14800.00
A1A30E	2017-08-11 01:57:00+03	175300.00
A1A3D0	2017-08-14 08:05:00+03	149800.00
A1A400	2017-08-06 17:05:00+03	227500.00
A1A401	2017-07-03 19:38:00+03	55600.00
A1A445	2017-07-16 10:22:00+03	50400.00
A1A465	2017-08-15 17:13:00+03	16000.00
A1A4A8	2017-07-01 16:37:00+03	7400.00
A1A4E7	2017-07-13 08:43:00+03	56100.00
A1A4F2	2017-07-10 07:10:00+03	76800.00
A1A532	2017-07-19 10:46:00+03	56500.00
A1A545	2017-08-15 16:04:00+03	37900.00
A1A54A	2017-07-06 06:15:00+03	77400.00
A1A5B9	2017-07-20 18:33:00+03	375200.00
A1A5F5	2017-07-04 11:38:00+03	38800.00
A1A623	2017-07-20 08:55:00+03	57600.00
A1A67E	2017-08-06 17:02:00+03	69500.00
A1A684	2017-08-01 15:52:00+03	57300.00
A1A6A3	2017-07-08 05:22:00+03	36800.00
A1A6C2	2017-07-25 02:30:00+03	17200.00
A1A76A	2017-07-08 00:52:00+03	56600.00
A1A76C	2017-07-25 01:52:00+03	26000.00
A1A7DF	2017-07-24 18:38:00+03	136500.00
A1A7EC	2017-08-04 11:03:00+03	56000.00
A1A811	2017-07-28 04:03:00+03	198400.00
A1A81A	2017-08-15 01:27:00+03	88900.00
A1A86E	2017-08-01 08:22:00+03	104000.00
A1A8B2	2017-07-22 22:52:00+03	44800.00
A1A8D6	2017-07-09 05:31:00+03	86500.00
A1A921	2017-08-09 22:04:00+03	75200.00
A1A922	2017-08-06 17:04:00+03	20800.00
A1A938	2017-07-27 03:39:00+03	14000.00
A1A979	2017-07-08 15:43:00+03	84100.00
A1A9B5	2017-07-18 00:56:00+03	38200.00
A1A9C8	2017-07-18 19:09:00+03	105000.00
A1AA3C	2017-07-10 17:02:00+03	52000.00
A1AA43	2017-08-06 07:06:00+03	54800.00
A1AA51	2017-08-08 08:44:00+03	56000.00
A1AA5E	2017-07-27 16:35:00+03	199700.00
A1AA81	2017-08-04 22:42:00+03	92800.00
A1AAFA	2017-07-09 01:48:00+03	112000.00
A1AB8B	2017-08-10 22:32:00+03	270000.00
A1AB9A	2017-07-16 02:22:00+03	136200.00
A1ABC4	2017-07-23 04:35:00+03	109600.00
A1ABCF	2017-07-20 23:16:00+03	136200.00
A1ABD5	2017-07-13 07:18:00+03	44800.00
A1AC34	2017-06-30 17:55:00+03	66600.00
A1AC5A	2017-08-01 05:04:00+03	22000.00
A1AC80	2017-07-11 23:47:00+03	26000.00
A1AD0C	2017-07-04 20:37:00+03	60700.00
A1AD46	2017-08-13 03:49:00+03	45900.00
A1AD9B	2017-07-30 16:09:00+03	62600.00
A1ADA1	2017-07-15 12:20:00+03	98600.00
A1ADDF	2017-07-07 13:27:00+03	164700.00
A1AE47	2017-07-25 01:31:00+03	341200.00
A1AE77	2017-08-05 20:51:00+03	23400.00
A1AEB3	2017-08-13 18:07:00+03	167400.00
A1AF03	2017-08-05 23:23:00+03	20400.00
A1AFA6	2017-07-14 09:44:00+03	73300.00
A1AFB1	2017-07-14 13:15:00+03	47000.00
A1AFB6	2017-08-04 12:56:00+03	23600.00
A1AFC9	2017-07-08 11:51:00+03	48400.00
A1B031	2017-07-12 15:45:00+03	44000.00
A1B078	2017-08-05 02:24:00+03	28000.00
A1B085	2017-07-23 05:23:00+03	33300.00
A1B0FC	2017-07-24 00:32:00+03	265700.00
A1B16B	2017-08-04 09:21:00+03	118100.00
A1B18E	2017-07-04 22:30:00+03	27200.00
A1B1A6	2017-08-07 15:04:00+03	53300.00
A1B1EA	2017-08-07 11:02:00+03	28300.00
A1B203	2017-07-04 19:23:00+03	246000.00
A1B233	2017-08-07 04:18:00+03	246000.00
A1B276	2017-08-01 18:15:00+03	55800.00
A1B351	2017-07-22 07:00:00+03	46200.00
A1B362	2017-07-31 17:00:00+03	40000.00
A1B3A1	2017-07-27 14:45:00+03	132800.00
A1B40A	2017-08-12 20:21:00+03	135600.00
A1B45D	2017-07-07 11:51:00+03	35200.00
A1B47E	2017-07-27 03:59:00+03	141500.00
A1B4D7	2017-08-14 22:37:00+03	24000.00
A1B501	2017-08-14 18:30:00+03	25800.00
A1B562	2017-07-06 16:38:00+03	64800.00
A1B564	2017-07-17 01:31:00+03	99200.00
A1B57A	2017-08-13 08:24:00+03	12600.00
A1B5C7	2017-07-20 11:59:00+03	27300.00
A1B5DA	2017-08-13 06:30:00+03	44800.00
A1B665	2017-07-31 23:57:00+03	46000.00
A1B683	2017-08-13 11:59:00+03	37700.00
A1B68E	2017-07-30 09:50:00+03	147700.00
A1B696	2017-07-21 01:11:00+03	65900.00
A1B6A9	2017-07-06 00:02:00+03	68400.00
A1B71D	2017-07-18 10:30:00+03	42000.00
A1B735	2017-07-24 06:41:00+03	135400.00
A1B76E	2017-07-29 13:35:00+03	46400.00
A1B798	2017-07-21 01:59:00+03	480600.00
A1B7AD	2017-07-20 05:08:00+03	19000.00
A1B816	2017-07-13 23:00:00+03	177200.00
A1B834	2017-07-28 00:33:00+03	48100.00
A1B85A	2017-08-12 09:30:00+03	50100.00
A1B85B	2017-07-05 19:53:00+03	117200.00
A1B92A	2017-07-17 04:55:00+03	47700.00
A1B957	2017-08-01 18:34:00+03	23200.00
A1B974	2017-07-16 12:37:00+03	13200.00
A1B987	2017-07-07 22:18:00+03	103800.00
A1B9C4	2017-08-14 23:57:00+03	85000.00
A1B9C6	2017-07-05 08:23:00+03	40400.00
A1BA52	2017-08-15 14:57:00+03	34000.00
A1BA6B	2017-07-10 08:45:00+03	19600.00
A1BA7E	2017-07-14 20:29:00+03	115300.00
A1BACF	2017-08-02 19:34:00+03	246000.00
A1BB3F	2017-08-14 08:36:00+03	40100.00
A1BB73	2017-08-02 05:04:00+03	20200.00
A1BBC7	2017-08-04 23:50:00+03	47900.00
A1BC03	2017-07-26 10:23:00+03	133100.00
A1BC2D	2017-07-18 09:05:00+03	17800.00
A1BC4F	2017-08-08 01:55:00+03	114200.00
A1BCE9	2017-06-28 02:37:00+03	36400.00
A1BD02	2017-08-05 13:02:00+03	8000.00
A1BD52	2017-08-12 09:56:00+03	49500.00
A1BD76	2017-07-03 22:07:00+03	246000.00
A1BD7C	2017-08-14 07:36:00+03	32700.00
A1BDAE	2017-08-09 23:09:00+03	147100.00
A1BDB2	2017-07-08 06:05:00+03	19600.00
A1BDB9	2017-06-29 09:56:00+03	38500.00
A1BDC6	2017-08-03 02:59:00+03	12600.00
A1BE15	2017-08-05 21:29:00+03	46000.00
A1BE68	2017-07-01 17:51:00+03	96800.00
A1BE90	2017-07-09 05:41:00+03	62600.00
A1BF2D	2017-08-10 05:49:00+03	37200.00
A1BF4D	2017-06-29 04:54:00+03	123000.00
A1C006	2017-07-25 14:31:00+03	23400.00
A1C091	2017-07-14 07:39:00+03	38400.00
A1C0B6	2017-07-16 23:29:00+03	24800.00
A1C111	2017-08-03 05:26:00+03	20200.00
A1C128	2017-08-12 21:26:00+03	14800.00
A1C1EB	2017-07-19 11:49:00+03	52900.00
A1C282	2017-07-14 00:34:00+03	21400.00
A1C2DB	2017-07-27 21:19:00+03	6000.00
A1C34B	2017-07-04 23:03:00+03	123200.00
A1C3C0	2017-07-11 17:24:00+03	87100.00
A1C3DA	2017-08-04 16:56:00+03	81400.00
A1C3DC	2017-07-14 11:01:00+03	123000.00
A1C4E8	2017-07-01 20:44:00+03	54300.00
A1C51C	2017-06-28 01:48:00+03	80900.00
A1C617	2017-07-22 22:14:00+03	23600.00
A1C6A6	2017-08-07 09:25:00+03	35700.00
A1C6C7	2017-07-02 03:54:00+03	32700.00
A1C72C	2017-08-02 19:25:00+03	34400.00
A1C72F	2017-07-05 05:46:00+03	23200.00
A1C73F	2017-08-03 07:15:00+03	28000.00
A1C786	2017-07-31 10:22:00+03	23200.00
A1C7B1	2017-07-10 01:37:00+03	44600.00
A1C7B7	2017-07-03 01:13:00+03	23900.00
A1C7CB	2017-07-04 15:33:00+03	22000.00
A1C7E1	2017-08-06 06:21:00+03	6800.00
A1C878	2017-07-19 11:13:00+03	23200.00
A1C88D	2017-07-28 00:59:00+03	44000.00
A1C8A0	2017-08-14 02:00:00+03	133200.00
A1C8A4	2017-08-03 03:29:00+03	134400.00
A1C8B7	2017-07-11 13:01:00+03	6600.00
A1C92F	2017-07-10 08:04:00+03	39300.00
A1C950	2017-08-10 17:19:00+03	6700.00
A1C973	2017-08-08 17:11:00+03	32800.00
A1C9F8	2017-07-30 22:12:00+03	43900.00
A1CA12	2017-07-21 19:02:00+03	27800.00
A1CA17	2017-07-02 11:32:00+03	25000.00
A1CA30	2017-07-16 04:27:00+03	6000.00
A1CA68	2017-07-10 08:22:00+03	73600.00
A1CAE8	2017-07-17 05:13:00+03	36800.00
A1CB44	2017-08-14 11:27:00+03	265800.00
A1CB67	2017-07-14 08:54:00+03	131100.00
A1CBB7	2017-08-14 03:40:00+03	28800.00
A1CBE9	2017-07-10 19:58:00+03	23600.00
A1CC06	2017-08-03 16:41:00+03	62600.00
A1CC46	2017-07-22 22:05:00+03	38300.00
A1CD7B	2017-07-18 03:13:00+03	94700.00
A1CD81	2017-08-13 02:09:00+03	23200.00
A1CE0D	2017-07-05 19:05:00+03	38800.00
A1CE5E	2017-08-15 05:51:00+03	397100.00
A1CE85	2017-07-12 17:09:00+03	136800.00
A1CECB	2017-07-21 13:27:00+03	42900.00
A1CF56	2017-07-20 16:34:00+03	398400.00
A1CF59	2017-08-05 15:11:00+03	175000.00
A1CFB4	2017-07-25 10:57:00+03	32700.00
A1CFEA	2017-07-09 01:23:00+03	132800.00
A1D00A	2017-07-18 20:04:00+03	360600.00
A1D041	2017-07-02 09:04:00+03	43800.00
A1D062	2017-08-06 11:58:00+03	190100.00
A1D087	2017-08-03 12:07:00+03	81700.00
A1D08E	2017-08-12 17:26:00+03	61900.00
A1D099	2017-08-11 00:19:00+03	132500.00
A1D0C0	2017-08-05 07:52:00+03	40400.00
A1D187	2017-07-01 18:03:00+03	169900.00
A1D1A5	2017-07-31 23:34:00+03	49600.00
A1D243	2017-07-12 01:51:00+03	56600.00
A1D263	2017-08-11 13:29:00+03	61900.00
A1D2D3	2017-07-13 00:38:00+03	3700.00
A1D2D6	2017-07-29 11:38:00+03	27800.00
A1D2E1	2017-07-16 12:37:00+03	6000.00
A1D2F1	2017-08-06 10:46:00+03	11300.00
A1D2F2	2017-07-13 02:06:00+03	11000.00
A1D335	2017-08-02 22:38:00+03	23200.00
A1D33B	2017-07-24 18:29:00+03	55800.00
A1D36B	2017-08-15 05:51:00+03	100200.00
A1D371	2017-07-19 11:55:00+03	99300.00
A1D379	2017-07-10 03:43:00+03	28800.00
A1D394	2017-08-12 01:31:00+03	177200.00
A1D3C0	2017-07-12 16:38:00+03	42800.00
A1D3ED	2017-07-14 11:19:00+03	39600.00
A1D459	2017-08-06 19:04:00+03	48800.00
A1D464	2017-08-12 15:03:00+03	81700.00
A1D48D	2017-07-07 13:10:00+03	55800.00
A1D4A1	2017-07-08 16:33:00+03	135800.00
A1D4B9	2017-08-15 00:43:00+03	26000.00
A1D4D4	2017-07-29 06:47:00+03	16400.00
A1D515	2017-08-02 08:16:00+03	166300.00
A1D548	2017-06-27 02:30:00+03	58400.00
A1D563	2017-08-09 08:43:00+03	116900.00
A1D58F	2017-07-05 16:16:00+03	156600.00
A1D664	2017-07-26 05:08:00+03	111700.00
A1D6A3	2017-07-17 06:03:00+03	88600.00
A1D6EC	2017-07-26 10:02:00+03	61600.00
A1D705	2017-07-15 10:55:00+03	37900.00
A1D742	2017-07-02 14:44:00+03	31400.00
A1D7B0	2017-07-08 12:27:00+03	408500.00
A1D7B1	2017-07-04 10:49:00+03	58800.00
A1D7FD	2017-07-21 15:16:00+03	148200.00
A1D805	2017-07-25 17:05:00+03	321100.00
A1D825	2017-08-08 01:35:00+03	112600.00
A1D83D	2017-07-24 15:56:00+03	36500.00
A1D8E1	2017-07-13 03:05:00+03	91800.00
A1D935	2017-07-15 08:54:00+03	53600.00
A1D937	2017-08-02 23:12:00+03	85000.00
A1D96C	2017-07-09 01:14:00+03	14800.00
A1D98D	2017-08-12 15:40:00+03	58800.00
A1D9A8	2017-07-10 17:31:00+03	36200.00
A1D9AD	2017-07-30 04:01:00+03	58200.00
A1D9B0	2017-07-09 20:19:00+03	25400.00
A1D9E0	2017-07-17 13:53:00+03	27300.00
A1D9F8	2017-07-02 12:32:00+03	27200.00
A1DAE5	2017-08-12 18:45:00+03	46400.00
A1DB2D	2017-07-09 17:06:00+03	22000.00
A1DB3D	2017-07-22 11:31:00+03	103500.00
A1DB4A	2017-08-04 16:14:00+03	57600.00
A1DB89	2017-07-17 11:56:00+03	23600.00
A1DBAC	2017-07-19 16:03:00+03	16400.00
A1DBDB	2017-08-01 03:37:00+03	185600.00
A1DC23	2017-07-03 22:55:00+03	55800.00
A1DC28	2017-07-18 19:06:00+03	138400.00
A1DDB9	2017-08-12 15:16:00+03	26000.00
A1DDD7	2017-08-15 17:15:00+03	114300.00
A1DDF8	2017-07-19 21:39:00+03	13200.00
A1DDFF	2017-07-18 13:25:00+03	162700.00
A1DEEA	2017-07-21 11:24:00+03	129200.00
A1DEF1	2017-07-18 18:15:00+03	52000.00
A1DF24	2017-08-02 20:31:00+03	16800.00
A1DF25	2017-08-13 05:35:00+03	80600.00
A1DF5E	2017-07-18 14:04:00+03	185300.00
A1DF9E	2017-07-15 04:50:00+03	16800.00
A1DFB0	2017-07-31 09:19:00+03	30200.00
A1DFD9	2017-08-01 05:14:00+03	43000.00
A1E043	2017-07-26 19:04:00+03	21000.00
A1E080	2017-08-01 16:23:00+03	37000.00
A1E0BF	2017-07-21 19:55:00+03	73200.00
A1E0C1	2017-07-23 00:42:00+03	110300.00
A1E139	2017-07-27 07:12:00+03	56000.00
A1E25E	2017-07-03 23:53:00+03	119700.00
A1E270	2017-07-19 17:07:00+03	58200.00
A1E29C	2017-07-23 20:52:00+03	53100.00
A1E2AD	2017-06-29 10:45:00+03	90600.00
A1E2F5	2017-07-06 06:20:00+03	81000.00
A1E333	2017-08-01 14:21:00+03	186900.00
A1E37C	2017-07-23 06:00:00+03	112000.00
A1E396	2017-08-07 11:11:00+03	23200.00
A1E3EF	2017-07-18 02:12:00+03	98400.00
A1E409	2017-07-19 00:53:00+03	42500.00
A1E436	2017-07-19 15:46:00+03	75600.00
A1E488	2017-07-31 15:08:00+03	62400.00
A1E4B4	2017-06-30 13:07:00+03	28800.00
A1E4BB	2017-07-08 14:50:00+03	27200.00
A1E4BF	2017-07-14 06:23:00+03	28000.00
A1E527	2017-08-02 12:18:00+03	103800.00
A1E6A7	2017-08-01 03:17:00+03	54500.00
A1E6BE	2017-07-13 08:36:00+03	178800.00
A1E6C6	2017-08-14 14:29:00+03	36100.00
A1E6EE	2017-07-27 03:57:00+03	28000.00
A1E73F	2017-07-04 18:00:00+03	21400.00
A1E77E	2017-07-14 16:50:00+03	26800.00
A1E7BF	2017-07-31 16:52:00+03	52300.00
A1E7E4	2017-08-10 05:16:00+03	46300.00
A1E7F7	2017-08-11 20:37:00+03	55000.00
A1E8BE	2017-07-16 14:26:00+03	193600.00
A1E8FB	2017-08-11 15:18:00+03	62000.00
A1E922	2017-07-27 20:03:00+03	12400.00
A1E925	2017-07-19 11:31:00+03	16800.00
A1E94B	2017-08-08 22:32:00+03	48100.00
A1E959	2017-07-28 13:57:00+03	35200.00
A1E96F	2017-07-10 13:22:00+03	56600.00
A1E976	2017-08-14 07:07:00+03	56000.00
A1E980	2017-08-12 16:29:00+03	40000.00
A1E9A5	2017-07-20 05:27:00+03	36000.00
A1E9D6	2017-07-04 09:45:00+03	83300.00
A1EA65	2017-07-21 01:41:00+03	31400.00
A1EAAC	2017-07-01 15:55:00+03	36200.00
A1EAE5	2017-08-01 11:33:00+03	14000.00
A1EAFB	2017-08-05 02:03:00+03	20200.00
A1EAFE	2017-08-12 17:59:00+03	145100.00
A1EB17	2017-07-25 22:21:00+03	11600.00
A1EB3F	2017-07-21 10:53:00+03	50400.00
A1EB84	2017-08-03 11:04:00+03	185300.00
A1EBD0	2017-07-31 14:05:00+03	22200.00
A1EC14	2017-07-01 01:04:00+03	46400.00
A1EC36	2017-07-06 05:36:00+03	49800.00
A1ED50	2017-08-01 23:47:00+03	45200.00
A1ED55	2017-08-11 12:00:00+03	10800.00
A1ED7C	2017-07-18 20:57:00+03	84000.00
A1EDF4	2017-07-25 06:31:00+03	32800.00
A1EE16	2017-08-07 17:27:00+03	25100.00
A1EE2E	2017-07-22 02:15:00+03	38600.00
A1EE35	2017-08-03 06:49:00+03	22000.00
A1EE47	2017-08-06 23:31:00+03	62900.00
A1EE97	2017-07-31 04:32:00+03	12000.00
A1EEAC	2017-07-20 11:33:00+03	23200.00
A1EEB5	2017-07-19 18:16:00+03	122400.00
A1EEC4	2017-07-22 06:32:00+03	25200.00
A1EF91	2017-07-06 06:01:00+03	272300.00
A1EFC4	2017-07-10 06:21:00+03	69000.00
A1EFF7	2017-07-11 01:55:00+03	126000.00
A1F019	2017-08-03 05:41:00+03	20000.00
A1F07D	2017-07-16 20:37:00+03	122800.00
A1F0CD	2017-07-03 09:15:00+03	492000.00
A1F0EE	2017-07-16 19:48:00+03	27200.00
A1F152	2017-07-27 21:19:00+03	89600.00
A1F1B9	2017-08-05 08:51:00+03	54500.00
A1F1CE	2017-07-23 17:22:00+03	94000.00
A1F1DB	2017-08-15 05:35:00+03	23200.00
A1F1DF	2017-08-08 15:05:00+03	131100.00
A1F1E7	2017-07-05 10:36:00+03	28000.00
A1F1FA	2017-07-10 17:32:00+03	23400.00
A1F221	2017-08-13 00:56:00+03	67600.00
A1F251	2017-07-06 09:33:00+03	28800.00
A1F275	2017-07-31 07:59:00+03	99900.00
A1F2B6	2017-08-10 19:31:00+03	67400.00
A1F31C	2017-07-08 09:55:00+03	38600.00
A1F344	2017-07-05 00:21:00+03	96300.00
A1F3F2	2017-08-14 14:30:00+03	51800.00
A1F3F9	2017-07-21 08:40:00+03	38600.00
A1F437	2017-07-05 11:18:00+03	14000.00
A1F4DC	2017-08-11 09:04:00+03	24400.00
A1F5C1	2017-07-10 21:17:00+03	12200.00
A1F607	2017-07-02 20:35:00+03	73200.00
A1F61E	2017-07-25 18:34:00+03	84400.00
A1F66B	2017-07-06 18:54:00+03	94200.00
A1F66F	2017-07-18 06:23:00+03	193600.00
A1F776	2017-07-07 10:58:00+03	4400.00
A1F78D	2017-08-03 09:40:00+03	38600.00
A1F7A1	2017-07-20 03:15:00+03	131600.00
A1F7A6	2017-07-23 07:44:00+03	89600.00
A1F88F	2017-07-25 07:14:00+03	47400.00
A1F8C1	2017-07-06 04:29:00+03	32200.00
A1F8E5	2017-07-17 20:51:00+03	31400.00
A1F90A	2017-07-09 10:54:00+03	62000.00
A1F918	2017-08-13 08:15:00+03	28800.00
A1F961	2017-08-15 11:28:00+03	28800.00
A1F9A9	2017-07-17 21:58:00+03	175300.00
A1F9F6	2017-07-17 06:09:00+03	33600.00
A1F9F9	2017-07-22 04:05:00+03	31000.00
A1F9FD	2017-08-11 20:40:00+03	40600.00
A1FA07	2017-08-08 00:38:00+03	55800.00
A1FA43	2017-08-05 21:11:00+03	30200.00
A1FA5F	2017-07-29 19:27:00+03	6000.00
A1FA96	2017-08-05 12:14:00+03	26000.00
A1FA9F	2017-08-06 22:15:00+03	30000.00
A1FAB4	2017-08-04 00:01:00+03	55800.00
A1FAE7	2017-07-05 12:24:00+03	95000.00
A1FB50	2017-07-31 07:18:00+03	56600.00
A1FB66	2017-08-02 23:58:00+03	36200.00
A1FBA8	2017-07-05 13:39:00+03	14400.00
A1FBCD	2017-08-05 17:26:00+03	19600.00
A1FBF3	2017-07-14 00:42:00+03	38600.00
A1FBFA	2017-07-16 07:04:00+03	465800.00
A1FC40	2017-07-03 01:34:00+03	48800.00
A1FC7E	2017-07-04 06:03:00+03	89700.00
A1FD0E	2017-07-14 14:52:00+03	165500.00
A1FD24	2017-07-02 05:14:00+03	46400.00
A1FD31	2017-08-08 17:16:00+03	399600.00
A1FD39	2017-07-04 16:15:00+03	283100.00
A1FD53	2017-07-21 06:21:00+03	13400.00
A1FDD7	2017-08-13 02:07:00+03	64100.00
A1FDE8	2017-07-03 21:20:00+03	81600.00
A1FE04	2017-07-30 20:26:00+03	81300.00
A1FEBE	2017-08-13 03:17:00+03	72800.00
A1FF06	2017-08-01 05:34:00+03	55000.00
A1FF2B	2017-07-19 10:21:00+03	57500.00
A1FF4C	2017-08-01 00:20:00+03	14400.00
A1FF69	2017-07-28 22:46:00+03	86800.00
A1FF6D	2017-08-13 06:06:00+03	152100.00
A1FFAA	2017-07-24 09:43:00+03	66600.00
A1FFAC	2017-07-22 16:53:00+03	35200.00
A2002C	2017-07-27 13:21:00+03	162200.00
A2002F	2017-08-10 18:56:00+03	53400.00
A20075	2017-08-01 07:36:00+03	6000.00
A200B6	2017-07-25 20:58:00+03	59800.00
A200BE	2017-07-13 19:55:00+03	40400.00
A200CE	2017-07-14 09:40:00+03	11800.00
A200E1	2017-07-08 04:20:00+03	61800.00
A20153	2017-07-03 02:23:00+03	56100.00
A20167	2017-08-04 21:04:00+03	34000.00
A201D3	2017-07-14 14:04:00+03	64300.00
A20212	2017-07-15 09:04:00+03	306500.00
A2023C	2017-07-14 01:43:00+03	89700.00
A2026A	2017-07-12 06:22:00+03	40100.00
A20346	2017-07-12 16:51:00+03	50100.00
A20347	2017-07-18 05:06:00+03	23200.00
A20362	2017-08-04 03:08:00+03	21800.00
A203BD	2017-07-27 06:19:00+03	92400.00
A203F8	2017-07-27 22:47:00+03	226200.00
A204EE	2017-08-11 06:54:00+03	39800.00
A20516	2017-07-06 19:10:00+03	128800.00
A20533	2017-08-04 21:17:00+03	38800.00
A20595	2017-07-15 20:40:00+03	139400.00
A205BC	2017-07-11 08:44:00+03	43200.00
A205C8	2017-07-08 13:29:00+03	19600.00
A205FA	2017-07-27 16:04:00+03	313400.00
A20626	2017-08-05 10:45:00+03	27300.00
A20637	2017-08-02 08:22:00+03	69000.00
A20673	2017-07-19 02:33:00+03	271100.00
A20689	2017-07-28 10:51:00+03	114800.00
A2069D	2017-07-02 06:08:00+03	173200.00
A2077E	2017-07-31 16:35:00+03	46000.00
A20796	2017-07-11 16:20:00+03	8400.00
A2079F	2017-07-17 21:27:00+03	91000.00
A20819	2017-07-25 18:42:00+03	50000.00
A2082F	2017-07-12 09:46:00+03	52100.00
A2085F	2017-07-30 20:23:00+03	167500.00
A208A4	2017-07-21 00:44:00+03	69200.00
A20956	2017-08-12 20:16:00+03	28000.00
A2097D	2017-08-11 10:07:00+03	109000.00
A20A3E	2017-07-19 03:59:00+03	67200.00
A20AF9	2017-07-08 23:59:00+03	153300.00
A20B06	2017-07-05 09:16:00+03	83700.00
A20B49	2017-08-09 16:55:00+03	137400.00
A20B5D	2017-08-09 10:19:00+03	127500.00
A20BBF	2017-07-23 17:22:00+03	23400.00
A20C07	2017-07-23 01:13:00+03	40100.00
A20CEB	2017-07-18 09:19:00+03	13200.00
A20D0E	2017-07-10 05:40:00+03	199600.00
A20D53	2017-07-18 23:45:00+03	6000.00
A20D69	2017-08-09 12:05:00+03	12600.00
A20DA0	2017-07-27 15:59:00+03	23200.00
A20DB8	2017-06-29 11:43:00+03	36200.00
A20E91	2017-07-30 05:04:00+03	39000.00
A20E97	2017-07-07 15:58:00+03	7200.00
A20EEA	2017-08-14 08:43:00+03	6000.00
A20FC2	2017-07-04 01:53:00+03	45100.00
A20FEA	2017-07-22 10:20:00+03	54000.00
A20FF3	2017-07-05 14:58:00+03	46000.00
A21042	2017-07-12 05:04:00+03	62800.00
A2109A	2017-07-25 20:25:00+03	56900.00
A2109D	2017-08-11 06:33:00+03	69500.00
A210B9	2017-07-20 14:14:00+03	30800.00
A210C5	2017-07-08 20:37:00+03	49800.00
A210EC	2017-07-28 08:36:00+03	22600.00
A21152	2017-07-14 01:43:00+03	23200.00
A211CD	2017-08-05 10:33:00+03	20600.00
A21220	2017-07-17 22:22:00+03	92800.00
A2123F	2017-08-09 00:52:00+03	109700.00
A21248	2017-07-07 05:56:00+03	152000.00
A212CA	2017-08-06 05:55:00+03	59400.00
A21350	2017-07-26 00:19:00+03	377400.00
A213A9	2017-08-08 23:58:00+03	32700.00
A21439	2017-08-07 10:38:00+03	6700.00
A21495	2017-08-14 03:11:00+03	40000.00
A214AC	2017-08-15 05:30:00+03	271200.00
A21532	2017-07-20 02:35:00+03	398400.00
A215A6	2017-07-29 14:33:00+03	62900.00
A2166F	2017-08-09 02:29:00+03	92000.00
A2167B	2017-07-16 00:54:00+03	174500.00
A216A5	2017-08-08 08:52:00+03	75600.00
A216AD	2017-07-07 06:34:00+03	6800.00
A21738	2017-08-10 00:16:00+03	56600.00
A2173C	2017-08-01 20:56:00+03	135400.00
A217D4	2017-06-30 13:49:00+03	85000.00
A217D8	2017-07-16 12:03:00+03	46400.00
A217DA	2017-08-13 14:54:00+03	132800.00
A21848	2017-08-08 11:21:00+03	50400.00
A21906	2017-08-04 11:18:00+03	29600.00
A2191F	2017-08-01 11:18:00+03	6800.00
A219B3	2017-07-22 11:18:00+03	77200.00
A219F5	2017-08-12 01:42:00+03	64400.00
A21A2F	2017-07-11 11:11:00+03	47000.00
A21A51	2017-08-12 02:07:00+03	29600.00
A21A5B	2017-08-05 19:58:00+03	26000.00
A21A7F	2017-07-29 01:51:00+03	71400.00
A21AC0	2017-07-18 12:40:00+03	135600.00
A21AD8	2017-08-03 16:19:00+03	14000.00
A21B03	2017-07-28 10:59:00+03	188500.00
A21B6D	2017-08-15 13:20:00+03	79500.00
A21B8F	2017-08-05 10:04:00+03	40000.00
A21BA8	2017-08-04 04:21:00+03	49200.00
A21BAA	2017-07-15 09:06:00+03	68900.00
A21BFB	2017-07-02 13:19:00+03	19600.00
A21C3E	2017-07-31 12:35:00+03	29600.00
A21C70	2017-07-26 07:56:00+03	62600.00
A21C8F	2017-07-20 12:06:00+03	71400.00
A21D16	2017-08-08 12:03:00+03	185700.00
A21D43	2017-07-28 18:58:00+03	92000.00
A21D98	2017-07-11 01:23:00+03	34000.00
A21DB3	2017-07-03 02:37:00+03	83600.00
A21DC8	2017-07-17 11:33:00+03	37900.00
A21DC9	2017-07-29 23:40:00+03	24800.00
A21E11	2017-08-11 10:04:00+03	34000.00
A21E45	2017-07-20 20:04:00+03	57300.00
A21E95	2017-08-07 18:20:00+03	421200.00
A21ECD	2017-06-30 05:55:00+03	55600.00
A21ED9	2017-08-03 13:46:00+03	148200.00
A21F63	2017-07-26 04:06:00+03	36200.00
A21FD7	2017-07-25 18:40:00+03	199600.00
A22065	2017-07-27 20:38:00+03	345200.00
A220B6	2017-08-05 05:21:00+03	46300.00
A220FA	2017-07-20 19:44:00+03	41800.00
A22113	2017-07-10 16:22:00+03	16400.00
A2212E	2017-07-25 20:00:00+03	217900.00
A2213C	2017-08-01 13:44:00+03	27000.00
A22199	2017-07-26 12:58:00+03	123000.00
A221DD	2017-07-05 04:01:00+03	17000.00
A221EA	2017-07-29 06:50:00+03	14000.00
A2231D	2017-07-27 15:24:00+03	77900.00
A22332	2017-08-03 09:48:00+03	47400.00
A22333	2017-07-05 11:13:00+03	6000.00
A22468	2017-07-30 22:43:00+03	21500.00
A22527	2017-08-12 02:59:00+03	45400.00
A2255C	2017-08-07 21:26:00+03	141000.00
A2258D	2017-08-14 06:37:00+03	57600.00
A225A4	2017-08-03 04:38:00+03	14000.00
A225CB	2017-07-09 02:27:00+03	147800.00
A225E5	2017-07-25 08:08:00+03	82400.00
A22628	2017-07-16 10:58:00+03	28800.00
A22652	2017-07-15 14:17:00+03	31400.00
A226B1	2017-07-29 00:48:00+03	9200.00
A226E5	2017-07-24 05:20:00+03	7200.00
A2271B	2017-07-25 23:35:00+03	44800.00
A2273F	2017-07-16 01:17:00+03	54800.00
A2274B	2017-07-09 20:47:00+03	50600.00
A22832	2017-07-09 23:31:00+03	16000.00
A228E9	2017-07-04 20:39:00+03	87100.00
A228FB	2017-08-15 13:22:00+03	53500.00
A229B4	2017-08-08 09:49:00+03	9800.00
A229D9	2017-07-23 05:59:00+03	136200.00
A229FF	2017-07-25 02:15:00+03	24400.00
A22A92	2017-08-01 22:42:00+03	30800.00
A22B4E	2017-06-29 18:13:00+03	16400.00
A22B7A	2017-08-04 19:48:00+03	269200.00
A22BBF	2017-07-20 04:30:00+03	6000.00
A22C20	2017-08-13 18:33:00+03	168000.00
A22C98	2017-08-14 11:19:00+03	8400.00
A22CD0	2017-07-23 21:54:00+03	179400.00
A22CFC	2017-08-05 12:43:00+03	12600.00
A22D0E	2017-07-21 08:36:00+03	246000.00
A22D20	2017-08-11 06:28:00+03	50600.00
A22DD5	2017-08-03 11:05:00+03	23200.00
A22E4E	2017-07-24 12:23:00+03	62800.00
A22EAA	2017-07-11 01:49:00+03	19600.00
A22EED	2017-07-26 01:55:00+03	25100.00
A22F4F	2017-08-07 01:36:00+03	26000.00
A22F6B	2017-07-26 04:22:00+03	60900.00
A22F87	2017-07-24 11:14:00+03	33800.00
A22FC4	2017-08-07 18:13:00+03	33100.00
A23021	2017-07-19 04:48:00+03	48800.00
A23062	2017-07-15 20:02:00+03	38000.00
A230D3	2017-08-08 05:50:00+03	68000.00
A230D7	2017-06-29 13:10:00+03	56000.00
A23145	2017-08-09 15:48:00+03	36200.00
A2318D	2017-07-16 15:11:00+03	173500.00
A231EC	2017-07-12 18:23:00+03	39100.00
A23240	2017-07-07 13:05:00+03	26000.00
A23268	2017-08-08 00:37:00+03	36000.00
A23271	2017-07-19 11:42:00+03	68400.00
A2331E	2017-07-25 05:47:00+03	96100.00
A2332A	2017-07-18 16:44:00+03	87100.00
A2334A	2017-07-15 00:33:00+03	136800.00
A23367	2017-07-10 15:43:00+03	91600.00
A23388	2017-08-11 08:50:00+03	16400.00
A2344B	2017-08-12 12:06:00+03	56000.00
A2344E	2017-07-19 00:56:00+03	8800.00
A2345C	2017-07-10 06:24:00+03	13800.00
A23515	2017-07-23 01:04:00+03	81900.00
A23519	2017-08-11 17:14:00+03	122800.00
A23576	2017-07-30 15:30:00+03	65900.00
A235B7	2017-08-06 17:13:00+03	55800.00
A23636	2017-08-06 05:41:00+03	94000.00
A23685	2017-08-11 10:50:00+03	43600.00
A2368A	2017-07-28 15:26:00+03	70700.00
A23690	2017-07-06 21:07:00+03	516800.00
A236B5	2017-08-09 00:07:00+03	46000.00
A236CA	2017-07-25 08:58:00+03	6300.00
A23741	2017-07-15 07:23:00+03	12600.00
A23753	2017-08-08 11:18:00+03	34400.00
A2378A	2017-07-31 23:06:00+03	19600.00
A237BD	2017-07-09 00:18:00+03	99100.00
A2386C	2017-08-03 18:15:00+03	14000.00
A2387C	2017-08-08 16:31:00+03	136200.00
A23882	2017-07-06 22:31:00+03	57800.00
A238B4	2017-07-10 21:57:00+03	132800.00
A238FB	2017-07-21 10:36:00+03	16800.00
A238FF	2017-07-02 21:03:00+03	97900.00
A2396B	2017-07-19 11:38:00+03	364600.00
A239E9	2017-08-07 22:53:00+03	13200.00
A239EF	2017-08-13 20:54:00+03	19600.00
A239FC	2017-07-25 08:56:00+03	12600.00
A23A1F	2017-07-28 02:41:00+03	61200.00
A23A26	2017-07-02 09:09:00+03	56000.00
A23A50	2017-07-03 02:54:00+03	40100.00
A23A96	2017-07-20 06:26:00+03	153400.00
A23B41	2017-07-29 01:47:00+03	56000.00
A23B43	2017-08-12 08:14:00+03	23900.00
A23B7C	2017-08-02 15:42:00+03	47000.00
A23BC7	2017-06-27 01:05:00+03	28000.00
A23C14	2017-07-01 21:24:00+03	25100.00
A23C57	2017-08-05 00:57:00+03	103600.00
A23C69	2017-07-07 08:27:00+03	24000.00
A23C83	2017-07-11 14:03:00+03	48500.00
A23C8D	2017-07-06 01:53:00+03	7200.00
A23CBA	2017-07-21 00:59:00+03	23400.00
A23CBE	2017-08-15 12:38:00+03	179200.00
A23CF4	2017-08-06 04:06:00+03	45400.00
A23D50	2017-07-02 23:21:00+03	67600.00
A23DE2	2017-08-14 16:03:00+03	136200.00
A23DF5	2017-07-05 02:06:00+03	25600.00
A23E02	2017-08-14 05:32:00+03	57300.00
A23E52	2017-07-17 21:53:00+03	95000.00
A23E90	2017-08-14 09:26:00+03	271200.00
A23F5F	2017-07-17 11:56:00+03	112000.00
A23FE9	2017-08-12 03:44:00+03	147100.00
A24012	2017-06-29 07:50:00+03	30800.00
A24066	2017-07-30 21:43:00+03	50800.00
A24076	2017-07-20 01:39:00+03	14400.00
A240CC	2017-07-14 18:29:00+03	119800.00
A240DD	2017-07-01 05:46:00+03	45600.00
A2413C	2017-08-06 04:48:00+03	63900.00
A24151	2017-08-11 14:58:00+03	283100.00
A2417E	2017-07-24 23:37:00+03	46300.00
A241D2	2017-08-10 22:40:00+03	38600.00
A241E3	2017-07-22 00:16:00+03	175900.00
A242A4	2017-08-05 05:32:00+03	20400.00
A242B3	2017-07-20 14:28:00+03	56000.00
A242EE	2017-08-11 01:31:00+03	77200.00
A2434D	2017-08-09 07:19:00+03	128800.00
A243B3	2017-08-11 19:51:00+03	7200.00
A243DE	2017-07-24 16:53:00+03	16400.00
A243EE	2017-08-03 01:41:00+03	9200.00
A243F6	2017-07-09 16:30:00+03	46300.00
A2448A	2017-07-16 13:43:00+03	6300.00
A244E8	2017-07-15 19:16:00+03	37200.00
A2450D	2017-07-21 01:10:00+03	29300.00
A24527	2017-07-10 03:33:00+03	25000.00
A2452E	2017-07-07 14:40:00+03	7400.00
A245B7	2017-07-04 18:21:00+03	398600.00
A245B9	2017-07-17 16:20:00+03	85000.00
A245DF	2017-07-17 08:43:00+03	206700.00
A24672	2017-07-17 10:38:00+03	56000.00
A2469C	2017-08-13 13:34:00+03	28800.00
A24702	2017-08-02 20:47:00+03	85000.00
A24705	2017-08-12 07:08:00+03	203000.00
A2471F	2017-07-12 23:59:00+03	54300.00
A24723	2017-07-10 18:22:00+03	90600.00
A247A2	2017-07-08 12:09:00+03	43600.00
A247AF	2017-07-03 07:33:00+03	21000.00
A24832	2017-07-02 14:56:00+03	13600.00
A24854	2017-06-30 20:13:00+03	18100.00
A2486A	2017-07-22 20:10:00+03	37100.00
A24899	2017-07-29 18:31:00+03	162200.00
A2489A	2017-07-12 15:27:00+03	149300.00
A248A9	2017-07-24 09:12:00+03	168000.00
A2491A	2017-08-14 09:43:00+03	54000.00
A24943	2017-08-06 04:56:00+03	45200.00
A24961	2017-07-03 01:12:00+03	103500.00
A24974	2017-07-16 03:58:00+03	28000.00
A24A3B	2017-07-15 02:20:00+03	201200.00
A24A69	2017-08-06 02:13:00+03	89600.00
A24A9C	2017-07-18 09:18:00+03	123600.00
A24B21	2017-07-15 02:29:00+03	94800.00
A24B30	2017-07-28 04:25:00+03	36200.00
A24B9D	2017-07-16 01:45:00+03	26000.00
A24BA0	2017-07-02 14:56:00+03	28000.00
A24BAD	2017-07-08 10:53:00+03	298800.00
A24BDA	2017-07-11 13:55:00+03	67900.00
A24BF3	2017-08-15 10:37:00+03	63300.00
A24C58	2017-07-05 13:12:00+03	21800.00
A24C9F	2017-07-15 19:57:00+03	135400.00
A24CE3	2017-07-10 07:25:00+03	40800.00
A24D2D	2017-07-21 20:52:00+03	40800.00
A24D58	2017-07-05 07:49:00+03	21400.00
A24D86	2017-08-07 01:25:00+03	56200.00
A24D9C	2017-07-12 23:49:00+03	14400.00
A24DDC	2017-07-08 22:26:00+03	290400.00
A24E20	2017-07-11 22:23:00+03	13200.00
A24E22	2017-08-08 08:25:00+03	133100.00
A24EA2	2017-08-08 09:28:00+03	40000.00
A24EA5	2017-07-22 00:08:00+03	92800.00
A24EBC	2017-07-17 00:30:00+03	258400.00
A24EE1	2017-07-17 03:06:00+03	14800.00
A24F5C	2017-07-09 18:35:00+03	40800.00
A24F85	2017-07-06 20:54:00+03	46000.00
A24FB3	2017-07-14 23:09:00+03	86400.00
A24FE4	2017-08-07 22:38:00+03	27400.00
A25043	2017-08-08 17:37:00+03	19600.00
A25044	2017-08-09 16:16:00+03	147200.00
A25057	2017-07-31 21:38:00+03	12400.00
A2506E	2017-08-09 07:53:00+03	60400.00
A25076	2017-07-03 03:12:00+03	99200.00
A250D3	2017-08-12 05:58:00+03	59900.00
A250F3	2017-07-24 13:41:00+03	100600.00
A2514A	2017-07-22 21:07:00+03	89700.00
A2517B	2017-07-23 05:42:00+03	85000.00
A2520A	2017-08-10 13:39:00+03	70700.00
A25220	2017-08-06 15:56:00+03	23200.00
A25255	2017-07-18 10:53:00+03	124200.00
A2525F	2017-07-13 03:16:00+03	168000.00
A25281	2017-08-13 17:43:00+03	53200.00
A25289	2017-07-31 04:00:00+03	12600.00
A252F0	2017-08-13 06:48:00+03	13400.00
A253FB	2017-07-19 20:15:00+03	16400.00
A25411	2017-07-26 01:37:00+03	96800.00
A25428	2017-07-15 17:31:00+03	131600.00
A2542C	2017-07-30 20:12:00+03	226200.00
A254CA	2017-07-22 12:09:00+03	117200.00
A254E6	2017-07-03 14:23:00+03	38400.00
A25523	2017-07-24 12:47:00+03	20400.00
A2557E	2017-08-09 01:55:00+03	40200.00
A255A1	2017-08-14 03:35:00+03	291000.00
A255B0	2017-07-08 13:29:00+03	52700.00
A255DD	2017-08-07 08:41:00+03	67600.00
A25631	2017-08-07 04:51:00+03	92800.00
A25676	2017-07-19 15:04:00+03	15000.00
A256CF	2017-07-07 03:14:00+03	56000.00
A256DE	2017-07-05 03:30:00+03	70700.00
A25738	2017-07-03 07:36:00+03	136200.00
A25751	2017-07-17 21:12:00+03	639800.00
A25755	2017-08-08 14:27:00+03	67900.00
A257DE	2017-07-01 03:59:00+03	37900.00
A2586A	2017-07-24 20:37:00+03	56000.00
A258AF	2017-08-02 00:56:00+03	34100.00
A258EB	2017-07-19 17:21:00+03	33100.00
A258F1	2017-08-03 10:49:00+03	23200.00
A2590B	2017-07-28 05:15:00+03	25000.00
A25953	2017-07-25 23:44:00+03	39300.00
A25957	2017-07-10 04:53:00+03	6300.00
A2599D	2017-07-14 03:57:00+03	59400.00
A259A0	2017-07-30 16:19:00+03	56600.00
A259A6	2017-08-14 06:54:00+03	67800.00
A259E4	2017-08-04 18:31:00+03	27200.00
A259EA	2017-07-25 09:15:00+03	84100.00
A25A0A	2017-08-08 15:05:00+03	22200.00
A25A32	2017-07-24 09:53:00+03	28600.00
A25A67	2017-07-23 22:18:00+03	83000.00
A25A87	2017-08-06 18:36:00+03	24400.00
A25A9C	2017-08-13 23:38:00+03	28400.00
A25B14	2017-07-12 15:00:00+03	43100.00
A25B91	2017-07-05 16:02:00+03	39500.00
A25C06	2017-07-04 14:23:00+03	189200.00
A25C4B	2017-07-06 19:55:00+03	46000.00
A25C62	2017-08-02 00:17:00+03	99300.00
A25C8B	2017-07-16 02:26:00+03	88300.00
A25C90	2017-07-13 04:16:00+03	28800.00
A25C9E	2017-07-31 10:04:00+03	24200.00
A25D90	2017-07-27 02:04:00+03	17000.00
A25E40	2017-07-11 05:35:00+03	21800.00
A25E57	2017-07-11 03:07:00+03	137800.00
A25E7D	2017-07-30 18:26:00+03	86300.00
A25E8E	2017-08-01 22:28:00+03	28700.00
A25EB2	2017-08-08 22:47:00+03	186900.00
A25EB3	2017-07-28 12:53:00+03	22600.00
A25F18	2017-08-14 18:28:00+03	6000.00
A25F32	2017-07-05 13:00:00+03	29800.00
A2604A	2017-07-18 20:24:00+03	192900.00
A26091	2017-08-09 03:23:00+03	37900.00
A260D5	2017-07-08 07:53:00+03	25600.00
A260DB	2017-07-29 06:29:00+03	50600.00
A260E8	2017-08-06 23:26:00+03	28800.00
A26175	2017-07-24 06:08:00+03	112000.00
A26182	2017-07-10 15:02:00+03	29400.00
A261CD	2017-07-22 19:14:00+03	176400.00
A2621C	2017-07-03 00:39:00+03	56000.00
A2623C	2017-08-10 15:41:00+03	102100.00
A26241	2017-08-13 10:22:00+03	98200.00
A262E9	2017-07-03 11:13:00+03	137100.00
A262F7	2017-07-15 04:51:00+03	147000.00
A2634D	2017-07-01 01:42:00+03	46000.00
A26358	2017-07-27 10:21:00+03	19600.00
A2635D	2017-08-14 16:10:00+03	35600.00
A263A5	2017-07-26 15:40:00+03	131600.00
A263AE	2017-07-24 03:54:00+03	248300.00
A263FC	2017-08-07 09:50:00+03	75300.00
A263FD	2017-07-18 19:39:00+03	63100.00
A2642B	2017-07-02 11:00:00+03	64400.00
A26465	2017-07-23 17:28:00+03	99700.00
A264C9	2017-07-06 02:51:00+03	111600.00
A2651E	2017-08-02 17:39:00+03	91100.00
A26522	2017-07-05 14:01:00+03	179600.00
A26661	2017-07-07 07:37:00+03	189200.00
A26698	2017-08-07 04:25:00+03	14400.00
A266C8	2017-07-19 05:00:00+03	406200.00
A2674B	2017-07-12 17:01:00+03	33300.00
A26759	2017-07-04 11:38:00+03	67800.00
A267A4	2017-08-10 00:53:00+03	68000.00
A26820	2017-08-15 08:44:00+03	13400.00
A2683A	2017-07-13 08:23:00+03	23600.00
A2688E	2017-08-12 01:50:00+03	68800.00
A269A5	2017-07-02 17:02:00+03	106800.00
A269CD	2017-07-15 10:17:00+03	26700.00
A269E1	2017-07-12 02:02:00+03	121800.00
A26A60	2017-07-12 00:15:00+03	26200.00
A26AA0	2017-06-28 08:28:00+03	99200.00
A26AF5	2017-07-13 19:47:00+03	28800.00
A26C3D	2017-07-22 23:32:00+03	9200.00
A26C81	2017-07-21 08:25:00+03	136800.00
A26C97	2017-07-09 22:22:00+03	149300.00
A26CB8	2017-08-10 11:33:00+03	19600.00
A26CBE	2017-08-12 21:50:00+03	44500.00
A26D50	2017-08-04 03:02:00+03	50900.00
A26D6E	2017-07-15 11:44:00+03	14000.00
A26DA8	2017-07-28 20:52:00+03	16000.00
A26E58	2017-07-29 00:02:00+03	28000.00
A26E59	2017-08-03 01:36:00+03	129700.00
A26E64	2017-07-11 12:15:00+03	6000.00
A26E77	2017-07-06 17:22:00+03	123700.00
A26EF7	2017-07-14 07:16:00+03	134700.00
A26F63	2017-07-15 08:29:00+03	53700.00
A26F93	2017-07-16 04:48:00+03	24400.00
A26FAD	2017-08-07 07:56:00+03	78800.00
A2700E	2017-07-17 13:49:00+03	265200.00
A270B5	2017-07-06 22:37:00+03	66000.00
A270D0	2017-07-14 22:16:00+03	139500.00
A27131	2017-07-19 01:23:00+03	239300.00
A27181	2017-07-03 18:40:00+03	122400.00
A271A2	2017-07-28 03:50:00+03	55800.00
A271CC	2017-07-27 18:35:00+03	46300.00
A271EF	2017-07-17 18:14:00+03	46400.00
A27223	2017-08-01 05:10:00+03	58000.00
A27247	2017-07-14 01:14:00+03	130800.00
A2724B	2017-07-24 06:15:00+03	50000.00
A2727C	2017-07-06 12:40:00+03	143100.00
A272D5	2017-08-03 12:28:00+03	25200.00
A27301	2017-07-04 10:41:00+03	91200.00
A27314	2017-08-12 02:12:00+03	25900.00
A27380	2017-08-04 09:01:00+03	105600.00
A2738B	2017-07-30 21:11:00+03	131600.00
A273B4	2017-07-26 18:25:00+03	65600.00
A27474	2017-06-29 08:33:00+03	29600.00
A274DB	2017-08-08 15:02:00+03	12200.00
A275A4	2017-07-12 03:41:00+03	86500.00
A275F6	2017-08-03 21:23:00+03	12000.00
A27603	2017-08-01 10:07:00+03	14400.00
A2760E	2017-07-17 05:28:00+03	44700.00
A2768F	2017-07-15 23:04:00+03	81800.00
A276BA	2017-07-03 18:53:00+03	55800.00
A276D0	2017-08-15 17:50:00+03	18500.00
A276F0	2017-08-03 16:52:00+03	31600.00
A2777B	2017-07-21 02:10:00+03	32800.00
A277D7	2017-07-14 19:32:00+03	24800.00
A277D9	2017-08-15 10:04:00+03	230200.00
A2794F	2017-07-05 04:12:00+03	103200.00
A2798C	2017-07-04 05:22:00+03	28000.00
A279EE	2017-07-24 16:11:00+03	42400.00
A27A15	2017-07-21 07:12:00+03	136800.00
A27A5A	2017-07-19 09:00:00+03	33400.00
A27A62	2017-07-05 08:52:00+03	168000.00
A27A75	2017-07-20 07:05:00+03	25600.00
A27A7D	2017-07-27 06:22:00+03	57400.00
A27AAE	2017-07-12 06:25:00+03	46400.00
A27AEE	2017-07-05 14:46:00+03	26000.00
A27AFB	2017-07-29 12:18:00+03	114900.00
A27B11	2017-07-29 07:04:00+03	76600.00
A27B1E	2017-07-06 09:07:00+03	68100.00
A27B1F	2017-08-05 11:25:00+03	14000.00
A27B22	2017-06-30 15:45:00+03	64700.00
A27B4C	2017-07-15 04:47:00+03	44400.00
A27B8B	2017-07-27 17:19:00+03	443000.00
A27B9B	2017-08-07 20:15:00+03	23600.00
A27BC7	2017-07-05 11:38:00+03	248300.00
A27BC8	2017-07-04 21:40:00+03	24400.00
A27BE2	2017-06-26 06:54:00+03	119500.00
A27C15	2017-08-01 08:17:00+03	16400.00
A27C6A	2017-07-11 12:57:00+03	13000.00
A27CB9	2017-08-10 11:22:00+03	44600.00
A27CCC	2017-07-04 09:12:00+03	28000.00
A27CEE	2017-08-15 12:16:00+03	26000.00
A27CFF	2017-07-08 19:05:00+03	6200.00
A27D19	2017-07-16 06:09:00+03	33100.00
A27DF2	2017-07-13 03:40:00+03	64100.00
A27EF5	2017-07-04 07:48:00+03	31400.00
A27F11	2017-08-09 20:11:00+03	133700.00
A27F78	2017-07-03 08:19:00+03	83600.00
A27F99	2017-07-10 06:46:00+03	177600.00
A27FE2	2017-08-08 18:14:00+03	47000.00
A280AF	2017-07-25 09:23:00+03	69500.00
A280EA	2017-07-16 10:48:00+03	28800.00
A2810D	2017-07-01 16:36:00+03	49300.00
A28250	2017-08-11 16:46:00+03	27400.00
A28286	2017-07-18 09:32:00+03	189200.00
A28331	2017-08-07 00:24:00+03	29600.00
A283A1	2017-08-13 19:18:00+03	51300.00
A283AC	2017-08-13 07:24:00+03	128800.00
A283C7	2017-08-04 03:07:00+03	31600.00
A283EB	2017-07-14 05:23:00+03	129700.00
A284DA	2017-07-30 12:35:00+03	130700.00
A284E3	2017-08-09 19:00:00+03	396500.00
A284F5	2017-07-19 23:59:00+03	64800.00
A28529	2017-07-22 11:09:00+03	79000.00
A2855B	2017-07-16 22:44:00+03	277900.00
A285E9	2017-07-15 07:20:00+03	34600.00
A28607	2017-07-28 03:42:00+03	35700.00
A28622	2017-07-26 11:21:00+03	94000.00
A28651	2017-07-28 16:22:00+03	236900.00
A28657	2017-06-30 02:42:00+03	48800.00
A286AE	2017-08-07 10:48:00+03	54800.00
A286F9	2017-07-15 04:32:00+03	31600.00
A2870B	2017-07-23 16:13:00+03	28800.00
A28745	2017-07-20 20:54:00+03	201200.00
A28746	2017-07-13 12:37:00+03	39600.00
A28761	2017-08-14 16:51:00+03	100000.00
A28818	2017-08-13 07:56:00+03	135400.00
A2882C	2017-07-15 13:24:00+03	135000.00
A28885	2017-08-14 16:54:00+03	14400.00
A288B8	2017-07-29 07:12:00+03	48900.00
A288BD	2017-07-22 19:58:00+03	179400.00
A288FF	2017-07-14 04:28:00+03	39500.00
A2891C	2017-07-05 19:13:00+03	53500.00
A28936	2017-07-28 05:20:00+03	70800.00
A28AB3	2017-07-03 08:56:00+03	199700.00
A28AD0	2017-07-09 20:12:00+03	96300.00
A28AE8	2017-07-12 19:46:00+03	48100.00
A28B6B	2017-07-17 00:39:00+03	46400.00
A28B90	2017-07-22 05:22:00+03	38400.00
A28BB1	2017-07-15 17:14:00+03	131600.00
A28BC0	2017-08-04 19:38:00+03	36500.00
A28BCA	2017-08-06 08:40:00+03	24400.00
A28C26	2017-08-01 16:12:00+03	172400.00
A28D1B	2017-07-09 08:03:00+03	89600.00
A28D41	2017-07-26 00:46:00+03	16400.00
A28D60	2017-07-28 19:06:00+03	124300.00
A28DD0	2017-07-07 20:04:00+03	173900.00
A28E10	2017-07-26 20:02:00+03	133200.00
A28E47	2017-07-27 13:43:00+03	67200.00
A28E59	2017-08-12 16:24:00+03	32800.00
A28ED5	2017-08-14 02:58:00+03	103800.00
A28EF1	2017-07-18 00:12:00+03	6800.00
A28F4B	2017-07-09 21:52:00+03	66800.00
A28F5A	2017-07-06 13:13:00+03	38400.00
A29017	2017-07-11 21:31:00+03	50700.00
A2901D	2017-07-09 11:20:00+03	133700.00
A29031	2017-07-08 01:57:00+03	75600.00
A2907B	2017-07-04 21:13:00+03	14400.00
A290A3	2017-07-27 03:59:00+03	184700.00
A290AA	2017-07-02 03:04:00+03	39400.00
A290BF	2017-08-14 13:46:00+03	12600.00
A290CC	2017-07-28 01:55:00+03	214900.00
A2912A	2017-08-01 18:24:00+03	221700.00
A29140	2017-07-30 14:53:00+03	29100.00
A2916A	2017-07-04 22:39:00+03	60200.00
A29177	2017-07-05 10:54:00+03	218800.00
A291EB	2017-07-08 04:26:00+03	125200.00
A29201	2017-08-12 11:40:00+03	59400.00
A2927C	2017-07-11 03:16:00+03	117200.00
A2928A	2017-07-08 22:11:00+03	265700.00
A29298	2017-08-10 23:46:00+03	25800.00
A292AD	2017-07-16 12:55:00+03	43800.00
A292F3	2017-07-01 05:11:00+03	36200.00
A2930F	2017-08-07 11:38:00+03	77000.00
A2932C	2017-08-14 01:24:00+03	56000.00
A29497	2017-07-05 11:56:00+03	92800.00
A295A2	2017-07-22 20:13:00+03	68000.00
A295CD	2017-08-02 00:56:00+03	133100.00
A295F0	2017-08-06 10:41:00+03	46400.00
A29604	2017-08-10 19:04:00+03	246000.00
A29631	2017-07-13 16:27:00+03	44000.00
A29656	2017-07-22 22:42:00+03	67200.00
A29677	2017-07-05 11:32:00+03	92000.00
A2968E	2017-07-18 00:27:00+03	57400.00
A296AD	2017-07-18 23:40:00+03	81600.00
A296C6	2017-07-20 23:04:00+03	59800.00
A296FC	2017-07-11 16:53:00+03	23600.00
A29722	2017-08-01 19:31:00+03	29600.00
A2972D	2017-08-07 01:27:00+03	44600.00
A29734	2017-08-09 14:14:00+03	134700.00
A29774	2017-06-30 21:55:00+03	97900.00
A2983B	2017-07-26 00:34:00+03	111900.00
A2985F	2017-07-24 12:33:00+03	56000.00
A29883	2017-08-12 05:35:00+03	15900.00
A298B6	2017-08-08 10:55:00+03	69500.00
A298C0	2017-07-15 12:27:00+03	69500.00
A29968	2017-08-15 05:29:00+03	36500.00
A299B2	2017-07-14 21:27:00+03	89200.00
A299B4	2017-07-19 05:27:00+03	133100.00
A299B7	2017-07-02 14:51:00+03	43600.00
A29A13	2017-07-17 07:12:00+03	29600.00
A29A29	2017-08-11 06:07:00+03	8200.00
A29A9E	2017-07-18 04:03:00+03	23200.00
A29B25	2017-07-24 18:09:00+03	6000.00
A29B32	2017-07-26 11:30:00+03	25400.00
A29B36	2017-08-03 10:05:00+03	75800.00
A29B3B	2017-08-07 11:04:00+03	111600.00
A29B42	2017-06-30 03:33:00+03	38400.00
A29B53	2017-08-14 17:22:00+03	199700.00
A29B55	2017-07-21 13:30:00+03	66600.00
A29B74	2017-08-06 16:26:00+03	137700.00
A29B83	2017-07-30 05:53:00+03	36200.00
A29B8B	2017-08-03 16:59:00+03	114800.00
A29B93	2017-08-13 03:20:00+03	320200.00
A29BC8	2017-07-10 01:22:00+03	157100.00
A29BEE	2017-08-06 00:53:00+03	70800.00
A29C08	2017-08-14 13:42:00+03	166900.00
A29C1D	2017-07-27 16:55:00+03	6800.00
A29CDF	2017-08-02 18:47:00+03	23400.00
A29D0A	2017-07-24 11:45:00+03	50400.00
A29D25	2017-07-25 22:36:00+03	48800.00
A29D57	2017-07-14 21:01:00+03	85700.00
A29D71	2017-07-03 11:10:00+03	32800.00
A29DCA	2017-08-15 10:14:00+03	6000.00
A29E4E	2017-07-21 16:38:00+03	12600.00
A29E6A	2017-07-17 00:38:00+03	189200.00
A29E8B	2017-08-07 15:39:00+03	46400.00
A29F03	2017-07-23 18:39:00+03	46000.00
A29F5A	2017-07-23 19:36:00+03	23600.00
A29F64	2017-07-24 17:38:00+03	42300.00
A29F90	2017-08-11 17:31:00+03	290500.00
A29FCA	2017-07-04 09:19:00+03	86800.00
A29FEE	2017-08-13 20:20:00+03	78300.00
A2A050	2017-07-06 10:46:00+03	112400.00
A2A112	2017-08-15 13:26:00+03	52800.00
A2A15E	2017-08-15 04:06:00+03	55800.00
A2A1EB	2017-07-04 20:16:00+03	28800.00
A2A2A0	2017-08-04 15:42:00+03	179200.00
A2A2CB	2017-07-23 15:09:00+03	129700.00
A2A352	2017-08-09 01:11:00+03	62600.00
A2A37F	2017-07-19 19:55:00+03	50600.00
A2A453	2017-07-05 20:14:00+03	46200.00
A2A471	2017-07-10 05:33:00+03	13400.00
A2A474	2017-08-15 08:01:00+03	149400.00
A2A492	2017-07-07 06:47:00+03	22000.00
A2A4BA	2017-07-08 06:53:00+03	6300.00
A2A4BC	2017-08-08 07:44:00+03	154800.00
A2A502	2017-07-01 08:26:00+03	8000.00
A2A54C	2017-07-23 00:13:00+03	46300.00
A2A562	2017-07-20 07:08:00+03	136200.00
A2A592	2017-08-08 10:35:00+03	52000.00
A2A5A3	2017-07-25 22:45:00+03	123400.00
A2A5CF	2017-07-12 19:10:00+03	116000.00
A2A5F6	2017-06-27 10:08:00+03	86600.00
A2A602	2017-08-04 02:28:00+03	291600.00
A2A626	2017-07-24 22:59:00+03	36200.00
A2A662	2017-07-17 08:26:00+03	12600.00
A2A6AF	2017-07-10 23:15:00+03	75300.00
A2A742	2017-07-30 00:02:00+03	85000.00
A2A743	2017-08-12 10:52:00+03	71900.00
A2A76D	2017-08-12 04:58:00+03	61100.00
A2A7D5	2017-07-03 11:06:00+03	94700.00
A2A7DD	2017-08-14 10:07:00+03	47000.00
A2A824	2017-07-10 17:14:00+03	86300.00
A2A82B	2017-07-13 07:20:00+03	45300.00
A2A854	2017-07-02 07:03:00+03	66600.00
A2A859	2017-07-17 03:01:00+03	84100.00
A2A882	2017-07-10 11:01:00+03	26300.00
A2A8AB	2017-07-17 22:49:00+03	102200.00
A2A8D2	2017-08-04 13:25:00+03	36400.00
A2A8FE	2017-07-24 03:07:00+03	63700.00
A2A8FF	2017-07-17 19:55:00+03	272400.00
A2A91D	2017-07-06 16:58:00+03	152200.00
A2A927	2017-08-07 22:58:00+03	25800.00
A2A932	2017-07-22 19:43:00+03	28000.00
A2A941	2017-08-09 16:20:00+03	123000.00
A2A95E	2017-08-04 05:30:00+03	43500.00
A2A973	2017-08-08 05:46:00+03	47500.00
A2A999	2017-07-18 22:55:00+03	25200.00
A2A9BE	2017-08-09 16:38:00+03	35300.00
A2A9DC	2017-07-18 17:32:00+03	136800.00
A2AA41	2017-06-29 10:00:00+03	53100.00
A2AA7F	2017-08-07 02:22:00+03	143000.00
A2AA89	2017-08-09 20:28:00+03	155600.00
A2AB29	2017-08-12 12:57:00+03	28800.00
A2AB5F	2017-07-12 09:28:00+03	59400.00
A2ABA1	2017-07-29 17:04:00+03	55800.00
A2ABB0	2017-08-12 11:51:00+03	93900.00
A2ABB4	2017-07-02 02:16:00+03	22200.00
A2ABDE	2017-07-10 14:04:00+03	103400.00
A2AC12	2017-08-13 13:48:00+03	62600.00
A2AC4F	2017-08-06 05:41:00+03	71600.00
A2AC7C	2017-07-18 12:12:00+03	190300.00
A2AC92	2017-08-08 19:45:00+03	80800.00
A2AD3B	2017-08-09 15:28:00+03	65900.00
A2AD44	2017-07-12 17:19:00+03	40800.00
A2AE46	2017-08-10 10:00:00+03	39300.00
A2AE68	2017-07-28 00:06:00+03	24000.00
A2AEB0	2017-07-30 18:59:00+03	80800.00
A2AF00	2017-07-24 00:51:00+03	16400.00
A2AF3E	2017-08-09 09:38:00+03	29000.00
A2AFBD	2017-07-10 12:37:00+03	50600.00
A2B054	2017-07-07 05:19:00+03	13000.00
A2B071	2017-07-17 22:58:00+03	34100.00
A2B075	2017-08-11 19:32:00+03	30200.00
A2B091	2017-07-27 08:58:00+03	40800.00
A2B0FA	2017-08-05 14:23:00+03	83200.00
A2B11E	2017-07-31 04:00:00+03	32200.00
A2B192	2017-06-29 11:09:00+03	31400.00
A2B20E	2017-07-01 14:10:00+03	36200.00
A2B251	2017-08-07 21:46:00+03	54400.00
A2B276	2017-07-23 08:19:00+03	27200.00
A2B325	2017-07-13 13:20:00+03	248300.00
A2B38F	2017-07-24 08:41:00+03	155700.00
A2B391	2017-06-29 23:35:00+03	399600.00
A2B3A5	2017-08-09 11:01:00+03	99200.00
A2B3D5	2017-08-03 16:13:00+03	42000.00
A2B410	2017-07-23 23:11:00+03	37900.00
A2B42C	2017-07-21 02:34:00+03	130800.00
A2B455	2017-07-02 06:14:00+03	16400.00
A2B4B1	2017-08-03 23:55:00+03	84500.00
A2B4DA	2017-07-08 09:32:00+03	57600.00
A2B4EF	2017-07-07 22:11:00+03	58200.00
A2B516	2017-07-05 10:27:00+03	134300.00
A2B51F	2017-07-05 16:36:00+03	89100.00
A2B555	2017-08-12 14:25:00+03	24000.00
A2B585	2017-07-30 12:13:00+03	133700.00
A2B59A	2017-07-28 14:04:00+03	35600.00
A2B5B8	2017-08-07 20:19:00+03	68400.00
A2B609	2017-07-31 19:24:00+03	6000.00
A2B61E	2017-08-09 09:59:00+03	102100.00
A2B652	2017-08-09 06:11:00+03	44500.00
A2B668	2017-07-27 04:42:00+03	90600.00
A2B6AE	2017-07-02 02:27:00+03	34700.00
A2B7B3	2017-07-10 10:59:00+03	34000.00
A2B7BE	2017-08-07 22:20:00+03	16400.00
A2B7ED	2017-07-04 19:23:00+03	102100.00
A2B801	2017-07-04 05:07:00+03	233000.00
A2B89E	2017-08-06 11:09:00+03	36200.00
A2B973	2017-08-02 13:14:00+03	34000.00
A2B999	2017-08-08 18:35:00+03	66800.00
A2B9D3	2017-07-08 15:02:00+03	13600.00
A2BB7C	2017-07-14 02:32:00+03	65900.00
A2BC21	2017-07-15 14:17:00+03	26200.00
A2BD19	2017-07-02 13:19:00+03	114200.00
A2BD7C	2017-08-13 22:53:00+03	17000.00
A2BD90	2017-07-15 19:58:00+03	78200.00
A2BDC8	2017-07-17 00:56:00+03	135200.00
A2BE64	2017-07-07 15:37:00+03	73600.00
A2BE8E	2017-07-25 20:39:00+03	29600.00
A2BEBE	2017-08-03 03:18:00+03	29600.00
A2BEC0	2017-07-03 14:47:00+03	123000.00
A2BEF2	2017-07-21 20:12:00+03	77500.00
A2BEF7	2017-07-13 20:13:00+03	27300.00
A2BF0A	2017-06-30 08:50:00+03	169900.00
A2BF40	2017-07-20 20:12:00+03	29600.00
A2BF47	2017-08-11 22:29:00+03	40400.00
A2BF63	2017-06-28 02:03:00+03	386300.00
A2BFA8	2017-08-09 10:55:00+03	18000.00
A2C004	2017-08-03 09:06:00+03	47200.00
A2C0AB	2017-07-05 23:46:00+03	34000.00
A2C0FC	2017-07-25 02:36:00+03	121000.00
A2C12B	2017-08-03 08:17:00+03	103500.00
A2C1AB	2017-08-08 08:43:00+03	39500.00
A2C1E8	2017-08-08 13:37:00+03	42900.00
A2C259	2017-08-10 21:35:00+03	56000.00
A2C364	2017-07-10 07:07:00+03	66000.00
A2C38C	2017-07-09 23:15:00+03	93400.00
A2C3BF	2017-08-05 00:36:00+03	25900.00
A2C3C9	2017-07-05 11:43:00+03	63500.00
A2C453	2017-07-10 16:11:00+03	203700.00
A2C4A0	2017-07-15 14:02:00+03	101200.00
A2C4A1	2017-07-25 19:58:00+03	38400.00
A2C4B7	2017-07-07 00:58:00+03	16800.00
A2C4D4	2017-07-29 16:01:00+03	73300.00
A2C4EB	2017-07-08 07:09:00+03	23200.00
A2C547	2017-08-06 13:47:00+03	75300.00
A2C555	2017-07-05 15:51:00+03	115800.00
A2C5A5	2017-07-07 05:22:00+03	52000.00
A2C5A9	2017-07-07 00:29:00+03	148200.00
A2C5EA	2017-08-13 19:15:00+03	84200.00
A2C624	2017-08-11 15:54:00+03	47200.00
A2C650	2017-07-29 08:38:00+03	48000.00
A2C6DF	2017-08-04 18:17:00+03	75600.00
A2C711	2017-08-12 09:22:00+03	45400.00
A2C738	2017-07-17 03:00:00+03	59200.00
A2C771	2017-08-06 02:38:00+03	88900.00
A2C79A	2017-07-20 16:44:00+03	32800.00
A2C824	2017-07-05 20:40:00+03	61500.00
A2C863	2017-07-03 22:01:00+03	27200.00
A2C87E	2017-08-03 11:05:00+03	40600.00
A2C8B2	2017-07-19 14:25:00+03	49400.00
A2C8FD	2017-08-12 05:29:00+03	35200.00
A2C906	2017-08-11 02:55:00+03	102800.00
A2C965	2017-06-30 05:27:00+03	178200.00
A2C967	2017-07-29 14:05:00+03	32800.00
A2C97C	2017-07-11 11:54:00+03	116000.00
A2C9C5	2017-07-28 09:54:00+03	35300.00
A2C9E2	2017-07-27 18:26:00+03	61800.00
A2CA16	2017-08-05 19:44:00+03	39000.00
A2CA2B	2017-06-28 02:17:00+03	28700.00
A2CA3C	2017-08-15 12:44:00+03	6000.00
A2CABD	2017-08-13 18:46:00+03	20100.00
A2CB4C	2017-07-28 13:40:00+03	123000.00
A2CB71	2017-08-12 09:51:00+03	20400.00
A2CBDC	2017-08-15 07:20:00+03	57300.00
A2CC0E	2017-07-28 14:42:00+03	173600.00
A2CC27	2017-08-08 07:41:00+03	43600.00
A2CC36	2017-07-26 06:58:00+03	46200.00
A2CC3F	2017-07-14 06:47:00+03	25600.00
A2CC83	2017-07-31 10:17:00+03	86800.00
A2CCA9	2017-08-13 08:14:00+03	10800.00
A2CCB5	2017-07-31 00:21:00+03	20800.00
A2CCC0	2017-07-12 03:10:00+03	83700.00
A2CD4E	2017-08-05 19:11:00+03	54000.00
A2CDDE	2017-07-28 14:25:00+03	242600.00
A2CE12	2017-07-06 00:54:00+03	201200.00
A2CE8F	2017-07-08 04:23:00+03	52300.00
A2CEDA	2017-08-01 22:28:00+03	95300.00
A2CF30	2017-08-10 21:03:00+03	14400.00
A2CF3A	2017-07-12 10:45:00+03	86600.00
A2CF9B	2017-08-04 20:13:00+03	62600.00
A2D03C	2017-07-01 14:14:00+03	70600.00
A2D0B0	2017-07-25 22:46:00+03	65900.00
A2D0BD	2017-07-28 07:12:00+03	55000.00
A2D0C2	2017-07-09 04:13:00+03	54500.00
A2D0EB	2017-07-11 05:22:00+03	51600.00
A2D0F2	2017-07-17 12:17:00+03	265700.00
A2D187	2017-07-02 18:30:00+03	23200.00
A2D234	2017-08-09 00:13:00+03	25000.00
A2D23D	2017-07-30 18:03:00+03	65900.00
A2D25F	2017-07-08 17:47:00+03	62400.00
A2D298	2017-07-21 12:46:00+03	101200.00
A2D2D8	2017-07-28 05:20:00+03	23200.00
A2D304	2017-08-13 20:12:00+03	23200.00
A2D4BC	2017-07-16 19:58:00+03	588800.00
A2D510	2017-08-04 14:01:00+03	28800.00
A2D521	2017-08-12 13:10:00+03	69500.00
A2D534	2017-08-12 09:24:00+03	46200.00
A2D54B	2017-07-10 17:12:00+03	59200.00
A2D64A	2017-07-20 08:36:00+03	40800.00
A2D650	2017-07-07 17:17:00+03	86600.00
A2D6B8	2017-07-12 23:01:00+03	111600.00
A2D6CB	2017-07-29 11:46:00+03	57900.00
A2D7DA	2017-08-04 23:42:00+03	65900.00
A2D820	2017-07-17 20:31:00+03	47100.00
A2D857	2017-08-05 13:53:00+03	84900.00
A2D867	2017-07-02 16:58:00+03	64200.00
A2D87E	2017-07-11 05:06:00+03	81700.00
A2D885	2017-07-18 08:48:00+03	203000.00
A2D88B	2017-07-12 18:06:00+03	52300.00
A2D8B3	2017-07-17 18:00:00+03	26000.00
A2D902	2017-08-08 12:24:00+03	23500.00
A2D928	2017-08-02 05:12:00+03	76600.00
A2D945	2017-07-22 23:01:00+03	37800.00
A2DAE2	2017-06-29 14:38:00+03	52600.00
A2DAF2	2017-07-27 06:24:00+03	20200.00
A2DB31	2017-07-26 14:12:00+03	38800.00
A2DB5F	2017-07-15 19:47:00+03	54000.00
A2DC66	2017-07-31 12:54:00+03	293200.00
A2DCD9	2017-08-08 19:00:00+03	58800.00
A2DCE1	2017-07-14 00:23:00+03	85000.00
A2DD3B	2017-08-05 08:03:00+03	15100.00
A2DD82	2017-08-07 16:03:00+03	81900.00
A2DD9B	2017-08-04 06:25:00+03	38800.00
A2DDF5	2017-08-03 06:32:00+03	47200.00
A2DE1D	2017-07-29 05:46:00+03	88800.00
A2DE3E	2017-07-12 16:23:00+03	188100.00
A2DEB9	2017-07-26 05:51:00+03	408500.00
A2DEC4	2017-08-06 20:54:00+03	18600.00
A2DEC9	2017-07-04 20:24:00+03	26700.00
A2DED5	2017-07-19 06:22:00+03	40100.00
A2DEF6	2017-08-04 17:49:00+03	89700.00
A2DEFE	2017-07-26 16:53:00+03	83000.00
A2DF22	2017-07-15 04:14:00+03	72700.00
A2DF30	2017-07-14 20:47:00+03	49100.00
A2DF96	2017-08-14 19:24:00+03	56000.00
A2DFAA	2017-07-20 13:50:00+03	65100.00
A2E043	2017-07-16 07:58:00+03	52400.00
A2E09E	2017-08-07 10:08:00+03	92800.00
A2E0EB	2017-06-29 05:33:00+03	33100.00
A2E124	2017-08-15 01:02:00+03	174900.00
A2E12E	2017-08-09 17:06:00+03	78900.00
A2E144	2017-07-11 03:53:00+03	31000.00
A2E148	2017-07-21 21:36:00+03	97400.00
A2E176	2017-07-02 15:25:00+03	241300.00
A2E17D	2017-07-02 11:35:00+03	92400.00
A2E1BE	2017-07-22 21:46:00+03	135400.00
A2E225	2017-07-08 16:34:00+03	6000.00
A2E251	2017-08-06 12:54:00+03	99900.00
A2E252	2017-08-12 03:26:00+03	25800.00
A2E2B8	2017-07-04 17:11:00+03	116700.00
A2E2BE	2017-07-03 11:46:00+03	11800.00
A2E394	2017-07-26 06:03:00+03	135200.00
A2E3D5	2017-07-09 07:22:00+03	62800.00
A2E3E8	2017-07-26 04:12:00+03	12600.00
A2E431	2017-07-27 11:26:00+03	50100.00
A2E44B	2017-06-30 05:20:00+03	34400.00
A2E460	2017-08-09 22:30:00+03	23200.00
A2E4E2	2017-07-03 02:15:00+03	15000.00
A2E4F0	2017-07-17 00:17:00+03	291700.00
A2E4F8	2017-08-03 17:30:00+03	59300.00
A2E5F4	2017-07-08 22:46:00+03	25200.00
A2E638	2017-08-14 11:54:00+03	75600.00
A2E66C	2017-07-28 19:34:00+03	23400.00
A2E685	2017-08-04 05:33:00+03	135200.00
A2E6A5	2017-07-04 03:01:00+03	246000.00
A2E6BA	2017-07-08 22:02:00+03	25700.00
A2E6D7	2017-08-03 21:18:00+03	66600.00
A2E6E4	2017-07-07 23:22:00+03	529100.00
A2E6EA	2017-07-27 13:28:00+03	98200.00
A2E730	2017-07-23 03:47:00+03	142300.00
A2E76E	2017-07-29 03:47:00+03	16400.00
A2E78C	2017-07-17 20:51:00+03	81600.00
A2E7DF	2017-07-26 16:09:00+03	134800.00
A2E805	2017-07-20 22:23:00+03	6700.00
A2E81E	2017-07-16 00:05:00+03	67000.00
A2E829	2017-07-03 05:57:00+03	202000.00
A2E896	2017-06-30 17:22:00+03	91500.00
A2E8B3	2017-07-08 09:50:00+03	29200.00
A2E999	2017-07-19 14:06:00+03	28800.00
A2E9F9	2017-07-13 09:41:00+03	67900.00
A2EAB7	2017-07-22 01:57:00+03	32800.00
A2EAEE	2017-07-06 19:24:00+03	122500.00
A2EB9A	2017-08-06 12:41:00+03	33100.00
A2EBCA	2017-07-07 13:17:00+03	28800.00
A2EC6D	2017-07-08 20:23:00+03	49500.00
A2ECBA	2017-07-14 22:15:00+03	380700.00
A2ECC6	2017-07-04 10:12:00+03	53300.00
A2EDAE	2017-08-02 03:50:00+03	67100.00
A2EDB9	2017-07-11 23:17:00+03	32700.00
A2EDD7	2017-07-22 21:41:00+03	48600.00
A2EE23	2017-08-08 16:03:00+03	14000.00
A2EE27	2017-08-05 06:49:00+03	27300.00
A2EF74	2017-07-21 18:28:00+03	39300.00
A2EF97	2017-07-16 10:48:00+03	14000.00
A2F089	2017-06-30 20:54:00+03	34900.00
A2F0C1	2017-07-14 13:15:00+03	6700.00
A2F104	2017-07-04 21:07:00+03	25400.00
A2F1DA	2017-08-15 12:40:00+03	112600.00
A2F246	2017-07-22 04:18:00+03	46300.00
A2F24E	2017-07-01 11:59:00+03	139400.00
A2F2B0	2017-08-08 01:00:00+03	25200.00
A2F2E3	2017-08-06 03:09:00+03	40000.00
A2F2F8	2017-07-31 19:21:00+03	42100.00
A2F346	2017-07-05 00:00:00+03	45400.00
A2F3D6	2017-07-04 21:46:00+03	41600.00
A2F3DB	2017-07-30 03:05:00+03	39200.00
A2F4AF	2017-07-10 21:44:00+03	51200.00
A2F527	2017-07-26 10:12:00+03	149400.00
A2F571	2017-08-15 00:38:00+03	32400.00
A2F5C5	2017-07-17 09:12:00+03	111600.00
A2F5EA	2017-08-06 20:17:00+03	186700.00
A2F63E	2017-08-14 18:31:00+03	292300.00
A2F677	2017-08-09 14:29:00+03	117600.00
A2F67A	2017-08-12 08:13:00+03	242700.00
A2F6DA	2017-07-27 20:22:00+03	223200.00
A2F746	2017-07-09 22:18:00+03	22000.00
A2F77B	2017-07-05 10:45:00+03	265600.00
A2F7D5	2017-08-12 05:08:00+03	25800.00
A2F83E	2017-07-29 00:56:00+03	67600.00
A2F8B9	2017-07-29 02:20:00+03	46000.00
A2F8CF	2017-08-03 15:19:00+03	98400.00
A2F982	2017-08-07 15:02:00+03	69500.00
A2F99C	2017-06-30 01:50:00+03	136800.00
A2F9D1	2017-08-10 22:59:00+03	32200.00
A2F9F5	2017-07-07 01:11:00+03	26700.00
A2FA34	2017-07-24 20:31:00+03	174400.00
A2FA3D	2017-07-10 01:45:00+03	46000.00
A2FA3F	2017-07-10 07:51:00+03	52600.00
A2FA45	2017-07-10 13:36:00+03	115400.00
A2FA4E	2017-07-07 17:29:00+03	88600.00
A2FA6D	2017-08-06 18:38:00+03	58200.00
A2FA89	2017-07-02 13:19:00+03	51800.00
A2FAD2	2017-08-09 18:26:00+03	40800.00
A2FB26	2017-08-07 23:50:00+03	72400.00
A2FB37	2017-07-13 17:32:00+03	23200.00
A2FB9C	2017-07-28 11:18:00+03	50600.00
A2FBDA	2017-07-08 09:22:00+03	54400.00
A2FBE9	2017-07-12 13:33:00+03	40800.00
A2FC0E	2017-07-14 19:22:00+03	26000.00
A2FD46	2017-08-15 09:11:00+03	12600.00
A2FD79	2017-07-21 05:52:00+03	271100.00
A2FDA9	2017-07-06 08:27:00+03	15000.00
A2FDC1	2017-08-12 01:46:00+03	20200.00
A2FF37	2017-07-23 02:37:00+03	224000.00
A2FFB1	2017-07-11 20:17:00+03	170000.00
A3003B	2017-07-04 15:02:00+03	88100.00
A30124	2017-07-24 03:10:00+03	29200.00
A30166	2017-07-30 08:44:00+03	29600.00
A301A2	2017-07-10 13:15:00+03	85000.00
A301B1	2017-07-27 11:52:00+03	29600.00
A301FD	2017-07-21 20:34:00+03	88200.00
A30231	2017-08-12 18:48:00+03	27800.00
A3024E	2017-07-04 10:46:00+03	15900.00
A302E8	2017-07-07 04:29:00+03	83100.00
A30353	2017-08-05 18:59:00+03	106400.00
A3036B	2017-07-10 16:39:00+03	22000.00
A3036F	2017-07-31 10:53:00+03	132800.00
A303A8	2017-08-15 09:40:00+03	9800.00
A303DF	2017-07-06 08:22:00+03	56000.00
A303FF	2017-07-19 11:14:00+03	44800.00
A3042F	2017-07-25 01:30:00+03	67000.00
A3045A	2017-07-25 01:54:00+03	98100.00
A304B4	2017-07-18 08:20:00+03	27200.00
A304F0	2017-08-06 05:17:00+03	53500.00
A30513	2017-07-25 00:54:00+03	67600.00
A30542	2017-07-11 22:34:00+03	137000.00
A3057A	2017-07-20 00:46:00+03	46700.00
A3068F	2017-07-23 09:53:00+03	23600.00
A306EB	2017-08-06 15:25:00+03	35200.00
A3075A	2017-07-28 15:35:00+03	19000.00
A307B9	2017-07-29 05:27:00+03	101200.00
A307D4	2017-07-16 05:24:00+03	148200.00
A30801	2017-07-08 20:24:00+03	8200.00
A308C4	2017-08-10 02:26:00+03	115600.00
A30921	2017-07-10 12:33:00+03	22000.00
A3093D	2017-07-20 08:54:00+03	70800.00
A3094C	2017-07-06 15:06:00+03	131600.00
A309AE	2017-07-28 01:25:00+03	40200.00
A30A68	2017-07-02 21:52:00+03	138600.00
A30A6E	2017-08-04 05:18:00+03	83600.00
A30A87	2017-07-28 12:38:00+03	26000.00
A30AA2	2017-07-04 02:31:00+03	28000.00
A30AF6	2017-07-25 07:03:00+03	202700.00
A30B01	2017-07-08 02:11:00+03	27900.00
A30B33	2017-08-01 22:09:00+03	31400.00
A30B64	2017-07-26 01:53:00+03	31400.00
A30B76	2017-07-11 14:07:00+03	192500.00
A30BAD	2017-07-08 04:51:00+03	38400.00
A30BB7	2017-07-18 02:49:00+03	68800.00
A30CA1	2017-08-05 04:07:00+03	92900.00
A30CE8	2017-06-29 03:22:00+03	100000.00
A30D2B	2017-07-18 11:26:00+03	90400.00
A30D8C	2017-07-09 00:45:00+03	70700.00
A30D9A	2017-07-06 15:07:00+03	27500.00
A30DE6	2017-08-09 19:47:00+03	46400.00
A30DFD	2017-07-01 11:33:00+03	8400.00
A30E45	2017-07-14 03:02:00+03	75300.00
A30EBD	2017-08-02 21:51:00+03	6000.00
A30EE1	2017-08-05 04:57:00+03	208100.00
A30EE2	2017-07-31 22:45:00+03	13200.00
A30EEE	2017-07-16 15:55:00+03	173600.00
A30F8F	2017-08-02 09:48:00+03	57600.00
A30FB6	2017-07-31 04:45:00+03	22000.00
A30FEE	2017-07-18 13:39:00+03	64500.00
A31000	2017-07-18 15:32:00+03	28000.00
A31016	2017-07-16 22:06:00+03	202100.00
A3102A	2017-07-21 06:03:00+03	71900.00
A31050	2017-08-12 16:40:00+03	31400.00
A310B6	2017-07-08 13:30:00+03	658000.00
A31110	2017-08-11 13:40:00+03	92400.00
A3111F	2017-08-03 12:45:00+03	260300.00
A31150	2017-08-13 03:34:00+03	29800.00
A3116B	2017-08-10 15:09:00+03	111900.00
A31175	2017-07-30 14:27:00+03	105100.00
A311B7	2017-07-13 08:30:00+03	24600.00
A311C4	2017-07-26 10:19:00+03	109600.00
A3120D	2017-07-02 11:34:00+03	58200.00
A3124D	2017-08-02 12:07:00+03	73300.00
A3129D	2017-07-08 23:43:00+03	85000.00
A312DE	2017-07-30 08:14:00+03	73600.00
A31309	2017-08-13 06:17:00+03	41800.00
A31385	2017-08-13 04:12:00+03	30800.00
A313D2	2017-07-11 17:19:00+03	111600.00
A313F9	2017-08-04 18:58:00+03	12200.00
A31484	2017-07-21 07:12:00+03	57300.00
A31571	2017-08-04 07:16:00+03	73600.00
A31577	2017-08-10 23:59:00+03	32200.00
A315A2	2017-08-06 17:38:00+03	125200.00
A315DE	2017-07-23 23:21:00+03	12600.00
A315EA	2017-08-10 13:49:00+03	92800.00
A3162D	2017-07-23 00:15:00+03	257500.00
A3164A	2017-08-06 12:04:00+03	65900.00
A3165C	2017-07-13 16:54:00+03	23200.00
A316F9	2017-07-29 13:05:00+03	19500.00
A31797	2017-07-21 17:28:00+03	65900.00
A317C4	2017-07-22 09:02:00+03	252200.00
A3180C	2017-07-03 13:15:00+03	75500.00
A31818	2017-07-21 17:13:00+03	147700.00
A3183E	2017-08-12 09:06:00+03	26800.00
A31842	2017-08-04 10:45:00+03	99200.00
A31853	2017-07-19 09:13:00+03	43400.00
A31887	2017-07-06 10:05:00+03	26800.00
A318A1	2017-07-01 15:09:00+03	76300.00
A318B1	2017-07-03 16:23:00+03	72800.00
A3197E	2017-07-01 16:16:00+03	62600.00
A319E6	2017-07-15 11:21:00+03	7400.00
A319FF	2017-07-17 22:12:00+03	31400.00
A31A1C	2017-07-18 13:15:00+03	67400.00
A31AC7	2017-07-07 09:19:00+03	50800.00
A31AD4	2017-07-19 04:51:00+03	28000.00
A31AF8	2017-07-20 01:28:00+03	24400.00
A31B7E	2017-07-26 17:30:00+03	31600.00
A31B83	2017-07-04 17:38:00+03	28000.00
A31BA7	2017-07-16 20:52:00+03	135600.00
A31BBB	2017-07-24 14:13:00+03	43600.00
A31BD4	2017-07-24 15:29:00+03	25800.00
A31C21	2017-07-05 17:23:00+03	72200.00
A31C3B	2017-07-15 16:50:00+03	58600.00
A31C6B	2017-08-15 15:31:00+03	24800.00
A31D0F	2017-08-15 12:47:00+03	272300.00
A31D12	2017-08-06 19:10:00+03	24800.00
A31D15	2017-07-19 08:03:00+03	72300.00
A31D20	2017-07-06 09:50:00+03	30200.00
A31D2B	2017-07-04 13:21:00+03	56600.00
A31DDF	2017-08-06 16:36:00+03	23200.00
A31E4D	2017-07-31 02:53:00+03	137900.00
A31E70	2017-08-10 14:53:00+03	10800.00
A31E72	2017-08-01 01:43:00+03	56000.00
A31F3F	2017-07-16 01:24:00+03	167400.00
A31F43	2017-08-07 16:18:00+03	15700.00
A31F62	2017-07-23 11:57:00+03	56000.00
A3206D	2017-07-05 18:47:00+03	21400.00
A320C0	2017-07-06 13:21:00+03	6700.00
A320F9	2017-08-12 10:20:00+03	13600.00
A32190	2017-08-12 01:52:00+03	33100.00
A3219F	2017-08-03 12:20:00+03	85000.00
A321F0	2017-08-01 04:32:00+03	30400.00
A322A3	2017-07-14 07:07:00+03	85000.00
A323AA	2017-08-13 03:57:00+03	33100.00
A323B7	2017-07-12 14:58:00+03	66200.00
A323DF	2017-08-07 13:20:00+03	45200.00
A323EE	2017-08-04 15:29:00+03	59200.00
A323FF	2017-06-29 01:58:00+03	20800.00
A32408	2017-08-05 23:12:00+03	123000.00
A3245E	2017-07-26 21:43:00+03	81600.00
A324AB	2017-07-25 07:00:00+03	36200.00
A324DC	2017-08-14 05:30:00+03	67600.00
A324E0	2017-07-08 18:00:00+03	85000.00
A324E3	2017-07-07 13:37:00+03	40400.00
A325A8	2017-07-25 19:54:00+03	100000.00
A3263B	2017-08-03 10:19:00+03	40100.00
A3269C	2017-07-28 00:00:00+03	122300.00
A327C6	2017-07-03 09:13:00+03	174000.00
A3282B	2017-07-02 02:01:00+03	31400.00
A32999	2017-07-15 20:07:00+03	24400.00
A329D1	2017-08-05 14:54:00+03	85000.00
A32A09	2017-08-04 07:40:00+03	47000.00
A32A32	2017-08-15 13:38:00+03	92800.00
A32A98	2017-07-22 14:51:00+03	6000.00
A32B20	2017-08-14 13:55:00+03	40200.00
A32C39	2017-07-29 11:10:00+03	48700.00
A32DA0	2017-07-29 08:14:00+03	23200.00
A32DEC	2017-06-30 10:19:00+03	88500.00
A32E63	2017-07-10 07:15:00+03	47700.00
A32E87	2017-08-04 15:59:00+03	64400.00
A32E9C	2017-07-26 03:08:00+03	20000.00
A32EDD	2017-07-12 03:28:00+03	75300.00
A32F33	2017-08-09 17:33:00+03	70500.00
A32F55	2017-07-12 01:06:00+03	26000.00
A32F73	2017-08-12 05:59:00+03	123400.00
A32F9A	2017-08-13 05:31:00+03	12800.00
A32FA4	2017-07-27 08:26:00+03	133700.00
A32FCA	2017-07-15 08:48:00+03	56000.00
A32FEE	2017-07-15 07:51:00+03	16400.00
A33026	2017-08-12 07:53:00+03	31400.00
A3303D	2017-08-07 19:23:00+03	28800.00
A330A1	2017-08-15 17:54:00+03	83300.00
A330DA	2017-07-04 17:05:00+03	152400.00
A3310D	2017-07-23 11:36:00+03	258400.00
A3319E	2017-07-15 03:15:00+03	265700.00
A331B2	2017-08-03 02:34:00+03	386700.00
A331CD	2017-08-08 23:34:00+03	57500.00
A3320A	2017-07-19 10:58:00+03	241300.00
A332A1	2017-07-24 13:56:00+03	52700.00
A33324	2017-07-17 08:44:00+03	167400.00
A3333B	2017-08-10 15:40:00+03	61800.00
A33360	2017-07-14 10:50:00+03	182300.00
A33376	2017-08-13 04:47:00+03	64200.00
A3337A	2017-06-29 19:16:00+03	117200.00
A333B0	2017-07-31 14:56:00+03	125200.00
A333D1	2017-07-26 23:36:00+03	115600.00
A3340C	2017-07-06 16:28:00+03	14800.00
A33479	2017-07-08 20:50:00+03	55600.00
A33486	2017-08-15 14:49:00+03	142400.00
A334A3	2017-07-23 19:40:00+03	97400.00
A334E4	2017-07-29 03:13:00+03	167400.00
A334E6	2017-07-13 01:19:00+03	56000.00
A334F3	2017-08-02 07:26:00+03	71800.00
A33540	2017-08-10 23:22:00+03	155600.00
A33556	2017-08-06 01:00:00+03	32800.00
A335A1	2017-08-06 15:25:00+03	111700.00
A335B2	2017-08-12 21:04:00+03	38000.00
A33635	2017-07-19 18:29:00+03	48800.00
A33684	2017-08-09 16:46:00+03	114400.00
A3368B	2017-08-02 09:40:00+03	46400.00
A336C4	2017-07-25 23:12:00+03	28000.00
A3371A	2017-07-13 03:55:00+03	94800.00
A33754	2017-07-22 10:52:00+03	46400.00
A337B3	2017-07-05 13:43:00+03	73500.00
A33830	2017-07-09 08:26:00+03	77900.00
A33852	2017-07-06 18:59:00+03	26600.00
A33864	2017-08-12 08:07:00+03	25100.00
A33899	2017-07-15 00:50:00+03	32700.00
A338D2	2017-07-07 05:46:00+03	46000.00
A338D3	2017-06-29 15:55:00+03	54500.00
A338F1	2017-07-31 12:17:00+03	124200.00
A33929	2017-07-04 20:36:00+03	14800.00
A33985	2017-07-09 16:28:00+03	28000.00
A339A0	2017-07-26 06:06:00+03	170000.00
A339B6	2017-08-10 07:13:00+03	28300.00
A339FE	2017-07-15 20:33:00+03	17800.00
A33AAE	2017-08-02 14:16:00+03	70800.00
A33B0B	2017-08-15 01:59:00+03	99200.00
A33B2E	2017-07-18 06:44:00+03	27900.00
A33B43	2017-07-16 12:52:00+03	48800.00
A33B5D	2017-07-10 06:01:00+03	22100.00
A33B80	2017-07-30 03:03:00+03	65600.00
A33B8F	2017-08-05 03:35:00+03	114800.00
A33BB1	2017-08-13 20:20:00+03	136800.00
A33BED	2017-07-16 10:16:00+03	29600.00
A33BF4	2017-07-26 16:25:00+03	6700.00
A33BF6	2017-07-25 04:16:00+03	14100.00
A33C4C	2017-08-09 12:00:00+03	70500.00
A33C62	2017-07-08 06:11:00+03	161800.00
A33C92	2017-07-07 14:54:00+03	28000.00
A33C93	2017-07-31 15:07:00+03	86800.00
A33CF5	2017-07-01 06:03:00+03	30400.00
A33D36	2017-07-02 01:09:00+03	105100.00
A33D52	2017-08-03 20:05:00+03	25400.00
A33D67	2017-07-22 06:02:00+03	28800.00
A33D7D	2017-07-28 13:17:00+03	21400.00
A33DAD	2017-08-05 23:58:00+03	92700.00
A33DB6	2017-07-25 21:49:00+03	112000.00
A33DB7	2017-07-04 11:33:00+03	166100.00
A33E6A	2017-08-11 08:02:00+03	49400.00
A33E81	2017-08-10 12:41:00+03	77200.00
A33E88	2017-08-05 16:10:00+03	44400.00
A33E8A	2017-08-15 03:55:00+03	26000.00
A33EAA	2017-07-19 13:05:00+03	44000.00
A33F62	2017-07-25 04:50:00+03	31100.00
A33F6C	2017-07-05 16:27:00+03	6000.00
A33FA9	2017-07-26 19:09:00+03	50600.00
A33FB2	2017-07-12 22:31:00+03	65800.00
A3400F	2017-07-19 11:30:00+03	47200.00
A34077	2017-07-11 17:21:00+03	52500.00
A34079	2017-07-09 02:14:00+03	123000.00
A340A3	2017-07-25 20:08:00+03	16400.00
A340D7	2017-08-05 03:40:00+03	119500.00
A3414E	2017-07-30 13:32:00+03	28800.00
A34187	2017-08-13 10:01:00+03	160300.00
A341BE	2017-07-06 21:41:00+03	28800.00
A34233	2017-08-11 16:18:00+03	37500.00
A34268	2017-08-13 05:36:00+03	166000.00
A34305	2017-08-06 22:36:00+03	34000.00
A34353	2017-08-08 16:27:00+03	496600.00
A34382	2017-07-15 09:26:00+03	135100.00
A34384	2017-07-08 13:48:00+03	136600.00
A34399	2017-07-06 04:30:00+03	21200.00
A3444B	2017-07-17 11:38:00+03	24400.00
A34461	2017-07-16 17:29:00+03	86600.00
A345E7	2017-07-30 03:49:00+03	15100.00
A345F1	2017-08-11 18:22:00+03	31400.00
A3460D	2017-08-12 18:55:00+03	123000.00
A3461B	2017-08-09 22:01:00+03	142800.00
A34653	2017-07-03 05:37:00+03	43800.00
A346A9	2017-07-31 06:51:00+03	260900.00
A346CD	2017-08-06 02:52:00+03	131100.00
A346EE	2017-07-16 09:47:00+03	141800.00
A34714	2017-08-03 12:34:00+03	234700.00
A34747	2017-07-23 01:51:00+03	68400.00
A3474D	2017-07-09 10:24:00+03	117600.00
A3475B	2017-07-30 01:03:00+03	40800.00
A34767	2017-07-11 00:48:00+03	68000.00
A347A7	2017-08-08 11:46:00+03	154100.00
A347C2	2017-07-23 16:51:00+03	101200.00
A347E2	2017-06-30 04:57:00+03	207200.00
A34835	2017-07-24 23:14:00+03	101200.00
A34894	2017-07-13 15:54:00+03	149100.00
A348D3	2017-08-03 19:40:00+03	54000.00
A348FC	2017-08-04 19:12:00+03	80000.00
A3497D	2017-08-15 16:35:00+03	56300.00
A349DC	2017-08-10 16:13:00+03	157400.00
A349FE	2017-07-31 15:29:00+03	58200.00
A34A23	2017-07-13 10:18:00+03	67200.00
A34A4C	2017-07-14 21:17:00+03	200500.00
A34AB5	2017-07-07 07:15:00+03	71900.00
A34ACF	2017-07-04 07:47:00+03	10600.00
A34B58	2017-07-22 18:55:00+03	167400.00
A34BD0	2017-08-02 23:23:00+03	67100.00
A34C06	2017-07-23 21:59:00+03	23600.00
A34C1B	2017-08-08 10:46:00+03	22000.00
A34C7B	2017-08-05 15:15:00+03	147900.00
A34C8E	2017-08-01 10:51:00+03	56000.00
A34CDE	2017-07-14 07:56:00+03	59000.00
A34CEF	2017-08-12 04:50:00+03	38800.00
A34D01	2017-08-03 16:49:00+03	56000.00
A34D1D	2017-07-25 18:07:00+03	54800.00
A34D3A	2017-07-02 15:45:00+03	177200.00
A34DD2	2017-07-21 18:10:00+03	24700.00
A34DEC	2017-07-25 10:31:00+03	31600.00
A34E02	2017-07-01 16:16:00+03	136800.00
A34E08	2017-07-29 08:54:00+03	83000.00
A34E31	2017-07-21 16:03:00+03	99200.00
A34E6E	2017-07-08 11:45:00+03	14400.00
A34EAD	2017-08-14 18:03:00+03	36400.00
A34EF6	2017-07-17 18:10:00+03	54500.00
A34F40	2017-08-04 04:15:00+03	114900.00
A34F8F	2017-07-05 04:36:00+03	6300.00
A34FA6	2017-08-15 17:09:00+03	18100.00
A34FBA	2017-07-08 09:01:00+03	80200.00
A34FD9	2017-07-28 07:02:00+03	165500.00
A34FF4	2017-06-25 17:46:00+03	35200.00
A3507D	2017-07-11 21:46:00+03	12400.00
A350B0	2017-07-04 13:11:00+03	90800.00
A350B9	2017-07-18 03:34:00+03	73500.00
A35102	2017-08-01 18:37:00+03	41600.00
A35125	2017-07-13 02:53:00+03	71900.00
A35131	2017-07-23 22:49:00+03	49100.00
A35178	2017-08-15 01:04:00+03	8000.00
A3518C	2017-07-21 15:02:00+03	136200.00
A351C2	2017-07-14 18:40:00+03	77500.00
A35273	2017-07-29 08:01:00+03	36200.00
A352BA	2017-07-21 07:00:00+03	67600.00
A352D7	2017-08-15 02:06:00+03	32300.00
A3530E	2017-07-05 08:06:00+03	38600.00
A35312	2017-08-13 12:28:00+03	48800.00
A35319	2017-07-22 05:31:00+03	116000.00
A3535C	2017-08-14 05:06:00+03	44800.00
A35398	2017-07-22 16:41:00+03	28000.00
A353C4	2017-07-02 06:53:00+03	31400.00
A353D0	2017-08-11 17:10:00+03	111600.00
A3542C	2017-07-12 00:24:00+03	28800.00
A3543B	2017-07-20 00:29:00+03	54300.00
A35455	2017-07-10 11:48:00+03	47600.00
A35456	2017-07-22 05:24:00+03	119000.00
A3551D	2017-08-14 18:47:00+03	25800.00
A355A1	2017-07-22 08:03:00+03	26000.00
A355A5	2017-07-16 11:22:00+03	26000.00
A355BC	2017-07-09 00:38:00+03	28000.00
A35618	2017-08-12 06:09:00+03	48100.00
A35681	2017-08-07 23:29:00+03	26000.00
A35860	2017-07-10 12:02:00+03	80300.00
A358B9	2017-08-09 15:31:00+03	27500.00
A35953	2017-08-10 10:24:00+03	28800.00
A3596A	2017-08-09 14:38:00+03	24500.00
A35984	2017-08-06 21:03:00+03	135600.00
A3599D	2017-07-02 09:03:00+03	24400.00
A35A39	2017-07-26 22:46:00+03	6700.00
A35ADA	2017-07-19 15:04:00+03	47600.00
A35AE5	2017-07-20 23:30:00+03	34000.00
A35B26	2017-07-22 03:17:00+03	18000.00
A35B52	2017-07-06 20:55:00+03	25600.00
A35C30	2017-07-23 05:45:00+03	28800.00
A35CEF	2017-07-18 11:33:00+03	10600.00
A35D06	2017-07-16 07:03:00+03	83600.00
A35D73	2017-08-07 21:39:00+03	63200.00
A35D8E	2017-08-05 13:11:00+03	62800.00
A35D9E	2017-08-01 07:58:00+03	124400.00
A35DA0	2017-07-21 17:45:00+03	23200.00
A35DBD	2017-07-12 08:36:00+03	43200.00
A35DCC	2017-07-31 10:20:00+03	45100.00
A35DE4	2017-07-09 16:48:00+03	248400.00
A35E2C	2017-08-06 13:24:00+03	16400.00
A35E73	2017-07-10 05:43:00+03	32600.00
A35F54	2017-07-06 06:19:00+03	47100.00
A35F72	2017-07-25 12:01:00+03	88600.00
A35F96	2017-08-04 03:04:00+03	182700.00
A35FAD	2017-07-15 03:17:00+03	106900.00
A35FFA	2017-07-12 02:11:00+03	25600.00
A36022	2017-07-31 11:09:00+03	32900.00
A36069	2017-06-28 09:32:00+03	38800.00
A36073	2017-07-22 14:53:00+03	13600.00
A360A9	2017-07-16 01:12:00+03	52700.00
A360CE	2017-07-21 14:21:00+03	147000.00
A360DC	2017-08-14 17:32:00+03	157000.00
A360EB	2017-08-03 09:14:00+03	47700.00
A360ED	2017-07-06 21:14:00+03	73100.00
A3610C	2017-07-09 15:25:00+03	19600.00
A36129	2017-08-12 09:48:00+03	123000.00
A3613F	2017-07-23 17:24:00+03	67600.00
A36174	2017-07-26 18:32:00+03	21800.00
A3618C	2017-07-20 21:57:00+03	52300.00
A3619C	2017-07-05 12:35:00+03	46400.00
A3619E	2017-08-05 04:33:00+03	68800.00
A361DD	2017-08-08 05:50:00+03	26000.00
A361E4	2017-07-09 04:07:00+03	91600.00
A36230	2017-07-13 06:03:00+03	18600.00
A3623C	2017-07-30 00:20:00+03	51900.00
A36249	2017-08-07 06:11:00+03	14000.00
A36297	2017-07-03 14:26:00+03	235700.00
A362B1	2017-08-14 18:17:00+03	14400.00
A36309	2017-08-11 06:19:00+03	76800.00
A36423	2017-07-21 12:53:00+03	55800.00
A36457	2017-07-06 06:30:00+03	147700.00
A36459	2017-07-16 04:58:00+03	306500.00
A36478	2017-07-07 09:13:00+03	134400.00
A36529	2017-07-13 11:29:00+03	20400.00
A36634	2017-07-14 08:39:00+03	26500.00
A3664F	2017-07-27 00:29:00+03	8200.00
A36667	2017-08-08 08:22:00+03	185000.00
A3666D	2017-08-01 15:47:00+03	100600.00
A36685	2017-08-07 12:46:00+03	23200.00
A3674C	2017-08-12 18:57:00+03	260900.00
A36798	2017-07-25 16:04:00+03	46400.00
A36835	2017-07-16 00:59:00+03	93700.00
A36864	2017-07-18 15:00:00+03	92900.00
A368E4	2017-07-27 02:42:00+03	43200.00
A36908	2017-07-08 01:11:00+03	67400.00
A3690E	2017-08-09 19:43:00+03	23600.00
A3691B	2017-07-23 01:53:00+03	66600.00
A3694C	2017-08-01 20:17:00+03	123900.00
A36954	2017-06-28 16:44:00+03	170800.00
A3698F	2017-07-23 09:41:00+03	29600.00
A36998	2017-07-18 08:19:00+03	46400.00
A369AE	2017-07-21 23:15:00+03	107200.00
A369BD	2017-08-11 23:25:00+03	14400.00
A369C9	2017-08-07 05:38:00+03	81600.00
A369DA	2017-07-12 14:07:00+03	72400.00
A369EE	2017-07-30 13:20:00+03	132800.00
A36A48	2017-07-14 16:56:00+03	46300.00
A36B06	2017-07-21 23:37:00+03	162200.00
A36BAC	2017-07-13 21:44:00+03	86000.00
A36BB3	2017-07-03 06:56:00+03	62600.00
A36BC8	2017-07-24 22:28:00+03	111600.00
A36C09	2017-06-29 06:58:00+03	16400.00
A36C13	2017-07-19 09:40:00+03	55800.00
A36C35	2017-08-03 11:20:00+03	20200.00
A36C3A	2017-06-29 14:54:00+03	122300.00
A36C40	2017-07-27 15:37:00+03	28000.00
A36C65	2017-07-17 08:31:00+03	112000.00
A36C93	2017-08-14 04:54:00+03	42000.00
A36DCD	2017-07-20 05:41:00+03	28000.00
A36DD6	2017-07-05 22:07:00+03	67400.00
A36E60	2017-08-08 02:55:00+03	135000.00
A36E7F	2017-07-14 23:44:00+03	8400.00
A36EA9	2017-08-07 22:50:00+03	58000.00
A36ECC	2017-08-02 20:02:00+03	82000.00
A36EF0	2017-07-08 17:01:00+03	19600.00
A36F0F	2017-07-27 12:43:00+03	40000.00
A36F70	2017-07-05 21:58:00+03	81600.00
A36FA2	2017-07-10 19:48:00+03	14800.00
A37023	2017-07-17 23:40:00+03	37200.00
A370BA	2017-07-23 16:36:00+03	28200.00
A3713A	2017-07-13 12:32:00+03	50100.00
A3713E	2017-07-03 13:26:00+03	80000.00
A37199	2017-07-12 20:17:00+03	28000.00
A371C8	2017-08-10 05:01:00+03	139300.00
A371CD	2017-07-11 11:21:00+03	114800.00
A371ED	2017-07-16 17:35:00+03	46900.00
A371F2	2017-08-02 00:20:00+03	67900.00
A3721D	2017-06-30 03:16:00+03	40900.00
A37220	2017-07-29 14:28:00+03	31600.00
A37228	2017-07-17 06:52:00+03	44100.00
A3725F	2017-07-06 16:33:00+03	7400.00
A3726C	2017-08-03 02:19:00+03	22000.00
A3728D	2017-07-16 14:05:00+03	38400.00
A37292	2017-07-24 17:08:00+03	13000.00
A37350	2017-08-11 08:35:00+03	146300.00
A37393	2017-07-02 06:33:00+03	276800.00
A373A5	2017-07-23 04:14:00+03	39200.00
A3740A	2017-08-04 10:47:00+03	92700.00
A3740E	2017-07-03 00:41:00+03	47200.00
A37486	2017-08-04 21:55:00+03	28800.00
A37504	2017-07-24 03:21:00+03	24400.00
A37527	2017-07-31 09:49:00+03	40000.00
A37640	2017-06-30 08:51:00+03	170500.00
A3765B	2017-07-26 23:51:00+03	92400.00
A3765C	2017-08-11 19:34:00+03	15700.00
A376CE	2017-07-21 03:55:00+03	58800.00
A376E3	2017-08-13 11:02:00+03	205400.00
A37786	2017-08-06 20:22:00+03	144700.00
A3778E	2017-08-03 07:50:00+03	24400.00
A3778F	2017-08-11 07:21:00+03	29400.00
A377C4	2017-07-10 19:57:00+03	92600.00
A37893	2017-07-07 04:01:00+03	46000.00
A378A7	2017-07-08 06:34:00+03	67600.00
A378C1	2017-07-01 21:16:00+03	28000.00
A378DD	2017-08-04 13:12:00+03	100600.00
A37930	2017-08-06 01:24:00+03	77900.00
A3794E	2017-07-16 19:24:00+03	20000.00
A37968	2017-07-06 21:12:00+03	112600.00
A379C4	2017-07-19 18:56:00+03	59300.00
A37A0D	2017-07-11 16:12:00+03	70100.00
A37AB3	2017-08-14 02:34:00+03	30400.00
A37AB5	2017-08-11 08:08:00+03	102300.00
A37AB9	2017-08-06 23:27:00+03	55800.00
A37B12	2017-07-07 17:42:00+03	19600.00
A37B3F	2017-07-04 22:57:00+03	58900.00
A37B56	2017-07-21 14:37:00+03	65200.00
A37B9D	2017-07-21 11:38:00+03	34000.00
A37BE1	2017-07-20 14:56:00+03	10600.00
A37BF8	2017-08-11 02:38:00+03	252200.00
A37C33	2017-07-29 03:48:00+03	26700.00
A37C63	2017-08-02 17:00:00+03	266400.00
A37CA9	2017-07-11 00:30:00+03	49900.00
A37D61	2017-08-07 21:12:00+03	61800.00
A37DF9	2017-07-10 15:50:00+03	27200.00
A37E36	2017-07-25 02:32:00+03	149200.00
A37EDE	2017-08-02 21:36:00+03	198600.00
A37EE4	2017-08-08 12:29:00+03	86300.00
A37F29	2017-07-05 02:26:00+03	38200.00
A37F5D	2017-07-23 22:44:00+03	56100.00
A37F7C	2017-07-31 13:59:00+03	31400.00
A37FBD	2017-07-22 08:46:00+03	134200.00
A37FC5	2017-07-24 23:54:00+03	167500.00
A37FD6	2017-07-01 05:45:00+03	260300.00
A3802B	2017-08-08 15:11:00+03	36700.00
A380E5	2017-08-12 03:12:00+03	122800.00
A38155	2017-08-01 12:33:00+03	387400.00
A38174	2017-07-12 06:11:00+03	64600.00
A3820D	2017-07-25 15:09:00+03	14000.00
A38263	2017-08-12 18:30:00+03	113700.00
A3826D	2017-07-01 13:26:00+03	46400.00
A382D0	2017-08-08 13:56:00+03	248400.00
A38305	2017-07-27 15:18:00+03	71200.00
A3835F	2017-07-12 18:32:00+03	54500.00
A383B0	2017-07-05 16:43:00+03	47800.00
A383D2	2017-07-27 04:44:00+03	60700.00
A38419	2017-08-07 11:33:00+03	83000.00
A384C7	2017-08-08 01:02:00+03	103500.00
A3850E	2017-07-21 02:20:00+03	149100.00
A38530	2017-08-10 20:34:00+03	85000.00
A3854A	2017-07-26 16:37:00+03	102700.00
A38561	2017-08-10 19:17:00+03	55800.00
A38568	2017-07-28 19:59:00+03	85000.00
A3858B	2017-07-13 07:00:00+03	40100.00
A385C1	2017-07-30 21:32:00+03	66600.00
A385CC	2017-08-10 22:24:00+03	50600.00
A385CD	2017-07-28 02:42:00+03	28800.00
A385DC	2017-07-20 07:37:00+03	10800.00
A385F8	2017-07-04 14:25:00+03	50000.00
A3861A	2017-07-12 11:35:00+03	164600.00
A3861C	2017-07-15 23:17:00+03	28000.00
A3866F	2017-08-15 02:52:00+03	24400.00
A38680	2017-07-24 04:21:00+03	56000.00
A38730	2017-08-14 05:05:00+03	29400.00
A3873A	2017-06-29 22:41:00+03	124200.00
A3873E	2017-07-07 06:06:00+03	58800.00
A3874B	2017-07-08 13:53:00+03	153300.00
A38795	2017-07-16 01:04:00+03	50800.00
A387A9	2017-08-14 02:20:00+03	49800.00
A38805	2017-08-09 14:57:00+03	8400.00
A3888A	2017-07-22 08:02:00+03	32800.00
A388B5	2017-06-30 15:40:00+03	30200.00
A38A32	2017-08-06 03:08:00+03	21800.00
A38AA1	2017-08-05 23:35:00+03	57600.00
A38ADE	2017-07-26 12:23:00+03	124200.00
A38AEA	2017-08-10 06:33:00+03	73500.00
A38AED	2017-08-05 00:25:00+03	136600.00
A38B07	2017-08-09 02:44:00+03	23200.00
A38B13	2017-07-20 21:50:00+03	58800.00
A38B63	2017-07-23 18:51:00+03	93900.00
A38BD9	2017-07-20 10:29:00+03	133100.00
A38BEA	2017-07-27 22:46:00+03	32800.00
A38C00	2017-07-13 14:14:00+03	46900.00
A38C3C	2017-08-01 20:29:00+03	44600.00
A38C52	2017-08-14 05:30:00+03	163100.00
A38CF9	2017-08-09 02:25:00+03	54800.00
A38D0E	2017-07-08 07:15:00+03	11600.00
A38D45	2017-07-20 00:24:00+03	67500.00
A38D54	2017-07-12 00:07:00+03	531400.00
A38D96	2017-08-11 11:23:00+03	95700.00
A38E13	2017-08-08 06:09:00+03	73000.00
A38E15	2017-07-22 04:48:00+03	87700.00
A38E5A	2017-08-04 13:45:00+03	46200.00
A38E6E	2017-08-13 13:18:00+03	99200.00
A38F70	2017-07-16 20:51:00+03	65600.00
A38F98	2017-07-18 12:04:00+03	85600.00
A38FB6	2017-06-30 21:38:00+03	58600.00
A39088	2017-08-13 00:36:00+03	19600.00
A39090	2017-08-10 14:30:00+03	40600.00
A390A3	2017-07-17 20:04:00+03	34100.00
A390CB	2017-07-09 13:08:00+03	274200.00
A390EB	2017-07-10 01:49:00+03	44800.00
A390F5	2017-08-09 15:04:00+03	72600.00
A39103	2017-08-12 15:59:00+03	135400.00
A39129	2017-07-29 06:02:00+03	101200.00
A3912E	2017-08-08 18:55:00+03	12000.00
A39158	2017-08-06 05:07:00+03	17200.00
A39173	2017-08-06 14:51:00+03	28000.00
A39181	2017-07-16 12:29:00+03	116800.00
A391A4	2017-08-11 20:36:00+03	123000.00
A391F8	2017-08-03 21:08:00+03	46800.00
A39226	2017-07-19 01:18:00+03	46300.00
A392A2	2017-07-02 23:51:00+03	224000.00
A392BF	2017-08-08 17:00:00+03	21400.00
A392C6	2017-07-22 20:49:00+03	34700.00
A392CB	2017-07-26 00:50:00+03	131100.00
A392D0	2017-07-31 18:13:00+03	23200.00
A392F7	2017-07-23 13:31:00+03	57500.00
A392FC	2017-06-26 03:17:00+03	37500.00
A39337	2017-07-01 13:15:00+03	28000.00
A3938E	2017-08-05 00:41:00+03	281500.00
A393CF	2017-08-15 02:32:00+03	59300.00
A394F5	2017-07-25 03:13:00+03	86600.00
A39519	2017-07-12 17:13:00+03	133600.00
A39587	2017-07-16 19:07:00+03	103800.00
A39595	2017-07-17 23:19:00+03	106100.00
A395A3	2017-06-28 13:53:00+03	76300.00
A395B3	2017-07-17 13:14:00+03	69500.00
A395BD	2017-08-05 14:35:00+03	92400.00
A3968B	2017-08-12 18:22:00+03	55000.00
A396DD	2017-07-21 23:01:00+03	47400.00
A396EB	2017-08-13 03:40:00+03	31400.00
A397A9	2017-07-27 21:27:00+03	46500.00
A397BF	2017-08-06 18:25:00+03	55800.00
A397F0	2017-07-10 23:24:00+03	174900.00
A3983A	2017-08-01 12:59:00+03	20500.00
A3984A	2017-08-13 14:24:00+03	10800.00
A39889	2017-07-11 06:05:00+03	27800.00
A398F1	2017-07-29 05:37:00+03	30300.00
A39905	2017-07-31 09:17:00+03	168000.00
A39944	2017-08-15 11:38:00+03	53400.00
A399BB	2017-07-19 13:36:00+03	135600.00
A399E2	2017-07-20 21:03:00+03	81700.00
A39A3F	2017-07-15 08:51:00+03	148200.00
A39A89	2017-07-25 20:42:00+03	28000.00
A39ADB	2017-08-12 16:31:00+03	19600.00
A39AF7	2017-07-06 07:41:00+03	223200.00
A39B19	2017-07-19 12:30:00+03	31600.00
A39B8D	2017-07-22 19:47:00+03	43200.00
A39BB4	2017-07-24 13:26:00+03	43600.00
A39BFC	2017-08-12 13:01:00+03	89600.00
A39C60	2017-07-14 00:06:00+03	40800.00
A39C6A	2017-07-25 17:48:00+03	90400.00
A39C96	2017-08-03 05:57:00+03	133100.00
A39C9F	2017-08-13 21:32:00+03	254900.00
A39D5D	2017-08-14 11:07:00+03	86600.00
A39DB0	2017-06-28 05:21:00+03	25600.00
A39DC7	2017-07-25 00:48:00+03	8000.00
A39E35	2017-08-07 17:04:00+03	271200.00
A39ECF	2017-08-12 20:42:00+03	31100.00
A39EE1	2017-07-08 17:34:00+03	112600.00
A39F70	2017-08-15 05:25:00+03	61500.00
A39FB6	2017-07-21 12:39:00+03	44800.00
A3A00A	2017-07-25 17:38:00+03	78800.00
A3A020	2017-08-06 05:50:00+03	47600.00
A3A048	2017-07-14 09:12:00+03	185300.00
A3A076	2017-08-01 23:48:00+03	62800.00
A3A09D	2017-07-28 08:01:00+03	37200.00
A3A09E	2017-08-11 08:29:00+03	26000.00
A3A0BF	2017-07-29 02:59:00+03	19600.00
A3A116	2017-07-16 02:23:00+03	37400.00
A3A125	2017-08-06 17:11:00+03	45100.00
A3A13C	2017-07-27 08:46:00+03	8400.00
A3A1AE	2017-08-07 09:48:00+03	57600.00
A3A1BE	2017-07-17 08:28:00+03	182200.00
A3A1F6	2017-07-28 15:37:00+03	28000.00
A3A237	2017-07-12 02:12:00+03	11200.00
A3A2D2	2017-07-21 15:05:00+03	25800.00
A3A2E3	2017-08-06 22:51:00+03	201400.00
A3A371	2017-07-30 02:31:00+03	23600.00
A3A3BA	2017-07-18 04:43:00+03	23400.00
A3A3CB	2017-08-10 13:15:00+03	69400.00
A3A3D4	2017-07-09 15:54:00+03	184500.00
A3A4AF	2017-07-19 00:40:00+03	33600.00
A3A4B3	2017-07-08 06:21:00+03	23200.00
A3A4D6	2017-08-12 06:59:00+03	41900.00
A3A4E1	2017-08-14 13:39:00+03	72400.00
A3A511	2017-07-02 18:05:00+03	387300.00
A3A53F	2017-08-07 09:53:00+03	70700.00
A3A571	2017-07-06 14:18:00+03	23600.00
A3A58D	2017-07-25 19:20:00+03	124200.00
A3A5D5	2017-07-16 10:36:00+03	34600.00
A3A5ED	2017-07-29 00:23:00+03	139500.00
A3A694	2017-08-06 04:59:00+03	202000.00
A3A6AD	2017-07-15 06:09:00+03	123000.00
A3A6B8	2017-07-10 09:42:00+03	14800.00
A3A6D2	2017-07-12 02:02:00+03	119500.00
A3A718	2017-08-02 08:23:00+03	10700.00
A3A7D7	2017-08-02 06:12:00+03	67600.00
A3A7F0	2017-07-21 10:17:00+03	160800.00
A3A807	2017-08-15 15:35:00+03	62000.00
A3A856	2017-08-14 22:29:00+03	26000.00
A3A891	2017-07-10 23:53:00+03	174600.00
A3A89E	2017-07-19 22:16:00+03	62800.00
A3A8A8	2017-07-21 21:23:00+03	27500.00
A3A8EA	2017-08-14 04:28:00+03	99200.00
A3A965	2017-07-07 01:53:00+03	63300.00
A3A9FA	2017-08-05 22:30:00+03	21800.00
A3AA03	2017-07-25 21:16:00+03	57400.00
A3AA3E	2017-08-11 05:41:00+03	37600.00
A3AACF	2017-07-08 06:08:00+03	119700.00
A3AB23	2017-07-13 07:20:00+03	47400.00
A3AB45	2017-08-13 18:29:00+03	46300.00
A3AB52	2017-08-06 15:14:00+03	406700.00
A3AB70	2017-08-15 02:38:00+03	12400.00
A3ABAD	2017-07-21 07:42:00+03	36900.00
A3ABE3	2017-08-12 17:48:00+03	28000.00
A3AC00	2017-08-07 09:42:00+03	286100.00
A3AC0C	2017-07-16 07:17:00+03	26800.00
A3AC1F	2017-08-14 12:11:00+03	26700.00
A3AC45	2017-07-19 15:39:00+03	99200.00
A3AC8B	2017-07-10 15:25:00+03	73900.00
A3ACC8	2017-07-07 15:37:00+03	73600.00
A3ACC9	2017-08-09 21:48:00+03	23200.00
A3AD56	2017-07-13 20:16:00+03	88800.00
A3AD93	2017-08-14 21:05:00+03	66600.00
A3AE41	2017-08-11 02:08:00+03	60600.00
A3AE7B	2017-07-31 04:53:00+03	10800.00
A3AEB8	2017-07-15 12:23:00+03	64300.00
A3AEC0	2017-08-11 06:22:00+03	46200.00
A3AEF5	2017-08-08 14:21:00+03	24400.00
A3AF07	2017-08-02 00:32:00+03	48800.00
A3AF1F	2017-07-30 20:20:00+03	77600.00
A3AF39	2017-06-28 21:22:00+03	24400.00
A3B035	2017-07-16 18:39:00+03	62600.00
A3B0DD	2017-08-02 11:26:00+03	48800.00
A3B104	2017-07-07 20:51:00+03	195800.00
A3B1DB	2017-07-04 09:02:00+03	52000.00
A3B1FB	2017-07-06 00:22:00+03	77200.00
A3B241	2017-08-06 13:49:00+03	135400.00
A3B288	2017-07-12 03:30:00+03	24400.00
A3B295	2017-07-18 09:08:00+03	27200.00
A3B2C0	2017-07-10 22:22:00+03	269000.00
A3B2DC	2017-07-20 06:22:00+03	542300.00
A3B398	2017-07-07 12:57:00+03	169300.00
A3B3A9	2017-08-04 20:08:00+03	21400.00
A3B3AB	2017-08-10 17:26:00+03	380200.00
A3B3D0	2017-07-02 22:13:00+03	44500.00
A3B3DD	2017-08-04 12:52:00+03	83000.00
A3B43B	2017-07-20 11:17:00+03	14000.00
A3B4AD	2017-07-07 20:55:00+03	144300.00
A3B4D0	2017-08-05 19:20:00+03	53400.00
A3B4EF	2017-08-15 08:02:00+03	124000.00
A3B506	2017-07-31 23:05:00+03	20100.00
A3B51C	2017-07-20 04:21:00+03	138000.00
A3B524	2017-08-03 13:52:00+03	12000.00
A3B59B	2017-08-14 15:58:00+03	50800.00
A3B5CF	2017-07-01 03:34:00+03	17800.00
A3B61E	2017-08-04 05:20:00+03	43400.00
A3B6ED	2017-07-19 10:36:00+03	62600.00
A3B7B2	2017-07-06 13:59:00+03	57800.00
A3B866	2017-07-26 03:22:00+03	95700.00
A3B86D	2017-07-25 03:38:00+03	45200.00
A3B88D	2017-08-12 03:36:00+03	45200.00
A3B8A9	2017-08-09 22:13:00+03	21800.00
A3B8EC	2017-07-20 14:54:00+03	39300.00
A3BACE	2017-07-24 12:23:00+03	26200.00
A3BAD8	2017-08-09 19:24:00+03	98300.00
A3BB2F	2017-07-21 22:19:00+03	21400.00
A3BB35	2017-07-03 21:49:00+03	246000.00
A3BB4D	2017-07-31 11:28:00+03	25800.00
A3BB88	2017-07-13 11:23:00+03	51600.00
A3BB91	2017-08-13 07:04:00+03	396500.00
A3BBE8	2017-07-08 07:53:00+03	51600.00
A3BC04	2017-08-02 02:44:00+03	101200.00
A3BC39	2017-07-13 04:04:00+03	32800.00
A3BC4C	2017-08-06 00:05:00+03	133200.00
A3BD23	2017-07-26 22:45:00+03	21000.00
A3BD8F	2017-08-09 14:41:00+03	254600.00
A3BD94	2017-07-27 12:35:00+03	102100.00
A3BDF1	2017-08-07 03:29:00+03	84500.00
A3BE0B	2017-08-06 17:47:00+03	40800.00
A3BEE0	2017-07-11 10:10:00+03	58600.00
A3BEE9	2017-07-19 04:26:00+03	26000.00
A3BF24	2017-08-02 19:08:00+03	25100.00
A3BFB3	2017-07-22 00:59:00+03	65900.00
A3C044	2017-07-14 20:17:00+03	55000.00
A3C05E	2017-07-07 17:14:00+03	57500.00
A3C0A3	2017-07-23 02:16:00+03	20000.00
A3C0AC	2017-08-06 09:22:00+03	7200.00
A3C0C6	2017-07-11 20:06:00+03	25800.00
A3C126	2017-07-10 02:23:00+03	37200.00
A3C16A	2017-07-27 21:32:00+03	81600.00
A3C1A7	2017-07-12 08:36:00+03	28000.00
A3C267	2017-08-09 07:11:00+03	48800.00
A3C2E8	2017-08-04 07:16:00+03	23200.00
A3C337	2017-07-09 21:58:00+03	16800.00
A3C35E	2017-08-12 13:21:00+03	369000.00
A3C38F	2017-07-13 11:51:00+03	26800.00
A3C436	2017-08-08 22:44:00+03	58600.00
A3C43A	2017-08-03 10:59:00+03	87800.00
A3C45A	2017-08-06 19:07:00+03	32800.00
A3C4A8	2017-07-28 21:25:00+03	191200.00
A3C4FD	2017-08-14 12:14:00+03	8200.00
A3C55C	2017-07-13 13:05:00+03	168000.00
A3C5DD	2017-06-30 07:17:00+03	25800.00
A3C63D	2017-07-28 21:55:00+03	91100.00
A3C65C	2017-07-01 14:41:00+03	258000.00
A3C713	2017-07-02 22:49:00+03	46000.00
A3C72F	2017-07-14 05:28:00+03	40000.00
A3C76C	2017-08-12 08:26:00+03	14700.00
A3C797	2017-07-23 14:54:00+03	103500.00
A3C7C4	2017-07-24 14:26:00+03	123000.00
A3C7CB	2017-08-05 17:16:00+03	40600.00
A3C80C	2017-07-27 23:42:00+03	72200.00
A3C8A4	2017-07-25 19:09:00+03	51800.00
A3C8A8	2017-07-06 10:01:00+03	28000.00
A3C8C9	2017-07-28 20:02:00+03	52800.00
A3C91C	2017-08-02 20:55:00+03	26000.00
A3C94E	2017-07-19 06:33:00+03	379600.00
A3C951	2017-07-26 23:47:00+03	43000.00
A3CA11	2017-07-11 01:37:00+03	28800.00
A3CA1E	2017-07-21 14:43:00+03	85000.00
A3CA41	2017-07-06 06:33:00+03	42800.00
A3CA42	2017-08-12 03:45:00+03	57400.00
A3CA51	2017-07-12 02:35:00+03	86300.00
A3CA5B	2017-07-21 15:48:00+03	135400.00
A3CA79	2017-07-19 20:34:00+03	33100.00
A3CAD1	2017-07-14 00:36:00+03	23200.00
A3CB84	2017-08-02 09:34:00+03	40400.00
A3CB9C	2017-08-07 19:05:00+03	131600.00
A3CBEE	2017-06-30 11:22:00+03	372500.00
A3CC4F	2017-07-20 21:58:00+03	21400.00
A3CC54	2017-07-12 01:31:00+03	168600.00
A3CC58	2017-07-11 17:33:00+03	32700.00
A3CC84	2017-07-05 07:01:00+03	52700.00
A3CCBF	2017-07-11 15:39:00+03	19600.00
A3CCEC	2017-08-06 00:02:00+03	75600.00
A3CD1B	2017-08-07 23:28:00+03	363200.00
A3CD20	2017-08-04 15:47:00+03	6300.00
A3CD46	2017-07-26 06:22:00+03	100600.00
A3CD9F	2017-08-04 20:44:00+03	46400.00
A3CE1F	2017-07-14 01:56:00+03	129800.00
A3CE55	2017-07-23 16:02:00+03	40600.00
A3CE59	2017-08-10 01:40:00+03	23200.00
A3CE9A	2017-08-06 09:40:00+03	414700.00
A3CEB6	2017-07-09 16:24:00+03	36200.00
A3CED1	2017-07-25 18:33:00+03	84500.00
A3CF26	2017-07-30 08:48:00+03	57600.00
A3CF6B	2017-08-09 06:13:00+03	70700.00
A3CFB7	2017-08-03 16:17:00+03	132000.00
A3CFE2	2017-08-08 13:44:00+03	32800.00
A3CFF2	2017-08-09 11:07:00+03	28000.00
A3D057	2017-07-15 06:37:00+03	81900.00
A3D09A	2017-06-29 23:06:00+03	138500.00
A3D0A2	2017-07-05 00:47:00+03	23400.00
A3D118	2017-08-04 14:24:00+03	32800.00
A3D174	2017-07-30 04:03:00+03	26000.00
A3D175	2017-08-10 16:50:00+03	85400.00
A3D17E	2017-07-22 15:07:00+03	150600.00
A3D1B4	2017-08-07 07:43:00+03	141600.00
A3D1F8	2017-07-06 08:15:00+03	83200.00
A3D203	2017-07-06 10:06:00+03	62800.00
A3D251	2017-07-21 17:54:00+03	106400.00
A3D25E	2017-08-02 00:50:00+03	38600.00
A3D267	2017-08-10 13:09:00+03	9200.00
A3D2F3	2017-07-09 10:28:00+03	81300.00
A3D388	2017-07-31 23:59:00+03	93700.00
A3D390	2017-07-10 00:56:00+03	137600.00
A3D3A7	2017-08-11 00:38:00+03	69900.00
A3D3C4	2017-08-01 01:44:00+03	73600.00
A3D40C	2017-07-13 16:01:00+03	133200.00
A3D422	2017-08-04 06:17:00+03	46300.00
A3D456	2017-08-08 09:56:00+03	75300.00
A3D488	2017-07-18 07:02:00+03	48800.00
A3D4B4	2017-07-10 18:14:00+03	86300.00
A3D4E7	2017-07-22 09:28:00+03	135200.00
A3D502	2017-07-15 08:33:00+03	169900.00
A3D52A	2017-08-03 02:00:00+03	25600.00
A3D5AB	2017-08-10 23:22:00+03	47600.00
A3D5F1	2017-07-30 10:07:00+03	14700.00
A3D628	2017-07-15 22:16:00+03	61400.00
A3D648	2017-07-07 06:16:00+03	106100.00
A3D683	2017-06-27 04:15:00+03	13000.00
A3D6BC	2017-08-03 10:49:00+03	132800.00
A3D733	2017-07-29 02:23:00+03	46000.00
A3D79E	2017-07-06 07:10:00+03	70400.00
A3D7A7	2017-08-06 21:37:00+03	28800.00
A3D7EF	2017-07-07 02:56:00+03	85600.00
A3D899	2017-08-07 03:45:00+03	30200.00
A3D8A5	2017-06-28 02:20:00+03	224400.00
A3D8E3	2017-07-15 11:18:00+03	21400.00
A3D905	2017-08-07 07:51:00+03	68400.00
A3D9A6	2017-07-12 20:53:00+03	54500.00
A3D9B1	2017-07-18 09:14:00+03	114300.00
A3D9CF	2017-07-30 04:47:00+03	65400.00
A3D9D2	2017-07-15 20:54:00+03	61200.00
A3DA17	2017-07-10 10:09:00+03	196700.00
A3DA23	2017-07-24 15:39:00+03	25200.00
A3DABE	2017-07-19 17:40:00+03	54600.00
A3DAC0	2017-07-31 12:09:00+03	110500.00
A3DB75	2017-07-28 10:00:00+03	55800.00
A3DB78	2017-07-22 17:02:00+03	257600.00
A3DBC3	2017-07-20 21:03:00+03	103900.00
A3DBFF	2017-07-24 00:34:00+03	16400.00
A3DC57	2017-08-05 20:44:00+03	151000.00
A3DC8B	2017-08-04 00:21:00+03	47000.00
A3DCC5	2017-07-28 01:02:00+03	31100.00
A3DD40	2017-06-29 19:52:00+03	71900.00
A3DD4F	2017-07-23 22:55:00+03	173500.00
A3DE03	2017-08-03 18:58:00+03	12400.00
A3DE1C	2017-07-20 13:48:00+03	98300.00
A3DE96	2017-08-01 11:09:00+03	93000.00
A3DEC2	2017-08-08 00:10:00+03	14800.00
A3DEC9	2017-08-11 14:25:00+03	20400.00
A3DEF6	2017-08-03 14:16:00+03	22100.00
A3DF29	2017-07-25 11:59:00+03	78200.00
A3DF71	2017-07-24 04:31:00+03	59600.00
A3DF79	2017-08-13 03:28:00+03	92600.00
A3DF8B	2017-08-06 15:17:00+03	106600.00
A3DF9C	2017-07-22 03:06:00+03	71200.00
A3DFE4	2017-07-29 08:41:00+03	44000.00
A3E080	2017-07-09 09:01:00+03	232400.00
A3E0C0	2017-07-31 00:58:00+03	132800.00
A3E10C	2017-07-09 12:26:00+03	24800.00
A3E130	2017-08-06 18:34:00+03	32700.00
A3E160	2017-07-05 19:39:00+03	59800.00
A3E174	2017-08-01 15:44:00+03	207200.00
A3E180	2017-07-23 06:44:00+03	8400.00
A3E1D1	2017-07-06 11:09:00+03	56600.00
A3E217	2017-07-25 11:49:00+03	56000.00
A3E21A	2017-07-19 18:16:00+03	26000.00
A3E239	2017-07-31 13:07:00+03	133200.00
A3E250	2017-06-28 19:44:00+03	80000.00
A3E260	2017-07-21 09:16:00+03	39100.00
A3E26E	2017-07-08 01:22:00+03	20000.00
A3E27A	2017-07-11 01:23:00+03	36000.00
A3E27E	2017-07-24 06:18:00+03	259000.00
A3E2D7	2017-08-13 11:32:00+03	57900.00
A3E35B	2017-07-31 13:46:00+03	23600.00
A3E3AB	2017-06-30 22:52:00+03	23500.00
A3E3C6	2017-07-11 18:57:00+03	18000.00
A3E3EC	2017-06-28 13:39:00+03	78600.00
A3E3FE	2017-08-06 10:58:00+03	52600.00
A3E40A	2017-07-02 19:51:00+03	80100.00
A3E491	2017-08-03 12:39:00+03	15000.00
A3E4FF	2017-07-24 19:41:00+03	398400.00
A3E52B	2017-08-12 10:37:00+03	135400.00
A3E52D	2017-07-06 20:20:00+03	30700.00
A3E533	2017-08-04 14:21:00+03	23200.00
A3E5CE	2017-07-15 11:53:00+03	74400.00
A3E64A	2017-07-25 22:09:00+03	135400.00
A3E683	2017-08-13 17:33:00+03	44300.00
A3E68A	2017-08-14 14:55:00+03	83000.00
A3E69C	2017-08-10 03:03:00+03	102300.00
A3E6E1	2017-07-24 05:40:00+03	12800.00
A3E73B	2017-08-05 16:51:00+03	117600.00
A3E756	2017-08-14 20:11:00+03	81200.00
A3E775	2017-08-05 08:10:00+03	156000.00
A3E784	2017-07-28 07:49:00+03	29200.00
A3E78A	2017-07-14 16:45:00+03	65400.00
A3E832	2017-06-28 05:27:00+03	231800.00
A3E862	2017-07-18 20:16:00+03	40800.00
A3E86E	2017-07-29 17:40:00+03	118600.00
A3E8F2	2017-08-10 11:44:00+03	46400.00
A3E92A	2017-07-25 08:06:00+03	12600.00
A3E95D	2017-08-03 04:17:00+03	28800.00
A3E96C	2017-07-03 19:07:00+03	207800.00
A3E982	2017-08-03 22:30:00+03	79800.00
A3E98F	2017-08-12 01:08:00+03	186900.00
A3E9E8	2017-07-24 05:11:00+03	26000.00
A3EA5D	2017-07-11 14:13:00+03	6000.00
A3EA7D	2017-07-03 17:45:00+03	45200.00
A3EAA7	2017-07-18 14:42:00+03	95600.00
A3EAE3	2017-07-18 14:26:00+03	141000.00
A3EB01	2017-08-02 19:06:00+03	23400.00
A3EB2B	2017-08-11 08:47:00+03	46400.00
A3EB31	2017-07-19 04:25:00+03	16400.00
A3EB6A	2017-08-07 14:25:00+03	101200.00
A3EBAD	2017-07-18 03:30:00+03	13400.00
A3EBBC	2017-08-10 12:36:00+03	30400.00
A3EC04	2017-07-09 04:54:00+03	290600.00
A3EC28	2017-07-08 14:55:00+03	22000.00
A3EC38	2017-08-15 10:01:00+03	134800.00
A3EC64	2017-08-09 19:19:00+03	73000.00
A3EC82	2017-07-26 19:49:00+03	92800.00
A3ECAA	2017-07-18 19:55:00+03	23200.00
A3ECDA	2017-07-03 15:09:00+03	68000.00
A3ECF3	2017-08-01 22:43:00+03	133200.00
A3ED03	2017-07-11 13:39:00+03	56000.00
A3EDCD	2017-07-20 09:02:00+03	45100.00
A3EDF2	2017-06-30 01:50:00+03	49200.00
A3EED1	2017-07-31 18:46:00+03	44800.00
A3EF09	2017-07-31 20:03:00+03	187600.00
A3EF68	2017-07-03 18:30:00+03	92800.00
A3EF75	2017-06-29 01:05:00+03	173100.00
A3F03E	2017-08-13 19:02:00+03	62000.00
A3F063	2017-07-13 07:23:00+03	43200.00
A3F077	2017-08-10 22:34:00+03	46800.00
A3F0C7	2017-08-09 05:24:00+03	23200.00
A3F0C8	2017-07-01 22:06:00+03	11600.00
A3F127	2017-07-17 16:33:00+03	85000.00
A3F15A	2017-07-02 12:38:00+03	21800.00
A3F1E9	2017-07-24 17:36:00+03	36400.00
A3F1EE	2017-07-28 15:50:00+03	28000.00
A3F217	2017-07-22 03:31:00+03	43200.00
A3F24C	2017-08-06 17:09:00+03	46700.00
A3F28D	2017-07-20 20:15:00+03	26000.00
A3F360	2017-08-04 13:18:00+03	31600.00
A3F371	2017-07-13 17:36:00+03	44500.00
A3F3B4	2017-07-27 14:07:00+03	79200.00
A3F3B8	2017-08-11 09:29:00+03	80100.00
A3F411	2017-07-05 01:00:00+03	133200.00
A3F46B	2017-07-12 12:23:00+03	100700.00
A3F46F	2017-07-16 21:01:00+03	155600.00
A3F4BE	2017-06-30 11:35:00+03	52800.00
A3F514	2017-07-08 14:22:00+03	6000.00
A3F555	2017-07-18 20:24:00+03	68800.00
A3F56A	2017-07-25 03:51:00+03	40100.00
A3F5F6	2017-07-11 05:26:00+03	22000.00
A3F60F	2017-07-20 16:08:00+03	38800.00
A3F678	2017-08-12 06:54:00+03	18600.00
A3F694	2017-07-04 03:55:00+03	57400.00
A3F6FE	2017-07-18 03:32:00+03	38800.00
A3F78E	2017-07-24 06:00:00+03	435400.00
A3F7CA	2017-07-23 01:39:00+03	82900.00
A3F80B	2017-08-13 00:54:00+03	28800.00
A3F80E	2017-07-09 20:42:00+03	82000.00
A3F817	2017-08-10 14:37:00+03	21400.00
A3F898	2017-08-05 10:44:00+03	68800.00
A3F9C7	2017-07-07 22:04:00+03	48500.00
A3F9F5	2017-07-12 23:46:00+03	68100.00
A3F9FE	2017-08-07 10:33:00+03	59200.00
A3FAEE	2017-08-13 21:52:00+03	117600.00
A3FB02	2017-07-19 06:34:00+03	11800.00
A3FB1C	2017-08-09 05:12:00+03	45100.00
A3FBA2	2017-08-12 23:12:00+03	23600.00
A3FBF6	2017-08-10 23:54:00+03	56000.00
A3FBF8	2017-07-09 01:50:00+03	29000.00
A3FC1B	2017-08-10 05:43:00+03	70600.00
A3FC30	2017-07-07 21:35:00+03	71600.00
A3FC39	2017-07-14 21:03:00+03	52800.00
A3FC54	2017-07-29 20:44:00+03	44800.00
A3FC84	2017-07-07 16:22:00+03	135400.00
A3FCC2	2017-08-13 19:33:00+03	75300.00
A3FCCF	2017-07-01 10:12:00+03	47100.00
A3FCD4	2017-07-22 03:47:00+03	73600.00
A3FCE8	2017-07-28 12:26:00+03	101200.00
A3FDA7	2017-07-31 13:47:00+03	23200.00
A3FDF3	2017-07-03 17:36:00+03	36200.00
A3FE18	2017-08-09 16:01:00+03	62000.00
A3FE41	2017-07-09 11:32:00+03	52000.00
A3FE48	2017-07-25 15:19:00+03	52400.00
A3FE8C	2017-08-01 08:42:00+03	33400.00
A3FE98	2017-07-27 02:57:00+03	62600.00
A3FF37	2017-07-01 23:24:00+03	24400.00
A3FF4F	2017-07-07 17:39:00+03	83200.00
A3FFAB	2017-07-17 19:48:00+03	61200.00
A3FFEA	2017-07-16 06:56:00+03	30200.00
A3FFEF	2017-08-04 08:35:00+03	51600.00
A40003	2017-07-19 12:50:00+03	99300.00
A40038	2017-07-27 06:48:00+03	26700.00
A40039	2017-07-28 06:20:00+03	11800.00
A400B1	2017-07-14 08:56:00+03	40800.00
A400BB	2017-07-14 09:48:00+03	25900.00
A4010C	2017-08-03 22:13:00+03	265700.00
A40155	2017-07-17 03:20:00+03	28800.00
A40171	2017-07-25 21:19:00+03	34400.00
A401B7	2017-08-11 01:18:00+03	134700.00
A401DE	2017-07-27 13:53:00+03	105000.00
A401EB	2017-07-30 21:17:00+03	73200.00
A40202	2017-08-04 00:52:00+03	26000.00
A4023E	2017-08-11 12:31:00+03	69500.00
A40285	2017-07-07 19:47:00+03	12600.00
A40318	2017-07-21 22:42:00+03	24800.00
A40342	2017-07-18 13:41:00+03	6800.00
A40360	2017-07-14 10:11:00+03	75600.00
A40375	2017-08-13 18:16:00+03	44800.00
A4039D	2017-08-07 21:34:00+03	69600.00
A403C3	2017-07-30 08:38:00+03	150600.00
A403F5	2017-07-12 22:13:00+03	66800.00
A4040A	2017-07-20 03:03:00+03	21800.00
A4041B	2017-08-03 02:47:00+03	54800.00
A40437	2017-08-02 18:16:00+03	199800.00
A40438	2017-07-11 04:06:00+03	62600.00
A404AB	2017-07-23 20:38:00+03	24800.00
A404BC	2017-07-30 07:40:00+03	123000.00
A40520	2017-07-09 00:14:00+03	6600.00
A40525	2017-07-22 14:50:00+03	31600.00
A4053E	2017-08-13 10:10:00+03	95100.00
A40593	2017-08-14 23:23:00+03	40100.00
A405D4	2017-07-31 20:21:00+03	21200.00
A40647	2017-07-28 10:27:00+03	87000.00
A40661	2017-07-01 03:41:00+03	26800.00
A40674	2017-07-10 04:56:00+03	68800.00
A40687	2017-07-17 03:44:00+03	26800.00
A406AE	2017-07-08 11:46:00+03	260900.00
A406DC	2017-08-11 07:53:00+03	46900.00
A4070A	2017-07-29 06:55:00+03	28000.00
A4078C	2017-08-01 13:38:00+03	28000.00
A407FA	2017-07-30 23:58:00+03	78100.00
A40845	2017-07-21 00:56:00+03	59200.00
A4086B	2017-07-30 11:02:00+03	35800.00
A40890	2017-07-27 02:12:00+03	65900.00
A4089C	2017-08-03 11:37:00+03	38400.00
A408B0	2017-08-02 01:14:00+03	266400.00
A408BB	2017-07-15 19:55:00+03	43000.00
A408D9	2017-07-10 03:39:00+03	123000.00
A408E0	2017-07-12 12:20:00+03	60400.00
A40940	2017-07-02 15:38:00+03	97900.00
A4094D	2017-08-08 07:58:00+03	45300.00
A4095A	2017-07-15 08:51:00+03	207000.00
A409E7	2017-07-07 15:58:00+03	51900.00
A40A40	2017-08-05 19:03:00+03	105000.00
A40A73	2017-07-18 17:18:00+03	44800.00
A40B0B	2017-08-02 01:08:00+03	70100.00
A40B0C	2017-07-16 20:42:00+03	39300.00
A40B26	2017-07-22 07:53:00+03	24800.00
A40B3E	2017-07-06 00:35:00+03	23600.00
A40B9F	2017-07-18 14:23:00+03	59800.00
A40BC8	2017-08-03 13:28:00+03	29400.00
A40C14	2017-08-10 16:28:00+03	42700.00
A40C26	2017-07-10 10:56:00+03	54000.00
A40C3C	2017-07-21 02:29:00+03	144400.00
A40C44	2017-07-20 09:35:00+03	53400.00
A40CAD	2017-07-23 12:36:00+03	127500.00
A40CB4	2017-07-18 02:51:00+03	24400.00
A40CE0	2017-07-31 04:52:00+03	26800.00
A40CFE	2017-07-29 16:27:00+03	23200.00
A40D61	2017-07-11 03:34:00+03	32800.00
A40D87	2017-07-03 05:53:00+03	62800.00
A40DAA	2017-07-26 22:05:00+03	138700.00
A40E2A	2017-07-03 01:58:00+03	57800.00
A40E2C	2017-08-11 22:55:00+03	88900.00
A40E35	2017-08-14 06:22:00+03	28000.00
A40F4C	2017-07-06 22:48:00+03	97700.00
A40F55	2017-07-23 02:15:00+03	99800.00
A40F65	2017-08-12 00:02:00+03	14800.00
A40F6F	2017-07-18 05:14:00+03	107200.00
A40F8E	2017-07-12 15:03:00+03	64700.00
A40FC0	2017-07-08 01:37:00+03	26500.00
A40FD5	2017-08-08 23:33:00+03	16400.00
A40FF1	2017-08-14 12:19:00+03	48800.00
A41015	2017-07-14 15:30:00+03	6700.00
A41045	2017-07-01 22:25:00+03	119000.00
A4109A	2017-07-15 12:11:00+03	11700.00
A4111A	2017-08-09 12:22:00+03	93300.00
A41145	2017-07-22 08:50:00+03	248300.00
A4118E	2017-07-04 13:03:00+03	25100.00
A411B6	2017-08-15 08:00:00+03	12000.00
A411D4	2017-07-12 19:24:00+03	30800.00
A411F8	2017-07-06 07:17:00+03	13200.00
A41204	2017-08-07 18:55:00+03	29600.00
A4123C	2017-07-25 00:26:00+03	3700.00
A41272	2017-08-05 13:32:00+03	101500.00
A4132E	2017-07-08 00:05:00+03	13400.00
A41365	2017-07-30 02:42:00+03	85700.00
A4136B	2017-08-13 21:41:00+03	81300.00
A413EF	2017-07-18 21:36:00+03	46400.00
A413F1	2017-07-02 21:25:00+03	21400.00
A413F8	2017-07-03 21:08:00+03	70800.00
A4141B	2017-07-31 17:51:00+03	89200.00
A4143D	2017-07-16 21:51:00+03	80700.00
A4145D	2017-07-27 15:48:00+03	58000.00
A4148F	2017-07-21 09:03:00+03	55300.00
A414D8	2017-08-12 04:32:00+03	52900.00
A414F8	2017-08-08 08:39:00+03	87700.00
A41545	2017-07-11 03:48:00+03	212900.00
A4163A	2017-07-07 20:25:00+03	87200.00
A41673	2017-07-23 00:47:00+03	95200.00
A4167F	2017-07-05 18:05:00+03	100000.00
A41687	2017-08-12 05:08:00+03	26000.00
A41716	2017-08-05 05:04:00+03	131800.00
A417E7	2017-07-12 06:08:00+03	187600.00
A417F7	2017-08-03 12:49:00+03	38800.00
A41870	2017-08-11 18:58:00+03	72400.00
A418A5	2017-08-14 20:21:00+03	66600.00
A418B3	2017-07-09 12:56:00+03	34100.00
A418C1	2017-08-05 01:48:00+03	187800.00
A41958	2017-08-09 03:08:00+03	62300.00
A419B7	2017-07-06 14:47:00+03	51200.00
A419C9	2017-07-15 04:01:00+03	202100.00
A41AA0	2017-07-27 09:59:00+03	28800.00
A41AAF	2017-07-19 11:18:00+03	321900.00
A41AF4	2017-06-28 16:26:00+03	149200.00
A41AFB	2017-07-19 01:50:00+03	100600.00
A41B2F	2017-07-03 02:36:00+03	56100.00
A41B9E	2017-07-09 04:14:00+03	147700.00
A41BEC	2017-07-14 19:40:00+03	26800.00
A41BFD	2017-07-29 21:53:00+03	56900.00
A41C50	2017-07-11 14:55:00+03	123000.00
A41C54	2017-08-10 06:06:00+03	47100.00
A41C57	2017-07-13 15:58:00+03	27200.00
A41C7A	2017-08-13 02:24:00+03	112000.00
A41D68	2017-07-18 18:59:00+03	79600.00
A41D7E	2017-08-07 20:44:00+03	14400.00
A41D96	2017-08-15 11:52:00+03	96100.00
A41E1C	2017-07-11 20:24:00+03	44000.00
A41E23	2017-07-26 12:34:00+03	28800.00
A41EBE	2017-07-15 19:27:00+03	112000.00
A41EC5	2017-07-08 11:48:00+03	82000.00
A41F28	2017-08-10 17:49:00+03	31600.00
A41F2C	2017-07-20 02:22:00+03	28000.00
A41F72	2017-08-11 08:07:00+03	111600.00
A41FA7	2017-07-26 07:13:00+03	135200.00
A41FB5	2017-07-26 06:25:00+03	83000.00
A41FDA	2017-08-12 09:59:00+03	18600.00
A4204A	2017-07-10 16:08:00+03	24400.00
A42056	2017-07-31 09:59:00+03	266400.00
A42079	2017-06-30 22:11:00+03	172200.00
A420AA	2017-08-01 07:13:00+03	40800.00
A420C0	2017-07-06 04:30:00+03	35400.00
A420D4	2017-08-10 20:26:00+03	67600.00
A420E6	2017-07-27 23:40:00+03	50400.00
A42102	2017-07-11 07:31:00+03	17600.00
A42150	2017-07-18 14:09:00+03	22600.00
A42159	2017-08-11 20:50:00+03	59800.00
A42178	2017-07-16 17:09:00+03	6000.00
A421C2	2017-07-26 13:56:00+03	96300.00
A421DF	2017-08-13 07:43:00+03	271100.00
A42465	2017-07-08 01:30:00+03	217600.00
A42471	2017-07-23 20:46:00+03	56000.00
A4249D	2017-07-20 21:03:00+03	52000.00
A424EF	2017-07-01 16:04:00+03	29600.00
A42502	2017-07-04 08:05:00+03	53200.00
A42545	2017-08-05 16:38:00+03	112000.00
A425B5	2017-07-26 20:58:00+03	56000.00
A425BE	2017-08-11 01:52:00+03	386300.00
A425E7	2017-07-19 01:46:00+03	38500.00
A42611	2017-07-04 00:48:00+03	312000.00
A42628	2017-07-14 23:30:00+03	29300.00
A42641	2017-08-10 23:07:00+03	17200.00
A42666	2017-08-14 07:00:00+03	135200.00
A4267E	2017-08-02 14:18:00+03	92700.00
A426EA	2017-07-19 07:26:00+03	13800.00
A427D3	2017-07-31 06:03:00+03	68100.00
A42878	2017-07-21 21:38:00+03	56000.00
A428B5	2017-08-12 03:49:00+03	182300.00
A428D1	2017-07-10 20:44:00+03	54500.00
A428DC	2017-07-22 10:11:00+03	75300.00
A42910	2017-07-14 03:09:00+03	26000.00
A4294C	2017-07-06 22:11:00+03	545900.00
A429C0	2017-08-01 07:28:00+03	23600.00
A42A74	2017-08-02 05:25:00+03	9800.00
A42AB7	2017-07-04 11:38:00+03	12400.00
A42B13	2017-07-11 22:27:00+03	119800.00
A42BD0	2017-07-13 20:26:00+03	23100.00
A42BF4	2017-07-25 08:29:00+03	167400.00
A42BF8	2017-07-03 16:20:00+03	92000.00
A42C20	2017-07-23 14:21:00+03	6000.00
A42C50	2017-07-07 08:48:00+03	52000.00
A42D1F	2017-07-10 23:12:00+03	64700.00
A42D36	2017-08-10 01:26:00+03	22000.00
A42D5A	2017-08-11 07:32:00+03	168000.00
A42D68	2017-07-19 22:33:00+03	132800.00
A42E03	2017-07-26 05:14:00+03	80500.00
A42E37	2017-07-24 21:44:00+03	189200.00
A42E55	2017-08-06 12:25:00+03	75300.00
A42E80	2017-07-03 23:49:00+03	56600.00
A42E8B	2017-07-24 11:34:00+03	57800.00
A42E93	2017-08-10 19:56:00+03	83900.00
A42ECD	2017-07-06 01:46:00+03	271100.00
A42ED2	2017-07-30 13:00:00+03	92400.00
A42F0D	2017-08-08 15:50:00+03	92800.00
A42F14	2017-07-20 21:56:00+03	108500.00
A42F1F	2017-07-27 15:52:00+03	246000.00
A42FE1	2017-08-14 06:41:00+03	49100.00
A43037	2017-07-03 22:37:00+03	26700.00
A4305C	2017-08-06 19:32:00+03	12000.00
A43084	2017-08-08 07:03:00+03	17200.00
A430F9	2017-08-01 20:37:00+03	64800.00
A4310F	2017-08-02 03:43:00+03	50600.00
A43119	2017-07-12 06:29:00+03	93900.00
A43154	2017-07-10 12:37:00+03	29600.00
A4319F	2017-07-02 10:00:00+03	67700.00
A431D2	2017-08-03 06:14:00+03	73300.00
A431D6	2017-07-06 20:46:00+03	89700.00
A43219	2017-08-04 22:18:00+03	27900.00
A43232	2017-07-21 15:09:00+03	191400.00
A43255	2017-06-30 15:00:00+03	246000.00
A43257	2017-08-09 11:52:00+03	136800.00
A432AD	2017-07-11 16:52:00+03	96800.00
A432BD	2017-08-05 01:01:00+03	275900.00
A432ED	2017-07-24 08:08:00+03	32200.00
A43309	2017-07-24 01:36:00+03	125200.00
A43336	2017-07-30 19:19:00+03	137400.00
A43366	2017-07-29 05:43:00+03	170800.00
A433FE	2017-08-03 02:03:00+03	6700.00
A4340F	2017-08-05 10:31:00+03	116400.00
A434D5	2017-07-26 00:25:00+03	44000.00
A43513	2017-08-07 00:18:00+03	136400.00
A435B6	2017-07-19 20:41:00+03	38600.00
A43607	2017-07-24 16:54:00+03	60400.00
A4361E	2017-08-10 09:10:00+03	36800.00
A436C7	2017-07-30 17:31:00+03	114700.00
A436FD	2017-07-07 22:02:00+03	44500.00
A43713	2017-07-17 11:39:00+03	28000.00
A43728	2017-07-14 15:17:00+03	23600.00
A4376F	2017-07-06 10:50:00+03	121300.00
A43772	2017-08-11 15:54:00+03	27200.00
A4377F	2017-07-06 02:30:00+03	68400.00
A437EF	2017-07-17 14:47:00+03	140900.00
A4388D	2017-07-14 16:55:00+03	134600.00
A43901	2017-07-12 03:12:00+03	55600.00
A4397A	2017-07-09 20:33:00+03	85000.00
A43A5A	2017-07-01 06:35:00+03	15000.00
A43B73	2017-07-22 07:13:00+03	7200.00
A43B97	2017-08-01 17:57:00+03	58400.00
A43BAE	2017-07-20 19:31:00+03	32400.00
A43C1B	2017-08-06 09:17:00+03	22000.00
A43C37	2017-08-07 17:17:00+03	89700.00
A43C71	2017-07-08 21:39:00+03	214900.00
A43CDE	2017-08-12 18:10:00+03	18600.00
A43D82	2017-07-01 02:41:00+03	135800.00
A43DA7	2017-08-03 09:33:00+03	46300.00
A43DFB	2017-07-25 06:29:00+03	45400.00
A43E07	2017-07-04 14:14:00+03	13400.00
A43E49	2017-06-30 11:56:00+03	20000.00
A43E4F	2017-08-15 09:40:00+03	194200.00
A43EF5	2017-07-02 13:45:00+03	93100.00
A43F0A	2017-07-09 08:06:00+03	67700.00
A43F29	2017-08-11 06:25:00+03	46000.00
A43F69	2017-08-13 08:57:00+03	23400.00
A44031	2017-07-23 23:28:00+03	92900.00
A4408F	2017-08-12 18:42:00+03	43500.00
A440B8	2017-07-02 22:15:00+03	277800.00
A440C8	2017-07-23 17:34:00+03	29800.00
A440FA	2017-07-18 21:54:00+03	196100.00
A4410F	2017-08-05 03:49:00+03	68200.00
A4411C	2017-07-08 20:25:00+03	57500.00
A44134	2017-08-13 19:59:00+03	53600.00
A441B4	2017-06-30 11:14:00+03	43100.00
A441F1	2017-07-27 15:21:00+03	113700.00
A4425D	2017-08-11 19:57:00+03	26000.00
A44269	2017-07-09 22:49:00+03	28000.00
A44348	2017-08-12 17:02:00+03	81300.00
A443B9	2017-07-26 08:21:00+03	44800.00
A443EF	2017-08-12 16:32:00+03	23400.00
A443F0	2017-07-29 00:20:00+03	30200.00
A44459	2017-08-04 19:56:00+03	170000.00
A44483	2017-07-05 18:16:00+03	43600.00
A444D8	2017-07-09 00:35:00+03	100700.00
A44527	2017-07-03 18:18:00+03	58800.00
A445A5	2017-08-13 11:47:00+03	111600.00
A445B5	2017-07-31 03:23:00+03	111600.00
A445CF	2017-07-12 07:31:00+03	80000.00
A445F4	2017-07-22 07:29:00+03	444300.00
A44633	2017-07-09 12:46:00+03	36800.00
A44674	2017-07-22 05:49:00+03	62800.00
A44678	2017-07-25 08:37:00+03	89700.00
A446A2	2017-07-27 02:29:00+03	69000.00
A446D4	2017-08-13 09:06:00+03	46400.00
A44748	2017-08-14 15:05:00+03	21400.00
A44760	2017-08-06 06:27:00+03	37600.00
A4478F	2017-07-28 16:25:00+03	15700.00
A447F9	2017-07-05 16:59:00+03	283100.00
A4485B	2017-08-05 02:11:00+03	154400.00
A44883	2017-07-03 06:49:00+03	24200.00
A44977	2017-08-02 02:01:00+03	25600.00
A449E6	2017-08-02 22:50:00+03	75800.00
A449EE	2017-08-13 07:58:00+03	24500.00
A449EF	2017-07-22 15:36:00+03	112000.00
A44A0A	2017-07-23 06:39:00+03	336400.00
A44B09	2017-08-01 10:49:00+03	50600.00
A44BAC	2017-08-04 21:04:00+03	28000.00
A44C29	2017-07-07 02:30:00+03	28000.00
A44C6C	2017-07-19 05:22:00+03	24400.00
A44CAB	2017-07-02 16:56:00+03	166100.00
A44CFA	2017-07-03 23:00:00+03	75300.00
A44D17	2017-07-09 11:34:00+03	155600.00
A44D3D	2017-07-07 11:25:00+03	46200.00
A44DBF	2017-08-06 16:03:00+03	52100.00
A44DC3	2017-07-05 05:39:00+03	119600.00
A44E89	2017-08-02 06:21:00+03	101200.00
A44EB2	2017-08-05 00:40:00+03	53300.00
A4500C	2017-07-10 18:01:00+03	88800.00
A45014	2017-07-18 09:22:00+03	86600.00
A4502F	2017-07-28 03:22:00+03	27800.00
A45074	2017-07-02 11:20:00+03	41900.00
A45089	2017-07-22 16:31:00+03	130100.00
A45173	2017-07-18 00:30:00+03	117600.00
A45190	2017-08-09 19:59:00+03	88600.00
A451C4	2017-08-07 13:46:00+03	40400.00
A45226	2017-07-01 00:18:00+03	51600.00
A452AC	2017-07-24 10:24:00+03	67600.00
A452CF	2017-07-11 10:38:00+03	59000.00
A452E2	2017-07-17 02:04:00+03	123000.00
A45367	2017-07-27 11:52:00+03	47400.00
A4538C	2017-07-23 17:36:00+03	86000.00
A45398	2017-06-30 12:34:00+03	96400.00
A453A2	2017-07-01 21:42:00+03	123700.00
A45401	2017-07-26 00:26:00+03	14400.00
A45422	2017-07-25 16:30:00+03	687300.00
A45442	2017-07-22 16:34:00+03	45200.00
A454D7	2017-07-12 23:50:00+03	84100.00
A4552D	2017-08-12 03:11:00+03	56600.00
A4553A	2017-07-11 00:46:00+03	229300.00
A45558	2017-07-29 23:07:00+03	193600.00
A45562	2017-07-30 18:34:00+03	177500.00
A455AB	2017-07-17 12:20:00+03	35200.00
A4560C	2017-08-10 01:31:00+03	41600.00
A4560E	2017-07-24 20:37:00+03	62700.00
A4561D	2017-07-31 13:25:00+03	51900.00
A4563F	2017-07-29 04:48:00+03	72000.00
A45650	2017-08-07 19:43:00+03	48800.00
A45669	2017-08-02 08:12:00+03	65900.00
A45679	2017-07-11 16:38:00+03	68100.00
A456A2	2017-07-20 22:31:00+03	12400.00
A456CF	2017-07-16 23:16:00+03	64700.00
A456D2	2017-08-13 02:22:00+03	19600.00
A45716	2017-07-03 15:29:00+03	12600.00
A45755	2017-07-02 00:12:00+03	260300.00
A45797	2017-07-02 00:53:00+03	29600.00
A457D3	2017-08-09 23:22:00+03	24400.00
A457DC	2017-07-22 09:07:00+03	130900.00
A457DE	2017-08-04 17:08:00+03	14400.00
A457EE	2017-07-31 04:16:00+03	21000.00
A45800	2017-08-14 16:14:00+03	48900.00
A45802	2017-07-07 22:06:00+03	6700.00
A45843	2017-07-18 17:24:00+03	75700.00
A45845	2017-07-31 03:47:00+03	173500.00
A4584A	2017-07-28 23:57:00+03	136100.00
A45937	2017-07-11 04:35:00+03	6300.00
A45954	2017-07-05 17:49:00+03	85300.00
A459B2	2017-07-03 04:51:00+03	93000.00
A45A5E	2017-07-12 20:08:00+03	96800.00
A45A7D	2017-07-31 10:19:00+03	23200.00
A45AD2	2017-07-11 19:23:00+03	58200.00
A45AD3	2017-07-28 07:46:00+03	10600.00
A45AE4	2017-08-11 23:12:00+03	90400.00
A45B1E	2017-07-20 13:42:00+03	20400.00
A45B23	2017-08-08 19:01:00+03	23200.00
A45B53	2017-08-10 18:03:00+03	172600.00
A45BF4	2017-07-21 07:03:00+03	55000.00
A45C3E	2017-08-11 14:47:00+03	46300.00
A45C5C	2017-07-19 07:23:00+03	56600.00
A45C94	2017-07-31 15:08:00+03	75200.00
A45CB2	2017-08-06 11:38:00+03	147700.00
A45D86	2017-08-13 13:18:00+03	201800.00
A45DCC	2017-07-30 17:25:00+03	56000.00
A45E5B	2017-07-16 13:40:00+03	28000.00
A45E87	2017-07-14 04:02:00+03	357600.00
A45EBA	2017-08-14 22:51:00+03	73500.00
A45EBB	2017-07-15 16:15:00+03	29400.00
A45F33	2017-07-10 02:00:00+03	96800.00
A45F3A	2017-08-13 12:26:00+03	54400.00
A45F85	2017-06-28 20:55:00+03	159100.00
A45F8D	2017-08-10 05:37:00+03	41900.00
A45FA1	2017-07-07 06:02:00+03	83000.00
A46019	2017-08-14 09:54:00+03	50100.00
A4601D	2017-07-10 18:41:00+03	131600.00
A46064	2017-07-10 11:30:00+03	265700.00
A46066	2017-08-07 03:06:00+03	157700.00
A460D7	2017-07-30 17:02:00+03	13300.00
A4612A	2017-07-23 06:50:00+03	87300.00
A46139	2017-07-19 20:38:00+03	58800.00
A46154	2017-07-24 01:48:00+03	44000.00
A46171	2017-08-01 04:43:00+03	44600.00
A461B1	2017-08-07 06:39:00+03	58900.00
A461C8	2017-07-30 12:38:00+03	63800.00
A462D0	2017-07-25 06:12:00+03	49600.00
A462EA	2017-07-22 02:53:00+03	69000.00
A46309	2017-07-17 07:11:00+03	16000.00
A46322	2017-07-10 17:55:00+03	56000.00
A4638B	2017-07-19 03:33:00+03	56000.00
A46397	2017-08-06 05:00:00+03	286700.00
A463B8	2017-07-08 03:36:00+03	92100.00
A463FF	2017-08-03 01:44:00+03	56900.00
A4642D	2017-07-05 17:54:00+03	35200.00
A46441	2017-07-30 10:17:00+03	25600.00
A464B4	2017-08-02 00:49:00+03	77000.00
A4651B	2017-07-21 16:13:00+03	58200.00
A4651F	2017-07-13 08:52:00+03	121200.00
A4653D	2017-07-10 04:00:00+03	56000.00
A46573	2017-07-27 20:15:00+03	47700.00
A46593	2017-07-06 05:32:00+03	65900.00
A465DF	2017-07-23 14:26:00+03	123000.00
A465ED	2017-07-18 17:01:00+03	19800.00
A465F9	2017-08-12 05:55:00+03	67200.00
A46725	2017-08-14 22:41:00+03	55800.00
A46750	2017-08-02 07:14:00+03	67200.00
A46751	2017-08-09 07:23:00+03	6000.00
A4676E	2017-08-08 08:08:00+03	22000.00
A4681E	2017-08-13 11:30:00+03	156600.00
A46866	2017-07-22 16:02:00+03	15400.00
A46872	2017-07-16 06:03:00+03	210000.00
A468D7	2017-07-19 14:18:00+03	92400.00
A46921	2017-08-02 22:40:00+03	22100.00
A46949	2017-08-10 21:01:00+03	38800.00
A46966	2017-08-05 21:32:00+03	101200.00
A46A5E	2017-07-09 08:42:00+03	25600.00
A46AB3	2017-07-20 09:29:00+03	34000.00
A46AF2	2017-07-25 07:51:00+03	156500.00
A46AF5	2017-07-28 08:52:00+03	48800.00
A46B46	2017-07-13 16:15:00+03	58200.00
A46B4F	2017-08-12 07:40:00+03	65900.00
A46BE7	2017-08-06 20:51:00+03	50800.00
A46BED	2017-08-13 18:54:00+03	73600.00
A46BF9	2017-07-12 04:35:00+03	13600.00
A46C47	2017-08-15 13:30:00+03	55800.00
A46C9E	2017-07-27 16:16:00+03	12000.00
A46CB9	2017-07-20 04:32:00+03	110500.00
A46D0A	2017-08-12 17:29:00+03	92800.00
A46D3C	2017-07-18 16:53:00+03	47400.00
A46D3E	2017-07-26 09:29:00+03	21800.00
A46D5A	2017-07-17 13:50:00+03	103500.00
A46D84	2017-07-27 02:06:00+03	143800.00
A46E3B	2017-07-11 07:51:00+03	177200.00
A46E6A	2017-07-05 21:35:00+03	77500.00
A46E9B	2017-08-02 12:06:00+03	26000.00
A46EC7	2017-08-10 01:26:00+03	92200.00
A46EDE	2017-08-09 00:25:00+03	135400.00
A46EE9	2017-08-04 04:01:00+03	130400.00
A46F00	2017-08-15 03:36:00+03	29400.00
A46F08	2017-07-05 20:46:00+03	271200.00
A46F68	2017-07-14 11:29:00+03	35600.00
A46F6B	2017-07-07 22:23:00+03	149300.00
A46F83	2017-07-11 00:41:00+03	63200.00
A46FAA	2017-07-22 04:35:00+03	8200.00
A470ED	2017-07-06 14:22:00+03	160200.00
A47100	2017-07-21 03:25:00+03	270700.00
A47128	2017-07-26 14:11:00+03	77900.00
A471CD	2017-08-13 03:30:00+03	6800.00
A471DB	2017-07-17 22:06:00+03	45100.00
A4724C	2017-07-22 15:31:00+03	28000.00
A4731D	2017-07-01 05:45:00+03	40300.00
A47374	2017-07-24 22:34:00+03	30200.00
A47407	2017-07-21 22:03:00+03	56600.00
A47462	2017-07-24 14:29:00+03	46400.00
A47494	2017-08-01 04:13:00+03	54000.00
A4749D	2017-07-19 18:08:00+03	21400.00
A474CD	2017-07-10 21:36:00+03	62600.00
A47520	2017-07-25 02:46:00+03	154900.00
A47530	2017-07-02 00:10:00+03	47400.00
A47531	2017-08-09 23:32:00+03	62600.00
A4754C	2017-07-20 12:14:00+03	52000.00
A4759A	2017-07-12 10:24:00+03	25000.00
A475A2	2017-08-03 16:40:00+03	17800.00
A475B0	2017-07-22 02:09:00+03	406700.00
A475C1	2017-08-02 23:02:00+03	24400.00
A475DC	2017-08-15 06:43:00+03	246000.00
A475E4	2017-07-24 23:44:00+03	443000.00
A4763D	2017-08-10 17:57:00+03	27500.00
A476A1	2017-07-13 10:43:00+03	288600.00
A476BA	2017-07-30 14:41:00+03	8200.00
A476EF	2017-08-04 20:49:00+03	111600.00
A47710	2017-07-08 17:32:00+03	81300.00
A47716	2017-07-16 23:09:00+03	13400.00
A47721	2017-08-05 15:13:00+03	119500.00
A477AC	2017-08-09 22:34:00+03	20200.00
A477D5	2017-07-11 18:12:00+03	132800.00
A477FC	2017-07-31 08:16:00+03	161400.00
A47864	2017-07-18 00:20:00+03	38400.00
A478DA	2017-08-02 16:08:00+03	26000.00
A478E1	2017-07-08 11:24:00+03	109700.00
A4792D	2017-08-03 15:55:00+03	103800.00
A4793F	2017-07-31 19:26:00+03	67200.00
A4794F	2017-07-14 01:28:00+03	24600.00
A479A3	2017-07-15 20:45:00+03	99300.00
A47A32	2017-07-28 02:49:00+03	10800.00
A47A5B	2017-07-19 05:25:00+03	64700.00
A47A71	2017-08-13 19:37:00+03	25200.00
A47A80	2017-07-10 01:35:00+03	36200.00
A47A95	2017-07-25 07:26:00+03	24300.00
A47ABF	2017-08-06 10:22:00+03	68800.00
A47AE3	2017-08-13 13:51:00+03	24400.00
A47AF7	2017-07-31 23:52:00+03	16800.00
A47BC8	2017-07-30 15:55:00+03	78300.00
A47C15	2017-07-07 12:39:00+03	54500.00
A47C45	2017-07-19 15:58:00+03	66800.00
A47C7F	2017-07-12 09:13:00+03	52000.00
A47CBC	2017-08-08 17:03:00+03	27400.00
A47CBF	2017-07-05 18:35:00+03	21800.00
A47D18	2017-07-18 03:27:00+03	21800.00
A47D2F	2017-07-07 09:13:00+03	203000.00
A47DDB	2017-07-12 23:02:00+03	118100.00
A47E21	2017-07-03 15:20:00+03	109600.00
A47E40	2017-08-14 03:52:00+03	55600.00
A47E99	2017-08-08 04:47:00+03	14000.00
A47EBE	2017-08-11 06:58:00+03	51600.00
A47ECA	2017-08-13 05:02:00+03	258400.00
A47F4C	2017-08-01 05:42:00+03	241400.00
A47F9A	2017-07-29 05:39:00+03	177200.00
A47FE1	2017-07-22 18:08:00+03	75300.00
A47FE5	2017-07-16 19:04:00+03	25600.00
A47FF0	2017-08-01 22:27:00+03	7400.00
A48006	2017-06-27 18:59:00+03	21800.00
A48043	2017-07-23 13:47:00+03	11600.00
A48071	2017-06-30 18:18:00+03	24500.00
A48083	2017-07-10 14:23:00+03	94200.00
A48131	2017-07-09 14:36:00+03	24800.00
A4813C	2017-07-05 01:38:00+03	22000.00
A4815C	2017-08-13 14:54:00+03	44700.00
A481E4	2017-07-21 15:41:00+03	81700.00
A48200	2017-07-25 16:34:00+03	168000.00
A4823F	2017-07-17 07:26:00+03	112400.00
A482EF	2017-07-25 22:40:00+03	67600.00
A4834E	2017-07-20 19:07:00+03	32800.00
A4835B	2017-07-17 01:32:00+03	29600.00
A4835E	2017-07-02 10:51:00+03	32800.00
A48379	2017-07-15 02:29:00+03	30200.00
A48415	2017-07-03 11:16:00+03	177300.00
A4841B	2017-08-10 01:55:00+03	207700.00
A48426	2017-07-12 17:29:00+03	50600.00
A48492	2017-08-11 00:08:00+03	408600.00
A48499	2017-08-11 20:45:00+03	73300.00
A484C3	2017-07-23 16:55:00+03	125200.00
A4851E	2017-07-31 04:34:00+03	26700.00
A4852A	2017-07-12 04:36:00+03	109300.00
A48572	2017-07-16 02:15:00+03	142800.00
A485B9	2017-08-15 00:17:00+03	51300.00
A485E2	2017-07-30 09:09:00+03	28600.00
A4862E	2017-08-15 03:02:00+03	57500.00
A48727	2017-07-27 07:26:00+03	53600.00
A48747	2017-07-04 01:15:00+03	76600.00
A48764	2017-08-10 04:17:00+03	56100.00
A487AE	2017-08-02 04:22:00+03	35400.00
A487BC	2017-07-21 08:56:00+03	55800.00
A48815	2017-07-20 19:09:00+03	149200.00
A48837	2017-08-10 17:24:00+03	14000.00
A48843	2017-08-12 20:36:00+03	6700.00
A48878	2017-07-18 13:23:00+03	54300.00
A488C0	2017-08-11 13:11:00+03	295000.00
A488C1	2017-07-31 08:35:00+03	8000.00
A48913	2017-07-08 18:55:00+03	56000.00
A4897F	2017-07-21 23:26:00+03	22600.00
A48987	2017-08-01 08:11:00+03	128100.00
A48A15	2017-08-07 11:34:00+03	91500.00
A48A2D	2017-07-16 23:21:00+03	111600.00
A48A82	2017-07-11 23:02:00+03	66000.00
A48B05	2017-07-03 15:07:00+03	14400.00
A48B3B	2017-07-07 01:15:00+03	57500.00
A48BD9	2017-08-02 20:43:00+03	29600.00
A48C88	2017-07-28 01:51:00+03	63500.00
A48C92	2017-07-31 09:36:00+03	112000.00
A48CB2	2017-07-13 21:11:00+03	132800.00
A48CCD	2017-07-10 21:52:00+03	124300.00
A48CD3	2017-07-08 18:35:00+03	18300.00
A48CFC	2017-07-28 10:29:00+03	6200.00
A48D09	2017-07-29 18:12:00+03	31400.00
A48D0D	2017-07-11 09:01:00+03	99300.00
A48DAA	2017-07-19 08:56:00+03	105600.00
A48DAE	2017-08-02 04:45:00+03	29000.00
A48DE5	2017-07-31 09:16:00+03	26000.00
A48E3E	2017-07-12 11:28:00+03	26000.00
A48E68	2017-07-18 07:58:00+03	53500.00
A48E9F	2017-08-12 08:36:00+03	13400.00
A48F2E	2017-07-07 02:11:00+03	64700.00
A48F32	2017-07-05 11:02:00+03	34000.00
A48F76	2017-08-06 16:03:00+03	229800.00
A48FAD	2017-07-23 00:17:00+03	14400.00
A4905A	2017-08-02 00:21:00+03	185300.00
A490D1	2017-07-27 07:36:00+03	25600.00
A4910B	2017-07-07 16:30:00+03	156300.00
A49122	2017-07-21 00:40:00+03	57300.00
A49129	2017-08-03 03:21:00+03	70500.00
A4919C	2017-07-26 00:36:00+03	121800.00
A491C9	2017-08-08 09:23:00+03	20400.00
A49216	2017-08-03 01:08:00+03	6700.00
A4922E	2017-08-09 21:58:00+03	123000.00
A4926A	2017-08-02 05:27:00+03	21800.00
A492B3	2017-07-03 22:56:00+03	52400.00
A49300	2017-07-29 08:08:00+03	128800.00
A49336	2017-07-27 13:58:00+03	37200.00
A49342	2017-08-14 06:30:00+03	111100.00
A49345	2017-07-17 05:17:00+03	280500.00
A4941B	2017-08-04 22:16:00+03	38600.00
A494F4	2017-08-06 14:09:00+03	46400.00
A49528	2017-07-19 00:37:00+03	99500.00
A49588	2017-07-23 11:42:00+03	166000.00
A4961C	2017-07-31 17:05:00+03	65900.00
A4967E	2017-08-05 13:45:00+03	44600.00
A496F6	2017-06-30 23:09:00+03	8000.00
A49712	2017-08-06 22:47:00+03	91800.00
A4971B	2017-08-08 19:00:00+03	43900.00
A4973B	2017-08-05 07:42:00+03	23400.00
A4975C	2017-07-08 11:47:00+03	56600.00
A497EA	2017-06-29 21:59:00+03	83000.00
A49809	2017-08-05 08:16:00+03	369000.00
A4984A	2017-08-03 04:37:00+03	87700.00
A498AA	2017-07-18 21:12:00+03	54400.00
A49914	2017-07-29 21:10:00+03	340600.00
A4991D	2017-07-05 09:51:00+03	27800.00
A4995A	2017-07-05 02:41:00+03	56600.00
A49969	2017-07-12 15:23:00+03	46400.00
A499A7	2017-07-24 14:18:00+03	37400.00
A499ED	2017-08-13 18:30:00+03	14000.00
A49A1F	2017-08-11 19:07:00+03	23600.00
A49A24	2017-07-11 10:12:00+03	32400.00
A49A55	2017-07-02 16:10:00+03	6700.00
A49AF6	2017-07-23 18:38:00+03	40200.00
A49B00	2017-07-22 11:32:00+03	28800.00
A49B3B	2017-07-29 06:40:00+03	29800.00
A49B68	2017-07-29 00:54:00+03	81300.00
A49B7C	2017-07-28 20:20:00+03	21000.00
A49B99	2017-08-12 21:32:00+03	147700.00
A49BA6	2017-08-03 15:17:00+03	46800.00
A49BCA	2017-08-10 18:26:00+03	137200.00
A49BE4	2017-07-18 16:16:00+03	50700.00
A49BEE	2017-07-05 17:39:00+03	22000.00
A49BF9	2017-06-23 10:21:00+03	383300.00
A49C31	2017-07-04 08:36:00+03	31000.00
A49CBC	2017-07-08 13:00:00+03	91800.00
A49CF5	2017-07-11 14:41:00+03	56100.00
A49CFD	2017-07-24 05:47:00+03	200400.00
A49D19	2017-08-07 09:09:00+03	15400.00
A49D46	2017-07-30 12:50:00+03	89600.00
A49D64	2017-07-19 02:19:00+03	7400.00
A49D8C	2017-08-02 06:36:00+03	6800.00
A49E13	2017-07-20 08:24:00+03	37900.00
A49E45	2017-07-18 06:27:00+03	100000.00
A49ECE	2017-07-05 05:09:00+03	204700.00
A49F4F	2017-08-11 23:28:00+03	89700.00
A49F6D	2017-08-01 23:09:00+03	80000.00
A49FBA	2017-07-03 10:07:00+03	172100.00
A4A04A	2017-07-31 21:26:00+03	65900.00
A4A057	2017-07-22 10:19:00+03	22600.00
A4A061	2017-08-09 11:08:00+03	58800.00
A4A093	2017-07-27 16:01:00+03	112000.00
A4A0A5	2017-07-28 02:02:00+03	133200.00
A4A0B7	2017-07-22 00:08:00+03	6700.00
A4A0C4	2017-07-28 19:36:00+03	132800.00
A4A0E7	2017-07-25 21:05:00+03	12600.00
A4A0FF	2017-08-08 10:17:00+03	66900.00
A4A10E	2017-07-09 04:39:00+03	92400.00
A4A177	2017-08-08 00:09:00+03	135400.00
A4A19C	2017-07-05 10:39:00+03	55800.00
A4A1B1	2017-07-29 10:04:00+03	49400.00
A4A1BE	2017-08-13 18:51:00+03	34300.00
A4A221	2017-07-12 06:22:00+03	65600.00
A4A227	2017-07-01 20:06:00+03	30200.00
A4A24A	2017-07-18 17:49:00+03	60400.00
A4A2BA	2017-07-05 11:58:00+03	61500.00
A4A331	2017-08-14 13:32:00+03	83000.00
A4A389	2017-07-27 08:37:00+03	21400.00
A4A390	2017-08-08 11:52:00+03	40600.00
A4A3DE	2017-06-29 17:00:00+03	79000.00
A4A3FA	2017-07-06 22:46:00+03	89700.00
A4A444	2017-07-20 06:21:00+03	38600.00
A4A474	2017-08-03 03:52:00+03	26000.00
A4A4DD	2017-07-21 06:31:00+03	155600.00
A4A52B	2017-07-09 14:06:00+03	114700.00
A4A5D8	2017-08-01 19:56:00+03	23200.00
A4A5FE	2017-08-03 14:35:00+03	86400.00
A4A638	2017-07-25 02:52:00+03	65500.00
A4A6FD	2017-07-03 21:12:00+03	177200.00
A4A71A	2017-07-25 02:02:00+03	244800.00
A4A71F	2017-06-27 14:16:00+03	78100.00
A4A723	2017-07-30 20:07:00+03	44600.00
A4A72C	2017-06-29 02:04:00+03	28800.00
A4A771	2017-08-12 03:59:00+03	43000.00
A4A7C9	2017-07-15 11:26:00+03	24000.00
A4A839	2017-08-06 15:19:00+03	92000.00
A4A8B3	2017-07-29 20:42:00+03	135400.00
A4A8E8	2017-07-07 08:15:00+03	89200.00
A4A90A	2017-08-04 06:14:00+03	35200.00
A4A933	2017-08-11 07:24:00+03	28800.00
A4A93E	2017-07-31 14:16:00+03	24600.00
A4A943	2017-08-09 00:18:00+03	42400.00
A4AA0B	2017-08-07 04:31:00+03	61800.00
A4AA79	2017-08-01 21:47:00+03	57100.00
A4AB53	2017-08-06 11:36:00+03	177600.00
A4AB5B	2017-08-14 15:43:00+03	36900.00
A4ABE4	2017-07-03 02:37:00+03	98400.00
A4ABFC	2017-08-04 18:35:00+03	205200.00
A4AC1B	2017-07-18 17:44:00+03	98300.00
A4AC53	2017-07-30 04:56:00+03	116800.00
A4AC55	2017-07-06 19:41:00+03	62500.00
A4AC57	2017-07-24 17:49:00+03	56000.00
A4AC6E	2017-07-04 19:54:00+03	38600.00
A4AC81	2017-07-01 15:34:00+03	42800.00
A4AC90	2017-08-05 07:10:00+03	60700.00
A4AC96	2017-08-15 09:44:00+03	36200.00
A4ACCD	2017-08-08 06:10:00+03	84100.00
A4ACEE	2017-08-10 08:30:00+03	177800.00
A4ACF3	2017-07-27 12:22:00+03	44800.00
A4AD00	2017-07-26 20:00:00+03	14000.00
A4AD0B	2017-08-10 03:55:00+03	29100.00
A4AE8E	2017-08-11 22:23:00+03	47000.00
A4AE91	2017-07-29 06:41:00+03	85000.00
A4AED1	2017-08-08 06:51:00+03	149600.00
A4AEF9	2017-08-07 02:11:00+03	80900.00
A4AF31	2017-08-02 16:15:00+03	22000.00
A4AF66	2017-07-26 00:48:00+03	6800.00
A4AF80	2017-07-11 11:25:00+03	386300.00
A4AFDD	2017-07-18 12:39:00+03	34700.00
A4AFE8	2017-08-02 03:22:00+03	117200.00
A4AFFC	2017-07-24 18:15:00+03	142800.00
A4B01C	2017-07-23 17:16:00+03	25400.00
A4B096	2017-06-23 09:07:00+03	124200.00
A4B0B4	2017-07-07 15:54:00+03	111600.00
A4B0ED	2017-07-11 17:11:00+03	77800.00
A4B141	2017-07-12 18:18:00+03	86300.00
A4B18F	2017-08-09 22:21:00+03	43200.00
A4B197	2017-07-17 15:08:00+03	22000.00
A4B20D	2017-07-17 12:21:00+03	136000.00
A4B24D	2017-07-17 06:25:00+03	59800.00
A4B28E	2017-07-11 04:15:00+03	11700.00
A4B330	2017-07-30 11:48:00+03	25100.00
A4B334	2017-07-16 11:05:00+03	212400.00
A4B342	2017-07-22 22:35:00+03	78500.00
A4B3BC	2017-08-14 03:07:00+03	224700.00
A4B4D0	2017-07-09 07:23:00+03	119600.00
A4B558	2017-07-03 04:27:00+03	21800.00
A4B5DA	2017-08-11 17:57:00+03	69000.00
A4B606	2017-07-05 01:26:00+03	28800.00
A4B62E	2017-07-25 11:12:00+03	81700.00
A4B663	2017-08-12 06:26:00+03	60700.00
A4B724	2017-07-02 13:00:00+03	73300.00
A4B76B	2017-07-04 09:02:00+03	26000.00
A4B791	2017-07-13 18:37:00+03	17800.00
A4B7D2	2017-07-14 14:54:00+03	36200.00
A4B7D5	2017-07-24 22:17:00+03	21800.00
A4B7FB	2017-08-09 12:02:00+03	38400.00
A4B821	2017-08-06 07:49:00+03	32700.00
A4B859	2017-07-25 20:14:00+03	16400.00
A4B8E5	2017-07-27 14:12:00+03	136500.00
A4B94F	2017-07-08 18:51:00+03	102200.00
A4B951	2017-07-23 11:59:00+03	75300.00
A4B97C	2017-07-16 03:20:00+03	13400.00
A4BA09	2017-08-15 13:58:00+03	28000.00
A4BA37	2017-07-09 17:12:00+03	39200.00
A4BA47	2017-07-16 14:40:00+03	28600.00
A4BA59	2017-08-01 16:14:00+03	29600.00
A4BAB6	2017-07-19 18:05:00+03	71800.00
A4BAE0	2017-07-31 22:23:00+03	38000.00
A4BB0E	2017-07-14 11:42:00+03	65200.00
A4BB40	2017-08-03 08:59:00+03	37900.00
A4BBD0	2017-08-10 08:33:00+03	35600.00
A4BBDB	2017-08-06 17:53:00+03	29200.00
A4BCB8	2017-08-08 04:14:00+03	271100.00
A4BD18	2017-07-08 16:06:00+03	22600.00
A4BDA8	2017-08-07 09:41:00+03	6000.00
A4BDCD	2017-08-11 03:05:00+03	136500.00
A4BDED	2017-08-11 13:46:00+03	57700.00
A4BE25	2017-08-03 20:19:00+03	611700.00
A4BE30	2017-08-08 00:55:00+03	258400.00
A4BE66	2017-07-22 15:57:00+03	67200.00
A4BE83	2017-07-30 14:42:00+03	21000.00
A4BEED	2017-07-23 01:15:00+03	154500.00
A4BEF3	2017-07-28 05:49:00+03	118100.00
A4BF5D	2017-08-04 01:00:00+03	15300.00
A4BFFA	2017-07-28 05:35:00+03	22000.00
A4C0BE	2017-07-16 00:59:00+03	67600.00
A4C0DD	2017-08-02 22:49:00+03	88000.00
A4C0E0	2017-07-14 00:26:00+03	19600.00
A4C136	2017-07-13 14:41:00+03	183500.00
A4C153	2017-07-18 07:03:00+03	55800.00
A4C17F	2017-07-26 14:36:00+03	61800.00
A4C1DA	2017-07-13 05:07:00+03	57500.00
A4C1E3	2017-07-03 12:56:00+03	29600.00
A4C207	2017-07-23 07:39:00+03	137100.00
A4C25E	2017-07-15 01:50:00+03	64500.00
A4C26D	2017-07-08 12:51:00+03	28000.00
A4C327	2017-07-26 20:44:00+03	95600.00
A4C32D	2017-07-19 18:38:00+03	12000.00
A4C394	2017-08-05 20:35:00+03	86500.00
A4C3A1	2017-08-09 02:18:00+03	19800.00
A4C3C9	2017-08-01 18:54:00+03	67900.00
A4C3D2	2017-07-28 00:01:00+03	56000.00
A4C3F2	2017-08-05 08:21:00+03	101200.00
A4C3FC	2017-07-11 19:28:00+03	149600.00
A4C40C	2017-07-09 23:54:00+03	98400.00
A4C43C	2017-08-07 10:49:00+03	36800.00
A4C445	2017-08-15 06:28:00+03	21400.00
A4C44B	2017-07-31 06:51:00+03	25000.00
A4C457	2017-08-01 02:52:00+03	26000.00
A4C468	2017-08-10 09:49:00+03	36200.00
A4C48C	2017-07-07 09:46:00+03	393800.00
A4C4C7	2017-07-06 18:09:00+03	447400.00
A4C4FA	2017-07-07 00:35:00+03	229900.00
A4C504	2017-07-18 08:32:00+03	32800.00
A4C50F	2017-08-09 18:26:00+03	47100.00
A4C55E	2017-07-22 21:30:00+03	46900.00
A4C57C	2017-07-31 14:04:00+03	32700.00
A4C581	2017-07-09 13:02:00+03	29300.00
A4C589	2017-08-07 08:21:00+03	119500.00
A4C5C5	2017-07-13 00:51:00+03	230700.00
A4C5CD	2017-08-15 10:44:00+03	90000.00
A4C60C	2017-07-30 23:25:00+03	8400.00
A4C62D	2017-07-04 07:20:00+03	24000.00
A4C659	2017-08-08 09:54:00+03	46400.00
A4C672	2017-08-06 07:10:00+03	140200.00
A4C69E	2017-07-28 09:36:00+03	28800.00
A4C6AA	2017-07-11 06:15:00+03	35800.00
A4C6B6	2017-07-23 16:58:00+03	383200.00
A4C6BF	2017-08-04 07:32:00+03	138100.00
A4C6FB	2017-08-03 07:37:00+03	45400.00
A4C6FF	2017-08-13 22:45:00+03	46300.00
A4C744	2017-07-08 00:04:00+03	194800.00
A4C75C	2017-07-10 18:52:00+03	265600.00
A4C783	2017-07-02 18:55:00+03	51200.00
A4C7B2	2017-07-18 15:40:00+03	23400.00
A4C7B7	2017-07-20 09:23:00+03	156300.00
A4C7C1	2017-07-07 10:21:00+03	75600.00
A4C879	2017-07-21 09:27:00+03	13200.00
A4C8E1	2017-07-27 22:39:00+03	21800.00
A4C948	2017-08-04 16:51:00+03	103200.00
A4C9D8	2017-07-21 02:09:00+03	23200.00
A4C9E5	2017-08-08 23:43:00+03	19600.00
A4C9E6	2017-07-18 11:23:00+03	44800.00
A4CA6A	2017-07-22 17:54:00+03	48500.00
A4CA9E	2017-07-03 23:20:00+03	30200.00
A4CAF6	2017-08-08 18:37:00+03	56600.00
A4CB03	2017-07-05 05:41:00+03	56000.00
A4CB67	2017-08-09 18:10:00+03	169300.00
A4CB9B	2017-08-01 19:46:00+03	22000.00
A4CBCB	2017-07-19 22:19:00+03	61800.00
A4CC36	2017-08-10 04:10:00+03	67700.00
A4CCB8	2017-08-04 01:04:00+03	265700.00
A4CD1C	2017-08-11 19:42:00+03	64800.00
A4CD51	2017-07-07 17:35:00+03	26000.00
A4CDDA	2017-07-12 05:28:00+03	23200.00
A4CE35	2017-08-14 12:07:00+03	187600.00
A4CEEB	2017-07-26 09:44:00+03	27800.00
A4CF08	2017-07-08 18:44:00+03	61800.00
A4CF4F	2017-07-16 17:52:00+03	61800.00
A4CF9E	2017-07-26 16:43:00+03	20200.00
A4CFAC	2017-07-24 00:12:00+03	47200.00
A4D037	2017-08-12 21:34:00+03	105100.00
A4D05E	2017-08-04 08:56:00+03	112600.00
A4D08D	2017-07-24 01:16:00+03	282300.00
A4D098	2017-08-04 06:25:00+03	26000.00
A4D182	2017-08-08 00:46:00+03	40600.00
A4D1C5	2017-08-04 19:12:00+03	52100.00
A4D1D1	2017-07-11 06:23:00+03	127600.00
A4D1D6	2017-07-30 02:52:00+03	100600.00
A4D1F0	2017-07-28 01:56:00+03	92900.00
A4D237	2017-07-22 14:52:00+03	43400.00
A4D3EC	2017-07-28 14:53:00+03	53400.00
A4D3F0	2017-07-18 03:48:00+03	32800.00
A4D41B	2017-08-11 13:31:00+03	30200.00
A4D4B6	2017-07-21 02:34:00+03	149400.00
A4D4D4	2017-07-08 08:25:00+03	100600.00
A4D52B	2017-07-31 13:37:00+03	16400.00
A4D585	2017-07-28 07:55:00+03	420600.00
A4D5CA	2017-07-13 15:50:00+03	124200.00
A4D5CC	2017-07-14 23:38:00+03	46300.00
A4D5D4	2017-07-11 23:29:00+03	19800.00
A4D611	2017-07-16 10:29:00+03	21800.00
A4D61F	2017-08-12 13:16:00+03	46200.00
A4D63B	2017-07-04 23:58:00+03	13400.00
A4D6A0	2017-08-10 21:11:00+03	23200.00
A4D6BF	2017-07-30 00:43:00+03	40200.00
A4D6E5	2017-07-26 04:54:00+03	100600.00
A4D6FD	2017-07-17 17:37:00+03	27800.00
A4D703	2017-07-15 13:50:00+03	64800.00
A4D76B	2017-08-04 07:37:00+03	67600.00
A4D7C7	2017-07-11 16:31:00+03	136800.00
A4D7DC	2017-07-24 06:53:00+03	21400.00
A4D8D0	2017-08-15 12:44:00+03	43200.00
A4D8E1	2017-08-04 07:52:00+03	31000.00
A4D918	2017-07-26 04:32:00+03	64700.00
A4D958	2017-08-05 14:14:00+03	375900.00
A4D9EA	2017-07-22 15:56:00+03	64200.00
A4DA29	2017-08-03 09:59:00+03	12400.00
A4DA4A	2017-08-01 14:45:00+03	430800.00
A4DAAE	2017-07-28 06:00:00+03	68800.00
A4DB71	2017-08-09 08:08:00+03	25600.00
A4DBC3	2017-07-14 02:29:00+03	28800.00
A4DBD2	2017-07-03 09:49:00+03	70700.00
A4DC0C	2017-07-15 02:21:00+03	31200.00
A4DCA6	2017-08-11 18:05:00+03	35900.00
A4DD36	2017-07-03 05:39:00+03	440400.00
A4DD63	2017-07-01 02:32:00+03	26700.00
A4DD66	2017-07-09 15:36:00+03	28800.00
A4DD8C	2017-07-21 10:40:00+03	63200.00
A4DDBC	2017-07-11 03:54:00+03	533200.00
A4DDD5	2017-07-23 06:09:00+03	115700.00
A4DDE9	2017-07-27 16:31:00+03	35700.00
A4DE51	2017-08-02 19:18:00+03	14800.00
A4DE9D	2017-07-15 20:58:00+03	169900.00
A4DEAD	2017-08-08 21:27:00+03	34100.00
A4DEB1	2017-07-07 12:33:00+03	172300.00
A4DF46	2017-08-07 00:00:00+03	16000.00
A4DF54	2017-08-02 22:21:00+03	135600.00
A4DF58	2017-08-12 07:48:00+03	6800.00
A4DF8C	2017-08-06 01:48:00+03	205500.00
A4DFD9	2017-07-14 18:31:00+03	25000.00
A4DFFD	2017-08-11 01:09:00+03	27900.00
A4E004	2017-08-05 12:00:00+03	133700.00
A4E019	2017-07-13 19:52:00+03	56900.00
A4E0E8	2017-08-03 11:55:00+03	46400.00
A4E128	2017-07-09 10:23:00+03	62600.00
A4E132	2017-07-21 14:03:00+03	58400.00
A4E149	2017-08-08 15:03:00+03	78300.00
A4E18F	2017-07-25 13:16:00+03	40300.00
A4E191	2017-07-31 09:01:00+03	20400.00
A4E2A3	2017-08-02 14:29:00+03	14400.00
A4E2D2	2017-07-19 10:16:00+03	85400.00
A4E2EB	2017-08-11 13:13:00+03	54400.00
A4E33C	2017-07-19 14:39:00+03	252200.00
A4E33E	2017-08-01 19:56:00+03	85200.00
A4E340	2017-07-06 01:33:00+03	23200.00
A4E38F	2017-07-31 06:55:00+03	399600.00
A4E3A2	2017-07-19 19:06:00+03	167400.00
A4E3B7	2017-07-09 17:53:00+03	11800.00
A4E3E2	2017-07-31 10:54:00+03	12600.00
A4E3F0	2017-07-12 00:29:00+03	31600.00
A4E4E3	2017-07-23 04:47:00+03	81200.00
A4E54D	2017-08-03 21:23:00+03	26000.00
A4E550	2017-07-08 18:54:00+03	176000.00
A4E641	2017-07-22 17:44:00+03	119700.00
A4E642	2017-07-20 19:09:00+03	49600.00
A4E76B	2017-07-30 13:20:00+03	133700.00
A4E793	2017-07-25 05:29:00+03	113200.00
A4E7D5	2017-07-26 16:45:00+03	139500.00
A4E7D9	2017-07-29 00:37:00+03	43200.00
A4E80D	2017-08-10 03:15:00+03	34700.00
A4E848	2017-07-09 00:50:00+03	24200.00
A4E867	2017-07-18 19:38:00+03	34000.00
A4E8EB	2017-08-12 04:31:00+03	12000.00
A4E915	2017-07-04 02:47:00+03	14800.00
A4E91A	2017-07-06 11:48:00+03	47500.00
A4E934	2017-07-15 07:52:00+03	55800.00
A4E93D	2017-07-31 10:19:00+03	258400.00
A4E952	2017-07-23 22:38:00+03	64700.00
A4E954	2017-07-23 15:43:00+03	47100.00
A4E977	2017-07-08 10:24:00+03	22000.00
A4E98D	2017-07-15 06:39:00+03	189200.00
A4EA01	2017-08-05 14:46:00+03	44000.00
A4EA04	2017-08-15 12:46:00+03	53700.00
A4EA16	2017-07-29 05:21:00+03	188100.00
A4EA20	2017-08-14 02:11:00+03	44500.00
A4EA2C	2017-07-31 14:40:00+03	56000.00
A4EA59	2017-07-02 04:07:00+03	25000.00
A4EA6C	2017-07-18 00:59:00+03	36200.00
A4EA73	2017-07-07 04:37:00+03	75600.00
A4EAA9	2017-07-29 19:20:00+03	64200.00
A4EB1B	2017-08-10 05:58:00+03	28800.00
A4EB63	2017-06-27 02:29:00+03	148200.00
A4EB8C	2017-08-08 15:06:00+03	16400.00
A4EB92	2017-07-12 22:39:00+03	207200.00
A4EB97	2017-07-03 08:22:00+03	20000.00
A4EBA0	2017-08-10 19:31:00+03	42700.00
A4EBB3	2017-07-06 02:47:00+03	9800.00
A4EBB4	2017-07-28 23:48:00+03	123000.00
A4EBBB	2017-08-07 14:51:00+03	61100.00
A4EC06	2017-07-15 09:32:00+03	133100.00
A4EC2C	2017-08-05 14:56:00+03	42600.00
A4EC44	2017-08-05 05:32:00+03	61900.00
A4EC85	2017-07-12 17:08:00+03	55800.00
A4ECA6	2017-07-08 10:06:00+03	32200.00
A4ED09	2017-07-29 22:02:00+03	35700.00
A4ED33	2017-06-30 19:53:00+03	28000.00
A4ED72	2017-08-13 00:22:00+03	48800.00
A4ED9A	2017-07-31 14:27:00+03	61800.00
A4EE38	2017-07-06 20:17:00+03	21800.00
A4EEB4	2017-07-02 16:15:00+03	53600.00
A4EF13	2017-07-18 16:03:00+03	53600.00
A4EFE3	2017-07-17 22:18:00+03	10300.00
A4F04A	2017-07-16 13:41:00+03	6000.00
A4F057	2017-07-03 22:57:00+03	106000.00
A4F06E	2017-07-28 03:54:00+03	248400.00
A4F075	2017-07-18 02:54:00+03	112000.00
A4F07B	2017-07-26 11:44:00+03	66800.00
A4F0D1	2017-07-02 21:54:00+03	45400.00
A4F0F4	2017-08-07 01:48:00+03	103500.00
A4F1C7	2017-08-11 23:43:00+03	202300.00
A4F1FE	2017-07-27 20:22:00+03	47100.00
A4F287	2017-07-28 20:25:00+03	29400.00
A4F33B	2017-07-18 07:23:00+03	56000.00
A4F3A6	2017-07-19 16:55:00+03	90800.00
A4F41F	2017-08-03 10:16:00+03	16400.00
A4F42E	2017-08-02 11:54:00+03	369000.00
A4F470	2017-08-15 06:48:00+03	6300.00
A4F4AE	2017-07-11 00:20:00+03	32800.00
A4F4E4	2017-07-24 13:53:00+03	49400.00
A4F505	2017-07-12 10:34:00+03	86400.00
A4F511	2017-08-04 07:30:00+03	51900.00
A4F51A	2017-07-26 16:04:00+03	46800.00
A4F52B	2017-07-29 09:48:00+03	56000.00
A4F589	2017-07-07 15:47:00+03	46800.00
A4F605	2017-08-12 09:21:00+03	6000.00
A4F60C	2017-07-24 12:05:00+03	31400.00
A4F63A	2017-08-15 16:38:00+03	54100.00
A4F67D	2017-07-14 22:39:00+03	28800.00
A4F6A8	2017-07-06 19:23:00+03	140900.00
A4F71A	2017-08-11 05:50:00+03	28800.00
A4F75F	2017-08-11 17:54:00+03	66000.00
A4F76D	2017-07-22 01:10:00+03	59300.00
A4F785	2017-07-24 13:27:00+03	132800.00
A4F794	2017-08-02 08:15:00+03	29800.00
A4F79C	2017-07-29 22:53:00+03	8000.00
A4F7B4	2017-07-05 07:07:00+03	99200.00
A4F7EB	2017-08-11 06:54:00+03	40100.00
A4F7F2	2017-07-19 09:59:00+03	28800.00
A4F81A	2017-07-26 13:14:00+03	11600.00
A4F8C6	2017-08-12 13:23:00+03	31600.00
A4F8D9	2017-08-03 18:27:00+03	23600.00
A4F92C	2017-07-21 01:37:00+03	60300.00
A4F953	2017-07-30 01:47:00+03	111600.00
A4F986	2017-07-16 20:28:00+03	31200.00
A4F99A	2017-07-06 09:04:00+03	35000.00
A4F9E1	2017-07-20 18:11:00+03	174600.00
A4FA06	2017-07-06 14:00:00+03	48500.00
A4FA27	2017-06-25 02:04:00+03	111000.00
A4FA69	2017-07-30 23:35:00+03	64900.00
A4FA80	2017-07-21 08:08:00+03	111600.00
A4FA8C	2017-07-20 09:15:00+03	116400.00
A4FAB5	2017-06-27 20:39:00+03	51300.00
A4FAB6	2017-08-01 19:47:00+03	91100.00
A4FAD5	2017-08-10 02:23:00+03	40100.00
A4FB20	2017-07-25 20:48:00+03	28000.00
A4FB25	2017-08-10 04:37:00+03	54800.00
A4FB42	2017-07-19 00:01:00+03	11000.00
A4FB5B	2017-07-16 12:24:00+03	35200.00
A4FBEB	2017-07-31 00:25:00+03	18800.00
A4FC03	2017-07-07 21:21:00+03	32800.00
A4FC35	2017-08-08 08:17:00+03	119600.00
A4FC71	2017-07-31 02:11:00+03	85000.00
A4FCE4	2017-08-11 22:19:00+03	36200.00
A4FCEE	2017-07-22 04:25:00+03	22600.00
A4FD2A	2017-07-06 14:46:00+03	80900.00
A4FD5B	2017-07-15 00:17:00+03	65900.00
A4FD69	2017-07-12 07:53:00+03	28000.00
A4FD9B	2017-08-03 09:45:00+03	25200.00
A4FDFF	2017-07-14 22:08:00+03	252200.00
A4FE2A	2017-07-08 02:10:00+03	12000.00
A4FEB9	2017-08-01 20:00:00+03	81600.00
A4FED6	2017-07-14 03:51:00+03	290400.00
A4FEFE	2017-07-16 20:04:00+03	46800.00
A4FF19	2017-08-05 07:36:00+03	18900.00
A4FF22	2017-08-08 07:48:00+03	56000.00
A4FF44	2017-07-31 12:27:00+03	26400.00
A4FF65	2017-07-10 06:44:00+03	32800.00
A4FF83	2017-07-20 21:08:00+03	45200.00
A5003D	2017-07-27 11:09:00+03	22000.00
A50047	2017-08-12 03:00:00+03	55200.00
A5004C	2017-08-03 07:44:00+03	28800.00
A50096	2017-07-18 13:25:00+03	66600.00
A500EF	2017-07-08 11:00:00+03	47600.00
A5012E	2017-07-06 01:04:00+03	32800.00
A50131	2017-07-04 23:32:00+03	28000.00
A5016F	2017-07-24 03:10:00+03	31700.00
A50193	2017-07-09 15:40:00+03	55800.00
A501DA	2017-08-06 21:11:00+03	23600.00
A50230	2017-07-26 14:29:00+03	57600.00
A50265	2017-07-11 21:52:00+03	119600.00
A50286	2017-07-08 14:39:00+03	25800.00
A502AF	2017-07-06 12:15:00+03	23200.00
A502C2	2017-08-02 21:02:00+03	101800.00
A502D0	2017-08-14 21:41:00+03	46000.00
A5033D	2017-07-05 01:06:00+03	26300.00
A5037A	2017-07-12 01:50:00+03	25700.00
A5038F	2017-07-29 21:54:00+03	18600.00
A503E6	2017-08-01 14:55:00+03	65500.00
A504A6	2017-07-22 11:12:00+03	55800.00
A504E1	2017-07-22 09:51:00+03	16400.00
A5051C	2017-07-09 12:29:00+03	43600.00
A50577	2017-08-05 23:16:00+03	34000.00
A5057A	2017-07-16 01:26:00+03	47000.00
A5057D	2017-07-28 19:55:00+03	246000.00
A505BB	2017-08-07 14:12:00+03	33800.00
A505CD	2017-08-01 00:45:00+03	21600.00
A5061F	2017-07-04 03:49:00+03	114300.00
A5068E	2017-08-09 09:29:00+03	15400.00
A506A1	2017-08-15 17:21:00+03	152500.00
A5077D	2017-08-01 12:13:00+03	17200.00
A50788	2017-08-09 04:20:00+03	63400.00
A507A1	2017-07-03 03:00:00+03	14400.00
A507A4	2017-07-22 11:11:00+03	71600.00
A507BD	2017-08-09 23:27:00+03	112000.00
A507E7	2017-07-17 17:20:00+03	81700.00
A50829	2017-07-29 22:12:00+03	53400.00
A50861	2017-07-02 12:34:00+03	49800.00
A50884	2017-07-22 15:46:00+03	61800.00
A508B0	2017-06-29 19:07:00+03	150600.00
A508D6	2017-08-10 13:47:00+03	31600.00
A508DB	2017-08-01 05:53:00+03	28000.00
A5093E	2017-07-23 07:04:00+03	57500.00
A509AB	2017-07-16 19:26:00+03	67600.00
A509EA	2017-08-13 05:43:00+03	44800.00
A50A1C	2017-08-08 00:10:00+03	113800.00
A50A1E	2017-07-11 19:40:00+03	53400.00
A50A4C	2017-06-30 01:20:00+03	40800.00
A50AB0	2017-07-26 17:40:00+03	15000.00
A50B2F	2017-07-30 11:02:00+03	26000.00
A50BB4	2017-08-12 18:51:00+03	135400.00
A50C00	2017-07-23 06:11:00+03	399600.00
A50C04	2017-07-09 15:32:00+03	13600.00
A50C33	2017-07-08 01:31:00+03	27200.00
A50CA5	2017-07-04 19:21:00+03	57600.00
A50D41	2017-07-05 18:24:00+03	24400.00
A50D60	2017-07-17 21:50:00+03	47100.00
A50DCC	2017-08-02 20:47:00+03	28000.00
A50DDC	2017-07-03 21:07:00+03	55800.00
A50DE6	2017-07-02 23:45:00+03	88900.00
A50E9F	2017-07-31 09:14:00+03	7800.00
A50FAF	2017-07-20 05:06:00+03	67700.00
A50FD1	2017-07-25 06:49:00+03	187800.00
A5101C	2017-08-03 10:29:00+03	52300.00
A51091	2017-06-27 22:14:00+03	115400.00
A510DD	2017-08-14 07:39:00+03	148200.00
A51107	2017-08-06 19:30:00+03	134000.00
A5115C	2017-07-31 19:10:00+03	189700.00
A51173	2017-08-04 02:48:00+03	10800.00
A512AB	2017-07-30 14:52:00+03	67600.00
A51305	2017-08-04 21:05:00+03	29600.00
A513E9	2017-07-14 17:28:00+03	143600.00
A51454	2017-06-29 10:50:00+03	67600.00
A5145B	2017-07-15 03:04:00+03	52000.00
A51462	2017-08-15 13:53:00+03	28800.00
A51465	2017-08-06 20:43:00+03	37900.00
A51479	2017-07-06 09:09:00+03	148200.00
A514C4	2017-08-07 20:18:00+03	265700.00
A514DB	2017-08-09 07:13:00+03	80900.00
A51536	2017-08-15 11:01:00+03	58200.00
A515B0	2017-07-03 05:34:00+03	68400.00
A515B3	2017-07-11 15:25:00+03	116600.00
A515CD	2017-07-25 03:50:00+03	75600.00
A515D6	2017-07-05 12:17:00+03	32400.00
A51636	2017-07-04 11:29:00+03	106700.00
A51640	2017-08-04 14:45:00+03	66800.00
A51726	2017-07-07 20:43:00+03	62100.00
A51747	2017-08-14 03:03:00+03	14800.00
A51770	2017-07-04 23:40:00+03	162200.00
A51775	2017-08-01 01:01:00+03	23400.00
A5180B	2017-07-18 23:42:00+03	11200.00
A5185C	2017-08-02 14:40:00+03	26000.00
A51879	2017-07-15 05:40:00+03	136800.00
A518AD	2017-07-09 21:56:00+03	56600.00
A518CF	2017-07-18 01:25:00+03	150600.00
A51976	2017-08-09 04:38:00+03	29400.00
A51977	2017-07-04 14:54:00+03	16800.00
A519CA	2017-07-22 22:42:00+03	86000.00
A519E5	2017-07-26 12:50:00+03	25600.00
A51A12	2017-08-12 09:00:00+03	23600.00
A51A37	2017-08-12 17:51:00+03	14700.00
A51A42	2017-08-05 17:36:00+03	55800.00
A51A58	2017-07-14 11:16:00+03	265600.00
A51A64	2017-07-05 03:52:00+03	42800.00
A51A77	2017-07-28 00:35:00+03	23200.00
A51A7A	2017-08-03 15:54:00+03	53300.00
A51B4A	2017-08-06 15:27:00+03	22600.00
A51B51	2017-08-02 00:03:00+03	47100.00
A51BFC	2017-08-12 07:32:00+03	36400.00
A51C6A	2017-08-02 19:27:00+03	6700.00
A51CDC	2017-07-27 13:30:00+03	26000.00
A51CE2	2017-07-16 05:45:00+03	70800.00
A51D3E	2017-07-13 17:36:00+03	120200.00
A51D63	2017-08-09 00:53:00+03	65300.00
A51DAA	2017-07-05 10:29:00+03	40600.00
A51DAC	2017-07-18 22:40:00+03	6400.00
A51DC7	2017-07-29 03:54:00+03	56000.00
A51DF0	2017-08-15 12:06:00+03	74400.00
A51E0A	2017-07-09 13:33:00+03	18600.00
A51E49	2017-08-15 03:17:00+03	143800.00
A51E71	2017-08-04 01:04:00+03	27800.00
A51ED3	2017-07-29 15:31:00+03	22000.00
A51EDD	2017-07-10 20:33:00+03	32200.00
A51F04	2017-07-17 23:51:00+03	8200.00
A51F0D	2017-07-31 05:55:00+03	32600.00
A51F46	2017-07-20 13:53:00+03	39300.00
A51F81	2017-07-06 11:44:00+03	28600.00
A51F8D	2017-07-11 20:33:00+03	97900.00
A5200B	2017-08-15 04:59:00+03	27300.00
A52011	2017-07-31 13:14:00+03	16400.00
A52077	2017-08-09 09:58:00+03	45200.00
A52081	2017-08-13 17:18:00+03	136800.00
A520A2	2017-07-18 12:13:00+03	125900.00
A520FB	2017-07-03 13:35:00+03	68800.00
A521AF	2017-07-21 03:42:00+03	27200.00
A521C5	2017-08-05 11:33:00+03	135200.00
A521E8	2017-08-07 18:34:00+03	43400.00
A521EB	2017-07-10 22:13:00+03	73500.00
A521F8	2017-07-26 08:51:00+03	26600.00
A5224E	2017-08-06 20:40:00+03	6000.00
A52296	2017-07-03 03:36:00+03	199400.00
A522BE	2017-07-07 06:09:00+03	32700.00
A522FF	2017-08-15 10:05:00+03	136800.00
A52379	2017-08-04 12:20:00+03	24400.00
A523F0	2017-07-25 02:13:00+03	28000.00
A524AF	2017-08-13 18:15:00+03	55100.00
A524B5	2017-07-11 10:25:00+03	199300.00
A524C0	2017-08-13 13:36:00+03	67200.00
A524E7	2017-07-01 08:38:00+03	73600.00
A524FF	2017-08-10 19:04:00+03	39600.00
A5251C	2017-07-15 17:48:00+03	28000.00
A52556	2017-07-23 10:02:00+03	393800.00
A525A4	2017-07-03 23:01:00+03	87300.00
A525D4	2017-07-10 18:08:00+03	21800.00
A52615	2017-08-05 04:30:00+03	265700.00
A52617	2017-06-30 02:18:00+03	46000.00
A5269B	2017-06-25 05:50:00+03	176200.00
A526D2	2017-08-15 07:01:00+03	77000.00
A526EB	2017-08-10 22:57:00+03	22000.00
A5271E	2017-08-01 04:21:00+03	38200.00
A52761	2017-07-24 04:44:00+03	135400.00
A527DE	2017-08-08 16:33:00+03	30400.00
A527FA	2017-08-08 17:28:00+03	25400.00
A5280C	2017-08-14 03:44:00+03	133200.00
A52812	2017-08-15 02:30:00+03	57500.00
A52824	2017-07-18 11:24:00+03	15800.00
A52831	2017-07-11 12:19:00+03	56000.00
A528BA	2017-06-30 00:55:00+03	48800.00
A528E4	2017-07-12 01:30:00+03	467600.00
A52932	2017-08-08 22:21:00+03	38400.00
A52962	2017-07-11 15:56:00+03	45400.00
A52977	2017-07-09 09:02:00+03	149400.00
A529C1	2017-08-01 11:53:00+03	6800.00
A52A17	2017-08-11 07:05:00+03	41600.00
A52A1E	2017-08-07 06:34:00+03	89700.00
A52A84	2017-08-03 17:30:00+03	211600.00
A52ADE	2017-08-10 13:50:00+03	56000.00
A52AF2	2017-07-19 10:10:00+03	13000.00
A52BAF	2017-07-12 23:27:00+03	13600.00
A52BEE	2017-07-19 03:56:00+03	20200.00
A52BF3	2017-07-16 19:32:00+03	40100.00
A52C10	2017-07-19 06:26:00+03	123000.00
A52C4F	2017-07-31 06:28:00+03	137600.00
A52C90	2017-07-13 17:58:00+03	28000.00
A52D0F	2017-07-19 07:51:00+03	92900.00
A52D1D	2017-07-11 04:18:00+03	54300.00
A52D47	2017-07-29 21:26:00+03	59200.00
A52DAB	2017-08-06 10:24:00+03	99200.00
A52DBD	2017-07-19 11:58:00+03	134400.00
A52DC3	2017-07-09 19:30:00+03	55800.00
A52E00	2017-07-19 15:18:00+03	46800.00
A52E67	2017-07-12 03:23:00+03	383200.00
A52ECB	2017-08-15 16:57:00+03	89700.00
A52ED2	2017-08-14 11:46:00+03	63400.00
A52EDA	2017-07-25 13:13:00+03	6000.00
A52F8E	2017-07-06 18:20:00+03	66600.00
A52F9B	2017-07-30 21:37:00+03	62600.00
A52FC4	2017-06-30 20:05:00+03	27300.00
A5304B	2017-08-14 02:09:00+03	133700.00
A530A4	2017-07-16 14:03:00+03	220600.00
A530CE	2017-08-14 19:41:00+03	13400.00
A530ED	2017-07-05 05:58:00+03	57800.00
A53103	2017-08-03 08:15:00+03	135600.00
A53132	2017-08-01 12:18:00+03	214100.00
A53197	2017-08-05 04:24:00+03	32800.00
A5319B	2017-07-27 11:17:00+03	66800.00
A531C4	2017-07-23 11:55:00+03	28000.00
A531E7	2017-06-30 05:18:00+03	122000.00
A5321B	2017-07-02 00:49:00+03	149500.00
A532EF	2017-07-30 06:09:00+03	186900.00
A532F0	2017-07-22 05:40:00+03	86600.00
A53348	2017-08-03 00:40:00+03	156000.00
A53371	2017-07-24 15:36:00+03	101900.00
A53384	2017-06-29 16:12:00+03	90400.00
A533F4	2017-07-25 05:36:00+03	89000.00
A53482	2017-07-11 20:09:00+03	55800.00
A5349F	2017-08-10 15:12:00+03	44700.00
A534FA	2017-08-06 09:22:00+03	123000.00
A5351B	2017-08-15 12:29:00+03	34400.00
A5351D	2017-08-12 11:14:00+03	21000.00
A53523	2017-07-31 23:38:00+03	88900.00
A53525	2017-07-17 02:16:00+03	6300.00
A53582	2017-08-04 18:52:00+03	45100.00
A535C1	2017-07-24 11:18:00+03	101500.00
A535CF	2017-06-29 13:50:00+03	32700.00
A53622	2017-08-02 06:40:00+03	67800.00
A5362A	2017-07-11 19:41:00+03	149600.00
A5366B	2017-07-11 06:41:00+03	44600.00
A536E4	2017-07-04 17:44:00+03	56100.00
A536F2	2017-07-15 03:35:00+03	88800.00
A53703	2017-07-27 11:52:00+03	70700.00
A5370F	2017-07-13 03:04:00+03	273000.00
A53739	2017-07-20 12:27:00+03	29400.00
A5378F	2017-07-16 14:29:00+03	78600.00
A53790	2017-07-27 22:20:00+03	43700.00
A53791	2017-07-22 02:47:00+03	68100.00
A53796	2017-07-08 05:16:00+03	69400.00
A537A0	2017-07-10 12:11:00+03	149400.00
A537D0	2017-08-10 12:10:00+03	136800.00
A537E3	2017-08-09 05:02:00+03	23400.00
A537F6	2017-08-11 17:36:00+03	63000.00
A5391C	2017-07-26 16:18:00+03	56000.00
A53920	2017-06-29 12:13:00+03	246000.00
A53946	2017-07-06 14:00:00+03	12400.00
A5396A	2017-07-14 14:08:00+03	99900.00
A539DB	2017-08-04 02:46:00+03	49900.00
A539EE	2017-08-02 15:25:00+03	133100.00
A539FB	2017-07-06 02:25:00+03	67600.00
A53A02	2017-08-04 04:03:00+03	22200.00
A53A27	2017-07-24 14:10:00+03	16800.00
A53A86	2017-08-04 21:45:00+03	205600.00
A53AC0	2017-07-22 01:35:00+03	161200.00
A53B01	2017-07-20 21:25:00+03	67600.00
A53B87	2017-07-10 17:26:00+03	46300.00
A53BBE	2017-08-11 23:05:00+03	69500.00
A53BD3	2017-07-13 07:21:00+03	8400.00
A53BE8	2017-08-06 01:43:00+03	17800.00
A53BE9	2017-07-02 07:29:00+03	26000.00
A53BEA	2017-07-17 02:59:00+03	83700.00
A53C18	2017-07-20 21:48:00+03	13400.00
A53C52	2017-07-28 08:38:00+03	60900.00
A53C65	2017-08-06 15:25:00+03	18600.00
A53CCD	2017-07-17 07:51:00+03	15400.00
A53CE8	2017-07-20 13:07:00+03	37900.00
A53CFA	2017-07-22 06:48:00+03	128100.00
A53D8F	2017-08-03 19:40:00+03	12600.00
A53E07	2017-08-14 19:20:00+03	13000.00
A53E67	2017-07-08 18:12:00+03	58900.00
A53ED4	2017-08-02 13:41:00+03	88100.00
A53EDB	2017-06-28 04:41:00+03	24200.00
A53F10	2017-07-15 19:47:00+03	24200.00
A53F59	2017-07-31 09:08:00+03	28800.00
A53F88	2017-07-14 10:48:00+03	175200.00
A5404E	2017-06-29 18:03:00+03	56000.00
A54091	2017-07-16 20:02:00+03	55600.00
A540A3	2017-07-13 16:16:00+03	51600.00
A540AF	2017-07-01 11:50:00+03	14800.00
A540B2	2017-07-15 09:39:00+03	265700.00
A54126	2017-07-23 10:45:00+03	44800.00
A541D2	2017-08-13 12:38:00+03	15400.00
A54219	2017-08-09 20:26:00+03	75800.00
A54262	2017-07-19 21:56:00+03	47000.00
A5429B	2017-08-07 13:28:00+03	14400.00
A5429F	2017-07-07 19:43:00+03	28000.00
A542E1	2017-08-01 18:29:00+03	134000.00
A542FF	2017-07-13 11:40:00+03	56000.00
A54324	2017-07-11 04:18:00+03	51900.00
A5432E	2017-07-21 15:21:00+03	44000.00
A543BC	2017-07-16 19:32:00+03	46400.00
A543E7	2017-07-25 06:26:00+03	68100.00
A543F5	2017-07-10 18:14:00+03	59800.00
A5442A	2017-07-22 12:56:00+03	57500.00
A54576	2017-07-07 20:16:00+03	97500.00
A545B1	2017-07-26 05:12:00+03	41200.00
A545BF	2017-06-27 06:14:00+03	37900.00
A545EA	2017-07-31 22:43:00+03	46400.00
A54639	2017-07-21 03:12:00+03	28000.00
A54665	2017-08-11 01:00:00+03	85700.00
A54676	2017-07-10 03:46:00+03	52000.00
A54696	2017-07-13 03:56:00+03	123000.00
A546DC	2017-08-12 07:43:00+03	21400.00
A54710	2017-08-11 14:25:00+03	42800.00
A54765	2017-08-13 04:22:00+03	55800.00
A547CE	2017-07-15 20:09:00+03	45100.00
A548BA	2017-07-21 08:17:00+03	102600.00
A5490D	2017-07-03 07:26:00+03	82700.00
A54955	2017-07-21 15:45:00+03	67600.00
A54964	2017-08-06 16:35:00+03	86600.00
A54ABB	2017-08-12 00:47:00+03	123600.00
A54AF2	2017-07-18 12:05:00+03	44800.00
A54AFF	2017-07-09 00:43:00+03	179400.00
A54B26	2017-07-05 10:38:00+03	31000.00
A54B2D	2017-07-05 23:41:00+03	118300.00
A54B32	2017-07-26 09:31:00+03	159800.00
A54B3C	2017-08-01 13:39:00+03	77600.00
A54BC4	2017-08-07 00:42:00+03	6800.00
A54BDD	2017-08-04 17:18:00+03	22000.00
A54C31	2017-08-11 03:14:00+03	282300.00
A54C85	2017-08-08 16:32:00+03	160700.00
A54D02	2017-08-08 21:43:00+03	88000.00
A54D94	2017-08-11 23:41:00+03	24600.00
A54DCC	2017-06-27 15:53:00+03	112600.00
A54DE2	2017-07-18 02:25:00+03	85000.00
A54DF9	2017-08-04 20:16:00+03	59800.00
A54E30	2017-07-04 18:52:00+03	27300.00
A54E63	2017-07-09 04:46:00+03	331900.00
A54E80	2017-07-07 10:32:00+03	65400.00
A54EB3	2017-07-04 02:10:00+03	61100.00
A54EDB	2017-08-09 12:30:00+03	23600.00
A54F77	2017-07-16 06:56:00+03	96800.00
A54FBB	2017-08-06 13:42:00+03	420500.00
A54FDD	2017-07-10 00:45:00+03	70400.00
A54FFF	2017-08-10 23:02:00+03	42100.00
A550A7	2017-07-29 10:24:00+03	6000.00
A550E6	2017-08-04 15:54:00+03	114800.00
A551AD	2017-07-26 00:39:00+03	23200.00
A551B4	2017-08-02 15:13:00+03	47200.00
A55263	2017-07-30 19:38:00+03	12200.00
A55293	2017-07-21 09:19:00+03	88300.00
A55294	2017-07-04 04:04:00+03	56600.00
A5529E	2017-08-07 17:12:00+03	66600.00
A55329	2017-07-28 21:29:00+03	44000.00
A55338	2017-07-14 01:03:00+03	160100.00
A55353	2017-08-05 13:41:00+03	60700.00
A553A9	2017-08-06 07:07:00+03	16400.00
A553E7	2017-07-15 11:55:00+03	151200.00
A5540A	2017-08-15 09:57:00+03	40800.00
A5543C	2017-08-15 14:03:00+03	62000.00
A554DF	2017-08-13 09:41:00+03	25200.00
A554E0	2017-08-11 12:46:00+03	58600.00
A55513	2017-07-23 15:45:00+03	23600.00
A55525	2017-08-08 08:48:00+03	55800.00
A55530	2017-08-15 11:13:00+03	143000.00
A55531	2017-08-14 04:44:00+03	30000.00
A55543	2017-08-11 13:13:00+03	133200.00
A555EE	2017-07-30 10:56:00+03	74400.00
A55664	2017-07-23 04:25:00+03	135400.00
A55674	2017-07-05 20:06:00+03	111600.00
A55677	2017-07-12 21:36:00+03	6700.00
A55687	2017-07-02 18:08:00+03	369000.00
A556CB	2017-07-11 13:41:00+03	65900.00
A556F8	2017-07-26 14:13:00+03	199700.00
A55742	2017-07-21 21:40:00+03	25200.00
A55769	2017-07-05 21:41:00+03	24300.00
A557C5	2017-07-10 16:55:00+03	78000.00
A5584E	2017-08-12 06:47:00+03	201800.00
A558B0	2017-07-09 21:17:00+03	67600.00
A558D2	2017-08-13 21:06:00+03	147000.00
A55935	2017-08-07 03:59:00+03	32800.00
A55937	2017-07-28 15:43:00+03	23200.00
A55964	2017-08-03 20:18:00+03	136500.00
A5598B	2017-08-14 01:25:00+03	14000.00
A55994	2017-06-29 15:26:00+03	332800.00
A5599B	2017-07-18 06:39:00+03	39800.00
A559D9	2017-08-10 11:30:00+03	55800.00
A55A08	2017-08-10 15:14:00+03	48800.00
A55A35	2017-07-22 15:12:00+03	6000.00
A55A60	2017-08-05 11:04:00+03	17800.00
A55A99	2017-07-29 13:17:00+03	123000.00
A55AEC	2017-07-01 07:45:00+03	84100.00
A55B53	2017-07-26 20:37:00+03	40000.00
A55BC1	2017-08-07 21:42:00+03	98400.00
A55BCE	2017-08-08 11:08:00+03	46200.00
A55C12	2017-07-26 00:32:00+03	12400.00
A55C44	2017-08-13 16:42:00+03	13000.00
A55C62	2017-08-11 07:54:00+03	95200.00
A55C76	2017-08-03 12:20:00+03	393000.00
A55C85	2017-08-08 05:25:00+03	112600.00
A55D0B	2017-07-25 14:42:00+03	30900.00
A55D0F	2017-07-17 03:17:00+03	213800.00
A55DBE	2017-07-01 20:20:00+03	135500.00
A55DE4	2017-07-16 02:45:00+03	24200.00
A55DFC	2017-07-26 02:08:00+03	68400.00
A55DFD	2017-07-16 03:04:00+03	92000.00
A55E18	2017-07-05 10:17:00+03	26800.00
A55E84	2017-07-17 15:50:00+03	21800.00
A55E88	2017-08-04 15:27:00+03	23200.00
A55ED8	2017-07-04 13:16:00+03	316200.00
A55F00	2017-07-14 23:07:00+03	69500.00
A55F3D	2017-07-30 18:03:00+03	70400.00
A55F60	2017-07-17 12:05:00+03	187200.00
A55F63	2017-06-28 05:57:00+03	84500.00
A55F69	2017-07-29 11:11:00+03	47700.00
A55F73	2017-07-27 14:19:00+03	85600.00
A55F83	2017-07-15 09:41:00+03	23200.00
A55F86	2017-08-02 21:07:00+03	186900.00
A55FAF	2017-07-19 05:18:00+03	454500.00
A55FDB	2017-07-28 21:21:00+03	78600.00
A55FF1	2017-07-08 02:03:00+03	291600.00
A55FFA	2017-07-14 22:55:00+03	39600.00
A55FFE	2017-07-04 19:43:00+03	23600.00
A5607D	2017-07-23 15:29:00+03	29600.00
A56092	2017-07-02 14:07:00+03	135400.00
A560B4	2017-07-27 02:58:00+03	14400.00
A560F5	2017-07-18 23:10:00+03	28800.00
A561F8	2017-07-09 01:13:00+03	84500.00
A56216	2017-07-31 03:10:00+03	77900.00
A562BE	2017-07-28 01:08:00+03	73200.00
A5633A	2017-08-13 03:28:00+03	27200.00
A5635A	2017-08-08 10:20:00+03	369000.00
A56369	2017-07-19 00:48:00+03	111600.00
A5639D	2017-07-29 07:25:00+03	270800.00
A56403	2017-08-12 04:17:00+03	44800.00
A5648E	2017-07-10 04:05:00+03	103800.00
A564B7	2017-08-09 16:04:00+03	65600.00
A564C1	2017-07-14 00:22:00+03	272300.00
A564E1	2017-07-06 21:53:00+03	171400.00
A564F1	2017-07-28 08:18:00+03	23400.00
A5650B	2017-08-03 07:50:00+03	25600.00
A56553	2017-07-12 16:02:00+03	58100.00
A5658E	2017-07-25 23:46:00+03	14000.00
A565DE	2017-07-17 16:54:00+03	58400.00
A56655	2017-08-01 13:56:00+03	18700.00
A56657	2017-07-29 17:11:00+03	89700.00
A5667A	2017-07-16 06:56:00+03	26800.00
A566A3	2017-08-12 17:55:00+03	29600.00
A566F9	2017-07-20 02:01:00+03	22000.00
A56727	2017-07-10 20:46:00+03	26200.00
A56744	2017-08-01 09:18:00+03	27400.00
A567AF	2017-08-07 04:34:00+03	95700.00
A567F6	2017-07-05 14:23:00+03	210800.00
A56823	2017-07-15 01:12:00+03	78400.00
A568D1	2017-07-30 02:11:00+03	92100.00
A568E2	2017-07-06 16:46:00+03	90000.00
A5691E	2017-07-18 21:49:00+03	68100.00
A5693A	2017-08-08 18:58:00+03	24400.00
A569A2	2017-07-14 08:18:00+03	156700.00
A56B4B	2017-07-08 19:07:00+03	138300.00
A56B80	2017-07-07 08:42:00+03	47400.00
A56BA0	2017-08-10 06:36:00+03	27300.00
A56BCB	2017-07-18 16:52:00+03	40800.00
A56BEA	2017-07-13 23:50:00+03	27200.00
A56C24	2017-08-09 01:43:00+03	10700.00
A56C6E	2017-07-06 15:53:00+03	65900.00
A56C90	2017-07-06 20:18:00+03	6000.00
A56D34	2017-07-21 17:11:00+03	12400.00
A56D35	2017-07-20 14:11:00+03	30000.00
A56D63	2017-07-28 10:44:00+03	95600.00
A56E17	2017-07-19 14:45:00+03	21400.00
A56E1D	2017-08-03 13:53:00+03	77700.00
A56EB0	2017-08-10 00:19:00+03	103700.00
A56F21	2017-07-21 02:57:00+03	15000.00
A56F37	2017-07-15 22:33:00+03	67800.00
A57025	2017-08-03 23:42:00+03	31600.00
A5703B	2017-08-05 07:33:00+03	118500.00
A57089	2017-07-20 20:56:00+03	231700.00
A57134	2017-07-14 19:58:00+03	28800.00
A5717A	2017-08-12 08:37:00+03	67900.00
A5717C	2017-08-15 07:35:00+03	36700.00
A571DA	2017-08-09 10:22:00+03	47100.00
A571ED	2017-08-02 04:59:00+03	35700.00
A57377	2017-07-16 20:37:00+03	6700.00
A573FD	2017-08-02 20:07:00+03	26000.00
A57431	2017-08-02 08:41:00+03	112000.00
A5748E	2017-07-10 08:00:00+03	27200.00
A574C8	2017-07-30 05:31:00+03	17800.00
A575A4	2017-08-09 16:36:00+03	79600.00
A576A8	2017-08-02 20:16:00+03	26300.00
A576B1	2017-07-11 02:19:00+03	32700.00
A576E1	2017-07-14 10:38:00+03	417000.00
A576FA	2017-07-20 18:19:00+03	135400.00
A5774B	2017-07-13 17:25:00+03	594900.00
A57790	2017-08-08 00:48:00+03	90400.00
A5784B	2017-07-17 18:42:00+03	27200.00
A57972	2017-07-28 19:14:00+03	25800.00
A5798C	2017-07-07 00:10:00+03	24400.00
A579C5	2017-07-05 23:20:00+03	52000.00
A57A48	2017-08-07 21:27:00+03	21400.00
A57A78	2017-07-21 05:24:00+03	28300.00
A57A8B	2017-07-23 15:30:00+03	20000.00
A57AED	2017-07-03 07:38:00+03	89600.00
A57B40	2017-07-13 20:13:00+03	41600.00
A57BAF	2017-08-04 00:51:00+03	14400.00
A57BCE	2017-07-07 06:02:00+03	56000.00
A57BE1	2017-08-03 07:59:00+03	31600.00
A57C30	2017-07-27 20:44:00+03	101000.00
A57C32	2017-07-20 02:59:00+03	193900.00
A57C3C	2017-08-09 20:36:00+03	197700.00
A57C5F	2017-07-15 02:02:00+03	42700.00
A57C7D	2017-07-19 22:50:00+03	384800.00
A57D11	2017-08-11 10:39:00+03	531400.00
A57DAC	2017-08-11 14:51:00+03	32200.00
A57DC1	2017-08-05 20:00:00+03	86500.00
A57DCC	2017-08-14 12:18:00+03	237500.00
A57E40	2017-07-06 23:18:00+03	112000.00
A57E99	2017-08-05 18:25:00+03	143100.00
A57ED1	2017-07-04 00:35:00+03	20200.00
A57FBE	2017-06-29 04:20:00+03	28000.00
A5805D	2017-08-01 13:25:00+03	57800.00
A580E1	2017-07-16 07:02:00+03	58600.00
A5812C	2017-07-06 03:01:00+03	36200.00
A581AA	2017-08-10 16:26:00+03	147200.00
A58236	2017-08-14 16:59:00+03	13600.00
A58248	2017-07-06 22:01:00+03	48400.00
A582B3	2017-07-29 08:10:00+03	43600.00
A58326	2017-08-14 15:48:00+03	48700.00
A5834E	2017-07-26 12:30:00+03	110500.00
A5838B	2017-08-11 17:03:00+03	35700.00
A583F8	2017-08-06 13:26:00+03	93600.00
A58412	2017-07-26 22:20:00+03	40400.00
A58418	2017-08-13 23:13:00+03	186900.00
A58459	2017-07-22 06:07:00+03	117600.00
A584D6	2017-07-22 03:41:00+03	36200.00
A58543	2017-08-03 08:36:00+03	18100.00
A5854E	2017-06-30 16:05:00+03	81300.00
A58567	2017-07-24 02:50:00+03	96400.00
A58574	2017-08-07 10:28:00+03	56000.00
A58585	2017-07-18 20:26:00+03	123600.00
A585BB	2017-07-01 12:49:00+03	94300.00
A585DE	2017-07-26 21:16:00+03	30200.00
A5863B	2017-07-12 04:26:00+03	100600.00
A58659	2017-08-08 10:28:00+03	83000.00
A5873A	2017-07-10 07:33:00+03	28300.00
A5876C	2017-07-19 22:04:00+03	112000.00
A5880A	2017-07-22 17:51:00+03	133100.00
A5881C	2017-06-30 19:12:00+03	28000.00
A588AB	2017-07-07 07:19:00+03	219300.00
A588E9	2017-07-02 15:00:00+03	44000.00
A58910	2017-07-26 12:00:00+03	14000.00
A58967	2017-07-25 16:55:00+03	119400.00
A58998	2017-08-10 07:06:00+03	61800.00
A589B3	2017-07-04 11:52:00+03	28000.00
A58A1E	2017-07-20 16:59:00+03	40200.00
A58A35	2017-07-24 00:57:00+03	124200.00
A58A39	2017-07-23 10:35:00+03	37200.00
A58A43	2017-08-14 17:32:00+03	406700.00
A58A46	2017-07-01 16:52:00+03	116800.00
A58A86	2017-08-03 22:53:00+03	131100.00
A58ADF	2017-08-01 14:42:00+03	86800.00
A58AE4	2017-07-01 22:14:00+03	185500.00
A58B77	2017-07-13 19:13:00+03	66800.00
A58BCF	2017-07-06 02:23:00+03	25400.00
A58C0C	2017-07-25 05:28:00+03	33100.00
A58C6F	2017-08-02 18:25:00+03	78300.00
A58CD5	2017-07-10 04:45:00+03	56000.00
A58DB5	2017-07-01 19:47:00+03	94000.00
A58E27	2017-07-07 08:58:00+03	47500.00
A58E68	2017-07-11 10:35:00+03	23600.00
A58EDF	2017-08-12 03:16:00+03	207200.00
A58F06	2017-07-18 20:13:00+03	32700.00
A58FA1	2017-07-18 05:56:00+03	62600.00
A5904B	2017-07-15 08:47:00+03	708600.00
A59057	2017-07-17 03:31:00+03	119800.00
A590A9	2017-07-07 17:11:00+03	50000.00
A590AB	2017-07-18 16:47:00+03	24700.00
A590FA	2017-08-10 15:47:00+03	231300.00
A59169	2017-07-27 14:33:00+03	40000.00
A591AD	2017-08-05 11:08:00+03	147800.00
A591B0	2017-08-09 07:36:00+03	27900.00
A59259	2017-07-01 17:37:00+03	22200.00
A5931D	2017-07-31 17:17:00+03	26000.00
A59374	2017-08-13 14:40:00+03	21400.00
A593F1	2017-07-24 21:22:00+03	40100.00
A59416	2017-08-09 06:46:00+03	115500.00
A5944D	2017-08-06 03:29:00+03	6600.00
A59471	2017-08-03 06:48:00+03	29600.00
A59491	2017-07-19 08:12:00+03	47200.00
A594B0	2017-08-08 12:36:00+03	94800.00
A594B8	2017-07-31 04:38:00+03	43500.00
A594CD	2017-08-06 08:46:00+03	98000.00
A5957F	2017-08-09 11:40:00+03	37200.00
A595E0	2017-08-10 00:01:00+03	43200.00
A595FE	2017-08-10 01:39:00+03	52700.00
A59616	2017-07-23 03:26:00+03	46800.00
A5968B	2017-07-30 22:51:00+03	26500.00
A596B7	2017-08-10 20:51:00+03	399600.00
A596C2	2017-07-18 08:14:00+03	131800.00
A59712	2017-07-20 22:17:00+03	24800.00
A5973C	2017-08-05 12:26:00+03	39300.00
A59752	2017-07-15 10:19:00+03	58000.00
A59766	2017-08-02 18:45:00+03	189800.00
A5976B	2017-07-05 23:16:00+03	12000.00
A5981B	2017-07-15 21:15:00+03	64600.00
A59870	2017-08-01 04:57:00+03	148200.00
A59882	2017-08-06 04:48:00+03	27900.00
A598EF	2017-08-07 13:19:00+03	85800.00
A59912	2017-07-17 13:46:00+03	22000.00
A599A4	2017-08-10 11:03:00+03	213200.00
A599F7	2017-07-05 05:24:00+03	16400.00
A59A14	2017-07-27 09:29:00+03	64400.00
A59A1F	2017-07-05 03:12:00+03	111600.00
A59A46	2017-08-01 16:35:00+03	85000.00
A59A9F	2017-07-17 19:37:00+03	59800.00
A59AA8	2017-08-07 14:58:00+03	54100.00
A59B6B	2017-07-15 14:19:00+03	3700.00
A59B78	2017-07-25 16:01:00+03	46400.00
A59BC8	2017-07-08 22:07:00+03	13000.00
A59BDE	2017-08-06 16:55:00+03	40400.00
A59BFC	2017-07-28 06:59:00+03	47100.00
A59C05	2017-08-04 06:00:00+03	52300.00
A59C08	2017-07-02 22:44:00+03	236900.00
A59C75	2017-08-10 05:14:00+03	81300.00
A59C80	2017-07-25 02:34:00+03	27200.00
A59CEC	2017-07-23 22:09:00+03	530100.00
A59D36	2017-07-14 18:22:00+03	114800.00
A59D39	2017-08-04 01:26:00+03	93900.00
A59D40	2017-07-17 20:21:00+03	108600.00
A59DA4	2017-07-07 08:20:00+03	123000.00
A59DD6	2017-08-08 14:35:00+03	65900.00
A59E22	2017-08-02 16:42:00+03	15000.00
A59E8E	2017-07-20 05:32:00+03	47600.00
A59EBB	2017-07-13 10:17:00+03	149500.00
A59F1C	2017-06-30 02:48:00+03	44400.00
A59F25	2017-08-03 07:12:00+03	148200.00
A59F53	2017-07-08 13:27:00+03	53000.00
A5A001	2017-07-08 06:30:00+03	29800.00
A5A00C	2017-08-13 11:02:00+03	111600.00
A5A03C	2017-08-02 16:29:00+03	38600.00
A5A08C	2017-07-07 02:41:00+03	67600.00
A5A18A	2017-07-16 02:35:00+03	6800.00
A5A196	2017-07-23 17:14:00+03	37700.00
A5A1CB	2017-08-11 05:30:00+03	28800.00
A5A1E6	2017-07-27 04:03:00+03	56000.00
A5A1F7	2017-08-01 16:39:00+03	58200.00
A5A26F	2017-07-28 10:44:00+03	92000.00
A5A2EF	2017-07-11 12:10:00+03	26000.00
A5A30A	2017-08-05 11:39:00+03	89600.00
A5A314	2017-07-26 17:36:00+03	174600.00
A5A34B	2017-07-15 01:51:00+03	25200.00
A5A34D	2017-07-10 10:44:00+03	35400.00
A5A36C	2017-07-27 09:12:00+03	70700.00
A5A37E	2017-07-30 22:02:00+03	184500.00
A5A3E0	2017-07-16 05:08:00+03	90000.00
A5A3E4	2017-08-13 09:22:00+03	11300.00
A5A3F8	2017-07-24 02:22:00+03	155500.00
A5A47F	2017-08-11 07:08:00+03	34000.00
A5A494	2017-08-14 14:35:00+03	77200.00
A5A495	2017-08-14 08:27:00+03	46200.00
A5A4E2	2017-08-05 16:30:00+03	106400.00
A5A4F8	2017-07-13 14:26:00+03	10800.00
A5A527	2017-08-12 12:58:00+03	95700.00
A5A5C4	2017-08-13 07:18:00+03	222800.00
A5A5D8	2017-07-24 05:01:00+03	54500.00
A5A614	2017-07-07 04:09:00+03	6000.00
A5A631	2017-08-10 10:23:00+03	25600.00
A5A63A	2017-07-26 22:43:00+03	172100.00
A5A641	2017-07-12 14:07:00+03	93600.00
A5A65C	2017-07-31 10:50:00+03	24400.00
A5A69B	2017-06-30 23:06:00+03	65400.00
A5A6D0	2017-07-26 05:02:00+03	20400.00
A5A774	2017-07-23 19:12:00+03	199700.00
A5A7BF	2017-07-30 13:26:00+03	13400.00
A5A7E1	2017-07-16 03:12:00+03	55800.00
A5A7EF	2017-08-01 21:17:00+03	34000.00
A5A85B	2017-08-06 15:15:00+03	133200.00
A5A91A	2017-07-08 07:33:00+03	31400.00
A5A93B	2017-07-19 21:15:00+03	80500.00
A5AA16	2017-07-16 17:46:00+03	80300.00
A5AA4B	2017-07-31 01:54:00+03	79700.00
A5AA51	2017-07-15 22:07:00+03	116900.00
A5AA52	2017-07-15 13:12:00+03	105600.00
A5AA91	2017-07-03 10:15:00+03	103500.00
A5AA95	2017-08-11 16:58:00+03	21800.00
A5AAB9	2017-08-08 11:08:00+03	125400.00
A5AAD1	2017-07-12 05:10:00+03	30400.00
A5AAD5	2017-08-10 10:38:00+03	104000.00
A5AAFA	2017-07-06 12:52:00+03	23200.00
A5AB1E	2017-07-07 11:29:00+03	108600.00
A5AB9F	2017-07-06 04:03:00+03	92000.00
A5ABCC	2017-07-30 05:05:00+03	18000.00
A5AC03	2017-08-09 02:36:00+03	290400.00
A5AC13	2017-08-01 09:18:00+03	111600.00
A5AC1C	2017-07-31 22:26:00+03	70400.00
A5AC24	2017-07-22 02:15:00+03	31200.00
A5AC28	2017-08-13 10:07:00+03	265800.00
A5AC42	2017-08-09 17:16:00+03	28000.00
A5ACC1	2017-07-13 19:56:00+03	58000.00
A5AD6D	2017-08-09 10:47:00+03	49600.00
A5AEB2	2017-07-03 21:33:00+03	168700.00
A5AEE5	2017-08-09 02:52:00+03	82900.00
A5AFA5	2017-08-13 02:39:00+03	37100.00
A5AFDB	2017-07-21 19:48:00+03	31800.00
A5B00D	2017-07-10 22:09:00+03	35800.00
A5B099	2017-07-12 08:08:00+03	55800.00
A5B184	2017-08-08 16:31:00+03	98400.00
A5B1C1	2017-07-16 00:05:00+03	193600.00
A5B1DA	2017-08-02 16:28:00+03	75300.00
A5B204	2017-07-04 02:24:00+03	39100.00
A5B261	2017-07-11 17:03:00+03	114000.00
A5B26F	2017-07-15 09:35:00+03	56100.00
A5B271	2017-07-25 06:41:00+03	28000.00
A5B298	2017-07-25 07:28:00+03	14000.00
A5B2D4	2017-07-07 08:28:00+03	136800.00
A5B2F4	2017-07-13 03:41:00+03	21600.00
A5B304	2017-07-30 08:58:00+03	51900.00
A5B33E	2017-07-25 05:06:00+03	23600.00
A5B378	2017-07-05 06:13:00+03	75300.00
A5B37C	2017-08-06 14:03:00+03	56600.00
A5B382	2017-06-30 18:11:00+03	16400.00
A5B52B	2017-06-27 04:54:00+03	154800.00
A5B535	2017-07-31 21:18:00+03	6700.00
A5B540	2017-07-16 08:27:00+03	55500.00
A5B609	2017-07-18 00:54:00+03	135400.00
A5B6B0	2017-08-11 17:45:00+03	29600.00
A5B711	2017-08-13 12:29:00+03	397100.00
A5B71B	2017-08-03 02:48:00+03	58000.00
A5B71D	2017-07-07 10:43:00+03	19000.00
A5B7BE	2017-07-18 23:29:00+03	80400.00
A5B8E6	2017-07-21 02:26:00+03	28000.00
A5B91B	2017-07-18 07:20:00+03	56000.00
A5B92E	2017-08-12 04:52:00+03	7400.00
A5B939	2017-08-09 12:54:00+03	224000.00
A5B96B	2017-07-16 13:24:00+03	85000.00
A5B9B3	2017-07-05 04:46:00+03	48800.00
A5BA57	2017-07-15 18:59:00+03	62600.00
A5BA7F	2017-07-09 06:40:00+03	44000.00
A5BA94	2017-07-20 14:50:00+03	46400.00
A5BAEA	2017-07-24 22:45:00+03	202100.00
A5BB0D	2017-08-13 03:38:00+03	57600.00
A5BB39	2017-07-09 19:21:00+03	13200.00
A5BB51	2017-06-29 11:51:00+03	105400.00
A5BB5E	2017-07-07 00:12:00+03	18600.00
A5BB93	2017-08-04 09:25:00+03	88800.00
A5BBA2	2017-07-23 19:37:00+03	51600.00
A5BBFA	2017-07-28 09:30:00+03	57500.00
A5BC5F	2017-08-14 05:53:00+03	28800.00
A5BC8A	2017-08-07 05:00:00+03	17800.00
A5BCAB	2017-07-16 01:11:00+03	28000.00
A5BCD6	2017-08-03 02:59:00+03	44800.00
A5BCDF	2017-07-16 11:11:00+03	117600.00
A5BD27	2017-07-27 03:30:00+03	143600.00
A5BD94	2017-07-06 07:33:00+03	59200.00
A5BDEB	2017-08-04 17:29:00+03	79600.00
A5BDEF	2017-08-11 11:05:00+03	89700.00
A5BDF2	2017-07-31 05:17:00+03	51800.00
A5BDFC	2017-07-20 15:47:00+03	8000.00
A5BE4E	2017-07-11 17:29:00+03	53100.00
A5BEFE	2017-07-17 04:02:00+03	65500.00
A5BF02	2017-07-08 16:49:00+03	67000.00
A5C0AD	2017-07-08 08:02:00+03	17000.00
A5C125	2017-07-29 01:55:00+03	47000.00
A5C178	2017-07-11 03:12:00+03	28000.00
A5C18E	2017-07-06 13:53:00+03	133100.00
A5C1C4	2017-08-07 15:33:00+03	26000.00
A5C211	2017-07-30 06:45:00+03	148200.00
A5C213	2017-08-07 01:56:00+03	160000.00
A5C221	2017-07-23 07:09:00+03	38200.00
A5C23B	2017-08-14 09:26:00+03	79900.00
A5C282	2017-07-15 06:03:00+03	28000.00
A5C289	2017-06-30 06:14:00+03	15000.00
A5C3DA	2017-07-07 23:20:00+03	20800.00
A5C490	2017-07-27 01:59:00+03	44100.00
A5C4CF	2017-07-15 09:57:00+03	11000.00
A5C4F5	2017-07-10 09:02:00+03	318000.00
A5C52C	2017-08-05 23:08:00+03	51900.00
A5C5B0	2017-08-08 21:52:00+03	9200.00
A5C631	2017-08-13 05:31:00+03	16100.00
A5C6DC	2017-06-28 22:54:00+03	56100.00
A5C70F	2017-07-06 15:48:00+03	53300.00
A5C74F	2017-08-08 01:52:00+03	13600.00
A5C789	2017-08-12 01:08:00+03	67700.00
A5C817	2017-07-06 09:34:00+03	56000.00
A5C8DC	2017-08-04 01:52:00+03	44600.00
A5C92E	2017-08-06 07:15:00+03	28800.00
A5C947	2017-08-06 15:51:00+03	115900.00
A5C98E	2017-08-11 14:39:00+03	36500.00
A5C9A8	2017-06-30 10:29:00+03	153300.00
A5CA2D	2017-07-13 09:19:00+03	18000.00
A5CA3D	2017-07-11 17:16:00+03	59300.00
A5CA69	2017-07-30 00:56:00+03	61800.00
A5CA79	2017-07-22 20:52:00+03	79600.00
A5CA86	2017-08-11 11:07:00+03	24400.00
A5CAC1	2017-07-28 13:26:00+03	33800.00
A5CAC8	2017-08-01 02:41:00+03	145100.00
A5CAD9	2017-08-02 14:13:00+03	44500.00
A5CB3E	2017-07-10 22:43:00+03	170700.00
A5CBD9	2017-07-06 13:19:00+03	24400.00
A5CC5F	2017-08-11 23:22:00+03	131600.00
A5CC60	2017-08-11 00:05:00+03	201800.00
A5CCFE	2017-08-04 22:34:00+03	29600.00
A5CD55	2017-07-29 11:05:00+03	62100.00
A5CD79	2017-07-27 12:19:00+03	38600.00
A5CDF4	2017-07-26 03:16:00+03	234700.00
A5CDF9	2017-07-06 23:47:00+03	43100.00
A5CE94	2017-08-03 13:34:00+03	13800.00
A5CEAA	2017-07-02 01:54:00+03	113700.00
A5CEAB	2017-07-28 15:29:00+03	23600.00
A5CF09	2017-07-30 21:07:00+03	177600.00
A5CF53	2017-07-03 23:38:00+03	13600.00
A5CFF9	2017-07-30 01:26:00+03	137700.00
A5D03C	2017-07-09 06:59:00+03	35500.00
A5D113	2017-07-03 08:35:00+03	46800.00
A5D122	2017-06-27 06:12:00+03	54400.00
A5D16B	2017-07-19 05:02:00+03	24400.00
A5D1BF	2017-08-12 02:05:00+03	22600.00
A5D1C1	2017-07-12 02:38:00+03	172400.00
A5D230	2017-07-21 23:59:00+03	43600.00
A5D2F1	2017-08-14 10:03:00+03	154500.00
A5D362	2017-07-11 20:15:00+03	156300.00
A5D39D	2017-07-15 04:09:00+03	113700.00
A5D3BC	2017-07-14 06:17:00+03	213200.00
A5D3E0	2017-07-20 16:00:00+03	31100.00
A5D3ED	2017-07-26 17:14:00+03	189200.00
A5D457	2017-07-06 10:23:00+03	31600.00
A5D460	2017-07-11 09:34:00+03	18600.00
A5D4DA	2017-07-30 03:30:00+03	49200.00
A5D69E	2017-08-11 08:01:00+03	13400.00
A5D6DA	2017-08-06 23:55:00+03	21800.00
A5D6E1	2017-08-04 13:39:00+03	58600.00
A5D6F8	2017-07-04 22:19:00+03	188800.00
A5D6FB	2017-07-16 09:42:00+03	40000.00
A5D783	2017-08-14 10:24:00+03	17200.00
A5D7EB	2017-07-22 10:53:00+03	6200.00
A5D7EC	2017-07-15 00:51:00+03	75600.00
A5D81F	2017-07-11 05:57:00+03	57400.00
A5D891	2017-08-01 19:33:00+03	204900.00
A5D8F7	2017-07-29 17:21:00+03	111600.00
A5D904	2017-07-23 17:44:00+03	32800.00
A5D9A1	2017-07-09 23:44:00+03	111700.00
A5D9AE	2017-07-08 20:01:00+03	193600.00
A5D9CD	2017-07-24 12:45:00+03	44600.00
A5D9D0	2017-08-04 20:53:00+03	32200.00
A5DA22	2017-08-11 06:25:00+03	56600.00
A5DA95	2017-07-30 10:55:00+03	14400.00
A5DADE	2017-07-07 05:04:00+03	12600.00
A5DAE0	2017-07-11 17:13:00+03	46400.00
A5DB1D	2017-08-09 03:55:00+03	50000.00
A5DB7B	2017-07-10 14:20:00+03	29400.00
A5DC62	2017-08-12 06:30:00+03	33300.00
A5DC7F	2017-08-15 01:22:00+03	24300.00
A5DCD2	2017-08-05 19:33:00+03	55600.00
A5DD8F	2017-07-30 21:05:00+03	15000.00
A5DD9A	2017-07-09 03:59:00+03	186900.00
A5DE22	2017-07-15 16:11:00+03	103900.00
A5DEB6	2017-07-13 01:53:00+03	26000.00
A5DECB	2017-08-03 02:17:00+03	94000.00
A5DEE5	2017-08-13 16:49:00+03	369000.00
A5DF71	2017-07-21 18:27:00+03	88600.00
A5DFAA	2017-07-22 10:34:00+03	115700.00
A5DFC1	2017-08-15 04:43:00+03	6700.00
A5E01E	2017-07-17 13:21:00+03	73000.00
A5E04C	2017-07-13 22:19:00+03	86800.00
A5E050	2017-07-29 21:50:00+03	398500.00
A5E07B	2017-07-05 23:43:00+03	52000.00
A5E091	2017-07-02 17:14:00+03	88000.00
A5E0D1	2017-08-11 06:05:00+03	83100.00
A5E0F8	2017-07-16 04:51:00+03	86500.00
A5E180	2017-08-12 01:10:00+03	266400.00
A5E18A	2017-07-07 16:09:00+03	23600.00
A5E1CB	2017-08-01 20:19:00+03	279800.00
A5E1FF	2017-08-04 07:56:00+03	11700.00
A5E254	2017-07-04 09:23:00+03	380700.00
A5E29F	2017-07-26 11:08:00+03	37100.00
A5E2AA	2017-07-09 21:00:00+03	295400.00
A5E303	2017-06-29 08:16:00+03	13400.00
A5E329	2017-08-04 17:51:00+03	58000.00
A5E357	2017-08-14 03:01:00+03	302400.00
A5E3FC	2017-08-01 20:37:00+03	85000.00
A5E442	2017-08-07 00:40:00+03	62600.00
A5E496	2017-07-29 08:04:00+03	48800.00
A5E4A6	2017-08-07 21:47:00+03	13200.00
A5E4FF	2017-07-12 13:13:00+03	285800.00
A5E52D	2017-07-01 02:41:00+03	111000.00
A5E59D	2017-07-15 15:15:00+03	136400.00
A5E5F9	2017-07-05 06:38:00+03	24400.00
A5E645	2017-07-31 17:56:00+03	47500.00
A5E655	2017-08-11 20:58:00+03	6000.00
A5E658	2017-07-06 13:23:00+03	31600.00
A5E668	2017-07-29 02:48:00+03	64100.00
A5E712	2017-07-28 18:32:00+03	117500.00
A5E716	2017-08-08 15:32:00+03	94700.00
A5E736	2017-07-19 16:06:00+03	28000.00
A5E796	2017-07-02 07:06:00+03	39300.00
A5E7A8	2017-07-21 01:28:00+03	38200.00
A5E7D7	2017-07-11 07:52:00+03	29500.00
A5E850	2017-07-03 08:48:00+03	191200.00
A5E86D	2017-07-24 04:24:00+03	71200.00
A5E8B2	2017-08-03 09:54:00+03	46300.00
A5E8B3	2017-08-11 19:23:00+03	67600.00
A5E925	2017-07-02 04:53:00+03	29600.00
A5E9A1	2017-08-02 20:39:00+03	133100.00
A5E9A2	2017-07-14 20:49:00+03	375200.00
A5EA0E	2017-07-27 11:09:00+03	12600.00
A5EA96	2017-07-16 11:59:00+03	24000.00
A5EA9F	2017-07-15 15:10:00+03	13200.00
A5EAE7	2017-08-01 00:02:00+03	124200.00
A5EB6E	2017-07-18 11:55:00+03	18600.00
A5EC03	2017-07-25 11:18:00+03	98400.00
A5EC3F	2017-07-03 00:18:00+03	41800.00
A5EC8C	2017-08-07 12:57:00+03	6700.00
A5ECCA	2017-08-07 14:40:00+03	68800.00
A5ED37	2017-07-26 13:42:00+03	6700.00
A5EDE3	2017-08-01 13:25:00+03	28300.00
A5EE12	2017-07-29 19:01:00+03	65900.00
A5EE61	2017-07-23 17:13:00+03	105100.00
A5EE97	2017-07-30 23:07:00+03	9200.00
A5EECF	2017-08-15 03:46:00+03	29600.00
A5EEE2	2017-07-12 05:10:00+03	124200.00
A5EEFE	2017-08-14 05:03:00+03	396500.00
A5EF06	2017-08-13 11:42:00+03	168000.00
A5EF21	2017-07-31 01:25:00+03	47100.00
A5EF4E	2017-08-08 19:57:00+03	156600.00
A5EF7E	2017-08-13 02:52:00+03	57700.00
A5EFE0	2017-08-01 20:36:00+03	51300.00
A5EFE9	2017-07-11 00:48:00+03	26000.00
A5F05E	2017-07-31 12:25:00+03	77600.00
A5F0B4	2017-08-13 06:14:00+03	149200.00
A5F14B	2017-07-12 07:36:00+03	62600.00
A5F177	2017-08-08 16:35:00+03	47100.00
A5F194	2017-07-11 08:33:00+03	112000.00
A5F20C	2017-07-31 19:06:00+03	129200.00
A5F25D	2017-07-16 11:32:00+03	18600.00
A5F25E	2017-07-31 13:17:00+03	63300.00
A5F2B8	2017-07-04 07:50:00+03	44800.00
A5F2DC	2017-07-14 06:58:00+03	25600.00
A5F37A	2017-07-18 20:39:00+03	68400.00
A5F3DF	2017-06-27 02:18:00+03	67100.00
A5F455	2017-08-06 09:12:00+03	75600.00
A5F4AB	2017-07-21 06:23:00+03	179600.00
A5F4CD	2017-08-08 21:42:00+03	22600.00
A5F4EB	2017-07-15 12:48:00+03	40800.00
A5F4F0	2017-07-26 05:31:00+03	17200.00
A5F50F	2017-07-28 16:30:00+03	105100.00
A5F59D	2017-07-20 11:10:00+03	18600.00
A5F66F	2017-07-14 04:28:00+03	26800.00
A5F6C5	2017-06-29 07:23:00+03	369000.00
A5F757	2017-07-09 08:50:00+03	100300.00
A5F7E4	2017-07-11 04:44:00+03	260300.00
A5F847	2017-07-31 23:02:00+03	60400.00
A5F8B7	2017-07-27 11:44:00+03	57600.00
A5F90D	2017-07-21 23:38:00+03	22800.00
A5FA86	2017-07-16 00:32:00+03	49400.00
A5FAA2	2017-07-22 02:29:00+03	89700.00
A5FACC	2017-07-11 00:34:00+03	28800.00
A5FB03	2017-07-24 03:05:00+03	55800.00
A5FB7C	2017-07-11 10:42:00+03	112000.00
A5FB84	2017-07-06 16:03:00+03	53600.00
A5FB8A	2017-08-06 22:31:00+03	83000.00
A5FBE3	2017-07-10 09:54:00+03	236300.00
A5FC16	2017-08-11 23:48:00+03	52800.00
A5FC1E	2017-08-06 17:52:00+03	48300.00
A5FC46	2017-07-26 02:23:00+03	48400.00
A5FC5D	2017-07-14 22:48:00+03	195900.00
A5FCAC	2017-08-02 06:34:00+03	12400.00
A5FD0C	2017-06-29 23:09:00+03	25600.00
A5FD0D	2017-08-10 09:58:00+03	413400.00
A5FD73	2017-08-07 22:19:00+03	29600.00
A5FDCF	2017-07-08 11:56:00+03	56000.00
A5FE0B	2017-07-08 00:54:00+03	58600.00
A5FE32	2017-07-10 13:47:00+03	65500.00
A5FEBC	2017-07-27 13:39:00+03	8000.00
A5FEFC	2017-07-09 20:14:00+03	105900.00
A5FF04	2017-07-25 15:59:00+03	19600.00
A5FF4C	2017-08-13 19:37:00+03	15900.00
A5FF57	2017-08-11 12:51:00+03	131600.00
A5FFC6	2017-07-13 02:41:00+03	339800.00
A60039	2017-06-24 08:02:00+03	35200.00
A6012F	2017-08-14 19:18:00+03	30200.00
A601C9	2017-07-28 23:24:00+03	46400.00
A60256	2017-07-02 14:10:00+03	16400.00
A60273	2017-07-06 15:32:00+03	99200.00
A602F5	2017-07-15 19:30:00+03	44700.00
A60354	2017-07-08 22:13:00+03	41600.00
A6037C	2017-07-12 13:45:00+03	136800.00
A603EF	2017-07-27 11:26:00+03	53600.00
A60426	2017-08-08 15:03:00+03	143200.00
A6049A	2017-08-12 18:24:00+03	25200.00
A604B6	2017-07-13 03:54:00+03	66600.00
A604C4	2017-08-14 06:38:00+03	60200.00
A60506	2017-07-06 13:17:00+03	99200.00
A6058E	2017-07-28 09:54:00+03	65900.00
A605D0	2017-07-03 09:25:00+03	19600.00
A605DB	2017-07-08 00:00:00+03	83300.00
A605FC	2017-07-10 03:08:00+03	44400.00
A60622	2017-07-27 01:01:00+03	23200.00
A60653	2017-08-04 03:47:00+03	46500.00
A60689	2017-07-09 08:34:00+03	214900.00
A6069D	2017-08-10 13:06:00+03	112000.00
A606BE	2017-07-20 15:29:00+03	51900.00
A606D8	2017-07-19 19:49:00+03	34800.00
A606E3	2017-07-05 14:21:00+03	131600.00
A6075F	2017-07-03 01:12:00+03	152900.00
A607A2	2017-07-12 00:47:00+03	69000.00
A607C7	2017-07-02 19:13:00+03	282600.00
A60805	2017-07-22 16:48:00+03	68600.00
A608BC	2017-08-10 13:37:00+03	26200.00
A608C2	2017-07-21 07:07:00+03	37900.00
A608C3	2017-08-03 12:04:00+03	8000.00
A60907	2017-07-06 03:07:00+03	32700.00
A6095E	2017-08-05 21:58:00+03	92800.00
A60972	2017-06-28 00:50:00+03	39200.00
A609B2	2017-07-08 18:46:00+03	46400.00
A609CA	2017-08-12 20:43:00+03	258400.00
A60A42	2017-07-02 22:59:00+03	22100.00
A60A43	2017-07-26 17:10:00+03	113500.00
A60A5D	2017-08-09 10:06:00+03	206400.00
A60A79	2017-07-10 06:13:00+03	68400.00
A60A80	2017-07-22 03:03:00+03	16400.00
A60ABB	2017-08-06 20:16:00+03	37200.00
A60AF0	2017-07-17 20:07:00+03	398500.00
A60B2F	2017-07-09 12:22:00+03	80000.00
A60BF7	2017-08-14 03:33:00+03	26000.00
A60CAE	2017-07-24 06:43:00+03	56600.00
A60D25	2017-07-08 07:56:00+03	123000.00
A60D50	2017-08-06 07:15:00+03	101100.00
A60D83	2017-07-23 13:40:00+03	23200.00
A60D8F	2017-07-29 20:48:00+03	46200.00
A60E2C	2017-08-03 22:29:00+03	68900.00
A60E3E	2017-07-19 07:12:00+03	40800.00
A60ED8	2017-07-21 13:26:00+03	242000.00
A60EEA	2017-08-07 00:27:00+03	73500.00
A60F1B	2017-07-18 18:04:00+03	248300.00
A60F30	2017-07-11 13:17:00+03	75300.00
A60F40	2017-07-27 05:47:00+03	12600.00
A60F56	2017-08-14 19:12:00+03	137700.00
A60F68	2017-07-14 09:39:00+03	39500.00
A60F9D	2017-08-03 23:04:00+03	90300.00
A60FB8	2017-07-26 09:42:00+03	21500.00
A61012	2017-07-30 02:33:00+03	39300.00
A61065	2017-08-06 23:45:00+03	81800.00
A61076	2017-08-05 10:14:00+03	6800.00
A61083	2017-08-07 05:34:00+03	59800.00
A6109F	2017-08-10 04:00:00+03	35200.00
A61108	2017-07-20 07:47:00+03	71200.00
A61189	2017-08-08 23:43:00+03	71900.00
A611A5	2017-07-03 17:51:00+03	39600.00
A611F4	2017-07-28 19:37:00+03	67200.00
A611F9	2017-07-20 16:22:00+03	15100.00
A611FC	2017-08-15 12:45:00+03	27900.00
A61223	2017-07-27 07:34:00+03	168000.00
A6131F	2017-08-13 20:00:00+03	10800.00
A6134C	2017-07-28 02:22:00+03	37900.00
A61399	2017-08-02 05:25:00+03	129800.00
A6140F	2017-07-18 00:15:00+03	42400.00
A61449	2017-07-05 01:11:00+03	112000.00
A61474	2017-07-23 23:41:00+03	23200.00
A614AF	2017-07-09 11:59:00+03	15400.00
A614F5	2017-08-02 05:04:00+03	58200.00
A614FF	2017-08-13 12:53:00+03	39800.00
A6152C	2017-07-11 15:59:00+03	148200.00
A6157F	2017-06-30 14:03:00+03	40800.00
A61593	2017-07-28 06:15:00+03	247300.00
A61595	2017-08-12 07:06:00+03	28800.00
A61597	2017-07-21 15:30:00+03	116500.00
A61598	2017-07-12 11:36:00+03	65900.00
A615DC	2017-07-17 21:55:00+03	58200.00
A615DF	2017-08-14 13:55:00+03	82300.00
A615EF	2017-07-02 01:53:00+03	48800.00
A615F7	2017-08-14 06:13:00+03	86300.00
A615FD	2017-08-08 21:48:00+03	40300.00
A616F6	2017-08-10 10:55:00+03	54000.00
A61756	2017-07-26 01:33:00+03	38600.00
A6176A	2017-08-06 11:34:00+03	34700.00
A617AB	2017-08-09 07:40:00+03	61800.00
A6184F	2017-07-07 00:48:00+03	40000.00
A61861	2017-06-30 21:39:00+03	69500.00
A6187A	2017-07-20 21:36:00+03	101500.00
A618A8	2017-07-19 01:14:00+03	135400.00
A618BC	2017-08-02 01:46:00+03	45400.00
A618C7	2017-07-25 17:33:00+03	408500.00
A618FC	2017-07-07 09:56:00+03	283100.00
A61961	2017-07-21 04:44:00+03	118000.00
A6196E	2017-07-31 21:52:00+03	13600.00
A61972	2017-08-15 12:59:00+03	50800.00
A61989	2017-07-11 21:08:00+03	135100.00
A619A9	2017-08-07 22:43:00+03	69000.00
A619BC	2017-07-21 04:35:00+03	174000.00
A619E6	2017-07-22 11:41:00+03	17000.00
A61A7E	2017-07-28 07:39:00+03	60400.00
A61A88	2017-07-13 03:52:00+03	15100.00
A61ABA	2017-07-29 01:41:00+03	43200.00
A61AFB	2017-08-03 04:04:00+03	36800.00
A61B42	2017-08-15 09:08:00+03	18000.00
A61C18	2017-07-06 01:21:00+03	67900.00
A61CA1	2017-08-08 23:17:00+03	103200.00
A61D84	2017-07-22 04:23:00+03	36200.00
A61DE7	2017-07-14 16:55:00+03	14400.00
A61E07	2017-07-10 13:59:00+03	73600.00
A61E12	2017-07-15 08:30:00+03	101100.00
A61E2C	2017-08-08 11:29:00+03	13400.00
A61E7A	2017-07-07 07:16:00+03	61800.00
A61E8F	2017-08-14 18:56:00+03	63700.00
A61EA9	2017-08-11 02:47:00+03	96200.00
A61EC1	2017-07-11 23:07:00+03	43200.00
A61ED7	2017-08-12 07:52:00+03	134800.00
A61EEE	2017-07-21 18:44:00+03	75300.00
A61F8C	2017-07-04 03:36:00+03	27300.00
A61FCD	2017-07-12 16:18:00+03	377100.00
A61FD1	2017-08-10 18:12:00+03	37600.00
A62001	2017-07-17 23:08:00+03	492000.00
A6202E	2017-07-03 08:43:00+03	120100.00
A6206B	2017-08-09 22:12:00+03	172600.00
A62074	2017-07-18 13:29:00+03	184900.00
A620D3	2017-07-15 23:24:00+03	27200.00
A62142	2017-07-11 00:40:00+03	56600.00
A62143	2017-08-13 06:43:00+03	59400.00
A62162	2017-07-13 14:44:00+03	34000.00
A62187	2017-07-08 04:50:00+03	63200.00
A621F0	2017-07-18 10:29:00+03	94000.00
A62262	2017-08-01 22:30:00+03	52000.00
A62282	2017-08-09 18:44:00+03	29200.00
A6230B	2017-07-13 22:58:00+03	55800.00
A62369	2017-08-01 02:39:00+03	781100.00
A62378	2017-07-16 00:28:00+03	30200.00
A623AD	2017-07-07 06:07:00+03	12400.00
A62418	2017-08-13 21:04:00+03	26000.00
A62430	2017-08-02 13:13:00+03	22600.00
A62468	2017-07-24 18:50:00+03	23200.00
A62469	2017-07-16 04:33:00+03	47000.00
A6246A	2017-07-24 20:24:00+03	24400.00
A6249F	2017-07-27 03:43:00+03	54300.00
A624C9	2017-07-06 16:54:00+03	92200.00
A62518	2017-08-03 18:47:00+03	29600.00
A62519	2017-07-17 03:22:00+03	61800.00
A62575	2017-07-20 14:15:00+03	56000.00
A625D4	2017-07-19 12:28:00+03	43200.00
A625E4	2017-07-10 06:04:00+03	68400.00
A62686	2017-07-12 16:22:00+03	46700.00
A626C0	2017-08-12 05:04:00+03	405100.00
A6271E	2017-07-15 21:56:00+03	58800.00
A6275E	2017-08-03 22:05:00+03	49100.00
A6276A	2017-07-05 05:21:00+03	120100.00
A627B2	2017-07-13 22:42:00+03	14400.00
A62830	2017-07-15 09:51:00+03	56000.00
A62856	2017-08-04 00:13:00+03	117200.00
A6285D	2017-07-20 03:07:00+03	45200.00
A62875	2017-08-10 00:40:00+03	82900.00
A62880	2017-07-09 08:47:00+03	78200.00
A62883	2017-07-06 04:25:00+03	101200.00
A6291D	2017-08-05 14:26:00+03	6700.00
A62981	2017-07-13 01:12:00+03	16400.00
A62999	2017-08-03 21:24:00+03	62000.00
A629ED	2017-07-15 20:46:00+03	89600.00
A62A64	2017-07-27 20:46:00+03	50000.00
A62AB7	2017-08-14 14:49:00+03	75600.00
A62B8B	2017-07-20 12:02:00+03	26700.00
A62BAD	2017-07-22 11:42:00+03	102100.00
A62BCD	2017-08-01 06:47:00+03	66600.00
A62C52	2017-07-09 07:58:00+03	170200.00
A62C6B	2017-07-19 03:59:00+03	66000.00
A62CE3	2017-07-16 20:44:00+03	66800.00
A62CFB	2017-08-10 02:34:00+03	28600.00
A62D22	2017-07-13 14:17:00+03	67100.00
A62D5E	2017-07-06 12:59:00+03	61800.00
A62DFD	2017-07-06 00:36:00+03	61800.00
A62EC7	2017-07-07 10:08:00+03	113800.00
A62EEA	2017-07-22 13:32:00+03	231200.00
A62F11	2017-08-09 12:55:00+03	53000.00
A62F31	2017-08-03 19:50:00+03	11600.00
A62F35	2017-07-22 01:34:00+03	90800.00
A62FB0	2017-08-09 06:13:00+03	129600.00
A62FD8	2017-07-01 18:39:00+03	196800.00
A63010	2017-07-20 04:56:00+03	70200.00
A6310D	2017-07-08 14:30:00+03	55800.00
A63192	2017-08-07 07:01:00+03	26000.00
A631D0	2017-08-14 07:51:00+03	24000.00
A631F0	2017-07-15 10:04:00+03	44000.00
A631F7	2017-08-04 08:42:00+03	6000.00
A63282	2017-07-10 05:36:00+03	92800.00
A632F8	2017-07-15 15:15:00+03	26200.00
A63323	2017-07-07 08:40:00+03	55800.00
A63363	2017-08-05 18:10:00+03	44500.00
A63369	2017-08-10 07:37:00+03	34000.00
A633C6	2017-07-19 16:52:00+03	130600.00
A633E0	2017-08-11 14:12:00+03	198400.00
A63441	2017-07-21 02:31:00+03	67300.00
A6344B	2017-07-10 15:11:00+03	6300.00
A63490	2017-07-31 06:52:00+03	114300.00
A634EE	2017-07-09 05:51:00+03	6300.00
A63502	2017-08-12 12:06:00+03	12000.00
A6350B	2017-07-20 02:26:00+03	136200.00
A635C7	2017-07-06 20:05:00+03	28800.00
A6363C	2017-07-12 17:42:00+03	37200.00
A63656	2017-08-01 20:42:00+03	532800.00
A636EA	2017-08-06 15:01:00+03	135200.00
A636EB	2017-07-08 18:43:00+03	57500.00
A63705	2017-08-04 14:25:00+03	30900.00
A6378C	2017-08-07 14:25:00+03	168000.00
A637AD	2017-07-11 20:08:00+03	16400.00
A637B1	2017-08-09 21:52:00+03	71400.00
A637F1	2017-08-11 10:07:00+03	29400.00
A6380F	2017-07-02 20:34:00+03	77600.00
A6388A	2017-08-15 12:30:00+03	155700.00
A638D6	2017-07-20 10:49:00+03	67600.00
A63907	2017-07-02 08:53:00+03	145100.00
A63922	2017-08-09 13:49:00+03	12400.00
A639D7	2017-07-08 15:32:00+03	78600.00
A63A93	2017-07-09 15:16:00+03	78200.00
A63A9B	2017-08-07 10:10:00+03	42700.00
A63B05	2017-07-18 22:18:00+03	73600.00
A63B33	2017-08-08 02:20:00+03	106100.00
A63B76	2017-07-10 13:47:00+03	65400.00
A63C8F	2017-07-13 03:24:00+03	99200.00
A63CB9	2017-07-10 09:18:00+03	47400.00
A63CE6	2017-07-30 05:42:00+03	39200.00
A63CF4	2017-07-27 04:05:00+03	42800.00
A63DCE	2017-07-06 05:08:00+03	46500.00
A63DE7	2017-07-16 22:27:00+03	25600.00
A63E07	2017-08-09 18:56:00+03	21600.00
A63E54	2017-07-15 17:39:00+03	68000.00
A63E72	2017-08-14 22:17:00+03	7400.00
A63EAD	2017-07-07 07:23:00+03	11600.00
A63ED2	2017-08-12 21:14:00+03	44700.00
A63EF4	2017-06-28 04:10:00+03	26800.00
A63F34	2017-08-08 09:11:00+03	74900.00
A63FC0	2017-07-14 09:31:00+03	116900.00
A63FC8	2017-07-28 13:10:00+03	84100.00
A6406D	2017-07-20 09:24:00+03	68000.00
A640B3	2017-07-13 02:20:00+03	48800.00
A640C7	2017-07-09 11:27:00+03	16400.00
A6418E	2017-07-28 17:55:00+03	28000.00
A641C1	2017-07-10 23:49:00+03	75600.00
A641C7	2017-07-06 10:31:00+03	112600.00
A641E5	2017-08-07 00:33:00+03	406700.00
A64211	2017-07-15 20:28:00+03	26000.00
A6428A	2017-08-07 09:08:00+03	303500.00
A642D0	2017-07-20 13:01:00+03	29200.00
A64347	2017-07-26 23:39:00+03	81700.00
A6438F	2017-07-09 09:10:00+03	85900.00
A64481	2017-07-16 16:46:00+03	62700.00
A64488	2017-08-10 14:04:00+03	37800.00
A6448D	2017-07-09 09:52:00+03	14700.00
A6449D	2017-08-01 12:12:00+03	139100.00
A644A3	2017-07-09 14:09:00+03	23100.00
A644E5	2017-08-08 05:28:00+03	211000.00
A64516	2017-08-08 20:35:00+03	25200.00
A645C4	2017-08-14 13:46:00+03	273600.00
A645DB	2017-07-19 03:59:00+03	539400.00
A64611	2017-08-08 15:48:00+03	111600.00
A64624	2017-08-13 06:12:00+03	23200.00
A64643	2017-08-10 16:25:00+03	48800.00
A64676	2017-08-07 01:54:00+03	128800.00
A646B0	2017-08-01 02:01:00+03	78100.00
A647D6	2017-07-06 23:03:00+03	62600.00
A64800	2017-07-29 09:50:00+03	79600.00
A6488B	2017-08-15 14:53:00+03	15800.00
A648A2	2017-07-12 17:12:00+03	62800.00
A64905	2017-08-09 10:24:00+03	28800.00
A64910	2017-08-10 08:38:00+03	24700.00
A64913	2017-07-29 22:53:00+03	6600.00
A6492C	2017-07-25 13:06:00+03	48500.00
A6492F	2017-08-10 04:15:00+03	47000.00
A6498E	2017-08-12 23:40:00+03	47200.00
A649A5	2017-08-06 19:30:00+03	29600.00
A649C6	2017-07-13 19:02:00+03	246000.00
A649E1	2017-07-03 04:24:00+03	47100.00
A64A51	2017-07-22 14:30:00+03	49600.00
A64A6C	2017-08-03 23:47:00+03	78800.00
A64A73	2017-07-28 09:32:00+03	277900.00
A64A78	2017-07-20 18:03:00+03	67600.00
A64AB1	2017-06-30 03:18:00+03	56000.00
A64AC4	2017-07-04 03:14:00+03	51600.00
A64B46	2017-07-01 14:58:00+03	75600.00
A64B4F	2017-07-05 10:56:00+03	37600.00
A64B68	2017-07-05 00:16:00+03	73600.00
A64C23	2017-07-20 16:08:00+03	38600.00
A64C41	2017-08-04 12:15:00+03	100000.00
A64C85	2017-07-29 17:56:00+03	193600.00
A64CE5	2017-07-06 14:15:00+03	7200.00
A64CF6	2017-08-14 05:14:00+03	24000.00
A64D06	2017-07-10 21:37:00+03	23600.00
A64DB9	2017-08-13 21:41:00+03	46000.00
A64E14	2017-07-06 23:16:00+03	28300.00
A64E3C	2017-08-05 10:08:00+03	37900.00
A64E94	2017-07-17 11:51:00+03	23200.00
A64EB0	2017-08-03 23:31:00+03	14000.00
A64EB8	2017-06-30 21:17:00+03	6700.00
A64F28	2017-08-07 04:24:00+03	199700.00
A64F38	2017-07-07 01:14:00+03	30000.00
A64F3D	2017-06-29 03:40:00+03	99700.00
A64F9F	2017-08-08 00:01:00+03	103700.00
A64FAE	2017-07-19 05:34:00+03	6000.00
A64FD8	2017-07-10 03:00:00+03	291600.00
A64FDC	2017-08-02 08:24:00+03	14000.00
A64FDE	2017-08-13 13:57:00+03	83200.00
A6507F	2017-07-21 09:53:00+03	157900.00
A650C2	2017-08-14 23:08:00+03	26600.00
A650CA	2017-08-13 13:12:00+03	32800.00
A651A4	2017-08-08 09:26:00+03	79900.00
A6522F	2017-07-06 00:52:00+03	31600.00
A65246	2017-07-06 22:20:00+03	57500.00
A653D2	2017-07-10 21:36:00+03	42700.00
A65401	2017-08-06 10:24:00+03	23600.00
A654BF	2017-07-15 00:49:00+03	29600.00
A654FF	2017-08-09 06:55:00+03	49500.00
A65546	2017-07-21 08:08:00+03	22000.00
A6559C	2017-08-11 07:58:00+03	15400.00
A655DD	2017-08-12 20:50:00+03	116000.00
A65603	2017-07-27 03:04:00+03	21800.00
A6561C	2017-07-01 10:29:00+03	62600.00
A6563A	2017-08-12 18:57:00+03	156300.00
A6564D	2017-08-14 10:12:00+03	84500.00
A65650	2017-07-11 06:04:00+03	31600.00
A656EE	2017-07-29 02:15:00+03	30100.00
A65723	2017-07-04 08:30:00+03	37600.00
A6573C	2017-07-07 14:20:00+03	21800.00
A65756	2017-07-12 03:10:00+03	28800.00
A658A0	2017-07-10 16:25:00+03	201800.00
A658A4	2017-07-01 19:37:00+03	46200.00
A658B0	2017-08-13 15:50:00+03	75300.00
A658CE	2017-07-17 19:01:00+03	6700.00
A65966	2017-07-08 06:55:00+03	12000.00
A659E2	2017-07-13 03:20:00+03	213600.00
A65A4B	2017-07-19 03:50:00+03	8000.00
A65A8C	2017-07-08 23:41:00+03	71800.00
A65BA1	2017-07-16 18:28:00+03	112100.00
A65BD4	2017-07-08 19:13:00+03	56000.00
A65BFC	2017-07-05 08:06:00+03	28000.00
A65D05	2017-07-21 22:48:00+03	22600.00
A65D36	2017-07-11 17:48:00+03	56000.00
A65D70	2017-07-13 18:55:00+03	137700.00
A65E16	2017-07-10 18:40:00+03	406200.00
A65EB9	2017-08-03 17:24:00+03	44800.00
A65F0A	2017-07-06 10:15:00+03	31600.00
A65F14	2017-08-08 09:23:00+03	67600.00
A65F19	2017-07-02 11:12:00+03	34700.00
A65F26	2017-07-21 22:48:00+03	47500.00
A65F9E	2017-07-24 07:30:00+03	46300.00
A66002	2017-07-10 19:56:00+03	148200.00
A66046	2017-08-08 05:28:00+03	57800.00
A66069	2017-07-28 13:28:00+03	146300.00
A660BA	2017-07-12 20:22:00+03	75200.00
A660EE	2017-08-06 02:20:00+03	34600.00
A66111	2017-08-09 00:24:00+03	136800.00
A66179	2017-07-05 20:43:00+03	46400.00
A661DB	2017-07-07 09:29:00+03	38400.00
A661F5	2017-07-17 02:01:00+03	68800.00
A6620D	2017-07-27 12:28:00+03	72200.00
A6623E	2017-07-18 19:43:00+03	65600.00
A6624F	2017-08-01 17:12:00+03	41800.00
A66283	2017-07-12 16:23:00+03	57500.00
A6629C	2017-07-11 17:30:00+03	29400.00
A662B2	2017-07-14 06:48:00+03	46800.00
A662EF	2017-07-02 05:15:00+03	23600.00
A66324	2017-07-25 19:11:00+03	58200.00
A6636B	2017-07-20 01:03:00+03	24400.00
A6638B	2017-08-09 09:20:00+03	64900.00
A663D6	2017-07-02 18:00:00+03	57600.00
A663DC	2017-07-18 13:02:00+03	615000.00
A6653F	2017-07-14 06:58:00+03	27300.00
A6654A	2017-07-29 11:14:00+03	39400.00
A6656F	2017-08-10 12:34:00+03	75600.00
A665D3	2017-08-12 06:13:00+03	30000.00
A66615	2017-08-06 14:04:00+03	202200.00
A66623	2017-07-24 03:41:00+03	45600.00
A66637	2017-07-23 03:08:00+03	26000.00
A66676	2017-07-22 17:26:00+03	75700.00
A6667E	2017-07-28 10:30:00+03	28000.00
A6669D	2017-07-17 17:15:00+03	37900.00
A666B6	2017-07-21 17:11:00+03	38800.00
A666CE	2017-06-29 11:57:00+03	27800.00
A66712	2017-08-14 05:38:00+03	62700.00
A66715	2017-07-29 04:46:00+03	6700.00
A6672D	2017-07-08 20:14:00+03	66000.00
A667BD	2017-07-31 23:07:00+03	40600.00
A667CA	2017-08-12 19:11:00+03	20800.00
A667EB	2017-07-25 20:52:00+03	69500.00
A667FA	2017-07-21 11:00:00+03	8200.00
A66855	2017-07-27 23:10:00+03	46000.00
A668FE	2017-07-17 19:13:00+03	52800.00
A66949	2017-07-24 19:53:00+03	69500.00
A66962	2017-07-22 22:36:00+03	52600.00
A66988	2017-08-07 17:16:00+03	27200.00
A669A0	2017-07-07 14:44:00+03	44800.00
A669C9	2017-08-04 13:23:00+03	68100.00
A669F3	2017-07-11 05:32:00+03	369000.00
A66A05	2017-07-15 09:41:00+03	103100.00
A66A2A	2017-07-18 14:52:00+03	19600.00
A66A4E	2017-07-06 11:01:00+03	46200.00
A66A9C	2017-06-27 23:21:00+03	24400.00
A66AC5	2017-07-18 16:28:00+03	173900.00
A66AE8	2017-08-13 04:49:00+03	82500.00
A66B7E	2017-08-10 13:51:00+03	174000.00
A66BE8	2017-07-14 06:20:00+03	55800.00
A66BEF	2017-08-12 07:00:00+03	22000.00
A66C1A	2017-07-03 12:25:00+03	61800.00
A66C4F	2017-08-12 19:31:00+03	7200.00
A66C52	2017-07-15 15:50:00+03	201800.00
A66C57	2017-08-12 05:30:00+03	91100.00
A66C84	2017-07-08 11:32:00+03	48700.00
A66C91	2017-07-22 12:38:00+03	48800.00
A66CB8	2017-07-11 19:15:00+03	51600.00
A66CED	2017-07-12 03:20:00+03	20600.00
A66D9C	2017-08-11 00:11:00+03	96300.00
A66D9F	2017-07-22 06:24:00+03	26200.00
A66DD1	2017-08-14 10:21:00+03	231900.00
A66E14	2017-07-03 02:02:00+03	138000.00
A66EB5	2017-07-29 02:18:00+03	53900.00
A66F09	2017-08-01 03:56:00+03	67300.00
A66F57	2017-07-22 09:12:00+03	37900.00
A66F76	2017-07-11 07:31:00+03	178800.00
A66F88	2017-07-01 06:28:00+03	92000.00
A66FB0	2017-08-05 23:49:00+03	14400.00
A67016	2017-08-05 11:29:00+03	81700.00
A67047	2017-07-30 23:55:00+03	37900.00
A6709A	2017-07-15 16:06:00+03	24400.00
A6713C	2017-07-01 15:26:00+03	147100.00
A671F9	2017-07-18 00:27:00+03	44700.00
A6723F	2017-07-20 10:04:00+03	24000.00
A6724A	2017-08-13 17:28:00+03	24200.00
A67258	2017-08-07 05:55:00+03	136000.00
A67262	2017-08-10 11:48:00+03	56000.00
A672A5	2017-07-09 04:08:00+03	67600.00
A67331	2017-07-05 09:21:00+03	26800.00
A67335	2017-07-23 05:09:00+03	100000.00
A6735D	2017-07-06 06:34:00+03	56000.00
A67388	2017-07-12 10:38:00+03	51900.00
A67398	2017-07-15 01:04:00+03	22000.00
A673E8	2017-07-04 00:06:00+03	27200.00
A67493	2017-07-28 18:35:00+03	58000.00
A674A6	2017-07-29 10:54:00+03	39500.00
A674D3	2017-07-14 06:52:00+03	20200.00
A674EC	2017-07-29 13:47:00+03	89700.00
A6756B	2017-07-23 12:05:00+03	17200.00
A675B7	2017-07-26 18:50:00+03	136200.00
A675D1	2017-08-09 10:43:00+03	7400.00
A675DB	2017-08-13 20:54:00+03	496700.00
A677B5	2017-07-08 21:30:00+03	37800.00
A677C3	2017-08-15 07:00:00+03	28000.00
A677CD	2017-07-10 13:24:00+03	52600.00
A6782D	2017-07-13 16:04:00+03	6000.00
A678B5	2017-07-01 04:28:00+03	21800.00
A6794C	2017-07-14 08:27:00+03	65500.00
A67A01	2017-07-27 07:54:00+03	25000.00
A67A0F	2017-07-05 14:23:00+03	131100.00
A67AAB	2017-07-21 00:14:00+03	103600.00
A67AB3	2017-07-23 01:26:00+03	406200.00
A67ADA	2017-08-13 08:49:00+03	56000.00
A67B0A	2017-08-13 17:54:00+03	27400.00
A67B92	2017-08-11 03:26:00+03	6000.00
A67B96	2017-07-17 07:13:00+03	6300.00
A67BFC	2017-08-04 01:30:00+03	61900.00
A67C47	2017-08-13 13:09:00+03	24400.00
A67C53	2017-07-06 07:36:00+03	136800.00
A67C5A	2017-06-30 23:07:00+03	46000.00
A67D1F	2017-08-09 06:04:00+03	26700.00
A67D32	2017-08-10 17:01:00+03	75300.00
A67D9B	2017-07-13 13:17:00+03	38800.00
A67E03	2017-07-22 01:52:00+03	21400.00
A67E91	2017-07-26 19:16:00+03	46000.00
A67EA6	2017-08-06 20:19:00+03	63200.00
A67EAB	2017-07-25 05:40:00+03	48700.00
A67EBF	2017-07-13 21:10:00+03	10600.00
A67F17	2017-07-11 15:29:00+03	38800.00
A67F1F	2017-07-30 21:29:00+03	30300.00
A67F5D	2017-07-22 14:13:00+03	56200.00
A67F66	2017-07-31 13:42:00+03	6700.00
A67F9A	2017-08-14 10:31:00+03	148200.00
A68036	2017-07-24 15:26:00+03	73000.00
A6803F	2017-07-06 10:10:00+03	56000.00
A680AD	2017-08-10 07:42:00+03	32200.00
A680BE	2017-07-28 05:51:00+03	56000.00
A6816B	2017-08-09 16:32:00+03	81600.00
A68189	2017-07-14 22:38:00+03	44000.00
A68195	2017-07-15 02:01:00+03	83600.00
A681CC	2017-08-06 14:27:00+03	122300.00
A681E7	2017-07-13 15:10:00+03	270700.00
A6826B	2017-07-12 11:13:00+03	88000.00
A6828B	2017-07-24 10:10:00+03	46400.00
A682A1	2017-07-18 19:39:00+03	256700.00
A68301	2017-07-11 10:33:00+03	67300.00
A68389	2017-07-02 04:15:00+03	76600.00
A683E6	2017-08-04 11:28:00+03	23600.00
A683ED	2017-07-03 18:22:00+03	54500.00
A683FA	2017-07-17 21:56:00+03	7400.00
A6845E	2017-07-20 10:01:00+03	123000.00
A68491	2017-07-27 20:58:00+03	102800.00
A68501	2017-07-15 12:39:00+03	120600.00
A68557	2017-07-31 18:56:00+03	8200.00
A685A6	2017-08-03 10:46:00+03	132800.00
A68636	2017-08-03 17:44:00+03	67500.00
A6869B	2017-06-27 20:43:00+03	14800.00
A686AC	2017-07-23 03:11:00+03	27200.00
A686CE	2017-07-06 05:30:00+03	81200.00
A6870B	2017-08-11 12:31:00+03	265700.00
A68746	2017-08-01 02:18:00+03	25200.00
A6874A	2017-07-02 10:44:00+03	95700.00
A68751	2017-07-19 09:26:00+03	113200.00
A687C3	2017-07-14 22:37:00+03	24800.00
A687D0	2017-08-01 22:43:00+03	179200.00
A68804	2017-07-28 01:14:00+03	46400.00
A6881B	2017-08-14 18:28:00+03	47600.00
A6887A	2017-07-07 16:34:00+03	132800.00
A688B9	2017-07-23 01:44:00+03	30200.00
A688BA	2017-07-15 14:08:00+03	26200.00
A68905	2017-07-01 17:43:00+03	70700.00
A6891C	2017-08-09 20:43:00+03	54800.00
A6892B	2017-07-03 03:31:00+03	165500.00
A689B9	2017-07-30 20:37:00+03	13200.00
A689C0	2017-07-05 05:34:00+03	24400.00
A68A46	2017-07-08 03:13:00+03	160800.00
A68A55	2017-08-07 09:06:00+03	135600.00
A68A5D	2017-08-10 10:22:00+03	246000.00
A68A62	2017-07-07 21:59:00+03	44800.00
A68A87	2017-07-18 04:21:00+03	52300.00
A68ADA	2017-07-12 13:36:00+03	95700.00
A68BE6	2017-07-23 08:24:00+03	13600.00
A68BFA	2017-07-23 06:32:00+03	31600.00
A68C0E	2017-07-09 08:29:00+03	59800.00
A68C2E	2017-08-01 18:52:00+03	38800.00
A68CE0	2017-07-22 03:47:00+03	266400.00
A68CEE	2017-07-23 03:09:00+03	135400.00
A68D4E	2017-08-04 10:32:00+03	18900.00
A68DE7	2017-08-05 01:37:00+03	128800.00
A68E2C	2017-08-15 04:24:00+03	148200.00
A68E57	2017-07-03 04:09:00+03	19600.00
A68E5E	2017-07-24 19:30:00+03	119400.00
A68E62	2017-08-07 06:11:00+03	56900.00
A68E9C	2017-07-29 05:40:00+03	123000.00
A68EF8	2017-07-07 23:40:00+03	51200.00
A68F4F	2017-07-13 02:16:00+03	59300.00
A68F71	2017-07-03 20:27:00+03	52000.00
A68FB8	2017-08-02 22:58:00+03	169900.00
A68FD7	2017-08-08 23:06:00+03	189100.00
A68FE2	2017-07-27 04:05:00+03	59000.00
A68FF9	2017-07-04 00:30:00+03	47100.00
A69018	2017-08-01 10:55:00+03	63200.00
A6902F	2017-07-20 00:55:00+03	138100.00
A6904D	2017-08-13 17:02:00+03	92000.00
A6905A	2017-07-13 11:41:00+03	40000.00
A69147	2017-08-15 10:19:00+03	40600.00
A6916F	2017-07-03 22:13:00+03	46400.00
A691C1	2017-07-31 04:46:00+03	68400.00
A69237	2017-07-15 19:09:00+03	58600.00
A69297	2017-07-22 04:36:00+03	56200.00
A69328	2017-08-12 07:37:00+03	248700.00
A69346	2017-07-30 16:07:00+03	94800.00
A69362	2017-07-26 04:50:00+03	51900.00
A6938E	2017-07-07 02:55:00+03	47400.00
A694B5	2017-06-30 09:29:00+03	31600.00
A694CD	2017-07-18 18:10:00+03	96200.00
A694EC	2017-08-07 17:26:00+03	89700.00
A6955D	2017-07-23 22:05:00+03	37900.00
A69575	2017-08-05 12:14:00+03	15800.00
A69627	2017-08-12 18:37:00+03	81600.00
A69644	2017-06-30 04:17:00+03	29600.00
A69682	2017-07-26 11:31:00+03	103400.00
A69698	2017-07-04 01:22:00+03	95600.00
A696E1	2017-07-07 00:53:00+03	166100.00
A69711	2017-07-22 15:21:00+03	37900.00
A697B3	2017-07-24 04:56:00+03	26700.00
A697B7	2017-07-18 15:17:00+03	81700.00
A697C1	2017-07-09 00:30:00+03	288600.00
A697C3	2017-07-31 09:07:00+03	521800.00
A697E5	2017-07-31 15:00:00+03	32800.00
A69863	2017-07-16 05:01:00+03	23200.00
A6989C	2017-07-22 07:06:00+03	23200.00
A698A0	2017-07-23 14:16:00+03	48300.00
A698B3	2017-07-19 23:47:00+03	56600.00
A698E9	2017-08-11 10:00:00+03	50800.00
A698EE	2017-07-10 05:38:00+03	28800.00
A698FD	2017-06-30 12:37:00+03	70600.00
A69940	2017-07-09 10:52:00+03	26800.00
A6996C	2017-07-28 05:09:00+03	67600.00
A69A05	2017-06-29 20:12:00+03	132200.00
A69A73	2017-08-06 17:46:00+03	68400.00
A69A8B	2017-07-11 16:10:00+03	56600.00
A69AD8	2017-07-11 23:45:00+03	61900.00
A69ADA	2017-07-28 01:57:00+03	49000.00
A69AF3	2017-08-10 14:15:00+03	118500.00
A69C61	2017-07-14 06:33:00+03	111700.00
A69C6F	2017-07-25 11:44:00+03	55800.00
A69CDF	2017-07-24 00:37:00+03	29600.00
A69D12	2017-07-20 05:25:00+03	99200.00
A69D5D	2017-08-10 14:09:00+03	31400.00
A69D75	2017-08-04 16:57:00+03	56000.00
A69D81	2017-07-11 14:39:00+03	37900.00
A69DD8	2017-07-29 11:15:00+03	28000.00
A69E23	2017-08-02 08:56:00+03	20200.00
A69E32	2017-07-25 07:20:00+03	46000.00
A69E87	2017-08-12 00:06:00+03	136800.00
A69EC0	2017-07-10 06:08:00+03	133100.00
A69EC3	2017-07-16 23:39:00+03	24700.00
A69EC8	2017-07-10 03:54:00+03	147800.00
A69EFA	2017-08-14 16:36:00+03	82000.00
A69F16	2017-07-12 09:00:00+03	390400.00
A69F5D	2017-08-06 14:41:00+03	67100.00
A69F7D	2017-08-11 03:42:00+03	47000.00
A69FCF	2017-08-09 02:18:00+03	24600.00
A6A004	2017-08-13 10:31:00+03	39200.00
A6A013	2017-08-08 09:58:00+03	27400.00
A6A070	2017-07-09 12:22:00+03	34100.00
A6A0A9	2017-07-25 22:51:00+03	58200.00
A6A130	2017-08-09 04:45:00+03	75300.00
A6A151	2017-07-24 18:18:00+03	34000.00
A6A1C9	2017-07-11 22:55:00+03	62700.00
A6A206	2017-07-29 01:15:00+03	67700.00
A6A270	2017-07-14 20:10:00+03	149900.00
A6A2E6	2017-07-08 23:52:00+03	65500.00
A6A308	2017-07-19 04:20:00+03	69500.00
A6A34A	2017-07-03 09:27:00+03	51300.00
A6A3F4	2017-07-15 05:33:00+03	95600.00
A6A3FC	2017-07-11 09:02:00+03	6700.00
A6A45F	2017-07-02 02:50:00+03	83100.00
A6A482	2017-08-01 13:29:00+03	131100.00
A6A488	2017-07-17 15:29:00+03	70600.00
A6A4AF	2017-08-02 08:29:00+03	20200.00
A6A4E9	2017-07-11 04:40:00+03	58900.00
A6A50B	2017-07-08 20:19:00+03	38500.00
A6A514	2017-08-09 12:58:00+03	6800.00
A6A585	2017-07-06 22:46:00+03	42400.00
A6A5A7	2017-08-05 20:11:00+03	56000.00
A6A5EF	2017-08-13 19:04:00+03	46000.00
A6A5F6	2017-08-10 02:53:00+03	266400.00
A6A613	2017-07-22 14:28:00+03	100200.00
A6A625	2017-08-08 07:32:00+03	133100.00
A6A62B	2017-07-06 18:42:00+03	30800.00
A6A62D	2017-07-22 04:11:00+03	37200.00
A6A631	2017-07-16 05:11:00+03	273400.00
A6A63A	2017-07-14 06:34:00+03	48300.00
A6A6B6	2017-07-28 21:36:00+03	31400.00
A6A6F8	2017-07-20 00:37:00+03	85400.00
A6A70D	2017-07-28 12:30:00+03	57800.00
A6A732	2017-08-15 04:31:00+03	48800.00
A6A77B	2017-07-31 14:10:00+03	57700.00
A6A7D5	2017-08-13 14:21:00+03	115100.00
A6A8D2	2017-08-09 12:47:00+03	12000.00
A6A916	2017-07-16 22:59:00+03	224000.00
A6A957	2017-07-20 01:42:00+03	272700.00
A6A962	2017-07-08 22:35:00+03	87900.00
A6A986	2017-08-04 11:04:00+03	294200.00
A6A9C4	2017-08-03 03:20:00+03	76600.00
A6A9DF	2017-08-12 15:07:00+03	67600.00
A6A9FB	2017-07-02 11:20:00+03	78000.00
A6AA18	2017-08-15 13:20:00+03	148200.00
A6AA22	2017-07-29 12:39:00+03	97000.00
A6AA3C	2017-07-21 03:59:00+03	46400.00
A6AA57	2017-07-27 01:37:00+03	89800.00
A6AA5F	2017-08-09 10:56:00+03	46400.00
A6AA86	2017-08-04 20:39:00+03	123600.00
A6AA8E	2017-06-29 06:56:00+03	55800.00
A6AB1E	2017-07-30 02:10:00+03	201200.00
A6AB79	2017-08-13 06:21:00+03	25100.00
A6AB8D	2017-08-03 12:31:00+03	191300.00
A6ABB5	2017-08-08 17:17:00+03	42800.00
A6AC0B	2017-07-25 22:25:00+03	126800.00
A6AC4F	2017-08-06 07:26:00+03	47700.00
A6ACA0	2017-07-06 12:27:00+03	26000.00
A6ACE4	2017-08-07 06:29:00+03	19800.00
A6AD2D	2017-07-27 19:03:00+03	103200.00
A6AD6E	2017-07-28 09:40:00+03	65900.00
A6AD70	2017-07-24 04:46:00+03	89700.00
A6AD72	2017-08-12 17:50:00+03	24400.00
A6AD79	2017-07-13 10:42:00+03	67600.00
A6ADD4	2017-07-08 14:13:00+03	28000.00
A6ADED	2017-07-09 03:36:00+03	39900.00
A6AF1B	2017-06-29 20:26:00+03	84100.00
A6AF23	2017-07-08 04:36:00+03	26700.00
A6AF8E	2017-07-30 04:18:00+03	200500.00
A6AF95	2017-07-13 19:50:00+03	63900.00
A6AFB3	2017-08-09 00:23:00+03	66600.00
A6B003	2017-08-11 17:35:00+03	174400.00
A6B0A3	2017-08-12 16:21:00+03	23200.00
A6B0F2	2017-07-05 09:29:00+03	59800.00
A6B12D	2017-08-15 14:28:00+03	29600.00
A6B1DB	2017-08-06 01:58:00+03	36200.00
A6B22F	2017-07-25 22:57:00+03	21800.00
A6B261	2017-07-29 12:05:00+03	248400.00
A6B262	2017-07-15 07:02:00+03	6000.00
A6B2B1	2017-08-01 17:26:00+03	67600.00
A6B2F0	2017-07-14 10:26:00+03	302600.00
A6B3AC	2017-07-11 16:30:00+03	15800.00
A6B3EC	2017-07-25 11:33:00+03	55800.00
A6B42B	2017-08-01 00:47:00+03	297000.00
A6B4AF	2017-07-05 07:22:00+03	52000.00
A6B562	2017-07-24 00:55:00+03	68100.00
A6B5FD	2017-07-08 08:00:00+03	86800.00
A6B64C	2017-08-08 04:14:00+03	40000.00
A6B68D	2017-07-11 08:52:00+03	382500.00
A6B693	2017-07-31 01:16:00+03	20200.00
A6B6AD	2017-08-11 06:17:00+03	396500.00
A6B6BE	2017-07-28 00:51:00+03	47200.00
A6B6C6	2017-07-19 05:06:00+03	57600.00
A6B6D3	2017-08-05 08:33:00+03	6400.00
A6B6E2	2017-08-07 10:29:00+03	273000.00
A6B6F1	2017-07-16 19:10:00+03	135400.00
A6B6FD	2017-08-13 17:47:00+03	10800.00
A6B71B	2017-07-28 15:04:00+03	104100.00
A6B763	2017-07-20 09:50:00+03	136500.00
A6B765	2017-08-06 07:33:00+03	23200.00
A6B7B5	2017-07-12 18:17:00+03	27500.00
A6B7CC	2017-07-31 17:40:00+03	94200.00
A6B7E1	2017-08-05 13:56:00+03	26700.00
A6B852	2017-07-02 17:29:00+03	28000.00
A6B899	2017-07-21 00:20:00+03	96800.00
A6B8BE	2017-07-05 14:54:00+03	81300.00
A6B9A6	2017-07-29 19:34:00+03	6000.00
A6BA04	2017-06-29 23:10:00+03	146400.00
A6BA6D	2017-07-29 11:49:00+03	26800.00
A6BA7E	2017-07-02 08:37:00+03	47000.00
A6BA8E	2017-08-14 23:02:00+03	21800.00
A6BAB4	2017-08-01 21:03:00+03	31400.00
A6BAEE	2017-08-10 18:41:00+03	12200.00
A6BB01	2017-07-08 06:32:00+03	109300.00
A6BB77	2017-08-07 17:32:00+03	55800.00
A6BB8E	2017-08-04 05:05:00+03	38600.00
A6BB9A	2017-07-27 17:12:00+03	28000.00
A6BBB7	2017-08-04 13:22:00+03	25100.00
A6BBBF	2017-08-08 03:32:00+03	6800.00
A6BBED	2017-07-28 17:34:00+03	39400.00
A6BC09	2017-08-06 12:35:00+03	79000.00
A6BC40	2017-07-05 08:12:00+03	25200.00
A6BC5E	2017-08-09 07:50:00+03	40400.00
A6BC87	2017-07-10 18:59:00+03	44500.00
A6BC95	2017-07-25 07:06:00+03	32700.00
A6BCBA	2017-08-14 06:40:00+03	37900.00
A6BCE5	2017-08-01 17:35:00+03	27400.00
A6BD07	2017-08-10 16:34:00+03	75300.00
A6BD64	2017-08-08 04:27:00+03	69900.00
A6BDC1	2017-07-01 05:00:00+03	52700.00
A6BDE1	2017-07-19 17:25:00+03	249100.00
A6BE58	2017-07-13 19:43:00+03	6700.00
A6BE6E	2017-07-01 00:27:00+03	34000.00
A6BED0	2017-07-01 06:22:00+03	398500.00
A6BF6E	2017-08-13 05:01:00+03	45200.00
A6BFB3	2017-06-27 20:20:00+03	26600.00
A6BFB9	2017-07-18 10:16:00+03	29600.00
A6BFBA	2017-07-14 14:33:00+03	67100.00
A6BFBC	2017-07-22 12:48:00+03	47700.00
A6BFD1	2017-07-31 07:47:00+03	123000.00
A6C013	2017-07-04 22:25:00+03	147100.00
A6C127	2017-07-04 11:39:00+03	58000.00
A6C16D	2017-07-07 02:12:00+03	114800.00
A6C202	2017-07-21 10:58:00+03	123600.00
A6C2C9	2017-07-02 23:27:00+03	92000.00
A6C2D8	2017-07-15 22:28:00+03	80000.00
A6C35A	2017-07-15 20:00:00+03	62600.00
A6C35C	2017-08-10 22:22:00+03	135600.00
A6C38F	2017-08-10 12:05:00+03	205000.00
A6C3AC	2017-08-09 03:51:00+03	21400.00
A6C3B7	2017-08-02 03:44:00+03	67400.00
A6C446	2017-07-28 11:43:00+03	134400.00
A6C48A	2017-07-01 03:36:00+03	213800.00
A6C496	2017-07-28 21:26:00+03	135600.00
A6C4A6	2017-08-02 13:00:00+03	54800.00
A6C4A7	2017-07-01 19:42:00+03	37700.00
A6C4AF	2017-06-30 22:57:00+03	241300.00
A6C508	2017-08-04 21:15:00+03	48500.00
A6C51F	2017-08-12 04:56:00+03	104800.00
A6C56A	2017-07-30 11:20:00+03	34100.00
A6C5A7	2017-07-02 17:31:00+03	51300.00
A6C639	2017-07-15 19:45:00+03	16400.00
A6C682	2017-07-23 10:33:00+03	270000.00
A6C690	2017-07-03 15:14:00+03	23600.00
A6C6B6	2017-07-19 00:57:00+03	23600.00
A6C72F	2017-06-30 03:09:00+03	99300.00
A6C7C3	2017-08-05 18:39:00+03	51000.00
A6C80A	2017-07-11 12:55:00+03	46000.00
A6C822	2017-06-30 19:56:00+03	23200.00
A6C842	2017-07-13 01:25:00+03	29800.00
A6C89B	2017-08-10 06:40:00+03	48500.00
A6C8F3	2017-07-18 09:03:00+03	68100.00
A6C91D	2017-07-31 20:42:00+03	33600.00
A6C980	2017-08-10 11:26:00+03	54000.00
A6CA0F	2017-08-03 10:18:00+03	124200.00
A6CACD	2017-07-11 04:30:00+03	58400.00
A6CAF3	2017-07-10 22:06:00+03	214900.00
A6CAF8	2017-08-08 03:46:00+03	29200.00
A6CB5B	2017-07-29 17:19:00+03	270800.00
A6CB6B	2017-07-11 21:52:00+03	13400.00
A6CC7F	2017-08-05 06:32:00+03	62400.00
A6CC83	2017-07-02 01:31:00+03	6700.00
A6CCB0	2017-08-06 09:33:00+03	12100.00
A6CCB7	2017-07-14 18:20:00+03	81600.00
A6CD05	2017-07-29 04:26:00+03	269000.00
A6CD18	2017-07-03 02:29:00+03	26800.00
A6CE40	2017-07-13 09:28:00+03	88500.00
A6CE4E	2017-07-23 19:57:00+03	76900.00
A6CE5A	2017-08-13 01:42:00+03	59000.00
A6CED0	2017-07-31 20:08:00+03	93400.00
A6CEE2	2017-07-27 07:18:00+03	212000.00
A6CEE5	2017-07-18 05:46:00+03	23200.00
A6CF47	2017-08-11 02:22:00+03	269600.00
A6CF61	2017-07-16 09:19:00+03	30800.00
A6D075	2017-07-22 08:00:00+03	105000.00
A6D0D1	2017-07-24 14:47:00+03	44800.00
A6D0D2	2017-08-04 19:10:00+03	24400.00
A6D129	2017-07-04 00:17:00+03	6300.00
A6D149	2017-08-08 11:05:00+03	59400.00
A6D182	2017-07-23 23:39:00+03	282100.00
A6D1E1	2017-07-14 21:25:00+03	266400.00
A6D28D	2017-07-03 05:04:00+03	398500.00
A6D2A8	2017-07-14 08:48:00+03	57600.00
A6D2BD	2017-08-14 14:02:00+03	28000.00
A6D2D2	2017-07-22 05:02:00+03	22800.00
A6D2D5	2017-08-07 07:40:00+03	65200.00
A6D2F6	2017-07-07 23:30:00+03	87200.00
A6D2FC	2017-08-03 09:13:00+03	44700.00
A6D3A8	2017-07-14 22:55:00+03	13400.00
A6D3B7	2017-06-30 05:58:00+03	12600.00
A6D3C7	2017-07-11 10:21:00+03	36200.00
A6D3E7	2017-07-28 12:10:00+03	31400.00
A6D3F2	2017-07-12 02:49:00+03	16400.00
A6D416	2017-07-21 11:30:00+03	56600.00
A6D420	2017-08-01 07:29:00+03	38600.00
A6D441	2017-07-31 21:15:00+03	106100.00
A6D487	2017-07-01 12:52:00+03	135000.00
A6D4ED	2017-08-03 00:29:00+03	278600.00
A6D4FD	2017-07-11 20:29:00+03	135600.00
A6D52F	2017-07-01 02:18:00+03	28000.00
A6D543	2017-07-03 19:09:00+03	28800.00
A6D57E	2017-08-11 05:58:00+03	48800.00
A6D588	2017-07-20 23:36:00+03	277800.00
A6D598	2017-08-06 01:28:00+03	23400.00
A6D5AD	2017-08-14 09:43:00+03	6800.00
A6D5C5	2017-08-09 08:27:00+03	85500.00
A6D630	2017-08-14 02:27:00+03	42800.00
A6D679	2017-07-07 23:39:00+03	146800.00
A6D6D0	2017-08-09 16:23:00+03	78100.00
A6D700	2017-06-29 17:15:00+03	19600.00
A6D712	2017-08-05 00:19:00+03	25000.00
A6D76E	2017-07-03 19:00:00+03	14000.00
A6D795	2017-07-29 05:53:00+03	64400.00
A6D7FF	2017-07-13 18:30:00+03	11800.00
A6D80A	2017-07-10 02:10:00+03	42400.00
A6D80D	2017-07-17 02:40:00+03	67600.00
A6D857	2017-07-26 16:49:00+03	84100.00
A6D8AB	2017-07-19 04:22:00+03	26000.00
A6D911	2017-07-30 00:48:00+03	55600.00
A6D955	2017-07-19 10:03:00+03	27200.00
A6D966	2017-07-15 04:27:00+03	68400.00
A6D9A1	2017-08-10 20:39:00+03	122300.00
A6D9CB	2017-08-10 09:48:00+03	93900.00
A6DA2F	2017-07-29 20:44:00+03	77000.00
A6DA65	2017-07-12 11:49:00+03	39400.00
A6DA8F	2017-08-09 05:28:00+03	22000.00
A6DAC7	2017-07-21 08:47:00+03	273000.00
A6DB7C	2017-07-15 06:45:00+03	52400.00
A6DB89	2017-08-11 14:44:00+03	61400.00
A6DBA2	2017-08-05 01:34:00+03	38800.00
A6DBAB	2017-07-09 14:34:00+03	50000.00
A6DC20	2017-07-30 15:35:00+03	34000.00
A6DC41	2017-07-24 23:06:00+03	26800.00
A6DCBC	2017-07-08 05:20:00+03	79600.00
A6DCCC	2017-07-07 05:26:00+03	109500.00
A6DD44	2017-08-15 12:14:00+03	58000.00
A6DD52	2017-06-27 01:48:00+03	23400.00
A6DD66	2017-07-17 19:45:00+03	20400.00
A6DDC9	2017-08-07 22:02:00+03	57500.00
A6DDFA	2017-08-14 05:17:00+03	27400.00
A6DE01	2017-08-07 17:21:00+03	215500.00
A6DE1E	2017-07-14 23:03:00+03	54500.00
A6DE37	2017-07-22 22:54:00+03	72300.00
A6DE3A	2017-08-07 04:32:00+03	123600.00
A6DE47	2017-08-15 11:38:00+03	544700.00
A6DE64	2017-08-03 08:48:00+03	40600.00
A6DE6A	2017-07-17 15:24:00+03	155300.00
A6DE9F	2017-07-06 00:48:00+03	46300.00
A6DEAF	2017-08-02 07:10:00+03	332800.00
A6DF27	2017-06-25 23:12:00+03	19600.00
A6DF4C	2017-07-17 18:59:00+03	57800.00
A6DF97	2017-07-11 11:28:00+03	111600.00
A6DFAB	2017-07-17 22:36:00+03	11800.00
A6DFD2	2017-08-07 13:19:00+03	54800.00
A6DFE6	2017-07-28 04:49:00+03	246000.00
A6E05D	2017-07-20 11:19:00+03	163400.00
A6E099	2017-07-21 05:47:00+03	266400.00
A6E0D7	2017-08-12 12:26:00+03	23200.00
A6E0DA	2017-07-14 15:27:00+03	30800.00
A6E0E3	2017-06-27 19:37:00+03	103800.00
A6E112	2017-07-20 23:46:00+03	103500.00
A6E17A	2017-07-14 18:39:00+03	28800.00
A6E1BE	2017-07-09 23:06:00+03	117200.00
A6E1CA	2017-07-31 12:43:00+03	257600.00
A6E255	2017-07-31 16:49:00+03	73000.00
A6E280	2017-08-02 09:40:00+03	272300.00
A6E2D1	2017-07-27 00:11:00+03	17200.00
A6E386	2017-07-22 01:34:00+03	187800.00
A6E397	2017-07-10 16:32:00+03	29200.00
A6E3C4	2017-07-30 12:59:00+03	92000.00
A6E3CD	2017-07-19 04:23:00+03	203300.00
A6E3F1	2017-08-12 15:09:00+03	130000.00
A6E418	2017-07-15 14:34:00+03	56000.00
A6E43D	2017-06-27 04:40:00+03	192700.00
A6E463	2017-07-08 23:20:00+03	22000.00
A6E487	2017-07-11 01:37:00+03	112000.00
A6E56E	2017-07-13 05:42:00+03	135400.00
A6E580	2017-07-24 15:16:00+03	67200.00
A6E62C	2017-07-30 04:50:00+03	273200.00
A6E689	2017-07-14 18:37:00+03	34000.00
A6E6A1	2017-07-12 11:22:00+03	53200.00
A6E6ED	2017-08-04 12:20:00+03	48400.00
A6E6EE	2017-08-04 22:53:00+03	165800.00
A6E6FD	2017-08-07 22:48:00+03	133200.00
A6E722	2017-08-01 07:56:00+03	103100.00
A6E79C	2017-07-31 03:48:00+03	56000.00
A6E7C0	2017-07-09 20:39:00+03	141400.00
A6E7D0	2017-07-26 00:31:00+03	101200.00
A6E7FA	2017-08-06 00:21:00+03	16400.00
A6E834	2017-07-12 04:58:00+03	26800.00
A6E869	2017-07-20 19:49:00+03	57400.00
A6E880	2017-08-04 16:23:00+03	188600.00
A6E8A7	2017-07-31 08:40:00+03	60900.00
A6E907	2017-07-30 05:11:00+03	86400.00
A6E971	2017-07-20 17:52:00+03	266400.00
A6E9A7	2017-07-14 01:21:00+03	54800.00
A6E9EC	2017-07-04 04:49:00+03	26000.00
A6EA26	2017-07-28 01:48:00+03	111600.00
A6EA2C	2017-07-25 04:36:00+03	92100.00
A6EA3D	2017-07-10 03:20:00+03	24800.00
A6EA85	2017-08-13 15:57:00+03	48800.00
A6EB17	2017-08-07 09:35:00+03	103500.00
A6EB71	2017-08-03 06:21:00+03	50000.00
A6EBD1	2017-08-08 05:06:00+03	29600.00
A6EC31	2017-08-03 06:31:00+03	56000.00
A6EC44	2017-08-10 16:09:00+03	13400.00
A6EC79	2017-07-17 19:29:00+03	36200.00
A6ECF7	2017-07-24 15:25:00+03	56100.00
A6ED2D	2017-07-30 18:05:00+03	16400.00
A6ED62	2017-08-12 08:59:00+03	18900.00
A6EDCD	2017-07-17 03:14:00+03	23200.00
A6EDCE	2017-08-06 10:39:00+03	50000.00
A6EDE2	2017-07-30 06:13:00+03	11200.00
A6EE60	2017-07-13 09:31:00+03	73600.00
A6EE99	2017-07-15 22:22:00+03	86400.00
A6EEAA	2017-07-28 19:08:00+03	26000.00
A6EEB0	2017-08-13 19:08:00+03	248400.00
A6EECF	2017-08-12 18:08:00+03	66000.00
A6EF94	2017-07-31 21:44:00+03	58400.00
A6F00C	2017-07-15 16:38:00+03	56000.00
A6F079	2017-07-30 10:39:00+03	142700.00
A6F0A4	2017-07-25 05:55:00+03	116400.00
A6F0E1	2017-07-03 01:07:00+03	34000.00
A6F0FE	2017-07-01 13:49:00+03	9800.00
A6F130	2017-07-24 01:40:00+03	8800.00
A6F166	2017-07-08 07:02:00+03	53600.00
A6F17D	2017-07-27 05:29:00+03	157200.00
A6F1C7	2017-07-17 08:39:00+03	101200.00
A6F1F2	2017-08-03 02:15:00+03	259000.00
A6F203	2017-07-16 16:28:00+03	24300.00
A6F21A	2017-07-21 22:05:00+03	54200.00
A6F26E	2017-07-18 19:11:00+03	70800.00
A6F271	2017-08-03 21:26:00+03	38800.00
A6F29E	2017-08-08 21:15:00+03	27900.00
A6F2BC	2017-08-10 09:47:00+03	162800.00
A6F331	2017-07-19 10:15:00+03	33600.00
A6F38E	2017-08-13 00:22:00+03	290600.00
A6F3A1	2017-08-02 00:49:00+03	167400.00
A6F3AC	2017-07-30 14:58:00+03	48800.00
A6F3CD	2017-07-11 07:40:00+03	75300.00
A6F434	2017-07-29 20:27:00+03	26800.00
A6F492	2017-07-26 07:46:00+03	46400.00
A6F4FE	2017-07-08 15:47:00+03	31600.00
A6F521	2017-07-17 17:01:00+03	44500.00
A6F57D	2017-08-07 07:35:00+03	40000.00
A6F5C5	2017-08-14 20:27:00+03	13400.00
A6F5DA	2017-08-13 10:45:00+03	223200.00
A6F5FD	2017-07-04 21:26:00+03	116400.00
A6F631	2017-07-23 10:06:00+03	64800.00
A6F65D	2017-07-09 09:05:00+03	120800.00
A6F67B	2017-07-03 16:55:00+03	46300.00
A6F6FE	2017-08-01 18:37:00+03	88400.00
A6F771	2017-07-23 14:12:00+03	35800.00
A6F795	2017-08-02 04:35:00+03	53700.00
A6F7E1	2017-08-05 22:40:00+03	46000.00
A6F7F9	2017-07-23 07:03:00+03	60300.00
A6F846	2017-08-06 22:05:00+03	19600.00
A6F881	2017-08-04 05:06:00+03	43100.00
A6F8AA	2017-07-04 04:19:00+03	41900.00
A6F8D7	2017-07-23 06:05:00+03	56600.00
A6F9EE	2017-07-24 03:29:00+03	14000.00
A6FA15	2017-08-02 02:11:00+03	37100.00
A6FA61	2017-07-13 12:19:00+03	36200.00
A6FA62	2017-07-04 02:53:00+03	73300.00
A6FA70	2017-07-14 20:05:00+03	37100.00
A6FAFA	2017-07-16 13:12:00+03	66600.00
A6FB3E	2017-07-29 12:10:00+03	120600.00
A6FB52	2017-07-29 08:23:00+03	28000.00
A6FB77	2017-07-31 09:39:00+03	14400.00
A6FBDF	2017-07-19 05:12:00+03	178700.00
A6FD60	2017-07-10 10:34:00+03	28000.00
A6FD61	2017-08-12 07:25:00+03	375200.00
A6FDA4	2017-07-07 17:26:00+03	26000.00
A6FDD7	2017-07-30 17:12:00+03	173500.00
A6FDE8	2017-08-13 00:00:00+03	86600.00
A6FE1A	2017-07-23 16:14:00+03	67700.00
A6FED3	2017-07-12 21:07:00+03	14700.00
A6FF3D	2017-08-04 07:10:00+03	242000.00
A6FF63	2017-07-09 02:02:00+03	15000.00
A6FF75	2017-08-15 17:22:00+03	47200.00
A6FF84	2017-07-01 19:00:00+03	50800.00
A6FFB0	2017-07-08 00:55:00+03	170500.00
A70031	2017-08-09 14:00:00+03	56000.00
A700A6	2017-07-05 20:35:00+03	199200.00
A7013A	2017-08-02 02:32:00+03	43500.00
A70196	2017-08-04 11:13:00+03	52100.00
A70287	2017-07-18 15:55:00+03	123000.00
A702BA	2017-07-14 10:29:00+03	17800.00
A703B7	2017-08-10 09:04:00+03	279000.00
A70476	2017-08-12 07:28:00+03	81600.00
A704E6	2017-08-10 18:39:00+03	89600.00
A704FB	2017-08-08 09:41:00+03	288600.00
A70527	2017-07-05 22:18:00+03	24800.00
A705B0	2017-07-25 07:11:00+03	80700.00
A7064E	2017-07-15 14:45:00+03	26000.00
A706C3	2017-07-31 06:28:00+03	90000.00
A706E0	2017-07-12 12:30:00+03	140100.00
A706F1	2017-08-14 17:39:00+03	11800.00
A70729	2017-08-11 19:45:00+03	9300.00
A7073F	2017-07-07 15:27:00+03	28800.00
A70755	2017-07-04 14:10:00+03	26800.00
A7076C	2017-08-01 05:06:00+03	182700.00
A7077F	2017-07-25 11:54:00+03	53100.00
A70786	2017-07-20 19:00:00+03	56000.00
A707DA	2017-08-12 10:51:00+03	84000.00
A707F0	2017-07-29 22:06:00+03	31800.00
A70814	2017-07-06 03:28:00+03	28800.00
A70824	2017-07-31 23:29:00+03	131100.00
A7083E	2017-07-26 12:33:00+03	13400.00
A7089E	2017-07-08 11:11:00+03	19600.00
A7089F	2017-07-26 16:57:00+03	270700.00
A708D4	2017-07-25 22:44:00+03	23200.00
A7090C	2017-08-15 08:21:00+03	67700.00
A7091F	2017-07-31 03:02:00+03	100000.00
A70A2E	2017-08-07 07:17:00+03	27300.00
A70A71	2017-06-29 07:55:00+03	369000.00
A70A85	2017-07-02 04:47:00+03	12700.00
A70AAF	2017-06-29 17:29:00+03	133100.00
A70AD4	2017-08-14 20:15:00+03	129200.00
A70B26	2017-08-02 10:28:00+03	189200.00
A70B92	2017-08-05 19:16:00+03	111600.00
A70B99	2017-08-14 00:01:00+03	86100.00
A70B9E	2017-06-30 17:43:00+03	143100.00
A70BBF	2017-07-13 12:56:00+03	14000.00
A70BDF	2017-08-03 12:57:00+03	35200.00
A70BF8	2017-08-05 02:10:00+03	81900.00
A70C4A	2017-07-16 14:52:00+03	6000.00
A70C6A	2017-08-04 13:00:00+03	23200.00
A70C89	2017-07-12 09:24:00+03	532800.00
A70CBD	2017-07-18 10:47:00+03	6000.00
A70CF2	2017-08-14 08:41:00+03	46500.00
A70D28	2017-07-06 21:40:00+03	797100.00
A70D98	2017-07-05 08:58:00+03	16400.00
A70DA2	2017-07-09 04:03:00+03	257600.00
A70E31	2017-07-14 01:46:00+03	61600.00
A70E78	2017-07-15 01:32:00+03	51600.00
A70FD1	2017-06-29 13:15:00+03	109000.00
A70FD5	2017-07-25 04:25:00+03	199700.00
A70FE2	2017-08-11 02:10:00+03	56000.00
A71022	2017-07-31 03:02:00+03	136200.00
A71057	2017-07-05 18:55:00+03	141600.00
A7105B	2017-08-12 05:38:00+03	107400.00
A71086	2017-07-07 14:15:00+03	31400.00
A710EF	2017-08-05 10:54:00+03	42400.00
A7117E	2017-08-11 01:08:00+03	50000.00
A71206	2017-07-31 12:44:00+03	34000.00
A71240	2017-07-15 16:14:00+03	118900.00
A71244	2017-07-30 03:28:00+03	25400.00
A7124D	2017-07-05 06:08:00+03	394400.00
A7126B	2017-07-15 22:24:00+03	55600.00
A7128B	2017-07-12 06:01:00+03	42800.00
A71295	2017-08-08 09:03:00+03	117800.00
A7131E	2017-07-11 19:00:00+03	40400.00
A71390	2017-08-15 06:12:00+03	136200.00
A71408	2017-07-02 22:32:00+03	48800.00
A7140E	2017-07-26 03:22:00+03	372500.00
A71450	2017-08-02 11:31:00+03	21800.00
A714C8	2017-07-26 07:01:00+03	77200.00
A714D7	2017-08-08 05:12:00+03	37900.00
A714E6	2017-07-02 16:31:00+03	58200.00
A7159A	2017-07-25 02:44:00+03	48800.00
A71774	2017-07-20 20:54:00+03	28000.00
A717F0	2017-07-23 15:36:00+03	106900.00
A71827	2017-08-07 20:40:00+03	167500.00
A71831	2017-07-22 01:05:00+03	246000.00
A71834	2017-07-23 12:06:00+03	281500.00
A71878	2017-07-27 12:44:00+03	39800.00
A718E0	2017-08-03 22:45:00+03	181200.00
A71914	2017-07-09 16:59:00+03	29400.00
A71958	2017-07-29 12:43:00+03	40100.00
A71962	2017-08-02 21:30:00+03	79000.00
A7198E	2017-07-12 22:58:00+03	200500.00
A71A12	2017-07-29 12:44:00+03	46000.00
A71A90	2017-07-20 23:15:00+03	246000.00
A71ACA	2017-07-15 14:31:00+03	43900.00
A71ADD	2017-08-09 23:52:00+03	28000.00
A71AE8	2017-07-26 19:37:00+03	44000.00
A71B3C	2017-07-19 23:27:00+03	75600.00
A71B3F	2017-07-09 16:36:00+03	78700.00
A71B8E	2017-08-01 05:25:00+03	38600.00
A71BCF	2017-07-23 12:50:00+03	49200.00
A71C6A	2017-07-10 07:23:00+03	246000.00
A71C91	2017-07-10 18:31:00+03	58600.00
A71CAA	2017-07-22 00:12:00+03	53600.00
A71CE9	2017-07-11 09:10:00+03	6700.00
A71D00	2017-07-18 22:56:00+03	68100.00
A71D27	2017-06-29 19:13:00+03	290400.00
A71DA9	2017-07-05 16:06:00+03	26500.00
A71DEC	2017-06-30 13:58:00+03	92900.00
A71DF0	2017-07-15 12:10:00+03	59200.00
A71E74	2017-07-01 06:03:00+03	88500.00
A71EE1	2017-07-28 02:35:00+03	27200.00
A71EE4	2017-08-08 11:21:00+03	170500.00
A71F4E	2017-07-20 10:11:00+03	9800.00
A71F64	2017-07-14 13:18:00+03	27200.00
A71F68	2017-07-29 02:39:00+03	114700.00
A71F83	2017-07-19 22:32:00+03	75900.00
A71FAF	2017-08-05 06:06:00+03	45200.00
A71FB7	2017-07-01 02:57:00+03	173900.00
A71FB8	2017-07-04 14:36:00+03	198800.00
A71FCA	2017-07-15 02:35:00+03	28800.00
A71FD2	2017-08-12 14:46:00+03	681500.00
A71FF4	2017-07-27 06:45:00+03	43200.00
A7207B	2017-07-18 05:35:00+03	199700.00
A72081	2017-08-14 01:35:00+03	115200.00
A720DD	2017-08-14 00:25:00+03	73500.00
A7215E	2017-07-10 20:05:00+03	15800.00
A721A1	2017-07-28 07:16:00+03	131600.00
A72200	2017-07-11 15:13:00+03	25600.00
A72218	2017-07-21 17:00:00+03	119500.00
A7225F	2017-08-13 17:49:00+03	111600.00
A722EE	2017-07-13 06:36:00+03	66400.00
A72323	2017-07-23 07:37:00+03	56000.00
A7234F	2017-07-30 00:45:00+03	40600.00
A72396	2017-08-11 08:12:00+03	59300.00
A723A4	2017-07-10 21:34:00+03	147200.00
A723E2	2017-07-06 07:00:00+03	23600.00
A72430	2017-07-04 04:11:00+03	79600.00
A7243D	2017-07-29 10:02:00+03	61800.00
A724E7	2017-08-05 01:29:00+03	91000.00
A72535	2017-07-14 01:08:00+03	266400.00
A72542	2017-07-28 15:14:00+03	162200.00
A72557	2017-07-06 16:25:00+03	20600.00
A725C9	2017-07-14 06:29:00+03	34600.00
A72688	2017-06-30 21:42:00+03	32800.00
A726CB	2017-07-13 03:52:00+03	37900.00
A72750	2017-07-15 18:32:00+03	51600.00
A72754	2017-07-14 06:08:00+03	189800.00
A7276D	2017-08-14 06:10:00+03	13400.00
A727B8	2017-07-24 09:31:00+03	25600.00
A727C4	2017-08-13 01:15:00+03	14400.00
A72801	2017-07-24 07:58:00+03	13800.00
A72829	2017-07-26 18:47:00+03	129200.00
A7286D	2017-07-11 00:17:00+03	38600.00
A7287F	2017-08-10 15:34:00+03	24400.00
A728A1	2017-07-09 01:01:00+03	56000.00
A728AD	2017-08-01 08:41:00+03	117200.00
A728D9	2017-07-31 23:54:00+03	104600.00
A7292D	2017-07-14 06:57:00+03	8400.00
A72969	2017-07-18 16:10:00+03	135600.00
A7296F	2017-07-07 14:23:00+03	172100.00
A72996	2017-07-09 05:42:00+03	36200.00
A729A0	2017-07-19 22:28:00+03	72200.00
A72A78	2017-07-01 20:50:00+03	58400.00
A72B08	2017-07-11 10:50:00+03	372500.00
A72B0C	2017-07-12 16:27:00+03	117600.00
A72B55	2017-07-15 04:55:00+03	28000.00
A72B66	2017-07-14 17:15:00+03	67000.00
A72B6A	2017-07-18 18:09:00+03	291000.00
A72B9A	2017-07-24 13:37:00+03	47400.00
A72C36	2017-07-04 05:00:00+03	73600.00
A72C37	2017-07-01 00:06:00+03	76600.00
A72C53	2017-07-03 09:04:00+03	73200.00
A72C88	2017-08-10 17:16:00+03	44500.00
A72CAA	2017-07-17 09:33:00+03	23900.00
A72CD3	2017-08-01 07:48:00+03	27200.00
A72DCD	2017-07-29 22:52:00+03	40100.00
A72E39	2017-07-07 20:22:00+03	34000.00
A72E67	2017-08-06 14:51:00+03	7400.00
A72E79	2017-08-10 10:49:00+03	87000.00
A72ED3	2017-07-19 19:20:00+03	43000.00
A72ED5	2017-07-08 12:17:00+03	61800.00
A72EDE	2017-08-02 06:49:00+03	63500.00
A72EE8	2017-07-12 10:33:00+03	23400.00
A72EEC	2017-07-28 08:57:00+03	246000.00
A72EF7	2017-07-22 06:51:00+03	66000.00
A72F13	2017-07-15 09:20:00+03	57200.00
A72F57	2017-07-22 00:25:00+03	46200.00
A72F73	2017-07-02 13:13:00+03	10600.00
A72F9B	2017-07-23 15:32:00+03	58200.00
A72FEF	2017-07-09 07:30:00+03	147700.00
A73008	2017-07-06 09:52:00+03	92100.00
A73013	2017-07-24 12:06:00+03	58800.00
A73052	2017-07-22 02:22:00+03	31600.00
A73094	2017-08-06 22:48:00+03	77600.00
A730E5	2017-07-09 01:14:00+03	86500.00
A7311A	2017-07-28 17:11:00+03	182100.00
A7311F	2017-08-13 08:18:00+03	56100.00
A7314E	2017-07-10 01:46:00+03	83000.00
A7318A	2017-07-16 04:37:00+03	13200.00
A731C1	2017-07-17 01:59:00+03	54000.00
A731D9	2017-08-12 19:06:00+03	22000.00
A731E8	2017-07-19 18:29:00+03	14800.00
A73203	2017-07-20 09:52:00+03	24400.00
A7320E	2017-08-10 22:48:00+03	20600.00
A73212	2017-07-12 20:33:00+03	28000.00
A732C2	2017-07-23 04:17:00+03	39400.00
A732DF	2017-08-15 03:40:00+03	75300.00
A73347	2017-07-31 04:17:00+03	132800.00
A73389	2017-08-14 15:26:00+03	21800.00
A7339E	2017-07-29 10:12:00+03	128800.00
A733ED	2017-07-07 03:03:00+03	73100.00
A734E6	2017-08-05 20:04:00+03	23200.00
A73500	2017-07-02 19:23:00+03	40100.00
A7353B	2017-08-15 07:20:00+03	156100.00
A73586	2017-07-24 00:36:00+03	140300.00
A735A0	2017-08-06 09:06:00+03	169900.00
A735AE	2017-07-20 16:10:00+03	46000.00
A735C7	2017-07-04 10:49:00+03	97900.00
A73689	2017-07-20 04:15:00+03	70700.00
A736CB	2017-08-08 13:56:00+03	38600.00
A736F6	2017-07-30 20:48:00+03	21200.00
A736F7	2017-07-01 07:38:00+03	31000.00
A7370B	2017-07-28 03:56:00+03	73200.00
A7372D	2017-07-05 10:23:00+03	31100.00
A73739	2017-07-10 04:16:00+03	18300.00
A737CC	2017-07-21 07:06:00+03	32800.00
A737EC	2017-08-11 22:36:00+03	50100.00
A73855	2017-08-05 09:38:00+03	55800.00
A738A7	2017-07-26 12:47:00+03	581000.00
A738D9	2017-08-06 07:53:00+03	136000.00
A7396B	2017-08-08 10:00:00+03	57600.00
A739D9	2017-07-25 08:30:00+03	206400.00
A73A88	2017-07-16 05:12:00+03	265700.00
A73ABF	2017-07-26 13:35:00+03	20400.00
A73AC8	2017-08-07 09:47:00+03	31400.00
A73AF5	2017-08-04 19:46:00+03	88500.00
A73B61	2017-07-23 04:45:00+03	33300.00
A73BC9	2017-07-22 22:53:00+03	54500.00
A73C2A	2017-07-14 05:51:00+03	58600.00
A73C3B	2017-07-17 02:02:00+03	6700.00
A73C75	2017-07-25 10:35:00+03	40000.00
A73CAA	2017-08-07 07:25:00+03	97600.00
A73D0F	2017-08-09 16:09:00+03	30200.00
A73E50	2017-08-12 04:55:00+03	200400.00
A73E53	2017-07-24 03:18:00+03	117600.00
A73F35	2017-07-03 08:50:00+03	23400.00
A73F8F	2017-07-20 07:52:00+03	49100.00
A73FE5	2017-07-11 15:56:00+03	123000.00
A7405D	2017-08-14 14:15:00+03	37900.00
A740A8	2017-07-11 23:19:00+03	6000.00
A740B0	2017-07-22 05:02:00+03	213200.00
A740B3	2017-07-15 01:34:00+03	38400.00
A740F3	2017-07-31 02:34:00+03	92800.00
A741CA	2017-08-05 16:38:00+03	90400.00
A741CC	2017-08-13 19:55:00+03	6700.00
A741FF	2017-08-11 00:27:00+03	23400.00
A74227	2017-08-03 17:21:00+03	26000.00
A74228	2017-07-18 10:12:00+03	53400.00
A7429B	2017-07-11 22:03:00+03	29400.00
A742A7	2017-08-04 05:48:00+03	28800.00
A742AA	2017-07-26 17:51:00+03	31600.00
A742C0	2017-07-09 22:42:00+03	43800.00
A74334	2017-08-14 03:40:00+03	189800.00
A7434B	2017-07-25 06:10:00+03	92300.00
A74387	2017-08-11 04:14:00+03	44000.00
A74392	2017-07-02 13:42:00+03	38400.00
A743B2	2017-08-13 11:43:00+03	59800.00
A743DB	2017-07-18 23:13:00+03	8000.00
A74434	2017-08-07 07:22:00+03	87400.00
A74454	2017-07-03 00:12:00+03	73500.00
A74469	2017-07-07 00:08:00+03	65900.00
A744FC	2017-08-07 00:22:00+03	29800.00
A7452B	2017-07-14 03:24:00+03	199000.00
A745C6	2017-07-07 17:41:00+03	155600.00
A74622	2017-07-09 14:17:00+03	44000.00
A74627	2017-07-16 19:33:00+03	48800.00
A74636	2017-06-30 15:01:00+03	61700.00
A74667	2017-07-18 17:22:00+03	22600.00
A746EE	2017-08-03 14:11:00+03	44600.00
A74714	2017-07-17 22:20:00+03	136800.00
A74750	2017-07-20 13:01:00+03	26000.00
A74783	2017-07-13 07:24:00+03	266400.00
A7478F	2017-07-23 03:43:00+03	41800.00
A747FE	2017-07-29 04:21:00+03	48800.00
A7484C	2017-07-06 18:14:00+03	39100.00
A74889	2017-08-13 01:26:00+03	91400.00
A748AE	2017-08-10 15:12:00+03	40600.00
A748B9	2017-07-31 00:38:00+03	27900.00
A748C3	2017-07-27 13:27:00+03	28700.00
A74929	2017-07-10 17:00:00+03	304300.00
A74981	2017-08-02 14:35:00+03	89700.00
A7499A	2017-07-20 10:32:00+03	58200.00
A749B8	2017-07-24 03:11:00+03	40000.00
A74A3A	2017-07-02 17:10:00+03	14000.00
A74A56	2017-07-12 08:32:00+03	26700.00
A74AA3	2017-07-19 08:22:00+03	59800.00
A74AD9	2017-07-25 08:40:00+03	71200.00
A74B1F	2017-08-09 03:30:00+03	34000.00
A74BAE	2017-07-03 14:52:00+03	269400.00
A74C15	2017-07-15 14:50:00+03	73600.00
A74D42	2017-07-09 13:27:00+03	54500.00
A74DCC	2017-07-06 17:58:00+03	95700.00
A74E15	2017-07-24 22:44:00+03	62400.00
A74E24	2017-08-06 07:17:00+03	76600.00
A74E3B	2017-08-03 15:21:00+03	94000.00
A74E64	2017-08-07 18:11:00+03	85000.00
A74E7E	2017-07-17 10:55:00+03	242700.00
A74EA1	2017-07-29 20:58:00+03	23400.00
A74F0C	2017-06-30 21:35:00+03	12600.00
A74FED	2017-08-14 22:00:00+03	100000.00
A7500C	2017-07-24 11:53:00+03	67200.00
A750ED	2017-07-23 01:26:00+03	66700.00
A7510E	2017-07-19 09:02:00+03	48800.00
A7519A	2017-06-27 16:31:00+03	22000.00
A751FA	2017-07-06 02:07:00+03	109200.00
A75209	2017-07-04 17:58:00+03	56000.00
A75234	2017-07-04 20:59:00+03	44600.00
A7524F	2017-07-23 22:43:00+03	42900.00
A75281	2017-07-30 12:07:00+03	56000.00
A752BE	2017-07-27 02:29:00+03	48500.00
A75303	2017-07-24 04:42:00+03	31100.00
A75306	2017-07-15 14:17:00+03	56100.00
A7535A	2017-07-12 16:13:00+03	40000.00
A753E7	2017-08-12 15:06:00+03	36200.00
A7540B	2017-07-18 22:42:00+03	172200.00
A75460	2017-08-07 19:46:00+03	46400.00
A7546D	2017-07-21 14:39:00+03	173600.00
A75482	2017-08-07 21:29:00+03	56000.00
A75497	2017-08-07 19:04:00+03	332200.00
A754CC	2017-07-28 14:56:00+03	62600.00
A754D6	2017-07-13 20:20:00+03	25400.00
A75521	2017-07-13 23:31:00+03	40000.00
A7554D	2017-07-17 06:05:00+03	271100.00
A7556B	2017-07-28 17:45:00+03	30200.00
A75669	2017-07-27 09:04:00+03	166100.00
A75681	2017-08-15 17:33:00+03	113700.00
A75688	2017-07-03 13:53:00+03	78300.00
A756A0	2017-07-09 11:48:00+03	189200.00
A756E1	2017-07-22 06:07:00+03	52700.00
A756FC	2017-06-30 04:46:00+03	33100.00
A7577F	2017-08-06 03:52:00+03	18400.00
A757CE	2017-08-06 07:48:00+03	78900.00
A757F7	2017-06-29 21:28:00+03	55800.00
A75814	2017-07-28 01:47:00+03	75300.00
A7585A	2017-07-14 11:09:00+03	13200.00
A75872	2017-08-06 18:37:00+03	22200.00
A758BF	2017-07-10 01:44:00+03	43600.00
A7590C	2017-08-14 02:42:00+03	47500.00
A75917	2017-07-12 03:30:00+03	13400.00
A7593A	2017-07-30 14:40:00+03	59300.00
A759AE	2017-07-28 08:24:00+03	34200.00
A75A66	2017-07-04 17:10:00+03	70000.00
A75A7F	2017-07-04 06:29:00+03	28000.00
A75A8D	2017-08-14 06:49:00+03	174400.00
A75B89	2017-07-22 16:43:00+03	97700.00
A75BAC	2017-07-02 08:13:00+03	32400.00
A75C19	2017-07-11 23:54:00+03	22600.00
A75C3D	2017-07-04 07:34:00+03	67200.00
A75C6A	2017-07-17 10:44:00+03	78400.00
A75CA9	2017-07-02 18:23:00+03	168000.00
A75CB0	2017-08-03 09:00:00+03	11700.00
A75CE2	2017-07-03 17:47:00+03	136500.00
A75CE3	2017-07-14 22:06:00+03	36200.00
A75D11	2017-07-16 01:36:00+03	86800.00
A75D27	2017-07-01 01:48:00+03	23200.00
A75D3D	2017-08-11 20:04:00+03	272400.00
A75D43	2017-07-18 03:17:00+03	42800.00
A75D5C	2017-07-04 13:26:00+03	65400.00
A75DA3	2017-07-10 22:15:00+03	21800.00
A75DA8	2017-07-25 02:40:00+03	81200.00
A75DD9	2017-08-13 02:15:00+03	37100.00
A75E04	2017-07-28 19:06:00+03	123000.00
A75E14	2017-08-07 06:15:00+03	25200.00
A75E6C	2017-08-03 20:18:00+03	24400.00
A75E6F	2017-07-17 00:51:00+03	7400.00
A75E9A	2017-07-26 11:33:00+03	69600.00
A75E9F	2017-07-10 09:51:00+03	290500.00
A75EAD	2017-07-16 23:06:00+03	54800.00
A75EAF	2017-07-25 21:50:00+03	46400.00
A75ECC	2017-07-09 10:05:00+03	101800.00
A75EEE	2017-07-31 04:00:00+03	24400.00
A75F04	2017-08-04 15:20:00+03	131100.00
A75F99	2017-07-07 07:20:00+03	99300.00
A75FA5	2017-08-02 11:22:00+03	119500.00
A75FAD	2017-07-13 07:01:00+03	70700.00
A75FAF	2017-07-13 04:52:00+03	56000.00
A75FD0	2017-06-30 14:38:00+03	72200.00
A75FEB	2017-08-05 06:11:00+03	36800.00
A75FEC	2017-08-01 16:28:00+03	23200.00
A76025	2017-08-05 03:34:00+03	102100.00
A76029	2017-07-10 19:13:00+03	53500.00
A76145	2017-07-05 04:27:00+03	47200.00
A7614C	2017-07-04 19:11:00+03	58400.00
A76194	2017-07-15 18:25:00+03	44600.00
A761C1	2017-07-03 05:39:00+03	38600.00
A761C2	2017-07-12 01:38:00+03	152100.00
A7624A	2017-07-09 06:36:00+03	60400.00
A76292	2017-07-19 15:53:00+03	155500.00
A762C7	2017-08-03 19:38:00+03	36400.00
A762EC	2017-07-20 09:34:00+03	139500.00
A762F5	2017-07-16 01:55:00+03	38600.00
A7634F	2017-07-14 17:33:00+03	47100.00
A763EA	2017-07-08 18:36:00+03	51900.00
A763FE	2017-07-27 05:02:00+03	18000.00
A76492	2017-07-25 20:32:00+03	406700.00
A764C2	2017-07-09 21:24:00+03	13600.00
A764C8	2017-07-04 15:47:00+03	52800.00
A764DD	2017-07-17 05:10:00+03	47500.00
A764DF	2017-08-05 22:38:00+03	58600.00
A76514	2017-08-04 21:34:00+03	67600.00
A76530	2017-07-28 08:51:00+03	131100.00
A7659F	2017-08-14 06:32:00+03	32200.00
A76613	2017-07-13 15:58:00+03	113200.00
A766BB	2017-08-07 17:07:00+03	97700.00
A766D4	2017-07-17 00:51:00+03	57500.00
A76749	2017-07-13 12:38:00+03	123000.00
A7675B	2017-08-10 12:09:00+03	56000.00
A76773	2017-07-04 15:32:00+03	67800.00
A76783	2017-07-30 21:33:00+03	82900.00
A76794	2017-08-06 23:06:00+03	44600.00
A76847	2017-07-21 15:43:00+03	105600.00
A7687C	2017-07-28 09:29:00+03	43000.00
A7690D	2017-08-04 20:53:00+03	45200.00
A769AF	2017-07-03 10:18:00+03	123000.00
A76A04	2017-07-09 00:08:00+03	64800.00
A76A44	2017-07-15 01:38:00+03	70400.00
A76A49	2017-07-29 22:30:00+03	246000.00
A76A7F	2017-07-14 05:52:00+03	37100.00
A76A94	2017-07-08 06:51:00+03	46800.00
A76B17	2017-07-07 09:19:00+03	85800.00
A76B5E	2017-07-14 17:26:00+03	93800.00
A76BB4	2017-07-03 14:24:00+03	64700.00
A76BC7	2017-07-13 03:07:00+03	47100.00
A76BF2	2017-08-07 20:08:00+03	33100.00
A76CA2	2017-07-14 09:51:00+03	271100.00
A76CBA	2017-08-06 03:52:00+03	38800.00
A76D33	2017-07-21 10:17:00+03	57400.00
A76D47	2017-07-16 23:38:00+03	20500.00
A76D6D	2017-08-11 13:54:00+03	56600.00
A76DE5	2017-08-04 02:28:00+03	160800.00
A76E06	2017-07-02 20:14:00+03	13400.00
A76E0A	2017-07-29 09:49:00+03	93900.00
A76E34	2017-08-11 06:02:00+03	20000.00
A76E3E	2017-08-03 05:19:00+03	77500.00
A76E83	2017-08-10 21:25:00+03	12600.00
A76ECB	2017-07-21 16:58:00+03	62600.00
A76F33	2017-08-14 19:27:00+03	46400.00
A76F81	2017-08-14 16:44:00+03	144400.00
A76F89	2017-07-01 10:24:00+03	76600.00
A76F90	2017-08-12 15:58:00+03	24400.00
A76F9B	2017-07-23 08:02:00+03	529800.00
A76FAC	2017-07-15 00:44:00+03	87400.00
A76FC2	2017-07-10 14:29:00+03	52600.00
A76FE8	2017-07-08 04:55:00+03	283300.00
A77005	2017-07-15 15:12:00+03	46400.00
A77018	2017-07-28 21:12:00+03	109600.00
A7703E	2017-07-22 17:35:00+03	29600.00
A77056	2017-07-06 14:26:00+03	56600.00
A77061	2017-07-08 17:09:00+03	47600.00
A770ED	2017-08-11 07:47:00+03	71400.00
A7711A	2017-07-10 17:32:00+03	64400.00
A7719B	2017-07-18 23:10:00+03	31400.00
A771A7	2017-08-04 05:31:00+03	52800.00
A771B5	2017-07-15 09:48:00+03	44600.00
A771FA	2017-07-04 18:22:00+03	197000.00
A7721C	2017-07-23 01:31:00+03	107200.00
A77296	2017-08-15 08:38:00+03	199100.00
A772DC	2017-07-18 07:59:00+03	76300.00
A77351	2017-08-14 17:38:00+03	23600.00
A77364	2017-07-24 22:39:00+03	23200.00
A773CB	2017-08-08 22:31:00+03	29600.00
A7741E	2017-08-09 18:11:00+03	112000.00
A7744A	2017-07-06 18:17:00+03	68000.00
A774ED	2017-08-01 00:08:00+03	41600.00
A774F0	2017-07-28 11:47:00+03	54500.00
A775C8	2017-07-26 17:36:00+03	55900.00
A77656	2017-08-05 13:46:00+03	58800.00
A776D4	2017-08-07 21:40:00+03	166100.00
A776F2	2017-07-03 12:13:00+03	73600.00
A77716	2017-08-09 16:43:00+03	17200.00
A7772C	2017-08-11 02:04:00+03	115800.00
A77734	2017-07-30 08:49:00+03	47500.00
A7773F	2017-07-27 07:07:00+03	23200.00
A77753	2017-07-24 05:54:00+03	407400.00
A7778D	2017-07-30 13:15:00+03	92000.00
A77795	2017-08-13 20:48:00+03	266500.00
A77799	2017-07-28 14:37:00+03	136200.00
A777A2	2017-07-08 15:19:00+03	28800.00
A777E3	2017-08-07 13:28:00+03	100600.00
A77859	2017-08-04 13:32:00+03	266200.00
A778AE	2017-07-13 16:13:00+03	20600.00
A778DA	2017-08-03 17:33:00+03	132800.00
A77938	2017-07-03 07:12:00+03	76600.00
A77A10	2017-08-10 11:27:00+03	73600.00
A77AAA	2017-07-11 23:10:00+03	60400.00
A77AAC	2017-07-08 21:05:00+03	123000.00
A77AF4	2017-06-26 22:51:00+03	47400.00
A77AF5	2017-07-14 19:00:00+03	46400.00
A77B1B	2017-08-07 13:40:00+03	29600.00
A77B4F	2017-08-12 13:52:00+03	130200.00
A77B5D	2017-08-08 18:40:00+03	23200.00
A77B7B	2017-07-11 06:04:00+03	27400.00
A77B7F	2017-07-19 19:50:00+03	95200.00
A77B94	2017-07-08 08:50:00+03	55500.00
A77C50	2017-07-21 20:48:00+03	77500.00
A77C5C	2017-08-03 18:29:00+03	62600.00
A77D24	2017-07-18 21:24:00+03	146300.00
A77DA6	2017-08-02 20:49:00+03	39900.00
A77DBD	2017-08-15 05:53:00+03	11700.00
A77DEF	2017-08-02 07:48:00+03	150500.00
A77E32	2017-07-03 06:41:00+03	46000.00
A77EC7	2017-08-02 06:58:00+03	81200.00
A77EE0	2017-08-04 16:32:00+03	6800.00
A77F36	2017-08-06 08:57:00+03	19600.00
A77F41	2017-08-15 10:02:00+03	163800.00
A77F45	2017-07-24 21:16:00+03	28800.00
A77F54	2017-07-12 21:34:00+03	86500.00
A77FA4	2017-08-02 17:17:00+03	53600.00
A77FED	2017-07-12 04:26:00+03	26700.00
A7809A	2017-08-01 00:02:00+03	47000.00
A780B9	2017-08-11 05:17:00+03	91900.00
A780F4	2017-07-11 00:03:00+03	26800.00
A78153	2017-07-12 12:43:00+03	81600.00
A78180	2017-07-09 11:19:00+03	114600.00
A7819A	2017-08-13 22:48:00+03	14400.00
A781E2	2017-07-22 05:25:00+03	57800.00
A781E3	2017-07-14 13:54:00+03	28800.00
A7824E	2017-08-01 01:39:00+03	51400.00
A7826A	2017-07-17 00:25:00+03	25400.00
A7830C	2017-07-20 17:37:00+03	136800.00
A78321	2017-07-27 19:10:00+03	270800.00
A7838A	2017-07-24 00:50:00+03	50800.00
A78393	2017-08-01 07:47:00+03	70700.00
A783B1	2017-08-13 02:42:00+03	28800.00
A783BB	2017-08-03 20:11:00+03	186900.00
A78426	2017-08-14 15:48:00+03	23200.00
A78428	2017-07-10 00:00:00+03	54600.00
A78452	2017-07-20 09:10:00+03	166900.00
A7852E	2017-07-19 05:23:00+03	103500.00
A7858C	2017-07-17 23:53:00+03	8200.00
A785B2	2017-07-28 21:20:00+03	56000.00
A785E6	2017-07-15 22:23:00+03	270800.00
A78610	2017-07-13 20:03:00+03	46000.00
A7865C	2017-08-10 05:15:00+03	133100.00
A78660	2017-08-13 05:14:00+03	58600.00
A7868E	2017-06-26 02:39:00+03	28700.00
A786AC	2017-07-14 22:22:00+03	97300.00
A786EE	2017-07-08 05:10:00+03	61800.00
A787AF	2017-08-13 20:30:00+03	14800.00
A787B9	2017-07-10 05:53:00+03	66400.00
A787C0	2017-08-02 18:01:00+03	531400.00
A7881A	2017-08-14 23:25:00+03	62600.00
A788AA	2017-07-31 15:38:00+03	37900.00
A78908	2017-07-20 07:18:00+03	35800.00
A78936	2017-07-15 17:30:00+03	92900.00
A78975	2017-07-14 16:04:00+03	62600.00
A789C3	2017-07-22 04:59:00+03	48800.00
A789D9	2017-07-30 21:45:00+03	54900.00
A78A95	2017-08-05 18:53:00+03	19600.00
A78ADE	2017-07-15 00:04:00+03	49900.00
A78AF3	2017-08-08 10:25:00+03	56000.00
A78B2D	2017-07-19 07:09:00+03	20200.00
A78B32	2017-07-09 18:44:00+03	123000.00
A78B4A	2017-07-10 11:55:00+03	12400.00
A78B62	2017-07-04 16:54:00+03	56000.00
A78B8E	2017-07-21 00:37:00+03	26000.00
A78BB3	2017-08-04 15:00:00+03	39200.00
A78BD0	2017-08-08 07:08:00+03	381400.00
A78BEE	2017-07-29 17:50:00+03	75600.00
A78C3B	2017-08-14 22:56:00+03	131800.00
A78C3F	2017-07-05 07:24:00+03	38200.00
A78C87	2017-08-09 08:37:00+03	99200.00
A78C8D	2017-08-01 06:04:00+03	77500.00
A78CB6	2017-08-15 14:00:00+03	31300.00
A78CBD	2017-07-20 21:42:00+03	75600.00
A78CF5	2017-07-15 22:24:00+03	38600.00
A78D62	2017-08-14 23:50:00+03	48200.00
A78E48	2017-08-12 02:36:00+03	56600.00
A78E66	2017-08-13 19:09:00+03	124000.00
A78E8A	2017-07-31 10:22:00+03	31400.00
A78ECE	2017-07-27 13:18:00+03	136500.00
A78F28	2017-08-03 12:15:00+03	13400.00
A78F36	2017-07-05 17:23:00+03	61800.00
A78F47	2017-07-10 10:53:00+03	89700.00
A78F66	2017-08-13 08:50:00+03	32800.00
A78FD0	2017-07-10 22:39:00+03	49800.00
A79019	2017-07-01 11:34:00+03	15700.00
A7902F	2017-07-03 02:53:00+03	9300.00
A79032	2017-08-06 18:12:00+03	170000.00
A790BF	2017-07-09 03:51:00+03	33300.00
A79153	2017-08-05 08:15:00+03	26800.00
A7919A	2017-08-11 09:57:00+03	149300.00
A791C1	2017-08-05 06:05:00+03	16400.00
A7928B	2017-07-23 11:28:00+03	138500.00
A792A3	2017-07-05 05:22:00+03	272300.00
A79357	2017-08-12 13:04:00+03	58200.00
A7936F	2017-08-07 23:00:00+03	42600.00
A7937E	2017-07-12 16:16:00+03	57700.00
A793AA	2017-07-25 06:13:00+03	28000.00
A793B4	2017-07-08 13:06:00+03	56600.00
A793B8	2017-07-15 06:57:00+03	67700.00
A793DA	2017-08-05 07:35:00+03	38600.00
A793EB	2017-08-04 09:58:00+03	92600.00
A793F0	2017-07-07 07:29:00+03	11800.00
A7940F	2017-07-27 01:11:00+03	67600.00
A79428	2017-08-07 08:00:00+03	12200.00
A79432	2017-07-17 03:39:00+03	12400.00
A79499	2017-07-12 12:33:00+03	27300.00
A794DD	2017-07-07 05:26:00+03	67600.00
A79508	2017-08-10 15:40:00+03	74600.00
A79598	2017-08-11 07:24:00+03	55800.00
A795CD	2017-07-23 00:12:00+03	21400.00
A795EA	2017-07-26 01:12:00+03	312900.00
A795F4	2017-08-01 19:37:00+03	28800.00
A79622	2017-07-12 13:53:00+03	26000.00
A79685	2017-08-13 16:37:00+03	137900.00
A796C2	2017-08-03 11:20:00+03	14000.00
A796C7	2017-07-20 10:17:00+03	62600.00
A796CF	2017-08-03 06:34:00+03	306800.00
A796DD	2017-07-02 07:01:00+03	21600.00
A79735	2017-08-04 02:48:00+03	72400.00
A7976E	2017-08-06 23:40:00+03	64800.00
A79788	2017-07-05 19:55:00+03	31600.00
A797D9	2017-07-23 13:40:00+03	26600.00
A79844	2017-07-02 08:31:00+03	14300.00
A79867	2017-07-14 07:35:00+03	100600.00
A79898	2017-08-07 19:47:00+03	105000.00
A79914	2017-08-03 02:42:00+03	19600.00
A799AD	2017-08-04 20:44:00+03	25000.00
A799EF	2017-08-01 15:50:00+03	57000.00
A79A34	2017-07-04 18:20:00+03	86600.00
A79AB1	2017-08-14 06:24:00+03	13400.00
A79B3A	2017-07-09 11:26:00+03	8000.00
A79B3F	2017-07-27 21:14:00+03	96300.00
A79B72	2017-08-01 15:03:00+03	30900.00
A79C79	2017-06-30 22:27:00+03	29400.00
A79C80	2017-07-09 03:47:00+03	113200.00
A79CDF	2017-07-23 14:16:00+03	43200.00
A79CFB	2017-08-06 07:25:00+03	246000.00
A79D70	2017-08-15 14:46:00+03	10600.00
A79D85	2017-08-15 17:44:00+03	3400.00
A79E06	2017-07-24 16:55:00+03	66600.00
A79E2E	2017-08-08 21:52:00+03	65200.00
A79E70	2017-07-17 15:43:00+03	19600.00
A79E8E	2017-07-15 03:27:00+03	28800.00
A79E92	2017-07-09 09:07:00+03	46000.00
A79EA7	2017-08-12 18:28:00+03	269100.00
A79ED0	2017-07-18 05:29:00+03	81700.00
A79ED5	2017-08-01 08:58:00+03	31400.00
A79EEB	2017-07-27 00:35:00+03	13300.00
A79F04	2017-07-16 05:53:00+03	28000.00
A79F54	2017-07-26 23:40:00+03	117600.00
A79FE2	2017-08-11 18:16:00+03	23200.00
A7A019	2017-07-05 05:49:00+03	76200.00
A7A01A	2017-07-31 22:18:00+03	60500.00
A7A039	2017-07-12 07:58:00+03	26800.00
A7A065	2017-08-09 21:59:00+03	103500.00
A7A0CA	2017-07-20 20:21:00+03	28300.00
A7A0FA	2017-07-30 08:01:00+03	173600.00
A7A147	2017-07-14 07:50:00+03	65900.00
A7A164	2017-08-03 17:01:00+03	65900.00
A7A19B	2017-07-25 17:21:00+03	26700.00
A7A217	2017-07-03 07:55:00+03	179400.00
A7A262	2017-07-31 06:21:00+03	132800.00
A7A2CD	2017-08-01 03:34:00+03	101200.00
A7A333	2017-07-06 07:00:00+03	133100.00
A7A3FF	2017-08-08 15:45:00+03	14000.00
A7A407	2017-08-04 18:16:00+03	46800.00
A7A40B	2017-07-07 13:54:00+03	45500.00
A7A425	2017-08-12 04:44:00+03	109200.00
A7A48D	2017-08-14 10:14:00+03	36200.00
A7A4DB	2017-07-20 13:26:00+03	79200.00
A7A53C	2017-07-08 12:28:00+03	23200.00
A7A569	2017-08-07 13:51:00+03	61500.00
A7A576	2017-07-17 06:33:00+03	54800.00
A7A658	2017-07-28 06:46:00+03	27200.00
A7A674	2017-07-05 02:11:00+03	23200.00
A7A687	2017-07-16 16:49:00+03	62200.00
A7A6B0	2017-07-03 04:18:00+03	24400.00
A7A6CE	2017-07-05 05:35:00+03	49100.00
A7A6FA	2017-08-14 20:40:00+03	26000.00
A7A776	2017-07-18 00:05:00+03	34000.00
A7A77A	2017-07-02 04:57:00+03	46400.00
A7A7E4	2017-08-10 20:14:00+03	56600.00
A7A7F1	2017-07-03 03:53:00+03	92700.00
A7A82F	2017-07-13 07:47:00+03	136100.00
A7A853	2017-07-22 13:25:00+03	32700.00
A7A88F	2017-07-27 08:27:00+03	49700.00
A7A8EC	2017-08-11 15:22:00+03	16800.00
A7A964	2017-07-11 22:12:00+03	40300.00
A7AA00	2017-07-25 13:03:00+03	47000.00
A7AA59	2017-07-19 11:22:00+03	26000.00
A7ABBA	2017-08-11 15:13:00+03	55800.00
A7ABBE	2017-07-05 10:00:00+03	70800.00
A7ABF4	2017-07-21 16:16:00+03	46500.00
A7AC60	2017-07-10 07:04:00+03	135600.00
A7ACA1	2017-07-15 11:16:00+03	19600.00
A7AD29	2017-08-04 21:52:00+03	265700.00
A7ADB0	2017-08-04 10:54:00+03	77900.00
A7ADB8	2017-08-09 05:32:00+03	67600.00
A7AE0D	2017-07-28 03:38:00+03	44700.00
A7AE1F	2017-07-03 02:01:00+03	198400.00
A7AE57	2017-07-16 18:39:00+03	16400.00
A7AEE8	2017-08-01 17:47:00+03	54300.00
A7AF1D	2017-07-12 00:41:00+03	124200.00
A7AF48	2017-08-14 17:59:00+03	103400.00
A7AF96	2017-07-21 09:52:00+03	58000.00
A7AFCD	2017-08-06 23:00:00+03	6000.00
A7AFF7	2017-07-17 09:59:00+03	22000.00
A7B019	2017-08-06 02:28:00+03	27200.00
A7B01E	2017-07-19 11:22:00+03	61500.00
A7B094	2017-07-16 07:40:00+03	200500.00
A7B0B8	2017-07-04 04:40:00+03	159800.00
A7B0CC	2017-07-08 22:27:00+03	454200.00
A7B0D5	2017-08-07 16:49:00+03	56000.00
A7B16D	2017-07-06 06:29:00+03	64500.00
A7B183	2017-07-11 08:51:00+03	114800.00
A7B1E3	2017-08-04 09:21:00+03	28800.00
A7B1EC	2017-08-13 20:40:00+03	187200.00
A7B209	2017-08-03 18:55:00+03	8000.00
A7B22F	2017-07-13 05:11:00+03	40100.00
A7B28B	2017-07-15 02:00:00+03	56000.00
A7B28D	2017-07-12 06:05:00+03	54800.00
A7B367	2017-08-11 20:24:00+03	58600.00
A7B387	2017-08-08 20:55:00+03	26000.00
A7B3C8	2017-07-23 07:58:00+03	73600.00
A7B4C9	2017-07-04 01:15:00+03	146300.00
A7B4E1	2017-07-11 06:05:00+03	142200.00
A7B582	2017-08-11 21:35:00+03	103000.00
A7B588	2017-07-12 17:08:00+03	50800.00
A7B59B	2017-08-07 21:28:00+03	133100.00
A7B60A	2017-06-27 06:31:00+03	188000.00
A7B63D	2017-08-14 06:13:00+03	57400.00
A7B69D	2017-08-05 13:35:00+03	26000.00
A7B6B2	2017-07-17 04:05:00+03	28800.00
A7B6C0	2017-07-07 08:27:00+03	96200.00
A7B6C9	2017-07-30 14:19:00+03	26500.00
A7B7C8	2017-08-08 09:42:00+03	48500.00
A7B7E5	2017-06-30 16:19:00+03	68100.00
A7B7EC	2017-08-08 00:07:00+03	52600.00
A7B816	2017-07-30 07:51:00+03	23200.00
A7B828	2017-07-15 19:14:00+03	46400.00
A7B856	2017-07-25 06:58:00+03	6700.00
A7B88A	2017-07-10 20:40:00+03	62700.00
A7B908	2017-07-10 08:39:00+03	10700.00
A7B934	2017-07-13 05:04:00+03	71800.00
A7B980	2017-07-16 13:34:00+03	369000.00
A7B981	2017-08-06 14:16:00+03	48900.00
A7B9A3	2017-07-10 21:07:00+03	135400.00
A7BA0C	2017-07-17 18:03:00+03	15200.00
A7BA2A	2017-08-01 19:08:00+03	86600.00
A7BA6B	2017-07-11 15:46:00+03	42000.00
A7BB02	2017-07-13 11:43:00+03	80700.00
A7BB35	2017-08-10 12:50:00+03	16400.00
A7BB72	2017-07-12 06:26:00+03	54200.00
A7BBD6	2017-08-07 13:22:00+03	20400.00
A7BC23	2017-08-12 15:07:00+03	112600.00
A7BC76	2017-07-13 04:55:00+03	246000.00
A7BC7A	2017-07-06 09:25:00+03	313800.00
A7BCD0	2017-07-31 06:51:00+03	115200.00
A7BCFE	2017-07-22 11:16:00+03	59300.00
A7BD16	2017-07-30 19:26:00+03	85000.00
A7BD3B	2017-08-06 09:36:00+03	47100.00
A7BD70	2017-08-12 20:03:00+03	26800.00
A7BE5A	2017-07-20 22:30:00+03	51400.00
A7BE7F	2017-08-02 10:06:00+03	77800.00
A7BE88	2017-06-30 22:30:00+03	25100.00
A7BE9D	2017-07-21 12:14:00+03	137700.00
A7BEC5	2017-07-14 00:31:00+03	24400.00
A7BF4B	2017-07-21 12:18:00+03	369000.00
A7C028	2017-08-09 01:20:00+03	26000.00
A7C05F	2017-08-09 07:40:00+03	72800.00
A7C066	2017-08-12 16:22:00+03	144700.00
A7C077	2017-07-14 05:43:00+03	26000.00
A7C084	2017-07-28 04:29:00+03	205400.00
A7C11A	2017-07-22 11:12:00+03	170600.00
A7C1AC	2017-07-05 07:47:00+03	248400.00
A7C224	2017-08-02 20:19:00+03	108500.00
A7C274	2017-07-05 01:06:00+03	58400.00
A7C290	2017-07-09 18:55:00+03	123000.00
A7C352	2017-07-25 10:03:00+03	113200.00
A7C3A1	2017-07-17 15:11:00+03	31600.00
A7C47E	2017-07-08 14:01:00+03	28000.00
A7C4AA	2017-07-28 21:55:00+03	8200.00
A7C4D7	2017-08-05 06:53:00+03	271100.00
A7C4E2	2017-08-07 10:49:00+03	65000.00
A7C4EB	2017-07-22 21:32:00+03	111600.00
A7C500	2017-07-01 22:37:00+03	38500.00
A7C526	2017-07-04 15:19:00+03	21800.00
A7C54A	2017-07-18 13:32:00+03	542300.00
A7C57F	2017-08-11 08:52:00+03	56000.00
A7C66C	2017-07-07 13:26:00+03	58800.00
A7C683	2017-07-22 19:53:00+03	21200.00
A7C6B3	2017-07-27 12:31:00+03	111000.00
A7C6B5	2017-07-03 02:41:00+03	149300.00
A7C6B9	2017-07-25 13:10:00+03	11600.00
A7C6ED	2017-07-11 16:22:00+03	65400.00
A7C730	2017-07-28 11:13:00+03	40000.00
A7C746	2017-07-23 11:50:00+03	38200.00
A7C74B	2017-07-05 07:02:00+03	114400.00
A7C7F6	2017-07-15 14:04:00+03	12600.00
A7C7FD	2017-08-14 12:49:00+03	39300.00
A7C80F	2017-07-16 06:45:00+03	29600.00
A7C8BF	2017-06-29 15:02:00+03	177600.00
A7C917	2017-07-24 16:15:00+03	42400.00
A7C971	2017-08-12 22:22:00+03	47200.00
A7C9A8	2017-07-24 14:36:00+03	46000.00
A7C9E7	2017-07-24 12:08:00+03	67600.00
A7CA08	2017-08-09 09:46:00+03	187400.00
A7CA49	2017-07-06 23:47:00+03	61800.00
A7CA4B	2017-07-18 14:44:00+03	25400.00
A7CB1D	2017-07-12 00:10:00+03	386300.00
A7CB23	2017-08-04 17:09:00+03	70600.00
A7CB32	2017-07-03 01:10:00+03	26000.00
A7CB76	2017-07-03 12:43:00+03	28800.00
A7CBB5	2017-08-02 04:29:00+03	112000.00
A7CBDE	2017-08-10 04:43:00+03	46200.00
A7CC32	2017-07-29 07:00:00+03	19800.00
A7CC40	2017-07-27 21:05:00+03	58400.00
A7CC5D	2017-07-07 02:49:00+03	92400.00
A7CC82	2017-07-05 15:16:00+03	86300.00
A7CC92	2017-07-18 10:56:00+03	26000.00
A7CCDB	2017-07-25 18:13:00+03	57500.00
A7CD02	2017-07-23 16:24:00+03	141000.00
A7CD09	2017-07-05 11:02:00+03	22000.00
A7CD95	2017-07-10 04:35:00+03	28800.00
A7CDAE	2017-08-01 14:24:00+03	150600.00
A7CE1D	2017-07-11 23:00:00+03	6000.00
A7CE4C	2017-08-04 14:06:00+03	80000.00
A7CE8F	2017-08-01 15:17:00+03	6700.00
A7CE9C	2017-07-11 15:22:00+03	44000.00
A7CEA6	2017-08-01 18:43:00+03	51600.00
A7CEAF	2017-07-24 07:20:00+03	28000.00
A7CF1C	2017-07-12 19:59:00+03	12000.00
A7CF1F	2017-07-29 13:08:00+03	28700.00
A7CF34	2017-07-12 19:32:00+03	27200.00
A7CF5E	2017-08-15 00:55:00+03	44800.00
A7CF6F	2017-07-02 19:31:00+03	114700.00
A7CF73	2017-08-03 20:31:00+03	139200.00
A7CF7E	2017-07-11 10:42:00+03	21600.00
A7D00F	2017-07-27 03:08:00+03	88500.00
A7D01C	2017-08-15 14:01:00+03	55500.00
A7D08C	2017-08-10 12:29:00+03	189800.00
A7D0A6	2017-08-09 12:25:00+03	29400.00
A7D0F5	2017-07-28 04:46:00+03	26000.00
A7D113	2017-07-23 18:33:00+03	136200.00
A7D1CB	2017-07-20 23:01:00+03	26300.00
A7D1E9	2017-07-21 01:06:00+03	46400.00
A7D1EC	2017-08-04 12:02:00+03	34000.00
A7D335	2017-08-12 09:32:00+03	12600.00
A7D3D1	2017-08-15 06:53:00+03	12600.00
A7D3DC	2017-08-07 15:13:00+03	157800.00
A7D478	2017-07-25 19:04:00+03	26800.00
A7D4D3	2017-07-28 04:48:00+03	14000.00
A7D50E	2017-08-12 15:41:00+03	28000.00
A7D521	2017-07-11 00:40:00+03	124600.00
A7D56F	2017-07-23 17:33:00+03	62000.00
A7D5DD	2017-06-30 03:57:00+03	25600.00
A7D601	2017-07-12 10:50:00+03	238600.00
A7D640	2017-08-09 02:11:00+03	131600.00
A7D655	2017-07-01 01:21:00+03	29200.00
A7D65D	2017-08-11 17:49:00+03	118100.00
A7D67C	2017-07-29 14:29:00+03	274300.00
A7D709	2017-07-16 20:35:00+03	7200.00
A7D787	2017-07-13 22:49:00+03	24400.00
A7D7D7	2017-08-08 01:55:00+03	55800.00
A7D7DD	2017-07-07 00:20:00+03	61800.00
A7D834	2017-07-25 09:22:00+03	22000.00
A7D883	2017-07-24 04:39:00+03	269400.00
A7D8B0	2017-07-16 14:46:00+03	23200.00
A7D908	2017-08-06 10:34:00+03	30900.00
A7D9C4	2017-07-02 16:13:00+03	25600.00
A7D9D6	2017-07-15 05:35:00+03	43600.00
A7DA35	2017-08-10 19:23:00+03	177200.00
A7DAB8	2017-08-12 18:24:00+03	31600.00
A7DAC2	2017-08-01 06:41:00+03	12600.00
A7DAE1	2017-08-07 07:07:00+03	62000.00
A7DB7E	2017-07-22 22:24:00+03	37100.00
A7DB87	2017-07-18 20:36:00+03	56000.00
A7DC06	2017-07-12 17:09:00+03	131100.00
A7DC18	2017-06-29 01:29:00+03	25800.00
A7DC4A	2017-07-24 03:22:00+03	42900.00
A7DC4D	2017-08-07 16:38:00+03	90400.00
A7DCBE	2017-08-01 15:31:00+03	133200.00
A7DD2D	2017-07-10 09:22:00+03	13600.00
A7DD41	2017-07-08 12:42:00+03	59400.00
A7DD54	2017-08-03 18:48:00+03	123000.00
A7DD5C	2017-07-07 10:25:00+03	24200.00
A7DDC9	2017-07-27 15:02:00+03	58900.00
A7DE22	2017-07-26 06:03:00+03	31400.00
A7DE31	2017-07-09 07:41:00+03	52400.00
A7DE9A	2017-08-03 08:04:00+03	72300.00
A7DEA1	2017-08-13 22:26:00+03	139700.00
A7DEC8	2017-08-01 10:40:00+03	3400.00
A7DFC0	2017-08-03 23:40:00+03	75300.00
A7DFE4	2017-07-26 19:35:00+03	515100.00
A7DFEE	2017-08-12 09:45:00+03	93900.00
A7E075	2017-08-10 21:41:00+03	26000.00
A7E095	2017-07-14 12:46:00+03	66600.00
A7E0D3	2017-07-20 22:50:00+03	29600.00
A7E0EB	2017-07-30 00:42:00+03	115900.00
A7E120	2017-08-02 17:44:00+03	66600.00
A7E1CD	2017-08-10 03:28:00+03	28000.00
A7E22D	2017-07-13 19:05:00+03	135600.00
A7E231	2017-07-20 11:57:00+03	24400.00
A7E262	2017-07-22 09:02:00+03	200800.00
A7E27D	2017-07-21 20:17:00+03	42800.00
A7E2B0	2017-08-10 22:56:00+03	20600.00
A7E34D	2017-07-20 22:20:00+03	179400.00
A7E404	2017-07-14 21:08:00+03	49400.00
A7E455	2017-08-07 14:01:00+03	269100.00
A7E45F	2017-07-09 15:44:00+03	55800.00
A7E471	2017-07-01 14:30:00+03	31200.00
A7E4BD	2017-07-31 01:03:00+03	123000.00
A7E54F	2017-07-28 22:40:00+03	20600.00
A7E559	2017-07-06 09:12:00+03	38000.00
A7E6A2	2017-06-30 05:05:00+03	269600.00
A7E6B0	2017-08-03 04:58:00+03	92800.00
A7E6B7	2017-08-08 08:18:00+03	73800.00
A7E6EF	2017-07-18 18:38:00+03	23400.00
A7E710	2017-08-08 02:59:00+03	146300.00
A7E774	2017-07-16 14:31:00+03	24000.00
A7E7C7	2017-07-18 20:52:00+03	22000.00
A7E82F	2017-08-02 07:29:00+03	27400.00
A7E851	2017-08-02 04:43:00+03	23200.00
A7E85C	2017-07-16 02:23:00+03	38200.00
A7E8B4	2017-07-04 15:16:00+03	28300.00
A7E905	2017-07-21 08:04:00+03	353300.00
A7E96D	2017-06-28 03:57:00+03	56900.00
A7E9AE	2017-08-15 07:30:00+03	90300.00
A7E9B8	2017-07-12 07:39:00+03	55600.00
A7E9C5	2017-07-06 14:58:00+03	51900.00
A7E9ED	2017-07-21 21:53:00+03	84900.00
A7EA1A	2017-08-15 01:30:00+03	47500.00
A7EA2F	2017-08-07 19:56:00+03	75800.00
A7EA32	2017-08-14 09:43:00+03	12400.00
A7EA88	2017-08-02 19:10:00+03	67900.00
A7EA94	2017-08-06 12:33:00+03	48700.00
A7EB48	2017-08-01 06:49:00+03	9800.00
A7EB60	2017-07-23 02:40:00+03	187600.00
A7EB84	2017-07-24 21:23:00+03	41400.00
A7EBD4	2017-06-29 22:45:00+03	35200.00
A7EC19	2017-07-12 07:54:00+03	6300.00
A7EC20	2017-07-24 01:01:00+03	73500.00
A7ECB2	2017-07-18 07:31:00+03	93900.00
A7ED18	2017-07-19 00:38:00+03	147100.00
A7ED36	2017-07-20 09:08:00+03	80400.00
A7ED5B	2017-07-06 16:59:00+03	56100.00
A7ED87	2017-08-10 04:06:00+03	53100.00
A7EDC0	2017-07-27 13:51:00+03	52100.00
A7EDDE	2017-07-18 04:04:00+03	55800.00
A7EE3E	2017-08-03 16:53:00+03	56000.00
A7EEB1	2017-07-11 14:50:00+03	46400.00
A7EEF9	2017-07-05 09:52:00+03	398500.00
A7EF42	2017-08-10 14:08:00+03	49000.00
A7EF57	2017-07-23 08:13:00+03	69500.00
A7EFA9	2017-07-09 23:40:00+03	42800.00
A7EFB1	2017-06-28 21:44:00+03	34000.00
A7EFE0	2017-07-02 10:41:00+03	63200.00
A7F06C	2017-07-06 02:03:00+03	201200.00
A7F0A8	2017-07-19 19:00:00+03	72000.00
A7F0D4	2017-07-11 07:19:00+03	55800.00
A7F114	2017-07-30 10:16:00+03	6800.00
A7F1B3	2017-08-04 08:00:00+03	248300.00
A7F1F8	2017-07-18 07:15:00+03	12600.00
A7F21D	2017-08-06 06:53:00+03	69500.00
A7F24B	2017-07-27 04:39:00+03	15400.00
A7F28F	2017-07-05 15:54:00+03	27500.00
A7F295	2017-08-15 04:59:00+03	40100.00
A7F2B6	2017-07-24 12:17:00+03	177200.00
A7F2E2	2017-07-25 10:23:00+03	24400.00
A7F2E5	2017-07-31 22:33:00+03	155700.00
A7F30A	2017-07-14 16:29:00+03	480700.00
A7F30E	2017-08-09 18:06:00+03	17600.00
A7F347	2017-08-02 12:54:00+03	58200.00
A7F34B	2017-07-29 20:35:00+03	11800.00
A7F35B	2017-07-27 14:58:00+03	56100.00
A7F3A5	2017-08-09 17:10:00+03	19600.00
A7F3C5	2017-08-09 20:38:00+03	31600.00
A7F3D2	2017-07-12 06:08:00+03	30400.00
A7F40F	2017-07-23 15:21:00+03	23200.00
A7F45B	2017-08-12 10:11:00+03	12000.00
A7F485	2017-07-05 19:51:00+03	30800.00
A7F4A5	2017-07-19 06:26:00+03	78400.00
A7F4AD	2017-07-22 00:48:00+03	133200.00
A7F4CC	2017-07-31 16:39:00+03	20200.00
A7F4E4	2017-08-07 09:22:00+03	27000.00
A7F4F6	2017-07-11 04:31:00+03	40600.00
A7F51A	2017-07-23 08:57:00+03	56000.00
A7F524	2017-07-06 14:35:00+03	132800.00
A7F562	2017-06-30 23:52:00+03	81600.00
A7F5B4	2017-07-16 18:38:00+03	49200.00
A7F5B6	2017-08-15 09:54:00+03	203000.00
A7F639	2017-07-11 22:36:00+03	73500.00
A7F66A	2017-08-04 06:06:00+03	58700.00
A7F678	2017-07-14 05:39:00+03	6700.00
A7F6D2	2017-08-09 11:31:00+03	243600.00
A7F6DD	2017-07-21 22:28:00+03	83600.00
A7F751	2017-07-15 18:40:00+03	177200.00
A7F7F3	2017-07-25 13:35:00+03	54800.00
A7F7FA	2017-08-01 01:55:00+03	37200.00
A7F80C	2017-07-25 07:08:00+03	110500.00
A7F85B	2017-07-09 08:12:00+03	53400.00
A7F8E9	2017-08-04 22:31:00+03	47400.00
A7F967	2017-08-07 13:04:00+03	62000.00
A7F968	2017-08-10 21:49:00+03	48900.00
A7F9B0	2017-08-04 17:22:00+03	271400.00
A7F9B6	2017-07-14 18:58:00+03	86800.00
A7F9BD	2017-06-30 23:12:00+03	124200.00
A7F9D3	2017-08-09 06:45:00+03	86600.00
A7F9E1	2017-07-11 17:51:00+03	29400.00
A7F9F7	2017-07-21 12:04:00+03	17200.00
A7FA04	2017-07-21 23:45:00+03	57500.00
A7FA06	2017-07-04 14:21:00+03	149200.00
A7FA1C	2017-07-29 23:12:00+03	93700.00
A7FACA	2017-07-11 20:50:00+03	117600.00
A7FB51	2017-08-12 17:13:00+03	125700.00
A7FB73	2017-08-15 03:45:00+03	258600.00
A7FBA7	2017-08-13 16:36:00+03	86000.00
A7FBFE	2017-07-03 10:31:00+03	84500.00
A7FC0C	2017-07-31 01:14:00+03	57200.00
A7FC8B	2017-08-12 05:09:00+03	185500.00
A7FCCD	2017-08-04 09:49:00+03	46500.00
A7FCF9	2017-07-22 03:33:00+03	75800.00
A7FD40	2017-08-09 13:03:00+03	14000.00
A7FD56	2017-08-13 01:00:00+03	102300.00
A7FD68	2017-07-12 21:20:00+03	141600.00
A7FD6B	2017-07-28 09:24:00+03	36400.00
A7FD8C	2017-08-10 09:08:00+03	101200.00
A7FDF1	2017-08-01 12:59:00+03	119500.00
A7FDF9	2017-07-14 08:39:00+03	35200.00
A7FE2E	2017-08-07 07:19:00+03	37100.00
A7FE4D	2017-07-24 22:53:00+03	119600.00
A7FE52	2017-07-12 02:14:00+03	12600.00
A7FE99	2017-07-07 21:03:00+03	45200.00
A7FEA3	2017-07-11 05:05:00+03	24800.00
A7FEAB	2017-07-21 10:06:00+03	72400.00
A7FF61	2017-08-11 10:15:00+03	85200.00
A7FF68	2017-07-15 10:17:00+03	49100.00
A7FFFF	2017-07-24 20:49:00+03	112000.00
A8002A	2017-07-14 22:59:00+03	26100.00
A80080	2017-07-16 13:16:00+03	24200.00
A800A5	2017-07-18 17:16:00+03	88600.00
A800B4	2017-08-05 16:42:00+03	46400.00
A800F0	2017-08-06 06:18:00+03	41200.00
A80144	2017-07-09 04:56:00+03	133900.00
A80183	2017-07-15 21:28:00+03	45400.00
A801A5	2017-07-02 20:44:00+03	136200.00
A801B3	2017-08-01 06:50:00+03	73300.00
A801B5	2017-08-07 01:45:00+03	47400.00
A801D4	2017-07-07 01:27:00+03	84400.00
A801ED	2017-08-07 18:44:00+03	70800.00
A801F2	2017-07-10 03:36:00+03	75300.00
A8021D	2017-07-14 09:47:00+03	78600.00
A80220	2017-08-01 18:10:00+03	61500.00
A8023C	2017-07-24 14:41:00+03	42800.00
A8023E	2017-08-07 15:19:00+03	393000.00
A80249	2017-08-13 11:15:00+03	99200.00
A8027E	2017-08-12 17:01:00+03	114600.00
A80298	2017-07-19 11:12:00+03	75000.00
A8029D	2017-07-14 20:01:00+03	37900.00
A80316	2017-08-07 15:06:00+03	27600.00
A80353	2017-07-02 13:35:00+03	83700.00
A80372	2017-07-22 06:02:00+03	265800.00
A8037E	2017-08-02 00:52:00+03	119700.00
A803B9	2017-08-12 19:49:00+03	36200.00
A803C1	2017-07-21 08:57:00+03	101200.00
A80401	2017-07-21 18:05:00+03	102700.00
A80424	2017-07-16 17:41:00+03	131600.00
A80434	2017-06-27 04:39:00+03	46300.00
A80439	2017-08-09 13:30:00+03	13200.00
A8045B	2017-07-04 17:08:00+03	109600.00
A8046B	2017-07-24 17:02:00+03	396500.00
A804BB	2017-07-11 02:21:00+03	13600.00
A804D8	2017-08-13 12:49:00+03	13400.00
A804E7	2017-07-29 01:39:00+03	256300.00
A8055A	2017-08-04 00:53:00+03	47200.00
A80592	2017-07-01 22:17:00+03	77500.00
A805A3	2017-06-25 06:14:00+03	24800.00
A805CE	2017-07-20 17:40:00+03	51200.00
A80610	2017-07-18 10:34:00+03	93900.00
A80629	2017-07-15 05:52:00+03	65900.00
A8063C	2017-08-02 08:44:00+03	20000.00
A806A9	2017-07-24 06:41:00+03	56000.00
A80740	2017-08-09 09:14:00+03	6400.00
A80743	2017-08-01 11:46:00+03	66600.00
A80786	2017-08-06 20:28:00+03	59200.00
A8080E	2017-08-05 04:28:00+03	27400.00
A80846	2017-07-24 03:04:00+03	23200.00
A80848	2017-08-05 08:45:00+03	67600.00
A8087A	2017-07-21 00:39:00+03	88700.00
A808AF	2017-06-30 23:00:00+03	6300.00
A808B3	2017-07-30 01:00:00+03	27200.00
A808D5	2017-07-12 19:05:00+03	151200.00
A8095F	2017-07-23 22:38:00+03	131600.00
A80996	2017-07-30 00:51:00+03	128100.00
A809AA	2017-07-13 06:38:00+03	25000.00
A809EB	2017-07-14 22:13:00+03	28000.00
A80A38	2017-07-27 23:14:00+03	81900.00
A80A7E	2017-08-06 03:32:00+03	44800.00
A80A9D	2017-06-28 01:28:00+03	75300.00
A80B41	2017-07-22 03:04:00+03	138000.00
A80B79	2017-07-30 05:30:00+03	86200.00
A80BFB	2017-07-21 02:14:00+03	56000.00
A80C14	2017-07-07 07:18:00+03	38600.00
A80C45	2017-08-14 17:57:00+03	33100.00
A80CAA	2017-07-24 06:31:00+03	78500.00
A80CB1	2017-07-19 18:40:00+03	61800.00
A80CCB	2017-07-30 22:17:00+03	147700.00
A80CDB	2017-07-04 14:18:00+03	111600.00
A80D10	2017-07-06 22:43:00+03	28000.00
A80D18	2017-07-17 05:16:00+03	148200.00
A80D37	2017-07-19 16:11:00+03	89100.00
A80D46	2017-07-18 02:48:00+03	28000.00
A80D48	2017-08-15 04:01:00+03	175500.00
A80D5B	2017-07-14 14:07:00+03	101200.00
A80DC5	2017-07-28 19:48:00+03	23600.00
A80DFF	2017-08-05 18:22:00+03	93900.00
A80E5B	2017-07-09 13:59:00+03	21400.00
A80E79	2017-07-23 13:43:00+03	56600.00
A80ED5	2017-07-15 20:38:00+03	19600.00
A80F0F	2017-08-08 20:01:00+03	82000.00
A80F40	2017-07-04 16:57:00+03	90000.00
A80F45	2017-07-15 09:50:00+03	32300.00
A80F5C	2017-07-19 08:26:00+03	246000.00
A81035	2017-07-28 06:55:00+03	94900.00
A810A6	2017-08-01 20:16:00+03	23600.00
A810B3	2017-08-01 03:06:00+03	32900.00
A810D1	2017-07-29 04:00:00+03	106100.00
A8110B	2017-07-09 18:15:00+03	85000.00
A81199	2017-07-04 15:18:00+03	155300.00
A811E1	2017-07-19 17:37:00+03	38600.00
A81268	2017-07-12 14:42:00+03	129200.00
A81298	2017-07-04 02:09:00+03	14800.00
A812C0	2017-08-02 07:08:00+03	38600.00
A81387	2017-07-29 05:33:00+03	164400.00
A813C2	2017-07-04 07:05:00+03	78500.00
A813EA	2017-07-05 07:08:00+03	55800.00
A813ED	2017-07-09 21:39:00+03	50600.00
A813F7	2017-08-09 14:45:00+03	36400.00
A81414	2017-07-13 23:40:00+03	26800.00
A814A3	2017-07-14 16:05:00+03	36000.00
A814A9	2017-08-10 00:51:00+03	64500.00
A81590	2017-07-16 22:18:00+03	153300.00
A8159A	2017-08-08 05:28:00+03	87200.00
A815E4	2017-07-25 05:58:00+03	24400.00
A81604	2017-07-16 11:46:00+03	26000.00
A816EA	2017-08-02 04:20:00+03	151200.00
A81716	2017-08-09 01:35:00+03	146300.00
A81801	2017-07-28 14:11:00+03	46400.00
A818AE	2017-07-06 18:23:00+03	26000.00
A8193B	2017-07-18 21:36:00+03	148200.00
A819BE	2017-07-28 04:44:00+03	52600.00
A81A1C	2017-06-29 01:28:00+03	120300.00
A81AD4	2017-08-02 06:15:00+03	70600.00
A81AE4	2017-07-03 21:17:00+03	420200.00
A81B0F	2017-08-09 22:04:00+03	6800.00
A81B40	2017-08-09 03:10:00+03	61800.00
A81B55	2017-07-29 13:32:00+03	258400.00
A81B66	2017-07-01 02:10:00+03	242200.00
A81B69	2017-07-19 23:48:00+03	65900.00
A81BA7	2017-07-07 17:44:00+03	99600.00
A81BB1	2017-08-13 19:20:00+03	37900.00
A81BDF	2017-07-24 14:53:00+03	96300.00
A81BF8	2017-07-20 09:42:00+03	12600.00
A81C75	2017-07-06 06:18:00+03	58000.00
A81CB2	2017-07-09 01:50:00+03	140900.00
A81CC2	2017-08-06 13:32:00+03	14800.00
A81D2C	2017-07-26 04:35:00+03	211600.00
A81D5C	2017-07-16 21:56:00+03	40800.00
A81DC5	2017-07-16 06:18:00+03	125400.00
A81DD6	2017-08-03 21:03:00+03	31400.00
A81DDA	2017-08-12 23:44:00+03	15000.00
A81DDD	2017-07-06 18:24:00+03	88800.00
A81E0F	2017-07-18 23:20:00+03	38800.00
A81E65	2017-08-13 08:55:00+03	100800.00
A81E6E	2017-07-16 22:41:00+03	21800.00
A81E89	2017-06-28 05:51:00+03	12600.00
A81F6F	2017-07-08 21:08:00+03	241400.00
A81F75	2017-08-12 05:29:00+03	301800.00
A81F9B	2017-07-07 23:57:00+03	55800.00
A81FA6	2017-07-24 23:27:00+03	36600.00
A81FC1	2017-08-09 16:36:00+03	68800.00
A81FDE	2017-07-22 00:18:00+03	55800.00
A82139	2017-07-29 18:37:00+03	28000.00
A8217C	2017-07-28 15:24:00+03	28800.00
A82180	2017-07-09 02:55:00+03	6000.00
A821D3	2017-08-03 12:49:00+03	46300.00
A82203	2017-07-29 09:24:00+03	246200.00
A8226E	2017-08-01 12:25:00+03	23200.00
A822CB	2017-06-29 20:14:00+03	26000.00
A822D3	2017-07-31 04:07:00+03	258000.00
A82381	2017-08-11 20:29:00+03	298800.00
A823F1	2017-07-14 07:44:00+03	398600.00
A8240D	2017-07-08 14:02:00+03	248400.00
A8240F	2017-07-20 11:37:00+03	152500.00
A82415	2017-07-13 01:48:00+03	34000.00
A8241C	2017-07-23 09:07:00+03	82800.00
A8246A	2017-08-05 19:41:00+03	78200.00
A824D8	2017-07-07 07:57:00+03	38600.00
A824EC	2017-08-08 03:32:00+03	15400.00
A82503	2017-07-10 06:04:00+03	76900.00
A825AC	2017-08-01 04:46:00+03	90600.00
A825CC	2017-07-04 06:51:00+03	27800.00
A825EE	2017-07-22 22:49:00+03	95600.00
A82615	2017-07-11 13:24:00+03	23400.00
A82685	2017-08-15 10:29:00+03	83900.00
A8268F	2017-07-24 05:56:00+03	48800.00
A826A7	2017-08-07 16:29:00+03	92800.00
A826BC	2017-08-13 04:10:00+03	13400.00
A82733	2017-07-19 22:42:00+03	23900.00
A8279F	2017-08-02 08:28:00+03	65900.00
A827EE	2017-07-04 21:25:00+03	13300.00
A82854	2017-07-07 07:39:00+03	96800.00
A8290A	2017-07-07 23:53:00+03	102100.00
A82944	2017-07-07 13:28:00+03	61500.00
A8295B	2017-08-08 16:58:00+03	112000.00
A829C9	2017-08-15 02:56:00+03	79600.00
A829DC	2017-07-28 05:04:00+03	69500.00
A82A2A	2017-08-14 18:09:00+03	81300.00
A82A48	2017-08-05 20:14:00+03	52000.00
A82A59	2017-07-26 03:22:00+03	65500.00
A82A68	2017-07-30 12:14:00+03	173500.00
A82A74	2017-07-27 14:43:00+03	23200.00
A82B2E	2017-08-07 19:49:00+03	156000.00
A82B4D	2017-07-13 10:28:00+03	111600.00
A82B75	2017-08-13 09:28:00+03	127600.00
A82B87	2017-07-12 20:43:00+03	170000.00
A82BFF	2017-07-16 00:29:00+03	26800.00
A82C2A	2017-07-03 13:13:00+03	18600.00
A82C58	2017-07-10 09:28:00+03	11800.00
A82C96	2017-07-09 18:45:00+03	56000.00
A82CAE	2017-08-09 21:29:00+03	38600.00
A82D0C	2017-07-06 16:19:00+03	30400.00
A82D1A	2017-07-22 08:59:00+03	46500.00
A82D70	2017-07-13 05:37:00+03	39600.00
A82DCB	2017-08-11 19:12:00+03	30200.00
A82DE1	2017-08-12 09:03:00+03	27900.00
A82E29	2017-07-02 10:43:00+03	75300.00
A82E5C	2017-07-10 00:41:00+03	94900.00
A82E85	2017-07-06 12:40:00+03	109600.00
A82E8C	2017-07-26 05:31:00+03	12600.00
A82E98	2017-07-28 05:26:00+03	66600.00
A82EEF	2017-07-23 17:32:00+03	52000.00
A82F4D	2017-07-30 10:40:00+03	59800.00
A82F88	2017-08-08 16:55:00+03	275400.00
A82FC1	2017-08-05 10:30:00+03	39500.00
A82FDA	2017-07-11 09:49:00+03	26000.00
A82FEA	2017-08-05 08:42:00+03	62700.00
A8300B	2017-08-01 12:43:00+03	154400.00
A83033	2017-07-27 05:30:00+03	60400.00
A83079	2017-07-02 15:19:00+03	37700.00
A8307E	2017-08-03 01:28:00+03	62700.00
A83091	2017-08-14 16:10:00+03	98400.00
A830C6	2017-07-12 13:12:00+03	50800.00
A830FA	2017-08-04 02:16:00+03	6700.00
A83156	2017-08-02 10:34:00+03	8600.00
A831DB	2017-07-12 00:16:00+03	46500.00
A831FC	2017-07-22 20:59:00+03	44600.00
A83235	2017-07-19 12:13:00+03	38800.00
A83236	2017-07-12 05:22:00+03	47800.00
A8326C	2017-07-17 01:40:00+03	65600.00
A83280	2017-08-10 00:29:00+03	39800.00
A832F1	2017-07-27 13:06:00+03	26000.00
A8330E	2017-07-05 16:52:00+03	112600.00
A8332B	2017-07-24 16:18:00+03	46300.00
A8338D	2017-08-08 16:40:00+03	246000.00
A833B6	2017-07-09 04:50:00+03	64600.00
A8340E	2017-08-02 10:31:00+03	43200.00
A83481	2017-07-13 16:40:00+03	52700.00
A83544	2017-08-07 07:47:00+03	23400.00
A8358C	2017-08-11 00:20:00+03	35700.00
A835D5	2017-07-30 14:13:00+03	62600.00
A835DC	2017-07-09 05:40:00+03	139300.00
A8366D	2017-08-07 20:24:00+03	59300.00
A83677	2017-07-02 15:55:00+03	40300.00
A836D3	2017-07-28 06:37:00+03	28000.00
A83738	2017-07-29 19:39:00+03	81600.00
A8373D	2017-07-14 16:58:00+03	94000.00
A83752	2017-07-08 15:36:00+03	279000.00
A83792	2017-07-25 12:56:00+03	57600.00
A8379D	2017-08-05 01:22:00+03	111600.00
A837C2	2017-07-27 13:11:00+03	59000.00
A837CF	2017-08-11 10:34:00+03	56000.00
A83831	2017-08-05 14:57:00+03	13400.00
A8383E	2017-07-07 18:13:00+03	25100.00
A83881	2017-08-02 13:12:00+03	38600.00
A838DB	2017-07-09 02:27:00+03	36400.00
A83912	2017-07-19 09:11:00+03	92600.00
A83917	2017-07-31 17:30:00+03	22000.00
A83959	2017-07-11 12:04:00+03	54000.00
A83998	2017-07-14 15:10:00+03	28800.00
A839BF	2017-08-12 01:59:00+03	54800.00
A83A69	2017-07-06 20:57:00+03	146000.00
A83AA6	2017-07-21 02:40:00+03	39600.00
A83ADD	2017-07-23 08:13:00+03	23400.00
A83B25	2017-07-04 04:55:00+03	7200.00
A83BA1	2017-07-21 10:51:00+03	23200.00
A83CF3	2017-07-24 20:24:00+03	91300.00
A83D18	2017-07-27 17:16:00+03	8400.00
A83D7E	2017-07-24 10:30:00+03	101200.00
A83DE3	2017-07-30 08:54:00+03	13800.00
A83E08	2017-08-10 07:50:00+03	67600.00
A83E42	2017-07-09 20:11:00+03	75600.00
A83E67	2017-08-01 22:31:00+03	33400.00
A83E69	2017-07-31 08:35:00+03	28000.00
A83E9E	2017-07-15 06:47:00+03	189800.00
A83EB9	2017-07-08 23:26:00+03	68400.00
A83EE7	2017-07-08 00:54:00+03	77200.00
A83F33	2017-08-09 02:30:00+03	56600.00
A83F97	2017-06-29 13:02:00+03	40600.00
A84049	2017-08-02 18:30:00+03	83000.00
A840B6	2017-08-12 17:12:00+03	128800.00
A840F7	2017-07-03 16:00:00+03	229500.00
A84103	2017-08-11 10:12:00+03	11600.00
A8410F	2017-08-14 21:19:00+03	54500.00
A84113	2017-08-03 14:33:00+03	64200.00
A8413C	2017-07-05 11:11:00+03	63200.00
A84148	2017-07-12 02:26:00+03	46200.00
A84193	2017-08-12 10:59:00+03	31800.00
A841A4	2017-07-30 16:54:00+03	270800.00
A841FC	2017-06-28 01:01:00+03	37800.00
A84219	2017-08-06 15:19:00+03	38600.00
A8422E	2017-07-11 11:05:00+03	154500.00
A8424D	2017-07-30 01:21:00+03	35300.00
A8425E	2017-07-27 09:47:00+03	245500.00
A842A5	2017-07-09 12:32:00+03	112000.00
A842B0	2017-07-15 03:36:00+03	159200.00
A842F1	2017-07-31 23:34:00+03	12400.00
A84311	2017-07-15 09:39:00+03	306600.00
A84371	2017-07-07 17:52:00+03	45100.00
A8438A	2017-07-11 15:57:00+03	28400.00
A843A2	2017-08-10 01:22:00+03	254900.00
A843B1	2017-07-29 08:12:00+03	39800.00
A843CD	2017-08-15 15:54:00+03	34000.00
A84412	2017-06-30 20:48:00+03	36800.00
A84435	2017-06-30 02:28:00+03	185000.00
A84470	2017-07-23 09:20:00+03	65900.00
A84477	2017-07-17 21:08:00+03	86300.00
A84572	2017-08-06 13:34:00+03	36000.00
A84580	2017-07-03 14:36:00+03	54700.00
A845A1	2017-08-07 01:46:00+03	63200.00
A84606	2017-07-20 07:03:00+03	26800.00
A8461C	2017-07-06 19:32:00+03	130400.00
A8465D	2017-08-09 07:29:00+03	57500.00
A8468B	2017-07-26 01:50:00+03	135400.00
A846A1	2017-08-03 05:39:00+03	13400.00
A846B4	2017-07-03 14:24:00+03	11600.00
A846F2	2017-07-12 08:48:00+03	35300.00
A84768	2017-07-15 02:03:00+03	136000.00
A847AE	2017-07-26 13:03:00+03	43300.00
A84822	2017-07-06 14:20:00+03	321300.00
A8482C	2017-07-25 18:00:00+03	59200.00
A84837	2017-08-02 10:14:00+03	312100.00
A84897	2017-08-05 16:52:00+03	124200.00
A848AF	2017-07-13 09:44:00+03	56000.00
A848E3	2017-07-16 07:15:00+03	86600.00
A84903	2017-07-11 01:24:00+03	21500.00
A8497A	2017-08-14 10:09:00+03	18000.00
A8497D	2017-08-02 08:26:00+03	138800.00
A849A3	2017-08-14 18:21:00+03	84700.00
A849AA	2017-07-19 17:35:00+03	49800.00
A849D2	2017-07-26 07:16:00+03	31600.00
A849FE	2017-07-10 01:58:00+03	199200.00
A84A35	2017-07-10 19:29:00+03	24400.00
A84A38	2017-08-01 18:21:00+03	38800.00
A84C20	2017-07-30 01:18:00+03	75300.00
A84C4C	2017-07-23 19:50:00+03	39600.00
A84C6C	2017-08-09 12:18:00+03	52000.00
A84C7E	2017-06-30 11:53:00+03	89700.00
A84CA4	2017-07-18 16:59:00+03	56000.00
A84D00	2017-07-09 17:55:00+03	59200.00
A84D28	2017-07-17 01:34:00+03	21400.00
A84D3E	2017-07-02 00:18:00+03	58600.00
A84D6C	2017-07-18 17:03:00+03	37900.00
A84D75	2017-07-17 18:39:00+03	27200.00
A84D88	2017-07-11 04:03:00+03	16400.00
A84DDE	2017-07-12 18:42:00+03	194800.00
A84DEA	2017-08-06 19:22:00+03	125200.00
A84DF4	2017-08-06 23:50:00+03	84800.00
A84E03	2017-07-09 14:35:00+03	20200.00
A84E04	2017-07-16 19:16:00+03	66100.00
A84E2C	2017-07-19 11:29:00+03	89600.00
A84E9B	2017-08-04 16:52:00+03	56600.00
A84EBA	2017-07-23 09:22:00+03	22000.00
A84F27	2017-07-18 09:37:00+03	123000.00
A84FCF	2017-07-12 12:34:00+03	112100.00
A84FE1	2017-08-12 14:59:00+03	133100.00
A84FFC	2017-08-14 21:25:00+03	13400.00
A8501A	2017-07-08 06:01:00+03	58400.00
A8501B	2017-07-10 14:29:00+03	60200.00
A85063	2017-07-13 12:24:00+03	94800.00
A850AB	2017-08-13 04:12:00+03	257600.00
A850FA	2017-08-10 11:28:00+03	81700.00
A85114	2017-07-27 17:05:00+03	15400.00
A85119	2017-07-12 15:28:00+03	26700.00
A8511C	2017-07-15 18:47:00+03	103600.00
A851F9	2017-07-08 14:38:00+03	8000.00
A8533F	2017-08-10 07:20:00+03	64400.00
A8534B	2017-08-10 23:27:00+03	56000.00
A85356	2017-07-12 00:01:00+03	71900.00
A85358	2017-08-11 23:11:00+03	28000.00
A85389	2017-07-20 02:27:00+03	28800.00
A853B8	2017-06-25 01:25:00+03	28800.00
A853C6	2017-08-13 01:57:00+03	45200.00
A8541A	2017-06-30 13:16:00+03	133700.00
A85420	2017-08-11 20:06:00+03	15800.00
A8543E	2017-08-05 22:52:00+03	46200.00
A85453	2017-08-09 14:26:00+03	189200.00
A85472	2017-07-06 06:35:00+03	150400.00
A85479	2017-07-09 20:58:00+03	369000.00
A854A4	2017-07-16 23:27:00+03	109600.00
A854B2	2017-07-21 08:01:00+03	88800.00
A85527	2017-08-15 09:38:00+03	12600.00
A85568	2017-07-13 12:37:00+03	206300.00
A855E2	2017-07-06 06:15:00+03	295400.00
A85624	2017-07-28 01:41:00+03	12000.00
A85698	2017-07-17 14:15:00+03	46400.00
A856C9	2017-07-28 12:31:00+03	98000.00
A856D8	2017-07-04 17:30:00+03	34000.00
A856E0	2017-08-14 23:40:00+03	39700.00
A856E9	2017-07-25 13:43:00+03	111600.00
A8571E	2017-07-25 09:51:00+03	111600.00
A85734	2017-07-17 21:00:00+03	89700.00
A85740	2017-06-29 10:49:00+03	56000.00
A85750	2017-08-04 02:08:00+03	10800.00
A85779	2017-08-12 21:54:00+03	169900.00
A857B4	2017-08-15 10:10:00+03	55400.00
A8580C	2017-07-07 01:11:00+03	73000.00
A85829	2017-07-04 07:43:00+03	273000.00
A85856	2017-08-04 21:49:00+03	269400.00
A858B1	2017-07-21 15:36:00+03	23200.00
A858DF	2017-07-01 20:20:00+03	40100.00
A858F2	2017-08-07 02:01:00+03	119600.00
A85921	2017-07-07 13:29:00+03	22600.00
A85922	2017-07-20 14:17:00+03	16400.00
A8595D	2017-07-13 07:10:00+03	79900.00
A859CD	2017-07-21 06:16:00+03	115900.00
A859D0	2017-08-15 17:49:00+03	52900.00
A859D9	2017-07-21 06:28:00+03	14400.00
A85A3A	2017-08-14 08:23:00+03	6700.00
A85A5B	2017-08-13 03:23:00+03	20400.00
A85AD2	2017-08-14 04:41:00+03	28000.00
A85B14	2017-07-11 04:07:00+03	112000.00
A85B36	2017-07-05 07:14:00+03	55800.00
A85BDD	2017-07-19 16:41:00+03	333600.00
A85BEE	2017-08-12 18:39:00+03	95200.00
A85BF8	2017-07-22 21:50:00+03	83200.00
A85BF9	2017-07-15 15:11:00+03	64700.00
A85C0F	2017-07-19 07:50:00+03	105800.00
A85C74	2017-07-20 06:43:00+03	57400.00
A85C81	2017-07-30 08:38:00+03	149300.00
A85C92	2017-08-12 23:36:00+03	57200.00
A85C97	2017-08-08 22:09:00+03	46400.00
A85C99	2017-08-07 01:28:00+03	32700.00
A85CE4	2017-08-02 04:46:00+03	26000.00
A85D00	2017-07-24 05:42:00+03	14400.00
A85D02	2017-07-09 21:30:00+03	73600.00
A85D2B	2017-08-03 09:01:00+03	6000.00
A85D57	2017-07-12 12:49:00+03	50000.00
A85D69	2017-06-29 00:53:00+03	13400.00
A85D83	2017-08-11 20:19:00+03	45200.00
A85D98	2017-07-26 11:11:00+03	35800.00
A85D9F	2017-08-15 12:23:00+03	8000.00
A85DDE	2017-07-23 15:30:00+03	264000.00
A85E0B	2017-07-06 16:22:00+03	144700.00
A85E41	2017-07-18 05:03:00+03	53600.00
A85E50	2017-08-11 13:19:00+03	36800.00
A85ED4	2017-07-06 16:36:00+03	53400.00
A85EF4	2017-07-30 15:39:00+03	55800.00
A85F3C	2017-08-03 15:51:00+03	47200.00
A86071	2017-07-24 10:32:00+03	28000.00
A86078	2017-08-12 04:09:00+03	69900.00
A8609A	2017-08-07 02:57:00+03	111600.00
A860C0	2017-08-15 07:58:00+03	111700.00
A861BB	2017-07-25 06:07:00+03	42800.00
A861E8	2017-07-21 02:28:00+03	40000.00
A861F5	2017-07-01 14:20:00+03	131100.00
A86203	2017-08-14 20:26:00+03	69500.00
A86230	2017-07-10 12:32:00+03	28800.00
A86264	2017-07-11 10:09:00+03	73900.00
A862B4	2017-08-08 05:58:00+03	57700.00
A862ED	2017-07-19 21:13:00+03	24200.00
A86315	2017-08-01 15:42:00+03	59200.00
A8631C	2017-07-08 00:56:00+03	6000.00
A86330	2017-08-05 11:19:00+03	29400.00
A8633A	2017-07-15 05:05:00+03	24800.00
A86363	2017-08-12 22:51:00+03	44600.00
A86374	2017-07-16 00:57:00+03	101200.00
A86376	2017-07-29 14:47:00+03	114700.00
A86383	2017-08-06 08:40:00+03	213200.00
A86391	2017-07-10 18:26:00+03	42700.00
A863D7	2017-07-18 07:28:00+03	31600.00
A86404	2017-07-15 16:27:00+03	46700.00
A86411	2017-07-29 09:33:00+03	40800.00
A8646B	2017-07-30 07:30:00+03	37100.00
A8654C	2017-07-28 00:23:00+03	15100.00
A865BF	2017-08-09 02:50:00+03	14000.00
A865D5	2017-07-11 22:23:00+03	28800.00
A865D7	2017-07-09 17:27:00+03	30400.00
A865E3	2017-07-13 01:40:00+03	14000.00
A866ED	2017-08-03 08:14:00+03	24400.00
A86764	2017-07-31 05:19:00+03	24400.00
A867BF	2017-08-09 15:04:00+03	7400.00
A867F9	2017-07-07 03:08:00+03	143800.00
A86852	2017-07-14 00:51:00+03	105000.00
A8685B	2017-08-09 02:33:00+03	24400.00
A8688D	2017-07-27 17:03:00+03	52100.00
A868BD	2017-08-07 16:16:00+03	28000.00
A868E4	2017-07-30 06:16:00+03	46400.00
A868F3	2017-07-26 18:41:00+03	27200.00
A86953	2017-07-19 18:03:00+03	68100.00
A8695F	2017-07-23 23:38:00+03	8200.00
A86996	2017-07-24 19:55:00+03	46500.00
A869F6	2017-07-27 18:44:00+03	93400.00
A869FB	2017-08-12 08:25:00+03	35800.00
A86A28	2017-07-30 03:40:00+03	142300.00
A86A87	2017-08-04 12:50:00+03	13400.00
A86A94	2017-07-14 10:43:00+03	86400.00
A86AD9	2017-07-13 03:49:00+03	70700.00
A86B2B	2017-07-25 05:45:00+03	8200.00
A86B3C	2017-08-05 14:36:00+03	25000.00
A86B3F	2017-08-02 06:38:00+03	6700.00
A86CE0	2017-08-05 13:59:00+03	92400.00
A86CE6	2017-07-23 13:56:00+03	65900.00
A86D0F	2017-07-12 08:44:00+03	42400.00
A86D2E	2017-07-13 23:25:00+03	36800.00
A86D77	2017-06-25 09:28:00+03	16800.00
A86D79	2017-07-31 19:34:00+03	6800.00
A86D9D	2017-08-09 00:23:00+03	24400.00
A86D9F	2017-07-04 17:58:00+03	48800.00
A86E01	2017-07-01 01:22:00+03	93400.00
A86E21	2017-07-29 14:36:00+03	57700.00
A86E35	2017-07-23 22:46:00+03	34100.00
A86E39	2017-07-10 17:04:00+03	6700.00
A86E63	2017-08-01 01:34:00+03	86800.00
A86E81	2017-07-07 13:03:00+03	43200.00
A86ECB	2017-07-26 21:38:00+03	342100.00
A86EF5	2017-07-10 19:44:00+03	50600.00
A86FEA	2017-07-03 17:35:00+03	27900.00
A86FED	2017-08-07 15:41:00+03	413400.00
A87002	2017-07-17 07:02:00+03	22000.00
A87045	2017-07-20 00:54:00+03	14000.00
A87079	2017-08-01 03:58:00+03	54400.00
A870B7	2017-08-11 13:32:00+03	252200.00
A870BE	2017-08-12 15:54:00+03	26700.00
A870FB	2017-07-17 06:25:00+03	24000.00
A87118	2017-08-14 14:14:00+03	23200.00
A8714E	2017-06-30 21:00:00+03	28000.00
A871C1	2017-07-16 16:35:00+03	167400.00
A87235	2017-07-23 16:32:00+03	21400.00
A872AD	2017-07-20 09:55:00+03	47100.00
A872D5	2017-08-12 09:58:00+03	60400.00
A872F1	2017-07-20 09:44:00+03	47000.00
A872F8	2017-08-03 13:59:00+03	29600.00
A8731C	2017-07-09 12:41:00+03	26200.00
A87382	2017-07-24 05:11:00+03	177600.00
A873A5	2017-08-01 01:10:00+03	396000.00
A873BB	2017-07-03 21:26:00+03	42800.00
A873CD	2017-07-31 01:22:00+03	240800.00
A87411	2017-08-14 22:07:00+03	48800.00
A8743A	2017-08-11 23:29:00+03	136500.00
A87458	2017-08-11 12:55:00+03	31700.00
A87474	2017-08-11 08:57:00+03	43200.00
A87499	2017-08-01 06:53:00+03	123000.00
A874AC	2017-07-20 14:59:00+03	100600.00
A874BF	2017-07-06 17:11:00+03	38600.00
A874D1	2017-07-04 19:33:00+03	6800.00
A87512	2017-06-28 22:40:00+03	94900.00
A87552	2017-08-01 00:03:00+03	81300.00
A875CB	2017-08-13 01:41:00+03	131100.00
A875EA	2017-07-28 10:32:00+03	30200.00
A875F9	2017-07-24 03:27:00+03	37700.00
A876D6	2017-07-26 13:00:00+03	55800.00
A87716	2017-08-15 11:26:00+03	119400.00
A877C9	2017-07-16 01:16:00+03	12000.00
A877FC	2017-08-10 14:21:00+03	219300.00
A87812	2017-07-13 09:59:00+03	174600.00
A87849	2017-08-07 00:14:00+03	19600.00
A87879	2017-07-06 04:49:00+03	29000.00
A87897	2017-07-25 20:26:00+03	271200.00
A878B8	2017-08-04 13:26:00+03	111200.00
A879A5	2017-07-18 22:01:00+03	89600.00
A879A7	2017-07-30 22:12:00+03	191600.00
A879AA	2017-08-01 12:05:00+03	23200.00
A879DB	2017-06-29 12:27:00+03	59800.00
A87A1D	2017-07-10 20:11:00+03	66800.00
A87A60	2017-07-08 07:17:00+03	66200.00
A87ADE	2017-08-06 15:16:00+03	76300.00
A87B06	2017-07-16 05:03:00+03	56600.00
A87B2F	2017-07-14 13:24:00+03	86600.00
A87B6A	2017-08-10 22:35:00+03	62800.00
A87B6E	2017-08-02 03:16:00+03	112000.00
A87B9C	2017-07-12 06:55:00+03	272400.00
A87BBD	2017-07-10 03:01:00+03	28800.00
A87BE2	2017-07-09 00:21:00+03	88100.00
A87BE6	2017-07-14 01:43:00+03	92900.00
A87C47	2017-07-26 15:28:00+03	50800.00
A87C53	2017-07-03 07:51:00+03	111600.00
A87CD3	2017-07-19 04:54:00+03	52000.00
A87D11	2017-08-06 07:03:00+03	37900.00
A87D5D	2017-07-24 21:38:00+03	201600.00
A87D79	2017-07-05 16:53:00+03	189800.00
A87D8F	2017-08-10 06:26:00+03	94200.00
A87D91	2017-07-01 10:17:00+03	32200.00
A87DE5	2017-07-27 08:36:00+03	21200.00
A87E5C	2017-07-26 13:13:00+03	112000.00
A87EA4	2017-07-28 02:31:00+03	213600.00
A87ED6	2017-07-24 22:49:00+03	78300.00
A87EF0	2017-08-04 13:19:00+03	106400.00
A87F66	2017-08-13 08:36:00+03	123000.00
A8801B	2017-08-10 22:34:00+03	21400.00
A880A4	2017-07-14 04:31:00+03	96800.00
A8818F	2017-07-20 20:10:00+03	16400.00
A88216	2017-08-04 21:00:00+03	168000.00
A88244	2017-07-25 23:24:00+03	20200.00
A882A5	2017-07-11 19:44:00+03	56600.00
A88301	2017-08-02 16:43:00+03	135400.00
A8839C	2017-08-14 17:57:00+03	84500.00
A883A6	2017-07-04 22:47:00+03	46300.00
A883C1	2017-08-09 21:46:00+03	26700.00
A8842B	2017-08-07 22:24:00+03	73200.00
A8844A	2017-07-26 14:12:00+03	37900.00
A8846D	2017-08-13 18:48:00+03	12600.00
A88471	2017-06-28 17:52:00+03	93500.00
A8849D	2017-07-26 18:17:00+03	40300.00
A884B1	2017-08-12 06:28:00+03	12000.00
A884D8	2017-07-26 03:35:00+03	57200.00
A8850B	2017-08-01 19:21:00+03	23600.00
A88520	2017-08-12 23:55:00+03	55800.00
A885E9	2017-07-04 09:19:00+03	26000.00
A8863B	2017-07-04 22:46:00+03	252200.00
A88655	2017-07-28 18:58:00+03	30400.00
A88693	2017-07-24 09:39:00+03	54800.00
A886DB	2017-08-05 01:04:00+03	26000.00
A886E2	2017-08-14 14:45:00+03	109800.00
A886FF	2017-07-19 03:23:00+03	65500.00
A88709	2017-07-22 17:54:00+03	6800.00
A8874C	2017-08-11 07:42:00+03	24600.00
A887B9	2017-07-16 19:56:00+03	31700.00
A888A9	2017-08-05 17:46:00+03	271100.00
A888EE	2017-08-11 21:29:00+03	45900.00
A88911	2017-07-22 20:31:00+03	99200.00
A88981	2017-08-12 04:03:00+03	123000.00
A8898D	2017-07-24 19:29:00+03	58400.00
A889AA	2017-07-15 00:24:00+03	46200.00
A889AB	2017-07-28 09:44:00+03	37900.00
A889C6	2017-07-03 19:13:00+03	25000.00
A88A45	2017-07-07 07:07:00+03	28300.00
A88A61	2017-07-06 12:33:00+03	44700.00
A88A7B	2017-07-13 00:27:00+03	51300.00
A88A92	2017-07-05 10:09:00+03	85000.00
A88B38	2017-07-07 13:03:00+03	75300.00
A88B91	2017-08-13 22:00:00+03	356700.00
A88BEE	2017-07-05 05:20:00+03	13400.00
A88C0E	2017-07-09 23:44:00+03	11600.00
A88C84	2017-07-18 08:31:00+03	131600.00
A88CA8	2017-07-11 12:01:00+03	28800.00
A88CCA	2017-07-31 11:22:00+03	112000.00
A88D43	2017-08-11 17:46:00+03	70600.00
A88DEF	2017-07-06 19:54:00+03	36200.00
A88E44	2017-08-11 05:40:00+03	23200.00
A88E76	2017-08-10 17:50:00+03	21400.00
A88E9F	2017-07-27 11:25:00+03	24000.00
A88EAE	2017-07-14 00:15:00+03	29600.00
A88ED3	2017-07-26 13:18:00+03	170600.00
A88F01	2017-07-27 18:13:00+03	100600.00
A88F67	2017-08-04 01:02:00+03	36000.00
A88FAB	2017-07-22 14:43:00+03	76400.00
A89000	2017-07-05 20:52:00+03	12600.00
A89069	2017-07-16 08:28:00+03	86400.00
A89094	2017-08-13 05:26:00+03	56600.00
A890B6	2017-07-04 18:15:00+03	95300.00
A890BA	2017-07-08 06:41:00+03	63600.00
A89137	2017-08-04 01:37:00+03	143100.00
A8914F	2017-07-15 23:03:00+03	50800.00
A89165	2017-07-05 16:22:00+03	35200.00
A891C7	2017-07-03 12:50:00+03	38800.00
A891FF	2017-07-31 04:04:00+03	109900.00
A89247	2017-08-02 19:41:00+03	56900.00
A8925C	2017-08-01 15:49:00+03	31100.00
A8927C	2017-07-09 08:08:00+03	25800.00
A89286	2017-08-07 23:37:00+03	24400.00
A892D5	2017-08-07 18:32:00+03	12400.00
A89301	2017-07-03 13:15:00+03	93900.00
A89334	2017-07-29 20:49:00+03	62100.00
A89392	2017-07-07 04:36:00+03	136800.00
A893A0	2017-08-06 04:47:00+03	52700.00
A8942A	2017-08-11 10:24:00+03	16400.00
A8944E	2017-07-26 02:27:00+03	67900.00
A8949C	2017-08-09 09:57:00+03	144400.00
A894E6	2017-07-29 16:41:00+03	27300.00
A894EB	2017-07-29 21:51:00+03	57500.00
A89514	2017-07-19 22:38:00+03	22000.00
A8952D	2017-08-06 21:04:00+03	66600.00
A89565	2017-08-09 23:00:00+03	89700.00
A895A4	2017-07-24 10:31:00+03	28600.00
A895E2	2017-07-07 07:46:00+03	44600.00
A8960F	2017-07-30 15:06:00+03	43200.00
A8961E	2017-08-13 14:31:00+03	26500.00
A89653	2017-07-15 06:50:00+03	299200.00
A89693	2017-08-07 16:51:00+03	666000.00
A89748	2017-07-11 14:19:00+03	83300.00
A8975F	2017-08-13 19:02:00+03	37900.00
A89767	2017-08-10 17:23:00+03	6300.00
A8976B	2017-07-21 16:02:00+03	115600.00
A8983E	2017-07-26 17:41:00+03	37400.00
A8985A	2017-08-01 19:49:00+03	56600.00
A8985E	2017-07-21 06:35:00+03	69500.00
A8986F	2017-07-16 15:44:00+03	40000.00
A898C9	2017-07-22 14:36:00+03	135400.00
A8995F	2017-07-08 05:59:00+03	75800.00
A89977	2017-07-04 20:52:00+03	26000.00
A89979	2017-07-12 06:13:00+03	105600.00
A89994	2017-07-26 14:25:00+03	35600.00
A899F4	2017-07-16 14:48:00+03	290100.00
A899FF	2017-08-02 19:13:00+03	111600.00
A89A1B	2017-08-12 16:56:00+03	52900.00
A89A3B	2017-08-01 12:54:00+03	55800.00
A89A63	2017-07-02 21:07:00+03	21200.00
A89AB7	2017-07-14 15:41:00+03	81000.00
A89AD3	2017-07-22 13:16:00+03	30000.00
A89B11	2017-08-09 15:41:00+03	59800.00
A89B68	2017-07-05 11:01:00+03	56600.00
A89B8B	2017-07-22 07:00:00+03	23600.00
A89BB3	2017-07-06 14:41:00+03	82900.00
A89BBD	2017-07-25 03:48:00+03	79600.00
A89BEE	2017-08-06 16:21:00+03	372600.00
A89C13	2017-08-11 20:24:00+03	111600.00
A89C84	2017-07-23 00:22:00+03	28800.00
A89CAB	2017-07-08 11:12:00+03	40800.00
A89CD1	2017-07-10 06:28:00+03	24800.00
A89CEE	2017-08-14 22:41:00+03	10600.00
A89DA2	2017-07-03 21:17:00+03	42000.00
A89DCE	2017-07-30 23:55:00+03	20200.00
A89DE3	2017-08-08 01:39:00+03	46000.00
A89DFC	2017-07-28 12:33:00+03	70600.00
A89E3E	2017-07-22 17:37:00+03	15000.00
A89E6D	2017-08-08 14:43:00+03	21400.00
A89E7F	2017-07-11 13:39:00+03	357200.00
A89F38	2017-07-13 19:23:00+03	189200.00
A89FE0	2017-08-08 07:37:00+03	64800.00
A89FF8	2017-08-11 15:56:00+03	126600.00
A8A051	2017-08-14 09:10:00+03	123000.00
A8A067	2017-07-17 16:47:00+03	29400.00
A8A099	2017-07-07 11:48:00+03	223200.00
A8A0B1	2017-07-08 10:43:00+03	90200.00
A8A0EA	2017-08-12 17:54:00+03	26000.00
A8A101	2017-08-14 03:04:00+03	47100.00
A8A11D	2017-07-22 13:03:00+03	185600.00
A8A150	2017-08-04 15:36:00+03	53600.00
A8A177	2017-07-21 07:22:00+03	34100.00
A8A1E1	2017-07-11 09:30:00+03	39300.00
A8A220	2017-07-15 09:56:00+03	57600.00
A8A29C	2017-07-25 21:37:00+03	25600.00
A8A2EC	2017-07-29 17:44:00+03	89600.00
A8A32E	2017-08-06 20:29:00+03	32400.00
A8A3C6	2017-07-18 03:52:00+03	47000.00
A8A3F0	2017-07-14 20:30:00+03	33800.00
A8A41D	2017-07-24 13:08:00+03	35200.00
A8A421	2017-07-19 02:38:00+03	92700.00
A8A43E	2017-07-31 09:10:00+03	148200.00
A8A452	2017-07-27 07:37:00+03	265700.00
A8A481	2017-08-13 08:57:00+03	198400.00
A8A48E	2017-08-02 01:31:00+03	73600.00
A8A4AD	2017-07-14 19:37:00+03	56900.00
A8A4CF	2017-07-03 04:42:00+03	124200.00
A8A4E1	2017-07-25 21:03:00+03	141000.00
A8A4E6	2017-08-10 17:55:00+03	66400.00
A8A4FB	2017-08-06 23:02:00+03	56000.00
A8A54E	2017-07-15 11:21:00+03	73200.00
A8A564	2017-07-13 04:49:00+03	18800.00
A8A585	2017-07-14 22:37:00+03	125400.00
A8A5F7	2017-07-07 22:05:00+03	10800.00
A8A61A	2017-07-23 08:55:00+03	54800.00
A8A61D	2017-08-11 15:02:00+03	40100.00
A8A660	2017-07-29 01:58:00+03	114600.00
A8A679	2017-07-18 21:39:00+03	51200.00
A8A6A7	2017-08-05 23:53:00+03	6000.00
A8A6D9	2017-07-14 22:35:00+03	76800.00
A8A6EA	2017-08-07 08:37:00+03	398500.00
A8A6F6	2017-07-28 12:46:00+03	77900.00
A8A70F	2017-08-06 15:35:00+03	293700.00
A8A716	2017-08-08 21:14:00+03	118300.00
A8A76F	2017-07-03 02:03:00+03	61100.00
A8A792	2017-07-23 07:04:00+03	12600.00
A8A7A6	2017-08-08 14:06:00+03	24400.00
A8A7CE	2017-07-18 16:59:00+03	59000.00
A8A817	2017-07-18 10:02:00+03	16400.00
A8A876	2017-07-03 01:08:00+03	56100.00
A8A904	2017-08-12 08:48:00+03	135400.00
A8A928	2017-07-13 00:53:00+03	218200.00
A8A94C	2017-06-30 19:37:00+03	193300.00
A8A973	2017-07-06 14:59:00+03	246000.00
A8A9CD	2017-07-31 10:24:00+03	60400.00
A8A9CF	2017-07-23 20:08:00+03	273400.00
A8A9F5	2017-08-13 23:20:00+03	43800.00
A8AA41	2017-07-15 16:18:00+03	115600.00
A8AAB4	2017-07-03 08:40:00+03	25400.00
A8AAE1	2017-07-17 04:33:00+03	156300.00
A8AB0C	2017-07-16 20:27:00+03	72600.00
A8AB40	2017-08-11 22:13:00+03	52700.00
A8AC5C	2017-07-28 19:21:00+03	146300.00
A8AC6C	2017-08-06 09:17:00+03	76600.00
A8ACAD	2017-07-31 08:14:00+03	22400.00
A8ACC4	2017-07-24 08:57:00+03	28800.00
A8ADAB	2017-07-25 12:23:00+03	55600.00
A8ADBC	2017-07-23 00:03:00+03	163400.00
A8ADF8	2017-07-24 15:53:00+03	28300.00
A8AE79	2017-08-09 02:42:00+03	76300.00
A8AE7B	2017-07-02 19:32:00+03	51600.00
A8AE90	2017-07-26 08:57:00+03	40800.00
A8AEDE	2017-07-02 16:10:00+03	336800.00
A8AF6D	2017-07-29 06:37:00+03	47000.00
A8AF8D	2017-08-15 10:43:00+03	72400.00
A8AF9A	2017-07-23 11:43:00+03	90800.00
A8AFB0	2017-08-15 07:47:00+03	69600.00
A8B021	2017-07-19 01:26:00+03	154500.00
A8B079	2017-08-12 17:20:00+03	18600.00
A8B080	2017-07-19 13:17:00+03	42800.00
A8B0E0	2017-07-21 05:04:00+03	56000.00
A8B0EE	2017-08-07 02:43:00+03	64200.00
A8B0F8	2017-07-06 22:35:00+03	36800.00
A8B13A	2017-07-27 00:05:00+03	69500.00
A8B1A4	2017-07-30 20:24:00+03	22600.00
A8B222	2017-08-15 01:02:00+03	14800.00
A8B233	2017-07-12 07:52:00+03	93400.00
A8B286	2017-07-12 07:00:00+03	34000.00
A8B287	2017-07-13 01:05:00+03	11800.00
A8B342	2017-08-07 20:24:00+03	97500.00
A8B361	2017-08-05 02:59:00+03	102100.00
A8B368	2017-07-29 19:37:00+03	78800.00
A8B3E1	2017-07-07 00:32:00+03	19600.00
A8B447	2017-08-10 01:53:00+03	113200.00
A8B4A7	2017-08-01 15:41:00+03	4000.00
A8B4D4	2017-08-02 14:16:00+03	59800.00
A8B4E8	2017-07-11 19:57:00+03	116900.00
A8B5C3	2017-08-06 09:05:00+03	53700.00
A8B5FE	2017-07-15 04:36:00+03	28000.00
A8B618	2017-08-10 18:21:00+03	26000.00
A8B622	2017-08-03 10:27:00+03	21400.00
A8B654	2017-08-07 01:05:00+03	94600.00
A8B679	2017-08-11 08:20:00+03	136600.00
A8B6A4	2017-07-05 13:04:00+03	46200.00
A8B6B4	2017-07-01 04:03:00+03	150600.00
A8B6C7	2017-07-21 17:07:00+03	179500.00
A8B6D0	2017-07-21 13:28:00+03	31600.00
A8B6DB	2017-07-20 01:28:00+03	68900.00
A8B6F4	2017-07-19 15:30:00+03	46800.00
A8B7B1	2017-07-06 17:48:00+03	38400.00
A8B7FC	2017-07-27 06:26:00+03	67000.00
A8B811	2017-07-31 13:26:00+03	101500.00
A8B93B	2017-07-13 06:58:00+03	94800.00
A8B981	2017-07-26 19:41:00+03	73300.00
A8B9A4	2017-07-13 11:43:00+03	39200.00
A8B9D0	2017-08-08 10:34:00+03	135200.00
A8B9E5	2017-08-04 11:35:00+03	27900.00
A8BA09	2017-07-02 20:29:00+03	41300.00
A8BA29	2017-07-15 15:20:00+03	16200.00
A8BA5C	2017-07-16 21:25:00+03	55800.00
A8BA6B	2017-08-04 17:33:00+03	86300.00
A8BA72	2017-07-28 21:46:00+03	260300.00
A8BA74	2017-07-02 19:03:00+03	103800.00
A8BA85	2017-07-26 06:43:00+03	47600.00
A8BA8F	2017-07-06 11:50:00+03	70400.00
A8BAA6	2017-08-05 12:08:00+03	101300.00
A8BABA	2017-07-20 21:41:00+03	95700.00
A8BADA	2017-08-06 14:43:00+03	67600.00
A8BAFD	2017-07-27 00:27:00+03	135400.00
A8BB01	2017-07-31 13:19:00+03	28000.00
A8BB04	2017-07-10 00:55:00+03	103600.00
A8BB1C	2017-07-24 13:47:00+03	92800.00
A8BB94	2017-08-09 00:45:00+03	60400.00
A8BBB8	2017-08-11 13:01:00+03	28800.00
A8BBF6	2017-08-13 16:27:00+03	56500.00
A8BCA0	2017-07-03 00:04:00+03	27200.00
A8BCD3	2017-07-25 19:43:00+03	302400.00
A8BD0C	2017-07-19 15:16:00+03	22000.00
A8BD24	2017-07-01 03:34:00+03	167400.00
A8BD58	2017-07-27 17:51:00+03	79600.00
A8BE1F	2017-07-10 20:52:00+03	46400.00
A8BE2B	2017-07-17 19:20:00+03	46000.00
A8BE34	2017-08-14 16:25:00+03	54500.00
A8BE3E	2017-08-06 19:04:00+03	42000.00
A8BE9A	2017-08-01 00:54:00+03	56000.00
A8BF09	2017-07-17 14:59:00+03	25000.00
A8BF16	2017-07-03 01:39:00+03	17000.00
A8BF54	2017-08-01 08:39:00+03	34400.00
A8BF86	2017-08-15 13:43:00+03	14000.00
A8C000	2017-08-01 22:36:00+03	40400.00
A8C036	2017-07-01 19:18:00+03	47400.00
A8C041	2017-07-27 16:23:00+03	23200.00
A8C050	2017-07-14 19:14:00+03	122000.00
A8C06A	2017-07-13 03:02:00+03	31900.00
A8C125	2017-07-26 06:13:00+03	20100.00
A8C142	2017-07-14 05:05:00+03	301600.00
A8C15C	2017-08-07 02:36:00+03	418600.00
A8C1FE	2017-07-08 16:08:00+03	47100.00
A8C200	2017-08-05 12:38:00+03	8200.00
A8C235	2017-07-16 19:41:00+03	84100.00
A8C247	2017-07-15 23:10:00+03	7400.00
A8C2B7	2017-07-08 13:35:00+03	265700.00
A8C2B8	2017-07-20 21:00:00+03	131600.00
A8C393	2017-07-18 00:50:00+03	30400.00
A8C3AF	2017-08-05 18:44:00+03	56000.00
A8C3B6	2017-08-08 01:54:00+03	28700.00
A8C3FE	2017-08-08 16:37:00+03	186900.00
A8C42C	2017-07-04 22:06:00+03	11600.00
A8C4A8	2017-07-29 13:25:00+03	31600.00
A8C4FF	2017-08-08 13:15:00+03	33600.00
A8C51C	2017-08-10 04:04:00+03	114600.00
A8C5C8	2017-07-30 15:25:00+03	88800.00
A8C62D	2017-07-21 00:26:00+03	42200.00
A8C6D1	2017-07-17 16:23:00+03	246000.00
A8C73E	2017-07-01 13:52:00+03	36200.00
A8C7F1	2017-07-06 02:52:00+03	92400.00
A8C842	2017-07-31 21:09:00+03	57500.00
A8C86B	2017-07-30 15:45:00+03	105100.00
A8C875	2017-07-16 06:11:00+03	97500.00
A8C878	2017-08-05 00:37:00+03	57500.00
A8C8A0	2017-08-08 06:44:00+03	84300.00
A8C8B4	2017-07-19 22:35:00+03	309500.00
A8C90C	2017-07-30 19:39:00+03	37600.00
A8C91E	2017-07-25 11:41:00+03	16400.00
A8C959	2017-07-13 18:00:00+03	25100.00
A8C95F	2017-08-10 20:59:00+03	93700.00
A8C979	2017-08-07 01:10:00+03	78500.00
A8C9C2	2017-08-12 12:09:00+03	173500.00
A8C9D9	2017-07-21 18:54:00+03	189500.00
A8CAC8	2017-06-27 15:23:00+03	39100.00
A8CAD5	2017-08-12 08:59:00+03	89600.00
A8CAFA	2017-07-10 16:49:00+03	98400.00
A8CB4E	2017-08-03 02:33:00+03	29600.00
A8CC4C	2017-07-22 07:33:00+03	46300.00
A8CC79	2017-07-18 05:22:00+03	40600.00
A8CCA1	2017-07-20 12:46:00+03	125200.00
A8CCA3	2017-07-04 22:09:00+03	87100.00
A8CCC4	2017-08-07 17:05:00+03	14000.00
A8CCED	2017-07-26 14:13:00+03	198400.00
A8CD0A	2017-07-14 10:18:00+03	155600.00
A8CD11	2017-07-26 23:02:00+03	22000.00
A8CD38	2017-07-24 12:31:00+03	45200.00
A8CD6D	2017-08-05 17:31:00+03	112000.00
A8CDA0	2017-07-09 13:59:00+03	94700.00
A8CEDA	2017-07-04 16:23:00+03	32900.00
A8CEDD	2017-07-06 12:09:00+03	45500.00
A8CF98	2017-08-01 07:18:00+03	23400.00
A8CFAA	2017-07-24 14:52:00+03	39900.00
A8D015	2017-08-06 11:09:00+03	142800.00
A8D028	2017-08-07 21:04:00+03	34000.00
A8D071	2017-07-15 05:04:00+03	93900.00
A8D086	2017-07-26 03:11:00+03	52200.00
A8D0A8	2017-08-03 16:55:00+03	39400.00
A8D129	2017-07-17 14:42:00+03	119500.00
A8D14A	2017-08-05 18:11:00+03	245400.00
A8D14B	2017-07-29 18:19:00+03	62600.00
A8D16C	2017-08-07 23:24:00+03	67200.00
A8D1E2	2017-07-31 22:33:00+03	46000.00
A8D215	2017-08-13 08:52:00+03	24700.00
A8D2AD	2017-07-21 11:45:00+03	15000.00
A8D2BB	2017-07-25 06:24:00+03	88600.00
A8D2FD	2017-07-19 17:55:00+03	68600.00
A8D35C	2017-08-02 10:05:00+03	57400.00
A8D364	2017-07-14 03:24:00+03	38000.00
A8D37C	2017-08-07 01:36:00+03	121800.00
A8D422	2017-07-21 11:26:00+03	14800.00
A8D425	2017-08-05 13:42:00+03	283100.00
A8D437	2017-07-24 18:24:00+03	58400.00
A8D43F	2017-07-22 23:30:00+03	64900.00
A8D4D2	2017-07-31 10:48:00+03	61800.00
A8D4F3	2017-08-03 13:10:00+03	41200.00
A8D551	2017-07-25 17:56:00+03	173900.00
A8D5C3	2017-07-03 13:18:00+03	21000.00
A8D5E1	2017-07-12 02:09:00+03	56000.00
A8D5EA	2017-07-17 08:06:00+03	123000.00
A8D63D	2017-08-13 07:38:00+03	58200.00
A8D685	2017-08-05 00:10:00+03	71400.00
A8D742	2017-07-07 06:30:00+03	84000.00
A8D787	2017-07-08 02:53:00+03	75300.00
A8D7BF	2017-06-29 23:03:00+03	266400.00
A8D81C	2017-07-24 01:11:00+03	28800.00
A8D821	2017-08-06 13:24:00+03	383200.00
A8D855	2017-08-04 05:46:00+03	130800.00
A8D885	2017-07-24 21:03:00+03	23200.00
A8D8B1	2017-07-25 08:45:00+03	114500.00
A8D922	2017-08-03 16:42:00+03	305800.00
A8D971	2017-08-07 10:37:00+03	56000.00
A8D98D	2017-06-28 18:59:00+03	62600.00
A8D9A5	2017-07-26 15:19:00+03	3400.00
A8D9AD	2017-07-03 19:41:00+03	54500.00
A8D9E3	2017-08-08 13:11:00+03	82000.00
A8D9FD	2017-08-01 18:52:00+03	14900.00
A8DA12	2017-08-13 16:32:00+03	51000.00
A8DA34	2017-08-01 22:10:00+03	68800.00
A8DAB3	2017-07-11 04:41:00+03	266400.00
A8DAE7	2017-07-10 17:52:00+03	6700.00
A8DB03	2017-07-09 14:09:00+03	6300.00
A8DB39	2017-07-02 13:55:00+03	27800.00
A8DC16	2017-07-12 04:30:00+03	31400.00
A8DC30	2017-08-12 01:39:00+03	123000.00
A8DC35	2017-08-13 13:35:00+03	11600.00
A8DC48	2017-08-09 08:35:00+03	135600.00
A8DC9A	2017-07-21 02:45:00+03	111600.00
A8DC9E	2017-07-19 00:20:00+03	258400.00
A8DCFB	2017-07-12 13:19:00+03	27200.00
A8DD1F	2017-07-17 22:59:00+03	89500.00
A8DD4D	2017-07-26 10:52:00+03	69600.00
A8DD89	2017-07-13 06:47:00+03	69400.00
A8DDD4	2017-06-30 11:26:00+03	106400.00
A8DDF7	2017-07-18 15:22:00+03	81200.00
A8DE2A	2017-08-01 18:13:00+03	146500.00
A8DE2B	2017-07-31 22:28:00+03	19600.00
A8DE4E	2017-08-13 16:01:00+03	46500.00
A8DF67	2017-08-07 07:10:00+03	27800.00
A8DF88	2017-07-09 02:54:00+03	31400.00
A8E014	2017-08-09 20:03:00+03	58600.00
A8E049	2017-07-30 00:16:00+03	202400.00
A8E0AA	2017-08-01 14:29:00+03	67500.00
A8E0D0	2017-07-26 03:40:00+03	119600.00
A8E118	2017-08-10 08:43:00+03	92600.00
A8E16A	2017-07-09 01:33:00+03	18800.00
A8E1A8	2017-07-04 12:45:00+03	43500.00
A8E1BE	2017-07-17 10:10:00+03	63200.00
A8E1D7	2017-07-01 16:15:00+03	55800.00
A8E1DB	2017-07-28 06:57:00+03	75800.00
A8E1E0	2017-08-09 23:34:00+03	158500.00
A8E1F9	2017-08-06 23:49:00+03	75600.00
A8E250	2017-06-27 15:38:00+03	24400.00
A8E28F	2017-07-06 10:33:00+03	28000.00
A8E38D	2017-07-25 05:23:00+03	131100.00
A8E3B2	2017-07-31 06:18:00+03	150400.00
A8E3FC	2017-08-13 16:47:00+03	99300.00
A8E41E	2017-08-09 12:47:00+03	38200.00
A8E451	2017-07-01 15:32:00+03	96800.00
A8E46A	2017-07-26 14:18:00+03	47000.00
A8E4C8	2017-07-14 16:50:00+03	28800.00
A8E568	2017-08-08 01:59:00+03	26600.00
A8E579	2017-08-11 21:00:00+03	69500.00
A8E5DC	2017-07-13 21:20:00+03	143100.00
A8E62C	2017-07-07 18:46:00+03	22000.00
A8E647	2017-08-05 00:50:00+03	47400.00
A8E661	2017-07-22 10:54:00+03	56000.00
A8E672	2017-08-10 03:32:00+03	95600.00
A8E6C5	2017-07-10 13:17:00+03	23100.00
A8E6FF	2017-07-08 23:54:00+03	112000.00
A8E7A3	2017-08-11 13:00:00+03	34400.00
A8E7EB	2017-06-28 04:59:00+03	46200.00
A8E7FD	2017-07-09 08:15:00+03	410200.00
A8E80C	2017-08-14 05:46:00+03	26200.00
A8E848	2017-07-21 00:39:00+03	36200.00
A8E89F	2017-07-04 16:35:00+03	23200.00
A8E8AB	2017-07-06 09:51:00+03	79200.00
A8E8CD	2017-07-15 19:30:00+03	52900.00
A8E8DF	2017-08-01 16:22:00+03	283000.00
A8E929	2017-07-13 06:48:00+03	66700.00
A8E94D	2017-07-25 06:26:00+03	49600.00
A8E9BE	2017-07-22 20:14:00+03	202600.00
A8E9CE	2017-08-03 21:01:00+03	134400.00
A8E9DA	2017-07-17 23:25:00+03	85000.00
A8EA0F	2017-08-07 09:59:00+03	56600.00
A8EA62	2017-07-14 18:17:00+03	123000.00
A8EA9D	2017-08-03 22:48:00+03	55900.00
A8EB02	2017-07-14 15:39:00+03	55800.00
A8EB32	2017-07-18 21:34:00+03	72400.00
A8EB58	2017-08-11 08:47:00+03	29400.00
A8EB6F	2017-08-15 06:00:00+03	113000.00
A8EBFE	2017-08-06 04:23:00+03	75300.00
A8EC6D	2017-07-12 03:29:00+03	68000.00
A8ECDD	2017-07-29 18:52:00+03	28800.00
A8ED28	2017-07-11 20:24:00+03	75600.00
A8ED37	2017-07-01 18:40:00+03	20600.00
A8ED5C	2017-08-04 05:10:00+03	55000.00
A8ED91	2017-06-30 21:32:00+03	39200.00
A8ED97	2017-07-29 21:05:00+03	21800.00
A8EDA2	2017-08-12 12:53:00+03	17300.00
A8EDB1	2017-07-10 11:39:00+03	90400.00
A8EE0F	2017-07-05 08:11:00+03	22000.00
A8EE1E	2017-07-17 02:21:00+03	88600.00
A8EE6C	2017-07-23 17:57:00+03	46000.00
A8EE87	2017-08-12 11:40:00+03	23600.00
A8EF37	2017-08-07 07:46:00+03	6400.00
A8EFFA	2017-07-28 04:32:00+03	25400.00
A8F068	2017-07-27 02:21:00+03	35700.00
A8F074	2017-07-09 03:03:00+03	123000.00
A8F0D5	2017-08-04 14:30:00+03	92800.00
A8F110	2017-07-16 10:38:00+03	44600.00
A8F13B	2017-08-09 07:53:00+03	92800.00
A8F1CD	2017-07-12 22:05:00+03	158700.00
A8F1EB	2017-07-08 04:17:00+03	48300.00
A8F1F4	2017-07-24 16:13:00+03	46000.00
A8F216	2017-08-15 09:28:00+03	94800.00
A8F2C4	2017-07-21 00:58:00+03	30200.00
A8F36D	2017-07-20 05:02:00+03	17200.00
A8F3B8	2017-08-12 08:10:00+03	229900.00
A8F3CB	2017-07-06 21:50:00+03	56600.00
A8F3F4	2017-08-03 11:43:00+03	30800.00
A8F435	2017-07-03 06:39:00+03	377400.00
A8F43E	2017-07-23 05:01:00+03	35200.00
A8F453	2017-07-17 00:01:00+03	53600.00
A8F455	2017-08-14 16:50:00+03	54500.00
A8F4D1	2017-06-28 17:56:00+03	65600.00
A8F5AC	2017-06-30 22:40:00+03	68800.00
A8F5DA	2017-08-06 11:37:00+03	44800.00
A8F613	2017-07-23 19:26:00+03	77700.00
A8F63D	2017-07-28 07:51:00+03	112000.00
A8F657	2017-06-29 02:04:00+03	11600.00
A8F676	2017-07-19 21:27:00+03	53400.00
A8F683	2017-07-03 14:22:00+03	56600.00
A8F69D	2017-07-13 23:11:00+03	16400.00
A8F6F5	2017-07-06 04:48:00+03	103900.00
A8F815	2017-08-03 17:03:00+03	68800.00
A8F833	2017-08-06 09:26:00+03	35200.00
A8F8B9	2017-07-26 08:36:00+03	398600.00
A8F8C5	2017-07-31 19:38:00+03	31600.00
A8F8D1	2017-08-09 19:04:00+03	83600.00
A8F910	2017-07-11 00:54:00+03	48700.00
A8F913	2017-07-27 18:14:00+03	44800.00
A8F915	2017-08-11 20:25:00+03	26000.00
A8F93A	2017-07-02 23:06:00+03	43200.00
A8F957	2017-06-26 06:11:00+03	46400.00
A8FA5D	2017-08-04 18:40:00+03	66600.00
A8FA85	2017-08-14 14:18:00+03	128800.00
A8FAB0	2017-07-10 18:22:00+03	102800.00
A8FAE6	2017-07-02 08:53:00+03	148700.00
A8FB04	2017-07-01 01:04:00+03	13400.00
A8FB39	2017-07-19 09:16:00+03	400000.00
A8FBA0	2017-08-14 08:42:00+03	57500.00
A8FBBD	2017-07-26 00:21:00+03	27800.00
A8FBF0	2017-07-12 00:55:00+03	102100.00
A8FC78	2017-08-06 15:45:00+03	205600.00
A8FD8E	2017-07-04 13:45:00+03	118300.00
A8FDA7	2017-06-30 14:17:00+03	257500.00
A8FDDE	2017-07-06 03:39:00+03	80100.00
A8FE01	2017-08-10 04:50:00+03	26000.00
A8FE17	2017-07-18 02:44:00+03	55800.00
A8FE6B	2017-07-27 21:27:00+03	18400.00
A8FE73	2017-07-24 02:05:00+03	16400.00
A8FEBA	2017-08-02 14:53:00+03	85000.00
A8FF66	2017-07-24 18:28:00+03	65900.00
A90014	2017-07-28 04:51:00+03	28800.00
A90053	2017-07-13 17:59:00+03	40200.00
A9007F	2017-07-26 06:53:00+03	192700.00
A900FE	2017-08-02 01:30:00+03	51900.00
A90123	2017-07-13 13:40:00+03	64300.00
A9012E	2017-07-22 04:40:00+03	48800.00
A901D6	2017-08-05 19:21:00+03	132500.00
A9029B	2017-07-28 00:18:00+03	56600.00
A9032D	2017-08-11 22:28:00+03	83000.00
A90349	2017-07-01 16:02:00+03	119700.00
A90380	2017-07-08 21:39:00+03	56600.00
A90398	2017-08-06 21:03:00+03	40600.00
A9039F	2017-07-13 12:28:00+03	21800.00
A903C2	2017-07-24 20:18:00+03	265800.00
A903CA	2017-08-12 15:58:00+03	6700.00
A903D9	2017-07-13 06:03:00+03	69100.00
A90401	2017-07-04 15:37:00+03	301800.00
A90454	2017-08-01 16:01:00+03	135400.00
A9051C	2017-07-16 16:08:00+03	123000.00
A90532	2017-08-09 06:23:00+03	69900.00
A9056C	2017-07-18 01:05:00+03	13600.00
A905A8	2017-06-30 17:32:00+03	120900.00
A90640	2017-08-11 20:53:00+03	43600.00
A9069F	2017-07-26 10:49:00+03	13600.00
A906C4	2017-06-28 17:01:00+03	214800.00
A90742	2017-07-13 21:01:00+03	56600.00
A9075B	2017-07-25 15:55:00+03	75300.00
A9077E	2017-07-22 02:32:00+03	16400.00
A907B0	2017-08-12 11:13:00+03	12400.00
A90818	2017-08-10 02:27:00+03	6000.00
A90859	2017-08-04 21:17:00+03	26000.00
A908C1	2017-08-10 15:24:00+03	46700.00
A908D8	2017-08-08 21:43:00+03	39300.00
A908F1	2017-08-14 04:49:00+03	26000.00
A90944	2017-07-27 19:20:00+03	68700.00
A90953	2017-07-16 04:12:00+03	81600.00
A90959	2017-07-21 00:14:00+03	81600.00
A9097A	2017-08-10 22:19:00+03	115500.00
A9099C	2017-06-30 11:18:00+03	36400.00
A909E0	2017-07-31 22:45:00+03	26600.00
A909FA	2017-07-05 08:57:00+03	116900.00
A90A76	2017-07-02 17:56:00+03	21800.00
A90B06	2017-08-15 11:25:00+03	46800.00
A90BAE	2017-08-14 04:38:00+03	97900.00
A90BC5	2017-07-01 22:13:00+03	83000.00
A90BC7	2017-07-23 05:53:00+03	108000.00
A90BDE	2017-07-30 03:11:00+03	26000.00
A90BF9	2017-08-11 13:02:00+03	212400.00
A90CE2	2017-07-04 11:31:00+03	39300.00
A90D03	2017-07-22 07:48:00+03	169900.00
A90D10	2017-08-11 12:32:00+03	32400.00
A90D28	2017-08-08 18:57:00+03	334400.00
A90D2F	2017-08-03 06:40:00+03	47400.00
A90D35	2017-07-13 21:52:00+03	46400.00
A90D4F	2017-07-09 06:38:00+03	149300.00
A90D84	2017-07-07 09:22:00+03	120900.00
A90DC6	2017-08-07 15:39:00+03	266300.00
A90E1A	2017-07-05 18:03:00+03	56600.00
A90E3A	2017-07-26 06:40:00+03	23200.00
A90ED9	2017-08-11 12:42:00+03	37600.00
A90EE7	2017-07-08 06:21:00+03	134400.00
A90F1F	2017-08-11 05:27:00+03	75600.00
A90F38	2017-07-12 18:50:00+03	193100.00
A90F61	2017-07-29 05:22:00+03	97900.00
A90F6D	2017-07-25 22:44:00+03	24500.00
A90F79	2017-07-10 04:19:00+03	34600.00
A90F89	2017-08-07 03:40:00+03	32700.00
A90FFC	2017-08-13 17:25:00+03	99200.00
A90FFF	2017-07-31 23:54:00+03	211500.00
A91054	2017-07-30 12:45:00+03	11700.00
A91060	2017-07-08 13:06:00+03	205000.00
A91089	2017-07-13 17:10:00+03	75300.00
A910A4	2017-07-16 16:48:00+03	27200.00
A910F5	2017-07-04 10:13:00+03	92700.00
A91105	2017-07-28 23:06:00+03	111600.00
A9111B	2017-08-01 16:52:00+03	16400.00
A91126	2017-07-22 15:07:00+03	229900.00
A91128	2017-07-11 18:13:00+03	28000.00
A9114E	2017-08-10 01:50:00+03	13400.00
A9119B	2017-07-21 07:12:00+03	46200.00
A911C0	2017-07-10 22:38:00+03	71800.00
A91267	2017-07-14 16:35:00+03	77900.00
A912EB	2017-08-03 00:03:00+03	59800.00
A91325	2017-08-03 23:20:00+03	13600.00
A913E6	2017-07-27 20:46:00+03	26800.00
A9151E	2017-07-09 02:08:00+03	28800.00
A9155F	2017-08-09 11:22:00+03	48100.00
A9157D	2017-08-15 17:35:00+03	60400.00
A915CC	2017-08-11 03:49:00+03	97700.00
A9168A	2017-08-02 02:29:00+03	29400.00
A9170F	2017-07-06 00:59:00+03	54300.00
A91760	2017-08-02 02:22:00+03	168000.00
A9177C	2017-07-19 16:59:00+03	291600.00
A91796	2017-06-27 12:37:00+03	46000.00
A91811	2017-07-14 22:22:00+03	169300.00
A91826	2017-07-02 17:06:00+03	35600.00
A91864	2017-07-23 14:50:00+03	24400.00
A9186B	2017-08-09 20:16:00+03	47100.00
A91871	2017-07-20 16:25:00+03	174300.00
A91886	2017-08-05 03:22:00+03	38800.00
A9189F	2017-07-27 15:00:00+03	249100.00
A91941	2017-06-28 06:25:00+03	62600.00
A91994	2017-07-19 09:47:00+03	59300.00
A919BE	2017-07-21 00:58:00+03	46800.00
A919C6	2017-07-05 20:35:00+03	265600.00
A919E8	2017-07-02 11:05:00+03	35900.00
A91A97	2017-07-31 01:47:00+03	6600.00
A91AD6	2017-07-07 04:15:00+03	81300.00
A91AEC	2017-07-28 11:56:00+03	46400.00
A91B15	2017-07-08 06:15:00+03	639800.00
A91B18	2017-08-15 09:26:00+03	28800.00
A91B52	2017-07-23 11:15:00+03	36200.00
A91B66	2017-08-06 16:50:00+03	42700.00
A91C0B	2017-08-12 13:59:00+03	86200.00
A91C3F	2017-07-27 23:36:00+03	46800.00
A91C61	2017-08-01 21:32:00+03	11800.00
A91CAB	2017-08-11 19:27:00+03	20000.00
A91D46	2017-07-26 17:00:00+03	54800.00
A91D48	2017-08-09 07:41:00+03	47200.00
A91D57	2017-07-03 22:54:00+03	66600.00
A91D60	2017-06-30 19:43:00+03	40800.00
A91D68	2017-08-04 06:57:00+03	25800.00
A91E48	2017-07-29 23:35:00+03	27200.00
A91E55	2017-07-24 09:35:00+03	56000.00
A91EA2	2017-06-28 21:12:00+03	120100.00
A91F92	2017-07-13 13:54:00+03	120400.00
A91FCC	2017-07-23 14:33:00+03	277000.00
A91FDD	2017-08-09 20:31:00+03	42800.00
A91FE8	2017-07-10 05:38:00+03	48800.00
A9202B	2017-08-15 02:13:00+03	16400.00
A92046	2017-07-20 06:53:00+03	393000.00
A9209E	2017-07-31 23:15:00+03	26600.00
A920B1	2017-08-06 04:17:00+03	28300.00
A920D0	2017-07-13 18:22:00+03	111700.00
A9211E	2017-07-29 17:55:00+03	68000.00
A9215A	2017-07-15 00:52:00+03	25400.00
A921B7	2017-08-08 14:09:00+03	71400.00
A92249	2017-07-28 12:25:00+03	27900.00
A92292	2017-07-10 09:57:00+03	199200.00
A9234B	2017-08-11 02:42:00+03	138000.00
A92358	2017-08-14 06:54:00+03	246000.00
A9235E	2017-07-26 17:16:00+03	28000.00
A9236D	2017-08-11 18:36:00+03	136400.00
A923F3	2017-08-09 16:33:00+03	133200.00
A92450	2017-07-27 11:15:00+03	60600.00
A92469	2017-07-29 15:28:00+03	46400.00
A92486	2017-07-08 10:41:00+03	59800.00
A924B7	2017-08-14 10:37:00+03	100600.00
A9254C	2017-07-23 17:14:00+03	28800.00
A92565	2017-08-12 06:42:00+03	72400.00
A925FD	2017-08-11 03:55:00+03	24600.00
A92661	2017-07-06 10:49:00+03	131100.00
A926CF	2017-08-03 00:01:00+03	101500.00
A926E2	2017-08-12 10:56:00+03	132800.00
A927AB	2017-07-14 14:53:00+03	154900.00
A927AF	2017-07-03 13:31:00+03	22800.00
A92877	2017-07-20 18:08:00+03	46200.00
A9287E	2017-06-30 20:09:00+03	74800.00
A928AA	2017-08-07 12:38:00+03	79600.00
A92921	2017-07-11 23:08:00+03	61500.00
A9296D	2017-08-10 23:00:00+03	35800.00
A92986	2017-07-25 03:07:00+03	13600.00
A9299E	2017-07-23 03:26:00+03	144400.00
A929CF	2017-08-02 04:18:00+03	27800.00
A92AB1	2017-07-04 06:16:00+03	53800.00
A92AEB	2017-07-21 09:21:00+03	23400.00
A92B25	2017-08-12 17:41:00+03	229300.00
A92B38	2017-06-30 13:10:00+03	372500.00
A92B6F	2017-07-12 10:23:00+03	100600.00
A92B9A	2017-07-26 16:19:00+03	57500.00
A92BBD	2017-07-08 02:38:00+03	88800.00
A92BD7	2017-08-11 03:03:00+03	72100.00
A92BF6	2017-08-14 19:31:00+03	140800.00
A92C12	2017-07-11 17:39:00+03	136800.00
A92C3F	2017-07-05 07:39:00+03	44000.00
A92C55	2017-07-04 19:46:00+03	118700.00
A92C69	2017-07-28 15:06:00+03	272400.00
A92CE1	2017-07-29 21:22:00+03	61800.00
A92D3E	2017-07-20 19:05:00+03	21200.00
A92D77	2017-07-09 08:44:00+03	63700.00
A92DC7	2017-08-13 21:37:00+03	30400.00
A92E73	2017-06-26 02:24:00+03	42800.00
A92E96	2017-08-05 01:32:00+03	56000.00
A92E97	2017-07-17 15:15:00+03	28300.00
A92EE8	2017-08-05 16:26:00+03	31400.00
A92F0D	2017-08-05 18:40:00+03	67600.00
A92F1D	2017-07-21 19:19:00+03	175400.00
A92F7B	2017-08-06 16:15:00+03	45400.00
A92FD0	2017-07-16 03:49:00+03	49200.00
A93010	2017-07-17 21:06:00+03	7300.00
A93026	2017-08-15 12:02:00+03	33700.00
A930B2	2017-07-24 03:07:00+03	155600.00
A930DB	2017-07-01 12:28:00+03	28000.00
A930F4	2017-07-27 11:59:00+03	50600.00
A93107	2017-07-08 12:04:00+03	56600.00
A93132	2017-08-04 17:26:00+03	92800.00
A93147	2017-07-10 05:33:00+03	81300.00
A93150	2017-08-06 22:44:00+03	20200.00
A93206	2017-07-27 22:50:00+03	67400.00
A93258	2017-07-28 10:33:00+03	28300.00
A93297	2017-07-12 22:46:00+03	10800.00
A932A1	2017-07-26 00:35:00+03	144400.00
A9330E	2017-07-18 19:19:00+03	92400.00
A93325	2017-07-31 23:57:00+03	302800.00
A93344	2017-07-20 06:53:00+03	54600.00
A933E7	2017-07-26 02:24:00+03	109600.00
A933E9	2017-08-01 15:48:00+03	119800.00
A93402	2017-07-01 15:11:00+03	50600.00
A9342C	2017-08-06 14:19:00+03	70400.00
A93442	2017-07-31 10:29:00+03	62600.00
A93474	2017-06-29 22:30:00+03	140900.00
A934DA	2017-07-02 17:14:00+03	7400.00
A934FE	2017-07-14 13:48:00+03	179400.00
A9355B	2017-07-05 23:16:00+03	73300.00
A935CA	2017-07-13 20:42:00+03	69600.00
A93609	2017-07-14 12:35:00+03	25600.00
A9362F	2017-08-05 09:44:00+03	47000.00
A93642	2017-07-22 18:06:00+03	15900.00
A93684	2017-08-10 10:35:00+03	26800.00
A9369F	2017-08-10 18:48:00+03	108900.00
A936B6	2017-07-01 06:40:00+03	66600.00
A936D2	2017-07-19 12:24:00+03	59800.00
A936F1	2017-07-23 05:20:00+03	42800.00
A9372D	2017-07-10 10:58:00+03	24600.00
A93791	2017-07-04 18:35:00+03	42800.00
A937EF	2017-07-23 13:30:00+03	51500.00
A93813	2017-07-25 03:08:00+03	111600.00
A938DA	2017-08-09 06:17:00+03	102300.00
A93946	2017-07-07 23:47:00+03	49000.00
A93980	2017-08-13 19:43:00+03	48000.00
A9398C	2017-08-15 12:08:00+03	13000.00
A93990	2017-07-15 09:42:00+03	25000.00
A939D0	2017-07-03 14:03:00+03	42500.00
A93A12	2017-07-22 18:16:00+03	113700.00
A93A2F	2017-07-29 08:56:00+03	71000.00
A93A5E	2017-07-14 23:55:00+03	76600.00
A93A7C	2017-08-09 05:55:00+03	128800.00
A93A96	2017-08-04 01:34:00+03	6300.00
A93AE7	2017-07-30 16:05:00+03	54800.00
A93B00	2017-07-23 02:19:00+03	30400.00
A93B08	2017-07-07 18:58:00+03	31600.00
A93B79	2017-06-30 07:55:00+03	35200.00
A93B88	2017-08-03 14:28:00+03	36200.00
A93C10	2017-07-04 12:28:00+03	136200.00
A93C53	2017-08-10 22:54:00+03	52000.00
A93C56	2017-07-05 19:21:00+03	226800.00
A93C6F	2017-08-13 13:13:00+03	14400.00
A93C94	2017-07-16 17:59:00+03	226200.00
A93CAA	2017-07-24 23:32:00+03	36200.00
A93CC0	2017-07-18 22:34:00+03	16400.00
A93DA8	2017-07-06 20:21:00+03	27800.00
A93DF0	2017-07-12 10:32:00+03	6400.00
A93DF1	2017-08-03 03:49:00+03	52000.00
A93EB3	2017-08-11 04:53:00+03	162000.00
A93F14	2017-08-14 06:23:00+03	39400.00
A93F42	2017-07-08 00:54:00+03	11000.00
A93F5B	2017-08-06 02:46:00+03	22600.00
A93F6D	2017-07-05 23:40:00+03	68800.00
A93F8E	2017-07-12 21:52:00+03	56000.00
A93FA1	2017-08-05 02:13:00+03	64700.00
A93FBF	2017-08-02 21:05:00+03	38400.00
A93FDE	2017-07-19 09:31:00+03	164300.00
A9401C	2017-08-11 03:24:00+03	39200.00
A94097	2017-07-19 18:50:00+03	238900.00
A940E9	2017-07-21 22:37:00+03	38500.00
A94114	2017-08-07 06:18:00+03	73200.00
A94134	2017-07-05 02:08:00+03	39800.00
A941AF	2017-07-26 16:11:00+03	46400.00
A941C8	2017-08-13 03:43:00+03	25800.00
A9421B	2017-07-06 23:45:00+03	39500.00
A94227	2017-07-09 02:25:00+03	89000.00
A9424D	2017-07-12 19:07:00+03	45200.00
A9429F	2017-06-29 16:21:00+03	7200.00
A942A3	2017-07-27 14:08:00+03	9000.00
A942DF	2017-08-12 16:27:00+03	79900.00
A94339	2017-07-27 12:15:00+03	7200.00
A9436E	2017-07-06 09:07:00+03	37400.00
A943B1	2017-07-26 19:14:00+03	87000.00
A94422	2017-07-01 11:23:00+03	107900.00
A9442D	2017-08-10 17:51:00+03	56100.00
A9449B	2017-07-20 11:44:00+03	21500.00
A9450B	2017-07-25 01:45:00+03	13400.00
A94528	2017-07-02 15:10:00+03	45400.00
A94557	2017-07-07 09:18:00+03	34400.00
A94578	2017-08-11 05:10:00+03	88500.00
A94588	2017-08-13 09:16:00+03	48800.00
A945D7	2017-08-09 02:20:00+03	87900.00
A9461E	2017-06-27 13:09:00+03	20100.00
A9462F	2017-08-06 04:25:00+03	353600.00
A94643	2017-07-26 01:39:00+03	202400.00
A9464F	2017-07-11 19:28:00+03	239400.00
A9466F	2017-07-07 23:58:00+03	8600.00
A9467A	2017-07-05 13:21:00+03	43000.00
A9468C	2017-07-17 15:36:00+03	56000.00
A9471C	2017-08-12 12:07:00+03	22000.00
A94768	2017-08-11 20:47:00+03	103500.00
A94787	2017-08-14 06:28:00+03	6700.00
A947B5	2017-08-08 05:27:00+03	55800.00
A947C8	2017-07-12 12:17:00+03	18100.00
A9481F	2017-08-13 04:57:00+03	102000.00
A9482A	2017-07-03 22:20:00+03	42000.00
A94856	2017-08-07 06:31:00+03	36800.00
A94874	2017-07-20 06:32:00+03	75500.00
A948A0	2017-07-06 21:43:00+03	16400.00
A948BC	2017-07-18 05:33:00+03	16400.00
A94912	2017-07-04 15:31:00+03	43600.00
A949DF	2017-08-11 08:36:00+03	75800.00
A949E1	2017-07-15 03:02:00+03	99200.00
A94A5B	2017-07-26 00:20:00+03	68400.00
A94A69	2017-07-17 00:21:00+03	58200.00
A94A74	2017-07-27 21:14:00+03	88000.00
A94A7A	2017-07-31 01:06:00+03	28200.00
A94AB7	2017-07-15 14:31:00+03	81800.00
A94AF9	2017-07-13 03:14:00+03	101200.00
A94B00	2017-07-13 16:33:00+03	18600.00
A94B2A	2017-07-20 08:47:00+03	55600.00
A94B45	2017-08-09 23:30:00+03	56000.00
A94B74	2017-07-19 14:16:00+03	496700.00
A94B7D	2017-07-24 14:21:00+03	12400.00
A94BA2	2017-07-25 22:41:00+03	22000.00
A94BD9	2017-07-17 12:49:00+03	80200.00
A94BF3	2017-07-15 12:31:00+03	135400.00
A94C29	2017-07-27 08:55:00+03	21200.00
A94C83	2017-07-25 13:42:00+03	290500.00
A94C8A	2017-08-02 10:50:00+03	283000.00
A94CDC	2017-07-26 11:37:00+03	59900.00
A94D1A	2017-08-12 00:28:00+03	31100.00
A94D40	2017-08-09 06:12:00+03	123000.00
A94D79	2017-07-02 19:47:00+03	24400.00
A94D8B	2017-07-29 22:24:00+03	59800.00
A94DB6	2017-07-24 02:15:00+03	14000.00
A94DC0	2017-07-09 09:03:00+03	14700.00
A94DE2	2017-07-24 05:20:00+03	7200.00
A94DE7	2017-08-07 18:52:00+03	58600.00
A94DE8	2017-07-12 00:39:00+03	54400.00
A94DEC	2017-07-06 04:44:00+03	26000.00
A94DED	2017-08-09 06:25:00+03	224000.00
A94DF9	2017-07-26 22:33:00+03	23400.00
A94E0B	2017-07-17 02:35:00+03	13400.00
A94E12	2017-07-15 16:00:00+03	6800.00
A94E32	2017-07-29 08:26:00+03	40800.00
A94E36	2017-07-22 22:33:00+03	168000.00
A94E73	2017-07-13 18:37:00+03	73300.00
A94EA5	2017-08-15 06:25:00+03	18300.00
A94ED9	2017-07-11 14:46:00+03	137800.00
A94EE1	2017-08-14 21:15:00+03	58000.00
A94F3B	2017-08-10 06:56:00+03	57800.00
A94F5F	2017-08-06 05:07:00+03	66600.00
A94F7C	2017-08-01 10:47:00+03	36400.00
A94FC1	2017-07-04 05:03:00+03	135400.00
A94FC5	2017-08-13 05:52:00+03	36000.00
A94FD8	2017-07-06 13:16:00+03	13400.00
A94FF3	2017-07-22 13:50:00+03	22000.00
A950BC	2017-07-17 12:55:00+03	21800.00
A950C7	2017-08-04 04:41:00+03	184000.00
A95133	2017-07-16 23:56:00+03	22200.00
A951A2	2017-07-23 02:58:00+03	52000.00
A951ED	2017-08-04 04:30:00+03	80900.00
A951F9	2017-07-14 20:01:00+03	76600.00
A9524B	2017-08-12 10:46:00+03	54000.00
A95347	2017-07-23 08:08:00+03	46200.00
A95348	2017-08-15 02:23:00+03	25400.00
A9535E	2017-08-14 00:05:00+03	268300.00
A95369	2017-08-09 19:09:00+03	117700.00
A95377	2017-07-12 18:10:00+03	33600.00
A95383	2017-07-22 02:07:00+03	65500.00
A953D1	2017-07-06 14:17:00+03	12200.00
A953E7	2017-07-09 15:53:00+03	11200.00
A95414	2017-08-04 11:28:00+03	43200.00
A95427	2017-07-10 22:57:00+03	59800.00
A95440	2017-07-17 04:29:00+03	55600.00
A95477	2017-07-08 02:42:00+03	35200.00
A9548A	2017-08-10 00:32:00+03	25800.00
A954E4	2017-08-14 06:04:00+03	136500.00
A954F5	2017-07-18 13:28:00+03	77200.00
A954FB	2017-07-09 18:42:00+03	54800.00
A95520	2017-06-26 20:47:00+03	87400.00
A9557F	2017-07-19 12:56:00+03	125400.00
A9558F	2017-07-08 10:48:00+03	76800.00
A95592	2017-07-03 19:54:00+03	28800.00
A9559F	2017-08-02 20:40:00+03	6000.00
A95683	2017-07-19 12:14:00+03	28000.00
A9572E	2017-08-02 21:33:00+03	36900.00
A9574D	2017-07-27 12:30:00+03	36200.00
A95828	2017-07-30 09:53:00+03	62600.00
A9587E	2017-08-03 11:41:00+03	139400.00
A958B0	2017-07-01 16:04:00+03	147700.00
A958F2	2017-07-04 01:37:00+03	103200.00
A95A51	2017-07-02 11:06:00+03	7400.00
A95A81	2017-08-09 17:01:00+03	35600.00
A95AA0	2017-07-25 10:26:00+03	34000.00
A95B21	2017-06-30 03:49:00+03	46400.00
A95B25	2017-07-22 10:43:00+03	135600.00
A95B3A	2017-08-09 13:23:00+03	101000.00
A95B3C	2017-07-04 01:41:00+03	34000.00
A95BE0	2017-07-23 08:01:00+03	73500.00
A95BFA	2017-07-24 01:54:00+03	69600.00
A95C49	2017-07-16 11:25:00+03	30200.00
A95C7F	2017-08-07 06:32:00+03	6700.00
A95CB6	2017-07-21 13:35:00+03	181800.00
A95D1C	2017-07-14 08:13:00+03	88900.00
A95D41	2017-08-06 18:33:00+03	7200.00
A95D43	2017-07-29 13:07:00+03	22000.00
A95DFD	2017-07-12 17:53:00+03	40400.00
A95E0E	2017-07-28 06:39:00+03	56000.00
A95E18	2017-07-06 20:24:00+03	46500.00
A95E53	2017-07-04 05:52:00+03	36200.00
A95E93	2017-07-22 19:45:00+03	83000.00
A95EC1	2017-07-14 08:42:00+03	54400.00
A95EE5	2017-08-01 17:14:00+03	176500.00
A95EF0	2017-07-26 18:37:00+03	103500.00
A95F8C	2017-07-14 18:02:00+03	75300.00
A95FD5	2017-07-11 10:18:00+03	166100.00
A9600F	2017-07-04 21:53:00+03	40900.00
A9602D	2017-07-24 20:55:00+03	36400.00
A96088	2017-07-27 11:16:00+03	46000.00
A960E0	2017-07-25 14:09:00+03	55600.00
A96101	2017-07-16 07:27:00+03	72300.00
A96142	2017-06-30 14:03:00+03	129400.00
A96212	2017-08-01 02:22:00+03	62000.00
A9622A	2017-07-06 04:35:00+03	153300.00
A9623B	2017-08-14 04:27:00+03	74600.00
A96240	2017-07-25 02:26:00+03	173500.00
A9628B	2017-07-11 20:52:00+03	89700.00
A962D1	2017-07-04 04:49:00+03	65300.00
A96306	2017-08-06 14:21:00+03	39900.00
A9638C	2017-07-08 14:54:00+03	78800.00
A9639E	2017-07-08 17:02:00+03	58400.00
A96402	2017-07-10 12:32:00+03	28300.00
A96433	2017-07-03 18:47:00+03	23900.00
A964BD	2017-07-20 16:03:00+03	28000.00
A964C9	2017-08-14 14:44:00+03	34400.00
A964EF	2017-08-04 11:11:00+03	24400.00
A96568	2017-08-01 23:27:00+03	25400.00
A9662D	2017-08-10 21:27:00+03	18400.00
A9671F	2017-07-06 12:24:00+03	51600.00
A9672C	2017-08-14 05:37:00+03	62800.00
A9675F	2017-08-09 07:58:00+03	29600.00
A967D3	2017-06-30 12:11:00+03	58000.00
A9682A	2017-07-02 11:09:00+03	47000.00
A9685F	2017-08-08 05:51:00+03	40000.00
A968AD	2017-07-19 21:22:00+03	75300.00
A96A20	2017-07-21 21:22:00+03	56100.00
A96A66	2017-08-14 15:44:00+03	13200.00
A96ADE	2017-06-28 06:03:00+03	26700.00
A96AE2	2017-08-15 07:06:00+03	47000.00
A96B47	2017-07-11 11:52:00+03	266400.00
A96B63	2017-08-09 12:04:00+03	191600.00
A96BA4	2017-07-24 19:59:00+03	28800.00
A96BD1	2017-08-14 02:33:00+03	20400.00
A96BF6	2017-08-13 15:07:00+03	283100.00
A96C33	2017-08-06 04:26:00+03	86600.00
A96C53	2017-08-07 10:38:00+03	68400.00
A96CAB	2017-08-09 09:50:00+03	98300.00
A96CC2	2017-07-12 04:24:00+03	86400.00
A96CC8	2017-07-09 03:44:00+03	49600.00
A96D18	2017-07-14 12:04:00+03	56000.00
A96E3E	2017-08-10 17:38:00+03	68800.00
A96E85	2017-07-18 13:46:00+03	42400.00
A96EEA	2017-08-14 20:12:00+03	65600.00
A96EEC	2017-08-02 19:23:00+03	38500.00
A96F11	2017-07-05 10:54:00+03	43600.00
A96F8D	2017-08-10 08:34:00+03	36200.00
A96FCE	2017-08-12 06:55:00+03	142300.00
A96FFE	2017-07-15 16:24:00+03	28000.00
A97030	2017-07-25 02:23:00+03	123000.00
A97049	2017-07-15 21:20:00+03	26000.00
A97088	2017-07-08 15:34:00+03	12600.00
A970B4	2017-07-14 11:16:00+03	13600.00
A9710E	2017-07-21 17:16:00+03	75300.00
A9713F	2017-08-03 15:35:00+03	36200.00
A9718C	2017-07-17 11:45:00+03	198900.00
A971DD	2017-08-07 01:46:00+03	26800.00
A971E2	2017-08-14 01:31:00+03	49100.00
A971E9	2017-07-01 01:51:00+03	27200.00
A97240	2017-08-03 02:32:00+03	190000.00
A972C1	2017-07-27 20:49:00+03	11600.00
A972C2	2017-08-15 10:26:00+03	22100.00
A972ED	2017-07-07 16:10:00+03	13000.00
A972F8	2017-08-10 23:59:00+03	137900.00
A972FA	2017-07-13 00:13:00+03	60600.00
A97328	2017-07-20 12:45:00+03	46400.00
A9736C	2017-07-26 22:21:00+03	56000.00
A97373	2017-07-06 14:56:00+03	180800.00
A973E1	2017-08-15 09:37:00+03	53900.00
A97456	2017-07-01 08:48:00+03	17600.00
A97482	2017-08-03 10:05:00+03	47000.00
A97495	2017-08-08 03:12:00+03	23200.00
A974C5	2017-07-08 08:16:00+03	6300.00
A9753E	2017-07-03 11:21:00+03	136600.00
A97557	2017-07-04 10:07:00+03	40800.00
A97596	2017-08-03 21:35:00+03	102700.00
A975F4	2017-07-31 13:19:00+03	38500.00
A9763D	2017-07-14 05:09:00+03	132800.00
A97679	2017-08-14 03:47:00+03	121100.00
A97759	2017-08-01 16:42:00+03	73100.00
A977CA	2017-07-18 09:23:00+03	135400.00
A9782B	2017-07-13 08:49:00+03	103500.00
A9784D	2017-08-04 16:41:00+03	177200.00
A9785A	2017-08-02 08:39:00+03	53600.00
A97878	2017-07-09 09:18:00+03	47400.00
A978F7	2017-07-18 21:34:00+03	56600.00
A97927	2017-07-07 09:37:00+03	213800.00
A979A3	2017-08-13 00:44:00+03	80900.00
A979E2	2017-07-17 13:32:00+03	26800.00
A97A3E	2017-06-29 15:17:00+03	52800.00
A97A47	2017-07-29 11:28:00+03	93600.00
A97A7E	2017-07-14 15:45:00+03	34000.00
A97AA6	2017-07-04 13:41:00+03	175300.00
A97B26	2017-08-03 23:28:00+03	86600.00
A97B2A	2017-07-14 14:39:00+03	62700.00
A97B92	2017-07-26 15:04:00+03	46200.00
A97BAC	2017-07-03 09:43:00+03	22400.00
A97BDB	2017-07-17 00:17:00+03	11600.00
A97C2C	2017-07-14 09:46:00+03	186500.00
A97C63	2017-08-15 11:01:00+03	40200.00
A97C65	2017-07-26 15:06:00+03	33100.00
A97C6E	2017-07-22 04:28:00+03	37200.00
A97C97	2017-07-16 16:35:00+03	67200.00
A97CDA	2017-07-09 17:18:00+03	57200.00
A97CFA	2017-07-01 12:48:00+03	6000.00
A97D60	2017-08-15 05:49:00+03	47100.00
A97D69	2017-07-16 14:06:00+03	61500.00
A97D7D	2017-07-02 02:37:00+03	21800.00
A97D99	2017-07-07 08:22:00+03	57500.00
A97DD6	2017-08-08 03:23:00+03	135600.00
A97E34	2017-08-13 06:16:00+03	136800.00
A97E38	2017-07-13 16:41:00+03	38500.00
A97EF6	2017-08-14 16:50:00+03	43500.00
A97F19	2017-07-28 06:06:00+03	6000.00
A97F7A	2017-07-30 06:05:00+03	30100.00
A98049	2017-07-28 19:08:00+03	48800.00
A980A2	2017-08-12 01:28:00+03	52100.00
A980D3	2017-08-10 06:04:00+03	174400.00
A980E8	2017-07-25 22:57:00+03	71300.00
A980F5	2017-07-06 10:08:00+03	52000.00
A98138	2017-07-06 21:49:00+03	169300.00
A981A4	2017-08-09 19:03:00+03	56000.00
A981C9	2017-08-10 12:02:00+03	29600.00
A981E5	2017-07-18 19:45:00+03	282100.00
A9821C	2017-07-13 01:25:00+03	29400.00
A9828F	2017-07-31 22:41:00+03	73600.00
A982B5	2017-08-13 03:51:00+03	56000.00
A982CF	2017-08-06 01:42:00+03	57500.00
A98311	2017-08-08 21:16:00+03	14000.00
A98362	2017-07-28 13:54:00+03	123000.00
A9836B	2017-07-29 15:08:00+03	11300.00
A98395	2017-07-21 22:03:00+03	23200.00
A983D6	2017-07-15 06:18:00+03	22000.00
A983EB	2017-07-12 03:13:00+03	21000.00
A9846B	2017-07-30 10:38:00+03	101200.00
A9846F	2017-07-10 17:11:00+03	56000.00
A984FA	2017-08-05 21:44:00+03	58800.00
A98590	2017-07-27 01:25:00+03	35500.00
A985C9	2017-08-15 13:33:00+03	135400.00
A985D8	2017-07-17 13:20:00+03	17600.00
A985E1	2017-08-05 21:32:00+03	25600.00
A985E5	2017-07-05 04:21:00+03	174400.00
A9868C	2017-08-05 03:10:00+03	81300.00
A986E8	2017-07-21 09:45:00+03	36200.00
A986F2	2017-07-25 06:12:00+03	314400.00
A98733	2017-07-23 00:22:00+03	61800.00
A98737	2017-08-11 15:44:00+03	133200.00
A98783	2017-07-31 01:07:00+03	28000.00
A987FF	2017-07-14 00:23:00+03	28300.00
A98817	2017-07-19 14:20:00+03	68000.00
A98820	2017-07-07 18:15:00+03	128100.00
A988A9	2017-07-17 23:31:00+03	91000.00
A988AD	2017-07-18 21:45:00+03	23200.00
A988C3	2017-07-13 02:18:00+03	369000.00
A98967	2017-07-22 22:07:00+03	94000.00
A98993	2017-07-14 04:12:00+03	13400.00
A989A6	2017-08-08 15:26:00+03	57200.00
A98A0D	2017-08-15 11:59:00+03	23200.00
A98A77	2017-07-07 09:58:00+03	62600.00
A98B23	2017-07-29 18:45:00+03	46000.00
A98B85	2017-07-24 21:49:00+03	36000.00
A98BE2	2017-07-14 17:13:00+03	57800.00
A98BE4	2017-07-21 13:35:00+03	20600.00
A98C1A	2017-07-14 12:01:00+03	57800.00
A98C3E	2017-08-09 18:37:00+03	51300.00
A98CE6	2017-07-22 20:08:00+03	87900.00
A98D09	2017-07-09 23:02:00+03	116500.00
A98D2E	2017-06-30 09:23:00+03	82900.00
A98D44	2017-07-15 09:26:00+03	102300.00
A98D49	2017-08-05 14:34:00+03	84500.00
A98D55	2017-08-07 23:34:00+03	28000.00
A98D8B	2017-07-26 04:41:00+03	111100.00
A98E99	2017-07-09 04:27:00+03	142200.00
A98EC6	2017-06-30 02:04:00+03	6000.00
A98F41	2017-07-08 05:28:00+03	65100.00
A98F5A	2017-07-16 04:30:00+03	396500.00
A98FA3	2017-07-16 20:45:00+03	47100.00
A99050	2017-07-27 00:59:00+03	47600.00
A99063	2017-07-19 17:50:00+03	142400.00
A990A8	2017-08-13 11:40:00+03	24000.00
A990C0	2017-07-16 01:10:00+03	117200.00
A99130	2017-08-04 07:39:00+03	43000.00
A99140	2017-07-02 07:16:00+03	19600.00
A99196	2017-07-12 13:41:00+03	86400.00
A991D3	2017-08-05 12:27:00+03	111900.00
A991E1	2017-08-15 09:07:00+03	204000.00
A991FD	2017-07-25 19:45:00+03	123000.00
A9920C	2017-08-12 18:12:00+03	321600.00
A99219	2017-07-24 19:30:00+03	71800.00
A99246	2017-07-31 11:46:00+03	73500.00
A99287	2017-07-13 03:37:00+03	44000.00
A992F9	2017-08-08 01:18:00+03	40400.00
A99318	2017-08-11 14:43:00+03	30900.00
A9934F	2017-08-13 01:31:00+03	40000.00
A993E3	2017-08-14 16:15:00+03	25200.00
A994D0	2017-07-30 09:22:00+03	41900.00
A99517	2017-07-13 09:42:00+03	45200.00
A99519	2017-07-21 14:53:00+03	48800.00
A9953C	2017-08-06 18:19:00+03	186900.00
A99552	2017-06-28 19:44:00+03	16400.00
A995A8	2017-07-11 23:03:00+03	390400.00
A99626	2017-07-15 16:22:00+03	71400.00
A99694	2017-07-28 08:09:00+03	39000.00
A99697	2017-08-07 21:26:00+03	28800.00
A996C9	2017-08-05 10:20:00+03	273300.00
A99745	2017-07-23 01:40:00+03	68100.00
A99749	2017-07-31 01:16:00+03	246000.00
A99753	2017-06-28 07:06:00+03	76100.00
A99764	2017-08-14 03:04:00+03	75300.00
A99768	2017-07-05 07:06:00+03	25100.00
A99794	2017-08-11 02:37:00+03	31100.00
A997EA	2017-07-26 15:24:00+03	41400.00
A99810	2017-07-17 05:32:00+03	44800.00
A9988C	2017-08-05 14:29:00+03	29600.00
A998ED	2017-07-20 15:48:00+03	26700.00
A999A4	2017-08-07 13:00:00+03	14000.00
A999CA	2017-08-10 09:36:00+03	92800.00
A999D5	2017-07-25 16:47:00+03	46000.00
A99ABF	2017-07-11 02:47:00+03	36800.00
A99AE8	2017-07-05 20:41:00+03	46300.00
A99AEA	2017-08-14 10:19:00+03	464600.00
A99B13	2017-07-11 08:17:00+03	311900.00
A99B45	2017-06-30 21:40:00+03	268800.00
A99B55	2017-08-04 06:42:00+03	293700.00
A99B63	2017-06-30 04:58:00+03	92000.00
A99B7D	2017-08-02 19:13:00+03	26000.00
A99B80	2017-07-07 07:58:00+03	23900.00
A99B8C	2017-07-27 23:15:00+03	51900.00
A99C30	2017-07-24 19:17:00+03	83000.00
A99C5D	2017-08-14 16:31:00+03	56000.00
A99C7B	2017-07-16 03:58:00+03	27700.00
A99C84	2017-07-17 01:22:00+03	126000.00
A99CAA	2017-08-01 14:59:00+03	54400.00
A99CC1	2017-07-20 07:43:00+03	21400.00
A99D77	2017-07-04 08:02:00+03	21400.00
A99DDD	2017-07-08 09:07:00+03	123000.00
A99E59	2017-07-08 20:26:00+03	8400.00
A99E88	2017-07-13 05:34:00+03	66600.00
A99E90	2017-07-29 05:58:00+03	89200.00
A99EC8	2017-07-25 13:24:00+03	66600.00
A99EE4	2017-07-10 10:57:00+03	147400.00
A99EF5	2017-07-14 08:45:00+03	68100.00
A99F2A	2017-08-10 18:34:00+03	17600.00
A99F34	2017-07-29 19:25:00+03	93900.00
A99F3A	2017-07-13 13:49:00+03	46300.00
A99F3D	2017-07-16 19:39:00+03	56000.00
A99F58	2017-08-13 19:12:00+03	42800.00
A99F6B	2017-07-01 11:06:00+03	11200.00
A99F9C	2017-07-27 23:08:00+03	22000.00
A99FC4	2017-08-08 16:16:00+03	257500.00
A9A00B	2017-08-13 22:06:00+03	45100.00
A9A043	2017-07-17 17:29:00+03	18600.00
A9A0C6	2017-08-02 00:24:00+03	24400.00
A9A0E9	2017-08-02 23:05:00+03	16400.00
A9A128	2017-07-29 05:32:00+03	43600.00
A9A15B	2017-07-23 17:58:00+03	55800.00
A9A1A8	2017-07-22 05:16:00+03	12600.00
A9A224	2017-07-21 14:39:00+03	44800.00
A9A245	2017-08-06 07:56:00+03	26700.00
A9A24B	2017-07-06 02:56:00+03	273300.00
A9A29F	2017-08-07 23:35:00+03	131600.00
A9A2AC	2017-07-09 15:31:00+03	58800.00
A9A2B7	2017-08-15 17:25:00+03	92100.00
A9A31B	2017-08-04 17:22:00+03	31000.00
A9A32F	2017-07-31 15:36:00+03	39700.00
A9A34F	2017-08-12 11:12:00+03	24400.00
A9A3B7	2017-08-12 14:39:00+03	30200.00
A9A3E8	2017-07-15 10:25:00+03	28000.00
A9A417	2017-08-01 21:41:00+03	16400.00
A9A41B	2017-08-10 19:33:00+03	135000.00
A9A44E	2017-08-04 02:04:00+03	24800.00
A9A461	2017-07-05 19:55:00+03	24400.00
A9A4C0	2017-07-28 17:14:00+03	63400.00
A9A4E1	2017-07-18 07:06:00+03	64500.00
A9A4E8	2017-07-07 02:02:00+03	28000.00
A9A503	2017-07-30 12:16:00+03	57600.00
A9A565	2017-08-09 14:41:00+03	112000.00
A9A69D	2017-07-27 02:52:00+03	25200.00
A9A6FC	2017-08-04 05:24:00+03	521200.00
A9A704	2017-07-03 19:47:00+03	64200.00
A9A779	2017-08-13 11:37:00+03	182300.00
A9A7A3	2017-07-09 03:33:00+03	64700.00
A9A7DA	2017-07-05 23:35:00+03	103200.00
A9A818	2017-07-05 17:29:00+03	51900.00
A9A88F	2017-08-05 21:17:00+03	50600.00
A9A8D8	2017-07-16 23:41:00+03	25000.00
A9A966	2017-07-24 22:03:00+03	64000.00
A9A96D	2017-07-06 09:56:00+03	135600.00
A9A97A	2017-07-13 08:05:00+03	30300.00
A9A9EF	2017-07-17 07:45:00+03	254900.00
A9AA59	2017-07-14 22:21:00+03	152200.00
A9AA8B	2017-07-09 17:49:00+03	42400.00
A9AAE9	2017-07-28 06:53:00+03	27200.00
A9AB3B	2017-08-04 05:33:00+03	133100.00
A9AB5D	2017-08-04 17:56:00+03	24700.00
A9ABE4	2017-08-10 22:56:00+03	88500.00
A9AC08	2017-07-28 13:23:00+03	76600.00
A9AC0B	2017-07-09 22:15:00+03	24800.00
A9ACBC	2017-08-13 07:21:00+03	23200.00
A9ACBF	2017-07-04 22:12:00+03	7400.00
A9AD75	2017-08-09 09:03:00+03	49600.00
A9AE17	2017-07-28 15:39:00+03	111000.00
A9AE1D	2017-07-10 08:56:00+03	54400.00
A9AE8D	2017-07-27 13:12:00+03	72400.00
A9AEA6	2017-07-16 10:03:00+03	75300.00
A9AEEF	2017-07-15 05:41:00+03	34400.00
A9AF14	2017-07-21 07:36:00+03	44000.00
A9AF6B	2017-07-03 00:07:00+03	64500.00
A9AF76	2017-07-22 21:16:00+03	117200.00
A9AFA0	2017-07-13 11:05:00+03	53300.00
A9AFCB	2017-08-05 15:46:00+03	31600.00
A9B12D	2017-08-11 05:19:00+03	150300.00
A9B1A4	2017-07-29 17:44:00+03	48800.00
A9B1A8	2017-08-15 08:42:00+03	17100.00
A9B1F1	2017-08-01 16:56:00+03	25400.00
A9B1F2	2017-07-04 17:24:00+03	56600.00
A9B244	2017-08-10 08:03:00+03	77000.00
A9B256	2017-07-28 18:57:00+03	381400.00
A9B27C	2017-07-29 15:36:00+03	422700.00
A9B2DA	2017-07-09 15:11:00+03	88800.00
A9B370	2017-07-08 19:07:00+03	40000.00
A9B3A4	2017-07-10 14:52:00+03	31000.00
A9B3D5	2017-07-23 05:41:00+03	21800.00
A9B3FF	2017-08-04 10:40:00+03	8000.00
A9B407	2017-07-16 10:40:00+03	37700.00
A9B425	2017-07-20 01:03:00+03	270000.00
A9B472	2017-07-23 19:01:00+03	85000.00
A9B49F	2017-07-01 04:16:00+03	22000.00
A9B4E6	2017-07-12 02:55:00+03	150600.00
A9B4EC	2017-08-03 01:23:00+03	109000.00
A9B4FE	2017-08-15 10:39:00+03	43800.00
A9B50E	2017-07-28 04:23:00+03	123000.00
A9B53A	2017-07-04 13:26:00+03	19600.00
A9B622	2017-07-24 18:42:00+03	145400.00
A9B652	2017-08-15 03:35:00+03	25100.00
A9B667	2017-07-17 15:17:00+03	58200.00
A9B71F	2017-07-19 10:44:00+03	37200.00
A9B7DF	2017-07-20 12:30:00+03	105000.00
A9B7FE	2017-07-01 21:35:00+03	40000.00
A9B849	2017-07-16 01:14:00+03	7400.00
A9B86C	2017-07-24 19:20:00+03	29600.00
A9B8BD	2017-07-23 18:56:00+03	93900.00
A9B8D3	2017-07-28 14:42:00+03	36200.00
A9B912	2017-08-01 22:46:00+03	68100.00
A9B940	2017-07-06 15:09:00+03	104800.00
A9B951	2017-08-14 00:58:00+03	144400.00
A9B973	2017-07-13 12:45:00+03	23600.00
A9B97B	2017-07-21 19:13:00+03	40400.00
A9BA10	2017-08-14 08:02:00+03	27200.00
A9BAB3	2017-07-29 16:48:00+03	266400.00
A9BAEB	2017-07-12 12:33:00+03	121300.00
A9BB0D	2017-07-09 02:48:00+03	179500.00
A9BB42	2017-07-08 21:58:00+03	28800.00
A9BBF5	2017-07-22 01:15:00+03	89600.00
A9BC20	2017-07-27 08:56:00+03	36400.00
A9BC5C	2017-07-12 18:32:00+03	173500.00
A9BD3F	2017-07-08 08:47:00+03	23200.00
A9BD9F	2017-08-11 23:45:00+03	25100.00
A9BDA6	2017-08-12 01:53:00+03	62600.00
A9BDB9	2017-07-14 02:26:00+03	51600.00
A9BDBC	2017-06-27 19:10:00+03	50000.00
A9BDC2	2017-08-11 23:14:00+03	26500.00
A9BDFE	2017-07-26 18:56:00+03	27800.00
A9BE30	2017-07-14 22:17:00+03	24400.00
A9BEA6	2017-07-10 04:48:00+03	147200.00
A9BEBC	2017-08-12 14:58:00+03	40000.00
A9BEC2	2017-07-24 22:37:00+03	111600.00
A9BEC7	2017-07-02 20:29:00+03	36200.00
A9BF32	2017-07-18 22:36:00+03	32200.00
A9BF8D	2017-07-11 00:53:00+03	66600.00
A9BFA1	2017-07-11 08:58:00+03	42800.00
A9C02E	2017-07-10 06:28:00+03	83200.00
A9C034	2017-07-26 22:20:00+03	375200.00
A9C045	2017-07-30 20:57:00+03	118900.00
A9C0CC	2017-08-10 22:34:00+03	65200.00
A9C12E	2017-07-03 07:03:00+03	50600.00
A9C16E	2017-07-26 02:14:00+03	94000.00
A9C2A3	2017-07-25 22:50:00+03	145400.00
A9C2C1	2017-07-12 05:16:00+03	132800.00
A9C305	2017-07-31 18:43:00+03	94400.00
A9C30D	2017-08-15 08:50:00+03	68800.00
A9C492	2017-08-08 11:30:00+03	13200.00
A9C4D3	2017-07-18 15:09:00+03	55800.00
A9C4E8	2017-08-10 14:55:00+03	85000.00
A9C4E9	2017-08-12 16:32:00+03	89700.00
A9C561	2017-07-25 15:35:00+03	102600.00
A9C571	2017-07-15 03:52:00+03	6000.00
A9C5E7	2017-07-09 05:57:00+03	12400.00
A9C65C	2017-08-11 00:44:00+03	24400.00
A9C67F	2017-07-17 19:20:00+03	75300.00
A9C6B0	2017-08-09 02:36:00+03	24800.00
A9C6F7	2017-08-10 20:36:00+03	28000.00
A9C808	2017-07-26 14:07:00+03	27400.00
A9C80F	2017-07-25 20:15:00+03	70200.00
A9C813	2017-07-26 12:05:00+03	13600.00
A9C828	2017-07-08 21:58:00+03	288600.00
A9C8F8	2017-07-30 06:29:00+03	35700.00
A9C8FA	2017-07-14 22:05:00+03	185600.00
A9C910	2017-07-28 04:16:00+03	6300.00
A9C94E	2017-07-22 14:14:00+03	30000.00
A9C95B	2017-08-15 01:52:00+03	89700.00
A9C970	2017-07-07 05:33:00+03	26800.00
A9C9B6	2017-07-09 06:35:00+03	133700.00
A9CA1C	2017-08-14 01:09:00+03	122500.00
A9CA41	2017-08-11 00:59:00+03	100600.00
A9CA7B	2017-07-16 12:48:00+03	67200.00
A9CA83	2017-08-01 19:55:00+03	31900.00
A9CB47	2017-08-10 16:11:00+03	50200.00
A9CB52	2017-07-08 12:41:00+03	39600.00
A9CCB6	2017-07-23 05:11:00+03	111600.00
A9CCC7	2017-07-03 15:17:00+03	31400.00
A9CD33	2017-08-09 22:44:00+03	38400.00
A9CDA1	2017-07-06 20:37:00+03	38800.00
A9CDBE	2017-07-11 18:42:00+03	49100.00
A9CDEA	2017-08-10 10:02:00+03	38600.00
A9CE01	2017-07-04 15:49:00+03	46400.00
A9CE1E	2017-07-07 05:41:00+03	55800.00
A9CE25	2017-07-08 15:40:00+03	65900.00
A9CE2C	2017-08-10 13:27:00+03	182400.00
A9CE57	2017-08-08 21:41:00+03	38600.00
A9CE92	2017-08-03 23:21:00+03	76800.00
A9CE9C	2017-06-29 18:31:00+03	85000.00
A9CECA	2017-07-28 01:42:00+03	46000.00
A9CEE4	2017-07-19 12:33:00+03	10600.00
A9CF2F	2017-08-15 10:54:00+03	67700.00
A9CF67	2017-07-29 04:45:00+03	39200.00
A9D0B5	2017-07-17 18:14:00+03	184300.00
A9D0C0	2017-07-06 04:35:00+03	40800.00
A9D15B	2017-07-08 19:53:00+03	80900.00
A9D1B3	2017-07-11 12:38:00+03	6700.00
A9D1B6	2017-07-02 01:13:00+03	926700.00
A9D1F0	2017-07-12 19:35:00+03	204200.00
A9D2A9	2017-08-01 11:59:00+03	123000.00
A9D2C8	2017-07-29 23:45:00+03	48400.00
A9D2FC	2017-08-09 21:32:00+03	122300.00
A9D342	2017-08-08 17:17:00+03	22000.00
A9D39C	2017-08-01 15:43:00+03	23200.00
A9D3DF	2017-07-29 10:28:00+03	23200.00
A9D412	2017-08-01 21:02:00+03	42700.00
A9D416	2017-07-21 21:22:00+03	26000.00
A9D4D7	2017-07-30 05:19:00+03	16400.00
A9D505	2017-08-12 11:48:00+03	52700.00
A9D525	2017-08-04 21:59:00+03	36100.00
A9D53E	2017-08-15 13:46:00+03	34000.00
A9D639	2017-07-24 23:37:00+03	42700.00
A9D64F	2017-07-06 21:05:00+03	26700.00
A9D6A4	2017-08-09 16:23:00+03	58400.00
A9D6C4	2017-07-21 22:28:00+03	166100.00
A9D71F	2017-07-10 13:28:00+03	278500.00
A9D771	2017-07-17 23:05:00+03	13600.00
A9D78C	2017-08-09 04:32:00+03	57400.00
A9D7F9	2017-08-01 23:07:00+03	24400.00
A9D82E	2017-08-07 16:57:00+03	68800.00
A9D862	2017-07-31 22:00:00+03	11600.00
A9D8CF	2017-08-10 21:08:00+03	23400.00
A9D902	2017-07-02 11:59:00+03	6000.00
A9D921	2017-08-04 15:12:00+03	72500.00
A9D97C	2017-07-17 11:54:00+03	296100.00
A9D99F	2017-07-12 23:02:00+03	15000.00
A9D9B3	2017-08-03 11:11:00+03	21800.00
A9D9EE	2017-08-06 00:50:00+03	24600.00
A9D9F5	2017-07-29 15:35:00+03	46800.00
A9DA36	2017-07-09 23:55:00+03	47800.00
A9DAF8	2017-07-20 21:26:00+03	7400.00
A9DAFF	2017-08-08 14:07:00+03	30700.00
A9DB14	2017-08-05 21:05:00+03	273500.00
A9DB82	2017-07-27 23:17:00+03	56000.00
A9DBDC	2017-07-31 22:13:00+03	29600.00
A9DC43	2017-07-11 10:32:00+03	48800.00
A9DC5A	2017-07-18 22:25:00+03	20200.00
A9DC92	2017-06-28 20:18:00+03	75300.00
A9DD14	2017-07-31 01:03:00+03	67800.00
A9DDF1	2017-07-16 16:30:00+03	103500.00
A9DE4A	2017-07-01 04:24:00+03	40800.00
A9DEB0	2017-07-05 10:27:00+03	25900.00
A9DED2	2017-07-29 23:44:00+03	8000.00
A9DF38	2017-08-14 22:38:00+03	797100.00
A9DF75	2017-07-12 16:15:00+03	369000.00
A9DFA0	2017-08-07 20:16:00+03	26000.00
A9E013	2017-07-09 03:12:00+03	29600.00
A9E049	2017-07-20 09:24:00+03	73600.00
A9E0BD	2017-08-11 16:55:00+03	25000.00
A9E0CD	2017-08-13 17:10:00+03	177200.00
A9E13D	2017-07-14 08:27:00+03	6300.00
A9E141	2017-07-10 01:33:00+03	26200.00
A9E165	2017-08-13 17:07:00+03	135400.00
A9E182	2017-08-04 15:47:00+03	54400.00
A9E1DE	2017-07-10 05:54:00+03	68800.00
A9E275	2017-08-15 12:32:00+03	15900.00
A9E285	2017-07-02 21:04:00+03	133200.00
A9E2AC	2017-08-02 18:01:00+03	206800.00
A9E2B7	2017-07-08 05:18:00+03	21000.00
A9E2E7	2017-07-01 04:49:00+03	58200.00
A9E30D	2017-06-29 02:29:00+03	36200.00
A9E325	2017-08-11 16:31:00+03	41300.00
A9E32A	2017-08-04 04:09:00+03	39300.00
A9E350	2017-07-25 18:07:00+03	54500.00
A9E519	2017-07-22 16:11:00+03	85000.00
A9E521	2017-08-06 00:35:00+03	93900.00
A9E523	2017-07-23 00:56:00+03	65500.00
A9E5A1	2017-07-09 05:07:00+03	27200.00
A9E5B0	2017-07-16 14:52:00+03	369000.00
A9E5C9	2017-07-25 12:41:00+03	57500.00
A9E603	2017-08-04 22:43:00+03	58600.00
A9E6C6	2017-07-27 15:36:00+03	65900.00
A9E6C7	2017-07-16 11:11:00+03	95000.00
A9E6CF	2017-08-10 10:45:00+03	20400.00
A9E6F5	2017-08-12 21:23:00+03	273000.00
A9E6F8	2017-07-19 03:29:00+03	35200.00
A9E700	2017-07-25 06:04:00+03	42800.00
A9E760	2017-08-14 06:40:00+03	417800.00
A9E766	2017-07-17 18:55:00+03	134400.00
A9E83D	2017-07-09 20:18:00+03	18800.00
A9E851	2017-07-27 18:40:00+03	301800.00
A9E8D0	2017-07-17 02:12:00+03	92000.00
A9E8F5	2017-08-01 21:08:00+03	8400.00
A9E970	2017-07-28 23:15:00+03	95200.00
A9E99F	2017-08-07 11:16:00+03	70800.00
A9E9A5	2017-08-08 17:48:00+03	28000.00
A9E9B9	2017-08-12 20:22:00+03	69200.00
A9E9E8	2017-08-09 06:31:00+03	32200.00
A9EA16	2017-08-05 09:39:00+03	28000.00
A9EA6F	2017-07-25 17:06:00+03	189700.00
A9EC1D	2017-08-15 13:11:00+03	56900.00
A9EC5F	2017-07-20 18:56:00+03	37600.00
A9EC89	2017-07-05 18:53:00+03	173600.00
A9ECAB	2017-07-15 02:10:00+03	70600.00
A9ECB5	2017-08-10 06:44:00+03	38800.00
A9ED12	2017-07-21 08:03:00+03	55800.00
A9ED56	2017-07-09 06:36:00+03	35800.00
A9ED99	2017-07-16 03:40:00+03	138000.00
A9EE26	2017-08-10 02:53:00+03	28000.00
A9EE76	2017-07-13 14:44:00+03	149500.00
A9EEC9	2017-07-16 15:39:00+03	142300.00
A9EF06	2017-07-26 00:18:00+03	88900.00
A9EF32	2017-07-16 14:49:00+03	88600.00
A9EF8A	2017-07-19 11:20:00+03	50800.00
A9F025	2017-07-03 04:59:00+03	92000.00
A9F034	2017-08-15 05:27:00+03	36000.00
A9F0BF	2017-07-18 11:43:00+03	76200.00
A9F12B	2017-07-26 07:07:00+03	46400.00
A9F150	2017-08-02 04:15:00+03	16800.00
A9F185	2017-07-28 08:05:00+03	102100.00
A9F1BA	2017-08-05 01:11:00+03	12400.00
A9F265	2017-07-06 04:45:00+03	46000.00
A9F2FB	2017-07-06 13:18:00+03	7400.00
A9F327	2017-07-12 11:50:00+03	34000.00
A9F32B	2017-06-30 13:11:00+03	58600.00
A9F330	2017-07-18 12:22:00+03	32800.00
A9F341	2017-07-18 00:17:00+03	72500.00
A9F3C5	2017-08-10 00:53:00+03	54800.00
A9F437	2017-07-25 21:10:00+03	182300.00
A9F499	2017-07-28 21:30:00+03	67700.00
A9F4E2	2017-07-18 11:55:00+03	28000.00
A9F54E	2017-07-22 20:32:00+03	397700.00
A9F5C2	2017-07-20 12:23:00+03	30200.00
A9F6E9	2017-07-13 07:39:00+03	27400.00
A9F75C	2017-07-02 16:36:00+03	40600.00
A9F7AA	2017-08-02 01:40:00+03	37100.00
A9F7D3	2017-07-26 10:45:00+03	31400.00
A9F822	2017-07-16 05:59:00+03	185500.00
A9F83B	2017-07-26 01:01:00+03	31600.00
A9F860	2017-07-12 23:10:00+03	80900.00
A9F8B5	2017-07-04 07:33:00+03	16800.00
A9F8D9	2017-08-12 07:29:00+03	44300.00
A9F922	2017-07-15 03:39:00+03	50600.00
A9F9B7	2017-08-11 01:54:00+03	108500.00
A9F9F7	2017-08-09 11:19:00+03	62900.00
A9FA57	2017-06-30 18:01:00+03	24800.00
A9FBEE	2017-07-18 11:29:00+03	116400.00
A9FC10	2017-08-10 02:48:00+03	22000.00
A9FC44	2017-08-10 08:24:00+03	73200.00
A9FCA9	2017-07-04 09:30:00+03	59300.00
A9FCBB	2017-08-14 11:37:00+03	23600.00
A9FCE7	2017-08-01 13:04:00+03	99500.00
A9FD2F	2017-08-01 12:12:00+03	520600.00
A9FDE2	2017-07-30 23:25:00+03	24400.00
A9FE04	2017-08-13 11:45:00+03	246000.00
A9FE96	2017-07-05 14:21:00+03	86800.00
A9FE99	2017-07-11 11:12:00+03	39800.00
A9FE9D	2017-08-02 01:48:00+03	37600.00
A9FE9E	2017-06-27 00:45:00+03	52000.00
A9FEC0	2017-08-12 10:57:00+03	75600.00
A9FEC6	2017-07-21 23:19:00+03	187800.00
A9FEE7	2017-07-26 13:18:00+03	145900.00
A9FEF9	2017-07-23 17:58:00+03	44000.00
A9FF14	2017-07-10 00:01:00+03	166000.00
A9FF36	2017-07-05 00:19:00+03	43600.00
A9FF8F	2017-07-09 03:33:00+03	46400.00
A9FFCD	2017-07-02 06:46:00+03	27900.00
AA0020	2017-07-31 16:41:00+03	56000.00
AA00F6	2017-07-25 10:39:00+03	169900.00
AA011F	2017-07-29 13:01:00+03	23400.00
AA014B	2017-07-27 23:45:00+03	43200.00
AA0152	2017-07-09 16:28:00+03	14800.00
AA0177	2017-08-06 01:45:00+03	213600.00
AA01B6	2017-07-20 01:18:00+03	52000.00
AA01C3	2017-08-13 19:15:00+03	52700.00
AA01C7	2017-07-04 12:04:00+03	46300.00
AA01C8	2017-08-06 21:26:00+03	94800.00
AA01DB	2017-07-16 21:25:00+03	65200.00
AA0200	2017-07-20 00:26:00+03	83000.00
AA0202	2017-07-06 05:21:00+03	13000.00
AA02D8	2017-07-12 15:40:00+03	86300.00
AA02F6	2017-07-08 08:13:00+03	38600.00
AA035B	2017-08-12 06:11:00+03	81600.00
AA038B	2017-07-17 12:50:00+03	262600.00
AA041A	2017-07-17 03:58:00+03	65400.00
AA042C	2017-07-24 06:36:00+03	93700.00
AA0481	2017-06-27 21:26:00+03	37200.00
AA0524	2017-07-15 03:30:00+03	6700.00
AA05B7	2017-08-05 00:31:00+03	26700.00
AA0601	2017-07-09 12:59:00+03	24400.00
AA0605	2017-08-02 03:55:00+03	42800.00
AA0674	2017-08-02 18:33:00+03	131100.00
AA067A	2017-08-01 10:54:00+03	21800.00
AA0693	2017-07-09 11:11:00+03	99200.00
AA06B9	2017-08-15 03:15:00+03	298600.00
AA06D5	2017-07-27 03:45:00+03	140500.00
AA06DD	2017-08-12 03:28:00+03	51900.00
AA06FD	2017-07-20 15:52:00+03	98200.00
AA0700	2017-08-10 04:12:00+03	39300.00
AA0761	2017-08-04 16:48:00+03	38300.00
AA0779	2017-08-15 15:36:00+03	14000.00
AA08B9	2017-07-06 23:04:00+03	55800.00
AA08D8	2017-07-11 10:38:00+03	14800.00
AA08F8	2017-07-24 12:52:00+03	14800.00
AA0903	2017-07-07 10:16:00+03	14000.00
AA0904	2017-08-12 18:16:00+03	19600.00
AA0911	2017-07-30 18:46:00+03	39600.00
AA0939	2017-07-19 00:02:00+03	115700.00
AA0971	2017-07-01 19:23:00+03	139300.00
AA09BF	2017-07-14 15:26:00+03	21000.00
AA0A4F	2017-08-08 12:44:00+03	116000.00
AA0A7C	2017-08-11 14:22:00+03	61800.00
AA0A88	2017-07-14 09:01:00+03	87700.00
AA0AAF	2017-07-23 11:03:00+03	39800.00
AA0AB9	2017-07-11 01:04:00+03	70700.00
AA0ABC	2017-07-06 19:14:00+03	67600.00
AA0B18	2017-07-22 20:24:00+03	14000.00
AA0B20	2017-08-07 11:38:00+03	124200.00
AA0BAC	2017-07-18 01:51:00+03	46200.00
AA0BFD	2017-07-10 12:35:00+03	102000.00
AA0C20	2017-07-12 17:53:00+03	22400.00
AA0C32	2017-07-18 11:48:00+03	67600.00
AA0C43	2017-07-23 18:53:00+03	67400.00
AA0C44	2017-08-04 23:08:00+03	137800.00
AA0C89	2017-07-04 02:00:00+03	79600.00
AA0CBF	2017-07-24 18:25:00+03	99600.00
AA0CCC	2017-08-03 21:59:00+03	58900.00
AA0D4B	2017-08-15 06:19:00+03	13300.00
AA0D79	2017-07-28 22:14:00+03	23200.00
AA0E15	2017-07-08 06:21:00+03	266400.00
AA0E31	2017-07-23 03:54:00+03	109900.00
AA0E7E	2017-08-12 01:42:00+03	41600.00
AA0EA0	2017-08-09 00:17:00+03	76600.00
AA0EBF	2017-07-28 09:20:00+03	13200.00
AA0ED2	2017-07-21 23:37:00+03	270700.00
AA0F2E	2017-07-10 06:36:00+03	119800.00
AA0F4C	2017-07-25 11:48:00+03	68800.00
AA0F63	2017-07-14 23:10:00+03	36200.00
AA0F7D	2017-08-06 23:57:00+03	32800.00
AA0FAC	2017-06-27 20:15:00+03	136400.00
AA0FB8	2017-07-04 03:07:00+03	109800.00
AA0FEE	2017-07-05 03:26:00+03	156000.00
AA104A	2017-07-14 02:04:00+03	292300.00
AA10E2	2017-07-27 12:27:00+03	66900.00
AA1105	2017-08-06 11:51:00+03	29600.00
AA1129	2017-07-25 16:33:00+03	58700.00
AA1145	2017-08-01 20:40:00+03	170200.00
AA114F	2017-07-29 14:23:00+03	86800.00
AA1223	2017-08-01 15:48:00+03	18700.00
AA1280	2017-07-13 12:17:00+03	21400.00
AA1297	2017-08-06 10:35:00+03	248100.00
AA1314	2017-08-07 02:37:00+03	8200.00
AA1386	2017-07-20 13:10:00+03	231300.00
AA13A9	2017-08-04 05:07:00+03	199700.00
AA142E	2017-07-04 11:33:00+03	26800.00
AA1443	2017-07-17 02:46:00+03	101100.00
AA14C9	2017-07-22 21:42:00+03	12400.00
AA150C	2017-07-05 15:24:00+03	138600.00
AA153A	2017-07-02 19:12:00+03	84100.00
AA153F	2017-08-13 08:22:00+03	150600.00
AA1540	2017-06-30 22:33:00+03	81600.00
AA1561	2017-07-06 12:49:00+03	75300.00
AA1569	2017-07-05 01:43:00+03	27200.00
AA1586	2017-07-28 19:45:00+03	26000.00
AA15A2	2017-07-09 04:05:00+03	12400.00
AA15C0	2017-08-09 16:44:00+03	75800.00
AA15CF	2017-07-07 03:55:00+03	85300.00
AA15F2	2017-07-29 03:01:00+03	139400.00
AA1639	2017-07-02 03:47:00+03	81900.00
AA1642	2017-08-04 15:35:00+03	46400.00
AA169E	2017-07-16 08:23:00+03	123000.00
AA16DA	2017-07-14 05:31:00+03	315000.00
AA172C	2017-07-31 14:02:00+03	206700.00
AA1775	2017-07-26 07:58:00+03	38800.00
AA1778	2017-07-27 22:44:00+03	65600.00
AA17A1	2017-07-03 06:41:00+03	11600.00
AA17DA	2017-08-09 03:17:00+03	24300.00
AA1832	2017-07-22 02:53:00+03	147700.00
AA183B	2017-08-07 20:49:00+03	3400.00
AA1843	2017-07-22 12:24:00+03	13700.00
AA186F	2017-07-20 16:05:00+03	13600.00
AA1886	2017-08-03 11:32:00+03	112600.00
AA1887	2017-08-05 20:14:00+03	12600.00
AA1906	2017-07-16 15:04:00+03	57400.00
AA1910	2017-07-05 05:32:00+03	68100.00
AA1916	2017-07-20 05:23:00+03	24400.00
AA196A	2017-07-11 10:06:00+03	53400.00
AA19AF	2017-08-08 14:12:00+03	31200.00
AA1A33	2017-07-15 14:32:00+03	13700.00
AA1B1D	2017-07-09 17:52:00+03	188900.00
AA1B44	2017-07-03 05:22:00+03	32700.00
AA1B45	2017-07-04 04:54:00+03	24800.00
AA1B58	2017-07-13 22:06:00+03	104800.00
AA1B88	2017-08-12 07:00:00+03	8200.00
AA1BA6	2017-06-30 11:02:00+03	46000.00
AA1C1C	2017-07-04 05:06:00+03	111600.00
AA1CDE	2017-07-04 19:13:00+03	119600.00
AA1CFC	2017-07-02 15:16:00+03	35300.00
AA1D41	2017-07-11 16:43:00+03	28000.00
AA1D9D	2017-07-12 11:59:00+03	56200.00
AA1DD2	2017-08-15 03:15:00+03	25600.00
AA1E32	2017-07-09 17:44:00+03	10800.00
AA1E64	2017-08-03 11:54:00+03	455400.00
AA1E88	2017-07-13 19:54:00+03	10800.00
AA1ED3	2017-08-08 06:26:00+03	6000.00
AA1EEC	2017-08-15 07:24:00+03	205000.00
AA1F0E	2017-07-02 18:27:00+03	65900.00
AA1F67	2017-07-12 05:03:00+03	138900.00
AA1F74	2017-08-05 04:35:00+03	46400.00
AA1F75	2017-08-11 12:39:00+03	73100.00
AA1FCC	2017-07-25 11:39:00+03	46200.00
AA2048	2017-08-10 23:05:00+03	28800.00
AA2065	2017-06-29 17:53:00+03	56000.00
AA207C	2017-08-14 12:50:00+03	67200.00
AA20AA	2017-07-15 07:08:00+03	46000.00
AA20AB	2017-08-10 04:05:00+03	194000.00
AA20BA	2017-07-09 05:00:00+03	124300.00
AA20BB	2017-07-31 09:52:00+03	123000.00
AA20E2	2017-08-05 09:24:00+03	52800.00
AA2140	2017-08-09 15:13:00+03	6200.00
AA2157	2017-07-26 22:31:00+03	91000.00
AA218D	2017-07-31 00:30:00+03	111600.00
AA21CB	2017-07-26 08:00:00+03	28000.00
AA21DB	2017-08-09 19:51:00+03	28000.00
AA223C	2017-07-12 14:36:00+03	73500.00
AA22CD	2017-07-04 12:21:00+03	56000.00
AA22D9	2017-07-20 17:50:00+03	38800.00
AA22E4	2017-08-04 17:12:00+03	67700.00
AA22E8	2017-08-15 17:07:00+03	115300.00
AA2325	2017-07-16 09:00:00+03	76100.00
AA2349	2017-07-30 10:47:00+03	58400.00
AA234D	2017-07-18 13:35:00+03	70700.00
AA23AC	2017-07-14 04:34:00+03	46700.00
AA2413	2017-08-08 05:27:00+03	66600.00
AA24A1	2017-07-11 12:45:00+03	21800.00
AA24CB	2017-07-11 17:04:00+03	28800.00
AA24D3	2017-07-05 13:39:00+03	76600.00
AA2513	2017-07-05 06:51:00+03	291200.00
AA2545	2017-07-21 13:24:00+03	128700.00
AA25C0	2017-06-28 11:31:00+03	21200.00
AA25C9	2017-07-02 11:44:00+03	36200.00
AA25DE	2017-07-25 23:31:00+03	52000.00
AA2613	2017-07-30 15:43:00+03	85000.00
AA2616	2017-07-24 06:33:00+03	246000.00
AA2645	2017-07-06 07:42:00+03	75300.00
AA2647	2017-07-21 07:15:00+03	62200.00
AA266B	2017-08-04 01:38:00+03	51300.00
AA26B1	2017-07-13 08:05:00+03	100600.00
AA26D8	2017-08-05 00:21:00+03	99200.00
AA272B	2017-08-06 23:17:00+03	36200.00
AA2732	2017-08-06 17:13:00+03	75600.00
AA2780	2017-08-11 00:04:00+03	46400.00
AA27C2	2017-07-29 01:58:00+03	86600.00
AA27EA	2017-07-13 14:45:00+03	13400.00
AA283E	2017-07-09 11:56:00+03	68800.00
AA2851	2017-08-12 04:58:00+03	62600.00
AA285A	2017-08-02 18:23:00+03	144300.00
AA2864	2017-07-01 04:29:00+03	31100.00
AA2875	2017-07-22 21:08:00+03	75600.00
AA28A7	2017-07-13 20:53:00+03	20400.00
AA2915	2017-07-02 23:35:00+03	91300.00
AA2953	2017-07-08 14:54:00+03	155600.00
AA296B	2017-07-19 02:31:00+03	24400.00
AA2979	2017-07-04 03:43:00+03	92900.00
AA29F4	2017-07-15 08:30:00+03	6600.00
AA2A00	2017-07-16 06:01:00+03	43200.00
AA2A25	2017-08-01 05:10:00+03	142400.00
AA2A28	2017-07-25 13:47:00+03	86400.00
AA2B1A	2017-06-30 11:26:00+03	51200.00
AA2B1B	2017-08-08 21:48:00+03	52800.00
AA2B6A	2017-07-02 16:06:00+03	402400.00
AA2BB1	2017-07-31 14:10:00+03	81500.00
AA2BB6	2017-07-05 03:13:00+03	23200.00
AA2BDB	2017-08-15 04:12:00+03	13400.00
AA2C26	2017-07-16 09:11:00+03	8000.00
AA2C32	2017-08-15 01:33:00+03	136800.00
AA2C5E	2017-08-11 08:06:00+03	42700.00
AA2C6F	2017-07-27 17:56:00+03	132800.00
AA2CBC	2017-07-01 10:26:00+03	204200.00
AA2CBF	2017-08-04 09:40:00+03	238300.00
AA2CC0	2017-07-31 22:08:00+03	75300.00
AA2D1B	2017-07-22 08:38:00+03	110500.00
AA2DB1	2017-08-14 09:31:00+03	181100.00
AA2DB2	2017-07-02 17:53:00+03	101200.00
AA2DFE	2017-08-06 08:31:00+03	59200.00
AA2E0B	2017-08-11 13:55:00+03	7400.00
AA2E0C	2017-08-04 17:46:00+03	53300.00
AA2ECC	2017-08-01 22:19:00+03	23400.00
AA2F08	2017-08-02 17:13:00+03	32700.00
AA3033	2017-06-29 22:21:00+03	56600.00
AA3035	2017-07-22 23:54:00+03	112000.00
AA3047	2017-07-01 05:13:00+03	28000.00
AA3057	2017-08-05 01:25:00+03	13400.00
AA30A0	2017-08-03 13:31:00+03	136800.00
AA310D	2017-07-28 21:31:00+03	53300.00
AA317A	2017-07-05 12:56:00+03	112000.00
AA31BB	2017-07-12 18:07:00+03	58200.00
AA326A	2017-06-27 15:01:00+03	24300.00
AA3278	2017-07-18 13:07:00+03	83700.00
AA3335	2017-08-10 11:37:00+03	174900.00
AA3337	2017-07-13 04:19:00+03	34200.00
AA3346	2017-07-03 06:50:00+03	41400.00
AA3365	2017-07-27 19:53:00+03	56100.00
AA33A7	2017-07-20 21:20:00+03	45200.00
AA33CF	2017-07-13 23:10:00+03	26000.00
AA33D6	2017-07-15 17:09:00+03	94100.00
AA3434	2017-06-29 06:14:00+03	49400.00
AA346B	2017-08-04 00:50:00+03	33600.00
AA348B	2017-07-02 20:01:00+03	13800.00
AA34AA	2017-07-14 02:41:00+03	12600.00
AA34C6	2017-07-15 02:23:00+03	232800.00
AA34F5	2017-07-30 19:19:00+03	131100.00
AA3501	2017-08-12 01:38:00+03	56000.00
AA351D	2017-07-09 09:06:00+03	211100.00
AA3557	2017-07-06 04:58:00+03	6800.00
AA3574	2017-07-21 19:42:00+03	101100.00
AA3590	2017-08-06 21:00:00+03	13600.00
AA35A4	2017-07-08 04:16:00+03	266200.00
AA35CE	2017-08-02 23:15:00+03	19600.00
AA367C	2017-07-20 04:43:00+03	47000.00
AA36B3	2017-06-29 06:19:00+03	94400.00
AA36D7	2017-07-16 07:55:00+03	58000.00
AA36D8	2017-08-14 07:37:00+03	89100.00
AA372A	2017-08-15 09:23:00+03	167900.00
AA3761	2017-07-08 05:57:00+03	48300.00
AA3795	2017-08-05 02:25:00+03	24400.00
AA37B2	2017-07-25 10:20:00+03	67600.00
AA3811	2017-07-28 22:14:00+03	40000.00
AA3846	2017-08-08 00:27:00+03	34000.00
AA385B	2017-07-21 05:57:00+03	123700.00
AA3872	2017-07-04 17:37:00+03	75300.00
AA3878	2017-07-20 09:41:00+03	48500.00
AA38FC	2017-07-10 20:36:00+03	73300.00
AA3939	2017-07-12 06:21:00+03	39800.00
AA39A7	2017-08-07 00:09:00+03	19600.00
AA39F0	2017-08-14 02:15:00+03	38800.00
AA3A4C	2017-07-19 20:41:00+03	38400.00
AA3A5B	2017-07-30 09:36:00+03	140900.00
AA3A63	2017-08-12 07:13:00+03	28000.00
AA3AEF	2017-07-29 07:34:00+03	24400.00
AA3B1D	2017-08-06 13:54:00+03	28000.00
AA3B53	2017-07-07 13:41:00+03	57300.00
AA3B5A	2017-07-18 10:52:00+03	34000.00
AA3BAB	2017-08-08 18:15:00+03	59800.00
AA3BD8	2017-07-09 18:50:00+03	92000.00
AA3C11	2017-07-06 08:40:00+03	117700.00
AA3CAE	2017-08-03 21:31:00+03	112000.00
AA3CAF	2017-06-30 03:55:00+03	170900.00
AA3D0A	2017-07-17 18:28:00+03	26700.00
AA3D0D	2017-07-03 03:31:00+03	26000.00
AA3D2B	2017-07-28 03:54:00+03	36200.00
AA3DB3	2017-08-08 07:24:00+03	80000.00
AA3E82	2017-07-11 10:36:00+03	93900.00
AA3EA0	2017-08-11 01:48:00+03	50600.00
AA3EA4	2017-07-31 05:27:00+03	43000.00
AA3EB6	2017-07-02 09:12:00+03	75600.00
AA3EBB	2017-07-10 06:28:00+03	176500.00
AA3ED2	2017-07-25 06:04:00+03	167400.00
AA3EDD	2017-07-24 07:58:00+03	93400.00
AA3EDF	2017-08-01 05:08:00+03	94800.00
AA3F4A	2017-07-25 00:53:00+03	53600.00
AA3F64	2017-08-06 08:14:00+03	78700.00
AA3F67	2017-07-23 23:17:00+03	98700.00
AA3FB6	2017-07-08 14:14:00+03	55800.00
AA3FBA	2017-07-29 12:12:00+03	35200.00
AA3FCE	2017-07-01 14:33:00+03	48500.00
AA40AD	2017-07-01 09:36:00+03	68400.00
AA4116	2017-07-29 10:11:00+03	114800.00
AA4117	2017-07-13 01:11:00+03	61800.00
AA4118	2017-07-29 13:13:00+03	81600.00
AA4121	2017-08-04 23:27:00+03	7200.00
AA41B2	2017-08-05 04:15:00+03	35300.00
AA41B8	2017-08-07 06:35:00+03	19600.00
AA41CE	2017-07-04 09:21:00+03	123000.00
AA41D7	2017-07-13 05:09:00+03	58900.00
AA424F	2017-08-07 04:35:00+03	428600.00
AA4271	2017-07-25 10:34:00+03	32700.00
AA4289	2017-07-24 20:43:00+03	269200.00
AA42B0	2017-08-04 16:38:00+03	31600.00
AA42BA	2017-08-09 07:03:00+03	265700.00
AA4387	2017-07-20 07:22:00+03	59900.00
AA441E	2017-08-11 13:25:00+03	14400.00
AA442F	2017-08-06 08:23:00+03	61800.00
AA44B5	2017-08-15 13:04:00+03	53700.00
AA4513	2017-08-15 07:40:00+03	42800.00
AA4535	2017-07-01 04:13:00+03	112000.00
AA4561	2017-08-05 05:07:00+03	64800.00
AA458D	2017-08-05 04:19:00+03	36200.00
AA45B5	2017-07-10 18:11:00+03	88900.00
AA461B	2017-07-06 09:23:00+03	80000.00
AA462E	2017-08-11 14:11:00+03	103400.00
AA46C8	2017-07-09 19:29:00+03	35600.00
AA46E5	2017-08-11 23:30:00+03	20000.00
AA46FA	2017-07-15 06:08:00+03	11600.00
AA474E	2017-07-20 09:15:00+03	20200.00
AA4792	2017-08-02 01:51:00+03	75600.00
AA47BB	2017-07-02 11:02:00+03	49600.00
AA483B	2017-07-26 10:01:00+03	123900.00
AA4887	2017-08-13 19:07:00+03	110200.00
AA48B0	2017-07-09 12:53:00+03	311200.00
AA491A	2017-07-21 17:26:00+03	135600.00
AA4923	2017-07-14 09:34:00+03	32800.00
AA494E	2017-07-25 18:03:00+03	123900.00
AA496D	2017-08-01 12:29:00+03	211800.00
AA4A0E	2017-07-24 04:51:00+03	66600.00
AA4A24	2017-07-31 06:27:00+03	33100.00
AA4ACA	2017-07-20 18:17:00+03	67600.00
AA4AE1	2017-07-17 03:02:00+03	13400.00
AA4AF8	2017-07-08 16:25:00+03	75300.00
AA4B13	2017-08-06 23:40:00+03	23400.00
AA4B27	2017-08-05 18:34:00+03	27200.00
AA4B6B	2017-07-05 18:12:00+03	203000.00
AA4BA9	2017-07-01 14:03:00+03	85000.00
AA4BCB	2017-08-03 05:49:00+03	191200.00
AA4BE8	2017-07-08 17:53:00+03	124200.00
AA4C58	2017-07-07 16:00:00+03	50800.00
AA4C8F	2017-07-27 05:09:00+03	36200.00
AA4C90	2017-06-26 15:01:00+03	39600.00
AA4CA7	2017-07-19 19:41:00+03	36200.00
AA4CAD	2017-07-31 07:42:00+03	99200.00
AA4CE7	2017-07-21 12:00:00+03	48400.00
AA4CF0	2017-08-13 08:44:00+03	63800.00
AA4D09	2017-07-22 23:01:00+03	102100.00
AA4D52	2017-07-18 22:43:00+03	378400.00
AA4D5D	2017-07-11 06:25:00+03	61500.00
AA4DAA	2017-08-06 15:28:00+03	6000.00
AA4DC7	2017-08-04 09:51:00+03	100200.00
AA4DE3	2017-06-25 17:07:00+03	77000.00
AA4E31	2017-07-04 10:27:00+03	92900.00
AA4F18	2017-07-09 01:11:00+03	29400.00
AA4F1F	2017-07-08 09:58:00+03	55500.00
AA4F4E	2017-07-01 20:40:00+03	28000.00
AA4F5B	2017-07-11 03:48:00+03	65500.00
AA4FFA	2017-07-18 12:32:00+03	23200.00
AA500E	2017-07-20 06:46:00+03	133800.00
AA5025	2017-07-11 07:41:00+03	114800.00
AA5053	2017-08-13 23:42:00+03	42800.00
AA505F	2017-07-11 22:54:00+03	74300.00
AA5075	2017-07-05 05:14:00+03	92100.00
AA509A	2017-08-03 19:58:00+03	12600.00
AA50D3	2017-07-24 19:45:00+03	57500.00
AA50E1	2017-07-17 00:02:00+03	608400.00
AA512A	2017-08-05 02:11:00+03	31200.00
AA5189	2017-08-12 07:51:00+03	23600.00
AA5208	2017-07-03 20:24:00+03	25400.00
AA52A3	2017-08-02 15:18:00+03	75300.00
AA52F7	2017-07-12 11:26:00+03	28000.00
AA5379	2017-07-15 22:38:00+03	83600.00
AA5388	2017-07-30 12:31:00+03	46500.00
AA539A	2017-07-01 14:53:00+03	43700.00
AA53BC	2017-07-16 03:52:00+03	287700.00
AA53DD	2017-07-06 06:54:00+03	187700.00
AA5409	2017-08-05 03:26:00+03	97900.00
AA542C	2017-07-28 14:45:00+03	68200.00
AA548D	2017-08-06 16:26:00+03	35800.00
AA549E	2017-07-19 01:59:00+03	28000.00
AA54A9	2017-08-12 23:29:00+03	48400.00
AA54D3	2017-08-14 20:15:00+03	135000.00
AA561F	2017-07-31 23:50:00+03	48200.00
AA562B	2017-08-09 04:16:00+03	105000.00
AA564C	2017-07-26 10:23:00+03	86300.00
AA5653	2017-08-10 03:05:00+03	93900.00
AA56EC	2017-07-29 12:29:00+03	81600.00
AA5722	2017-07-05 18:27:00+03	12200.00
AA572E	2017-07-15 09:20:00+03	27900.00
AA5750	2017-07-30 22:39:00+03	55800.00
AA5768	2017-08-08 14:54:00+03	62600.00
AA57AA	2017-07-02 12:59:00+03	38800.00
AA57B7	2017-07-05 12:42:00+03	46000.00
AA57D3	2017-08-14 00:53:00+03	123000.00
AA57DB	2017-07-11 18:34:00+03	394400.00
AA5822	2017-07-23 13:14:00+03	28800.00
AA5829	2017-07-03 13:52:00+03	30400.00
AA58B4	2017-07-24 16:49:00+03	28700.00
AA58CF	2017-07-22 00:47:00+03	14400.00
AA58FB	2017-07-10 21:34:00+03	57600.00
AA5969	2017-08-06 13:22:00+03	23400.00
AA598B	2017-07-24 01:51:00+03	97900.00
AA5A1D	2017-07-21 07:01:00+03	62600.00
AA5A36	2017-08-06 11:19:00+03	155600.00
AA5A49	2017-08-14 16:51:00+03	95600.00
AA5A95	2017-07-13 20:33:00+03	15000.00
AA5B09	2017-07-03 23:25:00+03	47000.00
AA5BFB	2017-08-04 19:34:00+03	13600.00
AA5CA9	2017-07-03 13:50:00+03	187800.00
AA5CE9	2017-07-01 14:24:00+03	25600.00
AA5D7B	2017-07-16 19:29:00+03	11600.00
AA5DA4	2017-07-05 09:07:00+03	55800.00
AA5DBA	2017-08-06 16:28:00+03	193900.00
AA5E08	2017-07-20 17:30:00+03	75300.00
AA5E28	2017-07-30 06:48:00+03	29100.00
AA5E37	2017-07-04 01:32:00+03	134400.00
AA5E63	2017-07-14 06:59:00+03	26700.00
AA5E8E	2017-07-20 17:34:00+03	31400.00
AA5F38	2017-07-12 07:17:00+03	44500.00
AA5FB2	2017-08-09 02:39:00+03	105900.00
AA5FC4	2017-08-06 00:05:00+03	153600.00
AA604A	2017-08-12 23:25:00+03	60700.00
AA6053	2017-08-12 08:37:00+03	46800.00
AA6086	2017-07-26 18:25:00+03	397100.00
AA609C	2017-07-01 07:58:00+03	26800.00
AA60D6	2017-07-10 11:25:00+03	28000.00
AA61CB	2017-07-04 19:40:00+03	28700.00
AA61CC	2017-07-04 08:31:00+03	54500.00
AA6247	2017-07-24 13:39:00+03	99200.00
AA6289	2017-07-16 11:19:00+03	13600.00
AA62AD	2017-08-08 21:17:00+03	63500.00
AA62DD	2017-07-17 18:10:00+03	93700.00
AA62E9	2017-07-23 12:55:00+03	14800.00
AA6301	2017-07-22 05:14:00+03	270800.00
AA635F	2017-07-23 07:36:00+03	65300.00
AA63B7	2017-07-09 02:45:00+03	17800.00
AA63B9	2017-07-26 06:33:00+03	40000.00
AA63DB	2017-08-07 10:20:00+03	22000.00
AA63E1	2017-08-14 03:06:00+03	40800.00
AA63EC	2017-08-14 04:33:00+03	49500.00
AA647D	2017-08-12 19:21:00+03	40400.00
AA64E3	2017-07-01 05:14:00+03	77600.00
AA6569	2017-07-30 22:09:00+03	173200.00
AA65CB	2017-07-16 15:22:00+03	252200.00
AA65E1	2017-07-17 06:51:00+03	49600.00
AA6623	2017-08-02 11:14:00+03	28000.00
AA6625	2017-08-14 17:24:00+03	10900.00
AA6659	2017-07-30 20:46:00+03	203400.00
AA6688	2017-08-14 07:39:00+03	40400.00
AA66C9	2017-08-13 18:07:00+03	149000.00
AA66E9	2017-07-18 07:20:00+03	28000.00
AA6703	2017-08-14 17:41:00+03	49400.00
AA671F	2017-08-06 23:46:00+03	72600.00
AA673A	2017-08-11 16:29:00+03	123900.00
AA6774	2017-07-27 05:46:00+03	35200.00
AA67D7	2017-07-07 06:50:00+03	29400.00
AA682A	2017-07-27 20:15:00+03	8200.00
AA6876	2017-07-11 12:52:00+03	123000.00
AA68A6	2017-08-13 23:23:00+03	48400.00
AA68BD	2017-08-03 10:53:00+03	43600.00
AA68D9	2017-07-21 11:32:00+03	172100.00
AA690D	2017-07-31 23:37:00+03	70500.00
AA6960	2017-07-08 23:53:00+03	37900.00
AA6978	2017-07-25 04:14:00+03	65500.00
AA698E	2017-08-05 21:41:00+03	34800.00
AA69E9	2017-08-14 18:21:00+03	75600.00
AA6A43	2017-07-27 12:13:00+03	34000.00
AA6AC9	2017-07-13 08:43:00+03	40800.00
AA6B17	2017-08-11 23:44:00+03	147000.00
AA6B24	2017-07-28 00:37:00+03	553200.00
AA6B31	2017-08-11 23:28:00+03	103500.00
AA6B35	2017-07-24 01:14:00+03	38800.00
AA6B36	2017-07-06 08:09:00+03	92800.00
AA6B6A	2017-08-03 06:10:00+03	52900.00
AA6B9E	2017-07-25 02:31:00+03	16400.00
AA6BB6	2017-08-01 16:40:00+03	16400.00
AA6BBB	2017-07-17 04:22:00+03	115900.00
AA6C00	2017-07-29 01:09:00+03	35800.00
AA6C0A	2017-06-29 15:36:00+03	99300.00
AA6C24	2017-07-27 16:23:00+03	8000.00
AA6C39	2017-07-25 04:25:00+03	18300.00
AA6C43	2017-08-13 10:06:00+03	161800.00
AA6C74	2017-07-18 11:25:00+03	86600.00
AA6C8F	2017-07-17 12:04:00+03	37200.00
AA6CAD	2017-08-02 15:46:00+03	25600.00
AA6D52	2017-07-16 01:46:00+03	43600.00
AA6E16	2017-07-19 07:57:00+03	52800.00
AA6E1E	2017-07-27 19:46:00+03	58000.00
AA6E2A	2017-08-10 11:52:00+03	75300.00
AA6E3C	2017-07-25 21:49:00+03	51600.00
AA6EBA	2017-08-11 17:44:00+03	75700.00
AA6EBB	2017-07-06 07:30:00+03	60700.00
AA6ED4	2017-08-14 11:04:00+03	62900.00
AA6F12	2017-07-24 23:38:00+03	61900.00
AA6F34	2017-08-09 02:51:00+03	56100.00
AA6F48	2017-07-08 11:10:00+03	43800.00
AA6F85	2017-07-05 08:12:00+03	23200.00
AA6F8E	2017-07-13 15:25:00+03	113800.00
AA6FBD	2017-07-15 23:47:00+03	14800.00
AA7025	2017-07-13 11:08:00+03	46400.00
AA7044	2017-07-20 07:02:00+03	205400.00
AA7065	2017-08-07 03:50:00+03	81500.00
AA708A	2017-07-06 21:37:00+03	20800.00
AA70B6	2017-08-08 19:45:00+03	46300.00
AA7135	2017-08-06 13:11:00+03	17000.00
AA716B	2017-08-06 09:58:00+03	33200.00
AA71D4	2017-07-11 13:59:00+03	28000.00
AA7239	2017-07-14 21:30:00+03	8200.00
AA7295	2017-07-14 13:32:00+03	36400.00
AA72CB	2017-07-10 01:01:00+03	47700.00
AA72D3	2017-08-11 19:51:00+03	92100.00
AA7304	2017-07-31 10:44:00+03	48100.00
AA7374	2017-07-07 13:39:00+03	142300.00
AA739E	2017-07-29 18:16:00+03	74000.00
AA74C2	2017-07-25 12:39:00+03	50800.00
AA74E0	2017-08-08 15:17:00+03	35600.00
AA750B	2017-07-23 20:44:00+03	93700.00
AA7580	2017-07-14 19:59:00+03	19600.00
AA7588	2017-07-10 08:29:00+03	65600.00
AA75C9	2017-08-03 10:32:00+03	45400.00
AA760A	2017-07-08 10:52:00+03	16800.00
AA763C	2017-08-03 05:32:00+03	28800.00
AA7729	2017-07-16 09:08:00+03	31000.00
AA7742	2017-07-28 21:40:00+03	54600.00
AA774B	2017-08-06 11:45:00+03	12600.00
AA778E	2017-08-14 21:18:00+03	153200.00
AA77C8	2017-08-12 04:32:00+03	14100.00
AA77F4	2017-07-13 12:57:00+03	32500.00
AA7887	2017-08-06 23:08:00+03	38200.00
AA78D0	2017-07-05 06:54:00+03	20500.00
AA7901	2017-07-21 14:23:00+03	31800.00
AA7A08	2017-07-29 12:36:00+03	44000.00
AA7A20	2017-07-25 14:25:00+03	56000.00
AA7A25	2017-07-31 18:36:00+03	40800.00
AA7A33	2017-07-12 07:28:00+03	24600.00
AA7A4F	2017-07-12 14:24:00+03	128800.00
AA7A6F	2017-07-09 21:47:00+03	189800.00
AA7A98	2017-07-08 07:14:00+03	67800.00
AA7A9F	2017-08-14 22:36:00+03	265600.00
AA7AA5	2017-07-19 21:25:00+03	52000.00
AA7ABF	2017-07-30 15:28:00+03	26200.00
AA7B32	2017-07-03 03:44:00+03	67600.00
AA7B8B	2017-06-28 11:58:00+03	14400.00
AA7B95	2017-08-02 01:55:00+03	272900.00
AA7B96	2017-08-14 03:56:00+03	47100.00
AA7BAD	2017-07-17 22:34:00+03	23400.00
AA7C08	2017-08-12 11:33:00+03	37200.00
AA7C3E	2017-07-13 19:56:00+03	46200.00
AA7CCB	2017-08-01 13:35:00+03	103100.00
AA7D23	2017-07-18 22:39:00+03	54800.00
AA7D71	2017-07-09 11:38:00+03	111400.00
AA7D86	2017-08-06 10:40:00+03	28000.00
AA7E37	2017-07-12 02:46:00+03	59100.00
AA7E82	2017-08-10 09:02:00+03	24700.00
AA7EC6	2017-07-19 21:48:00+03	40600.00
AA7EDC	2017-08-09 07:54:00+03	37900.00
AA7EEE	2017-07-29 10:54:00+03	123000.00
AA7F64	2017-07-19 16:16:00+03	50600.00
AA7F7A	2017-08-06 15:52:00+03	88800.00
AA7F95	2017-07-17 20:02:00+03	47500.00
AA7F9D	2017-07-20 09:44:00+03	23600.00
AA7FA0	2017-08-02 04:13:00+03	205700.00
AA7FCA	2017-07-03 11:29:00+03	55800.00
AA7FD1	2017-07-02 13:05:00+03	53100.00
AA7FF1	2017-07-27 09:45:00+03	52600.00
AA8036	2017-08-10 15:06:00+03	38300.00
AA8042	2017-07-22 11:46:00+03	210200.00
AA80AD	2017-08-02 23:38:00+03	167400.00
AA8118	2017-07-01 23:29:00+03	45000.00
AA8177	2017-07-29 12:49:00+03	23200.00
AA8178	2017-07-14 18:01:00+03	54000.00
AA8199	2017-08-01 11:31:00+03	47400.00
AA81A7	2017-07-20 14:32:00+03	65200.00
AA822A	2017-07-09 01:39:00+03	124000.00
AA8241	2017-08-13 06:54:00+03	46000.00
AA8246	2017-08-09 15:28:00+03	141100.00
AA8269	2017-08-01 17:14:00+03	14000.00
AA8272	2017-07-11 14:17:00+03	89700.00
AA82C3	2017-08-12 14:27:00+03	50600.00
AA8345	2017-08-12 00:16:00+03	247700.00
AA8402	2017-08-12 17:57:00+03	48800.00
AA8471	2017-07-13 02:45:00+03	270400.00
AA8481	2017-07-21 02:08:00+03	30000.00
AA84C9	2017-08-11 06:06:00+03	43900.00
AA852C	2017-07-03 05:35:00+03	45200.00
AA8549	2017-06-30 11:36:00+03	50600.00
AA855B	2017-07-23 04:40:00+03	52700.00
AA8573	2017-07-09 17:10:00+03	26000.00
AA8581	2017-07-23 22:33:00+03	50900.00
AA859F	2017-08-14 05:08:00+03	42600.00
AA8633	2017-07-15 22:08:00+03	40000.00
AA8656	2017-08-12 22:41:00+03	46800.00
AA867D	2017-08-08 12:01:00+03	10800.00
AA8698	2017-07-08 04:10:00+03	405200.00
AA86DB	2017-08-02 16:13:00+03	95600.00
AA86F3	2017-08-12 12:55:00+03	26000.00
AA86F4	2017-08-08 08:37:00+03	265800.00
AA8701	2017-08-04 14:21:00+03	57400.00
AA87A5	2017-07-05 12:04:00+03	128600.00
AA87DE	2017-07-13 17:39:00+03	143000.00
AA87EF	2017-07-22 20:23:00+03	23400.00
AA87F5	2017-08-08 05:13:00+03	21400.00
AA8803	2017-07-21 14:46:00+03	45100.00
AA888A	2017-07-31 08:19:00+03	35700.00
AA88B0	2017-07-21 19:34:00+03	170500.00
AA8913	2017-07-23 11:34:00+03	11600.00
AA8924	2017-08-07 09:21:00+03	27200.00
AA897A	2017-08-12 21:54:00+03	6900.00
AA899E	2017-08-09 19:04:00+03	51600.00
AA89E7	2017-08-10 21:52:00+03	28800.00
AA8A3A	2017-07-07 03:18:00+03	75200.00
AA8A74	2017-07-18 14:28:00+03	56000.00
AA8ACE	2017-08-10 09:36:00+03	77900.00
AA8B82	2017-08-07 07:34:00+03	14000.00
AA8B9B	2017-07-07 22:38:00+03	9200.00
AA8C41	2017-07-06 12:47:00+03	6700.00
AA8C60	2017-07-11 09:08:00+03	98200.00
AA8C9B	2017-08-05 23:16:00+03	28000.00
AA8CC6	2017-07-23 00:15:00+03	38500.00
AA8D16	2017-07-04 17:50:00+03	50800.00
AA8D2C	2017-07-21 21:30:00+03	6300.00
AA8D5F	2017-08-12 06:37:00+03	168000.00
AA8D67	2017-07-19 18:28:00+03	98800.00
AA8D6D	2017-07-29 06:37:00+03	62600.00
AA8D84	2017-07-04 10:12:00+03	34000.00
AA8D94	2017-07-29 23:02:00+03	132800.00
AA8DC8	2017-07-25 02:54:00+03	231900.00
AA8E37	2017-07-28 01:11:00+03	396100.00
AA8E39	2017-08-12 23:35:00+03	69000.00
AA8ED6	2017-06-29 18:01:00+03	23400.00
AA8ED8	2017-07-20 06:17:00+03	50000.00
AA8EF4	2017-07-08 15:52:00+03	50800.00
AA8F01	2017-08-10 06:35:00+03	22200.00
AA8F5F	2017-07-29 04:23:00+03	21700.00
AA8FA4	2017-07-23 10:30:00+03	75600.00
AA90DA	2017-08-09 13:24:00+03	55800.00
AA9133	2017-07-11 13:34:00+03	72400.00
AA9141	2017-08-03 18:51:00+03	31000.00
AA915D	2017-08-13 01:36:00+03	57500.00
AA9162	2017-08-01 08:27:00+03	28800.00
AA9177	2017-08-14 21:00:00+03	102100.00
AA9193	2017-08-12 02:45:00+03	24400.00
AA91A1	2017-07-18 06:14:00+03	12400.00
AA91A9	2017-07-28 07:06:00+03	47100.00
AA9272	2017-07-03 19:55:00+03	36900.00
AA9286	2017-07-14 15:18:00+03	122000.00
AA928C	2017-07-07 19:58:00+03	26000.00
AA929A	2017-07-28 04:45:00+03	12400.00
AA92C3	2017-08-13 19:50:00+03	52700.00
AA938E	2017-08-13 00:13:00+03	132800.00
AA93AC	2017-07-06 00:52:00+03	46400.00
AA93B1	2017-08-05 20:23:00+03	112600.00
AA93B4	2017-07-07 18:11:00+03	55800.00
AA93D1	2017-07-22 15:57:00+03	133200.00
AA942C	2017-07-20 12:22:00+03	38800.00
AA9432	2017-06-30 10:20:00+03	56000.00
AA9481	2017-08-15 14:32:00+03	56900.00
AA94A7	2017-07-10 01:18:00+03	13200.00
AA94AA	2017-08-11 23:50:00+03	189800.00
AA94BD	2017-07-15 15:45:00+03	128800.00
AA94E1	2017-08-04 11:17:00+03	50400.00
AA94F1	2017-08-10 17:06:00+03	57300.00
AA94FD	2017-07-28 04:13:00+03	52900.00
AA951A	2017-07-17 07:20:00+03	31600.00
AA957F	2017-07-29 16:49:00+03	10700.00
AA95BA	2017-08-01 22:22:00+03	481500.00
AA9691	2017-08-13 00:12:00+03	92400.00
AA96D7	2017-08-01 02:21:00+03	20200.00
AA9732	2017-07-08 22:58:00+03	64700.00
AA976D	2017-08-06 18:10:00+03	51800.00
AA97C5	2017-07-18 11:16:00+03	25800.00
AA980C	2017-07-19 15:01:00+03	55800.00
AA982A	2017-07-12 23:05:00+03	10600.00
AA9831	2017-07-13 22:17:00+03	88500.00
AA986E	2017-08-01 00:58:00+03	123000.00
AA98EC	2017-08-10 11:07:00+03	26000.00
AA9921	2017-07-14 08:52:00+03	56000.00
AA992A	2017-07-18 08:54:00+03	51800.00
AA9936	2017-08-12 01:53:00+03	104500.00
AA9944	2017-07-08 18:48:00+03	249100.00
AA99CD	2017-08-05 03:16:00+03	194200.00
AA99CE	2017-08-12 02:31:00+03	92000.00
AA9A0C	2017-08-06 03:42:00+03	23200.00
AA9A15	2017-07-11 02:42:00+03	50800.00
AA9A91	2017-07-09 23:31:00+03	59100.00
AA9AE1	2017-07-16 17:52:00+03	12400.00
AA9B8E	2017-08-04 00:56:00+03	88600.00
AA9BC8	2017-07-18 17:46:00+03	49100.00
AA9BE6	2017-07-14 18:53:00+03	11600.00
AA9BFB	2017-08-04 07:14:00+03	87100.00
AA9BFF	2017-08-05 12:54:00+03	81600.00
AA9C26	2017-07-09 23:30:00+03	393800.00
AA9C3B	2017-07-18 05:21:00+03	29600.00
AA9C77	2017-08-11 16:17:00+03	89800.00
AA9C81	2017-07-11 01:50:00+03	112600.00
AA9CCC	2017-08-14 10:43:00+03	43200.00
AA9CF3	2017-07-12 02:34:00+03	28000.00
AA9D0C	2017-08-15 17:51:00+03	22000.00
AA9D0F	2017-07-30 07:28:00+03	14400.00
AA9D2B	2017-07-21 07:25:00+03	13400.00
AA9D9A	2017-08-05 19:51:00+03	201200.00
AA9DD4	2017-08-09 07:51:00+03	223200.00
AA9E6A	2017-06-29 14:35:00+03	51200.00
AA9E83	2017-07-06 21:40:00+03	65100.00
AA9E90	2017-07-14 08:34:00+03	28000.00
AA9E98	2017-07-06 09:38:00+03	20400.00
AA9ED2	2017-07-31 07:39:00+03	23200.00
AAA033	2017-08-15 10:00:00+03	54300.00
AAA09C	2017-07-04 20:31:00+03	132800.00
AAA0D5	2017-08-01 09:09:00+03	8200.00
AAA203	2017-08-02 12:28:00+03	359500.00
AAA236	2017-08-09 20:50:00+03	65900.00
AAA256	2017-07-26 02:50:00+03	135200.00
AAA28E	2017-07-31 17:14:00+03	22100.00
AAA2A8	2017-07-09 08:41:00+03	92900.00
AAA2ED	2017-08-02 02:31:00+03	51900.00
AAA35B	2017-07-14 04:53:00+03	59000.00
AAA3CE	2017-07-24 22:54:00+03	73200.00
AAA3EB	2017-07-08 01:16:00+03	20400.00
AAA409	2017-08-02 09:59:00+03	92900.00
AAA41D	2017-07-11 21:30:00+03	96800.00
AAA45C	2017-08-01 02:25:00+03	80300.00
AAA46B	2017-07-16 20:25:00+03	37900.00
AAA488	2017-07-30 03:26:00+03	258400.00
AAA49C	2017-08-11 05:32:00+03	14000.00
AAA4BA	2017-07-17 20:24:00+03	105600.00
AAA4C1	2017-08-06 14:45:00+03	46400.00
AAA4C3	2017-08-03 00:30:00+03	23400.00
AAA50E	2017-08-14 06:03:00+03	47200.00
AAA52A	2017-08-10 11:15:00+03	113300.00
AAA54C	2017-07-24 10:30:00+03	83200.00
AAA58C	2017-07-07 10:10:00+03	56000.00
AAA5E7	2017-08-12 22:37:00+03	136500.00
AAA5F4	2017-07-21 12:14:00+03	43700.00
AAA61A	2017-07-07 03:16:00+03	46300.00
AAA629	2017-07-04 08:58:00+03	71000.00
AAA64E	2017-07-16 07:42:00+03	14000.00
AAA65C	2017-08-13 16:10:00+03	82200.00
AAA668	2017-07-03 06:41:00+03	185600.00
AAA6CE	2017-08-09 01:51:00+03	17200.00
AAA73C	2017-07-25 04:14:00+03	31600.00
AAA748	2017-07-11 14:41:00+03	131100.00
AAA781	2017-07-01 03:51:00+03	14400.00
AAA7DF	2017-07-15 21:36:00+03	17800.00
AAA7E7	2017-07-11 16:13:00+03	96800.00
AAA834	2017-07-07 12:06:00+03	141300.00
AAA93D	2017-07-16 13:17:00+03	112000.00
AAA950	2017-07-17 16:39:00+03	26700.00
AAA979	2017-07-14 23:51:00+03	31100.00
AAA9F6	2017-08-11 21:38:00+03	28800.00
AAAA19	2017-08-02 07:30:00+03	248300.00
AAAA34	2017-07-06 15:49:00+03	35600.00
AAAA5D	2017-07-13 12:30:00+03	105200.00
AAAA6B	2017-08-11 15:49:00+03	23400.00
AAAAAF	2017-08-10 11:48:00+03	31600.00
AAAAB4	2017-07-01 01:16:00+03	75900.00
AAAAF8	2017-07-25 18:54:00+03	46000.00
AAAB13	2017-07-06 15:20:00+03	14100.00
AAAB7C	2017-07-09 07:51:00+03	14400.00
AAAB88	2017-07-02 21:16:00+03	17600.00
AAABE5	2017-07-06 20:00:00+03	47100.00
AAABF4	2017-08-05 10:28:00+03	74300.00
AAAC22	2017-07-17 14:31:00+03	59800.00
AAAC2D	2017-08-09 07:30:00+03	95600.00
AAAC42	2017-07-26 11:13:00+03	173200.00
AAAC56	2017-07-17 09:25:00+03	79600.00
AAAD46	2017-07-17 09:37:00+03	42700.00
AAAD5B	2017-07-31 17:50:00+03	266200.00
AAAD97	2017-07-14 22:50:00+03	21800.00
AAADD7	2017-08-11 17:30:00+03	12600.00
AAADF4	2017-08-01 08:14:00+03	24300.00
AAAE00	2017-07-06 07:59:00+03	50200.00
AAAE2E	2017-07-16 13:47:00+03	37900.00
AAAE44	2017-07-27 10:43:00+03	74900.00
AAAED8	2017-08-03 01:18:00+03	52000.00
AAAF25	2017-08-11 05:18:00+03	32800.00
AAAF55	2017-07-05 07:10:00+03	20200.00
AAAF58	2017-08-13 14:58:00+03	92400.00
AAAF5C	2017-07-31 22:27:00+03	24200.00
AAAF88	2017-06-28 11:07:00+03	6700.00
AAAF8A	2017-08-09 23:20:00+03	28800.00
AAAFD6	2017-07-09 22:46:00+03	30400.00
AAB021	2017-07-07 05:22:00+03	209500.00
AAB032	2017-08-10 01:29:00+03	33300.00
AAB04A	2017-08-14 04:23:00+03	199600.00
AAB070	2017-07-22 12:49:00+03	85000.00
AAB079	2017-07-23 17:28:00+03	72400.00
AAB07A	2017-07-18 11:26:00+03	114600.00
AAB08B	2017-07-16 12:49:00+03	111600.00
AAB0CA	2017-08-05 08:23:00+03	55800.00
AAB0DA	2017-08-10 10:07:00+03	55800.00
AAB0DE	2017-08-01 03:51:00+03	23200.00
AAB10D	2017-07-05 22:45:00+03	8000.00
AAB164	2017-07-16 22:29:00+03	38600.00
AAB21C	2017-08-02 03:54:00+03	102600.00
AAB228	2017-08-13 03:12:00+03	12000.00
AAB242	2017-06-30 07:11:00+03	36000.00
AAB250	2017-07-23 15:21:00+03	369000.00
AAB29B	2017-07-19 20:13:00+03	22400.00
AAB328	2017-08-09 11:20:00+03	199300.00
AAB338	2017-08-09 02:07:00+03	22000.00
AAB33C	2017-07-03 10:48:00+03	56000.00
AAB358	2017-08-15 09:53:00+03	47200.00
AAB3E3	2017-08-09 16:50:00+03	80000.00
AAB469	2017-07-07 11:41:00+03	75600.00
AAB473	2017-08-15 07:41:00+03	66600.00
AAB508	2017-07-29 05:07:00+03	113200.00
AAB510	2017-06-28 04:58:00+03	76800.00
AAB61B	2017-08-10 17:43:00+03	95100.00
AAB63A	2017-08-15 11:59:00+03	39000.00
AAB6A9	2017-07-19 14:42:00+03	129700.00
AAB6B7	2017-07-07 18:25:00+03	287100.00
AAB6FD	2017-08-11 21:54:00+03	223200.00
AAB733	2017-07-18 03:26:00+03	103600.00
AAB785	2017-07-08 07:49:00+03	50000.00
AAB79F	2017-07-04 15:16:00+03	88500.00
AAB820	2017-07-19 23:55:00+03	67100.00
AAB87A	2017-08-08 01:43:00+03	68100.00
AAB8E8	2017-07-02 23:34:00+03	6000.00
AAB911	2017-08-11 16:04:00+03	170000.00
AAB939	2017-07-18 16:00:00+03	68800.00
AAB96A	2017-06-27 00:19:00+03	77900.00
AAB9D4	2017-07-11 06:56:00+03	135600.00
AABA70	2017-08-05 02:38:00+03	40000.00
AABAB5	2017-08-09 23:29:00+03	127300.00
AABAD8	2017-07-22 05:28:00+03	16800.00
AABAF1	2017-07-12 15:47:00+03	23100.00
AABB2A	2017-07-15 20:44:00+03	46400.00
AABB2B	2017-07-29 10:31:00+03	166000.00
AABBB3	2017-08-09 02:27:00+03	66600.00
AABBCB	2017-08-12 15:35:00+03	212500.00
AABC07	2017-07-31 08:06:00+03	23400.00
AABC30	2017-08-04 19:59:00+03	136800.00
AABC40	2017-08-10 04:53:00+03	48800.00
AABCBD	2017-07-29 19:22:00+03	80900.00
AABCC6	2017-07-08 20:19:00+03	45500.00
AABD56	2017-08-04 10:35:00+03	116400.00
AABD5F	2017-07-09 08:56:00+03	30400.00
AABD6B	2017-07-23 11:58:00+03	51900.00
AABD76	2017-07-22 19:27:00+03	58400.00
AABDA5	2017-07-23 05:17:00+03	50000.00
AABDA9	2017-07-09 18:51:00+03	130100.00
AABDBE	2017-07-22 00:57:00+03	146800.00
AABDC7	2017-07-13 09:23:00+03	6000.00
AABE09	2017-07-12 17:12:00+03	177600.00
AABE47	2017-07-13 08:47:00+03	48800.00
AABF2C	2017-08-13 22:46:00+03	62600.00
AABF37	2017-07-17 11:26:00+03	57400.00
AABF76	2017-06-28 11:02:00+03	65900.00
AABFB4	2017-08-10 04:28:00+03	18600.00
AABFDA	2017-07-06 11:53:00+03	36800.00
AAC000	2017-07-29 09:36:00+03	29600.00
AAC0FE	2017-07-05 12:00:00+03	23600.00
AAC14C	2017-07-16 22:59:00+03	116800.00
AAC160	2017-07-20 10:05:00+03	111600.00
AAC180	2017-08-04 18:17:00+03	32400.00
AAC1A4	2017-06-30 18:41:00+03	111700.00
AAC215	2017-07-11 12:29:00+03	20200.00
AAC29D	2017-08-06 06:02:00+03	684600.00
AAC2A1	2017-07-03 18:58:00+03	213600.00
AAC30D	2017-08-01 03:15:00+03	11600.00
AAC358	2017-07-28 09:26:00+03	257500.00
AAC370	2017-07-16 20:47:00+03	40800.00
AAC3C2	2017-07-17 19:46:00+03	31600.00
AAC3FA	2017-08-04 02:47:00+03	12000.00
AAC414	2017-07-17 12:41:00+03	99800.00
AAC450	2017-08-04 11:05:00+03	57500.00
AAC4D6	2017-07-17 18:53:00+03	55800.00
AAC4DC	2017-07-28 13:57:00+03	73600.00
AAC4F7	2017-07-31 01:26:00+03	106400.00
AAC509	2017-07-12 20:35:00+03	28000.00
AAC50B	2017-07-26 14:21:00+03	129700.00
AAC53E	2017-07-25 13:41:00+03	90700.00
AAC55E	2017-08-05 22:48:00+03	38800.00
AAC616	2017-08-13 10:08:00+03	95900.00
AAC63F	2017-07-05 04:48:00+03	111600.00
AAC73B	2017-07-25 01:04:00+03	28800.00
AAC74A	2017-07-10 05:00:00+03	39300.00
AAC758	2017-07-30 05:23:00+03	126000.00
AAC7A0	2017-07-02 09:40:00+03	16400.00
AAC851	2017-07-08 03:42:00+03	44600.00
AAC856	2017-07-24 12:18:00+03	26600.00
AAC874	2017-07-29 11:10:00+03	123000.00
AAC8CB	2017-07-15 09:34:00+03	40000.00
AAC933	2017-07-09 21:18:00+03	112000.00
AAC936	2017-08-07 18:47:00+03	84400.00
AAC983	2017-08-14 11:05:00+03	13400.00
AACA26	2017-07-27 04:12:00+03	83900.00
AACA43	2017-07-06 00:12:00+03	189200.00
AACA91	2017-08-11 18:52:00+03	155600.00
AACAEA	2017-07-28 04:40:00+03	169600.00
AACB7C	2017-07-20 15:17:00+03	111600.00
AACB9D	2017-08-14 01:36:00+03	51600.00
AACC4F	2017-08-11 19:11:00+03	23200.00
AACC66	2017-07-04 06:00:00+03	16400.00
AACC76	2017-08-10 15:49:00+03	26000.00
AACC78	2017-07-11 20:00:00+03	23600.00
AACCA0	2017-08-14 10:44:00+03	119600.00
AACCB1	2017-08-11 08:08:00+03	37800.00
AACDF2	2017-08-13 11:25:00+03	123000.00
AACE27	2017-07-05 13:34:00+03	243700.00
AACE4B	2017-07-04 03:13:00+03	56000.00
AACECE	2017-08-03 01:36:00+03	32700.00
AACF48	2017-07-16 12:43:00+03	46000.00
AACF53	2017-08-10 19:25:00+03	46400.00
AACFA7	2017-07-28 19:08:00+03	79600.00
AAD059	2017-07-09 03:04:00+03	135400.00
AAD073	2017-07-27 13:42:00+03	56000.00
AAD0CB	2017-08-13 10:16:00+03	49200.00
AAD124	2017-08-15 02:52:00+03	28000.00
AAD1AE	2017-07-15 03:25:00+03	76800.00
AAD1DB	2017-06-30 03:03:00+03	265800.00
AAD25D	2017-08-09 22:39:00+03	44600.00
AAD284	2017-07-11 13:04:00+03	12600.00
AAD288	2017-07-11 03:18:00+03	162500.00
AAD2E5	2017-07-31 08:14:00+03	36200.00
AAD304	2017-07-17 14:02:00+03	23600.00
AAD323	2017-07-31 01:34:00+03	169900.00
AAD352	2017-07-03 23:02:00+03	198500.00
AAD364	2017-07-24 12:09:00+03	142400.00
AAD386	2017-07-30 03:45:00+03	26000.00
AAD3E2	2017-08-15 07:22:00+03	43200.00
AAD403	2017-07-28 18:00:00+03	46400.00
AAD458	2017-07-27 08:22:00+03	22400.00
AAD45C	2017-07-25 11:54:00+03	71600.00
AAD467	2017-08-06 03:15:00+03	19800.00
AAD49C	2017-07-13 04:09:00+03	46400.00
AAD4C8	2017-08-05 22:58:00+03	90400.00
AAD52D	2017-08-12 11:25:00+03	38400.00
AAD532	2017-07-16 03:28:00+03	123700.00
AAD533	2017-08-11 15:38:00+03	90400.00
AAD587	2017-07-07 02:44:00+03	48400.00
AAD5BC	2017-07-14 09:11:00+03	59800.00
AAD60F	2017-07-27 10:57:00+03	294800.00
AAD6E5	2017-07-18 23:41:00+03	32400.00
AAD70F	2017-08-10 03:45:00+03	38700.00
AAD769	2017-08-15 15:15:00+03	6000.00
AAD789	2017-08-12 16:03:00+03	28000.00
AAD7B4	2017-07-28 23:58:00+03	78300.00
AAD81D	2017-07-14 18:42:00+03	30200.00
AAD869	2017-07-08 05:11:00+03	78200.00
AAD8E7	2017-08-10 05:16:00+03	16400.00
AADA9D	2017-08-14 06:54:00+03	47400.00
AADBCF	2017-08-01 18:53:00+03	286600.00
AADC0D	2017-07-29 01:59:00+03	10800.00
AADC3A	2017-08-06 23:49:00+03	103600.00
AADC83	2017-06-25 23:27:00+03	124200.00
AADC8D	2017-08-02 23:27:00+03	132800.00
AADD08	2017-07-31 23:55:00+03	92000.00
AADD28	2017-07-31 18:11:00+03	38800.00
AADD46	2017-08-07 14:23:00+03	27200.00
AADD5F	2017-08-13 08:58:00+03	28800.00
AADD9A	2017-07-21 00:25:00+03	66800.00
AADDB3	2017-08-11 18:25:00+03	12200.00
AADDEB	2017-08-11 05:55:00+03	23900.00
AADE15	2017-07-24 15:44:00+03	36200.00
AADE51	2017-08-10 19:24:00+03	36200.00
AADEC2	2017-07-12 01:33:00+03	14400.00
AADEE5	2017-07-16 19:00:00+03	48800.00
AADEF4	2017-07-31 03:50:00+03	46300.00
AADF19	2017-07-11 00:12:00+03	265700.00
AADF6D	2017-08-13 13:36:00+03	54800.00
AADFA8	2017-08-11 22:13:00+03	62500.00
AADFE9	2017-07-12 08:15:00+03	14800.00
AADFF7	2017-08-09 08:18:00+03	28800.00
AAE019	2017-08-01 18:29:00+03	108500.00
AAE06A	2017-07-30 23:54:00+03	70800.00
AAE078	2017-07-30 06:56:00+03	83100.00
AAE07A	2017-07-08 03:25:00+03	16400.00
AAE087	2017-07-29 09:53:00+03	60300.00
AAE117	2017-07-19 10:52:00+03	59800.00
AAE193	2017-08-08 07:15:00+03	24400.00
AAE1C1	2017-07-07 03:11:00+03	75600.00
AAE1F0	2017-07-29 14:31:00+03	67600.00
AAE205	2017-08-14 16:21:00+03	49600.00
AAE20D	2017-07-26 03:40:00+03	93900.00
AAE2A7	2017-07-12 22:06:00+03	30300.00
AAE2CB	2017-07-09 02:49:00+03	15800.00
AAE2D5	2017-08-07 11:25:00+03	32800.00
AAE2DB	2017-08-04 19:41:00+03	99400.00
AAE32E	2017-08-09 12:46:00+03	46800.00
AAE32F	2017-08-08 10:48:00+03	52900.00
AAE339	2017-08-14 19:09:00+03	14400.00
AAE344	2017-07-15 13:22:00+03	76800.00
AAE3A5	2017-06-30 07:01:00+03	46200.00
AAE3AB	2017-08-02 07:32:00+03	23400.00
AAE3CE	2017-07-28 09:19:00+03	124300.00
AAE3E3	2017-07-19 00:37:00+03	66600.00
AAE427	2017-07-10 04:59:00+03	50000.00
AAE44E	2017-08-04 05:52:00+03	82900.00
AAE462	2017-07-23 01:54:00+03	23200.00
AAE4A7	2017-08-15 16:31:00+03	50200.00
AAE4DD	2017-07-04 17:24:00+03	90800.00
AAE4FD	2017-07-13 22:30:00+03	49200.00
AAE50E	2017-08-10 19:58:00+03	46000.00
AAE516	2017-07-22 22:42:00+03	47000.00
AAE549	2017-08-05 09:07:00+03	71600.00
AAE561	2017-08-07 03:45:00+03	93400.00
AAE56C	2017-07-22 13:52:00+03	105800.00
AAE579	2017-07-20 00:56:00+03	111600.00
AAE5EB	2017-08-03 12:33:00+03	281500.00
AAE60C	2017-08-15 16:00:00+03	102100.00
AAE643	2017-07-28 16:44:00+03	25900.00
AAE6E3	2017-06-29 18:34:00+03	38200.00
AAE771	2017-08-04 07:06:00+03	178800.00
AAE7A0	2017-07-22 00:27:00+03	20600.00
AAE83A	2017-07-20 04:22:00+03	55800.00
AAE844	2017-07-15 16:50:00+03	144300.00
AAE874	2017-08-10 04:18:00+03	7400.00
AAE8DD	2017-07-07 06:49:00+03	31400.00
AAE8E2	2017-08-05 11:22:00+03	126900.00
AAE8E4	2017-07-23 21:45:00+03	23200.00
AAE92F	2017-08-12 08:30:00+03	39500.00
AAE93F	2017-07-29 13:23:00+03	98600.00
AAE97E	2017-08-03 14:14:00+03	131100.00
AAE9D5	2017-07-17 12:03:00+03	49600.00
AAEA35	2017-08-01 18:01:00+03	22000.00
AAEA3A	2017-08-08 07:06:00+03	84000.00
AAEA73	2017-08-09 14:58:00+03	40000.00
AAEA85	2017-07-21 11:50:00+03	59100.00
AAEAA9	2017-08-13 20:57:00+03	92200.00
AAEAAF	2017-07-27 15:20:00+03	145300.00
AAEAE4	2017-08-11 23:53:00+03	139300.00
AAEB31	2017-08-03 15:49:00+03	386200.00
AAEBCF	2017-07-19 06:13:00+03	67200.00
AAEBFE	2017-08-14 01:56:00+03	40800.00
AAEC50	2017-08-06 22:13:00+03	77900.00
AAEC7F	2017-07-22 01:31:00+03	18800.00
AAEC97	2017-08-03 13:40:00+03	56000.00
AAECE6	2017-08-12 11:08:00+03	258000.00
AAECF8	2017-07-14 08:18:00+03	12400.00
AAED0E	2017-07-11 06:07:00+03	28000.00
AAED5A	2017-07-01 06:54:00+03	85700.00
AAED79	2017-07-06 21:05:00+03	56000.00
AAEDC2	2017-07-29 18:39:00+03	86600.00
AAEDC4	2017-07-05 15:27:00+03	270000.00
AAEDE8	2017-07-06 00:17:00+03	317200.00
AAEE6A	2017-08-15 06:49:00+03	27200.00
AAEF1C	2017-07-19 06:20:00+03	139100.00
AAEFEE	2017-07-16 10:18:00+03	66600.00
AAF038	2017-08-08 04:35:00+03	260900.00
AAF04F	2017-08-11 21:48:00+03	34000.00
AAF053	2017-07-03 21:11:00+03	70700.00
AAF0CB	2017-07-28 11:28:00+03	84100.00
AAF119	2017-07-26 00:27:00+03	146400.00
AAF1F4	2017-08-04 02:13:00+03	36000.00
AAF231	2017-07-08 19:25:00+03	54600.00
AAF2D4	2017-07-12 21:18:00+03	13400.00
AAF3B7	2017-07-03 20:21:00+03	73600.00
AAF3CE	2017-07-06 14:28:00+03	43200.00
AAF3F2	2017-07-19 20:11:00+03	28000.00
AAF4F5	2017-07-17 21:17:00+03	69600.00
AAF5BE	2017-07-13 22:38:00+03	270800.00
AAF636	2017-08-07 14:13:00+03	62700.00
AAF655	2017-08-13 22:12:00+03	15100.00
AAF678	2017-07-27 22:27:00+03	70100.00
AAF6AF	2017-08-11 03:12:00+03	92300.00
AAF6CF	2017-07-18 12:06:00+03	43200.00
AAF783	2017-07-18 16:12:00+03	55800.00
AAF820	2017-07-21 01:49:00+03	143000.00
AAF883	2017-08-13 22:45:00+03	26000.00
AAF8A9	2017-08-10 02:44:00+03	238700.00
AAF8B0	2017-07-20 21:51:00+03	58500.00
AAF8EE	2017-07-21 07:20:00+03	133100.00
AAF957	2017-08-11 17:28:00+03	164000.00
AAF99D	2017-08-09 21:39:00+03	45200.00
AAF9D1	2017-07-11 19:38:00+03	75300.00
AAF9E9	2017-07-10 19:38:00+03	43600.00
AAFA14	2017-07-04 17:21:00+03	135200.00
AAFA35	2017-08-07 11:41:00+03	103500.00
AAFA99	2017-07-22 12:47:00+03	27300.00
AAFAA2	2017-07-02 09:00:00+03	55800.00
AAFABA	2017-07-11 16:48:00+03	69700.00
AAFAE5	2017-07-06 01:48:00+03	75800.00
AAFBBD	2017-08-13 17:47:00+03	28800.00
AAFBE0	2017-07-16 22:37:00+03	29600.00
AAFBF1	2017-07-06 14:35:00+03	34000.00
AAFC3C	2017-07-16 14:15:00+03	231400.00
AAFC70	2017-08-09 10:00:00+03	97900.00
AAFCB8	2017-07-04 14:43:00+03	80700.00
AAFD89	2017-08-05 14:19:00+03	39500.00
AAFDC3	2017-07-17 13:59:00+03	52900.00
AAFDE6	2017-07-14 18:46:00+03	105800.00
AAFDEA	2017-07-11 10:50:00+03	99300.00
AAFE4F	2017-07-28 22:21:00+03	40800.00
AB004A	2017-07-27 17:22:00+03	58400.00
AB00A8	2017-08-04 23:36:00+03	44800.00
AB00FA	2017-07-08 15:46:00+03	175300.00
AB0133	2017-07-23 10:54:00+03	30800.00
AB0191	2017-08-10 07:48:00+03	31800.00
AB01D1	2017-08-09 20:12:00+03	8600.00
AB0280	2017-07-06 21:02:00+03	113000.00
AB02C7	2017-08-11 07:45:00+03	133100.00
AB0363	2017-07-15 00:04:00+03	90700.00
AB0372	2017-06-30 15:59:00+03	6600.00
AB038D	2017-07-14 15:02:00+03	30000.00
AB03DA	2017-07-15 20:13:00+03	56000.00
AB0444	2017-07-14 00:17:00+03	31600.00
AB0481	2017-07-15 21:12:00+03	369000.00
AB0546	2017-08-06 10:39:00+03	48100.00
AB0582	2017-07-27 03:51:00+03	58200.00
AB05F4	2017-08-10 09:50:00+03	246000.00
AB080E	2017-08-04 04:11:00+03	133200.00
AB0832	2017-08-13 13:47:00+03	16400.00
AB083E	2017-08-11 09:33:00+03	53300.00
AB08F8	2017-07-08 06:40:00+03	28000.00
AB092C	2017-07-04 21:17:00+03	16400.00
AB0A60	2017-08-11 05:39:00+03	97900.00
AB0A81	2017-08-01 11:59:00+03	103700.00
AB0AA4	2017-07-02 09:08:00+03	98400.00
AB0ACB	2017-07-19 13:52:00+03	88500.00
AB0AE9	2017-07-14 08:54:00+03	33100.00
AB0B3B	2017-07-13 09:25:00+03	28000.00
AB0BB1	2017-07-03 13:54:00+03	77600.00
AB0BBF	2017-07-07 09:56:00+03	60200.00
AB0BCC	2017-07-13 14:34:00+03	96400.00
AB0C26	2017-07-17 20:37:00+03	71700.00
AB0C51	2017-08-07 02:49:00+03	271200.00
AB0C65	2017-08-14 00:26:00+03	25200.00
AB0C85	2017-07-05 11:17:00+03	100600.00
AB0CCF	2017-07-16 16:20:00+03	108300.00
AB0CF0	2017-07-21 15:39:00+03	38800.00
AB0CFE	2017-08-14 06:36:00+03	40800.00
AB0D00	2017-07-12 18:44:00+03	6700.00
AB0D99	2017-07-18 07:05:00+03	91600.00
AB0DCA	2017-07-20 13:52:00+03	23600.00
AB0E5A	2017-08-06 11:36:00+03	32800.00
AB0E89	2017-07-28 02:27:00+03	55800.00
AB0EC3	2017-08-12 12:29:00+03	62000.00
AB0ED1	2017-07-31 14:54:00+03	122600.00
AB0EF0	2017-08-14 09:46:00+03	58900.00
AB0F34	2017-07-31 21:33:00+03	54000.00
AB0F57	2017-07-28 14:12:00+03	32700.00
AB0F77	2017-08-02 11:37:00+03	24500.00
AB0F84	2017-08-14 02:10:00+03	131100.00
AB0FFE	2017-07-07 01:48:00+03	31600.00
AB1019	2017-07-15 22:34:00+03	88400.00
AB1042	2017-07-19 08:51:00+03	28000.00
AB106F	2017-07-07 13:17:00+03	31200.00
AB1080	2017-07-06 08:53:00+03	23200.00
AB1097	2017-07-12 03:14:00+03	40000.00
AB109C	2017-07-11 09:05:00+03	94700.00
AB10A2	2017-08-11 11:38:00+03	72200.00
AB115C	2017-07-06 08:45:00+03	283100.00
AB11A5	2017-08-13 01:38:00+03	36100.00
AB11C7	2017-08-10 23:49:00+03	209100.00
AB11FD	2017-08-02 08:29:00+03	249200.00
AB1251	2017-07-25 23:24:00+03	31600.00
AB12EF	2017-07-09 15:34:00+03	66800.00
AB1301	2017-07-29 04:00:00+03	57600.00
AB1318	2017-07-31 04:55:00+03	65500.00
AB1341	2017-07-29 00:49:00+03	34000.00
AB138B	2017-08-05 19:45:00+03	55000.00
AB13FF	2017-07-16 11:52:00+03	258400.00
AB1406	2017-07-21 21:17:00+03	76900.00
AB145D	2017-08-11 09:12:00+03	6000.00
AB1485	2017-08-05 13:49:00+03	36200.00
AB148F	2017-07-26 11:16:00+03	26800.00
AB14A5	2017-07-04 00:20:00+03	177600.00
AB14CC	2017-07-20 13:44:00+03	260900.00
AB153B	2017-08-03 22:16:00+03	26800.00
AB1565	2017-07-27 07:37:00+03	36800.00
AB15BF	2017-07-06 04:28:00+03	58600.00
AB15D0	2017-07-28 22:39:00+03	34200.00
AB1631	2017-07-21 14:58:00+03	19600.00
AB169E	2017-07-14 08:18:00+03	111600.00
AB16A8	2017-08-14 23:38:00+03	22300.00
AB16DE	2017-08-07 00:57:00+03	6700.00
AB16F1	2017-07-25 16:33:00+03	169900.00
AB1759	2017-07-03 04:56:00+03	78300.00
AB176D	2017-07-26 20:44:00+03	13600.00
AB1779	2017-08-01 11:31:00+03	98200.00
AB1781	2017-08-07 21:45:00+03	19600.00
AB180B	2017-08-04 02:03:00+03	99200.00
AB1829	2017-07-31 05:33:00+03	21000.00
AB18D5	2017-07-23 18:28:00+03	130900.00
AB196D	2017-07-26 21:05:00+03	54200.00
AB199F	2017-07-23 05:12:00+03	13400.00
AB19B2	2017-07-04 06:08:00+03	11300.00
AB19BD	2017-08-14 21:08:00+03	38200.00
AB19D0	2017-07-09 22:56:00+03	18900.00
AB1A16	2017-07-17 06:26:00+03	56900.00
AB1A55	2017-07-30 21:37:00+03	43600.00
AB1A56	2017-07-23 12:00:00+03	23200.00
AB1A7B	2017-07-08 16:25:00+03	46400.00
AB1A95	2017-08-10 18:41:00+03	22600.00
AB1AD1	2017-08-03 07:12:00+03	51200.00
AB1AFC	2017-08-08 11:02:00+03	187600.00
AB1B05	2017-07-30 06:48:00+03	211000.00
AB1B28	2017-08-03 20:29:00+03	114200.00
AB1B3C	2017-07-22 17:02:00+03	20000.00
AB1B63	2017-07-20 09:52:00+03	6300.00
AB1BB0	2017-08-03 09:25:00+03	49600.00
AB1BF7	2017-07-17 09:09:00+03	148200.00
AB1C0A	2017-07-07 21:46:00+03	61900.00
AB1C49	2017-07-06 09:12:00+03	289300.00
AB1CA0	2017-07-20 13:34:00+03	56000.00
AB1D20	2017-07-07 16:57:00+03	14400.00
AB1D49	2017-07-03 09:43:00+03	25400.00
AB1D58	2017-07-06 20:15:00+03	38600.00
AB1DC8	2017-07-19 07:07:00+03	40600.00
AB1E65	2017-08-12 12:54:00+03	100600.00
AB1ECD	2017-07-10 01:14:00+03	123000.00
AB1EDB	2017-07-25 16:18:00+03	155600.00
AB1F25	2017-06-29 08:37:00+03	24400.00
AB1FD0	2017-07-13 12:34:00+03	56000.00
AB1FF9	2017-07-16 21:40:00+03	52400.00
AB20AA	2017-08-05 11:37:00+03	21600.00
AB20C0	2017-07-11 20:51:00+03	19600.00
AB20EE	2017-08-11 07:53:00+03	47400.00
AB2108	2017-08-15 02:48:00+03	46300.00
AB213C	2017-07-23 13:44:00+03	59000.00
AB2161	2017-07-23 18:25:00+03	78200.00
AB219E	2017-07-07 19:20:00+03	56600.00
AB223E	2017-07-19 06:14:00+03	170000.00
AB22AA	2017-07-16 03:07:00+03	39800.00
AB22CC	2017-07-15 19:52:00+03	14000.00
AB22F2	2017-07-04 11:59:00+03	22000.00
AB22F8	2017-08-08 01:28:00+03	92900.00
AB2366	2017-08-12 10:12:00+03	46900.00
AB236A	2017-07-05 18:53:00+03	74300.00
AB236B	2017-08-15 07:33:00+03	36600.00
AB240C	2017-07-07 10:10:00+03	48800.00
AB2438	2017-08-04 08:58:00+03	28000.00
AB2448	2017-07-22 03:28:00+03	39200.00
AB249F	2017-08-03 12:53:00+03	67600.00
AB24FB	2017-08-05 02:59:00+03	18700.00
AB2529	2017-07-04 10:51:00+03	6000.00
AB2583	2017-08-01 13:53:00+03	55600.00
AB259A	2017-07-08 09:16:00+03	56600.00
AB25C2	2017-07-06 20:10:00+03	58600.00
AB2626	2017-06-30 17:51:00+03	73000.00
AB2651	2017-08-14 11:17:00+03	90000.00
AB26F7	2017-07-28 23:30:00+03	92400.00
AB270F	2017-08-01 16:19:00+03	28800.00
AB2797	2017-07-08 10:54:00+03	93200.00
AB27F7	2017-07-24 15:51:00+03	43400.00
AB2805	2017-07-30 04:48:00+03	153300.00
AB28A7	2017-08-12 10:05:00+03	124600.00
AB28B6	2017-07-17 09:14:00+03	122700.00
AB2961	2017-06-29 20:56:00+03	56000.00
AB2968	2017-07-26 17:43:00+03	131100.00
AB298C	2017-08-03 00:56:00+03	49100.00
AB298F	2017-07-28 10:41:00+03	52300.00
AB299F	2017-07-21 03:54:00+03	28000.00
AB2A92	2017-07-19 08:11:00+03	55600.00
AB2AB2	2017-07-11 10:01:00+03	30600.00
AB2B17	2017-07-30 19:17:00+03	57800.00
AB2B25	2017-07-02 22:39:00+03	75300.00
AB2B54	2017-07-27 17:51:00+03	56000.00
AB2BA4	2017-07-24 21:02:00+03	20800.00
AB2BC2	2017-07-04 05:28:00+03	68800.00
AB2C17	2017-08-07 18:55:00+03	13200.00
AB2C25	2017-08-14 13:00:00+03	20200.00
AB2C35	2017-07-17 19:28:00+03	12400.00
AB2C87	2017-07-01 18:36:00+03	24800.00
AB2CBC	2017-08-07 11:08:00+03	84100.00
AB2D0C	2017-07-10 03:18:00+03	85700.00
AB2D2B	2017-07-20 08:54:00+03	64700.00
AB2DDF	2017-07-16 08:52:00+03	103200.00
AB2E53	2017-08-11 10:02:00+03	26700.00
AB2E5D	2017-08-10 04:56:00+03	22000.00
AB2E7B	2017-07-16 05:57:00+03	76600.00
AB2E9B	2017-07-29 21:39:00+03	182400.00
AB2EE5	2017-08-07 08:06:00+03	20200.00
AB2F2F	2017-07-27 22:57:00+03	65900.00
AB2F5F	2017-08-04 17:33:00+03	102100.00
AB2F93	2017-07-08 06:16:00+03	48800.00
AB2F94	2017-07-03 21:18:00+03	195800.00
AB2F99	2017-08-10 15:11:00+03	35600.00
AB2FA8	2017-08-11 17:07:00+03	65500.00
AB2FFF	2017-08-07 06:44:00+03	83700.00
AB3020	2017-08-14 13:25:00+03	84100.00
AB3023	2017-06-29 06:47:00+03	55600.00
AB3028	2017-07-19 21:13:00+03	125600.00
AB304B	2017-07-03 01:34:00+03	44300.00
AB3072	2017-08-13 19:55:00+03	74100.00
AB30A1	2017-07-15 19:20:00+03	266200.00
AB320F	2017-07-22 00:10:00+03	11600.00
AB324A	2017-06-29 16:30:00+03	36200.00
AB324F	2017-07-14 15:33:00+03	25000.00
AB32F0	2017-07-16 07:55:00+03	198400.00
AB32F9	2017-07-18 20:35:00+03	67000.00
AB3375	2017-07-25 18:51:00+03	66400.00
AB33AC	2017-07-21 22:10:00+03	81800.00
AB33CC	2017-07-24 15:45:00+03	84500.00
AB3422	2017-08-06 20:44:00+03	52800.00
AB34A4	2017-07-17 21:48:00+03	95200.00
AB3515	2017-07-28 04:44:00+03	100600.00
AB3559	2017-07-02 07:17:00+03	26600.00
AB356A	2017-07-22 15:08:00+03	28000.00
AB3571	2017-07-13 03:03:00+03	30000.00
AB3582	2017-08-07 11:49:00+03	53500.00
AB359B	2017-08-08 21:04:00+03	175300.00
AB35DB	2017-08-05 09:02:00+03	398500.00
AB361B	2017-07-30 13:03:00+03	14700.00
AB364E	2017-07-09 17:33:00+03	104200.00
AB3656	2017-08-10 17:06:00+03	19600.00
AB36AC	2017-07-16 23:18:00+03	37000.00
AB36B7	2017-07-03 23:35:00+03	31400.00
AB36BD	2017-08-04 12:17:00+03	26000.00
AB36C9	2017-08-06 20:28:00+03	394000.00
AB36F6	2017-07-06 05:32:00+03	67200.00
AB3716	2017-07-31 03:01:00+03	18000.00
AB3730	2017-08-03 16:57:00+03	14400.00
AB3755	2017-07-17 20:05:00+03	68100.00
AB3843	2017-07-04 03:59:00+03	69100.00
AB3847	2017-08-10 13:58:00+03	26000.00
AB3864	2017-07-17 03:32:00+03	46400.00
AB386F	2017-07-28 14:06:00+03	67700.00
AB39AD	2017-08-11 16:50:00+03	54000.00
AB3A8E	2017-07-07 03:05:00+03	102100.00
AB3A8F	2017-07-31 18:59:00+03	81300.00
AB3B28	2017-07-26 10:27:00+03	26700.00
AB3B2B	2017-07-29 23:07:00+03	103100.00
AB3B46	2017-07-02 04:25:00+03	139300.00
AB3BAC	2017-07-30 11:13:00+03	66600.00
AB3BD3	2017-07-28 13:55:00+03	46200.00
AB3BD7	2017-07-09 04:37:00+03	78900.00
AB3C1D	2017-07-02 14:35:00+03	57800.00
AB3D7B	2017-07-30 15:10:00+03	36200.00
AB3E09	2017-07-13 09:57:00+03	24000.00
AB3E4D	2017-07-29 06:08:00+03	109300.00
AB3E70	2017-07-29 18:23:00+03	36000.00
AB3E7D	2017-07-14 13:37:00+03	46900.00
AB3EFF	2017-07-30 21:06:00+03	71100.00
AB3F62	2017-08-02 02:06:00+03	27800.00
AB3F88	2017-07-29 23:35:00+03	25700.00
AB3FA9	2017-07-19 17:33:00+03	30400.00
AB3FB7	2017-08-06 15:25:00+03	39200.00
AB3FDF	2017-07-08 20:22:00+03	369000.00
AB4053	2017-07-09 18:04:00+03	34000.00
AB40D2	2017-08-13 11:26:00+03	516000.00
AB40F9	2017-08-07 16:52:00+03	19600.00
AB413E	2017-07-18 07:28:00+03	75300.00
AB416B	2017-08-04 05:35:00+03	63300.00
AB4170	2017-07-02 23:50:00+03	193700.00
AB41C1	2017-07-11 05:57:00+03	70600.00
AB421F	2017-07-27 17:53:00+03	28800.00
AB426B	2017-07-20 08:44:00+03	4100.00
AB42CA	2017-07-18 01:22:00+03	136800.00
AB42E9	2017-07-14 03:27:00+03	123000.00
AB42EC	2017-07-27 02:45:00+03	53600.00
AB4396	2017-07-08 06:29:00+03	135600.00
AB43E4	2017-08-11 23:40:00+03	94000.00
AB441B	2017-07-03 13:35:00+03	85600.00
AB443B	2017-07-26 21:09:00+03	55800.00
AB4471	2017-07-07 01:48:00+03	257500.00
AB44A2	2017-08-08 09:31:00+03	19600.00
AB44FF	2017-08-11 08:57:00+03	62700.00
AB4511	2017-07-24 10:49:00+03	30700.00
AB4526	2017-07-27 08:24:00+03	135000.00
AB4537	2017-07-26 05:18:00+03	178300.00
AB4556	2017-07-27 04:57:00+03	40000.00
AB45C5	2017-07-06 05:26:00+03	133200.00
AB4625	2017-06-30 07:10:00+03	57700.00
AB4638	2017-08-14 22:46:00+03	46400.00
AB4685	2017-08-05 12:26:00+03	65500.00
AB478E	2017-08-05 01:47:00+03	56600.00
AB4793	2017-08-12 17:38:00+03	495400.00
AB47A4	2017-08-09 15:36:00+03	38600.00
AB47AD	2017-07-01 21:53:00+03	54300.00
AB4836	2017-07-13 01:24:00+03	16800.00
AB483C	2017-08-10 07:56:00+03	111600.00
AB488A	2017-07-24 10:51:00+03	47800.00
AB48F2	2017-07-28 16:59:00+03	38400.00
AB48F7	2017-07-16 23:32:00+03	81300.00
AB4924	2017-07-24 12:20:00+03	265800.00
AB49D0	2017-07-06 20:44:00+03	38800.00
AB4A0A	2017-07-21 23:05:00+03	42000.00
AB4A53	2017-08-04 17:17:00+03	46400.00
AB4A88	2017-07-12 14:43:00+03	78500.00
AB4A8C	2017-07-02 00:28:00+03	118100.00
AB4A99	2017-07-20 09:37:00+03	55500.00
AB4B15	2017-07-15 20:38:00+03	163600.00
AB4B4F	2017-07-13 05:51:00+03	31400.00
AB4B8A	2017-08-04 07:27:00+03	52000.00
AB4C40	2017-08-08 07:56:00+03	65600.00
AB4C5A	2017-08-13 19:55:00+03	111700.00
AB4C98	2017-07-31 18:20:00+03	131100.00
AB4D15	2017-07-18 12:03:00+03	136200.00
AB4D7E	2017-07-05 00:46:00+03	22000.00
AB4DB9	2017-08-07 19:40:00+03	31200.00
AB4E22	2017-06-30 20:32:00+03	40800.00
AB4E24	2017-07-20 22:40:00+03	44300.00
AB4E34	2017-08-13 08:28:00+03	115500.00
AB4ED5	2017-07-15 04:41:00+03	38600.00
AB4EEA	2017-08-09 09:21:00+03	22100.00
AB4F7A	2017-08-15 08:42:00+03	8200.00
AB4FA3	2017-07-27 13:23:00+03	73400.00
AB5011	2017-07-27 05:55:00+03	104200.00
AB5017	2017-07-12 20:30:00+03	198400.00
AB5050	2017-07-20 00:16:00+03	13600.00
AB505D	2017-08-15 13:09:00+03	26700.00
AB5076	2017-07-03 02:16:00+03	173400.00
AB50C1	2017-07-21 01:21:00+03	133100.00
AB5139	2017-07-27 05:47:00+03	65000.00
AB518A	2017-07-15 23:37:00+03	271100.00
AB519C	2017-08-10 22:31:00+03	224000.00
AB51AC	2017-07-01 15:53:00+03	31400.00
AB51CB	2017-08-08 03:10:00+03	100600.00
AB5251	2017-07-06 16:00:00+03	73600.00
AB527F	2017-07-26 21:14:00+03	273000.00
AB52D1	2017-07-12 16:09:00+03	70600.00
AB52E3	2017-07-25 13:15:00+03	102300.00
AB52FD	2017-07-18 23:32:00+03	54100.00
AB5308	2017-07-11 04:08:00+03	23100.00
AB5371	2017-08-13 07:09:00+03	156300.00
AB5412	2017-07-06 09:45:00+03	29400.00
AB542D	2017-08-02 22:36:00+03	90800.00
AB5447	2017-07-22 15:13:00+03	73500.00
AB544F	2017-06-29 04:41:00+03	25000.00
AB5457	2017-07-04 00:23:00+03	70700.00
AB5482	2017-08-12 06:42:00+03	68900.00
AB54BF	2017-07-30 08:18:00+03	31900.00
AB5526	2017-07-10 11:42:00+03	53400.00
AB554A	2017-08-15 02:31:00+03	43200.00
AB55CB	2017-08-15 04:33:00+03	46400.00
AB55F5	2017-06-29 18:24:00+03	133100.00
AB56AC	2017-08-04 03:25:00+03	37100.00
AB56F9	2017-08-02 04:07:00+03	54500.00
AB5710	2017-07-13 17:21:00+03	94300.00
AB571E	2017-06-28 10:54:00+03	23400.00
AB5729	2017-08-09 06:11:00+03	553200.00
AB5774	2017-08-10 02:05:00+03	13200.00
AB5786	2017-07-29 10:33:00+03	27200.00
AB57AF	2017-08-08 14:04:00+03	57600.00
AB57C9	2017-07-03 12:38:00+03	6800.00
AB57DD	2017-07-28 01:18:00+03	113800.00
AB57EA	2017-06-28 04:12:00+03	67000.00
AB57FB	2017-08-09 16:18:00+03	39500.00
AB581F	2017-07-15 21:11:00+03	260300.00
AB587A	2017-07-27 06:04:00+03	32800.00
AB588F	2017-07-13 20:40:00+03	60400.00
AB58A6	2017-08-12 19:13:00+03	20800.00
AB598F	2017-07-29 10:30:00+03	38600.00
AB59B2	2017-07-06 13:25:00+03	118000.00
AB59FC	2017-08-07 23:39:00+03	102600.00
AB5A0E	2017-07-14 12:28:00+03	188000.00
AB5A10	2017-07-13 06:26:00+03	249000.00
AB5A69	2017-06-28 03:46:00+03	47600.00
AB5A8B	2017-07-08 07:53:00+03	47500.00
AB5AB0	2017-07-22 21:25:00+03	229300.00
AB5AEB	2017-08-02 09:51:00+03	3700.00
AB5BAF	2017-07-08 07:00:00+03	16000.00
AB5BC2	2017-08-14 10:07:00+03	47000.00
AB5BFB	2017-07-16 18:41:00+03	246000.00
AB5C12	2017-08-03 04:35:00+03	92000.00
AB5CAF	2017-07-02 16:29:00+03	381400.00
AB5CEA	2017-07-11 18:32:00+03	258300.00
AB5D02	2017-07-27 08:52:00+03	10800.00
AB5D6F	2017-07-13 21:11:00+03	42400.00
AB5DA8	2017-07-17 02:18:00+03	93900.00
AB5E1D	2017-07-07 06:53:00+03	30200.00
AB5E3F	2017-07-07 09:05:00+03	180600.00
AB5ED9	2017-07-12 08:33:00+03	199600.00
AB5EE3	2017-08-13 13:12:00+03	26800.00
AB5F2F	2017-07-15 06:38:00+03	6700.00
AB5F5E	2017-07-31 16:40:00+03	63200.00
AB5F6C	2017-07-22 15:51:00+03	56600.00
AB5F7D	2017-07-28 05:41:00+03	54000.00
AB5FCB	2017-07-05 22:46:00+03	73300.00
AB6004	2017-08-09 04:31:00+03	176800.00
AB610C	2017-07-21 04:33:00+03	28800.00
AB6172	2017-08-12 07:56:00+03	302600.00
AB618D	2017-08-10 05:43:00+03	23600.00
AB6190	2017-07-24 23:48:00+03	28800.00
AB6198	2017-07-20 07:20:00+03	31700.00
AB61B3	2017-07-09 02:07:00+03	93000.00
AB628F	2017-08-05 18:54:00+03	79600.00
AB629F	2017-06-30 05:31:00+03	63800.00
AB630A	2017-07-21 08:15:00+03	40000.00
AB631A	2017-07-22 13:40:00+03	23400.00
AB634E	2017-07-17 11:32:00+03	187600.00
AB6353	2017-08-02 15:35:00+03	189700.00
AB63BC	2017-07-12 21:57:00+03	42000.00
AB63D1	2017-07-22 12:25:00+03	66600.00
AB63FD	2017-07-01 15:28:00+03	46800.00
AB6400	2017-07-10 13:43:00+03	95700.00
AB6423	2017-08-08 20:54:00+03	55800.00
AB6580	2017-08-14 05:55:00+03	37200.00
AB6585	2017-08-10 04:58:00+03	22000.00
AB662B	2017-08-04 21:54:00+03	25800.00
AB6632	2017-08-02 17:40:00+03	90900.00
AB66A3	2017-07-07 17:41:00+03	12600.00
AB66D2	2017-07-02 10:28:00+03	52000.00
AB66D3	2017-07-21 16:31:00+03	28400.00
AB66DC	2017-08-06 00:01:00+03	62200.00
AB671D	2017-07-11 22:42:00+03	58600.00
AB6725	2017-07-11 03:48:00+03	111600.00
AB6737	2017-07-02 06:25:00+03	70700.00
AB6739	2017-08-11 13:24:00+03	18400.00
AB674E	2017-07-05 18:45:00+03	6800.00
AB6771	2017-07-19 06:44:00+03	48800.00
AB67B1	2017-08-08 15:09:00+03	47200.00
AB67E2	2017-07-24 06:53:00+03	120700.00
AB698B	2017-07-09 08:07:00+03	28000.00
AB699E	2017-08-04 00:09:00+03	224000.00
AB69B4	2017-08-10 19:37:00+03	90800.00
AB69E4	2017-07-07 17:09:00+03	227600.00
AB6A34	2017-08-11 02:35:00+03	18000.00
AB6AA2	2017-07-25 02:51:00+03	71500.00
AB6AC6	2017-07-18 20:05:00+03	36800.00
AB6B67	2017-07-24 08:38:00+03	23100.00
AB6B7C	2017-08-07 04:27:00+03	23500.00
AB6C29	2017-08-10 19:05:00+03	31000.00
AB6C9C	2017-07-24 21:57:00+03	133100.00
AB6CF3	2017-07-27 18:31:00+03	32800.00
AB6D02	2017-08-09 19:10:00+03	111600.00
AB6D31	2017-08-04 05:01:00+03	26000.00
AB6D8D	2017-08-08 11:25:00+03	155600.00
AB6DE6	2017-08-05 14:42:00+03	28800.00
AB6E0A	2017-08-07 13:46:00+03	40000.00
AB6E15	2017-08-01 23:03:00+03	80900.00
AB6E1E	2017-07-24 18:01:00+03	21800.00
AB6E3E	2017-08-14 05:06:00+03	12000.00
AB6F3A	2017-07-22 11:45:00+03	24600.00
AB6F5F	2017-07-26 02:14:00+03	27800.00
AB6FE1	2017-08-12 04:57:00+03	18400.00
AB701E	2017-07-10 06:49:00+03	46800.00
AB70A4	2017-08-10 04:47:00+03	82900.00
AB70EE	2017-08-02 15:05:00+03	39500.00
AB7143	2017-08-15 17:18:00+03	12000.00
AB715C	2017-07-31 00:07:00+03	65900.00
AB7175	2017-08-11 21:43:00+03	34000.00
AB7186	2017-07-10 14:26:00+03	49600.00
AB719C	2017-08-08 21:10:00+03	32700.00
AB71C5	2017-07-09 05:02:00+03	99600.00
AB7258	2017-08-04 18:39:00+03	133100.00
AB7288	2017-08-06 04:44:00+03	35600.00
AB733B	2017-08-12 18:11:00+03	136000.00
AB734D	2017-08-06 06:37:00+03	130400.00
AB735D	2017-07-28 06:40:00+03	34200.00
AB7361	2017-07-29 03:30:00+03	45900.00
AB7372	2017-08-12 08:12:00+03	28800.00
AB739C	2017-07-27 04:57:00+03	26000.00
AB73E8	2017-07-05 10:26:00+03	187800.00
AB73FE	2017-07-11 11:43:00+03	28800.00
AB7433	2017-07-21 10:05:00+03	33300.00
AB743E	2017-08-12 02:47:00+03	28000.00
AB745D	2017-07-24 14:42:00+03	51900.00
AB7482	2017-07-24 03:05:00+03	102100.00
AB74C7	2017-07-06 02:53:00+03	56000.00
AB74F0	2017-07-11 04:26:00+03	65500.00
AB7531	2017-08-06 02:22:00+03	32800.00
AB7581	2017-08-13 05:37:00+03	57800.00
AB761E	2017-07-11 13:53:00+03	99700.00
AB7644	2017-07-24 14:42:00+03	76600.00
AB7656	2017-07-16 16:37:00+03	220500.00
AB7688	2017-08-05 00:15:00+03	26500.00
AB76B9	2017-08-06 15:45:00+03	12000.00
AB76FE	2017-08-03 02:59:00+03	28800.00
AB7719	2017-08-08 08:07:00+03	6000.00
AB771E	2017-07-17 01:04:00+03	93000.00
AB772A	2017-07-31 02:17:00+03	42400.00
AB7744	2017-08-14 09:32:00+03	70800.00
AB776B	2017-08-15 06:27:00+03	28200.00
AB77F4	2017-07-21 22:26:00+03	18600.00
AB7835	2017-07-29 12:48:00+03	6000.00
AB789C	2017-07-28 23:39:00+03	52000.00
AB7919	2017-07-07 13:17:00+03	28000.00
AB7954	2017-07-25 02:42:00+03	73300.00
AB7980	2017-07-21 03:25:00+03	65900.00
AB79DC	2017-08-08 18:19:00+03	52800.00
AB7A2D	2017-08-04 20:25:00+03	186900.00
AB7B4D	2017-07-21 17:41:00+03	28800.00
AB7BB0	2017-07-12 03:14:00+03	34000.00
AB7BBB	2017-07-16 10:56:00+03	70700.00
AB7BF4	2017-07-16 16:07:00+03	20000.00
AB7C27	2017-08-02 22:08:00+03	269000.00
AB7C67	2017-08-13 04:08:00+03	177600.00
AB7CA6	2017-08-01 04:07:00+03	14000.00
AB7CED	2017-07-03 17:32:00+03	284400.00
AB7D67	2017-08-15 00:29:00+03	26800.00
AB7D73	2017-08-05 15:39:00+03	272400.00
AB7DB7	2017-08-15 12:37:00+03	50600.00
AB7E2E	2017-08-03 18:23:00+03	56600.00
AB7E53	2017-07-14 10:06:00+03	27200.00
AB7E8C	2017-08-13 10:35:00+03	71200.00
AB7E95	2017-07-16 09:53:00+03	23400.00
AB7ECB	2017-07-31 05:53:00+03	32400.00
AB7F30	2017-07-31 00:26:00+03	118600.00
AB7F3A	2017-07-01 04:28:00+03	27200.00
AB7F47	2017-07-30 19:18:00+03	166700.00
AB7F66	2017-07-15 00:10:00+03	32200.00
AB7FA0	2017-07-02 07:37:00+03	32800.00
AB7FD7	2017-07-08 13:55:00+03	115400.00
AB7FDB	2017-07-28 23:59:00+03	180800.00
AB8031	2017-07-16 22:25:00+03	70500.00
AB8090	2017-07-14 01:53:00+03	112600.00
AB8092	2017-08-02 05:31:00+03	57600.00
AB8102	2017-07-29 19:37:00+03	111000.00
AB8114	2017-08-07 23:56:00+03	41600.00
AB8147	2017-07-19 16:14:00+03	26000.00
AB817B	2017-07-17 14:39:00+03	46400.00
AB81DC	2017-07-29 03:45:00+03	16400.00
AB81F9	2017-08-11 04:20:00+03	26700.00
AB821E	2017-07-04 08:43:00+03	47600.00
AB8234	2017-07-15 14:09:00+03	199700.00
AB8244	2017-08-10 07:06:00+03	58600.00
AB829A	2017-07-21 05:07:00+03	28000.00
AB8356	2017-07-17 03:01:00+03	25200.00
AB83A9	2017-08-11 04:37:00+03	26000.00
AB83BF	2017-07-02 10:51:00+03	96800.00
AB842C	2017-08-03 12:52:00+03	74400.00
AB843C	2017-07-14 18:38:00+03	64000.00
AB843E	2017-08-05 11:34:00+03	12000.00
AB844C	2017-07-20 11:43:00+03	27600.00
AB8473	2017-06-28 06:06:00+03	124200.00
AB8498	2017-08-15 12:05:00+03	88100.00
AB84C6	2017-08-11 12:14:00+03	31100.00
AB84F9	2017-07-21 11:04:00+03	163000.00
AB8518	2017-07-10 03:11:00+03	12000.00
AB8565	2017-07-23 05:11:00+03	112600.00
AB8596	2017-08-09 04:29:00+03	94800.00
AB85D4	2017-08-05 09:53:00+03	58600.00
AB85FE	2017-07-25 09:40:00+03	136800.00
AB864D	2017-08-03 10:35:00+03	52800.00
AB8653	2017-08-09 05:41:00+03	66600.00
AB86BE	2017-08-04 22:01:00+03	56100.00
AB86DD	2017-07-05 22:03:00+03	199700.00
AB8701	2017-07-03 22:41:00+03	26000.00
AB8834	2017-08-10 00:04:00+03	111600.00
AB885C	2017-07-31 03:51:00+03	67100.00
AB88A9	2017-08-06 05:14:00+03	339900.00
AB88EF	2017-08-07 04:14:00+03	266500.00
AB898C	2017-07-07 06:01:00+03	44600.00
AB8A1A	2017-08-09 20:38:00+03	147900.00
AB8A2D	2017-07-19 05:52:00+03	11100.00
AB8A30	2017-07-11 19:53:00+03	49100.00
AB8A52	2017-07-17 00:42:00+03	38800.00
AB8A7C	2017-08-10 08:30:00+03	31800.00
AB8A98	2017-06-29 14:00:00+03	20100.00
AB8AA5	2017-07-13 10:33:00+03	75800.00
AB8ACC	2017-08-05 05:21:00+03	49400.00
AB8AE5	2017-08-07 11:04:00+03	26000.00
AB8B37	2017-07-01 13:58:00+03	28000.00
AB8B6B	2017-07-01 16:28:00+03	16400.00
AB8BB0	2017-08-10 16:47:00+03	68800.00
AB8C8B	2017-07-20 17:24:00+03	131400.00
AB8CA5	2017-07-14 07:21:00+03	38400.00
AB8CC1	2017-08-11 17:22:00+03	55800.00
AB8D26	2017-07-30 04:10:00+03	92800.00
AB8DFC	2017-07-03 23:50:00+03	65900.00
AB8E02	2017-08-10 10:21:00+03	119800.00
AB8E1E	2017-06-29 18:58:00+03	120400.00
AB8EBC	2017-07-19 17:15:00+03	260900.00
AB8ED4	2017-08-04 03:07:00+03	36200.00
AB8F0F	2017-08-04 16:16:00+03	43100.00
AB8F1E	2017-08-05 20:27:00+03	110400.00
AB8F27	2017-08-15 07:07:00+03	17800.00
AB8F6A	2017-07-30 14:23:00+03	93400.00
AB8F70	2017-07-09 11:41:00+03	55800.00
AB8FB6	2017-07-19 11:05:00+03	46800.00
AB8FCA	2017-07-30 20:57:00+03	62700.00
AB8FDF	2017-07-20 04:45:00+03	23100.00
AB9011	2017-07-10 21:19:00+03	46400.00
AB902B	2017-08-05 20:04:00+03	12600.00
AB904B	2017-08-08 02:27:00+03	70800.00
AB9076	2017-08-13 23:18:00+03	43900.00
AB9095	2017-07-22 20:04:00+03	48400.00
AB90CE	2017-07-29 04:48:00+03	169900.00
AB9121	2017-07-07 09:47:00+03	63200.00
AB9124	2017-07-13 17:01:00+03	14900.00
AB9140	2017-07-17 02:22:00+03	72200.00
AB91B0	2017-07-12 20:19:00+03	35700.00
AB926D	2017-08-14 19:19:00+03	50800.00
AB9279	2017-07-06 01:09:00+03	56000.00
AB928F	2017-07-19 00:24:00+03	270000.00
AB92AB	2017-07-06 22:13:00+03	90500.00
AB92B0	2017-07-29 19:10:00+03	69500.00
AB92C8	2017-07-09 14:41:00+03	101200.00
AB92CA	2017-07-13 06:50:00+03	198400.00
AB92CC	2017-07-18 15:17:00+03	111700.00
AB93AC	2017-07-25 21:19:00+03	39600.00
AB940C	2017-07-25 09:26:00+03	92900.00
AB9412	2017-07-18 20:42:00+03	66100.00
AB9417	2017-08-07 19:54:00+03	69200.00
AB9451	2017-08-13 12:44:00+03	73200.00
AB94C2	2017-07-24 19:52:00+03	120800.00
AB9566	2017-08-11 19:47:00+03	27200.00
AB958B	2017-08-15 13:31:00+03	62000.00
AB95DD	2017-08-06 15:55:00+03	46300.00
AB9641	2017-08-09 06:39:00+03	36200.00
AB9643	2017-07-14 12:05:00+03	80200.00
AB9658	2017-07-25 17:33:00+03	55400.00
AB966A	2017-08-09 13:17:00+03	98600.00
AB96AD	2017-07-12 20:00:00+03	48500.00
AB971E	2017-07-27 23:42:00+03	44700.00
AB9721	2017-07-18 12:18:00+03	12000.00
AB9764	2017-07-23 19:51:00+03	83000.00
AB9780	2017-07-30 19:57:00+03	108600.00
AB978E	2017-08-13 06:40:00+03	22000.00
AB97A3	2017-08-02 21:57:00+03	177200.00
AB9863	2017-08-14 18:35:00+03	54200.00
AB9933	2017-08-10 13:02:00+03	491000.00
AB9986	2017-07-09 23:31:00+03	33300.00
AB99D2	2017-07-11 23:38:00+03	28000.00
AB99D4	2017-08-12 13:29:00+03	151800.00
AB9A05	2017-07-18 08:26:00+03	118000.00
AB9A0A	2017-08-01 11:47:00+03	13000.00
AB9A8B	2017-07-23 07:20:00+03	54800.00
AB9AAC	2017-07-16 04:56:00+03	141600.00
AB9ABA	2017-07-16 20:50:00+03	59800.00
AB9AE9	2017-07-22 21:46:00+03	168000.00
AB9AFB	2017-07-04 01:00:00+03	85800.00
AB9B0B	2017-07-20 07:51:00+03	99900.00
AB9B6B	2017-07-13 01:20:00+03	18000.00
AB9C4A	2017-08-13 16:13:00+03	19600.00
AB9CA0	2017-07-21 00:46:00+03	62600.00
AB9CBD	2017-08-15 05:09:00+03	72600.00
AB9CF9	2017-07-18 09:38:00+03	50600.00
AB9D00	2017-07-08 11:48:00+03	27400.00
AB9DCF	2017-08-10 16:24:00+03	55800.00
AB9DDB	2017-08-12 22:24:00+03	13400.00
AB9E45	2017-06-30 03:34:00+03	46000.00
AB9E8A	2017-07-02 01:09:00+03	24500.00
AB9E8B	2017-07-14 01:03:00+03	113200.00
AB9F2B	2017-07-11 01:25:00+03	134400.00
AB9FCD	2017-08-12 14:47:00+03	75600.00
AB9FE3	2017-07-30 18:04:00+03	18300.00
ABA07F	2017-07-30 22:48:00+03	112600.00
ABA084	2017-07-21 03:26:00+03	398500.00
ABA091	2017-08-09 15:50:00+03	148200.00
ABA0AD	2017-07-03 20:44:00+03	26000.00
ABA0AF	2017-07-19 16:24:00+03	58800.00
ABA0B0	2017-06-29 12:27:00+03	58600.00
ABA1AD	2017-08-09 04:19:00+03	73600.00
ABA1C4	2017-07-18 18:53:00+03	125100.00
ABA1EB	2017-07-25 15:24:00+03	6800.00
ABA227	2017-07-23 00:45:00+03	145300.00
ABA22A	2017-08-13 15:09:00+03	55800.00
ABA28D	2017-08-13 20:58:00+03	48400.00
ABA29D	2017-07-28 15:07:00+03	47500.00
ABA2A2	2017-07-07 10:35:00+03	60400.00
ABA2B3	2017-08-15 14:19:00+03	14400.00
ABA31C	2017-08-01 19:02:00+03	167500.00
ABA326	2017-08-06 05:02:00+03	8000.00
ABA365	2017-07-03 11:45:00+03	21000.00
ABA3A0	2017-07-05 05:29:00+03	26700.00
ABA3AB	2017-07-18 18:00:00+03	68100.00
ABA3B9	2017-07-21 23:09:00+03	122800.00
ABA3CA	2017-07-04 04:05:00+03	133200.00
ABA3E8	2017-07-17 20:58:00+03	55800.00
ABA405	2017-07-29 14:11:00+03	19600.00
ABA426	2017-07-28 07:36:00+03	6300.00
ABA43E	2017-08-14 01:45:00+03	32200.00
ABA459	2017-07-07 01:47:00+03	32700.00
ABA4F9	2017-08-03 08:58:00+03	97000.00
ABA569	2017-07-25 00:47:00+03	40000.00
ABA584	2017-07-20 01:47:00+03	23400.00
ABA596	2017-07-24 14:40:00+03	77000.00
ABA679	2017-08-12 13:17:00+03	203300.00
ABA680	2017-08-12 05:16:00+03	24000.00
ABA6BD	2017-07-21 15:16:00+03	42800.00
ABA70B	2017-07-28 15:42:00+03	70100.00
ABA743	2017-08-13 17:42:00+03	32900.00
ABA765	2017-08-10 10:32:00+03	38400.00
ABA790	2017-08-14 11:14:00+03	42800.00
ABA7BA	2017-07-06 05:16:00+03	26700.00
ABA7C9	2017-06-30 05:20:00+03	47400.00
ABA7E9	2017-08-03 20:23:00+03	94500.00
ABA81A	2017-07-28 07:40:00+03	6700.00
ABA831	2017-07-01 17:24:00+03	53300.00
ABA84F	2017-07-31 17:37:00+03	23100.00
ABA850	2017-07-29 14:26:00+03	139800.00
ABA871	2017-07-12 13:13:00+03	24800.00
ABA8A2	2017-08-07 15:41:00+03	354900.00
ABA8C2	2017-08-04 22:01:00+03	27200.00
ABA8E7	2017-08-07 00:16:00+03	123000.00
ABA90C	2017-07-05 21:59:00+03	248300.00
ABA958	2017-07-17 12:48:00+03	81300.00
ABA9B2	2017-07-12 01:23:00+03	95700.00
ABA9F6	2017-08-14 15:29:00+03	84500.00
ABAA83	2017-08-01 04:48:00+03	43200.00
ABAA99	2017-08-09 20:39:00+03	184300.00
ABAB36	2017-08-01 03:11:00+03	47200.00
ABAB67	2017-06-30 02:36:00+03	24400.00
ABABB6	2017-08-05 03:24:00+03	64200.00
ABAC3B	2017-08-04 10:07:00+03	25100.00
ABAC4D	2017-08-14 15:29:00+03	43500.00
ABAC8C	2017-07-18 16:28:00+03	267500.00
ABACC7	2017-07-05 14:04:00+03	39200.00
ABACF6	2017-07-08 11:11:00+03	8200.00
ABACFE	2017-07-03 01:24:00+03	30000.00
ABAD3A	2017-07-26 01:48:00+03	6000.00
ABADA2	2017-08-06 17:07:00+03	72400.00
ABADC2	2017-07-13 05:11:00+03	64000.00
ABADF6	2017-07-31 23:47:00+03	101100.00
ABAE04	2017-07-16 03:48:00+03	16400.00
ABAF05	2017-07-10 11:40:00+03	46400.00
ABAF3E	2017-08-14 20:34:00+03	28800.00
ABAFDD	2017-08-13 01:55:00+03	52400.00
ABAFFA	2017-07-31 05:52:00+03	141600.00
ABB00C	2017-08-13 09:54:00+03	14400.00
ABB018	2017-07-31 12:10:00+03	273000.00
ABB026	2017-07-05 11:11:00+03	47500.00
ABB060	2017-07-30 08:42:00+03	34000.00
ABB0F7	2017-08-04 16:02:00+03	114800.00
ABB0F9	2017-08-15 15:10:00+03	53000.00
ABB1DB	2017-07-23 00:48:00+03	234800.00
ABB1F9	2017-07-17 03:20:00+03	41600.00
ABB211	2017-08-13 06:33:00+03	70700.00
ABB21F	2017-08-02 13:42:00+03	72900.00
ABB23B	2017-08-06 09:41:00+03	32800.00
ABB273	2017-07-23 02:02:00+03	62600.00
ABB309	2017-07-09 17:58:00+03	48500.00
ABB33F	2017-08-10 15:34:00+03	67200.00
ABB3D8	2017-07-24 21:00:00+03	90600.00
ABB41E	2017-07-07 18:37:00+03	66200.00
ABB476	2017-07-10 04:29:00+03	14700.00
ABB5FC	2017-07-24 23:08:00+03	46400.00
ABB638	2017-08-05 14:08:00+03	99000.00
ABB66F	2017-07-09 23:42:00+03	112600.00
ABB696	2017-07-12 03:35:00+03	38600.00
ABB6DA	2017-07-15 18:39:00+03	278200.00
ABB6E0	2017-07-29 23:07:00+03	70500.00
ABB6E6	2017-07-06 04:51:00+03	6300.00
ABB737	2017-07-05 02:08:00+03	29600.00
ABB7AF	2017-08-02 18:36:00+03	15800.00
ABB82D	2017-07-15 02:14:00+03	31000.00
ABB8B8	2017-07-20 19:13:00+03	155600.00
ABB8CE	2017-07-02 08:53:00+03	31000.00
ABB8EB	2017-07-12 07:10:00+03	92800.00
ABB9AB	2017-07-04 12:08:00+03	42700.00
ABB9D2	2017-08-08 00:18:00+03	67200.00
ABB9D7	2017-08-14 04:20:00+03	15000.00
ABB9E3	2017-07-28 11:10:00+03	62600.00
ABBA55	2017-07-10 19:34:00+03	27700.00
ABBA72	2017-08-04 19:05:00+03	25100.00
ABBAAE	2017-07-11 21:53:00+03	92800.00
ABBAFF	2017-07-17 01:50:00+03	57600.00
ABBB0A	2017-07-30 18:02:00+03	118000.00
ABBB96	2017-07-08 08:54:00+03	153200.00
ABBC32	2017-07-14 06:07:00+03	56000.00
ABBC6A	2017-07-10 02:03:00+03	27200.00
ABBC7F	2017-07-02 23:28:00+03	64700.00
ABBCBD	2017-08-03 14:08:00+03	114800.00
ABBCE8	2017-07-15 05:37:00+03	25400.00
ABBD88	2017-07-02 07:47:00+03	59800.00
ABBD9A	2017-08-13 18:11:00+03	26000.00
ABBDE5	2017-07-11 18:43:00+03	22000.00
ABBDF3	2017-07-17 18:30:00+03	23600.00
ABBDFC	2017-08-02 00:06:00+03	23600.00
ABBE19	2017-08-05 12:53:00+03	120700.00
ABBE2E	2017-07-23 05:48:00+03	29200.00
ABBE35	2017-07-13 14:32:00+03	242100.00
ABBF20	2017-08-09 22:31:00+03	65900.00
ABBF3D	2017-06-27 05:17:00+03	11600.00
ABC0CE	2017-08-05 04:38:00+03	119400.00
ABC13B	2017-07-31 04:13:00+03	39200.00
ABC147	2017-07-04 08:43:00+03	50400.00
ABC164	2017-07-30 03:20:00+03	103500.00
ABC199	2017-08-02 03:39:00+03	92400.00
ABC1A5	2017-08-07 01:11:00+03	54400.00
ABC2B9	2017-07-20 00:21:00+03	101500.00
ABC2C0	2017-07-11 03:56:00+03	85400.00
ABC395	2017-07-15 20:53:00+03	137600.00
ABC3A2	2017-07-29 13:49:00+03	28300.00
ABC3DD	2017-08-13 05:51:00+03	301500.00
ABC3E5	2017-07-16 07:17:00+03	55800.00
ABC433	2017-07-06 15:41:00+03	32800.00
ABC4CD	2017-08-15 06:27:00+03	28000.00
ABC4E5	2017-07-13 05:30:00+03	37000.00
ABC526	2017-08-01 20:25:00+03	21700.00
ABC571	2017-07-25 19:33:00+03	56200.00
ABC5E7	2017-08-02 12:45:00+03	13400.00
ABC61E	2017-08-12 12:59:00+03	96800.00
ABC673	2017-07-14 17:41:00+03	87400.00
ABC682	2017-07-23 10:42:00+03	90800.00
ABC6A0	2017-07-14 06:45:00+03	22400.00
ABC6EE	2017-07-15 09:53:00+03	48800.00
ABC6F5	2017-08-05 14:27:00+03	105100.00
ABC722	2017-07-24 08:06:00+03	21800.00
ABC753	2017-08-01 19:52:00+03	19600.00
ABC771	2017-07-03 19:29:00+03	49100.00
ABC774	2017-07-27 04:43:00+03	36400.00
ABC7A3	2017-07-15 09:16:00+03	123000.00
ABC7A7	2017-07-09 06:18:00+03	58000.00
ABC8B4	2017-07-11 21:23:00+03	39300.00
ABC920	2017-07-17 06:52:00+03	8400.00
ABC951	2017-07-13 07:01:00+03	47200.00
ABC968	2017-07-28 14:31:00+03	42800.00
ABC96B	2017-07-16 09:44:00+03	6000.00
ABC96C	2017-07-13 11:50:00+03	112000.00
ABC983	2017-07-02 21:47:00+03	167500.00
ABCA1F	2017-07-08 00:48:00+03	15400.00
ABCAA6	2017-07-12 17:30:00+03	59200.00
ABCABE	2017-07-10 00:30:00+03	6300.00
ABCB36	2017-08-14 06:35:00+03	35800.00
ABCBCB	2017-07-19 10:20:00+03	21800.00
ABCC0F	2017-07-05 08:38:00+03	57600.00
ABCC3D	2017-07-25 03:04:00+03	135400.00
ABCC9C	2017-07-07 15:48:00+03	25000.00
ABCCA7	2017-07-10 03:29:00+03	75600.00
ABCD1C	2017-07-30 05:13:00+03	150300.00
ABCD25	2017-07-26 14:16:00+03	11600.00
ABCD8F	2017-06-30 09:32:00+03	29400.00
ABCE11	2017-07-02 21:52:00+03	65000.00
ABCE17	2017-07-11 06:16:00+03	6800.00
ABCE71	2017-08-14 14:16:00+03	84100.00
ABCF03	2017-07-13 07:50:00+03	194200.00
ABCF89	2017-07-19 21:22:00+03	47000.00
ABCFD8	2017-07-17 09:42:00+03	70700.00
ABCFE4	2017-08-15 11:34:00+03	260300.00
ABD07F	2017-07-27 09:40:00+03	20400.00
ABD08A	2017-07-30 14:48:00+03	30000.00
ABD0A2	2017-07-06 05:52:00+03	44600.00
ABD0BC	2017-07-28 07:54:00+03	73200.00
ABD0E8	2017-07-30 23:39:00+03	57500.00
ABD0FF	2017-07-31 02:22:00+03	117600.00
ABD152	2017-07-24 19:57:00+03	56600.00
ABD1C4	2017-07-08 14:53:00+03	57300.00
ABD1CC	2017-07-10 18:42:00+03	47400.00
ABD1F3	2017-08-09 02:06:00+03	123000.00
ABD204	2017-08-01 16:23:00+03	14400.00
ABD270	2017-08-06 02:48:00+03	68800.00
ABD278	2017-07-31 19:07:00+03	75600.00
ABD313	2017-07-24 12:05:00+03	60200.00
ABD35C	2017-07-18 10:03:00+03	78600.00
ABD3F2	2017-07-12 01:52:00+03	136500.00
ABD40B	2017-08-02 07:38:00+03	250000.00
ABD410	2017-07-10 23:49:00+03	155600.00
ABD435	2017-07-13 13:56:00+03	81900.00
ABD4BC	2017-07-03 03:13:00+03	6800.00
ABD4C9	2017-08-13 09:02:00+03	265700.00
ABD4D6	2017-08-13 18:26:00+03	28800.00
ABD4E6	2017-07-06 05:01:00+03	75600.00
ABD4EF	2017-08-08 18:58:00+03	80300.00
ABD501	2017-07-05 15:02:00+03	12400.00
ABD536	2017-08-01 10:48:00+03	28000.00
ABD558	2017-06-29 03:24:00+03	46200.00
ABD575	2017-07-01 12:25:00+03	90400.00
ABD599	2017-08-08 01:23:00+03	492000.00
ABD5F3	2017-07-19 00:28:00+03	12200.00
ABD623	2017-08-14 01:03:00+03	43000.00
ABD6BC	2017-07-28 23:58:00+03	155600.00
ABD6E6	2017-07-28 17:20:00+03	50900.00
ABD723	2017-08-09 05:11:00+03	62600.00
ABD73C	2017-08-14 00:49:00+03	36000.00
ABD757	2017-07-31 17:49:00+03	140900.00
ABD76A	2017-07-26 19:50:00+03	69000.00
ABD781	2017-08-13 06:24:00+03	28800.00
ABD789	2017-07-16 04:03:00+03	68000.00
ABD798	2017-08-04 22:34:00+03	190400.00
ABD829	2017-07-18 10:42:00+03	13200.00
ABD82E	2017-06-30 06:15:00+03	41300.00
ABD850	2017-08-06 11:22:00+03	160700.00
ABD8AD	2017-07-03 22:48:00+03	26800.00
ABD916	2017-07-15 11:04:00+03	117200.00
ABD918	2017-07-16 20:39:00+03	52000.00
ABD921	2017-07-09 10:57:00+03	52800.00
ABD92E	2017-07-10 09:43:00+03	96600.00
ABD963	2017-07-08 13:15:00+03	193700.00
ABD9AA	2017-08-03 16:32:00+03	28800.00
ABD9EA	2017-07-05 03:05:00+03	112000.00
ABDA1B	2017-08-10 10:54:00+03	55600.00
ABDA46	2017-08-12 06:57:00+03	29600.00
ABDA8A	2017-08-15 09:14:00+03	136200.00
ABDAFC	2017-07-18 12:15:00+03	88100.00
ABDB0B	2017-08-03 12:00:00+03	239000.00
ABDB7B	2017-07-25 09:00:00+03	52000.00
ABDBC2	2017-07-30 03:13:00+03	83000.00
ABDC05	2017-07-05 17:44:00+03	36200.00
ABDC25	2017-08-10 17:39:00+03	78300.00
ABDC2D	2017-08-04 13:42:00+03	44000.00
ABDC40	2017-08-04 11:35:00+03	27400.00
ABDC5B	2017-07-11 16:45:00+03	54800.00
ABDCE7	2017-07-18 14:09:00+03	52000.00
ABDDFA	2017-07-17 00:25:00+03	14000.00
ABDE0C	2017-07-07 13:26:00+03	163500.00
ABDE5D	2017-07-27 11:45:00+03	16800.00
ABDEB6	2017-07-09 11:05:00+03	166100.00
ABDF38	2017-08-06 01:16:00+03	117600.00
ABDF3D	2017-08-13 20:25:00+03	75300.00
ABDF69	2017-07-09 00:26:00+03	27800.00
ABDFF1	2017-07-08 13:56:00+03	38600.00
ABDFF7	2017-07-28 17:03:00+03	25800.00
ABE048	2017-08-07 09:05:00+03	77000.00
ABE061	2017-07-15 08:34:00+03	40600.00
ABE064	2017-07-15 02:37:00+03	266400.00
ABE072	2017-07-13 23:08:00+03	16400.00
ABE08C	2017-07-26 00:47:00+03	119700.00
ABE09C	2017-07-16 03:46:00+03	21200.00
ABE0A2	2017-07-20 11:06:00+03	66800.00
ABE0B2	2017-07-11 14:12:00+03	38800.00
ABE0CB	2017-07-27 09:13:00+03	54400.00
ABE11B	2017-07-31 14:03:00+03	23200.00
ABE145	2017-07-13 20:53:00+03	23200.00
ABE16B	2017-06-24 11:08:00+03	215500.00
ABE175	2017-08-14 18:49:00+03	117900.00
ABE17A	2017-07-30 01:20:00+03	44000.00
ABE1D4	2017-08-05 22:33:00+03	22000.00
ABE273	2017-07-01 12:17:00+03	73100.00
ABE28D	2017-07-09 00:32:00+03	95200.00
ABE32C	2017-07-05 20:02:00+03	23600.00
ABE342	2017-07-20 21:34:00+03	260300.00
ABE373	2017-06-25 03:39:00+03	198800.00
ABE3FF	2017-07-19 16:48:00+03	43600.00
ABE500	2017-07-19 00:42:00+03	16400.00
ABE51D	2017-07-18 14:15:00+03	91500.00
ABE527	2017-08-07 13:25:00+03	40100.00
ABE5BE	2017-08-14 09:40:00+03	37600.00
ABE66C	2017-08-05 11:19:00+03	31600.00
ABE705	2017-08-03 05:13:00+03	92100.00
ABE715	2017-07-13 03:09:00+03	64600.00
ABE76E	2017-07-27 12:17:00+03	23200.00
ABE77F	2017-08-09 20:44:00+03	14000.00
ABE7B4	2017-07-04 20:26:00+03	493300.00
ABE7BA	2017-07-01 08:55:00+03	46200.00
ABE833	2017-07-01 12:53:00+03	8000.00
ABE889	2017-06-28 23:43:00+03	51400.00
ABE9C1	2017-07-15 11:20:00+03	16800.00
ABE9E0	2017-07-14 02:31:00+03	56000.00
ABE9E8	2017-07-08 17:52:00+03	24700.00
ABEA1F	2017-07-16 15:56:00+03	23400.00
ABEA2C	2017-07-11 11:58:00+03	52000.00
ABEA85	2017-07-19 12:32:00+03	6000.00
ABEB0F	2017-07-06 15:13:00+03	62200.00
ABEB47	2017-07-03 05:55:00+03	19600.00
ABEB7C	2017-08-05 12:01:00+03	31900.00
ABEB81	2017-08-03 15:50:00+03	88800.00
ABEBE1	2017-08-04 17:25:00+03	32800.00
ABEC52	2017-07-26 14:27:00+03	59200.00
ABEC61	2017-07-05 04:50:00+03	11800.00
ABEC91	2017-08-06 20:04:00+03	8200.00
ABEC9E	2017-07-31 02:05:00+03	30000.00
ABECE1	2017-08-02 21:54:00+03	280000.00
ABED9C	2017-08-13 16:13:00+03	25600.00
ABEDBB	2017-07-28 03:22:00+03	47500.00
ABEE34	2017-07-28 06:58:00+03	53200.00
ABEE4B	2017-07-24 12:15:00+03	51300.00
ABEF0D	2017-07-28 10:08:00+03	100000.00
ABEF5B	2017-07-15 03:43:00+03	292200.00
ABEF85	2017-08-05 09:02:00+03	286200.00
ABEFB9	2017-07-07 09:34:00+03	67600.00
ABEFE3	2017-07-06 13:36:00+03	83400.00
ABF015	2017-08-12 18:00:00+03	69500.00
ABF030	2017-07-26 08:28:00+03	135600.00
ABF03C	2017-07-08 07:51:00+03	73300.00
ABF03D	2017-07-28 21:12:00+03	31900.00
ABF046	2017-07-04 15:44:00+03	24400.00
ABF07F	2017-08-03 09:18:00+03	90400.00
ABF0FB	2017-07-14 05:44:00+03	21400.00
ABF10F	2017-07-15 09:57:00+03	91200.00
ABF16E	2017-07-08 08:37:00+03	56000.00
ABF174	2017-07-31 11:04:00+03	26700.00
ABF177	2017-08-09 04:57:00+03	38800.00
ABF257	2017-07-08 03:56:00+03	153200.00
ABF262	2017-08-10 18:55:00+03	265800.00
ABF305	2017-08-13 12:48:00+03	64700.00
ABF3EE	2017-07-24 01:54:00+03	177600.00
ABF409	2017-08-06 08:05:00+03	7400.00
ABF45D	2017-07-13 22:51:00+03	124600.00
ABF4AA	2017-07-09 14:04:00+03	260400.00
ABF4CA	2017-07-23 22:25:00+03	70700.00
ABF4E0	2017-07-14 17:45:00+03	27200.00
ABF507	2017-07-24 11:17:00+03	48800.00
ABF532	2017-08-07 14:21:00+03	86000.00
ABF59B	2017-08-13 22:06:00+03	60400.00
ABF5A4	2017-07-16 22:10:00+03	66000.00
ABF5C0	2017-08-04 02:00:00+03	113800.00
ABF5D7	2017-07-08 13:54:00+03	188800.00
ABF5E9	2017-07-08 16:23:00+03	288900.00
ABF600	2017-07-06 07:36:00+03	47400.00
ABF614	2017-07-11 03:36:00+03	28000.00
ABF61A	2017-08-07 23:20:00+03	74800.00
ABF629	2017-07-06 03:47:00+03	89000.00
ABF660	2017-07-31 19:03:00+03	25200.00
ABF674	2017-07-30 20:30:00+03	46400.00
ABF698	2017-07-02 14:05:00+03	8000.00
ABF6D8	2017-07-22 21:45:00+03	40800.00
ABF7EA	2017-08-14 01:49:00+03	28800.00
ABF7FA	2017-08-10 04:09:00+03	249100.00
ABF878	2017-06-29 22:12:00+03	58800.00
ABF87B	2017-08-02 07:12:00+03	113200.00
ABF8EE	2017-07-02 04:43:00+03	167400.00
ABF911	2017-07-28 09:27:00+03	265700.00
ABF91E	2017-08-09 11:45:00+03	105800.00
ABF926	2017-07-27 04:48:00+03	170700.00
ABF940	2017-07-16 14:03:00+03	122500.00
ABF96B	2017-08-11 14:10:00+03	43200.00
ABF97E	2017-08-01 15:50:00+03	44800.00
ABF99F	2017-08-06 07:06:00+03	54000.00
ABFA4A	2017-07-04 12:01:00+03	283700.00
ABFAAD	2017-08-12 23:46:00+03	12600.00
ABFAB3	2017-07-17 04:59:00+03	43200.00
ABFACC	2017-08-04 23:49:00+03	257300.00
ABFB0C	2017-07-26 09:08:00+03	50800.00
ABFB26	2017-07-27 19:17:00+03	28000.00
ABFB5D	2017-07-19 23:13:00+03	36000.00
ABFBDC	2017-07-25 14:52:00+03	32900.00
ABFBE6	2017-08-13 05:32:00+03	47100.00
ABFC21	2017-07-29 16:27:00+03	43400.00
ABFC35	2017-07-08 02:59:00+03	39500.00
ABFC4F	2017-07-03 06:20:00+03	209900.00
ABFC60	2017-07-23 19:27:00+03	122500.00
ABFCB7	2017-07-22 19:17:00+03	47100.00
ABFCC0	2017-07-14 14:12:00+03	57500.00
ABFD3F	2017-08-15 03:54:00+03	64700.00
ABFD92	2017-08-07 04:13:00+03	72700.00
ABFDAF	2017-08-06 05:08:00+03	25600.00
ABFE3E	2017-07-29 10:16:00+03	271100.00
ABFE9A	2017-08-08 18:44:00+03	59300.00
ABFE9C	2017-07-13 13:59:00+03	14400.00
ABFEA8	2017-07-21 23:42:00+03	66600.00
ABFECB	2017-07-18 04:00:00+03	67200.00
ABFED7	2017-08-15 05:32:00+03	12600.00
ABFF1B	2017-07-25 18:30:00+03	20200.00
ABFF1C	2017-07-19 12:03:00+03	36200.00
ABFF52	2017-07-17 18:01:00+03	59000.00
ABFF5E	2017-07-25 12:41:00+03	152600.00
ABFF7F	2017-07-04 06:00:00+03	192700.00
ABFF83	2017-07-28 20:22:00+03	135400.00
ABFF9F	2017-07-12 19:20:00+03	57400.00
ABFFA1	2017-07-31 22:05:00+03	14000.00
ABFFD4	2017-08-14 02:41:00+03	38800.00
AC0010	2017-08-02 00:44:00+03	372500.00
AC0078	2017-08-07 17:27:00+03	264000.00
AC009D	2017-08-12 01:44:00+03	102100.00
AC00A5	2017-07-10 02:10:00+03	133100.00
AC013A	2017-07-04 07:05:00+03	77500.00
AC019B	2017-07-07 15:19:00+03	66600.00
AC01E2	2017-07-23 11:03:00+03	38200.00
AC02A4	2017-07-14 23:30:00+03	52000.00
AC033C	2017-08-14 03:48:00+03	62200.00
AC0350	2017-07-13 08:59:00+03	14000.00
AC03E1	2017-07-09 11:32:00+03	74800.00
AC041D	2017-07-22 19:37:00+03	111600.00
AC04A0	2017-07-19 16:04:00+03	126400.00
AC04A9	2017-08-10 21:23:00+03	135600.00
AC04B3	2017-07-29 19:53:00+03	123600.00
AC04C5	2017-07-17 01:39:00+03	79900.00
AC04FD	2017-08-07 03:53:00+03	189200.00
AC0550	2017-07-18 19:48:00+03	26200.00
AC0589	2017-07-23 23:55:00+03	23600.00
AC05B3	2017-07-19 02:39:00+03	129200.00
AC05D8	2017-07-05 10:31:00+03	87800.00
AC060E	2017-07-26 08:47:00+03	369000.00
AC0622	2017-07-17 06:17:00+03	174600.00
AC064E	2017-08-13 09:25:00+03	142800.00
AC06C6	2017-07-07 11:59:00+03	98100.00
AC06D0	2017-07-20 18:59:00+03	75500.00
AC070A	2017-07-03 20:23:00+03	54500.00
AC07B9	2017-07-12 01:53:00+03	62600.00
AC0806	2017-08-14 20:37:00+03	143800.00
AC086B	2017-07-22 21:21:00+03	29600.00
AC0890	2017-07-14 23:05:00+03	119600.00
AC08A6	2017-07-23 15:57:00+03	252200.00
AC08FA	2017-07-04 21:21:00+03	270400.00
AC09C6	2017-08-04 00:02:00+03	136800.00
AC09FE	2017-07-14 11:06:00+03	13400.00
AC0A03	2017-07-16 13:37:00+03	46900.00
AC0A2D	2017-07-26 16:35:00+03	83100.00
AC0A44	2017-07-25 03:02:00+03	58400.00
AC0B49	2017-08-12 02:42:00+03	22000.00
AC0BB4	2017-08-14 21:58:00+03	28000.00
AC0BEE	2017-07-28 01:37:00+03	123000.00
AC0BEF	2017-08-12 19:01:00+03	152400.00
AC0C98	2017-07-07 16:20:00+03	92800.00
AC0D28	2017-07-06 06:55:00+03	52700.00
AC0D71	2017-07-01 04:18:00+03	69500.00
AC0DAC	2017-07-10 13:32:00+03	57700.00
AC0DC4	2017-07-11 07:55:00+03	226200.00
AC0DF4	2017-07-03 01:05:00+03	189200.00
AC0E80	2017-08-08 13:58:00+03	26000.00
AC0EA1	2017-07-25 18:53:00+03	47800.00
AC0F0C	2017-08-12 04:22:00+03	49100.00
AC0F75	2017-07-09 10:32:00+03	133200.00
AC0FCF	2017-08-01 21:20:00+03	40000.00
AC0FE2	2017-07-25 08:27:00+03	12000.00
AC0FF1	2017-08-01 01:55:00+03	69000.00
AC1009	2017-08-10 15:03:00+03	80900.00
AC1018	2017-07-06 13:10:00+03	124200.00
AC1032	2017-08-13 07:02:00+03	52800.00
AC1046	2017-07-31 20:01:00+03	112600.00
AC10E5	2017-07-18 23:48:00+03	26000.00
AC116F	2017-08-01 03:27:00+03	146300.00
AC11BB	2017-08-14 05:25:00+03	24000.00
AC1296	2017-07-26 08:12:00+03	13000.00
AC12D9	2017-07-04 16:45:00+03	46000.00
AC137C	2017-07-23 11:50:00+03	31600.00
AC138D	2017-08-06 05:33:00+03	133700.00
AC13A1	2017-07-02 14:43:00+03	47200.00
AC13D0	2017-07-31 15:58:00+03	100600.00
AC13D8	2017-07-20 04:38:00+03	31700.00
AC1487	2017-07-07 22:26:00+03	28800.00
AC14E5	2017-07-09 20:36:00+03	116700.00
AC1535	2017-07-09 22:16:00+03	21400.00
AC1555	2017-07-13 07:13:00+03	18000.00
AC1579	2017-07-27 22:46:00+03	135600.00
AC15A0	2017-07-17 09:24:00+03	36800.00
AC15C0	2017-07-15 05:42:00+03	84100.00
AC15F2	2017-08-11 17:47:00+03	174600.00
AC164A	2017-07-26 09:09:00+03	27800.00
AC166D	2017-07-10 22:32:00+03	38600.00
AC169B	2017-07-23 14:55:00+03	78300.00
AC16D6	2017-07-10 20:39:00+03	146600.00
AC1713	2017-06-30 01:13:00+03	178300.00
AC1728	2017-07-07 07:59:00+03	46300.00
AC1730	2017-07-29 06:20:00+03	28800.00
AC1772	2017-07-05 11:28:00+03	49500.00
AC177C	2017-08-06 20:33:00+03	73300.00
AC1819	2017-07-25 04:30:00+03	70700.00
AC1820	2017-07-30 21:48:00+03	7400.00
AC1897	2017-07-02 12:26:00+03	49300.00
AC189C	2017-07-06 03:47:00+03	31400.00
AC18D0	2017-08-11 17:29:00+03	25100.00
AC1921	2017-08-06 19:46:00+03	28000.00
AC1977	2017-07-13 04:52:00+03	65600.00
AC198D	2017-08-03 13:39:00+03	86300.00
AC19A9	2017-07-12 00:09:00+03	40800.00
AC19BE	2017-08-01 03:44:00+03	67600.00
AC19CC	2017-08-05 23:38:00+03	47200.00
AC19DD	2017-07-06 07:05:00+03	258400.00
AC19E6	2017-07-16 17:27:00+03	38400.00
AC19F3	2017-07-10 00:33:00+03	100300.00
AC1B5C	2017-07-06 03:37:00+03	133200.00
AC1B70	2017-07-27 07:14:00+03	66200.00
AC1BD0	2017-07-20 23:06:00+03	266400.00
AC1BD8	2017-08-14 13:28:00+03	28800.00
AC1BF6	2017-07-18 01:20:00+03	21400.00
AC1C39	2017-07-29 19:11:00+03	62800.00
AC1C40	2017-07-04 02:12:00+03	91400.00
AC1C46	2017-07-29 22:53:00+03	95700.00
AC1C63	2017-07-14 20:28:00+03	24400.00
AC1CC9	2017-07-07 00:27:00+03	18000.00
AC1CE4	2017-07-31 02:30:00+03	142400.00
AC1D79	2017-07-25 13:18:00+03	49100.00
AC1D8B	2017-08-02 04:49:00+03	62300.00
AC1D98	2017-07-13 17:56:00+03	20400.00
AC1D9D	2017-07-06 11:22:00+03	77600.00
AC1DF5	2017-07-21 10:20:00+03	141600.00
AC1E44	2017-07-01 19:18:00+03	50800.00
AC1F3C	2017-08-05 01:45:00+03	26000.00
AC1F86	2017-08-13 19:49:00+03	14800.00
AC1F8B	2017-07-09 21:22:00+03	61400.00
AC1FDF	2017-07-08 07:00:00+03	258400.00
AC1FF8	2017-07-10 15:17:00+03	48900.00
AC20B7	2017-08-09 23:34:00+03	7400.00
AC20F1	2017-08-01 00:48:00+03	23200.00
AC20F9	2017-08-02 03:53:00+03	34600.00
AC210D	2017-07-29 04:09:00+03	69500.00
AC2111	2017-07-11 16:22:00+03	23200.00
AC2132	2017-07-12 09:47:00+03	6700.00
AC2160	2017-08-06 18:14:00+03	12600.00
AC219F	2017-07-03 10:23:00+03	17000.00
AC21AB	2017-07-24 02:17:00+03	96800.00
AC21D7	2017-07-28 08:11:00+03	28000.00
AC21DF	2017-07-27 07:45:00+03	40600.00
AC2224	2017-07-08 14:57:00+03	295200.00
AC2288	2017-07-17 05:09:00+03	58800.00
AC229E	2017-07-28 19:53:00+03	49200.00
AC22AA	2017-08-05 09:00:00+03	30400.00
AC22CB	2017-07-24 20:20:00+03	92000.00
AC22FB	2017-07-15 01:37:00+03	246000.00
AC2300	2017-07-10 18:58:00+03	44000.00
AC230C	2017-07-18 14:23:00+03	89600.00
AC2391	2017-07-21 06:58:00+03	18800.00
AC2405	2017-07-12 03:00:00+03	23400.00
AC2433	2017-08-01 02:10:00+03	20200.00
AC247F	2017-07-04 04:30:00+03	243600.00
AC2519	2017-07-27 23:13:00+03	60400.00
AC2521	2017-07-05 11:21:00+03	58200.00
AC2528	2017-06-29 16:04:00+03	77600.00
AC252C	2017-07-23 12:39:00+03	104400.00
AC257B	2017-07-10 06:19:00+03	14800.00
AC25E3	2017-07-31 19:44:00+03	170700.00
AC2611	2017-07-11 23:05:00+03	69500.00
AC265C	2017-08-14 12:25:00+03	25800.00
AC269D	2017-07-20 10:17:00+03	273400.00
AC271C	2017-07-19 08:06:00+03	13600.00
AC2750	2017-08-02 08:43:00+03	8000.00
AC2769	2017-08-06 19:38:00+03	66600.00
AC2780	2017-07-02 18:11:00+03	191500.00
AC27B1	2017-08-15 11:43:00+03	84100.00
AC27BB	2017-07-14 03:44:00+03	131600.00
AC2883	2017-08-14 06:38:00+03	24400.00
AC29B7	2017-07-19 20:18:00+03	70700.00
AC29D2	2017-07-13 09:35:00+03	21400.00
AC2A91	2017-08-13 15:34:00+03	29600.00
AC2ADC	2017-07-09 16:40:00+03	14000.00
AC2B38	2017-07-26 00:09:00+03	28800.00
AC2BA1	2017-07-15 18:37:00+03	270000.00
AC2BD4	2017-06-27 10:06:00+03	111600.00
AC2C7E	2017-07-19 04:11:00+03	13000.00
AC2C83	2017-07-08 14:41:00+03	95200.00
AC2D3D	2017-07-20 08:45:00+03	88800.00
AC2D40	2017-08-01 13:44:00+03	100600.00
AC2D49	2017-07-16 02:23:00+03	241400.00
AC2D4F	2017-07-01 13:14:00+03	16400.00
AC2E92	2017-07-07 14:09:00+03	40000.00
AC2EA0	2017-08-13 16:41:00+03	50600.00
AC2EF7	2017-08-14 12:25:00+03	29600.00
AC2EFE	2017-07-28 09:20:00+03	134400.00
AC2F2E	2017-08-07 07:31:00+03	56000.00
AC2FA7	2017-08-10 14:29:00+03	26200.00
AC2FAB	2017-06-29 16:05:00+03	24600.00
AC300D	2017-07-17 12:03:00+03	271100.00
AC3017	2017-07-16 23:05:00+03	85600.00
AC3091	2017-07-23 22:45:00+03	132800.00
AC30BB	2017-07-10 15:18:00+03	49100.00
AC30FB	2017-07-07 04:33:00+03	154100.00
AC3125	2017-08-02 05:24:00+03	28000.00
AC3187	2017-07-14 04:07:00+03	135200.00
AC31A8	2017-07-01 19:22:00+03	11300.00
AC31B5	2017-08-08 18:46:00+03	52100.00
AC31C3	2017-08-06 08:38:00+03	37600.00
AC31FB	2017-07-18 13:30:00+03	15400.00
AC3242	2017-08-05 02:11:00+03	28000.00
AC336D	2017-07-22 15:24:00+03	24400.00
AC3402	2017-07-17 09:21:00+03	44000.00
AC3470	2017-07-06 10:12:00+03	61700.00
AC34CF	2017-07-09 19:08:00+03	73500.00
AC34D1	2017-07-19 12:47:00+03	70800.00
AC356A	2017-07-06 08:00:00+03	96800.00
AC357F	2017-06-30 17:32:00+03	14000.00
AC358A	2017-08-12 04:28:00+03	14000.00
AC358D	2017-08-06 19:46:00+03	49000.00
AC35AB	2017-07-14 20:00:00+03	28000.00
AC35EE	2017-07-15 07:36:00+03	46400.00
AC362F	2017-07-25 04:34:00+03	90800.00
AC36BB	2017-07-08 00:31:00+03	12400.00
AC37A9	2017-07-09 01:12:00+03	58900.00
AC37CE	2017-07-28 14:49:00+03	23200.00
AC37E4	2017-08-11 16:58:00+03	38600.00
AC380A	2017-07-09 02:30:00+03	47000.00
AC384A	2017-07-06 09:20:00+03	343300.00
AC388F	2017-07-04 09:26:00+03	14300.00
AC38AB	2017-08-03 19:40:00+03	19600.00
AC38BD	2017-07-09 20:37:00+03	85000.00
AC38F2	2017-07-21 02:27:00+03	44800.00
AC3922	2017-07-11 22:10:00+03	19200.00
AC3957	2017-08-02 08:37:00+03	202200.00
AC3964	2017-07-11 06:20:00+03	133200.00
AC397C	2017-07-16 18:59:00+03	142700.00
AC3980	2017-07-05 02:36:00+03	56000.00
AC3983	2017-07-09 03:15:00+03	477500.00
AC39BF	2017-08-06 19:16:00+03	14400.00
AC3A03	2017-07-27 14:34:00+03	31100.00
AC3A10	2017-07-13 08:33:00+03	34100.00
AC3A44	2017-07-23 12:11:00+03	92900.00
AC3B2C	2017-08-09 16:34:00+03	22400.00
AC3B2E	2017-08-08 20:47:00+03	59800.00
AC3B3B	2017-07-21 11:00:00+03	26800.00
AC3B87	2017-08-06 13:01:00+03	66600.00
AC3B8A	2017-08-04 21:42:00+03	44600.00
AC3BBA	2017-08-13 17:37:00+03	20400.00
AC3C14	2017-08-09 19:18:00+03	21400.00
AC3CAB	2017-07-13 23:50:00+03	93000.00
AC3CE3	2017-07-09 19:14:00+03	73600.00
AC3D3F	2017-07-28 15:42:00+03	6300.00
AC3D44	2017-08-12 01:46:00+03	51400.00
AC3D47	2017-08-07 21:48:00+03	96300.00
AC3D73	2017-07-15 23:38:00+03	56100.00
AC3D93	2017-08-13 14:09:00+03	83200.00
AC3E6E	2017-07-22 13:10:00+03	56900.00
AC3EB1	2017-08-13 03:25:00+03	150000.00
AC3F0B	2017-08-08 12:20:00+03	132800.00
AC3F1E	2017-07-03 04:56:00+03	46400.00
AC4107	2017-07-22 11:05:00+03	50800.00
AC41A1	2017-07-14 23:16:00+03	147900.00
AC41F4	2017-08-02 05:15:00+03	32800.00
AC4204	2017-08-07 22:43:00+03	135400.00
AC4271	2017-07-19 14:15:00+03	7400.00
AC42C6	2017-08-07 10:33:00+03	75300.00
AC4324	2017-07-17 20:13:00+03	6400.00
AC4376	2017-08-07 07:47:00+03	92800.00
AC43B6	2017-08-06 20:19:00+03	131600.00
AC4431	2017-08-04 03:43:00+03	65900.00
AC4442	2017-07-04 22:04:00+03	94800.00
AC444F	2017-07-28 03:41:00+03	161600.00
AC4494	2017-08-04 15:54:00+03	47700.00
AC4526	2017-07-14 00:21:00+03	38400.00
AC4536	2017-07-25 10:53:00+03	27300.00
AC4541	2017-07-15 21:58:00+03	23200.00
AC45AD	2017-08-02 19:50:00+03	31800.00
AC45B1	2017-08-01 23:49:00+03	21200.00
AC45B4	2017-07-15 15:04:00+03	142800.00
AC45E8	2017-07-01 11:04:00+03	37900.00
AC4603	2017-08-02 17:55:00+03	49600.00
AC462F	2017-07-11 06:35:00+03	6000.00
AC464F	2017-07-05 23:04:00+03	57600.00
AC4681	2017-08-04 08:57:00+03	102100.00
AC468E	2017-07-26 23:25:00+03	181100.00
AC46A9	2017-07-08 12:10:00+03	150600.00
AC470E	2017-07-12 17:47:00+03	56000.00
AC47A3	2017-07-20 07:34:00+03	66800.00
AC47EE	2017-07-25 23:26:00+03	23600.00
AC4878	2017-07-26 07:39:00+03	66700.00
AC48A3	2017-07-12 08:24:00+03	53300.00
AC48C1	2017-07-06 16:48:00+03	77000.00
AC4929	2017-08-13 14:20:00+03	44800.00
AC492A	2017-08-02 03:26:00+03	91700.00
AC4A21	2017-07-17 06:43:00+03	39600.00
AC4A7A	2017-08-10 20:38:00+03	35700.00
AC4A9F	2017-08-04 22:14:00+03	53500.00
AC4AFD	2017-08-07 16:30:00+03	71900.00
AC4B2B	2017-07-19 21:07:00+03	65900.00
AC4B96	2017-07-29 03:03:00+03	40600.00
AC4C19	2017-07-15 02:47:00+03	119500.00
AC4C31	2017-06-30 08:09:00+03	10800.00
AC4C3A	2017-07-15 05:00:00+03	32800.00
AC4CE8	2017-08-03 05:59:00+03	28000.00
AC4CF3	2017-07-24 02:04:00+03	75600.00
AC4D01	2017-07-22 05:38:00+03	415100.00
AC4D45	2017-07-04 19:08:00+03	78000.00
AC4D62	2017-07-12 13:20:00+03	7400.00
AC4D7F	2017-08-02 01:57:00+03	28700.00
AC4D95	2017-07-26 02:55:00+03	15900.00
AC4DD2	2017-07-22 15:38:00+03	26800.00
AC4DDA	2017-08-13 16:20:00+03	28800.00
AC4E3A	2017-08-03 21:13:00+03	111600.00
AC4E49	2017-07-28 22:17:00+03	22600.00
AC4E91	2017-07-17 08:58:00+03	28800.00
AC4EFB	2017-07-05 16:35:00+03	62600.00
AC4F29	2017-07-11 09:53:00+03	31600.00
AC4F36	2017-07-19 14:02:00+03	25200.00
AC4F4D	2017-08-02 10:21:00+03	89100.00
AC4F52	2017-07-10 10:18:00+03	6700.00
AC4F7D	2017-08-15 17:37:00+03	298500.00
AC4F8C	2017-07-17 23:12:00+03	26000.00
AC4FAD	2017-07-31 23:39:00+03	22400.00
AC5032	2017-07-30 23:35:00+03	72400.00
AC503E	2017-07-03 19:31:00+03	40000.00
AC5076	2017-07-19 05:38:00+03	112000.00
AC5092	2017-07-28 02:15:00+03	54400.00
AC50CB	2017-07-05 15:44:00+03	55800.00
AC511F	2017-08-09 03:52:00+03	32200.00
AC518F	2017-07-11 02:20:00+03	144400.00
AC519B	2017-08-15 00:30:00+03	204200.00
AC51EE	2017-08-01 14:06:00+03	136100.00
AC523A	2017-07-25 15:07:00+03	16400.00
AC5262	2017-07-14 06:26:00+03	31000.00
AC52CD	2017-08-02 17:02:00+03	137600.00
AC52E2	2017-08-14 02:10:00+03	37900.00
AC52F6	2017-07-14 17:45:00+03	46400.00
AC52F9	2017-07-20 09:54:00+03	112000.00
AC530B	2017-08-01 19:41:00+03	81300.00
AC532A	2017-08-02 00:25:00+03	40400.00
AC532F	2017-08-10 07:57:00+03	25200.00
AC5340	2017-07-28 04:52:00+03	123000.00
AC5370	2017-07-25 22:15:00+03	37900.00
AC5376	2017-08-11 20:54:00+03	18400.00
AC53D4	2017-07-31 07:16:00+03	54500.00
AC540F	2017-08-14 16:49:00+03	236000.00
AC5438	2017-08-15 14:35:00+03	92900.00
AC5443	2017-08-04 18:46:00+03	135400.00
AC54BA	2017-07-23 15:52:00+03	6800.00
AC54DB	2017-07-29 14:28:00+03	90600.00
AC54F2	2017-07-23 21:53:00+03	246000.00
AC5503	2017-07-02 20:03:00+03	16800.00
AC5519	2017-07-06 08:39:00+03	265800.00
AC551D	2017-07-15 17:22:00+03	136800.00
AC558F	2017-07-26 13:23:00+03	64800.00
AC55A6	2017-08-13 11:53:00+03	78200.00
AC55AA	2017-06-29 15:18:00+03	279000.00
AC5630	2017-07-04 04:45:00+03	64600.00
AC563A	2017-07-22 05:00:00+03	38600.00
AC564A	2017-08-06 12:06:00+03	52300.00
AC565A	2017-07-07 14:57:00+03	32700.00
AC5692	2017-07-27 00:48:00+03	133100.00
AC56C1	2017-08-12 06:37:00+03	25600.00
AC56C5	2017-07-20 12:37:00+03	62600.00
AC56E7	2017-06-29 19:12:00+03	23600.00
AC5719	2017-07-15 23:04:00+03	219900.00
AC574C	2017-07-10 05:35:00+03	55800.00
AC5768	2017-07-09 21:00:00+03	124200.00
AC579E	2017-07-23 06:24:00+03	64800.00
AC57A6	2017-07-03 09:15:00+03	39100.00
AC5848	2017-07-22 22:04:00+03	54400.00
AC587F	2017-07-31 11:55:00+03	40800.00
AC58A2	2017-07-31 21:26:00+03	46400.00
AC58A5	2017-07-07 13:45:00+03	26000.00
AC58AE	2017-07-26 01:24:00+03	32200.00
AC58B8	2017-07-27 21:51:00+03	20200.00
AC5A1A	2017-08-12 01:37:00+03	223700.00
AC5A84	2017-07-07 06:51:00+03	47700.00
AC5A8C	2017-07-12 16:02:00+03	24000.00
AC5A98	2017-07-18 19:10:00+03	47100.00
AC5AA5	2017-07-15 13:30:00+03	35600.00
AC5AD5	2017-07-26 03:01:00+03	20400.00
AC5AE3	2017-08-05 06:14:00+03	41200.00
AC5B0D	2017-07-03 15:43:00+03	14400.00
AC5B21	2017-07-12 12:24:00+03	59600.00
AC5B34	2017-08-01 05:12:00+03	31400.00
AC5B7B	2017-07-28 00:14:00+03	12000.00
AC5B88	2017-07-22 08:47:00+03	19600.00
AC5B97	2017-06-27 03:43:00+03	26000.00
AC5BA8	2017-07-08 15:47:00+03	26000.00
AC5BDE	2017-08-06 13:16:00+03	55800.00
AC5BF6	2017-07-13 00:25:00+03	119700.00
AC5BF8	2017-07-26 19:10:00+03	58600.00
AC5C11	2017-07-03 09:31:00+03	6800.00
AC5C7C	2017-08-15 02:08:00+03	64600.00
AC5C7E	2017-08-14 22:58:00+03	66800.00
AC5D7D	2017-07-21 15:15:00+03	160000.00
AC5DA7	2017-07-04 22:05:00+03	68900.00
AC5DF1	2017-08-11 05:11:00+03	96100.00
AC5E0C	2017-07-04 00:59:00+03	51000.00
AC5E1D	2017-07-11 19:10:00+03	36800.00
AC5E49	2017-07-17 17:23:00+03	12600.00
AC5E7F	2017-06-29 19:53:00+03	129200.00
AC5F05	2017-07-30 20:33:00+03	306500.00
AC5F07	2017-07-19 13:33:00+03	55600.00
AC5F10	2017-08-01 22:44:00+03	13400.00
AC5F6C	2017-08-15 01:19:00+03	13800.00
AC5FA1	2017-08-04 05:22:00+03	87200.00
AC5FB8	2017-07-29 05:32:00+03	14000.00
AC6077	2017-07-25 09:40:00+03	155600.00
AC60D6	2017-08-07 20:24:00+03	180000.00
AC614D	2017-07-18 22:48:00+03	12600.00
AC617A	2017-08-07 21:05:00+03	20400.00
AC61C2	2017-08-12 00:29:00+03	84500.00
AC61FA	2017-07-18 19:05:00+03	26000.00
AC622E	2017-07-20 15:30:00+03	19800.00
AC624F	2017-07-17 11:14:00+03	28000.00
AC628A	2017-08-15 05:21:00+03	81700.00
AC62F6	2017-07-25 01:48:00+03	47000.00
AC630B	2017-07-12 20:43:00+03	135300.00
AC636B	2017-07-22 18:12:00+03	55800.00
AC63A8	2017-07-21 02:29:00+03	52800.00
AC63B3	2017-06-27 01:46:00+03	11600.00
AC63F9	2017-07-31 03:09:00+03	21500.00
AC6402	2017-07-05 23:03:00+03	65600.00
AC6403	2017-07-23 19:44:00+03	35600.00
AC6418	2017-07-18 16:12:00+03	52000.00
AC641E	2017-08-03 05:13:00+03	85000.00
AC6437	2017-08-03 21:31:00+03	21400.00
AC643D	2017-07-27 17:01:00+03	24500.00
AC6442	2017-07-05 00:15:00+03	48400.00
AC6461	2017-07-27 20:00:00+03	929900.00
AC64B2	2017-08-01 20:15:00+03	168700.00
AC6505	2017-08-12 22:53:00+03	21800.00
AC6554	2017-07-02 18:18:00+03	28000.00
AC6567	2017-07-06 19:51:00+03	14400.00
AC6587	2017-07-14 07:49:00+03	70200.00
AC65E7	2017-08-12 05:34:00+03	48400.00
AC6680	2017-07-23 11:51:00+03	69500.00
AC66BE	2017-08-01 10:24:00+03	43600.00
AC677C	2017-07-11 06:14:00+03	58000.00
AC67BA	2017-07-03 09:24:00+03	26000.00
AC67E3	2017-07-27 10:36:00+03	16800.00
AC67F6	2017-07-05 13:01:00+03	133200.00
AC6848	2017-07-04 18:38:00+03	135000.00
AC6904	2017-08-08 05:38:00+03	53400.00
AC691D	2017-07-25 03:45:00+03	199100.00
AC6925	2017-06-29 06:27:00+03	28000.00
AC692C	2017-07-14 18:06:00+03	20600.00
AC69D3	2017-08-06 22:54:00+03	42800.00
AC69E1	2017-07-15 07:01:00+03	21600.00
AC6A11	2017-07-18 09:35:00+03	136800.00
AC6A14	2017-07-05 00:46:00+03	51600.00
AC6ACF	2017-07-11 12:41:00+03	523000.00
AC6B02	2017-08-11 14:44:00+03	23200.00
AC6BA2	2017-08-10 16:07:00+03	40800.00
AC6BEB	2017-08-02 06:33:00+03	46700.00
AC6C21	2017-07-08 08:28:00+03	13600.00
AC6C62	2017-07-21 19:32:00+03	131100.00
AC6CBB	2017-07-24 20:54:00+03	169000.00
AC6D92	2017-07-29 18:20:00+03	24400.00
AC6E00	2017-08-10 09:23:00+03	54000.00
AC6E0A	2017-07-24 09:13:00+03	20000.00
AC6E19	2017-07-23 14:45:00+03	16400.00
AC6E60	2017-07-15 02:39:00+03	37200.00
AC6EB1	2017-07-28 05:14:00+03	46400.00
AC6EB2	2017-08-06 05:40:00+03	62900.00
AC6EC5	2017-07-12 07:47:00+03	121800.00
AC6ECF	2017-07-20 19:28:00+03	27400.00
AC6F14	2017-07-27 19:42:00+03	92800.00
AC6F5D	2017-08-10 11:39:00+03	53600.00
AC6F64	2017-08-11 07:18:00+03	24400.00
AC708B	2017-07-11 13:57:00+03	32800.00
AC70E6	2017-07-19 14:32:00+03	120000.00
AC714A	2017-07-22 04:41:00+03	42700.00
AC71A9	2017-08-03 01:36:00+03	68100.00
AC71C0	2017-08-14 04:07:00+03	113100.00
AC71C2	2017-07-14 05:58:00+03	151200.00
AC7216	2017-07-06 16:01:00+03	19600.00
AC7238	2017-07-25 12:18:00+03	56000.00
AC7242	2017-08-02 11:19:00+03	113100.00
AC7267	2017-07-12 17:11:00+03	52300.00
AC72CC	2017-06-30 10:55:00+03	55800.00
AC72EE	2017-07-18 16:42:00+03	156600.00
AC72F7	2017-07-03 21:37:00+03	70800.00
AC7317	2017-07-07 07:47:00+03	44000.00
AC733E	2017-07-16 18:11:00+03	28800.00
AC7343	2017-08-05 02:30:00+03	7400.00
AC7359	2017-07-15 14:32:00+03	25100.00
AC7384	2017-07-24 05:56:00+03	68400.00
AC73AF	2017-07-13 06:44:00+03	29600.00
AC73C9	2017-07-24 20:15:00+03	24600.00
AC73E6	2017-08-03 05:57:00+03	55800.00
AC7400	2017-07-19 15:18:00+03	168300.00
AC740B	2017-07-08 01:36:00+03	56000.00
AC7423	2017-07-18 04:53:00+03	56000.00
AC74A3	2017-07-30 05:28:00+03	14400.00
AC7505	2017-08-01 15:39:00+03	173500.00
AC757F	2017-08-05 13:36:00+03	139800.00
AC75E7	2017-07-11 21:13:00+03	42800.00
AC7639	2017-08-10 13:58:00+03	98400.00
AC7659	2017-08-02 21:04:00+03	48800.00
AC766A	2017-07-09 21:30:00+03	56000.00
AC7713	2017-07-09 00:34:00+03	28000.00
AC7755	2017-08-10 19:30:00+03	172300.00
AC777F	2017-08-11 16:12:00+03	27200.00
AC78E9	2017-08-05 16:39:00+03	28000.00
AC78F8	2017-07-11 13:14:00+03	22000.00
AC794B	2017-08-08 10:12:00+03	28000.00
AC7967	2017-07-18 18:27:00+03	59800.00
AC7980	2017-07-17 10:49:00+03	67700.00
AC7A15	2017-08-04 08:11:00+03	34100.00
AC7A1D	2017-07-28 17:36:00+03	81600.00
AC7A28	2017-07-07 14:53:00+03	80000.00
AC7A52	2017-07-20 05:34:00+03	124200.00
AC7A53	2017-07-11 04:08:00+03	71900.00
AC7A6F	2017-07-12 06:59:00+03	24400.00
AC7AA0	2017-07-30 19:58:00+03	131600.00
AC7AD2	2017-07-22 00:03:00+03	44400.00
AC7ADB	2017-07-21 13:59:00+03	47200.00
AC7B14	2017-07-08 23:42:00+03	27200.00
AC7B92	2017-08-02 01:02:00+03	67400.00
AC7B96	2017-08-10 20:16:00+03	15000.00
AC7C55	2017-07-14 05:53:00+03	39300.00
AC7C60	2017-07-22 03:38:00+03	60400.00
AC7D28	2017-07-14 19:46:00+03	97400.00
AC7D87	2017-08-10 11:00:00+03	56000.00
AC7E1F	2017-07-20 20:54:00+03	173500.00
AC7E35	2017-07-03 05:13:00+03	124200.00
AC7E62	2017-07-22 03:46:00+03	130900.00
AC7EB5	2017-07-01 08:10:00+03	6200.00
AC7ED8	2017-07-20 00:15:00+03	35200.00
AC7EED	2017-07-25 23:08:00+03	135600.00
AC7F06	2017-07-15 03:33:00+03	28000.00
AC7FE6	2017-08-03 12:34:00+03	21400.00
AC7FFE	2017-07-21 08:23:00+03	70600.00
AC8018	2017-08-14 05:18:00+03	171100.00
AC804B	2017-08-04 06:44:00+03	187600.00
AC806C	2017-07-19 23:28:00+03	42800.00
AC813D	2017-07-20 13:19:00+03	64600.00
AC815B	2017-07-15 15:38:00+03	115700.00
AC8160	2017-07-30 22:48:00+03	67200.00
AC81A3	2017-08-06 22:30:00+03	20800.00
AC81A5	2017-07-07 04:52:00+03	56100.00
AC8212	2017-08-11 11:31:00+03	127300.00
AC822D	2017-07-10 03:28:00+03	64800.00
AC8243	2017-07-31 04:09:00+03	142800.00
AC82DC	2017-08-05 07:49:00+03	38000.00
AC82F2	2017-07-21 01:43:00+03	173200.00
AC8334	2017-08-07 18:20:00+03	16000.00
AC83BA	2017-06-30 09:10:00+03	12600.00
AC83E0	2017-08-11 02:16:00+03	23200.00
AC83F7	2017-07-04 20:56:00+03	190200.00
AC8483	2017-08-08 16:34:00+03	20200.00
AC84E4	2017-08-02 11:52:00+03	73800.00
AC851A	2017-07-07 16:03:00+03	147700.00
AC8520	2017-07-04 04:03:00+03	21500.00
AC8570	2017-07-08 09:20:00+03	187600.00
AC85AD	2017-08-02 01:44:00+03	37900.00
AC85C1	2017-07-21 05:31:00+03	18600.00
AC8626	2017-08-06 23:33:00+03	32700.00
AC86A1	2017-07-27 06:15:00+03	78300.00
AC86D2	2017-07-21 15:01:00+03	51600.00
AC8723	2017-08-07 19:49:00+03	58900.00
AC8747	2017-07-02 07:10:00+03	131400.00
AC875A	2017-08-03 06:29:00+03	9200.00
AC877F	2017-07-11 09:25:00+03	15400.00
AC8790	2017-07-22 07:16:00+03	64700.00
AC879A	2017-07-05 19:45:00+03	101200.00
AC87C6	2017-07-11 18:56:00+03	81200.00
AC87EC	2017-08-08 03:12:00+03	102100.00
AC8853	2017-07-03 05:06:00+03	105000.00
AC8885	2017-07-25 21:52:00+03	15900.00
AC8950	2017-08-12 19:33:00+03	88100.00
AC8978	2017-07-29 22:25:00+03	28600.00
AC8A54	2017-07-01 22:44:00+03	13000.00
AC8A9A	2017-07-21 23:15:00+03	48800.00
AC8AAD	2017-07-22 16:03:00+03	109800.00
AC8AF1	2017-07-20 21:11:00+03	47200.00
AC8B01	2017-08-04 20:42:00+03	135600.00
AC8B02	2017-06-30 09:56:00+03	121400.00
AC8B1E	2017-07-31 05:26:00+03	44600.00
AC8B6A	2017-07-20 13:38:00+03	188700.00
AC8BC8	2017-07-27 09:07:00+03	24500.00
AC8D01	2017-06-28 12:32:00+03	67400.00
AC8D59	2017-08-13 00:25:00+03	65500.00
AC8D5D	2017-07-21 14:05:00+03	66600.00
AC8DB1	2017-08-08 02:45:00+03	132800.00
AC8DEF	2017-08-12 02:29:00+03	46500.00
AC8E07	2017-07-15 02:04:00+03	37700.00
AC8E68	2017-08-12 20:30:00+03	793000.00
AC8E6A	2017-08-02 20:33:00+03	53400.00
AC8E7E	2017-07-21 09:39:00+03	128800.00
AC8EA9	2017-07-20 12:27:00+03	55800.00
AC8EF0	2017-07-14 08:52:00+03	34000.00
AC8F31	2017-07-13 01:04:00+03	13600.00
AC8F35	2017-07-22 02:29:00+03	21800.00
AC8FA9	2017-07-19 19:45:00+03	49800.00
AC8FFE	2017-08-14 19:08:00+03	16400.00
AC904B	2017-07-12 18:28:00+03	44000.00
AC90A7	2017-07-25 16:22:00+03	136500.00
AC916A	2017-07-04 02:36:00+03	61800.00
AC91A0	2017-08-01 16:55:00+03	65900.00
AC9201	2017-07-13 10:20:00+03	44600.00
AC92AE	2017-07-08 08:53:00+03	40800.00
AC9320	2017-07-03 15:27:00+03	31900.00
AC932C	2017-07-14 23:45:00+03	93700.00
AC9353	2017-07-01 21:06:00+03	105400.00
AC93B2	2017-07-10 15:25:00+03	68800.00
AC93C5	2017-07-13 18:17:00+03	31600.00
AC93F3	2017-07-11 00:19:00+03	56000.00
AC93FD	2017-07-22 09:29:00+03	212000.00
AC945E	2017-08-06 14:49:00+03	272400.00
AC94A8	2017-07-02 16:30:00+03	16400.00
AC94E0	2017-08-03 22:33:00+03	55800.00
AC94E2	2017-07-07 04:01:00+03	405100.00
AC9522	2017-07-13 14:16:00+03	6000.00
AC95BE	2017-07-24 04:47:00+03	128800.00
AC95E2	2017-08-09 02:53:00+03	146300.00
AC9600	2017-08-05 01:29:00+03	23200.00
AC961E	2017-07-15 00:26:00+03	57400.00
AC969F	2017-08-09 16:38:00+03	100600.00
AC96AE	2017-08-03 07:32:00+03	25200.00
AC96BD	2017-07-19 20:54:00+03	71000.00
AC971D	2017-07-30 22:48:00+03	23200.00
AC9886	2017-07-12 07:05:00+03	59200.00
AC98A2	2017-06-28 03:34:00+03	46200.00
AC9902	2017-07-08 03:35:00+03	52000.00
AC9973	2017-07-13 01:20:00+03	80000.00
AC9991	2017-07-14 08:13:00+03	57100.00
AC9999	2017-07-25 04:37:00+03	106100.00
AC99A3	2017-08-14 22:36:00+03	67600.00
AC99AC	2017-07-31 19:31:00+03	55800.00
AC99BC	2017-07-29 12:06:00+03	199800.00
AC9A22	2017-08-07 12:49:00+03	113300.00
AC9A5E	2017-07-22 04:49:00+03	17000.00
AC9A72	2017-07-17 19:50:00+03	14000.00
AC9A97	2017-07-18 00:21:00+03	66600.00
AC9ABB	2017-07-26 07:53:00+03	16400.00
AC9AC9	2017-07-31 13:14:00+03	29600.00
AC9B00	2017-07-24 04:46:00+03	36800.00
AC9B07	2017-07-01 13:39:00+03	46000.00
AC9B4F	2017-06-30 03:19:00+03	123700.00
AC9BB3	2017-08-07 06:18:00+03	80400.00
AC9BBA	2017-07-03 14:29:00+03	52400.00
AC9C22	2017-08-08 14:13:00+03	44600.00
AC9C27	2017-08-14 11:10:00+03	62000.00
AC9CC4	2017-07-22 07:34:00+03	133200.00
AC9CC8	2017-07-09 08:02:00+03	88800.00
AC9DB5	2017-08-03 14:30:00+03	135600.00
AC9DF7	2017-07-24 01:45:00+03	271200.00
AC9DF8	2017-07-27 07:17:00+03	108000.00
AC9E4C	2017-07-01 17:58:00+03	83900.00
AC9E99	2017-07-08 14:40:00+03	288500.00
AC9EB4	2017-07-16 05:48:00+03	269300.00
AC9EEA	2017-07-14 09:23:00+03	170200.00
AC9EF3	2017-08-01 12:18:00+03	85000.00
AC9EFB	2017-08-14 16:05:00+03	132000.00
AC9FD8	2017-07-29 21:22:00+03	63400.00
AC9FDF	2017-07-02 13:20:00+03	231900.00
ACA031	2017-07-18 11:50:00+03	47000.00
ACA037	2017-07-21 00:31:00+03	28800.00
ACA0D9	2017-07-29 06:56:00+03	26000.00
ACA0FE	2017-08-09 12:59:00+03	48900.00
ACA156	2017-07-25 00:03:00+03	113000.00
ACA174	2017-08-10 21:10:00+03	14800.00
ACA18A	2017-08-15 03:05:00+03	46200.00
ACA194	2017-08-09 16:45:00+03	133700.00
ACA1D9	2017-08-08 03:03:00+03	236700.00
ACA1ED	2017-07-02 11:05:00+03	23200.00
ACA2B9	2017-08-03 09:11:00+03	88000.00
ACA2BF	2017-08-06 21:36:00+03	124300.00
ACA325	2017-07-04 20:00:00+03	48500.00
ACA32B	2017-07-17 21:55:00+03	27200.00
ACA345	2017-07-18 16:06:00+03	87000.00
ACA34E	2017-07-01 02:39:00+03	43200.00
ACA422	2017-07-22 16:49:00+03	37700.00
ACA427	2017-07-25 09:36:00+03	103700.00
ACA45D	2017-07-12 01:11:00+03	102100.00
ACA4DA	2017-07-10 12:56:00+03	58600.00
ACA4EB	2017-08-15 05:31:00+03	14400.00
ACA4FF	2017-07-28 12:23:00+03	22000.00
ACA555	2017-07-10 05:23:00+03	14000.00
ACA583	2017-08-12 11:06:00+03	7400.00
ACA58F	2017-08-01 15:07:00+03	58800.00
ACA5A7	2017-07-20 23:23:00+03	90800.00
ACA5A9	2017-07-26 20:50:00+03	133100.00
ACA5B9	2017-07-01 11:48:00+03	56000.00
ACA5D0	2017-07-17 17:17:00+03	50700.00
ACA672	2017-08-10 06:42:00+03	106400.00
ACA69A	2017-07-17 01:04:00+03	50600.00
ACA6AD	2017-07-01 04:41:00+03	76000.00
ACA6F8	2017-07-15 06:59:00+03	81900.00
ACA76D	2017-07-09 19:50:00+03	17600.00
ACA83C	2017-08-10 23:13:00+03	117600.00
ACA877	2017-08-10 20:34:00+03	7400.00
ACA8D2	2017-07-17 21:16:00+03	174900.00
ACA943	2017-07-07 06:03:00+03	92800.00
ACA94F	2017-07-07 12:22:00+03	62200.00
ACA9AB	2017-07-08 17:43:00+03	58000.00
ACA9CC	2017-07-01 20:00:00+03	103500.00
ACA9EE	2017-08-12 08:59:00+03	192000.00
ACA9F6	2017-07-26 02:35:00+03	174700.00
ACAA29	2017-07-16 18:27:00+03	137600.00
ACAA61	2017-06-29 04:25:00+03	123000.00
ACAA68	2017-07-25 12:38:00+03	55800.00
ACAA93	2017-07-10 18:36:00+03	20500.00
ACAACD	2017-07-19 09:16:00+03	25400.00
ACAAD8	2017-07-08 15:02:00+03	28000.00
ACAB0D	2017-08-13 01:26:00+03	54800.00
ACAB4E	2017-08-14 20:38:00+03	116800.00
ACAC2D	2017-07-31 02:35:00+03	59800.00
ACAC7A	2017-07-19 22:44:00+03	14800.00
ACACE5	2017-07-08 20:51:00+03	177200.00
ACAD24	2017-08-12 06:41:00+03	74000.00
ACAD45	2017-08-02 01:44:00+03	74400.00
ACAD46	2017-07-05 05:24:00+03	119400.00
ACADC9	2017-07-21 07:00:00+03	28000.00
ACADF2	2017-08-03 06:06:00+03	13000.00
ACAE4A	2017-07-17 03:43:00+03	59200.00
ACAE66	2017-07-06 10:42:00+03	20600.00
ACAE82	2017-07-12 11:05:00+03	410200.00
ACAEB2	2017-07-13 11:22:00+03	55800.00
ACAEDA	2017-08-13 02:45:00+03	71200.00
ACAFAD	2017-07-29 04:20:00+03	81600.00
ACB004	2017-07-11 22:16:00+03	92800.00
ACB048	2017-08-06 23:34:00+03	62000.00
ACB0D7	2017-08-13 13:06:00+03	28000.00
ACB105	2017-07-15 03:20:00+03	272300.00
ACB156	2017-08-02 08:26:00+03	11600.00
ACB17F	2017-07-27 17:54:00+03	69000.00
ACB222	2017-07-29 13:40:00+03	12600.00
ACB224	2017-07-27 06:10:00+03	29400.00
ACB255	2017-08-01 02:03:00+03	85700.00
ACB284	2017-08-12 18:31:00+03	75600.00
ACB289	2017-08-05 05:36:00+03	108300.00
ACB2BC	2017-07-17 15:10:00+03	179300.00
ACB300	2017-07-02 22:48:00+03	27200.00
ACB34E	2017-08-02 15:51:00+03	43400.00
ACB3AA	2017-07-08 11:16:00+03	59600.00
ACB3C6	2017-07-15 05:25:00+03	46800.00
ACB3D6	2017-08-06 06:52:00+03	99200.00
ACB411	2017-08-12 01:56:00+03	128800.00
ACB416	2017-07-24 01:42:00+03	111600.00
ACB493	2017-07-22 00:00:00+03	111300.00
ACB4B1	2017-08-12 12:56:00+03	186900.00
ACB4C6	2017-07-29 11:28:00+03	86800.00
ACB4F8	2017-07-03 19:41:00+03	39800.00
ACB4FA	2017-07-27 12:37:00+03	37000.00
ACB53E	2017-07-17 18:25:00+03	52300.00
ACB579	2017-07-17 20:03:00+03	92800.00
ACB5AA	2017-07-12 09:35:00+03	28800.00
ACB5BF	2017-07-12 04:22:00+03	68800.00
ACB5FB	2017-07-19 08:03:00+03	17000.00
ACB614	2017-07-30 09:00:00+03	65900.00
ACB6E2	2017-07-06 00:09:00+03	7200.00
ACB747	2017-08-06 13:46:00+03	32400.00
ACB78A	2017-07-25 03:32:00+03	14400.00
ACB7AD	2017-08-07 17:56:00+03	49400.00
ACB820	2017-07-13 15:24:00+03	71700.00
ACB876	2017-07-29 21:43:00+03	99200.00
ACB88A	2017-07-17 22:19:00+03	48800.00
ACB8B4	2017-08-10 20:50:00+03	31600.00
ACB8C8	2017-07-23 17:02:00+03	40600.00
ACB8D0	2017-07-11 06:06:00+03	26800.00
ACB919	2017-08-06 20:41:00+03	26200.00
ACB93C	2017-07-16 16:07:00+03	26200.00
ACBA3D	2017-08-10 16:15:00+03	32800.00
ACBA91	2017-07-19 04:00:00+03	19800.00
ACBAA0	2017-07-23 13:40:00+03	133200.00
ACBACA	2017-07-29 10:05:00+03	184300.00
ACBAD4	2017-07-12 21:18:00+03	117000.00
ACBAEF	2017-07-03 05:32:00+03	246000.00
ACBBF9	2017-07-15 07:15:00+03	166100.00
ACBC43	2017-08-14 22:36:00+03	37700.00
ACBCC9	2017-07-31 23:11:00+03	13600.00
ACBD01	2017-08-13 19:49:00+03	95700.00
ACBD28	2017-07-17 05:43:00+03	26000.00
ACBD43	2017-08-08 21:19:00+03	22000.00
ACBD5F	2017-08-03 00:39:00+03	55700.00
ACBD7C	2017-07-26 17:55:00+03	229900.00
ACBD96	2017-08-14 15:07:00+03	37900.00
ACBD98	2017-08-08 18:33:00+03	38400.00
ACBDD7	2017-08-06 15:56:00+03	135600.00
ACBE5F	2017-08-11 13:22:00+03	91600.00
ACBEF5	2017-07-16 04:00:00+03	28000.00
ACBF18	2017-08-14 16:24:00+03	46300.00
ACBF28	2017-08-12 01:01:00+03	70400.00
ACBF45	2017-08-01 22:57:00+03	14400.00
ACBFAE	2017-08-10 22:42:00+03	88000.00
ACBFF3	2017-07-20 21:58:00+03	91800.00
ACC007	2017-08-11 09:59:00+03	119500.00
ACC011	2017-07-12 09:58:00+03	48600.00
ACC073	2017-08-09 11:59:00+03	26000.00
ACC0A7	2017-07-02 17:20:00+03	31000.00
ACC103	2017-07-07 23:29:00+03	56900.00
ACC12E	2017-08-12 22:30:00+03	168000.00
ACC194	2017-07-22 09:47:00+03	15400.00
ACC1D1	2017-08-04 23:12:00+03	28800.00
ACC1F3	2017-07-13 09:34:00+03	47100.00
ACC30B	2017-07-24 22:01:00+03	33300.00
ACC330	2017-07-09 06:50:00+03	273500.00
ACC35B	2017-07-25 14:53:00+03	92000.00
ACC3B0	2017-07-18 02:59:00+03	139400.00
ACC440	2017-08-05 22:09:00+03	24200.00
ACC446	2017-07-08 15:18:00+03	193600.00
ACC4DA	2017-07-16 23:19:00+03	176300.00
ACC507	2017-07-02 01:20:00+03	45600.00
ACC54C	2017-07-10 23:52:00+03	23200.00
ACC5DC	2017-07-24 06:57:00+03	99200.00
ACC65D	2017-08-14 16:12:00+03	25300.00
ACC667	2017-07-28 05:26:00+03	47600.00
ACC6A4	2017-07-24 05:43:00+03	12600.00
ACC6AD	2017-07-28 14:33:00+03	52400.00
ACC70C	2017-07-10 22:03:00+03	24000.00
ACC747	2017-08-01 20:26:00+03	66600.00
ACC7A3	2017-07-27 18:22:00+03	229900.00
ACC7D7	2017-08-01 11:30:00+03	124200.00
ACC821	2017-07-20 13:38:00+03	33800.00
ACC8B9	2017-07-06 09:36:00+03	140900.00
ACC905	2017-07-19 10:39:00+03	67600.00
ACC931	2017-07-15 12:08:00+03	270000.00
ACC980	2017-07-24 05:19:00+03	26600.00
ACC995	2017-08-11 08:32:00+03	53500.00
ACC9F7	2017-08-05 09:56:00+03	61500.00
ACCA92	2017-08-03 15:48:00+03	6200.00
ACCB28	2017-07-31 06:37:00+03	23600.00
ACCB29	2017-07-28 15:59:00+03	149300.00
ACCB9F	2017-08-11 11:16:00+03	92900.00
ACCBA0	2017-07-17 20:44:00+03	85000.00
ACCC62	2017-07-09 14:43:00+03	133200.00
ACCCBA	2017-07-11 04:24:00+03	6000.00
ACCD0F	2017-07-29 15:24:00+03	112600.00
ACCD88	2017-07-20 09:17:00+03	130100.00
ACCE28	2017-07-11 23:46:00+03	93900.00
ACCE49	2017-07-23 09:37:00+03	61800.00
ACCE4F	2017-08-01 07:10:00+03	135400.00
ACCF08	2017-08-05 05:28:00+03	16400.00
ACCF58	2017-07-26 16:24:00+03	24400.00
ACCF68	2017-07-29 23:21:00+03	412300.00
ACCF98	2017-08-06 06:27:00+03	34200.00
ACCFD7	2017-07-30 20:44:00+03	67600.00
ACCFE0	2017-07-30 12:49:00+03	92100.00
ACD00A	2017-07-18 05:22:00+03	27400.00
ACD085	2017-08-14 15:20:00+03	188000.00
ACD0E3	2017-07-13 19:35:00+03	37900.00
ACD14A	2017-07-11 00:53:00+03	41600.00
ACD1AD	2017-07-18 07:20:00+03	198300.00
ACD1BE	2017-07-08 14:58:00+03	49200.00
ACD247	2017-07-27 23:13:00+03	270800.00
ACD254	2017-06-26 11:26:00+03	6800.00
ACD26A	2017-06-30 02:24:00+03	36200.00
ACD337	2017-07-27 10:34:00+03	44600.00
ACD338	2017-07-20 05:05:00+03	49300.00
ACD339	2017-08-11 21:57:00+03	39300.00
ACD382	2017-07-23 14:41:00+03	56000.00
ACD3C4	2017-08-07 06:34:00+03	19600.00
ACD3C8	2017-07-28 10:56:00+03	52800.00
ACD439	2017-07-09 21:46:00+03	6700.00
ACD496	2017-07-30 17:17:00+03	23200.00
ACD51A	2017-07-21 23:07:00+03	6000.00
ACD5BF	2017-07-16 10:34:00+03	12000.00
ACD72F	2017-07-15 13:36:00+03	47400.00
ACD75D	2017-07-22 06:17:00+03	12000.00
ACD7B2	2017-07-09 03:59:00+03	39300.00
ACD808	2017-07-03 05:38:00+03	20900.00
ACD888	2017-08-06 05:08:00+03	96400.00
ACD899	2017-06-27 08:03:00+03	6000.00
ACD8AA	2017-06-27 02:10:00+03	21200.00
ACD922	2017-08-05 18:25:00+03	88400.00
ACD92B	2017-07-17 15:55:00+03	36000.00
ACD961	2017-07-08 05:04:00+03	91100.00
ACD989	2017-07-05 19:55:00+03	30200.00
ACD98C	2017-07-10 06:56:00+03	46400.00
ACD9B6	2017-07-14 23:52:00+03	18800.00
ACDA01	2017-07-16 04:27:00+03	6300.00
ACDA43	2017-07-13 23:23:00+03	28200.00
ACDA60	2017-07-13 14:36:00+03	606200.00
ACDA68	2017-07-13 10:26:00+03	136200.00
ACDAAD	2017-07-27 11:47:00+03	46400.00
ACDADB	2017-08-07 11:03:00+03	8000.00
ACDB37	2017-06-25 10:09:00+03	125400.00
ACDB4A	2017-07-25 23:47:00+03	23100.00
ACDB69	2017-07-22 14:27:00+03	57400.00
ACDB6D	2017-07-07 13:03:00+03	57600.00
ACDB83	2017-07-19 17:10:00+03	88000.00
ACDB93	2017-08-02 10:49:00+03	289800.00
ACDC3E	2017-07-21 03:23:00+03	22000.00
ACDC3F	2017-07-24 05:02:00+03	114600.00
ACDC6C	2017-07-05 18:00:00+03	12400.00
ACDCA8	2017-08-12 21:57:00+03	32800.00
ACDD06	2017-08-08 08:45:00+03	47000.00
ACDD0F	2017-07-09 22:01:00+03	119600.00
ACDD32	2017-08-12 04:34:00+03	37900.00
ACDD55	2017-07-27 10:32:00+03	136200.00
ACDD64	2017-06-27 01:37:00+03	40200.00
ACDD7C	2017-07-18 17:40:00+03	188000.00
ACDD91	2017-07-23 15:59:00+03	40000.00
ACDDA7	2017-07-04 02:00:00+03	44600.00
ACDDC7	2017-08-14 08:09:00+03	58200.00
ACDDF7	2017-07-26 09:46:00+03	50000.00
ACDE5A	2017-08-15 03:10:00+03	21400.00
ACDE9E	2017-07-12 15:33:00+03	254600.00
ACDEAF	2017-07-22 13:14:00+03	207200.00
ACDEF5	2017-07-12 03:00:00+03	30000.00
ACDF03	2017-08-12 09:24:00+03	147500.00
ACDF07	2017-08-15 14:51:00+03	24400.00
ACDF08	2017-07-05 11:59:00+03	6000.00
ACDF0A	2017-07-15 23:36:00+03	37900.00
ACDFB9	2017-07-22 19:38:00+03	56000.00
ACE097	2017-07-09 18:21:00+03	42800.00
ACE11E	2017-06-27 18:42:00+03	384400.00
ACE153	2017-08-13 14:40:00+03	6800.00
ACE156	2017-07-09 01:08:00+03	65900.00
ACE1DB	2017-07-13 08:48:00+03	41500.00
ACE1E0	2017-07-29 09:26:00+03	119600.00
ACE216	2017-07-31 17:58:00+03	31400.00
ACE257	2017-08-06 07:26:00+03	28000.00
ACE290	2017-08-01 14:19:00+03	59700.00
ACE298	2017-07-28 14:26:00+03	21800.00
ACE299	2017-07-02 12:56:00+03	38500.00
ACE2F9	2017-07-17 10:03:00+03	100600.00
ACE35F	2017-07-15 13:03:00+03	79600.00
ACE360	2017-07-14 05:26:00+03	139100.00
ACE3CE	2017-07-31 04:53:00+03	280900.00
ACE3D1	2017-07-08 12:44:00+03	99200.00
ACE43D	2017-07-24 12:30:00+03	67700.00
ACE478	2017-07-25 03:39:00+03	155600.00
ACE49D	2017-07-23 08:57:00+03	131900.00
ACE584	2017-07-26 12:35:00+03	66000.00
ACE58D	2017-07-05 23:34:00+03	100600.00
ACE593	2017-08-14 09:42:00+03	136200.00
ACE5A9	2017-07-30 05:06:00+03	92400.00
ACE5C0	2017-07-17 10:59:00+03	27900.00
ACE5D4	2017-07-25 17:07:00+03	16400.00
ACE5F0	2017-07-26 16:57:00+03	144400.00
ACE605	2017-08-15 01:06:00+03	13400.00
ACE61C	2017-07-28 01:14:00+03	102000.00
ACE698	2017-07-14 10:27:00+03	19800.00
ACE742	2017-08-13 04:14:00+03	89700.00
ACE765	2017-07-17 03:56:00+03	131600.00
ACE786	2017-07-17 02:21:00+03	24200.00
ACE799	2017-08-10 08:12:00+03	24400.00
ACE7B0	2017-08-09 20:56:00+03	50700.00
ACE86B	2017-07-08 06:38:00+03	58700.00
ACE8A4	2017-07-21 09:03:00+03	30200.00
ACE8AF	2017-08-08 10:45:00+03	29600.00
ACE8C8	2017-08-03 09:11:00+03	66100.00
ACE8F3	2017-08-04 06:11:00+03	132800.00
ACE966	2017-07-21 04:09:00+03	6700.00
ACEA02	2017-07-28 04:14:00+03	110000.00
ACEAE7	2017-07-11 10:59:00+03	71200.00
ACEB28	2017-07-14 12:10:00+03	20500.00
ACEB2D	2017-08-15 10:18:00+03	23600.00
ACEB5C	2017-07-15 04:29:00+03	265700.00
ACEBA3	2017-07-14 15:16:00+03	52900.00
ACEBBA	2017-08-01 22:35:00+03	56100.00
ACEC1B	2017-07-30 04:28:00+03	63300.00
ACED1F	2017-08-14 07:26:00+03	372600.00
ACED2C	2017-08-15 14:40:00+03	68100.00
ACED62	2017-08-01 04:36:00+03	14000.00
ACEDE2	2017-07-24 02:16:00+03	23900.00
ACEDE8	2017-07-22 20:31:00+03	30300.00
ACEDF4	2017-08-06 02:58:00+03	53600.00
ACEE2D	2017-08-03 20:22:00+03	14000.00
ACEEC5	2017-08-03 14:21:00+03	222000.00
ACEF00	2017-08-06 16:09:00+03	136500.00
ACEF23	2017-07-24 16:45:00+03	19800.00
ACEFAE	2017-07-05 02:56:00+03	36200.00
ACF0C8	2017-07-22 04:32:00+03	39200.00
ACF0E9	2017-07-20 20:19:00+03	21400.00
ACF11F	2017-08-15 00:50:00+03	277900.00
ACF12A	2017-08-02 09:10:00+03	107700.00
ACF1A8	2017-07-20 01:14:00+03	124200.00
ACF1A9	2017-08-04 17:54:00+03	58000.00
ACF228	2017-07-25 10:38:00+03	273600.00
ACF24D	2017-07-21 20:31:00+03	27900.00
ACF2B7	2017-08-06 16:21:00+03	11700.00
ACF2CD	2017-07-12 14:04:00+03	61800.00
ACF2DC	2017-08-08 10:02:00+03	86500.00
ACF2E3	2017-08-11 03:28:00+03	101900.00
ACF331	2017-07-23 19:49:00+03	32900.00
ACF348	2017-07-13 15:42:00+03	56600.00
ACF36A	2017-07-23 13:59:00+03	69500.00
ACF384	2017-08-04 13:57:00+03	28000.00
ACF4A3	2017-08-10 14:12:00+03	68900.00
ACF4C0	2017-08-04 22:22:00+03	6700.00
ACF4D1	2017-07-19 13:04:00+03	67000.00
ACF4E9	2017-07-19 05:28:00+03	212500.00
ACF58E	2017-07-27 21:23:00+03	64700.00
ACF598	2017-07-04 20:19:00+03	70100.00
ACF5D1	2017-07-13 09:52:00+03	11100.00
ACF5F5	2017-07-04 13:49:00+03	15100.00
ACF627	2017-07-21 16:28:00+03	26000.00
ACF6CE	2017-08-07 08:02:00+03	42900.00
ACF6E3	2017-08-06 06:17:00+03	25000.00
ACF73E	2017-07-17 10:18:00+03	101200.00
ACF79F	2017-07-09 09:51:00+03	135400.00
ACF7C0	2017-07-11 13:25:00+03	243300.00
ACF7E4	2017-07-10 21:00:00+03	8800.00
ACF807	2017-07-17 21:36:00+03	65200.00
ACF818	2017-08-03 20:31:00+03	68800.00
ACF820	2017-08-10 07:31:00+03	6000.00
ACF879	2017-07-24 23:53:00+03	84800.00
ACF8C9	2017-07-04 16:23:00+03	147400.00
ACF8F3	2017-08-06 06:20:00+03	103500.00
ACF9D6	2017-07-08 10:21:00+03	36200.00
ACFA3B	2017-07-25 11:10:00+03	14400.00
ACFAD3	2017-07-27 19:57:00+03	26700.00
ACFB1A	2017-07-16 11:51:00+03	75300.00
ACFBA1	2017-07-20 02:08:00+03	40200.00
ACFBC5	2017-07-18 05:05:00+03	58300.00
ACFBCC	2017-08-14 19:16:00+03	51600.00
ACFBDE	2017-07-12 22:35:00+03	8400.00
ACFC24	2017-07-31 14:39:00+03	58600.00
ACFCA7	2017-08-15 15:32:00+03	30200.00
ACFD19	2017-07-22 11:12:00+03	128800.00
ACFD71	2017-07-02 07:58:00+03	28700.00
ACFDB6	2017-07-10 14:25:00+03	55800.00
ACFE3A	2017-07-27 00:59:00+03	24400.00
ACFEC7	2017-08-07 07:17:00+03	58000.00
ACFECC	2017-08-01 07:20:00+03	31600.00
ACFF74	2017-08-05 12:29:00+03	60900.00
ACFFB8	2017-07-24 19:03:00+03	64700.00
ACFFD7	2017-07-11 15:25:00+03	40800.00
AD0002	2017-07-24 10:03:00+03	297600.00
AD0017	2017-08-07 21:59:00+03	34000.00
AD003E	2017-07-19 14:34:00+03	28000.00
AD0065	2017-07-17 21:43:00+03	61400.00
AD0077	2017-08-14 07:53:00+03	19600.00
AD008F	2017-07-06 11:16:00+03	8600.00
AD009E	2017-07-17 02:49:00+03	11600.00
AD00A6	2017-07-15 05:30:00+03	87100.00
AD00AF	2017-08-08 22:50:00+03	70600.00
AD00E4	2017-07-25 04:49:00+03	23200.00
AD013A	2017-08-04 09:02:00+03	98400.00
AD0156	2017-07-05 11:02:00+03	57600.00
AD017F	2017-07-25 10:26:00+03	36400.00
AD01C7	2017-08-10 08:18:00+03	52000.00
AD027A	2017-08-02 03:38:00+03	47500.00
AD038E	2017-08-08 10:26:00+03	123000.00
AD03B7	2017-07-06 16:34:00+03	14000.00
AD0438	2017-08-14 08:29:00+03	16400.00
AD0503	2017-08-12 20:11:00+03	88700.00
AD050A	2017-08-10 05:46:00+03	46400.00
AD051B	2017-07-23 03:55:00+03	28800.00
AD0645	2017-08-04 08:06:00+03	422700.00
AD066C	2017-07-24 10:16:00+03	73900.00
AD068D	2017-08-01 03:43:00+03	28000.00
AD06CA	2017-07-30 11:57:00+03	28000.00
AD06EB	2017-07-25 01:51:00+03	58800.00
AD0740	2017-07-19 22:42:00+03	23600.00
AD075F	2017-07-17 05:24:00+03	27200.00
AD0771	2017-07-14 12:36:00+03	40300.00
AD078C	2017-07-27 11:18:00+03	81200.00
AD0795	2017-07-26 22:06:00+03	457800.00
AD07DF	2017-07-07 22:23:00+03	129000.00
AD07E8	2017-08-12 06:56:00+03	479600.00
AD07EC	2017-07-18 21:43:00+03	14000.00
AD0836	2017-07-25 15:25:00+03	23100.00
AD085B	2017-07-29 06:56:00+03	79600.00
AD08BA	2017-08-10 04:23:00+03	119500.00
AD08EE	2017-08-07 03:26:00+03	151200.00
AD08F1	2017-07-25 05:04:00+03	26000.00
AD08F9	2017-07-18 11:20:00+03	73200.00
AD0922	2017-08-09 08:48:00+03	199700.00
AD0939	2017-08-09 09:49:00+03	56000.00
AD093E	2017-08-10 03:55:00+03	43200.00
AD094A	2017-08-14 19:28:00+03	496700.00
AD0980	2017-07-16 20:52:00+03	135400.00
AD09DA	2017-07-18 07:01:00+03	23400.00
AD0A21	2017-07-28 01:52:00+03	122600.00
AD0A81	2017-07-16 12:04:00+03	179400.00
AD0B33	2017-07-24 09:57:00+03	75200.00
AD0B93	2017-08-01 22:31:00+03	47400.00
AD0BB3	2017-07-26 14:31:00+03	37900.00
AD0BC4	2017-07-07 17:17:00+03	28000.00
AD0BCC	2017-08-13 20:55:00+03	54000.00
AD0BEC	2017-07-11 00:01:00+03	76600.00
AD0BF6	2017-08-15 12:39:00+03	64700.00
AD0C37	2017-08-09 13:54:00+03	111600.00
AD0CF8	2017-08-14 04:41:00+03	61500.00
AD0D00	2017-07-22 08:00:00+03	266200.00
AD0D06	2017-07-11 14:54:00+03	46400.00
AD0D21	2017-07-04 13:43:00+03	25000.00
AD0D4A	2017-07-18 22:23:00+03	14000.00
AD0D4B	2017-07-01 05:19:00+03	66800.00
AD0DC6	2017-07-22 07:51:00+03	45800.00
AD0DF8	2017-07-29 14:32:00+03	56000.00
AD0EF8	2017-07-22 07:00:00+03	6300.00
AD0EFC	2017-08-02 06:51:00+03	29600.00
AD0F85	2017-07-15 03:05:00+03	28800.00
AD0FDF	2017-08-09 02:26:00+03	203500.00
AD102E	2017-08-11 08:18:00+03	42100.00
AD1056	2017-07-23 07:07:00+03	83600.00
AD1075	2017-07-18 18:03:00+03	19600.00
AD1080	2017-07-11 17:36:00+03	13800.00
AD1097	2017-07-31 01:58:00+03	195000.00
AD10BF	2017-08-01 07:09:00+03	23200.00
AD10E3	2017-08-13 13:48:00+03	40000.00
AD1101	2017-07-06 01:32:00+03	56000.00
AD117E	2017-07-24 11:33:00+03	87400.00
AD119E	2017-07-05 15:21:00+03	120800.00
AD11D1	2017-07-06 23:42:00+03	99300.00
AD11E4	2017-07-26 11:47:00+03	47200.00
AD11F1	2017-07-04 11:16:00+03	23200.00
AD11F7	2017-07-08 09:01:00+03	248300.00
AD121C	2017-08-04 01:33:00+03	12600.00
AD12C8	2017-07-15 01:20:00+03	46800.00
AD12F7	2017-08-14 02:47:00+03	30400.00
AD1313	2017-07-15 19:45:00+03	31400.00
AD1331	2017-07-16 17:48:00+03	31600.00
AD1386	2017-07-10 11:22:00+03	81300.00
AD13C6	2017-07-22 21:57:00+03	86400.00
AD148E	2017-08-09 07:04:00+03	61800.00
AD149F	2017-08-08 05:50:00+03	36200.00
AD14DE	2017-07-31 11:27:00+03	28000.00
AD1509	2017-07-08 13:27:00+03	90400.00
AD150B	2017-06-29 10:12:00+03	36000.00
AD1541	2017-07-31 06:37:00+03	40000.00
AD1560	2017-08-04 01:03:00+03	92100.00
AD1583	2017-08-03 08:53:00+03	117200.00
AD15D5	2017-08-07 21:34:00+03	90700.00
AD1612	2017-08-09 03:23:00+03	54000.00
AD1655	2017-07-07 03:35:00+03	23200.00
AD1684	2017-07-13 02:40:00+03	120900.00
AD1688	2017-07-14 18:45:00+03	119000.00
AD16B1	2017-07-06 04:17:00+03	65900.00
AD171E	2017-07-11 04:51:00+03	12600.00
AD1732	2017-07-04 19:47:00+03	14400.00
AD1769	2017-07-30 20:42:00+03	52600.00
AD17C8	2017-06-29 15:44:00+03	66000.00
AD186A	2017-07-26 18:59:00+03	55800.00
AD18F1	2017-06-29 07:42:00+03	55800.00
AD1930	2017-07-06 06:37:00+03	3400.00
AD1A13	2017-07-24 06:26:00+03	40600.00
AD1A42	2017-07-13 16:25:00+03	58800.00
AD1A92	2017-07-24 23:17:00+03	38800.00
AD1A94	2017-07-14 19:06:00+03	26000.00
AD1AAD	2017-06-30 06:08:00+03	106400.00
AD1ABE	2017-08-14 03:03:00+03	26700.00
AD1AC5	2017-08-06 08:14:00+03	95900.00
AD1B1D	2017-07-12 08:14:00+03	65500.00
AD1B21	2017-07-31 21:30:00+03	175200.00
AD1B9A	2017-07-09 03:16:00+03	101200.00
AD1BC8	2017-07-05 15:54:00+03	145300.00
AD1BC9	2017-08-07 12:12:00+03	6000.00
AD1C2F	2017-07-29 14:18:00+03	78800.00
AD1C6D	2017-07-30 16:53:00+03	28300.00
AD1C8E	2017-07-17 16:15:00+03	26200.00
AD1D04	2017-07-07 08:10:00+03	29600.00
AD1D08	2017-07-28 00:21:00+03	98200.00
AD1D65	2017-06-26 21:11:00+03	27200.00
AD1DB3	2017-08-04 10:22:00+03	65200.00
AD1DCC	2017-07-08 20:45:00+03	137700.00
AD1DCE	2017-08-15 02:53:00+03	32400.00
AD1E50	2017-07-09 22:49:00+03	63200.00
AD1E76	2017-07-16 16:30:00+03	46400.00
AD1F02	2017-07-03 19:34:00+03	66800.00
AD209F	2017-08-13 06:13:00+03	39800.00
AD20F9	2017-08-13 03:19:00+03	28000.00
AD2160	2017-07-03 09:05:00+03	31400.00
AD21A6	2017-07-30 06:15:00+03	112000.00
AD21CF	2017-07-10 04:15:00+03	131800.00
AD228F	2017-07-26 11:51:00+03	149300.00
AD2303	2017-07-17 14:21:00+03	49400.00
AD2340	2017-07-19 17:43:00+03	36200.00
AD235B	2017-08-12 13:09:00+03	38500.00
AD239A	2017-08-04 03:52:00+03	26000.00
AD23D5	2017-08-09 05:42:00+03	45200.00
AD23F0	2017-07-17 16:25:00+03	14000.00
AD2427	2017-08-14 23:26:00+03	38400.00
AD2499	2017-08-05 15:49:00+03	23400.00
AD24C3	2017-08-04 06:18:00+03	418800.00
AD2737	2017-08-04 18:10:00+03	198400.00
AD2763	2017-07-25 23:01:00+03	30000.00
AD279B	2017-07-23 07:43:00+03	46200.00
AD27B4	2017-07-16 03:02:00+03	123000.00
AD27E6	2017-07-04 13:07:00+03	16800.00
AD280F	2017-08-08 01:01:00+03	8200.00
AD2855	2017-07-06 03:51:00+03	96300.00
AD2864	2017-07-14 09:55:00+03	24400.00
AD290A	2017-07-02 21:29:00+03	96800.00
AD2933	2017-08-08 03:01:00+03	114400.00
AD2956	2017-07-06 16:37:00+03	31600.00
AD29D0	2017-07-30 02:42:00+03	6000.00
AD2A37	2017-07-25 03:38:00+03	46200.00
AD2A38	2017-07-15 00:30:00+03	141600.00
AD2A84	2017-08-15 11:06:00+03	23200.00
AD2B1C	2017-08-15 17:36:00+03	37700.00
AD2B2D	2017-07-13 02:32:00+03	26000.00
AD2B42	2017-08-01 20:25:00+03	52100.00
AD2B69	2017-07-01 16:46:00+03	17800.00
AD2B82	2017-08-10 06:28:00+03	54000.00
AD2B92	2017-08-08 10:53:00+03	26400.00
AD2B9B	2017-08-10 04:58:00+03	28800.00
AD2BDB	2017-07-07 19:06:00+03	11800.00
AD2BE0	2017-07-09 05:28:00+03	69900.00
AD2C05	2017-07-03 20:11:00+03	46400.00
AD2C18	2017-07-14 04:53:00+03	54700.00
AD2C5D	2017-08-10 05:25:00+03	81300.00
AD2D89	2017-07-14 15:26:00+03	56900.00
AD2D98	2017-08-03 17:43:00+03	38400.00
AD2DD6	2017-07-27 13:33:00+03	48700.00
AD2DE0	2017-07-04 02:02:00+03	24400.00
AD2E25	2017-08-12 09:17:00+03	56900.00
AD2E97	2017-08-13 12:29:00+03	247400.00
AD2E9A	2017-07-05 08:42:00+03	37900.00
AD2F0A	2017-07-30 12:09:00+03	24400.00
AD2F3A	2017-07-21 17:38:00+03	42800.00
AD2F73	2017-07-13 15:31:00+03	61800.00
AD2F8A	2017-07-09 17:42:00+03	18500.00
AD2FAA	2017-07-09 18:52:00+03	185600.00
AD2FBF	2017-07-23 23:46:00+03	293900.00
AD2FE7	2017-07-22 06:16:00+03	88400.00
AD3095	2017-07-15 14:43:00+03	108000.00
AD30BA	2017-07-17 02:24:00+03	136800.00
AD3195	2017-07-06 05:04:00+03	204500.00
AD31BC	2017-08-07 17:57:00+03	99700.00
AD31C6	2017-07-21 06:37:00+03	151200.00
AD32C6	2017-07-09 12:52:00+03	257600.00
AD32CA	2017-07-05 23:42:00+03	12000.00
AD32FD	2017-07-10 14:23:00+03	46000.00
AD3363	2017-07-20 00:38:00+03	119500.00
AD33A1	2017-07-03 19:59:00+03	14400.00
AD33A4	2017-07-10 05:09:00+03	128800.00
AD33D8	2017-07-12 00:59:00+03	10600.00
AD341A	2017-07-20 19:04:00+03	45200.00
AD3427	2017-07-25 08:06:00+03	14000.00
AD342E	2017-07-27 06:10:00+03	169900.00
AD3498	2017-08-09 00:25:00+03	105100.00
AD3505	2017-08-03 01:59:00+03	56000.00
AD3559	2017-08-14 02:41:00+03	52000.00
AD35B4	2017-07-09 00:35:00+03	187600.00
AD35BF	2017-07-11 15:20:00+03	40600.00
AD35F9	2017-07-29 01:04:00+03	55800.00
AD361E	2017-07-17 11:17:00+03	28000.00
AD3677	2017-08-07 07:01:00+03	62800.00
AD3688	2017-08-10 11:30:00+03	120300.00
AD36DD	2017-07-28 22:50:00+03	26000.00
AD36EA	2017-08-15 08:20:00+03	14000.00
AD3710	2017-07-12 00:47:00+03	52900.00
AD3712	2017-08-07 18:08:00+03	251500.00
AD3713	2017-07-29 22:26:00+03	22000.00
AD373E	2017-07-24 07:24:00+03	71300.00
AD379E	2017-08-10 21:03:00+03	92900.00
AD37CF	2017-07-10 13:15:00+03	33500.00
AD37D1	2017-07-06 10:15:00+03	246000.00
AD37E2	2017-07-13 09:47:00+03	46800.00
AD381D	2017-07-21 17:16:00+03	62700.00
AD3856	2017-07-16 11:35:00+03	8600.00
AD385B	2017-07-30 13:40:00+03	46800.00
AD3865	2017-08-06 20:42:00+03	123000.00
AD3869	2017-07-10 01:33:00+03	57400.00
AD3873	2017-07-09 08:24:00+03	189200.00
AD388B	2017-08-12 21:05:00+03	27400.00
AD388F	2017-08-02 05:15:00+03	21400.00
AD38E0	2017-07-13 05:58:00+03	24800.00
AD38E9	2017-06-30 22:50:00+03	38800.00
AD3904	2017-07-04 05:16:00+03	131100.00
AD390C	2017-07-02 07:53:00+03	101500.00
AD392A	2017-07-03 18:37:00+03	198400.00
AD3951	2017-07-12 02:44:00+03	46400.00
AD3961	2017-07-29 16:41:00+03	136200.00
AD3982	2017-07-11 01:12:00+03	406700.00
AD39B2	2017-07-05 02:56:00+03	32700.00
AD39D8	2017-07-06 22:18:00+03	108600.00
AD3AD6	2017-07-31 15:46:00+03	96300.00
AD3BB4	2017-07-12 09:04:00+03	50600.00
AD3C5C	2017-07-04 17:37:00+03	85000.00
AD3CF1	2017-07-09 20:46:00+03	111600.00
AD3D1C	2017-07-12 22:43:00+03	56600.00
AD3D27	2017-07-14 11:29:00+03	84100.00
AD3D39	2017-07-14 22:46:00+03	92400.00
AD3DA6	2017-07-31 16:59:00+03	46700.00
AD3DB4	2017-08-15 06:04:00+03	102100.00
AD3DCB	2017-07-23 18:52:00+03	67700.00
AD3E0B	2017-08-03 08:20:00+03	46000.00
AD3E86	2017-07-13 00:33:00+03	43900.00
AD3F23	2017-07-06 13:00:00+03	109600.00
AD3F28	2017-08-13 12:32:00+03	28300.00
AD3FBC	2017-07-28 01:04:00+03	76200.00
AD3FF1	2017-08-10 05:42:00+03	46000.00
AD4037	2017-07-05 04:52:00+03	6300.00
AD40FD	2017-08-09 05:31:00+03	68800.00
AD4183	2017-08-03 15:39:00+03	25100.00
AD421D	2017-06-29 03:42:00+03	26000.00
AD4230	2017-07-15 14:22:00+03	93900.00
AD4287	2017-07-21 12:00:00+03	137400.00
AD4290	2017-07-24 06:07:00+03	67800.00
AD42B8	2017-07-26 21:29:00+03	48800.00
AD42D2	2017-07-01 15:54:00+03	39300.00
AD42D7	2017-08-13 10:19:00+03	177200.00
AD42F0	2017-08-06 12:46:00+03	123000.00
AD4399	2017-07-20 01:33:00+03	179500.00
AD43A7	2017-07-01 23:46:00+03	213800.00
AD43F1	2017-07-16 15:08:00+03	15000.00
AD4458	2017-07-20 19:56:00+03	26700.00
AD4476	2017-06-29 18:51:00+03	25600.00
AD44FF	2017-08-13 00:56:00+03	23400.00
AD4536	2017-07-06 15:31:00+03	55000.00
AD4588	2017-07-07 23:32:00+03	23400.00
AD468E	2017-07-27 00:02:00+03	68800.00
AD46E7	2017-08-14 19:46:00+03	37600.00
AD46EC	2017-07-30 02:09:00+03	48900.00
AD4706	2017-07-18 00:55:00+03	31000.00
AD4738	2017-08-13 07:03:00+03	81700.00
AD4793	2017-07-26 22:09:00+03	41200.00
AD47A6	2017-08-15 14:29:00+03	34000.00
AD47E3	2017-08-12 01:43:00+03	185600.00
AD47E4	2017-08-01 22:07:00+03	246000.00
AD47FF	2017-07-30 20:43:00+03	78700.00
AD4809	2017-08-13 15:52:00+03	52000.00
AD484F	2017-07-20 22:07:00+03	70500.00
AD48ED	2017-08-09 13:11:00+03	54500.00
AD48F5	2017-07-20 00:49:00+03	67600.00
AD48F6	2017-07-10 17:19:00+03	125400.00
AD493E	2017-08-12 00:44:00+03	24400.00
AD4955	2017-07-27 03:33:00+03	111600.00
AD49DB	2017-07-25 01:18:00+03	53300.00
AD4A04	2017-07-03 02:23:00+03	45500.00
AD4A2A	2017-07-05 01:18:00+03	119500.00
AD4A86	2017-08-11 06:42:00+03	36900.00
AD4ACE	2017-08-13 23:01:00+03	74300.00
AD4ADC	2017-07-14 06:59:00+03	155600.00
AD4AF1	2017-07-10 07:21:00+03	32800.00
AD4B1B	2017-07-18 01:48:00+03	26100.00
AD4B1E	2017-08-07 22:31:00+03	120800.00
AD4B63	2017-08-02 00:03:00+03	164600.00
AD4B93	2017-08-08 08:06:00+03	39600.00
AD4C3A	2017-08-07 16:56:00+03	43200.00
AD4C6B	2017-07-13 22:54:00+03	163400.00
AD4CB0	2017-08-11 21:06:00+03	24400.00
AD4D80	2017-07-18 04:06:00+03	31600.00
AD4E04	2017-07-04 11:04:00+03	136200.00
AD4E2E	2017-08-12 12:38:00+03	36000.00
AD4E35	2017-07-01 08:30:00+03	56000.00
AD4E49	2017-08-01 08:21:00+03	37900.00
AD4E58	2017-07-14 16:52:00+03	266400.00
AD4E7B	2017-08-14 21:11:00+03	113300.00
AD4E84	2017-08-09 03:01:00+03	32800.00
AD4EA3	2017-08-07 05:12:00+03	184000.00
AD4ECD	2017-08-04 19:39:00+03	46500.00
AD4F6A	2017-08-14 06:24:00+03	14400.00
AD4F77	2017-07-15 19:11:00+03	46400.00
AD4FCE	2017-08-02 21:40:00+03	6700.00
AD505F	2017-06-30 07:02:00+03	59800.00
AD508B	2017-08-02 01:06:00+03	35000.00
AD50AC	2017-07-16 06:40:00+03	33300.00
AD50BF	2017-08-10 07:47:00+03	70100.00
AD50D0	2017-07-29 15:43:00+03	46000.00
AD513D	2017-07-09 23:02:00+03	38400.00
AD51B5	2017-07-12 17:22:00+03	20600.00
AD51FF	2017-07-14 20:37:00+03	42800.00
AD529E	2017-07-20 14:39:00+03	101200.00
AD531F	2017-08-15 01:06:00+03	6800.00
AD5340	2017-07-18 15:32:00+03	131100.00
AD5349	2017-06-28 15:14:00+03	223200.00
AD5363	2017-07-28 04:40:00+03	86600.00
AD5378	2017-08-06 14:58:00+03	72800.00
AD539C	2017-07-24 15:48:00+03	89700.00
AD53F4	2017-08-09 09:11:00+03	369000.00
AD542E	2017-07-26 06:03:00+03	17600.00
AD5453	2017-07-12 01:31:00+03	136700.00
AD5456	2017-08-10 08:19:00+03	30800.00
AD545E	2017-08-01 18:04:00+03	92100.00
AD546D	2017-08-05 14:20:00+03	51300.00
AD5476	2017-08-15 16:30:00+03	53300.00
AD5500	2017-08-04 02:04:00+03	42700.00
AD5637	2017-07-09 15:55:00+03	54500.00
AD56D0	2017-07-09 06:30:00+03	23600.00
AD56D2	2017-08-14 19:22:00+03	155600.00
AD56D7	2017-07-19 11:27:00+03	96100.00
AD56F6	2017-08-12 22:47:00+03	73200.00
AD57D6	2017-07-31 18:08:00+03	67800.00
AD581B	2017-08-04 11:54:00+03	154500.00
AD582E	2017-08-10 01:12:00+03	44000.00
AD584C	2017-08-01 17:55:00+03	68000.00
AD5876	2017-07-28 05:55:00+03	34000.00
AD58A7	2017-07-25 17:03:00+03	257600.00
AD58FE	2017-08-07 04:45:00+03	89600.00
AD5954	2017-07-16 03:44:00+03	65900.00
AD5991	2017-08-06 18:25:00+03	28000.00
AD59FE	2017-07-18 02:00:00+03	38400.00
AD5A34	2017-08-05 15:24:00+03	39500.00
AD5A43	2017-07-03 19:36:00+03	94200.00
AD5A51	2017-07-15 17:16:00+03	28800.00
AD5A71	2017-07-10 17:15:00+03	25800.00
AD5A8C	2017-08-12 11:28:00+03	12000.00
AD5AA7	2017-07-07 01:53:00+03	78800.00
AD5B6B	2017-07-18 14:10:00+03	693400.00
AD5BA8	2017-08-07 07:10:00+03	135400.00
AD5BB5	2017-08-06 21:43:00+03	55800.00
AD5C36	2017-07-16 14:07:00+03	113100.00
AD5C67	2017-07-19 12:54:00+03	8000.00
AD5C91	2017-08-01 22:14:00+03	43500.00
AD5C9B	2017-06-29 05:49:00+03	136800.00
AD5CB8	2017-06-28 14:44:00+03	13600.00
AD5CC3	2017-07-24 20:03:00+03	43200.00
AD5D26	2017-08-05 14:16:00+03	64700.00
AD5D79	2017-08-14 02:44:00+03	26800.00
AD5DAD	2017-07-11 20:00:00+03	97800.00
AD5E01	2017-08-12 08:54:00+03	64300.00
AD5E36	2017-07-09 23:21:00+03	34200.00
AD5E6E	2017-08-08 02:24:00+03	46200.00
AD5EDC	2017-07-03 23:51:00+03	70800.00
AD5EE8	2017-07-02 21:06:00+03	28000.00
AD5F23	2017-08-04 19:58:00+03	123400.00
AD5FC6	2017-07-21 07:57:00+03	54300.00
AD6016	2017-07-21 22:14:00+03	33600.00
AD60D4	2017-08-13 09:59:00+03	69500.00
AD6105	2017-08-13 21:26:00+03	34000.00
AD6121	2017-07-31 14:43:00+03	22400.00
AD612A	2017-07-22 00:03:00+03	68100.00
AD6131	2017-07-23 02:17:00+03	31600.00
AD61AF	2017-08-04 06:48:00+03	28600.00
AD61E6	2017-07-31 10:30:00+03	54900.00
AD6236	2017-08-10 01:54:00+03	59300.00
AD6266	2017-07-09 03:35:00+03	72600.00
AD62DA	2017-07-14 19:49:00+03	59000.00
AD62FF	2017-07-04 06:43:00+03	28800.00
AD6344	2017-07-05 00:57:00+03	52600.00
AD63A0	2017-07-11 11:11:00+03	22100.00
AD6402	2017-07-25 08:16:00+03	31500.00
AD6438	2017-08-02 04:50:00+03	70700.00
AD6467	2017-07-19 04:51:00+03	57400.00
AD64BA	2017-07-24 20:18:00+03	28800.00
AD64CE	2017-07-26 04:24:00+03	21400.00
AD6569	2017-08-12 12:05:00+03	133200.00
AD659B	2017-08-06 05:33:00+03	43900.00
AD66BD	2017-08-03 22:48:00+03	56600.00
AD66C3	2017-07-07 15:22:00+03	16400.00
AD66D0	2017-07-15 01:50:00+03	43300.00
AD6736	2017-08-03 00:53:00+03	39700.00
AD6742	2017-07-28 18:05:00+03	28000.00
AD6745	2017-07-25 16:55:00+03	86800.00
AD679D	2017-07-18 11:51:00+03	111600.00
AD67D0	2017-08-04 08:45:00+03	52000.00
AD67D6	2017-07-05 18:37:00+03	67700.00
AD682B	2017-07-06 21:39:00+03	23200.00
AD6832	2017-08-12 11:33:00+03	37600.00
AD684F	2017-08-08 04:41:00+03	26000.00
AD6853	2017-08-13 16:32:00+03	271100.00
AD6868	2017-07-30 04:59:00+03	62600.00
AD6873	2017-07-31 16:26:00+03	23400.00
AD6882	2017-08-08 04:41:00+03	111600.00
AD68A2	2017-08-01 21:53:00+03	271100.00
AD68BB	2017-07-28 07:57:00+03	21000.00
AD68CE	2017-07-14 05:16:00+03	56000.00
AD6902	2017-07-26 01:18:00+03	67800.00
AD695D	2017-07-11 13:42:00+03	134700.00
AD6964	2017-08-11 12:29:00+03	57600.00
AD69C4	2017-08-11 08:56:00+03	65000.00
AD69EC	2017-07-23 12:15:00+03	271400.00
AD6AA4	2017-07-29 14:34:00+03	51900.00
AD6AD5	2017-08-09 07:58:00+03	28800.00
AD6AD8	2017-07-20 00:44:00+03	102100.00
AD6AEC	2017-08-12 18:36:00+03	265800.00
AD6B2B	2017-08-04 15:54:00+03	10800.00
AD6BC3	2017-07-30 04:24:00+03	135400.00
AD6C06	2017-07-06 22:45:00+03	10100.00
AD6C1F	2017-08-07 08:45:00+03	64600.00
AD6D1C	2017-08-02 15:16:00+03	43200.00
AD6D5B	2017-08-04 10:07:00+03	28800.00
AD6D77	2017-08-02 11:47:00+03	98400.00
AD6DD4	2017-07-07 20:23:00+03	7400.00
AD6E70	2017-07-23 04:06:00+03	72800.00
AD6E79	2017-07-12 12:01:00+03	398500.00
AD6E86	2017-07-23 06:47:00+03	66600.00
AD6EC5	2017-07-18 03:38:00+03	26200.00
AD6F39	2017-08-11 05:19:00+03	42600.00
AD6FAB	2017-07-14 18:19:00+03	22400.00
AD6FB9	2017-06-30 23:36:00+03	44000.00
AD6FF3	2017-07-22 02:39:00+03	32800.00
AD702F	2017-07-13 15:28:00+03	135000.00
AD7095	2017-08-15 17:01:00+03	40400.00
AD70A0	2017-08-09 20:57:00+03	137700.00
AD70E5	2017-08-09 20:02:00+03	167500.00
AD70E7	2017-07-21 02:47:00+03	16400.00
AD7109	2017-08-11 20:44:00+03	16800.00
AD711D	2017-07-07 06:18:00+03	22400.00
AD717F	2017-07-09 23:13:00+03	46500.00
AD71AE	2017-07-08 02:31:00+03	265700.00
AD71B4	2017-08-01 23:29:00+03	70600.00
AD71F7	2017-08-08 10:41:00+03	44000.00
AD71F8	2017-07-07 13:03:00+03	72200.00
AD71FD	2017-07-24 02:00:00+03	14400.00
AD720C	2017-07-16 20:25:00+03	135300.00
AD720F	2017-08-10 12:13:00+03	50800.00
AD721C	2017-07-29 23:00:00+03	67600.00
AD721E	2017-06-30 15:47:00+03	39100.00
AD722B	2017-07-11 03:37:00+03	40800.00
AD7246	2017-07-23 05:01:00+03	32800.00
AD7262	2017-07-06 03:26:00+03	24400.00
AD7313	2017-07-15 13:59:00+03	38400.00
AD737E	2017-07-11 17:18:00+03	30900.00
AD742E	2017-08-07 04:52:00+03	154500.00
AD7438	2017-07-14 04:33:00+03	40000.00
AD7440	2017-07-08 12:21:00+03	15100.00
AD74A3	2017-08-14 05:13:00+03	40000.00
AD74E8	2017-08-11 13:44:00+03	135400.00
AD7505	2017-08-14 07:00:00+03	399600.00
AD7553	2017-07-18 17:14:00+03	27400.00
AD757D	2017-07-25 06:29:00+03	28800.00
AD75D2	2017-07-23 11:20:00+03	89200.00
AD75F4	2017-08-11 09:06:00+03	23200.00
AD7604	2017-07-14 03:11:00+03	143600.00
AD7647	2017-08-10 23:35:00+03	53400.00
AD767F	2017-07-31 05:57:00+03	59200.00
AD7691	2017-07-14 08:09:00+03	52000.00
AD7739	2017-08-15 11:31:00+03	49100.00
AD7745	2017-08-08 06:01:00+03	65500.00
AD77DA	2017-07-30 23:15:00+03	198000.00
AD77E9	2017-07-10 09:24:00+03	14800.00
AD77FC	2017-08-11 17:21:00+03	65600.00
AD7842	2017-07-08 03:00:00+03	28800.00
AD7888	2017-07-11 22:46:00+03	55800.00
AD788D	2017-08-02 07:07:00+03	246000.00
AD78C0	2017-08-11 20:04:00+03	38400.00
AD78F8	2017-07-24 14:28:00+03	8000.00
AD7906	2017-07-24 03:21:00+03	85600.00
AD7921	2017-08-08 21:42:00+03	56600.00
AD794A	2017-07-28 05:22:00+03	14000.00
AD799B	2017-08-05 08:48:00+03	26800.00
AD79D4	2017-08-14 04:33:00+03	13400.00
AD7A39	2017-07-19 14:43:00+03	56000.00
AD7AB7	2017-08-08 04:21:00+03	150000.00
AD7B2D	2017-08-06 13:24:00+03	62600.00
AD7C35	2017-07-07 17:05:00+03	26000.00
AD7C9F	2017-07-08 05:08:00+03	65200.00
AD7CA9	2017-07-26 12:36:00+03	32800.00
AD7CDF	2017-08-15 09:15:00+03	25100.00
AD7D0A	2017-07-21 23:02:00+03	66600.00
AD7D5F	2017-07-23 03:09:00+03	87200.00
AD7D81	2017-07-23 23:43:00+03	96300.00
AD7DB9	2017-07-18 13:43:00+03	29600.00
AD7DFB	2017-07-30 09:25:00+03	27200.00
AD7EFA	2017-07-01 05:39:00+03	155600.00
AD7F3A	2017-07-03 17:54:00+03	8200.00
AD7F81	2017-07-24 01:26:00+03	55800.00
AD7FB3	2017-07-23 16:30:00+03	119400.00
AD7FB4	2017-08-03 23:06:00+03	26800.00
AD7FF2	2017-07-30 10:49:00+03	64400.00
AD8039	2017-08-01 13:05:00+03	34700.00
AD8042	2017-07-26 14:47:00+03	47400.00
AD80A1	2017-07-22 13:55:00+03	74200.00
AD80A5	2017-08-13 17:31:00+03	6000.00
AD80BF	2017-08-03 16:07:00+03	136200.00
AD8156	2017-07-10 11:06:00+03	57400.00
AD8168	2017-08-12 18:24:00+03	112000.00
AD8179	2017-08-05 22:27:00+03	66000.00
AD81B9	2017-07-18 16:42:00+03	75300.00
AD81C4	2017-08-12 17:51:00+03	209800.00
AD81F8	2017-08-09 23:49:00+03	40000.00
AD82C3	2017-08-04 04:48:00+03	129600.00
AD82CD	2017-07-06 23:46:00+03	24700.00
AD82F0	2017-07-20 13:39:00+03	56000.00
AD835A	2017-07-09 10:54:00+03	66600.00
AD838C	2017-06-30 03:01:00+03	96800.00
AD838D	2017-07-13 11:27:00+03	246000.00
AD838F	2017-07-02 09:45:00+03	55900.00
AD83B0	2017-07-08 03:53:00+03	30200.00
AD8400	2017-07-21 08:08:00+03	114800.00
AD8411	2017-07-03 14:21:00+03	135000.00
AD841A	2017-07-25 01:08:00+03	23200.00
AD8423	2017-07-12 14:28:00+03	103500.00
AD84B2	2017-07-10 14:56:00+03	228800.00
AD84C1	2017-08-12 02:43:00+03	73500.00
AD84E9	2017-07-08 07:09:00+03	189200.00
AD8528	2017-07-20 04:06:00+03	68800.00
AD8546	2017-06-29 10:39:00+03	32200.00
AD85A3	2017-07-17 03:30:00+03	41200.00
AD85C7	2017-07-22 01:27:00+03	35200.00
AD85C9	2017-07-12 14:24:00+03	54000.00
AD865A	2017-07-14 08:53:00+03	26000.00
AD86AF	2017-07-14 13:41:00+03	69000.00
AD8755	2017-08-01 23:12:00+03	55800.00
AD875F	2017-08-05 23:55:00+03	70400.00
AD886E	2017-07-06 10:45:00+03	189800.00
AD8879	2017-07-11 11:13:00+03	75300.00
AD8881	2017-08-04 23:55:00+03	207200.00
AD88BB	2017-07-19 20:18:00+03	65900.00
AD893B	2017-08-08 05:38:00+03	160200.00
AD895C	2017-06-28 15:32:00+03	135200.00
AD89AC	2017-07-27 18:11:00+03	68100.00
AD89C6	2017-07-23 06:00:00+03	111600.00
AD89CF	2017-08-09 04:29:00+03	128700.00
AD8A18	2017-08-04 05:12:00+03	123600.00
AD8A85	2017-08-04 08:17:00+03	56600.00
AD8A9B	2017-08-14 00:55:00+03	58000.00
AD8AE1	2017-08-08 05:38:00+03	31600.00
AD8B4C	2017-07-26 15:56:00+03	32700.00
AD8B92	2017-06-29 19:06:00+03	28000.00
AD8BEF	2017-08-01 03:02:00+03	89700.00
AD8C51	2017-07-22 22:37:00+03	167500.00
AD8CCE	2017-08-06 07:15:00+03	58000.00
AD8CCF	2017-07-24 14:16:00+03	7200.00
AD8CF4	2017-07-27 23:42:00+03	158400.00
AD8D6F	2017-07-05 14:38:00+03	24400.00
AD8DA1	2017-07-24 17:56:00+03	41200.00
AD8E44	2017-08-11 21:02:00+03	13400.00
AD8E94	2017-07-11 04:33:00+03	81700.00
AD8FFE	2017-08-02 06:19:00+03	35300.00
AD9056	2017-08-11 17:22:00+03	25200.00
AD907C	2017-07-08 14:08:00+03	28800.00
AD9097	2017-08-05 09:56:00+03	120000.00
AD909A	2017-07-07 15:26:00+03	84100.00
AD90B9	2017-08-03 14:11:00+03	29600.00
AD90E9	2017-08-08 03:46:00+03	77900.00
AD913A	2017-07-25 11:02:00+03	14000.00
AD9177	2017-07-02 00:16:00+03	55800.00
AD9193	2017-07-13 10:55:00+03	32700.00
AD91C0	2017-07-09 09:33:00+03	90400.00
AD91DE	2017-08-02 02:33:00+03	74400.00
AD91DF	2017-07-03 19:47:00+03	152700.00
AD920B	2017-08-02 21:12:00+03	189800.00
AD9235	2017-08-09 01:06:00+03	270000.00
AD92A3	2017-08-07 10:56:00+03	20400.00
AD931E	2017-07-12 10:08:00+03	138600.00
AD933A	2017-08-14 09:57:00+03	86800.00
AD937C	2017-08-09 06:37:00+03	16200.00
AD9380	2017-07-03 12:42:00+03	60700.00
AD93D4	2017-07-27 06:01:00+03	167400.00
AD9427	2017-07-27 16:01:00+03	84500.00
AD946E	2017-07-20 01:07:00+03	28800.00
AD947D	2017-08-02 10:56:00+03	70400.00
AD949D	2017-07-09 05:34:00+03	43200.00
AD94C6	2017-08-01 12:09:00+03	53500.00
AD951D	2017-07-22 19:59:00+03	34800.00
AD9591	2017-07-22 02:36:00+03	122300.00
AD9673	2017-07-16 20:56:00+03	58800.00
AD9676	2017-07-18 12:00:00+03	73600.00
AD969F	2017-07-07 03:55:00+03	80000.00
AD96A4	2017-07-29 03:03:00+03	6200.00
AD970A	2017-07-23 02:53:00+03	35200.00
AD9731	2017-07-01 07:04:00+03	138500.00
AD9784	2017-07-12 08:09:00+03	56600.00
AD979D	2017-08-04 05:02:00+03	52700.00
AD97AA	2017-06-30 17:16:00+03	23600.00
AD9811	2017-07-29 09:29:00+03	8200.00
AD9816	2017-07-11 19:23:00+03	271200.00
AD9848	2017-07-05 16:19:00+03	19600.00
AD98C9	2017-07-09 22:02:00+03	57600.00
AD9913	2017-08-13 16:38:00+03	26600.00
AD9930	2017-07-05 11:29:00+03	52400.00
AD9951	2017-07-15 10:43:00+03	67200.00
AD99AD	2017-07-01 11:06:00+03	43500.00
AD99FC	2017-08-02 10:33:00+03	96800.00
AD9A12	2017-07-06 04:09:00+03	332800.00
AD9A1F	2017-07-05 12:08:00+03	32400.00
AD9A43	2017-06-28 11:43:00+03	205400.00
AD9A9D	2017-07-20 03:08:00+03	412400.00
AD9AAF	2017-07-06 22:33:00+03	22000.00
AD9AB7	2017-08-14 17:20:00+03	273600.00
AD9B76	2017-08-13 06:41:00+03	142300.00
AD9B88	2017-07-20 15:49:00+03	26000.00
AD9CE1	2017-07-07 14:16:00+03	99700.00
AD9CF1	2017-08-07 23:08:00+03	272400.00
AD9D02	2017-08-12 11:15:00+03	106100.00
AD9D27	2017-07-11 16:34:00+03	11600.00
AD9D54	2017-07-27 14:36:00+03	160000.00
AD9DD1	2017-07-23 08:37:00+03	83700.00
AD9E14	2017-07-05 15:41:00+03	23200.00
AD9E20	2017-07-11 00:45:00+03	383300.00
AD9EB7	2017-07-12 18:08:00+03	173500.00
AD9EB8	2017-07-07 10:37:00+03	112000.00
AD9EDB	2017-07-25 06:13:00+03	290200.00
AD9F07	2017-07-22 06:08:00+03	78200.00
AD9F25	2017-07-01 07:39:00+03	46300.00
AD9F3E	2017-07-02 19:41:00+03	93900.00
AD9F68	2017-07-11 18:50:00+03	28800.00
AD9FB2	2017-07-31 12:50:00+03	34000.00
ADA0B4	2017-07-28 02:38:00+03	136200.00
ADA0DA	2017-08-07 12:20:00+03	114700.00
ADA12B	2017-07-22 02:59:00+03	65900.00
ADA143	2017-08-07 18:40:00+03	174500.00
ADA1AD	2017-07-29 01:54:00+03	155600.00
ADA1E4	2017-07-11 07:06:00+03	53400.00
ADA1E6	2017-07-21 05:53:00+03	28000.00
ADA234	2017-07-14 09:10:00+03	57600.00
ADA28F	2017-07-24 01:04:00+03	23200.00
ADA29E	2017-07-11 21:43:00+03	136200.00
ADA361	2017-08-15 10:59:00+03	44000.00
ADA39E	2017-07-18 18:17:00+03	28800.00
ADA3A5	2017-08-05 05:45:00+03	136600.00
ADA3BA	2017-07-04 21:44:00+03	65800.00
ADA3EE	2017-07-22 00:06:00+03	26200.00
ADA408	2017-07-24 11:17:00+03	212700.00
ADA455	2017-07-29 13:19:00+03	89600.00
ADA48F	2017-07-29 17:06:00+03	92900.00
ADA4C0	2017-07-20 16:52:00+03	40800.00
ADA4C3	2017-08-14 13:28:00+03	138000.00
ADA4F3	2017-07-16 03:09:00+03	16000.00
ADA4F9	2017-07-13 02:04:00+03	270700.00
ADA508	2017-07-28 01:10:00+03	189200.00
ADA555	2017-07-06 14:38:00+03	24800.00
ADA5A1	2017-07-12 11:05:00+03	28800.00
ADA606	2017-07-25 17:06:00+03	30800.00
ADA63D	2017-07-10 21:51:00+03	37400.00
ADA650	2017-08-13 13:58:00+03	65900.00
ADA669	2017-07-24 21:39:00+03	43700.00
ADA66F	2017-07-18 17:23:00+03	176600.00
ADA6EC	2017-07-02 09:20:00+03	41600.00
ADA74E	2017-07-16 03:07:00+03	132800.00
ADA76A	2017-06-28 23:41:00+03	70100.00
ADA77F	2017-08-07 06:46:00+03	31600.00
ADA7FC	2017-07-31 07:31:00+03	26000.00
ADA81B	2017-07-01 18:38:00+03	56000.00
ADA81F	2017-08-05 18:37:00+03	130400.00
ADA8D7	2017-07-15 08:18:00+03	123600.00
ADA9CF	2017-08-04 08:45:00+03	572000.00
ADAA0C	2017-07-11 00:49:00+03	246000.00
ADAA14	2017-07-18 16:47:00+03	153800.00
ADAA33	2017-08-02 07:27:00+03	46400.00
ADAA51	2017-07-12 08:06:00+03	39000.00
ADAACF	2017-08-03 12:57:00+03	89700.00
ADABD4	2017-07-13 15:59:00+03	21000.00
ADAC12	2017-07-07 18:50:00+03	139400.00
ADAC97	2017-07-29 21:46:00+03	28000.00
ADAD2A	2017-08-12 21:54:00+03	81000.00
ADAD72	2017-08-10 00:43:00+03	594400.00
ADAD78	2017-07-27 13:52:00+03	20600.00
ADAD86	2017-07-20 12:41:00+03	257500.00
ADAE46	2017-07-18 22:13:00+03	87300.00
ADAE50	2017-08-12 12:11:00+03	47600.00
ADAE8E	2017-07-11 16:34:00+03	47400.00
ADAE9A	2017-08-05 21:17:00+03	32200.00
ADAEA0	2017-07-30 23:01:00+03	28000.00
ADAEB2	2017-07-11 02:20:00+03	38800.00
ADAF94	2017-08-05 00:50:00+03	40600.00
ADAFFE	2017-07-16 22:47:00+03	75300.00
ADB012	2017-07-29 15:24:00+03	281500.00
ADB028	2017-07-13 15:58:00+03	286600.00
ADB058	2017-08-11 13:15:00+03	35600.00
ADB0D4	2017-07-12 12:14:00+03	160400.00
ADB11C	2017-08-07 15:27:00+03	31600.00
ADB143	2017-07-22 22:16:00+03	44000.00
ADB18E	2017-07-29 09:23:00+03	139800.00
ADB24F	2017-08-02 08:33:00+03	35200.00
ADB268	2017-07-15 10:45:00+03	149400.00
ADB290	2017-08-10 11:48:00+03	51900.00
ADB2C3	2017-07-08 12:25:00+03	88600.00
ADB39D	2017-08-04 05:37:00+03	116500.00
ADB41A	2017-07-17 21:54:00+03	56600.00
ADB453	2017-08-11 11:26:00+03	42400.00
ADB549	2017-07-15 16:11:00+03	32700.00
ADB57B	2017-07-07 08:38:00+03	68000.00
ADB59D	2017-08-07 19:47:00+03	283100.00
ADB5A4	2017-07-26 10:24:00+03	32800.00
ADB5CC	2017-06-30 20:48:00+03	101200.00
ADB5DE	2017-07-01 13:04:00+03	492000.00
ADB651	2017-08-14 19:31:00+03	92000.00
ADB77B	2017-07-21 20:52:00+03	85800.00
ADB791	2017-07-27 15:57:00+03	28800.00
ADB7CA	2017-07-30 09:39:00+03	133200.00
ADB7FA	2017-07-31 04:21:00+03	28000.00
ADB7FF	2017-07-07 06:19:00+03	31600.00
ADB852	2017-07-20 19:20:00+03	67700.00
ADB8D9	2017-08-06 02:33:00+03	95300.00
ADB917	2017-08-08 04:18:00+03	236000.00
ADB935	2017-07-10 04:02:00+03	170700.00
ADB97A	2017-07-19 05:25:00+03	89600.00
ADB986	2017-08-12 21:01:00+03	81600.00
ADB9B5	2017-08-01 20:25:00+03	72000.00
ADBA2B	2017-08-04 00:02:00+03	39600.00
ADBA94	2017-08-08 06:54:00+03	16400.00
ADBB22	2017-07-15 07:39:00+03	214900.00
ADBB4E	2017-07-26 01:24:00+03	44600.00
ADBBEE	2017-07-09 09:42:00+03	23200.00
ADBC47	2017-07-14 04:41:00+03	135000.00
ADBCCF	2017-08-15 07:10:00+03	76300.00
ADBD98	2017-07-31 20:25:00+03	77900.00
ADBDA5	2017-07-06 19:37:00+03	28000.00
ADBDAB	2017-07-20 06:30:00+03	21400.00
ADBDC4	2017-08-08 08:29:00+03	65200.00
ADBE23	2017-06-27 16:30:00+03	47000.00
ADBE71	2017-08-08 22:26:00+03	24400.00
ADBEF3	2017-07-06 11:41:00+03	24800.00
ADBF4B	2017-07-20 21:57:00+03	84500.00
ADBF5A	2017-07-04 21:53:00+03	35200.00
ADBF88	2017-08-15 03:57:00+03	51000.00
ADBF9A	2017-07-17 05:02:00+03	184800.00
ADBFC2	2017-08-10 20:31:00+03	62000.00
ADBFD1	2017-07-03 06:23:00+03	23400.00
ADBFF4	2017-07-07 12:50:00+03	21600.00
ADC019	2017-08-12 17:29:00+03	13400.00
ADC030	2017-07-31 14:05:00+03	179400.00
ADC061	2017-07-21 18:43:00+03	25100.00
ADC0D6	2017-07-18 20:15:00+03	23400.00
ADC163	2017-08-11 13:37:00+03	21800.00
ADC164	2017-07-11 23:05:00+03	93600.00
ADC189	2017-07-20 19:03:00+03	36200.00
ADC1A3	2017-07-12 17:06:00+03	69500.00
ADC1AF	2017-07-20 03:27:00+03	106500.00
ADC1D9	2017-07-01 09:13:00+03	47000.00
ADC209	2017-07-28 09:04:00+03	103700.00
ADC219	2017-08-07 07:31:00+03	40000.00
ADC24E	2017-07-07 10:45:00+03	25400.00
ADC256	2017-07-19 06:10:00+03	40800.00
ADC280	2017-07-30 11:53:00+03	91900.00
ADC28C	2017-07-15 03:30:00+03	29600.00
ADC2A0	2017-07-18 21:41:00+03	25100.00
ADC2DA	2017-08-09 23:21:00+03	89500.00
ADC3AD	2017-07-22 19:26:00+03	13200.00
ADC3AE	2017-07-18 02:50:00+03	32700.00
ADC3DF	2017-06-30 17:34:00+03	20400.00
ADC45A	2017-08-14 08:29:00+03	16400.00
ADC464	2017-07-11 05:07:00+03	58000.00
ADC480	2017-07-10 06:34:00+03	38400.00
ADC4B9	2017-07-18 01:24:00+03	46200.00
ADC57B	2017-08-12 07:57:00+03	248300.00
ADC5B1	2017-07-25 21:15:00+03	156500.00
ADC613	2017-07-25 20:20:00+03	66600.00
ADC64C	2017-07-31 22:13:00+03	24400.00
ADC6D8	2017-07-24 15:34:00+03	100600.00
ADC6E9	2017-07-07 03:18:00+03	11700.00
ADC70E	2017-08-03 15:01:00+03	26600.00
ADC71B	2017-07-07 08:31:00+03	24200.00
ADC766	2017-08-13 13:50:00+03	86300.00
ADC782	2017-08-15 17:19:00+03	272300.00
ADC7A5	2017-08-07 22:53:00+03	167400.00
ADC7E7	2017-07-09 12:17:00+03	139200.00
ADC88B	2017-07-21 19:59:00+03	26000.00
ADC892	2017-07-19 05:52:00+03	41800.00
ADC92F	2017-08-01 04:53:00+03	28700.00
ADC958	2017-08-11 20:25:00+03	16800.00
ADC9A0	2017-06-27 17:20:00+03	29400.00
ADCA07	2017-07-01 11:12:00+03	6600.00
ADCA88	2017-07-22 02:57:00+03	194000.00
ADCA93	2017-08-02 23:13:00+03	90400.00
ADCAB0	2017-07-10 05:12:00+03	39600.00
ADCACE	2017-07-22 14:29:00+03	98700.00
ADCAE7	2017-08-11 15:40:00+03	19600.00
ADCAF9	2017-08-09 13:32:00+03	39900.00
ADCB84	2017-08-09 00:14:00+03	161600.00
ADCBA7	2017-07-13 17:40:00+03	8200.00
ADCBAC	2017-07-24 17:00:00+03	139300.00
ADCBB1	2017-07-13 00:05:00+03	67800.00
ADCBE0	2017-08-01 16:34:00+03	85000.00
ADCBEC	2017-07-09 14:42:00+03	6800.00
ADCBFF	2017-07-13 16:00:00+03	44700.00
ADCC0C	2017-07-08 09:47:00+03	17200.00
ADCC67	2017-08-08 09:43:00+03	86600.00
ADCCA1	2017-08-10 15:43:00+03	56000.00
ADCCD8	2017-08-07 16:50:00+03	184700.00
ADCD38	2017-07-28 12:20:00+03	28600.00
ADCD64	2017-07-17 07:55:00+03	123000.00
ADCDB6	2017-08-14 08:45:00+03	74800.00
ADCDE5	2017-08-01 20:58:00+03	68800.00
ADCE25	2017-07-17 09:44:00+03	68500.00
ADCE5A	2017-08-03 08:57:00+03	56000.00
ADCF20	2017-07-29 12:51:00+03	16400.00
ADCF38	2017-07-23 15:31:00+03	189800.00
ADCFFE	2017-07-17 00:19:00+03	28000.00
ADD0F6	2017-07-15 08:44:00+03	384900.00
ADD210	2017-07-15 19:10:00+03	59000.00
ADD220	2017-07-24 05:27:00+03	167500.00
ADD2D9	2017-07-29 00:52:00+03	112000.00
ADD335	2017-07-09 05:22:00+03	47600.00
ADD33E	2017-08-10 17:37:00+03	37900.00
ADD35F	2017-07-12 18:57:00+03	26200.00
ADD381	2017-07-07 15:02:00+03	24600.00
ADD401	2017-07-07 13:05:00+03	198400.00
ADD41D	2017-07-11 12:12:00+03	73500.00
ADD46D	2017-07-30 13:46:00+03	46300.00
ADD47A	2017-07-20 04:50:00+03	24400.00
ADD48C	2017-07-03 23:25:00+03	135600.00
ADD49F	2017-07-15 04:59:00+03	21200.00
ADD4D3	2017-07-25 05:14:00+03	38400.00
ADD4E0	2017-08-01 02:08:00+03	42400.00
ADD4F6	2017-07-04 12:33:00+03	12400.00
ADD4FC	2017-07-17 04:06:00+03	223700.00
ADD521	2017-08-02 00:32:00+03	123000.00
ADD54A	2017-08-08 01:00:00+03	246000.00
ADD5EB	2017-08-09 13:14:00+03	240600.00
ADD6C7	2017-07-08 08:17:00+03	152500.00
ADD705	2017-07-20 02:53:00+03	143100.00
ADD70D	2017-07-31 10:45:00+03	311200.00
ADD726	2017-07-02 17:30:00+03	26800.00
ADD778	2017-08-12 21:52:00+03	151500.00
ADD892	2017-07-22 15:25:00+03	69500.00
ADD930	2017-08-13 17:32:00+03	14800.00
ADD947	2017-07-10 08:17:00+03	31000.00
ADD956	2017-07-14 05:21:00+03	137900.00
ADD96F	2017-07-27 00:32:00+03	28800.00
ADD995	2017-07-05 05:24:00+03	37400.00
ADD9BA	2017-08-11 05:09:00+03	62800.00
ADD9DA	2017-07-01 14:13:00+03	28000.00
ADD9E6	2017-07-08 14:13:00+03	28000.00
ADDA18	2017-07-14 01:09:00+03	240600.00
ADDA30	2017-08-02 09:53:00+03	56000.00
ADDB73	2017-07-27 00:54:00+03	134700.00
ADDBA7	2017-07-31 03:57:00+03	49500.00
ADDC09	2017-07-30 23:39:00+03	26200.00
ADDC1C	2017-07-24 13:51:00+03	92000.00
ADDC84	2017-07-10 12:58:00+03	37100.00
ADDCE4	2017-08-14 14:54:00+03	30400.00
ADDD11	2017-07-13 16:47:00+03	125100.00
ADDD57	2017-08-07 12:05:00+03	16800.00
ADDD61	2017-07-22 06:05:00+03	28000.00
ADDDB1	2017-08-05 00:36:00+03	34000.00
ADDDB9	2017-08-09 17:44:00+03	123000.00
ADDE22	2017-07-24 10:10:00+03	36200.00
ADDE24	2017-07-01 14:32:00+03	26000.00
ADDE5F	2017-08-02 18:13:00+03	64100.00
ADDE84	2017-07-24 21:05:00+03	56200.00
ADDF48	2017-08-04 07:39:00+03	56000.00
ADDFC0	2017-07-01 22:01:00+03	106900.00
ADDFDF	2017-08-13 08:40:00+03	80100.00
ADE018	2017-08-04 05:10:00+03	67000.00
ADE06E	2017-07-19 04:40:00+03	101200.00
ADE099	2017-07-22 22:48:00+03	33600.00
ADE09E	2017-08-04 10:49:00+03	110500.00
ADE0C5	2017-08-02 19:06:00+03	27200.00
ADE117	2017-08-12 19:51:00+03	25000.00
ADE14F	2017-07-01 12:38:00+03	27200.00
ADE1D7	2017-07-11 02:58:00+03	12600.00
ADE1E2	2017-07-08 17:48:00+03	67600.00
ADE1FA	2017-07-05 21:28:00+03	40000.00
ADE20E	2017-08-13 01:52:00+03	28000.00
ADE25C	2017-07-17 03:40:00+03	170400.00
ADE273	2017-07-29 10:41:00+03	102100.00
ADE312	2017-07-17 13:30:00+03	83700.00
ADE334	2017-08-13 01:19:00+03	23400.00
ADE3DD	2017-07-20 20:39:00+03	14400.00
ADE421	2017-08-15 06:11:00+03	267400.00
ADE43D	2017-08-04 11:02:00+03	44000.00
ADE45B	2017-08-09 01:16:00+03	124200.00
ADE4A2	2017-07-14 20:01:00+03	114400.00
ADE4E4	2017-08-11 17:36:00+03	27300.00
ADE4EA	2017-07-27 13:41:00+03	47800.00
ADE52A	2017-07-24 18:59:00+03	14800.00
ADE5A3	2017-08-02 05:31:00+03	113200.00
ADE636	2017-07-07 19:10:00+03	86300.00
ADE7C1	2017-08-08 01:23:00+03	37000.00
ADE7CC	2017-07-27 21:58:00+03	46300.00
ADE7FD	2017-08-04 05:30:00+03	83700.00
ADE818	2017-07-06 23:32:00+03	55400.00
ADE819	2017-08-01 05:07:00+03	77200.00
ADE84A	2017-08-04 15:37:00+03	84100.00
ADE88A	2017-08-04 22:12:00+03	303500.00
ADE8B0	2017-07-28 16:28:00+03	85000.00
ADE8B2	2017-07-28 09:46:00+03	58000.00
ADE8E3	2017-08-10 16:33:00+03	399600.00
ADE9D0	2017-07-28 05:21:00+03	26200.00
ADE9E9	2017-08-13 00:43:00+03	20000.00
ADE9EB	2017-08-15 00:04:00+03	42800.00
ADEA3B	2017-08-03 05:14:00+03	56900.00
ADEA80	2017-07-02 21:34:00+03	128800.00
ADEAC5	2017-07-02 08:31:00+03	14400.00
ADEACC	2017-07-23 16:26:00+03	123000.00
ADEB1A	2017-07-08 06:33:00+03	123000.00
ADEB82	2017-07-18 07:32:00+03	87700.00
ADEB93	2017-07-15 09:27:00+03	237700.00
ADEC6E	2017-07-15 14:48:00+03	65900.00
ADECAE	2017-07-07 22:28:00+03	677700.00
ADED0A	2017-07-17 11:28:00+03	113900.00
ADED43	2017-08-02 13:18:00+03	7400.00
ADED46	2017-07-13 03:14:00+03	81300.00
ADEDDC	2017-07-12 21:02:00+03	56600.00
ADEE1D	2017-08-12 05:05:00+03	6800.00
ADEE23	2017-07-11 19:43:00+03	45300.00
ADEE30	2017-08-03 10:20:00+03	48800.00
ADEE51	2017-07-12 13:31:00+03	57500.00
ADEE59	2017-07-08 13:33:00+03	92800.00
ADEE78	2017-07-04 14:44:00+03	26000.00
ADEE79	2017-07-28 23:29:00+03	92400.00
ADEEB7	2017-07-07 15:02:00+03	25600.00
ADEEBF	2017-07-26 10:04:00+03	55800.00
ADEECF	2017-08-10 00:03:00+03	49500.00
ADEEE5	2017-07-09 09:16:00+03	112000.00
ADEF12	2017-08-03 00:51:00+03	160200.00
ADEF16	2017-08-14 02:53:00+03	55500.00
ADEF33	2017-08-12 16:23:00+03	26000.00
ADEF61	2017-08-01 20:01:00+03	24000.00
ADEF7F	2017-06-29 09:36:00+03	666000.00
ADEF84	2017-07-28 17:12:00+03	22000.00
ADEFA7	2017-07-25 00:11:00+03	56000.00
ADEFBA	2017-08-03 19:43:00+03	24400.00
ADEFBE	2017-07-29 08:10:00+03	46000.00
ADF048	2017-07-25 04:11:00+03	29500.00
ADF073	2017-07-06 11:26:00+03	177600.00
ADF0DE	2017-07-21 04:13:00+03	40300.00
ADF11A	2017-06-30 18:27:00+03	47000.00
ADF131	2017-07-27 23:55:00+03	256700.00
ADF1BE	2017-08-03 19:14:00+03	49400.00
ADF1CB	2017-07-07 14:11:00+03	12600.00
ADF1EE	2017-07-23 21:34:00+03	112000.00
ADF1F2	2017-07-02 05:45:00+03	23600.00
ADF22A	2017-07-06 11:32:00+03	64400.00
ADF237	2017-07-29 00:02:00+03	62700.00
ADF265	2017-07-27 00:09:00+03	40700.00
ADF292	2017-07-16 12:42:00+03	140900.00
ADF2DD	2017-06-28 22:05:00+03	42400.00
ADF311	2017-07-04 23:19:00+03	57500.00
ADF31F	2017-08-15 05:19:00+03	80900.00
ADF354	2017-08-15 08:14:00+03	23600.00
ADF3BB	2017-08-08 03:12:00+03	40000.00
ADF419	2017-07-15 05:23:00+03	64800.00
ADF437	2017-08-03 14:44:00+03	40400.00
ADF44A	2017-07-17 11:12:00+03	166900.00
ADF518	2017-06-30 22:22:00+03	18000.00
ADF590	2017-08-10 17:59:00+03	27300.00
ADF5BB	2017-07-18 22:49:00+03	92800.00
ADF5F7	2017-07-31 04:43:00+03	40800.00
ADF641	2017-06-30 11:52:00+03	11300.00
ADF643	2017-07-28 15:53:00+03	177200.00
ADF650	2017-07-14 23:37:00+03	55800.00
ADF656	2017-07-22 18:57:00+03	75200.00
ADF662	2017-07-11 21:12:00+03	76200.00
ADF674	2017-07-22 08:30:00+03	77600.00
ADF67F	2017-08-08 06:18:00+03	11000.00
ADF688	2017-08-01 21:54:00+03	10600.00
ADF6CB	2017-08-12 18:11:00+03	55000.00
ADF6F8	2017-07-03 07:18:00+03	168000.00
ADF713	2017-07-07 23:42:00+03	383900.00
ADF77C	2017-07-11 20:59:00+03	199100.00
ADF7B0	2017-07-11 02:27:00+03	34000.00
ADF816	2017-07-21 08:09:00+03	71200.00
ADF82E	2017-08-05 19:50:00+03	103600.00
ADF875	2017-08-09 07:55:00+03	59800.00
ADF8B9	2017-08-11 06:36:00+03	48700.00
ADF8D4	2017-07-21 13:04:00+03	77200.00
ADF955	2017-07-01 09:28:00+03	201200.00
ADF9AB	2017-07-15 05:19:00+03	103200.00
ADF9D6	2017-07-29 06:27:00+03	73200.00
ADF9F9	2017-07-01 02:08:00+03	46400.00
ADFA46	2017-07-07 20:21:00+03	28000.00
ADFA58	2017-07-21 05:49:00+03	92000.00
ADFA5D	2017-07-04 02:24:00+03	106600.00
ADFA69	2017-08-06 18:47:00+03	277900.00
ADFAA8	2017-07-03 01:48:00+03	49900.00
ADFADB	2017-07-15 00:08:00+03	28000.00
ADFBDD	2017-08-03 05:40:00+03	13400.00
ADFC5F	2017-08-01 21:38:00+03	59800.00
ADFD3B	2017-08-14 16:27:00+03	133200.00
ADFDA9	2017-08-05 11:21:00+03	175700.00
ADFDAF	2017-08-01 23:42:00+03	67900.00
ADFE44	2017-07-04 05:55:00+03	92800.00
ADFE9C	2017-07-13 04:10:00+03	31900.00
ADFEFE	2017-08-05 10:15:00+03	70600.00
ADFF0B	2017-06-25 20:20:00+03	16400.00
ADFF5F	2017-07-10 13:42:00+03	90800.00
ADFF6A	2017-07-25 22:15:00+03	86700.00
ADFFFE	2017-08-11 16:12:00+03	260900.00
AE0040	2017-07-27 14:39:00+03	12600.00
AE0056	2017-07-22 15:05:00+03	18000.00
AE00A9	2017-07-03 13:03:00+03	50800.00
AE00C4	2017-07-05 09:28:00+03	14400.00
AE0156	2017-07-25 15:23:00+03	45200.00
AE01B9	2017-07-04 12:31:00+03	46400.00
AE01EF	2017-07-04 06:31:00+03	14600.00
AE0241	2017-08-06 18:41:00+03	154300.00
AE0264	2017-07-27 02:03:00+03	117600.00
AE0348	2017-07-11 10:41:00+03	36800.00
AE0359	2017-08-01 21:57:00+03	45100.00
AE0376	2017-07-09 03:36:00+03	62600.00
AE0390	2017-08-13 21:34:00+03	18000.00
AE03C4	2017-08-01 10:37:00+03	6700.00
AE03D2	2017-08-04 06:25:00+03	58600.00
AE03F5	2017-07-28 22:15:00+03	47100.00
AE042E	2017-07-31 01:16:00+03	40800.00
AE0437	2017-07-09 11:44:00+03	78300.00
AE0479	2017-08-11 16:59:00+03	50600.00
AE04B0	2017-08-12 22:53:00+03	21800.00
AE04B3	2017-07-28 22:05:00+03	16800.00
AE04E3	2017-07-18 12:54:00+03	48700.00
AE0516	2017-08-14 05:09:00+03	59100.00
AE0522	2017-06-28 01:05:00+03	149700.00
AE0588	2017-08-13 20:48:00+03	62600.00
AE05F4	2017-07-23 12:33:00+03	12600.00
AE0634	2017-07-11 17:26:00+03	11600.00
AE0637	2017-07-11 02:03:00+03	14000.00
AE06C6	2017-08-11 06:24:00+03	34200.00
AE06CD	2017-07-09 21:27:00+03	25000.00
AE06E5	2017-08-09 16:57:00+03	185400.00
AE06F6	2017-07-13 16:23:00+03	27400.00
AE0763	2017-07-12 12:01:00+03	64100.00
AE0791	2017-07-25 19:59:00+03	32100.00
AE07A6	2017-07-01 15:35:00+03	21400.00
AE07BB	2017-08-03 17:55:00+03	23200.00
AE07E8	2017-08-08 13:49:00+03	66100.00
AE0881	2017-08-14 13:00:00+03	312400.00
AE08FB	2017-08-06 14:29:00+03	27800.00
AE0927	2017-07-13 08:41:00+03	43000.00
AE092D	2017-07-20 15:40:00+03	117600.00
AE099E	2017-08-01 08:43:00+03	46900.00
AE09E0	2017-08-15 04:05:00+03	260900.00
AE0A44	2017-07-12 06:19:00+03	37900.00
AE0ACF	2017-07-15 03:10:00+03	56000.00
AE0B60	2017-07-19 22:43:00+03	48500.00
AE0BCD	2017-08-03 23:12:00+03	139400.00
AE0BD0	2017-08-06 16:34:00+03	41600.00
AE0BF1	2017-08-14 08:53:00+03	282300.00
AE0C2D	2017-07-21 20:29:00+03	28600.00
AE0C6A	2017-07-19 12:29:00+03	57500.00
AE0C83	2017-08-08 01:21:00+03	81700.00
AE0C87	2017-07-05 19:43:00+03	55800.00
AE0C88	2017-08-02 15:19:00+03	24600.00
AE0D12	2017-08-08 04:57:00+03	31900.00
AE0D72	2017-07-25 20:19:00+03	124000.00
AE0DA6	2017-08-09 14:01:00+03	6000.00
AE0DDA	2017-07-14 18:29:00+03	23200.00
AE0DDE	2017-08-11 07:48:00+03	92900.00
AE0E13	2017-07-28 03:32:00+03	125200.00
AE0E63	2017-08-14 01:14:00+03	62900.00
AE0E81	2017-07-07 09:03:00+03	191200.00
AE0EEE	2017-08-01 15:46:00+03	26100.00
AE0F38	2017-07-15 07:31:00+03	20200.00
AE0F44	2017-06-30 22:35:00+03	238600.00
AE0FA4	2017-08-11 23:04:00+03	163100.00
AE103A	2017-07-16 16:18:00+03	54500.00
AE1063	2017-07-02 23:05:00+03	136800.00
AE10F0	2017-07-20 13:25:00+03	76800.00
AE10F4	2017-07-11 02:08:00+03	81800.00
AE114A	2017-07-05 12:52:00+03	47800.00
AE11A5	2017-08-14 03:56:00+03	56900.00
AE128B	2017-07-28 03:09:00+03	56000.00
AE12FE	2017-07-03 00:01:00+03	56000.00
AE1305	2017-07-26 05:03:00+03	188800.00
AE132F	2017-07-27 12:31:00+03	26800.00
AE1348	2017-08-11 21:10:00+03	67600.00
AE135D	2017-08-07 06:37:00+03	51600.00
AE1462	2017-07-25 00:57:00+03	39300.00
AE148E	2017-07-27 09:55:00+03	116000.00
AE14B8	2017-07-05 12:33:00+03	65900.00
AE1547	2017-07-02 08:17:00+03	125400.00
AE1561	2017-08-10 06:37:00+03	46000.00
AE1579	2017-07-27 15:46:00+03	337600.00
AE158E	2017-07-14 13:57:00+03	246000.00
AE15E3	2017-07-03 19:31:00+03	96300.00
AE15E5	2017-07-27 05:14:00+03	46400.00
AE1640	2017-08-08 01:51:00+03	66000.00
AE16E1	2017-08-14 16:10:00+03	23600.00
AE17A5	2017-08-02 06:00:00+03	95000.00
AE17DA	2017-08-14 03:05:00+03	42000.00
AE17EE	2017-07-22 16:37:00+03	50600.00
AE1806	2017-07-27 05:37:00+03	18900.00
AE190F	2017-07-26 09:28:00+03	20200.00
AE193C	2017-07-08 17:53:00+03	15100.00
AE19AE	2017-07-08 13:44:00+03	64400.00
AE19B3	2017-07-01 10:41:00+03	103700.00
AE19B6	2017-07-20 19:53:00+03	30700.00
AE1AA1	2017-07-05 23:57:00+03	41800.00
AE1AC3	2017-07-11 20:28:00+03	53600.00
AE1AFC	2017-08-07 21:13:00+03	248500.00
AE1B02	2017-07-13 19:37:00+03	26800.00
AE1B23	2017-08-02 22:36:00+03	38000.00
AE1B75	2017-07-10 08:37:00+03	34800.00
AE1B8B	2017-07-31 17:39:00+03	372500.00
AE1BB0	2017-07-06 18:29:00+03	6000.00
AE1BF1	2017-07-09 04:09:00+03	46900.00
AE1BF4	2017-08-12 02:29:00+03	85000.00
AE1BFC	2017-07-17 14:16:00+03	62000.00
AE1C19	2017-08-06 19:30:00+03	6700.00
AE1C8F	2017-07-11 19:49:00+03	56600.00
AE1CCF	2017-07-16 00:45:00+03	49800.00
AE1D59	2017-08-02 01:56:00+03	14400.00
AE1D5B	2017-08-02 04:46:00+03	76800.00
AE1E24	2017-07-16 04:12:00+03	234800.00
AE1E2C	2017-06-30 13:13:00+03	51800.00
AE1EFD	2017-07-08 08:52:00+03	11800.00
AE1F70	2017-06-28 23:52:00+03	99300.00
AE1FCA	2017-07-11 08:13:00+03	69000.00
AE1FF3	2017-08-06 10:27:00+03	25800.00
AE2103	2017-07-10 06:46:00+03	78600.00
AE214D	2017-08-13 17:03:00+03	103200.00
AE21BA	2017-08-05 08:45:00+03	64600.00
AE21C1	2017-07-31 08:22:00+03	46400.00
AE21C2	2017-07-14 05:32:00+03	134400.00
AE21DA	2017-07-29 06:03:00+03	49600.00
AE2216	2017-07-06 09:47:00+03	74700.00
AE2241	2017-08-13 10:54:00+03	6000.00
AE22C9	2017-07-06 13:11:00+03	11600.00
AE22E4	2017-07-15 00:08:00+03	119400.00
AE237D	2017-07-14 08:02:00+03	26800.00
AE23DD	2017-08-09 16:11:00+03	39300.00
AE2402	2017-07-20 22:35:00+03	25400.00
AE2416	2017-08-08 02:20:00+03	47100.00
AE2436	2017-08-06 13:09:00+03	47400.00
AE243C	2017-07-03 21:10:00+03	28000.00
AE2486	2017-07-14 06:41:00+03	73200.00
AE253D	2017-08-02 13:13:00+03	250100.00
AE25BF	2017-07-15 10:57:00+03	99300.00
AE2604	2017-07-22 14:08:00+03	62000.00
AE2618	2017-08-05 19:50:00+03	153300.00
AE2683	2017-07-24 07:28:00+03	19600.00
AE26AF	2017-07-12 17:23:00+03	94300.00
AE26C2	2017-07-25 07:47:00+03	65300.00
AE26EE	2017-07-31 23:20:00+03	138100.00
AE2732	2017-08-10 23:53:00+03	42900.00
AE275D	2017-08-07 06:58:00+03	166100.00
AE2782	2017-06-29 12:33:00+03	26800.00
AE27AD	2017-08-04 03:28:00+03	39800.00
AE27E8	2017-07-18 21:33:00+03	198600.00
AE27EB	2017-07-20 19:00:00+03	57500.00
AE2803	2017-07-09 23:42:00+03	136000.00
AE281A	2017-08-10 16:27:00+03	20000.00
AE2844	2017-07-10 08:11:00+03	24400.00
AE291A	2017-07-04 06:38:00+03	98300.00
AE2932	2017-06-27 06:29:00+03	87100.00
AE297F	2017-07-24 19:46:00+03	123000.00
AE29A9	2017-07-13 21:53:00+03	167400.00
AE29F8	2017-07-24 18:36:00+03	22000.00
AE2A03	2017-08-15 06:42:00+03	44500.00
AE2A3F	2017-07-31 06:45:00+03	37900.00
AE2A74	2017-07-21 22:20:00+03	35800.00
AE2A7A	2017-08-06 05:16:00+03	51500.00
AE2ADD	2017-07-16 15:37:00+03	19600.00
AE2C2A	2017-06-27 22:12:00+03	34000.00
AE2C68	2017-07-07 00:57:00+03	185300.00
AE2CED	2017-08-13 13:17:00+03	212800.00
AE2CF7	2017-07-23 10:23:00+03	19200.00
AE2CFC	2017-07-12 20:21:00+03	199300.00
AE2D3B	2017-07-21 12:15:00+03	62600.00
AE2D50	2017-07-08 06:13:00+03	23200.00
AE2DDB	2017-07-18 09:38:00+03	23200.00
AE2DE2	2017-07-10 15:40:00+03	36600.00
AE2DFF	2017-08-08 06:58:00+03	27400.00
AE2E65	2017-07-28 21:07:00+03	13000.00
AE2E76	2017-07-08 16:41:00+03	112000.00
AE2EA5	2017-08-15 09:55:00+03	84500.00
AE2ECE	2017-08-11 13:39:00+03	48800.00
AE2ED1	2017-07-19 08:02:00+03	23200.00
AE2F21	2017-07-24 18:26:00+03	56000.00
AE2F40	2017-07-11 09:52:00+03	24400.00
AE315A	2017-07-27 23:05:00+03	83100.00
AE316B	2017-07-22 20:14:00+03	14000.00
AE31A9	2017-07-25 09:21:00+03	40000.00
AE31E8	2017-07-28 13:13:00+03	52900.00
AE3203	2017-07-13 21:03:00+03	14400.00
AE3252	2017-08-07 13:14:00+03	115900.00
AE328E	2017-07-17 05:45:00+03	14900.00
AE3307	2017-08-04 19:40:00+03	136200.00
AE330E	2017-08-15 08:00:00+03	14900.00
AE3322	2017-07-12 09:45:00+03	120800.00
AE33A2	2017-07-26 10:24:00+03	46400.00
AE33CE	2017-07-31 13:30:00+03	47200.00
AE3487	2017-07-08 05:58:00+03	32400.00
AE3499	2017-07-14 17:02:00+03	34100.00
AE34D9	2017-07-05 14:13:00+03	131600.00
AE350E	2017-07-03 11:12:00+03	56000.00
AE3540	2017-07-04 12:28:00+03	6200.00
AE3570	2017-07-03 07:11:00+03	61500.00
AE35A1	2017-07-01 08:57:00+03	73500.00
AE35C2	2017-07-02 04:16:00+03	37100.00
AE3604	2017-07-24 12:34:00+03	56600.00
AE3610	2017-08-14 06:22:00+03	23200.00
AE366B	2017-08-12 08:35:00+03	67200.00
AE36B6	2017-07-28 23:05:00+03	203000.00
AE3734	2017-07-14 10:59:00+03	119500.00
AE3743	2017-07-17 13:59:00+03	44000.00
AE3744	2017-08-03 23:46:00+03	46300.00
AE3769	2017-07-18 16:46:00+03	66000.00
AE3779	2017-07-17 15:22:00+03	97600.00
AE377F	2017-07-29 15:24:00+03	70400.00
AE3865	2017-08-07 17:26:00+03	14000.00
AE3896	2017-07-10 07:33:00+03	25400.00
AE38D7	2017-07-12 17:40:00+03	58800.00
AE3920	2017-07-23 20:34:00+03	136100.00
AE392C	2017-07-18 04:44:00+03	113200.00
AE397C	2017-07-14 06:47:00+03	25400.00
AE3993	2017-08-13 21:17:00+03	55800.00
AE39D1	2017-08-10 19:58:00+03	146300.00
AE39D9	2017-08-06 14:44:00+03	46400.00
AE39E9	2017-06-30 09:26:00+03	115600.00
AE39EA	2017-08-15 17:44:00+03	6300.00
AE3A63	2017-06-28 12:29:00+03	26800.00
AE3A7A	2017-07-31 03:09:00+03	44700.00
AE3AC6	2017-08-01 16:51:00+03	103800.00
AE3ADD	2017-08-12 22:27:00+03	116700.00
AE3B02	2017-08-08 22:18:00+03	26800.00
AE3B1B	2017-08-05 10:44:00+03	23600.00
AE3B76	2017-07-16 11:40:00+03	113200.00
AE3B8C	2017-07-17 21:06:00+03	81600.00
AE3BD9	2017-08-15 14:04:00+03	47400.00
AE3C16	2017-08-15 01:55:00+03	87200.00
AE3C2D	2017-07-26 05:02:00+03	38800.00
AE3C49	2017-07-11 15:35:00+03	33300.00
AE3C5A	2017-08-09 19:06:00+03	40800.00
AE3C69	2017-07-31 02:35:00+03	72400.00
AE3C6A	2017-07-14 16:21:00+03	123000.00
AE3C7C	2017-08-09 02:29:00+03	48400.00
AE3CD2	2017-08-05 08:51:00+03	84000.00
AE3D07	2017-07-25 00:14:00+03	99500.00
AE3D68	2017-08-07 04:53:00+03	410200.00
AE3E3D	2017-07-10 16:13:00+03	67300.00
AE3E71	2017-07-15 09:44:00+03	43900.00
AE3E79	2017-07-16 03:49:00+03	89700.00
AE3F8B	2017-08-04 13:58:00+03	6000.00
AE3F91	2017-07-15 13:53:00+03	147700.00
AE3FC6	2017-07-28 20:15:00+03	38500.00
AE401D	2017-08-03 21:22:00+03	43100.00
AE4061	2017-07-05 23:08:00+03	28800.00
AE40B5	2017-07-12 04:49:00+03	55800.00
AE40B6	2017-07-17 15:43:00+03	21400.00
AE40F3	2017-08-14 09:13:00+03	13400.00
AE4124	2017-08-09 17:52:00+03	20400.00
AE4179	2017-08-05 00:19:00+03	75700.00
AE41A3	2017-07-07 08:46:00+03	64800.00
AE423D	2017-07-20 09:28:00+03	133100.00
AE4273	2017-08-03 00:00:00+03	148600.00
AE4344	2017-07-21 16:30:00+03	54000.00
AE4391	2017-08-02 20:01:00+03	37200.00
AE4394	2017-08-13 11:37:00+03	37700.00
AE43A6	2017-07-16 09:00:00+03	46000.00
AE43CE	2017-07-28 21:28:00+03	6800.00
AE4497	2017-07-11 13:55:00+03	29800.00
AE44C0	2017-07-02 22:10:00+03	133200.00
AE44CB	2017-08-11 16:45:00+03	58700.00
AE4517	2017-08-04 02:49:00+03	26000.00
AE455A	2017-08-02 06:35:00+03	59300.00
AE45D8	2017-08-14 15:55:00+03	28200.00
AE461F	2017-08-01 04:14:00+03	14400.00
AE4621	2017-08-07 05:22:00+03	36400.00
AE4626	2017-08-13 06:25:00+03	103000.00
AE4665	2017-07-08 00:44:00+03	48400.00
AE46B0	2017-07-10 03:48:00+03	344800.00
AE46F9	2017-07-08 01:05:00+03	39200.00
AE4719	2017-07-13 03:33:00+03	541500.00
AE4758	2017-07-31 13:02:00+03	6700.00
AE47ED	2017-07-13 12:32:00+03	260300.00
AE4849	2017-07-13 06:26:00+03	53200.00
AE4880	2017-07-04 19:58:00+03	37200.00
AE491A	2017-08-11 07:51:00+03	36200.00
AE4A90	2017-07-23 06:49:00+03	57600.00
AE4A97	2017-07-18 06:59:00+03	31300.00
AE4B25	2017-07-16 03:07:00+03	6300.00
AE4C08	2017-07-17 23:39:00+03	47000.00
AE4C75	2017-07-17 21:43:00+03	246000.00
AE4CA0	2017-07-16 01:51:00+03	54500.00
AE4CB4	2017-07-26 03:27:00+03	26000.00
AE4E16	2017-07-26 16:53:00+03	148800.00
AE4E5B	2017-07-09 09:50:00+03	6000.00
AE4E6C	2017-07-22 18:33:00+03	151900.00
AE4EE3	2017-07-23 00:19:00+03	61800.00
AE4EE5	2017-07-18 20:55:00+03	43200.00
AE4F01	2017-08-05 03:12:00+03	46800.00
AE4F3B	2017-07-26 23:10:00+03	33300.00
AE4F3E	2017-07-28 09:25:00+03	21500.00
AE4FC2	2017-07-26 18:51:00+03	101200.00
AE5017	2017-07-14 02:06:00+03	55800.00
AE503B	2017-07-14 16:33:00+03	44000.00
AE50FB	2017-07-05 22:41:00+03	229500.00
AE5182	2017-08-02 18:57:00+03	67600.00
AE51AF	2017-07-26 00:37:00+03	38600.00
AE51B1	2017-08-09 06:21:00+03	96300.00
AE51BB	2017-07-26 11:07:00+03	43600.00
AE51CC	2017-07-31 07:25:00+03	89600.00
AE51E8	2017-08-06 11:56:00+03	6300.00
AE5216	2017-07-22 08:06:00+03	7400.00
AE5226	2017-07-11 05:44:00+03	12400.00
AE5266	2017-07-11 06:54:00+03	123000.00
AE52AE	2017-08-12 10:30:00+03	203400.00
AE52B3	2017-07-31 03:36:00+03	14000.00
AE5321	2017-07-24 00:17:00+03	16400.00
AE5351	2017-07-18 23:39:00+03	40800.00
AE53A5	2017-08-12 18:19:00+03	131100.00
AE53FC	2017-08-08 09:00:00+03	199200.00
AE5400	2017-07-29 01:52:00+03	28000.00
AE5513	2017-07-16 21:27:00+03	226200.00
AE552B	2017-07-18 21:11:00+03	122500.00
AE5558	2017-07-19 05:07:00+03	76200.00
AE5590	2017-07-28 03:22:00+03	54400.00
AE55BF	2017-07-18 02:20:00+03	26000.00
AE55F7	2017-07-05 07:56:00+03	266100.00
AE5612	2017-07-09 01:58:00+03	56600.00
AE565F	2017-08-03 10:16:00+03	79600.00
AE5694	2017-07-11 15:01:00+03	58800.00
AE569A	2017-07-31 16:40:00+03	233000.00
AE56B9	2017-06-29 20:37:00+03	56900.00
AE5703	2017-07-10 15:34:00+03	73300.00
AE5710	2017-07-21 14:19:00+03	69500.00
AE5718	2017-08-02 17:29:00+03	154500.00
AE576C	2017-07-03 05:38:00+03	54800.00
AE57EB	2017-08-03 21:26:00+03	56600.00
AE586D	2017-07-04 19:42:00+03	136200.00
AE589F	2017-07-09 20:46:00+03	57500.00
AE591F	2017-07-01 21:21:00+03	68800.00
AE592E	2017-07-12 19:58:00+03	59200.00
AE5954	2017-07-12 03:02:00+03	56900.00
AE595B	2017-08-02 05:37:00+03	10800.00
AE5976	2017-07-27 14:52:00+03	55800.00
AE59A4	2017-07-18 16:48:00+03	56000.00
AE59BD	2017-07-08 09:04:00+03	160100.00
AE5A9A	2017-07-23 10:54:00+03	48800.00
AE5B17	2017-07-20 01:14:00+03	33300.00
AE5B68	2017-07-04 05:24:00+03	8400.00
AE5BB3	2017-07-11 11:00:00+03	44500.00
AE5C2D	2017-08-02 11:39:00+03	117600.00
AE5C2E	2017-07-06 19:56:00+03	153200.00
AE5C47	2017-07-21 04:06:00+03	14900.00
AE5C59	2017-08-09 02:23:00+03	58000.00
AE5CA5	2017-07-23 13:58:00+03	55800.00
AE5CA6	2017-07-31 21:40:00+03	169900.00
AE5CA7	2017-08-02 18:59:00+03	27000.00
AE5CAB	2017-07-19 04:26:00+03	35300.00
AE5CCB	2017-08-09 15:51:00+03	25100.00
AE5D28	2017-08-08 05:41:00+03	94300.00
AE5D31	2017-07-07 21:16:00+03	62000.00
AE5D86	2017-07-07 16:59:00+03	102100.00
AE5D9E	2017-07-11 01:37:00+03	70800.00
AE5DBB	2017-07-07 03:10:00+03	58800.00
AE5E07	2017-07-29 07:28:00+03	107100.00
AE5E19	2017-08-05 09:28:00+03	139100.00
AE5E54	2017-08-07 18:39:00+03	53600.00
AE5E84	2017-08-03 04:07:00+03	43600.00
AE5E8E	2017-07-10 19:01:00+03	36800.00
AE5E98	2017-07-18 14:57:00+03	54500.00
AE5EBA	2017-08-12 15:12:00+03	70100.00
AE5F3C	2017-07-10 09:53:00+03	99200.00
AE5F3D	2017-07-07 14:29:00+03	135200.00
AE5F86	2017-07-27 12:58:00+03	189200.00
AE5FBE	2017-07-28 12:57:00+03	54800.00
AE6091	2017-07-07 22:02:00+03	273200.00
AE6093	2017-07-28 07:15:00+03	67100.00
AE60B8	2017-07-04 09:08:00+03	279800.00
AE60BC	2017-08-13 13:02:00+03	59800.00
AE60C8	2017-06-30 02:26:00+03	28000.00
AE6127	2017-08-10 11:57:00+03	25400.00
AE6175	2017-07-14 00:50:00+03	139300.00
AE61AB	2017-07-12 18:55:00+03	301800.00
AE61E9	2017-08-11 03:25:00+03	24400.00
AE622D	2017-07-22 15:40:00+03	111600.00
AE62AC	2017-08-11 04:15:00+03	135400.00
AE62CD	2017-07-15 22:33:00+03	97900.00
AE62F0	2017-08-08 22:42:00+03	104100.00
AE6331	2017-08-03 02:54:00+03	71900.00
AE6345	2017-07-11 20:04:00+03	235800.00
AE634B	2017-07-18 12:43:00+03	369000.00
AE6391	2017-07-20 23:03:00+03	6000.00
AE6406	2017-07-28 14:26:00+03	6300.00
AE6445	2017-08-08 18:38:00+03	22000.00
AE644F	2017-07-23 08:57:00+03	185800.00
AE6471	2017-07-02 18:14:00+03	127100.00
AE64A7	2017-07-27 19:44:00+03	266400.00
AE64AF	2017-08-03 06:34:00+03	27300.00
AE64E9	2017-07-30 14:59:00+03	90000.00
AE64F1	2017-08-10 06:35:00+03	12600.00
AE6530	2017-08-14 10:51:00+03	67600.00
AE656C	2017-08-08 16:58:00+03	28000.00
AE659E	2017-07-25 19:52:00+03	19800.00
AE65A0	2017-07-24 08:01:00+03	56000.00
AE65FD	2017-07-04 08:19:00+03	28000.00
AE6604	2017-07-21 04:45:00+03	46300.00
AE6605	2017-07-19 04:52:00+03	6300.00
AE6614	2017-08-14 04:17:00+03	166100.00
AE6666	2017-07-08 14:23:00+03	13200.00
AE668E	2017-07-30 22:16:00+03	49100.00
AE66D4	2017-08-15 05:16:00+03	107900.00
AE6720	2017-08-13 00:36:00+03	23200.00
AE6727	2017-07-04 23:27:00+03	15000.00
AE674E	2017-08-07 07:10:00+03	113300.00
AE6765	2017-08-13 00:57:00+03	26800.00
AE6773	2017-07-14 05:24:00+03	7400.00
AE6796	2017-08-13 11:49:00+03	44500.00
AE67A0	2017-08-06 14:38:00+03	43200.00
AE6802	2017-07-07 04:43:00+03	56100.00
AE683A	2017-07-18 00:21:00+03	64500.00
AE683E	2017-07-05 10:22:00+03	265600.00
AE6850	2017-07-07 12:12:00+03	8000.00
AE6853	2017-08-01 16:19:00+03	46700.00
AE68E8	2017-07-28 05:39:00+03	22600.00
AE69B1	2017-08-04 10:57:00+03	185600.00
AE69C0	2017-08-06 22:11:00+03	285000.00
AE69CF	2017-07-14 11:36:00+03	76200.00
AE69F6	2017-07-26 10:28:00+03	14000.00
AE6A60	2017-08-15 04:50:00+03	83000.00
AE6A89	2017-08-11 22:23:00+03	93900.00
AE6A9D	2017-08-02 02:59:00+03	209900.00
AE6AC3	2017-07-11 23:47:00+03	8400.00
AE6B5A	2017-07-20 05:38:00+03	175700.00
AE6B62	2017-07-28 15:47:00+03	54400.00
AE6BCF	2017-08-09 12:21:00+03	103800.00
AE6BFE	2017-08-14 17:49:00+03	66600.00
AE6C02	2017-07-24 19:28:00+03	40400.00
AE6C0B	2017-07-17 19:58:00+03	70700.00
AE6D45	2017-07-03 18:09:00+03	40200.00
AE6D48	2017-07-30 07:47:00+03	58600.00
AE6D96	2017-08-09 10:39:00+03	77400.00
AE6DC5	2017-07-19 04:40:00+03	15800.00
AE6DDC	2017-07-15 23:33:00+03	74400.00
AE6E24	2017-07-29 21:05:00+03	93900.00
AE6E9B	2017-07-06 09:18:00+03	67400.00
AE6F4C	2017-07-12 21:29:00+03	7400.00
AE6FD7	2017-07-30 11:36:00+03	21400.00
AE701E	2017-07-06 03:10:00+03	141000.00
AE7052	2017-07-30 18:57:00+03	48300.00
AE7079	2017-07-02 02:28:00+03	231800.00
AE7090	2017-07-26 03:42:00+03	24200.00
AE70A0	2017-07-11 02:47:00+03	45200.00
AE70C0	2017-07-15 18:49:00+03	219300.00
AE712D	2017-07-09 06:08:00+03	22000.00
AE7154	2017-08-14 06:34:00+03	45100.00
AE71C0	2017-08-01 11:05:00+03	54300.00
AE71C2	2017-07-17 05:36:00+03	39800.00
AE7215	2017-07-12 04:47:00+03	67600.00
AE7247	2017-08-14 16:36:00+03	124200.00
AE726D	2017-08-14 13:46:00+03	39200.00
AE72A4	2017-07-31 18:36:00+03	246000.00
AE72D3	2017-06-29 14:58:00+03	136100.00
AE7333	2017-07-25 12:54:00+03	119400.00
AE7347	2017-08-07 10:33:00+03	141600.00
AE735E	2017-07-02 22:10:00+03	270800.00
AE73FD	2017-07-21 17:11:00+03	58400.00
AE7428	2017-07-17 15:07:00+03	93900.00
AE743F	2017-08-15 07:39:00+03	109600.00
AE7454	2017-07-11 08:00:00+03	42800.00
AE7486	2017-07-19 13:35:00+03	23100.00
AE7495	2017-07-19 15:18:00+03	6600.00
AE74A4	2017-07-22 18:19:00+03	94000.00
AE7530	2017-07-24 03:06:00+03	28000.00
AE7551	2017-07-10 21:34:00+03	116400.00
AE75A9	2017-07-07 18:55:00+03	20600.00
AE75BF	2017-07-06 01:47:00+03	94700.00
AE7659	2017-07-09 07:59:00+03	119400.00
AE7666	2017-07-30 17:16:00+03	20100.00
AE7698	2017-07-12 17:38:00+03	38300.00
AE76A9	2017-07-08 12:51:00+03	22100.00
AE7736	2017-07-28 09:37:00+03	396200.00
AE7760	2017-08-07 16:16:00+03	85400.00
AE7768	2017-08-13 07:46:00+03	59800.00
AE77C5	2017-06-30 10:25:00+03	92200.00
AE77CE	2017-07-20 21:13:00+03	37900.00
AE788E	2017-07-30 02:22:00+03	666000.00
AE78A7	2017-08-04 07:45:00+03	177600.00
AE78DA	2017-07-25 10:32:00+03	28000.00
AE794D	2017-07-12 15:44:00+03	231400.00
AE7969	2017-07-06 14:26:00+03	170300.00
AE79DB	2017-07-03 19:35:00+03	46400.00
AE7A79	2017-06-28 10:27:00+03	57600.00
AE7AA8	2017-07-12 17:12:00+03	94000.00
AE7AB4	2017-07-15 16:57:00+03	10800.00
AE7B47	2017-08-05 16:33:00+03	34600.00
AE7B60	2017-08-10 19:04:00+03	111600.00
AE7BFB	2017-07-16 11:02:00+03	50600.00
AE7C33	2017-08-03 23:11:00+03	28000.00
AE7C4C	2017-08-05 03:39:00+03	27000.00
AE7C52	2017-07-09 14:53:00+03	67200.00
AE7C72	2017-08-03 12:40:00+03	28000.00
AE7CA1	2017-07-14 02:21:00+03	167400.00
AE7CBB	2017-07-27 14:47:00+03	70600.00
AE7CF1	2017-07-27 04:29:00+03	249000.00
AE7D5D	2017-07-07 08:56:00+03	11800.00
AE7D67	2017-08-05 15:56:00+03	305500.00
AE7E08	2017-07-02 22:27:00+03	45200.00
AE7E14	2017-07-04 05:22:00+03	12400.00
AE7E41	2017-07-06 01:22:00+03	62700.00
AE7E4E	2017-07-01 15:42:00+03	54800.00
AE7E66	2017-07-18 09:41:00+03	55800.00
AE7EF8	2017-08-04 17:16:00+03	114200.00
AE7F20	2017-07-06 21:34:00+03	31600.00
AE7F3F	2017-08-11 16:48:00+03	369000.00
AE7F5E	2017-07-09 23:35:00+03	78500.00
AE7F8E	2017-08-04 19:55:00+03	25600.00
AE7FCB	2017-08-11 10:18:00+03	84500.00
AE7FDB	2017-08-05 17:42:00+03	68800.00
AE8005	2017-08-01 12:06:00+03	6000.00
AE8018	2017-07-18 13:51:00+03	24800.00
AE8019	2017-08-15 07:59:00+03	57500.00
AE801F	2017-08-10 22:52:00+03	28800.00
AE8055	2017-08-01 04:48:00+03	72800.00
AE80C5	2017-07-30 13:18:00+03	29600.00
AE80ED	2017-07-17 01:35:00+03	16400.00
AE80FF	2017-08-06 22:25:00+03	24800.00
AE8163	2017-08-08 07:42:00+03	25800.00
AE8177	2017-07-18 01:04:00+03	108500.00
AE817A	2017-07-10 12:38:00+03	81200.00
AE8264	2017-08-14 20:19:00+03	48800.00
AE8275	2017-08-01 08:17:00+03	73600.00
AE82F5	2017-07-29 10:55:00+03	20200.00
AE8342	2017-07-24 02:18:00+03	47500.00
AE8347	2017-07-28 06:54:00+03	56900.00
AE8366	2017-07-09 11:24:00+03	25400.00
AE83AE	2017-08-01 01:38:00+03	74100.00
AE83D7	2017-08-11 10:37:00+03	46600.00
AE840F	2017-08-13 21:44:00+03	23600.00
AE8418	2017-07-28 10:38:00+03	11000.00
AE8439	2017-07-10 16:03:00+03	20400.00
AE848F	2017-07-02 15:00:00+03	223200.00
AE849F	2017-07-14 11:04:00+03	84600.00
AE84D6	2017-07-04 08:07:00+03	13400.00
AE84DE	2017-08-05 08:41:00+03	82900.00
AE850E	2017-08-01 22:42:00+03	68400.00
AE852C	2017-07-21 17:20:00+03	10600.00
AE8537	2017-07-26 05:25:00+03	117600.00
AE853B	2017-07-17 00:05:00+03	35600.00
AE853D	2017-07-27 03:36:00+03	44500.00
AE85B7	2017-07-16 09:39:00+03	46400.00
AE85C8	2017-07-25 16:21:00+03	273600.00
AE8633	2017-08-15 16:54:00+03	54500.00
AE8643	2017-07-03 13:50:00+03	72400.00
AE8667	2017-07-31 13:16:00+03	159100.00
AE868E	2017-07-19 06:04:00+03	141000.00
AE8691	2017-07-23 17:12:00+03	48800.00
AE8723	2017-08-09 23:43:00+03	95200.00
AE872F	2017-07-05 08:06:00+03	128800.00
AE8775	2017-07-01 05:38:00+03	167400.00
AE8791	2017-08-04 17:02:00+03	44000.00
AE87F8	2017-07-01 18:14:00+03	28800.00
AE885B	2017-07-06 19:25:00+03	20200.00
AE8863	2017-07-29 18:18:00+03	24400.00
AE8890	2017-08-07 07:12:00+03	492000.00
AE88B3	2017-07-17 02:57:00+03	23600.00
AE8924	2017-07-16 19:18:00+03	26000.00
AE8942	2017-07-12 17:29:00+03	48500.00
AE8946	2017-07-13 04:55:00+03	6000.00
AE8996	2017-07-29 17:14:00+03	156500.00
AE89D5	2017-07-25 22:42:00+03	28800.00
AE8A95	2017-07-06 07:00:00+03	11800.00
AE8B0A	2017-08-10 00:45:00+03	290500.00
AE8B3B	2017-08-11 20:09:00+03	69000.00
AE8B62	2017-07-13 12:29:00+03	101200.00
AE8BF2	2017-08-09 05:07:00+03	28300.00
AE8C12	2017-08-01 23:43:00+03	19600.00
AE8C29	2017-08-06 23:28:00+03	54000.00
AE8C4B	2017-07-13 02:37:00+03	37700.00
AE8D29	2017-08-14 21:19:00+03	85500.00
AE8D3D	2017-07-09 12:25:00+03	131100.00
AE8DDA	2017-08-10 04:28:00+03	19600.00
AE8E3D	2017-08-11 17:43:00+03	287800.00
AE8E44	2017-08-04 03:09:00+03	56000.00
AE8E52	2017-08-12 22:56:00+03	10800.00
AE8E68	2017-07-19 19:14:00+03	22000.00
AE8EE2	2017-07-26 04:26:00+03	13400.00
AE8EF5	2017-08-07 09:01:00+03	133100.00
AE8EF7	2017-07-18 01:57:00+03	77200.00
AE9006	2017-08-07 17:20:00+03	56000.00
AE9064	2017-07-25 13:18:00+03	67900.00
AE909A	2017-07-05 19:02:00+03	24400.00
AE90A0	2017-07-31 14:19:00+03	56000.00
AE90BF	2017-08-12 23:03:00+03	27200.00
AE90EC	2017-07-11 16:14:00+03	183200.00
AE9171	2017-07-14 15:45:00+03	65900.00
AE918E	2017-08-04 02:29:00+03	33200.00
AE91BF	2017-07-03 03:57:00+03	159100.00
AE91C2	2017-08-04 14:34:00+03	23200.00
AE9230	2017-07-21 15:14:00+03	69800.00
AE925F	2017-07-20 03:48:00+03	66600.00
AE9279	2017-07-18 18:40:00+03	46500.00
AE92B5	2017-08-11 07:40:00+03	58200.00
AE92CB	2017-07-15 17:20:00+03	248400.00
AE9357	2017-07-27 07:37:00+03	55800.00
AE9383	2017-07-28 02:32:00+03	23200.00
AE940C	2017-07-21 16:10:00+03	71100.00
AE94F1	2017-07-29 13:12:00+03	19600.00
AE9522	2017-07-19 06:55:00+03	20400.00
AE9528	2017-07-27 12:58:00+03	23200.00
AE9544	2017-07-13 04:46:00+03	14000.00
AE959F	2017-07-11 04:25:00+03	39000.00
AE95A3	2017-07-26 16:42:00+03	187500.00
AE9735	2017-07-24 13:59:00+03	175800.00
AE97C9	2017-07-17 12:49:00+03	25000.00
AE98B6	2017-08-08 09:34:00+03	24700.00
AE9937	2017-08-08 00:14:00+03	36000.00
AE994B	2017-08-01 08:22:00+03	65000.00
AE999E	2017-08-06 13:30:00+03	71600.00
AE99A7	2017-07-30 14:31:00+03	24000.00
AE99F4	2017-07-12 16:32:00+03	54800.00
AE9A05	2017-07-24 21:31:00+03	120000.00
AE9A81	2017-07-02 14:02:00+03	39800.00
AE9B09	2017-08-12 04:26:00+03	62700.00
AE9B2C	2017-06-29 00:17:00+03	73100.00
AE9C44	2017-06-29 07:33:00+03	23600.00
AE9C50	2017-08-06 12:56:00+03	28800.00
AE9CF7	2017-08-12 15:20:00+03	84500.00
AE9D11	2017-07-03 00:09:00+03	12600.00
AE9D1A	2017-07-04 13:57:00+03	6000.00
AE9D2F	2017-06-27 14:59:00+03	131600.00
AE9D53	2017-07-29 07:59:00+03	58200.00
AE9D86	2017-07-11 02:41:00+03	16400.00
AE9D9F	2017-08-05 20:40:00+03	13400.00
AE9DBA	2017-08-04 06:31:00+03	248400.00
AE9DC9	2017-07-01 07:22:00+03	92100.00
AE9E34	2017-08-04 23:27:00+03	131100.00
AE9E3D	2017-07-04 19:15:00+03	66600.00
AE9E54	2017-07-16 12:52:00+03	75000.00
AE9EBD	2017-08-05 03:32:00+03	65900.00
AE9EDB	2017-08-03 21:19:00+03	43400.00
AE9EEC	2017-07-06 10:12:00+03	89700.00
AE9F1C	2017-07-23 02:33:00+03	42800.00
AE9F3C	2017-07-26 01:35:00+03	81900.00
AE9F71	2017-06-29 15:25:00+03	24400.00
AEA04D	2017-07-08 10:41:00+03	6800.00
AEA0F6	2017-07-31 05:01:00+03	17800.00
AEA10C	2017-07-10 02:32:00+03	28800.00
AEA114	2017-07-04 21:34:00+03	57600.00
AEA115	2017-07-22 02:29:00+03	232800.00
AEA133	2017-07-04 10:52:00+03	23400.00
AEA18D	2017-07-15 16:05:00+03	280000.00
AEA1B5	2017-08-04 22:28:00+03	103000.00
AEA26D	2017-08-12 19:22:00+03	67600.00
AEA2C1	2017-08-01 08:49:00+03	19200.00
AEA31F	2017-08-10 08:32:00+03	14000.00
AEA3D6	2017-08-15 12:28:00+03	102800.00
AEA468	2017-08-13 02:24:00+03	8200.00
AEA534	2017-07-16 15:01:00+03	98400.00
AEA56F	2017-08-12 07:39:00+03	177200.00
AEA571	2017-07-09 21:45:00+03	36000.00
AEA5CC	2017-08-06 23:14:00+03	36200.00
AEA5D4	2017-07-05 16:08:00+03	28000.00
AEA5E3	2017-08-11 07:56:00+03	40000.00
AEA62F	2017-07-29 08:46:00+03	198400.00
AEA648	2017-07-15 21:41:00+03	187600.00
AEA669	2017-06-28 04:20:00+03	23400.00
AEA687	2017-07-13 03:44:00+03	67000.00
AEA688	2017-07-22 11:33:00+03	25400.00
AEA696	2017-08-09 03:53:00+03	12400.00
AEA69E	2017-07-01 05:34:00+03	28000.00
AEA77B	2017-07-25 01:36:00+03	56000.00
AEA784	2017-07-11 06:02:00+03	24400.00
AEA7A2	2017-07-22 17:52:00+03	75100.00
AEA7B6	2017-08-09 03:38:00+03	30200.00
AEA7ED	2017-07-23 07:18:00+03	36200.00
AEA7FC	2017-07-07 12:47:00+03	111600.00
AEA82E	2017-07-04 14:40:00+03	43500.00
AEA854	2017-08-04 08:16:00+03	21800.00
AEA8A2	2017-07-05 17:07:00+03	57300.00
AEA954	2017-07-30 04:51:00+03	67900.00
AEA981	2017-07-19 18:05:00+03	57800.00
AEA9EE	2017-08-06 13:50:00+03	56000.00
AEAA2B	2017-08-02 02:24:00+03	59300.00
AEAAD4	2017-07-07 00:44:00+03	6000.00
AEAB3F	2017-07-29 07:09:00+03	131100.00
AEAB8E	2017-07-15 13:03:00+03	212800.00
AEABC8	2017-08-06 22:03:00+03	24400.00
AEABC9	2017-07-26 19:42:00+03	24800.00
AEABD2	2017-07-17 13:11:00+03	130400.00
AEABD3	2017-08-01 08:19:00+03	166000.00
AEABDD	2017-08-15 17:26:00+03	55800.00
AEABFB	2017-07-07 22:27:00+03	14800.00
AEAC04	2017-08-07 03:42:00+03	89000.00
AEACCA	2017-07-30 00:02:00+03	36800.00
AEACDA	2017-07-05 15:03:00+03	56000.00
AEACEF	2017-08-03 08:54:00+03	6200.00
AEAD21	2017-07-21 19:18:00+03	17800.00
AEAD40	2017-08-08 00:25:00+03	187600.00
AEAD5C	2017-07-26 08:28:00+03	111600.00
AEAD5E	2017-07-17 14:48:00+03	116500.00
AEAD86	2017-08-03 18:30:00+03	57800.00
AEADAF	2017-07-18 10:58:00+03	246000.00
AEADEB	2017-07-28 14:19:00+03	133200.00
AEAE67	2017-07-04 00:45:00+03	30400.00
AEAE72	2017-07-25 15:15:00+03	25000.00
AEAEBD	2017-06-27 04:20:00+03	39200.00
AEAEDE	2017-07-27 17:04:00+03	56000.00
AEAEF5	2017-07-10 23:01:00+03	105600.00
AEAF5F	2017-08-13 17:36:00+03	26000.00
AEAF88	2017-07-25 14:18:00+03	55600.00
AEAFAF	2017-08-02 04:56:00+03	46000.00
AEB04F	2017-07-20 02:26:00+03	58800.00
AEB053	2017-07-29 19:59:00+03	16800.00
AEB0C1	2017-07-21 08:26:00+03	38800.00
AEB0D1	2017-08-01 15:59:00+03	8000.00
AEB0E9	2017-07-05 00:21:00+03	53600.00
AEB0F0	2017-07-30 20:25:00+03	30200.00
AEB0FF	2017-07-15 12:06:00+03	46200.00
AEB104	2017-08-05 02:00:00+03	28800.00
AEB15D	2017-07-10 12:05:00+03	173400.00
AEB167	2017-07-07 19:21:00+03	40300.00
AEB174	2017-08-04 04:26:00+03	69400.00
AEB1B4	2017-08-13 04:06:00+03	23100.00
AEB202	2017-06-30 01:19:00+03	147900.00
AEB232	2017-07-27 02:52:00+03	25000.00
AEB2B1	2017-07-27 14:54:00+03	15000.00
AEB2F8	2017-07-30 18:30:00+03	273600.00
AEB3A0	2017-08-14 08:53:00+03	27800.00
AEB3A9	2017-08-12 05:15:00+03	29600.00
AEB3CE	2017-06-29 14:39:00+03	13200.00
AEB3E7	2017-08-12 06:50:00+03	625400.00
AEB41E	2017-07-02 08:21:00+03	405100.00
AEB4F0	2017-07-31 18:54:00+03	75300.00
AEB519	2017-07-12 07:26:00+03	12400.00
AEB543	2017-07-13 16:10:00+03	41600.00
AEB5BF	2017-07-18 13:07:00+03	63200.00
AEB673	2017-08-11 18:51:00+03	46400.00
AEB6B7	2017-07-29 13:39:00+03	99800.00
AEB6C9	2017-07-26 06:40:00+03	246000.00
AEB6DE	2017-07-25 01:42:00+03	101200.00
AEB71A	2017-07-02 07:14:00+03	369000.00
AEB7B5	2017-07-01 16:24:00+03	68800.00
AEB7EE	2017-08-11 15:45:00+03	97900.00
AEB86D	2017-08-10 01:50:00+03	14000.00
AEB877	2017-08-14 13:12:00+03	89600.00
AEB89A	2017-07-18 14:42:00+03	17200.00
AEB906	2017-08-14 23:45:00+03	21200.00
AEB933	2017-07-05 20:03:00+03	56600.00
AEB965	2017-08-01 04:31:00+03	125200.00
AEB986	2017-07-19 19:11:00+03	53600.00
AEB9C6	2017-08-09 09:42:00+03	26000.00
AEBA1A	2017-07-11 08:43:00+03	88300.00
AEBAA7	2017-07-21 09:25:00+03	35100.00
AEBAFA	2017-07-14 20:33:00+03	47100.00
AEBB0E	2017-07-22 23:50:00+03	57700.00
AEBB69	2017-08-10 20:38:00+03	9200.00
AEBBD3	2017-07-26 14:59:00+03	23200.00
AEBBEE	2017-07-30 23:26:00+03	28000.00
AEBC03	2017-08-02 17:11:00+03	52400.00
AEBC0F	2017-08-07 01:14:00+03	71900.00
AEBC55	2017-07-26 22:23:00+03	48400.00
AEBCB2	2017-08-11 05:25:00+03	40100.00
AEBCB7	2017-07-28 03:22:00+03	28000.00
AEBCE6	2017-07-04 05:18:00+03	88000.00
AEBCF2	2017-07-30 18:35:00+03	86600.00
AEBD14	2017-08-04 18:22:00+03	126900.00
AEBD34	2017-08-07 18:53:00+03	28000.00
AEBD5B	2017-08-10 23:05:00+03	18400.00
AEBD88	2017-07-29 07:04:00+03	59800.00
AEBE27	2017-08-07 07:19:00+03	245400.00
AEBE3E	2017-08-04 18:53:00+03	123200.00
AEBE44	2017-07-08 16:48:00+03	40800.00
AEBEE0	2017-07-04 20:06:00+03	164800.00
AEBF2A	2017-07-28 10:07:00+03	40200.00
AEBF7D	2017-07-25 06:12:00+03	52000.00
AEBF85	2017-08-03 21:26:00+03	39500.00
AEBFAC	2017-08-12 23:03:00+03	521200.00
AEC09B	2017-07-16 12:52:00+03	35800.00
AEC0A4	2017-08-05 06:47:00+03	27200.00
AEC0CA	2017-07-04 13:46:00+03	111600.00
AEC0DC	2017-07-06 16:45:00+03	78300.00
AEC172	2017-08-01 03:56:00+03	153200.00
AEC186	2017-06-30 21:03:00+03	65500.00
AEC1ED	2017-08-14 12:09:00+03	34000.00
AEC210	2017-08-02 07:44:00+03	293900.00
AEC23E	2017-07-15 11:14:00+03	21400.00
AEC253	2017-07-22 02:21:00+03	29600.00
AEC2EA	2017-07-05 23:20:00+03	234600.00
AEC2ED	2017-07-26 04:40:00+03	6000.00
AEC382	2017-07-09 05:10:00+03	40000.00
AEC430	2017-08-13 20:02:00+03	542800.00
AEC486	2017-08-07 11:32:00+03	43900.00
AEC4A4	2017-07-21 19:13:00+03	9200.00
AEC50C	2017-08-13 09:30:00+03	189200.00
AEC538	2017-08-03 01:48:00+03	13400.00
AEC586	2017-07-19 21:07:00+03	39900.00
AEC58B	2017-07-20 18:06:00+03	114900.00
AEC58D	2017-07-25 02:04:00+03	59200.00
AEC5EF	2017-08-02 14:12:00+03	27800.00
AEC623	2017-07-10 07:35:00+03	40900.00
AEC6C8	2017-07-31 16:27:00+03	24400.00
AEC6D4	2017-07-17 01:30:00+03	27800.00
AEC6EF	2017-07-04 05:24:00+03	149300.00
AEC739	2017-07-13 16:49:00+03	84500.00
AEC74C	2017-08-09 18:55:00+03	13600.00
AEC758	2017-07-02 10:08:00+03	150600.00
AEC79C	2017-07-23 20:03:00+03	62000.00
AEC7DB	2017-07-27 03:57:00+03	26800.00
AEC841	2017-08-12 09:01:00+03	114600.00
AEC860	2017-07-12 08:17:00+03	71700.00
AEC8FE	2017-07-05 04:29:00+03	69900.00
AEC95F	2017-07-31 16:33:00+03	16400.00
AEC980	2017-07-03 00:56:00+03	76400.00
AEC9BB	2017-07-22 19:16:00+03	67100.00
AECA4C	2017-08-02 08:48:00+03	60400.00
AECAA3	2017-07-25 10:48:00+03	46300.00
AECAAE	2017-06-26 17:16:00+03	37500.00
AECAB9	2017-08-03 10:37:00+03	115400.00
AECAC5	2017-08-15 02:28:00+03	37200.00
AECAE8	2017-07-25 11:21:00+03	30800.00
AECB0A	2017-08-11 21:19:00+03	74800.00
AECB1C	2017-08-10 20:37:00+03	89600.00
AECB4F	2017-08-07 17:06:00+03	54800.00
AECB88	2017-07-25 12:56:00+03	66400.00
AECB9A	2017-08-01 00:31:00+03	8200.00
AECBFA	2017-07-29 18:00:00+03	23200.00
AECC21	2017-08-09 12:03:00+03	30300.00
AECCB5	2017-07-30 21:15:00+03	109600.00
AECD0A	2017-07-15 10:33:00+03	47200.00
AECD93	2017-08-11 07:45:00+03	24300.00
AECDAF	2017-07-03 02:41:00+03	40800.00
AECE37	2017-06-30 15:22:00+03	37200.00
AECE48	2017-07-31 23:58:00+03	49400.00
AECE55	2017-07-09 18:42:00+03	23200.00
AECE6A	2017-08-10 21:12:00+03	86200.00
AECEC2	2017-08-01 11:27:00+03	136200.00
AECF01	2017-07-18 08:46:00+03	199700.00
AECF0D	2017-08-02 10:49:00+03	70700.00
AECF61	2017-07-27 18:17:00+03	55800.00
AECF8B	2017-07-25 12:29:00+03	520600.00
AECF99	2017-08-04 15:49:00+03	27300.00
AECFAD	2017-08-07 01:15:00+03	18600.00
AECFCF	2017-07-17 06:14:00+03	28000.00
AED050	2017-07-11 04:37:00+03	60700.00
AED095	2017-07-20 20:18:00+03	105100.00
AED0DE	2017-07-20 02:21:00+03	80400.00
AED0F0	2017-07-30 00:14:00+03	66800.00
AED0F5	2017-07-05 05:30:00+03	56100.00
AED1F7	2017-08-10 14:22:00+03	8400.00
AED20A	2017-07-09 16:32:00+03	40100.00
AED2E6	2017-06-30 20:53:00+03	14100.00
AED317	2017-07-31 19:04:00+03	133100.00
AED357	2017-07-29 19:04:00+03	32400.00
AED35E	2017-08-06 22:26:00+03	99300.00
AED380	2017-07-29 09:29:00+03	8400.00
AED393	2017-07-28 02:42:00+03	101500.00
AED454	2017-08-10 04:39:00+03	73500.00
AED461	2017-07-24 20:00:00+03	168000.00
AED463	2017-08-03 14:18:00+03	56900.00
AED471	2017-07-02 18:57:00+03	32800.00
AED55B	2017-07-05 06:47:00+03	27000.00
AED585	2017-08-04 17:01:00+03	11800.00
AED5B2	2017-07-21 09:47:00+03	125200.00
AED5C2	2017-08-08 17:17:00+03	112000.00
AED5DE	2017-07-19 10:47:00+03	52300.00
AED5F6	2017-08-06 15:12:00+03	77200.00
AED6C7	2017-07-25 02:00:00+03	119700.00
AED736	2017-08-01 06:08:00+03	62600.00
AED74E	2017-07-13 13:25:00+03	12400.00
AED7BF	2017-07-26 16:47:00+03	12400.00
AED7ED	2017-08-08 12:03:00+03	6800.00
AED8D5	2017-07-13 07:52:00+03	39300.00
AED8E0	2017-07-07 11:59:00+03	36200.00
AED8F0	2017-07-23 09:16:00+03	14000.00
AED912	2017-07-26 04:17:00+03	48400.00
AED9D6	2017-07-11 00:13:00+03	28000.00
AEDA68	2017-07-05 19:13:00+03	28800.00
AEDAAB	2017-08-05 07:47:00+03	112600.00
AEDB32	2017-07-24 18:47:00+03	160200.00
AEDB50	2017-08-09 01:02:00+03	46400.00
AEDBC6	2017-08-04 05:38:00+03	144300.00
AEDBFE	2017-07-24 17:18:00+03	52100.00
AEDC19	2017-07-19 00:14:00+03	53800.00
AEDC43	2017-07-04 08:28:00+03	75600.00
AEDC51	2017-07-08 23:01:00+03	26000.00
AEDC94	2017-08-15 17:49:00+03	67400.00
AEDCAA	2017-07-26 22:42:00+03	38800.00
AEDD23	2017-08-04 06:36:00+03	426600.00
AEDD5F	2017-08-05 10:10:00+03	47400.00
AEDEA4	2017-07-17 23:23:00+03	28900.00
AEDEB1	2017-08-05 17:28:00+03	41400.00
AEDF0F	2017-07-10 02:46:00+03	13400.00
AEDFB6	2017-08-06 20:17:00+03	51900.00
AEDFEF	2017-07-02 18:19:00+03	207000.00
AEE010	2017-07-12 09:03:00+03	197700.00
AEE059	2017-07-26 09:31:00+03	21400.00
AEE072	2017-07-22 00:38:00+03	35700.00
AEE075	2017-08-08 00:19:00+03	89700.00
AEE0C0	2017-07-08 14:21:00+03	66600.00
AEE0D5	2017-08-11 21:29:00+03	124300.00
AEE12A	2017-08-01 12:54:00+03	52100.00
AEE134	2017-07-01 18:09:00+03	40100.00
AEE1F2	2017-07-27 00:31:00+03	65900.00
AEE26C	2017-07-08 00:28:00+03	21400.00
AEE30D	2017-07-16 05:00:00+03	246000.00
AEE33D	2017-08-03 05:30:00+03	44000.00
AEE356	2017-08-10 15:41:00+03	56200.00
AEE36C	2017-07-21 11:26:00+03	26000.00
AEE36D	2017-07-18 05:33:00+03	208700.00
AEE3A9	2017-07-28 13:20:00+03	47600.00
AEE3D2	2017-08-05 23:36:00+03	54400.00
AEE416	2017-08-14 02:33:00+03	61800.00
AEE45C	2017-07-26 14:26:00+03	47400.00
AEE4DC	2017-08-06 10:25:00+03	13600.00
AEE4FD	2017-07-01 03:00:00+03	56000.00
AEE540	2017-07-25 14:22:00+03	66000.00
AEE54D	2017-08-11 16:23:00+03	56000.00
AEE574	2017-08-06 08:54:00+03	42800.00
AEE5C0	2017-07-12 17:53:00+03	13400.00
AEE5E1	2017-07-27 11:22:00+03	95600.00
AEE60A	2017-07-20 09:27:00+03	23200.00
AEE6C6	2017-08-14 23:54:00+03	14400.00
AEE6CF	2017-08-02 11:47:00+03	117600.00
AEE6D1	2017-08-02 11:16:00+03	68800.00
AEE762	2017-08-06 09:38:00+03	75200.00
AEE7A9	2017-08-13 02:54:00+03	50600.00
AEE7C5	2017-08-04 18:52:00+03	40400.00
AEE7C6	2017-08-08 11:46:00+03	24600.00
AEE806	2017-07-31 19:13:00+03	372500.00
AEE838	2017-07-29 07:17:00+03	13800.00
AEE841	2017-07-02 12:18:00+03	59300.00
AEE871	2017-06-30 11:57:00+03	25600.00
AEE8E8	2017-07-08 06:52:00+03	42400.00
AEE944	2017-08-03 13:43:00+03	80900.00
AEE957	2017-07-13 13:59:00+03	62600.00
AEE97C	2017-07-29 16:54:00+03	94000.00
AEE981	2017-07-15 17:26:00+03	192500.00
AEE995	2017-07-19 18:36:00+03	26000.00
AEE9C0	2017-07-20 15:41:00+03	103500.00
AEE9F7	2017-07-13 10:44:00+03	79300.00
AEEA51	2017-07-17 11:03:00+03	60400.00
AEEACB	2017-07-16 11:46:00+03	14000.00
AEEAE4	2017-07-03 08:33:00+03	54500.00
AEEB08	2017-08-09 14:50:00+03	134400.00
AEEB1C	2017-07-21 20:04:00+03	37900.00
AEEB1F	2017-08-01 09:52:00+03	8000.00
AEEB7C	2017-08-06 10:27:00+03	44800.00
AEEB8A	2017-07-14 13:24:00+03	25600.00
AEEB99	2017-07-21 21:31:00+03	20200.00
AEEBDA	2017-07-19 00:22:00+03	68100.00
AEEC3E	2017-07-16 09:58:00+03	135600.00
AEEC46	2017-07-19 20:33:00+03	36900.00
AEEC87	2017-07-18 18:29:00+03	89600.00
AEEC97	2017-08-06 10:47:00+03	13400.00
AEECCB	2017-07-07 02:45:00+03	464600.00
AEECD0	2017-08-12 21:00:00+03	38400.00
AEED82	2017-08-05 10:32:00+03	28300.00
AEED84	2017-07-22 18:46:00+03	21400.00
AEEDB2	2017-08-09 01:46:00+03	26200.00
AEEE0B	2017-07-10 21:21:00+03	286700.00
AEEE2E	2017-08-13 22:02:00+03	8200.00
AEEE6E	2017-07-26 15:25:00+03	123600.00
AEEE7A	2017-07-18 00:22:00+03	76600.00
AEEE7E	2017-07-29 16:53:00+03	39100.00
AEEE9E	2017-07-23 14:47:00+03	52600.00
AEEF3D	2017-08-06 03:20:00+03	8400.00
AEEF95	2017-08-03 10:07:00+03	70500.00
AEF02A	2017-06-25 10:48:00+03	7400.00
AEF074	2017-07-31 11:49:00+03	102200.00
AEF09F	2017-07-31 13:32:00+03	73900.00
AEF0D8	2017-07-21 21:12:00+03	92800.00
AEF11E	2017-08-04 04:20:00+03	96300.00
AEF16D	2017-07-22 08:00:00+03	28800.00
AEF1B6	2017-08-06 17:30:00+03	67900.00
AEF210	2017-06-24 01:43:00+03	99600.00
AEF238	2017-07-08 14:23:00+03	146300.00
AEF250	2017-07-05 02:29:00+03	13000.00
AEF351	2017-07-30 17:20:00+03	97100.00
AEF365	2017-08-02 17:26:00+03	34000.00
AEF38D	2017-08-13 14:44:00+03	101200.00
AEF3BB	2017-08-12 09:37:00+03	250600.00
AEF3EB	2017-07-17 19:19:00+03	51100.00
AEF403	2017-07-01 23:06:00+03	135200.00
AEF404	2017-07-22 10:42:00+03	35300.00
AEF40B	2017-07-03 11:32:00+03	135000.00
AEF45A	2017-08-07 00:27:00+03	67600.00
AEF465	2017-08-11 14:01:00+03	32200.00
AEF516	2017-07-28 20:43:00+03	316200.00
AEF536	2017-07-05 08:59:00+03	6800.00
AEF571	2017-07-06 15:56:00+03	65600.00
AEF5A9	2017-07-23 12:56:00+03	13400.00
AEF5C2	2017-08-15 11:34:00+03	12000.00
AEF5FD	2017-08-03 00:46:00+03	32700.00
AEF65E	2017-08-08 04:57:00+03	166400.00
AEF675	2017-07-07 07:35:00+03	50000.00
AEF6C3	2017-08-04 23:17:00+03	27400.00
AEF723	2017-07-17 07:18:00+03	501100.00
AEF7C3	2017-08-05 09:41:00+03	138400.00
AEF7D0	2017-07-06 10:14:00+03	147200.00
AEF7E6	2017-08-12 04:42:00+03	40600.00
AEF81A	2017-08-05 07:14:00+03	26800.00
AEF83F	2017-07-13 05:21:00+03	23600.00
AEF890	2017-08-12 19:43:00+03	141300.00
AEF8CC	2017-06-30 12:43:00+03	39800.00
AEF8D1	2017-07-21 07:51:00+03	39200.00
AEF8ED	2017-07-19 20:54:00+03	22100.00
AEF9BE	2017-06-29 08:26:00+03	40000.00
AEFA14	2017-07-18 12:39:00+03	114200.00
AEFA6C	2017-07-02 01:34:00+03	23600.00
AEFAF2	2017-07-29 08:08:00+03	133200.00
AEFB7A	2017-08-06 23:40:00+03	22000.00
AEFB94	2017-07-18 00:50:00+03	28000.00
AEFBD2	2017-07-08 12:49:00+03	68800.00
AEFC30	2017-07-09 02:49:00+03	288600.00
AEFCA2	2017-08-15 13:35:00+03	13400.00
AEFCA5	2017-08-05 11:18:00+03	86800.00
AEFCBB	2017-07-31 21:46:00+03	85000.00
AEFCBE	2017-08-01 17:31:00+03	78300.00
AEFD64	2017-07-10 07:53:00+03	75300.00
AEFD6A	2017-08-10 20:39:00+03	136200.00
AEFD7B	2017-07-09 01:06:00+03	28000.00
AEFDCB	2017-08-10 17:10:00+03	369000.00
AEFDDD	2017-07-24 19:44:00+03	58000.00
AEFDE2	2017-07-14 18:12:00+03	28800.00
AEFE2E	2017-07-02 14:49:00+03	23200.00
AEFE33	2017-08-01 03:36:00+03	30200.00
AEFE67	2017-07-14 22:54:00+03	56000.00
AEFF48	2017-07-05 04:38:00+03	29400.00
AEFF4A	2017-07-03 22:00:00+03	10300.00
AEFF70	2017-07-01 22:02:00+03	65600.00
AEFF7C	2017-08-06 01:00:00+03	62600.00
AEFF92	2017-08-03 03:35:00+03	75300.00
AEFF97	2017-08-06 11:35:00+03	75200.00
AF001D	2017-07-27 16:03:00+03	30100.00
AF008F	2017-07-18 13:21:00+03	6700.00
AF00E9	2017-07-06 10:48:00+03	190400.00
AF014A	2017-08-09 10:23:00+03	62800.00
AF016B	2017-08-05 18:03:00+03	21600.00
AF018D	2017-07-25 00:43:00+03	35800.00
AF024F	2017-07-29 18:41:00+03	36200.00
AF0261	2017-07-02 09:32:00+03	26200.00
AF0263	2017-07-19 18:01:00+03	83000.00
AF02A1	2017-07-28 01:44:00+03	111700.00
AF02CB	2017-07-20 23:19:00+03	12600.00
AF02E9	2017-08-11 08:54:00+03	54000.00
AF02EF	2017-07-13 20:48:00+03	73500.00
AF02F4	2017-07-30 06:29:00+03	284800.00
AF0408	2017-07-15 05:00:00+03	272600.00
AF0460	2017-08-07 21:24:00+03	46300.00
AF0472	2017-07-07 09:27:00+03	139300.00
AF047F	2017-08-04 06:50:00+03	84100.00
AF04A4	2017-07-18 12:04:00+03	6800.00
AF04AD	2017-07-01 02:52:00+03	20000.00
AF054A	2017-08-06 22:21:00+03	38400.00
AF05CA	2017-08-04 20:09:00+03	49800.00
AF060C	2017-07-25 23:06:00+03	49400.00
AF0758	2017-07-29 08:51:00+03	168000.00
AF079E	2017-07-18 10:32:00+03	26000.00
AF07BC	2017-07-17 04:04:00+03	26000.00
AF0807	2017-07-22 06:14:00+03	111700.00
AF0812	2017-07-29 09:44:00+03	37200.00
AF0825	2017-07-04 00:36:00+03	115600.00
AF0855	2017-07-25 22:42:00+03	89300.00
AF0879	2017-07-23 16:03:00+03	138500.00
AF08D0	2017-07-26 02:13:00+03	18300.00
AF0912	2017-07-20 13:37:00+03	49400.00
AF091F	2017-07-30 03:33:00+03	128100.00
AF0957	2017-08-03 00:42:00+03	56600.00
AF097A	2017-07-07 16:34:00+03	46400.00
AF0A28	2017-07-01 19:34:00+03	56800.00
AF0A49	2017-08-09 11:31:00+03	16400.00
AF0AA8	2017-07-19 04:06:00+03	51800.00
AF0B81	2017-07-15 11:10:00+03	23200.00
AF0BD5	2017-08-15 14:53:00+03	113700.00
AF0BE4	2017-07-21 23:38:00+03	68400.00
AF0BEE	2017-07-28 08:41:00+03	167400.00
AF0BF0	2017-07-14 16:01:00+03	67000.00
AF0C05	2017-07-27 17:01:00+03	88500.00
AF0C2B	2017-07-16 01:51:00+03	129900.00
AF0C47	2017-07-11 13:47:00+03	36400.00
AF0D3F	2017-07-11 22:19:00+03	29600.00
AF0E11	2017-07-31 07:47:00+03	12000.00
AF0E21	2017-07-10 02:25:00+03	47200.00
AF0E27	2017-07-23 21:05:00+03	28800.00
AF0E2C	2017-07-13 13:56:00+03	13600.00
AF0EC2	2017-07-02 05:03:00+03	94200.00
AF0EF8	2017-08-09 19:41:00+03	136800.00
AF0F3F	2017-07-12 03:00:00+03	53300.00
AF0F4B	2017-08-05 11:56:00+03	112000.00
AF0F4D	2017-06-29 21:44:00+03	46400.00
AF0F78	2017-07-17 20:55:00+03	24200.00
AF0F8E	2017-07-06 18:52:00+03	193200.00
AF0FD7	2017-07-29 05:34:00+03	84100.00
AF1008	2017-08-12 04:40:00+03	40800.00
AF1009	2017-07-16 13:35:00+03	7200.00
AF1062	2017-08-09 03:43:00+03	56000.00
AF1075	2017-07-05 12:09:00+03	12600.00
AF108B	2017-07-03 08:55:00+03	64300.00
AF10AD	2017-07-09 02:40:00+03	101200.00
AF10BD	2017-07-12 14:14:00+03	46400.00
AF1171	2017-07-18 17:27:00+03	40200.00
AF118A	2017-08-10 19:24:00+03	125200.00
AF1192	2017-08-04 11:07:00+03	44800.00
AF121C	2017-07-04 16:26:00+03	132800.00
AF1245	2017-07-02 17:37:00+03	27200.00
AF12A4	2017-08-11 12:03:00+03	270700.00
AF132A	2017-08-13 20:54:00+03	37700.00
AF13F6	2017-07-25 08:25:00+03	58200.00
AF1422	2017-07-20 08:31:00+03	24600.00
AF143B	2017-08-15 08:59:00+03	186900.00
AF146B	2017-07-11 23:56:00+03	40800.00
AF14AE	2017-08-08 08:17:00+03	117100.00
AF14F3	2017-08-06 19:19:00+03	36200.00
AF14F7	2017-07-19 12:09:00+03	13000.00
AF1566	2017-07-29 19:52:00+03	119700.00
AF15AB	2017-07-07 13:32:00+03	27200.00
AF167F	2017-07-09 18:45:00+03	37900.00
AF16AD	2017-07-15 23:48:00+03	17600.00
AF16E6	2017-08-04 08:32:00+03	90800.00
AF1750	2017-07-08 22:14:00+03	56000.00
AF1752	2017-07-07 01:00:00+03	16400.00
AF1770	2017-08-09 01:18:00+03	8200.00
AF1782	2017-07-29 17:01:00+03	28800.00
AF17C3	2017-07-28 02:24:00+03	58400.00
AF1829	2017-08-12 14:50:00+03	78100.00
AF1845	2017-08-14 16:26:00+03	26600.00
AF18AE	2017-07-28 02:39:00+03	160800.00
AF18C8	2017-07-26 07:49:00+03	65900.00
AF1900	2017-07-06 11:44:00+03	57600.00
AF1908	2017-07-31 15:23:00+03	23600.00
AF190F	2017-07-28 22:14:00+03	446700.00
AF1940	2017-07-22 23:23:00+03	49500.00
AF1944	2017-07-07 09:01:00+03	115600.00
AF1980	2017-07-17 07:01:00+03	28000.00
AF19A5	2017-07-14 05:43:00+03	35300.00
AF19A6	2017-08-07 06:51:00+03	277900.00
AF1A00	2017-07-01 13:15:00+03	332800.00
AF1A4E	2017-07-13 09:26:00+03	40600.00
AF1ACA	2017-07-18 02:23:00+03	54000.00
AF1AFE	2017-07-13 20:03:00+03	41200.00
AF1B0F	2017-07-16 22:07:00+03	65500.00
AF1B8A	2017-07-31 23:29:00+03	26800.00
AF1C0B	2017-07-28 15:35:00+03	24000.00
AF1C27	2017-08-09 02:35:00+03	14000.00
AF1C42	2017-07-14 09:58:00+03	147500.00
AF1C86	2017-07-01 13:26:00+03	85000.00
AF1C90	2017-07-25 05:57:00+03	40800.00
AF1CAB	2017-06-29 10:07:00+03	102700.00
AF1CE9	2017-08-07 05:40:00+03	74800.00
AF1D0A	2017-07-11 19:18:00+03	250400.00
AF1D12	2017-07-08 12:16:00+03	133200.00
AF1D20	2017-08-12 13:21:00+03	37100.00
AF1D23	2017-08-07 06:02:00+03	43500.00
AF1D2A	2017-07-26 15:07:00+03	122500.00
AF1D56	2017-08-09 15:12:00+03	36200.00
AF1D86	2017-08-01 17:54:00+03	25200.00
AF1DCA	2017-08-10 21:56:00+03	98000.00
AF1DD4	2017-08-03 06:37:00+03	155700.00
AF1DF7	2017-07-11 05:05:00+03	56600.00
AF1E18	2017-08-06 17:18:00+03	62900.00
AF1E58	2017-07-23 02:16:00+03	88400.00
AF1E7A	2017-08-09 02:57:00+03	38600.00
AF1E7C	2017-08-04 17:46:00+03	123000.00
AF1EDC	2017-07-04 14:24:00+03	124200.00
AF1EFA	2017-07-20 10:46:00+03	95900.00
AF1F0E	2017-07-29 10:32:00+03	62800.00
AF1F20	2017-07-27 07:25:00+03	40100.00
AF1F38	2017-07-24 18:11:00+03	86600.00
AF1F5B	2017-07-02 06:06:00+03	34200.00
AF1F80	2017-07-25 10:02:00+03	133100.00
AF1FF0	2017-07-14 23:39:00+03	67900.00
AF2032	2017-07-17 08:08:00+03	73900.00
AF2034	2017-08-03 18:27:00+03	23600.00
AF20C0	2017-07-29 13:33:00+03	47100.00
AF20D4	2017-08-03 21:11:00+03	54800.00
AF20FA	2017-07-23 06:17:00+03	615000.00
AF2133	2017-07-15 06:16:00+03	260600.00
AF21E8	2017-07-06 01:04:00+03	34000.00
AF22CB	2017-07-10 03:25:00+03	57400.00
AF22DC	2017-07-09 21:56:00+03	85000.00
AF2320	2017-08-10 20:37:00+03	141900.00
AF2354	2017-08-06 02:39:00+03	97700.00
AF2361	2017-07-14 22:04:00+03	38400.00
AF23A3	2017-07-17 07:44:00+03	21800.00
AF23A5	2017-07-08 02:28:00+03	72800.00
AF23CD	2017-07-04 06:27:00+03	24400.00
AF240F	2017-07-28 09:44:00+03	18300.00
AF247C	2017-08-01 13:45:00+03	84000.00
AF2545	2017-07-16 17:59:00+03	88800.00
AF2598	2017-07-01 20:37:00+03	52100.00
AF25E3	2017-08-14 08:15:00+03	48500.00
AF25E8	2017-08-09 01:45:00+03	38400.00
AF2622	2017-07-20 17:49:00+03	152900.00
AF263F	2017-07-15 18:56:00+03	136800.00
AF264E	2017-07-16 07:38:00+03	70700.00
AF2666	2017-07-24 14:54:00+03	111600.00
AF26AB	2017-07-27 11:43:00+03	139200.00
AF26B8	2017-08-15 11:40:00+03	231800.00
AF26B9	2017-08-13 08:13:00+03	125200.00
AF27A3	2017-07-05 02:26:00+03	43500.00
AF2814	2017-08-08 21:41:00+03	57400.00
AF283F	2017-07-25 13:14:00+03	82000.00
AF285D	2017-07-25 04:22:00+03	46200.00
AF2870	2017-07-16 13:30:00+03	37500.00
AF28A2	2017-07-07 10:23:00+03	26000.00
AF28C8	2017-08-04 18:09:00+03	49500.00
AF28DB	2017-07-18 20:50:00+03	67800.00
AF28DE	2017-08-05 14:54:00+03	266200.00
AF28FB	2017-07-24 01:17:00+03	27300.00
AF2972	2017-08-02 17:45:00+03	187600.00
AF29CB	2017-07-16 20:20:00+03	36200.00
AF2A08	2017-07-28 10:40:00+03	10600.00
AF2A21	2017-08-15 02:35:00+03	99200.00
AF2A37	2017-08-05 09:18:00+03	43500.00
AF2A57	2017-08-12 20:35:00+03	258400.00
AF2A5D	2017-07-23 16:20:00+03	20800.00
AF2ACF	2017-07-13 18:04:00+03	56100.00
AF2B06	2017-07-13 01:27:00+03	55800.00
AF2B0E	2017-07-04 23:09:00+03	28800.00
AF2B11	2017-08-07 02:32:00+03	173200.00
AF2B59	2017-07-14 21:16:00+03	43600.00
AF2BF9	2017-07-06 11:14:00+03	309700.00
AF2C54	2017-08-09 03:13:00+03	68800.00
AF2C5D	2017-07-19 23:20:00+03	49400.00
AF2C65	2017-08-06 16:57:00+03	132800.00
AF2C75	2017-08-15 06:41:00+03	15800.00
AF2CB9	2017-08-11 11:10:00+03	53800.00
AF2CBB	2017-07-21 21:23:00+03	6700.00
AF2D7F	2017-07-18 04:03:00+03	34600.00
AF2DB5	2017-07-01 17:41:00+03	56000.00
AF2DD4	2017-07-16 07:49:00+03	47100.00
AF2E97	2017-08-14 22:53:00+03	45900.00
AF2ED2	2017-07-29 20:47:00+03	181000.00
AF2EDC	2017-08-15 04:56:00+03	30000.00
AF2F1D	2017-08-14 14:15:00+03	333800.00
AF2F3F	2017-07-29 21:32:00+03	28800.00
AF2F75	2017-07-13 19:03:00+03	6000.00
AF2F9C	2017-08-11 20:42:00+03	12600.00
AF2FAF	2017-07-18 10:04:00+03	48500.00
AF2FC2	2017-08-07 07:04:00+03	43200.00
AF2FFF	2017-07-18 02:10:00+03	73300.00
AF3012	2017-07-24 15:27:00+03	104400.00
AF3082	2017-07-16 21:22:00+03	112600.00
AF308F	2017-07-27 05:37:00+03	119500.00
AF3097	2017-07-16 12:13:00+03	23900.00
AF30A2	2017-07-29 04:49:00+03	100600.00
AF30B4	2017-08-15 11:17:00+03	32700.00
AF30B9	2017-07-05 02:17:00+03	27200.00
AF311E	2017-07-10 13:38:00+03	40000.00
AF319E	2017-07-13 19:07:00+03	48300.00
AF31C6	2017-07-04 04:09:00+03	64700.00
AF3214	2017-07-10 09:06:00+03	32800.00
AF3244	2017-07-24 09:52:00+03	49100.00
AF324C	2017-07-07 01:18:00+03	47100.00
AF3279	2017-07-04 22:12:00+03	166100.00
AF32C1	2017-07-29 22:49:00+03	54800.00
AF32F4	2017-07-25 23:58:00+03	46800.00
AF32F5	2017-08-06 08:13:00+03	11000.00
AF3330	2017-08-02 16:22:00+03	59300.00
AF33D2	2017-07-19 20:08:00+03	74200.00
AF33EF	2017-07-02 05:54:00+03	7400.00
AF343A	2017-07-12 06:01:00+03	111600.00
AF3497	2017-08-15 02:20:00+03	23200.00
AF34BF	2017-07-12 07:47:00+03	12100.00
AF34DC	2017-07-12 01:30:00+03	86800.00
AF34DF	2017-07-17 16:11:00+03	46700.00
AF34E1	2017-07-15 21:19:00+03	107400.00
AF3549	2017-07-05 06:53:00+03	92600.00
AF3570	2017-07-21 00:09:00+03	137600.00
AF35BD	2017-08-06 04:02:00+03	64600.00
AF35FD	2017-07-26 09:00:00+03	57600.00
AF3679	2017-07-05 19:41:00+03	61800.00
AF369F	2017-07-22 08:33:00+03	124200.00
AF36FD	2017-07-25 20:31:00+03	115700.00
AF3706	2017-08-14 20:13:00+03	26000.00
AF37A2	2017-08-04 00:11:00+03	36200.00
AF3817	2017-07-06 11:21:00+03	29600.00
AF3890	2017-08-10 23:19:00+03	176200.00
AF389E	2017-07-18 23:15:00+03	40800.00
AF3944	2017-07-11 14:49:00+03	88000.00
AF3966	2017-07-09 07:26:00+03	276200.00
AF397E	2017-07-18 23:51:00+03	25000.00
AF39A3	2017-07-15 14:48:00+03	46000.00
AF39B8	2017-08-02 09:47:00+03	25000.00
AF39D7	2017-08-09 21:23:00+03	24700.00
AF3A59	2017-08-15 09:56:00+03	6000.00
AF3AB4	2017-08-04 13:38:00+03	57600.00
AF3AFB	2017-08-14 08:53:00+03	127800.00
AF3B05	2017-07-24 01:28:00+03	34000.00
AF3B1B	2017-07-30 08:01:00+03	33100.00
AF3B31	2017-07-20 13:34:00+03	59200.00
AF3B49	2017-07-13 17:16:00+03	12600.00
AF3B4A	2017-07-24 04:56:00+03	123000.00
AF3B52	2017-08-09 11:12:00+03	49200.00
AF3B76	2017-07-22 03:40:00+03	67600.00
AF3B9B	2017-08-07 20:09:00+03	61800.00
AF3BB5	2017-08-01 16:31:00+03	12600.00
AF3BE6	2017-07-04 05:16:00+03	118000.00
AF3C4A	2017-07-28 05:54:00+03	6000.00
AF3C5D	2017-08-06 10:38:00+03	25200.00
AF3C62	2017-08-04 05:25:00+03	66000.00
AF3CCB	2017-08-02 06:32:00+03	32200.00
AF3D8F	2017-07-30 19:25:00+03	42700.00
AF3E37	2017-08-10 15:32:00+03	47200.00
AF3E66	2017-08-02 04:45:00+03	44800.00
AF3F37	2017-07-05 07:09:00+03	66000.00
AF3F51	2017-07-06 01:23:00+03	149200.00
AF3F59	2017-07-13 03:10:00+03	126600.00
AF3FFC	2017-07-15 17:06:00+03	23400.00
AF4003	2017-07-13 04:37:00+03	50000.00
AF4009	2017-08-08 13:47:00+03	6800.00
AF40C7	2017-08-06 11:30:00+03	97400.00
AF40CA	2017-08-01 10:26:00+03	28800.00
AF40CB	2017-07-15 19:25:00+03	37900.00
AF40E6	2017-08-05 21:19:00+03	24200.00
AF4103	2017-08-14 15:44:00+03	381600.00
AF413F	2017-08-14 06:05:00+03	141600.00
AF4192	2017-07-25 06:13:00+03	84100.00
AF41EA	2017-07-02 07:53:00+03	13300.00
AF4273	2017-07-05 06:21:00+03	34000.00
AF428C	2017-07-20 01:37:00+03	46500.00
AF42D3	2017-07-25 13:30:00+03	28800.00
AF430C	2017-07-20 09:31:00+03	54400.00
AF4322	2017-07-13 03:56:00+03	47000.00
AF4324	2017-07-27 14:45:00+03	87100.00
AF438F	2017-07-18 13:57:00+03	265600.00
AF43BC	2017-07-09 21:38:00+03	68800.00
AF440E	2017-08-08 15:43:00+03	32900.00
AF4449	2017-07-19 20:16:00+03	252700.00
AF4470	2017-08-05 10:28:00+03	32200.00
AF44D6	2017-07-29 07:11:00+03	86400.00
AF44DA	2017-07-24 22:10:00+03	40000.00
AF44EA	2017-07-05 16:54:00+03	173600.00
AF4510	2017-07-16 21:42:00+03	111600.00
AF4511	2017-07-18 13:09:00+03	46400.00
AF457D	2017-08-11 08:56:00+03	23200.00
AF458B	2017-08-06 03:34:00+03	64800.00
AF4611	2017-08-11 13:41:00+03	12400.00
AF4626	2017-08-01 10:15:00+03	332800.00
AF46B2	2017-06-30 07:10:00+03	284300.00
AF46DF	2017-07-31 00:45:00+03	126800.00
AF472F	2017-08-09 16:04:00+03	31900.00
AF474C	2017-07-31 18:37:00+03	26000.00
AF4762	2017-08-13 22:51:00+03	24400.00
AF47C2	2017-08-04 06:45:00+03	58000.00
AF47D2	2017-08-01 01:34:00+03	129100.00
AF493C	2017-07-03 16:28:00+03	56000.00
AF49D5	2017-08-01 18:47:00+03	46300.00
AF4A87	2017-07-21 20:48:00+03	176300.00
AF4AB9	2017-08-13 13:59:00+03	172200.00
AF4B11	2017-07-07 18:42:00+03	28800.00
AF4B52	2017-07-16 17:18:00+03	15800.00
AF4B72	2017-08-15 01:58:00+03	86600.00
AF4B89	2017-08-10 09:52:00+03	14400.00
AF4BD7	2017-07-06 14:32:00+03	73300.00
AF4C34	2017-07-15 07:01:00+03	46300.00
AF4C40	2017-08-13 19:11:00+03	46900.00
AF4C87	2017-07-27 04:48:00+03	59600.00
AF4CC3	2017-08-05 08:15:00+03	86400.00
AF4CC9	2017-08-14 13:17:00+03	69000.00
AF4CFA	2017-06-27 00:45:00+03	32800.00
AF4D8E	2017-07-16 07:21:00+03	268000.00
AF4DC3	2017-08-10 20:45:00+03	38400.00
AF4DC4	2017-07-21 08:02:00+03	6000.00
AF4ED2	2017-07-12 00:10:00+03	146400.00
AF4F0D	2017-07-27 04:35:00+03	28800.00
AF4F2D	2017-07-26 06:10:00+03	233000.00
AF4F6D	2017-07-18 11:27:00+03	106400.00
AF4F75	2017-07-19 17:55:00+03	39800.00
AF4F92	2017-07-02 15:42:00+03	539400.00
AF4F98	2017-08-03 12:52:00+03	46000.00
AF4FBE	2017-07-27 20:18:00+03	26000.00
AF4FF0	2017-08-07 11:58:00+03	122300.00
AF5019	2017-08-02 16:48:00+03	56100.00
AF50AA	2017-08-08 14:57:00+03	64800.00
AF50B1	2017-08-09 17:58:00+03	68800.00
AF50F7	2017-07-09 18:49:00+03	30200.00
AF5132	2017-07-19 03:38:00+03	132800.00
AF5142	2017-07-26 04:30:00+03	203500.00
AF51BE	2017-07-14 02:13:00+03	123000.00
AF51E7	2017-07-04 06:42:00+03	123000.00
AF51F8	2017-07-14 18:02:00+03	372600.00
AF521C	2017-07-08 00:44:00+03	34200.00
AF52A0	2017-07-08 11:21:00+03	21200.00
AF52E2	2017-06-25 06:43:00+03	111700.00
AF52F9	2017-07-05 20:44:00+03	32900.00
AF5332	2017-08-02 13:49:00+03	13400.00
AF540E	2017-07-21 16:06:00+03	59800.00
AF5411	2017-08-01 18:24:00+03	10600.00
AF5453	2017-08-14 08:46:00+03	12400.00
AF5487	2017-07-29 04:06:00+03	323900.00
AF5490	2017-06-30 22:56:00+03	67600.00
AF54C4	2017-07-05 17:26:00+03	30700.00
AF54D9	2017-07-26 03:47:00+03	56100.00
AF54E9	2017-07-20 14:49:00+03	93900.00
AF5547	2017-07-02 05:39:00+03	196100.00
AF5587	2017-07-13 08:02:00+03	68100.00
AF55BE	2017-06-29 19:19:00+03	26000.00
AF560E	2017-07-16 22:33:00+03	58600.00
AF561B	2017-08-02 00:09:00+03	19600.00
AF566A	2017-07-09 10:30:00+03	153300.00
AF56CB	2017-07-25 17:06:00+03	250400.00
AF570F	2017-07-24 22:16:00+03	115800.00
AF5715	2017-06-30 05:04:00+03	23200.00
AF573B	2017-08-05 05:46:00+03	136200.00
AF5760	2017-07-09 14:30:00+03	11200.00
AF57F2	2017-08-14 14:21:00+03	25200.00
AF5860	2017-07-23 19:03:00+03	92800.00
AF58CA	2017-07-04 09:51:00+03	68400.00
AF5902	2017-08-01 22:20:00+03	156300.00
AF5908	2017-07-19 19:47:00+03	116000.00
AF593D	2017-08-12 13:18:00+03	41400.00
AF5950	2017-08-06 17:10:00+03	46400.00
AF5987	2017-08-15 09:34:00+03	135200.00
AF59E7	2017-07-01 11:10:00+03	57800.00
AF59FE	2017-07-18 23:06:00+03	48800.00
AF5A2F	2017-07-02 22:21:00+03	14000.00
AF5A4F	2017-07-03 19:22:00+03	28200.00
AF5AAF	2017-08-03 11:27:00+03	40000.00
AF5AF3	2017-08-05 11:39:00+03	43600.00
AF5BA3	2017-08-10 08:49:00+03	281500.00
AF5BB0	2017-07-23 23:57:00+03	38600.00
AF5BE8	2017-07-16 14:07:00+03	40000.00
AF5C1F	2017-08-10 09:25:00+03	217900.00
AF5C35	2017-07-28 10:16:00+03	13000.00
AF5C3A	2017-07-29 00:08:00+03	15000.00
AF5C49	2017-08-10 14:21:00+03	13600.00
AF5C7E	2017-07-07 08:09:00+03	47200.00
AF5C93	2017-07-02 07:06:00+03	38400.00
AF5CEE	2017-07-14 18:03:00+03	40000.00
AF5CFB	2017-07-06 08:55:00+03	46400.00
AF5D46	2017-07-24 12:29:00+03	49200.00
AF5D77	2017-08-13 20:33:00+03	13000.00
AF5D99	2017-08-04 23:40:00+03	28600.00
AF5DBD	2017-07-27 22:40:00+03	405600.00
AF5DE7	2017-07-22 01:40:00+03	73500.00
AF5E31	2017-07-04 10:46:00+03	32800.00
AF5EE9	2017-07-12 17:20:00+03	235400.00
AF5F06	2017-07-29 06:42:00+03	45700.00
AF5F3E	2017-08-08 08:36:00+03	76400.00
AF5F43	2017-07-31 10:00:00+03	21400.00
AF5F80	2017-07-10 16:53:00+03	36200.00
AF5FBD	2017-08-05 21:11:00+03	12000.00
AF5FC1	2017-07-02 13:01:00+03	29400.00
AF6034	2017-07-07 07:41:00+03	20500.00
AF6054	2017-07-25 00:27:00+03	131100.00
AF605A	2017-07-23 10:10:00+03	13700.00
AF605E	2017-07-10 21:46:00+03	44000.00
AF60E1	2017-07-02 19:11:00+03	39300.00
AF6110	2017-08-15 09:04:00+03	67200.00
AF611B	2017-07-04 11:06:00+03	24700.00
AF6139	2017-07-26 02:12:00+03	266400.00
AF61B1	2017-08-15 14:33:00+03	121500.00
AF61E2	2017-07-13 19:02:00+03	26200.00
AF61EE	2017-07-12 21:55:00+03	24400.00
AF6203	2017-08-10 10:47:00+03	128100.00
AF624A	2017-07-03 10:36:00+03	28800.00
AF62B5	2017-07-12 03:37:00+03	13400.00
AF6303	2017-08-15 01:01:00+03	61300.00
AF6330	2017-08-06 01:04:00+03	240600.00
AF635D	2017-08-04 23:46:00+03	18600.00
AF6388	2017-08-07 08:05:00+03	394900.00
AF63F5	2017-08-11 21:30:00+03	22000.00
AF63FE	2017-07-28 01:51:00+03	28300.00
AF645C	2017-07-13 12:11:00+03	27200.00
AF651C	2017-08-11 18:29:00+03	22000.00
AF658E	2017-08-06 04:18:00+03	40400.00
AF65C4	2017-07-02 18:00:00+03	12600.00
AF65CB	2017-08-12 11:06:00+03	12600.00
AF65F7	2017-07-19 23:22:00+03	19600.00
AF66DF	2017-08-14 10:31:00+03	148200.00
AF66F2	2017-07-08 12:58:00+03	95200.00
AF66F5	2017-07-03 19:51:00+03	62600.00
AF6704	2017-07-09 02:07:00+03	117900.00
AF676B	2017-07-25 17:04:00+03	31600.00
AF679C	2017-08-03 08:57:00+03	139800.00
AF67AB	2017-07-03 17:01:00+03	58800.00
AF67CD	2017-07-07 00:03:00+03	76600.00
AF67FC	2017-07-03 13:32:00+03	19600.00
AF692F	2017-08-04 13:27:00+03	131100.00
AF696B	2017-07-15 00:36:00+03	51300.00
AF69CE	2017-07-20 09:55:00+03	15100.00
AF6A36	2017-07-11 12:43:00+03	31600.00
AF6A50	2017-07-08 17:40:00+03	75300.00
AF6ACA	2017-08-11 19:02:00+03	37200.00
AF6ACD	2017-08-14 14:04:00+03	64300.00
AF6B0F	2017-07-19 12:40:00+03	32700.00
AF6B6D	2017-08-10 11:55:00+03	363200.00
AF6B8C	2017-08-12 02:27:00+03	36200.00
AF6C3D	2017-07-08 12:43:00+03	57500.00
AF6CA1	2017-07-13 01:50:00+03	32400.00
AF6CAF	2017-07-14 13:29:00+03	64800.00
AF6D0A	2017-07-06 15:07:00+03	57500.00
AF6D77	2017-07-08 02:31:00+03	92600.00
AF6DA9	2017-08-10 03:32:00+03	62800.00
AF6DD7	2017-07-20 02:49:00+03	86600.00
AF6E73	2017-07-30 06:54:00+03	521800.00
AF6EA2	2017-08-10 01:17:00+03	28800.00
AF6EAF	2017-07-19 04:20:00+03	515100.00
AF6ED7	2017-07-15 17:27:00+03	71400.00
AF6F29	2017-08-03 06:33:00+03	52000.00
AF6F50	2017-08-09 14:07:00+03	41600.00
AF6F66	2017-08-05 10:07:00+03	43400.00
AF6FBB	2017-08-11 12:29:00+03	48300.00
AF6FBC	2017-07-28 02:57:00+03	28700.00
AF6FCA	2017-07-18 00:34:00+03	67800.00
AF6FCC	2017-07-30 03:06:00+03	26800.00
AF6FFA	2017-07-25 02:19:00+03	69500.00
AF7022	2017-08-15 07:00:00+03	31200.00
AF7049	2017-08-12 18:41:00+03	60800.00
AF7059	2017-07-31 13:15:00+03	81200.00
AF716E	2017-07-09 02:33:00+03	37700.00
AF7221	2017-07-07 05:58:00+03	25400.00
AF7237	2017-07-09 14:24:00+03	131100.00
AF723C	2017-07-09 19:11:00+03	60000.00
AF727A	2017-08-03 19:34:00+03	67600.00
AF737B	2017-07-18 14:10:00+03	84000.00
AF73BB	2017-08-08 04:57:00+03	43200.00
AF73D6	2017-06-29 06:05:00+03	109300.00
AF73E9	2017-07-17 19:17:00+03	225200.00
AF740E	2017-07-24 11:04:00+03	136600.00
AF7444	2017-07-11 13:12:00+03	66400.00
AF744E	2017-08-09 10:01:00+03	12600.00
AF7479	2017-07-01 00:07:00+03	36000.00
AF7505	2017-07-10 18:05:00+03	103200.00
AF75B4	2017-08-15 10:22:00+03	91500.00
AF761B	2017-07-08 01:48:00+03	135600.00
AF7620	2017-07-18 20:33:00+03	44800.00
AF7637	2017-07-28 15:19:00+03	40600.00
AF7673	2017-07-17 21:49:00+03	20400.00
AF768D	2017-07-14 10:49:00+03	67100.00
AF76DA	2017-07-26 13:05:00+03	119400.00
AF76E8	2017-08-06 19:14:00+03	147100.00
AF7738	2017-07-22 13:57:00+03	153200.00
AF7787	2017-07-26 09:49:00+03	21800.00
AF78CE	2017-07-29 23:24:00+03	85700.00
AF791A	2017-07-23 03:03:00+03	28000.00
AF799A	2017-07-28 16:10:00+03	103600.00
AF799C	2017-08-12 05:21:00+03	81900.00
AF79D7	2017-07-20 01:27:00+03	28700.00
AF7A2A	2017-08-14 19:38:00+03	122000.00
AF7AB1	2017-07-16 04:22:00+03	100600.00
AF7AE5	2017-07-25 17:49:00+03	11800.00
AF7AFD	2017-07-10 15:32:00+03	40800.00
AF7B14	2017-07-21 07:30:00+03	50000.00
AF7B4F	2017-07-30 20:55:00+03	44600.00
AF7B5A	2017-08-15 00:48:00+03	144400.00
AF7B90	2017-08-04 05:17:00+03	277800.00
AF7B98	2017-08-06 16:19:00+03	210800.00
AF7BBC	2017-07-14 11:16:00+03	14800.00
AF7C05	2017-07-04 10:32:00+03	56000.00
AF7C3E	2017-06-29 21:55:00+03	94000.00
AF7C65	2017-07-30 17:42:00+03	57900.00
AF7CBD	2017-08-03 03:11:00+03	70600.00
AF7CE6	2017-08-10 19:11:00+03	73800.00
AF7CF8	2017-08-06 06:17:00+03	66100.00
AF7D12	2017-06-30 17:57:00+03	153300.00
AF7D43	2017-07-24 05:10:00+03	77500.00
AF7D4C	2017-07-27 22:20:00+03	24400.00
AF7E0D	2017-08-07 10:31:00+03	57600.00
AF7E9D	2017-07-15 21:20:00+03	18600.00
AF7F45	2017-07-17 23:50:00+03	44800.00
AF7F4D	2017-08-03 07:49:00+03	21400.00
AF7F8A	2017-07-09 03:09:00+03	13400.00
AF7F9B	2017-07-28 23:15:00+03	14400.00
AF7FC0	2017-08-08 19:01:00+03	149900.00
AF7FD7	2017-07-14 11:40:00+03	43600.00
AF803A	2017-08-13 15:20:00+03	80700.00
AF8044	2017-07-08 13:41:00+03	26800.00
AF8052	2017-08-11 05:41:00+03	46300.00
AF8076	2017-07-15 06:15:00+03	96800.00
AF8090	2017-07-11 12:09:00+03	62000.00
AF8093	2017-07-22 13:48:00+03	94000.00
AF80CE	2017-07-22 02:50:00+03	16400.00
AF8112	2017-08-02 12:43:00+03	101000.00
AF814C	2017-07-17 05:29:00+03	58000.00
AF814F	2017-08-09 03:29:00+03	14300.00
AF8158	2017-08-11 16:31:00+03	147000.00
AF817B	2017-08-15 06:53:00+03	12600.00
AF81D0	2017-07-04 06:24:00+03	84000.00
AF8212	2017-08-10 12:28:00+03	20200.00
AF821D	2017-07-23 03:33:00+03	66900.00
AF8225	2017-08-03 14:10:00+03	86800.00
AF822C	2017-08-04 17:06:00+03	29600.00
AF8239	2017-07-22 06:37:00+03	76600.00
AF8258	2017-07-12 20:55:00+03	93900.00
AF82C1	2017-07-19 15:21:00+03	23400.00
AF8355	2017-07-16 22:02:00+03	66600.00
AF83B1	2017-08-09 10:48:00+03	46400.00
AF83F8	2017-07-25 12:16:00+03	73600.00
AF8413	2017-07-14 12:00:00+03	270400.00
AF8414	2017-07-18 23:11:00+03	59800.00
AF843A	2017-07-30 19:45:00+03	39500.00
AF8440	2017-07-20 09:17:00+03	89600.00
AF847B	2017-07-23 15:42:00+03	156600.00
AF8489	2017-07-09 23:34:00+03	88500.00
AF84D5	2017-08-05 08:29:00+03	6300.00
AF8515	2017-07-17 19:05:00+03	13700.00
AF858B	2017-08-01 02:34:00+03	89600.00
AF8608	2017-08-12 06:58:00+03	43600.00
AF863C	2017-07-15 11:10:00+03	111600.00
AF86AD	2017-07-14 14:39:00+03	115600.00
AF86D2	2017-07-22 01:13:00+03	65500.00
AF871D	2017-07-25 18:26:00+03	46200.00
AF8739	2017-07-11 21:28:00+03	24400.00
AF879A	2017-07-10 01:35:00+03	54600.00
AF87E7	2017-07-09 10:57:00+03	35300.00
AF8803	2017-08-13 09:31:00+03	119500.00
AF8883	2017-08-07 13:49:00+03	84000.00
AF888B	2017-08-01 20:48:00+03	15800.00
AF88B7	2017-08-12 21:42:00+03	133100.00
AF88B9	2017-07-04 18:26:00+03	28800.00
AF88CB	2017-07-07 20:48:00+03	258400.00
AF891C	2017-07-14 07:52:00+03	302200.00
AF89AF	2017-07-24 10:31:00+03	32800.00
AF89D8	2017-07-22 16:42:00+03	124200.00
AF89DB	2017-06-29 15:14:00+03	27900.00
AF8A7B	2017-08-15 05:32:00+03	52000.00
AF8A88	2017-08-05 17:25:00+03	55800.00
AF8AA8	2017-08-09 11:43:00+03	135600.00
AF8AF6	2017-07-18 02:28:00+03	136200.00
AF8B0A	2017-08-04 23:25:00+03	28800.00
AF8B36	2017-07-22 17:06:00+03	137100.00
AF8B40	2017-07-03 06:37:00+03	56600.00
AF8BBB	2017-08-09 01:36:00+03	44000.00
AF8BCE	2017-08-10 08:04:00+03	121400.00
AF8C3E	2017-07-23 07:59:00+03	185800.00
AF8CF7	2017-07-08 00:34:00+03	99200.00
AF8D10	2017-07-22 12:49:00+03	67600.00
AF8D27	2017-08-04 07:26:00+03	260900.00
AF8D31	2017-08-09 09:30:00+03	26000.00
AF8D4E	2017-08-05 22:33:00+03	170300.00
AF8D65	2017-08-13 12:37:00+03	51800.00
AF8D9B	2017-07-30 22:53:00+03	176800.00
AF8E24	2017-07-08 17:48:00+03	58200.00
AF8E36	2017-07-08 05:01:00+03	24400.00
AF8E3F	2017-08-03 06:56:00+03	177200.00
AF8F46	2017-07-25 00:41:00+03	24400.00
AF8FB4	2017-07-10 13:04:00+03	78100.00
AF8FBF	2017-07-04 19:42:00+03	56200.00
AF8FE4	2017-08-10 21:03:00+03	56000.00
AF8FE5	2017-07-26 01:28:00+03	37900.00
AF907A	2017-08-14 13:06:00+03	136200.00
AF9085	2017-07-08 05:08:00+03	20400.00
AF90C6	2017-08-05 09:39:00+03	14000.00
AF9165	2017-08-12 16:24:00+03	135400.00
AF91AB	2017-07-25 20:57:00+03	44800.00
AF91BC	2017-08-02 09:47:00+03	19600.00
AF91EE	2017-08-05 08:05:00+03	37900.00
AF920F	2017-07-29 15:43:00+03	28800.00
AF921F	2017-07-20 02:44:00+03	114300.00
AF924E	2017-07-11 17:09:00+03	39100.00
AF92D8	2017-07-15 23:58:00+03	58800.00
AF92DA	2017-07-11 08:24:00+03	39400.00
AF92DF	2017-07-03 03:22:00+03	270000.00
AF930C	2017-08-04 22:47:00+03	238000.00
AF9318	2017-07-12 22:24:00+03	42800.00
AF93D4	2017-07-13 14:55:00+03	103500.00
AF93E3	2017-07-18 17:29:00+03	12600.00
AF9411	2017-07-26 00:34:00+03	25600.00
AF94AB	2017-07-23 22:17:00+03	96200.00
AF94AD	2017-07-20 02:59:00+03	27900.00
AF951F	2017-07-11 16:37:00+03	87800.00
AF95C5	2017-07-31 08:08:00+03	66000.00
AF9601	2017-07-25 15:59:00+03	16400.00
AF96D7	2017-07-07 04:52:00+03	132800.00
AF97C3	2017-07-18 00:21:00+03	58400.00
AF980B	2017-07-14 09:39:00+03	74300.00
AF9832	2017-07-30 03:50:00+03	25400.00
AF9846	2017-07-16 11:32:00+03	105100.00
AF9865	2017-07-31 17:21:00+03	50800.00
AF9866	2017-07-12 19:16:00+03	147700.00
AF986D	2017-07-30 02:20:00+03	73200.00
AF9875	2017-07-11 10:44:00+03	28000.00
AF992D	2017-07-29 23:46:00+03	60800.00
AF993E	2017-08-06 05:02:00+03	13400.00
AF99BE	2017-08-12 11:36:00+03	39100.00
AF99E3	2017-07-14 11:07:00+03	59900.00
AF9A2D	2017-07-18 19:56:00+03	102200.00
AF9AE4	2017-07-05 11:21:00+03	396700.00
AF9AE5	2017-07-30 03:28:00+03	177200.00
AF9AFD	2017-07-27 11:06:00+03	96300.00
AF9B18	2017-07-16 07:22:00+03	56100.00
AF9BEA	2017-08-15 05:16:00+03	58200.00
AF9BFF	2017-08-13 15:46:00+03	46200.00
AF9CB4	2017-08-01 09:50:00+03	135300.00
AF9CB5	2017-07-26 22:31:00+03	36200.00
AF9DA2	2017-08-13 16:33:00+03	99200.00
AF9E20	2017-07-15 16:28:00+03	24400.00
AF9F0A	2017-07-28 15:59:00+03	67200.00
AF9F5F	2017-08-03 09:52:00+03	90400.00
AF9F93	2017-07-08 15:34:00+03	27400.00
AF9FCC	2017-07-23 18:42:00+03	167400.00
AF9FF3	2017-08-10 07:15:00+03	235800.00
AFA082	2017-07-04 16:12:00+03	33100.00
AFA135	2017-08-15 17:37:00+03	65600.00
AFA156	2017-08-13 13:20:00+03	6000.00
AFA1A9	2017-07-28 17:22:00+03	23600.00
AFA214	2017-07-28 07:18:00+03	13400.00
AFA30E	2017-06-26 05:24:00+03	40300.00
AFA312	2017-07-30 16:22:00+03	64700.00
AFA383	2017-08-12 20:22:00+03	74000.00
AFA3CF	2017-07-08 11:13:00+03	30000.00
AFA3D8	2017-08-08 10:17:00+03	516800.00
AFA3E2	2017-07-14 14:08:00+03	20800.00
AFA43D	2017-08-08 10:42:00+03	26200.00
AFA44C	2017-07-16 18:03:00+03	30200.00
AFA490	2017-08-13 22:24:00+03	13400.00
AFA4A2	2017-07-25 21:47:00+03	80900.00
AFA556	2017-07-03 00:15:00+03	36900.00
AFA562	2017-07-18 12:46:00+03	88700.00
AFA59F	2017-07-30 22:06:00+03	31400.00
AFA5B9	2017-08-09 02:05:00+03	27200.00
AFA5F9	2017-08-14 08:04:00+03	28000.00
AFA629	2017-07-23 09:16:00+03	23600.00
AFA660	2017-08-14 01:55:00+03	12600.00
AFA683	2017-07-05 03:32:00+03	14400.00
AFA688	2017-08-13 02:35:00+03	182300.00
AFA6BF	2017-08-04 03:14:00+03	75300.00
AFA6F6	2017-07-20 15:41:00+03	296700.00
AFA6FF	2017-07-30 18:19:00+03	27200.00
AFA746	2017-08-10 12:41:00+03	105100.00
AFA798	2017-08-12 00:12:00+03	46700.00
AFA7AC	2017-08-01 08:55:00+03	54000.00
AFA7D8	2017-07-02 11:05:00+03	39800.00
AFA7E1	2017-08-10 13:22:00+03	112100.00
AFA800	2017-08-10 14:54:00+03	22600.00
AFA817	2017-08-03 09:18:00+03	378400.00
AFA97F	2017-07-26 09:57:00+03	134700.00
AFA9F3	2017-07-26 10:49:00+03	22000.00
AFAA2D	2017-07-19 08:19:00+03	277800.00
AFAA64	2017-07-23 06:34:00+03	181400.00
AFAAA5	2017-07-22 03:24:00+03	58800.00
AFAACE	2017-07-15 21:59:00+03	6600.00
AFAB50	2017-08-14 08:49:00+03	55800.00
AFABCC	2017-07-23 10:14:00+03	21800.00
AFABEC	2017-08-01 16:37:00+03	55500.00
AFAC52	2017-07-29 13:14:00+03	33300.00
AFAC73	2017-07-11 08:15:00+03	205500.00
AFAC7D	2017-07-02 17:06:00+03	265700.00
AFAD73	2017-07-09 13:05:00+03	15000.00
AFADD2	2017-08-13 04:06:00+03	28000.00
AFADF7	2017-07-12 06:26:00+03	46400.00
AFAE13	2017-07-23 13:22:00+03	58800.00
AFAE45	2017-07-04 13:13:00+03	265600.00
AFAE56	2017-07-30 10:57:00+03	115100.00
AFAE5D	2017-08-10 06:46:00+03	201200.00
AFAE7C	2017-07-16 21:02:00+03	38600.00
AFAF1A	2017-07-30 20:43:00+03	23200.00
AFAF2A	2017-08-04 22:33:00+03	25200.00
AFAF99	2017-07-21 23:28:00+03	56600.00
AFAFE8	2017-08-05 18:20:00+03	117600.00
AFB011	2017-07-05 04:49:00+03	45400.00
AFB071	2017-08-05 06:08:00+03	228900.00
AFB10F	2017-07-15 13:26:00+03	64100.00
AFB1B1	2017-07-10 15:11:00+03	43200.00
AFB282	2017-07-30 17:08:00+03	46800.00
AFB328	2017-07-27 10:52:00+03	68800.00
AFB374	2017-07-30 00:29:00+03	53300.00
AFB380	2017-08-01 01:39:00+03	23200.00
AFB3BB	2017-08-13 01:28:00+03	92400.00
AFB3EB	2017-07-26 19:37:00+03	86400.00
AFB4A8	2017-07-27 12:44:00+03	45100.00
AFB57D	2017-07-11 09:40:00+03	31200.00
AFB597	2017-07-10 08:11:00+03	80800.00
AFB5E6	2017-08-06 03:24:00+03	124000.00
AFB5F3	2017-07-03 01:23:00+03	83000.00
AFB655	2017-07-10 12:18:00+03	398500.00
AFB691	2017-07-22 01:42:00+03	25600.00
AFB6A9	2017-07-23 22:49:00+03	59300.00
AFB702	2017-07-18 19:30:00+03	54800.00
AFB716	2017-07-20 20:18:00+03	55600.00
AFB7BE	2017-07-21 19:34:00+03	135100.00
AFB7C1	2017-07-08 02:32:00+03	134400.00
AFB7D4	2017-07-31 15:42:00+03	112000.00
AFB861	2017-07-05 20:39:00+03	114400.00
AFB981	2017-08-14 20:07:00+03	47500.00
AFB9D9	2017-08-12 16:23:00+03	66500.00
AFB9DC	2017-07-31 03:26:00+03	35200.00
AFB9DE	2017-08-15 06:11:00+03	39200.00
AFB9FE	2017-07-26 01:19:00+03	64800.00
AFBA00	2017-07-16 20:19:00+03	19800.00
AFBA12	2017-07-29 01:43:00+03	99500.00
AFBA34	2017-07-03 21:08:00+03	26000.00
AFBAF7	2017-08-10 18:56:00+03	66600.00
AFBAFD	2017-07-08 10:21:00+03	63300.00
AFBB09	2017-07-25 12:36:00+03	89700.00
AFBB42	2017-07-23 12:03:00+03	75300.00
AFBB88	2017-07-04 17:56:00+03	199600.00
AFBC8A	2017-08-02 18:36:00+03	57600.00
AFBC8B	2017-07-12 22:17:00+03	14000.00
AFBC96	2017-08-15 05:38:00+03	249000.00
AFBD7A	2017-06-30 21:14:00+03	24400.00
AFBE18	2017-07-19 20:14:00+03	70600.00
AFBE6B	2017-08-05 23:47:00+03	23600.00
AFBE77	2017-08-12 22:21:00+03	6700.00
AFBEE2	2017-07-07 07:02:00+03	68000.00
AFBF3C	2017-07-03 11:43:00+03	53600.00
AFBF86	2017-07-19 20:06:00+03	6000.00
AFBF91	2017-07-30 01:22:00+03	26000.00
AFBFD6	2017-08-06 21:14:00+03	27200.00
AFBFEE	2017-07-19 06:04:00+03	206400.00
AFC006	2017-08-07 18:54:00+03	113300.00
AFC032	2017-07-07 12:18:00+03	48400.00
AFC0C1	2017-07-27 00:03:00+03	63500.00
AFC0C5	2017-08-04 00:15:00+03	62600.00
AFC13A	2017-07-29 08:59:00+03	32900.00
AFC168	2017-08-03 06:11:00+03	51900.00
AFC175	2017-07-25 21:23:00+03	134400.00
AFC1D5	2017-08-02 23:12:00+03	55800.00
AFC1DD	2017-08-04 12:49:00+03	20000.00
AFC1E8	2017-08-05 02:23:00+03	56000.00
AFC302	2017-08-03 07:53:00+03	135600.00
AFC34B	2017-07-05 09:05:00+03	23200.00
AFC350	2017-08-08 05:32:00+03	61400.00
AFC3A0	2017-07-27 04:45:00+03	33300.00
AFC46C	2017-08-06 19:46:00+03	22000.00
AFC527	2017-07-03 13:59:00+03	7400.00
AFC538	2017-07-01 04:45:00+03	26000.00
AFC542	2017-08-09 22:53:00+03	81700.00
AFC55B	2017-07-26 20:24:00+03	71900.00
AFC56F	2017-08-15 00:45:00+03	59000.00
AFC576	2017-07-14 13:25:00+03	58800.00
AFC5A3	2017-08-03 17:28:00+03	62100.00
AFC5D4	2017-07-22 16:34:00+03	72700.00
AFC602	2017-07-08 22:45:00+03	83200.00
AFC60D	2017-07-07 07:35:00+03	88500.00
AFC61C	2017-07-13 12:17:00+03	26000.00
AFC628	2017-07-28 00:15:00+03	64900.00
AFC6C9	2017-08-06 19:50:00+03	35200.00
AFC70D	2017-07-04 05:21:00+03	22000.00
AFC743	2017-07-04 18:20:00+03	29600.00
AFC834	2017-07-19 01:13:00+03	25100.00
AFC860	2017-08-04 12:40:00+03	113200.00
AFC89B	2017-08-12 18:32:00+03	137100.00
AFC8A5	2017-07-01 12:10:00+03	13700.00
AFC8A6	2017-06-26 23:23:00+03	23600.00
AFC943	2017-08-04 06:09:00+03	48800.00
AFC94E	2017-07-20 05:35:00+03	36200.00
AFC963	2017-07-21 09:50:00+03	49400.00
AFC9BF	2017-07-22 08:58:00+03	119600.00
AFCB25	2017-07-06 00:43:00+03	73500.00
AFCBF6	2017-08-05 04:16:00+03	25600.00
AFCC3D	2017-07-03 05:16:00+03	257700.00
AFCC5C	2017-07-29 23:59:00+03	73500.00
AFCC64	2017-08-05 05:39:00+03	57600.00
AFCC93	2017-08-04 13:43:00+03	14000.00
AFCCA6	2017-08-02 03:02:00+03	20900.00
AFCCF5	2017-07-07 13:53:00+03	32200.00
AFCD5E	2017-08-08 04:25:00+03	136800.00
AFCD68	2017-08-04 05:01:00+03	114600.00
AFCD95	2017-07-24 14:04:00+03	171000.00
AFCDC8	2017-08-06 05:44:00+03	119500.00
AFCE94	2017-07-24 02:11:00+03	84500.00
AFCF22	2017-07-03 08:11:00+03	54800.00
AFCF3D	2017-07-20 11:07:00+03	54000.00
AFCF8C	2017-07-15 12:30:00+03	145100.00
AFCFC3	2017-07-27 06:58:00+03	48700.00
AFD01C	2017-07-03 10:59:00+03	56600.00
AFD0AC	2017-07-27 03:58:00+03	260900.00
AFD117	2017-08-13 19:21:00+03	266300.00
AFD165	2017-07-08 14:33:00+03	11800.00
AFD213	2017-08-04 17:42:00+03	16400.00
AFD22A	2017-08-11 09:02:00+03	8600.00
AFD35B	2017-07-29 23:41:00+03	137100.00
AFD3E2	2017-08-02 23:29:00+03	110900.00
AFD3FC	2017-07-24 21:37:00+03	117100.00
AFD41B	2017-08-06 07:55:00+03	57400.00
AFD4A4	2017-08-12 13:03:00+03	181600.00
AFD515	2017-08-05 20:54:00+03	57800.00
AFD561	2017-07-20 13:39:00+03	129200.00
AFD594	2017-07-13 11:34:00+03	62900.00
AFD59B	2017-08-11 12:10:00+03	68800.00
AFD5DD	2017-06-27 17:46:00+03	187800.00
AFD5E8	2017-07-23 03:21:00+03	89600.00
AFD6A4	2017-07-25 17:15:00+03	133100.00
AFD6C5	2017-07-20 18:06:00+03	111900.00
AFD6D6	2017-07-28 05:00:00+03	123000.00
AFD6E0	2017-07-24 01:19:00+03	78400.00
AFD703	2017-07-26 23:35:00+03	57600.00
AFD727	2017-07-01 16:04:00+03	56000.00
AFD7D9	2017-07-02 12:56:00+03	23600.00
AFD8B3	2017-08-01 01:01:00+03	135600.00
AFD8EB	2017-07-02 22:24:00+03	66600.00
AFD905	2017-07-13 16:33:00+03	173200.00
AFD90B	2017-07-23 11:42:00+03	160300.00
AFD912	2017-08-14 18:23:00+03	12000.00
AFD91B	2017-07-17 03:59:00+03	26800.00
AFDA20	2017-08-12 19:22:00+03	46400.00
AFDA46	2017-07-04 10:44:00+03	23600.00
AFDA50	2017-07-16 00:46:00+03	227600.00
AFDA66	2017-07-09 20:18:00+03	75200.00
AFDA75	2017-07-27 07:50:00+03	8600.00
AFDAB9	2017-07-28 07:35:00+03	56600.00
AFDB08	2017-07-07 19:53:00+03	257600.00
AFDB2E	2017-07-14 11:54:00+03	265800.00
AFDB36	2017-08-06 01:04:00+03	56000.00
AFDB7E	2017-07-23 06:54:00+03	31600.00
AFDB91	2017-08-14 10:20:00+03	70800.00
AFDBD1	2017-07-28 18:43:00+03	84500.00
AFDBE2	2017-07-31 11:24:00+03	39200.00
AFDC09	2017-07-07 19:54:00+03	6700.00
AFDC69	2017-07-01 05:18:00+03	22000.00
AFDD90	2017-08-05 10:48:00+03	61500.00
AFDE30	2017-07-01 09:53:00+03	47000.00
AFDEA3	2017-08-11 16:58:00+03	67200.00
AFDF03	2017-07-18 12:58:00+03	59800.00
AFDF69	2017-08-09 20:07:00+03	134600.00
AFDF7E	2017-07-11 17:32:00+03	140800.00
AFE044	2017-07-29 07:35:00+03	50000.00
AFE095	2017-07-28 11:05:00+03	246000.00
AFE09F	2017-07-21 16:21:00+03	118400.00
AFE1FE	2017-07-13 22:32:00+03	67200.00
AFE212	2017-08-03 12:24:00+03	125200.00
AFE222	2017-07-16 23:58:00+03	15000.00
AFE27D	2017-08-02 22:57:00+03	23400.00
AFE28A	2017-08-10 06:46:00+03	14800.00
AFE301	2017-07-14 17:08:00+03	149100.00
AFE311	2017-08-12 06:40:00+03	33300.00
AFE32C	2017-08-02 07:43:00+03	92600.00
AFE369	2017-08-03 19:11:00+03	56600.00
AFE3A6	2017-07-23 08:51:00+03	57600.00
AFE3F1	2017-08-10 21:31:00+03	170300.00
AFE444	2017-07-03 07:32:00+03	40700.00
AFE478	2017-07-11 06:01:00+03	43500.00
AFE49F	2017-07-15 23:59:00+03	297600.00
AFE4A0	2017-07-23 18:59:00+03	43000.00
AFE4DB	2017-08-12 09:38:00+03	265600.00
AFE538	2017-07-30 01:04:00+03	89000.00
AFE562	2017-07-17 09:02:00+03	56000.00
AFE59D	2017-08-10 10:42:00+03	57400.00
AFE68E	2017-07-04 08:57:00+03	47200.00
AFE71D	2017-07-21 19:42:00+03	78500.00
AFE72E	2017-07-15 17:12:00+03	86500.00
AFE737	2017-07-04 19:55:00+03	58200.00
AFE746	2017-07-24 12:54:00+03	412400.00
AFE788	2017-07-08 23:30:00+03	23200.00
AFE79D	2017-08-07 11:19:00+03	55800.00
AFE7A0	2017-08-08 15:13:00+03	6800.00
AFE869	2017-08-13 17:27:00+03	21800.00
AFE8B5	2017-07-09 18:15:00+03	37900.00
AFE8D3	2017-08-08 04:52:00+03	56100.00
AFE8DF	2017-08-02 22:55:00+03	112300.00
AFE8F9	2017-07-03 10:28:00+03	38800.00
AFE92B	2017-07-30 16:13:00+03	156200.00
AFE97B	2017-07-18 00:18:00+03	69500.00
AFE9F6	2017-07-02 10:46:00+03	56000.00
AFEA49	2017-07-16 06:59:00+03	113200.00
AFEA99	2017-07-08 20:58:00+03	6000.00
AFEB1A	2017-08-01 07:31:00+03	28800.00
AFEB7A	2017-08-13 04:09:00+03	45100.00
AFEBCE	2017-08-04 20:44:00+03	6300.00
AFEC10	2017-08-06 19:57:00+03	64700.00
AFEC44	2017-08-14 14:29:00+03	6700.00
AFEC5E	2017-07-13 08:00:00+03	94900.00
AFECC3	2017-07-12 08:43:00+03	46000.00
AFED52	2017-07-16 00:17:00+03	30400.00
AFED76	2017-08-09 12:04:00+03	65400.00
AFEDC3	2017-07-23 16:27:00+03	34000.00
AFEDE7	2017-07-07 22:52:00+03	73500.00
AFEE68	2017-08-14 00:59:00+03	38400.00
AFEE96	2017-08-13 20:31:00+03	14400.00
AFEF13	2017-07-26 06:39:00+03	88600.00
AFEF31	2017-08-06 07:29:00+03	24400.00
AFEF3C	2017-07-27 21:16:00+03	86800.00
AFEF3E	2017-07-15 22:50:00+03	28000.00
AFF02A	2017-07-19 15:38:00+03	265700.00
AFF060	2017-08-01 06:02:00+03	67200.00
AFF062	2017-07-24 12:25:00+03	43500.00
AFF06A	2017-07-14 16:53:00+03	112000.00
AFF084	2017-07-11 00:00:00+03	21800.00
AFF16F	2017-07-03 19:55:00+03	28800.00
AFF185	2017-07-25 14:45:00+03	184300.00
AFF189	2017-08-04 23:53:00+03	54800.00
AFF20F	2017-08-14 16:10:00+03	71600.00
AFF21E	2017-08-11 10:40:00+03	113000.00
AFF245	2017-07-06 02:11:00+03	6000.00
AFF259	2017-07-10 20:30:00+03	16400.00
AFF25E	2017-07-07 06:21:00+03	55400.00
AFF2CE	2017-07-21 09:02:00+03	56900.00
AFF2CF	2017-07-03 19:39:00+03	25000.00
AFF319	2017-08-13 11:15:00+03	79400.00
AFF388	2017-07-23 13:23:00+03	206800.00
AFF39E	2017-07-07 01:19:00+03	13600.00
AFF3B3	2017-07-27 03:07:00+03	23600.00
AFF3E8	2017-07-24 20:29:00+03	116800.00
AFF42F	2017-07-27 02:25:00+03	153800.00
AFF437	2017-07-04 05:26:00+03	20000.00
AFF46F	2017-07-31 21:01:00+03	55800.00
AFF493	2017-07-22 20:01:00+03	28000.00
AFF4C5	2017-08-01 16:25:00+03	253300.00
AFF564	2017-08-03 11:44:00+03	254600.00
AFF57A	2017-08-05 17:20:00+03	213200.00
AFF58D	2017-07-16 21:32:00+03	6700.00
AFF5E9	2017-07-12 22:10:00+03	30200.00
AFF60D	2017-07-27 21:38:00+03	105600.00
AFF664	2017-07-12 01:23:00+03	140900.00
AFF668	2017-07-16 05:11:00+03	35900.00
AFF670	2017-07-22 03:13:00+03	139200.00
AFF767	2017-06-29 05:42:00+03	95700.00
AFF7A0	2017-08-11 11:10:00+03	59600.00
AFF7B2	2017-07-02 02:50:00+03	47700.00
AFF826	2017-07-17 15:14:00+03	203100.00
AFF870	2017-08-07 10:14:00+03	112000.00
AFF871	2017-07-20 02:41:00+03	72400.00
AFF8AC	2017-08-12 13:31:00+03	50400.00
AFF8AF	2017-07-02 10:26:00+03	28000.00
AFF8BA	2017-08-08 15:18:00+03	378400.00
AFF8E3	2017-07-10 07:40:00+03	12600.00
AFF8EB	2017-08-12 22:56:00+03	63500.00
AFF962	2017-07-20 20:18:00+03	44800.00
AFF98D	2017-07-20 07:43:00+03	31600.00
AFF993	2017-08-03 05:13:00+03	243600.00
AFFA0C	2017-07-19 03:08:00+03	266400.00
AFFA27	2017-07-14 15:25:00+03	62300.00
AFFA52	2017-08-08 21:01:00+03	166100.00
AFFA8C	2017-07-09 20:58:00+03	215100.00
AFFA8D	2017-08-09 00:09:00+03	15800.00
AFFAE1	2017-07-12 21:52:00+03	90400.00
AFFB73	2017-07-15 07:34:00+03	6700.00
AFFBC2	2017-07-10 12:54:00+03	21800.00
AFFC05	2017-08-10 11:44:00+03	46400.00
AFFC0C	2017-07-26 17:43:00+03	52700.00
AFFC8B	2017-07-15 01:24:00+03	133100.00
AFFC8D	2017-07-31 20:31:00+03	70400.00
AFFD49	2017-07-02 16:44:00+03	96800.00
AFFD62	2017-08-05 06:12:00+03	22000.00
AFFDB9	2017-08-01 14:15:00+03	136200.00
AFFE40	2017-08-12 02:05:00+03	12000.00
AFFE48	2017-07-02 14:25:00+03	65900.00
AFFE81	2017-07-16 20:36:00+03	16400.00
AFFEE9	2017-08-15 12:42:00+03	56600.00
AFFF18	2017-07-23 01:31:00+03	67100.00
AFFF99	2017-07-02 10:27:00+03	56000.00
AFFFA2	2017-07-12 09:07:00+03	257600.00
AFFFD0	2017-07-24 05:12:00+03	51900.00
B00043	2017-07-14 13:54:00+03	58000.00
B0006F	2017-07-28 13:09:00+03	112000.00
B000B6	2017-07-19 01:58:00+03	179400.00
B00106	2017-07-17 06:46:00+03	24800.00
B00115	2017-07-22 18:44:00+03	65500.00
B00137	2017-07-10 01:38:00+03	111600.00
B0017C	2017-07-26 00:02:00+03	50000.00
B001A4	2017-07-03 04:09:00+03	23600.00
B001F6	2017-08-04 00:16:00+03	289100.00
B00222	2017-07-13 03:30:00+03	133200.00
B00286	2017-07-28 14:26:00+03	46200.00
B002B4	2017-08-08 07:50:00+03	28200.00
B002B6	2017-07-15 23:10:00+03	26800.00
B002E2	2017-07-11 05:22:00+03	59200.00
B0034B	2017-07-26 20:02:00+03	47000.00
B00365	2017-07-11 08:35:00+03	91200.00
B00386	2017-07-04 07:10:00+03	246000.00
B003C3	2017-07-31 20:56:00+03	24400.00
B003D5	2017-08-01 09:40:00+03	47000.00
B003E2	2017-07-31 11:05:00+03	497800.00
B00415	2017-07-31 23:19:00+03	35300.00
B00430	2017-07-28 03:18:00+03	72400.00
B0046C	2017-07-02 18:05:00+03	56200.00
B0047D	2017-07-19 13:40:00+03	43200.00
B0047F	2017-06-30 00:42:00+03	328600.00
B004EE	2017-07-07 16:12:00+03	100500.00
B004F8	2017-07-11 06:22:00+03	18900.00
B0051A	2017-07-28 18:39:00+03	36200.00
B005A5	2017-07-15 08:23:00+03	40100.00
B005C5	2017-07-06 17:39:00+03	13600.00
B00671	2017-07-09 12:57:00+03	75600.00
B00744	2017-07-21 09:44:00+03	157100.00
B00847	2017-07-28 15:25:00+03	77200.00
B0085C	2017-07-07 08:09:00+03	72200.00
B008A0	2017-08-02 23:52:00+03	98400.00
B008C3	2017-07-31 06:27:00+03	58800.00
B00937	2017-07-26 10:38:00+03	235200.00
B00960	2017-07-04 23:42:00+03	133200.00
B00991	2017-07-21 11:09:00+03	41900.00
B009A4	2017-07-19 23:40:00+03	234700.00
B00A21	2017-08-10 00:12:00+03	55600.00
B00A8E	2017-08-13 18:38:00+03	23100.00
B00AEE	2017-07-15 12:19:00+03	40800.00
B00AF3	2017-07-22 10:33:00+03	79400.00
B00B38	2017-07-18 17:02:00+03	73500.00
B00C66	2017-08-03 06:17:00+03	12600.00
B00C74	2017-07-14 13:10:00+03	112000.00
B00D56	2017-08-10 06:10:00+03	44700.00
B00DB4	2017-08-05 09:16:00+03	31600.00
B00DEE	2017-07-13 20:15:00+03	136200.00
B00DFC	2017-07-08 07:02:00+03	89700.00
B00E1C	2017-07-26 19:13:00+03	91700.00
B00EB5	2017-07-17 12:49:00+03	22000.00
B00EC7	2017-08-07 14:20:00+03	24400.00
B00EE1	2017-07-18 01:27:00+03	122300.00
B00EE5	2017-08-07 10:14:00+03	28000.00
B00F66	2017-07-08 15:32:00+03	42400.00
B00F6D	2017-07-21 06:53:00+03	14800.00
B00FA5	2017-08-02 00:30:00+03	115400.00
B00FB3	2017-07-07 11:15:00+03	265700.00
B0111F	2017-07-31 02:41:00+03	137600.00
B01122	2017-07-26 06:25:00+03	12600.00
B01137	2017-07-26 04:57:00+03	15900.00
B011A0	2017-08-12 07:05:00+03	72600.00
B011B5	2017-07-23 04:59:00+03	90400.00
B011D6	2017-07-06 19:25:00+03	87400.00
B011E8	2017-08-15 16:49:00+03	44100.00
B01216	2017-07-04 03:29:00+03	61900.00
B0121B	2017-07-24 00:03:00+03	58600.00
B01245	2017-08-06 11:11:00+03	225800.00
B01296	2017-08-09 12:48:00+03	88800.00
B01299	2017-07-26 15:05:00+03	84300.00
B012BC	2017-07-16 23:24:00+03	28000.00
B012FA	2017-07-12 06:02:00+03	62600.00
B013BE	2017-07-25 08:34:00+03	136200.00
B01457	2017-07-12 20:54:00+03	57100.00
B014A2	2017-07-24 19:36:00+03	64800.00
B014E1	2017-08-09 01:30:00+03	88800.00
B01519	2017-07-27 02:39:00+03	21800.00
B01557	2017-07-16 12:06:00+03	369000.00
B0156B	2017-07-28 12:02:00+03	112600.00
B015C8	2017-08-11 12:26:00+03	70800.00
B015CA	2017-08-14 12:27:00+03	11700.00
B015DB	2017-07-26 21:16:00+03	53800.00
B015FB	2017-08-11 21:58:00+03	40300.00
B01608	2017-07-06 21:29:00+03	101700.00
B01672	2017-07-05 07:49:00+03	13400.00
B016D3	2017-08-12 13:21:00+03	24300.00
B016F3	2017-07-18 03:22:00+03	38400.00
B01749	2017-08-13 21:50:00+03	54500.00
B0178B	2017-07-18 01:19:00+03	13400.00
B017B8	2017-07-26 03:33:00+03	135200.00
B01820	2017-07-06 19:25:00+03	68000.00
B0183D	2017-08-13 06:09:00+03	23200.00
B01878	2017-07-21 09:02:00+03	57700.00
B01902	2017-08-04 19:51:00+03	33600.00
B0190A	2017-06-28 05:42:00+03	67200.00
B01A78	2017-07-25 13:23:00+03	12600.00
B01B04	2017-08-11 21:12:00+03	246000.00
B01B23	2017-08-13 12:56:00+03	147000.00
B01B4D	2017-07-04 14:38:00+03	135600.00
B01BE8	2017-07-12 23:14:00+03	42400.00
B01BF2	2017-08-12 12:05:00+03	72400.00
B01C01	2017-08-06 14:23:00+03	31600.00
B01C2A	2017-07-29 17:39:00+03	152900.00
B01C4E	2017-08-09 19:33:00+03	81600.00
B01C5D	2017-07-03 12:51:00+03	135400.00
B01C75	2017-07-03 20:48:00+03	20400.00
B01CB6	2017-08-09 19:03:00+03	82000.00
B01D76	2017-08-04 12:31:00+03	43200.00
B01E04	2017-07-19 13:30:00+03	47200.00
B01E49	2017-07-10 09:45:00+03	39800.00
B01EE2	2017-07-11 06:19:00+03	46000.00
B01FB2	2017-07-14 18:38:00+03	39800.00
B01FF9	2017-07-10 05:53:00+03	135400.00
B02067	2017-07-09 04:01:00+03	57600.00
B02073	2017-07-08 22:00:00+03	19800.00
B02087	2017-07-12 06:05:00+03	27300.00
B020B7	2017-07-14 16:34:00+03	145300.00
B020BF	2017-07-12 05:10:00+03	133700.00
B020FE	2017-07-24 15:51:00+03	12600.00
B02132	2017-07-08 13:47:00+03	115900.00
B02151	2017-07-11 19:14:00+03	16000.00
B02156	2017-07-25 14:55:00+03	173600.00
B02169	2017-07-24 17:34:00+03	123000.00
B02183	2017-06-26 21:54:00+03	169600.00
B021C7	2017-07-16 07:39:00+03	28000.00
B021DC	2017-07-24 15:50:00+03	155600.00
B021FB	2017-07-23 01:10:00+03	52000.00
B02207	2017-07-31 02:02:00+03	85700.00
B02245	2017-07-24 21:54:00+03	114500.00
B0226A	2017-07-18 10:10:00+03	11600.00
B02277	2017-08-10 03:05:00+03	64700.00
B0227C	2017-07-18 23:51:00+03	168000.00
B02344	2017-07-31 06:35:00+03	58600.00
B0238C	2017-07-20 10:31:00+03	6000.00
B023D4	2017-07-19 14:59:00+03	25600.00
B0243D	2017-07-08 19:09:00+03	86500.00
B0248C	2017-08-06 17:05:00+03	26000.00
B024AA	2017-08-10 10:45:00+03	128800.00
B024AB	2017-08-01 16:39:00+03	38400.00
B024EE	2017-06-29 06:19:00+03	30200.00
B02559	2017-08-09 22:53:00+03	103900.00
B02609	2017-07-04 18:06:00+03	55800.00
B0261C	2017-07-19 16:40:00+03	116900.00
B02645	2017-07-23 01:42:00+03	16400.00
B0269F	2017-07-21 19:44:00+03	32400.00
B026A4	2017-07-25 13:03:00+03	48500.00
B026B8	2017-08-14 14:55:00+03	56000.00
B026B9	2017-07-27 10:11:00+03	226200.00
B0270D	2017-08-06 16:12:00+03	27800.00
B0270E	2017-08-15 17:39:00+03	168000.00
B02738	2017-08-02 17:40:00+03	131600.00
B02757	2017-07-13 09:01:00+03	32700.00
B0276C	2017-08-11 11:31:00+03	81500.00
B027D3	2017-08-07 02:31:00+03	47000.00
B027FA	2017-08-08 03:00:00+03	53600.00
B0280F	2017-08-08 05:22:00+03	32800.00
B02830	2017-07-25 23:16:00+03	20600.00
B02832	2017-08-08 12:55:00+03	14800.00
B02850	2017-08-03 01:16:00+03	112000.00
B02863	2017-08-07 08:11:00+03	29800.00
B028B2	2017-08-13 02:51:00+03	201200.00
B028E4	2017-08-13 08:01:00+03	16000.00
B02928	2017-07-12 05:15:00+03	24400.00
B0292C	2017-07-18 10:13:00+03	103000.00
B02971	2017-07-11 12:34:00+03	15000.00
B02979	2017-07-19 01:52:00+03	66600.00
B0299E	2017-06-30 18:56:00+03	137100.00
B029F8	2017-07-09 18:10:00+03	114300.00
B02A45	2017-08-14 21:03:00+03	54400.00
B02AE5	2017-07-04 13:47:00+03	57900.00
B02BE7	2017-07-10 22:54:00+03	187600.00
B02C0B	2017-07-15 05:47:00+03	32700.00
B02C0C	2017-07-16 00:27:00+03	154500.00
B02C35	2017-07-12 09:04:00+03	59300.00
B02C9A	2017-07-18 17:02:00+03	94000.00
B02CAB	2017-07-04 08:00:00+03	37700.00
B02CC8	2017-07-20 07:08:00+03	137600.00
B02D04	2017-07-12 14:18:00+03	100200.00
B02D21	2017-08-01 09:41:00+03	21000.00
B02DB5	2017-07-12 19:59:00+03	187600.00
B02DEE	2017-08-10 00:46:00+03	88800.00
B02E2D	2017-07-14 04:22:00+03	62000.00
B02ED0	2017-08-04 16:54:00+03	43200.00
B02F11	2017-07-11 20:08:00+03	70600.00
B02F56	2017-07-22 19:18:00+03	25600.00
B02FC8	2017-07-14 07:55:00+03	26000.00
B02FDB	2017-07-31 16:07:00+03	12600.00
B02FFC	2017-07-05 23:02:00+03	57800.00
B02FFE	2017-08-11 10:27:00+03	285000.00
B0304D	2017-07-30 00:36:00+03	40400.00
B0306F	2017-07-25 14:58:00+03	72400.00
B03097	2017-07-14 18:15:00+03	49100.00
B030A2	2017-07-18 14:49:00+03	123000.00
B03106	2017-07-03 13:42:00+03	46200.00
B0316A	2017-07-07 10:17:00+03	18000.00
B031B1	2017-08-14 12:17:00+03	26600.00
B03218	2017-07-02 07:10:00+03	59300.00
B03281	2017-07-15 18:54:00+03	25400.00
B03299	2017-08-14 14:53:00+03	69500.00
B032BA	2017-07-12 13:32:00+03	21400.00
B032FA	2017-07-01 10:07:00+03	166100.00
B0331B	2017-08-15 09:47:00+03	26000.00
B03321	2017-06-29 19:50:00+03	139200.00
B0334E	2017-08-15 12:37:00+03	46300.00
B03362	2017-07-05 22:28:00+03	26100.00
B03382	2017-07-08 09:44:00+03	53600.00
B033B3	2017-07-31 13:15:00+03	116100.00
B033D2	2017-08-12 14:54:00+03	85400.00
B033DB	2017-07-22 23:11:00+03	19800.00
B03423	2017-07-29 03:36:00+03	65400.00
B03435	2017-07-14 01:56:00+03	23200.00
B03494	2017-07-14 10:23:00+03	114800.00
B034E3	2017-07-17 14:43:00+03	75300.00
B0351A	2017-06-30 08:00:00+03	79900.00
B03530	2017-06-30 14:37:00+03	132800.00
B03544	2017-07-29 01:47:00+03	67100.00
B035EA	2017-07-12 13:47:00+03	28200.00
B03611	2017-07-01 02:24:00+03	265800.00
B03613	2017-08-06 00:59:00+03	48800.00
B03635	2017-08-10 01:02:00+03	132800.00
B03655	2017-07-03 05:11:00+03	67200.00
B03680	2017-07-02 18:08:00+03	55800.00
B036D2	2017-08-10 00:53:00+03	119500.00
B03744	2017-08-13 03:17:00+03	109800.00
B037A8	2017-08-09 20:13:00+03	23200.00
B037BA	2017-08-11 16:40:00+03	99200.00
B037C2	2017-08-04 12:36:00+03	34000.00
B037DD	2017-07-08 03:23:00+03	50800.00
B037F9	2017-07-20 08:29:00+03	44600.00
B038CC	2017-07-14 05:42:00+03	12400.00
B038EA	2017-07-09 04:48:00+03	111600.00
B03935	2017-07-03 09:16:00+03	46300.00
B039E5	2017-07-20 03:27:00+03	27300.00
B03A0B	2017-07-22 22:21:00+03	24000.00
B03A78	2017-07-20 03:24:00+03	96300.00
B03A8B	2017-06-30 18:28:00+03	273400.00
B03B2E	2017-08-04 19:49:00+03	36600.00
B03B34	2017-07-12 13:49:00+03	25400.00
B03B9D	2017-07-05 09:05:00+03	112400.00
B03BC6	2017-08-02 06:27:00+03	33000.00
B03C7D	2017-08-02 15:11:00+03	23600.00
B03C86	2017-07-30 03:27:00+03	30200.00
B03CF5	2017-08-13 21:07:00+03	40400.00
B03D4D	2017-07-09 11:33:00+03	56000.00
B03D65	2017-08-11 02:09:00+03	34000.00
B03D6E	2017-08-14 22:09:00+03	36700.00
B03D75	2017-07-11 22:33:00+03	136400.00
B03D97	2017-07-06 02:10:00+03	36200.00
B03DB9	2017-07-06 22:08:00+03	235800.00
B03DEE	2017-08-05 13:28:00+03	28800.00
B03EEC	2017-07-17 01:11:00+03	58400.00
B03F56	2017-08-04 09:00:00+03	147700.00
B03FEE	2017-07-16 17:59:00+03	30200.00
B0403B	2017-07-28 06:34:00+03	55800.00
B0404F	2017-07-02 17:56:00+03	6000.00
B040B5	2017-08-05 21:47:00+03	33800.00
B040F1	2017-07-12 18:16:00+03	48800.00
B041C0	2017-08-11 00:58:00+03	64600.00
B041C9	2017-07-24 14:10:00+03	108000.00
B041E5	2017-07-10 17:07:00+03	26800.00
B04226	2017-07-30 08:55:00+03	60300.00
B0425B	2017-07-25 07:09:00+03	83100.00
B042B1	2017-07-14 14:18:00+03	55800.00
B042C2	2017-07-18 14:35:00+03	398500.00
B042F8	2017-07-24 00:40:00+03	128800.00
B0437B	2017-08-05 12:39:00+03	142400.00
B043A0	2017-07-11 19:13:00+03	73400.00
B04462	2017-08-07 13:59:00+03	64800.00
B04484	2017-07-04 03:27:00+03	30200.00
B044A9	2017-08-13 15:46:00+03	94000.00
B044BD	2017-07-12 02:48:00+03	48600.00
B0455E	2017-08-07 09:42:00+03	62600.00
B04592	2017-07-23 19:52:00+03	71300.00
B045B1	2017-07-26 14:37:00+03	120000.00
B045B8	2017-07-28 07:23:00+03	58600.00
B045E6	2017-07-08 06:41:00+03	62600.00
B04612	2017-07-10 12:23:00+03	189200.00
B0462D	2017-07-18 17:01:00+03	160700.00
B0462F	2017-07-27 08:45:00+03	24400.00
B04669	2017-07-24 19:05:00+03	103500.00
B0466C	2017-07-04 18:36:00+03	157500.00
B04693	2017-07-04 08:28:00+03	69500.00
B0469B	2017-07-17 09:40:00+03	28000.00
B046C7	2017-07-01 23:20:00+03	35200.00
B046D7	2017-08-12 22:36:00+03	77200.00
B04758	2017-08-02 20:22:00+03	18600.00
B0476B	2017-07-20 19:14:00+03	90400.00
B04874	2017-07-08 01:23:00+03	21600.00
B04877	2017-08-02 17:00:00+03	45200.00
B04906	2017-07-09 07:47:00+03	131600.00
B04929	2017-07-07 15:08:00+03	47500.00
B04933	2017-08-07 11:41:00+03	28000.00
B04995	2017-08-08 22:49:00+03	246000.00
B04A93	2017-07-01 19:06:00+03	24800.00
B04AB8	2017-07-15 19:00:00+03	98200.00
B04B42	2017-08-04 02:35:00+03	16800.00
B04B79	2017-07-12 19:36:00+03	8200.00
B04BE6	2017-08-04 10:31:00+03	38000.00
B04BF7	2017-08-03 20:09:00+03	130900.00
B04C5B	2017-07-24 03:03:00+03	12400.00
B04CFC	2017-07-17 22:10:00+03	21800.00
B04D21	2017-07-09 19:10:00+03	52000.00
B04D2E	2017-07-04 06:50:00+03	36200.00
B04D56	2017-07-21 05:30:00+03	21800.00
B04D8D	2017-07-17 04:09:00+03	73500.00
B04DD0	2017-08-09 23:04:00+03	100800.00
B04DE9	2017-08-15 14:40:00+03	18800.00
B04E2C	2017-07-21 07:07:00+03	46400.00
B04E44	2017-07-02 15:58:00+03	67800.00
B04E75	2017-07-29 13:20:00+03	15000.00
B04EA5	2017-08-05 09:31:00+03	80300.00
B04F5D	2017-08-07 12:59:00+03	34000.00
B04F68	2017-07-14 04:14:00+03	78500.00
B04F73	2017-08-03 01:36:00+03	123000.00
B04F97	2017-07-14 14:32:00+03	260300.00
B04FA9	2017-08-13 13:27:00+03	42600.00
B04FBA	2017-07-22 06:20:00+03	100600.00
B04FCA	2017-07-27 09:54:00+03	95200.00
B04FD3	2017-08-14 16:51:00+03	55800.00
B0512F	2017-07-20 11:37:00+03	66600.00
B05156	2017-08-07 01:02:00+03	165500.00
B051BA	2017-08-09 07:14:00+03	95200.00
B05205	2017-08-10 14:15:00+03	9200.00
B05224	2017-08-01 18:35:00+03	166900.00
B05230	2017-08-05 07:13:00+03	81700.00
B05249	2017-07-30 06:58:00+03	85000.00
B05285	2017-08-02 08:58:00+03	22400.00
B052CC	2017-07-26 20:23:00+03	66400.00
B052D2	2017-08-09 17:56:00+03	36200.00
B052F8	2017-08-03 15:44:00+03	6600.00
B052FA	2017-07-06 23:44:00+03	28700.00
B05300	2017-08-09 14:07:00+03	177200.00
B0530B	2017-08-06 18:51:00+03	24600.00
B05322	2017-07-06 02:57:00+03	116900.00
B05363	2017-07-24 11:23:00+03	27800.00
B05380	2017-08-05 15:08:00+03	23600.00
B0538A	2017-07-22 00:20:00+03	55800.00
B0538E	2017-07-13 00:51:00+03	8200.00
B053A7	2017-07-30 22:09:00+03	39500.00
B053EF	2017-07-10 03:02:00+03	85500.00
B05485	2017-07-17 09:25:00+03	37800.00
B054A7	2017-07-17 12:38:00+03	30400.00
B054E8	2017-08-02 04:19:00+03	81800.00
B05567	2017-08-11 23:19:00+03	88600.00
B055CF	2017-07-08 04:42:00+03	124300.00
B05610	2017-08-13 09:04:00+03	77900.00
B05699	2017-07-23 15:13:00+03	114700.00
B056AA	2017-07-07 01:34:00+03	35400.00
B0575E	2017-07-18 23:23:00+03	40800.00
B0579B	2017-07-22 06:39:00+03	53300.00
B057CF	2017-08-13 10:49:00+03	243300.00
B057FD	2017-07-29 23:27:00+03	29400.00
B0580E	2017-08-13 01:43:00+03	134800.00
B0581E	2017-08-06 09:19:00+03	341900.00
B05821	2017-08-06 08:17:00+03	36200.00
B05854	2017-07-22 16:10:00+03	112000.00
B0586D	2017-07-10 00:56:00+03	28000.00
B05884	2017-07-26 18:05:00+03	188100.00
B05893	2017-07-06 19:14:00+03	168600.00
B058F6	2017-07-24 20:04:00+03	70700.00
B05916	2017-07-18 22:34:00+03	31400.00
B05951	2017-08-06 18:42:00+03	54800.00
B0597A	2017-07-23 18:35:00+03	47400.00
B0599D	2017-07-02 16:06:00+03	49200.00
B059B1	2017-08-06 11:43:00+03	13800.00
B059B3	2017-07-12 14:36:00+03	31100.00
B059E8	2017-07-11 23:03:00+03	43000.00
B05A3C	2017-07-09 06:40:00+03	248300.00
B05AB1	2017-07-01 04:57:00+03	87700.00
B05B17	2017-07-10 00:21:00+03	56600.00
B05B1D	2017-07-28 19:47:00+03	35600.00
B05B4A	2017-08-05 16:38:00+03	14000.00
B05BAC	2017-07-24 00:51:00+03	47100.00
B05BCE	2017-08-02 10:53:00+03	119500.00
B05BDD	2017-07-31 04:50:00+03	27200.00
B05C56	2017-08-04 03:20:00+03	6700.00
B05C77	2017-08-05 13:27:00+03	92800.00
B05D5C	2017-07-30 06:18:00+03	50600.00
B05EE9	2017-07-02 02:16:00+03	39600.00
B05EF6	2017-07-23 12:00:00+03	116000.00
B05F3A	2017-07-27 18:02:00+03	65100.00
B05F73	2017-07-06 05:08:00+03	93000.00
B05FAC	2017-08-01 07:02:00+03	13700.00
B05FC3	2017-08-08 10:30:00+03	97000.00
B06022	2017-08-03 03:43:00+03	95600.00
B060BB	2017-08-08 10:46:00+03	18600.00
B060FB	2017-08-11 15:17:00+03	33300.00
B06157	2017-08-14 22:35:00+03	25100.00
B06159	2017-07-10 15:54:00+03	29600.00
B061AE	2017-08-06 20:42:00+03	26800.00
B061AF	2017-07-01 10:39:00+03	190700.00
B061F7	2017-07-03 07:09:00+03	26000.00
B0620C	2017-07-30 04:09:00+03	35800.00
B062C6	2017-08-12 08:27:00+03	35700.00
B062CE	2017-08-02 04:51:00+03	36200.00
B06310	2017-08-07 14:19:00+03	86600.00
B06366	2017-07-09 04:49:00+03	25400.00
B063A5	2017-07-19 18:05:00+03	25100.00
B063E3	2017-08-05 19:39:00+03	143100.00
B063F9	2017-08-01 14:07:00+03	67600.00
B06421	2017-07-17 09:43:00+03	48400.00
B06515	2017-07-30 00:48:00+03	19600.00
B0658E	2017-08-01 11:36:00+03	28000.00
B065BA	2017-07-15 09:03:00+03	75000.00
B066A4	2017-07-21 21:04:00+03	164400.00
B066B9	2017-07-05 09:36:00+03	85000.00
B066BC	2017-07-16 16:38:00+03	132800.00
B066FB	2017-07-13 15:52:00+03	55800.00
B06710	2017-07-18 08:55:00+03	85700.00
B06715	2017-08-09 14:09:00+03	90600.00
B06799	2017-07-08 06:41:00+03	13400.00
B067ED	2017-08-10 00:37:00+03	31100.00
B06816	2017-07-07 23:41:00+03	56600.00
B0686E	2017-08-13 08:21:00+03	85000.00
B068CE	2017-08-07 07:42:00+03	48000.00
B068D2	2017-07-11 22:32:00+03	69600.00
B069D7	2017-07-14 10:01:00+03	33300.00
B06A85	2017-08-08 11:11:00+03	433200.00
B06B3C	2017-08-03 09:19:00+03	414800.00
B06B6A	2017-07-23 16:06:00+03	56200.00
B06BCB	2017-07-13 13:05:00+03	199300.00
B06BFF	2017-07-18 14:24:00+03	25600.00
B06C38	2017-07-01 18:23:00+03	56600.00
B06C43	2017-07-19 23:31:00+03	153300.00
B06C6A	2017-07-16 22:14:00+03	52000.00
B06CC0	2017-07-10 23:53:00+03	59400.00
B06CDE	2017-08-15 07:30:00+03	44500.00
B06D6D	2017-07-31 06:54:00+03	53300.00
B06DB7	2017-07-05 15:59:00+03	35200.00
B06E3B	2017-07-31 00:08:00+03	53600.00
B06EFF	2017-07-20 06:50:00+03	53300.00
B06F1C	2017-08-09 20:18:00+03	56100.00
B06F3E	2017-07-15 15:12:00+03	94200.00
B06F7E	2017-07-25 22:16:00+03	67900.00
B06FA0	2017-07-14 09:54:00+03	517400.00
B07019	2017-07-09 09:13:00+03	75300.00
B0701D	2017-07-15 07:24:00+03	13400.00
B0702C	2017-08-10 05:07:00+03	133900.00
B070B5	2017-07-05 17:35:00+03	136800.00
B07122	2017-08-01 15:00:00+03	23200.00
B0712B	2017-08-07 09:36:00+03	42400.00
B07159	2017-07-19 03:42:00+03	141600.00
B071E6	2017-08-14 06:21:00+03	27900.00
B071E7	2017-07-20 23:22:00+03	135400.00
B071F2	2017-08-05 10:18:00+03	80000.00
B07220	2017-07-04 11:44:00+03	19600.00
B07268	2017-07-14 13:57:00+03	26000.00
B072AC	2017-07-05 05:02:00+03	70700.00
B07311	2017-07-14 22:08:00+03	6700.00
B07349	2017-07-13 20:21:00+03	54500.00
B07435	2017-07-24 14:29:00+03	86600.00
B0746A	2017-06-29 03:36:00+03	139300.00
B07536	2017-07-06 21:08:00+03	99300.00
B07562	2017-08-09 02:59:00+03	52000.00
B07565	2017-08-09 05:39:00+03	87000.00
B07653	2017-08-08 17:03:00+03	136800.00
B076B6	2017-07-17 00:28:00+03	56100.00
B076D9	2017-07-08 01:44:00+03	133200.00
B07726	2017-07-26 03:13:00+03	28800.00
B077A9	2017-08-07 02:34:00+03	62100.00
B07865	2017-08-08 02:23:00+03	89700.00
B078AC	2017-07-14 13:51:00+03	46400.00
B078F3	2017-07-22 13:36:00+03	18000.00
B078FA	2017-07-08 23:14:00+03	6700.00
B0798F	2017-08-12 07:09:00+03	32400.00
B0799F	2017-07-06 03:18:00+03	28000.00
B07A42	2017-07-23 10:48:00+03	124200.00
B07B84	2017-08-10 14:27:00+03	81300.00
B07C13	2017-07-20 23:30:00+03	185800.00
B07C16	2017-07-16 21:40:00+03	25000.00
B07C4E	2017-08-06 19:00:00+03	57400.00
B07C66	2017-08-09 10:12:00+03	185700.00
B07C7F	2017-07-03 09:17:00+03	246000.00
B07CBB	2017-07-31 09:18:00+03	209900.00
B07D35	2017-08-06 18:40:00+03	36800.00
B07D82	2017-08-13 02:00:00+03	74200.00
B07DD4	2017-08-13 13:13:00+03	21400.00
B07DFC	2017-08-02 19:29:00+03	6000.00
B07E31	2017-08-03 08:50:00+03	29600.00
B07E42	2017-08-01 00:27:00+03	187800.00
B07EAA	2017-07-27 15:43:00+03	64700.00
B07EC5	2017-07-09 21:00:00+03	69200.00
B07EE8	2017-07-12 06:48:00+03	126100.00
B07F51	2017-07-10 09:46:00+03	35600.00
B07F8E	2017-07-19 03:41:00+03	46200.00
B07FE4	2017-07-04 06:20:00+03	21800.00
B07FEA	2017-07-27 01:55:00+03	13800.00
B0801E	2017-08-03 02:47:00+03	99200.00
B08027	2017-07-14 01:53:00+03	67400.00
B0809A	2017-07-19 12:42:00+03	22000.00
B080FC	2017-08-11 07:58:00+03	47200.00
B08154	2017-07-15 16:53:00+03	35600.00
B0820E	2017-08-09 06:35:00+03	133200.00
B0822C	2017-07-09 13:51:00+03	30200.00
B08260	2017-07-09 23:36:00+03	10600.00
B0827E	2017-07-04 07:18:00+03	55800.00
B082EB	2017-07-08 10:41:00+03	42400.00
B0837B	2017-07-21 18:17:00+03	56600.00
B083BE	2017-07-12 03:25:00+03	132700.00
B083D0	2017-08-13 08:51:00+03	46500.00
B083FF	2017-07-08 07:54:00+03	66600.00
B08435	2017-07-23 06:26:00+03	109000.00
B08477	2017-08-10 19:09:00+03	90000.00
B08491	2017-08-02 19:26:00+03	52300.00
B084C2	2017-08-05 06:50:00+03	23200.00
B084DF	2017-07-26 08:04:00+03	46400.00
B085E8	2017-07-13 23:27:00+03	46400.00
B085FD	2017-08-07 07:36:00+03	7400.00
B08621	2017-07-27 00:12:00+03	286100.00
B08644	2017-07-01 17:47:00+03	35600.00
B08692	2017-07-09 17:34:00+03	23600.00
B0878F	2017-08-11 17:06:00+03	257600.00
B087A2	2017-08-06 10:01:00+03	86800.00
B087C8	2017-07-02 04:09:00+03	102100.00
B087E0	2017-08-14 23:49:00+03	81300.00
B08858	2017-07-26 04:03:00+03	56000.00
B0888E	2017-07-01 19:24:00+03	95600.00
B088CE	2017-08-04 04:50:00+03	6700.00
B08972	2017-07-31 10:55:00+03	97400.00
B0899B	2017-07-17 04:36:00+03	75300.00
B089AE	2017-08-08 18:16:00+03	135200.00
B089E2	2017-07-30 19:39:00+03	68400.00
B089FE	2017-07-29 09:59:00+03	97500.00
B08A5C	2017-08-06 00:23:00+03	56000.00
B08B0A	2017-08-08 10:08:00+03	73500.00
B08BC3	2017-07-06 05:28:00+03	284400.00
B08C6E	2017-07-08 22:08:00+03	44800.00
B08CFE	2017-07-26 14:32:00+03	28000.00
B08D18	2017-08-04 11:27:00+03	39400.00
B08D8C	2017-07-09 09:43:00+03	96200.00
B08E0A	2017-08-06 00:43:00+03	111600.00
B08E77	2017-07-30 04:47:00+03	12600.00
B08EBD	2017-07-31 11:56:00+03	23600.00
B08EEC	2017-08-03 04:29:00+03	16400.00
B08F85	2017-07-07 22:58:00+03	38200.00
B08FF7	2017-08-06 17:40:00+03	89000.00
B0902B	2017-08-04 14:34:00+03	131100.00
B09060	2017-07-10 20:18:00+03	66000.00
B090FA	2017-06-29 13:58:00+03	30200.00
B09126	2017-08-08 11:43:00+03	16800.00
B091A7	2017-07-30 00:55:00+03	102100.00
B091C6	2017-08-15 04:24:00+03	25200.00
B091C8	2017-07-23 18:34:00+03	114400.00
B0920F	2017-08-09 12:20:00+03	24800.00
B09221	2017-07-28 18:02:00+03	250600.00
B0927B	2017-08-03 01:38:00+03	270800.00
B092B6	2017-07-22 19:54:00+03	25800.00
B092C6	2017-08-05 04:57:00+03	262200.00
B092D3	2017-07-16 06:37:00+03	23200.00
B092FA	2017-07-06 02:57:00+03	132200.00
B0936D	2017-07-21 01:09:00+03	76600.00
B09374	2017-07-27 11:58:00+03	123800.00
B09377	2017-08-13 04:07:00+03	172900.00
B0937E	2017-07-26 18:43:00+03	68800.00
B09381	2017-08-07 06:55:00+03	198400.00
B093D9	2017-08-10 08:19:00+03	285500.00
B0941E	2017-07-19 08:57:00+03	95200.00
B09471	2017-06-29 23:44:00+03	88500.00
B09475	2017-07-24 09:49:00+03	14400.00
B09497	2017-07-28 08:16:00+03	46400.00
B094C1	2017-08-09 10:22:00+03	56600.00
B09507	2017-08-07 10:40:00+03	117200.00
B09521	2017-08-11 18:08:00+03	36700.00
B0960F	2017-08-02 23:26:00+03	64700.00
B09611	2017-08-02 13:02:00+03	112000.00
B096A0	2017-07-31 07:11:00+03	38400.00
B096CC	2017-07-14 18:42:00+03	41500.00
B09719	2017-07-15 09:23:00+03	25200.00
B097A5	2017-07-18 18:31:00+03	21000.00
B097CC	2017-07-19 02:50:00+03	58200.00
B098DF	2017-07-25 05:16:00+03	52300.00
B098EA	2017-08-05 22:29:00+03	59800.00
B0991D	2017-07-15 16:53:00+03	38800.00
B09974	2017-07-13 15:04:00+03	123000.00
B09986	2017-06-30 13:18:00+03	153300.00
B099E6	2017-07-30 06:17:00+03	196000.00
B09A06	2017-08-13 06:58:00+03	23600.00
B09B8A	2017-06-29 23:11:00+03	26000.00
B09B90	2017-07-31 10:48:00+03	93700.00
B09BC1	2017-07-17 16:20:00+03	28300.00
B09C0B	2017-08-13 14:24:00+03	146700.00
B09C4D	2017-07-27 19:18:00+03	26000.00
B09C8C	2017-07-14 09:37:00+03	19600.00
B09C94	2017-07-22 03:30:00+03	36800.00
B09CF4	2017-08-14 09:47:00+03	62100.00
B09CFD	2017-07-13 03:45:00+03	50400.00
B09D24	2017-07-16 16:16:00+03	56000.00
B09D6D	2017-07-20 17:31:00+03	6700.00
B09DEC	2017-07-04 03:03:00+03	101100.00
B09E06	2017-07-30 04:32:00+03	26000.00
B09E57	2017-07-12 17:42:00+03	27400.00
B09F61	2017-07-30 19:59:00+03	26200.00
B09F92	2017-07-07 07:16:00+03	44600.00
B09FE8	2017-07-22 07:09:00+03	6000.00
B0A00F	2017-08-15 02:10:00+03	58800.00
B0A04B	2017-07-11 07:29:00+03	284400.00
B0A06A	2017-08-01 02:03:00+03	21600.00
B0A06F	2017-07-16 19:28:00+03	71900.00
B0A094	2017-08-03 20:55:00+03	25600.00
B0A0F0	2017-07-29 01:55:00+03	83500.00
B0A0F5	2017-08-14 12:59:00+03	44500.00
B0A11F	2017-07-11 11:09:00+03	61400.00
B0A137	2017-08-08 17:03:00+03	270800.00
B0A151	2017-07-08 07:11:00+03	47400.00
B0A19B	2017-08-06 21:51:00+03	125700.00
B0A20F	2017-08-09 21:07:00+03	57800.00
B0A2B3	2017-08-15 03:38:00+03	272300.00
B0A2CA	2017-07-17 10:17:00+03	46800.00
B0A2FE	2017-07-01 19:05:00+03	43800.00
B0A34F	2017-08-14 08:56:00+03	67100.00
B0A383	2017-07-13 12:22:00+03	29400.00
B0A427	2017-08-14 18:00:00+03	24400.00
B0A450	2017-08-04 01:52:00+03	390400.00
B0A451	2017-08-06 23:02:00+03	66600.00
B0A584	2017-08-02 04:30:00+03	85000.00
B0A5A1	2017-07-22 09:00:00+03	15900.00
B0A614	2017-08-10 03:20:00+03	86800.00
B0A65D	2017-07-30 13:31:00+03	36500.00
B0A67D	2017-08-08 23:14:00+03	13700.00
B0A6AB	2017-07-14 10:38:00+03	54800.00
B0A727	2017-07-05 04:38:00+03	112000.00
B0A742	2017-08-03 23:45:00+03	133200.00
B0A74E	2017-07-15 04:25:00+03	21200.00
B0A74F	2017-07-29 15:02:00+03	30000.00
B0A7C1	2017-08-14 23:16:00+03	40600.00
B0A867	2017-08-09 07:50:00+03	58500.00
B0A947	2017-07-20 14:23:00+03	293700.00
B0A94F	2017-07-28 17:12:00+03	29600.00
B0AA0D	2017-07-17 20:55:00+03	56000.00
B0AA7A	2017-08-14 17:13:00+03	23600.00
B0AA9C	2017-08-14 13:01:00+03	49700.00
B0AA9D	2017-07-18 17:28:00+03	56000.00
B0AAB7	2017-08-09 12:24:00+03	97900.00
B0AAE5	2017-07-05 20:07:00+03	66400.00
B0AB22	2017-07-10 10:03:00+03	103800.00
B0ABAE	2017-08-04 18:34:00+03	90400.00
B0AC46	2017-07-13 07:13:00+03	61800.00
B0AC48	2017-08-09 08:21:00+03	27400.00
B0ACA7	2017-07-18 22:12:00+03	36600.00
B0AD33	2017-07-29 18:21:00+03	167200.00
B0AD9F	2017-07-28 22:41:00+03	196000.00
B0ADC1	2017-08-04 13:08:00+03	92800.00
B0ADCB	2017-08-02 09:54:00+03	52900.00
B0ADDA	2017-07-02 07:40:00+03	60400.00
B0AE01	2017-08-08 14:02:00+03	81600.00
B0AE07	2017-07-14 23:43:00+03	286100.00
B0AE7E	2017-07-10 23:08:00+03	16400.00
B0AEDB	2017-07-15 06:42:00+03	54800.00
B0AF4A	2017-08-01 22:31:00+03	135400.00
B0AF87	2017-07-13 01:44:00+03	92400.00
B0AF8E	2017-08-03 18:14:00+03	40000.00
B0AFE3	2017-07-05 07:04:00+03	125200.00
B0B032	2017-07-16 21:18:00+03	25600.00
B0B05F	2017-08-15 17:36:00+03	83000.00
B0B070	2017-07-13 05:55:00+03	24400.00
B0B14C	2017-08-13 21:42:00+03	88100.00
B0B17D	2017-08-14 14:01:00+03	13600.00
B0B1F2	2017-07-10 23:29:00+03	30200.00
B0B21D	2017-08-06 16:50:00+03	94000.00
B0B239	2017-07-12 01:01:00+03	71600.00
B0B244	2017-08-06 09:26:00+03	28000.00
B0B2A7	2017-08-04 21:21:00+03	23200.00
B0B342	2017-07-13 04:46:00+03	66600.00
B0B38D	2017-08-12 10:09:00+03	7400.00
B0B3D8	2017-07-06 19:32:00+03	13400.00
B0B40F	2017-08-12 19:38:00+03	224000.00
B0B427	2017-08-10 16:59:00+03	46800.00
B0B438	2017-06-30 04:58:00+03	40400.00
B0B5A6	2017-08-15 17:26:00+03	113200.00
B0B5F8	2017-07-09 18:40:00+03	73500.00
B0B66D	2017-08-06 17:43:00+03	46000.00
B0B67E	2017-08-07 05:49:00+03	53600.00
B0B6E9	2017-07-08 21:21:00+03	14400.00
B0B6F4	2017-07-26 22:17:00+03	56000.00
B0B6FF	2017-07-04 00:56:00+03	24800.00
B0B710	2017-07-10 04:53:00+03	278400.00
B0B780	2017-07-31 14:16:00+03	93000.00
B0B808	2017-07-21 01:28:00+03	113600.00
B0B80A	2017-07-11 20:05:00+03	136200.00
B0B844	2017-07-09 06:52:00+03	24700.00
B0B85D	2017-07-16 19:25:00+03	34000.00
B0B8C5	2017-07-08 18:54:00+03	316000.00
B0B8D7	2017-07-02 20:37:00+03	41800.00
B0B900	2017-07-11 18:53:00+03	37100.00
B0B9C2	2017-07-11 07:00:00+03	18600.00
B0B9CD	2017-07-10 18:38:00+03	54800.00
B0B9DD	2017-07-31 05:30:00+03	73500.00
B0B9F4	2017-08-11 17:12:00+03	373600.00
B0BA8C	2017-07-21 00:56:00+03	25100.00
B0BAEF	2017-08-11 02:36:00+03	47000.00
B0BB1E	2017-08-08 16:58:00+03	24700.00
B0BB64	2017-07-02 09:53:00+03	66800.00
B0BBD3	2017-07-01 21:44:00+03	177200.00
B0BBF6	2017-06-29 00:49:00+03	24800.00
B0BBFD	2017-08-12 18:00:00+03	67600.00
B0BC02	2017-08-15 01:26:00+03	18800.00
B0BC41	2017-08-09 17:17:00+03	37900.00
B0BC91	2017-08-15 12:26:00+03	32800.00
B0BCA5	2017-07-14 00:26:00+03	28000.00
B0BCC2	2017-08-14 20:28:00+03	269200.00
B0BCEB	2017-08-03 04:31:00+03	50700.00
B0BCFB	2017-07-05 14:12:00+03	100600.00
B0BD3E	2017-08-01 02:24:00+03	11600.00
B0BD49	2017-07-11 13:21:00+03	97600.00
B0BD90	2017-08-14 23:52:00+03	40100.00
B0BE27	2017-07-12 12:57:00+03	26300.00
B0BE2C	2017-06-24 13:15:00+03	44000.00
B0BE3C	2017-07-24 11:42:00+03	27800.00
B0BE3D	2017-07-21 19:57:00+03	78600.00
B0BE64	2017-08-01 19:36:00+03	61800.00
B0BE82	2017-07-18 07:45:00+03	80400.00
B0BE8D	2017-08-13 07:22:00+03	25100.00
B0BEC1	2017-08-04 08:53:00+03	28000.00
B0BED3	2017-07-04 20:43:00+03	73300.00
B0BEE8	2017-07-23 23:00:00+03	56100.00
B0BEF4	2017-07-20 04:54:00+03	27200.00
B0BF09	2017-07-30 23:18:00+03	117900.00
B0BF54	2017-07-10 07:30:00+03	85000.00
B0BFB1	2017-07-16 19:02:00+03	29400.00
B0BFE9	2017-07-22 04:17:00+03	42800.00
B0C03E	2017-08-04 04:14:00+03	39500.00
B0C06E	2017-07-14 08:00:00+03	22600.00
B0C09C	2017-07-04 21:31:00+03	205200.00
B0C0A5	2017-07-25 03:08:00+03	44800.00
B0C108	2017-07-31 09:05:00+03	46500.00
B0C120	2017-07-27 03:47:00+03	14800.00
B0C15A	2017-08-06 22:12:00+03	31400.00
B0C1C7	2017-07-28 02:02:00+03	47000.00
B0C1D7	2017-07-11 01:28:00+03	98600.00
B0C263	2017-07-02 16:58:00+03	49600.00
B0C283	2017-08-09 09:23:00+03	27900.00
B0C291	2017-08-14 20:39:00+03	357600.00
B0C29B	2017-08-14 05:53:00+03	50600.00
B0C2C5	2017-07-02 01:13:00+03	52000.00
B0C337	2017-07-04 02:14:00+03	70700.00
B0C349	2017-07-26 22:46:00+03	18000.00
B0C370	2017-07-03 15:56:00+03	52400.00
B0C374	2017-08-07 19:40:00+03	32700.00
B0C3B0	2017-07-31 16:47:00+03	25600.00
B0C3B5	2017-08-04 10:49:00+03	66700.00
B0C3FE	2017-07-10 11:35:00+03	46500.00
B0C400	2017-08-12 09:18:00+03	229500.00
B0C488	2017-07-26 08:14:00+03	38600.00
B0C4B8	2017-07-30 19:39:00+03	62100.00
B0C4E0	2017-07-13 00:27:00+03	65900.00
B0C56D	2017-07-25 15:51:00+03	33300.00
B0C590	2017-07-04 16:08:00+03	117700.00
B0C695	2017-08-09 04:39:00+03	73300.00
B0C69A	2017-08-13 01:03:00+03	28800.00
B0C6A6	2017-06-30 13:22:00+03	23200.00
B0C6D1	2017-07-02 02:53:00+03	96800.00
B0C6D7	2017-08-10 05:12:00+03	40000.00
B0C6E0	2017-08-13 05:30:00+03	148200.00
B0C719	2017-07-14 17:51:00+03	19600.00
B0C726	2017-08-07 01:51:00+03	8200.00
B0C76A	2017-07-05 09:16:00+03	87200.00
B0C8A7	2017-08-13 16:29:00+03	120300.00
B0C8B4	2017-07-11 21:18:00+03	14000.00
B0C8BC	2017-07-11 20:51:00+03	89600.00
B0C938	2017-07-26 10:59:00+03	92000.00
B0C9A0	2017-08-10 06:57:00+03	32800.00
B0C9AA	2017-07-01 20:23:00+03	94000.00
B0CA17	2017-07-23 03:38:00+03	404900.00
B0CA8D	2017-07-06 16:36:00+03	123000.00
B0CABE	2017-07-13 10:48:00+03	35000.00
B0CADE	2017-08-08 08:55:00+03	58000.00
B0CB06	2017-07-16 21:28:00+03	26000.00
B0CB08	2017-07-04 23:58:00+03	283100.00
B0CB74	2017-08-03 00:54:00+03	238700.00
B0CB98	2017-07-11 02:24:00+03	167400.00
B0CC3E	2017-08-06 01:28:00+03	26000.00
B0CCFA	2017-07-30 04:50:00+03	8200.00
B0CD03	2017-07-24 16:42:00+03	13600.00
B0CD36	2017-07-13 12:35:00+03	40400.00
B0CD59	2017-07-12 08:24:00+03	33000.00
B0CE04	2017-08-13 13:09:00+03	29600.00
B0CE33	2017-07-04 16:55:00+03	55800.00
B0CE47	2017-08-02 21:43:00+03	178800.00
B0CE4B	2017-07-31 19:58:00+03	40000.00
B0CE94	2017-07-19 15:49:00+03	17200.00
B0CEBE	2017-07-17 21:03:00+03	72300.00
B0CF22	2017-07-18 23:35:00+03	51600.00
B0CF2B	2017-07-25 21:33:00+03	248500.00
B0CFBA	2017-07-16 19:30:00+03	159200.00
B0CFD3	2017-07-29 10:56:00+03	32800.00
B0CFFB	2017-07-04 05:04:00+03	16800.00
B0D02F	2017-07-12 13:27:00+03	151500.00
B0D034	2017-06-30 06:05:00+03	67200.00
B0D050	2017-08-03 09:11:00+03	31600.00
B0D06B	2017-07-12 05:06:00+03	178800.00
B0D0A6	2017-08-03 00:53:00+03	73600.00
B0D0ED	2017-07-22 04:04:00+03	97700.00
B0D109	2017-07-29 05:12:00+03	100000.00
B0D1C0	2017-07-22 06:13:00+03	12000.00
B0D1C1	2017-07-28 23:19:00+03	124200.00
B0D265	2017-07-23 04:09:00+03	11600.00
B0D275	2017-07-15 02:17:00+03	39800.00
B0D27F	2017-08-11 15:07:00+03	45100.00
B0D28D	2017-07-31 17:03:00+03	38400.00
B0D2B0	2017-08-05 13:22:00+03	44000.00
B0D2C7	2017-06-30 11:39:00+03	53600.00
B0D309	2017-07-29 11:42:00+03	28800.00
B0D344	2017-07-31 02:21:00+03	26000.00
B0D366	2017-07-05 08:15:00+03	300800.00
B0D38F	2017-07-11 16:26:00+03	247700.00
B0D3A0	2017-07-21 17:56:00+03	20400.00
B0D3BE	2017-08-08 05:00:00+03	11600.00
B0D4AA	2017-07-04 04:00:00+03	6000.00
B0D4BB	2017-07-09 16:07:00+03	38400.00
B0D4D2	2017-07-11 04:37:00+03	153200.00
B0D4F4	2017-07-01 01:16:00+03	39800.00
B0D60A	2017-07-30 06:59:00+03	55800.00
B0D64D	2017-07-27 18:11:00+03	24400.00
B0D659	2017-07-16 15:19:00+03	28800.00
B0D695	2017-08-06 16:30:00+03	266300.00
B0D69D	2017-08-08 17:06:00+03	65100.00
B0D6E7	2017-07-23 18:48:00+03	45100.00
B0D736	2017-07-21 20:04:00+03	63200.00
B0D788	2017-07-07 23:59:00+03	132800.00
B0D7AC	2017-07-06 07:14:00+03	49200.00
B0D7C4	2017-07-13 02:28:00+03	63700.00
B0D7ED	2017-08-01 09:22:00+03	25000.00
B0D805	2017-07-13 03:10:00+03	75300.00
B0D80D	2017-08-12 00:43:00+03	44000.00
B0D811	2017-07-09 02:35:00+03	109600.00
B0D879	2017-07-19 13:52:00+03	74900.00
B0D880	2017-07-28 18:48:00+03	25600.00
B0D8A6	2017-07-06 21:35:00+03	14900.00
B0D8C6	2017-06-30 13:19:00+03	290500.00
B0D8C7	2017-08-06 03:48:00+03	73500.00
B0D8C8	2017-07-02 13:01:00+03	170800.00
B0D8C9	2017-07-04 13:47:00+03	93800.00
B0D907	2017-08-15 04:35:00+03	26000.00
B0D90C	2017-07-11 01:36:00+03	11600.00
B0D960	2017-08-09 21:15:00+03	25400.00
B0D969	2017-07-01 16:38:00+03	28000.00
B0D983	2017-07-06 11:23:00+03	24800.00
B0D9B3	2017-07-20 09:11:00+03	60400.00
B0D9D0	2017-08-12 02:42:00+03	52600.00
B0D9FD	2017-07-23 22:53:00+03	6900.00
B0DA27	2017-07-20 21:02:00+03	78100.00
B0DA3F	2017-08-11 17:40:00+03	32200.00
B0DA87	2017-07-01 04:44:00+03	46300.00
B0DB11	2017-08-01 00:40:00+03	36200.00
B0DB42	2017-06-27 03:02:00+03	100600.00
B0DB7A	2017-08-07 03:22:00+03	6300.00
B0DC25	2017-07-31 23:51:00+03	99200.00
B0DCA5	2017-07-23 14:59:00+03	25400.00
B0DCEC	2017-07-21 18:17:00+03	94400.00
B0DD71	2017-07-07 23:29:00+03	49400.00
B0DD8B	2017-07-26 22:42:00+03	75600.00
B0DE37	2017-07-07 10:44:00+03	192500.00
B0DE49	2017-07-17 18:45:00+03	139100.00
B0DE71	2017-08-10 20:12:00+03	61800.00
B0DE8B	2017-07-20 04:14:00+03	135900.00
B0DEA9	2017-08-10 08:46:00+03	24400.00
B0DEB3	2017-08-13 02:56:00+03	18000.00
B0DEE0	2017-08-13 19:45:00+03	51100.00
B0DEEC	2017-07-01 23:12:00+03	56000.00
B0DEF2	2017-08-09 03:29:00+03	23200.00
B0DF16	2017-07-20 15:13:00+03	21800.00
B0DF34	2017-08-12 19:20:00+03	129000.00
B0DF5B	2017-07-12 07:52:00+03	56100.00
B0DF70	2017-07-19 21:01:00+03	55800.00
B0DFBD	2017-07-12 15:26:00+03	30800.00
B0DFBF	2017-07-19 21:41:00+03	38600.00
B0E029	2017-08-07 19:14:00+03	89700.00
B0E033	2017-07-06 09:42:00+03	56000.00
B0E043	2017-08-15 13:32:00+03	75300.00
B0E090	2017-08-14 12:48:00+03	25800.00
B0E116	2017-07-10 11:38:00+03	16400.00
B0E140	2017-07-10 23:59:00+03	46400.00
B0E165	2017-07-07 05:39:00+03	19600.00
B0E1FB	2017-07-26 22:03:00+03	61800.00
B0E2AF	2017-08-11 16:00:00+03	70700.00
B0E2EA	2017-07-30 08:43:00+03	135600.00
B0E362	2017-08-13 06:54:00+03	51600.00
B0E383	2017-07-11 07:54:00+03	30200.00
B0E3C3	2017-08-12 16:38:00+03	53700.00
B0E42D	2017-08-10 13:45:00+03	95500.00
B0E4C1	2017-07-05 16:57:00+03	31600.00
B0E4F1	2017-07-31 04:27:00+03	99200.00
B0E50B	2017-07-03 07:34:00+03	105000.00
B0E587	2017-08-10 03:55:00+03	112000.00
B0E5D7	2017-07-31 05:09:00+03	23200.00
B0E620	2017-07-09 23:13:00+03	55800.00
B0E63D	2017-07-10 01:48:00+03	23200.00
B0E65B	2017-07-11 01:42:00+03	28000.00
B0E661	2017-07-21 19:10:00+03	23600.00
B0E66B	2017-08-14 05:34:00+03	132800.00
B0E684	2017-07-25 01:11:00+03	40800.00
B0E692	2017-07-01 18:27:00+03	14400.00
B0E6A8	2017-07-14 19:21:00+03	31000.00
B0E6CC	2017-07-26 02:38:00+03	8200.00
B0E6DF	2017-08-05 04:59:00+03	14800.00
B0E6EA	2017-08-03 04:14:00+03	16800.00
B0E6F1	2017-07-03 22:34:00+03	21400.00
B0E703	2017-07-28 22:40:00+03	35700.00
B0E741	2017-07-22 02:13:00+03	16400.00
B0E7A4	2017-08-12 03:49:00+03	20400.00
B0E7EE	2017-08-01 11:16:00+03	38100.00
B0E802	2017-07-12 04:14:00+03	73900.00
B0E83D	2017-07-09 08:05:00+03	36200.00
B0E86A	2017-07-25 04:58:00+03	85000.00
B0E8DB	2017-07-01 21:50:00+03	53300.00
B0E907	2017-07-11 20:12:00+03	115900.00
B0E917	2017-07-03 07:45:00+03	14800.00
B0E931	2017-07-05 09:14:00+03	24400.00
B0E93A	2017-08-05 16:19:00+03	86800.00
B0E94B	2017-07-11 15:40:00+03	17200.00
B0E985	2017-07-12 18:47:00+03	56000.00
B0E9B3	2017-07-09 18:47:00+03	112000.00
B0EAC1	2017-07-23 19:59:00+03	398500.00
B0EACD	2017-08-10 22:26:00+03	46700.00
B0EB2F	2017-07-02 17:59:00+03	10700.00
B0EB84	2017-07-28 06:30:00+03	67500.00
B0EBE3	2017-08-13 23:06:00+03	56100.00
B0EBEC	2017-07-21 07:34:00+03	36000.00
B0EBF4	2017-07-09 18:10:00+03	58600.00
B0EC70	2017-07-19 23:34:00+03	23100.00
B0ED05	2017-08-12 04:24:00+03	172200.00
B0ED0D	2017-08-15 09:31:00+03	24600.00
B0EDE1	2017-07-06 08:03:00+03	167400.00
B0EDF4	2017-08-14 15:25:00+03	104800.00
B0EE5A	2017-06-28 12:14:00+03	31500.00
B0EEAB	2017-08-13 10:18:00+03	6200.00
B0EEF4	2017-08-13 21:10:00+03	56100.00
B0EF14	2017-08-07 20:19:00+03	22400.00
B0EF44	2017-07-30 22:58:00+03	55800.00
B0EF76	2017-07-23 11:02:00+03	58900.00
B0EF9A	2017-07-20 20:34:00+03	45100.00
B0EFE1	2017-08-05 00:32:00+03	10800.00
B0F039	2017-07-20 07:31:00+03	69500.00
B0F049	2017-07-19 13:46:00+03	64700.00
B0F092	2017-07-20 15:33:00+03	38200.00
B0F099	2017-08-03 17:38:00+03	28000.00
B0F0B9	2017-07-18 01:37:00+03	91100.00
B0F125	2017-08-10 23:23:00+03	135400.00
B0F129	2017-08-08 04:30:00+03	65900.00
B0F133	2017-07-28 22:37:00+03	12600.00
B0F154	2017-08-12 12:12:00+03	79600.00
B0F177	2017-07-05 05:56:00+03	27800.00
B0F1A4	2017-07-17 21:30:00+03	67600.00
B0F1BC	2017-08-09 06:19:00+03	193100.00
B0F1DE	2017-07-13 10:21:00+03	88100.00
B0F248	2017-07-21 09:18:00+03	29600.00
B0F288	2017-08-09 23:02:00+03	14800.00
B0F2BC	2017-07-07 05:55:00+03	114800.00
B0F2CC	2017-08-03 00:48:00+03	202800.00
B0F2DA	2017-06-29 18:51:00+03	114700.00
B0F2E4	2017-08-12 05:45:00+03	20400.00
B0F379	2017-08-14 04:25:00+03	33300.00
B0F37E	2017-07-28 11:27:00+03	266400.00
B0F3B6	2017-07-05 17:06:00+03	46400.00
B0F3B9	2017-07-30 12:55:00+03	28800.00
B0F3C9	2017-07-08 20:31:00+03	40000.00
B0F4EE	2017-07-17 11:29:00+03	50600.00
B0F51E	2017-07-13 07:21:00+03	25000.00
B0F53C	2017-08-11 13:55:00+03	198000.00
B0F544	2017-07-05 17:03:00+03	26700.00
B0F548	2017-07-25 07:12:00+03	135600.00
B0F57B	2017-07-21 05:47:00+03	22800.00
B0F5C6	2017-08-15 13:45:00+03	41500.00
B0F5D6	2017-07-31 16:21:00+03	53600.00
B0F5D7	2017-07-17 07:26:00+03	112000.00
B0F5E7	2017-07-28 04:12:00+03	55600.00
B0F680	2017-07-09 12:07:00+03	23400.00
B0F6A1	2017-08-11 06:57:00+03	61800.00
B0F713	2017-07-25 18:54:00+03	41800.00
B0F718	2017-07-29 09:18:00+03	111600.00
B0F73F	2017-06-29 19:20:00+03	98800.00
B0F767	2017-08-14 01:03:00+03	12100.00
B0F791	2017-06-29 19:28:00+03	83200.00
B0F7D4	2017-07-20 19:42:00+03	166000.00
B0F7E1	2017-07-11 01:34:00+03	108900.00
B0F832	2017-08-08 16:57:00+03	83700.00
B0F899	2017-08-03 22:58:00+03	113000.00
B0F8EA	2017-07-23 19:23:00+03	44800.00
B0F8F4	2017-07-10 20:36:00+03	21800.00
B0F906	2017-08-08 07:26:00+03	56600.00
B0F92D	2017-06-29 08:35:00+03	196100.00
B0F97C	2017-07-11 16:33:00+03	147700.00
B0F990	2017-07-04 14:33:00+03	75600.00
B0F9F4	2017-07-21 10:31:00+03	28000.00
B0FA0A	2017-07-27 20:59:00+03	66600.00
B0FACB	2017-07-05 08:38:00+03	37200.00
B0FAD1	2017-08-03 22:47:00+03	28000.00
B0FB87	2017-08-09 10:28:00+03	59300.00
B0FB8C	2017-08-14 05:44:00+03	30800.00
B0FBBC	2017-08-03 23:54:00+03	43600.00
B0FBE2	2017-07-22 12:02:00+03	46400.00
B0FBE8	2017-08-08 15:27:00+03	29600.00
B0FC68	2017-07-27 14:08:00+03	62900.00
B0FCCE	2017-07-18 22:06:00+03	40200.00
B0FD24	2017-07-13 01:40:00+03	24400.00
B0FD50	2017-07-22 16:52:00+03	75300.00
B0FD65	2017-08-02 11:55:00+03	93200.00
B0FD9C	2017-07-28 14:25:00+03	131900.00
B0FE4F	2017-08-06 08:43:00+03	54800.00
B0FEC7	2017-08-03 04:44:00+03	88400.00
B0FEE4	2017-08-13 03:18:00+03	98100.00
B0FF55	2017-08-08 19:36:00+03	26800.00
B0FF6A	2017-07-16 08:46:00+03	14800.00
B0FF6B	2017-08-03 18:55:00+03	91600.00
B0FF8D	2017-07-20 11:39:00+03	116400.00
B1000F	2017-07-02 15:58:00+03	56600.00
B10026	2017-07-05 03:07:00+03	28800.00
B10081	2017-08-06 19:06:00+03	12600.00
B10101	2017-07-10 11:21:00+03	168000.00
B1010C	2017-07-16 20:48:00+03	23200.00
B1016F	2017-07-18 00:07:00+03	62000.00
B101C5	2017-07-21 03:42:00+03	40200.00
B101D4	2017-08-09 09:54:00+03	37700.00
B101DC	2017-07-05 00:51:00+03	57900.00
B1029F	2017-07-07 22:40:00+03	28000.00
B102DC	2017-07-26 23:11:00+03	55800.00
B1038B	2017-07-11 05:26:00+03	88900.00
B10396	2017-08-12 11:59:00+03	27300.00
B103F0	2017-07-07 20:17:00+03	73200.00
B103F2	2017-08-07 18:49:00+03	56600.00
B1045A	2017-07-03 10:02:00+03	42800.00
B1046D	2017-07-24 04:54:00+03	29000.00
B104BF	2017-08-03 13:56:00+03	117200.00
B104E1	2017-07-28 05:00:00+03	72300.00
B10501	2017-08-13 19:31:00+03	80500.00
B10518	2017-07-14 03:37:00+03	35800.00
B10554	2017-08-06 02:46:00+03	89700.00
B1057C	2017-08-03 17:41:00+03	56600.00
B1057F	2017-07-20 13:46:00+03	54300.00
B1063A	2017-07-07 22:21:00+03	477500.00
B10667	2017-07-27 01:28:00+03	25600.00
B106C2	2017-08-09 05:51:00+03	32800.00
B106D9	2017-07-05 18:11:00+03	32200.00
B106E4	2017-07-26 23:39:00+03	229900.00
B106FD	2017-07-24 14:05:00+03	48800.00
B10701	2017-07-28 20:32:00+03	51900.00
B107F8	2017-07-04 14:05:00+03	54600.00
B10808	2017-07-10 17:33:00+03	54800.00
B1084B	2017-07-04 21:05:00+03	98200.00
B108CC	2017-08-02 20:32:00+03	28800.00
B108F7	2017-07-28 07:40:00+03	106400.00
B10920	2017-07-20 20:03:00+03	103600.00
B109A7	2017-08-01 08:15:00+03	229800.00
B109D7	2017-06-30 12:13:00+03	162200.00
B10AC4	2017-07-11 10:45:00+03	23500.00
B10AD2	2017-08-06 02:04:00+03	170800.00
B10AE2	2017-08-02 12:32:00+03	131100.00
B10B45	2017-08-06 16:57:00+03	209900.00
B10B9E	2017-08-08 18:36:00+03	120900.00
B10BF9	2017-07-02 15:53:00+03	81600.00
B10C54	2017-08-13 13:08:00+03	29600.00
B10C6C	2017-07-05 02:35:00+03	64800.00
B10CA2	2017-07-10 01:55:00+03	36000.00
B10CAB	2017-07-28 09:31:00+03	406100.00
B10CC8	2017-07-22 02:37:00+03	62600.00
B10D15	2017-07-12 06:51:00+03	87200.00
B10D75	2017-07-28 00:09:00+03	25600.00
B10DC3	2017-07-27 03:06:00+03	57400.00
B10DDD	2017-07-05 04:52:00+03	169900.00
B10F2F	2017-08-12 09:35:00+03	55700.00
B10F3F	2017-07-29 08:08:00+03	67200.00
B10F59	2017-07-30 21:42:00+03	199700.00
B10F89	2017-07-24 05:23:00+03	45200.00
B11034	2017-07-18 23:04:00+03	70600.00
B11076	2017-07-09 01:27:00+03	71700.00
B11089	2017-07-12 22:09:00+03	14400.00
B1113D	2017-07-25 13:42:00+03	93900.00
B1113F	2017-08-11 08:43:00+03	18400.00
B11176	2017-07-11 16:10:00+03	46000.00
B11181	2017-08-06 16:25:00+03	26000.00
B1118D	2017-07-26 10:52:00+03	67800.00
B11197	2017-08-02 09:54:00+03	12400.00
B111B1	2017-08-03 03:41:00+03	119600.00
B111C0	2017-08-11 21:39:00+03	21400.00
B111F4	2017-08-15 10:09:00+03	51800.00
B11212	2017-07-09 13:52:00+03	48800.00
B11242	2017-07-23 20:52:00+03	53200.00
B11264	2017-07-22 09:06:00+03	81900.00
B11286	2017-07-25 18:29:00+03	6800.00
B112B3	2017-08-02 07:43:00+03	6400.00
B112FC	2017-07-24 04:25:00+03	23200.00
B1140E	2017-08-04 21:40:00+03	14000.00
B114AC	2017-07-19 13:15:00+03	481900.00
B114FC	2017-08-09 08:11:00+03	47100.00
B11569	2017-07-01 01:04:00+03	13000.00
B11599	2017-07-23 15:46:00+03	115600.00
B115BF	2017-08-06 22:24:00+03	164400.00
B115CB	2017-07-16 12:22:00+03	41600.00
B116A1	2017-08-06 18:38:00+03	40400.00
B11716	2017-07-22 04:19:00+03	46400.00
B11730	2017-08-06 00:56:00+03	26200.00
B11790	2017-07-16 09:40:00+03	137700.00
B11811	2017-08-01 13:20:00+03	54400.00
B1182B	2017-08-11 23:07:00+03	28700.00
B11835	2017-07-07 15:33:00+03	305400.00
B11840	2017-07-28 05:16:00+03	56600.00
B11858	2017-07-01 14:39:00+03	43200.00
B1190E	2017-08-01 20:16:00+03	61900.00
B1193F	2017-07-29 09:49:00+03	336100.00
B119B7	2017-07-10 17:08:00+03	103700.00
B119F1	2017-07-28 04:18:00+03	44500.00
B11A28	2017-07-07 03:07:00+03	26800.00
B11A63	2017-08-03 20:49:00+03	67600.00
B11A67	2017-08-13 07:15:00+03	48800.00
B11A77	2017-08-04 07:41:00+03	68200.00
B11ABF	2017-07-04 15:13:00+03	232800.00
B11B0B	2017-07-14 08:36:00+03	92700.00
B11B3D	2017-07-13 14:53:00+03	23200.00
B11BBF	2017-07-26 04:20:00+03	53500.00
B11C29	2017-07-30 10:36:00+03	12600.00
B11C6E	2017-07-04 02:29:00+03	15200.00
B11C8C	2017-07-06 06:50:00+03	193500.00
B11CB9	2017-07-15 19:07:00+03	38400.00
B11D16	2017-06-30 15:18:00+03	43200.00
B11D1C	2017-07-08 21:36:00+03	123000.00
B11DA6	2017-07-10 20:15:00+03	42800.00
B11DC6	2017-07-13 14:37:00+03	126500.00
B11DE4	2017-07-10 06:53:00+03	94700.00
B11DF2	2017-07-19 00:50:00+03	7200.00
B11E0E	2017-08-03 18:52:00+03	61200.00
B11E23	2017-08-03 18:31:00+03	22200.00
B11E2C	2017-08-14 05:58:00+03	37700.00
B11E6F	2017-07-03 21:48:00+03	105900.00
B11F42	2017-07-27 04:20:00+03	29400.00
B11F7C	2017-07-09 04:49:00+03	15800.00
B11FCC	2017-08-01 11:11:00+03	51800.00
B12050	2017-08-06 09:06:00+03	49100.00
B120C8	2017-07-13 10:27:00+03	64400.00
B12102	2017-07-29 03:04:00+03	28000.00
B121E6	2017-08-07 11:14:00+03	58600.00
B12206	2017-07-09 22:29:00+03	121200.00
B12220	2017-08-13 15:46:00+03	167200.00
B12261	2017-07-06 12:13:00+03	148800.00
B1227C	2017-08-06 06:54:00+03	112000.00
B12283	2017-08-06 05:41:00+03	78100.00
B122DA	2017-08-06 22:34:00+03	135400.00
B122E8	2017-07-17 17:59:00+03	653400.00
B1235B	2017-08-12 04:31:00+03	22600.00
B1239E	2017-07-10 03:12:00+03	47200.00
B123A2	2017-07-13 15:40:00+03	86100.00
B123D8	2017-08-10 17:30:00+03	129100.00
B1240E	2017-07-26 06:43:00+03	23200.00
B1247E	2017-07-09 11:46:00+03	64300.00
B124A4	2017-07-06 13:51:00+03	113600.00
B12546	2017-07-02 16:39:00+03	43200.00
B1259E	2017-07-18 14:37:00+03	81700.00
B125AA	2017-07-19 15:57:00+03	37200.00
B1262B	2017-07-06 15:16:00+03	114400.00
B126A0	2017-08-04 23:09:00+03	171100.00
B126B9	2017-08-01 04:20:00+03	182300.00
B126C6	2017-08-07 16:14:00+03	34000.00
B126CC	2017-07-12 15:08:00+03	20200.00
B126D1	2017-08-02 19:20:00+03	99300.00
B126DE	2017-07-04 18:56:00+03	94000.00
B12729	2017-07-29 09:53:00+03	61500.00
B1272B	2017-08-06 04:27:00+03	143600.00
B1275E	2017-08-05 09:41:00+03	92800.00
B12769	2017-07-28 11:59:00+03	66100.00
B1279D	2017-07-21 16:24:00+03	29000.00
B127A5	2017-07-19 01:19:00+03	50000.00
B127C5	2017-07-28 19:46:00+03	9200.00
B12818	2017-07-15 13:43:00+03	76600.00
B1282F	2017-07-12 14:32:00+03	34000.00
B12848	2017-07-27 22:17:00+03	47400.00
B12856	2017-08-15 05:11:00+03	8000.00
B128DE	2017-07-27 16:19:00+03	50600.00
B128E4	2017-07-21 18:24:00+03	75500.00
B128F3	2017-08-15 00:16:00+03	24000.00
B1293D	2017-07-28 11:47:00+03	31400.00
B12960	2017-08-05 01:51:00+03	84800.00
B12983	2017-07-03 12:38:00+03	98400.00
B129C1	2017-08-13 09:47:00+03	37000.00
B129C7	2017-08-03 03:20:00+03	13700.00
B129EB	2017-07-24 04:30:00+03	28800.00
B12A49	2017-07-02 16:29:00+03	21000.00
B12AF3	2017-08-12 03:27:00+03	34000.00
B12BE8	2017-07-08 17:16:00+03	18000.00
B12BE9	2017-07-21 21:43:00+03	32100.00
B12C13	2017-07-01 00:52:00+03	46200.00
B12C6A	2017-08-12 08:35:00+03	100600.00
B12CE4	2017-07-08 01:19:00+03	14400.00
B12CE8	2017-07-29 09:36:00+03	25400.00
B12CF0	2017-08-03 05:48:00+03	70900.00
B12D2C	2017-07-22 09:31:00+03	37500.00
B12D91	2017-08-02 09:37:00+03	38400.00
B12DA5	2017-07-23 06:30:00+03	117600.00
B12DEA	2017-08-13 02:11:00+03	12600.00
B12EF1	2017-07-29 08:36:00+03	18600.00
B12EFC	2017-07-16 06:57:00+03	54500.00
B12F18	2017-06-30 12:58:00+03	24400.00
B12F39	2017-08-14 08:09:00+03	43200.00
B12F55	2017-07-16 13:10:00+03	44400.00
B12F70	2017-06-28 01:50:00+03	68100.00
B12F71	2017-08-08 14:57:00+03	28800.00
B1306A	2017-08-07 02:44:00+03	31200.00
B1311B	2017-08-12 10:02:00+03	45000.00
B13166	2017-07-27 10:50:00+03	199600.00
B13224	2017-08-01 07:05:00+03	14400.00
B132D0	2017-07-31 19:48:00+03	141600.00
B132D1	2017-07-21 10:14:00+03	28000.00
B13339	2017-07-13 06:56:00+03	178800.00
B1333A	2017-07-25 14:51:00+03	421200.00
B13386	2017-07-23 08:22:00+03	94000.00
B133D8	2017-06-30 22:27:00+03	84600.00
B133F7	2017-07-21 08:53:00+03	20200.00
B13582	2017-08-13 23:58:00+03	49500.00
B1359D	2017-08-02 07:41:00+03	75300.00
B135AA	2017-07-21 12:06:00+03	26800.00
B135D1	2017-08-13 08:30:00+03	53800.00
B135D3	2017-07-23 05:33:00+03	47400.00
B135EA	2017-08-02 16:00:00+03	65900.00
B135F3	2017-08-13 13:51:00+03	28000.00
B1362E	2017-07-13 19:01:00+03	12400.00
B1365A	2017-08-08 21:32:00+03	26000.00
B13785	2017-07-22 02:38:00+03	12000.00
B137CB	2017-07-24 13:36:00+03	28800.00
B1387B	2017-08-04 06:16:00+03	40800.00
B1387F	2017-08-06 05:03:00+03	20400.00
B138AF	2017-08-04 08:00:00+03	248400.00
B138B8	2017-07-09 04:26:00+03	25400.00
B1396C	2017-07-25 17:35:00+03	26800.00
B13986	2017-08-10 07:19:00+03	85200.00
B13987	2017-07-30 03:44:00+03	246000.00
B139DD	2017-07-08 17:24:00+03	50000.00
B13A98	2017-08-03 22:59:00+03	147900.00
B13AAE	2017-08-14 20:12:00+03	26800.00
B13B17	2017-07-27 09:34:00+03	71200.00
B13B35	2017-08-14 19:43:00+03	135400.00
B13BB0	2017-07-22 13:07:00+03	13400.00
B13C51	2017-08-06 20:08:00+03	92800.00
B13C59	2017-08-02 03:36:00+03	28800.00
B13C6B	2017-08-06 03:27:00+03	12400.00
B13C79	2017-07-25 08:13:00+03	67400.00
B13C88	2017-08-08 08:07:00+03	28000.00
B13CA2	2017-07-05 03:34:00+03	17000.00
B13CDB	2017-07-05 13:28:00+03	114700.00
B13D19	2017-08-07 16:23:00+03	40800.00
B13D1C	2017-07-24 13:17:00+03	86600.00
B13D39	2017-07-17 16:01:00+03	12400.00
B13D3E	2017-07-10 11:03:00+03	100600.00
B13DDD	2017-07-29 09:49:00+03	6300.00
B13E21	2017-07-07 17:11:00+03	32200.00
B13E49	2017-07-17 13:12:00+03	123000.00
B13E5F	2017-08-04 18:13:00+03	156400.00
B13E61	2017-08-06 03:01:00+03	57600.00
B13E8A	2017-08-03 19:52:00+03	35600.00
B13EDC	2017-07-31 04:04:00+03	66600.00
B13F2D	2017-07-13 07:12:00+03	99700.00
B13F51	2017-08-06 07:33:00+03	14000.00
B13FD6	2017-08-07 00:12:00+03	19600.00
B13FDC	2017-08-07 20:02:00+03	15000.00
B14053	2017-07-14 22:10:00+03	29400.00
B14094	2017-08-01 16:33:00+03	135600.00
B140B2	2017-07-24 20:21:00+03	172200.00
B1413F	2017-07-29 02:56:00+03	155600.00
B14174	2017-07-16 11:18:00+03	28000.00
B14270	2017-07-24 18:39:00+03	48900.00
B14290	2017-07-20 10:16:00+03	66600.00
B142B8	2017-08-02 06:50:00+03	29600.00
B1432B	2017-07-21 07:49:00+03	28000.00
B14342	2017-07-27 09:48:00+03	103900.00
B1436C	2017-07-27 04:37:00+03	123000.00
B14426	2017-07-18 19:05:00+03	98400.00
B1444C	2017-08-14 17:20:00+03	26000.00
B1444D	2017-07-28 07:29:00+03	32800.00
B14499	2017-07-22 09:43:00+03	44000.00
B144A3	2017-07-03 08:09:00+03	6000.00
B144AB	2017-07-11 12:08:00+03	26000.00
B144DE	2017-07-14 03:25:00+03	13600.00
B14601	2017-08-04 11:55:00+03	22200.00
B1460A	2017-07-07 18:44:00+03	125400.00
B1464F	2017-07-03 03:46:00+03	75600.00
B1466E	2017-06-30 13:49:00+03	23200.00
B14682	2017-08-13 07:03:00+03	49500.00
B14691	2017-07-18 04:29:00+03	168000.00
B146D0	2017-07-31 03:59:00+03	25100.00
B14758	2017-07-21 02:59:00+03	55600.00
B14765	2017-08-15 08:21:00+03	89600.00
B14818	2017-07-29 02:47:00+03	21000.00
B1493B	2017-07-09 07:29:00+03	46400.00
B149E2	2017-07-11 22:34:00+03	118800.00
B149E6	2017-07-22 06:46:00+03	60700.00
B149F5	2017-07-07 21:46:00+03	68100.00
B14A0B	2017-07-19 16:04:00+03	56000.00
B14A70	2017-08-05 07:35:00+03	56100.00
B14A95	2017-08-15 04:23:00+03	13400.00
B14A96	2017-07-10 12:02:00+03	103800.00
B14ABC	2017-07-28 04:59:00+03	189300.00
B14AC5	2017-07-21 06:46:00+03	39700.00
B14BAC	2017-07-13 09:11:00+03	136800.00
B14BD2	2017-07-06 16:48:00+03	8200.00
B14BD7	2017-07-04 15:32:00+03	100200.00
B14BF4	2017-07-08 02:52:00+03	28000.00
B14C27	2017-07-29 00:16:00+03	31400.00
B14C5F	2017-08-09 18:24:00+03	46800.00
B14C99	2017-08-07 04:01:00+03	36500.00
B14C9F	2017-07-31 23:39:00+03	73500.00
B14CA9	2017-07-25 18:01:00+03	23200.00
B14CDE	2017-07-03 03:32:00+03	55900.00
B14D01	2017-07-08 17:14:00+03	57600.00
B14D1C	2017-08-06 07:42:00+03	75600.00
B14D4F	2017-07-12 04:31:00+03	17800.00
B14DAE	2017-08-05 05:11:00+03	25000.00
B14DD8	2017-07-14 20:45:00+03	30200.00
B14E66	2017-07-30 23:36:00+03	55800.00
B14E83	2017-07-11 16:46:00+03	59300.00
B14E9F	2017-07-04 23:14:00+03	140800.00
B14F32	2017-07-09 11:02:00+03	67600.00
B14F7A	2017-07-10 17:04:00+03	41600.00
B14F81	2017-08-02 03:07:00+03	25400.00
B14FA3	2017-07-31 12:12:00+03	68800.00
B14FE5	2017-07-25 07:43:00+03	56000.00
B14FF9	2017-08-02 09:41:00+03	42400.00
B15063	2017-07-01 17:05:00+03	51900.00
B1506A	2017-07-31 13:49:00+03	68800.00
B15092	2017-08-10 17:31:00+03	40100.00
B150B3	2017-07-11 11:59:00+03	16400.00
B150F1	2017-08-06 20:28:00+03	65900.00
B15193	2017-07-30 09:59:00+03	72600.00
B151AF	2017-07-08 20:29:00+03	43200.00
B151CE	2017-07-02 23:14:00+03	72800.00
B151F9	2017-08-14 18:21:00+03	62700.00
B1522F	2017-07-29 20:11:00+03	40100.00
B15292	2017-07-14 10:06:00+03	68000.00
B15313	2017-08-13 22:54:00+03	69500.00
B1534B	2017-07-09 00:55:00+03	67200.00
B1534C	2017-07-01 14:56:00+03	69000.00
B1537F	2017-07-22 09:15:00+03	23400.00
B15381	2017-07-11 04:58:00+03	38600.00
B15388	2017-07-24 23:59:00+03	37200.00
B153DC	2017-07-06 04:26:00+03	129200.00
B153E7	2017-07-17 23:09:00+03	57600.00
B15411	2017-07-16 08:52:00+03	60400.00
B15416	2017-08-01 21:03:00+03	104100.00
B1546A	2017-08-05 18:56:00+03	139800.00
B154D7	2017-07-21 00:56:00+03	136200.00
B1551E	2017-08-14 03:32:00+03	61400.00
B15570	2017-06-30 07:09:00+03	93400.00
B155F7	2017-07-26 03:37:00+03	47100.00
B155FA	2017-07-26 16:55:00+03	24400.00
B1560D	2017-07-08 22:58:00+03	79000.00
B15611	2017-08-01 12:16:00+03	6000.00
B1565F	2017-07-26 16:39:00+03	30400.00
B1568D	2017-07-05 16:15:00+03	128800.00
B156B2	2017-08-11 11:34:00+03	31600.00
B156D0	2017-07-24 08:09:00+03	26700.00
B156D3	2017-07-10 08:10:00+03	59800.00
B1573D	2017-08-01 11:00:00+03	76300.00
B15786	2017-07-16 12:50:00+03	31000.00
B157FF	2017-07-13 18:41:00+03	230400.00
B1582B	2017-07-13 17:59:00+03	149300.00
B1582C	2017-08-12 15:39:00+03	21800.00
B158AE	2017-07-17 06:31:00+03	59100.00
B15973	2017-07-09 00:34:00+03	115800.00
B15A01	2017-08-05 20:49:00+03	25000.00
B15A4E	2017-08-13 10:34:00+03	41500.00
B15A63	2017-07-13 02:52:00+03	157100.00
B15A80	2017-08-11 17:26:00+03	48700.00
B15A83	2017-08-01 02:10:00+03	38600.00
B15B53	2017-07-24 23:25:00+03	38600.00
B15B6D	2017-07-11 21:34:00+03	33200.00
B15BFC	2017-08-08 23:24:00+03	57800.00
B15C0A	2017-07-16 19:12:00+03	56600.00
B15C3C	2017-08-01 10:09:00+03	92800.00
B15C56	2017-08-03 00:27:00+03	40800.00
B15CAB	2017-08-14 12:08:00+03	53500.00
B15CB8	2017-08-14 20:34:00+03	43600.00
B15CDC	2017-08-04 22:42:00+03	47100.00
B15CDD	2017-07-28 15:42:00+03	29200.00
B15CE0	2017-07-25 20:06:00+03	44800.00
B15E31	2017-07-29 06:28:00+03	37900.00
B15E3D	2017-07-20 22:48:00+03	148200.00
B15F09	2017-08-02 02:27:00+03	55800.00
B15F24	2017-07-11 02:03:00+03	27900.00
B15F2E	2017-06-28 07:36:00+03	12600.00
B15F35	2017-07-06 01:00:00+03	114800.00
B15F37	2017-08-11 03:01:00+03	26000.00
B1600D	2017-07-18 05:50:00+03	46700.00
B16020	2017-07-13 14:34:00+03	201200.00
B1608E	2017-07-21 03:21:00+03	23200.00
B1609B	2017-07-07 09:04:00+03	112000.00
B160C3	2017-07-24 06:49:00+03	282300.00
B16114	2017-08-01 14:13:00+03	40800.00
B161C6	2017-07-08 10:10:00+03	120800.00
B16212	2017-07-13 14:16:00+03	69900.00
B1625A	2017-07-31 23:02:00+03	71600.00
B16279	2017-07-03 15:58:00+03	167300.00
B1637A	2017-08-04 12:58:00+03	20400.00
B16394	2017-08-12 12:53:00+03	64200.00
B163B1	2017-07-17 04:20:00+03	24400.00
B163EE	2017-07-13 17:42:00+03	102200.00
B16442	2017-07-21 06:01:00+03	101200.00
B164C8	2017-07-05 02:04:00+03	50600.00
B16549	2017-08-04 09:24:00+03	6700.00
B16556	2017-08-15 16:48:00+03	25900.00
B16574	2017-07-07 13:02:00+03	87100.00
B1658A	2017-08-15 16:58:00+03	43200.00
B16657	2017-07-13 03:36:00+03	37700.00
B166EA	2017-08-08 23:18:00+03	266400.00
B16753	2017-07-29 11:17:00+03	56000.00
B16798	2017-07-13 06:49:00+03	6600.00
B167A9	2017-08-14 05:41:00+03	86600.00
B167FE	2017-07-10 13:25:00+03	133200.00
B16801	2017-08-04 17:58:00+03	81600.00
B16810	2017-07-12 23:19:00+03	46000.00
B16824	2017-07-02 13:31:00+03	50700.00
B16847	2017-07-30 19:50:00+03	50000.00
B16855	2017-06-29 22:41:00+03	85000.00
B16865	2017-08-06 18:42:00+03	76600.00
B16878	2017-07-19 16:21:00+03	26700.00
B168C8	2017-08-02 12:24:00+03	136200.00
B16902	2017-07-21 00:23:00+03	25600.00
B16A66	2017-08-12 17:55:00+03	125200.00
B16AA8	2017-07-31 18:13:00+03	92800.00
B16B75	2017-07-31 14:19:00+03	65600.00
B16B88	2017-07-13 12:50:00+03	64700.00
B16B9A	2017-07-22 14:22:00+03	100600.00
B16BA7	2017-07-19 19:37:00+03	159600.00
B16BAF	2017-08-08 16:40:00+03	131600.00
B16C24	2017-07-11 12:04:00+03	28000.00
B16C5A	2017-07-10 14:04:00+03	59300.00
B16C5F	2017-07-19 22:04:00+03	14400.00
B16CDB	2017-07-02 09:44:00+03	46300.00
B16D73	2017-08-15 06:16:00+03	52000.00
B16EAB	2017-07-10 22:29:00+03	26000.00
B16EB8	2017-08-06 09:05:00+03	42800.00
B16F2D	2017-07-03 23:52:00+03	77200.00
B1707E	2017-07-06 17:50:00+03	32800.00
B17093	2017-08-11 01:41:00+03	31000.00
B170FF	2017-07-18 12:52:00+03	132800.00
B1710C	2017-07-10 13:53:00+03	54800.00
B1712C	2017-07-15 15:35:00+03	27800.00
B1719D	2017-07-21 17:03:00+03	12600.00
B171E7	2017-08-08 03:38:00+03	23400.00
B172D7	2017-07-29 16:58:00+03	6800.00
B1738B	2017-08-08 11:46:00+03	289300.00
B173D1	2017-07-23 17:24:00+03	95300.00
B173EE	2017-07-07 07:58:00+03	65900.00
B17446	2017-07-22 23:35:00+03	56000.00
B17449	2017-08-08 19:28:00+03	67700.00
B1752A	2017-07-14 16:15:00+03	23200.00
B17554	2017-07-08 05:38:00+03	68900.00
B1755C	2017-07-19 18:12:00+03	94800.00
B1756C	2017-07-12 18:05:00+03	57300.00
B1757F	2017-08-12 19:47:00+03	147800.00
B175DB	2017-08-09 02:01:00+03	142900.00
B17670	2017-08-08 06:16:00+03	40000.00
B17683	2017-07-19 22:42:00+03	258400.00
B17686	2017-07-11 06:31:00+03	43900.00
B176AD	2017-08-03 14:34:00+03	6300.00
B176E1	2017-07-15 20:10:00+03	78800.00
B17725	2017-07-15 10:36:00+03	164900.00
B1772F	2017-07-01 20:28:00+03	51600.00
B177A0	2017-07-15 04:54:00+03	123600.00
B1782D	2017-08-08 03:30:00+03	12600.00
B17835	2017-07-06 08:03:00+03	32600.00
B17839	2017-08-02 19:07:00+03	16000.00
B1784A	2017-08-10 01:35:00+03	111600.00
B17898	2017-07-27 17:29:00+03	273000.00
B178BB	2017-08-06 06:38:00+03	27500.00
B17914	2017-07-17 11:42:00+03	51900.00
B17969	2017-07-23 14:18:00+03	84500.00
B1796B	2017-08-11 10:28:00+03	52000.00
B179AD	2017-08-11 02:24:00+03	77000.00
B179EA	2017-08-01 02:50:00+03	31700.00
B17A37	2017-07-19 18:26:00+03	112000.00
B17A57	2017-07-11 15:56:00+03	12400.00
B17A81	2017-07-27 17:14:00+03	7300.00
B17A93	2017-08-08 11:39:00+03	47000.00
B17AC4	2017-07-20 12:41:00+03	46400.00
B17AD9	2017-07-24 17:40:00+03	130300.00
B17B4E	2017-08-02 05:57:00+03	88500.00
B17B52	2017-08-01 20:56:00+03	133200.00
B17B8F	2017-07-22 01:21:00+03	112000.00
B17BA0	2017-08-14 03:38:00+03	25100.00
B17BD1	2017-06-29 18:48:00+03	48100.00
B17C24	2017-08-11 02:07:00+03	7400.00
B17C2A	2017-08-02 08:20:00+03	43600.00
B17C4F	2017-07-06 13:09:00+03	58600.00
B17C5A	2017-07-14 18:03:00+03	13600.00
B17CDC	2017-08-13 15:20:00+03	35900.00
B17CED	2017-07-22 17:08:00+03	28000.00
B17CEF	2017-08-10 20:15:00+03	101100.00
B17D35	2017-07-26 17:44:00+03	28700.00
B17DAD	2017-07-14 07:18:00+03	67000.00
B17E0F	2017-07-23 03:42:00+03	101200.00
B17E42	2017-08-06 02:36:00+03	50400.00
B17E44	2017-07-14 01:53:00+03	49600.00
B17E7F	2017-07-26 14:11:00+03	63200.00
B17E90	2017-08-11 12:20:00+03	6000.00
B17EC9	2017-07-29 04:14:00+03	41800.00
B17F01	2017-07-10 07:36:00+03	131100.00
B17F26	2017-07-26 02:06:00+03	70400.00
B17F7F	2017-08-02 10:43:00+03	153200.00
B17FB0	2017-07-21 09:37:00+03	169900.00
B17FB5	2017-07-31 12:55:00+03	28800.00
B17FE1	2017-08-12 23:09:00+03	25600.00
B1816E	2017-07-21 13:16:00+03	37900.00
B18178	2017-07-12 05:13:00+03	94000.00
B181A2	2017-08-01 09:03:00+03	38800.00
B181BE	2017-07-19 02:39:00+03	153000.00
B182F6	2017-07-04 01:57:00+03	23200.00
B1835C	2017-08-05 00:08:00+03	15800.00
B18389	2017-07-11 04:44:00+03	28800.00
B183A9	2017-08-04 20:55:00+03	167900.00
B183AB	2017-08-04 06:32:00+03	124600.00
B1843C	2017-07-12 07:23:00+03	27400.00
B18443	2017-07-05 03:11:00+03	27200.00
B18447	2017-07-04 10:35:00+03	17200.00
B184D1	2017-07-24 06:48:00+03	28800.00
B184D2	2017-08-13 19:17:00+03	100600.00
B184E1	2017-07-13 15:04:00+03	27200.00
B184E2	2017-07-17 12:57:00+03	19800.00
B18511	2017-07-17 23:31:00+03	112000.00
B1853C	2017-07-16 23:00:00+03	17000.00
B185D7	2017-07-25 22:57:00+03	42800.00
B18606	2017-07-25 12:46:00+03	28000.00
B186C4	2017-07-28 08:51:00+03	75200.00
B186F1	2017-07-31 19:46:00+03	32800.00
B18702	2017-07-19 20:08:00+03	15800.00
B18708	2017-08-07 23:52:00+03	27200.00
B1876D	2017-06-29 00:00:00+03	112000.00
B18770	2017-07-05 03:50:00+03	149600.00
B187C2	2017-07-13 18:40:00+03	13100.00
B18872	2017-07-27 17:52:00+03	173400.00
B1889C	2017-07-23 21:51:00+03	82900.00
B188B4	2017-07-09 20:12:00+03	6000.00
B188CA	2017-08-03 11:37:00+03	86800.00
B18921	2017-07-11 01:02:00+03	31600.00
B18924	2017-07-21 23:30:00+03	28800.00
B1897E	2017-08-06 08:55:00+03	179400.00
B189BF	2017-07-25 16:58:00+03	75300.00
B189C4	2017-07-14 20:01:00+03	26100.00
B189DE	2017-07-14 17:29:00+03	35700.00
B189F2	2017-07-11 00:20:00+03	531400.00
B18A5E	2017-07-25 14:37:00+03	71900.00
B18AD1	2017-07-25 11:21:00+03	46200.00
B18B0D	2017-07-26 02:34:00+03	192900.00
B18B62	2017-08-06 14:58:00+03	38800.00
B18B65	2017-08-13 21:51:00+03	58600.00
B18BC4	2017-07-18 16:53:00+03	106400.00
B18C1E	2017-07-19 22:36:00+03	65200.00
B18C27	2017-08-04 12:45:00+03	136400.00
B18CAA	2017-07-20 18:33:00+03	46400.00
B18CB0	2017-07-21 13:43:00+03	106400.00
B18CEF	2017-08-12 22:45:00+03	72400.00
B18D12	2017-08-15 14:33:00+03	22100.00
B18D16	2017-07-17 11:19:00+03	55800.00
B18D92	2017-07-26 12:29:00+03	13400.00
B18DCC	2017-07-22 15:47:00+03	28000.00
B18DFE	2017-08-10 16:12:00+03	62000.00
B18E08	2017-08-01 07:53:00+03	42000.00
B18E33	2017-08-08 04:05:00+03	23600.00
B18E76	2017-08-10 21:36:00+03	123000.00
B18EF0	2017-07-15 09:22:00+03	36700.00
B18FC7	2017-08-03 11:31:00+03	236300.00
B1907E	2017-07-09 10:28:00+03	12200.00
B19100	2017-07-29 10:22:00+03	42900.00
B19143	2017-08-01 07:40:00+03	398400.00
B19145	2017-07-11 23:49:00+03	58800.00
B19161	2017-08-10 21:22:00+03	52800.00
B19189	2017-07-25 06:24:00+03	31400.00
B19211	2017-08-07 08:09:00+03	56600.00
B1924C	2017-08-02 20:45:00+03	71800.00
B1924E	2017-07-15 18:34:00+03	47200.00
B192A7	2017-07-18 05:12:00+03	23600.00
B1934E	2017-07-26 19:58:00+03	56600.00
B19353	2017-07-06 19:52:00+03	46500.00
B1937C	2017-07-18 12:51:00+03	112800.00
B1939C	2017-08-06 20:27:00+03	46000.00
B193E3	2017-07-08 22:03:00+03	147800.00
B193E5	2017-08-02 07:04:00+03	16400.00
B19516	2017-08-02 10:30:00+03	28000.00
B19531	2017-07-07 06:08:00+03	46000.00
B1959B	2017-08-04 02:21:00+03	115700.00
B195A8	2017-07-03 13:32:00+03	306600.00
B19600	2017-08-11 18:09:00+03	81800.00
B19634	2017-07-30 20:45:00+03	133200.00
B1967B	2017-07-31 14:22:00+03	23400.00
B196B6	2017-07-12 08:17:00+03	56000.00
B196F6	2017-07-14 00:32:00+03	131900.00
B196FF	2017-08-08 13:02:00+03	23600.00
B1985C	2017-07-07 17:48:00+03	156500.00
B198A0	2017-08-12 01:17:00+03	67000.00
B198AA	2017-07-11 06:08:00+03	66100.00
B19942	2017-07-30 06:01:00+03	133800.00
B1995C	2017-07-07 07:21:00+03	66400.00
B19974	2017-07-29 11:04:00+03	83600.00
B19980	2017-07-08 04:17:00+03	149500.00
B199BD	2017-07-20 12:53:00+03	16000.00
B199D1	2017-08-06 20:05:00+03	77800.00
B199EC	2017-08-10 00:09:00+03	38800.00
B19A31	2017-08-05 23:33:00+03	12400.00
B19A4A	2017-08-03 01:00:00+03	246000.00
B19AB9	2017-08-08 06:39:00+03	76600.00
B19AD0	2017-07-13 01:47:00+03	12400.00
B19B3E	2017-08-03 12:43:00+03	52000.00
B19B69	2017-08-04 02:08:00+03	56600.00
B19BC2	2017-08-04 19:54:00+03	65900.00
B19BC9	2017-07-14 13:36:00+03	21300.00
B19BDD	2017-07-18 08:14:00+03	301800.00
B19BE2	2017-08-06 00:57:00+03	75300.00
B19C26	2017-07-05 20:01:00+03	59200.00
B19C5A	2017-07-03 21:32:00+03	184200.00
B19D32	2017-08-13 17:56:00+03	46200.00
B19D5E	2017-08-13 09:15:00+03	56000.00
B19D79	2017-07-30 15:44:00+03	6700.00
B19E25	2017-08-14 01:44:00+03	58200.00
B19E94	2017-08-01 00:11:00+03	178300.00
B19EED	2017-08-08 19:49:00+03	28000.00
B19F32	2017-08-12 16:47:00+03	135400.00
B1A01D	2017-07-06 00:40:00+03	55800.00
B1A02A	2017-07-05 12:28:00+03	259000.00
B1A0BA	2017-08-12 09:13:00+03	88900.00
B1A122	2017-08-09 07:55:00+03	54800.00
B1A136	2017-07-21 08:43:00+03	88900.00
B1A1C1	2017-07-27 10:11:00+03	57400.00
B1A1DA	2017-07-04 20:12:00+03	46800.00
B1A21E	2017-07-19 00:51:00+03	100600.00
B1A24A	2017-08-06 03:28:00+03	39100.00
B1A27A	2017-08-01 13:06:00+03	299700.00
B1A297	2017-07-30 03:51:00+03	78100.00
B1A300	2017-07-29 19:38:00+03	46400.00
B1A3D4	2017-08-11 01:53:00+03	14400.00
B1A43B	2017-07-05 00:38:00+03	70800.00
B1A49B	2017-07-29 01:59:00+03	25400.00
B1A49D	2017-08-09 07:39:00+03	128400.00
B1A55B	2017-07-15 21:04:00+03	63500.00
B1A579	2017-06-29 01:19:00+03	199700.00
B1A5B7	2017-07-16 08:14:00+03	89700.00
B1A5E2	2017-07-07 19:47:00+03	26800.00
B1A60C	2017-08-06 02:23:00+03	134800.00
B1A646	2017-07-27 04:22:00+03	15400.00
B1A65D	2017-08-10 07:28:00+03	380200.00
B1A68A	2017-07-07 11:10:00+03	167900.00
B1A6A2	2017-06-29 08:21:00+03	40000.00
B1A6F1	2017-07-11 03:16:00+03	24400.00
B1A7A2	2017-07-24 23:45:00+03	42400.00
B1A7A7	2017-08-06 10:34:00+03	85000.00
B1A81D	2017-07-17 12:44:00+03	190400.00
B1A824	2017-07-21 07:52:00+03	229900.00
B1A93A	2017-07-14 05:36:00+03	77200.00
B1A971	2017-08-03 23:07:00+03	16800.00
B1A99A	2017-08-06 01:49:00+03	51600.00
B1AA2E	2017-08-09 23:52:00+03	73500.00
B1AA44	2017-08-04 08:55:00+03	27400.00
B1AA4C	2017-08-06 13:28:00+03	27200.00
B1AAC4	2017-07-07 23:20:00+03	57700.00
B1AB43	2017-07-20 19:54:00+03	13000.00
B1AB6E	2017-07-13 17:32:00+03	123000.00
B1AC07	2017-08-13 17:09:00+03	187200.00
B1AC0D	2017-08-01 23:19:00+03	13300.00
B1AC15	2017-07-03 05:46:00+03	67200.00
B1AC53	2017-08-15 00:55:00+03	7400.00
B1AC5D	2017-07-16 07:58:00+03	12200.00
B1AC8F	2017-08-07 18:13:00+03	29600.00
B1ACE7	2017-07-25 09:34:00+03	67000.00
B1AD42	2017-08-03 19:33:00+03	258400.00
B1ADD9	2017-08-15 09:44:00+03	44400.00
B1AE55	2017-07-05 09:27:00+03	137100.00
B1AE5A	2017-07-06 18:20:00+03	13600.00
B1AEC2	2017-08-02 04:03:00+03	32900.00
B1AF0D	2017-07-09 05:16:00+03	170200.00
B1AFD3	2017-07-02 21:16:00+03	8200.00
B1AFDF	2017-08-07 07:30:00+03	66900.00
B1AFE4	2017-08-04 09:47:00+03	15400.00
B1B005	2017-07-03 04:37:00+03	122800.00
B1B015	2017-08-13 03:36:00+03	186900.00
B1B024	2017-07-21 19:33:00+03	68800.00
B1B030	2017-07-07 22:44:00+03	34100.00
B1B047	2017-07-14 12:42:00+03	12600.00
B1B04E	2017-08-14 21:15:00+03	97500.00
B1B065	2017-07-11 16:14:00+03	56300.00
B1B098	2017-07-21 21:27:00+03	224700.00
B1B09E	2017-07-31 19:40:00+03	35800.00
B1B0E8	2017-08-12 17:33:00+03	234700.00
B1B102	2017-07-23 00:30:00+03	30200.00
B1B12B	2017-07-04 23:24:00+03	160000.00
B1B166	2017-07-18 13:34:00+03	12600.00
B1B191	2017-08-02 00:24:00+03	197200.00
B1B1D3	2017-08-11 21:09:00+03	45200.00
B1B1D4	2017-08-06 08:09:00+03	96300.00
B1B247	2017-08-08 01:09:00+03	70100.00
B1B24F	2017-07-10 03:22:00+03	96100.00
B1B273	2017-07-16 18:18:00+03	47100.00
B1B2BF	2017-07-15 15:34:00+03	16400.00
B1B313	2017-07-19 15:52:00+03	57400.00
B1B3A3	2017-07-30 18:25:00+03	39800.00
B1B3EB	2017-07-16 14:00:00+03	23400.00
B1B42B	2017-07-01 21:52:00+03	67600.00
B1B443	2017-07-19 11:39:00+03	6700.00
B1B464	2017-07-16 11:49:00+03	84800.00
B1B484	2017-08-13 12:56:00+03	169900.00
B1B495	2017-08-11 17:31:00+03	49200.00
B1B49C	2017-07-05 08:51:00+03	40300.00
B1B4D3	2017-07-09 22:35:00+03	67100.00
B1B4FF	2017-07-16 05:41:00+03	108700.00
B1B510	2017-07-26 00:59:00+03	24400.00
B1B546	2017-08-09 19:19:00+03	105000.00
B1B564	2017-07-12 04:57:00+03	28800.00
B1B5A9	2017-07-15 20:34:00+03	14400.00
B1B5AB	2017-07-23 07:34:00+03	60700.00
B1B5C3	2017-07-11 11:00:00+03	27400.00
B1B5D8	2017-08-09 15:53:00+03	96800.00
B1B5FA	2017-08-09 06:29:00+03	24600.00
B1B63E	2017-08-13 10:46:00+03	12600.00
B1B64F	2017-08-14 18:43:00+03	52000.00
B1B6F7	2017-07-17 04:44:00+03	39800.00
B1B727	2017-07-04 01:39:00+03	83600.00
B1B76C	2017-07-25 18:06:00+03	137600.00
B1B874	2017-07-02 12:08:00+03	6000.00
B1B8A6	2017-08-09 23:25:00+03	53000.00
B1B96E	2017-08-04 18:39:00+03	58900.00
B1B980	2017-08-13 06:33:00+03	48500.00
B1B998	2017-07-13 04:31:00+03	37200.00
B1B9BC	2017-08-08 21:39:00+03	243600.00
B1BA2A	2017-08-13 03:04:00+03	65900.00
B1BA33	2017-07-06 05:37:00+03	43200.00
B1BA68	2017-07-21 10:58:00+03	60600.00
B1BA6A	2017-07-25 00:14:00+03	6700.00
B1BA81	2017-08-12 02:53:00+03	100600.00
B1BA89	2017-08-02 07:51:00+03	12600.00
B1BB5B	2017-07-14 05:01:00+03	6800.00
B1BB60	2017-08-11 13:19:00+03	27400.00
B1BBAC	2017-08-01 04:08:00+03	206800.00
B1BCCA	2017-08-03 04:34:00+03	19600.00
B1BD25	2017-07-09 15:24:00+03	62600.00
B1BD52	2017-08-03 23:18:00+03	85000.00
B1BD7C	2017-07-26 21:10:00+03	56900.00
B1BDCA	2017-08-09 10:11:00+03	32800.00
B1BDCF	2017-07-08 12:22:00+03	229900.00
B1BE04	2017-08-06 23:41:00+03	84000.00
B1BE22	2017-07-12 07:17:00+03	65500.00
B1BE27	2017-07-26 04:00:00+03	47400.00
B1BE38	2017-07-05 04:47:00+03	6700.00
B1BE4A	2017-08-08 17:30:00+03	104400.00
B1BE79	2017-08-01 16:07:00+03	153900.00
B1BEBA	2017-08-10 20:08:00+03	25200.00
B1BF0A	2017-07-23 18:11:00+03	22000.00
B1BF0B	2017-07-20 06:33:00+03	66900.00
B1BF47	2017-07-09 21:32:00+03	284300.00
B1BF8C	2017-08-03 01:10:00+03	7400.00
B1BFC2	2017-08-07 06:02:00+03	50600.00
B1BFC3	2017-07-27 08:45:00+03	17800.00
B1BFD4	2017-08-07 13:12:00+03	379600.00
B1C019	2017-08-02 16:41:00+03	57500.00
B1C022	2017-07-10 18:12:00+03	61800.00
B1C111	2017-07-21 09:39:00+03	260300.00
B1C185	2017-07-13 09:18:00+03	392800.00
B1C1C5	2017-07-09 14:56:00+03	26200.00
B1C202	2017-08-07 11:41:00+03	86400.00
B1C22F	2017-07-29 18:35:00+03	21400.00
B1C232	2017-06-28 00:55:00+03	78300.00
B1C23E	2017-08-05 11:10:00+03	28000.00
B1C29A	2017-07-29 02:56:00+03	16400.00
B1C2A6	2017-07-27 09:56:00+03	48500.00
B1C2C1	2017-07-17 06:13:00+03	58200.00
B1C2D0	2017-07-29 16:05:00+03	58900.00
B1C2D1	2017-07-21 19:50:00+03	25400.00
B1C321	2017-07-18 00:30:00+03	67200.00
B1C329	2017-07-14 08:14:00+03	56000.00
B1C36E	2017-06-28 05:28:00+03	23600.00
B1C3A0	2017-08-13 09:04:00+03	133100.00
B1C3B5	2017-07-09 03:57:00+03	22000.00
B1C433	2017-07-02 03:30:00+03	21800.00
B1C480	2017-07-19 20:02:00+03	36400.00
B1C4AC	2017-07-13 18:39:00+03	56600.00
B1C531	2017-08-11 16:30:00+03	123600.00
B1C53C	2017-08-15 15:00:00+03	62000.00
B1C652	2017-07-04 22:31:00+03	26000.00
B1C674	2017-07-01 07:33:00+03	88500.00
B1C688	2017-07-10 01:28:00+03	198400.00
B1C7CB	2017-08-07 21:15:00+03	99500.00
B1C85F	2017-08-05 02:49:00+03	134400.00
B1C8A2	2017-08-05 19:45:00+03	43500.00
B1C919	2017-07-12 14:19:00+03	33600.00
B1C935	2017-07-16 08:02:00+03	112400.00
B1C93A	2017-07-09 13:10:00+03	67500.00
B1C94E	2017-07-08 11:38:00+03	75600.00
B1CA05	2017-08-13 13:25:00+03	89600.00
B1CA24	2017-07-25 00:52:00+03	19600.00
B1CA25	2017-08-09 10:21:00+03	89600.00
B1CA57	2017-08-05 14:19:00+03	12000.00
B1CAB3	2017-07-17 16:43:00+03	99200.00
B1CB06	2017-08-14 12:55:00+03	12600.00
B1CB36	2017-07-04 10:04:00+03	37000.00
B1CB3A	2017-08-14 23:50:00+03	72600.00
B1CB47	2017-07-23 21:09:00+03	56600.00
B1CB75	2017-07-25 20:01:00+03	24400.00
B1CB9C	2017-07-01 15:42:00+03	85000.00
B1CC0F	2017-08-03 05:06:00+03	252200.00
B1CC36	2017-08-10 15:44:00+03	24000.00
B1CC96	2017-07-22 00:39:00+03	30200.00
B1CCC5	2017-07-16 07:16:00+03	30100.00
B1CCCB	2017-07-11 00:11:00+03	36200.00
B1CD44	2017-08-03 13:53:00+03	59200.00
B1CD52	2017-08-13 13:33:00+03	17800.00
B1CD7C	2017-07-10 08:54:00+03	39200.00
B1CDB6	2017-07-11 20:52:00+03	31600.00
B1CDE6	2017-07-26 12:41:00+03	12600.00
B1CDED	2017-08-03 11:20:00+03	61800.00
B1CE45	2017-08-06 13:34:00+03	62100.00
B1CE8E	2017-07-21 10:35:00+03	246000.00
B1CEA6	2017-07-30 19:25:00+03	137400.00
B1CEEB	2017-08-12 05:38:00+03	113700.00
B1CEF2	2017-08-03 19:03:00+03	105200.00
B1CF4C	2017-07-28 01:31:00+03	125400.00
B1CF96	2017-07-23 21:31:00+03	23600.00
B1D046	2017-07-15 07:54:00+03	81600.00
B1D086	2017-08-05 06:22:00+03	70700.00
B1D149	2017-07-11 06:15:00+03	33300.00
B1D155	2017-07-15 14:59:00+03	40800.00
B1D166	2017-07-14 14:02:00+03	67600.00
B1D22C	2017-07-21 23:13:00+03	198400.00
B1D24A	2017-07-20 23:43:00+03	18000.00
B1D251	2017-07-22 12:21:00+03	13600.00
B1D2A4	2017-07-08 10:09:00+03	23600.00
B1D30F	2017-08-01 00:05:00+03	46300.00
B1D31D	2017-08-09 12:04:00+03	12200.00
B1D347	2017-08-08 03:03:00+03	73300.00
B1D36D	2017-08-07 15:52:00+03	11700.00
B1D38E	2017-08-14 12:29:00+03	6300.00
B1D3A4	2017-07-26 08:41:00+03	69000.00
B1D3AC	2017-07-24 20:30:00+03	29200.00
B1D3B7	2017-08-03 03:36:00+03	16400.00
B1D3D6	2017-07-23 23:31:00+03	65000.00
B1D3D9	2017-07-21 04:44:00+03	111600.00
B1D3DB	2017-08-05 04:06:00+03	54200.00
B1D3FA	2017-08-02 08:36:00+03	31300.00
B1D42C	2017-07-31 02:22:00+03	177200.00
B1D445	2017-07-26 04:22:00+03	27200.00
B1D473	2017-08-12 20:16:00+03	113200.00
B1D4CA	2017-06-28 11:11:00+03	246000.00
B1D5C6	2017-07-15 16:11:00+03	46000.00
B1D66B	2017-07-31 06:54:00+03	178800.00
B1D684	2017-07-08 06:19:00+03	120700.00
B1D6B8	2017-07-21 09:00:00+03	123000.00
B1D72C	2017-07-28 20:08:00+03	26700.00
B1D758	2017-08-15 05:46:00+03	25000.00
B1D7D5	2017-07-11 04:21:00+03	46400.00
B1D7DD	2017-07-13 16:43:00+03	62900.00
B1D816	2017-08-03 19:48:00+03	427600.00
B1D844	2017-08-14 19:40:00+03	26000.00
B1D861	2017-08-10 18:17:00+03	34000.00
B1D863	2017-07-23 01:50:00+03	112000.00
B1D874	2017-08-09 02:37:00+03	19600.00
B1D890	2017-07-05 06:16:00+03	23400.00
B1D8B4	2017-07-26 04:44:00+03	133900.00
B1D8DC	2017-07-25 17:18:00+03	67600.00
B1D8E9	2017-08-06 16:19:00+03	54500.00
B1D9B2	2017-07-17 22:35:00+03	23200.00
B1D9CE	2017-08-09 18:03:00+03	135600.00
B1D9FE	2017-08-11 04:56:00+03	166100.00
B1DA0C	2017-06-29 04:07:00+03	21800.00
B1DA13	2017-07-31 14:15:00+03	94900.00
B1DA1A	2017-07-31 04:05:00+03	202100.00
B1DA60	2017-07-02 11:15:00+03	11000.00
B1DA7D	2017-07-20 15:10:00+03	12100.00
B1DA96	2017-08-13 20:42:00+03	48800.00
B1DAAE	2017-08-13 20:12:00+03	12100.00
B1DAD8	2017-07-08 07:18:00+03	75600.00
B1DAE4	2017-07-22 01:10:00+03	25600.00
B1DB40	2017-06-30 19:19:00+03	69500.00
B1DB65	2017-07-23 17:04:00+03	40300.00
B1DC68	2017-07-24 03:39:00+03	28000.00
B1DCD3	2017-08-14 02:58:00+03	46400.00
B1DCFD	2017-08-14 11:33:00+03	57600.00
B1DD07	2017-08-06 09:55:00+03	48800.00
B1DD1D	2017-07-09 14:40:00+03	9800.00
B1DD37	2017-08-04 05:29:00+03	30200.00
B1DD81	2017-07-11 23:32:00+03	139200.00
B1DD9E	2017-08-06 07:22:00+03	12600.00
B1DDC9	2017-06-27 18:07:00+03	51600.00
B1DDDA	2017-08-07 19:06:00+03	177500.00
B1DDFA	2017-07-19 17:59:00+03	46200.00
B1DDFD	2017-07-25 05:24:00+03	29200.00
B1DE17	2017-07-27 10:29:00+03	72300.00
B1DE1E	2017-07-28 20:31:00+03	34700.00
B1DE35	2017-08-01 06:14:00+03	106400.00
B1DEBE	2017-07-04 09:54:00+03	15800.00
B1DF06	2017-07-28 07:14:00+03	115700.00
B1DF14	2017-07-02 10:57:00+03	36200.00
B1DF30	2017-08-12 08:46:00+03	396500.00
B1DF42	2017-07-21 11:27:00+03	16800.00
B1DF77	2017-08-07 23:56:00+03	40000.00
B1DFD6	2017-07-08 10:32:00+03	77500.00
B1DFD7	2017-07-21 15:39:00+03	20200.00
B1E004	2017-07-19 21:02:00+03	46400.00
B1E070	2017-07-18 20:29:00+03	26800.00
B1E0D0	2017-07-25 13:37:00+03	12000.00
B1E193	2017-07-10 10:16:00+03	15400.00
B1E1AC	2017-07-13 12:32:00+03	248300.00
B1E1D6	2017-07-13 17:03:00+03	92000.00
B1E1F1	2017-08-03 16:31:00+03	81600.00
B1E219	2017-07-06 12:17:00+03	28800.00
B1E2C3	2017-08-03 13:12:00+03	135600.00
B1E2D7	2017-07-25 12:37:00+03	46000.00
B1E2E7	2017-07-17 19:38:00+03	12600.00
B1E31D	2017-07-24 21:29:00+03	89400.00
B1E346	2017-08-03 01:59:00+03	46300.00
B1E3A1	2017-07-31 08:49:00+03	95700.00
B1E3B4	2017-08-07 19:05:00+03	36200.00
B1E488	2017-07-23 22:36:00+03	45200.00
B1E4A2	2017-07-19 21:57:00+03	134400.00
B1E4B6	2017-07-13 05:54:00+03	32800.00
B1E4BC	2017-07-07 18:39:00+03	21800.00
B1E4EC	2017-07-09 06:49:00+03	12400.00
B1E516	2017-06-27 04:00:00+03	58400.00
B1E584	2017-08-07 21:28:00+03	12600.00
B1E5E1	2017-07-12 10:21:00+03	48700.00
B1E5F4	2017-07-31 00:54:00+03	128800.00
B1E667	2017-08-13 01:36:00+03	88300.00
B1E681	2017-07-31 08:47:00+03	89700.00
B1E6B0	2017-08-13 19:33:00+03	7400.00
B1E6EA	2017-07-06 01:45:00+03	26400.00
B1E78B	2017-08-14 22:19:00+03	97700.00
B1E83C	2017-08-05 22:40:00+03	91100.00
B1E857	2017-07-28 11:07:00+03	37200.00
B1E870	2017-07-15 06:57:00+03	121600.00
B1E88A	2017-08-04 10:42:00+03	56000.00
B1E904	2017-07-24 05:35:00+03	189000.00
B1E9CC	2017-07-19 21:54:00+03	76400.00
B1E9F0	2017-07-02 11:23:00+03	277000.00
B1E9FE	2017-07-26 03:04:00+03	28000.00
B1EA16	2017-07-20 00:39:00+03	6700.00
B1EAB4	2017-07-09 14:17:00+03	69900.00
B1EAD5	2017-08-15 16:33:00+03	76600.00
B1EB5A	2017-08-06 10:01:00+03	29600.00
B1EBAD	2017-07-05 04:54:00+03	99300.00
B1EBCE	2017-08-08 04:12:00+03	65900.00
B1EBFC	2017-07-16 10:07:00+03	79000.00
B1EC03	2017-07-24 18:35:00+03	174000.00
B1EC3C	2017-07-05 12:50:00+03	34200.00
B1ECA9	2017-08-04 10:56:00+03	99800.00
B1ECCD	2017-07-25 01:07:00+03	55000.00
B1ECE0	2017-07-25 11:51:00+03	132800.00
B1ED15	2017-08-13 04:44:00+03	23200.00
B1ED38	2017-07-16 18:33:00+03	23600.00
B1ED59	2017-08-06 23:26:00+03	69100.00
B1EDA1	2017-07-23 21:30:00+03	14800.00
B1EDB5	2017-08-09 06:50:00+03	23600.00
B1EDBC	2017-08-15 03:00:00+03	46700.00
B1EDDA	2017-08-09 12:56:00+03	19600.00
B1EE97	2017-07-25 00:16:00+03	69400.00
B1EEEC	2017-07-10 10:33:00+03	16400.00
B1EF30	2017-07-08 13:32:00+03	116500.00
B1EF64	2017-07-02 13:42:00+03	46000.00
B1EF8F	2017-08-03 07:40:00+03	13600.00
B1EFFA	2017-07-21 16:04:00+03	202000.00
B1F038	2017-07-25 06:41:00+03	70800.00
B1F073	2017-08-13 10:02:00+03	97900.00
B1F08A	2017-07-28 16:01:00+03	32800.00
B1F0AC	2017-07-11 00:15:00+03	6000.00
B1F0DD	2017-07-26 23:08:00+03	16400.00
B1F2E0	2017-08-01 06:34:00+03	68800.00
B1F34F	2017-07-04 10:26:00+03	26200.00
B1F3B7	2017-07-30 09:15:00+03	181100.00
B1F3C4	2017-07-31 09:33:00+03	70700.00
B1F415	2017-07-26 15:36:00+03	260900.00
B1F455	2017-07-16 23:40:00+03	60900.00
B1F47A	2017-08-01 05:01:00+03	29600.00
B1F515	2017-07-24 10:31:00+03	36200.00
B1F530	2017-07-20 05:44:00+03	17800.00
B1F550	2017-08-09 16:46:00+03	177800.00
B1F5E1	2017-07-05 02:51:00+03	53200.00
B1F5FC	2017-07-08 17:27:00+03	34000.00
B1F675	2017-07-17 21:04:00+03	26200.00
B1F69A	2017-07-16 01:57:00+03	279300.00
B1F7E5	2017-07-26 08:40:00+03	22000.00
B1F7EF	2017-08-11 11:47:00+03	78000.00
B1F7F5	2017-07-21 02:36:00+03	17000.00
B1F7FE	2017-07-07 10:07:00+03	98300.00
B1F85D	2017-07-17 21:16:00+03	42600.00
B1F8A2	2017-07-11 07:24:00+03	49100.00
B1F906	2017-07-29 18:56:00+03	168000.00
B1F910	2017-08-04 10:00:00+03	111600.00
B1F912	2017-07-26 09:49:00+03	311900.00
B1F966	2017-06-30 23:57:00+03	102200.00
B1F984	2017-07-06 12:26:00+03	28800.00
B1F9A2	2017-07-17 17:16:00+03	28000.00
B1F9CE	2017-08-11 02:04:00+03	16000.00
B1F9DB	2017-07-07 06:32:00+03	272400.00
B1FA10	2017-08-01 13:10:00+03	80100.00
B1FA4C	2017-07-25 15:49:00+03	74900.00
B1FA5E	2017-07-11 21:39:00+03	66600.00
B1FA75	2017-07-11 05:43:00+03	28000.00
B1FA7A	2017-07-27 06:24:00+03	25400.00
B1FA8A	2017-08-14 11:53:00+03	7400.00
B1FA99	2017-07-12 12:44:00+03	6700.00
B1FAA8	2017-08-06 15:33:00+03	26000.00
B1FAF8	2017-08-14 20:37:00+03	23600.00
B1FB8D	2017-07-09 02:56:00+03	150700.00
B1FC15	2017-08-02 21:40:00+03	48500.00
B1FC55	2017-07-31 11:09:00+03	21200.00
B1FCB7	2017-08-09 15:39:00+03	40800.00
B1FCD9	2017-08-09 01:19:00+03	10800.00
B1FCED	2017-07-21 21:55:00+03	56000.00
B1FD21	2017-07-10 23:57:00+03	90400.00
B1FDB7	2017-07-13 04:56:00+03	59400.00
B1FDD4	2017-08-04 19:51:00+03	36200.00
B1FE05	2017-07-21 17:38:00+03	55600.00
B1FEEE	2017-08-02 16:32:00+03	61800.00
B1FF24	2017-08-08 00:43:00+03	103600.00
B1FF53	2017-08-01 21:12:00+03	26000.00
B20010	2017-07-31 20:26:00+03	78200.00
B2002F	2017-07-30 16:17:00+03	67800.00
B20038	2017-07-10 18:21:00+03	58600.00
B20060	2017-08-13 07:53:00+03	54800.00
B20096	2017-08-15 09:58:00+03	37900.00
B200DC	2017-07-13 03:09:00+03	149200.00
B200E2	2017-07-23 11:49:00+03	29200.00
B201AE	2017-07-28 00:13:00+03	298600.00
B201B9	2017-07-28 20:01:00+03	23200.00
B201E2	2017-07-04 15:47:00+03	55800.00
B201E3	2017-07-09 23:42:00+03	32600.00
B202AE	2017-08-11 16:28:00+03	32800.00
B202C4	2017-08-14 04:26:00+03	6000.00
B202FA	2017-07-17 11:17:00+03	75300.00
B20324	2017-08-12 22:11:00+03	16800.00
B2034C	2017-08-11 20:35:00+03	92800.00
B20353	2017-07-07 11:31:00+03	77400.00
B20384	2017-08-08 01:13:00+03	62800.00
B203AA	2017-08-03 05:46:00+03	58000.00
B203CF	2017-08-04 17:58:00+03	101200.00
B203F0	2017-07-16 06:12:00+03	122800.00
B203F5	2017-07-13 17:38:00+03	31400.00
B2042B	2017-07-16 20:38:00+03	37900.00
B20456	2017-07-26 05:21:00+03	70800.00
B204C2	2017-07-20 20:02:00+03	24400.00
B20513	2017-07-24 07:53:00+03	46300.00
B2055E	2017-07-15 06:30:00+03	56000.00
B205A0	2017-07-14 02:30:00+03	62000.00
B205CE	2017-07-22 15:46:00+03	135400.00
B205FD	2017-06-30 14:28:00+03	112000.00
B2060E	2017-07-09 13:20:00+03	29600.00
B2061B	2017-07-14 09:31:00+03	81300.00
B20669	2017-07-29 03:25:00+03	36200.00
B206C0	2017-08-11 16:30:00+03	43200.00
B20757	2017-08-10 20:15:00+03	80700.00
B2077B	2017-07-10 00:31:00+03	56000.00
B207AD	2017-08-01 03:51:00+03	20800.00
B2081A	2017-08-10 01:21:00+03	6200.00
B208B9	2017-08-06 14:28:00+03	139000.00
B208C2	2017-07-01 19:56:00+03	29500.00
B20916	2017-08-07 09:57:00+03	91700.00
B2098E	2017-07-08 03:58:00+03	81600.00
B209C6	2017-08-10 05:45:00+03	260300.00
B209F0	2017-07-12 20:04:00+03	29500.00
B20A3B	2017-07-15 07:23:00+03	27000.00
B20A9B	2017-07-01 03:27:00+03	202600.00
B20ACE	2017-08-10 19:41:00+03	73200.00
B20ADE	2017-07-16 10:33:00+03	273600.00
B20AE7	2017-07-15 18:40:00+03	21600.00
B20B53	2017-07-01 03:03:00+03	118900.00
B20B5D	2017-08-05 10:17:00+03	56200.00
B20B7E	2017-08-02 21:01:00+03	37900.00
B20B84	2017-07-11 16:12:00+03	34000.00
B20BC2	2017-08-01 02:20:00+03	24800.00
B20BE6	2017-08-15 14:58:00+03	100600.00
B20C30	2017-08-06 07:31:00+03	132800.00
B20C32	2017-08-15 14:28:00+03	38400.00
B20C5D	2017-07-18 04:49:00+03	110300.00
B20C67	2017-08-01 23:36:00+03	139000.00
B20C8B	2017-07-07 16:28:00+03	123000.00
B20D0B	2017-08-02 20:23:00+03	70600.00
B20D43	2017-07-22 05:06:00+03	13000.00
B20D4D	2017-08-07 12:43:00+03	135600.00
B20D8B	2017-07-08 21:53:00+03	6300.00
B20DB6	2017-08-10 22:33:00+03	42800.00
B20E29	2017-07-04 01:16:00+03	40600.00
B20E41	2017-07-26 21:26:00+03	46200.00
B20EB7	2017-07-22 02:49:00+03	14800.00
B20EF5	2017-07-26 14:51:00+03	57400.00
B20F25	2017-07-03 02:35:00+03	56600.00
B20F2D	2017-07-16 04:29:00+03	119500.00
B20F83	2017-08-06 04:00:00+03	64400.00
B20FB0	2017-07-20 08:30:00+03	9200.00
B20FB4	2017-07-12 11:23:00+03	55800.00
B21027	2017-07-24 15:52:00+03	67000.00
B21072	2017-07-18 04:58:00+03	7200.00
B2114E	2017-07-24 04:53:00+03	85800.00
B21183	2017-07-14 04:25:00+03	112000.00
B211DE	2017-07-14 13:42:00+03	56000.00
B2132A	2017-07-05 08:25:00+03	48300.00
B2136D	2017-08-14 19:24:00+03	28000.00
B213B2	2017-07-24 04:17:00+03	76600.00
B213B5	2017-07-26 18:45:00+03	92800.00
B21419	2017-07-16 19:46:00+03	88300.00
B2141E	2017-08-09 03:44:00+03	38800.00
B214E4	2017-08-15 11:41:00+03	39300.00
B2152E	2017-08-07 13:47:00+03	87800.00
B21563	2017-08-03 18:43:00+03	8000.00
B215C7	2017-07-17 23:50:00+03	47000.00
B21620	2017-08-07 01:36:00+03	108900.00
B216F8	2017-08-06 00:39:00+03	85000.00
B21790	2017-07-11 03:25:00+03	56000.00
B217B0	2017-07-12 23:20:00+03	160800.00
B217B2	2017-07-05 03:23:00+03	92500.00
B21819	2017-07-27 07:04:00+03	28800.00
B21849	2017-07-18 12:09:00+03	109600.00
B21929	2017-07-16 11:45:00+03	21000.00
B2193B	2017-08-13 13:02:00+03	146300.00
B21962	2017-07-16 17:21:00+03	136200.00
B21975	2017-07-27 06:02:00+03	113700.00
B21B13	2017-08-05 14:59:00+03	6800.00
B21B2F	2017-07-10 02:06:00+03	65100.00
B21B31	2017-08-02 19:43:00+03	55800.00
B21B4C	2017-08-07 13:38:00+03	190500.00
B21B7E	2017-07-07 05:05:00+03	409700.00
B21BF3	2017-08-11 19:10:00+03	738000.00
B21C01	2017-07-03 10:50:00+03	258400.00
B21CB9	2017-07-01 19:17:00+03	23200.00
B21DA7	2017-07-08 20:29:00+03	58400.00
B21DE2	2017-07-23 16:55:00+03	13400.00
B21E4E	2017-08-15 02:28:00+03	54800.00
B21E56	2017-08-12 21:14:00+03	85200.00
B21E73	2017-08-01 00:36:00+03	124200.00
B21E74	2017-08-06 11:48:00+03	78100.00
B21EFC	2017-08-10 17:17:00+03	42400.00
B21F08	2017-07-05 02:55:00+03	138000.00
B21F0F	2017-08-07 01:04:00+03	38800.00
B21F47	2017-07-16 07:29:00+03	78200.00
B21F64	2017-08-14 17:59:00+03	49900.00
B21FC1	2017-07-17 01:58:00+03	26000.00
B22044	2017-07-27 03:53:00+03	70600.00
B22115	2017-07-07 06:10:00+03	35800.00
B22143	2017-07-22 14:13:00+03	58800.00
B22144	2017-08-02 20:07:00+03	289800.00
B22159	2017-07-20 22:09:00+03	3700.00
B22189	2017-07-28 19:21:00+03	29600.00
B2219C	2017-08-06 05:10:00+03	92000.00
B221B8	2017-07-11 10:20:00+03	48500.00
B221DE	2017-08-12 05:32:00+03	39200.00
B221E5	2017-07-24 10:46:00+03	6000.00
B221F2	2017-07-30 13:40:00+03	32200.00
B22224	2017-08-12 09:52:00+03	37900.00
B222A7	2017-08-14 16:46:00+03	273400.00
B2230C	2017-07-13 19:42:00+03	447500.00
B22315	2017-07-13 18:03:00+03	67600.00
B223D6	2017-07-13 01:19:00+03	132800.00
B223DA	2017-08-10 11:22:00+03	47000.00
B223F5	2017-07-17 03:14:00+03	14800.00
B22484	2017-07-15 11:37:00+03	133200.00
B22495	2017-06-27 23:37:00+03	38200.00
B2250B	2017-06-29 07:08:00+03	26800.00
B22546	2017-07-29 19:11:00+03	134400.00
B22592	2017-07-12 18:54:00+03	70800.00
B225A5	2017-08-09 04:24:00+03	38200.00
B22614	2017-08-06 01:48:00+03	68800.00
B2272C	2017-07-17 19:55:00+03	95000.00
B2275A	2017-08-04 09:08:00+03	136200.00
B22777	2017-07-03 01:05:00+03	27400.00
B22788	2017-07-05 15:30:00+03	160100.00
B227CB	2017-06-29 07:51:00+03	40000.00
B22826	2017-08-07 05:14:00+03	39200.00
B2285A	2017-07-15 20:29:00+03	156500.00
B2285B	2017-08-14 05:31:00+03	449600.00
B22898	2017-07-13 05:18:00+03	78300.00
B228AD	2017-07-08 06:41:00+03	55000.00
B228C2	2017-07-29 00:10:00+03	11300.00
B22926	2017-07-16 03:58:00+03	147200.00
B229A4	2017-08-03 08:38:00+03	92600.00
B22A2C	2017-07-29 08:22:00+03	6000.00
B22A33	2017-08-14 16:23:00+03	59000.00
B22A3B	2017-08-10 16:27:00+03	410800.00
B22A4A	2017-07-17 02:50:00+03	109600.00
B22AFE	2017-07-11 22:21:00+03	34000.00
B22B45	2017-07-02 09:12:00+03	34000.00
B22B76	2017-08-14 19:01:00+03	88300.00
B22B7B	2017-08-05 17:20:00+03	27200.00
B22C06	2017-07-14 10:27:00+03	6700.00
B22C2C	2017-07-20 05:20:00+03	38900.00
B22C6A	2017-07-06 19:30:00+03	100200.00
B22C86	2017-07-11 02:42:00+03	54100.00
B22CB6	2017-07-19 05:36:00+03	410200.00
B22CDC	2017-08-13 23:12:00+03	23400.00
B22D0C	2017-07-29 01:55:00+03	13600.00
B22D6F	2017-07-28 03:45:00+03	27200.00
B22E71	2017-07-07 15:59:00+03	13000.00
B22F53	2017-08-09 17:33:00+03	135400.00
B22FB3	2017-07-31 05:32:00+03	51900.00
B22FBC	2017-07-15 03:41:00+03	102100.00
B22FEC	2017-08-02 15:27:00+03	43300.00
B22FED	2017-08-05 03:52:00+03	114800.00
B2301C	2017-08-01 00:59:00+03	64500.00
B23076	2017-07-07 22:56:00+03	132800.00
B230B4	2017-08-05 10:03:00+03	57500.00
B231EE	2017-07-19 04:38:00+03	23200.00
B231FB	2017-07-28 10:47:00+03	52700.00
B23283	2017-08-14 20:25:00+03	53600.00
B232B6	2017-07-15 05:46:00+03	79600.00
B232CC	2017-07-24 08:54:00+03	102100.00
B232F6	2017-07-04 22:57:00+03	43600.00
B23380	2017-07-07 07:42:00+03	69000.00
B233A4	2017-08-08 23:15:00+03	65200.00
B233A8	2017-07-15 23:14:00+03	173200.00
B233C1	2017-07-22 01:17:00+03	6700.00
B233E3	2017-08-07 06:43:00+03	83500.00
B23405	2017-07-09 11:06:00+03	165500.00
B23474	2017-07-05 12:45:00+03	131100.00
B23480	2017-07-11 13:13:00+03	58000.00
B23494	2017-08-09 13:16:00+03	84100.00
B234C0	2017-07-25 22:23:00+03	68200.00
B2351C	2017-07-04 20:49:00+03	48800.00
B23521	2017-07-31 22:12:00+03	145600.00
B23542	2017-08-13 19:03:00+03	132800.00
B2354D	2017-07-07 11:27:00+03	56000.00
B23595	2017-07-24 00:08:00+03	25200.00
B235B7	2017-08-12 15:55:00+03	35400.00
B23618	2017-07-03 05:24:00+03	47400.00
B23651	2017-07-01 05:14:00+03	55800.00
B23685	2017-08-07 11:41:00+03	27200.00
B2368F	2017-07-05 01:15:00+03	24800.00
B236B9	2017-08-09 03:38:00+03	88600.00
B236DF	2017-07-27 14:54:00+03	46200.00
B23729	2017-07-23 07:31:00+03	111600.00
B2379E	2017-07-22 13:25:00+03	133200.00
B2382D	2017-07-26 23:54:00+03	99000.00
B2383B	2017-07-18 07:03:00+03	70700.00
B23852	2017-08-05 00:01:00+03	11700.00
B238BA	2017-08-05 12:06:00+03	92800.00
B238E5	2017-07-12 08:38:00+03	40800.00
B23A14	2017-08-11 16:11:00+03	177600.00
B23A8F	2017-07-11 21:09:00+03	117700.00
B23AB2	2017-07-01 08:55:00+03	6000.00
B23AED	2017-08-07 05:30:00+03	117200.00
B23AFB	2017-08-09 01:52:00+03	25600.00
B23B2B	2017-07-12 06:58:00+03	70600.00
B23B41	2017-07-08 18:57:00+03	26000.00
B23B54	2017-08-06 15:20:00+03	123600.00
B23B61	2017-07-29 06:01:00+03	97900.00
B23B7B	2017-07-29 13:59:00+03	93900.00
B23BA4	2017-08-09 08:24:00+03	52400.00
B23BAD	2017-08-13 09:03:00+03	6700.00
B23BB8	2017-08-15 04:52:00+03	18100.00
B23BC1	2017-07-11 05:05:00+03	28400.00
B23BCB	2017-07-26 13:18:00+03	103500.00
B23C17	2017-07-03 03:14:00+03	75800.00
B23C33	2017-08-15 05:57:00+03	88900.00
B23CA1	2017-08-09 19:21:00+03	48800.00
B23CCE	2017-08-14 23:39:00+03	56900.00
B23DBB	2017-08-02 21:35:00+03	62700.00
B23DED	2017-06-29 23:58:00+03	378700.00
B23E13	2017-08-14 20:35:00+03	94400.00
B23E50	2017-08-02 17:54:00+03	84500.00
B23E5E	2017-08-02 16:29:00+03	198400.00
B23E68	2017-07-22 05:37:00+03	136800.00
B23EDD	2017-08-05 22:44:00+03	27800.00
B23EEB	2017-08-05 18:10:00+03	40300.00
B23F46	2017-08-01 16:52:00+03	135600.00
B23F67	2017-07-23 22:02:00+03	90000.00
B23F7C	2017-07-06 09:00:00+03	59200.00
B23F9B	2017-08-09 16:50:00+03	47200.00
B23FBB	2017-07-20 04:06:00+03	25000.00
B24010	2017-07-01 22:08:00+03	11600.00
B240E8	2017-07-20 19:41:00+03	73500.00
B240EE	2017-07-07 13:37:00+03	95200.00
B24102	2017-07-31 23:16:00+03	393000.00
B24194	2017-07-09 18:53:00+03	101200.00
B241A2	2017-07-21 06:01:00+03	68000.00
B24223	2017-07-17 09:05:00+03	135400.00
B2427F	2017-07-28 09:17:00+03	37900.00
B24363	2017-08-01 00:08:00+03	173900.00
B243FB	2017-08-11 11:45:00+03	34000.00
B24475	2017-07-29 22:13:00+03	20400.00
B244F3	2017-07-28 12:22:00+03	81600.00
B24501	2017-07-11 10:59:00+03	29300.00
B24554	2017-07-22 03:08:00+03	56000.00
B24567	2017-08-06 05:45:00+03	146600.00
B2457D	2017-07-14 11:26:00+03	92400.00
B24582	2017-07-19 09:27:00+03	81500.00
B24590	2017-07-03 07:10:00+03	260300.00
B245B4	2017-08-05 11:43:00+03	30900.00
B245F7	2017-07-07 13:59:00+03	25400.00
B245FE	2017-08-14 08:37:00+03	257600.00
B24654	2017-07-14 08:20:00+03	86500.00
B24692	2017-07-25 01:47:00+03	56600.00
B246B0	2017-07-24 13:26:00+03	48100.00
B246DD	2017-08-15 15:05:00+03	131100.00
B246FE	2017-07-24 16:20:00+03	30200.00
B2470A	2017-08-12 06:02:00+03	189200.00
B2475C	2017-07-11 08:55:00+03	90800.00
B247AC	2017-07-05 02:29:00+03	93000.00
B247BC	2017-07-15 20:47:00+03	73600.00
B247D5	2017-07-27 15:30:00+03	40000.00
B247F9	2017-07-03 17:44:00+03	55600.00
B24838	2017-07-12 11:33:00+03	202800.00
B24855	2017-08-05 02:09:00+03	29400.00
B248E1	2017-08-07 11:45:00+03	96200.00
B248E2	2017-07-17 19:06:00+03	87200.00
B24908	2017-07-11 08:56:00+03	26000.00
B2493F	2017-07-12 15:23:00+03	196800.00
B24944	2017-06-28 23:21:00+03	41200.00
B2496B	2017-07-23 11:34:00+03	128800.00
B249EF	2017-07-10 18:57:00+03	68000.00
B24A06	2017-07-30 08:19:00+03	86400.00
B24A7C	2017-08-06 21:52:00+03	86400.00
B24A97	2017-07-15 13:30:00+03	120700.00
B24AF0	2017-08-05 11:02:00+03	49400.00
B24B23	2017-08-11 04:02:00+03	73400.00
B24B2A	2017-07-14 07:20:00+03	136200.00
B24B62	2017-06-29 18:32:00+03	23600.00
B24B86	2017-07-20 19:52:00+03	43200.00
B24D18	2017-07-20 04:20:00+03	13600.00
B24D71	2017-07-09 15:44:00+03	58200.00
B24DE5	2017-08-03 13:21:00+03	22000.00
B24E13	2017-08-08 21:45:00+03	35500.00
B24E2C	2017-07-10 02:35:00+03	103500.00
B24E4D	2017-07-18 19:54:00+03	30200.00
B24EA4	2017-08-08 06:49:00+03	92700.00
B24F32	2017-07-25 07:12:00+03	40600.00
B24F86	2017-07-22 19:14:00+03	95300.00
B24F94	2017-08-12 02:55:00+03	100600.00
B24F9D	2017-07-20 03:54:00+03	29600.00
B24FA1	2017-07-08 12:30:00+03	46700.00
B24FAD	2017-08-05 04:53:00+03	149500.00
B24FB9	2017-07-13 20:28:00+03	178800.00
B24FE9	2017-08-14 16:29:00+03	133100.00
B2503B	2017-08-08 09:26:00+03	11700.00
B2505D	2017-08-04 07:18:00+03	73200.00
B2514E	2017-07-20 12:55:00+03	169900.00
B251E2	2017-07-18 19:29:00+03	34000.00
B25228	2017-07-05 12:37:00+03	37700.00
B25267	2017-08-11 03:29:00+03	56600.00
B252A5	2017-07-13 07:09:00+03	133100.00
B252BC	2017-07-18 06:06:00+03	6000.00
B252F5	2017-07-02 14:31:00+03	53800.00
B2539B	2017-07-29 13:01:00+03	131400.00
B25404	2017-08-07 02:24:00+03	39300.00
B25455	2017-07-16 21:47:00+03	48800.00
B25471	2017-07-23 10:24:00+03	57800.00
B2547B	2017-07-01 01:21:00+03	54300.00
B25494	2017-07-29 00:34:00+03	56000.00
B254DC	2017-07-09 01:12:00+03	91500.00
B2556F	2017-08-06 18:29:00+03	109600.00
B2558A	2017-08-12 12:47:00+03	40000.00
B2558B	2017-08-13 08:15:00+03	37000.00
B25592	2017-08-06 10:09:00+03	52000.00
B255F3	2017-07-16 21:38:00+03	57800.00
B2563D	2017-07-13 11:52:00+03	35200.00
B256D2	2017-07-20 10:31:00+03	64200.00
B256D9	2017-08-11 01:37:00+03	15100.00
B256EF	2017-08-08 18:27:00+03	75600.00
B2575B	2017-08-13 22:05:00+03	29600.00
B2579B	2017-07-01 10:28:00+03	28800.00
B257BF	2017-07-24 08:20:00+03	92700.00
B258B7	2017-07-30 05:40:00+03	11300.00
B258EC	2017-08-08 23:34:00+03	55800.00
B25909	2017-08-12 16:28:00+03	202400.00
B2590F	2017-07-07 23:17:00+03	50600.00
B2592B	2017-07-04 12:34:00+03	99300.00
B25956	2017-07-03 08:51:00+03	61500.00
B25980	2017-07-12 01:58:00+03	32200.00
B25987	2017-07-05 23:02:00+03	36900.00
B25ACF	2017-08-04 05:11:00+03	26300.00
B25C0D	2017-07-24 15:13:00+03	190400.00
B25C6A	2017-07-17 02:29:00+03	77600.00
B25CB6	2017-07-03 19:00:00+03	35700.00
B25CC0	2017-07-18 21:36:00+03	46400.00
B25D02	2017-08-09 09:18:00+03	101200.00
B25D12	2017-08-15 09:16:00+03	26000.00
B25D4F	2017-07-10 04:40:00+03	51300.00
B25D58	2017-07-22 00:03:00+03	65500.00
B25DEB	2017-07-05 04:31:00+03	21400.00
B25DF9	2017-07-01 01:49:00+03	50600.00
B25E4C	2017-07-10 12:06:00+03	277000.00
B25E55	2017-08-11 20:43:00+03	117600.00
B25EC4	2017-07-29 16:36:00+03	84100.00
B25EEF	2017-08-03 05:15:00+03	36000.00
B25F0A	2017-08-12 21:08:00+03	254900.00
B25F25	2017-08-06 00:37:00+03	50600.00
B25F91	2017-08-13 03:23:00+03	101800.00
B25FB9	2017-07-09 12:39:00+03	68800.00
B26004	2017-07-28 20:01:00+03	28600.00
B26040	2017-07-06 09:50:00+03	75600.00
B26051	2017-07-03 14:09:00+03	46000.00
B260A9	2017-07-12 04:22:00+03	114800.00
B260BD	2017-07-07 23:52:00+03	111600.00
B260D4	2017-08-09 07:34:00+03	88400.00
B260ED	2017-07-26 19:31:00+03	38400.00
B26114	2017-07-25 10:15:00+03	254900.00
B2612C	2017-07-30 13:55:00+03	40200.00
B26156	2017-07-17 04:52:00+03	21400.00
B261A0	2017-07-12 01:19:00+03	52400.00
B261E0	2017-07-12 12:51:00+03	54400.00
B261E7	2017-07-03 04:11:00+03	111600.00
B2620A	2017-07-26 00:27:00+03	11100.00
B262A6	2017-08-02 02:42:00+03	6700.00
B262BA	2017-07-04 03:36:00+03	111600.00
B262F6	2017-07-08 22:49:00+03	87700.00
B26329	2017-08-15 12:29:00+03	109700.00
B26355	2017-08-10 04:11:00+03	36800.00
B26362	2017-07-29 10:34:00+03	127500.00
B263BA	2017-08-14 03:14:00+03	28800.00
B26488	2017-07-31 16:15:00+03	75300.00
B26588	2017-07-29 07:52:00+03	32800.00
B265B3	2017-08-13 16:36:00+03	21500.00
B26616	2017-06-29 00:08:00+03	170800.00
B2669B	2017-08-12 00:11:00+03	6800.00
B266B8	2017-07-13 22:41:00+03	19600.00
B266D6	2017-07-28 15:20:00+03	84100.00
B266DF	2017-07-26 20:52:00+03	19600.00
B26723	2017-07-17 03:13:00+03	273000.00
B26731	2017-08-02 20:46:00+03	47000.00
B26739	2017-07-27 21:08:00+03	6800.00
B2674D	2017-08-05 11:19:00+03	67600.00
B267A9	2017-08-01 08:38:00+03	106500.00
B267EA	2017-06-30 20:18:00+03	26200.00
B2693D	2017-07-05 12:54:00+03	99300.00
B269AD	2017-08-08 02:53:00+03	139200.00
B269BD	2017-07-18 19:01:00+03	6000.00
B269EC	2017-08-03 06:13:00+03	271400.00
B269F6	2017-07-09 14:58:00+03	202400.00
B269F9	2017-07-31 15:08:00+03	48800.00
B26A2C	2017-07-14 17:22:00+03	55500.00
B26A6A	2017-07-25 09:35:00+03	311400.00
B26AD8	2017-07-19 03:12:00+03	6700.00
B26BC5	2017-07-22 09:33:00+03	49100.00
B26BFC	2017-07-16 16:19:00+03	230600.00
B26C53	2017-07-01 23:18:00+03	49100.00
B26C5A	2017-08-06 06:15:00+03	3400.00
B26C9F	2017-07-24 18:42:00+03	38800.00
B26CB6	2017-07-05 18:36:00+03	56600.00
B26CCC	2017-07-02 04:32:00+03	129700.00
B26D07	2017-08-15 11:15:00+03	28000.00
B26D13	2017-07-07 16:36:00+03	94900.00
B26D9F	2017-06-30 14:26:00+03	56000.00
B26DCB	2017-07-14 04:28:00+03	66600.00
B26DF0	2017-08-05 06:38:00+03	56000.00
B26E47	2017-08-10 09:25:00+03	47100.00
B26F35	2017-07-21 06:10:00+03	20200.00
B26F50	2017-08-08 12:19:00+03	28800.00
B26F83	2017-08-08 21:50:00+03	157000.00
B26F86	2017-08-12 20:55:00+03	38300.00
B26FD4	2017-07-31 09:09:00+03	92800.00
B26FDA	2017-07-26 07:44:00+03	26800.00
B2707D	2017-07-01 08:13:00+03	51800.00
B27142	2017-07-17 20:58:00+03	64700.00
B2716A	2017-07-30 10:22:00+03	60400.00
B271B6	2017-08-09 21:17:00+03	105400.00
B271BE	2017-07-06 07:13:00+03	46200.00
B271C3	2017-07-28 04:24:00+03	188500.00
B271EC	2017-07-29 19:20:00+03	54000.00
B2722C	2017-07-09 04:31:00+03	48800.00
B27358	2017-07-23 16:37:00+03	7300.00
B27367	2017-07-09 10:53:00+03	105100.00
B27374	2017-08-14 19:32:00+03	32200.00
B273FF	2017-07-29 06:09:00+03	43400.00
B27404	2017-07-13 21:32:00+03	73600.00
B27406	2017-08-05 18:35:00+03	46400.00
B27457	2017-07-30 10:38:00+03	265700.00
B2750C	2017-08-09 06:49:00+03	56000.00
B2751F	2017-07-04 15:59:00+03	67600.00
B27523	2017-07-14 12:29:00+03	103000.00
B27529	2017-07-27 05:48:00+03	81800.00
B27533	2017-07-06 13:38:00+03	158100.00
B27547	2017-08-08 04:33:00+03	103000.00
B27575	2017-07-23 05:02:00+03	59000.00
B2757B	2017-07-04 17:04:00+03	47800.00
B275C2	2017-08-08 14:57:00+03	59300.00
B275D5	2017-08-11 03:20:00+03	16400.00
B27627	2017-07-22 15:54:00+03	82900.00
B276B3	2017-08-15 11:10:00+03	60600.00
B276F5	2017-07-16 16:52:00+03	111600.00
B276F9	2017-08-02 02:38:00+03	127900.00
B27798	2017-07-21 22:38:00+03	81700.00
B27799	2017-08-08 05:03:00+03	61800.00
B277B6	2017-07-03 01:44:00+03	30700.00
B2783A	2017-07-29 14:00:00+03	37900.00
B278C3	2017-08-10 17:19:00+03	109800.00
B278D7	2017-07-17 12:45:00+03	355200.00
B27916	2017-07-23 22:42:00+03	118600.00
B27951	2017-07-17 21:04:00+03	75600.00
B279C4	2017-08-07 00:23:00+03	59800.00
B27A4D	2017-07-04 08:06:00+03	53400.00
B27B3C	2017-07-08 03:52:00+03	85000.00
B27B60	2017-08-12 22:09:00+03	71900.00
B27B70	2017-07-12 03:05:00+03	38400.00
B27BDF	2017-07-29 00:04:00+03	87100.00
B27BEE	2017-07-29 21:59:00+03	49500.00
B27BF2	2017-07-02 04:37:00+03	137600.00
B27C14	2017-07-08 17:28:00+03	77900.00
B27C2C	2017-07-11 17:53:00+03	47400.00
B27C57	2017-07-12 17:20:00+03	28000.00
B27CF7	2017-07-21 09:42:00+03	86300.00
B27D2D	2017-08-07 01:48:00+03	45200.00
B27D96	2017-07-20 17:43:00+03	6400.00
B27DC3	2017-07-05 06:40:00+03	88900.00
B27DCE	2017-07-01 08:40:00+03	56600.00
B27E2A	2017-07-10 15:31:00+03	16400.00
B27E80	2017-07-06 21:35:00+03	8200.00
B27EC3	2017-07-31 08:27:00+03	130400.00
B27EC7	2017-08-03 11:21:00+03	24800.00
B27EF9	2017-08-10 09:10:00+03	24400.00
B27F23	2017-07-26 07:10:00+03	75000.00
B27F43	2017-08-15 08:40:00+03	23100.00
B27FFD	2017-06-27 10:11:00+03	24300.00
B28029	2017-07-06 05:36:00+03	26000.00
B28034	2017-08-04 06:51:00+03	30000.00
B28111	2017-08-13 14:08:00+03	102000.00
B2811A	2017-07-31 06:00:00+03	30200.00
B28122	2017-08-03 20:21:00+03	111600.00
B28130	2017-08-02 21:54:00+03	79900.00
B28138	2017-08-07 19:13:00+03	35600.00
B281C6	2017-08-02 00:33:00+03	33200.00
B28216	2017-07-24 16:22:00+03	139200.00
B2826F	2017-08-11 11:31:00+03	52000.00
B2829B	2017-07-28 17:26:00+03	26700.00
B282A6	2017-06-29 14:01:00+03	39800.00
B282A9	2017-07-07 12:38:00+03	28000.00
B282EC	2017-07-24 06:10:00+03	17800.00
B28303	2017-07-23 22:23:00+03	137600.00
B28324	2017-08-14 04:45:00+03	31400.00
B28340	2017-07-08 04:17:00+03	11600.00
B2838C	2017-08-11 10:34:00+03	26000.00
B284B1	2017-08-07 21:50:00+03	22600.00
B284EF	2017-08-06 03:05:00+03	187900.00
B2851F	2017-07-01 15:43:00+03	130900.00
B28533	2017-07-13 00:31:00+03	12400.00
B2853B	2017-08-15 01:35:00+03	88100.00
B28542	2017-07-13 15:27:00+03	24400.00
B2855F	2017-08-14 09:44:00+03	50400.00
B28566	2017-07-03 04:27:00+03	88900.00
B2859C	2017-07-07 21:37:00+03	56000.00
B285F7	2017-08-03 21:09:00+03	44500.00
B285F9	2017-07-13 14:26:00+03	47200.00
B28616	2017-07-23 09:20:00+03	42700.00
B2864D	2017-07-27 00:53:00+03	111600.00
B28683	2017-07-24 13:04:00+03	28000.00
B286D9	2017-08-10 14:41:00+03	48900.00
B2870C	2017-07-29 01:59:00+03	26000.00
B2871F	2017-08-10 04:48:00+03	123000.00
B28730	2017-08-10 13:27:00+03	66000.00
B2875F	2017-08-01 20:19:00+03	23400.00
B28865	2017-08-03 06:38:00+03	78600.00
B2886D	2017-07-23 14:43:00+03	67200.00
B288A3	2017-07-21 02:13:00+03	16400.00
B28924	2017-08-14 19:27:00+03	6700.00
B2894F	2017-07-21 01:20:00+03	21200.00
B28951	2017-07-02 20:35:00+03	56600.00
B28992	2017-07-17 09:19:00+03	46400.00
B289EC	2017-08-06 13:00:00+03	12400.00
B28A2F	2017-08-03 16:32:00+03	60400.00
B28A4B	2017-07-09 00:19:00+03	21400.00
B28A4D	2017-07-10 12:02:00+03	96300.00
B28A97	2017-08-02 18:39:00+03	199600.00
B28AE3	2017-08-10 09:15:00+03	233700.00
B28B14	2017-08-13 15:53:00+03	23600.00
B28B4B	2017-07-17 00:16:00+03	19100.00
B28BA4	2017-07-14 20:31:00+03	18300.00
B28BBF	2017-07-16 09:10:00+03	36200.00
B28C04	2017-07-20 23:29:00+03	101200.00
B28C15	2017-07-10 22:55:00+03	118500.00
B28CD8	2017-07-22 06:11:00+03	55800.00
B28CE6	2017-07-10 11:17:00+03	55800.00
B28DD3	2017-07-28 07:17:00+03	46900.00
B28DD5	2017-07-01 20:25:00+03	67600.00
B28E01	2017-08-07 10:08:00+03	27200.00
B28E10	2017-07-22 05:14:00+03	70800.00
B28E7B	2017-07-04 00:55:00+03	67400.00
B28EF4	2017-07-31 02:12:00+03	136500.00
B28F66	2017-08-06 12:25:00+03	65500.00
B28FC4	2017-08-11 18:57:00+03	67300.00
B29013	2017-07-04 12:07:00+03	67200.00
B29033	2017-07-09 10:13:00+03	103900.00
B2905B	2017-07-14 22:42:00+03	35700.00
B2909A	2017-08-10 02:36:00+03	46400.00
B290A2	2017-07-20 12:03:00+03	32200.00
B29101	2017-07-09 11:25:00+03	113200.00
B2914A	2017-07-11 06:43:00+03	116400.00
B29168	2017-07-08 13:39:00+03	123000.00
B291F4	2017-07-23 03:17:00+03	92800.00
B291FE	2017-08-07 00:21:00+03	28600.00
B29230	2017-08-08 00:50:00+03	26000.00
B292B2	2017-07-14 10:43:00+03	12600.00
B29327	2017-07-26 20:34:00+03	66900.00
B29331	2017-08-12 06:03:00+03	56000.00
B2940F	2017-08-13 20:32:00+03	15000.00
B29417	2017-07-06 00:07:00+03	21400.00
B2941C	2017-07-11 03:02:00+03	46400.00
B29485	2017-08-08 13:43:00+03	49700.00
B294B1	2017-07-27 17:00:00+03	23600.00
B29562	2017-07-11 10:39:00+03	95200.00
B295CA	2017-08-07 23:54:00+03	99300.00
B296AD	2017-07-19 05:49:00+03	26800.00
B296DB	2017-07-05 03:23:00+03	7400.00
B296FD	2017-07-30 08:04:00+03	21800.00
B2971B	2017-08-09 23:23:00+03	31100.00
B29792	2017-07-21 17:33:00+03	27400.00
B297A6	2017-07-14 14:25:00+03	70700.00
B297B2	2017-08-14 11:51:00+03	40400.00
B297B8	2017-08-14 08:40:00+03	14400.00
B2981F	2017-08-06 05:24:00+03	134800.00
B29837	2017-07-26 17:32:00+03	135400.00
B2985C	2017-08-07 03:17:00+03	28000.00
B29867	2017-08-04 08:05:00+03	12400.00
B298BD	2017-07-09 04:59:00+03	38200.00
B298E7	2017-07-17 03:34:00+03	68400.00
B298F8	2017-07-12 09:13:00+03	39500.00
B29944	2017-08-09 02:19:00+03	123600.00
B2994C	2017-07-28 04:31:00+03	94300.00
B29992	2017-07-27 15:50:00+03	65500.00
B29999	2017-07-10 00:39:00+03	46200.00
B29A60	2017-08-15 12:43:00+03	72300.00
B29A8A	2017-08-12 12:15:00+03	62800.00
B29A99	2017-07-11 13:30:00+03	27800.00
B29B00	2017-07-12 04:11:00+03	10600.00
B29B7A	2017-08-13 01:50:00+03	140200.00
B29BBE	2017-07-03 02:28:00+03	94000.00
B29BC8	2017-07-18 15:30:00+03	19500.00
B29C07	2017-07-07 04:02:00+03	67000.00
B29C09	2017-07-11 22:53:00+03	57400.00
B29C6B	2017-07-19 05:18:00+03	6000.00
B29CDC	2017-08-07 08:59:00+03	57500.00
B29CE4	2017-06-28 07:24:00+03	46300.00
B29CFA	2017-08-05 23:06:00+03	25200.00
B29D49	2017-07-08 11:10:00+03	69600.00
B29D54	2017-07-13 18:05:00+03	24400.00
B29E19	2017-07-07 14:22:00+03	117600.00
B29EFF	2017-07-02 20:12:00+03	40800.00
B29F3C	2017-07-12 01:16:00+03	25600.00
B29F53	2017-08-09 11:31:00+03	48800.00
B29FC2	2017-08-07 21:45:00+03	34000.00
B29FD6	2017-07-27 00:00:00+03	383400.00
B2A0C4	2017-08-14 07:49:00+03	18000.00
B2A114	2017-08-03 09:13:00+03	14800.00
B2A12C	2017-08-15 06:43:00+03	119500.00
B2A141	2017-08-05 03:34:00+03	54400.00
B2A216	2017-07-26 15:25:00+03	111600.00
B2A24C	2017-08-10 16:07:00+03	67600.00
B2A27E	2017-07-20 00:12:00+03	180300.00
B2A2B5	2017-08-05 07:22:00+03	6700.00
B2A331	2017-07-01 09:28:00+03	16400.00
B2A345	2017-07-28 13:25:00+03	113000.00
B2A377	2017-08-10 17:13:00+03	19800.00
B2A3AC	2017-08-06 08:54:00+03	58900.00
B2A3C5	2017-08-09 10:53:00+03	18000.00
B2A3CC	2017-07-10 21:57:00+03	103500.00
B2A3DC	2017-07-13 07:39:00+03	28000.00
B2A40C	2017-08-12 11:51:00+03	51800.00
B2A434	2017-07-07 13:33:00+03	68000.00
B2A45E	2017-07-12 10:55:00+03	45200.00
B2A473	2017-07-09 05:35:00+03	53600.00
B2A5FE	2017-07-11 01:00:00+03	32800.00
B2A62D	2017-08-04 20:35:00+03	95400.00
B2A658	2017-07-26 03:36:00+03	123000.00
B2A65D	2017-07-26 08:14:00+03	46300.00
B2A663	2017-08-05 23:16:00+03	91100.00
B2A6D7	2017-07-29 06:10:00+03	103200.00
B2A75B	2017-07-20 17:08:00+03	28000.00
B2A7A5	2017-08-08 20:55:00+03	10700.00
B2A7DA	2017-08-14 20:26:00+03	145300.00
B2A80D	2017-07-03 10:56:00+03	57400.00
B2A854	2017-07-21 15:48:00+03	135400.00
B2A890	2017-08-04 00:01:00+03	56100.00
B2A8C4	2017-07-15 05:49:00+03	155600.00
B2A923	2017-07-03 13:12:00+03	62600.00
B2A981	2017-08-01 01:31:00+03	20200.00
B2AA11	2017-07-13 01:25:00+03	14400.00
B2AA4C	2017-07-14 19:42:00+03	115900.00
B2AAA2	2017-07-13 16:06:00+03	76600.00
B2AAA7	2017-07-29 05:35:00+03	246000.00
B2AAAF	2017-08-10 16:28:00+03	21800.00
B2AAF6	2017-07-14 04:52:00+03	36700.00
B2AB28	2017-08-14 10:23:00+03	23900.00
B2AB5B	2017-07-03 02:28:00+03	22000.00
B2AB85	2017-07-20 10:37:00+03	128800.00
B2AC51	2017-08-06 06:53:00+03	31200.00
B2AC59	2017-07-06 11:15:00+03	58900.00
B2AD29	2017-07-30 19:06:00+03	21200.00
B2AD5C	2017-08-01 13:00:00+03	40800.00
B2AD61	2017-08-11 01:42:00+03	55800.00
B2AD9E	2017-07-31 09:56:00+03	492000.00
B2AF3F	2017-07-27 16:14:00+03	19600.00
B2AF8E	2017-08-10 23:41:00+03	45100.00
B2AFAE	2017-07-23 16:20:00+03	77700.00
B2AFEF	2017-07-12 11:44:00+03	73300.00
B2AFF7	2017-07-31 19:04:00+03	75300.00
B2B026	2017-07-21 08:35:00+03	20400.00
B2B05F	2017-08-14 07:54:00+03	25100.00
B2B069	2017-07-19 12:37:00+03	14800.00
B2B08C	2017-08-01 14:28:00+03	136000.00
B2B0FF	2017-08-05 15:41:00+03	45200.00
B2B10D	2017-07-27 16:59:00+03	294200.00
B2B167	2017-07-12 23:01:00+03	55800.00
B2B172	2017-06-30 14:09:00+03	48800.00
B2B200	2017-07-14 10:10:00+03	25100.00
B2B220	2017-07-24 09:20:00+03	56600.00
B2B242	2017-07-25 14:20:00+03	80300.00
B2B2C7	2017-07-24 16:53:00+03	28000.00
B2B2E1	2017-06-30 11:27:00+03	13600.00
B2B2FC	2017-07-03 16:36:00+03	112000.00
B2B304	2017-07-09 09:59:00+03	152500.00
B2B33F	2017-07-24 21:49:00+03	28800.00
B2B405	2017-07-01 10:14:00+03	8200.00
B2B41F	2017-07-17 11:15:00+03	67600.00
B2B479	2017-07-30 17:35:00+03	248500.00
B2B4C8	2017-07-29 19:44:00+03	21800.00
B2B4C9	2017-07-10 10:54:00+03	186900.00
B2B4F8	2017-07-30 15:07:00+03	65500.00
B2B504	2017-07-26 20:59:00+03	46000.00
B2B517	2017-07-25 18:07:00+03	24400.00
B2B575	2017-07-03 14:38:00+03	246000.00
B2B5C6	2017-07-04 12:41:00+03	44000.00
B2B5D6	2017-08-04 23:25:00+03	56000.00
B2B61D	2017-07-26 18:46:00+03	34400.00
B2B62F	2017-08-04 07:02:00+03	21500.00
B2B652	2017-07-20 07:11:00+03	67800.00
B2B685	2017-08-05 04:31:00+03	22000.00
B2B6BE	2017-08-02 18:52:00+03	111600.00
B2B6F2	2017-07-07 07:00:00+03	70500.00
B2B722	2017-08-06 05:07:00+03	153300.00
B2B773	2017-07-10 09:27:00+03	87100.00
B2B788	2017-07-22 16:59:00+03	41400.00
B2B7B1	2017-07-14 22:36:00+03	53800.00
B2B7F6	2017-07-14 01:01:00+03	55600.00
B2B7FC	2017-08-10 03:54:00+03	322600.00
B2B82D	2017-06-30 15:16:00+03	89700.00
B2B83F	2017-07-12 20:40:00+03	20400.00
B2B8A4	2017-08-04 04:24:00+03	22600.00
B2B8DB	2017-07-17 10:44:00+03	65600.00
B2B8EA	2017-07-13 05:22:00+03	38200.00
B2B91A	2017-07-30 02:57:00+03	38600.00
B2B993	2017-08-15 09:39:00+03	81500.00
B2BA6B	2017-07-11 04:46:00+03	189800.00
B2BA90	2017-07-29 01:00:00+03	34200.00
B2BAED	2017-07-07 10:12:00+03	23200.00
B2BC1F	2017-06-30 05:50:00+03	173300.00
B2BC5C	2017-07-07 04:31:00+03	406100.00
B2BC9B	2017-07-21 14:57:00+03	68800.00
B2BCBF	2017-08-11 16:39:00+03	54000.00
B2BD63	2017-07-07 19:51:00+03	133200.00
B2BD69	2017-07-10 12:17:00+03	28800.00
B2BDE2	2017-08-05 14:18:00+03	31200.00
B2BE24	2017-08-11 03:17:00+03	99600.00
B2BF06	2017-08-14 06:34:00+03	64700.00
B2BF24	2017-07-15 02:35:00+03	26700.00
B2BF5F	2017-08-11 07:40:00+03	12400.00
B2BF63	2017-07-01 17:58:00+03	99800.00
B2BF6B	2017-07-15 08:22:00+03	38800.00
B2BFAC	2017-06-29 13:43:00+03	6300.00
B2BFD5	2017-08-10 23:47:00+03	49600.00
B2C03E	2017-07-05 07:30:00+03	56900.00
B2C0D8	2017-08-02 17:57:00+03	135000.00
B2C151	2017-07-26 10:02:00+03	43200.00
B2C2AE	2017-06-30 05:54:00+03	88600.00
B2C2D7	2017-07-21 23:30:00+03	19600.00
B2C2DF	2017-07-16 23:28:00+03	81700.00
B2C2EB	2017-08-11 23:16:00+03	95200.00
B2C2F4	2017-08-02 16:03:00+03	65200.00
B2C363	2017-07-16 22:46:00+03	24000.00
B2C37F	2017-07-15 05:08:00+03	49000.00
B2C396	2017-08-06 05:40:00+03	139300.00
B2C3B4	2017-07-24 20:51:00+03	55800.00
B2C3CA	2017-07-17 15:33:00+03	27300.00
B2C4EC	2017-07-27 08:38:00+03	52800.00
B2C4FF	2017-08-15 04:50:00+03	66600.00
B2C59C	2017-07-02 00:11:00+03	24000.00
B2C5DA	2017-06-30 20:17:00+03	55800.00
B2C62A	2017-07-23 17:20:00+03	96500.00
B2C64B	2017-08-15 02:45:00+03	135400.00
B2C6AE	2017-08-12 15:57:00+03	58800.00
B2C721	2017-07-22 22:26:00+03	162300.00
B2C73F	2017-08-10 23:42:00+03	134400.00
B2C75F	2017-07-15 16:02:00+03	100600.00
B2C815	2017-08-09 06:44:00+03	23400.00
B2C86F	2017-07-07 06:43:00+03	18800.00
B2C878	2017-07-28 03:19:00+03	59800.00
B2C8FB	2017-07-28 00:25:00+03	12400.00
B2C908	2017-08-14 13:23:00+03	331200.00
B2C941	2017-07-30 11:35:00+03	136600.00
B2C977	2017-07-16 03:36:00+03	38600.00
B2C994	2017-08-06 04:18:00+03	25700.00
B2CA18	2017-07-26 21:31:00+03	31500.00
B2CA65	2017-08-11 20:06:00+03	112400.00
B2CAF9	2017-08-01 15:31:00+03	56000.00
B2CB1A	2017-08-13 16:11:00+03	134900.00
B2CB3D	2017-08-04 03:00:00+03	24400.00
B2CB46	2017-08-10 19:33:00+03	38400.00
B2CB4E	2017-08-07 16:08:00+03	6000.00
B2CB67	2017-07-28 03:12:00+03	12600.00
B2CBBA	2017-07-28 12:53:00+03	26000.00
B2CC7B	2017-07-04 08:40:00+03	85000.00
B2CD0E	2017-07-12 21:15:00+03	77400.00
B2CD30	2017-07-03 23:03:00+03	51900.00
B2CDBE	2017-08-05 07:04:00+03	123000.00
B2CDE9	2017-07-14 20:43:00+03	89700.00
B2CE1A	2017-08-02 09:17:00+03	28000.00
B2CF09	2017-08-11 05:37:00+03	27300.00
B2CF5A	2017-07-25 23:56:00+03	111200.00
B2CF5E	2017-08-11 01:03:00+03	24600.00
B2CF9C	2017-07-20 14:42:00+03	39300.00
B2CFE3	2017-08-11 17:52:00+03	33800.00
B2D00D	2017-07-02 10:38:00+03	24300.00
B2D01C	2017-07-09 23:18:00+03	103200.00
B2D021	2017-07-23 12:57:00+03	98400.00
B2D051	2017-07-27 06:56:00+03	8000.00
B2D063	2017-07-15 08:02:00+03	37900.00
B2D099	2017-07-05 16:02:00+03	26000.00
B2D0D9	2017-07-26 04:47:00+03	343300.00
B2D10B	2017-08-09 11:29:00+03	31400.00
B2D15B	2017-07-20 20:56:00+03	92400.00
B2D1B5	2017-07-20 15:10:00+03	41200.00
B2D1E0	2017-08-15 11:58:00+03	44000.00
B2D225	2017-08-11 21:26:00+03	80500.00
B2D235	2017-07-19 06:21:00+03	78100.00
B2D2D0	2017-07-20 22:09:00+03	99600.00
B2D2D3	2017-08-06 23:52:00+03	50600.00
B2D317	2017-07-18 02:32:00+03	82900.00
B2D322	2017-08-07 18:11:00+03	26800.00
B2D342	2017-08-02 01:16:00+03	89000.00
B2D34A	2017-08-13 12:49:00+03	55800.00
B2D36A	2017-07-03 22:53:00+03	103400.00
B2D3A9	2017-07-02 14:26:00+03	125400.00
B2D41B	2017-08-11 13:09:00+03	78000.00
B2D41F	2017-07-12 19:42:00+03	26000.00
B2D45C	2017-07-27 01:01:00+03	8200.00
B2D491	2017-07-28 05:48:00+03	170000.00
B2D53B	2017-07-29 01:13:00+03	22000.00
B2D555	2017-08-10 00:17:00+03	57500.00
B2D5D3	2017-07-20 09:35:00+03	55400.00
B2D613	2017-07-26 15:52:00+03	70500.00
B2D617	2017-07-12 11:48:00+03	57600.00
B2D624	2017-07-11 06:55:00+03	35700.00
B2D636	2017-07-16 00:11:00+03	67700.00
B2D6DC	2017-07-15 22:25:00+03	56000.00
B2D71C	2017-08-09 00:09:00+03	60400.00
B2D732	2017-07-31 23:08:00+03	75200.00
B2D73E	2017-07-17 16:41:00+03	98800.00
B2D770	2017-07-17 15:27:00+03	44400.00
B2D775	2017-08-10 23:58:00+03	54400.00
B2D784	2017-07-09 10:36:00+03	112000.00
B2D7A5	2017-08-08 01:29:00+03	75300.00
B2D8A2	2017-08-01 07:42:00+03	74600.00
B2D8B5	2017-07-16 00:47:00+03	46300.00
B2D8DB	2017-08-09 07:03:00+03	36100.00
B2D8E3	2017-07-31 02:03:00+03	381500.00
B2D924	2017-07-28 16:40:00+03	115700.00
B2D92D	2017-08-03 10:41:00+03	46200.00
B2DA24	2017-08-13 19:43:00+03	100600.00
B2DA67	2017-07-05 18:44:00+03	68900.00
B2DA7B	2017-07-12 11:55:00+03	27300.00
B2DAD7	2017-08-05 09:10:00+03	92800.00
B2DAE2	2017-07-25 05:59:00+03	82200.00
B2DB6F	2017-08-07 15:44:00+03	135400.00
B2DBD9	2017-07-20 14:12:00+03	23600.00
B2DC01	2017-07-27 04:12:00+03	79600.00
B2DC08	2017-07-04 19:06:00+03	31400.00
B2DC2E	2017-07-21 10:03:00+03	222700.00
B2DC5D	2017-08-14 11:34:00+03	136600.00
B2DC6E	2017-07-21 20:18:00+03	24800.00
B2DCC3	2017-07-14 22:56:00+03	31200.00
B2DCDC	2017-08-08 05:14:00+03	47400.00
B2DD31	2017-07-05 13:31:00+03	109800.00
B2DD60	2017-08-14 01:54:00+03	87200.00
B2DD72	2017-06-30 20:18:00+03	64100.00
B2DD75	2017-08-09 22:37:00+03	149400.00
B2DD9A	2017-08-07 07:40:00+03	410200.00
B2DDEF	2017-08-08 01:17:00+03	6700.00
B2DE9B	2017-08-08 19:09:00+03	55800.00
B2DEB0	2017-08-05 08:26:00+03	124200.00
B2DEC5	2017-08-14 18:27:00+03	39300.00
B2DEC7	2017-08-13 01:31:00+03	55800.00
B2DEF5	2017-07-31 03:15:00+03	70600.00
B2DEFB	2017-08-06 09:49:00+03	58000.00
B2DF2F	2017-08-05 07:56:00+03	52700.00
B2DFE3	2017-08-03 06:34:00+03	23600.00
B2E088	2017-07-27 03:56:00+03	94000.00
B2E0F5	2017-07-09 12:01:00+03	111600.00
B2E111	2017-07-11 13:16:00+03	69500.00
B2E120	2017-07-31 00:58:00+03	58400.00
B2E152	2017-08-10 04:41:00+03	34600.00
B2E170	2017-07-23 22:07:00+03	167400.00
B2E1FA	2017-06-30 04:41:00+03	18600.00
B2E209	2017-07-02 03:25:00+03	25600.00
B2E225	2017-08-08 03:31:00+03	56600.00
B2E258	2017-06-30 16:04:00+03	56000.00
B2E292	2017-07-19 22:14:00+03	6000.00
B2E2AF	2017-07-14 02:47:00+03	56600.00
B2E2FD	2017-07-12 21:31:00+03	57500.00
B2E2FE	2017-07-09 10:13:00+03	67200.00
B2E301	2017-07-07 17:32:00+03	34800.00
B2E304	2017-07-01 12:12:00+03	58800.00
B2E31D	2017-07-28 23:03:00+03	29100.00
B2E3CC	2017-07-11 23:57:00+03	58000.00
B2E44A	2017-08-12 04:05:00+03	22000.00
B2E4A2	2017-07-09 02:02:00+03	171400.00
B2E4BC	2017-07-27 20:53:00+03	94000.00
B2E4E3	2017-06-30 22:49:00+03	12700.00
B2E521	2017-08-05 03:43:00+03	26000.00
B2E53B	2017-07-23 11:01:00+03	265800.00
B2E55A	2017-07-08 03:35:00+03	100800.00
B2E56B	2017-07-30 09:30:00+03	31600.00
B2E598	2017-08-05 19:29:00+03	152900.00
B2E5BF	2017-08-03 10:09:00+03	78200.00
B2E603	2017-08-13 20:54:00+03	135200.00
B2E6A3	2017-07-18 03:58:00+03	121600.00
B2E6A8	2017-07-15 06:56:00+03	111600.00
B2E70D	2017-08-15 02:18:00+03	43200.00
B2E72A	2017-08-11 17:37:00+03	139300.00
B2E732	2017-07-19 06:40:00+03	21200.00
B2E74C	2017-07-30 10:10:00+03	28800.00
B2E79A	2017-07-09 09:06:00+03	64800.00
B2E7CA	2017-08-02 18:47:00+03	168700.00
B2E7D5	2017-07-12 19:43:00+03	21800.00
B2E876	2017-07-19 14:44:00+03	77200.00
B2E8E0	2017-07-08 15:04:00+03	114800.00
B2E90B	2017-08-14 08:26:00+03	44000.00
B2E953	2017-07-10 19:43:00+03	14000.00
B2EA0B	2017-07-31 22:09:00+03	112700.00
B2EA48	2017-07-11 16:24:00+03	57500.00
B2EA52	2017-08-10 01:49:00+03	67900.00
B2EAC2	2017-07-03 17:04:00+03	52800.00
B2EB41	2017-08-09 04:10:00+03	118700.00
B2EB6B	2017-08-05 03:39:00+03	68800.00
B2EB70	2017-08-09 14:47:00+03	85000.00
B2EBFB	2017-08-14 12:42:00+03	28800.00
B2EC4F	2017-07-08 15:13:00+03	32200.00
B2EC60	2017-08-15 14:59:00+03	71600.00
B2EC7D	2017-07-03 13:10:00+03	68800.00
B2ECAD	2017-08-08 02:30:00+03	68800.00
B2ED65	2017-08-14 19:08:00+03	58900.00
B2ED97	2017-07-28 19:58:00+03	16000.00
B2EE4D	2017-07-31 05:32:00+03	106500.00
B2EE57	2017-07-22 07:58:00+03	135600.00
B2EE75	2017-07-15 11:39:00+03	76600.00
B2EEEC	2017-07-24 13:09:00+03	24400.00
B2EFC4	2017-07-30 18:23:00+03	89700.00
B2F08F	2017-08-02 08:20:00+03	47400.00
B2F0B3	2017-08-02 02:34:00+03	26000.00
B2F166	2017-08-06 18:07:00+03	138300.00
B2F1AF	2017-07-19 18:20:00+03	117700.00
B2F1C1	2017-07-21 05:01:00+03	96800.00
B2F1D1	2017-08-08 16:13:00+03	6600.00
B2F1E4	2017-07-23 01:29:00+03	62600.00
B2F211	2017-08-05 10:59:00+03	31800.00
B2F23C	2017-08-08 17:30:00+03	42800.00
B2F246	2017-07-16 14:51:00+03	50000.00
B2F267	2017-07-22 01:34:00+03	47400.00
B2F348	2017-07-24 11:04:00+03	266400.00
B2F3A1	2017-08-12 16:53:00+03	18800.00
B2F3C3	2017-07-31 19:55:00+03	122800.00
B2F4C0	2017-07-19 06:07:00+03	94700.00
B2F500	2017-07-26 09:50:00+03	152500.00
B2F504	2017-08-14 11:13:00+03	51700.00
B2F515	2017-07-01 11:10:00+03	21600.00
B2F532	2017-07-19 22:06:00+03	14000.00
B2F54D	2017-08-07 11:40:00+03	57500.00
B2F55F	2017-06-30 00:23:00+03	66600.00
B2F590	2017-07-15 22:32:00+03	266300.00
B2F664	2017-07-13 07:36:00+03	66600.00
B2F670	2017-07-12 17:13:00+03	48700.00
B2F6C4	2017-08-03 08:34:00+03	132800.00
B2F705	2017-08-06 10:39:00+03	128800.00
B2F715	2017-07-04 01:45:00+03	64700.00
B2F71D	2017-08-09 00:17:00+03	22400.00
B2F746	2017-08-11 07:36:00+03	43000.00
B2F78C	2017-07-06 18:23:00+03	67200.00
B2F7B4	2017-07-05 00:21:00+03	200200.00
B2F820	2017-08-06 16:23:00+03	127400.00
B2F829	2017-07-13 08:38:00+03	41200.00
B2F833	2017-07-03 19:23:00+03	59000.00
B2F83C	2017-08-10 09:12:00+03	6700.00
B2F85F	2017-06-25 18:32:00+03	179700.00
B2F8B6	2017-08-01 02:58:00+03	75300.00
B2F8E0	2017-07-16 04:49:00+03	14400.00
B2F91E	2017-07-15 10:36:00+03	21000.00
B2F92B	2017-07-23 14:01:00+03	115900.00
B2F992	2017-07-24 07:58:00+03	39300.00
B2F9D8	2017-07-04 01:59:00+03	135000.00
B2FA68	2017-08-09 01:44:00+03	117700.00
B2FB1D	2017-08-13 05:59:00+03	108500.00
B2FB7D	2017-08-15 08:28:00+03	57100.00
B2FBBE	2017-08-08 21:02:00+03	92600.00
B2FBD7	2017-08-04 20:23:00+03	12000.00
B2FBFF	2017-07-20 02:39:00+03	12600.00
B2FC5C	2017-08-02 19:51:00+03	48800.00
B2FCE7	2017-07-08 21:14:00+03	52900.00
B2FD3D	2017-07-29 05:49:00+03	75300.00
B2FE1C	2017-07-02 04:00:00+03	38600.00
B2FE33	2017-07-05 10:19:00+03	27900.00
B2FE7C	2017-08-10 08:19:00+03	46400.00
B2FE88	2017-07-24 03:11:00+03	77600.00
B2FF46	2017-07-29 16:54:00+03	46800.00
B2FF51	2017-08-05 13:25:00+03	52000.00
B2FF5B	2017-08-01 11:59:00+03	15000.00
B2FF7C	2017-07-02 18:57:00+03	132800.00
B2FFDD	2017-07-02 19:38:00+03	39400.00
B30034	2017-08-10 07:36:00+03	136800.00
B30093	2017-07-12 18:30:00+03	46000.00
B301BE	2017-07-19 10:15:00+03	100600.00
B301C4	2017-07-04 17:44:00+03	87000.00
B301C9	2017-07-30 19:31:00+03	31000.00
B3023F	2017-08-09 23:17:00+03	57500.00
B30268	2017-08-15 14:15:00+03	48300.00
B30286	2017-08-12 05:06:00+03	34400.00
B3028F	2017-07-25 08:02:00+03	179300.00
B30293	2017-08-13 14:32:00+03	32700.00
B302DA	2017-07-15 10:57:00+03	32700.00
B302E9	2017-06-28 08:21:00+03	63300.00
B30320	2017-07-28 13:28:00+03	132800.00
B3032B	2017-07-09 23:02:00+03	29000.00
B303B1	2017-07-30 18:25:00+03	16400.00
B3040D	2017-08-02 10:23:00+03	81600.00
B30412	2017-07-06 23:40:00+03	185300.00
B30439	2017-07-20 05:37:00+03	56600.00
B30515	2017-07-07 19:12:00+03	15100.00
B3053D	2017-07-19 16:38:00+03	23400.00
B30540	2017-08-13 00:27:00+03	26700.00
B3056A	2017-07-27 19:34:00+03	24200.00
B305A1	2017-08-15 00:25:00+03	44500.00
B305F1	2017-08-13 11:17:00+03	90400.00
B30643	2017-07-09 08:13:00+03	49100.00
B3069D	2017-07-16 10:42:00+03	98400.00
B306BC	2017-07-17 18:22:00+03	23600.00
B30736	2017-07-27 00:40:00+03	100200.00
B30754	2017-07-20 03:54:00+03	57400.00
B307B3	2017-07-01 03:50:00+03	65500.00
B307CE	2017-08-04 22:15:00+03	30900.00
B30810	2017-07-04 02:23:00+03	40400.00
B30847	2017-07-04 07:28:00+03	81300.00
B30871	2017-07-15 18:52:00+03	84500.00
B308BC	2017-06-30 04:34:00+03	63300.00
B30913	2017-07-07 06:48:00+03	56000.00
B30957	2017-07-20 08:18:00+03	13200.00
B30971	2017-07-26 23:40:00+03	10800.00
B30996	2017-08-05 17:25:00+03	94300.00
B309A1	2017-07-14 03:13:00+03	29600.00
B309A4	2017-08-12 14:12:00+03	190100.00
B30A68	2017-07-28 05:16:00+03	6700.00
B30ADA	2017-07-03 00:14:00+03	14100.00
B30AF1	2017-08-09 14:43:00+03	23400.00
B30B4B	2017-08-14 11:43:00+03	113700.00
B30B4D	2017-07-23 09:10:00+03	28000.00
B30B50	2017-07-18 18:12:00+03	6600.00
B30B53	2017-08-01 10:13:00+03	25200.00
B30BC0	2017-07-13 09:42:00+03	13000.00
B30C94	2017-08-09 06:33:00+03	69500.00
B30CAD	2017-07-02 20:23:00+03	192400.00
B30D24	2017-08-05 16:28:00+03	34000.00
B30D2C	2017-07-05 21:33:00+03	92000.00
B30D60	2017-07-25 23:49:00+03	102100.00
B30D68	2017-06-29 13:46:00+03	35200.00
B30DAE	2017-07-30 01:34:00+03	49100.00
B30DD7	2017-08-07 23:56:00+03	42800.00
B30DFA	2017-08-09 10:31:00+03	61800.00
B30E2A	2017-08-06 11:39:00+03	29600.00
B30EA4	2017-07-21 11:42:00+03	67000.00
B30EA8	2017-07-05 19:08:00+03	96100.00
B30F1B	2017-07-19 16:16:00+03	38600.00
B30F7C	2017-07-06 19:48:00+03	36200.00
B30F81	2017-07-12 00:50:00+03	59800.00
B30F94	2017-07-14 03:27:00+03	25600.00
B30FA4	2017-07-14 05:15:00+03	115900.00
B30FBE	2017-07-13 22:34:00+03	90800.00
B30FC8	2017-08-10 23:22:00+03	3400.00
B30FD4	2017-07-09 18:37:00+03	59200.00
B3109C	2017-07-18 16:18:00+03	22000.00
B310C0	2017-06-29 03:30:00+03	34000.00
B31100	2017-07-29 03:06:00+03	190200.00
B3118F	2017-07-10 23:57:00+03	46800.00
B31196	2017-07-04 03:18:00+03	96800.00
B311D9	2017-07-08 13:28:00+03	58000.00
B31225	2017-08-05 08:12:00+03	49800.00
B31235	2017-08-08 01:17:00+03	140900.00
B312B3	2017-07-01 16:15:00+03	63000.00
B312C0	2017-08-08 19:32:00+03	56000.00
B312E9	2017-07-05 08:02:00+03	113300.00
B3132F	2017-08-02 04:21:00+03	8000.00
B3134A	2017-07-09 10:35:00+03	399600.00
B3136C	2017-07-04 23:30:00+03	23200.00
B31382	2017-08-10 16:41:00+03	40400.00
B31386	2017-07-30 21:13:00+03	77000.00
B313AA	2017-07-10 01:50:00+03	52800.00
B313C6	2017-07-17 17:06:00+03	29200.00
B313DB	2017-08-04 12:27:00+03	136200.00
B31405	2017-07-15 01:59:00+03	57500.00
B31430	2017-07-28 01:50:00+03	66600.00
B31446	2017-07-18 01:25:00+03	38600.00
B31474	2017-08-06 01:40:00+03	86300.00
B314B4	2017-07-15 15:52:00+03	13200.00
B314E2	2017-07-05 16:53:00+03	24400.00
B314E8	2017-07-19 08:11:00+03	60400.00
B314EE	2017-07-27 12:17:00+03	113600.00
B31553	2017-07-16 11:06:00+03	55800.00
B315E9	2017-08-13 00:19:00+03	46400.00
B315FB	2017-07-15 21:26:00+03	16400.00
B31668	2017-07-25 08:31:00+03	6700.00
B31696	2017-07-16 19:59:00+03	38800.00
B3170A	2017-07-31 16:36:00+03	12600.00
B3178F	2017-07-27 18:49:00+03	75300.00
B317B6	2017-08-03 07:10:00+03	7400.00
B317C8	2017-07-08 17:13:00+03	6700.00
B31810	2017-07-05 10:30:00+03	265800.00
B3181D	2017-07-05 11:09:00+03	38400.00
B31851	2017-08-09 15:30:00+03	48800.00
B31865	2017-08-14 06:25:00+03	52300.00
B3188B	2017-07-15 13:16:00+03	61800.00
B31898	2017-08-05 19:12:00+03	58200.00
B3189B	2017-08-11 14:04:00+03	63800.00
B318BA	2017-08-06 15:18:00+03	44000.00
B318BE	2017-07-19 08:39:00+03	13000.00
B3196F	2017-08-14 14:14:00+03	6000.00
B31998	2017-08-09 06:30:00+03	31600.00
B3199D	2017-06-27 09:26:00+03	89700.00
B319B3	2017-07-31 10:24:00+03	57500.00
B319B6	2017-07-25 14:30:00+03	21400.00
B319C2	2017-07-26 15:38:00+03	298600.00
B319FC	2017-07-10 18:23:00+03	44800.00
B31A17	2017-08-10 23:11:00+03	49600.00
B31A3B	2017-07-19 22:48:00+03	57800.00
B31A3F	2017-08-06 16:55:00+03	8200.00
B31A70	2017-08-12 15:11:00+03	32700.00
B31A7F	2017-08-14 23:28:00+03	22000.00
B31AB5	2017-08-04 18:04:00+03	58400.00
B31B57	2017-07-13 21:20:00+03	10100.00
B31B59	2017-07-07 13:09:00+03	28000.00
B31B96	2017-07-08 09:15:00+03	59800.00
B31BA2	2017-07-04 05:10:00+03	54000.00
B31CA5	2017-08-14 01:56:00+03	15700.00
B31D25	2017-08-02 07:16:00+03	12600.00
B31D2D	2017-08-11 14:46:00+03	125700.00
B31D32	2017-08-11 12:35:00+03	408500.00
B31D37	2017-08-10 15:52:00+03	201200.00
B31D93	2017-07-07 20:58:00+03	58000.00
B31E0B	2017-07-19 23:29:00+03	6700.00
B31E39	2017-08-11 00:14:00+03	44600.00
B31E3E	2017-07-30 13:42:00+03	56900.00
B31E6F	2017-06-29 04:02:00+03	6000.00
B31E8D	2017-07-28 14:06:00+03	32200.00
B31E95	2017-08-11 18:49:00+03	72400.00
B31EC1	2017-07-06 12:38:00+03	111600.00
B31EE4	2017-08-10 16:29:00+03	199700.00
B31EE5	2017-07-27 06:28:00+03	168000.00
B31F38	2017-08-06 16:57:00+03	112000.00
B31F8A	2017-07-25 14:45:00+03	11000.00
B31FB7	2017-07-03 02:51:00+03	44400.00
B3201E	2017-08-09 11:20:00+03	86300.00
B32052	2017-07-27 06:58:00+03	32800.00
B32091	2017-07-01 04:27:00+03	46000.00
B3214F	2017-07-05 08:49:00+03	167400.00
B3215D	2017-07-26 08:52:00+03	95000.00
B32237	2017-07-24 02:10:00+03	42700.00
B32247	2017-08-12 12:43:00+03	9300.00
B3224C	2017-07-19 04:25:00+03	151200.00
B32304	2017-08-03 19:14:00+03	114500.00
B32328	2017-08-15 00:47:00+03	79600.00
B32373	2017-08-08 12:11:00+03	34100.00
B32390	2017-07-02 07:52:00+03	59100.00
B323C6	2017-07-21 10:05:00+03	60400.00
B323EA	2017-07-13 19:25:00+03	40000.00
B3243B	2017-08-12 21:38:00+03	26000.00
B32448	2017-07-18 21:38:00+03	48800.00
B324EE	2017-07-26 21:57:00+03	135400.00
B32500	2017-08-09 05:53:00+03	14400.00
B3252F	2017-08-06 01:21:00+03	32800.00
B325AD	2017-07-13 08:34:00+03	124200.00
B325DA	2017-07-15 13:57:00+03	32800.00
B325FD	2017-07-01 11:19:00+03	149300.00
B326EC	2017-08-06 10:39:00+03	135400.00
B327DC	2017-08-07 14:07:00+03	65900.00
B327DF	2017-07-30 15:29:00+03	71600.00
B32834	2017-08-07 15:28:00+03	119500.00
B32857	2017-08-03 15:36:00+03	81600.00
B3285A	2017-07-24 16:42:00+03	46400.00
B32881	2017-07-23 07:57:00+03	31400.00
B3291B	2017-07-04 04:53:00+03	17800.00
B32939	2017-07-10 08:26:00+03	68400.00
B329EA	2017-07-10 07:05:00+03	20200.00
B32A12	2017-07-15 22:11:00+03	121200.00
B32A99	2017-07-15 02:30:00+03	56000.00
B32AB3	2017-07-30 03:23:00+03	67600.00
B32AD2	2017-08-14 12:04:00+03	63500.00
B32B09	2017-08-05 01:04:00+03	137100.00
B32B67	2017-08-05 09:50:00+03	32800.00
B32B81	2017-07-17 01:50:00+03	26000.00
B32BC6	2017-07-04 03:57:00+03	51200.00
B32BF1	2017-08-01 07:44:00+03	57600.00
B32C07	2017-07-30 17:32:00+03	43900.00
B32C1C	2017-08-08 18:43:00+03	111600.00
B32C27	2017-07-04 15:37:00+03	112100.00
B32C4B	2017-08-12 12:11:00+03	54500.00
B32C8C	2017-07-22 15:49:00+03	14000.00
B32C8F	2017-07-12 00:50:00+03	55800.00
B32CD8	2017-07-17 07:43:00+03	146400.00
B32CF6	2017-08-06 10:55:00+03	16400.00
B32D2F	2017-07-15 08:46:00+03	25800.00
B32D41	2017-08-13 16:59:00+03	46400.00
B32D46	2017-08-12 12:58:00+03	192400.00
B32E28	2017-07-21 09:34:00+03	296400.00
B32E89	2017-08-04 09:02:00+03	26100.00
B32E91	2017-07-23 15:20:00+03	31600.00
B32F2D	2017-08-09 19:09:00+03	119500.00
B32F5A	2017-07-07 21:14:00+03	9200.00
B32FB3	2017-07-24 15:01:00+03	45200.00
B32FE2	2017-07-21 18:02:00+03	20400.00
B32FE9	2017-07-03 13:15:00+03	28800.00
B32FEE	2017-08-04 20:54:00+03	6400.00
B3301A	2017-06-27 17:46:00+03	28000.00
B33026	2017-08-08 16:56:00+03	25000.00
B3302E	2017-07-29 18:23:00+03	123000.00
B330A1	2017-07-22 20:35:00+03	26800.00
B33113	2017-08-06 14:24:00+03	40000.00
B33126	2017-07-06 11:07:00+03	81700.00
B33158	2017-07-11 16:37:00+03	174900.00
B3315C	2017-07-08 09:37:00+03	28300.00
B331F3	2017-08-11 09:15:00+03	87100.00
B33213	2017-07-24 10:36:00+03	25600.00
B33241	2017-07-10 10:53:00+03	71900.00
B33295	2017-08-15 07:03:00+03	60000.00
B332E8	2017-07-17 18:07:00+03	12400.00
B33304	2017-07-30 19:30:00+03	178300.00
B33377	2017-08-13 03:48:00+03	73300.00
B33398	2017-08-08 02:59:00+03	21800.00
B333E4	2017-07-09 17:55:00+03	59600.00
B3350B	2017-07-13 10:22:00+03	21400.00
B3350F	2017-08-12 16:31:00+03	40800.00
B3352A	2017-07-26 16:24:00+03	58400.00
B33544	2017-08-02 23:16:00+03	52400.00
B33562	2017-07-26 02:33:00+03	24800.00
B33569	2017-07-06 18:49:00+03	44400.00
B33592	2017-07-25 10:26:00+03	73600.00
B335A1	2017-08-03 04:55:00+03	12600.00
B335D4	2017-07-18 06:14:00+03	648300.00
B335E3	2017-07-20 02:17:00+03	189800.00
B33673	2017-07-08 11:43:00+03	27600.00
B33686	2017-08-06 06:07:00+03	22000.00
B336C1	2017-07-19 15:21:00+03	34000.00
B336FB	2017-06-29 04:03:00+03	185600.00
B33706	2017-07-27 16:05:00+03	62000.00
B3378F	2017-08-10 06:55:00+03	6300.00
B33847	2017-08-14 08:23:00+03	132800.00
B338C2	2017-07-11 03:45:00+03	75600.00
B338F4	2017-07-04 19:33:00+03	528000.00
B3390C	2017-07-11 22:05:00+03	29400.00
B33936	2017-07-19 21:38:00+03	14400.00
B33942	2017-07-23 20:53:00+03	57400.00
B33944	2017-08-01 13:36:00+03	123000.00
B33953	2017-07-23 14:49:00+03	119500.00
B3397B	2017-07-10 12:21:00+03	36800.00
B33984	2017-08-12 11:55:00+03	25400.00
B339DC	2017-08-01 14:20:00+03	24800.00
B339DF	2017-07-29 13:16:00+03	56000.00
B33A08	2017-08-14 02:28:00+03	96800.00
B33A4F	2017-07-13 10:14:00+03	135600.00
B33A5C	2017-07-18 11:57:00+03	45200.00
B33A92	2017-08-13 08:54:00+03	128400.00
B33B51	2017-07-05 09:36:00+03	22000.00
B33B70	2017-07-06 00:53:00+03	39200.00
B33BF1	2017-07-11 03:26:00+03	54400.00
B33C2A	2017-08-13 14:02:00+03	45200.00
B33C33	2017-08-05 08:05:00+03	12600.00
B33C49	2017-06-29 18:28:00+03	70700.00
B33CBD	2017-08-11 05:39:00+03	261100.00
B33D1D	2017-07-18 09:21:00+03	91600.00
B33D99	2017-07-20 17:34:00+03	84000.00
B33DCD	2017-08-03 17:30:00+03	193600.00
B33DDD	2017-08-04 13:16:00+03	53700.00
B33E06	2017-07-18 17:17:00+03	6400.00
B33E2A	2017-07-27 11:56:00+03	30400.00
B33E56	2017-07-27 15:06:00+03	29400.00
B33EF5	2017-07-05 06:17:00+03	46800.00
B33F00	2017-08-02 17:59:00+03	113100.00
B33F0E	2017-07-24 02:26:00+03	243700.00
B33FB0	2017-07-26 06:49:00+03	88900.00
B33FC4	2017-08-09 10:54:00+03	20200.00
B33FCD	2017-07-05 09:09:00+03	135600.00
B33FCF	2017-07-22 17:29:00+03	372500.00
B33FDB	2017-07-22 17:52:00+03	136500.00
B33FDF	2017-07-20 12:28:00+03	67400.00
B33FE3	2017-07-10 08:34:00+03	8000.00
B33FF5	2017-08-06 14:24:00+03	15800.00
B34000	2017-08-08 09:06:00+03	243600.00
B34006	2017-07-28 05:37:00+03	120700.00
B3400E	2017-08-10 00:14:00+03	123900.00
B34082	2017-07-14 05:41:00+03	44800.00
B34159	2017-07-30 13:40:00+03	24400.00
B3416E	2017-07-12 16:33:00+03	86400.00
B34170	2017-08-11 11:05:00+03	268000.00
B3418E	2017-07-06 22:16:00+03	39800.00
B3418F	2017-07-25 01:58:00+03	6700.00
B342B0	2017-07-12 12:24:00+03	28800.00
B342B4	2017-07-30 09:03:00+03	47200.00
B342BC	2017-07-28 02:58:00+03	100300.00
B342D2	2017-07-24 02:20:00+03	136200.00
B34310	2017-07-15 07:13:00+03	101800.00
B34312	2017-07-04 12:06:00+03	35700.00
B34316	2017-07-01 01:10:00+03	13000.00
B34317	2017-07-14 09:03:00+03	7400.00
B3431E	2017-08-12 19:00:00+03	75300.00
B34324	2017-07-28 15:30:00+03	34200.00
B3432C	2017-07-29 13:56:00+03	69000.00
B34340	2017-07-22 13:28:00+03	101200.00
B3440F	2017-07-05 03:07:00+03	25600.00
B34449	2017-07-11 09:34:00+03	31600.00
B344B9	2017-08-13 01:18:00+03	267100.00
B344EB	2017-08-11 01:20:00+03	32800.00
B34508	2017-08-03 16:46:00+03	195100.00
B3451C	2017-08-09 01:29:00+03	27000.00
B34539	2017-07-24 06:54:00+03	96300.00
B3455C	2017-07-08 07:51:00+03	43800.00
B34578	2017-08-05 07:15:00+03	62600.00
B3459D	2017-07-08 02:10:00+03	182700.00
B34647	2017-07-02 13:57:00+03	68000.00
B34673	2017-07-07 07:00:00+03	133100.00
B3467D	2017-08-05 06:59:00+03	27300.00
B346A0	2017-08-11 12:50:00+03	46000.00
B346EE	2017-08-11 15:57:00+03	88100.00
B3476B	2017-07-13 20:21:00+03	99800.00
B347C6	2017-07-24 19:59:00+03	114800.00
B347F4	2017-06-30 00:35:00+03	6000.00
B34838	2017-08-14 21:11:00+03	338800.00
B3488B	2017-08-02 03:26:00+03	86400.00
B348BA	2017-07-17 20:27:00+03	146300.00
B3491F	2017-07-14 14:42:00+03	124100.00
B34927	2017-07-28 02:37:00+03	73400.00
B349C3	2017-08-04 17:36:00+03	58600.00
B349C9	2017-07-24 12:35:00+03	295400.00
B349E4	2017-08-14 15:23:00+03	189200.00
B34A10	2017-08-11 06:33:00+03	98200.00
B34A1B	2017-07-11 22:55:00+03	861000.00
B34A23	2017-07-02 19:33:00+03	92800.00
B34A3B	2017-06-28 06:22:00+03	15400.00
B34ACC	2017-08-06 21:05:00+03	112000.00
B34AD7	2017-07-29 21:07:00+03	259000.00
B34AEE	2017-07-09 19:11:00+03	23600.00
B34AF5	2017-07-11 22:23:00+03	46800.00
B34B0A	2017-07-26 21:43:00+03	55800.00
B34B21	2017-08-05 18:43:00+03	240600.00
B34B49	2017-08-10 12:58:00+03	100200.00
B34B4A	2017-08-07 20:00:00+03	193200.00
B34B56	2017-08-09 11:56:00+03	23200.00
B34B89	2017-07-21 19:52:00+03	39500.00
B34C24	2017-07-25 14:38:00+03	26000.00
B34C6A	2017-08-06 08:56:00+03	17200.00
B34C9B	2017-07-14 12:30:00+03	57300.00
B34CC3	2017-08-10 06:30:00+03	63200.00
B34CC4	2017-07-06 05:29:00+03	27900.00
B34D88	2017-07-31 14:34:00+03	144600.00
B34D9E	2017-08-02 16:07:00+03	99700.00
B34DF9	2017-08-11 17:21:00+03	93900.00
B34E0B	2017-07-29 14:56:00+03	59800.00
B34E22	2017-08-14 22:00:00+03	47000.00
B34E71	2017-07-30 00:40:00+03	62000.00
B34E7F	2017-08-04 10:06:00+03	57800.00
B34EB6	2017-07-03 16:24:00+03	47100.00
B34F22	2017-07-25 21:16:00+03	70600.00
B34F4E	2017-07-11 06:01:00+03	95200.00
B34F5A	2017-08-13 05:51:00+03	91200.00
B34F9F	2017-07-15 08:56:00+03	64600.00
B34FA5	2017-07-03 05:26:00+03	290900.00
B34FCD	2017-07-26 20:02:00+03	22600.00
B34FEA	2017-07-31 01:47:00+03	336000.00
B34FED	2017-07-01 22:49:00+03	87800.00
B35131	2017-07-09 12:59:00+03	77000.00
B35137	2017-07-22 17:42:00+03	111600.00
B351CF	2017-07-03 06:26:00+03	48800.00
B351E5	2017-08-11 18:22:00+03	32100.00
B35216	2017-07-12 20:43:00+03	123000.00
B35221	2017-07-07 11:44:00+03	125700.00
B35269	2017-07-16 18:49:00+03	415000.00
B35368	2017-06-27 17:44:00+03	31400.00
B353EB	2017-07-04 19:54:00+03	74800.00
B3540A	2017-07-11 02:37:00+03	38800.00
B3540B	2017-07-28 11:43:00+03	103000.00
B35467	2017-07-21 09:58:00+03	20400.00
B35473	2017-07-15 13:50:00+03	14000.00
B354A3	2017-07-04 02:49:00+03	41200.00
B3551D	2017-07-22 17:28:00+03	40800.00
B3552B	2017-07-23 09:17:00+03	76400.00
B35531	2017-07-13 09:55:00+03	25100.00
B35556	2017-07-25 22:34:00+03	44800.00
B3555B	2017-07-21 14:53:00+03	7400.00
B35577	2017-07-27 03:05:00+03	396400.00
B355CE	2017-07-12 01:38:00+03	6800.00
B355D7	2017-08-11 15:39:00+03	70100.00
B355FB	2017-08-07 23:11:00+03	116400.00
B35616	2017-08-02 18:11:00+03	68400.00
B35628	2017-07-21 03:09:00+03	141300.00
B35641	2017-07-31 21:11:00+03	341200.00
B3565A	2017-07-31 08:12:00+03	270700.00
B356D3	2017-07-05 06:23:00+03	38600.00
B35749	2017-08-05 16:57:00+03	14400.00
B35796	2017-07-05 09:39:00+03	27200.00
B357AD	2017-07-04 05:34:00+03	56000.00
B357C5	2017-07-29 15:00:00+03	36200.00
B35819	2017-08-07 14:26:00+03	56600.00
B35845	2017-08-12 10:12:00+03	26700.00
B358BA	2017-07-03 08:41:00+03	44800.00
B359D7	2017-07-27 05:29:00+03	54900.00
B359F5	2017-07-15 02:44:00+03	132800.00
B35A80	2017-07-29 03:23:00+03	270800.00
B35A8E	2017-07-30 11:39:00+03	46200.00
B35ACE	2017-07-17 06:20:00+03	106800.00
B35ADC	2017-07-07 02:43:00+03	81200.00
B35BAF	2017-07-30 21:01:00+03	40800.00
B35BC3	2017-06-30 10:19:00+03	6600.00
B35BE4	2017-08-07 11:26:00+03	23200.00
B35C63	2017-08-06 19:58:00+03	386300.00
B35CD0	2017-08-03 12:20:00+03	40800.00
B35CDE	2017-07-30 13:10:00+03	12400.00
B35CE3	2017-07-29 08:22:00+03	21000.00
B35CE9	2017-08-06 11:31:00+03	30000.00
B35CF3	2017-08-09 02:31:00+03	26400.00
B35D04	2017-07-16 00:21:00+03	28800.00
B35D0F	2017-07-26 08:47:00+03	155500.00
B35D64	2017-07-07 14:38:00+03	69100.00
B35DCE	2017-07-30 03:53:00+03	77800.00
B35DD5	2017-08-03 16:17:00+03	100500.00
B35E0B	2017-06-29 08:25:00+03	24300.00
B35E87	2017-08-10 06:10:00+03	51600.00
B35EC8	2017-07-15 05:35:00+03	81300.00
B35EDA	2017-07-26 05:10:00+03	56100.00
B35EDC	2017-08-04 17:29:00+03	25600.00
B35F58	2017-07-20 03:30:00+03	45200.00
B35F5C	2017-07-16 16:12:00+03	34000.00
B35FCD	2017-07-06 15:16:00+03	60400.00
B35FE5	2017-08-13 20:15:00+03	18600.00
B36017	2017-08-07 22:07:00+03	59300.00
B3604D	2017-08-02 05:46:00+03	178800.00
B36065	2017-07-17 15:31:00+03	131100.00
B3609C	2017-07-24 21:54:00+03	38400.00
B360AF	2017-07-19 17:45:00+03	113900.00
B360E1	2017-08-05 00:42:00+03	111700.00
B36163	2017-07-21 15:22:00+03	23200.00
B36192	2017-08-04 17:52:00+03	80000.00
B361D7	2017-07-18 04:07:00+03	239800.00
B36282	2017-07-21 00:48:00+03	306200.00
B36289	2017-07-22 11:29:00+03	40400.00
B362C8	2017-07-04 19:00:00+03	29500.00
B36349	2017-08-11 07:41:00+03	135400.00
B36358	2017-07-26 01:50:00+03	29400.00
B36378	2017-08-03 01:08:00+03	46400.00
B363AA	2017-07-17 03:55:00+03	47400.00
B363F9	2017-08-01 18:52:00+03	311200.00
B36446	2017-07-22 19:14:00+03	58400.00
B364A4	2017-08-05 16:16:00+03	56900.00
B364CA	2017-07-13 16:02:00+03	101200.00
B3656B	2017-06-30 17:02:00+03	170800.00
B36571	2017-08-13 09:20:00+03	12600.00
B365AA	2017-07-30 12:13:00+03	28800.00
B36631	2017-07-12 12:35:00+03	21400.00
B36651	2017-08-07 17:19:00+03	27800.00
B36677	2017-07-19 07:12:00+03	59000.00
B36689	2017-07-22 06:09:00+03	114700.00
B366BB	2017-08-12 17:44:00+03	26800.00
B36706	2017-07-08 05:36:00+03	57500.00
B36709	2017-08-02 18:16:00+03	58200.00
B36748	2017-07-17 09:24:00+03	28800.00
B36776	2017-07-07 10:11:00+03	16400.00
B36814	2017-08-04 10:20:00+03	141300.00
B36829	2017-07-16 03:59:00+03	92900.00
B368AC	2017-07-17 05:16:00+03	47400.00
B36917	2017-07-05 17:21:00+03	225800.00
B36918	2017-08-14 00:27:00+03	86800.00
B3692D	2017-07-23 23:52:00+03	16000.00
B36957	2017-08-15 10:09:00+03	37200.00
B369A1	2017-07-23 09:14:00+03	31600.00
B369CD	2017-08-03 12:25:00+03	51600.00
B369D4	2017-07-16 02:28:00+03	132500.00
B369DC	2017-07-22 11:02:00+03	63300.00
B36A26	2017-07-16 15:53:00+03	78000.00
B36A36	2017-08-14 21:52:00+03	21400.00
B36A3D	2017-06-30 21:21:00+03	63900.00
B36A63	2017-06-30 15:37:00+03	99600.00
B36A9F	2017-07-19 01:23:00+03	95900.00
B36AB7	2017-07-16 13:43:00+03	85700.00
B36ADA	2017-07-24 01:26:00+03	134400.00
B36AE5	2017-07-18 09:59:00+03	52300.00
B36AFC	2017-07-14 11:35:00+03	8200.00
B36B3F	2017-08-06 12:33:00+03	8200.00
B36B84	2017-08-04 02:55:00+03	7400.00
B36C3B	2017-07-13 08:56:00+03	24400.00
B36C60	2017-07-01 06:24:00+03	28000.00
B36C6D	2017-08-11 01:39:00+03	54000.00
B36C75	2017-08-07 12:57:00+03	37100.00
B36CD8	2017-08-02 21:57:00+03	531300.00
B36CF9	2017-07-23 00:39:00+03	81300.00
B36D0F	2017-06-30 05:44:00+03	51200.00
B36D28	2017-06-30 18:59:00+03	39200.00
B36D33	2017-08-14 16:07:00+03	46000.00
B36D5E	2017-08-09 01:07:00+03	340600.00
B36D68	2017-07-26 10:10:00+03	41200.00
B36D90	2017-07-24 17:58:00+03	37800.00
B36DC7	2017-07-04 10:43:00+03	81600.00
B36DDF	2017-08-01 23:20:00+03	60400.00
B36DF9	2017-07-04 18:34:00+03	6800.00
B36E01	2017-07-05 15:21:00+03	23600.00
B36E1B	2017-07-20 17:37:00+03	48800.00
B36E4D	2017-08-01 09:15:00+03	100600.00
B36E71	2017-07-29 04:56:00+03	65900.00
B36EA9	2017-08-05 06:32:00+03	94900.00
B36EC4	2017-07-16 10:04:00+03	136200.00
B36EEF	2017-08-13 02:57:00+03	35200.00
B36F2F	2017-07-12 23:04:00+03	55800.00
B36F5D	2017-08-05 16:19:00+03	40600.00
B36F74	2017-08-08 05:23:00+03	54800.00
B36FFE	2017-07-14 16:47:00+03	136200.00
B3700D	2017-08-10 09:50:00+03	38400.00
B3701B	2017-07-21 08:46:00+03	57300.00
B37038	2017-07-14 16:42:00+03	27300.00
B37066	2017-07-13 23:47:00+03	273400.00
B37082	2017-07-09 02:34:00+03	28000.00
B370AD	2017-08-02 10:40:00+03	25600.00
B37110	2017-07-08 03:54:00+03	382200.00
B37128	2017-08-08 02:01:00+03	13200.00
B371B4	2017-07-17 23:54:00+03	116000.00
B372AA	2017-07-30 03:10:00+03	22100.00
B372E8	2017-07-18 17:27:00+03	246000.00
B37368	2017-07-10 08:18:00+03	70800.00
B37376	2017-08-07 04:06:00+03	131600.00
B37433	2017-08-01 05:31:00+03	6700.00
B37464	2017-08-04 16:46:00+03	16400.00
B3747B	2017-07-18 21:16:00+03	16800.00
B37483	2017-08-01 07:08:00+03	8400.00
B374BB	2017-07-09 11:29:00+03	170000.00
B374BE	2017-08-05 22:25:00+03	21400.00
B374DD	2017-07-20 05:02:00+03	12200.00
B37504	2017-07-30 22:48:00+03	369000.00
B37574	2017-07-08 12:25:00+03	59000.00
B37586	2017-08-12 16:38:00+03	25400.00
B37653	2017-07-09 18:44:00+03	131100.00
B376B7	2017-07-07 07:37:00+03	35700.00
B37710	2017-07-20 19:31:00+03	187800.00
B37788	2017-08-10 05:55:00+03	22600.00
B377C4	2017-08-13 11:21:00+03	16400.00
B377DE	2017-07-01 01:38:00+03	62200.00
B3781B	2017-08-15 12:48:00+03	33000.00
B378CF	2017-08-08 16:02:00+03	138500.00
B37902	2017-07-13 00:45:00+03	52300.00
B37915	2017-07-24 13:37:00+03	27200.00
B3795D	2017-08-06 06:50:00+03	46200.00
B3798C	2017-07-29 14:31:00+03	135400.00
B379F6	2017-08-14 06:52:00+03	96300.00
B379FC	2017-07-22 11:45:00+03	62600.00
B37A18	2017-07-27 11:40:00+03	13400.00
B37A2F	2017-08-09 20:54:00+03	55800.00
B37ACD	2017-07-10 00:58:00+03	25800.00
B37ADB	2017-08-11 14:19:00+03	51600.00
B37AFB	2017-07-31 12:03:00+03	36200.00
B37B89	2017-07-30 17:22:00+03	89700.00
B37B98	2017-08-13 09:14:00+03	124600.00
B37BF8	2017-07-26 04:55:00+03	46400.00
B37C4C	2017-07-23 07:56:00+03	133200.00
B37C69	2017-07-02 22:35:00+03	28000.00
B37CCE	2017-07-16 09:50:00+03	58200.00
B37D0C	2017-07-30 22:45:00+03	116400.00
B37D10	2017-08-04 04:39:00+03	46300.00
B37D23	2017-08-07 22:51:00+03	26800.00
B37DA8	2017-08-11 12:48:00+03	77200.00
B37DAD	2017-07-25 11:20:00+03	378400.00
B37DC4	2017-07-05 21:26:00+03	107300.00
B37E3C	2017-07-25 19:21:00+03	73100.00
B37EA4	2017-07-13 04:35:00+03	44800.00
B37ED1	2017-07-05 03:12:00+03	280600.00
B37F64	2017-08-11 06:51:00+03	25600.00
B37FC5	2017-08-13 01:34:00+03	135400.00
B38059	2017-08-09 03:39:00+03	409800.00
B3806C	2017-07-27 17:12:00+03	25100.00
B38071	2017-07-19 04:35:00+03	48700.00
B380B7	2017-08-09 22:28:00+03	26700.00
B38115	2017-07-18 23:04:00+03	55800.00
B38124	2017-08-12 20:56:00+03	95200.00
B38179	2017-07-11 20:39:00+03	147700.00
B381BB	2017-08-15 15:16:00+03	114800.00
B381D7	2017-07-02 20:31:00+03	97700.00
B38229	2017-07-03 02:52:00+03	56000.00
B3823C	2017-07-19 06:41:00+03	8400.00
B3829B	2017-07-03 20:08:00+03	81700.00
B3832D	2017-07-11 00:24:00+03	46000.00
B38336	2017-07-22 22:31:00+03	136800.00
B383D3	2017-06-29 07:18:00+03	48800.00
B38450	2017-07-19 07:08:00+03	242700.00
B38459	2017-07-17 22:37:00+03	187500.00
B384C1	2017-08-06 12:10:00+03	36200.00
B384EE	2017-08-02 14:31:00+03	68800.00
B38511	2017-08-13 02:32:00+03	27900.00
B385EF	2017-07-19 07:00:00+03	54300.00
B3860D	2017-08-02 13:48:00+03	89700.00
B3868C	2017-08-10 15:58:00+03	123000.00
B38709	2017-07-04 10:52:00+03	29100.00
B38713	2017-08-10 04:43:00+03	99300.00
B3879D	2017-07-05 01:31:00+03	76800.00
B387EC	2017-07-05 04:07:00+03	28800.00
B38830	2017-07-27 22:29:00+03	25400.00
B38854	2017-08-15 02:05:00+03	248400.00
B3886E	2017-08-06 17:50:00+03	40600.00
B38877	2017-08-11 14:42:00+03	75600.00
B388E0	2017-07-01 10:48:00+03	43800.00
B38933	2017-07-15 09:08:00+03	135400.00
B38956	2017-07-26 22:54:00+03	6900.00
B389BF	2017-07-04 04:59:00+03	111900.00
B389D4	2017-07-18 03:25:00+03	37900.00
B389D8	2017-07-15 12:33:00+03	10600.00
B38A20	2017-08-02 18:21:00+03	47000.00
B38A28	2017-08-04 12:22:00+03	108000.00
B38A4A	2017-07-21 23:09:00+03	23200.00
B38A80	2017-07-11 04:01:00+03	134800.00
B38AA7	2017-07-31 14:37:00+03	12400.00
B38AE3	2017-07-09 23:37:00+03	46300.00
B38AE7	2017-07-03 23:50:00+03	71000.00
B38B29	2017-08-14 23:37:00+03	102300.00
B38BD0	2017-07-25 11:23:00+03	68800.00
B38C21	2017-07-18 01:26:00+03	27200.00
B38C64	2017-06-30 18:30:00+03	51600.00
B38CB9	2017-07-01 05:43:00+03	68100.00
B38CFF	2017-08-12 15:26:00+03	34800.00
B38D49	2017-07-17 18:45:00+03	44600.00
B38D91	2017-07-29 12:12:00+03	62600.00
B38E08	2017-07-08 23:33:00+03	58800.00
B38E0A	2017-07-10 02:37:00+03	136200.00
B38E2A	2017-07-18 08:29:00+03	228700.00
B38E47	2017-07-07 20:03:00+03	6400.00
B38E6D	2017-08-05 10:17:00+03	23200.00
B38EA8	2017-07-29 07:01:00+03	126300.00
B38EB7	2017-08-03 02:17:00+03	52000.00
B38F0F	2017-07-03 07:33:00+03	369000.00
B38F3C	2017-07-11 02:56:00+03	46200.00
B38F72	2017-07-20 10:41:00+03	57600.00
B38FCF	2017-06-30 15:31:00+03	167400.00
B38FE0	2017-07-30 20:43:00+03	79600.00
B38FFE	2017-08-04 06:20:00+03	74200.00
B39022	2017-08-14 03:28:00+03	19600.00
B39023	2017-08-13 02:21:00+03	35600.00
B39074	2017-08-04 10:56:00+03	6700.00
B390BB	2017-07-11 04:01:00+03	157200.00
B39122	2017-08-12 21:15:00+03	50200.00
B39149	2017-07-21 14:33:00+03	266400.00
B3914A	2017-07-06 13:15:00+03	189700.00
B39173	2017-08-02 13:38:00+03	46400.00
B3919B	2017-08-09 10:26:00+03	22000.00
B391BF	2017-07-27 13:35:00+03	26000.00
B39240	2017-08-01 21:15:00+03	12400.00
B39265	2017-07-28 02:22:00+03	131200.00
B392F4	2017-07-15 10:16:00+03	26000.00
B392FD	2017-08-11 06:52:00+03	179400.00
B39313	2017-08-09 21:24:00+03	67600.00
B39367	2017-08-06 18:06:00+03	20800.00
B393C0	2017-07-18 05:23:00+03	92900.00
B393E2	2017-07-12 08:57:00+03	69900.00
B39423	2017-07-09 03:56:00+03	168000.00
B39442	2017-07-21 09:55:00+03	14400.00
B3947A	2017-08-10 01:32:00+03	64200.00
B394BB	2017-07-30 20:51:00+03	22000.00
B39586	2017-07-17 18:09:00+03	22400.00
B395DB	2017-08-07 06:39:00+03	57800.00
B395E1	2017-08-02 03:45:00+03	51800.00
B395EE	2017-07-31 13:41:00+03	52600.00
B395F8	2017-06-30 19:22:00+03	40100.00
B39690	2017-07-19 15:32:00+03	7400.00
B396B6	2017-07-09 01:38:00+03	28800.00
B396E6	2017-07-08 09:08:00+03	52800.00
B3971E	2017-08-05 17:16:00+03	43000.00
B3978D	2017-08-04 17:19:00+03	25200.00
B39825	2017-08-07 16:05:00+03	46400.00
B39842	2017-08-01 17:38:00+03	43200.00
B39860	2017-07-21 03:13:00+03	43000.00
B3993B	2017-08-07 07:03:00+03	65800.00
B39986	2017-07-11 17:01:00+03	217600.00
B399F0	2017-07-19 07:17:00+03	14800.00
B399FE	2017-07-06 10:18:00+03	68900.00
B39A73	2017-07-19 14:36:00+03	123200.00
B39AA8	2017-07-31 20:39:00+03	131600.00
B39AC4	2017-07-31 06:16:00+03	116400.00
B39AE0	2017-07-29 16:52:00+03	42700.00
B39B16	2017-07-29 20:25:00+03	54800.00
B39B1A	2017-07-24 16:09:00+03	148200.00
B39B1C	2017-07-31 10:14:00+03	89700.00
B39B50	2017-07-31 00:18:00+03	87000.00
B39B58	2017-07-21 22:48:00+03	34800.00
B39B74	2017-07-10 03:42:00+03	31100.00
B39BCB	2017-07-15 10:18:00+03	67200.00
B39C08	2017-08-03 02:34:00+03	113200.00
B39C2D	2017-07-31 19:12:00+03	68100.00
B39C57	2017-07-23 05:07:00+03	31400.00
B39C7A	2017-07-07 13:47:00+03	55800.00
B39C99	2017-08-06 23:00:00+03	7400.00
B39CF8	2017-08-10 14:43:00+03	43500.00
B39D95	2017-07-22 20:53:00+03	55800.00
B39DA4	2017-08-03 15:59:00+03	29600.00
B39DC2	2017-08-11 07:41:00+03	94900.00
B39DEC	2017-07-09 19:02:00+03	23600.00
B39E06	2017-07-18 19:49:00+03	75300.00
B39E66	2017-07-02 21:15:00+03	18000.00
B39F02	2017-07-30 09:57:00+03	86600.00
B39F58	2017-07-25 15:44:00+03	46300.00
B39F7F	2017-07-11 03:35:00+03	18900.00
B39FE4	2017-07-21 23:24:00+03	54400.00
B3A046	2017-08-07 07:40:00+03	32200.00
B3A090	2017-07-27 01:09:00+03	46300.00
B3A0C0	2017-07-03 03:12:00+03	50600.00
B3A0D3	2017-07-07 14:24:00+03	12400.00
B3A0D9	2017-08-13 23:01:00+03	14400.00
B3A13C	2017-07-27 11:31:00+03	111600.00
B3A184	2017-07-05 00:56:00+03	127900.00
B3A18F	2017-07-16 16:42:00+03	29600.00
B3A1EE	2017-07-09 18:16:00+03	149100.00
B3A255	2017-08-07 03:12:00+03	156300.00
B3A349	2017-07-24 17:08:00+03	187800.00
B3A380	2017-07-12 16:46:00+03	301800.00
B3A3C6	2017-07-16 21:52:00+03	21400.00
B3A421	2017-06-29 16:18:00+03	137900.00
B3A424	2017-08-04 01:08:00+03	131600.00
B3A43F	2017-07-02 03:03:00+03	56000.00
B3A4A3	2017-07-26 17:13:00+03	39300.00
B3A4A6	2017-08-02 11:16:00+03	199400.00
B3A4B6	2017-07-21 22:02:00+03	36400.00
B3A4D5	2017-07-21 21:10:00+03	13400.00
B3A4E3	2017-07-11 10:36:00+03	56600.00
B3A523	2017-07-09 16:54:00+03	64200.00
B3A603	2017-08-14 03:25:00+03	21200.00
B3A607	2017-07-12 16:19:00+03	18600.00
B3A64F	2017-06-30 02:21:00+03	46000.00
B3A66C	2017-07-22 07:52:00+03	496600.00
B3A68F	2017-08-14 16:20:00+03	89600.00
B3A6EA	2017-08-02 23:07:00+03	170000.00
B3A736	2017-07-20 20:32:00+03	74300.00
B3A748	2017-08-07 04:02:00+03	27500.00
B3A74E	2017-07-12 03:27:00+03	21400.00
B3A7B4	2017-07-13 16:35:00+03	131100.00
B3A7D0	2017-07-12 21:09:00+03	82900.00
B3A812	2017-07-28 03:53:00+03	46300.00
B3A859	2017-07-24 18:13:00+03	117200.00
B3A88C	2017-07-31 18:53:00+03	185800.00
B3A8B0	2017-07-13 15:35:00+03	252200.00
B3A926	2017-07-03 11:31:00+03	92000.00
B3AA52	2017-08-10 19:32:00+03	34000.00
B3AA5C	2017-07-21 15:09:00+03	54000.00
B3AA6C	2017-07-24 13:51:00+03	112400.00
B3AACE	2017-08-04 11:25:00+03	31600.00
B3AAE1	2017-07-22 15:34:00+03	29600.00
B3AAF6	2017-07-04 13:23:00+03	73300.00
B3AB30	2017-08-08 18:08:00+03	52000.00
B3AB69	2017-06-30 12:27:00+03	29600.00
B3AB9F	2017-07-08 02:46:00+03	72400.00
B3ABB7	2017-07-31 03:17:00+03	55800.00
B3ABDA	2017-07-12 08:32:00+03	23600.00
B3AC7F	2017-07-22 04:41:00+03	32800.00
B3ACAC	2017-08-01 16:02:00+03	39100.00
B3ACFB	2017-08-08 20:23:00+03	121400.00
B3AD28	2017-07-19 22:13:00+03	25400.00
B3AD93	2017-07-20 18:07:00+03	102100.00
B3ADD8	2017-07-23 20:21:00+03	26200.00
B3ADE8	2017-08-13 10:29:00+03	57600.00
B3AE68	2017-07-22 00:45:00+03	52700.00
B3AE7A	2017-07-11 17:25:00+03	36200.00
B3AEB6	2017-07-25 22:50:00+03	88600.00
B3AEEF	2017-07-16 10:49:00+03	40800.00
B3AEF2	2017-07-27 16:02:00+03	136500.00
B3AF00	2017-08-04 00:28:00+03	137600.00
B3AFB3	2017-08-08 14:06:00+03	76300.00
B3B09C	2017-07-12 03:51:00+03	21400.00
B3B0C5	2017-07-01 04:18:00+03	65400.00
B3B109	2017-07-07 17:28:00+03	52300.00
B3B12D	2017-07-10 05:08:00+03	166000.00
B3B149	2017-07-03 07:46:00+03	136800.00
B3B1CD	2017-07-11 17:26:00+03	112100.00
B3B21C	2017-07-09 12:20:00+03	26000.00
B3B25F	2017-08-07 15:37:00+03	59800.00
B3B266	2017-08-06 14:50:00+03	28800.00
B3B34B	2017-07-10 22:40:00+03	20400.00
B3B36F	2017-08-10 18:22:00+03	48100.00
B3B37B	2017-07-22 03:07:00+03	18600.00
B3B3D5	2017-07-22 12:09:00+03	70500.00
B3B407	2017-07-09 05:09:00+03	265700.00
B3B41E	2017-07-17 04:14:00+03	26000.00
B3B42B	2017-08-03 07:46:00+03	40000.00
B3B48B	2017-08-13 15:17:00+03	6700.00
B3B4F6	2017-07-10 15:13:00+03	12000.00
B3B568	2017-07-24 15:29:00+03	223200.00
B3B588	2017-07-07 10:20:00+03	73300.00
B3B5D4	2017-07-13 06:42:00+03	155300.00
B3B5E8	2017-07-30 21:38:00+03	36200.00
B3B61D	2017-06-29 12:30:00+03	22000.00
B3B626	2017-07-25 08:50:00+03	138900.00
B3B685	2017-07-15 20:36:00+03	265800.00
B3B6D6	2017-07-06 13:17:00+03	62600.00
B3B70A	2017-08-03 13:31:00+03	49100.00
B3B78A	2017-07-05 13:20:00+03	36000.00
B3B7A3	2017-08-06 07:25:00+03	140800.00
B3B846	2017-06-30 14:30:00+03	6000.00
B3B89B	2017-08-07 19:58:00+03	45300.00
B3B959	2017-07-25 05:07:00+03	79600.00
B3B9A0	2017-08-10 18:26:00+03	47400.00
B3B9FA	2017-07-25 22:37:00+03	136800.00
B3BA3A	2017-07-27 04:36:00+03	62600.00
B3BA7D	2017-08-01 21:00:00+03	57600.00
B3BAC7	2017-07-10 22:28:00+03	19600.00
B3BB38	2017-07-28 16:51:00+03	14400.00
B3BB6F	2017-07-28 22:18:00+03	54800.00
B3BB7F	2017-08-03 19:25:00+03	149600.00
B3BBA1	2017-08-09 02:47:00+03	44000.00
B3BBAA	2017-07-06 17:08:00+03	83700.00
B3BC27	2017-08-03 10:34:00+03	56000.00
B3BC4B	2017-08-03 19:41:00+03	131100.00
B3BC66	2017-07-11 02:56:00+03	40200.00
B3BD33	2017-07-11 18:19:00+03	56200.00
B3BD74	2017-07-03 00:51:00+03	66600.00
B3BDE6	2017-08-14 16:49:00+03	28300.00
B3BE17	2017-08-02 02:25:00+03	28800.00
B3BE58	2017-07-16 16:11:00+03	22000.00
B3BEAB	2017-08-15 09:38:00+03	19300.00
B3BEAE	2017-07-31 23:45:00+03	61900.00
B3BEB7	2017-07-27 02:38:00+03	26500.00
B3BEC5	2017-07-11 23:29:00+03	123000.00
B3BED5	2017-07-02 12:20:00+03	26000.00
B3BF6B	2017-08-13 00:42:00+03	123000.00
B3BF81	2017-07-25 01:19:00+03	101100.00
B3BFF6	2017-07-29 22:19:00+03	15000.00
B3C018	2017-07-19 08:10:00+03	32800.00
B3C02F	2017-08-08 04:15:00+03	98400.00
B3C054	2017-07-04 19:36:00+03	70800.00
B3C064	2017-07-16 15:54:00+03	26200.00
B3C0CB	2017-07-05 18:53:00+03	123000.00
B3C0F3	2017-08-11 10:32:00+03	189200.00
B3C102	2017-08-13 18:13:00+03	100200.00
B3C189	2017-07-27 05:00:00+03	199700.00
B3C255	2017-07-23 02:38:00+03	112000.00
B3C301	2017-07-25 20:18:00+03	92700.00
B3C31F	2017-07-12 02:37:00+03	54400.00
B3C39A	2017-08-15 04:36:00+03	131600.00
B3C42F	2017-08-02 19:48:00+03	24800.00
B3C452	2017-08-05 07:29:00+03	46200.00
B3C45A	2017-08-08 17:14:00+03	260300.00
B3C4B1	2017-08-13 20:49:00+03	62600.00
B3C4F2	2017-07-23 03:31:00+03	83600.00
B3C52D	2017-08-12 20:08:00+03	16400.00
B3C554	2017-08-08 20:26:00+03	39200.00
B3C596	2017-07-06 01:33:00+03	56600.00
B3C5C1	2017-07-26 11:53:00+03	45500.00
B3C5E3	2017-08-01 23:57:00+03	23400.00
B3C5E9	2017-08-01 23:09:00+03	68800.00
B3C5EA	2017-07-30 16:53:00+03	27800.00
B3C603	2017-08-12 21:30:00+03	15000.00
B3C648	2017-07-26 13:03:00+03	124200.00
B3C65F	2017-08-02 04:55:00+03	52000.00
B3C66E	2017-07-31 19:26:00+03	14400.00
B3C680	2017-08-12 05:27:00+03	52800.00
B3C715	2017-07-18 18:21:00+03	67600.00
B3C741	2017-07-16 02:58:00+03	64100.00
B3C7A7	2017-08-09 00:05:00+03	36200.00
B3C802	2017-08-02 07:16:00+03	48800.00
B3C810	2017-08-12 20:09:00+03	43200.00
B3C85E	2017-07-02 08:26:00+03	6000.00
B3C886	2017-07-26 09:05:00+03	176800.00
B3C8D6	2017-07-22 02:34:00+03	30200.00
B3C93C	2017-08-07 08:51:00+03	74900.00
B3C987	2017-07-27 14:02:00+03	185700.00
B3C996	2017-07-12 18:41:00+03	69500.00
B3C9BB	2017-08-14 09:08:00+03	172100.00
B3C9C8	2017-08-11 14:28:00+03	12600.00
B3CA60	2017-07-24 19:24:00+03	12600.00
B3CA98	2017-07-23 18:27:00+03	125200.00
B3CAAD	2017-08-07 07:40:00+03	32800.00
B3CAF0	2017-07-27 14:31:00+03	58200.00
B3CB41	2017-07-03 00:49:00+03	32700.00
B3CB97	2017-07-30 03:08:00+03	27300.00
B3CBBF	2017-08-05 13:02:00+03	65900.00
B3CBDC	2017-07-16 03:29:00+03	158700.00
B3CC29	2017-08-15 10:34:00+03	21800.00
B3CCB9	2017-07-22 17:14:00+03	136800.00
B3CD56	2017-08-07 08:16:00+03	55800.00
B3CD75	2017-06-30 10:34:00+03	46800.00
B3CE3D	2017-07-29 04:34:00+03	30200.00
B3CEB3	2017-07-26 15:36:00+03	92200.00
B3CEBB	2017-07-27 02:08:00+03	25800.00
B3CEEE	2017-07-08 12:37:00+03	136500.00
B3CF11	2017-07-25 11:16:00+03	47400.00
B3CF51	2017-06-29 05:27:00+03	185300.00
B3CF5C	2017-07-21 11:08:00+03	148900.00
B3CF92	2017-07-08 06:16:00+03	103500.00
B3CFFC	2017-07-30 08:50:00+03	51900.00
B3D032	2017-07-15 14:43:00+03	150600.00
B3D069	2017-07-11 01:02:00+03	114300.00
B3D06B	2017-07-01 11:49:00+03	46200.00
B3D090	2017-06-26 18:46:00+03	60400.00
B3D0BE	2017-08-07 13:18:00+03	8200.00
B3D112	2017-08-06 09:36:00+03	26200.00
B3D16E	2017-08-04 11:59:00+03	28000.00
B3D1BC	2017-07-08 10:09:00+03	19000.00
B3D1ED	2017-07-12 18:43:00+03	21800.00
B3D2A9	2017-07-24 23:03:00+03	69000.00
B3D2B9	2017-07-15 03:32:00+03	15700.00
B3D2D0	2017-06-28 11:05:00+03	56000.00
B3D3A6	2017-07-14 01:35:00+03	61800.00
B3D3D2	2017-07-30 01:36:00+03	32700.00
B3D431	2017-08-09 04:22:00+03	55800.00
B3D48E	2017-07-31 02:32:00+03	57500.00
B3D490	2017-08-07 12:37:00+03	67000.00
B3D4B5	2017-08-04 23:27:00+03	56600.00
B3D54B	2017-08-07 02:01:00+03	44800.00
B3D605	2017-06-28 06:58:00+03	70700.00
B3D606	2017-07-18 06:52:00+03	8200.00
B3D60A	2017-07-09 09:14:00+03	41100.00
B3D685	2017-07-25 11:52:00+03	199600.00
B3D6DC	2017-07-12 18:13:00+03	84500.00
B3D71C	2017-07-08 23:53:00+03	115600.00
B3D774	2017-08-01 03:21:00+03	33300.00
B3D7A5	2017-07-19 16:16:00+03	135600.00
B3D814	2017-07-10 17:55:00+03	30200.00
B3D867	2017-08-03 17:17:00+03	67000.00
B3D895	2017-06-30 06:59:00+03	39800.00
B3D8A1	2017-07-25 16:44:00+03	89600.00
B3D8E9	2017-08-13 18:35:00+03	85000.00
B3D93D	2017-07-06 07:38:00+03	16400.00
B3D97A	2017-08-01 18:41:00+03	54800.00
B3D985	2017-07-19 13:42:00+03	72400.00
B3D99F	2017-07-13 09:26:00+03	26000.00
B3D9B0	2017-08-06 13:03:00+03	63700.00
B3D9BE	2017-07-12 03:11:00+03	58000.00
B3D9D5	2017-07-01 22:10:00+03	43200.00
B3D9EA	2017-07-31 21:13:00+03	40800.00
B3DA05	2017-07-16 21:57:00+03	61100.00
B3DA14	2017-06-30 08:33:00+03	83200.00
B3DA16	2017-06-28 04:42:00+03	14400.00
B3DA2D	2017-07-05 18:44:00+03	61800.00
B3DA36	2017-07-07 19:37:00+03	47000.00
B3DABE	2017-07-27 02:21:00+03	50500.00
B3DAD2	2017-08-14 15:58:00+03	6200.00
B3DAF2	2017-07-19 17:34:00+03	166100.00
B3DAFF	2017-07-15 17:00:00+03	70800.00
B3DB44	2017-08-10 04:48:00+03	163200.00
B3DB61	2017-07-11 21:54:00+03	46400.00
B3DBD7	2017-07-26 13:22:00+03	40400.00
B3DC3C	2017-06-24 03:05:00+03	26600.00
B3DC8D	2017-07-27 16:36:00+03	88200.00
B3DD0C	2017-08-11 15:42:00+03	114800.00
B3DD35	2017-07-21 12:56:00+03	61900.00
B3DD5B	2017-08-04 19:36:00+03	111600.00
B3DDA4	2017-08-14 10:16:00+03	89600.00
B3DE71	2017-07-05 21:12:00+03	84100.00
B3DE98	2017-07-14 14:40:00+03	115700.00
B3DEB4	2017-07-24 15:14:00+03	58400.00
B3DF05	2017-07-04 04:18:00+03	30800.00
B3DF41	2017-07-28 19:56:00+03	332100.00
B3DF5D	2017-07-06 13:52:00+03	83900.00
B3DF88	2017-08-05 03:06:00+03	20400.00
B3DFFC	2017-07-14 07:05:00+03	30200.00
B3E06E	2017-08-03 15:14:00+03	16400.00
B3E081	2017-07-02 10:33:00+03	17200.00
B3E0CB	2017-07-01 15:41:00+03	44500.00
B3E0CF	2017-08-14 16:50:00+03	50300.00
B3E122	2017-08-09 02:22:00+03	31600.00
B3E131	2017-07-21 14:00:00+03	14000.00
B3E139	2017-07-31 01:57:00+03	30400.00
B3E13F	2017-08-15 10:58:00+03	24400.00
B3E196	2017-08-10 15:21:00+03	146400.00
B3E1E6	2017-07-27 11:46:00+03	40300.00
B3E200	2017-07-22 11:25:00+03	86400.00
B3E202	2017-07-09 19:55:00+03	14000.00
B3E269	2017-08-11 04:19:00+03	116000.00
B3E2A6	2017-08-10 09:18:00+03	52300.00
B3E2EE	2017-08-09 20:35:00+03	135400.00
B3E311	2017-07-06 22:03:00+03	106100.00
B3E3B3	2017-07-31 12:05:00+03	516800.00
B3E3B6	2017-07-18 08:11:00+03	23400.00
B3E42B	2017-07-01 10:31:00+03	75800.00
B3E4A4	2017-07-24 00:17:00+03	100600.00
B3E504	2017-07-23 16:41:00+03	57600.00
B3E52E	2017-07-21 09:35:00+03	16400.00
B3E547	2017-08-13 08:06:00+03	46800.00
B3E58D	2017-07-23 06:34:00+03	46400.00
B3E5C0	2017-07-17 04:18:00+03	68100.00
B3E5EF	2017-07-13 18:25:00+03	64600.00
B3E605	2017-07-11 16:53:00+03	59300.00
B3E608	2017-08-01 08:11:00+03	54800.00
B3E622	2017-07-03 05:29:00+03	7400.00
B3E64A	2017-08-14 00:40:00+03	66000.00
B3E66E	2017-08-12 06:51:00+03	84100.00
B3E72A	2017-07-09 06:42:00+03	58200.00
B3E758	2017-07-04 17:34:00+03	19600.00
B3E791	2017-08-09 11:07:00+03	48500.00
B3E7A3	2017-08-05 12:58:00+03	69500.00
B3E83E	2017-08-10 13:23:00+03	43200.00
B3E869	2017-07-14 11:57:00+03	116000.00
B3E8AC	2017-07-02 12:42:00+03	27200.00
B3E8CF	2017-07-04 02:36:00+03	88500.00
B3E8F4	2017-08-12 14:33:00+03	68600.00
B3E909	2017-07-19 07:12:00+03	22000.00
B3E90A	2017-07-16 12:04:00+03	165800.00
B3E91C	2017-08-11 08:13:00+03	199200.00
B3E94B	2017-07-10 14:10:00+03	124300.00
B3E9C9	2017-08-11 10:24:00+03	39200.00
B3E9D7	2017-08-05 07:30:00+03	46000.00
B3EA42	2017-08-14 01:39:00+03	48800.00
B3EA9D	2017-07-10 14:50:00+03	29600.00
B3EAEA	2017-07-21 09:17:00+03	46000.00
B3EAFE	2017-07-09 17:03:00+03	143900.00
B3EB19	2017-07-25 23:05:00+03	6800.00
B3EB49	2017-08-08 05:20:00+03	212800.00
B3EB4B	2017-07-19 02:08:00+03	61200.00
B3EB90	2017-07-12 21:48:00+03	28800.00
B3EBA7	2017-08-07 20:00:00+03	98400.00
B3EC74	2017-07-28 08:26:00+03	69900.00
B3ED22	2017-07-15 15:39:00+03	96800.00
B3ED3C	2017-07-04 07:33:00+03	42800.00
B3ED86	2017-08-02 22:59:00+03	6800.00
B3ED8C	2017-08-03 21:17:00+03	38200.00
B3EE38	2017-07-16 22:43:00+03	47000.00
B3EE9C	2017-07-14 01:32:00+03	27300.00
B3EEAC	2017-07-24 15:17:00+03	44200.00
B3EF2C	2017-07-06 06:34:00+03	133100.00
B3F04F	2017-07-18 00:47:00+03	55800.00
B3F05D	2017-07-08 17:10:00+03	68100.00
B3F0B7	2017-07-15 07:50:00+03	88900.00
B3F0BD	2017-08-02 16:46:00+03	6700.00
B3F0C8	2017-07-16 02:40:00+03	266400.00
B3F0E5	2017-07-26 06:59:00+03	44000.00
B3F180	2017-08-02 09:56:00+03	36200.00
B3F221	2017-07-28 05:44:00+03	248500.00
B3F263	2017-08-04 01:09:00+03	135300.00
B3F276	2017-07-30 18:09:00+03	64400.00
B3F27D	2017-07-27 16:37:00+03	67600.00
B3F289	2017-07-03 05:03:00+03	19600.00
B3F343	2017-07-19 06:12:00+03	127200.00
B3F378	2017-08-13 03:07:00+03	8000.00
B3F3E9	2017-08-02 11:04:00+03	136500.00
B3F3F8	2017-08-08 06:15:00+03	54100.00
B3F483	2017-07-31 05:09:00+03	36000.00
B3F4B3	2017-08-01 12:04:00+03	36200.00
B3F4C5	2017-07-02 23:42:00+03	38800.00
B3F4D2	2017-07-14 22:45:00+03	24400.00
B3F520	2017-08-05 04:01:00+03	40000.00
B3F57B	2017-06-29 08:07:00+03	56000.00
B3F5E4	2017-07-05 12:12:00+03	14000.00
B3F600	2017-07-25 17:02:00+03	50000.00
B3F606	2017-07-30 05:43:00+03	133200.00
B3F628	2017-08-08 01:16:00+03	10700.00
B3F63D	2017-07-04 13:00:00+03	76600.00
B3F661	2017-07-04 21:26:00+03	86600.00
B3F6A8	2017-07-29 10:05:00+03	173100.00
B3F6E1	2017-07-15 11:21:00+03	47200.00
B3F6ED	2017-08-11 13:18:00+03	271100.00
B3F6FC	2017-07-18 12:33:00+03	102100.00
B3F72F	2017-07-17 10:09:00+03	92800.00
B3F75A	2017-08-07 01:21:00+03	38800.00
B3F7B1	2017-07-21 10:36:00+03	45200.00
B3F7C1	2017-07-09 21:00:00+03	34600.00
B3F844	2017-07-07 15:48:00+03	21400.00
B3F8A0	2017-08-05 04:31:00+03	28000.00
B3F8DC	2017-07-08 21:03:00+03	86300.00
B3F8E9	2017-06-30 08:36:00+03	29800.00
B3F90E	2017-07-24 12:28:00+03	11600.00
B3F937	2017-07-16 21:54:00+03	398500.00
B3F96C	2017-07-04 10:40:00+03	133200.00
B3F974	2017-07-19 16:44:00+03	83000.00
B3F9E8	2017-08-10 20:38:00+03	23200.00
B3FA7E	2017-07-21 05:07:00+03	199700.00
B3FAA8	2017-08-02 18:44:00+03	21000.00
B3FB17	2017-07-13 08:05:00+03	79900.00
B3FB1D	2017-07-17 02:49:00+03	65600.00
B3FB99	2017-08-14 11:20:00+03	67100.00
B3FBD8	2017-08-02 04:24:00+03	70800.00
B3FBEA	2017-08-06 04:12:00+03	42000.00
B3FC09	2017-07-25 02:09:00+03	84000.00
B3FC38	2017-08-12 08:01:00+03	70600.00
B3FCB3	2017-07-20 17:29:00+03	63700.00
B3FCE1	2017-07-29 01:13:00+03	27600.00
B3FD5D	2017-07-19 18:57:00+03	8200.00
B3FD77	2017-07-30 04:01:00+03	27300.00
B3FDB8	2017-07-23 10:55:00+03	119700.00
B3FDCA	2017-07-06 05:09:00+03	131600.00
B3FDE2	2017-07-14 18:40:00+03	38400.00
B3FDE8	2017-07-14 10:10:00+03	67600.00
B3FE1D	2017-07-17 06:35:00+03	10700.00
B3FE8E	2017-07-15 10:59:00+03	17800.00
B3FEA6	2017-07-25 19:35:00+03	62800.00
B3FEEC	2017-08-08 17:08:00+03	34000.00
B3FEF3	2017-07-14 21:48:00+03	396500.00
B3FF06	2017-07-23 21:37:00+03	31100.00
B3FF24	2017-07-26 13:24:00+03	46300.00
B3FF82	2017-08-12 06:50:00+03	225900.00
B3FF8D	2017-07-14 03:34:00+03	155500.00
B40013	2017-07-24 23:39:00+03	28000.00
B40089	2017-07-11 14:47:00+03	96300.00
B40105	2017-07-13 13:38:00+03	20000.00
B40156	2017-07-06 22:10:00+03	43400.00
B40228	2017-08-07 09:34:00+03	26000.00
B402A0	2017-07-08 17:04:00+03	42800.00
B402AF	2017-07-09 22:02:00+03	64700.00
B4031C	2017-08-02 18:10:00+03	94000.00
B4031E	2017-07-21 05:30:00+03	53400.00
B40390	2017-07-08 11:50:00+03	64800.00
B403D8	2017-07-25 13:01:00+03	13600.00
B403F8	2017-07-11 13:50:00+03	86600.00
B4040D	2017-08-11 17:29:00+03	54800.00
B4043E	2017-07-13 06:29:00+03	88000.00
B40442	2017-07-25 15:37:00+03	22600.00
B40444	2017-08-12 02:23:00+03	34600.00
B40468	2017-07-26 04:48:00+03	16400.00
B40499	2017-06-28 10:23:00+03	19600.00
B404C6	2017-07-20 03:55:00+03	150600.00
B40566	2017-07-14 05:45:00+03	21400.00
B40597	2017-08-02 12:33:00+03	12000.00
B405B4	2017-08-03 13:00:00+03	26700.00
B405E2	2017-08-06 03:50:00+03	64800.00
B40621	2017-07-15 12:07:00+03	68000.00
B40642	2017-08-11 07:37:00+03	57200.00
B40667	2017-07-30 09:08:00+03	83200.00
B40692	2017-07-08 20:47:00+03	27800.00
B406C5	2017-07-11 08:47:00+03	369000.00
B40720	2017-07-22 16:54:00+03	19600.00
B40799	2017-07-01 12:15:00+03	16400.00
B40821	2017-08-06 14:13:00+03	68000.00
B40873	2017-08-07 22:41:00+03	24400.00
B4087A	2017-07-23 23:56:00+03	8400.00
B4088D	2017-06-29 23:46:00+03	80100.00
B4089A	2017-07-09 14:56:00+03	37100.00
B40979	2017-07-20 10:42:00+03	123000.00
B40988	2017-08-12 07:41:00+03	24400.00
B409C2	2017-07-29 23:49:00+03	10800.00
B40A1A	2017-08-02 08:48:00+03	65400.00
B40A3B	2017-08-15 03:24:00+03	114400.00
B40A4B	2017-07-06 19:58:00+03	14000.00
B40A71	2017-08-14 17:49:00+03	281400.00
B40AFA	2017-07-07 15:56:00+03	115600.00
B40B12	2017-07-15 05:11:00+03	44700.00
B40B66	2017-08-03 17:36:00+03	28800.00
B40B67	2017-07-14 09:30:00+03	31600.00
B40B9F	2017-08-01 15:09:00+03	122600.00
B40BD6	2017-07-23 09:13:00+03	39600.00
B40BDF	2017-06-27 07:00:00+03	201200.00
B40C1C	2017-06-30 01:55:00+03	20800.00
B40C68	2017-07-08 12:42:00+03	8000.00
B40C6A	2017-07-24 05:55:00+03	59200.00
B40C88	2017-07-06 17:27:00+03	54000.00
B40CCC	2017-08-04 16:10:00+03	40600.00
B40CF9	2017-07-27 17:47:00+03	35400.00
B40DE7	2017-08-13 18:28:00+03	19600.00
B40E31	2017-07-01 11:38:00+03	26300.00
B40E3F	2017-07-06 09:59:00+03	53300.00
B40E72	2017-08-11 15:59:00+03	116000.00
B40F6C	2017-08-05 17:41:00+03	95600.00
B40F91	2017-07-19 13:00:00+03	69900.00
B40FCD	2017-08-13 23:39:00+03	129900.00
B40FDE	2017-07-16 21:46:00+03	24400.00
B40FF3	2017-07-21 01:23:00+03	48400.00
B41030	2017-07-27 05:12:00+03	108500.00
B410D4	2017-08-14 09:45:00+03	70200.00
B41100	2017-07-13 18:49:00+03	136200.00
B41192	2017-08-14 09:16:00+03	58800.00
B4119C	2017-07-15 12:34:00+03	40800.00
B4123C	2017-07-04 20:47:00+03	74600.00
B4129D	2017-06-27 02:08:00+03	69900.00
B412A6	2017-07-09 07:08:00+03	64700.00
B412FE	2017-08-03 09:12:00+03	8000.00
B4134A	2017-07-29 20:39:00+03	394300.00
B41369	2017-07-02 14:56:00+03	143900.00
B413A0	2017-07-28 23:06:00+03	21400.00
B4142C	2017-06-30 04:44:00+03	6000.00
B41458	2017-07-04 06:44:00+03	265700.00
B4146D	2017-07-26 21:54:00+03	52400.00
B414A2	2017-07-03 21:44:00+03	46000.00
B4152F	2017-07-10 19:20:00+03	45200.00
B41561	2017-07-08 23:31:00+03	28000.00
B415D0	2017-07-28 22:38:00+03	90400.00
B415E2	2017-07-14 16:32:00+03	31600.00
B416AF	2017-07-24 01:53:00+03	54800.00
B416B7	2017-08-07 15:56:00+03	88800.00
B416E3	2017-07-29 19:33:00+03	21600.00
B416EC	2017-07-08 17:06:00+03	52900.00
B41780	2017-08-03 09:40:00+03	25100.00
B41794	2017-07-23 06:28:00+03	55800.00
B417BB	2017-08-01 20:00:00+03	48300.00
B417FE	2017-08-01 05:22:00+03	57400.00
B4185B	2017-07-18 10:42:00+03	55800.00
B4187B	2017-07-06 22:27:00+03	24400.00
B418BF	2017-07-21 02:47:00+03	123000.00
B4190B	2017-08-06 09:45:00+03	143000.00
B41945	2017-07-25 20:12:00+03	36800.00
B419AE	2017-07-31 11:19:00+03	227500.00
B419BF	2017-07-31 02:14:00+03	66000.00
B41A7C	2017-08-11 16:47:00+03	46200.00
B41A7D	2017-08-14 16:07:00+03	148200.00
B41ABC	2017-07-21 17:09:00+03	181600.00
B41B8A	2017-07-28 04:56:00+03	56000.00
B41C0A	2017-07-04 03:14:00+03	27400.00
B41C58	2017-08-07 14:45:00+03	62600.00
B41C5E	2017-06-29 09:07:00+03	43200.00
B41C5F	2017-07-12 23:42:00+03	38400.00
B41CA4	2017-07-24 19:38:00+03	21600.00
B41D0C	2017-07-10 06:41:00+03	400000.00
B41D21	2017-08-07 06:56:00+03	8200.00
B41D2B	2017-06-30 03:17:00+03	179300.00
B41DD0	2017-08-01 22:49:00+03	46200.00
B41DDD	2017-07-10 23:04:00+03	47100.00
B41E09	2017-07-01 02:36:00+03	40800.00
B41E29	2017-07-25 07:10:00+03	85000.00
B41E51	2017-08-12 11:31:00+03	31600.00
B41EA5	2017-08-07 18:08:00+03	28000.00
B41F13	2017-07-20 21:15:00+03	373500.00
B41F2C	2017-07-24 00:29:00+03	62800.00
B41F3F	2017-07-30 17:47:00+03	46400.00
B41F4E	2017-07-05 12:53:00+03	57400.00
B41F78	2017-07-01 03:06:00+03	32800.00
B41F95	2017-08-07 13:21:00+03	234200.00
B4201B	2017-07-27 18:33:00+03	75300.00
B42074	2017-08-01 00:14:00+03	40800.00
B4207E	2017-08-04 14:57:00+03	92400.00
B4207F	2017-07-14 16:39:00+03	54800.00
B4208F	2017-08-10 11:23:00+03	92800.00
B4216B	2017-07-23 14:08:00+03	26000.00
B42191	2017-08-09 04:56:00+03	132800.00
B421B9	2017-07-15 21:38:00+03	66600.00
B421BC	2017-07-24 04:45:00+03	46200.00
B42224	2017-07-25 05:43:00+03	56100.00
B42237	2017-07-11 11:29:00+03	59800.00
B4223D	2017-07-30 15:04:00+03	88900.00
B422CB	2017-08-12 12:48:00+03	26800.00
B422D0	2017-07-10 10:09:00+03	167400.00
B422DF	2017-07-02 19:00:00+03	24400.00
B4234D	2017-07-23 21:14:00+03	109400.00
B4238F	2017-08-11 03:39:00+03	6300.00
B423E5	2017-08-08 10:27:00+03	66200.00
B42455	2017-08-05 16:25:00+03	93000.00
B424A3	2017-07-14 19:37:00+03	277800.00
B424B6	2017-07-06 04:36:00+03	92600.00
B424D7	2017-08-13 19:31:00+03	13400.00
B4255D	2017-07-14 01:56:00+03	12800.00
B42599	2017-08-05 02:22:00+03	67200.00
B425A9	2017-08-14 18:29:00+03	24400.00
B4260D	2017-07-16 07:22:00+03	46400.00
B42678	2017-07-23 08:00:00+03	52900.00
B42693	2017-08-05 15:05:00+03	32800.00
B42698	2017-08-14 15:49:00+03	90000.00
B426A6	2017-07-09 19:44:00+03	69500.00
B42754	2017-07-25 11:14:00+03	44000.00
B42764	2017-07-05 16:35:00+03	80000.00
B42796	2017-07-14 13:20:00+03	24400.00
B42810	2017-07-04 07:29:00+03	217600.00
B4284F	2017-07-25 15:26:00+03	136600.00
B428B8	2017-08-07 20:12:00+03	11700.00
B428D1	2017-08-14 17:17:00+03	55800.00
B428D4	2017-07-04 14:52:00+03	38500.00
B428E0	2017-07-21 10:03:00+03	26000.00
B42902	2017-08-13 04:02:00+03	14400.00
B42933	2017-07-27 22:16:00+03	58400.00
B4296F	2017-07-06 09:56:00+03	23200.00
B429CA	2017-07-18 04:00:00+03	59300.00
B429D9	2017-07-17 02:08:00+03	8200.00
B42A50	2017-07-14 01:44:00+03	17600.00
B42A68	2017-07-02 07:57:00+03	13600.00
B42A6C	2017-08-04 07:14:00+03	24400.00
B42AA1	2017-07-08 00:23:00+03	65900.00
B42B01	2017-08-10 06:35:00+03	77000.00
B42B2C	2017-08-01 22:07:00+03	12000.00
B42B64	2017-07-27 19:22:00+03	168000.00
B42B66	2017-08-14 05:56:00+03	6700.00
B42B7B	2017-07-31 03:40:00+03	21400.00
B42B7C	2017-07-02 22:31:00+03	13400.00
B42B86	2017-08-05 12:39:00+03	24000.00
B42BCE	2017-07-30 19:59:00+03	22100.00
B42C90	2017-07-14 01:50:00+03	68800.00
B42CC6	2017-07-23 20:25:00+03	124200.00
B42E4C	2017-07-17 01:43:00+03	31600.00
B42E61	2017-07-29 02:18:00+03	19600.00
B42E8B	2017-07-13 04:58:00+03	14000.00
B42EC6	2017-08-01 17:56:00+03	70700.00
B42F0B	2017-08-06 12:49:00+03	121400.00
B42F2D	2017-07-23 16:15:00+03	559700.00
B42F41	2017-07-11 17:05:00+03	144300.00
B42F8B	2017-08-08 22:34:00+03	94200.00
B42F99	2017-08-09 04:04:00+03	24200.00
B42FFD	2017-08-02 18:49:00+03	30000.00
B43044	2017-08-10 13:57:00+03	67200.00
B43045	2017-07-25 16:21:00+03	88500.00
B4305B	2017-08-14 00:34:00+03	79900.00
B431B0	2017-07-30 19:16:00+03	62700.00
B431E3	2017-07-20 10:15:00+03	40400.00
B43216	2017-08-06 20:00:00+03	89600.00
B43220	2017-08-09 07:35:00+03	62100.00
B43237	2017-07-08 04:37:00+03	39700.00
B43286	2017-08-03 05:14:00+03	41200.00
B432BE	2017-08-02 17:20:00+03	59800.00
B4333A	2017-08-15 06:28:00+03	133300.00
B43394	2017-07-02 05:43:00+03	52000.00
B4339A	2017-07-26 21:09:00+03	63200.00
B433A2	2017-07-29 09:48:00+03	111600.00
B4340D	2017-08-15 01:42:00+03	254900.00
B43433	2017-06-30 06:01:00+03	7300.00
B4343D	2017-07-24 15:03:00+03	60400.00
B4347B	2017-07-08 20:38:00+03	93200.00
B435A4	2017-08-12 23:39:00+03	83200.00
B435C8	2017-07-26 09:28:00+03	111600.00
B43611	2017-08-15 12:01:00+03	55800.00
B4361D	2017-08-08 12:56:00+03	82200.00
B43648	2017-08-03 08:41:00+03	271200.00
B436A9	2017-07-18 04:20:00+03	115900.00
B436CE	2017-07-19 06:22:00+03	50900.00
B436D2	2017-07-21 03:10:00+03	111700.00
B436F9	2017-07-29 13:34:00+03	59800.00
B43798	2017-08-08 12:17:00+03	53600.00
B437D4	2017-07-01 16:45:00+03	136800.00
B437E3	2017-07-19 20:05:00+03	28000.00
B43804	2017-07-17 14:04:00+03	23200.00
B43856	2017-07-25 13:03:00+03	52300.00
B43888	2017-07-03 00:07:00+03	94500.00
B438DA	2017-08-09 17:47:00+03	37900.00
B438E5	2017-08-13 14:01:00+03	73600.00
B4392B	2017-08-14 04:52:00+03	37100.00
B4393C	2017-08-02 00:00:00+03	81600.00
B43955	2017-08-12 08:59:00+03	117200.00
B4397D	2017-08-14 16:27:00+03	23400.00
B439A7	2017-08-09 22:28:00+03	76600.00
B43A02	2017-07-15 21:37:00+03	26800.00
B43A7D	2017-07-08 19:44:00+03	217600.00
B43AF2	2017-06-30 17:48:00+03	56000.00
B43BE3	2017-07-17 11:36:00+03	96400.00
B43C29	2017-08-10 16:58:00+03	93900.00
B43C6D	2017-08-05 18:06:00+03	32200.00
B43CA4	2017-07-26 07:55:00+03	20400.00
B43CAD	2017-08-05 14:32:00+03	44600.00
B43CEE	2017-07-19 04:07:00+03	40600.00
B43D1E	2017-08-04 19:45:00+03	26700.00
B43D2B	2017-07-09 05:55:00+03	39300.00
B43D6C	2017-07-26 08:26:00+03	114700.00
B43DE5	2017-07-24 21:28:00+03	12600.00
B43E8E	2017-07-19 13:22:00+03	174500.00
B43EEB	2017-08-06 13:33:00+03	99700.00
B43F8A	2017-07-24 00:12:00+03	111600.00
B43FB9	2017-08-04 17:21:00+03	23200.00
B43FBC	2017-08-12 21:26:00+03	272300.00
B44013	2017-08-01 03:14:00+03	295400.00
B44054	2017-08-07 07:44:00+03	14000.00
B440C6	2017-07-10 14:54:00+03	25800.00
B440D6	2017-07-09 21:45:00+03	99200.00
B44108	2017-07-03 07:24:00+03	31800.00
B44124	2017-08-09 12:54:00+03	174600.00
B4419C	2017-07-30 19:32:00+03	42700.00
B441B2	2017-07-08 22:02:00+03	24000.00
B4422C	2017-08-07 16:55:00+03	8200.00
B4430F	2017-08-01 12:18:00+03	22000.00
B44334	2017-07-09 08:16:00+03	92600.00
B4437F	2017-07-14 12:14:00+03	160200.00
B443FC	2017-07-18 08:06:00+03	20600.00
B44442	2017-07-08 19:40:00+03	133200.00
B4444B	2017-08-01 03:30:00+03	28000.00
B44474	2017-07-13 21:50:00+03	42800.00
B44517	2017-07-04 10:51:00+03	145500.00
B44534	2017-06-29 00:30:00+03	49500.00
B4455B	2017-07-16 16:01:00+03	52400.00
B44595	2017-08-14 23:22:00+03	138000.00
B4459A	2017-08-13 22:02:00+03	41200.00
B445D4	2017-08-02 16:51:00+03	80000.00
B445D8	2017-07-18 02:29:00+03	24000.00
B44601	2017-07-17 20:42:00+03	47000.00
B44642	2017-08-15 03:00:00+03	56000.00
B4464A	2017-07-15 10:45:00+03	47100.00
B44665	2017-07-28 12:36:00+03	26000.00
B4466F	2017-08-11 20:33:00+03	8000.00
B44679	2017-07-30 03:45:00+03	66300.00
B446B8	2017-08-12 10:31:00+03	67200.00
B44739	2017-07-31 13:50:00+03	62600.00
B44760	2017-07-08 23:21:00+03	57200.00
B44775	2017-07-02 12:45:00+03	134200.00
B44788	2017-08-02 05:26:00+03	56000.00
B4478E	2017-07-17 10:16:00+03	32800.00
B44793	2017-07-20 03:59:00+03	21200.00
B447AD	2017-08-10 20:50:00+03	75300.00
B4483F	2017-07-16 14:18:00+03	46000.00
B4489B	2017-07-04 18:46:00+03	43200.00
B4497D	2017-08-10 00:50:00+03	26000.00
B449C8	2017-07-11 15:24:00+03	52000.00
B44A3E	2017-07-25 10:02:00+03	23200.00
B44A5B	2017-07-11 09:12:00+03	26900.00
B44A79	2017-07-24 12:23:00+03	52000.00
B44A7F	2017-07-27 14:07:00+03	44800.00
B44AAA	2017-07-20 08:55:00+03	379600.00
B44ACE	2017-07-30 07:09:00+03	22600.00
B44AD6	2017-08-11 19:25:00+03	13400.00
B44ADE	2017-07-11 23:38:00+03	102100.00
B44BBB	2017-07-20 05:01:00+03	24000.00
B44BCA	2017-07-10 10:04:00+03	48800.00
B44C4A	2017-07-14 11:39:00+03	24400.00
B44C54	2017-08-04 21:33:00+03	14800.00
B44CAB	2017-08-09 09:53:00+03	161800.00
B44CB6	2017-07-16 07:37:00+03	68000.00
B44CE8	2017-07-18 15:18:00+03	130900.00
B44CFC	2017-08-09 21:25:00+03	96900.00
B44D54	2017-08-10 15:00:00+03	65900.00
B44D65	2017-07-09 15:48:00+03	269200.00
B44D8F	2017-08-05 22:30:00+03	68400.00
B44D91	2017-08-13 22:03:00+03	102100.00
B44E4D	2017-07-06 20:19:00+03	265600.00
B44E55	2017-08-04 04:55:00+03	23400.00
B44E5A	2017-07-20 07:12:00+03	57400.00
B44E8B	2017-08-03 23:01:00+03	43200.00
B44E94	2017-08-05 05:57:00+03	14400.00
B44EF2	2017-08-08 22:07:00+03	81300.00
B44F15	2017-07-23 01:55:00+03	6700.00
B44F28	2017-07-30 04:35:00+03	75600.00
B44F8C	2017-07-20 21:03:00+03	12600.00
B44FBD	2017-07-18 10:40:00+03	37900.00
B44FF5	2017-07-26 14:20:00+03	92800.00
B45014	2017-08-09 06:18:00+03	146800.00
B45039	2017-07-27 08:17:00+03	79000.00
B450C2	2017-08-03 03:05:00+03	39200.00
B450DF	2017-07-05 03:11:00+03	137600.00
B45187	2017-08-13 10:23:00+03	95600.00
B451C7	2017-07-29 01:20:00+03	26200.00
B451F2	2017-07-18 07:59:00+03	66600.00
B45206	2017-08-08 09:33:00+03	201200.00
B45233	2017-08-14 03:24:00+03	21800.00
B4523F	2017-08-01 07:52:00+03	23200.00
B45298	2017-07-12 15:42:00+03	66600.00
B452B8	2017-08-03 14:15:00+03	86300.00
B452E2	2017-08-01 09:41:00+03	208100.00
B452FB	2017-07-21 20:43:00+03	73300.00
B452FD	2017-07-07 06:28:00+03	64400.00
B45310	2017-07-31 11:10:00+03	36200.00
B45324	2017-07-12 02:28:00+03	25100.00
B45385	2017-08-08 20:09:00+03	101100.00
B4539E	2017-07-24 16:41:00+03	219900.00
B453B8	2017-07-07 22:12:00+03	63500.00
B454D4	2017-07-03 12:48:00+03	29600.00
B454DA	2017-07-14 04:33:00+03	124200.00
B454DC	2017-07-21 20:19:00+03	65400.00
B45518	2017-08-09 04:42:00+03	395000.00
B45569	2017-07-26 23:42:00+03	46400.00
B455DC	2017-08-10 04:38:00+03	92800.00
B456A0	2017-07-15 08:28:00+03	40600.00
B456A3	2017-07-01 09:11:00+03	17600.00
B456D4	2017-07-25 10:09:00+03	111600.00
B456EB	2017-08-01 14:52:00+03	130900.00
B45726	2017-07-03 13:06:00+03	106900.00
B4574E	2017-07-26 10:28:00+03	36800.00
B45771	2017-07-03 03:08:00+03	52700.00
B4578D	2017-08-09 21:15:00+03	57400.00
B45818	2017-07-10 05:35:00+03	21800.00
B4583F	2017-07-02 02:50:00+03	56900.00
B4587D	2017-08-14 20:09:00+03	29200.00
B45895	2017-07-26 22:29:00+03	65400.00
B4589B	2017-07-27 12:40:00+03	26800.00
B45912	2017-07-15 22:27:00+03	49900.00
B45962	2017-07-06 16:00:00+03	46400.00
B45965	2017-07-31 19:48:00+03	25100.00
B45968	2017-06-28 18:10:00+03	92600.00
B4599C	2017-08-06 03:33:00+03	93600.00
B459AC	2017-06-30 23:36:00+03	161200.00
B459C3	2017-07-06 04:33:00+03	38200.00
B459D8	2017-08-05 00:12:00+03	24700.00
B459DA	2017-08-10 02:11:00+03	71800.00
B45A0C	2017-07-28 20:05:00+03	48300.00
B45A2E	2017-07-08 03:37:00+03	168000.00
B45A46	2017-07-22 04:00:00+03	37500.00
B45A75	2017-07-26 19:18:00+03	70500.00
B45ADD	2017-07-25 00:09:00+03	49600.00
B45B45	2017-07-31 07:30:00+03	25600.00
B45B82	2017-08-03 23:20:00+03	45200.00
B45BE6	2017-07-16 02:34:00+03	133100.00
B45BF9	2017-07-22 03:23:00+03	56000.00
B45C01	2017-07-14 11:36:00+03	14000.00
B45C6D	2017-07-30 01:00:00+03	51800.00
B45C95	2017-08-06 15:09:00+03	86300.00
B45D13	2017-07-27 04:28:00+03	266400.00
B45D1E	2017-07-05 21:29:00+03	105000.00
B45D66	2017-07-31 16:41:00+03	135400.00
B45D6B	2017-08-07 18:48:00+03	282100.00
B45DB6	2017-07-25 08:46:00+03	92900.00
B45DBA	2017-07-23 00:43:00+03	147700.00
B45E38	2017-08-15 12:03:00+03	26800.00
B45E3B	2017-07-06 12:26:00+03	53600.00
B45EC1	2017-07-20 10:48:00+03	34600.00
B45F13	2017-07-09 05:10:00+03	26800.00
B45F17	2017-07-11 16:58:00+03	55800.00
B45F1C	2017-08-13 17:50:00+03	88400.00
B45F1F	2017-07-10 21:38:00+03	14400.00
B45F43	2017-07-01 13:25:00+03	156600.00
B45F91	2017-08-07 05:38:00+03	28300.00
B45F9F	2017-07-17 20:43:00+03	195600.00
B45FB8	2017-08-13 18:43:00+03	50600.00
B45FCA	2017-08-14 19:16:00+03	28000.00
B45FFD	2017-07-16 05:01:00+03	14400.00
B46137	2017-07-07 09:48:00+03	61700.00
B461DE	2017-07-19 19:48:00+03	85000.00
B46258	2017-07-15 23:54:00+03	70700.00
B46267	2017-08-03 15:57:00+03	67300.00
B46270	2017-08-05 10:57:00+03	108500.00
B46276	2017-08-14 17:46:00+03	135200.00
B462AE	2017-08-02 22:24:00+03	193900.00
B462C4	2017-07-22 02:32:00+03	54800.00
B46347	2017-07-30 18:48:00+03	48800.00
B463E9	2017-07-21 14:18:00+03	15000.00
B46401	2017-08-07 05:05:00+03	53700.00
B46456	2017-07-10 03:25:00+03	19600.00
B46469	2017-07-12 03:28:00+03	117600.00
B4648D	2017-08-07 22:18:00+03	51900.00
B4649F	2017-07-25 07:10:00+03	12600.00
B4650E	2017-08-09 01:05:00+03	19600.00
B46517	2017-06-28 16:27:00+03	29600.00
B46538	2017-07-18 08:07:00+03	38600.00
B46561	2017-07-24 16:49:00+03	6700.00
B4656E	2017-07-25 15:30:00+03	96100.00
B465CA	2017-08-08 09:02:00+03	48900.00
B4664A	2017-07-09 21:18:00+03	12600.00
B4669C	2017-07-27 13:19:00+03	17200.00
B466B5	2017-08-12 01:51:00+03	23200.00
B466BF	2017-07-05 01:07:00+03	28000.00
B4678D	2017-07-31 23:25:00+03	79200.00
B467FD	2017-07-31 17:56:00+03	30200.00
B4680F	2017-08-10 21:53:00+03	74600.00
B46814	2017-07-06 00:51:00+03	29600.00
B4683B	2017-07-14 21:53:00+03	46400.00
B4683D	2017-08-05 21:09:00+03	29800.00
B468CC	2017-07-12 02:58:00+03	19800.00
B468D5	2017-07-18 15:51:00+03	56900.00
B46931	2017-08-05 02:25:00+03	87200.00
B46950	2017-07-16 21:31:00+03	6700.00
B46962	2017-07-06 15:34:00+03	67700.00
B46989	2017-07-21 15:10:00+03	21400.00
B469E9	2017-07-14 12:43:00+03	54700.00
B469EC	2017-07-25 23:39:00+03	113200.00
B46A6C	2017-07-13 18:01:00+03	381400.00
B46A74	2017-07-05 11:25:00+03	46000.00
B46A78	2017-07-03 13:02:00+03	42700.00
B46AF0	2017-08-15 07:09:00+03	270200.00
B46B4B	2017-07-02 22:21:00+03	32700.00
B46B5C	2017-07-22 22:30:00+03	34600.00
B46BBE	2017-07-26 16:39:00+03	77900.00
B46C2E	2017-07-08 07:04:00+03	53000.00
B46C35	2017-07-24 20:51:00+03	111600.00
B46C41	2017-07-26 22:45:00+03	28800.00
B46C58	2017-07-12 06:47:00+03	173500.00
B46C59	2017-07-20 10:04:00+03	132800.00
B46CAC	2017-07-20 05:06:00+03	12600.00
B46CD9	2017-07-11 06:43:00+03	66600.00
B46CF4	2017-08-11 15:07:00+03	73000.00
B46E09	2017-07-06 22:19:00+03	56000.00
B46E4F	2017-07-02 22:30:00+03	20600.00
B46E91	2017-07-14 13:59:00+03	89600.00
B46E9D	2017-07-24 11:35:00+03	45200.00
B46EC4	2017-07-13 08:36:00+03	124200.00
B46EDB	2017-07-09 09:17:00+03	57400.00
B46F11	2017-08-07 19:47:00+03	200300.00
B46F1E	2017-06-29 20:32:00+03	52000.00
B46F2F	2017-07-08 04:55:00+03	56900.00
B46F60	2017-07-08 10:46:00+03	47000.00
B46F69	2017-08-02 10:26:00+03	91600.00
B46F86	2017-08-09 01:04:00+03	9200.00
B46F9A	2017-07-22 14:35:00+03	56000.00
B46FA3	2017-07-07 07:26:00+03	70800.00
B46FD3	2017-08-01 22:13:00+03	89100.00
B47008	2017-08-14 04:51:00+03	25800.00
B47023	2017-08-04 11:00:00+03	168000.00
B47051	2017-08-01 12:44:00+03	44300.00
B47082	2017-08-11 08:03:00+03	55800.00
B470BE	2017-07-17 19:21:00+03	37900.00
B4714B	2017-07-23 11:26:00+03	277000.00
B47178	2017-07-22 10:35:00+03	138500.00
B471C9	2017-07-14 04:47:00+03	123000.00
B471F5	2017-07-12 03:43:00+03	52000.00
B4720E	2017-08-07 08:07:00+03	67900.00
B47237	2017-08-06 19:33:00+03	46200.00
B47292	2017-08-13 14:37:00+03	46400.00
B472D3	2017-08-12 23:40:00+03	141900.00
B4736D	2017-07-22 15:16:00+03	22400.00
B473F5	2017-07-01 23:23:00+03	28800.00
B4741F	2017-08-01 15:26:00+03	40300.00
B47464	2017-08-02 19:10:00+03	96800.00
B47488	2017-08-12 03:24:00+03	13800.00
B474F2	2017-07-26 23:50:00+03	70700.00
B47546	2017-08-10 17:51:00+03	37200.00
B47571	2017-07-15 10:29:00+03	11000.00
B475E1	2017-08-09 23:51:00+03	27200.00
B475F4	2017-08-01 04:53:00+03	35300.00
B4765B	2017-08-02 00:14:00+03	83000.00
B4765F	2017-07-07 00:28:00+03	8000.00
B477C5	2017-08-05 17:39:00+03	355200.00
B477E8	2017-08-03 06:57:00+03	55800.00
B477F5	2017-07-20 07:45:00+03	30800.00
B47937	2017-07-15 03:05:00+03	15000.00
B47941	2017-07-20 17:10:00+03	75600.00
B47A34	2017-07-30 23:21:00+03	87000.00
B47A50	2017-07-04 15:06:00+03	55800.00
B47A55	2017-07-05 14:21:00+03	41200.00
B47A98	2017-07-11 22:48:00+03	54800.00
B47ABB	2017-07-07 18:05:00+03	18000.00
B47AC0	2017-08-14 10:29:00+03	24400.00
B47B74	2017-07-04 05:19:00+03	123000.00
B47C20	2017-07-06 18:44:00+03	55000.00
B47CD1	2017-07-05 11:06:00+03	44800.00
B47CFC	2017-07-30 05:46:00+03	85700.00
B47D69	2017-08-01 12:56:00+03	40000.00
B47D7B	2017-07-13 17:46:00+03	160400.00
B47D8C	2017-07-14 11:47:00+03	28800.00
B47D99	2017-07-27 21:56:00+03	21400.00
B47DB4	2017-07-14 03:27:00+03	64500.00
B47DF6	2017-07-10 23:59:00+03	224300.00
B47E7D	2017-07-27 15:53:00+03	40800.00
B47E93	2017-07-10 09:41:00+03	23600.00
B47EA7	2017-07-01 09:51:00+03	90400.00
B47EE4	2017-08-05 13:39:00+03	98400.00
B47F26	2017-07-07 23:43:00+03	85300.00
B47F85	2017-08-03 19:08:00+03	167400.00
B47FD4	2017-07-02 04:02:00+03	199200.00
B47FF6	2017-07-07 11:21:00+03	35200.00
B48010	2017-07-12 05:08:00+03	95700.00
B48071	2017-07-13 23:30:00+03	56000.00
B48117	2017-07-18 11:55:00+03	54100.00
B48119	2017-07-19 00:24:00+03	6800.00
B48122	2017-07-08 15:05:00+03	151800.00
B4818F	2017-08-13 20:39:00+03	6700.00
B481B4	2017-07-13 10:16:00+03	21400.00
B481C3	2017-07-18 10:32:00+03	18000.00
B482A7	2017-08-15 15:28:00+03	261800.00
B482DE	2017-08-14 02:57:00+03	27400.00
B4835C	2017-08-03 04:26:00+03	13400.00
B48361	2017-07-10 16:29:00+03	48800.00
B4838D	2017-08-01 15:25:00+03	397100.00
B483DC	2017-07-11 02:59:00+03	40800.00
B483E5	2017-07-16 20:00:00+03	104200.00
B4846A	2017-07-07 17:11:00+03	257500.00
B4846D	2017-08-05 13:20:00+03	52300.00
B4847F	2017-08-09 18:05:00+03	135300.00
B48539	2017-08-03 14:21:00+03	44000.00
B48553	2017-07-21 12:26:00+03	10600.00
B48556	2017-08-02 04:29:00+03	92800.00
B485C4	2017-07-31 20:29:00+03	26000.00
B4862E	2017-07-24 02:48:00+03	47000.00
B4866A	2017-07-06 20:18:00+03	23200.00
B48695	2017-07-17 06:36:00+03	27300.00
B486F1	2017-08-02 00:59:00+03	116000.00
B48708	2017-07-03 18:13:00+03	67600.00
B48732	2017-08-09 03:29:00+03	63900.00
B48826	2017-08-15 12:35:00+03	29600.00
B48877	2017-08-06 14:40:00+03	25000.00
B4892C	2017-08-15 11:40:00+03	27900.00
B4893C	2017-07-20 16:13:00+03	31600.00
B48973	2017-07-05 20:45:00+03	189000.00
B489C5	2017-08-02 13:20:00+03	80000.00
B489EA	2017-07-14 05:15:00+03	55800.00
B48A09	2017-08-06 18:16:00+03	271400.00
B48A1D	2017-07-13 15:27:00+03	46400.00
B48A34	2017-08-09 22:07:00+03	82000.00
B48A58	2017-08-07 06:14:00+03	15700.00
B48A67	2017-08-08 22:42:00+03	53300.00
B48A7C	2017-08-08 18:35:00+03	199700.00
B48A80	2017-08-10 12:30:00+03	102100.00
B48A98	2017-07-18 11:50:00+03	112000.00
B48AD4	2017-07-04 15:22:00+03	116500.00
B48B0E	2017-07-19 01:53:00+03	39600.00
B48B39	2017-08-02 07:52:00+03	19600.00
B48B7E	2017-08-01 01:16:00+03	47200.00
B48C4C	2017-07-26 12:23:00+03	24400.00
B48C96	2017-08-11 15:49:00+03	21200.00
B48CA3	2017-07-08 06:44:00+03	99200.00
B48CC1	2017-08-08 11:47:00+03	47400.00
B48CCD	2017-08-03 14:54:00+03	24800.00
B48CD0	2017-07-25 18:25:00+03	28800.00
B48D92	2017-07-22 19:16:00+03	26000.00
B48DC3	2017-08-02 02:50:00+03	48900.00
B48E1F	2017-07-15 00:28:00+03	136000.00
B48E2D	2017-08-09 11:57:00+03	72800.00
B48E35	2017-07-30 11:17:00+03	135600.00
B48E4A	2017-08-12 13:09:00+03	112000.00
B48E4D	2017-07-31 00:36:00+03	56000.00
B48E76	2017-07-02 21:06:00+03	23200.00
B48E8D	2017-07-27 10:10:00+03	85000.00
B48E98	2017-07-09 21:17:00+03	68000.00
B48EB7	2017-07-13 09:17:00+03	28800.00
B48EE8	2017-07-08 09:55:00+03	170400.00
B48F4D	2017-07-17 18:30:00+03	163200.00
B48FF2	2017-07-13 22:30:00+03	46800.00
B48FF8	2017-08-01 00:39:00+03	43000.00
B48FFA	2017-08-03 01:56:00+03	68000.00
B49005	2017-08-04 11:11:00+03	75200.00
B4906D	2017-08-10 23:02:00+03	85000.00
B49070	2017-07-18 06:49:00+03	44000.00
B49095	2017-07-10 14:48:00+03	49600.00
B4922A	2017-07-07 13:45:00+03	14400.00
B49245	2017-08-13 07:04:00+03	149200.00
B49246	2017-08-13 10:02:00+03	22600.00
B4927E	2017-07-03 13:44:00+03	106400.00
B492B6	2017-08-01 08:35:00+03	56000.00
B49311	2017-08-01 16:30:00+03	71200.00
B49315	2017-07-24 06:53:00+03	266400.00
B4934C	2017-07-02 04:49:00+03	58800.00
B49372	2017-08-13 20:58:00+03	92400.00
B49386	2017-07-23 18:57:00+03	46000.00
B493E9	2017-07-09 14:18:00+03	47400.00
B4941C	2017-08-09 19:25:00+03	193200.00
B494FB	2017-07-09 01:53:00+03	67200.00
B49511	2017-08-06 18:03:00+03	47700.00
B49521	2017-07-17 07:03:00+03	66600.00
B495BB	2017-07-10 17:50:00+03	31600.00
B495FC	2017-07-01 02:34:00+03	140400.00
B49622	2017-06-28 20:27:00+03	50400.00
B4962B	2017-08-12 12:36:00+03	40400.00
B49649	2017-07-30 13:48:00+03	85000.00
B49664	2017-08-14 09:18:00+03	69500.00
B4967B	2017-07-28 18:46:00+03	74000.00
B496B0	2017-07-24 02:41:00+03	23200.00
B496B6	2017-08-10 20:06:00+03	79800.00
B496C7	2017-07-13 10:33:00+03	277800.00
B49746	2017-08-10 03:58:00+03	6700.00
B49779	2017-06-30 19:16:00+03	18100.00
B497BF	2017-07-06 18:27:00+03	44900.00
B497EE	2017-07-13 22:30:00+03	53800.00
B49800	2017-07-26 11:26:00+03	92700.00
B4988C	2017-08-12 16:38:00+03	66000.00
B498F1	2017-08-04 00:27:00+03	93400.00
B49909	2017-07-28 16:37:00+03	67000.00
B4991E	2017-07-10 12:33:00+03	257500.00
B49939	2017-07-31 02:23:00+03	22400.00
B49980	2017-06-30 00:07:00+03	126800.00
B499A0	2017-07-30 15:48:00+03	47600.00
B499D7	2017-08-02 13:13:00+03	28800.00
B49A37	2017-06-30 13:44:00+03	170500.00
B49A38	2017-07-17 08:16:00+03	21800.00
B49A89	2017-08-09 14:12:00+03	29600.00
B49A8A	2017-08-11 17:50:00+03	13800.00
B49ABD	2017-08-14 21:18:00+03	25100.00
B49AE3	2017-08-14 23:19:00+03	40100.00
B49B6D	2017-06-30 16:25:00+03	46700.00
B49B8B	2017-08-10 14:40:00+03	19600.00
B49B8E	2017-07-03 17:48:00+03	123000.00
B49BA7	2017-08-04 08:16:00+03	108000.00
B49BB6	2017-08-04 09:15:00+03	25000.00
B49BD0	2017-08-01 18:31:00+03	29400.00
B49C3E	2017-07-02 13:17:00+03	42100.00
B49C54	2017-08-07 15:29:00+03	65900.00
B49CBF	2017-08-15 00:40:00+03	102100.00
B49CD8	2017-08-05 10:50:00+03	29600.00
B49D1B	2017-07-28 04:04:00+03	59200.00
B49D3B	2017-08-15 13:26:00+03	114700.00
B49D62	2017-07-06 02:59:00+03	406600.00
B49DB6	2017-07-31 09:36:00+03	132800.00
B49DF0	2017-08-09 01:38:00+03	21400.00
B49E10	2017-07-06 22:53:00+03	99200.00
B49E23	2017-08-14 17:17:00+03	272300.00
B49E57	2017-07-15 15:38:00+03	113600.00
B49E89	2017-07-03 21:31:00+03	393800.00
B49ED8	2017-07-20 12:53:00+03	22000.00
B49EED	2017-07-22 23:29:00+03	27800.00
B49F1A	2017-08-08 05:23:00+03	20200.00
B49FB3	2017-08-06 23:18:00+03	59400.00
B49FCE	2017-08-10 21:23:00+03	47400.00
B49FF8	2017-08-02 22:28:00+03	24600.00
B4A05A	2017-08-12 17:56:00+03	50600.00
B4A091	2017-07-17 13:48:00+03	30400.00
B4A0BF	2017-08-15 02:51:00+03	39800.00
B4A1BD	2017-08-02 15:59:00+03	22000.00
B4A1C4	2017-07-11 21:27:00+03	22000.00
B4A1DB	2017-07-17 10:33:00+03	62800.00
B4A21A	2017-08-04 23:58:00+03	40800.00
B4A21C	2017-07-23 18:10:00+03	155600.00
B4A2B3	2017-08-05 07:39:00+03	528000.00
B4A2CF	2017-08-14 15:16:00+03	55500.00
B4A2D8	2017-07-20 07:01:00+03	21200.00
B4A2F8	2017-07-27 22:07:00+03	119600.00
B4A30E	2017-07-16 07:27:00+03	20200.00
B4A3F0	2017-07-30 02:18:00+03	56900.00
B4A40B	2017-07-25 07:40:00+03	31600.00
B4A432	2017-08-13 16:02:00+03	14000.00
B4A45B	2017-07-21 19:08:00+03	68000.00
B4A461	2017-07-06 10:18:00+03	116000.00
B4A466	2017-07-18 20:40:00+03	103200.00
B4A499	2017-07-13 18:35:00+03	133200.00
B4A4F7	2017-07-28 14:04:00+03	101200.00
B4A576	2017-08-03 05:42:00+03	64600.00
B4A5F7	2017-08-09 21:38:00+03	38500.00
B4A621	2017-08-02 18:02:00+03	56000.00
B4A6C9	2017-08-06 23:08:00+03	16400.00
B4A6F2	2017-08-10 14:28:00+03	99800.00
B4A750	2017-07-27 21:25:00+03	96200.00
B4A7C5	2017-07-10 18:43:00+03	201200.00
B4A83F	2017-08-14 18:29:00+03	206400.00
B4A89A	2017-07-25 19:27:00+03	26000.00
B4A8D8	2017-07-26 10:26:00+03	147700.00
B4A8D9	2017-08-03 08:18:00+03	36200.00
B4A920	2017-08-04 00:20:00+03	13400.00
B4A93B	2017-08-15 00:54:00+03	39800.00
B4A96B	2017-07-18 17:25:00+03	67900.00
B4A99C	2017-07-22 13:58:00+03	59800.00
B4AA23	2017-07-15 11:06:00+03	21800.00
B4AAB3	2017-08-11 11:43:00+03	56000.00
B4AB09	2017-07-01 02:51:00+03	128800.00
B4AB3F	2017-07-03 08:40:00+03	64100.00
B4ABC7	2017-07-18 05:56:00+03	156500.00
B4AC34	2017-07-15 02:36:00+03	55800.00
B4AC9D	2017-08-01 14:16:00+03	75300.00
B4AE78	2017-08-08 13:49:00+03	38600.00
B4AEAC	2017-07-22 03:09:00+03	24600.00
B4AECE	2017-07-08 14:02:00+03	28800.00
B4AEDB	2017-07-10 11:03:00+03	28700.00
B4AF30	2017-08-04 04:32:00+03	8800.00
B4AF9F	2017-07-04 19:21:00+03	96300.00
B4AFD4	2017-07-31 00:47:00+03	58000.00
B4AFD6	2017-07-06 08:27:00+03	14400.00
B4B010	2017-07-30 21:47:00+03	14000.00
B4B089	2017-07-05 00:22:00+03	67900.00
B4B15E	2017-07-31 19:36:00+03	86400.00
B4B189	2017-07-08 11:40:00+03	105400.00
B4B1F1	2017-07-16 04:52:00+03	14400.00
B4B1F4	2017-07-15 22:46:00+03	55800.00
B4B1FD	2017-07-09 17:41:00+03	50800.00
B4B266	2017-08-11 07:57:00+03	52400.00
B4B28B	2017-08-02 18:19:00+03	68800.00
B4B2D8	2017-07-26 16:17:00+03	70700.00
B4B2FD	2017-07-05 01:49:00+03	40800.00
B4B31F	2017-08-13 12:31:00+03	99200.00
B4B35B	2017-07-17 17:25:00+03	77000.00
B4B372	2017-07-14 16:53:00+03	56000.00
B4B3E3	2017-07-08 10:01:00+03	130400.00
B4B40C	2017-08-06 15:26:00+03	25800.00
B4B436	2017-08-10 00:02:00+03	28000.00
B4B452	2017-08-06 14:45:00+03	55800.00
B4B45A	2017-08-04 19:22:00+03	20400.00
B4B486	2017-07-29 06:26:00+03	38600.00
B4B493	2017-08-11 10:59:00+03	29600.00
B4B49C	2017-07-22 00:57:00+03	28000.00
B4B4EC	2017-08-11 05:27:00+03	106100.00
B4B4FE	2017-07-12 11:04:00+03	23200.00
B4B54F	2017-07-28 15:18:00+03	151200.00
B4B641	2017-08-05 15:46:00+03	21400.00
B4B64D	2017-07-15 20:46:00+03	133700.00
B4B665	2017-07-28 16:09:00+03	184300.00
B4B68F	2017-07-23 15:43:00+03	6300.00
B4B6B9	2017-08-11 21:17:00+03	44300.00
B4B6F2	2017-08-07 06:12:00+03	17800.00
B4B70C	2017-07-05 07:51:00+03	65900.00
B4B78A	2017-07-05 14:06:00+03	43700.00
B4B8EB	2017-08-01 10:49:00+03	59000.00
B4B93A	2017-08-10 20:55:00+03	44100.00
B4B952	2017-08-05 02:50:00+03	111600.00
B4B9A4	2017-07-15 10:39:00+03	125400.00
B4B9FE	2017-07-11 14:14:00+03	28300.00
B4BA2B	2017-07-07 19:22:00+03	38500.00
B4BAC8	2017-08-06 12:08:00+03	55800.00
B4BAD5	2017-08-07 18:38:00+03	96300.00
B4BAE8	2017-07-07 15:49:00+03	40000.00
B4BB0A	2017-07-19 03:14:00+03	6300.00
B4BB54	2017-07-27 21:47:00+03	369000.00
B4BB5F	2017-07-27 04:31:00+03	93900.00
B4BB82	2017-07-26 05:51:00+03	20000.00
B4BBC3	2017-07-17 08:51:00+03	8200.00
B4BBD1	2017-07-25 16:07:00+03	94600.00
B4BBFA	2017-08-06 18:55:00+03	26800.00
B4BC23	2017-07-03 02:06:00+03	56000.00
B4BC2A	2017-08-13 12:09:00+03	43100.00
B4BC7E	2017-07-11 11:41:00+03	136800.00
B4BCA9	2017-07-22 17:15:00+03	117600.00
B4BCAC	2017-07-22 21:34:00+03	75300.00
B4BDC0	2017-08-11 13:45:00+03	125400.00
B4BE11	2017-08-03 17:05:00+03	65100.00
B4BE21	2017-08-13 04:44:00+03	31400.00
B4BE37	2017-08-15 13:27:00+03	31200.00
B4BE7D	2017-08-03 08:43:00+03	70600.00
B4BED4	2017-07-15 21:31:00+03	44500.00
B4BF23	2017-07-27 02:15:00+03	111600.00
B4BF7B	2017-07-13 22:56:00+03	44800.00
B4BFA7	2017-07-15 14:32:00+03	66600.00
B4BFA8	2017-08-15 17:03:00+03	46300.00
B4C017	2017-07-23 04:23:00+03	398400.00
B4C024	2017-07-13 08:41:00+03	142400.00
B4C0CD	2017-07-08 04:14:00+03	24700.00
B4C10A	2017-08-05 23:24:00+03	283000.00
B4C11F	2017-07-15 09:45:00+03	27700.00
B4C124	2017-07-06 00:18:00+03	46300.00
B4C131	2017-08-03 14:03:00+03	131600.00
B4C1B6	2017-08-12 16:10:00+03	77200.00
B4C1D1	2017-08-04 23:50:00+03	23600.00
B4C1E0	2017-06-29 05:43:00+03	13400.00
B4C211	2017-07-29 20:56:00+03	56900.00
B4C3C7	2017-07-16 11:22:00+03	28800.00
B4C404	2017-07-04 19:47:00+03	68900.00
B4C41A	2017-07-18 23:53:00+03	43200.00
B4C41B	2017-07-06 16:47:00+03	43600.00
B4C4B9	2017-07-23 00:38:00+03	40200.00
B4C4C0	2017-08-12 19:24:00+03	22000.00
B4C4E6	2017-07-29 21:09:00+03	109200.00
B4C4E9	2017-07-12 16:47:00+03	27400.00
B4C52C	2017-08-04 08:00:00+03	55800.00
B4C560	2017-07-07 04:41:00+03	75300.00
B4C585	2017-07-20 02:05:00+03	38800.00
B4C5A7	2017-08-13 22:40:00+03	104600.00
B4C5DE	2017-07-04 02:20:00+03	37200.00
B4C606	2017-07-08 03:06:00+03	39200.00
B4C697	2017-08-10 21:01:00+03	50600.00
B4C6C1	2017-08-04 23:54:00+03	114900.00
B4C6F8	2017-07-20 02:25:00+03	126300.00
B4C6FB	2017-08-06 20:11:00+03	46100.00
B4C729	2017-07-27 01:26:00+03	86800.00
B4C72D	2017-07-06 04:13:00+03	14000.00
B4C732	2017-07-04 21:49:00+03	27200.00
B4C73D	2017-08-03 12:42:00+03	34000.00
B4C759	2017-07-31 21:26:00+03	250600.00
B4C7D1	2017-08-15 12:59:00+03	86400.00
B4C819	2017-08-01 11:12:00+03	68800.00
B4C872	2017-07-14 09:56:00+03	191600.00
B4C8A0	2017-07-17 17:46:00+03	133200.00
B4C8AC	2017-08-01 19:10:00+03	56000.00
B4C8B7	2017-07-05 10:35:00+03	30200.00
B4C90F	2017-08-05 06:17:00+03	139100.00
B4C970	2017-07-21 11:59:00+03	131600.00
B4C9EB	2017-08-14 23:01:00+03	108500.00
B4C9FD	2017-07-23 09:44:00+03	30900.00
B4CA4C	2017-07-19 13:21:00+03	43300.00
B4CA95	2017-07-29 23:05:00+03	52700.00
B4CAB1	2017-08-15 06:13:00+03	7400.00
B4CAF5	2017-07-03 10:27:00+03	58000.00
B4CB11	2017-07-28 12:12:00+03	62600.00
B4CB87	2017-07-11 23:54:00+03	31600.00
B4CBD6	2017-07-31 16:38:00+03	106100.00
B4CC2A	2017-07-19 07:08:00+03	369000.00
B4CC39	2017-07-25 19:51:00+03	11600.00
B4CC8F	2017-07-12 20:17:00+03	73100.00
B4CC9C	2017-07-06 14:38:00+03	31600.00
B4CCB9	2017-07-06 09:19:00+03	133200.00
B4CCD2	2017-07-05 22:30:00+03	40000.00
B4CD12	2017-07-25 14:52:00+03	14000.00
B4CD29	2017-07-25 13:21:00+03	65100.00
B4CD48	2017-07-18 11:47:00+03	90000.00
B4CD55	2017-07-21 03:34:00+03	23900.00
B4CD56	2017-07-23 15:33:00+03	47400.00
B4CD84	2017-08-04 16:26:00+03	31600.00
B4CD97	2017-07-20 13:12:00+03	77700.00
B4CDB3	2017-07-24 06:43:00+03	66600.00
B4CDE5	2017-07-22 15:26:00+03	46000.00
B4CE4E	2017-08-04 20:54:00+03	18000.00
B4CE8F	2017-06-29 07:22:00+03	79900.00
B4CEE4	2017-08-04 07:35:00+03	28400.00
B4CEFF	2017-07-31 14:24:00+03	25600.00
B4CF0D	2017-07-31 05:07:00+03	30800.00
B4CF14	2017-08-09 04:04:00+03	68100.00
B4CF3F	2017-08-08 22:21:00+03	400600.00
B4CF44	2017-07-08 09:38:00+03	21800.00
B4CF65	2017-08-05 15:42:00+03	68100.00
B4D000	2017-07-31 18:34:00+03	79900.00
B4D04E	2017-08-02 21:10:00+03	30000.00
B4D067	2017-07-08 00:46:00+03	37200.00
B4D086	2017-08-05 03:22:00+03	9200.00
B4D096	2017-08-05 19:26:00+03	266400.00
B4D0AB	2017-07-28 19:03:00+03	172300.00
B4D0DB	2017-08-14 15:10:00+03	14400.00
B4D11B	2017-07-31 13:09:00+03	75100.00
B4D19F	2017-07-14 00:42:00+03	28000.00
B4D1D7	2017-07-22 01:12:00+03	57400.00
B4D24B	2017-07-12 19:19:00+03	67600.00
B4D24E	2017-08-12 01:58:00+03	126300.00
B4D278	2017-07-27 23:43:00+03	23600.00
B4D289	2017-07-18 12:45:00+03	170200.00
B4D2D7	2017-07-30 04:28:00+03	15600.00
B4D2F3	2017-07-19 07:45:00+03	16400.00
B4D33B	2017-07-03 20:53:00+03	51600.00
B4D36A	2017-07-30 04:52:00+03	28000.00
B4D396	2017-08-06 19:08:00+03	87800.00
B4D40F	2017-08-05 08:19:00+03	44800.00
B4D420	2017-07-25 06:51:00+03	96800.00
B4D4FF	2017-08-03 04:31:00+03	118500.00
B4D581	2017-07-06 08:38:00+03	60700.00
B4D5C4	2017-06-30 15:38:00+03	23200.00
B4D5D1	2017-08-09 03:42:00+03	103200.00
B4D5DA	2017-07-31 20:08:00+03	56000.00
B4D62D	2017-08-06 02:10:00+03	27800.00
B4D64A	2017-07-29 01:15:00+03	509700.00
B4D67F	2017-07-27 23:44:00+03	55800.00
B4D69D	2017-07-10 13:12:00+03	61500.00
B4D6A2	2017-08-08 17:25:00+03	81400.00
B4D6C1	2017-07-08 18:11:00+03	139100.00
B4D6C2	2017-08-15 15:57:00+03	195900.00
B4D760	2017-07-06 14:08:00+03	298400.00
B4D776	2017-07-01 17:31:00+03	46000.00
B4D797	2017-08-15 07:34:00+03	97900.00
B4D7A5	2017-08-02 07:36:00+03	42000.00
B4D7C2	2017-06-28 01:03:00+03	52900.00
B4D7F6	2017-07-24 21:45:00+03	43200.00
B4D812	2017-07-21 22:25:00+03	8000.00
B4D817	2017-07-15 10:19:00+03	133900.00
B4D831	2017-08-07 16:14:00+03	240600.00
B4D839	2017-08-05 18:16:00+03	27200.00
B4D93B	2017-07-21 22:46:00+03	73100.00
B4D9D4	2017-07-12 21:37:00+03	51600.00
B4DA06	2017-08-03 01:13:00+03	9200.00
B4DA43	2017-07-13 18:50:00+03	92800.00
B4DA50	2017-07-27 03:44:00+03	56000.00
B4DA5F	2017-07-23 12:12:00+03	62700.00
B4DA81	2017-07-29 21:06:00+03	224300.00
B4DAC1	2017-07-25 14:31:00+03	43400.00
B4DAEE	2017-08-09 08:19:00+03	47100.00
B4DB99	2017-07-16 03:56:00+03	21500.00
B4DB9D	2017-07-25 03:55:00+03	54500.00
B4DBEC	2017-07-18 08:17:00+03	15000.00
B4DC0D	2017-08-14 12:04:00+03	58800.00
B4DC35	2017-07-16 22:17:00+03	30800.00
B4DC70	2017-08-06 12:26:00+03	181000.00
B4DC72	2017-07-05 19:10:00+03	62100.00
B4DC74	2017-08-02 02:07:00+03	12400.00
B4DCAA	2017-07-22 22:09:00+03	270800.00
B4DCB2	2017-07-15 16:52:00+03	339900.00
B4DD44	2017-06-29 14:01:00+03	21400.00
B4DD50	2017-07-09 05:47:00+03	126500.00
B4DDA5	2017-07-25 11:10:00+03	111600.00
B4DE32	2017-08-05 10:29:00+03	135400.00
B4DE67	2017-07-23 05:20:00+03	6000.00
B4DEBF	2017-07-05 06:28:00+03	8200.00
B4DF00	2017-08-03 05:55:00+03	43200.00
B4DF5E	2017-07-27 17:56:00+03	166000.00
B4DF8B	2017-07-25 16:50:00+03	49200.00
B4DFA7	2017-08-06 00:36:00+03	102100.00
B4DFE4	2017-07-22 07:45:00+03	40800.00
B4E047	2017-08-07 08:24:00+03	178300.00
B4E05E	2017-07-16 22:13:00+03	40300.00
B4E129	2017-07-11 04:03:00+03	52000.00
B4E12A	2017-07-17 00:25:00+03	443000.00
B4E133	2017-08-05 23:50:00+03	26700.00
B4E13D	2017-06-29 01:49:00+03	100600.00
B4E20A	2017-07-28 19:51:00+03	35100.00
B4E27F	2017-07-20 18:02:00+03	56000.00
B4E290	2017-07-15 08:47:00+03	372500.00
B4E295	2017-08-15 13:12:00+03	8800.00
B4E2E3	2017-07-01 01:53:00+03	43700.00
B4E2F8	2017-08-02 01:40:00+03	98400.00
B4E317	2017-07-01 08:35:00+03	131600.00
B4E31E	2017-07-31 03:34:00+03	124400.00
B4E36E	2017-07-28 00:14:00+03	27200.00
B4E3B8	2017-07-29 19:32:00+03	40000.00
B4E3E4	2017-07-23 03:28:00+03	25200.00
B4E3F5	2017-08-01 06:15:00+03	44000.00
B4E473	2017-07-16 11:23:00+03	171700.00
B4E475	2017-07-14 20:27:00+03	24300.00
B4E47C	2017-07-25 08:05:00+03	29800.00
B4E4BC	2017-07-12 09:59:00+03	37200.00
B4E504	2017-08-08 16:24:00+03	41400.00
B4E55D	2017-07-22 11:45:00+03	58000.00
B4E577	2017-07-08 13:52:00+03	56000.00
B4E638	2017-08-13 09:58:00+03	55800.00
B4E67C	2017-08-09 12:21:00+03	98400.00
B4E68F	2017-08-11 03:53:00+03	66800.00
B4E696	2017-08-03 15:49:00+03	40100.00
B4E69E	2017-07-16 15:38:00+03	8200.00
B4E707	2017-07-04 09:01:00+03	35600.00
B4E722	2017-07-18 14:37:00+03	133200.00
B4E72E	2017-07-08 04:26:00+03	57600.00
B4E746	2017-06-29 21:30:00+03	48100.00
B4E760	2017-07-10 08:49:00+03	129000.00
B4E76F	2017-07-02 13:36:00+03	35500.00
B4E7A8	2017-08-10 07:33:00+03	73300.00
B4E807	2017-07-24 11:58:00+03	23200.00
B4E854	2017-07-03 02:35:00+03	13200.00
B4E863	2017-07-05 03:42:00+03	16400.00
B4E890	2017-07-13 22:13:00+03	23200.00
B4E891	2017-07-26 22:32:00+03	10800.00
B4E8E9	2017-08-13 22:08:00+03	265700.00
B4E8F4	2017-08-13 05:47:00+03	24000.00
B4E929	2017-07-19 23:57:00+03	65100.00
B4E92B	2017-07-21 21:52:00+03	43600.00
B4E985	2017-07-04 10:39:00+03	156100.00
B4E9C0	2017-07-09 08:17:00+03	32200.00
B4E9EE	2017-07-21 06:15:00+03	50400.00
B4EA22	2017-08-10 17:26:00+03	30200.00
B4EAA0	2017-07-11 13:01:00+03	29200.00
B4EAA1	2017-08-06 23:49:00+03	114900.00
B4EAE9	2017-07-07 06:39:00+03	92600.00
B4EB66	2017-07-28 14:56:00+03	18600.00
B4EBDC	2017-07-14 06:43:00+03	170200.00
B4EC45	2017-08-15 02:51:00+03	98300.00
B4EC49	2017-08-13 11:17:00+03	189800.00
B4EC79	2017-07-05 13:54:00+03	59800.00
B4EC81	2017-07-04 23:33:00+03	133100.00
B4EC99	2017-07-22 12:22:00+03	23400.00
B4ECC4	2017-08-11 09:58:00+03	13400.00
B4ED50	2017-07-20 19:53:00+03	56000.00
B4ED83	2017-07-02 06:53:00+03	67200.00
B4ED86	2017-08-04 21:39:00+03	152100.00
B4EE4C	2017-07-02 17:28:00+03	39300.00
B4EE87	2017-08-04 08:38:00+03	45200.00
B4EE88	2017-08-11 21:55:00+03	56000.00
B4EECC	2017-07-19 02:59:00+03	85300.00
B4EF57	2017-07-31 13:33:00+03	67600.00
B4EFAE	2017-07-11 18:09:00+03	25100.00
B4F031	2017-07-26 04:42:00+03	55800.00
B4F0B3	2017-08-01 02:38:00+03	27900.00
B4F104	2017-08-11 18:55:00+03	56600.00
B4F161	2017-07-17 05:00:00+03	24000.00
B4F256	2017-07-19 06:15:00+03	29600.00
B4F2DA	2017-07-12 03:13:00+03	68000.00
B4F357	2017-07-22 07:23:00+03	51900.00
B4F38E	2017-07-24 12:16:00+03	7300.00
B4F3B8	2017-06-29 09:37:00+03	98400.00
B4F410	2017-07-04 06:18:00+03	131600.00
B4F421	2017-07-04 23:05:00+03	677800.00
B4F429	2017-07-13 09:46:00+03	57600.00
B4F484	2017-07-11 13:02:00+03	13700.00
B4F4A2	2017-07-19 07:05:00+03	80500.00
B4F4EF	2017-07-17 15:39:00+03	21400.00
B4F535	2017-07-08 21:30:00+03	31600.00
B4F657	2017-07-22 07:34:00+03	86800.00
B4F693	2017-07-14 00:58:00+03	28800.00
B4F6E4	2017-06-27 05:46:00+03	6800.00
B4F714	2017-07-13 18:15:00+03	266200.00
B4F720	2017-06-28 17:10:00+03	25600.00
B4F732	2017-08-04 10:25:00+03	136800.00
B4F770	2017-07-25 17:21:00+03	44800.00
B4F787	2017-07-07 00:12:00+03	20000.00
B4F793	2017-07-15 11:16:00+03	66400.00
B4F7B3	2017-07-30 09:09:00+03	15000.00
B4F7F1	2017-08-15 14:03:00+03	93900.00
B4F7FE	2017-07-03 05:10:00+03	59800.00
B4F84B	2017-08-15 00:52:00+03	134400.00
B4F877	2017-08-02 22:20:00+03	70600.00
B4F8AD	2017-07-17 19:31:00+03	61800.00
B4F8F0	2017-08-02 15:10:00+03	79900.00
B4F8FE	2017-08-02 23:16:00+03	25500.00
B4F947	2017-07-26 20:19:00+03	26200.00
B4F969	2017-08-14 15:34:00+03	53500.00
B4F9AE	2017-08-14 23:49:00+03	37100.00
B4F9C8	2017-07-04 05:52:00+03	142400.00
B4F9D7	2017-08-06 22:52:00+03	59200.00
B4F9F4	2017-08-11 09:11:00+03	27200.00
B4FA0A	2017-07-21 19:37:00+03	91900.00
B4FA20	2017-07-09 15:17:00+03	62000.00
B4FA6D	2017-08-08 15:00:00+03	75300.00
B4FB1B	2017-06-29 18:10:00+03	57600.00
B4FC2D	2017-08-10 09:53:00+03	37500.00
B4FC94	2017-08-12 04:19:00+03	103500.00
B4FCA9	2017-07-30 12:53:00+03	32700.00
B4FCAF	2017-07-13 19:43:00+03	46400.00
B4FCB2	2017-07-14 10:04:00+03	112000.00
B4FCDB	2017-07-30 12:44:00+03	149100.00
B4FCEF	2017-07-15 13:26:00+03	53300.00
B4FD39	2017-08-01 03:06:00+03	112000.00
B4FD8C	2017-07-11 02:17:00+03	398500.00
B4FDAB	2017-07-04 01:55:00+03	132800.00
B4FE58	2017-07-31 14:36:00+03	36800.00
B4FE6D	2017-08-10 11:17:00+03	85000.00
B4FF21	2017-07-30 14:39:00+03	47400.00
B4FF40	2017-07-26 20:51:00+03	92900.00
B4FF4B	2017-07-07 04:17:00+03	56600.00
B4FF95	2017-07-29 05:35:00+03	23900.00
B5000F	2017-08-09 06:03:00+03	77200.00
B50058	2017-07-06 11:26:00+03	7400.00
B500AD	2017-08-05 16:03:00+03	131100.00
B500B8	2017-08-15 10:31:00+03	75600.00
B5012F	2017-07-19 02:22:00+03	64800.00
B50184	2017-08-06 20:00:00+03	165800.00
B5022B	2017-08-11 01:01:00+03	75600.00
B502CB	2017-07-19 10:10:00+03	58800.00
B503DB	2017-07-06 07:06:00+03	50100.00
B503FB	2017-07-03 05:05:00+03	6600.00
B50400	2017-08-05 20:14:00+03	6700.00
B50424	2017-07-10 10:31:00+03	30400.00
B50473	2017-08-12 02:34:00+03	136200.00
B504A3	2017-07-16 05:56:00+03	55500.00
B504DD	2017-07-22 14:06:00+03	65500.00
B504FA	2017-08-01 02:01:00+03	55800.00
B5054D	2017-07-07 18:02:00+03	38800.00
B50583	2017-07-16 14:48:00+03	56600.00
B505A2	2017-07-12 15:56:00+03	25000.00
B5061B	2017-07-01 19:44:00+03	50300.00
B5062B	2017-07-11 02:17:00+03	76700.00
B50636	2017-07-21 01:40:00+03	35700.00
B50644	2017-07-25 04:13:00+03	36200.00
B506B6	2017-07-08 14:30:00+03	67900.00
B506DD	2017-07-24 05:36:00+03	22000.00
B50723	2017-08-08 04:13:00+03	15100.00
B5084A	2017-07-16 20:29:00+03	19000.00
B50880	2017-07-02 05:32:00+03	20200.00
B508AB	2017-07-04 12:10:00+03	61800.00
B508B5	2017-08-11 19:41:00+03	136200.00
B508CF	2017-06-27 04:46:00+03	134400.00
B509D1	2017-07-05 04:48:00+03	21200.00
B509F8	2017-07-28 23:54:00+03	31200.00
B50A36	2017-08-09 14:33:00+03	128800.00
B50A73	2017-07-20 13:43:00+03	59800.00
B50A7A	2017-07-05 22:27:00+03	31300.00
B50B2C	2017-08-13 20:46:00+03	48000.00
B50B75	2017-08-10 13:13:00+03	112400.00
B50B8D	2017-07-18 22:01:00+03	59000.00
B50BBB	2017-07-24 09:16:00+03	46800.00
B50C0D	2017-07-11 17:03:00+03	50700.00
B50C2C	2017-07-08 16:12:00+03	369000.00
B50C34	2017-07-07 14:13:00+03	138500.00
B50C3B	2017-08-02 23:17:00+03	14000.00
B50C76	2017-08-14 14:07:00+03	38400.00
B50CE0	2017-08-03 12:17:00+03	266400.00
B50CE8	2017-08-09 14:05:00+03	65900.00
B50D19	2017-08-08 10:41:00+03	189700.00
B50D5B	2017-08-11 02:47:00+03	50800.00
B50D5C	2017-07-23 03:17:00+03	23400.00
B50DF9	2017-08-01 05:56:00+03	56000.00
B50E03	2017-07-23 18:58:00+03	6000.00
B50E1C	2017-08-08 11:56:00+03	59600.00
B50E29	2017-08-12 08:27:00+03	62700.00
B50E3C	2017-07-10 13:10:00+03	170300.00
B50EB6	2017-08-13 09:48:00+03	38600.00
B50EE0	2017-07-07 19:50:00+03	265600.00
B50F04	2017-08-01 21:06:00+03	28800.00
B50F1D	2017-07-10 16:31:00+03	210600.00
B50F2B	2017-07-12 05:35:00+03	44000.00
B50FC1	2017-07-10 04:25:00+03	112600.00
B50FDC	2017-07-23 14:15:00+03	96000.00
B51028	2017-07-07 04:16:00+03	47000.00
B51067	2017-07-06 13:15:00+03	18600.00
B5109C	2017-08-13 17:45:00+03	30200.00
B510C6	2017-07-25 04:52:00+03	8000.00
B510FF	2017-07-20 09:36:00+03	23200.00
B5113E	2017-07-28 08:26:00+03	106000.00
B51144	2017-07-15 00:18:00+03	34000.00
B5118B	2017-08-12 04:43:00+03	295400.00
B511D5	2017-07-26 04:03:00+03	277000.00
B512AE	2017-07-25 05:05:00+03	78200.00
B512C7	2017-08-01 03:12:00+03	27800.00
B5131A	2017-07-18 06:24:00+03	66600.00
B5132D	2017-07-05 14:00:00+03	112000.00
B51423	2017-07-16 13:50:00+03	8000.00
B5145B	2017-07-25 15:29:00+03	30600.00
B51482	2017-07-19 02:50:00+03	92800.00
B514A1	2017-08-01 05:50:00+03	15000.00
B514B9	2017-07-07 10:31:00+03	8400.00
B51545	2017-07-03 23:41:00+03	75300.00
B515DB	2017-08-09 16:20:00+03	87200.00
B51638	2017-07-10 23:32:00+03	61800.00
B5165E	2017-07-19 05:59:00+03	24400.00
B5166F	2017-08-08 16:03:00+03	28000.00
B5167B	2017-08-02 01:04:00+03	23200.00
B5168D	2017-07-31 11:43:00+03	67200.00
B5170C	2017-07-03 15:54:00+03	68800.00
B517C4	2017-08-13 14:49:00+03	56600.00
B518B3	2017-07-01 07:30:00+03	123000.00
B518D8	2017-06-30 10:25:00+03	172700.00
B518E5	2017-07-11 10:02:00+03	136600.00
B51970	2017-07-17 06:59:00+03	61500.00
B51998	2017-07-15 03:48:00+03	26000.00
B519B3	2017-07-28 10:01:00+03	189200.00
B519BA	2017-07-26 15:14:00+03	28800.00
B519BB	2017-07-05 04:00:00+03	58000.00
B519C0	2017-07-07 08:53:00+03	133200.00
B519D5	2017-07-05 17:48:00+03	13400.00
B519E5	2017-07-13 04:28:00+03	50600.00
B51A28	2017-07-16 21:52:00+03	56000.00
B51B27	2017-07-07 07:37:00+03	277800.00
B51B86	2017-07-08 15:52:00+03	43500.00
B51BDD	2017-07-06 19:21:00+03	20200.00
B51BE4	2017-08-11 00:22:00+03	21400.00
B51C3B	2017-07-15 13:22:00+03	27400.00
B51C44	2017-07-03 20:46:00+03	44000.00
B51C5B	2017-07-26 23:52:00+03	26000.00
B51C7E	2017-07-07 13:55:00+03	24800.00
B51C92	2017-07-18 15:21:00+03	55500.00
B51CF4	2017-07-16 01:25:00+03	51100.00
B51CF5	2017-07-03 20:20:00+03	398500.00
B51DCA	2017-07-09 14:12:00+03	236100.00
B51E0F	2017-08-09 12:21:00+03	99300.00
B51E40	2017-07-29 02:28:00+03	30200.00
B51E71	2017-07-06 19:41:00+03	45200.00
B51E84	2017-07-04 13:10:00+03	84000.00
B51EA1	2017-07-10 16:33:00+03	9200.00
B51ED2	2017-08-10 15:46:00+03	48800.00
B51EFA	2017-08-07 01:14:00+03	43900.00
B51FAD	2017-08-09 08:40:00+03	16000.00
B51FD6	2017-07-14 14:47:00+03	69500.00
B51FEA	2017-07-10 02:58:00+03	6000.00
B52028	2017-07-20 08:11:00+03	105600.00
B52064	2017-07-19 11:18:00+03	27800.00
B52086	2017-07-23 17:09:00+03	23600.00
B5209F	2017-07-17 21:49:00+03	66600.00
B52121	2017-07-21 04:55:00+03	65900.00
B521CB	2017-07-08 21:00:00+03	42800.00
B5220B	2017-07-26 08:54:00+03	13400.00
B52219	2017-08-15 15:34:00+03	135200.00
B5224E	2017-07-21 11:46:00+03	36200.00
B52262	2017-07-09 04:42:00+03	35700.00
B52294	2017-07-09 08:20:00+03	123000.00
B522D8	2017-07-01 19:53:00+03	85000.00
B52333	2017-07-28 19:36:00+03	23200.00
B5237C	2017-07-30 13:09:00+03	27200.00
B52473	2017-08-05 04:01:00+03	6300.00
B52493	2017-07-20 04:38:00+03	31600.00
B524FD	2017-08-07 11:29:00+03	40600.00
B52504	2017-07-08 21:04:00+03	14400.00
B52529	2017-07-29 13:08:00+03	75000.00
B52550	2017-07-11 00:27:00+03	64800.00
B5257A	2017-08-09 02:18:00+03	24300.00
B52599	2017-08-11 20:12:00+03	124800.00
B525E4	2017-07-13 11:36:00+03	42800.00
B525FD	2017-07-04 13:14:00+03	155100.00
B52635	2017-07-22 01:03:00+03	138400.00
B526B9	2017-08-10 09:12:00+03	84200.00
B52778	2017-08-11 17:04:00+03	48800.00
B5278F	2017-07-25 19:40:00+03	117200.00
B528EF	2017-07-24 01:00:00+03	10800.00
B52952	2017-07-11 22:28:00+03	479600.00
B5298A	2017-08-09 13:53:00+03	413400.00
B52997	2017-07-13 03:41:00+03	59000.00
B529A8	2017-07-04 09:33:00+03	289200.00
B529B1	2017-07-06 22:03:00+03	166100.00
B52A73	2017-07-09 12:15:00+03	196800.00
B52AA8	2017-07-01 22:30:00+03	67600.00
B52AB9	2017-07-19 09:57:00+03	22000.00
B52AE3	2017-07-27 15:19:00+03	277300.00
B52B0E	2017-08-07 21:14:00+03	64400.00
B52B3C	2017-07-11 13:34:00+03	114800.00
B52B6D	2017-08-04 11:58:00+03	38500.00
B52BA0	2017-07-05 17:05:00+03	21400.00
B52BA1	2017-08-15 16:41:00+03	92700.00
B52BF8	2017-07-08 15:07:00+03	83700.00
B52C0C	2017-07-30 21:26:00+03	55800.00
B52C4F	2017-08-06 17:39:00+03	90000.00
B52C6F	2017-08-14 10:57:00+03	99500.00
B52CDD	2017-08-04 13:45:00+03	398500.00
B52DBF	2017-07-09 08:43:00+03	176400.00
B52DC8	2017-06-29 20:28:00+03	133200.00
B52DED	2017-07-10 07:50:00+03	186900.00
B52E49	2017-07-15 21:55:00+03	38600.00
B52E52	2017-08-15 16:02:00+03	48800.00
B52E90	2017-08-02 04:10:00+03	124200.00
B52EDA	2017-07-16 23:04:00+03	88500.00
B52EF4	2017-07-09 09:11:00+03	56100.00
B52F04	2017-06-30 08:30:00+03	79900.00
B52F6E	2017-07-15 02:24:00+03	35200.00
B52F9E	2017-07-16 04:03:00+03	83700.00
B5300A	2017-07-05 12:12:00+03	73300.00
B53037	2017-07-11 05:22:00+03	125200.00
B53054	2017-08-08 20:47:00+03	30200.00
B530BA	2017-07-15 06:16:00+03	265800.00
B5316A	2017-07-31 08:41:00+03	31400.00
B53196	2017-07-08 02:25:00+03	44800.00
B531A2	2017-07-01 22:27:00+03	11000.00
B53286	2017-07-17 01:18:00+03	123000.00
B532AD	2017-07-01 12:57:00+03	46300.00
B532D2	2017-07-15 17:16:00+03	84500.00
B533B3	2017-07-05 20:22:00+03	43000.00
B533EC	2017-07-31 21:22:00+03	26000.00
B53410	2017-08-06 15:34:00+03	133200.00
B53480	2017-07-24 23:36:00+03	51600.00
B53499	2017-07-07 02:17:00+03	20600.00
B534B1	2017-07-31 18:04:00+03	15800.00
B534D8	2017-07-22 19:21:00+03	23400.00
B535EB	2017-07-25 04:03:00+03	8400.00
B53631	2017-07-07 10:40:00+03	79900.00
B53670	2017-08-06 15:52:00+03	7200.00
B536B8	2017-08-13 15:16:00+03	133200.00
B5371B	2017-07-29 17:22:00+03	51600.00
B53730	2017-07-08 14:58:00+03	16400.00
B53739	2017-07-01 05:07:00+03	25200.00
B537FF	2017-07-10 02:47:00+03	71600.00
B5382A	2017-07-05 03:40:00+03	58200.00
B53863	2017-08-08 15:41:00+03	130300.00
B53874	2017-07-21 16:07:00+03	40000.00
B53894	2017-08-12 11:10:00+03	53600.00
B538B9	2017-07-04 00:51:00+03	294200.00
B538C6	2017-07-06 20:37:00+03	28800.00
B538E8	2017-07-07 02:09:00+03	66600.00
B538FA	2017-07-03 15:21:00+03	58900.00
B53925	2017-08-13 22:31:00+03	154500.00
B5392E	2017-07-19 17:46:00+03	26000.00
B539B6	2017-07-24 17:26:00+03	88900.00
B53A7F	2017-07-26 04:55:00+03	141700.00
B53AA3	2017-08-04 01:21:00+03	35600.00
B53AA9	2017-07-10 13:47:00+03	26000.00
B53AAB	2017-07-05 04:41:00+03	28300.00
B53B2B	2017-07-28 15:59:00+03	25400.00
B53B3C	2017-07-31 01:54:00+03	40800.00
B53B41	2017-07-31 13:50:00+03	42800.00
B53BA1	2017-08-11 22:43:00+03	86300.00
B53BBF	2017-07-05 16:54:00+03	34000.00
B53BD8	2017-07-08 04:45:00+03	40800.00
B53C6D	2017-08-13 11:36:00+03	88600.00
B53D01	2017-08-04 11:17:00+03	134800.00
B53D17	2017-08-02 13:02:00+03	12600.00
B53D6E	2017-08-03 16:19:00+03	26800.00
B53DC9	2017-07-18 19:08:00+03	85000.00
B53DEE	2017-08-05 16:26:00+03	53800.00
B53E40	2017-07-20 10:42:00+03	77600.00
B53E60	2017-07-31 19:40:00+03	3700.00
B53E79	2017-06-28 15:57:00+03	80700.00
B53F02	2017-07-01 04:36:00+03	28600.00
B53F83	2017-07-14 14:05:00+03	87100.00
B54039	2017-08-01 14:40:00+03	50800.00
B54057	2017-08-10 18:20:00+03	13600.00
B5409E	2017-07-24 12:57:00+03	73200.00
B54105	2017-08-15 04:00:00+03	175800.00
B54114	2017-08-06 10:57:00+03	53300.00
B541E6	2017-07-18 01:36:00+03	20200.00
B541F3	2017-07-16 10:37:00+03	133200.00
B54205	2017-07-28 07:17:00+03	24400.00
B542AF	2017-08-11 00:31:00+03	18600.00
B542CC	2017-07-22 07:59:00+03	77200.00
B54355	2017-08-08 02:39:00+03	39200.00
B543CD	2017-07-15 09:58:00+03	254900.00
B543CE	2017-07-06 12:54:00+03	84000.00
B5444C	2017-07-19 19:05:00+03	80300.00
B54454	2017-07-31 10:39:00+03	73200.00
B54455	2017-07-17 13:17:00+03	23600.00
B544C4	2017-08-10 23:51:00+03	57900.00
B544E0	2017-08-14 07:43:00+03	84700.00
B544F3	2017-08-02 01:18:00+03	12600.00
B54516	2017-08-14 20:30:00+03	118200.00
B54598	2017-07-26 02:26:00+03	93700.00
B545B3	2017-07-11 08:01:00+03	24000.00
B545B7	2017-07-30 02:50:00+03	77900.00
B545CF	2017-07-13 03:14:00+03	26000.00
B54655	2017-08-02 12:42:00+03	135200.00
B54668	2017-06-29 12:45:00+03	131600.00
B546A4	2017-07-12 17:41:00+03	20200.00
B546DD	2017-07-12 21:34:00+03	386200.00
B5476B	2017-07-30 09:52:00+03	23600.00
B547C5	2017-07-17 14:28:00+03	94000.00
B5484F	2017-07-24 23:38:00+03	6700.00
B54933	2017-07-25 00:04:00+03	173400.00
B54A03	2017-07-20 10:42:00+03	13000.00
B54A45	2017-07-21 09:35:00+03	369000.00
B54A76	2017-08-05 01:23:00+03	199600.00
B54AA4	2017-07-13 16:35:00+03	8200.00
B54AC8	2017-07-10 23:04:00+03	55800.00
B54B01	2017-07-01 07:07:00+03	8200.00
B54C26	2017-07-30 19:26:00+03	14900.00
B54C6A	2017-07-21 03:22:00+03	36400.00
B54DA6	2017-08-04 19:21:00+03	12600.00
B54DA8	2017-08-07 11:52:00+03	31200.00
B54DD4	2017-08-09 05:21:00+03	67600.00
B54DD7	2017-07-12 17:27:00+03	52300.00
B54DFA	2017-08-13 12:48:00+03	40000.00
B54E09	2017-07-26 08:20:00+03	24200.00
B54E62	2017-07-07 00:01:00+03	44000.00
B54E6B	2017-08-02 21:58:00+03	88600.00
B54E71	2017-08-11 11:40:00+03	44600.00
B54EA1	2017-08-15 07:45:00+03	35800.00
B54EBC	2017-07-01 14:25:00+03	6700.00
B54EE2	2017-07-23 23:01:00+03	18600.00
B54EEB	2017-08-08 11:25:00+03	25600.00
B54F57	2017-07-23 23:35:00+03	89700.00
B54FC2	2017-07-02 06:52:00+03	75300.00
B5502B	2017-08-07 09:05:00+03	265600.00
B55045	2017-07-14 04:16:00+03	185300.00
B55088	2017-07-14 07:58:00+03	13600.00
B550BB	2017-08-10 03:04:00+03	69900.00
B55226	2017-07-05 09:31:00+03	22000.00
B5528C	2017-08-12 14:23:00+03	6700.00
B552B4	2017-08-13 20:04:00+03	97900.00
B552F5	2017-07-24 20:44:00+03	89600.00
B55386	2017-07-15 07:30:00+03	26000.00
B553D9	2017-07-21 05:07:00+03	241300.00
B55405	2017-07-16 11:53:00+03	31000.00
B554A3	2017-07-30 23:27:00+03	62600.00
B554A4	2017-08-08 20:12:00+03	119600.00
B554C3	2017-07-22 20:14:00+03	14000.00
B554C7	2017-07-07 23:19:00+03	60400.00
B554E2	2017-07-05 17:10:00+03	29200.00
B554F4	2017-07-12 03:07:00+03	46400.00
B554F6	2017-07-23 11:00:00+03	15100.00
B555B0	2017-08-13 13:20:00+03	147100.00
B555EE	2017-08-13 03:41:00+03	25400.00
B555F4	2017-07-05 23:44:00+03	260900.00
B55600	2017-07-15 05:03:00+03	21400.00
B556F8	2017-08-06 22:51:00+03	121600.00
B55711	2017-07-20 12:54:00+03	62700.00
B5572A	2017-07-25 07:28:00+03	271200.00
B55769	2017-08-12 18:51:00+03	85000.00
B557A0	2017-07-31 03:25:00+03	24400.00
B557D7	2017-07-27 08:39:00+03	31600.00
B55824	2017-08-03 09:08:00+03	36200.00
B55843	2017-07-27 14:37:00+03	25000.00
B55958	2017-07-30 21:48:00+03	229900.00
B559AF	2017-07-05 18:44:00+03	56000.00
B55A04	2017-07-22 03:07:00+03	109600.00
B55A36	2017-08-06 23:05:00+03	31600.00
B55A60	2017-07-06 18:30:00+03	67400.00
B55AB0	2017-07-29 16:02:00+03	6700.00
B55AD6	2017-07-14 01:37:00+03	55600.00
B55AEC	2017-07-20 15:05:00+03	103800.00
B55AEE	2017-07-07 16:45:00+03	68400.00
B55B15	2017-08-07 17:21:00+03	46000.00
B55B1D	2017-07-16 14:45:00+03	23600.00
B55BA4	2017-07-13 23:58:00+03	64700.00
B55BBC	2017-07-11 13:42:00+03	132800.00
B55C65	2017-07-26 02:04:00+03	14400.00
B55C7C	2017-07-08 06:08:00+03	94900.00
B55C85	2017-07-11 02:57:00+03	67600.00
B55C92	2017-07-18 00:49:00+03	8200.00
B55CA3	2017-08-02 01:06:00+03	36000.00
B55CC4	2017-08-11 04:10:00+03	115800.00
B55D23	2017-07-12 17:58:00+03	138000.00
B55D2A	2017-07-08 00:52:00+03	20500.00
B55D41	2017-07-26 10:36:00+03	28000.00
B55D44	2017-08-10 04:14:00+03	56600.00
B55D9B	2017-07-10 18:05:00+03	24400.00
B55DE0	2017-08-10 01:48:00+03	57800.00
B55E2C	2017-07-24 23:15:00+03	270800.00
B55E3D	2017-07-01 14:43:00+03	59800.00
B55E5D	2017-07-26 17:55:00+03	24700.00
B55E64	2017-07-28 01:11:00+03	56000.00
B55F38	2017-07-03 15:10:00+03	58800.00
B55FB1	2017-07-01 02:09:00+03	30800.00
B55FD9	2017-07-17 22:55:00+03	123000.00
B55FE0	2017-07-08 04:30:00+03	46400.00
B55FE2	2017-07-21 08:26:00+03	38400.00
B5609D	2017-07-12 17:49:00+03	34200.00
B560A1	2017-08-08 12:09:00+03	20000.00
B56115	2017-07-13 10:02:00+03	26000.00
B5621E	2017-08-05 11:30:00+03	43100.00
B56271	2017-07-05 13:30:00+03	24400.00
B562C2	2017-07-21 17:26:00+03	38600.00
B562CC	2017-07-18 15:59:00+03	92800.00
B56373	2017-07-17 06:29:00+03	56000.00
B5637A	2017-07-26 12:09:00+03	133200.00
B5640A	2017-08-07 08:36:00+03	46400.00
B56442	2017-07-20 22:40:00+03	90000.00
B5646C	2017-07-06 04:27:00+03	136800.00
B564AA	2017-07-14 01:27:00+03	52000.00
B564C6	2017-08-11 16:06:00+03	26200.00
B564C7	2017-08-10 06:26:00+03	114900.00
B564CA	2017-07-13 02:41:00+03	99200.00
B56514	2017-07-30 14:24:00+03	15900.00
B5655C	2017-07-22 02:01:00+03	57600.00
B56574	2017-08-13 08:06:00+03	31200.00
B565CE	2017-08-13 05:54:00+03	27900.00
B565DE	2017-08-09 16:44:00+03	94700.00
B565E2	2017-08-12 11:59:00+03	26000.00
B56622	2017-07-09 23:17:00+03	26800.00
B5666E	2017-08-15 11:00:00+03	82000.00
B566D3	2017-07-26 23:53:00+03	90800.00
B5670F	2017-08-06 13:17:00+03	369000.00
B5676B	2017-07-11 02:34:00+03	129800.00
B567CD	2017-07-25 18:11:00+03	13700.00
B56882	2017-08-10 06:16:00+03	171400.00
B568F5	2017-07-17 23:43:00+03	111600.00
B56976	2017-07-10 15:16:00+03	72400.00
B56982	2017-07-14 07:18:00+03	13600.00
B56984	2017-08-11 11:41:00+03	22200.00
B56A38	2017-08-10 18:31:00+03	65500.00
B56A43	2017-07-11 00:38:00+03	46000.00
B56A4E	2017-08-04 22:41:00+03	67600.00
B56A62	2017-07-11 07:25:00+03	33300.00
B56A8C	2017-08-10 15:04:00+03	97900.00
B56AFE	2017-07-17 13:42:00+03	141200.00
B56B99	2017-07-09 10:31:00+03	56000.00
B56BEA	2017-07-28 14:34:00+03	86300.00
B56C35	2017-07-29 21:09:00+03	57500.00
B56C3C	2017-08-15 05:15:00+03	169600.00
B56C64	2017-07-09 01:52:00+03	111600.00
B56C76	2017-08-12 11:34:00+03	36800.00
B56C91	2017-07-17 09:44:00+03	56000.00
B56C9D	2017-07-13 08:22:00+03	44600.00
B56CEA	2017-07-21 03:38:00+03	27900.00
B56D2E	2017-07-23 17:46:00+03	189200.00
B56D76	2017-07-24 17:13:00+03	133100.00
B56D92	2017-07-28 10:21:00+03	103500.00
B56E10	2017-07-19 18:25:00+03	64800.00
B56E8C	2017-08-04 13:00:00+03	48600.00
B56E99	2017-08-01 23:13:00+03	129700.00
B56F02	2017-07-18 13:59:00+03	51200.00
B56F03	2017-07-12 21:19:00+03	111600.00
B56F07	2017-07-05 02:01:00+03	23200.00
B56F4D	2017-08-14 22:30:00+03	27000.00
B56F7B	2017-07-13 15:48:00+03	47200.00
B56FA4	2017-07-21 15:04:00+03	258400.00
B56FF7	2017-08-15 12:13:00+03	24700.00
B5700B	2017-07-29 13:55:00+03	26000.00
B57055	2017-07-03 16:07:00+03	146600.00
B57084	2017-07-25 10:57:00+03	81200.00
B57154	2017-08-11 17:29:00+03	26000.00
B57169	2017-07-15 13:49:00+03	51600.00
B57186	2017-08-08 00:38:00+03	106200.00
B57192	2017-07-07 14:54:00+03	406200.00
B571B8	2017-07-19 22:51:00+03	19600.00
B571C2	2017-07-20 17:08:00+03	26600.00
B571C9	2017-08-03 22:46:00+03	25100.00
B571CE	2017-07-06 06:30:00+03	6700.00
B57256	2017-08-09 00:01:00+03	185800.00
B572C6	2017-07-19 14:12:00+03	39300.00
B5732F	2017-08-02 03:46:00+03	25400.00
B57342	2017-08-02 03:23:00+03	12400.00
B57385	2017-07-07 12:36:00+03	38500.00
B573B5	2017-08-04 21:37:00+03	46400.00
B57441	2017-07-20 08:38:00+03	26700.00
B5749D	2017-07-23 07:42:00+03	73600.00
B574C7	2017-07-10 03:15:00+03	32800.00
B57531	2017-08-11 22:12:00+03	8400.00
B57592	2017-08-01 21:07:00+03	92900.00
B575AB	2017-07-27 22:48:00+03	90800.00
B575ED	2017-07-16 08:59:00+03	193700.00
B575F6	2017-07-09 21:33:00+03	90400.00
B5765A	2017-07-27 08:17:00+03	72200.00
B57673	2017-07-11 14:51:00+03	257600.00
B576E6	2017-07-05 12:28:00+03	37200.00
B57721	2017-07-26 18:16:00+03	33100.00
B57817	2017-07-14 19:00:00+03	105700.00
B5781B	2017-08-13 03:38:00+03	89700.00
B57886	2017-08-12 21:46:00+03	15900.00
B578BF	2017-07-11 14:38:00+03	37700.00
B57920	2017-07-05 14:27:00+03	64800.00
B5792A	2017-06-30 19:24:00+03	202300.00
B5793A	2017-07-24 12:30:00+03	57100.00
B5796D	2017-08-11 13:56:00+03	83000.00
B579C8	2017-08-05 00:29:00+03	16400.00
B57A10	2017-08-08 03:27:00+03	40000.00
B57A54	2017-07-27 01:41:00+03	286700.00
B57A7F	2017-08-05 13:34:00+03	86600.00
B57A8F	2017-07-03 15:15:00+03	93900.00
B57AFE	2017-07-22 22:59:00+03	52700.00
B57B2B	2017-06-30 17:39:00+03	75600.00
B57B32	2017-08-04 04:55:00+03	21800.00
B57B8C	2017-08-11 17:03:00+03	18600.00
B57C6A	2017-07-20 04:57:00+03	85600.00
B57C91	2017-07-06 22:11:00+03	20000.00
B57CC3	2017-08-12 21:34:00+03	28800.00
B57D27	2017-08-02 02:30:00+03	10800.00
B57D52	2017-08-03 09:37:00+03	203400.00
B57D6C	2017-08-13 07:40:00+03	6600.00
B57D94	2017-08-04 01:07:00+03	137400.00
B57DD3	2017-07-17 15:44:00+03	76800.00
B57E26	2017-07-25 12:24:00+03	38400.00
B57E2A	2017-07-19 01:37:00+03	27000.00
B57EE0	2017-07-30 21:47:00+03	36000.00
B57EEB	2017-07-29 18:59:00+03	9800.00
B57EFF	2017-07-06 11:52:00+03	56600.00
B57F21	2017-08-11 10:22:00+03	178800.00
B57F75	2017-07-06 03:39:00+03	47000.00
B57FC1	2017-07-28 07:47:00+03	65500.00
B57FF6	2017-08-15 11:06:00+03	69100.00
B5805A	2017-06-30 10:20:00+03	40800.00
B5808D	2017-07-21 15:58:00+03	6700.00
B580A1	2017-08-02 11:04:00+03	28800.00
B580B1	2017-07-20 12:36:00+03	39800.00
B580B9	2017-07-28 14:10:00+03	53300.00
B58127	2017-07-03 03:07:00+03	25600.00
B581CC	2017-07-01 06:25:00+03	16400.00
B58224	2017-07-17 04:22:00+03	259000.00
B5822B	2017-08-14 18:29:00+03	96800.00
B5826A	2017-08-05 06:36:00+03	55800.00
B5827F	2017-08-14 13:03:00+03	92000.00
B58284	2017-07-08 06:49:00+03	75300.00
B582CC	2017-07-11 20:51:00+03	56000.00
B58315	2017-07-13 16:46:00+03	132800.00
B5831B	2017-07-26 08:25:00+03	125000.00
B58389	2017-07-24 20:49:00+03	67200.00
B58407	2017-08-12 06:55:00+03	37200.00
B5841C	2017-07-03 12:14:00+03	13600.00
B58434	2017-07-25 07:45:00+03	14400.00
B58459	2017-07-08 10:29:00+03	111600.00
B584CD	2017-07-30 05:21:00+03	97900.00
B58675	2017-07-01 17:09:00+03	70400.00
B586A4	2017-07-27 02:03:00+03	20200.00
B586C2	2017-07-12 07:51:00+03	47600.00
B58740	2017-08-06 20:56:00+03	58000.00
B58780	2017-07-23 12:49:00+03	42400.00
B58799	2017-07-07 06:41:00+03	265700.00
B587C7	2017-08-10 19:09:00+03	99000.00
B58832	2017-07-24 04:06:00+03	35200.00
B58852	2017-07-16 01:46:00+03	13600.00
B588CC	2017-08-09 18:27:00+03	67700.00
B58900	2017-08-09 14:53:00+03	86800.00
B58931	2017-08-13 15:35:00+03	28200.00
B58942	2017-07-25 10:00:00+03	187600.00
B58945	2017-08-01 02:10:00+03	139500.00
B589A3	2017-07-17 09:08:00+03	28300.00
B589F4	2017-08-12 12:05:00+03	35700.00
B589FD	2017-08-12 06:13:00+03	178800.00
B58A1E	2017-07-12 08:31:00+03	277600.00
B58A6B	2017-07-09 23:31:00+03	111600.00
B58AFF	2017-07-26 20:45:00+03	8200.00
B58B10	2017-07-06 04:51:00+03	12600.00
B58B3A	2017-08-14 02:12:00+03	40700.00
B58B43	2017-07-01 00:17:00+03	133200.00
B58B89	2017-08-01 12:01:00+03	199700.00
B58B8F	2017-07-02 16:38:00+03	66600.00
B58BB4	2017-07-24 23:14:00+03	50100.00
B58BF5	2017-08-03 20:14:00+03	143000.00
B58C47	2017-07-20 00:25:00+03	73100.00
B58C51	2017-07-13 13:46:00+03	44800.00
B58CC0	2017-08-01 11:51:00+03	85000.00
B58CD6	2017-07-24 20:52:00+03	28800.00
B58CE7	2017-07-09 14:57:00+03	51800.00
B58D5A	2017-08-13 03:52:00+03	68900.00
B58D8C	2017-08-06 15:41:00+03	13400.00
B58D94	2017-07-30 10:49:00+03	248500.00
B58DBC	2017-08-02 08:17:00+03	112000.00
B58DF3	2017-07-29 19:51:00+03	106400.00
B58E28	2017-08-02 05:07:00+03	257600.00
B58E67	2017-07-31 15:38:00+03	91100.00
B58E85	2017-07-02 21:04:00+03	66600.00
B58EAC	2017-07-06 13:38:00+03	147000.00
B58EDA	2017-07-21 16:02:00+03	56100.00
B58EDF	2017-08-11 22:59:00+03	62600.00
B58F36	2017-07-25 19:52:00+03	139100.00
B58F72	2017-07-16 13:05:00+03	7200.00
B58F86	2017-07-24 10:32:00+03	43400.00
B58F99	2017-08-13 05:57:00+03	14800.00
B58FC9	2017-08-07 07:02:00+03	13200.00
B59001	2017-08-10 23:18:00+03	186000.00
B59025	2017-07-16 22:08:00+03	133200.00
B59031	2017-07-27 04:43:00+03	615000.00
B59036	2017-07-27 14:43:00+03	99300.00
B59043	2017-07-19 18:02:00+03	126800.00
B59079	2017-08-04 16:55:00+03	129700.00
B590BC	2017-08-15 16:56:00+03	126000.00
B59106	2017-07-21 19:35:00+03	8600.00
B59114	2017-08-15 12:26:00+03	26700.00
B5912F	2017-07-10 05:18:00+03	69500.00
B59166	2017-08-08 01:15:00+03	62000.00
B59173	2017-06-30 03:10:00+03	66400.00
B59179	2017-07-05 05:59:00+03	144400.00
B591AC	2017-07-11 03:38:00+03	23400.00
B59290	2017-07-10 07:03:00+03	43500.00
B592D8	2017-08-11 21:39:00+03	85000.00
B59353	2017-07-21 21:24:00+03	258400.00
B59369	2017-08-01 07:28:00+03	29300.00
B5937E	2017-07-21 11:32:00+03	24300.00
B593B5	2017-07-08 15:44:00+03	170000.00
B593EF	2017-07-07 09:32:00+03	94300.00
B593F1	2017-08-06 21:42:00+03	86800.00
B59427	2017-07-23 12:42:00+03	43000.00
B5946B	2017-08-07 22:21:00+03	23200.00
B59472	2017-08-11 05:11:00+03	20200.00
B59474	2017-07-10 09:24:00+03	177600.00
B5947F	2017-08-07 10:51:00+03	36200.00
B594AE	2017-08-05 06:59:00+03	49900.00
B594ED	2017-07-11 04:02:00+03	167400.00
B595A2	2017-06-28 09:02:00+03	35300.00
B595AF	2017-08-14 22:20:00+03	77600.00
B595C4	2017-08-03 10:03:00+03	188000.00
B59655	2017-07-24 04:43:00+03	41200.00
B5968B	2017-07-02 21:19:00+03	49100.00
B596BA	2017-08-12 14:59:00+03	52700.00
B596C1	2017-08-04 01:14:00+03	11600.00
B596CC	2017-08-12 12:49:00+03	51900.00
B59714	2017-07-09 21:39:00+03	75600.00
B59825	2017-08-10 07:02:00+03	168000.00
B5983B	2017-07-17 16:13:00+03	94000.00
B5988B	2017-07-12 23:15:00+03	28800.00
B599D8	2017-07-05 06:37:00+03	133100.00
B599DF	2017-08-07 19:19:00+03	89200.00
B599E2	2017-08-06 19:34:00+03	49100.00
B59A27	2017-07-31 16:14:00+03	136800.00
B59A6B	2017-08-01 17:38:00+03	28000.00
B59A90	2017-07-05 12:57:00+03	40800.00
B59AA4	2017-08-12 16:07:00+03	131100.00
B59AAA	2017-07-21 12:16:00+03	133200.00
B59AB4	2017-07-11 10:02:00+03	30200.00
B59AF8	2017-07-22 15:57:00+03	23400.00
B59B07	2017-07-08 06:54:00+03	23600.00
B59B26	2017-07-27 23:09:00+03	75300.00
B59B57	2017-07-17 11:30:00+03	22100.00
B59B7F	2017-07-19 01:25:00+03	44500.00
B59B9D	2017-08-01 03:29:00+03	133700.00
B59BD0	2017-08-08 23:45:00+03	134400.00
B59BE5	2017-07-28 08:36:00+03	29600.00
B59C0A	2017-08-06 05:04:00+03	23600.00
B59C37	2017-07-15 05:02:00+03	60400.00
B59C4B	2017-07-09 14:58:00+03	28300.00
B59C5F	2017-07-02 15:48:00+03	48500.00
B59C6D	2017-07-07 13:13:00+03	80800.00
B59CA1	2017-06-26 06:04:00+03	11800.00
B59D0C	2017-07-14 01:52:00+03	88900.00
B59D39	2017-07-10 12:14:00+03	62800.00
B59D72	2017-07-18 10:39:00+03	53600.00
B59D85	2017-07-19 14:29:00+03	30200.00
B59D9B	2017-07-03 04:12:00+03	27600.00
B59DA0	2017-08-15 04:09:00+03	28800.00
B59E02	2017-07-06 12:59:00+03	19600.00
B59E79	2017-08-01 14:11:00+03	79900.00
B59E7C	2017-08-11 02:38:00+03	438900.00
B59E88	2017-06-26 08:15:00+03	153100.00
B59E8C	2017-07-23 15:31:00+03	51900.00
B59ED3	2017-08-07 18:01:00+03	23900.00
B59F24	2017-07-19 22:04:00+03	12600.00
B59F3E	2017-07-10 16:37:00+03	28800.00
B59F80	2017-07-07 08:15:00+03	49200.00
B59F9A	2017-08-14 11:27:00+03	38400.00
B5A031	2017-07-04 16:39:00+03	61500.00
B5A0C1	2017-08-09 12:20:00+03	49200.00
B5A0D1	2017-07-14 04:00:00+03	112000.00
B5A0D3	2017-07-31 17:29:00+03	3700.00
B5A103	2017-08-01 08:49:00+03	20400.00
B5A148	2017-08-04 00:43:00+03	40200.00
B5A1A3	2017-06-30 15:22:00+03	112000.00
B5A1CF	2017-08-02 19:41:00+03	35300.00
B5A210	2017-08-05 17:35:00+03	93400.00
B5A211	2017-08-04 16:28:00+03	65500.00
B5A21D	2017-07-22 16:27:00+03	28800.00
B5A269	2017-07-28 09:32:00+03	31100.00
B5A26E	2017-08-06 21:31:00+03	147700.00
B5A29A	2017-08-10 17:19:00+03	35600.00
B5A2D1	2017-07-16 10:16:00+03	11600.00
B5A2E7	2017-07-24 14:40:00+03	145300.00
B5A360	2017-07-27 08:46:00+03	25600.00
B5A3F8	2017-07-05 18:19:00+03	31100.00
B5A46C	2017-08-07 01:08:00+03	66800.00
B5A4BB	2017-07-17 17:37:00+03	21400.00
B5A4D3	2017-07-05 14:11:00+03	115900.00
B5A571	2017-08-13 15:34:00+03	12800.00
B5A57F	2017-07-26 22:49:00+03	72400.00
B5A5B8	2017-07-16 12:24:00+03	36200.00
B5A5D3	2017-06-29 11:01:00+03	24800.00
B5A5E5	2017-08-05 00:43:00+03	260300.00
B5A62B	2017-08-11 20:18:00+03	26700.00
B5A651	2017-07-27 23:26:00+03	46400.00
B5A676	2017-08-08 10:24:00+03	98400.00
B5A6AC	2017-07-03 12:58:00+03	10600.00
B5A6DA	2017-07-24 20:19:00+03	98400.00
B5A72C	2017-07-03 19:49:00+03	96300.00
B5A747	2017-07-04 01:29:00+03	116900.00
B5A792	2017-08-05 19:23:00+03	246000.00
B5A82B	2017-07-12 13:09:00+03	247700.00
B5A833	2017-06-29 05:34:00+03	77200.00
B5A83D	2017-07-04 07:42:00+03	173500.00
B5A87A	2017-08-02 08:15:00+03	21800.00
B5A884	2017-07-19 22:06:00+03	54500.00
B5A8D8	2017-07-31 14:38:00+03	85200.00
B5A933	2017-08-06 00:10:00+03	54500.00
B5A951	2017-08-14 07:36:00+03	147700.00
B5A9C9	2017-08-07 00:10:00+03	23600.00
B5A9E9	2017-07-05 10:22:00+03	134000.00
B5AA21	2017-07-26 10:26:00+03	87300.00
B5AA3C	2017-07-06 14:01:00+03	147200.00
B5AA42	2017-08-07 23:06:00+03	57600.00
B5AA49	2017-07-16 20:38:00+03	46300.00
B5AA5F	2017-08-13 09:26:00+03	18600.00
B5AA96	2017-08-13 23:46:00+03	23200.00
B5AABC	2017-08-05 10:29:00+03	6200.00
B5AAF4	2017-07-30 17:32:00+03	58600.00
B5ABE0	2017-08-09 16:20:00+03	25800.00
B5AC53	2017-08-06 23:14:00+03	16000.00
B5ACC9	2017-08-15 06:25:00+03	99300.00
B5ADD3	2017-07-17 14:08:00+03	46400.00
B5ADFC	2017-07-31 08:18:00+03	24400.00
B5AE1F	2017-08-14 23:22:00+03	6700.00
B5AF38	2017-07-21 08:26:00+03	12400.00
B5AF6B	2017-07-01 08:52:00+03	58600.00
B5AFAD	2017-07-15 20:24:00+03	45600.00
B5AFCD	2017-07-18 17:51:00+03	12600.00
B5AFE0	2017-07-20 10:37:00+03	46300.00
B5AFF5	2017-08-07 18:48:00+03	145100.00
B5B01F	2017-07-29 21:46:00+03	21200.00
B5B042	2017-07-02 21:58:00+03	124200.00
B5B04E	2017-08-01 08:45:00+03	23600.00
B5B10C	2017-07-29 22:17:00+03	19600.00
B5B1AB	2017-07-26 10:10:00+03	25100.00
B5B1BF	2017-07-09 00:43:00+03	117600.00
B5B1C2	2017-07-04 10:46:00+03	22000.00
B5B1C4	2017-07-14 14:29:00+03	132800.00
B5B1FE	2017-07-07 21:30:00+03	125400.00
B5B272	2017-07-25 09:33:00+03	27900.00
B5B27D	2017-08-11 09:01:00+03	30200.00
B5B341	2017-07-27 06:38:00+03	143100.00
B5B39A	2017-08-08 09:39:00+03	36200.00
B5B3A4	2017-07-27 17:27:00+03	23200.00
B5B3A5	2017-07-25 20:34:00+03	99600.00
B5B3CB	2017-07-20 09:42:00+03	66600.00
B5B439	2017-07-04 03:38:00+03	12600.00
B5B474	2017-07-23 17:04:00+03	174600.00
B5B475	2017-08-04 17:21:00+03	64300.00
B5B48A	2017-07-10 13:23:00+03	39200.00
B5B495	2017-08-01 06:55:00+03	271200.00
B5B4A5	2017-08-09 17:14:00+03	8000.00
B5B4B9	2017-06-29 21:49:00+03	30200.00
B5B4CB	2017-08-03 09:01:00+03	136500.00
B5B4F6	2017-08-01 02:19:00+03	58600.00
B5B4F9	2017-08-07 08:33:00+03	106400.00
B5B510	2017-07-29 11:10:00+03	147400.00
B5B515	2017-07-26 06:54:00+03	9800.00
B5B559	2017-07-27 23:01:00+03	131600.00
B5B5A4	2017-08-12 10:28:00+03	52500.00
B5B5CB	2017-07-06 17:42:00+03	15900.00
B5B5E8	2017-08-14 07:48:00+03	22500.00
B5B625	2017-07-06 07:12:00+03	125200.00
B5B69C	2017-08-13 14:40:00+03	98000.00
B5B6B8	2017-07-12 10:43:00+03	106100.00
B5B6E9	2017-07-20 16:22:00+03	70600.00
B5B781	2017-07-13 23:56:00+03	26200.00
B5B7C4	2017-07-31 09:17:00+03	148200.00
B5B7CF	2017-07-06 07:44:00+03	46400.00
B5B7EF	2017-07-27 01:59:00+03	199700.00
B5B83F	2017-08-13 23:38:00+03	84000.00
B5B958	2017-07-03 22:03:00+03	14000.00
B5B95A	2017-06-28 20:39:00+03	44000.00
B5B995	2017-08-06 16:12:00+03	139300.00
B5BA5C	2017-07-18 21:43:00+03	12000.00
B5BA8E	2017-07-07 19:42:00+03	402400.00
B5BAC7	2017-08-11 11:56:00+03	67800.00
B5BACC	2017-07-04 20:43:00+03	58600.00
B5BAD2	2017-07-12 00:42:00+03	48300.00
B5BB15	2017-08-06 21:02:00+03	28000.00
B5BB52	2017-07-19 10:33:00+03	22600.00
B5BB9E	2017-07-12 13:26:00+03	46200.00
B5BBAE	2017-07-25 22:52:00+03	20600.00
B5BBD2	2017-08-14 21:32:00+03	23400.00
B5BBD6	2017-07-20 04:55:00+03	58000.00
B5BC00	2017-07-22 18:21:00+03	73600.00
B5BC1B	2017-08-01 17:26:00+03	36200.00
B5BC1D	2017-07-22 02:24:00+03	20100.00
B5BC5A	2017-07-10 08:52:00+03	55800.00
B5BC68	2017-08-05 08:49:00+03	105000.00
B5BCFF	2017-08-01 17:15:00+03	98400.00
B5BD2D	2017-07-09 16:09:00+03	41600.00
B5BD69	2017-07-17 00:38:00+03	52000.00
B5BDA6	2017-07-19 11:39:00+03	166100.00
B5BDD4	2017-07-12 13:00:00+03	301800.00
B5BE64	2017-07-17 15:07:00+03	81600.00
B5BE91	2017-07-27 20:17:00+03	28000.00
B5BF55	2017-08-04 09:13:00+03	74400.00
B5BF63	2017-07-29 19:01:00+03	47000.00
B5BFB8	2017-07-09 22:53:00+03	46000.00
B5C043	2017-08-06 07:40:00+03	18600.00
B5C071	2017-08-11 23:49:00+03	24400.00
B5C082	2017-08-03 21:09:00+03	51900.00
B5C0BB	2017-07-30 06:30:00+03	61500.00
B5C0D2	2017-07-22 22:21:00+03	47400.00
B5C0E3	2017-08-01 10:59:00+03	85000.00
B5C0ED	2017-07-21 02:36:00+03	73600.00
B5C166	2017-07-14 15:34:00+03	92400.00
B5C1B9	2017-07-05 01:30:00+03	88500.00
B5C1CB	2017-08-10 03:20:00+03	263000.00
B5C1D0	2017-08-08 00:30:00+03	106400.00
B5C1E9	2017-06-28 12:38:00+03	135600.00
B5C255	2017-07-07 16:46:00+03	80200.00
B5C26A	2017-07-26 10:49:00+03	23600.00
B5C29E	2017-07-21 03:29:00+03	44600.00
B5C304	2017-08-06 13:57:00+03	63700.00
B5C311	2017-08-07 10:46:00+03	18600.00
B5C328	2017-07-20 01:02:00+03	11800.00
B5C3B0	2017-08-15 12:09:00+03	125300.00
B5C3B2	2017-08-13 05:06:00+03	7200.00
B5C460	2017-08-07 15:51:00+03	43900.00
B5C479	2017-07-11 19:30:00+03	41500.00
B5C4B1	2017-08-08 02:05:00+03	133100.00
B5C4C2	2017-07-01 00:13:00+03	24400.00
B5C4D6	2017-08-08 20:24:00+03	29600.00
B5C4E8	2017-07-11 02:43:00+03	119300.00
B5C57E	2017-07-15 01:49:00+03	54400.00
B5C589	2017-07-13 09:31:00+03	46000.00
B5C58B	2017-08-01 22:34:00+03	121700.00
B5C5BF	2017-07-05 12:52:00+03	47000.00
B5C661	2017-08-01 16:37:00+03	99000.00
B5C6A8	2017-07-14 00:06:00+03	133200.00
B5C703	2017-08-04 00:54:00+03	120700.00
B5C70D	2017-08-14 04:25:00+03	94200.00
B5C825	2017-07-14 13:38:00+03	61900.00
B5C885	2017-07-22 12:45:00+03	136800.00
B5C9C7	2017-07-30 04:47:00+03	193900.00
B5C9FB	2017-08-13 15:39:00+03	18400.00
B5CA23	2017-08-01 12:37:00+03	35200.00
B5CA6D	2017-07-16 22:20:00+03	84500.00
B5CAB4	2017-07-13 00:53:00+03	46400.00
B5CAE0	2017-07-24 10:27:00+03	113800.00
B5CAE8	2017-07-13 09:03:00+03	26000.00
B5CB52	2017-07-19 09:26:00+03	48800.00
B5CB9E	2017-08-14 05:50:00+03	54000.00
B5CBB1	2017-07-01 08:40:00+03	57200.00
B5CBD5	2017-08-12 04:17:00+03	194000.00
B5CC01	2017-07-04 06:35:00+03	49800.00
B5CCA3	2017-08-08 18:56:00+03	193600.00
B5CCC9	2017-07-21 18:16:00+03	314400.00
B5CCD8	2017-07-03 06:40:00+03	78700.00
B5CD4F	2017-08-04 17:40:00+03	231300.00
B5CD72	2017-07-14 22:49:00+03	66000.00
B5CD78	2017-07-18 04:49:00+03	32100.00
B5CDC6	2017-07-16 20:10:00+03	8000.00
B5CDE0	2017-08-04 07:57:00+03	122300.00
B5CEC7	2017-07-23 11:30:00+03	133200.00
B5CF0D	2017-08-11 16:29:00+03	21400.00
B5CF53	2017-07-07 04:24:00+03	28800.00
B5CFA9	2017-07-08 06:28:00+03	16400.00
B5CFD6	2017-08-10 11:24:00+03	112600.00
B5D006	2017-07-12 05:13:00+03	37600.00
B5D025	2017-07-23 21:24:00+03	28000.00
B5D094	2017-07-28 18:25:00+03	116800.00
B5D0BF	2017-07-23 10:13:00+03	120400.00
B5D12D	2017-08-03 17:19:00+03	69500.00
B5D153	2017-08-05 01:31:00+03	42400.00
B5D183	2017-07-12 14:34:00+03	52000.00
B5D224	2017-08-03 13:19:00+03	58900.00
B5D22E	2017-07-26 05:38:00+03	24400.00
B5D244	2017-08-14 16:39:00+03	62600.00
B5D25B	2017-06-29 02:38:00+03	136700.00
B5D26D	2017-07-17 08:37:00+03	114800.00
B5D375	2017-08-11 10:15:00+03	196800.00
B5D3C0	2017-08-12 14:10:00+03	20200.00
B5D3CE	2017-08-02 07:07:00+03	84500.00
B5D3D2	2017-08-15 09:23:00+03	59000.00
B5D402	2017-07-11 04:29:00+03	19600.00
B5D47C	2017-07-16 10:47:00+03	32800.00
B5D49B	2017-07-08 22:22:00+03	43000.00
B5D4AB	2017-08-09 13:14:00+03	27400.00
B5D4C6	2017-07-03 11:07:00+03	131600.00
B5D4E9	2017-07-17 05:24:00+03	58800.00
B5D57B	2017-07-02 04:56:00+03	40400.00
B5D58B	2017-08-03 12:30:00+03	29600.00
B5D5F0	2017-08-02 09:28:00+03	137800.00
B5D5F8	2017-08-10 16:33:00+03	132800.00
B5D600	2017-07-23 15:20:00+03	56000.00
B5D621	2017-07-16 02:21:00+03	259600.00
B5D698	2017-07-24 10:18:00+03	17200.00
B5D6F2	2017-07-11 08:06:00+03	56000.00
B5D711	2017-08-10 16:41:00+03	73200.00
B5D77E	2017-08-14 20:31:00+03	46800.00
B5D7AC	2017-07-19 23:29:00+03	265700.00
B5D808	2017-08-04 14:49:00+03	107500.00
B5D812	2017-08-03 04:50:00+03	40800.00
B5D82B	2017-07-19 13:35:00+03	149900.00
B5D8D2	2017-07-16 01:57:00+03	34400.00
B5D8DE	2017-07-16 17:38:00+03	270200.00
B5D8E3	2017-07-09 19:01:00+03	27300.00
B5D8E8	2017-08-01 04:15:00+03	98400.00
B5D8F0	2017-07-05 07:06:00+03	19600.00
B5D905	2017-07-24 15:19:00+03	136600.00
B5D917	2017-07-13 12:40:00+03	90400.00
B5D937	2017-07-18 05:46:00+03	132800.00
B5D946	2017-07-28 19:38:00+03	111600.00
B5D984	2017-07-31 14:17:00+03	47200.00
B5D996	2017-08-13 03:20:00+03	99200.00
B5D9BD	2017-08-09 04:21:00+03	33100.00
B5D9C3	2017-08-02 20:07:00+03	119500.00
B5D9C5	2017-07-03 19:33:00+03	28000.00
B5DA3C	2017-07-08 22:42:00+03	47700.00
B5DA49	2017-07-31 02:57:00+03	140900.00
B5DA72	2017-07-02 14:20:00+03	246000.00
B5DB63	2017-07-16 15:13:00+03	92800.00
B5DBA2	2017-08-06 18:57:00+03	44000.00
B5DBF6	2017-07-28 03:30:00+03	14800.00
B5DC40	2017-07-07 22:37:00+03	81900.00
B5DC45	2017-07-21 00:46:00+03	70800.00
B5DC5F	2017-08-12 07:03:00+03	65500.00
B5DC93	2017-06-30 18:17:00+03	30000.00
B5DD16	2017-08-11 10:10:00+03	36200.00
B5DD25	2017-08-13 04:11:00+03	16400.00
B5DD5B	2017-07-29 11:48:00+03	30200.00
B5DD68	2017-08-11 08:44:00+03	55800.00
B5DD74	2017-07-06 13:05:00+03	27200.00
B5DDA5	2017-07-31 00:13:00+03	24200.00
B5DDC3	2017-08-08 05:31:00+03	20500.00
B5DDFA	2017-08-07 09:04:00+03	59900.00
B5DE40	2017-07-09 07:39:00+03	22000.00
B5DEB4	2017-07-04 19:27:00+03	36000.00
B5DEC5	2017-08-05 06:09:00+03	75600.00
B5DEDB	2017-08-01 00:39:00+03	12000.00
B5DF1F	2017-07-17 20:25:00+03	67200.00
B5DF2F	2017-07-09 14:54:00+03	112600.00
B5DF42	2017-08-08 11:30:00+03	76600.00
B5DF9D	2017-08-05 13:01:00+03	296400.00
B5DFD2	2017-07-02 03:48:00+03	53400.00
B5DFE2	2017-07-21 01:55:00+03	12600.00
B5DFE5	2017-07-23 11:52:00+03	35600.00
B5E042	2017-07-25 09:00:00+03	24400.00
B5E057	2017-07-17 19:24:00+03	100000.00
B5E077	2017-07-10 06:04:00+03	58200.00
B5E0B1	2017-07-14 03:22:00+03	189500.00
B5E0F5	2017-07-13 17:17:00+03	8200.00
B5E135	2017-07-03 11:33:00+03	15100.00
B5E13D	2017-07-21 09:29:00+03	147000.00
B5E171	2017-08-04 23:53:00+03	88100.00
B5E19A	2017-07-21 21:40:00+03	167400.00
B5E1FE	2017-07-07 04:43:00+03	41600.00
B5E26B	2017-07-11 10:04:00+03	48200.00
B5E278	2017-07-14 13:48:00+03	18000.00
B5E27B	2017-08-05 00:23:00+03	94100.00
B5E2A0	2017-06-27 19:28:00+03	117900.00
B5E2C4	2017-07-16 08:21:00+03	112000.00
B5E304	2017-07-12 13:31:00+03	204500.00
B5E317	2017-07-30 21:51:00+03	16400.00
B5E372	2017-07-02 20:11:00+03	187800.00
B5E38A	2017-07-07 00:07:00+03	100600.00
B5E39D	2017-07-15 12:56:00+03	107700.00
B5E3D0	2017-07-21 14:19:00+03	195500.00
B5E404	2017-08-06 22:03:00+03	92800.00
B5E455	2017-07-16 00:38:00+03	51300.00
B5E502	2017-07-10 03:51:00+03	128800.00
B5E56B	2017-07-24 02:32:00+03	15000.00
B5E5DA	2017-07-05 11:52:00+03	40400.00
B5E5F5	2017-08-01 11:49:00+03	43500.00
B5E620	2017-08-02 21:46:00+03	40800.00
B5E623	2017-07-02 21:52:00+03	29500.00
B5E687	2017-07-14 05:26:00+03	88500.00
B5E6D2	2017-08-14 12:54:00+03	68100.00
B5E757	2017-07-20 19:05:00+03	76000.00
B5E75E	2017-07-30 19:09:00+03	41200.00
B5E788	2017-07-30 14:59:00+03	38800.00
B5E7F9	2017-07-28 23:14:00+03	66800.00
B5E805	2017-08-15 14:39:00+03	24200.00
B5E809	2017-07-13 07:42:00+03	16400.00
B5E87C	2017-08-07 00:55:00+03	68900.00
B5E88E	2017-07-11 14:18:00+03	271100.00
B5E8AA	2017-08-09 20:12:00+03	24400.00
B5E94B	2017-07-17 15:47:00+03	56300.00
B5E955	2017-07-15 21:15:00+03	27600.00
B5EA77	2017-07-15 12:25:00+03	39600.00
B5EB1B	2017-07-04 15:34:00+03	32700.00
B5EB60	2017-08-07 18:22:00+03	75200.00
B5EB78	2017-07-28 14:12:00+03	57400.00
B5EB9B	2017-08-01 08:35:00+03	70400.00
B5EBDB	2017-08-04 22:54:00+03	11600.00
B5EBF6	2017-07-08 20:08:00+03	32700.00
B5EC61	2017-07-25 21:25:00+03	147700.00
B5ECAB	2017-07-02 12:55:00+03	28000.00
B5ECFB	2017-06-28 02:48:00+03	300700.00
B5ED26	2017-07-12 13:32:00+03	67800.00
B5ED60	2017-07-25 06:12:00+03	94700.00
B5EDFB	2017-07-31 23:06:00+03	38600.00
B5EE56	2017-07-06 03:34:00+03	12200.00
B5EE5B	2017-07-05 17:02:00+03	45200.00
B5EEAC	2017-07-15 00:38:00+03	47400.00
B5EEC0	2017-07-03 16:37:00+03	124200.00
B5EED5	2017-07-23 21:49:00+03	26000.00
B5EED8	2017-07-12 22:37:00+03	59300.00
B5EF58	2017-08-09 21:51:00+03	74000.00
B5EF65	2017-08-07 11:59:00+03	54800.00
B5EF70	2017-07-30 07:26:00+03	300700.00
B5EF7E	2017-07-06 17:21:00+03	73300.00
B5EFA1	2017-07-04 04:40:00+03	230000.00
B5EFA4	2017-07-29 03:18:00+03	99300.00
B5EFD7	2017-08-03 14:02:00+03	57600.00
B5EFE3	2017-08-04 05:20:00+03	40600.00
B5F09A	2017-07-23 21:05:00+03	44600.00
B5F152	2017-07-10 09:03:00+03	43200.00
B5F1A7	2017-07-09 03:46:00+03	46200.00
B5F269	2017-07-02 09:25:00+03	17200.00
B5F2F5	2017-07-21 05:39:00+03	105400.00
B5F348	2017-07-15 20:16:00+03	30700.00
B5F36F	2017-07-06 03:10:00+03	39300.00
B5F38E	2017-07-02 01:29:00+03	246000.00
B5F39E	2017-08-01 23:27:00+03	266300.00
B5F424	2017-08-13 23:36:00+03	29600.00
B5F45D	2017-08-02 15:40:00+03	89600.00
B5F470	2017-08-08 05:22:00+03	58900.00
B5F508	2017-08-01 19:59:00+03	33500.00
B5F575	2017-07-06 08:13:00+03	30000.00
B5F59E	2017-07-21 10:39:00+03	123000.00
B5F5B4	2017-08-15 12:07:00+03	40600.00
B5F5E9	2017-07-07 17:19:00+03	65500.00
B5F601	2017-07-17 22:44:00+03	54800.00
B5F604	2017-06-29 12:07:00+03	88800.00
B5F722	2017-07-25 19:54:00+03	124200.00
B5F723	2017-07-15 20:26:00+03	32800.00
B5F763	2017-07-20 22:06:00+03	44600.00
B5F780	2017-07-16 05:25:00+03	55800.00
B5F7BB	2017-08-02 16:56:00+03	21400.00
B5F7E5	2017-07-18 09:55:00+03	92000.00
B5F847	2017-07-25 01:12:00+03	37100.00
B5F8A7	2017-07-11 03:50:00+03	26000.00
B5F8A9	2017-07-17 02:38:00+03	37900.00
B5F8BF	2017-07-29 12:27:00+03	16400.00
B5F966	2017-08-02 06:40:00+03	31100.00
B5F99E	2017-07-31 20:42:00+03	10800.00
B5F9C1	2017-08-04 09:10:00+03	23200.00
B5F9E7	2017-07-23 05:12:00+03	19600.00
B5F9FE	2017-07-17 04:50:00+03	16400.00
B5FA0D	2017-08-03 11:05:00+03	94200.00
B5FA11	2017-07-10 07:33:00+03	15000.00
B5FA35	2017-08-10 12:12:00+03	13000.00
B5FA81	2017-07-17 16:46:00+03	26000.00
B5FABA	2017-07-22 19:13:00+03	77400.00
B5FB19	2017-07-07 22:00:00+03	77100.00
B5FB2A	2017-07-12 19:58:00+03	86300.00
B5FB47	2017-07-09 18:36:00+03	137700.00
B5FB8B	2017-07-14 20:16:00+03	16800.00
B5FB8C	2017-07-11 06:06:00+03	14400.00
B5FC76	2017-07-05 14:54:00+03	58800.00
B5FC94	2017-07-05 04:19:00+03	49800.00
B5FCDE	2017-07-07 03:08:00+03	28000.00
B5FCE4	2017-07-26 11:27:00+03	23600.00
B5FD34	2017-07-14 03:02:00+03	13000.00
B5FD48	2017-07-30 23:58:00+03	29100.00
B5FDA9	2017-07-13 17:08:00+03	266400.00
B5FEFE	2017-07-12 17:38:00+03	38800.00
B5FF0C	2017-06-30 10:37:00+03	7400.00
B5FF38	2017-07-04 09:28:00+03	132800.00
B5FF4A	2017-07-20 02:44:00+03	103500.00
B5FF5E	2017-07-13 23:14:00+03	246000.00
B5FF90	2017-07-26 10:14:00+03	31400.00
B5FFA3	2017-07-26 12:31:00+03	117200.00
B5FFAA	2017-07-01 19:10:00+03	66400.00
B6006A	2017-08-08 10:11:00+03	102300.00
B60083	2017-07-31 13:12:00+03	38600.00
B60162	2017-07-10 05:41:00+03	12600.00
B601EF	2017-07-29 10:02:00+03	56000.00
B601F1	2017-08-04 00:03:00+03	57500.00
B601F3	2017-07-11 08:46:00+03	53300.00
B6020B	2017-07-31 13:22:00+03	116000.00
B60217	2017-07-13 08:23:00+03	256300.00
B60220	2017-07-28 09:18:00+03	77400.00
B6024A	2017-08-09 07:52:00+03	189100.00
B6025E	2017-07-27 00:02:00+03	555600.00
B60299	2017-06-29 15:55:00+03	79300.00
B602E9	2017-06-30 10:15:00+03	59800.00
B6030E	2017-07-25 14:52:00+03	92800.00
B60318	2017-07-28 04:18:00+03	13400.00
B60336	2017-07-21 02:13:00+03	281500.00
B6033A	2017-07-27 03:30:00+03	40200.00
B60364	2017-07-17 05:08:00+03	167500.00
B603CA	2017-07-29 14:22:00+03	17000.00
B603E2	2017-08-12 20:11:00+03	28000.00
B6048D	2017-08-11 10:54:00+03	56000.00
B604DC	2017-07-20 18:51:00+03	28000.00
B6051B	2017-07-30 14:14:00+03	55800.00
B60535	2017-08-02 20:19:00+03	23200.00
B605F2	2017-07-31 10:13:00+03	57600.00
B6069F	2017-07-14 06:10:00+03	28000.00
B606F3	2017-07-29 22:45:00+03	26700.00
B607D4	2017-07-29 05:30:00+03	143400.00
B607DB	2017-07-31 22:29:00+03	11600.00
B60837	2017-07-10 03:45:00+03	25600.00
B60856	2017-08-06 04:19:00+03	55800.00
B60881	2017-08-08 11:18:00+03	40800.00
B608D0	2017-07-19 06:38:00+03	26000.00
B608F9	2017-08-10 08:09:00+03	16400.00
B60A16	2017-07-04 21:01:00+03	266400.00
B60A2A	2017-07-21 23:13:00+03	17000.00
B60A2C	2017-08-15 00:02:00+03	26000.00
B60A4D	2017-08-14 13:07:00+03	26800.00
B60A7D	2017-07-31 07:03:00+03	37900.00
B60A87	2017-07-12 11:16:00+03	75600.00
B60AB0	2017-07-26 09:13:00+03	14400.00
B60AB5	2017-07-30 12:38:00+03	29100.00
B60B8F	2017-08-10 04:55:00+03	4000.00
B60BF8	2017-07-11 19:07:00+03	89600.00
B60BFC	2017-08-08 18:25:00+03	25800.00
B60C73	2017-07-18 18:33:00+03	13700.00
B60C7E	2017-08-11 02:46:00+03	17200.00
B60C8C	2017-07-25 01:05:00+03	23600.00
B60D04	2017-06-29 12:09:00+03	113600.00
B60D26	2017-08-03 04:09:00+03	77000.00
B60D36	2017-08-09 11:25:00+03	122000.00
B60D6B	2017-08-05 12:15:00+03	87400.00
B60D90	2017-07-18 05:27:00+03	23600.00
B60E0C	2017-08-08 23:03:00+03	15800.00
B60E68	2017-07-13 08:12:00+03	242600.00
B60E8B	2017-07-25 09:31:00+03	136800.00
B60F34	2017-07-24 20:55:00+03	34200.00
B60F6F	2017-08-09 00:17:00+03	32800.00
B60FFD	2017-08-10 19:09:00+03	88600.00
B6107F	2017-07-22 03:41:00+03	39600.00
B610A1	2017-07-13 20:16:00+03	26000.00
B610F5	2017-07-27 04:33:00+03	111700.00
B6113B	2017-07-20 12:57:00+03	32700.00
B611D3	2017-07-18 05:48:00+03	28800.00
B61231	2017-07-16 09:59:00+03	116000.00
B6126F	2017-07-05 22:21:00+03	8000.00
B612C1	2017-07-22 07:27:00+03	26800.00
B612CB	2017-07-14 06:30:00+03	25100.00
B612D6	2017-07-18 04:45:00+03	24400.00
B612FF	2017-07-11 02:26:00+03	39200.00
B6130C	2017-07-28 19:32:00+03	56000.00
B61331	2017-07-03 11:23:00+03	270700.00
B6139D	2017-08-14 06:59:00+03	10800.00
B613E0	2017-07-08 20:41:00+03	193600.00
B61401	2017-07-20 10:56:00+03	173500.00
B61406	2017-07-26 09:54:00+03	31400.00
B6145F	2017-07-22 09:19:00+03	78800.00
B6147D	2017-07-28 02:18:00+03	55800.00
B6148F	2017-07-19 20:18:00+03	262200.00
B614C1	2017-07-31 11:38:00+03	55800.00
B614DB	2017-08-06 07:38:00+03	46200.00
B6155C	2017-07-02 18:00:00+03	60400.00
B61590	2017-07-10 07:18:00+03	57600.00
B61599	2017-07-13 04:50:00+03	28000.00
B615C5	2017-07-24 06:15:00+03	39800.00
B615C8	2017-07-15 09:13:00+03	111600.00
B615E1	2017-07-17 12:00:00+03	212000.00
B615ED	2017-07-12 00:51:00+03	15000.00
B61609	2017-07-22 18:11:00+03	21600.00
B61613	2017-08-01 13:39:00+03	38400.00
B6166B	2017-07-29 22:49:00+03	38800.00
B61683	2017-08-04 09:40:00+03	269200.00
B61688	2017-07-04 08:51:00+03	31700.00
B61743	2017-07-28 17:16:00+03	136200.00
B61752	2017-08-05 09:11:00+03	56600.00
B61754	2017-07-07 09:31:00+03	14400.00
B61796	2017-07-01 07:35:00+03	46000.00
B617BD	2017-07-20 14:13:00+03	83600.00
B617D1	2017-08-12 05:28:00+03	69000.00
B617DB	2017-07-20 00:53:00+03	26800.00
B617DC	2017-07-24 10:39:00+03	29400.00
B6188A	2017-07-15 16:32:00+03	73200.00
B618A1	2017-07-21 12:59:00+03	139800.00
B618E5	2017-08-15 10:23:00+03	20000.00
B61918	2017-07-07 16:58:00+03	14000.00
B6191C	2017-07-23 11:03:00+03	27200.00
B61925	2017-07-29 12:33:00+03	21400.00
B6192E	2017-07-16 13:03:00+03	12400.00
B61939	2017-07-29 05:12:00+03	749000.00
B61959	2017-07-13 10:53:00+03	6300.00
B619A0	2017-07-27 15:20:00+03	92700.00
B619BF	2017-07-04 14:39:00+03	6700.00
B619D0	2017-08-01 20:18:00+03	62800.00
B619D3	2017-07-17 05:08:00+03	38500.00
B61A30	2017-07-15 07:19:00+03	283500.00
B61A45	2017-07-17 11:13:00+03	31600.00
B61A51	2017-08-04 17:55:00+03	38200.00
B61A7D	2017-08-11 09:45:00+03	43500.00
B61AB4	2017-08-14 01:19:00+03	54000.00
B61ADB	2017-08-04 11:51:00+03	25100.00
B61B10	2017-07-19 20:45:00+03	118700.00
B61B3A	2017-07-30 06:36:00+03	123600.00
B61B79	2017-07-09 22:02:00+03	39800.00
B61B7E	2017-07-02 22:19:00+03	62600.00
B61BAC	2017-07-13 12:05:00+03	62600.00
B61BCB	2017-07-12 16:13:00+03	163400.00
B61BE4	2017-08-11 09:48:00+03	43900.00
B61C25	2017-08-09 13:19:00+03	135800.00
B61C8F	2017-07-23 03:23:00+03	28800.00
B61CCD	2017-08-15 04:04:00+03	26000.00
B61CEA	2017-07-20 02:03:00+03	34000.00
B61D52	2017-07-17 21:52:00+03	75600.00
B61D5A	2017-08-05 23:12:00+03	201200.00
B61DBE	2017-08-03 10:29:00+03	67400.00
B61DE8	2017-08-09 07:37:00+03	6000.00
B61E01	2017-08-10 23:19:00+03	43500.00
B61E29	2017-08-12 02:19:00+03	18800.00
B61E2E	2017-07-09 04:38:00+03	103100.00
B61E44	2017-08-06 02:05:00+03	37100.00
B61E8C	2017-07-16 15:37:00+03	290500.00
B61EA0	2017-07-13 16:47:00+03	29600.00
B61F08	2017-07-18 19:07:00+03	29600.00
B61F24	2017-07-27 20:59:00+03	23200.00
B61F58	2017-08-06 11:12:00+03	65900.00
B61F5D	2017-07-30 17:59:00+03	147000.00
B62051	2017-07-04 14:29:00+03	243400.00
B6205B	2017-07-23 15:47:00+03	41300.00
B6207E	2017-07-06 13:53:00+03	38600.00
B6208E	2017-08-10 01:52:00+03	7400.00
B620A0	2017-07-14 12:36:00+03	73500.00
B620B7	2017-06-28 01:54:00+03	24300.00
B62218	2017-07-30 07:46:00+03	123900.00
B6228B	2017-07-06 16:42:00+03	28800.00
B622A9	2017-07-10 08:57:00+03	95200.00
B622B1	2017-08-03 16:05:00+03	149600.00
B622D9	2017-07-07 12:25:00+03	92600.00
B62389	2017-06-29 00:56:00+03	58400.00
B62405	2017-07-10 18:39:00+03	105100.00
B62447	2017-07-18 11:14:00+03	91500.00
B6247F	2017-07-10 13:44:00+03	399600.00
B6250A	2017-08-12 19:44:00+03	12000.00
B6252C	2017-08-13 12:44:00+03	60300.00
B62543	2017-07-09 06:54:00+03	33100.00
B6254F	2017-08-11 07:17:00+03	135400.00
B6256C	2017-07-09 05:43:00+03	85000.00
B6256F	2017-08-08 04:32:00+03	156500.00
B6258F	2017-07-18 05:44:00+03	131000.00
B625B7	2017-07-22 03:39:00+03	21400.00
B625BB	2017-07-30 14:11:00+03	56000.00
B625D8	2017-07-18 16:30:00+03	28000.00
B6261B	2017-08-05 04:10:00+03	60000.00
B6265F	2017-08-14 02:01:00+03	12000.00
B626A5	2017-08-05 19:11:00+03	49500.00
B62737	2017-08-14 09:41:00+03	99300.00
B62754	2017-08-07 11:07:00+03	136200.00
B62773	2017-07-09 21:10:00+03	111600.00
B62780	2017-06-30 01:50:00+03	102100.00
B62794	2017-08-01 07:09:00+03	58200.00
B627B3	2017-07-02 02:31:00+03	49100.00
B627CD	2017-07-24 01:29:00+03	240500.00
B62811	2017-07-16 08:33:00+03	36600.00
B6288C	2017-07-07 21:01:00+03	46900.00
B628BE	2017-08-12 22:28:00+03	27800.00
B6292A	2017-08-08 08:16:00+03	104600.00
B6296D	2017-07-20 14:21:00+03	69000.00
B629D5	2017-07-29 06:04:00+03	73400.00
B629F4	2017-07-19 00:23:00+03	81600.00
B62A4D	2017-07-12 06:43:00+03	39200.00
B62A73	2017-07-15 11:02:00+03	293600.00
B62AD6	2017-07-02 11:29:00+03	29600.00
B62AF6	2017-07-21 06:35:00+03	48500.00
B62B2C	2017-07-02 13:31:00+03	38800.00
B62B62	2017-08-04 01:47:00+03	29800.00
B62B98	2017-07-19 16:03:00+03	62900.00
B62BD1	2017-08-11 02:56:00+03	46200.00
B62C5E	2017-06-30 05:33:00+03	44600.00
B62C6C	2017-07-08 16:01:00+03	54500.00
B62CB8	2017-07-04 19:37:00+03	170000.00
B62CC7	2017-08-14 04:07:00+03	99300.00
B62DF4	2017-08-05 05:32:00+03	42800.00
B62E10	2017-07-10 06:22:00+03	30000.00
B62E6B	2017-07-07 08:53:00+03	46400.00
B62E6F	2017-08-01 07:19:00+03	409600.00
B62E88	2017-08-12 16:30:00+03	36900.00
B62E9E	2017-07-07 20:41:00+03	35200.00
B62EBD	2017-08-05 12:00:00+03	90800.00
B62ED8	2017-07-21 13:51:00+03	81900.00
B62FAD	2017-07-02 09:36:00+03	96800.00
B62FBB	2017-07-10 17:13:00+03	16000.00
B62FF0	2017-07-11 00:54:00+03	64100.00
B6309F	2017-07-26 19:38:00+03	7400.00
B630E3	2017-07-20 16:50:00+03	28800.00
B630F8	2017-08-02 14:46:00+03	114900.00
B631E6	2017-07-03 18:18:00+03	6300.00
B63202	2017-08-05 11:23:00+03	115600.00
B6322A	2017-07-17 05:23:00+03	12600.00
B6322C	2017-06-30 18:25:00+03	27600.00
B63267	2017-07-14 07:43:00+03	70800.00
B6328A	2017-07-12 06:07:00+03	23600.00
B6338A	2017-07-26 13:27:00+03	63700.00
B633B8	2017-08-03 02:19:00+03	28000.00
B633C9	2017-07-06 18:28:00+03	37900.00
B6341E	2017-08-10 01:51:00+03	22600.00
B6341F	2017-07-08 06:50:00+03	40800.00
B63499	2017-07-02 12:13:00+03	58000.00
B634FD	2017-07-20 07:52:00+03	6200.00
B63523	2017-07-30 06:56:00+03	75600.00
B6354F	2017-07-03 13:25:00+03	54400.00
B6355C	2017-07-31 10:34:00+03	69400.00
B6357C	2017-07-14 13:33:00+03	29600.00
B635E5	2017-07-10 14:14:00+03	36000.00
B63612	2017-07-05 04:40:00+03	243700.00
B63624	2017-08-05 16:03:00+03	46000.00
B636C1	2017-07-04 04:18:00+03	93900.00
B636D0	2017-07-05 09:09:00+03	10800.00
B636E0	2017-08-08 16:15:00+03	173100.00
B63704	2017-08-12 22:56:00+03	35700.00
B6377F	2017-07-13 18:11:00+03	73300.00
B637D3	2017-07-31 17:10:00+03	57500.00
B6380A	2017-07-10 10:38:00+03	133100.00
B6380F	2017-07-07 16:21:00+03	193300.00
B6383C	2017-08-11 13:03:00+03	270400.00
B63845	2017-07-18 02:33:00+03	27300.00
B6385B	2017-07-25 16:11:00+03	21800.00
B638D2	2017-06-26 04:18:00+03	141100.00
B63909	2017-08-12 00:45:00+03	747600.00
B63970	2017-07-29 10:51:00+03	23200.00
B639B0	2017-07-25 11:59:00+03	69100.00
B63A18	2017-07-09 11:37:00+03	89700.00
B63A77	2017-07-20 10:01:00+03	67600.00
B63AAA	2017-07-19 07:42:00+03	105000.00
B63AF8	2017-08-14 12:13:00+03	37700.00
B63B47	2017-07-21 12:17:00+03	74300.00
B63B4A	2017-08-09 18:57:00+03	239300.00
B63B6E	2017-08-15 14:34:00+03	135400.00
B63C79	2017-07-10 13:05:00+03	28000.00
B63CD4	2017-06-30 14:29:00+03	28800.00
B63DCC	2017-07-19 11:41:00+03	46800.00
B63E17	2017-08-11 10:26:00+03	38600.00
B63E3B	2017-07-30 07:04:00+03	135400.00
B63ED6	2017-07-16 01:10:00+03	258400.00
B63ED8	2017-07-24 13:48:00+03	80700.00
B63F09	2017-08-13 22:19:00+03	83600.00
B63F2A	2017-07-05 19:22:00+03	20200.00
B63F79	2017-08-03 05:02:00+03	34000.00
B63FB9	2017-07-08 13:59:00+03	57800.00
B63FCA	2017-07-05 11:22:00+03	135600.00
B63FE1	2017-07-21 07:52:00+03	8400.00
B64048	2017-07-24 13:17:00+03	120800.00
B64051	2017-08-05 05:06:00+03	270800.00
B64066	2017-08-04 22:55:00+03	40800.00
B64110	2017-08-05 23:27:00+03	28800.00
B6414C	2017-07-28 01:20:00+03	27300.00
B6414D	2017-08-13 03:25:00+03	97400.00
B64154	2017-08-07 03:21:00+03	42800.00
B64174	2017-07-11 20:30:00+03	226200.00
B641D6	2017-08-08 09:58:00+03	23200.00
B6423F	2017-07-30 00:03:00+03	31400.00
B642A0	2017-07-16 19:51:00+03	123000.00
B64329	2017-08-11 05:24:00+03	43200.00
B64342	2017-08-02 04:10:00+03	56100.00
B64360	2017-08-02 17:49:00+03	111700.00
B643DF	2017-08-04 14:53:00+03	23400.00
B6444A	2017-08-07 20:12:00+03	23600.00
B6446C	2017-08-06 08:30:00+03	353000.00
B64486	2017-08-03 14:30:00+03	31600.00
B644AE	2017-08-11 16:49:00+03	74800.00
B644C8	2017-07-11 03:54:00+03	46300.00
B6457D	2017-07-20 17:09:00+03	135000.00
B645CF	2017-07-11 19:10:00+03	238500.00
B646DE	2017-07-18 02:14:00+03	38600.00
B646EB	2017-07-10 21:48:00+03	55800.00
B646FE	2017-08-06 10:48:00+03	21500.00
B6470E	2017-08-06 06:43:00+03	84500.00
B64733	2017-08-14 22:00:00+03	30200.00
B6476E	2017-07-11 22:09:00+03	6300.00
B647F5	2017-07-10 14:33:00+03	29400.00
B6484B	2017-07-28 18:54:00+03	57600.00
B648A4	2017-07-15 19:41:00+03	31600.00
B648A8	2017-07-18 07:56:00+03	31900.00
B648E1	2017-08-01 08:56:00+03	68400.00
B648E8	2017-07-02 13:02:00+03	208700.00
B6494A	2017-07-06 22:22:00+03	6800.00
B64962	2017-06-29 03:50:00+03	54500.00
B64981	2017-08-13 04:32:00+03	29600.00
B649D0	2017-07-07 16:32:00+03	46400.00
B649DA	2017-07-09 14:43:00+03	58600.00
B64A54	2017-07-15 05:49:00+03	75300.00
B64ADA	2017-07-12 11:51:00+03	290500.00
B64ADF	2017-07-08 22:17:00+03	168000.00
B64B58	2017-08-04 01:39:00+03	542300.00
B64BA7	2017-08-14 06:53:00+03	386200.00
B64C25	2017-08-02 11:41:00+03	51300.00
B64C85	2017-08-11 14:12:00+03	62000.00
B64CB6	2017-07-16 23:13:00+03	74800.00
B64CC7	2017-08-03 08:11:00+03	15800.00
B64CF3	2017-07-05 01:16:00+03	53200.00
B64D00	2017-08-14 17:07:00+03	312000.00
B64D0E	2017-08-14 09:44:00+03	111600.00
B64D1E	2017-08-04 20:41:00+03	39800.00
B64D3B	2017-07-30 22:20:00+03	43500.00
B64DE0	2017-07-31 03:59:00+03	95600.00
B64E37	2017-07-05 18:58:00+03	72400.00
B64E58	2017-07-25 01:25:00+03	73300.00
B64E5C	2017-07-27 13:37:00+03	54900.00
B64E7E	2017-08-06 06:11:00+03	26000.00
B64EEC	2017-07-09 02:10:00+03	56900.00
B64F33	2017-07-04 04:55:00+03	38400.00
B64F8C	2017-07-06 17:07:00+03	6800.00
B64F9B	2017-08-13 14:26:00+03	18600.00
B64FAC	2017-08-15 06:06:00+03	59100.00
B64FC6	2017-07-28 15:43:00+03	46200.00
B64FCF	2017-07-03 14:16:00+03	79600.00
B6500C	2017-07-02 15:21:00+03	30400.00
B6501B	2017-07-07 20:02:00+03	49200.00
B6502B	2017-07-28 20:40:00+03	62800.00
B65030	2017-07-30 23:28:00+03	56600.00
B65039	2017-08-09 20:58:00+03	30000.00
B65059	2017-07-19 04:54:00+03	197100.00
B6505D	2017-08-11 02:38:00+03	70200.00
B6507F	2017-08-03 02:04:00+03	52100.00
B6508C	2017-07-16 23:41:00+03	57500.00
B6509F	2017-08-03 20:42:00+03	32800.00
B65170	2017-08-04 11:42:00+03	193600.00
B651D7	2017-07-15 06:10:00+03	111600.00
B651EC	2017-07-26 13:08:00+03	47200.00
B651F6	2017-07-19 03:10:00+03	105000.00
B651FC	2017-07-07 05:22:00+03	100600.00
B652A6	2017-07-14 10:43:00+03	48700.00
B652E1	2017-07-31 13:29:00+03	22000.00
B65307	2017-08-06 20:41:00+03	92400.00
B65346	2017-08-11 17:21:00+03	44800.00
B653A6	2017-07-31 13:41:00+03	56000.00
B653AB	2017-08-05 21:57:00+03	29500.00
B65432	2017-07-15 04:42:00+03	43600.00
B65438	2017-08-02 12:15:00+03	14000.00
B6543A	2017-08-15 10:57:00+03	24000.00
B65457	2017-07-20 18:55:00+03	39000.00
B654F0	2017-07-08 03:45:00+03	27200.00
B654F2	2017-07-27 22:30:00+03	112000.00
B65569	2017-07-31 23:54:00+03	58200.00
B655A0	2017-07-30 22:53:00+03	64200.00
B65619	2017-08-10 11:57:00+03	61800.00
B65636	2017-08-15 02:47:00+03	40100.00
B6567C	2017-07-22 03:43:00+03	89100.00
B656A5	2017-08-11 13:04:00+03	44000.00
B656A9	2017-07-10 05:52:00+03	297700.00
B656B8	2017-07-09 19:44:00+03	21800.00
B656C9	2017-08-02 14:36:00+03	100000.00
B6577B	2017-07-18 03:18:00+03	20200.00
B657A9	2017-07-28 15:34:00+03	64000.00
B65823	2017-07-04 01:54:00+03	136500.00
B65826	2017-08-14 20:54:00+03	19600.00
B6582A	2017-07-08 15:43:00+03	92600.00
B65830	2017-07-10 17:43:00+03	182300.00
B65832	2017-07-17 09:46:00+03	55800.00
B65899	2017-06-30 08:38:00+03	237000.00
B658C2	2017-07-22 06:39:00+03	67900.00
B658EC	2017-07-28 08:39:00+03	112000.00
B658F6	2017-07-30 01:58:00+03	27300.00
B658FE	2017-08-10 23:21:00+03	71400.00
B6594F	2017-07-20 05:21:00+03	135000.00
B659AE	2017-07-11 14:49:00+03	87400.00
B659EB	2017-08-10 04:13:00+03	198400.00
B65A2E	2017-07-07 14:06:00+03	125700.00
B65AE8	2017-07-10 08:59:00+03	46400.00
B65AED	2017-07-20 06:57:00+03	12600.00
B65BBE	2017-07-13 10:56:00+03	26000.00
B65BD7	2017-07-25 01:51:00+03	14000.00
B65BDE	2017-07-26 03:34:00+03	28800.00
B65C15	2017-08-11 16:31:00+03	6000.00
B65CCF	2017-07-17 04:25:00+03	58400.00
B65D86	2017-08-10 13:19:00+03	23200.00
B65DD5	2017-07-06 05:23:00+03	137600.00
B65DFF	2017-07-25 19:34:00+03	71500.00
B65E6B	2017-07-23 12:41:00+03	100000.00
B65EBB	2017-08-12 10:12:00+03	88900.00
B65ED6	2017-07-31 08:54:00+03	76100.00
B65F0C	2017-07-28 17:30:00+03	39800.00
B65F50	2017-07-15 06:13:00+03	62700.00
B65F91	2017-07-23 21:04:00+03	24000.00
B65FB5	2017-07-11 02:44:00+03	11800.00
B65FC3	2017-08-08 03:13:00+03	48800.00
B65FE9	2017-07-17 22:50:00+03	117600.00
B66028	2017-07-21 06:34:00+03	31400.00
B6607B	2017-07-24 17:32:00+03	128800.00
B660C6	2017-07-16 13:42:00+03	70400.00
B660DB	2017-07-19 16:29:00+03	28000.00
B660EF	2017-07-07 10:51:00+03	62700.00
B660F9	2017-07-07 22:06:00+03	65500.00
B66115	2017-07-27 18:21:00+03	262000.00
B6613A	2017-08-01 07:31:00+03	91100.00
B6617D	2017-07-29 20:02:00+03	32800.00
B661A3	2017-08-12 20:50:00+03	246000.00
B661AC	2017-07-19 03:05:00+03	47200.00
B66219	2017-07-05 09:43:00+03	321600.00
B66257	2017-07-19 15:09:00+03	27900.00
B6630B	2017-07-17 01:50:00+03	6000.00
B66373	2017-08-01 13:13:00+03	94200.00
B6638A	2017-07-15 12:59:00+03	55800.00
B66407	2017-08-05 04:59:00+03	40800.00
B6642B	2017-07-09 12:23:00+03	52000.00
B66430	2017-07-16 15:28:00+03	78200.00
B664E2	2017-08-02 00:49:00+03	50400.00
B664FB	2017-07-30 05:18:00+03	31600.00
B6652D	2017-07-11 11:29:00+03	84100.00
B66587	2017-07-16 04:06:00+03	18600.00
B665E4	2017-07-09 19:32:00+03	99300.00
B6666B	2017-08-08 00:21:00+03	46800.00
B6666F	2017-08-05 02:13:00+03	39300.00
B6668C	2017-07-24 17:04:00+03	31600.00
B666A7	2017-07-07 21:35:00+03	24400.00
B6672F	2017-07-06 13:19:00+03	46300.00
B667CE	2017-07-04 22:26:00+03	123000.00
B667E1	2017-07-04 21:08:00+03	62700.00
B66806	2017-07-22 05:23:00+03	60700.00
B6683D	2017-07-18 02:12:00+03	54800.00
B66893	2017-08-11 18:10:00+03	54000.00
B668E4	2017-08-06 07:04:00+03	79900.00
B66928	2017-07-14 07:13:00+03	122800.00
B66944	2017-07-18 23:32:00+03	378400.00
B66993	2017-07-14 05:10:00+03	39600.00
B669C4	2017-07-08 14:25:00+03	58600.00
B66A40	2017-08-06 08:11:00+03	6300.00
B66A91	2017-07-08 14:40:00+03	147700.00
B66AA7	2017-07-17 09:56:00+03	94000.00
B66AFE	2017-08-13 12:14:00+03	102100.00
B66B41	2017-07-19 13:55:00+03	73600.00
B66B99	2017-07-10 18:18:00+03	31200.00
B66BF7	2017-07-03 14:08:00+03	135400.00
B66C02	2017-06-23 14:53:00+03	27200.00
B66C38	2017-08-12 06:37:00+03	45100.00
B66C4E	2017-07-25 07:41:00+03	112000.00
B66C70	2017-08-06 06:20:00+03	16000.00
B66C8A	2017-07-15 05:33:00+03	67800.00
B66CCB	2017-07-28 20:20:00+03	22000.00
B66D3B	2017-07-15 21:38:00+03	11300.00
B66D40	2017-07-20 18:08:00+03	167400.00
B66D4B	2017-07-07 07:26:00+03	31600.00
B66DE3	2017-07-01 05:09:00+03	36200.00
B66DE4	2017-07-09 12:27:00+03	39300.00
B66E06	2017-07-01 02:19:00+03	39300.00
B66E0C	2017-07-13 04:34:00+03	95200.00
B66E19	2017-08-01 12:29:00+03	42400.00
B66E3B	2017-07-10 00:39:00+03	81900.00
B66EC4	2017-08-12 18:55:00+03	39100.00
B66F68	2017-07-10 17:34:00+03	69500.00
B66F71	2017-07-30 21:33:00+03	42000.00
B66F9F	2017-06-27 10:45:00+03	6700.00
B66FAB	2017-07-30 12:29:00+03	75500.00
B66FD8	2017-08-14 22:47:00+03	18600.00
B66FE1	2017-07-16 06:50:00+03	87700.00
B6703A	2017-08-08 10:26:00+03	56000.00
B6703B	2017-07-06 22:31:00+03	36800.00
B67055	2017-07-18 16:08:00+03	289500.00
B67088	2017-08-12 17:12:00+03	102800.00
B67103	2017-07-03 01:40:00+03	62600.00
B67124	2017-07-15 21:13:00+03	51600.00
B6716F	2017-07-12 02:56:00+03	27200.00
B6717C	2017-08-01 03:19:00+03	246000.00
B671BE	2017-07-21 01:59:00+03	15400.00
B671E1	2017-08-09 17:14:00+03	87200.00
B672CC	2017-07-31 09:40:00+03	68100.00
B672E9	2017-08-05 04:49:00+03	69500.00
B67368	2017-07-04 01:21:00+03	12600.00
B6736C	2017-07-20 06:16:00+03	6300.00
B673CA	2017-08-09 16:51:00+03	188000.00
B673D5	2017-08-02 01:52:00+03	199300.00
B673F3	2017-08-06 11:28:00+03	26600.00
B67434	2017-08-05 18:34:00+03	44600.00
B67452	2017-07-29 03:25:00+03	73400.00
B67499	2017-07-11 15:54:00+03	29200.00
B67508	2017-08-03 11:55:00+03	131600.00
B67517	2017-08-07 04:36:00+03	38400.00
B6757B	2017-07-27 09:50:00+03	22200.00
B67616	2017-07-31 05:12:00+03	60400.00
B67629	2017-08-05 06:14:00+03	183100.00
B67632	2017-07-25 17:12:00+03	47200.00
B676E8	2017-07-14 20:59:00+03	139000.00
B67746	2017-07-27 03:16:00+03	144800.00
B67747	2017-07-09 07:57:00+03	408500.00
B67772	2017-07-08 16:07:00+03	27200.00
B6779C	2017-07-18 14:37:00+03	66600.00
B677CA	2017-06-30 03:28:00+03	23600.00
B67842	2017-07-31 21:24:00+03	133200.00
B6786C	2017-07-03 20:05:00+03	111600.00
B678BA	2017-08-12 14:25:00+03	56900.00
B678BE	2017-07-10 20:33:00+03	21800.00
B67935	2017-08-04 16:55:00+03	406800.00
B6797A	2017-08-03 09:55:00+03	54800.00
B6799A	2017-08-06 01:45:00+03	109100.00
B67A48	2017-07-08 02:11:00+03	63700.00
B67A6C	2017-07-21 16:54:00+03	49200.00
B67B40	2017-07-24 08:08:00+03	201200.00
B67B9B	2017-07-29 19:20:00+03	56000.00
B67BC3	2017-08-10 02:31:00+03	70600.00
B67C3D	2017-07-29 18:00:00+03	54300.00
B67C4B	2017-08-03 16:32:00+03	7200.00
B67CDD	2017-07-13 05:53:00+03	325500.00
B67CE8	2017-08-13 16:47:00+03	148500.00
B67D1C	2017-07-28 22:08:00+03	266400.00
B67DD2	2017-07-22 09:06:00+03	30700.00
B67E0C	2017-08-12 19:20:00+03	230000.00
B67E20	2017-08-14 15:30:00+03	81600.00
B67E84	2017-07-13 13:38:00+03	27200.00
B67E98	2017-08-07 10:14:00+03	180000.00
B67E9E	2017-08-07 20:56:00+03	179500.00
B67EE1	2017-07-17 09:00:00+03	39400.00
B67F30	2017-07-10 03:35:00+03	89600.00
B67F45	2017-07-06 15:39:00+03	133200.00
B67F87	2017-07-10 13:49:00+03	38800.00
B67FAA	2017-07-15 10:12:00+03	163800.00
B67FAE	2017-08-14 04:08:00+03	77900.00
B67FC0	2017-07-16 15:33:00+03	41200.00
B67FCA	2017-07-28 13:04:00+03	88600.00
B67FDC	2017-07-26 01:38:00+03	181400.00
B6802C	2017-08-09 03:11:00+03	93500.00
B68051	2017-08-12 02:25:00+03	28800.00
B6808F	2017-07-22 21:14:00+03	70100.00
B68093	2017-07-12 16:46:00+03	129700.00
B680AF	2017-08-01 07:17:00+03	297600.00
B680FA	2017-08-15 03:08:00+03	186100.00
B68116	2017-08-04 09:43:00+03	102200.00
B6817C	2017-07-03 09:31:00+03	24400.00
B681BB	2017-07-18 18:48:00+03	68800.00
B6823A	2017-07-23 03:26:00+03	126900.00
B6827F	2017-07-19 10:03:00+03	58800.00
B682B8	2017-08-07 13:31:00+03	15300.00
B682CC	2017-07-06 20:09:00+03	28000.00
B6834B	2017-07-04 10:57:00+03	50600.00
B6838C	2017-08-03 17:21:00+03	48300.00
B6841D	2017-08-07 06:33:00+03	6800.00
B68421	2017-08-07 01:54:00+03	81300.00
B68425	2017-07-04 17:05:00+03	38200.00
B68429	2017-08-13 18:45:00+03	8800.00
B68434	2017-07-11 22:47:00+03	92000.00
B6844D	2017-07-14 20:13:00+03	21400.00
B68484	2017-07-16 16:44:00+03	25600.00
B6848D	2017-08-06 20:11:00+03	58000.00
B684E5	2017-08-09 20:37:00+03	40800.00
B68527	2017-08-14 11:45:00+03	90400.00
B68549	2017-06-29 04:38:00+03	55600.00
B685D4	2017-07-27 12:22:00+03	83300.00
B685DE	2017-08-13 01:54:00+03	205600.00
B6864A	2017-08-01 18:39:00+03	78300.00
B6866C	2017-07-26 23:05:00+03	25100.00
B68749	2017-08-03 12:06:00+03	43600.00
B6874C	2017-07-31 07:08:00+03	80000.00
B68767	2017-07-05 05:25:00+03	23200.00
B68802	2017-08-08 16:41:00+03	10800.00
B68854	2017-07-09 19:56:00+03	195800.00
B68857	2017-07-07 08:33:00+03	66600.00
B68863	2017-08-06 16:07:00+03	157200.00
B68881	2017-08-11 07:58:00+03	80000.00
B68884	2017-08-02 15:25:00+03	87200.00
B68922	2017-08-05 03:36:00+03	198400.00
B68934	2017-07-28 09:58:00+03	47100.00
B68A0C	2017-07-27 14:08:00+03	18000.00
B68A1C	2017-08-04 18:29:00+03	68800.00
B68AD5	2017-07-19 12:14:00+03	55800.00
B68AEB	2017-08-04 22:16:00+03	38600.00
B68B61	2017-07-13 17:23:00+03	14800.00
B68B66	2017-07-19 19:37:00+03	24800.00
B68C0E	2017-08-08 10:19:00+03	34600.00
B68C15	2017-08-13 15:47:00+03	92800.00
B68C5B	2017-07-07 14:29:00+03	8600.00
B68CD8	2017-08-14 19:00:00+03	71200.00
B68CEB	2017-07-20 01:17:00+03	110500.00
B68D23	2017-07-03 09:36:00+03	72100.00
B68D71	2017-07-05 19:44:00+03	38600.00
B68E1C	2017-08-14 23:49:00+03	237900.00
B68E6A	2017-08-10 20:10:00+03	25600.00
B68EE4	2017-07-08 14:38:00+03	16400.00
B68EEA	2017-07-08 02:21:00+03	47200.00
B68EF1	2017-07-27 15:49:00+03	114800.00
B68EFC	2017-08-01 23:21:00+03	55800.00
B68F04	2017-07-09 02:57:00+03	57400.00
B68F13	2017-07-04 16:50:00+03	9200.00
B68F18	2017-08-11 07:29:00+03	40300.00
B68F2A	2017-07-07 03:45:00+03	12600.00
B68F85	2017-08-12 09:06:00+03	65500.00
B68F87	2017-08-13 16:38:00+03	31600.00
B68F95	2017-08-01 14:25:00+03	57200.00
B68FA6	2017-08-10 11:17:00+03	31400.00
B68FA8	2017-07-04 05:13:00+03	74400.00
B68FCB	2017-07-01 18:07:00+03	76300.00
B69053	2017-07-26 18:59:00+03	27800.00
B69054	2017-08-11 12:02:00+03	57500.00
B6905C	2017-07-15 02:15:00+03	103700.00
B69098	2017-07-28 18:29:00+03	47400.00
B690C8	2017-08-03 11:32:00+03	221900.00
B69135	2017-07-22 03:48:00+03	8000.00
B69158	2017-08-10 11:18:00+03	306500.00
B6926F	2017-08-14 18:51:00+03	67700.00
B69357	2017-07-09 21:28:00+03	37200.00
B69359	2017-07-27 07:15:00+03	149300.00
B693EE	2017-07-11 23:06:00+03	76800.00
B694B9	2017-08-05 14:56:00+03	26000.00
B694DC	2017-07-13 13:14:00+03	37600.00
B694F0	2017-07-17 05:29:00+03	52600.00
B69507	2017-07-07 03:30:00+03	83000.00
B695C8	2017-07-15 23:43:00+03	9800.00
B695D4	2017-08-15 07:46:00+03	30200.00
B69631	2017-07-08 17:05:00+03	129200.00
B69641	2017-07-17 09:15:00+03	32700.00
B69669	2017-07-03 15:21:00+03	132600.00
B696E4	2017-07-10 17:51:00+03	99600.00
B696E8	2017-07-21 12:34:00+03	111600.00
B69782	2017-08-04 14:35:00+03	25600.00
B697B8	2017-08-10 00:21:00+03	28800.00
B6981A	2017-08-06 06:14:00+03	275600.00
B6985B	2017-07-21 02:11:00+03	42000.00
B698B5	2017-08-08 06:08:00+03	24400.00
B698D8	2017-07-29 22:08:00+03	48400.00
B698DD	2017-07-19 22:02:00+03	14400.00
B698EF	2017-07-03 06:33:00+03	137900.00
B698F7	2017-07-25 07:21:00+03	37200.00
B6990A	2017-07-04 20:17:00+03	61700.00
B6991E	2017-07-14 22:38:00+03	55200.00
B69922	2017-07-12 23:36:00+03	52900.00
B69985	2017-07-14 09:22:00+03	39800.00
B6999E	2017-07-20 12:28:00+03	26000.00
B699F7	2017-07-21 20:24:00+03	19800.00
B69A17	2017-08-01 08:51:00+03	23600.00
B69A61	2017-06-29 01:51:00+03	23600.00
B69B56	2017-07-13 04:31:00+03	45200.00
B69B63	2017-07-25 21:50:00+03	28800.00
B69B89	2017-08-04 20:26:00+03	123000.00
B69BB3	2017-08-04 23:08:00+03	48400.00
B69BE8	2017-08-09 15:28:00+03	27200.00
B69C9F	2017-08-14 17:53:00+03	89600.00
B69CFC	2017-07-08 21:20:00+03	32400.00
B69D1D	2017-08-03 19:24:00+03	123700.00
B69D62	2017-07-27 15:31:00+03	9800.00
B69DB6	2017-07-05 14:49:00+03	16400.00
B69DBE	2017-07-07 07:19:00+03	43800.00
B69DF2	2017-07-13 20:24:00+03	52800.00
B69E24	2017-08-06 20:51:00+03	73500.00
B69E3D	2017-07-29 18:00:00+03	17800.00
B69E78	2017-08-06 20:37:00+03	42800.00
B69EA5	2017-08-03 06:04:00+03	145700.00
B69EC4	2017-07-06 05:23:00+03	6400.00
B69EC7	2017-07-17 07:31:00+03	13400.00
B69ECC	2017-07-19 07:33:00+03	56600.00
B69FD5	2017-08-04 23:56:00+03	32800.00
B69FDA	2017-07-18 11:17:00+03	29400.00
B69FEA	2017-07-28 01:16:00+03	30200.00
B69FF7	2017-07-25 13:10:00+03	36800.00
B6A057	2017-06-29 07:55:00+03	175300.00
B6A09A	2017-07-17 10:50:00+03	29800.00
B6A23B	2017-08-02 14:54:00+03	77200.00
B6A246	2017-08-09 08:58:00+03	44000.00
B6A2DF	2017-07-07 03:01:00+03	168300.00
B6A2E3	2017-08-14 17:40:00+03	139800.00
B6A326	2017-08-06 12:11:00+03	38400.00
B6A333	2017-07-24 16:37:00+03	62200.00
B6A394	2017-07-27 20:56:00+03	55000.00
B6A39B	2017-08-08 22:02:00+03	55800.00
B6A3B1	2017-07-18 00:43:00+03	43500.00
B6A3B7	2017-08-09 18:29:00+03	37200.00
B6A3F6	2017-08-09 17:23:00+03	23200.00
B6A444	2017-08-13 00:19:00+03	119500.00
B6A459	2017-08-05 17:06:00+03	25400.00
B6A468	2017-08-13 20:53:00+03	46400.00
B6A503	2017-08-02 00:55:00+03	46000.00
B6A50D	2017-08-01 01:18:00+03	175300.00
B6A564	2017-08-11 23:12:00+03	51900.00
B6A5B2	2017-08-02 03:39:00+03	405100.00
B6A5C4	2017-07-17 03:20:00+03	76600.00
B6A601	2017-07-01 16:46:00+03	112000.00
B6A64D	2017-08-15 13:44:00+03	15900.00
B6A672	2017-08-12 18:43:00+03	117200.00
B6A6A3	2017-08-08 06:37:00+03	64600.00
B6A6AB	2017-08-14 00:02:00+03	101200.00
B6A6EA	2017-08-09 23:50:00+03	56000.00
B6A700	2017-07-03 03:41:00+03	8200.00
B6A796	2017-08-14 07:28:00+03	14000.00
B6A7AD	2017-07-22 06:35:00+03	66600.00
B6A7E8	2017-08-01 19:44:00+03	68800.00
B6A7FA	2017-07-22 05:22:00+03	13600.00
B6A814	2017-07-01 21:49:00+03	123700.00
B6A857	2017-07-11 09:30:00+03	23200.00
B6A87B	2017-07-09 13:33:00+03	62000.00
B6A8B1	2017-08-06 04:37:00+03	59200.00
B6A8B2	2017-07-04 03:34:00+03	43300.00
B6A8D7	2017-06-30 21:34:00+03	118100.00
B6A8FA	2017-07-11 01:47:00+03	16400.00
B6A948	2017-08-02 00:15:00+03	46400.00
B6A9CE	2017-07-19 09:36:00+03	12600.00
B6A9E5	2017-07-15 21:15:00+03	23400.00
B6AA02	2017-08-02 11:39:00+03	21800.00
B6AA76	2017-07-22 10:40:00+03	73200.00
B6AA85	2017-07-10 22:21:00+03	48800.00
B6AB22	2017-07-12 17:48:00+03	56000.00
B6AB44	2017-08-08 08:41:00+03	38600.00
B6AB79	2017-07-30 21:22:00+03	56000.00
B6ABFB	2017-08-01 20:10:00+03	77900.00
B6AC1B	2017-07-26 01:28:00+03	246000.00
B6AC24	2017-07-29 01:35:00+03	85800.00
B6AC6A	2017-08-03 10:55:00+03	36900.00
B6AC83	2017-07-18 17:59:00+03	70800.00
B6AD99	2017-07-26 03:35:00+03	54300.00
B6ADEB	2017-08-09 21:54:00+03	147200.00
B6ADF0	2017-07-26 02:48:00+03	272000.00
B6AE13	2017-08-03 22:50:00+03	14000.00
B6AE28	2017-07-16 22:50:00+03	369000.00
B6AE29	2017-08-12 10:43:00+03	6700.00
B6AE62	2017-07-30 18:36:00+03	40800.00
B6AEB9	2017-07-21 09:41:00+03	306500.00
B6AEC6	2017-07-13 23:41:00+03	54000.00
B6AEFE	2017-07-22 10:59:00+03	28800.00
B6AF03	2017-07-14 06:57:00+03	73400.00
B6B00A	2017-06-30 01:19:00+03	16400.00
B6B063	2017-07-09 14:45:00+03	16800.00
B6B0E3	2017-07-28 23:20:00+03	60500.00
B6B145	2017-07-08 11:39:00+03	202100.00
B6B146	2017-07-31 11:14:00+03	93400.00
B6B1C9	2017-07-23 01:26:00+03	22100.00
B6B1DD	2017-07-18 05:23:00+03	29600.00
B6B1EC	2017-07-21 13:38:00+03	55800.00
B6B1F8	2017-07-23 06:00:00+03	67300.00
B6B225	2017-07-24 10:14:00+03	13400.00
B6B256	2017-07-07 21:43:00+03	26600.00
B6B281	2017-07-09 10:44:00+03	57500.00
B6B29F	2017-07-03 11:32:00+03	134400.00
B6B311	2017-07-09 15:08:00+03	149400.00
B6B3AA	2017-08-10 08:40:00+03	55800.00
B6B3DC	2017-07-03 03:38:00+03	40800.00
B6B421	2017-07-09 12:49:00+03	246200.00
B6B445	2017-08-10 19:12:00+03	26000.00
B6B45A	2017-08-06 03:07:00+03	50800.00
B6B520	2017-07-16 21:57:00+03	289800.00
B6B566	2017-08-15 12:31:00+03	55800.00
B6B5A2	2017-07-04 02:22:00+03	64700.00
B6B5A5	2017-08-02 21:20:00+03	29600.00
B6B5AC	2017-07-03 09:46:00+03	258400.00
B6B5B3	2017-07-06 00:16:00+03	10800.00
B6B5C2	2017-07-22 20:09:00+03	148200.00
B6B5D3	2017-07-17 13:18:00+03	79600.00
B6B5DF	2017-06-30 19:41:00+03	77200.00
B6B602	2017-06-28 21:56:00+03	29800.00
B6B640	2017-08-14 06:02:00+03	56900.00
B6B678	2017-07-14 00:33:00+03	89700.00
B6B69F	2017-07-09 11:17:00+03	18700.00
B6B6A1	2017-07-06 12:19:00+03	40800.00
B6B6A3	2017-07-11 22:26:00+03	376300.00
B6B6A9	2017-07-12 07:19:00+03	16000.00
B6B73C	2017-07-03 20:01:00+03	67400.00
B6B73D	2017-07-14 01:54:00+03	10800.00
B6B744	2017-06-27 17:55:00+03	123000.00
B6B7EE	2017-07-06 18:13:00+03	51500.00
B6B805	2017-07-05 05:55:00+03	46400.00
B6B818	2017-08-07 16:08:00+03	28000.00
B6B937	2017-07-24 10:11:00+03	123000.00
B6B9FB	2017-06-30 22:28:00+03	79200.00
B6BA25	2017-08-09 20:37:00+03	313800.00
B6BA37	2017-07-07 20:21:00+03	72300.00
B6BA65	2017-08-06 14:13:00+03	59800.00
B6BA78	2017-07-03 20:33:00+03	46300.00
B6BAA3	2017-08-01 11:44:00+03	231800.00
B6BABA	2017-08-14 10:58:00+03	40800.00
B6BAF8	2017-07-16 12:24:00+03	35200.00
B6BB11	2017-07-31 03:27:00+03	138100.00
B6BBB0	2017-07-24 14:36:00+03	17200.00
B6BC8F	2017-07-28 06:40:00+03	22400.00
B6BCD2	2017-07-04 16:57:00+03	87000.00
B6BD04	2017-07-23 19:41:00+03	13300.00
B6BD12	2017-08-06 06:40:00+03	301800.00
B6BD30	2017-08-14 15:41:00+03	21400.00
B6BD5E	2017-07-15 14:55:00+03	25400.00
B6BDC5	2017-07-13 07:20:00+03	81200.00
B6BDD3	2017-07-30 00:03:00+03	28800.00
B6BE23	2017-07-27 00:01:00+03	28000.00
B6BE52	2017-07-09 10:14:00+03	8200.00
B6BE76	2017-07-30 14:19:00+03	73200.00
B6BE78	2017-07-24 04:29:00+03	36200.00
B6BE80	2017-07-10 17:09:00+03	40600.00
B6BE8B	2017-07-03 17:12:00+03	68900.00
B6BE9B	2017-07-04 06:42:00+03	26000.00
B6BED2	2017-08-11 15:33:00+03	15000.00
B6BEF9	2017-07-28 01:37:00+03	116800.00
B6BF55	2017-08-10 11:00:00+03	61900.00
B6BF8E	2017-07-26 13:39:00+03	101200.00
B6C021	2017-07-15 09:16:00+03	40000.00
B6C03B	2017-07-16 16:40:00+03	13000.00
B6C062	2017-07-16 05:12:00+03	66600.00
B6C099	2017-08-09 18:03:00+03	31400.00
B6C0D5	2017-08-01 05:10:00+03	62600.00
B6C12B	2017-07-04 15:14:00+03	23200.00
B6C14C	2017-08-13 22:35:00+03	75500.00
B6C1AC	2017-07-12 10:49:00+03	81500.00
B6C244	2017-08-14 05:42:00+03	62000.00
B6C245	2017-07-27 17:24:00+03	40600.00
B6C247	2017-07-02 02:45:00+03	38400.00
B6C2B8	2017-08-12 08:04:00+03	28000.00
B6C2E5	2017-07-10 10:16:00+03	152600.00
B6C30C	2017-07-09 14:58:00+03	6700.00
B6C33C	2017-08-03 20:44:00+03	124200.00
B6C393	2017-08-07 17:55:00+03	18000.00
B6C39D	2017-07-08 11:03:00+03	43200.00
B6C3F8	2017-07-15 15:45:00+03	57600.00
B6C430	2017-07-17 15:12:00+03	62600.00
B6C4A8	2017-07-14 08:50:00+03	20200.00
B6C505	2017-07-22 16:54:00+03	51800.00
B6C520	2017-08-03 09:19:00+03	86400.00
B6C529	2017-07-17 21:08:00+03	43200.00
B6C54E	2017-07-09 04:56:00+03	133200.00
B6C554	2017-06-30 21:50:00+03	280400.00
B6C567	2017-07-05 13:59:00+03	73600.00
B6C581	2017-07-08 19:38:00+03	32200.00
B6C5A3	2017-07-27 02:10:00+03	21800.00
B6C5BD	2017-07-19 11:54:00+03	65900.00
B6C5E5	2017-07-17 04:17:00+03	28000.00
B6C5EE	2017-07-08 07:57:00+03	46400.00
B6C60B	2017-07-21 22:27:00+03	37100.00
B6C63B	2017-07-25 05:59:00+03	133200.00
B6C649	2017-08-02 20:55:00+03	44500.00
B6C67C	2017-07-23 04:26:00+03	101800.00
B6C6C2	2017-08-02 07:22:00+03	7900.00
B6C6C6	2017-07-02 10:11:00+03	45200.00
B6C6CC	2017-07-10 14:01:00+03	57400.00
B6C6EB	2017-07-26 10:41:00+03	169800.00
B6C710	2017-07-19 01:07:00+03	28800.00
B6C73D	2017-08-04 17:10:00+03	87000.00
B6C75A	2017-07-30 07:22:00+03	30000.00
B6C765	2017-07-09 23:32:00+03	6700.00
B6C7BE	2017-08-06 17:54:00+03	28000.00
B6C7D0	2017-07-10 05:19:00+03	46200.00
B6C812	2017-07-06 13:53:00+03	52300.00
B6C899	2017-08-15 16:28:00+03	27200.00
B6C8F7	2017-07-18 13:50:00+03	57400.00
B6C8FA	2017-07-03 23:07:00+03	219900.00
B6C903	2017-07-13 14:14:00+03	394400.00
B6C918	2017-08-02 06:49:00+03	18000.00
B6C92B	2017-07-17 20:35:00+03	24600.00
B6C937	2017-06-30 04:47:00+03	13400.00
B6C978	2017-07-26 08:14:00+03	57600.00
B6C986	2017-07-17 14:34:00+03	125600.00
B6CA60	2017-07-25 06:25:00+03	63200.00
B6CAE0	2017-07-29 08:54:00+03	47500.00
B6CB69	2017-08-03 04:40:00+03	57500.00
B6CBAD	2017-07-26 11:39:00+03	8000.00
B6CBCA	2017-07-06 04:02:00+03	20900.00
B6CBDA	2017-07-28 13:15:00+03	85700.00
B6CC1E	2017-06-26 01:10:00+03	12600.00
B6CCEE	2017-07-09 22:57:00+03	117900.00
B6CD25	2017-07-05 02:02:00+03	84500.00
B6CD32	2017-08-11 01:15:00+03	69500.00
B6CD5F	2017-07-15 11:41:00+03	71600.00
B6CD61	2017-07-23 20:37:00+03	28000.00
B6CDD2	2017-07-05 11:34:00+03	67800.00
B6CE0C	2017-08-08 02:14:00+03	49800.00
B6CE31	2017-08-06 02:53:00+03	141600.00
B6CE70	2017-08-01 13:55:00+03	23200.00
B6CE9A	2017-08-05 17:39:00+03	172100.00
B6CEB6	2017-08-03 14:15:00+03	251100.00
B6CEC6	2017-07-31 05:17:00+03	33100.00
B6CEF3	2017-07-07 11:35:00+03	58600.00
B6CF2F	2017-07-07 01:40:00+03	93800.00
B6CF33	2017-07-31 02:42:00+03	27900.00
B6CFD2	2017-07-16 21:19:00+03	32200.00
B6D011	2017-06-29 19:45:00+03	32200.00
B6D023	2017-07-25 00:06:00+03	14700.00
B6D051	2017-07-22 08:41:00+03	29600.00
B6D083	2017-07-14 10:05:00+03	282000.00
B6D101	2017-07-21 04:36:00+03	246000.00
B6D106	2017-08-02 01:09:00+03	16400.00
B6D161	2017-08-10 09:13:00+03	34300.00
B6D22D	2017-07-14 12:18:00+03	51900.00
B6D251	2017-08-08 17:29:00+03	40800.00
B6D25D	2017-07-12 15:32:00+03	30100.00
B6D2DE	2017-07-10 22:59:00+03	28000.00
B6D31C	2017-07-29 12:58:00+03	50100.00
B6D356	2017-08-09 06:51:00+03	98200.00
B6D370	2017-08-09 11:50:00+03	47400.00
B6D419	2017-08-07 01:33:00+03	51300.00
B6D420	2017-08-12 09:37:00+03	119800.00
B6D43D	2017-08-12 08:49:00+03	55700.00
B6D4C4	2017-07-16 04:25:00+03	303500.00
B6D4E9	2017-08-12 18:01:00+03	24800.00
B6D558	2017-08-11 07:55:00+03	37600.00
B6D58D	2017-08-12 02:35:00+03	55800.00
B6D593	2017-07-08 16:38:00+03	8400.00
B6D5DB	2017-08-10 23:25:00+03	23200.00
B6D5E4	2017-07-17 10:30:00+03	112000.00
B6D665	2017-07-09 11:15:00+03	28800.00
B6D6E0	2017-06-30 22:51:00+03	67200.00
B6D6F0	2017-07-28 17:22:00+03	94200.00
B6D739	2017-07-07 14:04:00+03	11700.00
B6D754	2017-07-09 04:02:00+03	28000.00
B6D77C	2017-08-01 13:51:00+03	131900.00
B6D7EA	2017-06-30 23:43:00+03	29300.00
B6D80D	2017-07-26 06:07:00+03	57300.00
B6D82B	2017-07-16 07:51:00+03	23200.00
B6D835	2017-07-11 07:27:00+03	48800.00
B6D89F	2017-08-13 22:37:00+03	34200.00
B6D8CC	2017-07-19 23:38:00+03	80500.00
B6D8E2	2017-07-05 18:39:00+03	57600.00
B6D95F	2017-07-23 09:14:00+03	19600.00
B6D9BC	2017-07-21 02:25:00+03	135400.00
B6D9DE	2017-08-15 12:35:00+03	123900.00
B6D9DF	2017-08-12 13:53:00+03	26000.00
B6DA94	2017-06-29 01:10:00+03	102600.00
B6DAB2	2017-07-09 22:56:00+03	51600.00
B6DAE3	2017-08-02 19:48:00+03	138000.00
B6DAE6	2017-08-15 06:00:00+03	89700.00
B6DAF2	2017-07-18 19:04:00+03	27400.00
B6DBE7	2017-08-04 09:58:00+03	22000.00
B6DCAD	2017-07-31 21:00:00+03	59600.00
B6DCC9	2017-07-05 02:42:00+03	56600.00
B6DD50	2017-07-04 20:35:00+03	184500.00
B6DD60	2017-07-14 15:48:00+03	118000.00
B6DDAC	2017-08-06 04:33:00+03	37100.00
B6DDB8	2017-08-05 11:54:00+03	101200.00
B6DE09	2017-07-02 07:44:00+03	37900.00
B6DE83	2017-07-23 18:43:00+03	57700.00
B6DECE	2017-08-12 07:19:00+03	44700.00
B6DEFF	2017-07-06 19:56:00+03	75200.00
B6DF21	2017-07-14 14:33:00+03	50600.00
B6DF9C	2017-07-10 03:43:00+03	133200.00
B6DFA1	2017-08-01 04:47:00+03	69600.00
B6DFA2	2017-07-13 16:18:00+03	45100.00
B6DFB8	2017-08-13 21:49:00+03	54200.00
B6DFDC	2017-07-21 12:51:00+03	56200.00
B6E10D	2017-06-27 14:53:00+03	49800.00
B6E138	2017-08-15 02:52:00+03	60000.00
B6E153	2017-07-20 01:48:00+03	26800.00
B6E1AB	2017-07-21 21:47:00+03	24000.00
B6E1D1	2017-08-12 09:04:00+03	19600.00
B6E1F1	2017-08-14 23:35:00+03	10700.00
B6E201	2017-07-09 16:37:00+03	51600.00
B6E205	2017-08-12 09:50:00+03	9200.00
B6E222	2017-07-30 17:22:00+03	147000.00
B6E289	2017-07-13 16:18:00+03	47000.00
B6E325	2017-08-11 00:32:00+03	39300.00
B6E343	2017-07-10 07:31:00+03	102100.00
B6E388	2017-07-04 22:52:00+03	258400.00
B6E38A	2017-07-01 15:53:00+03	136800.00
B6E3DE	2017-07-20 07:27:00+03	66100.00
B6E3F8	2017-07-08 00:19:00+03	264000.00
B6E3F9	2017-07-25 16:55:00+03	44000.00
B6E411	2017-07-10 22:21:00+03	114700.00
B6E4AE	2017-07-09 07:20:00+03	25900.00
B6E4BF	2017-07-08 13:18:00+03	21400.00
B6E4CC	2017-07-18 21:41:00+03	22000.00
B6E4F0	2017-07-09 08:42:00+03	241600.00
B6E4F3	2017-08-13 08:01:00+03	99500.00
B6E579	2017-07-11 20:54:00+03	88600.00
B6E5A6	2017-07-02 03:57:00+03	20400.00
B6E5E6	2017-08-01 16:47:00+03	148800.00
B6E5EB	2017-07-02 03:51:00+03	20700.00
B6E5FE	2017-07-05 17:35:00+03	6700.00
B6E606	2017-07-26 17:54:00+03	124200.00
B6E626	2017-07-06 00:32:00+03	60400.00
B6E66C	2017-08-06 12:47:00+03	11800.00
B6E6B4	2017-07-06 17:41:00+03	236700.00
B6E6C8	2017-08-15 10:35:00+03	24600.00
B6E6DC	2017-07-29 17:27:00+03	29600.00
B6E814	2017-07-05 18:41:00+03	101200.00
B6E881	2017-07-19 14:51:00+03	90400.00
B6E899	2017-07-14 11:53:00+03	266200.00
B6E8BA	2017-08-12 17:56:00+03	55800.00
B6E92C	2017-07-22 15:04:00+03	95200.00
B6E93E	2017-08-03 15:34:00+03	52600.00
B6E9BA	2017-08-11 15:02:00+03	106600.00
B6EA3B	2017-08-10 03:20:00+03	27900.00
B6EA63	2017-07-07 04:59:00+03	111600.00
B6EA85	2017-08-11 13:18:00+03	58600.00
B6EA8A	2017-08-11 15:24:00+03	168200.00
B6EAA1	2017-07-20 14:58:00+03	56000.00
B6EB5E	2017-07-31 05:32:00+03	106400.00
B6EB6A	2017-08-04 17:28:00+03	48800.00
B6EBD5	2017-07-29 00:56:00+03	63700.00
B6EC6F	2017-07-04 11:47:00+03	56000.00
B6EC77	2017-07-25 17:55:00+03	66000.00
B6ECD7	2017-07-14 13:49:00+03	102100.00
B6ED2C	2017-08-15 05:53:00+03	77900.00
B6EDCA	2017-08-01 02:16:00+03	57300.00
B6EE0B	2017-07-03 06:43:00+03	37900.00
B6EE1A	2017-08-05 12:32:00+03	42700.00
B6EE3C	2017-08-02 23:52:00+03	73500.00
B6EE71	2017-07-10 06:06:00+03	23400.00
B6EECD	2017-07-29 21:05:00+03	34000.00
B6F026	2017-07-13 16:29:00+03	143200.00
B6F0FB	2017-07-11 02:17:00+03	65400.00
B6F102	2017-07-11 10:48:00+03	39300.00
B6F13E	2017-07-04 01:20:00+03	67000.00
B6F14F	2017-07-23 13:13:00+03	47400.00
B6F171	2017-07-29 13:46:00+03	80000.00
B6F174	2017-08-07 09:47:00+03	75300.00
B6F194	2017-08-01 23:33:00+03	14400.00
B6F1AC	2017-08-13 00:39:00+03	46400.00
B6F1D0	2017-08-08 04:04:00+03	68800.00
B6F1DF	2017-08-15 01:48:00+03	62000.00
B6F1FB	2017-08-13 13:04:00+03	24400.00
B6F200	2017-07-20 03:00:00+03	666000.00
B6F2C5	2017-08-04 15:49:00+03	64200.00
B6F2EA	2017-07-09 00:31:00+03	258400.00
B6F2ED	2017-07-07 23:08:00+03	22400.00
B6F302	2017-08-02 01:38:00+03	132500.00
B6F3AB	2017-08-12 01:48:00+03	44000.00
B6F3DC	2017-07-26 09:03:00+03	265600.00
B6F402	2017-07-04 08:43:00+03	93600.00
B6F404	2017-08-12 00:26:00+03	37200.00
B6F45B	2017-07-08 11:56:00+03	13400.00
B6F4AE	2017-08-10 18:16:00+03	43200.00
B6F4C1	2017-08-09 07:40:00+03	95600.00
B6F4C3	2017-07-21 13:38:00+03	75500.00
B6F528	2017-08-01 05:36:00+03	152400.00
B6F54A	2017-06-25 23:34:00+03	86400.00
B6F559	2017-07-14 09:08:00+03	246000.00
B6F5A3	2017-08-06 09:46:00+03	114800.00
B6F5CA	2017-08-05 06:36:00+03	23200.00
B6F5D6	2017-08-08 19:03:00+03	81300.00
B6F5DC	2017-08-06 15:42:00+03	21200.00
B6F5FD	2017-06-26 04:11:00+03	56600.00
B6F693	2017-07-31 05:23:00+03	26000.00
B6F709	2017-07-31 20:01:00+03	103500.00
B6F70F	2017-07-12 01:53:00+03	29400.00
B6F717	2017-06-29 02:48:00+03	49600.00
B6F727	2017-07-06 22:09:00+03	88600.00
B6F729	2017-08-13 15:18:00+03	70700.00
B6F89B	2017-08-02 08:51:00+03	6000.00
B6F8C2	2017-07-17 11:34:00+03	54000.00
B6F8E8	2017-07-02 20:34:00+03	25200.00
B6F920	2017-07-04 09:45:00+03	411400.00
B6F95F	2017-07-12 09:39:00+03	22600.00
B6F975	2017-07-04 20:44:00+03	66300.00
B6FA17	2017-06-30 01:10:00+03	40800.00
B6FA3C	2017-07-21 10:00:00+03	270800.00
B6FA54	2017-08-10 11:55:00+03	38600.00
B6FAAC	2017-08-06 05:42:00+03	90100.00
B6FADB	2017-07-21 23:08:00+03	64500.00
B6FB07	2017-07-27 15:04:00+03	66600.00
B6FB20	2017-07-09 18:16:00+03	42800.00
B6FB7B	2017-07-13 22:29:00+03	26200.00
B6FB98	2017-07-29 09:43:00+03	75600.00
B6FBCD	2017-07-03 22:56:00+03	90100.00
B6FBD7	2017-07-07 14:29:00+03	56000.00
B6FBF0	2017-08-04 12:16:00+03	38200.00
B6FC17	2017-07-29 15:08:00+03	133200.00
B6FC2F	2017-07-20 21:07:00+03	31100.00
B6FCD6	2017-07-30 02:54:00+03	55800.00
B6FCDC	2017-08-01 15:40:00+03	177200.00
B6FD34	2017-07-30 04:51:00+03	79600.00
B6FD55	2017-07-03 18:20:00+03	46400.00
B6FDFA	2017-07-12 10:36:00+03	184500.00
B6FE12	2017-08-10 06:59:00+03	110400.00
B6FE45	2017-07-04 10:05:00+03	84000.00
B6FE4A	2017-08-10 23:29:00+03	257600.00
B6FE74	2017-07-08 06:53:00+03	119600.00
B6FE8B	2017-07-19 13:17:00+03	48300.00
B6FEBD	2017-07-21 13:44:00+03	47500.00
B6FEC8	2017-08-10 16:58:00+03	23400.00
B6FECD	2017-07-24 12:11:00+03	65900.00
B6FF07	2017-08-05 19:23:00+03	52700.00
B6FF65	2017-07-22 22:06:00+03	32800.00
B6FF8D	2017-08-10 14:34:00+03	26800.00
B6FFA0	2017-07-15 10:09:00+03	23200.00
B6FFF6	2017-08-12 18:37:00+03	103900.00
B700E9	2017-07-21 15:27:00+03	65500.00
B70149	2017-07-26 17:19:00+03	64700.00
B701F5	2017-07-04 10:27:00+03	265700.00
B70284	2017-08-08 02:55:00+03	75300.00
B702FD	2017-07-29 15:09:00+03	75300.00
B70303	2017-07-21 17:47:00+03	149300.00
B7032E	2017-06-29 23:06:00+03	47100.00
B70348	2017-07-26 21:48:00+03	19600.00
B70376	2017-07-20 14:01:00+03	36200.00
B70479	2017-07-28 17:09:00+03	113100.00
B704FA	2017-07-28 22:08:00+03	73500.00
B70522	2017-07-24 15:02:00+03	38800.00
B70526	2017-07-03 13:49:00+03	162200.00
B70539	2017-07-16 11:59:00+03	57800.00
B70550	2017-08-11 01:37:00+03	23200.00
B70557	2017-07-08 10:26:00+03	43200.00
B70586	2017-07-18 16:06:00+03	77600.00
B705C2	2017-07-31 01:15:00+03	40800.00
B705DF	2017-08-14 22:58:00+03	20800.00
B7060C	2017-07-30 09:25:00+03	125400.00
B7060E	2017-08-04 23:46:00+03	30200.00
B70628	2017-07-13 00:45:00+03	146300.00
B70651	2017-08-15 06:07:00+03	146400.00
B70688	2017-06-26 23:17:00+03	58100.00
B706BA	2017-08-01 17:58:00+03	26100.00
B7075C	2017-07-20 19:11:00+03	54600.00
B7076F	2017-07-27 23:10:00+03	65400.00
B70783	2017-07-04 13:57:00+03	6000.00
B7078C	2017-07-11 14:31:00+03	89600.00
B707DC	2017-07-11 08:38:00+03	92800.00
B70830	2017-07-02 15:31:00+03	88600.00
B70835	2017-07-22 23:48:00+03	26000.00
B70848	2017-07-17 19:02:00+03	49000.00
B70875	2017-08-11 08:40:00+03	19600.00
B70890	2017-07-05 11:16:00+03	254900.00
B70891	2017-07-23 09:04:00+03	37900.00
B708E2	2017-07-15 11:20:00+03	30200.00
B70917	2017-07-12 10:51:00+03	246200.00
B7096F	2017-08-09 21:22:00+03	68000.00
B709AC	2017-07-18 07:27:00+03	86300.00
B709D6	2017-08-08 16:16:00+03	11600.00
B70A06	2017-08-05 17:44:00+03	88600.00
B70A45	2017-07-10 00:41:00+03	103100.00
B70ACC	2017-07-11 20:16:00+03	28800.00
B70AEF	2017-07-05 17:18:00+03	46400.00
B70AF3	2017-07-09 09:57:00+03	37900.00
B70B37	2017-07-23 09:42:00+03	30200.00
B70B4E	2017-08-06 21:23:00+03	31600.00
B70BC9	2017-07-06 11:17:00+03	52000.00
B70BDA	2017-07-09 16:35:00+03	44500.00
B70BE9	2017-08-12 05:10:00+03	19600.00
B70C0E	2017-07-14 13:47:00+03	23200.00
B70D76	2017-08-12 11:40:00+03	46400.00
B70DBA	2017-08-10 08:03:00+03	167400.00
B70DD4	2017-08-02 09:25:00+03	76200.00
B70E0A	2017-07-24 12:17:00+03	29400.00
B70F27	2017-08-05 23:15:00+03	17600.00
B70F64	2017-07-16 22:17:00+03	38200.00
B70F88	2017-07-25 20:10:00+03	42800.00
B70F9F	2017-08-07 15:15:00+03	14000.00
B70FB9	2017-07-01 06:10:00+03	69000.00
B71015	2017-07-25 12:31:00+03	64500.00
B71064	2017-08-05 19:38:00+03	281500.00
B710A5	2017-08-13 08:26:00+03	173900.00
B710EB	2017-07-18 07:19:00+03	52000.00
B710FF	2017-07-02 03:12:00+03	61800.00
B71113	2017-07-02 00:14:00+03	25700.00
B7111B	2017-07-07 14:31:00+03	14400.00
B71156	2017-08-14 20:51:00+03	32800.00
B7122A	2017-08-11 01:33:00+03	49500.00
B71284	2017-07-10 11:22:00+03	85000.00
B7129D	2017-07-12 11:13:00+03	23900.00
B712C0	2017-07-28 05:24:00+03	59100.00
B712CD	2017-07-17 05:06:00+03	8200.00
B712FD	2017-06-30 08:39:00+03	136800.00
B7132E	2017-07-22 22:10:00+03	246000.00
B7133B	2017-07-22 06:06:00+03	37700.00
B71347	2017-08-07 00:32:00+03	56000.00
B713BD	2017-07-05 10:12:00+03	170500.00
B713F2	2017-07-03 09:02:00+03	75300.00
B713FB	2017-08-01 17:30:00+03	54500.00
B71402	2017-07-10 02:27:00+03	38000.00
B714E1	2017-07-15 03:26:00+03	66800.00
B7155B	2017-08-06 01:44:00+03	48800.00
B71570	2017-07-07 01:46:00+03	46200.00
B715B2	2017-08-05 14:46:00+03	93500.00
B715EC	2017-08-10 13:45:00+03	107500.00
B71602	2017-07-04 15:58:00+03	58000.00
B71640	2017-07-29 23:16:00+03	6800.00
B71740	2017-07-07 18:56:00+03	35400.00
B71752	2017-07-27 07:37:00+03	193600.00
B71762	2017-08-06 05:48:00+03	386300.00
B71785	2017-07-26 04:05:00+03	269200.00
B7179C	2017-08-07 17:12:00+03	58600.00
B717AB	2017-08-01 13:10:00+03	272300.00
B717BB	2017-07-18 13:37:00+03	239100.00
B717BE	2017-08-08 16:54:00+03	14700.00
B717D6	2017-07-22 07:29:00+03	28800.00
B71882	2017-08-10 14:07:00+03	26400.00
B718F5	2017-08-03 13:18:00+03	34400.00
B71944	2017-07-24 06:37:00+03	25000.00
B7195C	2017-07-06 23:43:00+03	163000.00
B7196C	2017-07-17 20:55:00+03	201200.00
B71981	2017-08-13 07:30:00+03	25100.00
B719AE	2017-07-20 15:15:00+03	36200.00
B719BA	2017-07-03 23:00:00+03	34000.00
B719F2	2017-07-16 12:58:00+03	62600.00
B719F9	2017-07-02 04:19:00+03	28000.00
B71AD5	2017-07-17 09:34:00+03	198600.00
B71AED	2017-08-09 20:02:00+03	46000.00
B71AF3	2017-07-27 05:14:00+03	13400.00
B71B2D	2017-08-07 12:22:00+03	55800.00
B71B32	2017-08-05 01:08:00+03	52300.00
B71B40	2017-07-07 12:22:00+03	187800.00
B71BA7	2017-07-08 08:50:00+03	30400.00
B71BC1	2017-07-09 10:37:00+03	15900.00
B71BEF	2017-08-05 08:51:00+03	93400.00
B71C35	2017-07-25 08:44:00+03	50000.00
B71C90	2017-08-09 17:31:00+03	67600.00
B71D03	2017-07-19 18:23:00+03	22800.00
B71D71	2017-07-29 02:30:00+03	97900.00
B71DDD	2017-08-13 05:00:00+03	120400.00
B71E6E	2017-07-28 21:46:00+03	139300.00
B71EE1	2017-07-14 23:15:00+03	133200.00
B71F5F	2017-08-03 03:47:00+03	23600.00
B71F6E	2017-07-12 21:01:00+03	265800.00
B71F8B	2017-07-05 13:49:00+03	24000.00
B71FCB	2017-07-27 17:49:00+03	26000.00
B71FD2	2017-07-01 21:53:00+03	6600.00
B72041	2017-08-06 07:59:00+03	61400.00
B72048	2017-07-03 22:07:00+03	58000.00
B7205E	2017-07-06 03:40:00+03	179500.00
B72069	2017-07-07 07:40:00+03	16400.00
B72085	2017-07-19 10:16:00+03	47000.00
B720DC	2017-07-06 21:48:00+03	48800.00
B72106	2017-08-06 09:46:00+03	27200.00
B72150	2017-07-29 00:30:00+03	132300.00
B7216C	2017-07-04 22:08:00+03	67600.00
B721D5	2017-07-22 08:07:00+03	40800.00
B721F7	2017-08-11 22:58:00+03	26100.00
B72215	2017-08-08 13:33:00+03	14000.00
B722AD	2017-07-05 15:03:00+03	52700.00
B722D3	2017-07-02 20:15:00+03	131100.00
B72375	2017-07-07 11:06:00+03	8200.00
B72391	2017-08-09 17:39:00+03	29200.00
B723AA	2017-08-08 20:24:00+03	396600.00
B723B6	2017-08-12 13:10:00+03	152900.00
B723E1	2017-07-16 07:28:00+03	15900.00
B723E5	2017-06-30 03:54:00+03	372500.00
B72411	2017-07-12 20:46:00+03	119700.00
B72434	2017-08-02 21:52:00+03	39200.00
B7244B	2017-07-02 06:29:00+03	46000.00
B724BE	2017-07-23 12:42:00+03	46200.00
B7250F	2017-08-14 05:42:00+03	25100.00
B7254F	2017-07-16 08:30:00+03	342300.00
B72589	2017-08-08 04:38:00+03	189200.00
B725C9	2017-07-26 04:45:00+03	44500.00
B7263E	2017-08-11 09:03:00+03	118500.00
B7264E	2017-08-12 19:18:00+03	193600.00
B726B8	2017-08-07 21:09:00+03	111600.00
B7272F	2017-07-07 14:00:00+03	152500.00
B7274D	2017-07-19 09:42:00+03	399600.00
B72751	2017-08-13 23:06:00+03	14400.00
B72780	2017-07-12 06:12:00+03	61800.00
B727F7	2017-07-18 22:26:00+03	26000.00
B727FD	2017-07-21 16:15:00+03	39400.00
B7280C	2017-07-03 04:11:00+03	56000.00
B72815	2017-08-12 00:33:00+03	6700.00
B72832	2017-07-11 18:56:00+03	246000.00
B7284A	2017-07-16 02:01:00+03	231200.00
B72858	2017-07-13 01:24:00+03	155600.00
B728AC	2017-07-01 03:27:00+03	67900.00
B72945	2017-08-03 13:45:00+03	82100.00
B72970	2017-07-09 04:54:00+03	64900.00
B729F2	2017-07-11 00:44:00+03	23600.00
B72A4D	2017-07-10 12:21:00+03	179300.00
B72A5E	2017-08-12 17:39:00+03	31600.00
B72A83	2017-07-20 21:41:00+03	266200.00
B72ADC	2017-07-09 07:17:00+03	64100.00
B72AE4	2017-08-06 16:39:00+03	38400.00
B72B4A	2017-07-12 17:13:00+03	119800.00
B72B70	2017-07-15 03:57:00+03	136200.00
B72BF4	2017-07-13 10:23:00+03	103600.00
B72CF8	2017-07-28 11:03:00+03	38300.00
B72D5F	2017-07-15 09:37:00+03	258400.00
B72D94	2017-08-03 17:11:00+03	94900.00
B72DBA	2017-08-15 01:58:00+03	43600.00
B72DF6	2017-07-15 05:57:00+03	101100.00
B72E27	2017-07-01 16:19:00+03	135400.00
B72E87	2017-07-10 16:35:00+03	10800.00
B72EA0	2017-07-04 00:48:00+03	7200.00
B72EBB	2017-07-30 11:09:00+03	36900.00
B72EC3	2017-08-15 12:12:00+03	66600.00
B72EC4	2017-07-16 00:27:00+03	73600.00
B72F16	2017-07-31 01:57:00+03	67000.00
B72F67	2017-08-08 09:21:00+03	24600.00
B72F99	2017-07-18 17:20:00+03	54600.00
B72FEB	2017-08-04 04:17:00+03	73000.00
B7300C	2017-07-30 15:30:00+03	41800.00
B730FB	2017-07-12 15:40:00+03	145300.00
B730FE	2017-08-01 05:08:00+03	67600.00
B73117	2017-07-08 22:13:00+03	36200.00
B7311C	2017-08-06 00:59:00+03	315000.00
B7312A	2017-07-20 19:02:00+03	28800.00
B73161	2017-07-03 02:16:00+03	122800.00
B73178	2017-08-06 07:07:00+03	23600.00
B731F0	2017-06-30 15:20:00+03	64500.00
B73200	2017-07-18 10:27:00+03	12600.00
B73251	2017-07-17 08:22:00+03	55800.00
B73283	2017-07-05 23:52:00+03	76600.00
B732A9	2017-07-12 02:23:00+03	113200.00
B73341	2017-07-31 01:33:00+03	22000.00
B733A0	2017-08-01 00:49:00+03	51500.00
B733B0	2017-08-09 06:34:00+03	60400.00
B733D6	2017-08-01 13:29:00+03	133200.00
B733EE	2017-07-30 21:31:00+03	21400.00
B733F1	2017-08-06 07:28:00+03	36800.00
B7345B	2017-06-30 10:35:00+03	46800.00
B73485	2017-07-17 03:16:00+03	25200.00
B734BE	2017-07-09 23:44:00+03	170600.00
B734CA	2017-07-01 12:33:00+03	39300.00
B734EF	2017-07-06 02:15:00+03	87000.00
B734FC	2017-08-09 09:24:00+03	51800.00
B73523	2017-07-03 15:27:00+03	50700.00
B73582	2017-07-09 02:50:00+03	52800.00
B73620	2017-08-07 04:29:00+03	172100.00
B73621	2017-07-27 02:46:00+03	92700.00
B73695	2017-07-24 19:54:00+03	168200.00
B736E0	2017-08-13 05:39:00+03	54800.00
B736F1	2017-08-02 14:14:00+03	40800.00
B73768	2017-07-19 15:25:00+03	136500.00
B737C4	2017-07-08 23:09:00+03	47700.00
B73859	2017-07-23 14:50:00+03	48800.00
B73869	2017-08-04 06:52:00+03	166000.00
B73889	2017-07-21 08:07:00+03	300700.00
B738F0	2017-07-09 06:29:00+03	34800.00
B73953	2017-08-14 13:25:00+03	36800.00
B73955	2017-08-12 22:55:00+03	55800.00
B7396A	2017-08-05 05:18:00+03	199300.00
B73987	2017-07-31 10:05:00+03	81200.00
B7399E	2017-07-08 05:31:00+03	132800.00
B739D3	2017-07-30 17:25:00+03	32800.00
B739D9	2017-07-13 03:02:00+03	44600.00
B739F2	2017-07-07 16:30:00+03	91100.00
B73AB4	2017-08-13 08:25:00+03	26000.00
B73B67	2017-08-12 03:22:00+03	26000.00
B73B9B	2017-07-01 23:48:00+03	27200.00
B73BBC	2017-07-11 01:01:00+03	21000.00
B73BC4	2017-08-13 01:34:00+03	69500.00
B73BD2	2017-08-07 17:34:00+03	57600.00
B73BE1	2017-07-27 06:25:00+03	68300.00
B73C10	2017-08-13 00:09:00+03	43500.00
B73C35	2017-08-06 22:36:00+03	56000.00
B73C8D	2017-08-14 19:41:00+03	40800.00
B73D12	2017-07-29 12:09:00+03	28800.00
B73D48	2017-08-15 09:33:00+03	28800.00
B73D70	2017-07-21 20:24:00+03	30000.00
B73D74	2017-07-31 11:45:00+03	36000.00
B73DFF	2017-07-05 14:49:00+03	68800.00
B73F3F	2017-08-08 23:41:00+03	186900.00
B73FBD	2017-07-14 06:44:00+03	111600.00
B74002	2017-07-13 20:44:00+03	81600.00
B74066	2017-08-09 11:19:00+03	18600.00
B740B0	2017-07-27 12:15:00+03	14800.00
B740C6	2017-07-16 08:54:00+03	36600.00
B740EA	2017-07-06 03:56:00+03	101200.00
B7414E	2017-08-10 04:16:00+03	28000.00
B7419A	2017-08-02 04:55:00+03	28000.00
B741AA	2017-08-14 14:29:00+03	260900.00
B7423F	2017-07-29 02:03:00+03	44700.00
B742FA	2017-07-05 02:05:00+03	23600.00
B74328	2017-08-11 19:29:00+03	54100.00
B74393	2017-07-29 10:28:00+03	75200.00
B743EA	2017-08-02 12:31:00+03	73300.00
B74411	2017-08-11 15:14:00+03	135400.00
B74450	2017-08-14 21:14:00+03	57400.00
B7447E	2017-07-17 07:16:00+03	40800.00
B74492	2017-07-29 05:02:00+03	135400.00
B744B6	2017-08-08 14:04:00+03	36200.00
B744EC	2017-07-15 22:43:00+03	20600.00
B7455F	2017-07-29 13:02:00+03	23200.00
B74567	2017-07-02 06:47:00+03	52300.00
B745AE	2017-07-12 20:00:00+03	189200.00
B745CA	2017-08-12 19:20:00+03	265700.00
B74626	2017-07-14 07:12:00+03	47100.00
B74629	2017-08-01 19:21:00+03	26000.00
B74639	2017-07-19 13:00:00+03	217900.00
B7463D	2017-07-17 01:04:00+03	107700.00
B74646	2017-08-10 06:49:00+03	30000.00
B74651	2017-07-21 13:02:00+03	27700.00
B746AF	2017-08-11 04:54:00+03	75300.00
B746C9	2017-07-28 02:37:00+03	52300.00
B74706	2017-08-06 20:53:00+03	74800.00
B74719	2017-07-08 09:45:00+03	17200.00
B74736	2017-08-07 21:32:00+03	35200.00
B74751	2017-07-30 04:44:00+03	193500.00
B74760	2017-08-12 06:56:00+03	34600.00
B74859	2017-07-30 05:37:00+03	102300.00
B74865	2017-07-07 11:07:00+03	10800.00
B74891	2017-07-17 11:12:00+03	192700.00
B7493E	2017-08-03 18:11:00+03	6000.00
B74967	2017-08-12 21:58:00+03	75500.00
B74980	2017-07-18 20:16:00+03	119500.00
B7498E	2017-08-04 00:54:00+03	46000.00
B749A3	2017-08-07 01:28:00+03	27900.00
B74A36	2017-07-21 11:41:00+03	40600.00
B74AB0	2017-08-06 02:44:00+03	37200.00
B74B04	2017-08-09 11:48:00+03	22000.00
B74BA1	2017-08-08 05:52:00+03	137600.00
B74BDD	2017-08-11 09:27:00+03	66900.00
B74C70	2017-07-02 13:43:00+03	73500.00
B74C92	2017-07-16 14:03:00+03	22000.00
B74C99	2017-07-20 06:29:00+03	81600.00
B74CC3	2017-07-03 11:44:00+03	6800.00
B74D6C	2017-08-14 02:20:00+03	93700.00
B74D83	2017-08-08 13:31:00+03	79600.00
B74D92	2017-08-07 04:40:00+03	64500.00
B74DA1	2017-07-09 17:14:00+03	26000.00
B74E2D	2017-08-10 17:27:00+03	99300.00
B74ECB	2017-07-27 17:45:00+03	79200.00
B74EE4	2017-07-08 14:16:00+03	23400.00
B74F09	2017-07-07 23:19:00+03	32800.00
B74F6D	2017-08-10 09:49:00+03	14400.00
B75001	2017-07-26 08:05:00+03	26000.00
B750CC	2017-07-17 12:07:00+03	97800.00
B7517D	2017-08-08 09:06:00+03	32700.00
B751A6	2017-07-24 22:32:00+03	56600.00
B751B9	2017-08-13 19:47:00+03	12600.00
B751BC	2017-07-02 19:58:00+03	92000.00
B751D4	2017-08-10 12:45:00+03	62600.00
B751EB	2017-07-22 03:05:00+03	58600.00
B752C1	2017-08-03 15:08:00+03	129700.00
B75314	2017-07-10 10:22:00+03	69500.00
B7531E	2017-08-05 01:13:00+03	23200.00
B7539D	2017-08-01 20:51:00+03	55800.00
B753CC	2017-07-05 10:09:00+03	95200.00
B753E3	2017-07-30 23:25:00+03	134600.00
B753F4	2017-07-25 20:17:00+03	85000.00
B753F5	2017-07-24 18:20:00+03	43600.00
B7542E	2017-07-05 16:54:00+03	32800.00
B75465	2017-07-27 01:05:00+03	169900.00
B75549	2017-07-19 11:33:00+03	60400.00
B75570	2017-07-13 23:38:00+03	99600.00
B755D4	2017-07-09 15:10:00+03	19500.00
B755E3	2017-07-04 20:40:00+03	25200.00
B75612	2017-08-12 05:44:00+03	16000.00
B75683	2017-08-11 13:25:00+03	12600.00
B756B1	2017-07-26 01:13:00+03	13600.00
B756C7	2017-08-06 20:05:00+03	55800.00
B756F7	2017-08-09 08:14:00+03	111600.00
B75701	2017-07-13 00:08:00+03	78500.00
B75704	2017-07-27 15:30:00+03	246000.00
B7574E	2017-07-26 18:29:00+03	55800.00
B75763	2017-07-15 19:47:00+03	184500.00
B7576F	2017-08-05 01:05:00+03	13000.00
B757CF	2017-07-21 10:43:00+03	46400.00
B75818	2017-07-13 02:17:00+03	12600.00
B75840	2017-07-15 12:24:00+03	21800.00
B7587D	2017-06-30 11:51:00+03	46400.00
B75880	2017-08-03 05:59:00+03	29600.00
B75892	2017-07-16 16:41:00+03	28000.00
B75896	2017-08-01 23:19:00+03	64700.00
B758D9	2017-08-04 18:08:00+03	24400.00
B758E7	2017-06-29 15:22:00+03	58800.00
B7590F	2017-07-17 15:43:00+03	14400.00
B75917	2017-07-24 14:54:00+03	23200.00
B75942	2017-07-02 08:51:00+03	48800.00
B7595A	2017-08-03 01:15:00+03	56000.00
B759EA	2017-08-10 20:18:00+03	12000.00
B759FF	2017-07-18 17:26:00+03	27200.00
B75A26	2017-07-28 23:48:00+03	38400.00
B75A7D	2017-07-02 06:47:00+03	26000.00
B75AEA	2017-07-05 10:00:00+03	110300.00
B75B07	2017-07-19 04:02:00+03	26800.00
B75B5C	2017-08-06 16:29:00+03	40000.00
B75B6B	2017-07-21 15:19:00+03	50600.00
B75B71	2017-08-01 19:42:00+03	321100.00
B75BF9	2017-07-12 09:31:00+03	269500.00
B75CFA	2017-07-31 16:07:00+03	187900.00
B75D1B	2017-06-27 01:27:00+03	68700.00
B75D1C	2017-07-21 16:17:00+03	29600.00
B75D23	2017-08-09 07:45:00+03	92100.00
B75E4E	2017-07-20 08:34:00+03	86300.00
B75E55	2017-07-13 11:31:00+03	213200.00
B75E6D	2017-08-13 19:14:00+03	119500.00
B75E78	2017-08-13 13:10:00+03	70800.00
B75E85	2017-07-09 12:10:00+03	67700.00
B75EA2	2017-08-10 03:47:00+03	70400.00
B75EB1	2017-07-14 20:56:00+03	43000.00
B75EDC	2017-08-13 09:28:00+03	40100.00
B75EF7	2017-08-08 11:37:00+03	161600.00
B75F1A	2017-07-20 12:10:00+03	28800.00
B75F74	2017-08-05 01:03:00+03	109000.00
B75F95	2017-07-11 10:12:00+03	31200.00
B75FD9	2017-08-14 04:37:00+03	193500.00
B760E9	2017-07-24 22:59:00+03	67100.00
B760EA	2017-08-07 15:27:00+03	344100.00
B7610B	2017-08-01 05:30:00+03	65500.00
B76112	2017-07-24 07:58:00+03	72400.00
B76182	2017-07-13 13:24:00+03	60400.00
B7618E	2017-07-16 01:33:00+03	88800.00
B76191	2017-07-07 21:31:00+03	31000.00
B761BA	2017-07-17 21:36:00+03	115900.00
B76254	2017-07-31 18:29:00+03	135200.00
B76276	2017-08-12 13:04:00+03	25200.00
B762AE	2017-07-22 02:28:00+03	52000.00
B762B3	2017-08-05 11:22:00+03	44000.00
B7633F	2017-07-30 11:49:00+03	72300.00
B76344	2017-07-23 19:29:00+03	68800.00
B76345	2017-07-10 00:12:00+03	8000.00
B7638F	2017-08-05 02:21:00+03	31600.00
B763FD	2017-07-19 09:53:00+03	47400.00
B76423	2017-08-10 23:11:00+03	38400.00
B764CE	2017-07-26 12:06:00+03	48800.00
B764D5	2017-08-05 00:27:00+03	46400.00
B764DC	2017-07-03 07:05:00+03	21400.00
B76546	2017-07-31 01:02:00+03	12600.00
B76586	2017-08-06 09:04:00+03	24400.00
B765F6	2017-07-25 08:55:00+03	112000.00
B76620	2017-07-09 15:31:00+03	73300.00
B76622	2017-08-05 05:14:00+03	218800.00
B76659	2017-07-11 18:25:00+03	132800.00
B7665A	2017-08-09 22:00:00+03	166000.00
B76672	2017-08-11 11:18:00+03	331000.00
B766CD	2017-07-25 14:19:00+03	73300.00
B766E8	2017-08-05 11:30:00+03	12600.00
B766FA	2017-07-24 01:51:00+03	306200.00
B7672B	2017-07-05 04:05:00+03	6000.00
B76737	2017-07-31 15:47:00+03	70200.00
B76740	2017-08-12 07:30:00+03	92400.00
B76744	2017-07-20 22:04:00+03	31900.00
B76809	2017-07-22 22:05:00+03	75600.00
B76826	2017-08-04 15:05:00+03	46400.00
B76853	2017-08-06 15:32:00+03	46000.00
B769AC	2017-08-04 22:51:00+03	39100.00
B76A37	2017-08-09 05:22:00+03	148200.00
B76A64	2017-07-10 13:51:00+03	126900.00
B76A65	2017-07-29 00:33:00+03	28000.00
B76A93	2017-08-14 08:41:00+03	67600.00
B76AAF	2017-07-23 15:41:00+03	12600.00
B76AC4	2017-07-08 12:22:00+03	21200.00
B76ACD	2017-08-12 02:37:00+03	36100.00
B76AE2	2017-08-06 16:02:00+03	24000.00
B76B03	2017-07-06 12:05:00+03	67200.00
B76B45	2017-07-12 00:09:00+03	23200.00
B76B46	2017-07-06 15:20:00+03	12600.00
B76B6F	2017-07-21 13:26:00+03	27200.00
B76B74	2017-07-05 06:00:00+03	26000.00
B76BA4	2017-08-05 00:43:00+03	103800.00
B76BCF	2017-07-20 18:28:00+03	26000.00
B76C2C	2017-07-20 15:40:00+03	131100.00
B76C30	2017-07-06 10:10:00+03	33100.00
B76C4F	2017-07-29 14:55:00+03	43300.00
B76C65	2017-07-12 12:06:00+03	28600.00
B76D81	2017-08-11 08:00:00+03	28000.00
B76DA4	2017-08-13 18:33:00+03	29500.00
B76DD5	2017-07-29 21:37:00+03	10800.00
B76DF0	2017-08-12 13:14:00+03	47000.00
B76E12	2017-08-13 11:07:00+03	56600.00
B76E1C	2017-07-25 12:30:00+03	86800.00
B76F57	2017-07-17 11:31:00+03	83100.00
B76F6C	2017-07-25 14:43:00+03	30200.00
B76FB7	2017-08-02 18:13:00+03	99600.00
B77021	2017-07-23 07:48:00+03	43500.00
B77087	2017-08-15 08:27:00+03	41800.00
B770A7	2017-08-02 06:15:00+03	57800.00
B7714B	2017-07-12 13:16:00+03	58200.00
B77155	2017-07-26 02:04:00+03	59200.00
B771FA	2017-07-06 14:53:00+03	56900.00
B77202	2017-07-12 14:01:00+03	65500.00
B772CB	2017-07-28 06:18:00+03	23400.00
B772E4	2017-07-19 06:30:00+03	51600.00
B7733A	2017-08-03 23:05:00+03	143100.00
B7734F	2017-07-30 04:49:00+03	40800.00
B77393	2017-07-22 14:37:00+03	28000.00
B773AE	2017-08-14 18:04:00+03	51900.00
B773DB	2017-07-29 17:06:00+03	265400.00
B7741D	2017-07-28 19:02:00+03	65100.00
B77428	2017-07-28 22:56:00+03	188900.00
B7743D	2017-06-27 02:31:00+03	49000.00
B77493	2017-08-01 10:19:00+03	209200.00
B7749E	2017-07-27 22:18:00+03	33600.00
B774B2	2017-08-03 21:34:00+03	87000.00
B7752D	2017-08-02 01:46:00+03	43200.00
B77539	2017-08-10 08:34:00+03	91600.00
B77592	2017-07-11 21:47:00+03	32800.00
B775F7	2017-08-02 13:47:00+03	12400.00
B77630	2017-07-10 13:37:00+03	27800.00
B77633	2017-07-02 03:45:00+03	93900.00
B77648	2017-07-02 03:46:00+03	70800.00
B7773B	2017-08-14 21:05:00+03	44000.00
B77798	2017-08-12 09:49:00+03	69500.00
B7779C	2017-07-28 23:14:00+03	54800.00
B777C2	2017-07-02 09:24:00+03	38600.00
B77801	2017-07-15 23:08:00+03	47200.00
B77802	2017-06-28 11:53:00+03	9800.00
B7789B	2017-07-27 21:18:00+03	27300.00
B778EA	2017-07-26 20:04:00+03	82200.00
B77907	2017-07-30 09:19:00+03	45400.00
B7790D	2017-07-08 17:04:00+03	13600.00
B77950	2017-07-13 09:22:00+03	6700.00
B7795A	2017-07-11 08:17:00+03	48800.00
B7798C	2017-07-06 19:39:00+03	236000.00
B779AE	2017-07-12 20:17:00+03	480200.00
B779E5	2017-07-03 22:28:00+03	159500.00
B779F2	2017-07-14 20:18:00+03	24200.00
B77A14	2017-08-12 21:28:00+03	62000.00
B77A45	2017-07-26 09:43:00+03	27200.00
B77A5F	2017-07-19 20:16:00+03	40800.00
B77A6E	2017-07-16 11:51:00+03	190400.00
B77A82	2017-07-14 06:40:00+03	75600.00
B77A87	2017-07-22 20:31:00+03	117700.00
B77AEE	2017-07-13 14:36:00+03	25400.00
B77B02	2017-07-22 04:19:00+03	65500.00
B77BB9	2017-08-12 18:00:00+03	393800.00
B77BDA	2017-08-14 16:45:00+03	28000.00
B77C51	2017-07-15 14:55:00+03	26000.00
B77CB8	2017-07-18 13:40:00+03	48800.00
B77CCC	2017-08-06 19:58:00+03	67000.00
B77CE0	2017-08-06 22:59:00+03	36800.00
B77D24	2017-07-12 20:29:00+03	111600.00
B77D60	2017-07-13 20:14:00+03	26000.00
B77D87	2017-07-04 07:40:00+03	31700.00
B77D8D	2017-07-17 00:12:00+03	62000.00
B77D9E	2017-07-25 17:43:00+03	45200.00
B77E37	2017-07-14 07:03:00+03	77200.00
B77E38	2017-07-06 05:20:00+03	55800.00
B77E5C	2017-08-11 12:57:00+03	48800.00
B77EBC	2017-07-07 19:54:00+03	6000.00
B77EDA	2017-07-27 08:04:00+03	55800.00
B77F58	2017-07-18 18:51:00+03	23200.00
B77F7B	2017-07-05 14:21:00+03	21800.00
B77FB0	2017-07-01 22:17:00+03	390400.00
B77FB2	2017-07-16 10:48:00+03	29800.00
B78024	2017-08-07 14:45:00+03	169900.00
B780D8	2017-07-31 15:04:00+03	32800.00
B7812D	2017-08-03 18:09:00+03	34000.00
B7815B	2017-08-09 21:15:00+03	25800.00
B78179	2017-07-31 22:46:00+03	56600.00
B7817C	2017-07-20 11:43:00+03	16400.00
B781B8	2017-07-06 06:42:00+03	19600.00
B781E6	2017-07-05 21:33:00+03	394400.00
B7821B	2017-07-30 07:20:00+03	36200.00
B78257	2017-06-30 13:22:00+03	88900.00
B78286	2017-07-10 19:58:00+03	159100.00
B7829B	2017-07-03 12:50:00+03	92800.00
B782AC	2017-08-08 14:05:00+03	112000.00
B78318	2017-08-13 01:35:00+03	23200.00
B78383	2017-07-31 23:30:00+03	57800.00
B7839C	2017-08-12 15:17:00+03	53500.00
B7839E	2017-08-15 01:20:00+03	31600.00
B783D9	2017-07-04 16:11:00+03	214100.00
B783F2	2017-07-27 07:44:00+03	35300.00
B7841C	2017-07-20 15:12:00+03	111600.00
B784EF	2017-08-02 22:05:00+03	70400.00
B7856D	2017-08-03 06:26:00+03	187600.00
B78591	2017-07-24 15:40:00+03	51300.00
B785F6	2017-08-10 20:17:00+03	100200.00
B7862C	2017-06-24 04:33:00+03	31400.00
B78640	2017-08-03 04:32:00+03	73600.00
B78656	2017-07-06 00:51:00+03	58800.00
B7865F	2017-07-24 09:35:00+03	40100.00
B78681	2017-08-15 04:08:00+03	132800.00
B786D8	2017-07-18 02:20:00+03	6700.00
B786DA	2017-08-15 15:51:00+03	63800.00
B786ED	2017-08-10 02:15:00+03	51800.00
B78738	2017-07-05 14:57:00+03	369000.00
B7880D	2017-07-03 18:07:00+03	66000.00
B7881B	2017-08-01 09:17:00+03	131600.00
B7881C	2017-08-04 01:08:00+03	44500.00
B78820	2017-08-14 11:31:00+03	182300.00
B78879	2017-08-08 21:13:00+03	11600.00
B788D0	2017-07-25 19:22:00+03	56800.00
B788E6	2017-08-13 03:06:00+03	12600.00
B7890D	2017-08-06 14:24:00+03	93900.00
B78938	2017-07-11 14:08:00+03	56100.00
B78966	2017-08-10 15:12:00+03	34000.00
B78973	2017-07-26 00:57:00+03	13000.00
B789DB	2017-08-13 18:02:00+03	36800.00
B78A40	2017-08-13 21:05:00+03	56000.00
B78A58	2017-08-06 06:24:00+03	92800.00
B78A76	2017-08-09 19:29:00+03	13600.00
B78AD6	2017-07-24 03:40:00+03	10800.00
B78B0F	2017-08-12 02:02:00+03	56600.00
B78B15	2017-08-02 19:48:00+03	99700.00
B78B63	2017-07-12 12:28:00+03	85700.00
B78B91	2017-07-08 17:59:00+03	94200.00
B78C00	2017-07-16 10:40:00+03	42400.00
B78C57	2017-08-15 15:22:00+03	146400.00
B78C59	2017-07-13 22:22:00+03	88800.00
B78CA6	2017-08-02 20:36:00+03	76200.00
B78CE8	2017-07-18 00:08:00+03	58000.00
B78CF3	2017-07-12 06:22:00+03	57500.00
B78CFF	2017-07-19 07:49:00+03	25100.00
B78D1D	2017-07-03 09:57:00+03	112200.00
B78D41	2017-07-10 14:31:00+03	85000.00
B78D4E	2017-06-28 21:14:00+03	115600.00
B78D5C	2017-07-28 10:37:00+03	95200.00
B78D6B	2017-07-04 18:12:00+03	44000.00
B78DA6	2017-07-22 04:01:00+03	28800.00
B78E19	2017-08-04 09:29:00+03	38600.00
B78E1A	2017-07-07 10:06:00+03	99200.00
B78E2A	2017-08-11 05:03:00+03	20200.00
B78E52	2017-08-14 00:17:00+03	101800.00
B78E94	2017-08-03 20:31:00+03	6000.00
B78EBB	2017-07-17 02:43:00+03	21400.00
B78EF5	2017-08-10 09:19:00+03	40400.00
B78F19	2017-08-04 04:55:00+03	89200.00
B78FAF	2017-06-29 18:55:00+03	43200.00
B78FEB	2017-08-04 14:16:00+03	133900.00
B79020	2017-07-23 02:41:00+03	136500.00
B79070	2017-07-25 11:27:00+03	8000.00
B79072	2017-07-26 04:19:00+03	16800.00
B79123	2017-07-03 12:54:00+03	19600.00
B79151	2017-08-04 08:22:00+03	95600.00
B79187	2017-07-01 20:39:00+03	11000.00
B79196	2017-07-30 13:17:00+03	87100.00
B791E1	2017-07-23 09:25:00+03	22000.00
B791EF	2017-08-11 21:27:00+03	57500.00
B79271	2017-08-08 12:49:00+03	46900.00
B792CE	2017-08-05 10:08:00+03	56000.00
B792FA	2017-07-22 21:12:00+03	189200.00
B7931E	2017-07-22 10:52:00+03	37800.00
B79322	2017-07-21 06:36:00+03	58600.00
B79382	2017-08-13 21:42:00+03	132500.00
B793E6	2017-07-22 17:00:00+03	186900.00
B793ED	2017-07-04 04:09:00+03	61800.00
B79410	2017-07-14 00:31:00+03	56000.00
B79412	2017-07-11 08:01:00+03	24400.00
B79427	2017-07-26 08:13:00+03	39800.00
B7945B	2017-07-29 13:08:00+03	41600.00
B79465	2017-07-26 22:14:00+03	170000.00
B794E4	2017-07-30 16:13:00+03	136500.00
B79543	2017-07-13 14:43:00+03	49800.00
B79591	2017-08-08 13:20:00+03	94300.00
B79634	2017-08-14 11:31:00+03	32400.00
B79652	2017-08-01 03:33:00+03	47400.00
B79784	2017-07-07 21:55:00+03	20800.00
B797A4	2017-08-03 14:10:00+03	65500.00
B797AC	2017-07-23 11:40:00+03	22400.00
B797B1	2017-07-10 23:13:00+03	88300.00
B797C0	2017-07-15 14:56:00+03	135100.00
B797CA	2017-07-15 08:14:00+03	94000.00
B797DC	2017-08-05 14:26:00+03	80000.00
B79822	2017-07-04 07:37:00+03	32800.00
B79832	2017-07-20 20:25:00+03	410200.00
B7983B	2017-07-27 20:00:00+03	44800.00
B7986E	2017-07-24 11:41:00+03	81700.00
B798A6	2017-08-06 08:27:00+03	141200.00
B798B7	2017-07-11 12:48:00+03	135400.00
B798CA	2017-07-20 00:02:00+03	64800.00
B79923	2017-08-02 09:47:00+03	199700.00
B79925	2017-08-05 01:08:00+03	55800.00
B7993E	2017-07-29 04:52:00+03	36200.00
B79947	2017-07-21 06:49:00+03	90400.00
B7995F	2017-07-12 07:09:00+03	92400.00
B79981	2017-08-02 04:24:00+03	49200.00
B799A3	2017-07-11 20:48:00+03	75300.00
B799DA	2017-07-04 23:53:00+03	35200.00
B799E2	2017-08-04 15:43:00+03	46400.00
B79A24	2017-07-25 05:43:00+03	61500.00
B79A71	2017-08-14 19:57:00+03	136200.00
B79B3B	2017-07-13 22:01:00+03	47200.00
B79B5C	2017-07-12 09:50:00+03	114800.00
B79B5F	2017-07-03 09:12:00+03	59000.00
B79BE1	2017-08-12 16:42:00+03	105000.00
B79BF0	2017-08-01 07:19:00+03	62100.00
B79C08	2017-08-04 16:31:00+03	128800.00
B79C31	2017-07-28 21:02:00+03	173500.00
B79C3B	2017-07-07 01:46:00+03	113800.00
B79C5F	2017-07-20 21:54:00+03	29400.00
B79CA9	2017-08-13 23:58:00+03	162100.00
B79CE6	2017-07-26 16:23:00+03	67200.00
B79D01	2017-07-22 14:05:00+03	79700.00
B79D07	2017-08-05 11:34:00+03	14800.00
B79D2A	2017-07-30 21:51:00+03	496000.00
B79D95	2017-08-07 05:21:00+03	178800.00
B79DBB	2017-07-27 15:29:00+03	46700.00
B79DD2	2017-07-27 10:43:00+03	48800.00
B79DE8	2017-08-11 15:51:00+03	172200.00
B79E25	2017-07-29 07:16:00+03	16800.00
B79E79	2017-07-16 18:50:00+03	20600.00
B79E7C	2017-07-23 09:04:00+03	15100.00
B79E7E	2017-07-13 08:45:00+03	31600.00
B79F7B	2017-06-27 09:03:00+03	27400.00
B79F81	2017-07-24 07:12:00+03	26000.00
B79FA9	2017-08-13 23:59:00+03	118900.00
B79FE3	2017-08-07 12:01:00+03	55100.00
B7A00C	2017-07-11 15:36:00+03	23200.00
B7A01B	2017-07-09 19:58:00+03	62600.00
B7A037	2017-08-02 19:45:00+03	79600.00
B7A03B	2017-07-19 11:43:00+03	14800.00
B7A047	2017-07-06 23:45:00+03	176800.00
B7A059	2017-07-12 06:21:00+03	28800.00
B7A079	2017-07-01 23:02:00+03	21400.00
B7A097	2017-07-23 19:02:00+03	65300.00
B7A0E8	2017-07-25 03:12:00+03	6800.00
B7A103	2017-07-13 20:30:00+03	28000.00
B7A17E	2017-07-31 06:55:00+03	67700.00
B7A1B5	2017-07-13 23:17:00+03	25600.00
B7A1E2	2017-08-06 20:25:00+03	36600.00
B7A224	2017-07-13 07:14:00+03	67600.00
B7A23A	2017-08-12 12:08:00+03	67600.00
B7A261	2017-07-01 17:31:00+03	56000.00
B7A2B8	2017-07-23 01:22:00+03	23200.00
B7A2F1	2017-07-06 09:00:00+03	10600.00
B7A306	2017-07-22 01:26:00+03	56100.00
B7A318	2017-07-31 03:32:00+03	125200.00
B7A329	2017-08-14 13:25:00+03	156000.00
B7A366	2017-07-31 19:04:00+03	50100.00
B7A3B3	2017-08-10 16:22:00+03	13400.00
B7A41E	2017-08-14 19:13:00+03	12000.00
B7A511	2017-07-09 05:20:00+03	117600.00
B7A571	2017-07-05 08:00:00+03	23200.00
B7A596	2017-07-22 20:17:00+03	20400.00
B7A5C9	2017-07-31 18:05:00+03	49300.00
B7A5CF	2017-07-29 01:50:00+03	66000.00
B7A600	2017-07-09 16:24:00+03	46400.00
B7A638	2017-07-05 18:16:00+03	20500.00
B7A63A	2017-07-11 16:41:00+03	94200.00
B7A648	2017-08-08 15:26:00+03	153200.00
B7A650	2017-08-03 11:14:00+03	295600.00
B7A67D	2017-07-31 06:01:00+03	139300.00
B7A699	2017-07-28 22:56:00+03	73500.00
B7A74A	2017-07-25 05:25:00+03	16800.00
B7A7A0	2017-07-18 09:17:00+03	27200.00
B7A86B	2017-07-07 04:25:00+03	66000.00
B7A878	2017-07-12 02:01:00+03	148200.00
B7A879	2017-08-10 17:33:00+03	258400.00
B7A8B8	2017-07-31 05:35:00+03	112600.00
B7A90B	2017-08-07 07:28:00+03	147100.00
B7A911	2017-07-16 13:42:00+03	43600.00
B7A95B	2017-07-23 10:37:00+03	90000.00
B7A992	2017-07-22 04:32:00+03	55800.00
B7A999	2017-07-14 09:59:00+03	131100.00
B7A9B5	2017-07-25 16:58:00+03	6800.00
B7A9B6	2017-07-24 01:02:00+03	10800.00
B7AA21	2017-08-13 16:56:00+03	28800.00
B7AA3D	2017-07-06 19:56:00+03	68200.00
B7AA40	2017-07-17 05:07:00+03	27000.00
B7AA5E	2017-07-22 15:47:00+03	70600.00
B7AA76	2017-08-12 11:42:00+03	81000.00
B7AAC5	2017-07-16 07:46:00+03	24800.00
B7AB12	2017-07-11 23:25:00+03	70800.00
B7AB44	2017-07-06 05:29:00+03	6000.00
B7AB7E	2017-07-05 15:30:00+03	29600.00
B7AB98	2017-08-15 06:46:00+03	44700.00
B7AC00	2017-08-09 17:52:00+03	38200.00
B7AC50	2017-08-15 16:42:00+03	96400.00
B7AC6C	2017-07-26 06:39:00+03	56000.00
B7AC7C	2017-08-02 13:39:00+03	46700.00
B7ACB6	2017-07-26 10:41:00+03	73600.00
B7ACDB	2017-07-09 18:03:00+03	25200.00
B7ACDC	2017-07-23 06:06:00+03	72800.00
B7AD42	2017-08-13 12:49:00+03	108600.00
B7AD52	2017-08-06 06:23:00+03	89700.00
B7AD77	2017-07-01 04:32:00+03	127800.00
B7AD9D	2017-07-31 12:10:00+03	55400.00
B7ADD7	2017-07-18 09:33:00+03	91600.00
B7AE14	2017-08-08 11:56:00+03	78300.00
B7AE7A	2017-07-28 02:06:00+03	39300.00
B7AE95	2017-06-30 17:05:00+03	33600.00
B7AEFD	2017-07-06 10:16:00+03	57800.00
B7AF2D	2017-08-01 07:18:00+03	115300.00
B7AF68	2017-07-15 23:12:00+03	138000.00
B7AF77	2017-08-08 22:27:00+03	49400.00
B7AFBF	2017-08-13 17:37:00+03	56600.00
B7AFD4	2017-07-06 06:54:00+03	55800.00
B7B005	2017-07-26 14:14:00+03	38400.00
B7B012	2017-08-06 13:12:00+03	13700.00
B7B069	2017-07-20 16:06:00+03	270000.00
B7B0AA	2017-07-22 05:10:00+03	55800.00
B7B0BE	2017-07-26 14:54:00+03	84000.00
B7B0C6	2017-07-19 19:37:00+03	235700.00
B7B0F5	2017-07-03 08:36:00+03	64700.00
B7B0F7	2017-07-27 17:48:00+03	37200.00
B7B139	2017-08-04 16:51:00+03	166900.00
B7B13F	2017-08-12 01:33:00+03	67600.00
B7B140	2017-08-09 05:59:00+03	14400.00
B7B146	2017-08-09 12:13:00+03	56100.00
B7B156	2017-08-01 18:58:00+03	47400.00
B7B17F	2017-07-27 19:39:00+03	15400.00
B7B1C8	2017-08-05 17:56:00+03	7200.00
B7B1FD	2017-07-17 05:08:00+03	19600.00
B7B215	2017-07-15 13:30:00+03	82900.00
B7B22F	2017-06-26 00:53:00+03	28000.00
B7B2F9	2017-07-07 04:42:00+03	28000.00
B7B36B	2017-06-29 06:02:00+03	61500.00
B7B380	2017-07-12 11:39:00+03	33200.00
B7B3DE	2017-07-17 14:43:00+03	92800.00
B7B3EB	2017-08-10 03:33:00+03	106900.00
B7B3F0	2017-07-20 08:33:00+03	279600.00
B7B47D	2017-08-10 02:48:00+03	53500.00
B7B48A	2017-08-01 21:42:00+03	83000.00
B7B4B0	2017-08-07 04:22:00+03	207600.00
B7B4E1	2017-07-11 15:42:00+03	40000.00
B7B551	2017-07-22 15:10:00+03	12000.00
B7B58C	2017-07-31 14:14:00+03	123700.00
B7B663	2017-07-23 08:09:00+03	29000.00
B7B678	2017-07-08 12:24:00+03	61800.00
B7B681	2017-07-15 08:55:00+03	46000.00
B7B6C1	2017-07-29 05:04:00+03	61800.00
B7B6C4	2017-07-29 13:54:00+03	206700.00
B7B6DB	2017-08-07 17:27:00+03	132800.00
B7B727	2017-07-22 06:33:00+03	38600.00
B7B7BB	2017-08-04 23:40:00+03	18900.00
B7B7C0	2017-08-13 23:35:00+03	228700.00
B7B7C2	2017-08-04 03:06:00+03	56200.00
B7B7D7	2017-08-10 05:08:00+03	229300.00
B7B7EF	2017-07-28 05:20:00+03	18400.00
B7B81E	2017-07-22 03:42:00+03	135200.00
B7B85B	2017-07-08 18:50:00+03	114400.00
B7B85C	2017-07-06 20:23:00+03	258400.00
B7B884	2017-08-15 06:20:00+03	90400.00
B7B8E1	2017-08-13 14:58:00+03	105000.00
B7B92D	2017-07-03 18:03:00+03	25600.00
B7B97B	2017-07-04 17:40:00+03	36200.00
B7B994	2017-07-13 16:43:00+03	210000.00
B7B99C	2017-07-17 03:50:00+03	29600.00
B7B9A2	2017-08-06 17:59:00+03	19600.00
B7B9BB	2017-08-02 21:46:00+03	73500.00
B7B9E2	2017-07-18 00:05:00+03	20400.00
B7BA4E	2017-07-21 20:28:00+03	28000.00
B7BBAE	2017-07-25 04:19:00+03	135400.00
B7BBB8	2017-08-14 17:46:00+03	34000.00
B7BBBF	2017-07-15 10:52:00+03	47200.00
B7BBEC	2017-07-17 02:11:00+03	46300.00
B7BC16	2017-07-08 07:47:00+03	266400.00
B7BC17	2017-08-01 20:44:00+03	29600.00
B7BCCA	2017-08-13 11:45:00+03	56600.00
B7BCF0	2017-07-14 19:48:00+03	8200.00
B7BD28	2017-08-01 10:57:00+03	55600.00
B7BD97	2017-08-06 23:02:00+03	4000.00
B7BDD7	2017-07-24 05:11:00+03	176500.00
B7BDE0	2017-07-12 20:13:00+03	7300.00
B7BE66	2017-08-08 19:48:00+03	109400.00
B7BE69	2017-07-31 18:45:00+03	75300.00
B7BEF4	2017-07-23 17:25:00+03	37200.00
B7BF0B	2017-07-09 21:53:00+03	369000.00
B7BF5E	2017-07-12 02:26:00+03	56600.00
B7BF82	2017-07-31 03:01:00+03	65900.00
B7BFAE	2017-08-09 10:08:00+03	73200.00
B7BFBE	2017-08-12 11:18:00+03	51900.00
B7BFD5	2017-08-11 13:49:00+03	36200.00
B7BFEE	2017-07-18 10:16:00+03	300700.00
B7C01E	2017-07-12 05:56:00+03	101200.00
B7C02F	2017-07-01 19:34:00+03	133200.00
B7C03A	2017-07-23 06:49:00+03	139300.00
B7C060	2017-07-03 15:41:00+03	160200.00
B7C0D1	2017-08-06 00:00:00+03	73500.00
B7C0DC	2017-07-03 01:00:00+03	28800.00
B7C139	2017-07-06 04:50:00+03	17200.00
B7C173	2017-07-15 15:00:00+03	37700.00
B7C198	2017-07-31 15:28:00+03	23600.00
B7C234	2017-08-01 14:43:00+03	83600.00
B7C2B8	2017-08-15 14:19:00+03	137100.00
B7C2E1	2017-07-20 01:53:00+03	6700.00
B7C315	2017-07-08 12:11:00+03	31700.00
B7C37D	2017-07-05 14:55:00+03	211000.00
B7C37F	2017-08-06 18:18:00+03	155600.00
B7C38B	2017-07-19 00:39:00+03	36800.00
B7C3AD	2017-07-28 17:30:00+03	81600.00
B7C3FD	2017-08-13 15:36:00+03	55800.00
B7C406	2017-07-13 22:09:00+03	90000.00
B7C41F	2017-08-12 18:55:00+03	46300.00
B7C49A	2017-07-14 11:26:00+03	269200.00
B7C511	2017-08-07 17:47:00+03	178800.00
B7C523	2017-07-08 06:36:00+03	199700.00
B7C55D	2017-07-02 06:00:00+03	381400.00
B7C571	2017-07-28 00:53:00+03	14000.00
B7C5D0	2017-07-29 07:32:00+03	342100.00
B7C5DA	2017-08-09 22:10:00+03	122400.00
B7C5E6	2017-07-14 06:32:00+03	315900.00
B7C6C7	2017-07-21 16:53:00+03	33100.00
B7C6EE	2017-07-10 08:24:00+03	58800.00
B7C73C	2017-07-15 08:54:00+03	23600.00
B7C74A	2017-08-13 10:44:00+03	73600.00
B7C761	2017-08-05 23:24:00+03	62400.00
B7C772	2017-07-04 10:54:00+03	18600.00
B7C7F5	2017-07-10 23:02:00+03	136700.00
B7C808	2017-07-27 00:45:00+03	15000.00
B7C836	2017-08-02 04:27:00+03	24400.00
B7C868	2017-07-13 05:33:00+03	55800.00
B7C87C	2017-07-15 13:31:00+03	52900.00
B7C8F5	2017-06-30 12:55:00+03	167400.00
B7C9C2	2017-07-02 10:23:00+03	52000.00
B7CA05	2017-08-10 04:09:00+03	70900.00
B7CA41	2017-07-12 10:52:00+03	52300.00
B7CAB0	2017-07-22 00:36:00+03	75300.00
B7CAC8	2017-08-13 13:25:00+03	101000.00
B7CAC9	2017-08-01 19:26:00+03	96300.00
B7CB3D	2017-06-29 17:34:00+03	144000.00
B7CB54	2017-08-04 14:49:00+03	129700.00
B7CB6D	2017-08-07 05:49:00+03	11900.00
B7CBB0	2017-07-16 18:19:00+03	258400.00
B7CBF7	2017-07-04 19:29:00+03	113600.00
B7CC44	2017-08-01 14:17:00+03	52000.00
B7CC56	2017-07-13 01:38:00+03	98400.00
B7CC59	2017-07-24 20:30:00+03	58000.00
B7CC79	2017-07-12 13:36:00+03	66600.00
B7CCE0	2017-07-10 05:11:00+03	40800.00
B7CD13	2017-07-08 16:23:00+03	4400.00
B7CD8E	2017-07-31 14:41:00+03	52000.00
B7CD95	2017-07-28 18:34:00+03	18300.00
B7CDC3	2017-07-24 21:39:00+03	95200.00
B7CE02	2017-08-10 08:02:00+03	44600.00
B7CE20	2017-08-09 14:22:00+03	46400.00
B7CE3A	2017-07-20 10:23:00+03	79200.00
B7CE3C	2017-07-16 12:43:00+03	113500.00
B7CE59	2017-07-14 10:35:00+03	51300.00
B7CE5A	2017-07-04 03:01:00+03	34000.00
B7CE80	2017-08-10 06:17:00+03	113700.00
B7CEF6	2017-07-09 03:05:00+03	12600.00
B7CFEC	2017-07-21 12:54:00+03	44000.00
B7D071	2017-07-07 20:21:00+03	83000.00
B7D089	2017-07-23 23:13:00+03	275500.00
B7D0C4	2017-08-12 22:16:00+03	62900.00
B7D134	2017-07-07 22:35:00+03	172400.00
B7D144	2017-07-19 17:25:00+03	84000.00
B7D147	2017-08-04 17:42:00+03	23200.00
B7D19F	2017-07-18 13:53:00+03	234100.00
B7D1D4	2017-07-30 16:40:00+03	97700.00
B7D1EC	2017-07-18 02:49:00+03	132800.00
B7D232	2017-08-15 14:42:00+03	12000.00
B7D379	2017-08-12 02:58:00+03	19600.00
B7D399	2017-07-25 13:49:00+03	68000.00
B7D3A0	2017-07-10 04:22:00+03	40800.00
B7D3CC	2017-08-14 21:42:00+03	36800.00
B7D3D3	2017-08-14 18:12:00+03	59000.00
B7D46B	2017-08-13 15:19:00+03	92000.00
B7D4B1	2017-07-25 13:40:00+03	22000.00
B7D51A	2017-07-21 11:13:00+03	85400.00
B7D540	2017-08-04 22:52:00+03	23200.00
B7D55A	2017-08-13 03:38:00+03	54100.00
B7D577	2017-07-02 12:08:00+03	52000.00
B7D583	2017-08-10 12:04:00+03	90400.00
B7D5D8	2017-07-14 10:09:00+03	62800.00
B7D5DC	2017-07-23 23:57:00+03	55600.00
B7D5ED	2017-07-30 17:11:00+03	12600.00
B7D627	2017-07-18 15:25:00+03	223300.00
B7D644	2017-07-17 06:56:00+03	297300.00
B7D651	2017-08-13 11:06:00+03	68800.00
B7D67D	2017-07-23 08:51:00+03	248400.00
B7D698	2017-08-02 05:27:00+03	111600.00
B7D6A4	2017-07-15 12:55:00+03	47200.00
B7D6A7	2017-08-05 16:47:00+03	141600.00
B7D6DD	2017-07-07 06:06:00+03	136600.00
B7D6E0	2017-08-06 15:56:00+03	25800.00
B7D6E1	2017-08-12 00:00:00+03	111600.00
B7D708	2017-07-14 10:25:00+03	6000.00
B7D723	2017-07-02 11:07:00+03	92800.00
B7D7B4	2017-07-11 12:14:00+03	284300.00
B7D815	2017-07-09 03:53:00+03	89100.00
B7D818	2017-07-10 08:09:00+03	54800.00
B7D822	2017-08-02 19:49:00+03	63400.00
B7D83C	2017-08-12 10:30:00+03	57400.00
B7D85C	2017-08-01 13:32:00+03	20200.00
B7D8E7	2017-07-05 18:14:00+03	30200.00
B7D90F	2017-07-31 16:02:00+03	129700.00
B7D94B	2017-06-30 22:28:00+03	21400.00
B7D95A	2017-07-07 10:09:00+03	6000.00
B7D972	2017-08-06 05:35:00+03	92000.00
B7DA07	2017-07-08 03:09:00+03	58600.00
B7DA13	2017-08-03 14:09:00+03	155000.00
B7DA68	2017-07-12 09:06:00+03	61800.00
B7DA7A	2017-08-03 01:46:00+03	38400.00
B7DA9A	2017-06-29 14:21:00+03	29100.00
B7DAE4	2017-07-13 09:50:00+03	26000.00
B7DB1D	2017-08-15 03:57:00+03	26800.00
B7DB9C	2017-08-15 07:46:00+03	19600.00
B7DBFF	2017-07-09 12:03:00+03	46400.00
B7DC41	2017-07-26 16:02:00+03	21800.00
B7DC93	2017-08-12 20:07:00+03	39200.00
B7DCB5	2017-07-11 12:49:00+03	62600.00
B7DCB7	2017-06-30 20:40:00+03	103700.00
B7DCD2	2017-08-08 13:59:00+03	133100.00
B7DD18	2017-08-07 15:29:00+03	19800.00
B7DD29	2017-07-09 16:48:00+03	8200.00
B7DD84	2017-07-18 19:06:00+03	10700.00
B7DD8C	2017-07-25 04:44:00+03	100200.00
B7DE26	2017-07-09 19:17:00+03	22000.00
B7DE59	2017-07-05 07:09:00+03	57500.00
B7DE5F	2017-08-08 12:09:00+03	239400.00
B7DF38	2017-07-25 08:55:00+03	6900.00
B7DFD6	2017-07-20 23:13:00+03	34000.00
B7DFDF	2017-07-04 17:55:00+03	108700.00
B7E060	2017-07-27 05:45:00+03	62200.00
B7E078	2017-07-31 23:17:00+03	45200.00
B7E088	2017-07-17 17:58:00+03	58200.00
B7E0DA	2017-07-25 19:09:00+03	16400.00
B7E0E4	2017-07-07 18:31:00+03	16800.00
B7E126	2017-07-28 00:00:00+03	56600.00
B7E164	2017-07-21 22:56:00+03	28000.00
B7E167	2017-07-20 18:54:00+03	20400.00
B7E186	2017-07-16 12:15:00+03	39600.00
B7E1B5	2017-07-21 04:28:00+03	93900.00
B7E1DC	2017-07-02 14:26:00+03	29600.00
B7E294	2017-07-26 02:52:00+03	42900.00
B7E2A1	2017-08-03 01:46:00+03	114800.00
B7E2A7	2017-08-01 07:40:00+03	15800.00
B7E39C	2017-08-07 23:45:00+03	13400.00
B7E423	2017-08-07 07:24:00+03	27200.00
B7E468	2017-07-26 14:15:00+03	23200.00
B7E4F0	2017-07-28 06:12:00+03	93800.00
B7E51A	2017-07-27 17:01:00+03	27200.00
B7E5FF	2017-07-22 05:43:00+03	88900.00
B7E61E	2017-07-22 23:05:00+03	32800.00
B7E7AA	2017-07-13 09:43:00+03	16400.00
B7E88F	2017-07-02 11:04:00+03	68000.00
B7E896	2017-08-03 15:32:00+03	20600.00
B7E89D	2017-07-29 23:07:00+03	22400.00
B7E8A0	2017-07-07 10:59:00+03	58000.00
B7E905	2017-07-21 16:15:00+03	89700.00
B7E906	2017-07-18 23:01:00+03	51600.00
B7E90E	2017-07-05 15:37:00+03	26200.00
B7E976	2017-08-10 16:31:00+03	63200.00
B7E980	2017-08-13 04:23:00+03	66000.00
B7EA03	2017-07-26 15:13:00+03	65900.00
B7EA0F	2017-07-16 06:21:00+03	54800.00
B7EA1E	2017-07-09 20:27:00+03	40000.00
B7EA29	2017-08-13 08:49:00+03	81300.00
B7EAAB	2017-07-30 04:04:00+03	46300.00
B7EB3B	2017-07-29 01:03:00+03	59700.00
B7EB54	2017-07-27 10:35:00+03	23100.00
B7EB73	2017-07-16 23:56:00+03	157200.00
B7EB90	2017-07-01 13:09:00+03	40800.00
B7EB9E	2017-07-14 11:19:00+03	266400.00
B7EBAD	2017-08-11 02:19:00+03	63100.00
B7EBE1	2017-07-19 22:18:00+03	27200.00
B7EBF5	2017-08-05 15:34:00+03	13200.00
B7EC06	2017-07-27 21:06:00+03	131100.00
B7EC3B	2017-07-21 06:32:00+03	29800.00
B7ED1B	2017-07-10 09:12:00+03	21400.00
B7ED4B	2017-07-15 06:26:00+03	61800.00
B7EDC6	2017-07-20 01:41:00+03	405200.00
B7EDEC	2017-07-24 09:32:00+03	85000.00
B7EE12	2017-08-15 15:58:00+03	39600.00
B7EE95	2017-08-10 14:21:00+03	100600.00
B7EE97	2017-07-31 21:46:00+03	28000.00
B7EEAA	2017-08-11 18:53:00+03	73600.00
B7EEBD	2017-07-05 22:40:00+03	134800.00
B7EECF	2017-08-11 06:19:00+03	147700.00
B7EF1C	2017-07-12 17:46:00+03	28800.00
B7EF55	2017-07-26 15:33:00+03	60000.00
B7EFB1	2017-07-12 13:04:00+03	342300.00
B7F033	2017-07-23 07:52:00+03	19600.00
B7F03A	2017-07-18 23:20:00+03	52400.00
B7F059	2017-07-17 10:43:00+03	9800.00
B7F095	2017-07-23 19:31:00+03	36200.00
B7F0AB	2017-07-29 21:00:00+03	95700.00
B7F0C2	2017-08-04 08:29:00+03	56000.00
B7F0E7	2017-07-23 04:55:00+03	93900.00
B7F173	2017-07-11 18:08:00+03	148200.00
B7F1C1	2017-07-30 11:33:00+03	6700.00
B7F1E8	2017-07-14 05:27:00+03	119700.00
B7F213	2017-07-17 08:02:00+03	117700.00
B7F233	2017-07-20 13:51:00+03	79700.00
B7F241	2017-07-05 20:25:00+03	85000.00
B7F271	2017-07-28 08:23:00+03	13600.00
B7F2DA	2017-07-21 20:59:00+03	101900.00
B7F2EB	2017-08-01 06:44:00+03	147500.00
B7F310	2017-07-29 03:07:00+03	21800.00
B7F350	2017-07-12 09:10:00+03	100600.00
B7F37B	2017-07-24 17:01:00+03	133200.00
B7F3B7	2017-07-10 10:50:00+03	59800.00
B7F3CC	2017-07-31 18:30:00+03	186900.00
B7F3E3	2017-06-29 13:30:00+03	37200.00
B7F423	2017-07-02 06:40:00+03	39400.00
B7F442	2017-07-05 03:39:00+03	123600.00
B7F443	2017-08-12 18:02:00+03	24500.00
B7F4BA	2017-06-29 08:52:00+03	24700.00
B7F4D6	2017-07-16 21:44:00+03	55800.00
B7F531	2017-07-03 04:43:00+03	37100.00
B7F57D	2017-07-09 20:20:00+03	103400.00
B7F583	2017-07-10 05:34:00+03	185000.00
B7F5F9	2017-07-06 05:29:00+03	205500.00
B7F626	2017-07-29 07:31:00+03	28000.00
B7F689	2017-08-02 19:18:00+03	30000.00
B7F6A7	2017-07-11 20:11:00+03	16400.00
B7F74E	2017-08-14 23:31:00+03	92600.00
B7F845	2017-07-25 15:00:00+03	136600.00
B7F888	2017-07-30 07:50:00+03	280700.00
B7F8DE	2017-07-02 11:47:00+03	27200.00
B7F8F4	2017-08-08 09:58:00+03	80700.00
B7F927	2017-07-13 22:14:00+03	90000.00
B7F959	2017-07-28 15:19:00+03	41600.00
B7F97B	2017-08-02 17:40:00+03	46400.00
B7FA1F	2017-08-10 05:52:00+03	21400.00
B7FA4C	2017-07-17 05:05:00+03	70000.00
B7FADF	2017-08-14 17:19:00+03	27900.00
B7FAE8	2017-08-05 23:32:00+03	73600.00
B7FAF1	2017-07-13 04:15:00+03	51900.00
B7FAF8	2017-07-10 15:13:00+03	40400.00
B7FB2C	2017-08-12 13:59:00+03	92500.00
B7FB3D	2017-08-13 21:33:00+03	46400.00
B7FB4F	2017-08-12 23:46:00+03	80800.00
B7FB52	2017-07-06 17:53:00+03	28000.00
B7FB9B	2017-07-21 20:33:00+03	43800.00
B7FBA2	2017-08-08 17:50:00+03	26000.00
B7FC15	2017-07-14 09:04:00+03	135400.00
B7FC25	2017-07-15 23:37:00+03	47400.00
B7FC98	2017-08-08 05:02:00+03	27400.00
B7FD0F	2017-08-12 13:11:00+03	172400.00
B7FD75	2017-07-27 20:01:00+03	133100.00
B7FD9E	2017-07-09 11:09:00+03	64800.00
B7FDC9	2017-08-15 16:35:00+03	35200.00
B7FDCB	2017-07-10 23:27:00+03	13400.00
B7FDE4	2017-08-12 01:30:00+03	201600.00
B7FE53	2017-07-18 15:17:00+03	98300.00
B7FE8C	2017-08-08 19:36:00+03	270800.00
B7FEAB	2017-07-13 16:00:00+03	190100.00
B7FED0	2017-08-14 12:04:00+03	29500.00
B7FF41	2017-07-23 10:46:00+03	89700.00
B80011	2017-08-11 15:10:00+03	69600.00
B80012	2017-07-26 20:20:00+03	158400.00
B80035	2017-07-03 05:52:00+03	52300.00
B8004E	2017-07-17 13:44:00+03	6300.00
B80123	2017-08-14 11:55:00+03	99200.00
B80182	2017-07-29 10:55:00+03	105600.00
B80191	2017-07-16 18:22:00+03	46700.00
B801EE	2017-07-07 06:07:00+03	73600.00
B80235	2017-08-13 19:20:00+03	92000.00
B80282	2017-07-15 07:17:00+03	34000.00
B80294	2017-07-11 17:35:00+03	96000.00
B802AE	2017-07-22 13:22:00+03	42800.00
B802CE	2017-07-07 01:59:00+03	381400.00
B8032C	2017-07-12 08:04:00+03	177000.00
B80330	2017-08-11 23:39:00+03	100600.00
B80375	2017-07-18 20:04:00+03	64800.00
B803FA	2017-07-29 18:01:00+03	38600.00
B80414	2017-07-03 22:50:00+03	28000.00
B8043C	2017-06-29 08:19:00+03	54800.00
B8046B	2017-08-09 16:43:00+03	170200.00
B8046F	2017-07-11 13:20:00+03	23200.00
B80480	2017-08-06 16:42:00+03	133200.00
B804A5	2017-07-01 13:26:00+03	393800.00
B804A7	2017-07-15 23:40:00+03	8400.00
B805D5	2017-08-15 04:16:00+03	25100.00
B805ED	2017-08-10 21:20:00+03	25100.00
B805FF	2017-07-11 22:13:00+03	50600.00
B806E2	2017-08-11 13:59:00+03	39400.00
B806E9	2017-08-02 07:12:00+03	150400.00
B80717	2017-06-29 15:26:00+03	55800.00
B8071C	2017-06-28 21:28:00+03	62700.00
B80723	2017-08-12 06:53:00+03	19600.00
B8076A	2017-07-23 19:37:00+03	57600.00
B80788	2017-08-06 18:54:00+03	25000.00
B8079B	2017-08-06 11:39:00+03	29800.00
B807A8	2017-07-12 01:02:00+03	249100.00
B807A9	2017-07-29 01:35:00+03	12000.00
B807D7	2017-07-18 11:02:00+03	52800.00
B807F6	2017-07-29 19:55:00+03	80100.00
B80849	2017-07-19 00:02:00+03	214900.00
B80870	2017-08-10 11:35:00+03	25900.00
B808EB	2017-07-07 21:02:00+03	65500.00
B808F6	2017-08-02 15:56:00+03	60600.00
B809A4	2017-07-20 11:35:00+03	64200.00
B80A14	2017-07-05 11:25:00+03	97500.00
B80A17	2017-07-19 14:59:00+03	51200.00
B80A5E	2017-08-02 06:28:00+03	59800.00
B80A8E	2017-07-17 06:01:00+03	38400.00
B80ADF	2017-08-12 00:56:00+03	26000.00
B80B3C	2017-07-27 02:24:00+03	97900.00
B80B6E	2017-08-05 12:17:00+03	57400.00
B80B91	2017-08-12 02:35:00+03	23900.00
B80C52	2017-07-17 04:01:00+03	25800.00
B80C54	2017-08-09 04:10:00+03	54500.00
B80CAF	2017-07-21 10:35:00+03	56300.00
B80CC2	2017-07-04 15:31:00+03	13600.00
B80CCF	2017-07-14 12:00:00+03	67600.00
B80D1B	2017-07-21 21:52:00+03	258400.00
B80D20	2017-08-12 18:20:00+03	124400.00
B80D62	2017-07-11 17:21:00+03	62600.00
B80DE2	2017-07-27 15:53:00+03	405000.00
B80DF1	2017-07-26 14:18:00+03	111000.00
B80E19	2017-08-03 05:59:00+03	54000.00
B80E77	2017-08-04 11:02:00+03	12600.00
B80E79	2017-08-14 04:20:00+03	44000.00
B80E98	2017-07-10 21:46:00+03	58400.00
B80EC0	2017-07-16 22:13:00+03	13400.00
B80F0F	2017-07-13 17:23:00+03	71900.00
B80F39	2017-07-17 20:26:00+03	38800.00
B80F6D	2017-07-15 17:41:00+03	119000.00
B80FE8	2017-08-06 14:16:00+03	39300.00
B80FFF	2017-07-23 09:41:00+03	31600.00
B81012	2017-07-09 17:16:00+03	13400.00
B81040	2017-07-04 23:06:00+03	65500.00
B81077	2017-08-05 04:41:00+03	6700.00
B810EF	2017-07-01 00:10:00+03	21400.00
B81116	2017-08-12 06:40:00+03	28000.00
B81127	2017-08-08 04:15:00+03	68800.00
B8115E	2017-08-13 18:16:00+03	21000.00
B8116F	2017-08-04 21:59:00+03	65500.00
B811C1	2017-08-02 14:28:00+03	94000.00
B81225	2017-07-07 19:57:00+03	6000.00
B812D1	2017-07-24 08:50:00+03	207200.00
B81316	2017-08-04 00:17:00+03	46400.00
B81339	2017-07-13 12:04:00+03	131600.00
B813E8	2017-08-10 20:32:00+03	68100.00
B8142A	2017-07-07 18:12:00+03	94000.00
B81451	2017-07-02 21:08:00+03	28000.00
B814BE	2017-08-03 20:04:00+03	170500.00
B814F9	2017-07-16 06:10:00+03	29600.00
B815D0	2017-08-03 03:22:00+03	60800.00
B815FF	2017-07-12 10:50:00+03	47100.00
B81605	2017-07-28 17:27:00+03	38400.00
B8162B	2017-07-23 06:54:00+03	6300.00
B81634	2017-07-10 07:10:00+03	60600.00
B81687	2017-06-30 22:02:00+03	103800.00
B816B4	2017-08-03 23:52:00+03	29000.00
B8171C	2017-06-29 17:19:00+03	25600.00
B81757	2017-07-28 21:23:00+03	202100.00
B8176F	2017-07-19 23:48:00+03	148200.00
B8178A	2017-07-17 09:00:00+03	28000.00
B817B3	2017-07-08 20:29:00+03	222100.00
B81800	2017-07-06 14:53:00+03	174400.00
B8183F	2017-08-01 19:41:00+03	65300.00
B81888	2017-07-04 23:58:00+03	14400.00
B81891	2017-07-05 01:33:00+03	34400.00
B818F8	2017-07-25 12:12:00+03	120500.00
B81906	2017-07-05 15:39:00+03	50300.00
B81968	2017-07-06 20:48:00+03	87600.00
B81981	2017-07-24 00:44:00+03	39400.00
B81A08	2017-07-18 08:24:00+03	28000.00
B81A76	2017-08-07 15:13:00+03	29400.00
B81AAE	2017-08-07 15:38:00+03	19800.00
B81B10	2017-07-25 13:21:00+03	14800.00
B81B6B	2017-07-18 00:05:00+03	40600.00
B81B6E	2017-08-13 12:29:00+03	29500.00
B81B75	2017-07-13 16:43:00+03	46200.00
B81C0B	2017-08-07 18:34:00+03	43000.00
B81C7C	2017-07-11 07:35:00+03	28000.00
B81C88	2017-08-11 23:24:00+03	67700.00
B81CD5	2017-07-06 04:50:00+03	27000.00
B81E51	2017-07-19 15:42:00+03	146000.00
B81E5A	2017-08-06 00:53:00+03	55800.00
B81E83	2017-07-30 17:53:00+03	32800.00
B81E8D	2017-07-23 23:02:00+03	46700.00
B81E9F	2017-08-06 19:18:00+03	117200.00
B81EA0	2017-07-13 06:22:00+03	51600.00
B81EBF	2017-08-09 07:35:00+03	49100.00
B81F05	2017-08-15 12:38:00+03	134600.00
B81F14	2017-08-03 12:19:00+03	18000.00
B81F5E	2017-08-14 21:23:00+03	76600.00
B81F92	2017-08-12 00:33:00+03	134400.00
B81FFF	2017-07-23 16:14:00+03	73900.00
B8203C	2017-07-11 09:12:00+03	133700.00
B82097	2017-06-27 15:57:00+03	58000.00
B820B1	2017-07-20 23:38:00+03	50600.00
B820B7	2017-07-15 22:14:00+03	59800.00
B820EF	2017-07-27 09:30:00+03	44000.00
B82118	2017-08-07 20:32:00+03	136400.00
B82153	2017-08-14 02:52:00+03	12600.00
B82197	2017-07-31 08:47:00+03	45500.00
B821A0	2017-08-03 17:26:00+03	65900.00
B821A1	2017-07-01 09:31:00+03	75800.00
B821BB	2017-08-01 19:31:00+03	30400.00
B821EF	2017-07-17 12:14:00+03	47000.00
B822F7	2017-08-14 07:23:00+03	42000.00
B82325	2017-07-23 03:09:00+03	39800.00
B8235A	2017-07-20 06:03:00+03	26700.00
B823FF	2017-07-02 20:23:00+03	24800.00
B82491	2017-07-14 12:07:00+03	6000.00
B8255C	2017-07-22 01:23:00+03	67900.00
B825A3	2017-07-30 05:08:00+03	41200.00
B825A7	2017-08-10 16:15:00+03	25400.00
B82618	2017-07-25 15:40:00+03	37900.00
B826F3	2017-07-16 15:19:00+03	69000.00
B8274D	2017-07-28 09:24:00+03	69500.00
B82785	2017-07-22 13:29:00+03	132900.00
B827DD	2017-07-31 03:27:00+03	127300.00
B827EE	2017-08-13 09:12:00+03	26800.00
B82815	2017-07-31 01:10:00+03	55400.00
B8287E	2017-08-11 01:09:00+03	36200.00
B8289C	2017-08-10 19:11:00+03	13400.00
B828AD	2017-08-03 06:51:00+03	179200.00
B828FD	2017-08-03 02:15:00+03	62000.00
B82948	2017-07-28 06:38:00+03	420500.00
B82952	2017-07-21 17:42:00+03	13000.00
B829D8	2017-07-08 20:46:00+03	246000.00
B829FF	2017-08-15 05:41:00+03	15700.00
B82A04	2017-07-04 18:24:00+03	175300.00
B82A4F	2017-07-28 21:14:00+03	99200.00
B82AC5	2017-08-01 21:06:00+03	58900.00
B82AFD	2017-07-26 22:03:00+03	56600.00
B82BAB	2017-08-13 14:55:00+03	46000.00
B82C0D	2017-08-01 21:29:00+03	21800.00
B82C15	2017-07-13 02:18:00+03	28000.00
B82C23	2017-07-09 09:05:00+03	135300.00
B82C8C	2017-07-15 14:24:00+03	29600.00
B82C95	2017-07-28 23:54:00+03	67200.00
B82CD5	2017-07-27 04:49:00+03	15900.00
B82CDC	2017-08-06 07:13:00+03	97900.00
B82CF2	2017-08-13 12:50:00+03	21800.00
B82DE3	2017-07-26 19:03:00+03	71200.00
B82DFD	2017-07-16 23:02:00+03	56100.00
B82E44	2017-07-13 00:27:00+03	38400.00
B82E81	2017-07-15 19:18:00+03	19600.00
B82EB9	2017-07-18 18:55:00+03	40000.00
B82EC9	2017-07-24 01:08:00+03	15400.00
B82ED4	2017-07-23 21:10:00+03	23200.00
B82F23	2017-07-20 02:08:00+03	13400.00
B82F38	2017-08-14 08:07:00+03	147100.00
B82FC4	2017-08-02 13:01:00+03	24400.00
B8300A	2017-07-10 13:49:00+03	56000.00
B8301C	2017-06-29 17:55:00+03	38800.00
B8305A	2017-08-01 17:11:00+03	24800.00
B830BE	2017-07-20 21:01:00+03	54500.00
B83114	2017-07-16 09:35:00+03	58800.00
B83117	2017-07-31 18:33:00+03	133100.00
B83130	2017-07-15 17:17:00+03	153900.00
B83137	2017-07-27 13:29:00+03	68000.00
B8313F	2017-07-22 14:35:00+03	31000.00
B83143	2017-08-06 02:14:00+03	92900.00
B83168	2017-08-08 17:35:00+03	93700.00
B83175	2017-07-24 03:36:00+03	30000.00
B83188	2017-07-04 23:46:00+03	87700.00
B831EB	2017-07-08 00:48:00+03	12200.00
B83256	2017-07-17 05:43:00+03	64800.00
B83267	2017-08-12 13:57:00+03	53100.00
B832F0	2017-07-30 02:20:00+03	85000.00
B8334F	2017-08-02 08:53:00+03	112100.00
B8335B	2017-08-02 21:54:00+03	55800.00
B83393	2017-07-09 07:43:00+03	6700.00
B8348A	2017-07-29 05:39:00+03	6000.00
B834DB	2017-07-24 09:12:00+03	36000.00
B834FC	2017-07-08 09:51:00+03	177200.00
B83503	2017-07-26 10:45:00+03	148200.00
B83504	2017-08-02 23:53:00+03	248300.00
B83507	2017-07-08 20:35:00+03	174600.00
B83561	2017-07-24 22:00:00+03	199300.00
B83648	2017-07-15 20:21:00+03	20800.00
B83668	2017-08-13 15:55:00+03	53600.00
B8366D	2017-08-04 10:25:00+03	27400.00
B8367E	2017-07-07 13:37:00+03	56600.00
B836B3	2017-07-10 18:23:00+03	22000.00
B836BA	2017-08-04 14:44:00+03	16400.00
B83794	2017-07-29 16:02:00+03	33300.00
B83798	2017-07-12 02:58:00+03	92800.00
B837CD	2017-07-15 19:10:00+03	26000.00
B837F0	2017-08-15 07:12:00+03	14000.00
B83820	2017-07-29 00:15:00+03	108500.00
B83870	2017-07-05 05:13:00+03	132500.00
B83875	2017-07-05 12:47:00+03	47200.00
B8387E	2017-07-11 22:26:00+03	226200.00
B83898	2017-07-11 00:04:00+03	37500.00
B83899	2017-07-11 14:04:00+03	89700.00
B838D5	2017-08-09 00:18:00+03	40400.00
B838E4	2017-08-13 11:58:00+03	59300.00
B83909	2017-07-20 14:58:00+03	53600.00
B83939	2017-07-11 12:11:00+03	28700.00
B839EE	2017-08-11 02:06:00+03	29600.00
B83A6B	2017-08-13 20:58:00+03	13600.00
B83B1F	2017-08-13 21:13:00+03	219900.00
B83B2F	2017-07-31 21:22:00+03	35300.00
B83C65	2017-07-04 23:44:00+03	12600.00
B83C68	2017-08-02 19:34:00+03	155600.00
B83C79	2017-07-23 08:59:00+03	108200.00
B83C81	2017-07-14 09:28:00+03	23600.00
B83C94	2017-08-03 16:20:00+03	28800.00
B83C96	2017-07-17 06:00:00+03	93500.00
B83CE3	2017-07-15 07:01:00+03	6000.00
B83DB4	2017-07-16 10:08:00+03	80100.00
B83E06	2017-07-08 07:34:00+03	13400.00
B83E30	2017-08-08 05:20:00+03	53600.00
B83E38	2017-07-22 15:33:00+03	50800.00
B83E58	2017-07-21 23:10:00+03	106300.00
B83E8E	2017-08-01 06:30:00+03	84500.00
B83ED2	2017-07-06 16:36:00+03	29600.00
B83FB1	2017-08-02 19:59:00+03	9800.00
B8402F	2017-08-09 02:29:00+03	112200.00
B8406D	2017-07-12 00:45:00+03	9300.00
B84086	2017-08-06 09:37:00+03	68800.00
B84098	2017-08-15 06:11:00+03	68800.00
B840B8	2017-08-01 13:38:00+03	66600.00
B840BB	2017-08-10 09:45:00+03	86300.00
B840E1	2017-07-24 11:22:00+03	107700.00
B840FF	2017-07-08 06:23:00+03	46200.00
B84183	2017-07-25 19:21:00+03	19800.00
B841BB	2017-07-07 05:45:00+03	257500.00
B8427D	2017-08-13 09:08:00+03	66800.00
B84302	2017-08-03 02:24:00+03	48800.00
B8431D	2017-08-05 17:11:00+03	6600.00
B84328	2017-07-15 22:40:00+03	21400.00
B8433B	2017-08-14 12:46:00+03	650200.00
B843A7	2017-07-18 00:14:00+03	44600.00
B843ED	2017-07-21 06:44:00+03	79200.00
B8441C	2017-08-02 22:39:00+03	63200.00
B84489	2017-07-08 08:19:00+03	36000.00
B844A8	2017-07-27 11:47:00+03	65500.00
B844C0	2017-07-31 18:58:00+03	160700.00
B8450D	2017-07-22 23:36:00+03	125200.00
B84573	2017-07-18 23:54:00+03	14000.00
B84592	2017-06-29 21:35:00+03	32700.00
B84606	2017-07-17 23:44:00+03	32200.00
B84666	2017-07-14 21:12:00+03	86600.00
B84684	2017-07-03 22:50:00+03	26000.00
B8469F	2017-07-25 19:28:00+03	26700.00
B846B2	2017-08-09 13:10:00+03	59800.00
B846CF	2017-07-15 11:28:00+03	28000.00
B846E7	2017-07-26 09:40:00+03	12600.00
B846E9	2017-07-17 10:21:00+03	203500.00
B84789	2017-07-02 10:38:00+03	12400.00
B847D9	2017-07-07 10:49:00+03	25800.00
B847E5	2017-06-29 15:01:00+03	312000.00
B84838	2017-08-13 11:02:00+03	62600.00
B848C2	2017-07-30 02:34:00+03	62600.00
B848F9	2017-08-05 05:56:00+03	67600.00
B84998	2017-07-31 00:47:00+03	134000.00
B849D2	2017-07-31 17:22:00+03	28800.00
B849D4	2017-07-29 08:51:00+03	130900.00
B849E5	2017-07-30 12:23:00+03	67600.00
B849F2	2017-07-10 06:24:00+03	212900.00
B849FB	2017-07-14 09:24:00+03	147200.00
B84AB7	2017-07-08 09:11:00+03	126500.00
B84B23	2017-08-07 17:24:00+03	13000.00
B84BC8	2017-08-15 15:55:00+03	47200.00
B84C5E	2017-07-25 09:31:00+03	114600.00
B84CF5	2017-07-29 07:23:00+03	49500.00
B84CF8	2017-07-23 13:18:00+03	46400.00
B84D28	2017-07-19 01:00:00+03	36200.00
B84D3B	2017-07-26 21:02:00+03	50600.00
B84D57	2017-06-28 22:08:00+03	86400.00
B84D73	2017-07-05 17:04:00+03	88900.00
B84E7C	2017-07-25 00:59:00+03	38800.00
B84E8D	2017-07-23 09:37:00+03	93000.00
B84EF5	2017-07-27 22:33:00+03	46000.00
B84F12	2017-07-21 04:57:00+03	318000.00
B84F14	2017-07-14 10:54:00+03	95000.00
B84F47	2017-07-31 19:44:00+03	273600.00
B84F5C	2017-07-20 14:43:00+03	45200.00
B84F8D	2017-07-22 04:14:00+03	191000.00
B85044	2017-07-03 23:17:00+03	55000.00
B8506C	2017-08-04 02:11:00+03	82900.00
B8509D	2017-08-07 04:14:00+03	77000.00
B850A6	2017-07-31 02:18:00+03	58800.00
B85128	2017-07-23 06:47:00+03	45900.00
B85156	2017-07-25 04:40:00+03	29600.00
B8516E	2017-07-10 23:11:00+03	52000.00
B8518A	2017-07-23 10:27:00+03	46300.00
B8518B	2017-07-20 18:43:00+03	113900.00
B85198	2017-07-29 10:13:00+03	114600.00
B85216	2017-07-20 07:59:00+03	74800.00
B85228	2017-07-20 12:31:00+03	173500.00
B852DE	2017-07-11 04:59:00+03	72800.00
B85343	2017-07-19 07:19:00+03	188000.00
B853AF	2017-07-14 11:10:00+03	46400.00
B8543A	2017-07-04 17:20:00+03	138000.00
B85492	2017-07-15 01:49:00+03	57800.00
B854A8	2017-08-06 02:31:00+03	45200.00
B854F6	2017-07-18 14:15:00+03	27200.00
B855A0	2017-07-09 05:22:00+03	30000.00
B855B0	2017-07-24 17:12:00+03	75600.00
B855FC	2017-07-18 13:07:00+03	167400.00
B85646	2017-08-01 03:39:00+03	55800.00
B85681	2017-07-06 18:43:00+03	17800.00
B856AB	2017-08-03 16:15:00+03	86400.00
B856F2	2017-07-04 20:13:00+03	66600.00
B85721	2017-07-25 08:27:00+03	24800.00
B8572B	2017-08-04 12:01:00+03	44600.00
B85787	2017-08-01 09:46:00+03	63200.00
B85870	2017-08-03 17:16:00+03	96300.00
B85877	2017-08-11 04:49:00+03	131600.00
B858D5	2017-07-28 01:13:00+03	37900.00
B858E1	2017-07-21 06:18:00+03	118600.00
B858E6	2017-08-04 17:45:00+03	123000.00
B859D0	2017-07-22 16:58:00+03	35800.00
B85A52	2017-07-05 21:58:00+03	23200.00
B85A57	2017-08-10 10:39:00+03	56600.00
B85A78	2017-07-11 18:18:00+03	24800.00
B85AED	2017-08-10 09:21:00+03	91600.00
B85AF9	2017-07-24 16:50:00+03	20500.00
B85B95	2017-07-15 19:05:00+03	114200.00
B85BD0	2017-07-13 20:39:00+03	36900.00
B85C43	2017-07-05 20:01:00+03	81700.00
B85CAD	2017-07-31 23:25:00+03	56600.00
B85CB4	2017-07-22 01:02:00+03	28800.00
B85CB6	2017-08-04 18:45:00+03	46400.00
B85CD9	2017-07-13 11:13:00+03	56000.00
B85CFF	2017-07-28 23:58:00+03	28800.00
B85D6E	2017-07-15 05:30:00+03	46300.00
B85DAD	2017-07-24 22:29:00+03	43200.00
B85E15	2017-07-19 06:01:00+03	23200.00
B85E1B	2017-07-27 22:00:00+03	47200.00
B85E49	2017-08-14 11:47:00+03	83400.00
B85EB9	2017-08-15 05:41:00+03	120900.00
B85EBF	2017-06-30 11:46:00+03	39300.00
B85EC4	2017-07-21 07:29:00+03	14400.00
B85F28	2017-07-04 15:40:00+03	52300.00
B85F2F	2017-07-25 08:50:00+03	31000.00
B85F73	2017-07-03 08:22:00+03	48500.00
B85FF4	2017-07-13 21:02:00+03	115700.00
B86000	2017-07-05 03:50:00+03	117200.00
B8606B	2017-07-30 02:36:00+03	36200.00
B86091	2017-06-30 02:11:00+03	14000.00
B860AC	2017-07-27 15:18:00+03	106300.00
B860DB	2017-07-25 10:57:00+03	31400.00
B86140	2017-07-10 00:59:00+03	60400.00
B8614C	2017-07-12 06:53:00+03	68400.00
B86188	2017-07-21 11:38:00+03	102200.00
B8619C	2017-07-13 13:29:00+03	23200.00
B8622C	2017-08-13 06:18:00+03	135600.00
B8627D	2017-07-26 14:18:00+03	28800.00
B8628A	2017-06-30 17:11:00+03	246000.00
B86290	2017-07-29 14:52:00+03	14000.00
B862C3	2017-08-06 09:15:00+03	391000.00
B86327	2017-08-13 14:46:00+03	443000.00
B863EB	2017-07-20 11:46:00+03	82000.00
B8644C	2017-07-08 23:21:00+03	369000.00
B8645A	2017-08-01 04:33:00+03	22000.00
B864C1	2017-08-14 04:24:00+03	41800.00
B864EE	2017-07-05 13:39:00+03	169200.00
B86563	2017-07-11 09:51:00+03	42400.00
B8656D	2017-07-19 20:18:00+03	230500.00
B86598	2017-08-09 00:12:00+03	46400.00
B8676D	2017-08-08 20:29:00+03	27800.00
B867AA	2017-07-22 09:23:00+03	45100.00
B86803	2017-07-06 03:18:00+03	28800.00
B86808	2017-08-11 17:20:00+03	30000.00
B86831	2017-07-25 08:51:00+03	139400.00
B86846	2017-08-01 16:53:00+03	40000.00
B868EF	2017-08-08 01:04:00+03	68100.00
B868F6	2017-07-15 04:38:00+03	522200.00
B8692B	2017-07-12 23:09:00+03	179900.00
B8693E	2017-08-11 12:41:00+03	28800.00
B8695F	2017-07-12 16:01:00+03	66400.00
B86985	2017-07-22 00:23:00+03	28800.00
B8699F	2017-08-13 22:20:00+03	30000.00
B86A9E	2017-07-01 00:50:00+03	37900.00
B86B10	2017-08-01 02:10:00+03	114300.00
B86B4F	2017-07-11 08:13:00+03	67200.00
B86B77	2017-07-14 13:38:00+03	8200.00
B86BD9	2017-07-01 11:50:00+03	23200.00
B86BF6	2017-07-07 03:11:00+03	44000.00
B86C21	2017-07-09 01:52:00+03	75600.00
B86C40	2017-08-08 11:30:00+03	23200.00
B86C5A	2017-07-02 19:08:00+03	56600.00
B86CA7	2017-06-28 20:37:00+03	28000.00
B86CBC	2017-06-29 05:11:00+03	111600.00
B86CD4	2017-07-10 21:37:00+03	20500.00
B86CE7	2017-07-11 05:33:00+03	272400.00
B86CF0	2017-07-26 10:14:00+03	86800.00
B86D18	2017-07-07 10:57:00+03	103800.00
B86D20	2017-07-13 11:26:00+03	32800.00
B86D46	2017-07-10 22:40:00+03	118300.00
B86DA4	2017-07-29 17:46:00+03	21400.00
B86E10	2017-07-18 14:18:00+03	55800.00
B86EA3	2017-07-15 01:50:00+03	19600.00
B86EC0	2017-07-24 15:05:00+03	18500.00
B86ED7	2017-08-09 05:55:00+03	6700.00
B86F8F	2017-07-26 05:59:00+03	38600.00
B86FE5	2017-07-31 13:42:00+03	16800.00
B87008	2017-08-12 15:59:00+03	46400.00
B8704E	2017-07-21 08:39:00+03	36400.00
B87063	2017-08-01 20:16:00+03	149600.00
B8709A	2017-07-06 17:20:00+03	225800.00
B8717F	2017-07-14 00:35:00+03	90100.00
B871C8	2017-07-13 07:55:00+03	109500.00
B871D4	2017-07-06 09:47:00+03	39400.00
B871E1	2017-06-29 02:22:00+03	36800.00
B871FA	2017-07-29 15:56:00+03	66600.00
B8723A	2017-07-30 17:33:00+03	42400.00
B87255	2017-07-28 21:09:00+03	20100.00
B87281	2017-08-11 06:05:00+03	28000.00
B8730A	2017-08-04 13:18:00+03	24500.00
B8732F	2017-07-25 02:17:00+03	151200.00
B87401	2017-07-05 13:19:00+03	4000.00
B8747C	2017-07-31 12:55:00+03	12600.00
B87493	2017-07-05 07:44:00+03	174600.00
B874FA	2017-07-10 09:49:00+03	40800.00
B874FF	2017-08-09 15:18:00+03	136200.00
B87531	2017-08-13 18:09:00+03	31400.00
B8759F	2017-07-11 01:47:00+03	43000.00
B875C6	2017-08-06 12:13:00+03	137600.00
B875D4	2017-07-10 18:17:00+03	31400.00
B87679	2017-07-10 07:26:00+03	56600.00
B876CE	2017-07-24 06:45:00+03	65200.00
B876DB	2017-07-26 15:31:00+03	256300.00
B877B2	2017-07-09 01:41:00+03	111600.00
B8780C	2017-06-29 22:25:00+03	14000.00
B87850	2017-07-04 19:11:00+03	41800.00
B87892	2017-07-04 16:23:00+03	56000.00
B878A8	2017-08-12 14:55:00+03	65300.00
B878C3	2017-07-24 11:35:00+03	24800.00
B878EB	2017-07-31 10:19:00+03	13000.00
B878ED	2017-07-08 07:54:00+03	50100.00
B87941	2017-08-15 16:28:00+03	125000.00
B87956	2017-08-11 21:37:00+03	14000.00
B879C7	2017-08-07 09:28:00+03	20000.00
B87A14	2017-07-05 08:56:00+03	51600.00
B87A4A	2017-08-05 22:51:00+03	186900.00
B87A69	2017-07-17 07:57:00+03	28000.00
B87A6E	2017-08-05 16:44:00+03	97900.00
B87AA0	2017-08-15 04:39:00+03	12600.00
B87ABB	2017-07-19 19:52:00+03	6000.00
B87B06	2017-07-04 08:32:00+03	28000.00
B87B53	2017-06-28 21:10:00+03	35600.00
B87C3E	2017-07-20 03:43:00+03	133900.00
B87C4A	2017-08-14 11:32:00+03	59700.00
B87C92	2017-08-07 23:10:00+03	26000.00
B87D43	2017-07-16 02:27:00+03	100000.00
B87D5F	2017-08-10 11:11:00+03	46400.00
B87D87	2017-07-19 18:11:00+03	28000.00
B87D95	2017-07-26 23:20:00+03	146700.00
B87DDA	2017-07-22 20:45:00+03	57500.00
B87DDF	2017-07-18 01:55:00+03	58800.00
B87E08	2017-08-01 12:26:00+03	70800.00
B87F22	2017-07-28 16:11:00+03	42800.00
B87F2B	2017-07-13 22:24:00+03	132800.00
B87FDC	2017-07-12 11:14:00+03	63800.00
B87FFC	2017-07-26 06:28:00+03	41200.00
B8803B	2017-08-04 17:02:00+03	44300.00
B8809C	2017-07-24 03:54:00+03	13400.00
B8815D	2017-08-11 12:53:00+03	37900.00
B881AB	2017-08-11 14:46:00+03	131800.00
B881D9	2017-07-31 00:48:00+03	8200.00
B88222	2017-07-02 02:01:00+03	162700.00
B8822B	2017-07-24 06:38:00+03	51000.00
B8824F	2017-07-29 18:19:00+03	44000.00
B8826E	2017-07-29 12:50:00+03	32800.00
B88274	2017-07-18 16:05:00+03	58400.00
B882F3	2017-06-27 17:40:00+03	27200.00
B8838D	2017-08-07 06:39:00+03	265800.00
B883F9	2017-07-30 23:32:00+03	67700.00
B884A2	2017-07-02 00:55:00+03	111600.00
B88517	2017-08-15 09:38:00+03	87700.00
B88576	2017-08-12 16:36:00+03	54800.00
B88584	2017-07-06 21:41:00+03	28800.00
B88598	2017-07-26 13:42:00+03	18800.00
B885C2	2017-08-14 09:47:00+03	64800.00
B885E7	2017-07-27 13:21:00+03	67400.00
B8861B	2017-08-02 06:15:00+03	29400.00
B8862F	2017-07-19 11:01:00+03	10800.00
B8863B	2017-08-13 09:38:00+03	144400.00
B88652	2017-07-01 13:16:00+03	15900.00
B886F1	2017-08-12 08:56:00+03	14300.00
B8870A	2017-08-12 12:49:00+03	85000.00
B8873D	2017-08-04 16:03:00+03	49600.00
B887D2	2017-08-13 05:05:00+03	44000.00
B88847	2017-07-25 13:34:00+03	85000.00
B88850	2017-07-06 13:25:00+03	42700.00
B88881	2017-08-02 22:41:00+03	26000.00
B88889	2017-07-16 07:53:00+03	68400.00
B888B5	2017-07-30 03:46:00+03	47000.00
B888BF	2017-07-14 03:06:00+03	28800.00
B88907	2017-07-24 20:00:00+03	98000.00
B88944	2017-07-15 02:29:00+03	19600.00
B88945	2017-07-19 01:10:00+03	257300.00
B889A2	2017-08-05 04:48:00+03	18400.00
B889AF	2017-07-21 22:05:00+03	56600.00
B88A0E	2017-07-19 00:11:00+03	21400.00
B88A4B	2017-07-08 06:36:00+03	75300.00
B88A9B	2017-08-13 16:01:00+03	152400.00
B88ABE	2017-07-23 15:36:00+03	75600.00
B88AE2	2017-08-11 13:59:00+03	39200.00
B88BD6	2017-08-09 19:49:00+03	100600.00
B88BF4	2017-08-12 05:56:00+03	81600.00
B88C2F	2017-07-11 05:53:00+03	13000.00
B88C40	2017-08-14 21:32:00+03	45200.00
B88CE8	2017-07-28 14:30:00+03	46400.00
B88D16	2017-08-15 11:34:00+03	18400.00
B88D6B	2017-08-02 16:39:00+03	54000.00
B88D70	2017-07-11 06:20:00+03	38800.00
B88D87	2017-07-09 21:58:00+03	203100.00
B88DA8	2017-07-24 17:51:00+03	12600.00
B88DB1	2017-07-31 10:54:00+03	52100.00
B88DB2	2017-08-13 10:11:00+03	14400.00
B88DBA	2017-08-13 07:19:00+03	123000.00
B88DE4	2017-07-18 00:01:00+03	22000.00
B88E04	2017-07-06 04:05:00+03	67600.00
B88E45	2017-08-01 22:30:00+03	94900.00
B88EAA	2017-07-04 21:46:00+03	120900.00
B88EB4	2017-07-31 06:26:00+03	134000.00
B88F5D	2017-07-29 01:32:00+03	91600.00
B88FA1	2017-07-04 17:02:00+03	35600.00
B88FAD	2017-07-07 12:29:00+03	63200.00
B88FBD	2017-08-03 17:47:00+03	25000.00
B88FE5	2017-07-16 21:08:00+03	43000.00
B8907A	2017-07-31 13:10:00+03	246400.00
B890D8	2017-08-08 15:48:00+03	136800.00
B89152	2017-08-07 22:37:00+03	123600.00
B89158	2017-07-18 05:44:00+03	6700.00
B89183	2017-07-16 11:23:00+03	49900.00
B891A4	2017-07-16 22:30:00+03	147700.00
B891BC	2017-07-03 23:35:00+03	35200.00
B891F6	2017-07-15 00:34:00+03	49700.00
B89222	2017-07-10 13:45:00+03	50800.00
B89224	2017-08-01 11:18:00+03	81200.00
B89233	2017-08-11 12:01:00+03	7400.00
B89244	2017-08-14 16:24:00+03	28000.00
B89267	2017-07-28 12:13:00+03	75600.00
B8927C	2017-07-15 20:56:00+03	26000.00
B892D2	2017-07-03 07:41:00+03	106300.00
B892E1	2017-08-06 08:46:00+03	207000.00
B892E2	2017-07-30 07:47:00+03	11800.00
B8930A	2017-07-12 11:21:00+03	46000.00
B89358	2017-07-26 06:54:00+03	42700.00
B89366	2017-07-15 09:28:00+03	26000.00
B8939D	2017-07-22 01:49:00+03	10800.00
B893D0	2017-08-07 23:53:00+03	67600.00
B893DA	2017-07-19 13:18:00+03	141100.00
B893EE	2017-07-28 11:19:00+03	12600.00
B893EF	2017-07-23 19:53:00+03	56000.00
B89445	2017-08-09 21:06:00+03	24400.00
B8944F	2017-07-17 07:39:00+03	34000.00
B894DF	2017-07-03 03:18:00+03	68800.00
B894F1	2017-07-18 09:46:00+03	14000.00
B89506	2017-07-10 23:43:00+03	94600.00
B89555	2017-07-14 20:47:00+03	492000.00
B895D3	2017-07-28 17:52:00+03	81300.00
B89651	2017-07-02 03:44:00+03	93500.00
B8968B	2017-07-09 19:23:00+03	22000.00
B896E7	2017-08-04 11:07:00+03	28700.00
B89718	2017-07-22 04:14:00+03	59200.00
B89766	2017-07-14 10:53:00+03	55800.00
B89784	2017-07-29 05:28:00+03	26100.00
B897A2	2017-07-10 16:24:00+03	63200.00
B8982E	2017-07-08 09:18:00+03	22000.00
B89878	2017-07-20 20:27:00+03	17000.00
B89883	2017-07-11 09:23:00+03	195800.00
B89896	2017-08-06 13:48:00+03	111600.00
B8989D	2017-07-30 01:57:00+03	116900.00
B89902	2017-07-18 17:47:00+03	6000.00
B8996E	2017-07-06 14:21:00+03	232200.00
B899D1	2017-07-22 19:30:00+03	54800.00
B899D4	2017-07-10 23:11:00+03	106600.00
B89A25	2017-07-17 04:32:00+03	52300.00
B89A27	2017-06-26 10:32:00+03	138000.00
B89A41	2017-07-07 03:48:00+03	64700.00
B89A97	2017-07-03 14:10:00+03	78100.00
B89ABA	2017-08-13 14:39:00+03	8200.00
B89ABB	2017-08-02 07:51:00+03	71400.00
B89B34	2017-07-14 17:53:00+03	23400.00
B89B71	2017-07-15 06:29:00+03	137600.00
B89BEE	2017-07-19 16:38:00+03	58000.00
B89C23	2017-07-15 10:48:00+03	7400.00
B89C4A	2017-08-06 11:58:00+03	46000.00
B89C77	2017-07-17 23:16:00+03	73600.00
B89C83	2017-08-07 13:15:00+03	62000.00
B89C8D	2017-08-11 10:11:00+03	124400.00
B89CD3	2017-06-28 16:22:00+03	18600.00
B89D1D	2017-08-02 10:54:00+03	40300.00
B89DB4	2017-07-05 09:54:00+03	67600.00
B89E20	2017-07-12 02:02:00+03	32800.00
B89E44	2017-07-02 00:16:00+03	80000.00
B89EC4	2017-07-14 19:30:00+03	31400.00
B89F1D	2017-07-10 13:53:00+03	189200.00
B89F1E	2017-07-22 07:03:00+03	200400.00
B89F52	2017-07-17 14:18:00+03	92800.00
B89FC4	2017-07-18 02:50:00+03	65500.00
B8A012	2017-08-02 19:51:00+03	266400.00
B8A021	2017-08-13 11:55:00+03	56000.00
B8A024	2017-07-03 02:39:00+03	136800.00
B8A05D	2017-07-18 16:44:00+03	429100.00
B8A0DA	2017-08-03 08:13:00+03	132800.00
B8A118	2017-08-06 12:46:00+03	51200.00
B8A140	2017-08-01 13:56:00+03	96200.00
B8A182	2017-07-30 16:39:00+03	66600.00
B8A1CD	2017-07-22 12:22:00+03	48800.00
B8A260	2017-08-05 18:26:00+03	43900.00
B8A2ED	2017-07-12 07:38:00+03	46000.00
B8A384	2017-07-27 05:10:00+03	26000.00
B8A3F6	2017-07-12 00:03:00+03	52800.00
B8A47B	2017-08-13 17:58:00+03	19600.00
B8A48E	2017-07-15 02:16:00+03	21400.00
B8A4C8	2017-08-08 13:04:00+03	47200.00
B8A50F	2017-08-13 08:33:00+03	23900.00
B8A51A	2017-06-30 23:02:00+03	68400.00
B8A552	2017-07-18 06:53:00+03	122300.00
B8A56B	2017-07-25 13:45:00+03	35200.00
B8A579	2017-07-04 11:32:00+03	13800.00
B8A57E	2017-07-05 14:13:00+03	104000.00
B8A5C2	2017-08-14 08:03:00+03	112000.00
B8A63D	2017-07-06 16:50:00+03	23200.00
B8A641	2017-07-31 09:03:00+03	28000.00
B8A654	2017-07-05 02:47:00+03	26000.00
B8A79F	2017-07-22 07:07:00+03	125600.00
B8A7C4	2017-07-09 07:27:00+03	18700.00
B8A7ED	2017-08-07 17:00:00+03	64700.00
B8A823	2017-07-12 21:52:00+03	47200.00
B8A825	2017-07-03 01:03:00+03	170200.00
B8A8AC	2017-08-12 23:16:00+03	56000.00
B8A979	2017-08-12 20:46:00+03	21800.00
B8A9E0	2017-07-08 06:36:00+03	56000.00
B8AAD6	2017-08-06 14:54:00+03	38600.00
B8AB07	2017-07-21 08:09:00+03	131100.00
B8AB08	2017-08-10 20:44:00+03	6800.00
B8AB75	2017-07-03 06:25:00+03	58600.00
B8AC61	2017-08-12 06:19:00+03	50000.00
B8AC70	2017-07-05 08:37:00+03	109400.00
B8AC88	2017-07-12 09:30:00+03	214700.00
B8ACE8	2017-07-11 14:18:00+03	21000.00
B8AD2C	2017-07-31 05:08:00+03	28800.00
B8AD40	2017-08-03 01:09:00+03	57300.00
B8AD85	2017-08-09 08:04:00+03	48100.00
B8ADBC	2017-08-11 04:11:00+03	23400.00
B8ADD0	2017-08-12 05:59:00+03	30800.00
B8ADD6	2017-07-29 23:44:00+03	6000.00
B8ADF9	2017-07-21 05:55:00+03	111600.00
B8AE8B	2017-07-28 11:24:00+03	199100.00
B8AE9B	2017-07-20 14:31:00+03	185500.00
B8AEA0	2017-07-24 21:21:00+03	136200.00
B8AEA4	2017-07-19 20:32:00+03	40000.00
B8AEC8	2017-07-09 22:09:00+03	26700.00
B8AF02	2017-08-14 21:05:00+03	92700.00
B8B061	2017-08-08 15:39:00+03	44400.00
B8B098	2017-07-10 15:19:00+03	275900.00
B8B0AB	2017-07-09 07:21:00+03	93900.00
B8B18A	2017-07-20 00:26:00+03	38600.00
B8B1F0	2017-08-15 17:10:00+03	42000.00
B8B1F3	2017-06-30 05:55:00+03	23600.00
B8B21D	2017-07-04 11:58:00+03	87200.00
B8B2F5	2017-07-25 03:16:00+03	112600.00
B8B314	2017-07-15 04:02:00+03	88900.00
B8B346	2017-07-16 05:54:00+03	56100.00
B8B37B	2017-08-03 22:32:00+03	69500.00
B8B3B4	2017-07-04 14:09:00+03	37900.00
B8B3C4	2017-07-26 15:13:00+03	56000.00
B8B3C6	2017-07-02 07:36:00+03	10700.00
B8B40F	2017-08-12 00:41:00+03	384900.00
B8B419	2017-08-09 06:18:00+03	164700.00
B8B43F	2017-07-30 01:59:00+03	23600.00
B8B454	2017-07-12 08:41:00+03	131900.00
B8B478	2017-08-05 14:15:00+03	49500.00
B8B484	2017-08-10 19:19:00+03	133200.00
B8B4A0	2017-07-23 15:57:00+03	97900.00
B8B4EF	2017-07-31 05:05:00+03	52300.00
B8B53C	2017-08-04 23:20:00+03	61200.00
B8B59A	2017-08-04 03:28:00+03	123000.00
B8B5D0	2017-07-13 12:32:00+03	393800.00
B8B67B	2017-08-12 04:13:00+03	153300.00
B8B6DE	2017-08-06 12:20:00+03	46400.00
B8B798	2017-07-03 06:41:00+03	19100.00
B8B7D4	2017-07-19 17:28:00+03	193600.00
B8B7D6	2017-07-09 19:25:00+03	44600.00
B8B7DD	2017-08-01 05:37:00+03	68400.00
B8B810	2017-08-01 23:17:00+03	56000.00
B8B868	2017-07-13 11:59:00+03	61800.00
B8B883	2017-08-05 13:48:00+03	78200.00
B8B89A	2017-08-12 05:34:00+03	21400.00
B8B8A9	2017-08-11 11:26:00+03	11800.00
B8B8B0	2017-07-26 01:19:00+03	77000.00
B8B905	2017-07-05 10:51:00+03	54000.00
B8B90B	2017-06-30 16:47:00+03	43500.00
B8B920	2017-08-12 07:17:00+03	86600.00
B8B996	2017-07-16 14:38:00+03	74400.00
B8B9AC	2017-07-09 08:12:00+03	14400.00
B8B9F0	2017-07-27 17:47:00+03	98300.00
B8BA24	2017-07-16 22:22:00+03	310300.00
B8BA4A	2017-08-03 03:34:00+03	243100.00
B8BA61	2017-07-13 08:25:00+03	120900.00
B8BA72	2017-07-01 06:18:00+03	16400.00
B8BA8D	2017-07-04 14:45:00+03	121400.00
B8BABB	2017-07-27 10:04:00+03	160100.00
B8BACC	2017-07-29 10:37:00+03	14400.00
B8BB2C	2017-07-14 05:21:00+03	67200.00
B8BB72	2017-07-24 06:00:00+03	266400.00
B8BC77	2017-08-11 06:15:00+03	136200.00
B8BCC1	2017-07-27 06:43:00+03	26000.00
B8BCF1	2017-07-21 18:49:00+03	6000.00
B8BCF8	2017-07-28 23:10:00+03	67000.00
B8BD00	2017-07-19 17:25:00+03	116800.00
B8BDA1	2017-07-24 23:07:00+03	31900.00
B8BDAE	2017-07-24 07:52:00+03	54000.00
B8BDB6	2017-08-01 02:31:00+03	43400.00
B8BE2E	2017-07-03 02:29:00+03	62600.00
B8BE4C	2017-07-09 02:51:00+03	172600.00
B8BE92	2017-07-11 08:20:00+03	32800.00
B8BE9A	2017-08-14 22:43:00+03	11600.00
B8BE9D	2017-08-01 06:07:00+03	13400.00
B8BEBB	2017-06-30 15:54:00+03	18000.00
B8BEBF	2017-08-14 04:11:00+03	105000.00
B8BED7	2017-08-05 23:55:00+03	13200.00
B8BF1F	2017-07-17 21:29:00+03	136200.00
B8BF3E	2017-07-26 08:42:00+03	296400.00
B8BF4D	2017-07-10 15:40:00+03	137600.00
B8BF6D	2017-08-07 09:42:00+03	13000.00
B8BF8D	2017-07-13 09:18:00+03	44800.00
B8BFDD	2017-07-31 07:07:00+03	16400.00
B8BFED	2017-08-11 15:06:00+03	81600.00
B8C054	2017-07-02 03:50:00+03	400000.00
B8C059	2017-07-02 22:30:00+03	111600.00
B8C07B	2017-07-30 14:24:00+03	92600.00
B8C0AC	2017-07-16 15:45:00+03	106400.00
B8C0D9	2017-07-07 00:23:00+03	56000.00
B8C0DD	2017-08-05 21:51:00+03	28000.00
B8C146	2017-07-14 07:27:00+03	55800.00
B8C174	2017-07-24 04:10:00+03	123000.00
B8C1D0	2017-08-15 05:39:00+03	14300.00
B8C227	2017-07-11 12:46:00+03	92500.00
B8C264	2017-07-09 16:01:00+03	111600.00
B8C278	2017-07-18 00:57:00+03	185000.00
B8C2B0	2017-07-26 11:38:00+03	168000.00
B8C2D2	2017-08-03 02:49:00+03	64700.00
B8C2D9	2017-07-14 20:58:00+03	14000.00
B8C338	2017-07-23 02:41:00+03	57800.00
B8C339	2017-08-01 07:29:00+03	139200.00
B8C36E	2017-08-11 04:17:00+03	6000.00
B8C3A2	2017-07-07 13:36:00+03	61800.00
B8C3C4	2017-07-21 17:54:00+03	149300.00
B8C41F	2017-07-24 13:38:00+03	123000.00
B8C439	2017-07-13 00:04:00+03	133200.00
B8C48C	2017-07-03 00:30:00+03	118900.00
B8C497	2017-07-12 06:18:00+03	8200.00
B8C54F	2017-07-21 08:40:00+03	54800.00
B8C58B	2017-08-09 15:10:00+03	39500.00
B8C59D	2017-07-29 01:45:00+03	31400.00
B8C5B8	2017-06-29 05:02:00+03	63600.00
B8C64F	2017-07-17 04:49:00+03	52400.00
B8C69A	2017-07-07 10:39:00+03	92100.00
B8C6E3	2017-07-06 13:11:00+03	144400.00
B8C752	2017-08-05 16:19:00+03	21800.00
B8C77B	2017-08-14 10:16:00+03	49500.00
B8C787	2017-07-22 19:09:00+03	67200.00
B8C7A5	2017-08-13 23:46:00+03	115600.00
B8C7C3	2017-07-21 11:42:00+03	54400.00
B8C7C7	2017-07-30 13:43:00+03	43900.00
B8C7E2	2017-07-16 04:37:00+03	246000.00
B8C7E6	2017-08-06 21:21:00+03	65200.00
B8C8A2	2017-07-27 05:36:00+03	8000.00
B8C8E7	2017-08-02 17:41:00+03	108500.00
B8C979	2017-07-14 11:41:00+03	46200.00
B8C9A6	2017-08-11 08:23:00+03	23800.00
B8C9BE	2017-07-05 08:27:00+03	19600.00
B8C9DD	2017-08-01 04:55:00+03	24400.00
B8C9E8	2017-08-09 14:12:00+03	123000.00
B8CA20	2017-08-02 13:03:00+03	25100.00
B8CA9D	2017-07-23 05:05:00+03	23200.00
B8CAD1	2017-07-23 16:43:00+03	6300.00
B8CAFE	2017-08-14 00:24:00+03	47200.00
B8CB46	2017-07-06 19:27:00+03	25100.00
B8CB62	2017-07-04 06:35:00+03	48800.00
B8CBB1	2017-07-31 03:44:00+03	566700.00
B8CBC2	2017-07-27 01:40:00+03	47500.00
B8CBC5	2017-07-18 11:28:00+03	144400.00
B8CC6F	2017-07-12 21:08:00+03	24800.00
B8CCA2	2017-08-03 04:11:00+03	13400.00
B8CCA3	2017-07-09 11:45:00+03	83600.00
B8CCAF	2017-08-15 08:47:00+03	58000.00
B8CD18	2017-08-06 16:04:00+03	59800.00
B8CD82	2017-07-06 02:58:00+03	44000.00
B8CDB3	2017-07-12 14:54:00+03	12000.00
B8CE27	2017-07-13 02:40:00+03	75600.00
B8CE53	2017-07-01 11:28:00+03	55800.00
B8CE58	2017-08-12 22:51:00+03	265600.00
B8CE60	2017-07-09 10:33:00+03	54000.00
B8CEED	2017-08-01 12:13:00+03	56000.00
B8CF31	2017-07-21 11:09:00+03	103300.00
B8CF42	2017-08-15 11:00:00+03	64200.00
B8CF80	2017-07-28 06:32:00+03	46000.00
B8CF81	2017-08-12 09:57:00+03	56000.00
B8CFB8	2017-07-06 08:33:00+03	28800.00
B8D022	2017-07-16 05:41:00+03	8200.00
B8D02A	2017-06-28 01:32:00+03	96700.00
B8D057	2017-07-09 04:28:00+03	184800.00
B8D098	2017-08-11 14:25:00+03	167200.00
B8D205	2017-07-18 17:49:00+03	209900.00
B8D29A	2017-07-15 23:22:00+03	10600.00
B8D2C5	2017-07-26 10:20:00+03	64100.00
B8D2D0	2017-08-02 16:06:00+03	6700.00
B8D2EA	2017-08-01 18:51:00+03	101800.00
B8D306	2017-06-30 22:17:00+03	82600.00
B8D386	2017-08-01 19:26:00+03	111000.00
B8D3E2	2017-07-13 23:30:00+03	155100.00
B8D3F3	2017-08-07 02:53:00+03	316400.00
B8D41C	2017-07-06 01:47:00+03	135400.00
B8D47F	2017-06-28 03:43:00+03	67100.00
B8D4A8	2017-07-03 12:16:00+03	123000.00
B8D4F7	2017-08-10 03:42:00+03	60400.00
B8D523	2017-08-10 08:32:00+03	135600.00
B8D548	2017-07-29 16:16:00+03	102100.00
B8D567	2017-07-09 11:14:00+03	23200.00
B8D5B7	2017-07-30 03:47:00+03	101200.00
B8D5BF	2017-08-14 16:24:00+03	46300.00
B8D5C0	2017-08-02 01:41:00+03	54000.00
B8D5EE	2017-07-23 18:35:00+03	13600.00
B8D6F5	2017-07-28 13:11:00+03	56800.00
B8D6FD	2017-07-10 15:07:00+03	23200.00
B8D761	2017-07-07 23:27:00+03	58900.00
B8D789	2017-08-06 18:07:00+03	70800.00
B8D795	2017-07-31 16:17:00+03	97700.00
B8D79D	2017-07-03 20:12:00+03	138000.00
B8D7AF	2017-07-24 06:46:00+03	48400.00
B8D7C9	2017-07-04 12:30:00+03	191000.00
B8D814	2017-07-08 23:47:00+03	42800.00
B8D85D	2017-07-03 09:36:00+03	23600.00
B8D8B2	2017-07-17 18:04:00+03	110500.00
B8D8FB	2017-07-05 10:17:00+03	56000.00
B8D966	2017-07-15 15:07:00+03	84100.00
B8D9CD	2017-07-16 10:55:00+03	51300.00
B8DA8D	2017-07-30 02:45:00+03	6800.00
B8DB34	2017-07-03 07:58:00+03	131100.00
B8DB5F	2017-07-25 16:11:00+03	70800.00
B8DB66	2017-07-09 03:49:00+03	16400.00
B8DBCF	2017-07-06 23:22:00+03	100600.00
B8DBDE	2017-08-06 07:37:00+03	316700.00
B8DC23	2017-07-25 05:40:00+03	14000.00
B8DCB2	2017-08-03 10:33:00+03	86600.00
B8DD1A	2017-07-24 12:41:00+03	168200.00
B8DD2F	2017-08-07 05:48:00+03	49700.00
B8DD44	2017-07-10 08:36:00+03	11000.00
B8DD59	2017-07-20 20:08:00+03	266400.00
B8DDA8	2017-07-10 20:22:00+03	88600.00
B8DDC7	2017-07-25 11:02:00+03	131600.00
B8DDE9	2017-08-15 09:31:00+03	89600.00
B8DDEE	2017-07-20 15:29:00+03	26800.00
B8DE14	2017-07-24 15:27:00+03	97600.00
B8DE19	2017-07-15 06:57:00+03	48700.00
B8DE46	2017-07-04 23:52:00+03	40300.00
B8DE7B	2017-07-19 23:42:00+03	58000.00
B8DEBE	2017-08-12 06:35:00+03	67100.00
B8DED5	2017-07-22 08:47:00+03	76600.00
B8DF08	2017-07-25 23:32:00+03	46400.00
B8DFA0	2017-08-01 06:29:00+03	20800.00
B8DFE5	2017-08-15 12:44:00+03	66300.00
B8DFF0	2017-08-06 07:46:00+03	28800.00
B8E03A	2017-07-10 06:14:00+03	26200.00
B8E0BA	2017-07-08 14:21:00+03	57400.00
B8E0C0	2017-07-10 02:42:00+03	27200.00
B8E0E7	2017-08-12 16:43:00+03	159500.00
B8E175	2017-07-28 01:03:00+03	35400.00
B8E18E	2017-07-12 16:24:00+03	28800.00
B8E1D1	2017-07-11 02:09:00+03	65500.00
B8E26B	2017-07-31 01:26:00+03	98400.00
B8E27D	2017-08-06 21:48:00+03	44500.00
B8E2BA	2017-07-08 10:26:00+03	47100.00
B8E2BE	2017-08-08 06:44:00+03	44000.00
B8E2C4	2017-07-26 03:55:00+03	46400.00
B8E31F	2017-07-24 17:59:00+03	7200.00
B8E321	2017-08-03 15:20:00+03	44800.00
B8E36F	2017-07-25 11:30:00+03	88600.00
B8E371	2017-08-15 05:03:00+03	92600.00
B8E3A1	2017-07-30 22:28:00+03	23400.00
B8E3F5	2017-08-09 12:46:00+03	16400.00
B8E42C	2017-08-05 03:29:00+03	25800.00
B8E53D	2017-08-08 06:00:00+03	85000.00
B8E584	2017-07-19 22:26:00+03	96300.00
B8E59E	2017-07-29 06:58:00+03	68800.00
B8E5F0	2017-08-05 18:11:00+03	112000.00
B8E6B2	2017-08-05 07:26:00+03	76800.00
B8E6C7	2017-07-03 14:14:00+03	398500.00
B8E744	2017-07-04 21:28:00+03	27600.00
B8E751	2017-07-30 08:53:00+03	75600.00
B8E7AC	2017-08-05 03:57:00+03	261500.00
B8E7DB	2017-08-10 10:21:00+03	22000.00
B8E837	2017-08-12 06:04:00+03	26000.00
B8E8A1	2017-08-06 02:31:00+03	61400.00
B8E93F	2017-07-07 18:38:00+03	23200.00
B8E98F	2017-08-08 02:28:00+03	357600.00
B8EA41	2017-08-02 19:39:00+03	26000.00
B8EA4A	2017-07-29 17:17:00+03	52000.00
B8EA50	2017-07-23 19:25:00+03	89200.00
B8EB4F	2017-07-07 00:52:00+03	37200.00
B8EB87	2017-08-11 06:24:00+03	28800.00
B8EBB7	2017-07-15 19:12:00+03	6800.00
B8EBBC	2017-07-16 18:06:00+03	31100.00
B8EBEE	2017-07-10 16:31:00+03	28800.00
B8EBF5	2017-08-04 13:31:00+03	57600.00
B8EC01	2017-08-09 07:54:00+03	49000.00
B8EC07	2017-07-05 03:56:00+03	32800.00
B8EC3B	2017-08-07 04:20:00+03	38600.00
B8EC3C	2017-07-08 07:13:00+03	128300.00
B8EC82	2017-07-18 00:21:00+03	50000.00
B8ECD1	2017-07-17 19:00:00+03	46300.00
B8ECDE	2017-08-04 19:12:00+03	17000.00
B8ED35	2017-07-09 07:40:00+03	65300.00
B8ED45	2017-07-12 23:12:00+03	67700.00
B8ED83	2017-07-27 04:54:00+03	46300.00
B8ED9F	2017-07-25 01:41:00+03	75200.00
B8EDB2	2017-08-07 14:01:00+03	143200.00
B8EDD1	2017-08-07 02:38:00+03	20200.00
B8EDE9	2017-07-10 12:06:00+03	31600.00
B8EDFB	2017-07-19 20:55:00+03	57300.00
B8EE15	2017-07-24 04:30:00+03	12600.00
B8EE41	2017-07-29 13:39:00+03	40800.00
B8EE98	2017-07-23 08:32:00+03	55300.00
B8EECE	2017-08-07 12:15:00+03	133200.00
B8EEDB	2017-08-07 14:56:00+03	46400.00
B8EF8F	2017-08-08 23:38:00+03	23200.00
B8F011	2017-07-09 10:14:00+03	399600.00
B8F0BF	2017-07-01 08:27:00+03	75600.00
B8F0D2	2017-07-29 14:18:00+03	56100.00
B8F0F8	2017-07-31 01:38:00+03	10600.00
B8F0FD	2017-08-03 20:28:00+03	46000.00
B8F11A	2017-07-01 18:30:00+03	92100.00
B8F13F	2017-07-10 18:18:00+03	140900.00
B8F15C	2017-07-30 20:30:00+03	49400.00
B8F17F	2017-07-16 02:40:00+03	13400.00
B8F1AC	2017-07-16 11:21:00+03	48300.00
B8F1B7	2017-08-06 16:18:00+03	136200.00
B8F1EF	2017-08-13 22:35:00+03	58800.00
B8F22C	2017-07-09 15:08:00+03	69000.00
B8F27B	2017-07-29 00:19:00+03	18400.00
B8F292	2017-07-21 00:06:00+03	324700.00
B8F2FD	2017-07-25 13:03:00+03	32800.00
B8F301	2017-07-14 03:38:00+03	14800.00
B8F334	2017-07-16 10:47:00+03	48500.00
B8F355	2017-08-05 01:48:00+03	70200.00
B8F3A4	2017-08-07 20:07:00+03	6700.00
B8F3CD	2017-07-07 06:02:00+03	52100.00
B8F3E2	2017-08-08 07:18:00+03	30200.00
B8F3E9	2017-08-05 10:10:00+03	6000.00
B8F3FD	2017-07-10 14:17:00+03	20600.00
B8F4E2	2017-08-11 17:07:00+03	58600.00
B8F4F3	2017-07-09 09:59:00+03	81300.00
B8F557	2017-07-15 03:43:00+03	75000.00
B8F575	2017-08-12 02:52:00+03	12600.00
B8F5C6	2017-07-22 09:41:00+03	32800.00
B8F5E2	2017-07-07 18:56:00+03	42800.00
B8F5E5	2017-07-27 06:56:00+03	77000.00
B8F5FD	2017-07-08 09:22:00+03	129700.00
B8F624	2017-07-25 15:26:00+03	59600.00
B8F625	2017-07-28 03:34:00+03	145500.00
B8F62E	2017-07-28 10:33:00+03	14400.00
B8F634	2017-08-06 04:07:00+03	46000.00
B8F63B	2017-07-02 11:48:00+03	31600.00
B8F66D	2017-07-27 12:11:00+03	69500.00
B8F6D4	2017-07-01 09:11:00+03	70800.00
B8F6E2	2017-07-26 19:07:00+03	119500.00
B8F76E	2017-07-05 22:04:00+03	91100.00
B8F7A4	2017-08-14 03:47:00+03	21500.00
B8F8D4	2017-07-07 14:36:00+03	6700.00
B8F936	2017-07-04 06:35:00+03	72400.00
B8F96C	2017-07-22 00:30:00+03	21800.00
B8F99F	2017-07-10 13:57:00+03	112000.00
B8FA27	2017-08-01 14:11:00+03	188900.00
B8FA7D	2017-07-03 08:32:00+03	147100.00
B8FAC6	2017-07-25 18:36:00+03	70700.00
B8FB47	2017-08-03 07:32:00+03	311200.00
B8FB94	2017-07-17 15:45:00+03	23200.00
B8FB9C	2017-07-27 05:04:00+03	187600.00
B8FBB0	2017-07-20 10:46:00+03	43600.00
B8FBD7	2017-07-03 17:43:00+03	28000.00
B8FC01	2017-07-29 19:59:00+03	105100.00
B8FC25	2017-07-22 21:21:00+03	271100.00
B8FC4B	2017-08-01 04:56:00+03	93900.00
B8FC6D	2017-08-08 03:51:00+03	44000.00
B8FC9D	2017-08-04 19:19:00+03	546800.00
B8FCFF	2017-07-24 05:14:00+03	41200.00
B8FD39	2017-07-04 20:39:00+03	406600.00
B8FDA1	2017-07-28 12:58:00+03	94100.00
B8FDA6	2017-07-06 17:34:00+03	26700.00
B8FDA7	2017-08-06 10:31:00+03	29200.00
B8FDB4	2017-08-12 18:31:00+03	137100.00
B8FDFB	2017-06-30 07:43:00+03	255600.00
B8FE60	2017-07-04 02:59:00+03	112000.00
B8FF16	2017-07-02 23:47:00+03	57300.00
B8FFAE	2017-07-06 17:34:00+03	173900.00
B901C6	2017-07-20 03:21:00+03	49100.00
B901E2	2017-08-12 19:56:00+03	114800.00
B90220	2017-07-13 03:41:00+03	40600.00
B902DF	2017-07-02 14:06:00+03	23200.00
B90308	2017-07-14 13:24:00+03	83700.00
B90311	2017-07-29 10:11:00+03	492000.00
B90468	2017-07-29 04:20:00+03	75600.00
B90505	2017-07-06 13:41:00+03	28600.00
B9053E	2017-07-19 11:28:00+03	168000.00
B905A2	2017-07-31 03:21:00+03	62600.00
B905C3	2017-08-09 21:08:00+03	40800.00
B9062E	2017-07-08 18:30:00+03	40800.00
B90646	2017-07-07 09:19:00+03	23200.00
B90658	2017-08-02 11:46:00+03	112000.00
B90677	2017-07-25 20:08:00+03	26200.00
B906B4	2017-07-11 23:54:00+03	54000.00
B906C2	2017-07-20 16:41:00+03	24800.00
B90732	2017-07-10 07:00:00+03	24400.00
B9074B	2017-08-08 17:49:00+03	27400.00
B90788	2017-07-14 01:53:00+03	56000.00
B907B2	2017-07-07 17:16:00+03	18600.00
B90845	2017-07-12 19:51:00+03	187600.00
B90883	2017-07-04 18:40:00+03	97600.00
B9089D	2017-08-02 23:52:00+03	79800.00
B908DA	2017-08-15 17:53:00+03	145200.00
B90911	2017-07-03 01:09:00+03	6300.00
B9091A	2017-07-28 23:28:00+03	34600.00
B90928	2017-07-30 18:30:00+03	184300.00
B90979	2017-07-24 09:31:00+03	99300.00
B909E2	2017-07-06 19:39:00+03	139100.00
B909E6	2017-08-04 02:25:00+03	179300.00
B90A1F	2017-08-05 02:59:00+03	122800.00
B90AD5	2017-07-15 21:25:00+03	46400.00
B90B6A	2017-08-14 03:31:00+03	47100.00
B90B78	2017-07-23 13:08:00+03	40000.00
B90B87	2017-07-14 19:28:00+03	19600.00
B90BAD	2017-07-20 05:16:00+03	58400.00
B90BF6	2017-06-30 18:36:00+03	88600.00
B90BFD	2017-07-21 22:07:00+03	161100.00
B90C30	2017-08-12 12:24:00+03	45200.00
B90C39	2017-07-25 17:13:00+03	15000.00
B90C5B	2017-08-10 20:31:00+03	102100.00
B90C77	2017-07-13 01:48:00+03	53700.00
B90C8E	2017-08-10 12:55:00+03	128800.00
B90CD3	2017-08-10 21:11:00+03	114600.00
B90DC2	2017-07-15 18:34:00+03	23100.00
B90DE1	2017-07-13 08:16:00+03	125100.00
B90DE8	2017-07-18 20:02:00+03	399600.00
B90E2C	2017-07-28 16:13:00+03	40600.00
B90E51	2017-06-30 23:00:00+03	147200.00
B90E60	2017-08-01 17:06:00+03	185500.00
B90FD8	2017-08-10 15:05:00+03	44600.00
B910A8	2017-08-10 02:33:00+03	55600.00
B910C5	2017-07-20 13:20:00+03	36200.00
B91175	2017-07-09 13:02:00+03	26000.00
B911AB	2017-08-11 23:34:00+03	102100.00
B911D6	2017-07-20 23:58:00+03	369000.00
B911F1	2017-07-29 09:12:00+03	43100.00
B91239	2017-07-23 18:34:00+03	58200.00
B91240	2017-08-02 19:59:00+03	35800.00
B912AF	2017-07-29 07:18:00+03	131800.00
B91351	2017-08-09 05:01:00+03	93700.00
B91374	2017-07-15 07:36:00+03	168200.00
B9139E	2017-07-18 10:44:00+03	29600.00
B913F9	2017-07-28 11:53:00+03	149300.00
B9140A	2017-07-04 18:29:00+03	46300.00
B91515	2017-07-09 23:52:00+03	117600.00
B9151C	2017-07-27 20:25:00+03	112700.00
B9151E	2017-08-03 04:14:00+03	77200.00
B91522	2017-07-18 08:08:00+03	28000.00
B9153F	2017-07-16 07:08:00+03	268500.00
B91558	2017-08-03 23:46:00+03	47400.00
B916C3	2017-08-08 17:26:00+03	30000.00
B916DB	2017-08-14 22:41:00+03	28000.00
B91707	2017-07-18 10:55:00+03	55800.00
B91748	2017-07-20 02:35:00+03	260300.00
B91785	2017-07-30 23:50:00+03	56000.00
B9179C	2017-07-24 13:25:00+03	134800.00
B917B1	2017-07-07 14:04:00+03	13400.00
B918A3	2017-07-15 20:39:00+03	44000.00
B918F6	2017-08-10 13:00:00+03	46400.00
B918FC	2017-08-11 14:10:00+03	51400.00
B9194C	2017-07-14 01:43:00+03	12600.00
B91968	2017-08-01 20:45:00+03	115700.00
B9197F	2017-08-01 10:55:00+03	27200.00
B91987	2017-08-01 10:21:00+03	179400.00
B919AF	2017-08-04 19:42:00+03	62700.00
B91A46	2017-07-26 14:11:00+03	50000.00
B91AF4	2017-07-11 02:43:00+03	35200.00
B91AF8	2017-08-15 13:53:00+03	14000.00
B91B0D	2017-06-29 15:39:00+03	40800.00
B91B27	2017-06-26 21:19:00+03	89600.00
B91B8A	2017-07-27 04:33:00+03	529200.00
B91BFB	2017-08-08 05:33:00+03	6000.00
B91C12	2017-08-03 12:34:00+03	29600.00
B91C16	2017-07-17 00:32:00+03	38900.00
B91C98	2017-08-04 14:35:00+03	26000.00
B91CCD	2017-07-16 00:57:00+03	26000.00
B91CD7	2017-07-25 00:55:00+03	25600.00
B91CF3	2017-07-29 18:28:00+03	62900.00
B91D16	2017-07-22 02:35:00+03	90000.00
B91D47	2017-08-13 13:10:00+03	57500.00
B91DF6	2017-08-08 18:03:00+03	92300.00
B91E5C	2017-08-10 18:54:00+03	112600.00
B91E6C	2017-07-27 12:27:00+03	105400.00
B91E96	2017-08-14 06:47:00+03	725400.00
B91EB9	2017-08-15 11:38:00+03	56000.00
B91F01	2017-07-26 02:54:00+03	28000.00
B91F65	2017-07-15 01:25:00+03	6000.00
B91FAA	2017-07-07 06:45:00+03	56000.00
B91FD9	2017-08-13 19:10:00+03	34100.00
B92006	2017-07-10 18:38:00+03	41600.00
B920BC	2017-07-29 12:06:00+03	59800.00
B92143	2017-07-14 00:04:00+03	30200.00
B921C6	2017-08-10 00:49:00+03	136200.00
B921DF	2017-08-15 01:35:00+03	14000.00
B921F7	2017-08-11 20:49:00+03	13300.00
B92208	2017-07-29 14:11:00+03	85600.00
B9220A	2017-07-14 13:44:00+03	123000.00
B922B7	2017-08-02 02:24:00+03	106500.00
B922B9	2017-07-01 23:51:00+03	92400.00
B922C8	2017-07-31 01:44:00+03	19000.00
B9231E	2017-07-05 04:18:00+03	28800.00
B9237F	2017-07-30 14:58:00+03	56600.00
B923AF	2017-07-27 05:40:00+03	24300.00
B92457	2017-08-15 13:14:00+03	34000.00
B9246D	2017-07-09 05:42:00+03	75300.00
B92477	2017-08-10 00:46:00+03	31100.00
B924C6	2017-07-06 01:32:00+03	223200.00
B924DD	2017-07-04 14:16:00+03	49000.00
B9254E	2017-08-10 14:02:00+03	114300.00
B9255A	2017-07-14 18:33:00+03	68400.00
B92595	2017-07-23 10:29:00+03	13800.00
B92619	2017-07-29 20:39:00+03	69600.00
B92630	2017-07-24 01:53:00+03	12400.00
B92635	2017-08-15 08:05:00+03	23600.00
B92638	2017-08-04 06:46:00+03	172100.00
B92644	2017-07-18 15:55:00+03	15000.00
B9266D	2017-07-29 10:49:00+03	48200.00
B926D6	2017-08-11 12:42:00+03	6700.00
B92703	2017-07-23 21:57:00+03	86800.00
B92781	2017-07-09 07:23:00+03	16400.00
B927F4	2017-08-02 16:18:00+03	12400.00
B927FB	2017-07-04 14:51:00+03	92800.00
B9280E	2017-07-07 02:24:00+03	73500.00
B92844	2017-07-26 10:57:00+03	33100.00
B92854	2017-07-26 05:41:00+03	34000.00
B928EF	2017-07-01 20:51:00+03	146600.00
B92902	2017-07-17 03:52:00+03	39500.00
B929D3	2017-08-07 22:58:00+03	105000.00
B92A0C	2017-08-14 08:39:00+03	40800.00
B92A3B	2017-08-06 15:56:00+03	12600.00
B92B03	2017-07-01 13:23:00+03	34700.00
B92B3D	2017-07-06 20:44:00+03	23200.00
B92B40	2017-07-22 22:54:00+03	37900.00
B92B42	2017-07-28 04:22:00+03	82200.00
B92B43	2017-06-30 19:18:00+03	56800.00
B92B44	2017-07-22 17:28:00+03	6000.00
B92B76	2017-08-05 18:00:00+03	44800.00
B92B79	2017-07-30 23:14:00+03	147000.00
B92B92	2017-08-03 13:23:00+03	59200.00
B92B97	2017-08-01 16:04:00+03	34000.00
B92BC0	2017-08-04 07:45:00+03	43600.00
B92C17	2017-07-05 05:24:00+03	24800.00
B92C1D	2017-08-02 11:24:00+03	116500.00
B92C89	2017-07-04 14:20:00+03	14400.00
B92C9E	2017-08-11 21:03:00+03	88100.00
B92CDF	2017-07-15 13:17:00+03	145400.00
B92CF5	2017-07-11 22:59:00+03	69700.00
B92D0D	2017-07-31 19:18:00+03	83800.00
B92D0F	2017-08-05 11:28:00+03	13600.00
B92D2B	2017-08-15 11:05:00+03	20000.00
B92D81	2017-07-24 19:45:00+03	152900.00
B92DED	2017-08-09 08:31:00+03	68100.00
B92E0C	2017-07-23 01:20:00+03	13000.00
B92EAB	2017-07-14 07:43:00+03	6700.00
B92ED2	2017-07-01 19:08:00+03	97100.00
B92F2D	2017-08-09 16:25:00+03	78100.00
B92F3B	2017-08-15 10:09:00+03	43900.00
B92F5D	2017-07-07 05:49:00+03	40600.00
B92F94	2017-08-09 10:50:00+03	46200.00
B92FD5	2017-08-12 16:15:00+03	31600.00
B9300A	2017-07-22 06:57:00+03	74700.00
B930B8	2017-07-06 20:27:00+03	88000.00
B930E8	2017-07-09 00:23:00+03	29600.00
B9315F	2017-08-05 01:13:00+03	139400.00
B93173	2017-07-24 11:19:00+03	38600.00
B93180	2017-08-07 18:47:00+03	84500.00
B931B2	2017-07-07 04:08:00+03	135600.00
B93298	2017-08-05 11:06:00+03	25800.00
B932D8	2017-07-12 19:55:00+03	40800.00
B932E1	2017-07-01 11:29:00+03	13600.00
B9330F	2017-07-03 17:13:00+03	13500.00
B93313	2017-07-14 05:12:00+03	67400.00
B93354	2017-08-03 15:45:00+03	6200.00
B93355	2017-08-08 07:41:00+03	96200.00
B93375	2017-07-15 08:28:00+03	109600.00
B93409	2017-07-26 21:27:00+03	25600.00
B93453	2017-07-09 10:07:00+03	15400.00
B93498	2017-07-30 03:35:00+03	117900.00
B934D7	2017-08-03 11:19:00+03	50600.00
B934E2	2017-07-22 10:57:00+03	92400.00
B93512	2017-08-03 05:55:00+03	93900.00
B9355A	2017-07-17 05:57:00+03	281500.00
B9356C	2017-07-31 04:59:00+03	175000.00
B93589	2017-08-11 02:05:00+03	38600.00
B9358B	2017-07-31 05:08:00+03	26000.00
B93591	2017-07-31 04:42:00+03	24400.00
B935CA	2017-07-28 21:58:00+03	13400.00
B9360A	2017-08-10 12:09:00+03	107200.00
B93641	2017-08-02 11:17:00+03	26000.00
B93698	2017-08-01 06:46:00+03	90800.00
B936B6	2017-07-21 20:08:00+03	25600.00
B936CF	2017-08-09 08:22:00+03	68100.00
B9376A	2017-07-15 02:15:00+03	17200.00
B937A1	2017-07-20 22:44:00+03	69000.00
B937C6	2017-08-03 00:13:00+03	30200.00
B93853	2017-07-25 23:24:00+03	14000.00
B938C1	2017-07-17 12:51:00+03	14400.00
B93905	2017-06-30 20:04:00+03	56100.00
B93926	2017-08-02 16:01:00+03	70100.00
B9394E	2017-06-27 17:40:00+03	45200.00
B9398B	2017-07-03 23:05:00+03	57700.00
B939A3	2017-07-03 04:54:00+03	133100.00
B939B7	2017-07-12 23:57:00+03	192000.00
B939CC	2017-07-20 05:01:00+03	48300.00
B93A5D	2017-07-24 03:09:00+03	111200.00
B93AB2	2017-07-02 10:40:00+03	26000.00
B93B20	2017-08-13 01:00:00+03	134400.00
B93B3E	2017-07-28 12:32:00+03	11600.00
B93BC6	2017-07-26 06:50:00+03	117600.00
B93C27	2017-07-18 16:47:00+03	85000.00
B93C7D	2017-07-07 13:31:00+03	16400.00
B93C94	2017-08-15 03:36:00+03	74900.00
B93CB7	2017-08-01 17:20:00+03	73600.00
B93CEA	2017-07-12 14:35:00+03	166000.00
B93CEE	2017-08-12 23:48:00+03	42700.00
B93D3B	2017-07-28 07:28:00+03	23200.00
B93D4D	2017-08-03 19:34:00+03	28000.00
B93DEA	2017-07-16 18:08:00+03	52000.00
B93E44	2017-08-13 23:33:00+03	75600.00
B93E88	2017-08-09 03:53:00+03	20900.00
B93E9C	2017-08-11 13:40:00+03	48800.00
B93F3D	2017-07-23 20:08:00+03	48800.00
B93F7E	2017-07-18 11:14:00+03	59300.00
B93FB3	2017-07-07 01:12:00+03	132800.00
B94016	2017-08-05 15:37:00+03	28800.00
B94042	2017-07-21 03:52:00+03	26600.00
B94058	2017-08-07 19:46:00+03	114600.00
B94132	2017-08-11 02:11:00+03	73900.00
B9415F	2017-07-21 06:29:00+03	32700.00
B9424D	2017-07-31 11:59:00+03	133100.00
B9427F	2017-07-22 03:49:00+03	65500.00
B943A9	2017-08-05 15:28:00+03	73200.00
B943C1	2017-07-08 19:27:00+03	65500.00
B94450	2017-07-28 15:19:00+03	6800.00
B9449A	2017-08-12 12:59:00+03	155600.00
B944B4	2017-07-26 03:09:00+03	148200.00
B944BD	2017-07-08 06:43:00+03	46200.00
B9451F	2017-07-16 05:31:00+03	177600.00
B94530	2017-07-05 10:40:00+03	50800.00
B94551	2017-07-06 06:01:00+03	22000.00
B945CA	2017-07-17 05:10:00+03	31400.00
B945D9	2017-07-02 21:51:00+03	57600.00
B94603	2017-08-15 15:47:00+03	28700.00
B94661	2017-07-10 04:39:00+03	57500.00
B9466D	2017-07-24 04:26:00+03	40600.00
B946A9	2017-06-30 23:12:00+03	52300.00
B94735	2017-07-09 19:12:00+03	43200.00
B94745	2017-07-21 00:19:00+03	41600.00
B947DC	2017-07-16 21:09:00+03	68800.00
B94886	2017-08-09 13:26:00+03	40800.00
B9488C	2017-08-13 00:24:00+03	75700.00
B949CB	2017-08-14 20:47:00+03	24700.00
B949E0	2017-07-18 03:16:00+03	28800.00
B94AD2	2017-08-13 06:30:00+03	37000.00
B94B22	2017-07-07 13:56:00+03	111600.00
B94B37	2017-07-18 07:48:00+03	68100.00
B94C0B	2017-07-02 16:47:00+03	49000.00
B94C50	2017-08-04 10:30:00+03	193700.00
B94C93	2017-07-21 19:55:00+03	16400.00
B94C9A	2017-08-08 03:01:00+03	135400.00
B94CB0	2017-07-24 23:42:00+03	11700.00
B94CCE	2017-07-28 08:25:00+03	73500.00
B94D2C	2017-07-24 10:49:00+03	79600.00
B94D53	2017-07-06 02:10:00+03	202100.00
B94D90	2017-08-09 14:23:00+03	111600.00
B94DBA	2017-07-30 08:56:00+03	127400.00
B94DE5	2017-07-31 23:08:00+03	111600.00
B94E3E	2017-07-11 01:52:00+03	172600.00
B94E61	2017-07-26 05:25:00+03	136200.00
B94EC6	2017-08-13 04:14:00+03	16400.00
B94EF2	2017-06-27 01:34:00+03	26000.00
B94FA0	2017-07-13 09:50:00+03	56900.00
B94FA8	2017-06-29 13:16:00+03	31100.00
B94FC5	2017-08-11 08:43:00+03	169900.00
B95027	2017-07-21 16:36:00+03	79100.00
B9503C	2017-07-14 13:52:00+03	62600.00
B9504D	2017-08-12 00:46:00+03	74800.00
B950C3	2017-08-06 16:27:00+03	44600.00
B95107	2017-07-16 10:48:00+03	123000.00
B95139	2017-08-11 22:52:00+03	29000.00
B95173	2017-07-22 15:08:00+03	16400.00
B95198	2017-08-01 07:41:00+03	51900.00
B9519B	2017-08-09 11:48:00+03	54000.00
B951CB	2017-08-15 14:51:00+03	13600.00
B951EC	2017-08-01 01:01:00+03	36200.00
B95209	2017-07-11 16:49:00+03	492000.00
B9520D	2017-07-21 07:17:00+03	27800.00
B95251	2017-07-31 20:55:00+03	91300.00
B9528B	2017-07-28 01:39:00+03	16400.00
B95293	2017-07-08 19:47:00+03	24700.00
B9529C	2017-07-17 09:31:00+03	116800.00
B952F0	2017-08-08 09:44:00+03	227600.00
B9530D	2017-08-05 23:49:00+03	25400.00
B95335	2017-07-15 06:25:00+03	168000.00
B95350	2017-07-27 17:24:00+03	20000.00
B9537B	2017-07-10 23:42:00+03	38300.00
B953AC	2017-08-06 13:42:00+03	28800.00
B95424	2017-07-23 00:09:00+03	21600.00
B9543F	2017-08-11 03:25:00+03	54400.00
B95447	2017-08-02 19:32:00+03	14700.00
B9545C	2017-07-01 20:34:00+03	92800.00
B95473	2017-07-05 04:09:00+03	114800.00
B954FC	2017-07-14 20:55:00+03	69500.00
B954FE	2017-08-10 03:42:00+03	248300.00
B9554D	2017-07-23 14:38:00+03	21400.00
B95559	2017-07-18 06:34:00+03	67200.00
B955A0	2017-07-06 06:46:00+03	23200.00
B956B9	2017-07-28 12:52:00+03	94300.00
B957AE	2017-07-25 06:51:00+03	145200.00
B957E2	2017-08-02 06:27:00+03	52700.00
B95869	2017-08-07 09:49:00+03	36100.00
B9588D	2017-08-08 16:50:00+03	75300.00
B958EA	2017-07-25 09:39:00+03	134800.00
B9594B	2017-07-06 13:42:00+03	36200.00
B9599A	2017-07-27 21:13:00+03	146300.00
B959C5	2017-08-08 01:35:00+03	38800.00
B95A04	2017-07-07 15:44:00+03	62600.00
B95A0D	2017-07-30 15:33:00+03	15000.00
B95A14	2017-07-25 11:41:00+03	193200.00
B95A6C	2017-07-12 03:20:00+03	54000.00
B95ABB	2017-08-06 05:16:00+03	73300.00
B95ADD	2017-07-25 22:30:00+03	23600.00
B95B06	2017-08-14 05:50:00+03	264000.00
B95B49	2017-08-10 19:17:00+03	94700.00
B95C2E	2017-06-28 17:23:00+03	29000.00
B95C55	2017-07-28 15:13:00+03	22000.00
B95C58	2017-08-15 15:25:00+03	67100.00
B95C8D	2017-07-05 12:25:00+03	6000.00
B95CBD	2017-08-05 18:15:00+03	111600.00
B95D63	2017-08-06 17:41:00+03	56000.00
B95D6D	2017-07-31 11:48:00+03	10800.00
B95D7F	2017-07-24 07:01:00+03	11600.00
B95E0B	2017-07-18 03:25:00+03	46400.00
B95E9E	2017-06-28 19:46:00+03	101200.00
B95EBD	2017-07-25 23:16:00+03	203000.00
B95F3D	2017-07-11 18:16:00+03	100600.00
B95FCA	2017-08-13 01:09:00+03	222800.00
B95FF2	2017-07-06 00:36:00+03	42400.00
B9601A	2017-07-31 13:52:00+03	52000.00
B960A0	2017-07-01 01:48:00+03	46000.00
B960D8	2017-08-10 05:37:00+03	14000.00
B9616C	2017-08-12 03:59:00+03	89700.00
B9617E	2017-08-10 00:57:00+03	281500.00
B961B4	2017-08-10 04:14:00+03	37300.00
B961FA	2017-07-23 13:35:00+03	112600.00
B9620E	2017-07-14 13:04:00+03	16000.00
B96232	2017-06-29 07:22:00+03	14000.00
B96249	2017-07-18 18:08:00+03	55800.00
B962C3	2017-07-13 12:49:00+03	26000.00
B962FC	2017-08-11 07:13:00+03	492000.00
B96311	2017-07-19 07:14:00+03	77000.00
B9632F	2017-08-13 20:57:00+03	140900.00
B9635F	2017-07-28 10:46:00+03	55800.00
B963D3	2017-08-03 04:37:00+03	266200.00
B963DC	2017-07-31 13:04:00+03	18000.00
B963E4	2017-07-20 06:56:00+03	39200.00
B96417	2017-07-28 19:53:00+03	71900.00
B96427	2017-07-27 00:12:00+03	28400.00
B96465	2017-07-11 06:36:00+03	18800.00
B964C8	2017-07-26 00:12:00+03	61200.00
B964D5	2017-08-08 03:56:00+03	52700.00
B964F7	2017-08-05 21:49:00+03	61800.00
B9651A	2017-08-14 15:58:00+03	40600.00
B9651B	2017-07-21 01:23:00+03	30800.00
B96520	2017-06-28 02:53:00+03	28000.00
B96525	2017-07-30 22:07:00+03	47500.00
B96529	2017-08-07 19:58:00+03	38800.00
B965D2	2017-07-13 22:56:00+03	400900.00
B96662	2017-07-12 20:43:00+03	95200.00
B966DA	2017-07-03 14:57:00+03	30200.00
B966F9	2017-07-21 01:32:00+03	177200.00
B96702	2017-07-21 17:26:00+03	33100.00
B9670D	2017-08-01 14:05:00+03	16400.00
B96721	2017-08-08 11:00:00+03	43600.00
B96737	2017-08-12 11:22:00+03	88900.00
B967CE	2017-07-02 04:49:00+03	47000.00
B967DE	2017-08-11 19:54:00+03	75300.00
B967E4	2017-08-06 17:44:00+03	58600.00
B967FE	2017-07-06 02:56:00+03	33600.00
B9680F	2017-08-08 21:37:00+03	37200.00
B96849	2017-07-29 04:01:00+03	24500.00
B968C4	2017-08-11 02:17:00+03	123000.00
B968DC	2017-07-23 17:41:00+03	105600.00
B96955	2017-07-06 20:34:00+03	19600.00
B96960	2017-07-21 09:31:00+03	38600.00
B96983	2017-08-01 18:35:00+03	28000.00
B96991	2017-07-19 12:25:00+03	84500.00
B969A4	2017-07-27 08:28:00+03	28000.00
B969EF	2017-07-08 08:55:00+03	66600.00
B96A22	2017-07-23 22:00:00+03	26000.00
B96A85	2017-08-06 21:49:00+03	14800.00
B96ABD	2017-07-11 01:20:00+03	17800.00
B96B25	2017-08-11 05:32:00+03	20200.00
B96B26	2017-07-16 10:19:00+03	113200.00
B96C26	2017-07-16 13:10:00+03	47000.00
B96C5C	2017-07-21 22:40:00+03	35200.00
B96C9A	2017-07-31 16:01:00+03	189200.00
B96CEA	2017-07-07 15:18:00+03	41400.00
B96CF1	2017-07-07 09:06:00+03	25000.00
B96D1A	2017-07-04 17:10:00+03	103600.00
B96D80	2017-08-14 01:55:00+03	46000.00
B96D84	2017-08-13 18:18:00+03	176500.00
B96D96	2017-08-10 06:25:00+03	31100.00
B96DC9	2017-08-10 18:39:00+03	170500.00
B96DE6	2017-07-21 17:58:00+03	28000.00
B96DF7	2017-07-08 08:40:00+03	46500.00
B96E30	2017-07-02 18:58:00+03	133200.00
B96E5D	2017-07-23 21:26:00+03	32400.00
B96E9A	2017-08-10 04:36:00+03	25800.00
B96EB5	2017-07-10 00:15:00+03	54400.00
B96F02	2017-08-14 00:05:00+03	26600.00
B96F5F	2017-07-06 12:26:00+03	249100.00
B96F61	2017-07-20 03:41:00+03	46300.00
B96FB6	2017-07-27 11:08:00+03	28000.00
B96FDA	2017-07-22 05:54:00+03	52700.00
B96FEB	2017-07-25 00:24:00+03	114800.00
B97006	2017-07-12 13:23:00+03	14400.00
B97041	2017-08-09 02:02:00+03	56000.00
B97055	2017-07-28 14:09:00+03	33300.00
B97058	2017-08-12 02:33:00+03	68400.00
B9713C	2017-08-15 11:15:00+03	68400.00
B971EF	2017-07-06 13:13:00+03	54500.00
B9721A	2017-08-10 04:51:00+03	244600.00
B97246	2017-07-29 15:47:00+03	84100.00
B97472	2017-07-03 20:12:00+03	45100.00
B974D4	2017-08-03 20:34:00+03	30000.00
B97506	2017-08-11 18:57:00+03	28800.00
B97533	2017-07-25 00:24:00+03	44000.00
B97555	2017-07-28 09:40:00+03	38400.00
B9756B	2017-07-24 12:51:00+03	28800.00
B9757F	2017-07-17 12:11:00+03	116900.00
B97582	2017-07-25 02:25:00+03	24400.00
B975C6	2017-08-15 16:08:00+03	109700.00
B975D7	2017-07-28 02:33:00+03	24400.00
B97663	2017-08-01 06:09:00+03	139300.00
B9769C	2017-08-08 18:18:00+03	45100.00
B976CB	2017-07-05 07:03:00+03	28800.00
B976F6	2017-07-26 15:50:00+03	102100.00
B976FE	2017-08-15 16:03:00+03	57500.00
B9775A	2017-08-09 10:46:00+03	50600.00
B97770	2017-08-08 14:28:00+03	93400.00
B97782	2017-07-11 04:11:00+03	28400.00
B977DF	2017-07-05 14:58:00+03	87900.00
B977F6	2017-07-07 10:41:00+03	148200.00
B97828	2017-08-13 19:14:00+03	38600.00
B97844	2017-07-21 06:17:00+03	46400.00
B9785E	2017-07-04 11:36:00+03	45200.00
B978EB	2017-07-16 20:05:00+03	6800.00
B9790C	2017-08-11 14:22:00+03	240600.00
B97925	2017-08-04 14:09:00+03	72400.00
B9793D	2017-07-20 11:52:00+03	85600.00
B97961	2017-06-29 18:57:00+03	35200.00
B979C4	2017-07-15 04:20:00+03	44000.00
B979D1	2017-08-03 16:12:00+03	73200.00
B979E2	2017-08-07 11:34:00+03	47600.00
B97A16	2017-07-21 19:21:00+03	23200.00
B97A27	2017-08-06 04:47:00+03	66300.00
B97A7C	2017-06-27 15:48:00+03	75800.00
B97A8B	2017-07-02 22:47:00+03	51800.00
B97A91	2017-07-28 17:41:00+03	14400.00
B97AD0	2017-07-12 17:38:00+03	57500.00
B97B5B	2017-07-24 04:42:00+03	75800.00
B97B7A	2017-07-01 10:58:00+03	92800.00
B97B96	2017-07-07 17:11:00+03	22600.00
B97BD7	2017-07-01 23:01:00+03	291000.00
B97BF2	2017-07-04 07:31:00+03	56600.00
B97C28	2017-07-07 06:59:00+03	56000.00
B97D0B	2017-07-24 03:54:00+03	90400.00
B97D43	2017-07-20 16:03:00+03	62700.00
B97D75	2017-08-07 13:14:00+03	91200.00
B97DCB	2017-07-15 11:39:00+03	21800.00
B97E5D	2017-07-19 03:37:00+03	35200.00
B97EC0	2017-08-15 01:53:00+03	54100.00
B97F68	2017-08-15 06:00:00+03	54800.00
B97F71	2017-08-13 14:31:00+03	288600.00
B97F83	2017-08-06 03:46:00+03	24200.00
B97FAD	2017-07-20 02:19:00+03	47500.00
B97FFD	2017-08-05 03:50:00+03	18800.00
B9801D	2017-06-28 17:57:00+03	34000.00
B980C9	2017-07-30 16:41:00+03	119400.00
B98101	2017-07-17 03:58:00+03	20400.00
B98102	2017-07-21 21:22:00+03	204700.00
B98105	2017-07-09 09:05:00+03	13400.00
B9815D	2017-08-06 14:53:00+03	116000.00
B98173	2017-08-08 07:40:00+03	28000.00
B9818A	2017-07-16 19:31:00+03	48800.00
B9818F	2017-07-14 09:52:00+03	94000.00
B981BB	2017-08-14 08:57:00+03	23900.00
B981C7	2017-07-23 06:33:00+03	248500.00
B981D1	2017-07-10 09:48:00+03	34000.00
B981DF	2017-07-10 21:02:00+03	111600.00
B981EB	2017-07-24 04:43:00+03	85700.00
B981EC	2017-08-13 00:03:00+03	8200.00
B981F9	2017-07-06 03:20:00+03	199700.00
B9827D	2017-07-13 07:27:00+03	40900.00
B98283	2017-07-07 00:41:00+03	55800.00
B98286	2017-07-28 14:38:00+03	46800.00
B9829D	2017-08-04 04:46:00+03	42400.00
B98304	2017-07-28 16:32:00+03	21800.00
B9836C	2017-07-18 02:04:00+03	131100.00
B98389	2017-07-10 11:08:00+03	60400.00
B98433	2017-07-20 07:22:00+03	53100.00
B9844C	2017-08-13 18:59:00+03	260300.00
B984FD	2017-07-30 04:08:00+03	32100.00
B9851A	2017-07-29 03:17:00+03	167400.00
B9855C	2017-07-18 12:21:00+03	74100.00
B9857C	2017-06-30 21:09:00+03	23100.00
B98580	2017-08-03 21:32:00+03	43500.00
B9858A	2017-07-27 22:30:00+03	75600.00
B98639	2017-07-21 16:26:00+03	29200.00
B98674	2017-07-11 15:06:00+03	16400.00
B98681	2017-07-05 09:04:00+03	32200.00
B986E0	2017-07-25 15:00:00+03	57500.00
B986F3	2017-07-11 18:31:00+03	85700.00
B98712	2017-08-14 03:47:00+03	26800.00
B987A9	2017-07-06 03:34:00+03	547000.00
B987EB	2017-08-02 02:09:00+03	23100.00
B98848	2017-08-11 06:14:00+03	29600.00
B98864	2017-08-02 21:06:00+03	184300.00
B988CC	2017-07-07 10:03:00+03	92200.00
B988F9	2017-07-07 18:55:00+03	121800.00
B98936	2017-07-20 17:34:00+03	78600.00
B9893B	2017-07-16 16:34:00+03	54800.00
B9897C	2017-07-21 21:34:00+03	83200.00
B98A4C	2017-07-25 05:34:00+03	85000.00
B98A57	2017-07-21 19:27:00+03	385000.00
B98A79	2017-08-08 02:19:00+03	344100.00
B98A90	2017-07-17 16:09:00+03	28000.00
B98AE4	2017-07-18 05:11:00+03	47400.00
B98AFC	2017-08-15 16:18:00+03	27800.00
B98B28	2017-07-12 16:19:00+03	79200.00
B98B5F	2017-08-14 22:49:00+03	147800.00
B98B94	2017-07-29 09:47:00+03	39300.00
B98BC4	2017-06-28 07:13:00+03	40800.00
B98BDE	2017-08-02 04:15:00+03	21400.00
B98BE0	2017-08-08 21:38:00+03	27300.00
B98CAA	2017-07-23 05:17:00+03	12600.00
B98CB5	2017-07-07 11:00:00+03	39300.00
B98D66	2017-08-10 10:46:00+03	95000.00
B98D77	2017-07-21 22:51:00+03	47200.00
B98D9A	2017-07-14 12:24:00+03	69100.00
B98DBA	2017-07-02 17:41:00+03	133700.00
B98E63	2017-08-11 22:04:00+03	128800.00
B98EA5	2017-08-03 16:59:00+03	14000.00
B98EEC	2017-08-08 08:46:00+03	515100.00
B98F53	2017-06-27 09:41:00+03	26000.00
B98FBA	2017-07-17 11:38:00+03	63200.00
B98FF5	2017-08-10 04:47:00+03	39200.00
B99047	2017-08-13 14:09:00+03	42800.00
B9912B	2017-07-31 14:31:00+03	98700.00
B9913B	2017-07-22 20:39:00+03	51800.00
B99161	2017-07-18 02:58:00+03	37700.00
B99174	2017-06-27 04:57:00+03	7400.00
B991D6	2017-07-02 23:27:00+03	39200.00
B991F6	2017-07-20 01:34:00+03	20200.00
B991FE	2017-08-10 13:22:00+03	48800.00
B99205	2017-07-08 19:50:00+03	28000.00
B9923E	2017-08-12 23:35:00+03	47400.00
B99250	2017-08-13 04:57:00+03	72600.00
B99296	2017-07-12 14:07:00+03	46200.00
B99356	2017-07-03 08:24:00+03	68800.00
B993A7	2017-08-08 16:14:00+03	106700.00
B993BA	2017-07-30 12:13:00+03	78300.00
B993CE	2017-07-01 23:15:00+03	48800.00
B99454	2017-07-25 19:14:00+03	57500.00
B994D4	2017-08-13 10:15:00+03	133100.00
B994EA	2017-08-15 11:02:00+03	187400.00
B994F5	2017-07-17 06:36:00+03	19600.00
B9953A	2017-07-24 13:47:00+03	402100.00
B99583	2017-07-02 01:30:00+03	266400.00
B995B6	2017-07-29 08:33:00+03	51900.00
B995D3	2017-07-20 11:25:00+03	25800.00
B995D7	2017-07-27 14:34:00+03	81200.00
B9963E	2017-07-04 22:58:00+03	96400.00
B99644	2017-08-13 04:07:00+03	35400.00
B99687	2017-08-11 06:16:00+03	391000.00
B996A2	2017-07-07 21:04:00+03	43000.00
B996D8	2017-08-03 17:43:00+03	27800.00
B996E3	2017-08-05 19:40:00+03	54600.00
B9971C	2017-07-17 06:29:00+03	35200.00
B9971E	2017-07-10 01:20:00+03	121900.00
B99790	2017-07-28 20:00:00+03	58500.00
B9979E	2017-08-09 20:44:00+03	111600.00
B99813	2017-07-24 02:59:00+03	24700.00
B99818	2017-07-13 02:28:00+03	126800.00
B99841	2017-07-01 15:48:00+03	47200.00
B99865	2017-07-18 17:18:00+03	66600.00
B998C1	2017-07-24 00:43:00+03	62800.00
B99903	2017-08-09 17:50:00+03	79900.00
B99932	2017-08-04 11:20:00+03	36200.00
B99952	2017-08-04 10:44:00+03	36200.00
B9996D	2017-07-25 03:31:00+03	70400.00
B999F7	2017-07-13 12:14:00+03	14000.00
B99A71	2017-08-08 15:17:00+03	41600.00
B99A82	2017-07-25 10:53:00+03	59300.00
B99AED	2017-07-28 05:38:00+03	133200.00
B99B9F	2017-08-03 12:38:00+03	28200.00
B99BC7	2017-08-11 13:50:00+03	100800.00
B99BF9	2017-07-21 05:14:00+03	59400.00
B99C41	2017-07-17 05:17:00+03	28800.00
B99C96	2017-07-22 16:03:00+03	71900.00
B99CBA	2017-07-28 18:55:00+03	120700.00
B99CE4	2017-07-16 08:17:00+03	74600.00
B99D5B	2017-08-11 06:08:00+03	56000.00
B99D63	2017-07-24 11:56:00+03	26700.00
B99D70	2017-07-02 15:19:00+03	39400.00
B99DB0	2017-07-03 06:48:00+03	96800.00
B99E03	2017-07-10 23:49:00+03	23200.00
B99E1F	2017-06-29 03:02:00+03	418500.00
B99E26	2017-06-24 14:36:00+03	118200.00
B99EF2	2017-07-20 17:55:00+03	48800.00
B99F23	2017-07-24 22:17:00+03	25100.00
B99F48	2017-07-16 22:13:00+03	51600.00
B99F4B	2017-07-13 22:01:00+03	56200.00
B9A066	2017-08-09 03:34:00+03	23400.00
B9A074	2017-07-05 09:15:00+03	166000.00
B9A0F3	2017-07-02 23:27:00+03	12600.00
B9A0F7	2017-07-20 18:00:00+03	40000.00
B9A16C	2017-08-08 20:04:00+03	95200.00
B9A1B5	2017-07-11 10:38:00+03	46400.00
B9A1C2	2017-08-06 06:09:00+03	89700.00
B9A2C3	2017-08-14 04:58:00+03	13600.00
B9A2D8	2017-08-11 06:12:00+03	142400.00
B9A2DB	2017-08-12 03:32:00+03	42600.00
B9A323	2017-07-04 07:53:00+03	191200.00
B9A394	2017-07-03 13:12:00+03	84400.00
B9A40F	2017-08-15 09:12:00+03	68000.00
B9A475	2017-07-30 01:12:00+03	21800.00
B9A49C	2017-08-03 07:54:00+03	31400.00
B9A4E9	2017-07-24 05:49:00+03	30200.00
B9A527	2017-08-03 08:37:00+03	43200.00
B9A5AB	2017-07-18 23:10:00+03	30200.00
B9A5BC	2017-07-23 12:35:00+03	46000.00
B9A5C9	2017-07-06 05:00:00+03	55600.00
B9A5EE	2017-07-23 11:11:00+03	32800.00
B9A608	2017-08-11 09:55:00+03	33600.00
B9A638	2017-08-15 16:33:00+03	27600.00
B9A645	2017-07-14 01:03:00+03	93400.00
B9A648	2017-07-23 03:22:00+03	32200.00
B9A673	2017-07-16 18:59:00+03	87300.00
B9A710	2017-07-06 09:06:00+03	189200.00
B9A74B	2017-07-04 14:53:00+03	46200.00
B9A767	2017-07-17 13:38:00+03	149600.00
B9A77A	2017-07-01 09:16:00+03	8000.00
B9A792	2017-08-10 13:12:00+03	147500.00
B9A7CA	2017-07-08 11:45:00+03	54400.00
B9A7ED	2017-07-31 02:56:00+03	74800.00
B9A81B	2017-08-06 17:03:00+03	169300.00
B9A831	2017-08-08 08:16:00+03	81900.00
B9A846	2017-08-10 11:04:00+03	47200.00
B9A85C	2017-08-13 17:54:00+03	151200.00
B9A882	2017-07-04 17:19:00+03	148100.00
B9A887	2017-08-05 19:24:00+03	135600.00
B9A8BD	2017-08-01 03:57:00+03	38800.00
B9A8E6	2017-07-04 04:27:00+03	47400.00
B9A9B1	2017-08-12 22:19:00+03	97200.00
B9A9BE	2017-07-31 16:24:00+03	55800.00
B9A9CD	2017-08-01 06:39:00+03	12000.00
B9A9F6	2017-07-05 09:41:00+03	31200.00
B9AA17	2017-07-21 03:41:00+03	59200.00
B9AA21	2017-08-12 03:09:00+03	63000.00
B9AA26	2017-08-14 17:10:00+03	88800.00
B9AA5A	2017-07-07 16:26:00+03	51300.00
B9AABF	2017-07-26 09:04:00+03	246000.00
B9AB0B	2017-07-03 14:49:00+03	24700.00
B9AB18	2017-07-09 22:58:00+03	23400.00
B9AB29	2017-08-09 16:39:00+03	61500.00
B9AB5A	2017-08-15 15:35:00+03	260300.00
B9AB9B	2017-07-26 18:58:00+03	59000.00
B9ABB6	2017-08-06 00:21:00+03	40200.00
B9AC70	2017-07-28 22:20:00+03	53600.00
B9ACA2	2017-07-17 03:58:00+03	64800.00
B9ACDB	2017-07-31 04:12:00+03	144100.00
B9AD1C	2017-07-28 20:37:00+03	101200.00
B9AD74	2017-07-20 08:32:00+03	81600.00
B9ADCE	2017-07-13 01:52:00+03	26600.00
B9ADEB	2017-08-03 02:34:00+03	131600.00
B9ADF4	2017-07-31 13:47:00+03	56000.00
B9AE6D	2017-08-04 21:59:00+03	21800.00
B9AE8B	2017-07-22 05:05:00+03	9800.00
B9AEE3	2017-07-11 10:39:00+03	117600.00
B9AEF8	2017-08-15 02:13:00+03	59300.00
B9AF01	2017-07-31 17:13:00+03	37500.00
B9AF23	2017-08-02 20:30:00+03	37200.00
B9AF2A	2017-08-02 15:42:00+03	266400.00
B9AF5D	2017-07-21 11:45:00+03	12600.00
B9AF78	2017-07-22 20:12:00+03	81200.00
B9B010	2017-07-07 21:08:00+03	196800.00
B9B049	2017-08-12 05:35:00+03	260300.00
B9B06B	2017-07-10 14:54:00+03	40600.00
B9B09B	2017-07-03 11:45:00+03	24400.00
B9B124	2017-07-25 22:40:00+03	606200.00
B9B12B	2017-07-29 06:27:00+03	49100.00
B9B132	2017-07-31 10:42:00+03	25600.00
B9B189	2017-08-06 23:45:00+03	160600.00
B9B1A0	2017-07-12 17:18:00+03	39000.00
B9B1B1	2017-06-28 18:45:00+03	28800.00
B9B268	2017-07-14 05:12:00+03	58000.00
B9B29A	2017-07-24 22:48:00+03	28000.00
B9B2D4	2017-07-30 12:32:00+03	12000.00
B9B308	2017-07-07 02:01:00+03	49800.00
B9B313	2017-07-04 01:12:00+03	170200.00
B9B31F	2017-07-20 08:27:00+03	187600.00
B9B32B	2017-08-04 23:12:00+03	110300.00
B9B345	2017-06-24 12:08:00+03	78000.00
B9B34F	2017-07-09 09:55:00+03	76600.00
B9B423	2017-07-23 05:49:00+03	62600.00
B9B48F	2017-07-17 10:05:00+03	11800.00
B9B4AF	2017-07-05 04:11:00+03	314400.00
B9B4C9	2017-08-11 18:17:00+03	18600.00
B9B4D3	2017-08-08 23:33:00+03	9300.00
B9B4EC	2017-07-20 12:59:00+03	32700.00
B9B4EE	2017-08-01 01:13:00+03	283900.00
B9B4FB	2017-06-28 22:45:00+03	151200.00
B9B5C4	2017-07-24 19:39:00+03	88300.00
B9B62F	2017-08-08 05:04:00+03	265700.00
B9B659	2017-08-02 14:14:00+03	214900.00
B9B678	2017-08-01 15:45:00+03	16300.00
B9B686	2017-07-26 13:45:00+03	18000.00
B9B6CE	2017-07-02 19:09:00+03	21800.00
B9B6E6	2017-07-28 03:06:00+03	50000.00
B9B6FF	2017-07-08 13:49:00+03	13800.00
B9B700	2017-07-28 14:05:00+03	62600.00
B9B7A6	2017-07-16 11:09:00+03	7400.00
B9B7F9	2017-06-30 23:53:00+03	30200.00
B9B80A	2017-07-05 03:29:00+03	6700.00
B9B80E	2017-07-22 22:01:00+03	111600.00
B9B88B	2017-08-14 07:15:00+03	48700.00
B9B897	2017-07-09 01:43:00+03	123600.00
B9B8A7	2017-07-18 16:14:00+03	89600.00
B9B8BD	2017-06-28 16:52:00+03	32800.00
B9B93C	2017-07-27 16:27:00+03	36200.00
B9B96F	2017-07-30 23:17:00+03	38600.00
B9B9B8	2017-07-03 16:37:00+03	12600.00
B9BA00	2017-08-13 04:38:00+03	167400.00
B9BA5B	2017-07-16 14:29:00+03	133100.00
B9BA75	2017-07-10 19:19:00+03	144400.00
B9BA82	2017-07-17 20:48:00+03	31200.00
B9BAB3	2017-07-26 12:49:00+03	35200.00
B9BACC	2017-08-03 17:22:00+03	46400.00
B9BB32	2017-08-10 06:46:00+03	70400.00
B9BB3D	2017-08-13 17:54:00+03	31600.00
B9BB47	2017-07-23 08:38:00+03	36200.00
B9BB53	2017-08-12 12:52:00+03	184300.00
B9BB65	2017-07-27 11:06:00+03	44800.00
B9BBF5	2017-07-31 15:05:00+03	27200.00
B9BC18	2017-07-28 07:18:00+03	65900.00
B9BCDE	2017-07-31 22:18:00+03	18000.00
B9BD4B	2017-08-01 10:46:00+03	23200.00
B9BD94	2017-07-31 18:14:00+03	258600.00
B9BDB5	2017-07-28 04:21:00+03	48500.00
B9BDB7	2017-07-30 22:07:00+03	38600.00
B9BDEA	2017-08-09 00:18:00+03	77200.00
B9BE31	2017-08-12 16:30:00+03	24700.00
B9BE6C	2017-07-13 15:45:00+03	19600.00
B9BE7E	2017-07-01 05:57:00+03	48800.00
B9BE83	2017-07-10 15:52:00+03	29800.00
B9BEB3	2017-07-30 14:27:00+03	44800.00
B9BECE	2017-07-17 14:46:00+03	11600.00
B9BF41	2017-07-30 21:51:00+03	37200.00
B9C01D	2017-07-15 14:33:00+03	51900.00
B9C074	2017-08-07 14:02:00+03	22100.00
B9C076	2017-06-29 08:05:00+03	38600.00
B9C0CF	2017-07-11 08:52:00+03	68100.00
B9C0F0	2017-07-17 18:38:00+03	34100.00
B9C0F7	2017-07-24 15:39:00+03	78400.00
B9C0FF	2017-07-26 16:47:00+03	62800.00
B9C149	2017-07-29 17:06:00+03	140400.00
B9C168	2017-07-29 09:31:00+03	185300.00
B9C1D9	2017-07-14 09:16:00+03	46400.00
B9C1E5	2017-07-23 22:06:00+03	64100.00
B9C1F6	2017-07-03 18:17:00+03	70400.00
B9C245	2017-07-26 05:28:00+03	202200.00
B9C267	2017-07-24 22:50:00+03	6700.00
B9C322	2017-07-30 22:43:00+03	132800.00
B9C342	2017-07-14 08:57:00+03	70600.00
B9C3A8	2017-07-25 11:24:00+03	26000.00
B9C3A9	2017-08-13 06:43:00+03	13400.00
B9C470	2017-07-06 03:27:00+03	192300.00
B9C48A	2017-07-28 03:49:00+03	77900.00
B9C4A8	2017-08-07 11:21:00+03	56600.00
B9C4CA	2017-07-24 18:49:00+03	38800.00
B9C581	2017-07-10 00:15:00+03	36200.00
B9C5D2	2017-08-08 20:23:00+03	105300.00
B9C634	2017-08-09 00:24:00+03	19600.00
B9C70F	2017-07-12 09:04:00+03	75600.00
B9C716	2017-08-13 02:15:00+03	19800.00
B9C73C	2017-08-01 02:42:00+03	48700.00
B9C76C	2017-07-05 07:57:00+03	270200.00
B9C7C6	2017-08-01 19:04:00+03	173400.00
B9C836	2017-07-20 19:29:00+03	23600.00
B9C8B0	2017-08-03 14:00:00+03	41800.00
B9C8DD	2017-08-09 06:45:00+03	20000.00
B9C918	2017-08-02 06:20:00+03	284400.00
B9C942	2017-08-14 00:17:00+03	26700.00
B9C98C	2017-07-11 17:28:00+03	28800.00
B9C98D	2017-07-02 21:36:00+03	62600.00
B9CA03	2017-08-11 15:55:00+03	50000.00
B9CA26	2017-08-09 04:07:00+03	31900.00
B9CA69	2017-07-20 23:43:00+03	14800.00
B9CACF	2017-08-02 12:19:00+03	56000.00
B9CBFD	2017-07-17 14:23:00+03	88300.00
B9CC23	2017-07-04 19:46:00+03	35500.00
B9CC6F	2017-08-04 18:31:00+03	82900.00
B9CD10	2017-07-09 16:11:00+03	19600.00
B9CD12	2017-07-31 08:18:00+03	15700.00
B9CD20	2017-08-06 22:34:00+03	79900.00
B9CD68	2017-07-11 17:50:00+03	31200.00
B9CD6D	2017-07-13 18:49:00+03	130800.00
B9CD89	2017-07-14 04:19:00+03	46000.00
B9CDBE	2017-07-02 18:34:00+03	26000.00
B9CE7C	2017-07-30 17:55:00+03	86300.00
B9CE7F	2017-07-07 06:29:00+03	23200.00
B9CE87	2017-07-25 00:33:00+03	46400.00
B9CEAC	2017-06-23 03:49:00+03	32700.00
B9CF21	2017-08-06 19:42:00+03	57800.00
B9CF61	2017-08-14 17:14:00+03	64800.00
B9CF81	2017-07-11 18:42:00+03	51200.00
B9CF9D	2017-08-08 07:17:00+03	34700.00
B9CFA1	2017-07-20 17:12:00+03	58200.00
B9CFB6	2017-07-05 23:54:00+03	25200.00
B9D060	2017-08-07 08:30:00+03	24800.00
B9D0A4	2017-08-08 13:08:00+03	136200.00
B9D0D9	2017-07-31 19:54:00+03	46500.00
B9D0F3	2017-08-08 23:14:00+03	99200.00
B9D11D	2017-07-10 20:39:00+03	40700.00
B9D14C	2017-07-01 10:47:00+03	28800.00
B9D17F	2017-08-08 00:29:00+03	66600.00
B9D1FA	2017-08-09 03:07:00+03	143200.00
B9D205	2017-07-01 12:29:00+03	23600.00
B9D21B	2017-07-17 09:10:00+03	21800.00
B9D26A	2017-08-04 03:30:00+03	22400.00
B9D28B	2017-07-11 01:46:00+03	26800.00
B9D296	2017-08-07 01:10:00+03	155600.00
B9D305	2017-07-23 02:39:00+03	56600.00
B9D341	2017-07-07 15:53:00+03	27500.00
B9D3AA	2017-07-31 20:19:00+03	38600.00
B9D3D3	2017-07-20 10:31:00+03	65900.00
B9D409	2017-08-02 01:30:00+03	65300.00
B9D463	2017-07-25 07:51:00+03	43600.00
B9D52B	2017-08-04 14:20:00+03	24400.00
B9D542	2017-07-24 00:42:00+03	69500.00
B9D550	2017-07-01 21:46:00+03	40800.00
B9D602	2017-07-24 09:42:00+03	25600.00
B9D634	2017-07-04 09:35:00+03	43900.00
B9D67F	2017-07-20 04:17:00+03	56900.00
B9D7DA	2017-07-07 00:24:00+03	45200.00
B9D8B8	2017-07-11 02:59:00+03	101500.00
B9D8EE	2017-07-06 16:31:00+03	125200.00
B9D8F3	2017-07-25 22:48:00+03	131100.00
B9D941	2017-07-29 06:54:00+03	47000.00
B9D960	2017-07-20 16:53:00+03	103000.00
B9D9B0	2017-08-11 19:43:00+03	113800.00
B9D9EB	2017-07-09 01:07:00+03	56000.00
B9DA14	2017-07-17 00:53:00+03	31900.00
B9DA26	2017-07-14 05:15:00+03	23600.00
B9DA56	2017-07-26 01:04:00+03	135600.00
B9DAC2	2017-08-01 11:45:00+03	84500.00
B9DAD9	2017-08-05 14:57:00+03	37500.00
B9DB0C	2017-07-27 01:16:00+03	50000.00
B9DC58	2017-08-12 00:27:00+03	196800.00
B9DC8D	2017-07-28 14:51:00+03	49200.00
B9DD29	2017-07-09 19:40:00+03	51200.00
B9DD51	2017-07-22 03:37:00+03	23400.00
B9DD69	2017-07-20 22:16:00+03	56000.00
B9DDC5	2017-08-04 17:15:00+03	29500.00
B9DE82	2017-07-19 12:56:00+03	34000.00
B9DE89	2017-08-01 09:26:00+03	46400.00
B9DEE0	2017-07-19 05:10:00+03	48700.00
B9DF89	2017-07-07 09:51:00+03	24500.00
B9E03B	2017-07-20 14:33:00+03	161400.00
B9E048	2017-07-15 02:53:00+03	67600.00
B9E069	2017-08-05 22:54:00+03	16400.00
B9E08E	2017-08-06 23:00:00+03	24700.00
B9E0BF	2017-08-15 11:00:00+03	21800.00
B9E0D1	2017-07-31 00:56:00+03	51000.00
B9E13A	2017-08-11 01:01:00+03	50400.00
B9E197	2017-07-13 08:22:00+03	43200.00
B9E1F2	2017-07-07 11:08:00+03	37100.00
B9E1FD	2017-08-11 20:57:00+03	19600.00
B9E26B	2017-08-15 11:13:00+03	23400.00
B9E283	2017-07-28 17:59:00+03	112000.00
B9E290	2017-07-30 23:02:00+03	18900.00
B9E2E5	2017-07-20 19:24:00+03	45100.00
B9E2F0	2017-07-10 10:12:00+03	123000.00
B9E35D	2017-08-08 20:52:00+03	111600.00
B9E3A6	2017-08-03 02:43:00+03	120900.00
B9E3B7	2017-08-02 02:14:00+03	36200.00
B9E3EF	2017-07-07 14:38:00+03	33100.00
B9E4A4	2017-07-13 07:38:00+03	546800.00
B9E4D0	2017-07-26 14:00:00+03	133100.00
B9E4DD	2017-07-28 23:28:00+03	32600.00
B9E530	2017-08-12 16:19:00+03	28800.00
B9E550	2017-08-09 22:56:00+03	25800.00
B9E564	2017-07-21 07:08:00+03	146400.00
B9E5A1	2017-07-25 04:25:00+03	164400.00
B9E5F4	2017-07-14 14:00:00+03	99200.00
B9E60D	2017-07-26 19:00:00+03	46800.00
B9E622	2017-08-08 03:30:00+03	13600.00
B9E790	2017-08-10 07:06:00+03	86800.00
B9E7AA	2017-07-09 03:25:00+03	38600.00
B9E80A	2017-07-08 10:07:00+03	43600.00
B9E916	2017-07-21 03:04:00+03	46000.00
B9EA06	2017-08-09 13:10:00+03	64000.00
B9EA3D	2017-07-16 12:53:00+03	34600.00
B9EA80	2017-07-17 14:22:00+03	52000.00
B9EA81	2017-08-06 05:54:00+03	253300.00
B9EAB1	2017-07-08 13:06:00+03	13600.00
B9EAC6	2017-08-05 17:14:00+03	27400.00
B9EAED	2017-07-08 00:51:00+03	28800.00
B9EB40	2017-08-08 06:53:00+03	34600.00
B9EB55	2017-07-29 10:40:00+03	265700.00
B9EBAF	2017-07-23 22:07:00+03	37200.00
B9EC15	2017-07-17 20:04:00+03	62600.00
B9ECFA	2017-07-20 03:57:00+03	47000.00
B9ED04	2017-08-15 15:55:00+03	66000.00
B9ED7A	2017-07-26 08:05:00+03	44000.00
B9ED7D	2017-07-03 16:17:00+03	28800.00
B9EE09	2017-07-03 09:44:00+03	57600.00
B9EE26	2017-07-13 00:45:00+03	68000.00
B9EE3A	2017-07-07 20:31:00+03	430800.00
B9EE5A	2017-07-25 03:01:00+03	84000.00
B9EEA6	2017-08-11 06:11:00+03	73600.00
B9EEB2	2017-08-02 16:16:00+03	57400.00
B9EED0	2017-07-07 22:42:00+03	75800.00
B9EEE8	2017-07-11 05:50:00+03	144400.00
B9EFC8	2017-08-03 09:25:00+03	43000.00
B9EFCC	2017-08-15 12:12:00+03	49800.00
B9EFDD	2017-07-10 11:57:00+03	48400.00
B9F004	2017-07-13 17:28:00+03	29100.00
B9F014	2017-08-07 21:13:00+03	23200.00
B9F019	2017-07-29 16:59:00+03	16400.00
B9F056	2017-07-02 10:22:00+03	28000.00
B9F064	2017-07-18 14:48:00+03	34000.00
B9F078	2017-07-05 01:19:00+03	103600.00
B9F093	2017-07-18 12:00:00+03	35800.00
B9F0AD	2017-07-11 11:54:00+03	24400.00
B9F15F	2017-08-11 17:37:00+03	91500.00
B9F1A5	2017-07-22 04:17:00+03	73600.00
B9F366	2017-07-04 06:09:00+03	26600.00
B9F3C2	2017-07-19 18:54:00+03	55800.00
B9F44D	2017-07-17 04:57:00+03	81600.00
B9F454	2017-08-02 04:43:00+03	62500.00
B9F464	2017-07-26 11:59:00+03	9200.00
B9F4E7	2017-08-09 23:31:00+03	61800.00
B9F506	2017-06-28 11:15:00+03	39300.00
B9F518	2017-07-17 21:02:00+03	17000.00
B9F53F	2017-08-05 20:08:00+03	40400.00
B9F540	2017-08-09 20:17:00+03	67600.00
B9F571	2017-07-02 20:10:00+03	79600.00
B9F5EF	2017-08-13 09:10:00+03	8000.00
B9F6A1	2017-08-04 10:49:00+03	26000.00
B9F6B3	2017-07-12 23:04:00+03	77200.00
B9F725	2017-07-21 14:16:00+03	26800.00
B9F8BE	2017-08-06 06:14:00+03	34600.00
B9F8C2	2017-07-01 11:57:00+03	67200.00
B9F8CB	2017-08-06 10:53:00+03	56600.00
B9F979	2017-07-11 17:51:00+03	63700.00
B9FA04	2017-08-06 10:46:00+03	417600.00
B9FA05	2017-07-21 13:16:00+03	161200.00
B9FA31	2017-07-05 03:07:00+03	38500.00
B9FACE	2017-08-05 15:38:00+03	112000.00
B9FAEA	2017-07-05 01:43:00+03	7400.00
B9FAF9	2017-07-15 18:22:00+03	135600.00
B9FAFB	2017-07-20 02:48:00+03	115600.00
B9FB16	2017-07-21 01:54:00+03	156500.00
B9FB29	2017-07-05 05:37:00+03	62100.00
B9FB42	2017-08-12 00:04:00+03	35600.00
B9FBCF	2017-07-29 02:42:00+03	23200.00
B9FBED	2017-07-16 04:47:00+03	11700.00
B9FC0E	2017-07-05 05:39:00+03	72300.00
B9FC1D	2017-07-15 18:04:00+03	76400.00
B9FC90	2017-07-12 23:27:00+03	242700.00
B9FCC3	2017-08-02 20:56:00+03	179400.00
B9FD16	2017-07-02 18:10:00+03	62200.00
B9FDC0	2017-06-23 01:05:00+03	28000.00
B9FDD1	2017-07-06 03:00:00+03	13200.00
B9FE2F	2017-07-07 00:11:00+03	27800.00
B9FE6D	2017-07-05 13:54:00+03	86400.00
B9FEC2	2017-07-07 06:36:00+03	23400.00
B9FEC3	2017-08-06 08:02:00+03	288300.00
B9FEF8	2017-08-07 03:48:00+03	124200.00
B9FF1F	2017-07-02 21:01:00+03	59700.00
BA0044	2017-07-06 03:48:00+03	17000.00
BA00A5	2017-07-16 11:57:00+03	97800.00
BA00CB	2017-07-11 15:40:00+03	45400.00
BA00E2	2017-08-14 00:25:00+03	68400.00
BA012F	2017-08-05 06:26:00+03	46400.00
BA01B2	2017-07-11 17:05:00+03	28000.00
BA01B8	2017-07-30 04:12:00+03	28800.00
BA01BA	2017-07-31 17:41:00+03	46500.00
BA01EB	2017-07-27 17:07:00+03	15000.00
BA02A1	2017-08-08 15:13:00+03	8000.00
BA02C4	2017-08-07 03:36:00+03	6700.00
BA02C8	2017-08-11 18:51:00+03	40800.00
BA02EE	2017-07-26 09:27:00+03	20100.00
BA02FC	2017-07-07 02:19:00+03	29500.00
BA0334	2017-06-29 23:58:00+03	165800.00
BA03CC	2017-07-20 17:07:00+03	11600.00
BA041B	2017-07-13 03:38:00+03	40000.00
BA0436	2017-07-13 22:50:00+03	66600.00
BA0466	2017-07-13 15:52:00+03	44800.00
BA046C	2017-08-06 17:42:00+03	40800.00
BA0478	2017-07-17 00:57:00+03	36100.00
BA049C	2017-07-17 23:07:00+03	55800.00
BA049F	2017-07-28 21:16:00+03	178800.00
BA04FA	2017-07-26 09:41:00+03	246000.00
BA04FB	2017-07-14 16:50:00+03	16000.00
BA0511	2017-07-30 12:04:00+03	43600.00
BA054F	2017-07-22 10:06:00+03	207000.00
BA0555	2017-07-30 17:40:00+03	61800.00
BA05A1	2017-07-13 05:11:00+03	44000.00
BA0657	2017-07-25 06:50:00+03	107500.00
BA067D	2017-08-01 07:35:00+03	14400.00
BA06C7	2017-07-23 03:36:00+03	296400.00
BA06DF	2017-07-07 09:49:00+03	114800.00
BA0715	2017-07-27 03:25:00+03	38800.00
BA07F3	2017-07-12 08:00:00+03	492000.00
BA0840	2017-07-12 11:39:00+03	246000.00
BA0878	2017-08-13 19:07:00+03	12000.00
BA08D3	2017-08-08 18:29:00+03	35200.00
BA08D4	2017-08-11 09:27:00+03	541500.00
BA08DA	2017-07-30 04:10:00+03	31600.00
BA08FE	2017-07-19 12:29:00+03	6600.00
BA0995	2017-08-08 21:10:00+03	81600.00
BA09E5	2017-07-25 20:24:00+03	248300.00
BA0A27	2017-07-26 02:09:00+03	36200.00
BA0A41	2017-07-25 07:52:00+03	6600.00
BA0A77	2017-07-12 03:46:00+03	40600.00
BA0B12	2017-07-28 23:27:00+03	94000.00
BA0B1C	2017-06-29 13:52:00+03	14400.00
BA0B1E	2017-07-19 08:50:00+03	26000.00
BA0B91	2017-07-08 12:28:00+03	54500.00
BA0BB3	2017-06-29 11:51:00+03	112000.00
BA0C4A	2017-06-30 08:34:00+03	69800.00
BA0C54	2017-07-23 14:04:00+03	43600.00
BA0C66	2017-08-11 08:13:00+03	172800.00
BA0C6B	2017-07-05 15:11:00+03	207200.00
BA0D1C	2017-07-25 10:49:00+03	57600.00
BA0D34	2017-07-31 05:07:00+03	96400.00
BA0DD6	2017-07-15 22:44:00+03	322600.00
BA0E1F	2017-08-01 01:43:00+03	36800.00
BA0EAC	2017-08-13 18:13:00+03	73500.00
BA0EAD	2017-08-14 07:05:00+03	25200.00
BA0F05	2017-07-08 07:47:00+03	94000.00
BA0F0C	2017-07-12 10:26:00+03	8200.00
BA0F75	2017-07-27 20:42:00+03	184500.00
BA0FB5	2017-07-26 08:17:00+03	53500.00
BA10A0	2017-07-03 02:31:00+03	92800.00
BA10C5	2017-07-13 16:49:00+03	170000.00
BA10D4	2017-07-03 15:52:00+03	140900.00
BA1152	2017-07-25 09:20:00+03	40000.00
BA115F	2017-07-29 01:56:00+03	97800.00
BA1166	2017-08-12 05:33:00+03	29400.00
BA11CB	2017-08-12 14:26:00+03	82600.00
BA11E9	2017-07-05 20:53:00+03	58900.00
BA120E	2017-07-31 17:56:00+03	23200.00
BA1236	2017-07-04 08:02:00+03	32800.00
BA12B9	2017-07-23 19:46:00+03	8000.00
BA12FE	2017-07-18 14:57:00+03	47500.00
BA130D	2017-08-08 23:01:00+03	58600.00
BA133F	2017-07-23 09:16:00+03	265500.00
BA139A	2017-08-04 00:36:00+03	493400.00
BA139E	2017-07-05 23:26:00+03	55800.00
BA141E	2017-07-24 14:38:00+03	177200.00
BA145A	2017-08-12 14:33:00+03	86800.00
BA1462	2017-07-11 06:42:00+03	25200.00
BA1484	2017-07-01 13:27:00+03	6700.00
BA14DF	2017-07-27 23:05:00+03	30400.00
BA1562	2017-07-04 04:15:00+03	74000.00
BA15B4	2017-07-23 04:45:00+03	25600.00
BA15DE	2017-07-28 11:18:00+03	135600.00
BA15E0	2017-08-06 17:28:00+03	69500.00
BA1609	2017-07-07 16:04:00+03	18800.00
BA162C	2017-07-07 11:36:00+03	57500.00
BA1652	2017-07-29 00:27:00+03	48700.00
BA1682	2017-07-12 02:03:00+03	10800.00
BA169C	2017-07-06 09:20:00+03	77500.00
BA1729	2017-08-10 13:59:00+03	56000.00
BA175A	2017-07-26 04:44:00+03	80400.00
BA177F	2017-07-03 01:38:00+03	74200.00
BA17AA	2017-08-11 06:10:00+03	46200.00
BA17F3	2017-07-06 21:39:00+03	33100.00
BA17FB	2017-08-09 03:13:00+03	74800.00
BA1801	2017-07-17 23:31:00+03	46400.00
BA1814	2017-07-22 06:56:00+03	26000.00
BA1867	2017-07-26 08:56:00+03	139000.00
BA1893	2017-07-14 03:25:00+03	7400.00
BA18EC	2017-07-30 15:27:00+03	39800.00
BA1926	2017-07-25 16:02:00+03	99300.00
BA195B	2017-07-20 06:42:00+03	168000.00
BA197A	2017-07-05 10:06:00+03	57500.00
BA19B6	2017-07-18 03:59:00+03	28000.00
BA19C8	2017-08-10 22:34:00+03	56000.00
BA19F1	2017-07-05 07:05:00+03	22600.00
BA1A61	2017-07-04 18:14:00+03	205000.00
BA1AB1	2017-07-07 12:37:00+03	52300.00
BA1AE5	2017-07-02 09:48:00+03	71900.00
BA1B0D	2017-08-06 15:29:00+03	148200.00
BA1B22	2017-08-12 04:34:00+03	246200.00
BA1B27	2017-08-15 06:45:00+03	266500.00
BA1BE3	2017-07-04 03:52:00+03	92600.00
BA1C5C	2017-08-13 20:47:00+03	396500.00
BA1C77	2017-07-14 19:00:00+03	27900.00
BA1D3B	2017-07-15 19:33:00+03	202100.00
BA1D6E	2017-08-10 17:45:00+03	13400.00
BA1DF0	2017-07-17 05:25:00+03	168000.00
BA1E59	2017-07-05 15:15:00+03	75300.00
BA1E64	2017-08-10 14:18:00+03	40800.00
BA1EC2	2017-08-06 17:18:00+03	84800.00
BA1F08	2017-07-31 10:41:00+03	75300.00
BA1F4C	2017-07-09 09:15:00+03	23200.00
BA1F4E	2017-08-01 12:47:00+03	24400.00
BA1F81	2017-08-03 09:17:00+03	27900.00
BA1F85	2017-07-19 12:25:00+03	81700.00
BA1FB2	2017-07-15 19:47:00+03	95200.00
BA1FC9	2017-08-02 20:45:00+03	40600.00
BA2005	2017-07-03 15:44:00+03	47200.00
BA2078	2017-07-08 22:02:00+03	58900.00
BA207E	2017-08-05 13:01:00+03	65000.00
BA2139	2017-07-12 05:35:00+03	88600.00
BA214F	2017-07-24 14:42:00+03	155100.00
BA2173	2017-07-29 17:21:00+03	54000.00
BA2191	2017-07-25 06:29:00+03	32800.00
BA21D3	2017-07-16 17:48:00+03	193100.00
BA2243	2017-07-18 02:45:00+03	175000.00
BA231A	2017-07-14 16:50:00+03	189200.00
BA234C	2017-07-13 18:57:00+03	81300.00
BA2395	2017-07-31 07:26:00+03	34000.00
BA2397	2017-08-09 01:47:00+03	38800.00
BA23BA	2017-07-16 19:18:00+03	16400.00
BA2418	2017-07-22 01:36:00+03	225700.00
BA248A	2017-07-27 00:23:00+03	63800.00
BA24E8	2017-08-10 23:08:00+03	23600.00
BA24F5	2017-07-21 23:22:00+03	51200.00
BA24FF	2017-08-10 02:38:00+03	45200.00
BA2503	2017-07-02 21:24:00+03	136200.00
BA250F	2017-07-18 00:49:00+03	23600.00
BA2522	2017-08-07 01:31:00+03	54800.00
BA254E	2017-08-04 22:13:00+03	68800.00
BA257E	2017-07-16 08:56:00+03	8000.00
BA25BF	2017-08-01 10:24:00+03	68800.00
BA2606	2017-08-07 12:31:00+03	6700.00
BA2609	2017-08-06 06:12:00+03	26000.00
BA2677	2017-07-21 14:51:00+03	16400.00
BA26B8	2017-07-31 23:25:00+03	189800.00
BA26C0	2017-07-22 21:28:00+03	46000.00
BA2726	2017-07-19 22:17:00+03	86800.00
BA2727	2017-07-19 18:37:00+03	12600.00
BA2733	2017-07-05 02:36:00+03	55800.00
BA276A	2017-07-25 17:41:00+03	13600.00
BA278F	2017-07-03 12:08:00+03	135400.00
BA27E4	2017-08-07 12:21:00+03	115000.00
BA287C	2017-07-03 14:06:00+03	36200.00
BA28A8	2017-06-28 20:08:00+03	54000.00
BA290B	2017-07-29 10:56:00+03	50000.00
BA295E	2017-07-03 15:40:00+03	188000.00
BA29FF	2017-06-29 10:17:00+03	186900.00
BA2A53	2017-07-18 03:38:00+03	21800.00
BA2A78	2017-07-24 06:38:00+03	11800.00
BA2A99	2017-07-14 10:20:00+03	174600.00
BA2AD0	2017-07-15 19:01:00+03	52000.00
BA2AFB	2017-08-02 10:10:00+03	37200.00
BA2B72	2017-07-18 04:39:00+03	44000.00
BA2BC1	2017-07-18 22:24:00+03	224000.00
BA2CAD	2017-07-26 09:02:00+03	133100.00
BA2CC7	2017-07-15 07:36:00+03	34600.00
BA2CE0	2017-07-02 05:49:00+03	40600.00
BA2E04	2017-08-09 06:54:00+03	67600.00
BA2E10	2017-08-11 23:41:00+03	38600.00
BA2E4B	2017-08-14 13:00:00+03	47100.00
BA2E95	2017-08-08 08:49:00+03	34200.00
BA2EE6	2017-07-05 08:39:00+03	23400.00
BA2EEA	2017-07-06 13:31:00+03	57600.00
BA2FA3	2017-07-08 05:20:00+03	46900.00
BA2FC3	2017-08-13 03:44:00+03	23200.00
BA2FDD	2017-07-28 08:57:00+03	166100.00
BA3016	2017-07-18 12:34:00+03	56000.00
BA30AD	2017-07-29 01:37:00+03	23900.00
BA315C	2017-07-23 04:59:00+03	78600.00
BA3180	2017-07-06 14:39:00+03	6700.00
BA319E	2017-07-30 19:46:00+03	34000.00
BA31CE	2017-07-26 23:02:00+03	86300.00
BA31FA	2017-07-29 17:12:00+03	8200.00
BA331C	2017-07-01 08:19:00+03	181800.00
BA3333	2017-08-13 22:35:00+03	19600.00
BA33FC	2017-08-07 18:03:00+03	6000.00
BA3408	2017-07-16 16:19:00+03	47100.00
BA3424	2017-07-01 19:20:00+03	36500.00
BA3469	2017-07-25 18:11:00+03	26800.00
BA349D	2017-08-02 15:03:00+03	155000.00
BA34A7	2017-07-30 23:41:00+03	133200.00
BA34C8	2017-07-19 00:38:00+03	32400.00
BA34D7	2017-07-25 03:49:00+03	28000.00
BA3583	2017-07-21 21:34:00+03	13200.00
BA35B3	2017-07-14 12:19:00+03	67700.00
BA35BB	2017-07-27 17:01:00+03	138000.00
BA35CD	2017-08-02 07:38:00+03	26000.00
BA3662	2017-07-19 17:48:00+03	54000.00
BA36A5	2017-07-07 15:28:00+03	193100.00
BA36C6	2017-07-19 11:13:00+03	44800.00
BA36E9	2017-07-17 08:15:00+03	17000.00
BA370A	2017-07-11 07:02:00+03	92400.00
BA37B1	2017-07-18 07:33:00+03	145100.00
BA3802	2017-07-19 10:41:00+03	175000.00
BA3844	2017-07-04 19:35:00+03	13200.00
BA384E	2017-08-13 23:16:00+03	20000.00
BA38B8	2017-08-14 05:07:00+03	136200.00
BA38C3	2017-07-01 06:49:00+03	101200.00
BA38D0	2017-08-01 18:21:00+03	38200.00
BA38ED	2017-07-20 07:33:00+03	53400.00
BA391D	2017-07-31 04:26:00+03	26800.00
BA3944	2017-07-25 05:05:00+03	34000.00
BA39CB	2017-08-04 16:54:00+03	28000.00
BA3A1F	2017-07-29 05:09:00+03	425600.00
BA3A3B	2017-07-02 10:40:00+03	125200.00
BA3A40	2017-07-30 22:01:00+03	28300.00
BA3A75	2017-07-29 22:55:00+03	20400.00
BA3BE7	2017-08-13 02:40:00+03	47000.00
BA3C21	2017-07-19 10:28:00+03	140000.00
BA3C42	2017-08-11 19:17:00+03	14400.00
BA3CA6	2017-08-13 05:33:00+03	29900.00
BA3D08	2017-07-02 05:50:00+03	65500.00
BA3D17	2017-07-13 04:01:00+03	25400.00
BA3D7D	2017-07-14 06:50:00+03	44100.00
BA3DA5	2017-07-28 04:01:00+03	135400.00
BA3DB7	2017-07-07 00:02:00+03	40000.00
BA3E0B	2017-07-02 14:38:00+03	86800.00
BA3E81	2017-07-30 15:36:00+03	32700.00
BA3EB3	2017-07-06 22:47:00+03	45100.00
BA3EFF	2017-07-27 06:26:00+03	89600.00
BA3F0E	2017-07-12 15:13:00+03	344700.00
BA3F1F	2017-07-11 05:38:00+03	90400.00
BA3F32	2017-07-24 15:12:00+03	52800.00
BA3F3C	2017-07-21 23:54:00+03	91800.00
BA3F49	2017-07-06 04:04:00+03	132500.00
BA3F7D	2017-08-07 17:55:00+03	32200.00
BA3FB1	2017-07-21 10:44:00+03	86300.00
BA3FD8	2017-08-03 13:10:00+03	32700.00
BA402E	2017-07-16 18:41:00+03	68600.00
BA4053	2017-08-01 13:21:00+03	10800.00
BA40A1	2017-08-13 00:29:00+03	290600.00
BA41CE	2017-06-30 05:11:00+03	8000.00
BA41F1	2017-08-07 20:10:00+03	67500.00
BA4206	2017-07-06 10:14:00+03	101800.00
BA4231	2017-08-05 07:57:00+03	65900.00
BA4248	2017-07-15 05:21:00+03	258400.00
BA425E	2017-07-17 00:44:00+03	95000.00
BA42CD	2017-08-04 00:23:00+03	27600.00
BA42E7	2017-07-28 23:38:00+03	91600.00
BA430A	2017-07-06 20:09:00+03	106100.00
BA431C	2017-07-12 07:14:00+03	135200.00
BA43BD	2017-08-14 17:49:00+03	41200.00
BA4478	2017-08-14 23:59:00+03	128400.00
BA449A	2017-07-24 17:54:00+03	67700.00
BA44E4	2017-08-09 09:57:00+03	299300.00
BA457F	2017-07-25 12:03:00+03	26800.00
BA45DD	2017-06-30 02:48:00+03	354400.00
BA4639	2017-08-08 06:04:00+03	26000.00
BA464A	2017-08-04 21:49:00+03	118100.00
BA4685	2017-07-15 09:41:00+03	68800.00
BA4747	2017-07-22 12:51:00+03	73500.00
BA4751	2017-08-15 01:56:00+03	56600.00
BA478E	2017-07-31 15:26:00+03	10600.00
BA47DB	2017-07-29 13:27:00+03	28000.00
BA482D	2017-07-13 13:55:00+03	131100.00
BA483E	2017-08-10 23:48:00+03	46400.00
BA489D	2017-07-14 20:49:00+03	28000.00
BA48D5	2017-07-16 01:42:00+03	211400.00
BA48E8	2017-07-01 17:30:00+03	14000.00
BA4A26	2017-08-03 10:09:00+03	57500.00
BA4A59	2017-08-12 20:50:00+03	28800.00
BA4A93	2017-07-14 01:09:00+03	15000.00
BA4AB5	2017-08-07 06:33:00+03	106000.00
BA4ADF	2017-07-20 10:42:00+03	56000.00
BA4AED	2017-07-07 01:29:00+03	157900.00
BA4B41	2017-08-02 11:45:00+03	70700.00
BA4B54	2017-07-23 22:54:00+03	75600.00
BA4B5F	2017-07-10 06:41:00+03	28700.00
BA4B85	2017-07-09 04:58:00+03	185000.00
BA4B90	2017-07-02 09:59:00+03	22400.00
BA4B9E	2017-07-05 16:10:00+03	47600.00
BA4BF2	2017-08-07 22:46:00+03	56000.00
BA4C31	2017-07-23 04:02:00+03	134400.00
BA4D29	2017-07-26 02:07:00+03	38600.00
BA4D69	2017-07-04 09:54:00+03	87600.00
BA4D83	2017-07-03 16:29:00+03	117900.00
BA4D88	2017-07-11 08:36:00+03	55800.00
BA4D93	2017-07-10 05:36:00+03	98800.00
BA4DFC	2017-06-28 10:07:00+03	115100.00
BA4E14	2017-07-29 18:59:00+03	131800.00
BA4E55	2017-07-15 22:29:00+03	31600.00
BA4E9A	2017-07-23 08:53:00+03	535300.00
BA4EB3	2017-07-26 19:14:00+03	25900.00
BA4EF7	2017-08-05 01:17:00+03	199700.00
BA4F5C	2017-08-11 23:28:00+03	20400.00
BA4F61	2017-07-02 08:34:00+03	34100.00
BA4F9D	2017-07-21 12:21:00+03	103200.00
BA501D	2017-07-30 02:54:00+03	192200.00
BA505E	2017-08-10 05:34:00+03	12400.00
BA508E	2017-07-31 21:55:00+03	46300.00
BA50F4	2017-07-31 07:14:00+03	151200.00
BA51FF	2017-07-09 15:56:00+03	142800.00
BA52C1	2017-07-13 08:35:00+03	342300.00
BA52ED	2017-08-07 05:54:00+03	271400.00
BA5317	2017-08-12 20:06:00+03	37200.00
BA5326	2017-07-16 05:17:00+03	134000.00
BA5333	2017-08-15 13:52:00+03	98400.00
BA5334	2017-07-29 00:46:00+03	133700.00
BA5343	2017-08-06 06:00:00+03	13600.00
BA5365	2017-08-09 03:43:00+03	136200.00
BA53D2	2017-08-10 04:09:00+03	26000.00
BA53DB	2017-07-12 10:33:00+03	28000.00
BA5401	2017-07-11 10:46:00+03	44000.00
BA545D	2017-08-05 17:33:00+03	24700.00
BA548A	2017-07-18 19:58:00+03	62700.00
BA54D0	2017-07-24 22:18:00+03	73600.00
BA54FA	2017-07-22 04:37:00+03	300700.00
BA5549	2017-07-15 14:46:00+03	49600.00
BA5558	2017-08-02 07:30:00+03	69000.00
BA5593	2017-07-13 15:00:00+03	12000.00
BA559E	2017-08-06 02:30:00+03	136800.00
BA55BD	2017-07-15 05:32:00+03	32700.00
BA55C2	2017-08-10 20:55:00+03	25800.00
BA5635	2017-07-08 17:55:00+03	14400.00
BA5750	2017-07-07 15:35:00+03	111600.00
BA5760	2017-08-04 11:00:00+03	69500.00
BA57B7	2017-07-19 20:30:00+03	265800.00
BA57DE	2017-07-11 03:04:00+03	55800.00
BA5818	2017-08-12 04:48:00+03	38400.00
BA582C	2017-07-17 11:45:00+03	97200.00
BA5857	2017-08-11 19:52:00+03	32200.00
BA58D3	2017-08-15 10:49:00+03	73600.00
BA58F6	2017-08-13 12:04:00+03	92600.00
BA5933	2017-07-25 21:42:00+03	131100.00
BA5949	2017-08-04 14:20:00+03	78600.00
BA59C2	2017-07-04 15:42:00+03	21400.00
BA59E9	2017-08-10 10:28:00+03	70600.00
BA5A44	2017-08-10 21:31:00+03	203000.00
BA5A49	2017-08-12 15:32:00+03	103500.00
BA5A60	2017-08-02 07:01:00+03	65900.00
BA5ABA	2017-07-31 08:46:00+03	236000.00
BA5B0B	2017-07-28 19:04:00+03	369000.00
BA5B55	2017-07-05 19:00:00+03	133600.00
BA5B92	2017-07-12 16:39:00+03	85700.00
BA5C0D	2017-07-20 23:49:00+03	20700.00
BA5C4E	2017-07-16 02:32:00+03	99700.00
BA5C74	2017-07-08 15:30:00+03	46400.00
BA5C9B	2017-07-01 06:46:00+03	15400.00
BA5CC2	2017-07-26 01:19:00+03	36200.00
BA5CFD	2017-08-15 06:12:00+03	64700.00
BA5D26	2017-08-09 04:09:00+03	62600.00
BA5D77	2017-07-24 03:53:00+03	71400.00
BA5D82	2017-07-29 16:17:00+03	43600.00
BA5DAF	2017-07-25 03:12:00+03	49900.00
BA5DEF	2017-07-28 16:20:00+03	28700.00
BA5E05	2017-07-22 19:40:00+03	260300.00
BA5E56	2017-06-30 04:01:00+03	21800.00
BA5F28	2017-07-28 09:17:00+03	31400.00
BA5F2B	2017-07-22 10:39:00+03	146300.00
BA5F36	2017-07-20 04:12:00+03	75300.00
BA5F89	2017-07-23 20:23:00+03	7400.00
BA5F96	2017-07-18 16:28:00+03	13400.00
BA5FC2	2017-07-12 22:01:00+03	135600.00
BA5FF0	2017-07-30 00:48:00+03	28000.00
BA611D	2017-07-29 01:49:00+03	51100.00
BA616A	2017-07-23 23:43:00+03	64600.00
BA6194	2017-08-12 11:43:00+03	277000.00
BA61A3	2017-08-08 07:13:00+03	374400.00
BA61CE	2017-07-27 23:34:00+03	13200.00
BA61F4	2017-08-12 16:47:00+03	13700.00
BA6242	2017-07-31 08:11:00+03	48100.00
BA62AC	2017-07-08 04:11:00+03	66600.00
BA62EF	2017-06-30 01:58:00+03	49100.00
BA6312	2017-07-18 00:08:00+03	14800.00
BA6320	2017-07-05 13:28:00+03	70100.00
BA6340	2017-08-04 11:22:00+03	66800.00
BA6368	2017-07-30 05:02:00+03	54800.00
BA63E9	2017-07-14 07:52:00+03	68400.00
BA640B	2017-07-22 22:48:00+03	103400.00
BA6426	2017-08-12 13:20:00+03	603600.00
BA645E	2017-08-05 05:34:00+03	147700.00
BA6498	2017-07-05 08:19:00+03	192900.00
BA6536	2017-08-12 01:31:00+03	136800.00
BA6571	2017-07-07 23:31:00+03	46400.00
BA65CF	2017-07-23 16:32:00+03	36800.00
BA65F4	2017-06-30 05:28:00+03	76800.00
BA6659	2017-07-17 10:37:00+03	55800.00
BA6685	2017-08-13 00:18:00+03	65600.00
BA6756	2017-08-01 18:28:00+03	15100.00
BA676E	2017-08-10 07:34:00+03	47700.00
BA681C	2017-07-03 10:10:00+03	67200.00
BA6886	2017-07-27 12:42:00+03	99300.00
BA6887	2017-08-05 04:19:00+03	78300.00
BA68AE	2017-07-26 06:29:00+03	156500.00
BA68EA	2017-07-15 07:43:00+03	46400.00
BA68EC	2017-08-05 02:05:00+03	46400.00
BA6964	2017-07-27 20:32:00+03	19600.00
BA698D	2017-08-07 08:51:00+03	57800.00
BA6993	2017-08-11 08:01:00+03	67200.00
BA69D5	2017-08-05 07:47:00+03	31600.00
BA6A79	2017-07-19 08:48:00+03	14400.00
BA6A9B	2017-07-23 16:00:00+03	109600.00
BA6ACD	2017-07-13 15:09:00+03	47000.00
BA6B2C	2017-07-13 21:00:00+03	88400.00
BA6B4A	2017-07-22 08:11:00+03	30200.00
BA6B60	2017-07-11 19:51:00+03	26800.00
BA6B84	2017-07-15 10:18:00+03	60400.00
BA6B92	2017-07-28 14:56:00+03	23600.00
BA6BB3	2017-07-29 02:18:00+03	37900.00
BA6BB4	2017-08-06 07:21:00+03	23200.00
BA6C56	2017-07-07 21:27:00+03	80000.00
BA6CF5	2017-07-06 02:49:00+03	26000.00
BA6D3F	2017-07-10 07:23:00+03	52700.00
BA6D87	2017-08-04 03:33:00+03	34000.00
BA6DF2	2017-08-11 10:44:00+03	129700.00
BA6E16	2017-08-13 23:18:00+03	111600.00
BA6E66	2017-07-05 04:25:00+03	99500.00
BA6F5A	2017-07-29 20:39:00+03	54300.00
BA6F72	2017-07-18 16:51:00+03	38600.00
BA6F83	2017-07-29 07:50:00+03	224000.00
BA7073	2017-07-26 16:23:00+03	234700.00
BA70FA	2017-07-05 04:47:00+03	47400.00
BA715B	2017-07-13 14:26:00+03	93700.00
BA7211	2017-08-03 17:43:00+03	131600.00
BA7222	2017-08-06 15:52:00+03	40400.00
BA7228	2017-08-12 13:48:00+03	59100.00
BA7257	2017-08-15 14:52:00+03	56100.00
BA7264	2017-07-07 18:22:00+03	102100.00
BA7278	2017-07-28 05:15:00+03	26000.00
BA7283	2017-07-20 17:49:00+03	6700.00
BA72A3	2017-07-22 10:29:00+03	65100.00
BA7362	2017-08-07 13:59:00+03	78900.00
BA7382	2017-07-31 12:58:00+03	21400.00
BA7390	2017-07-11 08:11:00+03	56000.00
BA73D0	2017-07-29 22:48:00+03	123000.00
BA73E7	2017-07-03 17:33:00+03	51800.00
BA73EC	2017-06-30 14:42:00+03	86600.00
BA7402	2017-07-17 00:47:00+03	47400.00
BA7457	2017-08-08 05:46:00+03	23400.00
BA746E	2017-08-01 14:41:00+03	29600.00
BA7490	2017-08-01 13:16:00+03	24400.00
BA74A1	2017-08-06 05:37:00+03	40800.00
BA74B4	2017-07-10 16:25:00+03	45100.00
BA74F3	2017-07-22 05:58:00+03	56000.00
BA750E	2017-07-24 17:11:00+03	55800.00
BA7514	2017-08-10 22:01:00+03	39400.00
BA7518	2017-07-09 18:09:00+03	84100.00
BA75AE	2017-07-18 01:39:00+03	98200.00
BA75EE	2017-08-05 10:15:00+03	31400.00
BA7671	2017-07-27 05:11:00+03	24800.00
BA7682	2017-08-08 13:59:00+03	39300.00
BA7688	2017-07-01 01:48:00+03	73100.00
BA76CD	2017-07-08 00:33:00+03	24800.00
BA76E7	2017-07-10 02:27:00+03	118500.00
BA76ED	2017-07-15 11:37:00+03	123000.00
BA7733	2017-07-28 22:30:00+03	199700.00
BA7748	2017-07-15 16:20:00+03	21600.00
BA7775	2017-07-19 14:56:00+03	13300.00
BA777B	2017-07-22 05:49:00+03	111900.00
BA77C5	2017-08-05 21:56:00+03	139500.00
BA77D4	2017-07-21 13:51:00+03	44800.00
BA7803	2017-07-30 03:13:00+03	29600.00
BA7863	2017-08-13 04:42:00+03	67100.00
BA7878	2017-08-03 14:09:00+03	102900.00
BA78A2	2017-07-11 17:42:00+03	48800.00
BA78DB	2017-08-08 01:25:00+03	186900.00
BA78E3	2017-07-23 22:59:00+03	56200.00
BA7915	2017-07-14 13:06:00+03	24400.00
BA793C	2017-07-23 12:46:00+03	155100.00
BA79AF	2017-07-15 00:24:00+03	59800.00
BA79C1	2017-07-29 10:54:00+03	30200.00
BA7A55	2017-08-07 07:27:00+03	23200.00
BA7AE2	2017-08-05 02:29:00+03	31400.00
BA7B87	2017-07-24 12:58:00+03	157000.00
BA7B9F	2017-08-03 23:41:00+03	36200.00
BA7C26	2017-07-02 11:03:00+03	34000.00
BA7C4B	2017-07-19 06:44:00+03	43700.00
BA7C5D	2017-07-24 07:04:00+03	105600.00
BA7C7D	2017-06-30 00:14:00+03	117200.00
BA7D05	2017-07-13 01:34:00+03	34100.00
BA7D0F	2017-07-31 17:40:00+03	99700.00
BA7D12	2017-07-06 17:59:00+03	18400.00
BA7D63	2017-08-04 02:43:00+03	22900.00
BA7D69	2017-08-04 18:12:00+03	52800.00
BA7D9F	2017-07-18 20:27:00+03	26700.00
BA7DAE	2017-08-13 03:50:00+03	54500.00
BA7DE3	2017-08-13 17:52:00+03	46000.00
BA7E22	2017-07-20 06:00:00+03	72400.00
BA7E2C	2017-08-11 19:02:00+03	173500.00
BA7E3C	2017-07-07 09:16:00+03	62600.00
BA7E61	2017-07-07 16:29:00+03	54400.00
BA7ED2	2017-08-10 20:57:00+03	21600.00
BA7F44	2017-08-08 18:23:00+03	135400.00
BA7F9E	2017-08-01 17:30:00+03	100600.00
BA7FAD	2017-08-04 09:03:00+03	65900.00
BA7FAF	2017-07-03 02:18:00+03	110300.00
BA7FB8	2017-08-04 03:23:00+03	73600.00
BA7FD4	2017-07-26 06:15:00+03	56000.00
BA7FF3	2017-07-09 06:56:00+03	67600.00
BA8011	2017-07-18 02:45:00+03	39800.00
BA801A	2017-07-09 15:14:00+03	77000.00
BA8021	2017-07-13 05:10:00+03	17000.00
BA8060	2017-07-19 20:19:00+03	27400.00
BA8077	2017-07-11 02:55:00+03	16400.00
BA80CE	2017-08-10 15:23:00+03	143100.00
BA81CA	2017-08-07 11:23:00+03	73100.00
BA8230	2017-08-08 04:57:00+03	146300.00
BA826D	2017-07-05 16:33:00+03	58600.00
BA83C0	2017-08-04 12:59:00+03	86500.00
BA847D	2017-08-13 01:37:00+03	36400.00
BA847E	2017-07-07 10:54:00+03	27300.00
BA849F	2017-07-08 15:43:00+03	18000.00
BA84AD	2017-08-07 19:11:00+03	444000.00
BA84D7	2017-07-10 16:35:00+03	139300.00
BA8517	2017-07-01 16:01:00+03	206400.00
BA858D	2017-07-14 23:07:00+03	59800.00
BA85BB	2017-08-12 14:38:00+03	42800.00
BA8603	2017-08-12 09:14:00+03	57400.00
BA8607	2017-07-23 13:44:00+03	118000.00
BA860C	2017-08-09 14:20:00+03	28800.00
BA86AB	2017-07-19 07:06:00+03	8000.00
BA86B4	2017-07-26 15:18:00+03	91900.00
BA86CE	2017-08-03 16:21:00+03	71200.00
BA870F	2017-08-01 22:30:00+03	77200.00
BA872F	2017-07-29 11:59:00+03	73600.00
BA8736	2017-08-02 07:17:00+03	55800.00
BA8769	2017-08-13 10:49:00+03	111600.00
BA87C2	2017-08-08 18:33:00+03	36200.00
BA8833	2017-07-15 12:04:00+03	23100.00
BA88DE	2017-07-19 10:26:00+03	35400.00
BA890B	2017-07-20 08:24:00+03	56500.00
BA8911	2017-08-04 20:24:00+03	47400.00
BA8947	2017-07-16 00:28:00+03	73600.00
BA89A3	2017-07-12 22:12:00+03	27900.00
BA89D6	2017-07-18 12:58:00+03	46400.00
BA8A5C	2017-07-06 12:14:00+03	59800.00
BA8A70	2017-07-10 17:43:00+03	266400.00
BA8B60	2017-07-09 12:52:00+03	131600.00
BA8BB5	2017-07-31 06:54:00+03	80900.00
BA8BB9	2017-08-10 16:19:00+03	75100.00
BA8BD9	2017-07-28 07:53:00+03	67300.00
BA8C17	2017-07-05 02:41:00+03	36200.00
BA8C23	2017-08-12 06:05:00+03	265600.00
BA8C38	2017-07-12 04:03:00+03	89600.00
BA8C48	2017-08-05 10:35:00+03	62600.00
BA8C62	2017-08-08 02:38:00+03	89900.00
BA8C98	2017-07-25 18:24:00+03	260300.00
BA8D8A	2017-07-03 13:18:00+03	112600.00
BA8D95	2017-08-07 19:54:00+03	39200.00
BA8D9E	2017-07-05 19:00:00+03	131300.00
BA8D9F	2017-07-09 18:16:00+03	68100.00
BA8DC4	2017-08-05 02:26:00+03	67600.00
BA8E06	2017-07-25 14:20:00+03	67700.00
BA8E30	2017-07-26 05:49:00+03	114400.00
BA8E34	2017-07-06 01:33:00+03	25800.00
BA8E64	2017-08-13 22:10:00+03	14400.00
BA8E74	2017-07-04 23:46:00+03	47000.00
BA8EA5	2017-07-26 15:33:00+03	70100.00
BA8EE6	2017-07-25 12:24:00+03	124200.00
BA8F49	2017-08-04 20:50:00+03	51300.00
BA8FFE	2017-07-09 11:37:00+03	32700.00
BA905C	2017-07-21 01:29:00+03	155600.00
BA909B	2017-07-04 12:53:00+03	44000.00
BA90C9	2017-07-09 14:23:00+03	85500.00
BA91C4	2017-07-25 03:12:00+03	45600.00
BA9275	2017-07-13 19:00:00+03	75300.00
BA9297	2017-07-14 01:27:00+03	43600.00
BA9363	2017-08-04 18:45:00+03	33000.00
BA937B	2017-08-10 06:51:00+03	37200.00
BA93D4	2017-07-15 03:52:00+03	58400.00
BA941F	2017-07-24 10:29:00+03	68100.00
BA9426	2017-08-09 01:42:00+03	389000.00
BA9448	2017-08-01 14:57:00+03	67600.00
BA9456	2017-07-27 19:57:00+03	33200.00
BA950E	2017-07-13 12:31:00+03	135000.00
BA95C7	2017-07-25 09:14:00+03	27800.00
BA9614	2017-08-08 14:18:00+03	36200.00
BA9666	2017-07-23 20:35:00+03	26500.00
BA96B7	2017-07-03 01:33:00+03	68800.00
BA96C1	2017-08-13 22:05:00+03	84800.00
BA96D0	2017-07-11 07:54:00+03	19800.00
BA96DB	2017-07-28 09:02:00+03	29000.00
BA9736	2017-07-21 19:08:00+03	377400.00
BA9789	2017-07-25 22:39:00+03	101800.00
BA978A	2017-07-11 02:51:00+03	15000.00
BA9797	2017-08-14 06:04:00+03	67600.00
BA97C9	2017-07-23 05:40:00+03	51600.00
BA9806	2017-08-11 09:26:00+03	39200.00
BA9857	2017-08-11 11:09:00+03	50800.00
BA988B	2017-07-15 16:17:00+03	20000.00
BA98C3	2017-08-06 05:32:00+03	167500.00
BA98F5	2017-07-01 23:19:00+03	38400.00
BA9969	2017-08-03 21:13:00+03	28000.00
BA9A22	2017-07-28 08:09:00+03	23400.00
BA9A43	2017-08-07 13:22:00+03	86400.00
BA9A76	2017-08-10 19:07:00+03	53800.00
BA9AA9	2017-07-25 02:17:00+03	13700.00
BA9ABD	2017-08-04 07:38:00+03	38400.00
BA9AD1	2017-08-05 05:43:00+03	32700.00
BA9AF7	2017-08-04 05:06:00+03	213200.00
BA9B88	2017-07-15 14:28:00+03	32700.00
BA9B93	2017-07-10 10:51:00+03	46000.00
BA9B9E	2017-07-17 11:58:00+03	70800.00
BA9BA6	2017-07-24 00:28:00+03	45400.00
BA9C1C	2017-07-06 04:51:00+03	121400.00
BA9C32	2017-07-23 07:47:00+03	81600.00
BA9C3E	2017-07-30 14:03:00+03	30000.00
BA9C93	2017-07-02 23:03:00+03	166100.00
BA9D2D	2017-08-10 22:59:00+03	23400.00
BA9D35	2017-08-03 23:52:00+03	17600.00
BA9D42	2017-07-23 03:04:00+03	68100.00
BA9D65	2017-07-15 02:04:00+03	26800.00
BA9DCB	2017-08-03 12:31:00+03	85300.00
BA9E1E	2017-06-30 02:48:00+03	41800.00
BA9E24	2017-07-07 20:14:00+03	52000.00
BA9E3A	2017-08-13 05:09:00+03	78500.00
BA9E3B	2017-07-13 16:51:00+03	406700.00
BA9EBF	2017-07-31 03:08:00+03	86900.00
BA9F27	2017-07-12 07:47:00+03	110500.00
BA9F32	2017-07-06 23:25:00+03	12600.00
BA9F72	2017-08-11 07:11:00+03	99200.00
BA9F80	2017-07-23 16:41:00+03	54000.00
BA9FA9	2017-07-16 02:28:00+03	35000.00
BA9FC1	2017-08-11 10:40:00+03	103800.00
BA9FD2	2017-08-03 16:36:00+03	6800.00
BAA02C	2017-08-09 00:03:00+03	83000.00
BAA0A7	2017-07-01 06:11:00+03	139500.00
BAA0F8	2017-07-28 16:36:00+03	38400.00
BAA1C6	2017-07-09 04:48:00+03	10800.00
BAA1D8	2017-07-30 13:08:00+03	28000.00
BAA200	2017-07-10 22:35:00+03	14000.00
BAA219	2017-07-20 14:30:00+03	52000.00
BAA22F	2017-08-10 18:46:00+03	45200.00
BAA243	2017-07-16 17:22:00+03	24700.00
BAA301	2017-07-30 21:57:00+03	173500.00
BAA312	2017-07-02 22:36:00+03	113300.00
BAA317	2017-07-12 21:21:00+03	40000.00
BAA33B	2017-07-14 03:37:00+03	6700.00
BAA3AD	2017-07-17 13:39:00+03	100600.00
BAA3D8	2017-08-12 17:33:00+03	40000.00
BAA4A9	2017-08-15 13:56:00+03	25600.00
BAA4BB	2017-07-22 20:42:00+03	147400.00
BAA4ED	2017-08-08 07:48:00+03	18400.00
BAA512	2017-07-19 14:58:00+03	7400.00
BAA55C	2017-08-14 23:42:00+03	53300.00
BAA58D	2017-07-22 01:46:00+03	26800.00
BAA612	2017-07-11 08:54:00+03	55800.00
BAA625	2017-07-06 00:20:00+03	40800.00
BAA6D3	2017-08-15 01:44:00+03	51200.00
BAA737	2017-07-10 22:58:00+03	56000.00
BAA7A5	2017-07-29 09:12:00+03	23400.00
BAA7BA	2017-07-16 01:48:00+03	32800.00
BAA7C1	2017-07-25 19:17:00+03	270700.00
BAA829	2017-07-20 21:56:00+03	115100.00
BAA854	2017-07-14 16:43:00+03	260300.00
BAA8EF	2017-08-14 16:40:00+03	25200.00
BAA918	2017-07-06 09:40:00+03	271200.00
BAA93D	2017-07-18 18:00:00+03	21600.00
BAA958	2017-08-04 07:29:00+03	140900.00
BAA9B1	2017-08-08 12:38:00+03	13400.00
BAAA4E	2017-07-26 17:24:00+03	23600.00
BAAA57	2017-07-03 00:50:00+03	13400.00
BAAA80	2017-08-10 05:52:00+03	67700.00
BAAA81	2017-07-11 00:15:00+03	32800.00
BAAA8B	2017-07-08 10:53:00+03	117300.00
BAAAAC	2017-07-24 00:19:00+03	66400.00
BAAAF6	2017-07-13 15:01:00+03	51800.00
BAAB9B	2017-07-17 04:22:00+03	22000.00
BAABBD	2017-07-29 02:55:00+03	94700.00
BAABBF	2017-08-15 12:30:00+03	28000.00
BAABF7	2017-08-08 15:21:00+03	67400.00
BAAC2C	2017-07-28 21:13:00+03	70700.00
BAAC40	2017-07-24 03:44:00+03	69900.00
BAAD3F	2017-07-18 14:59:00+03	70700.00
BAAD61	2017-08-01 05:06:00+03	38200.00
BAAD73	2017-07-21 09:47:00+03	254900.00
BAAD89	2017-07-12 12:21:00+03	60700.00
BAAE2E	2017-07-08 10:41:00+03	72600.00
BAAE48	2017-07-24 07:47:00+03	43800.00
BAAE74	2017-07-13 07:39:00+03	148200.00
BAAEE5	2017-07-14 13:10:00+03	75600.00
BAAF07	2017-07-08 17:19:00+03	88400.00
BAAF20	2017-08-14 00:23:00+03	86800.00
BAAF66	2017-07-27 00:12:00+03	56000.00
BAAFCD	2017-07-20 03:19:00+03	6300.00
BAAFD7	2017-07-12 08:56:00+03	14400.00
BAAFE8	2017-08-11 23:40:00+03	66800.00
BAAFF9	2017-08-08 10:52:00+03	24000.00
BAB000	2017-07-13 16:25:00+03	85000.00
BAB019	2017-07-02 20:41:00+03	46300.00
BAB051	2017-08-05 16:10:00+03	61700.00
BAB0B6	2017-07-24 07:46:00+03	46400.00
BAB0C0	2017-07-09 18:19:00+03	21800.00
BAB0E1	2017-07-09 20:56:00+03	236300.00
BAB116	2017-07-12 10:47:00+03	369000.00
BAB119	2017-08-06 13:38:00+03	87100.00
BAB16D	2017-07-07 00:01:00+03	52800.00
BAB1AC	2017-07-04 04:35:00+03	151200.00
BAB213	2017-07-08 21:30:00+03	27200.00
BAB252	2017-07-14 15:36:00+03	27200.00
BAB370	2017-08-03 08:48:00+03	24800.00
BAB377	2017-07-16 00:04:00+03	6800.00
BAB390	2017-08-05 20:47:00+03	136200.00
BAB3B2	2017-07-29 07:59:00+03	56000.00
BAB3CA	2017-07-08 18:15:00+03	170000.00
BAB3E8	2017-07-29 02:55:00+03	52400.00
BAB3F3	2017-06-28 06:09:00+03	145300.00
BAB3F8	2017-07-27 07:25:00+03	42700.00
BAB40D	2017-08-07 15:35:00+03	43000.00
BAB419	2017-07-27 17:43:00+03	6000.00
BAB43B	2017-07-20 05:04:00+03	10800.00
BAB4C0	2017-07-29 23:20:00+03	23200.00
BAB56E	2017-08-11 06:22:00+03	125300.00
BAB584	2017-07-19 20:50:00+03	20000.00
BAB599	2017-07-26 13:47:00+03	316400.00
BAB5A7	2017-07-10 10:14:00+03	178800.00
BAB683	2017-07-30 22:29:00+03	83200.00
BAB688	2017-07-14 20:50:00+03	6700.00
BAB6B2	2017-07-18 18:38:00+03	111600.00
BAB6B8	2017-07-21 15:35:00+03	56000.00
BAB6D6	2017-07-27 15:26:00+03	170500.00
BAB708	2017-07-17 11:20:00+03	105600.00
BAB7A7	2017-07-21 17:38:00+03	29200.00
BAB861	2017-07-21 05:22:00+03	16400.00
BAB891	2017-08-04 06:14:00+03	25000.00
BAB8C0	2017-07-29 06:51:00+03	167200.00
BAB922	2017-07-14 14:39:00+03	56900.00
BAB927	2017-08-11 12:14:00+03	61800.00
BAB93E	2017-07-07 07:01:00+03	27900.00
BAB950	2017-07-17 08:32:00+03	40800.00
BAB973	2017-08-07 01:02:00+03	18300.00
BAB98B	2017-08-10 03:39:00+03	47700.00
BAB9E7	2017-07-27 08:32:00+03	26000.00
BABA32	2017-08-15 15:37:00+03	27900.00
BABA91	2017-08-14 14:11:00+03	173800.00
BABA93	2017-07-26 17:20:00+03	15000.00
BABAAF	2017-06-29 19:50:00+03	189800.00
BABAF1	2017-07-29 05:50:00+03	47100.00
BABB23	2017-07-30 08:09:00+03	52800.00
BABB98	2017-07-01 11:46:00+03	116000.00
BABCC2	2017-08-11 04:56:00+03	27900.00
BABD16	2017-08-02 06:59:00+03	77000.00
BABD25	2017-08-05 02:38:00+03	73200.00
BABD3C	2017-08-12 00:41:00+03	139500.00
BABD73	2017-07-25 09:34:00+03	131100.00
BABD7C	2017-07-17 10:24:00+03	265600.00
BABD95	2017-07-23 18:02:00+03	36200.00
BABD96	2017-08-01 20:42:00+03	169900.00
BABD97	2017-07-14 05:37:00+03	27200.00
BABDD0	2017-07-15 17:53:00+03	106400.00
BABDE1	2017-07-13 04:09:00+03	12000.00
BABDFA	2017-08-12 23:48:00+03	77300.00
BABE45	2017-07-26 02:31:00+03	6000.00
BABE95	2017-07-20 02:39:00+03	130800.00
BABEB4	2017-07-25 07:56:00+03	27900.00
BABED6	2017-08-01 07:30:00+03	6000.00
BABF53	2017-07-23 12:20:00+03	26800.00
BABF6F	2017-08-07 13:05:00+03	115100.00
BABF83	2017-07-23 18:03:00+03	75700.00
BABF84	2017-07-25 20:54:00+03	409100.00
BABFD1	2017-08-06 17:53:00+03	62600.00
BABFE7	2017-07-21 12:24:00+03	25600.00
BAC037	2017-07-12 02:39:00+03	102100.00
BAC082	2017-08-07 03:49:00+03	52000.00
BAC086	2017-08-12 05:11:00+03	72300.00
BAC0A2	2017-08-02 01:39:00+03	46200.00
BAC0E2	2017-08-15 12:02:00+03	34000.00
BAC182	2017-07-05 22:37:00+03	58000.00
BAC192	2017-07-30 01:42:00+03	99900.00
BAC1BD	2017-08-15 12:29:00+03	206800.00
BAC1C9	2017-07-30 16:13:00+03	91000.00
BAC1E6	2017-07-06 19:18:00+03	94000.00
BAC271	2017-07-15 00:52:00+03	246000.00
BAC29F	2017-08-12 07:03:00+03	147000.00
BAC361	2017-07-21 22:41:00+03	47400.00
BAC3C5	2017-08-07 14:09:00+03	135200.00
BAC3DC	2017-08-05 17:51:00+03	134400.00
BAC3E2	2017-08-04 01:29:00+03	78800.00
BAC42D	2017-08-08 02:45:00+03	34000.00
BAC441	2017-07-22 12:47:00+03	92900.00
BAC56C	2017-07-09 02:08:00+03	38200.00
BAC578	2017-07-06 15:18:00+03	50600.00
BAC5AE	2017-08-02 10:50:00+03	62800.00
BAC5B7	2017-08-02 13:12:00+03	408500.00
BAC68A	2017-07-10 02:16:00+03	56000.00
BAC69E	2017-07-30 21:03:00+03	26000.00
BAC6EE	2017-08-07 06:09:00+03	163700.00
BAC727	2017-07-08 21:21:00+03	28800.00
BAC7BD	2017-07-27 02:34:00+03	43400.00
BAC7DB	2017-07-12 01:11:00+03	28000.00
BAC7E1	2017-07-12 03:07:00+03	27900.00
BAC7FC	2017-08-08 15:22:00+03	21400.00
BAC83B	2017-07-24 14:48:00+03	380700.00
BAC844	2017-07-21 12:26:00+03	203400.00
BAC858	2017-07-04 12:18:00+03	21200.00
BAC8D9	2017-08-08 02:46:00+03	289800.00
BAC8F7	2017-07-10 23:35:00+03	47000.00
BAC913	2017-08-14 08:35:00+03	23200.00
BAC953	2017-07-09 04:09:00+03	149500.00
BAC991	2017-07-08 07:10:00+03	102100.00
BAC9E7	2017-08-11 14:23:00+03	21400.00
BACA11	2017-08-13 20:58:00+03	66600.00
BACABE	2017-07-08 11:12:00+03	42000.00
BACBC6	2017-08-05 05:42:00+03	6000.00
BACBCD	2017-08-04 02:18:00+03	30000.00
BACC28	2017-07-29 10:03:00+03	46800.00
BACC4E	2017-07-15 08:22:00+03	28000.00
BACC76	2017-07-22 14:55:00+03	52000.00
BACC97	2017-07-02 01:48:00+03	28000.00
BACC9E	2017-07-12 15:10:00+03	73300.00
BACCBB	2017-07-24 22:13:00+03	46700.00
BACCCF	2017-07-06 23:55:00+03	49700.00
BACD4E	2017-07-25 14:26:00+03	48600.00
BACDD5	2017-07-29 09:35:00+03	13400.00
BACE05	2017-07-19 08:22:00+03	410500.00
BACE2A	2017-07-12 07:18:00+03	82900.00
BACE49	2017-06-25 16:01:00+03	11600.00
BACEC4	2017-07-29 16:55:00+03	54500.00
BACEDF	2017-07-22 01:54:00+03	81900.00
BACEE3	2017-08-02 16:09:00+03	38800.00
BACF0E	2017-07-31 08:23:00+03	46400.00
BACF16	2017-08-09 02:25:00+03	113200.00
BACF33	2017-07-28 07:35:00+03	28800.00
BACF49	2017-07-21 06:29:00+03	29600.00
BACFA6	2017-08-02 19:25:00+03	386300.00
BACFE5	2017-08-06 21:29:00+03	36600.00
BAD001	2017-07-15 09:07:00+03	7200.00
BAD01F	2017-07-30 22:33:00+03	28000.00
BAD02E	2017-08-12 19:52:00+03	58400.00
BAD146	2017-07-10 18:50:00+03	59000.00
BAD1BC	2017-08-04 23:11:00+03	62600.00
BAD1D4	2017-07-10 06:23:00+03	137600.00
BAD1F0	2017-07-31 14:42:00+03	177600.00
BAD1F9	2017-06-29 18:00:00+03	23200.00
BAD280	2017-08-01 21:30:00+03	40000.00
BAD299	2017-07-24 03:47:00+03	79600.00
BAD3AA	2017-08-03 05:35:00+03	46300.00
BAD3AE	2017-07-07 16:24:00+03	59800.00
BAD3FD	2017-06-28 11:23:00+03	266400.00
BAD410	2017-08-06 06:30:00+03	16400.00
BAD4C1	2017-08-07 12:10:00+03	16400.00
BAD4DB	2017-07-08 11:36:00+03	20200.00
BAD50E	2017-08-02 23:06:00+03	83000.00
BAD518	2017-08-03 23:28:00+03	37200.00
BAD52A	2017-07-06 15:43:00+03	18600.00
BAD53A	2017-07-28 23:35:00+03	230600.00
BAD5D6	2017-07-17 05:20:00+03	163600.00
BAD602	2017-08-13 12:31:00+03	34000.00
BAD61E	2017-07-13 06:13:00+03	56000.00
BAD686	2017-07-17 22:17:00+03	66600.00
BAD6C3	2017-07-26 06:34:00+03	23100.00
BAD6FB	2017-07-28 13:46:00+03	17800.00
BAD79C	2017-07-11 18:03:00+03	58600.00
BAD7FC	2017-07-04 11:17:00+03	58000.00
BAD8BF	2017-07-31 13:45:00+03	16400.00
BAD8C0	2017-07-12 09:50:00+03	25000.00
BAD8ED	2017-07-20 14:16:00+03	19800.00
BAD9BC	2017-07-05 13:48:00+03	123000.00
BAD9F5	2017-08-02 18:32:00+03	56000.00
BADA50	2017-07-21 20:24:00+03	55800.00
BADA51	2017-08-12 09:05:00+03	123700.00
BADB4D	2017-08-02 15:59:00+03	87100.00
BADBFA	2017-08-04 22:03:00+03	20000.00
BADC2F	2017-07-13 23:47:00+03	45200.00
BADC85	2017-07-23 08:52:00+03	6800.00
BADD0F	2017-08-11 19:26:00+03	35400.00
BADD1D	2017-07-22 22:57:00+03	117200.00
BADD46	2017-08-06 15:55:00+03	28800.00
BADDA0	2017-08-09 11:40:00+03	17800.00
BADDA1	2017-08-15 00:58:00+03	94800.00
BADDE4	2017-07-13 01:24:00+03	136100.00
BADE0E	2017-07-30 22:41:00+03	67200.00
BADE16	2017-07-09 22:11:00+03	266400.00
BADE50	2017-08-09 05:54:00+03	135600.00
BADE8E	2017-08-04 15:50:00+03	26000.00
BADEDA	2017-07-18 12:37:00+03	44500.00
BADF09	2017-08-14 21:28:00+03	54800.00
BADF17	2017-07-04 22:40:00+03	199700.00
BADF28	2017-07-05 00:29:00+03	102100.00
BADF5F	2017-07-31 14:10:00+03	27900.00
BADFBD	2017-07-03 15:32:00+03	28000.00
BADFCC	2017-07-02 18:59:00+03	13400.00
BAE015	2017-08-07 06:23:00+03	51900.00
BAE078	2017-07-14 09:45:00+03	19600.00
BAE081	2017-07-29 20:40:00+03	29400.00
BAE090	2017-07-26 18:02:00+03	23600.00
BAE0B1	2017-08-01 18:00:00+03	93900.00
BAE109	2017-08-13 01:18:00+03	38400.00
BAE258	2017-07-07 16:56:00+03	28000.00
BAE25A	2017-07-08 12:35:00+03	23900.00
BAE273	2017-07-04 05:26:00+03	52400.00
BAE279	2017-07-24 23:19:00+03	46500.00
BAE29A	2017-07-09 09:29:00+03	59800.00
BAE2D3	2017-08-03 22:01:00+03	31900.00
BAE2E7	2017-07-26 09:32:00+03	130200.00
BAE38C	2017-08-11 14:17:00+03	50700.00
BAE3CA	2017-07-16 16:39:00+03	23100.00
BAE434	2017-07-07 15:57:00+03	6700.00
BAE445	2017-08-04 03:48:00+03	43200.00
BAE4B5	2017-08-02 01:30:00+03	81600.00
BAE4F1	2017-08-05 08:03:00+03	44000.00
BAE4F3	2017-07-10 11:38:00+03	59000.00
BAE4F9	2017-08-01 21:12:00+03	23600.00
BAE59E	2017-08-11 19:57:00+03	12600.00
BAE5B3	2017-07-01 06:44:00+03	133100.00
BAE5C3	2017-08-02 07:42:00+03	13600.00
BAE5CE	2017-07-10 14:09:00+03	148200.00
BAE5D9	2017-08-04 10:28:00+03	185600.00
BAE604	2017-07-03 09:25:00+03	26600.00
BAE613	2017-07-30 08:58:00+03	48700.00
BAE64D	2017-07-26 08:49:00+03	70700.00
BAE656	2017-07-18 09:37:00+03	62800.00
BAE65F	2017-08-12 19:05:00+03	70700.00
BAE66B	2017-08-05 00:14:00+03	16400.00
BAE6B3	2017-07-01 13:37:00+03	64800.00
BAE6B8	2017-07-11 19:42:00+03	143100.00
BAE6C8	2017-07-12 14:42:00+03	18000.00
BAE6CB	2017-08-11 00:17:00+03	18600.00
BAE6DB	2017-07-15 00:27:00+03	28600.00
BAE72A	2017-08-14 01:50:00+03	36200.00
BAE746	2017-08-08 05:33:00+03	75300.00
BAE770	2017-07-02 11:49:00+03	148200.00
BAE7FB	2017-07-25 16:27:00+03	99200.00
BAE81D	2017-08-04 08:24:00+03	140200.00
BAE8D7	2017-07-10 21:19:00+03	37900.00
BAE935	2017-07-27 10:03:00+03	11600.00
BAE937	2017-08-03 06:35:00+03	542400.00
BAE953	2017-07-12 07:05:00+03	28000.00
BAE969	2017-08-14 11:04:00+03	40100.00
BAE9F1	2017-07-12 15:08:00+03	64700.00
BAEA07	2017-08-05 08:38:00+03	100600.00
BAEA33	2017-07-17 12:59:00+03	272300.00
BAEA43	2017-08-08 01:29:00+03	75700.00
BAEAAE	2017-08-09 05:35:00+03	37200.00
BAEB21	2017-08-03 13:01:00+03	26000.00
BAEB2B	2017-07-30 20:00:00+03	19600.00
BAEB55	2017-07-17 03:33:00+03	16400.00
BAEC1F	2017-07-13 15:19:00+03	201800.00
BAEC45	2017-08-06 19:19:00+03	40000.00
BAEC8A	2017-07-06 18:53:00+03	15000.00
BAED0A	2017-06-28 10:20:00+03	24400.00
BAED30	2017-07-06 09:01:00+03	92100.00
BAED62	2017-07-13 17:17:00+03	35300.00
BAED6E	2017-07-16 22:39:00+03	26000.00
BAEDA9	2017-07-30 23:52:00+03	99200.00
BAEDD9	2017-08-14 01:05:00+03	137600.00
BAEDDF	2017-07-31 03:54:00+03	50600.00
BAEDEE	2017-07-25 17:25:00+03	10100.00
BAEE23	2017-07-10 06:12:00+03	20200.00
BAEE78	2017-08-09 04:17:00+03	114800.00
BAEFA8	2017-07-23 08:48:00+03	35200.00
BAEFBF	2017-08-09 05:25:00+03	40400.00
BAEFE1	2017-07-05 17:47:00+03	137200.00
BAF0BD	2017-06-29 16:37:00+03	40800.00
BAF0CD	2017-06-29 18:07:00+03	56600.00
BAF157	2017-07-21 02:05:00+03	99200.00
BAF21B	2017-08-07 23:34:00+03	55800.00
BAF228	2017-07-30 05:56:00+03	43500.00
BAF22F	2017-07-18 21:50:00+03	42700.00
BAF240	2017-07-20 02:38:00+03	19800.00
BAF2BD	2017-08-14 20:26:00+03	21200.00
BAF2D2	2017-07-10 21:22:00+03	61700.00
BAF302	2017-07-13 14:25:00+03	51800.00
BAF363	2017-07-16 14:01:00+03	6000.00
BAF370	2017-08-02 11:28:00+03	13000.00
BAF37D	2017-08-01 18:41:00+03	11000.00
BAF3F9	2017-07-18 02:14:00+03	6800.00
BAF417	2017-08-05 01:11:00+03	50000.00
BAF42A	2017-07-23 14:50:00+03	80800.00
BAF49F	2017-07-10 16:05:00+03	254900.00
BAF4A7	2017-07-31 19:16:00+03	27200.00
BAF51B	2017-08-03 05:40:00+03	43200.00
BAF588	2017-08-13 02:16:00+03	13400.00
BAF596	2017-08-08 03:50:00+03	38400.00
BAF608	2017-08-09 09:25:00+03	69000.00
BAF609	2017-07-17 02:59:00+03	37200.00
BAF61D	2017-08-05 14:44:00+03	18700.00
BAF683	2017-08-14 09:43:00+03	37900.00
BAF6C9	2017-08-14 15:58:00+03	139400.00
BAF6E8	2017-08-06 03:33:00+03	79200.00
BAF711	2017-07-16 01:10:00+03	37100.00
BAF806	2017-07-30 22:10:00+03	88900.00
BAF83E	2017-07-22 16:10:00+03	201800.00
BAF864	2017-07-22 11:36:00+03	86500.00
BAF8C3	2017-07-07 18:45:00+03	56000.00
BAF8F6	2017-07-26 05:15:00+03	26000.00
BAF905	2017-07-04 00:26:00+03	314400.00
BAF9B3	2017-07-31 21:51:00+03	151200.00
BAFA31	2017-08-13 08:09:00+03	49100.00
BAFA45	2017-07-24 16:40:00+03	135300.00
BAFA53	2017-08-15 06:56:00+03	252200.00
BAFAB9	2017-07-18 15:10:00+03	248400.00
BAFAC2	2017-08-11 08:18:00+03	55800.00
BAFAC6	2017-07-04 00:54:00+03	16400.00
BAFAD1	2017-07-17 12:52:00+03	35900.00
BAFAF1	2017-08-11 12:24:00+03	109400.00
BAFB3D	2017-08-14 08:22:00+03	44800.00
BAFB7F	2017-07-05 13:39:00+03	70800.00
BAFB99	2017-08-04 21:01:00+03	32400.00
BAFB9D	2017-06-24 12:50:00+03	46200.00
BAFBA3	2017-08-07 23:13:00+03	40800.00
BAFC09	2017-07-17 17:37:00+03	193600.00
BAFC84	2017-07-10 13:18:00+03	96800.00
BAFD54	2017-08-07 20:10:00+03	36200.00
BAFD73	2017-08-13 17:14:00+03	32700.00
BAFDD6	2017-07-27 21:07:00+03	168000.00
BAFE25	2017-07-18 06:24:00+03	16800.00
BAFE62	2017-07-14 13:16:00+03	88100.00
BAFED6	2017-07-10 16:37:00+03	6700.00
BAFEF7	2017-07-09 21:04:00+03	40900.00
BAFFD8	2017-07-12 10:02:00+03	25400.00
BB006B	2017-07-10 19:06:00+03	48800.00
BB0108	2017-08-11 20:10:00+03	19600.00
BB010D	2017-07-14 01:07:00+03	62600.00
BB0133	2017-07-14 19:54:00+03	6700.00
BB015B	2017-07-15 22:05:00+03	56000.00
BB0180	2017-07-03 20:30:00+03	75600.00
BB0186	2017-07-10 11:04:00+03	80500.00
BB01AB	2017-07-08 11:58:00+03	6000.00
BB01E5	2017-08-12 09:57:00+03	173600.00
BB0214	2017-07-11 10:15:00+03	72300.00
BB027E	2017-07-22 06:37:00+03	49900.00
BB02BA	2017-08-10 10:32:00+03	136800.00
BB02D5	2017-08-12 05:19:00+03	37900.00
BB0375	2017-08-01 19:38:00+03	56100.00
BB03D9	2017-07-27 00:20:00+03	135400.00
BB03E4	2017-08-09 22:50:00+03	51800.00
BB03EF	2017-07-21 17:02:00+03	46400.00
BB0480	2017-06-28 03:50:00+03	38200.00
BB04A7	2017-07-12 09:25:00+03	134700.00
BB04DE	2017-07-15 06:13:00+03	51300.00
BB04E8	2017-07-04 04:22:00+03	133200.00
BB04EE	2017-08-09 21:51:00+03	35200.00
BB0559	2017-08-04 18:55:00+03	50300.00
BB0603	2017-08-08 03:18:00+03	77600.00
BB063D	2017-07-10 13:39:00+03	70600.00
BB065B	2017-08-05 05:19:00+03	27800.00
BB0677	2017-07-28 00:26:00+03	46400.00
BB06BE	2017-08-14 19:37:00+03	66600.00
BB06D9	2017-07-26 13:56:00+03	32800.00
BB06E4	2017-08-09 10:49:00+03	26700.00
BB06FF	2017-07-01 08:06:00+03	47800.00
BB071E	2017-08-15 04:36:00+03	396500.00
BB0747	2017-07-24 19:08:00+03	195600.00
BB07B4	2017-08-11 13:17:00+03	92100.00
BB07D8	2017-08-14 19:51:00+03	44800.00
BB07E5	2017-07-20 15:10:00+03	88600.00
BB0822	2017-08-14 05:05:00+03	80800.00
BB0857	2017-08-02 15:02:00+03	28000.00
BB0866	2017-08-13 14:53:00+03	52000.00
BB0886	2017-07-18 04:37:00+03	32800.00
BB0933	2017-08-11 19:28:00+03	39500.00
BB0948	2017-08-08 10:47:00+03	26000.00
BB0989	2017-07-07 22:14:00+03	166100.00
BB0A1D	2017-08-07 23:17:00+03	55600.00
BB0A34	2017-07-16 02:24:00+03	43600.00
BB0A4B	2017-08-04 16:54:00+03	51400.00
BB0A70	2017-07-30 17:51:00+03	9800.00
BB0AEB	2017-07-02 11:48:00+03	48800.00
BB0B02	2017-08-09 19:06:00+03	123000.00
BB0B30	2017-07-12 16:07:00+03	277900.00
BB0B37	2017-07-18 23:13:00+03	60200.00
BB0B42	2017-07-27 17:26:00+03	130300.00
BB0B70	2017-07-10 05:35:00+03	96200.00
BB0C75	2017-07-24 06:51:00+03	86600.00
BB0C97	2017-07-10 21:53:00+03	40800.00
BB0CFE	2017-07-16 09:42:00+03	75300.00
BB0D2E	2017-08-03 01:07:00+03	28000.00
BB0D46	2017-07-18 12:51:00+03	72800.00
BB0DAE	2017-08-05 12:56:00+03	73400.00
BB0DED	2017-08-14 03:12:00+03	44000.00
BB0E3C	2017-08-14 10:59:00+03	421200.00
BB0E7F	2017-07-06 05:39:00+03	15700.00
BB0EA7	2017-08-07 01:00:00+03	55800.00
BB0EB7	2017-07-10 09:07:00+03	12400.00
BB0EB9	2017-07-27 13:28:00+03	206100.00
BB0EFC	2017-08-07 15:30:00+03	21000.00
BB0F2A	2017-08-07 17:51:00+03	133200.00
BB0FB1	2017-08-13 15:11:00+03	95200.00
BB1024	2017-07-13 13:51:00+03	24500.00
BB102C	2017-08-03 09:47:00+03	47000.00
BB105A	2017-07-29 21:19:00+03	29600.00
BB10B9	2017-07-05 17:04:00+03	25000.00
BB10BF	2017-08-07 04:06:00+03	32700.00
BB110B	2017-08-14 00:54:00+03	12000.00
BB1136	2017-07-02 21:02:00+03	58600.00
BB1234	2017-07-30 20:58:00+03	8200.00
BB1241	2017-07-25 06:06:00+03	181000.00
BB1276	2017-07-13 19:27:00+03	49600.00
BB12CD	2017-07-12 07:34:00+03	62600.00
BB130B	2017-07-20 04:48:00+03	29000.00
BB1336	2017-08-05 01:38:00+03	82200.00
BB13B6	2017-07-07 17:51:00+03	27800.00
BB13D4	2017-08-02 19:33:00+03	133600.00
BB1403	2017-07-14 20:07:00+03	38200.00
BB145F	2017-07-07 10:45:00+03	53300.00
BB14AF	2017-07-10 10:20:00+03	46400.00
BB1501	2017-07-28 04:21:00+03	64700.00
BB15B6	2017-08-11 09:42:00+03	26000.00
BB15E3	2017-07-30 20:42:00+03	88800.00
BB1723	2017-07-12 15:39:00+03	170000.00
BB1786	2017-08-02 07:48:00+03	123000.00
BB17B8	2017-08-06 19:59:00+03	21400.00
BB17BD	2017-08-10 09:15:00+03	50100.00
BB17C1	2017-08-02 12:05:00+03	452600.00
BB1857	2017-07-27 13:45:00+03	29400.00
BB189C	2017-07-29 13:44:00+03	25000.00
BB18A9	2017-07-07 05:11:00+03	23200.00
BB18B8	2017-07-23 11:20:00+03	42800.00
BB19A8	2017-07-16 09:43:00+03	36200.00
BB1AAD	2017-08-04 23:09:00+03	32200.00
BB1B66	2017-07-02 15:24:00+03	95200.00
BB1B71	2017-08-15 05:37:00+03	61800.00
BB1BD7	2017-07-10 09:20:00+03	20400.00
BB1C19	2017-07-13 14:19:00+03	272700.00
BB1C43	2017-07-25 15:35:00+03	23900.00
BB1D0B	2017-07-27 13:21:00+03	37900.00
BB1D34	2017-07-24 11:34:00+03	46500.00
BB1D52	2017-08-08 09:33:00+03	16400.00
BB1DCA	2017-07-17 14:59:00+03	62600.00
BB1DE1	2017-07-22 15:15:00+03	135600.00
BB1EC4	2017-07-28 12:56:00+03	37500.00
BB1EEB	2017-07-16 15:32:00+03	66600.00
BB1F19	2017-07-21 11:49:00+03	73200.00
BB205F	2017-08-05 19:17:00+03	7400.00
BB2122	2017-07-25 16:34:00+03	6400.00
BB213D	2017-07-11 02:29:00+03	25000.00
BB2172	2017-07-09 02:44:00+03	107400.00
BB21F7	2017-08-04 23:27:00+03	40300.00
BB22B1	2017-07-21 07:09:00+03	73300.00
BB22CA	2017-07-22 22:18:00+03	38600.00
BB22DD	2017-07-29 05:18:00+03	131600.00
BB23A4	2017-07-04 17:29:00+03	120800.00
BB23F4	2017-07-31 23:38:00+03	168000.00
BB2427	2017-07-28 11:51:00+03	54800.00
BB24AE	2017-08-03 07:20:00+03	22000.00
BB24F3	2017-07-14 16:30:00+03	133400.00
BB2511	2017-07-24 01:36:00+03	114500.00
BB2520	2017-07-19 22:31:00+03	8000.00
BB255C	2017-07-20 20:29:00+03	44600.00
BB255F	2017-07-21 04:48:00+03	81700.00
BB25B3	2017-07-06 14:33:00+03	12400.00
BB260A	2017-07-09 13:05:00+03	14800.00
BB261B	2017-07-28 03:04:00+03	59100.00
BB2641	2017-07-25 15:39:00+03	12000.00
BB26C4	2017-07-14 11:27:00+03	68100.00
BB27A2	2017-08-13 19:13:00+03	49500.00
BB27AC	2017-08-04 18:48:00+03	119000.00
BB27B4	2017-08-09 16:33:00+03	69000.00
BB27F2	2017-08-04 01:32:00+03	124000.00
BB281B	2017-08-07 01:44:00+03	92800.00
BB283D	2017-08-15 04:32:00+03	13400.00
BB285F	2017-07-11 12:03:00+03	55600.00
BB28A2	2017-08-10 10:02:00+03	16400.00
BB28C4	2017-08-01 19:07:00+03	27200.00
BB28C6	2017-07-08 09:56:00+03	46400.00
BB2952	2017-07-28 04:55:00+03	67600.00
BB29F7	2017-07-29 11:50:00+03	188000.00
BB2A51	2017-07-30 02:52:00+03	270000.00
BB2A91	2017-07-25 17:16:00+03	8000.00
BB2AE3	2017-08-13 14:56:00+03	40000.00
BB2B27	2017-07-05 18:22:00+03	50500.00
BB2B4D	2017-07-10 08:15:00+03	6600.00
BB2B7C	2017-07-08 09:39:00+03	77200.00
BB2BB8	2017-06-29 11:37:00+03	260900.00
BB2BBA	2017-07-24 23:59:00+03	532800.00
BB2BBB	2017-07-28 14:08:00+03	116600.00
BB2BF6	2017-07-11 02:40:00+03	8000.00
BB2C06	2017-07-20 08:42:00+03	56600.00
BB2C0A	2017-07-07 21:13:00+03	286100.00
BB2C1B	2017-07-19 12:30:00+03	63200.00
BB2C1C	2017-07-06 12:26:00+03	270800.00
BB2C21	2017-07-22 13:30:00+03	173500.00
BB2CD4	2017-07-06 05:35:00+03	202300.00
BB2CF3	2017-07-10 02:57:00+03	55900.00
BB2D0A	2017-07-20 15:10:00+03	29800.00
BB2D6C	2017-07-21 05:58:00+03	95200.00
BB2D89	2017-08-14 12:12:00+03	31300.00
BB2E26	2017-08-13 03:41:00+03	176200.00
BB2E27	2017-08-12 00:38:00+03	254500.00
BB2E37	2017-07-24 16:56:00+03	40000.00
BB2E86	2017-07-18 09:03:00+03	26000.00
BB2EF9	2017-07-22 17:42:00+03	59100.00
BB2F02	2017-07-13 22:29:00+03	39500.00
BB2F5C	2017-07-31 07:14:00+03	22000.00
BB2F6B	2017-08-03 15:28:00+03	240500.00
BB2FB1	2017-07-24 14:20:00+03	21400.00
BB2FDF	2017-07-13 10:40:00+03	131600.00
BB2FE3	2017-07-05 03:19:00+03	166000.00
BB2FF7	2017-07-20 14:47:00+03	93900.00
BB3015	2017-08-09 21:39:00+03	51900.00
BB3050	2017-07-31 18:53:00+03	47000.00
BB30A0	2017-07-10 01:51:00+03	90700.00
BB30CE	2017-08-01 07:04:00+03	37700.00
BB310D	2017-07-22 13:15:00+03	112000.00
BB3135	2017-07-23 04:15:00+03	24400.00
BB3149	2017-07-24 05:20:00+03	86200.00
BB3187	2017-07-29 02:40:00+03	32800.00
BB318F	2017-07-17 23:35:00+03	34000.00
BB31D4	2017-07-18 06:36:00+03	51800.00
BB3259	2017-08-13 17:00:00+03	52000.00
BB331C	2017-07-05 15:08:00+03	46200.00
BB3346	2017-07-12 16:53:00+03	55500.00
BB336D	2017-07-02 10:54:00+03	72400.00
BB33D2	2017-08-03 19:48:00+03	40400.00
BB33FC	2017-07-04 10:43:00+03	70800.00
BB3422	2017-07-30 17:40:00+03	26000.00
BB346B	2017-07-30 07:07:00+03	48800.00
BB349F	2017-07-21 02:04:00+03	45000.00
BB34A4	2017-07-20 12:47:00+03	52800.00
BB3508	2017-07-15 13:15:00+03	66200.00
BB3576	2017-08-06 05:56:00+03	60600.00
BB3585	2017-07-23 07:43:00+03	20000.00
BB360D	2017-07-24 01:36:00+03	68000.00
BB3613	2017-07-20 08:16:00+03	44700.00
BB36AD	2017-08-10 03:19:00+03	15900.00
BB3775	2017-08-01 20:48:00+03	27200.00
BB377A	2017-07-12 11:23:00+03	136500.00
BB37A7	2017-07-21 09:10:00+03	37200.00
BB37C5	2017-07-29 22:28:00+03	93900.00
BB37D0	2017-07-09 15:26:00+03	50600.00
BB3810	2017-08-08 13:42:00+03	169900.00
BB38B4	2017-07-10 15:43:00+03	69600.00
BB38E1	2017-08-09 07:23:00+03	37200.00
BB3943	2017-08-01 14:45:00+03	174400.00
BB395F	2017-08-07 12:44:00+03	34600.00
BB3A74	2017-07-21 10:50:00+03	42800.00
BB3AD2	2017-07-16 17:05:00+03	40800.00
BB3AF8	2017-07-28 22:59:00+03	83000.00
BB3B25	2017-07-04 16:44:00+03	35200.00
BB3B39	2017-07-20 18:01:00+03	16400.00
BB3B8B	2017-08-14 06:38:00+03	55800.00
BB3C0D	2017-07-09 19:46:00+03	21400.00
BB3C93	2017-08-13 02:09:00+03	13500.00
BB3C94	2017-07-14 16:45:00+03	38300.00
BB3D0D	2017-07-05 12:04:00+03	66600.00
BB3DA5	2017-07-24 13:02:00+03	22600.00
BB3DCC	2017-08-11 14:30:00+03	20200.00
BB3E12	2017-08-09 09:31:00+03	108300.00
BB3E14	2017-07-06 14:48:00+03	56000.00
BB3E62	2017-07-17 09:55:00+03	43900.00
BB3EDE	2017-07-20 06:22:00+03	74500.00
BB3F36	2017-08-02 18:11:00+03	187600.00
BB3FBE	2017-06-26 17:23:00+03	38400.00
BB3FCE	2017-08-05 02:49:00+03	85000.00
BB4022	2017-08-05 10:35:00+03	66000.00
BB4046	2017-08-09 00:09:00+03	43000.00
BB40CF	2017-06-29 12:56:00+03	145100.00
BB4129	2017-07-15 21:34:00+03	16400.00
BB4158	2017-07-20 16:24:00+03	75300.00
BB4185	2017-08-15 04:18:00+03	266400.00
BB41B1	2017-07-14 16:03:00+03	56000.00
BB41B6	2017-08-06 22:50:00+03	40800.00
BB41FF	2017-07-19 13:37:00+03	40400.00
BB4214	2017-07-09 08:05:00+03	241200.00
BB4254	2017-07-26 17:23:00+03	126700.00
BB42B8	2017-07-20 22:55:00+03	248400.00
BB4334	2017-08-07 11:02:00+03	12000.00
BB4336	2017-06-27 08:27:00+03	170600.00
BB436A	2017-08-01 21:41:00+03	6800.00
BB4436	2017-08-14 03:14:00+03	43000.00
BB4490	2017-07-20 11:08:00+03	68800.00
BB4510	2017-06-30 13:00:00+03	93900.00
BB4515	2017-07-14 15:38:00+03	69500.00
BB4532	2017-07-23 07:13:00+03	32700.00
BB4576	2017-08-09 17:11:00+03	204200.00
BB460E	2017-07-04 19:15:00+03	112200.00
BB467D	2017-08-06 23:51:00+03	124200.00
BB46B3	2017-08-15 01:57:00+03	49600.00
BB46B5	2017-07-19 17:12:00+03	52000.00
BB46BA	2017-07-27 10:58:00+03	80100.00
BB46D6	2017-08-14 02:58:00+03	73600.00
BB4727	2017-06-28 02:05:00+03	28000.00
BB4763	2017-07-17 07:59:00+03	10800.00
BB4765	2017-06-29 12:38:00+03	111600.00
BB4798	2017-07-27 10:24:00+03	83900.00
BB47A3	2017-07-22 23:59:00+03	39800.00
BB47CA	2017-07-15 14:51:00+03	59700.00
BB4809	2017-07-05 18:35:00+03	219900.00
BB482B	2017-07-01 12:53:00+03	407100.00
BB4863	2017-07-04 14:04:00+03	110000.00
BB48F5	2017-07-22 15:47:00+03	51900.00
BB491D	2017-07-27 04:44:00+03	93000.00
BB499E	2017-07-05 09:58:00+03	11800.00
BB4ADA	2017-07-16 17:04:00+03	14400.00
BB4B16	2017-07-10 12:39:00+03	28000.00
BB4BC2	2017-08-04 20:10:00+03	22000.00
BB4BD5	2017-08-03 09:06:00+03	153600.00
BB4C39	2017-06-30 01:44:00+03	32100.00
BB4C89	2017-07-25 19:07:00+03	136500.00
BB4CA4	2017-08-03 23:07:00+03	26000.00
BB4CA5	2017-08-09 20:24:00+03	40300.00
BB4CA8	2017-07-13 15:57:00+03	116000.00
BB4CBF	2017-08-11 12:23:00+03	45200.00
BB4D01	2017-07-17 04:48:00+03	23200.00
BB4D7D	2017-07-17 14:58:00+03	54300.00
BB4D85	2017-08-11 11:00:00+03	75300.00
BB4DDF	2017-07-11 15:21:00+03	174400.00
BB4E05	2017-07-22 02:19:00+03	22200.00
BB4EA3	2017-07-18 04:28:00+03	69500.00
BB4EB8	2017-08-12 07:56:00+03	55800.00
BB4F41	2017-06-25 23:29:00+03	28800.00
BB4F7B	2017-06-28 03:15:00+03	63400.00
BB4F94	2017-08-12 14:57:00+03	173200.00
BB50A5	2017-08-06 19:42:00+03	68800.00
BB513C	2017-07-23 08:41:00+03	38000.00
BB515E	2017-07-09 07:11:00+03	75300.00
BB5179	2017-08-12 20:42:00+03	295400.00
BB5197	2017-08-05 05:22:00+03	57400.00
BB51F8	2017-07-11 13:21:00+03	118900.00
BB520F	2017-08-06 00:44:00+03	293900.00
BB5210	2017-07-29 05:16:00+03	80900.00
BB523A	2017-08-13 16:26:00+03	38400.00
BB5265	2017-08-04 04:27:00+03	28800.00
BB52BF	2017-07-14 17:22:00+03	43500.00
BB52C0	2017-07-03 19:23:00+03	155600.00
BB52F7	2017-07-04 21:23:00+03	128800.00
BB532C	2017-07-16 16:52:00+03	125200.00
BB53ED	2017-07-31 02:57:00+03	56000.00
BB541F	2017-08-14 23:18:00+03	37900.00
BB5432	2017-07-08 16:53:00+03	36200.00
BB5497	2017-08-04 13:11:00+03	202300.00
BB5539	2017-07-16 00:09:00+03	28000.00
BB5545	2017-08-15 11:19:00+03	37700.00
BB5579	2017-08-10 13:53:00+03	35600.00
BB5632	2017-07-10 21:55:00+03	49100.00
BB5645	2017-07-29 16:12:00+03	45200.00
BB564D	2017-07-10 11:03:00+03	16400.00
BB5671	2017-07-07 11:24:00+03	35600.00
BB5685	2017-07-01 21:06:00+03	65500.00
BB56A1	2017-08-03 15:11:00+03	39300.00
BB5733	2017-07-27 06:33:00+03	102200.00
BB575D	2017-07-14 17:12:00+03	112600.00
BB5760	2017-07-22 04:25:00+03	29600.00
BB5775	2017-07-27 13:42:00+03	57200.00
BB57A1	2017-08-11 20:24:00+03	37900.00
BB57BF	2017-08-06 16:15:00+03	31600.00
BB58CA	2017-07-15 13:27:00+03	78300.00
BB5962	2017-07-07 03:52:00+03	53200.00
BB596A	2017-07-04 04:08:00+03	65900.00
BB599A	2017-08-11 10:02:00+03	144300.00
BB59E3	2017-07-17 13:29:00+03	89200.00
BB5A13	2017-08-07 09:10:00+03	40800.00
BB5A71	2017-08-15 04:53:00+03	13200.00
BB5A9F	2017-07-01 15:08:00+03	80900.00
BB5B02	2017-07-28 18:11:00+03	39200.00
BB5BD2	2017-08-01 16:44:00+03	142800.00
BB5BFF	2017-07-15 03:44:00+03	23600.00
BB5CF6	2017-07-23 20:31:00+03	81600.00
BB5D20	2017-07-27 02:46:00+03	46400.00
BB5DC1	2017-07-27 17:47:00+03	272600.00
BB5DDD	2017-08-05 12:38:00+03	42800.00
BB5E43	2017-08-07 02:55:00+03	188600.00
BB5E49	2017-07-14 07:27:00+03	70700.00
BB5E68	2017-07-11 21:25:00+03	92200.00
BB5E7A	2017-07-03 19:50:00+03	36200.00
BB5F37	2017-07-12 01:57:00+03	25200.00
BB5F7B	2017-07-23 23:55:00+03	205900.00
BB5FC6	2017-08-07 01:52:00+03	18100.00
BB5FF5	2017-08-01 13:57:00+03	88600.00
BB6048	2017-07-29 11:38:00+03	132800.00
BB60E2	2017-07-31 08:16:00+03	47400.00
BB6149	2017-07-26 18:48:00+03	14400.00
BB615C	2017-07-29 14:58:00+03	58200.00
BB61BA	2017-07-04 11:14:00+03	54400.00
BB6215	2017-07-31 09:03:00+03	65900.00
BB6248	2017-07-23 17:53:00+03	229000.00
BB624E	2017-07-25 06:19:00+03	13000.00
BB625A	2017-07-15 13:54:00+03	36800.00
BB629F	2017-07-08 07:37:00+03	194200.00
BB62A8	2017-07-17 07:40:00+03	283500.00
BB62AC	2017-07-09 21:49:00+03	56600.00
BB62BD	2017-08-01 14:04:00+03	12000.00
BB62CB	2017-07-30 05:35:00+03	31800.00
BB632D	2017-07-28 13:24:00+03	281500.00
BB633C	2017-07-21 08:44:00+03	75800.00
BB6345	2017-07-22 17:21:00+03	101200.00
BB635F	2017-07-13 03:56:00+03	29600.00
BB63DA	2017-07-13 03:08:00+03	23600.00
BB63EA	2017-07-17 09:10:00+03	31000.00
BB63FF	2017-07-24 17:51:00+03	94800.00
BB640B	2017-07-05 12:44:00+03	28000.00
BB641B	2017-07-08 01:15:00+03	56000.00
BB64C0	2017-07-30 19:52:00+03	97800.00
BB652F	2017-07-15 11:33:00+03	145400.00
BB65E8	2017-08-06 00:37:00+03	95200.00
BB6625	2017-08-05 00:40:00+03	16400.00
BB66E5	2017-08-04 20:58:00+03	32400.00
BB66E9	2017-07-13 23:50:00+03	51200.00
BB673F	2017-08-13 22:27:00+03	47400.00
BB67D2	2017-08-12 18:43:00+03	26000.00
BB6819	2017-07-06 04:05:00+03	31400.00
BB6871	2017-06-30 23:12:00+03	160200.00
BB68CC	2017-08-14 19:50:00+03	38600.00
BB68FC	2017-07-07 20:45:00+03	119700.00
BB6978	2017-07-16 02:18:00+03	46000.00
BB699A	2017-07-11 11:20:00+03	116400.00
BB69B2	2017-07-29 00:11:00+03	23900.00
BB69E3	2017-07-11 12:28:00+03	47200.00
BB6A0D	2017-08-04 17:29:00+03	54500.00
BB6A12	2017-06-30 05:52:00+03	26000.00
BB6A3A	2017-07-18 21:15:00+03	56600.00
BB6A9B	2017-08-05 17:40:00+03	66600.00
BB6AAC	2017-07-18 14:46:00+03	71300.00
BB6B2A	2017-08-03 04:07:00+03	111600.00
BB6B35	2017-07-21 16:43:00+03	496700.00
BB6B57	2017-08-14 05:29:00+03	46400.00
BB6C18	2017-07-24 06:18:00+03	56000.00
BB6C2C	2017-07-02 11:32:00+03	16400.00
BB6C4C	2017-07-20 19:57:00+03	87400.00
BB6C4E	2017-07-03 16:26:00+03	44300.00
BB6CAD	2017-08-06 08:26:00+03	51600.00
BB6D26	2017-07-03 05:34:00+03	45200.00
BB6D56	2017-08-13 10:26:00+03	103800.00
BB6DFD	2017-08-12 15:31:00+03	15800.00
BB6E02	2017-07-31 18:37:00+03	244100.00
BB6E27	2017-07-08 07:55:00+03	27700.00
BB6E40	2017-07-22 22:28:00+03	99300.00
BB6EDD	2017-07-09 05:37:00+03	12400.00
BB6F21	2017-07-31 02:10:00+03	129700.00
BB6F3A	2017-08-10 07:16:00+03	27900.00
BB7037	2017-08-13 03:59:00+03	40000.00
BB7049	2017-08-05 12:19:00+03	25900.00
BB7052	2017-07-13 00:20:00+03	73600.00
BB7067	2017-07-30 03:58:00+03	96300.00
BB709D	2017-07-22 20:15:00+03	133100.00
BB70EF	2017-08-14 06:20:00+03	32400.00
BB7194	2017-07-13 04:17:00+03	130400.00
BB71A0	2017-07-04 09:33:00+03	58900.00
BB71AA	2017-08-04 10:12:00+03	532700.00
BB71BB	2017-07-09 10:16:00+03	31600.00
BB7277	2017-07-31 06:09:00+03	6400.00
BB7298	2017-07-28 18:40:00+03	70500.00
BB72C4	2017-07-28 09:22:00+03	174600.00
BB72EA	2017-07-13 05:55:00+03	14400.00
BB7324	2017-08-03 17:01:00+03	58200.00
BB7343	2017-07-31 19:42:00+03	46200.00
BB7396	2017-07-24 20:08:00+03	18000.00
BB73A3	2017-08-12 14:59:00+03	46200.00
BB73AF	2017-07-02 02:47:00+03	166100.00
BB73BE	2017-08-12 04:47:00+03	21800.00
BB7435	2017-07-11 01:48:00+03	27500.00
BB746B	2017-07-27 08:31:00+03	45200.00
BB7500	2017-07-29 04:53:00+03	284400.00
BB7506	2017-07-29 15:14:00+03	133200.00
BB7568	2017-08-11 06:51:00+03	72400.00
BB7613	2017-08-15 06:59:00+03	48700.00
BB761F	2017-07-23 09:13:00+03	62700.00
BB7636	2017-08-05 20:47:00+03	6000.00
BB7641	2017-07-01 15:12:00+03	10800.00
BB7663	2017-08-09 21:39:00+03	30200.00
BB7673	2017-07-14 18:13:00+03	135400.00
BB7692	2017-07-12 18:59:00+03	156000.00
BB7694	2017-08-07 07:08:00+03	47400.00
BB76DA	2017-08-05 14:38:00+03	146300.00
BB76E5	2017-07-16 04:07:00+03	119600.00
BB76FF	2017-08-13 12:09:00+03	51900.00
BB7717	2017-07-11 16:20:00+03	124200.00
BB771E	2017-08-11 16:10:00+03	47000.00
BB771F	2017-07-15 17:36:00+03	12400.00
BB7726	2017-07-31 07:25:00+03	199800.00
BB772B	2017-07-18 21:24:00+03	151200.00
BB7782	2017-08-01 17:29:00+03	63500.00
BB77C0	2017-07-30 17:33:00+03	26000.00
BB78BC	2017-07-20 02:34:00+03	75600.00
BB78CD	2017-07-13 18:25:00+03	25900.00
BB78FD	2017-07-11 22:47:00+03	56900.00
BB7943	2017-07-30 20:11:00+03	160200.00
BB795D	2017-08-15 07:52:00+03	28800.00
BB7983	2017-07-18 05:48:00+03	56100.00
BB798E	2017-06-29 07:16:00+03	59800.00
BB79C5	2017-07-29 09:31:00+03	56000.00
BB7A45	2017-07-25 13:17:00+03	111600.00
BB7A71	2017-07-03 20:07:00+03	53100.00
BB7A73	2017-08-06 00:01:00+03	29800.00
BB7B10	2017-07-13 12:01:00+03	111600.00
BB7B72	2017-06-30 23:08:00+03	40800.00
BB7B9A	2017-07-24 13:06:00+03	70800.00
BB7BA3	2017-07-09 07:43:00+03	48800.00
BB7BDF	2017-07-18 02:45:00+03	111600.00
BB7BF0	2017-07-25 18:44:00+03	18600.00
BB7CC8	2017-07-07 11:44:00+03	90100.00
BB7CE1	2017-07-02 00:44:00+03	532800.00
BB7DC0	2017-07-23 18:26:00+03	48800.00
BB7E19	2017-07-31 03:44:00+03	46300.00
BB7E36	2017-07-04 00:54:00+03	265600.00
BB7E96	2017-08-06 02:24:00+03	168000.00
BB7EA2	2017-07-27 17:53:00+03	112000.00
BB7EA9	2017-08-14 21:51:00+03	70800.00
BB7F70	2017-07-24 23:51:00+03	113300.00
BB7FB1	2017-08-03 10:37:00+03	325500.00
BB8009	2017-08-05 23:43:00+03	75500.00
BB8040	2017-08-08 02:18:00+03	111600.00
BB8051	2017-07-10 17:58:00+03	23200.00
BB80AD	2017-08-09 20:41:00+03	24800.00
BB8147	2017-07-19 19:37:00+03	34000.00
BB81BE	2017-07-26 00:52:00+03	40800.00
BB81C9	2017-07-10 02:33:00+03	136200.00
BB8210	2017-07-31 05:24:00+03	125200.00
BB8223	2017-07-07 23:01:00+03	86600.00
BB8234	2017-08-15 14:45:00+03	146000.00
BB8249	2017-07-23 05:10:00+03	155400.00
BB8287	2017-07-22 21:09:00+03	83200.00
BB829B	2017-07-08 06:21:00+03	61400.00
BB82CE	2017-08-14 15:54:00+03	326300.00
BB82DF	2017-07-04 21:34:00+03	465800.00
BB82E2	2017-07-14 22:59:00+03	31600.00
BB82F6	2017-08-12 06:24:00+03	8200.00
BB836F	2017-06-29 13:55:00+03	116000.00
BB83A3	2017-07-17 03:05:00+03	48800.00
BB83AF	2017-07-12 12:40:00+03	44800.00
BB83E8	2017-06-30 04:53:00+03	60800.00
BB841E	2017-06-27 04:07:00+03	136600.00
BB841F	2017-07-24 15:19:00+03	110500.00
BB84C1	2017-07-02 02:34:00+03	48800.00
BB850D	2017-07-09 07:54:00+03	185600.00
BB8513	2017-07-14 20:53:00+03	176500.00
BB8560	2017-07-10 01:43:00+03	88800.00
BB858B	2017-07-20 08:10:00+03	59800.00
BB859B	2017-07-06 03:40:00+03	58200.00
BB85AB	2017-07-09 21:45:00+03	411900.00
BB8613	2017-07-09 02:55:00+03	20200.00
BB862D	2017-06-30 03:20:00+03	39600.00
BB8634	2017-07-30 01:09:00+03	113200.00
BB8689	2017-08-08 09:51:00+03	36000.00
BB872F	2017-07-16 13:36:00+03	34100.00
BB8778	2017-07-16 21:59:00+03	12400.00
BB87CB	2017-07-03 01:16:00+03	92700.00
BB87E2	2017-07-24 20:55:00+03	112300.00
BB880F	2017-08-10 21:44:00+03	34000.00
BB88B9	2017-08-11 14:26:00+03	73200.00
BB8933	2017-07-20 21:05:00+03	35200.00
BB8976	2017-08-11 21:52:00+03	86400.00
BB89F7	2017-07-08 07:06:00+03	31100.00
BB8ABB	2017-08-15 17:32:00+03	40400.00
BB8ADC	2017-07-06 23:21:00+03	132800.00
BB8B0F	2017-07-13 09:53:00+03	85000.00
BB8BB1	2017-07-16 19:45:00+03	28000.00
BB8BC7	2017-07-20 23:40:00+03	82200.00
BB8C39	2017-08-15 15:27:00+03	27200.00
BB8C3A	2017-08-03 00:25:00+03	6000.00
BB8C43	2017-07-27 21:53:00+03	50200.00
BB8C44	2017-08-08 11:06:00+03	258400.00
BB8CFC	2017-07-23 09:16:00+03	79900.00
BB8D17	2017-07-14 13:12:00+03	111600.00
BB8D19	2017-08-13 23:37:00+03	77800.00
BB8D43	2017-07-10 11:23:00+03	37600.00
BB8D4D	2017-08-09 05:13:00+03	118700.00
BB8D70	2017-08-14 12:55:00+03	36500.00
BB8DF0	2017-08-14 05:58:00+03	51900.00
BB8E12	2017-07-09 04:01:00+03	23200.00
BB8E1A	2017-07-13 12:24:00+03	10800.00
BB8E56	2017-08-12 23:33:00+03	65900.00
BB8E5D	2017-07-11 11:09:00+03	62100.00
BB8E8C	2017-07-24 23:50:00+03	66200.00
BB8ED3	2017-07-19 15:06:00+03	131100.00
BB8EF7	2017-07-09 09:22:00+03	12600.00
BB8F91	2017-08-06 20:45:00+03	18600.00
BB8FAC	2017-07-17 10:56:00+03	67600.00
BB9062	2017-08-10 15:21:00+03	38400.00
BB90F1	2017-07-25 20:39:00+03	33100.00
BB913B	2017-07-09 14:45:00+03	102100.00
BB913C	2017-08-15 16:28:00+03	12600.00
BB9171	2017-07-31 17:07:00+03	62600.00
BB91DA	2017-07-29 12:34:00+03	93700.00
BB9223	2017-08-13 08:19:00+03	167400.00
BB92C5	2017-07-03 19:31:00+03	13000.00
BB9307	2017-08-06 14:27:00+03	239800.00
BB930B	2017-07-10 07:21:00+03	133200.00
BB9348	2017-08-01 07:15:00+03	29200.00
BB9353	2017-08-01 13:28:00+03	58600.00
BB935D	2017-08-02 19:39:00+03	51900.00
BB9367	2017-07-17 07:53:00+03	31600.00
BB9372	2017-07-18 22:09:00+03	25200.00
BB93BC	2017-07-29 04:50:00+03	135200.00
BB941F	2017-07-09 08:21:00+03	20100.00
BB94D9	2017-07-12 11:08:00+03	23600.00
BB950B	2017-07-01 00:13:00+03	20000.00
BB951A	2017-07-26 06:35:00+03	23600.00
BB951E	2017-07-18 09:39:00+03	56000.00
BB9536	2017-06-29 05:03:00+03	137600.00
BB9563	2017-08-13 11:15:00+03	13400.00
BB95CA	2017-08-01 22:03:00+03	36100.00
BB9632	2017-07-26 02:04:00+03	27300.00
BB9671	2017-07-07 08:35:00+03	149000.00
BB96E5	2017-07-11 20:32:00+03	30200.00
BB974F	2017-08-06 17:33:00+03	91900.00
BB976D	2017-07-01 19:33:00+03	96100.00
BB9785	2017-08-12 13:36:00+03	16000.00
BB97A8	2017-07-16 10:36:00+03	46800.00
BB986A	2017-08-06 14:33:00+03	56000.00
BB986D	2017-07-07 09:05:00+03	124000.00
BB989B	2017-08-10 10:17:00+03	23400.00
BB98A7	2017-08-07 07:04:00+03	67100.00
BB98AE	2017-07-31 23:47:00+03	20200.00
BB992A	2017-07-28 18:49:00+03	39800.00
BB9941	2017-07-17 18:48:00+03	30200.00
BB999C	2017-07-15 12:04:00+03	233300.00
BB999E	2017-07-22 08:50:00+03	56600.00
BB99A5	2017-07-06 10:40:00+03	56000.00
BB99A6	2017-07-20 06:27:00+03	50800.00
BB9A0D	2017-07-28 13:26:00+03	51100.00
BB9A88	2017-07-14 02:46:00+03	24400.00
BB9AF1	2017-07-31 13:08:00+03	40800.00
BB9B1E	2017-08-05 17:54:00+03	43200.00
BB9C6B	2017-07-29 06:36:00+03	140300.00
BB9C90	2017-07-16 08:53:00+03	83000.00
BB9D60	2017-07-01 21:55:00+03	101200.00
BB9D76	2017-07-13 00:26:00+03	97000.00
BB9D84	2017-07-24 19:51:00+03	30800.00
BB9E55	2017-07-24 06:06:00+03	51900.00
BB9EAB	2017-08-10 00:55:00+03	77200.00
BB9EAC	2017-06-30 17:38:00+03	66400.00
BB9F4F	2017-07-30 16:47:00+03	71200.00
BB9F68	2017-08-07 21:09:00+03	66600.00
BB9F7E	2017-07-19 08:18:00+03	80900.00
BB9FF5	2017-08-08 21:47:00+03	55800.00
BBA005	2017-07-27 03:49:00+03	91500.00
BBA07D	2017-07-15 04:33:00+03	134400.00
BBA081	2017-07-26 11:19:00+03	58000.00
BBA099	2017-07-30 02:28:00+03	31400.00
BBA0FE	2017-07-26 13:47:00+03	61200.00
BBA11A	2017-07-21 07:26:00+03	99200.00
BBA140	2017-08-15 14:10:00+03	106100.00
BBA180	2017-07-01 18:02:00+03	66600.00
BBA20D	2017-08-08 04:24:00+03	28000.00
BBA231	2017-07-16 21:01:00+03	147000.00
BBA24C	2017-07-16 18:33:00+03	46700.00
BBA261	2017-07-12 22:59:00+03	98300.00
BBA2B3	2017-08-01 03:18:00+03	102100.00
BBA2EC	2017-08-03 00:40:00+03	52400.00
BBA300	2017-07-03 01:30:00+03	84800.00
BBA3DB	2017-08-01 07:03:00+03	22000.00
BBA3DF	2017-08-06 08:57:00+03	24400.00
BBA3EF	2017-07-17 16:53:00+03	101100.00
BBA439	2017-08-12 01:57:00+03	25600.00
BBA4BD	2017-07-20 17:18:00+03	68000.00
BBA4EF	2017-07-23 02:23:00+03	28000.00
BBA538	2017-07-26 05:42:00+03	51300.00
BBA58F	2017-07-24 15:25:00+03	90600.00
BBA5BC	2017-08-12 14:00:00+03	62000.00
BBA612	2017-08-14 13:38:00+03	133200.00
BBA639	2017-07-27 04:09:00+03	174400.00
BBA6C2	2017-07-06 14:34:00+03	77900.00
BBA6D7	2017-08-05 19:10:00+03	131600.00
BBA6EE	2017-07-04 12:05:00+03	124300.00
BBA70C	2017-08-14 14:01:00+03	53600.00
BBA76B	2017-07-18 00:59:00+03	46000.00
BBA7C6	2017-07-12 16:39:00+03	14400.00
BBA837	2017-08-10 15:49:00+03	135600.00
BBA83A	2017-07-07 14:34:00+03	6000.00
BBA84B	2017-07-17 22:34:00+03	32300.00
BBA8C3	2017-07-31 20:14:00+03	24400.00
BBA8C6	2017-07-10 02:19:00+03	56600.00
BBA8F1	2017-08-12 18:50:00+03	16400.00
BBA8FE	2017-08-04 05:49:00+03	285600.00
BBA917	2017-08-06 15:22:00+03	14000.00
BBA97B	2017-08-12 13:14:00+03	90800.00
BBA9B0	2017-07-19 01:42:00+03	26800.00
BBA9F6	2017-07-23 17:34:00+03	39800.00
BBAA39	2017-07-21 06:26:00+03	25600.00
BBAAA0	2017-07-08 17:06:00+03	258400.00
BBAACD	2017-08-14 03:35:00+03	13400.00
BBAAE6	2017-07-31 07:45:00+03	28800.00
BBAB31	2017-07-14 11:30:00+03	100600.00
BBAB34	2017-07-04 14:09:00+03	26700.00
BBAB47	2017-07-26 07:15:00+03	20800.00
BBABC8	2017-07-26 21:04:00+03	52300.00
BBABED	2017-08-14 18:02:00+03	220300.00
BBAC11	2017-07-18 10:15:00+03	46000.00
BBAC58	2017-08-12 21:35:00+03	40000.00
BBACE7	2017-07-05 09:01:00+03	52000.00
BBAD2E	2017-08-14 16:52:00+03	56000.00
BBAD6A	2017-07-31 03:58:00+03	8200.00
BBAD7B	2017-08-09 09:00:00+03	62700.00
BBAD81	2017-08-01 07:51:00+03	69500.00
BBAE05	2017-07-30 11:16:00+03	65800.00
BBAE31	2017-08-14 10:36:00+03	101800.00
BBAE6F	2017-08-01 01:37:00+03	30400.00
BBAF73	2017-07-01 16:07:00+03	34000.00
BBAF95	2017-08-13 16:20:00+03	265700.00
BBAFA1	2017-08-15 08:55:00+03	172100.00
BBAFCD	2017-07-04 08:48:00+03	161500.00
BBAFF4	2017-07-17 19:47:00+03	52800.00
BBB044	2017-07-25 16:50:00+03	47400.00
BBB064	2017-07-03 00:43:00+03	14000.00
BBB095	2017-07-09 01:14:00+03	152200.00
BBB0A3	2017-08-05 03:23:00+03	40400.00
BBB0B7	2017-07-21 22:13:00+03	29800.00
BBB154	2017-07-11 22:58:00+03	23600.00
BBB15F	2017-07-31 14:48:00+03	25100.00
BBB17F	2017-07-29 18:55:00+03	67600.00
BBB1AF	2017-08-12 23:48:00+03	73500.00
BBB204	2017-08-02 01:30:00+03	23400.00
BBB207	2017-07-12 02:35:00+03	39800.00
BBB24F	2017-07-01 08:14:00+03	111600.00
BBB266	2017-07-13 17:22:00+03	17200.00
BBB2B0	2017-07-16 12:08:00+03	36800.00
BBB3B7	2017-07-11 00:05:00+03	14900.00
BBB3BA	2017-07-10 00:38:00+03	85000.00
BBB3BF	2017-08-05 20:52:00+03	7400.00
BBB3D2	2017-07-11 10:17:00+03	64600.00
BBB431	2017-07-11 03:36:00+03	46000.00
BBB487	2017-07-04 06:51:00+03	113800.00
BBB56C	2017-07-16 05:59:00+03	123000.00
BBB574	2017-08-13 21:03:00+03	49100.00
BBB5D0	2017-07-12 01:12:00+03	6700.00
BBB643	2017-07-21 14:27:00+03	73200.00
BBB64C	2017-07-30 14:09:00+03	13000.00
BBB6D3	2017-08-01 11:51:00+03	60200.00
BBB6F9	2017-07-29 00:59:00+03	74600.00
BBB758	2017-07-26 02:17:00+03	129500.00
BBB795	2017-07-19 12:58:00+03	70600.00
BBB7A0	2017-08-03 19:19:00+03	28000.00
BBB7B5	2017-08-04 20:29:00+03	28800.00
BBB7CE	2017-07-10 13:03:00+03	179300.00
BBB7EB	2017-06-27 19:14:00+03	136600.00
BBB811	2017-07-21 20:22:00+03	273600.00
BBB82F	2017-07-04 03:20:00+03	649100.00
BBB847	2017-07-04 12:49:00+03	32800.00
BBB849	2017-07-22 17:44:00+03	61500.00
BBB885	2017-08-08 08:02:00+03	68800.00
BBB8C8	2017-08-15 11:47:00+03	8000.00
BBB8F7	2017-08-04 05:20:00+03	68800.00
BBB8FA	2017-07-03 09:33:00+03	31400.00
BBB917	2017-07-17 11:48:00+03	24300.00
BBB93C	2017-07-08 11:11:00+03	20200.00
BBB947	2017-08-08 11:53:00+03	77900.00
BBBA63	2017-07-18 07:06:00+03	8400.00
BBBABD	2017-07-30 10:59:00+03	58000.00
BBBB56	2017-07-19 11:32:00+03	35300.00
BBBBAC	2017-07-05 23:59:00+03	6000.00
BBBBB9	2017-08-02 18:19:00+03	28800.00
BBBBBD	2017-08-03 18:00:00+03	136200.00
BBBBD9	2017-07-16 20:11:00+03	26600.00
BBBC16	2017-08-10 18:14:00+03	88500.00
BBBC76	2017-07-16 12:14:00+03	73500.00
BBBCD7	2017-07-11 04:31:00+03	139100.00
BBBD36	2017-07-06 13:37:00+03	93400.00
BBBDF4	2017-07-12 21:09:00+03	58200.00
BBBE98	2017-08-07 04:16:00+03	263200.00
BBBE9C	2017-08-10 12:53:00+03	240600.00
BBBEF2	2017-07-20 14:36:00+03	29400.00
BBBF96	2017-07-20 19:39:00+03	88000.00
BBBF9B	2017-07-16 13:46:00+03	168100.00
BBC09B	2017-08-03 08:26:00+03	196000.00
BBC0BC	2017-07-09 15:12:00+03	28800.00
BBC0F1	2017-08-15 00:04:00+03	33900.00
BBC121	2017-08-05 13:25:00+03	57600.00
BBC1E3	2017-08-04 04:14:00+03	6900.00
BBC215	2017-07-03 09:29:00+03	23400.00
BBC26F	2017-07-18 09:01:00+03	49500.00
BBC2A6	2017-07-09 03:38:00+03	23600.00
BBC2BF	2017-06-29 20:31:00+03	35600.00
BBC32F	2017-08-10 11:10:00+03	49100.00
BBC36A	2017-07-22 08:29:00+03	32800.00
BBC382	2017-07-03 07:07:00+03	433300.00
BBC3D4	2017-07-14 16:38:00+03	40400.00
BBC402	2017-07-09 04:12:00+03	42400.00
BBC404	2017-07-31 08:35:00+03	652200.00
BBC47F	2017-07-09 14:50:00+03	56000.00
BBC4A2	2017-07-08 02:42:00+03	22000.00
BBC4B8	2017-07-07 08:33:00+03	32200.00
BBC506	2017-07-12 18:54:00+03	48300.00
BBC5C0	2017-07-06 00:02:00+03	38600.00
BBC5C7	2017-08-10 06:47:00+03	127100.00
BBC5D9	2017-07-10 05:30:00+03	23600.00
BBC601	2017-07-22 18:47:00+03	73600.00
BBC62E	2017-07-29 07:02:00+03	136500.00
BBC684	2017-08-02 05:47:00+03	99200.00
BBC6A7	2017-08-10 14:52:00+03	54000.00
BBC6C6	2017-07-14 06:39:00+03	77900.00
BBC6EF	2017-07-06 17:49:00+03	133200.00
BBC6FB	2017-08-13 11:11:00+03	37200.00
BBC700	2017-07-02 12:58:00+03	19800.00
BBC71A	2017-07-16 20:24:00+03	91600.00
BBC72D	2017-07-13 14:32:00+03	55800.00
BBC75A	2017-08-09 19:13:00+03	27400.00
BBC789	2017-07-20 05:30:00+03	22100.00
BBC7D1	2017-08-05 14:04:00+03	6600.00
BBC822	2017-07-27 04:32:00+03	112000.00
BBC899	2017-07-19 04:44:00+03	71000.00
BBC8A3	2017-07-24 22:10:00+03	120400.00
BBC8F7	2017-07-25 01:51:00+03	23600.00
BBC8F9	2017-08-02 01:15:00+03	13800.00
BBC90D	2017-08-13 04:14:00+03	172100.00
BBC932	2017-07-24 05:04:00+03	19600.00
BBC94A	2017-08-08 13:51:00+03	56000.00
BBC995	2017-08-15 14:15:00+03	114800.00
BBC9B7	2017-07-20 18:27:00+03	12400.00
BBC9E0	2017-07-12 11:15:00+03	115900.00
BBCA0D	2017-07-10 07:16:00+03	107800.00
BBCA1B	2017-08-14 13:33:00+03	30200.00
BBCA26	2017-07-06 11:17:00+03	6000.00
BBCA2D	2017-08-03 01:45:00+03	32700.00
BBCA36	2017-08-03 00:42:00+03	26000.00
BBCA74	2017-07-05 19:44:00+03	36200.00
BBCADD	2017-07-09 03:00:00+03	52100.00
BBCB5E	2017-08-14 05:02:00+03	112000.00
BBCB70	2017-07-10 06:51:00+03	47400.00
BBCBC2	2017-08-07 14:02:00+03	46000.00
BBCBE7	2017-07-09 15:12:00+03	88000.00
BBCC78	2017-07-21 16:16:00+03	27300.00
BBCD71	2017-07-05 21:46:00+03	61800.00
BBCDAD	2017-08-01 15:20:00+03	123000.00
BBCDC3	2017-06-30 03:15:00+03	38800.00
BBCDD7	2017-08-09 06:22:00+03	58000.00
BBCE02	2017-08-05 00:04:00+03	30900.00
BBCE20	2017-08-07 09:29:00+03	62600.00
BBCE27	2017-07-18 18:35:00+03	133100.00
BBCE31	2017-08-14 23:30:00+03	133700.00
BBCE83	2017-07-28 09:26:00+03	31100.00
BBCE85	2017-08-11 20:27:00+03	306200.00
BBCE9A	2017-07-30 18:07:00+03	198800.00
BBCF6B	2017-07-05 09:39:00+03	32400.00
BBCFF9	2017-07-24 18:34:00+03	9800.00
BBD020	2017-08-12 15:17:00+03	73400.00
BBD04F	2017-07-06 18:45:00+03	58600.00
BBD061	2017-08-11 15:50:00+03	21800.00
BBD062	2017-07-05 06:46:00+03	25600.00
BBD06C	2017-07-31 02:14:00+03	46300.00
BBD084	2017-08-09 23:32:00+03	165000.00
BBD085	2017-08-08 00:42:00+03	62100.00
BBD0FA	2017-07-09 21:04:00+03	100600.00
BBD13D	2017-07-10 04:05:00+03	56000.00
BBD15A	2017-08-11 11:28:00+03	111100.00
BBD24B	2017-07-05 12:53:00+03	23600.00
BBD25E	2017-08-14 21:10:00+03	99300.00
BBD296	2017-07-11 10:19:00+03	28000.00
BBD2AC	2017-08-14 09:04:00+03	38800.00
BBD2FB	2017-07-27 18:46:00+03	247300.00
BBD3D2	2017-08-15 10:26:00+03	57800.00
BBD403	2017-08-08 07:18:00+03	9800.00
BBD408	2017-08-06 08:29:00+03	23400.00
BBD457	2017-08-13 08:16:00+03	73300.00
BBD48E	2017-07-23 13:35:00+03	264600.00
BBD4C5	2017-07-28 16:59:00+03	26000.00
BBD50B	2017-07-07 08:23:00+03	121500.00
BBD603	2017-07-16 21:02:00+03	135000.00
BBD630	2017-07-29 19:56:00+03	87700.00
BBD6B1	2017-08-04 23:21:00+03	151200.00
BBD6C9	2017-08-04 17:50:00+03	62100.00
BBD70B	2017-08-04 23:26:00+03	14000.00
BBD716	2017-08-06 20:04:00+03	18000.00
BBD743	2017-07-04 14:57:00+03	87100.00
BBD754	2017-07-21 05:52:00+03	24400.00
BBD79F	2017-07-01 06:11:00+03	81700.00
BBD7B3	2017-07-24 10:11:00+03	96800.00
BBD828	2017-07-07 23:52:00+03	109600.00
BBD858	2017-07-15 22:43:00+03	68800.00
BBD869	2017-07-08 13:37:00+03	52000.00
BBD8D4	2017-07-11 18:48:00+03	18600.00
BBD8F6	2017-07-10 04:33:00+03	38000.00
BBD925	2017-07-21 02:01:00+03	6800.00
BBD938	2017-08-14 08:49:00+03	209300.00
BBD96F	2017-08-12 22:52:00+03	40600.00
BBD97C	2017-07-04 14:05:00+03	11700.00
BBDA57	2017-07-13 04:53:00+03	223200.00
BBDAC7	2017-07-05 02:42:00+03	131100.00
BBDAD7	2017-07-31 11:10:00+03	19600.00
BBDB85	2017-08-13 03:59:00+03	47200.00
BBDBE2	2017-07-30 03:55:00+03	52300.00
BBDBE7	2017-08-13 16:50:00+03	250400.00
BBDC4E	2017-08-03 06:55:00+03	35200.00
BBDC9B	2017-08-13 16:03:00+03	156000.00
BBDD02	2017-07-11 02:19:00+03	58600.00
BBDD1D	2017-07-09 17:18:00+03	12600.00
BBDD76	2017-07-06 04:28:00+03	75300.00
BBDD7D	2017-07-10 10:26:00+03	190200.00
BBDDA6	2017-08-07 06:39:00+03	23400.00
BBDDB6	2017-08-05 16:10:00+03	66600.00
BBDE76	2017-07-13 05:48:00+03	106900.00
BBDE79	2017-07-07 15:11:00+03	86600.00
BBDE92	2017-07-07 05:56:00+03	180800.00
BBDEC1	2017-07-11 15:10:00+03	68800.00
BBDEC4	2017-08-08 11:18:00+03	47000.00
BBDF00	2017-08-09 05:35:00+03	77900.00
BBDF02	2017-07-02 03:32:00+03	42600.00
BBDFD8	2017-07-30 14:04:00+03	12600.00
BBE059	2017-08-14 12:35:00+03	66600.00
BBE065	2017-07-08 09:41:00+03	73100.00
BBE0A6	2017-07-12 14:17:00+03	326100.00
BBE0B4	2017-07-15 08:24:00+03	57600.00
BBE0E4	2017-07-30 19:42:00+03	66600.00
BBE104	2017-08-04 10:27:00+03	40400.00
BBE132	2017-08-05 00:38:00+03	237100.00
BBE161	2017-07-20 09:27:00+03	135400.00
BBE162	2017-07-08 19:43:00+03	179300.00
BBE186	2017-07-14 20:07:00+03	26000.00
BBE1A1	2017-08-05 01:50:00+03	81300.00
BBE1AC	2017-07-01 19:11:00+03	40800.00
BBE1C4	2017-07-23 18:55:00+03	57800.00
BBE1C7	2017-08-10 07:32:00+03	58600.00
BBE225	2017-07-17 20:55:00+03	246000.00
BBE23D	2017-07-06 03:28:00+03	64700.00
BBE24A	2017-08-02 12:56:00+03	101200.00
BBE276	2017-08-14 23:19:00+03	58800.00
BBE27F	2017-07-06 09:32:00+03	272600.00
BBE286	2017-07-26 09:41:00+03	108900.00
BBE293	2017-08-10 02:55:00+03	123000.00
BBE32A	2017-07-28 06:06:00+03	78100.00
BBE359	2017-07-11 01:28:00+03	123000.00
BBE37D	2017-08-05 14:37:00+03	86300.00
BBE3D4	2017-07-19 11:10:00+03	39400.00
BBE3EE	2017-07-13 07:44:00+03	143200.00
BBE47E	2017-07-04 12:10:00+03	25200.00
BBE4AD	2017-08-03 19:39:00+03	28000.00
BBE528	2017-07-21 06:50:00+03	12600.00
BBE589	2017-08-09 22:06:00+03	37600.00
BBE5B2	2017-07-04 18:55:00+03	50800.00
BBE605	2017-08-06 23:05:00+03	6000.00
BBE630	2017-08-04 04:36:00+03	36800.00
BBE633	2017-07-23 07:06:00+03	92000.00
BBE645	2017-07-01 23:11:00+03	56000.00
BBE653	2017-08-14 09:52:00+03	37100.00
BBE674	2017-08-10 18:07:00+03	55800.00
BBE675	2017-07-24 14:55:00+03	56000.00
BBE67E	2017-08-04 19:40:00+03	287100.00
BBE6A1	2017-07-15 10:21:00+03	74000.00
BBE703	2017-08-04 13:45:00+03	53300.00
BBE74D	2017-08-09 09:33:00+03	40800.00
BBE7AE	2017-07-19 03:51:00+03	186900.00
BBE89F	2017-07-23 15:13:00+03	13400.00
BBE8F8	2017-07-26 14:04:00+03	42400.00
BBE90D	2017-07-16 08:55:00+03	37900.00
BBE912	2017-07-04 06:15:00+03	138000.00
BBE915	2017-08-06 03:09:00+03	386400.00
BBE91C	2017-08-12 08:34:00+03	38600.00
BBE923	2017-08-15 00:14:00+03	38600.00
BBE93D	2017-07-14 17:19:00+03	29000.00
BBE99C	2017-07-23 22:43:00+03	55200.00
BBEA20	2017-07-09 13:52:00+03	66000.00
BBEA27	2017-08-15 13:27:00+03	73600.00
BBEA82	2017-07-01 09:15:00+03	92800.00
BBEA85	2017-08-02 10:11:00+03	47200.00
BBEAB1	2017-08-15 01:53:00+03	12000.00
BBEAB5	2017-08-11 10:18:00+03	101400.00
BBEB1F	2017-07-22 23:14:00+03	31600.00
BBEB20	2017-07-24 23:30:00+03	77600.00
BBEB25	2017-07-15 02:36:00+03	81900.00
BBEB3E	2017-07-04 22:28:00+03	38600.00
BBEB42	2017-07-19 00:34:00+03	29200.00
BBEB57	2017-07-15 17:52:00+03	42000.00
BBEBDF	2017-08-06 03:09:00+03	58000.00
BBEC08	2017-07-25 11:49:00+03	162600.00
BBEC3A	2017-08-01 19:45:00+03	31600.00
BBEC59	2017-08-06 03:45:00+03	27800.00
BBEC68	2017-08-02 10:38:00+03	260300.00
BBEC7B	2017-07-07 20:53:00+03	56000.00
BBECA8	2017-07-11 18:42:00+03	35200.00
BBECC8	2017-07-20 17:17:00+03	104600.00
BBECF1	2017-08-09 19:15:00+03	96800.00
BBECF7	2017-07-12 10:49:00+03	36200.00
BBEDF8	2017-07-22 13:23:00+03	70700.00
BBEE30	2017-08-05 13:58:00+03	12000.00
BBEE3B	2017-08-10 12:52:00+03	100300.00
BBEEC7	2017-07-16 07:28:00+03	168000.00
BBEEEE	2017-08-02 17:03:00+03	36200.00
BBEEFC	2017-07-29 13:12:00+03	65900.00
BBEF5E	2017-08-04 20:56:00+03	284700.00
BBEF83	2017-08-01 19:39:00+03	27300.00
BBF000	2017-07-16 04:36:00+03	45400.00
BBF027	2017-07-05 18:52:00+03	92000.00
BBF04D	2017-07-16 17:21:00+03	49800.00
BBF08D	2017-07-30 12:12:00+03	246000.00
BBF0A5	2017-07-06 22:18:00+03	13000.00
BBF0B5	2017-07-12 14:58:00+03	46400.00
BBF0C1	2017-07-26 06:12:00+03	42800.00
BBF0FC	2017-07-30 05:19:00+03	55800.00
BBF181	2017-08-03 23:15:00+03	77800.00
BBF183	2017-06-28 18:42:00+03	113800.00
BBF184	2017-08-12 20:33:00+03	20200.00
BBF190	2017-07-28 00:14:00+03	335000.00
BBF292	2017-08-15 14:29:00+03	27300.00
BBF2A9	2017-07-05 22:05:00+03	33100.00
BBF2F8	2017-07-07 22:25:00+03	23400.00
BBF33E	2017-08-13 22:50:00+03	43600.00
BBF377	2017-07-11 15:53:00+03	6600.00
BBF3D5	2017-07-24 12:59:00+03	335400.00
BBF3EA	2017-07-24 19:38:00+03	108500.00
BBF44A	2017-07-04 23:59:00+03	38800.00
BBF459	2017-07-29 00:47:00+03	188000.00
BBF46A	2017-08-06 16:11:00+03	114800.00
BBF497	2017-07-09 15:53:00+03	19600.00
BBF4F9	2017-08-14 11:09:00+03	6700.00
BBF52A	2017-08-01 16:41:00+03	102600.00
BBF573	2017-08-05 01:08:00+03	55800.00
BBF59A	2017-07-16 12:14:00+03	104200.00
BBF5AB	2017-07-15 23:43:00+03	46000.00
BBF62E	2017-08-01 14:02:00+03	288600.00
BBF646	2017-08-05 00:53:00+03	112000.00
BBF68B	2017-07-25 07:24:00+03	87400.00
BBF6CC	2017-08-06 06:49:00+03	99300.00
BBF6E7	2017-08-07 18:31:00+03	32800.00
BBF75E	2017-07-12 04:07:00+03	101500.00
BBF773	2017-07-03 23:38:00+03	54800.00
BBF780	2017-08-02 14:29:00+03	26000.00
BBF89D	2017-07-25 14:41:00+03	21200.00
BBF8EE	2017-08-09 06:25:00+03	189100.00
BBF91F	2017-07-18 12:01:00+03	66600.00
BBF925	2017-08-05 05:10:00+03	23600.00
BBF972	2017-08-14 04:54:00+03	531400.00
BBF99D	2017-08-07 07:19:00+03	49100.00
BBFA09	2017-08-09 16:31:00+03	55800.00
BBFA2E	2017-08-12 12:42:00+03	87700.00
BBFA8F	2017-07-09 09:53:00+03	168300.00
BBFA94	2017-07-12 17:57:00+03	27200.00
BBFAB3	2017-07-08 18:42:00+03	71600.00
BBFAE8	2017-08-09 08:35:00+03	101200.00
BBFB38	2017-07-15 20:45:00+03	100700.00
BBFB4A	2017-07-20 04:12:00+03	40800.00
BBFB77	2017-07-16 06:36:00+03	8000.00
BBFBB6	2017-07-02 20:25:00+03	58800.00
BBFC1A	2017-07-30 18:18:00+03	6000.00
BBFC21	2017-08-11 15:44:00+03	14700.00
BBFCAE	2017-07-22 06:39:00+03	36900.00
BBFCC7	2017-07-16 13:51:00+03	99800.00
BBFE33	2017-06-30 12:09:00+03	43200.00
BBFE4A	2017-07-13 00:52:00+03	31600.00
BBFE70	2017-07-29 11:14:00+03	135600.00
BBFE9D	2017-07-27 12:27:00+03	230400.00
BBFEAB	2017-08-07 14:09:00+03	22000.00
BBFF96	2017-07-13 13:39:00+03	28800.00
BBFFD9	2017-07-21 02:22:00+03	43200.00
BC0031	2017-07-05 16:19:00+03	9800.00
BC0049	2017-07-09 04:56:00+03	20200.00
BC008A	2017-08-14 21:39:00+03	22600.00
BC0099	2017-08-15 12:01:00+03	47100.00
BC00AC	2017-07-15 08:46:00+03	23200.00
BC00E4	2017-08-01 06:15:00+03	10700.00
BC00F7	2017-07-26 22:19:00+03	49400.00
BC0129	2017-08-06 14:48:00+03	47200.00
BC018B	2017-07-07 20:19:00+03	266400.00
BC01D8	2017-07-28 00:12:00+03	35300.00
BC01FA	2017-07-19 21:40:00+03	51900.00
BC0205	2017-08-15 08:42:00+03	21800.00
BC0224	2017-07-11 16:38:00+03	86500.00
BC0290	2017-07-07 14:24:00+03	16400.00
BC02DF	2017-07-24 18:42:00+03	89600.00
BC032B	2017-08-06 01:12:00+03	231800.00
BC03AD	2017-07-21 22:02:00+03	81300.00
BC03C6	2017-07-16 14:43:00+03	40000.00
BC0412	2017-08-03 05:41:00+03	6800.00
BC0463	2017-07-28 12:22:00+03	246000.00
BC04A1	2017-08-11 05:19:00+03	15100.00
BC0512	2017-07-07 23:31:00+03	27800.00
BC052D	2017-07-12 23:43:00+03	40200.00
BC0573	2017-07-13 10:23:00+03	29100.00
BC0577	2017-07-06 01:46:00+03	8200.00
BC05E0	2017-06-28 17:59:00+03	79600.00
BC063E	2017-07-05 07:20:00+03	139300.00
BC06C2	2017-07-21 06:15:00+03	15400.00
BC06C4	2017-07-20 07:41:00+03	33600.00
BC06C6	2017-08-03 03:47:00+03	178800.00
BC0729	2017-07-11 10:49:00+03	48800.00
BC076B	2017-07-06 17:06:00+03	75800.00
BC0779	2017-07-13 21:36:00+03	83700.00
BC07CC	2017-07-26 05:58:00+03	92000.00
BC0814	2017-07-26 07:21:00+03	135400.00
BC081D	2017-07-01 08:06:00+03	167500.00
BC083F	2017-08-11 09:38:00+03	40000.00
BC08E7	2017-07-30 09:16:00+03	37900.00
BC08FA	2017-08-07 07:54:00+03	31600.00
BC09C5	2017-08-09 12:40:00+03	24500.00
BC0A49	2017-06-30 07:28:00+03	106600.00
BC0A4F	2017-07-03 06:02:00+03	58200.00
BC0ABF	2017-07-23 13:55:00+03	229800.00
BC0B11	2017-07-09 00:43:00+03	15000.00
BC0B52	2017-07-24 13:46:00+03	46800.00
BC0B77	2017-07-19 11:32:00+03	99800.00
BC0BB7	2017-08-14 16:45:00+03	398600.00
BC0BD8	2017-07-17 08:08:00+03	68400.00
BC0BF0	2017-08-05 03:21:00+03	62000.00
BC0C1A	2017-07-22 15:11:00+03	47400.00
BC0C49	2017-08-09 13:54:00+03	74600.00
BC0C7A	2017-07-23 03:11:00+03	34400.00
BC0C9E	2017-07-13 02:40:00+03	156000.00
BC0CCC	2017-08-01 14:36:00+03	6400.00
BC0CDA	2017-07-23 15:39:00+03	40100.00
BC0CE0	2017-07-22 06:11:00+03	7200.00
BC0CF8	2017-07-18 23:20:00+03	38600.00
BC0D2A	2017-07-11 10:16:00+03	74400.00
BC0D53	2017-07-04 02:20:00+03	46300.00
BC0D87	2017-08-09 10:05:00+03	26000.00
BC0DBD	2017-07-21 22:59:00+03	36200.00
BC0E36	2017-08-08 20:22:00+03	47000.00
BC0ED4	2017-07-14 14:54:00+03	10600.00
BC0EE2	2017-08-15 00:07:00+03	191200.00
BC0F23	2017-08-11 05:41:00+03	58400.00
BC0F44	2017-07-26 02:49:00+03	46900.00
BC0F85	2017-07-15 20:48:00+03	46400.00
BC0F9B	2017-07-24 15:39:00+03	58400.00
BC0FC5	2017-07-04 04:48:00+03	21800.00
BC104B	2017-08-04 06:31:00+03	419200.00
BC10C2	2017-07-09 13:58:00+03	76800.00
BC1124	2017-07-22 14:37:00+03	166000.00
BC1194	2017-08-12 11:20:00+03	161800.00
BC11B1	2017-08-10 10:22:00+03	27200.00
BC11BE	2017-07-20 04:24:00+03	55800.00
BC1202	2017-07-02 06:27:00+03	39800.00
BC1204	2017-07-13 00:08:00+03	22600.00
BC121C	2017-07-26 23:05:00+03	43600.00
BC124E	2017-07-31 09:24:00+03	48800.00
BC125E	2017-07-08 03:26:00+03	56600.00
BC1287	2017-08-11 14:41:00+03	16400.00
BC12E6	2017-08-10 01:47:00+03	62000.00
BC1313	2017-08-06 18:47:00+03	28800.00
BC1372	2017-07-31 13:41:00+03	68400.00
BC1377	2017-07-27 19:53:00+03	137400.00
BC1394	2017-06-28 16:46:00+03	21400.00
BC1395	2017-07-16 05:31:00+03	104700.00
BC13CC	2017-08-09 23:05:00+03	99200.00
BC14A9	2017-07-18 19:09:00+03	54800.00
BC151D	2017-08-14 07:14:00+03	26200.00
BC157D	2017-08-03 18:11:00+03	234300.00
BC1587	2017-07-15 18:37:00+03	48900.00
BC1594	2017-07-07 16:20:00+03	102300.00
BC15CD	2017-08-12 04:27:00+03	41400.00
BC1641	2017-08-15 15:17:00+03	66800.00
BC167E	2017-07-16 22:03:00+03	25000.00
BC16AD	2017-07-29 23:17:00+03	166100.00
BC171E	2017-07-01 10:47:00+03	117600.00
BC1725	2017-08-14 01:45:00+03	36000.00
BC1749	2017-07-02 11:57:00+03	22400.00
BC175D	2017-07-04 10:10:00+03	75800.00
BC17FA	2017-07-13 18:12:00+03	6700.00
BC1818	2017-07-22 03:17:00+03	45200.00
BC183F	2017-07-29 02:10:00+03	139200.00
BC184F	2017-08-06 15:04:00+03	114400.00
BC1866	2017-07-04 00:00:00+03	81700.00
BC18C4	2017-07-20 22:15:00+03	28000.00
BC18D5	2017-07-18 10:11:00+03	105100.00
BC1922	2017-07-31 18:55:00+03	15000.00
BC1979	2017-08-07 21:08:00+03	31400.00
BC1998	2017-07-16 00:24:00+03	111400.00
BC19B0	2017-08-14 00:22:00+03	101200.00
BC19BB	2017-07-06 17:08:00+03	118100.00
BC19C6	2017-08-12 22:51:00+03	118000.00
BC1A4D	2017-08-06 09:21:00+03	23200.00
BC1A69	2017-07-02 22:55:00+03	206400.00
BC1A8E	2017-08-10 01:20:00+03	12400.00
BC1AA0	2017-07-14 06:08:00+03	122100.00
BC1AD8	2017-08-14 22:45:00+03	91000.00
BC1B52	2017-08-11 14:06:00+03	70600.00
BC1BC1	2017-07-14 13:19:00+03	65500.00
BC1C11	2017-07-07 12:38:00+03	84000.00
BC1C44	2017-08-11 10:01:00+03	32500.00
BC1CB1	2017-08-14 02:56:00+03	201800.00
BC1CB5	2017-08-11 17:53:00+03	85700.00
BC1CD8	2017-07-12 06:13:00+03	25000.00
BC1D25	2017-07-14 16:57:00+03	18100.00
BC1D52	2017-07-28 14:08:00+03	34100.00
BC1D71	2017-08-13 08:58:00+03	14800.00
BC1D93	2017-08-07 10:33:00+03	46400.00
BC1DC1	2017-07-08 04:37:00+03	20200.00
BC1DC3	2017-07-16 15:28:00+03	105400.00
BC1DC5	2017-07-31 16:39:00+03	52700.00
BC1E34	2017-07-17 18:00:00+03	95500.00
BC1F1D	2017-08-04 14:44:00+03	81700.00
BC1F4C	2017-07-17 12:53:00+03	46000.00
BC1F90	2017-07-12 19:17:00+03	59300.00
BC1FAB	2017-07-28 06:24:00+03	14400.00
BC1FDA	2017-08-07 06:57:00+03	57300.00
BC202B	2017-07-23 04:59:00+03	22000.00
BC20A3	2017-07-10 11:42:00+03	200400.00
BC20ED	2017-07-12 10:54:00+03	31100.00
BC2147	2017-06-30 13:04:00+03	23400.00
BC2178	2017-07-11 20:06:00+03	13700.00
BC218A	2017-07-07 17:16:00+03	49600.00
BC21B0	2017-06-28 12:37:00+03	148200.00
BC21C4	2017-07-14 09:11:00+03	73600.00
BC21D8	2017-08-10 06:28:00+03	14800.00
BC21F2	2017-07-17 17:57:00+03	115700.00
BC2207	2017-07-13 07:02:00+03	534300.00
BC2424	2017-07-06 20:39:00+03	46700.00
BC2461	2017-08-12 13:16:00+03	47000.00
BC2476	2017-08-14 07:56:00+03	82500.00
BC2481	2017-07-16 20:56:00+03	52500.00
BC24BD	2017-07-22 07:50:00+03	119500.00
BC2526	2017-07-19 05:18:00+03	28000.00
BC2533	2017-07-15 23:47:00+03	93700.00
BC2562	2017-07-06 13:00:00+03	35200.00
BC25BE	2017-07-08 22:47:00+03	118700.00
BC2611	2017-08-05 17:20:00+03	89600.00
BC2630	2017-07-08 05:31:00+03	21800.00
BC2633	2017-08-14 21:54:00+03	13000.00
BC2697	2017-08-15 05:16:00+03	60400.00
BC26BE	2017-08-01 10:48:00+03	73100.00
BC26E3	2017-08-09 08:16:00+03	114300.00
BC26F7	2017-07-02 02:35:00+03	139200.00
BC26F8	2017-08-14 18:14:00+03	123000.00
BC272A	2017-07-20 15:46:00+03	56900.00
BC2738	2017-07-08 20:55:00+03	181600.00
BC2756	2017-08-12 02:21:00+03	35300.00
BC2768	2017-07-07 06:07:00+03	115700.00
BC276B	2017-07-05 07:00:00+03	40800.00
BC27BC	2017-08-03 09:07:00+03	16400.00
BC27C4	2017-08-08 19:56:00+03	37900.00
BC27DF	2017-07-20 17:15:00+03	26100.00
BC27E2	2017-07-03 12:47:00+03	113300.00
BC2802	2017-07-28 23:34:00+03	199700.00
BC2840	2017-08-13 16:32:00+03	81700.00
BC2845	2017-07-19 01:51:00+03	28000.00
BC2846	2017-07-29 16:35:00+03	16400.00
BC2905	2017-07-04 02:49:00+03	51600.00
BC2A5D	2017-08-10 21:25:00+03	26000.00
BC2AC3	2017-08-11 21:07:00+03	47100.00
BC2B5B	2017-08-09 20:26:00+03	28800.00
BC2B82	2017-06-30 02:14:00+03	59800.00
BC2BAB	2017-07-09 14:44:00+03	224000.00
BC2BC2	2017-07-15 23:27:00+03	99200.00
BC2BC5	2017-07-11 06:35:00+03	105600.00
BC2C67	2017-07-04 03:11:00+03	31400.00
BC2C6C	2017-07-11 14:06:00+03	28800.00
BC2CDF	2017-08-07 14:35:00+03	42400.00
BC2CF3	2017-08-01 18:29:00+03	46800.00
BC2D00	2017-07-28 21:17:00+03	40300.00
BC2D19	2017-07-20 22:30:00+03	93700.00
BC2D87	2017-07-15 17:10:00+03	6700.00
BC2EE2	2017-08-07 10:00:00+03	36200.00
BC2EF8	2017-08-12 17:41:00+03	29200.00
BC2F19	2017-07-15 12:40:00+03	96400.00
BC2F5C	2017-07-29 03:05:00+03	186500.00
BC2FAD	2017-08-06 19:47:00+03	56300.00
BC2FAE	2017-07-06 03:41:00+03	27900.00
BC3019	2017-07-08 19:33:00+03	138600.00
BC3024	2017-08-07 05:53:00+03	28600.00
BC3087	2017-07-16 18:11:00+03	35200.00
BC30A0	2017-07-09 13:39:00+03	19600.00
BC30E4	2017-07-26 07:44:00+03	66600.00
BC3131	2017-07-11 04:16:00+03	35800.00
BC3133	2017-08-08 11:12:00+03	30900.00
BC3144	2017-08-01 19:15:00+03	131600.00
BC3237	2017-07-26 10:05:00+03	24700.00
BC3259	2017-07-15 07:19:00+03	112000.00
BC3266	2017-07-29 04:28:00+03	59200.00
BC32BC	2017-07-08 04:51:00+03	56000.00
BC330C	2017-06-28 09:05:00+03	59300.00
BC3321	2017-08-12 14:18:00+03	13000.00
BC3332	2017-07-30 16:47:00+03	30200.00
BC3339	2017-07-28 20:55:00+03	28800.00
BC3343	2017-08-15 16:07:00+03	39800.00
BC334F	2017-07-31 13:18:00+03	191200.00
BC3396	2017-07-24 01:45:00+03	92400.00
BC33DF	2017-07-06 10:06:00+03	98000.00
BC3402	2017-07-19 19:52:00+03	24700.00
BC341D	2017-07-01 23:07:00+03	56000.00
BC3426	2017-08-15 17:15:00+03	11600.00
BC34D6	2017-07-26 09:39:00+03	266400.00
BC3505	2017-07-08 18:47:00+03	108000.00
BC350A	2017-08-13 04:10:00+03	48000.00
BC3513	2017-07-08 03:29:00+03	46300.00
BC352C	2017-08-12 02:42:00+03	16000.00
BC3611	2017-07-05 01:06:00+03	39800.00
BC3699	2017-08-14 05:07:00+03	73600.00
BC36D8	2017-07-08 22:56:00+03	22600.00
BC36FA	2017-08-11 07:28:00+03	68800.00
BC3728	2017-07-26 16:02:00+03	41600.00
BC3779	2017-08-08 13:53:00+03	52000.00
BC3784	2017-07-11 06:27:00+03	9800.00
BC378A	2017-07-12 10:37:00+03	64800.00
BC378B	2017-07-30 19:31:00+03	56000.00
BC37C7	2017-08-01 13:55:00+03	56000.00
BC37FF	2017-07-11 10:42:00+03	58600.00
BC3809	2017-07-25 20:08:00+03	133200.00
BC3829	2017-08-10 09:39:00+03	66600.00
BC38E4	2017-08-10 03:48:00+03	28800.00
BC3927	2017-07-26 00:25:00+03	47400.00
BC3979	2017-08-07 09:59:00+03	59800.00
BC397E	2017-07-31 11:08:00+03	21800.00
BC39EC	2017-07-22 15:07:00+03	130400.00
BC39F4	2017-07-15 10:59:00+03	13400.00
BC39FB	2017-08-09 11:21:00+03	43500.00
BC3A04	2017-08-08 09:40:00+03	100600.00
BC3A63	2017-07-05 10:44:00+03	110300.00
BC3B47	2017-07-09 07:08:00+03	49100.00
BC3B86	2017-08-06 22:56:00+03	65900.00
BC3BB6	2017-07-09 08:30:00+03	40400.00
BC3BB7	2017-07-12 06:23:00+03	84100.00
BC3BF0	2017-07-26 13:48:00+03	56000.00
BC3C63	2017-08-10 03:27:00+03	203100.00
BC3CF5	2017-08-13 04:23:00+03	292200.00
BC3D13	2017-07-12 22:53:00+03	36200.00
BC3D1A	2017-07-27 00:46:00+03	23500.00
BC3DAF	2017-07-23 18:31:00+03	413400.00
BC3DD1	2017-07-08 03:43:00+03	113200.00
BC3E19	2017-08-10 01:56:00+03	43500.00
BC3E32	2017-08-12 21:32:00+03	59300.00
BC3E58	2017-07-16 18:23:00+03	14400.00
BC3E9E	2017-07-15 07:08:00+03	25800.00
BC3EBD	2017-08-07 08:38:00+03	7400.00
BC3EC1	2017-08-14 07:58:00+03	91100.00
BC3F02	2017-07-06 06:27:00+03	77700.00
BC3FB3	2017-08-08 15:02:00+03	24800.00
BC3FBD	2017-07-12 22:47:00+03	284800.00
BC4027	2017-07-29 23:57:00+03	326200.00
BC4041	2017-08-08 03:26:00+03	79100.00
BC4063	2017-08-06 17:00:00+03	23400.00
BC4070	2017-07-06 07:15:00+03	66400.00
BC410D	2017-08-12 23:18:00+03	8800.00
BC411A	2017-07-10 01:57:00+03	38600.00
BC4140	2017-07-06 06:42:00+03	134400.00
BC419E	2017-07-01 23:29:00+03	135200.00
BC41D5	2017-07-15 04:47:00+03	187600.00
BC4200	2017-07-21 06:05:00+03	70700.00
BC4260	2017-08-08 19:39:00+03	48600.00
BC4280	2017-07-29 20:49:00+03	266200.00
BC42D5	2017-07-14 08:40:00+03	169500.00
BC436F	2017-08-14 10:55:00+03	81500.00
BC4378	2017-07-18 22:32:00+03	80000.00
BC4445	2017-07-19 20:50:00+03	31600.00
BC4483	2017-07-25 15:04:00+03	27200.00
BC448D	2017-07-19 02:27:00+03	26000.00
BC448E	2017-07-07 01:52:00+03	225800.00
BC4534	2017-08-09 07:58:00+03	38400.00
BC45B5	2017-07-30 08:29:00+03	43600.00
BC45B8	2017-07-03 15:15:00+03	23200.00
BC4618	2017-08-07 15:14:00+03	69600.00
BC461F	2017-07-24 14:51:00+03	189200.00
BC4656	2017-07-31 19:09:00+03	20400.00
BC46A0	2017-07-02 14:46:00+03	99300.00
BC46A9	2017-08-06 03:16:00+03	67600.00
BC46BC	2017-07-05 08:08:00+03	12600.00
BC478A	2017-07-31 07:01:00+03	43000.00
BC478C	2017-08-15 04:19:00+03	45200.00
BC47BD	2017-08-12 11:07:00+03	32800.00
BC47CC	2017-07-07 05:44:00+03	26800.00
BC47D8	2017-07-30 22:58:00+03	39200.00
BC47E7	2017-08-15 02:05:00+03	68100.00
BC4833	2017-07-12 09:13:00+03	83600.00
BC4962	2017-08-12 23:13:00+03	35700.00
BC4981	2017-07-09 14:49:00+03	90700.00
BC4A29	2017-08-15 12:27:00+03	73600.00
BC4A30	2017-07-26 08:58:00+03	130200.00
BC4A39	2017-07-13 21:08:00+03	26800.00
BC4A6C	2017-07-07 06:32:00+03	66600.00
BC4AA4	2017-08-08 08:47:00+03	136200.00
BC4ABD	2017-07-25 20:31:00+03	23200.00
BC4B1E	2017-07-28 08:53:00+03	103500.00
BC4B3A	2017-08-09 23:09:00+03	136800.00
BC4B6C	2017-07-21 09:11:00+03	265600.00
BC4B74	2017-07-04 06:52:00+03	67100.00
BC4B7B	2017-07-09 06:51:00+03	31600.00
BC4BDD	2017-08-12 08:35:00+03	46000.00
BC4C0F	2017-07-18 06:10:00+03	132800.00
BC4C82	2017-07-30 22:10:00+03	62700.00
BC4C98	2017-07-02 03:23:00+03	156000.00
BC4CB6	2017-07-06 02:03:00+03	22600.00
BC4CB9	2017-08-14 23:51:00+03	100600.00
BC4CC1	2017-07-20 22:47:00+03	21800.00
BC4CCD	2017-07-27 19:47:00+03	81700.00
BC4CD1	2017-07-15 11:38:00+03	49100.00
BC4CE2	2017-07-08 01:55:00+03	27200.00
BC4CFB	2017-07-27 06:07:00+03	46400.00
BC4D08	2017-07-07 18:45:00+03	177200.00
BC4D1F	2017-07-12 13:39:00+03	39900.00
BC4D49	2017-07-13 07:51:00+03	95500.00
BC4D72	2017-08-06 08:34:00+03	43500.00
BC4D80	2017-07-18 14:37:00+03	297600.00
BC4D84	2017-07-07 16:49:00+03	31600.00
BC4E05	2017-08-08 05:24:00+03	74200.00
BC4E0D	2017-07-28 18:22:00+03	26800.00
BC4E22	2017-06-30 18:54:00+03	47500.00
BC4E37	2017-07-24 04:59:00+03	38400.00
BC4EA6	2017-07-24 05:12:00+03	200500.00
BC4EDF	2017-07-11 04:39:00+03	54000.00
BC4EFE	2017-06-27 23:09:00+03	46000.00
BC4F5E	2017-06-27 21:21:00+03	122500.00
BC4F9C	2017-07-04 04:18:00+03	49000.00
BC4FCE	2017-07-07 10:21:00+03	306200.00
BC4FD9	2017-07-12 22:30:00+03	56000.00
BC4FDE	2017-07-30 02:29:00+03	28000.00
BC4FE4	2017-07-20 13:08:00+03	66900.00
BC4FF7	2017-08-06 04:35:00+03	81600.00
BC4FFB	2017-07-05 13:20:00+03	72400.00
BC5062	2017-07-05 19:51:00+03	21500.00
BC50B3	2017-07-30 14:23:00+03	132500.00
BC510F	2017-08-04 20:04:00+03	53300.00
BC5125	2017-08-10 17:33:00+03	37600.00
BC5136	2017-07-27 17:43:00+03	89700.00
BC5145	2017-07-28 07:20:00+03	31600.00
BC5168	2017-08-12 03:55:00+03	23600.00
BC519C	2017-07-24 02:31:00+03	246000.00
BC51DE	2017-07-26 09:57:00+03	44000.00
BC51FD	2017-07-29 08:33:00+03	386300.00
BC5247	2017-07-26 01:26:00+03	30200.00
BC5268	2017-07-22 03:07:00+03	18600.00
BC5275	2017-07-06 02:37:00+03	24800.00
BC5285	2017-07-16 08:56:00+03	123200.00
BC5286	2017-08-12 18:29:00+03	48700.00
BC528E	2017-07-08 15:29:00+03	6800.00
BC52B0	2017-07-22 16:12:00+03	26000.00
BC52EB	2017-07-22 08:45:00+03	28300.00
BC52EE	2017-07-29 17:08:00+03	86500.00
BC5341	2017-07-17 16:44:00+03	99700.00
BC5430	2017-08-03 14:54:00+03	61800.00
BC5431	2017-07-21 02:04:00+03	56000.00
BC543E	2017-08-12 23:24:00+03	132800.00
BC5492	2017-07-29 07:14:00+03	27900.00
BC54C9	2017-08-03 08:48:00+03	28200.00
BC55C9	2017-07-12 14:24:00+03	28800.00
BC55E2	2017-08-11 09:33:00+03	51600.00
BC55E7	2017-08-03 04:44:00+03	67200.00
BC563C	2017-07-12 12:50:00+03	101100.00
BC569E	2017-07-30 02:51:00+03	85400.00
BC56CD	2017-07-29 15:33:00+03	78500.00
BC56E1	2017-08-11 19:32:00+03	62600.00
BC56F9	2017-07-23 12:20:00+03	8200.00
BC56FC	2017-07-26 16:09:00+03	56000.00
BC573C	2017-07-29 12:31:00+03	29600.00
BC57A5	2017-08-07 04:18:00+03	25600.00
BC57BF	2017-08-14 08:55:00+03	85000.00
BC57E7	2017-07-05 20:20:00+03	67700.00
BC5814	2017-08-06 11:19:00+03	265600.00
BC585F	2017-07-24 17:33:00+03	36200.00
BC5866	2017-08-05 08:49:00+03	47000.00
BC5899	2017-08-03 01:03:00+03	144400.00
BC58A0	2017-07-03 04:50:00+03	38400.00
BC58A3	2017-08-13 20:39:00+03	75300.00
BC58C6	2017-07-02 10:04:00+03	24800.00
BC58C8	2017-08-13 18:01:00+03	30200.00
BC58E9	2017-07-13 21:02:00+03	21800.00
BC591F	2017-07-12 18:27:00+03	36800.00
BC594C	2017-07-14 00:55:00+03	132800.00
BC596E	2017-07-20 20:26:00+03	515000.00
BC5A18	2017-07-17 09:42:00+03	42400.00
BC5A4A	2017-07-19 00:58:00+03	120100.00
BC5AA1	2017-06-30 10:59:00+03	77600.00
BC5AA8	2017-08-14 22:53:00+03	46400.00
BC5ADF	2017-08-10 21:03:00+03	128800.00
BC5AFE	2017-07-19 12:59:00+03	32200.00
BC5B26	2017-08-03 22:25:00+03	93000.00
BC5B50	2017-08-08 15:02:00+03	135400.00
BC5BD1	2017-08-10 08:08:00+03	43300.00
BC5BDD	2017-07-18 02:30:00+03	89600.00
BC5BDF	2017-07-06 06:49:00+03	59800.00
BC5C12	2017-07-31 18:45:00+03	18600.00
BC5C14	2017-07-16 00:59:00+03	56000.00
BC5C3C	2017-07-18 21:16:00+03	86300.00
BC5CBC	2017-07-17 16:19:00+03	52000.00
BC5CC0	2017-06-29 11:26:00+03	44800.00
BC5CF9	2017-07-14 22:49:00+03	28300.00
BC5D43	2017-08-12 05:36:00+03	36200.00
BC5D6B	2017-08-13 10:13:00+03	23200.00
BC5DA7	2017-07-06 16:11:00+03	27800.00
BC5DFC	2017-07-15 06:34:00+03	23600.00
BC5E24	2017-07-20 10:17:00+03	21400.00
BC5E35	2017-07-15 21:11:00+03	56000.00
BC5E93	2017-07-18 05:33:00+03	96800.00
BC5EB2	2017-07-17 22:57:00+03	129200.00
BC5EC4	2017-07-21 08:36:00+03	194000.00
BC5EDC	2017-07-30 13:36:00+03	121100.00
BC5EE0	2017-08-13 07:35:00+03	133100.00
BC5EE8	2017-08-15 08:53:00+03	18600.00
BC5FF9	2017-07-19 05:51:00+03	57400.00
BC6014	2017-07-09 13:12:00+03	56000.00
BC603C	2017-08-08 20:04:00+03	19600.00
BC609B	2017-07-16 00:51:00+03	39300.00
BC60E7	2017-07-11 23:36:00+03	49900.00
BC60FD	2017-07-29 01:33:00+03	81300.00
BC610C	2017-07-17 19:38:00+03	45200.00
BC6120	2017-06-29 00:53:00+03	135400.00
BC6164	2017-07-25 09:35:00+03	28000.00
BC616A	2017-07-21 20:39:00+03	78000.00
BC61A3	2017-07-09 05:38:00+03	168000.00
BC61BF	2017-08-01 10:04:00+03	20000.00
BC6268	2017-07-21 23:25:00+03	93500.00
BC6280	2017-07-29 12:40:00+03	64300.00
BC6294	2017-08-11 18:37:00+03	87200.00
BC62B6	2017-08-14 03:33:00+03	12000.00
BC62ED	2017-07-12 04:04:00+03	7200.00
BC6389	2017-08-01 23:49:00+03	27800.00
BC638E	2017-07-22 14:07:00+03	70700.00
BC640D	2017-07-22 13:42:00+03	111700.00
BC6481	2017-08-11 20:42:00+03	6000.00
BC64CF	2017-06-29 03:59:00+03	44800.00
BC6504	2017-07-18 03:07:00+03	46800.00
BC658E	2017-07-31 03:23:00+03	106900.00
BC659A	2017-08-12 07:05:00+03	51600.00
BC65DF	2017-08-10 03:01:00+03	8000.00
BC65FF	2017-07-11 02:43:00+03	48400.00
BC6602	2017-07-28 20:44:00+03	111600.00
BC664E	2017-07-03 05:23:00+03	56000.00
BC6664	2017-07-02 22:10:00+03	117200.00
BC66AB	2017-08-04 10:03:00+03	56900.00
BC66DA	2017-08-07 05:27:00+03	99200.00
BC6706	2017-08-04 17:39:00+03	133100.00
BC6755	2017-08-09 10:00:00+03	34000.00
BC6779	2017-07-08 16:14:00+03	110900.00
BC67A0	2017-07-17 18:47:00+03	30200.00
BC6881	2017-08-04 13:32:00+03	25200.00
BC68A9	2017-07-31 10:20:00+03	14000.00
BC68F1	2017-08-08 06:11:00+03	242000.00
BC68F4	2017-07-10 13:23:00+03	38400.00
BC6911	2017-08-03 05:20:00+03	23200.00
BC698A	2017-07-26 02:17:00+03	27200.00
BC6995	2017-07-13 02:51:00+03	84500.00
BC69DE	2017-07-22 19:22:00+03	13400.00
BC69EE	2017-08-02 13:50:00+03	88200.00
BC69FB	2017-07-12 22:55:00+03	112000.00
BC6A0A	2017-07-26 19:57:00+03	68800.00
BC6A3F	2017-07-31 09:23:00+03	14000.00
BC6A7B	2017-07-26 13:28:00+03	37100.00
BC6AA9	2017-08-08 09:40:00+03	14300.00
BC6AB4	2017-07-12 01:41:00+03	51000.00
BC6AFE	2017-08-11 18:31:00+03	67400.00
BC6B02	2017-07-21 22:29:00+03	12000.00
BC6B18	2017-08-09 07:09:00+03	51800.00
BC6B33	2017-08-11 01:15:00+03	127300.00
BC6B61	2017-07-27 10:58:00+03	44600.00
BC6B92	2017-07-31 02:09:00+03	27500.00
BC6BC6	2017-07-17 18:25:00+03	41300.00
BC6C10	2017-08-01 00:07:00+03	12600.00
BC6C39	2017-07-25 00:47:00+03	67000.00
BC6C7D	2017-07-09 04:13:00+03	123700.00
BC6CB6	2017-07-10 03:15:00+03	34000.00
BC6D69	2017-08-12 05:13:00+03	93700.00
BC6E6D	2017-07-23 13:30:00+03	40400.00
BC6EB5	2017-07-25 01:46:00+03	75600.00
BC6EDD	2017-07-03 21:36:00+03	26000.00
BC6F3F	2017-07-09 13:42:00+03	58600.00
BC6F79	2017-07-06 06:02:00+03	115800.00
BC6F87	2017-08-10 09:01:00+03	31000.00
BC6FA4	2017-07-31 01:12:00+03	14000.00
BC6FF4	2017-07-24 11:28:00+03	54400.00
BC7026	2017-08-13 13:12:00+03	24400.00
BC705E	2017-07-14 16:19:00+03	199200.00
BC707D	2017-07-01 15:44:00+03	14700.00
BC7082	2017-07-24 01:17:00+03	23200.00
BC7106	2017-07-16 22:12:00+03	120900.00
BC710E	2017-07-09 00:33:00+03	6000.00
BC7132	2017-07-08 14:07:00+03	60700.00
BC717F	2017-07-15 12:17:00+03	92800.00
BC71B9	2017-07-05 20:06:00+03	14900.00
BC7243	2017-07-31 06:02:00+03	21400.00
BC7245	2017-08-14 08:12:00+03	28700.00
BC7248	2017-07-18 18:12:00+03	122300.00
BC72E4	2017-08-12 21:12:00+03	52000.00
BC738B	2017-08-04 18:52:00+03	166000.00
BC73DB	2017-07-04 16:11:00+03	40000.00
BC7497	2017-08-04 23:05:00+03	44000.00
BC74FC	2017-07-22 13:32:00+03	43200.00
BC7506	2017-07-30 21:11:00+03	11600.00
BC751B	2017-07-22 09:18:00+03	12600.00
BC7569	2017-07-18 08:39:00+03	399800.00
BC759D	2017-07-28 00:37:00+03	266400.00
BC75A3	2017-08-05 02:15:00+03	28800.00
BC760E	2017-08-13 05:49:00+03	80400.00
BC7632	2017-07-22 23:13:00+03	36800.00
BC76AA	2017-07-11 02:14:00+03	47500.00
BC771A	2017-08-01 21:29:00+03	50000.00
BC773D	2017-07-08 16:28:00+03	73600.00
BC7747	2017-07-10 13:09:00+03	190400.00
BC7776	2017-07-15 09:20:00+03	86500.00
BC778E	2017-07-09 19:40:00+03	27300.00
BC77BE	2017-07-18 17:14:00+03	46000.00
BC77CB	2017-07-06 15:02:00+03	87000.00
BC7844	2017-08-04 22:44:00+03	135200.00
BC7871	2017-07-09 13:22:00+03	31600.00
BC7897	2017-08-08 07:00:00+03	59800.00
BC789A	2017-07-12 22:09:00+03	26000.00
BC790F	2017-07-04 02:43:00+03	179300.00
BC793F	2017-07-30 00:09:00+03	24400.00
BC7970	2017-07-21 18:57:00+03	56600.00
BC79E7	2017-08-11 09:44:00+03	96800.00
BC79F9	2017-08-09 20:00:00+03	111600.00
BC7A69	2017-07-18 20:27:00+03	106900.00
BC7AFC	2017-07-18 11:41:00+03	52000.00
BC7B09	2017-07-16 21:15:00+03	32900.00
BC7B45	2017-08-12 05:09:00+03	25600.00
BC7B62	2017-08-02 05:09:00+03	11300.00
BC7B74	2017-07-05 21:11:00+03	54000.00
BC7B89	2017-07-12 18:35:00+03	12600.00
BC7B8E	2017-07-16 23:34:00+03	93700.00
BC7BA5	2017-08-08 01:45:00+03	284000.00
BC7BB0	2017-08-14 10:41:00+03	48800.00
BC7C14	2017-08-08 05:57:00+03	44600.00
BC7C46	2017-08-06 16:19:00+03	103200.00
BC7C80	2017-07-23 16:42:00+03	62600.00
BC7CA1	2017-07-27 00:42:00+03	93800.00
BC7CE8	2017-07-23 22:51:00+03	52000.00
BC7DB4	2017-08-06 01:40:00+03	57600.00
BC7E06	2017-08-07 10:05:00+03	110300.00
BC7E0A	2017-07-06 18:24:00+03	170800.00
BC7E2D	2017-07-02 14:25:00+03	30000.00
BC7E2F	2017-08-13 14:28:00+03	55100.00
BC7E6C	2017-07-11 10:15:00+03	99800.00
BC7F46	2017-07-15 19:35:00+03	122600.00
BC7F92	2017-07-28 02:08:00+03	28000.00
BC7FFB	2017-07-07 12:36:00+03	52400.00
BC8018	2017-07-23 11:22:00+03	14000.00
BC8028	2017-07-06 21:34:00+03	6600.00
BC80BE	2017-07-16 15:08:00+03	51200.00
BC80CE	2017-07-20 23:35:00+03	308000.00
BC80F2	2017-07-26 10:56:00+03	47400.00
BC8108	2017-08-14 22:39:00+03	246000.00
BC8116	2017-07-03 19:44:00+03	7400.00
BC812C	2017-07-10 20:58:00+03	75800.00
BC818B	2017-07-20 12:48:00+03	14400.00
BC8272	2017-07-01 13:47:00+03	34000.00
BC8274	2017-07-02 06:21:00+03	119700.00
BC82CA	2017-07-06 07:34:00+03	21400.00
BC8336	2017-08-05 00:23:00+03	184300.00
BC8338	2017-08-12 10:54:00+03	20400.00
BC8357	2017-07-24 23:37:00+03	89400.00
BC838D	2017-07-28 12:33:00+03	80300.00
BC8487	2017-07-20 11:49:00+03	88500.00
BC8494	2017-07-02 11:06:00+03	6800.00
BC849D	2017-08-11 05:56:00+03	266400.00
BC84FC	2017-07-08 13:07:00+03	64500.00
BC8574	2017-07-23 14:09:00+03	117200.00
BC85F6	2017-08-10 02:37:00+03	92100.00
BC863C	2017-07-22 13:37:00+03	35700.00
BC8641	2017-07-03 05:50:00+03	175800.00
BC8644	2017-07-20 09:12:00+03	52700.00
BC86C8	2017-08-01 19:40:00+03	28000.00
BC86E1	2017-07-10 20:02:00+03	89800.00
BC872A	2017-07-28 21:04:00+03	132800.00
BC8786	2017-07-03 07:28:00+03	70800.00
BC87DB	2017-08-01 12:44:00+03	99300.00
BC8819	2017-07-03 07:47:00+03	114800.00
BC8828	2017-07-01 04:17:00+03	131100.00
BC8859	2017-07-13 19:52:00+03	6300.00
BC8862	2017-07-20 19:35:00+03	123600.00
BC895B	2017-07-10 20:14:00+03	56300.00
BC89C6	2017-07-28 05:22:00+03	16800.00
BC8A29	2017-08-08 05:57:00+03	26800.00
BC8A82	2017-08-14 00:35:00+03	79700.00
BC8AA3	2017-07-01 03:36:00+03	115800.00
BC8ABB	2017-07-21 06:00:00+03	10800.00
BC8AC0	2017-07-06 03:32:00+03	282000.00
BC8AD2	2017-07-30 10:13:00+03	26000.00
BC8B1F	2017-08-04 16:05:00+03	54800.00
BC8B43	2017-07-03 23:53:00+03	34000.00
BC8B7E	2017-07-25 11:46:00+03	20200.00
BC8BF8	2017-08-02 06:16:00+03	68400.00
BC8C52	2017-08-15 07:40:00+03	65100.00
BC8CA1	2017-07-21 23:51:00+03	22000.00
BC8CC8	2017-07-31 21:43:00+03	67800.00
BC8CD6	2017-07-28 08:44:00+03	19800.00
BC8CD7	2017-07-30 21:38:00+03	23200.00
BC8D17	2017-07-30 22:29:00+03	12100.00
BC8D21	2017-07-28 17:56:00+03	90600.00
BC8D72	2017-07-24 23:54:00+03	28000.00
BC8DAE	2017-07-04 22:24:00+03	37100.00
BC8E03	2017-07-29 12:11:00+03	313100.00
BC8EA6	2017-07-28 02:14:00+03	79600.00
BC8ED1	2017-07-04 02:50:00+03	58600.00
BC8F33	2017-07-24 17:44:00+03	339400.00
BC8F3B	2017-07-04 20:34:00+03	125100.00
BC8F58	2017-08-10 03:14:00+03	99200.00
BC8FEB	2017-07-13 05:16:00+03	54500.00
BC8FF1	2017-07-03 09:45:00+03	6700.00
BC8FF2	2017-08-13 10:16:00+03	67200.00
BC8FFE	2017-08-05 19:41:00+03	57700.00
BC901B	2017-07-30 00:38:00+03	128800.00
BC9026	2017-07-17 04:25:00+03	100300.00
BC9075	2017-07-22 01:01:00+03	93700.00
BC90B0	2017-08-14 11:19:00+03	99200.00
BC90F1	2017-07-21 12:44:00+03	54000.00
BC9124	2017-07-02 21:53:00+03	25600.00
BC9176	2017-07-04 00:47:00+03	99200.00
BC91B0	2017-07-25 01:37:00+03	38500.00
BC91D9	2017-08-03 18:15:00+03	26700.00
BC920A	2017-07-25 12:01:00+03	73600.00
BC9225	2017-06-30 05:29:00+03	52800.00
BC9257	2017-07-12 19:26:00+03	58000.00
BC9268	2017-08-14 02:09:00+03	91600.00
BC928E	2017-07-08 10:01:00+03	52700.00
BC92AD	2017-08-14 05:10:00+03	54000.00
BC92C6	2017-07-07 23:10:00+03	66600.00
BC930C	2017-07-06 22:19:00+03	193600.00
BC936E	2017-07-17 05:49:00+03	46200.00
BC9384	2017-08-05 11:12:00+03	95600.00
BC93C2	2017-07-30 09:29:00+03	38600.00
BC93FD	2017-08-12 23:41:00+03	70800.00
BC940C	2017-08-06 02:46:00+03	19600.00
BC9415	2017-07-08 03:46:00+03	105100.00
BC942A	2017-07-20 04:42:00+03	135600.00
BC94A0	2017-07-19 15:16:00+03	273300.00
BC94B7	2017-07-18 20:00:00+03	39100.00
BC9525	2017-07-17 11:03:00+03	129200.00
BC9528	2017-07-09 18:29:00+03	91400.00
BC954E	2017-07-20 23:32:00+03	430800.00
BC9569	2017-07-04 04:18:00+03	81800.00
BC956C	2017-08-04 05:24:00+03	34200.00
BC95C8	2017-07-16 09:14:00+03	21400.00
BC963F	2017-07-29 08:42:00+03	112000.00
BC9663	2017-08-13 20:52:00+03	68100.00
BC968D	2017-08-07 04:24:00+03	37900.00
BC96B3	2017-07-20 17:47:00+03	27200.00
BC96F7	2017-08-12 05:51:00+03	19800.00
BC9769	2017-07-21 03:26:00+03	23600.00
BC9856	2017-07-28 16:23:00+03	38600.00
BC9869	2017-08-12 13:12:00+03	70700.00
BC98BF	2017-07-13 15:31:00+03	58400.00
BC9955	2017-07-21 15:32:00+03	39800.00
BC998A	2017-08-11 01:51:00+03	191200.00
BC99D1	2017-07-04 05:40:00+03	166100.00
BC99EA	2017-07-10 13:06:00+03	98100.00
BC9A15	2017-08-14 21:40:00+03	36700.00
BC9A9A	2017-07-09 08:46:00+03	43200.00
BC9B16	2017-07-10 17:29:00+03	139700.00
BC9B54	2017-07-25 13:23:00+03	81200.00
BC9B5E	2017-07-11 14:32:00+03	139100.00
BC9BD1	2017-07-20 08:55:00+03	62400.00
BC9C0D	2017-07-03 08:31:00+03	26000.00
BC9C28	2017-07-18 08:43:00+03	35600.00
BC9C2D	2017-08-10 20:34:00+03	81600.00
BC9C9B	2017-08-14 19:38:00+03	156500.00
BC9CCE	2017-07-05 14:20:00+03	39800.00
BC9CEA	2017-07-25 16:07:00+03	68100.00
BC9CFB	2017-08-01 06:44:00+03	23200.00
BC9D19	2017-08-09 22:46:00+03	69500.00
BC9D9C	2017-08-04 19:51:00+03	67800.00
BC9DFD	2017-08-09 08:56:00+03	6700.00
BC9E37	2017-07-05 05:34:00+03	32700.00
BC9E3C	2017-07-17 15:54:00+03	141600.00
BC9E54	2017-08-09 17:09:00+03	46200.00
BC9E63	2017-08-14 04:31:00+03	147700.00
BC9E64	2017-08-12 00:23:00+03	34100.00
BC9E69	2017-08-04 12:36:00+03	35600.00
BC9F41	2017-08-13 14:25:00+03	89400.00
BC9FBB	2017-07-26 23:41:00+03	228700.00
BC9FD4	2017-08-14 10:23:00+03	24000.00
BCA011	2017-07-12 21:27:00+03	56600.00
BCA03D	2017-07-14 11:48:00+03	155600.00
BCA0ED	2017-08-09 17:25:00+03	7400.00
BCA112	2017-07-20 18:14:00+03	28000.00
BCA1BE	2017-08-13 10:47:00+03	12400.00
BCA1C8	2017-07-08 23:54:00+03	131100.00
BCA231	2017-07-29 10:08:00+03	48300.00
BCA25F	2017-07-03 04:32:00+03	14400.00
BCA268	2017-07-18 05:02:00+03	6800.00
BCA27A	2017-08-15 01:29:00+03	43200.00
BCA2AE	2017-07-03 20:16:00+03	26700.00
BCA2D4	2017-07-15 22:06:00+03	68800.00
BCA2E6	2017-07-24 06:07:00+03	49400.00
BCA31C	2017-07-30 13:40:00+03	57600.00
BCA338	2017-07-27 06:47:00+03	76800.00
BCA362	2017-08-06 10:57:00+03	47100.00
BCA37C	2017-07-09 00:56:00+03	38400.00
BCA395	2017-08-11 21:13:00+03	39800.00
BCA3C2	2017-08-14 13:14:00+03	28600.00
BCA44A	2017-07-10 18:28:00+03	6300.00
BCA569	2017-08-08 10:38:00+03	10800.00
BCA5B8	2017-08-03 15:18:00+03	66000.00
BCA5D9	2017-08-13 05:45:00+03	12000.00
BCA5EC	2017-07-26 00:44:00+03	52300.00
BCA5FC	2017-07-08 22:08:00+03	58800.00
BCA609	2017-08-03 01:43:00+03	52400.00
BCA631	2017-08-08 00:29:00+03	190400.00
BCA646	2017-07-31 22:23:00+03	6000.00
BCA67E	2017-08-14 15:34:00+03	75300.00
BCA69D	2017-06-30 21:22:00+03	58600.00
BCA6BF	2017-07-13 08:18:00+03	46000.00
BCA726	2017-08-11 23:33:00+03	38800.00
BCA799	2017-07-28 17:53:00+03	70600.00
BCA7BE	2017-07-06 06:58:00+03	13800.00
BCA7CA	2017-07-09 21:09:00+03	23600.00
BCA852	2017-07-16 14:23:00+03	128400.00
BCA85A	2017-07-06 10:26:00+03	58700.00
BCA880	2017-07-22 18:36:00+03	202300.00
BCA8B0	2017-07-30 05:54:00+03	46400.00
BCA916	2017-06-24 22:25:00+03	41200.00
BCA921	2017-07-30 09:53:00+03	110700.00
BCA967	2017-07-25 02:34:00+03	80800.00
BCA972	2017-08-11 13:40:00+03	46300.00
BCAA0B	2017-08-13 12:29:00+03	46300.00
BCAA97	2017-07-25 10:05:00+03	158500.00
BCAAF9	2017-07-08 10:52:00+03	396500.00
BCAB12	2017-08-02 15:37:00+03	6800.00
BCAB6B	2017-07-03 07:06:00+03	111000.00
BCAB76	2017-08-07 10:57:00+03	65100.00
BCAC0C	2017-07-05 05:59:00+03	160700.00
BCAC3A	2017-07-30 19:37:00+03	16400.00
BCAC4B	2017-07-28 03:13:00+03	32200.00
BCAC70	2017-07-26 11:26:00+03	14000.00
BCAC86	2017-08-14 21:41:00+03	190700.00
BCAD2E	2017-07-02 18:44:00+03	36100.00
BCADCA	2017-08-04 17:47:00+03	279800.00
BCAE0C	2017-07-19 14:15:00+03	99200.00
BCAE60	2017-07-24 13:21:00+03	57300.00
BCAEE7	2017-08-14 02:44:00+03	21300.00
BCAEE9	2017-07-27 04:12:00+03	115400.00
BCAF84	2017-07-12 19:26:00+03	124300.00
BCAFC1	2017-08-09 20:25:00+03	53600.00
BCAFEE	2017-07-22 12:14:00+03	38400.00
BCB0EA	2017-07-30 22:56:00+03	58400.00
BCB0EF	2017-07-29 23:05:00+03	20400.00
BCB175	2017-07-30 20:47:00+03	80900.00
BCB17A	2017-08-14 14:48:00+03	105400.00
BCB182	2017-08-03 19:55:00+03	61700.00
BCB190	2017-07-25 01:22:00+03	6000.00
BCB1B8	2017-07-08 23:24:00+03	44800.00
BCB1E8	2017-07-17 01:46:00+03	64800.00
BCB23A	2017-07-12 09:17:00+03	26800.00
BCB281	2017-08-11 05:58:00+03	155600.00
BCB2AB	2017-07-12 02:32:00+03	64700.00
BCB304	2017-07-13 08:40:00+03	37200.00
BCB326	2017-07-05 22:24:00+03	271100.00
BCB32B	2017-07-10 08:21:00+03	95000.00
BCB34D	2017-07-22 10:11:00+03	63200.00
BCB352	2017-08-14 16:49:00+03	22000.00
BCB35E	2017-07-13 18:48:00+03	23600.00
BCB3FD	2017-07-24 06:06:00+03	94200.00
BCB484	2017-08-02 18:12:00+03	20200.00
BCB48E	2017-07-03 17:53:00+03	56000.00
BCB4B1	2017-07-11 23:34:00+03	744800.00
BCB4C2	2017-07-04 21:56:00+03	14800.00
BCB526	2017-07-02 07:32:00+03	54400.00
BCB5B2	2017-07-04 18:52:00+03	48400.00
BCB5EA	2017-08-09 20:15:00+03	6000.00
BCB616	2017-07-07 08:44:00+03	57400.00
BCB638	2017-07-31 14:24:00+03	75300.00
BCB664	2017-07-05 21:40:00+03	20200.00
BCB67E	2017-08-13 16:12:00+03	72400.00
BCB6A7	2017-07-05 04:42:00+03	90400.00
BCB732	2017-08-09 04:25:00+03	83000.00
BCB7A7	2017-07-25 19:35:00+03	12000.00
BCB7DC	2017-08-07 11:56:00+03	30200.00
BCB7F4	2017-08-11 03:59:00+03	39800.00
BCB866	2017-08-15 03:52:00+03	166000.00
BCB8B1	2017-07-04 18:53:00+03	12000.00
BCB926	2017-07-30 05:30:00+03	139400.00
BCB930	2017-07-30 06:29:00+03	83500.00
BCB93C	2017-07-10 05:51:00+03	43200.00
BCB985	2017-08-02 06:29:00+03	26000.00
BCB9CE	2017-08-04 10:07:00+03	202800.00
BCB9E9	2017-07-27 07:44:00+03	239400.00
BCBA36	2017-08-14 21:16:00+03	19600.00
BCBA49	2017-07-04 12:02:00+03	133100.00
BCBA4A	2017-06-29 14:47:00+03	19800.00
BCBA9C	2017-07-19 11:19:00+03	38600.00
BCBAAF	2017-07-29 05:09:00+03	29600.00
BCBB04	2017-08-12 23:35:00+03	81600.00
BCBB5A	2017-07-19 23:53:00+03	67900.00
BCBB86	2017-08-02 22:42:00+03	147200.00
BCBB98	2017-08-09 09:15:00+03	28000.00
BCBBA5	2017-07-30 20:10:00+03	24400.00
BCBBDB	2017-08-11 07:25:00+03	99300.00
BCBC65	2017-07-18 05:35:00+03	143000.00
BCBD3B	2017-07-27 00:15:00+03	22000.00
BCBE0A	2017-07-07 01:39:00+03	8400.00
BCBE67	2017-07-12 11:09:00+03	109600.00
BCBE94	2017-07-06 23:56:00+03	40800.00
BCBEFD	2017-07-05 08:24:00+03	123000.00
BCBF4B	2017-07-13 23:24:00+03	26800.00
BCBF68	2017-07-12 17:21:00+03	46400.00
BCC013	2017-07-05 13:42:00+03	52000.00
BCC060	2017-07-10 07:42:00+03	288200.00
BCC0DB	2017-08-01 00:20:00+03	56000.00
BCC0DD	2017-07-06 12:51:00+03	6700.00
BCC0EC	2017-07-28 12:26:00+03	55800.00
BCC1A5	2017-07-25 16:13:00+03	58800.00
BCC1F9	2017-08-08 19:55:00+03	47500.00
BCC21A	2017-07-17 07:13:00+03	31600.00
BCC255	2017-07-10 15:27:00+03	378200.00
BCC286	2017-07-18 21:06:00+03	94000.00
BCC334	2017-07-17 01:59:00+03	101200.00
BCC371	2017-07-08 09:48:00+03	38600.00
BCC388	2017-07-09 00:28:00+03	34000.00
BCC390	2017-07-02 23:17:00+03	433200.00
BCC3B3	2017-07-05 01:19:00+03	75100.00
BCC3DD	2017-07-06 11:48:00+03	170700.00
BCC407	2017-07-23 14:07:00+03	47100.00
BCC47D	2017-08-11 00:20:00+03	66600.00
BCC4DE	2017-07-23 17:19:00+03	123000.00
BCC4F0	2017-08-04 21:19:00+03	84500.00
BCC503	2017-07-29 00:21:00+03	77600.00
BCC55E	2017-06-25 00:03:00+03	88800.00
BCC583	2017-07-18 18:09:00+03	36200.00
BCC5E7	2017-07-17 00:57:00+03	303100.00
BCC5EB	2017-08-14 05:42:00+03	117900.00
BCC62A	2017-08-12 00:34:00+03	77200.00
BCC657	2017-08-11 19:41:00+03	28000.00
BCC678	2017-08-06 12:57:00+03	16800.00
BCC68E	2017-07-26 17:39:00+03	51200.00
BCC6A7	2017-07-19 01:40:00+03	28800.00
BCC6B7	2017-07-20 19:00:00+03	111600.00
BCC70C	2017-08-07 10:41:00+03	99700.00
BCC70D	2017-07-16 05:55:00+03	76400.00
BCC70E	2017-07-21 13:37:00+03	119500.00
BCC7A8	2017-07-10 16:31:00+03	111600.00
BCC80F	2017-08-13 16:34:00+03	246000.00
BCC856	2017-07-09 20:00:00+03	179200.00
BCC85A	2017-07-27 18:56:00+03	63400.00
BCC8E8	2017-07-31 18:53:00+03	56000.00
BCC93F	2017-08-08 00:59:00+03	57800.00
BCC9E4	2017-07-24 17:34:00+03	107300.00
BCC9F7	2017-06-27 15:22:00+03	23400.00
BCCA20	2017-07-22 03:21:00+03	30900.00
BCCA65	2017-07-16 14:01:00+03	80000.00
BCCACB	2017-07-18 00:00:00+03	132200.00
BCCB19	2017-08-10 21:09:00+03	68100.00
BCCB91	2017-07-24 03:51:00+03	40800.00
BCCBDA	2017-07-06 04:00:00+03	70800.00
BCCC07	2017-07-09 09:43:00+03	148700.00
BCCCAB	2017-08-02 18:49:00+03	67600.00
BCCD16	2017-08-14 20:48:00+03	80800.00
BCCD66	2017-07-09 04:28:00+03	135400.00
BCCD79	2017-07-17 11:18:00+03	59400.00
BCCD8E	2017-07-03 00:27:00+03	65000.00
BCCDCA	2017-08-10 11:25:00+03	24200.00
BCCDF0	2017-07-20 18:58:00+03	181800.00
BCCE2E	2017-07-02 19:22:00+03	123000.00
BCCE34	2017-07-18 23:58:00+03	59200.00
BCCE80	2017-08-05 10:37:00+03	28000.00
BCCE99	2017-08-01 17:41:00+03	84500.00
BCCEA2	2017-08-13 00:57:00+03	26000.00
BCCEA7	2017-07-17 10:33:00+03	266300.00
BCCEAB	2017-07-25 03:37:00+03	49200.00
BCCEB6	2017-08-13 19:54:00+03	68100.00
BCCEFB	2017-07-13 00:40:00+03	56600.00
BCCF18	2017-07-21 11:09:00+03	83000.00
BCCF3B	2017-07-15 00:16:00+03	26000.00
BCCF9C	2017-07-17 07:19:00+03	24600.00
BCCFD9	2017-07-28 19:12:00+03	44500.00
BCCFF7	2017-07-25 05:57:00+03	56100.00
BCD039	2017-07-21 16:38:00+03	258400.00
BCD06F	2017-08-09 00:10:00+03	37200.00
BCD0CC	2017-08-11 04:39:00+03	18400.00
BCD0F3	2017-07-07 08:22:00+03	156500.00
BCD163	2017-07-28 16:06:00+03	46200.00
BCD179	2017-08-08 03:42:00+03	28000.00
BCD1C2	2017-07-11 05:04:00+03	102000.00
BCD1C6	2017-07-28 14:42:00+03	49600.00
BCD212	2017-07-07 21:53:00+03	84100.00
BCD25A	2017-07-24 14:03:00+03	93900.00
BCD264	2017-07-10 18:22:00+03	152600.00
BCD2BA	2017-08-09 17:06:00+03	58900.00
BCD305	2017-08-06 07:12:00+03	12600.00
BCD308	2017-08-10 07:37:00+03	81800.00
BCD340	2017-08-04 22:20:00+03	16400.00
BCD377	2017-08-06 19:04:00+03	132800.00
BCD3ED	2017-07-06 08:37:00+03	190000.00
BCD420	2017-07-22 13:23:00+03	100200.00
BCD465	2017-08-04 07:04:00+03	21400.00
BCD485	2017-07-03 14:11:00+03	47400.00
BCD4F3	2017-07-02 11:20:00+03	48800.00
BCD512	2017-08-03 09:53:00+03	51000.00
BCD584	2017-07-19 00:42:00+03	131600.00
BCD5A9	2017-08-13 11:58:00+03	33600.00
BCD5B0	2017-07-01 07:13:00+03	386300.00
BCD5BE	2017-07-03 03:33:00+03	62800.00
BCD690	2017-08-03 21:40:00+03	24300.00
BCD69C	2017-08-14 09:38:00+03	24300.00
BCD6C3	2017-07-12 10:24:00+03	110400.00
BCD720	2017-08-02 02:51:00+03	142400.00
BCD731	2017-08-05 06:51:00+03	75600.00
BCD733	2017-07-07 22:43:00+03	137700.00
BCD79B	2017-08-12 16:33:00+03	54300.00
BCD7B7	2017-08-13 22:47:00+03	131100.00
BCD843	2017-08-15 17:22:00+03	62000.00
BCD845	2017-07-19 09:04:00+03	64200.00
BCD8B6	2017-06-28 21:47:00+03	22100.00
BCD913	2017-07-20 18:00:00+03	46000.00
BCD916	2017-07-15 21:33:00+03	96600.00
BCD926	2017-08-14 05:24:00+03	68800.00
BCD946	2017-08-14 05:15:00+03	57700.00
BCD94E	2017-08-05 21:46:00+03	28000.00
BCD950	2017-07-16 11:33:00+03	301800.00
BCD968	2017-07-15 11:45:00+03	83600.00
BCD969	2017-07-24 10:22:00+03	77900.00
BCD970	2017-08-04 19:26:00+03	14400.00
BCD9F3	2017-07-18 06:00:00+03	16400.00
BCDA1A	2017-07-04 16:25:00+03	57400.00
BCDA20	2017-07-08 10:42:00+03	65900.00
BCDA46	2017-08-03 20:29:00+03	40800.00
BCDA6A	2017-08-06 10:15:00+03	54400.00
BCDA8D	2017-07-26 02:48:00+03	231200.00
BCDAAC	2017-07-27 22:35:00+03	40400.00
BCDB70	2017-08-10 10:51:00+03	129600.00
BCDC90	2017-07-26 16:45:00+03	142200.00
BCDD2A	2017-07-31 06:04:00+03	63000.00
BCDD30	2017-07-21 16:54:00+03	54400.00
BCDDFB	2017-07-06 15:31:00+03	25400.00
BCDE35	2017-07-02 17:12:00+03	48100.00
BCDE5F	2017-07-18 15:07:00+03	7400.00
BCDE85	2017-07-17 05:42:00+03	40200.00
BCDEE7	2017-07-21 23:00:00+03	47100.00
BCDEE9	2017-07-27 18:00:00+03	117600.00
BCDF2F	2017-07-17 19:08:00+03	49500.00
BCDF3D	2017-07-19 08:59:00+03	167400.00
BCDF9E	2017-07-06 08:04:00+03	77900.00
BCE029	2017-07-17 19:31:00+03	64700.00
BCE079	2017-07-14 23:23:00+03	86600.00
BCE106	2017-07-12 23:26:00+03	55800.00
BCE133	2017-07-30 10:06:00+03	134000.00
BCE207	2017-07-03 04:54:00+03	40800.00
BCE21C	2017-08-09 19:38:00+03	123300.00
BCE272	2017-07-16 21:25:00+03	77200.00
BCE29D	2017-07-16 17:42:00+03	6000.00
BCE2DE	2017-07-29 23:42:00+03	8000.00
BCE32E	2017-07-28 04:28:00+03	25200.00
BCE456	2017-07-24 06:20:00+03	6800.00
BCE47B	2017-07-13 14:43:00+03	22000.00
BCE482	2017-07-26 21:53:00+03	55800.00
BCE4BF	2017-07-17 09:22:00+03	92000.00
BCE6A8	2017-08-03 22:59:00+03	50800.00
BCE6A9	2017-07-11 14:57:00+03	54400.00
BCE6D1	2017-07-19 00:32:00+03	78300.00
BCE6E1	2017-06-28 08:08:00+03	101400.00
BCE6E8	2017-07-11 09:16:00+03	88600.00
BCE6E9	2017-07-17 00:45:00+03	24800.00
BCE6EF	2017-07-24 05:43:00+03	13400.00
BCE77D	2017-08-05 16:22:00+03	43200.00
BCE795	2017-08-11 02:06:00+03	55800.00
BCE7D7	2017-07-09 20:46:00+03	29600.00
BCE7F2	2017-06-29 16:30:00+03	76200.00
BCE827	2017-08-10 00:09:00+03	187600.00
BCE891	2017-07-08 03:25:00+03	59800.00
BCE898	2017-08-15 01:58:00+03	115600.00
BCE8E8	2017-07-19 19:23:00+03	23600.00
BCE90C	2017-07-08 01:48:00+03	40000.00
BCE96D	2017-08-12 20:04:00+03	135200.00
BCE98E	2017-07-21 13:01:00+03	64500.00
BCEB6A	2017-07-06 07:03:00+03	124400.00
BCEB93	2017-07-05 23:12:00+03	111600.00
BCEBC3	2017-07-31 10:50:00+03	312300.00
BCEBD3	2017-07-18 00:54:00+03	133100.00
BCEC16	2017-08-12 03:49:00+03	147500.00
BCEC71	2017-07-07 10:14:00+03	45000.00
BCECAC	2017-08-09 22:52:00+03	13400.00
BCED10	2017-08-08 23:13:00+03	135600.00
BCED59	2017-07-18 21:51:00+03	38200.00
BCED78	2017-07-13 07:24:00+03	199200.00
BCEDCC	2017-08-10 03:18:00+03	209900.00
BCEDE2	2017-07-18 17:42:00+03	90600.00
BCEE3D	2017-07-15 14:12:00+03	379600.00
BCEE6A	2017-07-21 14:27:00+03	61200.00
BCEF12	2017-06-29 01:57:00+03	66600.00
BCEF25	2017-08-11 03:51:00+03	26600.00
BCEF44	2017-07-04 01:11:00+03	45000.00
BCEFFA	2017-07-09 00:39:00+03	6600.00
BCF049	2017-07-22 13:05:00+03	32200.00
BCF04A	2017-08-14 13:55:00+03	38600.00
BCF04D	2017-07-10 06:11:00+03	23200.00
BCF0E1	2017-08-13 07:49:00+03	65200.00
BCF0F7	2017-07-01 13:19:00+03	305800.00
BCF102	2017-08-10 22:15:00+03	65700.00
BCF12A	2017-08-13 02:17:00+03	6800.00
BCF168	2017-07-21 00:09:00+03	15800.00
BCF20F	2017-07-26 21:56:00+03	14800.00
BCF2AE	2017-07-16 05:47:00+03	37100.00
BCF300	2017-07-04 10:13:00+03	55900.00
BCF35C	2017-07-29 16:03:00+03	103400.00
BCF39A	2017-07-07 08:36:00+03	246000.00
BCF3B2	2017-06-29 12:33:00+03	34000.00
BCF470	2017-07-31 04:33:00+03	266400.00
BCF4B1	2017-08-01 00:34:00+03	26000.00
BCF53F	2017-08-05 18:27:00+03	92800.00
BCF581	2017-07-22 18:37:00+03	357600.00
BCF5E6	2017-08-05 11:24:00+03	269200.00
BCF5EB	2017-07-26 08:39:00+03	24400.00
BCF60F	2017-07-08 13:55:00+03	42800.00
BCF63F	2017-07-23 08:10:00+03	119700.00
BCF67B	2017-08-01 15:06:00+03	215500.00
BCF6A5	2017-08-02 04:41:00+03	6300.00
BCF70E	2017-07-21 09:58:00+03	76600.00
BCF796	2017-07-20 01:38:00+03	136200.00
BCF84F	2017-07-02 20:14:00+03	56000.00
BCF89D	2017-07-15 18:12:00+03	61700.00
BCF8D0	2017-07-01 18:36:00+03	97900.00
BCF8D7	2017-07-13 08:26:00+03	44700.00
BCF8EF	2017-07-29 16:09:00+03	179300.00
BCF91F	2017-07-21 06:54:00+03	25600.00
BCF953	2017-08-11 16:08:00+03	6800.00
BCF9C7	2017-07-02 11:23:00+03	142400.00
BCFA19	2017-07-05 02:18:00+03	27900.00
BCFA63	2017-07-18 11:33:00+03	266200.00
BCFB37	2017-08-05 15:02:00+03	15900.00
BCFB8B	2017-07-07 23:41:00+03	9800.00
BCFBDC	2017-08-05 01:35:00+03	51800.00
BCFBED	2017-08-14 05:02:00+03	26800.00
BCFC37	2017-07-18 18:51:00+03	95600.00
BCFC3B	2017-08-10 04:56:00+03	139300.00
BCFC95	2017-08-11 01:13:00+03	15000.00
BCFCB4	2017-07-21 12:38:00+03	25000.00
BCFD5B	2017-08-05 13:21:00+03	47400.00
BCFD8F	2017-07-24 19:49:00+03	78200.00
BCFDBF	2017-07-08 21:33:00+03	294400.00
BCFDC7	2017-08-03 19:34:00+03	136500.00
BCFE3C	2017-07-31 20:55:00+03	56000.00
BCFE55	2017-07-10 18:32:00+03	65900.00
BCFEAD	2017-07-14 07:26:00+03	162600.00
BCFEC4	2017-07-05 02:05:00+03	71900.00
BCFEDD	2017-07-17 19:01:00+03	67600.00
BCFF3A	2017-08-09 11:54:00+03	36200.00
BCFF3B	2017-07-20 21:22:00+03	44000.00
BCFF51	2017-07-18 09:55:00+03	25600.00
BCFFBF	2017-08-08 16:00:00+03	65500.00
BCFFC3	2017-07-29 03:36:00+03	119600.00
BCFFD7	2017-07-21 05:42:00+03	21400.00
BD0068	2017-07-26 08:08:00+03	265600.00
BD009E	2017-08-09 22:08:00+03	14400.00
BD00E5	2017-07-15 12:51:00+03	38600.00
BD00E7	2017-08-05 23:13:00+03	68800.00
BD018D	2017-07-17 04:42:00+03	179700.00
BD019A	2017-08-01 10:43:00+03	202400.00
BD020F	2017-08-06 21:29:00+03	252200.00
BD0262	2017-07-30 19:52:00+03	139100.00
BD02C5	2017-08-03 00:23:00+03	27200.00
BD02DE	2017-07-19 08:22:00+03	70400.00
BD02F1	2017-07-12 20:13:00+03	31600.00
BD0325	2017-08-14 16:36:00+03	56100.00
BD033A	2017-07-02 15:29:00+03	148300.00
BD035E	2017-08-08 10:20:00+03	98300.00
BD0360	2017-07-28 03:06:00+03	120700.00
BD038B	2017-06-30 04:52:00+03	28800.00
BD03B3	2017-08-06 01:17:00+03	28000.00
BD03FF	2017-08-08 07:58:00+03	67900.00
BD0446	2017-08-11 21:47:00+03	72300.00
BD044B	2017-07-29 06:13:00+03	54400.00
BD0473	2017-07-18 17:37:00+03	28800.00
BD048D	2017-07-23 21:28:00+03	23400.00
BD04B8	2017-07-04 18:09:00+03	85000.00
BD04E4	2017-07-06 07:45:00+03	24800.00
BD052C	2017-07-31 03:09:00+03	15800.00
BD05B7	2017-08-04 06:46:00+03	62700.00
BD05F7	2017-07-13 04:01:00+03	68800.00
BD05FD	2017-07-05 06:01:00+03	23400.00
BD060E	2017-08-10 01:30:00+03	31600.00
BD0614	2017-08-13 03:18:00+03	23200.00
BD0645	2017-07-22 23:04:00+03	56100.00
BD0649	2017-07-22 17:49:00+03	23200.00
BD0669	2017-07-16 16:37:00+03	84500.00
BD0679	2017-07-13 16:08:00+03	49000.00
BD0713	2017-07-14 05:03:00+03	82900.00
BD0758	2017-07-24 20:15:00+03	19800.00
BD0762	2017-08-02 19:56:00+03	6000.00
BD07A4	2017-07-22 00:10:00+03	25400.00
BD07BF	2017-07-31 01:27:00+03	21800.00
BD08A1	2017-08-13 14:40:00+03	33100.00
BD08B5	2017-07-20 21:52:00+03	276200.00
BD08BA	2017-07-11 21:10:00+03	10800.00
BD08C3	2017-07-11 15:09:00+03	36800.00
BD0918	2017-07-09 05:50:00+03	28000.00
BD093F	2017-08-13 14:17:00+03	28800.00
BD0942	2017-07-05 02:21:00+03	34000.00
BD0959	2017-07-17 11:38:00+03	92400.00
BD0A20	2017-07-23 19:14:00+03	44000.00
BD0A58	2017-08-07 06:05:00+03	194800.00
BD0A94	2017-07-21 10:10:00+03	92000.00
BD0AD9	2017-08-06 15:31:00+03	36900.00
BD0B84	2017-07-12 23:25:00+03	16400.00
BD0BCF	2017-08-14 02:09:00+03	64500.00
BD0BEF	2017-07-31 02:52:00+03	65500.00
BD0C09	2017-07-11 21:28:00+03	46800.00
BD0C84	2017-07-31 20:42:00+03	23600.00
BD0CC1	2017-07-12 14:29:00+03	42400.00
BD0CFB	2017-07-19 09:18:00+03	56900.00
BD0D0F	2017-08-13 18:59:00+03	19600.00
BD0D62	2017-07-16 09:34:00+03	65500.00
BD0DA3	2017-07-27 16:19:00+03	131600.00
BD0DE0	2017-07-18 22:35:00+03	30200.00
BD0DE6	2017-08-14 07:15:00+03	12000.00
BD0E1A	2017-07-18 21:15:00+03	270200.00
BD0E29	2017-07-20 02:54:00+03	26800.00
BD0E58	2017-07-26 15:53:00+03	33100.00
BD0EB3	2017-08-10 23:58:00+03	43800.00
BD0EDE	2017-08-07 10:29:00+03	56000.00
BD0EFF	2017-07-02 04:08:00+03	24700.00
BD0F0D	2017-08-13 01:08:00+03	73600.00
BD0F1A	2017-07-13 04:29:00+03	106400.00
BD0F25	2017-07-13 04:16:00+03	40800.00
BD0F2B	2017-08-12 23:21:00+03	96600.00
BD0F49	2017-08-11 04:12:00+03	14400.00
BD0F54	2017-07-31 21:10:00+03	29600.00
BD0FB8	2017-08-09 21:59:00+03	135400.00
BD0FEA	2017-08-03 04:08:00+03	40800.00
BD1012	2017-07-29 08:47:00+03	23200.00
BD1015	2017-07-31 21:11:00+03	69500.00
BD103B	2017-07-28 04:05:00+03	54500.00
BD107C	2017-07-19 11:32:00+03	270800.00
BD1194	2017-08-11 06:32:00+03	68200.00
BD11A3	2017-08-09 19:19:00+03	24400.00
BD11F2	2017-07-27 00:32:00+03	25400.00
BD121B	2017-07-08 08:30:00+03	20400.00
BD1260	2017-06-30 19:20:00+03	65500.00
BD129F	2017-07-27 00:30:00+03	163700.00
BD132D	2017-07-25 16:44:00+03	193100.00
BD134A	2017-08-06 14:30:00+03	63200.00
BD1369	2017-08-09 04:39:00+03	31600.00
BD138C	2017-08-08 04:26:00+03	93900.00
BD1441	2017-07-11 02:36:00+03	26000.00
BD145A	2017-07-06 10:14:00+03	124200.00
BD151A	2017-07-19 13:55:00+03	136000.00
BD153C	2017-08-12 21:49:00+03	111600.00
BD1585	2017-07-11 12:23:00+03	201800.00
BD1589	2017-08-03 01:45:00+03	217200.00
BD15EC	2017-08-07 09:11:00+03	223200.00
BD1615	2017-08-10 00:02:00+03	19600.00
BD1619	2017-07-21 19:19:00+03	58000.00
BD1649	2017-08-01 18:00:00+03	136200.00
BD16CD	2017-07-20 20:12:00+03	76600.00
BD16E9	2017-08-10 01:51:00+03	62000.00
BD16F1	2017-07-09 23:25:00+03	52700.00
BD16F6	2017-08-09 17:57:00+03	195000.00
BD1705	2017-07-27 22:31:00+03	49700.00
BD1756	2017-08-04 21:58:00+03	46400.00
BD176E	2017-08-01 23:34:00+03	121500.00
BD1776	2017-07-18 19:00:00+03	154500.00
BD17B2	2017-07-22 18:44:00+03	14400.00
BD180B	2017-07-22 21:01:00+03	181600.00
BD182B	2017-07-01 06:36:00+03	3700.00
BD18E6	2017-07-22 09:01:00+03	25800.00
BD1917	2017-07-31 15:55:00+03	123000.00
BD1924	2017-08-14 22:56:00+03	83000.00
BD1967	2017-06-26 04:33:00+03	25800.00
BD197B	2017-07-14 09:40:00+03	46400.00
BD198A	2017-07-03 07:18:00+03	56000.00
BD19AB	2017-07-24 23:27:00+03	28800.00
BD19F2	2017-07-26 08:58:00+03	75600.00
BD1A51	2017-08-05 02:38:00+03	43200.00
BD1A6D	2017-07-14 10:15:00+03	101400.00
BD1AB8	2017-07-23 09:17:00+03	25800.00
BD1ABB	2017-07-07 14:40:00+03	46400.00
BD1ACD	2017-07-25 16:02:00+03	28800.00
BD1AD6	2017-07-14 08:34:00+03	59400.00
BD1ADA	2017-07-27 04:23:00+03	44600.00
BD1B06	2017-07-03 21:29:00+03	67600.00
BD1B4B	2017-07-17 19:58:00+03	36800.00
BD1B89	2017-07-28 09:36:00+03	102100.00
BD1BAD	2017-08-12 12:36:00+03	124200.00
BD1BE1	2017-08-03 14:10:00+03	44500.00
BD1C1B	2017-08-14 23:39:00+03	62600.00
BD1C3E	2017-07-24 10:36:00+03	76000.00
BD1CA1	2017-08-02 19:07:00+03	28800.00
BD1CDC	2017-07-24 19:56:00+03	10800.00
BD1CF0	2017-07-18 22:34:00+03	40800.00
BD1D07	2017-08-03 15:01:00+03	79000.00
BD1D0E	2017-08-06 08:24:00+03	31400.00
BD1D55	2017-08-07 09:54:00+03	174400.00
BD2051	2017-07-07 10:34:00+03	44000.00
BD20C5	2017-07-05 09:47:00+03	103500.00
BD20FB	2017-08-04 14:21:00+03	59000.00
BD20FC	2017-07-18 08:01:00+03	123000.00
BD2177	2017-07-04 17:52:00+03	27300.00
BD2178	2017-07-20 07:11:00+03	31400.00
BD218C	2017-08-08 06:02:00+03	99200.00
BD218F	2017-08-14 00:34:00+03	136600.00
BD21A6	2017-08-03 19:02:00+03	372600.00
BD21CB	2017-07-20 09:27:00+03	65900.00
BD22A0	2017-07-26 07:57:00+03	26000.00
BD22B7	2017-08-10 09:12:00+03	43600.00
BD22BE	2017-06-28 09:39:00+03	54800.00
BD22C2	2017-07-19 21:04:00+03	48800.00
BD22CB	2017-08-11 06:34:00+03	606200.00
BD231B	2017-08-12 05:15:00+03	62600.00
BD2322	2017-07-13 14:20:00+03	75200.00
BD2327	2017-08-12 20:04:00+03	25600.00
BD236E	2017-08-04 09:43:00+03	70800.00
BD2396	2017-08-10 23:43:00+03	271200.00
BD239E	2017-07-10 18:33:00+03	71200.00
BD23CC	2017-07-28 16:52:00+03	33600.00
BD23D4	2017-08-04 03:50:00+03	112000.00
BD23DD	2017-07-26 03:01:00+03	41800.00
BD2401	2017-08-12 08:47:00+03	147900.00
BD241D	2017-08-12 00:10:00+03	133200.00
BD2433	2017-07-12 07:58:00+03	6000.00
BD2438	2017-08-01 16:07:00+03	43200.00
BD246A	2017-07-06 07:52:00+03	66600.00
BD2479	2017-07-23 03:52:00+03	408600.00
BD24D5	2017-07-09 13:48:00+03	54800.00
BD24DB	2017-07-30 19:07:00+03	186100.00
BD24ED	2017-07-14 23:20:00+03	16300.00
BD2518	2017-07-18 13:41:00+03	69400.00
BD2615	2017-07-13 12:55:00+03	56000.00
BD2766	2017-07-06 04:35:00+03	83000.00
BD2799	2017-08-07 12:15:00+03	115900.00
BD27C5	2017-08-14 20:44:00+03	31200.00
BD27D4	2017-08-07 11:04:00+03	179800.00
BD27F4	2017-08-10 02:40:00+03	95600.00
BD2808	2017-08-03 06:36:00+03	23100.00
BD2835	2017-07-25 00:03:00+03	15400.00
BD289E	2017-07-08 15:42:00+03	108000.00
BD28B8	2017-07-27 20:12:00+03	37700.00
BD28BD	2017-07-28 18:36:00+03	100600.00
BD28F6	2017-07-12 18:34:00+03	113200.00
BD2906	2017-07-26 12:05:00+03	42000.00
BD295B	2017-08-04 23:56:00+03	153300.00
BD2967	2017-07-05 21:45:00+03	49300.00
BD29C7	2017-07-13 18:11:00+03	67200.00
BD29F8	2017-08-11 10:01:00+03	39600.00
BD2A08	2017-07-21 17:13:00+03	28000.00
BD2A40	2017-07-14 16:53:00+03	248300.00
BD2A67	2017-07-23 18:51:00+03	11600.00
BD2ADC	2017-07-01 17:01:00+03	58200.00
BD2AE7	2017-07-08 07:28:00+03	88300.00
BD2AFD	2017-08-15 09:29:00+03	201800.00
BD2B10	2017-08-15 01:51:00+03	44000.00
BD2B2D	2017-07-11 20:49:00+03	27200.00
BD2B4D	2017-08-15 17:50:00+03	24000.00
BD2B86	2017-07-11 05:30:00+03	14400.00
BD2BE7	2017-07-19 13:38:00+03	46400.00
BD2C5A	2017-08-08 19:04:00+03	52000.00
BD2C64	2017-07-24 18:17:00+03	284800.00
BD2CCF	2017-07-08 10:53:00+03	38000.00
BD2CDA	2017-07-19 22:49:00+03	413400.00
BD2DED	2017-07-24 00:13:00+03	99200.00
BD2E07	2017-07-07 16:00:00+03	48800.00
BD2E39	2017-07-19 00:13:00+03	62300.00
BD2E3D	2017-07-19 10:06:00+03	123000.00
BD2E55	2017-06-29 16:18:00+03	26800.00
BD2F40	2017-06-30 11:17:00+03	44000.00
BD2F45	2017-07-24 07:19:00+03	26000.00
BD2F58	2017-08-07 10:23:00+03	100000.00
BD2F5B	2017-08-04 17:26:00+03	122300.00
BD3100	2017-07-20 06:10:00+03	38600.00
BD3131	2017-07-16 04:38:00+03	23200.00
BD3150	2017-07-04 19:41:00+03	123000.00
BD3194	2017-08-11 00:05:00+03	70700.00
BD31F2	2017-07-27 08:38:00+03	36200.00
BD3236	2017-07-10 09:37:00+03	55600.00
BD328B	2017-07-05 11:18:00+03	33300.00
BD32EF	2017-07-16 07:50:00+03	137100.00
BD334C	2017-07-30 22:14:00+03	55600.00
BD33A2	2017-08-02 07:30:00+03	89700.00
BD3446	2017-07-02 01:25:00+03	46300.00
BD348A	2017-07-30 16:41:00+03	125200.00
BD34A8	2017-07-01 22:49:00+03	28600.00
BD34AB	2017-07-07 07:19:00+03	39300.00
BD34B2	2017-07-13 18:58:00+03	78100.00
BD35FB	2017-06-30 06:36:00+03	196100.00
BD372B	2017-07-17 01:49:00+03	32700.00
BD3751	2017-08-11 02:47:00+03	32700.00
BD3760	2017-08-03 23:37:00+03	133100.00
BD3767	2017-07-25 23:38:00+03	99200.00
BD37EB	2017-07-25 21:14:00+03	57600.00
BD380E	2017-08-02 02:57:00+03	652700.00
BD3831	2017-08-01 21:22:00+03	46200.00
BD38E0	2017-07-08 01:11:00+03	36200.00
BD38F0	2017-07-06 14:33:00+03	12600.00
BD3930	2017-08-11 23:06:00+03	61500.00
BD3932	2017-08-04 07:36:00+03	33300.00
BD397E	2017-07-17 04:44:00+03	199700.00
BD39B4	2017-07-02 11:43:00+03	33800.00
BD39F1	2017-07-17 00:42:00+03	139300.00
BD3A0A	2017-08-07 07:47:00+03	135400.00
BD3A2A	2017-07-26 06:44:00+03	92800.00
BD3A32	2017-07-23 03:15:00+03	81600.00
BD3A9C	2017-08-04 07:44:00+03	55800.00
BD3ABA	2017-07-05 15:06:00+03	26000.00
BD3AE5	2017-07-16 08:14:00+03	46300.00
BD3AFC	2017-07-15 12:24:00+03	15400.00
BD3B91	2017-08-09 09:16:00+03	14400.00
BD3C1C	2017-08-11 04:16:00+03	136200.00
BD3C29	2017-07-14 11:21:00+03	28000.00
BD3C2A	2017-07-07 03:42:00+03	68800.00
BD3C43	2017-07-25 09:29:00+03	82900.00
BD3C53	2017-07-27 23:18:00+03	232300.00
BD3C5E	2017-08-07 07:34:00+03	47400.00
BD3C72	2017-07-29 20:22:00+03	17800.00
BD3C8D	2017-07-21 15:00:00+03	56600.00
BD3CA9	2017-07-13 18:52:00+03	26000.00
BD3CB0	2017-07-24 04:35:00+03	51600.00
BD3CB2	2017-08-02 03:08:00+03	26700.00
BD3CCD	2017-08-04 18:22:00+03	248300.00
BD3CCE	2017-07-05 11:37:00+03	69100.00
BD3CFB	2017-08-10 05:02:00+03	39500.00
BD3CFF	2017-07-26 11:25:00+03	10600.00
BD3D55	2017-07-12 22:06:00+03	44000.00
BD3D9A	2017-08-05 23:29:00+03	182100.00
BD3DB0	2017-07-01 00:27:00+03	304100.00
BD3DBA	2017-08-15 07:51:00+03	29400.00
BD3DFA	2017-07-09 04:19:00+03	7400.00
BD3E1B	2017-07-07 23:51:00+03	22000.00
BD3E73	2017-07-01 11:11:00+03	46800.00
BD3EE7	2017-07-23 06:48:00+03	46800.00
BD3EFC	2017-07-03 08:47:00+03	38400.00
BD3F0F	2017-07-22 04:40:00+03	55800.00
BD3F3D	2017-07-28 09:24:00+03	46200.00
BD4022	2017-07-25 00:34:00+03	7200.00
BD4037	2017-07-03 12:18:00+03	52000.00
BD40B2	2017-07-10 01:12:00+03	26000.00
BD40E4	2017-07-19 22:22:00+03	12600.00
BD40F9	2017-07-23 17:32:00+03	133100.00
BD4113	2017-08-14 17:19:00+03	72200.00
BD4171	2017-07-02 18:30:00+03	38800.00
BD41A7	2017-07-01 18:52:00+03	6000.00
BD4212	2017-07-08 15:20:00+03	40800.00
BD424B	2017-07-03 08:01:00+03	135400.00
BD42A2	2017-07-30 02:44:00+03	55800.00
BD42A9	2017-07-21 23:19:00+03	75300.00
BD42AF	2017-07-07 22:38:00+03	24400.00
BD42D4	2017-08-13 15:58:00+03	53500.00
BD435B	2017-07-30 11:59:00+03	38800.00
BD4379	2017-08-14 14:54:00+03	44000.00
BD439F	2017-08-01 17:14:00+03	117200.00
BD43D2	2017-07-27 20:01:00+03	23200.00
BD43DF	2017-07-09 10:07:00+03	59300.00
BD4400	2017-07-25 08:57:00+03	6700.00
BD4414	2017-08-14 03:19:00+03	53400.00
BD4478	2017-07-15 12:55:00+03	26000.00
BD44CC	2017-08-07 12:57:00+03	23200.00
BD44E2	2017-07-08 09:58:00+03	74400.00
BD44F5	2017-07-09 18:44:00+03	111700.00
BD450D	2017-08-12 11:45:00+03	38400.00
BD4529	2017-08-08 01:56:00+03	133200.00
BD454D	2017-07-12 13:37:00+03	96800.00
BD4577	2017-07-18 09:45:00+03	55800.00
BD45DE	2017-08-06 11:44:00+03	12400.00
BD4637	2017-07-12 13:12:00+03	57600.00
BD465B	2017-08-04 20:21:00+03	88000.00
BD4666	2017-08-07 09:29:00+03	133200.00
BD4679	2017-08-02 07:06:00+03	119500.00
BD4691	2017-07-03 00:03:00+03	143000.00
BD46BE	2017-07-09 02:03:00+03	38200.00
BD46DF	2017-07-06 13:17:00+03	65500.00
BD473D	2017-07-25 23:36:00+03	178800.00
BD47BC	2017-07-21 20:32:00+03	88600.00
BD484A	2017-07-11 13:30:00+03	181600.00
BD486F	2017-08-08 04:51:00+03	75600.00
BD489D	2017-07-12 15:48:00+03	19600.00
BD489F	2017-08-13 14:48:00+03	54000.00
BD48A8	2017-06-26 12:43:00+03	55800.00
BD494C	2017-08-12 18:58:00+03	20200.00
BD49C8	2017-07-30 01:13:00+03	55800.00
BD4A04	2017-07-20 15:22:00+03	58700.00
BD4A1C	2017-08-03 20:02:00+03	105200.00
BD4A44	2017-07-18 12:07:00+03	129800.00
BD4A8C	2017-07-31 03:04:00+03	61800.00
BD4AAE	2017-06-30 04:47:00+03	100000.00
BD4AB8	2017-07-27 15:53:00+03	28000.00
BD4B65	2017-07-16 23:28:00+03	271200.00
BD4B73	2017-06-24 17:17:00+03	31700.00
BD4BC5	2017-07-13 18:25:00+03	99300.00
BD4BC6	2017-07-17 18:28:00+03	51300.00
BD4C17	2017-07-29 18:44:00+03	177200.00
BD4C29	2017-08-03 08:11:00+03	53200.00
BD4CC8	2017-08-01 19:02:00+03	96800.00
BD4CDE	2017-07-14 08:33:00+03	71200.00
BD4CED	2017-08-14 19:06:00+03	127300.00
BD4CF6	2017-08-11 09:18:00+03	23600.00
BD4CFE	2017-07-04 02:05:00+03	26000.00
BD4D6E	2017-07-14 20:38:00+03	64900.00
BD4DA7	2017-07-06 10:57:00+03	47600.00
BD4DC7	2017-07-18 23:03:00+03	22600.00
BD4DEE	2017-08-06 09:24:00+03	43100.00
BD4E1B	2017-08-08 13:02:00+03	27200.00
BD4E8A	2017-07-29 21:01:00+03	40400.00
BD4EDA	2017-07-16 11:32:00+03	113300.00
BD4EED	2017-08-01 01:26:00+03	15000.00
BD4EFF	2017-07-24 21:06:00+03	38600.00
BD4F16	2017-07-24 07:24:00+03	136000.00
BD4F1D	2017-07-17 16:51:00+03	94000.00
BD4FB0	2017-08-08 11:04:00+03	28300.00
BD5125	2017-07-30 02:26:00+03	28300.00
BD5169	2017-08-13 07:56:00+03	185800.00
BD5187	2017-07-22 12:01:00+03	20200.00
BD51C6	2017-08-08 18:48:00+03	18000.00
BD51F2	2017-07-19 16:03:00+03	50000.00
BD5274	2017-07-27 16:58:00+03	124000.00
BD5299	2017-07-12 00:08:00+03	84800.00
BD5407	2017-07-16 05:43:00+03	143000.00
BD5425	2017-07-05 19:56:00+03	125000.00
BD544E	2017-07-02 04:24:00+03	111600.00
BD549C	2017-07-07 16:20:00+03	87400.00
BD5527	2017-07-28 01:38:00+03	92900.00
BD5550	2017-08-04 16:11:00+03	19600.00
BD556B	2017-08-01 10:47:00+03	193400.00
BD5586	2017-07-19 09:28:00+03	29500.00
BD5604	2017-08-15 05:50:00+03	24000.00
BD560F	2017-07-19 14:23:00+03	61700.00
BD5615	2017-07-09 18:53:00+03	27800.00
BD566C	2017-07-25 11:11:00+03	26000.00
BD567B	2017-08-06 22:41:00+03	111600.00
BD570A	2017-08-06 00:12:00+03	26800.00
BD570D	2017-08-10 04:36:00+03	40400.00
BD5750	2017-07-27 20:59:00+03	53300.00
BD57E5	2017-07-09 01:48:00+03	6000.00
BD5856	2017-07-23 23:29:00+03	98000.00
BD585B	2017-07-13 00:41:00+03	3700.00
BD58CC	2017-07-14 04:22:00+03	36700.00
BD591A	2017-07-31 13:28:00+03	59800.00
BD5937	2017-07-05 14:58:00+03	46400.00
BD5940	2017-08-09 08:09:00+03	60100.00
BD5943	2017-08-02 08:14:00+03	143200.00
BD596A	2017-07-27 03:41:00+03	38600.00
BD598C	2017-07-25 11:07:00+03	306600.00
BD5994	2017-08-12 09:18:00+03	37600.00
BD5995	2017-08-05 14:20:00+03	130300.00
BD59A7	2017-08-07 21:27:00+03	69500.00
BD59E2	2017-08-04 14:07:00+03	49900.00
BD59E7	2017-07-09 03:34:00+03	30000.00
BD5A97	2017-07-30 14:11:00+03	58600.00
BD5BBE	2017-07-12 22:00:00+03	64300.00
BD5BDD	2017-08-11 10:25:00+03	112000.00
BD5C7E	2017-08-06 12:39:00+03	28000.00
BD5C8C	2017-08-07 08:36:00+03	258300.00
BD5CB6	2017-08-05 18:07:00+03	133100.00
BD5CD6	2017-08-01 00:06:00+03	66900.00
BD5D32	2017-07-25 12:40:00+03	72000.00
BD5D98	2017-07-24 04:32:00+03	46000.00
BD5DA1	2017-07-20 16:49:00+03	246000.00
BD5E3E	2017-07-16 05:01:00+03	28000.00
BD5E4E	2017-07-12 20:04:00+03	45200.00
BD5EA3	2017-08-09 03:26:00+03	272000.00
BD5EBF	2017-08-08 14:07:00+03	19600.00
BD5F4C	2017-07-05 06:20:00+03	41800.00
BD5FF0	2017-07-28 12:26:00+03	144000.00
BD5FFC	2017-08-06 14:01:00+03	120900.00
BD6020	2017-07-15 16:35:00+03	27200.00
BD604A	2017-08-01 14:33:00+03	38600.00
BD60D9	2017-08-10 08:19:00+03	25000.00
BD60E2	2017-07-04 13:42:00+03	165700.00
BD6140	2017-08-15 17:07:00+03	55200.00
BD61DA	2017-07-23 23:31:00+03	76400.00
BD61FE	2017-07-23 00:41:00+03	124200.00
BD621D	2017-07-28 10:05:00+03	40800.00
BD6224	2017-07-10 22:19:00+03	96200.00
BD6287	2017-07-29 21:51:00+03	25100.00
BD628D	2017-08-06 17:48:00+03	23200.00
BD6334	2017-08-09 02:23:00+03	48800.00
BD635E	2017-08-15 11:56:00+03	6700.00
BD637C	2017-08-04 19:10:00+03	99200.00
BD63A2	2017-07-09 16:05:00+03	66700.00
BD63B9	2017-08-10 23:43:00+03	46200.00
BD63EA	2017-08-03 23:29:00+03	246000.00
BD63EF	2017-07-23 01:51:00+03	56000.00
BD6403	2017-07-27 07:14:00+03	199700.00
BD641D	2017-07-21 16:06:00+03	128000.00
BD6432	2017-08-10 14:04:00+03	115900.00
BD64AC	2017-07-28 16:44:00+03	42800.00
BD64D3	2017-07-10 18:07:00+03	26700.00
BD6545	2017-07-31 07:28:00+03	140700.00
BD6587	2017-07-02 02:18:00+03	92700.00
BD65CE	2017-07-31 11:02:00+03	15000.00
BD660A	2017-08-12 00:59:00+03	35600.00
BD6624	2017-07-24 06:43:00+03	109400.00
BD66B0	2017-08-04 09:02:00+03	56000.00
BD6701	2017-07-09 10:21:00+03	70400.00
BD6775	2017-07-09 11:29:00+03	26000.00
BD6806	2017-07-12 08:22:00+03	65600.00
BD68B9	2017-08-04 22:24:00+03	81600.00
BD68DA	2017-07-07 12:51:00+03	81600.00
BD6902	2017-07-21 17:22:00+03	102200.00
BD6981	2017-07-05 18:07:00+03	28000.00
BD69E3	2017-07-10 09:15:00+03	149800.00
BD6A08	2017-08-08 03:55:00+03	79700.00
BD6A0E	2017-07-13 13:43:00+03	40000.00
BD6A2F	2017-08-09 12:28:00+03	75300.00
BD6A6F	2017-07-04 17:44:00+03	84100.00
BD6ADF	2017-08-01 22:06:00+03	11600.00
BD6B07	2017-06-29 14:53:00+03	28800.00
BD6BC6	2017-08-12 16:54:00+03	43900.00
BD6BD6	2017-07-17 16:22:00+03	85500.00
BD6C85	2017-08-13 08:01:00+03	56600.00
BD6CC6	2017-07-25 21:22:00+03	56200.00
BD6D0C	2017-07-14 23:17:00+03	72800.00
BD6D4D	2017-07-29 02:50:00+03	57500.00
BD6D73	2017-07-06 21:16:00+03	29600.00
BD6D75	2017-07-10 18:18:00+03	35700.00
BD6DD5	2017-08-06 19:32:00+03	50800.00
BD6DEA	2017-07-28 19:20:00+03	77800.00
BD6E2E	2017-07-01 16:17:00+03	10800.00
BD6E40	2017-08-10 05:38:00+03	48800.00
BD6E5B	2017-07-17 18:45:00+03	32800.00
BD6E7B	2017-07-03 13:40:00+03	42700.00
BD6E81	2017-07-05 06:47:00+03	112000.00
BD6F04	2017-07-26 17:44:00+03	29600.00
BD6F28	2017-08-12 13:52:00+03	54800.00
BD6FB3	2017-07-07 16:20:00+03	28700.00
BD6FCB	2017-07-24 19:42:00+03	95000.00
BD702A	2017-08-03 12:45:00+03	124000.00
BD706D	2017-07-05 15:40:00+03	12600.00
BD70F6	2017-08-07 14:48:00+03	173900.00
BD71C1	2017-07-21 00:07:00+03	170000.00
BD71D5	2017-06-30 19:40:00+03	115700.00
BD723F	2017-08-01 20:37:00+03	55800.00
BD7264	2017-08-13 09:53:00+03	66000.00
BD7274	2017-07-26 10:11:00+03	57500.00
BD728D	2017-07-01 03:48:00+03	46000.00
BD730D	2017-08-06 18:54:00+03	25600.00
BD737A	2017-07-30 14:26:00+03	46300.00
BD73AE	2017-07-08 03:07:00+03	88600.00
BD73BE	2017-07-12 22:32:00+03	131900.00
BD73E3	2017-08-07 01:17:00+03	101200.00
BD73E6	2017-07-20 19:00:00+03	46000.00
BD7411	2017-08-11 17:05:00+03	82600.00
BD74A7	2017-07-26 09:08:00+03	23200.00
BD74D9	2017-07-18 16:39:00+03	146300.00
BD7560	2017-07-29 22:34:00+03	182300.00
BD7577	2017-07-06 21:43:00+03	177600.00
BD7591	2017-08-05 12:46:00+03	14400.00
BD75D1	2017-08-01 01:01:00+03	36200.00
BD7604	2017-07-22 06:49:00+03	139400.00
BD7625	2017-08-06 13:37:00+03	32500.00
BD7695	2017-07-26 09:19:00+03	22000.00
BD769A	2017-07-02 23:46:00+03	12600.00
BD76DA	2017-07-15 17:30:00+03	22000.00
BD7719	2017-07-09 07:27:00+03	44600.00
BD777C	2017-07-07 11:20:00+03	57600.00
BD77A0	2017-08-05 14:19:00+03	32800.00
BD77B5	2017-08-04 06:31:00+03	14000.00
BD77B9	2017-07-28 09:02:00+03	8000.00
BD77EE	2017-07-03 11:24:00+03	42800.00
BD77FE	2017-08-04 07:31:00+03	131300.00
BD7829	2017-07-09 08:05:00+03	12000.00
BD78AE	2017-07-06 16:06:00+03	52000.00
BD795A	2017-07-31 08:45:00+03	306800.00
BD7988	2017-07-06 03:45:00+03	47400.00
BD79D6	2017-07-25 13:20:00+03	92600.00
BD79D9	2017-07-25 10:02:00+03	199600.00
BD79FE	2017-08-02 05:53:00+03	136600.00
BD7A2B	2017-07-21 16:16:00+03	115600.00
BD7A3B	2017-07-06 19:27:00+03	62000.00
BD7A4B	2017-06-28 14:18:00+03	246000.00
BD7AB6	2017-08-06 12:02:00+03	11800.00
BD7AD2	2017-07-31 07:18:00+03	23600.00
BD7B16	2017-07-05 04:21:00+03	67600.00
BD7B46	2017-08-09 03:49:00+03	68800.00
BD7B51	2017-08-15 03:53:00+03	411900.00
BD7BC9	2017-08-08 12:49:00+03	46400.00
BD7C0A	2017-07-11 01:51:00+03	46800.00
BD7C30	2017-07-13 20:26:00+03	142400.00
BD7C64	2017-08-14 10:56:00+03	25200.00
BD7CC1	2017-07-04 13:43:00+03	37000.00
BD7E40	2017-08-06 08:27:00+03	116800.00
BD7E60	2017-08-08 09:32:00+03	131600.00
BD7E78	2017-08-05 13:08:00+03	6700.00
BD7EE7	2017-07-10 13:15:00+03	38400.00
BD8043	2017-07-24 01:36:00+03	159100.00
BD8053	2017-07-26 02:22:00+03	97200.00
BD8060	2017-08-12 05:03:00+03	121400.00
BD8070	2017-07-02 16:02:00+03	139800.00
BD8076	2017-08-02 08:02:00+03	67200.00
BD80AA	2017-07-25 01:22:00+03	19600.00
BD812A	2017-07-13 01:37:00+03	13400.00
BD8148	2017-07-15 11:49:00+03	46400.00
BD8149	2017-08-01 13:41:00+03	73600.00
BD8156	2017-07-23 04:53:00+03	81700.00
BD817D	2017-08-03 11:15:00+03	19600.00
BD8200	2017-07-30 16:01:00+03	51900.00
BD8231	2017-07-28 10:20:00+03	72700.00
BD82CB	2017-08-04 02:33:00+03	39800.00
BD82DB	2017-08-09 17:44:00+03	156000.00
BD8322	2017-08-01 01:31:00+03	166000.00
BD833E	2017-07-11 18:26:00+03	24400.00
BD83CF	2017-07-26 19:40:00+03	44800.00
BD8416	2017-08-13 20:40:00+03	21600.00
BD844E	2017-07-12 12:35:00+03	102100.00
BD8506	2017-08-06 22:20:00+03	110500.00
BD852E	2017-08-15 07:53:00+03	28100.00
BD85AE	2017-07-27 05:34:00+03	91500.00
BD85FF	2017-07-22 12:57:00+03	109400.00
BD8600	2017-08-15 01:50:00+03	26700.00
BD8605	2017-07-21 18:29:00+03	56000.00
BD866D	2017-07-27 08:51:00+03	76400.00
BD869E	2017-07-25 02:38:00+03	3700.00
BD86EC	2017-08-04 01:03:00+03	55600.00
BD870D	2017-08-15 07:34:00+03	7800.00
BD870F	2017-07-23 07:29:00+03	43200.00
BD8778	2017-07-16 22:45:00+03	62600.00
BD87DF	2017-07-02 04:32:00+03	20400.00
BD8819	2017-07-01 09:19:00+03	10600.00
BD8828	2017-07-30 07:44:00+03	88200.00
BD8832	2017-08-02 12:05:00+03	48300.00
BD8896	2017-08-12 06:18:00+03	70700.00
BD88B7	2017-06-27 23:18:00+03	28000.00
BD88E6	2017-07-19 14:55:00+03	136300.00
BD88F0	2017-08-08 17:58:00+03	99200.00
BD89A2	2017-08-08 04:04:00+03	46400.00
BD89AE	2017-07-13 06:00:00+03	67200.00
BD8A5D	2017-08-05 20:25:00+03	40800.00
BD8AB6	2017-08-07 21:41:00+03	28000.00
BD8AF2	2017-07-13 12:38:00+03	52300.00
BD8AF4	2017-07-06 16:00:00+03	184500.00
BD8B47	2017-07-26 17:05:00+03	23200.00
BD8B59	2017-07-17 05:25:00+03	28000.00
BD8B90	2017-07-31 11:15:00+03	168000.00
BD8BBA	2017-07-15 03:14:00+03	64800.00
BD8BE2	2017-07-23 00:31:00+03	184500.00
BD8C33	2017-07-13 01:10:00+03	111600.00
BD8CA2	2017-07-24 11:50:00+03	59300.00
BD8CC2	2017-07-12 02:54:00+03	56600.00
BD8CF1	2017-08-02 23:55:00+03	47500.00
BD8D03	2017-07-06 09:59:00+03	28000.00
BD8D18	2017-08-13 00:05:00+03	39800.00
BD8D33	2017-07-27 08:34:00+03	48800.00
BD8D60	2017-07-10 08:59:00+03	56100.00
BD8EC3	2017-08-02 17:11:00+03	108000.00
BD8ECA	2017-07-11 11:14:00+03	76400.00
BD8EE5	2017-07-22 12:38:00+03	89600.00
BD8FD8	2017-07-11 15:59:00+03	123000.00
BD8FE4	2017-07-22 21:26:00+03	47100.00
BD901B	2017-07-20 23:12:00+03	17200.00
BD9028	2017-07-28 02:23:00+03	89200.00
BD903D	2017-07-05 14:37:00+03	168200.00
BD9079	2017-08-10 13:31:00+03	135400.00
BD9084	2017-08-03 01:50:00+03	108000.00
BD9093	2017-07-13 05:54:00+03	57600.00
BD90F6	2017-07-24 13:33:00+03	270700.00
BD9102	2017-07-04 23:09:00+03	78700.00
BD918C	2017-08-12 18:17:00+03	14900.00
BD9204	2017-08-07 10:39:00+03	51600.00
BD9229	2017-07-06 20:09:00+03	43200.00
BD9243	2017-07-23 20:28:00+03	70700.00
BD9291	2017-07-23 21:42:00+03	131100.00
BD9293	2017-08-14 03:22:00+03	135400.00
BD92E9	2017-07-02 16:02:00+03	56100.00
BD92EE	2017-07-22 03:19:00+03	250000.00
BD92F9	2017-07-15 01:38:00+03	111600.00
BD9316	2017-07-18 04:01:00+03	28700.00
BD9329	2017-08-14 23:12:00+03	47400.00
BD93A6	2017-07-10 23:13:00+03	62000.00
BD93FC	2017-07-11 14:11:00+03	18000.00
BD94A6	2017-08-06 01:36:00+03	75300.00
BD94FC	2017-07-20 22:42:00+03	54800.00
BD95A0	2017-07-25 02:43:00+03	23600.00
BD95A9	2017-07-18 18:50:00+03	173600.00
BD95B6	2017-08-13 20:49:00+03	156600.00
BD9643	2017-07-21 00:01:00+03	125000.00
BD967B	2017-08-13 04:07:00+03	80900.00
BD967C	2017-07-20 09:55:00+03	133100.00
BD96CC	2017-07-09 11:29:00+03	13400.00
BD970D	2017-08-02 17:04:00+03	7400.00
BD971B	2017-07-04 08:15:00+03	101100.00
BD973F	2017-07-15 11:23:00+03	406700.00
BD9770	2017-08-13 14:47:00+03	30000.00
BD987C	2017-08-04 09:46:00+03	200500.00
BD9895	2017-08-04 02:30:00+03	55800.00
BD989A	2017-07-19 14:19:00+03	132800.00
BD98F8	2017-07-24 12:41:00+03	46400.00
BD99ED	2017-07-31 10:17:00+03	55600.00
BD9A9C	2017-08-05 10:29:00+03	25600.00
BD9B72	2017-07-05 19:14:00+03	223200.00
BD9BC8	2017-07-25 15:45:00+03	57600.00
BD9BD7	2017-08-13 01:17:00+03	77200.00
BD9C01	2017-07-06 10:50:00+03	135600.00
BD9C02	2017-07-16 06:19:00+03	75300.00
BD9C21	2017-08-13 01:56:00+03	148000.00
BD9C65	2017-08-04 22:41:00+03	81900.00
BD9D04	2017-08-05 09:00:00+03	39300.00
BD9D08	2017-07-14 06:54:00+03	51800.00
BD9D65	2017-08-13 17:05:00+03	99200.00
BD9DD8	2017-07-30 04:50:00+03	40800.00
BD9E26	2017-08-06 12:51:00+03	72400.00
BD9E32	2017-08-11 13:23:00+03	44500.00
BD9E70	2017-07-23 14:21:00+03	192300.00
BD9E75	2017-08-11 13:38:00+03	57400.00
BD9EA1	2017-07-06 03:29:00+03	48500.00
BD9EF0	2017-07-06 19:37:00+03	109200.00
BD9EF8	2017-07-05 01:20:00+03	40800.00
BD9F51	2017-08-11 19:03:00+03	151200.00
BD9F69	2017-07-15 00:13:00+03	47000.00
BD9F89	2017-07-20 03:40:00+03	42900.00
BDA063	2017-07-16 00:44:00+03	55800.00
BDA066	2017-07-29 14:56:00+03	47400.00
BDA091	2017-07-03 05:16:00+03	57800.00
BDA09E	2017-08-05 18:59:00+03	21000.00
BDA0AC	2017-08-04 23:13:00+03	99300.00
BDA0B8	2017-08-12 15:59:00+03	13400.00
BDA0C9	2017-07-27 00:50:00+03	16400.00
BDA0D9	2017-08-09 05:18:00+03	266300.00
BDA0DB	2017-08-06 23:12:00+03	70500.00
BDA11F	2017-08-06 07:50:00+03	96300.00
BDA153	2017-07-10 22:17:00+03	52800.00
BDA1AB	2017-07-22 22:13:00+03	70600.00
BDA1CF	2017-08-07 23:59:00+03	206300.00
BDA229	2017-08-10 16:52:00+03	186900.00
BDA2C0	2017-07-13 23:39:00+03	58200.00
BDA2D9	2017-07-21 06:32:00+03	99200.00
BDA2FD	2017-07-25 19:48:00+03	29800.00
BDA302	2017-07-28 17:27:00+03	31600.00
BDA325	2017-08-14 06:29:00+03	6300.00
BDA37C	2017-07-21 14:18:00+03	57500.00
BDA394	2017-07-13 09:59:00+03	22000.00
BDA3A3	2017-07-13 20:55:00+03	112000.00
BDA3EE	2017-08-12 06:58:00+03	43600.00
BDA409	2017-07-23 18:54:00+03	28300.00
BDA442	2017-07-21 05:47:00+03	125400.00
BDA46F	2017-07-08 22:10:00+03	100000.00
BDA481	2017-08-14 16:11:00+03	35600.00
BDA65F	2017-08-13 07:24:00+03	28000.00
BDA668	2017-07-07 22:05:00+03	223200.00
BDA6AC	2017-08-02 03:25:00+03	21400.00
BDA709	2017-07-30 13:48:00+03	111600.00
BDA70E	2017-07-21 09:23:00+03	170600.00
BDA74B	2017-07-29 19:20:00+03	55900.00
BDA75C	2017-07-19 04:19:00+03	21800.00
BDA76E	2017-07-01 08:53:00+03	93000.00
BDA7AE	2017-08-11 16:04:00+03	26800.00
BDA80F	2017-07-18 15:44:00+03	60000.00
BDA8AC	2017-07-23 04:25:00+03	57300.00
BDA8EC	2017-07-20 18:00:00+03	19600.00
BDA9CB	2017-08-02 02:27:00+03	270800.00
BDAA06	2017-07-28 16:43:00+03	38600.00
BDAACC	2017-07-08 20:08:00+03	12400.00
BDAAEE	2017-08-09 20:57:00+03	269100.00
BDAB11	2017-07-04 08:34:00+03	39200.00
BDAB1E	2017-07-19 13:27:00+03	83000.00
BDAB3B	2017-08-09 14:59:00+03	60700.00
BDAB7F	2017-07-27 01:19:00+03	136200.00
BDAB93	2017-08-03 03:16:00+03	58600.00
BDAB94	2017-07-19 21:48:00+03	270800.00
BDAC3A	2017-08-07 02:25:00+03	99200.00
BDACCA	2017-07-13 04:13:00+03	52300.00
BDACE8	2017-07-15 09:54:00+03	240600.00
BDAD39	2017-08-07 22:16:00+03	55800.00
BDAD58	2017-07-30 22:22:00+03	14000.00
BDADA9	2017-07-05 17:45:00+03	74400.00
BDADC3	2017-07-28 12:46:00+03	63700.00
BDADD1	2017-07-18 20:51:00+03	39400.00
BDAE0A	2017-07-23 08:32:00+03	78600.00
BDAE56	2017-08-10 13:32:00+03	10700.00
BDAF23	2017-08-04 20:09:00+03	28700.00
BDAF59	2017-07-08 13:08:00+03	120900.00
BDAF70	2017-08-12 02:44:00+03	56600.00
BDAFBC	2017-08-03 15:37:00+03	397700.00
BDAFC7	2017-07-11 16:24:00+03	29600.00
BDAFF7	2017-07-31 08:29:00+03	47300.00
BDB004	2017-07-16 20:48:00+03	28800.00
BDB008	2017-07-26 10:11:00+03	46200.00
BDB016	2017-07-19 12:43:00+03	112200.00
BDB050	2017-07-16 15:52:00+03	72300.00
BDB098	2017-07-18 15:44:00+03	24200.00
BDB0C6	2017-07-28 16:13:00+03	27200.00
BDB0F1	2017-07-09 01:42:00+03	103100.00
BDB121	2017-07-24 02:42:00+03	112000.00
BDB15D	2017-07-28 13:01:00+03	270800.00
BDB18A	2017-08-09 14:03:00+03	24400.00
BDB236	2017-07-18 22:45:00+03	246000.00
BDB244	2017-07-13 23:15:00+03	23200.00
BDB26B	2017-08-11 20:20:00+03	105100.00
BDB27A	2017-07-22 22:43:00+03	114700.00
BDB298	2017-07-14 14:14:00+03	73500.00
BDB2AA	2017-08-04 08:28:00+03	113600.00
BDB2C3	2017-08-03 07:17:00+03	89600.00
BDB2C9	2017-08-14 05:54:00+03	14400.00
BDB2F5	2017-07-13 00:26:00+03	30400.00
BDB345	2017-07-24 22:07:00+03	58400.00
BDB36F	2017-08-11 02:26:00+03	21800.00
BDB378	2017-07-07 07:27:00+03	38600.00
BDB37A	2017-08-06 00:26:00+03	81300.00
BDB382	2017-07-11 18:14:00+03	34000.00
BDB3B7	2017-08-15 17:52:00+03	28800.00
BDB3F3	2017-07-21 07:08:00+03	50700.00
BDB455	2017-07-01 17:36:00+03	28400.00
BDB467	2017-08-11 05:10:00+03	36800.00
BDB4B4	2017-07-23 03:43:00+03	123000.00
BDB581	2017-08-14 16:17:00+03	42000.00
BDB5F1	2017-07-07 23:34:00+03	35600.00
BDB61A	2017-08-03 22:37:00+03	69300.00
BDB631	2017-07-17 11:22:00+03	62000.00
BDB651	2017-07-15 13:07:00+03	163900.00
BDB682	2017-07-21 15:36:00+03	50000.00
BDB691	2017-07-29 16:28:00+03	139200.00
BDB6A5	2017-07-07 09:34:00+03	50800.00
BDB71A	2017-07-31 03:44:00+03	26200.00
BDB729	2017-07-26 20:47:00+03	56600.00
BDB72E	2017-07-04 16:05:00+03	26200.00
BDB737	2017-07-24 15:22:00+03	222700.00
BDB75B	2017-07-07 01:53:00+03	178800.00
BDB75D	2017-07-14 20:32:00+03	68100.00
BDB776	2017-08-15 17:49:00+03	42600.00
BDB7AA	2017-07-17 02:34:00+03	39300.00
BDB7DC	2017-07-28 21:20:00+03	6700.00
BDB83B	2017-07-06 23:26:00+03	88700.00
BDB89E	2017-08-11 10:34:00+03	313800.00
BDB8FA	2017-07-12 18:24:00+03	13700.00
BDB989	2017-08-11 05:01:00+03	28300.00
BDB9A6	2017-07-18 05:25:00+03	153300.00
BDB9D6	2017-08-07 18:20:00+03	121400.00
BDB9E5	2017-08-13 02:53:00+03	46500.00
BDBA6D	2017-07-18 21:35:00+03	181600.00
BDBB12	2017-08-10 23:54:00+03	24700.00
BDBB65	2017-07-20 00:47:00+03	135600.00
BDBB8F	2017-08-10 05:18:00+03	61800.00
BDBC38	2017-07-08 12:54:00+03	23400.00
BDBC5E	2017-07-07 22:09:00+03	31600.00
BDBCBE	2017-07-30 04:52:00+03	27200.00
BDBCE7	2017-07-26 21:57:00+03	33500.00
BDBD0C	2017-07-29 09:06:00+03	73500.00
BDBD52	2017-07-10 12:44:00+03	166000.00
BDBD8C	2017-07-12 09:01:00+03	123000.00
BDBDC2	2017-07-23 18:16:00+03	131100.00
BDBDDE	2017-07-14 21:12:00+03	229900.00
BDBDE5	2017-07-02 12:18:00+03	113300.00
BDBE04	2017-07-06 07:50:00+03	66600.00
BDBE05	2017-07-30 15:06:00+03	73500.00
BDBE21	2017-08-13 11:20:00+03	57900.00
BDBE45	2017-07-15 13:38:00+03	67900.00
BDBE81	2017-07-19 03:43:00+03	46300.00
BDBF37	2017-08-11 16:50:00+03	35700.00
BDBF3C	2017-08-14 19:48:00+03	21800.00
BDBFC7	2017-08-15 03:35:00+03	203300.00
BDC047	2017-07-24 22:57:00+03	28800.00
BDC09F	2017-08-08 21:24:00+03	85000.00
BDC0AA	2017-08-12 23:58:00+03	12000.00
BDC0CA	2017-08-08 17:59:00+03	95600.00
BDC0F0	2017-08-07 10:17:00+03	22000.00
BDC11B	2017-07-23 05:26:00+03	115800.00
BDC139	2017-06-29 03:38:00+03	32800.00
BDC156	2017-08-04 00:38:00+03	70800.00
BDC189	2017-07-06 08:54:00+03	85700.00
BDC206	2017-06-30 09:08:00+03	65600.00
BDC236	2017-07-08 23:40:00+03	62600.00
BDC298	2017-07-11 11:27:00+03	28000.00
BDC2B1	2017-07-28 15:35:00+03	26000.00
BDC3B8	2017-07-31 12:10:00+03	113300.00
BDC3BC	2017-07-06 17:26:00+03	75600.00
BDC3E8	2017-08-01 04:03:00+03	133200.00
BDC402	2017-07-19 22:18:00+03	48500.00
BDC4A2	2017-07-13 23:49:00+03	31600.00
BDC4C8	2017-08-09 17:00:00+03	113600.00
BDC4E5	2017-08-01 07:04:00+03	62900.00
BDC5E9	2017-07-13 05:28:00+03	21400.00
BDC6B0	2017-07-29 23:06:00+03	28800.00
BDC6C8	2017-07-14 05:19:00+03	83600.00
BDC70E	2017-08-04 04:32:00+03	36200.00
BDC7D6	2017-08-09 19:27:00+03	42600.00
BDC81D	2017-08-14 08:59:00+03	80400.00
BDC858	2017-08-07 16:29:00+03	52000.00
BDC8A8	2017-08-03 07:41:00+03	55800.00
BDC8D4	2017-07-05 01:41:00+03	107000.00
BDC8D9	2017-08-01 05:16:00+03	40800.00
BDC954	2017-07-09 20:31:00+03	170000.00
BDCA74	2017-08-08 20:08:00+03	68800.00
BDCACD	2017-07-22 06:59:00+03	10800.00
BDCAD7	2017-07-06 02:42:00+03	24200.00
BDCAD9	2017-07-24 19:22:00+03	25400.00
BDCB02	2017-08-04 02:28:00+03	12000.00
BDCB21	2017-07-20 21:07:00+03	48800.00
BDCB32	2017-07-14 17:59:00+03	56000.00
BDCB6E	2017-07-13 17:19:00+03	136200.00
BDCB84	2017-07-23 22:13:00+03	21000.00
BDCC65	2017-07-28 07:57:00+03	82900.00
BDCC72	2017-07-12 22:44:00+03	100600.00
BDCCCC	2017-08-04 02:28:00+03	48800.00
BDCCCE	2017-07-04 23:01:00+03	23200.00
BDCCE9	2017-07-10 03:35:00+03	124200.00
BDCD7A	2017-06-28 07:35:00+03	94200.00
BDCD97	2017-07-26 22:28:00+03	25600.00
BDCD99	2017-08-14 09:01:00+03	88500.00
BDCDD3	2017-07-31 04:04:00+03	66000.00
BDCE6B	2017-08-11 03:04:00+03	52900.00
BDCF43	2017-08-04 07:14:00+03	19600.00
BDCF44	2017-07-26 05:06:00+03	135300.00
BDCF66	2017-07-11 08:42:00+03	54800.00
BDCFF5	2017-07-16 13:57:00+03	24200.00
BDD022	2017-08-04 04:48:00+03	68900.00
BDD0D7	2017-07-15 08:10:00+03	109800.00
BDD104	2017-07-28 08:59:00+03	73600.00
BDD139	2017-07-17 04:02:00+03	135600.00
BDD227	2017-07-11 11:12:00+03	13400.00
BDD268	2017-08-09 03:50:00+03	13600.00
BDD39D	2017-07-09 15:16:00+03	6600.00
BDD3A7	2017-08-03 23:13:00+03	6700.00
BDD425	2017-08-06 12:28:00+03	14000.00
BDD47F	2017-07-12 15:45:00+03	27300.00
BDD4CD	2017-07-19 14:31:00+03	26000.00
BDD4DB	2017-08-12 21:09:00+03	26000.00
BDD53E	2017-07-28 14:58:00+03	22600.00
BDD56C	2017-07-27 15:17:00+03	54500.00
BDD599	2017-08-08 01:54:00+03	28000.00
BDD606	2017-07-18 03:37:00+03	18800.00
BDD6EF	2017-07-26 13:24:00+03	46300.00
BDD8CE	2017-07-22 20:07:00+03	136500.00
BDD8EE	2017-07-21 08:50:00+03	34000.00
BDD953	2017-07-18 06:51:00+03	88900.00
BDD98D	2017-08-03 02:26:00+03	38400.00
BDD9B3	2017-07-17 13:29:00+03	31400.00
BDD9BF	2017-08-11 19:16:00+03	28800.00
BDD9D8	2017-07-09 17:29:00+03	14400.00
BDD9EE	2017-07-24 05:02:00+03	8000.00
BDDA05	2017-08-04 05:43:00+03	21400.00
BDDA50	2017-07-25 15:25:00+03	103100.00
BDDA61	2017-07-12 02:19:00+03	47200.00
BDDA71	2017-07-08 02:09:00+03	90100.00
BDDA8A	2017-08-02 09:02:00+03	92800.00
BDDACA	2017-07-29 11:02:00+03	19600.00
BDDB03	2017-08-03 12:01:00+03	86500.00
BDDBC2	2017-08-11 21:04:00+03	87200.00
BDDC22	2017-07-13 00:30:00+03	301800.00
BDDC58	2017-07-15 07:06:00+03	13700.00
BDDC75	2017-07-02 13:49:00+03	73600.00
BDDC8F	2017-07-22 14:33:00+03	62600.00
BDDCB9	2017-07-16 12:56:00+03	12400.00
BDDCF5	2017-08-15 02:58:00+03	229000.00
BDDCF6	2017-07-25 18:26:00+03	54400.00
BDDD5F	2017-07-25 07:11:00+03	81200.00
BDDD91	2017-07-02 19:49:00+03	113000.00
BDDD9C	2017-07-04 07:04:00+03	191800.00
BDDE01	2017-07-28 15:03:00+03	24300.00
BDDE81	2017-07-27 16:44:00+03	46000.00
BDDEA8	2017-08-07 21:25:00+03	39100.00
BDDEF7	2017-08-14 18:39:00+03	95100.00
BDDF0D	2017-08-03 07:48:00+03	85600.00
BDDF20	2017-07-09 11:13:00+03	55800.00
BDDF7F	2017-08-15 06:21:00+03	52200.00
BDE0F8	2017-07-09 05:53:00+03	27900.00
BDE1B6	2017-08-05 01:53:00+03	87000.00
BDE1CC	2017-08-09 05:12:00+03	37000.00
BDE23C	2017-07-30 21:55:00+03	22000.00
BDE2A2	2017-07-08 10:14:00+03	13400.00
BDE2BC	2017-07-12 00:13:00+03	223200.00
BDE2D9	2017-08-06 02:26:00+03	112000.00
BDE301	2017-07-17 05:29:00+03	94900.00
BDE360	2017-07-30 17:44:00+03	204800.00
BDE368	2017-07-04 06:09:00+03	199100.00
BDE3AF	2017-07-07 04:47:00+03	58000.00
BDE3C0	2017-07-31 21:56:00+03	74800.00
BDE3E1	2017-07-05 23:32:00+03	78800.00
BDE4C6	2017-07-10 06:51:00+03	87900.00
BDE549	2017-07-17 06:51:00+03	31900.00
BDE567	2017-08-09 08:54:00+03	65900.00
BDE5F6	2017-08-09 23:37:00+03	15100.00
BDE5FC	2017-08-12 04:41:00+03	17800.00
BDE618	2017-07-02 18:00:00+03	24800.00
BDE649	2017-07-16 18:25:00+03	21500.00
BDE664	2017-08-13 01:33:00+03	82700.00
BDE685	2017-07-21 03:28:00+03	6000.00
BDE763	2017-07-31 02:36:00+03	131100.00
BDE76D	2017-07-27 09:49:00+03	53700.00
BDE7A9	2017-08-15 04:03:00+03	35800.00
BDE7F9	2017-07-29 10:14:00+03	52400.00
BDE841	2017-08-02 17:57:00+03	54200.00
BDE860	2017-07-06 10:01:00+03	24400.00
BDE8E2	2017-08-06 09:21:00+03	23200.00
BDE8E9	2017-07-29 22:06:00+03	123200.00
BDE9E0	2017-08-04 10:05:00+03	16400.00
BDEA00	2017-08-02 02:13:00+03	110000.00
BDEA2C	2017-08-11 08:41:00+03	92400.00
BDEA35	2017-07-24 09:58:00+03	216500.00
BDEA82	2017-07-31 20:21:00+03	175800.00
BDEA9E	2017-07-09 21:00:00+03	70400.00
BDEADF	2017-07-23 00:59:00+03	32700.00
BDEB06	2017-07-03 02:18:00+03	115600.00
BDEB4C	2017-07-15 05:59:00+03	32800.00
BDEB5A	2017-07-31 09:43:00+03	48800.00
BDEBFF	2017-07-26 21:09:00+03	76600.00
BDEC04	2017-07-04 18:18:00+03	86200.00
BDEC23	2017-06-27 09:41:00+03	27200.00
BDEC25	2017-08-13 19:33:00+03	43600.00
BDEC2C	2017-07-25 09:04:00+03	40600.00
BDEC2F	2017-07-27 16:35:00+03	40600.00
BDEC81	2017-07-04 23:55:00+03	49800.00
BDECC8	2017-07-26 00:41:00+03	45600.00
BDECE9	2017-07-27 09:38:00+03	47100.00
BDECFF	2017-07-01 23:36:00+03	64100.00
BDED15	2017-08-04 01:23:00+03	56000.00
BDED4F	2017-07-14 14:38:00+03	169600.00
BDEDAD	2017-08-11 15:41:00+03	15900.00
BDEE07	2017-08-11 13:47:00+03	122000.00
BDEE28	2017-08-07 14:31:00+03	44800.00
BDEE78	2017-08-01 06:32:00+03	52000.00
BDEE8F	2017-07-10 06:01:00+03	115000.00
BDEEC0	2017-08-10 05:24:00+03	94000.00
BDEECB	2017-08-14 01:50:00+03	30200.00
BDEED6	2017-07-24 17:53:00+03	56400.00
BDEF2D	2017-08-09 01:36:00+03	112000.00
BDEFA7	2017-07-25 23:07:00+03	65500.00
BDF009	2017-08-09 04:21:00+03	23200.00
BDF037	2017-07-09 11:40:00+03	135600.00
BDF062	2017-07-12 05:59:00+03	67600.00
BDF0DE	2017-07-01 05:21:00+03	43200.00
BDF0E5	2017-08-12 23:41:00+03	47100.00
BDF0F0	2017-08-10 00:15:00+03	51900.00
BDF150	2017-08-09 23:14:00+03	91200.00
BDF15A	2017-06-23 22:21:00+03	16400.00
BDF191	2017-07-30 19:27:00+03	11600.00
BDF1D1	2017-07-29 20:47:00+03	29800.00
BDF278	2017-07-28 06:09:00+03	32400.00
BDF27D	2017-07-11 11:23:00+03	68400.00
BDF2B5	2017-08-05 20:00:00+03	92000.00
BDF2DF	2017-08-14 19:04:00+03	40800.00
BDF2F1	2017-07-07 21:45:00+03	16400.00
BDF368	2017-07-21 02:24:00+03	40900.00
BDF3C3	2017-07-27 01:25:00+03	415400.00
BDF407	2017-07-27 11:43:00+03	122000.00
BDF4C2	2017-08-12 17:42:00+03	87400.00
BDF5A9	2017-08-11 01:24:00+03	80500.00
BDF600	2017-07-07 03:33:00+03	39200.00
BDF66E	2017-07-10 11:17:00+03	119500.00
BDF673	2017-07-26 14:40:00+03	39500.00
BDF708	2017-08-13 05:15:00+03	63500.00
BDF738	2017-06-27 08:55:00+03	112000.00
BDF75C	2017-07-29 20:08:00+03	28000.00
BDF837	2017-07-30 00:11:00+03	399600.00
BDF838	2017-07-28 14:02:00+03	332200.00
BDF84B	2017-07-14 02:42:00+03	32400.00
BDF89A	2017-07-24 18:27:00+03	6300.00
BDF8A6	2017-07-21 05:47:00+03	102100.00
BDF8E6	2017-07-22 07:37:00+03	19600.00
BDF98C	2017-07-27 10:17:00+03	26000.00
BDF9D6	2017-07-29 09:22:00+03	62100.00
BDF9DB	2017-07-20 07:17:00+03	32800.00
BDF9EC	2017-07-31 19:58:00+03	57200.00
BDFA09	2017-08-13 19:42:00+03	83000.00
BDFA31	2017-08-04 19:14:00+03	29400.00
BDFA4D	2017-07-06 04:10:00+03	29400.00
BDFA77	2017-07-25 03:02:00+03	84500.00
BDFB10	2017-07-10 15:38:00+03	344000.00
BDFB87	2017-08-15 12:37:00+03	113200.00
BDFBD5	2017-08-06 01:47:00+03	30000.00
BDFBE4	2017-07-31 12:43:00+03	42400.00
BDFC08	2017-08-02 00:27:00+03	7800.00
BDFC4D	2017-07-29 22:09:00+03	50900.00
BDFC82	2017-08-14 12:12:00+03	58400.00
BDFCAA	2017-08-10 14:06:00+03	26700.00
BDFCEF	2017-07-22 23:53:00+03	90800.00
BDFD2F	2017-07-27 13:19:00+03	99600.00
BDFD3A	2017-07-04 00:52:00+03	19600.00
BDFD56	2017-07-25 20:54:00+03	135200.00
BDFDCF	2017-08-13 09:27:00+03	89600.00
BDFE4C	2017-07-16 03:43:00+03	378700.00
BDFE65	2017-07-22 15:59:00+03	57200.00
BDFE6B	2017-08-01 21:14:00+03	47500.00
BDFEBD	2017-07-28 11:09:00+03	147100.00
BDFECD	2017-07-26 21:37:00+03	31600.00
BDFEE9	2017-08-02 17:14:00+03	67200.00
BDFF22	2017-07-22 17:54:00+03	57400.00
BDFF7E	2017-07-16 09:53:00+03	23200.00
BDFF9D	2017-08-08 13:40:00+03	62600.00
BDFFE4	2017-07-06 14:49:00+03	28800.00
BDFFF0	2017-07-11 16:08:00+03	137200.00
BE002D	2017-07-27 10:04:00+03	25600.00
BE0034	2017-07-18 04:49:00+03	41400.00
BE00D6	2017-07-03 22:48:00+03	191000.00
BE0103	2017-07-04 08:10:00+03	176600.00
BE0120	2017-08-05 23:40:00+03	97500.00
BE0122	2017-07-11 02:56:00+03	43600.00
BE0132	2017-07-22 07:47:00+03	23900.00
BE0183	2017-07-07 06:47:00+03	70800.00
BE01DB	2017-07-11 11:10:00+03	39400.00
BE01F0	2017-07-21 17:27:00+03	15400.00
BE021C	2017-07-12 21:44:00+03	187800.00
BE0282	2017-07-21 10:08:00+03	66300.00
BE02B8	2017-08-08 06:34:00+03	38800.00
BE02C0	2017-07-24 09:52:00+03	26000.00
BE0325	2017-07-10 00:13:00+03	136200.00
BE032C	2017-08-12 11:35:00+03	136200.00
BE032E	2017-06-29 08:20:00+03	62600.00
BE0366	2017-07-06 13:19:00+03	12400.00
BE036B	2017-08-03 10:23:00+03	39500.00
BE0376	2017-07-22 07:04:00+03	88600.00
BE038A	2017-07-04 02:13:00+03	123000.00
BE039D	2017-07-18 03:16:00+03	123000.00
BE03B9	2017-07-06 04:59:00+03	15400.00
BE03D5	2017-07-05 16:52:00+03	46000.00
BE0434	2017-07-19 02:44:00+03	47400.00
BE0469	2017-07-10 01:44:00+03	79300.00
BE04D2	2017-07-20 17:41:00+03	56100.00
BE04FF	2017-07-10 06:18:00+03	34000.00
BE0513	2017-07-13 04:03:00+03	23200.00
BE055C	2017-08-09 06:49:00+03	18800.00
BE0567	2017-07-20 00:47:00+03	92400.00
BE0581	2017-07-13 19:54:00+03	40800.00
BE058B	2017-07-11 19:53:00+03	231400.00
BE05D3	2017-08-15 13:48:00+03	29800.00
BE05DE	2017-07-17 09:18:00+03	248300.00
BE05E4	2017-08-08 20:27:00+03	36200.00
BE05F4	2017-07-19 23:28:00+03	27300.00
BE0609	2017-07-31 00:34:00+03	14700.00
BE0634	2017-08-14 03:57:00+03	229600.00
BE0770	2017-08-06 00:55:00+03	100000.00
BE07AF	2017-07-23 06:46:00+03	12600.00
BE07F4	2017-08-03 17:23:00+03	31400.00
BE082F	2017-08-06 21:49:00+03	57500.00
BE085D	2017-07-21 06:43:00+03	22600.00
BE0945	2017-07-25 20:20:00+03	20000.00
BE0956	2017-06-29 13:51:00+03	26000.00
BE0963	2017-08-01 14:04:00+03	85700.00
BE0A09	2017-08-10 20:02:00+03	41900.00
BE0A10	2017-08-04 03:46:00+03	15000.00
BE0A35	2017-08-06 19:36:00+03	43200.00
BE0A37	2017-08-12 20:48:00+03	222000.00
BE0A4B	2017-07-01 04:13:00+03	33200.00
BE0A57	2017-07-03 19:44:00+03	6700.00
BE0AB8	2017-08-04 17:31:00+03	6000.00
BE0AE4	2017-07-08 22:40:00+03	101100.00
BE0AFE	2017-07-22 22:00:00+03	271200.00
BE0B02	2017-08-06 06:18:00+03	65500.00
BE0B12	2017-07-31 04:02:00+03	59800.00
BE0B73	2017-07-08 00:48:00+03	46400.00
BE0BAB	2017-08-13 05:11:00+03	68100.00
BE0C9A	2017-07-14 13:12:00+03	92000.00
BE0C9F	2017-07-25 21:41:00+03	172400.00
BE0CCD	2017-07-10 10:10:00+03	120900.00
BE0CDE	2017-07-08 03:26:00+03	38600.00
BE0CE5	2017-07-15 13:44:00+03	75100.00
BE0D08	2017-07-26 05:20:00+03	65600.00
BE0E0F	2017-08-14 16:07:00+03	92100.00
BE0E32	2017-07-15 20:18:00+03	46000.00
BE0E90	2017-08-11 07:32:00+03	55800.00
BE1078	2017-07-05 23:35:00+03	125200.00
BE10C3	2017-07-05 08:51:00+03	59300.00
BE1108	2017-07-01 00:31:00+03	371700.00
BE1136	2017-07-11 04:32:00+03	101400.00
BE1152	2017-07-27 09:33:00+03	40600.00
BE119C	2017-08-01 06:30:00+03	88500.00
BE11DC	2017-07-04 20:56:00+03	46000.00
BE1265	2017-07-07 18:27:00+03	39500.00
BE12EF	2017-07-06 00:22:00+03	70700.00
BE1332	2017-07-26 02:33:00+03	399600.00
BE139D	2017-07-27 14:40:00+03	53600.00
BE1407	2017-07-05 17:25:00+03	80000.00
BE140B	2017-08-03 08:54:00+03	28800.00
BE145B	2017-07-03 23:09:00+03	28000.00
BE14E8	2017-07-02 05:03:00+03	35800.00
BE1508	2017-08-15 10:51:00+03	6800.00
BE1535	2017-07-27 08:42:00+03	80000.00
BE1556	2017-07-26 20:29:00+03	55800.00
BE1586	2017-08-03 09:55:00+03	16400.00
BE15D7	2017-08-08 18:12:00+03	180300.00
BE1654	2017-08-15 02:09:00+03	28200.00
BE16FB	2017-08-09 17:09:00+03	270200.00
BE1720	2017-06-29 23:53:00+03	30000.00
BE1755	2017-07-11 16:37:00+03	265700.00
BE184E	2017-07-06 12:33:00+03	43900.00
BE185E	2017-07-13 18:30:00+03	17800.00
BE1878	2017-07-25 08:56:00+03	47200.00
BE1884	2017-07-19 14:42:00+03	88900.00
BE18BB	2017-07-15 22:12:00+03	109600.00
BE18F1	2017-08-07 02:15:00+03	134800.00
BE1971	2017-07-11 07:18:00+03	211100.00
BE1985	2017-07-25 19:52:00+03	23600.00
BE19D2	2017-08-12 14:20:00+03	55800.00
BE19EC	2017-07-02 10:47:00+03	73600.00
BE1A39	2017-08-06 11:50:00+03	40300.00
BE1A65	2017-07-24 13:31:00+03	96800.00
BE1AA0	2017-07-28 12:10:00+03	6800.00
BE1B30	2017-07-09 07:55:00+03	31600.00
BE1BE4	2017-08-13 19:43:00+03	90800.00
BE1BE6	2017-08-11 22:02:00+03	74600.00
BE1C07	2017-07-16 11:59:00+03	185300.00
BE1C2D	2017-07-22 17:46:00+03	47000.00
BE1C4D	2017-07-29 04:01:00+03	29600.00
BE1C7A	2017-06-28 18:18:00+03	171000.00
BE1CC4	2017-07-01 19:26:00+03	62700.00
BE1CDA	2017-08-15 11:21:00+03	26700.00
BE1CF4	2017-07-19 11:21:00+03	26800.00
BE1D5C	2017-07-31 11:35:00+03	232200.00
BE1D6F	2017-07-22 16:02:00+03	25600.00
BE1D85	2017-07-29 19:53:00+03	38400.00
BE1DA8	2017-07-12 21:08:00+03	77900.00
BE1DAE	2017-07-19 16:13:00+03	28300.00
BE1DAF	2017-07-11 23:13:00+03	86300.00
BE1E12	2017-07-18 18:35:00+03	64300.00
BE1E14	2017-07-30 16:02:00+03	28800.00
BE1E44	2017-08-12 18:05:00+03	40800.00
BE1E5C	2017-08-01 16:32:00+03	369000.00
BE1E95	2017-07-31 15:50:00+03	8000.00
BE1ED9	2017-07-14 13:37:00+03	112000.00
BE1F08	2017-08-05 02:08:00+03	67200.00
BE1F1D	2017-07-14 01:49:00+03	119500.00
BE1F2C	2017-07-01 16:32:00+03	44100.00
BE1F4D	2017-07-29 06:12:00+03	28800.00
BE208A	2017-08-14 10:22:00+03	55800.00
BE20C0	2017-07-24 23:11:00+03	135400.00
BE21B3	2017-08-03 09:57:00+03	28800.00
BE21B7	2017-08-08 20:26:00+03	135600.00
BE220C	2017-08-04 02:35:00+03	29600.00
BE221A	2017-07-24 21:05:00+03	92000.00
BE2235	2017-08-01 20:19:00+03	289800.00
BE226D	2017-07-13 09:42:00+03	123900.00
BE2275	2017-07-25 21:56:00+03	26800.00
BE228A	2017-08-09 10:10:00+03	86500.00
BE2290	2017-08-09 14:24:00+03	8400.00
BE22B1	2017-08-11 10:18:00+03	95600.00
BE22D8	2017-07-05 18:05:00+03	13600.00
BE22DB	2017-07-26 21:45:00+03	66800.00
BE2355	2017-07-05 12:31:00+03	12600.00
BE2356	2017-07-24 04:39:00+03	87200.00
BE2392	2017-08-05 04:38:00+03	136200.00
BE23B7	2017-08-13 22:39:00+03	43400.00
BE23CB	2017-08-07 23:22:00+03	257500.00
BE23E6	2017-07-05 01:29:00+03	6700.00
BE2404	2017-08-09 04:57:00+03	65900.00
BE2440	2017-07-17 08:22:00+03	12400.00
BE245C	2017-07-22 03:49:00+03	48800.00
BE246C	2017-07-29 11:15:00+03	288600.00
BE24C5	2017-07-05 08:47:00+03	67400.00
BE2526	2017-08-11 09:59:00+03	131900.00
BE25AD	2017-07-24 10:00:00+03	26000.00
BE25C2	2017-07-18 20:59:00+03	24300.00
BE260E	2017-07-28 04:52:00+03	22000.00
BE262E	2017-07-04 12:33:00+03	88800.00
BE2634	2017-08-15 16:23:00+03	55800.00
BE26A6	2017-08-10 22:28:00+03	17200.00
BE26BE	2017-07-12 17:56:00+03	68800.00
BE26C8	2017-07-09 17:20:00+03	45200.00
BE26DD	2017-08-03 20:00:00+03	119700.00
BE26EF	2017-08-05 23:45:00+03	67600.00
BE2790	2017-07-30 17:37:00+03	42700.00
BE27B0	2017-08-08 11:15:00+03	54000.00
BE27D9	2017-07-27 18:29:00+03	50000.00
BE282F	2017-07-07 00:10:00+03	59300.00
BE2834	2017-08-14 07:39:00+03	56000.00
BE2840	2017-07-10 18:54:00+03	246000.00
BE2859	2017-07-07 12:12:00+03	81300.00
BE291F	2017-07-19 11:24:00+03	6600.00
BE2939	2017-08-05 01:03:00+03	29600.00
BE295E	2017-07-27 18:15:00+03	54800.00
BE299E	2017-07-12 00:18:00+03	25200.00
BE2A34	2017-08-14 11:22:00+03	89800.00
BE2A35	2017-07-06 23:17:00+03	28000.00
BE2ABE	2017-07-09 20:36:00+03	31700.00
BE2B78	2017-08-12 23:48:00+03	40100.00
BE2B85	2017-08-06 00:43:00+03	46400.00
BE2BBD	2017-07-04 21:32:00+03	12600.00
BE2BBF	2017-07-04 03:25:00+03	21500.00
BE2BD0	2017-08-01 17:32:00+03	200300.00
BE2C4D	2017-08-03 21:44:00+03	223200.00
BE2CC1	2017-08-13 20:36:00+03	25600.00
BE2CCD	2017-07-16 10:03:00+03	26200.00
BE2CEA	2017-07-29 13:28:00+03	27200.00
BE2DBC	2017-07-26 20:08:00+03	30600.00
BE2DCE	2017-08-15 15:06:00+03	53500.00
BE2E32	2017-08-08 20:35:00+03	204500.00
BE2E54	2017-08-02 14:56:00+03	126500.00
BE2E63	2017-07-11 05:48:00+03	319200.00
BE2E69	2017-07-01 18:50:00+03	415600.00
BE2EC0	2017-08-06 16:41:00+03	26800.00
BE2F7A	2017-07-17 23:31:00+03	78300.00
BE2F8C	2017-07-10 12:17:00+03	38600.00
BE2FA1	2017-08-07 04:37:00+03	69900.00
BE3025	2017-08-15 04:38:00+03	32700.00
BE3076	2017-08-01 23:35:00+03	290400.00
BE30E8	2017-07-17 20:05:00+03	25400.00
BE30F0	2017-07-21 13:51:00+03	14000.00
BE30F7	2017-07-11 19:43:00+03	13400.00
BE3120	2017-08-01 18:06:00+03	29600.00
BE3123	2017-08-03 00:22:00+03	96400.00
BE312E	2017-07-15 14:13:00+03	131600.00
BE3141	2017-07-21 13:46:00+03	42000.00
BE3256	2017-07-11 17:06:00+03	62000.00
BE32E7	2017-07-29 11:04:00+03	43000.00
BE3319	2017-08-13 11:39:00+03	89700.00
BE3326	2017-07-26 20:59:00+03	22600.00
BE3330	2017-07-12 22:42:00+03	38200.00
BE3351	2017-08-11 13:37:00+03	106000.00
BE3422	2017-08-01 04:16:00+03	23600.00
BE344B	2017-07-31 16:00:00+03	13600.00
BE3459	2017-08-02 16:58:00+03	89000.00
BE3467	2017-08-06 14:10:00+03	44800.00
BE349D	2017-06-27 10:57:00+03	61800.00
BE3506	2017-08-12 02:52:00+03	39800.00
BE351D	2017-07-08 11:11:00+03	46800.00
BE354B	2017-07-03 17:43:00+03	57800.00
BE354F	2017-08-04 04:05:00+03	39300.00
BE3591	2017-07-27 06:18:00+03	189800.00
BE35BA	2017-07-25 17:41:00+03	59300.00
BE35F8	2017-07-04 16:26:00+03	59800.00
BE3673	2017-07-30 21:39:00+03	44700.00
BE3691	2017-08-02 18:46:00+03	28000.00
BE36E2	2017-07-13 03:19:00+03	52300.00
BE377F	2017-08-14 11:18:00+03	40000.00
BE3788	2017-07-27 00:38:00+03	30200.00
BE37B7	2017-08-10 14:21:00+03	6700.00
BE3802	2017-08-12 04:32:00+03	35600.00
BE382A	2017-08-06 01:04:00+03	83600.00
BE38DC	2017-07-28 21:56:00+03	81700.00
BE38F4	2017-07-05 15:20:00+03	60600.00
BE39E8	2017-07-16 07:47:00+03	265600.00
BE39F5	2017-07-17 02:25:00+03	119500.00
BE3A1B	2017-07-01 19:48:00+03	34000.00
BE3A24	2017-08-06 05:05:00+03	15800.00
BE3A6D	2017-08-15 12:33:00+03	52700.00
BE3A90	2017-07-07 16:37:00+03	135600.00
BE3AA6	2017-06-27 05:49:00+03	38200.00
BE3AAC	2017-07-22 23:08:00+03	80000.00
BE3B0C	2017-07-13 22:16:00+03	47100.00
BE3B0D	2017-07-13 23:45:00+03	156300.00
BE3B23	2017-07-29 10:17:00+03	55800.00
BE3B5A	2017-08-15 14:10:00+03	83000.00
BE3B5B	2017-07-28 22:32:00+03	136500.00
BE3B9E	2017-07-29 07:44:00+03	64700.00
BE3BF3	2017-07-08 04:27:00+03	13400.00
BE3BFF	2017-07-07 15:40:00+03	119500.00
BE3C03	2017-07-01 04:13:00+03	56900.00
BE3C4D	2017-08-07 01:43:00+03	38600.00
BE3C68	2017-08-10 17:30:00+03	58400.00
BE3C81	2017-07-22 15:36:00+03	123000.00
BE3C88	2017-07-21 03:17:00+03	26000.00
BE3C9A	2017-08-07 13:49:00+03	28000.00
BE3CDD	2017-07-02 15:23:00+03	56000.00
BE3CF1	2017-07-20 22:24:00+03	18500.00
BE3D1E	2017-08-08 01:55:00+03	57500.00
BE3D24	2017-07-23 12:18:00+03	133200.00
BE3DC5	2017-07-18 05:50:00+03	14800.00
BE3DFA	2017-07-12 14:42:00+03	69900.00
BE3E14	2017-07-16 02:38:00+03	55800.00
BE3EDC	2017-08-01 06:03:00+03	34000.00
BE3F21	2017-07-18 09:14:00+03	56000.00
BE3F24	2017-07-11 12:23:00+03	47000.00
BE3F54	2017-06-29 08:34:00+03	20000.00
BE3F66	2017-08-14 05:45:00+03	97400.00
BE3FAB	2017-08-14 01:08:00+03	23200.00
BE4034	2017-07-10 15:32:00+03	58000.00
BE40E7	2017-07-11 17:14:00+03	229000.00
BE40F1	2017-07-12 00:47:00+03	49100.00
BE4150	2017-08-05 10:38:00+03	8400.00
BE416B	2017-07-14 20:43:00+03	42800.00
BE419A	2017-07-04 18:31:00+03	156000.00
BE4249	2017-07-31 03:04:00+03	75300.00
BE42C5	2017-07-22 00:30:00+03	283100.00
BE42FE	2017-06-30 17:56:00+03	8000.00
BE43AE	2017-06-29 07:23:00+03	46400.00
BE4441	2017-07-08 17:49:00+03	143200.00
BE4482	2017-07-20 16:38:00+03	56000.00
BE448F	2017-07-03 16:53:00+03	185600.00
BE4511	2017-07-06 16:25:00+03	147100.00
BE45AC	2017-07-04 21:00:00+03	76800.00
BE468C	2017-07-23 19:18:00+03	25600.00
BE46A3	2017-07-18 02:21:00+03	82900.00
BE46FB	2017-08-11 10:05:00+03	59000.00
BE4705	2017-07-30 13:07:00+03	14000.00
BE4814	2017-07-14 17:35:00+03	62700.00
BE4899	2017-07-08 16:54:00+03	128800.00
BE489A	2017-07-05 04:38:00+03	28800.00
BE48A9	2017-07-26 18:26:00+03	26000.00
BE48AE	2017-07-10 15:52:00+03	28800.00
BE4903	2017-08-09 10:48:00+03	75600.00
BE4957	2017-07-15 15:28:00+03	48800.00
BE499C	2017-07-04 06:18:00+03	6700.00
BE49AD	2017-07-22 19:19:00+03	31400.00
BE49E7	2017-08-08 19:38:00+03	40800.00
BE49E8	2017-08-12 18:13:00+03	8200.00
BE4ABE	2017-08-04 05:10:00+03	128800.00
BE4AFE	2017-08-11 23:33:00+03	62900.00
BE4B09	2017-07-07 18:36:00+03	31800.00
BE4B3F	2017-07-03 21:21:00+03	10800.00
BE4B7D	2017-07-11 01:22:00+03	43600.00
BE4BCE	2017-08-12 01:16:00+03	36200.00
BE4C4A	2017-07-20 18:24:00+03	32700.00
BE4CE9	2017-07-26 15:57:00+03	19600.00
BE4D7B	2017-08-13 20:54:00+03	169900.00
BE4D81	2017-07-03 09:00:00+03	169000.00
BE4E33	2017-07-27 11:13:00+03	68000.00
BE4E64	2017-08-10 04:57:00+03	152800.00
BE4E99	2017-07-16 01:35:00+03	14400.00
BE4EC5	2017-07-10 16:06:00+03	18300.00
BE4EF7	2017-07-18 22:07:00+03	42800.00
BE4F14	2017-07-26 15:40:00+03	55800.00
BE4F99	2017-07-12 03:46:00+03	41400.00
BE5015	2017-08-13 10:03:00+03	6600.00
BE5032	2017-08-05 10:51:00+03	12600.00
BE50E6	2017-07-02 06:13:00+03	75300.00
BE50F1	2017-07-30 13:45:00+03	62800.00
BE512D	2017-08-10 16:53:00+03	277000.00
BE5133	2017-07-26 12:09:00+03	92000.00
BE5147	2017-08-05 11:31:00+03	23400.00
BE5164	2017-08-04 08:13:00+03	68800.00
BE5167	2017-08-10 04:33:00+03	39300.00
BE51D1	2017-07-22 21:47:00+03	70800.00
BE521E	2017-07-03 21:06:00+03	127300.00
BE5235	2017-07-08 20:48:00+03	36000.00
BE52B0	2017-08-02 23:00:00+03	99300.00
BE5338	2017-07-30 13:42:00+03	46900.00
BE5346	2017-07-28 09:33:00+03	532800.00
BE534A	2017-07-22 03:56:00+03	55600.00
BE534F	2017-08-01 07:35:00+03	167400.00
BE5368	2017-07-06 09:39:00+03	59800.00
BE5380	2017-07-16 20:32:00+03	179400.00
BE5392	2017-07-13 12:24:00+03	65500.00
BE5397	2017-07-12 20:21:00+03	52000.00
BE53A0	2017-07-16 19:36:00+03	135200.00
BE53D1	2017-07-24 22:06:00+03	24400.00
BE53F3	2017-07-09 10:51:00+03	6000.00
BE5419	2017-08-12 19:38:00+03	102100.00
BE5439	2017-07-10 04:14:00+03	113300.00
BE547F	2017-07-16 21:16:00+03	34200.00
BE5501	2017-08-14 23:33:00+03	122700.00
BE55DB	2017-07-17 00:21:00+03	58200.00
BE566D	2017-07-21 16:27:00+03	88100.00
BE568D	2017-08-13 13:39:00+03	112600.00
BE569B	2017-08-01 07:01:00+03	81500.00
BE577E	2017-07-15 15:30:00+03	44400.00
BE577F	2017-07-16 20:14:00+03	58700.00
BE580B	2017-07-26 16:01:00+03	11600.00
BE5820	2017-07-07 18:24:00+03	48800.00
BE5884	2017-07-16 04:13:00+03	103800.00
BE592C	2017-07-08 18:15:00+03	46800.00
BE594D	2017-08-05 11:18:00+03	405200.00
BE59D2	2017-07-17 07:12:00+03	266400.00
BE5A4C	2017-07-27 07:59:00+03	147700.00
BE5A74	2017-07-09 23:34:00+03	36200.00
BE5A75	2017-07-08 20:38:00+03	277600.00
BE5B38	2017-07-04 13:05:00+03	111700.00
BE5B39	2017-07-31 05:47:00+03	40600.00
BE5B52	2017-07-29 22:25:00+03	44000.00
BE5B7B	2017-06-27 09:33:00+03	36800.00
BE5B84	2017-07-25 18:23:00+03	12600.00
BE5BED	2017-07-17 02:06:00+03	52000.00
BE5BF5	2017-08-03 02:18:00+03	59200.00
BE5C85	2017-07-20 10:34:00+03	38800.00
BE5C8B	2017-07-05 13:08:00+03	62000.00
BE5C8C	2017-08-11 16:44:00+03	134200.00
BE5CC3	2017-07-30 17:51:00+03	57600.00
BE5D56	2017-07-17 16:11:00+03	16400.00
BE5DCA	2017-07-19 06:36:00+03	26000.00
BE5DD0	2017-08-14 16:24:00+03	14000.00
BE5E19	2017-07-14 16:28:00+03	56600.00
BE5E5A	2017-07-18 16:23:00+03	198300.00
BE5E7D	2017-08-05 17:20:00+03	24400.00
BE5EC1	2017-08-07 21:53:00+03	54800.00
BE5EEA	2017-07-31 15:10:00+03	62900.00
BE5F23	2017-07-11 18:16:00+03	31000.00
BE5F71	2017-07-13 20:29:00+03	46900.00
BE5FCE	2017-07-15 09:00:00+03	404100.00
BE5FD3	2017-07-20 10:17:00+03	29400.00
BE600D	2017-08-05 22:15:00+03	31200.00
BE6045	2017-07-22 13:50:00+03	112000.00
BE607E	2017-07-09 23:08:00+03	132800.00
BE60CD	2017-07-27 19:16:00+03	46700.00
BE60FD	2017-07-21 00:28:00+03	6000.00
BE6105	2017-07-19 03:10:00+03	143200.00
BE6159	2017-07-14 21:58:00+03	46300.00
BE6166	2017-07-16 11:14:00+03	48800.00
BE6196	2017-07-27 08:24:00+03	92800.00
BE6199	2017-07-08 07:29:00+03	24400.00
BE628F	2017-08-10 20:04:00+03	16400.00
BE62D4	2017-08-12 12:03:00+03	14000.00
BE6363	2017-08-09 18:13:00+03	6800.00
BE64C8	2017-08-13 21:28:00+03	255000.00
BE655C	2017-08-09 18:53:00+03	28000.00
BE6589	2017-08-07 08:19:00+03	67200.00
BE65E2	2017-07-31 00:33:00+03	21800.00
BE6612	2017-07-30 19:44:00+03	36200.00
BE662B	2017-08-02 07:21:00+03	29200.00
BE668E	2017-07-09 07:00:00+03	34000.00
BE66FC	2017-07-31 16:13:00+03	406700.00
BE6774	2017-07-26 02:02:00+03	36200.00
BE6806	2017-08-12 19:49:00+03	13400.00
BE6825	2017-07-12 05:51:00+03	122800.00
BE6829	2017-07-29 02:47:00+03	33600.00
BE6834	2017-07-29 17:24:00+03	106400.00
BE6838	2017-08-07 13:27:00+03	56200.00
BE6849	2017-07-12 10:28:00+03	67700.00
BE6872	2017-07-27 07:31:00+03	24300.00
BE6956	2017-07-10 02:23:00+03	47000.00
BE6963	2017-07-24 05:05:00+03	30700.00
BE6989	2017-08-10 22:36:00+03	22000.00
BE69B5	2017-07-18 21:30:00+03	24400.00
BE69D3	2017-08-09 08:15:00+03	40800.00
BE69D6	2017-08-03 11:55:00+03	273000.00
BE69F5	2017-07-26 03:22:00+03	38400.00
BE6A06	2017-07-12 17:13:00+03	124000.00
BE6A27	2017-07-29 03:32:00+03	44000.00
BE6AF9	2017-08-03 08:22:00+03	285000.00
BE6B13	2017-08-09 14:34:00+03	24400.00
BE6BA0	2017-07-15 22:38:00+03	109900.00
BE6BC9	2017-07-24 17:28:00+03	40000.00
BE6C13	2017-07-23 08:09:00+03	45400.00
BE6C50	2017-07-12 06:28:00+03	77200.00
BE6CC0	2017-07-07 18:52:00+03	56600.00
BE6CDC	2017-08-09 17:51:00+03	84100.00
BE6CF1	2017-08-07 18:36:00+03	136200.00
BE6CFB	2017-08-03 07:41:00+03	36200.00
BE6D0F	2017-07-28 22:59:00+03	57500.00
BE6D47	2017-07-20 02:19:00+03	40000.00
BE6D66	2017-07-26 06:24:00+03	47100.00
BE6D6F	2017-07-14 11:35:00+03	32700.00
BE6D7A	2017-07-21 02:59:00+03	65600.00
BE6D9F	2017-08-15 09:18:00+03	103500.00
BE6DBB	2017-07-11 09:15:00+03	103400.00
BE6DC8	2017-06-30 07:51:00+03	179400.00
BE6DEF	2017-07-19 11:45:00+03	81700.00
BE6DF9	2017-08-06 12:50:00+03	57400.00
BE6E46	2017-07-19 18:59:00+03	86400.00
BE6E60	2017-07-29 04:42:00+03	96800.00
BE6E92	2017-07-21 19:47:00+03	46200.00
BE6E9B	2017-07-18 14:48:00+03	92000.00
BE6E9F	2017-08-09 08:53:00+03	42600.00
BE6EA0	2017-07-14 23:04:00+03	56000.00
BE6EF6	2017-07-20 13:49:00+03	75600.00
BE6FF0	2017-07-06 06:57:00+03	44500.00
BE7086	2017-08-11 02:27:00+03	187600.00
BE70F7	2017-07-28 15:18:00+03	90800.00
BE70FA	2017-08-15 14:21:00+03	12000.00
BE71F1	2017-07-12 11:36:00+03	28000.00
BE7217	2017-08-01 14:30:00+03	35200.00
BE721C	2017-07-30 22:42:00+03	16400.00
BE7258	2017-08-07 21:27:00+03	36000.00
BE7278	2017-08-06 08:22:00+03	31400.00
BE72A0	2017-08-04 02:58:00+03	43400.00
BE72A9	2017-07-22 18:15:00+03	90800.00
BE72DE	2017-08-15 08:03:00+03	18400.00
BE7332	2017-07-23 00:50:00+03	44700.00
BE7363	2017-07-09 21:03:00+03	28000.00
BE73B0	2017-07-22 11:24:00+03	111600.00
BE742B	2017-08-13 10:50:00+03	40800.00
BE742D	2017-07-25 14:23:00+03	97600.00
BE748E	2017-07-30 05:33:00+03	25800.00
BE74C6	2017-07-26 14:56:00+03	23100.00
BE74DF	2017-08-08 21:10:00+03	254900.00
BE75E7	2017-07-22 09:56:00+03	105100.00
BE75F3	2017-07-30 18:07:00+03	129700.00
BE7645	2017-08-11 18:57:00+03	30200.00
BE76E6	2017-07-29 21:50:00+03	26700.00
BE7733	2017-07-20 04:33:00+03	59000.00
BE776D	2017-07-26 18:31:00+03	177200.00
BE77C7	2017-07-23 22:27:00+03	83000.00
BE77DC	2017-08-09 15:46:00+03	34600.00
BE7821	2017-07-07 16:53:00+03	84100.00
BE7867	2017-07-19 09:26:00+03	56000.00
BE7897	2017-07-24 15:52:00+03	14400.00
BE79B4	2017-08-13 09:26:00+03	12400.00
BE79D2	2017-07-23 14:58:00+03	146100.00
BE79E5	2017-08-08 02:06:00+03	100600.00
BE79F1	2017-08-10 22:14:00+03	26000.00
BE7A56	2017-08-08 00:26:00+03	76800.00
BE7AB9	2017-08-14 03:28:00+03	59100.00
BE7ABE	2017-07-03 14:35:00+03	406000.00
BE7B8A	2017-07-11 04:30:00+03	49100.00
BE7C42	2017-07-22 17:52:00+03	140500.00
BE7D03	2017-07-23 00:11:00+03	21600.00
BE7D5C	2017-07-19 06:07:00+03	179300.00
BE7D99	2017-07-15 09:30:00+03	25600.00
BE7DA6	2017-08-04 16:56:00+03	28000.00
BE7DAB	2017-07-05 20:36:00+03	81300.00
BE7DCC	2017-07-07 12:12:00+03	86800.00
BE7DCF	2017-08-03 08:14:00+03	142400.00
BE7E13	2017-08-07 08:13:00+03	40600.00
BE7E36	2017-08-10 10:07:00+03	265700.00
BE7E55	2017-08-05 11:18:00+03	69500.00
BE7E6E	2017-07-15 03:00:00+03	47000.00
BE7EEC	2017-08-06 17:17:00+03	81600.00
BE7F03	2017-07-07 10:13:00+03	52300.00
BE7F5D	2017-07-21 23:44:00+03	21400.00
BE7F95	2017-07-12 04:17:00+03	78800.00
BE7FB6	2017-07-15 21:34:00+03	48800.00
BE8024	2017-08-12 01:27:00+03	54000.00
BE80D5	2017-08-13 12:16:00+03	28800.00
BE8281	2017-07-27 16:40:00+03	95000.00
BE832A	2017-07-19 15:01:00+03	67600.00
BE8370	2017-07-14 15:14:00+03	34000.00
BE838F	2017-08-12 17:43:00+03	164800.00
BE8478	2017-08-11 20:50:00+03	28200.00
BE8491	2017-07-02 07:17:00+03	111600.00
BE84B3	2017-07-06 01:48:00+03	42000.00
BE84D4	2017-07-24 07:47:00+03	14800.00
BE850B	2017-07-21 22:45:00+03	43400.00
BE8516	2017-08-11 08:59:00+03	29400.00
BE8530	2017-07-16 12:48:00+03	90800.00
BE853D	2017-08-09 11:52:00+03	38400.00
BE8599	2017-07-20 07:03:00+03	51300.00
BE85AB	2017-07-10 02:48:00+03	7400.00
BE85F5	2017-08-03 16:36:00+03	303100.00
BE85FA	2017-07-23 19:32:00+03	23200.00
BE861B	2017-07-11 01:35:00+03	64500.00
BE8625	2017-07-24 14:30:00+03	45500.00
BE862B	2017-08-04 10:05:00+03	14000.00
BE867E	2017-07-22 11:59:00+03	68900.00
BE86B4	2017-08-03 19:18:00+03	33800.00
BE86D7	2017-07-28 01:56:00+03	40800.00
BE8709	2017-07-16 20:38:00+03	40600.00
BE8772	2017-07-08 15:29:00+03	47600.00
BE8844	2017-07-10 13:54:00+03	381400.00
BE88E2	2017-07-31 14:11:00+03	96800.00
BE8927	2017-07-17 17:22:00+03	92900.00
BE89DE	2017-07-07 17:46:00+03	23400.00
BE89EA	2017-07-25 05:18:00+03	393800.00
BE8A2E	2017-07-20 13:36:00+03	39500.00
BE8AC4	2017-07-19 19:43:00+03	137100.00
BE8AEA	2017-07-24 03:05:00+03	26800.00
BE8B28	2017-07-31 01:11:00+03	6800.00
BE8B56	2017-07-30 07:43:00+03	77900.00
BE8B6B	2017-08-01 23:34:00+03	62600.00
BE8BCF	2017-07-06 04:04:00+03	21800.00
BE8BE2	2017-07-27 07:58:00+03	47500.00
BE8BFA	2017-07-02 10:22:00+03	28000.00
BE8C42	2017-07-07 00:53:00+03	246000.00
BE8C4C	2017-08-05 03:58:00+03	24800.00
BE8C62	2017-08-04 02:35:00+03	6000.00
BE8C82	2017-08-03 08:29:00+03	20000.00
BE8CA4	2017-08-05 05:13:00+03	24000.00
BE8CBB	2017-08-03 01:50:00+03	54800.00
BE8CC6	2017-07-06 00:53:00+03	87000.00
BE8CD2	2017-08-02 22:17:00+03	28000.00
BE8D21	2017-08-15 09:05:00+03	193600.00
BE8D89	2017-07-04 05:40:00+03	76800.00
BE8DCE	2017-07-31 12:26:00+03	19600.00
BE8E96	2017-08-02 07:41:00+03	59300.00
BE8EAB	2017-08-02 13:31:00+03	24800.00
BE8EC3	2017-07-20 13:51:00+03	46000.00
BE8ED8	2017-07-18 17:32:00+03	73600.00
BE8F2D	2017-08-14 13:49:00+03	116400.00
BE8F4B	2017-08-04 15:58:00+03	26000.00
BE8F66	2017-08-13 14:53:00+03	65400.00
BE8F69	2017-07-19 03:29:00+03	31100.00
BE9004	2017-07-28 15:15:00+03	20400.00
BE9069	2017-07-10 05:53:00+03	24400.00
BE90D4	2017-07-22 11:36:00+03	43200.00
BE90D8	2017-07-24 03:35:00+03	47000.00
BE90FE	2017-08-03 02:32:00+03	153300.00
BE910F	2017-08-07 22:45:00+03	63700.00
BE9116	2017-08-03 07:04:00+03	86500.00
BE917F	2017-07-18 12:24:00+03	28000.00
BE91BA	2017-07-06 10:35:00+03	118000.00
BE91F2	2017-07-13 00:08:00+03	187800.00
BE9282	2017-07-15 05:52:00+03	44600.00
BE92A7	2017-06-30 08:32:00+03	185700.00
BE92C1	2017-07-23 15:16:00+03	32800.00
BE930A	2017-07-06 15:50:00+03	28000.00
BE9332	2017-07-05 12:11:00+03	88600.00
BE940C	2017-07-07 19:26:00+03	55800.00
BE9453	2017-07-06 21:54:00+03	56900.00
BE94CF	2017-07-11 22:17:00+03	30200.00
BE953C	2017-07-12 18:40:00+03	258400.00
BE9555	2017-08-02 14:44:00+03	32400.00
BE95A1	2017-08-07 03:04:00+03	112400.00
BE95C8	2017-07-09 13:30:00+03	56000.00
BE95F4	2017-07-29 14:03:00+03	13400.00
BE95F7	2017-07-16 14:29:00+03	50000.00
BE9631	2017-07-28 22:01:00+03	130000.00
BE9644	2017-08-13 01:16:00+03	25100.00
BE9675	2017-08-08 17:20:00+03	75600.00
BE96B8	2017-07-14 08:16:00+03	21400.00
BE9733	2017-07-08 01:06:00+03	141300.00
BE9735	2017-07-17 02:27:00+03	372600.00
BE973E	2017-07-08 09:17:00+03	52800.00
BE9744	2017-07-02 01:53:00+03	135400.00
BE97E5	2017-08-14 19:38:00+03	46400.00
BE9891	2017-07-14 01:43:00+03	25100.00
BE98DA	2017-07-25 01:59:00+03	42800.00
BE98F9	2017-07-05 17:40:00+03	266400.00
BE992B	2017-08-08 02:30:00+03	52000.00
BE995D	2017-07-27 04:32:00+03	30000.00
BE9983	2017-06-28 11:05:00+03	23400.00
BE99AF	2017-08-06 08:14:00+03	67400.00
BE9A1D	2017-07-29 08:36:00+03	265800.00
BE9A3F	2017-07-22 17:56:00+03	101600.00
BE9A97	2017-07-22 15:24:00+03	64600.00
BE9BC3	2017-07-15 13:34:00+03	98400.00
BE9C2E	2017-07-11 19:52:00+03	102100.00
BE9C9A	2017-06-29 17:06:00+03	13700.00
BE9CB2	2017-07-19 13:45:00+03	64800.00
BE9D6D	2017-07-19 17:51:00+03	21800.00
BE9D89	2017-08-08 23:08:00+03	64500.00
BE9DDA	2017-07-27 17:00:00+03	48800.00
BE9E49	2017-08-02 19:05:00+03	46500.00
BE9E7B	2017-08-12 08:51:00+03	133100.00
BE9F0A	2017-07-18 23:11:00+03	290500.00
BE9F0E	2017-07-02 15:52:00+03	23400.00
BE9F2F	2017-07-25 21:16:00+03	64800.00
BE9F8E	2017-07-25 15:19:00+03	114800.00
BE9F9C	2017-07-04 22:59:00+03	88500.00
BE9FDE	2017-08-10 19:31:00+03	39300.00
BEA00C	2017-07-24 00:24:00+03	62000.00
BEA00D	2017-08-15 00:54:00+03	101200.00
BEA027	2017-08-13 11:49:00+03	14400.00
BEA061	2017-08-15 05:17:00+03	32700.00
BEA064	2017-08-08 10:24:00+03	63600.00
BEA073	2017-08-03 00:32:00+03	48200.00
BEA07C	2017-07-01 09:17:00+03	95200.00
BEA082	2017-06-29 04:49:00+03	135200.00
BEA09D	2017-07-05 10:05:00+03	64500.00
BEA0DE	2017-07-08 13:23:00+03	59200.00
BEA104	2017-07-21 07:46:00+03	26000.00
BEA181	2017-07-30 07:38:00+03	111600.00
BEA1EB	2017-08-15 03:05:00+03	100500.00
BEA21C	2017-08-02 23:03:00+03	56600.00
BEA275	2017-08-11 23:01:00+03	199200.00
BEA297	2017-08-04 07:26:00+03	66000.00
BEA2FC	2017-07-12 09:28:00+03	106600.00
BEA302	2017-07-28 22:56:00+03	8200.00
BEA456	2017-08-08 20:49:00+03	26000.00
BEA487	2017-07-15 01:16:00+03	123000.00
BEA4AB	2017-07-10 06:12:00+03	492200.00
BEA4C5	2017-07-31 17:18:00+03	6000.00
BEA4ED	2017-07-20 18:38:00+03	43800.00
BEA4FF	2017-08-06 09:54:00+03	33300.00
BEA5B5	2017-07-05 17:56:00+03	151800.00
BEA5BB	2017-07-29 05:34:00+03	54800.00
BEA5F0	2017-07-02 13:16:00+03	33300.00
BEA628	2017-07-21 14:35:00+03	47200.00
BEA62A	2017-07-08 13:56:00+03	45000.00
BEA664	2017-08-12 13:07:00+03	24400.00
BEA669	2017-07-21 01:25:00+03	47500.00
BEA686	2017-07-05 00:17:00+03	12000.00
BEA6EA	2017-08-10 21:38:00+03	31200.00
BEA6FD	2017-07-05 16:11:00+03	31400.00
BEA714	2017-08-10 20:11:00+03	131100.00
BEA766	2017-08-02 01:35:00+03	283000.00
BEA7A2	2017-07-30 02:09:00+03	23200.00
BEA802	2017-07-16 07:41:00+03	76600.00
BEA80C	2017-07-13 04:09:00+03	12600.00
BEA8BD	2017-07-21 07:47:00+03	46000.00
BEA8F9	2017-07-24 17:43:00+03	90000.00
BEA92D	2017-07-02 21:32:00+03	42700.00
BEA976	2017-07-29 12:38:00+03	12000.00
BEA98A	2017-07-02 04:25:00+03	35200.00
BEA9C6	2017-08-06 13:43:00+03	132800.00
BEA9DE	2017-07-17 06:40:00+03	84100.00
BEAA0F	2017-08-07 07:04:00+03	31600.00
BEAA1B	2017-07-03 08:21:00+03	33600.00
BEAA38	2017-06-29 08:47:00+03	112200.00
BEAA3D	2017-07-21 01:26:00+03	10700.00
BEAAD4	2017-08-02 04:31:00+03	55800.00
BEAAFA	2017-07-07 09:55:00+03	136500.00
BEAB2B	2017-08-01 08:24:00+03	160200.00
BEAB4F	2017-08-08 09:22:00+03	28800.00
BEABD1	2017-07-15 12:52:00+03	48500.00
BEABD2	2017-08-15 04:28:00+03	11800.00
BEABE0	2017-07-21 05:12:00+03	25000.00
BEAC5E	2017-08-09 21:13:00+03	23200.00
BEAC69	2017-08-06 19:14:00+03	120800.00
BEAC84	2017-07-18 09:15:00+03	123000.00
BEAD3F	2017-08-08 07:31:00+03	71200.00
BEAD55	2017-08-11 15:33:00+03	67600.00
BEAD62	2017-07-29 07:25:00+03	31600.00
BEAD8F	2017-07-09 07:20:00+03	56600.00
BEADAB	2017-07-10 07:01:00+03	46000.00
BEADE4	2017-07-09 03:56:00+03	28000.00
BEADF4	2017-07-25 13:18:00+03	30200.00
BEAE84	2017-07-27 23:05:00+03	246000.00
BEAEFF	2017-07-11 10:23:00+03	75600.00
BEAF0B	2017-07-10 00:12:00+03	20500.00
BEAF81	2017-08-13 09:48:00+03	13400.00
BEAFF7	2017-06-29 09:50:00+03	29600.00
BEB020	2017-07-08 10:05:00+03	22600.00
BEB024	2017-07-27 16:50:00+03	23600.00
BEB0A3	2017-08-07 09:34:00+03	24400.00
BEB0DC	2017-06-28 10:02:00+03	55800.00
BEB0ED	2017-06-29 23:43:00+03	56900.00
BEB103	2017-08-14 06:19:00+03	78200.00
BEB1A6	2017-07-18 06:36:00+03	56000.00
BEB1DF	2017-08-08 15:40:00+03	70700.00
BEB20F	2017-07-16 07:01:00+03	47400.00
BEB23F	2017-07-30 17:51:00+03	37900.00
BEB240	2017-07-07 22:30:00+03	14000.00
BEB249	2017-08-03 21:07:00+03	48800.00
BEB281	2017-07-27 10:52:00+03	135400.00
BEB2CF	2017-07-01 05:18:00+03	17800.00
BEB320	2017-07-04 00:31:00+03	119700.00
BEB34E	2017-08-11 13:48:00+03	80000.00
BEB38F	2017-08-08 06:53:00+03	81700.00
BEB550	2017-08-02 18:12:00+03	210000.00
BEB560	2017-08-15 17:44:00+03	67200.00
BEB60D	2017-07-31 17:37:00+03	79600.00
BEB613	2017-07-12 06:54:00+03	75600.00
BEB674	2017-08-03 12:15:00+03	313400.00
BEB681	2017-07-21 16:01:00+03	46900.00
BEB6A8	2017-07-24 14:39:00+03	40800.00
BEB6A9	2017-07-04 00:59:00+03	54600.00
BEB6C6	2017-08-10 05:55:00+03	90600.00
BEB753	2017-08-11 02:52:00+03	13400.00
BEB75C	2017-07-19 03:26:00+03	53700.00
BEB780	2017-07-30 08:54:00+03	174500.00
BEB7C1	2017-08-07 11:42:00+03	32700.00
BEB877	2017-08-10 05:14:00+03	92800.00
BEB881	2017-07-20 21:55:00+03	199700.00
BEB885	2017-07-29 13:12:00+03	118300.00
BEB8DE	2017-07-15 15:41:00+03	81200.00
BEB993	2017-07-22 16:50:00+03	44500.00
BEB9FC	2017-08-13 13:39:00+03	29600.00
BEBA48	2017-07-12 17:00:00+03	27200.00
BEBAE7	2017-07-14 14:52:00+03	258400.00
BEBB04	2017-08-15 01:16:00+03	70700.00
BEBB25	2017-07-20 08:16:00+03	23600.00
BEBB93	2017-08-14 11:35:00+03	35200.00
BEBBA2	2017-07-05 20:56:00+03	13400.00
BEBBAA	2017-07-15 22:31:00+03	393800.00
BEBBF3	2017-07-20 17:15:00+03	70200.00
BEBC0A	2017-07-16 03:48:00+03	98800.00
BEBC33	2017-07-19 23:33:00+03	87200.00
BEBC4F	2017-07-03 17:32:00+03	12600.00
BEBCA6	2017-07-01 14:11:00+03	98400.00
BEBCA9	2017-07-20 18:07:00+03	55800.00
BEBD38	2017-07-22 00:31:00+03	284600.00
BEBD78	2017-06-29 16:43:00+03	62000.00
BEBD92	2017-07-30 23:08:00+03	24700.00
BEBD98	2017-07-23 19:19:00+03	25400.00
BEBDBA	2017-07-06 07:56:00+03	15200.00
BEBDBE	2017-06-27 15:43:00+03	68800.00
BEBDDB	2017-08-09 05:01:00+03	136200.00
BEBDE1	2017-07-19 12:23:00+03	64700.00
BEBE0F	2017-08-15 03:53:00+03	131100.00
BEBE6E	2017-08-14 19:33:00+03	21700.00
BEBF39	2017-08-11 18:44:00+03	29600.00
BEBF69	2017-08-08 00:07:00+03	86600.00
BEBF92	2017-07-14 22:11:00+03	62600.00
BEBFA8	2017-07-30 05:53:00+03	249500.00
BEC031	2017-07-22 12:27:00+03	47000.00
BEC066	2017-07-11 16:53:00+03	86400.00
BEC0E2	2017-07-23 15:42:00+03	31600.00
BEC118	2017-07-13 12:07:00+03	288600.00
BEC14E	2017-08-07 12:01:00+03	108200.00
BEC168	2017-07-16 11:56:00+03	111600.00
BEC1B6	2017-08-15 02:26:00+03	41300.00
BEC1D6	2017-08-10 08:59:00+03	23200.00
BEC222	2017-08-02 20:16:00+03	58200.00
BEC25E	2017-07-21 16:12:00+03	13600.00
BEC273	2017-07-19 02:10:00+03	60400.00
BEC2FB	2017-07-05 20:41:00+03	66000.00
BEC336	2017-08-02 05:24:00+03	17800.00
BEC366	2017-07-06 10:40:00+03	57500.00
BEC398	2017-07-17 04:41:00+03	173200.00
BEC3C7	2017-07-08 01:00:00+03	332800.00
BEC427	2017-08-03 15:04:00+03	28800.00
BEC44D	2017-07-13 04:31:00+03	14400.00
BEC463	2017-07-03 18:36:00+03	114600.00
BEC4A4	2017-07-07 16:28:00+03	246000.00
BEC4B0	2017-08-08 18:08:00+03	31600.00
BEC4FD	2017-08-02 05:46:00+03	55800.00
BEC522	2017-07-13 05:34:00+03	402400.00
BEC530	2017-08-03 19:32:00+03	31600.00
BEC541	2017-08-02 20:54:00+03	14400.00
BEC5A4	2017-08-09 21:09:00+03	92700.00
BEC5B2	2017-08-12 10:12:00+03	111600.00
BEC5BE	2017-08-07 22:22:00+03	84100.00
BEC5DE	2017-07-23 11:41:00+03	28000.00
BEC5F2	2017-07-30 20:32:00+03	28300.00
BEC619	2017-08-10 02:22:00+03	21800.00
BEC633	2017-06-27 21:19:00+03	100600.00
BEC6C8	2017-07-06 11:21:00+03	94000.00
BEC6CA	2017-07-18 23:08:00+03	52900.00
BEC70C	2017-07-13 08:24:00+03	28000.00
BEC72F	2017-07-29 15:18:00+03	169800.00
BEC7F1	2017-08-01 12:23:00+03	147700.00
BEC7F2	2017-07-13 10:21:00+03	37700.00
BEC81C	2017-08-01 14:43:00+03	37600.00
BEC825	2017-06-27 20:08:00+03	84300.00
BEC891	2017-07-25 10:40:00+03	55800.00
BEC8C5	2017-07-18 23:56:00+03	39200.00
BEC8E6	2017-07-28 10:43:00+03	46400.00
BEC957	2017-07-04 13:38:00+03	40000.00
BEC9AF	2017-07-02 17:08:00+03	56000.00
BECA1B	2017-07-21 03:13:00+03	55800.00
BECAA5	2017-07-07 23:25:00+03	84500.00
BECABC	2017-07-26 11:40:00+03	61800.00
BECAD3	2017-08-12 01:41:00+03	133200.00
BECB11	2017-07-17 22:53:00+03	30200.00
BECB15	2017-07-21 17:20:00+03	28800.00
BECB6A	2017-07-14 18:27:00+03	32700.00
BECBEF	2017-07-23 10:21:00+03	27200.00
BECCCA	2017-07-12 09:15:00+03	24200.00
BECD81	2017-07-17 14:03:00+03	8200.00
BECDA9	2017-06-26 09:03:00+03	531400.00
BECDBF	2017-08-13 04:10:00+03	14000.00
BECE04	2017-07-09 19:35:00+03	120100.00
BECE0D	2017-07-18 16:20:00+03	10800.00
BECE31	2017-07-10 22:16:00+03	6700.00
BECE32	2017-08-15 06:32:00+03	87000.00
BECE71	2017-07-18 17:52:00+03	64500.00
BECEA8	2017-08-01 06:21:00+03	85200.00
BECEAA	2017-07-31 05:13:00+03	6900.00
BECF4F	2017-08-04 17:25:00+03	76300.00
BECFCA	2017-07-26 14:03:00+03	46400.00
BECFE9	2017-07-16 14:54:00+03	6000.00
BECFFE	2017-07-09 02:57:00+03	96800.00
BED05F	2017-07-25 00:42:00+03	59800.00
BED1A1	2017-08-02 09:47:00+03	67600.00
BED270	2017-07-02 03:08:00+03	136100.00
BED27B	2017-07-04 06:45:00+03	17800.00
BED292	2017-07-20 22:59:00+03	83700.00
BED295	2017-07-21 18:01:00+03	131700.00
BED296	2017-07-05 00:13:00+03	92800.00
BED2B9	2017-07-16 11:07:00+03	86300.00
BED2FF	2017-07-11 04:46:00+03	10800.00
BED304	2017-07-01 15:23:00+03	69300.00
BED33B	2017-07-14 04:35:00+03	46500.00
BED374	2017-07-19 04:22:00+03	142400.00
BED382	2017-07-24 00:28:00+03	39800.00
BED38A	2017-06-28 20:40:00+03	223200.00
BED3A7	2017-08-12 02:54:00+03	54800.00
BED436	2017-06-28 01:16:00+03	168000.00
BED473	2017-07-14 21:50:00+03	29600.00
BED47D	2017-07-19 22:36:00+03	148200.00
BED524	2017-07-10 19:23:00+03	69500.00
BED535	2017-07-21 12:44:00+03	116000.00
BED5C3	2017-07-30 12:43:00+03	40400.00
BED635	2017-07-30 04:24:00+03	24400.00
BED65A	2017-07-12 13:50:00+03	137600.00
BED665	2017-07-31 14:36:00+03	242600.00
BED6D1	2017-07-25 20:03:00+03	70600.00
BED719	2017-07-07 17:29:00+03	13800.00
BED764	2017-07-07 06:58:00+03	47100.00
BED824	2017-07-14 05:31:00+03	43200.00
BED88E	2017-07-07 18:17:00+03	32900.00
BED8BC	2017-08-10 12:19:00+03	68400.00
BED929	2017-07-10 03:20:00+03	46000.00
BED955	2017-07-19 22:39:00+03	43200.00
BED98A	2017-07-29 03:34:00+03	24300.00
BED990	2017-07-01 07:42:00+03	113900.00
BED9D0	2017-07-24 05:11:00+03	6700.00
BED9D3	2017-08-14 06:41:00+03	44800.00
BED9D5	2017-08-05 19:53:00+03	145000.00
BED9DF	2017-07-02 06:21:00+03	46400.00
BEDA09	2017-08-11 07:56:00+03	38600.00
BEDA49	2017-07-04 09:27:00+03	48800.00
BEDAD1	2017-07-09 11:58:00+03	43000.00
BEDAD7	2017-07-15 23:45:00+03	56000.00
BEDAE4	2017-08-09 17:37:00+03	26900.00
BEDBFA	2017-07-20 19:45:00+03	40400.00
BEDC60	2017-07-26 06:13:00+03	49100.00
BEDC68	2017-07-31 10:23:00+03	10800.00
BEDC69	2017-07-17 03:51:00+03	73600.00
BEDCB2	2017-07-06 11:08:00+03	45100.00
BEDCF5	2017-07-24 00:48:00+03	13600.00
BEDD5F	2017-07-05 16:19:00+03	115800.00
BEDDA0	2017-07-30 06:48:00+03	288300.00
BEDDAE	2017-07-30 12:25:00+03	64200.00
BEDDEC	2017-07-29 17:24:00+03	23600.00
BEDE19	2017-08-15 05:10:00+03	15400.00
BEDE3F	2017-07-19 09:06:00+03	83700.00
BEDE43	2017-07-20 00:41:00+03	261600.00
BEDEC9	2017-07-07 21:21:00+03	45400.00
BEDF41	2017-08-06 12:52:00+03	28000.00
BEDF44	2017-07-15 23:39:00+03	55800.00
BEDF79	2017-08-06 07:45:00+03	25100.00
BEDFAB	2017-07-08 09:02:00+03	87100.00
BEDFB5	2017-08-05 23:57:00+03	47200.00
BEE065	2017-08-10 18:00:00+03	26000.00
BEE09D	2017-07-07 17:21:00+03	22600.00
BEE0D1	2017-08-08 15:18:00+03	87700.00
BEE105	2017-08-10 01:14:00+03	149200.00
BEE131	2017-07-01 18:01:00+03	73200.00
BEE138	2017-08-06 09:14:00+03	28000.00
BEE150	2017-07-01 13:49:00+03	10800.00
BEE1D4	2017-06-29 09:23:00+03	40800.00
BEE1DF	2017-08-07 22:12:00+03	59300.00
BEE203	2017-08-14 22:14:00+03	95900.00
BEE235	2017-07-07 03:29:00+03	56900.00
BEE281	2017-08-09 06:20:00+03	28000.00
BEE29C	2017-08-15 03:48:00+03	6300.00
BEE2D8	2017-07-14 06:36:00+03	147500.00
BEE382	2017-07-03 14:00:00+03	6000.00
BEE38C	2017-07-23 20:24:00+03	67800.00
BEE3DB	2017-07-13 09:04:00+03	124200.00
BEE3DE	2017-07-09 21:54:00+03	193600.00
BEE3E8	2017-08-09 12:27:00+03	75300.00
BEE413	2017-07-08 09:55:00+03	133900.00
BEE49D	2017-07-02 01:38:00+03	79600.00
BEE49E	2017-07-17 01:42:00+03	354900.00
BEE52B	2017-07-15 14:12:00+03	137400.00
BEE55B	2017-08-09 11:41:00+03	18000.00
BEE593	2017-08-13 04:51:00+03	33100.00
BEE5A3	2017-08-14 04:43:00+03	137100.00
BEE5D3	2017-07-21 23:10:00+03	123000.00
BEE61A	2017-07-25 22:53:00+03	242600.00
BEE64C	2017-08-04 23:13:00+03	40000.00
BEE6EA	2017-07-21 16:55:00+03	125400.00
BEE713	2017-08-08 05:50:00+03	136200.00
BEE731	2017-08-14 19:14:00+03	135400.00
BEE77D	2017-07-03 00:25:00+03	116900.00
BEE787	2017-08-06 11:38:00+03	68100.00
BEE7C1	2017-08-12 12:27:00+03	92800.00
BEE83F	2017-08-09 01:42:00+03	31100.00
BEE858	2017-08-01 17:37:00+03	29200.00
BEE865	2017-08-06 17:08:00+03	34000.00
BEE894	2017-07-30 12:07:00+03	93700.00
BEE89C	2017-08-09 17:02:00+03	46000.00
BEE8AE	2017-08-10 20:53:00+03	67400.00
BEE8CD	2017-07-29 13:32:00+03	79900.00
BEE909	2017-07-14 22:01:00+03	52600.00
BEE99F	2017-07-17 12:06:00+03	90800.00
BEEA46	2017-07-22 05:35:00+03	102100.00
BEEA63	2017-08-09 19:43:00+03	33400.00
BEEA89	2017-08-02 03:46:00+03	56200.00
BEEAC0	2017-08-03 12:07:00+03	73500.00
BEEAE0	2017-08-14 03:57:00+03	131000.00
BEEAFF	2017-08-03 12:03:00+03	23600.00
BEEB43	2017-07-28 20:50:00+03	127700.00
BEEB7C	2017-07-20 02:36:00+03	29600.00
BEEBDB	2017-08-01 17:31:00+03	10800.00
BEEC94	2017-07-16 14:18:00+03	125000.00
BEED05	2017-08-06 05:06:00+03	64100.00
BEED34	2017-06-30 19:44:00+03	82400.00
BEEDB3	2017-07-29 01:32:00+03	26000.00
BEEDD9	2017-07-09 14:22:00+03	56100.00
BEEE82	2017-07-22 01:53:00+03	132800.00
BEEEEE	2017-08-06 12:55:00+03	25600.00
BEEEF3	2017-08-12 03:32:00+03	88500.00
BEEF04	2017-08-09 10:12:00+03	23200.00
BEEF73	2017-07-13 14:37:00+03	39800.00
BEEFAF	2017-07-12 16:20:00+03	270200.00
BEEFF1	2017-07-29 05:44:00+03	49800.00
BEF01A	2017-08-06 02:55:00+03	51900.00
BEF0A2	2017-07-26 23:36:00+03	49800.00
BEF0BB	2017-07-14 04:48:00+03	145300.00
BEF0D3	2017-08-14 11:10:00+03	64700.00
BEF0F5	2017-08-12 13:23:00+03	98700.00
BEF11F	2017-08-13 08:55:00+03	152500.00
BEF144	2017-07-02 10:57:00+03	62100.00
BEF1B4	2017-07-20 12:28:00+03	24400.00
BEF260	2017-08-04 12:08:00+03	23400.00
BEF27C	2017-07-15 19:57:00+03	86400.00
BEF28F	2017-08-02 05:54:00+03	49300.00
BEF2CC	2017-08-13 10:45:00+03	65200.00
BEF32D	2017-07-23 07:46:00+03	126700.00
BEF359	2017-07-27 18:36:00+03	25100.00
BEF36B	2017-08-12 10:09:00+03	136500.00
BEF387	2017-07-12 07:04:00+03	56000.00
BEF3AC	2017-07-30 00:03:00+03	14000.00
BEF3EA	2017-07-09 02:58:00+03	188900.00
BEF3EB	2017-07-21 13:48:00+03	48800.00
BEF439	2017-07-29 08:16:00+03	39600.00
BEF473	2017-06-29 11:57:00+03	25000.00
BEF47C	2017-07-02 09:21:00+03	28800.00
BEF4AC	2017-08-03 00:08:00+03	43200.00
BEF5C2	2017-07-23 21:23:00+03	68800.00
BEF5E6	2017-07-10 03:50:00+03	43900.00
BEF664	2017-08-01 22:42:00+03	28800.00
BEF6BC	2017-08-14 14:36:00+03	26000.00
BEF6EE	2017-08-10 17:14:00+03	44000.00
BEF7A0	2017-07-06 07:35:00+03	26000.00
BEF7B8	2017-07-08 23:06:00+03	28800.00
BEF7ED	2017-08-06 22:05:00+03	52900.00
BEF815	2017-07-27 18:52:00+03	27600.00
BEF82C	2017-08-12 02:37:00+03	44000.00
BEF831	2017-06-29 05:20:00+03	81900.00
BEF8C5	2017-08-05 00:44:00+03	64700.00
BEF8E6	2017-07-20 04:36:00+03	29600.00
BEF913	2017-08-13 10:10:00+03	6300.00
BEF923	2017-07-19 10:43:00+03	27200.00
BEF93E	2017-07-01 14:01:00+03	46800.00
BEF9A5	2017-08-09 11:37:00+03	74800.00
BEFA1F	2017-08-11 14:11:00+03	34200.00
BEFA60	2017-08-10 04:19:00+03	30900.00
BEFA95	2017-07-20 01:27:00+03	63700.00
BEFAAF	2017-07-07 12:26:00+03	123900.00
BEFAE6	2017-08-12 15:54:00+03	290600.00
BEFB13	2017-07-26 15:09:00+03	74400.00
BEFB50	2017-08-08 07:59:00+03	24400.00
BEFBB2	2017-08-07 16:05:00+03	266200.00
BEFBF5	2017-07-24 10:39:00+03	26000.00
BEFC6A	2017-07-15 18:24:00+03	28300.00
BEFC74	2017-07-14 11:43:00+03	65600.00
BEFC9E	2017-07-09 08:23:00+03	35200.00
BEFCAB	2017-07-18 11:33:00+03	24300.00
BEFCDF	2017-07-19 14:04:00+03	14800.00
BEFD00	2017-07-11 07:27:00+03	126300.00
BEFD8A	2017-07-05 15:04:00+03	39900.00
BEFD8D	2017-07-14 06:14:00+03	54800.00
BEFE02	2017-07-08 06:39:00+03	150600.00
BEFE33	2017-07-10 12:34:00+03	23400.00
BEFEE8	2017-07-13 01:19:00+03	13600.00
BEFF28	2017-07-11 17:20:00+03	15800.00
BEFF52	2017-08-08 19:10:00+03	136700.00
BEFFAA	2017-07-22 06:08:00+03	96800.00
BEFFDA	2017-07-02 17:09:00+03	68100.00
BF0022	2017-07-13 05:48:00+03	58600.00
BF0045	2017-07-28 16:50:00+03	35200.00
BF0082	2017-08-04 15:54:00+03	58800.00
BF00A4	2017-07-20 21:42:00+03	34000.00
BF00AB	2017-07-16 05:34:00+03	132800.00
BF01CD	2017-08-13 05:03:00+03	87400.00
BF01F0	2017-08-08 11:16:00+03	28800.00
BF0225	2017-07-07 14:03:00+03	131100.00
BF02A0	2017-08-05 10:10:00+03	193600.00
BF02A8	2017-08-10 02:23:00+03	26000.00
BF03B7	2017-08-04 03:29:00+03	96800.00
BF03C7	2017-07-26 02:59:00+03	16400.00
BF03E2	2017-08-13 00:37:00+03	52000.00
BF0548	2017-07-27 18:02:00+03	20200.00
BF05D5	2017-08-10 11:43:00+03	23600.00
BF05EA	2017-07-27 20:01:00+03	35400.00
BF05F8	2017-07-27 10:58:00+03	59100.00
BF0620	2017-08-01 06:45:00+03	79800.00
BF0697	2017-07-03 07:49:00+03	93900.00
BF06AB	2017-07-08 18:52:00+03	24400.00
BF06B6	2017-07-18 03:56:00+03	24400.00
BF074B	2017-07-23 04:07:00+03	246000.00
BF074F	2017-08-02 04:45:00+03	56000.00
BF0756	2017-08-13 02:01:00+03	64600.00
BF076C	2017-08-10 17:21:00+03	104600.00
BF082E	2017-07-05 02:10:00+03	89600.00
BF0851	2017-07-20 18:10:00+03	20400.00
BF0854	2017-08-12 04:48:00+03	78100.00
BF0904	2017-07-30 05:49:00+03	134400.00
BF0909	2017-07-09 04:41:00+03	55800.00
BF090D	2017-07-27 11:16:00+03	123000.00
BF0919	2017-07-12 09:18:00+03	199200.00
BF096B	2017-07-28 21:06:00+03	137600.00
BF096E	2017-07-02 02:34:00+03	11600.00
BF0979	2017-07-04 03:18:00+03	26200.00
BF0989	2017-07-27 19:22:00+03	51800.00
BF09AB	2017-08-14 11:52:00+03	29000.00
BF09AD	2017-08-14 16:22:00+03	68000.00
BF09AE	2017-07-10 22:58:00+03	27400.00
BF09EE	2017-07-07 13:54:00+03	57400.00
BF09F6	2017-07-03 05:18:00+03	44800.00
BF0A42	2017-07-04 00:09:00+03	56600.00
BF0A93	2017-07-19 01:11:00+03	93900.00
BF0AA8	2017-07-07 17:02:00+03	65500.00
BF0AB3	2017-07-21 15:24:00+03	112600.00
BF0AF5	2017-07-28 00:07:00+03	137000.00
BF0B02	2017-07-15 21:11:00+03	53400.00
BF0B1A	2017-08-15 16:23:00+03	147000.00
BF0B40	2017-07-27 07:36:00+03	246000.00
BF0B8D	2017-07-19 19:45:00+03	61800.00
BF0B94	2017-08-01 15:02:00+03	15000.00
BF0BBD	2017-06-27 13:43:00+03	168700.00
BF0BC3	2017-08-11 15:48:00+03	8200.00
BF0C00	2017-07-16 23:55:00+03	6300.00
BF0C8D	2017-08-02 14:13:00+03	12600.00
BF0C93	2017-07-17 14:38:00+03	131700.00
BF0CDE	2017-07-06 13:55:00+03	35200.00
BF0CE9	2017-08-10 21:27:00+03	75800.00
BF0D00	2017-07-07 13:57:00+03	23600.00
BF0D1D	2017-07-15 23:56:00+03	97600.00
BF0DB9	2017-08-11 19:51:00+03	277800.00
BF0F7A	2017-07-28 04:44:00+03	8200.00
BF1012	2017-08-14 19:51:00+03	97900.00
BF1017	2017-07-17 02:30:00+03	19100.00
BF1021	2017-07-22 04:22:00+03	94000.00
BF102B	2017-08-15 17:00:00+03	246000.00
BF1049	2017-07-23 21:55:00+03	56600.00
BF106C	2017-08-13 23:39:00+03	58800.00
BF108B	2017-07-02 14:01:00+03	111700.00
BF1094	2017-07-15 05:45:00+03	406700.00
BF10AC	2017-07-19 22:38:00+03	65900.00
BF10E6	2017-07-23 14:51:00+03	92800.00
BF1104	2017-07-26 08:20:00+03	14800.00
BF111D	2017-07-05 12:04:00+03	97900.00
BF112B	2017-08-07 11:27:00+03	123000.00
BF112F	2017-07-30 20:15:00+03	24800.00
BF11A5	2017-08-05 01:14:00+03	6000.00
BF11CC	2017-07-13 17:44:00+03	124200.00
BF11D3	2017-07-08 22:33:00+03	14000.00
BF11E2	2017-07-21 20:52:00+03	65900.00
BF129F	2017-08-06 01:38:00+03	169900.00
BF12DC	2017-07-13 12:59:00+03	22100.00
BF1312	2017-08-06 15:20:00+03	56600.00
BF136D	2017-07-22 02:49:00+03	23200.00
BF13AC	2017-07-18 18:52:00+03	357300.00
BF13C0	2017-07-12 12:05:00+03	21800.00
BF13F5	2017-07-02 20:55:00+03	28300.00
BF141A	2017-07-24 02:50:00+03	26000.00
BF1556	2017-07-14 05:38:00+03	30000.00
BF1574	2017-07-18 09:16:00+03	232800.00
BF1582	2017-07-14 10:09:00+03	93600.00
BF158D	2017-07-27 11:22:00+03	40600.00
BF159D	2017-07-17 09:42:00+03	136800.00
BF16B0	2017-08-05 10:03:00+03	47700.00
BF16BF	2017-07-28 05:51:00+03	126900.00
BF16C4	2017-07-06 08:18:00+03	22100.00
BF16DC	2017-07-08 21:11:00+03	22200.00
BF170B	2017-07-07 17:50:00+03	71600.00
BF1746	2017-07-11 13:07:00+03	64500.00
BF178C	2017-08-01 11:39:00+03	32800.00
BF17A0	2017-07-26 12:19:00+03	62800.00
BF17AC	2017-07-03 09:08:00+03	17000.00
BF17F1	2017-07-20 12:38:00+03	34000.00
BF1887	2017-08-05 05:36:00+03	43300.00
BF1889	2017-07-08 16:02:00+03	23200.00
BF1968	2017-07-09 06:13:00+03	115600.00
BF196C	2017-07-23 12:00:00+03	48500.00
BF1999	2017-08-07 13:22:00+03	52400.00
BF19E4	2017-07-14 07:22:00+03	129700.00
BF1A4F	2017-07-29 02:55:00+03	38200.00
BF1A89	2017-08-03 03:19:00+03	6800.00
BF1A8C	2017-07-18 03:46:00+03	56900.00
BF1A94	2017-08-10 16:27:00+03	284800.00
BF1AF6	2017-07-26 17:12:00+03	33100.00
BF1B3A	2017-07-15 07:25:00+03	58900.00
BF1B67	2017-08-06 14:13:00+03	41600.00
BF1B8D	2017-08-11 21:41:00+03	23600.00
BF1BB9	2017-08-04 21:55:00+03	25600.00
BF1BF0	2017-08-01 05:40:00+03	48800.00
BF1BF7	2017-07-17 12:39:00+03	36200.00
BF1CA7	2017-08-03 05:46:00+03	13800.00
BF1CC9	2017-08-09 12:23:00+03	39700.00
BF1D28	2017-07-12 15:29:00+03	135600.00
BF1D2D	2017-08-11 02:25:00+03	35700.00
BF1D66	2017-08-06 03:52:00+03	283000.00
BF1DE4	2017-07-25 13:51:00+03	46800.00
BF1E05	2017-07-24 15:41:00+03	270800.00
BF1E23	2017-07-02 17:05:00+03	372500.00
BF1E4A	2017-08-09 05:34:00+03	52400.00
BF1E7B	2017-07-13 20:51:00+03	90400.00
BF1E80	2017-06-27 01:09:00+03	85600.00
BF1ED1	2017-08-03 10:23:00+03	99200.00
BF1F22	2017-07-27 18:54:00+03	100000.00
BF1F96	2017-07-13 01:26:00+03	46200.00
BF202E	2017-07-13 10:30:00+03	39400.00
BF2077	2017-07-01 16:56:00+03	8200.00
BF20A5	2017-07-30 18:45:00+03	64700.00
BF20CB	2017-07-24 21:46:00+03	131100.00
BF20F6	2017-07-30 13:53:00+03	12400.00
BF2118	2017-08-09 04:09:00+03	34400.00
BF21E6	2017-07-29 21:24:00+03	37000.00
BF2297	2017-07-12 10:48:00+03	28000.00
BF22B4	2017-08-10 17:24:00+03	55800.00
BF2340	2017-08-03 11:51:00+03	27200.00
BF237E	2017-07-09 09:26:00+03	57200.00
BF2389	2017-07-23 17:27:00+03	74900.00
BF2460	2017-07-04 05:02:00+03	59000.00
BF246A	2017-08-15 14:04:00+03	113200.00
BF2475	2017-08-12 00:49:00+03	30300.00
BF2496	2017-07-14 07:21:00+03	67900.00
BF24D3	2017-08-15 04:06:00+03	40100.00
BF2582	2017-07-15 21:08:00+03	75200.00
BF2624	2017-07-04 16:46:00+03	40400.00
BF2656	2017-07-01 12:57:00+03	55800.00
BF26A3	2017-07-13 15:15:00+03	68000.00
BF26BA	2017-08-08 07:27:00+03	67600.00
BF2726	2017-07-13 10:07:00+03	52300.00
BF2797	2017-07-17 15:36:00+03	168000.00
BF280A	2017-07-14 14:15:00+03	47100.00
BF2830	2017-07-05 09:20:00+03	8200.00
BF2831	2017-07-14 02:15:00+03	47400.00
BF283D	2017-06-30 18:45:00+03	344600.00
BF289F	2017-08-04 17:54:00+03	15000.00
BF2953	2017-08-14 07:02:00+03	139000.00
BF2989	2017-08-15 11:27:00+03	23400.00
BF2997	2017-07-02 09:12:00+03	23400.00
BF29A6	2017-07-25 07:39:00+03	28000.00
BF29AE	2017-08-14 12:36:00+03	48800.00
BF29C6	2017-07-18 04:58:00+03	48800.00
BF29EC	2017-08-06 18:26:00+03	49900.00
BF29F0	2017-08-03 04:01:00+03	34400.00
BF2A38	2017-08-02 04:48:00+03	251300.00
BF2A5F	2017-08-14 04:30:00+03	108200.00
BF2AA6	2017-07-18 03:37:00+03	136200.00
BF2ABA	2017-07-31 06:04:00+03	88500.00
BF2AD7	2017-07-26 16:46:00+03	125100.00
BF2B01	2017-07-23 21:17:00+03	135400.00
BF2B10	2017-07-19 09:16:00+03	48100.00
BF2B1B	2017-08-13 20:24:00+03	46300.00
BF2B4F	2017-07-09 06:07:00+03	109700.00
BF2BF9	2017-07-25 11:31:00+03	21400.00
BF2C1C	2017-07-22 10:59:00+03	207400.00
BF2CC3	2017-07-06 07:37:00+03	65900.00
BF2CD5	2017-07-23 09:59:00+03	75300.00
BF2DA4	2017-07-28 20:19:00+03	13600.00
BF2DCB	2017-08-13 22:24:00+03	72200.00
BF2E02	2017-07-29 16:30:00+03	56100.00
BF2E1B	2017-07-26 12:23:00+03	88600.00
BF2EA7	2017-08-10 00:19:00+03	34000.00
BF2F7B	2017-08-03 05:16:00+03	66900.00
BF2F92	2017-08-12 08:35:00+03	202200.00
BF2FB6	2017-07-12 01:55:00+03	150600.00
BF3014	2017-07-29 11:00:00+03	68100.00
BF305C	2017-07-17 04:29:00+03	28000.00
BF312A	2017-07-08 03:09:00+03	48800.00
BF3145	2017-06-29 02:31:00+03	136800.00
BF324D	2017-07-17 10:07:00+03	55800.00
BF3250	2017-07-17 23:16:00+03	155600.00
BF3287	2017-07-06 23:06:00+03	32800.00
BF32AB	2017-07-22 14:51:00+03	13400.00
BF32F4	2017-07-21 01:22:00+03	56300.00
BF32F5	2017-07-30 18:33:00+03	66400.00
BF3301	2017-08-09 04:44:00+03	30200.00
BF3319	2017-07-19 03:05:00+03	131600.00
BF3391	2017-07-06 23:07:00+03	117600.00
BF33E8	2017-07-29 10:56:00+03	19600.00
BF346D	2017-07-26 19:26:00+03	15000.00
BF34B4	2017-07-30 19:55:00+03	56100.00
BF35AE	2017-08-14 07:29:00+03	79900.00
BF35B6	2017-07-11 22:22:00+03	64400.00
BF35BF	2017-07-17 14:32:00+03	128800.00
BF3666	2017-07-04 13:25:00+03	93800.00
BF36D3	2017-07-15 20:10:00+03	90600.00
BF372A	2017-08-14 06:46:00+03	28800.00
BF37F5	2017-07-19 04:12:00+03	167400.00
BF3817	2017-07-23 13:06:00+03	99200.00
BF3837	2017-07-02 22:29:00+03	31000.00
BF3894	2017-08-13 07:01:00+03	58200.00
BF3975	2017-07-01 20:34:00+03	56000.00
BF3A3C	2017-08-09 08:51:00+03	26000.00
BF3AE5	2017-07-14 00:16:00+03	112000.00
BF3B53	2017-07-02 16:59:00+03	67400.00
BF3B76	2017-07-06 21:13:00+03	57800.00
BF3B9D	2017-07-29 01:33:00+03	24000.00
BF3BB8	2017-08-14 23:26:00+03	28800.00
BF3BCC	2017-07-23 01:27:00+03	253300.00
BF3BF6	2017-08-12 15:55:00+03	90200.00
BF3BFE	2017-07-06 01:03:00+03	55800.00
BF3C1D	2017-07-05 15:22:00+03	59300.00
BF3C52	2017-07-21 02:38:00+03	34000.00
BF3CEC	2017-07-19 13:51:00+03	13400.00
BF3D08	2017-07-02 10:28:00+03	406200.00
BF3D7E	2017-07-31 02:39:00+03	42600.00
BF3DA1	2017-08-13 11:05:00+03	36800.00
BF3ED0	2017-07-23 14:45:00+03	6700.00
BF3FB8	2017-08-01 15:48:00+03	67200.00
BF3FCF	2017-08-05 12:10:00+03	56000.00
BF3FD8	2017-07-01 15:16:00+03	130400.00
BF406A	2017-07-26 05:42:00+03	184300.00
BF4071	2017-07-12 20:05:00+03	72200.00
BF4119	2017-07-21 13:31:00+03	80200.00
BF416B	2017-07-25 23:55:00+03	100900.00
BF41B4	2017-07-03 06:12:00+03	58000.00
BF4239	2017-08-10 23:46:00+03	121800.00
BF42E5	2017-07-26 06:51:00+03	135600.00
BF42F5	2017-07-02 16:08:00+03	137700.00
BF438C	2017-07-14 10:05:00+03	56000.00
BF44BA	2017-08-05 09:21:00+03	38400.00
BF44C5	2017-07-23 19:19:00+03	26600.00
BF45DF	2017-08-12 09:17:00+03	52900.00
BF45E3	2017-06-29 03:52:00+03	11000.00
BF45EC	2017-07-11 11:27:00+03	56000.00
BF460F	2017-08-05 09:01:00+03	74400.00
BF463D	2017-07-10 14:26:00+03	49100.00
BF469E	2017-07-13 06:36:00+03	33300.00
BF46AF	2017-07-26 18:18:00+03	31800.00
BF46ED	2017-08-09 20:00:00+03	85300.00
BF4711	2017-07-25 16:48:00+03	27200.00
BF4766	2017-07-12 07:20:00+03	55600.00
BF483A	2017-07-27 11:51:00+03	44000.00
BF488E	2017-08-13 17:55:00+03	24000.00
BF48A6	2017-07-28 03:23:00+03	23200.00
BF48B6	2017-07-21 06:26:00+03	87000.00
BF4951	2017-07-28 00:49:00+03	26000.00
BF49B4	2017-08-09 20:33:00+03	28000.00
BF49F5	2017-07-18 07:24:00+03	67600.00
BF4A22	2017-07-04 20:27:00+03	39400.00
BF4A28	2017-08-13 22:09:00+03	8400.00
BF4A81	2017-07-08 09:00:00+03	109300.00
BF4A8F	2017-07-31 05:20:00+03	60800.00
BF4ADA	2017-07-04 00:00:00+03	55800.00
BF4AE4	2017-08-13 01:52:00+03	22600.00
BF4BEC	2017-07-03 05:10:00+03	66900.00
BF4C1C	2017-06-30 03:41:00+03	6000.00
BF4C7A	2017-08-10 17:59:00+03	39300.00
BF4CB5	2017-07-25 08:31:00+03	63400.00
BF4CD7	2017-07-21 21:24:00+03	87600.00
BF4CF2	2017-07-23 19:13:00+03	26000.00
BF4D23	2017-07-23 23:02:00+03	96300.00
BF4D2A	2017-07-25 01:09:00+03	52900.00
BF4D77	2017-08-07 05:48:00+03	23600.00
BF4D9F	2017-07-20 15:38:00+03	258400.00
BF4DCC	2017-07-28 00:29:00+03	118100.00
BF4E03	2017-07-29 12:52:00+03	34600.00
BF4EAC	2017-08-07 18:25:00+03	43600.00
BF4EF2	2017-07-21 01:40:00+03	45400.00
BF4F35	2017-07-28 20:26:00+03	134400.00
BF4F39	2017-07-04 22:28:00+03	390400.00
BF4F73	2017-08-12 01:57:00+03	230000.00
BF4F78	2017-08-03 09:45:00+03	77900.00
BF4F89	2017-07-09 09:37:00+03	73000.00
BF4FA4	2017-07-30 04:27:00+03	44800.00
BF4FD5	2017-08-15 07:51:00+03	28000.00
BF508B	2017-07-27 17:18:00+03	90800.00
BF50CC	2017-08-12 09:42:00+03	43000.00
BF50ED	2017-07-13 00:37:00+03	266400.00
BF5113	2017-07-12 00:46:00+03	35200.00
BF511C	2017-08-06 02:29:00+03	19600.00
BF5144	2017-07-14 11:47:00+03	43800.00
BF51A4	2017-08-07 02:18:00+03	260300.00
BF51F0	2017-08-08 00:40:00+03	73600.00
BF5246	2017-07-27 04:57:00+03	48900.00
BF5266	2017-07-18 01:52:00+03	94000.00
BF5294	2017-07-17 13:58:00+03	58000.00
BF52AA	2017-07-09 04:27:00+03	23200.00
BF52C5	2017-07-21 18:53:00+03	86800.00
BF52E4	2017-08-04 21:01:00+03	44800.00
BF5308	2017-08-08 19:36:00+03	35500.00
BF53B1	2017-07-16 08:09:00+03	26600.00
BF53E1	2017-07-21 03:50:00+03	56200.00
BF5463	2017-07-09 10:34:00+03	46000.00
BF5477	2017-07-23 22:39:00+03	34000.00
BF5486	2017-07-03 03:56:00+03	153200.00
BF54B8	2017-07-13 16:20:00+03	24400.00
BF54E8	2017-08-01 01:14:00+03	117800.00
BF54F9	2017-08-05 17:05:00+03	32800.00
BF55F3	2017-07-22 17:48:00+03	23600.00
BF55FE	2017-08-11 11:51:00+03	77100.00
BF5642	2017-07-11 11:57:00+03	362400.00
BF564D	2017-07-09 18:14:00+03	17800.00
BF56A8	2017-07-06 23:57:00+03	84500.00
BF578D	2017-07-14 21:05:00+03	91100.00
BF5811	2017-08-08 21:32:00+03	98800.00
BF581B	2017-08-10 11:43:00+03	28300.00
BF582B	2017-07-27 15:45:00+03	21400.00
BF5853	2017-07-25 17:21:00+03	284700.00
BF58FE	2017-08-09 04:39:00+03	13400.00
BF591B	2017-07-05 22:48:00+03	28000.00
BF5975	2017-08-12 14:20:00+03	56900.00
BF5981	2017-07-13 14:05:00+03	10700.00
BF59A4	2017-07-28 10:57:00+03	28000.00
BF59FC	2017-07-20 14:22:00+03	55800.00
BF5A3A	2017-08-14 17:11:00+03	101300.00
BF5A60	2017-07-28 04:37:00+03	52300.00
BF5AF2	2017-08-08 04:14:00+03	73300.00
BF5B03	2017-07-22 17:22:00+03	88100.00
BF5B08	2017-06-28 05:06:00+03	38400.00
BF5B29	2017-08-03 14:04:00+03	163500.00
BF5B59	2017-07-21 15:16:00+03	31000.00
BF5B60	2017-07-16 01:04:00+03	12200.00
BF5B8D	2017-07-10 22:43:00+03	78900.00
BF5C15	2017-07-08 13:12:00+03	38800.00
BF5C2D	2017-08-06 18:20:00+03	100600.00
BF5C42	2017-08-12 22:46:00+03	15700.00
BF5C71	2017-07-20 08:57:00+03	34100.00
BF5C95	2017-07-06 22:40:00+03	110300.00
BF5D0A	2017-07-07 18:10:00+03	17000.00
BF5D1F	2017-08-08 12:46:00+03	38400.00
BF5E01	2017-08-03 09:24:00+03	46400.00
BF5E32	2017-07-30 12:38:00+03	45400.00
BF5ED6	2017-07-11 17:03:00+03	67600.00
BF5F1E	2017-07-11 01:49:00+03	56000.00
BF5F47	2017-08-05 20:07:00+03	15400.00
BF5FE3	2017-07-09 12:14:00+03	111600.00
BF600C	2017-08-08 12:52:00+03	22000.00
BF6030	2017-07-14 20:20:00+03	15900.00
BF6038	2017-07-17 11:55:00+03	58600.00
BF6089	2017-07-18 05:11:00+03	14000.00
BF60DE	2017-08-10 18:03:00+03	65400.00
BF60F8	2017-06-28 03:20:00+03	66600.00
BF60FD	2017-08-13 06:08:00+03	6800.00
BF6126	2017-07-18 15:19:00+03	86400.00
BF6170	2017-07-30 20:19:00+03	26800.00
BF61B1	2017-07-01 15:48:00+03	6000.00
BF61CE	2017-07-19 17:36:00+03	46400.00
BF6271	2017-07-21 14:25:00+03	103500.00
BF630D	2017-07-17 23:50:00+03	123600.00
BF63CA	2017-08-02 12:17:00+03	93200.00
BF641A	2017-07-14 10:49:00+03	27800.00
BF6456	2017-08-08 07:40:00+03	65900.00
BF6462	2017-07-11 10:37:00+03	132100.00
BF64A5	2017-08-10 23:09:00+03	39300.00
BF64EF	2017-08-05 13:36:00+03	56600.00
BF64FC	2017-07-26 11:44:00+03	46700.00
BF6517	2017-08-11 13:04:00+03	8000.00
BF6522	2017-06-29 08:45:00+03	67900.00
BF6558	2017-07-28 14:24:00+03	64700.00
BF6635	2017-07-24 14:51:00+03	94700.00
BF6649	2017-07-04 09:54:00+03	32700.00
BF66F2	2017-07-26 21:40:00+03	40600.00
BF66FF	2017-08-03 05:12:00+03	20000.00
BF6705	2017-08-06 14:53:00+03	15800.00
BF6712	2017-07-18 21:21:00+03	15000.00
BF6761	2017-08-14 04:06:00+03	81300.00
BF678C	2017-07-12 04:10:00+03	77600.00
BF67B8	2017-07-09 19:35:00+03	29300.00
BF67BD	2017-07-01 01:30:00+03	31600.00
BF6809	2017-08-03 01:31:00+03	47800.00
BF684A	2017-07-08 06:17:00+03	23400.00
BF6955	2017-07-19 00:11:00+03	36200.00
BF6965	2017-07-11 10:57:00+03	25600.00
BF6995	2017-08-03 04:56:00+03	73200.00
BF69D1	2017-08-03 22:42:00+03	155000.00
BF69EF	2017-08-05 02:16:00+03	239200.00
BF69F6	2017-07-20 08:41:00+03	125200.00
BF6A0D	2017-07-12 13:58:00+03	48800.00
BF6A42	2017-06-30 15:19:00+03	36900.00
BF6A6B	2017-08-14 11:37:00+03	198600.00
BF6A81	2017-07-01 03:00:00+03	123000.00
BF6AB5	2017-07-09 08:11:00+03	282300.00
BF6ABF	2017-07-01 06:33:00+03	58400.00
BF6AEC	2017-07-05 17:23:00+03	102300.00
BF6B04	2017-07-23 03:18:00+03	44800.00
BF6B61	2017-07-29 07:24:00+03	12600.00
BF6B67	2017-07-26 11:57:00+03	26600.00
BF6B81	2017-07-22 04:45:00+03	6800.00
BF6B8D	2017-07-06 20:22:00+03	6700.00
BF6BB1	2017-07-21 08:46:00+03	126600.00
BF6BBF	2017-08-06 20:43:00+03	14400.00
BF6BFA	2017-07-25 00:01:00+03	20900.00
BF6CAA	2017-07-28 12:44:00+03	34000.00
BF6CD0	2017-07-20 00:27:00+03	16400.00
BF6D1F	2017-07-05 05:46:00+03	28000.00
BF6E41	2017-07-10 05:42:00+03	123400.00
BF6E47	2017-07-28 13:59:00+03	92000.00
BF6E50	2017-08-15 00:10:00+03	175300.00
BF6F16	2017-07-17 07:40:00+03	88900.00
BF6FAC	2017-07-02 13:11:00+03	46300.00
BF703B	2017-07-29 00:35:00+03	12600.00
BF70D3	2017-07-06 16:22:00+03	44000.00
BF7179	2017-08-10 22:51:00+03	31600.00
BF717F	2017-08-05 03:50:00+03	92000.00
BF71F7	2017-07-18 16:19:00+03	124300.00
BF7237	2017-07-06 16:04:00+03	20200.00
BF723A	2017-07-07 12:25:00+03	29200.00
BF723D	2017-08-04 05:53:00+03	112000.00
BF73E0	2017-07-26 01:59:00+03	133100.00
BF73ED	2017-08-13 02:16:00+03	27200.00
BF740F	2017-08-15 16:26:00+03	19100.00
BF7423	2017-08-08 00:58:00+03	26000.00
BF747B	2017-07-13 05:03:00+03	14000.00
BF7501	2017-08-05 09:08:00+03	28800.00
BF751B	2017-07-17 04:12:00+03	54400.00
BF7531	2017-07-21 04:46:00+03	193100.00
BF753F	2017-07-16 10:32:00+03	55800.00
BF75F1	2017-07-29 17:44:00+03	24800.00
BF7643	2017-07-22 02:18:00+03	90100.00
BF76B9	2017-08-12 21:46:00+03	25600.00
BF76EB	2017-07-31 21:14:00+03	46200.00
BF76F6	2017-07-25 18:52:00+03	114200.00
BF7711	2017-08-06 12:34:00+03	58700.00
BF774E	2017-08-09 09:09:00+03	42800.00
BF77E1	2017-08-15 14:09:00+03	88100.00
BF7815	2017-08-06 08:40:00+03	16400.00
BF7822	2017-07-11 07:13:00+03	65900.00
BF7829	2017-07-11 21:59:00+03	285900.00
BF7847	2017-07-11 06:07:00+03	76300.00
BF784B	2017-08-15 15:44:00+03	19800.00
BF7863	2017-07-17 15:47:00+03	8200.00
BF787B	2017-06-29 00:27:00+03	16400.00
BF789E	2017-06-30 08:34:00+03	164700.00
BF78A3	2017-08-13 18:26:00+03	130400.00
BF78C2	2017-08-11 12:36:00+03	83000.00
BF78D5	2017-08-15 03:10:00+03	46200.00
BF7942	2017-07-29 09:36:00+03	28000.00
BF7961	2017-08-12 12:50:00+03	314400.00
BF7997	2017-07-12 11:35:00+03	25200.00
BF79A6	2017-08-03 06:00:00+03	266400.00
BF79B4	2017-07-09 08:45:00+03	277800.00
BF79DB	2017-06-27 07:27:00+03	27200.00
BF7A39	2017-08-12 09:35:00+03	43800.00
BF7A4A	2017-07-11 05:47:00+03	260900.00
BF7A7C	2017-07-25 09:41:00+03	50800.00
BF7A9F	2017-07-27 02:32:00+03	47400.00
BF7AFE	2017-07-12 05:29:00+03	6800.00
BF7B15	2017-07-26 12:27:00+03	161900.00
BF7B75	2017-07-08 12:10:00+03	122100.00
BF7BBA	2017-07-13 00:30:00+03	65500.00
BF7BC1	2017-08-08 04:17:00+03	58200.00
BF7C04	2017-07-26 19:59:00+03	28600.00
BF7C34	2017-07-22 03:05:00+03	16400.00
BF7CCE	2017-07-28 09:32:00+03	123000.00
BF7DE5	2017-07-18 19:02:00+03	28000.00
BF7DF7	2017-08-13 11:32:00+03	24800.00
BF7E11	2017-08-01 07:21:00+03	49600.00
BF7E5D	2017-07-20 06:08:00+03	69500.00
BF7EE1	2017-08-02 17:35:00+03	10800.00
BF7EF5	2017-06-29 15:51:00+03	69500.00
BF7F3B	2017-07-19 07:11:00+03	28000.00
BF7FBA	2017-08-12 02:40:00+03	55800.00
BF7FED	2017-07-22 10:00:00+03	23200.00
BF802A	2017-08-01 22:02:00+03	28000.00
BF8032	2017-08-13 17:58:00+03	63400.00
BF80A4	2017-08-13 10:18:00+03	91200.00
BF8167	2017-07-20 16:39:00+03	133100.00
BF8228	2017-07-30 06:37:00+03	13400.00
BF82BA	2017-06-30 11:06:00+03	57200.00
BF82D2	2017-08-06 16:26:00+03	128800.00
BF82D3	2017-07-03 06:58:00+03	58200.00
BF832B	2017-07-20 18:17:00+03	12600.00
BF8336	2017-07-29 01:49:00+03	30200.00
BF8378	2017-07-11 04:45:00+03	12400.00
BF83A6	2017-08-01 01:47:00+03	23400.00
BF83EC	2017-07-27 15:49:00+03	42400.00
BF842A	2017-08-02 02:57:00+03	83400.00
BF8491	2017-07-17 23:33:00+03	369000.00
BF84C6	2017-07-18 00:40:00+03	47400.00
BF84E9	2017-07-22 20:09:00+03	83200.00
BF851A	2017-08-02 06:05:00+03	111900.00
BF8521	2017-07-06 18:10:00+03	29600.00
BF8524	2017-07-29 20:35:00+03	28800.00
BF858D	2017-07-25 12:11:00+03	73300.00
BF85DE	2017-07-21 18:04:00+03	300700.00
BF8603	2017-08-04 21:08:00+03	75300.00
BF8605	2017-07-25 07:47:00+03	34000.00
BF8670	2017-07-26 08:56:00+03	8200.00
BF8748	2017-08-08 15:57:00+03	58200.00
BF875A	2017-08-12 12:46:00+03	200400.00
BF87A8	2017-08-10 12:01:00+03	66100.00
BF87C7	2017-07-30 17:48:00+03	95200.00
BF87DC	2017-08-05 00:27:00+03	66000.00
BF87EC	2017-07-12 14:23:00+03	13200.00
BF881B	2017-07-27 06:50:00+03	133200.00
BF883A	2017-08-07 15:31:00+03	184900.00
BF8849	2017-08-12 18:16:00+03	25200.00
BF8853	2017-07-16 17:06:00+03	13600.00
BF88AF	2017-08-04 17:35:00+03	33300.00
BF8900	2017-08-12 23:15:00+03	53200.00
BF892E	2017-08-12 08:15:00+03	42800.00
BF89E1	2017-08-09 02:57:00+03	342100.00
BF8A7E	2017-07-18 08:41:00+03	113800.00
BF8AA9	2017-07-20 19:42:00+03	51900.00
BF8AB5	2017-07-14 10:59:00+03	133100.00
BF8B37	2017-08-07 19:53:00+03	61800.00
BF8B42	2017-07-09 17:00:00+03	147200.00
BF8BE7	2017-06-30 06:00:00+03	27900.00
BF8BE8	2017-07-12 18:29:00+03	55800.00
BF8C32	2017-08-01 12:31:00+03	100600.00
BF8C49	2017-07-18 14:58:00+03	27300.00
BF8C7B	2017-08-06 21:34:00+03	73500.00
BF8CB9	2017-08-11 00:20:00+03	44600.00
BF8D09	2017-07-25 02:52:00+03	28000.00
BF8D86	2017-08-10 05:55:00+03	121600.00
BF8D93	2017-07-03 10:26:00+03	25200.00
BF8E2E	2017-07-13 09:57:00+03	25400.00
BF8E88	2017-08-01 20:23:00+03	92600.00
BF8ECF	2017-07-22 11:36:00+03	18600.00
BF8F05	2017-07-03 13:13:00+03	70700.00
BF8F4B	2017-07-27 11:26:00+03	36400.00
BF8F4F	2017-08-06 06:32:00+03	32800.00
BF8F53	2017-07-24 15:56:00+03	79600.00
BF8F98	2017-07-07 23:04:00+03	31800.00
BF9000	2017-08-02 08:07:00+03	28800.00
BF901F	2017-08-15 01:52:00+03	23600.00
BF9039	2017-07-17 18:09:00+03	23200.00
BF903F	2017-08-10 02:06:00+03	139100.00
BF907D	2017-08-05 05:19:00+03	87700.00
BF90BC	2017-07-26 00:02:00+03	52800.00
BF90C1	2017-07-16 18:01:00+03	64300.00
BF91B1	2017-07-26 02:51:00+03	68800.00
BF91DB	2017-08-06 02:03:00+03	18600.00
BF91FA	2017-08-11 12:33:00+03	155100.00
BF9220	2017-07-25 20:51:00+03	25200.00
BF9298	2017-07-23 10:19:00+03	13400.00
BF939D	2017-07-12 11:26:00+03	133200.00
BF9434	2017-08-13 23:44:00+03	12600.00
BF94AB	2017-08-07 09:12:00+03	110000.00
BF94CD	2017-08-14 15:46:00+03	31600.00
BF94E3	2017-08-01 08:37:00+03	139300.00
BF9518	2017-07-09 11:23:00+03	22000.00
BF957A	2017-07-12 00:34:00+03	258400.00
BF965D	2017-08-04 15:46:00+03	59800.00
BF968A	2017-08-04 12:32:00+03	51900.00
BF96A2	2017-08-14 02:33:00+03	44400.00
BF96EC	2017-08-12 13:24:00+03	24000.00
BF97B2	2017-08-11 23:43:00+03	40100.00
BF97BB	2017-07-30 09:41:00+03	52000.00
BF97FE	2017-08-15 10:49:00+03	32300.00
BF9801	2017-08-03 15:12:00+03	63700.00
BF9828	2017-07-08 14:02:00+03	25000.00
BF9857	2017-07-19 15:37:00+03	121800.00
BF997F	2017-07-25 04:27:00+03	7400.00
BF99AA	2017-07-27 05:21:00+03	61600.00
BF99AD	2017-07-07 23:24:00+03	42700.00
BF9A09	2017-07-03 01:27:00+03	25200.00
BF9A3A	2017-07-31 00:20:00+03	42800.00
BF9A4D	2017-07-30 13:00:00+03	48800.00
BF9A55	2017-07-24 01:44:00+03	46500.00
BF9AB0	2017-07-14 11:17:00+03	35900.00
BF9AEA	2017-07-23 22:44:00+03	169300.00
BF9AF5	2017-07-15 14:19:00+03	31100.00
BF9B69	2017-07-11 22:50:00+03	7400.00
BF9BE4	2017-07-30 22:52:00+03	24400.00
BF9C87	2017-07-21 22:19:00+03	40100.00
BF9CDC	2017-08-03 19:45:00+03	28800.00
BF9D18	2017-07-18 14:16:00+03	83000.00
BF9D22	2017-07-04 23:07:00+03	29400.00
BF9D2B	2017-08-01 06:08:00+03	57800.00
BF9D37	2017-07-11 14:59:00+03	49100.00
BF9DA0	2017-08-04 11:04:00+03	81900.00
BF9DAB	2017-08-05 08:26:00+03	35200.00
BF9DC4	2017-07-14 02:18:00+03	56000.00
BF9E3B	2017-08-13 10:39:00+03	28000.00
BF9E77	2017-07-31 21:31:00+03	27600.00
BF9EDF	2017-07-22 01:29:00+03	57800.00
BF9F2D	2017-07-12 06:49:00+03	36200.00
BF9F4A	2017-07-14 12:45:00+03	85700.00
BF9F5F	2017-07-09 07:04:00+03	111600.00
BF9F90	2017-07-14 10:07:00+03	31400.00
BF9FA6	2017-07-15 12:12:00+03	20600.00
BFA063	2017-08-11 13:32:00+03	79000.00
BFA0D5	2017-07-29 09:02:00+03	22000.00
BFA185	2017-07-06 06:58:00+03	93000.00
BFA1BF	2017-07-11 13:27:00+03	41600.00
BFA1D2	2017-07-21 12:26:00+03	6000.00
BFA27B	2017-08-12 20:11:00+03	47700.00
BFA29E	2017-08-06 13:29:00+03	51600.00
BFA2BE	2017-07-06 13:58:00+03	21400.00
BFA3F9	2017-08-11 09:18:00+03	101200.00
BFA482	2017-07-19 12:09:00+03	106100.00
BFA484	2017-07-04 20:31:00+03	6700.00
BFA549	2017-08-06 00:38:00+03	124300.00
BFA55B	2017-07-15 12:42:00+03	286100.00
BFA610	2017-07-21 02:56:00+03	42800.00
BFA658	2017-08-03 21:02:00+03	277800.00
BFA664	2017-08-14 07:28:00+03	44000.00
BFA66A	2017-08-13 00:01:00+03	55800.00
BFA680	2017-07-18 16:57:00+03	19600.00
BFA6F9	2017-07-28 17:07:00+03	7200.00
BFA741	2017-07-29 11:52:00+03	26700.00
BFA77F	2017-07-24 16:42:00+03	150000.00
BFA812	2017-07-10 03:35:00+03	492000.00
BFA816	2017-08-15 12:39:00+03	112600.00
BFA84F	2017-07-08 06:47:00+03	44500.00
BFA862	2017-07-06 22:12:00+03	28000.00
BFA865	2017-07-05 00:51:00+03	12600.00
BFA86F	2017-06-30 17:29:00+03	70700.00
BFA8F3	2017-08-06 23:05:00+03	29200.00
BFA95F	2017-07-11 15:48:00+03	31400.00
BFA96D	2017-08-15 14:08:00+03	311200.00
BFA992	2017-07-16 20:12:00+03	26000.00
BFA9AA	2017-07-16 13:16:00+03	23600.00
BFAA22	2017-08-10 06:50:00+03	301700.00
BFAA5C	2017-06-30 19:42:00+03	82900.00
BFAA68	2017-08-07 04:49:00+03	90400.00
BFAA76	2017-07-07 04:32:00+03	66600.00
BFAAA1	2017-07-27 04:07:00+03	44500.00
BFAB3D	2017-07-01 05:01:00+03	101200.00
BFAB9A	2017-07-15 21:01:00+03	20200.00
BFAB9C	2017-07-14 11:35:00+03	15400.00
BFAB9E	2017-08-11 23:00:00+03	54800.00
BFABD2	2017-07-13 18:32:00+03	68800.00
BFAC06	2017-08-14 00:24:00+03	36200.00
BFAC31	2017-08-03 17:34:00+03	105700.00
BFAC42	2017-07-24 08:13:00+03	132800.00
BFAC74	2017-07-19 11:13:00+03	12400.00
BFAC8B	2017-07-25 10:37:00+03	23400.00
BFACC2	2017-07-04 17:07:00+03	189100.00
BFACD7	2017-07-20 15:30:00+03	56600.00
BFACD8	2017-08-14 03:37:00+03	271100.00
BFAD6F	2017-08-12 04:56:00+03	105100.00
BFAE2B	2017-07-07 20:26:00+03	66600.00
BFAE59	2017-08-10 21:17:00+03	75600.00
BFAEE8	2017-07-17 10:47:00+03	15400.00
BFAF20	2017-08-02 23:22:00+03	57400.00
BFAFA6	2017-07-13 11:30:00+03	129200.00
BFAFCD	2017-08-11 11:53:00+03	21400.00
BFB002	2017-08-02 20:47:00+03	29200.00
BFB047	2017-08-09 03:29:00+03	615000.00
BFB05A	2017-08-15 06:13:00+03	81300.00
BFB0A0	2017-08-06 07:29:00+03	111600.00
BFB0A1	2017-08-12 21:23:00+03	73600.00
BFB0CF	2017-07-02 23:50:00+03	15100.00
BFB0EA	2017-07-14 12:05:00+03	59000.00
BFB0F6	2017-07-06 08:54:00+03	56000.00
BFB145	2017-07-07 05:27:00+03	155600.00
BFB159	2017-07-22 18:03:00+03	66200.00
BFB18D	2017-07-18 12:43:00+03	99300.00
BFB1F7	2017-07-28 21:11:00+03	32800.00
BFB215	2017-08-13 15:53:00+03	27200.00
BFB221	2017-07-03 13:44:00+03	21800.00
BFB265	2017-07-27 08:03:00+03	32700.00
BFB26A	2017-08-14 09:07:00+03	93900.00
BFB29A	2017-07-10 16:22:00+03	56600.00
BFB2AB	2017-08-03 02:03:00+03	28000.00
BFB300	2017-07-22 15:33:00+03	55600.00
BFB332	2017-08-14 11:51:00+03	282300.00
BFB34E	2017-08-02 09:19:00+03	126000.00
BFB39F	2017-08-15 09:55:00+03	170700.00
BFB440	2017-08-01 16:12:00+03	25600.00
BFB47F	2017-07-13 01:01:00+03	6700.00
BFB49A	2017-08-15 16:50:00+03	56600.00
BFB4F9	2017-08-08 18:33:00+03	162700.00
BFB505	2017-07-13 14:36:00+03	65500.00
BFB507	2017-08-06 18:55:00+03	99200.00
BFB572	2017-07-21 22:13:00+03	6700.00
BFB59E	2017-07-23 00:17:00+03	201200.00
BFB601	2017-07-19 04:13:00+03	43800.00
BFB659	2017-07-19 22:38:00+03	184300.00
BFB69A	2017-08-03 00:14:00+03	44500.00
BFB6F9	2017-07-30 18:35:00+03	12600.00
BFB786	2017-06-29 05:56:00+03	59200.00
BFB7A1	2017-08-09 05:21:00+03	269200.00
BFB7B0	2017-07-06 18:09:00+03	46000.00
BFB7D4	2017-08-14 20:35:00+03	108900.00
BFB80C	2017-07-09 17:33:00+03	39300.00
BFB816	2017-08-11 11:55:00+03	49600.00
BFB8B6	2017-07-11 07:18:00+03	34400.00
BFB955	2017-08-11 15:09:00+03	49100.00
BFB9B7	2017-07-16 04:49:00+03	26500.00
BFBA4A	2017-07-07 03:47:00+03	6800.00
BFBA9F	2017-07-05 15:06:00+03	38800.00
BFBAD5	2017-08-06 04:49:00+03	79900.00
BFBAFC	2017-07-28 06:19:00+03	131100.00
BFBB68	2017-07-22 09:19:00+03	21800.00
BFBB87	2017-08-03 02:36:00+03	135400.00
BFBBD9	2017-07-15 05:29:00+03	46900.00
BFBBDC	2017-07-07 02:12:00+03	55800.00
BFBC6F	2017-07-06 04:15:00+03	119200.00
BFBC87	2017-07-14 19:10:00+03	174900.00
BFBC9D	2017-07-11 19:15:00+03	246000.00
BFBD2C	2017-08-02 06:40:00+03	12600.00
BFBD34	2017-07-25 06:44:00+03	27800.00
BFBDB3	2017-07-18 19:38:00+03	246000.00
BFBE0D	2017-08-14 22:26:00+03	30800.00
BFBE44	2017-07-15 05:12:00+03	6000.00
BFBE51	2017-07-10 03:52:00+03	44000.00
BFBE77	2017-08-01 11:15:00+03	114400.00
BFBEE9	2017-07-28 08:16:00+03	88800.00
BFBF05	2017-07-14 14:05:00+03	91800.00
BFBF23	2017-07-30 14:41:00+03	43900.00
BFBF65	2017-07-28 09:01:00+03	24400.00
BFBF72	2017-07-31 20:31:00+03	86300.00
BFBF83	2017-08-15 00:22:00+03	161800.00
BFBF8E	2017-07-12 12:08:00+03	31400.00
BFC04B	2017-07-14 00:47:00+03	111600.00
BFC074	2017-08-13 12:05:00+03	155600.00
BFC0B8	2017-07-03 10:00:00+03	40000.00
BFC0CA	2017-07-13 23:31:00+03	86300.00
BFC0DC	2017-06-30 18:42:00+03	72200.00
BFC137	2017-07-16 13:20:00+03	16800.00
BFC157	2017-07-30 07:29:00+03	246000.00
BFC174	2017-07-04 08:11:00+03	173200.00
BFC1E0	2017-07-14 15:57:00+03	70200.00
BFC213	2017-08-02 08:58:00+03	68800.00
BFC22E	2017-06-29 19:48:00+03	393800.00
BFC266	2017-07-02 14:14:00+03	173600.00
BFC365	2017-06-29 07:01:00+03	69500.00
BFC375	2017-07-27 10:44:00+03	71100.00
BFC3A5	2017-07-13 21:07:00+03	48800.00
BFC3D1	2017-07-01 14:31:00+03	75600.00
BFC3D6	2017-07-24 02:24:00+03	55800.00
BFC3DA	2017-08-13 08:28:00+03	253300.00
BFC3F5	2017-07-13 20:14:00+03	173500.00
BFC4B7	2017-07-15 21:52:00+03	28800.00
BFC4EF	2017-07-24 17:09:00+03	25800.00
BFC531	2017-07-31 09:18:00+03	54100.00
BFC56F	2017-07-12 13:04:00+03	26000.00
BFC5AB	2017-07-04 14:38:00+03	21800.00
BFC5E7	2017-08-15 17:51:00+03	11300.00
BFC5EC	2017-07-22 19:14:00+03	13000.00
BFC66D	2017-08-07 16:40:00+03	265700.00
BFC675	2017-08-06 21:32:00+03	58100.00
BFC6A5	2017-08-08 04:58:00+03	6700.00
BFC6BA	2017-07-29 10:42:00+03	16400.00
BFC6DE	2017-07-20 04:56:00+03	30600.00
BFC6EE	2017-07-02 23:03:00+03	37500.00
BFC702	2017-07-13 08:33:00+03	84400.00
BFC714	2017-07-01 22:07:00+03	14800.00
BFC744	2017-08-06 07:34:00+03	46700.00
BFC759	2017-07-12 20:48:00+03	14800.00
BFC760	2017-07-10 10:47:00+03	41600.00
BFC807	2017-08-03 18:57:00+03	40800.00
BFC85E	2017-07-10 02:22:00+03	69500.00
BFC869	2017-07-31 05:39:00+03	24800.00
BFC8A6	2017-07-20 18:39:00+03	47000.00
BFC92E	2017-07-27 06:11:00+03	86400.00
BFC969	2017-08-12 22:36:00+03	120100.00
BFC997	2017-07-30 00:15:00+03	92800.00
BFC9DE	2017-08-12 23:38:00+03	208100.00
BFCA1F	2017-07-01 14:31:00+03	125700.00
BFCA5F	2017-07-17 03:13:00+03	112000.00
BFCAB3	2017-08-15 11:14:00+03	79800.00
BFCAF1	2017-07-24 11:05:00+03	67200.00
BFCB0F	2017-07-16 12:05:00+03	21800.00
BFCBBD	2017-07-04 08:53:00+03	170700.00
BFCBFB	2017-08-12 22:28:00+03	27900.00
BFCC04	2017-07-12 20:07:00+03	69000.00
BFCC15	2017-08-03 10:52:00+03	56000.00
BFCC17	2017-07-03 02:13:00+03	172500.00
BFCC6D	2017-07-13 21:17:00+03	8200.00
BFCC73	2017-08-14 11:31:00+03	13600.00
BFCCB9	2017-07-16 15:31:00+03	99300.00
BFCCC1	2017-08-06 12:03:00+03	18600.00
BFCCF5	2017-07-08 21:08:00+03	16400.00
BFCD0D	2017-07-09 18:57:00+03	134900.00
BFCD50	2017-07-13 05:07:00+03	26000.00
BFCD7C	2017-08-14 01:38:00+03	112000.00
BFCD80	2017-07-13 08:52:00+03	8400.00
BFCD83	2017-08-09 08:46:00+03	164700.00
BFCD93	2017-07-10 17:19:00+03	28800.00
BFCDD6	2017-08-13 02:06:00+03	13600.00
BFCE47	2017-07-06 21:52:00+03	28000.00
BFCECE	2017-07-04 05:38:00+03	69500.00
BFCF20	2017-08-10 06:39:00+03	22400.00
BFCF82	2017-08-13 13:38:00+03	42600.00
BFCF9D	2017-07-13 07:26:00+03	30700.00
BFCFBA	2017-07-06 05:48:00+03	21200.00
BFD004	2017-07-15 23:03:00+03	8400.00
BFD0FB	2017-08-05 09:42:00+03	61800.00
BFD109	2017-07-06 04:56:00+03	11600.00
BFD14B	2017-08-05 20:25:00+03	46400.00
BFD16C	2017-08-10 11:53:00+03	37200.00
BFD1A6	2017-07-22 13:12:00+03	44000.00
BFD1FE	2017-08-13 04:51:00+03	146300.00
BFD237	2017-07-24 08:34:00+03	27300.00
BFD23E	2017-08-13 10:53:00+03	134700.00
BFD250	2017-08-03 10:59:00+03	399600.00
BFD260	2017-08-13 22:15:00+03	26000.00
BFD28A	2017-07-16 13:47:00+03	26600.00
BFD28B	2017-08-08 06:33:00+03	117600.00
BFD411	2017-07-29 03:01:00+03	70600.00
BFD41D	2017-08-14 03:55:00+03	14000.00
BFD41F	2017-07-26 13:39:00+03	16400.00
BFD436	2017-07-14 19:40:00+03	77200.00
BFD4DF	2017-08-13 12:11:00+03	42600.00
BFD532	2017-08-05 18:05:00+03	67600.00
BFD580	2017-07-15 15:11:00+03	136800.00
BFD66B	2017-07-26 22:08:00+03	58800.00
BFD673	2017-07-28 08:07:00+03	131600.00
BFD789	2017-08-04 02:42:00+03	8200.00
BFD7D5	2017-07-06 01:21:00+03	120600.00
BFD7E2	2017-07-02 19:34:00+03	59200.00
BFD81E	2017-07-16 23:39:00+03	28000.00
BFD83B	2017-07-22 22:31:00+03	143300.00
BFD8D1	2017-07-06 19:17:00+03	271100.00
BFD90B	2017-08-10 08:29:00+03	275600.00
BFD90D	2017-07-03 01:31:00+03	40800.00
BFD913	2017-07-07 11:34:00+03	79800.00
BFD9C2	2017-08-09 00:42:00+03	48800.00
BFDA64	2017-07-31 11:12:00+03	63600.00
BFDAB0	2017-08-08 07:06:00+03	62300.00
BFDB1C	2017-07-12 13:39:00+03	70400.00
BFDB28	2017-07-20 09:36:00+03	102800.00
BFDB45	2017-07-25 04:17:00+03	59600.00
BFDB4D	2017-08-14 17:08:00+03	70100.00
BFDBE9	2017-07-27 14:51:00+03	36800.00
BFDCB7	2017-07-02 23:56:00+03	56000.00
BFDD15	2017-08-07 13:33:00+03	60800.00
BFDD24	2017-08-10 14:14:00+03	65800.00
BFDDD0	2017-08-13 15:35:00+03	26000.00
BFDEB0	2017-07-24 20:51:00+03	59000.00
BFDEF7	2017-07-25 10:51:00+03	29600.00
BFDF04	2017-07-14 09:17:00+03	66600.00
BFDF14	2017-07-09 01:11:00+03	112000.00
BFDF7D	2017-08-01 06:27:00+03	83000.00
BFDFB5	2017-08-14 05:22:00+03	92000.00
BFDFBC	2017-07-06 04:03:00+03	64600.00
BFE08C	2017-07-13 02:58:00+03	265600.00
BFE097	2017-07-17 09:40:00+03	55600.00
BFE0D3	2017-07-10 12:31:00+03	10800.00
BFE14D	2017-07-10 12:53:00+03	6700.00
BFE17E	2017-07-24 09:05:00+03	52000.00
BFE1B1	2017-07-14 22:51:00+03	43000.00
BFE1DB	2017-08-10 04:03:00+03	111600.00
BFE275	2017-08-03 13:45:00+03	38200.00
BFE2AB	2017-07-26 05:47:00+03	242800.00
BFE2E3	2017-07-11 02:09:00+03	65900.00
BFE33E	2017-07-10 11:46:00+03	37900.00
BFE381	2017-08-13 02:28:00+03	64700.00
BFE3DA	2017-07-21 15:14:00+03	71500.00
BFE41E	2017-07-24 12:03:00+03	24800.00
BFE438	2017-08-11 04:45:00+03	34100.00
BFE43F	2017-07-09 06:28:00+03	92800.00
BFE48D	2017-07-23 13:15:00+03	37800.00
BFE4BE	2017-08-13 22:40:00+03	61000.00
BFE4D4	2017-07-27 19:49:00+03	240600.00
BFE4F1	2017-06-26 21:18:00+03	47600.00
BFE50C	2017-07-08 18:29:00+03	32200.00
BFE59B	2017-07-25 02:22:00+03	16400.00
BFE5AE	2017-07-28 12:50:00+03	56000.00
BFE5FB	2017-07-26 11:20:00+03	76300.00
BFE6A3	2017-07-26 13:36:00+03	65500.00
BFE6DC	2017-07-17 00:28:00+03	179400.00
BFE6EB	2017-08-07 04:11:00+03	131100.00
BFE729	2017-08-12 22:14:00+03	96500.00
BFE79B	2017-07-11 17:10:00+03	133300.00
BFE7A5	2017-07-06 21:43:00+03	75300.00
BFE7E8	2017-08-10 09:13:00+03	117600.00
BFE86B	2017-07-03 19:55:00+03	75600.00
BFE8A5	2017-08-15 17:55:00+03	28500.00
BFE8B0	2017-08-15 07:49:00+03	199700.00
BFE8CD	2017-07-11 00:38:00+03	76800.00
BFE948	2017-08-02 04:58:00+03	38200.00
BFEA14	2017-08-12 14:26:00+03	26700.00
BFEB2C	2017-08-15 08:07:00+03	51900.00
BFEB40	2017-08-02 01:35:00+03	150600.00
BFEB5C	2017-07-26 04:19:00+03	56000.00
BFEC5D	2017-08-08 04:30:00+03	28000.00
BFECEA	2017-08-02 14:20:00+03	281500.00
BFED3C	2017-07-15 10:10:00+03	67700.00
BFED94	2017-07-19 11:37:00+03	8000.00
BFEDBD	2017-07-19 13:59:00+03	64800.00
BFEE53	2017-08-06 14:25:00+03	32700.00
BFEED9	2017-08-06 19:17:00+03	21400.00
BFEF0E	2017-08-05 03:16:00+03	16400.00
BFEF39	2017-07-17 13:48:00+03	114900.00
BFEFC4	2017-07-13 01:03:00+03	81600.00
BFEFE0	2017-07-21 12:40:00+03	23600.00
BFF00A	2017-07-10 01:34:00+03	202100.00
BFF089	2017-07-08 04:45:00+03	92400.00
BFF091	2017-08-12 09:54:00+03	136800.00
BFF0D8	2017-07-21 03:13:00+03	43600.00
BFF10E	2017-07-21 17:59:00+03	90700.00
BFF162	2017-08-15 04:31:00+03	78800.00
BFF29D	2017-08-10 09:10:00+03	92400.00
BFF2C6	2017-08-15 04:22:00+03	45200.00
BFF2CD	2017-07-11 09:34:00+03	135400.00
BFF36D	2017-07-22 08:13:00+03	55600.00
BFF386	2017-07-06 09:34:00+03	29000.00
BFF3B4	2017-07-27 19:54:00+03	187600.00
BFF3C7	2017-08-11 13:49:00+03	19600.00
BFF3DD	2017-08-02 01:29:00+03	40000.00
BFF400	2017-07-10 08:21:00+03	78800.00
BFF42C	2017-08-04 08:08:00+03	32800.00
BFF42E	2017-07-31 20:32:00+03	83600.00
BFF4ED	2017-07-12 17:13:00+03	57500.00
BFF504	2017-07-28 17:40:00+03	55800.00
BFF51F	2017-07-07 12:55:00+03	23600.00
BFF523	2017-07-25 05:33:00+03	62000.00
BFF55A	2017-07-08 10:46:00+03	105400.00
BFF55D	2017-07-11 18:07:00+03	86600.00
BFF5E3	2017-08-09 10:07:00+03	128000.00
BFF67F	2017-07-27 08:37:00+03	88800.00
BFF68B	2017-07-02 17:51:00+03	60400.00
BFF6DA	2017-07-29 02:11:00+03	80300.00
BFF6F4	2017-07-18 08:25:00+03	93900.00
BFF76A	2017-06-29 01:32:00+03	43400.00
BFF773	2017-07-27 23:37:00+03	32400.00
BFF775	2017-07-30 08:10:00+03	155600.00
BFF7C3	2017-07-22 02:49:00+03	19600.00
BFF818	2017-07-23 18:46:00+03	31100.00
BFF854	2017-07-14 01:57:00+03	111400.00
BFF882	2017-07-22 03:56:00+03	54800.00
BFF8C5	2017-07-24 02:24:00+03	243600.00
BFF93C	2017-07-15 16:20:00+03	142400.00
BFF9D2	2017-08-03 09:00:00+03	25600.00
BFF9EB	2017-07-07 22:32:00+03	40800.00
BFF9F1	2017-07-13 14:54:00+03	46400.00
BFF9FC	2017-07-16 04:19:00+03	11700.00
BFFA1E	2017-07-08 00:14:00+03	86600.00
BFFADF	2017-08-08 09:10:00+03	34000.00
BFFAFA	2017-08-02 22:18:00+03	37200.00
BFFB88	2017-07-08 18:36:00+03	36200.00
BFFBEE	2017-08-13 02:47:00+03	92100.00
BFFC7C	2017-08-11 04:22:00+03	25800.00
BFFC8F	2017-07-07 06:21:00+03	484300.00
BFFD03	2017-07-03 02:23:00+03	52700.00
BFFDA1	2017-07-01 19:06:00+03	18600.00
BFFDAE	2017-07-15 23:41:00+03	13400.00
BFFDD2	2017-07-10 03:02:00+03	93900.00
BFFDD8	2017-07-26 03:53:00+03	73500.00
BFFDE8	2017-08-09 06:11:00+03	14000.00
BFFE54	2017-07-03 12:53:00+03	102100.00
BFFEC7	2017-07-30 19:13:00+03	136500.00
BFFF44	2017-07-03 01:50:00+03	186200.00
BFFF5D	2017-06-30 14:53:00+03	195000.00
BFFFBD	2017-08-10 03:00:00+03	46300.00
C0001E	2017-07-01 19:12:00+03	166000.00
C00050	2017-08-06 17:47:00+03	94400.00
C00056	2017-08-15 17:50:00+03	149900.00
C0005C	2017-07-03 18:42:00+03	37200.00
C000E7	2017-07-23 06:50:00+03	131600.00
C0014D	2017-07-23 22:30:00+03	51200.00
C001CB	2017-08-02 17:07:00+03	26000.00
C001EE	2017-08-01 20:29:00+03	73300.00
C0022F	2017-07-23 09:34:00+03	23200.00
C0024B	2017-07-11 01:57:00+03	48400.00
C00289	2017-08-02 04:46:00+03	28000.00
C002E0	2017-08-04 14:28:00+03	28800.00
C002EC	2017-08-14 11:53:00+03	63200.00
C002F2	2017-07-23 18:48:00+03	19600.00
C002F4	2017-08-11 14:40:00+03	68800.00
C00316	2017-08-09 04:46:00+03	272300.00
C00329	2017-07-01 17:04:00+03	136200.00
C003E4	2017-08-09 23:45:00+03	28000.00
C003E5	2017-08-15 04:53:00+03	27700.00
C003EC	2017-07-23 22:57:00+03	25400.00
C00414	2017-08-14 05:31:00+03	8000.00
C0044E	2017-07-20 08:53:00+03	86600.00
C0045A	2017-06-30 13:13:00+03	98400.00
C00477	2017-07-07 05:49:00+03	112000.00
C00478	2017-07-16 15:27:00+03	70700.00
C00486	2017-07-25 16:17:00+03	57600.00
C00567	2017-08-14 12:06:00+03	36200.00
C0058B	2017-06-29 19:01:00+03	75800.00
C005A1	2017-07-25 12:08:00+03	36200.00
C005AB	2017-08-09 11:08:00+03	51900.00
C005B3	2017-07-10 09:14:00+03	133100.00
C00617	2017-07-19 00:33:00+03	192400.00
C0062E	2017-07-25 07:50:00+03	91500.00
C0068B	2017-08-12 04:27:00+03	266400.00
C006D2	2017-07-30 08:23:00+03	432900.00
C00751	2017-07-08 00:05:00+03	43800.00
C007A8	2017-08-14 07:36:00+03	255600.00
C00839	2017-08-08 18:02:00+03	28800.00
C00860	2017-07-07 06:56:00+03	128600.00
C00866	2017-07-14 19:34:00+03	114800.00
C008EF	2017-08-06 16:03:00+03	34000.00
C00906	2017-08-05 02:59:00+03	34000.00
C0091C	2017-08-15 01:21:00+03	67500.00
C00928	2017-07-02 17:03:00+03	28000.00
C0099F	2017-07-07 10:21:00+03	80200.00
C009B5	2017-07-05 16:03:00+03	67100.00
C00A1F	2017-07-22 16:22:00+03	164400.00
C00A3B	2017-06-30 08:13:00+03	70400.00
C00A5A	2017-07-04 22:37:00+03	129200.00
C00A6F	2017-07-24 15:17:00+03	282000.00
C00A86	2017-07-05 17:01:00+03	55800.00
C00A8F	2017-07-15 08:15:00+03	30600.00
C00A9D	2017-08-08 15:20:00+03	69700.00
C00ABB	2017-08-01 07:46:00+03	57800.00
C00AE2	2017-07-19 00:48:00+03	79600.00
C00AF4	2017-07-04 09:48:00+03	85000.00
C00B5F	2017-07-23 15:21:00+03	16400.00
C00BBA	2017-08-15 06:30:00+03	23300.00
C00BE6	2017-07-15 00:11:00+03	56000.00
C00CBB	2017-07-07 22:46:00+03	32800.00
C00CDA	2017-08-03 03:25:00+03	7400.00
C00D1A	2017-07-03 17:00:00+03	190000.00
C00D35	2017-07-14 14:55:00+03	111600.00
C00DC4	2017-07-27 08:41:00+03	92600.00
C00E77	2017-08-12 14:40:00+03	79800.00
C00E7F	2017-08-12 18:41:00+03	109800.00
C00EBF	2017-07-14 12:52:00+03	32700.00
C00ECA	2017-07-27 05:27:00+03	39300.00
C00ECB	2017-08-05 03:40:00+03	64800.00
C00FD3	2017-06-30 05:31:00+03	31400.00
C00FE5	2017-07-22 18:12:00+03	30700.00
C00FFC	2017-08-06 19:00:00+03	42400.00
C0102E	2017-08-15 10:52:00+03	206700.00
C01057	2017-08-11 01:20:00+03	46000.00
C01079	2017-07-26 05:22:00+03	67000.00
C010A0	2017-08-13 02:26:00+03	38400.00
C010B5	2017-08-09 12:49:00+03	56600.00
C0115E	2017-07-23 11:11:00+03	6000.00
C011BC	2017-07-18 20:02:00+03	68400.00
C011CD	2017-08-12 00:25:00+03	22000.00
C0121D	2017-08-13 12:59:00+03	98700.00
C01237	2017-07-24 07:44:00+03	14000.00
C01243	2017-07-13 09:09:00+03	25400.00
C0125A	2017-07-17 11:30:00+03	102300.00
C01260	2017-07-08 21:13:00+03	266400.00
C0126A	2017-08-09 12:07:00+03	20100.00
C01273	2017-08-14 08:58:00+03	28000.00
C01296	2017-08-10 19:01:00+03	89700.00
C01298	2017-07-15 20:50:00+03	135600.00
C012A3	2017-07-24 11:12:00+03	65500.00
C012C7	2017-08-12 21:33:00+03	270800.00
C01432	2017-08-03 08:29:00+03	98300.00
C01441	2017-07-13 00:25:00+03	55800.00
C01463	2017-07-09 19:40:00+03	97000.00
C01496	2017-08-07 17:04:00+03	67600.00
C014BB	2017-07-25 05:10:00+03	53400.00
C014F1	2017-07-27 07:55:00+03	136200.00
C01561	2017-08-01 08:00:00+03	133200.00
C01596	2017-07-05 23:42:00+03	31600.00
C015A0	2017-07-10 06:13:00+03	29200.00
C015DB	2017-07-31 14:52:00+03	94900.00
C0164A	2017-08-05 20:38:00+03	93800.00
C0164F	2017-07-22 05:56:00+03	47200.00
C016EA	2017-08-07 11:51:00+03	194700.00
C0170A	2017-08-03 04:53:00+03	77200.00
C01745	2017-08-04 15:45:00+03	57500.00
C01768	2017-07-20 21:36:00+03	40800.00
C01798	2017-08-13 20:14:00+03	25000.00
C017D0	2017-07-15 04:19:00+03	92800.00
C01815	2017-07-09 22:25:00+03	68000.00
C01849	2017-08-11 00:54:00+03	36800.00
C01886	2017-07-15 05:08:00+03	61800.00
C018D5	2017-07-22 08:17:00+03	92800.00
C018EF	2017-07-28 13:05:00+03	23200.00
C01990	2017-07-15 20:41:00+03	44500.00
C019B1	2017-07-20 05:04:00+03	258300.00
C019E2	2017-07-24 17:22:00+03	24700.00
C019F5	2017-07-20 20:11:00+03	43000.00
C019FD	2017-07-06 23:52:00+03	14000.00
C01A02	2017-06-30 15:31:00+03	85000.00
C01A62	2017-07-26 08:53:00+03	29300.00
C01A6A	2017-08-05 02:00:00+03	19600.00
C01A86	2017-08-07 20:16:00+03	59800.00
C01A91	2017-07-29 22:24:00+03	135400.00
C01ABC	2017-07-25 22:04:00+03	85600.00
C01AC5	2017-07-11 14:53:00+03	40800.00
C01AF3	2017-08-04 22:47:00+03	67600.00
C01B14	2017-08-04 17:36:00+03	178800.00
C01B4C	2017-08-15 10:47:00+03	246000.00
C01BDF	2017-08-11 05:38:00+03	95700.00
C01C52	2017-08-15 04:01:00+03	89600.00
C01C6E	2017-07-17 11:37:00+03	97600.00
C01CC1	2017-07-30 09:18:00+03	57500.00
C01D47	2017-07-14 12:25:00+03	38600.00
C01D89	2017-07-03 20:16:00+03	34000.00
C01DD5	2017-07-13 21:17:00+03	66000.00
C01DFA	2017-08-14 15:44:00+03	32200.00
C01E0A	2017-07-12 00:03:00+03	97600.00
C01E1E	2017-07-10 01:17:00+03	83000.00
C01E7F	2017-07-22 13:53:00+03	65600.00
C01E8F	2017-08-07 02:54:00+03	56000.00
C01E99	2017-08-07 08:40:00+03	21400.00
C01E9B	2017-07-02 16:02:00+03	62600.00
C01ED5	2017-07-04 19:19:00+03	96200.00
C01F0B	2017-07-17 19:12:00+03	32800.00
C01F57	2017-08-10 00:48:00+03	18600.00
C01F7D	2017-07-19 21:10:00+03	28000.00
C01FA6	2017-08-11 22:55:00+03	29400.00
C02048	2017-07-27 18:59:00+03	70600.00
C02093	2017-07-20 14:44:00+03	98200.00
C020E3	2017-06-29 07:13:00+03	59800.00
C020F5	2017-07-02 16:51:00+03	56000.00
C02153	2017-07-10 07:52:00+03	61700.00
C02164	2017-07-26 12:05:00+03	111600.00
C021A1	2017-08-07 23:11:00+03	92100.00
C021F4	2017-07-26 00:53:00+03	22000.00
C0223A	2017-07-30 00:08:00+03	19800.00
C02311	2017-07-03 14:19:00+03	91600.00
C02364	2017-08-12 05:34:00+03	28200.00
C0236B	2017-07-04 07:52:00+03	59800.00
C023E2	2017-07-24 16:46:00+03	135600.00
C0244D	2017-07-11 23:00:00+03	28800.00
C0244F	2017-07-05 23:51:00+03	135600.00
C02492	2017-07-27 05:50:00+03	29600.00
C024A9	2017-08-07 08:41:00+03	260900.00
C024B5	2017-07-19 16:00:00+03	56000.00
C024EB	2017-07-06 06:35:00+03	36200.00
C024FA	2017-06-29 15:41:00+03	139500.00
C0253C	2017-07-21 02:44:00+03	140800.00
C0256B	2017-07-19 20:21:00+03	52800.00
C02571	2017-07-11 10:46:00+03	55800.00
C025A0	2017-07-20 06:30:00+03	136500.00
C0263B	2017-07-27 16:06:00+03	55800.00
C02655	2017-07-07 22:01:00+03	159800.00
C02684	2017-07-07 22:09:00+03	273600.00
C026BF	2017-07-08 03:14:00+03	66600.00
C0271F	2017-08-10 19:21:00+03	37900.00
C02723	2017-07-21 07:37:00+03	34000.00
C0287C	2017-07-23 04:58:00+03	88000.00
C028AE	2017-07-28 03:20:00+03	79600.00
C028C4	2017-08-12 17:06:00+03	27900.00
C02975	2017-07-08 08:04:00+03	62600.00
C029BA	2017-08-02 13:22:00+03	22600.00
C029F0	2017-07-15 00:58:00+03	56000.00
C02B02	2017-07-30 13:38:00+03	145300.00
C02B2B	2017-08-14 20:44:00+03	109200.00
C02B7E	2017-07-24 10:49:00+03	88600.00
C02BF1	2017-08-07 01:25:00+03	68800.00
C02BFA	2017-08-07 19:02:00+03	33400.00
C02C0D	2017-07-16 08:29:00+03	54000.00
C02C12	2017-07-01 23:36:00+03	90700.00
C02C86	2017-08-09 19:12:00+03	71800.00
C02CE0	2017-08-14 22:27:00+03	79800.00
C02D86	2017-07-10 10:39:00+03	26800.00
C02D9F	2017-07-23 04:19:00+03	55800.00
C02DAD	2017-08-03 02:50:00+03	20600.00
C02DB2	2017-08-04 12:14:00+03	43500.00
C02E19	2017-08-12 02:48:00+03	76800.00
C02E98	2017-07-28 17:47:00+03	46000.00
C02EB0	2017-07-11 23:02:00+03	26200.00
C02EB4	2017-08-15 01:30:00+03	92800.00
C02EBD	2017-07-31 13:11:00+03	199800.00
C02EC1	2017-08-07 23:50:00+03	62700.00
C02F2A	2017-08-09 12:16:00+03	44000.00
C02F3B	2017-08-14 04:23:00+03	59300.00
C02FB1	2017-07-17 07:27:00+03	26200.00
C02FE0	2017-07-13 19:43:00+03	46500.00
C02FE5	2017-08-09 02:36:00+03	272300.00
C0301A	2017-08-13 15:08:00+03	28700.00
C03092	2017-07-19 15:15:00+03	85400.00
C030BC	2017-07-26 14:31:00+03	99200.00
C030C8	2017-08-10 14:35:00+03	57600.00
C030CD	2017-08-10 03:51:00+03	137800.00
C0314C	2017-08-07 02:37:00+03	52000.00
C0314D	2017-07-07 08:30:00+03	46400.00
C03163	2017-07-25 05:16:00+03	13600.00
C0318D	2017-08-04 22:48:00+03	62900.00
C03199	2017-07-25 04:08:00+03	8800.00
C031FF	2017-08-01 14:04:00+03	293400.00
C03201	2017-07-13 00:30:00+03	35200.00
C0323D	2017-07-29 20:53:00+03	39400.00
C0329A	2017-08-09 07:05:00+03	27400.00
C032B0	2017-08-10 16:42:00+03	62600.00
C0331D	2017-07-08 09:05:00+03	52100.00
C0341C	2017-06-28 17:20:00+03	46000.00
C0342C	2017-07-19 20:27:00+03	27800.00
C03460	2017-07-18 11:06:00+03	76300.00
C03532	2017-08-01 05:31:00+03	52800.00
C035CB	2017-07-03 12:55:00+03	16400.00
C0364E	2017-08-01 03:37:00+03	86300.00
C0365C	2017-06-27 14:30:00+03	56000.00
C0366D	2017-07-17 18:12:00+03	172100.00
C03688	2017-07-24 20:09:00+03	174000.00
C03691	2017-08-08 05:11:00+03	23200.00
C036A7	2017-08-06 03:48:00+03	130000.00
C036B2	2017-08-07 00:06:00+03	112200.00
C03741	2017-07-15 06:57:00+03	65500.00
C037C5	2017-07-03 06:55:00+03	26200.00
C037D2	2017-07-06 20:56:00+03	12600.00
C0385A	2017-07-24 09:49:00+03	132800.00
C03885	2017-07-11 12:33:00+03	53400.00
C038DE	2017-07-05 20:47:00+03	114800.00
C0394A	2017-07-15 00:56:00+03	24400.00
C03963	2017-07-18 20:29:00+03	105600.00
C03992	2017-07-23 21:05:00+03	56900.00
C039AC	2017-07-24 22:08:00+03	110500.00
C039C6	2017-07-02 01:17:00+03	13000.00
C03AC1	2017-07-27 05:48:00+03	167400.00
C03ADA	2017-07-08 19:35:00+03	67100.00
C03ADC	2017-07-12 12:00:00+03	43200.00
C03AFD	2017-08-13 18:34:00+03	23200.00
C03B25	2017-08-09 10:25:00+03	144400.00
C03BC3	2017-08-07 00:17:00+03	44700.00
C03C6F	2017-08-11 05:06:00+03	40300.00
C03C72	2017-08-04 11:00:00+03	130900.00
C03C99	2017-07-01 09:33:00+03	35200.00
C03CBE	2017-08-12 08:28:00+03	12400.00
C03CC1	2017-07-13 02:08:00+03	529100.00
C03CCF	2017-07-26 13:21:00+03	92600.00
C03D1B	2017-08-06 08:59:00+03	202400.00
C03DB6	2017-07-19 13:48:00+03	102100.00
C03DC8	2017-07-26 18:52:00+03	95200.00
C03E2C	2017-08-06 05:14:00+03	38600.00
C03E99	2017-07-18 04:38:00+03	56000.00
C03EC5	2017-07-20 21:29:00+03	86500.00
C03ED3	2017-07-27 19:52:00+03	277800.00
C03EDD	2017-08-09 23:49:00+03	12400.00
C03EF0	2017-07-11 21:07:00+03	43200.00
C03F1F	2017-07-19 21:49:00+03	23400.00
C03F3C	2017-08-10 03:10:00+03	59000.00
C04009	2017-07-06 15:25:00+03	168000.00
C040CF	2017-08-05 02:28:00+03	93900.00
C04180	2017-07-22 16:08:00+03	70800.00
C041CB	2017-07-24 00:37:00+03	18200.00
C041D5	2017-07-18 02:36:00+03	42800.00
C04246	2017-08-05 20:33:00+03	40800.00
C042AC	2017-08-14 01:12:00+03	113300.00
C04321	2017-08-05 05:51:00+03	38400.00
C0434D	2017-07-23 20:31:00+03	103500.00
C0435C	2017-07-21 09:07:00+03	28000.00
C04365	2017-07-06 08:38:00+03	29600.00
C0437D	2017-07-03 19:24:00+03	78100.00
C043B7	2017-08-15 12:04:00+03	113300.00
C0442A	2017-07-25 14:59:00+03	147000.00
C0443D	2017-07-26 03:29:00+03	26000.00
C04468	2017-07-25 17:22:00+03	24400.00
C0448B	2017-07-11 09:56:00+03	6800.00
C044E6	2017-08-03 00:08:00+03	133200.00
C044F2	2017-07-26 01:18:00+03	23200.00
C0450D	2017-07-05 13:28:00+03	9200.00
C04523	2017-08-11 20:31:00+03	9800.00
C0459B	2017-07-29 01:29:00+03	22000.00
C045BC	2017-08-11 22:28:00+03	25200.00
C045F3	2017-08-10 09:00:00+03	136200.00
C0463E	2017-07-04 11:33:00+03	15400.00
C04692	2017-08-12 08:40:00+03	88400.00
C04697	2017-07-21 17:59:00+03	51800.00
C04718	2017-07-13 20:40:00+03	111600.00
C0473E	2017-07-20 00:58:00+03	92100.00
C04764	2017-07-18 18:07:00+03	12400.00
C047BE	2017-07-22 23:03:00+03	31700.00
C047E6	2017-07-14 03:22:00+03	103800.00
C04826	2017-07-25 06:57:00+03	117200.00
C0483B	2017-08-03 20:53:00+03	28000.00
C04885	2017-07-04 06:35:00+03	86500.00
C048B0	2017-08-05 04:18:00+03	46500.00
C048B9	2017-08-14 08:44:00+03	24700.00
C04901	2017-08-04 18:44:00+03	130400.00
C04A2F	2017-07-24 04:11:00+03	45400.00
C04A44	2017-07-09 07:34:00+03	33300.00
C04AA4	2017-07-10 19:02:00+03	149200.00
C04AB6	2017-08-08 14:21:00+03	16400.00
C04AE4	2017-07-10 22:21:00+03	94000.00
C04AE5	2017-07-12 18:18:00+03	90400.00
C04B45	2017-07-31 19:59:00+03	28800.00
C04B8D	2017-08-09 15:44:00+03	105100.00
C04BE0	2017-06-29 14:57:00+03	202700.00
C04C05	2017-07-14 18:42:00+03	139400.00
C04C0D	2017-07-22 10:47:00+03	134800.00
C04C22	2017-08-07 16:45:00+03	19600.00
C04C38	2017-07-25 17:15:00+03	278400.00
C04C67	2017-07-31 12:18:00+03	40000.00
C04D26	2017-07-07 05:44:00+03	58200.00
C04D34	2017-07-15 21:52:00+03	74700.00
C04D6B	2017-07-03 17:49:00+03	40000.00
C04DBE	2017-08-04 21:06:00+03	67200.00
C04DC9	2017-07-06 07:41:00+03	34400.00
C04DDA	2017-07-10 11:21:00+03	271200.00
C04E27	2017-07-04 00:08:00+03	7200.00
C04E5F	2017-07-31 13:41:00+03	200800.00
C04E8A	2017-08-02 10:24:00+03	30600.00
C04E9E	2017-08-08 16:09:00+03	18100.00
C04EA2	2017-08-10 04:14:00+03	26000.00
C04EAD	2017-07-05 01:39:00+03	62800.00
C04EBB	2017-07-21 10:02:00+03	14400.00
C04EBF	2017-07-14 21:59:00+03	95900.00
C04EC1	2017-08-12 07:34:00+03	206200.00
C04EDD	2017-08-15 17:11:00+03	106400.00
C04EED	2017-07-21 00:07:00+03	135600.00
C04F6D	2017-08-09 22:50:00+03	22000.00
C04FC8	2017-08-11 10:20:00+03	67000.00
C05010	2017-07-28 14:43:00+03	28800.00
C05061	2017-07-04 19:56:00+03	413400.00
C05079	2017-07-25 12:34:00+03	179300.00
C05126	2017-07-19 19:35:00+03	47200.00
C051F7	2017-07-28 11:45:00+03	70100.00
C05206	2017-07-09 10:22:00+03	56000.00
C05251	2017-07-25 09:59:00+03	36200.00
C052A2	2017-08-13 20:33:00+03	41600.00
C052A3	2017-08-14 23:17:00+03	26100.00
C052DB	2017-07-17 19:14:00+03	7400.00
C0531D	2017-07-13 14:25:00+03	70600.00
C05362	2017-07-30 14:45:00+03	82900.00
C0537C	2017-08-14 03:48:00+03	43900.00
C0538D	2017-08-14 08:36:00+03	167400.00
C05402	2017-07-29 02:50:00+03	27200.00
C0540C	2017-07-24 14:43:00+03	245500.00
C05427	2017-08-13 01:48:00+03	35600.00
C05447	2017-07-25 13:55:00+03	56000.00
C0547B	2017-07-29 16:48:00+03	26800.00
C05665	2017-07-06 14:24:00+03	105500.00
C05752	2017-07-27 06:08:00+03	246000.00
C0578C	2017-07-06 23:55:00+03	65800.00
C057BE	2017-08-02 09:01:00+03	181600.00
C057D2	2017-08-12 08:48:00+03	25000.00
C0580C	2017-08-05 20:25:00+03	223200.00
C05810	2017-07-09 21:36:00+03	38500.00
C0582D	2017-07-28 22:51:00+03	28800.00
C05892	2017-08-11 00:49:00+03	56100.00
C058AF	2017-08-12 17:23:00+03	27800.00
C058C3	2017-07-14 06:47:00+03	200300.00
C058E0	2017-08-03 10:25:00+03	40800.00
C058F9	2017-06-30 06:19:00+03	62000.00
C05913	2017-07-14 15:27:00+03	44800.00
C05959	2017-07-30 08:32:00+03	294200.00
C05960	2017-08-10 18:22:00+03	61200.00
C05961	2017-08-14 20:07:00+03	14000.00
C059C4	2017-07-12 02:25:00+03	20000.00
C059CE	2017-07-12 10:02:00+03	59100.00
C059F1	2017-07-06 10:47:00+03	88600.00
C05A77	2017-08-13 16:57:00+03	59000.00
C05A97	2017-08-09 01:40:00+03	68000.00
C05A9D	2017-07-30 02:26:00+03	12000.00
C05AC1	2017-07-16 12:39:00+03	11800.00
C05BAE	2017-08-14 04:36:00+03	76400.00
C05BC2	2017-07-17 01:47:00+03	85600.00
C05BD9	2017-08-12 20:38:00+03	70800.00
C05BE9	2017-08-03 23:57:00+03	48300.00
C05C5F	2017-07-25 18:15:00+03	40400.00
C05CEC	2017-07-02 05:37:00+03	306200.00
C05DC8	2017-07-13 04:01:00+03	56100.00
C05E11	2017-07-19 05:24:00+03	67200.00
C05EA1	2017-07-21 00:55:00+03	49200.00
C05EC7	2017-08-07 20:56:00+03	46300.00
C05F83	2017-07-14 02:25:00+03	19600.00
C05FA8	2017-07-29 06:31:00+03	67200.00
C05FB1	2017-08-07 04:45:00+03	62700.00
C05FCC	2017-08-12 10:24:00+03	30400.00
C05FE6	2017-07-10 10:24:00+03	56000.00
C05FFD	2017-07-09 17:18:00+03	49900.00
C06105	2017-08-11 16:06:00+03	136200.00
C06122	2017-08-03 03:04:00+03	67400.00
C06180	2017-08-07 15:19:00+03	93900.00
C0618E	2017-07-17 16:43:00+03	96300.00
C061BC	2017-08-15 05:52:00+03	56100.00
C061ED	2017-07-02 11:01:00+03	86300.00
C0620B	2017-08-01 20:10:00+03	260300.00
C06226	2017-07-20 20:28:00+03	56000.00
C06296	2017-07-21 14:56:00+03	396500.00
C062C3	2017-07-18 14:01:00+03	6000.00
C0631C	2017-07-02 20:08:00+03	61800.00
C0633E	2017-07-05 06:00:00+03	77400.00
C06362	2017-07-11 10:33:00+03	50800.00
C0639E	2017-07-11 23:59:00+03	66600.00
C063E0	2017-08-01 20:47:00+03	40000.00
C063E8	2017-08-11 05:09:00+03	125400.00
C063EF	2017-07-08 09:39:00+03	58600.00
C063F6	2017-07-15 18:04:00+03	26800.00
C063F8	2017-06-29 14:19:00+03	3700.00
C064C6	2017-07-09 23:35:00+03	36200.00
C06560	2017-07-18 15:45:00+03	29200.00
C0659E	2017-08-06 15:01:00+03	298500.00
C065BB	2017-08-13 02:13:00+03	25400.00
C065BD	2017-08-15 12:11:00+03	70500.00
C06602	2017-07-26 00:39:00+03	12600.00
C06639	2017-08-09 08:09:00+03	46000.00
C066CA	2017-08-15 02:18:00+03	52000.00
C066FD	2017-07-04 05:49:00+03	50800.00
C06739	2017-08-14 17:20:00+03	6700.00
C0673A	2017-08-01 10:44:00+03	23200.00
C06747	2017-07-25 12:36:00+03	135400.00
C0678E	2017-08-05 02:48:00+03	186900.00
C067FA	2017-07-31 23:06:00+03	22000.00
C067FF	2017-07-25 23:59:00+03	6000.00
C068C5	2017-07-07 20:46:00+03	18000.00
C0690F	2017-07-11 09:25:00+03	59300.00
C0697C	2017-07-27 02:16:00+03	142800.00
C0698F	2017-07-10 05:30:00+03	138000.00
C069A4	2017-07-17 10:32:00+03	68800.00
C06ABD	2017-07-08 06:44:00+03	19600.00
C06BBD	2017-08-06 22:54:00+03	24400.00
C06BF3	2017-07-08 10:20:00+03	49800.00
C06C45	2017-07-20 08:38:00+03	45300.00
C06C7C	2017-08-12 06:21:00+03	66000.00
C06CB7	2017-08-10 06:51:00+03	85700.00
C06CBE	2017-07-15 14:37:00+03	44800.00
C06CD2	2017-07-03 01:37:00+03	45100.00
C06DBD	2017-08-06 13:02:00+03	96800.00
C06DC0	2017-07-12 22:23:00+03	40200.00
C06DEB	2017-07-22 16:01:00+03	46000.00
C06DF7	2017-07-11 17:33:00+03	32800.00
C06DFC	2017-06-26 03:00:00+03	42800.00
C06E51	2017-07-31 23:38:00+03	59300.00
C06E6A	2017-07-01 23:57:00+03	28800.00
C06E6E	2017-07-28 20:45:00+03	66100.00
C06EFA	2017-07-31 06:05:00+03	120100.00
C06F27	2017-08-06 02:58:00+03	86600.00
C06FB2	2017-07-03 19:11:00+03	48800.00
C06FD7	2017-07-07 19:19:00+03	134700.00
C06FDE	2017-07-30 22:20:00+03	111700.00
C06FF0	2017-07-01 05:02:00+03	49600.00
C07003	2017-07-06 22:39:00+03	88900.00
C07080	2017-08-01 13:17:00+03	20000.00
C070A2	2017-07-26 12:17:00+03	14800.00
C071A6	2017-08-11 22:26:00+03	286600.00
C071D9	2017-08-04 21:36:00+03	55800.00
C071EE	2017-07-23 01:59:00+03	118100.00
C07233	2017-07-10 17:43:00+03	71300.00
C07282	2017-07-02 17:30:00+03	26800.00
C072D6	2017-07-07 17:33:00+03	111000.00
C072F0	2017-08-07 20:33:00+03	6700.00
C07301	2017-07-18 17:42:00+03	34000.00
C0731F	2017-07-26 09:26:00+03	111600.00
C07374	2017-08-07 21:23:00+03	55800.00
C073A2	2017-07-12 02:19:00+03	35200.00
C07424	2017-07-09 05:58:00+03	170000.00
C074B2	2017-07-17 04:38:00+03	48800.00
C07544	2017-07-31 22:13:00+03	80000.00
C07554	2017-07-26 17:12:00+03	65600.00
C075A8	2017-07-19 16:08:00+03	56100.00
C075D5	2017-07-30 11:16:00+03	47000.00
C075F7	2017-08-07 04:49:00+03	87200.00
C07603	2017-07-31 12:42:00+03	38400.00
C0768F	2017-07-22 20:34:00+03	21200.00
C076A5	2017-08-07 22:43:00+03	369000.00
C076D9	2017-08-07 08:54:00+03	178800.00
C076FC	2017-07-23 12:45:00+03	181100.00
C077A1	2017-07-15 04:12:00+03	85700.00
C077EA	2017-07-04 18:58:00+03	34100.00
C0788B	2017-07-07 08:38:00+03	369000.00
C07898	2017-07-04 18:07:00+03	25100.00
C078CD	2017-07-04 11:44:00+03	56000.00
C07913	2017-07-25 22:14:00+03	75300.00
C0792B	2017-07-24 22:36:00+03	114800.00
C0795D	2017-07-21 16:59:00+03	46400.00
C07965	2017-08-07 03:35:00+03	96200.00
C07A4B	2017-07-21 04:29:00+03	103700.00
C07A6D	2017-07-27 00:49:00+03	55800.00
C07AB1	2017-08-04 15:14:00+03	94200.00
C07B09	2017-07-30 23:17:00+03	103600.00
C07BE6	2017-08-11 16:40:00+03	100600.00
C07C01	2017-07-20 06:02:00+03	20400.00
C07C8C	2017-07-05 18:04:00+03	89600.00
C07D0B	2017-07-03 18:45:00+03	21400.00
C07E0E	2017-08-14 01:52:00+03	166900.00
C07E3B	2017-07-11 17:33:00+03	131200.00
C07E51	2017-07-23 15:29:00+03	40800.00
C07E66	2017-07-08 20:26:00+03	27800.00
C07EDE	2017-07-13 22:39:00+03	25400.00
C07EEF	2017-08-04 09:55:00+03	43200.00
C07F4F	2017-08-15 06:08:00+03	100200.00
C07F88	2017-08-13 14:12:00+03	42800.00
C07F9F	2017-08-13 12:14:00+03	29600.00
C07FDD	2017-07-17 02:48:00+03	109800.00
C08004	2017-08-02 18:30:00+03	30000.00
C08019	2017-07-16 03:26:00+03	65900.00
C08030	2017-07-30 21:06:00+03	20800.00
C0803E	2017-07-30 22:48:00+03	86800.00
C0810C	2017-07-15 17:19:00+03	48800.00
C08136	2017-08-12 06:22:00+03	38200.00
C081BA	2017-08-03 14:46:00+03	21600.00
C081D9	2017-07-31 10:50:00+03	28800.00
C082C8	2017-07-10 21:38:00+03	23600.00
C082D1	2017-08-01 15:08:00+03	27400.00
C083DA	2017-07-28 21:18:00+03	14400.00
C083E3	2017-08-08 15:32:00+03	50000.00
C08418	2017-07-17 03:12:00+03	111600.00
C0843B	2017-08-04 17:00:00+03	46800.00
C0846B	2017-07-25 17:58:00+03	92100.00
C08495	2017-07-25 18:05:00+03	15400.00
C084B6	2017-07-29 14:56:00+03	55800.00
C0852A	2017-08-06 01:43:00+03	158000.00
C0854E	2017-08-04 20:25:00+03	41600.00
C08563	2017-07-05 04:16:00+03	26700.00
C0856E	2017-08-13 06:24:00+03	117500.00
C085CA	2017-07-15 23:52:00+03	88400.00
C08635	2017-07-21 20:15:00+03	77900.00
C0864F	2017-08-12 06:17:00+03	37600.00
C086DF	2017-07-04 13:45:00+03	273400.00
C0872E	2017-08-02 20:43:00+03	39800.00
C08733	2017-08-09 09:23:00+03	306200.00
C0873B	2017-08-14 00:31:00+03	88800.00
C0873C	2017-08-13 07:07:00+03	29600.00
C08750	2017-07-30 14:36:00+03	302400.00
C08767	2017-08-13 12:28:00+03	19600.00
C08809	2017-07-03 03:02:00+03	77900.00
C08839	2017-07-18 03:32:00+03	19600.00
C0885C	2017-08-07 06:30:00+03	50100.00
C08864	2017-07-19 03:12:00+03	28700.00
C08879	2017-07-27 15:16:00+03	23600.00
C088C2	2017-07-27 06:37:00+03	43900.00
C08951	2017-07-01 16:07:00+03	68800.00
C089B1	2017-07-15 15:54:00+03	14000.00
C08A25	2017-07-22 02:05:00+03	84000.00
C08B24	2017-07-11 13:32:00+03	40800.00
C08B89	2017-07-21 11:36:00+03	31400.00
C08BE0	2017-07-05 14:30:00+03	8400.00
C08C0E	2017-07-22 10:55:00+03	32700.00
C08C50	2017-07-20 04:50:00+03	137600.00
C08C95	2017-07-12 00:29:00+03	92700.00
C08CDC	2017-07-04 11:10:00+03	64600.00
C08D21	2017-08-14 17:01:00+03	199700.00
C08D2F	2017-07-28 19:52:00+03	28000.00
C08D42	2017-07-07 10:24:00+03	39500.00
C08D47	2017-07-12 20:35:00+03	31600.00
C08D52	2017-07-18 15:48:00+03	44000.00
C08DBA	2017-08-05 13:29:00+03	13200.00
C08E59	2017-07-22 15:41:00+03	170400.00
C08EA3	2017-08-10 19:48:00+03	681400.00
C08ED5	2017-07-22 01:57:00+03	38800.00
C08F5F	2017-07-24 18:23:00+03	73200.00
C08F7E	2017-07-05 18:39:00+03	29600.00
C08FA3	2017-07-04 04:00:00+03	103500.00
C08FD9	2017-07-05 05:54:00+03	56900.00
C08FFB	2017-08-03 19:43:00+03	56100.00
C09049	2017-07-22 01:59:00+03	204500.00
C0907D	2017-08-13 22:01:00+03	283100.00
C090D1	2017-07-05 22:07:00+03	11800.00
C09109	2017-07-08 13:04:00+03	97500.00
C09159	2017-08-06 05:10:00+03	55600.00
C091A6	2017-07-23 02:29:00+03	4000.00
C091E4	2017-07-11 16:45:00+03	94000.00
C09265	2017-07-06 02:58:00+03	16800.00
C09328	2017-07-03 22:58:00+03	25400.00
C0934F	2017-08-14 23:40:00+03	77900.00
C09360	2017-07-27 10:39:00+03	21800.00
C093CB	2017-07-13 13:23:00+03	17000.00
C09449	2017-07-04 09:42:00+03	111600.00
C0944B	2017-07-23 07:25:00+03	23400.00
C09493	2017-08-03 17:40:00+03	47100.00
C094EE	2017-06-30 18:45:00+03	185600.00
C0953A	2017-08-11 12:53:00+03	103200.00
C09545	2017-08-14 18:09:00+03	31800.00
C095B6	2017-07-18 12:08:00+03	127200.00
C095DF	2017-08-08 00:49:00+03	35600.00
C0960E	2017-07-28 13:29:00+03	70600.00
C09670	2017-07-19 13:00:00+03	35200.00
C09684	2017-08-06 14:24:00+03	28000.00
C097AF	2017-08-10 16:33:00+03	272300.00
C09804	2017-07-03 18:12:00+03	152500.00
C09812	2017-07-23 16:40:00+03	14400.00
C098B7	2017-08-10 08:11:00+03	84000.00
C09925	2017-07-16 13:04:00+03	44000.00
C0994C	2017-07-04 20:00:00+03	55800.00
C0996A	2017-07-11 19:30:00+03	86400.00
C09A05	2017-07-30 04:34:00+03	59800.00
C09A35	2017-08-04 05:16:00+03	22200.00
C09A7E	2017-07-08 20:10:00+03	46000.00
C09AA5	2017-08-11 14:46:00+03	25800.00
C09AED	2017-08-11 02:37:00+03	68700.00
C09B70	2017-07-24 09:51:00+03	58600.00
C09B83	2017-07-13 22:55:00+03	21800.00
C09BE1	2017-07-07 09:43:00+03	75600.00
C09BEF	2017-07-02 09:51:00+03	384000.00
C09C25	2017-08-13 04:23:00+03	105400.00
C09C67	2017-07-10 18:21:00+03	41200.00
C09CD7	2017-08-11 14:36:00+03	20400.00
C09DA7	2017-07-17 22:00:00+03	28800.00
C09DD7	2017-07-22 10:36:00+03	14400.00
C09DF5	2017-08-03 09:28:00+03	130400.00
C09E07	2017-06-29 20:14:00+03	32200.00
C09E8F	2017-08-05 01:46:00+03	23100.00
C09E93	2017-07-22 15:18:00+03	24400.00
C09F01	2017-07-20 19:45:00+03	8200.00
C09F15	2017-07-15 23:17:00+03	141600.00
C09F3B	2017-07-18 17:12:00+03	29600.00
C09F89	2017-07-23 21:10:00+03	64800.00
C09FA0	2017-07-30 07:27:00+03	121400.00
C09FA4	2017-08-01 04:52:00+03	99200.00
C09FC7	2017-07-01 19:41:00+03	26000.00
C09FE5	2017-07-09 18:38:00+03	34000.00
C0A038	2017-07-15 02:40:00+03	11600.00
C0A0A9	2017-08-11 18:08:00+03	225800.00
C0A0CE	2017-08-04 02:44:00+03	12400.00
C0A0E0	2017-07-13 13:35:00+03	75300.00
C0A0EA	2017-08-05 08:21:00+03	145900.00
C0A158	2017-08-10 05:45:00+03	71600.00
C0A1CC	2017-08-13 17:34:00+03	56000.00
C0A1CD	2017-07-27 15:43:00+03	28800.00
C0A1D1	2017-08-08 17:47:00+03	146600.00
C0A207	2017-07-24 10:58:00+03	45200.00
C0A224	2017-08-15 17:22:00+03	28000.00
C0A321	2017-07-26 22:58:00+03	73600.00
C0A366	2017-07-24 13:28:00+03	26000.00
C0A3C3	2017-07-16 20:14:00+03	52200.00
C0A3D9	2017-07-15 18:29:00+03	12600.00
C0A57B	2017-07-09 22:09:00+03	75800.00
C0A62A	2017-07-27 20:17:00+03	31100.00
C0A638	2017-08-01 08:40:00+03	26000.00
C0A6A3	2017-08-13 00:36:00+03	56900.00
C0A709	2017-07-20 03:21:00+03	28000.00
C0A70B	2017-07-07 12:27:00+03	31100.00
C0A710	2017-08-12 22:14:00+03	67700.00
C0A711	2017-08-12 05:50:00+03	40600.00
C0A72A	2017-07-13 03:17:00+03	79600.00
C0A77E	2017-06-29 03:13:00+03	11700.00
C0A7A8	2017-07-03 18:20:00+03	26800.00
C0A7BC	2017-08-08 00:40:00+03	23200.00
C0A7C2	2017-08-06 19:05:00+03	50000.00
C0A801	2017-08-05 13:25:00+03	13400.00
C0A813	2017-07-26 00:35:00+03	13400.00
C0A82C	2017-08-07 19:14:00+03	29100.00
C0A836	2017-08-14 04:09:00+03	46400.00
C0A8B6	2017-07-09 12:35:00+03	23200.00
C0A8C9	2017-07-22 14:58:00+03	92800.00
C0A98D	2017-07-30 09:01:00+03	26100.00
C0A9F2	2017-08-02 18:48:00+03	167400.00
C0A9F9	2017-08-02 02:02:00+03	40700.00
C0AA02	2017-08-14 01:02:00+03	47000.00
C0AA73	2017-08-11 15:15:00+03	55400.00
C0AA9C	2017-07-28 14:20:00+03	86600.00
C0AABB	2017-08-11 19:53:00+03	23400.00
C0AADA	2017-08-15 05:18:00+03	186200.00
C0ABB7	2017-08-05 07:36:00+03	8200.00
C0ABE1	2017-07-10 22:12:00+03	155300.00
C0AD04	2017-08-14 21:49:00+03	26800.00
C0AD08	2017-07-18 12:23:00+03	124200.00
C0AD12	2017-07-26 23:47:00+03	479600.00
C0AD55	2017-07-05 13:10:00+03	112000.00
C0ADDB	2017-06-30 01:43:00+03	23200.00
C0ADF1	2017-08-08 14:33:00+03	14000.00
C0AE03	2017-07-17 04:45:00+03	6000.00
C0AE05	2017-08-01 19:35:00+03	70700.00
C0AF92	2017-07-31 20:11:00+03	44000.00
C0AFDD	2017-07-26 19:19:00+03	26000.00
C0B03C	2017-07-02 00:39:00+03	291600.00
C0B03D	2017-07-14 07:30:00+03	66600.00
C0B0AC	2017-08-11 13:55:00+03	55800.00
C0B0E5	2017-07-03 13:34:00+03	103700.00
C0B0F0	2017-08-03 12:52:00+03	13400.00
C0B152	2017-07-21 04:35:00+03	19600.00
C0B155	2017-08-08 04:41:00+03	27200.00
C0B15A	2017-08-07 22:26:00+03	40000.00
C0B16A	2017-07-20 04:16:00+03	100600.00
C0B194	2017-08-10 01:42:00+03	46200.00
C0B1A4	2017-07-14 06:45:00+03	259500.00
C0B22A	2017-08-02 06:49:00+03	138000.00
C0B2AF	2017-07-23 02:51:00+03	24000.00
C0B2E6	2017-08-11 01:44:00+03	100600.00
C0B30B	2017-07-21 15:48:00+03	21800.00
C0B312	2017-06-30 14:10:00+03	49100.00
C0B350	2017-08-11 15:56:00+03	142400.00
C0B3CD	2017-07-24 04:10:00+03	170500.00
C0B3EA	2017-07-13 01:09:00+03	40600.00
C0B40D	2017-07-14 19:33:00+03	28800.00
C0B41B	2017-07-05 04:31:00+03	85700.00
C0B4D7	2017-08-14 14:24:00+03	38900.00
C0B580	2017-07-07 03:51:00+03	9800.00
C0B6A2	2017-08-11 06:43:00+03	369000.00
C0B6BE	2017-08-08 09:25:00+03	43500.00
C0B6C0	2017-07-04 23:47:00+03	70800.00
C0B700	2017-07-05 13:58:00+03	86800.00
C0B710	2017-07-07 18:10:00+03	64700.00
C0B71B	2017-07-30 23:34:00+03	46300.00
C0B721	2017-07-03 14:52:00+03	59800.00
C0B749	2017-07-26 04:06:00+03	108400.00
C0B752	2017-07-16 07:39:00+03	42800.00
C0B793	2017-07-31 05:41:00+03	96800.00
C0B796	2017-08-13 05:09:00+03	112000.00
C0B7A2	2017-07-14 20:20:00+03	55800.00
C0B7C9	2017-07-03 04:18:00+03	72400.00
C0B7EF	2017-08-14 04:10:00+03	520600.00
C0B859	2017-07-06 18:07:00+03	111600.00
C0B890	2017-07-08 05:49:00+03	166100.00
C0B89B	2017-08-01 19:31:00+03	97900.00
C0B8B4	2017-07-29 22:28:00+03	23200.00
C0B8C3	2017-07-15 03:00:00+03	120700.00
C0B8D5	2017-08-13 19:43:00+03	78800.00
C0B960	2017-07-16 21:50:00+03	32200.00
C0B962	2017-07-25 09:02:00+03	271200.00
C0B9C7	2017-07-30 10:46:00+03	70800.00
C0BA5A	2017-07-22 18:01:00+03	38800.00
C0BADC	2017-08-06 13:27:00+03	70100.00
C0BB1E	2017-08-09 06:01:00+03	58900.00
C0BB3A	2017-07-22 08:48:00+03	185000.00
C0BB3B	2017-07-05 00:43:00+03	99300.00
C0BB5B	2017-08-03 17:02:00+03	135000.00
C0BB93	2017-07-06 09:45:00+03	51800.00
C0BBF8	2017-07-27 10:56:00+03	26200.00
C0BBFA	2017-07-07 00:07:00+03	25800.00
C0BC3D	2017-08-09 19:26:00+03	10800.00
C0BC51	2017-07-22 14:22:00+03	49100.00
C0BC65	2017-08-15 11:01:00+03	11800.00
C0BC78	2017-07-19 23:22:00+03	21800.00
C0BC7A	2017-07-21 07:03:00+03	56000.00
C0BD3F	2017-07-23 01:26:00+03	32400.00
C0BD52	2017-07-31 17:07:00+03	60800.00
C0BD73	2017-08-09 11:45:00+03	277900.00
C0BDBA	2017-08-14 16:46:00+03	20200.00
C0BDBF	2017-08-15 12:10:00+03	149300.00
C0BE74	2017-07-31 04:54:00+03	6700.00
C0BE81	2017-08-07 09:58:00+03	111600.00
C0BE91	2017-08-09 11:09:00+03	47700.00
C0BEE8	2017-07-05 17:21:00+03	66600.00
C0BF20	2017-08-09 16:55:00+03	110500.00
C0BF33	2017-07-18 22:39:00+03	69600.00
C0C035	2017-08-14 04:40:00+03	64800.00
C0C060	2017-07-25 01:02:00+03	96500.00
C0C0A1	2017-07-21 17:04:00+03	55800.00
C0C0A2	2017-08-07 14:34:00+03	47200.00
C0C0E9	2017-07-30 22:21:00+03	70100.00
C0C10A	2017-08-01 04:46:00+03	402400.00
C0C175	2017-07-09 17:03:00+03	92800.00
C0C1B6	2017-07-05 12:27:00+03	55000.00
C0C1FD	2017-08-04 16:50:00+03	36500.00
C0C2CF	2017-07-17 04:09:00+03	35200.00
C0C38E	2017-07-17 11:08:00+03	173900.00
C0C3AD	2017-08-01 11:25:00+03	166000.00
C0C3C0	2017-08-08 06:01:00+03	220800.00
C0C3D4	2017-07-24 05:27:00+03	55800.00
C0C3E2	2017-08-14 10:42:00+03	46000.00
C0C447	2017-07-23 15:44:00+03	52000.00
C0C44E	2017-07-31 23:34:00+03	69500.00
C0C458	2017-07-10 14:06:00+03	35400.00
C0C48F	2017-07-22 05:12:00+03	38600.00
C0C4AD	2017-07-15 08:40:00+03	390400.00
C0C4FE	2017-07-22 03:04:00+03	36200.00
C0C504	2017-07-10 13:54:00+03	369000.00
C0C562	2017-08-09 18:01:00+03	47000.00
C0C56C	2017-07-15 02:10:00+03	75300.00
C0C589	2017-07-24 01:40:00+03	166400.00
C0C598	2017-07-13 05:14:00+03	92900.00
C0C5E4	2017-07-17 09:42:00+03	6700.00
C0C5F4	2017-08-10 10:44:00+03	23600.00
C0C5F5	2017-07-27 15:36:00+03	26000.00
C0C64C	2017-07-12 08:22:00+03	70600.00
C0C652	2017-07-14 11:30:00+03	40000.00
C0C690	2017-06-30 08:04:00+03	24300.00
C0C691	2017-08-13 09:16:00+03	91200.00
C0C6BD	2017-07-01 22:23:00+03	286800.00
C0C6E0	2017-07-27 16:21:00+03	64600.00
C0C6E4	2017-07-10 11:21:00+03	57300.00
C0C702	2017-07-07 04:52:00+03	34600.00
C0C762	2017-07-14 14:25:00+03	26800.00
C0C778	2017-07-13 15:10:00+03	46400.00
C0C78B	2017-07-18 22:54:00+03	123000.00
C0C80F	2017-07-08 18:31:00+03	37900.00
C0C82C	2017-07-03 06:36:00+03	119500.00
C0C844	2017-07-14 14:44:00+03	112600.00
C0C869	2017-07-31 03:15:00+03	77900.00
C0C8D0	2017-08-11 04:55:00+03	22400.00
C0C8E2	2017-07-09 08:26:00+03	32200.00
C0C904	2017-08-13 23:03:00+03	77900.00
C0C9E1	2017-08-01 08:56:00+03	38400.00
C0CA0A	2017-08-13 05:21:00+03	26000.00
C0CA88	2017-07-17 01:19:00+03	41400.00
C0CAC2	2017-07-09 11:01:00+03	99200.00
C0CB10	2017-07-26 00:24:00+03	58000.00
C0CB61	2017-07-13 05:58:00+03	38400.00
C0CB89	2017-08-12 00:04:00+03	14300.00
C0CB8B	2017-07-31 10:48:00+03	52000.00
C0CCC1	2017-08-05 14:59:00+03	154500.00
C0CD03	2017-07-03 21:46:00+03	58000.00
C0CD0B	2017-08-13 16:59:00+03	23200.00
C0CD0E	2017-07-21 19:58:00+03	66000.00
C0CD3B	2017-07-16 18:23:00+03	252300.00
C0CD59	2017-07-21 07:42:00+03	105000.00
C0CDBA	2017-07-13 19:53:00+03	40800.00
C0CE37	2017-07-24 02:32:00+03	26000.00
C0CEB4	2017-07-03 14:27:00+03	187600.00
C0CF44	2017-08-06 13:45:00+03	86600.00
C0CF76	2017-07-23 10:42:00+03	24400.00
C0CFB7	2017-07-02 14:01:00+03	67600.00
C0CFD2	2017-07-26 11:02:00+03	44100.00
C0CFDC	2017-07-06 06:50:00+03	201000.00
C0D025	2017-07-01 02:56:00+03	52800.00
C0D0B2	2017-07-21 08:02:00+03	156000.00
C0D0BD	2017-08-06 03:44:00+03	46400.00
C0D0E6	2017-08-10 20:48:00+03	144000.00
C0D0F1	2017-07-16 00:08:00+03	125400.00
C0D197	2017-08-11 21:33:00+03	59000.00
C0D1D0	2017-08-04 03:03:00+03	64400.00
C0D202	2017-07-11 04:54:00+03	18400.00
C0D2DB	2017-07-31 12:15:00+03	470100.00
C0D2F7	2017-07-18 04:37:00+03	187900.00
C0D307	2017-07-29 00:27:00+03	46200.00
C0D30B	2017-07-12 07:21:00+03	45100.00
C0D364	2017-07-12 16:18:00+03	67700.00
C0D371	2017-07-14 23:23:00+03	34000.00
C0D3C9	2017-07-13 11:35:00+03	95700.00
C0D3DA	2017-08-02 00:12:00+03	37900.00
C0D3EC	2017-07-05 23:22:00+03	20200.00
C0D468	2017-07-10 23:03:00+03	75300.00
C0D46C	2017-08-05 22:00:00+03	259500.00
C0D4ED	2017-07-04 19:02:00+03	25200.00
C0D4EE	2017-07-12 15:16:00+03	257500.00
C0D51F	2017-07-27 08:49:00+03	62000.00
C0D55E	2017-07-08 08:09:00+03	50600.00
C0D598	2017-07-06 23:32:00+03	67700.00
C0D5A9	2017-08-06 13:52:00+03	73600.00
C0D5D6	2017-07-22 17:32:00+03	46400.00
C0D61E	2017-07-17 19:58:00+03	76400.00
C0D645	2017-07-05 06:33:00+03	102300.00
C0D671	2017-07-02 18:28:00+03	52600.00
C0D69C	2017-07-25 11:04:00+03	56200.00
C0D69E	2017-08-08 05:39:00+03	61700.00
C0D714	2017-06-29 07:11:00+03	119800.00
C0D720	2017-07-30 12:48:00+03	36200.00
C0D72D	2017-08-01 14:04:00+03	50600.00
C0D75F	2017-08-08 13:31:00+03	37800.00
C0D7F1	2017-08-12 09:42:00+03	18600.00
C0D847	2017-07-30 01:58:00+03	58000.00
C0D84E	2017-07-29 19:55:00+03	101100.00
C0D8D5	2017-08-03 06:00:00+03	112000.00
C0D91F	2017-07-15 14:52:00+03	14400.00
C0D949	2017-07-05 11:24:00+03	140900.00
C0D9C6	2017-07-24 04:39:00+03	87300.00
C0D9FD	2017-07-17 01:37:00+03	50600.00
C0DA3D	2017-07-17 19:45:00+03	26700.00
C0DA4E	2017-07-14 11:39:00+03	18800.00
C0DB1D	2017-07-05 06:38:00+03	51300.00
C0DB8D	2017-07-18 18:10:00+03	30000.00
C0DC00	2017-07-26 12:10:00+03	19600.00
C0DC19	2017-08-04 02:01:00+03	17600.00
C0DC7A	2017-08-01 17:39:00+03	51000.00
C0DCBE	2017-08-14 01:15:00+03	82000.00
C0DD10	2017-08-01 16:24:00+03	246000.00
C0DD34	2017-08-06 21:47:00+03	28700.00
C0DDD6	2017-07-06 09:20:00+03	57500.00
C0DE18	2017-07-17 06:00:00+03	24700.00
C0DE24	2017-08-13 20:22:00+03	52000.00
C0DE31	2017-08-11 10:59:00+03	20200.00
C0DE32	2017-08-12 04:48:00+03	32800.00
C0DE38	2017-08-08 09:41:00+03	52000.00
C0DE7D	2017-07-25 21:50:00+03	94000.00
C0DE93	2017-07-23 10:36:00+03	82900.00
C0DE9A	2017-07-31 18:25:00+03	111600.00
C0DEC9	2017-07-25 13:59:00+03	10600.00
C0DEF0	2017-08-14 11:43:00+03	63200.00
C0DF39	2017-08-02 13:43:00+03	66600.00
C0DF40	2017-07-08 08:56:00+03	233000.00
C0DF61	2017-07-28 15:16:00+03	116900.00
C0DFE6	2017-07-15 01:19:00+03	114800.00
C0DFFB	2017-07-25 18:43:00+03	52400.00
C0E00E	2017-07-23 11:11:00+03	6700.00
C0E048	2017-07-30 12:23:00+03	46200.00
C0E054	2017-07-20 11:29:00+03	111600.00
C0E0D3	2017-08-10 18:37:00+03	143400.00
C0E100	2017-07-03 07:47:00+03	38600.00
C0E11B	2017-07-04 10:05:00+03	84300.00
C0E13D	2017-07-18 06:36:00+03	9200.00
C0E173	2017-07-29 17:43:00+03	224000.00
C0E275	2017-07-10 05:11:00+03	67900.00
C0E284	2017-07-02 11:37:00+03	119800.00
C0E308	2017-07-02 22:19:00+03	22000.00
C0E31D	2017-07-30 20:27:00+03	52000.00
C0E348	2017-08-13 17:48:00+03	50000.00
C0E34A	2017-07-01 22:35:00+03	51300.00
C0E37B	2017-07-23 13:25:00+03	111600.00
C0E39A	2017-07-28 03:42:00+03	117800.00
C0E446	2017-07-07 00:22:00+03	75600.00
C0E467	2017-07-07 11:35:00+03	13400.00
C0E479	2017-07-06 12:19:00+03	18900.00
C0E48F	2017-07-08 15:17:00+03	35200.00
C0E4C6	2017-08-08 22:25:00+03	26000.00
C0E503	2017-07-11 01:41:00+03	8000.00
C0E504	2017-07-13 19:37:00+03	70100.00
C0E51D	2017-07-24 23:14:00+03	27200.00
C0E589	2017-07-29 10:25:00+03	12200.00
C0E59B	2017-07-02 14:57:00+03	58400.00
C0E59D	2017-07-26 18:58:00+03	146300.00
C0E5CA	2017-07-08 21:47:00+03	48500.00
C0E5E3	2017-07-11 20:09:00+03	40800.00
C0E5E6	2017-07-19 15:40:00+03	277900.00
C0E667	2017-08-14 16:49:00+03	142600.00
C0E6A9	2017-08-05 01:32:00+03	36600.00
C0E726	2017-07-11 22:16:00+03	43500.00
C0E7B7	2017-07-12 03:01:00+03	61800.00
C0E7DA	2017-08-14 14:46:00+03	67000.00
C0E7E9	2017-07-23 08:05:00+03	114300.00
C0E7F1	2017-07-07 06:18:00+03	28800.00
C0E7FF	2017-07-27 09:07:00+03	35800.00
C0E841	2017-07-21 23:36:00+03	65300.00
C0E85D	2017-07-02 21:28:00+03	50000.00
C0E85E	2017-06-26 17:18:00+03	123900.00
C0E89D	2017-07-05 20:45:00+03	175200.00
C0E916	2017-07-11 07:59:00+03	100900.00
C0E9A2	2017-07-25 22:17:00+03	89200.00
C0E9BA	2017-06-29 09:39:00+03	22000.00
C0EA06	2017-07-26 04:21:00+03	266400.00
C0EA8C	2017-07-25 19:43:00+03	112000.00
C0EA9F	2017-07-18 09:41:00+03	209700.00
C0EAAD	2017-07-28 02:29:00+03	114600.00
C0EB53	2017-08-10 03:38:00+03	23400.00
C0EB90	2017-07-22 00:51:00+03	99300.00
C0EBC7	2017-07-30 11:07:00+03	68900.00
C0EBDF	2017-08-12 11:46:00+03	31600.00
C0EC30	2017-07-26 22:26:00+03	38400.00
C0EC52	2017-08-11 06:20:00+03	142300.00
C0EC78	2017-07-16 15:19:00+03	37100.00
C0EC93	2017-07-01 12:33:00+03	50600.00
C0ECC8	2017-07-24 04:03:00+03	69100.00
C0ECCB	2017-07-31 05:22:00+03	252200.00
C0ED0E	2017-08-02 14:24:00+03	59900.00
C0ED1D	2017-07-19 14:37:00+03	35200.00
C0ED2D	2017-08-03 15:30:00+03	54200.00
C0ED88	2017-08-05 13:31:00+03	48800.00
C0ED92	2017-07-20 08:15:00+03	22400.00
C0ED9A	2017-08-03 21:21:00+03	54400.00
C0EE05	2017-07-05 20:48:00+03	28000.00
C0EE1C	2017-07-07 01:23:00+03	26000.00
C0EE87	2017-07-18 04:05:00+03	43500.00
C0EEDC	2017-07-16 04:54:00+03	42800.00
C0EEF3	2017-07-19 09:55:00+03	112000.00
C0EF2D	2017-08-04 18:50:00+03	26000.00
C0EF8D	2017-07-16 08:58:00+03	132800.00
C0EFE7	2017-08-08 17:04:00+03	28800.00
C0F0CF	2017-07-24 19:37:00+03	93400.00
C0F0FD	2017-08-06 20:36:00+03	88800.00
C0F105	2017-08-10 16:04:00+03	46400.00
C0F113	2017-08-11 01:01:00+03	40100.00
C0F149	2017-08-10 17:33:00+03	36200.00
C0F1D3	2017-08-14 20:11:00+03	38400.00
C0F1FF	2017-07-25 01:27:00+03	44800.00
C0F2EC	2017-07-27 08:28:00+03	88000.00
C0F304	2017-07-07 00:17:00+03	76600.00
C0F365	2017-07-10 06:59:00+03	122300.00
C0F3A7	2017-07-17 01:56:00+03	183300.00
C0F3AC	2017-07-23 22:15:00+03	39000.00
C0F402	2017-08-14 15:03:00+03	90800.00
C0F41F	2017-07-29 18:48:00+03	56000.00
C0F493	2017-08-11 14:13:00+03	547400.00
C0F4A7	2017-07-06 08:29:00+03	68200.00
C0F4B5	2017-07-16 15:42:00+03	22000.00
C0F4DD	2017-08-13 08:53:00+03	51900.00
C0F4F6	2017-07-12 19:01:00+03	100600.00
C0F552	2017-07-06 20:21:00+03	6800.00
C0F59C	2017-07-13 15:16:00+03	64600.00
C0F5B2	2017-07-07 08:26:00+03	270000.00
C0F60C	2017-07-14 19:24:00+03	14800.00
C0F641	2017-08-09 20:49:00+03	34600.00
C0F64D	2017-07-21 11:34:00+03	28000.00
C0F67C	2017-07-16 02:48:00+03	301800.00
C0F685	2017-07-20 12:39:00+03	21400.00
C0F6B1	2017-07-06 05:22:00+03	28800.00
C0F6F6	2017-08-11 13:10:00+03	46700.00
C0F6F8	2017-07-16 01:26:00+03	56000.00
C0F6FC	2017-07-19 12:15:00+03	6000.00
C0F709	2017-07-29 08:57:00+03	210000.00
C0F7D6	2017-07-16 10:10:00+03	59200.00
C0F7F4	2017-07-02 09:20:00+03	73100.00
C0F8A0	2017-08-13 12:08:00+03	22600.00
C0F951	2017-07-12 21:53:00+03	52900.00
C0F963	2017-08-14 14:02:00+03	23200.00
C0F997	2017-07-03 07:48:00+03	44000.00
C0F9C5	2017-07-10 06:39:00+03	106800.00
C0F9C6	2017-07-22 14:28:00+03	40000.00
C0F9F4	2017-08-03 02:59:00+03	17200.00
C0FA05	2017-07-24 22:22:00+03	32800.00
C0FAB4	2017-07-07 10:06:00+03	92000.00
C0FAC4	2017-07-06 20:48:00+03	6000.00
C0FAE1	2017-07-31 07:42:00+03	23400.00
C0FBEB	2017-08-08 09:17:00+03	131600.00
C0FC1D	2017-08-11 15:18:00+03	21800.00
C0FC5D	2017-07-18 09:51:00+03	28300.00
C0FC6D	2017-08-13 09:38:00+03	173600.00
C0FC89	2017-08-05 09:35:00+03	128400.00
C0FCA8	2017-08-11 18:02:00+03	63200.00
C0FCEE	2017-07-25 07:48:00+03	68000.00
C0FD07	2017-08-05 06:51:00+03	30200.00
C0FD1B	2017-07-31 23:08:00+03	42800.00
C0FD29	2017-08-05 05:46:00+03	39000.00
C0FD8D	2017-07-04 21:00:00+03	146500.00
C0FDE9	2017-07-06 04:05:00+03	21400.00
C0FE96	2017-07-24 22:46:00+03	108000.00
C0FED2	2017-07-14 22:51:00+03	96800.00
C0FF25	2017-07-21 19:15:00+03	23400.00
C0FFB8	2017-07-19 01:20:00+03	45200.00
C0FFBA	2017-07-09 13:32:00+03	11800.00
C10027	2017-07-17 13:13:00+03	32700.00
C10032	2017-07-22 01:10:00+03	6000.00
C1003D	2017-07-07 21:46:00+03	62800.00
C10069	2017-07-23 11:30:00+03	57500.00
C10149	2017-08-03 19:47:00+03	33600.00
C1015A	2017-07-23 18:09:00+03	98100.00
C1015E	2017-07-12 00:02:00+03	12600.00
C1016F	2017-08-09 05:56:00+03	65900.00
C101D0	2017-08-11 22:07:00+03	62000.00
C101E3	2017-07-21 01:30:00+03	56000.00
C1022C	2017-08-02 20:26:00+03	86600.00
C102A8	2017-08-07 22:49:00+03	111600.00
C102C0	2017-08-04 17:43:00+03	31400.00
C10381	2017-07-08 23:47:00+03	43500.00
C103B8	2017-07-12 17:06:00+03	114800.00
C103CE	2017-07-12 12:40:00+03	191300.00
C103F3	2017-08-05 11:36:00+03	55800.00
C1041C	2017-07-03 14:59:00+03	32200.00
C1044D	2017-07-31 02:48:00+03	6800.00
C104C1	2017-07-09 08:50:00+03	24400.00
C10521	2017-07-15 01:00:00+03	94200.00
C10546	2017-08-04 01:34:00+03	79000.00
C10552	2017-07-02 18:17:00+03	337800.00
C10629	2017-08-01 19:16:00+03	92700.00
C1062C	2017-07-19 03:04:00+03	57300.00
C10640	2017-07-18 07:41:00+03	150200.00
C1064B	2017-08-12 01:34:00+03	283100.00
C10662	2017-07-24 18:50:00+03	112000.00
C10677	2017-07-03 21:30:00+03	474800.00
C10712	2017-07-25 22:14:00+03	19600.00
C107AE	2017-07-08 18:14:00+03	148200.00
C107D6	2017-07-18 06:36:00+03	6000.00
C10817	2017-07-23 04:21:00+03	39500.00
C10833	2017-07-10 05:44:00+03	31600.00
C1086D	2017-08-11 09:43:00+03	92800.00
C10879	2017-08-08 07:01:00+03	118400.00
C1093B	2017-07-22 19:40:00+03	23200.00
C10955	2017-08-04 08:17:00+03	133200.00
C10A0E	2017-08-11 22:03:00+03	26700.00
C10A12	2017-08-10 13:47:00+03	379600.00
C10A61	2017-08-12 01:46:00+03	30200.00
C10A77	2017-08-03 12:11:00+03	50800.00
C10AEB	2017-08-11 12:45:00+03	37600.00
C10B2E	2017-07-10 20:20:00+03	103600.00
C10B5F	2017-07-23 04:13:00+03	68800.00
C10BB1	2017-07-19 06:42:00+03	62500.00
C10BE3	2017-07-26 13:52:00+03	27200.00
C10C13	2017-07-12 01:49:00+03	133100.00
C10C3B	2017-07-04 14:12:00+03	27200.00
C10C3D	2017-07-11 19:43:00+03	25100.00
C10C7D	2017-08-11 11:33:00+03	39600.00
C10D18	2017-08-03 13:14:00+03	26700.00
C10D59	2017-07-31 01:53:00+03	36200.00
C10D95	2017-08-02 07:41:00+03	52400.00
C10D98	2017-08-02 16:42:00+03	68800.00
C10DAD	2017-07-09 22:21:00+03	99200.00
C10EE1	2017-08-14 10:05:00+03	62700.00
C10EF6	2017-07-22 00:00:00+03	102100.00
C10F47	2017-07-21 09:20:00+03	392700.00
C10F62	2017-07-04 01:44:00+03	54300.00
C10F9F	2017-08-03 02:52:00+03	13200.00
C10FC0	2017-08-13 23:07:00+03	22000.00
C10FF5	2017-07-12 12:40:00+03	52900.00
C11013	2017-08-04 18:03:00+03	88800.00
C11037	2017-08-15 05:50:00+03	64500.00
C11054	2017-07-14 11:33:00+03	123000.00
C1107A	2017-07-04 17:27:00+03	24800.00
C110BC	2017-07-31 22:50:00+03	52200.00
C110E2	2017-08-10 03:51:00+03	133200.00
C110E7	2017-06-28 12:02:00+03	37100.00
C11105	2017-08-11 13:56:00+03	72400.00
C1114F	2017-07-09 10:08:00+03	27200.00
C1116A	2017-08-09 20:44:00+03	21600.00
C1116B	2017-08-11 05:13:00+03	31900.00
C111B6	2017-07-09 01:09:00+03	46300.00
C111C0	2017-08-10 14:44:00+03	136800.00
C11227	2017-07-07 02:54:00+03	38500.00
C11229	2017-07-19 06:30:00+03	11600.00
C11248	2017-06-30 12:38:00+03	133200.00
C11254	2017-07-10 03:52:00+03	28800.00
C11257	2017-07-29 04:49:00+03	41400.00
C1126C	2017-07-07 12:37:00+03	82000.00
C112E9	2017-07-29 06:48:00+03	87400.00
C112EA	2017-08-10 11:40:00+03	222000.00
C11351	2017-08-09 02:36:00+03	37900.00
C1137A	2017-08-14 11:32:00+03	148200.00
C11431	2017-07-03 05:06:00+03	40800.00
C1144B	2017-07-28 14:52:00+03	37700.00
C1144C	2017-07-12 20:26:00+03	183900.00
C1145B	2017-07-07 05:44:00+03	96800.00
C1149F	2017-08-11 19:04:00+03	48800.00
C114A8	2017-08-07 09:23:00+03	31200.00
C114F1	2017-07-19 02:45:00+03	117600.00
C11508	2017-07-09 21:27:00+03	39600.00
C11579	2017-07-12 05:56:00+03	37700.00
C115E4	2017-07-27 03:43:00+03	92800.00
C11619	2017-07-23 07:33:00+03	271100.00
C1162E	2017-08-04 13:46:00+03	44800.00
C11686	2017-06-29 05:59:00+03	12000.00
C11721	2017-08-05 05:27:00+03	64600.00
C11774	2017-07-26 12:40:00+03	44000.00
C1177D	2017-07-25 01:58:00+03	83200.00
C1178F	2017-08-01 00:13:00+03	152300.00
C117F1	2017-07-09 18:29:00+03	43900.00
C117F5	2017-08-01 13:46:00+03	66800.00
C11872	2017-07-04 09:48:00+03	94000.00
C11878	2017-08-02 00:46:00+03	38600.00
C11887	2017-07-19 03:34:00+03	90600.00
C119B4	2017-07-19 11:31:00+03	56000.00
C119CB	2017-07-31 10:24:00+03	220700.00
C11A10	2017-07-07 11:44:00+03	111600.00
C11A58	2017-07-02 06:35:00+03	22000.00
C11A65	2017-08-03 03:42:00+03	46200.00
C11AA1	2017-07-21 00:46:00+03	113200.00
C11AB1	2017-06-30 23:24:00+03	75300.00
C11AC3	2017-07-14 23:27:00+03	116400.00
C11ACD	2017-07-12 17:41:00+03	81300.00
C11AE9	2017-08-12 03:58:00+03	101200.00
C11B1C	2017-07-10 19:14:00+03	65600.00
C11B2C	2017-07-21 18:58:00+03	111600.00
C11B39	2017-08-15 03:21:00+03	77000.00
C11B83	2017-07-14 02:20:00+03	201800.00
C11B9D	2017-07-07 22:16:00+03	32400.00
C11BA7	2017-07-18 18:39:00+03	28000.00
C11BB9	2017-08-06 16:12:00+03	71900.00
C11BF1	2017-06-30 08:42:00+03	22600.00
C11C04	2017-07-30 13:03:00+03	113200.00
C11C0E	2017-07-03 17:02:00+03	40000.00
C11C25	2017-08-05 17:18:00+03	68400.00
C11CA8	2017-07-16 10:01:00+03	94200.00
C11D1A	2017-08-01 20:01:00+03	181400.00
C11D56	2017-07-10 05:54:00+03	34000.00
C11D57	2017-08-08 12:34:00+03	15600.00
C11D9C	2017-07-16 06:20:00+03	103500.00
C11DB5	2017-07-27 16:28:00+03	83600.00
C11E18	2017-06-29 11:21:00+03	81700.00
C11E2E	2017-07-26 18:31:00+03	6000.00
C11E4A	2017-07-23 05:41:00+03	53000.00
C11E4C	2017-07-18 14:18:00+03	289800.00
C11E66	2017-07-01 23:55:00+03	55800.00
C11EA2	2017-08-03 10:31:00+03	38800.00
C11F10	2017-07-31 07:48:00+03	111600.00
C11F38	2017-07-31 14:30:00+03	43900.00
C11F5E	2017-07-26 14:05:00+03	45200.00
C11F6B	2017-08-05 15:12:00+03	40800.00
C11F81	2017-07-22 04:09:00+03	29600.00
C11F8F	2017-08-04 03:00:00+03	71600.00
C11FE3	2017-07-24 05:32:00+03	115800.00
C11FE4	2017-07-12 21:36:00+03	64500.00
C11FF5	2017-07-23 18:53:00+03	200200.00
C12028	2017-07-12 12:42:00+03	38800.00
C1205B	2017-07-24 07:41:00+03	57600.00
C12064	2017-07-23 08:14:00+03	390400.00
C12066	2017-08-14 12:11:00+03	89600.00
C12073	2017-08-09 15:51:00+03	36800.00
C120C3	2017-08-11 08:26:00+03	93900.00
C12110	2017-07-11 03:10:00+03	160200.00
C1212F	2017-07-27 19:17:00+03	128800.00
C12160	2017-07-28 17:29:00+03	139800.00
C12162	2017-08-10 04:33:00+03	26700.00
C12175	2017-07-19 13:13:00+03	6000.00
C1219B	2017-07-14 13:52:00+03	177600.00
C121B4	2017-08-02 08:52:00+03	6300.00
C122B3	2017-08-01 01:30:00+03	199800.00
C122B8	2017-08-02 05:57:00+03	112000.00
C122BE	2017-07-30 22:57:00+03	49900.00
C122C2	2017-07-10 17:59:00+03	67600.00
C123F2	2017-07-29 01:20:00+03	201200.00
C1240D	2017-07-01 17:36:00+03	40600.00
C1241B	2017-07-24 22:39:00+03	45100.00
C12422	2017-08-09 23:05:00+03	13200.00
C12469	2017-07-27 23:25:00+03	6300.00
C1249D	2017-07-28 16:50:00+03	38600.00
C124BA	2017-07-27 09:08:00+03	73600.00
C12535	2017-07-15 06:06:00+03	55800.00
C12569	2017-07-13 09:17:00+03	81600.00
C12571	2017-07-29 03:55:00+03	84000.00
C125B5	2017-07-15 05:27:00+03	369000.00
C1263C	2017-07-13 03:29:00+03	28000.00
C126B1	2017-07-10 09:38:00+03	30400.00
C126CC	2017-08-07 20:10:00+03	16400.00
C12727	2017-07-02 21:07:00+03	271200.00
C1283A	2017-08-11 03:47:00+03	61800.00
C1285C	2017-07-23 12:48:00+03	67600.00
C1287B	2017-07-16 22:41:00+03	123000.00
C128B5	2017-08-01 15:27:00+03	48600.00
C128F1	2017-07-05 15:37:00+03	99200.00
C12940	2017-07-07 05:35:00+03	92800.00
C129B1	2017-08-13 16:35:00+03	23200.00
C129FE	2017-07-03 23:21:00+03	20200.00
C12A4D	2017-07-01 06:37:00+03	94000.00
C12AA6	2017-07-10 00:33:00+03	8200.00
C12AF5	2017-07-03 12:29:00+03	72600.00
C12BE3	2017-08-10 08:35:00+03	27200.00
C12BF4	2017-07-19 02:48:00+03	27000.00
C12C25	2017-07-07 01:52:00+03	122000.00
C12C52	2017-08-07 09:39:00+03	99200.00
C12C73	2017-07-23 12:25:00+03	56000.00
C12C79	2017-07-10 22:32:00+03	71200.00
C12CD5	2017-08-05 11:13:00+03	28800.00
C12D3C	2017-08-02 20:32:00+03	101100.00
C12E30	2017-08-14 11:06:00+03	56000.00
C12E7F	2017-08-12 19:11:00+03	13600.00
C12FAA	2017-08-09 04:23:00+03	44600.00
C12FF2	2017-07-25 19:33:00+03	24400.00
C12FF9	2017-08-12 08:58:00+03	369000.00
C13058	2017-07-22 10:40:00+03	65900.00
C1308E	2017-08-15 15:32:00+03	24400.00
C130DC	2017-07-26 19:35:00+03	29600.00
C1312B	2017-07-12 11:44:00+03	56900.00
C131D5	2017-07-19 10:27:00+03	60800.00
C13209	2017-07-20 07:34:00+03	27200.00
C13287	2017-07-02 15:07:00+03	52100.00
C13310	2017-07-20 14:32:00+03	56100.00
C13345	2017-07-08 09:58:00+03	129700.00
C1338A	2017-07-16 11:29:00+03	54600.00
C1339F	2017-07-13 14:31:00+03	21800.00
C1351D	2017-07-12 21:28:00+03	46000.00
C13539	2017-07-01 07:11:00+03	105600.00
C135A4	2017-07-19 17:28:00+03	27200.00
C135BF	2017-08-10 12:16:00+03	56000.00
C135D5	2017-07-09 21:30:00+03	65900.00
C13638	2017-08-11 13:29:00+03	68400.00
C1363D	2017-07-08 16:16:00+03	146300.00
C13648	2017-08-05 09:24:00+03	32800.00
C13662	2017-07-22 16:09:00+03	58200.00
C13699	2017-07-11 23:39:00+03	47500.00
C136B7	2017-07-30 21:32:00+03	39800.00
C136E7	2017-07-02 19:08:00+03	123000.00
C13761	2017-07-04 22:37:00+03	169900.00
C1377D	2017-07-19 03:23:00+03	47100.00
C13791	2017-08-14 11:05:00+03	6800.00
C137E3	2017-07-02 10:23:00+03	31600.00
C13801	2017-07-23 06:10:00+03	81200.00
C1380D	2017-08-04 14:33:00+03	265600.00
C13886	2017-07-13 03:49:00+03	49800.00
C138F5	2017-07-15 00:21:00+03	39800.00
C13922	2017-08-11 10:17:00+03	77000.00
C13A37	2017-08-03 14:44:00+03	169300.00
C13A48	2017-08-01 07:18:00+03	67400.00
C13A96	2017-08-11 05:23:00+03	105600.00
C13ACB	2017-07-07 19:03:00+03	163400.00
C13B00	2017-07-12 16:23:00+03	42900.00
C13B2C	2017-07-19 06:04:00+03	117600.00
C13B65	2017-07-30 23:25:00+03	70600.00
C13B78	2017-07-04 17:23:00+03	13600.00
C13BD8	2017-08-11 16:41:00+03	134400.00
C13BED	2017-07-23 13:29:00+03	73500.00
C13BFB	2017-08-01 11:09:00+03	103300.00
C13C6C	2017-08-10 03:00:00+03	38400.00
C13C83	2017-07-30 14:30:00+03	170700.00
C13CBA	2017-07-21 10:39:00+03	132800.00
C13D85	2017-07-01 09:18:00+03	14400.00
C13E8B	2017-08-15 05:08:00+03	126500.00
C13EA6	2017-07-17 11:56:00+03	150300.00
C13EAF	2017-07-03 03:19:00+03	47400.00
C13FCC	2017-07-09 04:41:00+03	153900.00
C13FF2	2017-07-19 04:38:00+03	66600.00
C14012	2017-07-26 19:00:00+03	67600.00
C140FD	2017-07-22 23:08:00+03	54500.00
C14144	2017-07-13 17:27:00+03	37200.00
C141BB	2017-08-09 04:27:00+03	60800.00
C141FC	2017-07-29 05:14:00+03	55100.00
C14215	2017-08-01 19:40:00+03	69900.00
C14221	2017-07-18 23:22:00+03	21400.00
C14270	2017-08-01 21:56:00+03	57600.00
C14291	2017-08-11 08:15:00+03	27200.00
C1434E	2017-07-27 14:57:00+03	89200.00
C1436B	2017-07-09 00:39:00+03	119500.00
C14385	2017-07-19 02:54:00+03	120100.00
C143D9	2017-08-06 20:52:00+03	246300.00
C1444F	2017-08-03 01:46:00+03	65100.00
C144BB	2017-07-03 17:35:00+03	33200.00
C144BC	2017-07-23 18:02:00+03	70100.00
C14506	2017-07-11 00:22:00+03	54000.00
C1453B	2017-08-14 01:09:00+03	55900.00
C14548	2017-08-09 13:17:00+03	11800.00
C145D9	2017-07-23 22:30:00+03	91200.00
C1464A	2017-07-14 05:17:00+03	27300.00
C1467E	2017-07-25 23:35:00+03	230000.00
C146CF	2017-07-26 04:04:00+03	49100.00
C14740	2017-07-23 12:22:00+03	56600.00
C14745	2017-07-11 15:32:00+03	55800.00
C14763	2017-07-11 01:24:00+03	6700.00
C147AE	2017-07-24 08:17:00+03	43600.00
C147C6	2017-06-30 21:35:00+03	23200.00
C147E2	2017-08-08 03:03:00+03	98200.00
C1481F	2017-07-28 02:09:00+03	28800.00
C14859	2017-07-14 20:26:00+03	43000.00
C148C0	2017-07-24 15:37:00+03	67600.00
C148D1	2017-07-22 22:49:00+03	21400.00
C14907	2017-07-28 13:42:00+03	186500.00
C149AC	2017-07-31 09:18:00+03	21800.00
C149AF	2017-07-01 03:28:00+03	158200.00
C149DF	2017-07-29 07:26:00+03	57600.00
C149EA	2017-07-31 03:57:00+03	56900.00
C14A3B	2017-08-14 02:34:00+03	81100.00
C14A97	2017-08-09 15:18:00+03	23400.00
C14AC5	2017-07-22 19:14:00+03	20400.00
C14AD3	2017-07-19 06:29:00+03	146500.00
C14B6A	2017-07-01 11:22:00+03	64200.00
C14C01	2017-07-23 19:15:00+03	52700.00
C14C79	2017-07-28 05:09:00+03	36800.00
C14C8F	2017-07-25 19:37:00+03	100600.00
C14CF6	2017-07-14 23:27:00+03	70700.00
C14D6D	2017-07-28 01:01:00+03	46200.00
C14DA3	2017-08-04 23:16:00+03	42800.00
C14DA6	2017-08-09 17:09:00+03	70600.00
C14E30	2017-07-31 17:44:00+03	245300.00
C14E44	2017-08-11 01:46:00+03	88600.00
C14E4E	2017-07-16 09:14:00+03	40800.00
C14EDA	2017-07-25 12:52:00+03	30600.00
C14F3B	2017-08-13 17:21:00+03	85600.00
C14F84	2017-07-10 04:42:00+03	59100.00
C14F95	2017-07-05 17:34:00+03	21400.00
C14FA0	2017-07-08 10:14:00+03	75800.00
C15006	2017-07-07 03:57:00+03	12000.00
C1501E	2017-07-07 05:32:00+03	59800.00
C150F0	2017-08-01 13:12:00+03	6300.00
C150F6	2017-07-24 18:45:00+03	67400.00
C15144	2017-07-04 23:45:00+03	133100.00
C1514F	2017-08-05 20:33:00+03	38400.00
C15162	2017-07-22 23:55:00+03	78800.00
C1516A	2017-07-11 04:31:00+03	13000.00
C1517B	2017-08-01 23:15:00+03	58400.00
C151A2	2017-08-01 14:35:00+03	170000.00
C151B8	2017-07-21 20:00:00+03	43800.00
C1525D	2017-07-03 14:22:00+03	24600.00
C15272	2017-07-01 17:29:00+03	48800.00
C15297	2017-07-03 16:50:00+03	45200.00
C152E6	2017-07-06 18:11:00+03	102500.00
C15302	2017-07-29 20:36:00+03	105100.00
C15306	2017-07-14 05:41:00+03	61200.00
C15370	2017-07-29 05:08:00+03	186900.00
C15376	2017-08-01 04:07:00+03	112100.00
C153AC	2017-07-24 20:01:00+03	171400.00
C153BC	2017-08-03 09:47:00+03	67600.00
C153DF	2017-07-27 06:49:00+03	6700.00
C153FD	2017-07-04 00:30:00+03	258400.00
C1552B	2017-07-30 09:21:00+03	10800.00
C1561A	2017-07-31 10:32:00+03	16400.00
C156C9	2017-08-04 20:54:00+03	61800.00
C156EC	2017-06-30 00:02:00+03	41200.00
C157DB	2017-08-10 08:59:00+03	21800.00
C15890	2017-08-09 21:24:00+03	72400.00
C15896	2017-07-17 14:09:00+03	92800.00
C158B9	2017-08-07 09:06:00+03	56600.00
C1590F	2017-07-23 04:48:00+03	17200.00
C15924	2017-08-03 14:45:00+03	58600.00
C15925	2017-08-06 13:36:00+03	87300.00
C1594F	2017-07-10 12:52:00+03	23600.00
C159E6	2017-07-31 17:15:00+03	35600.00
C159EC	2017-08-03 09:06:00+03	20000.00
C15A33	2017-07-14 20:44:00+03	84800.00
C15A5B	2017-07-08 17:14:00+03	36200.00
C15A6F	2017-06-28 09:38:00+03	20200.00
C15ADD	2017-07-03 00:29:00+03	50100.00
C15B01	2017-08-02 22:13:00+03	169300.00
C15B17	2017-08-12 10:30:00+03	90800.00
C15B25	2017-08-14 08:22:00+03	66800.00
C15B62	2017-07-18 01:56:00+03	118600.00
C15B68	2017-08-12 22:51:00+03	114500.00
C15BC7	2017-07-31 11:47:00+03	23200.00
C15C11	2017-08-06 13:27:00+03	132800.00
C15C4C	2017-07-11 07:38:00+03	47100.00
C15C69	2017-07-11 08:02:00+03	54800.00
C15CC6	2017-07-26 20:50:00+03	80200.00
C15D3A	2017-08-13 04:04:00+03	62400.00
C15D45	2017-07-22 05:18:00+03	39500.00
C15DA7	2017-07-16 15:50:00+03	61800.00
C15DE5	2017-07-15 22:01:00+03	32800.00
C15EAE	2017-07-21 06:48:00+03	182300.00
C15F41	2017-07-20 05:08:00+03	48800.00
C15F45	2017-07-10 21:32:00+03	86400.00
C15F85	2017-08-02 06:31:00+03	37400.00
C16004	2017-07-25 20:30:00+03	12600.00
C1610D	2017-07-30 08:35:00+03	116400.00
C1613B	2017-07-21 17:35:00+03	103500.00
C1616B	2017-08-11 08:53:00+03	40300.00
C16180	2017-08-08 10:53:00+03	52000.00
C16193	2017-08-14 05:50:00+03	67200.00
C16199	2017-07-17 06:30:00+03	16400.00
C161A6	2017-07-18 04:30:00+03	24400.00
C161B3	2017-07-02 02:30:00+03	69500.00
C161CE	2017-07-12 11:35:00+03	38400.00
C161FB	2017-07-20 19:18:00+03	203100.00
C16231	2017-07-29 21:24:00+03	49900.00
C162E7	2017-08-14 18:43:00+03	38600.00
C162EF	2017-07-09 09:46:00+03	73200.00
C16356	2017-08-05 18:41:00+03	88500.00
C1645A	2017-07-03 14:24:00+03	83000.00
C16461	2017-08-12 22:06:00+03	28100.00
C164BF	2017-08-01 16:04:00+03	9800.00
C16538	2017-07-28 05:36:00+03	46200.00
C1654B	2017-07-08 06:14:00+03	45600.00
C16607	2017-07-11 10:28:00+03	46500.00
C16616	2017-08-07 15:27:00+03	81600.00
C1667A	2017-08-10 15:24:00+03	67100.00
C1667C	2017-08-01 13:29:00+03	114800.00
C166AE	2017-08-10 14:12:00+03	68400.00
C166CF	2017-07-20 06:51:00+03	150600.00
C16711	2017-08-06 16:13:00+03	35800.00
C16737	2017-07-26 14:39:00+03	37900.00
C1673D	2017-07-05 05:30:00+03	96300.00
C1678A	2017-08-09 22:20:00+03	56600.00
C167A3	2017-08-02 10:32:00+03	246000.00
C167A4	2017-07-31 11:50:00+03	16400.00
C167C3	2017-07-27 18:18:00+03	89600.00
C167FF	2017-07-07 00:04:00+03	166100.00
C1681B	2017-08-03 07:07:00+03	29600.00
C16848	2017-07-23 05:32:00+03	143800.00
C168B2	2017-08-07 18:57:00+03	58900.00
C168C9	2017-08-08 10:32:00+03	39200.00
C1694E	2017-07-27 15:00:00+03	45200.00
C1694F	2017-07-28 12:04:00+03	26000.00
C16975	2017-07-29 15:29:00+03	133200.00
C169ED	2017-06-25 19:07:00+03	126500.00
C16A70	2017-07-23 23:07:00+03	25200.00
C16AD1	2017-07-23 19:44:00+03	393000.00
C16AF0	2017-08-06 09:47:00+03	26700.00
C16B20	2017-07-10 17:10:00+03	133200.00
C16BE5	2017-07-08 00:54:00+03	132800.00
C16BE7	2017-08-14 21:51:00+03	12000.00
C16C48	2017-07-19 20:43:00+03	40000.00
C16C76	2017-08-10 10:32:00+03	120700.00
C16CAA	2017-08-03 05:19:00+03	67600.00
C16CC1	2017-07-22 14:29:00+03	51900.00
C16CC3	2017-07-30 15:17:00+03	6000.00
C16CDE	2017-08-08 22:50:00+03	75900.00
C16CF0	2017-07-14 22:54:00+03	23200.00
C16CF4	2017-07-08 00:44:00+03	30000.00
C16D29	2017-07-04 17:13:00+03	11000.00
C16EA8	2017-07-07 22:09:00+03	137600.00
C16ED2	2017-07-05 14:32:00+03	29600.00
C16ED7	2017-07-20 00:58:00+03	60500.00
C16EF0	2017-08-01 16:09:00+03	63400.00
C16EF2	2017-07-12 20:24:00+03	111600.00
C16F3A	2017-07-29 04:28:00+03	108000.00
C16F40	2017-08-06 12:55:00+03	112600.00
C16F4F	2017-07-09 03:50:00+03	12000.00
C16F73	2017-07-31 05:25:00+03	44800.00
C16F76	2017-07-07 09:34:00+03	13000.00
C16FBE	2017-08-07 17:15:00+03	734700.00
C16FF3	2017-08-09 11:28:00+03	136000.00
C170CD	2017-08-15 10:05:00+03	68100.00
C171FD	2017-08-01 08:35:00+03	108900.00
C1722A	2017-07-31 10:28:00+03	26000.00
C1722E	2017-07-30 10:51:00+03	30000.00
C17230	2017-07-29 23:04:00+03	59000.00
C17255	2017-07-31 21:49:00+03	26000.00
C1725F	2017-08-07 10:34:00+03	130400.00
C1729E	2017-07-06 05:17:00+03	22000.00
C172E5	2017-07-03 00:06:00+03	16000.00
C17335	2017-07-28 17:04:00+03	24700.00
C17404	2017-07-08 15:29:00+03	103500.00
C17420	2017-07-11 00:35:00+03	25600.00
C1744A	2017-07-23 13:48:00+03	86500.00
C17466	2017-08-02 01:55:00+03	7400.00
C17467	2017-08-03 05:26:00+03	125000.00
C174D7	2017-08-02 06:17:00+03	24800.00
C17516	2017-08-14 14:34:00+03	26000.00
C1755A	2017-08-11 00:11:00+03	178800.00
C1756D	2017-07-06 20:25:00+03	67600.00
C1758D	2017-08-15 02:57:00+03	38600.00
C175A2	2017-07-26 09:26:00+03	149100.00
C175B6	2017-07-07 22:50:00+03	188800.00
C175F1	2017-07-12 07:26:00+03	217900.00
C175F5	2017-07-26 20:09:00+03	64800.00
C17634	2017-07-06 04:10:00+03	99600.00
C1768D	2017-07-14 19:56:00+03	134600.00
C176EE	2017-07-26 16:30:00+03	112000.00
C17733	2017-07-27 16:47:00+03	47000.00
C17737	2017-07-04 04:12:00+03	135000.00
C17743	2017-08-09 16:27:00+03	23200.00
C17787	2017-08-07 11:25:00+03	118700.00
C17812	2017-07-07 03:15:00+03	198400.00
C17835	2017-08-03 23:47:00+03	58700.00
C17841	2017-08-14 08:54:00+03	115800.00
C1785E	2017-08-12 11:33:00+03	85000.00
C17880	2017-08-03 07:53:00+03	199700.00
C178ED	2017-07-07 17:19:00+03	40800.00
C1790A	2017-08-08 23:54:00+03	119400.00
C17938	2017-07-14 21:24:00+03	186900.00
C1797D	2017-07-17 15:41:00+03	72500.00
C17989	2017-08-14 22:19:00+03	113200.00
C179BD	2017-07-08 00:17:00+03	28800.00
C179DD	2017-07-09 21:56:00+03	18600.00
C179FF	2017-07-18 15:20:00+03	23200.00
C17A60	2017-07-25 01:25:00+03	377400.00
C17AE7	2017-08-03 12:21:00+03	28000.00
C17B92	2017-08-13 06:42:00+03	372000.00
C17BAC	2017-07-23 04:35:00+03	42600.00
C17BBA	2017-07-25 07:20:00+03	148200.00
C17C10	2017-07-07 00:50:00+03	56000.00
C17C2A	2017-07-01 02:12:00+03	27200.00
C17CC2	2017-06-29 15:01:00+03	65900.00
C17D32	2017-08-09 14:05:00+03	195900.00
C17D3F	2017-07-17 08:18:00+03	66400.00
C17D7C	2017-07-09 18:22:00+03	31400.00
C17DAE	2017-07-25 18:21:00+03	261500.00
C17DC2	2017-07-13 19:19:00+03	75600.00
C17DEA	2017-07-10 16:10:00+03	16400.00
C17DF9	2017-07-08 01:48:00+03	61600.00
C17E0F	2017-08-07 14:50:00+03	46000.00
C17E18	2017-08-14 17:57:00+03	135600.00
C17E43	2017-08-06 21:27:00+03	21400.00
C17EF1	2017-07-18 18:49:00+03	70800.00
C17F37	2017-07-12 05:36:00+03	63200.00
C17F39	2017-07-22 19:04:00+03	194000.00
C17F41	2017-08-04 14:08:00+03	69500.00
C18021	2017-07-09 05:14:00+03	133200.00
C18103	2017-07-06 08:04:00+03	92800.00
C18105	2017-07-28 05:13:00+03	55800.00
C1810D	2017-07-13 23:34:00+03	10600.00
C18221	2017-07-21 14:28:00+03	29600.00
C1823E	2017-08-04 18:16:00+03	119800.00
C1824A	2017-07-31 15:23:00+03	56600.00
C1828A	2017-07-26 00:58:00+03	67100.00
C182C4	2017-08-15 01:35:00+03	11700.00
C182F2	2017-07-04 09:05:00+03	46200.00
C18317	2017-07-20 07:49:00+03	17800.00
C18322	2017-08-13 02:20:00+03	96400.00
C18327	2017-08-11 21:23:00+03	45200.00
C18372	2017-08-04 16:51:00+03	243700.00
C183DD	2017-07-08 08:43:00+03	14400.00
C18446	2017-07-15 23:55:00+03	33100.00
C18470	2017-07-19 10:57:00+03	28800.00
C1850F	2017-07-12 03:04:00+03	100600.00
C18514	2017-08-08 05:03:00+03	123000.00
C1853E	2017-07-04 06:30:00+03	73200.00
C18597	2017-07-12 13:28:00+03	46200.00
C185B4	2017-07-13 22:15:00+03	123000.00
C185E1	2017-07-29 00:52:00+03	181400.00
C185E6	2017-07-23 20:33:00+03	174400.00
C18630	2017-07-09 23:00:00+03	16800.00
C18651	2017-08-03 18:24:00+03	191200.00
C186D6	2017-07-02 16:31:00+03	155600.00
C186EB	2017-07-03 21:30:00+03	139100.00
C186EE	2017-08-01 13:12:00+03	186900.00
C1872A	2017-08-08 18:50:00+03	28600.00
C1874D	2017-07-27 22:46:00+03	91800.00
C1875F	2017-07-30 19:00:00+03	193700.00
C187A4	2017-07-06 16:30:00+03	6000.00
C187D7	2017-07-06 14:24:00+03	38000.00
C187F3	2017-07-28 13:09:00+03	54400.00
C18803	2017-08-08 09:04:00+03	38400.00
C1881C	2017-07-06 21:36:00+03	67500.00
C188EA	2017-07-10 08:03:00+03	75300.00
C1894E	2017-07-08 22:43:00+03	3400.00
C1895B	2017-08-09 12:52:00+03	55800.00
C1896A	2017-07-09 04:03:00+03	123000.00
C18977	2017-07-19 06:10:00+03	79900.00
C189B5	2017-07-30 10:00:00+03	38600.00
C189C0	2017-07-31 04:19:00+03	23200.00
C189F1	2017-07-11 07:28:00+03	193600.00
C18A4A	2017-07-02 20:15:00+03	22600.00
C18A83	2017-08-01 13:34:00+03	26400.00
C18A89	2017-08-08 12:07:00+03	16400.00
C18AD5	2017-08-15 07:08:00+03	50600.00
C18AD6	2017-08-12 10:41:00+03	81800.00
C18B05	2017-08-08 15:47:00+03	100400.00
C18B12	2017-08-12 03:29:00+03	8000.00
C18BB1	2017-07-13 08:58:00+03	56900.00
C18C2C	2017-07-08 20:02:00+03	27200.00
C18C41	2017-07-11 02:37:00+03	123000.00
C18C86	2017-06-29 14:41:00+03	23400.00
C18C91	2017-08-06 15:29:00+03	68000.00
C18D14	2017-08-08 15:17:00+03	53700.00
C18D6D	2017-08-06 17:04:00+03	8400.00
C18DCD	2017-07-11 13:09:00+03	75600.00
C18DDA	2017-08-12 12:58:00+03	55000.00
C18E4F	2017-08-06 12:46:00+03	96400.00
C18E9F	2017-07-28 12:28:00+03	87700.00
C18EBF	2017-07-25 05:40:00+03	36200.00
C18EC5	2017-07-02 08:11:00+03	372500.00
C18F1E	2017-07-20 10:02:00+03	26000.00
C18F5F	2017-07-03 16:50:00+03	58400.00
C18F78	2017-08-14 10:34:00+03	60400.00
C18F7D	2017-07-15 02:35:00+03	32800.00
C18FF3	2017-08-06 07:37:00+03	67200.00
C18FFE	2017-07-22 13:52:00+03	40100.00
C19005	2017-07-30 03:11:00+03	61900.00
C19034	2017-07-20 19:21:00+03	23200.00
C1908B	2017-07-23 04:40:00+03	29200.00
C19094	2017-07-21 15:20:00+03	26000.00
C190B1	2017-08-08 15:32:00+03	135800.00
C1914A	2017-07-18 15:31:00+03	125200.00
C1919E	2017-08-13 10:41:00+03	17800.00
C191C8	2017-08-02 18:23:00+03	44000.00
C191EA	2017-07-17 00:54:00+03	170400.00
C19219	2017-07-24 06:09:00+03	24000.00
C1921C	2017-08-14 11:07:00+03	26000.00
C19232	2017-07-17 18:06:00+03	46100.00
C192C5	2017-07-26 18:45:00+03	66600.00
C192E4	2017-07-02 17:37:00+03	181700.00
C192F6	2017-07-27 13:18:00+03	75600.00
C1932A	2017-07-07 22:46:00+03	229500.00
C19382	2017-07-09 11:02:00+03	26000.00
C1940D	2017-08-01 13:58:00+03	46200.00
C19449	2017-08-09 08:22:00+03	35600.00
C194C1	2017-07-18 17:35:00+03	56000.00
C194D2	2017-07-15 08:30:00+03	333000.00
C194EE	2017-07-13 15:36:00+03	58800.00
C1951C	2017-08-02 15:26:00+03	75600.00
C19556	2017-07-13 07:43:00+03	23600.00
C19572	2017-06-29 14:52:00+03	28800.00
C195A3	2017-07-13 06:19:00+03	24000.00
C195B5	2017-08-12 01:32:00+03	54800.00
C195DC	2017-08-02 00:11:00+03	26200.00
C19607	2017-07-01 04:34:00+03	12400.00
C19653	2017-07-09 02:38:00+03	181600.00
C19667	2017-07-29 16:24:00+03	25000.00
C19670	2017-07-09 03:30:00+03	14800.00
C1967A	2017-08-13 04:52:00+03	55600.00
C196A9	2017-07-04 00:42:00+03	34800.00
C196EB	2017-07-29 19:03:00+03	166100.00
C196EE	2017-07-11 02:49:00+03	26000.00
C19722	2017-07-31 00:12:00+03	23200.00
C19728	2017-08-13 22:21:00+03	135600.00
C1977C	2017-08-10 06:31:00+03	18000.00
C19791	2017-07-03 08:09:00+03	93000.00
C197CE	2017-06-28 17:40:00+03	150000.00
C19812	2017-07-13 19:15:00+03	14000.00
C19826	2017-08-08 05:56:00+03	31900.00
C19873	2017-07-19 16:46:00+03	47000.00
C198B3	2017-07-19 17:46:00+03	31000.00
C198F0	2017-08-02 12:26:00+03	13800.00
C19934	2017-08-14 23:34:00+03	75300.00
C199E3	2017-08-10 02:20:00+03	202000.00
C19A58	2017-07-01 17:36:00+03	39200.00
C19B0E	2017-08-14 19:00:00+03	18600.00
C19B97	2017-07-31 17:46:00+03	79600.00
C19BEE	2017-08-04 22:10:00+03	26000.00
C19C3E	2017-07-24 02:08:00+03	96300.00
C19C90	2017-08-11 17:01:00+03	40800.00
C19C9D	2017-08-14 06:20:00+03	272300.00
C19CA7	2017-07-19 22:18:00+03	51200.00
C19CBF	2017-08-09 17:28:00+03	54800.00
C19D62	2017-07-16 16:24:00+03	65100.00
C19D7F	2017-08-10 14:17:00+03	40800.00
C19E4A	2017-07-18 12:14:00+03	56600.00
C19ECC	2017-08-15 15:22:00+03	51900.00
C19F81	2017-07-25 23:29:00+03	248400.00
C19F8F	2017-06-28 22:55:00+03	37900.00
C19FB8	2017-08-05 23:01:00+03	60400.00
C19FC4	2017-07-11 16:43:00+03	10100.00
C1A031	2017-07-02 01:47:00+03	13600.00
C1A04C	2017-07-16 13:04:00+03	68800.00
C1A04D	2017-08-09 14:44:00+03	40000.00
C1A053	2017-07-20 14:51:00+03	32400.00
C1A05E	2017-07-25 02:18:00+03	39200.00
C1A0FC	2017-07-31 06:07:00+03	42700.00
C1A119	2017-08-10 02:07:00+03	26800.00
C1A145	2017-07-23 02:48:00+03	88600.00
C1A18D	2017-08-11 18:06:00+03	30400.00
C1A253	2017-07-28 18:21:00+03	26000.00
C1A25B	2017-07-10 15:55:00+03	12400.00
C1A2A3	2017-07-11 21:40:00+03	152900.00
C1A2B8	2017-08-14 10:19:00+03	15800.00
C1A360	2017-08-03 07:43:00+03	111600.00
C1A3EF	2017-08-14 14:25:00+03	73800.00
C1A445	2017-06-28 04:19:00+03	26000.00
C1A44C	2017-08-11 13:12:00+03	155200.00
C1A45E	2017-08-08 23:35:00+03	16400.00
C1A4CE	2017-07-23 16:51:00+03	36200.00
C1A536	2017-07-14 13:24:00+03	56100.00
C1A541	2017-07-13 08:03:00+03	150500.00
C1A572	2017-07-06 08:38:00+03	64500.00
C1A596	2017-07-27 03:38:00+03	7400.00
C1A5CF	2017-07-29 00:26:00+03	121400.00
C1A5D3	2017-07-29 07:29:00+03	67400.00
C1A668	2017-07-22 15:03:00+03	56000.00
C1A6B3	2017-08-05 14:38:00+03	45600.00
C1A7A8	2017-08-07 16:20:00+03	133200.00
C1A7C1	2017-07-11 09:00:00+03	42000.00
C1A7CB	2017-07-04 20:11:00+03	25000.00
C1A7FC	2017-07-28 22:45:00+03	248500.00
C1A807	2017-08-01 08:37:00+03	134400.00
C1A844	2017-07-25 03:51:00+03	92800.00
C1A86F	2017-08-15 01:58:00+03	56600.00
C1A8D3	2017-07-21 07:41:00+03	62600.00
C1A939	2017-08-13 15:41:00+03	533300.00
C1A969	2017-07-11 18:11:00+03	127300.00
C1A9CA	2017-07-07 03:40:00+03	266400.00
C1A9E9	2017-08-07 15:13:00+03	86300.00
C1AA22	2017-07-22 01:45:00+03	56200.00
C1AA32	2017-07-15 08:18:00+03	37900.00
C1AA89	2017-07-01 18:59:00+03	55800.00
C1AB09	2017-07-02 16:47:00+03	13400.00
C1AB1E	2017-07-18 14:58:00+03	28800.00
C1ABA1	2017-07-15 19:47:00+03	15100.00
C1ABB7	2017-07-17 00:14:00+03	6400.00
C1ABEF	2017-08-15 06:53:00+03	62500.00
C1AC31	2017-07-05 12:17:00+03	75300.00
C1AC65	2017-07-17 16:33:00+03	64500.00
C1AC79	2017-07-28 12:36:00+03	43600.00
C1ACE6	2017-07-02 23:21:00+03	56100.00
C1ACEE	2017-08-10 12:04:00+03	350800.00
C1ACFA	2017-07-17 08:47:00+03	260300.00
C1AD4B	2017-07-22 15:39:00+03	44000.00
C1AD91	2017-08-01 23:07:00+03	111000.00
C1ADF3	2017-08-07 18:33:00+03	88100.00
C1AE01	2017-07-28 23:57:00+03	270000.00
C1AE02	2017-08-05 14:08:00+03	131800.00
C1AE8C	2017-07-04 00:37:00+03	28000.00
C1AE93	2017-07-15 13:51:00+03	62600.00
C1AEA5	2017-08-13 16:38:00+03	86200.00
C1AF5D	2017-06-29 08:33:00+03	66100.00
C1AFA1	2017-06-30 06:19:00+03	34600.00
C1AFE3	2017-08-04 16:36:00+03	141000.00
C1AFF0	2017-06-30 03:49:00+03	73500.00
C1B026	2017-07-03 09:54:00+03	23600.00
C1B02F	2017-07-21 20:05:00+03	29600.00
C1B05D	2017-07-08 21:38:00+03	55800.00
C1B06E	2017-07-02 05:30:00+03	369000.00
C1B0AD	2017-08-07 20:10:00+03	36200.00
C1B0E0	2017-08-11 16:43:00+03	136000.00
C1B16C	2017-07-05 15:52:00+03	6000.00
C1B219	2017-08-15 14:15:00+03	88100.00
C1B2BF	2017-08-15 01:13:00+03	28800.00
C1B2D2	2017-07-14 10:24:00+03	47100.00
C1B352	2017-07-22 15:52:00+03	26200.00
C1B385	2017-07-02 17:58:00+03	100800.00
C1B43D	2017-07-29 05:47:00+03	28800.00
C1B452	2017-07-30 07:49:00+03	76600.00
C1B51E	2017-07-16 08:32:00+03	15000.00
C1B55A	2017-07-31 15:50:00+03	25400.00
C1B56C	2017-06-30 20:19:00+03	45000.00
C1B56E	2017-07-31 20:10:00+03	66600.00
C1B59E	2017-07-14 14:43:00+03	78200.00
C1B59F	2017-08-11 16:15:00+03	61200.00
C1B5A9	2017-07-26 04:09:00+03	23200.00
C1B5CE	2017-07-28 03:11:00+03	106500.00
C1B5D5	2017-07-22 13:43:00+03	84000.00
C1B5E8	2017-08-04 15:11:00+03	56000.00
C1B612	2017-07-26 12:06:00+03	6000.00
C1B633	2017-07-05 09:40:00+03	113000.00
C1B639	2017-07-27 17:05:00+03	86300.00
C1B641	2017-07-22 06:29:00+03	12600.00
C1B712	2017-08-06 02:25:00+03	68400.00
C1B729	2017-07-20 01:09:00+03	62200.00
C1B735	2017-07-30 12:40:00+03	73600.00
C1B7AB	2017-07-11 17:59:00+03	59800.00
C1B7C3	2017-08-14 06:19:00+03	74800.00
C1B834	2017-08-09 19:31:00+03	119600.00
C1B84B	2017-07-06 08:12:00+03	89500.00
C1B857	2017-08-04 04:06:00+03	44800.00
C1B87A	2017-08-09 10:49:00+03	125000.00
C1B8F2	2017-08-05 17:33:00+03	31400.00
C1B91F	2017-07-06 09:21:00+03	56000.00
C1BB2C	2017-07-26 00:51:00+03	97900.00
C1BB70	2017-08-11 05:21:00+03	67600.00
C1BC31	2017-07-19 08:52:00+03	64400.00
C1BC6D	2017-07-29 01:04:00+03	30200.00
C1BC8B	2017-08-07 20:03:00+03	55800.00
C1BC8C	2017-07-30 00:28:00+03	56600.00
C1BC94	2017-07-18 20:19:00+03	81700.00
C1BCB3	2017-07-03 22:26:00+03	119400.00
C1BCC0	2017-08-04 22:40:00+03	26000.00
C1BCE4	2017-07-25 07:42:00+03	81800.00
C1BD37	2017-07-24 12:51:00+03	9200.00
C1BD65	2017-07-23 09:47:00+03	45200.00
C1BD72	2017-08-07 23:07:00+03	115600.00
C1BD7F	2017-07-30 01:23:00+03	71200.00
C1BDAA	2017-07-16 22:35:00+03	86600.00
C1BDED	2017-08-01 04:29:00+03	13000.00
C1BE2B	2017-07-27 16:58:00+03	18800.00
C1BE65	2017-08-01 15:17:00+03	16400.00
C1BE98	2017-07-11 04:32:00+03	81300.00
C1BEDE	2017-08-02 07:14:00+03	53400.00
C1BF64	2017-08-12 17:59:00+03	40800.00
C1BF89	2017-08-10 19:35:00+03	133700.00
C1BFBA	2017-08-04 15:18:00+03	19600.00
C1BFF3	2017-07-06 22:53:00+03	70800.00
C1C066	2017-07-28 11:11:00+03	492000.00
C1C072	2017-08-07 02:44:00+03	6600.00
C1C0E1	2017-08-14 02:42:00+03	28000.00
C1C135	2017-07-15 06:36:00+03	92800.00
C1C151	2017-07-25 13:54:00+03	66400.00
C1C160	2017-07-23 16:00:00+03	250500.00
C1C1A1	2017-08-02 02:06:00+03	67000.00
C1C21A	2017-08-12 15:54:00+03	111600.00
C1C239	2017-07-05 08:54:00+03	39800.00
C1C257	2017-07-27 15:27:00+03	88800.00
C1C272	2017-07-26 08:05:00+03	102300.00
C1C283	2017-07-24 01:05:00+03	74800.00
C1C2DF	2017-08-14 20:04:00+03	12600.00
C1C33E	2017-07-19 08:57:00+03	34600.00
C1C345	2017-07-08 02:22:00+03	42700.00
C1C3EE	2017-07-13 01:44:00+03	86400.00
C1C447	2017-07-21 01:04:00+03	46000.00
C1C477	2017-07-27 20:01:00+03	56100.00
C1C483	2017-07-22 11:06:00+03	39800.00
C1C498	2017-07-22 03:15:00+03	93000.00
C1C540	2017-08-15 06:50:00+03	26700.00
C1C560	2017-07-13 01:17:00+03	26000.00
C1C5D9	2017-07-31 17:39:00+03	23200.00
C1C5FC	2017-07-05 04:18:00+03	131800.00
C1C61F	2017-08-09 00:30:00+03	28000.00
C1C71B	2017-07-15 18:40:00+03	45400.00
C1C7A8	2017-07-05 14:09:00+03	169300.00
C1C7BA	2017-07-15 07:33:00+03	179100.00
C1C7BE	2017-07-06 21:00:00+03	30400.00
C1C7C7	2017-07-16 06:36:00+03	14000.00
C1C7E1	2017-07-31 15:57:00+03	62600.00
C1C8DF	2017-08-04 13:48:00+03	187600.00
C1C951	2017-07-14 04:46:00+03	87100.00
C1C975	2017-08-03 01:12:00+03	122000.00
C1CA4E	2017-08-03 13:16:00+03	85400.00
C1CB7A	2017-07-11 07:21:00+03	30200.00
C1CB8B	2017-07-21 00:24:00+03	176400.00
C1CBD4	2017-07-07 22:34:00+03	133100.00
C1CBF8	2017-07-27 03:30:00+03	6700.00
C1CC19	2017-07-26 03:01:00+03	100000.00
C1CC86	2017-08-04 07:36:00+03	264000.00
C1CC94	2017-07-11 17:16:00+03	183300.00
C1CC9A	2017-07-15 23:44:00+03	56000.00
C1CCAB	2017-07-30 09:22:00+03	99400.00
C1CCB1	2017-07-29 13:20:00+03	23600.00
C1CD04	2017-07-05 13:12:00+03	12000.00
C1CD91	2017-08-01 10:32:00+03	32200.00
C1CDB2	2017-07-04 00:58:00+03	21400.00
C1CDF5	2017-08-05 09:23:00+03	15800.00
C1CDF6	2017-08-07 09:59:00+03	57400.00
C1CE00	2017-07-11 19:54:00+03	118500.00
C1CE47	2017-08-13 20:12:00+03	37600.00
C1CE4B	2017-07-11 14:21:00+03	48900.00
C1CE77	2017-08-03 02:01:00+03	38800.00
C1CEA4	2017-07-05 17:16:00+03	117600.00
C1CF1C	2017-07-24 19:03:00+03	26000.00
C1D041	2017-07-25 19:47:00+03	90700.00
C1D0AF	2017-08-06 15:01:00+03	17800.00
C1D0BE	2017-08-04 00:50:00+03	29600.00
C1D126	2017-07-31 12:11:00+03	153200.00
C1D14F	2017-08-03 13:22:00+03	46800.00
C1D151	2017-07-13 02:55:00+03	47100.00
C1D157	2017-07-13 12:29:00+03	37900.00
C1D1C1	2017-07-25 12:19:00+03	112000.00
C1D207	2017-08-01 22:11:00+03	169900.00
C1D21B	2017-07-04 05:11:00+03	25200.00
C1D291	2017-07-08 22:38:00+03	24700.00
C1D2DF	2017-08-13 11:22:00+03	100000.00
C1D310	2017-08-14 10:06:00+03	55800.00
C1D364	2017-08-08 17:17:00+03	12000.00
C1D388	2017-07-29 02:43:00+03	16400.00
C1D3C1	2017-07-09 03:06:00+03	28000.00
C1D408	2017-07-02 14:59:00+03	123000.00
C1D410	2017-07-27 02:57:00+03	81600.00
C1D429	2017-08-12 04:52:00+03	25100.00
C1D480	2017-07-26 14:01:00+03	297400.00
C1D48B	2017-07-12 12:23:00+03	120400.00
C1D4BB	2017-07-03 09:15:00+03	38600.00
C1D52A	2017-07-31 15:09:00+03	52000.00
C1D609	2017-07-17 02:11:00+03	135600.00
C1D65D	2017-07-11 05:11:00+03	36200.00
C1D677	2017-08-09 04:08:00+03	64700.00
C1D707	2017-07-17 07:53:00+03	32700.00
C1D70B	2017-08-06 03:17:00+03	492000.00
C1D7C5	2017-07-19 06:48:00+03	81800.00
C1D7C9	2017-07-13 23:35:00+03	25400.00
C1D89C	2017-07-07 09:01:00+03	58000.00
C1D8C9	2017-08-03 04:29:00+03	26000.00
C1D8E3	2017-07-09 03:14:00+03	169300.00
C1D8E4	2017-08-10 18:53:00+03	8000.00
C1D906	2017-07-24 21:30:00+03	59900.00
C1D953	2017-08-11 22:05:00+03	29400.00
C1D95A	2017-08-02 22:11:00+03	18800.00
C1D96E	2017-07-28 20:26:00+03	80700.00
C1D9B1	2017-08-11 14:10:00+03	31600.00
C1DA03	2017-08-06 10:51:00+03	48500.00
C1DA47	2017-07-01 09:50:00+03	112000.00
C1DAAF	2017-08-04 01:36:00+03	297000.00
C1DAC5	2017-07-13 15:38:00+03	26000.00
C1DB09	2017-08-10 11:08:00+03	28000.00
C1DBB3	2017-07-05 16:45:00+03	26000.00
C1DBE1	2017-07-06 21:54:00+03	131600.00
C1DC4A	2017-08-09 01:17:00+03	156500.00
C1DC68	2017-08-02 06:31:00+03	45100.00
C1DC80	2017-08-01 00:22:00+03	36200.00
C1DC93	2017-07-29 16:47:00+03	234700.00
C1DCAC	2017-06-30 20:06:00+03	25200.00
C1DD2A	2017-06-30 04:04:00+03	56000.00
C1DD6A	2017-07-08 16:27:00+03	65500.00
C1DD95	2017-06-30 18:42:00+03	16400.00
C1DE1A	2017-08-02 13:59:00+03	136200.00
C1DEC4	2017-08-09 06:20:00+03	31100.00
C1DEC7	2017-07-29 16:22:00+03	48300.00
C1DEDA	2017-07-01 20:40:00+03	52800.00
C1DEEB	2017-07-16 07:51:00+03	380200.00
C1DFCC	2017-07-23 05:26:00+03	27200.00
C1E027	2017-08-04 17:25:00+03	43800.00
C1E065	2017-07-16 13:44:00+03	89700.00
C1E10A	2017-07-12 18:40:00+03	40200.00
C1E112	2017-08-10 13:08:00+03	369000.00
C1E122	2017-08-13 12:11:00+03	83300.00
C1E16E	2017-08-04 07:34:00+03	201200.00
C1E1AA	2017-08-03 14:23:00+03	63500.00
C1E300	2017-07-05 06:17:00+03	31600.00
C1E32F	2017-07-10 14:35:00+03	28800.00
C1E344	2017-07-04 17:37:00+03	28800.00
C1E348	2017-08-13 23:50:00+03	131400.00
C1E359	2017-07-20 01:54:00+03	56600.00
C1E398	2017-07-17 02:34:00+03	26100.00
C1E3E0	2017-08-06 01:05:00+03	20400.00
C1E42E	2017-08-14 18:53:00+03	136400.00
C1E43C	2017-06-28 23:07:00+03	181100.00
C1E457	2017-08-04 14:05:00+03	139300.00
C1E470	2017-07-13 13:50:00+03	177200.00
C1E4DD	2017-08-03 15:49:00+03	70800.00
C1E4F5	2017-07-23 18:41:00+03	246000.00
C1E4F8	2017-07-08 02:05:00+03	39900.00
C1E522	2017-08-12 13:46:00+03	132800.00
C1E529	2017-07-25 11:41:00+03	71900.00
C1E539	2017-08-05 18:41:00+03	6700.00
C1E5EC	2017-07-08 13:37:00+03	44800.00
C1E62E	2017-08-15 14:40:00+03	40200.00
C1E63D	2017-07-09 02:36:00+03	115100.00
C1E645	2017-08-08 16:06:00+03	3700.00
C1E66A	2017-07-11 11:27:00+03	45600.00
C1E699	2017-08-02 06:26:00+03	133100.00
C1E6CC	2017-07-09 21:45:00+03	26700.00
C1E6DD	2017-07-14 17:10:00+03	123000.00
C1E733	2017-07-22 14:52:00+03	68100.00
C1E73D	2017-07-19 06:23:00+03	23200.00
C1E7A0	2017-06-28 17:51:00+03	62000.00
C1E7E9	2017-06-30 16:05:00+03	47200.00
C1E85D	2017-07-24 16:26:00+03	23200.00
C1E868	2017-06-28 01:18:00+03	28000.00
C1E877	2017-07-02 11:30:00+03	62800.00
C1E8C4	2017-07-10 09:13:00+03	79700.00
C1E8E7	2017-07-17 22:21:00+03	147400.00
C1E8E9	2017-07-24 07:07:00+03	39600.00
C1E988	2017-07-07 01:27:00+03	396500.00
C1E9BF	2017-07-29 13:40:00+03	65500.00
C1E9FF	2017-07-17 04:36:00+03	56100.00
C1EA10	2017-08-08 22:51:00+03	118300.00
C1EA21	2017-08-03 21:13:00+03	189200.00
C1EA33	2017-07-04 19:32:00+03	75300.00
C1EA68	2017-07-08 22:56:00+03	37700.00
C1EAA3	2017-08-11 03:59:00+03	12600.00
C1EC31	2017-07-25 02:47:00+03	24300.00
C1EC3C	2017-07-20 02:58:00+03	26200.00
C1ECF8	2017-07-17 05:09:00+03	131100.00
C1ED83	2017-07-08 10:04:00+03	14400.00
C1EDC3	2017-08-15 10:36:00+03	39800.00
C1EE3C	2017-07-30 00:55:00+03	55800.00
C1EEAA	2017-07-15 03:10:00+03	55800.00
C1EEBF	2017-08-04 10:00:00+03	97600.00
C1EEC8	2017-08-03 19:42:00+03	185000.00
C1EEE5	2017-07-14 05:05:00+03	72800.00
C1EF3C	2017-07-20 12:18:00+03	20200.00
C1EF44	2017-07-27 17:11:00+03	32800.00
C1EF47	2017-07-27 00:54:00+03	30900.00
C1EF87	2017-07-19 23:55:00+03	137100.00
C1EF8A	2017-08-08 15:48:00+03	61400.00
C1EF93	2017-08-12 02:48:00+03	23400.00
C1EFE7	2017-07-16 22:44:00+03	53000.00
C1F001	2017-07-13 14:21:00+03	124200.00
C1F03A	2017-08-11 13:59:00+03	27200.00
C1F091	2017-07-27 14:32:00+03	124200.00
C1F0D6	2017-08-02 07:12:00+03	13400.00
C1F12B	2017-08-09 11:30:00+03	24400.00
C1F1B2	2017-07-10 06:42:00+03	73500.00
C1F1D3	2017-08-12 22:53:00+03	23600.00
C1F1E7	2017-08-02 15:59:00+03	11600.00
C1F1FD	2017-07-30 16:32:00+03	56000.00
C1F20B	2017-07-04 04:16:00+03	31500.00
C1F221	2017-08-04 12:28:00+03	166700.00
C1F2B6	2017-07-14 19:41:00+03	157400.00
C1F2F5	2017-08-07 08:58:00+03	38100.00
C1F327	2017-07-09 02:48:00+03	229900.00
C1F353	2017-08-03 18:16:00+03	75000.00
C1F390	2017-07-16 16:55:00+03	21200.00
C1F3B8	2017-08-12 20:50:00+03	254900.00
C1F449	2017-08-15 07:58:00+03	55800.00
C1F44D	2017-08-15 04:07:00+03	26000.00
C1F4F0	2017-08-03 05:50:00+03	188500.00
C1F4F5	2017-07-14 21:22:00+03	67200.00
C1F52E	2017-07-22 03:54:00+03	72400.00
C1F533	2017-07-22 02:33:00+03	19600.00
C1F54D	2017-08-04 18:35:00+03	99300.00
C1F560	2017-07-15 04:50:00+03	291600.00
C1F5C1	2017-07-25 14:57:00+03	126500.00
C1F5D3	2017-08-08 09:52:00+03	75300.00
C1F627	2017-07-16 16:09:00+03	7400.00
C1F628	2017-08-10 07:00:00+03	59200.00
C1F63B	2017-07-18 14:11:00+03	40800.00
C1F652	2017-07-17 18:32:00+03	65000.00
C1F69D	2017-07-02 03:16:00+03	325500.00
C1F6A0	2017-07-01 10:37:00+03	12600.00
C1F6BA	2017-07-24 22:16:00+03	522600.00
C1F70C	2017-08-11 18:01:00+03	37300.00
C1F714	2017-07-30 09:19:00+03	31400.00
C1F747	2017-07-24 23:13:00+03	6000.00
C1F794	2017-08-12 06:30:00+03	62800.00
C1F79B	2017-07-28 06:46:00+03	46400.00
C1F7DA	2017-07-04 10:12:00+03	36200.00
C1F82C	2017-08-02 00:15:00+03	54000.00
C1F972	2017-07-12 02:47:00+03	55800.00
C1F984	2017-07-12 04:36:00+03	116400.00
C1F9DE	2017-07-30 18:58:00+03	149600.00
C1F9E7	2017-08-07 22:35:00+03	155600.00
C1FA04	2017-07-09 14:53:00+03	26800.00
C1FA7F	2017-08-11 02:27:00+03	13400.00
C1FA88	2017-07-31 07:40:00+03	75600.00
C1FAD1	2017-08-09 15:06:00+03	444600.00
C1FADF	2017-08-14 09:03:00+03	56000.00
C1FB54	2017-07-30 09:41:00+03	25600.00
C1FBD3	2017-08-11 23:58:00+03	34200.00
C1FBD7	2017-07-03 03:29:00+03	43200.00
C1FBE2	2017-06-29 12:17:00+03	55800.00
C1FC35	2017-07-24 10:07:00+03	17600.00
C1FC42	2017-08-01 22:39:00+03	116800.00
C1FC70	2017-08-14 13:58:00+03	25600.00
C1FC92	2017-08-14 19:09:00+03	191200.00
C1FC9C	2017-08-05 00:36:00+03	113100.00
C1FCAB	2017-08-14 21:49:00+03	290500.00
C1FD35	2017-06-29 12:20:00+03	28000.00
C1FD5C	2017-08-06 05:08:00+03	119300.00
C1FD5E	2017-07-05 08:27:00+03	98000.00
C1FD7C	2017-07-13 02:02:00+03	52400.00
C1FDEC	2017-08-14 01:07:00+03	60400.00
C1FE2A	2017-07-30 22:50:00+03	105400.00
C1FE81	2017-08-03 18:59:00+03	260900.00
C1FEE5	2017-08-13 21:21:00+03	114800.00
C1FF3C	2017-08-07 10:38:00+03	78000.00
C1FFA9	2017-07-25 09:40:00+03	126300.00
C1FFAC	2017-08-08 20:44:00+03	14800.00
C1FFDC	2017-08-15 08:12:00+03	398400.00
C20000	2017-08-01 03:15:00+03	38900.00
C20008	2017-07-26 12:45:00+03	9800.00
C20032	2017-07-08 03:13:00+03	68000.00
C20054	2017-07-05 10:34:00+03	106800.00
C2010D	2017-08-01 10:29:00+03	270000.00
C20167	2017-08-10 20:27:00+03	68800.00
C201A7	2017-07-23 05:14:00+03	26800.00
C201CD	2017-07-20 16:37:00+03	33600.00
C201FE	2017-07-12 11:22:00+03	57200.00
C20242	2017-07-09 02:52:00+03	29600.00
C2027E	2017-08-11 05:40:00+03	41800.00
C202DB	2017-07-06 18:12:00+03	52000.00
C202E0	2017-06-27 21:34:00+03	25800.00
C202FB	2017-08-05 02:09:00+03	34400.00
C20362	2017-07-28 04:22:00+03	58900.00
C20363	2017-08-04 05:49:00+03	102100.00
C2036B	2017-07-13 20:22:00+03	47200.00
C20385	2017-07-14 16:24:00+03	75300.00
C203AD	2017-07-06 09:59:00+03	248300.00
C203B0	2017-08-06 19:33:00+03	82900.00
C20413	2017-08-02 22:30:00+03	19600.00
C20435	2017-08-08 20:55:00+03	17800.00
C204CA	2017-07-02 22:46:00+03	40000.00
C204DD	2017-07-17 05:53:00+03	20200.00
C20555	2017-08-15 05:17:00+03	13400.00
C2056D	2017-07-18 03:42:00+03	148100.00
C205A4	2017-07-17 14:19:00+03	28000.00
C2064B	2017-06-28 06:45:00+03	84500.00
C2067E	2017-07-24 19:04:00+03	28000.00
C206BF	2017-07-21 02:40:00+03	21200.00
C206E8	2017-08-14 02:35:00+03	40700.00
C2070A	2017-08-07 03:04:00+03	40000.00
C20728	2017-07-12 16:37:00+03	46300.00
C2075F	2017-08-12 03:16:00+03	35400.00
C207B7	2017-07-17 02:19:00+03	65300.00
C207C2	2017-08-12 00:08:00+03	20200.00
C20800	2017-08-09 21:20:00+03	630400.00
C20804	2017-07-26 04:22:00+03	146300.00
C20821	2017-08-06 15:08:00+03	270700.00
C20853	2017-07-16 01:25:00+03	40000.00
C2094B	2017-07-10 12:14:00+03	36000.00
C20972	2017-07-24 16:33:00+03	67600.00
C209ED	2017-07-18 05:05:00+03	91100.00
C20A13	2017-06-29 09:24:00+03	265800.00
C20A1F	2017-08-10 19:27:00+03	58800.00
C20A72	2017-07-30 22:45:00+03	274200.00
C20AAC	2017-06-28 11:38:00+03	28000.00
C20B20	2017-08-13 08:38:00+03	13700.00
C20B38	2017-07-21 15:11:00+03	24400.00
C20B64	2017-07-20 04:11:00+03	32800.00
C20B93	2017-07-15 23:44:00+03	133300.00
C20BC8	2017-07-21 22:50:00+03	24400.00
C20BF8	2017-08-06 18:34:00+03	224000.00
C20C8D	2017-07-14 22:51:00+03	77200.00
C20D5C	2017-07-30 05:29:00+03	36000.00
C20E5A	2017-07-31 21:35:00+03	29400.00
C20E65	2017-07-08 07:02:00+03	278000.00
C20EF9	2017-08-12 11:53:00+03	14000.00
C20F3A	2017-08-05 12:48:00+03	24700.00
C20F44	2017-07-23 05:20:00+03	258400.00
C20FCC	2017-07-23 01:43:00+03	51500.00
C20FED	2017-08-13 16:13:00+03	62300.00
C2100A	2017-07-31 04:50:00+03	69400.00
C21027	2017-07-18 10:43:00+03	6800.00
C2104E	2017-08-07 03:46:00+03	8200.00
C210C0	2017-07-05 23:43:00+03	136200.00
C210CD	2017-07-08 19:50:00+03	23600.00
C210EF	2017-07-08 23:49:00+03	73600.00
C210FD	2017-08-08 21:38:00+03	101200.00
C21100	2017-07-01 13:46:00+03	53700.00
C2113D	2017-07-10 18:56:00+03	23200.00
C21166	2017-07-07 20:41:00+03	192400.00
C211F6	2017-07-14 03:17:00+03	35800.00
C21205	2017-06-28 15:33:00+03	20400.00
C21206	2017-08-13 01:14:00+03	547000.00
C2120D	2017-07-31 04:24:00+03	168000.00
C2121D	2017-07-05 07:25:00+03	88500.00
C212BC	2017-08-14 17:32:00+03	46800.00
C212CA	2017-07-13 19:09:00+03	37600.00
C212D9	2017-07-22 18:52:00+03	31600.00
C21334	2017-07-31 07:20:00+03	21800.00
C2135B	2017-07-30 09:04:00+03	242700.00
C213B0	2017-08-08 21:33:00+03	13800.00
C213B4	2017-07-08 13:35:00+03	45200.00
C213C0	2017-08-15 17:29:00+03	26000.00
C213D4	2017-07-29 14:24:00+03	111700.00
C213FB	2017-07-02 12:18:00+03	40800.00
C214A9	2017-07-26 09:20:00+03	39700.00
C214B1	2017-07-16 00:58:00+03	131100.00
C214E1	2017-08-15 00:37:00+03	326200.00
C21537	2017-07-27 07:00:00+03	131600.00
C2154F	2017-08-04 10:06:00+03	47400.00
C2155E	2017-07-22 02:39:00+03	81800.00
C21589	2017-07-12 22:57:00+03	56900.00
C21591	2017-07-29 19:49:00+03	23200.00
C215DF	2017-07-17 02:09:00+03	23200.00
C21602	2017-08-14 13:01:00+03	47000.00
C21685	2017-07-05 14:55:00+03	39800.00
C216C1	2017-07-12 03:05:00+03	35200.00
C216CD	2017-07-25 22:24:00+03	22000.00
C216D0	2017-08-11 16:30:00+03	62700.00
C217CA	2017-07-11 18:51:00+03	131800.00
C217DD	2017-07-26 09:21:00+03	16800.00
C217EB	2017-07-29 08:59:00+03	37900.00
C217FB	2017-07-18 05:37:00+03	54800.00
C21873	2017-07-06 02:12:00+03	37900.00
C218B7	2017-07-18 22:44:00+03	98000.00
C218DA	2017-07-28 21:19:00+03	22000.00
C2192A	2017-07-02 15:11:00+03	28000.00
C21930	2017-08-14 07:48:00+03	13400.00
C21961	2017-07-21 18:47:00+03	135600.00
C219B9	2017-07-28 16:39:00+03	23200.00
C219F6	2017-08-07 11:19:00+03	147800.00
C21A0E	2017-08-13 17:09:00+03	31400.00
C21A16	2017-07-17 02:42:00+03	29500.00
C21A22	2017-07-16 01:17:00+03	58600.00
C21A84	2017-07-08 19:50:00+03	46000.00
C21AAC	2017-07-21 10:39:00+03	123000.00
C21B4E	2017-07-19 21:11:00+03	64400.00
C21B79	2017-07-26 03:24:00+03	85700.00
C21C06	2017-07-20 17:57:00+03	39300.00
C21C69	2017-07-13 19:33:00+03	266400.00
C21CAA	2017-07-13 01:38:00+03	339900.00
C21CDA	2017-07-29 02:46:00+03	134400.00
C21D7F	2017-07-14 12:22:00+03	135400.00
C21DAB	2017-07-13 21:19:00+03	18000.00
C21DB3	2017-07-08 01:28:00+03	28000.00
C21DDD	2017-07-18 16:13:00+03	89700.00
C21DF6	2017-08-12 16:59:00+03	183800.00
C21E09	2017-07-30 18:25:00+03	16400.00
C21E37	2017-07-27 03:19:00+03	36600.00
C21E6D	2017-07-30 13:46:00+03	591600.00
C21E85	2017-07-04 07:58:00+03	129000.00
C21ECE	2017-06-29 08:55:00+03	47000.00
C21F02	2017-07-17 09:23:00+03	83300.00
C21F71	2017-08-02 08:43:00+03	28800.00
C21F93	2017-08-02 12:07:00+03	21200.00
C21FD3	2017-07-02 05:28:00+03	111700.00
C21FE6	2017-07-28 16:11:00+03	47600.00
C21FEA	2017-07-11 10:55:00+03	24000.00
C21FEE	2017-08-13 16:53:00+03	62700.00
C22023	2017-07-08 11:30:00+03	90700.00
C22061	2017-08-05 23:13:00+03	84500.00
C2206A	2017-08-03 16:50:00+03	79600.00
C220E1	2017-07-10 13:35:00+03	65900.00
C2219D	2017-07-20 03:10:00+03	45200.00
C221A0	2017-08-07 08:45:00+03	38900.00
C221E2	2017-07-06 19:31:00+03	98400.00
C221E8	2017-07-07 09:03:00+03	168000.00
C2221B	2017-07-23 23:55:00+03	71900.00
C2222F	2017-08-12 19:29:00+03	112600.00
C222A8	2017-08-03 23:41:00+03	147700.00
C222AA	2017-07-19 04:50:00+03	21400.00
C222D6	2017-08-12 14:31:00+03	37600.00
C222DA	2017-07-28 18:37:00+03	89600.00
C222DF	2017-07-15 08:57:00+03	118600.00
C2234F	2017-07-02 20:53:00+03	23600.00
C2238D	2017-08-15 15:50:00+03	38400.00
C223FB	2017-07-22 04:29:00+03	99700.00
C2250A	2017-07-20 01:02:00+03	25600.00
C22524	2017-07-16 02:34:00+03	43200.00
C225DE	2017-07-15 12:53:00+03	43500.00
C225FE	2017-07-06 18:43:00+03	131600.00
C226F3	2017-07-25 08:32:00+03	33300.00
C2274C	2017-07-20 11:53:00+03	160400.00
C2274D	2017-07-04 11:28:00+03	117500.00
C22788	2017-07-14 07:51:00+03	40800.00
C227C0	2017-08-11 16:06:00+03	56000.00
C227EB	2017-08-14 10:42:00+03	138000.00
C227FF	2017-08-01 06:10:00+03	35900.00
C2280D	2017-07-18 18:03:00+03	16400.00
C22840	2017-08-11 02:01:00+03	83000.00
C2290E	2017-06-28 06:50:00+03	88200.00
C22927	2017-07-21 11:24:00+03	19500.00
C2293A	2017-07-19 03:29:00+03	30400.00
C22965	2017-07-25 20:36:00+03	52700.00
C22979	2017-08-07 08:00:00+03	19600.00
C22A02	2017-07-13 01:06:00+03	8200.00
C22A1D	2017-07-29 03:44:00+03	16800.00
C22A5C	2017-07-19 18:44:00+03	133800.00
C22AC3	2017-08-09 17:01:00+03	115700.00
C22B18	2017-07-09 05:33:00+03	105000.00
C22B53	2017-07-15 19:25:00+03	27700.00
C22B71	2017-07-28 20:55:00+03	105000.00
C22B83	2017-07-19 10:40:00+03	13600.00
C22B86	2017-07-09 16:36:00+03	177600.00
C22C0C	2017-08-14 00:13:00+03	65900.00
C22C1E	2017-08-04 13:47:00+03	28000.00
C22C42	2017-07-06 10:56:00+03	34700.00
C22C49	2017-08-10 20:07:00+03	75900.00
C22C7F	2017-08-12 01:12:00+03	84400.00
C22CB3	2017-07-10 22:01:00+03	33800.00
C22CEA	2017-06-30 23:41:00+03	128900.00
C22D03	2017-07-08 03:12:00+03	32900.00
C22D0B	2017-08-09 06:22:00+03	55900.00
C22D2E	2017-07-13 09:30:00+03	36200.00
C22D49	2017-07-18 17:48:00+03	28800.00
C22D95	2017-06-30 17:46:00+03	36800.00
C22DA6	2017-07-11 00:31:00+03	31600.00
C22DAA	2017-08-05 10:03:00+03	53200.00
C22DB5	2017-07-28 09:22:00+03	61800.00
C22DE5	2017-07-07 04:13:00+03	92900.00
C22E2B	2017-07-07 01:54:00+03	167500.00
C22E32	2017-07-27 20:02:00+03	28800.00
C22E59	2017-07-07 11:30:00+03	43600.00
C22E6F	2017-08-10 06:44:00+03	26000.00
C22E8E	2017-08-06 20:38:00+03	32700.00
C22EC4	2017-07-29 02:35:00+03	184500.00
C22EF4	2017-07-18 04:56:00+03	125400.00
C22EFB	2017-08-03 13:36:00+03	48800.00
C22F51	2017-07-14 21:50:00+03	27200.00
C22F56	2017-08-12 20:39:00+03	25200.00
C23011	2017-07-29 00:17:00+03	28800.00
C23019	2017-07-05 22:23:00+03	307900.00
C23081	2017-07-22 17:45:00+03	96800.00
C23083	2017-07-30 16:02:00+03	75600.00
C23084	2017-06-28 18:19:00+03	35600.00
C230CA	2017-07-07 07:49:00+03	25600.00
C230DA	2017-07-21 05:49:00+03	50100.00
C2315E	2017-07-27 15:14:00+03	23200.00
C23178	2017-07-21 10:17:00+03	38400.00
C2321F	2017-07-14 03:46:00+03	12400.00
C232B5	2017-07-04 00:54:00+03	72200.00
C232BD	2017-08-08 19:30:00+03	266400.00
C232EF	2017-07-10 12:26:00+03	28800.00
C23391	2017-07-24 21:13:00+03	176600.00
C233B0	2017-07-11 10:50:00+03	26000.00
C233B8	2017-08-05 20:25:00+03	83700.00
C233F0	2017-07-09 11:08:00+03	43000.00
C23463	2017-07-31 18:38:00+03	8200.00
C2349C	2017-08-13 19:11:00+03	92400.00
C23568	2017-07-17 21:55:00+03	61800.00
C23576	2017-07-13 23:38:00+03	16400.00
C23593	2017-07-17 12:22:00+03	169900.00
C235F6	2017-07-11 08:09:00+03	46300.00
C23696	2017-07-25 18:49:00+03	142200.00
C236AB	2017-08-06 22:22:00+03	193200.00
C2370C	2017-08-08 09:07:00+03	186900.00
C23718	2017-07-15 03:21:00+03	126300.00
C23743	2017-08-02 18:41:00+03	28000.00
C2377D	2017-07-16 18:16:00+03	111600.00
C23795	2017-07-03 03:28:00+03	48800.00
C2379D	2017-06-27 17:55:00+03	52800.00
C237B3	2017-08-13 13:25:00+03	14400.00
C237C4	2017-08-05 17:42:00+03	44400.00
C237C9	2017-07-11 01:36:00+03	38400.00
C2384D	2017-07-27 08:35:00+03	8200.00
C2385A	2017-07-21 07:24:00+03	28000.00
C23864	2017-08-13 15:27:00+03	281500.00
C23910	2017-07-27 21:50:00+03	43000.00
C23930	2017-07-04 19:50:00+03	57800.00
C23958	2017-07-27 23:21:00+03	6000.00
C2395B	2017-07-05 21:26:00+03	58800.00
C2396E	2017-07-30 07:27:00+03	61500.00
C23984	2017-07-11 16:51:00+03	170000.00
C23998	2017-08-13 17:18:00+03	67600.00
C2399A	2017-07-09 14:21:00+03	41200.00
C239EC	2017-08-04 09:56:00+03	67500.00
C239F5	2017-08-10 09:03:00+03	136100.00
C23A19	2017-07-12 16:19:00+03	313200.00
C23A78	2017-07-05 15:41:00+03	65900.00
C23B1B	2017-07-08 09:22:00+03	23100.00
C23B71	2017-07-16 18:04:00+03	117600.00
C23B9C	2017-07-05 01:25:00+03	19600.00
C23BAD	2017-07-14 13:59:00+03	49600.00
C23C1B	2017-07-08 03:42:00+03	47200.00
C23C48	2017-07-27 10:52:00+03	66600.00
C23C5F	2017-08-11 04:10:00+03	202800.00
C23CDE	2017-07-16 09:12:00+03	51000.00
C23CFA	2017-07-24 21:09:00+03	258400.00
C23D3C	2017-07-20 19:39:00+03	45100.00
C23D71	2017-07-28 22:48:00+03	6700.00
C23DC0	2017-07-31 18:49:00+03	123600.00
C23DFA	2017-07-16 20:53:00+03	111600.00
C23E16	2017-07-02 04:12:00+03	135400.00
C23F6B	2017-08-10 20:25:00+03	119300.00
C23F86	2017-07-14 12:07:00+03	296700.00
C23FBE	2017-07-12 18:28:00+03	20600.00
C23FFE	2017-07-26 22:25:00+03	131600.00
C24016	2017-08-01 11:06:00+03	66600.00
C240A0	2017-08-09 04:27:00+03	75300.00
C240CC	2017-08-14 02:23:00+03	155600.00
C240DC	2017-07-12 08:32:00+03	59200.00
C24165	2017-07-25 22:03:00+03	27000.00
C2418B	2017-08-15 07:21:00+03	128800.00
C241EE	2017-07-21 04:20:00+03	20800.00
C2422A	2017-06-30 00:11:00+03	123000.00
C2425F	2017-08-12 03:02:00+03	46400.00
C2428C	2017-08-01 14:44:00+03	24300.00
C24292	2017-08-07 23:29:00+03	8400.00
C24294	2017-07-16 18:32:00+03	56600.00
C24320	2017-07-13 09:37:00+03	192800.00
C24387	2017-07-10 00:02:00+03	32000.00
C2438B	2017-08-08 19:26:00+03	153100.00
C243B6	2017-07-01 10:57:00+03	279200.00
C243E5	2017-08-01 23:04:00+03	62400.00
C2449D	2017-08-10 07:53:00+03	46800.00
C245BC	2017-07-23 18:10:00+03	54500.00
C245C9	2017-08-08 04:28:00+03	66800.00
C24682	2017-07-31 15:31:00+03	12400.00
C246C2	2017-06-30 20:02:00+03	32400.00
C246CA	2017-08-04 06:06:00+03	222600.00
C246D8	2017-08-04 09:03:00+03	48800.00
C2478D	2017-08-08 02:46:00+03	135000.00
C247E2	2017-08-14 02:50:00+03	73400.00
C24876	2017-08-11 00:45:00+03	186000.00
C248B7	2017-07-14 17:28:00+03	32600.00
C248BE	2017-07-03 20:37:00+03	298800.00
C248C8	2017-07-29 00:44:00+03	112000.00
C248CC	2017-08-05 23:22:00+03	174800.00
C24952	2017-07-09 09:16:00+03	75300.00
C249A4	2017-07-17 20:59:00+03	38500.00
C249DF	2017-07-12 13:14:00+03	51200.00
C24AAF	2017-07-27 12:20:00+03	28000.00
C24AE0	2017-07-11 12:59:00+03	21400.00
C24B4B	2017-08-14 03:08:00+03	136200.00
C24BC5	2017-08-07 22:22:00+03	235700.00
C24D18	2017-08-14 10:29:00+03	55100.00
C24D69	2017-08-12 03:07:00+03	85000.00
C24D6C	2017-07-08 08:39:00+03	143200.00
C24D9A	2017-06-29 13:23:00+03	23900.00
C24D9B	2017-08-03 00:23:00+03	62600.00
C24E86	2017-07-05 01:34:00+03	64900.00
C24EF3	2017-07-25 21:40:00+03	67900.00
C24F17	2017-07-19 15:23:00+03	16400.00
C24F2A	2017-07-20 20:47:00+03	88800.00
C24F49	2017-07-02 21:34:00+03	40000.00
C24FC5	2017-07-13 18:12:00+03	23600.00
C24FF8	2017-08-03 16:58:00+03	136500.00
C25026	2017-07-01 02:15:00+03	88100.00
C250D4	2017-08-08 22:37:00+03	46500.00
C250D5	2017-07-13 06:09:00+03	46000.00
C25109	2017-08-08 09:48:00+03	72500.00
C2513E	2017-07-08 00:08:00+03	66600.00
C25183	2017-07-09 12:23:00+03	24400.00
C25381	2017-08-07 10:21:00+03	12400.00
C253C7	2017-08-08 12:27:00+03	62000.00
C253FB	2017-07-17 15:06:00+03	131600.00
C25403	2017-08-05 04:58:00+03	18600.00
C25411	2017-07-08 01:02:00+03	28000.00
C2542F	2017-08-12 02:42:00+03	92000.00
C2545B	2017-07-10 05:27:00+03	8000.00
C254AE	2017-07-11 17:13:00+03	67600.00
C254FD	2017-07-07 17:44:00+03	77200.00
C25613	2017-07-28 02:24:00+03	124300.00
C25627	2017-07-10 07:02:00+03	23600.00
C25642	2017-07-28 18:42:00+03	16400.00
C25674	2017-07-12 04:33:00+03	82900.00
C25689	2017-07-12 01:48:00+03	44000.00
C256CE	2017-08-05 03:58:00+03	148200.00
C25776	2017-07-09 18:25:00+03	88500.00
C25782	2017-06-30 13:10:00+03	21800.00
C25818	2017-07-27 17:22:00+03	21000.00
C25844	2017-07-24 09:17:00+03	22000.00
C2589C	2017-07-24 12:46:00+03	50300.00
C258EF	2017-08-14 05:43:00+03	147700.00
C25970	2017-07-31 22:33:00+03	159100.00
C259DC	2017-08-04 00:47:00+03	77700.00
C25A79	2017-08-07 07:42:00+03	38600.00
C25AAA	2017-06-29 19:50:00+03	83700.00
C25AC6	2017-08-15 00:34:00+03	86600.00
C25ADA	2017-07-14 17:42:00+03	39200.00
C25AEE	2017-07-15 09:31:00+03	81500.00
C25B2F	2017-07-26 01:05:00+03	111600.00
C25C16	2017-08-13 18:33:00+03	67700.00
C25C86	2017-07-11 18:42:00+03	114700.00
C25CC6	2017-08-15 07:31:00+03	52700.00
C25D58	2017-08-07 06:33:00+03	21800.00
C25D79	2017-07-27 22:40:00+03	14800.00
C25DB0	2017-07-07 18:56:00+03	116000.00
C25EB8	2017-08-14 05:06:00+03	189200.00
C25EF1	2017-07-26 11:07:00+03	45200.00
C25EF9	2017-07-10 01:03:00+03	43200.00
C25F2C	2017-07-14 13:57:00+03	6300.00
C25FDA	2017-08-01 08:57:00+03	31100.00
C26023	2017-08-05 17:12:00+03	406800.00
C2607D	2017-07-25 08:10:00+03	55800.00
C260D0	2017-07-26 09:43:00+03	81300.00
C2613F	2017-07-15 23:13:00+03	12600.00
C2615A	2017-07-15 10:10:00+03	23200.00
C2617F	2017-07-26 20:26:00+03	236900.00
C26238	2017-07-30 18:11:00+03	29200.00
C26240	2017-08-01 16:18:00+03	139700.00
C2627B	2017-07-23 16:03:00+03	42000.00
C2631F	2017-07-24 20:05:00+03	43000.00
C2633A	2017-08-09 21:59:00+03	51600.00
C263B2	2017-07-18 18:19:00+03	27200.00
C263C0	2017-08-10 23:10:00+03	56000.00
C26453	2017-07-23 23:21:00+03	37700.00
C264AD	2017-07-18 16:58:00+03	100600.00
C264DC	2017-07-15 14:59:00+03	65500.00
C26532	2017-07-30 17:13:00+03	99200.00
C2654E	2017-08-01 18:42:00+03	47200.00
C26562	2017-08-09 03:27:00+03	26000.00
C265A8	2017-07-06 21:48:00+03	38600.00
C265CB	2017-07-01 05:34:00+03	32700.00
C265F7	2017-07-08 18:07:00+03	64700.00
C26604	2017-08-05 13:57:00+03	16300.00
C2660F	2017-08-12 04:14:00+03	16400.00
C26628	2017-07-06 20:45:00+03	48300.00
C26629	2017-07-03 20:25:00+03	139100.00
C2666F	2017-08-06 13:55:00+03	137600.00
C266AF	2017-07-26 23:45:00+03	62800.00
C266C9	2017-07-13 04:12:00+03	6700.00
C266F0	2017-08-06 22:57:00+03	55800.00
C26706	2017-08-07 08:02:00+03	26000.00
C2676D	2017-07-21 11:29:00+03	70700.00
C2677B	2017-07-04 07:05:00+03	115800.00
C267B7	2017-07-29 23:15:00+03	19800.00
C2681E	2017-07-13 00:09:00+03	153200.00
C2683F	2017-07-21 07:44:00+03	21400.00
C26878	2017-07-04 14:18:00+03	38200.00
C268EB	2017-07-31 22:08:00+03	24800.00
C268F9	2017-07-09 17:32:00+03	111700.00
C2690E	2017-08-07 19:38:00+03	44600.00
C2691B	2017-08-03 23:41:00+03	92000.00
C26936	2017-07-13 22:01:00+03	50600.00
C26980	2017-07-13 19:43:00+03	47400.00
C26996	2017-07-10 02:56:00+03	39800.00
C269E5	2017-07-16 18:49:00+03	64100.00
C26A25	2017-07-09 04:46:00+03	23600.00
C26AB2	2017-06-27 23:00:00+03	17000.00
C26B4C	2017-08-15 07:02:00+03	43700.00
C26B6F	2017-07-11 02:37:00+03	160800.00
C26BD3	2017-08-10 16:54:00+03	29600.00
C26C09	2017-07-20 21:15:00+03	88900.00
C26C62	2017-07-29 06:24:00+03	148200.00
C26CE4	2017-07-23 09:47:00+03	23400.00
C26D64	2017-07-16 21:35:00+03	24800.00
C26DB3	2017-07-31 17:44:00+03	117900.00
C26DCD	2017-08-03 06:12:00+03	20200.00
C26DCF	2017-07-14 17:44:00+03	40400.00
C26DF8	2017-07-21 00:54:00+03	492200.00
C26E04	2017-08-12 05:49:00+03	206400.00
C26E49	2017-07-03 01:43:00+03	96800.00
C26E6A	2017-08-13 06:41:00+03	46200.00
C26EAA	2017-08-10 09:18:00+03	99300.00
C26F2B	2017-07-10 07:52:00+03	59300.00
C26FDE	2017-06-28 20:05:00+03	23900.00
C27005	2017-07-21 00:49:00+03	100200.00
C270CA	2017-08-12 21:06:00+03	43200.00
C2712A	2017-07-27 10:57:00+03	23200.00
C2712F	2017-08-04 03:18:00+03	167400.00
C2715D	2017-08-11 07:43:00+03	28800.00
C2723A	2017-07-05 06:28:00+03	74700.00
C2728A	2017-06-25 08:36:00+03	19600.00
C272EA	2017-07-08 10:56:00+03	27200.00
C272F6	2017-08-14 04:46:00+03	58900.00
C2739F	2017-08-07 23:39:00+03	40100.00
C273A0	2017-07-16 07:45:00+03	23500.00
C273C0	2017-08-05 06:03:00+03	25400.00
C27402	2017-08-12 23:21:00+03	141000.00
C2744F	2017-07-14 20:30:00+03	26000.00
C274AE	2017-07-19 05:17:00+03	15800.00
C274C0	2017-07-29 11:30:00+03	26000.00
C274E0	2017-07-27 12:15:00+03	61500.00
C274F2	2017-07-27 14:16:00+03	91700.00
C27536	2017-08-08 09:18:00+03	28000.00
C275CD	2017-07-27 08:52:00+03	59800.00
C275E2	2017-06-29 00:44:00+03	63800.00
C275E3	2017-07-01 17:09:00+03	156100.00
C275EB	2017-07-20 05:14:00+03	88100.00
C27731	2017-08-13 13:07:00+03	202100.00
C2778B	2017-07-11 17:25:00+03	79600.00
C277C9	2017-07-13 12:14:00+03	52000.00
C2781A	2017-07-13 06:38:00+03	84500.00
C27844	2017-08-01 02:22:00+03	70500.00
C27885	2017-07-28 09:48:00+03	28000.00
C2791E	2017-07-13 11:59:00+03	26800.00
C27971	2017-07-03 12:50:00+03	71900.00
C2798F	2017-08-06 19:12:00+03	68800.00
C279EE	2017-07-14 00:17:00+03	101200.00
C279F3	2017-08-15 08:45:00+03	115400.00
C27A27	2017-08-01 15:56:00+03	7400.00
C27A49	2017-08-14 22:20:00+03	139700.00
C27A97	2017-07-16 02:48:00+03	6700.00
C27AC1	2017-08-09 13:11:00+03	39500.00
C27C0B	2017-07-26 01:52:00+03	36200.00
C27C31	2017-07-14 09:31:00+03	81700.00
C27C34	2017-08-11 11:18:00+03	187800.00
C27CAA	2017-07-11 11:36:00+03	26800.00
C27CC4	2017-07-05 17:08:00+03	9200.00
C27CC7	2017-07-26 03:27:00+03	112000.00
C27CE1	2017-07-20 23:53:00+03	89600.00
C27D3F	2017-07-12 18:11:00+03	28000.00
C27D46	2017-07-30 04:56:00+03	146700.00
C27DAD	2017-08-03 23:30:00+03	47800.00
C27DFD	2017-08-08 16:48:00+03	83100.00
C27E36	2017-07-07 11:33:00+03	369000.00
C27E4F	2017-07-24 06:46:00+03	123000.00
C27E96	2017-08-09 23:38:00+03	246000.00
C27EAD	2017-07-30 19:02:00+03	86600.00
C27EBB	2017-07-22 05:21:00+03	47100.00
C27EF3	2017-08-07 17:33:00+03	50200.00
C27F05	2017-08-15 11:26:00+03	17000.00
C27F37	2017-08-07 00:31:00+03	40600.00
C27F42	2017-07-08 15:24:00+03	68100.00
C27F52	2017-07-10 02:25:00+03	21400.00
C27F65	2017-07-30 03:50:00+03	62100.00
C27F70	2017-08-04 15:22:00+03	24400.00
C27FE1	2017-08-08 10:00:00+03	12600.00
C28001	2017-07-28 05:06:00+03	87900.00
C28019	2017-06-25 05:28:00+03	147800.00
C28035	2017-07-17 12:48:00+03	54800.00
C28043	2017-08-13 19:44:00+03	40100.00
C28050	2017-08-14 02:14:00+03	54000.00
C28056	2017-08-01 06:21:00+03	95900.00
C2809D	2017-07-17 11:13:00+03	85000.00
C281C6	2017-07-16 11:12:00+03	41200.00
C281F9	2017-07-06 09:16:00+03	35200.00
C28223	2017-07-15 19:43:00+03	13600.00
C28260	2017-07-08 15:54:00+03	14400.00
C28328	2017-07-24 17:28:00+03	125200.00
C28367	2017-07-11 10:37:00+03	40100.00
C28387	2017-08-07 21:49:00+03	38800.00
C28390	2017-07-07 13:48:00+03	44800.00
C283BC	2017-08-12 07:27:00+03	24300.00
C283E4	2017-08-12 12:03:00+03	552000.00
C284D7	2017-07-08 07:54:00+03	101100.00
C2855D	2017-07-23 16:39:00+03	21000.00
C28584	2017-08-06 14:53:00+03	41800.00
C285F6	2017-07-09 04:13:00+03	70000.00
C28610	2017-08-10 05:33:00+03	69600.00
C28625	2017-07-24 14:01:00+03	35200.00
C28642	2017-07-10 21:20:00+03	44500.00
C28660	2017-07-13 03:40:00+03	254900.00
C2866F	2017-07-24 05:17:00+03	57300.00
C286DD	2017-06-29 06:18:00+03	30800.00
C286E3	2017-07-02 04:07:00+03	78300.00
C286E9	2017-07-03 02:07:00+03	142400.00
C286F5	2017-07-29 00:34:00+03	60400.00
C286FA	2017-08-09 15:23:00+03	32700.00
C28753	2017-07-07 11:17:00+03	16400.00
C287EB	2017-08-05 14:09:00+03	66600.00
C2883F	2017-08-06 10:25:00+03	62600.00
C28859	2017-07-22 00:54:00+03	6000.00
C2888C	2017-08-15 12:10:00+03	37100.00
C288A7	2017-07-05 21:33:00+03	6000.00
C288CC	2017-07-03 14:59:00+03	42100.00
C288CF	2017-07-16 18:03:00+03	14000.00
C288D7	2017-08-09 07:29:00+03	28800.00
C28A6A	2017-07-13 08:02:00+03	51600.00
C28B21	2017-07-09 18:11:00+03	35200.00
C28BB7	2017-06-28 01:39:00+03	93500.00
C28C28	2017-07-01 07:52:00+03	28600.00
C28C57	2017-07-05 03:55:00+03	6700.00
C28CC8	2017-08-04 20:42:00+03	62600.00
C28CD0	2017-07-26 10:09:00+03	72400.00
C28CEF	2017-07-11 10:31:00+03	48800.00
C28D0D	2017-08-06 21:14:00+03	35700.00
C28D67	2017-08-11 18:03:00+03	50800.00
C28D85	2017-07-18 05:29:00+03	149400.00
C28D8E	2017-07-24 22:27:00+03	92400.00
C28D91	2017-07-10 05:46:00+03	84000.00
C28DF2	2017-07-25 01:31:00+03	59200.00
C28E58	2017-06-29 16:21:00+03	598900.00
C28ED9	2017-07-10 06:31:00+03	291000.00
C28EEC	2017-08-12 18:25:00+03	70800.00
C28F43	2017-08-13 14:44:00+03	22600.00
C28FCF	2017-07-24 21:57:00+03	46800.00
C28FEF	2017-07-03 02:54:00+03	21800.00
C29021	2017-07-29 13:32:00+03	53600.00
C2904E	2017-07-10 11:02:00+03	46400.00
C29090	2017-07-22 00:02:00+03	62800.00
C290A3	2017-08-12 10:36:00+03	47200.00
C290D9	2017-07-06 22:06:00+03	58000.00
C29137	2017-07-25 19:55:00+03	153900.00
C2918E	2017-07-19 21:10:00+03	20200.00
C291F7	2017-08-12 02:22:00+03	52600.00
C2925D	2017-07-14 08:46:00+03	128000.00
C292A8	2017-07-28 03:04:00+03	27400.00
C292C3	2017-07-31 23:35:00+03	406700.00
C292F3	2017-08-12 05:59:00+03	99300.00
C29303	2017-08-15 13:26:00+03	46000.00
C29307	2017-07-14 19:42:00+03	14800.00
C29325	2017-08-15 10:32:00+03	12000.00
C29358	2017-06-28 14:57:00+03	6300.00
C29380	2017-07-10 13:17:00+03	38400.00
C293D1	2017-07-05 18:05:00+03	69500.00
C293EA	2017-07-22 00:58:00+03	21800.00
C29431	2017-07-20 13:52:00+03	33100.00
C29488	2017-07-27 21:29:00+03	123000.00
C2949B	2017-07-27 13:32:00+03	13400.00
C2964C	2017-07-11 19:02:00+03	56000.00
C2965C	2017-07-17 08:06:00+03	12600.00
C296D6	2017-08-02 12:56:00+03	26400.00
C29709	2017-07-13 03:23:00+03	31200.00
C2974C	2017-07-22 03:34:00+03	68300.00
C29777	2017-08-07 15:51:00+03	246000.00
C297A3	2017-07-15 16:11:00+03	125000.00
C297E6	2017-08-14 19:38:00+03	43400.00
C29808	2017-08-10 01:05:00+03	133700.00
C29833	2017-07-07 00:52:00+03	70800.00
C29848	2017-06-30 01:28:00+03	47700.00
C2986E	2017-07-30 04:01:00+03	71900.00
C298E7	2017-06-29 17:27:00+03	94700.00
C298FD	2017-07-10 22:28:00+03	14400.00
C29950	2017-08-11 01:51:00+03	405200.00
C29994	2017-06-27 04:37:00+03	91600.00
C299C3	2017-08-14 01:18:00+03	65900.00
C299CA	2017-07-19 11:32:00+03	189200.00
C299EE	2017-07-20 13:33:00+03	58000.00
C29A23	2017-07-11 06:06:00+03	15400.00
C29A44	2017-08-15 17:33:00+03	54400.00
C29A6C	2017-08-01 12:03:00+03	260300.00
C29A88	2017-08-05 18:01:00+03	63600.00
C29AFA	2017-07-05 15:54:00+03	37900.00
C29B33	2017-07-30 22:09:00+03	46400.00
C29B51	2017-07-16 07:53:00+03	66900.00
C29BB6	2017-07-08 16:08:00+03	40000.00
C29BB8	2017-07-23 07:17:00+03	124200.00
C29C1A	2017-08-15 02:30:00+03	16400.00
C29C4E	2017-07-24 10:24:00+03	14400.00
C29C5D	2017-07-19 03:27:00+03	36200.00
C29C68	2017-07-31 20:49:00+03	136200.00
C29D13	2017-07-09 07:47:00+03	43900.00
C29E7E	2017-07-14 21:04:00+03	16400.00
C29E82	2017-07-06 20:02:00+03	138200.00
C29EA3	2017-07-15 13:27:00+03	46900.00
C29EA5	2017-07-25 03:32:00+03	21400.00
C29EB4	2017-07-01 21:39:00+03	96500.00
C29EEB	2017-08-03 19:46:00+03	33300.00
C29F04	2017-08-04 02:28:00+03	188800.00
C29F14	2017-07-09 06:52:00+03	224000.00
C29FF7	2017-08-02 01:56:00+03	36200.00
C2A009	2017-08-09 15:50:00+03	40800.00
C2A012	2017-07-11 16:11:00+03	27000.00
C2A013	2017-07-10 19:30:00+03	85000.00
C2A11D	2017-07-13 04:42:00+03	29600.00
C2A188	2017-08-01 15:05:00+03	14400.00
C2A201	2017-07-02 01:27:00+03	37900.00
C2A230	2017-08-15 00:58:00+03	92600.00
C2A231	2017-07-01 03:08:00+03	67200.00
C2A2DB	2017-07-16 14:59:00+03	26000.00
C2A337	2017-07-15 20:06:00+03	66000.00
C2A33F	2017-08-06 17:03:00+03	131000.00
C2A42E	2017-08-07 14:49:00+03	23200.00
C2A462	2017-07-29 05:29:00+03	6800.00
C2A49B	2017-07-12 14:41:00+03	97800.00
C2A4B7	2017-07-15 01:42:00+03	23200.00
C2A50F	2017-07-06 14:15:00+03	22000.00
C2A525	2017-08-01 03:33:00+03	102200.00
C2A52D	2017-07-22 14:31:00+03	20100.00
C2A58E	2017-08-06 09:24:00+03	58400.00
C2A5AF	2017-07-12 17:33:00+03	46800.00
C2A611	2017-07-14 10:00:00+03	49500.00
C2A67E	2017-07-19 23:12:00+03	59800.00
C2A6E2	2017-08-08 13:17:00+03	47500.00
C2A6ED	2017-07-09 00:24:00+03	25600.00
C2A731	2017-08-11 13:44:00+03	64400.00
C2A78D	2017-07-18 11:19:00+03	123000.00
C2A79A	2017-08-06 00:41:00+03	30900.00
C2A7A9	2017-06-29 04:19:00+03	51300.00
C2A7AB	2017-07-27 08:26:00+03	58800.00
C2A7FF	2017-07-08 20:16:00+03	44000.00
C2A827	2017-07-22 17:50:00+03	38400.00
C2A82B	2017-07-19 09:28:00+03	46000.00
C2A838	2017-07-26 23:38:00+03	31100.00
C2A849	2017-07-17 14:48:00+03	58700.00
C2A84C	2017-07-31 20:53:00+03	56000.00
C2A888	2017-07-10 23:01:00+03	29200.00
C2A8C9	2017-08-11 19:59:00+03	36200.00
C2A8CA	2017-07-04 12:34:00+03	47500.00
C2A94F	2017-08-14 23:19:00+03	119600.00
C2A96E	2017-08-07 19:03:00+03	44000.00
C2A9AA	2017-07-14 14:57:00+03	170500.00
C2A9B1	2017-07-18 16:24:00+03	26700.00
C2A9BE	2017-08-15 05:26:00+03	10800.00
C2A9BF	2017-07-30 11:28:00+03	240500.00
C2A9C2	2017-08-09 23:54:00+03	7400.00
C2AA89	2017-07-09 03:36:00+03	93400.00
C2AA96	2017-08-04 11:42:00+03	94900.00
C2AAB7	2017-07-03 10:57:00+03	85000.00
C2AB28	2017-07-29 09:47:00+03	55600.00
C2AB6B	2017-07-10 23:54:00+03	89600.00
C2ABC9	2017-08-01 03:35:00+03	55800.00
C2ABD8	2017-07-22 02:09:00+03	131600.00
C2AC56	2017-07-10 02:08:00+03	34600.00
C2AC90	2017-07-19 15:45:00+03	101200.00
C2ACA4	2017-07-18 14:31:00+03	56000.00
C2ACB8	2017-08-02 18:21:00+03	199700.00
C2AD2F	2017-07-18 21:27:00+03	112600.00
C2AD4E	2017-06-30 13:47:00+03	55800.00
C2AD77	2017-08-08 08:08:00+03	43400.00
C2AD7F	2017-07-13 23:24:00+03	117200.00
C2AD91	2017-07-09 06:22:00+03	141000.00
C2AE25	2017-08-04 00:50:00+03	48100.00
C2AE38	2017-08-07 23:00:00+03	265700.00
C2AE66	2017-08-11 16:24:00+03	31400.00
C2AEC3	2017-08-05 01:24:00+03	32800.00
C2AEDD	2017-06-29 11:14:00+03	173600.00
C2AEDE	2017-08-07 07:14:00+03	192300.00
C2AEF4	2017-07-27 15:17:00+03	94300.00
C2AEF7	2017-07-09 22:13:00+03	8400.00
C2AF79	2017-07-23 03:52:00+03	31200.00
C2AF82	2017-07-05 02:54:00+03	19600.00
C2AFC0	2017-07-24 13:21:00+03	23600.00
C2B038	2017-07-20 20:41:00+03	28800.00
C2B0C9	2017-08-02 17:33:00+03	39300.00
C2B0CC	2017-07-20 01:40:00+03	120300.00
C2B0CE	2017-08-05 05:01:00+03	55800.00
C2B0E9	2017-07-30 05:39:00+03	115400.00
C2B0F3	2017-07-29 11:58:00+03	56000.00
C2B11A	2017-08-04 18:00:00+03	27800.00
C2B174	2017-06-30 18:23:00+03	129600.00
C2B1C3	2017-07-03 18:03:00+03	306200.00
C2B20C	2017-08-04 18:37:00+03	22000.00
C2B264	2017-07-24 07:15:00+03	115900.00
C2B276	2017-07-14 22:02:00+03	81900.00
C2B279	2017-08-11 10:08:00+03	93900.00
C2B28A	2017-07-01 14:13:00+03	220900.00
C2B2A2	2017-07-22 17:16:00+03	15000.00
C2B2D4	2017-06-29 04:48:00+03	91100.00
C2B2EF	2017-08-12 04:16:00+03	23600.00
C2B304	2017-07-22 06:47:00+03	44700.00
C2B374	2017-07-16 06:20:00+03	60400.00
C2B375	2017-08-13 22:16:00+03	60400.00
C2B3AE	2017-07-22 07:20:00+03	77900.00
C2B3B0	2017-07-29 23:04:00+03	147100.00
C2B3C5	2017-08-11 13:41:00+03	22100.00
C2B407	2017-07-16 20:30:00+03	70500.00
C2B51A	2017-08-08 10:43:00+03	48000.00
C2B52C	2017-07-08 06:50:00+03	14000.00
C2B53E	2017-07-13 17:58:00+03	23400.00
C2B56F	2017-08-10 12:09:00+03	26800.00
C2B5AA	2017-07-15 18:06:00+03	266200.00
C2B5ED	2017-08-04 13:35:00+03	23200.00
C2B61A	2017-08-14 20:48:00+03	56000.00
C2B622	2017-08-10 02:53:00+03	26800.00
C2B64B	2017-07-14 11:47:00+03	8200.00
C2B67E	2017-08-05 12:20:00+03	74200.00
C2B68E	2017-07-29 00:40:00+03	49600.00
C2B68F	2017-07-22 14:36:00+03	36200.00
C2B6A7	2017-07-27 03:33:00+03	6800.00
C2B6F3	2017-07-27 22:10:00+03	67400.00
C2B6FE	2017-07-02 23:24:00+03	44600.00
C2B717	2017-07-31 19:43:00+03	14400.00
C2B79B	2017-07-01 00:00:00+03	55800.00
C2B7D8	2017-07-21 12:01:00+03	113200.00
C2B803	2017-08-14 07:20:00+03	49700.00
C2B805	2017-07-30 04:38:00+03	78600.00
C2B8C0	2017-08-06 07:37:00+03	43100.00
C2B904	2017-08-13 06:02:00+03	37200.00
C2B939	2017-07-08 01:35:00+03	111600.00
C2B947	2017-07-23 07:29:00+03	11600.00
C2B949	2017-07-24 21:45:00+03	67700.00
C2B97F	2017-07-21 23:57:00+03	199700.00
C2B9D0	2017-07-19 08:28:00+03	8000.00
C2B9EB	2017-07-17 08:24:00+03	27800.00
C2BA10	2017-08-06 00:06:00+03	270000.00
C2BA39	2017-07-16 13:35:00+03	70700.00
C2BA9F	2017-08-06 20:45:00+03	20200.00
C2BABE	2017-07-05 11:07:00+03	98400.00
C2BAD4	2017-07-16 07:15:00+03	22000.00
C2BB3C	2017-08-03 02:02:00+03	132800.00
C2BB61	2017-06-27 02:27:00+03	9200.00
C2BB97	2017-07-09 13:02:00+03	29600.00
C2BB9C	2017-07-19 18:00:00+03	91200.00
C2BBD3	2017-07-26 10:39:00+03	278400.00
C2BC20	2017-07-27 02:06:00+03	31600.00
C2BCCC	2017-07-09 07:12:00+03	100600.00
C2BD49	2017-07-18 07:22:00+03	7400.00
C2BD4C	2017-08-07 06:29:00+03	14000.00
C2BDA5	2017-07-06 02:53:00+03	113100.00
C2BE2F	2017-07-31 21:31:00+03	73500.00
C2BF8E	2017-07-24 12:12:00+03	26000.00
C2C017	2017-07-20 19:14:00+03	77600.00
C2C07F	2017-07-24 10:14:00+03	32400.00
C2C0CD	2017-08-06 01:48:00+03	16000.00
C2C0DF	2017-08-07 15:08:00+03	75600.00
C2C11B	2017-08-13 08:03:00+03	15800.00
C2C127	2017-07-01 14:39:00+03	185600.00
C2C17C	2017-07-15 07:20:00+03	47800.00
C2C189	2017-07-30 02:32:00+03	136000.00
C2C19A	2017-07-10 22:29:00+03	32300.00
C2C229	2017-07-22 05:33:00+03	56000.00
C2C25A	2017-08-03 22:54:00+03	56000.00
C2C26D	2017-08-05 01:53:00+03	28000.00
C2C270	2017-07-08 04:28:00+03	31600.00
C2C2EB	2017-08-11 17:25:00+03	124600.00
C2C325	2017-07-06 17:30:00+03	28000.00
C2C34C	2017-08-06 23:02:00+03	51000.00
C2C352	2017-07-30 03:45:00+03	21800.00
C2C370	2017-07-01 20:37:00+03	270700.00
C2C40E	2017-07-29 22:57:00+03	23400.00
C2C477	2017-08-10 05:33:00+03	34000.00
C2C4CD	2017-07-08 02:10:00+03	39200.00
C2C564	2017-07-03 09:52:00+03	40600.00
C2C56E	2017-08-04 16:54:00+03	12400.00
C2C570	2017-07-25 13:56:00+03	10600.00
C2C58D	2017-08-01 09:45:00+03	94000.00
C2C5F2	2017-07-10 19:41:00+03	48800.00
C2C739	2017-08-06 03:38:00+03	55800.00
C2C747	2017-07-18 16:35:00+03	88700.00
C2C7E6	2017-07-12 03:27:00+03	58400.00
C2C837	2017-08-15 02:57:00+03	88900.00
C2C83B	2017-08-09 12:35:00+03	67400.00
C2C891	2017-08-13 08:21:00+03	61800.00
C2C897	2017-07-22 19:38:00+03	23600.00
C2C8CC	2017-07-09 02:26:00+03	213200.00
C2C900	2017-07-19 17:20:00+03	301800.00
C2C9AA	2017-07-22 18:05:00+03	128800.00
C2C9BF	2017-08-14 21:09:00+03	63300.00
C2C9C3	2017-08-15 04:21:00+03	30800.00
C2CA2C	2017-08-13 19:15:00+03	48800.00
C2CAB7	2017-07-12 20:03:00+03	6200.00
C2CABD	2017-07-21 12:24:00+03	24200.00
C2CADE	2017-07-09 06:23:00+03	24400.00
C2CAE8	2017-07-14 04:04:00+03	79300.00
C2CB02	2017-08-13 03:42:00+03	31800.00
C2CB1F	2017-07-06 06:20:00+03	18800.00
C2CB36	2017-08-10 11:48:00+03	114700.00
C2CB7B	2017-07-11 20:00:00+03	14000.00
C2CBC0	2017-07-30 03:07:00+03	160400.00
C2CBF0	2017-08-04 02:14:00+03	62800.00
C2CCAC	2017-07-30 07:45:00+03	103500.00
C2CCB3	2017-08-07 04:26:00+03	114600.00
C2CDBF	2017-08-07 22:45:00+03	25400.00
C2CE1A	2017-07-16 07:39:00+03	140000.00
C2CE51	2017-07-25 10:12:00+03	23600.00
C2CE8C	2017-08-10 01:53:00+03	86800.00
C2CF04	2017-07-02 14:48:00+03	24400.00
C2CF24	2017-07-10 02:09:00+03	85000.00
C2CF84	2017-07-18 15:38:00+03	146300.00
C2CFAE	2017-07-02 19:34:00+03	28000.00
C2D030	2017-07-13 04:43:00+03	44800.00
C2D09C	2017-07-21 08:00:00+03	292500.00
C2D0DB	2017-07-11 09:32:00+03	68100.00
C2D0E7	2017-07-09 07:22:00+03	47100.00
C2D19C	2017-07-30 21:07:00+03	29600.00
C2D21B	2017-07-18 14:39:00+03	185600.00
C2D232	2017-07-14 21:16:00+03	23200.00
C2D237	2017-07-06 07:33:00+03	17800.00
C2D262	2017-07-14 20:08:00+03	58200.00
C2D2C2	2017-08-06 11:31:00+03	24400.00
C2D2D1	2017-08-15 00:44:00+03	67800.00
C2D34A	2017-07-30 15:12:00+03	23200.00
C2D3B0	2017-08-08 11:59:00+03	41000.00
C2D3F2	2017-07-01 09:32:00+03	92700.00
C2D432	2017-07-16 05:06:00+03	87200.00
C2D433	2017-07-24 18:05:00+03	56000.00
C2D454	2017-07-09 21:01:00+03	56600.00
C2D4BD	2017-07-20 08:58:00+03	35200.00
C2D4C4	2017-07-28 19:24:00+03	51300.00
C2D4CC	2017-07-13 21:38:00+03	67600.00
C2D526	2017-07-23 05:01:00+03	118300.00
C2D5B3	2017-07-21 03:13:00+03	29600.00
C2D5CD	2017-07-24 12:36:00+03	35600.00
C2D6B7	2017-07-26 00:29:00+03	23200.00
C2D6C2	2017-08-08 14:34:00+03	38400.00
C2D6F0	2017-08-14 02:12:00+03	23600.00
C2D704	2017-07-14 03:55:00+03	167500.00
C2D718	2017-07-13 17:25:00+03	133100.00
C2D7BD	2017-08-11 13:18:00+03	97900.00
C2D861	2017-07-21 09:35:00+03	28000.00
C2D866	2017-07-30 22:13:00+03	131100.00
C2D891	2017-07-10 23:45:00+03	6600.00
C2D8B9	2017-07-17 06:44:00+03	68400.00
C2D8BA	2017-07-22 12:23:00+03	82900.00
C2D8C1	2017-07-15 06:19:00+03	64600.00
C2D8E2	2017-07-04 04:40:00+03	55800.00
C2D8F4	2017-07-20 10:00:00+03	31600.00
C2D90E	2017-06-30 12:03:00+03	61800.00
C2D911	2017-07-05 11:30:00+03	12600.00
C2D91D	2017-07-08 15:16:00+03	55600.00
C2D93B	2017-08-08 17:36:00+03	17600.00
C2D944	2017-07-10 12:13:00+03	27200.00
C2D996	2017-07-22 20:08:00+03	123000.00
C2D9F6	2017-06-30 05:09:00+03	154400.00
C2DA4D	2017-07-07 09:14:00+03	53600.00
C2DA62	2017-08-03 22:15:00+03	38200.00
C2DAD1	2017-08-03 08:02:00+03	55800.00
C2DADC	2017-07-27 05:31:00+03	26000.00
C2DB59	2017-08-14 09:12:00+03	131600.00
C2DB8D	2017-07-19 20:00:00+03	13400.00
C2DBC5	2017-08-05 08:01:00+03	15400.00
C2DBE1	2017-07-11 08:26:00+03	64800.00
C2DBE2	2017-08-12 00:32:00+03	139500.00
C2DC0A	2017-07-31 09:49:00+03	12000.00
C2DC63	2017-07-25 15:17:00+03	26000.00
C2DCB4	2017-07-05 17:35:00+03	50800.00
C2DD17	2017-08-13 19:25:00+03	46400.00
C2DD9A	2017-06-29 16:07:00+03	47400.00
C2DE65	2017-07-24 07:58:00+03	26700.00
C2DE78	2017-07-13 02:28:00+03	59300.00
C2DEA7	2017-08-09 20:21:00+03	24400.00
C2DEC0	2017-08-05 11:03:00+03	23200.00
C2DEEF	2017-07-03 19:24:00+03	188200.00
C2DF32	2017-08-13 04:27:00+03	167400.00
C2DF48	2017-07-17 19:28:00+03	46400.00
C2DF52	2017-07-25 17:09:00+03	26000.00
C2DF58	2017-07-29 11:23:00+03	60400.00
C2DF5A	2017-07-30 03:42:00+03	35700.00
C2DF7C	2017-08-10 00:02:00+03	147700.00
C2DF89	2017-06-29 04:53:00+03	16400.00
C2DFC5	2017-08-15 11:27:00+03	63900.00
C2DFF6	2017-08-01 00:57:00+03	40800.00
C2E01B	2017-07-26 07:03:00+03	23200.00
C2E04B	2017-07-30 05:45:00+03	31600.00
C2E0AE	2017-08-10 07:31:00+03	73200.00
C2E0C5	2017-07-02 00:59:00+03	49300.00
C2E0DA	2017-07-03 05:47:00+03	88800.00
C2E112	2017-07-20 01:31:00+03	59400.00
C2E11A	2017-07-09 16:27:00+03	55800.00
C2E144	2017-07-24 15:28:00+03	11300.00
C2E19F	2017-08-13 04:23:00+03	56000.00
C2E1C4	2017-08-15 17:59:00+03	28700.00
C2E245	2017-07-18 07:15:00+03	29600.00
C2E282	2017-08-05 12:15:00+03	105000.00
C2E2C3	2017-07-07 22:45:00+03	38500.00
C2E39B	2017-08-10 19:29:00+03	189200.00
C2E39E	2017-07-27 03:52:00+03	55800.00
C2E3D2	2017-07-16 09:48:00+03	77900.00
C2E3F9	2017-07-29 14:55:00+03	6400.00
C2E41F	2017-08-08 01:12:00+03	12400.00
C2E42A	2017-08-09 07:04:00+03	67900.00
C2E460	2017-07-24 12:29:00+03	541500.00
C2E4CC	2017-07-03 05:07:00+03	114800.00
C2E4F9	2017-08-02 22:07:00+03	75800.00
C2E504	2017-07-21 15:44:00+03	56000.00
C2E542	2017-07-23 01:57:00+03	42800.00
C2E55F	2017-08-01 12:40:00+03	21800.00
C2E568	2017-07-11 18:15:00+03	58200.00
C2E583	2017-07-17 16:27:00+03	133200.00
C2E5B1	2017-07-31 01:35:00+03	302400.00
C2E5E0	2017-07-31 17:40:00+03	10600.00
C2E671	2017-08-02 05:07:00+03	67400.00
C2E68D	2017-08-15 16:46:00+03	66700.00
C2E73F	2017-07-09 10:04:00+03	77900.00
C2E74C	2017-08-14 12:50:00+03	392800.00
C2E75C	2017-08-14 22:21:00+03	32400.00
C2E800	2017-07-28 06:47:00+03	133200.00
C2E876	2017-08-07 21:46:00+03	51900.00
C2E896	2017-08-03 17:59:00+03	101900.00
C2E8EF	2017-08-04 19:56:00+03	36400.00
C2E8FE	2017-07-30 11:25:00+03	127400.00
C2E949	2017-07-24 16:40:00+03	81200.00
C2E971	2017-08-12 16:57:00+03	63200.00
C2E97D	2017-07-10 06:24:00+03	24400.00
C2E9B2	2017-08-01 16:15:00+03	55800.00
C2E9F9	2017-07-31 08:14:00+03	61100.00
C2EA1A	2017-08-14 23:53:00+03	146400.00
C2EA1E	2017-07-17 22:44:00+03	43400.00
C2EA24	2017-07-23 02:55:00+03	133200.00
C2EA4D	2017-08-11 08:10:00+03	95200.00
C2EA4E	2017-08-13 14:41:00+03	86400.00
C2EA67	2017-07-16 17:48:00+03	56100.00
C2EAB0	2017-07-10 15:22:00+03	47500.00
C2EB02	2017-07-15 04:02:00+03	37800.00
C2EB10	2017-07-02 04:13:00+03	44800.00
C2EB52	2017-07-03 02:52:00+03	16800.00
C2EB6C	2017-07-27 19:30:00+03	28000.00
C2EB89	2017-07-28 08:19:00+03	42800.00
C2EBA2	2017-07-16 07:26:00+03	53200.00
C2EBBD	2017-07-24 00:59:00+03	83000.00
C2EBEE	2017-07-16 18:28:00+03	51800.00
C2EC22	2017-07-19 23:08:00+03	86800.00
C2EC51	2017-08-02 17:25:00+03	23600.00
C2EC73	2017-07-09 18:06:00+03	23400.00
C2ECDA	2017-08-12 13:28:00+03	516800.00
C2ED33	2017-08-08 16:47:00+03	40800.00
C2ED56	2017-07-12 19:42:00+03	57500.00
C2ED61	2017-06-29 10:34:00+03	51800.00
C2ED6F	2017-07-13 20:52:00+03	85000.00
C2EDDA	2017-08-10 18:45:00+03	60800.00
C2EE22	2017-08-01 07:23:00+03	32900.00
C2EE36	2017-06-29 23:27:00+03	111600.00
C2EE55	2017-08-14 18:45:00+03	48800.00
C2EE63	2017-08-14 07:58:00+03	61200.00
C2EE74	2017-07-17 03:26:00+03	112000.00
C2EEA8	2017-07-15 00:07:00+03	58400.00
C2EF45	2017-07-14 13:32:00+03	70800.00
C2EF7F	2017-07-31 04:22:00+03	28800.00
C2EFF2	2017-07-24 21:30:00+03	50800.00
C2F053	2017-08-03 23:00:00+03	26000.00
C2F079	2017-08-14 04:23:00+03	12600.00
C2F0A1	2017-07-26 05:49:00+03	246000.00
C2F0B6	2017-06-30 09:30:00+03	7400.00
C2F0D4	2017-07-10 09:56:00+03	131600.00
C2F0DF	2017-08-08 15:49:00+03	25200.00
C2F0F8	2017-07-11 13:24:00+03	43200.00
C2F16C	2017-07-18 19:36:00+03	131600.00
C2F17D	2017-07-26 11:06:00+03	69400.00
C2F18A	2017-08-14 06:28:00+03	81300.00
C2F18C	2017-07-18 01:05:00+03	29100.00
C2F221	2017-07-26 11:42:00+03	40000.00
C2F255	2017-07-29 17:52:00+03	23200.00
C2F2AE	2017-07-28 07:41:00+03	11000.00
C2F2CB	2017-08-09 09:53:00+03	50000.00
C2F2EA	2017-07-04 11:46:00+03	8000.00
C2F2F5	2017-07-03 06:02:00+03	372500.00
C2F3ED	2017-08-02 11:53:00+03	57800.00
C2F482	2017-07-24 15:43:00+03	43600.00
C2F485	2017-07-26 03:06:00+03	33200.00
C2F4AD	2017-07-15 22:21:00+03	28800.00
C2F511	2017-08-01 10:02:00+03	54800.00
C2F5BC	2017-08-15 05:01:00+03	24000.00
C2F68B	2017-08-14 12:28:00+03	136200.00
C2F696	2017-07-03 23:41:00+03	61800.00
C2F6B3	2017-08-10 18:45:00+03	58000.00
C2F6FA	2017-07-01 01:53:00+03	73600.00
C2F76B	2017-07-18 16:52:00+03	46800.00
C2F782	2017-08-09 05:14:00+03	124300.00
C2F7A3	2017-08-04 05:35:00+03	104000.00
C2F809	2017-07-20 09:17:00+03	47200.00
C2F837	2017-08-13 17:07:00+03	257500.00
C2F86A	2017-06-26 19:21:00+03	107700.00
C2F87A	2017-08-12 15:02:00+03	66600.00
C2F8F1	2017-07-30 09:27:00+03	76100.00
C2F909	2017-07-07 21:51:00+03	16000.00
C2F939	2017-07-22 00:04:00+03	130200.00
C2F98F	2017-07-16 06:36:00+03	46400.00
C2F9AB	2017-06-27 10:37:00+03	18400.00
C2F9CB	2017-07-14 16:01:00+03	96500.00
C2F9FD	2017-07-04 18:36:00+03	18000.00
C2FA2B	2017-07-07 18:16:00+03	246000.00
C2FA35	2017-07-02 17:01:00+03	115700.00
C2FA5E	2017-07-13 20:35:00+03	119500.00
C2FAAF	2017-07-24 13:33:00+03	46200.00
C2FAD4	2017-06-29 11:21:00+03	27700.00
C2FB11	2017-07-03 22:33:00+03	326300.00
C2FB16	2017-08-01 10:28:00+03	58200.00
C2FBB2	2017-07-22 20:44:00+03	45800.00
C2FC09	2017-08-13 02:01:00+03	242700.00
C2FC0B	2017-08-06 23:25:00+03	51600.00
C2FC0E	2017-07-27 11:35:00+03	87000.00
C2FCC3	2017-08-05 08:29:00+03	79600.00
C2FDA6	2017-07-13 15:03:00+03	48800.00
C2FDE9	2017-07-19 05:02:00+03	99300.00
C2FDFF	2017-07-11 04:35:00+03	62600.00
C2FE53	2017-07-01 18:54:00+03	26000.00
C2FEE8	2017-07-27 09:56:00+03	83000.00
C2FF29	2017-07-03 23:05:00+03	27300.00
C2FF95	2017-07-24 23:05:00+03	13600.00
C30057	2017-07-30 21:14:00+03	47700.00
C3005E	2017-07-20 23:58:00+03	88800.00
C300B7	2017-08-08 00:04:00+03	123000.00
C300EB	2017-08-09 19:20:00+03	160800.00
C30128	2017-08-02 13:41:00+03	57600.00
C3015D	2017-07-24 23:58:00+03	174400.00
C3017F	2017-08-11 10:31:00+03	81600.00
C30272	2017-07-31 11:24:00+03	31600.00
C30275	2017-08-03 08:51:00+03	177100.00
C302A3	2017-07-25 22:36:00+03	75600.00
C302E3	2017-07-18 15:56:00+03	25400.00
C30329	2017-08-14 17:32:00+03	65900.00
C303A1	2017-08-12 14:53:00+03	99200.00
C303D0	2017-08-08 17:09:00+03	15000.00
C303D3	2017-08-14 05:19:00+03	62600.00
C303DC	2017-08-07 14:35:00+03	254800.00
C3045E	2017-08-11 02:37:00+03	53200.00
C304A9	2017-08-03 13:34:00+03	103800.00
C304DA	2017-08-02 04:15:00+03	89600.00
C30587	2017-07-15 13:22:00+03	29600.00
C3067E	2017-08-11 19:44:00+03	142800.00
C306AA	2017-07-09 13:50:00+03	68800.00
C30802	2017-07-06 14:34:00+03	132800.00
C3082E	2017-07-11 14:45:00+03	40800.00
C308AB	2017-07-27 11:33:00+03	59000.00
C308E8	2017-08-03 19:12:00+03	45200.00
C30902	2017-07-14 19:57:00+03	55800.00
C30925	2017-08-05 08:57:00+03	23100.00
C3099B	2017-07-17 09:06:00+03	38400.00
C309CC	2017-07-13 10:45:00+03	66600.00
C309F3	2017-07-02 22:36:00+03	145900.00
C30A85	2017-07-02 01:10:00+03	119600.00
C30AA6	2017-07-13 19:46:00+03	24400.00
C30B1B	2017-07-21 03:47:00+03	26000.00
C30B22	2017-07-09 08:41:00+03	89700.00
C30BC7	2017-07-09 09:21:00+03	23400.00
C30C4A	2017-07-29 00:53:00+03	40000.00
C30C9A	2017-08-15 16:59:00+03	13400.00
C30CD1	2017-08-14 07:29:00+03	265700.00
C30D10	2017-07-03 05:06:00+03	38800.00
C30D43	2017-08-08 00:24:00+03	34200.00
C30D49	2017-07-23 16:01:00+03	66000.00
C30D67	2017-07-17 16:01:00+03	67600.00
C30E1A	2017-07-15 09:28:00+03	14400.00
C30E39	2017-08-04 12:45:00+03	47200.00
C30E5B	2017-06-29 23:46:00+03	63400.00
C30EC1	2017-07-27 07:49:00+03	168700.00
C30ECC	2017-07-28 06:59:00+03	128800.00
C30F2F	2017-07-25 07:34:00+03	536400.00
C30F57	2017-08-09 16:10:00+03	48800.00
C30FB3	2017-07-10 07:18:00+03	104800.00
C30FBE	2017-07-15 16:25:00+03	148700.00
C30FDB	2017-08-07 01:09:00+03	50200.00
C31019	2017-07-09 11:07:00+03	86400.00
C31025	2017-07-16 02:07:00+03	56600.00
C31071	2017-07-23 10:52:00+03	6000.00
C31092	2017-07-10 20:12:00+03	136800.00
C310BD	2017-07-13 03:45:00+03	145200.00
C310F2	2017-07-08 14:20:00+03	64400.00
C31140	2017-08-07 05:37:00+03	21400.00
C311A3	2017-08-11 21:51:00+03	38400.00
C3128B	2017-08-15 05:20:00+03	48600.00
C312FB	2017-08-08 19:49:00+03	133200.00
C31323	2017-07-06 04:13:00+03	54400.00
C31375	2017-08-09 11:27:00+03	59200.00
C313AE	2017-07-27 02:46:00+03	43200.00
C3143A	2017-07-14 14:51:00+03	78100.00
C314C6	2017-07-15 23:33:00+03	24000.00
C314EC	2017-07-10 07:13:00+03	153600.00
C314F5	2017-07-04 03:18:00+03	14800.00
C3155A	2017-08-12 04:07:00+03	75600.00
C315C2	2017-07-08 13:35:00+03	22000.00
C315D9	2017-07-24 06:46:00+03	49200.00
C315EC	2017-08-01 04:39:00+03	46800.00
C3164F	2017-07-13 22:42:00+03	69900.00
C316C6	2017-07-03 17:39:00+03	179300.00
C31702	2017-07-16 01:42:00+03	92800.00
C31745	2017-07-10 13:04:00+03	56000.00
C31773	2017-07-04 23:11:00+03	329100.00
C31793	2017-08-02 20:11:00+03	39500.00
C317C9	2017-08-02 00:22:00+03	11700.00
C3187C	2017-08-09 19:02:00+03	420600.00
C31967	2017-07-09 15:46:00+03	66800.00
C31A13	2017-08-12 13:06:00+03	52100.00
C31A2A	2017-07-27 09:48:00+03	16400.00
C31A72	2017-07-22 11:41:00+03	81600.00
C31A8B	2017-07-24 05:30:00+03	69500.00
C31AA0	2017-07-09 14:03:00+03	73500.00
C31B05	2017-07-18 02:58:00+03	46300.00
C31B1F	2017-07-10 06:30:00+03	82900.00
C31B3B	2017-07-16 08:20:00+03	47200.00
C31B83	2017-07-18 06:25:00+03	62600.00
C31BB1	2017-08-01 11:34:00+03	56000.00
C31C36	2017-08-12 19:51:00+03	103500.00
C31C3A	2017-07-21 16:41:00+03	165800.00
C31C62	2017-08-14 01:54:00+03	53000.00
C31CB0	2017-07-23 15:56:00+03	19600.00
C31DC7	2017-08-10 21:32:00+03	46400.00
C31E19	2017-07-15 12:19:00+03	42200.00
C31E6A	2017-07-11 11:49:00+03	25600.00
C31EA9	2017-08-10 05:02:00+03	127400.00
C31EDE	2017-08-15 13:27:00+03	58000.00
C31F0C	2017-08-09 11:52:00+03	11000.00
C31F79	2017-07-10 20:18:00+03	101500.00
C32036	2017-07-14 15:22:00+03	57600.00
C3210A	2017-08-06 03:30:00+03	119500.00
C3212F	2017-08-14 06:00:00+03	42600.00
C321A4	2017-07-27 19:11:00+03	53000.00
C321F6	2017-07-31 13:07:00+03	35600.00
C3222E	2017-08-08 02:58:00+03	129800.00
C32296	2017-08-15 03:47:00+03	147100.00
C322AD	2017-07-16 13:06:00+03	133200.00
C32316	2017-07-01 20:45:00+03	24200.00
C323E4	2017-08-15 15:38:00+03	90000.00
C323F6	2017-07-09 07:22:00+03	88600.00
C3245A	2017-08-12 03:59:00+03	32800.00
C324D2	2017-08-07 12:15:00+03	18800.00
C324DC	2017-07-13 08:36:00+03	26000.00
C324F9	2017-08-08 16:01:00+03	25400.00
C32502	2017-07-18 16:34:00+03	23600.00
C32532	2017-08-05 18:53:00+03	61800.00
C32547	2017-08-08 07:01:00+03	75000.00
C3255B	2017-07-03 13:59:00+03	45200.00
C32585	2017-07-27 04:29:00+03	153300.00
C32626	2017-08-10 16:10:00+03	128100.00
C3265C	2017-07-13 06:37:00+03	71900.00
C3265D	2017-07-01 16:47:00+03	92100.00
C32699	2017-07-12 18:16:00+03	132800.00
C326F4	2017-07-08 22:55:00+03	58800.00
C32702	2017-07-22 22:25:00+03	50900.00
C3271C	2017-08-12 02:02:00+03	34000.00
C32758	2017-07-23 14:39:00+03	72000.00
C32777	2017-08-11 20:24:00+03	23100.00
C3278E	2017-07-31 16:17:00+03	90800.00
C327C6	2017-08-14 21:51:00+03	87100.00
C327E1	2017-07-03 13:41:00+03	406700.00
C327E6	2017-07-02 10:04:00+03	67600.00
C32835	2017-07-04 06:16:00+03	280400.00
C32A06	2017-07-29 04:02:00+03	246000.00
C32A2C	2017-07-13 05:17:00+03	111600.00
C32A30	2017-07-18 20:35:00+03	58200.00
C32A4C	2017-08-08 18:36:00+03	8000.00
C32A59	2017-07-17 20:58:00+03	119600.00
C32A83	2017-07-27 04:44:00+03	12400.00
C32AC5	2017-07-14 06:16:00+03	143100.00
C32B65	2017-07-01 18:22:00+03	23200.00
C32B68	2017-08-12 18:08:00+03	86500.00
C32B88	2017-07-12 17:21:00+03	58900.00
C32BAA	2017-07-15 15:19:00+03	56000.00
C32C04	2017-07-18 00:21:00+03	119500.00
C32C12	2017-07-24 07:24:00+03	58900.00
C32C78	2017-07-16 20:37:00+03	26000.00
C32D34	2017-07-10 18:20:00+03	208200.00
C32D41	2017-08-13 02:56:00+03	6700.00
C32D5D	2017-07-07 19:42:00+03	52700.00
C32DA0	2017-08-12 06:50:00+03	38400.00
C32DF1	2017-08-15 06:35:00+03	18000.00
C32E65	2017-07-27 13:37:00+03	86600.00
C32EA9	2017-07-18 22:42:00+03	86400.00
C32EF6	2017-07-23 18:47:00+03	143200.00
C32F4A	2017-07-02 20:02:00+03	22000.00
C32F9C	2017-07-30 00:39:00+03	26200.00
C3300D	2017-07-22 09:48:00+03	138500.00
C33053	2017-07-28 16:41:00+03	20200.00
C33069	2017-08-14 05:53:00+03	140900.00
C3309B	2017-07-28 06:05:00+03	75300.00
C33111	2017-07-15 13:43:00+03	103900.00
C3312A	2017-07-24 09:51:00+03	265600.00
C33132	2017-07-02 12:56:00+03	202100.00
C33169	2017-07-14 04:57:00+03	123000.00
C3317B	2017-07-28 11:25:00+03	113300.00
C331B0	2017-07-26 13:22:00+03	14300.00
C331B5	2017-07-09 05:16:00+03	29600.00
C331EC	2017-08-11 08:28:00+03	88900.00
C33209	2017-07-11 08:04:00+03	92800.00
C33298	2017-08-14 11:00:00+03	224100.00
C332E8	2017-07-04 21:04:00+03	23400.00
C33342	2017-07-01 22:44:00+03	65900.00
C33354	2017-07-22 16:38:00+03	27200.00
C3335B	2017-07-20 16:05:00+03	23400.00
C33376	2017-07-12 04:10:00+03	7900.00
C33412	2017-07-06 02:40:00+03	52600.00
C33472	2017-07-12 07:52:00+03	60400.00
C33528	2017-08-11 03:38:00+03	43100.00
C3353E	2017-07-18 04:06:00+03	25400.00
C33545	2017-07-23 16:29:00+03	69100.00
C33547	2017-08-15 06:52:00+03	23200.00
C3356B	2017-07-06 15:21:00+03	105300.00
C3357D	2017-08-11 06:06:00+03	65500.00
C33581	2017-07-18 03:06:00+03	14000.00
C33585	2017-07-31 11:55:00+03	66600.00
C33587	2017-07-04 19:28:00+03	149700.00
C3366C	2017-08-01 00:35:00+03	123000.00
C33699	2017-08-04 17:46:00+03	169900.00
C336CF	2017-07-23 10:38:00+03	98300.00
C3373F	2017-07-25 00:54:00+03	40800.00
C3374B	2017-07-16 05:05:00+03	54800.00
C3377A	2017-07-30 07:37:00+03	23600.00
C33795	2017-08-07 16:25:00+03	93500.00
C337D6	2017-08-10 01:01:00+03	64200.00
C33801	2017-08-05 20:06:00+03	32700.00
C3382F	2017-07-02 05:59:00+03	14000.00
C3385E	2017-08-15 02:07:00+03	180100.00
C33866	2017-08-09 23:05:00+03	355200.00
C33893	2017-07-24 14:56:00+03	45400.00
C33899	2017-08-09 15:59:00+03	54400.00
C33912	2017-07-14 01:05:00+03	179500.00
C33943	2017-08-09 21:44:00+03	38200.00
C33982	2017-08-02 10:17:00+03	137400.00
C33990	2017-07-16 17:41:00+03	62600.00
C339A0	2017-07-17 08:53:00+03	52300.00
C339DA	2017-07-26 07:32:00+03	77200.00
C33A0E	2017-07-18 14:08:00+03	26000.00
C33A9D	2017-07-27 15:52:00+03	69500.00
C33ACA	2017-07-21 23:04:00+03	117600.00
C33AD6	2017-07-08 05:09:00+03	82900.00
C33B14	2017-08-02 20:43:00+03	82000.00
C33B99	2017-07-25 07:50:00+03	243700.00
C33C2E	2017-08-05 20:51:00+03	34400.00
C33C59	2017-07-16 15:09:00+03	124300.00
C33C9E	2017-08-12 13:55:00+03	166100.00
C33CE9	2017-07-14 13:49:00+03	55000.00
C33D68	2017-07-24 12:58:00+03	46700.00
C33D95	2017-07-23 04:26:00+03	52800.00
C33DFA	2017-07-13 18:33:00+03	496600.00
C33ECD	2017-08-08 02:10:00+03	133100.00
C33ECF	2017-07-08 14:27:00+03	35200.00
C33ED8	2017-07-05 17:01:00+03	313800.00
C33F0E	2017-07-22 02:42:00+03	110400.00
C33F47	2017-07-24 03:42:00+03	496700.00
C33F6E	2017-07-01 12:40:00+03	261500.00
C33F8E	2017-07-15 19:47:00+03	129000.00
C33F91	2017-08-14 20:29:00+03	7400.00
C34082	2017-08-02 18:13:00+03	23600.00
C340C2	2017-07-03 06:54:00+03	27200.00
C340C9	2017-08-08 02:10:00+03	44000.00
C3410F	2017-08-14 01:41:00+03	206400.00
C34125	2017-07-05 11:33:00+03	229900.00
C34141	2017-08-14 10:25:00+03	23200.00
C3415D	2017-07-11 19:30:00+03	86900.00
C34178	2017-07-22 17:39:00+03	21200.00
C341A8	2017-07-30 11:37:00+03	277900.00
C3428E	2017-08-03 11:54:00+03	55800.00
C342B5	2017-07-23 18:22:00+03	62800.00
C342E2	2017-07-15 09:26:00+03	38400.00
C34319	2017-07-23 13:46:00+03	46200.00
C34366	2017-06-30 05:26:00+03	47900.00
C34375	2017-07-05 01:20:00+03	66800.00
C3441E	2017-07-25 02:45:00+03	80000.00
C34450	2017-07-04 10:46:00+03	6800.00
C344D3	2017-07-26 13:13:00+03	94000.00
C34518	2017-07-02 16:42:00+03	20400.00
C3458E	2017-07-31 14:55:00+03	44500.00
C345AA	2017-07-03 05:33:00+03	42700.00
C345CB	2017-07-14 13:24:00+03	72300.00
C3464F	2017-08-05 00:46:00+03	24800.00
C34722	2017-07-20 11:31:00+03	38200.00
C34724	2017-07-28 05:21:00+03	48800.00
C34755	2017-07-24 09:58:00+03	10800.00
C347B5	2017-07-09 10:12:00+03	131100.00
C3486A	2017-07-29 18:48:00+03	168000.00
C3492A	2017-07-13 01:52:00+03	24200.00
C3496C	2017-07-17 00:54:00+03	36400.00
C349B5	2017-08-04 11:18:00+03	46000.00
C349CD	2017-07-04 22:02:00+03	133200.00
C34A05	2017-08-15 07:57:00+03	26800.00
C34A3D	2017-07-07 23:22:00+03	31600.00
C34A7B	2017-07-27 21:05:00+03	111600.00
C34AA5	2017-07-07 21:10:00+03	26000.00
C34AB4	2017-07-21 19:30:00+03	6000.00
C34ACA	2017-07-05 07:58:00+03	58800.00
C34B30	2017-08-06 23:58:00+03	35600.00
C34B94	2017-08-14 00:51:00+03	258400.00
C34BCA	2017-08-14 14:33:00+03	62600.00
C34BD8	2017-07-04 10:15:00+03	24400.00
C34C17	2017-08-02 22:11:00+03	38600.00
C34C56	2017-08-14 14:02:00+03	68800.00
C34CAF	2017-07-23 06:14:00+03	52000.00
C34D4C	2017-08-01 00:40:00+03	45200.00
C34D56	2017-08-07 12:39:00+03	49100.00
C34D7D	2017-07-09 17:12:00+03	38400.00
C34DF5	2017-07-14 23:21:00+03	45000.00
C34E19	2017-07-13 06:43:00+03	38700.00
C34EBE	2017-07-30 08:52:00+03	69500.00
C34F4C	2017-08-07 09:39:00+03	349700.00
C34F65	2017-08-15 17:03:00+03	53100.00
C34F6A	2017-08-13 12:15:00+03	273000.00
C3502E	2017-07-03 21:21:00+03	59200.00
C350D7	2017-08-15 11:18:00+03	141300.00
C35135	2017-07-02 23:05:00+03	38600.00
C35140	2017-08-01 19:56:00+03	137600.00
C3514A	2017-07-26 12:10:00+03	83000.00
C3514C	2017-08-02 02:28:00+03	195000.00
C35186	2017-07-13 10:42:00+03	139000.00
C35239	2017-08-15 16:55:00+03	111000.00
C35285	2017-07-09 15:26:00+03	62800.00
C352C1	2017-08-05 20:30:00+03	30000.00
C3536F	2017-08-06 03:57:00+03	57600.00
C353A3	2017-07-15 21:11:00+03	39300.00
C353F9	2017-07-10 11:40:00+03	24400.00
C3548B	2017-08-08 05:18:00+03	67200.00
C354EA	2017-07-01 04:14:00+03	47400.00
C3551C	2017-08-06 23:52:00+03	114300.00
C35597	2017-08-10 22:23:00+03	54600.00
C3559F	2017-07-20 09:57:00+03	111600.00
C355DA	2017-08-06 09:01:00+03	90800.00
C355F7	2017-08-05 19:24:00+03	66800.00
C3560A	2017-07-09 10:14:00+03	12400.00
C3560C	2017-07-22 00:19:00+03	16400.00
C35682	2017-07-25 23:46:00+03	98000.00
C356AB	2017-08-09 07:36:00+03	62600.00
C356E1	2017-07-06 13:04:00+03	58900.00
C35770	2017-07-13 16:51:00+03	25000.00
C3579C	2017-07-18 08:15:00+03	14800.00
C357A5	2017-07-27 09:53:00+03	135600.00
C357B4	2017-07-21 11:34:00+03	152500.00
C357C2	2017-07-10 02:47:00+03	68400.00
C357D7	2017-08-08 23:19:00+03	246000.00
C3580F	2017-07-26 23:50:00+03	41800.00
C35864	2017-07-14 08:37:00+03	133100.00
C35885	2017-08-15 17:46:00+03	51800.00
C35899	2017-08-01 09:44:00+03	37900.00
C358CB	2017-07-01 11:16:00+03	229900.00
C3590A	2017-07-28 22:29:00+03	62200.00
C3595E	2017-08-07 00:03:00+03	49300.00
C35974	2017-08-12 00:42:00+03	272400.00
C359AD	2017-07-30 23:27:00+03	38400.00
C359E1	2017-07-01 11:15:00+03	57500.00
C359E2	2017-07-13 09:09:00+03	28800.00
C35AAA	2017-07-14 00:55:00+03	6000.00
C35AFA	2017-07-19 12:21:00+03	32800.00
C35B20	2017-08-13 02:22:00+03	33300.00
C35B52	2017-07-25 04:20:00+03	117600.00
C35B66	2017-07-25 10:37:00+03	46000.00
C35BA3	2017-08-15 00:05:00+03	28700.00
C35BC1	2017-07-10 02:43:00+03	23600.00
C35BD5	2017-08-12 20:24:00+03	26000.00
C35BE4	2017-07-06 03:51:00+03	46800.00
C35C28	2017-07-08 00:46:00+03	8000.00
C35C86	2017-07-28 11:02:00+03	99300.00
C35CCF	2017-07-04 16:00:00+03	61800.00
C35CDF	2017-07-16 14:40:00+03	64600.00
C35CE9	2017-08-07 03:39:00+03	55800.00
C35D20	2017-08-14 12:09:00+03	60400.00
C35D49	2017-07-11 15:39:00+03	36400.00
C35D83	2017-08-12 07:57:00+03	42000.00
C35E24	2017-07-10 21:07:00+03	29600.00
C35E5D	2017-07-17 07:09:00+03	56600.00
C35E90	2017-07-19 18:28:00+03	68900.00
C35EF7	2017-07-08 00:57:00+03	28000.00
C35F68	2017-07-06 05:38:00+03	130700.00
C35F94	2017-06-30 18:06:00+03	170300.00
C3601D	2017-07-30 20:37:00+03	22000.00
C3607E	2017-07-07 14:04:00+03	67600.00
C3615A	2017-07-28 09:44:00+03	54600.00
C36169	2017-07-28 23:01:00+03	125400.00
C361B9	2017-07-07 12:40:00+03	29800.00
C361C8	2017-08-13 14:14:00+03	112000.00
C36205	2017-07-29 14:19:00+03	100600.00
C36273	2017-07-17 07:20:00+03	18600.00
C3627A	2017-07-15 01:20:00+03	36100.00
C362A3	2017-08-05 06:11:00+03	43600.00
C3631E	2017-07-12 16:17:00+03	27200.00
C36324	2017-07-23 14:57:00+03	73100.00
C36367	2017-07-28 00:51:00+03	31400.00
C3638A	2017-08-08 13:05:00+03	36200.00
C3641D	2017-07-27 18:21:00+03	166100.00
C3643A	2017-08-13 10:23:00+03	98400.00
C36467	2017-07-17 20:54:00+03	31600.00
C364FE	2017-08-11 06:45:00+03	344100.00
C36562	2017-08-01 04:42:00+03	32700.00
C365DE	2017-07-08 23:01:00+03	74300.00
C36612	2017-08-13 23:13:00+03	191500.00
C3663C	2017-07-16 19:03:00+03	170800.00
C36648	2017-07-19 18:32:00+03	7400.00
C366CC	2017-08-05 14:56:00+03	270800.00
C366D8	2017-07-08 02:06:00+03	25800.00
C36702	2017-08-04 18:30:00+03	67600.00
C3671A	2017-07-12 21:52:00+03	26000.00
C3674B	2017-07-06 09:22:00+03	208100.00
C36750	2017-07-16 08:58:00+03	55800.00
C367F6	2017-07-18 05:58:00+03	48500.00
C368DF	2017-07-15 06:32:00+03	28300.00
C368E9	2017-08-11 21:19:00+03	25100.00
C368EB	2017-08-14 14:23:00+03	17200.00
C3693B	2017-07-19 01:23:00+03	21200.00
C36993	2017-08-02 07:21:00+03	25600.00
C369A0	2017-07-24 07:17:00+03	68800.00
C369C5	2017-07-14 11:56:00+03	48700.00
C36A08	2017-07-28 05:34:00+03	89700.00
C36A1B	2017-08-09 13:08:00+03	103500.00
C36A1F	2017-07-29 12:20:00+03	37200.00
C36ACC	2017-08-09 05:08:00+03	83600.00
C36B72	2017-07-15 19:19:00+03	106400.00
C36B83	2017-07-16 02:01:00+03	10800.00
C36BC3	2017-08-09 12:23:00+03	23600.00
C36C1E	2017-08-06 08:07:00+03	273600.00
C36C25	2017-07-25 14:57:00+03	54300.00
C36C72	2017-07-18 01:21:00+03	169900.00
C36C8B	2017-07-22 12:40:00+03	147200.00
C36CBE	2017-07-15 19:13:00+03	97900.00
C36D08	2017-07-25 19:09:00+03	14000.00
C36D22	2017-07-03 18:37:00+03	73600.00
C36D43	2017-07-07 11:34:00+03	26700.00
C36DB2	2017-07-18 13:44:00+03	276200.00
C36DB8	2017-08-07 01:55:00+03	18400.00
C36DD2	2017-08-04 06:51:00+03	68000.00
C36DF4	2017-07-09 06:03:00+03	92800.00
C36E40	2017-08-12 05:52:00+03	23600.00
C36E73	2017-07-31 02:46:00+03	231700.00
C36E89	2017-08-03 20:27:00+03	44600.00
C36F33	2017-08-12 02:04:00+03	28800.00
C36F84	2017-07-17 06:17:00+03	30700.00
C36FB9	2017-08-13 22:49:00+03	297300.00
C36FD0	2017-07-11 14:55:00+03	46400.00
C3700E	2017-07-03 19:14:00+03	97700.00
C3709F	2017-08-03 12:32:00+03	25400.00
C370A9	2017-07-23 03:34:00+03	306600.00
C370E5	2017-08-13 17:01:00+03	103500.00
C37159	2017-07-17 11:35:00+03	107700.00
C37170	2017-08-06 09:12:00+03	49400.00
C3717C	2017-07-25 01:20:00+03	34400.00
C371C6	2017-07-11 10:10:00+03	133100.00
C37201	2017-07-03 09:28:00+03	141600.00
C37228	2017-07-17 17:04:00+03	112400.00
C37229	2017-08-15 14:55:00+03	33200.00
C3722A	2017-08-02 05:13:00+03	90800.00
C37259	2017-07-14 01:50:00+03	168000.00
C3726C	2017-08-09 04:44:00+03	21800.00
C37348	2017-07-05 18:59:00+03	643800.00
C37357	2017-07-31 22:31:00+03	45200.00
C37389	2017-07-21 04:16:00+03	63800.00
C373A1	2017-07-15 17:29:00+03	177200.00
C37452	2017-08-14 00:48:00+03	21400.00
C3747E	2017-08-06 17:17:00+03	89500.00
C374A5	2017-08-10 22:45:00+03	136800.00
C374A9	2017-08-05 01:33:00+03	72800.00
C375CA	2017-06-30 22:11:00+03	35700.00
C37675	2017-07-28 17:06:00+03	42400.00
C376AD	2017-07-12 15:31:00+03	129800.00
C376C0	2017-08-05 21:27:00+03	13400.00
C37708	2017-08-08 18:42:00+03	32200.00
C37759	2017-08-12 16:43:00+03	29800.00
C37793	2017-07-07 02:12:00+03	66600.00
C377B3	2017-08-14 13:02:00+03	28000.00
C37815	2017-08-14 22:25:00+03	99700.00
C37834	2017-07-16 12:42:00+03	49600.00
C3784D	2017-08-04 11:41:00+03	137700.00
C3785E	2017-07-27 02:37:00+03	80000.00
C3787B	2017-08-12 05:43:00+03	34800.00
C378A4	2017-07-25 03:31:00+03	25100.00
C378C2	2017-08-04 10:27:00+03	41600.00
C3791D	2017-06-30 15:31:00+03	106900.00
C37923	2017-07-13 06:05:00+03	112600.00
C37985	2017-07-21 08:14:00+03	26800.00
C37990	2017-07-27 11:19:00+03	48900.00
C37A07	2017-07-14 13:31:00+03	29200.00
C37A3F	2017-07-10 12:23:00+03	26000.00
C37A41	2017-07-07 20:15:00+03	48800.00
C37A46	2017-07-19 18:35:00+03	55000.00
C37A97	2017-07-17 20:24:00+03	10800.00
C37AAA	2017-08-12 10:08:00+03	56000.00
C37AD4	2017-07-19 21:14:00+03	34000.00
C37AF7	2017-07-14 13:56:00+03	23400.00
C37B81	2017-07-25 04:44:00+03	92700.00
C37BBA	2017-07-23 21:24:00+03	7400.00
C37C58	2017-07-04 18:02:00+03	66900.00
C37C89	2017-08-06 09:01:00+03	92800.00
C37CAC	2017-07-25 17:41:00+03	398500.00
C37CC4	2017-07-16 23:00:00+03	56000.00
C37CEA	2017-07-29 23:53:00+03	8200.00
C37D28	2017-07-18 00:55:00+03	44000.00
C37D48	2017-07-15 13:45:00+03	254600.00
C37D59	2017-07-28 22:38:00+03	36400.00
C37ED6	2017-07-30 05:15:00+03	70800.00
C37FB5	2017-07-31 01:20:00+03	58200.00
C38166	2017-07-24 18:06:00+03	56000.00
C381F7	2017-07-25 07:16:00+03	156400.00
C382A5	2017-08-10 20:47:00+03	43000.00
C382CB	2017-07-01 15:57:00+03	258400.00
C382E3	2017-07-08 03:50:00+03	23200.00
C38386	2017-07-16 05:17:00+03	56000.00
C3838B	2017-08-15 15:35:00+03	59000.00
C384CB	2017-07-03 00:15:00+03	76600.00
C384F2	2017-08-01 05:26:00+03	38600.00
C3853E	2017-08-10 03:39:00+03	81600.00
C38555	2017-08-10 10:53:00+03	91300.00
C385B4	2017-08-13 00:55:00+03	55800.00
C38651	2017-07-12 22:55:00+03	42700.00
C386D6	2017-08-04 00:37:00+03	78100.00
C3870E	2017-07-04 04:41:00+03	72400.00
C38725	2017-07-25 05:09:00+03	167400.00
C38757	2017-08-10 10:36:00+03	46800.00
C38772	2017-07-26 14:20:00+03	579600.00
C38773	2017-07-21 12:18:00+03	15000.00
C387F6	2017-08-05 04:07:00+03	6300.00
C38815	2017-07-13 06:12:00+03	200500.00
C38830	2017-07-19 11:06:00+03	275200.00
C3885D	2017-07-24 13:36:00+03	28000.00
C38878	2017-07-04 09:23:00+03	260300.00
C38885	2017-07-12 16:54:00+03	6000.00
C388F8	2017-08-05 02:24:00+03	62600.00
C38932	2017-07-21 12:46:00+03	33400.00
C38971	2017-08-01 22:41:00+03	90800.00
C3897B	2017-07-18 23:19:00+03	56600.00
C389B3	2017-07-25 22:52:00+03	43200.00
C389E1	2017-08-02 17:28:00+03	61200.00
C389EC	2017-07-30 16:14:00+03	7400.00
C38A20	2017-08-15 08:17:00+03	52000.00
C38A36	2017-07-31 09:16:00+03	276500.00
C38A44	2017-07-17 00:16:00+03	13600.00
C38AEF	2017-07-04 10:36:00+03	21700.00
C38B24	2017-07-17 19:57:00+03	23400.00
C38B51	2017-07-27 20:24:00+03	26600.00
C38B6D	2017-07-09 15:05:00+03	66600.00
C38BCB	2017-08-11 19:06:00+03	73400.00
C38C05	2017-07-15 03:52:00+03	285700.00
C38C06	2017-07-05 20:09:00+03	56000.00
C38C28	2017-07-04 13:45:00+03	7200.00
C38C56	2017-07-04 10:33:00+03	25400.00
C38C62	2017-07-14 14:45:00+03	56000.00
C38C9E	2017-07-13 13:54:00+03	188100.00
C38CAD	2017-07-14 10:33:00+03	98200.00
C38CEE	2017-07-15 15:19:00+03	21600.00
C38D07	2017-08-08 16:59:00+03	85400.00
C38D15	2017-07-04 11:38:00+03	64800.00
C38D8A	2017-07-10 07:50:00+03	39600.00
C38DA8	2017-07-06 19:15:00+03	170000.00
C38DAB	2017-07-10 11:50:00+03	26000.00
C38DAE	2017-08-04 10:05:00+03	26000.00
C38DF1	2017-07-15 15:15:00+03	135200.00
C38E21	2017-08-08 15:39:00+03	20800.00
C38E3B	2017-07-03 15:21:00+03	99200.00
C38E8C	2017-07-07 11:54:00+03	38800.00
C38E97	2017-08-07 22:02:00+03	54000.00
C38ECB	2017-08-02 20:54:00+03	43000.00
C38ED0	2017-07-28 15:39:00+03	23200.00
C38F26	2017-07-20 00:49:00+03	28800.00
C38F3D	2017-07-25 20:43:00+03	70600.00
C38FCF	2017-08-13 01:46:00+03	181600.00
C38FF1	2017-07-11 21:39:00+03	96800.00
C39031	2017-07-26 02:14:00+03	20800.00
C39035	2017-07-12 07:31:00+03	25400.00
C39096	2017-07-13 04:17:00+03	115900.00
C390E0	2017-08-11 04:18:00+03	74900.00
C390FC	2017-07-12 15:48:00+03	20400.00
C39131	2017-07-20 21:48:00+03	81800.00
C39154	2017-07-13 11:06:00+03	98600.00
C39159	2017-07-04 13:52:00+03	68700.00
C391BF	2017-07-26 06:07:00+03	28800.00
C391D6	2017-08-11 04:19:00+03	28800.00
C39219	2017-07-10 00:05:00+03	34700.00
C3923A	2017-07-05 04:35:00+03	122400.00
C392A2	2017-07-30 14:26:00+03	38400.00
C392C7	2017-08-14 23:45:00+03	65400.00
C392F0	2017-07-02 12:54:00+03	29600.00
C3934C	2017-07-30 02:59:00+03	94200.00
C39388	2017-07-16 14:09:00+03	78700.00
C3942C	2017-07-25 07:03:00+03	43900.00
C3949F	2017-08-01 02:49:00+03	26000.00
C394F7	2017-08-02 13:12:00+03	25200.00
C39500	2017-07-31 02:37:00+03	14000.00
C3952E	2017-08-13 20:42:00+03	22000.00
C3956A	2017-07-10 04:21:00+03	56000.00
C3959F	2017-07-27 20:22:00+03	92000.00
C395B0	2017-07-07 01:39:00+03	85000.00
C395B3	2017-07-12 13:02:00+03	41400.00
C39606	2017-08-13 05:15:00+03	85500.00
C39618	2017-08-04 00:20:00+03	28800.00
C39662	2017-07-18 19:14:00+03	23200.00
C3968D	2017-08-08 11:37:00+03	55800.00
C396C0	2017-08-14 09:46:00+03	14400.00
C396C2	2017-07-20 03:31:00+03	55800.00
C39709	2017-07-12 08:13:00+03	119500.00
C39742	2017-08-02 19:56:00+03	123900.00
C39802	2017-08-15 15:03:00+03	6300.00
C39816	2017-07-03 21:53:00+03	59100.00
C39863	2017-07-09 17:33:00+03	62000.00
C39882	2017-07-19 21:33:00+03	13400.00
C3989D	2017-07-14 16:55:00+03	94000.00
C39909	2017-07-06 18:58:00+03	94200.00
C39928	2017-07-18 13:05:00+03	118000.00
C39974	2017-07-10 15:41:00+03	98400.00
C399A5	2017-08-11 19:34:00+03	67200.00
C39A46	2017-08-01 12:02:00+03	123000.00
C39A66	2017-07-16 09:46:00+03	55800.00
C39AD1	2017-07-08 11:41:00+03	47400.00
C39AD4	2017-07-08 19:16:00+03	47400.00
C39AD5	2017-07-28 14:48:00+03	23200.00
C39AF1	2017-08-13 02:05:00+03	39800.00
C39B2F	2017-07-17 02:30:00+03	95200.00
C39B6D	2017-07-01 00:34:00+03	35200.00
C39BCF	2017-08-01 04:39:00+03	243700.00
C39BDD	2017-08-12 13:27:00+03	132800.00
C39BE1	2017-07-22 02:08:00+03	94000.00
C39BF1	2017-08-05 01:34:00+03	30800.00
C39C6B	2017-07-21 05:50:00+03	51900.00
C39CE8	2017-08-02 05:03:00+03	33600.00
C39CF5	2017-08-05 00:28:00+03	132700.00
C39D67	2017-08-10 06:30:00+03	24700.00
C39DAD	2017-07-17 14:33:00+03	136200.00
C39DB0	2017-07-22 11:30:00+03	26000.00
C39DFB	2017-07-20 17:14:00+03	36200.00
C39E0A	2017-08-11 12:46:00+03	49800.00
C39E1A	2017-07-14 12:32:00+03	13000.00
C39EA5	2017-07-05 16:17:00+03	104000.00
C39F07	2017-07-21 04:43:00+03	38400.00
C39F3E	2017-07-16 15:59:00+03	28800.00
C39F3F	2017-07-16 16:31:00+03	123900.00
C3A034	2017-08-15 00:18:00+03	56500.00
C3A058	2017-07-02 15:03:00+03	8400.00
C3A06F	2017-07-12 01:21:00+03	24000.00
C3A0CE	2017-07-13 05:59:00+03	64600.00
C3A14C	2017-07-14 09:26:00+03	21400.00
C3A183	2017-08-06 06:00:00+03	131600.00
C3A194	2017-08-03 16:08:00+03	84800.00
C3A1CD	2017-07-27 12:24:00+03	23200.00
C3A231	2017-08-05 22:47:00+03	123000.00
C3A265	2017-08-11 08:39:00+03	69600.00
C3A27C	2017-07-10 23:48:00+03	66600.00
C3A2B4	2017-08-03 19:47:00+03	40400.00
C3A2B5	2017-08-15 02:57:00+03	16400.00
C3A2D9	2017-07-24 22:02:00+03	59200.00
C3A2F0	2017-07-06 22:11:00+03	84500.00
C3A373	2017-08-01 09:19:00+03	135600.00
C3A3AF	2017-07-18 06:07:00+03	23600.00
C3A3D0	2017-07-22 10:58:00+03	88900.00
C3A446	2017-07-15 10:27:00+03	76600.00
C3A47D	2017-07-26 07:55:00+03	21200.00
C3A4A1	2017-07-17 17:19:00+03	6000.00
C3A4AF	2017-08-13 04:10:00+03	120200.00
C3A55E	2017-07-09 13:13:00+03	28800.00
C3A568	2017-07-23 02:40:00+03	142800.00
C3A56F	2017-08-13 22:00:00+03	49900.00
C3A580	2017-07-03 20:54:00+03	59800.00
C3A5A8	2017-07-03 15:14:00+03	67400.00
C3A5E5	2017-07-30 20:46:00+03	116400.00
C3A619	2017-08-01 07:41:00+03	189200.00
C3A61F	2017-07-22 07:42:00+03	28800.00
C3A630	2017-08-13 20:15:00+03	21800.00
C3A637	2017-07-27 19:22:00+03	65500.00
C3A647	2017-08-05 09:20:00+03	93100.00
C3A67A	2017-08-14 03:18:00+03	43700.00
C3A6C2	2017-07-02 04:30:00+03	23900.00
C3A716	2017-08-01 18:33:00+03	92800.00
C3A85D	2017-07-12 01:14:00+03	129200.00
C3A899	2017-07-14 11:18:00+03	6800.00
C3A93B	2017-07-21 03:53:00+03	30200.00
C3A956	2017-08-14 06:29:00+03	175800.00
C3A95A	2017-08-01 14:44:00+03	67900.00
C3A95B	2017-07-04 06:29:00+03	25600.00
C3A9DD	2017-07-09 02:07:00+03	164600.00
C3A9EB	2017-08-14 04:03:00+03	47200.00
C3AA21	2017-08-07 06:41:00+03	48800.00
C3AA2C	2017-07-19 21:56:00+03	101900.00
C3AA2F	2017-07-26 03:37:00+03	14800.00
C3AA3A	2017-07-04 07:26:00+03	159800.00
C3ABDC	2017-07-14 15:45:00+03	47000.00
C3ACF7	2017-07-29 02:08:00+03	31700.00
C3AD16	2017-07-12 18:43:00+03	57600.00
C3AD30	2017-07-12 00:15:00+03	23200.00
C3AD8D	2017-08-10 10:26:00+03	360400.00
C3ADC6	2017-08-01 07:32:00+03	16800.00
C3ADCD	2017-07-30 01:17:00+03	21400.00
C3AE06	2017-07-20 13:10:00+03	40900.00
C3AE09	2017-07-03 04:57:00+03	27900.00
C3AE2B	2017-07-23 13:17:00+03	23600.00
C3AE98	2017-07-14 10:29:00+03	100600.00
C3AE9D	2017-07-03 18:34:00+03	68000.00
C3AEF9	2017-07-10 04:38:00+03	88600.00
C3AF9B	2017-07-10 18:59:00+03	88500.00
C3B02E	2017-07-30 07:05:00+03	24400.00
C3B0EB	2017-06-29 19:22:00+03	25600.00
C3B154	2017-07-07 03:18:00+03	83600.00
C3B15C	2017-08-05 23:25:00+03	178800.00
C3B18F	2017-07-04 14:18:00+03	123000.00
C3B1B0	2017-07-22 18:25:00+03	40800.00
C3B203	2017-07-13 16:52:00+03	43600.00
C3B216	2017-07-16 11:09:00+03	87800.00
C3B221	2017-07-04 03:13:00+03	123600.00
C3B23D	2017-08-03 12:45:00+03	28000.00
C3B280	2017-07-21 17:38:00+03	42400.00
C3B2D3	2017-07-27 05:20:00+03	16400.00
C3B2F7	2017-08-06 23:57:00+03	48400.00
C3B35A	2017-07-09 05:25:00+03	153800.00
C3B397	2017-07-18 20:56:00+03	19600.00
C3B3D8	2017-07-16 18:21:00+03	43000.00
C3B3E6	2017-07-26 08:57:00+03	16400.00
C3B3F0	2017-07-18 02:13:00+03	105600.00
C3B463	2017-08-02 02:50:00+03	177600.00
C3B472	2017-07-04 10:39:00+03	131600.00
C3B49F	2017-08-10 00:50:00+03	8600.00
C3B4A1	2017-07-27 12:53:00+03	75600.00
C3B4A9	2017-08-03 10:55:00+03	399600.00
C3B572	2017-08-09 12:50:00+03	146700.00
C3B599	2017-08-08 14:15:00+03	246000.00
C3B5A5	2017-07-04 17:39:00+03	92800.00
C3B5D6	2017-07-14 19:57:00+03	83500.00
C3B5F6	2017-08-09 12:09:00+03	293700.00
C3B60B	2017-07-17 13:55:00+03	13000.00
C3B679	2017-07-02 07:43:00+03	99700.00
C3B70F	2017-08-09 22:28:00+03	16400.00
C3B737	2017-07-22 19:35:00+03	32700.00
C3B7B2	2017-08-03 19:48:00+03	96300.00
C3B843	2017-07-21 11:35:00+03	67700.00
C3B85B	2017-08-06 06:17:00+03	167400.00
C3B895	2017-08-03 11:05:00+03	12000.00
C3B89F	2017-07-21 21:03:00+03	64700.00
C3B8B8	2017-07-27 11:14:00+03	149800.00
C3B8CE	2017-08-12 19:11:00+03	115000.00
C3B8FE	2017-07-07 09:38:00+03	9300.00
C3B940	2017-07-04 15:22:00+03	56000.00
C3B950	2017-07-01 11:30:00+03	56000.00
C3B953	2017-07-26 06:53:00+03	34000.00
C3B97C	2017-08-01 02:58:00+03	248500.00
C3B9DB	2017-08-13 00:11:00+03	19800.00
C3B9F6	2017-06-30 07:59:00+03	75300.00
C3B9F9	2017-08-13 00:31:00+03	68100.00
C3BA23	2017-07-20 21:37:00+03	32000.00
C3BA2C	2017-08-05 22:25:00+03	8000.00
C3BA3B	2017-08-07 01:58:00+03	46000.00
C3BA40	2017-07-13 11:36:00+03	12400.00
C3BA55	2017-08-05 07:25:00+03	28000.00
C3BADF	2017-07-20 05:35:00+03	64700.00
C3BBCD	2017-07-24 07:12:00+03	135600.00
C3BBD9	2017-08-12 23:48:00+03	18300.00
C3BBFB	2017-07-17 18:01:00+03	73500.00
C3BC4E	2017-07-04 15:59:00+03	94200.00
C3BC55	2017-07-11 12:28:00+03	142400.00
C3BD0B	2017-08-11 02:43:00+03	47400.00
C3BD54	2017-08-02 05:52:00+03	58000.00
C3BD8E	2017-07-03 23:08:00+03	56000.00
C3BE17	2017-07-18 02:12:00+03	297900.00
C3BE7B	2017-07-05 15:59:00+03	48800.00
C3BE89	2017-07-18 18:09:00+03	39600.00
C3BE8B	2017-07-28 12:29:00+03	100200.00
C3BEC0	2017-08-03 14:25:00+03	21000.00
C3BED8	2017-07-07 19:59:00+03	43200.00
C3BF1A	2017-07-13 01:56:00+03	86800.00
C3BF3E	2017-07-22 05:24:00+03	117500.00
C3BF7F	2017-07-12 12:40:00+03	13400.00
C3BF99	2017-07-06 22:03:00+03	14000.00
C3BFAA	2017-08-15 05:29:00+03	132700.00
C3BFBF	2017-07-24 12:12:00+03	246000.00
C3BFDC	2017-07-13 04:25:00+03	6300.00
C3BFE3	2017-07-12 21:09:00+03	66000.00
C3C00E	2017-08-06 07:16:00+03	70200.00
C3C048	2017-08-04 01:20:00+03	6000.00
C3C06C	2017-08-11 18:24:00+03	69100.00
C3C084	2017-07-15 14:50:00+03	67600.00
C3C090	2017-07-25 18:27:00+03	45100.00
C3C0E3	2017-07-14 00:22:00+03	92900.00
C3C162	2017-07-02 18:56:00+03	28000.00
C3C189	2017-08-10 20:18:00+03	13400.00
C3C19C	2017-08-05 11:07:00+03	56000.00
C3C1C0	2017-07-02 14:12:00+03	60200.00
C3C205	2017-08-13 13:51:00+03	37000.00
C3C231	2017-07-30 17:22:00+03	20000.00
C3C24A	2017-07-19 00:28:00+03	25600.00
C3C266	2017-08-04 00:10:00+03	265600.00
C3C276	2017-07-06 00:06:00+03	41600.00
C3C2B9	2017-07-02 07:50:00+03	45200.00
C3C2DC	2017-08-01 20:20:00+03	28800.00
C3C31A	2017-07-12 20:07:00+03	118200.00
C3C325	2017-07-08 01:26:00+03	38800.00
C3C36B	2017-07-11 19:36:00+03	59000.00
C3C579	2017-08-14 23:16:00+03	24200.00
C3C59F	2017-07-19 14:59:00+03	42700.00
C3C600	2017-07-18 01:22:00+03	36200.00
C3C612	2017-07-31 16:20:00+03	266400.00
C3C658	2017-08-15 16:09:00+03	181200.00
C3C678	2017-08-15 12:01:00+03	68400.00
C3C6A8	2017-07-09 08:50:00+03	29600.00
C3C6BF	2017-07-09 04:11:00+03	94200.00
C3C6E6	2017-07-27 23:27:00+03	75600.00
C3C752	2017-08-11 20:50:00+03	92900.00
C3C794	2017-07-19 06:09:00+03	55800.00
C3C7A5	2017-07-09 07:52:00+03	21800.00
C3C818	2017-07-30 05:00:00+03	335400.00
C3C822	2017-08-08 00:06:00+03	20600.00
C3C8FF	2017-08-15 06:53:00+03	28900.00
C3C940	2017-07-26 06:09:00+03	133200.00
C3C9E5	2017-07-26 16:29:00+03	10800.00
C3CA04	2017-07-01 02:51:00+03	25600.00
C3CA29	2017-07-08 04:13:00+03	77000.00
C3CA35	2017-08-10 22:34:00+03	94700.00
C3CA38	2017-07-28 08:05:00+03	58600.00
C3CA50	2017-07-14 20:11:00+03	54800.00
C3CA5D	2017-07-05 22:01:00+03	56000.00
C3CAD4	2017-06-30 08:59:00+03	69000.00
C3CAE9	2017-07-18 16:57:00+03	88800.00
C3CAFA	2017-08-13 11:25:00+03	12600.00
C3CB4A	2017-07-06 10:09:00+03	50400.00
C3CB57	2017-07-19 09:43:00+03	12400.00
C3CB5F	2017-07-06 23:17:00+03	277800.00
C3CB6C	2017-07-10 20:34:00+03	141600.00
C3CB77	2017-08-11 05:24:00+03	28800.00
C3CBAE	2017-07-17 03:45:00+03	92700.00
C3CBF4	2017-07-05 09:16:00+03	69500.00
C3CC00	2017-07-27 15:15:00+03	244200.00
C3CC1F	2017-08-13 16:50:00+03	24400.00
C3CC3A	2017-08-05 11:43:00+03	54500.00
C3CC9A	2017-08-05 17:56:00+03	122800.00
C3CCE2	2017-07-17 02:24:00+03	172300.00
C3CD44	2017-07-18 15:02:00+03	112000.00
C3CD71	2017-08-10 16:50:00+03	136200.00
C3CD90	2017-08-02 15:28:00+03	47000.00
C3CD99	2017-07-31 16:20:00+03	26800.00
C3CDC2	2017-08-05 08:22:00+03	97900.00
C3CDEA	2017-07-09 17:27:00+03	32800.00
C3CF0F	2017-08-04 14:44:00+03	102800.00
C3CF4A	2017-08-07 16:10:00+03	68400.00
C3D008	2017-08-10 14:16:00+03	88800.00
C3D013	2017-07-27 04:00:00+03	13400.00
C3D070	2017-08-13 09:14:00+03	49200.00
C3D087	2017-08-04 15:19:00+03	55800.00
C3D0DE	2017-08-03 01:37:00+03	22000.00
C3D143	2017-08-13 04:18:00+03	40000.00
C3D219	2017-08-07 20:37:00+03	103700.00
C3D237	2017-08-09 18:55:00+03	23400.00
C3D35A	2017-07-14 15:03:00+03	33100.00
C3D365	2017-08-09 16:42:00+03	81600.00
C3D3B8	2017-07-29 06:30:00+03	42700.00
C3D406	2017-07-06 02:07:00+03	128800.00
C3D43A	2017-07-18 22:12:00+03	25200.00
C3D467	2017-07-28 13:42:00+03	181400.00
C3D46B	2017-08-06 04:44:00+03	132800.00
C3D47A	2017-08-04 03:42:00+03	131600.00
C3D481	2017-07-12 17:06:00+03	12600.00
C3D48E	2017-08-02 17:03:00+03	73600.00
C3D4C8	2017-07-12 00:07:00+03	521800.00
C3D4DF	2017-07-18 20:19:00+03	65100.00
C3D500	2017-07-05 05:05:00+03	140100.00
C3D50B	2017-07-14 04:07:00+03	64800.00
C3D512	2017-07-20 07:01:00+03	136800.00
C3D52D	2017-08-01 14:46:00+03	112000.00
C3D5FF	2017-08-04 07:34:00+03	187600.00
C3D608	2017-08-02 06:11:00+03	13400.00
C3D63B	2017-07-20 06:35:00+03	19600.00
C3D682	2017-08-10 23:47:00+03	25400.00
C3D6F2	2017-07-24 06:36:00+03	38200.00
C3D762	2017-08-10 01:33:00+03	32700.00
C3D79B	2017-07-14 05:58:00+03	19600.00
C3D7EF	2017-07-16 20:59:00+03	98400.00
C3D81B	2017-08-07 13:05:00+03	346100.00
C3D829	2017-08-01 00:16:00+03	53400.00
C3D834	2017-08-05 03:11:00+03	92000.00
C3D858	2017-07-16 03:49:00+03	13400.00
C3D891	2017-07-05 04:33:00+03	133200.00
C3D898	2017-06-30 09:17:00+03	15000.00
C3D8C2	2017-07-24 19:37:00+03	67600.00
C3D8CD	2017-08-04 08:35:00+03	111600.00
C3D8FB	2017-07-26 08:17:00+03	28800.00
C3D900	2017-07-02 14:27:00+03	182300.00
C3D974	2017-07-13 17:17:00+03	137600.00
C3DA04	2017-07-02 19:04:00+03	106200.00
C3DA0E	2017-07-09 11:27:00+03	56000.00
C3DA32	2017-08-13 03:04:00+03	177200.00
C3DA52	2017-07-15 03:46:00+03	257600.00
C3DA58	2017-07-27 01:01:00+03	12200.00
C3DA94	2017-07-22 09:33:00+03	6000.00
C3DAA2	2017-07-10 10:31:00+03	36800.00
C3DAD4	2017-08-02 14:51:00+03	88100.00
C3DB0B	2017-07-18 12:24:00+03	25800.00
C3DB15	2017-07-01 09:01:00+03	70100.00
C3DB77	2017-07-17 00:45:00+03	67600.00
C3DBAA	2017-07-12 12:48:00+03	25600.00
C3DBC2	2017-08-14 09:13:00+03	48800.00
C3DC04	2017-07-17 07:04:00+03	22000.00
C3DC5B	2017-07-22 09:59:00+03	46000.00
C3DD0F	2017-08-01 05:17:00+03	33100.00
C3DD46	2017-06-29 16:46:00+03	326300.00
C3DD5A	2017-07-22 14:43:00+03	111900.00
C3DD5D	2017-07-21 02:59:00+03	62600.00
C3DD89	2017-08-12 20:25:00+03	172100.00
C3DDFC	2017-08-03 11:07:00+03	25600.00
C3DE0E	2017-08-14 09:54:00+03	36200.00
C3DEA1	2017-07-05 05:05:00+03	137600.00
C3DEA9	2017-07-11 02:30:00+03	8000.00
C3DEC4	2017-08-05 16:33:00+03	86400.00
C3DEE4	2017-08-05 04:28:00+03	38600.00
C3DEEB	2017-07-18 01:04:00+03	52800.00
C3DF64	2017-07-16 07:21:00+03	389000.00
C3DF7E	2017-07-21 16:57:00+03	177200.00
C3DFC7	2017-08-10 20:56:00+03	65500.00
C3DFDB	2017-07-23 19:50:00+03	152500.00
C3E03E	2017-08-13 06:38:00+03	30200.00
C3E0AF	2017-07-27 20:51:00+03	83000.00
C3E11A	2017-07-12 10:20:00+03	41400.00
C3E122	2017-08-09 12:10:00+03	24400.00
C3E14F	2017-07-03 15:27:00+03	27400.00
C3E18A	2017-06-30 19:52:00+03	99200.00
C3E1DD	2017-08-15 14:57:00+03	67100.00
C3E218	2017-07-19 01:10:00+03	37100.00
C3E2CB	2017-07-28 02:54:00+03	8000.00
C3E3AF	2017-07-02 19:33:00+03	54800.00
C3E3CA	2017-08-11 08:11:00+03	69500.00
C3E422	2017-08-09 17:35:00+03	56000.00
C3E441	2017-07-04 19:26:00+03	56600.00
C3E447	2017-07-30 05:09:00+03	126500.00
C3E545	2017-08-09 02:42:00+03	46400.00
C3E56C	2017-07-06 09:51:00+03	50000.00
C3E577	2017-08-15 16:13:00+03	12000.00
C3E597	2017-07-29 01:30:00+03	136600.00
C3E71A	2017-07-15 09:25:00+03	27200.00
C3E73D	2017-07-06 17:01:00+03	173000.00
C3E755	2017-07-13 22:52:00+03	56100.00
C3E75B	2017-07-11 09:38:00+03	69900.00
C3E76B	2017-08-08 16:25:00+03	43800.00
C3E76E	2017-08-03 20:09:00+03	10800.00
C3E78A	2017-07-16 09:19:00+03	85000.00
C3E795	2017-07-25 06:31:00+03	59800.00
C3E7BE	2017-08-10 11:34:00+03	119500.00
C3E80A	2017-07-08 15:46:00+03	24000.00
C3E822	2017-08-02 07:30:00+03	45200.00
C3E84A	2017-08-08 20:40:00+03	22600.00
C3E86B	2017-07-18 08:59:00+03	134600.00
C3E88F	2017-07-09 23:42:00+03	74000.00
C3E8B6	2017-07-24 23:43:00+03	133100.00
C3E93E	2017-07-13 15:03:00+03	65900.00
C3E952	2017-07-16 20:51:00+03	51200.00
C3E953	2017-08-06 00:28:00+03	18900.00
C3E97F	2017-08-09 08:54:00+03	44500.00
C3E9BA	2017-06-30 18:18:00+03	20400.00
C3EA22	2017-08-15 12:28:00+03	10100.00
C3EA47	2017-08-06 15:31:00+03	87000.00
C3EAA6	2017-08-09 04:22:00+03	46200.00
C3EB1C	2017-07-20 10:06:00+03	100600.00
C3EBAF	2017-08-03 14:28:00+03	65500.00
C3EBB9	2017-07-10 22:03:00+03	405000.00
C3EBBA	2017-07-11 13:55:00+03	57600.00
C3EBCE	2017-07-09 22:32:00+03	113800.00
C3EBF3	2017-06-30 09:01:00+03	88600.00
C3EC1B	2017-07-11 02:37:00+03	141000.00
C3EC83	2017-07-16 23:27:00+03	12600.00
C3ED05	2017-08-15 15:03:00+03	101200.00
C3ED09	2017-08-15 03:19:00+03	54500.00
C3ED1A	2017-07-24 14:16:00+03	56600.00
C3ED52	2017-08-08 06:53:00+03	375200.00
C3EDA0	2017-08-01 20:39:00+03	45200.00
C3EDEE	2017-07-17 11:58:00+03	57600.00
C3EDF0	2017-07-07 00:39:00+03	12600.00
C3EE0B	2017-07-16 01:17:00+03	55800.00
C3EE2B	2017-07-21 16:28:00+03	62000.00
C3EE54	2017-07-10 20:56:00+03	21500.00
C3EE77	2017-07-19 12:49:00+03	31400.00
C3EEF8	2017-07-09 23:18:00+03	272300.00
C3EF21	2017-07-18 06:37:00+03	21800.00
C3EF43	2017-07-12 08:14:00+03	44000.00
C3EF74	2017-07-24 09:05:00+03	86300.00
C3EF9F	2017-07-16 03:37:00+03	44800.00
C3EFC0	2017-07-28 11:10:00+03	55800.00
C3EFD8	2017-07-25 02:27:00+03	38000.00
C3F089	2017-08-13 18:11:00+03	73600.00
C3F0E2	2017-07-05 00:23:00+03	15000.00
C3F10B	2017-07-19 04:28:00+03	12400.00
C3F163	2017-07-19 16:47:00+03	15000.00
C3F199	2017-08-10 14:24:00+03	108000.00
C3F1D2	2017-07-16 05:33:00+03	24200.00
C3F1FE	2017-07-14 18:19:00+03	50400.00
C3F218	2017-07-28 13:25:00+03	23400.00
C3F22D	2017-07-03 20:29:00+03	51900.00
C3F236	2017-08-07 13:23:00+03	38400.00
C3F24C	2017-07-13 20:43:00+03	40000.00
C3F256	2017-08-03 18:25:00+03	248300.00
C3F297	2017-07-09 19:56:00+03	33000.00
C3F2C2	2017-07-04 09:32:00+03	59800.00
C3F2ED	2017-07-28 13:51:00+03	31600.00
C3F357	2017-07-13 21:28:00+03	6600.00
C3F35C	2017-06-30 01:27:00+03	92900.00
C3F37A	2017-07-27 14:08:00+03	52100.00
C3F3AB	2017-07-07 16:28:00+03	76600.00
C3F41E	2017-08-07 21:51:00+03	147300.00
C3F423	2017-07-25 09:35:00+03	76600.00
C3F479	2017-07-05 19:38:00+03	35800.00
C3F4AE	2017-07-18 01:38:00+03	67000.00
C3F4FB	2017-08-04 04:49:00+03	92800.00
C3F515	2017-08-04 18:31:00+03	32700.00
C3F58C	2017-08-04 14:15:00+03	49100.00
C3F5E3	2017-08-01 18:46:00+03	23400.00
C3F5E7	2017-07-07 23:40:00+03	60400.00
C3F5ED	2017-08-15 12:05:00+03	132800.00
C3F5F8	2017-07-21 05:05:00+03	51000.00
C3F620	2017-06-30 15:20:00+03	98200.00
C3F64A	2017-07-27 04:58:00+03	51200.00
C3F64F	2017-07-12 12:14:00+03	55800.00
C3F6CB	2017-07-23 13:18:00+03	156100.00
C3F6F9	2017-08-10 09:13:00+03	42800.00
C3F733	2017-08-02 00:05:00+03	87000.00
C3F799	2017-08-09 09:43:00+03	43500.00
C3F7C5	2017-07-30 05:18:00+03	29600.00
C3F812	2017-07-14 13:32:00+03	137600.00
C3F838	2017-08-02 08:11:00+03	44800.00
C3F8E1	2017-07-10 14:38:00+03	76600.00
C3F930	2017-08-10 12:39:00+03	44500.00
C3F95F	2017-07-11 15:15:00+03	94800.00
C3F9DA	2017-07-18 20:32:00+03	66400.00
C3F9E1	2017-08-10 10:45:00+03	36800.00
C3FA36	2017-08-03 04:34:00+03	73100.00
C3FA92	2017-07-18 04:24:00+03	33200.00
C3FABC	2017-07-16 19:20:00+03	22200.00
C3FAFB	2017-07-14 13:16:00+03	33800.00
C3FB4E	2017-07-04 18:30:00+03	51200.00
C3FBB5	2017-07-14 11:51:00+03	44800.00
C3FBFE	2017-07-22 19:42:00+03	65200.00
C3FC13	2017-08-13 18:39:00+03	39600.00
C3FC8B	2017-07-31 16:52:00+03	15900.00
C3FCB3	2017-07-01 03:31:00+03	520600.00
C3FCC5	2017-07-30 13:50:00+03	236500.00
C3FCDE	2017-08-12 11:34:00+03	134400.00
C3FD00	2017-08-06 04:37:00+03	99200.00
C3FD0B	2017-07-23 02:34:00+03	12600.00
C3FD2F	2017-08-02 13:46:00+03	106800.00
C3FD45	2017-07-24 18:19:00+03	14000.00
C3FD4B	2017-07-21 15:04:00+03	27200.00
C3FDBC	2017-07-21 02:09:00+03	28000.00
C3FE0D	2017-08-07 23:45:00+03	28800.00
C3FE69	2017-07-29 13:16:00+03	28000.00
C3FEF3	2017-07-05 06:08:00+03	21400.00
C3FF32	2017-07-24 05:12:00+03	117600.00
C4002B	2017-07-12 14:27:00+03	132800.00
C40033	2017-08-03 06:08:00+03	272400.00
C40055	2017-07-23 19:39:00+03	27200.00
C40065	2017-08-06 08:19:00+03	258600.00
C4009F	2017-07-03 22:20:00+03	51900.00
C400BB	2017-07-03 09:29:00+03	42700.00
C400F5	2017-07-15 15:19:00+03	50700.00
C40128	2017-08-12 21:10:00+03	189800.00
C40185	2017-08-05 22:11:00+03	38400.00
C40186	2017-07-25 16:36:00+03	104600.00
C4021B	2017-08-08 13:18:00+03	111600.00
C40238	2017-08-11 19:27:00+03	198500.00
C40254	2017-08-06 00:50:00+03	28000.00
C4026A	2017-07-30 21:54:00+03	28000.00
C402AF	2017-07-16 20:48:00+03	142400.00
C402F7	2017-08-13 09:00:00+03	37000.00
C40379	2017-07-29 15:23:00+03	50800.00
C4037E	2017-08-06 18:44:00+03	134000.00
C403AA	2017-07-20 15:50:00+03	129000.00
C403E2	2017-07-12 10:24:00+03	64700.00
C40409	2017-08-04 12:12:00+03	6700.00
C40420	2017-08-06 03:55:00+03	83000.00
C40433	2017-07-15 11:47:00+03	103200.00
C40481	2017-07-27 04:56:00+03	76200.00
C404DA	2017-07-26 14:08:00+03	325500.00
C405C8	2017-07-10 16:58:00+03	73600.00
C4070A	2017-07-11 08:33:00+03	99200.00
C40762	2017-07-10 12:59:00+03	54400.00
C40770	2017-08-14 22:49:00+03	36200.00
C4079C	2017-07-19 23:34:00+03	133100.00
C40824	2017-08-10 03:28:00+03	123000.00
C40867	2017-07-25 19:04:00+03	69000.00
C4089B	2017-08-12 17:56:00+03	136200.00
C408DC	2017-08-06 21:12:00+03	212800.00
C408E7	2017-07-30 13:15:00+03	123200.00
C4091A	2017-07-14 01:33:00+03	85000.00
C40963	2017-07-27 02:57:00+03	20400.00
C409AC	2017-07-27 22:22:00+03	9800.00
C40A3C	2017-08-15 10:50:00+03	136200.00
C40A77	2017-07-19 11:25:00+03	36800.00
C40A7F	2017-06-26 16:54:00+03	29600.00
C40AD6	2017-08-05 18:13:00+03	6700.00
C40B69	2017-08-09 06:55:00+03	27200.00
C40BCF	2017-07-16 16:41:00+03	35200.00
C40BE1	2017-08-07 00:24:00+03	40800.00
C40C59	2017-08-11 11:42:00+03	34000.00
C40CAC	2017-07-12 01:23:00+03	79900.00
C40CAD	2017-08-02 04:15:00+03	89700.00
C40CF5	2017-08-12 17:37:00+03	35600.00
C40D18	2017-07-05 11:33:00+03	223200.00
C40DA1	2017-08-06 06:49:00+03	16400.00
C40E31	2017-07-31 14:18:00+03	28000.00
C40E8A	2017-08-08 17:42:00+03	55800.00
C40EA5	2017-07-31 13:08:00+03	86400.00
C40ED0	2017-07-13 21:59:00+03	62900.00
C40F1E	2017-07-04 21:38:00+03	25100.00
C40FAE	2017-07-14 09:44:00+03	60400.00
C40FC0	2017-07-11 15:40:00+03	63600.00
C40FC3	2017-07-19 20:12:00+03	114700.00
C40FF5	2017-08-14 02:09:00+03	54000.00
C4106D	2017-08-04 04:45:00+03	72300.00
C4107D	2017-08-12 11:37:00+03	37100.00
C41098	2017-08-07 00:57:00+03	39400.00
C410B7	2017-07-28 18:35:00+03	24800.00
C4111A	2017-07-16 23:17:00+03	37900.00
C41161	2017-07-28 02:17:00+03	92600.00
C4116A	2017-07-29 04:41:00+03	28800.00
C41180	2017-07-29 02:37:00+03	123000.00
C4119F	2017-08-11 10:54:00+03	62000.00
C411F1	2017-07-13 21:18:00+03	62600.00
C41203	2017-08-08 16:01:00+03	375200.00
C41211	2017-07-02 23:24:00+03	84800.00
C4127C	2017-07-12 14:32:00+03	38400.00
C412CE	2017-08-13 01:36:00+03	94100.00
C412F7	2017-08-01 10:02:00+03	119500.00
C412FD	2017-08-11 21:21:00+03	69100.00
C41305	2017-07-20 03:44:00+03	246000.00
C4134F	2017-08-01 02:55:00+03	32800.00
C41360	2017-08-09 09:02:00+03	70800.00
C41365	2017-07-27 07:56:00+03	113200.00
C4138F	2017-07-18 17:06:00+03	69500.00
C413AB	2017-08-05 12:15:00+03	64500.00
C413AF	2017-07-17 08:18:00+03	57500.00
C413D0	2017-07-19 13:28:00+03	78200.00
C413E5	2017-07-12 21:31:00+03	29600.00
C41433	2017-07-04 14:15:00+03	111600.00
C4143D	2017-08-04 18:23:00+03	26700.00
C414D2	2017-08-15 09:56:00+03	25000.00
C414D4	2017-08-10 02:06:00+03	234700.00
C4151C	2017-07-09 11:26:00+03	168000.00
C415AB	2017-07-23 10:19:00+03	47600.00
C415BE	2017-08-13 23:39:00+03	19800.00
C4164E	2017-08-06 05:49:00+03	90100.00
C41657	2017-07-13 11:11:00+03	8000.00
C4166C	2017-08-08 23:40:00+03	88500.00
C4167A	2017-07-19 11:31:00+03	15000.00
C416EF	2017-08-04 05:47:00+03	23200.00
C41730	2017-08-13 03:30:00+03	28800.00
C417CE	2017-08-02 07:27:00+03	224000.00
C4181A	2017-07-05 14:54:00+03	81300.00
C4184D	2017-07-20 12:18:00+03	273400.00
C41874	2017-07-18 16:39:00+03	52400.00
C418A6	2017-07-12 16:19:00+03	36800.00
C418B2	2017-07-22 09:41:00+03	28800.00
C41900	2017-08-06 23:24:00+03	133100.00
C41912	2017-07-13 05:30:00+03	83000.00
C41918	2017-08-04 07:20:00+03	57300.00
C41999	2017-08-09 12:35:00+03	55800.00
C419A9	2017-07-20 12:14:00+03	110400.00
C419C8	2017-07-08 05:54:00+03	86800.00
C419F8	2017-08-08 23:01:00+03	28000.00
C41A05	2017-08-10 04:43:00+03	43200.00
C41A21	2017-07-27 07:48:00+03	12600.00
C41A81	2017-07-05 01:28:00+03	48500.00
C41A9A	2017-07-18 21:00:00+03	25600.00
C41ADC	2017-08-13 22:52:00+03	46200.00
C41BEE	2017-08-05 10:57:00+03	47700.00
C41BF7	2017-08-08 00:10:00+03	16400.00
C41C91	2017-08-02 21:27:00+03	56000.00
C41D24	2017-08-01 13:52:00+03	70100.00
C41D64	2017-08-13 08:17:00+03	44500.00
C41D8E	2017-07-13 20:16:00+03	24400.00
C41D95	2017-07-03 03:09:00+03	16400.00
C41DD2	2017-07-06 10:37:00+03	393800.00
C41DDF	2017-07-20 23:29:00+03	136600.00
C41E55	2017-07-05 19:42:00+03	68800.00
C41E57	2017-07-09 09:06:00+03	25200.00
C41EBF	2017-07-04 18:41:00+03	383100.00
C41F4E	2017-07-06 18:39:00+03	10800.00
C41F86	2017-08-01 11:10:00+03	136800.00
C41F88	2017-08-13 08:46:00+03	57600.00
C41FC0	2017-07-13 22:19:00+03	131600.00
C41FD6	2017-08-15 13:08:00+03	55800.00
C42020	2017-08-02 14:38:00+03	53300.00
C42029	2017-07-03 13:31:00+03	166700.00
C420BE	2017-07-10 19:51:00+03	89700.00
C42114	2017-08-11 19:50:00+03	47400.00
C421C1	2017-08-15 00:01:00+03	19600.00
C421D7	2017-08-03 09:44:00+03	39800.00
C4226A	2017-07-30 10:54:00+03	19600.00
C422F3	2017-08-13 15:14:00+03	144400.00
C4235E	2017-07-28 17:58:00+03	136100.00
C423B1	2017-08-13 18:47:00+03	51900.00
C423D0	2017-07-07 16:57:00+03	76600.00
C423E9	2017-07-17 18:01:00+03	44800.00
C423F1	2017-07-02 11:45:00+03	270000.00
C42403	2017-07-08 23:05:00+03	32900.00
C42427	2017-07-08 20:23:00+03	78200.00
C42436	2017-07-09 14:31:00+03	155500.00
C424A8	2017-06-28 13:22:00+03	48500.00
C424D0	2017-08-14 03:20:00+03	10800.00
C42501	2017-08-05 23:25:00+03	12600.00
C42508	2017-08-03 06:37:00+03	67600.00
C42579	2017-08-02 13:53:00+03	24200.00
C425B6	2017-07-19 09:26:00+03	48500.00
C42603	2017-07-06 17:23:00+03	170600.00
C4265E	2017-08-11 12:54:00+03	133200.00
C4266C	2017-08-05 21:24:00+03	52000.00
C4269E	2017-08-11 05:17:00+03	32800.00
C426DE	2017-07-29 13:46:00+03	13600.00
C426EA	2017-07-31 03:15:00+03	36000.00
C426F1	2017-08-07 05:44:00+03	60400.00
C4270D	2017-07-28 02:11:00+03	59200.00
C4275C	2017-07-10 16:19:00+03	289800.00
C42761	2017-07-20 02:25:00+03	40800.00
C42769	2017-08-02 13:51:00+03	60700.00
C4278F	2017-08-09 11:53:00+03	272400.00
C4280E	2017-07-30 17:44:00+03	44800.00
C428AB	2017-07-10 06:56:00+03	64800.00
C428CC	2017-07-27 22:06:00+03	135600.00
C4290C	2017-07-20 04:10:00+03	15900.00
C4293F	2017-07-08 16:31:00+03	47100.00
C4294A	2017-08-05 11:23:00+03	46400.00
C4295A	2017-08-15 09:32:00+03	229900.00
C42999	2017-08-08 12:07:00+03	26000.00
C429AD	2017-08-03 11:22:00+03	115100.00
C429E5	2017-07-11 18:54:00+03	42800.00
C42A17	2017-07-10 12:53:00+03	90400.00
C42A31	2017-08-13 08:01:00+03	38200.00
C42ABF	2017-07-26 20:13:00+03	59200.00
C42B78	2017-07-09 07:13:00+03	68000.00
C42BD2	2017-08-10 17:58:00+03	54800.00
C42BEE	2017-07-20 18:40:00+03	45200.00
C42BF7	2017-08-14 09:29:00+03	257600.00
C42C16	2017-07-26 06:36:00+03	155600.00
C42CB7	2017-08-06 16:06:00+03	80000.00
C42D13	2017-07-24 08:52:00+03	16400.00
C42D37	2017-07-01 16:38:00+03	46700.00
C42D43	2017-08-01 23:29:00+03	205100.00
C42D76	2017-08-02 21:08:00+03	246000.00
C42D78	2017-07-18 21:49:00+03	270200.00
C42D88	2017-08-08 23:41:00+03	133100.00
C42E24	2017-08-15 01:09:00+03	126800.00
C42E28	2017-07-23 13:53:00+03	283100.00
C42E8C	2017-08-14 02:28:00+03	59300.00
C42EA7	2017-08-12 14:27:00+03	12000.00
C42F17	2017-07-04 10:43:00+03	133200.00
C42F2E	2017-08-01 22:34:00+03	125200.00
C42F47	2017-08-04 06:48:00+03	45200.00
C42F66	2017-08-07 07:17:00+03	87100.00
C42F9E	2017-08-15 05:12:00+03	36400.00
C4306B	2017-07-09 20:26:00+03	19100.00
C43077	2017-07-29 22:40:00+03	39600.00
C4308E	2017-08-12 06:13:00+03	62600.00
C430FC	2017-07-16 21:44:00+03	89700.00
C43156	2017-08-03 09:57:00+03	200400.00
C431ED	2017-07-03 15:19:00+03	28000.00
C43277	2017-07-20 08:44:00+03	12600.00
C43293	2017-07-31 07:44:00+03	47400.00
C432AC	2017-08-13 09:34:00+03	21800.00
C43305	2017-07-25 18:53:00+03	89500.00
C43385	2017-07-11 08:45:00+03	25600.00
C43417	2017-08-08 03:16:00+03	95200.00
C43596	2017-06-28 01:05:00+03	295200.00
C43611	2017-07-18 02:11:00+03	52000.00
C4362A	2017-07-11 17:12:00+03	166900.00
C4364E	2017-07-24 11:44:00+03	26000.00
C43661	2017-07-31 11:48:00+03	6700.00
C43677	2017-08-07 08:35:00+03	31200.00
C436A9	2017-08-02 10:59:00+03	12400.00
C436FD	2017-07-22 07:19:00+03	38800.00
C43760	2017-08-05 05:55:00+03	56000.00
C43790	2017-07-21 06:11:00+03	28000.00
C437EB	2017-08-11 17:29:00+03	24500.00
C4380B	2017-07-16 23:42:00+03	189800.00
C43826	2017-07-11 05:41:00+03	64500.00
C438DC	2017-08-09 03:06:00+03	53600.00
C438E8	2017-08-10 23:49:00+03	116700.00
C4397B	2017-08-13 16:20:00+03	29400.00
C439AC	2017-07-15 12:42:00+03	26700.00
C439BF	2017-08-11 16:01:00+03	19600.00
C43A38	2017-07-03 13:04:00+03	191300.00
C43A78	2017-08-09 16:04:00+03	36400.00
C43A9E	2017-07-13 01:56:00+03	28000.00
C43AC9	2017-08-10 07:04:00+03	92400.00
C43AF9	2017-07-09 14:41:00+03	46700.00
C43B46	2017-08-13 19:10:00+03	66600.00
C43BA7	2017-07-14 20:08:00+03	14700.00
C43BAC	2017-07-21 15:58:00+03	199600.00
C43BB5	2017-07-05 05:50:00+03	88600.00
C43BDB	2017-07-12 08:27:00+03	29400.00
C43C1C	2017-07-19 02:19:00+03	125200.00
C43C28	2017-07-30 23:20:00+03	155600.00
C43C2E	2017-07-12 12:08:00+03	37300.00
C43C3F	2017-08-08 22:42:00+03	30200.00
C43C49	2017-07-27 15:46:00+03	22600.00
C43C89	2017-07-14 07:01:00+03	96800.00
C43C93	2017-07-25 00:55:00+03	111600.00
C43CC8	2017-08-14 18:46:00+03	121400.00
C43CCA	2017-08-13 01:47:00+03	22600.00
C43CEA	2017-07-19 20:12:00+03	30900.00
C43D0C	2017-08-09 20:21:00+03	135400.00
C43D35	2017-07-04 16:32:00+03	39200.00
C43D8C	2017-07-01 13:17:00+03	28000.00
C43DB9	2017-08-13 08:21:00+03	99300.00
C43DF0	2017-07-30 12:45:00+03	46000.00
C43E01	2017-07-06 07:27:00+03	99700.00
C43E1A	2017-08-13 18:15:00+03	55900.00
C43E23	2017-07-22 18:48:00+03	262200.00
C43E29	2017-07-09 01:53:00+03	114600.00
C43E3A	2017-07-10 20:45:00+03	144400.00
C43E3D	2017-07-25 18:04:00+03	19600.00
C43E5D	2017-07-21 11:26:00+03	32300.00
C43E74	2017-08-06 00:25:00+03	14000.00
C43E9D	2017-07-20 15:06:00+03	31400.00
C43EB3	2017-08-05 23:49:00+03	133100.00
C43ED0	2017-08-14 09:53:00+03	111600.00
C43EE4	2017-07-04 11:50:00+03	36200.00
C43F3B	2017-07-06 08:22:00+03	167400.00
C43F70	2017-07-25 00:42:00+03	199100.00
C43F97	2017-08-14 08:03:00+03	120800.00
C43FE8	2017-08-03 08:31:00+03	394800.00
C43FEB	2017-06-27 23:53:00+03	191200.00
C4400E	2017-07-14 06:47:00+03	7200.00
C44071	2017-08-04 17:01:00+03	108000.00
C44081	2017-06-30 14:51:00+03	133100.00
C440BC	2017-08-13 11:42:00+03	27300.00
C440E2	2017-07-24 00:35:00+03	9300.00
C44158	2017-07-20 12:51:00+03	26700.00
C44181	2017-07-10 05:43:00+03	36200.00
C44182	2017-07-24 07:39:00+03	73600.00
C441EE	2017-07-05 20:18:00+03	64800.00
C44200	2017-08-13 16:09:00+03	28000.00
C44223	2017-07-17 10:34:00+03	39800.00
C44265	2017-07-26 21:42:00+03	24000.00
C442A0	2017-08-10 21:43:00+03	66200.00
C44354	2017-07-18 11:19:00+03	51300.00
C443B6	2017-07-07 16:18:00+03	20600.00
C44423	2017-08-08 05:48:00+03	39200.00
C4448C	2017-07-20 15:25:00+03	38600.00
C4455B	2017-07-22 13:22:00+03	87000.00
C44588	2017-07-08 23:00:00+03	170800.00
C445BA	2017-07-03 22:53:00+03	36200.00
C44625	2017-07-06 18:28:00+03	128800.00
C44663	2017-07-26 06:54:00+03	27600.00
C4468E	2017-08-09 20:34:00+03	119900.00
C44705	2017-07-04 14:18:00+03	85700.00
C44741	2017-07-18 12:50:00+03	48300.00
C447D6	2017-07-17 22:45:00+03	39600.00
C44851	2017-08-05 07:41:00+03	202300.00
C44888	2017-08-01 21:14:00+03	258000.00
C448A1	2017-07-11 08:53:00+03	64300.00
C4495E	2017-07-16 18:31:00+03	42600.00
C44A18	2017-08-05 10:06:00+03	37100.00
C44A5B	2017-08-10 13:37:00+03	67800.00
C44AEA	2017-07-31 21:40:00+03	80000.00
C44B67	2017-07-07 12:08:00+03	68800.00
C44B79	2017-08-06 06:45:00+03	64700.00
C44BAB	2017-08-03 17:49:00+03	81300.00
C44C25	2017-07-04 11:58:00+03	100600.00
C44CB5	2017-07-14 21:46:00+03	65500.00
C44D24	2017-07-20 08:26:00+03	70700.00
C44D79	2017-07-09 12:29:00+03	35200.00
C44D7D	2017-07-01 15:30:00+03	75600.00
C44DD8	2017-07-24 10:21:00+03	36900.00
C44E2C	2017-07-22 08:52:00+03	40800.00
C44E41	2017-07-06 05:44:00+03	516800.00
C44E51	2017-07-28 00:36:00+03	59800.00
C44E5B	2017-08-12 03:41:00+03	46300.00
C44E89	2017-07-18 06:08:00+03	67900.00
C44F2C	2017-07-10 22:35:00+03	46300.00
C44F4D	2017-08-03 17:12:00+03	29400.00
C44F89	2017-07-28 23:01:00+03	57500.00
C44F96	2017-07-08 21:50:00+03	18600.00
C4503B	2017-07-01 01:03:00+03	146300.00
C4504C	2017-08-12 02:03:00+03	14000.00
C450AE	2017-07-07 00:11:00+03	53600.00
C450B6	2017-08-05 20:39:00+03	14400.00
C450E1	2017-07-17 17:40:00+03	24600.00
C450EF	2017-08-06 01:59:00+03	67600.00
C45153	2017-07-27 16:59:00+03	234100.00
C451A8	2017-08-04 00:41:00+03	44800.00
C451EE	2017-08-06 05:15:00+03	28800.00
C452AA	2017-08-10 10:32:00+03	46800.00
C452C1	2017-08-12 07:47:00+03	106600.00
C452ED	2017-08-04 08:49:00+03	58800.00
C45319	2017-07-22 07:42:00+03	26000.00
C4532F	2017-07-24 19:37:00+03	36900.00
C4534D	2017-07-23 11:39:00+03	31000.00
C4538A	2017-08-05 20:22:00+03	28800.00
C45394	2017-08-15 06:58:00+03	25600.00
C45396	2017-07-11 07:43:00+03	31600.00
C453C3	2017-08-10 23:10:00+03	56000.00
C453E2	2017-07-22 13:35:00+03	44000.00
C45481	2017-07-06 04:28:00+03	100600.00
C4548C	2017-08-09 08:56:00+03	67100.00
C454F1	2017-07-28 19:05:00+03	27900.00
C45515	2017-07-04 12:46:00+03	70500.00
C45521	2017-07-16 07:51:00+03	18900.00
C4553C	2017-08-05 17:17:00+03	6000.00
C455B1	2017-07-09 16:52:00+03	111600.00
C455B9	2017-08-02 09:14:00+03	124200.00
C455EC	2017-08-04 05:13:00+03	124200.00
C45602	2017-08-01 15:23:00+03	178800.00
C456CF	2017-07-07 18:12:00+03	248400.00
C45712	2017-08-10 01:03:00+03	49800.00
C4571D	2017-07-18 14:02:00+03	6300.00
C4572A	2017-08-02 05:35:00+03	64500.00
C45746	2017-06-30 05:11:00+03	136800.00
C45794	2017-08-14 07:37:00+03	62400.00
C457D5	2017-07-05 09:17:00+03	155600.00
C458AE	2017-07-03 21:48:00+03	188000.00
C458E1	2017-07-17 16:22:00+03	21800.00
C458EB	2017-08-10 09:51:00+03	40000.00
C45911	2017-07-08 07:26:00+03	101000.00
C4598E	2017-07-29 14:32:00+03	14400.00
C4598F	2017-08-13 03:23:00+03	24000.00
C45991	2017-08-07 03:00:00+03	73600.00
C45A28	2017-08-13 21:19:00+03	50400.00
C45A6B	2017-08-06 16:59:00+03	58200.00
C45AAB	2017-07-22 10:40:00+03	78000.00
C45AD7	2017-07-04 06:35:00+03	31600.00
C45AE3	2017-07-01 09:50:00+03	83000.00
C45AEE	2017-07-13 04:51:00+03	113300.00
C45B1E	2017-07-16 01:09:00+03	26800.00
C45B30	2017-07-08 03:32:00+03	6800.00
C45B54	2017-08-14 12:06:00+03	99700.00
C45B8D	2017-08-12 00:13:00+03	101100.00
C45C04	2017-08-13 00:02:00+03	46300.00
C45C13	2017-08-06 06:48:00+03	12400.00
C45C14	2017-07-17 03:12:00+03	38800.00
C45C2E	2017-07-14 03:17:00+03	35700.00
C45C6E	2017-07-11 00:31:00+03	54400.00
C45C99	2017-07-14 03:19:00+03	24400.00
C45CB6	2017-07-03 21:30:00+03	84700.00
C45CBB	2017-08-14 11:54:00+03	283100.00
C45D33	2017-08-08 22:05:00+03	25000.00
C45D37	2017-07-11 15:31:00+03	21800.00
C45D82	2017-06-28 02:13:00+03	6300.00
C45E45	2017-07-01 12:17:00+03	20200.00
C45E62	2017-07-29 14:58:00+03	150600.00
C45EA1	2017-08-10 11:36:00+03	7800.00
C45EA2	2017-07-03 09:10:00+03	100300.00
C45EBC	2017-07-14 06:23:00+03	280000.00
C45F1D	2017-07-16 23:19:00+03	40200.00
C45F51	2017-08-04 12:06:00+03	110500.00
C45F80	2017-07-20 11:25:00+03	104600.00
C45F86	2017-07-06 09:12:00+03	111600.00
C4601F	2017-07-07 06:33:00+03	10800.00
C46041	2017-07-01 03:24:00+03	34000.00
C4604F	2017-07-19 02:16:00+03	135000.00
C4605F	2017-08-14 14:28:00+03	75600.00
C46125	2017-07-02 11:34:00+03	35200.00
C46151	2017-08-14 18:14:00+03	105000.00
C461AA	2017-07-05 17:56:00+03	131100.00
C461B9	2017-07-05 08:25:00+03	46200.00
C461E5	2017-07-24 01:26:00+03	15900.00
C4621A	2017-07-05 19:31:00+03	23200.00
C46288	2017-07-14 17:47:00+03	46300.00
C462A4	2017-08-04 15:53:00+03	31600.00
C462E1	2017-07-01 17:40:00+03	58900.00
C462E9	2017-07-01 13:50:00+03	20200.00
C462F0	2017-07-24 01:55:00+03	60400.00
C46382	2017-07-12 02:29:00+03	67600.00
C463A5	2017-08-11 20:16:00+03	32800.00
C463D4	2017-07-17 04:15:00+03	553900.00
C4641B	2017-07-09 15:31:00+03	153800.00
C4642D	2017-07-11 13:40:00+03	26800.00
C4644B	2017-08-10 19:30:00+03	105000.00
C46459	2017-07-14 10:43:00+03	139400.00
C46471	2017-07-12 00:17:00+03	37900.00
C4648E	2017-07-17 17:11:00+03	260900.00
C465F8	2017-08-07 06:48:00+03	99200.00
C4662C	2017-08-15 07:45:00+03	24000.00
C46681	2017-08-14 07:14:00+03	30700.00
C46762	2017-07-02 05:06:00+03	36400.00
C467C9	2017-08-02 05:03:00+03	111600.00
C4686F	2017-08-10 13:42:00+03	27700.00
C46874	2017-07-22 09:50:00+03	136600.00
C46896	2017-07-27 08:40:00+03	123900.00
C4689A	2017-07-26 09:56:00+03	35300.00
C4690B	2017-08-06 19:17:00+03	17200.00
C469A4	2017-07-24 17:35:00+03	47600.00
C469AF	2017-07-19 10:11:00+03	56100.00
C469E8	2017-07-02 19:30:00+03	22000.00
C469F3	2017-07-19 21:19:00+03	111600.00
C469FC	2017-08-01 16:24:00+03	20000.00
C46A3F	2017-07-05 21:02:00+03	36400.00
C46A4F	2017-07-06 18:57:00+03	471800.00
C46AEF	2017-07-13 11:09:00+03	58800.00
C46B81	2017-08-13 01:04:00+03	28800.00
C46B8C	2017-07-03 13:36:00+03	67600.00
C46B91	2017-07-17 15:12:00+03	37200.00
C46B94	2017-07-09 21:16:00+03	27800.00
C46C07	2017-07-25 04:00:00+03	67900.00
C46C1D	2017-07-29 00:49:00+03	78800.00
C46C2D	2017-07-16 13:26:00+03	100800.00
C46C3D	2017-07-11 18:38:00+03	7400.00
C46C75	2017-07-19 17:28:00+03	112000.00
C46CB0	2017-08-05 22:35:00+03	26700.00
C46CE5	2017-07-12 12:07:00+03	52700.00
C46D57	2017-08-14 20:57:00+03	100200.00
C46D7F	2017-07-26 20:43:00+03	28000.00
C46DC3	2017-07-07 11:23:00+03	207600.00
C46DC4	2017-08-14 14:38:00+03	18600.00
C46DD8	2017-06-30 01:46:00+03	29400.00
C46DE9	2017-07-23 08:54:00+03	52000.00
C46DF0	2017-07-15 07:25:00+03	112000.00
C46DF2	2017-07-09 10:20:00+03	13400.00
C46E33	2017-07-31 14:01:00+03	24400.00
C46E6B	2017-07-16 11:18:00+03	56600.00
C46E93	2017-07-15 02:57:00+03	12400.00
C46E9F	2017-08-03 06:16:00+03	67100.00
C46F4A	2017-07-09 11:11:00+03	25400.00
C46F66	2017-07-05 06:09:00+03	77200.00
C46F9B	2017-07-26 08:49:00+03	28000.00
C46FCD	2017-08-04 17:49:00+03	174300.00
C46FDA	2017-08-01 00:34:00+03	20400.00
C46FEB	2017-08-02 01:42:00+03	27200.00
C47006	2017-07-25 12:43:00+03	15900.00
C47012	2017-08-02 18:08:00+03	131100.00
C47026	2017-07-24 19:14:00+03	137600.00
C47085	2017-08-15 17:06:00+03	93800.00
C47115	2017-07-05 10:03:00+03	108200.00
C47129	2017-08-07 13:58:00+03	40400.00
C471DB	2017-08-07 01:12:00+03	88500.00
C4723D	2017-07-06 22:35:00+03	145300.00
C47242	2017-08-05 01:11:00+03	92900.00
C47288	2017-07-26 13:47:00+03	39600.00
C472A8	2017-07-24 12:33:00+03	57600.00
C472C8	2017-07-16 09:13:00+03	87400.00
C47310	2017-07-30 08:21:00+03	77200.00
C47378	2017-08-15 07:14:00+03	36200.00
C4738C	2017-07-15 08:56:00+03	42700.00
C473A8	2017-07-28 03:20:00+03	133200.00
C473CD	2017-08-09 09:30:00+03	79400.00
C4743F	2017-07-07 11:11:00+03	132800.00
C4744C	2017-07-19 18:27:00+03	49100.00
C4747C	2017-08-13 02:26:00+03	95000.00
C474A9	2017-08-01 09:58:00+03	174400.00
C47515	2017-07-10 15:44:00+03	167500.00
C4758D	2017-07-06 16:20:00+03	16400.00
C475E1	2017-07-12 01:05:00+03	16400.00
C4763E	2017-07-04 01:02:00+03	26800.00
C476C6	2017-07-13 17:17:00+03	47000.00
C477C2	2017-07-29 14:16:00+03	77500.00
C47871	2017-07-17 13:51:00+03	14000.00
C479B1	2017-07-01 20:05:00+03	45500.00
C479B2	2017-08-15 08:08:00+03	125700.00
C479EE	2017-07-14 09:13:00+03	189200.00
C479EF	2017-07-07 23:20:00+03	28800.00
C479FC	2017-07-05 23:52:00+03	28800.00
C479FF	2017-07-05 05:38:00+03	148200.00
C47A69	2017-07-11 13:41:00+03	85000.00
C47A9B	2017-07-07 04:35:00+03	31900.00
C47A9D	2017-07-11 03:21:00+03	101800.00
C47AEC	2017-07-13 08:28:00+03	19600.00
C47BC7	2017-08-02 16:05:00+03	155600.00
C47C62	2017-07-31 19:06:00+03	78100.00
C47C92	2017-07-10 05:59:00+03	66800.00
C47CAB	2017-07-25 08:31:00+03	66600.00
C47CD8	2017-07-29 22:50:00+03	68100.00
C47CF3	2017-07-10 02:54:00+03	8200.00
C47CF7	2017-07-14 03:03:00+03	79000.00
C47D68	2017-07-03 05:33:00+03	27400.00
C47D89	2017-08-08 07:22:00+03	26000.00
C47D8A	2017-07-14 01:20:00+03	20400.00
C47DD5	2017-08-06 07:39:00+03	157300.00
C47EEC	2017-07-15 09:10:00+03	40800.00
C47F11	2017-08-03 14:50:00+03	176500.00
C47F1E	2017-07-18 17:18:00+03	45200.00
C47F2B	2017-06-29 13:25:00+03	6000.00
C47F69	2017-08-15 14:14:00+03	65100.00
C47F83	2017-07-01 07:18:00+03	39500.00
C47F84	2017-07-08 16:40:00+03	38200.00
C47F8B	2017-08-09 06:51:00+03	96000.00
C47F8E	2017-06-30 09:44:00+03	52800.00
C48021	2017-07-05 10:51:00+03	40000.00
C4802E	2017-07-18 14:52:00+03	61600.00
C4809F	2017-07-28 17:52:00+03	23600.00
C480D5	2017-07-11 10:55:00+03	174400.00
C48104	2017-07-01 07:33:00+03	14400.00
C481B7	2017-07-18 05:57:00+03	39800.00
C481DE	2017-07-18 22:01:00+03	15000.00
C481DF	2017-07-12 08:22:00+03	38600.00
C4821F	2017-07-13 04:28:00+03	65100.00
C482DD	2017-07-13 01:30:00+03	56000.00
C482F5	2017-08-06 03:07:00+03	13000.00
C4833D	2017-07-24 03:33:00+03	137800.00
C4837C	2017-08-13 06:43:00+03	14800.00
C483BD	2017-07-19 13:03:00+03	98400.00
C4842B	2017-07-19 02:20:00+03	36600.00
C48436	2017-08-08 12:02:00+03	298600.00
C48441	2017-06-28 23:10:00+03	42600.00
C484C6	2017-08-11 10:22:00+03	39500.00
C48571	2017-08-07 01:28:00+03	13400.00
C485AD	2017-07-15 16:48:00+03	270800.00
C485E2	2017-07-18 07:37:00+03	126800.00
C48614	2017-07-09 22:10:00+03	153300.00
C4863F	2017-07-19 11:03:00+03	180400.00
C4864A	2017-07-25 02:32:00+03	131100.00
C48657	2017-07-12 17:52:00+03	24700.00
C4866D	2017-07-31 09:31:00+03	47400.00
C48755	2017-07-17 23:29:00+03	11200.00
C48756	2017-07-07 15:12:00+03	64800.00
C48779	2017-07-09 03:14:00+03	89600.00
C4878E	2017-07-13 17:36:00+03	36800.00
C487B9	2017-07-18 14:54:00+03	214100.00
C48853	2017-07-08 23:03:00+03	115700.00
C48869	2017-07-30 11:25:00+03	7400.00
C488AB	2017-07-14 20:59:00+03	354400.00
C4892B	2017-08-11 06:56:00+03	46400.00
C48943	2017-06-29 09:57:00+03	40800.00
C48982	2017-07-07 00:34:00+03	28000.00
C489E2	2017-07-31 20:05:00+03	99300.00
C48AE4	2017-06-30 07:40:00+03	65500.00
C48B31	2017-07-26 20:19:00+03	38800.00
C48B90	2017-08-13 20:02:00+03	179200.00
C48B94	2017-08-07 07:02:00+03	169300.00
C48C03	2017-07-01 02:42:00+03	187800.00
C48C1E	2017-07-14 00:48:00+03	132800.00
C48CC8	2017-08-08 13:12:00+03	351000.00
C48CD2	2017-07-30 10:46:00+03	24400.00
C48CFE	2017-07-05 11:19:00+03	26000.00
C48D02	2017-07-31 23:07:00+03	8400.00
C48D49	2017-08-06 20:30:00+03	21400.00
C48D73	2017-07-24 21:35:00+03	149300.00
C48D89	2017-07-31 20:58:00+03	50400.00
C48DAD	2017-07-28 18:00:00+03	54500.00
C48DD9	2017-07-30 12:19:00+03	6000.00
C48E45	2017-06-30 02:40:00+03	38400.00
C48E5D	2017-07-15 05:32:00+03	293100.00
C48EED	2017-07-23 17:04:00+03	353400.00
C48F0F	2017-07-01 23:54:00+03	21400.00
C48F35	2017-07-23 20:42:00+03	80700.00
C48F5A	2017-08-13 07:08:00+03	57500.00
C48F65	2017-07-02 07:57:00+03	46800.00
C49001	2017-07-02 13:03:00+03	144400.00
C490CE	2017-07-25 07:23:00+03	65500.00
C490D6	2017-07-08 16:41:00+03	46300.00
C4910A	2017-07-14 02:10:00+03	92100.00
C49145	2017-07-03 03:00:00+03	52000.00
C4917A	2017-07-27 09:46:00+03	30200.00
C4917E	2017-08-09 21:24:00+03	112000.00
C4918B	2017-07-29 23:11:00+03	71200.00
C491C3	2017-08-08 01:05:00+03	277000.00
C491F3	2017-07-31 16:04:00+03	48600.00
C491F8	2017-08-12 17:17:00+03	182000.00
C4923C	2017-08-06 01:31:00+03	29400.00
C4928B	2017-07-18 17:59:00+03	117700.00
C49346	2017-08-09 08:07:00+03	25100.00
C49406	2017-07-26 22:29:00+03	57600.00
C49430	2017-06-29 03:25:00+03	52100.00
C494AC	2017-07-26 03:52:00+03	23200.00
C49515	2017-08-13 12:27:00+03	62300.00
C49586	2017-07-31 14:25:00+03	83200.00
C495BB	2017-07-21 07:52:00+03	22000.00
C49673	2017-08-01 02:23:00+03	12400.00
C4969E	2017-08-15 05:54:00+03	56900.00
C496AD	2017-08-04 22:28:00+03	24400.00
C49704	2017-07-10 14:21:00+03	51900.00
C49718	2017-08-13 09:27:00+03	10800.00
C4971F	2017-08-12 09:30:00+03	12600.00
C49778	2017-07-28 13:18:00+03	12000.00
C4977B	2017-07-14 08:55:00+03	14000.00
C49788	2017-07-28 12:52:00+03	115600.00
C497D5	2017-07-06 20:44:00+03	56000.00
C4981E	2017-07-30 21:33:00+03	22000.00
C49840	2017-08-15 12:05:00+03	79900.00
C4986E	2017-08-15 02:45:00+03	55800.00
C49879	2017-06-28 16:24:00+03	6700.00
C498F2	2017-07-08 02:21:00+03	26700.00
C49998	2017-08-08 02:15:00+03	192700.00
C499D1	2017-07-25 21:44:00+03	22000.00
C49A49	2017-07-19 06:22:00+03	10800.00
C49A65	2017-07-03 21:57:00+03	194100.00
C49A6C	2017-08-07 18:21:00+03	28300.00
C49A79	2017-08-12 06:36:00+03	91500.00
C49AAF	2017-07-03 09:07:00+03	16400.00
C49C04	2017-07-16 10:11:00+03	46000.00
C49C08	2017-07-05 07:47:00+03	62600.00
C49C0A	2017-07-25 07:09:00+03	127200.00
C49C6D	2017-08-06 05:34:00+03	152400.00
C49C8A	2017-07-05 04:57:00+03	89700.00
C49D6B	2017-07-05 02:04:00+03	120100.00
C49DC9	2017-07-30 06:34:00+03	84500.00
C49E17	2017-08-01 09:45:00+03	8400.00
C49E37	2017-07-17 10:28:00+03	74200.00
C49E38	2017-07-06 08:33:00+03	97900.00
C49E4B	2017-08-02 04:46:00+03	83000.00
C49E64	2017-07-12 00:17:00+03	47400.00
C49E66	2017-08-12 13:51:00+03	66800.00
C49EC0	2017-07-17 08:33:00+03	103000.00
C49F07	2017-08-06 08:59:00+03	14000.00
C49F1E	2017-07-07 12:28:00+03	23200.00
C49F48	2017-08-01 12:04:00+03	138600.00
C49FA6	2017-07-25 21:48:00+03	23600.00
C49FB8	2017-08-13 19:06:00+03	146000.00
C4A013	2017-08-11 16:53:00+03	34000.00
C4A04D	2017-07-03 06:30:00+03	33300.00
C4A076	2017-07-10 02:08:00+03	32800.00
C4A0D3	2017-08-10 09:49:00+03	96100.00
C4A0DE	2017-07-23 11:54:00+03	90400.00
C4A194	2017-08-13 10:19:00+03	62600.00
C4A1B2	2017-07-21 01:27:00+03	86200.00
C4A1DE	2017-06-27 05:26:00+03	21800.00
C4A1DF	2017-07-01 19:25:00+03	45600.00
C4A201	2017-08-06 21:46:00+03	86300.00
C4A27C	2017-07-01 08:08:00+03	21000.00
C4A28D	2017-08-15 00:42:00+03	52600.00
C4A2AF	2017-07-22 16:25:00+03	168000.00
C4A2B3	2017-08-08 08:40:00+03	27400.00
C4A2B5	2017-08-11 12:28:00+03	46000.00
C4A2E1	2017-08-15 15:46:00+03	16800.00
C4A353	2017-08-11 12:31:00+03	77500.00
C4A368	2017-07-22 07:02:00+03	32800.00
C4A39B	2017-07-25 22:12:00+03	47200.00
C4A3A6	2017-08-14 08:01:00+03	117100.00
C4A41B	2017-07-22 12:28:00+03	56900.00
C4A44B	2017-08-06 08:20:00+03	90400.00
C4A4F5	2017-07-17 19:28:00+03	137600.00
C4A550	2017-07-11 00:57:00+03	42100.00
C4A582	2017-06-28 09:59:00+03	23400.00
C4A656	2017-07-20 16:36:00+03	169900.00
C4A743	2017-07-12 11:31:00+03	130000.00
C4A766	2017-08-02 12:53:00+03	44500.00
C4A76A	2017-07-22 22:00:00+03	23200.00
C4A7F0	2017-07-30 02:47:00+03	89700.00
C4A803	2017-07-27 03:47:00+03	136800.00
C4A8A8	2017-07-31 23:19:00+03	234700.00
C4A8F6	2017-08-14 17:20:00+03	122500.00
C4A908	2017-07-08 19:19:00+03	59200.00
C4A923	2017-07-09 03:18:00+03	39500.00
C4A93D	2017-07-23 18:43:00+03	335500.00
C4AA6E	2017-07-08 10:27:00+03	35200.00
C4AA8F	2017-08-07 04:01:00+03	47000.00
C4AA96	2017-07-03 22:32:00+03	393800.00
C4AAA3	2017-07-01 09:34:00+03	55800.00
C4AAE1	2017-07-30 00:38:00+03	40800.00
C4AB35	2017-07-19 19:49:00+03	66800.00
C4ABC8	2017-07-26 10:29:00+03	113200.00
C4ABE3	2017-07-27 17:49:00+03	26800.00
C4AC23	2017-08-14 07:45:00+03	13500.00
C4AC40	2017-07-15 10:56:00+03	98200.00
C4AC71	2017-08-10 19:30:00+03	217400.00
C4ACD6	2017-08-14 21:50:00+03	53600.00
C4ACE5	2017-07-07 21:50:00+03	46200.00
C4AD14	2017-08-14 22:38:00+03	76800.00
C4AD35	2017-08-14 07:28:00+03	188900.00
C4AD6B	2017-08-12 13:17:00+03	39200.00
C4AD78	2017-08-11 16:13:00+03	96700.00
C4ADED	2017-07-19 02:48:00+03	113000.00
C4AE65	2017-07-11 23:24:00+03	99200.00
C4AE99	2017-08-04 17:19:00+03	123000.00
C4AEF6	2017-07-07 07:06:00+03	71800.00
C4AEFE	2017-07-16 13:38:00+03	43200.00
C4AF42	2017-07-15 03:33:00+03	84300.00
C4AF43	2017-07-13 04:54:00+03	14800.00
C4AF7B	2017-06-29 23:50:00+03	67100.00
C4AFBE	2017-06-30 02:23:00+03	12400.00
C4AFD6	2017-07-09 20:20:00+03	258400.00
C4B059	2017-07-27 09:28:00+03	42800.00
C4B09A	2017-07-17 06:29:00+03	23200.00
C4B0AE	2017-08-01 23:35:00+03	13400.00
C4B203	2017-08-11 10:17:00+03	99800.00
C4B24B	2017-08-02 02:54:00+03	33400.00
C4B25A	2017-08-10 22:31:00+03	24400.00
C4B29D	2017-07-18 17:06:00+03	45200.00
C4B2B5	2017-08-04 06:23:00+03	22000.00
C4B2FA	2017-07-20 19:33:00+03	32800.00
C4B359	2017-07-17 03:58:00+03	131100.00
C4B3E0	2017-06-30 21:16:00+03	50800.00
C4B455	2017-07-13 02:52:00+03	19600.00
C4B49F	2017-08-10 14:16:00+03	27200.00
C4B4A8	2017-07-19 06:04:00+03	164800.00
C4B4D8	2017-07-04 17:42:00+03	27200.00
C4B4DF	2017-07-29 22:39:00+03	44500.00
C4B5A0	2017-08-06 00:02:00+03	34600.00
C4B5FD	2017-07-15 08:59:00+03	54600.00
C4B5FF	2017-07-26 23:53:00+03	26000.00
C4B613	2017-06-28 01:24:00+03	23600.00
C4B642	2017-08-08 04:31:00+03	47400.00
C4B6B5	2017-07-23 15:31:00+03	69500.00
C4B765	2017-07-19 08:45:00+03	79600.00
C4B776	2017-07-19 08:28:00+03	36800.00
C4B7F6	2017-07-27 15:30:00+03	43300.00
C4B808	2017-08-02 06:46:00+03	28800.00
C4B822	2017-07-12 23:59:00+03	112000.00
C4B829	2017-08-05 22:17:00+03	67700.00
C4B82B	2017-08-04 13:49:00+03	37900.00
C4B854	2017-07-22 23:33:00+03	89600.00
C4B87A	2017-08-10 22:23:00+03	57500.00
C4BA0A	2017-07-06 16:02:00+03	77200.00
C4BA49	2017-07-21 09:37:00+03	26800.00
C4BA5A	2017-08-05 05:25:00+03	67800.00
C4BADD	2017-07-27 05:21:00+03	23200.00
C4BAF1	2017-07-01 23:33:00+03	238200.00
C4BAF2	2017-08-13 02:07:00+03	169100.00
C4BB35	2017-07-11 22:39:00+03	55800.00
C4BB45	2017-08-07 02:47:00+03	56600.00
C4BB79	2017-07-19 11:02:00+03	42800.00
C4BC70	2017-08-02 05:08:00+03	73200.00
C4BCBF	2017-07-06 13:10:00+03	229600.00
C4BD2A	2017-07-23 19:32:00+03	27200.00
C4BE13	2017-07-25 03:02:00+03	67700.00
C4BE65	2017-08-09 01:48:00+03	39800.00
C4BEF2	2017-07-20 04:37:00+03	6700.00
C4BF06	2017-08-09 19:30:00+03	92900.00
C4BF48	2017-07-15 01:28:00+03	131600.00
C4BF55	2017-08-03 02:50:00+03	33900.00
C4BF6A	2017-07-17 15:46:00+03	201200.00
C4BF70	2017-08-05 01:42:00+03	72800.00
C4BFD0	2017-06-30 04:55:00+03	26200.00
C4C05F	2017-07-02 02:04:00+03	68400.00
C4C0C9	2017-07-31 00:37:00+03	151200.00
C4C0EF	2017-07-27 04:01:00+03	40600.00
C4C102	2017-07-28 08:36:00+03	24400.00
C4C123	2017-07-15 23:38:00+03	143600.00
C4C12A	2017-07-12 14:09:00+03	54400.00
C4C166	2017-07-30 06:56:00+03	36200.00
C4C1E0	2017-08-08 05:13:00+03	123000.00
C4C1F0	2017-08-08 07:34:00+03	40600.00
C4C1F6	2017-07-11 09:05:00+03	53800.00
C4C235	2017-08-13 18:31:00+03	131100.00
C4C291	2017-07-30 10:05:00+03	28000.00
C4C2DF	2017-08-07 02:15:00+03	136200.00
C4C2E2	2017-07-09 14:17:00+03	28800.00
C4C306	2017-07-17 03:08:00+03	27200.00
C4C341	2017-07-21 12:45:00+03	173600.00
C4C36E	2017-08-08 14:34:00+03	46000.00
C4C3B3	2017-07-08 20:53:00+03	46400.00
C4C41E	2017-07-24 20:25:00+03	133600.00
C4C42A	2017-07-05 01:54:00+03	33000.00
C4C494	2017-07-14 00:26:00+03	20400.00
C4C49B	2017-07-28 14:20:00+03	105600.00
C4C4DA	2017-07-04 20:42:00+03	70400.00
C4C53B	2017-08-05 12:38:00+03	75300.00
C4C542	2017-07-05 12:18:00+03	21400.00
C4C592	2017-07-09 07:33:00+03	28000.00
C4C5DE	2017-07-06 20:03:00+03	36100.00
C4C600	2017-08-09 18:36:00+03	75600.00
C4C631	2017-08-03 21:16:00+03	84500.00
C4C63F	2017-07-24 14:57:00+03	87600.00
C4C649	2017-08-03 22:24:00+03	326300.00
C4C6D7	2017-08-11 13:00:00+03	24800.00
C4C76C	2017-07-31 01:37:00+03	8200.00
C4C773	2017-08-09 19:56:00+03	284800.00
C4C7C5	2017-07-23 11:10:00+03	27600.00
C4C7F4	2017-08-05 11:56:00+03	29600.00
C4C844	2017-07-12 01:11:00+03	43700.00
C4C84F	2017-08-09 21:10:00+03	132800.00
C4C85F	2017-08-06 08:09:00+03	86900.00
C4C873	2017-07-18 16:29:00+03	7400.00
C4C8B7	2017-07-07 06:36:00+03	73500.00
C4C959	2017-07-09 07:40:00+03	56100.00
C4C9B1	2017-07-21 06:40:00+03	25400.00
C4CA21	2017-06-29 06:47:00+03	55800.00
C4CAF8	2017-07-31 16:16:00+03	69500.00
C4CB78	2017-07-06 22:35:00+03	53800.00
C4CC0C	2017-07-25 00:31:00+03	46400.00
C4CC5D	2017-07-17 15:33:00+03	47100.00
C4CC98	2017-07-14 18:13:00+03	33100.00
C4CCD5	2017-08-07 18:10:00+03	10800.00
C4CD09	2017-07-04 16:19:00+03	73300.00
C4CD44	2017-08-12 02:23:00+03	36400.00
C4CD80	2017-07-21 18:49:00+03	53300.00
C4CDCC	2017-07-18 04:29:00+03	13400.00
C4CDFD	2017-07-02 13:12:00+03	32800.00
C4CE17	2017-07-25 20:59:00+03	30200.00
C4CE33	2017-07-06 16:37:00+03	26700.00
C4CEBE	2017-07-12 03:56:00+03	79600.00
C4CED4	2017-08-01 12:28:00+03	28000.00
C4CEEA	2017-08-15 12:51:00+03	37100.00
C4CEEC	2017-08-08 23:10:00+03	40300.00
C4CF0C	2017-08-10 23:09:00+03	26200.00
C4CF2C	2017-08-01 04:00:00+03	46300.00
C4CF48	2017-07-17 11:50:00+03	58600.00
C4D02F	2017-08-09 08:35:00+03	56000.00
C4D176	2017-07-11 04:21:00+03	27800.00
C4D185	2017-07-15 01:45:00+03	52000.00
C4D187	2017-07-25 18:10:00+03	69500.00
C4D1C6	2017-08-01 13:23:00+03	28300.00
C4D25F	2017-07-14 07:22:00+03	28600.00
C4D2BA	2017-07-30 21:47:00+03	24400.00
C4D366	2017-06-30 23:02:00+03	15000.00
C4D369	2017-07-19 07:00:00+03	23200.00
C4D391	2017-06-27 19:19:00+03	132700.00
C4D3E9	2017-07-29 05:22:00+03	135400.00
C4D3F2	2017-08-03 04:01:00+03	23200.00
C4D400	2017-08-11 21:46:00+03	46500.00
C4D460	2017-08-04 09:08:00+03	26800.00
C4D4A9	2017-07-29 12:50:00+03	184000.00
C4D691	2017-07-11 07:05:00+03	24800.00
C4D6EC	2017-07-31 11:19:00+03	27200.00
C4D78A	2017-08-11 10:58:00+03	56000.00
C4D7AC	2017-07-11 19:44:00+03	31600.00
C4D8B6	2017-07-24 21:44:00+03	336100.00
C4D92C	2017-07-22 07:54:00+03	100000.00
C4D939	2017-07-20 09:35:00+03	23200.00
C4D9C6	2017-07-27 05:38:00+03	57400.00
C4D9C7	2017-07-14 09:09:00+03	13400.00
C4D9D8	2017-07-06 05:31:00+03	185000.00
C4D9FA	2017-08-15 00:04:00+03	75600.00
C4DA16	2017-08-03 04:18:00+03	23200.00
C4DA35	2017-06-30 10:46:00+03	12600.00
C4DA56	2017-08-10 05:27:00+03	51200.00
C4DA79	2017-08-06 10:15:00+03	91800.00
C4DAB6	2017-08-14 05:51:00+03	85700.00
C4DAD8	2017-08-02 09:24:00+03	51900.00
C4DAE3	2017-08-11 10:50:00+03	29600.00
C4DAF7	2017-07-16 02:25:00+03	19800.00
C4DB58	2017-07-07 21:26:00+03	112600.00
C4DB78	2017-07-02 14:04:00+03	56600.00
C4DBA4	2017-08-07 17:29:00+03	231900.00
C4DC2A	2017-07-26 06:54:00+03	100600.00
C4DC2E	2017-08-02 20:44:00+03	14800.00
C4DCAA	2017-07-05 19:33:00+03	56000.00
C4DCBE	2017-07-05 08:58:00+03	85500.00
C4DD82	2017-07-24 06:22:00+03	135400.00
C4DE19	2017-08-13 07:49:00+03	56000.00
C4DE4D	2017-07-09 14:55:00+03	75300.00
C4DE8B	2017-08-14 01:50:00+03	33600.00
C4DEA8	2017-08-02 06:57:00+03	20000.00
C4DEC1	2017-07-12 10:36:00+03	109400.00
C4DEE3	2017-08-07 18:24:00+03	544700.00
C4DEF5	2017-07-05 17:24:00+03	92700.00
C4DF1E	2017-06-28 00:58:00+03	6600.00
C4DF4A	2017-07-07 18:15:00+03	92800.00
C4DF8A	2017-07-16 09:38:00+03	8000.00
C4DFC7	2017-08-10 14:21:00+03	29600.00
C4DFF6	2017-08-06 20:31:00+03	28000.00
C4E02B	2017-08-11 17:48:00+03	60100.00
C4E053	2017-07-18 17:07:00+03	51600.00
C4E05B	2017-07-17 17:54:00+03	40000.00
C4E090	2017-07-23 04:56:00+03	137900.00
C4E0E0	2017-07-02 21:39:00+03	820000.00
C4E0E6	2017-08-13 09:20:00+03	30200.00
C4E0FF	2017-08-12 11:01:00+03	38300.00
C4E10F	2017-08-04 03:09:00+03	17200.00
C4E155	2017-07-09 16:59:00+03	133200.00
C4E166	2017-07-25 00:28:00+03	11600.00
C4E18C	2017-07-08 01:51:00+03	25400.00
C4E1C9	2017-07-23 01:56:00+03	37900.00
C4E1CF	2017-08-14 06:49:00+03	56600.00
C4E28A	2017-08-14 15:24:00+03	68800.00
C4E2A5	2017-08-10 19:53:00+03	75300.00
C4E445	2017-07-26 05:08:00+03	20100.00
C4E448	2017-08-11 21:33:00+03	14000.00
C4E4FB	2017-08-10 17:45:00+03	149200.00
C4E521	2017-07-05 00:02:00+03	32800.00
C4E53C	2017-08-03 03:08:00+03	6700.00
C4E598	2017-08-10 03:42:00+03	56100.00
C4E5BA	2017-07-24 02:23:00+03	11600.00
C4E5CE	2017-07-18 17:34:00+03	4000.00
C4E75F	2017-07-08 02:05:00+03	195600.00
C4E777	2017-08-05 10:26:00+03	28000.00
C4E79B	2017-07-05 07:39:00+03	6900.00
C4E7C6	2017-08-07 23:40:00+03	117200.00
C4E7DD	2017-07-27 10:13:00+03	27300.00
C4E81A	2017-07-31 03:12:00+03	62900.00
C4E83E	2017-07-23 08:13:00+03	43600.00
C4E896	2017-07-09 11:50:00+03	62900.00
C4E8B6	2017-08-11 08:33:00+03	51900.00
C4E92A	2017-07-13 09:29:00+03	248400.00
C4E971	2017-07-07 12:57:00+03	119300.00
C4E9D0	2017-08-10 07:57:00+03	131800.00
C4E9F3	2017-07-23 16:53:00+03	12400.00
C4E9F7	2017-07-11 08:27:00+03	40200.00
C4EA3F	2017-07-20 15:03:00+03	21400.00
C4EA72	2017-07-16 23:52:00+03	99700.00
C4EA9B	2017-07-06 20:57:00+03	62600.00
C4EAD1	2017-07-02 20:31:00+03	14000.00
C4EB0D	2017-07-09 20:03:00+03	106800.00
C4EB9D	2017-07-23 04:03:00+03	84100.00
C4EBB5	2017-08-04 16:03:00+03	148200.00
C4EBFB	2017-08-12 07:16:00+03	20200.00
C4EC13	2017-07-26 23:28:00+03	157100.00
C4ECB8	2017-07-13 11:38:00+03	123900.00
C4ECDE	2017-07-18 09:36:00+03	167500.00
C4ECF7	2017-08-04 05:15:00+03	135400.00
C4ED08	2017-07-20 20:45:00+03	27200.00
C4ED23	2017-08-09 15:30:00+03	88100.00
C4ED7C	2017-08-08 21:35:00+03	46400.00
C4EE00	2017-07-25 19:00:00+03	92000.00
C4EE3B	2017-07-19 02:08:00+03	13600.00
C4EE55	2017-07-07 11:48:00+03	40100.00
C4EECB	2017-06-28 11:54:00+03	57600.00
C4EF2D	2017-07-01 15:19:00+03	243600.00
C4EF69	2017-08-10 04:00:00+03	92800.00
C4EF85	2017-07-11 16:26:00+03	56000.00
C4EF9F	2017-07-21 12:48:00+03	160200.00
C4EFA1	2017-07-18 05:22:00+03	118000.00
C4EFD4	2017-07-24 11:38:00+03	58400.00
C4EFDA	2017-07-24 14:51:00+03	40000.00
C4F002	2017-07-29 21:02:00+03	66600.00
C4F062	2017-07-15 10:19:00+03	26000.00
C4F082	2017-07-09 11:41:00+03	86500.00
C4F0BA	2017-07-08 13:58:00+03	27200.00
C4F1C8	2017-07-22 09:41:00+03	64700.00
C4F254	2017-07-01 12:56:00+03	14400.00
C4F2A3	2017-08-08 05:18:00+03	114800.00
C4F2DC	2017-07-11 02:17:00+03	62100.00
C4F328	2017-07-31 10:30:00+03	113200.00
C4F357	2017-07-07 10:05:00+03	105400.00
C4F35D	2017-07-20 07:31:00+03	59800.00
C4F35F	2017-07-13 23:17:00+03	112000.00
C4F43A	2017-07-27 05:42:00+03	69500.00
C4F466	2017-07-26 01:52:00+03	54000.00
C4F46C	2017-08-03 11:11:00+03	31600.00
C4F4EC	2017-08-03 13:14:00+03	25600.00
C4F510	2017-08-08 12:24:00+03	56900.00
C4F52A	2017-08-11 21:50:00+03	144400.00
C4F53B	2017-07-05 01:21:00+03	11000.00
C4F542	2017-07-08 00:56:00+03	49100.00
C4F5BF	2017-07-24 17:28:00+03	172600.00
C4F65D	2017-08-13 17:49:00+03	43200.00
C4F672	2017-07-05 20:34:00+03	60000.00
C4F6D3	2017-07-11 20:33:00+03	87400.00
C4F765	2017-07-28 09:17:00+03	35200.00
C4F777	2017-07-08 23:36:00+03	257500.00
C4F881	2017-07-06 08:40:00+03	77500.00
C4F8F2	2017-07-22 10:53:00+03	86800.00
C4F92C	2017-07-02 14:02:00+03	47700.00
C4F93F	2017-08-02 15:35:00+03	8200.00
C4F96D	2017-08-09 11:30:00+03	14000.00
C4F9B0	2017-08-11 03:16:00+03	49700.00
C4F9C1	2017-07-12 02:42:00+03	117800.00
C4F9E8	2017-07-04 09:09:00+03	34000.00
C4FA01	2017-07-14 01:55:00+03	86300.00
C4FA0A	2017-08-08 10:53:00+03	54800.00
C4FABC	2017-08-07 10:08:00+03	36200.00
C4FBBD	2017-07-31 11:02:00+03	67200.00
C4FBEC	2017-08-03 12:58:00+03	116000.00
C4FBF6	2017-07-28 06:31:00+03	21800.00
C4FC7D	2017-07-08 18:39:00+03	65400.00
C4FCBE	2017-07-27 11:37:00+03	147200.00
C4FD02	2017-08-03 21:29:00+03	46000.00
C4FD5C	2017-07-06 13:50:00+03	26800.00
C4FE25	2017-07-19 01:12:00+03	51800.00
C4FE52	2017-07-29 00:59:00+03	56000.00
C4FE7A	2017-08-05 03:38:00+03	137600.00
C4FEAF	2017-08-08 10:48:00+03	108000.00
C4FED7	2017-07-26 22:01:00+03	45200.00
C4FF1E	2017-08-11 20:15:00+03	7400.00
C4FF40	2017-07-20 08:34:00+03	42000.00
C4FFB8	2017-07-07 13:40:00+03	101500.00
C4FFEC	2017-07-10 20:13:00+03	47200.00
C50042	2017-07-26 12:54:00+03	186900.00
C50063	2017-08-02 08:27:00+03	8000.00
C5008F	2017-07-19 17:57:00+03	21600.00
C50094	2017-08-07 08:07:00+03	32800.00
C5009A	2017-07-17 10:28:00+03	55600.00
C500CA	2017-07-20 06:11:00+03	28000.00
C50181	2017-07-16 20:58:00+03	136200.00
C501CE	2017-08-06 17:07:00+03	55800.00
C501E1	2017-08-11 17:32:00+03	56000.00
C5020A	2017-07-13 13:11:00+03	45200.00
C50229	2017-08-02 21:34:00+03	38600.00
C50258	2017-08-12 11:58:00+03	67100.00
C5029E	2017-08-13 20:30:00+03	95600.00
C50458	2017-07-14 06:28:00+03	7400.00
C504AC	2017-07-18 13:42:00+03	71900.00
C50506	2017-07-06 01:58:00+03	83000.00
C5053C	2017-07-15 07:32:00+03	129200.00
C50546	2017-07-16 05:24:00+03	167400.00
C5054C	2017-07-05 23:09:00+03	47000.00
C5055A	2017-07-03 00:57:00+03	13000.00
C505CF	2017-08-07 18:44:00+03	185600.00
C505FC	2017-08-13 20:45:00+03	154700.00
C50653	2017-08-10 06:50:00+03	94000.00
C50656	2017-07-15 21:20:00+03	56000.00
C5066B	2017-07-23 04:03:00+03	100600.00
C506B3	2017-08-02 11:05:00+03	46000.00
C506CD	2017-07-14 01:19:00+03	6300.00
C507B4	2017-08-13 16:34:00+03	75600.00
C507DF	2017-08-13 07:42:00+03	92800.00
C507E3	2017-07-23 13:09:00+03	46400.00
C50807	2017-08-06 14:11:00+03	385000.00
C5080C	2017-08-14 05:12:00+03	19800.00
C50814	2017-07-25 15:34:00+03	6000.00
C50823	2017-07-09 02:19:00+03	31700.00
C50828	2017-07-02 23:49:00+03	25400.00
C50864	2017-08-05 11:14:00+03	19800.00
C5086A	2017-07-06 20:16:00+03	180300.00
C5086E	2017-07-27 01:04:00+03	55800.00
C508CC	2017-07-24 00:07:00+03	70800.00
C508FF	2017-08-02 04:57:00+03	27200.00
C5092C	2017-07-11 22:47:00+03	54400.00
C5096F	2017-07-08 17:42:00+03	27200.00
C509C7	2017-08-14 00:57:00+03	140100.00
C509F4	2017-07-16 05:46:00+03	22000.00
C50A2B	2017-07-14 13:26:00+03	26700.00
C50A85	2017-07-04 00:10:00+03	10700.00
C50AA3	2017-08-07 23:12:00+03	96300.00
C50ACF	2017-07-27 20:06:00+03	12600.00
C50ADD	2017-07-12 02:12:00+03	45200.00
C50AE1	2017-07-11 15:45:00+03	23200.00
C50B46	2017-08-15 06:35:00+03	27800.00
C50B63	2017-07-19 13:01:00+03	23400.00
C50BC2	2017-07-16 12:26:00+03	45100.00
C50BC8	2017-08-06 12:25:00+03	81700.00
C50BD2	2017-07-11 22:57:00+03	153300.00
C50BED	2017-08-13 20:57:00+03	87800.00
C50C0A	2017-07-24 23:19:00+03	85000.00
C50C14	2017-08-06 00:04:00+03	70400.00
C50C70	2017-07-12 22:15:00+03	49500.00
C50CAD	2017-07-08 14:16:00+03	57600.00
C50D55	2017-08-04 01:55:00+03	182000.00
C50D6E	2017-07-04 01:01:00+03	38000.00
C50D70	2017-07-15 22:39:00+03	28000.00
C50E95	2017-08-08 23:37:00+03	96500.00
C50EAC	2017-08-10 12:43:00+03	66600.00
C50EBB	2017-08-14 06:12:00+03	100600.00
C50F0E	2017-08-11 01:19:00+03	19500.00
C50F40	2017-07-20 21:50:00+03	69000.00
C50F7F	2017-06-30 02:22:00+03	229000.00
C50FC8	2017-08-10 13:03:00+03	37200.00
C50FD1	2017-08-08 03:11:00+03	54300.00
C51074	2017-08-15 10:31:00+03	163200.00
C51093	2017-08-14 20:25:00+03	133200.00
C510D6	2017-08-14 16:18:00+03	98300.00
C510D7	2017-07-09 03:06:00+03	98400.00
C51110	2017-08-01 12:04:00+03	67700.00
C51173	2017-07-29 20:57:00+03	21800.00
C511A9	2017-07-06 16:24:00+03	27900.00
C511CB	2017-07-25 02:43:00+03	13600.00
C51216	2017-07-27 20:59:00+03	66700.00
C51298	2017-07-16 07:57:00+03	39300.00
C512EF	2017-08-04 08:31:00+03	44500.00
C512F2	2017-08-08 20:42:00+03	118100.00
C51301	2017-07-23 03:34:00+03	281500.00
C513DB	2017-07-30 23:26:00+03	28000.00
C51420	2017-06-27 14:07:00+03	67700.00
C5148A	2017-07-16 11:42:00+03	111900.00
C514E2	2017-08-02 06:10:00+03	28000.00
C51528	2017-08-08 19:28:00+03	44800.00
C51546	2017-07-04 03:25:00+03	274300.00
C51588	2017-07-31 12:12:00+03	353600.00
C515CC	2017-08-05 20:46:00+03	66000.00
C51700	2017-08-02 21:40:00+03	422900.00
C51738	2017-07-30 15:33:00+03	6700.00
C51765	2017-08-11 00:35:00+03	64000.00
C5178B	2017-08-04 14:24:00+03	146600.00
C5179A	2017-08-04 16:01:00+03	88600.00
C517A4	2017-07-20 22:27:00+03	30800.00
C517D0	2017-07-07 00:06:00+03	119400.00
C5185E	2017-08-12 02:43:00+03	87200.00
C5189E	2017-07-25 07:33:00+03	65800.00
C518D8	2017-07-16 17:10:00+03	117700.00
C51924	2017-07-01 02:46:00+03	56000.00
C51942	2017-07-31 19:25:00+03	89600.00
C519C1	2017-07-14 02:03:00+03	178800.00
C519D7	2017-07-06 08:54:00+03	173400.00
C51A1F	2017-08-15 12:58:00+03	21600.00
C51A56	2017-08-12 16:53:00+03	354900.00
C51A6D	2017-07-08 19:46:00+03	23200.00
C51AF3	2017-07-05 00:12:00+03	18600.00
C51B0B	2017-07-18 12:06:00+03	75600.00
C51B6C	2017-07-11 10:04:00+03	61200.00
C51B9C	2017-07-04 01:39:00+03	23600.00
C51CA2	2017-08-02 08:40:00+03	42800.00
C51D05	2017-08-12 08:54:00+03	187600.00
C51D14	2017-08-09 21:18:00+03	60400.00
C51D9B	2017-08-06 07:03:00+03	124200.00
C51DB1	2017-07-27 15:58:00+03	325800.00
C51E00	2017-07-04 01:33:00+03	48700.00
C51E10	2017-07-15 21:09:00+03	33100.00
C51E2C	2017-07-17 19:51:00+03	29100.00
C51E31	2017-07-19 00:21:00+03	64100.00
C51E49	2017-07-06 23:24:00+03	135600.00
C51E73	2017-07-24 15:36:00+03	24400.00
C51EBF	2017-06-25 02:25:00+03	68800.00
C51F61	2017-08-14 10:10:00+03	27900.00
C51FDC	2017-07-01 12:57:00+03	8400.00
C52092	2017-07-31 17:21:00+03	54000.00
C520B2	2017-07-01 11:59:00+03	49200.00
C520F6	2017-08-15 00:27:00+03	35500.00
C52139	2017-08-11 15:00:00+03	103800.00
C52164	2017-07-14 19:46:00+03	167400.00
C5216C	2017-07-25 11:47:00+03	28000.00
C521A6	2017-07-10 17:22:00+03	37200.00
C52227	2017-07-20 10:07:00+03	44800.00
C52265	2017-08-12 15:43:00+03	22000.00
C522C2	2017-07-09 15:49:00+03	12400.00
C522F4	2017-08-05 23:22:00+03	240600.00
C523BC	2017-07-29 00:54:00+03	85000.00
C523E5	2017-08-07 04:34:00+03	54800.00
C5247D	2017-07-22 17:25:00+03	56000.00
C524B4	2017-07-03 17:09:00+03	114700.00
C524FA	2017-07-31 07:09:00+03	119700.00
C5251B	2017-07-16 08:01:00+03	66000.00
C525CE	2017-07-30 19:10:00+03	13200.00
C5261C	2017-07-24 14:06:00+03	60200.00
C5262F	2017-08-09 00:57:00+03	87900.00
C52650	2017-08-11 19:30:00+03	55800.00
C52720	2017-07-12 04:48:00+03	28000.00
C5276C	2017-08-02 20:43:00+03	19600.00
C5277F	2017-07-14 10:47:00+03	176100.00
C52783	2017-06-29 05:13:00+03	64600.00
C52784	2017-07-10 21:48:00+03	46400.00
C527D0	2017-07-09 16:01:00+03	64500.00
C527DE	2017-07-26 20:21:00+03	25600.00
C52837	2017-07-21 16:36:00+03	59800.00
C5283F	2017-07-16 06:04:00+03	41100.00
C528B7	2017-08-11 21:41:00+03	39800.00
C528CD	2017-08-01 21:08:00+03	167400.00
C52904	2017-08-15 15:13:00+03	14000.00
C52913	2017-08-09 01:05:00+03	136800.00
C52968	2017-06-30 04:18:00+03	55800.00
C52982	2017-07-11 07:13:00+03	135600.00
C529BE	2017-07-18 12:45:00+03	381400.00
C52A71	2017-07-20 16:46:00+03	297600.00
C52A7E	2017-07-14 17:50:00+03	39600.00
C52AFF	2017-06-27 23:54:00+03	24600.00
C52B04	2017-07-20 19:12:00+03	56000.00
C52B3E	2017-08-10 15:37:00+03	37900.00
C52B44	2017-07-08 04:24:00+03	26700.00
C52B9B	2017-08-01 01:57:00+03	33500.00
C52B9F	2017-08-08 13:33:00+03	37200.00
C52BCC	2017-08-03 06:48:00+03	8400.00
C52BD2	2017-07-17 01:04:00+03	16400.00
C52C07	2017-07-20 12:02:00+03	27300.00
C52C31	2017-08-11 22:17:00+03	167400.00
C52D2E	2017-08-07 11:36:00+03	46200.00
C52E41	2017-07-26 15:18:00+03	136600.00
C52E43	2017-07-20 05:51:00+03	66600.00
C52EB3	2017-07-07 00:50:00+03	189200.00
C52F7B	2017-07-04 04:20:00+03	40800.00
C52FAE	2017-07-08 06:49:00+03	68400.00
C52FB0	2017-08-02 16:48:00+03	23400.00
C52FBD	2017-08-07 20:19:00+03	48800.00
C5302F	2017-07-21 05:36:00+03	30700.00
C5305F	2017-07-21 09:04:00+03	38000.00
C53087	2017-07-31 21:16:00+03	187600.00
C530C9	2017-07-01 18:02:00+03	113200.00
C530F4	2017-07-08 09:38:00+03	6000.00
C53115	2017-06-29 11:17:00+03	49100.00
C53129	2017-07-13 15:55:00+03	46000.00
C5314E	2017-08-06 12:55:00+03	27200.00
C5316E	2017-06-30 12:37:00+03	67200.00
C53182	2017-07-22 05:06:00+03	26300.00
C531AF	2017-07-04 01:47:00+03	137700.00
C531C2	2017-07-16 11:26:00+03	74400.00
C531F3	2017-07-29 21:04:00+03	47000.00
C5321D	2017-07-17 02:18:00+03	24400.00
C532AB	2017-07-09 22:44:00+03	155600.00
C532E6	2017-08-07 07:14:00+03	109300.00
C532FB	2017-07-13 05:56:00+03	49200.00
C53303	2017-07-01 00:52:00+03	57700.00
C5330C	2017-07-19 21:34:00+03	166100.00
C533C1	2017-08-08 12:51:00+03	95900.00
C533F9	2017-07-13 05:01:00+03	16400.00
C53405	2017-08-05 23:14:00+03	26000.00
C5346F	2017-08-11 23:35:00+03	18300.00
C534ED	2017-08-07 04:34:00+03	32800.00
C5356A	2017-08-09 21:33:00+03	56000.00
C535C5	2017-08-06 09:58:00+03	68100.00
C535F1	2017-08-12 21:31:00+03	48800.00
C5360B	2017-07-23 22:34:00+03	68900.00
C536BB	2017-07-23 09:19:00+03	89700.00
C5376B	2017-07-27 07:02:00+03	20500.00
C5389E	2017-08-14 18:08:00+03	204500.00
C538C7	2017-08-09 15:53:00+03	94000.00
C53932	2017-08-03 17:10:00+03	46400.00
C539AB	2017-08-10 00:28:00+03	12600.00
C539AC	2017-08-07 22:47:00+03	86600.00
C539F9	2017-07-14 11:46:00+03	39500.00
C53A46	2017-07-10 23:24:00+03	14000.00
C53A47	2017-07-17 07:09:00+03	13000.00
C53A55	2017-08-02 00:56:00+03	13600.00
C53A7D	2017-07-11 19:01:00+03	114800.00
C53AA1	2017-07-26 09:57:00+03	55800.00
C53AFB	2017-08-11 06:19:00+03	356700.00
C53B5E	2017-07-06 21:51:00+03	58600.00
C53C19	2017-07-03 21:54:00+03	25900.00
C53C3B	2017-07-03 02:59:00+03	32800.00
C53C76	2017-08-05 01:50:00+03	26000.00
C53CEB	2017-07-17 08:55:00+03	10700.00
C53DB6	2017-08-12 10:28:00+03	73800.00
C53E65	2017-07-23 08:11:00+03	48500.00
C53E74	2017-08-12 00:53:00+03	13600.00
C53EC9	2017-07-31 11:21:00+03	23600.00
C53EF8	2017-07-19 01:43:00+03	123600.00
C53F32	2017-07-13 23:35:00+03	66600.00
C53F5F	2017-08-12 00:56:00+03	95600.00
C53FA5	2017-07-16 00:06:00+03	16400.00
C5401F	2017-08-12 02:44:00+03	198800.00
C54087	2017-07-12 23:19:00+03	47000.00
C540A9	2017-07-09 08:41:00+03	210600.00
C540D5	2017-07-09 07:28:00+03	114700.00
C540DC	2017-07-16 20:34:00+03	38600.00
C540E8	2017-07-21 03:15:00+03	81300.00
C540F1	2017-08-02 16:55:00+03	21800.00
C54102	2017-07-26 13:58:00+03	28800.00
C541FF	2017-07-26 03:49:00+03	131100.00
C54201	2017-07-31 19:58:00+03	142200.00
C54224	2017-07-12 19:15:00+03	119600.00
C54267	2017-07-06 17:23:00+03	34000.00
C54293	2017-07-06 18:38:00+03	37200.00
C5436C	2017-07-29 14:32:00+03	93900.00
C54399	2017-07-26 05:53:00+03	175300.00
C543F0	2017-08-14 04:16:00+03	54400.00
C5442B	2017-07-14 03:23:00+03	143800.00
C54435	2017-07-21 05:24:00+03	86400.00
C54489	2017-08-07 09:59:00+03	40000.00
C5448C	2017-07-10 13:37:00+03	78300.00
C5449D	2017-07-09 17:08:00+03	123000.00
C544B2	2017-07-26 17:53:00+03	9800.00
C544CE	2017-07-06 00:22:00+03	49200.00
C544DB	2017-07-23 23:19:00+03	116000.00
C545B5	2017-07-19 14:41:00+03	133700.00
C545E5	2017-08-12 15:12:00+03	44000.00
C5460F	2017-07-22 00:06:00+03	56900.00
C546B7	2017-07-23 12:54:00+03	65900.00
C54727	2017-08-09 20:53:00+03	68000.00
C5474A	2017-08-04 23:28:00+03	240600.00
C54768	2017-07-27 13:10:00+03	151200.00
C54782	2017-07-08 08:21:00+03	58200.00
C547B4	2017-07-06 01:14:00+03	16400.00
C5480E	2017-07-13 15:23:00+03	15400.00
C5483B	2017-07-04 03:58:00+03	29600.00
C54844	2017-08-11 02:38:00+03	96800.00
C54845	2017-08-08 01:09:00+03	23600.00
C54851	2017-08-15 09:09:00+03	94800.00
C54861	2017-07-21 08:30:00+03	34000.00
C5486E	2017-08-08 05:51:00+03	14000.00
C548E8	2017-07-01 03:59:00+03	286900.00
C548EC	2017-07-26 22:55:00+03	81200.00
C548F1	2017-07-28 11:35:00+03	59800.00
C54901	2017-07-18 09:10:00+03	248300.00
C54949	2017-07-25 13:45:00+03	177200.00
C54976	2017-07-30 00:34:00+03	25400.00
C5497E	2017-08-06 08:18:00+03	94900.00
C54999	2017-07-15 13:31:00+03	36200.00
C54A56	2017-07-23 13:42:00+03	13800.00
C54AB7	2017-08-02 20:16:00+03	24400.00
C54AF8	2017-07-12 22:32:00+03	398500.00
C54B0A	2017-07-04 18:06:00+03	38800.00
C54B30	2017-07-06 01:59:00+03	66200.00
C54C04	2017-07-06 12:52:00+03	42400.00
C54CA1	2017-08-08 21:17:00+03	31400.00
C54E67	2017-07-06 18:57:00+03	87900.00
C54ED3	2017-07-10 03:11:00+03	31600.00
C54F30	2017-07-23 13:50:00+03	64600.00
C54F58	2017-07-25 12:25:00+03	75900.00
C54F70	2017-08-12 04:29:00+03	64700.00
C54FFC	2017-08-09 11:51:00+03	38200.00
C5501B	2017-07-16 23:08:00+03	95900.00
C550BE	2017-08-05 01:39:00+03	117400.00
C55140	2017-07-23 01:42:00+03	149900.00
C55162	2017-07-15 05:27:00+03	111600.00
C5517D	2017-08-15 11:33:00+03	6700.00
C551C1	2017-07-01 22:11:00+03	37700.00
C551D9	2017-06-30 03:51:00+03	55800.00
C5524E	2017-07-08 06:50:00+03	109800.00
C552B3	2017-07-31 18:20:00+03	107800.00
C552DB	2017-08-06 17:35:00+03	112600.00
C552F4	2017-07-05 16:30:00+03	83000.00
C55330	2017-07-26 14:53:00+03	28000.00
C55331	2017-08-11 11:47:00+03	101500.00
C5533E	2017-08-12 08:20:00+03	101200.00
C5536A	2017-07-17 02:50:00+03	266400.00
C5536D	2017-07-19 16:22:00+03	73600.00
C5538E	2017-08-12 04:17:00+03	12600.00
C55395	2017-08-11 01:56:00+03	43200.00
C553D7	2017-07-23 05:28:00+03	28000.00
C553E1	2017-07-27 00:10:00+03	67100.00
C554BD	2017-07-07 08:42:00+03	41400.00
C554DE	2017-07-22 01:57:00+03	88500.00
C554EF	2017-08-08 05:29:00+03	63900.00
C554F4	2017-07-31 16:04:00+03	135400.00
C55508	2017-07-18 17:12:00+03	28800.00
C55555	2017-07-04 11:39:00+03	168000.00
C55577	2017-07-14 14:07:00+03	55800.00
C5558B	2017-08-11 06:30:00+03	8400.00
C555D5	2017-07-23 20:57:00+03	16400.00
C555EA	2017-07-24 22:48:00+03	109800.00
C555F7	2017-07-04 17:28:00+03	55800.00
C55623	2017-07-18 09:17:00+03	47000.00
C55631	2017-08-08 19:34:00+03	6000.00
C55640	2017-08-11 20:26:00+03	111600.00
C556C5	2017-08-04 06:41:00+03	28000.00
C556EE	2017-07-04 07:26:00+03	89200.00
C55786	2017-08-06 19:41:00+03	46800.00
C557D7	2017-07-08 04:37:00+03	13600.00
C557F3	2017-08-12 05:24:00+03	13400.00
C55811	2017-07-02 21:53:00+03	44000.00
C5586C	2017-07-06 02:40:00+03	62000.00
C558B9	2017-07-10 19:14:00+03	54100.00
C558BB	2017-07-27 01:57:00+03	85000.00
C558C2	2017-07-25 16:33:00+03	23100.00
C5592D	2017-08-05 04:06:00+03	184300.00
C55933	2017-07-17 05:33:00+03	111600.00
C5596C	2017-08-07 09:29:00+03	135000.00
C55999	2017-08-15 11:14:00+03	10800.00
C55A60	2017-07-03 05:06:00+03	28800.00
C55AFB	2017-07-19 06:42:00+03	21400.00
C55B87	2017-07-17 06:33:00+03	67100.00
C55BB0	2017-08-07 07:27:00+03	94000.00
C55BCD	2017-07-27 15:43:00+03	36000.00
C55BFA	2017-07-26 18:28:00+03	44000.00
C55BFB	2017-08-13 15:37:00+03	46400.00
C55C29	2017-08-11 02:06:00+03	111600.00
C55C32	2017-08-09 12:06:00+03	44000.00
C55C40	2017-07-21 21:07:00+03	44800.00
C55C58	2017-07-04 18:41:00+03	116800.00
C55C9E	2017-07-21 10:24:00+03	25400.00
C55D22	2017-06-26 00:39:00+03	32400.00
C55E27	2017-07-30 17:05:00+03	54000.00
C55E89	2017-07-14 03:10:00+03	258400.00
C55EA5	2017-07-03 06:07:00+03	23200.00
C55EC5	2017-07-17 03:51:00+03	136300.00
C55EEF	2017-07-25 22:41:00+03	24700.00
C55F90	2017-08-01 00:30:00+03	6000.00
C55FCA	2017-07-16 23:58:00+03	46400.00
C55FCF	2017-08-04 10:23:00+03	55800.00
C55FD2	2017-07-11 16:57:00+03	406100.00
C56076	2017-07-14 21:56:00+03	57400.00
C56090	2017-07-27 12:51:00+03	46200.00
C560F0	2017-07-27 08:00:00+03	131000.00
C5611B	2017-07-16 22:00:00+03	224000.00
C5612A	2017-07-26 00:18:00+03	64700.00
C56183	2017-07-09 03:07:00+03	58900.00
C561C3	2017-07-29 08:54:00+03	48400.00
C56212	2017-07-03 11:31:00+03	174600.00
C56284	2017-08-10 09:45:00+03	28800.00
C56292	2017-07-18 10:36:00+03	68400.00
C562A5	2017-06-29 05:29:00+03	131100.00
C5637D	2017-07-26 11:41:00+03	22600.00
C563A0	2017-07-19 10:53:00+03	64700.00
C563B8	2017-07-13 07:25:00+03	72300.00
C563D6	2017-07-01 22:20:00+03	184500.00
C563E0	2017-08-12 13:12:00+03	32800.00
C563F3	2017-08-11 04:57:00+03	38600.00
C563F5	2017-08-03 11:31:00+03	110500.00
C56434	2017-08-10 05:28:00+03	63700.00
C5643B	2017-07-21 00:33:00+03	273400.00
C56458	2017-07-21 17:09:00+03	6700.00
C56464	2017-07-27 19:38:00+03	135200.00
C5649D	2017-08-14 09:05:00+03	32700.00
C564B1	2017-08-06 18:32:00+03	37900.00
C5651F	2017-07-03 20:42:00+03	75000.00
C56594	2017-08-14 23:10:00+03	75700.00
C565F6	2017-06-30 21:18:00+03	44000.00
C565FC	2017-08-02 11:10:00+03	186900.00
C5663C	2017-08-11 01:09:00+03	67600.00
C566CA	2017-07-17 08:33:00+03	26000.00
C566EA	2017-07-09 08:29:00+03	54200.00
C566F0	2017-06-30 15:49:00+03	26000.00
C566F5	2017-07-17 22:01:00+03	32400.00
C567F0	2017-07-19 00:10:00+03	46400.00
C567F5	2017-07-15 11:23:00+03	96200.00
C567F7	2017-07-09 08:06:00+03	48800.00
C567FF	2017-07-26 00:17:00+03	7400.00
C56819	2017-08-04 16:44:00+03	28800.00
C56857	2017-08-04 07:44:00+03	119600.00
C568A0	2017-08-07 04:24:00+03	7400.00
C568A1	2017-07-23 07:27:00+03	17800.00
C568C6	2017-08-09 07:40:00+03	95200.00
C56983	2017-06-29 12:43:00+03	32200.00
C569C7	2017-07-08 21:16:00+03	40400.00
C569ED	2017-07-28 16:34:00+03	43500.00
C56A25	2017-07-08 13:17:00+03	132800.00
C56A27	2017-07-09 05:34:00+03	18600.00
C56B27	2017-07-27 17:44:00+03	40600.00
C56B5A	2017-07-30 05:22:00+03	32200.00
C56B60	2017-07-20 00:20:00+03	73500.00
C56B78	2017-07-29 02:55:00+03	18000.00
C56C31	2017-08-04 21:24:00+03	64300.00
C56C56	2017-07-05 07:24:00+03	67700.00
C56C96	2017-07-24 12:57:00+03	27200.00
C56CCF	2017-07-13 04:12:00+03	52000.00
C56D0B	2017-08-03 22:05:00+03	39500.00
C56D18	2017-08-07 06:41:00+03	57600.00
C56D27	2017-08-09 04:00:00+03	12400.00
C56D30	2017-08-05 03:04:00+03	84900.00
C56DAD	2017-08-04 00:53:00+03	93500.00
C56DBF	2017-08-08 12:48:00+03	24700.00
C56E49	2017-08-07 00:39:00+03	155600.00
C56F65	2017-07-23 08:46:00+03	38600.00
C57009	2017-07-08 00:57:00+03	23200.00
C57024	2017-08-10 11:49:00+03	73600.00
C57025	2017-08-03 01:23:00+03	28000.00
C57051	2017-07-26 23:47:00+03	40800.00
C5705A	2017-08-07 12:03:00+03	38800.00
C57085	2017-07-27 20:11:00+03	42700.00
C570C3	2017-07-11 22:36:00+03	81700.00
C570E3	2017-08-10 01:25:00+03	14800.00
C5714C	2017-07-17 03:50:00+03	217900.00
C5721D	2017-08-15 04:44:00+03	27900.00
C57231	2017-08-07 13:42:00+03	66300.00
C5728F	2017-08-05 16:30:00+03	85000.00
C572F7	2017-07-27 00:46:00+03	40600.00
C5731C	2017-08-04 03:10:00+03	29500.00
C573D4	2017-07-10 18:48:00+03	11600.00
C573E5	2017-08-07 07:07:00+03	19600.00
C5740D	2017-07-01 03:02:00+03	76300.00
C57423	2017-08-01 19:58:00+03	58400.00
C574E6	2017-07-03 06:44:00+03	46800.00
C575A9	2017-08-05 05:00:00+03	33100.00
C575C0	2017-06-26 15:40:00+03	14400.00
C575CF	2017-07-28 22:07:00+03	56000.00
C57683	2017-08-10 04:33:00+03	48800.00
C576C1	2017-07-10 21:09:00+03	22600.00
C576CF	2017-07-19 15:12:00+03	258400.00
C576D5	2017-07-29 21:01:00+03	58400.00
C576EB	2017-07-21 14:17:00+03	86600.00
C576F8	2017-08-05 13:49:00+03	124000.00
C57737	2017-07-18 18:01:00+03	127300.00
C5780A	2017-08-03 16:29:00+03	140100.00
C57825	2017-07-16 14:21:00+03	77600.00
C57862	2017-07-15 21:38:00+03	258000.00
C578A0	2017-07-12 01:23:00+03	114900.00
C578C2	2017-07-28 03:07:00+03	18600.00
C57911	2017-07-13 19:52:00+03	65900.00
C57913	2017-07-14 07:12:00+03	49300.00
C57915	2017-07-22 12:50:00+03	29600.00
C5798A	2017-08-09 15:25:00+03	26000.00
C579BE	2017-07-05 11:51:00+03	23400.00
C579EF	2017-07-23 09:16:00+03	28000.00
C57A0E	2017-07-20 18:51:00+03	33100.00
C57A68	2017-08-05 02:29:00+03	38400.00
C57AC5	2017-07-21 19:04:00+03	69400.00
C57BF4	2017-07-14 03:29:00+03	87100.00
C57C7A	2017-07-15 23:56:00+03	55800.00
C57CC7	2017-07-26 00:25:00+03	285000.00
C57D14	2017-07-02 10:34:00+03	6800.00
C57D1C	2017-07-14 22:12:00+03	258700.00
C57E6D	2017-07-10 15:01:00+03	148000.00
C57E7C	2017-08-06 06:27:00+03	185000.00
C57E82	2017-08-02 03:03:00+03	334800.00
C57E8A	2017-08-15 12:34:00+03	37200.00
C57ECE	2017-07-19 00:12:00+03	56000.00
C57F2C	2017-08-07 18:34:00+03	29600.00
C57F59	2017-08-11 04:02:00+03	149700.00
C57F8A	2017-07-10 22:35:00+03	21400.00
C57FC6	2017-07-16 18:18:00+03	136600.00
C57FCC	2017-07-26 12:03:00+03	23100.00
C58066	2017-07-06 16:16:00+03	32800.00
C580A6	2017-07-03 14:01:00+03	76600.00
C580C5	2017-06-30 05:38:00+03	47000.00
C5815D	2017-07-09 15:23:00+03	38600.00
C5816B	2017-08-01 10:46:00+03	21600.00
C58199	2017-06-30 00:51:00+03	65900.00
C58249	2017-07-07 19:38:00+03	8200.00
C5827D	2017-08-03 16:35:00+03	27300.00
C582AD	2017-07-12 03:24:00+03	14400.00
C58316	2017-06-30 10:01:00+03	133200.00
C583C5	2017-07-29 08:50:00+03	87100.00
C584DD	2017-07-30 14:25:00+03	75600.00
C585F4	2017-06-27 16:24:00+03	136800.00
C58616	2017-07-06 03:42:00+03	85000.00
C58658	2017-08-04 10:04:00+03	68100.00
C586AE	2017-07-03 10:45:00+03	52700.00
C586D9	2017-08-02 18:14:00+03	84000.00
C586F7	2017-08-02 21:14:00+03	108900.00
C58713	2017-07-21 10:02:00+03	89600.00
C58734	2017-08-14 15:30:00+03	22400.00
C587D4	2017-07-16 10:30:00+03	131100.00
C58816	2017-07-27 23:26:00+03	56800.00
C5883D	2017-07-07 12:47:00+03	16400.00
C58847	2017-08-01 20:27:00+03	79900.00
C58885	2017-07-14 02:55:00+03	88600.00
C58A3F	2017-07-27 19:02:00+03	33800.00
C58B18	2017-07-15 18:00:00+03	75800.00
C58BAD	2017-07-27 06:32:00+03	92900.00
C58BB8	2017-07-21 22:43:00+03	112000.00
C58BBD	2017-07-16 08:57:00+03	170200.00
C58BCB	2017-08-09 08:03:00+03	398500.00
C58C2D	2017-08-11 17:01:00+03	67000.00
C58C62	2017-07-13 00:27:00+03	27800.00
C58C9B	2017-08-09 20:06:00+03	65200.00
C58CDF	2017-07-07 22:36:00+03	61800.00
C58DDC	2017-08-13 04:05:00+03	49400.00
C58DE3	2017-07-17 18:57:00+03	469400.00
C58DED	2017-07-08 05:42:00+03	23600.00
C58E31	2017-07-13 08:04:00+03	23200.00
C58E38	2017-08-09 03:05:00+03	137900.00
C58E43	2017-08-04 19:17:00+03	71800.00
C58E50	2017-08-07 05:11:00+03	265800.00
C58E76	2017-08-14 22:47:00+03	48600.00
C58EF3	2017-08-02 02:56:00+03	123200.00
C58F13	2017-07-18 22:53:00+03	64400.00
C58F21	2017-08-04 22:49:00+03	43900.00
C58F33	2017-08-02 07:47:00+03	177200.00
C58F89	2017-07-17 20:34:00+03	133200.00
C58FD6	2017-07-26 04:52:00+03	136200.00
C5906A	2017-07-27 18:28:00+03	65400.00
C590A2	2017-07-07 07:58:00+03	32800.00
C590AC	2017-07-30 10:04:00+03	22100.00
C59165	2017-07-21 19:06:00+03	75200.00
C59198	2017-07-26 17:52:00+03	19600.00
C591E9	2017-08-06 03:13:00+03	229400.00
C591FD	2017-07-09 21:18:00+03	47500.00
C59211	2017-07-08 17:42:00+03	95200.00
C59265	2017-07-20 06:57:00+03	143100.00
C5926E	2017-07-22 13:23:00+03	34600.00
C59297	2017-07-24 11:42:00+03	56000.00
C592D3	2017-07-06 01:19:00+03	23200.00
C59309	2017-07-30 09:47:00+03	166900.00
C59345	2017-07-31 07:37:00+03	46700.00
C593B3	2017-07-19 19:51:00+03	31600.00
C59464	2017-07-08 07:58:00+03	43800.00
C594AF	2017-07-10 17:29:00+03	43000.00
C59503	2017-07-25 17:02:00+03	94800.00
C59559	2017-08-15 10:36:00+03	62700.00
C59564	2017-07-21 07:36:00+03	133200.00
C59628	2017-08-08 20:37:00+03	43100.00
C59671	2017-08-05 21:20:00+03	129700.00
C596F7	2017-08-02 19:27:00+03	112000.00
C5972C	2017-07-08 02:10:00+03	16400.00
C597B6	2017-07-18 08:08:00+03	128400.00
C597CC	2017-07-11 21:04:00+03	46000.00
C597EA	2017-08-06 22:59:00+03	38400.00
C597F1	2017-07-25 12:09:00+03	133200.00
C5983F	2017-07-12 17:51:00+03	44800.00
C59842	2017-07-18 09:15:00+03	140900.00
C598C0	2017-07-28 10:53:00+03	32800.00
C598EC	2017-08-02 01:13:00+03	26000.00
C598F7	2017-08-05 12:17:00+03	67700.00
C5991B	2017-07-23 17:18:00+03	257600.00
C5994C	2017-08-04 20:24:00+03	144000.00
C599AE	2017-07-27 17:33:00+03	46200.00
C599EA	2017-07-17 00:26:00+03	139400.00
C59A01	2017-08-06 13:29:00+03	48400.00
C59A22	2017-07-23 04:02:00+03	76600.00
C59A42	2017-07-16 11:48:00+03	8600.00
C59A5C	2017-06-28 09:38:00+03	311900.00
C59A80	2017-07-25 22:47:00+03	123000.00
C59A88	2017-07-18 04:30:00+03	47400.00
C59C1D	2017-07-12 18:56:00+03	44800.00
C59C55	2017-07-06 02:00:00+03	81700.00
C59C64	2017-07-28 08:05:00+03	31400.00
C59C94	2017-07-14 10:55:00+03	23200.00
C59CE6	2017-08-09 01:30:00+03	47000.00
C59CEC	2017-08-04 05:31:00+03	56600.00
C59CFE	2017-08-06 02:32:00+03	11600.00
C59DA5	2017-08-09 05:37:00+03	112400.00
C59E5A	2017-08-06 13:16:00+03	119600.00
C59F0B	2017-07-27 07:16:00+03	133000.00
C59F68	2017-07-19 11:00:00+03	169300.00
C59F6E	2017-08-13 03:27:00+03	22000.00
C59F96	2017-08-13 23:35:00+03	18900.00
C5A000	2017-07-22 16:08:00+03	39500.00
C5A094	2017-07-28 13:51:00+03	246000.00
C5A0D2	2017-07-12 03:40:00+03	36200.00
C5A0EF	2017-08-02 08:25:00+03	21500.00
C5A108	2017-08-06 15:06:00+03	66600.00
C5A13D	2017-07-10 11:31:00+03	12900.00
C5A168	2017-08-05 04:05:00+03	48300.00
C5A18F	2017-07-17 17:43:00+03	31800.00
C5A23C	2017-08-10 00:02:00+03	42200.00
C5A2C0	2017-07-29 20:07:00+03	61900.00
C5A309	2017-07-18 06:35:00+03	188800.00
C5A316	2017-08-10 14:16:00+03	155300.00
C5A323	2017-07-31 10:56:00+03	28000.00
C5A386	2017-07-20 04:00:00+03	22000.00
C5A3A0	2017-08-06 01:01:00+03	32200.00
C5A3A1	2017-07-25 09:52:00+03	82500.00
C5A3AA	2017-07-14 21:31:00+03	18000.00
C5A3AB	2017-07-02 03:30:00+03	135200.00
C5A3B9	2017-07-30 22:08:00+03	258400.00
C5A462	2017-07-14 17:33:00+03	40400.00
C5A463	2017-07-31 10:45:00+03	28800.00
C5A483	2017-07-12 02:19:00+03	28000.00
C5A492	2017-08-01 04:52:00+03	55800.00
C5A4C5	2017-07-10 14:26:00+03	6800.00
C5A52D	2017-07-21 13:21:00+03	271100.00
C5A59D	2017-07-21 10:42:00+03	9200.00
C5A5B6	2017-07-23 12:46:00+03	36800.00
C5A5D7	2017-07-11 04:20:00+03	325500.00
C5A5F7	2017-07-23 12:42:00+03	174600.00
C5A659	2017-07-05 23:16:00+03	146400.00
C5A69F	2017-08-14 19:58:00+03	366800.00
C5A6D7	2017-07-03 08:17:00+03	80500.00
C5A70F	2017-07-28 16:39:00+03	126700.00
C5A78D	2017-07-27 08:50:00+03	70200.00
C5A7A4	2017-07-30 17:38:00+03	36800.00
C5A7D9	2017-07-04 19:40:00+03	62000.00
C5A821	2017-08-13 23:01:00+03	63200.00
C5A869	2017-07-08 10:51:00+03	53800.00
C5A873	2017-07-15 18:54:00+03	84100.00
C5A878	2017-08-06 03:25:00+03	88100.00
C5A8B5	2017-08-06 13:30:00+03	28300.00
C5A8EA	2017-07-18 07:38:00+03	21800.00
C5A90C	2017-08-13 07:44:00+03	34000.00
C5A924	2017-08-13 17:39:00+03	22000.00
C5A976	2017-07-24 13:01:00+03	51600.00
C5A97C	2017-08-07 21:40:00+03	33100.00
C5A97D	2017-08-14 00:33:00+03	115600.00
C5A9AE	2017-08-04 06:49:00+03	15400.00
C5A9E3	2017-07-11 03:56:00+03	67200.00
C5A9F0	2017-08-09 18:36:00+03	46400.00
C5A9FC	2017-07-31 17:38:00+03	8200.00
C5AA50	2017-07-04 06:32:00+03	49200.00
C5AA66	2017-08-13 21:36:00+03	153400.00
C5AA67	2017-08-01 21:43:00+03	31200.00
C5AA69	2017-08-09 07:14:00+03	66600.00
C5AAAA	2017-08-11 07:25:00+03	128800.00
C5AAC1	2017-07-17 17:09:00+03	19800.00
C5AAC5	2017-08-09 14:47:00+03	52700.00
C5AAE2	2017-07-05 19:05:00+03	61500.00
C5AB58	2017-07-10 22:28:00+03	61800.00
C5AB6A	2017-07-24 00:32:00+03	46400.00
C5AC26	2017-07-08 21:15:00+03	30200.00
C5ACB6	2017-07-15 12:23:00+03	8000.00
C5ACF8	2017-07-06 16:09:00+03	59400.00
C5AD93	2017-07-22 05:26:00+03	9200.00
C5ADB2	2017-07-03 13:01:00+03	6800.00
C5ADD8	2017-08-10 17:35:00+03	409100.00
C5AE65	2017-07-07 05:40:00+03	55800.00
C5AE85	2017-07-16 15:34:00+03	135400.00
C5AE99	2017-08-09 11:36:00+03	66600.00
C5AEED	2017-07-02 04:58:00+03	23200.00
C5AF92	2017-07-22 10:44:00+03	70400.00
C5AFD6	2017-07-28 00:41:00+03	53200.00
C5B015	2017-07-21 17:20:00+03	156000.00
C5B03F	2017-07-07 04:27:00+03	14000.00
C5B08D	2017-07-23 20:22:00+03	284400.00
C5B114	2017-07-06 21:09:00+03	16400.00
C5B23A	2017-08-03 11:35:00+03	68000.00
C5B25B	2017-07-03 20:16:00+03	35300.00
C5B27E	2017-08-11 09:58:00+03	203400.00
C5B29C	2017-08-08 12:14:00+03	22000.00
C5B2A5	2017-07-01 15:06:00+03	231300.00
C5B2D4	2017-08-06 08:48:00+03	26700.00
C5B325	2017-07-20 22:51:00+03	92000.00
C5B3AA	2017-08-06 19:05:00+03	11800.00
C5B3D1	2017-07-08 22:09:00+03	125200.00
C5B3DA	2017-07-18 00:52:00+03	91200.00
C5B3DB	2017-07-22 00:29:00+03	90400.00
C5B3EA	2017-08-14 17:56:00+03	44900.00
C5B3F2	2017-07-18 10:52:00+03	16400.00
C5B3FA	2017-08-02 16:01:00+03	81800.00
C5B41C	2017-07-20 01:50:00+03	75100.00
C5B452	2017-08-06 20:19:00+03	52100.00
C5B479	2017-07-29 22:08:00+03	101200.00
C5B490	2017-07-16 09:58:00+03	29600.00
C5B493	2017-08-04 02:26:00+03	37900.00
C5B4D5	2017-07-13 02:39:00+03	112000.00
C5B57B	2017-07-23 06:53:00+03	54000.00
C5B597	2017-07-11 13:43:00+03	155600.00
C5B674	2017-07-09 16:43:00+03	26700.00
C5B690	2017-08-13 13:38:00+03	131100.00
C5B693	2017-07-05 14:00:00+03	59800.00
C5B6A0	2017-08-07 22:13:00+03	33600.00
C5B6B8	2017-08-04 19:16:00+03	73500.00
C5B6DE	2017-08-11 18:43:00+03	34000.00
C5B70F	2017-07-15 09:22:00+03	46000.00
C5B78A	2017-07-26 09:02:00+03	6800.00
C5B795	2017-07-29 17:26:00+03	13000.00
C5B7E9	2017-08-07 01:35:00+03	55000.00
C5B8DE	2017-08-07 15:58:00+03	11600.00
C5B91A	2017-06-30 11:05:00+03	22000.00
C5B9C3	2017-07-04 10:29:00+03	98300.00
C5BA05	2017-07-28 23:10:00+03	155600.00
C5BAB2	2017-08-05 17:03:00+03	36200.00
C5BABF	2017-08-11 09:24:00+03	105100.00
C5BB4B	2017-07-16 17:59:00+03	64700.00
C5BB92	2017-06-28 15:51:00+03	169300.00
C5BBAA	2017-08-01 12:53:00+03	24400.00
C5BBB3	2017-08-10 05:33:00+03	257600.00
C5BBBB	2017-07-12 01:31:00+03	27900.00
C5BC14	2017-08-12 16:06:00+03	28800.00
C5BC4B	2017-07-31 08:29:00+03	263200.00
C5BC8E	2017-07-24 04:56:00+03	137700.00
C5BC96	2017-07-06 18:15:00+03	24500.00
C5BC9D	2017-08-04 00:59:00+03	265700.00
C5BCEC	2017-08-05 08:25:00+03	92800.00
C5BD02	2017-07-18 10:48:00+03	302400.00
C5BD67	2017-07-19 22:29:00+03	24400.00
C5BE46	2017-07-16 13:13:00+03	22000.00
C5BE4F	2017-07-23 22:24:00+03	60400.00
C5BE67	2017-08-03 14:25:00+03	102100.00
C5BEBE	2017-07-23 19:58:00+03	14800.00
C5BEE2	2017-07-02 12:24:00+03	6300.00
C5BF00	2017-07-07 19:00:00+03	48800.00
C5BF27	2017-07-23 12:05:00+03	28000.00
C5BF70	2017-08-15 09:35:00+03	28800.00
C5BF74	2017-07-18 22:02:00+03	72600.00
C5BFF9	2017-07-27 13:01:00+03	23900.00
C5BFFC	2017-07-25 00:13:00+03	95700.00
C5C059	2017-07-29 13:55:00+03	28800.00
C5C118	2017-08-06 04:50:00+03	56000.00
C5C167	2017-07-28 06:38:00+03	106900.00
C5C189	2017-08-15 09:59:00+03	342300.00
C5C1B9	2017-07-22 14:50:00+03	188200.00
C5C1F7	2017-07-09 07:36:00+03	15900.00
C5C318	2017-07-25 04:15:00+03	397700.00
C5C323	2017-07-03 19:53:00+03	135400.00
C5C332	2017-08-08 10:57:00+03	12400.00
C5C354	2017-08-04 20:41:00+03	46500.00
C5C3E5	2017-07-28 19:51:00+03	29600.00
C5C441	2017-08-14 11:45:00+03	37000.00
C5C44A	2017-07-02 03:18:00+03	134200.00
C5C463	2017-07-18 11:43:00+03	98600.00
C5C4A7	2017-07-29 16:12:00+03	79900.00
C5C4E6	2017-08-12 00:26:00+03	23200.00
C5C527	2017-07-04 04:40:00+03	166100.00
C5C564	2017-08-02 20:13:00+03	23200.00
C5C5B7	2017-07-21 00:04:00+03	28300.00
C5C5BC	2017-07-28 17:28:00+03	20200.00
C5C5E6	2017-07-15 04:29:00+03	32700.00
C5C63D	2017-07-28 02:34:00+03	31400.00
C5C674	2017-06-27 04:13:00+03	65900.00
C5C715	2017-07-05 12:43:00+03	73600.00
C5C73A	2017-07-31 15:18:00+03	23200.00
C5C747	2017-07-29 09:00:00+03	26600.00
C5C753	2017-08-02 04:49:00+03	170200.00
C5C7C0	2017-08-13 19:57:00+03	26800.00
C5C7CB	2017-07-11 22:20:00+03	69000.00
C5C7F3	2017-07-23 02:12:00+03	36400.00
C5C8F2	2017-07-26 12:23:00+03	24400.00
C5C929	2017-07-14 11:58:00+03	46400.00
C5C94B	2017-07-09 14:13:00+03	48300.00
C5C957	2017-07-23 08:33:00+03	67700.00
C5C980	2017-06-30 11:28:00+03	168300.00
C5CA50	2017-08-10 15:51:00+03	80100.00
C5CA58	2017-07-11 06:18:00+03	39500.00
C5CA83	2017-08-03 23:35:00+03	75600.00
C5CA9F	2017-07-27 03:33:00+03	40000.00
C5CB2B	2017-07-06 09:12:00+03	21600.00
C5CB34	2017-07-26 09:16:00+03	56000.00
C5CB51	2017-08-07 11:14:00+03	48500.00
C5CB5F	2017-07-29 14:39:00+03	19800.00
C5CB62	2017-07-25 23:30:00+03	47200.00
C5CB8F	2017-07-03 16:55:00+03	59800.00
C5CBC9	2017-07-14 05:08:00+03	290400.00
C5CC0F	2017-08-04 13:32:00+03	99200.00
C5CC27	2017-07-01 08:00:00+03	84100.00
C5CC93	2017-07-10 18:55:00+03	67600.00
C5CD03	2017-08-03 14:28:00+03	125200.00
C5CD84	2017-08-15 17:12:00+03	6000.00
C5CDDE	2017-07-21 09:28:00+03	153300.00
C5CDFE	2017-07-23 20:05:00+03	98400.00
C5CE11	2017-08-04 17:19:00+03	103200.00
C5CE1F	2017-08-08 09:48:00+03	28800.00
C5CE7D	2017-08-02 01:52:00+03	63200.00
C5CEB7	2017-07-12 01:47:00+03	87000.00
C5CEE9	2017-07-15 09:43:00+03	92800.00
C5CEF0	2017-08-03 07:27:00+03	185600.00
C5CF4D	2017-07-26 14:04:00+03	8400.00
C5CF64	2017-08-11 13:59:00+03	67800.00
C5CF7D	2017-07-30 14:08:00+03	14400.00
C5D029	2017-08-06 23:36:00+03	21800.00
C5D08D	2017-08-03 01:12:00+03	23400.00
C5D0A5	2017-08-12 05:50:00+03	23600.00
C5D0BA	2017-08-14 22:22:00+03	136800.00
C5D0E0	2017-07-22 23:02:00+03	61800.00
C5D137	2017-08-07 07:34:00+03	60700.00
C5D144	2017-08-14 14:34:00+03	396500.00
C5D167	2017-07-25 04:09:00+03	42800.00
C5D19E	2017-07-26 12:18:00+03	24800.00
C5D1B2	2017-08-01 20:27:00+03	57500.00
C5D1C1	2017-08-13 08:00:00+03	92800.00
C5D23B	2017-08-15 03:41:00+03	33600.00
C5D24C	2017-08-04 02:00:00+03	24400.00
C5D254	2017-07-03 13:28:00+03	46200.00
C5D26A	2017-07-08 02:48:00+03	55800.00
C5D281	2017-08-02 19:04:00+03	99700.00
C5D2C0	2017-08-09 06:59:00+03	100600.00
C5D35B	2017-07-25 03:35:00+03	73900.00
C5D368	2017-07-26 08:59:00+03	112000.00
C5D36C	2017-07-16 20:27:00+03	112000.00
C5D3CD	2017-07-11 06:36:00+03	174900.00
C5D434	2017-07-25 22:24:00+03	58800.00
C5D43B	2017-07-19 11:48:00+03	112000.00
C5D47F	2017-07-28 22:42:00+03	79600.00
C5D4CA	2017-07-16 17:59:00+03	8200.00
C5D4F4	2017-07-26 21:56:00+03	61800.00
C5D560	2017-06-29 11:25:00+03	7400.00
C5D569	2017-06-30 05:35:00+03	155600.00
C5D631	2017-07-07 03:14:00+03	56000.00
C5D6BD	2017-07-26 03:26:00+03	22600.00
C5D6EB	2017-07-21 05:03:00+03	48800.00
C5D721	2017-07-31 15:22:00+03	76800.00
C5D73B	2017-07-26 08:13:00+03	133100.00
C5D757	2017-07-20 10:49:00+03	28000.00
C5D78B	2017-08-03 20:46:00+03	169300.00
C5D7BE	2017-07-23 02:35:00+03	119600.00
C5D7D3	2017-07-29 22:15:00+03	118600.00
C5D883	2017-08-14 06:22:00+03	27200.00
C5D8B1	2017-07-30 11:55:00+03	24000.00
C5D8E4	2017-07-06 20:51:00+03	55800.00
C5D934	2017-07-02 06:32:00+03	59800.00
C5D935	2017-08-04 22:28:00+03	78400.00
C5D9D6	2017-07-23 20:27:00+03	28800.00
C5DA18	2017-07-26 23:12:00+03	111600.00
C5DA49	2017-07-05 10:50:00+03	23400.00
C5DA7C	2017-07-18 14:33:00+03	114800.00
C5DAE6	2017-08-10 23:18:00+03	100600.00
C5DAEE	2017-06-29 19:33:00+03	28800.00
C5DB31	2017-08-14 22:59:00+03	23600.00
C5DB90	2017-07-31 06:51:00+03	120400.00
C5DBF2	2017-07-13 11:48:00+03	265600.00
C5DCED	2017-07-20 11:57:00+03	56900.00
C5DD1F	2017-07-31 22:22:00+03	47600.00
C5DDEE	2017-07-03 20:52:00+03	66900.00
C5DDF5	2017-08-15 04:26:00+03	9200.00
C5DE03	2017-07-17 13:14:00+03	113300.00
C5DE0D	2017-08-14 04:25:00+03	95700.00
C5DE34	2017-07-27 17:00:00+03	161600.00
C5DE5F	2017-08-02 22:14:00+03	43800.00
C5DEC2	2017-07-08 07:48:00+03	56000.00
C5DEDA	2017-07-21 20:57:00+03	25900.00
C5DF30	2017-07-05 13:41:00+03	196100.00
C5DF44	2017-07-19 15:48:00+03	48500.00
C5DF49	2017-07-20 15:27:00+03	43900.00
C5DF7D	2017-07-28 23:00:00+03	20200.00
C5DF82	2017-07-04 09:31:00+03	24700.00
C5DFD1	2017-07-19 05:44:00+03	58600.00
C5E0A6	2017-07-08 23:56:00+03	112000.00
C5E12C	2017-08-10 23:16:00+03	28700.00
C5E16B	2017-07-05 03:19:00+03	56000.00
C5E1CB	2017-07-20 14:46:00+03	21800.00
C5E225	2017-07-29 08:19:00+03	284700.00
C5E256	2017-08-02 21:24:00+03	79900.00
C5E259	2017-08-09 20:17:00+03	24400.00
C5E25C	2017-07-17 06:17:00+03	135200.00
C5E275	2017-07-06 23:58:00+03	46400.00
C5E2CF	2017-08-06 12:01:00+03	136200.00
C5E3B9	2017-07-08 10:28:00+03	74400.00
C5E3D0	2017-07-18 02:23:00+03	30200.00
C5E3DF	2017-08-13 05:51:00+03	92800.00
C5E496	2017-07-18 15:14:00+03	25800.00
C5E4AC	2017-08-12 17:18:00+03	105900.00
C5E4F5	2017-07-26 06:31:00+03	22000.00
C5E52C	2017-07-18 13:05:00+03	24400.00
C5E556	2017-08-09 22:49:00+03	56900.00
C5E5B7	2017-07-05 16:11:00+03	52300.00
C5E5E3	2017-07-23 23:04:00+03	27200.00
C5E608	2017-08-15 17:40:00+03	260300.00
C5E61B	2017-07-28 13:47:00+03	85700.00
C5E63D	2017-07-16 01:51:00+03	46000.00
C5E6E9	2017-08-03 08:56:00+03	134000.00
C5E74D	2017-07-29 05:30:00+03	10600.00
C5E7AD	2017-06-28 05:45:00+03	28800.00
C5E7E1	2017-07-19 11:42:00+03	46200.00
C5E836	2017-08-09 13:36:00+03	29400.00
C5E85C	2017-08-13 04:35:00+03	29800.00
C5E8A2	2017-07-25 10:23:00+03	542300.00
C5E8B0	2017-07-16 22:57:00+03	246000.00
C5E8D6	2017-08-14 14:50:00+03	38600.00
C5E91C	2017-07-15 04:53:00+03	81300.00
C5E9E1	2017-07-11 22:12:00+03	381400.00
C5EA20	2017-08-13 05:35:00+03	182300.00
C5EA3F	2017-07-24 10:39:00+03	27200.00
C5EA75	2017-07-31 17:42:00+03	66000.00
C5EA77	2017-07-19 12:35:00+03	10800.00
C5EA8A	2017-07-25 01:53:00+03	143100.00
C5EB38	2017-07-14 06:02:00+03	47000.00
C5EB96	2017-07-01 06:22:00+03	46500.00
C5EBB7	2017-07-26 23:56:00+03	61800.00
C5EC03	2017-08-03 00:30:00+03	218000.00
C5EC0A	2017-08-09 23:34:00+03	83200.00
C5EC12	2017-07-21 22:49:00+03	58600.00
C5EC21	2017-07-11 09:56:00+03	14800.00
C5EC4A	2017-08-11 22:16:00+03	405000.00
C5EC6F	2017-06-26 13:18:00+03	112000.00
C5EC81	2017-07-14 14:25:00+03	32200.00
C5ECBC	2017-08-11 02:26:00+03	56900.00
C5ECE1	2017-07-24 18:21:00+03	101200.00
C5ECE4	2017-08-06 18:21:00+03	80700.00
C5ED17	2017-07-28 18:24:00+03	62600.00
C5ED43	2017-07-14 21:24:00+03	28800.00
C5EDFA	2017-07-17 00:03:00+03	8000.00
C5EE37	2017-07-15 19:59:00+03	116900.00
C5EE4F	2017-07-09 10:27:00+03	22600.00
C5EEA2	2017-07-28 20:38:00+03	93000.00
C5EF5F	2017-08-05 08:26:00+03	24200.00
C5EF6A	2017-07-22 07:10:00+03	66600.00
C5EFCA	2017-07-28 01:17:00+03	56000.00
C5EFEA	2017-07-22 20:10:00+03	75200.00
C5F009	2017-07-11 02:40:00+03	136800.00
C5F025	2017-07-27 12:41:00+03	23600.00
C5F08D	2017-07-07 08:39:00+03	59800.00
C5F09B	2017-08-11 20:04:00+03	48800.00
C5F0A4	2017-07-20 15:16:00+03	24400.00
C5F0B3	2017-07-30 11:47:00+03	37700.00
C5F1A6	2017-08-03 12:23:00+03	21800.00
C5F1C8	2017-08-04 10:49:00+03	22400.00
C5F1CD	2017-07-28 02:48:00+03	41600.00
C5F21C	2017-08-09 22:28:00+03	27400.00
C5F241	2017-07-02 06:26:00+03	25600.00
C5F282	2017-07-24 06:36:00+03	53300.00
C5F28E	2017-08-02 00:44:00+03	67500.00
C5F292	2017-07-05 09:27:00+03	40000.00
C5F29C	2017-07-11 05:20:00+03	266500.00
C5F2A1	2017-07-03 13:08:00+03	21400.00
C5F2AD	2017-08-13 12:35:00+03	19300.00
C5F2AE	2017-07-06 07:24:00+03	19600.00
C5F2C1	2017-07-23 22:01:00+03	289800.00
C5F31A	2017-07-20 04:22:00+03	98800.00
C5F3A8	2017-07-23 21:18:00+03	59200.00
C5F3CD	2017-07-23 07:02:00+03	288200.00
C5F415	2017-07-21 20:39:00+03	133700.00
C5F41F	2017-07-16 06:15:00+03	8000.00
C5F432	2017-07-08 15:10:00+03	44000.00
C5F479	2017-07-22 04:27:00+03	132800.00
C5F5D0	2017-07-03 14:53:00+03	123000.00
C5F640	2017-07-11 23:15:00+03	246000.00
C5F71B	2017-07-14 06:17:00+03	14800.00
C5F737	2017-07-13 08:30:00+03	134700.00
C5F741	2017-08-07 10:28:00+03	62800.00
C5F786	2017-06-30 23:19:00+03	26800.00
C5F837	2017-08-08 02:58:00+03	21400.00
C5F866	2017-08-11 08:52:00+03	239600.00
C5F871	2017-08-09 14:30:00+03	34700.00
C5F875	2017-07-20 20:22:00+03	24700.00
C5F89A	2017-06-29 17:52:00+03	53300.00
C5F89F	2017-08-14 05:12:00+03	85000.00
C5F8EF	2017-08-09 20:19:00+03	27400.00
C5F91D	2017-07-09 13:03:00+03	66600.00
C5F963	2017-08-04 03:29:00+03	18000.00
C5F9B2	2017-07-30 08:33:00+03	107500.00
C5FA1B	2017-07-30 11:03:00+03	62800.00
C5FA2D	2017-07-01 10:34:00+03	136800.00
C5FA2E	2017-07-16 03:19:00+03	6700.00
C5FA56	2017-08-03 08:43:00+03	100600.00
C5FA96	2017-07-19 15:36:00+03	35600.00
C5FB85	2017-07-20 13:53:00+03	69000.00
C5FB9E	2017-07-20 06:30:00+03	57500.00
C5FBDA	2017-07-09 16:52:00+03	67600.00
C5FBF0	2017-07-05 22:26:00+03	16400.00
C5FBFD	2017-07-06 13:54:00+03	25600.00
C5FC8D	2017-06-28 03:50:00+03	112600.00
C5FDD0	2017-08-11 22:30:00+03	40600.00
C5FE5D	2017-08-11 19:04:00+03	19600.00
C5FE66	2017-08-12 21:29:00+03	67400.00
C5FF08	2017-07-01 08:22:00+03	133100.00
C5FF86	2017-07-09 23:46:00+03	219400.00
C5FFCB	2017-07-05 03:48:00+03	59800.00
C600E0	2017-07-11 13:40:00+03	46800.00
C60165	2017-07-25 12:26:00+03	201300.00
C60197	2017-07-28 03:45:00+03	481800.00
C60203	2017-08-09 03:27:00+03	32700.00
C6020E	2017-07-23 11:16:00+03	31600.00
C6020F	2017-08-15 16:07:00+03	18600.00
C60258	2017-07-17 00:50:00+03	38800.00
C60303	2017-08-14 21:04:00+03	28800.00
C60304	2017-08-02 22:29:00+03	6000.00
C6032C	2017-07-31 18:17:00+03	50600.00
C60356	2017-08-05 14:56:00+03	81700.00
C60361	2017-07-14 16:32:00+03	70600.00
C6036A	2017-08-14 20:23:00+03	56800.00
C60389	2017-07-20 19:11:00+03	245200.00
C603B6	2017-07-29 15:03:00+03	24400.00
C603FA	2017-07-31 08:15:00+03	40800.00
C6047D	2017-07-04 23:28:00+03	64300.00
C60495	2017-08-11 15:54:00+03	76100.00
C604AA	2017-07-24 10:50:00+03	406700.00
C604E0	2017-08-06 04:20:00+03	99200.00
C60518	2017-08-05 15:06:00+03	75300.00
C6058E	2017-07-01 20:04:00+03	67600.00
C605B4	2017-06-30 10:00:00+03	154000.00
C60633	2017-08-03 01:07:00+03	66000.00
C60651	2017-07-07 07:00:00+03	85700.00
C60781	2017-08-04 11:57:00+03	246000.00
C60783	2017-07-28 05:37:00+03	10700.00
C607B2	2017-07-25 07:36:00+03	252200.00
C60859	2017-07-14 00:29:00+03	34000.00
C6088D	2017-07-21 08:20:00+03	356700.00
C609AD	2017-08-12 18:46:00+03	111600.00
C60A32	2017-08-02 07:21:00+03	230600.00
C60A54	2017-07-29 03:24:00+03	37900.00
C60AC9	2017-08-02 11:21:00+03	26000.00
C60AEF	2017-07-12 22:36:00+03	69100.00
C60B4B	2017-07-20 12:48:00+03	23600.00
C60C04	2017-07-25 14:31:00+03	112400.00
C60CE2	2017-08-09 05:18:00+03	203400.00
C60CF4	2017-07-04 21:50:00+03	40800.00
C60D30	2017-07-27 15:13:00+03	102100.00
C60D5C	2017-08-05 10:50:00+03	210000.00
C60DD7	2017-07-23 07:30:00+03	18400.00
C60DDA	2017-07-18 22:20:00+03	43000.00
C60E0C	2017-07-28 08:10:00+03	78300.00
C60EAB	2017-07-04 14:13:00+03	32700.00
C60EE2	2017-07-25 07:35:00+03	55800.00
C60EE7	2017-07-29 19:46:00+03	55800.00
C60F2D	2017-07-19 12:52:00+03	48300.00
C60F8C	2017-07-23 14:09:00+03	36100.00
C60FAB	2017-07-04 08:42:00+03	57600.00
C60FC8	2017-07-05 23:03:00+03	50200.00
C6102D	2017-08-15 10:25:00+03	124300.00
C610F2	2017-08-06 07:14:00+03	37900.00
C61171	2017-07-12 00:23:00+03	26800.00
C611EB	2017-07-25 03:26:00+03	50600.00
C61213	2017-07-19 13:04:00+03	59200.00
C6123E	2017-08-10 02:00:00+03	11700.00
C61274	2017-08-08 08:41:00+03	199700.00
C61294	2017-07-19 22:09:00+03	318200.00
C6131B	2017-07-22 06:19:00+03	100600.00
C61320	2017-07-18 19:32:00+03	36200.00
C6132D	2017-07-17 22:07:00+03	240600.00
C61348	2017-07-05 20:56:00+03	13400.00
C61359	2017-08-10 13:31:00+03	51900.00
C613A9	2017-07-20 03:54:00+03	34900.00
C61407	2017-07-18 02:23:00+03	184200.00
C61479	2017-08-04 21:35:00+03	28800.00
C61485	2017-07-29 19:32:00+03	46400.00
C614AC	2017-07-16 00:33:00+03	152900.00
C614B3	2017-08-13 11:59:00+03	91200.00
C61536	2017-08-04 00:18:00+03	67200.00
C61538	2017-07-08 09:11:00+03	56600.00
C61561	2017-07-11 07:54:00+03	135400.00
C61565	2017-08-09 07:54:00+03	46400.00
C61570	2017-07-25 16:43:00+03	92800.00
C6158B	2017-07-07 15:20:00+03	105600.00
C615C2	2017-07-06 03:54:00+03	67100.00
C61662	2017-07-25 03:02:00+03	40800.00
C616CC	2017-07-06 07:47:00+03	73300.00
C61722	2017-06-30 23:46:00+03	91600.00
C6173B	2017-07-07 12:06:00+03	93900.00
C61744	2017-08-07 22:41:00+03	88500.00
C6179E	2017-07-17 11:48:00+03	242600.00
C617A3	2017-07-23 00:27:00+03	51900.00
C617C1	2017-08-06 12:19:00+03	274200.00
C617C4	2017-07-16 17:28:00+03	127300.00
C617D5	2017-08-02 08:30:00+03	47200.00
C61976	2017-07-09 05:47:00+03	68800.00
C6197D	2017-07-27 02:52:00+03	186900.00
C619BB	2017-08-05 20:51:00+03	39200.00
C61A2B	2017-07-15 20:39:00+03	36000.00
C61ABC	2017-08-05 04:59:00+03	118400.00
C61ABF	2017-07-23 22:39:00+03	38200.00
C61AE2	2017-07-18 19:11:00+03	26200.00
C61AFA	2017-07-12 03:19:00+03	58200.00
C61B2A	2017-08-06 02:06:00+03	35700.00
C61B7F	2017-07-20 02:55:00+03	66600.00
C61BCC	2017-07-29 18:52:00+03	14400.00
C61C23	2017-07-11 22:32:00+03	35600.00
C61C6B	2017-08-14 07:10:00+03	216900.00
C61C73	2017-07-31 18:16:00+03	36200.00
C61CF0	2017-07-30 21:57:00+03	111600.00
C61CF3	2017-07-19 09:02:00+03	56000.00
C61D30	2017-07-05 13:02:00+03	48500.00
C61D3E	2017-08-02 10:52:00+03	110300.00
C61D81	2017-07-31 14:35:00+03	44600.00
C61E5E	2017-08-02 20:54:00+03	12400.00
C61EB3	2017-08-05 04:08:00+03	47100.00
C61EB5	2017-07-08 13:58:00+03	272300.00
C61F08	2017-07-11 06:05:00+03	63700.00
C61F30	2017-08-01 08:05:00+03	125000.00
C61F54	2017-08-08 11:12:00+03	66600.00
C61F9A	2017-08-04 14:31:00+03	49100.00
C61FB5	2017-07-14 09:26:00+03	46200.00
C61FEE	2017-07-07 23:57:00+03	391900.00
C62041	2017-07-27 13:01:00+03	34400.00
C6208B	2017-07-02 23:05:00+03	27200.00
C620B1	2017-07-29 00:07:00+03	78400.00
C620F9	2017-08-10 02:22:00+03	56900.00
C62178	2017-07-17 19:27:00+03	98300.00
C621D6	2017-08-10 05:25:00+03	23900.00
C6222C	2017-08-06 03:34:00+03	175000.00
C622AE	2017-08-11 11:54:00+03	24400.00
C62325	2017-08-08 04:49:00+03	48400.00
C6232B	2017-08-13 12:52:00+03	74700.00
C62359	2017-08-07 07:55:00+03	69700.00
C62392	2017-07-16 06:37:00+03	149300.00
C6239D	2017-07-26 16:58:00+03	56000.00
C623C1	2017-08-03 21:40:00+03	83000.00
C623CF	2017-07-30 17:28:00+03	64500.00
C623D3	2017-07-06 11:19:00+03	53300.00
C6241D	2017-07-22 07:56:00+03	47600.00
C62479	2017-07-14 20:41:00+03	39100.00
C62499	2017-08-14 10:36:00+03	23200.00
C62512	2017-07-27 07:00:00+03	79700.00
C625A3	2017-08-13 08:30:00+03	14000.00
C625B2	2017-08-07 18:59:00+03	193200.00
C625BC	2017-06-26 05:21:00+03	85700.00
C625F9	2017-07-13 12:28:00+03	73500.00
C626DC	2017-07-14 23:22:00+03	75600.00
C6273A	2017-06-30 08:28:00+03	72400.00
C627B0	2017-07-18 23:03:00+03	120000.00
C628E2	2017-07-06 23:28:00+03	66300.00
C62902	2017-07-26 13:12:00+03	49700.00
C62906	2017-08-08 17:01:00+03	10600.00
C629D1	2017-08-02 22:58:00+03	67000.00
C62A28	2017-07-18 17:46:00+03	6300.00
C62A64	2017-08-09 07:32:00+03	130400.00
C62AD4	2017-07-29 16:49:00+03	171400.00
C62B13	2017-07-22 06:22:00+03	76300.00
C62B5F	2017-07-22 03:40:00+03	421400.00
C62B63	2017-07-24 21:37:00+03	108600.00
C62B7D	2017-07-24 00:03:00+03	26000.00
C62B8A	2017-07-21 18:07:00+03	65900.00
C62B9B	2017-08-10 00:47:00+03	114800.00
C62BD4	2017-08-04 21:48:00+03	86500.00
C62C1F	2017-07-05 16:30:00+03	28800.00
C62D62	2017-07-26 11:47:00+03	24000.00
C62D89	2017-07-13 11:27:00+03	54800.00
C62DBB	2017-07-13 18:07:00+03	136100.00
C62DBC	2017-07-18 07:48:00+03	46400.00
C62DE0	2017-07-29 06:25:00+03	25400.00
C62DE1	2017-08-05 07:27:00+03	28800.00
C62DE3	2017-08-07 21:17:00+03	14400.00
C62DEE	2017-07-26 10:31:00+03	44600.00
C62DF5	2017-07-07 11:54:00+03	77900.00
C62DF7	2017-08-11 10:55:00+03	6600.00
C62E40	2017-08-01 23:20:00+03	28000.00
C62E7C	2017-07-25 06:56:00+03	42800.00
C62E87	2017-07-15 14:44:00+03	101100.00
C62EEA	2017-07-04 02:51:00+03	38600.00
C62F32	2017-07-31 01:14:00+03	98400.00
C62F3D	2017-07-02 04:15:00+03	103600.00
C62F47	2017-08-12 17:20:00+03	30200.00
C62F80	2017-07-09 19:39:00+03	56000.00
C62F9B	2017-08-11 20:12:00+03	44000.00
C62FA7	2017-07-07 10:05:00+03	43200.00
C62FBA	2017-08-05 12:30:00+03	40300.00
C62FCF	2017-07-17 09:54:00+03	10700.00
C62FF4	2017-07-23 18:04:00+03	246000.00
C63021	2017-08-02 01:56:00+03	116400.00
C6304F	2017-07-14 09:16:00+03	164100.00
C63075	2017-08-11 19:10:00+03	278500.00
C6307A	2017-08-01 16:45:00+03	115900.00
C6311B	2017-07-15 14:05:00+03	100200.00
C631A4	2017-07-17 16:46:00+03	28000.00
C6322C	2017-08-06 07:19:00+03	74400.00
C63239	2017-07-04 02:38:00+03	68800.00
C63277	2017-07-02 11:35:00+03	92800.00
C632B8	2017-08-02 21:49:00+03	173400.00
C63319	2017-07-19 02:02:00+03	52800.00
C633CC	2017-08-01 04:55:00+03	139200.00
C63415	2017-07-19 01:40:00+03	48800.00
C6348E	2017-07-04 05:18:00+03	59600.00
C634A2	2017-07-09 12:52:00+03	8400.00
C634C8	2017-07-04 00:40:00+03	50000.00
C634CA	2017-07-26 17:46:00+03	47100.00
C634FE	2017-06-29 20:08:00+03	48800.00
C63512	2017-08-07 21:32:00+03	67900.00
C635CF	2017-07-03 07:28:00+03	25800.00
C636C9	2017-07-10 04:16:00+03	139500.00
C6377A	2017-07-24 02:22:00+03	46400.00
C6380B	2017-08-10 02:32:00+03	13400.00
C6382D	2017-07-27 17:36:00+03	34000.00
C63876	2017-07-11 11:14:00+03	23200.00
C638A1	2017-07-27 21:54:00+03	132800.00
C6391E	2017-07-23 13:58:00+03	47200.00
C63945	2017-07-26 20:32:00+03	28300.00
C6395D	2017-07-05 21:28:00+03	55800.00
C6399E	2017-07-29 04:34:00+03	113300.00
C639CA	2017-07-25 04:38:00+03	43000.00
C63A13	2017-07-21 10:35:00+03	73600.00
C63A1E	2017-07-06 20:48:00+03	106400.00
C63A67	2017-08-03 07:42:00+03	175700.00
C63AD6	2017-08-03 07:27:00+03	60400.00
C63B70	2017-08-05 09:34:00+03	22600.00
C63BE4	2017-07-11 07:54:00+03	47000.00
C63BF9	2017-07-11 22:42:00+03	15400.00
C63C2A	2017-08-08 02:00:00+03	13000.00
C63C54	2017-08-09 03:11:00+03	40300.00
C63C85	2017-07-19 17:20:00+03	515000.00
C63D51	2017-08-13 18:08:00+03	30200.00
C63D6A	2017-08-05 21:48:00+03	22600.00
C63D77	2017-08-14 00:38:00+03	112600.00
C63DE2	2017-07-21 01:46:00+03	14800.00
C63E08	2017-07-29 14:20:00+03	57600.00
C63E12	2017-07-16 09:21:00+03	137400.00
C63E20	2017-08-10 07:21:00+03	20600.00
C63E2D	2017-07-09 14:06:00+03	43200.00
C63E59	2017-07-10 16:59:00+03	132800.00
C63EBA	2017-07-01 17:11:00+03	103700.00
C63EBE	2017-08-12 20:35:00+03	94000.00
C63EE4	2017-08-03 20:16:00+03	155600.00
C63EF3	2017-07-21 12:26:00+03	139200.00
C63F69	2017-08-02 00:11:00+03	61800.00
C63F86	2017-07-06 15:23:00+03	19600.00
C63FF4	2017-07-05 14:19:00+03	67000.00
C64001	2017-07-23 11:54:00+03	39200.00
C64056	2017-08-02 10:21:00+03	36200.00
C64094	2017-08-12 14:46:00+03	6000.00
C640E5	2017-07-17 17:00:00+03	186900.00
C64155	2017-07-29 15:35:00+03	56000.00
C64179	2017-07-30 17:37:00+03	12600.00
C641F9	2017-07-21 16:30:00+03	34100.00
C64221	2017-07-08 17:51:00+03	64600.00
C64239	2017-07-24 15:07:00+03	179400.00
C64269	2017-08-07 14:47:00+03	123000.00
C642D1	2017-08-13 21:43:00+03	25200.00
C6436D	2017-07-26 03:35:00+03	92800.00
C64375	2017-08-09 12:04:00+03	59200.00
C643D7	2017-08-01 18:21:00+03	44100.00
C643DF	2017-07-15 22:59:00+03	59300.00
C643FF	2017-07-06 09:29:00+03	48300.00
C64410	2017-07-05 19:58:00+03	38900.00
C64423	2017-07-05 04:23:00+03	21800.00
C64427	2017-07-09 01:18:00+03	105600.00
C64454	2017-08-13 16:57:00+03	19600.00
C6446E	2017-08-12 22:35:00+03	46700.00
C64497	2017-07-25 00:15:00+03	102100.00
C64507	2017-07-18 17:53:00+03	26700.00
C64548	2017-07-27 08:25:00+03	52300.00
C64611	2017-08-13 17:44:00+03	86500.00
C64627	2017-08-03 12:56:00+03	136200.00
C6464C	2017-07-16 20:42:00+03	126900.00
C646DF	2017-08-05 14:30:00+03	418500.00
C6473F	2017-07-22 08:02:00+03	46300.00
C64740	2017-08-11 23:38:00+03	39500.00
C64761	2017-07-23 16:21:00+03	135400.00
C64772	2017-07-17 08:25:00+03	123000.00
C6482B	2017-07-08 18:50:00+03	62700.00
C64839	2017-07-07 00:24:00+03	22400.00
C64865	2017-08-13 04:54:00+03	13400.00
C6487F	2017-08-07 18:01:00+03	461200.00
C6488B	2017-07-26 05:28:00+03	20400.00
C6488D	2017-07-27 08:48:00+03	26000.00
C649C3	2017-07-17 16:44:00+03	69600.00
C64A1D	2017-08-15 16:43:00+03	68100.00
C64A74	2017-07-26 19:29:00+03	56900.00
C64AB1	2017-08-04 11:43:00+03	136100.00
C64AB5	2017-07-04 06:23:00+03	86400.00
C64AC1	2017-07-03 14:07:00+03	213200.00
C64B19	2017-08-12 13:02:00+03	90800.00
C64B20	2017-07-07 07:27:00+03	52000.00
C64B42	2017-08-11 22:40:00+03	26000.00
C64B70	2017-07-24 05:52:00+03	20800.00
C64BBF	2017-07-18 15:50:00+03	53600.00
C64BDF	2017-08-14 09:02:00+03	88100.00
C64C53	2017-07-28 09:39:00+03	79200.00
C64C8A	2017-07-20 03:07:00+03	51300.00
C64C90	2017-07-10 19:37:00+03	47600.00
C64CF2	2017-07-19 03:21:00+03	46400.00
C64D14	2017-07-04 15:29:00+03	170500.00
C64D38	2017-07-06 19:32:00+03	55800.00
C64D7F	2017-07-12 00:27:00+03	38200.00
C64E11	2017-07-18 22:44:00+03	29600.00
C64E5E	2017-07-30 08:31:00+03	8000.00
C64E99	2017-08-15 09:10:00+03	24800.00
C64F27	2017-07-07 16:57:00+03	16400.00
C64F3A	2017-07-07 18:50:00+03	146300.00
C6503A	2017-07-27 16:47:00+03	81300.00
C650AC	2017-07-26 17:11:00+03	88600.00
C650C3	2017-07-19 03:07:00+03	68000.00
C6510C	2017-08-14 02:47:00+03	106500.00
C65131	2017-08-13 11:16:00+03	50600.00
C6517B	2017-07-04 01:51:00+03	40400.00
C65199	2017-08-11 23:04:00+03	48800.00
C65272	2017-08-08 02:46:00+03	189800.00
C6528B	2017-08-07 12:18:00+03	92700.00
C652E6	2017-07-17 06:30:00+03	6000.00
C652FA	2017-08-13 17:03:00+03	131600.00
C65308	2017-07-08 15:31:00+03	64800.00
C65313	2017-07-16 22:06:00+03	169300.00
C65321	2017-07-14 03:12:00+03	84500.00
C6533C	2017-07-18 19:04:00+03	6000.00
C65358	2017-07-22 02:37:00+03	311200.00
C65372	2017-08-12 21:35:00+03	32500.00
C6538E	2017-08-11 12:05:00+03	34000.00
C65401	2017-07-20 12:22:00+03	6800.00
C65432	2017-08-04 08:44:00+03	40800.00
C65460	2017-08-02 14:23:00+03	184300.00
C65474	2017-08-05 21:07:00+03	68100.00
C65497	2017-08-04 03:28:00+03	12600.00
C654E8	2017-07-20 22:16:00+03	26800.00
C65500	2017-07-11 18:49:00+03	23500.00
C65540	2017-07-19 22:37:00+03	136600.00
C65547	2017-07-04 12:57:00+03	56000.00
C655D8	2017-07-14 01:26:00+03	131600.00
C655FC	2017-07-28 11:11:00+03	69700.00
C65707	2017-07-11 12:50:00+03	59300.00
C65721	2017-07-17 22:36:00+03	45200.00
C6576C	2017-08-13 03:01:00+03	19600.00
C65815	2017-07-08 14:42:00+03	83700.00
C65832	2017-07-06 17:56:00+03	326700.00
C658B4	2017-07-29 17:59:00+03	59900.00
C65928	2017-07-31 08:12:00+03	10600.00
C65953	2017-08-02 20:31:00+03	20400.00
C65986	2017-07-22 02:40:00+03	180500.00
C65A26	2017-07-22 18:43:00+03	50000.00
C65A5E	2017-07-18 12:50:00+03	55800.00
C65A67	2017-07-16 14:16:00+03	26800.00
C65A91	2017-08-04 09:26:00+03	39200.00
C65AC1	2017-08-01 06:31:00+03	369000.00
C65ACE	2017-08-11 03:05:00+03	103500.00
C65AF8	2017-07-07 14:52:00+03	12600.00
C65B54	2017-07-21 14:31:00+03	67200.00
C65B8E	2017-07-06 06:18:00+03	46900.00
C65BB7	2017-08-02 14:48:00+03	88600.00
C65BFC	2017-07-01 14:38:00+03	115800.00
C65C32	2017-08-14 08:51:00+03	28000.00
C65C38	2017-08-07 15:18:00+03	46400.00
C65C9B	2017-07-11 06:06:00+03	17000.00
C65CA4	2017-08-10 07:18:00+03	241400.00
C65D0C	2017-07-11 00:20:00+03	59400.00
C65D1C	2017-08-12 12:58:00+03	36000.00
C65D32	2017-07-29 23:44:00+03	25800.00
C65D6D	2017-07-24 17:59:00+03	28000.00
C65DAC	2017-07-30 10:30:00+03	196800.00
C65DD9	2017-06-25 05:48:00+03	28800.00
C65DE7	2017-07-22 10:46:00+03	54800.00
C65E1D	2017-08-13 17:46:00+03	28000.00
C65E84	2017-07-30 06:14:00+03	89000.00
C65EBC	2017-07-07 16:04:00+03	133200.00
C65F1C	2017-07-31 18:06:00+03	67600.00
C65FDB	2017-07-17 00:03:00+03	20600.00
C65FDC	2017-07-29 01:53:00+03	26000.00
C65FE8	2017-07-13 20:31:00+03	112600.00
C66056	2017-08-04 21:47:00+03	47400.00
C6606D	2017-07-19 05:45:00+03	10700.00
C660DC	2017-07-13 05:16:00+03	51300.00
C66118	2017-07-16 01:05:00+03	36800.00
C66151	2017-07-09 08:10:00+03	77900.00
C66175	2017-07-13 17:37:00+03	26800.00
C6617A	2017-07-27 10:02:00+03	30200.00
C661CF	2017-06-24 12:58:00+03	136200.00
C661D1	2017-07-16 15:08:00+03	76300.00
C66203	2017-07-03 22:05:00+03	99300.00
C66232	2017-07-13 07:48:00+03	170000.00
C66290	2017-07-31 14:51:00+03	72800.00
C662A6	2017-08-08 00:00:00+03	24000.00
C66300	2017-08-08 18:02:00+03	59800.00
C66313	2017-07-02 05:52:00+03	36200.00
C66356	2017-08-07 12:15:00+03	58400.00
C6635B	2017-07-30 11:37:00+03	12600.00
C6636B	2017-07-20 18:44:00+03	29600.00
C663CF	2017-07-18 08:16:00+03	62900.00
C663D7	2017-07-07 01:02:00+03	11600.00
C663EE	2017-07-10 07:10:00+03	31900.00
C66421	2017-08-09 07:02:00+03	48800.00
C664A0	2017-07-31 01:02:00+03	36200.00
C664A9	2017-08-09 22:02:00+03	46300.00
C664C3	2017-08-09 23:26:00+03	136500.00
C6652D	2017-07-07 23:10:00+03	14400.00
C665AD	2017-07-24 09:16:00+03	78500.00
C665CA	2017-08-11 01:03:00+03	59800.00
C665D7	2017-08-13 02:59:00+03	50400.00
C665E9	2017-07-06 11:00:00+03	67400.00
C66671	2017-07-04 23:48:00+03	32800.00
C6669C	2017-07-18 14:50:00+03	110500.00
C66705	2017-07-24 03:15:00+03	48500.00
C66709	2017-07-29 10:56:00+03	31400.00
C66751	2017-08-11 08:18:00+03	125700.00
C667AE	2017-07-13 14:14:00+03	40800.00
C667C0	2017-07-02 22:45:00+03	69400.00
C667CA	2017-07-08 17:44:00+03	83600.00
C66831	2017-08-15 10:47:00+03	149300.00
C66941	2017-07-03 05:39:00+03	35200.00
C6698E	2017-07-13 11:19:00+03	72400.00
C669D6	2017-07-12 10:17:00+03	24300.00
C66AD4	2017-07-20 03:13:00+03	149400.00
C66B07	2017-07-23 08:08:00+03	162700.00
C66B20	2017-07-03 12:12:00+03	90800.00
C66B4B	2017-07-31 02:04:00+03	22000.00
C66B7F	2017-07-24 14:35:00+03	23200.00
C66B8C	2017-07-06 16:51:00+03	52800.00
C66C34	2017-08-05 03:24:00+03	130100.00
C66C88	2017-07-07 04:36:00+03	25000.00
C66D51	2017-07-04 23:51:00+03	84300.00
C66D63	2017-07-29 04:51:00+03	59000.00
C66D67	2017-07-10 23:15:00+03	58900.00
C66DBA	2017-07-11 07:52:00+03	75600.00
C66DCC	2017-07-04 00:50:00+03	24200.00
C66E60	2017-07-02 05:41:00+03	187600.00
C66E70	2017-07-28 15:22:00+03	112000.00
C66EAC	2017-08-12 23:49:00+03	14000.00
C66EDB	2017-07-13 00:17:00+03	58800.00
C66EEC	2017-07-15 10:13:00+03	80900.00
C66F18	2017-07-22 00:09:00+03	65200.00
C66F2C	2017-07-25 17:56:00+03	52000.00
C66FAE	2017-07-13 19:18:00+03	61800.00
C66FBC	2017-07-07 11:15:00+03	32400.00
C66FD9	2017-08-11 09:03:00+03	26000.00
C66FDF	2017-07-28 09:29:00+03	51300.00
C67031	2017-07-18 10:01:00+03	27200.00
C67049	2017-08-09 21:37:00+03	99300.00
C6704A	2017-08-08 05:49:00+03	124200.00
C67068	2017-07-26 08:04:00+03	138600.00
C6706E	2017-08-06 01:27:00+03	284400.00
C670B3	2017-07-14 22:52:00+03	32800.00
C670F8	2017-07-18 16:53:00+03	56900.00
C6711C	2017-08-07 00:03:00+03	66800.00
C6717C	2017-07-16 15:39:00+03	77200.00
C671A6	2017-08-12 23:53:00+03	53400.00
C671B3	2017-07-15 23:17:00+03	200500.00
C671DF	2017-08-02 16:52:00+03	139300.00
C672F2	2017-08-03 08:42:00+03	166400.00
C673AB	2017-07-28 06:39:00+03	189100.00
C67498	2017-06-29 09:19:00+03	155600.00
C6749D	2017-07-28 03:33:00+03	90400.00
C674AC	2017-08-10 16:10:00+03	54500.00
C674C2	2017-07-24 22:43:00+03	22000.00
C674C4	2017-07-12 04:15:00+03	38600.00
C6755F	2017-07-07 14:56:00+03	77900.00
C67568	2017-07-23 12:28:00+03	57700.00
C675B9	2017-08-10 08:41:00+03	26000.00
C6763F	2017-07-27 13:47:00+03	55800.00
C6764E	2017-07-22 04:47:00+03	88700.00
C6764F	2017-07-28 00:26:00+03	67200.00
C67651	2017-08-07 19:29:00+03	111600.00
C67674	2017-07-05 22:48:00+03	17000.00
C6769A	2017-07-13 19:36:00+03	14400.00
C676C7	2017-07-04 03:35:00+03	24400.00
C676D8	2017-08-03 16:08:00+03	51600.00
C676EA	2017-07-27 22:50:00+03	48500.00
C67720	2017-07-17 00:58:00+03	72000.00
C67735	2017-08-04 12:32:00+03	47100.00
C6776D	2017-08-04 17:04:00+03	195500.00
C677E9	2017-08-14 07:22:00+03	32800.00
C67855	2017-07-13 01:38:00+03	12000.00
C67906	2017-07-14 11:41:00+03	32800.00
C67938	2017-07-18 21:51:00+03	67600.00
C67950	2017-07-29 05:19:00+03	28000.00
C6798B	2017-07-09 14:04:00+03	67000.00
C679B8	2017-07-24 01:46:00+03	67700.00
C679C7	2017-08-14 17:51:00+03	55800.00
C679E7	2017-07-17 19:03:00+03	36000.00
C67A80	2017-07-21 09:52:00+03	14000.00
C67AC6	2017-08-01 16:23:00+03	112000.00
C67AEC	2017-07-14 22:52:00+03	93600.00
C67B58	2017-07-01 17:36:00+03	133200.00
C67C14	2017-07-16 21:28:00+03	49800.00
C67C48	2017-06-30 21:13:00+03	12600.00
C67C57	2017-08-07 21:13:00+03	32700.00
C67CA5	2017-08-11 17:02:00+03	84500.00
C67CDF	2017-08-04 09:43:00+03	135600.00
C67CE7	2017-08-01 19:56:00+03	44700.00
C67D9A	2017-08-05 13:54:00+03	101200.00
C67DAD	2017-07-14 03:20:00+03	246000.00
C67E3B	2017-07-15 10:17:00+03	272000.00
C67F05	2017-08-11 23:03:00+03	177200.00
C67F10	2017-08-15 08:23:00+03	303200.00
C67F28	2017-06-26 03:52:00+03	57600.00
C67F5E	2017-07-24 12:16:00+03	75700.00
C67F65	2017-08-11 09:45:00+03	43900.00
C67F68	2017-07-15 04:43:00+03	21800.00
C67F6B	2017-07-30 21:59:00+03	31700.00
C67F95	2017-07-05 16:13:00+03	24800.00
C67FAE	2017-07-28 08:33:00+03	13800.00
C67FE9	2017-07-15 18:33:00+03	23200.00
C67FEA	2017-07-11 23:36:00+03	58200.00
C68005	2017-08-10 13:51:00+03	325500.00
C68081	2017-07-12 05:02:00+03	29600.00
C680E2	2017-08-09 19:56:00+03	28300.00
C68105	2017-08-14 07:23:00+03	87700.00
C68138	2017-07-06 02:37:00+03	727400.00
C6819D	2017-07-08 04:15:00+03	78800.00
C681A1	2017-07-30 18:36:00+03	56600.00
C68220	2017-07-15 06:35:00+03	37900.00
C68264	2017-07-07 06:55:00+03	20200.00
C68277	2017-08-14 09:04:00+03	62800.00
C68296	2017-07-13 17:50:00+03	112000.00
C6829F	2017-08-02 16:07:00+03	84100.00
C682C4	2017-08-02 09:03:00+03	38600.00
C68332	2017-07-13 15:45:00+03	45200.00
C68350	2017-07-06 22:00:00+03	38200.00
C68374	2017-07-29 02:24:00+03	17800.00
C683BD	2017-07-10 00:51:00+03	66600.00
C683E1	2017-07-04 12:47:00+03	72300.00
C683ED	2017-07-13 08:58:00+03	44600.00
C68413	2017-07-13 01:22:00+03	38600.00
C68456	2017-06-27 11:17:00+03	23100.00
C6847E	2017-07-06 05:28:00+03	101100.00
C685CE	2017-08-14 17:34:00+03	21800.00
C685D0	2017-07-10 20:00:00+03	166000.00
C68627	2017-07-05 04:04:00+03	88500.00
C68691	2017-07-29 06:14:00+03	98600.00
C686A1	2017-08-15 03:38:00+03	109200.00
C686A5	2017-06-30 03:07:00+03	11600.00
C686CF	2017-07-28 07:00:00+03	271400.00
C686E6	2017-07-02 22:44:00+03	119800.00
C68794	2017-08-03 23:37:00+03	102100.00
C687A6	2017-07-04 14:10:00+03	19600.00
C687BA	2017-07-23 15:26:00+03	117600.00
C687D1	2017-08-04 13:09:00+03	66600.00
C68839	2017-08-01 21:41:00+03	28700.00
C68889	2017-08-14 20:26:00+03	36200.00
C68894	2017-07-18 21:03:00+03	266200.00
C688D5	2017-08-02 10:49:00+03	225800.00
C689CA	2017-07-18 00:47:00+03	243700.00
C689F8	2017-07-08 06:14:00+03	6700.00
C68AC1	2017-07-28 10:21:00+03	209700.00
C68AC9	2017-08-04 15:29:00+03	246000.00
C68AE3	2017-07-12 22:38:00+03	132800.00
C68AF5	2017-07-13 23:12:00+03	406700.00
C68B37	2017-07-16 04:52:00+03	147700.00
C68B55	2017-07-08 17:18:00+03	25100.00
C68B62	2017-08-01 12:24:00+03	37200.00
C68B66	2017-07-24 04:50:00+03	208200.00
C68B86	2017-07-09 22:16:00+03	133200.00
C68B98	2017-08-02 13:49:00+03	48100.00
C68BBC	2017-07-20 02:55:00+03	8200.00
C68BDF	2017-08-15 16:35:00+03	54500.00
C68C1F	2017-07-14 10:21:00+03	27200.00
C68C32	2017-07-05 05:03:00+03	51800.00
C68C6D	2017-07-11 11:54:00+03	6700.00
C68C81	2017-07-30 23:22:00+03	25600.00
C68CBD	2017-07-12 13:23:00+03	10700.00
C68CC1	2017-07-19 15:37:00+03	28000.00
C68CE6	2017-07-25 05:31:00+03	147300.00
C68D22	2017-07-05 00:12:00+03	24200.00
C68E54	2017-08-06 07:41:00+03	40800.00
C68E6F	2017-07-03 21:56:00+03	121200.00
C68EAC	2017-07-16 09:35:00+03	103100.00
C68EE3	2017-08-01 10:38:00+03	54100.00
C68F35	2017-07-16 00:45:00+03	25400.00
C68F91	2017-07-31 23:33:00+03	23200.00
C68F9B	2017-07-10 09:27:00+03	86800.00
C68FAA	2017-07-22 15:07:00+03	46000.00
C68FDF	2017-07-23 14:46:00+03	81700.00
C68FEE	2017-07-16 18:37:00+03	53500.00
C69004	2017-07-23 11:47:00+03	46000.00
C6903B	2017-07-05 23:20:00+03	246000.00
C69055	2017-08-10 13:49:00+03	67500.00
C690C1	2017-08-06 03:54:00+03	94800.00
C690C7	2017-07-24 10:05:00+03	25800.00
C690E4	2017-07-21 14:30:00+03	28800.00
C69136	2017-07-27 21:53:00+03	161800.00
C69143	2017-08-11 01:01:00+03	32700.00
C6920B	2017-07-26 15:52:00+03	189200.00
C69210	2017-07-03 09:40:00+03	18600.00
C692FD	2017-07-13 14:57:00+03	94400.00
C69307	2017-08-04 12:11:00+03	67600.00
C6931D	2017-08-02 04:44:00+03	39500.00
C69352	2017-07-15 16:10:00+03	135400.00
C6936A	2017-08-11 11:32:00+03	361400.00
C6937A	2017-07-03 04:29:00+03	134200.00
C69393	2017-08-05 19:01:00+03	78800.00
C69406	2017-06-28 20:11:00+03	41400.00
C6940E	2017-06-23 15:15:00+03	126300.00
C6942D	2017-07-16 22:42:00+03	31400.00
C694D7	2017-07-09 18:47:00+03	14400.00
C6950D	2017-07-15 18:03:00+03	26700.00
C69559	2017-07-09 19:12:00+03	36600.00
C69571	2017-07-26 08:47:00+03	73500.00
C69576	2017-07-20 01:27:00+03	8200.00
C6957D	2017-07-29 08:34:00+03	62600.00
C69584	2017-08-04 04:48:00+03	93600.00
C69587	2017-07-09 14:52:00+03	48400.00
C6958B	2017-07-08 19:27:00+03	23600.00
C695CA	2017-08-10 22:46:00+03	14800.00
C695E1	2017-08-13 11:33:00+03	57600.00
C69604	2017-07-11 22:41:00+03	179200.00
C69663	2017-07-17 10:44:00+03	55800.00
C6969E	2017-08-12 13:13:00+03	6800.00
C696B6	2017-06-29 15:24:00+03	38400.00
C696B7	2017-08-06 23:17:00+03	89700.00
C697A5	2017-06-27 16:25:00+03	369000.00
C697C9	2017-07-08 23:15:00+03	31600.00
C6982F	2017-06-28 06:55:00+03	86800.00
C69843	2017-07-14 18:41:00+03	175300.00
C69845	2017-08-12 12:57:00+03	80000.00
C69847	2017-07-20 08:21:00+03	69500.00
C6988D	2017-07-29 20:39:00+03	123900.00
C698B1	2017-07-24 17:55:00+03	55800.00
C698B8	2017-08-15 01:45:00+03	23600.00
C698DB	2017-07-21 11:44:00+03	123700.00
C6992E	2017-07-04 20:18:00+03	54800.00
C6997E	2017-08-07 15:12:00+03	176900.00
C69982	2017-07-20 09:44:00+03	62600.00
C69989	2017-07-28 14:21:00+03	33300.00
C6999D	2017-07-19 09:35:00+03	189200.00
C69A04	2017-08-12 08:30:00+03	182300.00
C69A85	2017-07-29 15:37:00+03	75900.00
C69A87	2017-07-07 03:52:00+03	114800.00
C69AEE	2017-07-20 18:56:00+03	92000.00
C69AFA	2017-07-13 17:26:00+03	28800.00
C69B4E	2017-08-12 05:42:00+03	97900.00
C69B90	2017-07-16 02:33:00+03	53200.00
C69B92	2017-07-29 22:29:00+03	23200.00
C69CC4	2017-07-02 10:20:00+03	75500.00
C69CE0	2017-08-14 18:55:00+03	75300.00
C69CE8	2017-07-22 06:13:00+03	23200.00
C69CED	2017-07-13 19:50:00+03	43700.00
C69D10	2017-08-10 08:47:00+03	85000.00
C69D21	2017-08-11 23:41:00+03	46400.00
C69D2E	2017-07-15 08:20:00+03	68100.00
C69D3D	2017-07-25 13:09:00+03	47200.00
C69D45	2017-07-25 18:33:00+03	65500.00
C69D76	2017-07-31 05:48:00+03	106900.00
C69DB0	2017-07-31 17:36:00+03	39200.00
C69E24	2017-07-29 21:06:00+03	14800.00
C69E8B	2017-08-10 20:25:00+03	38400.00
C69F16	2017-08-10 16:18:00+03	103500.00
C69F5F	2017-07-26 03:03:00+03	46000.00
C69FD4	2017-07-31 14:49:00+03	71900.00
C69FF6	2017-07-25 09:41:00+03	51600.00
C6A035	2017-07-16 09:40:00+03	28000.00
C6A055	2017-07-09 06:56:00+03	123000.00
C6A075	2017-07-09 19:56:00+03	32800.00
C6A0AB	2017-08-05 20:49:00+03	59000.00
C6A0FD	2017-08-06 00:50:00+03	52600.00
C6A101	2017-07-07 06:39:00+03	45900.00
C6A105	2017-07-03 21:58:00+03	99200.00
C6A12D	2017-07-02 06:22:00+03	65900.00
C6A133	2017-07-15 22:54:00+03	41900.00
C6A141	2017-07-27 21:15:00+03	40000.00
C6A150	2017-07-16 22:52:00+03	28000.00
C6A1BE	2017-07-02 12:09:00+03	67600.00
C6A224	2017-08-10 01:23:00+03	72300.00
C6A22B	2017-07-11 02:28:00+03	55800.00
C6A243	2017-06-29 09:58:00+03	36200.00
C6A26F	2017-08-10 01:21:00+03	133600.00
C6A27E	2017-07-06 04:50:00+03	151200.00
C6A2E2	2017-07-05 01:20:00+03	100600.00
C6A2E6	2017-07-11 05:54:00+03	43800.00
C6A30A	2017-08-15 07:43:00+03	66800.00
C6A31D	2017-07-01 15:08:00+03	70700.00
C6A34A	2017-07-28 01:50:00+03	42100.00
C6A384	2017-08-07 15:46:00+03	56600.00
C6A398	2017-07-06 16:53:00+03	173500.00
C6A3DE	2017-07-08 15:46:00+03	40000.00
C6A405	2017-07-03 22:41:00+03	59800.00
C6A40C	2017-08-06 14:28:00+03	48800.00
C6A452	2017-08-09 11:22:00+03	135000.00
C6A47F	2017-07-22 10:12:00+03	26000.00
C6A49D	2017-08-07 19:53:00+03	26400.00
C6A4CD	2017-07-14 22:43:00+03	24400.00
C6A516	2017-07-17 00:14:00+03	98300.00
C6A532	2017-06-26 06:28:00+03	78400.00
C6A540	2017-07-25 13:08:00+03	266400.00
C6A546	2017-08-02 10:08:00+03	85400.00
C6A549	2017-08-09 15:09:00+03	15700.00
C6A56A	2017-06-30 09:59:00+03	69000.00
C6A586	2017-07-16 06:51:00+03	47100.00
C6A595	2017-08-08 09:39:00+03	55800.00
C6A5EF	2017-08-12 21:25:00+03	40400.00
C6A699	2017-07-02 03:17:00+03	26000.00
C6A69D	2017-07-24 23:57:00+03	274000.00
C6A6A0	2017-07-06 23:29:00+03	46000.00
C6A6DD	2017-07-15 23:28:00+03	22000.00
C6A6FE	2017-07-25 14:13:00+03	32800.00
C6A707	2017-07-11 21:06:00+03	6000.00
C6A70A	2017-07-30 10:48:00+03	56000.00
C6A722	2017-07-20 09:47:00+03	44800.00
C6A75A	2017-07-17 14:50:00+03	90800.00
C6A784	2017-08-11 13:39:00+03	10800.00
C6A7C0	2017-07-14 12:48:00+03	8200.00
C6A7DA	2017-07-07 06:42:00+03	81700.00
C6A8A4	2017-07-24 22:36:00+03	34800.00
C6A96A	2017-08-15 16:13:00+03	47100.00
C6A9E9	2017-07-06 14:14:00+03	77000.00
C6AADD	2017-08-06 18:03:00+03	65900.00
C6AB01	2017-08-09 03:33:00+03	133100.00
C6AB2A	2017-07-13 12:57:00+03	56000.00
C6AB32	2017-07-24 08:04:00+03	15000.00
C6AB63	2017-07-01 15:07:00+03	39300.00
C6AB68	2017-08-14 21:22:00+03	28000.00
C6AB9E	2017-07-13 19:05:00+03	16400.00
C6ABB2	2017-07-27 08:33:00+03	91500.00
C6ABCB	2017-08-05 16:10:00+03	28800.00
C6AC38	2017-07-31 15:43:00+03	113200.00
C6ACD1	2017-07-02 22:16:00+03	49100.00
C6AD4B	2017-07-20 00:31:00+03	23400.00
C6ADE4	2017-07-22 12:27:00+03	10800.00
C6AE42	2017-08-09 06:25:00+03	37200.00
C6AE49	2017-08-12 14:01:00+03	56100.00
C6AECC	2017-07-05 04:18:00+03	28000.00
C6AF21	2017-08-12 05:37:00+03	14000.00
C6AF23	2017-07-30 14:34:00+03	54600.00
C6AF96	2017-07-07 04:51:00+03	99300.00
C6B007	2017-07-26 23:01:00+03	26800.00
C6B03B	2017-07-11 04:24:00+03	121700.00
C6B074	2017-08-05 22:24:00+03	56000.00
C6B087	2017-07-25 15:45:00+03	6700.00
C6B0B4	2017-07-19 22:07:00+03	106900.00
C6B178	2017-07-13 18:18:00+03	6000.00
C6B1B6	2017-07-29 09:59:00+03	57600.00
C6B202	2017-08-08 05:13:00+03	24400.00
C6B279	2017-07-25 05:43:00+03	44700.00
C6B28B	2017-07-25 11:03:00+03	92600.00
C6B30F	2017-07-29 23:49:00+03	56600.00
C6B312	2017-06-30 19:07:00+03	190400.00
C6B331	2017-07-06 11:52:00+03	25900.00
C6B39C	2017-07-02 09:47:00+03	21600.00
C6B3A9	2017-07-13 07:38:00+03	122100.00
C6B3C3	2017-07-24 19:49:00+03	68800.00
C6B3D9	2017-07-17 07:19:00+03	26200.00
C6B407	2017-07-22 14:18:00+03	60000.00
C6B4A8	2017-07-22 06:44:00+03	29600.00
C6B4F9	2017-07-09 15:21:00+03	61700.00
C6B531	2017-08-10 10:48:00+03	66600.00
C6B550	2017-07-14 23:59:00+03	20000.00
C6B5B0	2017-08-13 04:06:00+03	37700.00
C6B61A	2017-07-10 08:39:00+03	135400.00
C6B62B	2017-07-24 08:07:00+03	52000.00
C6B69F	2017-08-09 04:18:00+03	18900.00
C6B6CD	2017-07-27 05:33:00+03	80300.00
C6B730	2017-07-30 22:02:00+03	30000.00
C6B753	2017-07-15 21:21:00+03	124200.00
C6B814	2017-06-29 17:43:00+03	29600.00
C6B830	2017-07-04 06:53:00+03	62600.00
C6B886	2017-07-18 20:17:00+03	58600.00
C6B89E	2017-07-10 11:19:00+03	31600.00
C6B8EF	2017-07-14 10:00:00+03	22000.00
C6B9DA	2017-07-02 23:21:00+03	22600.00
C6B9FC	2017-07-21 11:04:00+03	56200.00
C6BAB3	2017-07-29 17:43:00+03	67600.00
C6BAB4	2017-07-13 15:28:00+03	58800.00
C6BB2D	2017-07-31 13:36:00+03	83200.00
C6BB57	2017-07-14 08:56:00+03	43000.00
C6BC02	2017-07-05 05:47:00+03	124200.00
C6BC34	2017-08-09 01:58:00+03	47000.00
C6BC50	2017-07-05 00:27:00+03	136800.00
C6BC6E	2017-07-30 11:26:00+03	115000.00
C6BC95	2017-07-30 03:16:00+03	62900.00
C6BCBF	2017-07-19 22:25:00+03	67000.00
C6BCC5	2017-07-07 23:33:00+03	21000.00
C6BD0E	2017-07-30 07:08:00+03	30200.00
C6BD2B	2017-07-08 19:17:00+03	131600.00
C6BD69	2017-07-03 09:14:00+03	38300.00
C6BE22	2017-08-13 21:19:00+03	183600.00
C6BE3F	2017-08-13 18:56:00+03	6000.00
C6BE4E	2017-07-02 11:01:00+03	60800.00
C6BED8	2017-07-27 21:25:00+03	67200.00
C6BF38	2017-07-02 09:09:00+03	52300.00
C6BF4C	2017-07-25 00:33:00+03	52400.00
C6BF68	2017-08-06 08:20:00+03	73600.00
C6BF6A	2017-07-08 18:53:00+03	37900.00
C6BF87	2017-07-31 14:52:00+03	57500.00
C6BFBE	2017-07-31 01:17:00+03	140200.00
C6C002	2017-07-30 01:22:00+03	32700.00
C6C024	2017-07-23 16:11:00+03	90600.00
C6C0E4	2017-07-12 23:13:00+03	24400.00
C6C111	2017-07-30 09:08:00+03	46000.00
C6C132	2017-07-17 20:15:00+03	229300.00
C6C140	2017-07-25 00:25:00+03	46400.00
C6C1B5	2017-07-21 08:31:00+03	35600.00
C6C1B6	2017-07-24 09:43:00+03	58200.00
C6C1F3	2017-07-24 02:38:00+03	101500.00
C6C213	2017-07-23 17:41:00+03	136200.00
C6C21E	2017-07-26 14:05:00+03	27300.00
C6C248	2017-07-05 01:14:00+03	163000.00
C6C24E	2017-07-27 23:41:00+03	73500.00
C6C25F	2017-06-26 21:38:00+03	46400.00
C6C2B3	2017-07-11 02:13:00+03	92600.00
C6C340	2017-07-30 05:20:00+03	31200.00
C6C353	2017-07-26 14:39:00+03	34000.00
C6C364	2017-07-18 03:02:00+03	78300.00
C6C382	2017-08-07 14:50:00+03	66600.00
C6C3DF	2017-07-13 12:44:00+03	147900.00
C6C3E6	2017-06-29 20:27:00+03	123000.00
C6C3FA	2017-08-08 05:32:00+03	43500.00
C6C400	2017-08-12 21:33:00+03	99200.00
C6C41C	2017-07-08 13:51:00+03	29600.00
C6C44A	2017-07-18 06:01:00+03	74900.00
C6C4EC	2017-07-14 23:16:00+03	28800.00
C6C516	2017-07-03 08:59:00+03	101200.00
C6C598	2017-07-25 19:28:00+03	127300.00
C6C5B3	2017-08-01 15:40:00+03	20200.00
C6C60E	2017-07-02 12:28:00+03	61600.00
C6C662	2017-08-09 04:03:00+03	75600.00
C6C6E5	2017-08-02 12:12:00+03	23400.00
C6C736	2017-08-11 17:35:00+03	27500.00
C6C738	2017-07-14 02:46:00+03	56000.00
C6C740	2017-07-10 21:03:00+03	69200.00
C6C76C	2017-07-10 02:30:00+03	26800.00
C6C76F	2017-07-13 04:55:00+03	202800.00
C6C773	2017-07-29 03:55:00+03	293900.00
C6C781	2017-08-04 07:23:00+03	73500.00
C6C7E1	2017-08-07 05:15:00+03	32800.00
C6C806	2017-07-29 12:23:00+03	283100.00
C6C858	2017-07-05 05:24:00+03	96400.00
C6C8A8	2017-08-07 18:54:00+03	14000.00
C6C8D6	2017-07-30 13:20:00+03	22000.00
C6C8DB	2017-07-13 04:26:00+03	23400.00
C6C97C	2017-08-08 21:15:00+03	20400.00
C6C9D7	2017-07-24 19:22:00+03	18600.00
C6CA40	2017-07-17 16:12:00+03	242700.00
C6CAA2	2017-07-31 14:37:00+03	20000.00
C6CAAF	2017-07-17 12:59:00+03	56000.00
C6CAF4	2017-07-02 05:27:00+03	84500.00
C6CB26	2017-08-06 01:06:00+03	101900.00
C6CB4E	2017-06-28 15:35:00+03	73500.00
C6CB5B	2017-07-08 11:36:00+03	52000.00
C6CBC1	2017-07-16 04:44:00+03	14000.00
C6CBF5	2017-07-24 21:48:00+03	28800.00
C6CC09	2017-07-16 08:25:00+03	19600.00
C6CC6D	2017-07-31 17:36:00+03	32800.00
C6CC91	2017-08-06 08:17:00+03	272000.00
C6CCF1	2017-07-11 01:08:00+03	64200.00
C6CCF4	2017-06-30 00:57:00+03	30800.00
C6CD05	2017-07-03 09:18:00+03	114300.00
C6CD12	2017-08-05 01:55:00+03	34600.00
C6CD17	2017-07-21 05:41:00+03	133200.00
C6CD1F	2017-07-11 22:59:00+03	69600.00
C6CD20	2017-07-15 02:54:00+03	13700.00
C6CD77	2017-08-07 09:56:00+03	36700.00
C6CD8F	2017-07-12 10:32:00+03	91100.00
C6CDBA	2017-07-04 04:09:00+03	40000.00
C6CDF6	2017-07-29 01:46:00+03	28800.00
C6CE47	2017-08-05 10:38:00+03	58900.00
C6CE72	2017-07-07 03:34:00+03	205600.00
C6CEB6	2017-08-07 08:45:00+03	31600.00
C6CF20	2017-08-06 11:20:00+03	20200.00
C6CF44	2017-07-24 16:43:00+03	21400.00
C6CFA4	2017-08-09 14:07:00+03	24700.00
C6CFAE	2017-08-13 03:31:00+03	12600.00
C6D06A	2017-08-03 16:29:00+03	265800.00
C6D0D6	2017-07-25 19:24:00+03	168000.00
C6D0DA	2017-07-21 13:19:00+03	99200.00
C6D0E1	2017-07-10 05:33:00+03	27800.00
C6D129	2017-07-11 10:43:00+03	43900.00
C6D13A	2017-08-15 08:55:00+03	56600.00
C6D1F2	2017-07-14 00:50:00+03	28800.00
C6D357	2017-07-16 04:19:00+03	32700.00
C6D3CE	2017-07-16 08:42:00+03	144600.00
C6D3D4	2017-07-27 08:59:00+03	96800.00
C6D426	2017-07-27 20:19:00+03	37200.00
C6D42B	2017-07-11 14:04:00+03	8200.00
C6D44E	2017-08-14 14:19:00+03	135400.00
C6D488	2017-07-18 22:29:00+03	31300.00
C6D4D8	2017-07-08 19:04:00+03	13400.00
C6D52E	2017-07-15 23:16:00+03	59100.00
C6D539	2017-08-08 21:23:00+03	10700.00
C6D591	2017-07-11 14:19:00+03	260900.00
C6D60A	2017-08-08 23:55:00+03	69500.00
C6D62E	2017-08-15 13:06:00+03	117700.00
C6D6A8	2017-07-04 13:07:00+03	406200.00
C6D6D4	2017-07-14 03:42:00+03	39300.00
C6D6E8	2017-07-04 20:32:00+03	87200.00
C6D6EC	2017-08-05 16:49:00+03	52700.00
C6D72D	2017-07-14 09:59:00+03	182300.00
C6D7E7	2017-08-04 09:33:00+03	14400.00
C6D81D	2017-07-30 12:37:00+03	132700.00
C6D862	2017-07-24 08:39:00+03	170300.00
C6D879	2017-07-13 18:43:00+03	83600.00
C6D926	2017-07-25 09:57:00+03	65500.00
C6D98E	2017-08-12 06:51:00+03	43600.00
C6D9A5	2017-07-09 13:32:00+03	36800.00
C6D9BE	2017-08-08 13:29:00+03	76800.00
C6D9F7	2017-07-14 14:10:00+03	66600.00
C6D9FC	2017-07-27 02:55:00+03	300300.00
C6DA5B	2017-08-10 14:48:00+03	21400.00
C6DA66	2017-07-13 09:08:00+03	12400.00
C6DA81	2017-07-07 20:55:00+03	30200.00
C6DA96	2017-07-21 14:06:00+03	16400.00
C6DAE4	2017-08-14 03:00:00+03	26000.00
C6DB1F	2017-08-06 08:15:00+03	26600.00
C6DB44	2017-07-29 23:06:00+03	121400.00
C6DC1B	2017-07-27 10:26:00+03	14400.00
C6DC46	2017-07-14 06:13:00+03	406100.00
C6DC4F	2017-07-23 19:45:00+03	65900.00
C6DC5B	2017-07-24 21:14:00+03	111600.00
C6DC6C	2017-07-23 07:00:00+03	62600.00
C6DCCC	2017-08-08 08:43:00+03	21500.00
C6DCF2	2017-07-05 15:06:00+03	48800.00
C6DD57	2017-08-12 15:44:00+03	12600.00
C6DD95	2017-08-11 22:57:00+03	7400.00
C6DD98	2017-07-06 11:14:00+03	112500.00
C6DEAB	2017-08-11 05:25:00+03	77200.00
C6DEE8	2017-07-27 20:12:00+03	65200.00
C6DF69	2017-08-02 00:14:00+03	311100.00
C6DF77	2017-07-08 07:50:00+03	24300.00
C6DF9E	2017-08-02 03:38:00+03	56100.00
C6DFEA	2017-08-11 03:08:00+03	141900.00
C6DFEC	2017-07-16 09:30:00+03	23200.00
C6E049	2017-07-23 15:57:00+03	42800.00
C6E05D	2017-07-21 08:42:00+03	111900.00
C6E064	2017-08-03 23:13:00+03	60300.00
C6E066	2017-07-04 00:25:00+03	66000.00
C6E0A1	2017-07-08 02:31:00+03	30000.00
C6E0EE	2017-06-30 10:49:00+03	439600.00
C6E101	2017-07-18 06:25:00+03	240600.00
C6E10E	2017-08-14 11:58:00+03	52900.00
C6E11C	2017-07-03 07:46:00+03	83000.00
C6E15B	2017-07-19 11:59:00+03	24400.00
C6E192	2017-07-02 19:12:00+03	23200.00
C6E22C	2017-08-08 09:10:00+03	28000.00
C6E27E	2017-07-08 06:25:00+03	24400.00
C6E2CF	2017-08-13 00:24:00+03	25800.00
C6E38F	2017-07-28 09:05:00+03	115100.00
C6E3B9	2017-07-26 00:29:00+03	119800.00
C6E42E	2017-07-14 21:50:00+03	166900.00
C6E4D5	2017-07-03 08:50:00+03	38400.00
C6E4EC	2017-07-16 08:15:00+03	21400.00
C6E524	2017-07-18 22:14:00+03	40400.00
C6E553	2017-07-03 06:04:00+03	28700.00
C6E57C	2017-07-15 03:41:00+03	131600.00
C6E583	2017-07-02 00:18:00+03	132800.00
C6E5AA	2017-07-06 09:38:00+03	136600.00
C6E5B4	2017-07-15 05:06:00+03	56000.00
C6E5E7	2017-07-01 02:54:00+03	68900.00
C6E638	2017-08-04 02:18:00+03	23200.00
C6E63F	2017-08-04 09:59:00+03	41600.00
C6E641	2017-07-18 13:21:00+03	21400.00
C6E6A5	2017-07-28 17:53:00+03	147700.00
C6E6AF	2017-07-13 07:00:00+03	53100.00
C6E6B7	2017-08-14 12:02:00+03	52000.00
C6E7B0	2017-07-10 01:36:00+03	27900.00
C6E7E1	2017-08-11 18:29:00+03	53400.00
C6E7ED	2017-07-18 22:22:00+03	532800.00
C6E7F8	2017-07-20 19:36:00+03	30000.00
C6E81B	2017-07-09 18:36:00+03	32800.00
C6E870	2017-08-13 01:17:00+03	118200.00
C6E8CC	2017-08-10 00:54:00+03	28000.00
C6E8D7	2017-08-09 21:02:00+03	27900.00
C6E8F7	2017-08-07 14:07:00+03	32700.00
C6E94A	2017-08-14 13:58:00+03	63800.00
C6E978	2017-07-09 08:03:00+03	128800.00
C6EA33	2017-08-01 09:31:00+03	67200.00
C6EA53	2017-07-10 02:20:00+03	56900.00
C6EA6F	2017-08-04 15:39:00+03	44600.00
C6EA78	2017-08-07 04:22:00+03	49100.00
C6EAF8	2017-07-27 10:50:00+03	27800.00
C6EB28	2017-08-12 15:03:00+03	57400.00
C6EB62	2017-07-11 11:26:00+03	38400.00
C6EBAC	2017-08-04 11:58:00+03	234800.00
C6EBAD	2017-06-30 20:06:00+03	70800.00
C6ECD1	2017-08-01 14:31:00+03	65500.00
C6ECE4	2017-07-03 14:46:00+03	56100.00
C6ED3E	2017-08-11 12:09:00+03	68800.00
C6ED5E	2017-07-28 23:30:00+03	54800.00
C6EE6B	2017-08-08 20:59:00+03	37600.00
C6EE71	2017-07-04 12:32:00+03	100200.00
C6EE79	2017-07-25 03:54:00+03	47100.00
C6EED1	2017-07-12 16:08:00+03	47600.00
C6EED8	2017-07-21 14:42:00+03	26000.00
C6EEDB	2017-07-22 09:40:00+03	153200.00
C6EF4B	2017-07-11 11:17:00+03	46000.00
C6EF60	2017-07-25 23:12:00+03	49400.00
C6EF9C	2017-07-09 17:34:00+03	28800.00
C6EFFD	2017-07-25 21:36:00+03	28800.00
C6F059	2017-08-11 00:12:00+03	23200.00
C6F068	2017-08-06 13:21:00+03	48900.00
C6F0DF	2017-07-09 09:16:00+03	115100.00
C6F104	2017-07-28 19:09:00+03	23600.00
C6F108	2017-08-10 11:44:00+03	6300.00
C6F133	2017-07-31 12:27:00+03	65500.00
C6F17A	2017-08-11 02:37:00+03	173200.00
C6F1A9	2017-07-29 20:18:00+03	246000.00
C6F1BD	2017-07-28 07:43:00+03	49200.00
C6F1CC	2017-08-04 21:12:00+03	62000.00
C6F1D1	2017-08-13 00:53:00+03	55600.00
C6F1DD	2017-08-05 15:58:00+03	19600.00
C6F1E0	2017-08-08 21:31:00+03	114900.00
C6F1EB	2017-07-07 02:34:00+03	57600.00
C6F305	2017-07-06 11:48:00+03	156500.00
C6F3DE	2017-07-14 20:15:00+03	102100.00
C6F4F1	2017-07-30 08:31:00+03	118500.00
C6F53F	2017-08-14 14:08:00+03	195800.00
C6F543	2017-08-08 11:41:00+03	48500.00
C6F575	2017-07-17 22:21:00+03	24400.00
C6F58C	2017-08-07 17:47:00+03	13000.00
C6F635	2017-07-09 18:30:00+03	40800.00
C6F6A6	2017-07-15 15:29:00+03	58600.00
C6F6FE	2017-07-14 11:15:00+03	133200.00
C6F709	2017-08-02 12:00:00+03	54800.00
C6F757	2017-08-04 09:14:00+03	37200.00
C6F773	2017-07-19 18:07:00+03	13400.00
C6F7A9	2017-06-30 09:26:00+03	23200.00
C6F7BF	2017-07-24 11:57:00+03	36200.00
C6F7D6	2017-07-09 17:48:00+03	49100.00
C6F7DA	2017-07-01 07:41:00+03	120400.00
C6F7E7	2017-06-28 21:10:00+03	170000.00
C6F80E	2017-07-12 12:53:00+03	43200.00
C6F846	2017-08-03 12:19:00+03	25000.00
C6F864	2017-08-10 16:29:00+03	136500.00
C6F8D0	2017-08-03 07:11:00+03	148200.00
C6F947	2017-07-04 20:54:00+03	20800.00
C6FA29	2017-07-12 23:25:00+03	61800.00
C6FA4C	2017-08-06 11:38:00+03	159800.00
C6FA6A	2017-08-10 02:00:00+03	11700.00
C6FB8E	2017-07-17 21:19:00+03	70800.00
C6FBFB	2017-08-09 02:28:00+03	67100.00
C6FC11	2017-07-02 22:34:00+03	65600.00
C6FC3D	2017-08-04 10:45:00+03	29600.00
C6FC60	2017-07-02 11:18:00+03	46400.00
C6FC64	2017-08-03 09:33:00+03	53400.00
C6FC71	2017-08-01 09:38:00+03	28000.00
C6FC97	2017-08-12 09:26:00+03	30700.00
C6FCA7	2017-08-01 13:05:00+03	17600.00
C6FD13	2017-07-10 00:14:00+03	94700.00
C6FD71	2017-08-14 05:47:00+03	120100.00
C6FD87	2017-08-15 15:43:00+03	46400.00
C6FE29	2017-08-05 16:02:00+03	72400.00
C6FE34	2017-07-18 09:14:00+03	105800.00
C6FE7D	2017-07-02 18:13:00+03	27900.00
C6FEA6	2017-07-05 20:45:00+03	107800.00
C6FED7	2017-07-20 06:30:00+03	46400.00
C6FEE2	2017-07-18 05:47:00+03	56100.00
C6FF59	2017-07-27 17:47:00+03	23600.00
C6FF69	2017-07-21 17:24:00+03	68800.00
C6FF73	2017-07-19 09:19:00+03	44000.00
C6FFDB	2017-08-11 10:49:00+03	92800.00
C6FFE7	2017-07-20 03:25:00+03	66800.00
C6FFF2	2017-07-15 03:12:00+03	32400.00
C6FFFE	2017-08-03 00:58:00+03	73000.00
C7000E	2017-08-05 02:15:00+03	265700.00
C70010	2017-07-26 13:42:00+03	128800.00
C70109	2017-08-13 13:50:00+03	265600.00
C70155	2017-07-14 13:43:00+03	385300.00
C70175	2017-08-04 20:57:00+03	8400.00
C7018A	2017-07-02 04:35:00+03	22000.00
C701A9	2017-07-08 19:31:00+03	28000.00
C701AB	2017-07-09 23:18:00+03	38600.00
C701F1	2017-08-13 09:20:00+03	80000.00
C701F6	2017-07-15 11:04:00+03	130400.00
C7020C	2017-07-17 23:13:00+03	38600.00
C70222	2017-07-14 23:33:00+03	27200.00
C70329	2017-07-18 17:07:00+03	19000.00
C70353	2017-07-18 01:12:00+03	35200.00
C70354	2017-08-10 00:54:00+03	91800.00
C70376	2017-07-23 20:06:00+03	56200.00
C7037E	2017-07-17 22:47:00+03	78600.00
C70390	2017-07-13 01:39:00+03	139100.00
C70424	2017-07-04 14:49:00+03	34000.00
C70451	2017-07-20 01:54:00+03	40800.00
C70453	2017-07-11 14:39:00+03	50600.00
C7046B	2017-08-15 02:44:00+03	64800.00
C70530	2017-07-08 20:24:00+03	157400.00
C705E2	2017-07-11 15:13:00+03	81600.00
C70632	2017-08-12 08:59:00+03	21400.00
C7064D	2017-07-31 07:56:00+03	6600.00
C7065B	2017-07-28 04:45:00+03	49800.00
C7069A	2017-07-10 11:39:00+03	27200.00
C706D7	2017-08-06 10:17:00+03	46500.00
C706F1	2017-08-11 14:32:00+03	14000.00
C706F9	2017-07-11 07:16:00+03	28800.00
C70706	2017-07-02 18:48:00+03	190100.00
C7074C	2017-07-18 19:33:00+03	48800.00
C70761	2017-08-15 01:40:00+03	18300.00
C70767	2017-08-11 17:11:00+03	35900.00
C70814	2017-08-03 21:23:00+03	160700.00
C7081E	2017-08-01 06:31:00+03	74800.00
C70853	2017-07-27 01:00:00+03	135000.00
C70962	2017-08-14 09:21:00+03	33200.00
C709BA	2017-07-28 09:45:00+03	38800.00
C70AA6	2017-07-31 13:45:00+03	46300.00
C70AA8	2017-07-06 22:24:00+03	205100.00
C70AD7	2017-08-09 00:38:00+03	21400.00
C70B6F	2017-07-10 03:02:00+03	32400.00
C70B7C	2017-07-21 18:35:00+03	50400.00
C70B9C	2017-08-04 06:28:00+03	54800.00
C70B9F	2017-07-02 17:58:00+03	44800.00
C70BCE	2017-07-27 07:42:00+03	16400.00
C70BEB	2017-08-08 11:36:00+03	67600.00
C70C75	2017-07-02 10:34:00+03	23200.00
C70C8C	2017-07-09 01:03:00+03	136200.00
C70CB2	2017-07-08 06:17:00+03	28800.00
C70CDF	2017-08-06 21:06:00+03	290600.00
C70CFC	2017-07-03 14:42:00+03	79000.00
C70D15	2017-08-04 09:02:00+03	92800.00
C70D24	2017-07-14 04:45:00+03	19600.00
C70D2A	2017-08-12 17:06:00+03	44800.00
C70DCB	2017-07-15 19:59:00+03	102100.00
C70DEA	2017-07-22 07:52:00+03	12400.00
C70E34	2017-08-14 14:05:00+03	45100.00
C70E45	2017-08-04 04:38:00+03	111600.00
C70EA7	2017-07-30 03:19:00+03	134400.00
C70F20	2017-08-03 17:42:00+03	70700.00
C70F93	2017-07-11 23:33:00+03	48800.00
C70FC9	2017-07-14 00:57:00+03	28800.00
C7101A	2017-07-22 21:46:00+03	40400.00
C71023	2017-07-03 23:48:00+03	55800.00
C7105D	2017-07-16 16:11:00+03	64200.00
C710FA	2017-08-01 15:28:00+03	12600.00
C71111	2017-08-14 10:09:00+03	39100.00
C7113A	2017-08-03 23:17:00+03	22100.00
C7114C	2017-07-21 20:07:00+03	83500.00
C711A4	2017-08-13 13:58:00+03	85000.00
C711B4	2017-07-13 16:19:00+03	87400.00
C71220	2017-07-30 18:31:00+03	86300.00
C71231	2017-07-16 22:13:00+03	21400.00
C712FB	2017-07-24 06:32:00+03	116900.00
C7135E	2017-08-09 21:49:00+03	81300.00
C7136B	2017-08-03 23:41:00+03	25800.00
C7143D	2017-07-14 04:42:00+03	40800.00
C71456	2017-08-15 04:27:00+03	37300.00
C71512	2017-07-08 18:09:00+03	72200.00
C7151F	2017-07-29 18:39:00+03	69600.00
C71558	2017-07-27 14:51:00+03	153300.00
C715C5	2017-08-01 18:02:00+03	58800.00
C7160F	2017-08-14 05:51:00+03	56000.00
C7161F	2017-07-31 05:18:00+03	39300.00
C716BC	2017-07-04 13:04:00+03	6300.00
C7172E	2017-07-03 22:25:00+03	81700.00
C7173B	2017-06-29 01:28:00+03	52800.00
C71751	2017-07-28 19:29:00+03	81300.00
C71773	2017-08-07 12:18:00+03	23400.00
C717B6	2017-07-19 19:19:00+03	19600.00
C717CF	2017-08-11 04:09:00+03	25000.00
C71800	2017-07-17 23:57:00+03	21800.00
C71821	2017-08-02 11:36:00+03	43100.00
C71822	2017-08-03 07:04:00+03	138300.00
C7182C	2017-07-27 04:00:00+03	23200.00
C71837	2017-07-13 05:48:00+03	133200.00
C7187D	2017-08-09 08:19:00+03	92800.00
C718D4	2017-08-13 10:14:00+03	30000.00
C71929	2017-07-23 23:13:00+03	55800.00
C71936	2017-08-15 14:49:00+03	135400.00
C71974	2017-07-11 03:19:00+03	13400.00
C7197A	2017-08-10 14:24:00+03	12000.00
C7198D	2017-07-31 22:33:00+03	93400.00
C71997	2017-07-17 15:35:00+03	41800.00
C719E5	2017-07-03 18:50:00+03	246000.00
C719FF	2017-07-21 16:55:00+03	131100.00
C71A45	2017-07-21 16:15:00+03	117400.00
C71A49	2017-08-02 06:07:00+03	138000.00
C71A54	2017-07-09 05:27:00+03	27200.00
C71ACB	2017-08-07 23:53:00+03	57500.00
C71B34	2017-07-21 12:26:00+03	82900.00
C71B4C	2017-07-24 03:35:00+03	41400.00
C71BF3	2017-07-15 21:13:00+03	76600.00
C71C01	2017-08-11 09:13:00+03	26200.00
C71C24	2017-07-25 13:24:00+03	166000.00
C71C84	2017-08-08 14:07:00+03	43200.00
C71C85	2017-08-03 16:51:00+03	397700.00
C71C98	2017-07-28 15:15:00+03	29600.00
C71C9C	2017-07-17 09:38:00+03	12400.00
C71D32	2017-07-17 06:59:00+03	31100.00
C71D74	2017-07-10 18:28:00+03	88600.00
C71E84	2017-07-11 17:41:00+03	62700.00
C71ED9	2017-07-23 05:49:00+03	134400.00
C71EF2	2017-08-07 20:10:00+03	172000.00
C71F5F	2017-07-03 19:14:00+03	133200.00
C72013	2017-07-04 23:25:00+03	28200.00
C7205A	2017-07-14 01:23:00+03	139200.00
C72068	2017-07-22 02:57:00+03	67100.00
C720B0	2017-08-11 00:15:00+03	68000.00
C720BC	2017-07-17 18:19:00+03	25200.00
C72119	2017-07-30 16:09:00+03	6300.00
C7214C	2017-08-11 05:34:00+03	11800.00
C721F1	2017-06-30 19:05:00+03	68100.00
C721F6	2017-08-04 09:44:00+03	189200.00
C72258	2017-07-02 19:35:00+03	26000.00
C722A7	2017-08-02 08:40:00+03	287300.00
C722BC	2017-07-27 17:49:00+03	55800.00
C72374	2017-07-22 02:39:00+03	48500.00
C723F0	2017-08-04 18:39:00+03	169300.00
C723F1	2017-07-29 15:42:00+03	58000.00
C72459	2017-07-06 02:40:00+03	70100.00
C724CE	2017-08-09 18:23:00+03	664200.00
C72517	2017-08-10 16:54:00+03	55800.00
C72550	2017-07-24 18:01:00+03	46400.00
C72554	2017-07-17 17:59:00+03	154500.00
C72581	2017-07-27 15:44:00+03	62000.00
C72588	2017-07-30 12:58:00+03	40800.00
C7258F	2017-08-14 00:59:00+03	51900.00
C72591	2017-08-14 16:13:00+03	201200.00
C725E1	2017-07-14 12:54:00+03	42400.00
C725F6	2017-07-01 19:28:00+03	128100.00
C72634	2017-08-09 18:03:00+03	42800.00
C726B6	2017-07-18 17:04:00+03	56100.00
C726C7	2017-07-09 16:49:00+03	44600.00
C726E9	2017-07-14 05:46:00+03	79900.00
C7276E	2017-06-30 04:48:00+03	40400.00
C72771	2017-07-14 19:24:00+03	19800.00
C727BC	2017-08-03 07:01:00+03	258400.00
C72837	2017-08-03 16:59:00+03	27200.00
C72870	2017-07-16 20:24:00+03	70600.00
C72895	2017-07-19 01:12:00+03	94700.00
C72914	2017-08-15 04:58:00+03	29000.00
C72949	2017-07-23 22:34:00+03	58000.00
C7294D	2017-07-24 02:43:00+03	9200.00
C72982	2017-07-19 03:37:00+03	22000.00
C729AE	2017-07-17 14:19:00+03	62800.00
C729F6	2017-08-09 15:14:00+03	21800.00
C729F8	2017-07-29 05:57:00+03	42700.00
C72A51	2017-08-13 11:04:00+03	56000.00
C72A89	2017-07-15 15:29:00+03	29600.00
C72B09	2017-07-21 23:23:00+03	132800.00
C72B5D	2017-07-22 18:02:00+03	55800.00
C72BC5	2017-07-24 00:43:00+03	20100.00
C72C33	2017-08-01 23:07:00+03	47200.00
C72C3A	2017-08-05 21:59:00+03	123000.00
C72C84	2017-07-30 02:57:00+03	38900.00
C72C8B	2017-07-10 06:32:00+03	54800.00
C72CA2	2017-07-02 10:01:00+03	46200.00
C72CB5	2017-07-14 23:43:00+03	24800.00
C72CD1	2017-07-27 14:54:00+03	7400.00
C72CF6	2017-08-02 14:56:00+03	40400.00
C72D7C	2017-08-11 04:08:00+03	872900.00
C72DBE	2017-07-28 07:44:00+03	135400.00
C72DEC	2017-08-01 04:53:00+03	57600.00
C72E75	2017-06-30 16:07:00+03	40400.00
C72E8E	2017-07-05 06:50:00+03	6700.00
C72E90	2017-06-30 17:42:00+03	18000.00
C72E9C	2017-07-28 00:25:00+03	87900.00
C72EB0	2017-07-07 14:23:00+03	193000.00
C72EB6	2017-07-09 17:03:00+03	126300.00
C72EC9	2017-08-06 08:05:00+03	13000.00
C72F55	2017-07-02 09:32:00+03	134700.00
C7303D	2017-07-11 03:09:00+03	59800.00
C7307F	2017-07-25 02:47:00+03	57400.00
C73098	2017-07-23 03:12:00+03	43200.00
C730B2	2017-08-03 13:27:00+03	3700.00
C73156	2017-07-20 13:24:00+03	23200.00
C7316A	2017-08-15 09:19:00+03	43600.00
C731C5	2017-07-11 09:14:00+03	36200.00
C731D4	2017-08-03 02:54:00+03	31600.00
C731E4	2017-07-15 19:45:00+03	38400.00
C731EA	2017-07-13 07:14:00+03	15000.00
C7322A	2017-08-15 09:46:00+03	54800.00
C7324B	2017-07-31 13:23:00+03	26700.00
C73366	2017-06-27 10:13:00+03	131800.00
C7336C	2017-07-09 13:25:00+03	79500.00
C733EE	2017-07-27 14:17:00+03	295400.00
C73406	2017-07-30 14:08:00+03	257600.00
C73407	2017-07-06 08:17:00+03	37200.00
C73430	2017-07-27 07:18:00+03	115800.00
C73432	2017-08-11 00:22:00+03	40800.00
C73465	2017-07-10 12:52:00+03	23600.00
C734A4	2017-07-22 19:06:00+03	136800.00
C734D1	2017-07-15 00:08:00+03	59200.00
C735E2	2017-08-06 19:00:00+03	25200.00
C735EE	2017-08-09 04:29:00+03	34000.00
C73678	2017-07-06 04:42:00+03	25800.00
C736D9	2017-08-06 23:13:00+03	73600.00
C736DB	2017-07-27 17:06:00+03	258400.00
C737A6	2017-08-08 22:59:00+03	118300.00
C737BB	2017-07-08 23:48:00+03	34200.00
C737F2	2017-08-08 09:04:00+03	35000.00
C7381D	2017-08-09 18:20:00+03	134700.00
C7384A	2017-08-12 17:14:00+03	26800.00
C7385F	2017-07-27 20:01:00+03	28800.00
C73873	2017-07-24 10:48:00+03	40600.00
C73895	2017-08-09 01:58:00+03	35800.00
C73903	2017-07-19 15:36:00+03	16400.00
C7393B	2017-07-29 16:43:00+03	36800.00
C73941	2017-07-27 08:04:00+03	128800.00
C7394A	2017-08-11 04:49:00+03	29300.00
C73951	2017-07-15 03:18:00+03	41400.00
C73976	2017-07-11 04:25:00+03	58800.00
C739BA	2017-07-15 12:47:00+03	36200.00
C739C8	2017-07-01 19:53:00+03	40300.00
C73A4D	2017-07-07 05:11:00+03	93700.00
C73AD4	2017-08-14 18:13:00+03	131600.00
C73B2F	2017-07-28 20:33:00+03	26800.00
C73B83	2017-07-22 03:07:00+03	48800.00
C73B84	2017-08-04 11:09:00+03	213200.00
C73BB7	2017-07-12 20:57:00+03	26300.00
C73BB9	2017-08-02 09:29:00+03	21800.00
C73BDC	2017-07-09 23:38:00+03	25000.00
C73C73	2017-07-27 19:37:00+03	42400.00
C73CAC	2017-07-01 14:45:00+03	44000.00
C73CFA	2017-07-03 21:41:00+03	21400.00
C73D28	2017-07-04 09:36:00+03	85000.00
C73D4A	2017-07-12 20:22:00+03	31600.00
C73D98	2017-07-22 06:24:00+03	34200.00
C73DA6	2017-08-04 12:06:00+03	128800.00
C73E0C	2017-07-28 10:34:00+03	80000.00
C73E64	2017-07-05 06:58:00+03	89400.00
C73E71	2017-08-01 12:49:00+03	60400.00
C73EB3	2017-06-30 21:59:00+03	273000.00
C73EF1	2017-07-11 15:45:00+03	124300.00
C73F2A	2017-08-08 01:10:00+03	113200.00
C73F66	2017-07-10 10:55:00+03	46500.00
C73F6D	2017-07-14 08:00:00+03	188000.00
C73FAC	2017-07-09 07:26:00+03	55800.00
C740C7	2017-08-02 09:00:00+03	86300.00
C740CD	2017-07-17 05:25:00+03	14000.00
C7412C	2017-07-09 11:32:00+03	28800.00
C7413E	2017-07-15 14:51:00+03	114300.00
C74141	2017-07-09 21:33:00+03	136800.00
C74166	2017-07-18 14:59:00+03	46000.00
C74190	2017-08-14 20:43:00+03	32700.00
C741C8	2017-06-29 10:42:00+03	33500.00
C741CC	2017-07-08 01:00:00+03	111600.00
C741CE	2017-06-30 17:29:00+03	349100.00
C7420B	2017-07-31 00:56:00+03	116800.00
C7424C	2017-07-17 10:50:00+03	56200.00
C74270	2017-07-30 04:29:00+03	24400.00
C7427E	2017-07-02 20:55:00+03	193500.00
C74288	2017-07-16 13:02:00+03	46400.00
C74312	2017-07-23 06:19:00+03	24400.00
C74320	2017-08-09 08:55:00+03	34000.00
C7432D	2017-07-14 11:19:00+03	44600.00
C74354	2017-07-18 11:23:00+03	47700.00
C7435F	2017-07-08 13:46:00+03	101800.00
C74387	2017-07-07 17:38:00+03	70200.00
C7439B	2017-07-25 17:31:00+03	61800.00
C74426	2017-08-12 00:31:00+03	73500.00
C74439	2017-08-07 11:38:00+03	83200.00
C74453	2017-07-21 04:52:00+03	19600.00
C7449A	2017-08-09 09:19:00+03	138500.00
C74542	2017-07-25 14:12:00+03	65600.00
C7456F	2017-07-28 22:57:00+03	23200.00
C74590	2017-07-13 15:08:00+03	42600.00
C745A7	2017-08-03 17:55:00+03	11700.00
C74634	2017-08-07 03:18:00+03	85000.00
C7473B	2017-08-02 01:43:00+03	79900.00
C747E5	2017-07-01 22:09:00+03	6700.00
C74834	2017-07-04 15:57:00+03	6300.00
C74924	2017-07-26 05:21:00+03	58800.00
C74942	2017-08-08 16:23:00+03	25600.00
C7495F	2017-07-23 06:32:00+03	170700.00
C74981	2017-08-11 15:50:00+03	73200.00
C749D3	2017-07-15 21:37:00+03	21200.00
C749D7	2017-08-11 10:15:00+03	39500.00
C74A23	2017-08-13 04:41:00+03	46000.00
C74A57	2017-08-05 13:20:00+03	70600.00
C74A88	2017-07-11 02:55:00+03	88000.00
C74AB2	2017-07-05 18:53:00+03	69500.00
C74AE1	2017-07-15 03:28:00+03	36200.00
C74BBD	2017-07-06 00:16:00+03	106900.00
C74BDC	2017-07-18 11:08:00+03	47100.00
C74BE7	2017-07-11 18:51:00+03	166100.00
C74BF2	2017-07-10 17:33:00+03	144400.00
C74C07	2017-08-07 04:21:00+03	25000.00
C74C3F	2017-08-01 06:47:00+03	291000.00
C74C43	2017-07-06 03:16:00+03	57700.00
C74C54	2017-08-07 18:22:00+03	34600.00
C74C9D	2017-07-24 19:58:00+03	25600.00
C74CC9	2017-07-14 14:24:00+03	40800.00
C74CFB	2017-06-30 20:27:00+03	58400.00
C74D56	2017-08-01 10:22:00+03	53600.00
C74D57	2017-08-13 07:28:00+03	101200.00
C74DD2	2017-08-03 01:07:00+03	22600.00
C74E4C	2017-08-03 01:33:00+03	22400.00
C74E81	2017-07-31 20:05:00+03	42000.00
C74E92	2017-07-11 18:18:00+03	99200.00
C74E9C	2017-07-16 16:06:00+03	88300.00
C74EAA	2017-07-20 17:19:00+03	58200.00
C74F0D	2017-07-03 09:38:00+03	38600.00
C74F14	2017-08-04 19:47:00+03	3400.00
C74F43	2017-08-12 22:05:00+03	75600.00
C74F45	2017-07-24 09:19:00+03	21400.00
C74F8D	2017-07-18 03:42:00+03	68800.00
C74F9C	2017-07-11 21:54:00+03	306600.00
C74FED	2017-08-07 11:58:00+03	6700.00
C74FF4	2017-08-09 08:13:00+03	100700.00
C75060	2017-07-20 06:00:00+03	97900.00
C75070	2017-07-08 22:10:00+03	25600.00
C75079	2017-07-23 21:54:00+03	28800.00
C75155	2017-07-21 11:50:00+03	28000.00
C7518C	2017-07-30 17:25:00+03	34000.00
C7519C	2017-07-22 13:14:00+03	65600.00
C751D7	2017-08-11 12:25:00+03	28800.00
C75240	2017-07-22 13:44:00+03	77900.00
C75291	2017-06-29 10:19:00+03	56000.00
C752D5	2017-08-14 10:15:00+03	6700.00
C7531F	2017-08-04 19:32:00+03	139300.00
C75339	2017-07-25 00:03:00+03	19600.00
C7534A	2017-07-15 04:14:00+03	8400.00
C75492	2017-07-09 22:38:00+03	26000.00
C754BE	2017-08-13 22:05:00+03	260300.00
C754DE	2017-07-17 15:56:00+03	10600.00
C754F0	2017-08-11 05:20:00+03	83600.00
C7550F	2017-07-08 12:03:00+03	50800.00
C75592	2017-07-15 07:34:00+03	55800.00
C7559C	2017-08-02 21:14:00+03	26700.00
C75645	2017-08-02 18:37:00+03	34000.00
C75686	2017-07-08 06:54:00+03	55800.00
C756B1	2017-07-17 17:39:00+03	70800.00
C756D0	2017-08-13 12:53:00+03	75600.00
C756EE	2017-08-13 05:46:00+03	56600.00
C756F9	2017-07-16 01:07:00+03	8000.00
C7570D	2017-08-07 23:21:00+03	81600.00
C75788	2017-07-16 16:53:00+03	103500.00
C7579D	2017-07-24 10:10:00+03	48500.00
C757C6	2017-07-20 05:39:00+03	69500.00
C75888	2017-07-05 06:39:00+03	79600.00
C758DA	2017-07-27 08:45:00+03	25100.00
C758E0	2017-07-10 12:39:00+03	60700.00
C75924	2017-07-06 11:04:00+03	46000.00
C75982	2017-08-08 14:21:00+03	36000.00
C7598B	2017-07-28 20:58:00+03	58800.00
C75994	2017-07-04 12:16:00+03	170200.00
C7599A	2017-07-26 01:22:00+03	36800.00
C75A32	2017-08-12 16:59:00+03	111600.00
C75B08	2017-07-15 17:28:00+03	24700.00
C75B14	2017-08-13 10:11:00+03	251900.00
C75B95	2017-07-02 22:06:00+03	119700.00
C75BC6	2017-07-23 13:34:00+03	83000.00
C75BDE	2017-07-05 12:42:00+03	109800.00
C75C1B	2017-07-24 14:30:00+03	46000.00
C75C30	2017-08-12 19:10:00+03	27300.00
C75C31	2017-07-15 21:13:00+03	113300.00
C75C4A	2017-07-27 21:44:00+03	64800.00
C75C97	2017-07-05 06:41:00+03	26000.00
C75CA1	2017-07-18 11:26:00+03	49700.00
C75CE8	2017-08-15 01:54:00+03	43400.00
C75D02	2017-07-18 07:00:00+03	44600.00
C75D11	2017-07-11 10:18:00+03	372500.00
C75D56	2017-07-13 02:52:00+03	92800.00
C75D81	2017-07-28 20:36:00+03	29400.00
C75ED6	2017-07-20 17:12:00+03	16100.00
C75F0A	2017-07-03 05:22:00+03	42400.00
C75F1A	2017-08-09 02:30:00+03	186900.00
C75F23	2017-07-23 16:55:00+03	36800.00
C75F2F	2017-07-27 12:18:00+03	10600.00
C75F31	2017-07-31 01:19:00+03	19600.00
C76073	2017-07-19 07:57:00+03	48800.00
C76078	2017-07-31 14:08:00+03	56000.00
C76132	2017-07-15 20:28:00+03	60200.00
C7615E	2017-07-11 20:14:00+03	6900.00
C761F3	2017-07-08 03:50:00+03	52800.00
C761FE	2017-07-22 01:29:00+03	105000.00
C7634E	2017-08-12 00:42:00+03	26000.00
C763CB	2017-07-04 17:43:00+03	6000.00
C76412	2017-07-23 13:05:00+03	23200.00
C764AA	2017-08-14 06:49:00+03	131100.00
C764AC	2017-08-04 03:08:00+03	124200.00
C76556	2017-08-07 14:50:00+03	27800.00
C765A7	2017-08-06 13:29:00+03	38600.00
C765B5	2017-08-05 07:49:00+03	76800.00
C765B8	2017-07-10 21:42:00+03	36900.00
C765C3	2017-08-06 16:47:00+03	122000.00
C7661D	2017-07-06 09:57:00+03	38600.00
C76676	2017-07-19 23:25:00+03	22600.00
C76681	2017-07-04 14:10:00+03	22600.00
C76684	2017-07-28 08:34:00+03	56000.00
C766D4	2017-07-14 12:19:00+03	111600.00
C766DB	2017-07-05 18:34:00+03	27400.00
C76720	2017-07-22 03:01:00+03	169900.00
C76754	2017-07-06 13:13:00+03	94300.00
C76774	2017-07-22 15:27:00+03	89600.00
C76779	2017-06-28 01:54:00+03	175900.00
C7679C	2017-07-05 00:49:00+03	46400.00
C767AB	2017-06-27 04:22:00+03	38800.00
C76802	2017-07-31 10:49:00+03	27200.00
C76882	2017-07-23 18:52:00+03	26800.00
C76890	2017-08-08 16:04:00+03	46400.00
C768CB	2017-07-04 19:57:00+03	25600.00
C768D4	2017-08-14 01:30:00+03	38400.00
C768EA	2017-07-28 10:30:00+03	52300.00
C76918	2017-07-30 00:33:00+03	114400.00
C76996	2017-07-04 20:16:00+03	14900.00
C769D1	2017-07-07 05:09:00+03	6700.00
C76A13	2017-07-28 05:43:00+03	58200.00
C76A26	2017-07-16 02:53:00+03	19600.00
C76A45	2017-07-12 20:58:00+03	208800.00
C76B6A	2017-08-03 21:59:00+03	265700.00
C76B86	2017-07-14 16:40:00+03	244600.00
C76BB5	2017-07-12 19:33:00+03	46500.00
C76BC0	2017-08-10 10:59:00+03	133100.00
C76BCB	2017-07-12 07:34:00+03	24700.00
C76CA4	2017-07-15 07:04:00+03	8200.00
C76CF3	2017-07-06 15:35:00+03	34600.00
C76D07	2017-07-14 08:32:00+03	64700.00
C76DFE	2017-07-12 22:57:00+03	34400.00
C76E98	2017-08-02 20:52:00+03	67200.00
C76F3D	2017-07-24 07:55:00+03	52700.00
C76FB8	2017-07-11 06:26:00+03	6300.00
C7703A	2017-07-19 12:33:00+03	113700.00
C77047	2017-08-12 18:45:00+03	16400.00
C77144	2017-07-06 16:53:00+03	21800.00
C771D9	2017-08-05 05:44:00+03	25800.00
C77235	2017-07-09 15:30:00+03	57600.00
C77243	2017-07-05 23:05:00+03	44600.00
C7727C	2017-07-20 23:47:00+03	42700.00
C772A3	2017-07-03 02:23:00+03	93900.00
C772C7	2017-08-06 17:09:00+03	34100.00
C772E4	2017-06-27 21:24:00+03	106400.00
C7730D	2017-07-05 20:13:00+03	23600.00
C77350	2017-08-10 15:06:00+03	46400.00
C773EA	2017-08-07 22:43:00+03	32800.00
C77436	2017-06-28 05:30:00+03	129000.00
C7743A	2017-08-14 19:51:00+03	102100.00
C774A2	2017-07-09 03:22:00+03	45200.00
C774C8	2017-07-03 12:56:00+03	60800.00
C77587	2017-07-21 02:47:00+03	144400.00
C77592	2017-08-06 20:17:00+03	92400.00
C775EE	2017-08-13 01:20:00+03	154100.00
C775EF	2017-07-24 20:50:00+03	22000.00
C7766B	2017-07-01 12:28:00+03	198600.00
C77691	2017-07-28 03:40:00+03	332100.00
C776A5	2017-07-08 04:34:00+03	58800.00
C776A8	2017-08-11 19:28:00+03	6000.00
C776B9	2017-07-04 12:40:00+03	391000.00
C77703	2017-07-26 01:13:00+03	69600.00
C77733	2017-08-15 13:58:00+03	106300.00
C77808	2017-08-06 17:03:00+03	56100.00
C77828	2017-07-07 10:43:00+03	146300.00
C7782F	2017-07-17 00:20:00+03	204500.00
C77848	2017-08-11 17:11:00+03	70800.00
C7785F	2017-07-15 05:41:00+03	123000.00
C7789E	2017-07-11 11:35:00+03	108500.00
C77928	2017-08-13 03:43:00+03	96200.00
C7792D	2017-07-29 02:25:00+03	23100.00
C77937	2017-07-31 17:43:00+03	26000.00
C77942	2017-07-17 02:45:00+03	271400.00
C77A83	2017-07-14 15:41:00+03	46900.00
C77AF0	2017-08-10 22:43:00+03	67200.00
C77B64	2017-07-21 21:57:00+03	28800.00
C77B77	2017-08-09 21:57:00+03	17000.00
C77BD7	2017-07-18 18:20:00+03	55800.00
C77C3A	2017-07-25 19:16:00+03	257600.00
C77C84	2017-07-25 05:49:00+03	15000.00
C77C8F	2017-07-08 17:25:00+03	8000.00
C77C94	2017-08-02 03:50:00+03	75600.00
C77CE0	2017-07-26 07:34:00+03	147000.00
C77D21	2017-08-09 00:34:00+03	103600.00
C77D30	2017-08-08 03:13:00+03	22000.00
C77D33	2017-07-04 12:47:00+03	53800.00
C77D77	2017-07-08 08:53:00+03	100900.00
C77D95	2017-07-13 12:00:00+03	86600.00
C77D96	2017-07-04 20:29:00+03	187600.00
C77DB2	2017-07-17 04:10:00+03	50800.00
C77DB3	2017-07-22 00:53:00+03	56000.00
C77DD1	2017-07-16 10:08:00+03	136600.00
C77DE7	2017-07-08 11:12:00+03	58600.00
C77E09	2017-08-12 15:38:00+03	128800.00
C77F89	2017-07-04 11:07:00+03	26800.00
C77F99	2017-08-12 13:49:00+03	46000.00
C77F9F	2017-07-05 15:43:00+03	21800.00
C77FA2	2017-07-11 04:43:00+03	45500.00
C77FB6	2017-07-03 04:25:00+03	101200.00
C77FD7	2017-07-30 03:49:00+03	40800.00
C77FDF	2017-07-31 14:39:00+03	130100.00
C77FEE	2017-07-15 12:55:00+03	134800.00
C78042	2017-07-18 20:53:00+03	23200.00
C78089	2017-08-14 23:47:00+03	28800.00
C78150	2017-08-02 01:20:00+03	55800.00
C7815E	2017-08-01 10:50:00+03	23200.00
C7817C	2017-07-02 10:29:00+03	151200.00
C781B5	2017-08-08 02:40:00+03	43900.00
C781C9	2017-07-14 17:56:00+03	36200.00
C7821E	2017-07-16 01:48:00+03	18800.00
C7825E	2017-07-30 04:11:00+03	79300.00
C78289	2017-07-11 22:40:00+03	155600.00
C782AD	2017-07-22 15:36:00+03	22000.00
C78341	2017-08-14 06:32:00+03	68800.00
C7835F	2017-07-08 09:25:00+03	31600.00
C7836B	2017-08-15 16:10:00+03	31100.00
C783DA	2017-08-14 02:41:00+03	185600.00
C7851E	2017-08-12 08:01:00+03	26100.00
C78564	2017-07-11 04:27:00+03	100600.00
C7859A	2017-08-07 11:27:00+03	78600.00
C785F1	2017-08-11 17:37:00+03	33100.00
C78611	2017-07-19 20:19:00+03	109000.00
C7863D	2017-08-03 02:30:00+03	111600.00
C7865F	2017-07-05 15:58:00+03	94800.00
C78676	2017-07-20 19:11:00+03	120400.00
C78698	2017-07-02 20:31:00+03	26000.00
C7869E	2017-07-17 22:09:00+03	61800.00
C786BF	2017-07-06 17:26:00+03	54800.00
C786EC	2017-07-27 19:03:00+03	281100.00
C78701	2017-07-25 03:38:00+03	35600.00
C787AB	2017-08-12 13:36:00+03	113300.00
C787BB	2017-08-12 13:49:00+03	20400.00
C787FD	2017-07-30 15:50:00+03	77900.00
C78851	2017-07-25 02:42:00+03	7400.00
C7888D	2017-07-19 18:14:00+03	112000.00
C788AD	2017-08-13 17:05:00+03	28800.00
C788CC	2017-07-28 08:57:00+03	70800.00
C788FA	2017-07-18 00:07:00+03	27200.00
C78902	2017-08-10 17:40:00+03	68800.00
C78909	2017-08-09 00:43:00+03	38000.00
C78914	2017-07-10 21:15:00+03	67600.00
C789C3	2017-07-22 06:01:00+03	44000.00
C78A17	2017-08-12 00:31:00+03	27800.00
C78A1D	2017-08-03 18:44:00+03	28800.00
C78A1F	2017-08-06 08:23:00+03	99200.00
C78A20	2017-08-04 13:38:00+03	23400.00
C78A26	2017-07-03 09:11:00+03	22400.00
C78A40	2017-08-04 09:00:00+03	62500.00
C78A43	2017-08-09 01:21:00+03	71900.00
C78A54	2017-08-08 21:29:00+03	35700.00
C78A64	2017-07-23 11:43:00+03	46500.00
C78A76	2017-07-13 21:23:00+03	81600.00
C78A83	2017-08-13 03:38:00+03	139800.00
C78A89	2017-08-04 07:28:00+03	146700.00
C78AFC	2017-07-08 07:17:00+03	86300.00
C78B26	2017-07-09 01:25:00+03	35600.00
C78B33	2017-08-15 11:06:00+03	56000.00
C78B3F	2017-08-11 01:24:00+03	73600.00
C78B7B	2017-08-09 10:19:00+03	66600.00
C78B91	2017-07-08 16:33:00+03	49100.00
C78BA4	2017-06-29 17:00:00+03	103500.00
C78BC7	2017-08-01 23:35:00+03	28800.00
C78BE7	2017-07-16 23:53:00+03	168000.00
C78BE8	2017-08-06 11:40:00+03	136800.00
C78C44	2017-07-28 16:46:00+03	260300.00
C78C60	2017-08-06 22:22:00+03	116000.00
C78C70	2017-08-14 16:46:00+03	169500.00
C78CF0	2017-07-20 04:31:00+03	26000.00
C78D33	2017-07-21 20:43:00+03	133200.00
C78D5F	2017-07-19 10:23:00+03	46400.00
C78D85	2017-07-29 02:16:00+03	92800.00
C78DBE	2017-07-27 18:12:00+03	15400.00
C78DDC	2017-07-16 05:46:00+03	81200.00
C78E0B	2017-07-10 06:09:00+03	24700.00
C78E9F	2017-07-25 04:24:00+03	85000.00
C78EE3	2017-08-06 01:33:00+03	38800.00
C78EE5	2017-07-23 13:31:00+03	265700.00
C78EF1	2017-07-16 15:10:00+03	190400.00
C78F16	2017-07-23 15:43:00+03	271200.00
C78F99	2017-08-15 11:26:00+03	68100.00
C79002	2017-07-03 04:01:00+03	55800.00
C79030	2017-08-06 09:30:00+03	169900.00
C7903C	2017-07-29 16:46:00+03	56000.00
C79068	2017-08-06 02:40:00+03	47600.00
C7906D	2017-07-19 22:23:00+03	10300.00
C79094	2017-07-30 19:50:00+03	83000.00
C790AB	2017-07-05 09:16:00+03	67600.00
C791BA	2017-07-25 17:10:00+03	14000.00
C791D3	2017-08-14 14:16:00+03	21800.00
C792A7	2017-07-04 08:17:00+03	36200.00
C792BF	2017-07-15 14:16:00+03	10600.00
C7934B	2017-08-10 16:15:00+03	90400.00
C79401	2017-07-21 13:57:00+03	64700.00
C79438	2017-07-17 22:45:00+03	32800.00
C79450	2017-07-16 03:23:00+03	24400.00
C79487	2017-07-09 19:08:00+03	38400.00
C794CF	2017-08-09 05:48:00+03	91000.00
C79518	2017-07-12 21:56:00+03	59800.00
C795FE	2017-08-13 23:45:00+03	34000.00
C796F3	2017-07-05 15:01:00+03	76300.00
C79732	2017-08-12 22:26:00+03	136200.00
C7976B	2017-07-01 21:18:00+03	69500.00
C79782	2017-08-05 07:11:00+03	133200.00
C79799	2017-08-06 22:13:00+03	52700.00
C798E8	2017-08-01 01:22:00+03	26800.00
C79901	2017-08-13 08:16:00+03	198900.00
C79963	2017-07-23 11:56:00+03	137600.00
C799B4	2017-07-13 14:34:00+03	7400.00
C79A10	2017-08-12 01:06:00+03	56800.00
C79A36	2017-08-08 01:50:00+03	52000.00
C79A90	2017-07-12 13:11:00+03	81300.00
C79AB3	2017-07-04 15:56:00+03	199600.00
C79B21	2017-07-18 01:56:00+03	189800.00
C79B42	2017-07-17 16:51:00+03	80200.00
C79C72	2017-08-13 13:20:00+03	23500.00
C79C9D	2017-08-15 06:18:00+03	67600.00
C79CDB	2017-07-24 15:09:00+03	50600.00
C79D12	2017-07-10 01:25:00+03	71200.00
C79D56	2017-08-02 03:25:00+03	31000.00
C79D67	2017-07-08 23:19:00+03	281500.00
C79D7B	2017-07-19 10:24:00+03	70500.00
C79D89	2017-07-03 09:34:00+03	246000.00
C79DA4	2017-07-14 09:37:00+03	21800.00
C79DAA	2017-07-11 20:11:00+03	16400.00
C79DC5	2017-07-02 10:02:00+03	141500.00
C79DFC	2017-08-06 17:44:00+03	56000.00
C79E46	2017-07-30 01:51:00+03	6700.00
C79E67	2017-07-29 12:48:00+03	89600.00
C79EB4	2017-07-15 20:21:00+03	401700.00
C79EFD	2017-07-06 13:04:00+03	189200.00
C79F62	2017-08-13 20:23:00+03	37900.00
C79FA2	2017-08-08 12:47:00+03	278400.00
C79FC1	2017-08-09 11:47:00+03	85000.00
C79FD3	2017-08-08 15:59:00+03	52700.00
C7A054	2017-08-14 06:27:00+03	312600.00
C7A0CD	2017-07-31 04:52:00+03	10800.00
C7A162	2017-08-15 11:32:00+03	41400.00
C7A1F0	2017-08-11 20:24:00+03	32200.00
C7A223	2017-08-08 19:39:00+03	65900.00
C7A282	2017-07-15 15:44:00+03	82000.00
C7A354	2017-07-28 10:02:00+03	96800.00
C7A3AA	2017-08-04 15:30:00+03	51900.00
C7A405	2017-08-12 20:15:00+03	8200.00
C7A411	2017-07-11 03:08:00+03	34200.00
C7A417	2017-07-19 23:04:00+03	14900.00
C7A451	2017-07-06 23:42:00+03	51800.00
C7A46C	2017-07-14 06:02:00+03	7400.00
C7A481	2017-07-24 06:36:00+03	54500.00
C7A4B4	2017-08-12 02:42:00+03	58600.00
C7A4E6	2017-08-14 08:31:00+03	138100.00
C7A4F5	2017-08-14 20:06:00+03	132800.00
C7A520	2017-07-20 00:54:00+03	56000.00
C7A557	2017-07-13 22:10:00+03	45200.00
C7A588	2017-06-29 05:32:00+03	47700.00
C7A599	2017-07-15 19:01:00+03	67700.00
C7A59E	2017-08-08 00:02:00+03	24000.00
C7A5A4	2017-08-02 08:50:00+03	64800.00
C7A5AD	2017-07-19 12:36:00+03	12600.00
C7A5DD	2017-07-05 17:02:00+03	40100.00
C7A5F4	2017-07-17 02:24:00+03	61800.00
C7A5F5	2017-08-02 19:02:00+03	192400.00
C7A690	2017-08-06 06:25:00+03	15000.00
C7A6C6	2017-08-13 15:20:00+03	132200.00
C7A6E7	2017-07-16 15:30:00+03	20200.00
C7A6EE	2017-07-31 14:15:00+03	109800.00
C7A711	2017-06-30 09:45:00+03	25400.00
C7A71C	2017-08-12 14:54:00+03	123000.00
C7A71F	2017-07-19 12:57:00+03	14000.00
C7A78D	2017-07-15 03:24:00+03	63500.00
C7A79D	2017-07-04 04:03:00+03	55800.00
C7A7E4	2017-07-01 16:51:00+03	50700.00
C7A7E9	2017-07-28 21:55:00+03	45200.00
C7A889	2017-08-09 16:46:00+03	31400.00
C7A8A7	2017-07-23 10:25:00+03	27500.00
C7A8AE	2017-07-19 14:28:00+03	160800.00
C7A8C0	2017-07-06 11:17:00+03	28800.00
C7A96D	2017-08-09 16:04:00+03	26000.00
C7A9BE	2017-06-30 21:23:00+03	84500.00
C7A9D7	2017-07-20 22:16:00+03	47000.00
C7A9E0	2017-08-09 10:11:00+03	8000.00
C7AA58	2017-07-18 09:53:00+03	87000.00
C7AA59	2017-08-14 18:25:00+03	37100.00
C7AABE	2017-07-14 17:47:00+03	62600.00
C7AB11	2017-07-19 11:57:00+03	22000.00
C7ABF8	2017-08-07 17:52:00+03	32900.00
C7ABFF	2017-07-10 15:19:00+03	12400.00
C7AC8E	2017-08-10 21:49:00+03	56600.00
C7ACAF	2017-08-10 15:20:00+03	52300.00
C7ACB1	2017-08-14 11:43:00+03	40100.00
C7ACBA	2017-08-03 06:56:00+03	57800.00
C7ACFE	2017-07-12 10:57:00+03	94000.00
C7AD40	2017-07-09 13:53:00+03	13400.00
C7AD68	2017-07-05 01:38:00+03	34600.00
C7ADAD	2017-07-11 18:56:00+03	47100.00
C7AE08	2017-07-12 09:27:00+03	8000.00
C7AE29	2017-08-08 23:15:00+03	26000.00
C7AEB3	2017-07-16 02:18:00+03	26800.00
C7AEC1	2017-07-01 00:17:00+03	65900.00
C7AEC6	2017-08-04 09:44:00+03	15000.00
C7AECE	2017-07-02 01:19:00+03	29000.00
C7AEE9	2017-07-31 03:39:00+03	40600.00
C7AF01	2017-08-09 20:25:00+03	151700.00
C7AF0C	2017-08-10 22:47:00+03	81700.00
C7AF19	2017-08-07 05:06:00+03	67200.00
C7AF50	2017-08-10 22:45:00+03	260300.00
C7AFDF	2017-08-05 15:29:00+03	21600.00
C7B00F	2017-07-02 19:49:00+03	50600.00
C7B01A	2017-07-06 03:21:00+03	46000.00
C7B07F	2017-08-11 15:34:00+03	102800.00
C7B086	2017-08-11 00:52:00+03	156600.00
C7B205	2017-08-11 15:04:00+03	54800.00
C7B268	2017-07-24 07:05:00+03	59800.00
C7B37D	2017-07-21 18:22:00+03	47000.00
C7B3DA	2017-07-25 02:16:00+03	137900.00
C7B402	2017-07-02 21:10:00+03	132300.00
C7B412	2017-08-05 09:10:00+03	88000.00
C7B477	2017-07-25 18:21:00+03	27300.00
C7B4C4	2017-07-09 11:01:00+03	50800.00
C7B521	2017-07-23 06:05:00+03	56000.00
C7B528	2017-08-14 12:03:00+03	81600.00
C7B548	2017-08-08 21:32:00+03	28000.00
C7B553	2017-08-05 13:31:00+03	233800.00
C7B580	2017-07-21 16:51:00+03	272700.00
C7B634	2017-08-02 20:09:00+03	85600.00
C7B679	2017-08-10 10:54:00+03	19600.00
C7B67C	2017-07-14 03:10:00+03	29600.00
C7B685	2017-07-06 05:16:00+03	28800.00
C7B6AF	2017-07-31 08:15:00+03	54500.00
C7B6C6	2017-07-15 15:47:00+03	191200.00
C7B75D	2017-07-03 14:30:00+03	77900.00
C7B774	2017-07-13 08:02:00+03	31600.00
C7B78C	2017-07-04 12:06:00+03	28000.00
C7B794	2017-07-16 16:29:00+03	25400.00
C7B79A	2017-08-11 04:54:00+03	190700.00
C7B7B7	2017-06-29 07:58:00+03	56000.00
C7B809	2017-07-27 05:00:00+03	35600.00
C7B80F	2017-07-05 16:02:00+03	8200.00
C7B86B	2017-07-27 16:42:00+03	43000.00
C7B8BC	2017-08-01 17:57:00+03	134200.00
C7B8D2	2017-08-02 09:14:00+03	52700.00
C7B8D4	2017-07-23 13:09:00+03	198400.00
C7B8D8	2017-07-31 11:30:00+03	248400.00
C7B999	2017-07-28 17:02:00+03	29800.00
C7B9CB	2017-07-24 13:52:00+03	23200.00
C7B9F7	2017-07-29 02:12:00+03	241300.00
C7BA87	2017-08-13 16:46:00+03	32200.00
C7BAA2	2017-07-04 10:08:00+03	86400.00
C7BB4C	2017-07-27 22:46:00+03	135400.00
C7BB55	2017-07-08 11:15:00+03	30000.00
C7BBBF	2017-07-26 19:07:00+03	43000.00
C7BC74	2017-07-14 12:38:00+03	35600.00
C7BCB1	2017-07-19 00:55:00+03	22000.00
C7BCC1	2017-07-19 04:28:00+03	39600.00
C7BCD3	2017-07-03 10:49:00+03	161100.00
C7BCF6	2017-07-07 23:19:00+03	59800.00
C7BD2F	2017-08-04 02:34:00+03	141600.00
C7BD30	2017-08-14 15:23:00+03	78500.00
C7BD44	2017-08-02 18:37:00+03	147100.00
C7BDE3	2017-07-25 08:50:00+03	24600.00
C7BE01	2017-07-23 16:47:00+03	25800.00
C7BE4B	2017-07-16 11:10:00+03	70700.00
C7BEB4	2017-07-30 17:46:00+03	72800.00
C7BEDF	2017-08-10 16:36:00+03	109000.00
C7BF02	2017-08-14 00:38:00+03	54400.00
C7BF2E	2017-07-07 22:56:00+03	46200.00
C7BFA6	2017-08-07 01:02:00+03	49700.00
C7C000	2017-07-18 23:28:00+03	56200.00
C7C00D	2017-07-07 23:34:00+03	53400.00
C7C025	2017-07-28 19:26:00+03	68000.00
C7C048	2017-07-26 13:21:00+03	16400.00
C7C07B	2017-08-14 13:18:00+03	16400.00
C7C0A6	2017-07-16 07:11:00+03	52300.00
C7C0C5	2017-07-19 20:58:00+03	52000.00
C7C10E	2017-08-08 13:02:00+03	26000.00
C7C123	2017-08-08 15:36:00+03	55800.00
C7C259	2017-07-20 19:12:00+03	20200.00
C7C283	2017-08-10 04:17:00+03	39300.00
C7C298	2017-08-05 15:01:00+03	240600.00
C7C2C3	2017-07-09 18:09:00+03	203400.00
C7C38A	2017-07-30 20:30:00+03	57500.00
C7C38B	2017-07-01 02:55:00+03	21400.00
C7C3FF	2017-07-29 13:45:00+03	65900.00
C7C423	2017-07-01 18:03:00+03	20200.00
C7C47E	2017-07-17 15:53:00+03	58200.00
C7C4EE	2017-07-15 00:57:00+03	21800.00
C7C500	2017-07-13 01:05:00+03	77500.00
C7C51A	2017-07-02 11:46:00+03	66800.00
C7C598	2017-07-24 09:50:00+03	11600.00
C7C5DD	2017-07-26 13:29:00+03	77100.00
C7C5ED	2017-08-13 19:27:00+03	23200.00
C7C633	2017-07-07 06:27:00+03	112000.00
C7C680	2017-07-05 18:33:00+03	154300.00
C7C69A	2017-08-14 06:44:00+03	57500.00
C7C708	2017-07-03 14:20:00+03	24600.00
C7C715	2017-08-04 05:39:00+03	46000.00
C7C728	2017-07-06 23:45:00+03	101500.00
C7C74C	2017-08-09 04:10:00+03	66100.00
C7C7AC	2017-07-12 03:05:00+03	28800.00
C7C81A	2017-07-14 16:43:00+03	62600.00
C7C865	2017-07-23 18:35:00+03	26200.00
C7C8EA	2017-07-12 17:15:00+03	133700.00
C7C8EF	2017-07-10 19:10:00+03	26000.00
C7C90A	2017-07-01 07:09:00+03	46300.00
C7C964	2017-07-29 10:36:00+03	28000.00
C7C99A	2017-07-06 06:23:00+03	100600.00
C7CA0B	2017-07-10 09:31:00+03	52700.00
C7CA26	2017-07-25 06:48:00+03	36700.00
C7CA3E	2017-07-26 18:04:00+03	24800.00
C7CA4F	2017-08-01 15:06:00+03	53600.00
C7CA94	2017-07-31 06:37:00+03	113600.00
C7CB19	2017-07-24 13:20:00+03	8000.00
C7CB2B	2017-08-08 16:42:00+03	20200.00
C7CB53	2017-08-12 02:59:00+03	26000.00
C7CB86	2017-08-07 21:32:00+03	50400.00
C7CBA7	2017-08-12 06:59:00+03	42800.00
C7CC49	2017-07-28 13:05:00+03	45400.00
C7CC88	2017-08-02 03:30:00+03	136200.00
C7CCB9	2017-07-19 19:36:00+03	302600.00
C7CCF6	2017-07-28 20:26:00+03	131100.00
C7CD53	2017-07-27 22:34:00+03	69400.00
C7CD80	2017-07-24 18:39:00+03	67200.00
C7CDA9	2017-07-31 07:36:00+03	28000.00
C7CDE9	2017-07-01 18:35:00+03	28000.00
C7CE24	2017-08-11 14:25:00+03	20800.00
C7CE3F	2017-07-30 13:44:00+03	39300.00
C7CE43	2017-07-13 00:18:00+03	40000.00
C7CEA9	2017-07-28 16:41:00+03	69600.00
C7CF98	2017-08-11 14:02:00+03	130800.00
C7CFCF	2017-07-31 06:28:00+03	51600.00
C7CFE1	2017-08-12 04:43:00+03	66600.00
C7CFFC	2017-08-04 12:24:00+03	28800.00
C7D01C	2017-07-13 14:29:00+03	16400.00
C7D02F	2017-07-07 06:13:00+03	56100.00
C7D045	2017-08-07 23:23:00+03	57500.00
C7D0C0	2017-08-14 18:10:00+03	96800.00
C7D0C2	2017-08-04 03:13:00+03	169900.00
C7D0D4	2017-08-12 05:48:00+03	27800.00
C7D175	2017-07-15 13:50:00+03	16400.00
C7D176	2017-07-11 14:48:00+03	4000.00
C7D1AC	2017-07-26 11:54:00+03	23100.00
C7D1B1	2017-07-27 09:53:00+03	82900.00
C7D1C1	2017-07-10 10:12:00+03	66600.00
C7D1DF	2017-08-13 06:30:00+03	23600.00
C7D201	2017-08-13 05:14:00+03	13400.00
C7D291	2017-07-18 02:06:00+03	146300.00
C7D2C8	2017-08-06 06:58:00+03	43600.00
C7D2D6	2017-07-31 23:37:00+03	410200.00
C7D2DD	2017-08-12 09:00:00+03	18600.00
C7D2EC	2017-07-01 06:22:00+03	81700.00
C7D305	2017-07-14 17:51:00+03	202600.00
C7D3AE	2017-07-04 17:19:00+03	95200.00
C7D3EB	2017-08-12 07:42:00+03	26700.00
C7D401	2017-07-13 02:25:00+03	84800.00
C7D420	2017-07-16 13:14:00+03	148300.00
C7D462	2017-08-11 06:38:00+03	103400.00
C7D463	2017-07-18 05:04:00+03	40100.00
C7D4E7	2017-07-03 08:35:00+03	31600.00
C7D50D	2017-07-28 15:14:00+03	41800.00
C7D538	2017-08-02 23:02:00+03	58200.00
C7D5CD	2017-07-06 16:06:00+03	32400.00
C7D642	2017-07-16 02:41:00+03	75600.00
C7D669	2017-07-07 07:35:00+03	82900.00
C7D66A	2017-08-08 01:49:00+03	21800.00
C7D711	2017-07-28 02:25:00+03	24700.00
C7D782	2017-07-21 08:11:00+03	27900.00
C7D79D	2017-08-01 14:35:00+03	6700.00
C7D7A2	2017-07-28 12:37:00+03	19800.00
C7D7E3	2017-07-13 00:28:00+03	119600.00
C7D837	2017-08-13 20:21:00+03	81600.00
C7D887	2017-08-03 23:31:00+03	62600.00
C7D8B9	2017-08-13 23:41:00+03	99200.00
C7D8E7	2017-07-09 19:53:00+03	37000.00
C7D924	2017-07-11 03:47:00+03	288600.00
C7D930	2017-07-23 00:33:00+03	14000.00
C7D954	2017-07-29 03:28:00+03	31600.00
C7D974	2017-07-03 05:36:00+03	246000.00
C7D9F5	2017-07-12 02:43:00+03	54500.00
C7D9F6	2017-07-19 04:11:00+03	254100.00
C7DA95	2017-07-28 20:42:00+03	62400.00
C7DABB	2017-08-10 20:57:00+03	12000.00
C7DAD4	2017-07-16 15:09:00+03	91600.00
C7DB47	2017-06-30 21:32:00+03	123000.00
C7DB89	2017-07-02 23:42:00+03	48300.00
C7DBA1	2017-07-10 19:55:00+03	103600.00
C7DBA8	2017-07-11 09:20:00+03	15000.00
C7DBB3	2017-07-06 13:45:00+03	71500.00
C7DBBE	2017-07-09 12:30:00+03	6800.00
C7DBCD	2017-08-05 17:31:00+03	23200.00
C7DBE2	2017-07-18 09:04:00+03	40800.00
C7DC24	2017-07-10 13:21:00+03	32800.00
C7DC2C	2017-07-07 15:59:00+03	56600.00
C7DC9C	2017-08-01 08:47:00+03	12600.00
C7DCAD	2017-08-11 04:00:00+03	112000.00
C7DCAF	2017-07-24 10:51:00+03	58900.00
C7DCD0	2017-07-12 14:12:00+03	131100.00
C7DD61	2017-07-12 20:19:00+03	181200.00
C7DDA6	2017-08-04 17:18:00+03	22000.00
C7DE29	2017-07-27 05:44:00+03	81500.00
C7DE6B	2017-07-14 18:58:00+03	95200.00
C7DE93	2017-07-04 15:44:00+03	42800.00
C7DE99	2017-07-09 19:59:00+03	12600.00
C7DEA3	2017-07-14 06:06:00+03	28800.00
C7DF14	2017-07-09 18:07:00+03	48500.00
C7DF4D	2017-07-27 20:49:00+03	48800.00
C7DF82	2017-07-09 14:10:00+03	123000.00
C7DFCD	2017-07-12 23:50:00+03	51800.00
C7E05E	2017-07-15 01:41:00+03	54000.00
C7E06C	2017-07-14 12:58:00+03	119500.00
C7E06E	2017-08-14 03:39:00+03	170000.00
C7E075	2017-07-12 23:35:00+03	36200.00
C7E0F1	2017-07-18 05:28:00+03	103800.00
C7E14D	2017-08-10 17:42:00+03	16400.00
C7E19A	2017-08-09 15:41:00+03	278600.00
C7E1DE	2017-08-15 01:17:00+03	271100.00
C7E208	2017-07-26 05:58:00+03	52400.00
C7E21F	2017-07-28 01:46:00+03	112000.00
C7E230	2017-07-18 01:35:00+03	18800.00
C7E244	2017-07-09 05:39:00+03	40100.00
C7E29B	2017-07-20 14:40:00+03	41200.00
C7E2BA	2017-07-08 18:35:00+03	46400.00
C7E3A3	2017-08-10 20:20:00+03	14800.00
C7E3E7	2017-07-26 05:14:00+03	140100.00
C7E403	2017-07-30 04:35:00+03	24400.00
C7E54F	2017-07-29 17:06:00+03	40800.00
C7E55B	2017-07-22 16:45:00+03	47200.00
C7E591	2017-07-30 03:22:00+03	100600.00
C7E5BC	2017-07-23 10:51:00+03	72400.00
C7E65E	2017-08-05 11:46:00+03	26000.00
C7E68D	2017-07-28 22:28:00+03	129200.00
C7E6CA	2017-08-01 09:07:00+03	56000.00
C7E6CF	2017-07-04 09:45:00+03	38300.00
C7E6F0	2017-08-13 07:14:00+03	104600.00
C7E73D	2017-07-26 23:33:00+03	39200.00
C7E741	2017-07-31 15:57:00+03	169900.00
C7E7B5	2017-08-08 05:57:00+03	98600.00
C7E7B6	2017-08-14 02:24:00+03	28800.00
C7E7DC	2017-07-23 08:44:00+03	21800.00
C7E7FC	2017-07-22 05:12:00+03	144400.00
C7E815	2017-07-08 02:26:00+03	22000.00
C7E843	2017-06-30 22:16:00+03	26000.00
C7E868	2017-07-08 12:43:00+03	99300.00
C7E876	2017-07-01 17:40:00+03	11200.00
C7E8FE	2017-08-15 08:38:00+03	13400.00
C7E901	2017-08-11 20:34:00+03	94700.00
C7E961	2017-08-14 15:31:00+03	26000.00
C7E997	2017-07-18 20:22:00+03	127300.00
C7E9F4	2017-08-03 12:52:00+03	152400.00
C7EA02	2017-07-05 12:27:00+03	59400.00
C7EA0A	2017-07-09 09:37:00+03	62600.00
C7EA4C	2017-07-07 15:38:00+03	58500.00
C7EA53	2017-07-04 02:36:00+03	44800.00
C7EACC	2017-08-04 04:14:00+03	52900.00
C7EADA	2017-07-10 17:09:00+03	111600.00
C7EB26	2017-07-14 04:53:00+03	45200.00
C7EB2A	2017-08-08 19:27:00+03	6800.00
C7EB79	2017-08-14 03:24:00+03	32700.00
C7EC0F	2017-08-07 10:56:00+03	168000.00
C7EC67	2017-08-08 20:02:00+03	65900.00
C7EC74	2017-07-11 09:17:00+03	61500.00
C7ED25	2017-07-03 03:45:00+03	25600.00
C7ED51	2017-07-25 01:11:00+03	70500.00
C7ED6E	2017-08-05 16:38:00+03	23200.00
C7ED73	2017-07-09 05:33:00+03	24600.00
C7ED74	2017-07-04 10:47:00+03	115700.00
C7ED87	2017-08-04 05:39:00+03	43800.00
C7EDAD	2017-07-24 19:49:00+03	207200.00
C7EDB8	2017-07-19 07:07:00+03	36200.00
C7EDBF	2017-07-15 21:46:00+03	28800.00
C7EDEE	2017-07-24 00:05:00+03	133100.00
C7EE94	2017-07-06 08:40:00+03	37900.00
C7EE98	2017-07-17 12:47:00+03	32600.00
C7EED5	2017-07-31 09:46:00+03	51900.00
C7EF04	2017-07-14 02:11:00+03	36200.00
C7EF9A	2017-07-08 12:11:00+03	13400.00
C7EFF8	2017-07-19 02:42:00+03	67000.00
C7F00C	2017-08-12 20:33:00+03	26000.00
C7F046	2017-07-25 05:59:00+03	26700.00
C7F0B1	2017-07-10 01:29:00+03	19500.00
C7F0B7	2017-08-06 08:43:00+03	46000.00
C7F0C4	2017-07-30 11:42:00+03	55800.00
C7F0C6	2017-08-04 19:15:00+03	63400.00
C7F0F1	2017-07-13 09:11:00+03	18800.00
C7F0F2	2017-07-12 01:21:00+03	47100.00
C7F117	2017-07-01 19:47:00+03	94000.00
C7F165	2017-06-30 05:49:00+03	55800.00
C7F166	2017-08-07 11:22:00+03	67600.00
C7F226	2017-08-09 01:08:00+03	73300.00
C7F35F	2017-07-06 18:37:00+03	55800.00
C7F37E	2017-07-26 19:18:00+03	45200.00
C7F3AE	2017-07-25 23:02:00+03	21400.00
C7F3B8	2017-07-15 08:37:00+03	145300.00
C7F3BD	2017-07-29 10:00:00+03	29600.00
C7F476	2017-07-17 12:09:00+03	37600.00
C7F499	2017-07-05 11:58:00+03	125200.00
C7F4D1	2017-07-18 06:47:00+03	141600.00
C7F564	2017-07-01 17:11:00+03	22800.00
C7F565	2017-08-10 15:51:00+03	87900.00
C7F570	2017-08-08 23:47:00+03	60600.00
C7F58B	2017-08-06 22:12:00+03	23200.00
C7F59E	2017-07-14 23:48:00+03	43000.00
C7F5B2	2017-07-30 23:10:00+03	66600.00
C7F5BD	2017-07-27 09:30:00+03	248400.00
C7F63E	2017-07-18 05:09:00+03	51900.00
C7F642	2017-07-25 07:41:00+03	160700.00
C7F67D	2017-08-13 10:28:00+03	246900.00
C7F6AF	2017-07-08 08:32:00+03	29800.00
C7F6BB	2017-07-02 22:02:00+03	26000.00
C7F6F8	2017-08-11 04:16:00+03	46500.00
C7F766	2017-07-10 05:50:00+03	21400.00
C7F814	2017-07-07 21:55:00+03	75300.00
C7F83F	2017-07-10 07:24:00+03	89700.00
C7F8F6	2017-08-05 06:26:00+03	55800.00
C7F8F7	2017-07-31 16:46:00+03	231800.00
C7F8FD	2017-08-15 07:08:00+03	67700.00
C7F9C3	2017-07-08 07:00:00+03	133100.00
C7FA6C	2017-07-12 21:53:00+03	25400.00
C7FACD	2017-07-06 12:54:00+03	65400.00
C7FB5D	2017-08-14 04:23:00+03	73300.00
C7FB7F	2017-07-25 05:04:00+03	65600.00
C7FBB9	2017-08-05 04:41:00+03	47600.00
C7FC60	2017-08-08 23:26:00+03	15800.00
C7FCA2	2017-08-14 23:13:00+03	75600.00
C7FD05	2017-07-24 14:16:00+03	49900.00
C7FD32	2017-08-11 19:29:00+03	32700.00
C7FD66	2017-07-23 01:09:00+03	8200.00
C7FD82	2017-08-12 10:32:00+03	99800.00
C7FDD7	2017-07-07 09:38:00+03	60900.00
C7FDD8	2017-08-14 14:57:00+03	111600.00
C7FE11	2017-08-11 21:36:00+03	89600.00
C7FEB2	2017-07-08 21:41:00+03	29500.00
C7FEDC	2017-08-09 16:52:00+03	111600.00
C7FF24	2017-07-13 03:16:00+03	47100.00
C7FF67	2017-07-12 07:17:00+03	29600.00
C7FF68	2017-08-05 06:28:00+03	158300.00
C7FFD1	2017-07-11 00:33:00+03	26800.00
C80009	2017-07-17 21:58:00+03	51900.00
C8005B	2017-08-12 00:03:00+03	50600.00
C80068	2017-07-16 02:30:00+03	40800.00
C80092	2017-08-13 19:16:00+03	81700.00
C800BB	2017-07-10 02:54:00+03	26000.00
C80102	2017-07-06 10:38:00+03	91200.00
C80111	2017-07-22 23:36:00+03	22000.00
C8013A	2017-08-07 08:55:00+03	38800.00
C8017D	2017-08-14 19:05:00+03	59600.00
C8019F	2017-07-23 19:14:00+03	51200.00
C801D3	2017-08-01 05:43:00+03	12200.00
C801F2	2017-07-31 23:03:00+03	26000.00
C80211	2017-07-26 09:31:00+03	28800.00
C8021A	2017-07-03 08:34:00+03	25600.00
C80220	2017-07-14 19:27:00+03	46500.00
C80237	2017-07-09 15:25:00+03	58100.00
C80241	2017-07-20 13:10:00+03	28300.00
C8024B	2017-07-10 20:08:00+03	207600.00
C80250	2017-07-05 15:11:00+03	179200.00
C80351	2017-08-05 20:01:00+03	30900.00
C80490	2017-07-06 13:18:00+03	66100.00
C8057E	2017-07-30 20:49:00+03	21800.00
C8060F	2017-07-17 23:32:00+03	55800.00
C80653	2017-07-23 09:06:00+03	24800.00
C80761	2017-08-04 04:08:00+03	80000.00
C80788	2017-07-20 12:09:00+03	24400.00
C807AB	2017-07-17 01:13:00+03	36800.00
C807F3	2017-07-03 20:21:00+03	378400.00
C80828	2017-08-10 18:38:00+03	30000.00
C80836	2017-07-26 21:21:00+03	29600.00
C8084D	2017-07-11 19:22:00+03	99700.00
C8087D	2017-07-02 19:05:00+03	26000.00
C80897	2017-07-29 05:24:00+03	28300.00
C8089D	2017-07-18 22:06:00+03	68800.00
C808EC	2017-06-30 01:23:00+03	97400.00
C80919	2017-07-21 06:30:00+03	46400.00
C80983	2017-07-27 22:17:00+03	40400.00
C8099E	2017-08-03 16:49:00+03	12400.00
C809C0	2017-07-14 18:49:00+03	53600.00
C809F6	2017-08-01 08:53:00+03	13400.00
C80A56	2017-08-10 17:42:00+03	84100.00
C80A7E	2017-07-10 12:19:00+03	40300.00
C80B14	2017-07-17 05:23:00+03	66300.00
C80B18	2017-07-09 22:27:00+03	45100.00
C80B67	2017-07-07 12:47:00+03	57600.00
C80B96	2017-08-10 05:45:00+03	46000.00
C80C05	2017-07-28 16:37:00+03	46400.00
C80CB3	2017-07-16 19:42:00+03	75600.00
C80CC6	2017-07-30 00:48:00+03	13400.00
C80CE0	2017-08-05 12:21:00+03	16400.00
C80D55	2017-07-06 06:34:00+03	47200.00
C80D59	2017-07-21 05:42:00+03	119800.00
C80D5B	2017-07-26 04:34:00+03	46000.00
C80DC1	2017-08-06 07:10:00+03	116700.00
C80E41	2017-07-08 16:31:00+03	27900.00
C80E52	2017-07-13 06:28:00+03	199700.00
C80EEC	2017-07-14 03:20:00+03	265600.00
C80F44	2017-07-18 18:07:00+03	133100.00
C80F5A	2017-07-26 04:42:00+03	91800.00
C81057	2017-07-12 00:07:00+03	114600.00
C81060	2017-08-05 00:20:00+03	68900.00
C810A6	2017-08-13 22:08:00+03	39800.00
C810B1	2017-07-23 14:37:00+03	54800.00
C81145	2017-08-11 15:14:00+03	78600.00
C81152	2017-07-13 18:47:00+03	7400.00
C81164	2017-08-09 14:46:00+03	99300.00
C8116C	2017-08-06 18:07:00+03	6600.00
C81174	2017-07-03 21:11:00+03	67200.00
C811A4	2017-07-03 13:49:00+03	65500.00
C811A8	2017-07-23 04:24:00+03	33800.00
C811C3	2017-07-05 04:42:00+03	34600.00
C811E3	2017-08-05 13:30:00+03	108500.00
C8123F	2017-07-29 03:16:00+03	11800.00
C81284	2017-07-17 06:17:00+03	55800.00
C81290	2017-07-27 02:39:00+03	62400.00
C812CC	2017-07-09 16:39:00+03	52900.00
C81326	2017-07-31 19:49:00+03	265800.00
C8133B	2017-07-22 19:52:00+03	26000.00
C8135B	2017-07-11 10:04:00+03	28300.00
C81381	2017-08-08 15:49:00+03	56600.00
C8139B	2017-07-29 02:24:00+03	79000.00
C8139F	2017-07-20 04:19:00+03	67600.00
C813D0	2017-07-05 21:04:00+03	207200.00
C81407	2017-07-22 13:27:00+03	132800.00
C81430	2017-08-06 15:48:00+03	114500.00
C81498	2017-07-20 18:12:00+03	56000.00
C81513	2017-08-10 06:27:00+03	92900.00
C815AC	2017-07-20 08:36:00+03	44800.00
C81638	2017-07-16 09:41:00+03	49600.00
C8170B	2017-07-07 19:48:00+03	85700.00
C81758	2017-07-19 05:14:00+03	77200.00
C817A7	2017-08-08 21:42:00+03	477500.00
C817EC	2017-08-13 17:55:00+03	46500.00
C81811	2017-07-29 20:15:00+03	43600.00
C81898	2017-07-15 17:28:00+03	36600.00
C818CC	2017-08-06 05:18:00+03	23200.00
C8191B	2017-07-21 20:57:00+03	41300.00
C81947	2017-07-12 21:16:00+03	131100.00
C8196B	2017-08-12 11:45:00+03	24600.00
C81A08	2017-06-29 14:30:00+03	99300.00
C81A11	2017-07-27 11:27:00+03	68000.00
C81A99	2017-08-14 12:54:00+03	26000.00
C81B7B	2017-07-11 17:56:00+03	88900.00
C81B88	2017-08-13 07:40:00+03	28000.00
C81BA0	2017-07-05 00:04:00+03	48800.00
C81BC3	2017-07-03 22:06:00+03	19800.00
C81BCB	2017-07-11 12:04:00+03	398300.00
C81C58	2017-07-08 19:16:00+03	34000.00
C81C90	2017-08-08 20:25:00+03	155600.00
C81CA9	2017-07-23 09:20:00+03	273600.00
C81CB1	2017-07-05 11:09:00+03	101900.00
C81CB3	2017-07-25 02:14:00+03	119300.00
C81D23	2017-07-22 18:20:00+03	135400.00
C81D2E	2017-07-24 19:52:00+03	31600.00
C81DF6	2017-07-02 09:10:00+03	116400.00
C81DF8	2017-07-18 21:18:00+03	36400.00
C81E15	2017-07-24 07:23:00+03	182300.00
C81E68	2017-08-04 12:31:00+03	36000.00
C81E7C	2017-07-08 19:47:00+03	21400.00
C81EA0	2017-08-08 08:35:00+03	271100.00
C81F43	2017-07-17 06:36:00+03	176500.00
C81F4D	2017-07-29 04:17:00+03	68100.00
C81F8C	2017-07-19 04:55:00+03	57600.00
C81F98	2017-07-12 23:08:00+03	136200.00
C81FEC	2017-07-07 00:58:00+03	531400.00
C82044	2017-08-09 16:51:00+03	188800.00
C82055	2017-07-25 17:24:00+03	54800.00
C820D8	2017-07-30 03:22:00+03	75600.00
C82115	2017-07-20 18:50:00+03	62600.00
C8212D	2017-07-20 07:31:00+03	95700.00
C82247	2017-07-18 03:40:00+03	161500.00
C8224C	2017-08-08 16:45:00+03	42800.00
C82253	2017-08-12 22:37:00+03	290400.00
C822C9	2017-07-18 18:37:00+03	46200.00
C822E4	2017-08-13 04:15:00+03	77600.00
C82306	2017-07-29 09:48:00+03	31700.00
C82337	2017-08-06 22:16:00+03	56000.00
C82430	2017-07-12 01:39:00+03	28000.00
C82455	2017-07-04 13:06:00+03	16400.00
C8248D	2017-06-26 03:47:00+03	76600.00
C824AF	2017-07-25 15:04:00+03	226200.00
C824B6	2017-07-29 06:46:00+03	48600.00
C824D0	2017-08-04 16:04:00+03	67600.00
C824F3	2017-07-11 10:57:00+03	150600.00
C824FC	2017-08-04 02:31:00+03	29600.00
C8250F	2017-07-22 21:52:00+03	94000.00
C8256B	2017-07-15 22:26:00+03	49100.00
C82586	2017-08-05 21:08:00+03	30000.00
C82640	2017-07-15 17:54:00+03	28800.00
C82672	2017-07-26 02:11:00+03	116700.00
C826D4	2017-08-15 11:14:00+03	17800.00
C827C9	2017-07-26 20:36:00+03	26200.00
C827FD	2017-07-04 04:20:00+03	122300.00
C828B8	2017-08-12 17:55:00+03	59800.00
C828DE	2017-08-14 23:24:00+03	166900.00
C82935	2017-06-29 12:09:00+03	246000.00
C8296E	2017-07-28 06:40:00+03	43600.00
C829A4	2017-08-04 15:27:00+03	37200.00
C829E0	2017-07-05 20:16:00+03	40100.00
C82A11	2017-07-08 23:59:00+03	98400.00
C82A75	2017-06-27 09:13:00+03	111600.00
C82A79	2017-07-18 08:17:00+03	25400.00
C82A99	2017-07-17 11:55:00+03	24200.00
C82B13	2017-08-14 13:52:00+03	48300.00
C82B1A	2017-07-28 00:31:00+03	14000.00
C82B43	2017-07-21 07:25:00+03	13600.00
C82BD3	2017-08-06 18:27:00+03	28000.00
C82C69	2017-07-22 16:54:00+03	28800.00
C82D2C	2017-08-03 17:02:00+03	107400.00
C82D59	2017-08-04 17:47:00+03	139100.00
C82DFB	2017-08-03 13:01:00+03	86300.00
C82E12	2017-07-24 06:40:00+03	17200.00
C82ED5	2017-07-11 17:43:00+03	116700.00
C82F20	2017-07-20 21:13:00+03	78600.00
C82F42	2017-07-26 02:27:00+03	117700.00
C82F51	2017-08-05 15:56:00+03	126700.00
C82F68	2017-07-17 09:25:00+03	99200.00
C8300B	2017-07-02 16:58:00+03	92800.00
C83056	2017-07-21 16:47:00+03	139000.00
C8307C	2017-07-27 15:25:00+03	83000.00
C83087	2017-07-01 23:35:00+03	25800.00
C830D9	2017-06-29 20:57:00+03	65400.00
C83134	2017-08-15 13:33:00+03	542300.00
C8315F	2017-08-11 12:27:00+03	77900.00
C8316F	2017-07-31 15:41:00+03	26000.00
C83176	2017-07-15 02:25:00+03	31200.00
C831A8	2017-07-19 00:51:00+03	154800.00
C831F4	2017-07-19 08:20:00+03	73600.00
C8326A	2017-07-27 21:18:00+03	81300.00
C83281	2017-07-07 09:17:00+03	59300.00
C83284	2017-07-25 11:33:00+03	24800.00
C832EC	2017-08-12 12:41:00+03	49800.00
C83312	2017-07-19 15:39:00+03	29400.00
C8331B	2017-07-25 14:22:00+03	33300.00
C83355	2017-06-29 20:41:00+03	43200.00
C83362	2017-08-14 14:58:00+03	59300.00
C833B5	2017-08-08 17:42:00+03	36200.00
C833CF	2017-07-30 08:56:00+03	70600.00
C83413	2017-07-07 03:11:00+03	111400.00
C8343A	2017-07-26 15:40:00+03	62600.00
C83484	2017-07-10 11:28:00+03	11700.00
C834D9	2017-08-05 08:49:00+03	45400.00
C83538	2017-07-19 18:39:00+03	22000.00
C83578	2017-07-05 03:39:00+03	71800.00
C8358A	2017-07-07 20:48:00+03	55800.00
C8358F	2017-07-09 17:19:00+03	157200.00
C835A4	2017-08-04 15:19:00+03	234700.00
C835C3	2017-08-07 23:50:00+03	131100.00
C835DD	2017-07-13 08:42:00+03	67200.00
C835F3	2017-07-07 06:03:00+03	54800.00
C83683	2017-08-14 17:10:00+03	116900.00
C83688	2017-07-31 07:00:00+03	78100.00
C836BC	2017-07-13 13:55:00+03	67300.00
C83769	2017-07-31 19:42:00+03	516600.00
C83782	2017-08-05 05:52:00+03	14000.00
C837CA	2017-07-29 14:36:00+03	27400.00
C83814	2017-08-04 00:18:00+03	7400.00
C8387F	2017-06-30 23:42:00+03	193100.00
C838CE	2017-06-29 17:47:00+03	238900.00
C838D7	2017-08-10 01:17:00+03	80200.00
C838F9	2017-07-25 06:55:00+03	145100.00
C83905	2017-07-08 17:07:00+03	193700.00
C83910	2017-08-15 08:33:00+03	6700.00
C83946	2017-07-15 00:14:00+03	39300.00
C83967	2017-08-08 16:28:00+03	124000.00
C83992	2017-07-23 17:50:00+03	57500.00
C8399D	2017-07-17 05:18:00+03	28800.00
C839CE	2017-07-23 04:53:00+03	89800.00
C83A12	2017-07-08 16:43:00+03	86300.00
C83A18	2017-07-12 01:25:00+03	56000.00
C83ADE	2017-08-15 14:05:00+03	13400.00
C83B00	2017-06-25 13:58:00+03	70400.00
C83B18	2017-08-12 03:40:00+03	26800.00
C83B37	2017-07-25 20:50:00+03	25800.00
C83B51	2017-07-11 01:44:00+03	8000.00
C83BEF	2017-08-07 16:05:00+03	32200.00
C83CAE	2017-08-04 21:54:00+03	103800.00
C83CC6	2017-07-19 20:27:00+03	67600.00
C83CEF	2017-08-08 00:56:00+03	75800.00
C83D22	2017-07-06 02:50:00+03	45200.00
C83D6B	2017-06-25 01:35:00+03	56000.00
C83D93	2017-07-03 13:45:00+03	139800.00
C83DB9	2017-07-26 00:07:00+03	29400.00
C83DD8	2017-08-04 18:03:00+03	133200.00
C83E31	2017-07-07 02:31:00+03	102100.00
C83E80	2017-07-30 06:28:00+03	168000.00
C83E88	2017-08-15 05:02:00+03	70100.00
C83EA3	2017-07-19 09:40:00+03	73200.00
C83EA6	2017-08-04 06:06:00+03	25200.00
C83EF1	2017-08-11 06:15:00+03	119500.00
C83F2C	2017-08-13 20:13:00+03	66600.00
C83F6F	2017-07-09 05:08:00+03	56000.00
C83FA0	2017-07-09 22:52:00+03	68800.00
C83FF0	2017-08-14 01:48:00+03	245500.00
C84033	2017-07-06 18:47:00+03	135400.00
C84054	2017-07-23 18:34:00+03	147800.00
C840A3	2017-07-30 18:23:00+03	23600.00
C841B4	2017-07-27 14:34:00+03	95900.00
C841E2	2017-08-12 13:01:00+03	44000.00
C8426B	2017-07-23 20:09:00+03	95600.00
C842C0	2017-08-03 19:03:00+03	59000.00
C842CA	2017-07-14 11:32:00+03	129200.00
C842F0	2017-07-05 07:20:00+03	27200.00
C84344	2017-07-18 05:59:00+03	285000.00
C8442F	2017-08-08 12:14:00+03	12200.00
C84485	2017-07-03 06:39:00+03	49800.00
C84488	2017-07-12 11:13:00+03	28800.00
C84490	2017-07-04 02:29:00+03	58900.00
C84493	2017-07-31 10:26:00+03	8200.00
C8449B	2017-08-12 11:04:00+03	69500.00
C844D5	2017-08-01 22:06:00+03	13400.00
C8455B	2017-07-09 07:00:00+03	133200.00
C845A5	2017-07-20 07:03:00+03	47200.00
C84614	2017-07-22 15:59:00+03	289800.00
C84644	2017-07-27 19:35:00+03	90800.00
C8465A	2017-07-24 00:19:00+03	101100.00
C846DE	2017-07-06 01:26:00+03	98400.00
C846F8	2017-06-27 21:50:00+03	67600.00
C84749	2017-07-24 06:16:00+03	119600.00
C847A7	2017-08-11 20:33:00+03	81300.00
C847CF	2017-07-08 07:49:00+03	81600.00
C848B0	2017-08-09 19:38:00+03	24400.00
C848F1	2017-07-27 03:39:00+03	30800.00
C84938	2017-07-28 22:24:00+03	40600.00
C8499A	2017-07-19 23:05:00+03	28000.00
C849A9	2017-08-05 18:08:00+03	115700.00
C849AB	2017-08-12 20:39:00+03	143800.00
C849B8	2017-08-09 07:55:00+03	27200.00
C849C1	2017-07-22 02:16:00+03	98300.00
C849D6	2017-08-04 18:49:00+03	58900.00
C84A73	2017-07-04 11:09:00+03	111600.00
C84AA5	2017-07-18 17:35:00+03	48400.00
C84AAB	2017-07-09 05:51:00+03	81700.00
C84AD0	2017-08-07 21:03:00+03	24000.00
C84B08	2017-08-05 20:47:00+03	55800.00
C84B60	2017-07-23 16:16:00+03	91700.00
C84B90	2017-06-26 18:37:00+03	29600.00
C84BC3	2017-07-08 18:56:00+03	24700.00
C84BD2	2017-08-06 12:59:00+03	25200.00
C84BF0	2017-08-04 15:22:00+03	30200.00
C84BFA	2017-07-25 12:28:00+03	34000.00
C84C1D	2017-07-04 05:05:00+03	59600.00
C84C32	2017-07-17 21:06:00+03	20200.00
C84C37	2017-07-30 23:08:00+03	55800.00
C84C4C	2017-07-17 12:28:00+03	54300.00
C84C6C	2017-07-18 12:28:00+03	400000.00
C84C89	2017-07-09 18:38:00+03	42800.00
C84C8D	2017-08-04 11:35:00+03	96800.00
C84CC1	2017-07-18 08:10:00+03	24300.00
C84CF8	2017-07-29 10:25:00+03	81200.00
C84D2A	2017-08-10 19:27:00+03	26800.00
C84D31	2017-07-22 11:12:00+03	71600.00
C84D4E	2017-07-14 10:22:00+03	93400.00
C84D4F	2017-07-09 05:22:00+03	88500.00
C84D53	2017-07-19 01:19:00+03	25600.00
C84DCA	2017-06-25 03:13:00+03	40800.00
C84DD9	2017-08-01 17:34:00+03	135400.00
C84E01	2017-08-06 08:31:00+03	46200.00
C84E05	2017-06-29 17:38:00+03	28000.00
C84E09	2017-07-17 15:57:00+03	39300.00
C84E31	2017-07-03 08:45:00+03	68800.00
C84EAD	2017-08-09 22:57:00+03	84100.00
C84F14	2017-07-15 11:12:00+03	81600.00
C84F23	2017-07-07 21:42:00+03	29600.00
C84F33	2017-08-10 23:28:00+03	114800.00
C84F83	2017-08-02 16:36:00+03	28000.00
C84F8B	2017-08-11 04:09:00+03	59600.00
C84FC6	2017-07-10 23:39:00+03	23200.00
C850A3	2017-07-17 06:53:00+03	65400.00
C850C8	2017-08-13 20:26:00+03	45200.00
C850D0	2017-06-27 17:00:00+03	92400.00
C85125	2017-07-29 06:19:00+03	40900.00
C85140	2017-07-18 14:59:00+03	72400.00
C85172	2017-07-24 09:15:00+03	26000.00
C85173	2017-08-10 05:21:00+03	75600.00
C8518B	2017-07-27 09:12:00+03	140800.00
C851C8	2017-07-11 03:46:00+03	135000.00
C85215	2017-08-08 01:11:00+03	47400.00
C85276	2017-07-02 04:46:00+03	38200.00
C85277	2017-07-29 00:47:00+03	37200.00
C85290	2017-07-22 13:48:00+03	56100.00
C85295	2017-07-05 06:30:00+03	266500.00
C85366	2017-08-12 18:37:00+03	58200.00
C853F8	2017-06-27 01:16:00+03	38800.00
C85401	2017-07-13 15:50:00+03	12600.00
C8542E	2017-08-08 01:47:00+03	73300.00
C85479	2017-08-08 15:21:00+03	88600.00
C854A1	2017-07-12 02:16:00+03	95400.00
C85521	2017-08-14 10:48:00+03	29600.00
C8556B	2017-08-10 11:26:00+03	112000.00
C85584	2017-08-15 05:34:00+03	131100.00
C8558C	2017-07-05 05:08:00+03	66400.00
C855A8	2017-08-13 14:12:00+03	82600.00
C855CF	2017-07-21 07:29:00+03	8000.00
C85631	2017-06-28 18:27:00+03	101200.00
C85637	2017-08-10 08:03:00+03	28800.00
C8566A	2017-07-30 01:14:00+03	37900.00
C85698	2017-08-12 23:58:00+03	266400.00
C856F8	2017-08-12 14:03:00+03	46300.00
C85778	2017-08-08 19:41:00+03	60800.00
C8578E	2017-07-12 20:05:00+03	114800.00
C857A8	2017-08-09 02:55:00+03	52000.00
C858CB	2017-07-21 18:34:00+03	69500.00
C858CF	2017-07-01 13:29:00+03	13000.00
C8590F	2017-07-13 18:57:00+03	427400.00
C85912	2017-07-24 17:44:00+03	159500.00
C859EE	2017-08-08 14:40:00+03	25400.00
C85A34	2017-08-15 11:59:00+03	169600.00
C85AD6	2017-07-24 15:07:00+03	28800.00
C85AF4	2017-07-10 18:33:00+03	212900.00
C85B34	2017-08-13 09:41:00+03	252200.00
C85B36	2017-07-08 00:31:00+03	58400.00
C85BAD	2017-07-27 05:45:00+03	52700.00
C85BC9	2017-07-29 21:20:00+03	136200.00
C85BF0	2017-07-24 16:21:00+03	62600.00
C85BFD	2017-06-30 10:31:00+03	17800.00
C85C0E	2017-07-23 21:18:00+03	53600.00
C85C25	2017-07-28 05:48:00+03	135200.00
C85C75	2017-07-03 21:11:00+03	145100.00
C85C8C	2017-08-07 09:35:00+03	39800.00
C85C99	2017-07-31 08:05:00+03	39800.00
C85CE8	2017-07-02 08:51:00+03	16400.00
C85CF7	2017-07-19 08:47:00+03	28000.00
C85DBF	2017-07-11 11:39:00+03	26000.00
C85E10	2017-07-08 08:11:00+03	23200.00
C85E42	2017-07-08 02:29:00+03	84800.00
C85E5D	2017-08-03 11:35:00+03	59400.00
C85F21	2017-07-21 01:37:00+03	26000.00
C85F47	2017-08-11 09:30:00+03	59300.00
C85F9A	2017-08-10 19:26:00+03	28800.00
C8606A	2017-07-22 01:22:00+03	39200.00
C8608B	2017-07-30 04:00:00+03	77200.00
C86096	2017-07-04 11:03:00+03	92800.00
C860F8	2017-08-02 08:40:00+03	157000.00
C861C0	2017-08-15 17:22:00+03	46800.00
C861EB	2017-07-07 12:00:00+03	38800.00
C86204	2017-07-04 11:34:00+03	6700.00
C86232	2017-07-17 14:27:00+03	24400.00
C86255	2017-07-30 03:33:00+03	133200.00
C8629A	2017-08-13 19:07:00+03	12000.00
C862DC	2017-07-29 06:57:00+03	6700.00
C86304	2017-07-25 10:47:00+03	123000.00
C86305	2017-08-02 18:43:00+03	44800.00
C863B0	2017-07-12 06:26:00+03	199200.00
C86437	2017-07-10 11:03:00+03	289800.00
C86438	2017-08-09 22:41:00+03	79000.00
C8644B	2017-07-15 21:01:00+03	32700.00
C8647C	2017-07-10 09:52:00+03	134800.00
C864C9	2017-07-23 06:18:00+03	27300.00
C86521	2017-07-13 02:19:00+03	35500.00
C86547	2017-08-12 11:07:00+03	34400.00
C865B3	2017-07-05 14:24:00+03	77200.00
C865CE	2017-08-10 18:15:00+03	75600.00
C865FB	2017-08-07 20:17:00+03	52000.00
C86604	2017-08-07 06:46:00+03	7800.00
C8661C	2017-08-10 12:31:00+03	57400.00
C86620	2017-08-06 01:29:00+03	28000.00
C8668B	2017-08-06 18:47:00+03	180000.00
C86696	2017-08-06 10:21:00+03	201200.00
C866F9	2017-07-17 07:41:00+03	177400.00
C86709	2017-07-07 01:02:00+03	111400.00
C8672C	2017-07-23 17:14:00+03	22100.00
C86746	2017-08-11 02:14:00+03	49600.00
C86780	2017-08-06 01:53:00+03	20200.00
C867AA	2017-08-11 16:15:00+03	62200.00
C867EC	2017-07-09 21:47:00+03	67600.00
C8686D	2017-07-01 12:54:00+03	135400.00
C8689D	2017-07-12 02:11:00+03	111500.00
C868C1	2017-07-17 10:03:00+03	100600.00
C868D3	2017-08-05 13:09:00+03	46400.00
C86964	2017-07-15 18:50:00+03	49100.00
C86979	2017-07-18 15:38:00+03	6900.00
C8697A	2017-08-11 16:16:00+03	25000.00
C86986	2017-07-25 21:50:00+03	6200.00
C8699F	2017-07-05 23:53:00+03	20500.00
C869CD	2017-07-15 16:41:00+03	59800.00
C86A6A	2017-08-15 11:37:00+03	56100.00
C86A84	2017-07-19 16:02:00+03	8400.00
C86AEF	2017-08-04 12:50:00+03	55600.00
C86B19	2017-07-10 01:53:00+03	178800.00
C86BA3	2017-07-19 05:43:00+03	148200.00
C86BB8	2017-07-28 08:26:00+03	39600.00
C86BFE	2017-08-11 07:17:00+03	213200.00
C86C81	2017-07-19 20:30:00+03	81700.00
C86CAC	2017-07-11 19:58:00+03	33600.00
C86CCB	2017-07-15 04:41:00+03	99300.00
C86D09	2017-08-03 07:30:00+03	114300.00
C86F3A	2017-08-07 19:39:00+03	48800.00
C86F71	2017-07-25 08:12:00+03	191200.00
C86F7C	2017-07-30 22:54:00+03	57400.00
C86F89	2017-06-29 14:41:00+03	133200.00
C86FFF	2017-07-13 15:12:00+03	265800.00
C87062	2017-08-10 13:49:00+03	131900.00
C870C3	2017-07-15 16:57:00+03	50800.00
C87135	2017-07-16 12:02:00+03	116000.00
C871A9	2017-07-18 00:21:00+03	12400.00
C871C1	2017-07-04 12:55:00+03	73300.00
C871D8	2017-07-17 19:58:00+03	27800.00
C87268	2017-07-25 12:38:00+03	3700.00
C87272	2017-07-29 13:44:00+03	65500.00
C8729A	2017-07-16 11:33:00+03	7800.00
C872C9	2017-07-31 11:57:00+03	109300.00
C87335	2017-08-05 04:54:00+03	103500.00
C8738A	2017-08-09 02:55:00+03	135600.00
C873AD	2017-07-29 06:02:00+03	112000.00
C8745E	2017-07-08 11:19:00+03	107200.00
C8746D	2017-08-14 23:18:00+03	103400.00
C8746E	2017-07-06 11:01:00+03	111600.00
C8749F	2017-07-14 06:36:00+03	62800.00
C874ED	2017-07-21 19:56:00+03	32700.00
C874EE	2017-07-19 06:22:00+03	59800.00
C875DC	2017-08-01 23:28:00+03	46400.00
C875E1	2017-08-14 16:37:00+03	107800.00
C875F3	2017-08-03 20:59:00+03	57600.00
C87623	2017-08-12 04:14:00+03	49500.00
C87648	2017-07-27 23:47:00+03	81700.00
C8764C	2017-07-25 16:07:00+03	29600.00
C8765D	2017-07-03 00:05:00+03	28800.00
C87671	2017-08-14 09:10:00+03	121500.00
C876EA	2017-07-21 05:35:00+03	68800.00
C877A7	2017-07-21 21:02:00+03	43200.00
C877AA	2017-07-13 00:41:00+03	16400.00
C877CF	2017-07-24 03:17:00+03	67500.00
C877F3	2017-08-08 10:11:00+03	58000.00
C8786D	2017-08-09 07:32:00+03	45200.00
C87916	2017-07-05 06:05:00+03	50000.00
C87955	2017-07-09 14:04:00+03	52700.00
C8795D	2017-07-15 08:16:00+03	51600.00
C879A9	2017-07-06 22:57:00+03	12200.00
C879BF	2017-08-15 16:31:00+03	37800.00
C879FA	2017-07-08 03:36:00+03	27900.00
C87A06	2017-07-05 17:18:00+03	231300.00
C87A41	2017-08-11 18:05:00+03	55800.00
C87A5D	2017-08-10 13:24:00+03	187600.00
C87AF8	2017-07-10 05:15:00+03	136200.00
C87B03	2017-08-08 06:32:00+03	132800.00
C87B35	2017-07-24 23:40:00+03	159100.00
C87B86	2017-08-02 03:11:00+03	73500.00
C87B92	2017-08-07 16:09:00+03	56000.00
C87B9A	2017-07-21 13:13:00+03	24400.00
C87BAB	2017-08-04 14:53:00+03	270800.00
C87BB9	2017-07-31 12:22:00+03	38600.00
C87BF9	2017-07-03 03:53:00+03	63000.00
C87BFA	2017-08-09 06:28:00+03	8000.00
C87C45	2017-08-11 14:24:00+03	43200.00
C87CB7	2017-08-15 15:00:00+03	26800.00
C87CD2	2017-07-31 21:20:00+03	28800.00
C87D35	2017-07-10 22:58:00+03	69500.00
C87D49	2017-08-05 12:55:00+03	24400.00
C87D51	2017-07-18 12:54:00+03	27400.00
C87D91	2017-07-24 02:39:00+03	50700.00
C87D92	2017-07-26 11:10:00+03	112100.00
C87D95	2017-07-15 08:56:00+03	38800.00
C87DD4	2017-07-28 05:43:00+03	38800.00
C87DE0	2017-07-09 05:52:00+03	11600.00
C87DFD	2017-08-02 16:28:00+03	45300.00
C87E01	2017-07-09 08:33:00+03	125100.00
C87E10	2017-07-03 04:40:00+03	48800.00
C87EA8	2017-07-02 02:39:00+03	75600.00
C87EC2	2017-06-30 07:53:00+03	136200.00
C87EF1	2017-07-25 16:00:00+03	48800.00
C87EF5	2017-07-05 00:49:00+03	37900.00
C87F08	2017-07-22 03:06:00+03	31700.00
C87F4B	2017-06-29 08:01:00+03	64000.00
C87FAF	2017-08-10 17:12:00+03	133200.00
C88041	2017-07-02 09:43:00+03	78600.00
C88058	2017-07-05 22:44:00+03	78300.00
C880D3	2017-07-24 14:34:00+03	53800.00
C880FF	2017-07-27 05:05:00+03	125200.00
C8822F	2017-07-19 09:12:00+03	65900.00
C8823F	2017-07-03 23:27:00+03	155000.00
C88287	2017-07-16 17:23:00+03	178800.00
C8829E	2017-07-10 08:14:00+03	99700.00
C8829F	2017-07-06 02:33:00+03	26000.00
C882D5	2017-08-03 09:45:00+03	43200.00
C882E2	2017-08-09 10:10:00+03	21400.00
C882E4	2017-07-20 05:01:00+03	101200.00
C8830A	2017-07-04 07:59:00+03	132800.00
C88333	2017-08-14 00:39:00+03	11800.00
C88343	2017-07-09 15:25:00+03	47200.00
C883DC	2017-07-09 02:30:00+03	52000.00
C883FC	2017-08-12 02:45:00+03	46800.00
C88427	2017-07-29 03:15:00+03	21400.00
C884B1	2017-08-10 02:33:00+03	59200.00
C884D0	2017-08-09 13:32:00+03	284400.00
C88571	2017-08-15 09:31:00+03	114400.00
C88596	2017-07-06 23:42:00+03	58200.00
C885AC	2017-07-08 12:05:00+03	14900.00
C885B8	2017-07-03 09:46:00+03	75300.00
C88622	2017-07-28 00:19:00+03	81300.00
C886D8	2017-08-11 13:41:00+03	85400.00
C8877B	2017-07-30 12:08:00+03	56000.00
C887A2	2017-08-13 21:30:00+03	13800.00
C887B6	2017-07-12 21:56:00+03	73600.00
C887C3	2017-08-02 20:36:00+03	67200.00
C887C4	2017-07-20 17:48:00+03	44800.00
C888CA	2017-07-08 10:25:00+03	615000.00
C88924	2017-07-25 14:36:00+03	77500.00
C88950	2017-07-10 16:55:00+03	26000.00
C8897F	2017-07-27 05:06:00+03	24400.00
C889A4	2017-07-23 05:43:00+03	96800.00
C889C3	2017-07-06 02:09:00+03	87900.00
C889FD	2017-07-16 11:59:00+03	52000.00
C88A10	2017-07-14 07:17:00+03	105200.00
C88A18	2017-07-25 04:01:00+03	57800.00
C88A1D	2017-07-18 03:45:00+03	9200.00
C88A3B	2017-07-21 06:28:00+03	99600.00
C88A40	2017-07-13 17:33:00+03	17800.00
C88A95	2017-07-25 07:27:00+03	8000.00
C88B18	2017-07-29 23:21:00+03	75600.00
C88B25	2017-08-02 16:46:00+03	68600.00
C88B87	2017-08-14 10:14:00+03	104600.00
C88C39	2017-06-29 04:25:00+03	95600.00
C88C56	2017-08-06 15:31:00+03	20200.00
C88C5C	2017-07-29 04:27:00+03	87700.00
C88C77	2017-07-01 02:06:00+03	36800.00
C88CC3	2017-07-23 14:09:00+03	46400.00
C88D20	2017-07-09 14:36:00+03	27300.00
C88D28	2017-08-11 08:57:00+03	99800.00
C88D35	2017-08-01 20:37:00+03	67200.00
C88D6B	2017-08-14 17:03:00+03	6700.00
C88DAB	2017-07-09 02:43:00+03	224000.00
C88DD9	2017-07-28 03:32:00+03	22200.00
C88DFB	2017-07-08 06:21:00+03	13000.00
C88E1B	2017-07-30 10:05:00+03	56800.00
C88E38	2017-07-10 05:25:00+03	85000.00
C88E50	2017-07-18 08:16:00+03	246000.00
C88E58	2017-08-13 12:52:00+03	42800.00
C88E62	2017-07-26 19:10:00+03	66200.00
C88E7C	2017-08-13 06:08:00+03	28000.00
C88E81	2017-08-03 10:41:00+03	179500.00
C88EE8	2017-08-06 15:49:00+03	24500.00
C88EEA	2017-07-31 08:48:00+03	39300.00
C88F28	2017-08-14 22:55:00+03	90400.00
C88F3F	2017-07-27 19:23:00+03	59800.00
C88F7A	2017-08-03 22:52:00+03	51900.00
C88F82	2017-07-23 16:24:00+03	91300.00
C88FCE	2017-07-09 17:29:00+03	87900.00
C8900D	2017-07-06 10:07:00+03	269200.00
C89037	2017-07-14 12:17:00+03	103900.00
C890D7	2017-07-26 21:56:00+03	51800.00
C89148	2017-07-11 22:19:00+03	51600.00
C89159	2017-08-08 12:37:00+03	138800.00
C891EA	2017-08-01 15:50:00+03	86300.00
C89289	2017-08-10 01:10:00+03	21800.00
C892BC	2017-08-03 04:37:00+03	46400.00
C89330	2017-08-13 17:30:00+03	46000.00
C89335	2017-08-06 23:45:00+03	26000.00
C8934A	2017-08-08 07:35:00+03	99200.00
C89372	2017-07-05 16:55:00+03	166000.00
C89441	2017-07-18 15:53:00+03	44800.00
C89443	2017-08-15 04:20:00+03	28800.00
C89476	2017-08-05 05:21:00+03	36200.00
C89598	2017-07-04 00:28:00+03	34400.00
C895A7	2017-07-25 03:01:00+03	12600.00
C89666	2017-07-08 12:41:00+03	29600.00
C896AC	2017-08-13 05:45:00+03	50600.00
C896C0	2017-07-28 13:42:00+03	38400.00
C896E2	2017-07-20 19:40:00+03	14000.00
C896F5	2017-08-15 09:11:00+03	26000.00
C89734	2017-07-19 23:13:00+03	26800.00
C897A2	2017-08-08 23:50:00+03	28800.00
C8984F	2017-07-29 08:24:00+03	48800.00
C8985D	2017-07-13 15:33:00+03	24700.00
C8987F	2017-08-13 22:46:00+03	46400.00
C898A4	2017-08-10 00:13:00+03	409100.00
C898AE	2017-08-09 01:03:00+03	116800.00
C898E6	2017-08-05 08:44:00+03	40800.00
C8993C	2017-07-15 03:08:00+03	46000.00
C8993F	2017-08-15 11:44:00+03	147700.00
C89950	2017-07-23 14:15:00+03	46200.00
C899B0	2017-08-05 10:53:00+03	81200.00
C899C8	2017-08-04 09:14:00+03	189000.00
C899D0	2017-07-27 19:45:00+03	123000.00
C899DE	2017-08-05 20:14:00+03	25400.00
C89A38	2017-07-04 15:53:00+03	125400.00
C89AD1	2017-07-31 06:42:00+03	14800.00
C89AE3	2017-07-25 04:49:00+03	6600.00
C89B3D	2017-07-26 15:27:00+03	60700.00
C89B87	2017-08-12 03:55:00+03	63700.00
C89BE3	2017-08-15 12:21:00+03	19600.00
C89BEF	2017-07-29 02:40:00+03	8200.00
C89C0F	2017-07-09 05:18:00+03	23600.00
C89C52	2017-07-18 10:58:00+03	30400.00
C89CB1	2017-07-19 22:46:00+03	65800.00
C89CB9	2017-08-10 10:25:00+03	100900.00
C89CDA	2017-07-23 22:35:00+03	83200.00
C89CF9	2017-07-01 12:15:00+03	46000.00
C89D21	2017-07-27 23:00:00+03	54500.00
C89DD0	2017-07-05 19:17:00+03	101200.00
C89DED	2017-08-10 07:01:00+03	40800.00
C89E64	2017-08-10 07:55:00+03	78600.00
C89F02	2017-07-21 21:36:00+03	26600.00
C89F4A	2017-08-08 03:38:00+03	193400.00
C89F6F	2017-07-04 07:04:00+03	73600.00
C89F9F	2017-07-22 06:01:00+03	84100.00
C89FCD	2017-07-06 00:52:00+03	47200.00
C89FED	2017-07-24 21:28:00+03	133100.00
C89FFC	2017-08-09 10:21:00+03	133700.00
C8A01C	2017-07-19 11:53:00+03	16400.00
C8A072	2017-07-09 09:58:00+03	131900.00
C8A088	2017-07-05 02:13:00+03	28000.00
C8A118	2017-07-18 11:04:00+03	216500.00
C8A144	2017-08-11 07:28:00+03	72600.00
C8A177	2017-08-07 04:28:00+03	58400.00
C8A19E	2017-07-08 06:49:00+03	57400.00
C8A1AF	2017-07-11 00:13:00+03	64700.00
C8A1E8	2017-07-21 02:39:00+03	46300.00
C8A21C	2017-07-31 04:54:00+03	133900.00
C8A222	2017-07-12 17:01:00+03	45100.00
C8A25A	2017-08-02 16:52:00+03	69400.00
C8A25F	2017-08-01 14:27:00+03	114800.00
C8A28D	2017-07-23 16:00:00+03	23600.00
C8A29C	2017-07-19 16:57:00+03	229900.00
C8A2A4	2017-07-22 12:23:00+03	375200.00
C8A2B2	2017-07-30 12:23:00+03	47200.00
C8A2DD	2017-07-14 03:21:00+03	187600.00
C8A30B	2017-07-02 04:51:00+03	27500.00
C8A344	2017-07-21 11:02:00+03	58000.00
C8A3A3	2017-07-13 18:38:00+03	56000.00
C8A3F4	2017-07-01 03:46:00+03	40600.00
C8A418	2017-07-26 23:35:00+03	48800.00
C8A49E	2017-07-30 19:16:00+03	73200.00
C8A4C7	2017-07-21 01:05:00+03	70000.00
C8A4D5	2017-07-12 23:00:00+03	69000.00
C8A4DB	2017-07-23 23:12:00+03	46400.00
C8A4FC	2017-07-20 06:48:00+03	31600.00
C8A540	2017-07-05 19:02:00+03	94000.00
C8A595	2017-08-07 00:45:00+03	272900.00
C8A59A	2017-08-14 09:54:00+03	44600.00
C8A61E	2017-07-29 20:55:00+03	31600.00
C8A6C6	2017-08-13 08:32:00+03	44800.00
C8A6CD	2017-07-07 02:05:00+03	131100.00
C8A711	2017-07-02 13:18:00+03	88600.00
C8A721	2017-08-05 09:00:00+03	6700.00
C8A72B	2017-07-16 23:46:00+03	230200.00
C8A72E	2017-07-31 21:50:00+03	47600.00
C8A7C5	2017-08-09 15:58:00+03	24300.00
C8A95D	2017-08-01 12:55:00+03	84000.00
C8A964	2017-07-04 22:49:00+03	178000.00
C8A97D	2017-08-05 04:01:00+03	65600.00
C8A98E	2017-07-02 13:38:00+03	90100.00
C8A993	2017-07-29 01:03:00+03	332000.00
C8A994	2017-07-04 06:42:00+03	40600.00
C8A9E5	2017-08-03 01:19:00+03	59800.00
C8AA02	2017-07-26 08:39:00+03	55800.00
C8AA4D	2017-07-30 20:29:00+03	73600.00
C8AA6B	2017-08-09 07:03:00+03	142300.00
C8AAF3	2017-07-21 19:28:00+03	116400.00
C8AB99	2017-07-24 03:58:00+03	202200.00
C8ABA6	2017-07-18 22:06:00+03	12600.00
C8AC0A	2017-07-20 15:30:00+03	136200.00
C8AC22	2017-08-08 12:17:00+03	15700.00
C8AC45	2017-08-06 23:33:00+03	124100.00
C8AC5D	2017-07-18 22:58:00+03	56600.00
C8ACAD	2017-07-30 19:40:00+03	66600.00
C8AD6C	2017-07-31 18:51:00+03	56000.00
C8ADA7	2017-08-07 00:28:00+03	26800.00
C8ADBF	2017-08-06 08:48:00+03	22000.00
C8AEA2	2017-08-05 10:08:00+03	103900.00
C8AEDF	2017-07-19 19:51:00+03	69900.00
C8AEE7	2017-07-11 07:54:00+03	48700.00
C8AF37	2017-07-10 03:26:00+03	25600.00
C8AF3C	2017-08-06 16:44:00+03	85000.00
C8B035	2017-07-19 11:51:00+03	140300.00
C8B056	2017-07-04 07:45:00+03	51000.00
C8B0B4	2017-08-08 22:53:00+03	39600.00
C8B0E8	2017-08-07 11:22:00+03	384600.00
C8B123	2017-07-07 05:33:00+03	15400.00
C8B152	2017-07-11 13:13:00+03	95600.00
C8B1A4	2017-07-30 06:26:00+03	51900.00
C8B205	2017-07-23 10:09:00+03	25400.00
C8B27F	2017-08-08 20:48:00+03	7400.00
C8B28E	2017-07-12 06:02:00+03	36200.00
C8B2B5	2017-08-05 23:18:00+03	34000.00
C8B2F4	2017-07-19 03:25:00+03	44600.00
C8B2FD	2017-08-05 09:30:00+03	25100.00
C8B357	2017-06-26 17:51:00+03	59300.00
C8B37B	2017-07-28 19:17:00+03	394800.00
C8B38B	2017-08-11 10:48:00+03	77600.00
C8B3A4	2017-07-06 09:50:00+03	218400.00
C8B3FF	2017-07-27 19:19:00+03	8000.00
C8B434	2017-07-08 02:22:00+03	33500.00
C8B452	2017-07-31 03:35:00+03	42000.00
C8B461	2017-07-02 00:12:00+03	117000.00
C8B4E6	2017-07-03 22:46:00+03	74800.00
C8B527	2017-08-10 02:06:00+03	189800.00
C8B535	2017-08-12 12:25:00+03	235500.00
C8B59A	2017-07-13 02:12:00+03	58500.00
C8B5F6	2017-08-06 20:53:00+03	28700.00
C8B617	2017-08-11 12:52:00+03	26000.00
C8B64C	2017-07-03 13:09:00+03	265800.00
C8B684	2017-07-11 10:15:00+03	22000.00
C8B706	2017-07-09 01:26:00+03	14800.00
C8B71A	2017-07-11 03:40:00+03	67700.00
C8B77E	2017-07-24 18:44:00+03	43600.00
C8B7D0	2017-07-28 20:42:00+03	27200.00
C8B7F3	2017-07-01 17:10:00+03	69500.00
C8B7FF	2017-07-23 16:45:00+03	31600.00
C8B831	2017-07-16 23:10:00+03	67900.00
C8B835	2017-06-29 18:44:00+03	56600.00
C8B852	2017-07-27 09:43:00+03	140400.00
C8B857	2017-08-01 07:42:00+03	25200.00
C8B8A9	2017-07-05 21:10:00+03	57400.00
C8B8C7	2017-08-11 08:45:00+03	15700.00
C8B8DB	2017-08-05 16:56:00+03	44600.00
C8B8FF	2017-07-18 13:33:00+03	50200.00
C8B946	2017-08-11 02:43:00+03	32800.00
C8B977	2017-07-22 03:42:00+03	56000.00
C8B991	2017-08-02 00:47:00+03	99700.00
C8B9D2	2017-07-02 16:19:00+03	38600.00
C8B9ED	2017-06-30 08:34:00+03	112600.00
C8BAB4	2017-07-30 12:53:00+03	22000.00
C8BB48	2017-07-29 04:47:00+03	56100.00
C8BB58	2017-07-08 09:42:00+03	27200.00
C8BB85	2017-07-24 09:21:00+03	74400.00
C8BBA6	2017-07-03 11:49:00+03	202600.00
C8BC37	2017-07-17 03:19:00+03	65500.00
C8BCB1	2017-07-27 22:43:00+03	68100.00
C8BCD0	2017-07-17 13:37:00+03	225800.00
C8BD4F	2017-08-13 16:43:00+03	7400.00
C8BD83	2017-07-09 18:56:00+03	31200.00
C8BD9C	2017-06-30 08:57:00+03	26000.00
C8BE37	2017-08-04 04:22:00+03	32600.00
C8BE3F	2017-07-08 17:14:00+03	83000.00
C8BE61	2017-07-16 16:43:00+03	179400.00
C8BEF9	2017-07-21 20:48:00+03	40000.00
C8BEFD	2017-08-09 19:57:00+03	139400.00
C8BF34	2017-07-22 22:20:00+03	32400.00
C8BFA6	2017-08-07 08:50:00+03	23200.00
C8C011	2017-07-05 01:26:00+03	88600.00
C8C045	2017-07-21 15:06:00+03	133100.00
C8C084	2017-07-31 14:37:00+03	114800.00
C8C0AD	2017-06-28 17:58:00+03	26800.00
C8C0C5	2017-08-01 01:38:00+03	39300.00
C8C0D6	2017-07-10 11:11:00+03	24800.00
C8C0E7	2017-08-14 01:47:00+03	103100.00
C8C0EC	2017-07-27 10:36:00+03	67800.00
C8C11F	2017-07-18 19:53:00+03	15400.00
C8C16C	2017-07-27 20:46:00+03	59800.00
C8C180	2017-08-01 16:44:00+03	31800.00
C8C1E3	2017-07-21 21:29:00+03	15100.00
C8C1F5	2017-07-22 07:44:00+03	95600.00
C8C1FA	2017-08-14 10:15:00+03	179400.00
C8C241	2017-08-02 19:30:00+03	67600.00
C8C251	2017-07-28 16:19:00+03	46000.00
C8C285	2017-07-26 22:02:00+03	412400.00
C8C2BC	2017-08-07 01:24:00+03	271300.00
C8C2DF	2017-07-22 13:06:00+03	316700.00
C8C30F	2017-07-21 22:00:00+03	62600.00
C8C319	2017-07-01 01:15:00+03	23100.00
C8C336	2017-07-10 21:16:00+03	246000.00
C8C34E	2017-07-18 16:10:00+03	26000.00
C8C3E2	2017-07-02 14:02:00+03	30200.00
C8C420	2017-07-14 08:15:00+03	36200.00
C8C42D	2017-07-31 23:34:00+03	58600.00
C8C496	2017-07-10 07:22:00+03	285800.00
C8C4C5	2017-07-08 16:37:00+03	69400.00
C8C4EF	2017-07-31 15:48:00+03	34400.00
C8C4F5	2017-07-16 03:35:00+03	257600.00
C8C50C	2017-08-08 22:20:00+03	13400.00
C8C54B	2017-07-17 10:29:00+03	78300.00
C8C55D	2017-08-11 16:05:00+03	336000.00
C8C5F3	2017-08-09 17:34:00+03	6700.00
C8C67C	2017-08-09 09:58:00+03	28800.00
C8C68B	2017-07-25 07:16:00+03	41400.00
C8C71E	2017-08-06 08:28:00+03	29600.00
C8C771	2017-08-06 04:46:00+03	188000.00
C8C79C	2017-07-28 10:58:00+03	15200.00
C8C7A1	2017-06-29 11:09:00+03	25400.00
C8C816	2017-07-24 14:09:00+03	6600.00
C8C977	2017-07-31 05:34:00+03	53700.00
C8C982	2017-08-09 06:11:00+03	28000.00
C8C9E9	2017-08-03 01:53:00+03	104800.00
C8CA57	2017-08-12 15:30:00+03	37900.00
C8CA88	2017-08-05 12:57:00+03	223200.00
C8CAC9	2017-07-10 15:32:00+03	73500.00
C8CAEB	2017-08-09 07:40:00+03	135400.00
C8CB00	2017-07-12 07:58:00+03	90800.00
C8CB68	2017-08-04 05:03:00+03	40800.00
C8CB94	2017-08-11 04:06:00+03	20800.00
C8CD39	2017-07-28 04:40:00+03	94700.00
C8CD43	2017-07-24 21:56:00+03	98100.00
C8CD45	2017-07-20 02:08:00+03	6000.00
C8CDBD	2017-07-06 02:24:00+03	8000.00
C8CE2D	2017-08-15 03:03:00+03	12600.00
C8CE50	2017-07-11 05:46:00+03	77200.00
C8CE51	2017-07-19 11:44:00+03	51600.00
C8CE5E	2017-08-09 16:03:00+03	173200.00
C8CE63	2017-07-11 21:43:00+03	44000.00
C8CEF5	2017-08-12 05:23:00+03	56000.00
C8CEF8	2017-06-29 05:38:00+03	27200.00
C8CF07	2017-06-30 23:32:00+03	190800.00
C8CF2F	2017-07-17 20:01:00+03	30400.00
C8CF84	2017-07-22 06:15:00+03	74100.00
C8CFD9	2017-08-10 00:09:00+03	45100.00
C8CFEF	2017-07-24 05:45:00+03	88700.00
C8D02F	2017-07-21 13:03:00+03	25200.00
C8D036	2017-07-01 06:04:00+03	46700.00
C8D06F	2017-08-05 06:10:00+03	25400.00
C8D0B3	2017-07-24 02:46:00+03	32700.00
C8D0B5	2017-07-26 02:16:00+03	77200.00
C8D0FB	2017-06-28 17:43:00+03	14800.00
C8D100	2017-07-27 23:04:00+03	84500.00
C8D164	2017-07-27 18:45:00+03	43000.00
C8D29D	2017-07-30 21:20:00+03	57200.00
C8D2C9	2017-08-05 09:19:00+03	54800.00
C8D32C	2017-07-17 05:22:00+03	102100.00
C8D336	2017-08-11 22:52:00+03	123000.00
C8D39C	2017-07-13 13:11:00+03	42700.00
C8D3C1	2017-08-11 09:17:00+03	62100.00
C8D3C9	2017-07-02 10:36:00+03	123000.00
C8D434	2017-07-14 19:41:00+03	36200.00
C8D448	2017-07-28 08:34:00+03	156600.00
C8D458	2017-07-18 07:47:00+03	57600.00
C8D460	2017-07-04 13:18:00+03	46300.00
C8D483	2017-08-05 18:13:00+03	38600.00
C8D4DD	2017-08-08 14:05:00+03	6700.00
C8D52B	2017-07-29 09:14:00+03	46000.00
C8D5AA	2017-08-04 14:01:00+03	6700.00
C8D5CD	2017-08-09 11:38:00+03	397700.00
C8D5EA	2017-08-13 08:33:00+03	12000.00
C8D607	2017-06-30 03:11:00+03	83100.00
C8D628	2017-07-06 11:06:00+03	13600.00
C8D630	2017-07-10 01:38:00+03	48800.00
C8D67C	2017-07-27 10:17:00+03	46400.00
C8D6D8	2017-07-26 02:35:00+03	28800.00
C8D84E	2017-07-05 10:18:00+03	134400.00
C8D856	2017-08-14 01:10:00+03	13600.00
C8D862	2017-07-13 10:43:00+03	36200.00
C8D88F	2017-07-28 07:24:00+03	67300.00
C8D8AB	2017-06-30 03:15:00+03	125200.00
C8D913	2017-08-02 07:31:00+03	179500.00
C8D918	2017-08-10 11:42:00+03	29600.00
C8D969	2017-07-04 04:13:00+03	77200.00
C8D97E	2017-07-12 19:32:00+03	133700.00
C8DA3A	2017-08-05 10:58:00+03	26700.00
C8DAB9	2017-08-03 07:04:00+03	63200.00
C8DABE	2017-07-12 04:26:00+03	25600.00
C8DAF3	2017-07-18 20:02:00+03	123000.00
C8DB64	2017-07-08 02:04:00+03	271100.00
C8DBFC	2017-08-04 13:58:00+03	78500.00
C8DC94	2017-07-28 19:28:00+03	62000.00
C8DC9D	2017-07-02 17:24:00+03	26800.00
C8DCE9	2017-07-19 07:49:00+03	258400.00
C8DCF4	2017-07-04 07:21:00+03	101500.00
C8DD19	2017-08-01 18:29:00+03	46300.00
C8DDA1	2017-07-09 23:18:00+03	47100.00
C8DDAC	2017-07-30 16:14:00+03	6800.00
C8DDD5	2017-07-25 12:59:00+03	82200.00
C8DE19	2017-07-18 05:38:00+03	59800.00
C8DE49	2017-07-02 12:41:00+03	43600.00
C8DE50	2017-07-21 13:13:00+03	55800.00
C8DF5E	2017-08-04 19:16:00+03	56900.00
C8DFB1	2017-08-11 03:42:00+03	62700.00
C8DFCB	2017-08-08 00:35:00+03	50600.00
C8DFD9	2017-07-09 17:19:00+03	602700.00
C8E003	2017-08-08 16:31:00+03	60300.00
C8E030	2017-07-26 02:05:00+03	168000.00
C8E06C	2017-08-08 04:48:00+03	30900.00
C8E070	2017-07-05 10:06:00+03	70600.00
C8E08B	2017-07-29 23:57:00+03	11700.00
C8E097	2017-07-28 22:19:00+03	93000.00
C8E1BA	2017-07-17 16:18:00+03	47600.00
C8E1C8	2017-08-10 08:50:00+03	529800.00
C8E23A	2017-07-17 18:18:00+03	256200.00
C8E2A5	2017-07-02 12:23:00+03	538000.00
C8E2B3	2017-07-31 15:22:00+03	125400.00
C8E328	2017-07-23 11:17:00+03	34100.00
C8E33E	2017-07-30 04:47:00+03	123000.00
C8E33F	2017-07-15 21:59:00+03	58900.00
C8E344	2017-08-08 23:58:00+03	198400.00
C8E3AF	2017-07-25 18:35:00+03	24800.00
C8E45C	2017-07-09 06:46:00+03	26000.00
C8E5F9	2017-07-12 11:38:00+03	99200.00
C8E637	2017-08-04 19:56:00+03	87700.00
C8E67D	2017-08-14 04:08:00+03	15400.00
C8E6C0	2017-08-10 19:34:00+03	28000.00
C8E6D3	2017-08-12 04:36:00+03	46400.00
C8E7A9	2017-07-13 14:34:00+03	73100.00
C8E87A	2017-07-20 12:47:00+03	48700.00
C8E8DA	2017-07-02 08:35:00+03	46400.00
C8E92B	2017-07-05 01:25:00+03	30200.00
C8E942	2017-07-02 14:01:00+03	74800.00
C8EA29	2017-07-10 21:13:00+03	136800.00
C8EA2C	2017-07-25 18:48:00+03	210800.00
C8EA49	2017-07-21 16:55:00+03	28000.00
C8EABF	2017-07-13 19:18:00+03	28800.00
C8EB14	2017-07-13 22:07:00+03	76200.00
C8EBAD	2017-08-04 14:12:00+03	53600.00
C8EBBB	2017-08-01 21:57:00+03	45200.00
C8EBFE	2017-07-28 11:55:00+03	103200.00
C8EC50	2017-07-10 03:37:00+03	37000.00
C8EC92	2017-07-25 06:28:00+03	87900.00
C8ECA9	2017-07-14 05:27:00+03	56000.00
C8ECDA	2017-07-20 22:43:00+03	69500.00
C8ECE0	2017-07-07 15:01:00+03	160700.00
C8ECF9	2017-07-24 02:08:00+03	48800.00
C8ECFC	2017-07-15 18:34:00+03	34000.00
C8ED96	2017-08-10 23:17:00+03	46800.00
C8EDB1	2017-07-29 01:30:00+03	37500.00
C8EE8D	2017-07-19 01:41:00+03	13600.00
C8EE97	2017-08-06 21:52:00+03	57500.00
C8EEB3	2017-07-13 04:38:00+03	79600.00
C8EF10	2017-08-15 00:25:00+03	168000.00
C8EFA7	2017-07-03 12:50:00+03	40800.00
C8F061	2017-06-28 17:35:00+03	28000.00
C8F0A5	2017-08-08 07:56:00+03	24400.00
C8F0DE	2017-07-10 21:26:00+03	38600.00
C8F122	2017-08-13 23:30:00+03	58000.00
C8F164	2017-07-21 15:23:00+03	81400.00
C8F1C3	2017-08-01 14:04:00+03	170000.00
C8F1F9	2017-07-15 00:25:00+03	6400.00
C8F225	2017-08-15 07:52:00+03	28000.00
C8F297	2017-06-30 07:06:00+03	77600.00
C8F2F0	2017-07-14 13:45:00+03	56600.00
C8F2FC	2017-08-07 02:26:00+03	136500.00
C8F326	2017-07-12 12:04:00+03	59200.00
C8F3A7	2017-07-15 09:33:00+03	147000.00
C8F3F5	2017-08-02 07:00:00+03	26700.00
C8F430	2017-07-13 23:00:00+03	56000.00
C8F43A	2017-08-11 13:13:00+03	128600.00
C8F43C	2017-07-22 15:46:00+03	46400.00
C8F45F	2017-07-16 08:45:00+03	40800.00
C8F4BD	2017-07-26 05:04:00+03	36000.00
C8F4D0	2017-07-04 21:39:00+03	44800.00
C8F55B	2017-07-30 19:52:00+03	26000.00
C8F56D	2017-07-12 19:08:00+03	521200.00
C8F593	2017-08-03 03:11:00+03	103800.00
C8F5A6	2017-07-15 03:47:00+03	6800.00
C8F5BF	2017-07-20 04:14:00+03	12600.00
C8F618	2017-08-05 08:57:00+03	23200.00
C8F619	2017-08-15 13:07:00+03	50400.00
C8F647	2017-07-06 20:45:00+03	111700.00
C8F65F	2017-07-21 12:38:00+03	300300.00
C8F6C4	2017-08-01 01:20:00+03	23400.00
C8F71D	2017-07-07 15:25:00+03	173900.00
C8F748	2017-07-20 01:19:00+03	123600.00
C8F75C	2017-07-23 00:33:00+03	105100.00
C8F786	2017-08-08 11:08:00+03	55800.00
C8F787	2017-07-14 02:47:00+03	46200.00
C8F7DB	2017-07-26 23:36:00+03	29200.00
C8F7E3	2017-08-02 16:48:00+03	56000.00
C8F85A	2017-06-29 20:28:00+03	69500.00
C8F89B	2017-07-11 23:58:00+03	46400.00
C8F915	2017-07-21 05:54:00+03	44400.00
C8F91C	2017-08-02 21:55:00+03	47200.00
C8F925	2017-06-29 21:27:00+03	11600.00
C8F958	2017-07-18 09:34:00+03	35600.00
C8F99D	2017-07-24 05:49:00+03	94000.00
C8FA97	2017-07-02 14:43:00+03	30200.00
C8FAB2	2017-07-23 10:47:00+03	88100.00
C8FAF8	2017-08-02 00:43:00+03	52800.00
C8FB72	2017-07-27 08:42:00+03	7400.00
C8FB77	2017-07-24 16:27:00+03	51300.00
C8FBDD	2017-08-15 16:52:00+03	30800.00
C8FBEB	2017-08-10 09:24:00+03	25200.00
C8FBFA	2017-08-14 08:29:00+03	161200.00
C8FC06	2017-07-25 02:24:00+03	128800.00
C8FC5D	2017-07-06 04:31:00+03	56000.00
C8FD02	2017-07-16 19:07:00+03	270700.00
C8FD52	2017-07-08 00:23:00+03	59800.00
C8FD8F	2017-08-06 09:59:00+03	27200.00
C8FDA2	2017-06-30 00:28:00+03	51900.00
C8FDF2	2017-07-31 17:18:00+03	21400.00
C8FEEC	2017-08-10 04:28:00+03	217900.00
C9000D	2017-07-27 18:44:00+03	90800.00
C9006A	2017-07-21 10:20:00+03	140900.00
C90094	2017-08-07 14:50:00+03	43900.00
C900A1	2017-08-15 11:19:00+03	81600.00
C900E3	2017-08-05 13:45:00+03	40800.00
C90100	2017-07-30 14:59:00+03	28000.00
C9014E	2017-06-30 02:51:00+03	40000.00
C90193	2017-08-06 13:58:00+03	21800.00
C901B2	2017-08-06 04:29:00+03	139500.00
C901F2	2017-07-12 07:35:00+03	69500.00
C90241	2017-07-31 22:24:00+03	46300.00
C90246	2017-07-27 15:41:00+03	134200.00
C902B7	2017-07-31 03:19:00+03	28800.00
C902E2	2017-08-14 04:51:00+03	50600.00
C902F8	2017-08-09 06:35:00+03	67200.00
C9033E	2017-07-12 16:16:00+03	80500.00
C9037F	2017-07-06 08:38:00+03	52700.00
C90413	2017-07-09 02:29:00+03	49000.00
C90436	2017-07-23 02:00:00+03	47400.00
C90488	2017-08-07 05:21:00+03	123000.00
C904EE	2017-07-26 10:32:00+03	27200.00
C904FC	2017-07-23 10:47:00+03	29600.00
C90542	2017-08-07 11:28:00+03	155600.00
C905A8	2017-07-25 23:44:00+03	22000.00
C905DA	2017-07-26 04:52:00+03	20200.00
C90635	2017-07-17 20:08:00+03	24300.00
C90678	2017-08-10 21:16:00+03	75300.00
C906B2	2017-08-08 01:02:00+03	111600.00
C90751	2017-08-08 22:26:00+03	88000.00
C9075A	2017-08-14 09:44:00+03	136800.00
C90761	2017-08-10 17:17:00+03	109800.00
C90771	2017-08-02 00:42:00+03	32600.00
C907C7	2017-07-23 19:50:00+03	56600.00
C907D9	2017-07-17 16:35:00+03	25900.00
C90844	2017-07-04 19:46:00+03	41200.00
C90853	2017-07-03 10:31:00+03	38800.00
C908C3	2017-07-02 04:05:00+03	86400.00
C908E9	2017-08-14 23:19:00+03	18400.00
C90913	2017-07-16 12:28:00+03	113800.00
C90928	2017-07-04 11:27:00+03	170000.00
C90940	2017-07-05 07:59:00+03	107800.00
C9095D	2017-08-14 18:26:00+03	265700.00
C9096D	2017-07-01 00:48:00+03	70800.00
C909AD	2017-07-09 02:36:00+03	117600.00
C909EF	2017-07-10 09:16:00+03	67000.00
C90A1D	2017-07-19 01:35:00+03	105100.00
C90A41	2017-08-07 19:17:00+03	111400.00
C90A84	2017-08-14 13:03:00+03	115800.00
C90AC6	2017-08-06 03:04:00+03	65900.00
C90AD0	2017-07-28 18:25:00+03	77200.00
C90AD9	2017-08-07 05:49:00+03	88100.00
C90AFF	2017-07-24 10:23:00+03	102100.00
C90B01	2017-07-23 09:29:00+03	40800.00
C90B1E	2017-07-17 14:54:00+03	102100.00
C90B4A	2017-07-29 21:59:00+03	25600.00
C90B8A	2017-07-11 15:43:00+03	79900.00
C90B91	2017-07-30 20:30:00+03	66400.00
C90B98	2017-07-14 11:56:00+03	20400.00
C90BAD	2017-07-30 11:53:00+03	65900.00
C90BC6	2017-07-20 16:12:00+03	28000.00
C90BDB	2017-07-07 04:37:00+03	6300.00
C90C0C	2017-08-08 15:27:00+03	114300.00
C90C48	2017-07-28 08:47:00+03	84900.00
C90D00	2017-08-14 08:03:00+03	24200.00
C90D2E	2017-07-21 23:16:00+03	134400.00
C90D99	2017-07-16 08:28:00+03	26800.00
C90DBC	2017-07-04 18:36:00+03	158100.00
C90E15	2017-08-13 22:11:00+03	18600.00
C90E21	2017-08-05 03:39:00+03	70800.00
C90E24	2017-07-27 17:41:00+03	377400.00
C90E27	2017-07-16 10:22:00+03	47500.00
C90E28	2017-08-14 14:12:00+03	26800.00
C90E2B	2017-07-23 14:08:00+03	28000.00
C90E4C	2017-08-05 12:46:00+03	48800.00
C90E5B	2017-07-09 10:24:00+03	115800.00
C90E7C	2017-07-21 19:22:00+03	23600.00
C90F3C	2017-07-10 05:19:00+03	21400.00
C90F5D	2017-07-23 23:25:00+03	65900.00
C90FFA	2017-08-12 08:25:00+03	369000.00
C91025	2017-08-11 07:26:00+03	67600.00
C91030	2017-07-12 15:36:00+03	67600.00
C910B5	2017-07-05 22:42:00+03	40800.00
C9114E	2017-08-09 10:51:00+03	54300.00
C91150	2017-08-03 09:47:00+03	36200.00
C9118C	2017-07-04 12:11:00+03	6600.00
C9125F	2017-08-06 21:54:00+03	48400.00
C912BF	2017-07-15 04:52:00+03	65500.00
C912E7	2017-08-09 12:51:00+03	102800.00
C912E8	2017-06-27 18:12:00+03	369000.00
C9131C	2017-08-02 15:29:00+03	84200.00
C91327	2017-07-16 16:26:00+03	101100.00
C913A6	2017-07-18 13:59:00+03	47400.00
C913AE	2017-07-02 16:10:00+03	89600.00
C913B6	2017-08-14 17:41:00+03	40900.00
C913B9	2017-07-27 12:47:00+03	16400.00
C913BE	2017-08-14 13:12:00+03	26800.00
C913CD	2017-07-31 03:23:00+03	40600.00
C913E7	2017-07-22 22:45:00+03	28000.00
C91401	2017-07-25 05:18:00+03	15800.00
C91405	2017-07-17 07:11:00+03	39200.00
C9145B	2017-07-03 00:11:00+03	81600.00
C91469	2017-07-08 10:21:00+03	137600.00
C91474	2017-07-19 20:58:00+03	205600.00
C91494	2017-07-30 00:48:00+03	35300.00
C9149A	2017-07-22 04:54:00+03	255600.00
C9159F	2017-07-10 13:24:00+03	199700.00
C91612	2017-07-13 17:58:00+03	46400.00
C91621	2017-07-15 16:26:00+03	113000.00
C91644	2017-07-12 14:30:00+03	28000.00
C91690	2017-07-24 17:26:00+03	57400.00
C916B0	2017-07-21 19:07:00+03	31400.00
C916E6	2017-07-28 04:46:00+03	97800.00
C91707	2017-08-11 22:51:00+03	177200.00
C917B7	2017-07-31 14:43:00+03	260300.00
C917D5	2017-08-06 18:14:00+03	260300.00
C917F0	2017-07-03 05:21:00+03	240600.00
C91847	2017-08-13 05:45:00+03	37000.00
C918BC	2017-08-13 19:04:00+03	12600.00
C918F9	2017-07-30 15:31:00+03	15900.00
C9190A	2017-07-25 18:36:00+03	31400.00
C91918	2017-08-05 09:52:00+03	35300.00
C91937	2017-07-13 00:07:00+03	27000.00
C9198B	2017-07-18 01:06:00+03	46300.00
C919A2	2017-07-24 11:13:00+03	125400.00
C919FB	2017-08-12 12:39:00+03	37100.00
C91A20	2017-07-03 01:35:00+03	45100.00
C91AA1	2017-07-09 18:07:00+03	106900.00
C91ACF	2017-07-11 14:01:00+03	18800.00
C91AE1	2017-08-07 09:38:00+03	135400.00
C91AE6	2017-08-05 20:29:00+03	363800.00
C91B36	2017-07-06 17:37:00+03	177200.00
C91B3C	2017-08-12 16:25:00+03	286700.00
C91B4E	2017-07-16 10:33:00+03	36800.00
C91B88	2017-08-13 20:48:00+03	124300.00
C91BAA	2017-07-09 15:08:00+03	47400.00
C91BC9	2017-07-19 06:05:00+03	26000.00
C91C23	2017-07-01 12:01:00+03	178800.00
C91C5F	2017-07-26 11:49:00+03	111600.00
C91C61	2017-07-02 03:25:00+03	55800.00
C91C68	2017-07-14 18:45:00+03	271100.00
C91CAB	2017-07-30 18:12:00+03	68000.00
C91CF4	2017-08-10 10:53:00+03	23200.00
C91D64	2017-07-24 06:24:00+03	21400.00
C91D8B	2017-07-30 17:58:00+03	23200.00
C91DC6	2017-08-08 06:07:00+03	56600.00
C91E2D	2017-07-06 03:34:00+03	40800.00
C91E6B	2017-08-13 18:15:00+03	41200.00
C91F0D	2017-07-22 21:35:00+03	124200.00
C91FFC	2017-08-01 08:20:00+03	19600.00
C92029	2017-08-15 15:13:00+03	265700.00
C9204E	2017-08-10 09:28:00+03	49100.00
C920BB	2017-08-02 22:26:00+03	53400.00
C921D6	2017-08-07 12:24:00+03	60400.00
C92207	2017-08-12 21:08:00+03	21400.00
C92230	2017-08-12 02:40:00+03	137900.00
C922A9	2017-08-13 21:39:00+03	16400.00
C922B6	2017-07-15 04:48:00+03	40800.00
C922CC	2017-07-26 03:08:00+03	139100.00
C922EE	2017-07-19 23:28:00+03	52000.00
C922F9	2017-07-01 04:45:00+03	29800.00
C92412	2017-07-01 09:11:00+03	67200.00
C924A5	2017-07-10 03:34:00+03	98400.00
C924BA	2017-07-27 15:42:00+03	89000.00
C924E8	2017-07-12 18:32:00+03	23200.00
C92537	2017-07-16 01:19:00+03	139400.00
C92561	2017-07-29 16:55:00+03	40000.00
C925A7	2017-08-12 20:08:00+03	86500.00
C925BA	2017-08-07 12:55:00+03	200800.00
C9263B	2017-08-07 21:29:00+03	118600.00
C92692	2017-08-02 21:53:00+03	43200.00
C9269C	2017-07-29 09:30:00+03	11600.00
C9269F	2017-07-30 22:06:00+03	56600.00
C926B2	2017-07-14 18:03:00+03	21400.00
C926F2	2017-07-03 18:39:00+03	45100.00
C92715	2017-07-25 12:42:00+03	75200.00
C9278E	2017-07-07 12:50:00+03	46400.00
C9279A	2017-07-04 17:40:00+03	242600.00
C9279C	2017-08-12 13:01:00+03	137600.00
C9279F	2017-07-26 18:16:00+03	40800.00
C927C1	2017-08-05 22:18:00+03	6300.00
C927E9	2017-07-29 01:30:00+03	413400.00
C927FD	2017-07-27 05:10:00+03	19600.00
C92802	2017-08-11 05:58:00+03	111000.00
C9286C	2017-07-15 06:36:00+03	12600.00
C9286E	2017-08-03 10:19:00+03	56000.00
C92885	2017-08-08 18:14:00+03	42700.00
C928AD	2017-07-28 21:39:00+03	141100.00
C928CF	2017-06-30 11:33:00+03	54800.00
C928D0	2017-07-18 08:59:00+03	16400.00
C928D7	2017-07-19 09:31:00+03	74400.00
C92909	2017-08-02 05:30:00+03	40800.00
C92913	2017-08-12 09:49:00+03	22100.00
C92964	2017-07-12 09:05:00+03	102100.00
C92969	2017-07-18 11:59:00+03	76900.00
C9298B	2017-07-06 19:44:00+03	137100.00
C9299F	2017-07-14 02:31:00+03	169900.00
C92A26	2017-07-03 22:04:00+03	56000.00
C92A82	2017-08-13 04:00:00+03	23600.00
C92AE2	2017-08-09 00:32:00+03	273600.00
C92AE6	2017-07-23 19:51:00+03	46400.00
C92B28	2017-07-11 11:50:00+03	121400.00
C92B40	2017-07-23 17:28:00+03	75600.00
C92B7D	2017-07-03 09:03:00+03	75600.00
C92C59	2017-08-14 03:53:00+03	28800.00
C92C60	2017-08-04 12:24:00+03	17800.00
C92DF4	2017-08-11 05:01:00+03	43200.00
C92E2C	2017-08-10 13:26:00+03	44500.00
C92EFB	2017-07-12 08:00:00+03	28000.00
C92F1D	2017-07-24 10:01:00+03	20600.00
C92F78	2017-07-08 16:13:00+03	48400.00
C9300D	2017-07-04 12:19:00+03	68800.00
C93012	2017-07-07 01:09:00+03	43500.00
C93063	2017-07-11 07:06:00+03	42800.00
C930C9	2017-07-23 15:26:00+03	144400.00
C930DB	2017-07-18 20:33:00+03	97500.00
C93124	2017-07-03 06:33:00+03	29600.00
C93134	2017-07-10 11:41:00+03	59700.00
C9314B	2017-07-14 20:27:00+03	66000.00
C9316A	2017-07-09 10:09:00+03	53100.00
C93198	2017-07-13 01:12:00+03	29600.00
C931E1	2017-08-06 01:46:00+03	532600.00
C93207	2017-08-12 23:27:00+03	66600.00
C9323A	2017-07-21 07:20:00+03	46200.00
C93252	2017-07-13 11:47:00+03	12200.00
C9326D	2017-07-08 18:11:00+03	29600.00
C93273	2017-08-15 11:06:00+03	37200.00
C932B4	2017-07-31 09:54:00+03	107500.00
C93318	2017-07-08 13:51:00+03	26000.00
C9331F	2017-07-03 09:45:00+03	23200.00
C933BF	2017-06-30 07:27:00+03	92000.00
C93425	2017-07-01 11:12:00+03	44500.00
C93448	2017-07-30 09:26:00+03	62900.00
C93452	2017-07-01 12:29:00+03	406700.00
C93478	2017-07-06 02:51:00+03	24400.00
C93480	2017-07-13 01:30:00+03	430800.00
C934A3	2017-06-30 11:18:00+03	304600.00
C934A9	2017-07-15 10:21:00+03	233700.00
C934AA	2017-08-01 05:59:00+03	58000.00
C934D0	2017-08-05 22:26:00+03	6600.00
C934E2	2017-07-07 20:50:00+03	20400.00
C934FF	2017-08-02 09:39:00+03	60700.00
C93621	2017-08-06 07:16:00+03	28000.00
C936C7	2017-07-29 20:58:00+03	57800.00
C936DD	2017-08-11 22:57:00+03	6400.00
C936FC	2017-07-13 20:19:00+03	23600.00
C936FE	2017-08-02 22:59:00+03	84100.00
C9371E	2017-07-25 06:19:00+03	62600.00
C9373E	2017-08-08 09:59:00+03	62000.00
C937E7	2017-08-07 04:39:00+03	20800.00
C93805	2017-07-28 22:29:00+03	41600.00
C93822	2017-07-09 20:39:00+03	14800.00
C93838	2017-06-29 03:17:00+03	149200.00
C938DF	2017-08-13 09:33:00+03	12400.00
C939DE	2017-07-07 12:58:00+03	89600.00
C939F7	2017-08-05 01:28:00+03	13000.00
C93A23	2017-07-31 08:35:00+03	112000.00
C93A54	2017-07-10 20:23:00+03	42800.00
C93AA0	2017-06-28 18:57:00+03	46400.00
C93AD5	2017-07-26 00:47:00+03	38000.00
C93AE9	2017-08-06 00:11:00+03	39100.00
C93AFF	2017-07-17 13:43:00+03	28000.00
C93B4D	2017-08-11 09:36:00+03	16400.00
C93B87	2017-08-07 08:29:00+03	29200.00
C93B8F	2017-07-09 15:41:00+03	136500.00
C93BE9	2017-08-05 13:56:00+03	18400.00
C93BFA	2017-08-12 18:31:00+03	57500.00
C93C0D	2017-07-23 06:54:00+03	23200.00
C93C4B	2017-08-14 07:25:00+03	46400.00
C93C4F	2017-08-06 12:57:00+03	65600.00
C93CB8	2017-07-08 20:34:00+03	41800.00
C93CDA	2017-08-07 18:33:00+03	205400.00
C93CFB	2017-07-15 23:35:00+03	56000.00
C93D4B	2017-07-22 00:58:00+03	62100.00
C93D64	2017-08-10 13:45:00+03	34000.00
C93E06	2017-07-01 20:48:00+03	62600.00
C93E50	2017-07-18 18:12:00+03	44000.00
C93E9D	2017-08-03 00:11:00+03	28800.00
C93EEE	2017-07-19 00:10:00+03	54800.00
C93F2B	2017-07-10 04:42:00+03	155600.00
C93FDE	2017-08-07 14:08:00+03	75600.00
C93FEF	2017-08-08 02:01:00+03	21800.00
C94010	2017-07-26 12:56:00+03	31400.00
C94073	2017-07-16 15:39:00+03	81700.00
C940A0	2017-08-13 04:56:00+03	85000.00
C940C2	2017-08-14 19:27:00+03	71900.00
C94111	2017-07-18 14:19:00+03	19600.00
C94116	2017-07-25 09:36:00+03	41800.00
C9412E	2017-07-28 15:25:00+03	135600.00
C94134	2017-07-22 22:03:00+03	6800.00
C94147	2017-07-28 20:21:00+03	55800.00
C94154	2017-08-03 02:03:00+03	46000.00
C94167	2017-08-02 05:25:00+03	37700.00
C94174	2017-07-06 19:34:00+03	21800.00
C941CB	2017-08-13 15:48:00+03	14000.00
C941D7	2017-07-28 18:22:00+03	193600.00
C941E2	2017-07-18 13:15:00+03	95600.00
C941FE	2017-06-26 00:27:00+03	26200.00
C942AE	2017-07-19 01:38:00+03	135400.00
C942C3	2017-07-09 15:34:00+03	123000.00
C9430C	2017-07-31 14:01:00+03	21800.00
C94399	2017-08-03 20:45:00+03	89600.00
C9439F	2017-07-10 02:55:00+03	80900.00
C943AB	2017-07-29 10:30:00+03	25400.00
C9440C	2017-07-15 19:33:00+03	193600.00
C94440	2017-08-05 06:30:00+03	163500.00
C9445D	2017-07-03 19:38:00+03	133100.00
C94470	2017-08-10 18:21:00+03	37200.00
C944A3	2017-07-06 20:13:00+03	114200.00
C944CA	2017-07-23 20:13:00+03	48800.00
C944D5	2017-07-05 10:41:00+03	369000.00
C944E0	2017-07-02 23:06:00+03	12600.00
C944F7	2017-07-12 15:00:00+03	12400.00
C94528	2017-07-27 14:46:00+03	133200.00
C9454E	2017-06-29 20:30:00+03	68800.00
C94619	2017-07-15 09:06:00+03	55800.00
C9464A	2017-08-15 15:21:00+03	6800.00
C9464E	2017-07-23 21:13:00+03	11600.00
C94670	2017-07-18 17:18:00+03	17800.00
C9468B	2017-08-13 16:17:00+03	117900.00
C9469A	2017-07-21 08:49:00+03	133200.00
C946AC	2017-08-02 05:56:00+03	66000.00
C94708	2017-07-01 10:30:00+03	516800.00
C9471A	2017-07-06 11:48:00+03	34000.00
C9476D	2017-07-25 08:19:00+03	152900.00
C947E6	2017-07-30 19:57:00+03	24300.00
C9480D	2017-07-19 21:06:00+03	40800.00
C948A0	2017-06-29 11:32:00+03	30200.00
C948DF	2017-08-10 01:38:00+03	28000.00
C9490F	2017-08-01 05:24:00+03	31600.00
C94927	2017-07-09 19:34:00+03	135600.00
C9493C	2017-07-23 08:09:00+03	40100.00
C94944	2017-07-30 12:10:00+03	26800.00
C9497F	2017-07-14 19:45:00+03	27200.00
C94991	2017-06-29 18:25:00+03	59200.00
C949B9	2017-07-05 22:01:00+03	46300.00
C949C9	2017-07-06 22:12:00+03	112000.00
C949D0	2017-07-07 01:37:00+03	129200.00
C949E2	2017-08-04 16:12:00+03	53300.00
C94A01	2017-07-10 10:26:00+03	86400.00
C94AB9	2017-07-22 02:31:00+03	71500.00
C94AFF	2017-08-11 23:26:00+03	111600.00
C94B5E	2017-07-30 04:01:00+03	34000.00
C94BB6	2017-08-09 09:59:00+03	64800.00
C94BB7	2017-08-01 02:34:00+03	93900.00
C94C08	2017-08-10 16:51:00+03	28000.00
C94C63	2017-08-03 02:35:00+03	103200.00
C94CB3	2017-07-26 01:23:00+03	50100.00
C94CED	2017-07-22 15:48:00+03	25200.00
C94CFF	2017-07-17 19:29:00+03	122600.00
C94D16	2017-07-27 10:49:00+03	101200.00
C94D54	2017-07-14 16:31:00+03	406100.00
C94D9B	2017-08-04 20:01:00+03	52900.00
C94DEE	2017-07-07 00:30:00+03	28700.00
C94E62	2017-08-01 19:41:00+03	31600.00
C94E66	2017-08-10 23:40:00+03	69900.00
C94E7A	2017-07-01 06:06:00+03	60200.00
C94ECF	2017-07-26 00:35:00+03	133200.00
C94ED6	2017-07-14 14:26:00+03	25600.00
C94F00	2017-07-18 07:53:00+03	137700.00
C94F95	2017-08-03 00:36:00+03	62600.00
C94FB0	2017-07-28 17:53:00+03	44000.00
C94FB1	2017-08-12 13:24:00+03	37000.00
C94FCA	2017-08-14 23:48:00+03	179400.00
C95154	2017-07-24 22:03:00+03	23200.00
C951B5	2017-08-05 09:30:00+03	102200.00
C951BE	2017-08-09 12:34:00+03	24200.00
C951C9	2017-07-18 02:29:00+03	23200.00
C95225	2017-08-07 15:43:00+03	52300.00
C95250	2017-08-01 18:56:00+03	198600.00
C95278	2017-08-05 01:38:00+03	22000.00
C95286	2017-07-17 23:17:00+03	177200.00
C9531B	2017-08-15 06:09:00+03	142200.00
C9532A	2017-07-27 21:33:00+03	73600.00
C953A5	2017-07-03 11:35:00+03	101200.00
C95459	2017-07-23 17:28:00+03	12600.00
C95462	2017-07-07 08:02:00+03	6300.00
C95477	2017-07-14 08:38:00+03	80500.00
C954BB	2017-07-10 03:51:00+03	58000.00
C95501	2017-08-11 17:48:00+03	133200.00
C95515	2017-07-02 13:40:00+03	42800.00
C95527	2017-07-08 19:12:00+03	185000.00
C9552C	2017-08-07 03:20:00+03	22000.00
C9555E	2017-08-12 12:54:00+03	14000.00
C9557C	2017-08-08 07:48:00+03	68900.00
C95589	2017-07-07 04:02:00+03	23200.00
C955DB	2017-07-28 13:46:00+03	6000.00
C9565A	2017-08-09 04:27:00+03	49100.00
C9566A	2017-07-22 14:17:00+03	55800.00
C95677	2017-08-14 10:30:00+03	28000.00
C956BA	2017-07-14 21:01:00+03	64500.00
C956D1	2017-07-16 12:54:00+03	187800.00
C95700	2017-08-12 23:45:00+03	130100.00
C9570B	2017-08-02 09:05:00+03	93500.00
C95736	2017-08-06 16:53:00+03	333000.00
C95756	2017-08-01 18:45:00+03	135400.00
C957C2	2017-07-09 19:12:00+03	8200.00
C957E2	2017-08-04 21:08:00+03	77200.00
C9580C	2017-07-28 10:33:00+03	131600.00
C95830	2017-08-11 05:26:00+03	23200.00
C95882	2017-08-03 13:18:00+03	51200.00
C958F5	2017-07-25 02:30:00+03	6700.00
C9590F	2017-07-15 17:22:00+03	19600.00
C95921	2017-07-24 05:32:00+03	59300.00
C95A10	2017-08-12 12:27:00+03	48000.00
C95A3C	2017-07-24 07:14:00+03	131100.00
C95C04	2017-08-01 07:45:00+03	101500.00
C95C11	2017-07-22 18:07:00+03	125100.00
C95D37	2017-07-08 23:24:00+03	66600.00
C95D62	2017-07-28 09:43:00+03	67100.00
C95DE2	2017-07-02 17:25:00+03	175200.00
C95E30	2017-07-27 13:13:00+03	37200.00
C95E4B	2017-08-06 09:55:00+03	8000.00
C95E9C	2017-07-11 12:45:00+03	35600.00
C95EA5	2017-08-07 10:46:00+03	32400.00
C95F07	2017-07-22 01:50:00+03	52000.00
C95F0F	2017-07-04 23:35:00+03	34000.00
C95F19	2017-08-04 05:47:00+03	60700.00
C95F28	2017-07-20 09:47:00+03	26000.00
C95F6D	2017-07-06 00:25:00+03	81300.00
C95FB4	2017-07-26 12:26:00+03	42000.00
C95FB6	2017-08-03 12:12:00+03	47400.00
C96026	2017-07-02 06:01:00+03	42800.00
C9606E	2017-07-13 05:57:00+03	24400.00
C96071	2017-07-07 13:26:00+03	54300.00
C9611A	2017-08-14 09:52:00+03	28000.00
C96128	2017-08-13 10:16:00+03	166100.00
C96192	2017-08-15 01:28:00+03	86700.00
C9619C	2017-08-08 20:42:00+03	28800.00
C961AA	2017-07-05 14:15:00+03	118000.00
C96201	2017-07-05 14:41:00+03	58700.00
C96264	2017-08-04 13:39:00+03	6300.00
C96287	2017-08-13 15:59:00+03	136600.00
C962B6	2017-07-29 06:12:00+03	56000.00
C96367	2017-07-11 15:53:00+03	136700.00
C9636C	2017-07-18 18:00:00+03	66600.00
C96423	2017-07-16 04:35:00+03	88600.00
C96433	2017-07-29 12:32:00+03	6000.00
C9643E	2017-07-27 09:04:00+03	198500.00
C964B0	2017-07-26 05:36:00+03	65400.00
C9650D	2017-08-07 21:08:00+03	93200.00
C9657B	2017-07-25 11:05:00+03	81900.00
C96587	2017-07-17 23:50:00+03	31400.00
C9659C	2017-08-04 22:11:00+03	10800.00
C965AA	2017-07-18 11:38:00+03	31400.00
C965C0	2017-07-22 15:59:00+03	6400.00
C965E3	2017-06-30 07:28:00+03	94500.00
C965FE	2017-06-28 04:42:00+03	28000.00
C96635	2017-07-29 06:21:00+03	150600.00
C966A8	2017-07-05 22:14:00+03	193600.00
C966FD	2017-07-30 04:40:00+03	47000.00
C9670F	2017-07-20 15:58:00+03	188000.00
C96725	2017-07-29 09:45:00+03	28800.00
C9673C	2017-07-15 23:41:00+03	133000.00
C96742	2017-07-26 19:27:00+03	155600.00
C96747	2017-07-12 16:39:00+03	134400.00
C9677D	2017-08-14 11:54:00+03	40400.00
C967C6	2017-07-03 11:12:00+03	49800.00
C967DC	2017-08-09 02:30:00+03	75600.00
C9680F	2017-07-05 01:22:00+03	135400.00
C96843	2017-08-14 07:07:00+03	12400.00
C9688A	2017-07-08 16:51:00+03	6300.00
C96899	2017-07-05 21:29:00+03	177200.00
C968AC	2017-07-02 19:42:00+03	10600.00
C9692F	2017-06-27 18:38:00+03	24300.00
C9693C	2017-07-26 03:04:00+03	28800.00
C96986	2017-07-26 09:00:00+03	538000.00
C969DD	2017-08-06 09:51:00+03	247700.00
C969F0	2017-07-07 07:21:00+03	60400.00
C96A21	2017-08-11 17:49:00+03	29300.00
C96A89	2017-08-02 11:33:00+03	56000.00
C96A99	2017-08-12 12:23:00+03	42900.00
C96AC4	2017-07-07 10:54:00+03	26000.00
C96AD2	2017-07-29 19:58:00+03	49200.00
C96B18	2017-08-12 02:33:00+03	47200.00
C96B69	2017-07-20 11:50:00+03	199700.00
C96BAD	2017-08-13 13:28:00+03	124200.00
C96BBA	2017-08-09 22:43:00+03	14900.00
C96BF9	2017-07-18 12:26:00+03	102100.00
C96C1D	2017-07-29 15:28:00+03	57500.00
C96C7A	2017-07-17 08:18:00+03	136500.00
C96CDE	2017-06-30 09:26:00+03	6300.00
C96D19	2017-08-14 01:07:00+03	28000.00
C96D1B	2017-08-05 22:09:00+03	278400.00
C96DDB	2017-07-24 20:24:00+03	99200.00
C96DFE	2017-08-09 16:42:00+03	135400.00
C96E48	2017-08-15 16:53:00+03	15100.00
C96E67	2017-07-15 05:10:00+03	56000.00
C96E6C	2017-07-10 22:41:00+03	85000.00
C96E78	2017-06-28 11:24:00+03	57500.00
C96E9D	2017-07-06 12:44:00+03	67200.00
C96EA7	2017-08-09 21:43:00+03	23200.00
C96EB9	2017-08-15 10:20:00+03	61400.00
C96F6C	2017-08-07 05:20:00+03	40800.00
C96F70	2017-07-05 06:50:00+03	64700.00
C96F84	2017-07-30 09:30:00+03	220900.00
C96FDA	2017-08-11 14:28:00+03	47100.00
C96FEC	2017-07-07 00:22:00+03	97900.00
C96FFA	2017-07-23 14:24:00+03	43900.00
C97048	2017-08-14 08:21:00+03	38000.00
C970C5	2017-08-08 14:07:00+03	7200.00
C970E3	2017-07-21 16:26:00+03	76100.00
C97100	2017-07-17 08:51:00+03	27200.00
C9716F	2017-08-06 23:36:00+03	257600.00
C9718F	2017-07-03 16:28:00+03	127100.00
C9719D	2017-07-29 20:50:00+03	90400.00
C9721D	2017-07-14 13:21:00+03	54300.00
C972C6	2017-08-09 11:53:00+03	131600.00
C972F1	2017-08-13 21:26:00+03	136800.00
C97332	2017-07-17 09:46:00+03	14400.00
C97428	2017-07-01 02:41:00+03	13400.00
C9744A	2017-07-18 16:06:00+03	103600.00
C97450	2017-08-13 19:44:00+03	43100.00
C97469	2017-07-26 21:48:00+03	92800.00
C974BF	2017-07-04 05:42:00+03	27200.00
C974E4	2017-07-29 11:31:00+03	28800.00
C974E7	2017-07-06 01:59:00+03	116400.00
C974F5	2017-07-18 01:47:00+03	189200.00
C97519	2017-08-10 10:26:00+03	38200.00
C9752B	2017-08-02 05:02:00+03	90800.00
C9753E	2017-07-30 19:37:00+03	112600.00
C97554	2017-07-15 08:39:00+03	66600.00
C975C7	2017-08-12 08:03:00+03	55000.00
C975CF	2017-07-11 07:49:00+03	133200.00
C97604	2017-07-20 15:16:00+03	112000.00
C976E2	2017-07-27 12:43:00+03	15400.00
C97716	2017-07-10 17:28:00+03	176600.00
C9776C	2017-06-29 11:31:00+03	54400.00
C97787	2017-07-21 10:27:00+03	139300.00
C97788	2017-07-29 21:01:00+03	92000.00
C9779D	2017-08-08 20:56:00+03	95200.00
C977D9	2017-08-05 21:43:00+03	42800.00
C97820	2017-07-05 05:40:00+03	32700.00
C97831	2017-07-03 00:04:00+03	56000.00
C9783B	2017-08-01 17:04:00+03	111600.00
C978B8	2017-07-10 04:21:00+03	92800.00
C97941	2017-07-08 06:42:00+03	75300.00
C97958	2017-07-06 05:18:00+03	123000.00
C97A22	2017-07-08 18:18:00+03	6000.00
C97A25	2017-07-26 13:36:00+03	273400.00
C97A84	2017-07-26 16:39:00+03	164100.00
C97A98	2017-08-05 03:13:00+03	56000.00
C97AAD	2017-06-29 05:55:00+03	135600.00
C97AAE	2017-07-04 07:06:00+03	56900.00
C97AD3	2017-07-05 05:51:00+03	69000.00
C97AFA	2017-07-11 06:59:00+03	51600.00
C97BA2	2017-08-13 13:07:00+03	187600.00
C97BA4	2017-06-30 12:53:00+03	12600.00
C97BBF	2017-07-24 12:56:00+03	107700.00
C97C43	2017-08-08 23:59:00+03	112600.00
C97C45	2017-07-10 17:06:00+03	50700.00
C97C7D	2017-07-30 02:03:00+03	111600.00
C97C90	2017-07-30 15:53:00+03	277000.00
C97CBD	2017-07-07 10:12:00+03	372400.00
C97D47	2017-08-13 06:09:00+03	386300.00
C97DAE	2017-07-07 11:07:00+03	8000.00
C97DD1	2017-08-03 07:12:00+03	12400.00
C97DD7	2017-06-27 06:03:00+03	84000.00
C97DDA	2017-08-06 23:43:00+03	54800.00
C97DF3	2017-07-19 18:55:00+03	46400.00
C97E09	2017-07-18 13:21:00+03	146300.00
C97EB3	2017-07-25 19:26:00+03	307000.00
C97EC1	2017-07-13 09:41:00+03	11600.00
C97EE1	2017-07-13 18:47:00+03	31600.00
C98017	2017-07-09 22:17:00+03	29300.00
C98058	2017-08-05 11:56:00+03	158500.00
C98083	2017-07-16 07:28:00+03	314200.00
C98087	2017-07-02 17:24:00+03	52800.00
C980B7	2017-07-28 15:43:00+03	54500.00
C980E2	2017-07-30 06:04:00+03	22000.00
C980E7	2017-07-22 16:31:00+03	72300.00
C9811C	2017-07-12 20:21:00+03	27300.00
C98145	2017-07-10 15:33:00+03	79600.00
C98176	2017-08-13 17:14:00+03	43200.00
C9818C	2017-08-03 00:03:00+03	51900.00
C98192	2017-08-03 13:04:00+03	136200.00
C9819F	2017-08-07 06:46:00+03	130000.00
C9823C	2017-07-21 12:02:00+03	169300.00
C98242	2017-08-15 10:13:00+03	51900.00
C98243	2017-08-05 14:39:00+03	196800.00
C98287	2017-07-18 16:13:00+03	76600.00
C982B7	2017-08-12 01:39:00+03	12600.00
C982BD	2017-06-28 16:41:00+03	36200.00
C9830E	2017-07-14 23:27:00+03	54000.00
C98312	2017-07-26 01:30:00+03	94000.00
C983D3	2017-07-07 04:28:00+03	14000.00
C983D4	2017-07-06 03:51:00+03	48400.00
C9841C	2017-07-20 03:48:00+03	46900.00
C98424	2017-08-04 08:42:00+03	25600.00
C98459	2017-07-15 06:42:00+03	233700.00
C98465	2017-07-14 05:35:00+03	19600.00
C98498	2017-08-13 13:47:00+03	170700.00
C9849B	2017-07-09 02:06:00+03	37900.00
C98534	2017-07-19 04:46:00+03	64800.00
C98567	2017-07-08 06:38:00+03	73200.00
C98571	2017-07-25 16:53:00+03	22400.00
C98583	2017-07-08 11:22:00+03	56100.00
C985DA	2017-07-23 21:46:00+03	88900.00
C9860E	2017-07-25 08:36:00+03	17600.00
C98681	2017-08-14 06:44:00+03	36100.00
C9868A	2017-08-13 10:11:00+03	23200.00
C986C1	2017-07-07 17:18:00+03	31400.00
C986C7	2017-07-08 07:11:00+03	23200.00
C986E3	2017-07-13 09:51:00+03	32400.00
C986EA	2017-07-21 12:12:00+03	44800.00
C98715	2017-07-28 07:14:00+03	38800.00
C98759	2017-08-09 01:06:00+03	246000.00
C987BB	2017-08-07 14:28:00+03	62000.00
C98855	2017-07-01 10:33:00+03	44800.00
C98859	2017-07-12 17:33:00+03	96300.00
C988A7	2017-07-15 11:21:00+03	12400.00
C988AB	2017-07-21 23:20:00+03	510500.00
C988D0	2017-08-11 11:29:00+03	66600.00
C988D8	2017-07-23 10:23:00+03	73600.00
C988DB	2017-07-13 05:27:00+03	185600.00
C988F5	2017-06-25 07:30:00+03	75300.00
C98942	2017-07-08 23:18:00+03	173500.00
C98962	2017-07-04 14:53:00+03	89700.00
C98984	2017-07-29 19:46:00+03	56000.00
C989FE	2017-08-01 18:40:00+03	86800.00
C98A02	2017-07-10 20:33:00+03	23400.00
C98A0F	2017-07-02 04:05:00+03	94000.00
C98A44	2017-07-23 05:05:00+03	172600.00
C98A4D	2017-08-02 04:11:00+03	6700.00
C98ACE	2017-07-08 08:32:00+03	123000.00
C98B6C	2017-07-23 09:44:00+03	28000.00
C98B9C	2017-07-01 17:09:00+03	22600.00
C98BD5	2017-08-12 17:07:00+03	148700.00
C98BFA	2017-08-07 04:12:00+03	25200.00
C98C15	2017-07-10 00:00:00+03	125200.00
C98C40	2017-07-22 06:17:00+03	257500.00
C98C54	2017-07-24 11:46:00+03	133200.00
C98CA9	2017-07-25 09:56:00+03	57500.00
C98CE6	2017-07-30 17:33:00+03	32900.00
C98CF5	2017-07-17 22:04:00+03	234700.00
C98D8A	2017-08-14 01:17:00+03	19600.00
C98E39	2017-07-22 06:36:00+03	23400.00
C98E3C	2017-07-27 05:23:00+03	246000.00
C98E4B	2017-07-11 06:29:00+03	100600.00
C98E95	2017-08-10 09:33:00+03	38800.00
C98F26	2017-08-02 00:58:00+03	46000.00
C98F59	2017-07-13 03:02:00+03	68800.00
C98F8B	2017-07-18 23:04:00+03	65900.00
C98FA8	2017-07-16 18:08:00+03	147000.00
C99020	2017-07-01 08:49:00+03	57500.00
C9903E	2017-08-07 06:16:00+03	67000.00
C99064	2017-07-01 22:59:00+03	129700.00
C990C5	2017-07-09 22:39:00+03	134400.00
C990CA	2017-06-30 18:39:00+03	8200.00
C9910A	2017-07-01 14:41:00+03	31100.00
C99141	2017-07-13 21:45:00+03	18600.00
C99178	2017-07-15 06:13:00+03	58800.00
C9919E	2017-07-02 09:58:00+03	6700.00
C991F1	2017-07-04 21:01:00+03	56800.00
C9920E	2017-07-03 00:06:00+03	21600.00
C99289	2017-08-13 17:26:00+03	108800.00
C992AF	2017-07-23 17:24:00+03	42900.00
C992D5	2017-08-12 11:56:00+03	81500.00
C9933B	2017-07-20 05:48:00+03	41800.00
C99395	2017-07-18 23:48:00+03	27200.00
C993BD	2017-08-02 19:43:00+03	501300.00
C993DF	2017-07-13 02:21:00+03	31400.00
C9943D	2017-06-30 21:21:00+03	15000.00
C9946E	2017-07-21 15:00:00+03	30900.00
C9948E	2017-07-05 08:37:00+03	139500.00
C994C9	2017-07-03 12:02:00+03	86800.00
C995BF	2017-07-18 12:38:00+03	162600.00
C9966D	2017-08-07 14:47:00+03	168700.00
C99690	2017-07-29 13:46:00+03	34200.00
C996B7	2017-07-16 13:28:00+03	145300.00
C99738	2017-08-13 13:35:00+03	153300.00
C9976B	2017-07-18 16:45:00+03	155600.00
C997BC	2017-07-25 17:40:00+03	12400.00
C997CC	2017-07-18 15:12:00+03	23200.00
C997DA	2017-08-15 07:50:00+03	31900.00
C997F8	2017-07-04 11:17:00+03	36200.00
C9981F	2017-07-13 12:37:00+03	6600.00
C99887	2017-07-22 10:53:00+03	48700.00
C99896	2017-07-05 04:40:00+03	40800.00
C998CB	2017-07-12 04:46:00+03	23200.00
C998E8	2017-08-04 11:32:00+03	13000.00
C99982	2017-07-22 13:50:00+03	30200.00
C99A14	2017-07-24 14:31:00+03	40000.00
C99A2E	2017-08-14 09:32:00+03	19600.00
C99A91	2017-07-01 16:22:00+03	8000.00
C99AA0	2017-07-25 16:29:00+03	179400.00
C99AFF	2017-07-29 06:55:00+03	167500.00
C99B07	2017-07-15 17:36:00+03	193600.00
C99B36	2017-07-18 02:07:00+03	24400.00
C99B3B	2017-06-28 18:40:00+03	56000.00
C99B49	2017-07-26 07:00:00+03	146300.00
C99B9C	2017-07-19 16:26:00+03	32700.00
C99BA4	2017-07-26 01:20:00+03	56000.00
C99BB4	2017-07-16 12:21:00+03	54000.00
C99BF6	2017-08-13 17:37:00+03	118500.00
C99C2E	2017-07-04 06:19:00+03	59800.00
C99C75	2017-08-09 18:40:00+03	22000.00
C99C8D	2017-08-14 21:10:00+03	28800.00
C99CF8	2017-07-16 16:46:00+03	55000.00
C99D45	2017-07-15 03:30:00+03	101200.00
C99D53	2017-08-10 13:00:00+03	28400.00
C99D66	2017-07-03 22:30:00+03	45100.00
C99DE2	2017-07-21 14:47:00+03	59800.00
C99E6C	2017-08-04 10:15:00+03	36800.00
C99E72	2017-07-29 01:40:00+03	8400.00
C99E7F	2017-07-31 13:34:00+03	44400.00
C99E8C	2017-07-16 22:41:00+03	332800.00
C99F0E	2017-07-06 08:38:00+03	181100.00
C99F41	2017-08-09 22:26:00+03	39300.00
C99F70	2017-08-14 20:01:00+03	145800.00
C9A059	2017-07-05 10:36:00+03	86300.00
C9A0B7	2017-08-12 00:18:00+03	386300.00
C9A0BD	2017-08-03 02:36:00+03	36900.00
C9A11A	2017-08-07 17:48:00+03	136800.00
C9A14B	2017-08-14 16:45:00+03	51900.00
C9A160	2017-08-07 18:27:00+03	50800.00
C9A186	2017-06-27 18:57:00+03	131100.00
C9A187	2017-07-19 23:51:00+03	67800.00
C9A21F	2017-08-01 05:28:00+03	25800.00
C9A265	2017-07-13 22:39:00+03	99200.00
C9A268	2017-08-09 12:34:00+03	116400.00
C9A3AC	2017-08-13 10:37:00+03	20400.00
C9A3B8	2017-07-26 18:16:00+03	26000.00
C9A47E	2017-07-14 04:03:00+03	50000.00
C9A4B2	2017-07-30 21:28:00+03	7400.00
C9A56B	2017-08-11 18:50:00+03	26700.00
C9A648	2017-08-09 02:25:00+03	270200.00
C9A699	2017-07-03 20:23:00+03	65000.00
C9A6C8	2017-07-30 08:09:00+03	186900.00
C9A6DA	2017-07-15 03:34:00+03	13600.00
C9A6F3	2017-07-24 15:42:00+03	71000.00
C9A735	2017-07-12 09:07:00+03	123000.00
C9A760	2017-08-02 04:54:00+03	86200.00
C9A77B	2017-07-21 15:57:00+03	50600.00
C9A84C	2017-07-02 05:56:00+03	177200.00
C9A88D	2017-06-28 19:20:00+03	95600.00
C9A894	2017-08-05 22:36:00+03	24300.00
C9A8A4	2017-07-26 18:28:00+03	36200.00
C9A8A5	2017-08-07 21:30:00+03	26000.00
C9A8D5	2017-07-21 14:39:00+03	149300.00
C9AA23	2017-07-29 07:06:00+03	33100.00
C9AA93	2017-07-22 13:18:00+03	14000.00
C9AADD	2017-07-28 11:25:00+03	46200.00
C9AC0F	2017-07-21 14:13:00+03	28000.00
C9AC2F	2017-07-10 21:37:00+03	26800.00
C9AC3F	2017-07-17 07:09:00+03	56900.00
C9AC49	2017-07-10 05:18:00+03	39300.00
C9AC9B	2017-07-10 18:14:00+03	167200.00
C9ACF8	2017-07-15 19:07:00+03	26700.00
C9ADB1	2017-07-18 15:05:00+03	21400.00
C9ADD1	2017-08-03 18:32:00+03	28000.00
C9AE3F	2017-07-08 18:40:00+03	93900.00
C9AEAE	2017-08-13 08:08:00+03	69500.00
C9AEF0	2017-07-18 17:05:00+03	47000.00
C9AF14	2017-07-06 15:48:00+03	25800.00
C9AF5E	2017-07-25 02:38:00+03	47200.00
C9AF9F	2017-07-10 18:14:00+03	81600.00
C9B00A	2017-07-06 00:37:00+03	286600.00
C9B030	2017-08-11 00:26:00+03	79800.00
C9B07C	2017-07-17 05:23:00+03	39200.00
C9B090	2017-07-12 00:21:00+03	17200.00
C9B0DE	2017-07-20 21:37:00+03	92800.00
C9B107	2017-07-20 10:05:00+03	83300.00
C9B14A	2017-07-17 06:05:00+03	56000.00
C9B161	2017-07-22 16:16:00+03	6000.00
C9B170	2017-07-07 05:46:00+03	6000.00
C9B18E	2017-07-25 14:51:00+03	32600.00
C9B211	2017-07-09 13:41:00+03	123000.00
C9B251	2017-07-05 17:24:00+03	96800.00
C9B313	2017-07-24 21:46:00+03	58800.00
C9B38C	2017-07-24 02:22:00+03	63200.00
C9B3FA	2017-07-15 03:35:00+03	56000.00
C9B401	2017-07-08 04:24:00+03	67600.00
C9B429	2017-07-20 12:28:00+03	47400.00
C9B4AB	2017-07-16 01:05:00+03	28800.00
C9B4D8	2017-07-14 10:04:00+03	125400.00
C9B4E8	2017-08-01 18:49:00+03	40800.00
C9B4F5	2017-07-18 19:22:00+03	27800.00
C9B500	2017-07-08 00:20:00+03	192700.00
C9B505	2017-08-06 03:43:00+03	46200.00
C9B51E	2017-08-02 16:17:00+03	116000.00
C9B570	2017-07-18 12:47:00+03	305800.00
C9B5AA	2017-06-28 07:10:00+03	51600.00
C9B5CB	2017-08-12 10:13:00+03	16400.00
C9B5CD	2017-08-09 14:56:00+03	272700.00
C9B5D8	2017-07-19 18:48:00+03	246000.00
C9B607	2017-08-08 08:32:00+03	112000.00
C9B60D	2017-07-05 12:19:00+03	9800.00
C9B633	2017-07-29 12:58:00+03	28800.00
C9B676	2017-08-07 14:58:00+03	15000.00
C9B682	2017-07-27 09:21:00+03	22000.00
C9B6D6	2017-07-21 19:54:00+03	75600.00
C9B753	2017-07-24 04:14:00+03	34000.00
C9B760	2017-07-01 13:46:00+03	301800.00
C9B761	2017-07-27 12:50:00+03	57400.00
C9B7CE	2017-07-10 00:53:00+03	38400.00
C9B7DE	2017-07-25 23:55:00+03	202600.00
C9B813	2017-07-06 10:23:00+03	92900.00
C9B844	2017-07-31 08:48:00+03	51300.00
C9B845	2017-07-25 01:53:00+03	89700.00
C9B8F0	2017-07-09 10:16:00+03	47000.00
C9B95A	2017-08-01 15:44:00+03	55800.00
C9B9E9	2017-08-04 01:04:00+03	369000.00
C9BA0D	2017-07-15 10:57:00+03	339300.00
C9BA16	2017-07-17 02:21:00+03	37200.00
C9BACF	2017-07-17 00:01:00+03	240600.00
C9BAD6	2017-07-03 12:39:00+03	81200.00
C9BAED	2017-07-25 16:03:00+03	24000.00
C9BB46	2017-08-04 10:54:00+03	58900.00
C9BB74	2017-07-06 19:35:00+03	27200.00
C9BB7A	2017-08-08 13:22:00+03	26600.00
C9BB93	2017-08-13 06:01:00+03	6700.00
C9BBE2	2017-07-11 05:41:00+03	112600.00
C9BBEF	2017-07-09 15:45:00+03	58600.00
C9BC30	2017-08-01 08:10:00+03	212800.00
C9BC6C	2017-07-15 05:33:00+03	22000.00
C9BC6F	2017-08-11 12:51:00+03	77500.00
C9BC70	2017-07-12 07:25:00+03	91100.00
C9BCA1	2017-08-15 14:27:00+03	15400.00
C9BCA6	2017-07-31 19:47:00+03	29600.00
C9BCCB	2017-07-11 20:53:00+03	57800.00
C9BCCD	2017-07-26 04:26:00+03	24400.00
C9BDAF	2017-07-20 22:01:00+03	12000.00
C9BDF6	2017-07-04 03:44:00+03	113300.00
C9BE2A	2017-07-27 02:54:00+03	115900.00
C9BE4D	2017-08-04 14:45:00+03	58000.00
C9BEC2	2017-07-09 22:29:00+03	89700.00
C9BF16	2017-08-13 04:09:00+03	23600.00
C9BF7E	2017-07-27 16:20:00+03	98400.00
C9BFF1	2017-07-15 08:32:00+03	12200.00
C9BFF8	2017-08-04 08:50:00+03	100600.00
C9C055	2017-08-12 02:02:00+03	87400.00
C9C069	2017-06-27 12:01:00+03	102200.00
C9C07A	2017-07-03 20:45:00+03	81600.00
C9C0C4	2017-07-24 00:22:00+03	43600.00
C9C0C5	2017-08-15 11:32:00+03	59600.00
C9C0D5	2017-07-13 18:11:00+03	531400.00
C9C0E7	2017-08-06 05:55:00+03	58800.00
C9C0EB	2017-07-21 00:49:00+03	40800.00
C9C111	2017-08-09 16:31:00+03	66000.00
C9C141	2017-07-05 00:04:00+03	27200.00
C9C182	2017-07-27 11:46:00+03	201200.00
C9C1CA	2017-07-08 01:22:00+03	105000.00
C9C1E0	2017-08-04 16:48:00+03	273000.00
C9C217	2017-08-08 16:07:00+03	94300.00
C9C219	2017-07-17 04:54:00+03	67400.00
C9C251	2017-08-14 13:47:00+03	112200.00
C9C2B1	2017-08-15 02:15:00+03	23200.00
C9C2BC	2017-07-10 14:09:00+03	56000.00
C9C326	2017-08-10 19:00:00+03	40400.00
C9C3D0	2017-08-05 03:49:00+03	72400.00
C9C3D5	2017-08-09 03:26:00+03	66000.00
C9C3E4	2017-07-26 18:02:00+03	50200.00
C9C49F	2017-07-16 03:28:00+03	22600.00
C9C54C	2017-07-04 10:58:00+03	28000.00
C9C555	2017-08-11 17:09:00+03	26700.00
C9C584	2017-08-12 22:26:00+03	193600.00
C9C59F	2017-07-21 11:59:00+03	20600.00
C9C5BE	2017-07-10 22:25:00+03	31600.00
C9C5F2	2017-07-26 04:36:00+03	117000.00
C9C647	2017-08-06 01:34:00+03	97700.00
C9C6BA	2017-08-03 14:00:00+03	66600.00
C9C7D1	2017-07-11 14:30:00+03	40400.00
C9C7F5	2017-08-05 19:03:00+03	44800.00
C9C80C	2017-08-07 18:36:00+03	40600.00
C9C85E	2017-08-14 03:14:00+03	118100.00
C9C8E0	2017-07-08 15:47:00+03	119300.00
C9C8E5	2017-07-16 01:52:00+03	92200.00
C9C94C	2017-08-09 19:06:00+03	240600.00
C9C94D	2017-06-30 12:36:00+03	72300.00
C9C991	2017-08-14 03:44:00+03	40200.00
C9C9A1	2017-07-14 22:00:00+03	46300.00
C9C9A7	2017-08-05 08:37:00+03	26000.00
C9C9CC	2017-07-01 18:53:00+03	43800.00
C9CA08	2017-07-03 07:13:00+03	246000.00
C9CA34	2017-07-10 10:29:00+03	286100.00
C9CB08	2017-07-04 20:33:00+03	9200.00
C9CB09	2017-08-11 06:32:00+03	55000.00
C9CBB7	2017-07-17 21:19:00+03	95200.00
C9CBE8	2017-07-13 08:53:00+03	19600.00
C9CC55	2017-07-19 20:31:00+03	396500.00
C9CCB6	2017-08-11 16:27:00+03	31600.00
C9CD3C	2017-08-07 15:38:00+03	123000.00
C9CDB6	2017-07-24 06:04:00+03	124200.00
C9CDDA	2017-08-10 17:02:00+03	91200.00
C9CDE2	2017-07-27 07:25:00+03	221800.00
C9CE28	2017-07-21 19:07:00+03	86300.00
C9CE2B	2017-07-27 17:03:00+03	398300.00
C9CEB7	2017-07-17 14:25:00+03	271100.00
C9CEEB	2017-07-20 04:40:00+03	3400.00
C9CF3F	2017-07-29 16:48:00+03	86800.00
C9CF5E	2017-07-03 01:47:00+03	20400.00
C9CFB0	2017-07-08 12:37:00+03	27200.00
C9CFD2	2017-07-26 10:28:00+03	156900.00
C9CFFC	2017-07-23 19:54:00+03	80000.00
C9D0C5	2017-07-05 19:50:00+03	278000.00
C9D119	2017-07-25 11:22:00+03	270000.00
C9D11E	2017-07-21 15:36:00+03	135600.00
C9D124	2017-08-04 10:04:00+03	413400.00
C9D1C3	2017-07-01 15:15:00+03	15500.00
C9D22E	2017-08-05 07:17:00+03	55800.00
C9D22F	2017-08-02 10:10:00+03	12400.00
C9D250	2017-07-12 04:04:00+03	54300.00
C9D2A0	2017-08-07 08:32:00+03	191300.00
C9D372	2017-07-22 02:57:00+03	135400.00
C9D37B	2017-07-17 00:48:00+03	326900.00
C9D420	2017-07-10 00:27:00+03	114300.00
C9D46D	2017-07-29 18:28:00+03	101100.00
C9D4C1	2017-08-08 02:25:00+03	40000.00
C9D4C9	2017-07-19 13:59:00+03	136800.00
C9D4CC	2017-07-28 05:19:00+03	46400.00
C9D4DC	2017-07-13 18:20:00+03	37900.00
C9D58A	2017-07-19 06:28:00+03	49200.00
C9D591	2017-07-25 13:04:00+03	26300.00
C9D5B6	2017-07-09 05:09:00+03	166000.00
C9D5B7	2017-08-08 12:07:00+03	25100.00
C9D5CD	2017-07-09 12:38:00+03	56600.00
C9D5DD	2017-07-30 15:18:00+03	72400.00
C9D675	2017-07-28 20:52:00+03	22000.00
C9D67B	2017-07-31 04:53:00+03	46800.00
C9D768	2017-07-25 10:32:00+03	36200.00
C9D78F	2017-07-31 07:38:00+03	92700.00
C9D792	2017-07-02 00:08:00+03	24800.00
C9D7AA	2017-07-05 23:44:00+03	46500.00
C9D7FB	2017-08-06 08:41:00+03	399600.00
C9D80B	2017-07-20 07:18:00+03	131100.00
C9D90D	2017-07-31 12:51:00+03	73200.00
C9D979	2017-08-08 12:59:00+03	47400.00
C9D9A3	2017-08-15 16:23:00+03	67900.00
C9D9B0	2017-08-03 16:50:00+03	258700.00
C9D9CA	2017-07-08 14:46:00+03	75300.00
C9D9D6	2017-07-21 06:31:00+03	15800.00
C9D9EE	2017-07-28 14:06:00+03	122000.00
C9DAD8	2017-08-02 18:22:00+03	20600.00
C9DB0D	2017-08-07 10:39:00+03	167700.00
C9DB17	2017-08-12 18:12:00+03	57500.00
C9DB44	2017-08-08 06:15:00+03	266400.00
C9DB4A	2017-08-01 09:34:00+03	18000.00
C9DBC2	2017-07-16 14:54:00+03	42700.00
C9DBD1	2017-08-01 18:26:00+03	72400.00
C9DC69	2017-07-27 12:04:00+03	540000.00
C9DC88	2017-08-15 06:38:00+03	22000.00
C9DCA2	2017-07-19 01:10:00+03	36200.00
C9DCBC	2017-07-24 13:05:00+03	38000.00
C9DCCE	2017-07-24 01:07:00+03	106600.00
C9DCF5	2017-08-06 17:38:00+03	6800.00
C9DD0E	2017-07-14 01:09:00+03	68100.00
C9DD3B	2017-07-28 20:48:00+03	58900.00
C9DD47	2017-07-09 09:34:00+03	26000.00
C9DD8E	2017-07-14 08:36:00+03	157300.00
C9DDBB	2017-07-29 16:06:00+03	40400.00
C9DDEB	2017-07-21 06:26:00+03	170200.00
C9DF37	2017-07-06 10:38:00+03	115600.00
C9DF80	2017-08-06 04:45:00+03	56600.00
C9DF8F	2017-08-10 16:38:00+03	170000.00
C9DFE5	2017-07-27 12:51:00+03	29600.00
C9DFEA	2017-07-04 16:26:00+03	76600.00
C9E03C	2017-08-04 22:34:00+03	56000.00
C9E084	2017-07-04 18:34:00+03	57600.00
C9E09D	2017-07-01 04:28:00+03	31600.00
C9E0A5	2017-07-01 13:17:00+03	48800.00
C9E0D0	2017-07-19 01:22:00+03	8000.00
C9E0E1	2017-07-17 10:25:00+03	44800.00
C9E15E	2017-08-02 08:33:00+03	6000.00
C9E17C	2017-08-11 01:55:00+03	94100.00
C9E188	2017-07-26 22:19:00+03	276200.00
C9E192	2017-08-12 02:06:00+03	381400.00
C9E1C3	2017-07-08 14:26:00+03	94800.00
C9E1DA	2017-08-11 13:12:00+03	56000.00
C9E1DC	2017-08-12 07:19:00+03	61800.00
C9E1F4	2017-07-24 20:49:00+03	183800.00
C9E2BD	2017-08-07 09:54:00+03	8000.00
C9E33F	2017-07-03 06:27:00+03	23600.00
C9E41B	2017-08-02 22:13:00+03	35700.00
C9E48B	2017-07-27 06:27:00+03	16400.00
C9E55B	2017-08-01 19:03:00+03	47000.00
C9E596	2017-07-19 12:41:00+03	111600.00
C9E5A5	2017-07-27 23:28:00+03	26700.00
C9E5D9	2017-07-30 19:36:00+03	60400.00
C9E6A3	2017-08-05 05:00:00+03	129200.00
C9E6C2	2017-07-14 16:15:00+03	60600.00
C9E8B2	2017-07-15 02:43:00+03	48800.00
C9E92F	2017-08-15 15:35:00+03	75600.00
C9E98F	2017-07-15 23:04:00+03	174000.00
C9E9DC	2017-07-23 13:07:00+03	28000.00
C9E9F3	2017-07-19 02:47:00+03	76400.00
C9EA06	2017-07-09 19:16:00+03	272400.00
C9EA24	2017-07-22 07:22:00+03	24200.00
C9EA41	2017-08-09 20:16:00+03	48800.00
C9EA78	2017-07-06 09:40:00+03	75300.00
C9EB5A	2017-08-03 03:36:00+03	52700.00
C9EBC9	2017-07-05 11:00:00+03	39800.00
C9EC6F	2017-07-22 17:48:00+03	92700.00
C9EC9D	2017-08-15 11:08:00+03	25200.00
C9ECBC	2017-07-19 13:50:00+03	27200.00
C9ECEB	2017-07-08 04:43:00+03	28800.00
C9ED10	2017-07-08 10:46:00+03	75100.00
C9ED33	2017-07-12 12:50:00+03	35800.00
C9ED74	2017-07-28 09:44:00+03	69200.00
C9EDBA	2017-08-09 01:32:00+03	26000.00
C9EDBC	2017-07-13 08:17:00+03	112000.00
C9EDF8	2017-07-30 09:15:00+03	8000.00
C9EE16	2017-08-13 01:04:00+03	152900.00
C9EE99	2017-08-02 16:53:00+03	45400.00
C9EECC	2017-07-25 23:46:00+03	70700.00
C9EF8E	2017-08-12 14:59:00+03	123600.00
C9EFBA	2017-07-22 13:51:00+03	69000.00
C9EFD4	2017-08-01 22:52:00+03	29600.00
C9EFF7	2017-07-15 22:50:00+03	395400.00
C9F0EC	2017-07-21 06:27:00+03	78000.00
C9F145	2017-07-12 01:38:00+03	399600.00
C9F171	2017-07-18 01:44:00+03	28800.00
C9F193	2017-07-03 13:01:00+03	101200.00
C9F1F7	2017-08-06 19:29:00+03	51900.00
C9F230	2017-07-29 01:10:00+03	51900.00
C9F260	2017-07-04 01:17:00+03	69500.00
C9F2ED	2017-07-06 08:30:00+03	40400.00
C9F33B	2017-07-17 17:20:00+03	21600.00
C9F3A0	2017-07-14 17:13:00+03	261400.00
C9F40A	2017-07-16 09:36:00+03	62800.00
C9F451	2017-07-15 22:12:00+03	55800.00
C9F45E	2017-08-04 05:53:00+03	28800.00
C9F489	2017-07-22 12:52:00+03	72600.00
C9F4A4	2017-08-14 15:16:00+03	114800.00
C9F4A9	2017-08-03 16:27:00+03	14400.00
C9F508	2017-07-12 17:35:00+03	45200.00
C9F539	2017-08-01 13:26:00+03	34600.00
C9F590	2017-07-21 07:42:00+03	156500.00
C9F5AF	2017-08-15 16:44:00+03	28800.00
C9F5B6	2017-06-30 21:09:00+03	64500.00
C9F5C9	2017-07-14 17:16:00+03	161200.00
C9F5FF	2017-08-15 03:02:00+03	28000.00
C9F64E	2017-08-11 16:01:00+03	29400.00
C9F666	2017-07-24 00:19:00+03	56600.00
C9F66A	2017-07-22 09:12:00+03	46200.00
C9F684	2017-08-01 05:43:00+03	22000.00
C9F6B1	2017-08-09 16:50:00+03	381400.00
C9F6BE	2017-07-12 02:58:00+03	80200.00
C9F6C7	2017-07-30 14:10:00+03	54800.00
C9F79C	2017-08-04 03:43:00+03	45200.00
C9F7A4	2017-08-15 15:59:00+03	70600.00
C9F7BC	2017-07-02 19:59:00+03	145300.00
C9F8B1	2017-08-08 06:12:00+03	28800.00
C9F8B9	2017-08-07 01:26:00+03	139200.00
C9F8E0	2017-07-23 13:34:00+03	114200.00
C9F904	2017-07-24 23:49:00+03	67600.00
C9F992	2017-08-15 04:57:00+03	81500.00
C9F9AD	2017-08-01 15:41:00+03	64700.00
C9F9BF	2017-07-24 10:19:00+03	72700.00
C9F9DD	2017-08-13 03:29:00+03	79300.00
C9FA34	2017-07-18 08:32:00+03	14800.00
C9FA3A	2017-08-08 05:52:00+03	16400.00
C9FA6A	2017-07-09 00:55:00+03	70700.00
C9FB2A	2017-07-11 01:45:00+03	23200.00
C9FB56	2017-07-16 04:14:00+03	136800.00
C9FB65	2017-07-13 17:23:00+03	38600.00
C9FBCC	2017-08-03 14:53:00+03	6300.00
C9FBDD	2017-06-28 05:08:00+03	63200.00
C9FC09	2017-07-17 01:03:00+03	40400.00
C9FC0E	2017-08-05 16:44:00+03	46000.00
C9FC44	2017-07-10 14:16:00+03	10100.00
C9FC99	2017-07-12 04:55:00+03	114900.00
C9FD1B	2017-08-08 19:11:00+03	21400.00
C9FD4E	2017-07-30 03:21:00+03	14400.00
C9FD5F	2017-07-25 11:55:00+03	47600.00
C9FDE4	2017-08-07 08:42:00+03	46400.00
C9FE74	2017-07-03 06:19:00+03	54800.00
C9FE8A	2017-08-11 18:07:00+03	58600.00
C9FEBF	2017-08-01 22:57:00+03	40000.00
C9FF08	2017-07-28 10:00:00+03	42800.00
C9FFD8	2017-07-10 08:37:00+03	39300.00
C9FFE0	2017-08-03 05:41:00+03	6700.00
CA0081	2017-07-04 02:34:00+03	12600.00
CA0136	2017-07-11 17:20:00+03	158500.00
CA013A	2017-07-06 11:23:00+03	65800.00
CA0195	2017-07-06 19:29:00+03	25400.00
CA019D	2017-08-06 11:30:00+03	37900.00
CA019F	2017-08-02 07:47:00+03	132100.00
CA01BC	2017-07-24 22:19:00+03	136800.00
CA023B	2017-07-14 19:50:00+03	64200.00
CA027F	2017-08-03 12:21:00+03	62700.00
CA02B3	2017-07-05 13:05:00+03	87000.00
CA02CC	2017-07-17 18:42:00+03	115700.00
CA038B	2017-07-02 18:38:00+03	487100.00
CA03D6	2017-08-12 20:49:00+03	80000.00
CA0448	2017-07-16 21:07:00+03	44100.00
CA04A6	2017-07-19 03:57:00+03	270700.00
CA04D4	2017-07-02 23:17:00+03	226200.00
CA04DB	2017-08-15 15:18:00+03	133700.00
CA0542	2017-08-14 12:49:00+03	14800.00
CA0546	2017-07-21 20:35:00+03	146200.00
CA059B	2017-08-09 07:41:00+03	36800.00
CA0639	2017-07-01 03:49:00+03	92800.00
CA0671	2017-08-07 20:49:00+03	246200.00
CA0696	2017-07-26 21:27:00+03	56000.00
CA06AF	2017-07-04 16:20:00+03	37100.00
CA06FB	2017-07-31 11:38:00+03	114200.00
CA074C	2017-08-10 01:17:00+03	84100.00
CA07A5	2017-07-30 21:15:00+03	40000.00
CA07DD	2017-07-02 21:26:00+03	80900.00
CA0899	2017-07-22 18:07:00+03	34000.00
CA08FB	2017-08-12 13:09:00+03	56000.00
CA0902	2017-07-13 18:39:00+03	27200.00
CA0945	2017-07-13 03:57:00+03	27900.00
CA099E	2017-07-15 19:58:00+03	56000.00
CA09E9	2017-08-02 15:54:00+03	31400.00
CA0A2E	2017-06-30 09:52:00+03	26000.00
CA0A37	2017-07-07 13:16:00+03	135000.00
CA0B0E	2017-07-16 14:36:00+03	67600.00
CA0B23	2017-07-25 13:02:00+03	43100.00
CA0B5E	2017-07-28 22:50:00+03	27700.00
CA0B6B	2017-07-11 11:31:00+03	20000.00
CA0B9C	2017-07-30 02:58:00+03	14400.00
CA0BE0	2017-08-08 02:25:00+03	111600.00
CA0BE9	2017-07-17 01:04:00+03	46000.00
CA0CBA	2017-07-17 08:37:00+03	72400.00
CA0CEF	2017-08-15 00:47:00+03	295400.00
CA0CFD	2017-07-17 14:04:00+03	25600.00
CA0DC6	2017-07-15 10:00:00+03	28300.00
CA0E2A	2017-07-04 10:02:00+03	77500.00
CA0E77	2017-07-27 12:39:00+03	156500.00
CA0EE4	2017-07-05 23:46:00+03	133100.00
CA0F21	2017-07-28 03:35:00+03	105100.00
CA0F52	2017-07-18 22:24:00+03	68100.00
CA0F7F	2017-07-09 23:36:00+03	25600.00
CA0F89	2017-07-24 04:30:00+03	54800.00
CA0F95	2017-08-14 16:05:00+03	99800.00
CA0FE5	2017-07-12 02:53:00+03	88000.00
CA102A	2017-07-31 02:13:00+03	133100.00
CA1061	2017-07-07 19:43:00+03	31600.00
CA1085	2017-07-07 19:37:00+03	30800.00
CA1123	2017-07-29 16:01:00+03	14000.00
CA112B	2017-07-24 11:56:00+03	224000.00
CA1245	2017-07-07 22:04:00+03	90600.00
CA126E	2017-07-13 20:33:00+03	177600.00
CA12CC	2017-08-04 15:36:00+03	28700.00
CA12CE	2017-07-20 19:14:00+03	42700.00
CA1322	2017-08-04 09:46:00+03	405000.00
CA1365	2017-07-06 19:05:00+03	87200.00
CA136F	2017-08-04 14:35:00+03	90800.00
CA13B2	2017-08-13 06:08:00+03	23100.00
CA14B9	2017-07-25 19:04:00+03	133200.00
CA14BA	2017-08-14 02:09:00+03	50800.00
CA14BC	2017-08-11 16:59:00+03	18600.00
CA150D	2017-07-06 02:27:00+03	53300.00
CA15A7	2017-06-30 15:55:00+03	24200.00
CA15C9	2017-07-26 01:06:00+03	24400.00
CA15D2	2017-07-26 23:00:00+03	136200.00
CA15D4	2017-06-27 17:16:00+03	133200.00
CA15E9	2017-07-23 12:46:00+03	106400.00
CA15F4	2017-07-12 20:53:00+03	123000.00
CA15FE	2017-08-04 12:19:00+03	39100.00
CA1650	2017-08-01 15:20:00+03	153300.00
CA170D	2017-07-30 08:52:00+03	24800.00
CA1712	2017-07-06 02:44:00+03	16400.00
CA1724	2017-07-22 03:28:00+03	187800.00
CA1735	2017-08-06 07:35:00+03	77400.00
CA1787	2017-07-27 00:03:00+03	28800.00
CA17B5	2017-07-03 07:05:00+03	73100.00
CA17B9	2017-07-14 13:46:00+03	183100.00
CA17BD	2017-08-12 06:11:00+03	95200.00
CA184A	2017-07-23 19:21:00+03	43200.00
CA1891	2017-07-19 13:46:00+03	30600.00
CA18A3	2017-07-02 02:55:00+03	99800.00
CA18EC	2017-08-13 10:43:00+03	31400.00
CA1913	2017-06-27 12:10:00+03	22000.00
CA1968	2017-08-05 05:53:00+03	51600.00
CA19F7	2017-07-23 22:02:00+03	78900.00
CA1A11	2017-06-29 22:32:00+03	34600.00
CA1A92	2017-08-11 01:56:00+03	325200.00
CA1AEA	2017-07-25 13:16:00+03	40400.00
CA1B5D	2017-07-15 00:32:00+03	68400.00
CA1B6D	2017-08-04 21:20:00+03	29400.00
CA1D46	2017-08-05 04:11:00+03	85600.00
CA1D68	2017-07-31 09:35:00+03	98400.00
CA1DC9	2017-07-14 07:14:00+03	459600.00
CA1E51	2017-07-10 21:28:00+03	43600.00
CA1E5A	2017-07-13 12:33:00+03	38200.00
CA1F17	2017-07-14 02:38:00+03	136500.00
CA1F2F	2017-07-26 04:07:00+03	58200.00
CA1F51	2017-07-29 01:27:00+03	14800.00
CA1F89	2017-07-19 04:30:00+03	38800.00
CA1FF9	2017-08-06 22:35:00+03	151800.00
CA207A	2017-07-12 19:02:00+03	20400.00
CA20A3	2017-08-14 22:42:00+03	114800.00
CA213A	2017-07-16 21:59:00+03	111700.00
CA21AD	2017-08-11 14:28:00+03	48800.00
CA221E	2017-07-05 15:39:00+03	152500.00
CA222B	2017-07-31 09:54:00+03	59200.00
CA22AC	2017-07-12 04:42:00+03	22000.00
CA22B4	2017-07-05 08:25:00+03	184300.00
CA22D3	2017-07-12 18:49:00+03	47000.00
CA22ED	2017-07-19 23:11:00+03	272300.00
CA2309	2017-07-05 21:08:00+03	29600.00
CA230D	2017-06-29 20:43:00+03	38700.00
CA237C	2017-07-18 07:54:00+03	37700.00
CA2380	2017-07-24 20:17:00+03	28800.00
CA2393	2017-08-11 11:21:00+03	112200.00
CA2435	2017-07-20 16:25:00+03	258400.00
CA246F	2017-06-30 05:00:00+03	203000.00
CA24AF	2017-08-03 21:00:00+03	72300.00
CA24DC	2017-07-07 06:53:00+03	50100.00
CA2547	2017-07-25 02:04:00+03	56000.00
CA255E	2017-08-02 11:55:00+03	66900.00
CA257E	2017-07-22 23:39:00+03	31600.00
CA25EE	2017-07-15 02:37:00+03	34100.00
CA261D	2017-08-13 13:52:00+03	6700.00
CA274C	2017-08-06 12:32:00+03	27900.00
CA2842	2017-07-09 14:54:00+03	42800.00
CA287C	2017-06-21 16:17:00+03	178800.00
CA28A2	2017-08-09 16:22:00+03	45100.00
CA28A9	2017-07-12 04:28:00+03	23200.00
CA28C8	2017-08-02 21:09:00+03	137600.00
CA28CA	2017-07-27 04:18:00+03	34600.00
CA292E	2017-07-09 22:27:00+03	73600.00
CA2980	2017-07-01 15:59:00+03	147100.00
CA2981	2017-08-15 01:41:00+03	36200.00
CA29AD	2017-07-22 14:09:00+03	23600.00
CA2A74	2017-07-21 10:24:00+03	59300.00
CA2A8C	2017-07-19 17:16:00+03	48200.00
CA2AFE	2017-07-13 14:05:00+03	27800.00
CA2B21	2017-08-06 08:52:00+03	34800.00
CA2BDF	2017-07-08 13:50:00+03	66000.00
CA2BE1	2017-07-03 08:05:00+03	244200.00
CA2BE6	2017-08-10 14:14:00+03	23900.00
CA2C0B	2017-07-23 00:45:00+03	49600.00
CA2C45	2017-07-13 21:06:00+03	51500.00
CA2C8B	2017-08-11 14:30:00+03	66100.00
CA2CA5	2017-07-03 09:39:00+03	83500.00
CA2D3A	2017-08-04 07:50:00+03	277000.00
CA2D42	2017-07-06 15:40:00+03	193600.00
CA2D9E	2017-08-11 03:07:00+03	14400.00
CA2DA0	2017-07-22 13:54:00+03	26800.00
CA2DB2	2017-07-27 12:36:00+03	78700.00
CA2DF5	2017-07-31 00:50:00+03	167400.00
CA2DF8	2017-08-02 14:43:00+03	49300.00
CA2E01	2017-07-04 04:13:00+03	26200.00
CA2E21	2017-07-26 02:43:00+03	117600.00
CA2E81	2017-07-23 19:06:00+03	66600.00
CA2E8E	2017-08-13 21:18:00+03	114600.00
CA2ECD	2017-08-13 18:57:00+03	67000.00
CA2EEB	2017-07-03 11:44:00+03	22000.00
CA2F0D	2017-08-08 17:46:00+03	37100.00
CA2F59	2017-07-26 17:01:00+03	39700.00
CA2F6F	2017-07-26 02:15:00+03	23600.00
CA2F78	2017-07-19 11:45:00+03	16400.00
CA2F7E	2017-07-25 10:49:00+03	14400.00
CA2F9D	2017-07-21 01:05:00+03	12600.00
CA2FD2	2017-08-12 13:37:00+03	178100.00
CA3000	2017-08-12 11:27:00+03	49900.00
CA3024	2017-08-12 17:33:00+03	26200.00
CA303F	2017-07-19 08:50:00+03	21800.00
CA3044	2017-08-06 04:31:00+03	47400.00
CA3090	2017-07-25 18:36:00+03	81600.00
CA30CF	2017-07-08 08:27:00+03	40600.00
CA3114	2017-08-12 03:43:00+03	51200.00
CA31AE	2017-07-08 08:11:00+03	185200.00
CA31C0	2017-07-30 07:12:00+03	100600.00
CA32C5	2017-07-25 08:20:00+03	57600.00
CA32FB	2017-08-02 10:01:00+03	38200.00
CA3300	2017-07-28 09:11:00+03	188000.00
CA33A8	2017-07-10 03:43:00+03	46000.00
CA33AE	2017-07-18 16:11:00+03	38600.00
CA33D8	2017-07-24 21:38:00+03	52300.00
CA33EB	2017-08-06 20:58:00+03	96200.00
CA341F	2017-08-03 17:33:00+03	45100.00
CA342F	2017-08-04 18:01:00+03	134400.00
CA34B4	2017-07-04 21:08:00+03	6000.00
CA34C5	2017-08-12 13:19:00+03	61800.00
CA34C7	2017-08-13 20:10:00+03	36200.00
CA3501	2017-07-19 14:15:00+03	44000.00
CA3505	2017-07-30 20:42:00+03	167400.00
CA3557	2017-08-08 20:38:00+03	44600.00
CA357E	2017-07-06 11:39:00+03	60000.00
CA35D2	2017-07-28 07:40:00+03	38600.00
CA3609	2017-08-12 21:12:00+03	44400.00
CA36F7	2017-08-09 01:47:00+03	31400.00
CA372B	2017-07-30 17:41:00+03	21800.00
CA3732	2017-08-01 11:10:00+03	48800.00
CA3772	2017-07-23 18:43:00+03	28800.00
CA37C9	2017-08-09 10:23:00+03	199700.00
CA37D4	2017-08-07 08:04:00+03	116500.00
CA37D7	2017-07-23 02:31:00+03	175200.00
CA387A	2017-07-15 17:05:00+03	75800.00
CA38B2	2017-08-14 15:07:00+03	86300.00
CA38BB	2017-08-12 02:06:00+03	480600.00
CA38DD	2017-07-27 03:48:00+03	80800.00
CA3995	2017-07-10 13:55:00+03	36400.00
CA399C	2017-07-20 00:23:00+03	89700.00
CA39CE	2017-07-10 15:00:00+03	29400.00
CA3A16	2017-06-29 13:15:00+03	133100.00
CA3A1D	2017-08-05 15:00:00+03	88600.00
CA3A45	2017-08-13 15:09:00+03	277000.00
CA3A52	2017-08-01 08:20:00+03	23400.00
CA3A5D	2017-08-02 02:23:00+03	166000.00
CA3A8E	2017-07-17 15:57:00+03	55800.00
CA3AE8	2017-07-25 02:15:00+03	201200.00
CA3B43	2017-07-28 08:07:00+03	49600.00
CA3B82	2017-07-16 20:35:00+03	41800.00
CA3BF4	2017-07-13 11:24:00+03	23200.00
CA3C3F	2017-08-07 05:34:00+03	50800.00
CA3C8C	2017-07-31 11:59:00+03	43500.00
CA3C91	2017-08-15 07:14:00+03	28800.00
CA3CA7	2017-07-04 03:57:00+03	46300.00
CA3CAF	2017-07-06 06:00:00+03	36200.00
CA3CDB	2017-08-03 02:18:00+03	27600.00
CA3CEA	2017-08-10 08:15:00+03	189200.00
CA3D0D	2017-08-14 11:38:00+03	15900.00
CA3D8E	2017-08-10 09:46:00+03	135400.00
CA3DCB	2017-07-05 21:01:00+03	50600.00
CA3E4B	2017-07-30 21:52:00+03	16400.00
CA3EB0	2017-07-18 08:09:00+03	131600.00
CA3F4F	2017-07-16 03:05:00+03	9300.00
CA3F9A	2017-07-31 09:21:00+03	48400.00
CA3FB7	2017-08-11 03:49:00+03	179200.00
CA4000	2017-08-05 07:42:00+03	258000.00
CA4068	2017-07-05 07:30:00+03	41200.00
CA406D	2017-08-08 20:00:00+03	99300.00
CA4074	2017-07-18 13:07:00+03	26000.00
CA414D	2017-07-07 21:43:00+03	89600.00
CA4181	2017-08-09 12:00:00+03	67800.00
CA4195	2017-08-10 08:20:00+03	96300.00
CA41DA	2017-07-17 06:15:00+03	26000.00
CA4287	2017-08-15 11:08:00+03	24400.00
CA4297	2017-08-06 09:18:00+03	100600.00
CA42A0	2017-08-11 14:15:00+03	205500.00
CA42C9	2017-08-10 18:58:00+03	54800.00
CA4310	2017-08-10 00:22:00+03	37200.00
CA4376	2017-07-28 18:26:00+03	43800.00
CA4394	2017-07-19 23:46:00+03	11000.00
CA43EB	2017-07-22 05:19:00+03	69600.00
CA43F4	2017-07-11 15:11:00+03	203200.00
CA443A	2017-08-05 02:57:00+03	41200.00
CA448A	2017-08-10 04:07:00+03	92800.00
CA44A5	2017-08-02 06:48:00+03	65900.00
CA4505	2017-07-29 12:06:00+03	65000.00
CA4521	2017-08-08 08:27:00+03	12400.00
CA455C	2017-07-08 12:51:00+03	7400.00
CA45AE	2017-07-17 15:45:00+03	39200.00
CA45B9	2017-07-13 19:19:00+03	139300.00
CA45E8	2017-07-25 23:14:00+03	246000.00
CA4619	2017-07-02 13:52:00+03	50700.00
CA462E	2017-08-12 05:14:00+03	62600.00
CA4658	2017-08-12 08:54:00+03	266400.00
CA4668	2017-08-06 11:28:00+03	258700.00
CA4669	2017-08-04 14:46:00+03	141600.00
CA470F	2017-07-17 17:46:00+03	125300.00
CA474A	2017-07-23 14:18:00+03	119700.00
CA47BC	2017-07-08 09:46:00+03	25400.00
CA482B	2017-07-10 02:58:00+03	39800.00
CA4832	2017-08-14 11:57:00+03	135400.00
CA486B	2017-06-30 22:42:00+03	59600.00
CA4965	2017-07-05 20:00:00+03	100600.00
CA4974	2017-08-09 19:08:00+03	39800.00
CA497B	2017-07-06 02:43:00+03	25100.00
CA4980	2017-07-20 21:47:00+03	144200.00
CA49FE	2017-06-27 17:40:00+03	13200.00
CA4A51	2017-07-30 22:36:00+03	88800.00
CA4B54	2017-08-04 01:28:00+03	139500.00
CA4B84	2017-08-14 18:10:00+03	35300.00
CA4BA6	2017-08-11 19:17:00+03	243600.00
CA4BE4	2017-06-28 00:39:00+03	13600.00
CA4BEB	2017-07-16 20:45:00+03	58400.00
CA4BEC	2017-07-01 12:21:00+03	135600.00
CA4C17	2017-07-26 04:32:00+03	48000.00
CA4C38	2017-08-15 02:38:00+03	35600.00
CA4C4E	2017-08-14 21:11:00+03	134800.00
CA4CC4	2017-07-08 23:32:00+03	20800.00
CA4CD0	2017-07-18 11:40:00+03	59800.00
CA4D04	2017-07-06 14:52:00+03	135600.00
CA4D42	2017-08-01 11:48:00+03	177200.00
CA4D83	2017-07-04 02:31:00+03	125200.00
CA4DE0	2017-08-01 07:07:00+03	26000.00
CA4E10	2017-07-14 20:51:00+03	194800.00
CA4EB4	2017-07-07 21:44:00+03	85000.00
CA4EBB	2017-08-05 09:45:00+03	136800.00
CA4ECB	2017-07-03 20:40:00+03	390400.00
CA4EE7	2017-07-31 08:39:00+03	17000.00
CA4F4B	2017-07-07 10:10:00+03	272400.00
CA4F6D	2017-07-29 19:16:00+03	91100.00
CA4F79	2017-07-30 01:40:00+03	6800.00
CA4FBE	2017-07-17 21:30:00+03	52000.00
CA4FE3	2017-07-27 22:32:00+03	66600.00
CA5001	2017-07-10 15:35:00+03	111600.00
CA5035	2017-07-07 06:45:00+03	28800.00
CA504F	2017-08-03 19:11:00+03	38600.00
CA509C	2017-08-12 05:00:00+03	93500.00
CA5109	2017-08-06 23:05:00+03	102100.00
CA5132	2017-07-19 06:52:00+03	7400.00
CA5172	2017-08-04 14:23:00+03	58800.00
CA5235	2017-07-24 14:39:00+03	114600.00
CA52AC	2017-08-11 19:15:00+03	496700.00
CA52ED	2017-07-30 10:24:00+03	22400.00
CA5303	2017-07-01 22:08:00+03	50300.00
CA5332	2017-07-28 02:05:00+03	189200.00
CA5416	2017-07-28 14:19:00+03	208500.00
CA5482	2017-07-16 18:26:00+03	124200.00
CA5514	2017-07-14 06:34:00+03	46400.00
CA554B	2017-07-12 10:29:00+03	226800.00
CA5567	2017-07-26 17:48:00+03	58200.00
CA5573	2017-07-19 19:01:00+03	67200.00
CA55A2	2017-08-11 02:19:00+03	51800.00
CA55B8	2017-07-13 02:25:00+03	111600.00
CA5615	2017-07-23 22:33:00+03	25000.00
CA5659	2017-07-26 20:37:00+03	40600.00
CA5705	2017-08-01 03:27:00+03	44400.00
CA574A	2017-08-09 18:37:00+03	6000.00
CA5759	2017-07-03 19:00:00+03	143200.00
CA577F	2017-07-05 03:27:00+03	3700.00
CA58AF	2017-07-15 14:52:00+03	25600.00
CA598C	2017-07-25 08:23:00+03	23600.00
CA59C1	2017-07-12 06:06:00+03	57700.00
CA5A12	2017-07-03 10:22:00+03	53100.00
CA5A13	2017-08-12 22:07:00+03	29600.00
CA5A99	2017-07-18 08:59:00+03	146700.00
CA5A9C	2017-08-01 18:39:00+03	38400.00
CA5AEC	2017-07-04 03:01:00+03	119600.00
CA5B41	2017-07-18 09:43:00+03	28800.00
CA5B76	2017-08-12 04:51:00+03	62600.00
CA5B95	2017-08-09 04:28:00+03	31400.00
CA5C1B	2017-07-02 19:10:00+03	55800.00
CA5C65	2017-08-09 15:31:00+03	124400.00
CA5C71	2017-08-10 07:59:00+03	52300.00
CA5CF1	2017-08-02 09:38:00+03	10800.00
CA5D04	2017-06-30 04:58:00+03	133200.00
CA5D2B	2017-08-08 05:14:00+03	21000.00
CA5D40	2017-08-15 14:08:00+03	53100.00
CA5D61	2017-06-28 21:00:00+03	22000.00
CA5DD2	2017-07-23 06:46:00+03	132800.00
CA5E32	2017-07-13 18:10:00+03	31400.00
CA5E51	2017-07-07 15:23:00+03	43800.00
CA5E55	2017-06-28 03:42:00+03	75300.00
CA5FAE	2017-08-10 02:02:00+03	57300.00
CA5FE3	2017-08-08 03:05:00+03	26000.00
CA6009	2017-07-25 07:32:00+03	46400.00
CA611F	2017-08-02 16:21:00+03	65900.00
CA615C	2017-07-24 14:43:00+03	79900.00
CA616F	2017-07-04 23:50:00+03	84500.00
CA6185	2017-06-29 21:30:00+03	62800.00
CA6195	2017-07-11 17:40:00+03	126300.00
CA61C7	2017-07-07 06:25:00+03	66600.00
CA620E	2017-08-12 13:35:00+03	66600.00
CA6212	2017-07-06 10:04:00+03	213800.00
CA62DE	2017-08-09 07:32:00+03	55800.00
CA6324	2017-08-05 07:11:00+03	55500.00
CA6360	2017-07-07 16:07:00+03	40800.00
CA6388	2017-07-01 10:54:00+03	56800.00
CA63A4	2017-07-02 02:28:00+03	6800.00
CA63E9	2017-07-21 14:50:00+03	534900.00
CA642F	2017-07-15 04:29:00+03	25100.00
CA6458	2017-07-21 03:18:00+03	50400.00
CA650F	2017-08-09 04:52:00+03	162200.00
CA6514	2017-08-15 16:39:00+03	136200.00
CA654F	2017-08-15 01:52:00+03	36100.00
CA6555	2017-07-05 19:05:00+03	20000.00
CA65BD	2017-07-26 21:49:00+03	117000.00
CA65C9	2017-07-07 16:52:00+03	12000.00
CA65D6	2017-07-27 12:28:00+03	56000.00
CA65E9	2017-07-31 20:30:00+03	115600.00
CA66DA	2017-07-03 05:46:00+03	222800.00
CA66EE	2017-07-27 15:18:00+03	15100.00
CA677E	2017-08-07 17:41:00+03	67600.00
CA678B	2017-08-09 10:20:00+03	284400.00
CA67B8	2017-08-01 15:46:00+03	65900.00
CA67DA	2017-08-10 12:59:00+03	114800.00
CA67DC	2017-08-12 13:22:00+03	19800.00
CA6863	2017-08-12 14:24:00+03	103600.00
CA68EB	2017-07-14 06:09:00+03	174600.00
CA6931	2017-07-08 19:46:00+03	230600.00
CA693C	2017-07-19 18:29:00+03	111600.00
CA6974	2017-08-05 08:00:00+03	26600.00
CA6992	2017-08-14 15:05:00+03	27200.00
CA6A76	2017-07-28 08:50:00+03	121400.00
CA6AC9	2017-07-25 21:09:00+03	24400.00
CA6AEA	2017-08-11 08:32:00+03	62800.00
CA6B1B	2017-06-30 00:19:00+03	26000.00
CA6B23	2017-07-01 16:36:00+03	123000.00
CA6B6B	2017-07-20 03:57:00+03	66800.00
CA6B81	2017-07-02 02:31:00+03	181100.00
CA6BA7	2017-07-19 14:27:00+03	57300.00
CA6C15	2017-08-09 20:31:00+03	67600.00
CA6C20	2017-07-07 18:35:00+03	44600.00
CA6C3D	2017-08-10 06:31:00+03	7400.00
CA6CB6	2017-08-07 04:23:00+03	136800.00
CA6CE2	2017-08-05 18:43:00+03	189200.00
CA6CE5	2017-07-12 23:13:00+03	172300.00
CA6D5F	2017-07-30 00:35:00+03	173200.00
CA6D6A	2017-08-06 13:32:00+03	28000.00
CA6D79	2017-07-14 01:44:00+03	92900.00
CA6D92	2017-07-31 10:37:00+03	27600.00
CA6DB5	2017-07-30 05:40:00+03	41600.00
CA6DBD	2017-07-11 04:29:00+03	239700.00
CA6DE3	2017-07-30 14:09:00+03	70800.00
CA6E1E	2017-07-11 22:37:00+03	273600.00
CA6E68	2017-08-12 16:13:00+03	94000.00
CA6E6D	2017-07-04 13:12:00+03	135600.00
CA6E8E	2017-07-06 12:36:00+03	37900.00
CA6F07	2017-08-14 23:58:00+03	204500.00
CA6F4F	2017-07-06 00:09:00+03	24400.00
CA6F87	2017-07-03 13:49:00+03	105400.00
CA705E	2017-07-16 13:50:00+03	197700.00
CA7083	2017-07-07 09:55:00+03	198400.00
CA70C6	2017-07-28 15:54:00+03	23200.00
CA71DC	2017-07-04 02:27:00+03	265700.00
CA722B	2017-08-01 13:49:00+03	202400.00
CA7239	2017-08-04 21:20:00+03	55800.00
CA725C	2017-07-26 04:24:00+03	28000.00
CA7364	2017-07-15 04:46:00+03	60300.00
CA7383	2017-07-20 03:02:00+03	6700.00
CA73D3	2017-08-06 07:25:00+03	26000.00
CA73F8	2017-07-10 02:27:00+03	24300.00
CA7419	2017-07-03 12:44:00+03	56900.00
CA741F	2017-08-01 02:11:00+03	134600.00
CA742F	2017-08-10 13:18:00+03	115100.00
CA7538	2017-08-13 09:04:00+03	50200.00
CA755F	2017-07-30 18:54:00+03	48400.00
CA75B5	2017-08-08 09:51:00+03	188900.00
CA75C3	2017-07-27 23:08:00+03	8400.00
CA7621	2017-08-09 15:48:00+03	44200.00
CA7647	2017-08-11 15:30:00+03	67600.00
CA7680	2017-08-01 17:00:00+03	99200.00
CA7722	2017-08-14 14:31:00+03	57600.00
CA7727	2017-07-09 21:01:00+03	301800.00
CA7740	2017-08-04 13:06:00+03	65000.00
CA7765	2017-07-10 14:17:00+03	96300.00
CA7767	2017-08-04 20:39:00+03	56000.00
CA77EB	2017-07-09 08:12:00+03	86500.00
CA7805	2017-08-14 16:46:00+03	25600.00
CA7809	2017-07-06 11:58:00+03	41500.00
CA7851	2017-08-09 03:20:00+03	40800.00
CA78CE	2017-07-26 18:01:00+03	51200.00
CA799F	2017-07-16 04:14:00+03	166100.00
CA7A16	2017-07-04 11:00:00+03	24400.00
CA7A36	2017-07-25 03:04:00+03	51900.00
CA7A39	2017-08-03 15:55:00+03	30000.00
CA7A72	2017-07-23 08:01:00+03	155300.00
CA7A8A	2017-07-06 20:54:00+03	44800.00
CA7A90	2017-08-03 12:47:00+03	27300.00
CA7AD4	2017-08-11 17:31:00+03	35800.00
CA7AEA	2017-07-09 04:31:00+03	26000.00
CA7B38	2017-08-02 10:39:00+03	82900.00
CA7B5A	2017-08-15 01:23:00+03	21200.00
CA7B64	2017-08-12 10:49:00+03	186900.00
CA7B8C	2017-07-31 12:29:00+03	180800.00
CA7BAF	2017-08-10 23:10:00+03	47500.00
CA7C35	2017-08-08 13:24:00+03	49900.00
CA7C41	2017-07-31 14:34:00+03	30000.00
CA7CDB	2017-08-06 10:35:00+03	265700.00
CA7CE2	2017-08-13 19:04:00+03	52800.00
CA7D11	2017-07-11 03:08:00+03	70400.00
CA7E10	2017-08-14 02:43:00+03	28000.00
CA7EAB	2017-07-14 00:04:00+03	20200.00
CA7ED6	2017-08-12 12:48:00+03	24700.00
CA7EE2	2017-07-20 03:29:00+03	67200.00
CA7F1A	2017-08-10 02:20:00+03	86800.00
CA7F75	2017-07-02 04:14:00+03	28000.00
CA7FC0	2017-07-22 19:16:00+03	51500.00
CA8035	2017-07-24 09:38:00+03	42800.00
CA8054	2017-08-08 15:46:00+03	28800.00
CA8076	2017-08-11 10:42:00+03	240600.00
CA8089	2017-07-17 09:08:00+03	39500.00
CA80B7	2017-08-14 13:10:00+03	11700.00
CA8174	2017-07-22 07:34:00+03	40400.00
CA817C	2017-07-26 05:53:00+03	42700.00
CA8182	2017-07-05 12:58:00+03	56100.00
CA8213	2017-08-12 23:13:00+03	180800.00
CA822B	2017-08-12 15:35:00+03	22000.00
CA82B1	2017-07-18 05:27:00+03	75300.00
CA82D4	2017-08-10 10:22:00+03	51900.00
CA82E3	2017-07-29 00:24:00+03	167400.00
CA82EC	2017-08-08 16:12:00+03	44800.00
CA830F	2017-07-20 21:06:00+03	27200.00
CA8313	2017-07-20 09:43:00+03	61800.00
CA834E	2017-07-08 03:15:00+03	86400.00
CA836D	2017-07-21 06:48:00+03	46000.00
CA8382	2017-08-07 19:32:00+03	18300.00
CA83D5	2017-08-06 08:01:00+03	48800.00
CA8442	2017-07-28 10:23:00+03	266400.00
CA8471	2017-07-12 10:19:00+03	112000.00
CA8497	2017-07-10 01:48:00+03	25400.00
CA849A	2017-08-02 19:11:00+03	26000.00
CA8531	2017-07-27 15:04:00+03	13700.00
CA8547	2017-07-07 00:06:00+03	52000.00
CA855D	2017-07-30 09:55:00+03	28800.00
CA8686	2017-07-05 00:52:00+03	28000.00
CA8703	2017-07-19 23:47:00+03	272300.00
CA871A	2017-08-10 08:22:00+03	80700.00
CA873F	2017-07-10 21:22:00+03	68400.00
CA8781	2017-07-07 13:23:00+03	43200.00
CA87A0	2017-07-09 20:23:00+03	21600.00
CA87EC	2017-08-08 21:18:00+03	23600.00
CA88D9	2017-07-25 18:38:00+03	69500.00
CA88DE	2017-07-26 00:31:00+03	46000.00
CA896A	2017-08-07 06:12:00+03	58200.00
CA897A	2017-07-06 22:45:00+03	44500.00
CA8A0E	2017-08-12 11:04:00+03	98200.00
CA8A1F	2017-08-04 08:43:00+03	46800.00
CA8A36	2017-08-12 23:45:00+03	23200.00
CA8A3D	2017-07-16 19:35:00+03	32800.00
CA8ACF	2017-07-05 05:01:00+03	149600.00
CA8BB4	2017-08-04 12:30:00+03	95800.00
CA8BD4	2017-07-08 08:55:00+03	123000.00
CA8C31	2017-07-12 05:17:00+03	139800.00
CA8C39	2017-08-08 19:30:00+03	408500.00
CA8CE6	2017-07-20 17:53:00+03	398900.00
CA8D6B	2017-08-03 12:22:00+03	94000.00
CA8D91	2017-08-02 11:18:00+03	29400.00
CA8D98	2017-07-16 08:56:00+03	39400.00
CA8DA5	2017-07-08 15:01:00+03	211600.00
CA8DAE	2017-07-30 05:42:00+03	41900.00
CA8E19	2017-07-08 14:12:00+03	26000.00
CA8E3A	2017-08-04 08:54:00+03	85000.00
CA8E6F	2017-07-12 16:18:00+03	88800.00
CA8EA3	2017-07-11 11:16:00+03	69500.00
CA8F33	2017-07-16 16:16:00+03	134800.00
CA8F62	2017-07-25 09:57:00+03	189700.00
CA8FFA	2017-07-10 11:36:00+03	31400.00
CA902D	2017-08-02 01:35:00+03	43600.00
CA90BB	2017-06-29 22:22:00+03	74000.00
CA90D9	2017-07-07 09:57:00+03	29400.00
CA910E	2017-07-12 13:31:00+03	72600.00
CA9131	2017-07-24 15:27:00+03	46000.00
CA9159	2017-08-10 23:23:00+03	38200.00
CA918B	2017-07-05 13:29:00+03	29600.00
CA91A0	2017-08-02 03:56:00+03	72000.00
CA91AC	2017-07-30 21:56:00+03	20600.00
CA921E	2017-07-20 18:16:00+03	15700.00
CA925D	2017-07-13 08:03:00+03	28000.00
CA9301	2017-08-11 11:46:00+03	128500.00
CA9318	2017-07-14 05:09:00+03	6700.00
CA934B	2017-08-03 07:00:00+03	35800.00
CA939A	2017-07-21 16:47:00+03	68200.00
CA93C9	2017-07-16 09:12:00+03	41600.00
CA93CF	2017-08-08 06:48:00+03	75600.00
CA9413	2017-07-19 19:38:00+03	14000.00
CA941B	2017-08-01 05:08:00+03	24200.00
CA9466	2017-08-05 02:43:00+03	8600.00
CA9485	2017-08-13 03:55:00+03	93400.00
CA9498	2017-07-01 02:24:00+03	23200.00
CA94D5	2017-07-09 01:23:00+03	83000.00
CA9553	2017-08-06 01:42:00+03	44800.00
CA957E	2017-07-14 03:14:00+03	28000.00
CA95A2	2017-07-23 22:18:00+03	65100.00
CA95A5	2017-08-10 04:04:00+03	25200.00
CA95DC	2017-08-05 13:30:00+03	104200.00
CA95E4	2017-07-23 23:19:00+03	97900.00
CA96FE	2017-08-01 11:48:00+03	31700.00
CA974A	2017-08-10 17:12:00+03	26800.00
CA975E	2017-07-29 22:27:00+03	113000.00
CA9760	2017-07-21 03:29:00+03	48500.00
CA9771	2017-08-04 17:40:00+03	166100.00
CA977A	2017-06-29 00:51:00+03	43500.00
CA97A7	2017-08-11 02:39:00+03	48800.00
CA97D7	2017-07-08 15:31:00+03	39500.00
CA97EE	2017-08-14 07:57:00+03	24800.00
CA983F	2017-08-08 08:23:00+03	68000.00
CA98D1	2017-08-05 10:45:00+03	39200.00
CA98F2	2017-07-11 10:59:00+03	266200.00
CA993B	2017-08-07 19:01:00+03	156300.00
CA999C	2017-07-04 03:22:00+03	46300.00
CA99CB	2017-07-09 16:37:00+03	69500.00
CA99F9	2017-07-09 23:12:00+03	75800.00
CA9A19	2017-07-09 18:32:00+03	58400.00
CA9A29	2017-08-14 15:58:00+03	80400.00
CA9A77	2017-07-25 10:06:00+03	87000.00
CA9A84	2017-08-07 20:57:00+03	27900.00
CA9AB2	2017-07-29 09:41:00+03	266300.00
CA9ABA	2017-07-25 06:01:00+03	398500.00
CA9ADE	2017-08-06 12:41:00+03	15100.00
CA9AE3	2017-07-04 17:12:00+03	43600.00
CA9B36	2017-07-09 12:09:00+03	124300.00
CA9B74	2017-08-06 00:52:00+03	83000.00
CA9BA8	2017-08-12 16:32:00+03	125200.00
CA9BFD	2017-08-08 14:40:00+03	135400.00
CA9C45	2017-08-09 19:03:00+03	92000.00
CA9C50	2017-07-12 14:43:00+03	9800.00
CA9CB9	2017-08-01 00:08:00+03	73300.00
CA9CC8	2017-07-20 02:04:00+03	141000.00
CA9CDE	2017-07-22 18:00:00+03	6600.00
CA9CF5	2017-08-15 15:26:00+03	25400.00
CA9D11	2017-07-27 11:58:00+03	22000.00
CA9D21	2017-06-29 16:11:00+03	67000.00
CA9DDD	2017-07-28 12:03:00+03	48800.00
CA9E01	2017-07-01 14:32:00+03	12600.00
CA9E1E	2017-08-04 22:07:00+03	46000.00
CA9E6E	2017-07-28 17:50:00+03	136800.00
CA9E75	2017-08-07 15:53:00+03	155000.00
CA9EB7	2017-08-14 15:22:00+03	13400.00
CA9F62	2017-07-20 20:54:00+03	21800.00
CA9F92	2017-07-21 15:40:00+03	98600.00
CA9F9B	2017-07-04 06:36:00+03	52000.00
CA9FB2	2017-08-12 02:44:00+03	42900.00
CA9FC1	2017-08-09 09:51:00+03	66200.00
CAA02C	2017-08-08 17:25:00+03	42000.00
CAA03E	2017-08-06 00:43:00+03	92700.00
CAA0AE	2017-08-06 20:10:00+03	36000.00
CAA0BB	2017-07-31 03:36:00+03	121100.00
CAA272	2017-07-15 21:41:00+03	31600.00
CAA275	2017-08-07 15:07:00+03	305300.00
CAA2E0	2017-08-15 08:54:00+03	59800.00
CAA2E5	2017-08-09 07:26:00+03	30700.00
CAA343	2017-08-11 16:42:00+03	87700.00
CAA397	2017-06-30 21:45:00+03	37200.00
CAA3F8	2017-07-30 01:33:00+03	69500.00
CAA420	2017-08-14 13:55:00+03	43900.00
CAA48A	2017-07-06 03:09:00+03	42400.00
CAA48B	2017-08-02 12:19:00+03	176800.00
CAA493	2017-07-26 23:22:00+03	213700.00
CAA4C4	2017-07-29 17:07:00+03	56000.00
CAA4EE	2017-07-18 14:34:00+03	131000.00
CAA61C	2017-07-31 08:15:00+03	35400.00
CAA65C	2017-07-30 07:51:00+03	62100.00
CAA660	2017-08-13 19:10:00+03	28000.00
CAA6A3	2017-08-05 19:06:00+03	84000.00
CAA6A6	2017-07-04 02:24:00+03	124200.00
CAA6F0	2017-07-10 03:15:00+03	60200.00
CAA70F	2017-07-05 16:37:00+03	6700.00
CAA758	2017-07-10 04:32:00+03	50600.00
CAA78B	2017-08-08 20:43:00+03	137700.00
CAA7D3	2017-08-03 14:54:00+03	20200.00
CAA8A9	2017-07-12 00:57:00+03	17800.00
CAA8EF	2017-07-19 22:54:00+03	59200.00
CAA931	2017-08-01 20:56:00+03	28000.00
CAA975	2017-07-01 05:27:00+03	142800.00
CAA9B6	2017-08-05 07:08:00+03	8000.00
CAA9C5	2017-07-14 12:01:00+03	93900.00
CAA9E4	2017-07-29 05:18:00+03	523000.00
CAAA09	2017-08-09 07:32:00+03	128800.00
CAAA29	2017-08-06 20:25:00+03	149200.00
CAAA6D	2017-07-15 05:26:00+03	40400.00
CAAA7A	2017-07-29 22:49:00+03	67800.00
CAAAB4	2017-06-26 03:58:00+03	65500.00
CAAAB8	2017-08-14 23:59:00+03	142400.00
CAAAB9	2017-07-20 06:05:00+03	56900.00
CAAACC	2017-07-16 04:07:00+03	23200.00
CAAACF	2017-07-19 05:58:00+03	123000.00
CAAB53	2017-07-21 19:47:00+03	81600.00
CAAC3D	2017-07-12 22:28:00+03	182000.00
CAAC6C	2017-08-01 07:40:00+03	24400.00
CAAC7C	2017-07-28 08:08:00+03	116900.00
CAACB4	2017-07-03 07:38:00+03	26000.00
CAACD5	2017-07-14 19:23:00+03	340100.00
CAADD0	2017-08-11 02:54:00+03	398500.00
CAADF6	2017-07-26 10:50:00+03	8400.00
CAAE83	2017-07-10 20:28:00+03	23400.00
CAAEC3	2017-07-14 02:00:00+03	58900.00
CAAEDF	2017-07-15 06:05:00+03	109800.00
CAAF0B	2017-08-07 19:19:00+03	131600.00
CAAF7A	2017-07-07 11:08:00+03	233800.00
CAAFE2	2017-08-10 06:08:00+03	168000.00
CAB00F	2017-07-11 04:46:00+03	114400.00
CAB012	2017-07-17 08:16:00+03	28800.00
CAB029	2017-07-06 23:01:00+03	72400.00
CAB080	2017-07-09 23:11:00+03	91500.00
CAB0E4	2017-07-08 23:01:00+03	58600.00
CAB1A3	2017-07-12 20:24:00+03	6800.00
CAB252	2017-07-29 10:03:00+03	198600.00
CAB2D4	2017-08-09 22:49:00+03	36200.00
CAB2E0	2017-07-04 23:53:00+03	91200.00
CAB302	2017-07-16 12:23:00+03	69100.00
CAB37D	2017-08-02 02:28:00+03	17800.00
CAB3A7	2017-06-28 12:44:00+03	40800.00
CAB3C8	2017-08-06 09:37:00+03	120700.00
CAB461	2017-07-18 14:02:00+03	94000.00
CAB4AB	2017-07-05 04:10:00+03	37100.00
CAB4AE	2017-07-29 13:49:00+03	56900.00
CAB4DC	2017-07-20 07:14:00+03	53900.00
CAB514	2017-07-17 03:49:00+03	115300.00
CAB51E	2017-07-20 17:36:00+03	75300.00
CAB572	2017-08-06 00:42:00+03	75600.00
CAB5F2	2017-07-25 11:53:00+03	43200.00
CAB6A3	2017-07-16 01:06:00+03	14000.00
CAB6E1	2017-07-15 13:24:00+03	182300.00
CAB6ED	2017-08-06 13:55:00+03	36200.00
CAB72D	2017-08-09 23:41:00+03	24000.00
CAB72F	2017-08-11 11:24:00+03	85400.00
CAB732	2017-07-22 04:08:00+03	54800.00
CAB7D6	2017-07-04 18:54:00+03	44600.00
CAB7E9	2017-07-28 03:14:00+03	79800.00
CAB81D	2017-07-13 10:56:00+03	52000.00
CAB81F	2017-08-12 20:00:00+03	34200.00
CAB826	2017-07-22 17:49:00+03	36400.00
CAB84A	2017-08-03 15:34:00+03	100600.00
CAB87A	2017-07-05 01:30:00+03	66600.00
CAB8C5	2017-08-02 05:07:00+03	36200.00
CAB8ED	2017-08-10 19:02:00+03	37900.00
CAB905	2017-08-13 20:07:00+03	27200.00
CAB91D	2017-06-30 00:40:00+03	37900.00
CAB92B	2017-07-18 22:39:00+03	103500.00
CAB93C	2017-07-24 09:01:00+03	26000.00
CAB97C	2017-07-18 02:29:00+03	353600.00
CAB98F	2017-07-11 00:03:00+03	234800.00
CAB9AA	2017-08-12 00:03:00+03	49000.00
CABA39	2017-07-21 17:00:00+03	24400.00
CABA43	2017-07-17 22:42:00+03	29600.00
CABA60	2017-07-22 04:26:00+03	46400.00
CABA67	2017-08-11 05:27:00+03	70600.00
CABA88	2017-07-03 06:54:00+03	115600.00
CABAA5	2017-07-27 07:22:00+03	160700.00
CABB11	2017-08-13 21:32:00+03	14400.00
CABB63	2017-07-08 08:24:00+03	79900.00
CABBB7	2017-07-24 08:23:00+03	58800.00
CABBD4	2017-07-07 20:32:00+03	47200.00
CABC03	2017-07-21 11:45:00+03	94700.00
CABC45	2017-08-09 00:40:00+03	73300.00
CABCEB	2017-07-13 11:58:00+03	136700.00
CABD41	2017-07-04 10:59:00+03	65900.00
CABD43	2017-08-06 22:43:00+03	6200.00
CABD55	2017-07-19 12:27:00+03	73900.00
CABD94	2017-07-10 13:44:00+03	36100.00
CABDE6	2017-07-01 03:32:00+03	35600.00
CABE74	2017-07-10 04:06:00+03	136000.00
CABE77	2017-08-05 04:31:00+03	29100.00
CABECA	2017-07-01 03:34:00+03	27200.00
CABECE	2017-07-08 00:34:00+03	8400.00
CABF0A	2017-08-08 04:16:00+03	205600.00
CABF37	2017-08-04 17:19:00+03	73200.00
CABF4A	2017-07-22 09:26:00+03	47400.00
CABF73	2017-08-06 12:34:00+03	50800.00
CABF7E	2017-08-06 05:39:00+03	185600.00
CABFAC	2017-08-06 12:41:00+03	149200.00
CABFEC	2017-07-17 09:06:00+03	265800.00
CABFED	2017-07-21 03:51:00+03	56600.00
CABFF1	2017-07-22 02:49:00+03	37900.00
CAC057	2017-07-20 10:08:00+03	46000.00
CAC087	2017-08-03 07:26:00+03	24400.00
CAC0E2	2017-06-29 04:04:00+03	73600.00
CAC18D	2017-07-19 01:24:00+03	16400.00
CAC1C2	2017-07-09 19:02:00+03	59300.00
CAC1D9	2017-07-14 20:34:00+03	172600.00
CAC204	2017-07-17 18:39:00+03	41800.00
CAC321	2017-07-14 00:38:00+03	128800.00
CAC329	2017-07-10 14:46:00+03	41300.00
CAC37A	2017-06-30 04:05:00+03	62800.00
CAC38B	2017-07-05 18:17:00+03	23200.00
CAC440	2017-07-23 06:27:00+03	136200.00
CAC45D	2017-08-12 20:21:00+03	26700.00
CAC5B2	2017-07-15 18:27:00+03	99300.00
CAC5BA	2017-08-02 05:08:00+03	38800.00
CAC5C7	2017-07-10 00:14:00+03	85000.00
CAC607	2017-08-08 19:42:00+03	28000.00
CAC684	2017-07-26 04:31:00+03	58000.00
CAC73C	2017-07-06 17:15:00+03	196300.00
CAC7DE	2017-08-10 23:32:00+03	84500.00
CAC89E	2017-07-22 01:13:00+03	28000.00
CAC8BB	2017-08-03 18:30:00+03	57700.00
CAC92F	2017-07-30 14:17:00+03	6000.00
CAC9CF	2017-07-08 07:51:00+03	10600.00
CAC9F3	2017-08-15 14:08:00+03	40000.00
CACA0B	2017-07-12 06:02:00+03	147800.00
CACA47	2017-08-14 11:16:00+03	81300.00
CACA99	2017-08-03 12:45:00+03	167400.00
CACAA8	2017-08-12 21:30:00+03	53500.00
CACB30	2017-07-09 12:07:00+03	25600.00
CACB5C	2017-07-17 05:02:00+03	6300.00
CACB6F	2017-07-30 14:56:00+03	26000.00
CACB77	2017-07-12 23:52:00+03	14000.00
CACB81	2017-07-05 09:45:00+03	64700.00
CACBBE	2017-08-08 23:25:00+03	69500.00
CACBCB	2017-07-07 16:54:00+03	30900.00
CACBD4	2017-06-30 20:00:00+03	56600.00
CACC88	2017-07-03 04:23:00+03	80400.00
CACCB1	2017-07-02 23:45:00+03	56600.00
CACD21	2017-07-05 03:07:00+03	46400.00
CACD3E	2017-08-14 15:52:00+03	23400.00
CACD5C	2017-07-26 06:47:00+03	44600.00
CACD73	2017-07-14 11:12:00+03	12400.00
CACE02	2017-08-08 02:52:00+03	21200.00
CACE75	2017-07-05 13:52:00+03	21400.00
CACEC6	2017-07-07 20:50:00+03	26700.00
CACED2	2017-07-22 00:06:00+03	21400.00
CACF24	2017-07-31 15:30:00+03	61800.00
CACF27	2017-07-15 00:02:00+03	50300.00
CACF41	2017-08-14 05:13:00+03	136200.00
CACF6D	2017-07-13 16:33:00+03	17800.00
CACF71	2017-07-27 05:15:00+03	92800.00
CACF8A	2017-07-17 22:47:00+03	182300.00
CACFAA	2017-07-17 01:11:00+03	410200.00
CAD016	2017-07-23 16:33:00+03	24400.00
CAD032	2017-08-07 09:14:00+03	246000.00
CAD06E	2017-07-19 23:28:00+03	6700.00
CAD096	2017-08-14 06:43:00+03	43200.00
CAD0BE	2017-07-20 23:49:00+03	47100.00
CAD0C5	2017-07-21 07:54:00+03	77600.00
CAD0C9	2017-07-18 17:07:00+03	92800.00
CAD100	2017-07-25 02:19:00+03	168200.00
CAD13E	2017-08-04 02:11:00+03	157100.00
CAD1E8	2017-07-29 04:48:00+03	24000.00
CAD2A2	2017-07-16 11:01:00+03	47200.00
CAD2B4	2017-08-10 11:52:00+03	46400.00
CAD2B6	2017-06-26 09:05:00+03	15800.00
CAD2C7	2017-08-03 13:02:00+03	27200.00
CAD320	2017-07-02 07:24:00+03	6800.00
CAD36B	2017-08-05 12:01:00+03	75600.00
CAD416	2017-08-09 05:19:00+03	58900.00
CAD420	2017-08-07 03:16:00+03	90600.00
CAD43E	2017-07-27 07:54:00+03	60400.00
CAD45F	2017-08-02 11:12:00+03	23600.00
CAD464	2017-08-11 22:52:00+03	26000.00
CAD490	2017-06-29 20:31:00+03	91500.00
CAD4C7	2017-07-19 01:58:00+03	23200.00
CAD4D3	2017-08-09 22:06:00+03	26000.00
CAD54D	2017-08-02 16:06:00+03	300700.00
CAD558	2017-08-02 00:20:00+03	27600.00
CAD559	2017-08-12 22:59:00+03	20800.00
CAD565	2017-07-21 18:45:00+03	68100.00
CAD56B	2017-07-09 06:54:00+03	111600.00
CAD5A6	2017-08-01 14:43:00+03	47500.00
CAD5E6	2017-08-07 21:17:00+03	187600.00
CAD5F5	2017-07-09 20:25:00+03	85000.00
CAD634	2017-07-08 11:16:00+03	88600.00
CAD6EA	2017-08-04 16:46:00+03	116900.00
CAD709	2017-08-07 07:15:00+03	38400.00
CAD71B	2017-07-10 13:05:00+03	136100.00
CAD72A	2017-07-09 05:58:00+03	23200.00
CAD72B	2017-07-26 23:56:00+03	54500.00
CAD73D	2017-08-02 08:14:00+03	91600.00
CAD817	2017-07-15 14:23:00+03	114300.00
CAD849	2017-07-24 02:37:00+03	25100.00
CAD864	2017-07-26 18:34:00+03	47100.00
CAD8BC	2017-07-27 19:44:00+03	117600.00
CAD921	2017-08-14 17:32:00+03	28000.00
CADA1A	2017-07-23 04:03:00+03	43600.00
CADA2F	2017-08-02 01:50:00+03	55800.00
CADA79	2017-08-03 14:52:00+03	81300.00
CADA8E	2017-08-07 00:18:00+03	211700.00
CADAB9	2017-07-17 18:54:00+03	248400.00
CADB4D	2017-07-13 19:17:00+03	17000.00
CADB66	2017-07-03 00:17:00+03	36800.00
CADB8A	2017-08-01 18:25:00+03	70100.00
CADB8F	2017-08-09 14:05:00+03	29600.00
CADBC8	2017-08-12 11:34:00+03	265700.00
CADC0D	2017-07-21 04:57:00+03	22000.00
CADC6A	2017-08-12 22:53:00+03	34000.00
CADC91	2017-07-07 07:07:00+03	23200.00
CADCAD	2017-08-03 21:13:00+03	14400.00
CADCD4	2017-07-22 12:27:00+03	46000.00
CADCF3	2017-08-13 14:23:00+03	15400.00
CADD0D	2017-07-24 12:06:00+03	23200.00
CADD43	2017-08-09 00:47:00+03	94900.00
CADD97	2017-08-05 18:43:00+03	75600.00
CADE74	2017-07-28 00:49:00+03	84600.00
CADE93	2017-07-14 16:13:00+03	40900.00
CADEF7	2017-07-29 03:14:00+03	64600.00
CADF17	2017-07-01 20:55:00+03	101500.00
CADFA5	2017-07-03 14:26:00+03	46200.00
CADFB3	2017-08-07 16:02:00+03	123000.00
CADFB9	2017-07-01 05:32:00+03	58800.00
CADFEE	2017-08-13 02:11:00+03	34000.00
CAE031	2017-08-12 16:53:00+03	46700.00
CAE0D5	2017-07-25 06:34:00+03	59200.00
CAE13A	2017-08-15 10:44:00+03	65500.00
CAE199	2017-08-07 14:50:00+03	92900.00
CAE1CE	2017-08-03 19:05:00+03	37900.00
CAE261	2017-07-14 01:06:00+03	112000.00
CAE28C	2017-07-08 15:17:00+03	40600.00
CAE297	2017-08-14 09:56:00+03	68100.00
CAE2A8	2017-07-23 08:44:00+03	181400.00
CAE2C5	2017-07-13 03:19:00+03	52600.00
CAE2F1	2017-07-25 21:50:00+03	27200.00
CAE347	2017-08-15 01:01:00+03	134400.00
CAE350	2017-08-15 01:05:00+03	26800.00
CAE39E	2017-07-22 13:40:00+03	46400.00
CAE3AA	2017-08-09 05:04:00+03	47900.00
CAE3B7	2017-07-11 13:14:00+03	26000.00
CAE499	2017-08-08 21:38:00+03	31400.00
CAE513	2017-07-05 03:45:00+03	46300.00
CAE51D	2017-07-19 20:25:00+03	181200.00
CAE525	2017-07-27 23:27:00+03	218000.00
CAE551	2017-07-06 04:43:00+03	23400.00
CAE563	2017-07-21 05:28:00+03	390400.00
CAE594	2017-07-03 21:44:00+03	77500.00
CAE5B4	2017-07-29 17:16:00+03	145300.00
CAE5C8	2017-07-22 09:04:00+03	29600.00
CAE5D0	2017-07-15 04:01:00+03	38600.00
CAE5D4	2017-07-20 15:07:00+03	213200.00
CAE616	2017-07-16 06:18:00+03	111700.00
CAE63A	2017-07-05 01:02:00+03	34000.00
CAE68B	2017-07-07 17:17:00+03	54000.00
CAE6EB	2017-07-02 12:40:00+03	29600.00
CAE703	2017-07-07 00:42:00+03	6000.00
CAE732	2017-07-29 21:04:00+03	259800.00
CAE7A2	2017-07-04 16:00:00+03	132800.00
CAE851	2017-07-12 23:40:00+03	19600.00
CAE879	2017-08-04 04:45:00+03	28000.00
CAE88D	2017-07-10 06:08:00+03	69900.00
CAE8A6	2017-08-11 13:02:00+03	61500.00
CAE8B9	2017-07-01 15:38:00+03	106100.00
CAE95B	2017-08-05 22:55:00+03	6000.00
CAE992	2017-07-31 08:34:00+03	16400.00
CAE9A7	2017-07-16 16:05:00+03	199200.00
CAEA13	2017-08-14 01:29:00+03	166100.00
CAEA27	2017-07-30 23:46:00+03	64700.00
CAEB99	2017-07-06 18:08:00+03	46100.00
CAEBB3	2017-08-14 13:24:00+03	92400.00
CAEBEE	2017-07-23 07:37:00+03	92700.00
CAECA7	2017-08-05 00:04:00+03	158000.00
CAECB4	2017-06-30 06:04:00+03	72400.00
CAEDE2	2017-07-14 04:11:00+03	93400.00
CAEDF1	2017-08-11 23:22:00+03	135400.00
CAEE13	2017-08-12 03:49:00+03	61800.00
CAEE2B	2017-07-07 02:05:00+03	11800.00
CAEE32	2017-08-01 18:51:00+03	77200.00
CAEE52	2017-07-16 12:35:00+03	24800.00
CAEE78	2017-07-09 02:03:00+03	41900.00
CAEE99	2017-07-26 14:38:00+03	16400.00
CAEEDC	2017-07-11 13:49:00+03	18600.00
CAEEF1	2017-08-09 20:15:00+03	38800.00
CAEF06	2017-07-02 23:19:00+03	56000.00
CAEF4E	2017-07-25 06:30:00+03	21400.00
CAEFB1	2017-08-12 05:26:00+03	24000.00
CAEFD3	2017-07-25 01:46:00+03	122700.00
CAEFF2	2017-07-24 18:54:00+03	149200.00
CAF076	2017-07-19 11:59:00+03	28800.00
CAF0AD	2017-07-25 20:30:00+03	26000.00
CAF0AF	2017-08-06 19:41:00+03	270800.00
CAF0C4	2017-07-18 11:23:00+03	83200.00
CAF0FA	2017-08-03 02:00:00+03	68400.00
CAF12E	2017-07-31 00:51:00+03	132800.00
CAF15C	2017-07-12 01:33:00+03	86100.00
CAF1A0	2017-06-29 06:48:00+03	28000.00
CAF1E8	2017-08-07 04:57:00+03	31800.00
CAF1F2	2017-07-23 10:13:00+03	58200.00
CAF211	2017-07-28 23:41:00+03	94000.00
CAF21E	2017-07-11 16:18:00+03	124200.00
CAF26D	2017-08-12 03:15:00+03	39800.00
CAF291	2017-07-08 12:24:00+03	133200.00
CAF2A9	2017-07-16 08:47:00+03	62900.00
CAF2C4	2017-07-26 19:39:00+03	30800.00
CAF2E0	2017-08-11 13:04:00+03	28800.00
CAF2E1	2017-08-09 15:27:00+03	31000.00
CAF320	2017-08-12 15:43:00+03	54500.00
CAF345	2017-07-01 01:18:00+03	48500.00
CAF352	2017-07-29 10:11:00+03	119000.00
CAF38A	2017-07-24 08:19:00+03	99600.00
CAF3E1	2017-07-05 02:50:00+03	36800.00
CAF41D	2017-08-01 23:21:00+03	12000.00
CAF41F	2017-08-11 19:36:00+03	124800.00
CAF45C	2017-08-09 12:29:00+03	266400.00
CAF48A	2017-08-08 08:58:00+03	531400.00
CAF4B0	2017-07-24 19:38:00+03	56000.00
CAF4F2	2017-07-17 08:47:00+03	70700.00
CAF509	2017-07-30 19:11:00+03	75600.00
CAF56F	2017-07-07 15:15:00+03	233800.00
CAF5CC	2017-07-22 21:27:00+03	32400.00
CAF5E9	2017-08-10 13:24:00+03	136200.00
CAF60C	2017-07-24 22:49:00+03	31900.00
CAF624	2017-07-12 01:54:00+03	13700.00
CAF629	2017-08-09 07:30:00+03	19800.00
CAF671	2017-07-28 22:19:00+03	37700.00
CAF681	2017-07-14 03:51:00+03	96200.00
CAF695	2017-07-17 13:29:00+03	137400.00
CAF6A7	2017-08-11 03:58:00+03	31200.00
CAF722	2017-06-28 19:07:00+03	32200.00
CAF771	2017-07-13 08:55:00+03	160800.00
CAF791	2017-07-12 11:25:00+03	66600.00
CAF7DD	2017-07-11 05:08:00+03	19800.00
CAF7E6	2017-07-31 21:29:00+03	97700.00
CAF7EF	2017-07-23 00:01:00+03	61800.00
CAF843	2017-07-04 07:19:00+03	147700.00
CAF8EF	2017-07-31 09:51:00+03	12600.00
CAF978	2017-07-28 08:47:00+03	35600.00
CAF9DB	2017-08-06 08:49:00+03	189200.00
CAF9EA	2017-08-05 09:21:00+03	8000.00
CAFA8F	2017-08-07 20:36:00+03	41600.00
CAFAB5	2017-08-05 22:53:00+03	40800.00
CAFB07	2017-07-29 17:23:00+03	17800.00
CAFB1C	2017-07-07 05:31:00+03	193800.00
CAFB3A	2017-08-12 09:09:00+03	26100.00
CAFBCA	2017-07-27 06:08:00+03	167400.00
CAFCA2	2017-07-03 13:30:00+03	23200.00
CAFCA3	2017-07-29 09:54:00+03	23600.00
CAFCAD	2017-07-27 01:19:00+03	64800.00
CAFCAF	2017-07-18 23:35:00+03	206400.00
CAFCDE	2017-08-07 02:48:00+03	61800.00
CAFCE7	2017-08-08 20:39:00+03	39500.00
CAFCF1	2017-07-31 21:28:00+03	25800.00
CAFCF8	2017-08-11 18:18:00+03	20600.00
CAFD5E	2017-07-03 02:26:00+03	408500.00
CAFD83	2017-07-30 11:27:00+03	123000.00
CAFD9F	2017-08-08 01:31:00+03	19600.00
CAFDE3	2017-07-28 08:15:00+03	245700.00
CAFDEE	2017-08-08 21:47:00+03	36700.00
CAFE46	2017-07-10 23:05:00+03	28800.00
CAFF11	2017-07-25 14:40:00+03	26700.00
CAFF38	2017-08-13 18:17:00+03	29600.00
CAFFD3	2017-08-07 04:02:00+03	7300.00
CB0007	2017-08-13 13:18:00+03	48600.00
CB0014	2017-06-26 14:10:00+03	14900.00
CB004C	2017-07-01 13:07:00+03	24400.00
CB0077	2017-07-07 16:19:00+03	58600.00
CB00D5	2017-07-21 11:34:00+03	32600.00
CB010F	2017-07-26 10:45:00+03	136800.00
CB011E	2017-08-04 19:07:00+03	32300.00
CB0131	2017-08-03 16:38:00+03	46200.00
CB01C8	2017-08-01 17:00:00+03	12600.00
CB01EB	2017-08-14 06:49:00+03	15900.00
CB0217	2017-07-02 06:17:00+03	68800.00
CB030B	2017-08-07 21:51:00+03	185600.00
CB0394	2017-08-10 14:33:00+03	184300.00
CB0395	2017-07-04 03:00:00+03	52400.00
CB03CF	2017-07-11 03:56:00+03	219100.00
CB03DA	2017-07-20 07:38:00+03	20400.00
CB03F6	2017-07-05 07:59:00+03	164600.00
CB0532	2017-07-19 11:14:00+03	96100.00
CB0598	2017-07-04 06:57:00+03	12400.00
CB05ED	2017-07-08 19:26:00+03	19600.00
CB060F	2017-08-08 17:53:00+03	32800.00
CB0614	2017-07-12 07:06:00+03	58400.00
CB061B	2017-07-11 23:52:00+03	130100.00
CB0629	2017-07-20 08:29:00+03	92800.00
CB065C	2017-07-16 19:28:00+03	103800.00
CB06E4	2017-07-13 02:56:00+03	56000.00
CB0709	2017-07-13 01:39:00+03	24800.00
CB0792	2017-08-05 12:08:00+03	28800.00
CB080A	2017-07-08 08:24:00+03	11600.00
CB0836	2017-08-02 09:52:00+03	248300.00
CB083C	2017-07-02 12:34:00+03	40400.00
CB08D6	2017-07-28 19:16:00+03	38600.00
CB08F7	2017-07-25 05:45:00+03	21400.00
CB090C	2017-08-13 16:52:00+03	32800.00
CB0942	2017-08-09 15:03:00+03	29100.00
CB09A5	2017-08-05 09:34:00+03	87000.00
CB09B4	2017-08-13 09:50:00+03	26000.00
CB09D4	2017-08-07 09:16:00+03	74800.00
CB0A02	2017-08-08 05:51:00+03	128800.00
CB0A07	2017-08-13 03:50:00+03	44500.00
CB0A51	2017-07-10 10:31:00+03	246000.00
CB0A9B	2017-07-07 08:58:00+03	97100.00
CB0AA2	2017-08-02 09:07:00+03	16400.00
CB0ACE	2017-07-14 11:15:00+03	28000.00
CB0C34	2017-07-22 18:37:00+03	28000.00
CB0CAD	2017-07-24 07:08:00+03	112000.00
CB0CBE	2017-07-04 04:31:00+03	56000.00
CB0D3F	2017-07-06 23:03:00+03	6300.00
CB0D55	2017-07-15 16:28:00+03	87200.00
CB0D64	2017-07-29 17:54:00+03	47200.00
CB0D66	2017-06-29 04:08:00+03	57600.00
CB0D6C	2017-08-11 06:56:00+03	38300.00
CB0D8B	2017-08-07 05:27:00+03	273600.00
CB0DED	2017-07-27 02:37:00+03	46400.00
CB0E04	2017-07-20 07:36:00+03	111600.00
CB0E3D	2017-08-13 04:47:00+03	6800.00
CB0ECB	2017-07-14 12:47:00+03	66000.00
CB0FB1	2017-07-25 11:43:00+03	40400.00
CB0FB6	2017-08-01 00:49:00+03	38000.00
CB1019	2017-07-24 07:08:00+03	46000.00
CB1021	2017-07-05 19:40:00+03	116700.00
CB1031	2017-08-07 12:47:00+03	26600.00
CB1048	2017-08-03 20:21:00+03	67600.00
CB10A5	2017-08-02 09:39:00+03	424600.00
CB10D1	2017-07-17 16:45:00+03	65200.00
CB10D5	2017-08-12 22:15:00+03	112000.00
CB10FC	2017-08-04 00:32:00+03	40000.00
CB1176	2017-08-01 20:39:00+03	48400.00
CB1193	2017-08-14 16:17:00+03	67900.00
CB1194	2017-07-02 01:30:00+03	31400.00
CB1232	2017-07-19 12:48:00+03	56000.00
CB1234	2017-08-13 16:19:00+03	57500.00
CB123F	2017-07-10 14:21:00+03	29600.00
CB125D	2017-07-13 17:31:00+03	73900.00
CB1260	2017-07-08 10:26:00+03	11600.00
CB1319	2017-07-12 23:28:00+03	31400.00
CB1372	2017-07-03 07:05:00+03	63400.00
CB13D9	2017-07-03 20:46:00+03	193600.00
CB13FF	2017-08-07 18:49:00+03	56000.00
CB1450	2017-07-30 17:24:00+03	118800.00
CB14A2	2017-07-10 08:39:00+03	36200.00
CB14AF	2017-08-15 05:58:00+03	83000.00
CB155D	2017-07-05 12:44:00+03	66600.00
CB1615	2017-07-19 21:55:00+03	91800.00
CB162E	2017-07-23 09:22:00+03	148800.00
CB1657	2017-07-01 12:01:00+03	135600.00
CB1672	2017-07-11 04:23:00+03	86800.00
CB167B	2017-08-09 21:52:00+03	12600.00
CB16CC	2017-08-07 12:24:00+03	73300.00
CB16F0	2017-07-16 01:40:00+03	58200.00
CB1719	2017-07-04 22:23:00+03	369000.00
CB1720	2017-08-05 01:38:00+03	191200.00
CB1751	2017-07-20 20:49:00+03	117600.00
CB17AD	2017-07-23 08:41:00+03	28800.00
CB17D0	2017-08-07 04:00:00+03	56000.00
CB1801	2017-07-23 17:51:00+03	26800.00
CB1875	2017-08-13 13:20:00+03	188000.00
CB18C5	2017-08-10 11:15:00+03	25800.00
CB1914	2017-08-10 21:46:00+03	42100.00
CB1960	2017-07-26 04:35:00+03	25200.00
CB19B2	2017-08-15 16:35:00+03	135400.00
CB19E6	2017-07-12 03:13:00+03	213200.00
CB1A25	2017-07-11 14:21:00+03	39200.00
CB1AAC	2017-08-01 10:32:00+03	117000.00
CB1AEC	2017-08-12 21:45:00+03	46400.00
CB1B3B	2017-07-02 14:38:00+03	268400.00
CB1B49	2017-08-11 12:37:00+03	25000.00
CB1B82	2017-08-03 15:19:00+03	50500.00
CB1BB0	2017-07-06 18:04:00+03	84800.00
CB1C36	2017-07-10 08:28:00+03	134400.00
CB1C93	2017-08-03 04:17:00+03	68800.00
CB1D1E	2017-08-01 08:55:00+03	75300.00
CB1D6C	2017-07-26 12:50:00+03	53300.00
CB1D96	2017-07-24 08:56:00+03	122000.00
CB1DF2	2017-07-20 06:38:00+03	133000.00
CB1E46	2017-08-13 12:52:00+03	49200.00
CB1E50	2017-07-22 14:00:00+03	23200.00
CB1E96	2017-08-12 17:01:00+03	113300.00
CB1ED7	2017-07-02 22:34:00+03	62600.00
CB1F41	2017-08-05 07:05:00+03	23200.00
CB1F6C	2017-08-03 11:15:00+03	73200.00
CB1F74	2017-07-02 15:26:00+03	59200.00
CB1FA2	2017-08-02 17:30:00+03	207200.00
CB1FAA	2017-08-06 23:58:00+03	66000.00
CB1FE1	2017-07-06 13:46:00+03	34000.00
CB2042	2017-07-15 06:42:00+03	101100.00
CB20C2	2017-06-29 16:42:00+03	40000.00
CB20D7	2017-07-30 15:26:00+03	20400.00
CB20E0	2017-07-30 02:58:00+03	33200.00
CB2121	2017-07-20 06:16:00+03	24700.00
CB2189	2017-08-02 19:36:00+03	73200.00
CB2204	2017-07-14 02:26:00+03	48800.00
CB222B	2017-07-13 22:18:00+03	21800.00
CB227C	2017-07-17 13:51:00+03	109000.00
CB2299	2017-08-06 22:14:00+03	41200.00
CB2342	2017-07-25 22:35:00+03	47000.00
CB234B	2017-07-23 02:00:00+03	28000.00
CB23AF	2017-07-27 11:40:00+03	15900.00
CB243A	2017-07-24 21:51:00+03	11300.00
CB244F	2017-07-11 21:40:00+03	54500.00
CB2475	2017-07-11 09:56:00+03	54200.00
CB2510	2017-08-05 17:34:00+03	6000.00
CB254E	2017-08-10 17:10:00+03	48800.00
CB25F9	2017-08-06 05:24:00+03	134400.00
CB2633	2017-08-08 16:38:00+03	32400.00
CB269A	2017-07-29 19:42:00+03	27300.00
CB26AF	2017-07-23 23:06:00+03	88800.00
CB26CB	2017-07-22 18:06:00+03	62800.00
CB26F6	2017-07-30 04:38:00+03	57400.00
CB2768	2017-08-02 16:04:00+03	40400.00
CB2781	2017-07-11 03:39:00+03	167500.00
CB2907	2017-08-06 17:23:00+03	82100.00
CB2995	2017-07-23 05:33:00+03	38800.00
CB29FD	2017-07-16 15:20:00+03	73500.00
CB2A0E	2017-08-06 20:35:00+03	18800.00
CB2A31	2017-07-03 04:37:00+03	67400.00
CB2A8D	2017-08-10 02:37:00+03	16400.00
CB2AD9	2017-07-18 06:57:00+03	64700.00
CB2B11	2017-07-31 13:44:00+03	37700.00
CB2B39	2017-06-30 14:21:00+03	46400.00
CB2B5B	2017-08-15 07:26:00+03	532600.00
CB2B62	2017-08-12 21:05:00+03	37500.00
CB2B97	2017-07-30 19:45:00+03	24400.00
CB2B9B	2017-07-04 00:36:00+03	28000.00
CB2BA8	2017-07-10 22:03:00+03	28000.00
CB2BC0	2017-07-12 05:07:00+03	84500.00
CB2C8C	2017-07-06 06:28:00+03	71400.00
CB2CD2	2017-07-19 22:11:00+03	40700.00
CB2CE2	2017-07-18 06:51:00+03	99300.00
CB2D07	2017-08-13 10:16:00+03	48800.00
CB2DAE	2017-07-18 05:01:00+03	59800.00
CB2DC0	2017-06-30 21:40:00+03	24600.00
CB2DE9	2017-08-02 18:19:00+03	123000.00
CB2DEA	2017-07-09 17:55:00+03	27900.00
CB2DEE	2017-08-04 18:43:00+03	50200.00
CB2DF3	2017-07-18 14:28:00+03	67000.00
CB2E36	2017-07-16 23:53:00+03	182300.00
CB2ED0	2017-07-31 10:13:00+03	103000.00
CB2EE8	2017-07-16 00:05:00+03	68400.00
CB2EED	2017-07-11 21:44:00+03	11000.00
CB2F1A	2017-07-15 21:40:00+03	187800.00
CB2FA2	2017-07-29 12:13:00+03	81600.00
CB2FC3	2017-07-31 03:15:00+03	25000.00
CB2FFD	2017-08-09 21:26:00+03	43800.00
CB300A	2017-07-18 06:29:00+03	118000.00
CB3017	2017-07-30 05:17:00+03	60700.00
CB304D	2017-07-30 21:13:00+03	68800.00
CB309C	2017-07-13 19:32:00+03	109600.00
CB310B	2017-08-05 11:41:00+03	28800.00
CB31CD	2017-07-27 08:59:00+03	28800.00
CB31F4	2017-07-29 13:31:00+03	44000.00
CB3230	2017-07-15 18:53:00+03	13300.00
CB32D5	2017-08-03 08:06:00+03	14000.00
CB32EB	2017-07-05 07:49:00+03	135200.00
CB3308	2017-07-11 04:54:00+03	51600.00
CB330C	2017-08-02 18:27:00+03	70700.00
CB3351	2017-08-12 10:28:00+03	36200.00
CB335A	2017-08-08 08:55:00+03	23600.00
CB33CF	2017-07-03 18:54:00+03	240600.00
CB33D4	2017-07-18 17:53:00+03	80400.00
CB3457	2017-07-24 18:25:00+03	67700.00
CB355A	2017-07-05 10:15:00+03	112600.00
CB3588	2017-07-10 19:19:00+03	84300.00
CB35CA	2017-07-08 05:00:00+03	60800.00
CB35DA	2017-08-07 11:48:00+03	22200.00
CB3606	2017-07-04 19:47:00+03	166000.00
CB3624	2017-07-06 05:42:00+03	54400.00
CB3644	2017-07-30 19:27:00+03	103200.00
CB3659	2017-07-22 17:20:00+03	125000.00
CB365C	2017-07-13 16:07:00+03	31000.00
CB3718	2017-07-25 17:05:00+03	25600.00
CB3730	2017-08-09 13:10:00+03	59300.00
CB3743	2017-07-13 22:50:00+03	88500.00
CB3764	2017-07-17 00:13:00+03	86600.00
CB37A7	2017-07-28 07:02:00+03	36900.00
CB37F2	2017-07-17 04:52:00+03	134000.00
CB3805	2017-08-14 23:11:00+03	93100.00
CB3845	2017-07-02 07:57:00+03	76900.00
CB3871	2017-07-08 15:32:00+03	38400.00
CB3880	2017-07-22 14:41:00+03	16800.00
CB38E6	2017-07-27 07:43:00+03	31900.00
CB393B	2017-07-09 14:31:00+03	16400.00
CB39E9	2017-07-29 20:12:00+03	21000.00
CB39F6	2017-07-20 12:07:00+03	100600.00
CB3A3D	2017-07-05 08:13:00+03	44000.00
CB3A84	2017-07-07 22:55:00+03	52000.00
CB3A9A	2017-08-03 09:25:00+03	63200.00
CB3AC8	2017-07-16 02:54:00+03	54500.00
CB3AE9	2017-07-16 19:21:00+03	155600.00
CB3AED	2017-07-17 10:40:00+03	131600.00
CB3AFD	2017-08-11 12:43:00+03	68500.00
CB3B0E	2017-07-14 05:13:00+03	67200.00
CB3B4F	2017-07-31 15:38:00+03	23600.00
CB3B8B	2017-07-01 07:13:00+03	64400.00
CB3BA0	2017-07-27 05:23:00+03	24400.00
CB3BA8	2017-08-14 17:50:00+03	16400.00
CB3C86	2017-08-12 08:12:00+03	136500.00
CB3D83	2017-07-14 08:51:00+03	26000.00
CB3D90	2017-07-10 03:17:00+03	89700.00
CB3E7E	2017-08-02 21:37:00+03	351000.00
CB3F2A	2017-08-07 03:39:00+03	48800.00
CB3F78	2017-07-07 12:20:00+03	30900.00
CB3F7B	2017-08-01 09:53:00+03	192900.00
CB3F9C	2017-07-12 01:09:00+03	193600.00
CB3FB6	2017-08-12 05:43:00+03	94900.00
CB3FC4	2017-08-03 21:40:00+03	137000.00
CB3FD2	2017-07-06 08:04:00+03	7400.00
CB3FE2	2017-07-13 11:18:00+03	100000.00
CB4018	2017-07-15 07:40:00+03	153200.00
CB402C	2017-08-15 08:13:00+03	266200.00
CB4054	2017-07-26 05:33:00+03	32800.00
CB4062	2017-08-13 11:31:00+03	21200.00
CB4082	2017-07-01 06:03:00+03	54500.00
CB40CD	2017-07-22 03:08:00+03	12000.00
CB40EF	2017-07-09 21:10:00+03	29800.00
CB416B	2017-07-10 12:17:00+03	6800.00
CB41AF	2017-07-25 17:59:00+03	165500.00
CB41F3	2017-07-31 11:12:00+03	134000.00
CB421E	2017-08-05 06:48:00+03	59800.00
CB4288	2017-07-06 09:28:00+03	8000.00
CB4293	2017-08-01 23:24:00+03	28000.00
CB42FE	2017-08-15 16:03:00+03	35300.00
CB436D	2017-07-25 10:15:00+03	33400.00
CB43CE	2017-07-22 13:27:00+03	51600.00
CB43D2	2017-08-01 00:57:00+03	38800.00
CB444F	2017-07-20 18:49:00+03	167400.00
CB4477	2017-08-02 11:25:00+03	46800.00
CB44E4	2017-07-04 15:04:00+03	43500.00
CB45D8	2017-07-06 03:16:00+03	65900.00
CB4601	2017-07-12 07:57:00+03	20200.00
CB4649	2017-07-28 08:21:00+03	132800.00
CB465F	2017-07-24 06:45:00+03	52000.00
CB468A	2017-07-07 08:06:00+03	34000.00
CB46FE	2017-08-11 08:22:00+03	146700.00
CB4743	2017-07-15 15:50:00+03	23100.00
CB4759	2017-07-13 20:09:00+03	202700.00
CB478B	2017-07-28 13:34:00+03	44600.00
CB4797	2017-07-25 14:17:00+03	23600.00
CB47A3	2017-07-14 01:08:00+03	72200.00
CB47AE	2017-07-22 02:32:00+03	117000.00
CB47DB	2017-07-13 09:00:00+03	201200.00
CB47E2	2017-07-07 00:01:00+03	56000.00
CB4823	2017-07-07 17:08:00+03	86400.00
CB4865	2017-08-10 06:21:00+03	31000.00
CB4893	2017-07-07 14:56:00+03	133200.00
CB48CA	2017-07-24 19:13:00+03	51900.00
CB48F1	2017-07-08 07:57:00+03	113300.00
CB4915	2017-07-27 19:36:00+03	33500.00
CB491B	2017-07-24 23:14:00+03	56000.00
CB49CD	2017-08-02 10:06:00+03	47000.00
CB4A71	2017-08-01 13:15:00+03	25800.00
CB4A77	2017-08-15 01:16:00+03	56600.00
CB4AB4	2017-08-03 02:21:00+03	36200.00
CB4B52	2017-07-20 22:48:00+03	168000.00
CB4B82	2017-08-07 08:10:00+03	42700.00
CB4BEE	2017-07-17 10:53:00+03	43600.00
CB4C58	2017-08-10 06:23:00+03	43000.00
CB4C5B	2017-08-04 13:35:00+03	44800.00
CB4CC2	2017-08-09 11:12:00+03	40800.00
CB4D66	2017-07-28 12:40:00+03	397300.00
CB4DBE	2017-07-30 03:22:00+03	398500.00
CB4DD5	2017-08-12 21:23:00+03	428100.00
CB4DE5	2017-07-06 18:18:00+03	92900.00
CB4E1A	2017-07-10 17:41:00+03	120700.00
CB4E66	2017-08-13 12:08:00+03	23600.00
CB4EB1	2017-07-23 14:41:00+03	57600.00
CB4FE1	2017-07-21 20:13:00+03	408500.00
CB503C	2017-08-15 16:21:00+03	49100.00
CB507E	2017-07-25 04:35:00+03	135100.00
CB50CC	2017-07-28 04:40:00+03	77600.00
CB5105	2017-08-05 03:05:00+03	61800.00
CB5122	2017-07-13 02:02:00+03	85000.00
CB512D	2017-07-03 05:02:00+03	21400.00
CB5154	2017-08-11 14:46:00+03	57600.00
CB51A9	2017-07-15 05:45:00+03	43100.00
CB5224	2017-07-10 02:01:00+03	23200.00
CB525A	2017-07-06 03:01:00+03	167400.00
CB52A0	2017-08-06 11:01:00+03	100600.00
CB5303	2017-08-02 23:17:00+03	46400.00
CB530B	2017-07-10 02:24:00+03	6200.00
CB531A	2017-08-04 18:37:00+03	317200.00
CB5346	2017-07-27 12:52:00+03	424700.00
CB534E	2017-07-06 00:29:00+03	113200.00
CB5366	2017-08-14 08:15:00+03	26000.00
CB5448	2017-07-17 04:16:00+03	21400.00
CB544C	2017-07-29 07:03:00+03	30200.00
CB5506	2017-07-05 18:40:00+03	115100.00
CB5532	2017-08-13 18:49:00+03	132800.00
CB5550	2017-06-30 16:18:00+03	48800.00
CB5582	2017-07-05 09:50:00+03	249200.00
CB55DB	2017-07-14 13:16:00+03	12600.00
CB55ED	2017-07-14 00:53:00+03	173600.00
CB563E	2017-08-10 01:11:00+03	123600.00
CB568A	2017-07-16 19:13:00+03	135200.00
CB56AA	2017-08-11 06:30:00+03	115900.00
CB56C6	2017-07-07 00:33:00+03	68900.00
CB5719	2017-07-19 01:01:00+03	58600.00
CB571A	2017-07-19 08:03:00+03	38200.00
CB572C	2017-07-12 15:26:00+03	35200.00
CB574B	2017-08-09 13:08:00+03	12400.00
CB57C6	2017-08-12 10:55:00+03	26000.00
CB57D9	2017-07-10 08:39:00+03	58000.00
CB57DA	2017-07-01 14:03:00+03	12600.00
CB5812	2017-08-11 14:44:00+03	99700.00
CB584F	2017-08-11 09:46:00+03	112600.00
CB5857	2017-08-11 04:58:00+03	25100.00
CB5876	2017-08-11 07:03:00+03	81300.00
CB587A	2017-07-23 18:44:00+03	167400.00
CB5899	2017-07-12 17:19:00+03	23200.00
CB58E0	2017-07-29 12:44:00+03	89700.00
CB58F9	2017-08-05 12:49:00+03	13400.00
CB5907	2017-07-19 10:47:00+03	75200.00
CB59AE	2017-08-12 22:47:00+03	13400.00
CB59DD	2017-07-23 07:13:00+03	134400.00
CB5A1F	2017-07-23 13:53:00+03	37400.00
CB5A2E	2017-08-01 02:44:00+03	23400.00
CB5A46	2017-07-04 03:06:00+03	15700.00
CB5AEF	2017-07-11 10:16:00+03	41600.00
CB5B2E	2017-07-03 17:39:00+03	198600.00
CB5B42	2017-07-13 11:36:00+03	145300.00
CB5B89	2017-07-23 03:46:00+03	28000.00
CB5BA1	2017-07-14 12:16:00+03	35800.00
CB5C08	2017-08-12 08:09:00+03	26700.00
CB5C38	2017-07-07 07:53:00+03	29800.00
CB5C57	2017-08-11 10:00:00+03	79800.00
CB5CB3	2017-07-17 07:07:00+03	89600.00
CB5CD7	2017-07-08 11:32:00+03	174900.00
CB5D97	2017-07-15 17:58:00+03	26800.00
CB5DC9	2017-08-08 16:05:00+03	131800.00
CB5DDB	2017-08-03 17:45:00+03	123000.00
CB5DDD	2017-08-04 16:00:00+03	70600.00
CB5EC9	2017-07-16 18:19:00+03	55800.00
CB5F01	2017-07-01 12:37:00+03	54600.00
CB6041	2017-07-28 21:14:00+03	55600.00
CB609D	2017-08-08 23:32:00+03	113300.00
CB6200	2017-07-03 22:00:00+03	58000.00
CB622A	2017-08-04 18:10:00+03	69000.00
CB629A	2017-08-01 05:58:00+03	26800.00
CB62A7	2017-07-03 14:30:00+03	56000.00
CB6327	2017-07-12 09:14:00+03	24400.00
CB6386	2017-07-13 09:10:00+03	75800.00
CB6395	2017-07-14 20:35:00+03	292900.00
CB63D5	2017-07-16 09:51:00+03	73600.00
CB6429	2017-07-21 06:17:00+03	13000.00
CB6430	2017-07-15 01:22:00+03	160200.00
CB648C	2017-08-07 11:16:00+03	74900.00
CB64A8	2017-07-13 04:18:00+03	157900.00
CB64CE	2017-07-27 10:38:00+03	81300.00
CB64DB	2017-07-18 10:13:00+03	140900.00
CB64E4	2017-08-15 11:25:00+03	26000.00
CB6509	2017-07-09 04:32:00+03	208100.00
CB6552	2017-08-08 07:45:00+03	57400.00
CB656B	2017-07-19 02:19:00+03	46000.00
CB65A9	2017-08-14 19:12:00+03	111600.00
CB65B5	2017-08-01 20:00:00+03	206100.00
CB65B7	2017-08-11 09:49:00+03	7400.00
CB65C0	2017-08-03 08:00:00+03	93900.00
CB65E8	2017-07-15 02:14:00+03	56200.00
CB6653	2017-07-26 22:21:00+03	30800.00
CB6662	2017-08-08 20:19:00+03	110500.00
CB66C9	2017-07-12 17:20:00+03	24700.00
CB66DA	2017-07-21 13:39:00+03	14000.00
CB6751	2017-07-03 23:17:00+03	43100.00
CB6766	2017-07-27 06:23:00+03	85000.00
CB67AA	2017-08-11 20:41:00+03	193600.00
CB67C6	2017-07-08 20:56:00+03	211100.00
CB67E7	2017-07-12 22:19:00+03	75300.00
CB6840	2017-08-13 03:38:00+03	46300.00
CB6882	2017-07-31 09:10:00+03	107700.00
CB68BA	2017-08-11 04:21:00+03	70700.00
CB6915	2017-08-15 02:54:00+03	49100.00
CB69D2	2017-07-17 01:49:00+03	22000.00
CB6A4F	2017-07-09 09:00:00+03	122000.00
CB6AAD	2017-06-29 11:38:00+03	13600.00
CB6ADD	2017-07-08 06:31:00+03	23600.00
CB6B06	2017-07-30 08:06:00+03	44000.00
CB6B87	2017-07-31 15:57:00+03	28800.00
CB6BFF	2017-07-24 01:52:00+03	53500.00
CB6C92	2017-07-16 09:04:00+03	86600.00
CB6CF5	2017-07-21 21:33:00+03	95600.00
CB6CFB	2017-07-02 15:46:00+03	140900.00
CB6D06	2017-07-18 20:01:00+03	35500.00
CB6D1C	2017-07-29 06:23:00+03	12600.00
CB6D5A	2017-08-01 22:48:00+03	45200.00
CB6D71	2017-07-18 00:51:00+03	85300.00
CB6D9C	2017-07-14 19:14:00+03	29600.00
CB6DA5	2017-08-07 20:13:00+03	378400.00
CB6DB4	2017-07-26 11:32:00+03	357000.00
CB6DCF	2017-07-07 22:43:00+03	246000.00
CB6DEF	2017-07-09 14:30:00+03	56000.00
CB6E0C	2017-07-26 11:30:00+03	226200.00
CB6E2F	2017-07-28 12:18:00+03	18600.00
CB6E45	2017-07-19 08:23:00+03	32800.00
CB6E6D	2017-08-10 09:53:00+03	47200.00
CB6EA9	2017-07-27 02:30:00+03	79600.00
CB6EB6	2017-08-04 19:23:00+03	147100.00
CB6EDD	2017-07-11 21:52:00+03	37900.00
CB6EE6	2017-08-02 10:27:00+03	48800.00
CB6F2D	2017-07-19 22:36:00+03	37400.00
CB701D	2017-08-03 00:36:00+03	89700.00
CB705C	2017-08-08 07:02:00+03	27200.00
CB705D	2017-08-15 11:20:00+03	92100.00
CB70B7	2017-07-14 16:54:00+03	50000.00
CB70BA	2017-07-03 09:46:00+03	164400.00
CB70D4	2017-07-31 23:29:00+03	38400.00
CB711A	2017-08-13 13:43:00+03	23400.00
CB7160	2017-08-10 10:38:00+03	36200.00
CB7183	2017-07-08 17:22:00+03	92400.00
CB7195	2017-07-25 04:11:00+03	189800.00
CB7196	2017-07-07 20:57:00+03	56000.00
CB71B6	2017-07-25 02:01:00+03	73500.00
CB7220	2017-08-04 08:34:00+03	31400.00
CB7239	2017-07-22 14:28:00+03	23900.00
CB72F2	2017-08-07 20:48:00+03	23400.00
CB739F	2017-07-02 00:49:00+03	122600.00
CB73C1	2017-07-22 16:41:00+03	58600.00
CB741C	2017-08-01 14:52:00+03	142000.00
CB744D	2017-08-08 16:00:00+03	147700.00
CB7498	2017-08-13 23:05:00+03	26800.00
CB74ED	2017-08-11 05:29:00+03	66600.00
CB7550	2017-07-08 11:56:00+03	152400.00
CB755E	2017-07-11 08:23:00+03	386200.00
CB75D3	2017-07-23 09:01:00+03	64100.00
CB7615	2017-07-30 15:16:00+03	73600.00
CB761C	2017-07-09 08:24:00+03	44800.00
CB766C	2017-07-07 21:14:00+03	105200.00
CB76E2	2017-07-20 16:23:00+03	24400.00
CB7740	2017-08-09 03:34:00+03	32700.00
CB7772	2017-07-13 10:27:00+03	14000.00
CB7781	2017-07-07 08:03:00+03	116400.00
CB7792	2017-07-22 02:18:00+03	66600.00
CB77BE	2017-07-20 23:45:00+03	92600.00
CB781F	2017-08-01 17:21:00+03	69500.00
CB785E	2017-07-07 21:17:00+03	170000.00
CB78D1	2017-07-21 08:51:00+03	46500.00
CB794F	2017-07-04 03:34:00+03	13000.00
CB7981	2017-06-30 14:19:00+03	14000.00
CB7995	2017-08-14 14:46:00+03	94200.00
CB7A3F	2017-07-22 21:20:00+03	16400.00
CB7A89	2017-07-20 12:58:00+03	61800.00
CB7ABB	2017-07-17 20:45:00+03	7400.00
CB7B62	2017-07-30 10:56:00+03	99200.00
CB7BE5	2017-08-10 08:27:00+03	39300.00
CB7C12	2017-08-09 17:31:00+03	46400.00
CB7C3B	2017-07-22 21:21:00+03	77400.00
CB7C68	2017-08-05 23:27:00+03	54800.00
CB7C7D	2017-07-31 07:35:00+03	67900.00
CB7C91	2017-07-29 14:13:00+03	13000.00
CB7CBE	2017-08-14 23:50:00+03	24000.00
CB7CDC	2017-07-29 02:42:00+03	19600.00
CB7CDE	2017-08-06 22:00:00+03	44600.00
CB7CFF	2017-08-01 23:47:00+03	73300.00
CB7DBF	2017-07-16 21:53:00+03	71500.00
CB7DE0	2017-08-10 11:33:00+03	8000.00
CB7E3A	2017-07-05 07:39:00+03	8200.00
CB7E69	2017-07-23 10:02:00+03	30200.00
CB7EB0	2017-08-11 21:46:00+03	28000.00
CB7F85	2017-08-01 17:20:00+03	28800.00
CB7F8D	2017-07-28 06:15:00+03	58600.00
CB7FB2	2017-07-29 21:41:00+03	47600.00
CB7FFD	2017-07-21 16:17:00+03	25400.00
CB8057	2017-07-20 03:46:00+03	72300.00
CB805C	2017-08-01 01:00:00+03	27300.00
CB80FF	2017-07-07 05:49:00+03	36200.00
CB8108	2017-07-24 06:54:00+03	86500.00
CB811D	2017-08-07 10:18:00+03	92100.00
CB8122	2017-07-25 17:11:00+03	282000.00
CB8150	2017-07-15 01:10:00+03	183200.00
CB81A3	2017-07-14 00:07:00+03	78500.00
CB81FA	2017-07-04 14:04:00+03	86800.00
CB820F	2017-08-05 11:44:00+03	28800.00
CB8217	2017-08-01 04:39:00+03	23200.00
CB82A8	2017-07-19 11:17:00+03	31300.00
CB82AA	2017-08-13 00:42:00+03	28800.00
CB82BA	2017-08-08 21:56:00+03	23400.00
CB8324	2017-07-17 18:09:00+03	48900.00
CB843C	2017-07-18 15:08:00+03	34000.00
CB8455	2017-07-20 12:26:00+03	120000.00
CB84A3	2017-07-17 05:08:00+03	100600.00
CB84BA	2017-07-05 04:11:00+03	36200.00
CB84C7	2017-07-23 11:47:00+03	46000.00
CB84CF	2017-08-03 21:07:00+03	147000.00
CB84DE	2017-07-23 10:35:00+03	118700.00
CB850D	2017-07-16 07:59:00+03	189100.00
CB851F	2017-07-24 16:45:00+03	58000.00
CB8590	2017-07-28 17:05:00+03	31600.00
CB859F	2017-08-15 14:22:00+03	24300.00
CB866E	2017-07-13 05:37:00+03	28800.00
CB867C	2017-08-06 01:56:00+03	52400.00
CB8704	2017-08-11 06:05:00+03	142400.00
CB8711	2017-08-05 06:23:00+03	6800.00
CB8791	2017-07-29 18:08:00+03	8000.00
CB8836	2017-07-14 12:13:00+03	46200.00
CB8871	2017-08-12 09:26:00+03	23400.00
CB898D	2017-08-11 00:00:00+03	18000.00
CB89EA	2017-07-14 17:52:00+03	30200.00
CB8A16	2017-07-31 13:48:00+03	375200.00
CB8A5A	2017-07-05 01:39:00+03	133200.00
CB8AAA	2017-08-12 08:27:00+03	46400.00
CB8AF6	2017-08-14 13:57:00+03	26700.00
CB8B22	2017-07-31 17:05:00+03	50600.00
CB8B9C	2017-07-05 03:19:00+03	38400.00
CB8BA6	2017-08-15 01:09:00+03	23600.00
CB8BF9	2017-07-24 00:40:00+03	28000.00
CB8C05	2017-07-10 09:32:00+03	94000.00
CB8C72	2017-07-26 08:11:00+03	35600.00
CB8C94	2017-07-09 03:07:00+03	46200.00
CB8C9B	2017-08-03 20:52:00+03	74000.00
CB8D1A	2017-07-10 11:42:00+03	68000.00
CB8D9D	2017-07-24 10:22:00+03	163500.00
CB8E08	2017-08-08 20:04:00+03	27800.00
CB8E67	2017-07-25 21:10:00+03	153200.00
CB8F35	2017-08-15 00:43:00+03	210000.00
CB8F51	2017-07-08 14:59:00+03	29600.00
CB8F6B	2017-08-12 22:21:00+03	77900.00
CB8F6E	2017-08-01 00:13:00+03	23600.00
CB8F87	2017-08-05 16:48:00+03	59400.00
CB8F88	2017-07-01 23:24:00+03	25600.00
CB8FEA	2017-07-04 08:41:00+03	288600.00
CB9091	2017-07-25 22:16:00+03	52600.00
CB9094	2017-08-01 09:52:00+03	66600.00
CB90A0	2017-08-01 15:00:00+03	61200.00
CB90C5	2017-08-14 09:51:00+03	19800.00
CB917A	2017-08-08 09:12:00+03	56900.00
CB9182	2017-07-11 02:47:00+03	33200.00
CB9191	2017-07-26 01:19:00+03	409100.00
CB9237	2017-07-18 09:23:00+03	28800.00
CB9297	2017-08-05 13:09:00+03	406700.00
CB9358	2017-08-06 23:52:00+03	48800.00
CB937E	2017-07-15 06:51:00+03	96200.00
CB93B7	2017-08-12 22:12:00+03	14000.00
CB9457	2017-07-23 07:13:00+03	51900.00
CB946E	2017-08-14 13:08:00+03	46900.00
CB9518	2017-07-02 12:26:00+03	12600.00
CB95D6	2017-07-16 02:09:00+03	46400.00
CB9613	2017-08-12 02:48:00+03	28800.00
CB966C	2017-07-27 14:32:00+03	111600.00
CB9696	2017-07-16 09:19:00+03	87400.00
CB96D2	2017-07-03 18:31:00+03	62100.00
CB9774	2017-08-09 05:41:00+03	26200.00
CB97B0	2017-07-18 23:04:00+03	43600.00
CB97DC	2017-06-29 15:58:00+03	47200.00
CB9844	2017-07-12 00:45:00+03	16000.00
CB98C7	2017-07-12 01:12:00+03	83300.00
CB9914	2017-07-01 17:22:00+03	89200.00
CB9919	2017-07-02 01:58:00+03	47500.00
CB9931	2017-07-07 06:07:00+03	13400.00
CB995A	2017-08-14 05:48:00+03	27300.00
CB995D	2017-08-10 07:16:00+03	24700.00
CB99A1	2017-07-20 15:16:00+03	31100.00
CB99DE	2017-07-14 00:24:00+03	56000.00
CB99FC	2017-08-01 01:09:00+03	46300.00
CB9A0F	2017-07-05 18:38:00+03	90400.00
CB9A2D	2017-07-14 19:49:00+03	93900.00
CB9A4D	2017-08-06 06:47:00+03	41400.00
CB9A50	2017-07-30 20:02:00+03	80000.00
CB9A76	2017-06-30 10:19:00+03	109600.00
CB9B3E	2017-07-06 06:20:00+03	36400.00
CB9B54	2017-06-28 11:19:00+03	90000.00
CB9B75	2017-07-11 01:27:00+03	27800.00
CB9BA5	2017-08-13 12:51:00+03	117200.00
CB9C86	2017-08-05 15:43:00+03	92800.00
CB9C8D	2017-08-06 16:59:00+03	44000.00
CB9CB8	2017-08-08 00:14:00+03	48700.00
CB9CBB	2017-07-18 21:45:00+03	13400.00
CB9CEA	2017-08-08 00:49:00+03	40400.00
CB9CF4	2017-07-12 08:39:00+03	12600.00
CB9D0C	2017-07-19 14:29:00+03	53300.00
CB9D64	2017-07-16 19:28:00+03	92600.00
CB9D70	2017-07-07 09:17:00+03	28300.00
CB9DC3	2017-07-15 12:59:00+03	56000.00
CB9DF7	2017-07-21 16:23:00+03	58600.00
CB9EB4	2017-07-12 18:23:00+03	21400.00
CB9EC0	2017-07-07 06:54:00+03	41200.00
CB9EF9	2017-07-15 21:48:00+03	38200.00
CB9F25	2017-07-26 08:21:00+03	77200.00
CB9FB3	2017-07-12 22:41:00+03	23900.00
CB9FDC	2017-07-07 21:04:00+03	147000.00
CBA017	2017-08-06 00:56:00+03	68100.00
CBA028	2017-07-26 19:55:00+03	75300.00
CBA031	2017-07-09 15:20:00+03	13400.00
CBA044	2017-07-05 15:02:00+03	16400.00
CBA04A	2017-07-19 00:29:00+03	55800.00
CBA123	2017-07-23 07:23:00+03	21400.00
CBA1A1	2017-08-08 14:11:00+03	66600.00
CBA226	2017-07-08 18:27:00+03	99600.00
CBA268	2017-07-31 14:45:00+03	48800.00
CBA2D2	2017-08-09 23:11:00+03	13400.00
CBA2DD	2017-07-20 18:28:00+03	45200.00
CBA310	2017-07-23 02:58:00+03	53600.00
CBA31C	2017-08-03 06:07:00+03	43600.00
CBA3A8	2017-07-02 08:29:00+03	67600.00
CBA3BE	2017-08-10 05:46:00+03	75200.00
CBA3EE	2017-08-13 13:25:00+03	67200.00
CBA40A	2017-07-25 06:57:00+03	23600.00
CBA42E	2017-07-26 14:20:00+03	62600.00
CBA4C7	2017-07-25 15:52:00+03	318200.00
CBA4D1	2017-07-29 19:17:00+03	64700.00
CBA521	2017-07-21 09:15:00+03	106100.00
CBA524	2017-07-13 17:28:00+03	52400.00
CBA544	2017-08-14 20:49:00+03	65600.00
CBA57C	2017-08-03 11:24:00+03	174400.00
CBA600	2017-07-07 22:56:00+03	135400.00
CBA67F	2017-08-12 04:22:00+03	65200.00
CBA70C	2017-07-17 22:04:00+03	47200.00
CBA716	2017-07-17 19:32:00+03	26800.00
CBA770	2017-07-14 20:07:00+03	26000.00
CBA7BA	2017-07-08 00:24:00+03	26000.00
CBA7CB	2017-07-11 12:47:00+03	35700.00
CBA808	2017-08-12 06:06:00+03	31200.00
CBA840	2017-07-08 04:50:00+03	33100.00
CBA879	2017-08-09 03:55:00+03	62100.00
CBA897	2017-07-17 18:33:00+03	77000.00
CBA917	2017-07-29 15:29:00+03	24700.00
CBA973	2017-07-04 15:39:00+03	38800.00
CBAAAD	2017-08-03 00:16:00+03	23200.00
CBAAD2	2017-08-01 13:56:00+03	312900.00
CBAB23	2017-07-05 21:28:00+03	291900.00
CBAB39	2017-07-22 04:31:00+03	27700.00
CBAB51	2017-07-29 16:43:00+03	6600.00
CBAB95	2017-06-28 08:28:00+03	82000.00
CBABD8	2017-08-11 08:08:00+03	29400.00
CBABDC	2017-07-26 13:15:00+03	86400.00
CBAC77	2017-07-07 21:48:00+03	82100.00
CBAD0C	2017-07-03 01:39:00+03	83000.00
CBAD43	2017-07-21 22:54:00+03	23400.00
CBAD46	2017-07-05 13:21:00+03	36700.00
CBAD4C	2017-07-08 15:44:00+03	246000.00
CBAD89	2017-07-11 06:55:00+03	18000.00
CBADA2	2017-07-03 22:18:00+03	104000.00
CBADA8	2017-07-26 07:32:00+03	22000.00
CBADCC	2017-07-30 18:12:00+03	211000.00
CBAE1C	2017-07-08 05:52:00+03	29600.00
CBAE40	2017-07-11 14:02:00+03	89700.00
CBAE5B	2017-07-17 23:49:00+03	13200.00
CBAE72	2017-07-12 01:09:00+03	130300.00
CBAE88	2017-08-07 01:31:00+03	59800.00
CBAF67	2017-07-11 03:10:00+03	44400.00
CBAF9C	2017-07-05 08:32:00+03	270800.00
CBAFA9	2017-08-12 08:01:00+03	40000.00
CBAFCD	2017-08-14 01:39:00+03	187600.00
CBB051	2017-08-02 17:49:00+03	88300.00
CBB081	2017-08-06 01:07:00+03	94800.00
CBB11E	2017-07-21 21:44:00+03	12600.00
CBB187	2017-07-25 23:49:00+03	117200.00
CBB215	2017-07-08 22:12:00+03	8200.00
CBB265	2017-08-10 01:12:00+03	28000.00
CBB26C	2017-07-13 02:13:00+03	12400.00
CBB2BF	2017-07-29 11:50:00+03	16400.00
CBB2DA	2017-06-28 10:38:00+03	107800.00
CBB357	2017-07-13 00:59:00+03	77000.00
CBB3A4	2017-08-03 18:32:00+03	28800.00
CBB3B4	2017-08-13 22:10:00+03	54000.00
CBB40E	2017-07-18 04:56:00+03	112000.00
CBB4D5	2017-08-13 11:05:00+03	105400.00
CBB4E9	2017-08-14 02:28:00+03	27400.00
CBB4F1	2017-07-19 12:03:00+03	25600.00
CBB4FC	2017-07-06 12:12:00+03	25900.00
CBB508	2017-07-30 06:24:00+03	65900.00
CBB58D	2017-08-15 17:14:00+03	111600.00
CBB5E7	2017-07-01 12:08:00+03	93700.00
CBB66B	2017-08-14 07:12:00+03	55400.00
CBB6BC	2017-07-20 20:57:00+03	67300.00
CBB6DC	2017-07-26 03:27:00+03	224800.00
CBB746	2017-07-26 06:57:00+03	99200.00
CBB772	2017-08-10 17:50:00+03	47500.00
CBB786	2017-07-09 11:39:00+03	38200.00
CBB794	2017-06-30 12:41:00+03	119800.00
CBB799	2017-07-18 15:11:00+03	35200.00
CBB7AC	2017-07-03 22:11:00+03	44700.00
CBB7DA	2017-08-13 03:43:00+03	116000.00
CBB821	2017-07-21 17:00:00+03	135000.00
CBB855	2017-07-24 15:03:00+03	125400.00
CBB88D	2017-08-07 02:38:00+03	112000.00
CBB8A0	2017-08-05 11:12:00+03	27200.00
CBB925	2017-08-02 19:39:00+03	140900.00
CBB9AD	2017-07-13 17:10:00+03	301800.00
CBB9B7	2017-08-11 20:19:00+03	38400.00
CBBA2B	2017-08-15 09:29:00+03	40800.00
CBBA5B	2017-07-13 10:55:00+03	84000.00
CBBAF7	2017-07-10 06:50:00+03	43600.00
CBBB02	2017-08-05 03:07:00+03	62400.00
CBBB57	2017-07-09 00:12:00+03	58800.00
CBBBAB	2017-07-15 03:35:00+03	40000.00
CBBC78	2017-08-05 20:35:00+03	56600.00
CBBCAF	2017-07-01 00:53:00+03	272300.00
CBBD5D	2017-08-02 13:50:00+03	29400.00
CBBDDA	2017-08-05 08:03:00+03	68400.00
CBBDE5	2017-08-11 08:02:00+03	18400.00
CBBEB9	2017-07-26 05:52:00+03	46500.00
CBBF0B	2017-08-03 20:15:00+03	67100.00
CBBF13	2017-07-31 09:27:00+03	6000.00
CBBF63	2017-07-23 12:50:00+03	46400.00
CBBFF7	2017-07-07 06:36:00+03	28600.00
CBC001	2017-08-10 22:28:00+03	42400.00
CBC04E	2017-08-05 23:48:00+03	77000.00
CBC092	2017-08-04 15:28:00+03	7400.00
CBC0AB	2017-08-11 20:35:00+03	174900.00
CBC0E4	2017-07-16 01:12:00+03	82900.00
CBC113	2017-07-31 04:41:00+03	25600.00
CBC178	2017-07-18 15:47:00+03	61500.00
CBC189	2017-07-10 02:20:00+03	123000.00
CBC1CE	2017-07-27 07:03:00+03	134400.00
CBC223	2017-08-14 21:01:00+03	55800.00
CBC24A	2017-07-11 11:02:00+03	207400.00
CBC25B	2017-08-14 08:55:00+03	111600.00
CBC269	2017-07-06 04:39:00+03	84000.00
CBC26A	2017-08-14 19:11:00+03	75700.00
CBC2A4	2017-07-18 13:25:00+03	10800.00
CBC343	2017-07-08 02:59:00+03	23400.00
CBC37B	2017-07-14 19:48:00+03	47500.00
CBC3AD	2017-07-30 20:08:00+03	6800.00
CBC3F4	2017-08-10 11:39:00+03	36200.00
CBC480	2017-07-29 07:40:00+03	23500.00
CBC4A2	2017-07-27 01:36:00+03	81700.00
CBC4A8	2017-08-02 04:12:00+03	53400.00
CBC530	2017-08-01 13:41:00+03	36800.00
CBC543	2017-08-14 04:00:00+03	24800.00
CBC557	2017-07-31 13:38:00+03	22000.00
CBC66D	2017-07-04 22:39:00+03	63800.00
CBC676	2017-08-04 17:13:00+03	8000.00
CBC6AE	2017-07-09 23:56:00+03	10600.00
CBC6B4	2017-07-26 15:16:00+03	23100.00
CBC6DF	2017-07-06 04:46:00+03	111600.00
CBC6EA	2017-08-03 03:08:00+03	36200.00
CBC6ED	2017-07-29 10:23:00+03	18800.00
CBC702	2017-07-19 03:53:00+03	111600.00
CBC70D	2017-08-03 02:28:00+03	36800.00
CBC75D	2017-07-30 00:46:00+03	29400.00
CBC776	2017-08-07 19:39:00+03	136600.00
CBC77E	2017-08-01 22:20:00+03	39400.00
CBC7AB	2017-07-29 06:28:00+03	515000.00
CBC818	2017-08-07 19:00:00+03	37900.00
CBC87B	2017-07-20 06:24:00+03	55800.00
CBC894	2017-07-11 18:18:00+03	133700.00
CBC8A0	2017-07-06 21:05:00+03	70800.00
CBC8F3	2017-07-13 02:40:00+03	66300.00
CBC8F7	2017-07-03 19:43:00+03	430800.00
CBC907	2017-08-12 22:17:00+03	112000.00
CBC976	2017-08-12 05:32:00+03	103500.00
CBC9AD	2017-07-06 14:12:00+03	41900.00
CBCA29	2017-07-14 21:34:00+03	50000.00
CBCA3F	2017-07-04 07:44:00+03	17600.00
CBCACA	2017-07-02 15:25:00+03	193700.00
CBCAF7	2017-07-25 13:26:00+03	49000.00
CBCB22	2017-07-17 23:27:00+03	53200.00
CBCB53	2017-08-07 22:11:00+03	62000.00
CBCBDD	2017-07-02 00:14:00+03	695600.00
CBCC64	2017-06-29 20:44:00+03	16400.00
CBCCA7	2017-07-19 06:29:00+03	48800.00
CBCCD0	2017-07-19 05:28:00+03	211400.00
CBCCE4	2017-07-11 03:44:00+03	85000.00
CBCD09	2017-07-22 12:31:00+03	100600.00
CBCD2B	2017-08-06 05:37:00+03	12100.00
CBCD49	2017-07-08 22:31:00+03	40800.00
CBCD58	2017-07-25 12:11:00+03	123000.00
CBCD64	2017-07-16 23:03:00+03	258400.00
CBCDB2	2017-08-10 03:30:00+03	84500.00
CBCDDD	2017-07-14 21:24:00+03	26000.00
CBCE58	2017-07-26 18:40:00+03	56000.00
CBCE64	2017-07-18 09:18:00+03	94200.00
CBCEEC	2017-07-12 21:01:00+03	26000.00
CBCEFF	2017-08-01 18:29:00+03	136000.00
CBCF4D	2017-07-22 17:01:00+03	103500.00
CBCF5E	2017-08-11 08:07:00+03	58200.00
CBCFF2	2017-08-15 12:07:00+03	24300.00
CBD038	2017-07-03 01:33:00+03	15100.00
CBD044	2017-07-04 22:13:00+03	229400.00
CBD0C8	2017-08-13 17:56:00+03	102000.00
CBD13B	2017-07-28 18:36:00+03	54000.00
CBD1A0	2017-08-15 05:32:00+03	131600.00
CBD1B9	2017-07-07 13:10:00+03	95600.00
CBD1CF	2017-07-14 02:27:00+03	23200.00
CBD203	2017-08-11 10:21:00+03	25100.00
CBD22D	2017-07-30 04:00:00+03	194400.00
CBD263	2017-07-20 22:00:00+03	32800.00
CBD2B3	2017-08-07 23:06:00+03	62800.00
CBD336	2017-08-04 17:51:00+03	101200.00
CBD35B	2017-08-06 21:23:00+03	40400.00
CBD3CE	2017-07-26 05:34:00+03	12400.00
CBD3E4	2017-07-17 08:45:00+03	63700.00
CBD470	2017-07-23 19:26:00+03	26800.00
CBD48F	2017-07-02 01:21:00+03	111600.00
CBD513	2017-08-04 16:40:00+03	55800.00
CBD51A	2017-07-27 23:54:00+03	27200.00
CBD54B	2017-08-11 03:41:00+03	40000.00
CBD554	2017-07-14 07:55:00+03	53500.00
CBD558	2017-07-04 02:45:00+03	179400.00
CBD605	2017-08-11 20:34:00+03	26000.00
CBD64E	2017-07-31 03:17:00+03	14900.00
CBD6A2	2017-07-21 23:20:00+03	7300.00
CBD6E3	2017-08-14 02:15:00+03	47200.00
CBD735	2017-07-25 07:53:00+03	83000.00
CBD761	2017-07-24 12:39:00+03	13700.00
CBD81E	2017-08-11 12:48:00+03	29300.00
CBD8DC	2017-06-29 08:53:00+03	14700.00
CBD904	2017-07-16 19:50:00+03	28800.00
CBD969	2017-07-19 12:19:00+03	8400.00
CBD992	2017-07-10 18:32:00+03	81800.00
CBD9B2	2017-07-22 08:59:00+03	12000.00
CBDA5C	2017-08-15 06:53:00+03	40400.00
CBDA92	2017-07-31 21:06:00+03	26600.00
CBDAC3	2017-07-14 06:56:00+03	67700.00
CBDAD4	2017-07-09 02:58:00+03	143300.00
CBDB51	2017-08-05 00:25:00+03	246200.00
CBDBEB	2017-07-07 07:20:00+03	19600.00
CBDC70	2017-08-05 13:51:00+03	412000.00
CBDCB8	2017-07-28 08:43:00+03	83700.00
CBDD08	2017-07-08 05:17:00+03	40400.00
CBDD78	2017-07-28 03:11:00+03	53600.00
CBDDCA	2017-07-11 19:58:00+03	28800.00
CBDE7B	2017-07-24 18:08:00+03	28000.00
CBDEF0	2017-08-15 01:10:00+03	27200.00
CBDEF3	2017-07-31 15:09:00+03	28000.00
CBDEFE	2017-07-17 15:29:00+03	90800.00
CBDFEF	2017-08-13 18:08:00+03	170200.00
CBE030	2017-08-14 23:21:00+03	37000.00
CBE068	2017-07-28 03:43:00+03	68000.00
CBE0A4	2017-08-14 10:30:00+03	112000.00
CBE0C2	2017-07-31 07:45:00+03	128800.00
CBE0C9	2017-08-12 14:03:00+03	80000.00
CBE133	2017-08-02 00:48:00+03	53400.00
CBE13A	2017-08-09 15:11:00+03	86400.00
CBE143	2017-07-02 06:13:00+03	174000.00
CBE23C	2017-08-13 19:50:00+03	47400.00
CBE27F	2017-07-07 13:46:00+03	246000.00
CBE2FB	2017-08-09 08:47:00+03	46800.00
CBE365	2017-07-23 12:34:00+03	28800.00
CBE3C8	2017-08-01 19:52:00+03	27500.00
CBE3CF	2017-08-15 09:17:00+03	29800.00
CBE426	2017-06-26 20:40:00+03	46300.00
CBE488	2017-07-06 05:09:00+03	38600.00
CBE489	2017-07-27 14:16:00+03	58900.00
CBE4CC	2017-07-15 20:33:00+03	21200.00
CBE4E8	2017-07-25 13:18:00+03	29500.00
CBE4E9	2017-07-09 05:51:00+03	51900.00
CBE514	2017-08-08 17:48:00+03	27200.00
CBE527	2017-08-03 17:00:00+03	40000.00
CBE54F	2017-06-27 05:07:00+03	22400.00
CBE558	2017-08-10 08:17:00+03	69600.00
CBE566	2017-07-03 00:01:00+03	66600.00
CBE5AB	2017-07-02 23:16:00+03	272400.00
CBE5FA	2017-07-29 09:45:00+03	46400.00
CBE5FE	2017-07-09 02:28:00+03	46400.00
CBE65E	2017-07-20 11:40:00+03	55800.00
CBE683	2017-07-13 23:00:00+03	75300.00
CBE6A7	2017-07-10 05:15:00+03	82700.00
CBE6D6	2017-07-25 14:58:00+03	78600.00
CBE7BB	2017-07-29 04:56:00+03	47400.00
CBE7D7	2017-08-13 15:51:00+03	62000.00
CBE801	2017-07-19 19:56:00+03	72200.00
CBE823	2017-07-17 08:38:00+03	64800.00
CBE830	2017-07-01 19:39:00+03	42800.00
CBE897	2017-08-01 20:13:00+03	109000.00
CBE8A6	2017-07-12 04:15:00+03	13800.00
CBE8DF	2017-08-15 05:18:00+03	28000.00
CBE991	2017-08-10 18:56:00+03	106900.00
CBE993	2017-07-22 14:51:00+03	23900.00
CBE9AF	2017-07-20 23:54:00+03	74300.00
CBE9CB	2017-08-14 21:59:00+03	174600.00
CBEA28	2017-07-06 08:16:00+03	37900.00
CBEA73	2017-07-28 07:36:00+03	40800.00
CBEA7D	2017-08-10 04:17:00+03	147700.00
CBEA82	2017-07-31 04:29:00+03	76800.00
CBEAC0	2017-07-14 20:30:00+03	24400.00
CBEB26	2017-07-31 08:52:00+03	67600.00
CBEB4E	2017-07-26 13:22:00+03	73500.00
CBEBBA	2017-07-18 16:59:00+03	18300.00
CBEBCB	2017-07-04 07:27:00+03	153300.00
CBEC4E	2017-07-29 14:09:00+03	28300.00
CBEC7A	2017-07-21 06:41:00+03	103500.00
CBED00	2017-08-02 17:01:00+03	66600.00
CBED2E	2017-07-21 08:41:00+03	216200.00
CBED55	2017-07-07 08:23:00+03	47000.00
CBED79	2017-07-13 01:41:00+03	55800.00
CBEE08	2017-07-06 10:17:00+03	64300.00
CBEEB0	2017-08-13 12:04:00+03	131100.00
CBEF6A	2017-07-22 21:53:00+03	14000.00
CBEFCF	2017-07-08 12:05:00+03	68000.00
CBEFE2	2017-08-09 20:35:00+03	11700.00
CBEFE8	2017-08-07 01:50:00+03	6700.00
CBF038	2017-07-18 01:02:00+03	133200.00
CBF081	2017-07-26 16:29:00+03	28000.00
CBF082	2017-08-08 05:44:00+03	56000.00
CBF0A1	2017-08-02 13:03:00+03	26800.00
CBF0CB	2017-07-03 19:43:00+03	92800.00
CBF104	2017-07-16 04:39:00+03	21800.00
CBF191	2017-08-02 03:55:00+03	189000.00
CBF196	2017-08-14 08:46:00+03	169600.00
CBF1BC	2017-08-05 13:21:00+03	62600.00
CBF1E4	2017-07-14 11:03:00+03	28800.00
CBF2B7	2017-07-16 00:24:00+03	13400.00
CBF2E8	2017-07-16 03:23:00+03	92800.00
CBF314	2017-07-10 13:18:00+03	66600.00
CBF337	2017-07-30 17:03:00+03	28000.00
CBF3B2	2017-07-03 05:26:00+03	157800.00
CBF3EF	2017-07-07 17:42:00+03	67200.00
CBF422	2017-07-01 00:51:00+03	68900.00
CBF42F	2017-08-04 09:32:00+03	7800.00
CBF43A	2017-07-15 05:31:00+03	128800.00
CBF4B6	2017-08-13 01:37:00+03	112000.00
CBF4F1	2017-07-19 00:10:00+03	26800.00
CBF521	2017-08-10 00:45:00+03	54800.00
CBF560	2017-07-03 13:47:00+03	7900.00
CBF5AC	2017-07-14 18:13:00+03	134400.00
CBF5B6	2017-07-17 09:56:00+03	202100.00
CBF5FC	2017-08-07 12:06:00+03	28000.00
CBF684	2017-07-15 03:39:00+03	13400.00
CBF69E	2017-07-08 20:52:00+03	53100.00
CBF6C5	2017-07-20 17:36:00+03	23200.00
CBF6F2	2017-07-15 21:07:00+03	262100.00
CBF6F4	2017-08-09 18:28:00+03	21400.00
CBF71B	2017-07-16 00:28:00+03	14800.00
CBF77E	2017-08-09 02:02:00+03	229100.00
CBF81E	2017-07-06 01:38:00+03	56400.00
CBF822	2017-07-28 01:31:00+03	66600.00
CBF869	2017-07-21 01:05:00+03	64700.00
CBF875	2017-07-02 18:15:00+03	33100.00
CBF89A	2017-08-02 14:51:00+03	46400.00
CBF8D8	2017-07-11 10:51:00+03	32800.00
CBF8DF	2017-07-04 05:50:00+03	67600.00
CBF96D	2017-07-01 02:39:00+03	75600.00
CBF9B5	2017-07-15 22:57:00+03	59200.00
CBF9F6	2017-07-16 16:54:00+03	56000.00
CBFA03	2017-07-24 14:14:00+03	75600.00
CBFA3C	2017-07-07 02:08:00+03	22400.00
CBFA64	2017-08-06 02:17:00+03	26700.00
CBFA70	2017-08-01 00:30:00+03	82900.00
CBFA9F	2017-07-25 13:42:00+03	230300.00
CBFACB	2017-07-22 03:06:00+03	102100.00
CBFB42	2017-07-08 23:31:00+03	56000.00
CBFB87	2017-07-25 23:52:00+03	47100.00
CBFBA7	2017-08-08 18:14:00+03	393800.00
CBFBD4	2017-07-10 12:54:00+03	43900.00
CBFC10	2017-08-05 02:51:00+03	68800.00
CBFC19	2017-07-16 05:43:00+03	25900.00
CBFD45	2017-07-24 03:35:00+03	31600.00
CBFD63	2017-07-12 23:43:00+03	91800.00
CBFD7C	2017-08-09 04:32:00+03	7400.00
CBFD86	2017-07-03 06:38:00+03	40100.00
CBFD97	2017-06-29 11:03:00+03	6300.00
CBFDA7	2017-07-06 19:49:00+03	46000.00
CBFE08	2017-07-22 05:25:00+03	119700.00
CBFE69	2017-07-17 02:52:00+03	146400.00
CBFE8A	2017-07-20 21:57:00+03	42100.00
CBFE9A	2017-07-17 15:05:00+03	35200.00
CBFEF2	2017-07-19 01:31:00+03	138000.00
CBFF70	2017-07-11 17:48:00+03	34800.00
CBFF93	2017-08-14 07:39:00+03	15400.00
CC0012	2017-07-05 23:45:00+03	38400.00
CC0052	2017-07-18 14:46:00+03	52400.00
CC0054	2017-07-03 13:18:00+03	42800.00
CC0056	2017-07-07 22:31:00+03	28000.00
CC006F	2017-07-10 07:23:00+03	151200.00
CC0097	2017-07-23 07:43:00+03	27800.00
CC00B4	2017-07-21 07:58:00+03	19600.00
CC00B5	2017-08-10 10:38:00+03	23200.00
CC017B	2017-07-23 16:32:00+03	23400.00
CC0194	2017-08-09 22:22:00+03	56000.00
CC01F3	2017-08-12 12:34:00+03	99300.00
CC0204	2017-07-02 22:07:00+03	6700.00
CC0221	2017-07-22 02:56:00+03	78800.00
CC0244	2017-07-25 13:46:00+03	172600.00
CC0287	2017-08-15 08:12:00+03	65800.00
CC030F	2017-08-10 07:45:00+03	21400.00
CC0334	2017-07-13 11:00:00+03	406600.00
CC03CF	2017-07-21 02:27:00+03	245400.00
CC0407	2017-08-07 12:10:00+03	12400.00
CC0466	2017-08-10 04:34:00+03	270800.00
CC0489	2017-07-15 23:57:00+03	28300.00
CC049A	2017-07-22 08:33:00+03	27300.00
CC04BA	2017-07-28 04:18:00+03	16400.00
CC04C6	2017-07-24 17:39:00+03	182300.00
CC04E9	2017-07-15 00:02:00+03	77900.00
CC0506	2017-07-26 22:58:00+03	135100.00
CC0570	2017-08-09 09:08:00+03	19600.00
CC05C5	2017-07-04 03:09:00+03	54800.00
CC05EE	2017-07-18 13:33:00+03	384800.00
CC05F0	2017-08-08 17:47:00+03	414400.00
CC0607	2017-07-25 13:34:00+03	62100.00
CC0629	2017-08-14 03:00:00+03	43200.00
CC062E	2017-07-31 23:03:00+03	95500.00
CC069E	2017-07-19 11:51:00+03	26000.00
CC06AA	2017-08-09 18:20:00+03	25600.00
CC06E3	2017-08-03 11:03:00+03	116400.00
CC06E4	2017-07-25 11:11:00+03	40800.00
CC0736	2017-08-11 07:00:00+03	25200.00
CC0757	2017-08-13 04:51:00+03	28000.00
CC0769	2017-08-05 14:04:00+03	132800.00
CC0776	2017-08-08 17:57:00+03	61800.00
CC0843	2017-07-07 08:25:00+03	9200.00
CC085B	2017-07-02 04:26:00+03	82900.00
CC08C7	2017-07-06 10:20:00+03	181600.00
CC08E0	2017-07-29 18:35:00+03	46000.00
CC08F7	2017-08-13 21:37:00+03	96600.00
CC094B	2017-07-06 22:08:00+03	125600.00
CC0973	2017-07-28 05:00:00+03	59800.00
CC09DF	2017-08-06 05:37:00+03	25200.00
CC09E6	2017-07-31 20:32:00+03	167500.00
CC0A24	2017-07-09 08:37:00+03	125200.00
CC0A34	2017-07-01 06:35:00+03	12600.00
CC0A75	2017-07-18 10:01:00+03	59100.00
CC0AF7	2017-08-10 14:36:00+03	117600.00
CC0AFE	2017-08-05 20:27:00+03	75300.00
CC0B04	2017-07-31 18:20:00+03	118100.00
CC0BF6	2017-08-07 05:58:00+03	16400.00
CC0C45	2017-08-07 06:57:00+03	42800.00
CC0CA9	2017-07-17 05:12:00+03	56600.00
CC0D46	2017-07-03 09:46:00+03	56600.00
CC0D6A	2017-07-20 19:52:00+03	52000.00
CC0D74	2017-07-31 11:51:00+03	123000.00
CC0DA0	2017-07-23 03:47:00+03	359600.00
CC0DBC	2017-08-15 10:54:00+03	396500.00
CC0E13	2017-07-17 10:24:00+03	53200.00
CC0E1A	2017-08-12 06:32:00+03	183600.00
CC0E30	2017-07-03 22:49:00+03	85000.00
CC0E37	2017-07-19 17:07:00+03	173400.00
CC0E57	2017-08-13 14:44:00+03	99300.00
CC0EDE	2017-07-09 09:38:00+03	44800.00
CC0EEB	2017-08-11 14:28:00+03	96800.00
CC0F7D	2017-07-22 13:28:00+03	85400.00
CC0F8A	2017-07-22 04:25:00+03	56000.00
CC0FDB	2017-07-12 04:40:00+03	136800.00
CC0FE4	2017-08-04 15:43:00+03	56000.00
CC109B	2017-08-13 01:05:00+03	294400.00
CC10ED	2017-07-17 23:36:00+03	37200.00
CC1107	2017-08-07 06:14:00+03	39200.00
CC1121	2017-08-13 16:55:00+03	98000.00
CC1133	2017-07-10 19:32:00+03	76300.00
CC1145	2017-07-13 10:30:00+03	19600.00
CC1157	2017-08-06 22:45:00+03	24400.00
CC115D	2017-08-02 10:01:00+03	133100.00
CC11C4	2017-08-04 04:57:00+03	133100.00
CC11D3	2017-07-17 17:53:00+03	147200.00
CC1229	2017-07-13 23:14:00+03	28800.00
CC122C	2017-08-05 17:09:00+03	112000.00
CC1251	2017-08-06 08:50:00+03	408500.00
CC12A6	2017-06-28 06:07:00+03	28800.00
CC12A8	2017-08-03 20:17:00+03	47100.00
CC12AA	2017-07-30 06:58:00+03	90000.00
CC12C5	2017-07-17 01:31:00+03	28800.00
CC1349	2017-07-25 03:23:00+03	46000.00
CC1364	2017-07-04 18:32:00+03	46200.00
CC138D	2017-07-14 17:03:00+03	57800.00
CC13E1	2017-08-04 12:11:00+03	46000.00
CC140D	2017-07-28 22:14:00+03	42800.00
CC1425	2017-07-06 17:51:00+03	21800.00
CC1445	2017-08-13 20:29:00+03	615000.00
CC147C	2017-07-13 21:32:00+03	10800.00
CC14D0	2017-08-05 15:34:00+03	401000.00
CC14EC	2017-08-03 15:37:00+03	68100.00
CC1536	2017-07-14 22:43:00+03	23100.00
CC1592	2017-08-02 23:42:00+03	66600.00
CC15F5	2017-08-08 10:28:00+03	40200.00
CC16C4	2017-07-23 06:15:00+03	174300.00
CC16D7	2017-08-04 16:21:00+03	48800.00
CC16D8	2017-07-14 09:39:00+03	45200.00
CC16F8	2017-08-04 03:39:00+03	89600.00
CC17ED	2017-07-26 15:32:00+03	22000.00
CC1841	2017-08-09 10:43:00+03	51800.00
CC1879	2017-07-06 22:35:00+03	199700.00
CC189B	2017-07-27 12:33:00+03	131900.00
CC18B8	2017-07-09 18:14:00+03	47100.00
CC18C3	2017-08-13 22:39:00+03	20200.00
CC18D2	2017-08-11 12:23:00+03	14000.00
CC18F1	2017-07-21 04:57:00+03	35400.00
CC192D	2017-07-28 20:18:00+03	189200.00
CC1946	2017-07-01 19:39:00+03	20400.00
CC1950	2017-08-01 17:29:00+03	21400.00
CC19A2	2017-06-30 21:03:00+03	46000.00
CC19A9	2017-07-12 17:45:00+03	54400.00
CC1A7C	2017-08-06 01:16:00+03	46200.00
CC1A80	2017-08-11 06:23:00+03	51900.00
CC1AAB	2017-07-14 09:47:00+03	246000.00
CC1AB8	2017-08-13 18:05:00+03	35600.00
CC1AC8	2017-08-10 22:54:00+03	10700.00
CC1B24	2017-06-30 15:49:00+03	62600.00
CC1BAF	2017-08-12 15:31:00+03	91200.00
CC1C8C	2017-07-05 15:09:00+03	160700.00
CC1CCD	2017-07-24 01:23:00+03	62700.00
CC1D1A	2017-07-05 02:31:00+03	75600.00
CC1D62	2017-07-26 06:52:00+03	166100.00
CC1DAF	2017-07-14 07:40:00+03	69500.00
CC1E3B	2017-08-12 23:06:00+03	97500.00
CC1E56	2017-08-12 13:16:00+03	30000.00
CC1E7C	2017-08-07 00:04:00+03	270800.00
CC1E92	2017-07-20 10:02:00+03	92400.00
CC1EB6	2017-07-04 16:57:00+03	86600.00
CC1F43	2017-07-09 09:21:00+03	150000.00
CC1FCA	2017-08-09 10:22:00+03	15900.00
CC1FEE	2017-08-09 08:14:00+03	64800.00
CC203F	2017-07-03 09:50:00+03	115900.00
CC2064	2017-07-04 23:31:00+03	62000.00
CC2077	2017-07-21 22:33:00+03	386300.00
CC2134	2017-07-21 10:13:00+03	61800.00
CC21DD	2017-08-09 15:15:00+03	67200.00
CC2220	2017-07-26 16:45:00+03	85700.00
CC2273	2017-07-05 17:46:00+03	47100.00
CC22A8	2017-08-08 06:32:00+03	99300.00
CC22D6	2017-08-07 01:52:00+03	137600.00
CC231B	2017-07-24 15:47:00+03	55800.00
CC2354	2017-07-19 06:16:00+03	34000.00
CC236B	2017-08-03 22:58:00+03	102000.00
CC23C8	2017-07-29 01:22:00+03	47500.00
CC24C9	2017-07-10 19:19:00+03	232100.00
CC2531	2017-07-17 08:46:00+03	23200.00
CC255E	2017-07-17 15:33:00+03	23400.00
CC25B8	2017-07-10 08:43:00+03	643800.00
CC25C9	2017-08-15 07:18:00+03	56000.00
CC25D9	2017-07-22 01:55:00+03	171900.00
CC2607	2017-07-19 15:14:00+03	6700.00
CC262D	2017-08-07 16:46:00+03	26000.00
CC2640	2017-07-03 21:54:00+03	58600.00
CC266C	2017-07-12 17:41:00+03	25800.00
CC2719	2017-07-02 00:53:00+03	230700.00
CC2745	2017-08-13 10:16:00+03	33600.00
CC27B2	2017-07-16 19:40:00+03	40100.00
CC27CC	2017-07-04 22:34:00+03	30200.00
CC27EC	2017-06-29 07:39:00+03	22000.00
CC2800	2017-07-26 06:53:00+03	230000.00
CC284E	2017-07-13 08:23:00+03	93000.00
CC28A7	2017-07-24 19:11:00+03	86600.00
CC28D1	2017-08-15 03:37:00+03	23600.00
CC28E2	2017-07-29 18:45:00+03	42700.00
CC28EC	2017-08-03 04:55:00+03	25100.00
CC2916	2017-08-03 11:59:00+03	239400.00
CC29B8	2017-07-24 21:20:00+03	123000.00
CC29BC	2017-08-05 07:26:00+03	13600.00
CC2A05	2017-07-28 13:46:00+03	32700.00
CC2AAC	2017-07-31 20:20:00+03	22000.00
CC2B15	2017-07-13 07:31:00+03	133100.00
CC2B8A	2017-08-04 13:48:00+03	93000.00
CC2BC6	2017-08-08 14:43:00+03	131100.00
CC2BCB	2017-07-22 12:08:00+03	118900.00
CC2C01	2017-07-03 20:28:00+03	21200.00
CC2CC1	2017-08-08 13:47:00+03	205600.00
CC2CEC	2017-07-25 08:53:00+03	20200.00
CC2D1B	2017-07-17 08:49:00+03	134700.00
CC2D67	2017-07-19 17:59:00+03	99700.00
CC2DC2	2017-07-10 13:30:00+03	72400.00
CC2DCD	2017-08-12 14:25:00+03	12300.00
CC2DF0	2017-08-13 11:44:00+03	71900.00
CC2DFF	2017-08-01 14:25:00+03	166900.00
CC2E96	2017-07-28 01:27:00+03	29200.00
CC2EFF	2017-08-01 18:31:00+03	30200.00
CC2F00	2017-06-30 07:42:00+03	24400.00
CC2F17	2017-07-17 13:28:00+03	81900.00
CC2FF2	2017-08-04 04:38:00+03	29600.00
CC30A3	2017-07-11 14:29:00+03	32800.00
CC3179	2017-07-14 04:31:00+03	67600.00
CC31AD	2017-06-29 13:05:00+03	31400.00
CC31D9	2017-07-03 06:32:00+03	28800.00
CC3217	2017-08-12 13:59:00+03	194200.00
CC3234	2017-07-06 08:47:00+03	56100.00
CC323E	2017-08-14 22:26:00+03	31400.00
CC32AA	2017-07-31 23:19:00+03	56600.00
CC331C	2017-08-13 10:32:00+03	190400.00
CC3381	2017-08-14 16:10:00+03	62600.00
CC33E6	2017-07-20 19:08:00+03	198600.00
CC3429	2017-07-09 12:44:00+03	46400.00
CC347D	2017-07-31 04:54:00+03	93900.00
CC34A5	2017-07-26 12:17:00+03	45100.00
CC351B	2017-08-12 21:30:00+03	25400.00
CC3636	2017-07-01 10:00:00+03	52800.00
CC3682	2017-07-18 14:48:00+03	57600.00
CC36BF	2017-07-14 05:09:00+03	6300.00
CC3754	2017-08-09 01:29:00+03	47100.00
CC376A	2017-07-13 08:41:00+03	19600.00
CC3792	2017-07-02 19:18:00+03	22000.00
CC37D3	2017-08-04 05:16:00+03	424800.00
CC37F9	2017-08-01 08:24:00+03	64600.00
CC38FC	2017-07-06 08:20:00+03	59800.00
CC3923	2017-07-21 23:49:00+03	177800.00
CC3943	2017-07-01 05:50:00+03	47000.00
CC3974	2017-07-30 10:35:00+03	111600.00
CC3A18	2017-07-31 08:39:00+03	94000.00
CC3A2B	2017-07-09 07:36:00+03	81300.00
CC3A36	2017-07-22 21:36:00+03	25800.00
CC3A83	2017-07-30 15:19:00+03	116800.00
CC3A97	2017-08-04 10:01:00+03	14400.00
CC3AA1	2017-08-15 12:23:00+03	33300.00
CC3B36	2017-08-05 10:25:00+03	45200.00
CC3B50	2017-07-10 18:05:00+03	43200.00
CC3BB4	2017-08-05 23:05:00+03	246000.00
CC3BC9	2017-07-03 20:51:00+03	41500.00
CC3BF4	2017-07-15 23:29:00+03	8000.00
CC3C2C	2017-08-02 01:11:00+03	74400.00
CC3CE3	2017-08-14 11:50:00+03	56600.00
CC3DCB	2017-07-17 09:20:00+03	76600.00
CC3E35	2017-07-08 23:57:00+03	51500.00
CC3E62	2017-07-16 23:25:00+03	12600.00
CC3E9E	2017-07-23 15:48:00+03	46000.00
CC3EC3	2017-07-19 20:29:00+03	22600.00
CC3ED0	2017-08-06 19:53:00+03	28000.00
CC3EDA	2017-07-13 13:41:00+03	8400.00
CC3F2C	2017-07-02 20:07:00+03	265700.00
CC3FC6	2017-07-31 09:17:00+03	114700.00
CC3FCB	2017-08-12 17:52:00+03	99200.00
CC3FEE	2017-06-30 15:32:00+03	54400.00
CC3FF5	2017-08-08 15:01:00+03	6000.00
CC4077	2017-08-01 16:53:00+03	46000.00
CC40D8	2017-07-24 22:13:00+03	134400.00
CC40E7	2017-08-05 10:14:00+03	52000.00
CC411B	2017-07-26 17:11:00+03	93400.00
CC4175	2017-07-07 09:45:00+03	19800.00
CC41A9	2017-08-02 05:32:00+03	55800.00
CC41CD	2017-07-11 11:01:00+03	18600.00
CC4241	2017-07-14 00:46:00+03	76600.00
CC4299	2017-07-06 03:45:00+03	37900.00
CC42B4	2017-08-07 15:54:00+03	30700.00
CC4328	2017-07-15 16:42:00+03	56000.00
CC433C	2017-07-21 09:17:00+03	135300.00
CC43AE	2017-07-09 23:21:00+03	58600.00
CC4480	2017-08-05 07:50:00+03	136800.00
CC449D	2017-07-19 11:36:00+03	69500.00
CC44B1	2017-07-09 06:04:00+03	149200.00
CC44B9	2017-06-29 18:01:00+03	63200.00
CC44C7	2017-07-07 03:17:00+03	21400.00
CC45C2	2017-08-13 01:30:00+03	38400.00
CC45F3	2017-07-24 10:56:00+03	89200.00
CC4648	2017-07-05 19:33:00+03	12600.00
CC464A	2017-08-05 20:16:00+03	28700.00
CC464D	2017-07-05 04:23:00+03	92700.00
CC4689	2017-07-05 08:44:00+03	23200.00
CC468A	2017-07-06 01:35:00+03	185600.00
CC46AF	2017-08-05 02:36:00+03	94800.00
CC46C5	2017-07-06 14:50:00+03	99200.00
CC46CA	2017-07-16 15:38:00+03	92800.00
CC46CF	2017-07-14 20:44:00+03	166100.00
CC46D0	2017-08-05 21:55:00+03	26000.00
CC46D9	2017-07-07 01:35:00+03	28800.00
CC4757	2017-08-05 00:44:00+03	80400.00
CC478C	2017-07-11 22:18:00+03	28800.00
CC47B0	2017-08-01 19:31:00+03	49100.00
CC47B3	2017-07-11 05:25:00+03	6000.00
CC47C5	2017-08-04 10:24:00+03	37900.00
CC47CD	2017-07-16 11:42:00+03	272300.00
CC4804	2017-08-15 14:08:00+03	46800.00
CC480F	2017-08-11 10:03:00+03	202100.00
CC4813	2017-06-30 08:54:00+03	28000.00
CC4839	2017-07-03 23:09:00+03	173900.00
CC4876	2017-07-09 00:22:00+03	42700.00
CC48D3	2017-07-17 12:09:00+03	40200.00
CC48D9	2017-07-31 02:05:00+03	168000.00
CC4904	2017-07-28 16:28:00+03	119600.00
CC4949	2017-07-03 09:12:00+03	58600.00
CC4983	2017-06-27 21:09:00+03	88600.00
CC4A28	2017-07-14 07:09:00+03	55800.00
CC4A98	2017-07-23 19:47:00+03	43600.00
CC4AC0	2017-08-01 17:11:00+03	25600.00
CC4AEE	2017-07-31 07:22:00+03	39000.00
CC4AFA	2017-07-26 00:12:00+03	39600.00
CC4B60	2017-07-09 01:16:00+03	89400.00
CC4B95	2017-07-15 22:33:00+03	21800.00
CC4C7F	2017-07-20 09:01:00+03	38900.00
CC4CE6	2017-07-16 23:53:00+03	33200.00
CC4D08	2017-07-11 12:24:00+03	12600.00
CC4D6A	2017-07-22 20:43:00+03	30200.00
CC4DBA	2017-08-07 11:27:00+03	40000.00
CC4E06	2017-07-31 17:41:00+03	123000.00
CC4E36	2017-08-10 21:09:00+03	159200.00
CC4E6C	2017-07-19 10:36:00+03	132800.00
CC4EA3	2017-07-05 00:11:00+03	6700.00
CC4F36	2017-07-08 02:25:00+03	81300.00
CC4F37	2017-07-07 14:28:00+03	28800.00
CC4F61	2017-07-16 16:39:00+03	46000.00
CC4FD5	2017-07-25 22:32:00+03	7400.00
CC4FD9	2017-08-05 20:41:00+03	111600.00
CC5021	2017-07-04 15:23:00+03	23900.00
CC5086	2017-07-15 05:17:00+03	12400.00
CC51E6	2017-07-06 18:36:00+03	89700.00
CC5215	2017-07-17 16:38:00+03	64000.00
CC5295	2017-08-05 19:53:00+03	51600.00
CC52A3	2017-07-01 13:20:00+03	131100.00
CC52B3	2017-07-20 17:27:00+03	44800.00
CC52D2	2017-07-12 08:12:00+03	73600.00
CC5330	2017-07-03 23:27:00+03	112000.00
CC5332	2017-08-09 06:56:00+03	65900.00
CC5340	2017-07-27 04:17:00+03	20200.00
CC5341	2017-07-26 16:39:00+03	95200.00
CC5347	2017-07-02 00:45:00+03	6700.00
CC5393	2017-08-10 14:36:00+03	28800.00
CC53A9	2017-07-04 13:49:00+03	23600.00
CC53BD	2017-07-10 10:16:00+03	33200.00
CC5405	2017-06-30 15:53:00+03	49400.00
CC5452	2017-07-04 16:25:00+03	97600.00
CC549F	2017-07-13 03:58:00+03	23600.00
CC54A9	2017-07-03 13:32:00+03	406600.00
CC5534	2017-08-07 15:09:00+03	13400.00
CC5541	2017-07-31 09:30:00+03	51900.00
CC558A	2017-08-12 03:49:00+03	37900.00
CC55D4	2017-07-27 17:13:00+03	29300.00
CC55FE	2017-07-27 02:43:00+03	38400.00
CC5630	2017-08-02 22:22:00+03	23600.00
CC56CD	2017-08-11 13:18:00+03	75100.00
CC56FD	2017-07-05 07:17:00+03	85000.00
CC5700	2017-08-11 02:19:00+03	147700.00
CC5718	2017-07-06 18:06:00+03	159900.00
CC57B2	2017-08-15 05:19:00+03	28800.00
CC57B8	2017-08-02 10:01:00+03	21200.00
CC57D7	2017-07-30 00:45:00+03	101200.00
CC57FC	2017-07-08 16:25:00+03	66200.00
CC5816	2017-07-02 00:56:00+03	62100.00
CC5857	2017-08-02 00:10:00+03	135400.00
CC5885	2017-07-09 10:24:00+03	102100.00
CC58B0	2017-07-29 11:44:00+03	27300.00
CC58B1	2017-07-03 13:43:00+03	58800.00
CC58BC	2017-07-04 02:42:00+03	67600.00
CC58BD	2017-07-30 22:41:00+03	150600.00
CC58EE	2017-08-06 08:05:00+03	65500.00
CC58F0	2017-07-31 03:31:00+03	81300.00
CC596A	2017-07-28 23:40:00+03	47400.00
CC5A09	2017-07-12 01:30:00+03	55800.00
CC5B05	2017-08-13 18:33:00+03	113700.00
CC5B1B	2017-07-22 10:20:00+03	80900.00
CC5B29	2017-08-02 17:56:00+03	48800.00
CC5B72	2017-08-08 09:12:00+03	111600.00
CC5B88	2017-07-09 13:40:00+03	111600.00
CC5BF2	2017-07-20 09:13:00+03	55800.00
CC5C15	2017-07-11 12:30:00+03	26700.00
CC5C3A	2017-07-29 03:04:00+03	12400.00
CC5C52	2017-07-20 20:05:00+03	24400.00
CC5C59	2017-07-10 00:26:00+03	34800.00
CC5CF2	2017-07-19 21:23:00+03	131100.00
CC5D4C	2017-07-11 11:51:00+03	67600.00
CC5D82	2017-08-12 23:11:00+03	111600.00
CC5D83	2017-08-06 17:12:00+03	32500.00
CC5DBB	2017-08-09 06:00:00+03	88600.00
CC5EB1	2017-07-16 16:26:00+03	69000.00
CC5EE4	2017-07-17 09:57:00+03	97600.00
CC5F43	2017-07-20 16:00:00+03	289500.00
CC5F55	2017-07-16 23:50:00+03	14900.00
CC5F8A	2017-07-23 15:32:00+03	34000.00
CC5F8C	2017-07-01 14:44:00+03	66400.00
CC5FD0	2017-08-06 19:51:00+03	147900.00
CC6003	2017-07-07 22:39:00+03	144400.00
CC6005	2017-07-13 23:01:00+03	49900.00
CC6019	2017-07-28 10:16:00+03	38400.00
CC606C	2017-08-06 23:41:00+03	132800.00
CC60A0	2017-07-30 09:36:00+03	72200.00
CC6190	2017-07-12 14:14:00+03	38500.00
CC61DC	2017-07-26 17:06:00+03	28000.00
CC621F	2017-08-08 08:40:00+03	143100.00
CC6224	2017-08-02 21:04:00+03	40900.00
CC6235	2017-07-13 03:56:00+03	394400.00
CC6259	2017-07-19 19:20:00+03	16400.00
CC625D	2017-07-27 03:27:00+03	111600.00
CC62CE	2017-08-15 07:18:00+03	375200.00
CC6305	2017-07-25 12:27:00+03	38800.00
CC634C	2017-08-08 13:35:00+03	52700.00
CC63AF	2017-07-24 17:03:00+03	100600.00
CC6452	2017-08-12 08:54:00+03	92200.00
CC6460	2017-07-09 22:45:00+03	88700.00
CC648D	2017-08-02 22:52:00+03	114400.00
CC6491	2017-08-09 20:35:00+03	114400.00
CC6492	2017-07-21 17:41:00+03	35600.00
CC649B	2017-07-02 02:32:00+03	53300.00
CC649D	2017-07-04 19:44:00+03	11800.00
CC64DC	2017-07-20 08:32:00+03	43000.00
CC6535	2017-08-06 08:21:00+03	189200.00
CC6539	2017-07-17 05:03:00+03	15400.00
CC653D	2017-07-17 06:58:00+03	36200.00
CC654D	2017-07-23 21:03:00+03	35700.00
CC65A0	2017-07-13 11:52:00+03	18700.00
CC65B4	2017-07-01 21:23:00+03	92600.00
CC65B6	2017-07-20 13:27:00+03	138100.00
CC65C6	2017-07-19 20:47:00+03	31400.00
CC65F8	2017-07-06 08:36:00+03	62700.00
CC660B	2017-07-13 17:53:00+03	44000.00
CC6636	2017-06-30 12:10:00+03	31900.00
CC6657	2017-07-18 20:41:00+03	53400.00
CC6665	2017-07-04 02:52:00+03	24800.00
CC6667	2017-08-14 19:52:00+03	12600.00
CC66D8	2017-07-15 08:54:00+03	56000.00
CC6764	2017-07-23 10:43:00+03	130900.00
CC6784	2017-07-08 01:18:00+03	290400.00
CC67B1	2017-07-20 13:06:00+03	50000.00
CC67C1	2017-07-31 01:57:00+03	139500.00
CC67E9	2017-08-12 09:12:00+03	133100.00
CC67F9	2017-08-05 04:56:00+03	31000.00
CC67FA	2017-08-12 18:18:00+03	64000.00
CC6817	2017-07-29 18:25:00+03	21200.00
CC6837	2017-08-15 10:31:00+03	137100.00
CC685B	2017-07-06 08:10:00+03	40000.00
CC6873	2017-07-22 00:52:00+03	136300.00
CC68A3	2017-08-04 13:40:00+03	21400.00
CC68AC	2017-07-10 12:12:00+03	21000.00
CC68B8	2017-08-06 10:07:00+03	59300.00
CC68DE	2017-07-31 00:50:00+03	75000.00
CC6925	2017-07-01 02:17:00+03	28800.00
CC692C	2017-07-07 17:29:00+03	23400.00
CC6971	2017-07-21 09:59:00+03	192400.00
CC6976	2017-08-09 01:58:00+03	202800.00
CC698F	2017-07-30 17:05:00+03	41800.00
CC69AA	2017-07-02 00:38:00+03	69500.00
CC69B8	2017-07-19 22:27:00+03	20500.00
CC69F5	2017-07-13 08:50:00+03	202700.00
CC6A2F	2017-07-12 03:38:00+03	25400.00
CC6A77	2017-08-13 01:00:00+03	20600.00
CC6AEB	2017-06-30 04:26:00+03	56000.00
CC6B22	2017-08-06 07:15:00+03	70700.00
CC6B31	2017-07-24 05:03:00+03	21800.00
CC6B37	2017-07-26 16:02:00+03	53600.00
CC6BEF	2017-08-11 00:32:00+03	16400.00
CC6C27	2017-07-01 21:05:00+03	26000.00
CC6D24	2017-07-28 01:20:00+03	113300.00
CC6D62	2017-08-09 03:10:00+03	492000.00
CC6D65	2017-07-20 17:23:00+03	26200.00
CC6D76	2017-07-20 07:01:00+03	57500.00
CC6D8E	2017-07-11 21:58:00+03	32400.00
CC6DC9	2017-07-05 15:07:00+03	125200.00
CC6E3A	2017-08-13 11:58:00+03	38800.00
CC6E47	2017-08-08 02:14:00+03	82900.00
CC6E53	2017-07-03 16:11:00+03	36200.00
CC6EBD	2017-07-29 09:45:00+03	23200.00
CC6EE6	2017-08-09 21:06:00+03	23200.00
CC6F64	2017-08-12 14:18:00+03	14100.00
CC6FF9	2017-08-02 09:40:00+03	26000.00
CC702A	2017-07-09 23:14:00+03	265700.00
CC7080	2017-08-13 16:59:00+03	35700.00
CC70B1	2017-08-14 15:52:00+03	274200.00
CC70CA	2017-08-07 17:14:00+03	31200.00
CC70CD	2017-07-04 23:49:00+03	41600.00
CC7110	2017-08-02 16:58:00+03	70700.00
CC7133	2017-07-27 00:27:00+03	20800.00
CC7135	2017-07-28 23:17:00+03	39200.00
CC7152	2017-08-14 01:47:00+03	68800.00
CC715C	2017-07-01 18:53:00+03	99700.00
CC7273	2017-07-21 21:58:00+03	23600.00
CC727C	2017-07-17 17:43:00+03	67800.00
CC729F	2017-08-02 07:43:00+03	31600.00
CC72B2	2017-07-15 07:04:00+03	112000.00
CC7313	2017-07-26 22:36:00+03	202400.00
CC732C	2017-07-24 04:05:00+03	528000.00
CC734B	2017-07-06 11:56:00+03	54400.00
CC73C1	2017-07-21 05:14:00+03	87700.00
CC7456	2017-07-27 14:44:00+03	27900.00
CC747C	2017-08-12 21:41:00+03	88600.00
CC74B5	2017-07-04 22:08:00+03	206200.00
CC74D2	2017-08-05 10:43:00+03	135000.00
CC7505	2017-08-01 06:07:00+03	52000.00
CC75CA	2017-07-20 01:43:00+03	26800.00
CC75D1	2017-08-11 21:05:00+03	59800.00
CC75DE	2017-07-09 18:33:00+03	40300.00
CC763F	2017-08-13 13:30:00+03	104600.00
CC7641	2017-07-07 20:36:00+03	25600.00
CC7670	2017-07-26 06:06:00+03	55800.00
CC7697	2017-08-07 00:38:00+03	136500.00
CC76A6	2017-07-30 16:48:00+03	236700.00
CC7743	2017-07-15 17:07:00+03	28000.00
CC7788	2017-07-04 11:52:00+03	43400.00
CC778D	2017-07-13 17:53:00+03	38200.00
CC779C	2017-08-10 09:18:00+03	28800.00
CC77D8	2017-07-06 21:03:00+03	97700.00
CC781D	2017-07-09 00:00:00+03	136200.00
CC786F	2017-07-11 01:06:00+03	117500.00
CC7883	2017-08-12 20:07:00+03	47600.00
CC78EE	2017-07-07 18:57:00+03	12600.00
CC7921	2017-08-15 14:58:00+03	10800.00
CC7945	2017-08-03 23:02:00+03	54800.00
CC7962	2017-07-09 12:54:00+03	11800.00
CC7988	2017-07-08 08:02:00+03	73500.00
CC79AA	2017-07-16 14:58:00+03	12000.00
CC79DA	2017-08-02 15:31:00+03	6000.00
CC7B60	2017-07-24 03:06:00+03	272000.00
CC7BE6	2017-08-02 10:31:00+03	136200.00
CC7C63	2017-08-10 16:40:00+03	49700.00
CC7C74	2017-07-03 18:10:00+03	70600.00
CC7C88	2017-08-01 23:44:00+03	20800.00
CC7C89	2017-08-06 11:56:00+03	118000.00
CC7CBA	2017-07-06 14:41:00+03	13000.00
CC7CE8	2017-07-21 19:19:00+03	257500.00
CC7D9E	2017-08-09 15:29:00+03	24400.00
CC7DA4	2017-07-29 13:50:00+03	174200.00
CC7DCA	2017-07-02 20:15:00+03	132800.00
CC7E3E	2017-07-21 12:57:00+03	46300.00
CC7E59	2017-07-31 18:57:00+03	46200.00
CC7F14	2017-07-21 02:43:00+03	32200.00
CC7F25	2017-07-12 12:03:00+03	19600.00
CC7FA3	2017-07-22 02:23:00+03	81700.00
CC7FAF	2017-08-05 15:37:00+03	90400.00
CC7FE4	2017-07-19 17:19:00+03	76600.00
CC7FEE	2017-07-13 10:38:00+03	46000.00
CC801B	2017-07-18 08:48:00+03	96800.00
CC803A	2017-07-17 00:50:00+03	112000.00
CC818D	2017-07-31 01:19:00+03	6700.00
CC8204	2017-07-06 15:18:00+03	22000.00
CC8225	2017-08-05 09:01:00+03	30200.00
CC8258	2017-08-10 12:56:00+03	31600.00
CC82BA	2017-07-15 03:55:00+03	37100.00
CC82BB	2017-08-08 21:14:00+03	86500.00
CC82E7	2017-08-01 07:08:00+03	52000.00
CC8308	2017-07-06 22:58:00+03	47000.00
CC83AF	2017-07-05 14:10:00+03	71100.00
CC84B6	2017-08-06 00:45:00+03	60400.00
CC8589	2017-07-02 03:44:00+03	6000.00
CC85AA	2017-07-19 14:41:00+03	167400.00
CC8674	2017-07-25 11:53:00+03	40300.00
CC86A4	2017-08-07 13:38:00+03	43100.00
CC86EF	2017-08-13 07:55:00+03	77000.00
CC8733	2017-07-22 14:39:00+03	51600.00
CC8752	2017-07-26 00:42:00+03	88200.00
CC8770	2017-07-13 09:15:00+03	25200.00
CC877F	2017-08-03 18:54:00+03	6700.00
CC8786	2017-07-16 01:04:00+03	25000.00
CC87C8	2017-07-26 18:56:00+03	23200.00
CC882B	2017-07-25 21:50:00+03	71200.00
CC889B	2017-07-30 19:29:00+03	19800.00
CC88BA	2017-07-29 01:51:00+03	23200.00
CC898A	2017-08-01 16:37:00+03	51200.00
CC8A11	2017-08-01 19:58:00+03	27800.00
CC8A30	2017-07-09 07:23:00+03	84300.00
CC8A43	2017-07-26 18:53:00+03	109400.00
CC8A55	2017-07-04 22:06:00+03	534300.00
CC8A68	2017-07-10 22:21:00+03	86800.00
CC8B08	2017-07-18 06:46:00+03	39300.00
CC8B51	2017-07-28 03:31:00+03	6000.00
CC8BC5	2017-07-18 14:48:00+03	26100.00
CC8BD5	2017-07-09 12:40:00+03	26000.00
CC8C68	2017-08-10 12:30:00+03	246000.00
CC8CAF	2017-08-01 06:57:00+03	156300.00
CC8CC4	2017-08-08 17:58:00+03	17200.00
CC8D4F	2017-08-06 00:02:00+03	115700.00
CC8D50	2017-08-15 02:12:00+03	78200.00
CC8D6E	2017-07-17 23:05:00+03	196800.00
CC8DDA	2017-07-06 14:14:00+03	21800.00
CC8E0C	2017-06-29 19:55:00+03	56000.00
CC8E5E	2017-07-11 11:55:00+03	85000.00
CC8EE4	2017-07-01 08:25:00+03	6000.00
CC8F27	2017-08-09 15:23:00+03	15700.00
CC8F60	2017-08-04 15:41:00+03	51900.00
CC8F62	2017-07-22 20:20:00+03	34000.00
CC8FE4	2017-07-28 04:51:00+03	111000.00
CC906E	2017-06-26 04:20:00+03	6900.00
CC90E6	2017-08-15 11:10:00+03	26800.00
CC912D	2017-07-12 15:39:00+03	185000.00
CC9141	2017-07-08 11:53:00+03	62800.00
CC9160	2017-07-25 21:20:00+03	248300.00
CC92B6	2017-08-08 17:41:00+03	38800.00
CC9332	2017-08-03 15:18:00+03	38600.00
CC9408	2017-07-06 22:55:00+03	13000.00
CC940B	2017-07-22 00:29:00+03	23500.00
CC9484	2017-07-03 10:20:00+03	16400.00
CC9491	2017-07-02 11:30:00+03	84800.00
CC9500	2017-07-23 18:47:00+03	65200.00
CC9542	2017-07-30 03:09:00+03	46300.00
CC9561	2017-07-19 08:31:00+03	92700.00
CC95E7	2017-07-19 12:03:00+03	303100.00
CC95EB	2017-07-09 14:32:00+03	55800.00
CC960A	2017-08-08 18:03:00+03	21400.00
CC9628	2017-07-10 14:14:00+03	43400.00
CC963C	2017-07-05 21:50:00+03	23200.00
CC9699	2017-06-28 15:01:00+03	57600.00
CC96FD	2017-07-02 09:21:00+03	24500.00
CC9710	2017-08-13 10:27:00+03	34000.00
CC9763	2017-08-06 17:47:00+03	53600.00
CC97BC	2017-07-21 02:29:00+03	23200.00
CC97CD	2017-07-15 09:56:00+03	192400.00
CC9838	2017-07-28 19:24:00+03	27200.00
CC988A	2017-07-12 20:20:00+03	75600.00
CC98BC	2017-07-31 01:30:00+03	21200.00
CC98FC	2017-08-02 06:03:00+03	266200.00
CC993F	2017-08-07 14:59:00+03	118100.00
CC9942	2017-07-24 20:00:00+03	254900.00
CC994A	2017-08-02 18:53:00+03	100600.00
CC9976	2017-07-23 03:31:00+03	104800.00
CC99F6	2017-07-15 06:00:00+03	23600.00
CC9A46	2017-07-06 00:38:00+03	28300.00
CC9B28	2017-07-07 05:13:00+03	68700.00
CC9B8D	2017-07-23 12:47:00+03	65600.00
CC9C62	2017-07-26 10:58:00+03	48700.00
CC9CCD	2017-07-25 10:04:00+03	8200.00
CC9D39	2017-07-11 16:20:00+03	45200.00
CC9D3C	2017-07-10 00:44:00+03	57500.00
CC9D56	2017-08-06 00:46:00+03	16400.00
CC9DAE	2017-07-24 11:08:00+03	36200.00
CC9DF5	2017-07-16 20:00:00+03	266200.00
CC9E42	2017-07-30 14:27:00+03	35200.00
CC9E99	2017-08-13 04:35:00+03	12000.00
CC9EA8	2017-07-06 16:42:00+03	13200.00
CC9ED7	2017-07-13 11:57:00+03	8200.00
CC9EEA	2017-07-04 01:49:00+03	68100.00
CC9F11	2017-06-29 20:31:00+03	23200.00
CC9F3F	2017-07-15 06:51:00+03	56000.00
CC9FE1	2017-07-16 15:02:00+03	62600.00
CCA0D2	2017-08-13 03:38:00+03	24700.00
CCA108	2017-07-24 10:37:00+03	25600.00
CCA113	2017-08-03 12:05:00+03	56600.00
CCA119	2017-07-05 00:37:00+03	112000.00
CCA168	2017-07-19 05:48:00+03	92000.00
CCA202	2017-08-02 15:54:00+03	93700.00
CCA2A0	2017-07-08 09:40:00+03	35200.00
CCA2A1	2017-07-26 18:59:00+03	21800.00
CCA2AF	2017-08-15 12:31:00+03	137600.00
CCA2E3	2017-08-06 11:14:00+03	73500.00
CCA325	2017-08-13 15:03:00+03	35600.00
CCA35D	2017-08-07 23:13:00+03	106800.00
CCA3A2	2017-08-07 11:31:00+03	109600.00
CCA3C3	2017-08-10 04:30:00+03	73500.00
CCA3E7	2017-07-26 04:39:00+03	52000.00
CCA42B	2017-07-09 18:21:00+03	46200.00
CCA4AA	2017-08-12 12:35:00+03	133200.00
CCA4AC	2017-08-14 02:19:00+03	54000.00
CCA562	2017-07-31 07:29:00+03	89600.00
CCA564	2017-07-25 05:04:00+03	16400.00
CCA59B	2017-07-28 02:02:00+03	97600.00
CCA5D0	2017-08-11 22:00:00+03	106400.00
CCA5D9	2017-07-19 07:48:00+03	234700.00
CCA63B	2017-07-12 21:23:00+03	22600.00
CCA643	2017-08-14 02:29:00+03	83900.00
CCA64B	2017-07-28 13:26:00+03	19600.00
CCA651	2017-07-20 01:29:00+03	14400.00
CCA700	2017-07-30 05:00:00+03	26000.00
CCA748	2017-07-17 01:20:00+03	84800.00
CCA769	2017-07-19 04:19:00+03	531300.00
CCA7B2	2017-07-06 23:08:00+03	157100.00
CCA7B7	2017-08-02 17:46:00+03	57800.00
CCA82D	2017-08-13 05:18:00+03	57300.00
CCA885	2017-08-10 03:36:00+03	119500.00
CCA899	2017-08-01 09:49:00+03	135600.00
CCA8A0	2017-07-03 06:59:00+03	19600.00
CCA8A7	2017-07-23 10:58:00+03	130000.00
CCA8BE	2017-07-30 15:18:00+03	35700.00
CCA8CC	2017-08-05 20:11:00+03	49400.00
CCA905	2017-07-03 07:12:00+03	91800.00
CCA937	2017-07-26 01:30:00+03	28000.00
CCA93D	2017-07-22 10:58:00+03	369000.00
CCA94D	2017-07-29 12:00:00+03	23200.00
CCA967	2017-07-29 22:10:00+03	32500.00
CCA98B	2017-07-29 12:33:00+03	386300.00
CCA9B1	2017-07-28 18:21:00+03	44600.00
CCA9CB	2017-07-21 11:57:00+03	66600.00
CCA9D8	2017-08-03 08:54:00+03	136200.00
CCAA76	2017-07-10 02:56:00+03	52000.00
CCAA83	2017-08-09 16:17:00+03	236000.00
CCAA8F	2017-08-15 03:17:00+03	12000.00
CCAAAB	2017-08-12 21:28:00+03	25600.00
CCAB23	2017-07-20 19:19:00+03	21400.00
CCAB68	2017-08-06 18:34:00+03	103500.00
CCAB9C	2017-07-25 05:15:00+03	103500.00
CCAB9F	2017-08-13 04:04:00+03	67600.00
CCABA1	2017-07-26 11:53:00+03	15000.00
CCABA9	2017-07-31 08:12:00+03	56100.00
CCAC3F	2017-07-13 16:29:00+03	35200.00
CCAC42	2017-07-29 21:13:00+03	26000.00
CCAC7E	2017-07-29 13:03:00+03	75200.00
CCACBB	2017-08-11 00:55:00+03	149600.00
CCAD0B	2017-07-20 19:08:00+03	68100.00
CCAD27	2017-07-27 20:25:00+03	21800.00
CCAD8D	2017-08-03 05:24:00+03	23200.00
CCAD9D	2017-07-29 16:07:00+03	58000.00
CCADA6	2017-07-22 07:31:00+03	65400.00
CCADD8	2017-07-05 13:09:00+03	52300.00
CCAE1D	2017-07-20 05:28:00+03	25800.00
CCAE7E	2017-07-15 21:09:00+03	72400.00
CCAE9F	2017-07-30 16:44:00+03	113200.00
CCAEC9	2017-07-27 00:06:00+03	36200.00
CCAEE6	2017-07-24 02:30:00+03	12000.00
CCAF02	2017-08-11 14:42:00+03	23600.00
CCAF17	2017-08-10 18:00:00+03	63200.00
CCAF2C	2017-08-14 03:00:00+03	46400.00
CCAF31	2017-07-18 12:36:00+03	266500.00
CCAF41	2017-07-10 04:29:00+03	73100.00
CCAF54	2017-07-25 07:20:00+03	123000.00
CCAF6D	2017-07-10 02:21:00+03	144700.00
CCAF95	2017-07-07 16:38:00+03	201200.00
CCAFD1	2017-08-05 12:10:00+03	29400.00
CCAFD5	2017-08-06 08:28:00+03	31000.00
CCAFF9	2017-07-21 05:20:00+03	20400.00
CCB040	2017-07-10 15:09:00+03	45000.00
CCB04E	2017-07-13 05:12:00+03	21800.00
CCB090	2017-08-09 04:40:00+03	12600.00
CCB0B9	2017-07-29 11:24:00+03	57600.00
CCB123	2017-07-30 19:15:00+03	29300.00
CCB12A	2017-07-25 12:52:00+03	21800.00
CCB145	2017-08-04 02:46:00+03	208100.00
CCB154	2017-08-14 11:49:00+03	42800.00
CCB162	2017-07-17 10:41:00+03	139300.00
CCB176	2017-08-10 10:48:00+03	31600.00
CCB227	2017-07-22 19:45:00+03	56000.00
CCB236	2017-07-07 06:41:00+03	43800.00
CCB242	2017-08-01 01:50:00+03	68800.00
CCB248	2017-08-13 08:57:00+03	272400.00
CCB265	2017-07-16 01:58:00+03	19600.00
CCB266	2017-07-03 07:02:00+03	47500.00
CCB27A	2017-08-10 08:25:00+03	23600.00
CCB2A6	2017-07-26 04:04:00+03	67900.00
CCB2B1	2017-07-24 02:11:00+03	63700.00
CCB2D9	2017-07-30 16:56:00+03	29600.00
CCB2DC	2017-07-01 18:56:00+03	40800.00
CCB396	2017-08-02 17:24:00+03	59300.00
CCB3C9	2017-08-04 09:02:00+03	31600.00
CCB40F	2017-08-11 19:16:00+03	12200.00
CCB4F6	2017-08-13 10:53:00+03	44000.00
CCB50D	2017-07-11 14:27:00+03	109600.00
CCB534	2017-08-09 11:33:00+03	56600.00
CCB556	2017-08-01 02:26:00+03	266400.00
CCB55A	2017-07-26 04:13:00+03	28000.00
CCB562	2017-08-15 09:20:00+03	38800.00
CCB594	2017-08-14 12:25:00+03	47200.00
CCB5FC	2017-07-14 15:55:00+03	29600.00
CCB615	2017-07-27 22:57:00+03	76600.00
CCB62E	2017-06-27 06:20:00+03	46400.00
CCB661	2017-08-10 08:38:00+03	55800.00
CCB667	2017-07-13 03:41:00+03	47100.00
CCB66F	2017-07-28 01:42:00+03	167400.00
CCB689	2017-07-19 07:26:00+03	38600.00
CCB69A	2017-08-10 22:53:00+03	80500.00
CCB6D1	2017-07-25 06:59:00+03	114700.00
CCB6E2	2017-07-29 04:26:00+03	76800.00
CCB6FE	2017-08-04 15:24:00+03	41800.00
CCB718	2017-08-12 09:04:00+03	76100.00
CCB774	2017-07-05 10:30:00+03	99200.00
CCB7AA	2017-08-11 19:16:00+03	40800.00
CCB83F	2017-07-19 15:19:00+03	99200.00
CCB8F5	2017-08-14 00:26:00+03	81700.00
CCB915	2017-08-04 21:58:00+03	163800.00
CCB957	2017-07-23 19:15:00+03	136800.00
CCB961	2017-07-20 10:46:00+03	26200.00
CCB995	2017-07-05 07:06:00+03	19100.00
CCB9D6	2017-07-29 18:54:00+03	72000.00
CCB9F7	2017-07-30 04:30:00+03	20600.00
CCBA02	2017-07-16 19:03:00+03	112000.00
CCBA6F	2017-07-30 14:05:00+03	26000.00
CCBA76	2017-08-01 22:01:00+03	24400.00
CCBA7D	2017-08-01 00:22:00+03	7200.00
CCBBAB	2017-07-10 18:31:00+03	94700.00
CCBBCA	2017-07-14 21:14:00+03	40400.00
CCBC28	2017-08-08 14:03:00+03	84100.00
CCBC6E	2017-07-22 07:41:00+03	81800.00
CCBCA9	2017-07-17 18:28:00+03	26800.00
CCBD86	2017-07-22 05:18:00+03	20600.00
CCBD95	2017-06-30 10:39:00+03	35400.00
CCBE24	2017-07-08 05:32:00+03	70700.00
CCBE38	2017-08-10 15:52:00+03	8200.00
CCBE3F	2017-07-10 14:51:00+03	68800.00
CCBE52	2017-07-22 07:25:00+03	48700.00
CCBEC5	2017-07-19 06:32:00+03	116800.00
CCBED8	2017-08-09 21:55:00+03	6000.00
CCBF05	2017-07-15 00:44:00+03	186900.00
CCC051	2017-08-10 17:41:00+03	6700.00
CCC107	2017-08-11 20:19:00+03	15000.00
CCC111	2017-08-11 09:54:00+03	49700.00
CCC148	2017-08-14 19:19:00+03	46000.00
CCC16B	2017-07-20 03:33:00+03	23600.00
CCC1C6	2017-07-03 14:13:00+03	266400.00
CCC20F	2017-07-20 13:20:00+03	23400.00
CCC28F	2017-07-24 15:21:00+03	39800.00
CCC2C4	2017-07-07 18:38:00+03	51300.00
CCC2E0	2017-08-14 15:59:00+03	25100.00
CCC358	2017-06-28 23:41:00+03	65500.00
CCC387	2017-07-09 00:03:00+03	133600.00
CCC397	2017-06-28 05:52:00+03	18000.00
CCC3B9	2017-07-09 11:32:00+03	56900.00
CCC41B	2017-08-09 22:00:00+03	73000.00
CCC451	2017-07-25 13:28:00+03	83000.00
CCC45C	2017-07-14 22:25:00+03	135000.00
CCC495	2017-07-08 22:43:00+03	35300.00
CCC49F	2017-07-15 06:30:00+03	206700.00
CCC5CB	2017-07-07 03:03:00+03	13000.00
CCC637	2017-07-15 03:24:00+03	90400.00
CCC63D	2017-07-28 02:21:00+03	38600.00
CCC65D	2017-07-12 08:04:00+03	73400.00
CCC674	2017-08-11 05:58:00+03	135200.00
CCC678	2017-07-10 16:26:00+03	266400.00
CCC687	2017-07-11 22:23:00+03	21000.00
CCC6CD	2017-07-19 23:22:00+03	28800.00
CCC6FB	2017-07-31 16:07:00+03	75300.00
CCC70E	2017-07-09 17:09:00+03	40600.00
CCC749	2017-08-14 20:29:00+03	73500.00
CCC78A	2017-07-25 12:49:00+03	189700.00
CCC797	2017-08-10 11:29:00+03	67800.00
CCC7EE	2017-07-02 17:28:00+03	356700.00
CCC7EF	2017-08-08 13:45:00+03	69700.00
CCC849	2017-07-30 16:00:00+03	50600.00
CCC85C	2017-07-21 18:37:00+03	8200.00
CCC860	2017-07-24 08:52:00+03	111600.00
CCC89C	2017-07-28 15:59:00+03	24400.00
CCC8B3	2017-07-11 05:00:00+03	62800.00
CCC8F0	2017-08-09 10:17:00+03	28000.00
CCC928	2017-08-09 06:14:00+03	16400.00
CCC9A9	2017-08-11 13:23:00+03	92200.00
CCC9C5	2017-07-31 20:11:00+03	207200.00
CCC9D0	2017-06-30 06:38:00+03	67900.00
CCC9DE	2017-06-29 03:24:00+03	67700.00
CCC9ED	2017-07-14 00:34:00+03	63200.00
CCC9F2	2017-08-04 22:52:00+03	135200.00
CCCA18	2017-08-03 10:02:00+03	32200.00
CCCA1B	2017-07-13 15:35:00+03	56100.00
CCCA30	2017-06-28 22:02:00+03	6800.00
CCCA47	2017-07-02 12:31:00+03	135600.00
CCCAD3	2017-07-08 04:26:00+03	102100.00
CCCB0C	2017-08-07 04:53:00+03	198600.00
CCCBBB	2017-06-30 13:06:00+03	38400.00
CCCBD8	2017-08-12 17:00:00+03	127300.00
CCCC22	2017-08-09 06:10:00+03	28000.00
CCCC35	2017-07-29 03:10:00+03	56100.00
CCCC60	2017-07-26 23:05:00+03	28800.00
CCCC94	2017-07-31 14:44:00+03	26000.00
CCCCDD	2017-07-21 04:19:00+03	46000.00
CCCCE1	2017-07-13 15:07:00+03	23200.00
CCCD1D	2017-08-15 02:40:00+03	109000.00
CCCD57	2017-08-04 10:29:00+03	8200.00
CCCD66	2017-07-23 18:29:00+03	9300.00
CCCD9E	2017-08-12 11:14:00+03	36200.00
CCCE0C	2017-07-09 03:14:00+03	6800.00
CCCE38	2017-08-03 09:15:00+03	26800.00
CCCE59	2017-07-20 10:20:00+03	21400.00
CCCF23	2017-08-12 16:31:00+03	13700.00
CCCF4A	2017-07-29 01:18:00+03	131700.00
CCCF9F	2017-07-03 15:26:00+03	42900.00
CCCFAF	2017-08-03 23:31:00+03	51000.00
CCCFC3	2017-07-11 07:18:00+03	23100.00
CCD00B	2017-08-06 04:25:00+03	111600.00
CCD029	2017-07-17 05:46:00+03	139300.00
CCD08D	2017-07-12 20:01:00+03	25400.00
CCD098	2017-08-09 13:49:00+03	48800.00
CCD0AA	2017-08-03 09:12:00+03	23600.00
CCD0EA	2017-07-17 14:22:00+03	34000.00
CCD11A	2017-07-11 01:41:00+03	26500.00
CCD152	2017-07-29 17:52:00+03	20400.00
CCD16C	2017-08-11 21:28:00+03	128800.00
CCD23F	2017-07-04 04:49:00+03	18800.00
CCD293	2017-08-11 07:27:00+03	293400.00
CCD297	2017-08-04 04:38:00+03	34000.00
CCD2BE	2017-07-16 14:52:00+03	109000.00
CCD2C7	2017-08-06 07:34:00+03	69500.00
CCD361	2017-08-07 05:48:00+03	36200.00
CCD369	2017-07-13 15:00:00+03	102100.00
CCD3B1	2017-07-28 00:43:00+03	32200.00
CCD3E8	2017-08-12 07:01:00+03	43500.00
CCD430	2017-08-05 11:31:00+03	55800.00
CCD48E	2017-06-28 22:53:00+03	87900.00
CCD525	2017-07-19 20:40:00+03	81600.00
CCD542	2017-08-01 21:36:00+03	223200.00
CCD57F	2017-08-05 13:34:00+03	24800.00
CCD5D2	2017-07-03 15:10:00+03	64600.00
CCD60B	2017-08-03 06:23:00+03	80300.00
CCD636	2017-07-01 21:57:00+03	39800.00
CCD65C	2017-08-12 20:18:00+03	61800.00
CCD788	2017-07-24 16:08:00+03	25000.00
CCD7A9	2017-08-14 16:31:00+03	106200.00
CCD82E	2017-08-14 20:15:00+03	29900.00
CCD8BC	2017-07-05 09:55:00+03	98400.00
CCD8CF	2017-07-28 06:40:00+03	406800.00
CCD8E6	2017-07-10 22:27:00+03	21800.00
CCD8F9	2017-08-01 11:11:00+03	77600.00
CCD92C	2017-07-03 10:06:00+03	6300.00
CCD94C	2017-07-09 02:35:00+03	24400.00
CCD9C6	2017-08-03 13:08:00+03	28000.00
CCDA88	2017-07-12 14:51:00+03	34000.00
CCDA99	2017-07-07 12:28:00+03	56000.00
CCDA9E	2017-08-04 15:38:00+03	108800.00
CCDABB	2017-08-05 05:21:00+03	16400.00
CCDB13	2017-07-27 06:40:00+03	240600.00
CCDB53	2017-07-21 08:28:00+03	24000.00
CCDB82	2017-07-11 05:17:00+03	55800.00
CCDB8A	2017-08-09 06:10:00+03	13000.00
CCDBC7	2017-08-02 01:35:00+03	172100.00
CCDC16	2017-08-08 12:42:00+03	72000.00
CCDC43	2017-07-20 23:08:00+03	38400.00
CCDC45	2017-07-06 07:44:00+03	51200.00
CCDD7C	2017-08-11 01:19:00+03	13400.00
CCDE01	2017-07-08 00:57:00+03	14400.00
CCDE1F	2017-07-20 15:00:00+03	35700.00
CCDE53	2017-07-21 09:14:00+03	179300.00
CCDE76	2017-08-04 22:27:00+03	36400.00
CCDE95	2017-07-23 04:09:00+03	369000.00
CCDEC3	2017-08-02 15:03:00+03	36200.00
CCDECD	2017-07-04 14:40:00+03	11600.00
CCDED1	2017-07-31 14:02:00+03	21800.00
CCDF07	2017-08-06 05:33:00+03	55800.00
CCDF37	2017-07-05 23:14:00+03	28000.00
CCDF54	2017-07-03 15:48:00+03	29600.00
CCE096	2017-07-31 13:50:00+03	18600.00
CCE0F1	2017-07-01 15:35:00+03	69400.00
CCE106	2017-08-11 01:22:00+03	112100.00
CCE121	2017-07-08 18:06:00+03	9800.00
CCE1BA	2017-07-10 04:50:00+03	13600.00
CCE1C4	2017-08-06 16:19:00+03	184300.00
CCE1D7	2017-08-01 08:34:00+03	119600.00
CCE201	2017-08-08 10:11:00+03	32800.00
CCE25C	2017-07-18 13:41:00+03	136000.00
CCE29D	2017-07-23 20:22:00+03	53200.00
CCE2B6	2017-07-02 05:20:00+03	92800.00
CCE2BC	2017-06-25 15:04:00+03	46400.00
CCE2F3	2017-07-26 09:31:00+03	25600.00
CCE326	2017-07-03 04:11:00+03	38600.00
CCE387	2017-07-26 15:31:00+03	78500.00
CCE390	2017-08-11 06:31:00+03	89000.00
CCE3AF	2017-07-08 22:19:00+03	67000.00
CCE3BF	2017-08-06 05:41:00+03	67200.00
CCE429	2017-08-14 06:22:00+03	6700.00
CCE4FD	2017-08-10 21:07:00+03	86800.00
CCE51A	2017-08-07 14:34:00+03	99200.00
CCE565	2017-08-11 21:03:00+03	18000.00
CCE5BD	2017-08-05 05:28:00+03	67400.00
CCE680	2017-07-16 09:07:00+03	27200.00
CCE69A	2017-07-10 04:15:00+03	19600.00
CCE6CD	2017-07-09 22:47:00+03	12600.00
CCE6ED	2017-07-25 14:58:00+03	64500.00
CCE7A7	2017-08-02 23:51:00+03	39300.00
CCE7CE	2017-07-16 19:30:00+03	26000.00
CCE7F4	2017-07-16 01:02:00+03	22000.00
CCE808	2017-08-01 08:20:00+03	155600.00
CCE80D	2017-08-02 08:13:00+03	46400.00
CCE84E	2017-07-27 18:25:00+03	46700.00
CCE882	2017-06-29 01:51:00+03	45500.00
CCE8A8	2017-07-13 00:50:00+03	48800.00
CCE8BA	2017-07-10 12:53:00+03	123600.00
CCE8EB	2017-08-01 11:33:00+03	155600.00
CCE91E	2017-07-11 15:13:00+03	39300.00
CCE92F	2017-08-15 13:57:00+03	36900.00
CCE933	2017-07-12 18:12:00+03	43300.00
CCE95F	2017-07-04 01:13:00+03	54000.00
CCE964	2017-07-27 00:56:00+03	77900.00
CCE9B5	2017-08-09 02:55:00+03	19800.00
CCE9F6	2017-07-06 15:15:00+03	28000.00
CCEA1C	2017-07-20 14:18:00+03	49000.00
CCEA81	2017-07-10 10:58:00+03	174900.00
CCEA90	2017-07-12 10:32:00+03	101200.00
CCEB1B	2017-08-01 11:13:00+03	23400.00
CCEB6A	2017-07-13 23:18:00+03	51900.00
CCEBB9	2017-08-06 05:42:00+03	20400.00
CCEBEB	2017-08-01 03:31:00+03	85000.00
CCEBF0	2017-08-09 03:08:00+03	84200.00
CCED24	2017-07-11 17:28:00+03	32300.00
CCED38	2017-06-30 02:11:00+03	40800.00
CCED68	2017-08-03 05:44:00+03	52300.00
CCEDF9	2017-07-08 13:56:00+03	62600.00
CCEEB0	2017-07-31 21:24:00+03	372500.00
CCEEBE	2017-08-07 09:02:00+03	204200.00
CCEED0	2017-07-14 11:14:00+03	23200.00
CCEF02	2017-07-19 10:52:00+03	43500.00
CCEF70	2017-07-25 03:48:00+03	91600.00
CCEFA6	2017-08-13 22:29:00+03	14800.00
CCEFAA	2017-07-14 11:05:00+03	32900.00
CCEFB5	2017-07-29 09:41:00+03	21400.00
CCEFBB	2017-08-07 15:37:00+03	90400.00
CCEFE3	2017-07-02 15:55:00+03	170800.00
CCF01F	2017-08-03 06:57:00+03	64700.00
CCF038	2017-06-29 01:55:00+03	10800.00
CCF059	2017-07-25 10:04:00+03	60400.00
CCF065	2017-08-06 08:05:00+03	113800.00
CCF0D1	2017-07-06 05:12:00+03	184500.00
CCF127	2017-08-08 06:40:00+03	22000.00
CCF14B	2017-07-03 17:52:00+03	12000.00
CCF14C	2017-07-14 21:08:00+03	113200.00
CCF1A7	2017-07-03 14:46:00+03	27000.00
CCF37C	2017-07-26 07:49:00+03	66600.00
CCF3F3	2017-07-29 07:59:00+03	20400.00
CCF46B	2017-07-24 13:38:00+03	24400.00
CCF5E3	2017-07-19 14:11:00+03	42800.00
CCF605	2017-08-13 04:35:00+03	24800.00
CCF61E	2017-07-20 21:10:00+03	31200.00
CCF693	2017-07-30 23:08:00+03	18000.00
CCF6AA	2017-07-18 12:44:00+03	148200.00
CCF6DD	2017-06-28 18:31:00+03	99300.00
CCF6F9	2017-07-26 12:16:00+03	16400.00
CCF716	2017-08-15 15:01:00+03	12600.00
CCF742	2017-07-21 01:47:00+03	41200.00
CCF74E	2017-07-14 11:38:00+03	155600.00
CCF761	2017-07-01 14:49:00+03	49800.00
CCF764	2017-08-07 08:57:00+03	85000.00
CCF795	2017-08-01 10:03:00+03	19600.00
CCF7A7	2017-07-06 13:13:00+03	27200.00
CCF7AE	2017-07-25 23:27:00+03	102100.00
CCF7BA	2017-08-02 13:28:00+03	43200.00
CCF7F2	2017-07-30 15:47:00+03	165200.00
CCF7F7	2017-07-04 11:54:00+03	36200.00
CCF811	2017-07-22 21:15:00+03	44000.00
CCF846	2017-07-02 05:43:00+03	125100.00
CCF893	2017-08-15 01:10:00+03	38800.00
CCF8E0	2017-07-17 04:37:00+03	39200.00
CCF8EE	2017-08-06 02:30:00+03	7200.00
CCF8F1	2017-07-26 00:51:00+03	93100.00
CCF91F	2017-07-27 08:35:00+03	196800.00
CCF99F	2017-07-12 15:31:00+03	23200.00
CCF9E4	2017-08-15 13:50:00+03	123000.00
CCFAFB	2017-07-27 23:48:00+03	117900.00
CCFB0D	2017-07-19 16:58:00+03	147700.00
CCFB3C	2017-07-23 19:04:00+03	54400.00
CCFB56	2017-08-08 22:34:00+03	92900.00
CCFB8E	2017-07-02 00:28:00+03	96800.00
CCFBEE	2017-07-21 12:49:00+03	32700.00
CCFC1F	2017-08-08 09:21:00+03	92800.00
CCFC7A	2017-08-07 03:17:00+03	82900.00
CCFCBD	2017-07-21 12:25:00+03	69500.00
CCFCC2	2017-07-19 19:52:00+03	38800.00
CCFCD8	2017-08-15 15:22:00+03	290400.00
CCFCDB	2017-08-10 06:33:00+03	56000.00
CCFD09	2017-08-03 21:18:00+03	26000.00
CCFD1C	2017-07-06 16:59:00+03	40600.00
CCFD97	2017-08-03 14:43:00+03	81500.00
CCFD99	2017-07-09 16:42:00+03	36400.00
CCFDB3	2017-07-20 00:39:00+03	7400.00
CCFDDA	2017-07-29 22:11:00+03	61500.00
CCFDF7	2017-08-15 00:07:00+03	54500.00
CCFDFD	2017-08-12 02:12:00+03	6700.00
CCFE30	2017-08-01 17:35:00+03	128800.00
CCFE45	2017-07-15 09:30:00+03	46300.00
CCFE66	2017-07-07 06:47:00+03	90400.00
CCFE69	2017-08-15 06:52:00+03	25000.00
CCFEAE	2017-07-29 04:53:00+03	281500.00
CCFEB8	2017-07-23 16:22:00+03	81200.00
CCFF1E	2017-08-09 05:00:00+03	212900.00
CCFF4C	2017-07-11 13:01:00+03	69500.00
CCFF63	2017-07-25 00:43:00+03	28000.00
CCFFB2	2017-08-02 17:06:00+03	23200.00
CCFFB4	2017-07-15 00:59:00+03	96400.00
CCFFCF	2017-07-05 13:19:00+03	36200.00
CD0039	2017-07-28 18:43:00+03	174400.00
CD0057	2017-07-04 13:06:00+03	111600.00
CD0059	2017-08-09 09:30:00+03	43800.00
CD007D	2017-07-29 05:28:00+03	72300.00
CD0083	2017-08-13 07:05:00+03	22000.00
CD00C6	2017-07-11 16:53:00+03	39500.00
CD00FA	2017-07-07 02:12:00+03	386400.00
CD012F	2017-08-13 14:55:00+03	18600.00
CD01E6	2017-07-02 07:42:00+03	12200.00
CD0214	2017-08-11 02:24:00+03	119400.00
CD0222	2017-07-13 15:53:00+03	196000.00
CD0276	2017-07-26 03:03:00+03	26000.00
CD0286	2017-07-09 03:09:00+03	81300.00
CD030E	2017-08-02 18:01:00+03	36200.00
CD03D5	2017-07-25 22:08:00+03	103500.00
CD043A	2017-08-06 23:33:00+03	32600.00
CD043D	2017-07-24 16:12:00+03	56900.00
CD0451	2017-07-20 09:26:00+03	28800.00
CD0453	2017-08-03 09:32:00+03	28000.00
CD049E	2017-08-02 17:24:00+03	130400.00
CD04A6	2017-07-23 16:05:00+03	67100.00
CD04D1	2017-08-12 04:14:00+03	51200.00
CD055D	2017-07-21 08:03:00+03	27200.00
CD0649	2017-08-14 03:14:00+03	46400.00
CD06FB	2017-07-17 11:01:00+03	61800.00
CD0716	2017-07-09 03:48:00+03	156500.00
CD0789	2017-07-15 14:08:00+03	20200.00
CD07DB	2017-08-06 00:37:00+03	99300.00
CD0840	2017-07-19 06:31:00+03	28800.00
CD084B	2017-08-02 16:51:00+03	236000.00
CD084D	2017-07-11 01:28:00+03	25600.00
CD08E3	2017-07-08 18:32:00+03	24400.00
CD08F0	2017-07-20 07:46:00+03	59800.00
CD092A	2017-08-14 05:21:00+03	52700.00
CD0939	2017-07-26 02:58:00+03	347100.00
CD0981	2017-08-08 18:42:00+03	25400.00
CD09B2	2017-08-14 04:41:00+03	13400.00
CD09C6	2017-07-24 13:58:00+03	184500.00
CD0A71	2017-08-01 01:08:00+03	15000.00
CD0A8C	2017-07-09 20:11:00+03	40600.00
CD0B6F	2017-08-01 23:14:00+03	168200.00
CD0B95	2017-07-02 13:50:00+03	24400.00
CD0C3E	2017-07-05 08:02:00+03	69600.00
CD0C83	2017-08-11 15:22:00+03	53200.00
CD0CCD	2017-07-28 14:19:00+03	114800.00
CD0CD6	2017-07-20 09:25:00+03	12400.00
CD0D16	2017-07-06 00:22:00+03	37200.00
CD0D37	2017-07-23 19:16:00+03	43500.00
CD0DB9	2017-07-24 01:21:00+03	73500.00
CD0DDF	2017-08-12 13:26:00+03	182300.00
CD0DE6	2017-07-04 18:00:00+03	270600.00
CD0E40	2017-06-28 06:54:00+03	26800.00
CD0F3E	2017-07-25 18:28:00+03	38200.00
CD0FC3	2017-07-22 19:23:00+03	266400.00
CD0FD9	2017-07-12 23:24:00+03	131600.00
CD1032	2017-08-15 14:01:00+03	28000.00
CD10C3	2017-08-14 23:38:00+03	55800.00
CD10C4	2017-07-17 06:14:00+03	57500.00
CD10F4	2017-07-07 14:21:00+03	55800.00
CD10F7	2017-07-19 12:04:00+03	164400.00
CD114B	2017-07-23 12:07:00+03	46800.00
CD115A	2017-08-12 10:11:00+03	38400.00
CD115F	2017-07-10 04:55:00+03	246000.00
CD11E9	2017-08-02 22:50:00+03	28000.00
CD11FD	2017-07-20 12:03:00+03	23200.00
CD1203	2017-08-10 05:17:00+03	99300.00
CD125F	2017-08-05 03:49:00+03	100600.00
CD1287	2017-07-20 02:30:00+03	66000.00
CD12DF	2017-07-06 23:06:00+03	29100.00
CD130A	2017-08-06 21:17:00+03	6000.00
CD131F	2017-08-09 13:56:00+03	14400.00
CD1325	2017-07-20 15:53:00+03	90100.00
CD132E	2017-08-06 02:05:00+03	23600.00
CD1337	2017-07-23 03:37:00+03	19600.00
CD1365	2017-08-08 06:51:00+03	112000.00
CD13AD	2017-08-07 00:44:00+03	146100.00
CD13DA	2017-07-10 00:23:00+03	114600.00
CD1432	2017-07-22 07:01:00+03	25800.00
CD1449	2017-08-10 17:01:00+03	52300.00
CD1455	2017-07-09 19:31:00+03	23200.00
CD14AF	2017-07-25 09:18:00+03	129700.00
CD1500	2017-06-29 22:03:00+03	42400.00
CD152A	2017-08-13 16:09:00+03	64700.00
CD15DA	2017-07-23 20:52:00+03	51200.00
CD15E5	2017-07-29 07:09:00+03	23600.00
CD15FA	2017-07-07 17:34:00+03	11700.00
CD1638	2017-07-09 16:29:00+03	81800.00
CD1639	2017-07-06 01:09:00+03	35800.00
CD164A	2017-07-06 20:58:00+03	10800.00
CD1659	2017-08-04 00:32:00+03	56900.00
CD165D	2017-08-08 21:03:00+03	381400.00
CD16D9	2017-07-07 11:29:00+03	23600.00
CD16DA	2017-07-13 10:18:00+03	31600.00
CD1734	2017-08-15 04:55:00+03	6000.00
CD173E	2017-07-01 20:32:00+03	61500.00
CD1749	2017-07-20 06:00:00+03	87000.00
CD1754	2017-07-19 01:37:00+03	24300.00
CD1788	2017-08-07 09:50:00+03	95200.00
CD17C4	2017-08-09 10:17:00+03	50400.00
CD17EB	2017-07-14 11:56:00+03	28000.00
CD1824	2017-07-30 21:31:00+03	52400.00
CD1825	2017-07-11 18:59:00+03	64200.00
CD1876	2017-07-22 23:59:00+03	46300.00
CD18A4	2017-08-01 23:13:00+03	75300.00
CD18E1	2017-07-02 10:02:00+03	24600.00
CD1913	2017-08-08 17:41:00+03	183100.00
CD1965	2017-07-23 21:43:00+03	56900.00
CD19E4	2017-08-14 01:04:00+03	239900.00
CD1A3C	2017-07-24 03:36:00+03	388900.00
CD1A5A	2017-07-05 22:56:00+03	58000.00
CD1A70	2017-07-28 23:25:00+03	29600.00
CD1AAD	2017-07-05 21:36:00+03	174400.00
CD1B36	2017-07-11 11:29:00+03	155600.00
CD1BCE	2017-07-27 19:16:00+03	28800.00
CD1BD3	2017-07-04 14:34:00+03	68600.00
CD1C23	2017-07-27 01:51:00+03	76600.00
CD1C59	2017-07-09 01:30:00+03	14000.00
CD1C95	2017-07-14 16:23:00+03	65900.00
CD1CBF	2017-07-05 13:55:00+03	12600.00
CD1CE0	2017-07-14 03:51:00+03	67700.00
CD1CE9	2017-07-15 20:06:00+03	94700.00
CD1D05	2017-07-24 06:29:00+03	128800.00
CD1E1D	2017-07-15 22:57:00+03	369000.00
CD1E45	2017-08-09 15:15:00+03	31100.00
CD1E5D	2017-07-09 23:00:00+03	94500.00
CD1E95	2017-07-06 22:33:00+03	131000.00
CD1E9D	2017-08-15 04:41:00+03	128800.00
CD1EF1	2017-07-17 02:23:00+03	24400.00
CD1EF5	2017-08-13 21:17:00+03	21200.00
CD1EFF	2017-07-22 19:28:00+03	92600.00
CD1F58	2017-07-04 02:51:00+03	31000.00
CD1FC1	2017-08-13 03:00:00+03	28000.00
CD2040	2017-08-12 10:04:00+03	209700.00
CD20A0	2017-07-23 06:09:00+03	101200.00
CD20C8	2017-06-30 16:27:00+03	200700.00
CD2107	2017-07-30 14:03:00+03	406700.00
CD2113	2017-07-30 16:39:00+03	34000.00
CD2139	2017-07-24 01:24:00+03	79100.00
CD2142	2017-08-15 13:50:00+03	95600.00
CD21EB	2017-08-14 23:32:00+03	14900.00
CD2223	2017-07-24 23:01:00+03	68800.00
CD2249	2017-07-13 12:21:00+03	187800.00
CD2276	2017-08-15 13:26:00+03	37000.00
CD22A5	2017-07-24 13:54:00+03	71200.00
CD22B3	2017-07-19 21:09:00+03	86500.00
CD22F9	2017-07-08 08:57:00+03	44500.00
CD231E	2017-08-08 21:07:00+03	183600.00
CD2342	2017-07-30 21:34:00+03	56000.00
CD23D1	2017-07-13 00:48:00+03	51900.00
CD2466	2017-07-28 03:00:00+03	139300.00
CD249A	2017-07-04 06:37:00+03	38600.00
CD2569	2017-08-06 20:09:00+03	122300.00
CD256E	2017-07-05 15:39:00+03	92800.00
CD2578	2017-08-14 09:55:00+03	39800.00
CD2598	2017-07-19 08:50:00+03	46300.00
CD25DA	2017-07-11 05:15:00+03	272400.00
CD262E	2017-08-13 05:51:00+03	81500.00
CD264C	2017-08-02 12:54:00+03	15100.00
CD267E	2017-08-08 18:45:00+03	76900.00
CD2693	2017-07-22 20:43:00+03	133200.00
CD26A2	2017-07-23 10:36:00+03	38400.00
CD26F1	2017-07-06 01:45:00+03	39200.00
CD2745	2017-08-07 13:44:00+03	86800.00
CD2762	2017-07-14 17:52:00+03	56000.00
CD276D	2017-07-12 12:21:00+03	41200.00
CD2790	2017-07-21 01:46:00+03	131100.00
CD27C6	2017-07-02 14:37:00+03	27600.00
CD27CC	2017-07-02 02:39:00+03	23200.00
CD2803	2017-08-09 04:29:00+03	67400.00
CD289B	2017-07-28 11:55:00+03	66400.00
CD2905	2017-07-10 22:31:00+03	97900.00
CD2922	2017-07-02 02:05:00+03	34100.00
CD298A	2017-08-02 01:14:00+03	111600.00
CD29BD	2017-07-27 15:06:00+03	55800.00
CD29C1	2017-07-11 16:22:00+03	111200.00
CD29E3	2017-08-04 06:01:00+03	187900.00
CD29F3	2017-08-01 22:15:00+03	406600.00
CD2AD1	2017-07-17 05:15:00+03	116400.00
CD2AE1	2017-07-25 03:05:00+03	77900.00
CD2BB0	2017-07-20 05:59:00+03	26000.00
CD2BDD	2017-08-09 01:45:00+03	171900.00
CD2BED	2017-07-08 18:58:00+03	32200.00
CD2C0B	2017-08-04 11:26:00+03	91500.00
CD2C3E	2017-08-13 07:34:00+03	72800.00
CD2C6D	2017-08-03 13:14:00+03	12600.00
CD2CCC	2017-08-10 23:31:00+03	93600.00
CD2D19	2017-08-02 06:24:00+03	46400.00
CD2D2A	2017-08-08 04:53:00+03	147700.00
CD2D39	2017-08-11 12:20:00+03	31600.00
CD2DB0	2017-08-07 18:30:00+03	62600.00
CD2DF9	2017-06-27 12:59:00+03	57800.00
CD2DFD	2017-08-14 16:47:00+03	48700.00
CD2EE2	2017-08-13 22:15:00+03	20000.00
CD2EFB	2017-07-19 15:02:00+03	192400.00
CD2F18	2017-07-18 21:20:00+03	59800.00
CD2F58	2017-07-14 19:41:00+03	14800.00
CD2FC7	2017-07-07 15:52:00+03	117000.00
CD30B9	2017-07-04 20:34:00+03	67600.00
CD3125	2017-07-14 09:43:00+03	8200.00
CD317B	2017-08-15 11:09:00+03	28000.00
CD31D3	2017-07-16 11:56:00+03	45200.00
CD31E1	2017-08-15 14:40:00+03	87100.00
CD320E	2017-07-26 02:59:00+03	105100.00
CD3217	2017-08-10 06:30:00+03	131600.00
CD3245	2017-08-09 03:05:00+03	118500.00
CD324B	2017-07-14 01:09:00+03	56000.00
CD3276	2017-07-16 09:56:00+03	54500.00
CD32A0	2017-07-11 17:51:00+03	12600.00
CD32EF	2017-07-28 01:35:00+03	24200.00
CD331B	2017-07-19 01:14:00+03	43000.00
CD3320	2017-08-04 22:29:00+03	56000.00
CD3330	2017-08-02 05:54:00+03	40000.00
CD3333	2017-07-01 15:12:00+03	295400.00
CD333C	2017-08-08 14:10:00+03	25800.00
CD3343	2017-08-14 03:53:00+03	42800.00
CD3378	2017-07-23 00:38:00+03	89200.00
CD3396	2017-08-04 12:21:00+03	177600.00
CD33CE	2017-07-17 23:16:00+03	31600.00
CD341C	2017-08-13 14:35:00+03	260300.00
CD3470	2017-07-08 04:07:00+03	112600.00
CD349F	2017-07-18 03:28:00+03	75600.00
CD34C4	2017-07-14 19:44:00+03	63700.00
CD351A	2017-08-04 05:02:00+03	32800.00
CD353F	2017-08-14 04:04:00+03	119500.00
CD3553	2017-07-22 05:31:00+03	138900.00
CD3579	2017-07-25 13:28:00+03	55800.00
CD35D5	2017-07-11 20:15:00+03	62800.00
CD35E8	2017-08-01 04:17:00+03	114400.00
CD35EB	2017-08-15 14:52:00+03	118300.00
CD3721	2017-07-30 23:29:00+03	88900.00
CD3779	2017-07-11 20:06:00+03	52000.00
CD380A	2017-07-18 21:58:00+03	134400.00
CD380C	2017-08-06 11:59:00+03	27200.00
CD3892	2017-07-23 17:39:00+03	40100.00
CD38C5	2017-08-02 23:58:00+03	56100.00
CD38EF	2017-08-04 23:26:00+03	69100.00
CD3964	2017-07-15 15:26:00+03	152700.00
CD3977	2017-08-13 04:29:00+03	29300.00
CD39AC	2017-08-06 23:26:00+03	82900.00
CD39DC	2017-07-29 00:58:00+03	7400.00
CD39EA	2017-07-28 15:26:00+03	115400.00
CD39F4	2017-08-14 10:48:00+03	77200.00
CD3A29	2017-07-27 06:38:00+03	420500.00
CD3A6A	2017-08-10 10:32:00+03	58600.00
CD3AA9	2017-07-05 12:16:00+03	21200.00
CD3AD1	2017-07-02 12:11:00+03	129400.00
CD3B1B	2017-07-23 13:24:00+03	31400.00
CD3B25	2017-08-11 14:58:00+03	23400.00
CD3B9C	2017-06-29 06:18:00+03	36200.00
CD3BE1	2017-08-14 13:42:00+03	60600.00
CD3BF6	2017-06-27 00:59:00+03	23200.00
CD3C1D	2017-08-05 18:55:00+03	65200.00
CD3C5A	2017-08-12 01:15:00+03	12600.00
CD3C5B	2017-07-12 18:30:00+03	110500.00
CD3C98	2017-08-05 10:02:00+03	64600.00
CD3CFE	2017-07-07 23:50:00+03	56000.00
CD3D33	2017-08-15 01:27:00+03	28000.00
CD3E13	2017-07-17 15:52:00+03	13600.00
CD3E50	2017-07-26 09:46:00+03	155600.00
CD3E69	2017-06-30 17:34:00+03	133300.00
CD3EEE	2017-08-04 08:40:00+03	48800.00
CD3F2F	2017-08-08 04:57:00+03	46400.00
CD3F65	2017-08-06 13:59:00+03	242200.00
CD3F76	2017-07-19 03:17:00+03	69500.00
CD3F78	2017-07-15 15:18:00+03	89700.00
CD4012	2017-08-09 18:12:00+03	41500.00
CD4016	2017-08-13 13:35:00+03	11600.00
CD4060	2017-07-05 21:25:00+03	86600.00
CD408D	2017-08-11 13:45:00+03	47600.00
CD40C8	2017-07-31 05:48:00+03	56600.00
CD4102	2017-07-29 01:53:00+03	26700.00
CD4104	2017-08-05 19:28:00+03	131100.00
CD41FD	2017-07-14 11:18:00+03	34100.00
CD4240	2017-07-20 04:15:00+03	27400.00
CD4251	2017-06-29 03:04:00+03	47600.00
CD42BB	2017-08-11 21:29:00+03	95200.00
CD430A	2017-07-03 12:11:00+03	92800.00
CD4312	2017-08-10 13:32:00+03	48700.00
CD433E	2017-07-12 04:53:00+03	32800.00
CD438F	2017-07-07 10:54:00+03	19400.00
CD43DA	2017-07-11 02:48:00+03	71400.00
CD4402	2017-08-14 08:02:00+03	26700.00
CD44B7	2017-07-04 01:07:00+03	271200.00
CD44E4	2017-08-05 22:58:00+03	55500.00
CD450C	2017-07-16 12:12:00+03	68000.00
CD4569	2017-07-23 05:28:00+03	144400.00
CD4666	2017-06-30 20:16:00+03	49100.00
CD4761	2017-08-01 02:02:00+03	248400.00
CD4888	2017-07-10 01:34:00+03	96400.00
CD4957	2017-08-13 15:21:00+03	15000.00
CD4958	2017-07-03 11:43:00+03	282300.00
CD4983	2017-08-03 21:58:00+03	278600.00
CD4985	2017-07-04 07:27:00+03	45600.00
CD49AB	2017-07-12 05:19:00+03	67200.00
CD49AE	2017-07-31 01:47:00+03	40800.00
CD49E9	2017-07-14 22:33:00+03	136600.00
CD4A6E	2017-07-19 05:23:00+03	12600.00
CD4AA9	2017-07-21 14:21:00+03	106400.00
CD4ADE	2017-07-27 08:01:00+03	34100.00
CD4AE2	2017-08-13 14:34:00+03	282100.00
CD4AEE	2017-07-26 10:19:00+03	46400.00
CD4AEF	2017-06-30 09:44:00+03	75300.00
CD4AF5	2017-07-05 06:21:00+03	90800.00
CD4B9A	2017-08-11 08:33:00+03	22000.00
CD4BA0	2017-08-06 19:13:00+03	6800.00
CD4BCD	2017-07-18 02:23:00+03	12000.00
CD4BF2	2017-07-07 17:53:00+03	193700.00
CD4C41	2017-07-22 04:01:00+03	131900.00
CD4C65	2017-07-27 10:43:00+03	189200.00
CD4C66	2017-08-04 04:35:00+03	111600.00
CD4C67	2017-08-09 19:01:00+03	240600.00
CD4CA1	2017-07-14 07:22:00+03	226200.00
CD4CC7	2017-08-09 19:04:00+03	221800.00
CD4CD1	2017-08-12 16:40:00+03	43800.00
CD4D2A	2017-07-17 16:03:00+03	119500.00
CD4D42	2017-08-10 07:08:00+03	14000.00
CD4D4F	2017-07-08 21:23:00+03	86300.00
CD4D5B	2017-07-25 16:03:00+03	60900.00
CD4D9F	2017-08-06 17:55:00+03	116800.00
CD4DEA	2017-07-31 06:35:00+03	65000.00
CD4DFD	2017-07-13 22:35:00+03	12400.00
CD4E14	2017-06-26 02:28:00+03	273500.00
CD4E15	2017-07-31 03:58:00+03	56000.00
CD4E94	2017-07-10 06:04:00+03	28800.00
CD4ED3	2017-08-01 05:06:00+03	15400.00
CD4F04	2017-07-30 07:59:00+03	22000.00
CD4F19	2017-07-15 04:27:00+03	67700.00
CD4FA1	2017-07-28 18:53:00+03	99700.00
CD4FA8	2017-07-10 09:17:00+03	83100.00
CD509B	2017-07-11 18:47:00+03	212000.00
CD50A8	2017-07-23 13:01:00+03	43200.00
CD50AC	2017-07-30 04:01:00+03	64100.00
CD50C9	2017-07-12 14:32:00+03	49600.00
CD50D4	2017-07-04 20:41:00+03	67200.00
CD50F0	2017-08-05 19:23:00+03	95600.00
CD5157	2017-07-22 01:15:00+03	65900.00
CD518D	2017-07-06 22:30:00+03	70700.00
CD519A	2017-08-07 16:05:00+03	25400.00
CD51AB	2017-07-30 22:44:00+03	28000.00
CD51EA	2017-08-13 05:41:00+03	131100.00
CD5203	2017-07-09 04:25:00+03	265600.00
CD5230	2017-07-14 00:21:00+03	9800.00
CD5286	2017-07-06 09:39:00+03	9200.00
CD52B2	2017-07-29 19:14:00+03	45100.00
CD52B9	2017-07-13 17:00:00+03	56600.00
CD52CE	2017-08-07 01:32:00+03	42000.00
CD52E4	2017-08-10 23:04:00+03	67600.00
CD52F3	2017-08-11 01:25:00+03	85000.00
CD5391	2017-08-03 11:33:00+03	52700.00
CD53C1	2017-07-15 06:44:00+03	36200.00
CD53D6	2017-07-11 20:18:00+03	111600.00
CD549A	2017-07-07 20:58:00+03	48000.00
CD54AD	2017-08-07 09:50:00+03	211000.00
CD54BB	2017-07-06 11:08:00+03	48100.00
CD54BE	2017-07-01 07:32:00+03	35600.00
CD5524	2017-07-07 05:46:00+03	55600.00
CD554D	2017-07-13 07:43:00+03	92800.00
CD55CA	2017-07-13 20:04:00+03	209700.00
CD5646	2017-07-11 16:11:00+03	117200.00
CD5657	2017-07-08 11:36:00+03	170200.00
CD56B5	2017-07-24 15:43:00+03	67600.00
CD56D5	2017-07-25 14:46:00+03	684700.00
CD5752	2017-08-03 20:02:00+03	78600.00
CD57C0	2017-07-03 20:47:00+03	40600.00
CD57C5	2017-07-02 12:38:00+03	131100.00
CD57C7	2017-07-14 07:37:00+03	17600.00
CD57F8	2017-08-13 02:53:00+03	26700.00
CD5806	2017-07-05 11:20:00+03	290500.00
CD5812	2017-08-06 10:46:00+03	64100.00
CD582C	2017-07-25 01:04:00+03	132100.00
CD5854	2017-07-28 16:43:00+03	46500.00
CD592E	2017-08-03 04:43:00+03	55800.00
CD59B6	2017-08-11 20:02:00+03	223400.00
CD59DC	2017-08-15 13:27:00+03	54800.00
CD5A31	2017-07-18 07:44:00+03	14400.00
CD5AC8	2017-08-09 11:41:00+03	99200.00
CD5AD2	2017-06-28 20:59:00+03	89600.00
CD5B1B	2017-07-13 02:32:00+03	25600.00
CD5B27	2017-08-06 16:15:00+03	139400.00
CD5B87	2017-07-04 08:33:00+03	11100.00
CD5B89	2017-07-06 09:38:00+03	50600.00
CD5C03	2017-07-26 21:34:00+03	56000.00
CD5C37	2017-08-12 13:26:00+03	134000.00
CD5D35	2017-08-11 03:40:00+03	132800.00
CD5E06	2017-08-04 09:14:00+03	27200.00
CD5E63	2017-08-08 02:35:00+03	202400.00
CD5EBA	2017-07-16 01:00:00+03	75300.00
CD5ECE	2017-07-14 23:45:00+03	26000.00
CD5F3C	2017-07-06 21:13:00+03	65800.00
CD5FB4	2017-07-24 04:47:00+03	9200.00
CD5FB7	2017-08-05 22:13:00+03	119700.00
CD605D	2017-07-31 16:21:00+03	23200.00
CD6092	2017-07-07 22:56:00+03	248400.00
CD60DC	2017-07-24 00:37:00+03	384000.00
CD610B	2017-08-02 21:22:00+03	20200.00
CD6133	2017-08-15 09:03:00+03	20200.00
CD6253	2017-07-11 11:52:00+03	28800.00
CD629D	2017-08-06 11:59:00+03	189200.00
CD6326	2017-07-29 22:02:00+03	185300.00
CD63B8	2017-08-06 00:03:00+03	12600.00
CD63D9	2017-07-28 16:42:00+03	139200.00
CD64A5	2017-07-25 16:49:00+03	70800.00
CD64B0	2017-07-04 03:51:00+03	21400.00
CD6512	2017-08-14 14:31:00+03	50000.00
CD6580	2017-08-12 08:40:00+03	166900.00
CD658E	2017-07-09 01:49:00+03	100600.00
CD65EE	2017-07-07 08:17:00+03	9300.00
CD65FE	2017-08-08 08:31:00+03	53400.00
CD6644	2017-07-20 20:05:00+03	36200.00
CD669F	2017-07-10 19:58:00+03	67100.00
CD6711	2017-07-12 09:51:00+03	174000.00
CD6794	2017-07-13 04:35:00+03	110000.00
CD67A2	2017-07-30 18:18:00+03	31200.00
CD67A9	2017-07-20 06:46:00+03	46400.00
CD67B4	2017-08-09 01:29:00+03	90600.00
CD67B5	2017-08-14 23:15:00+03	23200.00
CD67CC	2017-08-14 08:22:00+03	56100.00
CD683F	2017-07-20 04:30:00+03	27400.00
CD684D	2017-07-04 12:51:00+03	68200.00
CD68F6	2017-08-01 05:43:00+03	89600.00
CD6913	2017-07-09 21:15:00+03	26000.00
CD6947	2017-08-08 07:13:00+03	28000.00
CD6975	2017-08-08 22:51:00+03	51900.00
CD6989	2017-08-13 23:26:00+03	92100.00
CD69D7	2017-08-06 05:30:00+03	75600.00
CD69E4	2017-08-13 23:31:00+03	149000.00
CD6A7D	2017-06-28 18:32:00+03	64400.00
CD6AE4	2017-08-14 20:20:00+03	34000.00
CD6B04	2017-08-06 02:37:00+03	61900.00
CD6B20	2017-07-22 12:00:00+03	13300.00
CD6B24	2017-07-08 08:32:00+03	47600.00
CD6B58	2017-07-15 21:10:00+03	134700.00
CD6BA2	2017-07-03 17:13:00+03	6700.00
CD6C58	2017-07-03 11:33:00+03	131600.00
CD6C85	2017-07-23 04:51:00+03	13400.00
CD6C8A	2017-08-09 18:47:00+03	34600.00
CD6CF6	2017-07-18 16:15:00+03	22100.00
CD6D39	2017-07-15 10:10:00+03	108000.00
CD6D5B	2017-07-31 08:12:00+03	286900.00
CD6D60	2017-07-20 14:27:00+03	23400.00
CD6D8C	2017-08-10 02:13:00+03	142300.00
CD6DA0	2017-08-05 05:55:00+03	36400.00
CD6DAA	2017-07-28 22:41:00+03	61200.00
CD6E16	2017-07-08 20:20:00+03	36400.00
CD6E60	2017-07-10 08:30:00+03	52700.00
CD6E76	2017-08-07 10:44:00+03	14800.00
CD6E8A	2017-07-19 23:09:00+03	135200.00
CD6E93	2017-07-26 21:15:00+03	53500.00
CD6EAA	2017-07-04 16:29:00+03	102100.00
CD6EC2	2017-08-13 04:50:00+03	23400.00
CD6EDB	2017-07-15 03:20:00+03	60400.00
CD6FDF	2017-07-22 12:01:00+03	37900.00
CD6FFE	2017-07-13 04:48:00+03	21800.00
CD7021	2017-07-05 07:29:00+03	123000.00
CD702D	2017-07-28 16:35:00+03	21200.00
CD7038	2017-07-21 11:19:00+03	33500.00
CD7067	2017-06-26 14:04:00+03	54000.00
CD70B6	2017-08-14 06:46:00+03	63200.00
CD70E2	2017-08-10 04:45:00+03	201200.00
CD7105	2017-07-29 09:13:00+03	96800.00
CD7128	2017-08-06 09:50:00+03	53700.00
CD717B	2017-07-25 01:02:00+03	49600.00
CD7234	2017-08-10 15:33:00+03	18000.00
CD726A	2017-06-30 17:55:00+03	58000.00
CD726B	2017-07-21 05:51:00+03	32800.00
CD72A8	2017-07-10 01:24:00+03	104000.00
CD72AA	2017-08-09 03:48:00+03	375200.00
CD72D2	2017-07-04 08:05:00+03	49100.00
CD72D7	2017-08-03 09:16:00+03	65500.00
CD731F	2017-08-09 05:55:00+03	100700.00
CD7341	2017-08-14 06:14:00+03	6000.00
CD73B1	2017-07-18 03:35:00+03	6600.00
CD7434	2017-07-07 19:45:00+03	258400.00
CD7468	2017-07-16 18:20:00+03	7400.00
CD749B	2017-07-19 03:16:00+03	496700.00
CD749D	2017-07-18 02:44:00+03	21400.00
CD74A0	2017-08-08 20:48:00+03	272400.00
CD7512	2017-07-27 14:50:00+03	21400.00
CD755F	2017-07-09 15:37:00+03	200000.00
CD75B2	2017-07-31 10:09:00+03	92400.00
CD763D	2017-07-08 23:57:00+03	25100.00
CD76A7	2017-08-09 06:18:00+03	56000.00
CD76AA	2017-07-23 01:41:00+03	67200.00
CD76C8	2017-07-14 09:08:00+03	31600.00
CD770A	2017-08-13 08:34:00+03	13400.00
CD7733	2017-07-13 23:58:00+03	223200.00
CD775A	2017-07-09 10:17:00+03	32800.00
CD7788	2017-08-14 10:19:00+03	234900.00
CD77AF	2017-08-05 13:27:00+03	96800.00
CD77CE	2017-07-08 02:17:00+03	55800.00
CD780F	2017-07-25 00:14:00+03	46400.00
CD78E1	2017-07-22 07:04:00+03	189000.00
CD790B	2017-07-05 10:16:00+03	73600.00
CD7972	2017-08-11 02:06:00+03	93900.00
CD7977	2017-08-04 15:53:00+03	51200.00
CD7983	2017-08-15 15:22:00+03	18700.00
CD79CF	2017-08-15 05:20:00+03	205000.00
CD79F9	2017-07-27 23:36:00+03	37900.00
CD7A33	2017-08-01 19:29:00+03	51900.00
CD7AF8	2017-08-05 00:40:00+03	39800.00
CD7B0A	2017-06-28 02:53:00+03	43400.00
CD7B29	2017-08-12 17:14:00+03	113800.00
CD7B73	2017-08-09 16:39:00+03	244800.00
CD7BCB	2017-07-22 04:57:00+03	16800.00
CD7BDA	2017-08-02 00:41:00+03	117700.00
CD7BF1	2017-07-02 01:30:00+03	16400.00
CD7C72	2017-08-07 09:10:00+03	41900.00
CD7D5D	2017-08-07 21:55:00+03	29600.00
CD7D81	2017-07-26 20:58:00+03	23000.00
CD7DC5	2017-08-15 13:38:00+03	80900.00
CD7DFA	2017-08-13 21:52:00+03	93900.00
CD7E02	2017-07-07 23:51:00+03	31400.00
CD7E11	2017-07-03 16:02:00+03	28800.00
CD7E52	2017-07-25 06:23:00+03	41800.00
CD7E70	2017-07-15 08:06:00+03	26600.00
CD7E73	2017-07-19 20:41:00+03	135600.00
CD7F11	2017-07-30 17:28:00+03	93900.00
CD7F46	2017-08-15 13:52:00+03	38800.00
CD7F57	2017-07-19 05:12:00+03	80000.00
CD7F8F	2017-07-11 11:18:00+03	48600.00
CD7FE4	2017-07-02 13:16:00+03	66600.00
CD8024	2017-07-05 02:55:00+03	249100.00
CD8091	2017-07-02 19:27:00+03	67200.00
CD8099	2017-07-18 01:45:00+03	52000.00
CD80B3	2017-07-17 06:23:00+03	75300.00
CD80CF	2017-07-28 02:53:00+03	42700.00
CD8117	2017-07-17 04:12:00+03	67100.00
CD8126	2017-08-04 11:59:00+03	131600.00
CD8152	2017-08-15 07:11:00+03	399600.00
CD817B	2017-07-22 01:57:00+03	40000.00
CD8188	2017-08-08 21:22:00+03	47400.00
CD8195	2017-08-06 04:45:00+03	111600.00
CD81C0	2017-07-28 06:14:00+03	31400.00
CD81E3	2017-07-28 20:27:00+03	84800.00
CD81EE	2017-07-08 01:10:00+03	23400.00
CD81FC	2017-08-06 22:43:00+03	78300.00
CD825F	2017-07-30 12:38:00+03	23600.00
CD8269	2017-08-03 07:04:00+03	22600.00
CD8274	2017-08-06 21:05:00+03	23200.00
CD82C1	2017-07-10 03:06:00+03	54800.00
CD82C4	2017-08-09 02:25:00+03	136600.00
CD82D3	2017-08-08 03:27:00+03	106900.00
CD8326	2017-07-04 03:10:00+03	70600.00
CD836D	2017-07-17 10:56:00+03	272800.00
CD83CD	2017-07-16 17:27:00+03	98200.00
CD8421	2017-08-13 21:51:00+03	86600.00
CD845A	2017-07-16 21:10:00+03	16400.00
CD8470	2017-08-05 02:31:00+03	249200.00
CD8481	2017-07-23 10:30:00+03	9300.00
CD84DC	2017-07-28 22:34:00+03	25200.00
CD8545	2017-07-09 09:07:00+03	117600.00
CD8552	2017-08-14 15:26:00+03	59800.00
CD857D	2017-07-24 22:16:00+03	78300.00
CD85A1	2017-08-13 11:20:00+03	136200.00
CD85F2	2017-08-11 20:10:00+03	56100.00
CD8615	2017-08-07 19:34:00+03	54500.00
CD865F	2017-07-18 04:02:00+03	544700.00
CD8684	2017-07-20 12:26:00+03	85000.00
CD86BD	2017-07-21 05:37:00+03	29600.00
CD86CF	2017-07-29 08:57:00+03	40800.00
CD86F7	2017-08-08 20:58:00+03	46000.00
CD8779	2017-07-25 07:11:00+03	32800.00
CD87DE	2017-07-28 22:17:00+03	41900.00
CD883F	2017-07-10 17:14:00+03	19600.00
CD8848	2017-06-29 04:23:00+03	125500.00
CD8895	2017-07-11 03:42:00+03	26100.00
CD893D	2017-07-24 23:04:00+03	112000.00
CD896B	2017-07-28 07:16:00+03	70800.00
CD89DB	2017-08-09 11:58:00+03	42800.00
CD8A9E	2017-07-02 22:27:00+03	80800.00
CD8ABC	2017-07-16 22:43:00+03	73600.00
CD8ADC	2017-07-04 22:52:00+03	46400.00
CD8AEB	2017-07-16 10:18:00+03	46200.00
CD8AF6	2017-08-10 15:33:00+03	191000.00
CD8B2C	2017-07-27 18:19:00+03	64200.00
CD8BC3	2017-07-01 21:37:00+03	23600.00
CD8C11	2017-07-17 00:24:00+03	39800.00
CD8C14	2017-07-07 16:24:00+03	8200.00
CD8C23	2017-08-03 18:40:00+03	29200.00
CD8C53	2017-08-13 06:48:00+03	12200.00
CD8C63	2017-06-30 07:04:00+03	123000.00
CD8C67	2017-07-21 17:18:00+03	55800.00
CD8C9A	2017-08-11 01:36:00+03	202400.00
CD8CDA	2017-08-13 11:42:00+03	36800.00
CD8D2C	2017-07-14 21:06:00+03	70100.00
CD8D35	2017-07-04 03:22:00+03	26800.00
CD8D54	2017-07-03 21:09:00+03	62700.00
CD8D74	2017-08-13 10:31:00+03	25400.00
CD8D85	2017-07-15 04:01:00+03	75300.00
CD8DBD	2017-08-04 23:17:00+03	56000.00
CD8E18	2017-07-30 12:28:00+03	93500.00
CD8E23	2017-08-06 09:19:00+03	125500.00
CD8E2A	2017-08-11 04:17:00+03	47600.00
CD8E31	2017-08-11 12:33:00+03	23600.00
CD8E5A	2017-08-11 12:49:00+03	620800.00
CD8EA5	2017-07-31 09:14:00+03	114800.00
CD8F1F	2017-07-09 13:58:00+03	126600.00
CD8F2C	2017-07-05 22:32:00+03	43000.00
CD8F2F	2017-07-23 05:36:00+03	146900.00
CD8FAA	2017-08-14 09:47:00+03	89200.00
CD8FB2	2017-08-06 11:46:00+03	7400.00
CD8FCA	2017-07-24 11:50:00+03	31200.00
CD8FF2	2017-07-11 00:47:00+03	30400.00
CD901C	2017-07-23 23:26:00+03	20900.00
CD903B	2017-07-22 06:27:00+03	48800.00
CD907D	2017-07-05 13:09:00+03	66600.00
CD907F	2017-07-02 14:46:00+03	116900.00
CD90A4	2017-07-03 01:55:00+03	32800.00
CD90A5	2017-07-14 19:07:00+03	39200.00
CD9145	2017-06-29 05:57:00+03	37900.00
CD9153	2017-07-19 00:05:00+03	45100.00
CD9160	2017-08-09 06:13:00+03	55600.00
CD91EC	2017-07-25 02:50:00+03	111700.00
CD9221	2017-07-07 15:32:00+03	43600.00
CD9229	2017-07-09 02:24:00+03	25100.00
CD9257	2017-07-29 12:00:00+03	16400.00
CD9320	2017-08-13 06:43:00+03	23600.00
CD932C	2017-07-30 20:09:00+03	84300.00
CD9353	2017-08-01 21:48:00+03	206400.00
CD9388	2017-06-28 16:28:00+03	117200.00
CD941D	2017-07-16 19:10:00+03	59800.00
CD9472	2017-07-31 02:31:00+03	91000.00
CD95C8	2017-07-11 09:18:00+03	14000.00
CD95D5	2017-07-04 07:24:00+03	24200.00
CD9603	2017-07-18 08:13:00+03	92400.00
CD9608	2017-08-01 20:21:00+03	39800.00
CD9668	2017-07-19 16:42:00+03	14400.00
CD96BA	2017-08-15 16:23:00+03	40400.00
CD96E6	2017-07-01 06:05:00+03	37800.00
CD96EC	2017-08-12 13:09:00+03	54400.00
CD96F3	2017-08-01 10:03:00+03	128600.00
CD9714	2017-07-02 13:56:00+03	185600.00
CD9773	2017-06-28 14:51:00+03	136600.00
CD980A	2017-07-14 15:55:00+03	91800.00
CD9827	2017-07-12 23:02:00+03	22000.00
CD982A	2017-08-05 19:54:00+03	28800.00
CD9841	2017-07-18 05:14:00+03	23200.00
CD9850	2017-08-06 13:41:00+03	206800.00
CD9925	2017-07-26 05:18:00+03	21800.00
CD993C	2017-07-31 23:04:00+03	16400.00
CD99A8	2017-07-28 04:43:00+03	135200.00
CD99D5	2017-08-01 00:29:00+03	155700.00
CD99EE	2017-07-22 22:19:00+03	37100.00
CD9A7F	2017-08-03 04:16:00+03	31000.00
CD9A87	2017-07-30 19:59:00+03	37700.00
CD9A9C	2017-07-12 00:36:00+03	61500.00
CD9AD1	2017-08-12 19:22:00+03	111600.00
CD9B0F	2017-07-29 23:25:00+03	65900.00
CD9B6D	2017-07-17 01:49:00+03	52300.00
CD9B79	2017-08-12 20:30:00+03	73000.00
CD9B81	2017-07-25 01:25:00+03	40800.00
CD9BB3	2017-07-06 21:14:00+03	288300.00
CD9BCF	2017-07-12 20:05:00+03	52300.00
CD9BF9	2017-07-14 04:42:00+03	169300.00
CD9C7A	2017-08-11 22:28:00+03	193700.00
CD9CC7	2017-07-09 10:30:00+03	101300.00
CD9D01	2017-07-10 01:55:00+03	29500.00
CD9D02	2017-08-10 04:20:00+03	56000.00
CD9D83	2017-07-25 14:10:00+03	132800.00
CD9D8A	2017-07-04 20:10:00+03	8200.00
CD9D92	2017-07-24 05:24:00+03	111600.00
CD9DB7	2017-07-08 17:49:00+03	28000.00
CD9DD0	2017-07-15 20:38:00+03	173200.00
CD9DE0	2017-07-17 12:56:00+03	53300.00
CD9DF1	2017-07-17 15:38:00+03	32700.00
CD9E0E	2017-08-11 16:19:00+03	30000.00
CD9E63	2017-07-17 20:51:00+03	58200.00
CD9E70	2017-07-11 08:14:00+03	124200.00
CD9E75	2017-07-30 15:15:00+03	28000.00
CD9ECA	2017-07-04 12:48:00+03	135600.00
CD9ED3	2017-07-29 05:53:00+03	90600.00
CD9FDF	2017-07-12 05:26:00+03	23200.00
CDA05F	2017-08-07 05:06:00+03	26000.00
CDA096	2017-07-25 20:01:00+03	26000.00
CDA0C2	2017-07-17 02:03:00+03	48500.00
CDA0DE	2017-07-05 18:39:00+03	76800.00
CDA16C	2017-08-10 11:29:00+03	67600.00
CDA170	2017-07-14 06:33:00+03	65900.00
CDA195	2017-08-14 10:34:00+03	48800.00
CDA1A0	2017-07-16 12:06:00+03	138500.00
CDA1A3	2017-07-07 21:18:00+03	113100.00
CDA1AA	2017-07-15 04:22:00+03	149500.00
CDA1B4	2017-07-28 15:44:00+03	42700.00
CDA1DE	2017-08-11 08:30:00+03	12600.00
CDA1EF	2017-07-28 05:10:00+03	73400.00
CDA1F4	2017-08-14 12:17:00+03	13100.00
CDA21A	2017-08-11 05:48:00+03	23200.00
CDA269	2017-08-12 21:00:00+03	67700.00
CDA271	2017-08-11 06:41:00+03	106400.00
CDA272	2017-07-08 10:35:00+03	26800.00
CDA29C	2017-07-17 20:35:00+03	62400.00
CDA2AA	2017-07-05 16:13:00+03	86400.00
CDA378	2017-08-09 08:20:00+03	16400.00
CDA428	2017-08-11 18:00:00+03	46300.00
CDA4EC	2017-08-14 02:07:00+03	91100.00
CDA502	2017-07-17 20:04:00+03	265800.00
CDA51A	2017-08-09 06:46:00+03	78200.00
CDA53A	2017-07-10 13:21:00+03	246000.00
CDA559	2017-07-03 23:06:00+03	88000.00
CDA55A	2017-07-18 22:15:00+03	38200.00
CDA58E	2017-08-11 22:20:00+03	58200.00
CDA5CC	2017-07-03 23:18:00+03	148200.00
CDA65C	2017-07-12 08:22:00+03	89600.00
CDA6DC	2017-08-10 18:25:00+03	111600.00
CDA6E3	2017-07-27 13:59:00+03	37800.00
CDA708	2017-08-13 16:13:00+03	110800.00
CDA76D	2017-07-21 07:10:00+03	99200.00
CDA772	2017-07-26 07:39:00+03	190100.00
CDA7B9	2017-08-01 18:34:00+03	68400.00
CDA7C6	2017-07-27 07:50:00+03	201200.00
CDA805	2017-08-04 16:13:00+03	62600.00
CDA856	2017-07-09 16:28:00+03	112000.00
CDA88F	2017-07-14 05:51:00+03	77900.00
CDA8AE	2017-07-09 04:01:00+03	148200.00
CDA8C2	2017-07-30 02:51:00+03	156000.00
CDA8CA	2017-08-07 11:32:00+03	38600.00
CDA8E6	2017-07-03 01:50:00+03	182300.00
CDA8FC	2017-07-04 08:42:00+03	135600.00
CDA944	2017-07-16 16:25:00+03	136000.00
CDA951	2017-07-07 02:43:00+03	67200.00
CDA972	2017-07-28 05:12:00+03	15000.00
CDA97C	2017-07-09 10:40:00+03	28800.00
CDA98A	2017-08-09 16:37:00+03	87900.00
CDA9B5	2017-07-18 19:32:00+03	57600.00
CDAA54	2017-07-09 12:52:00+03	174300.00
CDAA73	2017-08-09 09:26:00+03	27200.00
CDAAFD	2017-07-01 15:15:00+03	44600.00
CDAB04	2017-07-27 01:24:00+03	47600.00
CDAB06	2017-07-09 10:26:00+03	158400.00
CDAB0F	2017-07-25 11:23:00+03	118000.00
CDAB2C	2017-08-11 21:16:00+03	46400.00
CDAB71	2017-07-06 08:43:00+03	58600.00
CDAC42	2017-07-31 14:40:00+03	14000.00
CDACB5	2017-07-25 13:20:00+03	182300.00
CDAD15	2017-08-11 11:41:00+03	66600.00
CDADC7	2017-08-14 04:55:00+03	119500.00
CDADD5	2017-08-11 21:26:00+03	116400.00
CDADFA	2017-07-12 18:59:00+03	18400.00
CDAE28	2017-06-30 20:46:00+03	310500.00
CDAE47	2017-06-29 15:48:00+03	48400.00
CDAE71	2017-07-14 14:53:00+03	95600.00
CDAECB	2017-07-22 07:27:00+03	44600.00
CDAED0	2017-08-08 21:50:00+03	14400.00
CDAF61	2017-07-09 23:35:00+03	133600.00
CDB000	2017-07-06 03:39:00+03	40000.00
CDB063	2017-08-12 07:33:00+03	85000.00
CDB148	2017-07-10 15:11:00+03	46300.00
CDB198	2017-07-14 21:47:00+03	59000.00
CDB1EE	2017-07-08 00:40:00+03	23600.00
CDB2C3	2017-07-12 20:56:00+03	68000.00
CDB346	2017-07-31 22:10:00+03	26400.00
CDB374	2017-07-08 21:43:00+03	72400.00
CDB389	2017-07-19 21:53:00+03	103200.00
CDB3A6	2017-07-01 13:51:00+03	49600.00
CDB3A9	2017-07-15 17:34:00+03	70700.00
CDB3B1	2017-07-18 05:34:00+03	24400.00
CDB425	2017-07-15 14:13:00+03	105600.00
CDB4AC	2017-07-22 10:47:00+03	16400.00
CDB50B	2017-07-23 02:58:00+03	36800.00
CDB574	2017-07-22 17:11:00+03	64800.00
CDB5EC	2017-07-06 04:27:00+03	69000.00
CDB639	2017-07-26 01:03:00+03	26800.00
CDB670	2017-07-02 23:09:00+03	75300.00
CDB698	2017-07-29 14:44:00+03	25000.00
CDB6A5	2017-07-27 01:15:00+03	591000.00
CDB7AD	2017-07-27 04:28:00+03	75500.00
CDB7BC	2017-07-23 21:39:00+03	14000.00
CDB7EA	2017-07-20 20:21:00+03	51800.00
CDB7EB	2017-08-07 06:38:00+03	62600.00
CDB821	2017-08-14 14:25:00+03	130400.00
CDB862	2017-08-06 20:43:00+03	231800.00
CDB877	2017-08-07 23:55:00+03	46000.00
CDB87D	2017-08-07 01:00:00+03	37900.00
CDB92A	2017-08-05 03:27:00+03	68800.00
CDB933	2017-07-24 23:04:00+03	75100.00
CDB9C8	2017-07-06 11:25:00+03	398500.00
CDB9F2	2017-07-05 09:37:00+03	21000.00
CDBA56	2017-08-06 19:52:00+03	55800.00
CDBA71	2017-08-10 05:52:00+03	54800.00
CDBAED	2017-07-28 03:58:00+03	46800.00
CDBBE6	2017-08-11 13:44:00+03	69000.00
CDBC0D	2017-08-03 06:24:00+03	140900.00
CDBC4C	2017-08-06 08:28:00+03	22400.00
CDBD08	2017-08-14 09:55:00+03	227400.00
CDBD3A	2017-06-30 13:59:00+03	46400.00
CDBD78	2017-08-10 18:07:00+03	314400.00
CDBD80	2017-07-14 08:27:00+03	21800.00
CDBDDC	2017-08-07 18:41:00+03	32200.00
CDBDDF	2017-08-14 01:35:00+03	40400.00
CDBE15	2017-07-25 18:53:00+03	12400.00
CDBE1C	2017-08-01 09:35:00+03	399600.00
CDBE42	2017-07-06 05:11:00+03	28000.00
CDBEB4	2017-07-10 11:54:00+03	46200.00
CDBF0B	2017-07-14 13:49:00+03	41800.00
CDBF4D	2017-08-09 06:52:00+03	114700.00
CDBF7E	2017-08-02 03:59:00+03	11600.00
CDC00A	2017-07-22 05:27:00+03	55800.00
CDC01A	2017-07-11 10:05:00+03	85000.00
CDC033	2017-08-03 08:14:00+03	98400.00
CDC055	2017-08-13 21:30:00+03	71200.00
CDC098	2017-07-24 19:05:00+03	46200.00
CDC0B1	2017-08-14 07:49:00+03	59600.00
CDC0CC	2017-07-14 13:40:00+03	48800.00
CDC116	2017-07-28 08:35:00+03	68100.00
CDC19C	2017-08-09 20:03:00+03	48800.00
CDC1E1	2017-07-27 03:59:00+03	6000.00
CDC1F2	2017-07-31 07:15:00+03	265700.00
CDC21C	2017-07-25 07:08:00+03	68400.00
CDC231	2017-06-30 17:39:00+03	13400.00
CDC256	2017-08-08 19:22:00+03	28300.00
CDC2C4	2017-07-18 19:30:00+03	155600.00
CDC302	2017-07-08 21:42:00+03	6700.00
CDC310	2017-07-28 11:47:00+03	40000.00
CDC311	2017-08-03 01:02:00+03	231400.00
CDC33F	2017-08-08 21:43:00+03	113100.00
CDC35A	2017-08-09 16:05:00+03	34200.00
CDC371	2017-07-16 11:01:00+03	53600.00
CDC465	2017-07-07 11:49:00+03	38500.00
CDC467	2017-07-10 21:43:00+03	89600.00
CDC49B	2017-08-10 14:39:00+03	43500.00
CDC4B2	2017-08-12 18:08:00+03	57300.00
CDC4B5	2017-07-05 12:22:00+03	117500.00
CDC52D	2017-07-30 23:52:00+03	49100.00
CDC551	2017-07-28 19:36:00+03	26600.00
CDC694	2017-07-29 03:25:00+03	16400.00
CDC69C	2017-08-08 21:48:00+03	111600.00
CDC6B0	2017-08-06 08:08:00+03	73200.00
CDC733	2017-08-03 21:46:00+03	102100.00
CDC7DC	2017-08-15 15:29:00+03	119800.00
CDC87D	2017-08-07 15:04:00+03	81700.00
CDC8F3	2017-07-06 02:10:00+03	12200.00
CDC8FA	2017-07-30 10:57:00+03	124000.00
CDC946	2017-07-31 14:16:00+03	134700.00
CDC97D	2017-08-12 22:40:00+03	25200.00
CDC9BD	2017-08-08 10:15:00+03	28000.00
CDC9FE	2017-07-22 10:10:00+03	278600.00
CDCA37	2017-07-20 22:16:00+03	37900.00
CDCA3D	2017-07-04 04:16:00+03	253200.00
CDCAB6	2017-08-04 01:18:00+03	43000.00
CDCAB8	2017-07-02 00:45:00+03	26000.00
CDCABD	2017-07-08 00:28:00+03	58600.00
CDCADD	2017-07-06 14:51:00+03	44600.00
CDCAFD	2017-07-29 08:12:00+03	41400.00
CDCB12	2017-07-19 18:40:00+03	53500.00
CDCB17	2017-08-14 20:06:00+03	11300.00
CDCB56	2017-07-09 10:07:00+03	211000.00
CDCBD5	2017-08-13 10:58:00+03	199800.00
CDCBD7	2017-07-09 23:10:00+03	16400.00
CDCC46	2017-07-24 00:24:00+03	67700.00
CDCC99	2017-07-23 19:39:00+03	16400.00
CDCCAD	2017-07-03 17:12:00+03	193200.00
CDCCEB	2017-08-06 23:30:00+03	92800.00
CDCCF4	2017-07-04 07:43:00+03	94000.00
CDCD42	2017-07-08 18:23:00+03	28000.00
CDCD83	2017-07-01 21:55:00+03	28300.00
CDCDC4	2017-07-27 14:17:00+03	397700.00
CDCE19	2017-08-04 06:27:00+03	270200.00
CDCE36	2017-07-09 07:30:00+03	48500.00
CDCE71	2017-07-13 20:52:00+03	206400.00
CDCEA6	2017-07-28 11:13:00+03	84300.00
CDCEAA	2017-07-12 00:59:00+03	70500.00
CDCF38	2017-07-15 11:52:00+03	122300.00
CDCF3E	2017-07-30 08:33:00+03	44800.00
CDCF5D	2017-07-05 01:56:00+03	88800.00
CDCF75	2017-07-29 20:21:00+03	6000.00
CDCFB2	2017-07-12 04:20:00+03	47400.00
CDCFBC	2017-08-13 16:38:00+03	6300.00
CDCFC5	2017-08-13 05:43:00+03	24000.00
CDD012	2017-08-09 15:19:00+03	199700.00
CDD046	2017-08-07 23:37:00+03	93700.00
CDD057	2017-08-06 03:39:00+03	100000.00
CDD089	2017-08-03 01:34:00+03	50600.00
CDD0CF	2017-08-02 18:48:00+03	56600.00
CDD0E8	2017-08-01 04:58:00+03	31100.00
CDD138	2017-07-30 11:17:00+03	22000.00
CDD187	2017-07-26 08:49:00+03	38800.00
CDD198	2017-07-20 19:13:00+03	20200.00
CDD1AF	2017-08-09 03:57:00+03	62700.00
CDD207	2017-08-12 17:06:00+03	108600.00
CDD221	2017-08-15 10:52:00+03	60600.00
CDD28C	2017-08-07 00:32:00+03	58600.00
CDD2BA	2017-08-03 10:02:00+03	100200.00
CDD2C9	2017-07-12 09:38:00+03	26400.00
CDD2E8	2017-08-15 05:18:00+03	74900.00
CDD310	2017-08-05 03:19:00+03	37100.00
CDD35B	2017-07-29 16:23:00+03	168000.00
CDD35E	2017-08-04 08:19:00+03	133700.00
CDD3E0	2017-07-04 01:17:00+03	88100.00
CDD42F	2017-07-29 17:41:00+03	8000.00
CDD45D	2017-07-21 06:08:00+03	27300.00
CDD54D	2017-08-03 11:28:00+03	99200.00
CDD598	2017-07-06 14:52:00+03	94000.00
CDD5C3	2017-07-08 13:22:00+03	22000.00
CDD5EE	2017-06-28 07:41:00+03	48400.00
CDD5F1	2017-07-24 12:53:00+03	396600.00
CDD602	2017-08-14 19:20:00+03	55800.00
CDD656	2017-07-06 23:48:00+03	54800.00
CDD723	2017-07-06 01:58:00+03	36200.00
CDD755	2017-07-16 14:38:00+03	24800.00
CDD7A8	2017-08-15 07:01:00+03	49600.00
CDD7D8	2017-07-21 06:28:00+03	14400.00
CDD7E7	2017-07-01 10:38:00+03	91800.00
CDD7F0	2017-07-13 07:14:00+03	40000.00
CDD800	2017-07-26 19:21:00+03	38600.00
CDD806	2017-07-17 09:52:00+03	85600.00
CDD814	2017-08-06 20:54:00+03	44700.00
CDD836	2017-07-23 04:32:00+03	88800.00
CDD83A	2017-08-13 16:51:00+03	13400.00
CDD9A2	2017-07-12 00:50:00+03	55800.00
CDD9AF	2017-07-11 23:57:00+03	46200.00
CDDA12	2017-08-02 15:57:00+03	33000.00
CDDA32	2017-07-12 03:22:00+03	38200.00
CDDA6F	2017-08-02 01:08:00+03	23200.00
CDDAAF	2017-08-11 20:21:00+03	70700.00
CDDACA	2017-07-10 21:18:00+03	126300.00
CDDB0F	2017-07-21 17:23:00+03	131100.00
CDDB2C	2017-07-18 01:52:00+03	76600.00
CDDB87	2017-08-08 22:32:00+03	46400.00
CDDBAD	2017-08-05 06:38:00+03	28000.00
CDDBEF	2017-07-01 01:33:00+03	14400.00
CDDC58	2017-08-08 01:04:00+03	133200.00
CDDCCB	2017-07-31 23:54:00+03	56000.00
CDDD05	2017-08-14 10:14:00+03	66600.00
CDDD31	2017-07-19 11:00:00+03	7200.00
CDDD97	2017-07-31 08:33:00+03	147800.00
CDDD9E	2017-07-21 04:58:00+03	19600.00
CDDDF0	2017-07-29 05:49:00+03	394400.00
CDDE06	2017-07-04 16:10:00+03	18800.00
CDDE25	2017-07-31 03:51:00+03	377100.00
CDDE67	2017-07-25 20:23:00+03	184500.00
CDDEB0	2017-07-09 06:28:00+03	168000.00
CDDEEE	2017-07-17 08:14:00+03	43200.00
CDDF32	2017-07-21 20:43:00+03	41500.00
CDE010	2017-07-01 16:55:00+03	57500.00
CDE01C	2017-07-17 07:00:00+03	127500.00
CDE02A	2017-08-15 08:44:00+03	27800.00
CDE037	2017-07-11 02:11:00+03	137600.00
CDE07F	2017-07-12 17:56:00+03	36200.00
CDE118	2017-08-01 22:01:00+03	29600.00
CDE152	2017-07-19 14:33:00+03	167800.00
CDE1A9	2017-07-19 00:19:00+03	120000.00
CDE1B4	2017-07-21 11:02:00+03	6700.00
CDE1EA	2017-08-08 19:28:00+03	92800.00
CDE234	2017-07-30 06:09:00+03	97900.00
CDE241	2017-08-07 20:17:00+03	188100.00
CDE251	2017-07-07 19:12:00+03	62600.00
CDE295	2017-07-12 05:51:00+03	116000.00
CDE310	2017-07-11 19:42:00+03	76900.00
CDE3A4	2017-06-30 15:59:00+03	48400.00
CDE3EB	2017-07-15 22:05:00+03	135600.00
CDE3F5	2017-07-13 19:47:00+03	16400.00
CDE420	2017-07-11 21:36:00+03	29600.00
CDE4DC	2017-07-01 10:38:00+03	82900.00
CDE4E8	2017-07-02 21:46:00+03	24600.00
CDE50D	2017-07-22 07:17:00+03	142400.00
CDE5B1	2017-07-10 18:39:00+03	85000.00
CDE5FB	2017-08-11 20:33:00+03	88400.00
CDE60E	2017-08-03 17:17:00+03	396600.00
CDE69C	2017-07-08 12:50:00+03	187600.00
CDE737	2017-08-15 13:45:00+03	126000.00
CDE75A	2017-07-13 12:14:00+03	49500.00
CDE76F	2017-07-12 14:34:00+03	59400.00
CDE786	2017-06-30 20:39:00+03	53400.00
CDE7C6	2017-08-05 18:16:00+03	12600.00
CDE800	2017-07-27 17:31:00+03	68000.00
CDE836	2017-07-25 07:13:00+03	103500.00
CDE875	2017-08-05 22:24:00+03	164000.00
CDE8A7	2017-06-29 23:28:00+03	35800.00
CDE8B5	2017-07-10 15:41:00+03	55800.00
CDE8BD	2017-08-04 04:37:00+03	30100.00
CDE900	2017-07-15 16:56:00+03	37900.00
CDE90F	2017-07-30 11:55:00+03	7200.00
CDE95B	2017-07-05 17:33:00+03	27200.00
CDE986	2017-07-07 22:46:00+03	92800.00
CDE9B2	2017-08-04 11:09:00+03	129000.00
CDE9EB	2017-08-04 17:57:00+03	28000.00
CDEA17	2017-07-03 20:48:00+03	124300.00
CDEA1F	2017-08-10 04:45:00+03	43400.00
CDEA32	2017-07-24 23:00:00+03	28800.00
CDEAA6	2017-07-01 23:21:00+03	37900.00
CDEAF9	2017-08-02 00:52:00+03	32700.00
CDEB43	2017-08-04 06:56:00+03	111600.00
CDEB57	2017-07-22 13:17:00+03	28000.00
CDEB62	2017-07-07 16:43:00+03	37900.00
CDEB79	2017-07-15 09:56:00+03	50100.00
CDEB89	2017-07-19 11:12:00+03	392200.00
CDEBA5	2017-08-03 05:10:00+03	45200.00
CDEBE6	2017-07-17 06:09:00+03	64800.00
CDEC00	2017-08-02 16:45:00+03	27200.00
CDEC25	2017-08-10 21:05:00+03	51900.00
CDEC35	2017-07-08 06:58:00+03	104600.00
CDECD9	2017-07-06 12:22:00+03	100600.00
CDECDD	2017-07-19 21:03:00+03	28800.00
CDED07	2017-07-04 02:34:00+03	224300.00
CDED1E	2017-08-02 21:57:00+03	162500.00
CDED38	2017-07-09 10:18:00+03	86500.00
CDED5B	2017-08-12 09:14:00+03	43600.00
CDEDEF	2017-08-13 10:20:00+03	100000.00
CDEE17	2017-08-11 13:50:00+03	30200.00
CDEE29	2017-08-13 15:26:00+03	31600.00
CDEE31	2017-07-16 09:49:00+03	32800.00
CDEE58	2017-07-31 13:07:00+03	133700.00
CDEEA0	2017-07-09 04:59:00+03	398500.00
CDEEBE	2017-07-02 10:41:00+03	75600.00
CDEF0A	2017-07-21 12:48:00+03	25400.00
CDEF1D	2017-08-10 20:28:00+03	8800.00
CDEF20	2017-07-03 15:05:00+03	72400.00
CDEF22	2017-08-09 23:24:00+03	326200.00
CDEFCA	2017-07-16 16:36:00+03	47900.00
CDEFD2	2017-07-31 22:44:00+03	95700.00
CDEFE6	2017-07-02 18:05:00+03	100600.00
CDF03A	2017-07-13 21:32:00+03	24800.00
CDF067	2017-07-07 07:18:00+03	51900.00
CDF09E	2017-07-17 16:31:00+03	73200.00
CDF0B0	2017-08-02 17:38:00+03	206400.00
CDF190	2017-07-14 19:25:00+03	28800.00
CDF1CA	2017-07-29 16:22:00+03	134400.00
CDF24D	2017-07-13 02:50:00+03	23600.00
CDF267	2017-07-11 17:17:00+03	30200.00
CDF26F	2017-08-14 00:54:00+03	20200.00
CDF28D	2017-07-25 13:54:00+03	125600.00
CDF34B	2017-08-04 20:36:00+03	87000.00
CDF34D	2017-07-16 19:16:00+03	20000.00
CDF383	2017-07-14 13:47:00+03	11600.00
CDF3E5	2017-07-10 19:44:00+03	52800.00
CDF3E7	2017-08-05 12:18:00+03	14400.00
CDF4A3	2017-07-13 03:01:00+03	28000.00
CDF4BC	2017-08-08 16:41:00+03	246000.00
CDF4D0	2017-08-15 12:40:00+03	72800.00
CDF525	2017-07-16 14:10:00+03	86400.00
CDF592	2017-08-12 11:13:00+03	34000.00
CDF5F3	2017-07-29 05:56:00+03	51900.00
CDF617	2017-07-14 01:52:00+03	56000.00
CDF61F	2017-08-11 09:15:00+03	74800.00
CDF660	2017-08-01 06:58:00+03	64600.00
CDF662	2017-08-02 01:40:00+03	184200.00
CDF689	2017-07-03 18:01:00+03	176400.00
CDF6B6	2017-07-27 07:29:00+03	9800.00
CDF6BB	2017-07-24 10:44:00+03	21400.00
CDF718	2017-08-02 19:05:00+03	133100.00
CDF72B	2017-07-22 05:04:00+03	31600.00
CDF751	2017-07-16 14:57:00+03	88800.00
CDF78D	2017-07-05 11:17:00+03	71800.00
CDF7BC	2017-07-08 04:59:00+03	66600.00
CDF816	2017-08-11 13:32:00+03	130700.00
CDF866	2017-08-04 23:52:00+03	132800.00
CDF881	2017-08-11 13:25:00+03	89600.00
CDF8A1	2017-07-06 14:22:00+03	67100.00
CDF8BF	2017-07-17 13:49:00+03	56600.00
CDF8EE	2017-08-07 16:11:00+03	124200.00
CDF950	2017-07-07 21:19:00+03	782400.00
CDF990	2017-07-03 11:08:00+03	46000.00
CDF992	2017-07-30 03:45:00+03	12600.00
CDF9B4	2017-07-16 18:22:00+03	24800.00
CDF9C3	2017-07-06 19:11:00+03	111600.00
CDF9CF	2017-08-05 03:58:00+03	76800.00
CDF9DD	2017-07-26 12:30:00+03	159600.00
CDF9F4	2017-08-11 06:14:00+03	113200.00
CDFA20	2017-07-11 11:31:00+03	59800.00
CDFA25	2017-07-24 16:23:00+03	52400.00
CDFABD	2017-07-01 14:18:00+03	24000.00
CDFAE2	2017-07-28 07:48:00+03	29000.00
CDFB63	2017-08-04 10:27:00+03	23600.00
CDFB8B	2017-07-18 15:54:00+03	27400.00
CDFBB2	2017-08-06 17:49:00+03	67600.00
CDFBCF	2017-07-14 01:43:00+03	24700.00
CDFBD8	2017-07-02 19:02:00+03	13400.00
CDFC4E	2017-07-12 07:35:00+03	14000.00
CDFCC0	2017-08-14 14:07:00+03	27600.00
CDFCE8	2017-07-26 14:30:00+03	142800.00
CDFD25	2017-07-26 11:08:00+03	55800.00
CDFD30	2017-06-29 12:29:00+03	45100.00
CDFDB1	2017-07-27 21:21:00+03	4000.00
CDFDBF	2017-08-02 18:18:00+03	55800.00
CDFE0E	2017-08-02 02:00:00+03	66600.00
CDFE1F	2017-07-21 20:33:00+03	39300.00
CDFE7C	2017-07-14 11:08:00+03	28800.00
CDFE83	2017-07-08 04:49:00+03	178400.00
CDFEC1	2017-08-12 04:24:00+03	135400.00
CDFF0A	2017-07-17 21:56:00+03	40800.00
CDFF30	2017-07-13 07:25:00+03	96100.00
CDFF68	2017-07-01 03:58:00+03	20800.00
CDFF8F	2017-08-10 15:16:00+03	67000.00
CDFFB9	2017-07-04 04:26:00+03	31600.00
CE0023	2017-07-27 09:57:00+03	66600.00
CE0132	2017-08-01 11:11:00+03	88000.00
CE019E	2017-07-12 10:05:00+03	73200.00
CE01AE	2017-07-01 22:46:00+03	199600.00
CE01CC	2017-07-05 09:56:00+03	35800.00
CE022D	2017-07-25 22:26:00+03	16400.00
CE029A	2017-08-12 15:30:00+03	28000.00
CE029C	2017-08-02 13:53:00+03	168000.00
CE038A	2017-08-11 11:41:00+03	46400.00
CE03BD	2017-07-21 01:32:00+03	112000.00
CE03DF	2017-07-11 08:48:00+03	33100.00
CE03E2	2017-08-11 13:37:00+03	47700.00
CE03EC	2017-08-04 18:24:00+03	28800.00
CE03F2	2017-07-16 21:33:00+03	20400.00
CE0405	2017-07-17 23:25:00+03	170700.00
CE0427	2017-07-17 06:08:00+03	46800.00
CE0447	2017-08-03 06:10:00+03	243900.00
CE0456	2017-08-14 03:48:00+03	22400.00
CE045C	2017-07-13 03:55:00+03	29600.00
CE0483	2017-07-18 06:56:00+03	11600.00
CE04A4	2017-07-09 13:15:00+03	32200.00
CE04AB	2017-08-11 03:53:00+03	7800.00
CE0519	2017-07-12 11:57:00+03	213200.00
CE0583	2017-08-08 23:22:00+03	177200.00
CE0638	2017-08-09 05:16:00+03	28800.00
CE06A1	2017-07-19 00:30:00+03	28000.00
CE06E6	2017-07-09 18:33:00+03	13400.00
CE06F3	2017-07-12 19:45:00+03	66600.00
CE06F4	2017-08-01 23:23:00+03	24600.00
CE070F	2017-07-09 21:00:00+03	23200.00
CE0746	2017-07-26 04:10:00+03	238700.00
CE078D	2017-08-03 14:23:00+03	36800.00
CE07B2	2017-07-27 13:56:00+03	72400.00
CE081C	2017-07-22 16:55:00+03	231800.00
CE0832	2017-07-09 03:37:00+03	26100.00
CE0838	2017-07-29 19:23:00+03	20200.00
CE0846	2017-08-11 21:27:00+03	32800.00
CE0898	2017-07-05 08:25:00+03	67600.00
CE08C3	2017-07-09 07:32:00+03	41200.00
CE08CD	2017-08-14 06:28:00+03	19900.00
CE08D1	2017-06-30 01:26:00+03	209700.00
CE08F3	2017-07-19 00:03:00+03	163500.00
CE0936	2017-07-08 05:28:00+03	16800.00
CE094D	2017-07-20 05:16:00+03	40600.00
CE0966	2017-07-29 18:50:00+03	101100.00
CE0A7D	2017-06-29 14:11:00+03	13600.00
CE0A8B	2017-08-05 19:45:00+03	260900.00
CE0B60	2017-07-27 11:09:00+03	126300.00
CE0B66	2017-07-26 20:44:00+03	47900.00
CE0B68	2017-08-03 15:12:00+03	111600.00
CE0B8C	2017-08-08 19:58:00+03	37700.00
CE0BC5	2017-07-02 15:25:00+03	273400.00
CE0BE2	2017-07-21 23:58:00+03	99300.00
CE0BF9	2017-08-09 17:15:00+03	19600.00
CE0C53	2017-08-15 03:05:00+03	13400.00
CE0CC6	2017-07-15 02:31:00+03	66300.00
CE0CDF	2017-07-22 06:39:00+03	135000.00
CE0CE0	2017-07-11 19:05:00+03	28800.00
CE0D12	2017-08-10 00:17:00+03	6600.00
CE0D45	2017-07-03 20:01:00+03	119400.00
CE0D5D	2017-07-15 08:52:00+03	103000.00
CE0DA4	2017-07-25 06:43:00+03	55800.00
CE0DB9	2017-07-21 22:08:00+03	94800.00
CE0DBA	2017-06-25 12:30:00+03	39500.00
CE0DBE	2017-08-15 04:05:00+03	44500.00
CE0E26	2017-08-06 15:52:00+03	276500.00
CE0E7B	2017-06-30 10:36:00+03	117000.00
CE0E84	2017-07-06 22:36:00+03	248400.00
CE0E9F	2017-07-23 21:14:00+03	25200.00
CE0EAC	2017-08-06 11:12:00+03	39500.00
CE0ED3	2017-08-05 02:55:00+03	122800.00
CE0EE1	2017-07-26 03:17:00+03	7200.00
CE0F25	2017-08-09 04:38:00+03	35600.00
CE0F5B	2017-06-28 12:44:00+03	49000.00
CE0FAA	2017-07-15 01:54:00+03	89600.00
CE0FB1	2017-08-02 02:21:00+03	46400.00
CE0FDC	2017-07-24 18:08:00+03	33400.00
CE106C	2017-07-05 13:30:00+03	56000.00
CE10D5	2017-07-28 12:54:00+03	61800.00
CE10E8	2017-08-05 01:03:00+03	136600.00
CE11A0	2017-08-13 19:16:00+03	27200.00
CE11B5	2017-07-09 15:59:00+03	136000.00
CE11BF	2017-08-01 20:26:00+03	25100.00
CE1237	2017-07-06 21:52:00+03	66200.00
CE12EA	2017-07-14 22:30:00+03	88500.00
CE1382	2017-07-01 14:28:00+03	336200.00
CE13AE	2017-07-23 06:42:00+03	22100.00
CE13D5	2017-07-16 18:59:00+03	96400.00
CE1439	2017-08-10 09:16:00+03	78000.00
CE145E	2017-08-15 04:55:00+03	145300.00
CE147D	2017-07-27 08:14:00+03	28800.00
CE1493	2017-07-11 02:29:00+03	99300.00
CE1558	2017-07-17 15:35:00+03	59800.00
CE155D	2017-08-08 20:18:00+03	8000.00
CE1567	2017-08-11 03:32:00+03	16400.00
CE15E6	2017-08-01 11:36:00+03	118000.00
CE164C	2017-08-11 19:08:00+03	199700.00
CE165D	2017-07-22 22:22:00+03	85400.00
CE166B	2017-08-11 00:56:00+03	38500.00
CE166D	2017-08-08 14:04:00+03	20400.00
CE167E	2017-07-12 20:00:00+03	12400.00
CE1694	2017-07-28 05:55:00+03	38800.00
CE169F	2017-08-09 10:55:00+03	34200.00
CE16AE	2017-07-23 18:55:00+03	118500.00
CE16C4	2017-07-31 03:03:00+03	58200.00
CE17BA	2017-07-09 17:33:00+03	18600.00
CE17C0	2017-07-13 11:11:00+03	89700.00
CE17C5	2017-07-07 21:13:00+03	81700.00
CE17E0	2017-07-11 12:49:00+03	166000.00
CE1810	2017-07-04 17:27:00+03	188000.00
CE1951	2017-08-06 03:17:00+03	51800.00
CE195D	2017-08-07 13:49:00+03	50600.00
CE19E6	2017-08-04 06:01:00+03	6300.00
CE1A06	2017-08-11 00:50:00+03	54800.00
CE1A11	2017-07-20 10:49:00+03	31600.00
CE1A25	2017-07-13 05:10:00+03	32400.00
CE1A3B	2017-07-27 03:15:00+03	64400.00
CE1A70	2017-08-08 23:25:00+03	80400.00
CE1A7A	2017-07-20 19:53:00+03	56000.00
CE1AB1	2017-08-08 14:36:00+03	89600.00
CE1ABD	2017-07-07 03:53:00+03	38800.00
CE1AC9	2017-07-04 20:33:00+03	152400.00
CE1AE0	2017-08-09 09:53:00+03	26000.00
CE1B18	2017-08-14 19:10:00+03	91800.00
CE1B61	2017-07-10 08:37:00+03	23400.00
CE1BEA	2017-08-11 12:11:00+03	15000.00
CE1BF9	2017-08-03 23:29:00+03	25200.00
CE1C0B	2017-08-10 15:41:00+03	69000.00
CE1CB2	2017-08-01 15:45:00+03	46300.00
CE1D40	2017-06-28 00:15:00+03	192200.00
CE1D4B	2017-08-03 10:27:00+03	39600.00
CE1D82	2017-08-02 01:55:00+03	24800.00
CE1D93	2017-08-14 22:50:00+03	233700.00
CE1DCF	2017-07-23 20:38:00+03	31200.00
CE1E4E	2017-07-29 17:29:00+03	86400.00
CE1EAA	2017-08-14 00:10:00+03	12600.00
CE1EB2	2017-06-29 06:36:00+03	81700.00
CE1EBA	2017-07-23 15:58:00+03	94900.00
CE1EC9	2017-08-03 15:50:00+03	55800.00
CE1EF2	2017-07-10 14:29:00+03	119700.00
CE1F02	2017-08-03 19:41:00+03	130300.00
CE1F87	2017-07-03 02:20:00+03	85700.00
CE1FC4	2017-07-16 11:37:00+03	62700.00
CE202B	2017-07-09 06:39:00+03	20800.00
CE20F0	2017-07-21 01:33:00+03	154500.00
CE2109	2017-08-09 06:35:00+03	29800.00
CE211E	2017-07-28 07:34:00+03	196400.00
CE21D5	2017-08-05 06:36:00+03	29600.00
CE21E0	2017-07-08 20:17:00+03	28000.00
CE2231	2017-07-25 07:26:00+03	39300.00
CE2256	2017-07-16 18:58:00+03	46400.00
CE2267	2017-08-14 03:55:00+03	38000.00
CE22E6	2017-07-22 05:42:00+03	18600.00
CE2366	2017-07-07 22:33:00+03	248400.00
CE239E	2017-07-19 04:58:00+03	271400.00
CE23CF	2017-07-29 07:01:00+03	86800.00
CE2455	2017-07-02 09:39:00+03	89100.00
CE24F9	2017-08-09 05:44:00+03	124200.00
CE2647	2017-08-15 11:23:00+03	6800.00
CE269B	2017-08-03 05:06:00+03	67600.00
CE26E1	2017-07-04 04:09:00+03	40200.00
CE2722	2017-08-12 04:18:00+03	46700.00
CE274F	2017-08-11 01:33:00+03	39400.00
CE2763	2017-07-09 05:57:00+03	24700.00
CE2772	2017-07-22 03:58:00+03	64400.00
CE27B1	2017-07-18 16:08:00+03	98000.00
CE27F9	2017-07-09 06:33:00+03	31600.00
CE282A	2017-06-29 19:29:00+03	99200.00
CE2837	2017-07-19 18:48:00+03	26000.00
CE283E	2017-07-04 03:11:00+03	39300.00
CE2851	2017-07-15 11:50:00+03	70800.00
CE289D	2017-08-11 14:49:00+03	46000.00
CE28D8	2017-07-06 20:30:00+03	119600.00
CE290A	2017-07-12 01:28:00+03	46200.00
CE2921	2017-07-09 19:36:00+03	32800.00
CE298F	2017-07-05 17:55:00+03	34800.00
CE29C5	2017-07-14 00:23:00+03	135600.00
CE29FE	2017-08-13 16:56:00+03	12300.00
CE2AF5	2017-07-18 17:08:00+03	35100.00
CE2B71	2017-07-27 02:52:00+03	157200.00
CE2BAD	2017-07-07 05:28:00+03	28000.00
CE2BAE	2017-07-02 01:12:00+03	55800.00
CE2BE7	2017-07-21 14:42:00+03	187600.00
CE2BEA	2017-07-10 00:02:00+03	55800.00
CE2C22	2017-07-13 09:33:00+03	61800.00
CE2C4A	2017-08-09 10:00:00+03	57600.00
CE2D06	2017-07-07 20:34:00+03	58600.00
CE2D50	2017-07-09 11:32:00+03	44600.00
CE2D84	2017-07-31 06:47:00+03	26000.00
CE2D89	2017-07-14 15:52:00+03	396500.00
CE2DBF	2017-08-08 23:57:00+03	56600.00
CE2DC2	2017-08-10 09:10:00+03	21500.00
CE2DE7	2017-07-01 20:20:00+03	88800.00
CE2E1F	2017-08-10 02:37:00+03	78800.00
CE2E2F	2017-08-08 13:27:00+03	58900.00
CE2E31	2017-08-13 10:17:00+03	214900.00
CE2E4D	2017-07-04 01:34:00+03	27900.00
CE2E8D	2017-07-04 04:49:00+03	40000.00
CE2E8E	2017-07-27 12:07:00+03	31600.00
CE2E95	2017-08-13 18:22:00+03	123000.00
CE2EB4	2017-07-08 23:11:00+03	165500.00
CE2EE9	2017-08-06 23:16:00+03	61800.00
CE2F4B	2017-07-21 18:06:00+03	114300.00
CE3021	2017-07-11 13:17:00+03	112000.00
CE305C	2017-07-07 08:52:00+03	66000.00
CE306A	2017-07-04 08:50:00+03	70800.00
CE30A1	2017-08-03 12:56:00+03	28300.00
CE30BB	2017-07-07 19:28:00+03	162400.00
CE30C3	2017-07-31 18:42:00+03	174600.00
CE30CA	2017-07-23 14:00:00+03	46000.00
CE30DC	2017-08-02 09:57:00+03	66800.00
CE3130	2017-07-21 14:18:00+03	95200.00
CE3191	2017-07-25 09:00:00+03	28800.00
CE3194	2017-07-23 17:46:00+03	35600.00
CE31D4	2017-08-01 13:38:00+03	154500.00
CE31E4	2017-08-14 22:57:00+03	55800.00
CE320D	2017-07-08 15:46:00+03	13300.00
CE3277	2017-08-13 21:35:00+03	62600.00
CE329E	2017-07-22 17:35:00+03	120100.00
CE329F	2017-08-05 23:37:00+03	14000.00
CE3364	2017-07-09 09:59:00+03	67900.00
CE33F8	2017-06-27 20:39:00+03	50000.00
CE3471	2017-07-28 14:37:00+03	38600.00
CE3480	2017-08-02 13:26:00+03	133200.00
CE3487	2017-07-06 08:52:00+03	34300.00
CE348F	2017-08-11 22:38:00+03	46300.00
CE349D	2017-07-17 18:14:00+03	174400.00
CE34CA	2017-07-15 08:54:00+03	86800.00
CE34E0	2017-07-30 05:19:00+03	210000.00
CE34EA	2017-07-10 07:01:00+03	58200.00
CE34F2	2017-08-07 03:19:00+03	92400.00
CE3504	2017-07-24 11:23:00+03	162200.00
CE3529	2017-08-06 22:21:00+03	28000.00
CE35FD	2017-08-10 01:57:00+03	76400.00
CE362E	2017-07-11 01:58:00+03	58600.00
CE36CC	2017-07-18 09:32:00+03	187600.00
CE3711	2017-07-31 08:27:00+03	6000.00
CE3736	2017-07-15 09:36:00+03	28000.00
CE3770	2017-08-04 06:59:00+03	88100.00
CE377E	2017-07-27 00:36:00+03	63200.00
CE37A6	2017-07-08 23:05:00+03	246000.00
CE37BA	2017-07-13 04:33:00+03	188000.00
CE383E	2017-08-02 11:14:00+03	28000.00
CE384B	2017-08-07 03:39:00+03	40100.00
CE38C1	2017-07-29 15:51:00+03	70200.00
CE3937	2017-07-24 08:15:00+03	6800.00
CE3981	2017-07-07 11:41:00+03	48800.00
CE3A11	2017-07-05 13:50:00+03	34100.00
CE3AAB	2017-08-10 14:08:00+03	56000.00
CE3ADD	2017-07-15 01:53:00+03	20200.00
CE3AE8	2017-07-16 10:10:00+03	174900.00
CE3B06	2017-07-02 15:42:00+03	27300.00
CE3B7A	2017-06-29 05:37:00+03	522400.00
CE3B94	2017-06-25 15:28:00+03	47000.00
CE3BC4	2017-07-30 07:03:00+03	28800.00
CE3CB1	2017-07-04 11:09:00+03	45200.00
CE3DEF	2017-07-31 04:42:00+03	38800.00
CE3E06	2017-08-12 19:03:00+03	66600.00
CE3E34	2017-07-08 02:32:00+03	57800.00
CE3E3A	2017-07-17 14:45:00+03	38600.00
CE3E40	2017-07-06 15:50:00+03	26600.00
CE3E4A	2017-07-05 15:38:00+03	167100.00
CE3E59	2017-07-22 16:06:00+03	36200.00
CE3E64	2017-07-10 05:46:00+03	94200.00
CE3EA0	2017-07-14 06:26:00+03	12600.00
CE3EA9	2017-07-28 20:41:00+03	112000.00
CE3EE7	2017-07-15 11:21:00+03	31400.00
CE3EF2	2017-08-14 07:14:00+03	28000.00
CE3F81	2017-08-08 04:17:00+03	25600.00
CE3F90	2017-07-24 23:26:00+03	59800.00
CE3FA7	2017-08-01 15:49:00+03	22000.00
CE3FCA	2017-08-07 06:51:00+03	35200.00
CE3FE1	2017-08-08 23:45:00+03	20400.00
CE3FEE	2017-07-16 12:22:00+03	19600.00
CE400C	2017-08-06 22:14:00+03	64300.00
CE4011	2017-07-09 10:13:00+03	280000.00
CE40E6	2017-07-29 21:07:00+03	13600.00
CE4161	2017-07-07 17:30:00+03	46400.00
CE4188	2017-07-19 08:41:00+03	129700.00
CE435A	2017-07-30 09:40:00+03	34000.00
CE4377	2017-07-12 22:37:00+03	100500.00
CE442F	2017-07-20 13:22:00+03	412300.00
CE444B	2017-07-03 15:15:00+03	191600.00
CE4454	2017-07-29 03:04:00+03	154400.00
CE4467	2017-08-11 11:59:00+03	137600.00
CE4486	2017-08-15 05:50:00+03	22100.00
CE44C0	2017-07-13 07:56:00+03	12600.00
CE451E	2017-08-07 22:47:00+03	75300.00
CE453F	2017-07-26 18:52:00+03	135200.00
CE459C	2017-08-08 00:50:00+03	57500.00
CE45AF	2017-07-26 13:53:00+03	117600.00
CE45C9	2017-07-31 23:28:00+03	174400.00
CE4604	2017-07-07 03:38:00+03	88400.00
CE4664	2017-07-28 08:59:00+03	131900.00
CE46BD	2017-07-23 18:57:00+03	27300.00
CE46CB	2017-08-11 16:57:00+03	51900.00
CE46E6	2017-07-17 15:58:00+03	191300.00
CE473A	2017-07-12 05:51:00+03	32900.00
CE4757	2017-08-13 11:21:00+03	92700.00
CE4810	2017-07-31 00:36:00+03	60900.00
CE494A	2017-07-02 07:11:00+03	170700.00
CE496C	2017-08-02 21:26:00+03	20400.00
CE49CE	2017-08-15 11:24:00+03	73200.00
CE49D5	2017-07-28 11:47:00+03	30400.00
CE49E0	2017-08-10 03:28:00+03	24400.00
CE4A03	2017-07-06 17:26:00+03	99300.00
CE4A1B	2017-07-24 16:51:00+03	34000.00
CE4A1D	2017-07-03 14:03:00+03	125300.00
CE4A6C	2017-08-06 14:11:00+03	12600.00
CE4A82	2017-07-03 15:24:00+03	66900.00
CE4A87	2017-07-26 11:07:00+03	16400.00
CE4A91	2017-07-13 09:42:00+03	204500.00
CE4AB4	2017-07-18 12:11:00+03	28800.00
CE4AD3	2017-07-05 11:42:00+03	58200.00
CE4AF1	2017-07-13 20:35:00+03	65900.00
CE4B15	2017-07-14 14:15:00+03	27900.00
CE4B70	2017-07-30 12:46:00+03	24200.00
CE4BD8	2017-08-06 03:16:00+03	46200.00
CE4BE0	2017-07-16 10:12:00+03	37200.00
CE4D26	2017-08-10 03:49:00+03	80900.00
CE4D59	2017-07-09 06:13:00+03	136200.00
CE4D65	2017-07-20 05:25:00+03	152900.00
CE4D7B	2017-08-10 00:27:00+03	22000.00
CE4D9D	2017-06-28 04:59:00+03	134700.00
CE4DCF	2017-07-12 13:35:00+03	39300.00
CE4E41	2017-07-24 08:56:00+03	149900.00
CE4E44	2017-08-03 21:57:00+03	120400.00
CE4E45	2017-07-08 15:19:00+03	29800.00
CE4ECE	2017-08-01 19:33:00+03	76600.00
CE4EEF	2017-08-02 18:23:00+03	99200.00
CE4F62	2017-07-27 03:38:00+03	98400.00
CE4F8B	2017-08-01 12:51:00+03	6300.00
CE5007	2017-07-11 22:16:00+03	35200.00
CE5039	2017-07-21 11:14:00+03	92900.00
CE50AE	2017-08-15 08:45:00+03	137400.00
CE50B4	2017-07-24 22:18:00+03	26700.00
CE50BC	2017-07-25 00:54:00+03	107000.00
CE50CA	2017-07-13 11:59:00+03	45400.00
CE50FF	2017-08-01 09:47:00+03	112600.00
CE5108	2017-08-12 18:53:00+03	26600.00
CE5151	2017-07-29 14:30:00+03	16400.00
CE5190	2017-07-08 05:57:00+03	92800.00
CE535C	2017-07-29 00:55:00+03	133200.00
CE5364	2017-07-12 23:53:00+03	45100.00
CE5377	2017-07-13 06:55:00+03	36200.00
CE53A6	2017-08-01 11:35:00+03	31800.00
CE5436	2017-08-01 07:08:00+03	14400.00
CE543B	2017-08-06 01:42:00+03	58700.00
CE544E	2017-08-14 02:22:00+03	516000.00
CE5451	2017-08-14 22:52:00+03	41200.00
CE546F	2017-07-08 03:59:00+03	259000.00
CE5487	2017-08-14 15:02:00+03	47200.00
CE54D8	2017-07-08 18:01:00+03	29600.00
CE553D	2017-07-04 10:03:00+03	28800.00
CE556C	2017-08-01 18:26:00+03	141100.00
CE55A0	2017-07-19 16:49:00+03	47600.00
CE5622	2017-08-04 09:21:00+03	10600.00
CE5628	2017-07-26 00:25:00+03	24200.00
CE5629	2017-07-11 07:28:00+03	6400.00
CE563F	2017-08-01 04:25:00+03	24400.00
CE56E1	2017-07-30 06:55:00+03	72300.00
CE5787	2017-07-25 00:56:00+03	81300.00
CE5797	2017-07-22 12:20:00+03	39200.00
CE57D9	2017-08-08 06:22:00+03	36800.00
CE5808	2017-07-17 07:13:00+03	103800.00
CE581C	2017-07-05 03:27:00+03	58800.00
CE583F	2017-06-29 20:10:00+03	32900.00
CE588E	2017-07-11 11:59:00+03	62800.00
CE58D3	2017-08-10 23:58:00+03	187600.00
CE5A84	2017-08-06 07:54:00+03	22000.00
CE5AD8	2017-08-03 21:39:00+03	119800.00
CE5B03	2017-08-10 13:28:00+03	23200.00
CE5B1C	2017-07-12 17:53:00+03	65500.00
CE5B30	2017-07-14 14:13:00+03	121800.00
CE5B97	2017-08-04 13:50:00+03	13300.00
CE5BC5	2017-08-14 23:31:00+03	398600.00
CE5BF0	2017-07-29 03:34:00+03	27300.00
CE5CF1	2017-07-05 15:04:00+03	21400.00
CE5D47	2017-08-12 23:19:00+03	406100.00
CE5D55	2017-07-08 22:11:00+03	35600.00
CE5E0E	2017-07-03 17:28:00+03	34600.00
CE5E5A	2017-08-03 05:14:00+03	78700.00
CE5EE6	2017-08-06 14:52:00+03	22000.00
CE5FBF	2017-08-06 04:28:00+03	36200.00
CE5FF4	2017-07-30 03:48:00+03	56600.00
CE603D	2017-07-22 12:50:00+03	39600.00
CE607D	2017-08-06 02:18:00+03	113800.00
CE6087	2017-07-04 11:17:00+03	77600.00
CE60B1	2017-07-17 22:46:00+03	115900.00
CE60D1	2017-08-11 06:14:00+03	54800.00
CE60F1	2017-08-09 02:53:00+03	104000.00
CE6149	2017-07-01 16:42:00+03	11000.00
CE622C	2017-07-21 15:29:00+03	120700.00
CE6330	2017-07-08 02:15:00+03	106900.00
CE633B	2017-07-11 21:20:00+03	38600.00
CE633E	2017-07-27 08:53:00+03	111600.00
CE6353	2017-08-14 13:20:00+03	28800.00
CE6444	2017-08-13 06:47:00+03	50000.00
CE648D	2017-08-11 04:37:00+03	128800.00
CE64C2	2017-07-15 08:11:00+03	141000.00
CE658A	2017-07-16 12:42:00+03	110500.00
CE6593	2017-08-13 15:43:00+03	386300.00
CE65D1	2017-07-10 05:17:00+03	55800.00
CE663B	2017-08-09 20:59:00+03	210100.00
CE669E	2017-08-13 11:51:00+03	6800.00
CE66BA	2017-08-11 01:41:00+03	276500.00
CE66D6	2017-07-21 05:00:00+03	248400.00
CE66F1	2017-08-11 03:30:00+03	25200.00
CE671F	2017-07-30 23:07:00+03	64200.00
CE6735	2017-07-25 09:38:00+03	25800.00
CE6757	2017-07-29 09:55:00+03	78600.00
CE6775	2017-07-23 20:16:00+03	46000.00
CE67E6	2017-07-31 23:24:00+03	25200.00
CE6807	2017-08-13 12:37:00+03	32800.00
CE6818	2017-08-05 04:28:00+03	28600.00
CE6877	2017-08-01 07:04:00+03	21800.00
CE6888	2017-08-03 04:10:00+03	94500.00
CE68A7	2017-08-02 02:21:00+03	67600.00
CE6918	2017-07-07 10:08:00+03	36100.00
CE691E	2017-07-04 10:28:00+03	53600.00
CE69D3	2017-08-12 11:13:00+03	145800.00
CE69EC	2017-08-01 21:43:00+03	32600.00
CE69FA	2017-07-22 02:12:00+03	52000.00
CE6A89	2017-07-10 12:23:00+03	308700.00
CE6AA4	2017-08-13 15:49:00+03	166100.00
CE6B00	2017-08-13 08:06:00+03	49400.00
CE6B40	2017-07-30 19:32:00+03	57600.00
CE6B64	2017-07-16 05:33:00+03	12600.00
CE6BCA	2017-08-11 20:55:00+03	24800.00
CE6BD9	2017-08-08 02:30:00+03	136500.00
CE6C5F	2017-08-02 13:14:00+03	14400.00
CE6C79	2017-07-09 06:40:00+03	116800.00
CE6CA0	2017-07-03 22:52:00+03	48100.00
CE6D21	2017-07-05 16:03:00+03	240600.00
CE6D5B	2017-08-14 07:50:00+03	47500.00
CE6D87	2017-07-03 08:46:00+03	30000.00
CE6DF1	2017-08-06 13:54:00+03	245300.00
CE6ED4	2017-07-13 03:56:00+03	8200.00
CE6EEB	2017-07-21 01:27:00+03	92100.00
CE6F5F	2017-08-06 16:27:00+03	25800.00
CE6F92	2017-07-26 16:29:00+03	43600.00
CE6FBF	2017-07-24 00:08:00+03	131600.00
CE6FE8	2017-07-30 14:27:00+03	23400.00
CE7010	2017-07-06 23:44:00+03	136600.00
CE704B	2017-07-17 12:08:00+03	30200.00
CE7094	2017-08-10 05:28:00+03	28000.00
CE716A	2017-08-13 06:44:00+03	78900.00
CE71A9	2017-08-07 03:53:00+03	180000.00
CE71D2	2017-08-07 13:59:00+03	54800.00
CE7280	2017-08-12 16:37:00+03	28300.00
CE7287	2017-08-07 22:28:00+03	23200.00
CE72B9	2017-07-15 22:42:00+03	6000.00
CE738E	2017-07-24 08:37:00+03	96300.00
CE739E	2017-08-15 16:32:00+03	189200.00
CE73D6	2017-06-30 09:57:00+03	23600.00
CE73E1	2017-07-21 03:06:00+03	27900.00
CE73E2	2017-07-02 18:10:00+03	70800.00
CE73EE	2017-07-24 15:08:00+03	31200.00
CE73F0	2017-07-07 01:59:00+03	47400.00
CE7475	2017-07-01 08:44:00+03	39200.00
CE7482	2017-07-29 03:32:00+03	12600.00
CE7489	2017-07-04 16:37:00+03	25000.00
CE7499	2017-07-04 14:53:00+03	55800.00
CE74D0	2017-07-15 22:49:00+03	80100.00
CE7560	2017-07-17 04:01:00+03	15900.00
CE7572	2017-08-14 08:47:00+03	46400.00
CE758F	2017-07-19 15:01:00+03	132300.00
CE75C8	2017-08-03 14:54:00+03	24400.00
CE764D	2017-07-13 18:13:00+03	28800.00
CE7688	2017-07-16 11:03:00+03	35300.00
CE76F5	2017-08-03 15:22:00+03	26700.00
CE7711	2017-08-06 16:06:00+03	58600.00
CE7736	2017-07-28 21:37:00+03	78400.00
CE773B	2017-08-01 04:46:00+03	23400.00
CE7752	2017-07-09 08:45:00+03	147300.00
CE7757	2017-07-06 23:05:00+03	189800.00
CE7761	2017-07-02 01:31:00+03	67400.00
CE7766	2017-07-06 12:00:00+03	16400.00
CE786A	2017-08-12 13:46:00+03	79600.00
CE789E	2017-07-19 16:57:00+03	8200.00
CE78C9	2017-07-19 04:44:00+03	85700.00
CE795B	2017-07-24 11:13:00+03	92300.00
CE7998	2017-07-17 09:06:00+03	62700.00
CE79AF	2017-08-01 10:52:00+03	28000.00
CE79C8	2017-07-17 11:08:00+03	38400.00
CE79CF	2017-08-12 22:38:00+03	119500.00
CE79ED	2017-08-09 06:42:00+03	246000.00
CE7A37	2017-07-22 11:48:00+03	25600.00
CE7AE1	2017-08-04 19:26:00+03	64500.00
CE7AEE	2017-07-12 05:24:00+03	31400.00
CE7B0A	2017-08-12 21:24:00+03	56000.00
CE7B46	2017-07-30 21:15:00+03	214300.00
CE7B78	2017-07-04 22:17:00+03	16000.00
CE7BEC	2017-07-10 22:27:00+03	111600.00
CE7BF4	2017-07-08 05:56:00+03	67600.00
CE7C27	2017-07-31 09:00:00+03	54900.00
CE7C4C	2017-07-15 04:56:00+03	37200.00
CE7C80	2017-07-16 23:48:00+03	146800.00
CE7CBC	2017-08-02 20:03:00+03	40000.00
CE7D32	2017-07-15 17:44:00+03	258400.00
CE7D99	2017-07-30 13:38:00+03	10800.00
CE7DED	2017-08-07 16:42:00+03	114800.00
CE7E03	2017-08-08 17:05:00+03	22000.00
CE7F70	2017-07-01 02:40:00+03	11600.00
CE7F73	2017-07-05 05:35:00+03	134700.00
CE7FC5	2017-08-08 18:16:00+03	135400.00
CE803A	2017-07-17 04:18:00+03	56000.00
CE807F	2017-08-11 06:37:00+03	56000.00
CE8084	2017-07-03 01:51:00+03	377100.00
CE80B7	2017-07-07 07:19:00+03	7200.00
CE80BB	2017-07-20 08:22:00+03	16400.00
CE80CD	2017-07-16 22:05:00+03	58000.00
CE80F0	2017-07-16 16:04:00+03	35200.00
CE8115	2017-07-25 09:51:00+03	99200.00
CE8195	2017-07-13 17:19:00+03	24800.00
CE81CC	2017-07-17 22:21:00+03	35200.00
CE81D9	2017-08-14 06:57:00+03	31400.00
CE81F5	2017-08-14 02:30:00+03	95200.00
CE8207	2017-07-16 14:48:00+03	92400.00
CE8212	2017-07-19 20:37:00+03	403600.00
CE8250	2017-07-06 02:13:00+03	270800.00
CE8259	2017-08-12 02:56:00+03	31600.00
CE8273	2017-07-19 10:30:00+03	83900.00
CE82A3	2017-07-06 22:10:00+03	111600.00
CE82D6	2017-08-03 07:48:00+03	78300.00
CE82E5	2017-08-12 17:01:00+03	32800.00
CE8352	2017-07-23 19:47:00+03	32600.00
CE837A	2017-07-25 14:39:00+03	24400.00
CE83D2	2017-07-14 10:59:00+03	40800.00
CE83DF	2017-08-15 15:08:00+03	8400.00
CE83F8	2017-08-01 08:00:00+03	15900.00
CE8413	2017-07-05 03:30:00+03	26600.00
CE8473	2017-07-18 06:16:00+03	6800.00
CE85AC	2017-07-22 14:34:00+03	78300.00
CE8619	2017-07-10 10:43:00+03	27300.00
CE868A	2017-08-12 02:33:00+03	58200.00
CE8716	2017-07-21 07:55:00+03	44100.00
CE8730	2017-06-28 07:28:00+03	152500.00
CE8767	2017-08-07 13:07:00+03	406200.00
CE87A4	2017-07-20 08:50:00+03	68400.00
CE87CB	2017-07-15 22:59:00+03	131100.00
CE881B	2017-06-28 08:46:00+03	46000.00
CE881E	2017-07-31 09:41:00+03	173900.00
CE8938	2017-08-07 12:56:00+03	46800.00
CE8982	2017-07-19 05:23:00+03	149200.00
CE89D1	2017-07-11 08:28:00+03	8200.00
CE89FB	2017-07-09 09:06:00+03	79800.00
CE8A21	2017-07-14 18:00:00+03	12400.00
CE8A35	2017-07-07 20:49:00+03	81200.00
CE8A37	2017-07-12 01:20:00+03	57400.00
CE8AAE	2017-07-03 12:26:00+03	47100.00
CE8B7F	2017-07-20 09:08:00+03	20400.00
CE8BB8	2017-08-03 04:47:00+03	83000.00
CE8BD0	2017-08-04 05:01:00+03	46300.00
CE8BE1	2017-08-10 10:11:00+03	81300.00
CE8C36	2017-07-24 19:32:00+03	89500.00
CE8C42	2017-08-03 12:28:00+03	59800.00
CE8C4D	2017-07-13 09:06:00+03	67400.00
CE8CAD	2017-07-16 19:19:00+03	23200.00
CE8CEE	2017-08-01 23:47:00+03	20600.00
CE8CF9	2017-07-25 08:03:00+03	6700.00
CE8D4A	2017-07-05 06:47:00+03	29600.00
CE8DA2	2017-08-05 20:22:00+03	24400.00
CE8DB0	2017-08-15 14:18:00+03	64500.00
CE8DD6	2017-07-11 23:32:00+03	32100.00
CE8E2B	2017-07-15 02:50:00+03	73600.00
CE8E4D	2017-07-18 10:15:00+03	312000.00
CE8EA8	2017-07-08 16:30:00+03	57500.00
CE8EE6	2017-07-31 04:54:00+03	21800.00
CE8F13	2017-07-08 19:54:00+03	26000.00
CE8F1B	2017-07-22 14:58:00+03	136200.00
CE8F23	2017-07-30 12:37:00+03	39400.00
CE8F43	2017-07-01 17:15:00+03	20200.00
CE8F9B	2017-07-31 05:58:00+03	58600.00
CE8FA0	2017-08-03 03:46:00+03	57600.00
CE9038	2017-08-05 01:16:00+03	136600.00
CE903F	2017-07-21 07:26:00+03	78400.00
CE9075	2017-08-03 14:00:00+03	42000.00
CE90A5	2017-08-14 16:26:00+03	168000.00
CE90CB	2017-08-15 12:11:00+03	40800.00
CE90D3	2017-08-15 15:31:00+03	100500.00
CE9137	2017-07-29 09:59:00+03	47100.00
CE917D	2017-07-28 18:44:00+03	46200.00
CE91D0	2017-07-30 07:08:00+03	26300.00
CE922A	2017-07-30 21:16:00+03	27600.00
CE924A	2017-08-08 21:22:00+03	65300.00
CE9311	2017-08-02 00:17:00+03	193600.00
CE9350	2017-08-08 17:13:00+03	37100.00
CE936C	2017-08-06 12:44:00+03	6000.00
CE93AA	2017-07-13 14:06:00+03	46400.00
CE9435	2017-08-12 04:20:00+03	48500.00
CE9488	2017-07-17 04:07:00+03	82900.00
CE94A5	2017-08-02 08:37:00+03	135400.00
CE94C4	2017-08-04 08:16:00+03	25400.00
CE95D6	2017-07-26 12:43:00+03	44700.00
CE95DB	2017-08-01 02:10:00+03	91200.00
CE960C	2017-07-13 08:30:00+03	13600.00
CE965D	2017-07-04 04:46:00+03	99300.00
CE9689	2017-07-05 12:16:00+03	43600.00
CE9690	2017-08-15 02:55:00+03	84500.00
CE969B	2017-08-09 18:36:00+03	131600.00
CE96B5	2017-08-13 23:56:00+03	50800.00
CE96CB	2017-07-11 00:59:00+03	196800.00
CE9725	2017-07-12 03:34:00+03	97500.00
CE9729	2017-07-11 11:14:00+03	19600.00
CE973E	2017-08-15 17:25:00+03	112300.00
CE9759	2017-07-07 20:17:00+03	26000.00
CE9796	2017-07-19 16:44:00+03	6000.00
CE97BB	2017-07-01 03:24:00+03	151100.00
CE9823	2017-07-22 10:48:00+03	56100.00
CE983B	2017-08-11 13:40:00+03	271200.00
CE986C	2017-07-06 10:53:00+03	232200.00
CE987E	2017-06-30 07:52:00+03	384100.00
CE9891	2017-07-08 12:04:00+03	177600.00
CE98A0	2017-08-15 07:36:00+03	72300.00
CE992C	2017-07-26 13:30:00+03	160200.00
CE9958	2017-07-29 00:05:00+03	16400.00
CE99A6	2017-08-11 23:56:00+03	46300.00
CE99F4	2017-08-01 23:08:00+03	59800.00
CE9A2C	2017-07-23 06:26:00+03	32800.00
CE9A31	2017-07-05 05:36:00+03	189200.00
CE9ADD	2017-08-12 01:22:00+03	44100.00
CE9B38	2017-08-09 03:23:00+03	67700.00
CE9B3E	2017-08-09 15:25:00+03	75600.00
CE9B63	2017-07-15 08:34:00+03	271100.00
CE9BB4	2017-08-04 10:28:00+03	43500.00
CE9BE5	2017-08-06 11:42:00+03	190100.00
CE9BE8	2017-07-26 06:23:00+03	66600.00
CE9C51	2017-07-26 03:02:00+03	235700.00
CE9C57	2017-08-11 16:18:00+03	80300.00
CE9C7B	2017-07-19 17:14:00+03	25400.00
CE9CE5	2017-08-03 14:11:00+03	79800.00
CE9CE8	2017-07-13 04:29:00+03	44700.00
CE9D06	2017-07-15 19:02:00+03	66600.00
CE9DBD	2017-07-30 09:22:00+03	96300.00
CE9E00	2017-07-06 18:46:00+03	6300.00
CE9E86	2017-08-10 05:51:00+03	26000.00
CE9E96	2017-08-13 10:30:00+03	72400.00
CE9E9D	2017-08-08 01:54:00+03	45200.00
CE9EC3	2017-08-11 19:21:00+03	31400.00
CE9F29	2017-07-08 16:08:00+03	114400.00
CE9F93	2017-08-05 03:54:00+03	160700.00
CE9FB9	2017-08-06 14:12:00+03	40800.00
CEA009	2017-08-11 05:10:00+03	36800.00
CEA020	2017-08-04 06:02:00+03	21200.00
CEA04C	2017-08-06 15:54:00+03	78000.00
CEA096	2017-08-04 09:35:00+03	46400.00
CEA0B1	2017-08-06 09:41:00+03	46200.00
CEA0E2	2017-07-19 20:25:00+03	70600.00
CEA166	2017-08-11 21:25:00+03	73600.00
CEA1C0	2017-08-04 03:21:00+03	24200.00
CEA1CA	2017-07-26 12:55:00+03	34400.00
CEA235	2017-08-04 15:44:00+03	178700.00
CEA29C	2017-07-30 14:04:00+03	54400.00
CEA2CE	2017-07-14 03:51:00+03	162600.00
CEA36F	2017-08-08 16:38:00+03	94000.00
CEA373	2017-08-15 11:47:00+03	21600.00
CEA3D1	2017-07-03 20:12:00+03	23600.00
CEA3F8	2017-08-02 09:55:00+03	81600.00
CEA418	2017-07-22 09:15:00+03	28000.00
CEA43F	2017-08-12 04:03:00+03	53100.00
CEA4FD	2017-07-20 16:48:00+03	172000.00
CEA51A	2017-08-13 21:11:00+03	48800.00
CEA543	2017-08-14 17:39:00+03	135000.00
CEA5A1	2017-07-06 04:50:00+03	79200.00
CEA5CC	2017-08-13 01:45:00+03	248400.00
CEA655	2017-07-08 18:23:00+03	196600.00
CEA65F	2017-08-13 12:03:00+03	53300.00
CEA69B	2017-07-31 12:23:00+03	85000.00
CEA6C8	2017-08-14 18:22:00+03	59000.00
CEA6E4	2017-07-18 02:32:00+03	47400.00
CEA76F	2017-07-25 06:44:00+03	288200.00
CEA779	2017-07-30 17:23:00+03	13200.00
CEA78E	2017-07-03 09:22:00+03	133100.00
CEA7E4	2017-08-15 03:05:00+03	47800.00
CEA885	2017-07-09 16:47:00+03	28800.00
CEA8B4	2017-08-08 18:17:00+03	95200.00
CEA8F0	2017-08-15 08:46:00+03	28000.00
CEA912	2017-07-21 22:54:00+03	28000.00
CEA942	2017-07-07 20:26:00+03	87900.00
CEA9B2	2017-08-02 21:08:00+03	10600.00
CEA9C7	2017-07-28 23:37:00+03	187800.00
CEAA0B	2017-08-02 22:02:00+03	57600.00
CEAAC7	2017-07-15 16:03:00+03	103800.00
CEAB16	2017-07-27 19:06:00+03	56100.00
CEAB23	2017-07-27 23:25:00+03	120000.00
CEAB4A	2017-07-10 11:00:00+03	57300.00
CEABAF	2017-07-30 23:15:00+03	25600.00
CEABBB	2017-07-21 21:29:00+03	132800.00
CEAC5B	2017-07-26 10:21:00+03	65100.00
CEAC73	2017-07-30 20:32:00+03	83100.00
CEAC81	2017-07-27 08:08:00+03	133200.00
CEAC8B	2017-07-16 15:10:00+03	16800.00
CEACC8	2017-08-13 21:48:00+03	18800.00
CEADC7	2017-07-18 08:42:00+03	115000.00
CEADF2	2017-08-03 13:24:00+03	15000.00
CEAE81	2017-07-10 20:33:00+03	131100.00
CEAE8C	2017-07-16 19:36:00+03	67200.00
CEAEA0	2017-07-10 23:58:00+03	153300.00
CEAEB8	2017-07-07 14:19:00+03	10800.00
CEAF22	2017-07-23 19:38:00+03	28700.00
CEAF3A	2017-07-06 01:04:00+03	134900.00
CEAF50	2017-08-08 00:01:00+03	147700.00
CEAF55	2017-07-18 03:51:00+03	46200.00
CEAF5C	2017-07-21 23:52:00+03	57500.00
CEAFCC	2017-07-10 10:13:00+03	134900.00
CEAFFA	2017-07-05 13:10:00+03	19600.00
CEB005	2017-07-16 22:00:00+03	23600.00
CEB02F	2017-08-14 00:44:00+03	111600.00
CEB068	2017-07-11 09:35:00+03	131600.00
CEB0A8	2017-08-13 19:01:00+03	20200.00
CEB0D8	2017-08-13 21:41:00+03	31400.00
CEB0EF	2017-07-06 02:03:00+03	22400.00
CEB159	2017-07-03 02:10:00+03	54400.00
CEB1F9	2017-08-08 21:09:00+03	34400.00
CEB21F	2017-07-01 00:31:00+03	123700.00
CEB266	2017-07-23 06:12:00+03	28800.00
CEB274	2017-07-22 00:44:00+03	53600.00
CEB30A	2017-07-18 11:10:00+03	130400.00
CEB358	2017-07-25 09:41:00+03	22000.00
CEB3AC	2017-08-08 04:59:00+03	73600.00
CEB3CC	2017-07-24 18:47:00+03	103500.00
CEB3F2	2017-07-12 14:50:00+03	9800.00
CEB4FB	2017-07-09 03:17:00+03	51600.00
CEB623	2017-07-28 09:48:00+03	39100.00
CEB665	2017-07-08 09:53:00+03	46300.00
CEB715	2017-07-22 16:52:00+03	57600.00
CEB7B2	2017-07-22 15:45:00+03	28000.00
CEB822	2017-07-27 04:46:00+03	79600.00
CEB82A	2017-07-07 20:29:00+03	70500.00
CEB82B	2017-08-12 11:19:00+03	28600.00
CEB88D	2017-08-05 01:59:00+03	12000.00
CEB8C1	2017-07-30 10:47:00+03	38400.00
CEB8C9	2017-07-24 06:12:00+03	19800.00
CEB8FA	2017-06-27 09:11:00+03	55800.00
CEB986	2017-07-23 03:49:00+03	124600.00
CEB9CA	2017-08-12 10:33:00+03	266200.00
CEBA72	2017-07-15 10:39:00+03	28000.00
CEBA81	2017-08-13 16:34:00+03	258400.00
CEBAC7	2017-07-19 09:35:00+03	118100.00
CEBB02	2017-07-20 15:10:00+03	185300.00
CEBB9D	2017-07-15 10:47:00+03	38800.00
CEBC34	2017-07-06 18:17:00+03	47000.00
CEBCAE	2017-07-02 19:53:00+03	138900.00
CEBCE8	2017-08-05 21:17:00+03	17600.00
CEBD4C	2017-07-27 14:55:00+03	47100.00
CEBD5D	2017-08-01 09:57:00+03	60000.00
CEBDEC	2017-07-27 12:19:00+03	56000.00
CEBE41	2017-07-04 23:06:00+03	18000.00
CEBE43	2017-07-11 09:33:00+03	61400.00
CEBE6F	2017-07-06 07:11:00+03	38500.00
CEBEAA	2017-07-13 23:49:00+03	86500.00
CEBEF0	2017-08-01 04:11:00+03	62600.00
CEBEFB	2017-07-28 06:27:00+03	197700.00
CEBFA6	2017-07-12 17:11:00+03	19600.00
CEBFC2	2017-08-10 03:51:00+03	129700.00
CEC0E0	2017-07-07 18:45:00+03	40800.00
CEC13A	2017-08-09 07:58:00+03	492000.00
CEC152	2017-07-30 04:22:00+03	31900.00
CEC191	2017-07-12 11:42:00+03	22100.00
CEC1E4	2017-07-05 20:38:00+03	86300.00
CEC1E9	2017-08-14 13:22:00+03	46200.00
CEC203	2017-08-02 22:48:00+03	55800.00
CEC228	2017-08-02 21:05:00+03	51600.00
CEC237	2017-08-14 21:07:00+03	59000.00
CEC24E	2017-07-14 14:01:00+03	138000.00
CEC251	2017-07-28 16:12:00+03	28800.00
CEC286	2017-07-13 18:48:00+03	46400.00
CEC29D	2017-07-12 02:22:00+03	67800.00
CEC2E9	2017-07-10 16:54:00+03	7400.00
CEC32E	2017-08-02 20:41:00+03	529100.00
CEC349	2017-07-31 00:01:00+03	64400.00
CEC3A8	2017-07-19 18:00:00+03	77500.00
CEC3C3	2017-08-15 02:32:00+03	12000.00
CEC3C6	2017-08-04 21:10:00+03	23400.00
CEC3CB	2017-07-26 18:40:00+03	44800.00
CEC421	2017-07-08 03:28:00+03	399600.00
CEC491	2017-08-15 10:02:00+03	137700.00
CEC4C6	2017-08-09 09:56:00+03	257600.00
CEC582	2017-08-08 13:16:00+03	68300.00
CEC592	2017-07-27 08:30:00+03	30100.00
CEC641	2017-07-19 23:04:00+03	20200.00
CEC68C	2017-08-01 08:11:00+03	28800.00
CEC6B8	2017-08-07 03:04:00+03	67000.00
CEC6C5	2017-08-04 03:51:00+03	43200.00
CEC71B	2017-07-13 06:24:00+03	88000.00
CEC759	2017-07-31 08:35:00+03	99600.00
CEC833	2017-07-31 21:19:00+03	47300.00
CEC863	2017-08-02 01:37:00+03	11800.00
CEC8C8	2017-07-17 17:37:00+03	68800.00
CEC8E8	2017-08-12 06:01:00+03	6800.00
CEC959	2017-07-09 10:07:00+03	74600.00
CEC974	2017-07-14 05:28:00+03	105000.00
CEC9E4	2017-08-10 03:12:00+03	35700.00
CECA49	2017-07-04 14:36:00+03	200300.00
CECA6E	2017-07-18 03:29:00+03	70700.00
CECAB5	2017-07-31 05:23:00+03	112000.00
CECAC3	2017-07-04 14:43:00+03	44700.00
CECB08	2017-07-23 16:06:00+03	48100.00
CECB4B	2017-07-16 08:19:00+03	13700.00
CECBC8	2017-07-29 16:05:00+03	25200.00
CECBCB	2017-08-12 11:24:00+03	19600.00
CECC65	2017-08-07 04:07:00+03	285100.00
CECC6D	2017-08-14 02:06:00+03	90600.00
CECC95	2017-07-12 02:30:00+03	35600.00
CECD86	2017-07-17 10:30:00+03	103500.00
CECDC1	2017-06-30 21:58:00+03	62600.00
CECDD7	2017-07-30 14:14:00+03	131900.00
CECDEF	2017-07-04 08:42:00+03	55500.00
CECE19	2017-07-04 01:18:00+03	78300.00
CECE58	2017-07-16 11:52:00+03	35700.00
CECE5C	2017-08-03 17:36:00+03	68800.00
CECE6D	2017-08-04 07:51:00+03	165500.00
CECEAE	2017-07-02 04:16:00+03	60400.00
CECED0	2017-07-31 17:15:00+03	55800.00
CECF5D	2017-08-10 16:16:00+03	82900.00
CECFBB	2017-08-10 19:58:00+03	22000.00
CECFEA	2017-08-14 14:36:00+03	81300.00
CED06D	2017-07-31 23:58:00+03	48800.00
CED0DE	2017-08-08 14:56:00+03	44000.00
CED176	2017-08-13 21:27:00+03	88000.00
CED24E	2017-08-06 13:47:00+03	17200.00
CED2BC	2017-07-26 03:55:00+03	36200.00
CED2E6	2017-07-21 04:08:00+03	111400.00
CED333	2017-07-27 07:51:00+03	51500.00
CED33D	2017-08-10 12:13:00+03	67600.00
CED351	2017-07-27 19:57:00+03	57700.00
CED3B4	2017-08-01 02:54:00+03	38400.00
CED3BB	2017-07-16 11:04:00+03	28000.00
CED3F4	2017-07-04 12:57:00+03	28000.00
CED402	2017-07-06 16:40:00+03	67600.00
CED434	2017-08-10 12:59:00+03	11800.00
CED459	2017-07-12 00:20:00+03	44500.00
CED487	2017-07-03 17:06:00+03	20400.00
CED4A6	2017-07-21 01:52:00+03	292300.00
CED51D	2017-07-23 11:44:00+03	35400.00
CED52B	2017-07-26 01:50:00+03	88800.00
CED591	2017-07-09 04:23:00+03	75300.00
CED5EB	2017-08-04 16:39:00+03	55800.00
CED663	2017-07-12 11:32:00+03	28000.00
CED700	2017-07-09 16:24:00+03	75300.00
CED71D	2017-07-12 08:59:00+03	16400.00
CED7C7	2017-08-05 23:52:00+03	22000.00
CED814	2017-08-03 20:41:00+03	27200.00
CED826	2017-08-12 00:56:00+03	57500.00
CED827	2017-08-12 23:38:00+03	75800.00
CED884	2017-07-10 06:33:00+03	136000.00
CED8CB	2017-07-22 11:25:00+03	92400.00
CED8FB	2017-08-09 10:08:00+03	66600.00
CED926	2017-08-03 23:57:00+03	22000.00
CED97F	2017-07-31 22:50:00+03	166000.00
CED999	2017-07-22 11:38:00+03	59800.00
CED9A2	2017-07-19 09:27:00+03	29400.00
CED9C6	2017-08-02 13:55:00+03	54400.00
CED9F7	2017-08-12 21:10:00+03	108000.00
CEDA05	2017-07-09 13:45:00+03	20200.00
CEDA5B	2017-08-03 12:58:00+03	56000.00
CEDA67	2017-07-26 16:00:00+03	58600.00
CEDAD7	2017-07-19 17:49:00+03	20000.00
CEDAE5	2017-08-02 00:22:00+03	36400.00
CEDBDE	2017-07-23 14:40:00+03	23600.00
CEDC91	2017-07-29 11:37:00+03	33200.00
CEDCC4	2017-07-30 10:32:00+03	60400.00
CEDD81	2017-07-14 01:19:00+03	66800.00
CEDDB8	2017-07-04 12:11:00+03	26000.00
CEDE4E	2017-07-26 11:30:00+03	168000.00
CEDE89	2017-07-11 09:43:00+03	194300.00
CEDEBF	2017-08-13 02:04:00+03	43800.00
CEDF6E	2017-07-28 20:22:00+03	89700.00
CEDFAC	2017-07-07 10:07:00+03	15000.00
CEDFC3	2017-07-11 22:11:00+03	64900.00
CEDFD3	2017-07-23 07:42:00+03	30200.00
CEE04E	2017-08-14 22:03:00+03	68000.00
CEE068	2017-07-12 12:36:00+03	101000.00
CEE06F	2017-07-19 21:26:00+03	73400.00
CEE0E2	2017-07-25 11:32:00+03	28800.00
CEE17A	2017-08-06 04:58:00+03	66600.00
CEE1BA	2017-07-17 18:33:00+03	19600.00
CEE1DE	2017-08-02 10:33:00+03	55800.00
CEE1E0	2017-07-18 00:49:00+03	44200.00
CEE1EB	2017-08-14 10:26:00+03	23200.00
CEE1EE	2017-07-16 10:15:00+03	70400.00
CEE20C	2017-07-27 00:22:00+03	72300.00
CEE24C	2017-07-16 10:52:00+03	265800.00
CEE29A	2017-07-31 20:51:00+03	133200.00
CEE2A9	2017-08-11 00:37:00+03	77900.00
CEE2D8	2017-07-14 06:35:00+03	38800.00
CEE2DF	2017-08-12 09:17:00+03	136600.00
CEE2FC	2017-07-19 11:13:00+03	25800.00
CEE320	2017-08-13 16:03:00+03	132800.00
CEE329	2017-07-07 19:59:00+03	30000.00
CEE36E	2017-08-01 09:53:00+03	92800.00
CEE3BB	2017-08-12 03:05:00+03	34400.00
CEE4B4	2017-08-14 20:58:00+03	70700.00
CEE4FB	2017-07-28 04:41:00+03	75300.00
CEE59D	2017-08-11 11:57:00+03	62100.00
CEE5AC	2017-07-31 07:53:00+03	38200.00
CEE63A	2017-08-08 01:14:00+03	46200.00
CEE65A	2017-07-28 16:57:00+03	79600.00
CEE663	2017-08-10 02:21:00+03	24200.00
CEE6B9	2017-08-06 22:39:00+03	119500.00
CEE78E	2017-07-24 15:28:00+03	70500.00
CEE790	2017-06-29 14:47:00+03	31400.00
CEE794	2017-07-18 12:26:00+03	239200.00
CEE7B9	2017-07-20 04:20:00+03	124200.00
CEE804	2017-07-14 12:48:00+03	25600.00
CEE82C	2017-07-01 18:40:00+03	112000.00
CEE884	2017-07-16 13:51:00+03	91500.00
CEE925	2017-08-02 11:00:00+03	78800.00
CEE95B	2017-07-25 12:48:00+03	42600.00
CEE964	2017-07-25 14:44:00+03	23600.00
CEE967	2017-08-03 22:39:00+03	6700.00
CEE9C3	2017-08-09 14:30:00+03	23200.00
CEE9C6	2017-08-02 04:43:00+03	26800.00
CEEA9C	2017-07-23 07:00:00+03	59200.00
CEEAA2	2017-07-26 15:05:00+03	85700.00
CEEAC2	2017-07-11 19:25:00+03	19300.00
CEEACF	2017-07-14 01:09:00+03	27900.00
CEEAE7	2017-08-03 16:54:00+03	64500.00
CEEB0E	2017-08-05 07:36:00+03	6700.00
CEEBB3	2017-08-11 14:32:00+03	56500.00
CEEBBA	2017-07-28 03:27:00+03	20400.00
CEEBE1	2017-07-27 02:59:00+03	12600.00
CEEC43	2017-07-08 12:28:00+03	94200.00
CEEC58	2017-07-29 23:16:00+03	124200.00
CEEC9B	2017-08-13 10:17:00+03	140300.00
CEECAF	2017-07-02 03:41:00+03	42800.00
CEECF9	2017-07-13 05:17:00+03	65900.00
CEED21	2017-08-07 20:01:00+03	172800.00
CEEDAF	2017-07-11 16:36:00+03	23400.00
CEEE1A	2017-07-18 11:48:00+03	88100.00
CEEE49	2017-07-13 20:56:00+03	65200.00
CEEEB7	2017-07-14 23:28:00+03	59100.00
CEEECC	2017-08-12 14:03:00+03	149000.00
CEEEF7	2017-08-09 21:06:00+03	50600.00
CEEF33	2017-07-24 02:17:00+03	32700.00
CEEFEB	2017-07-18 06:53:00+03	92100.00
CEEFF8	2017-07-17 17:55:00+03	23600.00
CEF01E	2017-07-31 20:38:00+03	47400.00
CEF048	2017-07-08 07:39:00+03	23600.00
CEF05A	2017-07-12 05:06:00+03	132800.00
CEF063	2017-07-23 10:23:00+03	25800.00
CEF066	2017-06-29 03:27:00+03	60400.00
CEF07C	2017-08-02 18:08:00+03	303100.00
CEF082	2017-07-15 22:41:00+03	226200.00
CEF0D8	2017-07-24 19:09:00+03	123000.00
CEF149	2017-07-08 01:15:00+03	25000.00
CEF14F	2017-07-10 08:35:00+03	28800.00
CEF158	2017-07-05 11:31:00+03	30200.00
CEF15C	2017-08-13 08:15:00+03	28000.00
CEF18F	2017-07-19 10:38:00+03	13200.00
CEF1DF	2017-06-26 00:07:00+03	40400.00
CEF26A	2017-07-14 15:23:00+03	6000.00
CEF273	2017-07-26 03:27:00+03	276200.00
CEF28B	2017-07-14 05:58:00+03	23200.00
CEF29D	2017-07-04 11:28:00+03	35800.00
CEF2A0	2017-07-22 03:45:00+03	124300.00
CEF2EF	2017-08-13 05:01:00+03	46200.00
CEF2FC	2017-07-18 16:54:00+03	7400.00
CEF4B9	2017-08-14 22:05:00+03	269600.00
CEF4C3	2017-07-20 04:16:00+03	369000.00
CEF4D7	2017-07-23 01:47:00+03	68800.00
CEF4E8	2017-08-08 12:15:00+03	32800.00
CEF504	2017-08-06 23:25:00+03	51900.00
CEF54A	2017-07-03 10:26:00+03	50600.00
CEF54C	2017-07-15 00:07:00+03	204900.00
CEF587	2017-08-13 19:33:00+03	24400.00
CEF5F0	2017-08-08 04:09:00+03	75300.00
CEF62A	2017-08-14 20:23:00+03	40800.00
CEF65B	2017-07-21 22:41:00+03	16400.00
CEF74B	2017-07-30 14:49:00+03	46000.00
CEF769	2017-07-09 10:16:00+03	202300.00
CEF7BB	2017-07-15 13:04:00+03	67300.00
CEF825	2017-07-23 03:38:00+03	70100.00
CEF831	2017-07-27 17:44:00+03	266400.00
CEF832	2017-07-20 18:14:00+03	6700.00
CEF834	2017-08-06 01:09:00+03	181600.00
CEF887	2017-08-10 02:20:00+03	34300.00
CEF888	2017-07-30 07:08:00+03	34000.00
CEF8A6	2017-07-28 10:27:00+03	169900.00
CEF8B2	2017-07-12 06:35:00+03	55800.00
CEF8E9	2017-07-24 05:50:00+03	54300.00
CEF94E	2017-06-30 11:06:00+03	137600.00
CEF959	2017-07-16 16:57:00+03	36800.00
CEF99E	2017-07-10 06:35:00+03	62800.00
CEF9A3	2017-08-13 21:18:00+03	62600.00
CEF9B8	2017-07-12 12:13:00+03	55800.00
CEF9DA	2017-07-05 04:55:00+03	49400.00
CEFA60	2017-07-07 22:20:00+03	84500.00
CEFAB8	2017-08-14 03:35:00+03	262000.00
CEFB0D	2017-08-01 00:19:00+03	257600.00
CEFB52	2017-07-08 00:32:00+03	139300.00
CEFB65	2017-07-29 21:48:00+03	46300.00
CEFBFD	2017-07-31 21:22:00+03	75300.00
CEFC97	2017-06-30 08:55:00+03	62800.00
CEFC99	2017-07-23 08:26:00+03	132800.00
CEFCBC	2017-07-03 01:29:00+03	83000.00
CEFD69	2017-07-13 03:26:00+03	87400.00
CEFD6D	2017-07-07 08:46:00+03	128800.00
CEFDCE	2017-07-22 00:58:00+03	67200.00
CEFDE8	2017-08-06 02:58:00+03	133200.00
CEFE72	2017-08-11 05:26:00+03	26800.00
CEFED5	2017-08-08 04:07:00+03	233700.00
CEFF49	2017-07-08 18:25:00+03	161400.00
CEFF52	2017-07-24 05:58:00+03	398500.00
CEFF67	2017-08-11 06:16:00+03	54400.00
CEFF98	2017-08-04 13:48:00+03	31200.00
CEFFA2	2017-08-14 07:54:00+03	32800.00
CEFFC2	2017-07-08 13:38:00+03	31700.00
CEFFFC	2017-08-11 14:21:00+03	47500.00
CF0059	2017-08-07 12:13:00+03	33800.00
CF00B2	2017-08-07 11:22:00+03	22100.00
CF00F1	2017-07-12 17:27:00+03	75600.00
CF0134	2017-07-20 10:33:00+03	99600.00
CF0151	2017-07-10 05:29:00+03	7200.00
CF0198	2017-08-04 21:33:00+03	100000.00
CF01C0	2017-07-15 10:54:00+03	36700.00
CF0208	2017-07-13 01:57:00+03	31400.00
CF0215	2017-07-26 14:30:00+03	23200.00
CF024D	2017-07-30 20:38:00+03	102600.00
CF0289	2017-07-16 23:36:00+03	114400.00
CF028A	2017-08-06 18:50:00+03	83200.00
CF0291	2017-07-06 15:31:00+03	133200.00
CF02A5	2017-07-25 11:59:00+03	22100.00
CF02D0	2017-07-26 09:43:00+03	26000.00
CF02DE	2017-08-09 01:48:00+03	7400.00
CF02E4	2017-07-19 00:04:00+03	83600.00
CF02ED	2017-07-26 01:33:00+03	47000.00
CF02F0	2017-07-15 18:44:00+03	14800.00
CF02F6	2017-07-25 10:41:00+03	8400.00
CF0330	2017-08-11 02:02:00+03	12000.00
CF0351	2017-08-14 15:45:00+03	13200.00
CF0352	2017-07-16 19:11:00+03	81200.00
CF0382	2017-07-16 13:41:00+03	20500.00
CF0430	2017-06-30 01:40:00+03	18300.00
CF04B9	2017-07-31 20:51:00+03	60300.00
CF04FA	2017-07-03 13:05:00+03	9800.00
CF052C	2017-07-25 20:13:00+03	58700.00
CF0549	2017-06-28 09:08:00+03	6600.00
CF05A3	2017-07-17 10:15:00+03	27200.00
CF05AE	2017-07-29 18:52:00+03	26600.00
CF05AF	2017-08-14 14:34:00+03	75300.00
CF05B9	2017-07-27 13:01:00+03	70600.00
CF05C7	2017-06-29 05:21:00+03	26500.00
CF05E5	2017-08-04 04:00:00+03	12600.00
CF05EF	2017-07-20 17:39:00+03	55800.00
CF0654	2017-07-03 00:17:00+03	62000.00
CF071D	2017-08-10 13:55:00+03	93600.00
CF078A	2017-07-30 10:47:00+03	50400.00
CF07AA	2017-08-08 06:23:00+03	46000.00
CF07C7	2017-08-07 22:27:00+03	135000.00
CF07F2	2017-07-09 04:08:00+03	66600.00
CF0838	2017-08-15 05:12:00+03	10800.00
CF0839	2017-07-16 15:20:00+03	58800.00
CF0875	2017-07-29 14:46:00+03	6000.00
CF08A3	2017-07-31 18:04:00+03	76800.00
CF08C8	2017-07-12 01:07:00+03	381800.00
CF08E5	2017-07-24 06:14:00+03	26000.00
CF0992	2017-08-14 07:09:00+03	70500.00
CF0A0C	2017-08-09 08:32:00+03	64700.00
CF0A24	2017-07-20 05:27:00+03	65300.00
CF0A47	2017-07-13 14:12:00+03	130900.00
CF0A4F	2017-07-16 07:48:00+03	45200.00
CF0A8C	2017-08-06 07:30:00+03	55800.00
CF0AC1	2017-07-25 23:05:00+03	8000.00
CF0B05	2017-08-15 08:51:00+03	85000.00
CF0B5F	2017-07-23 22:44:00+03	56000.00
CF0BB4	2017-08-13 14:33:00+03	246000.00
CF0BCC	2017-07-04 14:33:00+03	28000.00
CF0BCD	2017-07-08 10:04:00+03	75300.00
CF0BFA	2017-07-16 19:45:00+03	20000.00
CF0C32	2017-06-29 02:24:00+03	34400.00
CF0C41	2017-08-13 22:30:00+03	84800.00
CF0C83	2017-07-08 19:38:00+03	86600.00
CF0CE7	2017-07-13 20:16:00+03	97900.00
CF0CF6	2017-07-03 01:04:00+03	44000.00
CF0CFE	2017-08-15 17:09:00+03	83200.00
CF0D48	2017-08-04 06:26:00+03	126300.00
CF0D6A	2017-07-18 13:53:00+03	25400.00
CF0D84	2017-07-26 12:32:00+03	56000.00
CF0DCD	2017-07-11 02:24:00+03	28800.00
CF0E24	2017-08-12 05:39:00+03	259000.00
CF0F9D	2017-08-10 13:39:00+03	119300.00
CF0FD1	2017-07-03 19:49:00+03	9200.00
CF0FE4	2017-06-25 12:52:00+03	30000.00
CF0FFD	2017-07-05 11:06:00+03	129100.00
CF107E	2017-07-13 07:23:00+03	66600.00
CF1080	2017-07-15 03:23:00+03	71400.00
CF112A	2017-07-12 22:27:00+03	48800.00
CF1152	2017-07-18 03:19:00+03	35800.00
CF12C8	2017-07-26 16:06:00+03	149200.00
CF130F	2017-08-12 08:46:00+03	133200.00
CF1324	2017-07-14 21:14:00+03	25200.00
CF13D8	2017-07-12 11:04:00+03	47600.00
CF143D	2017-07-21 06:57:00+03	36400.00
CF14A3	2017-07-06 08:05:00+03	73600.00
CF14B3	2017-07-11 16:59:00+03	793500.00
CF150B	2017-07-21 08:43:00+03	56000.00
CF150F	2017-07-21 04:20:00+03	69400.00
CF1526	2017-08-02 23:27:00+03	56000.00
CF152C	2017-07-17 09:55:00+03	89600.00
CF15CF	2017-08-05 22:49:00+03	81900.00
CF1644	2017-08-08 03:24:00+03	25900.00
CF167E	2017-08-01 17:29:00+03	28800.00
CF1708	2017-07-12 19:12:00+03	151000.00
CF1743	2017-07-20 06:01:00+03	103000.00
CF1790	2017-07-18 17:25:00+03	112000.00
CF1796	2017-07-03 10:18:00+03	24400.00
CF17A1	2017-07-25 23:05:00+03	50600.00
CF17D0	2017-07-04 13:24:00+03	58600.00
CF185B	2017-08-08 07:03:00+03	8200.00
CF1866	2017-07-27 23:48:00+03	10800.00
CF1966	2017-08-15 12:59:00+03	6300.00
CF1967	2017-08-14 14:59:00+03	56000.00
CF1990	2017-07-05 19:07:00+03	55800.00
CF19FA	2017-08-08 22:57:00+03	521800.00
CF1A0C	2017-07-28 01:10:00+03	31900.00
CF1A19	2017-07-05 05:47:00+03	134700.00
CF1A6B	2017-07-31 21:43:00+03	49100.00
CF1A92	2017-07-04 05:48:00+03	102100.00
CF1AA6	2017-08-09 02:07:00+03	70600.00
CF1ACD	2017-07-05 20:21:00+03	193600.00
CF1B2C	2017-08-15 05:53:00+03	71900.00
CF1BB5	2017-08-02 12:09:00+03	22400.00
CF1BC5	2017-08-10 08:47:00+03	157100.00
CF1BEF	2017-07-23 14:38:00+03	41800.00
CF1C67	2017-07-14 16:55:00+03	59800.00
CF1CC1	2017-07-27 16:31:00+03	113800.00
CF1CE7	2017-07-03 16:19:00+03	61500.00
CF1CF0	2017-07-19 23:05:00+03	85000.00
CF1CFC	2017-07-28 04:06:00+03	56000.00
CF1D09	2017-06-29 18:02:00+03	119600.00
CF1D73	2017-08-03 23:05:00+03	55800.00
CF1DBA	2017-07-09 05:19:00+03	189800.00
CF1DE3	2017-07-01 12:34:00+03	21400.00
CF1E0C	2017-06-27 07:12:00+03	18100.00
CF1E1A	2017-07-11 07:52:00+03	23600.00
CF1E65	2017-08-13 03:26:00+03	108900.00
CF1E8B	2017-07-05 21:28:00+03	64500.00
CF1ECE	2017-07-26 01:16:00+03	26800.00
CF1EE4	2017-07-25 21:18:00+03	22000.00
CF1F41	2017-07-26 05:43:00+03	33300.00
CF1F62	2017-07-21 02:39:00+03	108500.00
CF1FB8	2017-07-03 07:59:00+03	48100.00
CF216A	2017-07-25 00:25:00+03	40800.00
CF21DC	2017-08-05 20:49:00+03	88200.00
CF2226	2017-06-30 05:05:00+03	46400.00
CF2284	2017-07-30 00:32:00+03	77000.00
CF229A	2017-07-10 10:24:00+03	102100.00
CF22B1	2017-07-17 18:43:00+03	14000.00
CF234E	2017-08-11 10:21:00+03	36800.00
CF2365	2017-08-06 17:43:00+03	52700.00
CF238F	2017-08-03 01:25:00+03	139000.00
CF23C8	2017-07-14 20:29:00+03	6600.00
CF23E7	2017-08-10 12:12:00+03	132800.00
CF2410	2017-07-07 07:26:00+03	248400.00
CF24F4	2017-07-03 02:28:00+03	22200.00
CF2574	2017-08-05 03:51:00+03	266400.00
CF25C7	2017-07-30 03:40:00+03	30000.00
CF25F5	2017-07-23 07:37:00+03	20500.00
CF26A8	2017-08-07 13:07:00+03	133200.00
CF26DE	2017-08-01 22:34:00+03	26700.00
CF2741	2017-07-06 05:31:00+03	288300.00
CF2763	2017-06-29 13:03:00+03	46400.00
CF277B	2017-08-03 22:48:00+03	123000.00
CF2804	2017-07-11 20:40:00+03	67600.00
CF2808	2017-08-12 06:57:00+03	56000.00
CF2818	2017-07-24 15:02:00+03	134400.00
CF282D	2017-07-20 14:35:00+03	72400.00
CF291D	2017-07-16 19:13:00+03	55100.00
CF2A24	2017-07-06 13:53:00+03	356200.00
CF2A2F	2017-07-31 05:42:00+03	23200.00
CF2B34	2017-08-13 03:20:00+03	221000.00
CF2B4C	2017-08-09 20:37:00+03	25600.00
CF2B7B	2017-07-13 22:37:00+03	24200.00
CF2BD1	2017-07-24 15:36:00+03	13600.00
CF2BDE	2017-07-15 21:06:00+03	32700.00
CF2BEB	2017-07-08 18:32:00+03	23400.00
CF2BEC	2017-07-03 01:59:00+03	20200.00
CF2C21	2017-07-01 09:16:00+03	65100.00
CF2C2A	2017-08-15 15:46:00+03	123000.00
CF2C6D	2017-07-22 15:43:00+03	16400.00
CF2C81	2017-07-06 21:40:00+03	66600.00
CF2CAC	2017-08-10 04:25:00+03	170900.00
CF2D2A	2017-07-24 14:41:00+03	70200.00
CF2DF1	2017-07-07 00:45:00+03	21800.00
CF2EC6	2017-07-15 16:29:00+03	46000.00
CF2EE1	2017-07-30 22:41:00+03	56000.00
CF2F06	2017-07-24 17:31:00+03	144000.00
CF2F47	2017-07-24 17:34:00+03	26700.00
CF2F72	2017-07-20 15:59:00+03	52100.00
CF2F7B	2017-08-03 14:09:00+03	28800.00
CF2F9A	2017-07-25 09:03:00+03	31600.00
CF2F9C	2017-07-08 03:29:00+03	87100.00
CF2FA5	2017-08-05 13:31:00+03	108500.00
CF2FD3	2017-07-18 11:49:00+03	19800.00
CF2FE0	2017-08-04 01:14:00+03	28000.00
CF3025	2017-07-07 19:37:00+03	102100.00
CF3028	2017-07-03 02:20:00+03	12000.00
CF3067	2017-07-24 23:02:00+03	35700.00
CF309E	2017-07-21 18:36:00+03	202100.00
CF30D7	2017-07-25 18:47:00+03	84100.00
CF3148	2017-08-02 21:56:00+03	57300.00
CF3169	2017-08-06 21:42:00+03	170000.00
CF3179	2017-07-06 05:57:00+03	125700.00
CF31C5	2017-07-30 04:12:00+03	23200.00
CF31D4	2017-08-10 05:49:00+03	40800.00
CF31DE	2017-08-08 01:33:00+03	134700.00
CF31E3	2017-08-07 03:50:00+03	34200.00
CF3211	2017-07-09 19:54:00+03	65900.00
CF3266	2017-07-03 16:16:00+03	48800.00
CF3330	2017-07-12 14:49:00+03	189800.00
CF3351	2017-06-29 02:24:00+03	40000.00
CF335A	2017-08-13 16:20:00+03	19600.00
CF337C	2017-08-05 13:04:00+03	35600.00
CF339B	2017-07-16 10:43:00+03	45000.00
CF33F7	2017-07-17 20:01:00+03	42800.00
CF3426	2017-08-12 22:34:00+03	97600.00
CF34CF	2017-08-15 03:36:00+03	15000.00
CF34F5	2017-07-01 15:55:00+03	24000.00
CF3558	2017-07-14 02:54:00+03	20400.00
CF362B	2017-08-14 22:28:00+03	66600.00
CF364C	2017-07-26 01:46:00+03	38900.00
CF36D7	2017-07-30 04:09:00+03	92800.00
CF378A	2017-08-06 15:28:00+03	59200.00
CF37BC	2017-07-03 18:47:00+03	56600.00
CF3827	2017-08-02 15:06:00+03	57800.00
CF382F	2017-07-06 21:53:00+03	57800.00
CF3846	2017-07-30 03:14:00+03	32200.00
CF384B	2017-07-31 22:08:00+03	58000.00
CF38D0	2017-07-04 23:05:00+03	32700.00
CF38E8	2017-07-03 08:56:00+03	26500.00
CF3990	2017-07-02 15:40:00+03	28000.00
CF399B	2017-08-14 04:43:00+03	27600.00
CF39F7	2017-08-01 18:38:00+03	79900.00
CF3A55	2017-08-10 06:54:00+03	26000.00
CF3AB7	2017-07-07 17:53:00+03	27300.00
CF3AD8	2017-07-14 16:13:00+03	54400.00
CF3B97	2017-07-30 22:44:00+03	32800.00
CF3C0A	2017-07-18 15:19:00+03	86300.00
CF3C59	2017-08-09 03:36:00+03	99000.00
CF3CCE	2017-07-16 03:10:00+03	26000.00
CF3D02	2017-07-30 10:09:00+03	30000.00
CF3D6E	2017-08-06 10:17:00+03	283000.00
CF3D85	2017-07-15 10:37:00+03	14400.00
CF3DF8	2017-08-14 14:45:00+03	137000.00
CF3E30	2017-08-14 08:42:00+03	284400.00
CF3E7E	2017-07-27 00:51:00+03	79900.00
CF3EB4	2017-07-07 14:47:00+03	40000.00
CF3F4F	2017-08-08 11:01:00+03	272400.00
CF3F7E	2017-08-09 15:55:00+03	101400.00
CF3F8A	2017-08-01 09:30:00+03	80900.00
CF3FD6	2017-07-04 19:09:00+03	200200.00
CF400E	2017-08-07 07:43:00+03	73400.00
CF408F	2017-07-27 05:52:00+03	131100.00
CF40B6	2017-07-14 04:13:00+03	22000.00
CF4107	2017-07-08 02:23:00+03	27200.00
CF418F	2017-07-11 02:51:00+03	154700.00
CF41EF	2017-07-15 02:37:00+03	95200.00
CF41FF	2017-08-01 11:18:00+03	93000.00
CF4226	2017-07-16 08:06:00+03	354400.00
CF4241	2017-07-20 23:57:00+03	52000.00
CF424A	2017-08-03 13:53:00+03	14000.00
CF4252	2017-08-12 13:19:00+03	131600.00
CF428D	2017-07-11 02:50:00+03	40400.00
CF42B6	2017-06-30 22:39:00+03	102100.00
CF42B8	2017-07-10 04:38:00+03	259100.00
CF4304	2017-07-10 10:42:00+03	66000.00
CF4309	2017-07-09 07:49:00+03	100600.00
CF4364	2017-07-29 15:26:00+03	58000.00
CF4372	2017-06-26 16:33:00+03	131100.00
CF4376	2017-08-01 21:32:00+03	13400.00
CF4418	2017-08-06 03:27:00+03	149300.00
CF4450	2017-07-08 23:16:00+03	55800.00
CF4452	2017-07-30 18:31:00+03	178800.00
CF446C	2017-07-28 06:27:00+03	113600.00
CF4470	2017-08-14 09:45:00+03	82900.00
CF4566	2017-07-22 21:38:00+03	111600.00
CF456B	2017-08-13 12:57:00+03	38600.00
CF457B	2017-08-07 03:54:00+03	34000.00
CF4582	2017-07-19 12:21:00+03	61500.00
CF4589	2017-08-08 09:17:00+03	14000.00
CF4635	2017-07-11 19:28:00+03	84100.00
CF469F	2017-07-14 23:05:00+03	32300.00
CF4763	2017-06-30 14:16:00+03	38600.00
CF47FB	2017-07-09 20:49:00+03	67700.00
CF485E	2017-07-09 04:24:00+03	56400.00
CF487D	2017-08-04 03:27:00+03	46400.00
CF488C	2017-07-30 07:53:00+03	45200.00
CF4912	2017-08-03 04:30:00+03	269500.00
CF4948	2017-07-28 14:23:00+03	99300.00
CF496D	2017-08-11 14:55:00+03	38600.00
CF499F	2017-08-15 17:15:00+03	53600.00
CF49C3	2017-07-29 23:42:00+03	90400.00
CF49DC	2017-08-13 01:18:00+03	26000.00
CF49F4	2017-08-12 11:34:00+03	49100.00
CF4A09	2017-07-09 12:51:00+03	26000.00
CF4A42	2017-07-09 22:26:00+03	70600.00
CF4A54	2017-07-20 21:17:00+03	257500.00
CF4A6E	2017-07-12 02:44:00+03	27800.00
CF4A79	2017-07-02 16:59:00+03	90800.00
CF4A9D	2017-07-01 07:45:00+03	304800.00
CF4AA5	2017-08-05 15:54:00+03	116400.00
CF4AAA	2017-08-07 08:42:00+03	67600.00
CF4AD7	2017-07-01 13:41:00+03	96100.00
CF4AD8	2017-07-15 03:56:00+03	32400.00
CF4AE7	2017-08-07 12:24:00+03	62800.00
CF4B42	2017-07-05 23:16:00+03	99200.00
CF4C52	2017-07-01 23:17:00+03	92800.00
CF4CFA	2017-08-11 06:32:00+03	48800.00
CF4D07	2017-07-26 06:53:00+03	28300.00
CF4D27	2017-07-23 17:41:00+03	22000.00
CF4E12	2017-07-17 03:27:00+03	202100.00
CF4E36	2017-07-18 01:13:00+03	84500.00
CF4E5D	2017-07-26 03:55:00+03	30200.00
CF4ED2	2017-08-10 03:03:00+03	67200.00
CF4F03	2017-07-26 03:00:00+03	66000.00
CF4FE8	2017-08-10 06:06:00+03	128800.00
CF5005	2017-07-27 15:20:00+03	71200.00
CF5031	2017-08-05 14:16:00+03	57800.00
CF504D	2017-07-21 17:00:00+03	38800.00
CF50E6	2017-08-07 00:15:00+03	67600.00
CF50F6	2017-07-11 18:46:00+03	23200.00
CF50F8	2017-07-25 21:31:00+03	141400.00
CF5147	2017-07-07 07:55:00+03	10600.00
CF51A2	2017-07-15 15:19:00+03	51600.00
CF51A4	2017-07-28 13:54:00+03	28000.00
CF51BE	2017-07-07 12:51:00+03	134700.00
CF51FE	2017-08-02 12:55:00+03	82100.00
CF5216	2017-07-22 05:01:00+03	126400.00
CF5271	2017-07-14 08:38:00+03	95200.00
CF5290	2017-08-07 06:04:00+03	47100.00
CF52AC	2017-07-03 09:26:00+03	27200.00
CF52F8	2017-06-30 07:59:00+03	117600.00
CF531B	2017-08-09 10:37:00+03	11600.00
CF5366	2017-08-13 18:55:00+03	99200.00
CF53B8	2017-07-08 03:22:00+03	552600.00
CF53D7	2017-07-04 07:35:00+03	35800.00
CF53F8	2017-08-07 12:00:00+03	72600.00
CF53FA	2017-07-12 15:46:00+03	47100.00
CF5421	2017-07-05 21:51:00+03	166100.00
CF546F	2017-08-15 05:03:00+03	138600.00
CF5478	2017-08-13 23:08:00+03	28800.00
CF54B9	2017-07-17 20:19:00+03	90800.00
CF54C9	2017-07-26 08:08:00+03	62700.00
CF54D2	2017-08-02 12:56:00+03	135000.00
CF5511	2017-07-04 15:41:00+03	113200.00
CF55B0	2017-07-30 18:09:00+03	28700.00
CF55B3	2017-07-10 12:00:00+03	14800.00
CF55CF	2017-08-12 09:40:00+03	10800.00
CF5629	2017-08-15 02:53:00+03	56700.00
CF566A	2017-07-09 16:22:00+03	229400.00
CF566F	2017-07-17 08:00:00+03	18300.00
CF568A	2017-08-01 14:35:00+03	43900.00
CF56A8	2017-08-01 11:19:00+03	112000.00
CF56D0	2017-08-03 05:03:00+03	36200.00
CF5754	2017-07-31 14:24:00+03	139800.00
CF57B8	2017-07-06 19:36:00+03	394900.00
CF57CE	2017-07-14 05:25:00+03	96800.00
CF5871	2017-07-11 16:04:00+03	198400.00
CF588E	2017-07-19 21:20:00+03	29500.00
CF58BC	2017-08-13 06:40:00+03	168000.00
CF58F6	2017-07-30 01:28:00+03	11000.00
CF59B5	2017-07-11 10:42:00+03	177200.00
CF5A4A	2017-06-29 08:49:00+03	14000.00
CF5A7B	2017-07-20 04:19:00+03	15000.00
CF5AB5	2017-08-10 19:24:00+03	89700.00
CF5AC4	2017-07-04 23:43:00+03	12600.00
CF5AC9	2017-08-04 17:05:00+03	42700.00
CF5BD6	2017-07-18 12:24:00+03	23600.00
CF5BFB	2017-08-15 13:37:00+03	20400.00
CF5C42	2017-07-23 15:01:00+03	31600.00
CF5C53	2017-08-11 10:52:00+03	89600.00
CF5C5F	2017-08-08 01:56:00+03	532800.00
CF5CC6	2017-07-06 01:19:00+03	22600.00
CF5E32	2017-08-13 15:10:00+03	38400.00
CF5E4A	2017-07-17 02:20:00+03	28800.00
CF5E5A	2017-08-10 23:12:00+03	47000.00
CF5E8D	2017-07-14 15:03:00+03	19600.00
CF5E94	2017-08-02 23:24:00+03	213200.00
CF5EA4	2017-07-23 06:25:00+03	33100.00
CF5EAD	2017-07-02 05:13:00+03	12000.00
CF5EED	2017-07-21 04:17:00+03	169900.00
CF5F2B	2017-07-12 06:47:00+03	62800.00
CF5F81	2017-07-27 21:00:00+03	42700.00
CF5FE0	2017-07-22 22:40:00+03	81600.00
CF5FE9	2017-07-11 07:18:00+03	24600.00
CF60CD	2017-07-24 14:08:00+03	55800.00
CF610D	2017-07-10 20:55:00+03	134700.00
CF6122	2017-07-14 23:05:00+03	31600.00
CF6145	2017-08-03 02:32:00+03	51600.00
CF61BC	2017-08-11 03:36:00+03	33400.00
CF6201	2017-07-03 11:40:00+03	36800.00
CF6234	2017-07-29 05:27:00+03	304100.00
CF6283	2017-08-07 13:44:00+03	174900.00
CF6287	2017-08-12 07:25:00+03	29800.00
CF62A9	2017-07-30 10:49:00+03	38600.00
CF62B1	2017-07-02 01:58:00+03	54800.00
CF62B3	2017-07-18 12:33:00+03	88600.00
CF62C6	2017-07-03 21:41:00+03	22000.00
CF62D6	2017-07-20 19:26:00+03	102100.00
CF632F	2017-07-29 06:39:00+03	45000.00
CF6335	2017-07-27 09:01:00+03	15000.00
CF6347	2017-07-23 23:03:00+03	66600.00
CF6380	2017-07-15 14:07:00+03	26800.00
CF638D	2017-07-12 09:43:00+03	46500.00
CF63AD	2017-07-10 11:46:00+03	67200.00
CF63EE	2017-08-09 14:37:00+03	135100.00
CF63FF	2017-06-30 18:30:00+03	25000.00
CF6407	2017-07-24 14:58:00+03	39800.00
CF6478	2017-07-27 13:38:00+03	8200.00
CF649E	2017-07-04 11:56:00+03	131100.00
CF64BE	2017-07-16 08:10:00+03	63500.00
CF6556	2017-07-06 02:05:00+03	97000.00
CF6571	2017-08-04 13:27:00+03	60000.00
CF669F	2017-07-26 19:16:00+03	22000.00
CF66A9	2017-07-08 17:17:00+03	54800.00
CF66D3	2017-07-13 23:04:00+03	135400.00
CF66D9	2017-08-14 17:01:00+03	69000.00
CF6723	2017-08-13 12:23:00+03	86600.00
CF6763	2017-07-19 06:26:00+03	133200.00
CF6765	2017-07-22 17:04:00+03	40000.00
CF67AA	2017-07-17 18:58:00+03	113800.00
CF6886	2017-07-05 17:39:00+03	35800.00
CF68DA	2017-07-29 09:13:00+03	79600.00
CF6909	2017-08-05 01:08:00+03	397700.00
CF6946	2017-07-21 06:08:00+03	24800.00
CF6985	2017-07-16 07:11:00+03	16400.00
CF6A23	2017-08-06 04:26:00+03	54400.00
CF6A5A	2017-06-30 15:32:00+03	135000.00
CF6A80	2017-07-07 10:32:00+03	39200.00
CF6AAF	2017-08-02 23:59:00+03	23200.00
CF6AD9	2017-07-25 07:33:00+03	26000.00
CF6AF2	2017-07-29 05:50:00+03	80400.00
CF6BA7	2017-08-12 03:43:00+03	64700.00
CF6C3A	2017-08-14 14:50:00+03	12000.00
CF6C44	2017-07-02 12:36:00+03	13400.00
CF6C5D	2017-07-09 00:36:00+03	60800.00
CF6C97	2017-07-29 22:15:00+03	168300.00
CF6D05	2017-07-22 13:48:00+03	45500.00
CF6D6E	2017-08-08 02:24:00+03	85000.00
CF6DBD	2017-07-25 12:22:00+03	21400.00
CF6E27	2017-07-25 09:36:00+03	135200.00
CF6E41	2017-07-20 02:25:00+03	35200.00
CF6EE4	2017-08-14 23:36:00+03	15100.00
CF6F20	2017-07-28 23:59:00+03	76800.00
CF6F56	2017-07-17 12:02:00+03	179400.00
CF6FC0	2017-08-07 12:38:00+03	51200.00
CF7047	2017-07-18 16:43:00+03	56000.00
CF70ED	2017-07-24 11:42:00+03	16400.00
CF70EE	2017-07-04 00:45:00+03	116000.00
CF7110	2017-08-05 16:40:00+03	7400.00
CF7167	2017-07-27 20:34:00+03	123000.00
CF7264	2017-08-08 01:23:00+03	40800.00
CF728F	2017-07-29 11:08:00+03	28200.00
CF72FC	2017-08-03 16:47:00+03	29100.00
CF741E	2017-06-27 17:11:00+03	3700.00
CF7422	2017-07-06 00:08:00+03	84000.00
CF750A	2017-08-11 01:10:00+03	39800.00
CF753C	2017-07-04 11:43:00+03	68800.00
CF755A	2017-07-04 13:34:00+03	23200.00
CF75C9	2017-08-11 09:06:00+03	258400.00
CF75F8	2017-06-27 14:17:00+03	31600.00
CF7659	2017-08-05 04:18:00+03	22600.00
CF76BC	2017-08-04 20:57:00+03	102100.00
CF76BF	2017-07-08 09:13:00+03	48800.00
CF76EF	2017-07-21 21:55:00+03	47800.00
CF7702	2017-07-04 20:49:00+03	19600.00
CF7751	2017-08-14 18:44:00+03	44800.00
CF7752	2017-07-15 13:16:00+03	53300.00
CF777A	2017-07-01 19:06:00+03	181400.00
CF7790	2017-08-13 21:20:00+03	380200.00
CF77C5	2017-07-26 02:49:00+03	40300.00
CF7832	2017-08-05 07:52:00+03	68800.00
CF7871	2017-07-02 08:53:00+03	58400.00
CF7968	2017-08-05 18:02:00+03	106600.00
CF79D8	2017-07-24 04:08:00+03	80000.00
CF7A43	2017-08-06 16:07:00+03	26000.00
CF7A67	2017-07-08 00:06:00+03	34100.00
CF7B99	2017-07-27 00:18:00+03	86400.00
CF7C88	2017-07-09 16:52:00+03	85000.00
CF7D54	2017-07-11 17:29:00+03	24400.00
CF7D71	2017-07-15 16:23:00+03	397700.00
CF7DE3	2017-07-30 14:39:00+03	124600.00
CF7E32	2017-08-10 18:06:00+03	95600.00
CF7E95	2017-08-07 06:04:00+03	47600.00
CF7EA5	2017-07-01 12:58:00+03	135400.00
CF7F5F	2017-08-06 15:13:00+03	274200.00
CF7FD9	2017-07-02 08:29:00+03	30700.00
CF8076	2017-07-15 14:28:00+03	155600.00
CF807F	2017-08-11 06:21:00+03	88700.00
CF8083	2017-07-11 02:23:00+03	27000.00
CF80AC	2017-07-17 18:57:00+03	52300.00
CF80B4	2017-07-16 10:16:00+03	116600.00
CF80B8	2017-07-04 11:29:00+03	92900.00
CF8110	2017-07-13 06:37:00+03	13500.00
CF8115	2017-08-04 06:35:00+03	34900.00
CF8125	2017-08-08 06:39:00+03	110800.00
CF817C	2017-07-22 22:51:00+03	19800.00
CF81CA	2017-07-14 16:34:00+03	34000.00
CF81D3	2017-07-21 19:00:00+03	36200.00
CF81D7	2017-08-04 10:43:00+03	94800.00
CF8274	2017-07-04 06:34:00+03	25200.00
CF82B4	2017-07-09 23:33:00+03	26700.00
CF82C6	2017-07-12 06:23:00+03	43400.00
CF82DF	2017-07-27 23:00:00+03	130900.00
CF82E5	2017-07-17 02:21:00+03	16800.00
CF835E	2017-07-23 16:29:00+03	26000.00
CF836D	2017-08-05 06:32:00+03	112600.00
CF8377	2017-07-11 01:48:00+03	8600.00
CF839A	2017-08-06 14:44:00+03	55800.00
CF83A3	2017-07-06 12:22:00+03	13200.00
CF8424	2017-07-11 12:47:00+03	27800.00
CF8456	2017-07-31 14:37:00+03	185300.00
CF84A1	2017-08-13 02:19:00+03	56000.00
CF84F6	2017-07-15 21:17:00+03	73100.00
CF854C	2017-07-09 21:26:00+03	23600.00
CF855A	2017-08-14 16:35:00+03	30200.00
CF859A	2017-07-14 12:11:00+03	8000.00
CF85A5	2017-07-17 20:36:00+03	91600.00
CF861F	2017-07-18 03:04:00+03	170800.00
CF86D4	2017-07-15 19:02:00+03	44700.00
CF8762	2017-07-05 23:54:00+03	64400.00
CF8777	2017-08-04 00:35:00+03	64700.00
CF888E	2017-08-07 23:18:00+03	31500.00
CF88B1	2017-07-14 17:01:00+03	24400.00
CF8920	2017-07-21 10:42:00+03	21800.00
CF8934	2017-08-14 09:20:00+03	94900.00
CF89CD	2017-07-29 08:00:00+03	21400.00
CF89ED	2017-07-24 13:49:00+03	303100.00
CF8A1E	2017-07-19 16:21:00+03	61500.00
CF8B19	2017-07-09 05:55:00+03	48600.00
CF8B54	2017-07-13 02:18:00+03	69500.00
CF8B84	2017-07-11 04:20:00+03	117600.00
CF8C7A	2017-07-27 09:18:00+03	266400.00
CF8CE5	2017-07-27 17:46:00+03	36600.00
CF8DEB	2017-07-11 19:02:00+03	13400.00
CF8EBC	2017-07-10 21:21:00+03	26600.00
CF8F14	2017-07-10 13:15:00+03	30000.00
CF8F4A	2017-07-22 22:11:00+03	116400.00
CF8F6A	2017-07-14 08:50:00+03	30900.00
CF8F8F	2017-08-08 17:37:00+03	49400.00
CF901C	2017-07-03 22:57:00+03	49100.00
CF908C	2017-07-07 11:15:00+03	24400.00
CF9111	2017-08-14 03:36:00+03	130800.00
CF911D	2017-07-01 18:12:00+03	60400.00
CF912D	2017-07-06 05:14:00+03	173900.00
CF9182	2017-08-04 04:49:00+03	26200.00
CF9193	2017-07-11 19:03:00+03	31100.00
CF919C	2017-07-31 11:06:00+03	24300.00
CF91FA	2017-07-23 22:17:00+03	32800.00
CF923B	2017-07-05 12:18:00+03	43900.00
CF926B	2017-07-28 09:26:00+03	67600.00
CF92B5	2017-07-20 12:21:00+03	123000.00
CF92DB	2017-07-15 06:14:00+03	156500.00
CF9300	2017-07-20 08:05:00+03	46800.00
CF9344	2017-07-18 19:29:00+03	520600.00
CF9348	2017-07-25 01:33:00+03	125400.00
CF93A7	2017-08-01 08:50:00+03	132800.00
CF93A9	2017-08-15 09:41:00+03	56000.00
CF93DE	2017-08-11 07:39:00+03	65300.00
CF9433	2017-08-11 17:24:00+03	18000.00
CF9444	2017-08-15 09:44:00+03	50600.00
CF944F	2017-07-21 12:34:00+03	28800.00
CF9478	2017-07-20 21:05:00+03	55800.00
CF94FA	2017-07-07 16:33:00+03	107400.00
CF957E	2017-07-05 01:18:00+03	16400.00
CF95B9	2017-08-01 04:22:00+03	30700.00
CF9747	2017-07-25 13:57:00+03	22000.00
CF97C4	2017-07-11 15:41:00+03	46200.00
CF97F9	2017-07-26 10:49:00+03	249100.00
CF97FA	2017-08-09 03:52:00+03	32700.00
CF980C	2017-08-01 06:33:00+03	18600.00
CF98AB	2017-07-29 12:24:00+03	26000.00
CF98D7	2017-07-27 23:09:00+03	50900.00
CF9921	2017-08-08 11:02:00+03	11600.00
CF9950	2017-07-28 03:47:00+03	46300.00
CF9973	2017-08-05 10:15:00+03	109000.00
CF99F3	2017-08-09 04:06:00+03	125400.00
CF9A56	2017-08-09 06:41:00+03	34600.00
CF9B0A	2017-07-13 13:51:00+03	62600.00
CF9B28	2017-08-05 06:06:00+03	62600.00
CF9B50	2017-08-15 01:04:00+03	38600.00
CF9B79	2017-07-26 07:41:00+03	85000.00
CF9BFB	2017-08-13 20:19:00+03	111200.00
CF9C00	2017-08-13 08:55:00+03	28000.00
CF9C16	2017-07-31 23:09:00+03	92100.00
CF9C44	2017-07-11 22:54:00+03	65100.00
CF9C52	2017-07-11 03:26:00+03	60700.00
CF9C5B	2017-08-08 23:42:00+03	54000.00
CF9C64	2017-07-17 07:52:00+03	137400.00
CF9C9F	2017-08-09 22:56:00+03	70700.00
CF9CA6	2017-08-02 19:55:00+03	112000.00
CF9CE9	2017-08-05 14:26:00+03	30400.00
CF9D6A	2017-07-05 22:38:00+03	301900.00
CF9D86	2017-07-14 00:53:00+03	170000.00
CF9DE0	2017-08-07 16:26:00+03	66800.00
CF9DE7	2017-07-22 16:47:00+03	58800.00
CF9E08	2017-07-09 18:18:00+03	6300.00
CF9E0A	2017-08-13 08:50:00+03	149300.00
CF9E8D	2017-08-05 14:57:00+03	25800.00
CF9EAB	2017-07-20 00:22:00+03	59100.00
CF9EF2	2017-07-22 06:25:00+03	155600.00
CF9F0C	2017-07-10 10:37:00+03	51300.00
CF9F0D	2017-08-14 00:31:00+03	57600.00
CF9F3A	2017-07-06 07:07:00+03	49100.00
CF9F56	2017-07-04 06:20:00+03	124200.00
CF9FD3	2017-07-07 16:37:00+03	19800.00
CFA01E	2017-08-12 03:29:00+03	50400.00
CFA034	2017-07-31 02:32:00+03	269200.00
CFA03F	2017-08-03 12:59:00+03	149600.00
CFA05A	2017-07-15 18:04:00+03	59800.00
CFA05B	2017-07-17 05:15:00+03	51300.00
CFA067	2017-07-13 20:56:00+03	136500.00
CFA074	2017-07-26 02:42:00+03	28800.00
CFA0A9	2017-07-27 02:59:00+03	290600.00
CFA0BA	2017-07-20 09:19:00+03	94000.00
CFA137	2017-08-09 02:20:00+03	77000.00
CFA1B6	2017-07-25 04:20:00+03	119600.00
CFA1F3	2017-07-05 14:18:00+03	29600.00
CFA203	2017-07-22 09:03:00+03	56900.00
CFA214	2017-07-04 04:07:00+03	67600.00
CFA22D	2017-07-27 12:52:00+03	38500.00
CFA263	2017-08-11 02:54:00+03	17800.00
CFA27E	2017-07-15 07:05:00+03	399600.00
CFA280	2017-07-25 10:58:00+03	87000.00
CFA33C	2017-07-03 11:22:00+03	72300.00
CFA36C	2017-07-19 19:45:00+03	137600.00
CFA37B	2017-08-01 17:13:00+03	43100.00
CFA3E7	2017-08-14 10:45:00+03	115800.00
CFA3F2	2017-08-02 10:44:00+03	23600.00
CFA46F	2017-08-02 11:58:00+03	62700.00
CFA488	2017-07-18 05:38:00+03	6700.00
CFA496	2017-07-16 01:15:00+03	133700.00
CFA55B	2017-07-04 15:01:00+03	51600.00
CFA563	2017-08-06 03:27:00+03	92800.00
CFA597	2017-07-14 06:22:00+03	54500.00
CFA60A	2017-07-17 18:48:00+03	106400.00
CFA613	2017-08-06 06:35:00+03	40000.00
CFA643	2017-08-04 22:41:00+03	98400.00
CFA660	2017-08-04 18:29:00+03	89600.00
CFA697	2017-07-22 00:59:00+03	198300.00
CFA6DE	2017-07-05 10:28:00+03	73500.00
CFA6F4	2017-08-03 21:09:00+03	66100.00
CFA775	2017-07-22 05:51:00+03	67100.00
CFA783	2017-07-15 06:07:00+03	147300.00
CFA7B4	2017-07-08 16:24:00+03	123600.00
CFA7DE	2017-07-31 01:15:00+03	45200.00
CFA7E1	2017-07-18 03:54:00+03	20900.00
CFA848	2017-07-23 19:58:00+03	56600.00
CFA85D	2017-08-01 23:53:00+03	62600.00
CFA883	2017-08-01 07:53:00+03	301800.00
CFA88C	2017-08-12 14:30:00+03	32800.00
CFA893	2017-07-16 19:22:00+03	88600.00
CFA897	2017-07-22 22:04:00+03	139500.00
CFA8F9	2017-07-09 13:44:00+03	8000.00
CFA964	2017-08-12 17:01:00+03	81200.00
CFA967	2017-08-05 16:54:00+03	46000.00
CFA9A1	2017-07-13 21:03:00+03	28800.00
CFAA1F	2017-07-01 22:19:00+03	18600.00
CFAA8B	2017-08-07 02:11:00+03	56000.00
CFAAD9	2017-07-13 19:30:00+03	80600.00
CFABC4	2017-08-11 07:51:00+03	35900.00
CFABD9	2017-07-30 15:38:00+03	28000.00
CFAC05	2017-08-03 20:56:00+03	53100.00
CFAC32	2017-07-26 12:37:00+03	193600.00
CFAC95	2017-08-06 18:10:00+03	147400.00
CFACA0	2017-07-06 04:08:00+03	30200.00
CFAD35	2017-07-14 11:31:00+03	48800.00
CFAD3A	2017-07-05 16:44:00+03	70800.00
CFAD7E	2017-08-02 00:05:00+03	38400.00
CFAD9F	2017-07-27 19:09:00+03	92900.00
CFADCC	2017-07-14 02:25:00+03	65200.00
CFAE14	2017-08-14 08:45:00+03	37900.00
CFAE9C	2017-07-10 04:40:00+03	38600.00
CFAEE8	2017-07-31 15:22:00+03	47600.00
CFAF03	2017-08-06 23:26:00+03	75600.00
CFAF15	2017-07-18 23:05:00+03	34200.00
CFAF65	2017-07-15 06:15:00+03	29600.00
CFAFEE	2017-08-13 11:05:00+03	32800.00
CFB0A4	2017-07-29 05:19:00+03	170100.00
CFB0F6	2017-08-14 02:31:00+03	77600.00
CFB155	2017-08-10 17:21:00+03	7400.00
CFB180	2017-07-27 13:55:00+03	139700.00
CFB18D	2017-07-28 07:57:00+03	129400.00
CFB19B	2017-08-11 14:05:00+03	271200.00
CFB1B4	2017-07-17 03:14:00+03	57600.00
CFB1E6	2017-07-10 04:41:00+03	132800.00
CFB2C8	2017-07-11 20:09:00+03	23200.00
CFB2DE	2017-07-21 14:56:00+03	24400.00
CFB322	2017-07-01 15:01:00+03	133200.00
CFB356	2017-07-10 01:09:00+03	393800.00
CFB37F	2017-07-20 14:30:00+03	36800.00
CFB39B	2017-07-21 19:31:00+03	32200.00
CFB3E3	2017-07-23 02:25:00+03	63500.00
CFB40A	2017-07-11 15:01:00+03	56000.00
CFB40B	2017-07-28 23:27:00+03	85200.00
CFB43E	2017-07-15 02:56:00+03	133200.00
CFB470	2017-08-02 04:03:00+03	66600.00
CFB48A	2017-07-26 17:09:00+03	67400.00
CFB499	2017-07-27 22:54:00+03	6300.00
CFB4C0	2017-07-15 23:34:00+03	131600.00
CFB4E6	2017-08-09 13:40:00+03	38800.00
CFB502	2017-07-17 10:55:00+03	105200.00
CFB5C3	2017-07-25 09:39:00+03	142400.00
CFB5E1	2017-07-26 16:00:00+03	28000.00
CFB5F6	2017-08-13 17:24:00+03	93800.00
CFB61B	2017-08-02 12:07:00+03	239400.00
CFB65D	2017-08-10 20:49:00+03	126300.00
CFB6CC	2017-07-07 15:10:00+03	124200.00
CFB786	2017-07-30 03:54:00+03	55800.00
CFB801	2017-08-09 19:52:00+03	101200.00
CFB85C	2017-07-30 01:30:00+03	23200.00
CFB89E	2017-07-16 04:59:00+03	66800.00
CFB8E5	2017-08-04 06:12:00+03	177600.00
CFB8F1	2017-07-13 17:08:00+03	12400.00
CFB976	2017-07-20 07:16:00+03	70600.00
CFB9FE	2017-07-06 12:48:00+03	40000.00
CFBB32	2017-07-22 20:55:00+03	81300.00
CFBB3D	2017-07-23 00:59:00+03	12600.00
CFBBE2	2017-07-10 22:38:00+03	7400.00
CFBC02	2017-07-08 08:12:00+03	29600.00
CFBC03	2017-07-29 06:38:00+03	23200.00
CFBC1B	2017-08-14 21:42:00+03	26800.00
CFBCA1	2017-08-02 16:27:00+03	12600.00
CFBCCF	2017-07-06 21:55:00+03	21200.00
CFBDC4	2017-07-07 02:51:00+03	23400.00
CFBE0E	2017-08-11 03:18:00+03	40800.00
CFBE4B	2017-07-01 15:15:00+03	232900.00
CFBEA8	2017-08-14 14:38:00+03	145300.00
CFBF47	2017-08-08 06:07:00+03	55900.00
CFBFF0	2017-07-23 04:26:00+03	48800.00
CFC0CE	2017-07-04 23:54:00+03	54800.00
CFC101	2017-08-09 22:12:00+03	136800.00
CFC105	2017-08-02 15:57:00+03	87900.00
CFC200	2017-07-02 03:19:00+03	133100.00
CFC211	2017-07-13 07:43:00+03	27200.00
CFC278	2017-07-21 23:43:00+03	59300.00
CFC288	2017-07-12 14:41:00+03	79900.00
CFC28A	2017-07-23 01:12:00+03	79600.00
CFC2C0	2017-07-08 00:04:00+03	27200.00
CFC2D8	2017-07-13 11:04:00+03	38600.00
CFC315	2017-08-10 09:22:00+03	66600.00
CFC31B	2017-08-14 19:21:00+03	103500.00
CFC3B0	2017-08-09 18:14:00+03	44000.00
CFC46F	2017-07-12 17:02:00+03	111600.00
CFC4A1	2017-08-15 11:09:00+03	13200.00
CFC4C7	2017-08-06 18:34:00+03	406100.00
CFC52A	2017-07-20 11:39:00+03	168600.00
CFC65F	2017-08-11 14:19:00+03	84000.00
CFC6E2	2017-07-17 21:21:00+03	28800.00
CFC76B	2017-07-26 18:31:00+03	25000.00
CFC77D	2017-07-21 15:01:00+03	39400.00
CFC7F5	2017-07-25 04:35:00+03	24400.00
CFC7FF	2017-07-08 20:54:00+03	43600.00
CFC8AB	2017-08-02 18:19:00+03	86800.00
CFC8BC	2017-07-08 11:07:00+03	128400.00
CFC8D6	2017-07-21 15:28:00+03	123000.00
CFC8E4	2017-08-07 11:23:00+03	62600.00
CFC93F	2017-07-13 16:31:00+03	34000.00
CFC99F	2017-08-07 00:17:00+03	19600.00
CFC9A7	2017-07-05 13:56:00+03	46400.00
CFC9BE	2017-07-30 20:20:00+03	176800.00
CFC9F1	2017-08-06 05:22:00+03	145300.00
CFCA41	2017-07-02 12:05:00+03	46000.00
CFCA70	2017-08-12 21:19:00+03	114500.00
CFCAF1	2017-07-17 04:52:00+03	100900.00
CFCB0A	2017-07-28 14:35:00+03	166900.00
CFCB18	2017-07-30 12:45:00+03	17000.00
CFCBFF	2017-07-31 04:42:00+03	54600.00
CFCC40	2017-07-26 05:06:00+03	73200.00
CFCC5F	2017-08-04 06:22:00+03	226800.00
CFCCE3	2017-07-15 10:56:00+03	65500.00
CFCCEF	2017-07-29 09:29:00+03	56000.00
CFCD4D	2017-07-20 18:31:00+03	123000.00
CFCD53	2017-07-18 18:54:00+03	136200.00
CFCD86	2017-08-06 22:47:00+03	50600.00
CFCD8D	2017-07-21 21:44:00+03	65500.00
CFCDAC	2017-07-26 15:01:00+03	133100.00
CFCDEA	2017-06-30 00:36:00+03	75600.00
CFCDFC	2017-08-13 05:45:00+03	67600.00
CFCE05	2017-07-10 19:26:00+03	31600.00
CFCE0D	2017-07-21 11:26:00+03	54800.00
CFCE12	2017-07-02 19:56:00+03	88900.00
CFCE14	2017-07-15 19:02:00+03	118500.00
CFCF25	2017-07-23 20:03:00+03	406700.00
CFCF49	2017-08-15 01:40:00+03	94700.00
CFCF75	2017-08-15 16:58:00+03	285900.00
CFCF99	2017-08-04 17:49:00+03	27800.00
CFD014	2017-08-11 21:39:00+03	21800.00
CFD037	2017-08-06 18:04:00+03	42800.00
CFD060	2017-07-29 03:28:00+03	279100.00
CFD0A5	2017-07-14 17:51:00+03	56600.00
CFD0D5	2017-07-29 02:24:00+03	14000.00
CFD173	2017-08-01 00:00:00+03	30800.00
CFD189	2017-08-12 07:00:00+03	132800.00
CFD18D	2017-07-09 20:54:00+03	34700.00
CFD1BC	2017-08-15 13:29:00+03	28300.00
CFD201	2017-07-27 00:53:00+03	40800.00
CFD2B7	2017-08-05 11:18:00+03	194900.00
CFD2CA	2017-07-27 07:20:00+03	100000.00
CFD2E1	2017-07-25 20:53:00+03	23600.00
CFD302	2017-08-07 05:07:00+03	56000.00
CFD304	2017-08-15 16:10:00+03	77000.00
CFD316	2017-08-09 23:21:00+03	29600.00
CFD335	2017-07-22 16:12:00+03	38500.00
CFD3BB	2017-08-09 15:58:00+03	64200.00
CFD420	2017-08-14 12:33:00+03	42800.00
CFD4CB	2017-08-09 22:32:00+03	56000.00
CFD4DC	2017-07-07 22:13:00+03	55800.00
CFD4F8	2017-07-07 02:02:00+03	87900.00
CFD515	2017-08-15 07:32:00+03	112000.00
CFD54E	2017-07-29 22:50:00+03	62700.00
CFD5F7	2017-07-16 19:22:00+03	67600.00
CFD620	2017-07-17 04:14:00+03	38800.00
CFD62F	2017-08-06 03:57:00+03	64700.00
CFD66E	2017-07-26 20:39:00+03	89600.00
CFD685	2017-07-19 19:16:00+03	202600.00
CFD6C5	2017-08-12 00:13:00+03	28700.00
CFD6E4	2017-07-25 13:47:00+03	23200.00
CFD716	2017-07-10 02:07:00+03	23600.00
CFD718	2017-07-13 18:10:00+03	6300.00
CFD71F	2017-07-13 07:29:00+03	46400.00
CFD74D	2017-08-02 20:24:00+03	48500.00
CFD79E	2017-07-17 04:00:00+03	40800.00
CFD7B1	2017-07-28 13:58:00+03	69800.00
CFD7CA	2017-07-29 21:46:00+03	46300.00
CFD7EA	2017-08-15 06:58:00+03	28300.00
CFD85D	2017-08-08 03:57:00+03	54700.00
CFDA63	2017-08-01 19:06:00+03	127200.00
CFDAA0	2017-08-08 16:05:00+03	42600.00
CFDAD7	2017-07-10 06:10:00+03	39200.00
CFDB4A	2017-08-11 12:35:00+03	128800.00
CFDB5F	2017-07-08 15:56:00+03	65600.00
CFDBFF	2017-08-15 04:20:00+03	14000.00
CFDC21	2017-08-08 18:30:00+03	258400.00
CFDC36	2017-07-19 18:27:00+03	32800.00
CFDC89	2017-07-01 04:30:00+03	54000.00
CFDC91	2017-07-16 13:08:00+03	266400.00
CFDCAD	2017-08-03 18:00:00+03	29200.00
CFDE08	2017-07-30 17:01:00+03	24400.00
CFDE2A	2017-07-19 22:28:00+03	90600.00
CFDEBC	2017-08-07 12:48:00+03	56600.00
CFDEC8	2017-07-18 19:40:00+03	46900.00
CFDEF3	2017-08-03 15:06:00+03	56600.00
CFDF5A	2017-08-11 19:05:00+03	52000.00
CFDFAB	2017-08-15 14:19:00+03	128800.00
CFDFCB	2017-07-24 05:56:00+03	37200.00
CFE033	2017-07-11 01:56:00+03	42800.00
CFE058	2017-07-03 18:27:00+03	13400.00
CFE09B	2017-08-15 08:11:00+03	102400.00
CFE173	2017-08-15 00:41:00+03	25200.00
CFE1CB	2017-08-11 20:41:00+03	133100.00
CFE266	2017-07-28 22:10:00+03	60400.00
CFE29B	2017-07-07 20:54:00+03	10300.00
CFE29C	2017-07-30 10:19:00+03	39300.00
CFE2B1	2017-06-28 11:45:00+03	14000.00
CFE2DD	2017-07-29 03:43:00+03	210000.00
CFE309	2017-07-09 06:40:00+03	47100.00
CFE3B9	2017-07-09 13:37:00+03	140900.00
CFE3BD	2017-08-01 22:09:00+03	58800.00
CFE410	2017-07-27 06:43:00+03	92000.00
CFE41C	2017-07-02 22:00:00+03	396900.00
CFE47B	2017-08-04 06:27:00+03	43100.00
CFE4B2	2017-08-07 22:52:00+03	12400.00
CFE4CD	2017-07-05 03:40:00+03	188000.00
CFE4EB	2017-07-24 06:22:00+03	21600.00
CFE506	2017-08-08 19:18:00+03	29600.00
CFE510	2017-08-12 16:02:00+03	92700.00
CFE5E0	2017-07-12 06:16:00+03	137400.00
CFE5E8	2017-08-11 18:13:00+03	270800.00
CFE5EB	2017-08-05 21:41:00+03	28700.00
CFE656	2017-07-27 17:58:00+03	45200.00
CFE688	2017-07-15 23:00:00+03	64700.00
CFE68A	2017-07-19 22:00:00+03	141300.00
CFE6AC	2017-08-01 22:21:00+03	16400.00
CFE703	2017-08-04 13:18:00+03	133600.00
CFE710	2017-08-14 10:13:00+03	20500.00
CFE71E	2017-08-01 08:21:00+03	149000.00
CFE724	2017-07-09 18:05:00+03	18000.00
CFE730	2017-07-18 10:52:00+03	19500.00
CFE754	2017-08-05 20:38:00+03	54800.00
CFE768	2017-07-12 10:10:00+03	37600.00
CFE790	2017-07-07 05:12:00+03	48400.00
CFE7FE	2017-08-09 17:31:00+03	258400.00
CFE863	2017-07-31 15:55:00+03	116600.00
CFE896	2017-07-19 09:24:00+03	61800.00
CFE8A8	2017-08-15 00:47:00+03	265600.00
CFE92C	2017-07-28 03:11:00+03	26000.00
CFE93B	2017-07-30 23:38:00+03	81900.00
CFE94F	2017-08-08 21:43:00+03	36000.00
CFE992	2017-07-31 15:31:00+03	28000.00
CFE99C	2017-07-25 17:45:00+03	48000.00
CFE9F4	2017-08-06 12:24:00+03	30200.00
CFEA3C	2017-08-03 18:59:00+03	133200.00
CFEA66	2017-08-06 06:03:00+03	28000.00
CFEAE2	2017-08-02 07:40:00+03	67000.00
CFEB04	2017-07-12 09:04:00+03	68900.00
CFEB36	2017-07-22 00:46:00+03	63000.00
CFEB88	2017-07-13 05:09:00+03	23200.00
CFEB92	2017-07-31 17:06:00+03	258400.00
CFEBA0	2017-08-13 01:00:00+03	25600.00
CFEC34	2017-08-13 13:02:00+03	28800.00
CFEC8C	2017-08-07 00:33:00+03	24200.00
CFECAC	2017-08-02 16:40:00+03	38600.00
CFECEB	2017-07-28 00:05:00+03	126700.00
CFED04	2017-07-04 17:48:00+03	29600.00
CFEDAF	2017-08-13 16:12:00+03	75700.00
CFEDE6	2017-08-02 23:38:00+03	6000.00
CFEE38	2017-07-20 21:42:00+03	56100.00
CFEE44	2017-07-09 23:58:00+03	33100.00
CFEE84	2017-08-12 14:48:00+03	53700.00
CFEE8C	2017-07-10 17:04:00+03	54100.00
CFEE8F	2017-07-30 19:02:00+03	87400.00
CFEE9C	2017-08-12 14:58:00+03	56000.00
CFEEF3	2017-06-28 04:17:00+03	118400.00
CFEF10	2017-07-08 10:40:00+03	56000.00
CFEF1D	2017-08-12 07:39:00+03	27400.00
CFEF24	2017-06-27 16:05:00+03	88900.00
CFEFA4	2017-07-23 22:23:00+03	487400.00
CFEFA7	2017-07-16 00:13:00+03	38600.00
CFEFEF	2017-07-31 16:19:00+03	28000.00
CFF08C	2017-07-10 02:30:00+03	28400.00
CFF0A0	2017-07-21 22:08:00+03	34000.00
CFF0A7	2017-07-26 02:57:00+03	11900.00
CFF0DB	2017-07-23 17:47:00+03	62000.00
CFF176	2017-06-29 07:28:00+03	51800.00
CFF188	2017-07-12 00:18:00+03	6700.00
CFF196	2017-07-11 07:55:00+03	24400.00
CFF19D	2017-07-19 05:29:00+03	24400.00
CFF1AF	2017-08-12 07:02:00+03	65200.00
CFF22A	2017-08-12 03:48:00+03	103200.00
CFF27E	2017-07-22 20:19:00+03	127300.00
CFF28E	2017-08-10 23:30:00+03	36800.00
CFF296	2017-07-25 19:36:00+03	47500.00
CFF2BF	2017-07-15 03:32:00+03	47400.00
CFF305	2017-08-04 09:15:00+03	96100.00
CFF309	2017-07-23 04:15:00+03	28000.00
CFF316	2017-07-08 03:03:00+03	19600.00
CFF336	2017-08-09 08:45:00+03	55800.00
CFF338	2017-07-23 14:49:00+03	50800.00
CFF36D	2017-07-08 23:03:00+03	102600.00
CFF36E	2017-08-06 15:54:00+03	16400.00
CFF3DB	2017-08-05 12:12:00+03	46400.00
CFF3E9	2017-08-04 18:56:00+03	75300.00
CFF409	2017-08-09 14:58:00+03	111700.00
CFF436	2017-08-05 13:35:00+03	59000.00
CFF44A	2017-07-24 02:54:00+03	50600.00
CFF455	2017-07-09 09:22:00+03	59300.00
CFF46D	2017-07-27 04:02:00+03	125400.00
CFF46F	2017-07-25 22:53:00+03	15000.00
CFF475	2017-08-05 07:43:00+03	39200.00
CFF47C	2017-07-14 10:00:00+03	62600.00
CFF47F	2017-07-25 12:33:00+03	46300.00
CFF480	2017-07-30 05:25:00+03	27200.00
CFF4A1	2017-07-03 12:00:00+03	115600.00
CFF4DE	2017-07-10 23:43:00+03	69900.00
CFF4FA	2017-07-02 16:30:00+03	27800.00
CFF56E	2017-07-28 12:00:00+03	56000.00
CFF63F	2017-08-06 19:14:00+03	55800.00
CFF662	2017-08-06 15:20:00+03	66000.00
CFF67C	2017-07-26 13:22:00+03	123000.00
CFF6B8	2017-07-24 11:57:00+03	27200.00
CFF6BD	2017-08-14 05:18:00+03	193500.00
CFF718	2017-07-28 16:37:00+03	92800.00
CFF773	2017-07-30 00:02:00+03	87100.00
CFF77A	2017-07-23 07:23:00+03	83000.00
CFF7A6	2017-06-24 12:03:00+03	22600.00
CFF7E4	2017-07-28 02:31:00+03	62700.00
CFF833	2017-07-05 18:54:00+03	27200.00
CFF837	2017-07-30 13:58:00+03	86400.00
CFF8C0	2017-07-06 18:36:00+03	18000.00
CFF8C2	2017-07-09 20:54:00+03	42000.00
CFF8ED	2017-07-15 22:32:00+03	199600.00
CFF92C	2017-08-01 03:04:00+03	56000.00
CFF92F	2017-08-10 13:00:00+03	124600.00
CFF953	2017-07-05 19:16:00+03	50000.00
CFF99D	2017-07-30 06:55:00+03	124200.00
CFFA03	2017-07-05 21:21:00+03	92900.00
CFFA15	2017-08-09 12:18:00+03	46000.00
CFFAB7	2017-07-26 03:37:00+03	86600.00
CFFAC3	2017-08-11 14:11:00+03	18600.00
CFFB14	2017-08-11 05:54:00+03	55800.00
CFFB32	2017-07-27 04:49:00+03	8400.00
CFFB42	2017-07-12 21:16:00+03	36800.00
CFFBA5	2017-07-19 20:18:00+03	56000.00
CFFBA7	2017-07-24 15:47:00+03	169000.00
CFFBFE	2017-07-30 13:37:00+03	87100.00
CFFC02	2017-07-28 12:33:00+03	37100.00
CFFC89	2017-08-05 08:33:00+03	129700.00
CFFC9B	2017-08-02 03:30:00+03	106900.00
CFFCE8	2017-07-20 03:34:00+03	28800.00
CFFD01	2017-08-14 20:28:00+03	163600.00
CFFD3B	2017-07-23 19:17:00+03	37200.00
CFFD9B	2017-08-13 04:58:00+03	6700.00
CFFDD2	2017-08-08 14:02:00+03	153000.00
CFFE7C	2017-08-02 23:43:00+03	55800.00
CFFE94	2017-07-12 23:21:00+03	166000.00
CFFEEE	2017-08-01 14:02:00+03	55800.00
CFFF11	2017-08-07 11:58:00+03	11000.00
CFFF18	2017-08-12 05:25:00+03	170000.00
CFFF2E	2017-07-16 03:06:00+03	23500.00
CFFF84	2017-08-01 09:01:00+03	89600.00
CFFFC2	2017-07-12 15:52:00+03	413400.00
D0002F	2017-07-26 06:50:00+03	201800.00
D0003A	2017-07-07 06:59:00+03	16400.00
D00094	2017-08-10 08:22:00+03	313600.00
D000B8	2017-08-07 22:09:00+03	12400.00
D00158	2017-07-17 20:40:00+03	28800.00
D00169	2017-07-29 19:31:00+03	44500.00
D001C6	2017-07-01 23:25:00+03	44000.00
D001F0	2017-07-23 14:26:00+03	166700.00
D00200	2017-07-27 16:33:00+03	24700.00
D00227	2017-07-14 23:42:00+03	75200.00
D00254	2017-08-05 11:07:00+03	48800.00
D00257	2017-07-04 07:03:00+03	169900.00
D00269	2017-08-09 04:43:00+03	12600.00
D0026F	2017-07-12 07:44:00+03	69900.00
D002C5	2017-08-11 06:43:00+03	131100.00
D002EF	2017-06-30 16:10:00+03	19000.00
D0034D	2017-07-12 21:37:00+03	58900.00
D0036D	2017-07-21 21:10:00+03	84500.00
D003C6	2017-08-13 15:06:00+03	57500.00
D003D8	2017-07-16 07:58:00+03	179400.00
D0046D	2017-08-09 18:33:00+03	521200.00
D004B6	2017-07-24 05:14:00+03	80300.00
D004F6	2017-08-09 23:29:00+03	149900.00
D0051B	2017-07-31 14:07:00+03	46400.00
D00571	2017-07-12 15:49:00+03	54800.00
D005C2	2017-07-05 23:36:00+03	75600.00
D00694	2017-08-08 18:23:00+03	66600.00
D0071A	2017-08-13 20:54:00+03	13400.00
D008EB	2017-08-13 03:40:00+03	57600.00
D0099D	2017-07-01 22:03:00+03	126600.00
D009F6	2017-07-31 19:28:00+03	20500.00
D00A3D	2017-07-18 15:01:00+03	33300.00
D00A79	2017-08-02 06:07:00+03	19800.00
D00A8E	2017-07-13 19:46:00+03	23200.00
D00AA1	2017-07-18 02:30:00+03	13400.00
D00AAB	2017-07-06 03:02:00+03	132800.00
D00ADB	2017-07-16 11:03:00+03	81200.00
D00B0B	2017-07-13 22:49:00+03	52600.00
D00BA6	2017-07-02 01:15:00+03	81600.00
D00BB6	2017-08-15 11:31:00+03	57500.00
D00BDB	2017-08-04 00:43:00+03	132800.00
D00C3E	2017-08-01 14:06:00+03	42400.00
D00C4A	2017-07-22 18:03:00+03	31600.00
D00C4D	2017-08-05 13:16:00+03	73200.00
D00C5F	2017-07-14 10:06:00+03	29200.00
D00C82	2017-07-17 23:57:00+03	30200.00
D00C8E	2017-07-04 06:37:00+03	78600.00
D00CA7	2017-07-27 16:01:00+03	115000.00
D00CAA	2017-07-28 21:35:00+03	46400.00
D00CD8	2017-07-23 19:25:00+03	67400.00
D00D45	2017-07-19 14:35:00+03	118700.00
D00DEA	2017-07-28 19:47:00+03	73400.00
D00DF8	2017-07-22 19:26:00+03	24400.00
D00E55	2017-07-10 11:14:00+03	8200.00
D00E9C	2017-07-15 08:27:00+03	23100.00
D00EC9	2017-07-15 06:33:00+03	402400.00
D00EDA	2017-07-11 08:23:00+03	95200.00
D00F1C	2017-07-10 17:31:00+03	20000.00
D00F23	2017-08-06 02:18:00+03	25000.00
D00FC7	2017-08-10 22:19:00+03	11000.00
D01065	2017-07-26 19:50:00+03	39300.00
D0106F	2017-08-12 02:31:00+03	27300.00
D010A9	2017-08-10 02:53:00+03	48800.00
D010C8	2017-07-12 15:12:00+03	31900.00
D0113D	2017-07-07 00:12:00+03	140900.00
D01151	2017-07-22 02:02:00+03	40800.00
D01185	2017-08-06 17:51:00+03	53300.00
D011AA	2017-06-30 14:00:00+03	23200.00
D01227	2017-07-04 09:20:00+03	33200.00
D0124F	2017-08-12 16:34:00+03	46800.00
D0125A	2017-07-12 02:04:00+03	290900.00
D01272	2017-07-26 23:20:00+03	265600.00
D01339	2017-07-05 15:40:00+03	46400.00
D0133B	2017-07-27 08:01:00+03	51800.00
D013EB	2017-07-16 21:14:00+03	234400.00
D013F7	2017-07-13 19:00:00+03	62600.00
D01465	2017-08-02 19:08:00+03	22000.00
D01484	2017-07-07 14:38:00+03	57500.00
D01508	2017-08-12 02:39:00+03	72400.00
D0151A	2017-07-18 10:23:00+03	93900.00
D0152A	2017-07-16 19:23:00+03	394400.00
D0152E	2017-07-17 00:02:00+03	100600.00
D01533	2017-08-01 05:33:00+03	27200.00
D01585	2017-08-08 22:22:00+03	88100.00
D015CF	2017-07-21 14:43:00+03	117500.00
D01639	2017-07-14 18:46:00+03	63200.00
D0167C	2017-08-08 08:13:00+03	24400.00
D0170D	2017-08-12 21:18:00+03	49100.00
D01720	2017-07-14 22:22:00+03	37600.00
D01745	2017-07-07 19:45:00+03	58000.00
D01773	2017-08-04 13:25:00+03	38800.00
D01782	2017-07-10 06:43:00+03	101200.00
D0183D	2017-07-09 07:42:00+03	52700.00
D0187B	2017-07-14 05:06:00+03	102100.00
D01884	2017-07-14 11:41:00+03	28300.00
D018AE	2017-08-07 23:51:00+03	155500.00
D01914	2017-07-25 00:16:00+03	56000.00
D01922	2017-07-21 15:23:00+03	46400.00
D0197E	2017-08-10 16:10:00+03	25600.00
D0198B	2017-07-07 01:28:00+03	31200.00
D01993	2017-08-13 09:53:00+03	117600.00
D019D4	2017-08-10 15:37:00+03	40800.00
D01A0B	2017-07-12 01:06:00+03	258400.00
D01A4B	2017-08-11 22:39:00+03	23600.00
D01A59	2017-08-01 20:50:00+03	143000.00
D01A9E	2017-08-05 08:31:00+03	6000.00
D01AFC	2017-07-18 05:15:00+03	47400.00
D01B33	2017-08-13 08:39:00+03	40800.00
D01B86	2017-08-06 13:40:00+03	50000.00
D01BB6	2017-08-07 11:35:00+03	36700.00
D01BC6	2017-08-10 20:18:00+03	88300.00
D01BF1	2017-07-23 22:24:00+03	139200.00
D01C7D	2017-07-01 17:35:00+03	115300.00
D01CAB	2017-07-06 19:12:00+03	52000.00
D01D66	2017-07-04 07:41:00+03	122800.00
D01D80	2017-06-27 20:55:00+03	64500.00
D01DFF	2017-07-10 03:38:00+03	75600.00
D01E0F	2017-07-12 11:26:00+03	20200.00
D01EE3	2017-07-27 08:38:00+03	283100.00
D01EFB	2017-07-31 14:35:00+03	29200.00
D02008	2017-08-15 13:23:00+03	124200.00
D02032	2017-07-05 21:14:00+03	246000.00
D02040	2017-06-27 14:22:00+03	192400.00
D020B0	2017-08-15 09:38:00+03	18500.00
D020C0	2017-07-07 23:48:00+03	56000.00
D020CC	2017-07-07 21:46:00+03	72800.00
D02104	2017-07-22 20:20:00+03	25100.00
D0210F	2017-08-05 07:52:00+03	136200.00
D02174	2017-07-01 18:56:00+03	73200.00
D021D5	2017-07-21 15:56:00+03	21400.00
D02231	2017-07-31 06:07:00+03	116400.00
D02252	2017-08-07 13:57:00+03	16400.00
D02270	2017-08-11 11:02:00+03	71900.00
D02294	2017-08-09 19:21:00+03	240000.00
D022AC	2017-08-05 10:38:00+03	57500.00
D022F0	2017-07-18 01:49:00+03	44800.00
D0233E	2017-07-09 20:12:00+03	137600.00
D02347	2017-07-27 13:53:00+03	124200.00
D02363	2017-08-10 16:21:00+03	37200.00
D02400	2017-07-18 00:11:00+03	54800.00
D024AC	2017-08-13 21:34:00+03	47200.00
D024B6	2017-07-17 20:37:00+03	39400.00
D0257D	2017-07-06 13:08:00+03	112000.00
D025FF	2017-08-02 01:20:00+03	28000.00
D0263B	2017-07-02 15:56:00+03	28800.00
D02672	2017-07-06 14:53:00+03	48600.00
D02683	2017-07-19 03:21:00+03	26000.00
D02717	2017-07-05 11:48:00+03	61200.00
D02746	2017-07-23 02:06:00+03	46200.00
D02749	2017-07-12 16:23:00+03	62700.00
D02780	2017-08-07 11:54:00+03	7400.00
D02797	2017-08-12 01:50:00+03	85000.00
D027C7	2017-08-05 04:12:00+03	29600.00
D027DC	2017-07-06 13:22:00+03	21200.00
D027EB	2017-08-08 18:38:00+03	124300.00
D02845	2017-07-18 09:49:00+03	48400.00
D02883	2017-07-09 01:44:00+03	77000.00
D028A1	2017-07-18 15:48:00+03	62800.00
D028EB	2017-07-05 20:48:00+03	133200.00
D0294A	2017-08-06 00:42:00+03	44500.00
D02998	2017-07-08 13:30:00+03	98300.00
D029A5	2017-08-09 07:05:00+03	39200.00
D029B1	2017-08-07 20:04:00+03	54600.00
D029B2	2017-07-17 12:23:00+03	43200.00
D02A99	2017-07-22 15:57:00+03	59000.00
D02B0C	2017-07-11 19:01:00+03	13400.00
D02B98	2017-07-30 04:48:00+03	117300.00
D02BDA	2017-07-18 14:50:00+03	45100.00
D02BFD	2017-08-03 06:10:00+03	25400.00
D02C1C	2017-08-12 13:47:00+03	58200.00
D02D08	2017-07-19 11:59:00+03	37200.00
D02D1E	2017-07-24 03:42:00+03	66600.00
D02D52	2017-07-10 01:57:00+03	131600.00
D02D9A	2017-08-10 12:42:00+03	92800.00
D02D9B	2017-08-01 11:28:00+03	99200.00
D02DA7	2017-08-12 23:57:00+03	166100.00
D02DDF	2017-07-29 21:48:00+03	22000.00
D02E0B	2017-08-01 08:06:00+03	17200.00
D02EB6	2017-07-29 18:21:00+03	28000.00
D02EE8	2017-08-08 22:24:00+03	33300.00
D02F29	2017-07-08 22:52:00+03	55600.00
D02FCB	2017-07-03 20:45:00+03	406700.00
D0300F	2017-06-28 01:42:00+03	23400.00
D0304B	2017-07-07 23:16:00+03	131100.00
D030A8	2017-07-21 23:03:00+03	43900.00
D030F2	2017-08-10 05:08:00+03	63200.00
D03152	2017-07-29 05:41:00+03	115900.00
D031AA	2017-08-08 21:36:00+03	92700.00
D03381	2017-08-09 01:06:00+03	6000.00
D033C2	2017-08-08 12:13:00+03	27200.00
D033DD	2017-07-12 22:02:00+03	231800.00
D03406	2017-08-01 08:39:00+03	32800.00
D03420	2017-07-14 19:37:00+03	29400.00
D03464	2017-07-14 13:21:00+03	8200.00
D034A0	2017-08-12 13:44:00+03	100200.00
D034DE	2017-07-15 05:12:00+03	332800.00
D03512	2017-07-01 03:01:00+03	280700.00
D0351C	2017-07-18 16:18:00+03	6700.00
D035C5	2017-06-30 05:13:00+03	28300.00
D03635	2017-07-04 05:26:00+03	28000.00
D03636	2017-07-28 20:05:00+03	68600.00
D03696	2017-07-13 12:00:00+03	58800.00
D03777	2017-07-03 12:25:00+03	67200.00
D03790	2017-07-19 17:18:00+03	67200.00
D037F1	2017-08-06 11:00:00+03	28800.00
D037FF	2017-07-31 02:51:00+03	65500.00
D03825	2017-07-18 16:59:00+03	134600.00
D03836	2017-07-28 13:09:00+03	44600.00
D03841	2017-08-03 01:50:00+03	235200.00
D03848	2017-07-01 19:30:00+03	111600.00
D0386D	2017-08-12 05:58:00+03	41800.00
D03897	2017-07-30 22:45:00+03	103100.00
D0389A	2017-06-30 19:03:00+03	54300.00
D038D2	2017-07-11 07:21:00+03	133200.00
D038D7	2017-07-19 16:34:00+03	51300.00
D038E8	2017-07-15 01:21:00+03	56000.00
D03978	2017-07-07 23:40:00+03	92900.00
D039AE	2017-08-09 15:13:00+03	41600.00
D03A35	2017-07-01 00:02:00+03	56600.00
D03A67	2017-07-27 17:37:00+03	50600.00
D03A7B	2017-08-14 06:30:00+03	36600.00
D03AE8	2017-07-04 11:34:00+03	21800.00
D03B42	2017-07-21 17:26:00+03	111600.00
D03B99	2017-07-07 22:58:00+03	46400.00
D03BAB	2017-07-29 17:38:00+03	71900.00
D03BF7	2017-07-24 09:51:00+03	182300.00
D03C0D	2017-08-10 18:27:00+03	106900.00
D03C87	2017-08-14 09:31:00+03	359700.00
D03C94	2017-07-18 17:53:00+03	42400.00
D03CB0	2017-07-25 22:04:00+03	42700.00
D03CCD	2017-08-12 05:51:00+03	31200.00
D03CEB	2017-07-02 10:35:00+03	68400.00
D03CED	2017-08-01 10:19:00+03	59000.00
D03D6F	2017-07-16 19:25:00+03	14800.00
D03D9A	2017-07-29 05:06:00+03	12600.00
D03DCB	2017-07-25 16:33:00+03	23600.00
D03DFA	2017-07-10 05:08:00+03	52300.00
D03E50	2017-08-11 02:59:00+03	40000.00
D03E73	2017-07-17 09:34:00+03	25200.00
D03EEA	2017-08-11 01:27:00+03	38600.00
D03EFC	2017-07-15 04:42:00+03	28000.00
D03FB3	2017-07-19 08:52:00+03	177200.00
D03FE3	2017-08-01 13:25:00+03	66600.00
D04011	2017-08-07 09:17:00+03	37200.00
D04015	2017-07-18 20:24:00+03	10800.00
D0408A	2017-07-11 18:56:00+03	160400.00
D040C4	2017-08-12 04:00:00+03	56000.00
D04148	2017-07-21 03:23:00+03	111700.00
D0414E	2017-07-07 14:22:00+03	13400.00
D0415B	2017-08-07 01:20:00+03	48800.00
D041FF	2017-08-10 10:03:00+03	20700.00
D0420E	2017-07-11 22:30:00+03	72800.00
D0421F	2017-08-01 21:21:00+03	6300.00
D042EC	2017-08-01 02:23:00+03	28000.00
D042F1	2017-07-14 01:03:00+03	56600.00
D0433C	2017-07-21 01:30:00+03	94900.00
D04346	2017-07-11 14:30:00+03	55800.00
D04375	2017-07-14 01:09:00+03	97900.00
D043B8	2017-08-08 05:53:00+03	132800.00
D043C7	2017-07-14 15:47:00+03	67700.00
D043E6	2017-07-15 00:37:00+03	171100.00
D043F4	2017-08-08 20:08:00+03	42800.00
D0454C	2017-07-03 16:44:00+03	27200.00
D04574	2017-08-02 02:22:00+03	28800.00
D0458E	2017-08-13 16:17:00+03	7200.00
D0459B	2017-07-24 02:41:00+03	123600.00
D04604	2017-07-09 19:34:00+03	46400.00
D04624	2017-07-09 03:42:00+03	65900.00
D04649	2017-07-31 12:13:00+03	32800.00
D0465E	2017-06-29 04:11:00+03	62600.00
D046A8	2017-08-13 11:09:00+03	64500.00
D046B7	2017-07-13 16:08:00+03	26700.00
D0470A	2017-07-05 05:56:00+03	14000.00
D04784	2017-07-26 21:15:00+03	34800.00
D04785	2017-08-11 12:38:00+03	14400.00
D047CF	2017-07-04 21:35:00+03	31900.00
D047D8	2017-07-30 02:09:00+03	29600.00
D047DA	2017-07-27 08:49:00+03	24800.00
D0490B	2017-07-23 07:42:00+03	46000.00
D049A6	2017-08-09 16:13:00+03	135400.00
D049BA	2017-08-02 04:51:00+03	23100.00
D049C1	2017-07-11 05:46:00+03	43100.00
D049DF	2017-07-22 13:57:00+03	53800.00
D04B7D	2017-08-15 13:09:00+03	43200.00
D04BEB	2017-07-05 10:58:00+03	112000.00
D04C6A	2017-08-06 06:10:00+03	57800.00
D04CE7	2017-08-07 06:11:00+03	135400.00
D04D19	2017-07-23 03:02:00+03	58600.00
D04D24	2017-07-20 08:38:00+03	73600.00
D04DD5	2017-07-14 04:15:00+03	20000.00
D04DD7	2017-07-16 12:19:00+03	231900.00
D04E1A	2017-08-10 21:44:00+03	12000.00
D04E54	2017-07-20 20:05:00+03	80300.00
D04E56	2017-07-21 19:50:00+03	65200.00
D04E89	2017-07-24 05:25:00+03	39400.00
D04E8C	2017-07-20 11:19:00+03	64100.00
D04ED0	2017-07-13 17:36:00+03	21800.00
D04FC1	2017-07-18 05:34:00+03	56600.00
D0505D	2017-08-08 06:41:00+03	55800.00
D050B1	2017-08-12 23:17:00+03	49100.00
D050E6	2017-08-11 04:59:00+03	14000.00
D05188	2017-07-07 22:17:00+03	89600.00
D051B2	2017-07-19 09:35:00+03	112000.00
D051B7	2017-08-12 13:05:00+03	16400.00
D051B8	2017-07-08 13:19:00+03	17800.00
D05214	2017-08-10 05:36:00+03	25400.00
D05224	2017-07-26 23:37:00+03	75600.00
D05253	2017-07-27 11:17:00+03	10100.00
D0525C	2017-07-25 20:05:00+03	27800.00
D05273	2017-08-03 20:37:00+03	162300.00
D052CE	2017-07-21 18:59:00+03	173900.00
D052EE	2017-07-13 12:19:00+03	57500.00
D053D8	2017-08-06 07:13:00+03	70400.00
D05416	2017-07-11 17:03:00+03	44600.00
D05474	2017-07-21 06:27:00+03	6700.00
D0549F	2017-07-31 18:51:00+03	25000.00
D054E4	2017-07-19 09:34:00+03	19800.00
D054F6	2017-08-09 07:20:00+03	69500.00
D05506	2017-07-27 18:39:00+03	14000.00
D05598	2017-07-01 14:16:00+03	26000.00
D055E3	2017-07-24 17:48:00+03	23200.00
D055FF	2017-07-20 13:40:00+03	40800.00
D05616	2017-07-10 15:09:00+03	92800.00
D05625	2017-07-23 09:10:00+03	23600.00
D056C6	2017-08-05 17:55:00+03	74400.00
D056EE	2017-07-05 21:42:00+03	55700.00
D05760	2017-08-05 14:47:00+03	46900.00
D05783	2017-08-09 04:25:00+03	44500.00
D0578B	2017-07-21 18:02:00+03	14800.00
D057B9	2017-07-15 04:21:00+03	78100.00
D057F9	2017-07-04 03:28:00+03	20400.00
D05816	2017-07-28 01:23:00+03	140300.00
D05837	2017-07-01 16:23:00+03	118400.00
D0583A	2017-07-20 00:28:00+03	46300.00
D05840	2017-08-10 05:16:00+03	72800.00
D05890	2017-07-24 10:13:00+03	133200.00
D058B9	2017-08-09 22:25:00+03	50600.00
D058D9	2017-07-08 07:16:00+03	27900.00
D05924	2017-07-07 02:43:00+03	73500.00
D0595A	2017-07-29 21:56:00+03	35300.00
D05A20	2017-08-01 21:48:00+03	254900.00
D05A31	2017-07-08 21:15:00+03	111600.00
D05AB5	2017-07-21 13:31:00+03	42100.00
D05B06	2017-07-13 08:00:00+03	26200.00
D05B50	2017-07-31 16:42:00+03	29400.00
D05B83	2017-07-03 05:21:00+03	35200.00
D05B86	2017-06-29 03:50:00+03	14400.00
D05BA2	2017-08-09 03:40:00+03	123000.00
D05BB4	2017-07-30 17:49:00+03	14000.00
D05BDC	2017-07-08 02:21:00+03	40800.00
D05BDE	2017-08-12 01:46:00+03	63400.00
D05C40	2017-07-05 21:59:00+03	246000.00
D05C75	2017-07-03 10:01:00+03	66600.00
D05CB4	2017-07-10 16:13:00+03	134200.00
D05D0A	2017-08-07 06:19:00+03	119500.00
D05D4B	2017-07-03 13:13:00+03	58400.00
D05D8E	2017-07-18 22:45:00+03	23200.00
D05DB2	2017-07-04 14:48:00+03	77200.00
D05E30	2017-08-05 19:55:00+03	47600.00
D05E3A	2017-07-12 21:36:00+03	24700.00
D05E42	2017-07-21 10:19:00+03	84000.00
D05EB2	2017-07-04 18:54:00+03	36200.00
D05EC6	2017-08-11 15:04:00+03	68100.00
D05EC7	2017-07-02 07:01:00+03	25400.00
D05EFE	2017-06-24 07:11:00+03	24200.00
D05F43	2017-08-09 06:10:00+03	131100.00
D05F70	2017-08-03 09:51:00+03	25600.00
D05F88	2017-07-07 09:35:00+03	207000.00
D05FB2	2017-07-07 12:50:00+03	112000.00
D05FD4	2017-07-16 04:41:00+03	106600.00
D05FDA	2017-07-26 21:59:00+03	147400.00
D05FF6	2017-07-23 18:19:00+03	114700.00
D0602C	2017-07-12 14:52:00+03	57500.00
D0608C	2017-08-10 01:20:00+03	23600.00
D060C5	2017-07-25 17:44:00+03	159100.00
D06165	2017-07-24 11:34:00+03	42900.00
D061E0	2017-07-26 18:25:00+03	25600.00
D06210	2017-08-03 23:44:00+03	28200.00
D062C4	2017-08-08 14:25:00+03	96800.00
D0633A	2017-07-12 13:35:00+03	92800.00
D06343	2017-07-15 05:49:00+03	56000.00
D06362	2017-07-26 16:06:00+03	73500.00
D063A9	2017-08-12 20:13:00+03	37600.00
D063AC	2017-08-14 09:36:00+03	90400.00
D063CA	2017-07-23 23:29:00+03	43200.00
D063DD	2017-07-05 15:10:00+03	54400.00
D063E8	2017-08-05 16:23:00+03	78500.00
D0642F	2017-08-09 01:28:00+03	28000.00
D06471	2017-07-26 02:59:00+03	42800.00
D06505	2017-07-04 11:03:00+03	9800.00
D06515	2017-08-02 12:14:00+03	357600.00
D065A5	2017-07-04 07:57:00+03	136800.00
D065A8	2017-08-03 08:56:00+03	40000.00
D065C1	2017-07-11 05:27:00+03	106400.00
D065EF	2017-08-07 15:17:00+03	72400.00
D06664	2017-07-13 18:15:00+03	20200.00
D06729	2017-08-12 19:39:00+03	63800.00
D0674E	2017-08-07 17:16:00+03	47200.00
D06775	2017-08-15 08:58:00+03	23600.00
D06778	2017-07-14 09:59:00+03	20200.00
D067BC	2017-08-02 05:59:00+03	12400.00
D0682F	2017-08-08 22:11:00+03	34000.00
D068BA	2017-08-09 15:14:00+03	133200.00
D068C3	2017-07-28 11:49:00+03	213200.00
D0697D	2017-07-02 00:28:00+03	96800.00
D0698E	2017-06-28 04:58:00+03	43200.00
D069E6	2017-08-12 01:06:00+03	35200.00
D06A01	2017-08-14 04:32:00+03	43000.00
D06A04	2017-07-16 11:52:00+03	57400.00
D06A7D	2017-07-27 20:38:00+03	265700.00
D06A83	2017-08-10 07:42:00+03	24400.00
D06ACD	2017-07-02 06:30:00+03	27200.00
D06B75	2017-08-11 18:56:00+03	46000.00
D06B7E	2017-07-25 06:46:00+03	119500.00
D06BC7	2017-07-22 13:27:00+03	72400.00
D06BCA	2017-07-24 05:27:00+03	56600.00
D06BEE	2017-07-03 19:36:00+03	25100.00
D06C62	2017-07-30 08:54:00+03	21200.00
D06C8F	2017-08-01 01:40:00+03	130900.00
D06CD6	2017-08-14 07:33:00+03	7200.00
D06CF0	2017-06-27 21:54:00+03	67900.00
D06CF4	2017-06-27 18:25:00+03	92000.00
D06D07	2017-07-15 13:49:00+03	29600.00
D06D1D	2017-08-09 19:42:00+03	22000.00
D06D60	2017-07-21 03:32:00+03	38400.00
D06D6F	2017-07-21 20:31:00+03	59300.00
D06D96	2017-07-14 16:50:00+03	34000.00
D06DB5	2017-07-13 08:31:00+03	83500.00
D06DD1	2017-07-06 03:47:00+03	73300.00
D06DD5	2017-07-26 00:46:00+03	16400.00
D06DF7	2017-08-03 20:08:00+03	55800.00
D06E8A	2017-08-14 08:50:00+03	91300.00
D06EAC	2017-07-17 16:36:00+03	265600.00
D06EED	2017-07-05 12:45:00+03	72400.00
D06F14	2017-08-01 12:12:00+03	46900.00
D06F28	2017-07-11 00:06:00+03	32700.00
D06F40	2017-07-09 06:09:00+03	46000.00
D06FCC	2017-08-14 21:18:00+03	58900.00
D07055	2017-08-13 05:34:00+03	85000.00
D07089	2017-07-18 04:47:00+03	96800.00
D070A5	2017-07-27 21:10:00+03	123000.00
D0711D	2017-07-01 16:07:00+03	32800.00
D0712D	2017-08-08 09:49:00+03	56000.00
D07180	2017-08-09 20:20:00+03	27800.00
D071A5	2017-08-06 02:29:00+03	40100.00
D071AF	2017-07-13 14:15:00+03	277800.00
D07209	2017-08-13 15:22:00+03	74400.00
D07214	2017-07-22 20:18:00+03	87400.00
D07229	2017-07-19 21:50:00+03	41600.00
D07247	2017-07-25 00:55:00+03	26000.00
D07267	2017-08-12 08:33:00+03	51600.00
D072A5	2017-07-10 01:52:00+03	92700.00
D0739A	2017-07-28 01:00:00+03	34000.00
D073CA	2017-07-30 15:00:00+03	80000.00
D07410	2017-07-06 15:51:00+03	10700.00
D07427	2017-07-20 07:03:00+03	32800.00
D074A8	2017-07-08 23:50:00+03	12200.00
D074CB	2017-07-22 01:53:00+03	12400.00
D0752D	2017-08-14 06:08:00+03	34100.00
D07549	2017-07-09 09:48:00+03	138000.00
D07580	2017-08-13 05:30:00+03	85000.00
D075A9	2017-07-26 11:39:00+03	28000.00
D075FA	2017-07-06 16:25:00+03	160100.00
D0760D	2017-07-03 00:12:00+03	6700.00
D07643	2017-07-26 06:54:00+03	41800.00
D0767F	2017-07-10 01:09:00+03	45200.00
D0768C	2017-07-11 04:48:00+03	63700.00
D07697	2017-08-04 07:08:00+03	13600.00
D076F9	2017-08-02 07:45:00+03	66600.00
D07700	2017-08-12 11:29:00+03	24600.00
D07708	2017-07-29 03:43:00+03	147200.00
D07712	2017-07-26 04:43:00+03	91600.00
D07752	2017-07-30 01:40:00+03	99300.00
D0779E	2017-08-04 08:12:00+03	95600.00
D077CD	2017-07-15 09:27:00+03	95700.00
D0782D	2017-07-17 05:47:00+03	13000.00
D0784C	2017-08-06 10:19:00+03	47400.00
D078AF	2017-08-09 13:44:00+03	47000.00
D078F5	2017-07-25 14:23:00+03	265600.00
D07952	2017-07-11 10:01:00+03	56600.00
D0796F	2017-06-24 05:04:00+03	56000.00
D0798F	2017-07-01 09:27:00+03	28800.00
D079A9	2017-08-05 15:43:00+03	62600.00
D079C4	2017-07-05 16:38:00+03	26000.00
D079CC	2017-07-12 16:26:00+03	248300.00
D079D6	2017-07-24 04:57:00+03	7400.00
D07A2D	2017-07-29 17:54:00+03	312200.00
D07A49	2017-07-08 17:05:00+03	29100.00
D07AC1	2017-07-26 17:27:00+03	123000.00
D07ACD	2017-07-20 20:26:00+03	124300.00
D07C22	2017-07-13 20:17:00+03	43600.00
D07CBF	2017-07-06 03:09:00+03	19600.00
D07CC5	2017-07-17 16:09:00+03	68000.00
D07D26	2017-07-04 04:08:00+03	42800.00
D07D2F	2017-08-08 05:53:00+03	44000.00
D07D5C	2017-07-28 11:17:00+03	39800.00
D07D72	2017-08-06 19:08:00+03	122000.00
D07DD7	2017-07-26 16:25:00+03	26000.00
D07DEC	2017-07-17 13:54:00+03	123000.00
D07F39	2017-08-05 06:15:00+03	14800.00
D07F3A	2017-07-16 05:56:00+03	23400.00
D07F4B	2017-08-14 06:56:00+03	58200.00
D07F52	2017-07-02 00:31:00+03	26800.00
D07FAC	2017-08-12 19:47:00+03	21400.00
D08066	2017-07-16 03:26:00+03	44000.00
D08079	2017-08-02 20:31:00+03	93900.00
D0809A	2017-07-11 08:22:00+03	141700.00
D080B1	2017-07-27 06:44:00+03	246000.00
D080D6	2017-07-29 07:04:00+03	257500.00
D08153	2017-07-26 22:51:00+03	167400.00
D08155	2017-07-13 04:57:00+03	213200.00
D08196	2017-07-12 04:51:00+03	28000.00
D08234	2017-08-14 18:11:00+03	26200.00
D0827E	2017-08-06 21:32:00+03	191800.00
D0829B	2017-07-28 13:10:00+03	64700.00
D082C8	2017-07-11 17:59:00+03	61800.00
D082F6	2017-08-10 00:39:00+03	23200.00
D08309	2017-07-10 10:46:00+03	210600.00
D08320	2017-07-24 07:14:00+03	140200.00
D0832B	2017-08-14 19:30:00+03	45200.00
D08353	2017-07-23 19:07:00+03	99200.00
D08369	2017-06-27 05:09:00+03	299000.00
D08370	2017-07-24 11:56:00+03	73300.00
D0837A	2017-07-29 19:00:00+03	75600.00
D08411	2017-07-31 16:03:00+03	8200.00
D0842F	2017-07-09 15:01:00+03	90800.00
D08435	2017-07-18 16:16:00+03	182200.00
D0844E	2017-07-11 11:20:00+03	48600.00
D084A5	2017-08-14 08:46:00+03	23400.00
D084BC	2017-08-01 07:37:00+03	51600.00
D084F7	2017-06-28 19:00:00+03	67000.00
D0859A	2017-07-29 04:20:00+03	46000.00
D085AD	2017-07-02 02:14:00+03	75800.00
D0860C	2017-07-23 10:10:00+03	48400.00
D08615	2017-07-16 10:44:00+03	15400.00
D0861D	2017-06-26 00:49:00+03	46300.00
D0863C	2017-07-27 05:09:00+03	84400.00
D0863D	2017-07-22 15:05:00+03	55800.00
D0868A	2017-08-09 02:38:00+03	496600.00
D086A7	2017-07-06 13:02:00+03	49600.00
D08704	2017-07-03 18:24:00+03	219500.00
D0872F	2017-07-29 05:10:00+03	86400.00
D087B8	2017-07-26 15:43:00+03	32400.00
D087DD	2017-08-10 23:56:00+03	112000.00
D087F8	2017-07-08 12:14:00+03	28800.00
D0880A	2017-07-25 00:57:00+03	103200.00
D0881D	2017-08-09 12:31:00+03	9800.00
D08941	2017-07-08 02:22:00+03	87900.00
D08950	2017-07-20 04:40:00+03	241300.00
D08986	2017-07-29 10:32:00+03	68400.00
D089A3	2017-08-12 09:07:00+03	29600.00
D089F7	2017-07-06 23:59:00+03	34700.00
D08A6C	2017-07-28 05:46:00+03	112000.00
D08A6E	2017-08-03 02:06:00+03	39400.00
D08A89	2017-08-01 16:27:00+03	71800.00
D08ACF	2017-07-03 20:20:00+03	73200.00
D08B0A	2017-08-15 08:03:00+03	97400.00
D08B28	2017-07-26 21:42:00+03	89600.00
D08B2C	2017-08-14 19:55:00+03	33100.00
D08B55	2017-07-18 13:49:00+03	26200.00
D08B88	2017-07-29 16:55:00+03	258400.00
D08B9B	2017-07-03 04:09:00+03	36200.00
D08BD2	2017-06-29 19:23:00+03	46000.00
D08C06	2017-08-04 02:33:00+03	198400.00
D08C49	2017-06-30 03:58:00+03	29600.00
D08C83	2017-07-17 23:55:00+03	53700.00
D08CA7	2017-07-25 20:47:00+03	46000.00
D08D40	2017-08-04 16:26:00+03	111000.00
D08D70	2017-07-21 14:11:00+03	46300.00
D08D96	2017-08-05 01:50:00+03	38800.00
D08DD1	2017-07-20 10:08:00+03	131600.00
D08E45	2017-07-28 02:52:00+03	57400.00
D08E58	2017-07-13 17:10:00+03	13400.00
D08E79	2017-07-17 09:27:00+03	11000.00
D08E9E	2017-08-06 21:55:00+03	71200.00
D08F19	2017-08-04 16:16:00+03	288500.00
D08F29	2017-07-10 08:58:00+03	20200.00
D08F67	2017-07-20 06:09:00+03	87700.00
D08FDF	2017-07-02 12:34:00+03	190900.00
D09077	2017-08-15 09:28:00+03	24000.00
D09078	2017-07-22 15:38:00+03	101200.00
D09099	2017-07-28 16:41:00+03	42500.00
D0909A	2017-07-20 10:50:00+03	28000.00
D090EC	2017-07-07 01:28:00+03	263200.00
D091F5	2017-08-12 09:51:00+03	73500.00
D09245	2017-07-20 17:21:00+03	147200.00
D09249	2017-07-13 19:00:00+03	69500.00
D0925D	2017-07-08 05:22:00+03	6700.00
D09395	2017-07-31 04:00:00+03	121200.00
D093D4	2017-08-04 13:20:00+03	24400.00
D09482	2017-07-30 14:24:00+03	24400.00
D094B4	2017-07-29 05:23:00+03	23200.00
D094E0	2017-07-04 03:20:00+03	46800.00
D094F6	2017-07-19 07:31:00+03	85000.00
D09572	2017-07-09 12:57:00+03	13400.00
D09598	2017-07-23 11:40:00+03	19600.00
D0959A	2017-07-13 22:06:00+03	56000.00
D09631	2017-08-02 10:16:00+03	19000.00
D09737	2017-07-30 14:56:00+03	113800.00
D0975B	2017-07-21 05:37:00+03	23200.00
D09761	2017-08-11 14:26:00+03	26800.00
D09766	2017-07-24 19:42:00+03	14400.00
D09782	2017-07-20 02:23:00+03	85000.00
D09802	2017-08-05 10:54:00+03	16400.00
D09820	2017-08-09 05:57:00+03	27200.00
D098B3	2017-08-08 16:59:00+03	26700.00
D098D5	2017-08-15 11:47:00+03	149000.00
D098D6	2017-07-19 23:58:00+03	88800.00
D098EF	2017-07-06 12:46:00+03	90600.00
D0990C	2017-07-31 04:20:00+03	73300.00
D099AE	2017-07-05 07:32:00+03	27300.00
D09A47	2017-07-20 14:26:00+03	24400.00
D09A51	2017-07-04 10:16:00+03	135200.00
D09ADC	2017-07-13 03:35:00+03	32700.00
D09B2F	2017-08-13 11:39:00+03	55800.00
D09B38	2017-07-25 07:49:00+03	103500.00
D09B4F	2017-07-20 09:07:00+03	30200.00
D09B7B	2017-08-14 22:19:00+03	193300.00
D09B9F	2017-07-29 07:01:00+03	105400.00
D09BDC	2017-08-09 10:24:00+03	27300.00
D09C95	2017-07-20 03:13:00+03	91900.00
D09D81	2017-07-19 06:11:00+03	62700.00
D09D83	2017-07-09 11:22:00+03	56000.00
D09E44	2017-07-13 07:04:00+03	12000.00
D09E67	2017-08-07 03:49:00+03	58600.00
D09E81	2017-07-05 02:06:00+03	47200.00
D09F0C	2017-07-27 11:15:00+03	36200.00
D09F2C	2017-08-04 12:06:00+03	34000.00
D09F7B	2017-07-02 18:38:00+03	12000.00
D09F7C	2017-07-16 11:17:00+03	53600.00
D09F84	2017-07-18 01:26:00+03	176800.00
D09F90	2017-07-31 09:10:00+03	25600.00
D09FDC	2017-08-01 18:41:00+03	55800.00
D0A04B	2017-07-09 14:10:00+03	46200.00
D0A05F	2017-08-05 11:57:00+03	37800.00
D0A060	2017-08-07 00:27:00+03	6000.00
D0A06C	2017-07-19 18:04:00+03	24400.00
D0A070	2017-07-13 23:17:00+03	123000.00
D0A08C	2017-07-27 23:54:00+03	170000.00
D0A18E	2017-07-27 23:14:00+03	6600.00
D0A198	2017-07-17 21:09:00+03	47400.00
D0A202	2017-08-05 10:08:00+03	114800.00
D0A29F	2017-08-09 06:31:00+03	56000.00
D0A2EC	2017-08-04 08:52:00+03	47600.00
D0A339	2017-07-12 10:19:00+03	135600.00
D0A33D	2017-07-29 04:09:00+03	56600.00
D0A342	2017-08-11 13:14:00+03	12600.00
D0A358	2017-07-21 02:41:00+03	189200.00
D0A39D	2017-07-27 19:09:00+03	16400.00
D0A3A5	2017-08-11 17:26:00+03	24000.00
D0A3E9	2017-07-27 13:05:00+03	38600.00
D0A445	2017-08-12 20:03:00+03	100700.00
D0A454	2017-08-01 23:03:00+03	22000.00
D0A471	2017-08-07 18:06:00+03	38600.00
D0A48A	2017-07-05 15:15:00+03	36200.00
D0A4BE	2017-07-25 00:08:00+03	37000.00
D0A518	2017-08-11 19:36:00+03	31200.00
D0A52E	2017-07-27 08:09:00+03	28000.00
D0A53E	2017-08-02 02:00:00+03	13600.00
D0A5F6	2017-08-08 14:08:00+03	6700.00
D0A623	2017-08-10 16:20:00+03	23200.00
D0A729	2017-07-25 02:19:00+03	135400.00
D0A740	2017-08-05 15:01:00+03	55800.00
D0A75B	2017-07-19 13:59:00+03	52900.00
D0A75D	2017-06-29 14:09:00+03	64700.00
D0A766	2017-07-12 15:47:00+03	6000.00
D0A789	2017-07-31 07:17:00+03	62800.00
D0A7C6	2017-07-01 17:00:00+03	49400.00
D0A7D8	2017-07-15 06:26:00+03	67400.00
D0A7FC	2017-08-15 15:02:00+03	28000.00
D0A882	2017-08-11 00:52:00+03	36200.00
D0A899	2017-08-13 19:17:00+03	53800.00
D0A8B8	2017-07-29 09:28:00+03	38800.00
D0A920	2017-07-21 12:28:00+03	6000.00
D0A924	2017-07-30 20:50:00+03	73600.00
D0A99F	2017-08-01 01:33:00+03	31900.00
D0A9BD	2017-08-10 18:56:00+03	28300.00
D0AA20	2017-07-08 02:02:00+03	78000.00
D0AA54	2017-07-29 12:26:00+03	40400.00
D0AA6E	2017-06-30 08:54:00+03	73200.00
D0AA7C	2017-07-24 08:13:00+03	130700.00
D0AAD3	2017-07-07 12:28:00+03	46700.00
D0AB0A	2017-08-12 09:25:00+03	39400.00
D0AB89	2017-08-09 14:14:00+03	531400.00
D0ABBD	2017-07-02 00:46:00+03	500100.00
D0ABD2	2017-08-02 16:18:00+03	38200.00
D0AC32	2017-08-05 13:05:00+03	56100.00
D0AC56	2017-07-10 09:25:00+03	111600.00
D0AC89	2017-08-01 23:10:00+03	6700.00
D0AD3C	2017-07-19 22:25:00+03	53500.00
D0ADA6	2017-07-31 02:31:00+03	24400.00
D0AEA9	2017-07-03 06:36:00+03	18800.00
D0AECD	2017-07-28 16:05:00+03	37600.00
D0AEEB	2017-07-31 05:46:00+03	123000.00
D0AF4B	2017-07-10 07:30:00+03	56600.00
D0AFAD	2017-07-17 08:56:00+03	6300.00
D0B171	2017-08-13 13:38:00+03	102600.00
D0B1A9	2017-07-06 05:58:00+03	16400.00
D0B200	2017-07-04 01:53:00+03	23200.00
D0B20E	2017-06-28 19:24:00+03	24400.00
D0B232	2017-07-08 07:34:00+03	189800.00
D0B2C2	2017-08-06 14:05:00+03	10600.00
D0B2F0	2017-07-05 01:00:00+03	81300.00
D0B353	2017-08-10 05:39:00+03	178800.00
D0B36D	2017-07-23 13:25:00+03	22000.00
D0B37F	2017-07-26 04:59:00+03	43500.00
D0B439	2017-08-10 11:31:00+03	47500.00
D0B480	2017-07-14 08:19:00+03	39600.00
D0B584	2017-07-15 06:03:00+03	57400.00
D0B5A9	2017-08-04 17:40:00+03	38800.00
D0B5C5	2017-08-02 14:19:00+03	68000.00
D0B5D9	2017-08-10 11:37:00+03	30200.00
D0B5E9	2017-08-01 04:44:00+03	27800.00
D0B5FD	2017-07-14 00:37:00+03	48800.00
D0B68C	2017-07-11 06:06:00+03	79100.00
D0B6E4	2017-07-17 08:44:00+03	52300.00
D0B73C	2017-08-14 11:57:00+03	137400.00
D0B7AC	2017-07-10 01:01:00+03	46000.00
D0B7CF	2017-08-09 12:40:00+03	85000.00
D0B7D1	2017-08-11 15:24:00+03	6300.00
D0B7E2	2017-07-27 19:45:00+03	59200.00
D0B7EE	2017-07-12 20:26:00+03	37100.00
D0B811	2017-07-06 17:47:00+03	58500.00
D0B815	2017-08-03 21:44:00+03	52000.00
D0B835	2017-07-14 08:15:00+03	26300.00
D0B838	2017-08-02 01:58:00+03	39500.00
D0B865	2017-07-15 19:55:00+03	81700.00
D0B8E4	2017-07-15 14:15:00+03	180900.00
D0B95E	2017-08-07 07:31:00+03	20200.00
D0B97C	2017-07-04 22:03:00+03	38600.00
D0B9AD	2017-07-23 05:06:00+03	266400.00
D0B9BA	2017-07-25 15:43:00+03	57400.00
D0B9CE	2017-08-05 02:56:00+03	18600.00
D0B9EF	2017-07-22 13:10:00+03	123000.00
D0BA15	2017-08-12 00:28:00+03	14400.00
D0BA1E	2017-07-22 07:55:00+03	54500.00
D0BA36	2017-07-17 21:03:00+03	198900.00
D0BA50	2017-07-10 17:07:00+03	56800.00
D0BA56	2017-07-10 16:10:00+03	87200.00
D0BAAD	2017-08-04 00:48:00+03	56000.00
D0BAB5	2017-07-22 12:43:00+03	137600.00
D0BB07	2017-07-31 05:00:00+03	66600.00
D0BBA2	2017-07-15 11:38:00+03	51000.00
D0BBA8	2017-07-31 09:02:00+03	29200.00
D0BBBF	2017-07-21 04:20:00+03	67400.00
D0BC06	2017-07-18 05:16:00+03	10600.00
D0BC25	2017-07-29 15:22:00+03	103500.00
D0BC7C	2017-07-24 14:04:00+03	46900.00
D0BCB0	2017-07-11 10:57:00+03	187800.00
D0BCDA	2017-07-13 04:02:00+03	39600.00
D0BCE9	2017-08-06 03:08:00+03	70100.00
D0BD52	2017-07-15 00:39:00+03	75200.00
D0BD53	2017-08-14 04:30:00+03	39200.00
D0BD63	2017-08-13 03:52:00+03	112600.00
D0BE0C	2017-07-11 08:59:00+03	25100.00
D0BE3C	2017-07-21 06:06:00+03	46300.00
D0BEF0	2017-06-28 11:51:00+03	62600.00
D0BF00	2017-08-14 09:28:00+03	166900.00
D0BF2F	2017-07-29 05:21:00+03	24500.00
D0BF3A	2017-07-10 02:45:00+03	111600.00
D0BF6F	2017-08-12 05:20:00+03	54000.00
D0BFC1	2017-07-15 18:44:00+03	103500.00
D0BFDD	2017-07-29 12:05:00+03	261700.00
D0C00A	2017-07-15 13:22:00+03	21000.00
D0C015	2017-07-01 17:47:00+03	55000.00
D0C01B	2017-07-15 13:58:00+03	75300.00
D0C034	2017-07-12 09:16:00+03	43100.00
D0C03B	2017-08-02 22:39:00+03	399600.00
D0C070	2017-07-23 14:34:00+03	135200.00
D0C0F0	2017-07-09 21:33:00+03	76200.00
D0C12C	2017-08-12 17:26:00+03	386300.00
D0C1A5	2017-07-31 06:58:00+03	34600.00
D0C205	2017-07-13 15:58:00+03	173200.00
D0C247	2017-07-17 20:19:00+03	45100.00
D0C264	2017-08-01 01:09:00+03	28000.00
D0C26C	2017-07-31 02:45:00+03	13700.00
D0C28F	2017-07-08 14:46:00+03	14700.00
D0C2A5	2017-08-12 12:37:00+03	258400.00
D0C2DF	2017-07-31 18:37:00+03	58800.00
D0C30F	2017-07-18 00:17:00+03	31600.00
D0C313	2017-07-17 08:11:00+03	77600.00
D0C373	2017-08-10 06:20:00+03	111400.00
D0C468	2017-08-03 02:06:00+03	113800.00
D0C564	2017-07-24 20:53:00+03	89700.00
D0C571	2017-07-27 02:34:00+03	62000.00
D0C58A	2017-07-27 22:50:00+03	32800.00
D0C5D3	2017-07-07 06:07:00+03	60200.00
D0C5EA	2017-08-15 13:31:00+03	133100.00
D0C623	2017-08-13 12:52:00+03	117600.00
D0C648	2017-07-26 09:00:00+03	123000.00
D0C64A	2017-07-18 19:08:00+03	46000.00
D0C673	2017-07-17 11:49:00+03	104200.00
D0C6AB	2017-07-15 06:30:00+03	59000.00
D0C785	2017-08-09 07:56:00+03	23200.00
D0C7B9	2017-07-09 16:34:00+03	23200.00
D0C7C6	2017-07-07 11:47:00+03	13600.00
D0C848	2017-07-16 00:19:00+03	12000.00
D0C8E1	2017-07-06 00:34:00+03	23400.00
D0C942	2017-07-04 11:54:00+03	101200.00
D0CA1F	2017-07-31 08:19:00+03	131600.00
D0CA33	2017-07-18 20:53:00+03	71600.00
D0CA66	2017-08-06 17:57:00+03	86300.00
D0CB08	2017-07-31 10:43:00+03	29600.00
D0CB4D	2017-07-07 08:51:00+03	27400.00
D0CC30	2017-07-15 01:36:00+03	77600.00
D0CC6E	2017-08-11 20:32:00+03	28000.00
D0CC9B	2017-07-05 11:41:00+03	6800.00
D0CCB2	2017-08-07 15:16:00+03	68000.00
D0CCC4	2017-07-17 18:58:00+03	31800.00
D0CD07	2017-07-14 22:04:00+03	36400.00
D0CD65	2017-08-13 21:46:00+03	99200.00
D0CD89	2017-07-03 22:15:00+03	114700.00
D0CE04	2017-07-08 08:37:00+03	104000.00
D0CE17	2017-08-03 06:15:00+03	26000.00
D0CE5A	2017-08-05 01:23:00+03	117200.00
D0CE76	2017-07-14 06:22:00+03	67600.00
D0CE79	2017-07-11 15:28:00+03	56000.00
D0CE97	2017-08-15 05:14:00+03	14000.00
D0CEBA	2017-07-10 07:24:00+03	90800.00
D0CEC4	2017-08-11 11:38:00+03	36400.00
D0CF19	2017-07-02 03:31:00+03	61800.00
D0CF99	2017-08-06 15:04:00+03	398500.00
D0D07E	2017-07-21 11:10:00+03	34600.00
D0D0AD	2017-08-08 12:11:00+03	29600.00
D0D111	2017-07-23 11:09:00+03	27800.00
D0D196	2017-07-07 13:47:00+03	110500.00
D0D1A3	2017-08-03 09:24:00+03	95100.00
D0D1DC	2017-08-04 23:43:00+03	139700.00
D0D224	2017-07-26 20:41:00+03	28000.00
D0D28F	2017-08-01 06:20:00+03	54400.00
D0D29D	2017-08-06 09:03:00+03	9800.00
D0D348	2017-08-12 23:15:00+03	16400.00
D0D357	2017-08-11 12:11:00+03	30900.00
D0D3D7	2017-07-17 03:12:00+03	112000.00
D0D48D	2017-08-14 02:50:00+03	67700.00
D0D56A	2017-07-25 19:01:00+03	46300.00
D0D583	2017-08-10 18:44:00+03	79800.00
D0D593	2017-07-25 15:54:00+03	28300.00
D0D59D	2017-07-29 05:39:00+03	87100.00
D0D5D5	2017-07-20 22:02:00+03	39300.00
D0D5DB	2017-08-05 13:53:00+03	131100.00
D0D647	2017-07-17 04:35:00+03	12400.00
D0D667	2017-07-13 04:43:00+03	10700.00
D0D71D	2017-08-07 13:34:00+03	173500.00
D0D744	2017-08-04 17:36:00+03	81000.00
D0D7BA	2017-07-04 12:24:00+03	47400.00
D0D7C6	2017-07-23 10:09:00+03	47000.00
D0D80E	2017-07-27 09:23:00+03	46000.00
D0D82A	2017-07-27 16:01:00+03	112000.00
D0D8D6	2017-07-23 08:04:00+03	56000.00
D0D96F	2017-08-12 13:41:00+03	40800.00
D0D99D	2017-07-12 09:41:00+03	96400.00
D0D9F9	2017-07-03 04:52:00+03	39000.00
D0DA40	2017-07-16 08:35:00+03	23600.00
D0DA43	2017-07-07 00:14:00+03	99300.00
D0DA58	2017-07-24 10:11:00+03	20000.00
D0DB16	2017-07-06 17:14:00+03	20200.00
D0DB19	2017-08-08 13:19:00+03	50000.00
D0DB6D	2017-07-09 21:59:00+03	27800.00
D0DBEF	2017-07-17 05:09:00+03	101100.00
D0DC53	2017-08-08 09:56:00+03	45200.00
D0DC9E	2017-07-14 11:43:00+03	95700.00
D0DCE4	2017-07-13 21:42:00+03	29000.00
D0DCF0	2017-08-05 09:00:00+03	45200.00
D0DD0B	2017-07-18 07:11:00+03	29400.00
D0DD0C	2017-08-14 20:10:00+03	25200.00
D0DD1A	2017-08-07 15:28:00+03	8400.00
D0DD7F	2017-08-11 04:36:00+03	48000.00
D0DE77	2017-07-14 15:38:00+03	123000.00
D0DE8A	2017-07-18 00:07:00+03	16800.00
D0DF07	2017-08-07 17:23:00+03	17800.00
D0DF4E	2017-07-20 07:28:00+03	60400.00
D0DF64	2017-07-20 17:54:00+03	40600.00
D0DF72	2017-08-12 13:37:00+03	421200.00
D0DF9D	2017-07-09 22:35:00+03	24700.00
D0DFB7	2017-07-07 00:44:00+03	23900.00
D0DFCD	2017-07-17 00:37:00+03	21400.00
D0DFE1	2017-07-15 11:31:00+03	133200.00
D0E011	2017-07-27 11:04:00+03	56600.00
D0E078	2017-08-07 19:28:00+03	48300.00
D0E0D2	2017-07-30 15:41:00+03	26000.00
D0E0E5	2017-07-20 09:37:00+03	15400.00
D0E0EE	2017-08-07 11:50:00+03	22600.00
D0E15B	2017-08-13 18:22:00+03	143100.00
D0E1E1	2017-07-14 05:25:00+03	135600.00
D0E1E6	2017-08-01 14:51:00+03	72600.00
D0E216	2017-07-19 16:24:00+03	386200.00
D0E25E	2017-08-11 22:47:00+03	54400.00
D0E264	2017-07-05 00:11:00+03	94000.00
D0E27E	2017-08-12 11:00:00+03	92000.00
D0E361	2017-07-19 17:27:00+03	100600.00
D0E369	2017-07-03 04:18:00+03	23600.00
D0E36A	2017-08-10 01:43:00+03	57200.00
D0E3D2	2017-07-20 09:39:00+03	26700.00
D0E410	2017-08-09 15:53:00+03	133100.00
D0E466	2017-08-03 14:49:00+03	246000.00
D0E4A3	2017-07-29 23:08:00+03	135100.00
D0E4AC	2017-07-22 18:12:00+03	27300.00
D0E4E8	2017-08-14 08:45:00+03	92700.00
D0E53E	2017-08-06 01:04:00+03	123000.00
D0E59D	2017-08-03 03:09:00+03	61100.00
D0E5CF	2017-07-31 17:16:00+03	94000.00
D0E67F	2017-07-05 03:11:00+03	69500.00
D0E69B	2017-07-31 04:35:00+03	163500.00
D0E75C	2017-07-06 05:13:00+03	10800.00
D0E768	2017-06-29 22:24:00+03	44800.00
D0E7B3	2017-07-14 06:33:00+03	46200.00
D0E7C2	2017-07-11 01:55:00+03	73100.00
D0E7E9	2017-07-16 15:43:00+03	73300.00
D0E7F3	2017-07-25 08:59:00+03	19200.00
D0E85A	2017-07-16 01:55:00+03	140800.00
D0E914	2017-08-09 23:51:00+03	39500.00
D0E93C	2017-07-28 02:11:00+03	282300.00
D0E972	2017-08-15 10:33:00+03	38400.00
D0E98E	2017-07-09 13:16:00+03	125400.00
D0E9C6	2017-07-29 17:19:00+03	189800.00
D0E9FE	2017-07-30 23:30:00+03	136200.00
D0EA08	2017-06-30 08:47:00+03	23200.00
D0EA37	2017-08-12 05:21:00+03	35800.00
D0EA7C	2017-07-17 09:12:00+03	50600.00
D0EABA	2017-07-23 21:56:00+03	25000.00
D0EB41	2017-07-16 16:52:00+03	92000.00
D0EB49	2017-07-05 14:50:00+03	31900.00
D0EBA4	2017-06-30 03:32:00+03	281500.00
D0EBE4	2017-07-09 08:35:00+03	103800.00
D0EC89	2017-07-14 04:04:00+03	25000.00
D0ECEB	2017-08-09 06:35:00+03	25000.00
D0ECF2	2017-07-07 09:00:00+03	95200.00
D0ECFF	2017-07-15 16:09:00+03	66000.00
D0ED14	2017-07-10 05:37:00+03	27200.00
D0ED60	2017-07-23 07:39:00+03	39400.00
D0EDBB	2017-07-29 14:47:00+03	69900.00
D0EEB5	2017-07-02 10:20:00+03	75300.00
D0EEDD	2017-07-19 05:34:00+03	92800.00
D0EEFA	2017-07-05 08:50:00+03	40000.00
D0EF21	2017-08-12 01:09:00+03	96100.00
D0EF7D	2017-07-16 23:20:00+03	23400.00
D0EFB0	2017-08-01 16:37:00+03	54800.00
D0F02B	2017-08-08 23:37:00+03	14000.00
D0F032	2017-07-27 15:52:00+03	32700.00
D0F0B3	2017-07-14 08:08:00+03	84500.00
D0F0B9	2017-08-11 03:54:00+03	6800.00
D0F0F9	2017-07-09 18:55:00+03	150600.00
D0F115	2017-08-06 00:57:00+03	57700.00
D0F190	2017-08-01 21:00:00+03	28800.00
D0F1B5	2017-07-08 20:12:00+03	135000.00
D0F247	2017-08-04 12:26:00+03	115600.00
D0F27C	2017-07-25 14:02:00+03	36800.00
D0F2B0	2017-08-15 11:45:00+03	8000.00
D0F2E1	2017-08-01 05:08:00+03	47200.00
D0F3BB	2017-08-08 19:48:00+03	30000.00
D0F3D3	2017-08-11 18:03:00+03	64700.00
D0F448	2017-07-15 06:11:00+03	3700.00
D0F45F	2017-08-07 15:41:00+03	47200.00
D0F46A	2017-08-03 09:11:00+03	56600.00
D0F48A	2017-07-18 01:49:00+03	26200.00
D0F4B8	2017-07-03 21:34:00+03	188100.00
D0F4C9	2017-08-01 07:33:00+03	32900.00
D0F4F3	2017-07-19 06:30:00+03	47800.00
D0F4F4	2017-07-23 10:54:00+03	89700.00
D0F5D9	2017-07-19 09:52:00+03	131100.00
D0F63E	2017-07-27 15:07:00+03	57600.00
D0F65A	2017-08-03 10:05:00+03	55800.00
D0F665	2017-07-22 01:41:00+03	48800.00
D0F6C1	2017-07-16 20:29:00+03	23600.00
D0F71B	2017-07-23 13:46:00+03	27200.00
D0F722	2017-08-15 01:24:00+03	57100.00
D0F72C	2017-08-07 02:34:00+03	112600.00
D0F72E	2017-07-07 22:42:00+03	121400.00
D0F776	2017-07-15 01:22:00+03	26700.00
D0F7A7	2017-07-12 17:50:00+03	13200.00
D0F8AB	2017-07-21 12:48:00+03	54000.00
D0F94B	2017-08-03 03:00:00+03	29100.00
D0F98A	2017-07-05 07:13:00+03	123000.00
D0F997	2017-07-07 00:53:00+03	155800.00
D0FA15	2017-08-13 11:04:00+03	48000.00
D0FA3C	2017-07-03 05:27:00+03	56000.00
D0FAC4	2017-07-20 03:50:00+03	78800.00
D0FAF6	2017-07-24 09:40:00+03	56000.00
D0FB2E	2017-07-28 10:23:00+03	15000.00
D0FB30	2017-07-26 13:55:00+03	61800.00
D0FB37	2017-08-08 08:05:00+03	155000.00
D0FB62	2017-07-25 06:24:00+03	13800.00
D0FCA0	2017-07-13 16:30:00+03	47100.00
D0FCBC	2017-08-14 10:35:00+03	141700.00
D0FD36	2017-08-01 01:01:00+03	46400.00
D0FD93	2017-07-20 15:17:00+03	51600.00
D0FDEE	2017-07-29 01:18:00+03	42700.00
D0FE6C	2017-07-06 03:49:00+03	113900.00
D0FE78	2017-06-30 06:57:00+03	46000.00
D0FE95	2017-08-14 17:49:00+03	64700.00
D0FEBC	2017-07-06 06:09:00+03	23600.00
D0FF1A	2017-07-04 21:56:00+03	91600.00
D0FF56	2017-07-29 07:00:00+03	6000.00
D0FF84	2017-07-01 09:52:00+03	15400.00
D0FFAB	2017-07-07 09:04:00+03	72200.00
D0FFB1	2017-07-26 16:53:00+03	151200.00
D0FFC1	2017-08-05 12:27:00+03	236000.00
D10050	2017-07-20 23:44:00+03	31000.00
D10056	2017-07-08 11:18:00+03	34600.00
D100BD	2017-07-13 10:48:00+03	193200.00
D10188	2017-07-02 05:56:00+03	141600.00
D10276	2017-07-26 05:54:00+03	66000.00
D1028B	2017-08-06 10:59:00+03	88000.00
D102F2	2017-07-11 11:53:00+03	47000.00
D10323	2017-07-09 00:53:00+03	133200.00
D10339	2017-07-13 01:34:00+03	150000.00
D103C0	2017-07-25 14:32:00+03	28000.00
D103F0	2017-08-11 16:49:00+03	35200.00
D10403	2017-06-29 21:13:00+03	29600.00
D1055D	2017-07-09 08:45:00+03	22000.00
D105F8	2017-07-28 04:13:00+03	133200.00
D10638	2017-07-06 09:11:00+03	157100.00
D10676	2017-08-15 08:15:00+03	50600.00
D10728	2017-07-09 12:31:00+03	22000.00
D1079A	2017-08-02 15:46:00+03	252200.00
D107D1	2017-07-18 18:26:00+03	40800.00
D107F6	2017-07-27 09:51:00+03	135400.00
D108EC	2017-07-07 11:27:00+03	29600.00
D109EE	2017-07-24 22:36:00+03	23200.00
D10A1B	2017-07-11 06:32:00+03	67200.00
D10A86	2017-07-13 16:57:00+03	25600.00
D10AD7	2017-08-04 00:52:00+03	100000.00
D10B54	2017-07-14 13:20:00+03	67100.00
D10B58	2017-07-19 19:34:00+03	29600.00
D10BAD	2017-07-08 03:18:00+03	21400.00
D10BAF	2017-07-03 05:32:00+03	84500.00
D10BE5	2017-07-16 06:20:00+03	102100.00
D10BF1	2017-06-29 14:02:00+03	23200.00
D10C51	2017-07-18 09:04:00+03	28800.00
D10C86	2017-08-13 20:33:00+03	12600.00
D10CAA	2017-07-06 05:12:00+03	88900.00
D10CAC	2017-07-30 16:17:00+03	112000.00
D10CB1	2017-08-06 04:13:00+03	133200.00
D10CDA	2017-08-01 23:51:00+03	94900.00
D10D43	2017-08-02 18:22:00+03	132800.00
D10D4B	2017-07-14 05:57:00+03	101100.00
D10DB9	2017-07-23 02:52:00+03	16400.00
D10DED	2017-07-12 19:22:00+03	47200.00
D10E08	2017-07-27 16:19:00+03	148200.00
D10E2C	2017-07-06 17:08:00+03	67600.00
D10EC1	2017-07-05 11:40:00+03	193700.00
D10ED3	2017-08-15 12:38:00+03	91500.00
D10F33	2017-08-12 23:46:00+03	32700.00
D10FC3	2017-07-14 18:20:00+03	298600.00
D110C7	2017-07-08 14:24:00+03	297200.00
D110CC	2017-07-27 14:36:00+03	112000.00
D11137	2017-08-15 11:21:00+03	40000.00
D1118A	2017-08-01 04:46:00+03	92800.00
D11227	2017-07-22 22:02:00+03	130400.00
D112CD	2017-07-18 18:32:00+03	115900.00
D112EF	2017-07-15 08:06:00+03	73500.00
D1131A	2017-07-21 12:28:00+03	68800.00
D113FC	2017-07-31 17:35:00+03	102100.00
D11459	2017-08-06 20:38:00+03	13700.00
D114E2	2017-07-13 11:35:00+03	23600.00
D11571	2017-07-20 22:58:00+03	204200.00
D11586	2017-08-02 12:33:00+03	47800.00
D11593	2017-07-17 18:43:00+03	111600.00
D11599	2017-08-01 04:08:00+03	52000.00
D115F6	2017-07-12 07:05:00+03	28800.00
D11681	2017-08-06 07:15:00+03	92400.00
D1169D	2017-08-02 01:17:00+03	112000.00
D116AC	2017-08-12 15:18:00+03	31600.00
D116AE	2017-07-28 07:27:00+03	265700.00
D116B9	2017-07-23 18:45:00+03	85700.00
D116C7	2017-08-02 13:37:00+03	47000.00
D116F7	2017-07-10 16:34:00+03	12600.00
D1171F	2017-07-02 05:48:00+03	99500.00
D11728	2017-08-06 04:30:00+03	43600.00
D11749	2017-07-10 00:05:00+03	88900.00
D1174A	2017-07-17 20:56:00+03	23400.00
D11758	2017-08-08 15:22:00+03	28000.00
D11761	2017-08-09 13:53:00+03	67200.00
D1179C	2017-08-04 07:01:00+03	47000.00
D117CF	2017-07-09 11:47:00+03	45200.00
D11804	2017-08-04 18:20:00+03	86600.00
D1180A	2017-07-26 23:08:00+03	59400.00
D118D1	2017-07-25 00:01:00+03	40100.00
D1192A	2017-07-25 05:06:00+03	43600.00
D1194C	2017-07-11 22:03:00+03	37700.00
D11955	2017-07-14 16:58:00+03	35200.00
D11A12	2017-08-14 16:05:00+03	48500.00
D11A1F	2017-07-14 08:08:00+03	18500.00
D11AE1	2017-07-05 11:40:00+03	113600.00
D11B19	2017-08-13 09:22:00+03	16400.00
D11B5A	2017-07-30 03:50:00+03	23600.00
D11BB2	2017-08-06 02:15:00+03	12400.00
D11BDB	2017-07-30 07:37:00+03	13600.00
D11BE5	2017-07-19 21:58:00+03	51200.00
D11BEF	2017-08-07 10:15:00+03	30300.00
D11BFE	2017-07-24 08:44:00+03	48800.00
D11C26	2017-07-02 15:32:00+03	59300.00
D11C2E	2017-08-03 16:28:00+03	33400.00
D11C30	2017-07-16 00:51:00+03	12600.00
D11C5C	2017-07-12 19:25:00+03	43200.00
D11C62	2017-07-28 18:56:00+03	64700.00
D11CB4	2017-07-14 13:45:00+03	40600.00
D11CD4	2017-07-15 03:56:00+03	51900.00
D11CE6	2017-07-26 00:59:00+03	46400.00
D11D3D	2017-08-11 08:39:00+03	86500.00
D11D50	2017-07-24 12:30:00+03	31400.00
D11DA5	2017-08-01 18:42:00+03	135000.00
D11E05	2017-08-05 16:04:00+03	13600.00
D11E37	2017-07-19 00:30:00+03	54500.00
D11E95	2017-07-16 02:54:00+03	43200.00
D11E97	2017-07-08 12:40:00+03	79600.00
D11F06	2017-08-11 02:45:00+03	73200.00
D11F5C	2017-07-01 08:38:00+03	71900.00
D11F65	2017-08-03 12:16:00+03	177200.00
D11FEC	2017-08-07 19:48:00+03	23600.00
D12018	2017-07-22 17:54:00+03	54800.00
D12039	2017-07-18 00:49:00+03	89600.00
D12110	2017-08-04 06:37:00+03	19800.00
D1215D	2017-07-13 07:38:00+03	29600.00
D1218B	2017-07-16 21:52:00+03	55600.00
D121AB	2017-08-14 06:53:00+03	50400.00
D121B5	2017-07-10 09:02:00+03	85000.00
D121B8	2017-07-18 02:48:00+03	8200.00
D121CC	2017-08-09 06:47:00+03	63300.00
D122D0	2017-07-22 13:07:00+03	72000.00
D122ED	2017-08-11 03:03:00+03	16000.00
D1231F	2017-07-22 10:53:00+03	69500.00
D1234D	2017-08-15 16:12:00+03	147100.00
D1238D	2017-07-30 15:36:00+03	31400.00
D123D7	2017-08-02 20:43:00+03	88300.00
D123E9	2017-07-06 22:07:00+03	184800.00
D1243B	2017-08-01 13:41:00+03	55600.00
D12458	2017-07-21 20:29:00+03	62600.00
D12500	2017-07-22 06:54:00+03	62900.00
D1251A	2017-07-11 20:52:00+03	47000.00
D1257A	2017-07-29 10:36:00+03	6000.00
D125B8	2017-07-19 06:11:00+03	34000.00
D125D4	2017-07-21 14:44:00+03	34000.00
D1260A	2017-08-02 06:47:00+03	246000.00
D12629	2017-07-04 04:46:00+03	14800.00
D1264B	2017-08-09 03:45:00+03	19600.00
D12676	2017-07-30 20:53:00+03	290600.00
D126AD	2017-07-17 12:52:00+03	9200.00
D126B7	2017-08-11 13:59:00+03	36800.00
D12731	2017-07-31 17:50:00+03	57600.00
D1274F	2017-07-29 11:24:00+03	27900.00
D127A2	2017-07-30 03:26:00+03	35700.00
D127DA	2017-07-23 07:54:00+03	40800.00
D127E0	2017-07-08 10:16:00+03	58600.00
D127E8	2017-07-05 03:06:00+03	23200.00
D127FD	2017-07-05 13:13:00+03	26200.00
D12855	2017-07-10 01:21:00+03	133200.00
D1286A	2017-08-09 07:15:00+03	13400.00
D1296C	2017-07-19 22:44:00+03	81200.00
D129C5	2017-07-20 18:10:00+03	109000.00
D12A15	2017-07-28 00:12:00+03	120600.00
D12A52	2017-08-04 11:08:00+03	34000.00
D12A73	2017-07-15 20:58:00+03	24800.00
D12AC2	2017-08-10 13:29:00+03	150300.00
D12B0A	2017-07-12 05:31:00+03	37900.00
D12B20	2017-08-01 09:05:00+03	123200.00
D12B58	2017-07-15 14:02:00+03	30000.00
D12B5A	2017-08-07 20:06:00+03	147700.00
D12B6F	2017-07-17 02:07:00+03	36200.00
D12BB7	2017-07-10 13:19:00+03	269600.00
D12BD3	2017-07-30 23:25:00+03	39500.00
D12BDD	2017-07-02 11:20:00+03	6000.00
D12C36	2017-07-25 16:29:00+03	38800.00
D12C46	2017-07-06 07:12:00+03	112800.00
D12C4E	2017-07-31 05:17:00+03	134000.00
D12CF9	2017-07-25 08:57:00+03	46300.00
D12CFB	2017-07-19 22:02:00+03	246000.00
D12DA2	2017-07-25 07:13:00+03	58200.00
D12E3E	2017-08-08 18:38:00+03	12400.00
D12E85	2017-08-10 10:38:00+03	25400.00
D12EC1	2017-07-20 09:12:00+03	56600.00
D12EC5	2017-08-12 12:24:00+03	79600.00
D12F6B	2017-07-17 09:24:00+03	14000.00
D12F85	2017-08-09 17:51:00+03	12400.00
D12FBD	2017-08-08 02:45:00+03	61900.00
D12FD3	2017-07-09 11:28:00+03	28800.00
D13059	2017-07-09 16:40:00+03	59200.00
D13064	2017-07-08 03:18:00+03	29600.00
D13073	2017-08-11 07:18:00+03	86800.00
D13148	2017-08-08 06:09:00+03	15400.00
D1319B	2017-08-15 14:38:00+03	111600.00
D13288	2017-07-09 03:21:00+03	36800.00
D132A8	2017-08-04 20:19:00+03	51600.00
D1330C	2017-07-18 01:57:00+03	24600.00
D1333A	2017-07-03 09:01:00+03	34000.00
D1333C	2017-08-09 14:08:00+03	133100.00
D13342	2017-07-13 09:34:00+03	26800.00
D13387	2017-07-28 10:08:00+03	65300.00
D133E0	2017-08-09 02:33:00+03	81000.00
D1341B	2017-07-09 21:16:00+03	302400.00
D134DC	2017-07-25 23:06:00+03	27200.00
D13527	2017-07-22 17:27:00+03	36600.00
D13553	2017-06-26 15:21:00+03	6800.00
D1357A	2017-08-05 04:32:00+03	73600.00
D13594	2017-08-15 14:22:00+03	28800.00
D135AF	2017-07-18 00:07:00+03	177200.00
D13614	2017-07-23 04:31:00+03	86300.00
D1371A	2017-07-20 16:34:00+03	6300.00
D137B9	2017-08-07 21:34:00+03	40100.00
D137C4	2017-07-06 20:12:00+03	62600.00
D137EC	2017-07-13 09:51:00+03	12600.00
D13831	2017-07-10 18:44:00+03	65500.00
D13835	2017-07-11 14:51:00+03	49600.00
D1383B	2017-08-07 05:57:00+03	28300.00
D13866	2017-07-29 22:13:00+03	39400.00
D138A9	2017-07-17 19:48:00+03	29800.00
D1394D	2017-07-28 00:27:00+03	257600.00
D1398B	2017-07-27 05:00:00+03	44600.00
D1398D	2017-08-15 11:53:00+03	37900.00
D139C7	2017-07-09 09:02:00+03	51600.00
D139FF	2017-07-16 17:57:00+03	129700.00
D13A0F	2017-07-02 22:11:00+03	223200.00
D13A73	2017-08-11 03:03:00+03	40000.00
D13AA5	2017-07-14 00:40:00+03	12600.00
D13AD4	2017-08-01 18:50:00+03	35200.00
D13AE5	2017-07-16 12:20:00+03	100600.00
D13B1B	2017-08-13 01:13:00+03	35600.00
D13BC9	2017-07-31 01:39:00+03	11000.00
D13C04	2017-08-07 20:49:00+03	29600.00
D13C35	2017-07-24 07:19:00+03	21800.00
D13C48	2017-07-27 12:50:00+03	58600.00
D13CA8	2017-07-16 19:43:00+03	133200.00
D13CCE	2017-07-29 22:23:00+03	28700.00
D13D17	2017-07-13 20:50:00+03	146700.00
D13D27	2017-07-06 20:57:00+03	52300.00
D13D32	2017-08-02 12:08:00+03	6000.00
D13DC7	2017-08-03 03:34:00+03	28000.00
D13F55	2017-07-22 07:08:00+03	117000.00
D13F61	2017-08-09 06:26:00+03	124300.00
D13F7D	2017-08-06 02:37:00+03	63900.00
D13FF3	2017-07-21 11:23:00+03	94200.00
D14021	2017-07-23 13:18:00+03	46400.00
D14052	2017-07-31 07:23:00+03	20400.00
D14077	2017-07-24 02:06:00+03	76600.00
D14094	2017-07-03 21:02:00+03	40800.00
D140AE	2017-07-05 13:18:00+03	155600.00
D14143	2017-07-21 18:12:00+03	153200.00
D14192	2017-07-17 00:07:00+03	141600.00
D1419D	2017-07-08 22:27:00+03	17200.00
D141B5	2017-07-16 22:32:00+03	23200.00
D141FF	2017-08-04 11:37:00+03	103500.00
D14206	2017-06-29 16:44:00+03	27900.00
D14245	2017-06-30 14:51:00+03	38800.00
D14300	2017-07-26 14:16:00+03	43000.00
D14343	2017-07-20 16:33:00+03	37900.00
D14372	2017-07-07 23:22:00+03	112000.00
D1437B	2017-08-11 09:09:00+03	28800.00
D14381	2017-07-30 23:54:00+03	22000.00
D1439A	2017-07-31 11:27:00+03	269500.00
D143A1	2017-07-02 19:36:00+03	9800.00
D143AF	2017-08-12 06:12:00+03	234200.00
D143D6	2017-08-01 13:20:00+03	13400.00
D143DD	2017-07-10 16:14:00+03	35300.00
D143ED	2017-07-27 08:11:00+03	52400.00
D143F9	2017-07-02 22:12:00+03	64800.00
D1443F	2017-07-27 06:11:00+03	36200.00
D14440	2017-07-03 18:46:00+03	44000.00
D14497	2017-07-28 04:03:00+03	63200.00
D144D7	2017-08-15 14:10:00+03	155600.00
D144F0	2017-08-11 23:28:00+03	37900.00
D14508	2017-07-24 16:08:00+03	34000.00
D1451A	2017-07-04 20:26:00+03	284800.00
D1456B	2017-07-01 08:17:00+03	22000.00
D14580	2017-08-10 07:07:00+03	122000.00
D1458C	2017-08-03 11:31:00+03	135200.00
D145EB	2017-07-28 16:14:00+03	86400.00
D1461A	2017-07-06 01:33:00+03	6000.00
D14651	2017-08-03 08:16:00+03	28800.00
D14652	2017-07-13 03:52:00+03	46200.00
D14663	2017-08-10 17:31:00+03	38800.00
D146B5	2017-07-03 11:26:00+03	8400.00
D146D7	2017-07-31 04:26:00+03	35700.00
D14709	2017-07-15 09:29:00+03	52800.00
D1473E	2017-07-15 06:52:00+03	39100.00
D1474D	2017-07-17 16:58:00+03	73200.00
D14773	2017-07-20 05:10:00+03	55600.00
D147A1	2017-07-27 15:01:00+03	39300.00
D147D9	2017-07-07 15:15:00+03	47300.00
D1481C	2017-07-20 15:22:00+03	56600.00
D1483E	2017-08-13 23:35:00+03	31400.00
D14841	2017-08-06 05:12:00+03	8000.00
D148AA	2017-08-07 18:18:00+03	38000.00
D148C3	2017-07-14 00:14:00+03	51900.00
D148D3	2017-08-03 16:14:00+03	44000.00
D14900	2017-08-01 05:17:00+03	24400.00
D14906	2017-08-05 19:59:00+03	25200.00
D14909	2017-07-19 13:54:00+03	64800.00
D14958	2017-07-11 01:28:00+03	160200.00
D149BE	2017-08-12 20:06:00+03	38400.00
D14A02	2017-08-07 20:50:00+03	45100.00
D14A1F	2017-07-15 21:26:00+03	46800.00
D14AAB	2017-08-12 01:54:00+03	122800.00
D14B0D	2017-08-10 21:30:00+03	22000.00
D14B46	2017-06-30 07:17:00+03	406700.00
D14B68	2017-07-12 14:54:00+03	167400.00
D14B6D	2017-08-01 23:04:00+03	24400.00
D14BAF	2017-08-10 05:38:00+03	95600.00
D14BCB	2017-07-06 05:53:00+03	85000.00
D14C30	2017-07-29 07:21:00+03	21800.00
D14C3F	2017-07-21 10:23:00+03	353000.00
D14C5C	2017-08-05 13:11:00+03	56600.00
D14C92	2017-07-30 18:27:00+03	68400.00
D14E35	2017-07-09 22:51:00+03	61200.00
D14E4E	2017-07-14 07:28:00+03	88600.00
D14ED1	2017-08-07 22:38:00+03	135600.00
D14EF2	2017-06-28 04:28:00+03	39700.00
D14EFB	2017-08-04 16:22:00+03	73000.00
D14F95	2017-08-03 07:36:00+03	39400.00
D14FB2	2017-07-14 20:47:00+03	37900.00
D14FDE	2017-07-21 00:17:00+03	289300.00
D14FE3	2017-07-13 03:36:00+03	99700.00
D15043	2017-07-01 08:40:00+03	50400.00
D1504D	2017-07-26 20:57:00+03	35500.00
D1507E	2017-08-10 02:45:00+03	23600.00
D150E5	2017-07-06 06:46:00+03	136800.00
D150F0	2017-08-08 22:06:00+03	246000.00
D1511B	2017-07-17 12:22:00+03	128800.00
D151C5	2017-07-30 19:08:00+03	101200.00
D151E1	2017-07-15 06:08:00+03	147700.00
D1520B	2017-07-14 05:22:00+03	19800.00
D15211	2017-07-02 08:42:00+03	14000.00
D15227	2017-07-20 18:01:00+03	270800.00
D1523F	2017-08-05 13:07:00+03	13200.00
D1525D	2017-08-04 21:02:00+03	65900.00
D15275	2017-08-12 23:33:00+03	31900.00
D152D4	2017-07-21 17:54:00+03	133200.00
D152E9	2017-07-29 10:21:00+03	15800.00
D152FB	2017-07-20 04:20:00+03	29800.00
D15312	2017-07-03 17:39:00+03	58400.00
D15341	2017-07-18 05:00:00+03	18800.00
D15368	2017-07-04 20:47:00+03	199700.00
D1539B	2017-07-24 15:46:00+03	244300.00
D153E2	2017-07-11 01:37:00+03	272300.00
D1541E	2017-08-05 03:36:00+03	532800.00
D154D5	2017-07-01 03:05:00+03	134900.00
D154FC	2017-08-13 03:14:00+03	83200.00
D1553F	2017-08-03 02:26:00+03	168000.00
D155A8	2017-08-05 19:23:00+03	38600.00
D155D0	2017-07-19 16:10:00+03	28000.00
D1565A	2017-07-28 06:35:00+03	26000.00
D1575E	2017-07-03 18:38:00+03	40800.00
D15777	2017-07-12 03:35:00+03	24400.00
D157FF	2017-08-05 08:44:00+03	101800.00
D15808	2017-07-31 09:41:00+03	12600.00
D1580D	2017-07-11 05:09:00+03	56000.00
D15823	2017-06-29 12:55:00+03	6000.00
D158B1	2017-07-14 00:50:00+03	56600.00
D158B4	2017-07-14 10:55:00+03	41600.00
D158F4	2017-07-26 05:20:00+03	74800.00
D1591D	2017-07-15 20:56:00+03	19800.00
D15946	2017-08-10 04:58:00+03	62800.00
D159D6	2017-06-30 15:53:00+03	57800.00
D159E8	2017-07-22 05:58:00+03	13700.00
D15A0F	2017-08-06 16:12:00+03	55600.00
D15AA2	2017-07-26 21:27:00+03	89700.00
D15AB9	2017-08-11 18:10:00+03	160700.00
D15AEE	2017-07-04 18:42:00+03	131100.00
D15B3B	2017-08-09 01:33:00+03	40200.00
D15B72	2017-07-10 09:50:00+03	54500.00
D15B76	2017-07-28 23:07:00+03	393800.00
D15B83	2017-08-14 08:56:00+03	109000.00
D15B8A	2017-08-10 03:22:00+03	343900.00
D15BF5	2017-07-08 11:15:00+03	8400.00
D15C3E	2017-08-05 23:37:00+03	10600.00
D15C55	2017-07-07 19:09:00+03	84200.00
D15CA7	2017-07-06 00:36:00+03	13000.00
D15CDF	2017-08-13 12:10:00+03	138500.00
D15CEC	2017-08-08 03:14:00+03	43000.00
D15D07	2017-08-02 10:56:00+03	73600.00
D15D15	2017-07-27 21:16:00+03	28000.00
D15D6B	2017-08-07 12:23:00+03	59200.00
D15DFE	2017-07-23 16:59:00+03	88900.00
D15E00	2017-07-16 03:26:00+03	55800.00
D15E17	2017-08-05 10:36:00+03	96800.00
D15E28	2017-07-06 10:09:00+03	122700.00
D15E42	2017-07-08 22:37:00+03	28000.00
D15E68	2017-07-08 02:54:00+03	37200.00
D15E8E	2017-07-04 00:16:00+03	26000.00
D15EF4	2017-07-18 12:33:00+03	12600.00
D15F08	2017-08-11 23:50:00+03	56000.00
D15F35	2017-08-02 13:01:00+03	20400.00
D15F85	2017-07-11 11:13:00+03	56000.00
D15FA3	2017-07-18 11:30:00+03	81600.00
D15FC8	2017-08-14 10:04:00+03	26000.00
D16039	2017-07-04 22:54:00+03	34000.00
D16056	2017-07-30 17:46:00+03	16400.00
D160F1	2017-07-20 18:37:00+03	132800.00
D16104	2017-07-23 22:49:00+03	62600.00
D1611D	2017-07-21 13:37:00+03	42800.00
D16201	2017-07-14 13:41:00+03	68800.00
D16220	2017-07-31 09:52:00+03	112000.00
D16267	2017-07-03 11:16:00+03	27200.00
D162A9	2017-08-01 12:34:00+03	103000.00
D162DE	2017-08-13 19:18:00+03	54800.00
D16337	2017-07-23 02:30:00+03	58600.00
D16342	2017-08-14 12:54:00+03	182200.00
D1634C	2017-07-23 06:24:00+03	73200.00
D163F5	2017-07-21 04:49:00+03	50000.00
D16403	2017-08-13 11:20:00+03	34000.00
D16406	2017-06-29 03:38:00+03	92600.00
D1642A	2017-07-27 05:11:00+03	28800.00
D164D1	2017-07-29 18:55:00+03	46400.00
D164EA	2017-07-17 02:09:00+03	52000.00
D16539	2017-08-06 17:23:00+03	52900.00
D16588	2017-07-18 11:06:00+03	516800.00
D1664B	2017-08-06 09:59:00+03	43900.00
D16653	2017-08-10 16:16:00+03	61800.00
D16667	2017-08-09 18:20:00+03	42400.00
D166B3	2017-07-27 07:26:00+03	66600.00
D166C7	2017-07-07 08:59:00+03	35200.00
D166F4	2017-07-29 05:24:00+03	28000.00
D167D0	2017-07-19 23:05:00+03	30200.00
D167DF	2017-06-29 17:18:00+03	37100.00
D168EE	2017-07-09 19:05:00+03	38000.00
D168F5	2017-08-03 05:00:00+03	19600.00
D16940	2017-08-11 11:22:00+03	59800.00
D169EC	2017-07-29 08:37:00+03	46400.00
D169F0	2017-08-09 19:12:00+03	546900.00
D169F1	2017-08-09 03:14:00+03	12600.00
D169F4	2017-08-10 06:31:00+03	19600.00
D169FF	2017-08-04 15:43:00+03	58900.00
D16A7F	2017-07-31 04:22:00+03	55800.00
D16AF5	2017-07-23 10:05:00+03	22200.00
D16AFB	2017-07-30 21:38:00+03	34400.00
D16B12	2017-07-03 08:57:00+03	61500.00
D16B71	2017-07-30 04:31:00+03	55000.00
D16BDE	2017-08-12 07:40:00+03	23600.00
D16C11	2017-07-08 20:14:00+03	266400.00
D16C36	2017-07-18 05:48:00+03	27200.00
D16CA6	2017-08-01 12:46:00+03	91800.00
D16CB9	2017-06-29 20:57:00+03	56000.00
D16D8A	2017-07-02 16:13:00+03	105000.00
D16DE2	2017-08-14 09:04:00+03	42700.00
D16E3C	2017-07-03 03:15:00+03	32600.00
D16E6B	2017-08-07 16:12:00+03	16400.00
D16EE7	2017-07-03 05:34:00+03	32800.00
D16F64	2017-08-08 07:17:00+03	354400.00
D16FB7	2017-08-04 03:32:00+03	31400.00
D17031	2017-08-15 13:35:00+03	52000.00
D17062	2017-08-13 11:43:00+03	116000.00
D1706E	2017-07-12 07:48:00+03	61500.00
D17086	2017-07-04 19:50:00+03	66400.00
D170A7	2017-07-25 04:56:00+03	60700.00
D170B2	2017-08-10 15:31:00+03	252200.00
D170B5	2017-07-31 16:15:00+03	69500.00
D170F9	2017-07-20 04:33:00+03	53400.00
D1710E	2017-07-12 03:56:00+03	23600.00
D17111	2017-07-27 18:48:00+03	198900.00
D1718A	2017-07-28 12:16:00+03	56000.00
D1718F	2017-07-24 20:17:00+03	19000.00
D171A2	2017-07-28 08:44:00+03	12600.00
D17222	2017-07-12 01:53:00+03	76600.00
D17233	2017-07-16 19:48:00+03	9300.00
D1725B	2017-08-14 11:48:00+03	20400.00
D1725F	2017-08-12 21:18:00+03	21500.00
D172A5	2017-08-03 22:43:00+03	24400.00
D172B0	2017-08-08 04:58:00+03	128800.00
D172CC	2017-07-15 23:39:00+03	135400.00
D172CF	2017-07-14 02:54:00+03	21400.00
D172DB	2017-07-13 03:47:00+03	33600.00
D17328	2017-06-30 14:19:00+03	55800.00
D17337	2017-07-30 15:21:00+03	62800.00
D17346	2017-06-30 23:39:00+03	89000.00
D1738B	2017-08-07 00:20:00+03	8200.00
D1739A	2017-07-14 23:35:00+03	34100.00
D1743F	2017-07-28 21:15:00+03	166000.00
D17462	2017-08-11 07:34:00+03	6000.00
D17479	2017-07-07 14:23:00+03	155600.00
D1748A	2017-07-02 15:37:00+03	6600.00
D1752C	2017-07-09 04:18:00+03	90400.00
D175D4	2017-08-08 13:21:00+03	56600.00
D17706	2017-08-07 08:11:00+03	58800.00
D177D8	2017-07-29 01:46:00+03	59200.00
D17813	2017-07-08 05:00:00+03	47400.00
D1782D	2017-08-06 10:03:00+03	131100.00
D1785D	2017-07-12 05:04:00+03	20400.00
D178BA	2017-08-11 02:38:00+03	112000.00
D178D4	2017-08-10 12:37:00+03	46200.00
D179A3	2017-07-17 07:47:00+03	92900.00
D179B5	2017-07-11 09:16:00+03	7300.00
D17A9B	2017-07-05 19:40:00+03	139300.00
D17AAF	2017-07-02 07:10:00+03	30200.00
D17AD6	2017-08-03 10:25:00+03	10100.00
D17B03	2017-07-06 22:37:00+03	56000.00
D17B0E	2017-07-14 01:08:00+03	37300.00
D17B77	2017-08-03 07:32:00+03	28800.00
D17B7B	2017-07-10 08:15:00+03	9200.00
D17B8D	2017-07-18 16:16:00+03	99300.00
D17B9E	2017-07-27 21:37:00+03	26000.00
D17BFD	2017-07-09 16:48:00+03	3400.00
D17C32	2017-07-24 03:35:00+03	52700.00
D17C4F	2017-08-01 14:56:00+03	134400.00
D17C56	2017-07-13 10:17:00+03	49600.00
D17CC9	2017-07-24 03:46:00+03	112000.00
D17D16	2017-07-03 08:47:00+03	111600.00
D17D19	2017-08-08 16:20:00+03	32200.00
D17D41	2017-07-09 08:51:00+03	189800.00
D17DE6	2017-07-30 03:34:00+03	62600.00
D17DF9	2017-07-12 01:31:00+03	147300.00
D17E9E	2017-06-29 09:03:00+03	56000.00
D17EAE	2017-07-11 14:32:00+03	24300.00
D17EFC	2017-08-06 08:13:00+03	22600.00
D17F04	2017-08-10 02:32:00+03	86800.00
D17F2F	2017-07-09 09:21:00+03	135400.00
D17F44	2017-08-02 23:50:00+03	72300.00
D17F83	2017-07-02 18:21:00+03	171700.00
D17FDE	2017-06-26 17:40:00+03	33100.00
D180A5	2017-07-07 19:56:00+03	46000.00
D180EF	2017-07-11 00:37:00+03	41800.00
D1810E	2017-07-25 18:05:00+03	23200.00
D18113	2017-07-28 19:18:00+03	135400.00
D18143	2017-07-06 22:57:00+03	32800.00
D18170	2017-07-13 02:54:00+03	82900.00
D18173	2017-07-19 08:48:00+03	28000.00
D181BE	2017-08-10 01:46:00+03	320400.00
D181E8	2017-08-13 10:59:00+03	26000.00
D181F8	2017-07-30 15:52:00+03	88800.00
D182A4	2017-08-10 21:24:00+03	40600.00
D1830C	2017-07-05 08:10:00+03	21800.00
D18341	2017-07-10 07:20:00+03	41400.00
D1834E	2017-07-19 16:35:00+03	283100.00
D1836C	2017-07-06 07:31:00+03	21800.00
D1839D	2017-08-11 12:21:00+03	52700.00
D183DB	2017-08-13 05:36:00+03	75200.00
D18435	2017-07-09 07:52:00+03	116800.00
D184F1	2017-07-16 08:19:00+03	54300.00
D1856A	2017-07-09 01:45:00+03	32700.00
D185D8	2017-07-18 17:27:00+03	40800.00
D185E3	2017-07-13 14:25:00+03	21800.00
D185FE	2017-08-06 06:15:00+03	265800.00
D1861A	2017-08-06 07:50:00+03	182000.00
D18656	2017-08-07 14:36:00+03	28800.00
D18694	2017-07-14 20:38:00+03	398500.00
D186E0	2017-08-12 18:16:00+03	125400.00
D186EB	2017-08-02 21:14:00+03	231800.00
D18733	2017-07-04 21:48:00+03	132800.00
D18760	2017-07-22 11:43:00+03	54500.00
D18797	2017-07-03 20:19:00+03	109600.00
D187A3	2017-08-07 10:46:00+03	95600.00
D187CE	2017-07-28 16:19:00+03	87400.00
D187EA	2017-07-24 01:51:00+03	12600.00
D1883C	2017-07-22 03:38:00+03	13400.00
D1883E	2017-06-29 19:09:00+03	229600.00
D188CB	2017-07-09 13:47:00+03	202400.00
D188EF	2017-07-08 23:33:00+03	74300.00
D18919	2017-08-13 14:51:00+03	43500.00
D18996	2017-07-25 03:07:00+03	75300.00
D18A0D	2017-08-14 10:36:00+03	40900.00
D18A19	2017-08-02 14:02:00+03	503000.00
D18A85	2017-08-03 15:27:00+03	135600.00
D18AB9	2017-08-04 22:35:00+03	15100.00
D18AC8	2017-08-07 03:36:00+03	28000.00
D18AF7	2017-08-10 14:38:00+03	110700.00
D18B1C	2017-07-10 03:37:00+03	51200.00
D18CF8	2017-08-09 19:08:00+03	136500.00
D18D20	2017-07-15 02:35:00+03	177200.00
D18D7C	2017-08-07 07:28:00+03	506500.00
D18DDD	2017-06-24 02:21:00+03	75100.00
D18DDE	2017-07-14 07:43:00+03	56600.00
D18DF3	2017-07-30 23:34:00+03	28800.00
D18E57	2017-07-03 15:15:00+03	16400.00
D18E5A	2017-08-09 21:17:00+03	135100.00
D18EC7	2017-08-13 03:26:00+03	12400.00
D18EE5	2017-07-27 20:23:00+03	44800.00
D18F22	2017-07-19 06:43:00+03	104000.00
D18F2E	2017-08-09 10:02:00+03	132800.00
D18F2F	2017-07-25 01:59:00+03	141600.00
D18F47	2017-08-12 01:34:00+03	71900.00
D18F9C	2017-07-16 02:43:00+03	122800.00
D18FA6	2017-08-14 19:30:00+03	44800.00
D18FD7	2017-08-15 02:37:00+03	128800.00
D18FDC	2017-08-07 19:57:00+03	42700.00
D190A9	2017-08-05 10:00:00+03	23400.00
D1919D	2017-07-31 09:03:00+03	36000.00
D191A4	2017-08-12 05:58:00+03	124800.00
D191C9	2017-07-06 00:48:00+03	78700.00
D1923F	2017-07-09 14:00:00+03	97900.00
D19277	2017-08-03 16:45:00+03	66600.00
D19293	2017-07-31 06:33:00+03	311200.00
D192A4	2017-07-05 12:14:00+03	86300.00
D192D7	2017-08-08 09:59:00+03	81300.00
D192FC	2017-07-07 22:34:00+03	55800.00
D19302	2017-07-06 21:42:00+03	29400.00
D1934D	2017-07-30 00:38:00+03	7400.00
D19361	2017-08-15 04:25:00+03	20200.00
D19364	2017-08-14 01:01:00+03	34000.00
D19397	2017-08-05 23:28:00+03	47200.00
D193BA	2017-07-26 22:52:00+03	126900.00
D193E9	2017-08-02 17:12:00+03	48800.00
D193EA	2017-07-09 08:04:00+03	173900.00
D19414	2017-08-05 05:21:00+03	96100.00
D19444	2017-08-13 00:22:00+03	8200.00
D194B4	2017-07-20 10:26:00+03	41400.00
D194DE	2017-07-17 18:48:00+03	59800.00
D1955F	2017-07-22 03:28:00+03	246000.00
D195BA	2017-08-05 20:28:00+03	67700.00
D196B8	2017-07-16 22:05:00+03	405600.00
D196BE	2017-07-25 12:42:00+03	16800.00
D196D7	2017-08-10 20:28:00+03	41400.00
D196E5	2017-07-03 10:17:00+03	16400.00
D19762	2017-08-15 17:21:00+03	27900.00
D197E3	2017-07-25 01:04:00+03	61900.00
D1984E	2017-07-04 05:20:00+03	26000.00
D19873	2017-07-22 21:35:00+03	103500.00
D19887	2017-07-13 15:01:00+03	12400.00
D198B3	2017-08-11 23:31:00+03	13200.00
D198E9	2017-07-03 23:02:00+03	99300.00
D1991E	2017-06-28 13:48:00+03	36000.00
D19920	2017-07-15 16:25:00+03	203300.00
D1992C	2017-07-11 08:31:00+03	75300.00
D19948	2017-07-22 10:50:00+03	8400.00
D19957	2017-07-08 09:03:00+03	23600.00
D1998E	2017-07-24 11:16:00+03	148300.00
D199AE	2017-07-13 01:03:00+03	369000.00
D199B4	2017-08-13 18:55:00+03	44800.00
D199CB	2017-08-07 04:03:00+03	54800.00
D19A1E	2017-08-08 02:27:00+03	92400.00
D19A4B	2017-08-13 13:38:00+03	56000.00
D19A57	2017-08-10 23:55:00+03	28000.00
D19A65	2017-08-09 03:28:00+03	113200.00
D19A6D	2017-07-15 15:33:00+03	43200.00
D19A83	2017-07-26 17:30:00+03	13400.00
D19A9D	2017-07-13 13:10:00+03	141600.00
D19ACA	2017-07-08 09:34:00+03	123000.00
D19ADE	2017-08-07 02:51:00+03	32800.00
D19B07	2017-07-30 12:18:00+03	100200.00
D19B0C	2017-07-01 13:26:00+03	201800.00
D19B19	2017-08-01 08:24:00+03	18600.00
D19B4B	2017-07-23 10:18:00+03	50000.00
D19B8C	2017-07-06 16:08:00+03	101200.00
D19B9A	2017-07-27 12:02:00+03	187400.00
D19BE2	2017-07-15 04:25:00+03	56000.00
D19BE3	2017-07-30 08:16:00+03	56000.00
D19C46	2017-07-05 20:06:00+03	167400.00
D19C4F	2017-08-02 17:36:00+03	64400.00
D19D0A	2017-07-17 06:58:00+03	260900.00
D19D57	2017-07-07 16:19:00+03	58800.00
D19D93	2017-08-04 22:15:00+03	189200.00
D19D9B	2017-08-10 11:07:00+03	137400.00
D19DCE	2017-08-14 01:58:00+03	28800.00
D19DE7	2017-07-03 06:14:00+03	140900.00
D19E5C	2017-07-09 14:12:00+03	57400.00
D19E66	2017-07-11 11:03:00+03	8400.00
D19EB3	2017-08-14 05:23:00+03	407200.00
D19EB5	2017-07-26 11:52:00+03	32400.00
D1A03D	2017-08-02 10:34:00+03	6000.00
D1A05E	2017-08-01 19:13:00+03	30900.00
D1A077	2017-07-04 02:51:00+03	39500.00
D1A0C4	2017-07-27 17:34:00+03	123000.00
D1A0DC	2017-08-10 07:21:00+03	112200.00
D1A0E3	2017-07-04 21:06:00+03	32700.00
D1A163	2017-07-25 19:20:00+03	113800.00
D1A168	2017-07-25 18:47:00+03	63400.00
D1A179	2017-07-10 14:10:00+03	112000.00
D1A17A	2017-07-20 18:55:00+03	52100.00
D1A199	2017-07-23 02:44:00+03	99200.00
D1A1BD	2017-08-11 20:17:00+03	137800.00
D1A21D	2017-07-12 21:22:00+03	14000.00
D1A234	2017-08-02 01:31:00+03	27200.00
D1A242	2017-08-06 00:34:00+03	130400.00
D1A2A6	2017-07-26 21:27:00+03	53400.00
D1A327	2017-07-02 20:45:00+03	66000.00
D1A366	2017-07-15 06:27:00+03	27200.00
D1A374	2017-07-11 02:23:00+03	123000.00
D1A384	2017-08-06 10:55:00+03	186200.00
D1A3A2	2017-07-16 21:29:00+03	28800.00
D1A3A8	2017-08-04 12:55:00+03	83600.00
D1A3E3	2017-07-18 08:01:00+03	21400.00
D1A4AD	2017-08-14 15:55:00+03	37200.00
D1A4CC	2017-08-02 10:58:00+03	78800.00
D1A4EA	2017-07-11 13:53:00+03	136800.00
D1A5E6	2017-07-08 05:10:00+03	123000.00
D1A615	2017-07-23 15:19:00+03	258400.00
D1A680	2017-07-19 03:04:00+03	66600.00
D1A692	2017-08-15 17:07:00+03	270700.00
D1A6A9	2017-07-29 05:03:00+03	37900.00
D1A70E	2017-07-04 15:11:00+03	56000.00
D1A71A	2017-07-30 03:05:00+03	25100.00
D1A71F	2017-07-19 22:42:00+03	235400.00
D1A7CE	2017-08-01 07:59:00+03	29600.00
D1A7F9	2017-06-27 21:40:00+03	39200.00
D1A828	2017-07-06 06:33:00+03	44000.00
D1A876	2017-07-03 00:30:00+03	43600.00
D1A8A5	2017-07-12 02:51:00+03	57500.00
D1A914	2017-07-14 04:56:00+03	34400.00
D1A9A6	2017-07-22 20:53:00+03	20200.00
D1A9D8	2017-07-03 18:02:00+03	250100.00
D1A9F4	2017-07-06 08:06:00+03	56000.00
D1AA1F	2017-08-06 11:34:00+03	84900.00
D1AA48	2017-08-08 00:13:00+03	75800.00
D1AA95	2017-07-25 05:13:00+03	132100.00
D1AACC	2017-08-07 12:31:00+03	109800.00
D1AAF5	2017-08-15 06:30:00+03	52000.00
D1AB22	2017-07-22 00:42:00+03	100200.00
D1ABD3	2017-07-17 00:46:00+03	51300.00
D1AC0E	2017-08-04 22:24:00+03	69600.00
D1ACD5	2017-07-24 12:55:00+03	199700.00
D1AD30	2017-08-13 00:16:00+03	25100.00
D1ADA0	2017-08-13 13:59:00+03	41600.00
D1ADE0	2017-07-04 23:50:00+03	76800.00
D1ADE7	2017-07-25 14:38:00+03	59000.00
D1AEB6	2017-07-29 01:21:00+03	7300.00
D1AED7	2017-07-06 02:54:00+03	20200.00
D1AF10	2017-07-08 09:29:00+03	58200.00
D1AF42	2017-07-16 04:06:00+03	92900.00
D1AF5D	2017-08-06 15:43:00+03	28800.00
D1AFA9	2017-08-07 10:10:00+03	40600.00
D1AFBA	2017-07-31 09:00:00+03	123700.00
D1AFE2	2017-07-03 11:09:00+03	54400.00
D1B001	2017-08-10 11:09:00+03	33000.00
D1B01C	2017-07-25 23:34:00+03	73600.00
D1B03A	2017-08-07 04:13:00+03	38800.00
D1B088	2017-07-21 09:39:00+03	51200.00
D1B112	2017-07-14 09:17:00+03	65500.00
D1B11D	2017-07-06 20:09:00+03	38600.00
D1B15F	2017-07-19 17:34:00+03	124800.00
D1B190	2017-07-06 17:06:00+03	128800.00
D1B1DE	2017-07-08 01:17:00+03	92700.00
D1B20F	2017-07-05 09:40:00+03	178800.00
D1B2DE	2017-08-06 22:14:00+03	11600.00
D1B330	2017-07-22 12:24:00+03	13400.00
D1B3C9	2017-07-10 18:28:00+03	368500.00
D1B41B	2017-08-09 17:40:00+03	16800.00
D1B48F	2017-07-04 14:11:00+03	45200.00
D1B4C7	2017-08-13 23:40:00+03	86400.00
D1B513	2017-07-17 03:48:00+03	24800.00
D1B56D	2017-07-14 10:21:00+03	23200.00
D1B57F	2017-07-05 13:34:00+03	28000.00
D1B58A	2017-08-05 06:13:00+03	100600.00
D1B5AE	2017-06-26 15:47:00+03	39200.00
D1B5C0	2017-08-07 07:52:00+03	6800.00
D1B5FB	2017-07-22 06:44:00+03	49600.00
D1B650	2017-07-30 18:22:00+03	70400.00
D1B6F5	2017-07-02 06:08:00+03	16400.00
D1B732	2017-08-04 16:43:00+03	12600.00
D1B737	2017-07-09 09:44:00+03	41400.00
D1B790	2017-07-12 07:51:00+03	105500.00
D1B794	2017-08-11 15:59:00+03	110600.00
D1B7CD	2017-07-31 10:03:00+03	40400.00
D1B81C	2017-08-11 08:05:00+03	37000.00
D1B82E	2017-07-22 20:13:00+03	465800.00
D1B83A	2017-07-25 11:01:00+03	14000.00
D1B849	2017-08-06 16:07:00+03	521600.00
D1B936	2017-07-15 08:39:00+03	100600.00
D1B945	2017-08-08 14:15:00+03	133100.00
D1B954	2017-08-11 00:44:00+03	39800.00
D1B9A7	2017-08-11 10:52:00+03	14400.00
D1B9CE	2017-07-18 12:41:00+03	14400.00
D1BA89	2017-07-15 04:38:00+03	57400.00
D1BAD8	2017-08-08 11:28:00+03	18600.00
D1BAF4	2017-07-25 06:21:00+03	109000.00
D1BB06	2017-08-09 10:00:00+03	14400.00
D1BB26	2017-07-17 13:24:00+03	56100.00
D1BB34	2017-07-16 23:18:00+03	114500.00
D1BB49	2017-08-08 06:58:00+03	75600.00
D1BB95	2017-07-07 08:56:00+03	75600.00
D1BBBF	2017-07-11 07:15:00+03	192500.00
D1BC64	2017-07-03 00:27:00+03	16400.00
D1BCFC	2017-07-18 00:41:00+03	29600.00
D1BD41	2017-07-12 19:58:00+03	35200.00
D1BD68	2017-07-20 20:24:00+03	286100.00
D1BDC2	2017-08-11 08:44:00+03	54000.00
D1BDCF	2017-08-03 00:15:00+03	124200.00
D1BE0F	2017-07-09 12:41:00+03	26000.00
D1BEB8	2017-07-04 00:59:00+03	6700.00
D1BEED	2017-08-14 12:12:00+03	135800.00
D1BF07	2017-07-15 17:31:00+03	26400.00
D1BF54	2017-07-13 16:30:00+03	134400.00
D1BFA5	2017-07-21 06:38:00+03	68800.00
D1BFA7	2017-07-18 07:00:00+03	25800.00
D1BFD0	2017-07-24 03:09:00+03	47000.00
D1BFDD	2017-07-06 03:26:00+03	16800.00
D1C037	2017-08-14 08:47:00+03	69400.00
D1C05D	2017-07-28 16:44:00+03	64800.00
D1C0AE	2017-08-04 03:25:00+03	110500.00
D1C0F9	2017-07-19 21:43:00+03	12400.00
D1C111	2017-06-25 18:05:00+03	92800.00
D1C13E	2017-07-19 22:29:00+03	136600.00
D1C145	2017-07-28 16:31:00+03	85400.00
D1C151	2017-08-09 07:28:00+03	60800.00
D1C1D9	2017-08-11 16:09:00+03	28800.00
D1C1E4	2017-07-13 10:25:00+03	78000.00
D1C1F9	2017-07-23 19:16:00+03	54500.00
D1C35A	2017-07-20 14:42:00+03	35200.00
D1C387	2017-07-19 05:36:00+03	24400.00
D1C39D	2017-07-11 22:09:00+03	83700.00
D1C3D1	2017-07-07 15:15:00+03	67600.00
D1C41A	2017-07-04 05:32:00+03	229000.00
D1C42E	2017-07-22 13:10:00+03	19600.00
D1C4CF	2017-07-05 11:24:00+03	13400.00
D1C517	2017-07-20 14:28:00+03	265700.00
D1C53C	2017-07-25 12:07:00+03	114200.00
D1C55D	2017-07-08 17:09:00+03	49800.00
D1C574	2017-08-03 16:44:00+03	40000.00
D1C5D3	2017-08-11 03:36:00+03	23400.00
D1C610	2017-08-13 05:51:00+03	8000.00
D1C658	2017-07-23 13:52:00+03	64000.00
D1C6D2	2017-07-02 08:23:00+03	57400.00
D1C6E1	2017-07-26 03:39:00+03	272400.00
D1C70D	2017-07-28 05:37:00+03	112000.00
D1C73D	2017-08-03 08:08:00+03	30200.00
D1C73E	2017-07-25 04:57:00+03	89800.00
D1C75B	2017-07-25 19:23:00+03	46400.00
D1C786	2017-07-10 20:32:00+03	112600.00
D1C848	2017-07-16 16:39:00+03	154800.00
D1C859	2017-07-17 21:28:00+03	6000.00
D1C8A7	2017-07-14 17:30:00+03	248300.00
D1C93A	2017-07-15 00:01:00+03	170200.00
D1C9B3	2017-07-08 17:00:00+03	54800.00
D1CA57	2017-07-23 14:00:00+03	132800.00
D1CA6D	2017-07-21 19:22:00+03	57700.00
D1CA73	2017-07-30 18:53:00+03	65200.00
D1CA89	2017-07-27 00:51:00+03	49100.00
D1CB10	2017-07-30 07:23:00+03	246000.00
D1CB32	2017-07-28 03:03:00+03	56000.00
D1CB5B	2017-07-07 23:11:00+03	66000.00
D1CBCE	2017-06-29 02:32:00+03	73600.00
D1CBFD	2017-08-12 15:04:00+03	53400.00
D1CC5D	2017-07-07 11:17:00+03	60400.00
D1CCA6	2017-07-20 18:02:00+03	263200.00
D1CD07	2017-08-06 03:18:00+03	15000.00
D1CD18	2017-07-09 03:42:00+03	75300.00
D1CD1E	2017-08-08 10:38:00+03	136500.00
D1CD3C	2017-07-05 00:47:00+03	67900.00
D1CD44	2017-08-14 00:01:00+03	95200.00
D1CD6E	2017-08-13 22:50:00+03	56000.00
D1CDD3	2017-07-29 20:32:00+03	113800.00
D1CDE2	2017-08-14 09:30:00+03	182300.00
D1CDF0	2017-08-10 05:30:00+03	54600.00
D1CE27	2017-07-10 21:34:00+03	77900.00
D1CE2F	2017-07-12 16:04:00+03	243600.00
D1CE4B	2017-08-06 06:09:00+03	31600.00
D1CE5C	2017-07-12 20:03:00+03	41600.00
D1CE91	2017-07-02 23:49:00+03	279000.00
D1CF60	2017-07-21 07:35:00+03	36400.00
D1CF9A	2017-08-11 06:29:00+03	111600.00
D1CFA1	2017-08-13 14:08:00+03	155100.00
D1D056	2017-07-09 00:04:00+03	27800.00
D1D08B	2017-07-29 06:19:00+03	83600.00
D1D08C	2017-07-09 12:34:00+03	135400.00
D1D090	2017-07-08 06:21:00+03	28700.00
D1D102	2017-08-03 16:34:00+03	40000.00
D1D12C	2017-08-09 11:21:00+03	29600.00
D1D1A2	2017-07-11 12:57:00+03	55600.00
D1D1A9	2017-07-09 15:49:00+03	47100.00
D1D1DB	2017-07-02 13:07:00+03	40200.00
D1D24B	2017-06-29 17:05:00+03	112000.00
D1D2B4	2017-08-14 08:04:00+03	80900.00
D1D2B9	2017-06-29 14:42:00+03	50100.00
D1D2F7	2017-07-21 21:22:00+03	81700.00
D1D35A	2017-07-09 06:25:00+03	32800.00
D1D459	2017-07-23 16:30:00+03	75300.00
D1D471	2017-08-11 16:28:00+03	107800.00
D1D49A	2017-07-20 21:09:00+03	122100.00
D1D4A3	2017-07-31 15:55:00+03	66600.00
D1D4BD	2017-07-27 17:54:00+03	62600.00
D1D4FC	2017-07-25 19:42:00+03	14800.00
D1D4FF	2017-06-30 00:49:00+03	75300.00
D1D5CF	2017-07-04 21:21:00+03	22000.00
D1D5FA	2017-08-14 09:59:00+03	36700.00
D1D692	2017-07-27 01:58:00+03	19600.00
D1D706	2017-07-26 13:58:00+03	6600.00
D1D732	2017-08-05 23:29:00+03	184200.00
D1D74C	2017-08-09 13:32:00+03	26000.00
D1D7D4	2017-07-04 12:06:00+03	58400.00
D1D894	2017-08-03 21:09:00+03	53700.00
D1D8AA	2017-08-03 05:18:00+03	76600.00
D1D8C1	2017-08-12 07:17:00+03	20200.00
D1D8E8	2017-07-18 22:48:00+03	39300.00
D1D931	2017-07-09 10:01:00+03	6600.00
D1D93D	2017-07-24 12:35:00+03	8200.00
D1D9DC	2017-07-16 17:27:00+03	76600.00
D1D9F7	2017-07-29 07:08:00+03	59800.00
D1DA2D	2017-08-13 17:18:00+03	81300.00
D1DA2F	2017-07-09 18:41:00+03	26200.00
D1DA38	2017-07-28 21:43:00+03	125800.00
D1DA3E	2017-06-28 15:23:00+03	173900.00
D1DA45	2017-07-24 23:14:00+03	85100.00
D1DA83	2017-07-21 21:46:00+03	90800.00
D1DA91	2017-08-04 23:39:00+03	82900.00
D1DA96	2017-07-30 09:13:00+03	57800.00
D1DAD2	2017-07-24 16:08:00+03	87900.00
D1DAD9	2017-07-26 18:14:00+03	54800.00
D1DAEE	2017-08-13 19:15:00+03	38800.00
D1DB26	2017-07-26 09:01:00+03	260300.00
D1DB29	2017-07-06 12:50:00+03	8400.00
D1DB99	2017-07-12 06:49:00+03	56600.00
D1DBB1	2017-08-08 04:19:00+03	69500.00
D1DBC3	2017-07-22 02:20:00+03	26800.00
D1DC7C	2017-07-31 11:33:00+03	111600.00
D1DD39	2017-08-02 23:15:00+03	39200.00
D1DD9E	2017-07-22 02:48:00+03	29600.00
D1DE8D	2017-08-08 11:38:00+03	65200.00
D1DECC	2017-07-10 11:34:00+03	28800.00
D1DF0C	2017-07-30 08:16:00+03	75300.00
D1DF8A	2017-07-17 08:37:00+03	14400.00
D1DFE7	2017-07-06 22:08:00+03	88800.00
D1E059	2017-07-20 17:41:00+03	159100.00
D1E0CD	2017-08-12 22:23:00+03	166100.00
D1E0DE	2017-08-13 03:33:00+03	36000.00
D1E0E8	2017-07-10 21:28:00+03	20400.00
D1E1C1	2017-07-26 18:29:00+03	15000.00
D1E1E7	2017-08-03 07:06:00+03	60400.00
D1E1FE	2017-07-13 22:54:00+03	22600.00
D1E268	2017-07-01 07:22:00+03	29600.00
D1E31C	2017-07-28 02:20:00+03	38800.00
D1E3B9	2017-07-10 16:24:00+03	16400.00
D1E3D1	2017-08-05 00:42:00+03	111000.00
D1E3FC	2017-07-07 13:39:00+03	41000.00
D1E455	2017-07-19 06:53:00+03	135600.00
D1E5B6	2017-07-12 11:03:00+03	26800.00
D1E5D4	2017-08-14 11:17:00+03	240800.00
D1E630	2017-07-11 16:22:00+03	46400.00
D1E649	2017-08-06 07:41:00+03	59000.00
D1E659	2017-07-09 11:25:00+03	6300.00
D1E66E	2017-08-05 22:39:00+03	398500.00
D1E66F	2017-08-04 15:24:00+03	22000.00
D1E688	2017-08-15 07:45:00+03	25400.00
D1E765	2017-08-09 18:52:00+03	13000.00
D1E76B	2017-07-27 15:26:00+03	136200.00
D1E76C	2017-08-13 08:17:00+03	19800.00
D1E7B1	2017-07-23 22:14:00+03	69500.00
D1E7B2	2017-08-04 12:34:00+03	20200.00
D1E7C4	2017-07-04 22:11:00+03	56600.00
D1E7DC	2017-07-29 20:09:00+03	26700.00
D1E866	2017-07-13 19:51:00+03	110000.00
D1E887	2017-08-13 08:58:00+03	132800.00
D1E88C	2017-06-30 22:05:00+03	28300.00
D1E8A2	2017-07-27 12:17:00+03	73900.00
D1E943	2017-07-25 00:50:00+03	44800.00
D1E94F	2017-07-23 20:12:00+03	11600.00
D1E985	2017-08-10 21:37:00+03	243700.00
D1E9C0	2017-08-09 14:20:00+03	35200.00
D1EA02	2017-07-29 20:51:00+03	67200.00
D1EA19	2017-07-26 13:12:00+03	53300.00
D1EA71	2017-07-04 16:41:00+03	51900.00
D1EA72	2017-08-11 03:30:00+03	51600.00
D1EA79	2017-08-02 10:28:00+03	126300.00
D1EA7A	2017-08-11 12:45:00+03	277800.00
D1EAF3	2017-07-20 00:10:00+03	12400.00
D1EB7D	2017-07-06 00:21:00+03	31400.00
D1EC5E	2017-07-30 09:33:00+03	122100.00
D1ED08	2017-07-05 11:20:00+03	24800.00
D1ED45	2017-08-01 12:20:00+03	59300.00
D1EDA6	2017-07-22 13:11:00+03	199200.00
D1EE2A	2017-08-05 13:26:00+03	113200.00
D1EE87	2017-06-30 18:00:00+03	10800.00
D1EEB1	2017-08-01 00:26:00+03	134400.00
D1EEB4	2017-07-03 06:35:00+03	59800.00
D1EED6	2017-06-30 14:30:00+03	25400.00
D1EF0B	2017-07-15 16:02:00+03	103000.00
D1EF15	2017-08-10 04:59:00+03	46000.00
D1EF3C	2017-07-07 13:49:00+03	164400.00
D1EFCD	2017-07-04 23:44:00+03	6700.00
D1EFD7	2017-07-11 19:03:00+03	30000.00
D1EFF4	2017-07-21 19:37:00+03	15800.00
D1F090	2017-07-05 05:24:00+03	38600.00
D1F093	2017-08-10 21:34:00+03	139300.00
D1F0D3	2017-07-03 00:36:00+03	21800.00
D1F0F6	2017-08-07 04:20:00+03	40800.00
D1F0F9	2017-08-04 00:14:00+03	8000.00
D1F16A	2017-07-13 03:24:00+03	120800.00
D1F225	2017-07-28 03:37:00+03	8000.00
D1F244	2017-08-13 02:26:00+03	28000.00
D1F2C0	2017-07-25 00:53:00+03	14000.00
D1F370	2017-07-29 16:18:00+03	38500.00
D1F38D	2017-07-21 15:41:00+03	44000.00
D1F38F	2017-08-10 22:15:00+03	40600.00
D1F3AD	2017-07-31 12:13:00+03	48500.00
D1F421	2017-07-12 04:44:00+03	12600.00
D1F440	2017-08-15 04:20:00+03	13600.00
D1F442	2017-07-24 05:23:00+03	95200.00
D1F455	2017-08-15 05:45:00+03	42500.00
D1F477	2017-08-14 08:38:00+03	92700.00
D1F4F0	2017-08-07 22:49:00+03	207200.00
D1F4F7	2017-08-05 21:27:00+03	32200.00
D1F535	2017-07-15 14:59:00+03	86400.00
D1F53E	2017-07-10 14:22:00+03	23600.00
D1F540	2017-07-15 22:05:00+03	40800.00
D1F56B	2017-07-19 06:32:00+03	46400.00
D1F578	2017-07-09 18:15:00+03	84000.00
D1F5FA	2017-08-04 10:50:00+03	89200.00
D1F63E	2017-07-14 13:50:00+03	55800.00
D1F648	2017-08-02 03:54:00+03	42400.00
D1F68E	2017-08-03 14:09:00+03	134400.00
D1F693	2017-08-15 15:59:00+03	28800.00
D1F711	2017-07-20 02:31:00+03	25600.00
D1F736	2017-07-21 18:48:00+03	117800.00
D1F74F	2017-08-09 03:22:00+03	25100.00
D1F778	2017-08-01 21:31:00+03	166700.00
D1F8A6	2017-07-17 14:32:00+03	63200.00
D1F8FC	2017-08-03 11:10:00+03	203600.00
D1F902	2017-08-11 00:03:00+03	49100.00
D1F9D1	2017-07-22 02:59:00+03	60800.00
D1F9E5	2017-07-09 18:25:00+03	100600.00
D1F9FC	2017-08-14 03:07:00+03	25900.00
D1FAC5	2017-08-08 10:41:00+03	39600.00
D1FACE	2017-08-05 05:35:00+03	54400.00
D1FB5E	2017-08-04 01:52:00+03	31800.00
D1FB78	2017-08-08 04:55:00+03	85600.00
D1FBC3	2017-06-29 09:35:00+03	68400.00
D1FC07	2017-07-07 08:41:00+03	93700.00
D1FC25	2017-07-24 11:44:00+03	76300.00
D1FC43	2017-07-10 08:48:00+03	67000.00
D1FC57	2017-08-05 06:03:00+03	147700.00
D1FC7D	2017-07-25 02:15:00+03	59300.00
D1FCD5	2017-07-07 19:17:00+03	13000.00
D1FD17	2017-08-09 12:13:00+03	46000.00
D1FD2E	2017-07-09 20:57:00+03	203800.00
D1FD93	2017-07-08 20:04:00+03	73700.00
D1FDA3	2017-08-11 16:04:00+03	66600.00
D1FDC8	2017-08-02 20:02:00+03	56000.00
D1FDEE	2017-08-15 04:51:00+03	13400.00
D1FE45	2017-07-18 23:14:00+03	57600.00
D1FE75	2017-07-21 12:00:00+03	44700.00
D1FF37	2017-07-04 22:44:00+03	284400.00
D1FF74	2017-08-06 04:31:00+03	73400.00
D1FF7F	2017-06-26 18:13:00+03	88500.00
D1FF9B	2017-08-12 03:06:00+03	103600.00
D20063	2017-08-05 10:44:00+03	101500.00
D200A0	2017-07-05 00:22:00+03	131600.00
D200E3	2017-07-07 20:04:00+03	132800.00
D200FF	2017-08-11 14:00:00+03	23600.00
D20122	2017-07-26 18:36:00+03	44800.00
D20159	2017-08-02 03:45:00+03	27600.00
D20160	2017-08-13 16:09:00+03	95200.00
D201CA	2017-07-02 20:53:00+03	210800.00
D20229	2017-07-17 04:06:00+03	81700.00
D20274	2017-07-04 12:01:00+03	30200.00
D20281	2017-08-07 06:31:00+03	47000.00
D20299	2017-08-13 04:21:00+03	103700.00
D202D0	2017-07-27 02:45:00+03	28000.00
D20306	2017-08-11 13:16:00+03	31200.00
D2034C	2017-07-07 13:12:00+03	105400.00
D20355	2017-07-25 22:46:00+03	32700.00
D20374	2017-08-12 01:02:00+03	30100.00
D203CE	2017-07-15 00:43:00+03	49400.00
D20403	2017-07-24 08:34:00+03	30200.00
D204D7	2017-07-24 22:37:00+03	155600.00
D204F9	2017-08-02 19:25:00+03	35600.00
D20521	2017-07-31 21:47:00+03	185900.00
D20555	2017-07-25 18:46:00+03	93500.00
D205C7	2017-07-04 00:28:00+03	133100.00
D2060D	2017-08-14 22:15:00+03	131600.00
D2061B	2017-07-26 13:38:00+03	16800.00
D206AD	2017-08-02 06:33:00+03	132800.00
D206DD	2017-07-15 17:08:00+03	8200.00
D2071E	2017-08-11 08:51:00+03	399600.00
D2074C	2017-07-19 17:21:00+03	28000.00
D207E7	2017-08-01 01:21:00+03	119500.00
D207E8	2017-08-01 23:08:00+03	31000.00
D20823	2017-08-03 13:11:00+03	29600.00
D20854	2017-07-23 19:46:00+03	46000.00
D2086E	2017-08-12 03:24:00+03	45200.00
D2094A	2017-08-15 11:22:00+03	36000.00
D20984	2017-08-06 09:34:00+03	55800.00
D209A9	2017-08-12 20:16:00+03	43600.00
D209E6	2017-07-16 04:20:00+03	169600.00
D20A3F	2017-07-09 19:43:00+03	86600.00
D20A56	2017-08-14 03:47:00+03	117200.00
D20AD3	2017-08-12 07:20:00+03	53600.00
D20B0E	2017-08-15 15:58:00+03	266500.00
D20B1E	2017-07-09 18:31:00+03	14100.00
D20B20	2017-07-20 17:17:00+03	59200.00
D20B3B	2017-07-10 05:38:00+03	38400.00
D20B8D	2017-07-16 04:42:00+03	20200.00
D20C0C	2017-08-10 06:50:00+03	47100.00
D20C6B	2017-08-11 23:53:00+03	187600.00
D20C9E	2017-07-06 20:19:00+03	14400.00
D20CEF	2017-07-12 07:04:00+03	12000.00
D20D18	2017-08-09 15:05:00+03	35600.00
D20D3B	2017-07-03 10:04:00+03	30700.00
D20D65	2017-08-06 10:34:00+03	61800.00
D20E25	2017-07-17 05:37:00+03	25600.00
D20EF0	2017-07-30 00:04:00+03	12600.00
D21059	2017-08-11 11:39:00+03	47200.00
D2105B	2017-07-05 05:21:00+03	132800.00
D2105D	2017-08-10 20:23:00+03	23600.00
D2113F	2017-07-11 20:18:00+03	23200.00
D21141	2017-08-14 17:21:00+03	182300.00
D21167	2017-07-03 16:33:00+03	20200.00
D2116C	2017-07-01 17:36:00+03	252200.00
D21181	2017-07-02 12:45:00+03	67600.00
D21209	2017-08-11 07:06:00+03	126400.00
D21271	2017-07-17 16:25:00+03	61500.00
D21286	2017-08-04 09:58:00+03	32500.00
D212D5	2017-08-13 17:13:00+03	45000.00
D21301	2017-07-19 05:58:00+03	46400.00
D2137E	2017-07-28 10:08:00+03	36200.00
D21395	2017-08-11 23:26:00+03	57400.00
D213A1	2017-07-30 13:48:00+03	134400.00
D213E0	2017-07-23 04:15:00+03	61800.00
D21433	2017-07-27 20:15:00+03	73500.00
D21498	2017-08-07 16:41:00+03	112000.00
D214F9	2017-08-05 00:28:00+03	34200.00
D21523	2017-08-15 06:53:00+03	115100.00
D21567	2017-08-05 21:54:00+03	19600.00
D2158C	2017-07-29 18:43:00+03	112000.00
D215F1	2017-07-20 19:57:00+03	545300.00
D215F2	2017-07-20 04:31:00+03	20200.00
D2165D	2017-08-11 15:40:00+03	156500.00
D216E4	2017-07-17 20:27:00+03	111600.00
D21822	2017-08-14 05:08:00+03	76300.00
D2187E	2017-06-27 04:20:00+03	189800.00
D218F5	2017-07-24 12:37:00+03	26300.00
D21924	2017-07-25 08:25:00+03	62600.00
D21969	2017-08-09 07:30:00+03	199300.00
D21976	2017-08-06 09:13:00+03	58600.00
D219C7	2017-07-30 21:55:00+03	23900.00
D219D6	2017-07-31 19:23:00+03	44000.00
D21A01	2017-07-22 05:13:00+03	297600.00
D21A30	2017-07-28 22:35:00+03	54400.00
D21A67	2017-08-11 21:31:00+03	40400.00
D21A8A	2017-07-06 06:18:00+03	73600.00
D21A8E	2017-07-03 17:02:00+03	70800.00
D21A92	2017-07-26 18:20:00+03	75600.00
D21A9E	2017-07-05 23:27:00+03	7400.00
D21AA4	2017-07-13 20:53:00+03	26000.00
D21ACC	2017-07-04 00:48:00+03	36200.00
D21AE2	2017-08-06 20:38:00+03	23400.00
D21AF3	2017-07-21 14:44:00+03	58000.00
D21AFB	2017-07-28 08:25:00+03	58800.00
D21B4C	2017-08-10 22:19:00+03	29400.00
D21BD1	2017-07-20 11:19:00+03	23200.00
D21C22	2017-07-23 07:39:00+03	15900.00
D21C26	2017-07-14 07:43:00+03	64700.00
D21C2B	2017-07-05 17:33:00+03	32800.00
D21C46	2017-07-09 11:44:00+03	46400.00
D21C77	2017-07-27 19:00:00+03	20100.00
D21CA4	2017-07-29 20:49:00+03	28000.00
D21CB2	2017-07-02 10:35:00+03	34100.00
D21CB7	2017-07-22 04:17:00+03	172400.00
D21D6D	2017-07-09 22:23:00+03	64500.00
D21E00	2017-07-07 13:23:00+03	56800.00
D21E0F	2017-07-12 00:08:00+03	36200.00
D21E79	2017-07-14 22:19:00+03	150100.00
D21EC2	2017-07-23 06:27:00+03	92900.00
D21EE2	2017-08-01 09:58:00+03	24400.00
D21EFB	2017-08-05 04:34:00+03	16400.00
D21F16	2017-07-29 14:21:00+03	67200.00
D21F75	2017-08-02 12:40:00+03	128800.00
D21F87	2017-07-17 21:58:00+03	28800.00
D21FF1	2017-08-12 13:17:00+03	23200.00
D22015	2017-06-30 06:58:00+03	54800.00
D22027	2017-08-01 18:16:00+03	100600.00
D22057	2017-08-08 20:49:00+03	24500.00
D220AE	2017-07-08 09:53:00+03	6300.00
D22110	2017-06-28 03:28:00+03	187800.00
D22118	2017-07-29 19:08:00+03	44000.00
D22121	2017-07-15 15:39:00+03	22000.00
D22139	2017-08-09 18:04:00+03	34100.00
D2216D	2017-08-02 19:56:00+03	47400.00
D22175	2017-07-28 03:53:00+03	88800.00
D22200	2017-07-01 20:16:00+03	20400.00
D2220C	2017-07-22 00:11:00+03	187800.00
D222CD	2017-08-08 17:57:00+03	138600.00
D222DC	2017-07-04 00:48:00+03	46800.00
D22356	2017-08-12 10:48:00+03	43500.00
D2236C	2017-08-15 15:41:00+03	213200.00
D22370	2017-08-01 00:00:00+03	67800.00
D22390	2017-07-18 21:27:00+03	14000.00
D22393	2017-08-08 14:50:00+03	55900.00
D22399	2017-07-07 00:28:00+03	49000.00
D223A7	2017-07-28 19:25:00+03	74900.00
D22463	2017-06-29 19:35:00+03	112000.00
D22552	2017-07-29 16:09:00+03	45200.00
D22557	2017-08-03 08:16:00+03	47200.00
D225A7	2017-08-07 13:53:00+03	57800.00
D225D3	2017-07-05 16:10:00+03	23200.00
D225FA	2017-07-29 19:03:00+03	88600.00
D22600	2017-07-09 17:56:00+03	111600.00
D22606	2017-07-09 18:30:00+03	18800.00
D226D2	2017-08-09 04:27:00+03	40200.00
D226FD	2017-08-14 05:39:00+03	15400.00
D22718	2017-08-07 17:22:00+03	35700.00
D22726	2017-08-11 19:18:00+03	49300.00
D22795	2017-08-07 08:16:00+03	56000.00
D227C0	2017-07-17 07:57:00+03	43600.00
D22860	2017-07-09 08:39:00+03	56000.00
D2287E	2017-07-25 19:46:00+03	42800.00
D228A1	2017-07-23 20:44:00+03	16800.00
D22921	2017-07-06 10:16:00+03	40100.00
D22969	2017-08-02 01:51:00+03	24400.00
D229AF	2017-07-01 05:59:00+03	225800.00
D229B7	2017-07-21 16:20:00+03	101200.00
D229BE	2017-07-13 17:24:00+03	136200.00
D229F9	2017-08-15 15:36:00+03	59300.00
D22A52	2017-07-12 08:16:00+03	22100.00
D22AA3	2017-07-17 09:50:00+03	44000.00
D22B00	2017-07-10 21:02:00+03	43000.00
D22B3A	2017-08-07 06:50:00+03	25000.00
D22B54	2017-08-11 18:36:00+03	135400.00
D22B78	2017-07-06 11:12:00+03	34000.00
D22BDE	2017-07-09 16:45:00+03	38800.00
D22BFE	2017-07-11 07:42:00+03	41200.00
D22BFF	2017-07-15 01:29:00+03	158000.00
D22C04	2017-07-01 12:44:00+03	47400.00
D22C64	2017-07-18 08:54:00+03	46000.00
D22C7E	2017-07-15 18:50:00+03	14400.00
D22CB1	2017-07-17 17:46:00+03	248300.00
D22CCA	2017-08-08 18:50:00+03	80000.00
D22D15	2017-07-08 04:58:00+03	123000.00
D22D82	2017-07-11 10:28:00+03	11600.00
D22E1F	2017-07-26 00:44:00+03	23600.00
D22E67	2017-07-05 16:18:00+03	71200.00
D22E8B	2017-07-27 00:59:00+03	77200.00
D22EFC	2017-07-17 20:40:00+03	26000.00
D22F59	2017-08-06 18:33:00+03	23600.00
D22F88	2017-07-08 17:57:00+03	13000.00
D23048	2017-07-23 16:13:00+03	69600.00
D2310A	2017-08-03 22:29:00+03	174600.00
D23128	2017-07-08 01:12:00+03	73300.00
D23178	2017-07-08 07:55:00+03	166100.00
D231E4	2017-07-22 23:14:00+03	54600.00
D23207	2017-07-25 09:37:00+03	6000.00
D23217	2017-08-10 17:36:00+03	72400.00
D2337D	2017-08-11 22:54:00+03	28000.00
D233F1	2017-08-09 20:47:00+03	77000.00
D23403	2017-08-03 06:04:00+03	59200.00
D23489	2017-08-14 05:29:00+03	44500.00
D23495	2017-08-10 01:47:00+03	76800.00
D23497	2017-08-13 06:07:00+03	31400.00
D234D5	2017-07-05 20:11:00+03	500100.00
D234D6	2017-07-20 06:30:00+03	61800.00
D23568	2017-08-01 03:41:00+03	67400.00
D23575	2017-07-25 00:18:00+03	198400.00
D2358A	2017-07-27 03:25:00+03	40400.00
D235ED	2017-08-06 17:38:00+03	90700.00
D2360E	2017-08-09 16:43:00+03	48800.00
D2365D	2017-07-19 10:18:00+03	66100.00
D236A1	2017-07-12 15:57:00+03	53600.00
D236CE	2017-07-03 13:48:00+03	46000.00
D236E6	2017-08-03 00:34:00+03	42800.00
D23749	2017-07-26 15:39:00+03	50200.00
D2374B	2017-07-06 22:36:00+03	128800.00
D23772	2017-07-16 22:53:00+03	56600.00
D2378D	2017-08-06 08:10:00+03	28800.00
D23897	2017-07-08 08:33:00+03	275100.00
D238B6	2017-07-14 15:59:00+03	89600.00
D238DC	2017-07-03 17:04:00+03	14000.00
D238E5	2017-07-28 06:35:00+03	36400.00
D238F0	2017-07-13 13:25:00+03	88100.00
D2391E	2017-07-30 10:21:00+03	13400.00
D23932	2017-08-08 04:02:00+03	28000.00
D23962	2017-07-29 16:37:00+03	69500.00
D239B3	2017-07-28 19:00:00+03	12600.00
D23A12	2017-08-01 01:18:00+03	23900.00
D23A2B	2017-08-08 00:29:00+03	147600.00
D23A31	2017-08-02 01:03:00+03	272300.00
D23A42	2017-08-05 19:58:00+03	18000.00
D23AE6	2017-08-04 08:17:00+03	112000.00
D23B4E	2017-07-14 07:05:00+03	220200.00
D23B76	2017-07-22 14:44:00+03	265600.00
D23B87	2017-07-30 07:44:00+03	66600.00
D23BA9	2017-07-19 21:11:00+03	136800.00
D23C0F	2017-08-06 07:48:00+03	15000.00
D23CBD	2017-08-15 05:05:00+03	14000.00
D23CFE	2017-07-25 02:51:00+03	92800.00
D23D0B	2017-07-08 21:57:00+03	125400.00
D23DB2	2017-07-30 20:13:00+03	64300.00
D23E32	2017-08-08 04:22:00+03	62700.00
D23E56	2017-07-06 14:08:00+03	91500.00
D23E66	2017-07-11 02:01:00+03	55800.00
D23E85	2017-08-04 23:17:00+03	55800.00
D23E9C	2017-07-26 11:28:00+03	101200.00
D23EB3	2017-08-03 21:14:00+03	133600.00
D23F37	2017-07-24 17:59:00+03	21800.00
D23F82	2017-08-11 00:19:00+03	62100.00
D23F8B	2017-07-06 12:15:00+03	56100.00
D23FC3	2017-07-16 04:54:00+03	110000.00
D23FD9	2017-08-05 20:36:00+03	36200.00
D23FE7	2017-08-10 11:33:00+03	71800.00
D2404F	2017-08-07 08:17:00+03	116700.00
D2412D	2017-07-20 00:31:00+03	28000.00
D241A3	2017-07-09 14:46:00+03	33100.00
D2421B	2017-08-09 11:20:00+03	40800.00
D24258	2017-08-04 10:08:00+03	131600.00
D24278	2017-06-28 05:21:00+03	21400.00
D242AC	2017-08-04 07:57:00+03	46200.00
D242EC	2017-07-11 04:10:00+03	117900.00
D242F4	2017-07-16 12:03:00+03	56000.00
D24301	2017-08-01 10:01:00+03	123000.00
D2435B	2017-07-26 18:04:00+03	39500.00
D2437B	2017-08-03 00:42:00+03	74800.00
D24383	2017-07-11 07:10:00+03	58000.00
D2438D	2017-07-30 07:31:00+03	15000.00
D243E3	2017-08-05 04:43:00+03	23900.00
D243F8	2017-07-20 07:19:00+03	86400.00
D24425	2017-07-04 17:13:00+03	75000.00
D2444F	2017-08-13 05:20:00+03	66600.00
D24484	2017-07-17 17:41:00+03	33600.00
D24498	2017-07-26 10:07:00+03	14000.00
D244B4	2017-07-27 16:48:00+03	77000.00
D244C9	2017-07-03 01:08:00+03	52000.00
D244F4	2017-07-16 08:10:00+03	56000.00
D24501	2017-08-09 14:22:00+03	131100.00
D24505	2017-07-27 21:32:00+03	68100.00
D24562	2017-07-26 12:20:00+03	207000.00
D2458D	2017-08-06 18:29:00+03	68100.00
D24598	2017-08-13 07:03:00+03	26000.00
D245C4	2017-08-11 17:09:00+03	45200.00
D245F8	2017-07-15 07:31:00+03	180000.00
D24601	2017-07-06 06:12:00+03	134400.00
D246C6	2017-07-25 17:31:00+03	270800.00
D24704	2017-07-08 05:13:00+03	85200.00
D24797	2017-08-02 22:14:00+03	308400.00
D247B0	2017-06-29 03:06:00+03	79600.00
D24813	2017-08-11 11:44:00+03	67600.00
D2484D	2017-08-13 14:04:00+03	29400.00
D2486E	2017-07-09 09:56:00+03	140900.00
D248E6	2017-08-07 03:33:00+03	23200.00
D24900	2017-07-03 16:13:00+03	38400.00
D24911	2017-07-16 22:16:00+03	69500.00
D2493B	2017-08-02 06:00:00+03	129200.00
D24967	2017-07-06 22:01:00+03	27800.00
D249A9	2017-07-24 06:41:00+03	21400.00
D249AF	2017-07-13 21:05:00+03	514100.00
D249E4	2017-07-15 09:26:00+03	135400.00
D24A81	2017-07-26 14:59:00+03	22600.00
D24A91	2017-07-19 18:12:00+03	6600.00
D24ADD	2017-07-27 08:35:00+03	61200.00
D24AF3	2017-07-24 13:46:00+03	142900.00
D24B18	2017-07-30 00:33:00+03	7400.00
D24B5C	2017-08-04 06:26:00+03	42800.00
D24B7F	2017-07-30 01:26:00+03	123000.00
D24BCE	2017-08-14 21:45:00+03	168000.00
D24BFF	2017-07-20 21:10:00+03	83200.00
D24CAF	2017-07-29 16:17:00+03	11800.00
D24CF0	2017-07-30 13:15:00+03	68400.00
D24D0D	2017-07-31 01:13:00+03	49600.00
D24D77	2017-07-01 12:15:00+03	23600.00
D24D91	2017-07-10 23:39:00+03	121600.00
D24D9C	2017-07-01 20:29:00+03	112000.00
D24DF2	2017-08-11 14:13:00+03	55800.00
D24E02	2017-08-09 18:39:00+03	78800.00
D24E30	2017-07-08 04:31:00+03	97200.00
D24E4A	2017-07-19 21:53:00+03	28000.00
D24EAB	2017-08-08 11:31:00+03	196800.00
D24EAE	2017-07-12 17:12:00+03	27800.00
D24EC4	2017-07-10 22:02:00+03	16400.00
D24F16	2017-07-13 21:54:00+03	25600.00
D24F63	2017-08-09 20:27:00+03	76600.00
D24F75	2017-08-11 10:24:00+03	43700.00
D24F88	2017-08-07 01:52:00+03	399600.00
D24F96	2017-08-14 12:45:00+03	11800.00
D24FD6	2017-08-11 16:00:00+03	24300.00
D25052	2017-08-14 14:59:00+03	77900.00
D25067	2017-07-12 16:56:00+03	53100.00
D2508D	2017-08-06 20:54:00+03	24800.00
D250FE	2017-07-01 15:55:00+03	29600.00
D251F6	2017-07-05 01:35:00+03	158000.00
D251FB	2017-08-15 17:29:00+03	26200.00
D25287	2017-07-21 02:22:00+03	57400.00
D2528E	2017-07-13 12:31:00+03	30200.00
D252BE	2017-08-15 14:37:00+03	58000.00
D25342	2017-08-10 04:02:00+03	107500.00
D253B3	2017-08-06 22:57:00+03	273600.00
D2545F	2017-07-14 18:10:00+03	28000.00
D25465	2017-07-14 10:14:00+03	75600.00
D2546B	2017-08-07 16:05:00+03	29800.00
D254A5	2017-07-01 01:13:00+03	6000.00
D254DB	2017-07-13 13:42:00+03	84800.00
D25565	2017-07-28 10:32:00+03	65500.00
D2556B	2017-08-03 21:57:00+03	52800.00
D2557E	2017-07-14 16:52:00+03	101200.00
D255BD	2017-08-05 01:51:00+03	73300.00
D255C2	2017-07-03 23:08:00+03	12000.00
D25615	2017-07-05 23:54:00+03	6600.00
D25640	2017-08-02 19:28:00+03	272400.00
D256D4	2017-07-31 01:26:00+03	13800.00
D25744	2017-07-01 01:01:00+03	20400.00
D25764	2017-08-05 04:12:00+03	24000.00
D25794	2017-07-05 01:20:00+03	129200.00
D2582A	2017-07-12 06:07:00+03	117000.00
D2585C	2017-08-02 12:40:00+03	52200.00
D258E2	2017-08-10 23:17:00+03	12000.00
D2592F	2017-07-22 07:04:00+03	53600.00
D259B1	2017-08-14 09:19:00+03	14300.00
D259C7	2017-07-10 17:59:00+03	131800.00
D259D9	2017-07-22 03:04:00+03	62000.00
D25A50	2017-07-20 12:38:00+03	26000.00
D25A62	2017-07-29 03:51:00+03	67600.00
D25A91	2017-07-07 14:56:00+03	59800.00
D25AB5	2017-07-31 00:20:00+03	17000.00
D25ABB	2017-07-10 17:37:00+03	6000.00
D25B3A	2017-08-10 22:03:00+03	74800.00
D25B4A	2017-07-28 01:07:00+03	75600.00
D25BA8	2017-07-04 18:50:00+03	149300.00
D25BB9	2017-08-10 22:02:00+03	102000.00
D25BBC	2017-07-23 16:33:00+03	114900.00
D25C1C	2017-08-03 17:01:00+03	58000.00
D25CD9	2017-06-30 09:08:00+03	33100.00
D25CEA	2017-08-06 12:18:00+03	167400.00
D25D0C	2017-07-29 21:29:00+03	45100.00
D25D22	2017-08-13 06:54:00+03	56000.00
D25D9E	2017-07-05 02:06:00+03	110500.00
D25DAB	2017-08-09 14:05:00+03	38400.00
D25DC3	2017-07-19 07:40:00+03	94900.00
D25E25	2017-07-09 22:11:00+03	50600.00
D25E27	2017-07-07 10:55:00+03	75600.00
D25E83	2017-08-11 20:11:00+03	40600.00
D25F5C	2017-07-16 08:48:00+03	132800.00
D25F89	2017-07-23 20:39:00+03	59800.00
D25FB4	2017-07-26 14:19:00+03	38400.00
D2600E	2017-08-02 11:28:00+03	229300.00
D26045	2017-08-14 16:23:00+03	16400.00
D26065	2017-07-14 23:32:00+03	139800.00
D2606C	2017-07-23 20:35:00+03	12600.00
D26097	2017-08-14 01:54:00+03	28800.00
D2612E	2017-08-03 14:53:00+03	94200.00
D26140	2017-07-05 20:17:00+03	52300.00
D261A2	2017-06-29 09:03:00+03	242600.00
D261A7	2017-07-18 11:01:00+03	47600.00
D2620B	2017-07-29 22:00:00+03	21400.00
D2623B	2017-08-14 09:01:00+03	24200.00
D26247	2017-07-28 13:42:00+03	68800.00
D26256	2017-07-02 19:05:00+03	47000.00
D2625D	2017-08-01 22:11:00+03	99200.00
D26268	2017-08-02 08:41:00+03	98400.00
D26308	2017-07-14 11:35:00+03	28000.00
D26326	2017-07-15 16:16:00+03	26700.00
D263A0	2017-08-15 09:04:00+03	73300.00
D263C1	2017-07-26 17:58:00+03	43600.00
D26423	2017-07-09 13:54:00+03	12600.00
D2643F	2017-07-14 23:01:00+03	7200.00
D26491	2017-07-20 19:45:00+03	48800.00
D264B5	2017-07-17 12:47:00+03	137100.00
D264E9	2017-07-10 09:42:00+03	46400.00
D26549	2017-07-26 10:16:00+03	40800.00
D265C2	2017-08-14 20:41:00+03	88500.00
D26667	2017-07-23 16:01:00+03	88500.00
D26693	2017-07-02 08:53:00+03	44000.00
D266D3	2017-07-18 15:03:00+03	16400.00
D2673D	2017-07-29 19:36:00+03	71000.00
D26765	2017-08-15 03:52:00+03	112600.00
D26787	2017-07-23 23:14:00+03	58000.00
D26795	2017-06-24 07:47:00+03	228800.00
D267B8	2017-08-07 19:32:00+03	62000.00
D2681D	2017-07-21 04:10:00+03	190600.00
D26849	2017-07-30 13:59:00+03	167400.00
D26927	2017-07-12 17:17:00+03	26000.00
D26954	2017-08-10 07:32:00+03	67600.00
D26976	2017-08-03 17:56:00+03	102100.00
D2697B	2017-07-18 01:04:00+03	24400.00
D26A27	2017-07-27 06:19:00+03	67600.00
D26A41	2017-07-24 16:32:00+03	51600.00
D26A67	2017-07-09 17:24:00+03	29400.00
D26AA8	2017-07-08 00:17:00+03	76800.00
D26AF4	2017-07-28 19:07:00+03	208100.00
D26B54	2017-07-21 17:12:00+03	25100.00
D26BCE	2017-07-13 02:44:00+03	46200.00
D26BEA	2017-07-25 23:21:00+03	22000.00
D26C27	2017-08-14 23:09:00+03	56000.00
D26CB4	2017-08-01 23:20:00+03	32800.00
D26CD6	2017-08-13 05:52:00+03	62600.00
D26DAB	2017-07-21 13:28:00+03	31400.00
D26E09	2017-07-23 01:38:00+03	189800.00
D26E89	2017-08-15 10:30:00+03	68300.00
D26E97	2017-08-04 20:20:00+03	66200.00
D26EB6	2017-07-06 17:00:00+03	141600.00
D26EC4	2017-08-14 14:42:00+03	12000.00
D26EDD	2017-07-31 22:56:00+03	46000.00
D26F2A	2017-07-26 10:49:00+03	28800.00
D26F81	2017-07-04 06:19:00+03	41200.00
D26FEE	2017-08-12 20:45:00+03	32400.00
D2701E	2017-08-01 03:50:00+03	47000.00
D27047	2017-07-04 05:02:00+03	115900.00
D27056	2017-08-14 01:48:00+03	369000.00
D2706E	2017-07-26 17:50:00+03	66000.00
D27070	2017-08-03 06:47:00+03	28800.00
D2707D	2017-07-06 22:17:00+03	12000.00
D270CC	2017-07-15 12:19:00+03	28000.00
D27117	2017-08-11 12:57:00+03	59300.00
D2711C	2017-08-03 05:45:00+03	29600.00
D27193	2017-07-07 03:02:00+03	58800.00
D271D6	2017-07-16 19:19:00+03	84000.00
D272E9	2017-08-07 01:01:00+03	19600.00
D273C6	2017-08-11 01:31:00+03	213200.00
D273D5	2017-08-08 04:25:00+03	167400.00
D27418	2017-08-12 04:24:00+03	62000.00
D2742C	2017-07-20 15:17:00+03	258400.00
D27438	2017-07-10 15:21:00+03	73500.00
D2743A	2017-07-06 16:15:00+03	20900.00
D27541	2017-07-18 23:10:00+03	36000.00
D27579	2017-07-09 12:28:00+03	94200.00
D2757B	2017-07-08 01:17:00+03	29200.00
D27599	2017-08-07 01:30:00+03	29600.00
D275E9	2017-07-20 02:08:00+03	47500.00
D2760F	2017-08-03 14:44:00+03	12600.00
D2768B	2017-07-30 18:01:00+03	99300.00
D27783	2017-07-20 00:18:00+03	13400.00
D27797	2017-07-14 05:00:00+03	13400.00
D2779C	2017-07-06 04:24:00+03	22000.00
D2779D	2017-07-16 01:25:00+03	21800.00
D27823	2017-08-04 23:11:00+03	37100.00
D2788A	2017-08-01 16:52:00+03	49100.00
D2789B	2017-07-31 15:36:00+03	70100.00
D278D0	2017-07-21 15:53:00+03	195600.00
D278FF	2017-07-09 07:48:00+03	282000.00
D2792C	2017-07-18 09:24:00+03	17200.00
D2794D	2017-07-14 14:09:00+03	135400.00
D2799A	2017-07-14 05:30:00+03	83700.00
D279C7	2017-07-03 21:24:00+03	15400.00
D279D3	2017-08-05 17:57:00+03	37900.00
D279F6	2017-08-12 22:36:00+03	260900.00
D279FA	2017-07-16 23:06:00+03	134300.00
D27A07	2017-08-01 13:56:00+03	15600.00
D27A7E	2017-08-04 18:01:00+03	47800.00
D27AB8	2017-08-03 12:01:00+03	52800.00
D27ACA	2017-08-15 13:34:00+03	26000.00
D27B3F	2017-07-30 03:28:00+03	81900.00
D27BB3	2017-07-13 23:40:00+03	14400.00
D27C2D	2017-07-13 00:47:00+03	46300.00
D27C42	2017-07-23 18:14:00+03	56000.00
D27C59	2017-08-13 18:34:00+03	61800.00
D27C7D	2017-07-16 20:57:00+03	79800.00
D27E1E	2017-08-14 09:23:00+03	59200.00
D27E44	2017-07-04 23:48:00+03	24300.00
D27E47	2017-07-24 17:54:00+03	138900.00
D27E78	2017-07-07 03:15:00+03	27300.00
D27ED2	2017-07-09 12:06:00+03	147900.00
D27F08	2017-07-09 20:04:00+03	90800.00
D27F7D	2017-08-02 01:09:00+03	85200.00
D27F82	2017-07-08 04:57:00+03	271100.00
D28020	2017-06-27 10:39:00+03	280500.00
D2802B	2017-07-01 23:57:00+03	89600.00
D2805B	2017-07-14 19:24:00+03	92900.00
D280DA	2017-07-23 07:55:00+03	49900.00
D280F0	2017-07-06 13:46:00+03	67600.00
D2816C	2017-07-13 13:52:00+03	23400.00
D281AD	2017-07-03 18:31:00+03	41200.00
D2820C	2017-08-02 17:15:00+03	14400.00
D28229	2017-07-12 23:16:00+03	114300.00
D2828B	2017-07-01 07:02:00+03	25800.00
D282D1	2017-07-31 10:12:00+03	266400.00
D28347	2017-07-23 11:39:00+03	85000.00
D28362	2017-07-13 11:06:00+03	58600.00
D28376	2017-07-28 05:20:00+03	38500.00
D283D8	2017-07-20 06:54:00+03	6800.00
D283DA	2017-07-19 02:45:00+03	13400.00
D283E0	2017-08-10 22:45:00+03	78300.00
D2840F	2017-07-12 07:07:00+03	102100.00
D28461	2017-08-14 12:10:00+03	273000.00
D28469	2017-07-05 20:23:00+03	102200.00
D28534	2017-08-07 01:00:00+03	132800.00
D2856B	2017-07-07 07:57:00+03	28000.00
D285A4	2017-08-12 12:32:00+03	238200.00
D285B8	2017-08-01 00:00:00+03	13100.00
D285CF	2017-06-29 22:40:00+03	28800.00
D285D1	2017-08-03 12:07:00+03	18300.00
D286AA	2017-07-01 16:45:00+03	142300.00
D286CC	2017-07-18 12:48:00+03	137000.00
D28756	2017-07-20 05:18:00+03	65600.00
D287C6	2017-07-15 02:36:00+03	18000.00
D28879	2017-07-06 17:10:00+03	93800.00
D28884	2017-08-14 13:45:00+03	136200.00
D2888F	2017-07-10 13:07:00+03	36200.00
D288D9	2017-08-07 09:34:00+03	209200.00
D28916	2017-07-10 04:37:00+03	24200.00
D28922	2017-07-10 23:52:00+03	167800.00
D28930	2017-08-14 23:54:00+03	88500.00
D28AE7	2017-08-13 11:16:00+03	68100.00
D28AEA	2017-07-10 21:47:00+03	24500.00
D28B00	2017-08-01 05:53:00+03	34000.00
D28B74	2017-07-30 00:40:00+03	56600.00
D28BFE	2017-08-07 03:18:00+03	205400.00
D28C22	2017-07-12 11:44:00+03	14400.00
D28C41	2017-07-31 17:09:00+03	37200.00
D28C7B	2017-07-08 14:45:00+03	498200.00
D28C86	2017-07-13 15:13:00+03	46300.00
D28C8F	2017-07-27 23:34:00+03	28700.00
D28CB4	2017-07-05 18:22:00+03	13600.00
D28D50	2017-07-30 16:01:00+03	12900.00
D28D86	2017-08-07 15:23:00+03	103200.00
D28DBA	2017-08-06 13:21:00+03	92000.00
D28DD2	2017-08-15 08:51:00+03	54800.00
D28DD8	2017-07-07 21:44:00+03	201800.00
D28DEA	2017-07-22 07:02:00+03	40800.00
D28E29	2017-07-21 03:03:00+03	47100.00
D28E3A	2017-07-02 22:05:00+03	24600.00
D28E4D	2017-07-21 09:45:00+03	66600.00
D28E86	2017-08-09 00:40:00+03	65800.00
D28EAD	2017-07-10 22:18:00+03	123000.00
D28EC0	2017-07-23 14:52:00+03	57500.00
D28EC3	2017-08-04 18:47:00+03	36200.00
D28EF3	2017-08-08 03:27:00+03	112000.00
D28F0C	2017-07-08 18:00:00+03	55800.00
D28F0D	2017-08-12 15:37:00+03	27200.00
D28F3B	2017-07-29 14:13:00+03	270400.00
D28F7B	2017-08-05 06:15:00+03	57700.00
D29003	2017-07-30 08:59:00+03	56600.00
D290B4	2017-08-13 00:57:00+03	37900.00
D290DE	2017-07-04 03:40:00+03	28800.00
D290EA	2017-07-21 20:58:00+03	75600.00
D290FC	2017-07-21 17:05:00+03	399400.00
D2913E	2017-07-04 04:30:00+03	34000.00
D2914C	2017-07-01 14:08:00+03	88600.00
D29179	2017-07-04 15:59:00+03	20200.00
D291FB	2017-08-13 15:34:00+03	128900.00
D29236	2017-07-23 02:37:00+03	47000.00
D29240	2017-07-07 11:03:00+03	16400.00
D2925F	2017-08-14 00:34:00+03	143200.00
D292CB	2017-06-27 01:24:00+03	19600.00
D292CC	2017-08-11 04:19:00+03	49600.00
D2936A	2017-07-27 08:08:00+03	26000.00
D293BD	2017-07-26 11:12:00+03	53600.00
D293C7	2017-07-29 08:02:00+03	57400.00
D293D7	2017-07-21 13:05:00+03	89200.00
D2941A	2017-08-15 05:11:00+03	26800.00
D2954B	2017-08-14 08:37:00+03	78300.00
D2955E	2017-07-15 22:03:00+03	133200.00
D2959B	2017-08-08 07:04:00+03	56000.00
D295BC	2017-08-02 21:07:00+03	406700.00
D295E5	2017-07-19 13:01:00+03	153900.00
D2963A	2017-07-20 18:32:00+03	26000.00
D2963E	2017-07-22 09:07:00+03	75600.00
D296EE	2017-07-04 14:03:00+03	19800.00
D296F0	2017-07-28 05:28:00+03	54400.00
D2971F	2017-08-03 11:17:00+03	26000.00
D29722	2017-07-01 07:44:00+03	116900.00
D2981D	2017-07-25 07:00:00+03	11000.00
D29876	2017-07-26 23:02:00+03	31100.00
D298A7	2017-07-15 19:32:00+03	24000.00
D298B5	2017-08-15 12:27:00+03	73200.00
D298F6	2017-07-07 02:14:00+03	39300.00
D29912	2017-08-13 06:27:00+03	69500.00
D29940	2017-07-26 08:11:00+03	139300.00
D29956	2017-07-29 00:10:00+03	31600.00
D2997A	2017-07-04 10:19:00+03	28000.00
D29994	2017-07-20 08:26:00+03	42000.00
D299F3	2017-08-04 14:35:00+03	46400.00
D29A3C	2017-08-06 18:14:00+03	8000.00
D29ABE	2017-08-12 16:46:00+03	6600.00
D29B89	2017-07-20 13:22:00+03	85000.00
D29BAB	2017-08-10 15:31:00+03	160200.00
D29BAC	2017-07-06 15:02:00+03	477500.00
D29BB6	2017-08-15 05:31:00+03	65200.00
D29C7A	2017-07-09 04:58:00+03	64100.00
D29C85	2017-08-02 13:56:00+03	36200.00
D29CDA	2017-07-06 03:10:00+03	8000.00
D29CEA	2017-07-04 01:22:00+03	188000.00
D29D64	2017-08-13 19:33:00+03	43900.00
D29DAF	2017-07-20 11:09:00+03	7400.00
D29E42	2017-07-31 15:18:00+03	38800.00
D29E48	2017-07-17 19:31:00+03	29000.00
D29EA1	2017-07-31 13:13:00+03	31600.00
D29EA9	2017-07-13 23:32:00+03	38600.00
D29EBE	2017-07-08 04:17:00+03	7400.00
D29ED7	2017-07-26 15:46:00+03	23200.00
D29EDD	2017-08-10 11:56:00+03	191000.00
D29F17	2017-07-13 12:26:00+03	6700.00
D29F3F	2017-08-03 08:17:00+03	13600.00
D29FFB	2017-07-29 10:43:00+03	56600.00
D2A0AC	2017-07-30 19:59:00+03	98400.00
D2A0CA	2017-08-01 01:58:00+03	133700.00
D2A10F	2017-07-19 04:27:00+03	19600.00
D2A133	2017-08-15 12:18:00+03	131100.00
D2A13A	2017-07-10 04:47:00+03	16400.00
D2A1C4	2017-08-05 20:46:00+03	78500.00
D2A22D	2017-07-17 19:30:00+03	627000.00
D2A263	2017-07-24 10:25:00+03	92800.00
D2A26D	2017-07-24 07:24:00+03	58200.00
D2A2A3	2017-07-14 04:53:00+03	58200.00
D2A2F9	2017-07-01 18:47:00+03	9300.00
D2A329	2017-07-14 06:27:00+03	87000.00
D2A336	2017-06-30 04:11:00+03	59100.00
D2A360	2017-08-15 09:13:00+03	232200.00
D2A38B	2017-08-02 05:20:00+03	56600.00
D2A3B5	2017-08-10 04:35:00+03	67700.00
D2A3FA	2017-07-19 22:19:00+03	173400.00
D2A445	2017-07-11 11:50:00+03	6700.00
D2A47C	2017-07-17 18:56:00+03	19600.00
D2A49A	2017-08-06 09:21:00+03	57300.00
D2A4B5	2017-07-09 21:43:00+03	60300.00
D2A4C2	2017-08-10 03:02:00+03	24400.00
D2A4DD	2017-07-30 09:21:00+03	40600.00
D2A4FA	2017-07-13 06:24:00+03	28800.00
D2A5A0	2017-07-15 12:12:00+03	49100.00
D2A5B5	2017-08-02 18:58:00+03	26000.00
D2A5EB	2017-07-06 13:07:00+03	28800.00
D2A631	2017-07-30 18:52:00+03	114800.00
D2A66B	2017-06-29 08:27:00+03	32800.00
D2A682	2017-07-05 17:35:00+03	21200.00
D2A6B0	2017-08-05 04:19:00+03	26200.00
D2A6E3	2017-07-17 08:20:00+03	46400.00
D2A710	2017-07-19 07:15:00+03	414700.00
D2A76B	2017-07-15 20:22:00+03	12400.00
D2A799	2017-07-20 15:03:00+03	280000.00
D2A7AE	2017-08-13 20:40:00+03	140800.00
D2A7DC	2017-07-16 21:08:00+03	111000.00
D2A7F6	2017-08-02 09:48:00+03	26000.00
D2A860	2017-08-03 11:00:00+03	80900.00
D2A8E9	2017-08-14 14:38:00+03	144400.00
D2A9AF	2017-08-02 14:54:00+03	19200.00
D2AA1E	2017-07-31 06:36:00+03	55800.00
D2AA39	2017-07-01 20:07:00+03	31600.00
D2AA6D	2017-08-12 19:17:00+03	93900.00
D2AAAF	2017-07-06 06:55:00+03	133200.00
D2AB45	2017-07-30 05:01:00+03	99300.00
D2AB59	2017-07-07 04:08:00+03	179500.00
D2AB6A	2017-07-09 08:39:00+03	116900.00
D2AC19	2017-07-16 12:20:00+03	126600.00
D2AC3B	2017-08-11 13:26:00+03	21400.00
D2ACB3	2017-07-26 08:57:00+03	58800.00
D2AD12	2017-07-19 08:45:00+03	67100.00
D2AD8B	2017-07-30 23:15:00+03	46800.00
D2ADA4	2017-07-18 21:20:00+03	33300.00
D2AEB8	2017-07-06 04:58:00+03	121400.00
D2AFBE	2017-08-12 14:41:00+03	26800.00
D2B016	2017-07-01 21:32:00+03	95600.00
D2B038	2017-08-05 02:29:00+03	12400.00
D2B090	2017-08-08 16:45:00+03	122300.00
D2B0D8	2017-08-12 00:33:00+03	36700.00
D2B0FE	2017-07-08 13:17:00+03	132800.00
D2B101	2017-07-18 07:26:00+03	258400.00
D2B134	2017-07-06 17:16:00+03	41400.00
D2B14E	2017-08-03 19:24:00+03	17000.00
D2B17F	2017-07-06 05:12:00+03	36600.00
D2B1BA	2017-07-08 12:12:00+03	101200.00
D2B1C2	2017-07-18 03:12:00+03	15000.00
D2B1F4	2017-08-07 09:27:00+03	42800.00
D2B21B	2017-08-11 20:44:00+03	211600.00
D2B277	2017-07-12 13:37:00+03	48800.00
D2B282	2017-07-08 09:15:00+03	12600.00
D2B316	2017-07-25 11:45:00+03	74100.00
D2B325	2017-07-17 06:36:00+03	78600.00
D2B32F	2017-08-14 08:32:00+03	143100.00
D2B333	2017-07-31 19:14:00+03	52000.00
D2B380	2017-07-27 12:04:00+03	58200.00
D2B3D6	2017-07-07 02:28:00+03	147200.00
D2B404	2017-07-05 11:34:00+03	8200.00
D2B40F	2017-07-20 14:01:00+03	130300.00
D2B51D	2017-07-13 18:27:00+03	75600.00
D2B51E	2017-07-03 22:27:00+03	260300.00
D2B546	2017-07-20 06:48:00+03	46800.00
D2B5D8	2017-08-08 12:07:00+03	29400.00
D2B62A	2017-07-20 16:16:00+03	28800.00
D2B6E7	2017-08-11 11:29:00+03	55900.00
D2B764	2017-08-10 09:16:00+03	55800.00
D2B7BE	2017-08-04 19:02:00+03	101200.00
D2B804	2017-07-06 17:01:00+03	24800.00
D2B806	2017-07-07 01:51:00+03	25600.00
D2B84D	2017-08-13 17:27:00+03	40200.00
D2B872	2017-07-31 15:57:00+03	241400.00
D2B877	2017-07-31 22:46:00+03	246000.00
D2B89A	2017-07-20 07:45:00+03	134800.00
D2B929	2017-07-05 22:14:00+03	46400.00
D2B94E	2017-08-08 13:25:00+03	260300.00
D2B955	2017-08-07 04:44:00+03	75300.00
D2B9C1	2017-08-01 04:39:00+03	11600.00
D2BA36	2017-08-02 18:11:00+03	72600.00
D2BA5A	2017-07-24 18:52:00+03	56000.00
D2BB72	2017-07-13 15:59:00+03	47100.00
D2BB84	2017-07-09 09:40:00+03	81200.00
D2BB91	2017-08-13 03:19:00+03	29100.00
D2BC7E	2017-07-10 00:18:00+03	22000.00
D2BC90	2017-07-19 09:13:00+03	116100.00
D2BCBF	2017-07-29 17:33:00+03	29600.00
D2BCE5	2017-08-06 20:53:00+03	66400.00
D2BCE8	2017-07-27 12:18:00+03	69600.00
D2BCFB	2017-08-03 17:17:00+03	44400.00
D2BDB5	2017-08-06 02:38:00+03	73300.00
D2BDD1	2017-08-03 01:04:00+03	30200.00
D2BDF0	2017-07-18 09:15:00+03	123000.00
D2BEC7	2017-08-14 14:33:00+03	69100.00
D2BEF7	2017-08-14 09:06:00+03	24600.00
D2BF3B	2017-07-04 12:08:00+03	46400.00
D2BF72	2017-07-23 17:59:00+03	96800.00
D2BFBA	2017-07-31 12:42:00+03	50600.00
D2C052	2017-07-17 01:44:00+03	26800.00
D2C0C8	2017-08-09 06:08:00+03	78100.00
D2C0D5	2017-07-01 15:47:00+03	119500.00
D2C0E6	2017-07-27 03:41:00+03	246000.00
D2C22C	2017-08-12 08:07:00+03	12000.00
D2C28C	2017-07-03 12:02:00+03	57800.00
D2C28D	2017-07-30 17:34:00+03	52000.00
D2C291	2017-08-09 02:47:00+03	354200.00
D2C2CB	2017-08-14 00:20:00+03	32700.00
D2C2E3	2017-07-26 05:05:00+03	57700.00
D2C305	2017-08-05 11:29:00+03	26700.00
D2C339	2017-08-05 21:15:00+03	185600.00
D2C349	2017-08-08 14:49:00+03	70400.00
D2C34B	2017-07-18 10:51:00+03	29600.00
D2C377	2017-07-21 03:29:00+03	28000.00
D2C38D	2017-07-20 12:30:00+03	67600.00
D2C3A4	2017-07-13 03:43:00+03	46400.00
D2C451	2017-07-09 18:55:00+03	139300.00
D2C457	2017-07-04 01:29:00+03	120800.00
D2C47A	2017-07-06 22:52:00+03	151200.00
D2C4A6	2017-06-29 05:28:00+03	248400.00
D2C514	2017-07-22 08:42:00+03	18600.00
D2C53D	2017-07-28 09:02:00+03	393800.00
D2C546	2017-07-14 02:49:00+03	85000.00
D2C569	2017-08-06 07:16:00+03	29400.00
D2C5AE	2017-08-11 21:41:00+03	16400.00
D2C5FC	2017-07-05 21:59:00+03	46400.00
D2C626	2017-07-20 16:34:00+03	133200.00
D2C644	2017-08-10 09:12:00+03	18400.00
D2C6D2	2017-07-09 02:10:00+03	62100.00
D2C6E6	2017-08-12 13:01:00+03	118600.00
D2C704	2017-07-23 16:47:00+03	36000.00
D2C756	2017-08-10 15:50:00+03	21800.00
D2C769	2017-07-29 17:12:00+03	136600.00
D2C772	2017-07-09 14:59:00+03	75600.00
D2C7F4	2017-08-13 15:49:00+03	18000.00
D2C80C	2017-07-16 13:13:00+03	69000.00
D2C897	2017-07-19 19:33:00+03	48700.00
D2C8A5	2017-08-09 12:36:00+03	72400.00
D2C982	2017-07-11 23:27:00+03	381000.00
D2C9D5	2017-07-21 16:42:00+03	163600.00
D2C9EE	2017-07-11 20:49:00+03	28800.00
D2CABE	2017-07-02 18:18:00+03	46000.00
D2CB54	2017-07-03 21:09:00+03	46200.00
D2CB8C	2017-06-27 20:07:00+03	109600.00
D2CBE5	2017-07-27 22:19:00+03	16400.00
D2CBE9	2017-08-08 05:28:00+03	92000.00
D2CBEC	2017-07-23 16:57:00+03	101500.00
D2CBF9	2017-07-01 22:33:00+03	41600.00
D2CC01	2017-07-24 23:02:00+03	38600.00
D2CCB6	2017-07-08 04:13:00+03	22000.00
D2CCC7	2017-07-21 15:38:00+03	168000.00
D2CD04	2017-07-08 09:28:00+03	37600.00
D2CD3D	2017-07-03 14:54:00+03	192400.00
D2CD80	2017-07-09 22:45:00+03	48400.00
D2CE1A	2017-07-03 10:59:00+03	12400.00
D2CE33	2017-08-12 18:30:00+03	26000.00
D2CEBA	2017-08-11 09:59:00+03	21400.00
D2CF31	2017-08-05 05:12:00+03	79300.00
D2CF67	2017-08-01 08:48:00+03	26800.00
D2CFF4	2017-08-14 16:30:00+03	25100.00
D2D000	2017-07-19 11:29:00+03	137600.00
D2D040	2017-07-05 01:45:00+03	36200.00
D2D066	2017-07-11 15:30:00+03	49100.00
D2D0AC	2017-07-24 03:53:00+03	23200.00
D2D0CB	2017-07-17 13:51:00+03	46700.00
D2D0E1	2017-07-18 21:53:00+03	33200.00
D2D151	2017-06-27 23:53:00+03	369000.00
D2D158	2017-07-09 05:27:00+03	55800.00
D2D189	2017-07-15 17:42:00+03	21600.00
D2D1B4	2017-07-24 08:53:00+03	47500.00
D2D1D4	2017-08-06 16:49:00+03	120700.00
D2D1D9	2017-07-30 23:10:00+03	131600.00
D2D1E2	2017-07-04 14:28:00+03	28800.00
D2D21F	2017-07-27 07:36:00+03	40300.00
D2D2C5	2017-07-29 23:52:00+03	46400.00
D2D339	2017-07-13 14:06:00+03	246000.00
D2D4DA	2017-07-04 08:01:00+03	46400.00
D2D4F9	2017-08-05 01:02:00+03	29400.00
D2D51A	2017-08-10 17:58:00+03	53400.00
D2D57B	2017-07-17 07:18:00+03	56000.00
D2D58A	2017-08-13 04:41:00+03	46300.00
D2D591	2017-08-13 14:54:00+03	70700.00
D2D5AC	2017-08-03 21:31:00+03	27000.00
D2D5F9	2017-07-07 09:50:00+03	48700.00
D2D610	2017-07-29 12:19:00+03	28000.00
D2D61B	2017-07-03 23:21:00+03	51800.00
D2D738	2017-07-21 18:48:00+03	84100.00
D2D75C	2017-07-26 02:56:00+03	40600.00
D2D7EE	2017-07-09 22:37:00+03	93400.00
D2D85D	2017-07-22 14:33:00+03	29600.00
D2D872	2017-07-31 05:00:00+03	100600.00
D2D8B5	2017-07-19 13:55:00+03	168000.00
D2D93E	2017-08-04 05:03:00+03	77900.00
D2D96A	2017-07-02 15:03:00+03	6800.00
D2D970	2017-08-13 16:18:00+03	13400.00
D2D9FB	2017-07-03 14:22:00+03	37800.00
D2DA36	2017-07-06 19:04:00+03	88800.00
D2DA3F	2017-07-08 20:43:00+03	38700.00
D2DA6D	2017-08-06 08:09:00+03	37000.00
D2DA9A	2017-08-07 10:41:00+03	64100.00
D2DADC	2017-07-28 22:08:00+03	68200.00
D2DAEF	2017-07-07 02:12:00+03	119600.00
D2DB10	2017-07-03 20:03:00+03	84500.00
D2DB11	2017-07-10 06:33:00+03	147200.00
D2DB1E	2017-08-05 07:12:00+03	28000.00
D2DB30	2017-07-06 23:17:00+03	52600.00
D2DB62	2017-07-24 21:15:00+03	14000.00
D2DB79	2017-08-05 00:01:00+03	91800.00
D2DB97	2017-07-31 23:12:00+03	202900.00
D2DB9F	2017-07-23 18:38:00+03	23900.00
D2DBA0	2017-08-01 02:54:00+03	66600.00
D2DBCF	2017-07-29 08:55:00+03	103500.00
D2DC10	2017-07-31 19:07:00+03	54800.00
D2DC48	2017-07-28 11:50:00+03	99200.00
D2DCAE	2017-07-29 03:23:00+03	189100.00
D2DCBF	2017-07-31 00:45:00+03	175300.00
D2DCD5	2017-08-04 01:26:00+03	67600.00
D2DCE9	2017-07-17 09:02:00+03	61800.00
D2DCFD	2017-07-28 15:14:00+03	53200.00
D2DE5F	2017-07-23 08:48:00+03	112000.00
D2DE8C	2017-07-21 09:56:00+03	28000.00
D2DEF4	2017-07-15 07:07:00+03	48500.00
D2DF1D	2017-08-14 14:58:00+03	45200.00
D2DF46	2017-08-14 13:35:00+03	111600.00
D2DF54	2017-07-23 14:10:00+03	123700.00
D2DF7F	2017-07-10 20:36:00+03	44800.00
D2DF88	2017-08-06 16:56:00+03	111600.00
D2DFCA	2017-06-26 04:17:00+03	73500.00
D2E01D	2017-07-04 07:56:00+03	56000.00
D2E03E	2017-07-14 13:11:00+03	31600.00
D2E047	2017-07-15 17:05:00+03	40800.00
D2E04B	2017-08-01 22:39:00+03	260900.00
D2E0BA	2017-08-01 21:25:00+03	12400.00
D2E105	2017-07-10 15:15:00+03	28800.00
D2E17B	2017-07-16 22:52:00+03	134600.00
D2E1A8	2017-06-30 19:19:00+03	56600.00
D2E1B5	2017-07-13 00:40:00+03	23200.00
D2E227	2017-08-01 15:05:00+03	67200.00
D2E22E	2017-07-19 01:40:00+03	135200.00
D2E27E	2017-07-08 21:24:00+03	19600.00
D2E283	2017-07-04 09:49:00+03	26800.00
D2E28D	2017-07-04 02:41:00+03	123000.00
D2E2CF	2017-07-24 20:19:00+03	26000.00
D2E363	2017-07-17 15:16:00+03	91200.00
D2E385	2017-07-13 23:01:00+03	18000.00
D2E39D	2017-08-15 12:52:00+03	8400.00
D2E3F2	2017-07-10 22:13:00+03	68800.00
D2E3F5	2017-07-10 20:01:00+03	101200.00
D2E3FC	2017-07-24 13:46:00+03	26200.00
D2E422	2017-08-08 17:14:00+03	75300.00
D2E425	2017-07-23 01:39:00+03	306200.00
D2E435	2017-08-01 18:51:00+03	43000.00
D2E4A9	2017-08-11 20:35:00+03	32700.00
D2E4EA	2017-07-15 08:42:00+03	50800.00
D2E575	2017-07-23 08:31:00+03	35200.00
D2E57E	2017-07-02 07:44:00+03	131600.00
D2E5A6	2017-07-18 18:26:00+03	114700.00
D2E6E0	2017-08-10 22:00:00+03	70500.00
D2E6FA	2017-07-11 10:42:00+03	23200.00
D2E724	2017-07-20 19:32:00+03	14700.00
D2E72D	2017-08-06 11:59:00+03	10700.00
D2E7D2	2017-07-23 04:40:00+03	46400.00
D2E7F5	2017-08-03 18:10:00+03	16400.00
D2E811	2017-08-09 05:51:00+03	184300.00
D2E834	2017-08-09 09:35:00+03	40000.00
D2E836	2017-07-13 17:13:00+03	134700.00
D2E8D5	2017-07-16 09:30:00+03	75000.00
D2E8F2	2017-08-04 12:00:00+03	54000.00
D2E92B	2017-07-08 22:17:00+03	47200.00
D2E981	2017-07-30 08:36:00+03	40800.00
D2EA90	2017-08-03 00:47:00+03	113200.00
D2EB67	2017-07-23 02:42:00+03	229800.00
D2EBE8	2017-08-04 02:14:00+03	39500.00
D2EC83	2017-07-06 04:47:00+03	72800.00
D2ECBF	2017-07-13 22:16:00+03	23200.00
D2ED74	2017-07-31 02:54:00+03	66600.00
D2EDBC	2017-07-05 10:26:00+03	48700.00
D2EE4F	2017-08-15 08:14:00+03	155600.00
D2EE5F	2017-07-19 00:53:00+03	26000.00
D2EE60	2017-07-11 00:46:00+03	486800.00
D2EEA4	2017-07-28 03:02:00+03	28800.00
D2EEDD	2017-07-29 08:33:00+03	143100.00
D2EF21	2017-07-20 02:57:00+03	28800.00
D2EF69	2017-08-15 05:41:00+03	126400.00
D2EF8A	2017-07-10 17:42:00+03	58200.00
D2EFDC	2017-08-14 18:01:00+03	36200.00
D2F03E	2017-06-29 21:57:00+03	44000.00
D2F057	2017-07-07 06:28:00+03	129200.00
D2F080	2017-07-08 05:35:00+03	26700.00
D2F0B9	2017-07-02 03:22:00+03	246000.00
D2F0F0	2017-07-23 22:52:00+03	70700.00
D2F11E	2017-07-16 12:45:00+03	32700.00
D2F14F	2017-07-21 09:06:00+03	40000.00
D2F1AD	2017-07-28 02:56:00+03	369000.00
D2F27F	2017-08-04 18:01:00+03	67900.00
D2F2C4	2017-07-02 04:24:00+03	57900.00
D2F2C7	2017-07-25 10:01:00+03	25800.00
D2F343	2017-07-07 00:11:00+03	21800.00
D2F3A1	2017-08-07 18:17:00+03	143300.00
D2F3AC	2017-07-12 16:27:00+03	25000.00
D2F3B1	2017-07-20 05:53:00+03	55800.00
D2F42F	2017-07-14 00:29:00+03	13400.00
D2F443	2017-07-22 13:37:00+03	66000.00
D2F49F	2017-08-04 01:56:00+03	246000.00
D2F4A0	2017-07-20 13:30:00+03	10600.00
D2F4D0	2017-08-14 11:07:00+03	29200.00
D2F4E8	2017-07-27 22:32:00+03	19800.00
D2F559	2017-06-28 20:42:00+03	8200.00
D2F625	2017-07-11 07:15:00+03	23600.00
D2F68B	2017-07-01 18:38:00+03	28800.00
D2F72A	2017-08-09 10:43:00+03	30900.00
D2F740	2017-07-19 14:46:00+03	42800.00
D2F7E2	2017-07-16 23:15:00+03	114200.00
D2F7F2	2017-07-14 19:34:00+03	50200.00
D2F813	2017-07-12 20:28:00+03	71200.00
D2F839	2017-07-13 13:37:00+03	53300.00
D2F866	2017-07-18 11:44:00+03	8200.00
D2F875	2017-07-29 19:33:00+03	151200.00
D2F88D	2017-07-21 00:19:00+03	67600.00
D2F8E8	2017-08-03 02:46:00+03	94800.00
D2F933	2017-08-14 08:29:00+03	34100.00
D2F972	2017-08-05 18:54:00+03	54400.00
D2F988	2017-07-14 16:40:00+03	6000.00
D2F992	2017-07-10 15:09:00+03	24600.00
D2F9D5	2017-07-18 17:16:00+03	55400.00
D2F9DD	2017-07-19 03:59:00+03	23600.00
D2F9E2	2017-08-15 03:49:00+03	61800.00
D2F9FE	2017-07-04 14:08:00+03	37900.00
D2FA00	2017-07-31 16:41:00+03	30200.00
D2FA12	2017-07-30 10:18:00+03	11200.00
D2FA46	2017-08-06 00:01:00+03	43100.00
D2FA9A	2017-07-05 04:53:00+03	89400.00
D2FAD2	2017-07-07 00:04:00+03	56600.00
D2FC3D	2017-07-26 18:07:00+03	39400.00
D2FC41	2017-07-18 10:49:00+03	45100.00
D2FC42	2017-08-07 08:18:00+03	23200.00
D2FD3F	2017-06-29 04:31:00+03	16400.00
D2FDA6	2017-07-31 11:21:00+03	284800.00
D2FDE5	2017-08-09 20:57:00+03	67600.00
D2FE1A	2017-07-31 04:00:00+03	184300.00
D2FE99	2017-07-20 20:32:00+03	378700.00
D2FEDB	2017-07-05 15:01:00+03	26700.00
D2FEEA	2017-08-10 06:47:00+03	39600.00
D2FFC8	2017-08-11 02:37:00+03	85000.00
D2FFD4	2017-07-14 16:02:00+03	39400.00
D2FFEC	2017-07-10 09:25:00+03	28300.00
D30004	2017-07-28 02:40:00+03	14000.00
D3000C	2017-07-07 10:47:00+03	112000.00
D30045	2017-08-10 20:52:00+03	56000.00
D3008F	2017-08-13 08:21:00+03	100600.00
D300A7	2017-07-07 08:43:00+03	246000.00
D300EB	2017-07-07 01:27:00+03	22000.00
D30118	2017-07-12 16:13:00+03	25200.00
D30153	2017-07-31 09:06:00+03	36200.00
D30164	2017-08-10 09:52:00+03	29600.00
D3019E	2017-07-22 10:14:00+03	183300.00
D301DD	2017-08-05 03:16:00+03	259400.00
D301E2	2017-07-16 12:16:00+03	38600.00
D301E4	2017-07-08 02:59:00+03	47800.00
D30263	2017-07-31 04:00:00+03	73600.00
D3028B	2017-08-08 22:10:00+03	84200.00
D30332	2017-07-29 10:12:00+03	92800.00
D30364	2017-07-13 17:48:00+03	28700.00
D30378	2017-08-03 21:48:00+03	137600.00
D3037B	2017-08-08 20:13:00+03	28400.00
D303B3	2017-07-13 07:59:00+03	265700.00
D303C0	2017-08-09 20:52:00+03	13800.00
D30457	2017-08-14 07:51:00+03	26700.00
D304D1	2017-07-02 20:57:00+03	169900.00
D3052D	2017-08-07 10:22:00+03	133900.00
D30586	2017-07-19 14:17:00+03	266400.00
D30588	2017-08-05 03:27:00+03	115300.00
D305E5	2017-07-26 10:23:00+03	37900.00
D305E7	2017-07-28 16:02:00+03	65900.00
D30622	2017-07-31 15:21:00+03	44000.00
D30684	2017-07-06 03:04:00+03	22000.00
D306A1	2017-08-12 20:42:00+03	7400.00
D306AD	2017-07-20 21:07:00+03	55800.00
D30720	2017-07-26 17:10:00+03	191400.00
D3072B	2017-07-06 17:20:00+03	32700.00
D307D0	2017-08-14 04:36:00+03	73900.00
D3081D	2017-07-29 18:59:00+03	50800.00
D308B3	2017-08-03 04:17:00+03	209500.00
D3095C	2017-08-01 17:03:00+03	25800.00
D309CF	2017-08-13 17:35:00+03	65500.00
D309DB	2017-08-05 18:51:00+03	27300.00
D30AC5	2017-07-15 09:28:00+03	84100.00
D30B13	2017-07-31 23:55:00+03	55800.00
D30B25	2017-08-09 04:20:00+03	125200.00
D30B2F	2017-07-22 17:36:00+03	61800.00
D30B57	2017-08-15 17:15:00+03	103900.00
D30BB3	2017-08-13 02:07:00+03	26800.00
D30BC2	2017-08-11 11:54:00+03	81300.00
D30BF9	2017-08-14 05:01:00+03	99600.00
D30C17	2017-07-16 08:43:00+03	103600.00
D30C2D	2017-07-26 15:33:00+03	56000.00
D30C78	2017-08-11 01:13:00+03	207200.00
D30CB1	2017-08-14 00:42:00+03	35300.00
D30CC2	2017-07-17 08:30:00+03	26000.00
D30D18	2017-07-07 20:13:00+03	104000.00
D30D54	2017-07-30 18:06:00+03	258400.00
D30DCD	2017-08-08 19:48:00+03	97800.00
D30DE9	2017-07-09 05:32:00+03	273000.00
D30EA0	2017-07-28 23:19:00+03	11600.00
D30F01	2017-07-04 12:14:00+03	30800.00
D30F07	2017-07-30 01:21:00+03	132800.00
D30F15	2017-07-31 02:24:00+03	23200.00
D30F53	2017-08-13 05:02:00+03	47000.00
D30F84	2017-07-21 07:39:00+03	339900.00
D30FB1	2017-08-03 04:14:00+03	49100.00
D30FC2	2017-07-17 01:03:00+03	34200.00
D30FFE	2017-07-20 23:45:00+03	52500.00
D31010	2017-07-12 21:48:00+03	49100.00
D31044	2017-08-14 16:39:00+03	32400.00
D31078	2017-07-16 07:57:00+03	99200.00
D31087	2017-07-14 11:58:00+03	22000.00
D310CF	2017-07-31 01:05:00+03	60400.00
D3119C	2017-07-25 12:10:00+03	7200.00
D311A3	2017-08-04 06:26:00+03	12600.00
D311F1	2017-07-22 09:11:00+03	135400.00
D312EA	2017-07-09 02:45:00+03	61800.00
D31307	2017-07-04 10:42:00+03	79600.00
D31317	2017-07-27 04:08:00+03	49200.00
D3135C	2017-08-09 01:18:00+03	43400.00
D31370	2017-07-26 09:41:00+03	143700.00
D313B8	2017-08-12 13:56:00+03	71700.00
D313F3	2017-08-07 01:23:00+03	122600.00
D313F6	2017-07-23 00:33:00+03	83400.00
D31411	2017-08-07 11:09:00+03	111600.00
D31438	2017-08-05 20:34:00+03	61400.00
D31483	2017-07-10 05:59:00+03	46300.00
D315FB	2017-07-05 07:02:00+03	540700.00
D3160B	2017-07-16 02:58:00+03	67100.00
D31676	2017-07-09 22:05:00+03	4000.00
D316B6	2017-07-05 08:29:00+03	202200.00
D316F5	2017-06-22 04:39:00+03	41600.00
D31701	2017-07-19 21:06:00+03	147200.00
D317EA	2017-07-01 23:34:00+03	174600.00
D31864	2017-06-29 14:16:00+03	100300.00
D318A2	2017-07-07 05:42:00+03	59800.00
D31916	2017-07-02 07:38:00+03	100600.00
D3192C	2017-07-31 04:13:00+03	100600.00
D3197B	2017-08-01 06:47:00+03	61200.00
D319C5	2017-08-15 12:41:00+03	100800.00
D319CF	2017-07-21 16:26:00+03	106300.00
D319FC	2017-08-11 08:44:00+03	112000.00
D31A02	2017-08-09 15:41:00+03	33600.00
D31A13	2017-07-30 17:37:00+03	102600.00
D31A6A	2017-07-16 18:32:00+03	15000.00
D31AB3	2017-08-05 21:54:00+03	44700.00
D31B01	2017-07-19 02:11:00+03	116000.00
D31B05	2017-07-09 06:13:00+03	148200.00
D31B1D	2017-08-08 15:06:00+03	38400.00
D31B3D	2017-07-14 12:53:00+03	102000.00
D31BD6	2017-08-09 13:40:00+03	68100.00
D31C03	2017-08-05 23:32:00+03	28000.00
D31C57	2017-08-11 01:43:00+03	29600.00
D31CCF	2017-08-09 05:12:00+03	14400.00
D31CF6	2017-08-02 14:28:00+03	26700.00
D31CF9	2017-08-14 05:39:00+03	152700.00
D31D1C	2017-07-18 10:05:00+03	18700.00
D31D80	2017-08-04 20:25:00+03	147500.00
D31D9A	2017-07-27 06:21:00+03	44800.00
D31DD4	2017-06-27 15:49:00+03	48800.00
D31DDF	2017-07-31 01:00:00+03	23200.00
D31E84	2017-07-06 11:23:00+03	201800.00
D31EBA	2017-08-13 16:21:00+03	153800.00
D31ECB	2017-07-26 03:11:00+03	99300.00
D31F48	2017-07-28 19:27:00+03	100200.00
D31F58	2017-07-11 01:04:00+03	37900.00
D3208B	2017-07-23 14:50:00+03	56000.00
D3208C	2017-08-10 21:50:00+03	138600.00
D320AA	2017-08-02 06:17:00+03	260300.00
D32154	2017-07-10 04:46:00+03	66600.00
D32157	2017-07-24 10:25:00+03	34100.00
D32179	2017-08-07 16:56:00+03	12200.00
D3219E	2017-07-20 19:43:00+03	82600.00
D3220E	2017-07-30 16:45:00+03	44500.00
D32278	2017-07-03 17:56:00+03	393700.00
D322EB	2017-07-11 05:15:00+03	148200.00
D32352	2017-07-02 15:56:00+03	61800.00
D32376	2017-07-12 02:05:00+03	18000.00
D32387	2017-07-28 03:51:00+03	73000.00
D32399	2017-08-15 16:29:00+03	86400.00
D323AC	2017-07-03 19:44:00+03	191200.00
D323CE	2017-07-22 03:06:00+03	55800.00
D323FB	2017-08-03 13:36:00+03	20000.00
D32438	2017-07-06 02:12:00+03	14000.00
D324B9	2017-07-31 14:18:00+03	102100.00
D324CC	2017-06-27 17:59:00+03	25600.00
D32517	2017-08-06 13:39:00+03	21800.00
D3251B	2017-07-18 09:53:00+03	32300.00
D32548	2017-07-12 05:25:00+03	11600.00
D3255C	2017-07-16 14:11:00+03	26700.00
D32563	2017-08-02 00:18:00+03	70800.00
D32575	2017-08-15 10:53:00+03	12600.00
D325C1	2017-07-24 20:40:00+03	131600.00
D325C7	2017-07-09 22:41:00+03	65100.00
D325D9	2017-07-04 13:05:00+03	45200.00
D32617	2017-08-09 17:52:00+03	28000.00
D32653	2017-07-28 20:39:00+03	184600.00
D326A2	2017-07-31 06:58:00+03	46000.00
D326CA	2017-07-04 21:58:00+03	22600.00
D326E7	2017-08-10 19:49:00+03	82000.00
D32842	2017-07-26 19:33:00+03	132800.00
D328E1	2017-07-28 22:34:00+03	24400.00
D328E4	2017-07-28 19:19:00+03	15000.00
D32901	2017-07-31 15:40:00+03	46200.00
D32905	2017-08-12 22:10:00+03	89600.00
D32911	2017-07-20 00:00:00+03	12400.00
D32916	2017-07-02 05:11:00+03	64800.00
D3294D	2017-07-10 06:44:00+03	25200.00
D32956	2017-07-10 11:00:00+03	8800.00
D3296C	2017-07-25 23:56:00+03	79900.00
D3297F	2017-07-28 09:15:00+03	26700.00
D3298C	2017-07-20 08:40:00+03	25400.00
D3299A	2017-08-08 04:50:00+03	39600.00
D329C4	2017-08-06 17:16:00+03	266400.00
D329E1	2017-07-24 15:48:00+03	23100.00
D32A23	2017-07-27 05:59:00+03	37200.00
D32A46	2017-07-02 03:09:00+03	83200.00
D32AAF	2017-07-23 13:57:00+03	258400.00
D32B20	2017-08-01 09:47:00+03	56000.00
D32BD9	2017-07-24 03:08:00+03	145600.00
D32C7E	2017-07-24 08:10:00+03	68000.00
D32CB6	2017-08-15 17:21:00+03	27800.00
D32D08	2017-08-08 03:12:00+03	75600.00
D32D70	2017-07-25 15:54:00+03	54500.00
D32E25	2017-07-26 12:14:00+03	189200.00
D32E4B	2017-07-14 19:20:00+03	13200.00
D32E6C	2017-07-29 00:29:00+03	116000.00
D32E7C	2017-08-14 18:43:00+03	155600.00
D32EC6	2017-07-15 04:58:00+03	168000.00
D32ECD	2017-08-06 08:09:00+03	266400.00
D32EEB	2017-07-26 11:45:00+03	56900.00
D32EFD	2017-07-09 10:01:00+03	35200.00
D32F26	2017-08-12 10:45:00+03	18600.00
D32F44	2017-08-09 20:16:00+03	134400.00
D32F49	2017-08-08 19:12:00+03	30200.00
D32FD5	2017-07-25 01:45:00+03	112000.00
D33004	2017-07-19 05:41:00+03	137600.00
D33018	2017-08-01 23:09:00+03	7200.00
D33023	2017-08-08 01:36:00+03	191000.00
D33095	2017-07-18 03:40:00+03	55800.00
D330BD	2017-07-26 10:51:00+03	34000.00
D330CD	2017-07-24 03:29:00+03	111600.00
D33164	2017-07-27 22:58:00+03	24300.00
D3317B	2017-06-30 12:47:00+03	28000.00
D331A2	2017-08-14 10:46:00+03	36700.00
D331E4	2017-08-09 13:15:00+03	10800.00
D33217	2017-07-16 03:54:00+03	22600.00
D3324D	2017-08-12 21:51:00+03	72400.00
D33267	2017-07-27 19:14:00+03	133200.00
D332F6	2017-08-04 03:07:00+03	147800.00
D333AE	2017-08-14 12:20:00+03	62500.00
D333DA	2017-07-28 00:56:00+03	63500.00
D333E2	2017-07-07 20:25:00+03	28000.00
D333E5	2017-08-01 06:02:00+03	257500.00
D3344D	2017-07-03 04:02:00+03	28800.00
D33474	2017-08-10 13:20:00+03	57800.00
D334BA	2017-08-06 08:11:00+03	124200.00
D33527	2017-08-14 23:06:00+03	60400.00
D33530	2017-07-22 01:00:00+03	17200.00
D3355E	2017-07-16 21:10:00+03	43100.00
D33591	2017-08-11 10:47:00+03	62600.00
D335A3	2017-07-30 21:30:00+03	44800.00
D335CA	2017-07-04 04:03:00+03	6700.00
D335D1	2017-07-20 05:41:00+03	246000.00
D335D8	2017-07-12 06:19:00+03	7400.00
D335E9	2017-07-04 08:17:00+03	101200.00
D33661	2017-08-09 08:25:00+03	369000.00
D336AB	2017-08-14 07:28:00+03	68100.00
D336B2	2017-08-07 21:58:00+03	70200.00
D33708	2017-07-17 17:11:00+03	44900.00
D3372F	2017-07-11 21:15:00+03	68700.00
D33759	2017-08-11 03:31:00+03	49000.00
D3379C	2017-07-19 23:01:00+03	130300.00
D3379F	2017-08-09 13:43:00+03	46700.00
D337C3	2017-08-03 23:10:00+03	112000.00
D337E2	2017-07-22 04:50:00+03	57600.00
D3390F	2017-08-01 07:30:00+03	43200.00
D33920	2017-07-10 03:30:00+03	66600.00
D3396C	2017-07-31 12:56:00+03	56000.00
D339D8	2017-07-09 14:28:00+03	288300.00
D339E4	2017-07-11 17:09:00+03	16800.00
D339E9	2017-07-14 21:52:00+03	135400.00
D339FD	2017-07-06 02:10:00+03	39600.00
D33A16	2017-08-01 15:19:00+03	74400.00
D33A25	2017-07-31 00:53:00+03	24700.00
D33B12	2017-07-08 21:26:00+03	25200.00
D33B32	2017-07-03 03:04:00+03	90000.00
D33B95	2017-08-09 09:14:00+03	119600.00
D33B9B	2017-07-06 16:20:00+03	48800.00
D33BA9	2017-07-03 04:47:00+03	10800.00
D33BB5	2017-07-12 19:08:00+03	119700.00
D33C33	2017-07-04 11:35:00+03	26700.00
D33C9E	2017-07-17 18:15:00+03	21400.00
D33CBF	2017-08-07 08:14:00+03	163600.00
D33D0B	2017-07-05 05:25:00+03	60400.00
D33D60	2017-07-04 07:43:00+03	20000.00
D33D89	2017-06-29 22:53:00+03	406700.00
D33DD5	2017-07-25 10:27:00+03	93900.00
D33DD7	2017-08-06 00:27:00+03	28800.00
D33DDC	2017-08-05 18:57:00+03	61800.00
D33DFF	2017-07-08 03:07:00+03	102100.00
D33ED2	2017-07-16 07:42:00+03	26200.00
D33EE2	2017-07-28 06:42:00+03	37900.00
D33F26	2017-06-29 11:08:00+03	39800.00
D33FA8	2017-07-19 07:32:00+03	28700.00
D33FAC	2017-07-30 20:55:00+03	84500.00
D33FB0	2017-07-22 06:01:00+03	43200.00
D33FCB	2017-07-21 23:28:00+03	7300.00
D34115	2017-07-03 03:45:00+03	93900.00
D34134	2017-08-06 21:27:00+03	21800.00
D34156	2017-08-06 23:27:00+03	70600.00
D341D5	2017-08-15 06:12:00+03	36200.00
D34220	2017-07-07 00:19:00+03	111600.00
D3422E	2017-07-05 17:55:00+03	37100.00
D34262	2017-07-18 16:13:00+03	168000.00
D3426F	2017-08-04 12:17:00+03	49000.00
D3428A	2017-08-13 15:28:00+03	54800.00
D342D8	2017-07-01 12:05:00+03	65500.00
D34338	2017-07-17 02:06:00+03	152900.00
D34351	2017-07-24 19:55:00+03	57600.00
D34395	2017-07-10 14:51:00+03	59800.00
D343D6	2017-08-09 07:02:00+03	87100.00
D3440E	2017-08-14 10:44:00+03	22000.00
D34469	2017-07-21 13:03:00+03	36200.00
D344CF	2017-08-12 06:55:00+03	55600.00
D34507	2017-08-03 15:16:00+03	132800.00
D345EC	2017-08-02 20:10:00+03	8000.00
D3461C	2017-08-15 01:20:00+03	53300.00
D34639	2017-08-05 03:32:00+03	19600.00
D34677	2017-08-04 19:22:00+03	97900.00
D3469E	2017-07-22 23:03:00+03	54000.00
D346C5	2017-08-06 11:32:00+03	43600.00
D346CB	2017-07-17 21:17:00+03	16400.00
D34797	2017-07-14 06:16:00+03	23200.00
D347C4	2017-07-14 14:28:00+03	19600.00
D34836	2017-08-11 20:30:00+03	44600.00
D348A2	2017-07-21 22:18:00+03	48800.00
D348C1	2017-08-10 19:07:00+03	46000.00
D348D7	2017-08-10 14:35:00+03	64700.00
D348F0	2017-07-30 12:48:00+03	137600.00
D34A5A	2017-06-30 06:49:00+03	31900.00
D34A61	2017-07-23 13:44:00+03	170600.00
D34AC6	2017-07-09 11:40:00+03	155400.00
D34ADF	2017-06-28 04:25:00+03	99800.00
D34AE0	2017-07-31 12:43:00+03	135600.00
D34AEF	2017-08-05 18:28:00+03	13600.00
D34B3F	2017-07-01 12:07:00+03	27900.00
D34C7F	2017-08-03 08:56:00+03	38600.00
D34CF5	2017-08-05 04:17:00+03	109000.00
D34CFB	2017-08-07 13:31:00+03	54500.00
D34E06	2017-07-13 19:38:00+03	20200.00
D34E53	2017-08-12 10:43:00+03	70900.00
D34E76	2017-08-01 09:26:00+03	398500.00
D34E81	2017-07-29 23:01:00+03	168300.00
D34F17	2017-07-18 05:12:00+03	101800.00
D34F18	2017-07-18 17:34:00+03	35400.00
D34F1E	2017-08-05 23:21:00+03	46400.00
D34F4C	2017-08-09 13:54:00+03	25600.00
D34FD0	2017-08-08 03:50:00+03	53100.00
D35037	2017-08-15 02:36:00+03	26800.00
D3504D	2017-07-18 22:47:00+03	147700.00
D350DE	2017-07-13 08:35:00+03	112000.00
D35163	2017-07-16 02:31:00+03	24800.00
D35168	2017-07-13 18:23:00+03	40600.00
D3518A	2017-07-25 21:58:00+03	12600.00
D35197	2017-07-23 04:06:00+03	14000.00
D35244	2017-08-07 13:29:00+03	36000.00
D35322	2017-07-17 10:37:00+03	257500.00
D35328	2017-07-27 18:38:00+03	36200.00
D3534C	2017-07-21 09:17:00+03	6200.00
D35359	2017-07-07 11:45:00+03	55800.00
D353E2	2017-07-26 19:12:00+03	246000.00
D35405	2017-08-03 15:18:00+03	40400.00
D3540E	2017-07-09 15:12:00+03	39600.00
D35425	2017-08-03 09:33:00+03	67200.00
D3542D	2017-07-26 06:26:00+03	8200.00
D35465	2017-07-04 06:47:00+03	139400.00
D35493	2017-07-28 22:13:00+03	12600.00
D3551F	2017-07-06 16:56:00+03	142800.00
D35523	2017-08-11 15:52:00+03	93700.00
D35535	2017-07-22 04:13:00+03	42800.00
D3554A	2017-07-03 20:04:00+03	36200.00
D35568	2017-07-08 09:59:00+03	66600.00
D35588	2017-07-26 21:40:00+03	40800.00
D35616	2017-07-11 00:44:00+03	57500.00
D35628	2017-07-12 00:00:00+03	52400.00
D3567F	2017-07-01 10:31:00+03	66600.00
D356DB	2017-07-19 15:55:00+03	66600.00
D356EB	2017-07-14 05:24:00+03	29800.00
D356FE	2017-07-23 03:51:00+03	46000.00
D35732	2017-07-24 22:03:00+03	14000.00
D35809	2017-07-05 14:41:00+03	75300.00
D35841	2017-08-06 02:27:00+03	174400.00
D3587F	2017-07-02 02:26:00+03	136400.00
D358DA	2017-08-09 13:06:00+03	74400.00
D3591D	2017-08-09 10:15:00+03	155600.00
D3596E	2017-08-01 08:06:00+03	92000.00
D359A2	2017-07-23 18:00:00+03	17800.00
D35A03	2017-08-08 06:22:00+03	24400.00
D35B0E	2017-08-05 19:21:00+03	28300.00
D35B1A	2017-08-01 12:23:00+03	6000.00
D35BB1	2017-07-26 23:03:00+03	13000.00
D35C13	2017-07-02 20:16:00+03	106200.00
D35C20	2017-08-10 11:03:00+03	111700.00
D35C40	2017-07-20 22:32:00+03	61500.00
D35C55	2017-08-01 19:04:00+03	46000.00
D35D3C	2017-08-04 15:44:00+03	24000.00
D35D55	2017-07-24 06:55:00+03	110300.00
D35D78	2017-08-09 16:37:00+03	54500.00
D35DA3	2017-07-27 22:22:00+03	56000.00
D35DCA	2017-07-24 01:34:00+03	88100.00
D35DD7	2017-08-15 08:20:00+03	10600.00
D35DEF	2017-07-24 04:22:00+03	204500.00
D35E24	2017-07-10 00:50:00+03	15100.00
D35E47	2017-08-10 16:12:00+03	14400.00
D35E58	2017-07-19 09:12:00+03	177600.00
D35E62	2017-08-07 12:26:00+03	75300.00
D35EA6	2017-07-17 22:14:00+03	48800.00
D35EE2	2017-08-04 04:52:00+03	53700.00
D35F24	2017-07-04 10:33:00+03	83600.00
D35F5B	2017-07-22 04:29:00+03	28000.00
D35F8D	2017-07-18 17:46:00+03	14000.00
D35F9F	2017-07-14 09:46:00+03	532700.00
D35FB1	2017-08-01 23:18:00+03	199700.00
D35FD6	2017-08-05 07:36:00+03	37400.00
D35FEF	2017-06-30 23:21:00+03	92800.00
D3603E	2017-07-28 08:12:00+03	21400.00
D36041	2017-07-06 02:16:00+03	62300.00
D360E2	2017-07-19 12:27:00+03	41600.00
D362D7	2017-07-18 04:12:00+03	69900.00
D362F5	2017-08-09 16:33:00+03	52300.00
D36319	2017-07-17 18:30:00+03	100600.00
D36321	2017-08-01 01:26:00+03	45100.00
D3633E	2017-07-27 03:14:00+03	56000.00
D3636A	2017-06-29 01:13:00+03	72600.00
D3644B	2017-07-18 14:55:00+03	289800.00
D364AE	2017-07-31 03:05:00+03	408500.00
D364E3	2017-07-24 12:18:00+03	311200.00
D3650C	2017-08-14 12:14:00+03	55800.00
D365F3	2017-08-05 19:28:00+03	199600.00
D36609	2017-08-14 18:07:00+03	50100.00
D3661A	2017-07-11 18:42:00+03	60800.00
D36638	2017-07-25 11:34:00+03	26000.00
D36649	2017-08-04 05:46:00+03	134400.00
D36686	2017-07-27 14:40:00+03	31600.00
D366A6	2017-07-14 22:48:00+03	12600.00
D366CB	2017-08-07 06:40:00+03	68100.00
D366F4	2017-07-06 05:12:00+03	257500.00
D36702	2017-07-17 21:07:00+03	26200.00
D3671C	2017-08-13 09:26:00+03	144700.00
D36742	2017-08-05 03:02:00+03	155000.00
D36794	2017-08-02 11:12:00+03	111700.00
D3684A	2017-07-03 21:42:00+03	25600.00
D368D1	2017-08-14 18:05:00+03	31000.00
D369C2	2017-07-02 18:53:00+03	46000.00
D369D1	2017-08-05 06:54:00+03	152900.00
D369FD	2017-07-10 16:54:00+03	432500.00
D36A4A	2017-08-02 22:03:00+03	39800.00
D36A5C	2017-07-29 23:30:00+03	28000.00
D36C25	2017-07-23 02:36:00+03	62700.00
D36C3C	2017-07-17 04:56:00+03	26200.00
D36CC1	2017-07-20 09:15:00+03	28000.00
D36D3D	2017-07-27 16:26:00+03	29600.00
D36D4C	2017-08-07 19:38:00+03	8200.00
D36D6D	2017-07-04 07:46:00+03	28800.00
D36DB2	2017-07-11 00:39:00+03	39500.00
D36DD9	2017-07-12 04:07:00+03	28000.00
D36DE6	2017-08-01 04:21:00+03	64800.00
D36E1A	2017-07-20 05:38:00+03	40000.00
D36E79	2017-08-12 10:19:00+03	21600.00
D36EA8	2017-07-30 05:49:00+03	179500.00
D36EF6	2017-07-31 19:17:00+03	8400.00
D36F1C	2017-08-05 22:04:00+03	32200.00
D36F41	2017-06-30 18:52:00+03	133200.00
D36F50	2017-07-26 12:38:00+03	160400.00
D36FA7	2017-07-13 22:04:00+03	273200.00
D37006	2017-07-24 10:56:00+03	56000.00
D37036	2017-07-23 05:08:00+03	30200.00
D370AF	2017-08-05 15:36:00+03	16800.00
D370C6	2017-07-21 15:58:00+03	58800.00
D3716C	2017-07-26 22:08:00+03	39600.00
D37186	2017-07-28 00:23:00+03	69500.00
D371A5	2017-08-08 09:13:00+03	26200.00
D3720F	2017-08-13 16:17:00+03	36200.00
D372AA	2017-07-05 12:41:00+03	66000.00
D372E0	2017-07-04 05:36:00+03	85000.00
D3733B	2017-08-04 04:49:00+03	23600.00
D373AA	2017-07-20 04:20:00+03	136800.00
D373D9	2017-07-09 18:58:00+03	23600.00
D373FD	2017-08-03 17:23:00+03	258300.00
D3746B	2017-07-20 17:13:00+03	37000.00
D37478	2017-08-12 15:01:00+03	127300.00
D37491	2017-08-07 07:31:00+03	187600.00
D374A4	2017-08-08 15:37:00+03	19600.00
D37505	2017-08-10 04:00:00+03	20200.00
D37525	2017-07-13 21:09:00+03	88600.00
D3754C	2017-08-15 13:06:00+03	25100.00
D3757D	2017-07-10 10:09:00+03	131600.00
D375D7	2017-08-11 03:36:00+03	23900.00
D375E5	2017-07-20 15:56:00+03	23600.00
D37611	2017-07-03 02:25:00+03	136300.00
D37630	2017-07-28 04:25:00+03	16400.00
D376BC	2017-07-02 07:30:00+03	115800.00
D37747	2017-07-15 04:00:00+03	12400.00
D377A9	2017-07-13 22:13:00+03	42600.00
D377FE	2017-07-08 21:46:00+03	88100.00
D3783D	2017-08-10 13:04:00+03	6000.00
D378BA	2017-07-05 12:43:00+03	26600.00
D378EA	2017-07-12 21:43:00+03	23600.00
D37903	2017-07-26 11:50:00+03	37900.00
D37904	2017-07-20 10:10:00+03	44600.00
D3796F	2017-07-11 04:45:00+03	292000.00
D379C3	2017-07-08 10:05:00+03	137600.00
D379D6	2017-07-20 18:22:00+03	28800.00
D37A26	2017-07-27 08:06:00+03	16800.00
D37A6F	2017-07-18 03:15:00+03	531300.00
D37A8B	2017-08-10 03:10:00+03	15000.00
D37A9C	2017-08-07 01:15:00+03	69400.00
D37AA6	2017-08-15 14:04:00+03	48900.00
D37AA8	2017-07-27 01:58:00+03	26000.00
D37B29	2017-07-29 12:09:00+03	93600.00
D37B31	2017-07-23 04:17:00+03	65300.00
D37B42	2017-08-09 10:36:00+03	56900.00
D37B47	2017-07-22 17:54:00+03	30900.00
D37BA4	2017-07-17 23:36:00+03	56000.00
D37BCA	2017-08-09 03:23:00+03	105600.00
D37C23	2017-06-30 21:21:00+03	46400.00
D37C3C	2017-07-29 02:20:00+03	99200.00
D37C84	2017-08-14 08:42:00+03	68000.00
D37D25	2017-07-17 07:59:00+03	27200.00
D37D42	2017-07-30 05:27:00+03	42800.00
D37D43	2017-08-14 21:38:00+03	81800.00
D37D62	2017-07-11 00:16:00+03	28000.00
D37D74	2017-07-11 06:46:00+03	34000.00
D37DA9	2017-08-15 15:30:00+03	52000.00
D37DB4	2017-08-01 13:03:00+03	15000.00
D37E70	2017-07-13 20:25:00+03	24400.00
D37E87	2017-07-14 14:09:00+03	133100.00
D37F85	2017-08-03 06:09:00+03	496700.00
D37F92	2017-07-23 15:25:00+03	53300.00
D37FAE	2017-07-09 11:27:00+03	75300.00
D380C5	2017-06-28 15:02:00+03	156500.00
D38105	2017-07-09 04:20:00+03	46000.00
D3815F	2017-07-29 07:01:00+03	25400.00
D38182	2017-08-13 05:08:00+03	34800.00
D381FD	2017-07-10 02:43:00+03	24400.00
D38219	2017-06-29 09:18:00+03	206400.00
D38262	2017-08-13 18:43:00+03	42800.00
D3827B	2017-07-02 23:35:00+03	23600.00
D3830D	2017-08-07 13:19:00+03	11700.00
D3836C	2017-08-12 23:58:00+03	32800.00
D38379	2017-07-12 09:45:00+03	21400.00
D38395	2017-08-15 11:40:00+03	56400.00
D383E2	2017-07-31 14:03:00+03	29800.00
D384B3	2017-08-09 22:32:00+03	114300.00
D385C1	2017-07-09 05:43:00+03	56100.00
D385C4	2017-07-09 06:22:00+03	36800.00
D3861D	2017-07-18 13:50:00+03	180100.00
D38632	2017-07-05 23:46:00+03	71800.00
D38642	2017-07-05 18:24:00+03	297000.00
D3867E	2017-08-13 14:24:00+03	36000.00
D38683	2017-07-16 17:32:00+03	85000.00
D386F8	2017-07-13 11:25:00+03	28000.00
D38761	2017-08-05 23:27:00+03	55600.00
D38763	2017-07-31 09:14:00+03	170800.00
D3876B	2017-07-27 18:30:00+03	25100.00
D3885A	2017-08-06 08:31:00+03	8000.00
D38877	2017-07-16 12:02:00+03	27400.00
D38882	2017-07-20 02:06:00+03	3700.00
D388AD	2017-07-20 23:51:00+03	23900.00
D388C0	2017-07-10 02:16:00+03	56000.00
D38968	2017-08-14 02:31:00+03	133200.00
D3899E	2017-07-04 04:27:00+03	16800.00
D389AF	2017-08-01 13:10:00+03	86400.00
D389DD	2017-08-13 13:29:00+03	66300.00
D389F9	2017-08-01 21:52:00+03	138000.00
D38A3C	2017-07-28 14:57:00+03	312000.00
D38AA8	2017-07-26 02:05:00+03	94000.00
D38AE3	2017-08-05 06:26:00+03	22400.00
D38B85	2017-07-26 17:06:00+03	55000.00
D38B94	2017-07-08 21:50:00+03	9200.00
D38C88	2017-07-10 17:56:00+03	97600.00
D38CB4	2017-07-25 12:14:00+03	37900.00
D38CB8	2017-08-02 23:37:00+03	116500.00
D38CD0	2017-07-01 14:55:00+03	123000.00
D38CE4	2017-07-30 09:46:00+03	31600.00
D38D1A	2017-07-12 00:50:00+03	28000.00
D38D6C	2017-08-13 07:00:00+03	59400.00
D38D9A	2017-07-11 02:07:00+03	229900.00
D38E2A	2017-07-14 07:04:00+03	52900.00
D38E3E	2017-07-12 10:58:00+03	27700.00
D38E40	2017-07-11 09:03:00+03	56600.00
D38E59	2017-07-11 15:46:00+03	48800.00
D38E72	2017-08-04 18:44:00+03	104200.00
D38E8A	2017-07-03 23:08:00+03	57600.00
D38F13	2017-07-07 21:35:00+03	59200.00
D38FAA	2017-07-24 05:23:00+03	77200.00
D39008	2017-08-07 01:57:00+03	85000.00
D39010	2017-07-08 11:47:00+03	99800.00
D390C2	2017-07-20 01:15:00+03	13700.00
D39110	2017-07-27 17:10:00+03	29600.00
D3911C	2017-07-07 23:11:00+03	46700.00
D3913B	2017-07-02 12:15:00+03	64600.00
D3918F	2017-07-21 00:34:00+03	75600.00
D391F0	2017-07-14 05:18:00+03	27900.00
D3920E	2017-07-08 19:00:00+03	23600.00
D39243	2017-07-29 05:16:00+03	15000.00
D392DD	2017-07-25 06:08:00+03	229300.00
D3934C	2017-07-31 14:39:00+03	14400.00
D39447	2017-07-28 18:05:00+03	21400.00
D3944B	2017-08-10 03:44:00+03	92600.00
D3946F	2017-07-22 20:54:00+03	101600.00
D394BC	2017-08-08 11:18:00+03	115900.00
D3951D	2017-08-09 23:40:00+03	38600.00
D39552	2017-07-28 14:44:00+03	34000.00
D3959C	2017-08-03 18:16:00+03	271200.00
D3959D	2017-07-28 06:48:00+03	8200.00
D395CD	2017-08-09 21:01:00+03	69500.00
D39616	2017-07-26 06:42:00+03	23600.00
D39617	2017-08-11 04:33:00+03	85000.00
D3963A	2017-08-03 06:20:00+03	43600.00
D3979A	2017-08-12 20:34:00+03	25100.00
D397A0	2017-07-24 23:36:00+03	117600.00
D397A5	2017-07-02 23:31:00+03	22000.00
D397CB	2017-08-04 04:38:00+03	81700.00
D397CD	2017-07-20 03:57:00+03	69500.00
D39805	2017-07-29 19:44:00+03	8200.00
D398DB	2017-08-01 08:46:00+03	16400.00
D39967	2017-07-16 04:33:00+03	61900.00
D399B3	2017-08-14 11:51:00+03	66600.00
D399C7	2017-08-11 14:43:00+03	40800.00
D399CC	2017-06-30 17:13:00+03	200400.00
D39A2B	2017-08-04 17:49:00+03	28800.00
D39A65	2017-07-14 18:04:00+03	802600.00
D39AFE	2017-08-06 19:23:00+03	84000.00
D39BB7	2017-08-11 22:55:00+03	49800.00
D39BD1	2017-07-20 22:42:00+03	64400.00
D39C20	2017-07-09 09:15:00+03	88600.00
D39C81	2017-08-11 07:45:00+03	116000.00
D39C99	2017-08-12 07:07:00+03	43600.00
D39D39	2017-07-05 17:21:00+03	16400.00
D39D4F	2017-07-18 16:04:00+03	119800.00
D39D8B	2017-07-21 23:52:00+03	56600.00
D39D98	2017-07-24 03:19:00+03	13400.00
D39DA4	2017-07-29 05:35:00+03	14400.00
D39DB9	2017-07-07 02:29:00+03	55800.00
D39DEF	2017-08-09 19:18:00+03	80000.00
D39E00	2017-08-01 06:44:00+03	39600.00
D39E0E	2017-08-07 21:48:00+03	70600.00
D39E94	2017-08-13 06:48:00+03	13000.00
D39ED2	2017-08-10 00:37:00+03	117600.00
D39F5A	2017-07-10 11:29:00+03	114300.00
D39F85	2017-07-26 23:41:00+03	32300.00
D39FCC	2017-08-01 00:57:00+03	187800.00
D39FD7	2017-07-30 08:51:00+03	80000.00
D3A09C	2017-08-14 04:24:00+03	47400.00
D3A0A1	2017-07-01 22:15:00+03	154800.00
D3A0B4	2017-08-06 05:36:00+03	14400.00
D3A0FE	2017-07-14 17:01:00+03	27200.00
D3A144	2017-07-22 20:22:00+03	24000.00
D3A154	2017-07-14 22:40:00+03	85000.00
D3A1B0	2017-07-08 18:38:00+03	43600.00
D3A1EA	2017-07-12 05:53:00+03	25600.00
D3A25A	2017-07-26 20:28:00+03	140500.00
D3A330	2017-07-01 02:48:00+03	20800.00
D3A349	2017-07-27 20:11:00+03	87000.00
D3A38D	2017-07-13 11:28:00+03	93900.00
D3A3FC	2017-08-15 01:46:00+03	50200.00
D3A426	2017-07-03 15:10:00+03	136400.00
D3A438	2017-07-01 07:06:00+03	46400.00
D3A43B	2017-08-02 18:58:00+03	33300.00
D3A470	2017-06-26 08:13:00+03	56000.00
D3A48B	2017-07-10 09:27:00+03	12400.00
D3A51E	2017-08-04 21:06:00+03	13200.00
D3A556	2017-08-07 12:50:00+03	37000.00
D3A596	2017-08-10 14:20:00+03	66600.00
D3A5AB	2017-07-27 22:48:00+03	19600.00
D3A5D3	2017-07-19 17:38:00+03	73300.00
D3A5D4	2017-08-11 12:10:00+03	40100.00
D3A61A	2017-07-30 22:06:00+03	34100.00
D3A67E	2017-07-08 19:03:00+03	23200.00
D3A6D2	2017-08-10 13:47:00+03	28000.00
D3A708	2017-08-15 06:13:00+03	12000.00
D3A740	2017-07-31 13:42:00+03	64300.00
D3A7EE	2017-07-11 18:29:00+03	113200.00
D3A839	2017-08-03 21:46:00+03	252200.00
D3A8BD	2017-07-19 10:41:00+03	39300.00
D3A93D	2017-07-28 22:08:00+03	27600.00
D3A943	2017-07-09 09:12:00+03	113700.00
D3A974	2017-08-08 00:18:00+03	47000.00
D3A9D2	2017-07-06 18:40:00+03	29600.00
D3A9EB	2017-08-11 12:27:00+03	88900.00
D3AAAC	2017-08-11 14:27:00+03	135400.00
D3AAC4	2017-07-19 12:07:00+03	44800.00
D3AADC	2017-08-01 11:58:00+03	81700.00
D3AAEB	2017-08-05 08:28:00+03	25600.00
D3AAF4	2017-07-06 05:43:00+03	30000.00
D3AB4F	2017-07-07 15:35:00+03	26800.00
D3AB7E	2017-08-05 06:20:00+03	6300.00
D3AB89	2017-08-03 07:58:00+03	57400.00
D3ABA4	2017-07-27 22:24:00+03	99600.00
D3ABB3	2017-07-07 03:45:00+03	19500.00
D3ABD3	2017-08-09 01:08:00+03	115700.00
D3AC3D	2017-07-25 02:36:00+03	138000.00
D3AC54	2017-07-20 17:33:00+03	59000.00
D3AC61	2017-07-26 02:30:00+03	50300.00
D3AC63	2017-07-02 18:33:00+03	16400.00
D3AD5D	2017-07-15 23:43:00+03	149200.00
D3AD8B	2017-07-02 15:41:00+03	18800.00
D3AE00	2017-07-26 06:27:00+03	133100.00
D3AE46	2017-07-10 12:42:00+03	149700.00
D3AEA0	2017-07-23 01:39:00+03	42400.00
D3AEAC	2017-08-04 05:40:00+03	39500.00
D3AEC6	2017-08-13 12:35:00+03	94000.00
D3AFB0	2017-06-29 07:44:00+03	270700.00
D3AFD5	2017-08-04 01:33:00+03	28000.00
D3AFE9	2017-07-24 13:02:00+03	47200.00
D3B067	2017-08-15 05:06:00+03	7400.00
D3B088	2017-07-25 06:49:00+03	23400.00
D3B0DC	2017-07-19 15:33:00+03	52300.00
D3B17C	2017-07-03 18:52:00+03	32800.00
D3B195	2017-07-31 03:14:00+03	43100.00
D3B1A0	2017-07-13 23:17:00+03	61800.00
D3B1AE	2017-07-31 00:58:00+03	24200.00
D3B211	2017-07-29 17:39:00+03	135000.00
D3B212	2017-08-12 19:08:00+03	103600.00
D3B218	2017-08-10 11:59:00+03	44000.00
D3B253	2017-06-30 06:07:00+03	51000.00
D3B292	2017-08-15 09:22:00+03	8000.00
D3B2E4	2017-07-21 21:36:00+03	206400.00
D3B336	2017-07-26 21:16:00+03	14000.00
D3B39C	2017-07-20 14:54:00+03	51000.00
D3B3A9	2017-07-26 05:25:00+03	56600.00
D3B3DE	2017-07-03 00:32:00+03	61100.00
D3B3F4	2017-07-04 12:59:00+03	73500.00
D3B426	2017-07-14 20:38:00+03	77900.00
D3B4D7	2017-07-08 04:18:00+03	136000.00
D3B4F1	2017-07-30 06:24:00+03	67200.00
D3B5AA	2017-07-28 14:08:00+03	28800.00
D3B5C0	2017-08-12 17:40:00+03	36200.00
D3B5C2	2017-07-10 22:16:00+03	66600.00
D3B5DE	2017-07-24 10:29:00+03	13600.00
D3B70A	2017-08-14 08:06:00+03	17800.00
D3B70D	2017-07-24 09:15:00+03	57200.00
D3B712	2017-08-14 01:54:00+03	154800.00
D3B725	2017-08-04 22:19:00+03	123000.00
D3B791	2017-07-24 03:05:00+03	38200.00
D3B819	2017-07-01 16:57:00+03	37200.00
D3B84D	2017-08-11 07:31:00+03	63500.00
D3B903	2017-07-22 16:20:00+03	112000.00
D3B914	2017-07-26 09:31:00+03	31400.00
D3B96E	2017-08-05 07:45:00+03	28200.00
D3B97B	2017-07-14 08:52:00+03	130900.00
D3B9A3	2017-08-01 07:56:00+03	66600.00
D3B9C0	2017-07-24 15:58:00+03	21400.00
D3B9C5	2017-08-08 13:35:00+03	289500.00
D3B9EC	2017-07-20 21:47:00+03	67800.00
D3BA3A	2017-08-03 13:30:00+03	33800.00
D3BA48	2017-07-15 15:39:00+03	27300.00
D3BA4D	2017-08-12 17:48:00+03	136200.00
D3BA7E	2017-08-08 03:51:00+03	73100.00
D3BAB5	2017-08-13 00:12:00+03	14400.00
D3BAC7	2017-08-12 01:21:00+03	43000.00
D3BB25	2017-07-03 03:07:00+03	85000.00
D3BB53	2017-08-08 15:26:00+03	14800.00
D3BB5E	2017-07-11 15:07:00+03	13400.00
D3BBA1	2017-08-11 10:22:00+03	68000.00
D3BC11	2017-07-12 04:15:00+03	93800.00
D3BC51	2017-07-09 00:46:00+03	31400.00
D3BC6B	2017-07-30 07:24:00+03	68100.00
D3BCBC	2017-08-06 08:35:00+03	39200.00
D3BD21	2017-07-29 15:46:00+03	47500.00
D3BD31	2017-08-07 21:03:00+03	36000.00
D3BDB1	2017-08-09 09:03:00+03	88400.00
D3BDD8	2017-07-28 13:16:00+03	104200.00
D3BE0B	2017-07-05 12:38:00+03	68400.00
D3BE3B	2017-08-03 17:40:00+03	25000.00
D3BE59	2017-08-10 07:15:00+03	89600.00
D3BF14	2017-07-25 03:06:00+03	47400.00
D3BF98	2017-07-21 15:47:00+03	185300.00
D3BFA1	2017-08-12 08:06:00+03	272400.00
D3BFB1	2017-08-11 12:23:00+03	498500.00
D3BFDE	2017-07-20 15:40:00+03	77000.00
D3BFE9	2017-08-13 07:10:00+03	12600.00
D3C03F	2017-07-21 23:04:00+03	59200.00
D3C046	2017-07-27 21:15:00+03	46000.00
D3C061	2017-07-27 19:07:00+03	34600.00
D3C0E5	2017-07-31 23:36:00+03	25200.00
D3C134	2017-07-10 07:14:00+03	90400.00
D3C157	2017-07-13 11:54:00+03	134400.00
D3C161	2017-07-06 16:04:00+03	32800.00
D3C1A0	2017-07-04 05:27:00+03	198300.00
D3C24C	2017-08-07 09:19:00+03	47200.00
D3C259	2017-08-07 21:48:00+03	78100.00
D3C25A	2017-08-11 04:05:00+03	192400.00
D3C266	2017-07-31 15:09:00+03	279200.00
D3C276	2017-08-13 12:22:00+03	19800.00
D3C2D8	2017-07-29 06:08:00+03	13700.00
D3C2F7	2017-07-08 02:03:00+03	26800.00
D3C349	2017-07-23 05:26:00+03	55800.00
D3C354	2017-07-12 18:09:00+03	58000.00
D3C3AF	2017-07-14 21:50:00+03	252200.00
D3C3BE	2017-07-10 08:05:00+03	19600.00
D3C486	2017-07-09 07:00:00+03	62100.00
D3C499	2017-07-19 11:24:00+03	136800.00
D3C4D2	2017-07-21 12:15:00+03	31900.00
D3C4F6	2017-07-20 14:26:00+03	139500.00
D3C56C	2017-07-19 11:10:00+03	13600.00
D3C582	2017-08-13 12:27:00+03	58800.00
D3C592	2017-08-13 23:37:00+03	37700.00
D3C5D9	2017-07-10 05:03:00+03	76800.00
D3C637	2017-08-09 07:05:00+03	32900.00
D3C677	2017-07-22 12:20:00+03	54000.00
D3C6C9	2017-07-23 21:56:00+03	46300.00
D3C6D6	2017-08-08 05:49:00+03	70700.00
D3C6EA	2017-08-12 05:36:00+03	32700.00
D3C75B	2017-07-24 10:46:00+03	102600.00
D3C7EF	2017-07-18 13:25:00+03	155600.00
D3C80B	2017-07-27 11:53:00+03	121700.00
D3C831	2017-08-14 06:25:00+03	41400.00
D3C889	2017-07-17 02:27:00+03	112600.00
D3C932	2017-07-24 01:14:00+03	12600.00
D3C966	2017-08-13 13:37:00+03	46300.00
D3C972	2017-08-10 23:27:00+03	53600.00
D3C975	2017-07-09 21:26:00+03	62600.00
D3C984	2017-08-13 17:30:00+03	101800.00
D3C989	2017-08-14 06:38:00+03	137600.00
D3C9A2	2017-07-13 13:12:00+03	99200.00
D3C9CC	2017-07-31 05:10:00+03	28000.00
D3C9E5	2017-07-22 09:36:00+03	123000.00
D3CA0C	2017-07-16 14:58:00+03	99700.00
D3CA1C	2017-08-07 20:39:00+03	31600.00
D3CA20	2017-07-16 08:02:00+03	56000.00
D3CAAF	2017-07-25 12:46:00+03	37300.00
D3CADD	2017-07-15 07:44:00+03	23200.00
D3CB60	2017-07-15 15:12:00+03	52300.00
D3CBB8	2017-07-04 00:12:00+03	62700.00
D3CCCF	2017-08-02 04:14:00+03	114700.00
D3CD27	2017-08-02 14:36:00+03	24400.00
D3CDCB	2017-07-10 07:31:00+03	65500.00
D3CDF1	2017-07-04 12:20:00+03	19600.00
D3CE11	2017-07-20 04:09:00+03	58800.00
D3CE2F	2017-08-13 21:17:00+03	294000.00
D3CEA5	2017-07-18 09:58:00+03	56000.00
D3CEDC	2017-08-04 21:19:00+03	136500.00
D3CF3E	2017-08-11 08:09:00+03	92100.00
D3CF98	2017-07-06 13:12:00+03	56400.00
D3CFAC	2017-07-29 07:09:00+03	73600.00
D3CFC6	2017-07-14 01:58:00+03	133200.00
D3D000	2017-08-05 04:20:00+03	40800.00
D3D043	2017-07-12 07:29:00+03	122300.00
D3D044	2017-07-25 08:40:00+03	55800.00
D3D05F	2017-07-28 22:05:00+03	112600.00
D3D084	2017-08-05 23:42:00+03	39800.00
D3D08A	2017-07-27 15:56:00+03	128000.00
D3D0A7	2017-08-01 18:08:00+03	202600.00
D3D102	2017-08-08 14:22:00+03	9300.00
D3D103	2017-08-13 20:29:00+03	214000.00
D3D138	2017-07-12 14:02:00+03	68400.00
D3D17D	2017-08-09 01:55:00+03	133200.00
D3D1DD	2017-07-13 00:57:00+03	50600.00
D3D241	2017-07-25 04:13:00+03	54300.00
D3D256	2017-08-10 15:53:00+03	33100.00
D3D257	2017-07-02 14:55:00+03	58800.00
D3D262	2017-08-02 05:34:00+03	16300.00
D3D285	2017-08-01 02:20:00+03	57800.00
D3D37F	2017-08-10 06:33:00+03	39700.00
D3D3D5	2017-07-19 08:11:00+03	229800.00
D3D3E2	2017-08-08 07:19:00+03	96000.00
D3D422	2017-07-08 22:36:00+03	62000.00
D3D488	2017-08-01 15:07:00+03	40800.00
D3D493	2017-07-13 20:54:00+03	120400.00
D3D4FA	2017-07-27 15:55:00+03	38600.00
D3D55C	2017-07-20 10:50:00+03	38800.00
D3D590	2017-07-12 19:28:00+03	42400.00
D3D598	2017-06-29 18:33:00+03	69600.00
D3D5B1	2017-08-13 17:46:00+03	147200.00
D3D5BC	2017-07-08 08:10:00+03	12000.00
D3D5C2	2017-07-07 19:54:00+03	16400.00
D3D5D6	2017-08-14 03:38:00+03	141600.00
D3D5FD	2017-07-09 08:39:00+03	81300.00
D3D642	2017-07-24 06:22:00+03	46400.00
D3D6A4	2017-08-04 04:31:00+03	124600.00
D3D734	2017-07-23 21:47:00+03	25100.00
D3D767	2017-08-05 08:52:00+03	14400.00
D3D793	2017-07-22 01:33:00+03	47100.00
D3D7CB	2017-07-26 11:34:00+03	43200.00
D3D7FA	2017-07-16 09:27:00+03	46200.00
D3D833	2017-07-04 02:06:00+03	22000.00
D3D837	2017-08-13 20:51:00+03	12600.00
D3D88B	2017-07-10 23:54:00+03	55800.00
D3D8D9	2017-07-02 18:27:00+03	55800.00
D3D902	2017-06-30 10:00:00+03	9000.00
D3D938	2017-08-01 15:48:00+03	30800.00
D3D9B5	2017-08-03 20:22:00+03	285100.00
D3D9EC	2017-07-21 11:24:00+03	13000.00
D3D9F3	2017-08-13 17:30:00+03	28800.00
D3D9FB	2017-07-07 09:07:00+03	76600.00
D3DA49	2017-07-09 22:42:00+03	111600.00
D3DAD7	2017-07-25 00:28:00+03	298600.00
D3DB00	2017-07-19 10:55:00+03	23200.00
D3DB9F	2017-07-24 23:57:00+03	31000.00
D3DBA1	2017-08-06 01:33:00+03	67700.00
D3DBAD	2017-07-11 09:07:00+03	66000.00
D3DBCE	2017-07-26 11:06:00+03	22100.00
D3DC2F	2017-07-28 09:36:00+03	94700.00
D3DC33	2017-08-10 03:37:00+03	26700.00
D3DC6B	2017-07-21 17:28:00+03	36200.00
D3DCA2	2017-07-24 16:08:00+03	75300.00
D3DCEC	2017-08-02 10:31:00+03	26000.00
D3DD00	2017-07-11 12:22:00+03	26400.00
D3DD2F	2017-08-04 12:10:00+03	88300.00
D3DD5D	2017-07-20 14:30:00+03	133200.00
D3DD69	2017-08-01 18:07:00+03	72200.00
D3DDA9	2017-08-04 16:19:00+03	88200.00
D3DE06	2017-06-27 16:13:00+03	12600.00
D3DE9D	2017-07-08 05:49:00+03	108600.00
D3DEF5	2017-08-10 07:35:00+03	13600.00
D3DF0B	2017-07-04 15:55:00+03	90800.00
D3DFB6	2017-08-09 21:26:00+03	156300.00
D3DFC8	2017-07-31 15:59:00+03	46000.00
D3E00B	2017-07-19 03:14:00+03	211800.00
D3E015	2017-07-24 23:17:00+03	51900.00
D3E02D	2017-07-12 23:22:00+03	22400.00
D3E05E	2017-08-04 06:39:00+03	26200.00
D3E085	2017-08-07 17:24:00+03	67600.00
D3E08A	2017-07-03 18:46:00+03	28000.00
D3E096	2017-08-14 01:41:00+03	189700.00
D3E106	2017-08-11 20:38:00+03	213600.00
D3E13F	2017-08-07 15:49:00+03	52000.00
D3E142	2017-08-06 20:55:00+03	21400.00
D3E164	2017-06-29 13:48:00+03	55800.00
D3E18B	2017-07-05 03:32:00+03	15800.00
D3E18F	2017-07-09 14:05:00+03	78800.00
D3E196	2017-07-23 08:34:00+03	147100.00
D3E220	2017-08-11 17:43:00+03	83300.00
D3E255	2017-07-08 18:32:00+03	50300.00
D3E25F	2017-07-22 00:49:00+03	10600.00
D3E2BE	2017-08-15 14:18:00+03	95000.00
D3E2CD	2017-08-04 16:44:00+03	21400.00
D3E2DC	2017-07-20 02:45:00+03	87900.00
D3E362	2017-07-13 11:16:00+03	19600.00
D3E39A	2017-07-14 16:23:00+03	92400.00
D3E3C7	2017-08-01 05:25:00+03	48800.00
D3E450	2017-08-08 12:04:00+03	109800.00
D3E506	2017-08-01 04:42:00+03	30400.00
D3E50A	2017-07-17 22:39:00+03	114800.00
D3E519	2017-08-11 11:52:00+03	6700.00
D3E5AF	2017-08-09 19:26:00+03	477500.00
D3E5D1	2017-07-29 11:52:00+03	64500.00
D3E64D	2017-07-19 03:15:00+03	49400.00
D3E681	2017-07-03 20:30:00+03	139400.00
D3E6ED	2017-07-23 23:04:00+03	67900.00
D3E76E	2017-07-23 09:52:00+03	378400.00
D3E794	2017-07-26 20:09:00+03	13400.00
D3E7B6	2017-07-14 15:37:00+03	177200.00
D3E7C4	2017-07-18 14:10:00+03	23400.00
D3E865	2017-08-03 04:59:00+03	6600.00
D3E8AD	2017-07-30 23:04:00+03	141600.00
D3E92B	2017-08-04 13:46:00+03	75600.00
D3E979	2017-07-18 22:03:00+03	100600.00
D3E9AB	2017-07-16 23:16:00+03	99900.00
D3E9BB	2017-08-13 16:07:00+03	130200.00
D3E9E3	2017-07-22 09:20:00+03	51900.00
D3EA37	2017-07-02 12:10:00+03	55600.00
D3EA50	2017-07-11 11:12:00+03	39300.00
D3EA73	2017-07-05 11:11:00+03	83000.00
D3EADA	2017-07-08 05:27:00+03	76800.00
D3EAEA	2017-07-05 13:39:00+03	56600.00
D3EB8F	2017-08-03 22:01:00+03	67900.00
D3EBB0	2017-08-05 13:59:00+03	13600.00
D3EBE3	2017-07-31 14:53:00+03	222700.00
D3EBE7	2017-07-10 18:41:00+03	67600.00
D3EC35	2017-08-13 10:48:00+03	124100.00
D3EC71	2017-07-02 01:17:00+03	398500.00
D3EC80	2017-08-01 04:48:00+03	59000.00
D3EC92	2017-08-03 02:51:00+03	46200.00
D3ECD6	2017-08-13 11:38:00+03	28000.00
D3ECFD	2017-07-12 20:08:00+03	23600.00
D3ED1B	2017-08-12 07:27:00+03	26000.00
D3ED3A	2017-08-01 23:42:00+03	19800.00
D3ED41	2017-07-15 12:26:00+03	16800.00
D3ED47	2017-07-16 13:47:00+03	12600.00
D3ED4D	2017-07-13 18:14:00+03	432600.00
D3ED55	2017-08-02 01:49:00+03	25600.00
D3EDB3	2017-07-21 22:21:00+03	66600.00
D3EE19	2017-08-12 16:20:00+03	59300.00
D3EE3B	2017-07-13 13:18:00+03	101200.00
D3EE40	2017-08-14 09:24:00+03	18600.00
D3EE54	2017-07-16 04:56:00+03	18600.00
D3EE95	2017-07-20 00:46:00+03	62100.00
D3EE98	2017-08-02 09:31:00+03	56600.00
D3EF8A	2017-07-31 04:01:00+03	272400.00
D3EFAE	2017-07-04 11:26:00+03	80300.00
D3EFCF	2017-08-08 01:32:00+03	21800.00
D3F00E	2017-07-24 12:20:00+03	269400.00
D3F04F	2017-08-08 14:05:00+03	87800.00
D3F06B	2017-07-18 10:16:00+03	93900.00
D3F0A0	2017-08-14 14:56:00+03	146400.00
D3F0C9	2017-07-04 13:20:00+03	66000.00
D3F0E3	2017-08-07 18:25:00+03	40100.00
D3F146	2017-07-23 08:08:00+03	97900.00
D3F17B	2017-07-13 13:57:00+03	26800.00
D3F188	2017-07-01 22:08:00+03	120400.00
D3F18E	2017-07-16 20:35:00+03	24600.00
D3F1EF	2017-07-23 04:22:00+03	234800.00
D3F1FD	2017-08-12 23:44:00+03	23200.00
D3F24C	2017-08-02 00:06:00+03	24000.00
D3F2F3	2017-07-01 05:07:00+03	291600.00
D3F3BC	2017-08-08 13:42:00+03	46400.00
D3F456	2017-07-14 18:04:00+03	55600.00
D3F4B9	2017-07-25 08:00:00+03	92600.00
D3F4F1	2017-07-04 17:44:00+03	87900.00
D3F503	2017-07-15 04:49:00+03	84100.00
D3F53C	2017-07-12 07:07:00+03	88800.00
D3F572	2017-08-09 13:28:00+03	15000.00
D3F5FE	2017-08-11 17:40:00+03	60700.00
D3F61F	2017-07-11 10:56:00+03	90800.00
D3F652	2017-07-23 07:16:00+03	40800.00
D3F6AF	2017-07-05 00:53:00+03	34000.00
D3F724	2017-07-30 03:20:00+03	61800.00
D3F7B4	2017-07-30 05:53:00+03	36200.00
D3F7C9	2017-07-14 18:43:00+03	57300.00
D3F840	2017-07-11 14:43:00+03	234300.00
D3F843	2017-07-04 02:36:00+03	66100.00
D3F8AE	2017-07-01 01:52:00+03	23200.00
D3F8B9	2017-08-13 20:39:00+03	32600.00
D3F8CC	2017-07-08 12:35:00+03	68300.00
D3F92C	2017-07-28 03:14:00+03	22000.00
D3F93D	2017-06-30 20:03:00+03	45200.00
D3F94D	2017-07-06 22:56:00+03	73600.00
D3F988	2017-07-16 06:58:00+03	272600.00
D3F995	2017-07-18 08:57:00+03	372600.00
D3FA09	2017-07-21 03:26:00+03	66600.00
D3FA1A	2017-08-10 21:25:00+03	25000.00
D3FA34	2017-08-12 18:29:00+03	66400.00
D3FA6E	2017-08-11 15:44:00+03	91100.00
D3FAA4	2017-07-17 05:59:00+03	172100.00
D3FAB6	2017-08-14 09:47:00+03	83600.00
D3FADD	2017-08-13 19:13:00+03	112000.00
D3FAE6	2017-07-16 12:14:00+03	131900.00
D3FB1F	2017-07-22 00:52:00+03	171300.00
D3FBA5	2017-07-07 19:16:00+03	136200.00
D3FC0A	2017-08-05 08:12:00+03	56000.00
D3FC2E	2017-07-02 12:21:00+03	21800.00
D3FC37	2017-07-27 16:48:00+03	6300.00
D3FC55	2017-08-02 20:40:00+03	118100.00
D3FC6C	2017-07-31 05:52:00+03	186000.00
D3FC95	2017-07-10 21:27:00+03	19600.00
D3FCA5	2017-07-16 22:39:00+03	102000.00
D3FCD3	2017-08-15 10:55:00+03	111600.00
D3FD35	2017-07-19 21:43:00+03	62800.00
D3FD41	2017-08-04 07:38:00+03	58400.00
D3FD6D	2017-07-31 18:42:00+03	39700.00
D3FD73	2017-08-03 01:38:00+03	318200.00
D3FD7D	2017-07-30 20:55:00+03	11000.00
D3FD8F	2017-07-30 23:55:00+03	111600.00
D3FDD7	2017-08-05 22:03:00+03	68000.00
D3FE8C	2017-07-11 08:19:00+03	61100.00
D3FEF1	2017-07-20 20:52:00+03	69000.00
D3FF33	2017-08-14 17:18:00+03	62400.00
D3FF7D	2017-07-09 05:13:00+03	75600.00
D3FFED	2017-07-31 21:31:00+03	39300.00
D40092	2017-08-13 10:40:00+03	75000.00
D400A2	2017-08-08 18:51:00+03	116400.00
D400B6	2017-07-10 03:10:00+03	85000.00
D400FF	2017-07-26 09:47:00+03	248400.00
D40140	2017-06-30 15:06:00+03	96300.00
D40184	2017-07-12 13:46:00+03	47500.00
D4018F	2017-08-03 20:39:00+03	23400.00
D401B9	2017-07-21 16:19:00+03	71100.00
D40281	2017-06-28 02:42:00+03	108200.00
D402F2	2017-07-03 02:01:00+03	46400.00
D402FC	2017-08-04 14:18:00+03	193600.00
D40303	2017-07-28 14:43:00+03	297000.00
D4031A	2017-07-27 23:22:00+03	117800.00
D4032E	2017-07-17 18:48:00+03	23200.00
D403A7	2017-08-03 15:04:00+03	129200.00
D40409	2017-07-27 03:45:00+03	88600.00
D404A6	2017-06-29 05:33:00+03	134400.00
D404B7	2017-07-16 05:02:00+03	109600.00
D404CE	2017-07-04 06:50:00+03	199700.00
D40502	2017-07-17 07:15:00+03	135400.00
D4050B	2017-08-02 07:36:00+03	45000.00
D4051E	2017-07-01 14:08:00+03	30800.00
D40531	2017-08-11 08:17:00+03	73600.00
D405B7	2017-08-09 01:40:00+03	270200.00
D405C2	2017-08-02 11:49:00+03	28800.00
D405D2	2017-07-18 13:23:00+03	21800.00
D4064A	2017-08-05 04:19:00+03	85400.00
D40655	2017-07-03 03:11:00+03	19600.00
D4065A	2017-08-06 01:55:00+03	65900.00
D406C1	2017-07-20 17:40:00+03	65500.00
D406CF	2017-07-26 17:07:00+03	135400.00
D40755	2017-08-01 17:29:00+03	53700.00
D407F8	2017-07-29 23:14:00+03	87200.00
D40802	2017-07-01 15:54:00+03	24000.00
D4087B	2017-07-31 09:05:00+03	55800.00
D4087E	2017-08-13 20:38:00+03	73900.00
D4088E	2017-07-26 08:24:00+03	26000.00
D408FD	2017-07-21 00:45:00+03	11300.00
D40911	2017-07-07 10:18:00+03	75600.00
D40955	2017-07-03 02:02:00+03	19800.00
D40969	2017-07-17 14:45:00+03	369000.00
D40973	2017-07-19 14:25:00+03	111600.00
D4098E	2017-07-13 11:27:00+03	14800.00
D40A28	2017-08-12 04:19:00+03	79600.00
D40A32	2017-07-06 19:45:00+03	28000.00
D40A79	2017-07-10 03:48:00+03	24800.00
D40A96	2017-08-12 17:52:00+03	133200.00
D40ABB	2017-07-22 11:04:00+03	53800.00
D40AE0	2017-07-02 09:32:00+03	14000.00
D40B23	2017-07-25 12:43:00+03	77600.00
D40B24	2017-07-31 04:30:00+03	92800.00
D40B52	2017-08-13 08:43:00+03	189200.00
D40B8A	2017-07-22 14:38:00+03	59300.00
D40BC4	2017-07-08 15:19:00+03	14000.00
D40C38	2017-07-13 20:37:00+03	56000.00
D40C60	2017-08-15 17:15:00+03	16400.00
D40D10	2017-08-12 06:26:00+03	229800.00
D40D40	2017-08-07 01:42:00+03	8200.00
D40D53	2017-06-28 19:59:00+03	56000.00
D40E2E	2017-07-05 07:20:00+03	48800.00
D40F58	2017-08-14 20:03:00+03	92100.00
D40F65	2017-07-09 01:16:00+03	28000.00
D40FD0	2017-07-17 11:35:00+03	135400.00
D41108	2017-07-16 19:33:00+03	56600.00
D41111	2017-07-16 13:08:00+03	57300.00
D41178	2017-07-26 12:26:00+03	62200.00
D411D3	2017-08-09 19:52:00+03	28000.00
D41225	2017-08-05 01:16:00+03	248400.00
D41252	2017-07-04 21:48:00+03	64200.00
D41255	2017-07-31 11:24:00+03	135200.00
D4126C	2017-07-11 21:11:00+03	12000.00
D41296	2017-07-24 08:09:00+03	67800.00
D41379	2017-07-27 00:11:00+03	19800.00
D41394	2017-07-29 11:41:00+03	26700.00
D413DA	2017-08-08 16:42:00+03	28700.00
D413F3	2017-07-05 15:17:00+03	68000.00
D414B7	2017-07-22 00:12:00+03	77700.00
D414D0	2017-08-09 20:08:00+03	88600.00
D4152D	2017-07-12 20:30:00+03	61800.00
D41537	2017-08-01 06:48:00+03	39200.00
D41563	2017-07-24 13:59:00+03	138100.00
D415D5	2017-08-03 14:50:00+03	20400.00
D415D7	2017-07-10 18:58:00+03	6000.00
D41621	2017-07-10 08:17:00+03	28000.00
D41628	2017-07-21 18:36:00+03	56600.00
D4162F	2017-06-30 16:30:00+03	60400.00
D416AE	2017-06-28 18:49:00+03	34600.00
D416C3	2017-07-06 08:13:00+03	20900.00
D416D4	2017-07-14 16:23:00+03	32700.00
D416E4	2017-07-12 09:50:00+03	50600.00
D416ED	2017-07-10 01:10:00+03	381400.00
D416F0	2017-07-12 04:12:00+03	58000.00
D416F1	2017-08-08 23:29:00+03	57400.00
D416FB	2017-07-04 15:20:00+03	41200.00
D4173F	2017-08-10 04:02:00+03	112000.00
D41776	2017-08-01 05:25:00+03	89100.00
D41796	2017-07-13 11:46:00+03	369000.00
D41798	2017-08-07 23:11:00+03	143400.00
D417A0	2017-07-11 11:26:00+03	89400.00
D417A3	2017-07-10 00:50:00+03	36100.00
D417F5	2017-07-17 05:03:00+03	92600.00
D41835	2017-07-13 01:40:00+03	297600.00
D41882	2017-07-08 06:59:00+03	179200.00
D4189F	2017-07-03 22:03:00+03	124300.00
D418D8	2017-07-21 00:41:00+03	164600.00
D418E0	2017-08-13 21:21:00+03	166100.00
D419C3	2017-07-09 00:54:00+03	89100.00
D419C5	2017-07-23 07:18:00+03	72200.00
D419D3	2017-07-14 10:06:00+03	55800.00
D419F3	2017-08-06 16:50:00+03	57400.00
D419F7	2017-08-14 21:53:00+03	31200.00
D41A63	2017-07-28 10:48:00+03	100600.00
D41ABB	2017-08-15 17:22:00+03	117100.00
D41AE3	2017-07-22 14:29:00+03	124200.00
D41B23	2017-07-30 06:59:00+03	125400.00
D41B27	2017-07-15 03:31:00+03	118100.00
D41B28	2017-07-05 17:46:00+03	6700.00
D41B8F	2017-07-11 07:03:00+03	38600.00
D41BBB	2017-07-31 20:58:00+03	28800.00
D41BED	2017-07-22 15:05:00+03	75700.00
D41C1C	2017-07-25 23:55:00+03	54800.00
D41C9B	2017-08-04 05:08:00+03	87400.00
D41CEE	2017-07-28 23:29:00+03	55800.00
D41D65	2017-07-28 06:33:00+03	57500.00
D41E61	2017-08-08 03:56:00+03	56000.00
D41E68	2017-07-29 16:46:00+03	101200.00
D41ED1	2017-07-01 21:21:00+03	40200.00
D41F0B	2017-08-11 03:43:00+03	28000.00
D41F16	2017-07-08 21:48:00+03	46400.00
D41F30	2017-08-04 17:36:00+03	57400.00
D41F88	2017-07-09 21:37:00+03	27200.00
D41FC9	2017-07-15 20:57:00+03	167400.00
D42050	2017-07-11 10:58:00+03	23600.00
D4206D	2017-07-18 16:42:00+03	139400.00
D420A3	2017-07-09 03:19:00+03	29400.00
D420C4	2017-08-08 03:09:00+03	25000.00
D42165	2017-08-02 14:52:00+03	37900.00
D42166	2017-07-21 06:28:00+03	20800.00
D42183	2017-07-21 12:41:00+03	40600.00
D42188	2017-08-06 18:23:00+03	122300.00
D421AA	2017-07-20 05:19:00+03	31600.00
D42222	2017-07-29 18:19:00+03	68800.00
D42226	2017-08-08 03:10:00+03	24400.00
D4232F	2017-07-25 04:02:00+03	31400.00
D42364	2017-08-03 21:51:00+03	14400.00
D423EA	2017-07-16 08:10:00+03	69000.00
D42400	2017-07-20 16:26:00+03	64400.00
D424E1	2017-08-12 16:18:00+03	76800.00
D4250F	2017-07-23 18:15:00+03	28000.00
D4252E	2017-07-05 14:21:00+03	26200.00
D42571	2017-07-07 04:55:00+03	133100.00
D4259B	2017-07-05 11:36:00+03	124300.00
D425AC	2017-07-04 12:12:00+03	111600.00
D425D5	2017-07-18 06:06:00+03	90400.00
D425E8	2017-07-23 18:14:00+03	28000.00
D426C1	2017-07-11 10:43:00+03	27200.00
D426DB	2017-07-20 19:08:00+03	57600.00
D42756	2017-08-05 13:10:00+03	286100.00
D4277B	2017-07-11 20:01:00+03	76800.00
D427A5	2017-07-23 03:33:00+03	56000.00
D427AB	2017-07-21 07:56:00+03	168000.00
D427BE	2017-07-02 08:32:00+03	89300.00
D428F5	2017-08-09 22:29:00+03	111700.00
D42909	2017-08-01 12:42:00+03	75800.00
D4293C	2017-07-09 10:18:00+03	136600.00
D42954	2017-07-30 10:46:00+03	46000.00
D42A30	2017-07-04 01:09:00+03	23200.00
D42AA9	2017-08-07 13:53:00+03	6000.00
D42B2D	2017-08-14 06:44:00+03	66600.00
D42C12	2017-07-28 10:15:00+03	192400.00
D42C17	2017-07-31 08:05:00+03	40800.00
D42C35	2017-07-12 13:48:00+03	193600.00
D42C48	2017-07-17 05:55:00+03	182400.00
D42C8E	2017-07-31 16:26:00+03	88800.00
D42CC3	2017-08-09 23:00:00+03	149300.00
D42CC5	2017-07-07 08:09:00+03	32200.00
D42CFC	2017-08-08 08:43:00+03	48800.00
D42D15	2017-08-03 14:18:00+03	28800.00
D42D5C	2017-08-12 08:16:00+03	117300.00
D42E60	2017-08-08 08:58:00+03	41600.00
D42EDA	2017-08-06 21:45:00+03	189800.00
D42F4D	2017-07-02 04:31:00+03	111600.00
D42F90	2017-08-06 01:16:00+03	6000.00
D42FDA	2017-08-12 03:33:00+03	138000.00
D43023	2017-07-26 10:51:00+03	24400.00
D43113	2017-07-05 16:04:00+03	6700.00
D43178	2017-08-10 20:10:00+03	133100.00
D43195	2017-08-03 04:55:00+03	99300.00
D43205	2017-07-15 15:17:00+03	143000.00
D43219	2017-07-03 15:21:00+03	51600.00
D43247	2017-07-16 12:07:00+03	13700.00
D43290	2017-07-18 11:40:00+03	16400.00
D432E4	2017-07-17 07:25:00+03	64400.00
D43310	2017-08-06 08:41:00+03	58500.00
D43314	2017-08-12 07:16:00+03	135400.00
D43319	2017-07-18 22:14:00+03	55800.00
D43368	2017-08-06 08:50:00+03	37900.00
D43373	2017-07-03 08:16:00+03	34000.00
D43375	2017-07-09 07:18:00+03	112600.00
D43384	2017-08-15 05:31:00+03	22000.00
D433EC	2017-07-25 15:14:00+03	11700.00
D4347A	2017-08-06 00:43:00+03	15800.00
D4347C	2017-07-04 02:27:00+03	136000.00
D434C0	2017-07-22 08:54:00+03	174900.00
D434C8	2017-07-18 21:38:00+03	80900.00
D434F5	2017-07-03 05:30:00+03	136200.00
D434FE	2017-07-20 07:04:00+03	56000.00
D4355B	2017-08-06 09:32:00+03	72400.00
D435A2	2017-07-04 10:49:00+03	140900.00
D435AA	2017-06-25 04:06:00+03	132900.00
D435B5	2017-07-22 19:50:00+03	67600.00
D43642	2017-07-19 03:40:00+03	40800.00
D4364E	2017-08-03 18:59:00+03	133100.00
D43680	2017-07-08 00:25:00+03	13200.00
D436C1	2017-07-17 20:22:00+03	128800.00
D43719	2017-08-07 11:42:00+03	98400.00
D43720	2017-07-04 19:23:00+03	39300.00
D43730	2017-07-28 23:20:00+03	38600.00
D437A8	2017-07-24 17:47:00+03	40800.00
D437AB	2017-07-13 09:36:00+03	50600.00
D437E5	2017-07-06 05:00:00+03	16400.00
D43861	2017-08-08 08:16:00+03	23400.00
D43868	2017-07-20 13:50:00+03	24400.00
D438FC	2017-07-27 14:22:00+03	8400.00
D4390D	2017-07-29 04:35:00+03	58800.00
D4392C	2017-08-13 08:42:00+03	65900.00
D43965	2017-08-10 03:35:00+03	81700.00
D4396B	2017-07-08 23:54:00+03	19600.00
D439B4	2017-07-12 13:06:00+03	36200.00
D439C4	2017-08-02 09:19:00+03	89700.00
D439E6	2017-07-07 17:31:00+03	57400.00
D43A20	2017-07-07 16:35:00+03	73500.00
D43A2A	2017-08-01 21:39:00+03	95600.00
D43A69	2017-08-01 23:08:00+03	61100.00
D43A9C	2017-07-28 10:53:00+03	136600.00
D43AC2	2017-07-30 16:41:00+03	66600.00
D43AF1	2017-07-08 14:43:00+03	58800.00
D43B4B	2017-08-02 01:32:00+03	47400.00
D43B85	2017-08-11 11:49:00+03	13600.00
D43BB4	2017-07-03 02:45:00+03	669400.00
D43BE5	2017-07-20 15:26:00+03	123000.00
D43BE9	2017-08-03 06:28:00+03	23600.00
D43C6B	2017-07-07 03:15:00+03	40800.00
D43C7A	2017-08-04 11:53:00+03	49200.00
D43C93	2017-07-04 15:57:00+03	14400.00
D43CB8	2017-07-11 13:20:00+03	94300.00
D43CDB	2017-08-05 11:17:00+03	142700.00
D43D81	2017-07-16 23:14:00+03	31600.00
D43DA9	2017-08-15 09:37:00+03	99300.00
D43DD3	2017-07-06 14:38:00+03	156700.00
D43E07	2017-07-19 05:49:00+03	46400.00
D43E1A	2017-08-13 13:15:00+03	181300.00
D43E2C	2017-07-26 00:17:00+03	43200.00
D43E38	2017-08-08 23:47:00+03	90700.00
D43EDA	2017-08-08 01:55:00+03	59800.00
D43F22	2017-08-01 00:13:00+03	44800.00
D43F69	2017-07-05 05:56:00+03	288300.00
D43FB1	2017-08-09 17:56:00+03	97700.00
D43FDA	2017-07-18 14:11:00+03	311200.00
D43FDB	2017-07-13 07:15:00+03	6800.00
D440A0	2017-08-09 04:36:00+03	119700.00
D440A6	2017-08-06 11:44:00+03	56000.00
D4410E	2017-07-27 06:07:00+03	42500.00
D4412E	2017-07-08 02:11:00+03	21800.00
D44181	2017-07-19 07:26:00+03	233800.00
D4419E	2017-07-15 10:52:00+03	47300.00
D441B7	2017-07-08 12:48:00+03	56600.00
D441F4	2017-07-08 13:01:00+03	48800.00
D44218	2017-06-30 13:26:00+03	26200.00
D442B0	2017-07-23 08:32:00+03	26600.00
D442C5	2017-07-10 16:44:00+03	75300.00
D442DE	2017-07-17 04:24:00+03	281500.00
D4436E	2017-07-18 07:57:00+03	39200.00
D4439B	2017-07-21 08:10:00+03	39400.00
D443C4	2017-07-31 09:20:00+03	41400.00
D44418	2017-07-23 04:11:00+03	80800.00
D44445	2017-07-10 13:57:00+03	271100.00
D4448C	2017-07-16 03:49:00+03	170500.00
D444D4	2017-07-28 16:33:00+03	27600.00
D444D6	2017-07-27 05:16:00+03	82500.00
D4453D	2017-07-18 15:56:00+03	43200.00
D445A9	2017-08-12 21:44:00+03	100600.00
D445AE	2017-07-16 20:48:00+03	73600.00
D44681	2017-07-18 12:15:00+03	47200.00
D446ED	2017-07-05 11:50:00+03	13200.00
D446F4	2017-07-06 03:05:00+03	178800.00
D44792	2017-07-09 12:56:00+03	23200.00
D447C8	2017-08-11 15:42:00+03	21400.00
D447C9	2017-08-01 22:46:00+03	34000.00
D44809	2017-07-13 12:54:00+03	18000.00
D44896	2017-07-12 15:48:00+03	6000.00
D44987	2017-07-28 02:11:00+03	26600.00
D449AA	2017-08-15 17:24:00+03	359000.00
D449CC	2017-08-14 01:26:00+03	32900.00
D449FE	2017-08-09 10:34:00+03	15500.00
D44A24	2017-07-03 04:46:00+03	48700.00
D44ACD	2017-07-18 23:53:00+03	43200.00
D44B06	2017-07-07 19:11:00+03	21400.00
D44B29	2017-08-15 03:48:00+03	48000.00
D44B5C	2017-07-22 19:02:00+03	172100.00
D44B64	2017-08-12 01:08:00+03	65900.00
D44B6A	2017-07-30 16:21:00+03	8200.00
D44B90	2017-07-03 00:05:00+03	129700.00
D44BEC	2017-07-12 22:07:00+03	65600.00
D44C33	2017-07-31 11:06:00+03	32200.00
D44C58	2017-07-11 16:09:00+03	201800.00
D44C85	2017-08-13 10:53:00+03	40800.00
D44CF0	2017-07-05 20:06:00+03	77200.00
D44D30	2017-07-29 10:53:00+03	27200.00
D44D40	2017-08-08 11:36:00+03	70700.00
D44D43	2017-08-06 23:09:00+03	54800.00
D44DEE	2017-08-03 18:57:00+03	143100.00
D44DFD	2017-07-08 06:59:00+03	147000.00
D44E25	2017-08-11 13:16:00+03	109600.00
D44ECC	2017-07-14 23:18:00+03	56000.00
D44ED1	2017-07-25 20:13:00+03	101200.00
D44F7D	2017-07-23 15:41:00+03	27200.00
D44FBC	2017-07-15 06:34:00+03	46000.00
D44FF7	2017-07-27 11:37:00+03	28000.00
D45098	2017-07-13 22:37:00+03	212800.00
D450F5	2017-07-10 19:25:00+03	102300.00
D4510D	2017-07-26 14:35:00+03	8000.00
D4513A	2017-08-08 02:32:00+03	6700.00
D4514B	2017-08-05 02:31:00+03	25000.00
D4515B	2017-07-18 18:06:00+03	68400.00
D4516F	2017-07-04 12:24:00+03	246000.00
D45174	2017-07-14 21:56:00+03	12000.00
D45179	2017-07-23 23:45:00+03	43600.00
D45228	2017-07-15 16:21:00+03	59800.00
D452B4	2017-08-02 04:18:00+03	56000.00
D452E3	2017-07-31 13:04:00+03	405200.00
D4533B	2017-07-06 15:46:00+03	136200.00
D45374	2017-07-31 01:12:00+03	19600.00
D453C3	2017-08-01 10:12:00+03	40800.00
D4543E	2017-07-09 23:20:00+03	48700.00
D4546C	2017-07-12 17:47:00+03	42800.00
D454A4	2017-07-18 18:15:00+03	25200.00
D454AF	2017-07-04 09:48:00+03	12000.00
D45533	2017-07-27 06:48:00+03	231200.00
D45569	2017-08-11 09:46:00+03	139100.00
D4556C	2017-07-28 12:17:00+03	193100.00
D455CE	2017-07-06 02:38:00+03	87000.00
D45615	2017-08-13 20:17:00+03	386300.00
D45669	2017-08-02 07:04:00+03	40800.00
D45675	2017-07-21 18:58:00+03	13800.00
D45724	2017-07-21 05:47:00+03	12400.00
D457A3	2017-07-09 06:28:00+03	47000.00
D457E6	2017-06-28 11:06:00+03	36200.00
D45803	2017-07-22 04:58:00+03	75000.00
D4582B	2017-07-27 23:34:00+03	64000.00
D4584E	2017-08-10 13:00:00+03	114200.00
D45880	2017-07-01 11:46:00+03	81700.00
D458E2	2017-08-11 18:00:00+03	126400.00
D45901	2017-07-25 16:58:00+03	45200.00
D45945	2017-08-06 08:20:00+03	15000.00
D4595B	2017-08-03 03:50:00+03	30200.00
D4596B	2017-07-19 13:43:00+03	34000.00
D4598F	2017-07-05 14:36:00+03	123000.00
D4599F	2017-07-13 02:37:00+03	85700.00
D45A61	2017-08-14 16:41:00+03	41800.00
D45A93	2017-08-08 12:24:00+03	23200.00
D45AD7	2017-07-20 06:02:00+03	454600.00
D45B44	2017-08-02 10:39:00+03	302400.00
D45B94	2017-07-11 07:37:00+03	20800.00
D45BFB	2017-08-09 23:45:00+03	38400.00
D45C87	2017-08-01 03:26:00+03	68100.00
D45D8E	2017-07-03 22:30:00+03	27700.00
D45E3C	2017-07-02 12:58:00+03	104600.00
D45EDE	2017-07-28 02:51:00+03	149200.00
D45EEE	2017-07-05 21:02:00+03	13600.00
D45F41	2017-08-13 01:52:00+03	29800.00
D45F8B	2017-07-08 13:13:00+03	296400.00
D45FA4	2017-08-11 12:35:00+03	51900.00
D45FC2	2017-08-03 18:02:00+03	26000.00
D46044	2017-07-07 15:08:00+03	37100.00
D46069	2017-08-02 13:27:00+03	66600.00
D46094	2017-07-14 07:35:00+03	194800.00
D460D9	2017-07-09 12:45:00+03	15200.00
D46167	2017-08-03 01:45:00+03	55800.00
D46190	2017-08-04 07:31:00+03	102000.00
D461BD	2017-08-12 14:23:00+03	23200.00
D461D8	2017-08-06 02:53:00+03	144400.00
D46205	2017-07-04 04:48:00+03	13300.00
D46212	2017-07-19 09:25:00+03	20200.00
D4621C	2017-07-02 16:20:00+03	126400.00
D46230	2017-08-14 04:18:00+03	89200.00
D46265	2017-08-14 03:04:00+03	61800.00
D462D0	2017-08-02 10:00:00+03	258000.00
D462FF	2017-08-04 01:47:00+03	60400.00
D46311	2017-07-09 07:23:00+03	114400.00
D46352	2017-08-07 13:32:00+03	47100.00
D46357	2017-07-12 19:26:00+03	62900.00
D463BD	2017-07-28 00:45:00+03	56000.00
D463CE	2017-08-07 22:22:00+03	125600.00
D46403	2017-08-03 21:48:00+03	16400.00
D46430	2017-07-16 14:02:00+03	77900.00
D4644C	2017-08-02 06:53:00+03	56200.00
D46473	2017-07-21 08:09:00+03	37900.00
D464B8	2017-08-12 15:47:00+03	17600.00
D464BE	2017-07-30 11:33:00+03	41600.00
D464C4	2017-07-02 18:13:00+03	155600.00
D4654C	2017-07-24 19:43:00+03	34400.00
D465A4	2017-07-12 17:33:00+03	268400.00
D465EF	2017-07-28 16:46:00+03	26000.00
D4660B	2017-07-12 16:49:00+03	369000.00
D4660C	2017-07-05 19:17:00+03	86600.00
D4660E	2017-07-19 14:58:00+03	92000.00
D46619	2017-07-08 05:16:00+03	48400.00
D4661A	2017-07-13 08:20:00+03	353100.00
D4661E	2017-07-13 01:40:00+03	88600.00
D4668E	2017-07-12 07:48:00+03	246000.00
D4669D	2017-08-08 16:33:00+03	28000.00
D466B4	2017-07-22 19:14:00+03	34400.00
D466CC	2017-07-31 23:51:00+03	132800.00
D466D4	2017-07-12 09:44:00+03	67700.00
D466DC	2017-07-21 18:08:00+03	116400.00
D46746	2017-07-11 03:37:00+03	109600.00
D4677A	2017-08-03 20:54:00+03	146300.00
D467FB	2017-07-18 20:01:00+03	8200.00
D46806	2017-08-08 12:16:00+03	109600.00
D46826	2017-07-11 12:40:00+03	89800.00
D46861	2017-08-06 18:40:00+03	119800.00
D46862	2017-07-12 14:43:00+03	24400.00
D468C9	2017-07-22 05:23:00+03	135600.00
D468DC	2017-08-15 00:19:00+03	37400.00
D468F7	2017-07-23 02:52:00+03	36200.00
D46923	2017-08-04 22:35:00+03	98400.00
D469C6	2017-07-27 09:43:00+03	68800.00
D469D3	2017-08-06 23:33:00+03	246000.00
D469FB	2017-07-11 03:09:00+03	260300.00
D46A14	2017-08-04 06:01:00+03	57600.00
D46A6F	2017-08-06 06:58:00+03	234700.00
D46A8D	2017-08-09 01:58:00+03	27400.00
D46ACE	2017-07-28 02:14:00+03	70400.00
D46AF9	2017-07-10 01:11:00+03	123000.00
D46B21	2017-07-05 15:30:00+03	19600.00
D46B57	2017-07-01 13:47:00+03	14000.00
D46B63	2017-07-28 08:29:00+03	54000.00
D46B64	2017-08-08 01:56:00+03	61800.00
D46B89	2017-07-26 11:37:00+03	28800.00
D46B8F	2017-07-24 22:13:00+03	136500.00
D46BF9	2017-07-12 06:15:00+03	28800.00
D46C04	2017-07-22 09:30:00+03	31400.00
D46C99	2017-08-08 09:55:00+03	41800.00
D46CBA	2017-08-01 03:32:00+03	21000.00
D46CEC	2017-07-12 12:34:00+03	13600.00
D46CFD	2017-07-04 05:59:00+03	37900.00
D46D0B	2017-08-13 12:06:00+03	12600.00
D46D1A	2017-07-21 21:41:00+03	101100.00
D46D53	2017-07-23 18:44:00+03	263200.00
D46D54	2017-07-29 04:44:00+03	32200.00
D46D5A	2017-07-18 00:52:00+03	15900.00
D46DFB	2017-07-25 23:00:00+03	24800.00
D46E36	2017-08-03 14:15:00+03	55800.00
D46E44	2017-07-28 17:16:00+03	62000.00
D46E87	2017-07-31 14:50:00+03	168000.00
D46E8D	2017-07-18 10:20:00+03	13600.00
D46EB0	2017-07-19 14:05:00+03	99900.00
D46ED6	2017-07-21 15:18:00+03	62600.00
D46EF5	2017-07-27 13:40:00+03	406700.00
D46F00	2017-07-14 22:43:00+03	34000.00
D46F7D	2017-08-10 03:33:00+03	266300.00
D46F84	2017-07-21 04:06:00+03	121400.00
D46F9B	2017-07-22 02:16:00+03	22000.00
D46FFB	2017-07-08 22:04:00+03	92900.00
D47016	2017-08-07 02:11:00+03	53000.00
D47023	2017-08-06 06:35:00+03	12000.00
D47069	2017-08-06 05:56:00+03	62700.00
D4707F	2017-07-11 08:16:00+03	78600.00
D47091	2017-08-11 19:22:00+03	70400.00
D4710F	2017-07-20 21:30:00+03	47400.00
D4711D	2017-08-01 18:20:00+03	6800.00
D4714D	2017-07-14 07:50:00+03	37100.00
D47152	2017-07-09 14:42:00+03	30200.00
D47157	2017-07-18 00:29:00+03	6000.00
D471A3	2017-07-06 06:07:00+03	18000.00
D471BC	2017-07-11 03:16:00+03	40200.00
D47205	2017-06-30 17:27:00+03	137600.00
D47219	2017-07-14 16:38:00+03	6800.00
D47248	2017-07-10 23:56:00+03	49100.00
D472F4	2017-07-01 21:32:00+03	136500.00
D47319	2017-08-03 17:13:00+03	297000.00
D4731F	2017-07-29 21:57:00+03	68800.00
D4740B	2017-07-05 20:22:00+03	382800.00
D47426	2017-07-16 09:26:00+03	46000.00
D47461	2017-08-14 05:33:00+03	43500.00
D474A7	2017-08-10 07:12:00+03	24400.00
D474B8	2017-08-04 05:55:00+03	120900.00
D47511	2017-07-12 10:42:00+03	111600.00
D47569	2017-07-21 21:22:00+03	92700.00
D4757E	2017-07-21 17:47:00+03	35700.00
D4758C	2017-07-15 14:49:00+03	62800.00
D475A7	2017-07-11 05:27:00+03	158500.00
D475E9	2017-07-08 09:23:00+03	31600.00
D475F8	2017-08-11 10:54:00+03	73000.00
D475FF	2017-07-19 14:33:00+03	26000.00
D47626	2017-08-08 18:33:00+03	40800.00
D47629	2017-07-23 21:13:00+03	41900.00
D4762C	2017-08-09 08:24:00+03	11700.00
D47699	2017-08-02 07:38:00+03	243600.00
D4773E	2017-08-15 09:09:00+03	40000.00
D4776D	2017-08-07 14:14:00+03	19600.00
D47840	2017-08-11 01:14:00+03	100600.00
D47846	2017-07-16 04:46:00+03	92000.00
D47887	2017-07-10 07:35:00+03	50600.00
D4796F	2017-07-12 21:32:00+03	6800.00
D47983	2017-07-19 12:00:00+03	36400.00
D479C3	2017-07-11 23:39:00+03	39800.00
D479C6	2017-08-06 13:13:00+03	204800.00
D47A5A	2017-07-29 01:24:00+03	41600.00
D47A93	2017-07-29 12:15:00+03	107800.00
D47A9F	2017-07-05 11:54:00+03	83400.00
D47B02	2017-07-22 05:21:00+03	14400.00
D47B52	2017-07-17 23:18:00+03	28000.00
D47B5A	2017-08-14 03:42:00+03	75300.00
D47B65	2017-08-15 09:14:00+03	136800.00
D47B93	2017-07-17 04:14:00+03	29600.00
D47BB3	2017-08-07 23:27:00+03	26000.00
D47BCC	2017-08-02 10:04:00+03	29600.00
D47C59	2017-08-06 18:11:00+03	7400.00
D47CDE	2017-07-30 15:48:00+03	98100.00
D47CF7	2017-08-12 21:56:00+03	45200.00
D47D2D	2017-07-28 12:06:00+03	139000.00
D47D75	2017-07-20 09:35:00+03	40000.00
D47DDF	2017-07-29 20:42:00+03	101200.00
D47DE1	2017-08-01 00:35:00+03	56600.00
D47DF4	2017-08-02 10:08:00+03	114400.00
D47E33	2017-07-06 08:41:00+03	246000.00
D47E51	2017-07-22 14:32:00+03	31900.00
D47E97	2017-08-04 12:02:00+03	7400.00
D47EAB	2017-07-23 04:17:00+03	100300.00
D47ECF	2017-08-09 10:37:00+03	123000.00
D47ED5	2017-07-22 15:50:00+03	53400.00
D47EFD	2017-07-28 12:07:00+03	24400.00
D47F0E	2017-08-15 08:40:00+03	9200.00
D47F15	2017-08-08 21:19:00+03	111600.00
D47F6E	2017-07-02 11:23:00+03	40400.00
D47F86	2017-08-05 08:55:00+03	266200.00
D4805D	2017-08-04 07:06:00+03	17600.00
D48075	2017-07-22 05:26:00+03	37900.00
D4808C	2017-07-23 18:13:00+03	101200.00
D480A1	2017-08-01 16:59:00+03	27200.00
D480CC	2017-07-21 17:00:00+03	43600.00
D480CE	2017-07-13 02:02:00+03	62700.00
D480CF	2017-08-01 12:31:00+03	43100.00
D480E5	2017-07-27 21:09:00+03	6300.00
D480F8	2017-07-31 19:52:00+03	23400.00
D48108	2017-08-07 16:49:00+03	23400.00
D4810C	2017-08-13 07:58:00+03	81600.00
D481E2	2017-08-12 03:41:00+03	37600.00
D48237	2017-07-16 11:23:00+03	86400.00
D48277	2017-08-14 01:14:00+03	29800.00
D48295	2017-08-08 23:53:00+03	13400.00
D48304	2017-08-09 16:45:00+03	112000.00
D48378	2017-07-18 07:48:00+03	132800.00
D48379	2017-07-24 04:48:00+03	81900.00
D483C9	2017-08-05 18:27:00+03	30700.00
D4844C	2017-07-25 22:59:00+03	38600.00
D4849F	2017-07-23 08:17:00+03	133200.00
D484AA	2017-08-04 13:30:00+03	11200.00
D484CE	2017-07-07 20:09:00+03	136700.00
D484E4	2017-07-11 19:27:00+03	192400.00
D48501	2017-08-06 22:21:00+03	137600.00
D48517	2017-07-25 01:14:00+03	174400.00
D4851F	2017-08-15 09:54:00+03	14000.00
D485A0	2017-07-21 16:16:00+03	20200.00
D485ED	2017-07-20 14:34:00+03	10800.00
D48625	2017-07-04 16:43:00+03	38400.00
D48630	2017-07-09 13:25:00+03	76100.00
D48644	2017-07-21 08:29:00+03	225200.00
D4869D	2017-07-07 21:48:00+03	28600.00
D486B0	2017-08-03 10:42:00+03	26000.00
D48731	2017-07-17 10:37:00+03	75800.00
D487BF	2017-08-12 08:53:00+03	67600.00
D487E2	2017-07-07 17:16:00+03	39200.00
D48818	2017-08-04 21:33:00+03	31600.00
D4882A	2017-08-05 23:52:00+03	6700.00
D48899	2017-07-20 12:02:00+03	50600.00
D48909	2017-07-03 23:31:00+03	28000.00
D48956	2017-07-15 06:12:00+03	23200.00
D4898A	2017-07-15 14:20:00+03	20400.00
D489B6	2017-07-18 01:22:00+03	59800.00
D489DE	2017-07-29 16:40:00+03	31600.00
D48AD0	2017-07-16 23:17:00+03	159900.00
D48AEB	2017-07-16 16:32:00+03	47400.00
D48B14	2017-07-20 21:14:00+03	6000.00
D48B2A	2017-08-04 04:51:00+03	57500.00
D48B30	2017-07-11 01:20:00+03	13400.00
D48BD5	2017-07-05 18:40:00+03	31900.00
D48BDE	2017-08-03 17:37:00+03	94400.00
D48BED	2017-08-07 17:26:00+03	44000.00
D48C26	2017-07-24 00:04:00+03	95000.00
D48C55	2017-07-03 05:12:00+03	185300.00
D48C57	2017-07-25 19:46:00+03	92800.00
D48CA9	2017-08-14 17:37:00+03	87800.00
D48CF3	2017-07-22 21:06:00+03	24700.00
D48CFC	2017-07-12 12:40:00+03	115600.00
D48D29	2017-08-03 04:15:00+03	31200.00
D48D6D	2017-07-18 20:29:00+03	17600.00
D48DB3	2017-07-01 11:13:00+03	30000.00
D48DDF	2017-08-10 07:00:00+03	39200.00
D48E10	2017-07-11 00:07:00+03	75300.00
D48E5E	2017-07-04 05:57:00+03	46300.00
D48E6D	2017-07-29 09:47:00+03	28800.00
D48ED6	2017-07-23 21:43:00+03	48800.00
D48EDA	2017-07-09 16:12:00+03	21600.00
D48F0F	2017-08-09 17:37:00+03	22000.00
D48F54	2017-07-09 08:26:00+03	105000.00
D48F9D	2017-07-10 15:00:00+03	92800.00
D49018	2017-08-02 20:11:00+03	153300.00
D4901C	2017-07-16 09:18:00+03	10700.00
D4903C	2017-07-06 05:53:00+03	136000.00
D490DA	2017-07-13 21:20:00+03	98400.00
D490E7	2017-07-15 18:16:00+03	40400.00
D4916E	2017-07-14 09:40:00+03	58600.00
D49184	2017-07-16 10:19:00+03	66600.00
D49208	2017-07-08 10:47:00+03	42800.00
D49324	2017-08-14 12:40:00+03	64500.00
D49358	2017-07-24 04:08:00+03	40300.00
D49366	2017-08-09 19:57:00+03	115800.00
D49391	2017-08-11 16:09:00+03	43500.00
D493D9	2017-07-02 12:11:00+03	52500.00
D493DD	2017-07-08 04:33:00+03	51000.00
D4943B	2017-07-10 20:16:00+03	73300.00
D494A5	2017-07-17 09:50:00+03	135800.00
D4952A	2017-08-13 08:40:00+03	357600.00
D49590	2017-07-10 14:57:00+03	67200.00
D495A4	2017-07-29 08:59:00+03	56900.00
D495B7	2017-07-21 00:57:00+03	14400.00
D495E8	2017-07-11 03:56:00+03	272300.00
D49648	2017-07-24 00:31:00+03	39200.00
D49734	2017-08-11 04:19:00+03	43100.00
D49739	2017-08-11 18:11:00+03	23900.00
D4975C	2017-08-15 04:19:00+03	119500.00
D49760	2017-07-14 13:34:00+03	201200.00
D497D8	2017-07-16 02:34:00+03	116900.00
D497F9	2017-07-24 22:16:00+03	144400.00
D49810	2017-07-10 13:01:00+03	36000.00
D49811	2017-07-20 03:39:00+03	27200.00
D49822	2017-08-07 07:38:00+03	137100.00
D49839	2017-07-26 07:16:00+03	12400.00
D49858	2017-08-14 06:40:00+03	80000.00
D49875	2017-08-06 00:19:00+03	246000.00
D49894	2017-07-10 23:05:00+03	71900.00
D498CB	2017-08-07 22:26:00+03	34000.00
D498D4	2017-07-09 07:07:00+03	35200.00
D498DA	2017-08-14 15:39:00+03	406700.00
D4990D	2017-07-17 13:08:00+03	26000.00
D4991C	2017-08-11 17:30:00+03	20200.00
D49927	2017-08-15 08:21:00+03	99600.00
D4996C	2017-08-12 12:56:00+03	23900.00
D4997A	2017-07-09 19:42:00+03	29800.00
D49984	2017-07-20 22:23:00+03	57600.00
D49988	2017-08-12 07:17:00+03	39800.00
D49A37	2017-08-13 23:21:00+03	51900.00
D49A54	2017-07-26 15:11:00+03	40600.00
D49AA4	2017-08-10 03:28:00+03	9200.00
D49AB2	2017-07-29 13:49:00+03	47200.00
D49AC8	2017-07-08 16:09:00+03	22000.00
D49AD9	2017-07-31 01:19:00+03	135600.00
D49B5D	2017-06-30 00:13:00+03	67300.00
D49BC8	2017-07-10 01:01:00+03	240600.00
D49C3E	2017-08-15 03:30:00+03	25200.00
D49D7D	2017-07-26 21:00:00+03	6300.00
D49D80	2017-07-16 07:42:00+03	406200.00
D49DB7	2017-06-30 09:40:00+03	56000.00
D49DBE	2017-07-14 06:29:00+03	66800.00
D49DCA	2017-08-08 21:25:00+03	56900.00
D49DFF	2017-08-14 21:04:00+03	58000.00
D49EE4	2017-07-05 16:29:00+03	6200.00
D49F90	2017-07-14 07:41:00+03	6700.00
D49FAF	2017-07-13 05:39:00+03	8800.00
D4A0C5	2017-08-12 12:53:00+03	21200.00
D4A0C8	2017-07-29 01:52:00+03	103800.00
D4A158	2017-08-07 14:14:00+03	59800.00
D4A16B	2017-07-01 16:06:00+03	8200.00
D4A182	2017-08-06 09:56:00+03	252200.00
D4A1BF	2017-07-11 11:39:00+03	92800.00
D4A1E3	2017-07-13 07:34:00+03	51800.00
D4A289	2017-07-30 01:53:00+03	24200.00
D4A310	2017-07-04 05:06:00+03	56600.00
D4A32F	2017-08-05 00:38:00+03	88100.00
D4A37C	2017-07-05 05:39:00+03	112000.00
D4A3BC	2017-07-27 15:30:00+03	23200.00
D4A413	2017-08-14 19:21:00+03	43200.00
D4A44A	2017-06-29 04:39:00+03	67700.00
D4A45B	2017-08-13 23:16:00+03	58800.00
D4A488	2017-07-24 06:26:00+03	61800.00
D4A55C	2017-08-04 09:16:00+03	75600.00
D4A610	2017-08-04 02:19:00+03	26600.00
D4A62E	2017-08-06 20:28:00+03	38800.00
D4A6A1	2017-07-21 05:27:00+03	21600.00
D4A6DB	2017-07-18 18:34:00+03	10600.00
D4A761	2017-07-31 09:04:00+03	98800.00
D4A784	2017-07-03 13:37:00+03	30200.00
D4A786	2017-08-14 12:55:00+03	64700.00
D4A7BD	2017-08-01 15:40:00+03	3400.00
D4A86E	2017-07-10 04:21:00+03	36200.00
D4A876	2017-07-27 15:24:00+03	6300.00
D4A88C	2017-07-05 16:47:00+03	68000.00
D4A89A	2017-08-12 20:26:00+03	36200.00
D4A951	2017-08-01 20:09:00+03	49600.00
D4A963	2017-08-10 05:31:00+03	81700.00
D4AA17	2017-08-04 10:30:00+03	8000.00
D4AA1B	2017-07-02 13:22:00+03	22100.00
D4AAB3	2017-07-15 18:02:00+03	46400.00
D4AB0F	2017-08-11 21:41:00+03	57500.00
D4AB69	2017-07-17 09:35:00+03	29800.00
D4ABAB	2017-07-01 13:14:00+03	10800.00
D4ABBB	2017-07-06 09:44:00+03	56100.00
D4ABD7	2017-06-27 04:24:00+03	60400.00
D4ABF0	2017-07-19 10:06:00+03	40000.00
D4ACC2	2017-06-30 14:54:00+03	182300.00
D4ACCD	2017-08-09 12:34:00+03	101200.00
D4AD55	2017-08-05 03:02:00+03	20400.00
D4AD65	2017-07-05 14:52:00+03	27200.00
D4AD7A	2017-07-24 14:31:00+03	66600.00
D4ADB9	2017-08-14 10:58:00+03	23400.00
D4ADCB	2017-07-27 06:48:00+03	69500.00
D4AE2D	2017-07-16 09:31:00+03	67800.00
D4AE5E	2017-07-06 04:48:00+03	163900.00
D4AE92	2017-07-22 23:23:00+03	16400.00
D4AEBF	2017-07-18 14:44:00+03	21800.00
D4AECD	2017-07-02 16:55:00+03	94800.00
D4AEED	2017-08-03 22:47:00+03	99300.00
D4AF17	2017-07-11 01:08:00+03	123000.00
D4AF42	2017-08-09 22:56:00+03	88600.00
D4AFC2	2017-07-19 06:59:00+03	46400.00
D4AFC9	2017-07-22 07:10:00+03	117200.00
D4AFF0	2017-07-04 09:34:00+03	94000.00
D4B010	2017-07-24 13:35:00+03	56900.00
D4B024	2017-07-21 22:41:00+03	17800.00
D4B060	2017-08-10 14:58:00+03	133100.00
D4B06B	2017-08-06 03:00:00+03	57600.00
D4B0C7	2017-07-07 15:23:00+03	223400.00
D4B0E1	2017-07-30 17:25:00+03	246000.00
D4B123	2017-07-15 14:13:00+03	202400.00
D4B126	2017-07-10 13:33:00+03	59100.00
D4B132	2017-07-23 16:44:00+03	136300.00
D4B156	2017-08-15 09:09:00+03	37200.00
D4B171	2017-08-01 09:07:00+03	38400.00
D4B206	2017-07-22 13:57:00+03	96800.00
D4B21A	2017-07-10 02:26:00+03	3400.00
D4B2AC	2017-07-25 00:31:00+03	113000.00
D4B32F	2017-07-06 23:57:00+03	111600.00
D4B358	2017-07-22 18:24:00+03	47700.00
D4B383	2017-07-11 01:36:00+03	13400.00
D4B39D	2017-07-24 15:04:00+03	12400.00
D4B3A1	2017-07-16 06:18:00+03	24400.00
D4B43D	2017-06-30 17:38:00+03	61800.00
D4B45A	2017-08-14 21:09:00+03	42800.00
D4B495	2017-07-02 17:24:00+03	20200.00
D4B49E	2017-07-17 07:41:00+03	51900.00
D4B4A1	2017-07-28 10:19:00+03	85000.00
D4B4F1	2017-08-12 17:18:00+03	36700.00
D4B532	2017-07-23 10:04:00+03	47100.00
D4B533	2017-08-15 08:38:00+03	43500.00
D4B537	2017-07-16 13:46:00+03	240600.00
D4B566	2017-07-14 22:51:00+03	39800.00
D4B67F	2017-08-12 16:17:00+03	81800.00
D4B69F	2017-08-06 03:20:00+03	20200.00
D4B74F	2017-06-28 07:59:00+03	14000.00
D4B7B9	2017-07-19 00:45:00+03	57800.00
D4B7C8	2017-07-01 01:15:00+03	54000.00
D4B7DE	2017-07-27 12:18:00+03	55800.00
D4B7F5	2017-07-06 16:31:00+03	273600.00
D4B8C7	2017-07-05 12:42:00+03	26000.00
D4B91E	2017-07-23 00:19:00+03	65900.00
D4B99E	2017-07-26 06:57:00+03	12600.00
D4B9D0	2017-07-23 10:23:00+03	111600.00
D4B9D8	2017-07-24 14:54:00+03	67600.00
D4BA09	2017-08-12 02:11:00+03	58900.00
D4BAD5	2017-07-08 03:12:00+03	46700.00
D4BBFB	2017-07-13 11:56:00+03	54500.00
D4BBFC	2017-08-12 09:27:00+03	92700.00
D4BCFD	2017-07-16 21:30:00+03	26200.00
D4BD11	2017-07-18 15:20:00+03	13400.00
D4BD31	2017-08-05 09:44:00+03	42700.00
D4BD37	2017-07-12 20:37:00+03	50600.00
D4BD46	2017-07-06 18:34:00+03	83000.00
D4BD4D	2017-07-31 07:19:00+03	13400.00
D4BD9B	2017-08-02 13:35:00+03	52000.00
D4BDE7	2017-08-15 05:32:00+03	87200.00
D4BE18	2017-08-02 21:07:00+03	135400.00
D4BE40	2017-07-07 20:15:00+03	47200.00
D4BEA8	2017-07-24 12:10:00+03	36200.00
D4BEC4	2017-07-26 00:06:00+03	40400.00
D4BEC5	2017-07-22 08:50:00+03	6800.00
D4BED6	2017-07-15 19:45:00+03	47200.00
D4BF20	2017-07-28 10:34:00+03	36800.00
D4BF30	2017-07-01 19:57:00+03	73400.00
D4BFB1	2017-07-26 01:22:00+03	52700.00
D4C044	2017-07-11 19:27:00+03	6000.00
D4C12F	2017-07-29 15:41:00+03	171000.00
D4C17C	2017-07-14 06:48:00+03	58600.00
D4C23A	2017-07-27 20:20:00+03	52300.00
D4C26E	2017-07-14 08:56:00+03	28800.00
D4C284	2017-07-15 12:06:00+03	134400.00
D4C29D	2017-07-10 23:56:00+03	59500.00
D4C2D8	2017-07-26 04:38:00+03	75600.00
D4C2DB	2017-07-07 13:58:00+03	24400.00
D4C2E6	2017-08-14 10:40:00+03	248100.00
D4C2E7	2017-08-09 22:08:00+03	44000.00
D4C304	2017-08-11 15:11:00+03	172200.00
D4C328	2017-08-06 18:44:00+03	196300.00
D4C384	2017-07-08 17:09:00+03	105100.00
D4C394	2017-07-13 06:08:00+03	142400.00
D4C405	2017-07-05 14:49:00+03	167500.00
D4C529	2017-08-06 15:33:00+03	46000.00
D4C57C	2017-08-05 11:05:00+03	132800.00
D4C584	2017-08-09 13:13:00+03	60600.00
D4C5C0	2017-07-25 13:35:00+03	16400.00
D4C5E3	2017-07-27 12:00:00+03	37900.00
D4C5EA	2017-08-03 10:45:00+03	14000.00
D4C610	2017-08-10 16:03:00+03	81600.00
D4C621	2017-08-09 09:32:00+03	133100.00
D4C6D9	2017-08-15 03:37:00+03	37200.00
D4C724	2017-07-31 23:52:00+03	188000.00
D4C72C	2017-07-02 07:53:00+03	111600.00
D4C757	2017-07-11 17:42:00+03	44000.00
D4C7DB	2017-08-01 08:57:00+03	10800.00
D4C7E7	2017-07-26 06:04:00+03	25600.00
D4C806	2017-08-14 22:00:00+03	40100.00
D4C8BE	2017-07-01 18:01:00+03	44500.00
D4C8F9	2017-08-13 10:09:00+03	67700.00
D4C903	2017-07-06 12:04:00+03	111600.00
D4C91A	2017-07-24 20:55:00+03	32400.00
D4C92E	2017-07-30 11:00:00+03	29100.00
D4C9BA	2017-07-09 17:23:00+03	106000.00
D4CA57	2017-08-09 02:58:00+03	48100.00
D4CA74	2017-07-13 04:38:00+03	70500.00
D4CAAB	2017-07-30 16:58:00+03	54100.00
D4CB5B	2017-07-22 01:55:00+03	38400.00
D4CC5B	2017-08-05 19:51:00+03	150300.00
D4CC7C	2017-07-13 22:49:00+03	23400.00
D4CC80	2017-07-08 13:28:00+03	74100.00
D4CCA5	2017-08-13 16:41:00+03	92400.00
D4CCBF	2017-07-21 13:20:00+03	48900.00
D4CCDC	2017-08-10 01:51:00+03	91900.00
D4CDB8	2017-07-05 19:03:00+03	23200.00
D4CDC0	2017-07-26 15:42:00+03	47100.00
D4CE12	2017-07-22 10:06:00+03	32200.00
D4CE8E	2017-07-25 14:42:00+03	58200.00
D4CE90	2017-07-19 12:16:00+03	119500.00
D4CEC3	2017-07-06 08:07:00+03	10100.00
D4CEC4	2017-07-01 09:57:00+03	20600.00
D4CEF3	2017-08-12 00:41:00+03	232800.00
D4CF29	2017-08-11 10:46:00+03	39400.00
D4CF46	2017-08-03 07:25:00+03	179400.00
D4CF5C	2017-07-17 08:07:00+03	25600.00
D4CF5D	2017-06-29 02:49:00+03	38200.00
D4CFB2	2017-07-30 08:45:00+03	56600.00
D4CFD4	2017-07-27 19:38:00+03	26700.00
D4CFE6	2017-07-04 00:40:00+03	28000.00
D4D073	2017-08-14 11:27:00+03	68900.00
D4D075	2017-08-04 01:44:00+03	65200.00
D4D0E4	2017-07-21 07:06:00+03	68800.00
D4D108	2017-06-25 00:07:00+03	21800.00
D4D168	2017-08-01 13:45:00+03	58000.00
D4D18A	2017-08-15 07:41:00+03	32400.00
D4D1AE	2017-08-09 19:53:00+03	37200.00
D4D1BB	2017-07-05 17:17:00+03	55800.00
D4D1C1	2017-07-22 16:17:00+03	6300.00
D4D1D7	2017-08-10 13:54:00+03	32800.00
D4D20E	2017-08-15 09:03:00+03	140800.00
D4D226	2017-08-11 10:01:00+03	32800.00
D4D285	2017-07-13 21:52:00+03	83600.00
D4D296	2017-07-01 18:54:00+03	134400.00
D4D2B2	2017-07-01 10:02:00+03	73600.00
D4D2BD	2017-07-24 18:09:00+03	30200.00
D4D2F4	2017-07-26 09:22:00+03	199800.00
D4D32A	2017-08-14 09:23:00+03	77900.00
D4D331	2017-07-08 21:29:00+03	40200.00
D4D3C2	2017-07-16 03:29:00+03	58200.00
D4D414	2017-07-09 20:57:00+03	130800.00
D4D41F	2017-08-08 09:40:00+03	48100.00
D4D492	2017-08-04 03:28:00+03	92000.00
D4D4F4	2017-07-08 20:52:00+03	53300.00
D4D508	2017-07-13 05:31:00+03	68600.00
D4D527	2017-07-10 14:42:00+03	67700.00
D4D54A	2017-06-26 02:33:00+03	25800.00
D4D559	2017-07-30 05:35:00+03	38500.00
D4D55F	2017-08-01 16:36:00+03	53700.00
D4D56C	2017-07-16 03:43:00+03	60400.00
D4D5DD	2017-06-29 16:45:00+03	47200.00
D4D610	2017-07-11 00:28:00+03	28700.00
D4D643	2017-07-26 08:19:00+03	118700.00
D4D690	2017-07-13 05:22:00+03	28300.00
D4D6A6	2017-08-06 23:34:00+03	11000.00
D4D725	2017-08-12 16:53:00+03	23500.00
D4D7A8	2017-07-26 12:46:00+03	37900.00
D4D7E3	2017-07-01 20:01:00+03	534900.00
D4D86D	2017-08-14 20:00:00+03	62500.00
D4D894	2017-07-07 12:07:00+03	31400.00
D4D8E3	2017-07-13 00:28:00+03	14000.00
D4D8E8	2017-07-03 05:56:00+03	35200.00
D4D922	2017-07-23 22:26:00+03	89700.00
D4D973	2017-08-09 20:42:00+03	16600.00
D4D97E	2017-08-05 20:02:00+03	16400.00
D4D9E5	2017-08-01 07:42:00+03	58400.00
D4DB59	2017-08-10 10:54:00+03	22000.00
D4DB74	2017-07-19 15:51:00+03	6700.00
D4DB8B	2017-07-24 20:18:00+03	56000.00
D4DC96	2017-07-12 14:20:00+03	126700.00
D4DCA5	2017-07-05 21:08:00+03	52100.00
D4DCCB	2017-07-31 18:53:00+03	62000.00
D4DD88	2017-08-14 22:14:00+03	12000.00
D4DDA9	2017-07-15 09:14:00+03	134400.00
D4DE18	2017-08-13 06:14:00+03	181300.00
D4DE21	2017-08-09 23:34:00+03	25100.00
D4DE51	2017-08-10 10:46:00+03	51300.00
D4DE81	2017-07-03 18:58:00+03	115200.00
D4DEE3	2017-08-05 04:12:00+03	203300.00
D4DF0B	2017-07-22 23:41:00+03	55800.00
D4DF79	2017-08-14 21:56:00+03	88600.00
D4DF91	2017-07-05 12:47:00+03	260300.00
D4DF9C	2017-07-10 06:10:00+03	28000.00
D4E014	2017-07-09 13:15:00+03	36900.00
D4E079	2017-07-26 00:09:00+03	72400.00
D4E0A8	2017-07-16 02:43:00+03	47200.00
D4E0AE	2017-07-14 20:33:00+03	118100.00
D4E0D1	2017-08-02 14:04:00+03	6300.00
D4E0F0	2017-07-06 08:28:00+03	97900.00
D4E16F	2017-08-07 09:07:00+03	35800.00
D4E175	2017-07-13 22:05:00+03	172100.00
D4E20B	2017-08-12 05:51:00+03	90000.00
D4E24E	2017-07-07 10:15:00+03	103300.00
D4E30E	2017-08-05 06:51:00+03	32800.00
D4E330	2017-08-10 15:39:00+03	56600.00
D4E334	2017-08-07 06:41:00+03	37900.00
D4E352	2017-08-14 04:00:00+03	12600.00
D4E37F	2017-06-27 19:32:00+03	37700.00
D4E41B	2017-07-06 09:11:00+03	98400.00
D4E431	2017-06-30 14:24:00+03	133200.00
D4E459	2017-07-14 07:42:00+03	61800.00
D4E466	2017-08-07 00:43:00+03	258000.00
D4E4D7	2017-08-12 21:19:00+03	43500.00
D4E504	2017-07-17 10:51:00+03	139300.00
D4E549	2017-08-11 03:36:00+03	56000.00
D4E553	2017-07-12 13:58:00+03	16400.00
D4E5E0	2017-07-10 05:11:00+03	185800.00
D4E608	2017-08-06 00:52:00+03	20000.00
D4E61E	2017-07-04 02:30:00+03	36900.00
D4E70C	2017-07-12 13:32:00+03	166100.00
D4E72E	2017-08-14 09:17:00+03	37200.00
D4E78F	2017-07-10 10:42:00+03	54800.00
D4E797	2017-07-05 14:47:00+03	134400.00
D4E81F	2017-07-15 20:16:00+03	13600.00
D4E82C	2017-07-24 09:32:00+03	24400.00
D4E899	2017-07-28 13:27:00+03	136600.00
D4E8BE	2017-08-14 13:56:00+03	234800.00
D4E90A	2017-07-25 07:33:00+03	40600.00
D4E9AC	2017-07-05 01:20:00+03	12600.00
D4E9D2	2017-08-12 10:51:00+03	52100.00
D4E9DC	2017-08-08 13:48:00+03	67100.00
D4E9DF	2017-07-14 16:26:00+03	75300.00
D4EA02	2017-07-26 06:17:00+03	56000.00
D4EA10	2017-07-14 00:30:00+03	50600.00
D4EA15	2017-08-03 10:03:00+03	100600.00
D4EA75	2017-06-30 09:10:00+03	22000.00
D4EAB1	2017-07-13 04:59:00+03	56000.00
D4EAB6	2017-07-24 23:57:00+03	66600.00
D4EAD2	2017-08-01 21:47:00+03	248300.00
D4EB29	2017-07-17 19:51:00+03	173200.00
D4EB62	2017-07-12 12:07:00+03	16400.00
D4EBAC	2017-07-21 15:22:00+03	21200.00
D4EC04	2017-07-25 04:28:00+03	61200.00
D4EC20	2017-07-10 08:06:00+03	19600.00
D4EC23	2017-07-10 23:44:00+03	60200.00
D4EC2F	2017-07-10 09:45:00+03	86300.00
D4EC60	2017-07-23 18:09:00+03	28000.00
D4EC7D	2017-08-02 01:30:00+03	8200.00
D4EC96	2017-07-18 00:53:00+03	111600.00
D4ECD2	2017-07-28 20:03:00+03	109600.00
D4ECED	2017-07-05 22:39:00+03	136600.00
D4ECF4	2017-07-09 10:38:00+03	134400.00
D4ED24	2017-08-02 08:34:00+03	48200.00
D4EDBE	2017-08-10 17:33:00+03	18000.00
D4EDFD	2017-08-12 11:30:00+03	65200.00
D4EE15	2017-08-06 08:03:00+03	25100.00
D4EEC6	2017-07-22 20:46:00+03	31600.00
D4EF0C	2017-07-09 19:10:00+03	174000.00
D4EF47	2017-07-11 01:19:00+03	312000.00
D4EFC4	2017-07-11 04:10:00+03	52900.00
D4EFED	2017-07-24 22:26:00+03	43500.00
D4F0FB	2017-07-21 06:08:00+03	81700.00
D4F0FE	2017-07-04 05:24:00+03	29600.00
D4F106	2017-07-20 18:12:00+03	6800.00
D4F16C	2017-07-26 14:55:00+03	56000.00
D4F197	2017-07-18 20:01:00+03	67600.00
D4F1B8	2017-08-08 17:51:00+03	150200.00
D4F1F7	2017-07-27 18:12:00+03	22000.00
D4F20E	2017-08-13 06:19:00+03	46400.00
D4F25D	2017-08-05 15:47:00+03	533300.00
D4F268	2017-07-21 11:56:00+03	93900.00
D4F2AC	2017-07-03 21:19:00+03	93000.00
D4F2C1	2017-08-10 09:29:00+03	56000.00
D4F313	2017-07-29 14:43:00+03	136800.00
D4F31B	2017-08-12 21:06:00+03	78300.00
D4F334	2017-07-17 12:11:00+03	101500.00
D4F398	2017-07-13 03:39:00+03	31400.00
D4F3B6	2017-07-16 23:38:00+03	15400.00
D4F3ED	2017-07-13 18:35:00+03	14400.00
D4F41A	2017-08-06 12:39:00+03	7400.00
D4F444	2017-07-15 19:45:00+03	49400.00
D4F46C	2017-08-14 14:32:00+03	29000.00
D4F48A	2017-07-08 11:05:00+03	39300.00
D4F499	2017-07-29 12:33:00+03	110000.00
D4F4C7	2017-07-06 06:04:00+03	114600.00
D4F4FF	2017-07-26 18:39:00+03	22000.00
D4F500	2017-07-24 22:30:00+03	23200.00
D4F50C	2017-07-22 03:14:00+03	46400.00
D4F54A	2017-07-11 22:22:00+03	40800.00
D4F58A	2017-07-18 01:29:00+03	48800.00
D4F653	2017-07-27 09:30:00+03	36900.00
D4F6A8	2017-08-12 02:19:00+03	50800.00
D4F707	2017-07-22 07:56:00+03	40800.00
D4F741	2017-08-07 21:37:00+03	48800.00
D4F74F	2017-08-12 16:06:00+03	139100.00
D4F792	2017-07-31 02:11:00+03	148200.00
D4F7B5	2017-07-12 08:49:00+03	140200.00
D4F824	2017-07-25 03:59:00+03	65900.00
D4F83B	2017-07-05 18:32:00+03	55800.00
D4F854	2017-08-05 17:55:00+03	33300.00
D4F869	2017-07-28 12:27:00+03	32700.00
D4F872	2017-07-09 03:02:00+03	534300.00
D4F981	2017-08-03 02:31:00+03	33400.00
D4F9BD	2017-07-27 23:54:00+03	83600.00
D4F9F0	2017-07-18 07:20:00+03	29600.00
D4FA38	2017-08-01 09:39:00+03	153300.00
D4FABF	2017-07-09 04:49:00+03	31400.00
D4FAF4	2017-07-20 15:37:00+03	136200.00
D4FB59	2017-08-02 20:37:00+03	56000.00
D4FB8A	2017-07-25 11:41:00+03	41300.00
D4FBC2	2017-07-05 00:11:00+03	84100.00
D4FBCB	2017-08-04 00:58:00+03	47000.00
D4FC0D	2017-07-22 12:28:00+03	136200.00
D4FC23	2017-07-28 11:30:00+03	11800.00
D4FC45	2017-07-04 20:07:00+03	136000.00
D4FCF5	2017-07-20 16:32:00+03	25400.00
D4FD06	2017-07-18 22:50:00+03	90000.00
D4FD42	2017-07-12 22:38:00+03	25600.00
D4FD59	2017-07-14 13:15:00+03	67800.00
D4FDAE	2017-08-02 09:06:00+03	44600.00
D4FE61	2017-07-03 13:18:00+03	123000.00
D4FE72	2017-07-05 03:36:00+03	28800.00
D4FEB7	2017-07-30 00:29:00+03	123000.00
D4FED2	2017-08-10 08:44:00+03	270700.00
D4FF64	2017-07-16 14:42:00+03	61800.00
D4FF92	2017-07-08 15:10:00+03	15000.00
D4FFA6	2017-08-15 12:18:00+03	57300.00
D4FFC2	2017-07-28 05:12:00+03	30200.00
D4FFFA	2017-07-20 06:08:00+03	16400.00
D50033	2017-07-25 13:41:00+03	14400.00
D50044	2017-08-03 00:37:00+03	239000.00
D5004B	2017-07-08 17:51:00+03	103000.00
D50053	2017-07-13 06:07:00+03	32800.00
D5005B	2017-08-13 22:35:00+03	101200.00
D5007A	2017-07-15 06:08:00+03	49200.00
D5007C	2017-07-28 17:37:00+03	21200.00
D50096	2017-08-09 22:49:00+03	60400.00
D500C2	2017-07-07 00:21:00+03	115600.00
D500D0	2017-07-11 00:10:00+03	92900.00
D500E3	2017-08-09 21:56:00+03	185400.00
D500EB	2017-07-14 19:01:00+03	98400.00
D5014B	2017-07-08 07:52:00+03	47000.00
D50160	2017-07-08 03:04:00+03	66300.00
D501BB	2017-07-04 22:30:00+03	92600.00
D501C0	2017-08-03 12:12:00+03	111600.00
D501D8	2017-08-13 07:03:00+03	89700.00
D501FB	2017-07-11 10:53:00+03	135000.00
D50214	2017-07-29 07:04:00+03	29800.00
D50217	2017-08-01 10:22:00+03	75400.00
D50265	2017-07-28 02:23:00+03	68400.00
D502A6	2017-07-23 12:08:00+03	44500.00
D502ED	2017-07-19 06:45:00+03	136600.00
D50307	2017-07-27 22:00:00+03	174200.00
D5031D	2017-07-20 02:38:00+03	147100.00
D503C1	2017-07-11 18:47:00+03	23600.00
D503F5	2017-08-03 00:31:00+03	79800.00
D50442	2017-07-21 00:00:00+03	19600.00
D5047C	2017-08-09 18:03:00+03	50000.00
D5047F	2017-07-31 08:29:00+03	39500.00
D5049F	2017-07-13 08:24:00+03	24400.00
D504D3	2017-07-16 03:45:00+03	51600.00
D504E4	2017-08-14 16:26:00+03	133200.00
D504EC	2017-07-19 02:34:00+03	664200.00
D50523	2017-07-15 04:08:00+03	45200.00
D5054D	2017-07-25 02:24:00+03	167700.00
D5056C	2017-08-15 10:17:00+03	31600.00
D50583	2017-07-31 03:53:00+03	59300.00
D5059B	2017-07-23 15:38:00+03	13200.00
D505AF	2017-08-06 19:59:00+03	85700.00
D505C2	2017-07-21 20:16:00+03	101200.00
D505D9	2017-06-30 18:27:00+03	40000.00
D505DA	2017-07-27 15:48:00+03	23200.00
D50612	2017-08-07 18:11:00+03	43200.00
D50655	2017-08-14 00:45:00+03	112000.00
D5065D	2017-07-02 15:32:00+03	25400.00
D50687	2017-07-15 08:12:00+03	55800.00
D506D6	2017-07-18 21:00:00+03	26000.00
D506E4	2017-07-07 13:03:00+03	112000.00
D50710	2017-08-08 11:07:00+03	14000.00
D5073C	2017-08-04 12:38:00+03	6000.00
D50781	2017-08-01 20:39:00+03	8600.00
D507AA	2017-07-10 12:04:00+03	264100.00
D507AC	2017-07-15 00:37:00+03	22600.00
D507C8	2017-08-15 14:43:00+03	184300.00
D5082B	2017-07-05 11:35:00+03	66800.00
D508D4	2017-07-17 06:12:00+03	45500.00
D508D9	2017-07-03 07:04:00+03	45200.00
D50922	2017-08-08 01:47:00+03	45200.00
D50974	2017-07-24 16:19:00+03	98000.00
D50979	2017-08-14 15:28:00+03	12400.00
D50A46	2017-08-09 15:08:00+03	9800.00
D50A6F	2017-08-06 20:46:00+03	120800.00
D50AA4	2017-08-07 02:54:00+03	290400.00
D50B60	2017-08-13 23:13:00+03	248300.00
D50B84	2017-08-06 05:43:00+03	510300.00
D50BBE	2017-08-13 09:48:00+03	50400.00
D50BD4	2017-06-29 07:41:00+03	80800.00
D50BE6	2017-07-04 10:30:00+03	67600.00
D50C46	2017-07-26 21:49:00+03	55800.00
D50C52	2017-08-09 20:34:00+03	40800.00
D50C5E	2017-08-14 00:32:00+03	14000.00
D50C84	2017-07-08 07:03:00+03	103900.00
D50CC2	2017-08-12 12:58:00+03	26000.00
D50CDB	2017-07-26 17:50:00+03	12600.00
D50D0A	2017-07-13 22:01:00+03	28000.00
D50D1E	2017-08-13 17:13:00+03	62000.00
D50D72	2017-08-11 22:28:00+03	28000.00
D50D9E	2017-07-15 06:34:00+03	116700.00
D50E16	2017-07-12 13:59:00+03	133100.00
D50E7B	2017-08-14 19:13:00+03	404300.00
D50EBA	2017-08-09 02:47:00+03	58400.00
D50ED7	2017-07-06 08:32:00+03	37200.00
D50ED8	2017-08-04 00:06:00+03	35200.00
D50EFC	2017-07-10 12:03:00+03	16400.00
D50F2B	2017-07-21 00:46:00+03	147900.00
D50F51	2017-07-31 20:15:00+03	56900.00
D50F60	2017-08-04 23:42:00+03	59800.00
D50F69	2017-08-14 17:31:00+03	26000.00
D50F75	2017-08-11 09:22:00+03	391300.00
D51060	2017-07-04 23:17:00+03	112600.00
D51079	2017-08-05 08:31:00+03	132800.00
D510A1	2017-07-30 22:12:00+03	98300.00
D510E0	2017-08-10 02:08:00+03	55800.00
D5117C	2017-07-30 12:56:00+03	70600.00
D51281	2017-07-03 15:28:00+03	92100.00
D512C7	2017-08-01 17:30:00+03	28800.00
D512CC	2017-07-11 03:11:00+03	137800.00
D513A2	2017-08-07 16:11:00+03	301800.00
D513D5	2017-07-10 05:59:00+03	14400.00
D5141C	2017-07-28 17:28:00+03	55800.00
D51501	2017-07-23 06:18:00+03	136800.00
D515A3	2017-07-26 22:30:00+03	85000.00
D515A4	2017-07-27 02:07:00+03	100600.00
D515F8	2017-07-31 16:17:00+03	170200.00
D51614	2017-08-08 07:59:00+03	8200.00
D51630	2017-07-25 23:02:00+03	131100.00
D516FA	2017-08-10 05:13:00+03	40500.00
D5174F	2017-07-08 21:16:00+03	248500.00
D51773	2017-07-01 10:42:00+03	15000.00
D5179E	2017-08-13 02:49:00+03	38400.00
D517C1	2017-07-05 13:51:00+03	44700.00
D5188D	2017-07-17 13:24:00+03	240600.00
D518F4	2017-07-06 14:25:00+03	70800.00
D51908	2017-08-08 23:44:00+03	126900.00
D51935	2017-07-24 14:22:00+03	36200.00
D519BB	2017-08-13 12:13:00+03	62100.00
D519C6	2017-08-03 16:03:00+03	38400.00
D51A1E	2017-07-14 17:53:00+03	47100.00
D51A6C	2017-07-15 03:53:00+03	266400.00
D51AAF	2017-08-10 01:51:00+03	79600.00
D51B25	2017-07-30 01:57:00+03	30200.00
D51B4E	2017-07-29 22:54:00+03	59000.00
D51B51	2017-07-13 19:50:00+03	77500.00
D51C42	2017-07-13 16:04:00+03	84500.00
D51C5C	2017-07-15 17:35:00+03	28800.00
D51C61	2017-07-10 05:09:00+03	369000.00
D51C73	2017-07-28 03:46:00+03	132800.00
D51CB8	2017-08-04 04:35:00+03	14000.00
D51D2A	2017-08-11 15:18:00+03	35300.00
D51D79	2017-07-14 14:47:00+03	168300.00
D51D96	2017-07-13 21:53:00+03	75900.00
D51DBB	2017-08-01 12:15:00+03	40800.00
D51E92	2017-08-05 00:32:00+03	135200.00
D51EA6	2017-07-08 02:01:00+03	205100.00
D51ED9	2017-07-22 03:06:00+03	54800.00
D51FB0	2017-07-07 06:00:00+03	107700.00
D51FEF	2017-07-11 07:36:00+03	79600.00
D51FFA	2017-08-05 09:02:00+03	17200.00
D52028	2017-07-09 00:38:00+03	39900.00
D5203B	2017-06-30 15:23:00+03	26800.00
D52088	2017-07-18 23:15:00+03	57800.00
D520DD	2017-07-19 17:32:00+03	54000.00
D521AA	2017-07-07 17:38:00+03	33400.00
D521C6	2017-07-08 07:32:00+03	27300.00
D521DD	2017-07-01 18:57:00+03	73000.00
D52261	2017-07-12 10:54:00+03	56900.00
D522DC	2017-08-10 21:17:00+03	75600.00
D522F2	2017-07-26 00:44:00+03	62800.00
D52365	2017-07-15 03:30:00+03	46500.00
D523C7	2017-08-04 02:01:00+03	44600.00
D52427	2017-07-02 11:14:00+03	84500.00
D52448	2017-07-29 15:06:00+03	47600.00
D5244B	2017-08-11 05:05:00+03	9200.00
D52450	2017-07-13 03:09:00+03	267100.00
D5247C	2017-07-11 10:21:00+03	13400.00
D524A8	2017-07-12 05:58:00+03	123900.00
D52504	2017-08-09 13:45:00+03	79800.00
D5253C	2017-08-12 11:18:00+03	38200.00
D5256B	2017-07-07 14:37:00+03	120400.00
D52586	2017-07-19 06:39:00+03	95600.00
D525A6	2017-07-13 16:53:00+03	24400.00
D525AD	2017-07-29 13:12:00+03	34200.00
D52634	2017-07-27 12:51:00+03	220600.00
D526A4	2017-07-14 11:51:00+03	7300.00
D527D2	2017-07-07 13:35:00+03	31800.00
D527F4	2017-07-15 12:46:00+03	8000.00
D52819	2017-08-14 12:54:00+03	38800.00
D52829	2017-07-01 19:06:00+03	40000.00
D5286C	2017-08-14 01:08:00+03	68100.00
D52905	2017-07-13 15:44:00+03	126300.00
D529E7	2017-07-09 08:43:00+03	311200.00
D52A89	2017-06-29 21:31:00+03	13500.00
D52ABB	2017-07-13 11:31:00+03	23200.00
D52AEF	2017-07-02 00:32:00+03	54400.00
D52B45	2017-07-01 08:05:00+03	24200.00
D52B79	2017-07-25 01:51:00+03	123000.00
D52B9E	2017-08-01 11:33:00+03	148200.00
D52BD8	2017-07-29 20:29:00+03	73600.00
D52CB6	2017-08-07 10:41:00+03	6900.00
D52CFC	2017-07-02 15:21:00+03	48500.00
D52D35	2017-07-11 09:48:00+03	133900.00
D52D82	2017-07-18 09:22:00+03	149300.00
D52DA2	2017-08-06 14:52:00+03	32300.00
D52E02	2017-07-31 01:39:00+03	46400.00
D52E1A	2017-07-05 05:05:00+03	24800.00
D52E33	2017-07-05 07:14:00+03	38200.00
D52E59	2017-07-27 14:39:00+03	67700.00
D52E79	2017-08-07 02:31:00+03	30400.00
D52E9F	2017-07-18 20:30:00+03	56600.00
D52EB1	2017-07-24 15:48:00+03	54800.00
D52ED4	2017-08-15 12:01:00+03	42600.00
D52F03	2017-07-09 11:40:00+03	7400.00
D52F33	2017-07-22 01:19:00+03	30200.00
D52F47	2017-08-11 13:25:00+03	139400.00
D52F5E	2017-08-05 19:08:00+03	25600.00
D52F97	2017-08-11 03:34:00+03	71200.00
D52FD8	2017-08-01 11:32:00+03	6800.00
D52FDE	2017-07-28 04:25:00+03	68400.00
D53017	2017-07-31 09:32:00+03	378400.00
D53026	2017-07-07 08:37:00+03	24600.00
D53037	2017-06-28 23:40:00+03	59800.00
D53057	2017-08-13 17:07:00+03	56000.00
D5306D	2017-07-27 07:17:00+03	26700.00
D53073	2017-07-22 19:11:00+03	55800.00
D53092	2017-07-01 09:44:00+03	46400.00
D530C1	2017-07-17 07:33:00+03	56600.00
D530E7	2017-07-24 01:52:00+03	155600.00
D530F8	2017-07-26 10:40:00+03	14000.00
D53113	2017-07-23 23:58:00+03	34600.00
D53114	2017-08-04 23:53:00+03	58200.00
D53167	2017-07-12 14:15:00+03	265600.00
D531A7	2017-08-09 06:11:00+03	6800.00
D531E0	2017-07-07 10:14:00+03	233000.00
D5321D	2017-06-30 21:42:00+03	52000.00
D53238	2017-07-22 08:06:00+03	18000.00
D53250	2017-08-11 05:11:00+03	77700.00
D53284	2017-06-27 22:30:00+03	168000.00
D533E4	2017-07-25 10:29:00+03	24700.00
D533E9	2017-07-10 15:59:00+03	50700.00
D53447	2017-07-08 11:20:00+03	119300.00
D534B1	2017-07-21 11:37:00+03	67200.00
D534C8	2017-08-11 14:47:00+03	134600.00
D534E1	2017-07-06 02:09:00+03	103500.00
D5352E	2017-07-10 23:01:00+03	58400.00
D535A0	2017-08-02 11:27:00+03	58900.00
D535B0	2017-07-09 13:18:00+03	55600.00
D5363A	2017-07-01 18:23:00+03	144400.00
D536EC	2017-07-14 01:23:00+03	62100.00
D53707	2017-08-01 20:00:00+03	145300.00
D53792	2017-07-09 12:48:00+03	83000.00
D537FC	2017-07-10 06:27:00+03	160800.00
D53838	2017-07-06 02:36:00+03	46400.00
D538DE	2017-08-12 18:55:00+03	12400.00
D538ED	2017-07-19 05:37:00+03	187800.00
D53904	2017-08-02 01:25:00+03	8400.00
D53952	2017-07-30 01:50:00+03	59100.00
D53970	2017-07-22 01:10:00+03	67200.00
D53A4C	2017-08-01 07:05:00+03	50600.00
D53A5D	2017-06-29 14:20:00+03	22000.00
D53A6B	2017-08-01 08:21:00+03	29600.00
D53ABA	2017-07-08 14:03:00+03	31600.00
D53B35	2017-07-09 18:15:00+03	169300.00
D53B4C	2017-07-05 12:05:00+03	21200.00
D53BA4	2017-08-07 01:35:00+03	21200.00
D53BF1	2017-07-08 22:38:00+03	131800.00
D53BF5	2017-07-02 22:32:00+03	199800.00
D53C7C	2017-08-04 17:18:00+03	40800.00
D53CD6	2017-08-08 04:29:00+03	179400.00
D53CE3	2017-07-16 08:07:00+03	257500.00
D53CF0	2017-07-04 01:28:00+03	40000.00
D53D3C	2017-08-04 00:39:00+03	60800.00
D53D45	2017-07-30 10:52:00+03	133200.00
D53DF0	2017-07-21 03:00:00+03	257500.00
D53E14	2017-07-24 00:17:00+03	22000.00
D53E1B	2017-06-28 23:37:00+03	18600.00
D53E8B	2017-07-29 09:57:00+03	23200.00
D53F3F	2017-07-27 00:00:00+03	271100.00
D53F70	2017-07-05 09:49:00+03	133200.00
D53F73	2017-07-14 09:02:00+03	26000.00
D53FA8	2017-07-30 19:13:00+03	76100.00
D53FAA	2017-06-30 17:17:00+03	85000.00
D53FF6	2017-07-12 23:40:00+03	67200.00
D54088	2017-07-13 06:37:00+03	31600.00
D540C5	2017-07-09 02:20:00+03	135600.00
D540C9	2017-07-17 04:32:00+03	424600.00
D5411B	2017-07-04 16:31:00+03	42900.00
D5414D	2017-07-15 17:11:00+03	115700.00
D54183	2017-08-06 13:26:00+03	55800.00
D541F1	2017-07-21 12:49:00+03	73600.00
D5422A	2017-07-09 14:11:00+03	77900.00
D5426F	2017-07-30 02:23:00+03	106800.00
D54284	2017-08-03 02:11:00+03	69500.00
D542AE	2017-08-01 23:04:00+03	133200.00
D542B9	2017-08-08 16:19:00+03	15000.00
D542C4	2017-07-30 13:43:00+03	143100.00
D542D4	2017-08-09 12:11:00+03	126700.00
D542E3	2017-07-07 11:36:00+03	283000.00
D5433E	2017-07-21 18:12:00+03	73600.00
D54344	2017-07-07 14:31:00+03	67600.00
D5435A	2017-06-27 06:04:00+03	406200.00
D54381	2017-07-13 06:42:00+03	84100.00
D54421	2017-07-31 08:28:00+03	76900.00
D54438	2017-07-15 03:21:00+03	24800.00
D5450B	2017-07-12 04:13:00+03	62600.00
D54552	2017-07-29 16:20:00+03	81300.00
D54582	2017-08-13 14:16:00+03	75300.00
D545CE	2017-07-18 23:13:00+03	56000.00
D5460A	2017-07-23 11:01:00+03	68800.00
D54628	2017-07-06 08:03:00+03	188300.00
D5463A	2017-07-14 00:41:00+03	20200.00
D546AA	2017-07-15 09:30:00+03	29400.00
D546B7	2017-07-09 22:08:00+03	107900.00
D546CC	2017-07-19 01:19:00+03	34800.00
D54717	2017-07-08 00:15:00+03	69700.00
D5479D	2017-07-31 11:42:00+03	135200.00
D547FF	2017-07-16 02:29:00+03	16400.00
D54825	2017-07-04 02:58:00+03	24800.00
D54826	2017-07-06 17:07:00+03	58400.00
D5483F	2017-08-14 22:02:00+03	142400.00
D54892	2017-07-30 23:22:00+03	92800.00
D548B7	2017-08-06 13:17:00+03	7400.00
D548BC	2017-07-09 16:26:00+03	91500.00
D548D9	2017-08-13 16:03:00+03	25100.00
D5490B	2017-07-11 10:18:00+03	59300.00
D54945	2017-06-29 01:36:00+03	45000.00
D54957	2017-07-27 20:23:00+03	32700.00
D549CE	2017-07-12 04:14:00+03	114700.00
D54A6F	2017-08-10 10:21:00+03	103000.00
D54A7B	2017-07-11 16:11:00+03	116400.00
D54A7E	2017-08-12 01:44:00+03	28800.00
D54A7F	2017-07-28 21:28:00+03	71900.00
D54A8F	2017-08-04 11:21:00+03	26600.00
D54A96	2017-07-21 07:54:00+03	25100.00
D54AAC	2017-07-08 10:33:00+03	174600.00
D54AC9	2017-07-10 05:07:00+03	25600.00
D54B1E	2017-08-08 06:11:00+03	29000.00
D54B5C	2017-07-31 18:40:00+03	80600.00
D54C00	2017-07-24 04:59:00+03	26800.00
D54C38	2017-07-05 19:37:00+03	73300.00
D54C64	2017-07-16 15:02:00+03	23200.00
D54C69	2017-08-03 14:51:00+03	56000.00
D54CB1	2017-08-12 13:42:00+03	37100.00
D54CDF	2017-08-06 22:41:00+03	54000.00
D54E38	2017-08-13 04:51:00+03	37600.00
D54E4C	2017-07-10 05:07:00+03	16800.00
D54E7E	2017-07-23 17:51:00+03	6000.00
D54E9A	2017-07-26 17:45:00+03	47000.00
D54EC0	2017-07-12 02:04:00+03	47000.00
D54F1D	2017-07-10 13:25:00+03	39500.00
D54F3F	2017-08-07 14:17:00+03	6600.00
D54F40	2017-08-10 11:18:00+03	135400.00
D54F84	2017-08-01 20:41:00+03	155600.00
D5506B	2017-07-11 13:48:00+03	29400.00
D5512D	2017-07-12 01:06:00+03	42400.00
D55180	2017-08-11 17:31:00+03	12400.00
D551AF	2017-07-23 20:43:00+03	43300.00
D5524C	2017-07-26 07:56:00+03	18300.00
D55262	2017-07-06 00:48:00+03	31200.00
D55267	2017-08-02 01:24:00+03	62400.00
D5526E	2017-07-08 07:48:00+03	100600.00
D55281	2017-08-01 21:44:00+03	119500.00
D55292	2017-07-02 22:31:00+03	19600.00
D55296	2017-07-11 05:28:00+03	35600.00
D552CC	2017-08-07 16:04:00+03	46400.00
D553CD	2017-07-05 23:47:00+03	83600.00
D553E4	2017-08-10 13:41:00+03	111400.00
D553FD	2017-07-26 15:07:00+03	123600.00
D55495	2017-07-24 04:31:00+03	36800.00
D5554B	2017-07-15 09:41:00+03	274200.00
D555BA	2017-08-09 13:45:00+03	131600.00
D55602	2017-08-06 18:41:00+03	52300.00
D55612	2017-07-06 01:35:00+03	36400.00
D55634	2017-07-13 21:05:00+03	47600.00
D55643	2017-07-23 02:21:00+03	46000.00
D55651	2017-08-07 23:42:00+03	36200.00
D55689	2017-07-12 14:22:00+03	13400.00
D55698	2017-08-08 23:51:00+03	42400.00
D556AE	2017-07-29 23:34:00+03	53700.00
D556DD	2017-07-13 10:30:00+03	198300.00
D55711	2017-07-25 06:04:00+03	104200.00
D55757	2017-08-10 18:43:00+03	190700.00
D55798	2017-08-09 12:17:00+03	38200.00
D557A6	2017-08-05 10:21:00+03	48900.00
D557C5	2017-07-05 02:24:00+03	47200.00
D557C8	2017-07-21 21:19:00+03	39800.00
D557ED	2017-08-02 00:59:00+03	57500.00
D557F2	2017-07-25 22:50:00+03	399600.00
D55806	2017-07-30 23:37:00+03	6000.00
D558B1	2017-07-01 20:49:00+03	265800.00
D558CA	2017-08-02 21:25:00+03	112000.00
D558E2	2017-07-12 14:02:00+03	21400.00
D558E7	2017-07-02 11:57:00+03	51900.00
D559F3	2017-08-11 05:55:00+03	33800.00
D55A3D	2017-07-25 07:12:00+03	42700.00
D55A44	2017-08-03 23:14:00+03	199700.00
D55AB5	2017-08-15 07:45:00+03	20800.00
D55ACD	2017-08-15 16:39:00+03	44700.00
D55B0A	2017-07-26 05:00:00+03	42200.00
D55B24	2017-07-28 23:10:00+03	188000.00
D55BAA	2017-08-14 11:22:00+03	344100.00
D55BDA	2017-07-06 10:05:00+03	25000.00
D55C29	2017-07-11 07:25:00+03	61800.00
D55C3A	2017-08-03 02:34:00+03	67000.00
D55D2B	2017-07-17 06:31:00+03	130000.00
D55D5C	2017-07-11 19:02:00+03	37200.00
D55DA9	2017-07-13 22:17:00+03	124400.00
D55DC3	2017-07-24 13:56:00+03	36400.00
D55E16	2017-07-21 05:12:00+03	88200.00
D55E38	2017-07-19 23:53:00+03	31400.00
D55E39	2017-07-16 10:51:00+03	58000.00
D55E50	2017-08-14 02:05:00+03	44000.00
D55E78	2017-07-31 14:50:00+03	30200.00
D55E91	2017-08-06 14:45:00+03	32400.00
D55E98	2017-07-14 22:23:00+03	68100.00
D55F53	2017-07-14 19:35:00+03	24200.00
D55F8C	2017-08-14 14:55:00+03	137400.00
D55FA5	2017-07-18 00:20:00+03	542100.00
D56065	2017-07-05 15:10:00+03	43000.00
D560A1	2017-08-07 08:29:00+03	49200.00
D560B0	2017-07-20 18:24:00+03	26200.00
D560EA	2017-07-25 20:18:00+03	23600.00
D5612D	2017-07-09 00:37:00+03	246000.00
D56183	2017-07-04 23:19:00+03	34000.00
D561B1	2017-07-20 07:05:00+03	124100.00
D561BD	2017-08-12 21:05:00+03	65900.00
D561CA	2017-07-18 19:54:00+03	38400.00
D561DE	2017-07-23 06:48:00+03	43500.00
D561FC	2017-08-09 20:16:00+03	23600.00
D56222	2017-07-13 16:40:00+03	162400.00
D56296	2017-08-10 01:24:00+03	42800.00
D562D0	2017-07-18 13:30:00+03	27800.00
D562DA	2017-06-29 02:24:00+03	284400.00
D562FF	2017-08-07 00:15:00+03	43800.00
D56366	2017-07-18 08:51:00+03	45100.00
D5638B	2017-07-11 14:21:00+03	296000.00
D5638D	2017-08-07 20:35:00+03	194800.00
D563F0	2017-07-19 14:32:00+03	6800.00
D56438	2017-08-10 14:38:00+03	71200.00
D56464	2017-07-11 05:46:00+03	6700.00
D5649B	2017-08-06 04:03:00+03	41200.00
D564A9	2017-07-16 23:18:00+03	17800.00
D564B5	2017-07-11 07:56:00+03	118200.00
D564C0	2017-07-30 00:44:00+03	6600.00
D564CC	2017-07-18 17:14:00+03	13600.00
D564D2	2017-08-07 14:06:00+03	68000.00
D564E2	2017-07-22 13:25:00+03	12000.00
D56503	2017-07-28 19:14:00+03	55800.00
D56510	2017-08-10 20:58:00+03	172100.00
D56576	2017-06-29 07:04:00+03	121400.00
D565B1	2017-07-18 19:33:00+03	36200.00
D56676	2017-07-10 10:59:00+03	21000.00
D566EB	2017-07-24 09:58:00+03	27900.00
D56704	2017-07-20 05:57:00+03	48400.00
D56710	2017-07-11 13:01:00+03	26000.00
D5671B	2017-07-21 18:52:00+03	56000.00
D5679D	2017-07-31 20:52:00+03	62000.00
D567C8	2017-07-17 15:11:00+03	111600.00
D56818	2017-07-04 21:36:00+03	29600.00
D56888	2017-08-03 00:33:00+03	52400.00
D568B5	2017-07-19 13:50:00+03	46400.00
D568BE	2017-06-29 14:45:00+03	26000.00
D568F6	2017-07-28 17:36:00+03	48400.00
D568F7	2017-07-04 00:25:00+03	289800.00
D56923	2017-07-20 10:45:00+03	35600.00
D56998	2017-08-09 12:43:00+03	74800.00
D5699B	2017-07-01 11:22:00+03	70800.00
D569AA	2017-07-25 03:44:00+03	38600.00
D569D1	2017-08-04 02:40:00+03	193000.00
D56AD5	2017-08-06 16:32:00+03	56000.00
D56ADF	2017-07-25 10:19:00+03	135400.00
D56AF3	2017-07-08 23:57:00+03	31700.00
D56B1F	2017-07-05 20:44:00+03	17200.00
D56B8C	2017-08-06 21:52:00+03	59800.00
D56B94	2017-07-08 00:04:00+03	54500.00
D56BB8	2017-07-20 14:51:00+03	28800.00
D56C24	2017-07-29 16:10:00+03	115600.00
D56C31	2017-06-30 18:28:00+03	99300.00
D56C6C	2017-07-03 22:56:00+03	89600.00
D56C81	2017-08-09 08:17:00+03	79600.00
D56CCE	2017-08-04 01:18:00+03	27200.00
D56D54	2017-07-02 13:07:00+03	123000.00
D56DA1	2017-08-06 23:26:00+03	21800.00
D56E02	2017-07-28 23:22:00+03	38700.00
D56E2B	2017-08-07 10:03:00+03	43200.00
D56E67	2017-07-27 09:43:00+03	31600.00
D56E81	2017-08-05 06:46:00+03	40800.00
D56E90	2017-08-06 21:08:00+03	20500.00
D56F73	2017-07-10 04:49:00+03	148200.00
D56F95	2017-08-15 02:23:00+03	45000.00
D56FA6	2017-07-17 04:46:00+03	398500.00
D56FB7	2017-07-05 07:06:00+03	6600.00
D56FD6	2017-08-10 06:07:00+03	135200.00
D57033	2017-07-08 06:50:00+03	6600.00
D5708E	2017-08-10 04:44:00+03	30700.00
D570EF	2017-07-09 00:07:00+03	67400.00
D570F8	2017-08-05 23:28:00+03	101200.00
D57104	2017-08-04 12:18:00+03	24400.00
D57112	2017-07-21 22:38:00+03	38400.00
D5713C	2017-07-28 00:41:00+03	34400.00
D5717B	2017-08-14 23:58:00+03	20400.00
D571CD	2017-06-29 03:51:00+03	112000.00
D57215	2017-07-30 04:20:00+03	61800.00
D57228	2017-07-07 22:25:00+03	278700.00
D57254	2017-07-24 06:41:00+03	8200.00
D57263	2017-07-17 21:50:00+03	99800.00
D57269	2017-07-26 06:55:00+03	58400.00
D572A4	2017-08-12 02:46:00+03	34000.00
D57306	2017-06-28 01:35:00+03	36800.00
D57322	2017-08-08 13:28:00+03	56600.00
D57335	2017-07-08 00:16:00+03	28000.00
D57366	2017-07-30 20:05:00+03	123000.00
D5739D	2017-07-14 16:16:00+03	18000.00
D573A2	2017-07-31 05:02:00+03	56000.00
D573D6	2017-07-24 10:25:00+03	88500.00
D57418	2017-07-12 07:10:00+03	24400.00
D57462	2017-07-01 10:18:00+03	123000.00
D574BD	2017-08-09 02:06:00+03	66200.00
D57541	2017-08-03 00:39:00+03	246000.00
D5758D	2017-08-02 21:25:00+03	131800.00
D57603	2017-08-07 22:53:00+03	23200.00
D57640	2017-08-13 17:09:00+03	69500.00
D57647	2017-08-11 23:16:00+03	8600.00
D57657	2017-07-21 02:18:00+03	6700.00
D576C4	2017-08-12 07:52:00+03	40200.00
D57815	2017-08-06 20:51:00+03	7400.00
D57876	2017-07-14 17:45:00+03	57400.00
D5788E	2017-07-26 10:14:00+03	23200.00
D5790E	2017-08-12 01:46:00+03	136800.00
D57933	2017-07-09 21:52:00+03	40400.00
D57946	2017-08-11 10:55:00+03	13200.00
D57A46	2017-07-30 17:19:00+03	84300.00
D57A76	2017-08-07 07:06:00+03	202100.00
D57A7D	2017-07-24 11:27:00+03	279700.00
D57A8F	2017-08-15 13:18:00+03	72400.00
D57ABB	2017-07-08 12:34:00+03	116000.00
D57AC5	2017-08-01 19:25:00+03	44800.00
D57B7A	2017-07-16 06:38:00+03	90300.00
D57BBA	2017-07-03 07:13:00+03	46400.00
D57BF0	2017-07-01 08:03:00+03	79900.00
D57C8E	2017-08-08 11:02:00+03	46000.00
D57C9A	2017-07-17 17:17:00+03	109900.00
D57CB0	2017-08-01 06:36:00+03	133100.00
D57D09	2017-07-24 19:42:00+03	71100.00
D57D21	2017-06-30 09:06:00+03	131600.00
D57E1E	2017-08-11 04:05:00+03	6000.00
D57E29	2017-08-08 12:13:00+03	104800.00
D57E39	2017-07-18 04:13:00+03	74800.00
D57E3E	2017-08-15 07:02:00+03	26000.00
D57E8B	2017-07-09 04:27:00+03	133200.00
D57EA0	2017-07-16 21:01:00+03	77000.00
D57ED0	2017-07-17 22:50:00+03	10300.00
D57F61	2017-07-04 10:40:00+03	131600.00
D57F88	2017-07-19 07:38:00+03	78500.00
D57FB6	2017-07-27 06:56:00+03	6900.00
D57FE1	2017-08-12 11:53:00+03	6200.00
D57FFF	2017-07-08 22:41:00+03	258400.00
D580DF	2017-08-05 12:23:00+03	43800.00
D58173	2017-07-09 10:54:00+03	34000.00
D581BE	2017-08-04 12:43:00+03	73500.00
D58202	2017-07-08 08:25:00+03	18300.00
D5824B	2017-08-07 14:45:00+03	136000.00
D582FE	2017-07-23 19:03:00+03	155600.00
D582FF	2017-07-07 13:14:00+03	13700.00
D5832F	2017-08-09 06:48:00+03	357600.00
D583A1	2017-08-08 16:14:00+03	171400.00
D583CE	2017-07-21 19:24:00+03	17000.00
D583F6	2017-07-18 11:24:00+03	74300.00
D584A2	2017-07-03 15:08:00+03	72300.00
D584A3	2017-07-06 05:53:00+03	33600.00
D585F0	2017-07-31 08:02:00+03	67600.00
D586B8	2017-07-31 14:01:00+03	73600.00
D586D9	2017-08-10 08:43:00+03	65600.00
D58841	2017-07-24 05:44:00+03	67600.00
D588E5	2017-07-08 00:20:00+03	20200.00
D5892C	2017-07-05 15:07:00+03	80300.00
D58939	2017-06-28 06:58:00+03	108900.00
D58952	2017-07-24 07:21:00+03	15100.00
D5895D	2017-08-03 19:36:00+03	45300.00
D58A39	2017-07-22 12:23:00+03	10800.00
D58A87	2017-08-06 13:16:00+03	6700.00
D58A9D	2017-07-23 14:03:00+03	43600.00
D58AF5	2017-08-14 07:34:00+03	111600.00
D58C31	2017-08-15 12:37:00+03	22100.00
D58D05	2017-07-08 20:41:00+03	73300.00
D58D0B	2017-07-24 04:26:00+03	166000.00
D58D4A	2017-07-01 19:32:00+03	97900.00
D58D8F	2017-08-13 00:11:00+03	14700.00
D58E79	2017-08-07 15:41:00+03	62600.00
D58E7A	2017-07-20 10:57:00+03	23200.00
D58EF7	2017-07-22 10:03:00+03	56900.00
D58F0B	2017-08-08 18:30:00+03	266400.00
D58F20	2017-08-02 12:48:00+03	40800.00
D58F89	2017-07-31 01:03:00+03	205400.00
D58F91	2017-07-30 15:35:00+03	69600.00
D58FD8	2017-07-28 13:27:00+03	67400.00
D59010	2017-07-22 16:58:00+03	26700.00
D5908D	2017-07-15 06:46:00+03	27300.00
D590DC	2017-08-12 04:45:00+03	67600.00
D590EA	2017-07-20 11:29:00+03	38000.00
D590FA	2017-08-13 09:34:00+03	111600.00
D5913D	2017-08-06 04:46:00+03	43700.00
D59177	2017-07-17 03:38:00+03	123000.00
D591A9	2017-07-31 18:22:00+03	66400.00
D591BA	2017-06-29 18:39:00+03	20400.00
D591E7	2017-07-08 11:11:00+03	22000.00
D591F1	2017-07-23 09:11:00+03	40400.00
D591F2	2017-08-08 08:02:00+03	25200.00
D59246	2017-08-04 13:09:00+03	88600.00
D59253	2017-07-28 12:45:00+03	36200.00
D592DB	2017-07-15 02:17:00+03	32700.00
D59328	2017-07-18 09:36:00+03	54500.00
D59340	2017-07-17 01:53:00+03	20400.00
D5938D	2017-07-27 03:32:00+03	244200.00
D5939A	2017-07-20 20:24:00+03	369000.00
D593F8	2017-07-16 06:08:00+03	80100.00
D5940D	2017-07-13 14:55:00+03	58600.00
D59423	2017-08-09 09:37:00+03	36100.00
D594BC	2017-08-07 19:00:00+03	64100.00
D594FE	2017-08-11 02:16:00+03	37900.00
D5952B	2017-07-27 12:31:00+03	252200.00
D595AE	2017-08-15 10:25:00+03	56000.00
D595CA	2017-07-14 09:56:00+03	97400.00
D595F4	2017-08-09 19:40:00+03	34000.00
D5960B	2017-08-02 20:56:00+03	37200.00
D59660	2017-07-05 23:02:00+03	114600.00
D596F4	2017-07-29 10:48:00+03	113200.00
D5971D	2017-07-13 16:27:00+03	111600.00
D5972F	2017-08-10 22:52:00+03	283000.00
D59779	2017-07-28 20:25:00+03	28800.00
D59802	2017-07-06 19:05:00+03	37500.00
D59826	2017-07-10 11:12:00+03	24800.00
D598AA	2017-07-01 00:32:00+03	139300.00
D598D5	2017-08-03 04:34:00+03	92100.00
D598E2	2017-07-14 21:33:00+03	23200.00
D598F3	2017-08-09 05:59:00+03	62000.00
D5997B	2017-08-06 15:28:00+03	23200.00
D599F4	2017-07-26 21:00:00+03	68500.00
D59A6D	2017-08-07 10:40:00+03	40600.00
D59AA5	2017-07-08 15:54:00+03	43200.00
D59AB4	2017-07-17 08:24:00+03	35700.00
D59AD2	2017-08-07 17:06:00+03	19600.00
D59AE4	2017-08-06 03:18:00+03	73600.00
D59B0D	2017-07-11 16:25:00+03	9200.00
D59B44	2017-08-14 09:30:00+03	34600.00
D59B45	2017-07-31 18:46:00+03	12400.00
D59B50	2017-08-10 02:29:00+03	32300.00
D59B6A	2017-08-10 07:24:00+03	101900.00
D59B88	2017-07-05 19:21:00+03	48300.00
D59BCE	2017-07-19 15:32:00+03	206400.00
D59C4C	2017-07-10 15:39:00+03	246000.00
D59C63	2017-07-31 21:01:00+03	16400.00
D59C9F	2017-08-13 16:55:00+03	290600.00
D59CC6	2017-08-01 19:37:00+03	58800.00
D59D14	2017-07-14 12:11:00+03	67600.00
D59D42	2017-07-07 11:45:00+03	16400.00
D59D97	2017-08-11 07:54:00+03	27200.00
D59DF0	2017-07-25 06:57:00+03	92800.00
D59E80	2017-07-03 23:31:00+03	25600.00
D59E88	2017-07-04 09:08:00+03	24400.00
D59EA1	2017-07-03 02:35:00+03	24400.00
D59EB5	2017-08-13 12:48:00+03	86200.00
D59F1F	2017-07-08 04:33:00+03	54500.00
D59F2F	2017-07-06 12:10:00+03	63700.00
D59F6D	2017-07-13 12:55:00+03	27800.00
D59F76	2017-07-13 16:36:00+03	117600.00
D59FA3	2017-07-06 09:26:00+03	28800.00
D59FCA	2017-08-07 00:34:00+03	155600.00
D59FCC	2017-07-11 09:35:00+03	55600.00
D5A03B	2017-07-30 04:59:00+03	133200.00
D5A047	2017-08-13 02:52:00+03	124000.00
D5A082	2017-07-21 12:22:00+03	46400.00
D5A0C1	2017-08-09 21:26:00+03	169900.00
D5A102	2017-07-31 11:55:00+03	311200.00
D5A12E	2017-07-29 02:02:00+03	27900.00
D5A170	2017-06-30 22:13:00+03	51900.00
D5A19F	2017-07-21 20:42:00+03	58400.00
D5A1DD	2017-07-09 23:13:00+03	29600.00
D5A245	2017-08-15 16:33:00+03	59100.00
D5A278	2017-07-24 08:11:00+03	154300.00
D5A2BE	2017-08-07 09:09:00+03	153300.00
D5A2D5	2017-07-23 07:24:00+03	46000.00
D5A31F	2017-08-03 00:37:00+03	51900.00
D5A417	2017-08-04 21:22:00+03	44400.00
D5A432	2017-07-13 14:31:00+03	123000.00
D5A44B	2017-07-14 06:12:00+03	26000.00
D5A452	2017-08-08 23:25:00+03	64700.00
D5A4FA	2017-07-13 20:36:00+03	70800.00
D5A532	2017-08-06 01:32:00+03	58200.00
D5A579	2017-08-10 07:59:00+03	23200.00
D5A5A5	2017-07-09 07:30:00+03	93700.00
D5A5F9	2017-08-03 18:39:00+03	136800.00
D5A5FA	2017-07-16 22:55:00+03	52000.00
D5A6B1	2017-07-11 13:04:00+03	31600.00
D5A6BB	2017-06-27 01:34:00+03	26100.00
D5A6D6	2017-08-09 16:47:00+03	40000.00
D5A709	2017-07-15 09:46:00+03	257500.00
D5A760	2017-07-03 19:28:00+03	103500.00
D5A77A	2017-08-06 06:48:00+03	11700.00
D5A90E	2017-07-07 09:23:00+03	40800.00
D5A93E	2017-07-04 20:12:00+03	33100.00
D5AA7F	2017-07-08 08:02:00+03	185300.00
D5AACA	2017-07-29 07:33:00+03	46000.00
D5AB25	2017-07-19 15:54:00+03	50100.00
D5AC4A	2017-08-13 06:02:00+03	131100.00
D5ACD5	2017-08-02 14:27:00+03	121100.00
D5AD0F	2017-08-07 03:41:00+03	186600.00
D5ADA0	2017-07-30 06:05:00+03	26700.00
D5ADB7	2017-08-14 23:19:00+03	92400.00
D5ADC7	2017-08-07 08:37:00+03	46400.00
D5ADE1	2017-07-13 11:55:00+03	76200.00
D5AE3E	2017-07-18 19:23:00+03	92000.00
D5AE80	2017-07-16 02:05:00+03	91500.00
D5AFA8	2017-07-06 09:46:00+03	27200.00
D5AFE3	2017-08-14 04:36:00+03	55800.00
D5B00C	2017-08-11 14:42:00+03	20000.00
D5B072	2017-07-15 16:32:00+03	27900.00
D5B0DF	2017-07-23 10:25:00+03	18100.00
D5B124	2017-08-13 22:58:00+03	36200.00
D5B135	2017-07-16 15:35:00+03	369000.00
D5B177	2017-08-02 18:21:00+03	65900.00
D5B1AD	2017-07-22 04:08:00+03	62400.00
D5B1F9	2017-07-08 14:46:00+03	28800.00
D5B22D	2017-07-02 04:06:00+03	57900.00
D5B2F1	2017-07-26 15:15:00+03	33800.00
D5B33E	2017-07-31 18:00:00+03	88200.00
D5B3B6	2017-08-13 23:16:00+03	26000.00
D5B3D0	2017-08-03 20:45:00+03	34000.00
D5B3D1	2017-07-06 10:00:00+03	124200.00
D5B481	2017-07-18 03:06:00+03	20000.00
D5B4B2	2017-07-08 17:56:00+03	44800.00
D5B4D2	2017-07-27 21:13:00+03	83000.00
D5B4EE	2017-08-02 21:26:00+03	42800.00
D5B507	2017-07-03 21:20:00+03	56600.00
D5B50D	2017-08-08 08:43:00+03	57400.00
D5B520	2017-08-13 00:43:00+03	403900.00
D5B522	2017-08-09 04:13:00+03	64400.00
D5B561	2017-07-03 13:31:00+03	31100.00
D5B570	2017-08-06 03:04:00+03	18000.00
D5B58C	2017-07-24 21:00:00+03	23200.00
D5B5EF	2017-07-05 11:45:00+03	56600.00
D5B611	2017-07-13 17:05:00+03	14000.00
D5B62F	2017-08-07 14:47:00+03	115000.00
D5B650	2017-08-03 15:17:00+03	159200.00
D5B654	2017-07-02 09:29:00+03	81700.00
D5B663	2017-07-24 01:14:00+03	99300.00
D5B6D7	2017-08-05 12:16:00+03	111600.00
D5B78A	2017-08-05 16:27:00+03	116000.00
D5B7F1	2017-07-12 08:24:00+03	21800.00
D5B7F9	2017-07-09 18:59:00+03	36200.00
D5B82B	2017-07-11 14:21:00+03	213200.00
D5B91E	2017-07-12 13:05:00+03	89700.00
D5B9B4	2017-07-19 12:46:00+03	35600.00
D5B9B5	2017-07-20 13:29:00+03	6900.00
D5B9FD	2017-08-10 20:26:00+03	143000.00
D5BA06	2017-08-10 04:13:00+03	83000.00
D5BA43	2017-07-01 10:29:00+03	21400.00
D5BA9A	2017-08-15 04:47:00+03	12000.00
D5BB03	2017-08-10 14:19:00+03	68100.00
D5BB5B	2017-08-01 01:07:00+03	147100.00
D5BBC3	2017-07-22 14:23:00+03	28800.00
D5BC06	2017-07-18 01:11:00+03	31600.00
D5BC0B	2017-07-11 07:14:00+03	93900.00
D5BC25	2017-07-27 03:26:00+03	23600.00
D5BCE2	2017-08-02 20:09:00+03	64400.00
D5BD38	2017-07-22 17:23:00+03	40800.00
D5BDC1	2017-07-30 18:17:00+03	87200.00
D5BDD6	2017-08-14 18:32:00+03	66200.00
D5BDFD	2017-07-14 08:28:00+03	55900.00
D5BEC0	2017-07-18 12:28:00+03	65900.00
D5BFA0	2017-07-14 13:11:00+03	155600.00
D5BFDE	2017-08-13 21:49:00+03	115700.00
D5C005	2017-08-03 22:59:00+03	34100.00
D5C083	2017-07-03 08:16:00+03	37900.00
D5C124	2017-07-25 03:52:00+03	43100.00
D5C18F	2017-07-20 15:32:00+03	22000.00
D5C1B5	2017-08-12 07:21:00+03	138000.00
D5C1B8	2017-08-10 10:56:00+03	272300.00
D5C1C3	2017-07-03 10:45:00+03	58400.00
D5C1FE	2017-08-10 19:58:00+03	170000.00
D5C213	2017-07-21 07:17:00+03	38400.00
D5C250	2017-08-10 06:15:00+03	30800.00
D5C25F	2017-07-11 01:38:00+03	88500.00
D5C262	2017-07-24 10:32:00+03	21400.00
D5C27F	2017-07-13 10:34:00+03	56600.00
D5C2B5	2017-08-05 03:15:00+03	23200.00
D5C399	2017-08-05 19:29:00+03	117600.00
D5C3DF	2017-08-03 13:32:00+03	95200.00
D5C3E2	2017-07-13 21:49:00+03	266400.00
D5C432	2017-08-10 23:40:00+03	115700.00
D5C43E	2017-07-13 08:24:00+03	140900.00
D5C48C	2017-08-02 10:04:00+03	47000.00
D5C4D2	2017-08-14 12:45:00+03	46800.00
D5C581	2017-08-08 23:28:00+03	32800.00
D5C594	2017-07-12 19:06:00+03	23200.00
D5C5A1	2017-07-15 16:46:00+03	28800.00
D5C5B0	2017-07-15 23:49:00+03	112000.00
D5C5D3	2017-08-10 08:46:00+03	318000.00
D5C659	2017-07-20 01:41:00+03	50200.00
D5C685	2017-07-17 01:43:00+03	29600.00
D5C687	2017-08-02 01:47:00+03	32200.00
D5C6C3	2017-08-08 07:13:00+03	46400.00
D5C750	2017-07-19 17:57:00+03	62900.00
D5C7FA	2017-06-29 04:39:00+03	121800.00
D5C838	2017-08-06 21:35:00+03	40800.00
D5C85F	2017-07-19 21:45:00+03	14100.00
D5C8AE	2017-07-15 05:06:00+03	44800.00
D5C8D0	2017-07-02 14:51:00+03	58200.00
D5C904	2017-08-13 22:45:00+03	28800.00
D5C94A	2017-08-03 06:44:00+03	123700.00
D5C95F	2017-07-16 09:21:00+03	27200.00
D5C992	2017-07-17 21:00:00+03	46000.00
D5C9B3	2017-07-25 10:53:00+03	28800.00
D5C9B6	2017-08-14 10:27:00+03	53800.00
D5C9DF	2017-07-09 11:32:00+03	22000.00
D5C9E3	2017-07-16 12:14:00+03	75300.00
D5C9E4	2017-07-05 15:35:00+03	111600.00
D5C9FC	2017-07-05 11:12:00+03	22600.00
D5CA44	2017-06-30 20:01:00+03	6000.00
D5CA5D	2017-08-12 17:55:00+03	71100.00
D5CA6A	2017-08-04 20:06:00+03	52300.00
D5CAA2	2017-08-04 10:09:00+03	54300.00
D5CAD5	2017-08-14 04:06:00+03	33800.00
D5CB49	2017-07-26 16:43:00+03	28000.00
D5CB4E	2017-07-25 12:20:00+03	249300.00
D5CB88	2017-08-14 11:08:00+03	52900.00
D5CB8C	2017-07-02 03:16:00+03	56000.00
D5CB90	2017-07-06 12:34:00+03	35200.00
D5CBE4	2017-07-10 05:15:00+03	46400.00
D5CC19	2017-07-04 08:46:00+03	38800.00
D5CC4C	2017-07-28 02:11:00+03	46000.00
D5CCFE	2017-08-05 04:57:00+03	39500.00
D5CD50	2017-08-11 03:23:00+03	66600.00
D5CDDE	2017-08-14 21:12:00+03	36000.00
D5CDE2	2017-08-04 16:57:00+03	43500.00
D5CDEB	2017-07-31 22:55:00+03	67300.00
D5CE2A	2017-07-06 12:18:00+03	111600.00
D5CE5F	2017-07-25 10:48:00+03	111400.00
D5CE62	2017-07-31 03:02:00+03	106900.00
D5CEB6	2017-07-24 13:46:00+03	170000.00
D5CEF2	2017-06-28 20:19:00+03	110500.00
D5CF24	2017-08-01 15:05:00+03	36600.00
D5CF37	2017-07-25 00:54:00+03	31100.00
D5CF59	2017-08-02 13:49:00+03	372500.00
D5CFB5	2017-07-30 14:54:00+03	7400.00
D5D012	2017-07-13 13:55:00+03	129600.00
D5D06E	2017-07-15 05:19:00+03	72400.00
D5D0E1	2017-08-08 02:09:00+03	33300.00
D5D0FA	2017-07-29 14:39:00+03	100200.00
D5D16F	2017-07-12 02:44:00+03	43500.00
D5D1AE	2017-07-03 08:09:00+03	132800.00
D5D20B	2017-08-11 01:54:00+03	76600.00
D5D275	2017-08-10 14:42:00+03	23200.00
D5D2B4	2017-07-21 03:29:00+03	64800.00
D5D315	2017-08-06 18:27:00+03	39500.00
D5D33B	2017-07-25 20:38:00+03	32800.00
D5D36E	2017-07-01 23:42:00+03	13400.00
D5D3E2	2017-08-08 10:28:00+03	369000.00
D5D44B	2017-08-10 00:31:00+03	76600.00
D5D480	2017-08-02 07:26:00+03	29600.00
D5D4BE	2017-08-10 07:03:00+03	169900.00
D5D4C0	2017-07-30 09:15:00+03	51300.00
D5D4E0	2017-07-21 23:40:00+03	29400.00
D5D53B	2017-07-26 14:54:00+03	50600.00
D5D58E	2017-07-02 16:08:00+03	79900.00
D5D5A8	2017-08-03 21:28:00+03	54800.00
D5D607	2017-08-13 12:29:00+03	86000.00
D5D65B	2017-07-02 22:19:00+03	31200.00
D5D67E	2017-08-12 20:49:00+03	63200.00
D5D692	2017-07-28 16:38:00+03	24400.00
D5D6C6	2017-08-13 06:18:00+03	78600.00
D5D7D1	2017-07-24 15:24:00+03	55800.00
D5D7F7	2017-06-30 03:31:00+03	38800.00
D5D81B	2017-07-20 02:18:00+03	91500.00
D5D845	2017-07-02 07:05:00+03	172100.00
D5D875	2017-07-24 00:36:00+03	43500.00
D5D916	2017-07-02 03:01:00+03	59400.00
D5D96A	2017-07-23 21:56:00+03	100600.00
D5D990	2017-08-07 13:47:00+03	111600.00
D5D9CE	2017-07-21 13:14:00+03	112000.00
D5DAD0	2017-08-13 09:28:00+03	410400.00
D5DB0D	2017-07-13 23:55:00+03	56100.00
D5DB49	2017-07-24 14:03:00+03	42400.00
D5DBDC	2017-07-07 21:56:00+03	36200.00
D5DBEE	2017-08-15 13:42:00+03	40300.00
D5DC03	2017-07-06 07:18:00+03	63200.00
D5DC1C	2017-07-26 09:38:00+03	156500.00
D5DC25	2017-07-09 15:42:00+03	91600.00
D5DC32	2017-08-11 00:36:00+03	26000.00
D5DC4A	2017-07-19 04:03:00+03	68000.00
D5DC6D	2017-08-04 06:21:00+03	206200.00
D5DC93	2017-08-12 23:53:00+03	20600.00
D5DCE6	2017-07-30 00:40:00+03	135400.00
D5DD28	2017-07-24 13:01:00+03	43800.00
D5DD58	2017-07-29 17:56:00+03	23200.00
D5DE0D	2017-08-13 00:09:00+03	28000.00
D5DEA0	2017-07-09 21:38:00+03	28000.00
D5DEBA	2017-07-15 08:28:00+03	48800.00
D5DEF1	2017-07-02 05:00:00+03	246000.00
D5DF12	2017-07-06 13:32:00+03	23400.00
D5DFB6	2017-07-18 05:02:00+03	23400.00
D5DFC3	2017-08-01 06:43:00+03	296400.00
D5E008	2017-08-14 20:15:00+03	403900.00
D5E076	2017-07-13 05:39:00+03	54000.00
D5E109	2017-07-20 16:09:00+03	67600.00
D5E138	2017-08-02 13:30:00+03	129700.00
D5E1A1	2017-07-08 00:47:00+03	65400.00
D5E1A9	2017-07-26 03:08:00+03	29400.00
D5E1E7	2017-08-02 11:52:00+03	67100.00
D5E1F2	2017-08-02 14:18:00+03	181400.00
D5E239	2017-07-25 16:23:00+03	7400.00
D5E25F	2017-08-03 00:56:00+03	86400.00
D5E298	2017-07-07 06:49:00+03	135400.00
D5E2A6	2017-08-12 08:28:00+03	135400.00
D5E32F	2017-08-04 05:08:00+03	89600.00
D5E33F	2017-07-16 15:11:00+03	79000.00
D5E357	2017-08-14 03:59:00+03	46300.00
D5E37F	2017-07-06 17:18:00+03	167400.00
D5E38B	2017-07-21 22:55:00+03	26800.00
D5E39A	2017-07-25 13:59:00+03	246000.00
D5E3C0	2017-07-25 10:09:00+03	117000.00
D5E3DB	2017-07-28 11:26:00+03	68800.00
D5E43D	2017-08-09 05:53:00+03	22900.00
D5E46E	2017-07-04 23:27:00+03	26000.00
D5E4D2	2017-07-08 15:42:00+03	149300.00
D5E512	2017-07-17 20:01:00+03	64300.00
D5E523	2017-08-07 12:04:00+03	75600.00
D5E559	2017-07-22 03:57:00+03	12600.00
D5E56D	2017-08-08 07:37:00+03	49500.00
D5E5C3	2017-08-09 08:40:00+03	21400.00
D5E5C9	2017-07-07 00:07:00+03	37900.00
D5E5E3	2017-08-03 13:18:00+03	135400.00
D5E602	2017-07-09 16:07:00+03	92800.00
D5E612	2017-06-30 15:07:00+03	13400.00
D5E629	2017-08-14 03:10:00+03	55800.00
D5E64D	2017-08-06 11:38:00+03	143100.00
D5E680	2017-06-26 00:31:00+03	246000.00
D5E68C	2017-07-28 22:30:00+03	48700.00
D5E742	2017-08-15 16:01:00+03	57100.00
D5E74D	2017-07-05 23:17:00+03	40000.00
D5E767	2017-07-16 15:22:00+03	14000.00
D5E76C	2017-07-05 07:08:00+03	7200.00
D5E868	2017-07-04 11:05:00+03	56000.00
D5E89B	2017-08-10 13:48:00+03	46000.00
D5E962	2017-07-19 07:55:00+03	60400.00
D5E9A5	2017-06-30 14:58:00+03	105600.00
D5EB46	2017-07-22 07:11:00+03	36200.00
D5EB88	2017-06-30 10:32:00+03	79600.00
D5EBBA	2017-07-07 16:31:00+03	25100.00
D5EBE8	2017-06-27 08:39:00+03	56000.00
D5EC2C	2017-08-05 14:58:00+03	75300.00
D5EC99	2017-07-15 01:01:00+03	69500.00
D5ED37	2017-07-04 22:06:00+03	126500.00
D5ED8A	2017-08-05 19:48:00+03	27200.00
D5EDA8	2017-08-13 21:58:00+03	30000.00
D5EE05	2017-07-08 16:38:00+03	136200.00
D5EE5A	2017-07-16 08:09:00+03	55800.00
D5EEB4	2017-08-09 10:04:00+03	152200.00
D5EF2A	2017-07-01 13:38:00+03	38800.00
D5EF77	2017-07-30 01:46:00+03	56900.00
D5EF7E	2017-07-12 06:53:00+03	81600.00
D5EFDB	2017-07-23 18:43:00+03	40300.00
D5F062	2017-06-26 23:20:00+03	27800.00
D5F06C	2017-08-15 03:04:00+03	31600.00
D5F0BC	2017-08-12 01:53:00+03	111700.00
D5F0CA	2017-08-07 00:27:00+03	23100.00
D5F13B	2017-07-28 14:56:00+03	8200.00
D5F148	2017-07-06 11:44:00+03	21400.00
D5F14A	2017-08-01 19:40:00+03	46300.00
D5F1CD	2017-07-11 05:49:00+03	111600.00
D5F200	2017-07-17 22:51:00+03	25200.00
D5F214	2017-08-02 02:19:00+03	166000.00
D5F245	2017-07-19 23:29:00+03	97700.00
D5F28E	2017-07-06 03:59:00+03	405000.00
D5F2A0	2017-07-24 18:07:00+03	62900.00
D5F2B4	2017-07-18 09:45:00+03	36200.00
D5F346	2017-07-21 23:40:00+03	102100.00
D5F3CB	2017-08-07 02:54:00+03	236700.00
D5F466	2017-08-02 03:43:00+03	88400.00
D5F4E5	2017-07-26 12:10:00+03	50100.00
D5F521	2017-07-06 18:42:00+03	39300.00
D5F577	2017-08-13 08:32:00+03	86400.00
D5F57E	2017-07-21 14:53:00+03	53900.00
D5F641	2017-08-08 17:34:00+03	58800.00
D5F691	2017-08-09 06:05:00+03	99200.00
D5F6AD	2017-08-11 11:26:00+03	55400.00
D5F6C3	2017-07-10 07:21:00+03	92900.00
D5F6F7	2017-07-09 11:48:00+03	49100.00
D5F70A	2017-07-21 02:06:00+03	97400.00
D5F749	2017-07-17 12:06:00+03	105000.00
D5F759	2017-07-27 04:42:00+03	67400.00
D5F79C	2017-07-11 15:43:00+03	4000.00
D5F8BD	2017-08-06 16:08:00+03	58600.00
D5F8D1	2017-07-28 04:16:00+03	16400.00
D5F928	2017-08-10 07:17:00+03	131100.00
D5FA02	2017-08-10 12:10:00+03	118300.00
D5FAB5	2017-08-06 20:34:00+03	55800.00
D5FAE7	2017-07-03 10:53:00+03	111600.00
D5FB31	2017-07-29 08:17:00+03	32500.00
D5FB36	2017-06-30 16:56:00+03	298600.00
D5FB8B	2017-07-07 09:29:00+03	39200.00
D5FC77	2017-08-14 14:22:00+03	75300.00
D5FCF0	2017-08-10 12:02:00+03	47500.00
D5FD04	2017-07-18 18:25:00+03	240600.00
D5FD2E	2017-08-15 08:52:00+03	51900.00
D5FD4C	2017-07-20 02:54:00+03	32200.00
D5FE18	2017-08-03 00:15:00+03	28000.00
D5FE1F	2017-07-21 10:31:00+03	26800.00
D5FE56	2017-07-02 05:24:00+03	7300.00
D5FE8D	2017-07-07 12:47:00+03	17000.00
D5FEFB	2017-08-01 21:13:00+03	133200.00
D5FF39	2017-07-31 07:54:00+03	35600.00
D5FF82	2017-07-12 01:20:00+03	73200.00
D5FFC7	2017-08-15 02:09:00+03	95300.00
D600FB	2017-07-25 23:26:00+03	29600.00
D6016C	2017-08-01 19:37:00+03	55800.00
D601DE	2017-07-02 17:01:00+03	94800.00
D601E7	2017-07-12 21:07:00+03	135000.00
D601F1	2017-08-10 04:33:00+03	13000.00
D60214	2017-08-10 19:07:00+03	248300.00
D60227	2017-08-11 23:17:00+03	23800.00
D60263	2017-08-06 22:14:00+03	28000.00
D602E7	2017-07-16 13:30:00+03	75300.00
D6030E	2017-07-30 14:26:00+03	66600.00
D60327	2017-08-04 05:42:00+03	64900.00
D6034E	2017-07-05 13:11:00+03	51100.00
D6037E	2017-07-21 06:34:00+03	37700.00
D60581	2017-06-27 06:15:00+03	46400.00
D6058C	2017-07-26 15:55:00+03	143800.00
D605B0	2017-06-26 15:01:00+03	246000.00
D605DB	2017-08-06 19:40:00+03	51900.00
D605E0	2017-07-15 06:26:00+03	16400.00
D605E3	2017-07-19 22:08:00+03	135000.00
D605F2	2017-07-24 14:19:00+03	123000.00
D6060A	2017-07-18 16:52:00+03	40800.00
D6065A	2017-07-25 17:19:00+03	58200.00
D60682	2017-08-11 14:48:00+03	146300.00
D606AF	2017-07-07 19:54:00+03	23200.00
D606C9	2017-06-29 11:02:00+03	116800.00
D606CA	2017-07-24 20:08:00+03	56600.00
D607EE	2017-07-03 21:20:00+03	44000.00
D607F3	2017-08-12 19:54:00+03	122700.00
D60856	2017-08-06 10:23:00+03	6200.00
D608B3	2017-07-17 02:51:00+03	146000.00
D608CD	2017-07-31 03:56:00+03	31600.00
D60917	2017-06-29 08:01:00+03	52000.00
D6093F	2017-08-03 08:31:00+03	24200.00
D6094C	2017-07-31 00:23:00+03	57600.00
D609A4	2017-07-27 15:19:00+03	23600.00
D609C8	2017-07-20 14:52:00+03	271200.00
D609CE	2017-07-23 08:12:00+03	369000.00
D60A22	2017-07-22 16:02:00+03	40800.00
D60A2E	2017-07-16 10:24:00+03	65600.00
D60A44	2017-08-02 17:05:00+03	130400.00
D60A81	2017-07-28 14:01:00+03	27200.00
D60AAE	2017-08-14 16:11:00+03	100600.00
D60ADC	2017-07-31 06:39:00+03	22000.00
D60ADF	2017-08-15 09:27:00+03	65900.00
D60B07	2017-07-15 04:32:00+03	18600.00
D60B33	2017-07-15 07:06:00+03	57800.00
D60BB6	2017-07-14 06:23:00+03	49500.00
D60BCC	2017-07-29 01:16:00+03	22000.00
D60BCE	2017-08-08 07:27:00+03	28000.00
D60C23	2017-07-26 23:57:00+03	111600.00
D60C75	2017-08-07 06:52:00+03	89600.00
D60C7E	2017-08-11 03:59:00+03	79900.00
D60C98	2017-07-12 18:47:00+03	25600.00
D60D11	2017-07-18 06:59:00+03	45100.00
D60D17	2017-07-24 19:31:00+03	76300.00
D60D22	2017-07-03 11:46:00+03	68800.00
D60D2E	2017-08-07 08:24:00+03	28000.00
D60D49	2017-07-26 08:32:00+03	100000.00
D60D5E	2017-07-17 06:29:00+03	38400.00
D60E15	2017-08-15 00:20:00+03	122900.00
D60E37	2017-07-22 04:44:00+03	68000.00
D60E5E	2017-07-26 12:02:00+03	28000.00
D60EBC	2017-07-10 23:44:00+03	20400.00
D60EE5	2017-07-07 21:39:00+03	126300.00
D60EE8	2017-07-27 21:26:00+03	14400.00
D60F13	2017-08-14 23:32:00+03	34000.00
D60F3E	2017-07-19 09:51:00+03	65200.00
D60FA8	2017-07-26 18:44:00+03	136200.00
D60FF5	2017-07-02 06:43:00+03	105400.00
D61009	2017-06-28 08:19:00+03	64500.00
D61016	2017-08-03 08:23:00+03	26200.00
D610A9	2017-07-05 02:42:00+03	88000.00
D61164	2017-07-29 19:14:00+03	20100.00
D61172	2017-07-18 11:39:00+03	24400.00
D6118F	2017-07-19 05:13:00+03	24600.00
D61196	2017-07-12 22:21:00+03	58800.00
D611C3	2017-07-23 03:31:00+03	38500.00
D611E2	2017-07-15 08:22:00+03	30000.00
D611EC	2017-07-02 16:42:00+03	204700.00
D611F0	2017-07-15 20:00:00+03	202600.00
D61231	2017-07-25 16:33:00+03	109800.00
D61289	2017-08-04 01:11:00+03	81300.00
D612F8	2017-07-15 18:43:00+03	46300.00
D6131F	2017-07-17 13:30:00+03	27800.00
D6133A	2017-07-06 16:24:00+03	57600.00
D61442	2017-07-19 13:00:00+03	67400.00
D614CF	2017-07-24 12:59:00+03	158800.00
D61550	2017-07-23 05:41:00+03	106100.00
D61584	2017-07-19 11:48:00+03	132800.00
D615AC	2017-08-02 21:38:00+03	59000.00
D61637	2017-07-17 09:43:00+03	23400.00
D61653	2017-08-11 15:50:00+03	57400.00
D61657	2017-06-28 19:26:00+03	57400.00
D616B7	2017-07-02 07:44:00+03	23200.00
D6170F	2017-07-25 17:04:00+03	101500.00
D61740	2017-07-28 10:56:00+03	66600.00
D6177E	2017-07-28 22:40:00+03	23200.00
D617A1	2017-08-10 21:08:00+03	128800.00
D617A5	2017-07-21 11:38:00+03	257600.00
D617C8	2017-08-15 01:40:00+03	12000.00
D61812	2017-07-27 11:11:00+03	28000.00
D61848	2017-08-11 14:55:00+03	65100.00
D61864	2017-07-21 02:45:00+03	111600.00
D61900	2017-08-11 09:36:00+03	12700.00
D6190C	2017-07-04 17:50:00+03	266400.00
D61910	2017-08-13 18:57:00+03	184400.00
D61938	2017-08-11 10:21:00+03	101900.00
D619D9	2017-07-08 05:24:00+03	28300.00
D619DA	2017-08-11 20:59:00+03	7400.00
D619F2	2017-08-05 10:17:00+03	24000.00
D61A0C	2017-08-10 02:52:00+03	53300.00
D61C6D	2017-07-13 05:09:00+03	92600.00
D61C98	2017-07-29 17:39:00+03	12000.00
D61C9E	2017-07-18 22:33:00+03	299200.00
D61D0E	2017-08-13 04:46:00+03	6300.00
D61D47	2017-07-22 07:20:00+03	147700.00
D61DAC	2017-07-06 03:54:00+03	112000.00
D61E18	2017-08-09 11:34:00+03	184000.00
D61E45	2017-08-06 13:48:00+03	112000.00
D61E4A	2017-08-11 23:56:00+03	6000.00
D61E86	2017-07-30 20:20:00+03	28000.00
D61EB2	2017-07-24 02:41:00+03	64700.00
D61EF3	2017-07-11 03:10:00+03	18000.00
D61F4D	2017-08-07 14:10:00+03	248300.00
D61FA4	2017-07-31 07:48:00+03	51900.00
D61FE9	2017-07-23 03:31:00+03	56000.00
D61FEB	2017-07-08 12:29:00+03	111900.00
D62038	2017-07-22 01:35:00+03	37000.00
D62132	2017-07-05 22:45:00+03	46300.00
D62143	2017-07-09 22:52:00+03	128800.00
D621EE	2017-07-26 14:56:00+03	135400.00
D62226	2017-08-04 14:30:00+03	21800.00
D6223D	2017-07-11 19:06:00+03	398500.00
D6229D	2017-07-09 22:08:00+03	73300.00
D622EA	2017-06-28 10:07:00+03	79200.00
D62312	2017-08-04 01:17:00+03	539400.00
D62314	2017-07-03 11:31:00+03	56000.00
D62397	2017-08-13 20:13:00+03	31600.00
D623CE	2017-07-28 14:20:00+03	111600.00
D623D2	2017-07-10 00:19:00+03	17800.00
D623DD	2017-08-15 15:58:00+03	167400.00
D6246D	2017-08-12 16:54:00+03	26800.00
D6250C	2017-07-28 19:02:00+03	572000.00
D6252D	2017-08-12 17:23:00+03	35300.00
D62550	2017-07-15 09:56:00+03	66600.00
D625EA	2017-08-02 11:09:00+03	89700.00
D62606	2017-07-25 21:52:00+03	189800.00
D62658	2017-07-27 04:23:00+03	116500.00
D62691	2017-07-18 12:52:00+03	54300.00
D626D7	2017-07-26 23:09:00+03	58800.00
D62705	2017-07-13 08:53:00+03	56200.00
D62785	2017-08-13 07:13:00+03	73600.00
D62792	2017-08-11 14:07:00+03	120700.00
D627A0	2017-07-13 03:06:00+03	3800.00
D627E7	2017-08-06 15:32:00+03	73500.00
D6281E	2017-08-04 00:28:00+03	134400.00
D62840	2017-07-28 02:16:00+03	115700.00
D6284C	2017-07-03 02:38:00+03	35800.00
D62883	2017-07-08 08:44:00+03	47000.00
D628DB	2017-07-31 05:35:00+03	15800.00
D62950	2017-08-14 01:39:00+03	65900.00
D629B4	2017-07-09 23:29:00+03	155600.00
D62A49	2017-07-16 19:50:00+03	42800.00
D62AD3	2017-07-21 09:05:00+03	37200.00
D62BAA	2017-08-14 01:55:00+03	81300.00
D62BFB	2017-07-21 18:26:00+03	372500.00
D62C38	2017-07-16 13:14:00+03	397700.00
D62CAA	2017-08-07 10:12:00+03	265700.00
D62DB2	2017-07-07 13:07:00+03	46000.00
D62DDD	2017-08-10 11:54:00+03	43500.00
D62E23	2017-07-17 12:33:00+03	21800.00
D62E44	2017-07-29 01:07:00+03	406700.00
D62E69	2017-07-04 21:18:00+03	54800.00
D62E6A	2017-07-09 14:50:00+03	24400.00
D62E79	2017-07-30 23:16:00+03	13400.00
D62FC4	2017-08-10 08:47:00+03	96300.00
D63075	2017-08-05 23:42:00+03	73100.00
D63084	2017-07-28 00:12:00+03	37900.00
D630AD	2017-08-04 04:35:00+03	85700.00
D630B7	2017-07-30 23:00:00+03	70600.00
D630CA	2017-07-21 20:48:00+03	21000.00
D630F4	2017-07-18 05:00:00+03	23200.00
D630FF	2017-07-11 11:54:00+03	39100.00
D63174	2017-07-03 07:28:00+03	56000.00
D6318B	2017-08-11 18:01:00+03	27400.00
D631D6	2017-08-07 02:23:00+03	46400.00
D631F8	2017-07-10 02:12:00+03	194200.00
D63229	2017-07-25 12:08:00+03	233800.00
D63259	2017-07-16 23:40:00+03	115700.00
D63276	2017-07-10 12:55:00+03	21800.00
D632E1	2017-08-13 11:57:00+03	38800.00
D632E9	2017-07-18 12:05:00+03	107600.00
D632EE	2017-07-16 12:07:00+03	73300.00
D63390	2017-07-22 09:52:00+03	111600.00
D633DB	2017-07-20 05:59:00+03	55800.00
D633F2	2017-08-13 04:36:00+03	18400.00
D6354C	2017-08-05 17:10:00+03	201200.00
D6355C	2017-08-10 07:15:00+03	81600.00
D6363A	2017-07-12 13:29:00+03	81800.00
D63644	2017-07-19 21:03:00+03	18900.00
D636D3	2017-07-20 14:53:00+03	44800.00
D636E4	2017-07-01 12:12:00+03	53200.00
D6372B	2017-08-11 11:46:00+03	8200.00
D6380B	2017-08-09 18:51:00+03	26200.00
D6383C	2017-08-13 16:04:00+03	36000.00
D63894	2017-07-14 09:32:00+03	104000.00
D638DC	2017-08-10 11:16:00+03	99200.00
D6391B	2017-08-03 21:38:00+03	85000.00
D63928	2017-07-17 20:05:00+03	60400.00
D63931	2017-07-21 06:03:00+03	75600.00
D6393C	2017-07-15 09:21:00+03	93900.00
D639AA	2017-07-03 09:39:00+03	112000.00
D639E8	2017-08-02 04:25:00+03	46500.00
D63A38	2017-07-23 00:03:00+03	51300.00
D63A3B	2017-07-07 00:33:00+03	32800.00
D63A59	2017-07-31 12:47:00+03	26000.00
D63AC3	2017-07-31 20:54:00+03	90400.00
D63B2F	2017-08-10 03:41:00+03	21400.00
D63B58	2017-07-08 22:10:00+03	123600.00
D63B62	2017-07-05 07:54:00+03	64500.00
D63B87	2017-08-11 11:06:00+03	32200.00
D63C8A	2017-08-10 02:07:00+03	22000.00
D63CDE	2017-07-08 07:11:00+03	43300.00
D63D04	2017-08-04 02:50:00+03	61800.00
D63D07	2017-07-27 16:03:00+03	56900.00
D63D52	2017-07-10 10:51:00+03	28800.00
D63E28	2017-08-10 12:59:00+03	19600.00
D63E2A	2017-08-10 22:38:00+03	49900.00
D63E8A	2017-08-13 22:19:00+03	27200.00
D63ECC	2017-06-29 03:56:00+03	51600.00
D63F1F	2017-07-04 04:37:00+03	298600.00
D63F50	2017-07-05 19:46:00+03	24800.00
D63F60	2017-07-12 04:52:00+03	248300.00
D63F65	2017-08-15 00:06:00+03	27200.00
D63FA9	2017-07-09 19:10:00+03	12800.00
D63FCC	2017-07-24 12:21:00+03	104000.00
D63FFD	2017-08-10 16:22:00+03	44500.00
D64091	2017-07-20 16:28:00+03	68800.00
D6411C	2017-07-10 16:28:00+03	532800.00
D6419B	2017-08-02 18:21:00+03	146800.00
D641B0	2017-07-24 11:40:00+03	32400.00
D64203	2017-08-12 17:26:00+03	50700.00
D64217	2017-07-24 05:51:00+03	47000.00
D6424C	2017-07-19 05:12:00+03	155000.00
D6425C	2017-07-11 01:43:00+03	33300.00
D64263	2017-07-05 08:42:00+03	44800.00
D642DC	2017-07-28 11:35:00+03	58800.00
D642E3	2017-07-10 22:34:00+03	46800.00
D64300	2017-07-10 02:03:00+03	32700.00
D643B4	2017-07-10 14:47:00+03	62600.00
D643D1	2017-08-07 23:42:00+03	38700.00
D643DD	2017-07-12 15:22:00+03	50800.00
D64400	2017-08-03 07:46:00+03	97600.00
D6442E	2017-08-03 12:07:00+03	57600.00
D64446	2017-08-05 06:20:00+03	181600.00
D6446B	2017-07-18 07:43:00+03	143100.00
D644B1	2017-07-12 08:24:00+03	97700.00
D644CB	2017-07-21 10:58:00+03	24400.00
D64559	2017-08-11 05:01:00+03	131600.00
D64563	2017-08-03 15:56:00+03	43600.00
D6459D	2017-07-18 10:16:00+03	14000.00
D645AD	2017-07-02 22:24:00+03	38600.00
D645F2	2017-08-02 13:56:00+03	184300.00
D645FB	2017-08-12 13:13:00+03	62700.00
D646CA	2017-08-04 10:37:00+03	48500.00
D64707	2017-07-29 20:45:00+03	67200.00
D6475C	2017-07-18 03:55:00+03	257500.00
D6476A	2017-08-07 00:19:00+03	137600.00
D64781	2017-08-10 14:08:00+03	124000.00
D647B8	2017-08-11 22:07:00+03	16400.00
D647E5	2017-07-29 15:31:00+03	76600.00
D64831	2017-07-01 20:03:00+03	100600.00
D648A6	2017-08-08 02:00:00+03	58800.00
D648D6	2017-08-08 11:53:00+03	23200.00
D648E1	2017-08-03 05:42:00+03	10100.00
D648EF	2017-07-01 05:50:00+03	23200.00
D6493A	2017-07-06 10:50:00+03	118100.00
D649E9	2017-07-21 01:14:00+03	22000.00
D649F1	2017-06-30 01:55:00+03	174400.00
D64A38	2017-07-09 13:33:00+03	25400.00
D64AA0	2017-08-06 03:36:00+03	56000.00
D64AB7	2017-08-09 23:13:00+03	285700.00
D64AE2	2017-07-25 03:07:00+03	115300.00
D64B50	2017-08-11 16:16:00+03	163600.00
D64B58	2017-07-17 15:23:00+03	55600.00
D64B73	2017-07-19 14:34:00+03	136200.00
D64B8F	2017-07-08 14:59:00+03	58100.00
D64BE8	2017-08-09 11:32:00+03	8000.00
D64C20	2017-08-03 05:47:00+03	21800.00
D64C3C	2017-08-03 20:58:00+03	191500.00
D64C60	2017-07-22 10:56:00+03	246000.00
D64C9D	2017-07-10 12:54:00+03	117000.00
D64C9F	2017-07-21 04:56:00+03	66000.00
D64CAE	2017-07-24 21:20:00+03	28800.00
D64CC5	2017-08-11 11:47:00+03	189800.00
D64CC9	2017-08-04 15:15:00+03	44600.00
D64CDE	2017-07-10 12:21:00+03	39300.00
D64D24	2017-08-06 05:17:00+03	55800.00
D64D2C	2017-08-09 20:24:00+03	132800.00
D64DB8	2017-07-12 14:17:00+03	36200.00
D64EAC	2017-06-27 00:37:00+03	12600.00
D64F03	2017-07-05 22:19:00+03	47400.00
D64F3E	2017-08-04 23:11:00+03	64700.00
D64F68	2017-07-18 22:37:00+03	23600.00
D64F78	2017-07-28 04:30:00+03	53400.00
D64F81	2017-07-19 00:06:00+03	111900.00
D64F8B	2017-07-12 14:37:00+03	59800.00
D64F93	2017-08-13 19:32:00+03	57300.00
D64FBB	2017-07-28 15:07:00+03	30200.00
D64FD4	2017-07-02 07:15:00+03	20200.00
D65044	2017-07-24 11:00:00+03	36200.00
D65049	2017-08-12 22:38:00+03	23200.00
D6507A	2017-08-06 21:45:00+03	13400.00
D65080	2017-07-07 15:59:00+03	23200.00
D6510F	2017-06-27 17:48:00+03	13400.00
D6512B	2017-07-11 07:07:00+03	70500.00
D6512C	2017-08-15 11:14:00+03	24800.00
D6517D	2017-07-07 11:28:00+03	11600.00
D651A4	2017-07-11 20:51:00+03	57600.00
D651F6	2017-07-07 22:46:00+03	28000.00
D65207	2017-07-15 17:17:00+03	30200.00
D6528A	2017-07-10 07:50:00+03	67000.00
D652A6	2017-07-21 14:19:00+03	31900.00
D65313	2017-07-21 22:46:00+03	187600.00
D65333	2017-07-19 05:14:00+03	96200.00
D65375	2017-08-11 00:09:00+03	23600.00
D653C6	2017-07-11 21:47:00+03	43100.00
D653D3	2017-08-13 06:06:00+03	46400.00
D65428	2017-08-05 13:31:00+03	46300.00
D654C0	2017-08-11 14:26:00+03	151200.00
D6551B	2017-07-15 15:48:00+03	22000.00
D65556	2017-07-15 00:46:00+03	54400.00
D655FA	2017-07-20 17:56:00+03	110500.00
D65614	2017-07-07 13:31:00+03	75300.00
D65669	2017-08-09 06:00:00+03	53300.00
D65690	2017-08-09 04:22:00+03	115900.00
D656F9	2017-08-14 10:29:00+03	17800.00
D657DD	2017-08-06 16:02:00+03	46400.00
D657F9	2017-08-08 06:12:00+03	137700.00
D65817	2017-07-27 23:25:00+03	12600.00
D65877	2017-07-29 10:35:00+03	20000.00
D658B2	2017-08-13 08:35:00+03	103400.00
D658E4	2017-08-02 21:55:00+03	46400.00
D658FE	2017-07-15 11:49:00+03	21400.00
D65916	2017-08-08 17:38:00+03	68800.00
D65926	2017-07-03 11:07:00+03	105900.00
D6595C	2017-07-07 07:15:00+03	73300.00
D65996	2017-07-26 11:56:00+03	47000.00
D65A10	2017-07-18 00:05:00+03	56000.00
D65A2C	2017-07-22 18:30:00+03	12600.00
D65A68	2017-07-28 08:49:00+03	112000.00
D65AD3	2017-07-24 06:39:00+03	44600.00
D65B30	2017-07-25 06:51:00+03	153200.00
D65BB0	2017-08-10 02:35:00+03	78200.00
D65BF6	2017-06-29 19:31:00+03	47500.00
D65C33	2017-08-13 20:16:00+03	14400.00
D65CA5	2017-06-28 21:57:00+03	26700.00
D65CB3	2017-08-09 04:02:00+03	62600.00
D65CBC	2017-07-28 03:40:00+03	39300.00
D65CF1	2017-07-06 19:51:00+03	25600.00
D65D08	2017-06-29 19:02:00+03	48800.00
D65D7D	2017-08-03 03:02:00+03	66000.00
D65D95	2017-08-13 21:48:00+03	85700.00
D65E20	2017-07-05 05:45:00+03	47000.00
D65E32	2017-07-13 06:19:00+03	187600.00
D65E96	2017-07-05 14:29:00+03	56900.00
D65ECC	2017-08-09 12:39:00+03	39300.00
D65EDA	2017-08-03 20:03:00+03	144000.00
D65F62	2017-08-10 06:59:00+03	116400.00
D65F86	2017-07-16 08:49:00+03	58900.00
D65F99	2017-07-23 23:52:00+03	75600.00
D65FAC	2017-07-29 20:06:00+03	103900.00
D65FE1	2017-08-01 19:16:00+03	127200.00
D65FF0	2017-07-26 13:05:00+03	41100.00
D6600C	2017-07-27 01:27:00+03	30000.00
D66030	2017-08-03 18:55:00+03	107000.00
D6609A	2017-08-03 02:24:00+03	93300.00
D660C7	2017-07-26 21:12:00+03	73600.00
D661B7	2017-07-03 20:34:00+03	87700.00
D661CD	2017-07-18 05:44:00+03	27800.00
D662A8	2017-08-15 07:52:00+03	7000.00
D662CF	2017-08-06 17:57:00+03	381400.00
D662D7	2017-08-02 01:34:00+03	40800.00
D662E3	2017-07-20 12:28:00+03	56000.00
D662F7	2017-07-12 08:51:00+03	57500.00
D6633B	2017-08-09 17:43:00+03	124200.00
D6634C	2017-07-27 13:10:00+03	23200.00
D663A0	2017-07-02 08:47:00+03	152500.00
D663B9	2017-08-14 22:09:00+03	18600.00
D663C1	2017-07-02 03:38:00+03	72400.00
D663D6	2017-08-13 19:32:00+03	82900.00
D66462	2017-07-28 10:13:00+03	23200.00
D66468	2017-08-03 04:01:00+03	20600.00
D66497	2017-07-04 05:38:00+03	65900.00
D6649B	2017-07-19 20:44:00+03	133900.00
D664C9	2017-07-29 20:29:00+03	61900.00
D664DC	2017-08-14 01:08:00+03	89700.00
D6658A	2017-07-19 12:29:00+03	18600.00
D665CD	2017-07-26 05:11:00+03	266400.00
D66650	2017-07-27 04:52:00+03	189200.00
D66708	2017-08-15 05:19:00+03	47700.00
D66715	2017-07-29 22:31:00+03	30000.00
D6677E	2017-07-03 10:21:00+03	19600.00
D66782	2017-07-09 18:45:00+03	37900.00
D667A1	2017-07-03 19:57:00+03	122000.00
D667B6	2017-07-06 21:34:00+03	6000.00
D667E8	2017-08-12 13:31:00+03	44000.00
D66881	2017-07-15 11:43:00+03	52700.00
D66963	2017-07-07 19:50:00+03	155600.00
D6696C	2017-07-18 00:12:00+03	28000.00
D669D1	2017-08-08 05:16:00+03	32400.00
D669D6	2017-07-30 15:39:00+03	26000.00
D669D8	2017-07-05 23:56:00+03	33000.00
D669DD	2017-07-07 05:49:00+03	135000.00
D669EB	2017-06-25 21:31:00+03	103000.00
D66A1B	2017-07-03 11:35:00+03	61500.00
D66B12	2017-07-26 00:50:00+03	147700.00
D66B15	2017-07-06 01:27:00+03	29600.00
D66B47	2017-08-06 10:31:00+03	14000.00
D66B76	2017-07-26 10:38:00+03	48800.00
D66C37	2017-07-14 11:34:00+03	280000.00
D66CF3	2017-07-04 10:26:00+03	29600.00
D66D4F	2017-07-23 13:29:00+03	13400.00
D66D6A	2017-07-21 01:49:00+03	156500.00
D66DF1	2017-07-12 20:52:00+03	21400.00
D66E50	2017-07-22 15:49:00+03	48500.00
D66EDF	2017-08-04 21:33:00+03	52300.00
D66F26	2017-07-10 12:57:00+03	29100.00
D66F38	2017-08-13 12:13:00+03	54300.00
D66F60	2017-07-24 04:54:00+03	25200.00
D66FCD	2017-07-08 03:06:00+03	27200.00
D66FF4	2017-08-12 05:19:00+03	22000.00
D6703B	2017-08-10 00:03:00+03	14400.00
D6705B	2017-07-13 03:20:00+03	26300.00
D67065	2017-07-19 12:48:00+03	14000.00
D670D5	2017-07-10 18:28:00+03	65400.00
D671D2	2017-07-13 15:44:00+03	28000.00
D6721D	2017-07-01 20:58:00+03	70700.00
D67279	2017-07-12 19:19:00+03	121400.00
D672D1	2017-07-27 16:31:00+03	24400.00
D672D6	2017-07-01 11:01:00+03	12600.00
D67348	2017-07-15 17:29:00+03	156000.00
D6741C	2017-07-20 00:14:00+03	76600.00
D67437	2017-07-19 13:15:00+03	66800.00
D6744C	2017-07-30 17:45:00+03	103000.00
D674AF	2017-07-22 15:47:00+03	6900.00
D67583	2017-07-26 08:17:00+03	26500.00
D675EC	2017-07-07 13:52:00+03	8200.00
D6762E	2017-08-15 09:25:00+03	13200.00
D676D4	2017-08-07 07:20:00+03	111600.00
D677A3	2017-07-30 18:19:00+03	115800.00
D677AF	2017-07-15 09:02:00+03	269900.00
D677DA	2017-07-20 21:04:00+03	28000.00
D67824	2017-07-10 01:35:00+03	8000.00
D6792A	2017-07-17 18:45:00+03	101000.00
D6799C	2017-08-03 03:09:00+03	776400.00
D6799E	2017-07-31 02:42:00+03	28800.00
D679BD	2017-07-05 15:49:00+03	55000.00
D679DD	2017-06-30 03:24:00+03	56600.00
D67A6D	2017-07-14 00:08:00+03	50600.00
D67ACB	2017-07-12 19:09:00+03	141700.00
D67AF0	2017-07-23 10:25:00+03	56000.00
D67B1B	2017-07-11 17:03:00+03	27300.00
D67B32	2017-07-28 03:32:00+03	42800.00
D67B49	2017-07-05 02:14:00+03	6000.00
D67B89	2017-07-13 06:49:00+03	53000.00
D67BD0	2017-07-14 11:33:00+03	107400.00
D67C29	2017-06-27 00:15:00+03	106400.00
D67C30	2017-08-07 09:31:00+03	29500.00
D67C90	2017-07-29 16:35:00+03	56600.00
D67D36	2017-07-18 22:48:00+03	123900.00
D67D3B	2017-07-06 12:16:00+03	50800.00
D67D64	2017-07-06 09:52:00+03	24800.00
D67D77	2017-08-10 14:03:00+03	116400.00
D67D8C	2017-07-03 20:49:00+03	37200.00
D67D90	2017-07-30 21:27:00+03	68400.00
D67DAB	2017-07-05 13:20:00+03	43900.00
D67DB5	2017-07-14 18:40:00+03	75000.00
D67E83	2017-08-03 00:50:00+03	65900.00
D67E95	2017-08-04 20:10:00+03	28000.00
D67EC2	2017-07-17 22:05:00+03	88600.00
D67F2B	2017-08-08 15:19:00+03	22000.00
D67F4F	2017-07-16 20:43:00+03	15000.00
D67F72	2017-07-05 04:23:00+03	23400.00
D67F73	2017-07-14 06:48:00+03	10100.00
D67FE4	2017-07-04 13:21:00+03	55800.00
D6801E	2017-07-20 05:42:00+03	418200.00
D68038	2017-07-16 00:44:00+03	26000.00
D68078	2017-08-13 22:04:00+03	16700.00
D68079	2017-07-10 19:09:00+03	14400.00
D680A5	2017-07-15 21:51:00+03	38800.00
D680A7	2017-07-22 23:21:00+03	30200.00
D680B2	2017-07-22 09:10:00+03	83200.00
D68103	2017-07-13 09:47:00+03	73600.00
D68136	2017-07-23 08:30:00+03	28800.00
D68146	2017-06-30 22:21:00+03	158400.00
D681AC	2017-07-24 21:20:00+03	169900.00
D681D6	2017-07-13 10:26:00+03	73600.00
D681FA	2017-07-05 16:40:00+03	117000.00
D682CE	2017-08-08 16:59:00+03	78600.00
D682DF	2017-07-29 13:38:00+03	133200.00
D68325	2017-07-23 04:59:00+03	69600.00
D6832D	2017-07-28 04:18:00+03	73200.00
D6833B	2017-07-25 23:56:00+03	73300.00
D68392	2017-07-25 00:20:00+03	42400.00
D6846B	2017-08-04 17:43:00+03	25600.00
D6856E	2017-07-11 20:54:00+03	7300.00
D68618	2017-08-14 06:02:00+03	36200.00
D6863D	2017-07-02 22:23:00+03	98700.00
D6867D	2017-07-21 02:38:00+03	123000.00
D6874A	2017-07-20 12:35:00+03	135400.00
D68792	2017-07-25 18:38:00+03	125800.00
D6880D	2017-07-30 07:35:00+03	54500.00
D68827	2017-07-26 11:55:00+03	136300.00
D6882E	2017-08-14 10:10:00+03	257500.00
D68863	2017-07-17 23:30:00+03	24400.00
D688AA	2017-07-05 00:05:00+03	124200.00
D688C3	2017-07-28 03:04:00+03	34000.00
D6890E	2017-07-09 01:31:00+03	198500.00
D68926	2017-07-29 21:46:00+03	45100.00
D6892C	2017-08-12 18:23:00+03	137600.00
D6892D	2017-07-19 04:54:00+03	64400.00
D6894B	2017-07-24 14:29:00+03	77100.00
D68969	2017-07-01 10:20:00+03	56000.00
D68972	2017-07-12 11:52:00+03	46300.00
D689DE	2017-07-04 04:41:00+03	57400.00
D68A58	2017-07-25 07:24:00+03	64300.00
D68A6A	2017-07-29 05:31:00+03	23400.00
D68A6B	2017-07-10 00:54:00+03	69500.00
D68A71	2017-07-08 02:35:00+03	21800.00
D68A83	2017-07-03 01:01:00+03	16400.00
D68A99	2017-07-15 07:05:00+03	37100.00
D68B84	2017-08-07 03:48:00+03	66100.00
D68B88	2017-07-14 09:55:00+03	55800.00
D68BC8	2017-08-08 12:57:00+03	14800.00
D68C21	2017-08-12 21:39:00+03	29800.00
D68C5D	2017-07-19 16:57:00+03	21800.00
D68C67	2017-07-11 06:12:00+03	54600.00
D68C6B	2017-08-04 18:16:00+03	49100.00
D68CB1	2017-07-04 00:48:00+03	59200.00
D68CDE	2017-07-31 12:10:00+03	86200.00
D68DCE	2017-08-01 18:11:00+03	25200.00
D68DCF	2017-07-07 12:30:00+03	266300.00
D68DDD	2017-07-02 15:31:00+03	298600.00
D68E09	2017-07-24 00:05:00+03	21000.00
D68E4B	2017-07-09 00:21:00+03	55600.00
D68EE6	2017-07-07 21:33:00+03	25200.00
D68EEC	2017-07-10 12:25:00+03	74800.00
D68F30	2017-07-24 18:07:00+03	60700.00
D68F50	2017-07-28 23:50:00+03	23200.00
D68F83	2017-07-26 10:26:00+03	92400.00
D68F98	2017-07-23 16:15:00+03	34000.00
D68FAE	2017-08-04 08:03:00+03	60400.00
D68FD4	2017-07-17 15:27:00+03	56000.00
D69003	2017-07-26 21:02:00+03	209800.00
D69005	2017-07-19 09:24:00+03	56900.00
D69026	2017-07-05 18:17:00+03	47100.00
D69038	2017-07-16 19:25:00+03	57800.00
D69063	2017-07-26 01:45:00+03	22400.00
D69071	2017-07-15 19:20:00+03	62200.00
D690BA	2017-08-08 08:51:00+03	55800.00
D690DC	2017-08-09 06:54:00+03	12400.00
D691CD	2017-08-01 19:06:00+03	45200.00
D6924A	2017-08-05 06:56:00+03	58000.00
D69276	2017-08-12 22:02:00+03	94200.00
D692C1	2017-07-02 23:27:00+03	252200.00
D692F9	2017-08-10 06:20:00+03	38400.00
D693A1	2017-08-11 19:38:00+03	63200.00
D693D2	2017-07-22 21:12:00+03	170700.00
D693FB	2017-08-07 10:20:00+03	435200.00
D69408	2017-07-27 17:14:00+03	112000.00
D69434	2017-07-07 15:52:00+03	15000.00
D694B1	2017-08-11 02:54:00+03	55800.00
D6951E	2017-08-11 11:28:00+03	111600.00
D6959D	2017-08-05 06:10:00+03	32800.00
D695D3	2017-07-20 18:04:00+03	118000.00
D696D3	2017-08-11 00:59:00+03	13400.00
D6973F	2017-07-21 17:51:00+03	252200.00
D69768	2017-08-13 05:05:00+03	176800.00
D69793	2017-07-31 00:50:00+03	56600.00
D697BF	2017-08-11 14:59:00+03	141700.00
D697DD	2017-08-02 22:28:00+03	38400.00
D69830	2017-08-13 10:56:00+03	92100.00
D69866	2017-08-15 03:50:00+03	53200.00
D69980	2017-07-17 00:11:00+03	118100.00
D699FA	2017-08-03 06:49:00+03	16300.00
D69A51	2017-08-09 01:06:00+03	248300.00
D69AC6	2017-06-24 20:24:00+03	69500.00
D69BC4	2017-07-13 16:56:00+03	26000.00
D69BE9	2017-07-16 08:46:00+03	54000.00
D69BFE	2017-08-05 12:01:00+03	28700.00
D69C3C	2017-08-12 12:04:00+03	41200.00
D69C41	2017-08-09 11:33:00+03	34700.00
D69C7C	2017-07-12 07:36:00+03	92800.00
D69C8E	2017-07-17 13:41:00+03	131100.00
D69CC9	2017-08-13 19:16:00+03	34200.00
D69CE2	2017-08-13 05:11:00+03	27200.00
D69CF4	2017-07-12 19:33:00+03	28800.00
D69E1D	2017-07-21 19:26:00+03	79600.00
D69E3A	2017-07-16 05:34:00+03	39800.00
D69E3E	2017-06-29 14:51:00+03	160700.00
D69E96	2017-07-18 16:50:00+03	20200.00
D69EE6	2017-07-14 18:30:00+03	83000.00
D69EF0	2017-07-23 17:29:00+03	57600.00
D69F02	2017-07-13 17:06:00+03	28000.00
D69FCC	2017-08-06 08:31:00+03	20900.00
D6A06E	2017-08-14 12:39:00+03	42800.00
D6A0DF	2017-07-28 13:03:00+03	46000.00
D6A162	2017-07-31 06:29:00+03	135600.00
D6A181	2017-08-06 11:15:00+03	6800.00
D6A1D3	2017-07-26 01:56:00+03	6300.00
D6A279	2017-08-13 22:48:00+03	56100.00
D6A2E0	2017-08-02 20:16:00+03	257600.00
D6A306	2017-08-06 17:07:00+03	131600.00
D6A30C	2017-07-06 09:55:00+03	53100.00
D6A3BC	2017-07-11 06:36:00+03	6900.00
D6A3D2	2017-07-31 20:08:00+03	56000.00
D6A3EC	2017-07-05 23:07:00+03	69200.00
D6A420	2017-08-14 03:53:00+03	39500.00
D6A46F	2017-07-08 02:30:00+03	169900.00
D6A4CE	2017-07-03 01:44:00+03	43700.00
D6A517	2017-07-19 01:30:00+03	81800.00
D6A51A	2017-07-21 01:27:00+03	63200.00
D6A569	2017-08-12 13:08:00+03	81600.00
D6A573	2017-07-27 19:14:00+03	64500.00
D6A597	2017-07-15 13:32:00+03	143100.00
D6A645	2017-07-15 18:53:00+03	26800.00
D6A647	2017-07-20 20:05:00+03	47600.00
D6A659	2017-07-11 09:42:00+03	142800.00
D6A698	2017-07-20 01:39:00+03	26000.00
D6A6C9	2017-07-01 06:01:00+03	89600.00
D6A6DE	2017-07-18 19:31:00+03	38800.00
D6A6E4	2017-07-11 16:46:00+03	36800.00
D6A71F	2017-08-11 19:30:00+03	6700.00
D6A722	2017-07-27 14:56:00+03	47000.00
D6A7BC	2017-08-04 14:21:00+03	88900.00
D6A7D8	2017-08-03 00:24:00+03	28800.00
D6A7F7	2017-08-15 17:45:00+03	119700.00
D6A861	2017-07-17 07:16:00+03	123800.00
D6A89A	2017-07-08 06:49:00+03	20200.00
D6A8F1	2017-07-26 23:34:00+03	28000.00
D6A97F	2017-07-29 19:13:00+03	113200.00
D6A98B	2017-08-06 00:09:00+03	123600.00
D6A9BC	2017-07-08 18:20:00+03	125000.00
D6A9BD	2017-07-24 02:15:00+03	67600.00
D6A9FD	2017-08-13 19:50:00+03	75300.00
D6AA19	2017-07-11 04:20:00+03	127500.00
D6AB22	2017-08-04 09:30:00+03	277800.00
D6ABB4	2017-07-31 01:03:00+03	77000.00
D6ABBE	2017-08-14 08:37:00+03	26000.00
D6ABE9	2017-07-19 00:39:00+03	113200.00
D6AC2A	2017-07-28 11:36:00+03	57500.00
D6AC3C	2017-07-14 05:56:00+03	56100.00
D6AC56	2017-07-09 10:06:00+03	60700.00
D6AC58	2017-07-18 17:46:00+03	56100.00
D6AC6F	2017-07-24 21:39:00+03	24400.00
D6ACCF	2017-07-18 06:28:00+03	92000.00
D6ACE2	2017-08-05 09:24:00+03	26600.00
D6AD1B	2017-07-20 04:41:00+03	87700.00
D6AD93	2017-07-20 08:58:00+03	36400.00
D6AE15	2017-07-10 01:06:00+03	25600.00
D6AE23	2017-08-04 15:56:00+03	160800.00
D6AE46	2017-07-20 03:05:00+03	49600.00
D6AE78	2017-07-07 21:37:00+03	13600.00
D6AE86	2017-08-09 07:13:00+03	28000.00
D6AEAE	2017-07-02 11:01:00+03	23400.00
D6AEF8	2017-07-13 00:39:00+03	6800.00
D6AF1F	2017-08-05 14:33:00+03	87200.00
D6AF21	2017-07-06 10:48:00+03	147100.00
D6AF4C	2017-07-11 09:11:00+03	70500.00
D6AF6E	2017-08-13 11:06:00+03	190700.00
D6AFD6	2017-07-08 00:29:00+03	122400.00
D6AFE8	2017-08-15 15:25:00+03	27700.00
D6B07C	2017-08-12 05:23:00+03	23200.00
D6B099	2017-07-06 13:33:00+03	21200.00
D6B0B8	2017-07-16 12:00:00+03	36800.00
D6B0F0	2017-07-09 02:56:00+03	43700.00
D6B1D4	2017-08-08 18:05:00+03	136800.00
D6B2E0	2017-07-29 02:05:00+03	115900.00
D6B34D	2017-07-03 04:14:00+03	27200.00
D6B41A	2017-08-14 09:08:00+03	25600.00
D6B430	2017-07-28 17:37:00+03	80900.00
D6B495	2017-07-14 23:21:00+03	79000.00
D6B50D	2017-08-01 07:09:00+03	74400.00
D6B522	2017-08-15 15:53:00+03	56600.00
D6B577	2017-07-28 02:44:00+03	40600.00
D6B5BA	2017-08-12 21:02:00+03	21600.00
D6B5E0	2017-07-12 19:47:00+03	73500.00
D6B5E1	2017-07-27 06:17:00+03	43800.00
D6B609	2017-07-03 03:43:00+03	168000.00
D6B60B	2017-07-08 11:22:00+03	46300.00
D6B669	2017-07-12 19:09:00+03	81600.00
D6B753	2017-07-19 21:51:00+03	229500.00
D6B78C	2017-07-25 14:59:00+03	187600.00
D6B791	2017-07-09 19:47:00+03	65600.00
D6B7EC	2017-07-06 06:39:00+03	67600.00
D6B86A	2017-08-04 23:01:00+03	85000.00
D6B8B4	2017-07-01 16:37:00+03	34000.00
D6B93F	2017-07-14 06:56:00+03	208100.00
D6B976	2017-08-05 19:33:00+03	35800.00
D6B9E6	2017-07-16 23:33:00+03	52700.00
D6BA0C	2017-07-07 07:37:00+03	48100.00
D6BA19	2017-08-13 17:59:00+03	265700.00
D6BA4B	2017-07-21 21:56:00+03	111600.00
D6BA7A	2017-06-30 21:26:00+03	46700.00
D6BB2A	2017-08-15 05:02:00+03	50000.00
D6BB48	2017-07-30 03:01:00+03	6300.00
D6BBBF	2017-07-16 15:06:00+03	95200.00
D6BBEF	2017-07-08 13:42:00+03	67100.00
D6BC33	2017-07-21 23:00:00+03	25200.00
D6BC3D	2017-07-21 04:04:00+03	131100.00
D6BCE3	2017-07-16 04:45:00+03	96200.00
D6BD9D	2017-08-05 15:46:00+03	98000.00
D6BDBD	2017-08-08 04:07:00+03	532800.00
D6BE0A	2017-08-04 04:33:00+03	399600.00
D6BE1F	2017-08-13 08:59:00+03	87900.00
D6BF46	2017-07-01 22:26:00+03	168000.00
D6BF8C	2017-07-28 01:27:00+03	88000.00
D6BF9A	2017-07-24 03:27:00+03	65600.00
D6BFD1	2017-07-07 18:48:00+03	99200.00
D6C001	2017-07-21 09:02:00+03	113300.00
D6C02D	2017-07-09 06:39:00+03	109600.00
D6C05F	2017-07-09 23:48:00+03	66400.00
D6C0F1	2017-07-01 00:00:00+03	271100.00
D6C115	2017-07-05 01:31:00+03	24400.00
D6C128	2017-06-30 07:38:00+03	57600.00
D6C17C	2017-07-21 18:35:00+03	23200.00
D6C1CF	2017-07-30 14:21:00+03	28000.00
D6C1DA	2017-07-01 17:31:00+03	73200.00
D6C219	2017-08-11 15:31:00+03	48100.00
D6C221	2017-08-12 14:19:00+03	119500.00
D6C270	2017-08-05 01:08:00+03	27200.00
D6C29C	2017-08-14 22:16:00+03	114900.00
D6C2B6	2017-07-07 01:56:00+03	47800.00
D6C2CB	2017-07-10 21:12:00+03	169900.00
D6C2E4	2017-08-03 14:40:00+03	133200.00
D6C2EC	2017-08-13 15:19:00+03	56000.00
D6C31D	2017-07-07 20:21:00+03	47400.00
D6C356	2017-08-11 07:57:00+03	77900.00
D6C362	2017-06-29 00:45:00+03	88400.00
D6C388	2017-07-27 21:23:00+03	26000.00
D6C3D8	2017-07-29 00:04:00+03	27300.00
D6C416	2017-08-09 14:03:00+03	31600.00
D6C42A	2017-07-10 08:13:00+03	11800.00
D6C44A	2017-08-06 04:46:00+03	80400.00
D6C46B	2017-07-22 08:08:00+03	131100.00
D6C47D	2017-07-15 14:47:00+03	93900.00
D6C499	2017-08-11 07:57:00+03	82000.00
D6C4C0	2017-08-06 15:48:00+03	11300.00
D6C4F9	2017-07-14 14:37:00+03	75300.00
D6C4FA	2017-07-24 01:49:00+03	32800.00
D6C571	2017-07-17 14:59:00+03	90800.00
D6C5A2	2017-07-29 00:31:00+03	38600.00
D6C5CB	2017-07-12 17:48:00+03	73100.00
D6C62A	2017-07-21 21:56:00+03	34800.00
D6C62B	2017-07-12 03:20:00+03	28000.00
D6C66E	2017-07-09 22:17:00+03	282300.00
D6C691	2017-07-25 20:30:00+03	110500.00
D6C6D7	2017-08-13 19:53:00+03	55800.00
D6C706	2017-07-10 20:46:00+03	24300.00
D6C724	2017-08-07 19:38:00+03	21700.00
D6C775	2017-07-21 14:31:00+03	26800.00
D6C7FB	2017-07-28 11:57:00+03	440900.00
D6C8C9	2017-07-03 00:13:00+03	24800.00
D6C8FE	2017-07-31 10:52:00+03	34800.00
D6C90F	2017-08-15 03:39:00+03	89600.00
D6C953	2017-08-13 18:56:00+03	40800.00
D6C97A	2017-07-05 18:02:00+03	25200.00
D6C9A6	2017-07-20 23:19:00+03	166100.00
D6CA8C	2017-08-06 01:58:00+03	26800.00
D6CAA7	2017-08-02 18:07:00+03	10600.00
D6CABC	2017-07-08 03:39:00+03	143200.00
D6CB0A	2017-08-02 18:20:00+03	81600.00
D6CB2F	2017-07-07 05:41:00+03	64800.00
D6CB6E	2017-07-09 21:04:00+03	135900.00
D6CB84	2017-07-24 12:11:00+03	24800.00
D6CC69	2017-07-21 05:05:00+03	40100.00
D6CC87	2017-07-07 21:02:00+03	36200.00
D6CC9E	2017-07-05 02:24:00+03	169000.00
D6CCB3	2017-07-05 06:14:00+03	62400.00
D6CCCB	2017-07-19 04:00:00+03	62600.00
D6CD26	2017-08-08 08:21:00+03	18000.00
D6CD2A	2017-08-08 18:30:00+03	137600.00
D6CD70	2017-08-06 14:39:00+03	24400.00
D6CD84	2017-07-24 09:02:00+03	134400.00
D6CDAE	2017-07-09 08:20:00+03	35300.00
D6CDD9	2017-07-09 01:20:00+03	92900.00
D6CE31	2017-07-25 13:02:00+03	91200.00
D6CE6F	2017-08-08 21:21:00+03	24000.00
D6CEB0	2017-07-26 09:58:00+03	131600.00
D6CF8D	2017-07-30 23:32:00+03	63500.00
D6CFD9	2017-07-01 12:37:00+03	92800.00
D6D00B	2017-07-28 16:04:00+03	25000.00
D6D01A	2017-07-24 20:19:00+03	22400.00
D6D02E	2017-07-30 08:47:00+03	7400.00
D6D039	2017-07-21 01:16:00+03	58400.00
D6D083	2017-07-15 03:35:00+03	177200.00
D6D0BA	2017-08-08 22:39:00+03	86400.00
D6D0C8	2017-07-03 18:39:00+03	24000.00
D6D0DA	2017-08-03 14:18:00+03	55800.00
D6D103	2017-07-07 17:52:00+03	55800.00
D6D173	2017-08-13 12:23:00+03	15800.00
D6D17C	2017-07-30 12:31:00+03	49100.00
D6D19C	2017-08-04 08:03:00+03	27800.00
D6D1D6	2017-08-10 06:34:00+03	20200.00
D6D1D9	2017-07-08 15:24:00+03	186000.00
D6D23E	2017-07-31 02:09:00+03	60400.00
D6D26E	2017-07-31 06:13:00+03	56000.00
D6D304	2017-08-04 19:34:00+03	67400.00
D6D318	2017-07-07 04:48:00+03	51600.00
D6D365	2017-08-09 15:39:00+03	41100.00
D6D38A	2017-08-08 01:01:00+03	23200.00
D6D3FE	2017-08-09 00:57:00+03	63500.00
D6D403	2017-07-14 17:35:00+03	44800.00
D6D44B	2017-08-04 22:07:00+03	114400.00
D6D45A	2017-07-22 20:22:00+03	86800.00
D6D4DA	2017-08-06 04:32:00+03	49800.00
D6D534	2017-08-03 21:36:00+03	23600.00
D6D536	2017-08-10 03:49:00+03	62600.00
D6D543	2017-08-06 04:10:00+03	270700.00
D6D54E	2017-08-13 12:11:00+03	267500.00
D6D56D	2017-07-29 01:58:00+03	37900.00
D6D59D	2017-07-03 21:02:00+03	6300.00
D6D5D1	2017-07-26 07:21:00+03	14400.00
D6D60E	2017-08-14 08:54:00+03	28000.00
D6D610	2017-07-06 22:59:00+03	23200.00
D6D691	2017-07-07 02:24:00+03	102100.00
D6D6A2	2017-07-13 00:22:00+03	12400.00
D6D6D1	2017-07-01 02:57:00+03	48800.00
D6D6D9	2017-08-11 19:27:00+03	50000.00
D6D717	2017-07-13 06:51:00+03	55800.00
D6D720	2017-08-14 12:01:00+03	81000.00
D6D76A	2017-07-12 21:21:00+03	56600.00
D6D77B	2017-07-04 12:17:00+03	78100.00
D6D7AE	2017-07-09 18:44:00+03	64700.00
D6D84B	2017-07-11 18:41:00+03	55800.00
D6D879	2017-07-08 09:06:00+03	73800.00
D6D89F	2017-08-11 08:08:00+03	57800.00
D6D8C4	2017-08-03 01:10:00+03	137600.00
D6D8DB	2017-07-28 01:52:00+03	14400.00
D6D8ED	2017-08-12 16:09:00+03	111600.00
D6D93B	2017-07-24 00:47:00+03	50600.00
D6D97D	2017-07-02 13:49:00+03	20600.00
D6D9AF	2017-07-21 14:59:00+03	26000.00
D6DA24	2017-07-27 15:48:00+03	24800.00
D6DA83	2017-07-30 14:22:00+03	137700.00
D6DAC3	2017-07-04 01:08:00+03	122800.00
D6DB1F	2017-08-07 05:18:00+03	133100.00
D6DB59	2017-07-08 19:10:00+03	26000.00
D6DBE6	2017-07-24 21:41:00+03	113000.00
D6DC1F	2017-07-24 01:11:00+03	20200.00
D6DC4C	2017-07-14 07:58:00+03	98400.00
D6DC52	2017-08-09 18:13:00+03	26000.00
D6DC5E	2017-07-12 13:40:00+03	87400.00
D6DC6A	2017-07-23 19:55:00+03	92900.00
D6DC87	2017-08-15 14:03:00+03	62000.00
D6DCD1	2017-08-08 22:10:00+03	59300.00
D6DD1D	2017-07-17 17:54:00+03	114800.00
D6DD22	2017-07-06 12:09:00+03	72400.00
D6DD49	2017-07-20 16:54:00+03	6000.00
D6DD55	2017-07-29 23:05:00+03	54800.00
D6DD70	2017-08-07 14:39:00+03	25400.00
D6DDA4	2017-07-13 21:15:00+03	147000.00
D6DE93	2017-07-10 03:00:00+03	58600.00
D6DE9E	2017-08-11 08:29:00+03	257500.00
D6DEAE	2017-07-22 20:20:00+03	108100.00
D6DEB3	2017-07-31 10:09:00+03	48100.00
D6DF0E	2017-07-07 06:38:00+03	102100.00
D6DF4C	2017-08-09 15:01:00+03	14000.00
D6DF6F	2017-07-16 21:40:00+03	26800.00
D6DF8A	2017-08-10 12:09:00+03	32800.00
D6DF8B	2017-08-12 04:01:00+03	180000.00
D6DF9E	2017-07-10 10:04:00+03	45200.00
D6DFE8	2017-07-16 18:35:00+03	44000.00
D6E017	2017-07-12 12:10:00+03	57600.00
D6E02A	2017-07-21 13:40:00+03	124400.00
D6E037	2017-08-08 13:22:00+03	112000.00
D6E043	2017-07-04 03:49:00+03	55800.00
D6E088	2017-07-27 09:20:00+03	83100.00
D6E0AC	2017-07-08 07:34:00+03	25600.00
D6E0CA	2017-07-27 06:51:00+03	25400.00
D6E15D	2017-08-06 20:35:00+03	47100.00
D6E1AC	2017-07-28 05:28:00+03	179500.00
D6E204	2017-07-25 04:25:00+03	24700.00
D6E20C	2017-07-08 08:23:00+03	72400.00
D6E245	2017-07-25 19:47:00+03	154400.00
D6E276	2017-07-26 05:55:00+03	171800.00
D6E2A7	2017-07-17 03:46:00+03	30200.00
D6E2CB	2017-06-30 14:30:00+03	132800.00
D6E3E1	2017-08-05 11:40:00+03	40000.00
D6E487	2017-08-04 20:31:00+03	81700.00
D6E49A	2017-07-31 07:13:00+03	61800.00
D6E4F1	2017-07-30 12:47:00+03	105800.00
D6E4FD	2017-07-30 19:35:00+03	162500.00
D6E547	2017-08-11 22:34:00+03	57600.00
D6E573	2017-07-12 06:01:00+03	179200.00
D6E620	2017-07-24 19:41:00+03	10700.00
D6E62F	2017-08-01 09:44:00+03	75600.00
D6E6AF	2017-07-07 03:06:00+03	100600.00
D6E745	2017-07-27 02:13:00+03	81200.00
D6E77B	2017-07-18 22:14:00+03	166100.00
D6E7C1	2017-07-23 16:58:00+03	168000.00
D6E902	2017-07-30 09:55:00+03	58600.00
D6E97E	2017-07-13 03:08:00+03	12000.00
D6E9B2	2017-07-27 13:24:00+03	6800.00
D6E9E1	2017-08-11 06:36:00+03	88100.00
D6EA3D	2017-07-09 17:05:00+03	184300.00
D6EA61	2017-07-14 16:38:00+03	40800.00
D6EA86	2017-07-06 18:54:00+03	381800.00
D6EA91	2017-07-07 13:09:00+03	62800.00
D6EAA7	2017-07-11 14:03:00+03	46800.00
D6EAC3	2017-07-25 00:50:00+03	13400.00
D6EAF8	2017-07-17 22:49:00+03	136200.00
D6EBFB	2017-07-08 18:18:00+03	15000.00
D6EC0F	2017-07-27 03:52:00+03	17800.00
D6EC3F	2017-08-03 18:41:00+03	60600.00
D6EC7F	2017-07-16 21:48:00+03	99200.00
D6EC88	2017-07-15 15:59:00+03	47000.00
D6ECA2	2017-08-04 19:52:00+03	20200.00
D6ECBA	2017-07-16 20:27:00+03	38600.00
D6ED72	2017-07-09 03:06:00+03	46300.00
D6ED79	2017-08-13 03:13:00+03	138900.00
D6EDCB	2017-07-17 04:35:00+03	52400.00
D6EDCE	2017-07-29 18:38:00+03	47000.00
D6EE1D	2017-08-06 19:36:00+03	135200.00
D6EE57	2017-07-16 06:39:00+03	87200.00
D6EE98	2017-06-30 05:01:00+03	202600.00
D6EEB1	2017-08-04 04:19:00+03	83000.00
D6EEB8	2017-08-14 15:52:00+03	115800.00
D6EF1A	2017-07-29 06:56:00+03	38400.00
D6EF24	2017-07-15 22:14:00+03	95200.00
D6EF34	2017-07-05 01:02:00+03	56000.00
D6EF39	2017-07-29 10:54:00+03	6300.00
D6EF56	2017-07-23 19:17:00+03	105200.00
D6EF78	2017-08-15 00:03:00+03	46000.00
D6EF88	2017-08-09 05:40:00+03	19800.00
D6EFB3	2017-07-05 20:15:00+03	29600.00
D6EFCF	2017-07-18 15:46:00+03	9800.00
D6F02F	2017-08-04 15:09:00+03	169300.00
D6F069	2017-08-04 11:26:00+03	113800.00
D6F0A0	2017-08-09 07:07:00+03	23200.00
D6F0B3	2017-07-02 16:49:00+03	62600.00
D6F0C6	2017-07-05 06:00:00+03	64600.00
D6F0D7	2017-07-07 14:18:00+03	63900.00
D6F0FD	2017-08-01 22:33:00+03	74800.00
D6F161	2017-07-04 12:54:00+03	92800.00
D6F18A	2017-08-15 02:11:00+03	21800.00
D6F1E5	2017-07-20 18:18:00+03	105000.00
D6F224	2017-07-26 10:28:00+03	32700.00
D6F266	2017-07-20 07:44:00+03	151800.00
D6F2D1	2017-08-01 14:45:00+03	28000.00
D6F33A	2017-07-14 22:06:00+03	8600.00
D6F3A9	2017-08-06 15:43:00+03	65600.00
D6F3AD	2017-07-31 03:25:00+03	22100.00
D6F3B6	2017-06-26 10:17:00+03	28000.00
D6F405	2017-08-13 21:43:00+03	84500.00
D6F44A	2017-08-06 00:58:00+03	92800.00
D6F469	2017-07-23 20:19:00+03	24500.00
D6F470	2017-07-13 20:21:00+03	28000.00
D6F4FE	2017-07-18 13:19:00+03	492000.00
D6F506	2017-07-28 04:14:00+03	52700.00
D6F549	2017-08-09 04:41:00+03	128800.00
D6F5FA	2017-08-08 04:43:00+03	102800.00
D6F60C	2017-07-20 14:32:00+03	69100.00
D6F627	2017-07-09 16:30:00+03	26000.00
D6F63A	2017-08-11 14:44:00+03	265900.00
D6F661	2017-07-08 18:54:00+03	30700.00
D6F69D	2017-08-08 07:14:00+03	47100.00
D6F6C9	2017-08-11 23:12:00+03	67600.00
D6F8E9	2017-07-31 09:26:00+03	56000.00
D6F92E	2017-08-10 22:30:00+03	258000.00
D6F946	2017-07-27 18:30:00+03	69500.00
D6F975	2017-06-25 16:11:00+03	6300.00
D6F98D	2017-07-05 18:59:00+03	42800.00
D6FA12	2017-08-05 12:16:00+03	70700.00
D6FA26	2017-07-21 18:58:00+03	56600.00
D6FA2D	2017-08-11 12:10:00+03	14400.00
D6FAC1	2017-07-13 23:15:00+03	120400.00
D6FAC5	2017-07-17 14:44:00+03	25100.00
D6FB03	2017-07-06 10:44:00+03	69900.00
D6FB7D	2017-07-20 18:52:00+03	80700.00
D6FBB4	2017-07-18 19:38:00+03	27400.00
D6FBEC	2017-07-15 21:21:00+03	73300.00
D6FBF1	2017-08-09 07:15:00+03	111600.00
D6FBF9	2017-07-12 05:51:00+03	112000.00
D6FC26	2017-07-05 02:06:00+03	18000.00
D6FC59	2017-07-17 00:34:00+03	6700.00
D6FCBA	2017-07-15 11:04:00+03	31100.00
D6FCD4	2017-08-15 09:50:00+03	62600.00
D6FD5A	2017-08-08 18:19:00+03	189200.00
D6FD86	2017-08-12 16:31:00+03	59000.00
D6FD99	2017-07-12 13:01:00+03	29600.00
D6FDB9	2017-08-10 00:34:00+03	173300.00
D6FDD7	2017-08-01 06:33:00+03	28000.00
D6FDE5	2017-07-17 12:16:00+03	115900.00
D6FE78	2017-07-01 05:04:00+03	113000.00
D6FEE3	2017-07-12 21:31:00+03	152600.00
D6FEFC	2017-07-18 10:49:00+03	23600.00
D6FF1F	2017-07-06 09:34:00+03	55800.00
D6FF6B	2017-08-05 15:04:00+03	59800.00
D6FFB2	2017-07-11 01:04:00+03	22000.00
D70040	2017-07-17 21:18:00+03	26800.00
D7009A	2017-07-06 10:21:00+03	206700.00
D700E5	2017-08-07 06:41:00+03	199800.00
D70120	2017-08-01 17:19:00+03	100600.00
D70178	2017-07-31 06:52:00+03	179400.00
D701B0	2017-07-10 16:56:00+03	69500.00
D701C4	2017-08-10 21:25:00+03	102100.00
D701C5	2017-07-08 13:27:00+03	55800.00
D701FD	2017-08-08 13:47:00+03	119500.00
D702C6	2017-07-17 07:34:00+03	29500.00
D70399	2017-08-04 08:07:00+03	16400.00
D7045B	2017-07-20 10:32:00+03	29100.00
D7046E	2017-08-11 06:25:00+03	40400.00
D7047E	2017-08-05 15:20:00+03	53400.00
D70496	2017-08-12 17:37:00+03	25400.00
D704BA	2017-07-25 09:05:00+03	26700.00
D70508	2017-07-27 04:38:00+03	26000.00
D70550	2017-08-05 00:35:00+03	51500.00
D70565	2017-07-09 16:12:00+03	131100.00
D70571	2017-07-02 17:56:00+03	240600.00
D70588	2017-08-04 14:12:00+03	22000.00
D705C5	2017-07-16 02:26:00+03	88900.00
D70629	2017-08-03 16:26:00+03	27900.00
D70637	2017-07-15 23:07:00+03	142400.00
D70673	2017-08-08 09:13:00+03	24600.00
D70679	2017-07-24 17:23:00+03	71100.00
D706FF	2017-08-11 11:28:00+03	56000.00
D7078F	2017-08-05 19:13:00+03	75700.00
D707C6	2017-07-17 00:47:00+03	12200.00
D707EB	2017-07-26 02:07:00+03	27200.00
D70842	2017-06-30 18:50:00+03	97700.00
D70850	2017-07-17 23:39:00+03	56000.00
D708B4	2017-08-01 14:01:00+03	58800.00
D7093F	2017-07-16 00:06:00+03	65100.00
D70A3C	2017-07-27 07:58:00+03	27800.00
D70A95	2017-07-09 20:05:00+03	15000.00
D70ABF	2017-08-07 04:07:00+03	65600.00
D70ACC	2017-07-12 05:28:00+03	59000.00
D70AE3	2017-07-26 06:05:00+03	30200.00
D70B25	2017-07-08 07:13:00+03	136800.00
D70BD9	2017-07-05 12:47:00+03	947500.00
D70BE6	2017-07-21 17:22:00+03	14000.00
D70C25	2017-07-30 13:43:00+03	12600.00
D70C3D	2017-07-31 19:48:00+03	13400.00
D70C48	2017-08-07 03:33:00+03	19800.00
D70C52	2017-08-10 05:16:00+03	6300.00
D70C65	2017-08-09 12:40:00+03	51800.00
D70C7D	2017-07-22 04:29:00+03	17600.00
D70CDF	2017-07-06 15:02:00+03	68800.00
D70CEF	2017-07-14 19:24:00+03	129400.00
D70E52	2017-07-29 00:19:00+03	26100.00
D70E9A	2017-08-10 01:12:00+03	28000.00
D70F19	2017-07-20 18:39:00+03	14400.00
D70F5D	2017-07-25 12:45:00+03	36800.00
D70FAE	2017-08-13 08:14:00+03	70800.00
D70FCB	2017-07-02 13:36:00+03	273600.00
D70FF8	2017-08-13 18:41:00+03	56000.00
D71009	2017-07-01 04:35:00+03	46400.00
D71043	2017-08-11 04:22:00+03	46000.00
D710D3	2017-07-22 22:06:00+03	98400.00
D71115	2017-08-13 05:43:00+03	16400.00
D711CD	2017-08-10 13:18:00+03	28800.00
D7124E	2017-07-02 05:10:00+03	39500.00
D712A4	2017-08-08 21:44:00+03	31600.00
D712C3	2017-07-13 04:33:00+03	15100.00
D7138B	2017-07-26 18:02:00+03	61000.00
D713A3	2017-07-23 03:18:00+03	40800.00
D7143E	2017-07-26 01:34:00+03	24000.00
D71478	2017-08-06 13:56:00+03	32200.00
D7147F	2017-07-24 13:01:00+03	54500.00
D71484	2017-08-01 18:52:00+03	59200.00
D7152A	2017-07-20 01:53:00+03	166100.00
D71569	2017-07-27 00:17:00+03	11000.00
D71582	2017-07-04 17:20:00+03	8200.00
D71631	2017-08-12 03:52:00+03	134000.00
D7165E	2017-08-05 06:37:00+03	55800.00
D7166F	2017-08-01 12:32:00+03	210100.00
D7167D	2017-07-24 02:39:00+03	52700.00
D716C0	2017-07-05 20:35:00+03	65600.00
D716CA	2017-07-03 02:25:00+03	23200.00
D716D5	2017-07-08 02:45:00+03	65500.00
D7171D	2017-07-14 01:36:00+03	24400.00
D717A6	2017-07-02 06:12:00+03	40600.00
D717B5	2017-07-14 04:48:00+03	15800.00
D71800	2017-07-29 06:22:00+03	124200.00
D71814	2017-08-05 12:20:00+03	17200.00
D7181F	2017-07-27 09:45:00+03	52000.00
D71877	2017-07-25 01:15:00+03	179500.00
D7189B	2017-07-27 10:22:00+03	406100.00
D718B0	2017-07-12 23:42:00+03	48800.00
D718CF	2017-07-29 03:16:00+03	61800.00
D7194A	2017-07-29 17:01:00+03	23200.00
D71962	2017-07-27 07:01:00+03	92700.00
D7199A	2017-08-05 01:21:00+03	32800.00
D719D0	2017-06-30 22:53:00+03	65600.00
D71AB3	2017-07-29 05:34:00+03	25000.00
D71B24	2017-08-11 09:17:00+03	10800.00
D71B30	2017-08-09 06:41:00+03	123000.00
D71B50	2017-08-06 16:58:00+03	67100.00
D71B8B	2017-08-01 02:47:00+03	40000.00
D71B94	2017-07-08 07:21:00+03	46400.00
D71C3D	2017-08-01 06:49:00+03	34100.00
D71C53	2017-08-02 06:52:00+03	23600.00
D71C54	2017-07-10 20:54:00+03	258000.00
D71C8E	2017-07-10 05:51:00+03	67600.00
D71CFB	2017-07-06 05:59:00+03	53400.00
D71D61	2017-07-29 01:19:00+03	266400.00
D71D72	2017-07-08 03:15:00+03	54000.00
D71D99	2017-08-08 07:34:00+03	25000.00
D71DDD	2017-08-04 11:28:00+03	270800.00
D71E10	2017-07-13 23:06:00+03	218400.00
D71E3D	2017-07-05 10:04:00+03	136100.00
D71E6C	2017-07-23 22:29:00+03	666000.00
D71E82	2017-07-18 02:24:00+03	28000.00
D71F14	2017-07-13 03:35:00+03	59800.00
D71F25	2017-07-01 14:47:00+03	44000.00
D71F28	2017-08-14 21:14:00+03	12600.00
D71F4C	2017-07-03 22:12:00+03	260900.00
D71F70	2017-07-14 12:14:00+03	28800.00
D71F8A	2017-07-29 03:10:00+03	58600.00
D71FA8	2017-08-02 10:15:00+03	6000.00
D7202C	2017-08-07 03:47:00+03	69500.00
D72065	2017-07-24 03:03:00+03	43100.00
D720AF	2017-07-01 17:58:00+03	14400.00
D72157	2017-07-20 09:20:00+03	112000.00
D72198	2017-07-10 05:40:00+03	27200.00
D722A1	2017-07-12 07:04:00+03	224000.00
D722AC	2017-08-09 16:05:00+03	47200.00
D722D3	2017-07-24 01:16:00+03	14400.00
D722F0	2017-07-22 07:17:00+03	132800.00
D72339	2017-07-12 14:33:00+03	99300.00
D723A2	2017-07-22 17:31:00+03	24200.00
D723D1	2017-07-08 21:59:00+03	55800.00
D723D4	2017-08-15 17:25:00+03	26000.00
D723D5	2017-06-30 14:50:00+03	64600.00
D72421	2017-07-18 17:14:00+03	44800.00
D72538	2017-07-26 19:01:00+03	39800.00
D7254C	2017-07-13 09:45:00+03	14400.00
D72593	2017-07-27 09:18:00+03	45200.00
D725CE	2017-08-02 00:15:00+03	41600.00
D725F3	2017-07-25 02:31:00+03	46400.00
D725F8	2017-07-25 05:14:00+03	42700.00
D72605	2017-07-25 17:13:00+03	3400.00
D7264C	2017-08-02 12:57:00+03	241400.00
D72650	2017-07-07 17:57:00+03	36000.00
D726A3	2017-07-07 16:00:00+03	12200.00
D726AC	2017-07-24 05:31:00+03	24800.00
D726AE	2017-07-05 09:46:00+03	54400.00
D726BD	2017-07-05 10:35:00+03	28800.00
D726E6	2017-07-08 06:27:00+03	119600.00
D7271B	2017-07-19 15:24:00+03	59600.00
D7274C	2017-08-10 19:55:00+03	167400.00
D727D1	2017-07-02 10:28:00+03	131100.00
D727D6	2017-07-28 04:37:00+03	34000.00
D72927	2017-08-10 20:59:00+03	26000.00
D72939	2017-07-22 17:23:00+03	165800.00
D729AE	2017-07-10 15:04:00+03	80200.00
D729EE	2017-08-09 08:33:00+03	89700.00
D729F0	2017-08-12 00:09:00+03	82900.00
D72A19	2017-08-12 20:01:00+03	13600.00
D72A54	2017-08-04 15:05:00+03	84300.00
D72B27	2017-07-08 22:57:00+03	102600.00
D72B43	2017-08-13 02:56:00+03	19800.00
D72B53	2017-06-29 07:52:00+03	49100.00
D72B89	2017-07-26 19:11:00+03	100200.00
D72B8C	2017-07-17 18:12:00+03	119800.00
D72BA3	2017-07-21 14:23:00+03	170000.00
D72BB0	2017-07-10 20:12:00+03	64500.00
D72BC4	2017-08-08 11:59:00+03	31800.00
D72BEF	2017-07-08 08:51:00+03	56000.00
D72C1A	2017-08-15 07:13:00+03	85000.00
D72C32	2017-07-21 07:18:00+03	56000.00
D72C68	2017-07-21 20:25:00+03	84000.00
D72C78	2017-07-11 12:53:00+03	32600.00
D72CC2	2017-07-03 03:47:00+03	12900.00
D72D31	2017-06-30 21:48:00+03	136200.00
D72DB5	2017-08-10 21:16:00+03	232800.00
D72DCD	2017-07-08 07:09:00+03	26000.00
D72DF2	2017-08-01 02:21:00+03	293600.00
D72DF8	2017-08-15 15:25:00+03	64700.00
D72E0B	2017-07-16 23:43:00+03	34000.00
D72E4B	2017-08-14 07:56:00+03	78200.00
D72EA6	2017-07-14 15:06:00+03	12400.00
D72EB1	2017-07-26 09:27:00+03	40800.00
D72F04	2017-07-06 03:55:00+03	31400.00
D72F51	2017-07-22 17:21:00+03	73500.00
D72F57	2017-08-08 05:42:00+03	89000.00
D72F61	2017-07-11 08:05:00+03	21400.00
D72F76	2017-07-18 03:38:00+03	54800.00
D72FEB	2017-08-12 23:22:00+03	47500.00
D7302B	2017-08-15 01:29:00+03	26000.00
D73081	2017-07-30 01:28:00+03	54000.00
D730AD	2017-08-06 03:26:00+03	55800.00
D730BA	2017-08-14 11:50:00+03	210600.00
D7312F	2017-07-12 23:26:00+03	532800.00
D73135	2017-07-14 22:24:00+03	7800.00
D73158	2017-07-17 11:30:00+03	273000.00
D73165	2017-07-13 22:21:00+03	66600.00
D731B4	2017-07-24 23:29:00+03	46000.00
D731C8	2017-07-08 06:39:00+03	54500.00
D7324E	2017-08-06 01:50:00+03	60400.00
D732CD	2017-07-04 15:45:00+03	265700.00
D732D1	2017-08-06 04:45:00+03	136800.00
D732F2	2017-07-25 22:48:00+03	55000.00
D7332E	2017-08-11 07:51:00+03	26200.00
D733E4	2017-07-24 15:21:00+03	94800.00
D73443	2017-07-25 20:21:00+03	70800.00
D73493	2017-07-28 04:22:00+03	6600.00
D73509	2017-07-21 16:55:00+03	62600.00
D7352E	2017-08-12 07:29:00+03	32200.00
D73568	2017-08-05 11:07:00+03	201200.00
D735A6	2017-08-04 21:53:00+03	114800.00
D735A7	2017-08-12 07:36:00+03	83000.00
D735BD	2017-07-21 08:18:00+03	290500.00
D735D4	2017-08-06 11:08:00+03	81300.00
D735D6	2017-07-24 10:28:00+03	28000.00
D735E4	2017-07-06 13:55:00+03	166100.00
D7365E	2017-07-08 14:24:00+03	56600.00
D73758	2017-07-15 08:23:00+03	32900.00
D73769	2017-08-11 07:32:00+03	64700.00
D737A6	2017-08-14 19:56:00+03	16000.00
D73821	2017-08-10 02:52:00+03	31600.00
D7383A	2017-08-11 04:58:00+03	99300.00
D7383B	2017-07-09 22:54:00+03	49900.00
D73845	2017-06-30 11:56:00+03	15000.00
D73872	2017-08-12 02:20:00+03	161200.00
D73880	2017-07-12 19:11:00+03	109800.00
D738DB	2017-07-26 01:58:00+03	62800.00
D73908	2017-07-23 00:06:00+03	117600.00
D7393D	2017-07-28 15:28:00+03	32400.00
D73940	2017-08-09 14:55:00+03	55800.00
D73966	2017-07-23 00:42:00+03	12000.00
D7396A	2017-07-09 08:15:00+03	46400.00
D739FF	2017-07-19 13:16:00+03	13600.00
D73A25	2017-07-09 21:23:00+03	24400.00
D73A61	2017-08-10 12:28:00+03	14400.00
D73ACE	2017-07-18 10:55:00+03	125000.00
D73AED	2017-07-15 03:25:00+03	56100.00
D73B32	2017-07-27 18:19:00+03	59200.00
D73B6C	2017-08-01 10:56:00+03	40800.00
D73B72	2017-06-28 13:54:00+03	167400.00
D73C8F	2017-07-21 14:16:00+03	249200.00
D73CA6	2017-07-18 10:07:00+03	60400.00
D73CB9	2017-07-25 08:18:00+03	23900.00
D73CD8	2017-07-01 08:19:00+03	49800.00
D73CFE	2017-07-03 02:46:00+03	112000.00
D73CFF	2017-08-11 09:10:00+03	91100.00
D73D2A	2017-08-13 19:46:00+03	131600.00
D73D5E	2017-07-03 07:51:00+03	77200.00
D73D7F	2017-07-09 14:50:00+03	131100.00
D73D9C	2017-07-16 12:06:00+03	9800.00
D73DA2	2017-07-13 18:47:00+03	47600.00
D73DBD	2017-07-24 12:23:00+03	6000.00
D73E26	2017-07-22 16:38:00+03	270800.00
D73E45	2017-08-02 23:04:00+03	135400.00
D73E82	2017-08-07 00:46:00+03	56600.00
D73E83	2017-07-09 20:32:00+03	369000.00
D73EC1	2017-08-08 20:00:00+03	34000.00
D73EEA	2017-08-08 14:35:00+03	6700.00
D73F20	2017-07-26 11:54:00+03	55600.00
D73FAB	2017-07-10 20:21:00+03	138600.00
D73FBD	2017-07-10 23:15:00+03	39300.00
D73FC6	2017-07-27 15:20:00+03	114400.00
D73FC7	2017-07-26 19:35:00+03	23200.00
D74033	2017-07-11 11:17:00+03	40000.00
D7404C	2017-07-25 13:24:00+03	131800.00
D740A9	2017-08-11 03:19:00+03	57700.00
D740B4	2017-08-03 06:04:00+03	93900.00
D740C8	2017-07-04 21:03:00+03	59200.00
D74125	2017-07-06 06:21:00+03	96300.00
D7415F	2017-07-31 13:25:00+03	133100.00
D7417B	2017-07-18 10:16:00+03	56000.00
D74197	2017-07-16 04:56:00+03	57800.00
D741A2	2017-08-13 11:30:00+03	39700.00
D741D4	2017-07-23 05:47:00+03	179400.00
D74209	2017-07-14 14:27:00+03	30200.00
D7426D	2017-08-15 09:53:00+03	20200.00
D7426F	2017-07-09 07:38:00+03	43200.00
D7430C	2017-08-12 04:57:00+03	10800.00
D74331	2017-08-08 15:48:00+03	230500.00
D7436F	2017-07-12 15:52:00+03	60900.00
D74373	2017-07-25 21:06:00+03	65600.00
D743E4	2017-08-13 02:08:00+03	82000.00
D743E9	2017-07-25 06:26:00+03	44000.00
D74417	2017-07-14 23:02:00+03	57600.00
D7441C	2017-07-14 17:10:00+03	86500.00
D74433	2017-08-13 04:47:00+03	64900.00
D7443E	2017-07-13 03:25:00+03	184300.00
D74460	2017-08-07 21:58:00+03	36800.00
D7448C	2017-07-11 17:05:00+03	59200.00
D74531	2017-07-19 11:08:00+03	11600.00
D74559	2017-08-15 16:39:00+03	38200.00
D74587	2017-08-03 19:22:00+03	242000.00
D745D5	2017-08-03 05:05:00+03	323900.00
D74608	2017-07-13 05:05:00+03	40000.00
D74638	2017-07-31 06:12:00+03	75300.00
D74646	2017-07-15 11:30:00+03	49100.00
D74689	2017-08-08 04:31:00+03	55400.00
D7468B	2017-08-04 08:09:00+03	170000.00
D746DC	2017-07-04 03:17:00+03	62600.00
D74738	2017-07-09 19:06:00+03	45400.00
D74769	2017-07-08 10:39:00+03	129800.00
D7479F	2017-08-04 10:56:00+03	139300.00
D7484F	2017-08-06 00:59:00+03	271500.00
D748D3	2017-08-13 05:55:00+03	30300.00
D7496C	2017-08-06 10:16:00+03	211500.00
D749AA	2017-07-21 21:10:00+03	33100.00
D749B2	2017-07-29 12:36:00+03	48500.00
D749BC	2017-08-12 15:03:00+03	25800.00
D749D5	2017-08-08 21:17:00+03	180100.00
D749F9	2017-07-22 21:38:00+03	36800.00
D74A1E	2017-08-11 10:06:00+03	86300.00
D74A42	2017-07-24 23:05:00+03	24400.00
D74A4D	2017-08-11 13:45:00+03	8400.00
D74A5F	2017-07-08 23:24:00+03	65200.00
D74A74	2017-07-12 08:38:00+03	88900.00
D74A98	2017-07-19 09:46:00+03	144700.00
D74AE7	2017-07-22 19:16:00+03	73900.00
D74B08	2017-08-10 16:55:00+03	83000.00
D74B0D	2017-08-13 03:15:00+03	295300.00
D74B9F	2017-07-29 14:48:00+03	28000.00
D74BA2	2017-07-01 07:01:00+03	20200.00
D74BD4	2017-07-21 18:51:00+03	114400.00
D74C6E	2017-06-25 14:08:00+03	86200.00
D74C99	2017-07-19 22:53:00+03	28000.00
D74CA1	2017-08-12 15:11:00+03	9800.00
D74CB1	2017-07-05 04:13:00+03	386300.00
D74D03	2017-08-09 00:33:00+03	8000.00
D74D4A	2017-07-27 23:39:00+03	55800.00
D74D8C	2017-07-09 13:53:00+03	29400.00
D74E31	2017-07-14 21:03:00+03	85000.00
D74E37	2017-08-03 10:15:00+03	93200.00
D74EAE	2017-07-23 09:04:00+03	46500.00
D74EDE	2017-07-22 23:40:00+03	133200.00
D74FAF	2017-07-11 21:36:00+03	19600.00
D74FC3	2017-07-30 16:32:00+03	90400.00
D74FF7	2017-07-31 00:51:00+03	33600.00
D7505A	2017-08-15 00:52:00+03	155600.00
D7506C	2017-07-11 03:23:00+03	40800.00
D75087	2017-07-07 22:58:00+03	51900.00
D7508A	2017-08-12 13:42:00+03	170700.00
D750B5	2017-08-12 04:26:00+03	37900.00
D750CF	2017-07-12 08:14:00+03	37200.00
D75161	2017-07-02 03:58:00+03	21000.00
D751AF	2017-07-06 07:00:00+03	397600.00
D75235	2017-07-13 03:25:00+03	22000.00
D75243	2017-07-05 13:31:00+03	58600.00
D752C7	2017-07-02 14:40:00+03	93700.00
D75300	2017-07-03 15:28:00+03	13700.00
D75481	2017-08-11 07:53:00+03	28000.00
D754CC	2017-08-01 03:02:00+03	265700.00
D754DB	2017-07-29 17:36:00+03	44600.00
D754F0	2017-07-26 08:52:00+03	26800.00
D755B2	2017-07-26 01:56:00+03	133200.00
D755F7	2017-08-09 08:20:00+03	51500.00
D756C3	2017-08-12 19:05:00+03	152500.00
D756D5	2017-07-12 00:36:00+03	38600.00
D756DE	2017-07-20 02:24:00+03	136400.00
D7570D	2017-07-03 08:10:00+03	6800.00
D757A8	2017-08-03 01:33:00+03	77000.00
D757CE	2017-07-25 18:01:00+03	126700.00
D757E0	2017-07-22 07:29:00+03	13400.00
D757FC	2017-07-04 15:24:00+03	13400.00
D75828	2017-07-18 00:33:00+03	48500.00
D7582C	2017-07-24 01:52:00+03	23600.00
D75830	2017-07-30 16:27:00+03	58900.00
D75840	2017-08-14 14:25:00+03	58800.00
D75874	2017-07-06 17:45:00+03	112000.00
D75894	2017-08-02 09:21:00+03	13400.00
D758F3	2017-07-13 14:09:00+03	52800.00
D75964	2017-08-11 10:21:00+03	65500.00
D7596D	2017-07-31 23:28:00+03	133200.00
D75973	2017-07-29 20:58:00+03	50800.00
D759B3	2017-08-11 03:24:00+03	58200.00
D759C5	2017-08-06 22:01:00+03	123600.00
D75A69	2017-07-05 07:49:00+03	36200.00
D75AA6	2017-07-07 01:17:00+03	26000.00
D75AC7	2017-07-20 11:14:00+03	81200.00
D75ADD	2017-08-08 05:48:00+03	65000.00
D75B09	2017-07-14 15:43:00+03	27200.00
D75B49	2017-07-06 01:38:00+03	135400.00
D75B61	2017-07-07 00:44:00+03	199200.00
D75B7A	2017-08-01 03:25:00+03	283100.00
D75B8B	2017-08-15 10:44:00+03	13400.00
D75C22	2017-07-31 05:28:00+03	189800.00
D75CBD	2017-08-10 17:31:00+03	23400.00
D75CD2	2017-06-30 05:58:00+03	120700.00
D75D1F	2017-07-10 04:43:00+03	24800.00
D75DA0	2017-07-14 11:25:00+03	30900.00
D75DC9	2017-06-30 10:07:00+03	30000.00
D75E14	2017-07-20 08:49:00+03	47000.00
D75E26	2017-06-25 13:44:00+03	51900.00
D75E3C	2017-07-14 07:15:00+03	135600.00
D75E45	2017-07-23 13:50:00+03	44700.00
D75EAB	2017-07-11 22:37:00+03	179300.00
D75EB6	2017-07-30 06:34:00+03	53300.00
D75EC8	2017-07-23 21:27:00+03	17000.00
D75F3F	2017-08-04 17:18:00+03	73500.00
D75F68	2017-07-22 00:49:00+03	28800.00
D76014	2017-08-04 10:28:00+03	58800.00
D7603D	2017-07-06 14:23:00+03	46400.00
D7605A	2017-07-28 01:30:00+03	26500.00
D76080	2017-07-22 16:11:00+03	38600.00
D760F4	2017-07-25 05:10:00+03	32400.00
D76129	2017-08-11 11:11:00+03	38000.00
D7619A	2017-07-17 06:54:00+03	399600.00
D76203	2017-08-08 05:47:00+03	136700.00
D76236	2017-08-07 13:35:00+03	23400.00
D762DC	2017-07-24 12:48:00+03	257500.00
D762F4	2017-07-18 20:43:00+03	42000.00
D762FC	2017-08-08 03:11:00+03	73600.00
D7631F	2017-07-17 05:16:00+03	45200.00
D76326	2017-08-15 16:50:00+03	516800.00
D7636B	2017-07-15 14:50:00+03	54800.00
D763B0	2017-07-26 13:34:00+03	52400.00
D763B2	2017-07-27 03:10:00+03	67400.00
D763CA	2017-07-10 01:32:00+03	39400.00
D763EC	2017-07-25 07:11:00+03	68400.00
D763FE	2017-07-26 12:10:00+03	26000.00
D764DC	2017-07-02 00:00:00+03	28800.00
D764E2	2017-07-09 04:35:00+03	15700.00
D7650F	2017-07-22 10:06:00+03	25200.00
D76568	2017-07-28 01:30:00+03	60700.00
D765B4	2017-07-07 19:49:00+03	77900.00
D765EA	2017-08-03 17:16:00+03	46000.00
D765F9	2017-07-06 03:09:00+03	49100.00
D765FB	2017-07-21 15:00:00+03	147700.00
D76606	2017-07-23 22:03:00+03	44400.00
D76607	2017-08-14 18:37:00+03	93500.00
D7663B	2017-08-15 03:43:00+03	18600.00
D76651	2017-07-23 01:58:00+03	25400.00
D76687	2017-08-13 03:21:00+03	77100.00
D766A4	2017-07-02 07:41:00+03	57500.00
D767AC	2017-08-15 17:27:00+03	112000.00
D767C7	2017-06-28 02:07:00+03	21400.00
D767E4	2017-07-08 10:22:00+03	58400.00
D76853	2017-07-06 14:36:00+03	112000.00
D7688D	2017-07-16 19:50:00+03	86500.00
D768A5	2017-06-28 13:44:00+03	47400.00
D768BC	2017-08-02 20:39:00+03	73200.00
D769D1	2017-08-12 07:49:00+03	135400.00
D76A13	2017-07-14 05:27:00+03	37900.00
D76A2A	2017-08-14 01:44:00+03	73100.00
D76A7B	2017-07-04 11:01:00+03	81500.00
D76ABE	2017-07-29 21:07:00+03	13400.00
D76B47	2017-08-05 22:40:00+03	292300.00
D76B51	2017-08-04 01:53:00+03	129200.00
D76B59	2017-06-30 08:47:00+03	386000.00
D76B5C	2017-07-22 07:25:00+03	170000.00
D76B66	2017-08-01 18:59:00+03	113000.00
D76B89	2017-08-02 04:22:00+03	47000.00
D76B8B	2017-07-16 02:02:00+03	53900.00
D76B9B	2017-07-15 03:17:00+03	30000.00
D76BF8	2017-07-27 13:37:00+03	229400.00
D76C33	2017-07-19 18:35:00+03	46400.00
D76D04	2017-08-09 12:28:00+03	39300.00
D76D3D	2017-07-20 09:43:00+03	14000.00
D76D51	2017-07-11 06:41:00+03	24600.00
D76E91	2017-07-22 20:40:00+03	17800.00
D76EF2	2017-08-09 08:52:00+03	29200.00
D76EFC	2017-08-01 06:57:00+03	73600.00
D76F01	2017-08-04 10:39:00+03	532800.00
D76F05	2017-08-04 17:11:00+03	73600.00
D76F6B	2017-08-10 00:44:00+03	213800.00
D76FC9	2017-07-29 06:27:00+03	122600.00
D7704A	2017-07-07 02:46:00+03	72300.00
D77079	2017-07-05 11:11:00+03	92400.00
D77083	2017-07-12 02:17:00+03	48700.00
D770A2	2017-07-08 11:36:00+03	23100.00
D770A7	2017-07-21 12:50:00+03	35600.00
D771A8	2017-07-01 03:40:00+03	257500.00
D77207	2017-06-30 12:40:00+03	31400.00
D7722D	2017-08-09 13:15:00+03	21800.00
D77235	2017-08-09 14:36:00+03	133200.00
D77281	2017-07-10 17:20:00+03	57600.00
D77318	2017-07-11 02:10:00+03	53600.00
D7733F	2017-07-22 14:47:00+03	73600.00
D77374	2017-08-03 12:48:00+03	92400.00
D773A6	2017-08-07 07:58:00+03	114800.00
D773C7	2017-07-18 23:05:00+03	25000.00
D773CF	2017-08-13 10:29:00+03	25800.00
D77412	2017-07-10 14:16:00+03	4000.00
D7741D	2017-07-31 08:15:00+03	86400.00
D77426	2017-07-11 00:55:00+03	68800.00
D77489	2017-08-04 01:24:00+03	124800.00
D774B6	2017-07-04 05:58:00+03	111600.00
D77507	2017-07-21 01:23:00+03	37200.00
D77538	2017-08-14 13:36:00+03	18100.00
D775A6	2017-07-24 19:23:00+03	361600.00
D77626	2017-07-02 09:11:00+03	71600.00
D7764E	2017-07-02 15:16:00+03	27200.00
D77689	2017-07-26 14:17:00+03	46500.00
D776C0	2017-08-03 13:38:00+03	90400.00
D776D5	2017-08-09 14:56:00+03	56000.00
D7773F	2017-08-11 18:40:00+03	80000.00
D7781E	2017-07-17 14:32:00+03	29500.00
D77838	2017-07-27 05:16:00+03	47100.00
D7792D	2017-08-12 09:39:00+03	36200.00
D77A38	2017-08-14 07:40:00+03	43600.00
D77A55	2017-08-12 04:58:00+03	47000.00
D77A62	2017-07-24 21:32:00+03	52000.00
D77A71	2017-08-11 01:30:00+03	13400.00
D77B4B	2017-08-05 15:21:00+03	25200.00
D77B7E	2017-07-07 21:27:00+03	52400.00
D77B9B	2017-08-10 08:12:00+03	55800.00
D77BA4	2017-07-16 12:45:00+03	78300.00
D77BB1	2017-07-07 15:31:00+03	23200.00
D77BCD	2017-07-20 01:31:00+03	32900.00
D77BDB	2017-07-25 02:43:00+03	77600.00
D77C0E	2017-08-11 04:57:00+03	25100.00
D77D1F	2017-08-02 20:16:00+03	202400.00
D77DA1	2017-07-13 20:54:00+03	66600.00
D77DAA	2017-07-05 12:31:00+03	7400.00
D77DAD	2017-08-15 07:53:00+03	179400.00
D77E68	2017-07-10 21:46:00+03	6700.00
D77EAE	2017-07-01 18:44:00+03	273600.00
D77EF4	2017-08-02 19:03:00+03	48500.00
D77EFE	2017-07-13 23:50:00+03	17800.00
D77F6F	2017-08-01 08:43:00+03	64700.00
D77F74	2017-07-24 08:10:00+03	54400.00
D77F76	2017-07-18 04:48:00+03	56000.00
D77F99	2017-07-06 23:36:00+03	177600.00
D77F9A	2017-07-01 21:37:00+03	36800.00
D77FF8	2017-08-04 20:07:00+03	272300.00
D7800B	2017-07-05 02:47:00+03	115700.00
D7800D	2017-08-03 15:21:00+03	35200.00
D78076	2017-07-05 08:58:00+03	54500.00
D780CE	2017-07-11 12:45:00+03	135400.00
D78172	2017-07-02 23:53:00+03	56000.00
D78177	2017-06-27 18:31:00+03	170200.00
D78182	2017-07-23 09:25:00+03	74100.00
D78185	2017-07-28 04:10:00+03	39800.00
D7825C	2017-07-28 05:47:00+03	38400.00
D78272	2017-07-22 11:34:00+03	38400.00
D782F0	2017-08-09 15:03:00+03	198300.00
D7830F	2017-08-08 00:38:00+03	49600.00
D78380	2017-07-30 07:51:00+03	22000.00
D783C7	2017-07-13 03:11:00+03	25600.00
D783F8	2017-08-03 13:38:00+03	23600.00
D78404	2017-07-10 22:54:00+03	96300.00
D7845E	2017-08-12 17:00:00+03	149300.00
D784A4	2017-08-04 19:28:00+03	74900.00
D785BC	2017-08-03 17:17:00+03	68700.00
D78621	2017-08-07 22:00:00+03	46400.00
D78655	2017-07-01 04:29:00+03	47100.00
D7866C	2017-07-18 19:03:00+03	54500.00
D786B1	2017-08-12 03:22:00+03	55800.00
D7877E	2017-07-28 05:56:00+03	116400.00
D787F5	2017-07-26 18:20:00+03	67600.00
D78812	2017-07-16 17:55:00+03	281500.00
D78853	2017-07-19 16:22:00+03	6800.00
D78864	2017-07-12 02:17:00+03	55800.00
D78869	2017-07-26 11:59:00+03	32500.00
D788A4	2017-07-18 04:11:00+03	24600.00
D78929	2017-08-13 09:22:00+03	46000.00
D78959	2017-07-12 02:53:00+03	46000.00
D78967	2017-07-04 01:10:00+03	27900.00
D789BF	2017-07-19 16:17:00+03	32100.00
D789C9	2017-07-01 09:20:00+03	183300.00
D78A8A	2017-07-13 22:00:00+03	147100.00
D78A99	2017-07-24 07:22:00+03	67500.00
D78ABE	2017-08-15 06:44:00+03	22000.00
D78B89	2017-08-06 02:42:00+03	8400.00
D78BB3	2017-07-05 00:08:00+03	84300.00
D78C5D	2017-06-26 23:58:00+03	88900.00
D78C67	2017-08-10 01:07:00+03	81800.00
D78C78	2017-07-18 03:22:00+03	28000.00
D78CEA	2017-07-27 05:05:00+03	27600.00
D78CF6	2017-08-13 01:34:00+03	61500.00
D78D29	2017-07-17 23:28:00+03	29600.00
D78D3D	2017-07-15 04:23:00+03	8400.00
D78D72	2017-08-11 07:43:00+03	43700.00
D78E00	2017-07-07 10:53:00+03	169300.00
D78E01	2017-07-11 06:26:00+03	258000.00
D78E64	2017-07-09 15:23:00+03	57400.00
D78F23	2017-08-05 15:41:00+03	116400.00
D78F6A	2017-08-10 05:57:00+03	265600.00
D7903D	2017-07-24 10:54:00+03	16400.00
D7906E	2017-08-08 15:07:00+03	229100.00
D790E3	2017-07-25 22:20:00+03	137700.00
D79114	2017-07-07 13:49:00+03	8400.00
D7911A	2017-08-06 13:42:00+03	58400.00
D79187	2017-07-28 17:47:00+03	29600.00
D79206	2017-08-10 23:00:00+03	15900.00
D79230	2017-07-05 01:50:00+03	13400.00
D79238	2017-07-12 19:36:00+03	27200.00
D7926D	2017-07-06 22:50:00+03	61800.00
D792D0	2017-07-08 14:57:00+03	141800.00
D792F0	2017-08-03 00:48:00+03	13700.00
D792F2	2017-07-29 04:57:00+03	223200.00
D7930A	2017-08-06 12:29:00+03	90800.00
D7936B	2017-07-01 05:45:00+03	63700.00
D793AE	2017-07-02 09:44:00+03	189800.00
D793BF	2017-07-22 20:40:00+03	54600.00
D794B1	2017-07-07 16:28:00+03	97800.00
D79538	2017-07-07 05:28:00+03	129200.00
D79584	2017-08-10 05:20:00+03	21800.00
D79595	2017-07-12 07:39:00+03	265600.00
D795CC	2017-07-30 19:03:00+03	68000.00
D79602	2017-08-01 13:54:00+03	71900.00
D79605	2017-07-20 04:40:00+03	153300.00
D79637	2017-07-20 12:40:00+03	175900.00
D7963D	2017-07-09 06:18:00+03	44000.00
D79679	2017-08-06 05:54:00+03	69500.00
D796ED	2017-08-04 21:55:00+03	79300.00
D796F6	2017-08-01 16:19:00+03	52000.00
D79777	2017-07-18 14:10:00+03	27900.00
D797AF	2017-08-06 17:05:00+03	38600.00
D797E2	2017-07-01 05:40:00+03	34400.00
D7986E	2017-07-24 15:42:00+03	62600.00
D798B9	2017-08-04 07:24:00+03	133200.00
D798C3	2017-07-14 14:58:00+03	90800.00
D798D7	2017-07-17 17:51:00+03	14800.00
D79961	2017-08-01 08:26:00+03	67200.00
D7997B	2017-07-09 20:58:00+03	100200.00
D79998	2017-07-02 17:32:00+03	34100.00
D79A7D	2017-07-11 09:11:00+03	57400.00
D79A8D	2017-07-17 03:39:00+03	51900.00
D79AAA	2017-07-16 02:50:00+03	23100.00
D79AB9	2017-08-09 19:25:00+03	77400.00
D79AC5	2017-07-24 21:50:00+03	36600.00
D79AFD	2017-08-05 14:30:00+03	75200.00
D79B2A	2017-07-23 05:38:00+03	50400.00
D79B79	2017-07-02 06:49:00+03	73500.00
D79BAC	2017-07-08 06:15:00+03	265800.00
D79BBC	2017-07-20 18:32:00+03	6700.00
D79BC9	2017-07-21 05:51:00+03	59300.00
D79BE8	2017-07-20 14:33:00+03	252200.00
D79C07	2017-08-09 03:52:00+03	18300.00
D79C19	2017-08-11 14:58:00+03	83200.00
D79D5A	2017-08-10 10:55:00+03	106500.00
D79F85	2017-07-25 00:28:00+03	14400.00
D79F8E	2017-07-10 08:54:00+03	140900.00
D79FB2	2017-06-29 14:17:00+03	15000.00
D7A037	2017-07-04 12:18:00+03	93500.00
D7A044	2017-07-02 11:08:00+03	22000.00
D7A06F	2017-07-27 12:32:00+03	56000.00
D7A0D5	2017-08-11 11:38:00+03	58200.00
D7A0F7	2017-07-07 13:47:00+03	48800.00
D7A105	2017-07-14 13:40:00+03	48800.00
D7A119	2017-08-08 12:10:00+03	56000.00
D7A130	2017-07-07 21:43:00+03	173500.00
D7A137	2017-07-30 23:23:00+03	363500.00
D7A144	2017-06-28 21:32:00+03	139000.00
D7A237	2017-08-12 02:36:00+03	28800.00
D7A2AF	2017-07-14 12:00:00+03	18800.00
D7A30B	2017-07-30 07:26:00+03	27700.00
D7A3A1	2017-07-14 09:44:00+03	23600.00
D7A40D	2017-08-10 02:36:00+03	8400.00
D7A456	2017-08-10 10:09:00+03	148200.00
D7A47C	2017-06-30 09:57:00+03	6300.00
D7A4F6	2017-08-09 13:59:00+03	123900.00
D7A502	2017-07-27 14:39:00+03	36200.00
D7A539	2017-07-30 07:00:00+03	14000.00
D7A547	2017-07-03 20:37:00+03	88300.00
D7A5FD	2017-08-12 16:22:00+03	6300.00
D7A63C	2017-08-09 12:13:00+03	112000.00
D7A685	2017-07-14 19:08:00+03	57500.00
D7A6C2	2017-07-10 23:30:00+03	123000.00
D7A6F8	2017-07-05 11:17:00+03	28000.00
D7A705	2017-08-08 13:17:00+03	66600.00
D7A720	2017-08-05 13:01:00+03	46000.00
D7A722	2017-08-09 22:19:00+03	132800.00
D7A760	2017-07-19 10:51:00+03	26700.00
D7A770	2017-07-08 11:45:00+03	8200.00
D7A771	2017-07-07 05:42:00+03	120700.00
D7A795	2017-07-02 03:29:00+03	67400.00
D7A816	2017-07-19 12:20:00+03	24400.00
D7A81C	2017-07-14 17:15:00+03	248300.00
D7A87E	2017-07-04 14:28:00+03	27300.00
D7A8B9	2017-07-10 11:30:00+03	108000.00
D7A8E4	2017-07-10 10:39:00+03	24400.00
D7A902	2017-07-25 20:18:00+03	28600.00
D7A9B5	2017-07-23 18:28:00+03	22000.00
D7A9BA	2017-07-15 12:03:00+03	43600.00
D7A9D3	2017-07-12 08:57:00+03	140900.00
D7A9EE	2017-08-08 14:22:00+03	119500.00
D7A9FA	2017-08-09 04:01:00+03	16400.00
D7AA4F	2017-07-31 08:26:00+03	56600.00
D7AA8F	2017-07-28 21:25:00+03	23400.00
D7AA95	2017-07-08 10:27:00+03	290200.00
D7AAB6	2017-07-15 10:13:00+03	56000.00
D7AAC9	2017-07-22 14:37:00+03	125800.00
D7AACE	2017-07-22 06:12:00+03	28000.00
D7AAEB	2017-07-08 12:23:00+03	46200.00
D7AB2A	2017-08-12 10:33:00+03	254900.00
D7AB4B	2017-07-15 19:02:00+03	19600.00
D7AB6C	2017-07-12 03:57:00+03	56100.00
D7AB82	2017-08-01 18:17:00+03	45200.00
D7AB8A	2017-07-16 23:17:00+03	50000.00
D7ABCD	2017-08-07 08:59:00+03	67600.00
D7AC2B	2017-07-30 02:36:00+03	57400.00
D7ACB0	2017-08-05 08:38:00+03	195800.00
D7ACCF	2017-07-20 07:39:00+03	52900.00
D7ACDF	2017-07-05 23:00:00+03	86300.00
D7ACE6	2017-08-03 09:56:00+03	121400.00
D7AD1C	2017-07-09 07:07:00+03	101800.00
D7AD5A	2017-08-08 23:05:00+03	67700.00
D7AD6E	2017-07-16 08:21:00+03	77900.00
D7AE2E	2017-07-01 05:12:00+03	81900.00
D7AE6F	2017-07-13 07:37:00+03	115800.00
D7AE94	2017-07-03 08:54:00+03	119600.00
D7AEC7	2017-07-23 10:28:00+03	67900.00
D7AECD	2017-07-19 16:36:00+03	55800.00
D7AEEB	2017-07-26 15:30:00+03	40100.00
D7AF2A	2017-08-02 17:45:00+03	182500.00
D7AFB4	2017-06-24 04:45:00+03	117200.00
D7AFE9	2017-07-02 03:47:00+03	46400.00
D7B065	2017-07-21 10:08:00+03	46000.00
D7B076	2017-08-05 08:27:00+03	117200.00
D7B0A9	2017-07-24 11:02:00+03	42800.00
D7B107	2017-07-03 18:48:00+03	23600.00
D7B10D	2017-07-29 00:10:00+03	21800.00
D7B130	2017-08-09 14:33:00+03	56600.00
D7B13F	2017-07-09 19:11:00+03	59200.00
D7B141	2017-08-13 12:30:00+03	54000.00
D7B1C1	2017-07-08 12:05:00+03	32300.00
D7B1E3	2017-07-23 20:55:00+03	133100.00
D7B28E	2017-07-30 02:29:00+03	13400.00
D7B29E	2017-07-01 01:45:00+03	62200.00
D7B2B9	2017-08-10 20:08:00+03	55000.00
D7B2C6	2017-07-23 15:27:00+03	47400.00
D7B374	2017-07-11 23:31:00+03	31100.00
D7B414	2017-07-19 02:52:00+03	61400.00
D7B443	2017-08-06 01:00:00+03	51600.00
D7B506	2017-08-05 00:07:00+03	66600.00
D7B51E	2017-07-10 13:16:00+03	202400.00
D7B530	2017-08-15 17:52:00+03	29900.00
D7B5FE	2017-07-01 14:15:00+03	50600.00
D7B618	2017-07-25 18:57:00+03	133100.00
D7B629	2017-07-19 05:44:00+03	70700.00
D7B649	2017-07-29 20:23:00+03	266300.00
D7B6DD	2017-08-02 05:03:00+03	272300.00
D7B704	2017-08-02 10:03:00+03	56000.00
D7B728	2017-07-04 11:04:00+03	31600.00
D7B76D	2017-07-09 20:35:00+03	3400.00
D7B782	2017-07-28 19:48:00+03	14400.00
D7B7A2	2017-07-12 03:43:00+03	128800.00
D7B7B5	2017-07-26 19:25:00+03	55600.00
D7B815	2017-07-15 14:50:00+03	40300.00
D7B83D	2017-08-02 02:12:00+03	17000.00
D7B858	2017-07-17 13:44:00+03	9200.00
D7B85C	2017-07-11 05:57:00+03	114800.00
D7B868	2017-07-14 00:19:00+03	277900.00
D7B88C	2017-07-11 00:10:00+03	102100.00
D7B8BC	2017-07-01 02:59:00+03	56000.00
D7B93D	2017-07-04 02:14:00+03	24600.00
D7B941	2017-08-04 08:21:00+03	57500.00
D7B97D	2017-08-08 03:49:00+03	226500.00
D7B9A1	2017-07-09 09:06:00+03	57800.00
D7BA08	2017-07-04 01:02:00+03	57700.00
D7BA18	2017-08-15 16:45:00+03	23600.00
D7BA1A	2017-07-11 00:41:00+03	42800.00
D7BA38	2017-08-10 15:28:00+03	42400.00
D7BA46	2017-07-15 07:43:00+03	13800.00
D7BA89	2017-07-13 13:24:00+03	273400.00
D7BABB	2017-07-13 12:43:00+03	136600.00
D7BB50	2017-07-07 19:03:00+03	24400.00
D7BBBE	2017-07-15 20:56:00+03	163600.00
D7BBE3	2017-08-08 20:40:00+03	8400.00
D7BBFD	2017-08-11 19:11:00+03	53500.00
D7BC9C	2017-07-15 04:36:00+03	23200.00
D7BCA8	2017-07-16 04:44:00+03	6300.00
D7BD1F	2017-08-08 13:29:00+03	39800.00
D7BD36	2017-08-01 15:38:00+03	28800.00
D7BD47	2017-08-09 03:01:00+03	52400.00
D7BD92	2017-08-10 16:45:00+03	39500.00
D7BDC7	2017-07-15 16:20:00+03	48800.00
D7BDE4	2017-07-30 23:03:00+03	73600.00
D7BE1D	2017-07-06 15:31:00+03	67200.00
D7BE4D	2017-07-10 23:29:00+03	79600.00
D7BE5C	2017-08-13 14:20:00+03	85000.00
D7BE70	2017-07-13 06:32:00+03	210100.00
D7BE7E	2017-07-27 06:37:00+03	6800.00
D7BE99	2017-07-28 02:11:00+03	24200.00
D7BECE	2017-07-04 21:37:00+03	66600.00
D7BF8E	2017-07-18 18:33:00+03	69500.00
D7BFAB	2017-07-17 22:15:00+03	26200.00
D7BFE4	2017-07-24 04:29:00+03	156600.00
D7C040	2017-07-25 23:09:00+03	54000.00
D7C0B7	2017-07-25 06:14:00+03	169400.00
D7C0BA	2017-07-16 02:11:00+03	48500.00
D7C12C	2017-07-31 17:47:00+03	131100.00
D7C12E	2017-08-07 14:54:00+03	265700.00
D7C186	2017-08-06 13:14:00+03	38800.00
D7C190	2017-08-08 09:09:00+03	81300.00
D7C196	2017-07-15 10:28:00+03	52000.00
D7C1AD	2017-07-15 20:27:00+03	369000.00
D7C2E5	2017-07-18 21:32:00+03	6300.00
D7C333	2017-07-16 08:05:00+03	374400.00
D7C375	2017-07-26 06:03:00+03	91200.00
D7C3C2	2017-07-24 08:21:00+03	67400.00
D7C41B	2017-07-24 04:57:00+03	47600.00
D7C470	2017-07-03 03:41:00+03	205200.00
D7C477	2017-07-29 20:48:00+03	30200.00
D7C4B9	2017-08-12 04:47:00+03	23600.00
D7C4EE	2017-08-03 19:24:00+03	46300.00
D7C50B	2017-07-17 21:42:00+03	22000.00
D7C524	2017-08-05 02:47:00+03	24400.00
D7C529	2017-07-16 16:57:00+03	111600.00
D7C58B	2017-07-06 12:53:00+03	136200.00
D7C595	2017-07-04 17:34:00+03	34000.00
D7C5F6	2017-06-28 04:37:00+03	167200.00
D7C644	2017-08-12 01:34:00+03	82900.00
D7C6C5	2017-07-25 21:46:00+03	92100.00
D7C6CC	2017-07-30 21:30:00+03	103500.00
D7C753	2017-07-02 18:04:00+03	68800.00
D7C859	2017-07-13 04:26:00+03	191500.00
D7C899	2017-08-07 13:13:00+03	7400.00
D7C8E6	2017-08-02 13:56:00+03	33100.00
D7C8F7	2017-07-09 23:40:00+03	23100.00
D7C920	2017-07-27 17:22:00+03	55800.00
D7C942	2017-07-04 18:08:00+03	54000.00
D7C96A	2017-08-09 09:27:00+03	38600.00
D7C9A6	2017-08-09 08:36:00+03	103500.00
D7CA00	2017-08-06 10:20:00+03	89700.00
D7CA4F	2017-07-31 18:53:00+03	48800.00
D7CA65	2017-08-10 12:17:00+03	71200.00
D7CA85	2017-07-18 11:33:00+03	106200.00
D7CAD7	2017-07-16 12:12:00+03	21800.00
D7CAF3	2017-07-13 01:45:00+03	10700.00
D7CCFC	2017-07-26 22:18:00+03	73200.00
D7CD00	2017-08-03 17:55:00+03	25800.00
D7CD58	2017-07-21 01:54:00+03	14800.00
D7CD95	2017-07-24 07:47:00+03	25600.00
D7CDCB	2017-07-26 03:41:00+03	92800.00
D7CDCF	2017-08-04 22:47:00+03	23200.00
D7CDF7	2017-07-02 08:11:00+03	13400.00
D7CE19	2017-08-01 08:38:00+03	78000.00
D7CE88	2017-07-12 18:48:00+03	55800.00
D7CEB5	2017-06-28 18:22:00+03	65900.00
D7CECC	2017-07-12 21:05:00+03	274800.00
D7CF2A	2017-08-05 12:25:00+03	39300.00
D7CF2D	2017-08-13 03:19:00+03	30200.00
D7CF7F	2017-07-31 13:19:00+03	36800.00
D7D01E	2017-07-24 22:35:00+03	26600.00
D7D065	2017-07-18 00:54:00+03	62100.00
D7D100	2017-08-12 11:14:00+03	123000.00
D7D109	2017-08-07 09:41:00+03	23400.00
D7D19D	2017-07-18 22:37:00+03	69500.00
D7D1A0	2017-07-30 07:34:00+03	56000.00
D7D1B5	2017-08-05 01:33:00+03	50800.00
D7D1BF	2017-08-10 13:11:00+03	139300.00
D7D226	2017-08-01 16:15:00+03	60800.00
D7D2AC	2017-07-31 12:25:00+03	145400.00
D7D2EF	2017-08-09 10:36:00+03	98400.00
D7D30F	2017-07-23 15:10:00+03	14000.00
D7D316	2017-07-12 22:43:00+03	142800.00
D7D34F	2017-08-13 10:24:00+03	39800.00
D7D352	2017-07-07 15:28:00+03	46400.00
D7D394	2017-08-01 06:17:00+03	39800.00
D7D395	2017-07-20 06:08:00+03	57500.00
D7D451	2017-07-27 15:28:00+03	123000.00
D7D45D	2017-07-07 01:31:00+03	6000.00
D7D461	2017-08-06 15:09:00+03	32200.00
D7D490	2017-07-23 09:43:00+03	62900.00
D7D493	2017-08-12 15:54:00+03	24400.00
D7D4A4	2017-07-10 10:02:00+03	55800.00
D7D4B7	2017-08-13 21:07:00+03	248300.00
D7D4E8	2017-07-17 11:50:00+03	67600.00
D7D4EE	2017-07-08 06:07:00+03	92900.00
D7D50E	2017-08-13 08:41:00+03	40800.00
D7D5B4	2017-08-14 15:28:00+03	12600.00
D7D5D5	2017-07-26 12:46:00+03	34400.00
D7D5F0	2017-08-01 19:24:00+03	46000.00
D7D611	2017-08-13 10:32:00+03	93000.00
D7D644	2017-07-14 02:43:00+03	31000.00
D7D6C0	2017-07-02 07:25:00+03	34400.00
D7D6E5	2017-08-12 20:42:00+03	57700.00
D7D768	2017-08-07 22:20:00+03	187600.00
D7D781	2017-07-08 06:45:00+03	24400.00
D7D7A0	2017-07-26 13:32:00+03	80200.00
D7D7E0	2017-07-14 13:18:00+03	15000.00
D7D7E1	2017-07-26 01:33:00+03	59100.00
D7D7F7	2017-08-11 08:06:00+03	13400.00
D7D80E	2017-08-10 20:10:00+03	62600.00
D7D85C	2017-07-21 19:54:00+03	139300.00
D7D91C	2017-07-06 15:53:00+03	7300.00
D7D9F1	2017-07-18 22:39:00+03	66600.00
D7DA1D	2017-07-17 20:57:00+03	14800.00
D7DA22	2017-08-13 12:33:00+03	26000.00
D7DA82	2017-08-12 09:31:00+03	38600.00
D7DA84	2017-07-04 09:35:00+03	20200.00
D7DBCE	2017-08-05 06:40:00+03	14000.00
D7DBD9	2017-08-06 02:13:00+03	53000.00
D7DC04	2017-08-09 16:25:00+03	399600.00
D7DC32	2017-07-06 02:01:00+03	28800.00
D7DC95	2017-07-20 13:32:00+03	369000.00
D7DCE9	2017-07-07 20:23:00+03	22000.00
D7DD21	2017-08-10 09:11:00+03	27300.00
D7DD3F	2017-08-03 02:55:00+03	50600.00
D7DD9C	2017-07-27 21:11:00+03	70700.00
D7DDB0	2017-07-06 17:57:00+03	65100.00
D7DDC0	2017-07-23 02:07:00+03	26000.00
D7DDEA	2017-07-05 20:54:00+03	124200.00
D7DE1E	2017-08-13 15:13:00+03	22000.00
D7DE6D	2017-08-11 20:59:00+03	67600.00
D7DEDA	2017-06-30 06:33:00+03	85400.00
D7DF00	2017-08-10 08:27:00+03	55900.00
D7DF04	2017-08-07 01:20:00+03	35200.00
D7DF34	2017-07-20 20:25:00+03	254900.00
D7DFEE	2017-07-04 05:40:00+03	266400.00
D7E001	2017-08-13 06:41:00+03	58900.00
D7E016	2017-07-06 15:41:00+03	14400.00
D7E06D	2017-07-20 18:40:00+03	60300.00
D7E092	2017-08-14 22:18:00+03	168000.00
D7E0AA	2017-07-27 04:09:00+03	9800.00
D7E0BB	2017-08-01 07:56:00+03	16400.00
D7E13D	2017-08-14 16:31:00+03	86300.00
D7E17F	2017-07-28 19:13:00+03	37900.00
D7E24E	2017-07-05 01:09:00+03	206400.00
D7E271	2017-07-24 06:38:00+03	142300.00
D7E321	2017-07-22 20:35:00+03	59800.00
D7E345	2017-08-07 10:34:00+03	112000.00
D7E34A	2017-07-14 17:06:00+03	23600.00
D7E3BF	2017-07-05 20:21:00+03	37200.00
D7E434	2017-07-05 22:11:00+03	40000.00
D7E43D	2017-07-31 23:41:00+03	265600.00
D7E444	2017-08-07 03:44:00+03	46800.00
D7E488	2017-08-13 10:49:00+03	135400.00
D7E4F1	2017-08-11 17:54:00+03	37900.00
D7E4F3	2017-07-03 07:33:00+03	103200.00
D7E505	2017-08-07 09:46:00+03	233000.00
D7E553	2017-07-23 22:08:00+03	26200.00
D7E57A	2017-07-22 23:31:00+03	246000.00
D7E581	2017-07-08 22:21:00+03	24300.00
D7E59F	2017-07-30 20:31:00+03	128800.00
D7E5AF	2017-07-16 14:45:00+03	13600.00
D7E714	2017-07-08 20:42:00+03	30400.00
D7E75F	2017-07-14 22:12:00+03	32200.00
D7E77E	2017-07-24 17:25:00+03	12600.00
D7E78B	2017-07-20 05:33:00+03	56000.00
D7E7C1	2017-07-22 12:45:00+03	57500.00
D7E864	2017-07-01 03:04:00+03	20000.00
D7E87E	2017-07-08 22:39:00+03	16200.00
D7E90F	2017-08-03 15:56:00+03	22000.00
D7E954	2017-08-08 12:37:00+03	134600.00
D7E96D	2017-07-01 04:19:00+03	62000.00
D7E9AA	2017-08-08 05:29:00+03	1062800.00
D7E9D1	2017-07-24 03:32:00+03	46400.00
D7EA46	2017-07-07 02:38:00+03	166100.00
D7EA6E	2017-07-24 19:21:00+03	43500.00
D7EA88	2017-07-07 21:42:00+03	57300.00
D7EACC	2017-07-29 00:13:00+03	14000.00
D7EAFC	2017-07-08 14:18:00+03	95800.00
D7EB56	2017-07-02 23:18:00+03	14000.00
D7EBF7	2017-08-09 03:16:00+03	112000.00
D7EC26	2017-07-10 21:45:00+03	143200.00
D7EC84	2017-07-22 00:12:00+03	67600.00
D7EC9C	2017-08-15 07:07:00+03	13400.00
D7ED56	2017-08-12 15:35:00+03	56000.00
D7EDB8	2017-07-10 09:10:00+03	13400.00
D7EDE6	2017-06-26 16:02:00+03	99300.00
D7EE09	2017-08-12 17:47:00+03	43800.00
D7EE27	2017-06-30 01:19:00+03	31700.00
D7EE88	2017-08-12 17:57:00+03	77900.00
D7EE9D	2017-07-21 21:43:00+03	147000.00
D7EED7	2017-07-23 12:59:00+03	108000.00
D7EF2B	2017-08-02 10:13:00+03	32900.00
D7EF6D	2017-08-01 16:09:00+03	68800.00
D7EFDA	2017-08-01 10:08:00+03	62500.00
D7F032	2017-07-06 00:31:00+03	35700.00
D7F0AD	2017-08-05 10:51:00+03	24400.00
D7F0C4	2017-07-13 04:01:00+03	58000.00
D7F134	2017-08-12 03:03:00+03	205400.00
D7F183	2017-07-13 22:07:00+03	28000.00
D7F1BB	2017-07-29 06:15:00+03	112000.00
D7F1C4	2017-08-07 02:04:00+03	26800.00
D7F1EA	2017-08-01 08:39:00+03	31000.00
D7F208	2017-07-12 14:28:00+03	66600.00
D7F209	2017-08-10 23:22:00+03	101200.00
D7F23F	2017-08-12 18:32:00+03	58600.00
D7F254	2017-08-11 14:15:00+03	55800.00
D7F291	2017-07-27 01:31:00+03	80700.00
D7F322	2017-07-24 13:54:00+03	54600.00
D7F32C	2017-07-13 01:45:00+03	227100.00
D7F335	2017-07-07 07:19:00+03	125200.00
D7F3BA	2017-07-30 18:02:00+03	56100.00
D7F408	2017-08-08 00:50:00+03	111600.00
D7F47B	2017-07-18 08:57:00+03	24700.00
D7F579	2017-07-08 05:08:00+03	44600.00
D7F580	2017-08-07 19:26:00+03	132900.00
D7F5EF	2017-07-17 00:06:00+03	31400.00
D7F60A	2017-08-05 00:57:00+03	58700.00
D7F60B	2017-08-14 19:43:00+03	303500.00
D7F687	2017-07-29 15:54:00+03	58600.00
D7F68E	2017-08-10 18:19:00+03	69600.00
D7F69F	2017-08-04 17:50:00+03	46400.00
D7F6F6	2017-07-29 17:39:00+03	61800.00
D7F70E	2017-08-14 14:51:00+03	174800.00
D7F721	2017-07-31 11:50:00+03	52800.00
D7F773	2017-07-27 13:44:00+03	153800.00
D7F788	2017-08-13 18:33:00+03	133200.00
D7F79E	2017-07-21 09:28:00+03	20200.00
D7F7C2	2017-08-01 07:42:00+03	60700.00
D7F7C3	2017-07-21 07:31:00+03	57400.00
D7F7CA	2017-08-02 09:40:00+03	38400.00
D7F7F1	2017-07-19 02:22:00+03	67000.00
D7F7F3	2017-07-29 19:55:00+03	163400.00
D7F853	2017-07-23 15:50:00+03	148900.00
D7F881	2017-07-20 14:23:00+03	101200.00
D7F884	2017-07-15 17:45:00+03	105400.00
D7F8C8	2017-08-09 04:34:00+03	28800.00
D7F918	2017-08-12 07:36:00+03	31400.00
D7F946	2017-07-19 13:01:00+03	139300.00
D7F97A	2017-08-09 01:37:00+03	271200.00
D7F996	2017-06-28 09:38:00+03	56100.00
D7F9B4	2017-07-03 11:33:00+03	28000.00
D7F9B6	2017-07-08 13:05:00+03	55000.00
D7F9D3	2017-07-10 22:27:00+03	38800.00
D7FA37	2017-07-18 07:02:00+03	398500.00
D7FABE	2017-07-13 19:08:00+03	26800.00
D7FAC8	2017-07-10 02:40:00+03	265700.00
D7FB18	2017-07-18 03:52:00+03	139700.00
D7FB3D	2017-07-25 09:43:00+03	46200.00
D7FBD9	2017-07-27 20:28:00+03	131600.00
D7FBEC	2017-08-06 19:01:00+03	27300.00
D7FBFD	2017-07-26 06:59:00+03	46400.00
D7FC2C	2017-07-17 10:36:00+03	103400.00
D7FC63	2017-08-05 15:32:00+03	89700.00
D7FC75	2017-07-29 12:31:00+03	8400.00
D7FCA9	2017-07-30 04:00:00+03	28000.00
D7FCB3	2017-07-05 04:34:00+03	40000.00
D7FCFC	2017-07-14 14:57:00+03	47000.00
D7FD1A	2017-07-07 11:36:00+03	29400.00
D7FD2E	2017-07-27 22:14:00+03	271100.00
D7FDCD	2017-07-28 19:37:00+03	55800.00
D7FDD4	2017-07-24 00:32:00+03	142400.00
D7FDD8	2017-07-29 03:02:00+03	32800.00
D7FDFC	2017-07-19 12:52:00+03	498800.00
D7FE05	2017-07-22 14:59:00+03	12200.00
D7FE54	2017-07-29 11:21:00+03	30800.00
D7FE7D	2017-08-01 10:21:00+03	132800.00
D7FED3	2017-07-09 04:16:00+03	47600.00
D7FFB8	2017-08-15 05:11:00+03	13600.00
D7FFF1	2017-08-08 06:02:00+03	284400.00
D80008	2017-08-01 10:19:00+03	31200.00
D80021	2017-07-09 12:58:00+03	26700.00
D8004C	2017-08-08 16:26:00+03	31600.00
D800B2	2017-07-10 07:23:00+03	58200.00
D80113	2017-07-11 15:35:00+03	44400.00
D8014C	2017-07-11 19:03:00+03	178300.00
D80166	2017-08-04 04:54:00+03	42800.00
D8019B	2017-08-01 20:25:00+03	125200.00
D80217	2017-07-20 09:41:00+03	80300.00
D8021B	2017-08-14 17:30:00+03	55600.00
D80266	2017-07-12 11:18:00+03	133100.00
D80295	2017-08-02 13:12:00+03	325500.00
D802F4	2017-07-21 03:31:00+03	21000.00
D80348	2017-08-01 07:21:00+03	6000.00
D80357	2017-07-20 15:02:00+03	119400.00
D80393	2017-08-03 17:34:00+03	28000.00
D80458	2017-07-18 09:55:00+03	57600.00
D80484	2017-07-24 08:15:00+03	9300.00
D804CC	2017-07-13 06:40:00+03	45200.00
D80539	2017-08-09 07:45:00+03	257500.00
D805B5	2017-08-14 00:46:00+03	34300.00
D805F5	2017-08-08 12:19:00+03	58900.00
D8063A	2017-08-14 00:28:00+03	37800.00
D8063D	2017-07-22 01:50:00+03	41200.00
D80687	2017-07-23 03:27:00+03	98200.00
D80719	2017-08-02 04:26:00+03	59300.00
D8071C	2017-08-09 07:34:00+03	393800.00
D80742	2017-07-28 05:32:00+03	45100.00
D80852	2017-08-08 02:53:00+03	14800.00
D808F8	2017-08-07 18:57:00+03	54000.00
D808F9	2017-08-12 02:27:00+03	80000.00
D80912	2017-08-12 02:00:00+03	55800.00
D80924	2017-08-14 17:44:00+03	30200.00
D8092F	2017-07-19 20:35:00+03	73500.00
D80947	2017-08-09 00:01:00+03	102100.00
D8094E	2017-08-05 13:37:00+03	6200.00
D80A0E	2017-07-22 22:48:00+03	194200.00
D80A1E	2017-07-07 02:34:00+03	112000.00
D80A95	2017-07-24 21:48:00+03	67000.00
D80ABE	2017-07-14 14:23:00+03	46500.00
D80B08	2017-07-07 18:48:00+03	142300.00
D80B14	2017-07-25 09:10:00+03	21000.00
D80B36	2017-07-14 04:54:00+03	97800.00
D80B86	2017-07-13 17:14:00+03	174900.00
D80BE0	2017-07-12 17:32:00+03	73200.00
D80C7D	2017-07-10 06:03:00+03	46300.00
D80CA6	2017-08-13 01:38:00+03	211600.00
D80E07	2017-07-16 22:22:00+03	114200.00
D80E08	2017-07-12 18:39:00+03	166200.00
D80E43	2017-07-27 14:06:00+03	49200.00
D80EA3	2017-08-13 00:12:00+03	100300.00
D80EFF	2017-07-30 06:03:00+03	56000.00
D80F19	2017-07-14 18:30:00+03	87200.00
D80F64	2017-08-14 22:04:00+03	48200.00
D80FEF	2017-08-03 23:58:00+03	94300.00
D81001	2017-07-27 03:25:00+03	14000.00
D8104B	2017-08-09 23:05:00+03	43700.00
D810B6	2017-08-02 10:56:00+03	22000.00
D810BA	2017-08-03 15:23:00+03	120200.00
D8111C	2017-07-08 18:13:00+03	13000.00
D81135	2017-07-30 19:19:00+03	105100.00
D81144	2017-07-19 04:03:00+03	32700.00
D8119E	2017-07-24 07:02:00+03	56000.00
D811CA	2017-08-14 16:04:00+03	101200.00
D81290	2017-07-13 02:31:00+03	31400.00
D8129B	2017-08-12 23:53:00+03	516000.00
D8129F	2017-07-16 12:13:00+03	67200.00
D812C3	2017-07-25 20:35:00+03	76600.00
D81341	2017-08-12 13:17:00+03	99200.00
D81344	2017-07-26 18:40:00+03	12600.00
D813E7	2017-07-29 00:18:00+03	119500.00
D8144D	2017-07-20 12:38:00+03	149300.00
D8152B	2017-07-04 09:49:00+03	28800.00
D81540	2017-08-02 00:45:00+03	59000.00
D81549	2017-07-11 12:41:00+03	156300.00
D815B7	2017-07-24 20:42:00+03	68100.00
D815BB	2017-08-08 07:55:00+03	6000.00
D815C9	2017-07-13 17:26:00+03	45200.00
D81622	2017-07-08 21:02:00+03	257600.00
D81740	2017-07-13 09:04:00+03	25000.00
D818E7	2017-07-19 18:30:00+03	229500.00
D81989	2017-07-07 04:08:00+03	20200.00
D819D6	2017-07-22 10:49:00+03	62000.00
D81AC7	2017-07-22 21:30:00+03	193600.00
D81AF4	2017-07-08 00:57:00+03	67200.00
D81B4B	2017-07-29 02:56:00+03	111700.00
D81B89	2017-07-17 21:20:00+03	48800.00
D81BC7	2017-07-25 16:59:00+03	291000.00
D81BF2	2017-07-08 13:25:00+03	122300.00
D81C05	2017-07-31 02:33:00+03	59800.00
D81C11	2017-07-09 11:12:00+03	69500.00
D81CAC	2017-08-13 03:55:00+03	46900.00
D81CF0	2017-08-13 07:47:00+03	13400.00
D81D07	2017-07-25 17:12:00+03	25600.00
D81D3C	2017-07-25 11:12:00+03	51300.00
D81DE7	2017-08-04 00:13:00+03	23200.00
D81E2A	2017-07-29 09:50:00+03	178800.00
D81E59	2017-08-10 15:34:00+03	62600.00
D81EE8	2017-07-10 12:06:00+03	83000.00
D81F08	2017-07-13 09:23:00+03	40000.00
D81F50	2017-07-08 01:44:00+03	56600.00
D81FB5	2017-07-10 03:39:00+03	41600.00
D81FCD	2017-07-12 18:06:00+03	24400.00
D82026	2017-07-05 01:59:00+03	22000.00
D82029	2017-08-03 21:25:00+03	28000.00
D8202A	2017-07-24 19:51:00+03	43600.00
D8206D	2017-07-11 09:56:00+03	136500.00
D82087	2017-07-26 10:43:00+03	34000.00
D8214A	2017-08-02 02:49:00+03	12600.00
D82166	2017-07-24 19:28:00+03	73500.00
D82191	2017-07-04 06:02:00+03	52000.00
D821B3	2017-07-09 23:31:00+03	136200.00
D822A1	2017-08-12 15:23:00+03	116000.00
D822BB	2017-07-15 10:16:00+03	177200.00
D82402	2017-07-17 16:49:00+03	84100.00
D8244C	2017-07-25 00:03:00+03	29600.00
D82461	2017-07-28 02:08:00+03	58000.00
D824DC	2017-08-09 11:45:00+03	23600.00
D82547	2017-08-03 16:30:00+03	36200.00
D8257A	2017-07-15 14:08:00+03	135400.00
D82588	2017-07-05 18:19:00+03	20600.00
D82597	2017-07-26 17:10:00+03	30900.00
D825F1	2017-06-30 00:40:00+03	56000.00
D82620	2017-07-10 00:31:00+03	25800.00
D8264C	2017-07-17 02:27:00+03	99300.00
D826AA	2017-07-20 01:33:00+03	70400.00
D826B0	2017-07-21 17:12:00+03	32400.00
D82710	2017-07-30 22:27:00+03	199200.00
D82748	2017-08-08 00:12:00+03	61900.00
D82798	2017-07-25 12:13:00+03	26000.00
D827CA	2017-08-05 13:19:00+03	88800.00
D82819	2017-07-09 00:21:00+03	36200.00
D82822	2017-07-25 04:23:00+03	31600.00
D82826	2017-07-07 07:17:00+03	62600.00
D828BC	2017-07-29 20:24:00+03	23600.00
D828E6	2017-08-12 11:28:00+03	23600.00
D82922	2017-08-07 05:06:00+03	132800.00
D8294D	2017-07-04 21:47:00+03	51900.00
D829E0	2017-07-09 22:43:00+03	67100.00
D82A47	2017-08-15 06:00:00+03	30800.00
D82A57	2017-08-14 02:33:00+03	56000.00
D82A8F	2017-06-29 08:23:00+03	34600.00
D82B13	2017-08-04 09:04:00+03	34000.00
D82BAD	2017-08-04 21:02:00+03	229600.00
D82BC5	2017-08-02 08:28:00+03	86400.00
D82D62	2017-07-05 18:12:00+03	119500.00
D82DBE	2017-07-30 04:12:00+03	26400.00
D82DDF	2017-07-23 03:03:00+03	124200.00
D82DF8	2017-07-27 06:26:00+03	13400.00
D82E06	2017-08-11 15:32:00+03	67600.00
D82E09	2017-07-10 06:07:00+03	70700.00
D82E4E	2017-08-14 06:11:00+03	6300.00
D82E71	2017-07-05 19:35:00+03	114500.00
D82E87	2017-07-06 10:28:00+03	57600.00
D82EA3	2017-07-05 16:30:00+03	55000.00
D82EC3	2017-08-01 16:47:00+03	56000.00
D82EE5	2017-08-03 04:56:00+03	27900.00
D82EE9	2017-08-14 14:59:00+03	40300.00
D82EF7	2017-08-10 10:16:00+03	81600.00
D82F44	2017-08-05 17:52:00+03	20400.00
D82F9B	2017-06-29 04:54:00+03	26700.00
D82FD8	2017-07-12 00:34:00+03	23400.00
D83058	2017-07-15 13:41:00+03	88600.00
D8307E	2017-08-09 18:48:00+03	121100.00
D83083	2017-07-23 19:42:00+03	26800.00
D830CC	2017-08-06 22:21:00+03	117200.00
D83180	2017-08-01 03:37:00+03	25400.00
D83229	2017-08-14 04:47:00+03	14400.00
D8326C	2017-07-27 09:18:00+03	54400.00
D83285	2017-07-13 10:59:00+03	84600.00
D8329D	2017-07-17 09:48:00+03	6000.00
D832A5	2017-07-03 11:47:00+03	56100.00
D833A8	2017-08-10 12:29:00+03	40800.00
D833D9	2017-07-08 12:44:00+03	23200.00
D83400	2017-06-30 10:50:00+03	6000.00
D83450	2017-06-28 11:20:00+03	91200.00
D83460	2017-07-24 07:54:00+03	21400.00
D83463	2017-07-07 19:05:00+03	49600.00
D83492	2017-07-05 19:08:00+03	12000.00
D8349F	2017-08-13 15:05:00+03	24000.00
D834A8	2017-07-21 16:55:00+03	63200.00
D834D2	2017-07-11 12:53:00+03	115900.00
D834D6	2017-07-03 21:09:00+03	168300.00
D83500	2017-07-11 00:17:00+03	21800.00
D83514	2017-07-31 02:30:00+03	234400.00
D8353C	2017-07-12 13:26:00+03	134800.00
D83573	2017-08-11 16:01:00+03	55800.00
D83641	2017-08-05 12:59:00+03	44800.00
D83643	2017-08-11 00:03:00+03	19600.00
D83650	2017-07-25 23:49:00+03	262200.00
D8369E	2017-07-02 19:41:00+03	16200.00
D836DD	2017-07-13 15:08:00+03	6000.00
D836E6	2017-07-23 23:13:00+03	40800.00
D83748	2017-07-27 18:44:00+03	133200.00
D83780	2017-07-06 07:55:00+03	48800.00
D837B3	2017-08-09 08:42:00+03	19800.00
D837CF	2017-07-24 05:38:00+03	121300.00
D83855	2017-07-25 12:08:00+03	27900.00
D838DA	2017-07-30 14:22:00+03	133800.00
D838E1	2017-07-31 09:13:00+03	23600.00
D8392E	2017-07-19 07:31:00+03	167500.00
D83964	2017-08-15 15:22:00+03	15100.00
D8396A	2017-07-28 22:49:00+03	56600.00
D839B8	2017-07-30 12:49:00+03	23200.00
D839F7	2017-07-06 22:43:00+03	332800.00
D83A1B	2017-07-13 14:32:00+03	75300.00
D83AA8	2017-08-15 09:37:00+03	47400.00
D83AF8	2017-08-01 11:25:00+03	122400.00
D83B0A	2017-07-20 10:31:00+03	55800.00
D83B7D	2017-07-26 23:06:00+03	36200.00
D83B7F	2017-08-11 10:48:00+03	46400.00
D83BD5	2017-07-06 14:21:00+03	42700.00
D83C05	2017-08-02 11:45:00+03	96200.00
D83C9B	2017-07-12 17:03:00+03	24400.00
D83CD3	2017-07-07 17:01:00+03	135200.00
D83D67	2017-07-07 20:23:00+03	58600.00
D83DA7	2017-07-07 09:09:00+03	28000.00
D83E4A	2017-07-10 21:13:00+03	234600.00
D83E6F	2017-07-13 05:55:00+03	179600.00
D83EA2	2017-07-19 09:37:00+03	23600.00
D83FD0	2017-08-08 13:23:00+03	204100.00
D840BC	2017-08-09 14:01:00+03	22000.00
D840FA	2017-07-11 23:31:00+03	23200.00
D84112	2017-08-05 21:56:00+03	84100.00
D8415E	2017-08-13 13:26:00+03	46300.00
D8419F	2017-07-21 02:25:00+03	226800.00
D841DB	2017-07-08 23:12:00+03	31600.00
D841FF	2017-08-13 17:07:00+03	91200.00
D84225	2017-07-10 04:39:00+03	66600.00
D84263	2017-07-20 07:04:00+03	73000.00
D84264	2017-08-14 19:32:00+03	31300.00
D84329	2017-08-07 10:58:00+03	15100.00
D84358	2017-08-13 23:13:00+03	85400.00
D8437C	2017-07-31 20:11:00+03	119500.00
D843A4	2017-07-12 14:15:00+03	41400.00
D84449	2017-08-09 22:32:00+03	27800.00
D84492	2017-08-08 21:28:00+03	22400.00
D844B9	2017-07-09 21:14:00+03	24400.00
D844DF	2017-06-30 09:21:00+03	120400.00
D844E4	2017-08-09 05:41:00+03	18600.00
D844E8	2017-08-11 02:42:00+03	9200.00
D8456C	2017-08-13 21:12:00+03	599000.00
D8457B	2017-07-21 14:04:00+03	57500.00
D845B6	2017-08-08 04:06:00+03	25600.00
D845E9	2017-07-31 08:40:00+03	36400.00
D845F8	2017-08-04 04:08:00+03	67600.00
D84639	2017-07-16 17:39:00+03	34100.00
D84763	2017-07-19 15:36:00+03	56600.00
D84768	2017-07-31 20:28:00+03	50600.00
D84778	2017-07-25 09:13:00+03	8200.00
D8477F	2017-08-05 21:30:00+03	87300.00
D8478B	2017-07-14 12:28:00+03	372500.00
D8481E	2017-07-23 06:30:00+03	90400.00
D8483C	2017-08-02 03:51:00+03	32700.00
D84850	2017-08-03 10:57:00+03	46200.00
D84862	2017-08-02 22:10:00+03	28000.00
D8491A	2017-07-03 07:33:00+03	54800.00
D84940	2017-08-11 07:24:00+03	71000.00
D84955	2017-07-27 06:28:00+03	67600.00
D84957	2017-07-26 17:48:00+03	42900.00
D84A18	2017-06-29 18:57:00+03	40000.00
D84A45	2017-07-09 01:24:00+03	95600.00
D84AEF	2017-07-24 06:09:00+03	25100.00
D84B36	2017-07-17 09:56:00+03	55800.00
D84B83	2017-07-29 03:22:00+03	56000.00
D84BE1	2017-08-07 09:03:00+03	111700.00
D84C03	2017-06-29 14:45:00+03	30200.00
D84C2C	2017-06-30 10:13:00+03	47100.00
D84C4C	2017-07-15 21:04:00+03	31600.00
D84C5F	2017-08-11 18:39:00+03	42800.00
D84C64	2017-07-31 09:44:00+03	36800.00
D84C66	2017-07-18 13:46:00+03	6700.00
D84C7E	2017-08-15 17:07:00+03	124200.00
D84C8C	2017-07-25 16:26:00+03	394400.00
D84CCD	2017-07-16 17:38:00+03	92800.00
D84D5B	2017-07-02 04:58:00+03	23200.00
D84DB5	2017-07-03 18:49:00+03	48800.00
D84DC6	2017-07-03 06:02:00+03	25400.00
D84DF4	2017-07-29 21:33:00+03	19600.00
D84E66	2017-07-13 19:18:00+03	40000.00
D84F12	2017-07-24 03:28:00+03	73800.00
D84F1A	2017-07-20 11:03:00+03	77200.00
D84F1B	2017-08-12 20:02:00+03	38400.00
D84F48	2017-07-06 20:30:00+03	8000.00
D84F80	2017-08-07 21:08:00+03	97900.00
D84FC9	2017-08-11 05:53:00+03	20800.00
D84FD4	2017-08-15 14:05:00+03	20200.00
D85022	2017-07-06 07:35:00+03	40100.00
D85041	2017-07-30 17:34:00+03	46300.00
D8504C	2017-07-29 21:00:00+03	64100.00
D85072	2017-07-21 05:31:00+03	142400.00
D8508F	2017-07-09 02:17:00+03	85200.00
D850A0	2017-07-29 13:44:00+03	343400.00
D85103	2017-07-14 14:23:00+03	190300.00
D85163	2017-08-02 05:26:00+03	58000.00
D8516D	2017-08-09 07:40:00+03	84200.00
D85176	2017-07-20 05:49:00+03	289800.00
D851CB	2017-08-13 13:23:00+03	43200.00
D851D1	2017-07-18 10:26:00+03	134400.00
D8524C	2017-07-04 22:07:00+03	47400.00
D8527B	2017-07-15 00:28:00+03	282600.00
D85316	2017-07-15 12:37:00+03	63400.00
D8531B	2017-08-07 10:01:00+03	37000.00
D85352	2017-07-29 06:27:00+03	3700.00
D853AC	2017-08-15 10:13:00+03	13400.00
D8545D	2017-07-30 06:20:00+03	29300.00
D85497	2017-07-08 15:50:00+03	226800.00
D854CC	2017-07-07 13:13:00+03	149200.00
D854D3	2017-08-09 16:37:00+03	28800.00
D854D7	2017-07-14 23:04:00+03	48800.00
D854F7	2017-08-03 04:24:00+03	35900.00
D85547	2017-08-07 20:13:00+03	26400.00
D855AB	2017-08-03 09:00:00+03	75600.00
D856A2	2017-08-03 06:08:00+03	114400.00
D85704	2017-07-02 19:29:00+03	34600.00
D8571E	2017-07-24 22:15:00+03	6800.00
D8575B	2017-07-08 20:55:00+03	23100.00
D8577D	2017-07-14 13:39:00+03	111600.00
D85785	2017-07-15 06:11:00+03	73500.00
D857A5	2017-07-21 18:36:00+03	90800.00
D8581F	2017-08-13 16:59:00+03	44300.00
D85894	2017-07-24 05:00:00+03	26000.00
D858E8	2017-06-27 05:42:00+03	24000.00
D85923	2017-06-28 03:34:00+03	45200.00
D85935	2017-08-14 20:37:00+03	85300.00
D8593C	2017-08-14 14:39:00+03	134600.00
D85A06	2017-08-07 00:53:00+03	112600.00
D85A14	2017-07-08 14:05:00+03	66900.00
D85A1B	2017-08-13 00:05:00+03	14400.00
D85A2D	2017-07-06 17:52:00+03	79600.00
D85A41	2017-07-23 09:35:00+03	15000.00
D85A76	2017-08-07 20:03:00+03	38800.00
D85A91	2017-07-04 21:22:00+03	26000.00
D85BA2	2017-07-22 00:45:00+03	55800.00
D85BC4	2017-07-25 13:01:00+03	56600.00
D85C53	2017-07-16 08:52:00+03	59100.00
D85C9B	2017-07-08 06:34:00+03	344700.00
D85CC1	2017-08-05 10:52:00+03	135400.00
D85CDA	2017-08-15 17:59:00+03	12000.00
D85D13	2017-06-30 04:10:00+03	68400.00
D85D68	2017-06-30 18:51:00+03	34000.00
D85D83	2017-08-03 11:07:00+03	31400.00
D85D95	2017-07-30 05:07:00+03	51600.00
D85E58	2017-07-29 06:03:00+03	7400.00
D85E79	2017-08-14 12:27:00+03	288300.00
D85EBF	2017-08-14 01:00:00+03	80700.00
D85F0D	2017-07-27 10:47:00+03	43200.00
D85F1F	2017-07-14 10:59:00+03	70700.00
D85F22	2017-08-11 05:15:00+03	47200.00
D86013	2017-07-31 19:41:00+03	28800.00
D86016	2017-08-03 12:16:00+03	21400.00
D86077	2017-08-10 13:35:00+03	166100.00
D860B7	2017-08-12 17:33:00+03	167400.00
D860D5	2017-07-05 07:40:00+03	89700.00
D86123	2017-08-02 10:20:00+03	37900.00
D86216	2017-07-24 04:53:00+03	14400.00
D86228	2017-07-07 17:33:00+03	24400.00
D86229	2017-08-05 17:32:00+03	31000.00
D8622E	2017-07-09 07:40:00+03	6000.00
D8634E	2017-07-16 17:59:00+03	84400.00
D863A9	2017-08-13 22:19:00+03	133200.00
D863C0	2017-08-09 19:49:00+03	95800.00
D863C6	2017-07-24 13:20:00+03	30000.00
D863D4	2017-08-12 05:54:00+03	40600.00
D863F6	2017-07-27 12:32:00+03	31600.00
D8642B	2017-07-13 14:47:00+03	38800.00
D864C9	2017-08-13 02:04:00+03	23200.00
D86522	2017-07-21 16:47:00+03	28800.00
D86551	2017-07-22 13:24:00+03	26000.00
D8655C	2017-07-23 07:40:00+03	330200.00
D8655D	2017-07-19 01:25:00+03	154500.00
D86660	2017-08-04 14:45:00+03	28700.00
D8666C	2017-07-23 15:28:00+03	16800.00
D8667A	2017-07-28 08:01:00+03	258400.00
D8667B	2017-07-20 07:12:00+03	34000.00
D86685	2017-08-14 06:33:00+03	71600.00
D866B8	2017-07-12 01:33:00+03	67200.00
D866DC	2017-07-31 22:27:00+03	176800.00
D866E4	2017-07-02 21:26:00+03	40800.00
D8670B	2017-07-30 21:28:00+03	85700.00
D86721	2017-07-12 08:00:00+03	18900.00
D8674B	2017-08-12 17:55:00+03	43900.00
D86759	2017-07-16 00:29:00+03	66000.00
D86775	2017-07-20 17:24:00+03	124000.00
D8678D	2017-07-16 08:49:00+03	58000.00
D867C7	2017-07-21 20:38:00+03	23100.00
D867CE	2017-08-01 12:49:00+03	52700.00
D867E7	2017-07-12 14:11:00+03	55600.00
D867FA	2017-08-05 21:31:00+03	387300.00
D8683A	2017-08-12 20:57:00+03	31100.00
D86872	2017-08-03 02:44:00+03	167400.00
D86874	2017-07-10 16:46:00+03	21400.00
D86918	2017-07-29 03:55:00+03	27200.00
D86930	2017-08-04 20:42:00+03	73600.00
D86960	2017-08-10 13:53:00+03	92100.00
D869B1	2017-07-27 14:53:00+03	13400.00
D869C5	2017-07-15 20:44:00+03	48800.00
D86A38	2017-07-12 14:50:00+03	23200.00
D86A75	2017-07-08 20:34:00+03	93800.00
D86A9E	2017-07-13 22:32:00+03	29100.00
D86AB1	2017-08-13 09:58:00+03	14400.00
D86B0A	2017-07-13 00:25:00+03	75300.00
D86B54	2017-07-20 02:54:00+03	13600.00
D86B96	2017-08-09 21:44:00+03	14000.00
D86BC9	2017-08-13 17:29:00+03	12600.00
D86BF9	2017-07-22 17:31:00+03	97500.00
D86C14	2017-08-01 16:55:00+03	66600.00
D86C16	2017-08-01 18:41:00+03	6700.00
D86C28	2017-08-03 22:34:00+03	97000.00
D86C4E	2017-08-06 15:46:00+03	72300.00
D86CA9	2017-08-09 19:44:00+03	47200.00
D86CF0	2017-07-14 16:47:00+03	12600.00
D86D7D	2017-07-15 11:06:00+03	26000.00
D86D7E	2017-07-28 17:13:00+03	47600.00
D86D9A	2017-07-16 11:31:00+03	137400.00
D86DE6	2017-07-28 01:45:00+03	68000.00
D86E39	2017-07-02 13:14:00+03	12400.00
D86E46	2017-08-14 19:55:00+03	139300.00
D86E92	2017-07-04 22:51:00+03	85000.00
D86ED2	2017-08-07 23:38:00+03	73500.00
D86F52	2017-08-02 14:46:00+03	84100.00
D86F88	2017-07-02 09:41:00+03	149300.00
D86FBA	2017-08-11 22:29:00+03	142300.00
D86FFD	2017-07-04 01:18:00+03	11600.00
D87072	2017-08-13 10:46:00+03	45100.00
D870E2	2017-07-09 17:29:00+03	46400.00
D87158	2017-07-23 08:51:00+03	74900.00
D87167	2017-08-03 10:41:00+03	185300.00
D8716A	2017-08-14 21:44:00+03	123600.00
D8726C	2017-08-15 11:09:00+03	39100.00
D872A4	2017-08-10 02:54:00+03	23400.00
D87344	2017-07-20 05:37:00+03	79800.00
D87362	2017-07-27 11:32:00+03	72400.00
D87378	2017-08-01 04:16:00+03	112600.00
D87387	2017-07-23 10:33:00+03	26000.00
D87423	2017-08-05 06:35:00+03	46400.00
D8745A	2017-07-18 06:30:00+03	90700.00
D874A1	2017-08-02 07:39:00+03	81400.00
D874DB	2017-07-05 02:30:00+03	66600.00
D87533	2017-07-10 00:34:00+03	44200.00
D8757E	2017-07-09 12:19:00+03	132800.00
D875E3	2017-07-16 19:55:00+03	123000.00
D87624	2017-07-19 06:12:00+03	305400.00
D8763A	2017-07-05 02:28:00+03	7300.00
D876C3	2017-07-24 11:40:00+03	26000.00
D876DA	2017-07-29 19:01:00+03	132800.00
D877D4	2017-08-11 17:57:00+03	23600.00
D877E4	2017-07-21 23:49:00+03	39200.00
D87857	2017-07-28 00:42:00+03	55600.00
D878DA	2017-07-13 09:11:00+03	42800.00
D87905	2017-06-26 02:43:00+03	32800.00
D87929	2017-07-11 17:44:00+03	75300.00
D8795D	2017-07-15 06:11:00+03	43600.00
D8796B	2017-07-31 04:31:00+03	198600.00
D87A14	2017-06-30 04:15:00+03	88100.00
D87A23	2017-07-19 21:39:00+03	67700.00
D87A47	2017-08-06 23:54:00+03	61800.00
D87A6E	2017-07-31 21:57:00+03	49900.00
D87A79	2017-07-11 21:54:00+03	10700.00
D87AB5	2017-08-03 10:40:00+03	42700.00
D87B54	2017-07-15 22:51:00+03	28800.00
D87B56	2017-06-28 07:03:00+03	14400.00
D87B69	2017-08-05 07:19:00+03	23400.00
D87C13	2017-08-02 21:45:00+03	134400.00
D87C1F	2017-07-08 17:45:00+03	55800.00
D87CCC	2017-08-12 17:55:00+03	85000.00
D87CDC	2017-07-11 10:55:00+03	67800.00
D87D23	2017-07-07 20:39:00+03	57600.00
D87D3C	2017-08-07 19:41:00+03	133200.00
D87D58	2017-08-01 08:34:00+03	30000.00
D87DFC	2017-07-16 01:55:00+03	31000.00
D87E5B	2017-07-26 08:32:00+03	8000.00
D87E6B	2017-08-01 03:13:00+03	20500.00
D87E72	2017-07-07 21:07:00+03	31400.00
D87E84	2017-08-09 02:31:00+03	85000.00
D87E8B	2017-08-14 21:24:00+03	14400.00
D87E9E	2017-07-20 18:44:00+03	192900.00
D87ED9	2017-07-08 05:49:00+03	101800.00
D87EF9	2017-07-19 11:23:00+03	94000.00
D87F90	2017-07-26 17:36:00+03	26800.00
D87FC9	2017-07-17 01:20:00+03	123600.00
D87FE0	2017-08-13 18:48:00+03	91600.00
D87FF4	2017-07-26 13:36:00+03	57600.00
D88069	2017-08-06 03:38:00+03	123000.00
D8807B	2017-08-08 03:39:00+03	90400.00
D88086	2017-08-14 00:43:00+03	26000.00
D880E0	2017-07-18 20:36:00+03	6700.00
D88193	2017-07-03 20:51:00+03	233000.00
D881D8	2017-07-04 03:31:00+03	10700.00
D8823A	2017-08-14 20:14:00+03	150600.00
D8823E	2017-07-09 02:57:00+03	19600.00
D88242	2017-07-30 03:33:00+03	47500.00
D88285	2017-07-25 23:16:00+03	259800.00
D882B5	2017-07-17 10:19:00+03	175300.00
D882B7	2017-07-23 00:02:00+03	44800.00
D882EE	2017-07-19 09:09:00+03	7400.00
D882FC	2017-08-08 20:00:00+03	21600.00
D8830F	2017-08-02 14:53:00+03	73300.00
D88343	2017-07-10 18:01:00+03	24200.00
D88356	2017-07-28 10:54:00+03	23600.00
D88371	2017-08-04 04:40:00+03	15700.00
D883D7	2017-07-27 00:23:00+03	168000.00
D88446	2017-08-07 16:57:00+03	50800.00
D88447	2017-07-01 09:37:00+03	21200.00
D88468	2017-07-18 16:39:00+03	147600.00
D884B4	2017-08-07 04:24:00+03	73600.00
D88510	2017-07-20 06:23:00+03	43900.00
D88555	2017-07-30 21:56:00+03	123000.00
D88578	2017-07-16 23:19:00+03	131600.00
D88593	2017-08-13 01:28:00+03	59300.00
D88594	2017-07-02 08:08:00+03	65900.00
D885AE	2017-07-26 12:19:00+03	54900.00
D885B9	2017-08-05 08:35:00+03	63200.00
D8862D	2017-08-06 23:04:00+03	23600.00
D88655	2017-07-31 13:33:00+03	31600.00
D88687	2017-06-30 16:46:00+03	28800.00
D886D7	2017-08-12 01:09:00+03	59200.00
D886F9	2017-08-07 19:22:00+03	46000.00
D88748	2017-07-26 07:45:00+03	58100.00
D887C4	2017-07-16 16:31:00+03	16400.00
D887C6	2017-07-01 19:32:00+03	54800.00
D88826	2017-07-29 18:13:00+03	85000.00
D88882	2017-07-08 23:22:00+03	67900.00
D88898	2017-07-12 03:50:00+03	92800.00
D8889A	2017-08-13 18:54:00+03	23600.00
D888BA	2017-08-08 00:00:00+03	56000.00
D888C1	2017-07-29 19:25:00+03	144000.00
D888C2	2017-07-18 07:52:00+03	44600.00
D888E6	2017-08-11 18:44:00+03	30200.00
D888FF	2017-08-01 01:35:00+03	48500.00
D88922	2017-07-31 09:30:00+03	14400.00
D889A2	2017-08-10 16:20:00+03	123000.00
D889A6	2017-08-13 23:48:00+03	66600.00
D889D1	2017-08-11 02:07:00+03	53200.00
D88A36	2017-07-26 00:16:00+03	47800.00
D88A3B	2017-08-04 10:51:00+03	46800.00
D88A9C	2017-08-05 06:21:00+03	77900.00
D88ACF	2017-08-15 10:34:00+03	26000.00
D88B43	2017-08-04 16:07:00+03	328300.00
D88B96	2017-08-09 13:08:00+03	32800.00
D88BB1	2017-07-06 16:38:00+03	40800.00
D88BE4	2017-07-07 02:17:00+03	112000.00
D88C00	2017-08-12 08:50:00+03	86800.00
D88C40	2017-07-23 16:29:00+03	159300.00
D88CED	2017-08-06 07:32:00+03	48400.00
D88D00	2017-08-09 06:33:00+03	27300.00
D88D39	2017-07-17 05:52:00+03	58000.00
D88D3A	2017-07-11 00:54:00+03	81300.00
D88D44	2017-07-16 11:44:00+03	47900.00
D88D6E	2017-07-13 15:56:00+03	123000.00
D88DB9	2017-07-21 02:15:00+03	56000.00
D88E15	2017-07-12 18:48:00+03	46400.00
D88E78	2017-08-07 02:32:00+03	105600.00
D88E80	2017-07-24 02:54:00+03	40800.00
D88ECD	2017-07-12 21:04:00+03	154500.00
D88ED1	2017-08-14 15:46:00+03	83000.00
D88EE4	2017-07-05 03:54:00+03	136200.00
D88FAA	2017-07-21 02:12:00+03	55600.00
D89019	2017-07-13 10:29:00+03	40800.00
D89033	2017-08-03 04:35:00+03	39700.00
D8906F	2017-08-07 05:39:00+03	64800.00
D890CE	2017-07-09 10:00:00+03	23200.00
D890D2	2017-07-01 13:24:00+03	7200.00
D89149	2017-07-09 09:40:00+03	99500.00
D89193	2017-07-11 10:20:00+03	16400.00
D8919A	2017-07-02 18:51:00+03	46300.00
D8920E	2017-08-08 10:31:00+03	16800.00
D89287	2017-06-30 22:50:00+03	73200.00
D89294	2017-07-25 13:04:00+03	26700.00
D89295	2017-08-07 08:13:00+03	70800.00
D89342	2017-08-10 02:03:00+03	8400.00
D89468	2017-08-10 22:05:00+03	33400.00
D89498	2017-08-12 10:51:00+03	13400.00
D894F2	2017-07-27 05:46:00+03	28000.00
D8950B	2017-08-04 03:17:00+03	73200.00
D8951A	2017-08-03 07:39:00+03	62200.00
D89575	2017-07-03 07:26:00+03	85500.00
D8957E	2017-07-17 19:09:00+03	173900.00
D8959D	2017-07-13 10:41:00+03	47000.00
D8959F	2017-07-07 05:33:00+03	40600.00
D895A3	2017-07-25 08:39:00+03	57500.00
D89603	2017-07-17 09:32:00+03	114300.00
D89621	2017-08-01 02:47:00+03	73500.00
D8966C	2017-07-03 05:24:00+03	35300.00
D896AA	2017-07-08 20:33:00+03	34000.00
D896B5	2017-08-02 11:27:00+03	11000.00
D896FB	2017-07-30 13:14:00+03	35800.00
D89742	2017-07-18 03:33:00+03	24700.00
D89769	2017-07-19 21:19:00+03	62800.00
D897A9	2017-07-26 13:58:00+03	24400.00
D897D3	2017-08-03 05:18:00+03	56600.00
D89835	2017-08-12 18:55:00+03	138300.00
D89839	2017-07-05 00:42:00+03	57700.00
D8987E	2017-08-06 21:02:00+03	16400.00
D898A9	2017-07-05 08:14:00+03	28800.00
D898C8	2017-07-18 21:14:00+03	39200.00
D89902	2017-08-10 09:24:00+03	23200.00
D8992E	2017-08-01 01:57:00+03	92400.00
D89A7D	2017-07-11 17:55:00+03	79000.00
D89B14	2017-07-15 11:08:00+03	25400.00
D89B61	2017-07-05 09:44:00+03	24000.00
D89B85	2017-08-07 20:18:00+03	53200.00
D89B8B	2017-07-26 18:56:00+03	40600.00
D89BE5	2017-07-13 07:40:00+03	70900.00
D89C67	2017-07-18 04:21:00+03	114800.00
D89CEC	2017-08-06 04:08:00+03	115600.00
D89D7D	2017-07-03 19:36:00+03	86400.00
D89D8D	2017-08-13 17:41:00+03	148200.00
D89DAC	2017-07-11 05:12:00+03	131100.00
D89DBA	2017-07-19 23:26:00+03	98300.00
D89DDA	2017-07-21 00:46:00+03	58200.00
D89E1A	2017-07-23 13:40:00+03	133200.00
D89E33	2017-07-16 10:20:00+03	23600.00
D89E70	2017-07-05 18:54:00+03	13200.00
D89E9A	2017-07-08 22:46:00+03	58800.00
D89EEC	2017-08-06 08:41:00+03	113300.00
D89F0B	2017-08-09 11:16:00+03	55400.00
D89F3B	2017-07-23 08:32:00+03	29400.00
D89F47	2017-07-13 11:27:00+03	79300.00
D89FD7	2017-07-27 06:04:00+03	94400.00
D8A048	2017-08-08 19:41:00+03	39800.00
D8A068	2017-08-10 13:46:00+03	491000.00
D8A0D9	2017-07-22 20:13:00+03	65900.00
D8A0F9	2017-07-28 06:44:00+03	132800.00
D8A0FF	2017-07-09 07:04:00+03	13800.00
D8A291	2017-07-29 17:38:00+03	19600.00
D8A2EB	2017-07-31 07:24:00+03	37900.00
D8A33D	2017-08-14 15:35:00+03	87100.00
D8A343	2017-07-29 09:39:00+03	69900.00
D8A38B	2017-07-16 06:57:00+03	28800.00
D8A396	2017-07-16 06:19:00+03	57600.00
D8A3B1	2017-08-14 10:48:00+03	144900.00
D8A41E	2017-08-13 05:29:00+03	28800.00
D8A4B6	2017-08-12 16:50:00+03	88300.00
D8A505	2017-08-01 15:46:00+03	67200.00
D8A586	2017-07-14 14:06:00+03	38800.00
D8A5A9	2017-08-14 19:39:00+03	13400.00
D8A5DF	2017-07-12 04:32:00+03	75600.00
D8A6A0	2017-07-25 01:17:00+03	136800.00
D8A6E0	2017-07-09 20:33:00+03	31400.00
D8A736	2017-08-15 04:02:00+03	111600.00
D8A74E	2017-07-03 03:53:00+03	22100.00
D8A752	2017-07-02 05:12:00+03	48500.00
D8A77F	2017-07-05 22:45:00+03	69000.00
D8A7E3	2017-07-14 03:55:00+03	45400.00
D8A867	2017-06-29 22:50:00+03	94800.00
D8A882	2017-07-18 11:21:00+03	40000.00
D8A8A3	2017-07-07 12:19:00+03	27300.00
D8A8F7	2017-07-22 10:21:00+03	21400.00
D8A8F9	2017-07-25 10:53:00+03	120000.00
D8A914	2017-08-05 15:17:00+03	75800.00
D8A94F	2017-07-18 19:37:00+03	61500.00
D8A958	2017-08-01 10:14:00+03	224000.00
D8A977	2017-08-07 10:38:00+03	57000.00
D8A990	2017-07-07 16:33:00+03	43200.00
D8A996	2017-08-02 11:18:00+03	65100.00
D8A99B	2017-07-09 13:26:00+03	48800.00
D8AA98	2017-07-26 15:10:00+03	85000.00
D8AAFC	2017-08-07 14:47:00+03	73500.00
D8AB27	2017-07-24 14:13:00+03	246000.00
D8AB29	2017-07-18 23:08:00+03	28800.00
D8AB59	2017-07-31 22:03:00+03	13400.00
D8AB71	2017-07-28 17:46:00+03	29600.00
D8AB72	2017-07-29 20:44:00+03	6400.00
D8AB8C	2017-07-12 22:01:00+03	27300.00
D8ABAF	2017-07-15 09:40:00+03	56900.00
D8AC19	2017-08-14 19:26:00+03	534300.00
D8AC64	2017-07-22 06:37:00+03	12600.00
D8AD23	2017-08-12 22:24:00+03	58900.00
D8AD29	2017-08-10 18:30:00+03	62600.00
D8AD48	2017-08-11 09:14:00+03	56000.00
D8AD4F	2017-07-27 13:20:00+03	46400.00
D8ADC5	2017-08-15 10:23:00+03	14000.00
D8ADEA	2017-08-09 12:19:00+03	39600.00
D8AE52	2017-07-18 12:37:00+03	332500.00
D8AEC3	2017-07-23 14:31:00+03	133100.00
D8AEE4	2017-07-06 04:06:00+03	119800.00
D8AF00	2017-07-13 10:15:00+03	44600.00
D8AF8D	2017-07-18 19:45:00+03	53400.00
D8AF9B	2017-07-27 03:01:00+03	37100.00
D8AFE2	2017-07-19 21:27:00+03	188000.00
D8B01B	2017-07-25 16:33:00+03	56600.00
D8B01F	2017-07-04 14:50:00+03	72200.00
D8B022	2017-07-29 03:30:00+03	37100.00
D8B041	2017-08-03 00:53:00+03	21400.00
D8B061	2017-08-05 20:47:00+03	97600.00
D8B0A1	2017-07-16 11:26:00+03	43700.00
D8B132	2017-08-08 14:11:00+03	24400.00
D8B1C6	2017-07-10 03:50:00+03	111600.00
D8B1CE	2017-07-10 09:19:00+03	156300.00
D8B1DE	2017-08-04 18:04:00+03	46400.00
D8B1EA	2017-07-21 03:57:00+03	67600.00
D8B228	2017-08-07 10:41:00+03	11700.00
D8B22D	2017-08-05 12:17:00+03	24400.00
D8B25C	2017-07-24 12:18:00+03	61800.00
D8B26C	2017-07-26 06:25:00+03	110000.00
D8B293	2017-07-04 16:12:00+03	26700.00
D8B299	2017-08-09 02:17:00+03	112000.00
D8B2DE	2017-07-19 09:51:00+03	46500.00
D8B2E4	2017-07-02 10:18:00+03	96200.00
D8B333	2017-07-13 17:10:00+03	6800.00
D8B38A	2017-07-24 21:21:00+03	68800.00
D8B391	2017-07-27 16:00:00+03	25200.00
D8B3D8	2017-07-11 08:44:00+03	62800.00
D8B422	2017-08-02 08:25:00+03	29600.00
D8B478	2017-07-10 14:41:00+03	73500.00
D8B487	2017-08-09 21:26:00+03	66600.00
D8B51F	2017-07-06 10:18:00+03	14000.00
D8B579	2017-08-11 02:44:00+03	85000.00
D8B58C	2017-08-02 23:04:00+03	66000.00
D8B594	2017-07-24 23:40:00+03	73400.00
D8B5FF	2017-08-13 09:15:00+03	66600.00
D8B665	2017-07-10 09:04:00+03	56600.00
D8B68C	2017-08-08 11:27:00+03	81700.00
D8B6F0	2017-07-15 01:33:00+03	111700.00
D8B713	2017-07-04 17:31:00+03	6000.00
D8B7B8	2017-07-21 03:29:00+03	163900.00
D8B803	2017-07-17 17:47:00+03	99200.00
D8B82E	2017-07-13 09:05:00+03	164800.00
D8B880	2017-07-28 05:49:00+03	246000.00
D8B93C	2017-08-09 20:02:00+03	40000.00
D8B957	2017-07-06 18:36:00+03	100600.00
D8BA9C	2017-08-10 04:04:00+03	258400.00
D8BAA6	2017-07-07 21:53:00+03	66600.00
D8BAB0	2017-07-30 22:00:00+03	51500.00
D8BB1A	2017-07-17 04:10:00+03	393800.00
D8BB75	2017-07-09 22:04:00+03	279000.00
D8BB8C	2017-08-10 21:53:00+03	40800.00
D8BBD9	2017-07-31 23:11:00+03	149400.00
D8BC3D	2017-08-03 06:59:00+03	31400.00
D8BC83	2017-07-17 06:09:00+03	14800.00
D8BCAF	2017-07-09 14:44:00+03	28600.00
D8BCB6	2017-07-27 11:39:00+03	65600.00
D8BCBF	2017-07-17 13:07:00+03	14400.00
D8BD2D	2017-07-23 00:14:00+03	94300.00
D8BD41	2017-07-11 19:36:00+03	288600.00
D8BEFD	2017-08-12 05:52:00+03	62000.00
D8BF15	2017-07-04 09:37:00+03	13400.00
D8BF7B	2017-07-08 14:20:00+03	28000.00
D8C024	2017-07-24 13:38:00+03	21400.00
D8C109	2017-07-30 22:02:00+03	68800.00
D8C160	2017-08-04 19:33:00+03	44700.00
D8C176	2017-07-16 20:08:00+03	6800.00
D8C184	2017-07-20 01:21:00+03	23900.00
D8C192	2017-07-03 22:16:00+03	12400.00
D8C1F1	2017-07-28 07:58:00+03	28000.00
D8C21B	2017-07-25 18:41:00+03	50600.00
D8C231	2017-08-09 01:16:00+03	398500.00
D8C27A	2017-08-14 00:55:00+03	17200.00
D8C27C	2017-08-13 11:54:00+03	66700.00
D8C2F7	2017-07-23 01:59:00+03	21800.00
D8C388	2017-07-09 03:43:00+03	24700.00
D8C42C	2017-07-02 04:26:00+03	46000.00
D8C4A7	2017-07-16 09:49:00+03	178800.00
D8C4B7	2017-08-09 11:33:00+03	103600.00
D8C4ED	2017-06-29 16:47:00+03	25600.00
D8C4FF	2017-07-20 13:38:00+03	100600.00
D8C500	2017-06-30 15:04:00+03	16400.00
D8C59F	2017-08-13 19:00:00+03	14000.00
D8C5AE	2017-07-07 01:46:00+03	23600.00
D8C609	2017-07-29 15:40:00+03	63300.00
D8C617	2017-07-05 11:48:00+03	31600.00
D8C637	2017-08-09 19:47:00+03	193900.00
D8C68F	2017-07-16 10:10:00+03	92700.00
D8C69E	2017-08-02 18:21:00+03	25000.00
D8C6FE	2017-07-17 13:45:00+03	47100.00
D8C70B	2017-07-02 08:03:00+03	33300.00
D8C751	2017-07-06 10:17:00+03	284800.00
D8C762	2017-08-15 01:24:00+03	22200.00
D8C77C	2017-07-14 01:49:00+03	46000.00
D8C7E7	2017-07-10 06:53:00+03	87400.00
D8C867	2017-07-02 09:52:00+03	105700.00
D8C8CD	2017-06-30 03:52:00+03	248400.00
D8C925	2017-08-06 09:30:00+03	28000.00
D8C98C	2017-07-19 07:32:00+03	25100.00
D8CA2F	2017-08-07 12:59:00+03	31400.00
D8CA82	2017-07-10 15:31:00+03	123000.00
D8CAEA	2017-08-01 14:30:00+03	10800.00
D8CB7E	2017-07-07 09:40:00+03	100600.00
D8CBC1	2017-08-03 06:10:00+03	106400.00
D8CC62	2017-08-07 07:36:00+03	6700.00
D8CCF1	2017-07-13 21:00:00+03	145100.00
D8CD4B	2017-07-24 11:41:00+03	12800.00
D8CD9F	2017-07-26 20:37:00+03	20200.00
D8CDAD	2017-07-22 22:52:00+03	143100.00
D8CE7C	2017-07-09 16:10:00+03	6300.00
D8CEAC	2017-07-16 07:36:00+03	6700.00
D8CEEF	2017-08-02 06:02:00+03	64200.00
D8CF22	2017-07-19 13:56:00+03	65400.00
D8CF6C	2017-08-11 02:21:00+03	25200.00
D8CF8B	2017-07-22 13:10:00+03	22600.00
D8CFB4	2017-07-28 23:56:00+03	49600.00
D8D072	2017-07-13 18:00:00+03	85000.00
D8D087	2017-08-02 09:51:00+03	55700.00
D8D0CE	2017-08-05 03:31:00+03	147700.00
D8D0D8	2017-08-06 20:35:00+03	53600.00
D8D0E4	2017-08-14 01:01:00+03	6800.00
D8D0E7	2017-07-22 00:31:00+03	258300.00
D8D0E8	2017-08-11 03:49:00+03	46000.00
D8D10A	2017-07-22 18:51:00+03	187800.00
D8D11E	2017-07-02 09:25:00+03	122300.00
D8D14E	2017-07-20 12:34:00+03	23200.00
D8D150	2017-08-06 05:23:00+03	27200.00
D8D159	2017-08-09 14:32:00+03	38800.00
D8D17B	2017-07-14 20:21:00+03	29600.00
D8D1D8	2017-07-17 02:40:00+03	25400.00
D8D252	2017-07-06 03:24:00+03	69600.00
D8D27A	2017-08-02 18:44:00+03	23600.00
D8D343	2017-08-12 17:20:00+03	140900.00
D8D35A	2017-08-08 04:13:00+03	4000.00
D8D35E	2017-06-30 17:16:00+03	43200.00
D8D361	2017-08-02 18:15:00+03	13400.00
D8D366	2017-08-11 11:23:00+03	260900.00
D8D37F	2017-08-01 22:03:00+03	168000.00
D8D3DB	2017-06-29 06:50:00+03	8200.00
D8D3FA	2017-07-08 04:44:00+03	137700.00
D8D3FD	2017-07-25 03:45:00+03	101400.00
D8D466	2017-07-25 13:19:00+03	58600.00
D8D4AC	2017-07-20 13:02:00+03	109600.00
D8D4D5	2017-07-09 06:55:00+03	59800.00
D8D4D9	2017-07-28 10:46:00+03	90600.00
D8D50E	2017-08-01 05:24:00+03	90300.00
D8D546	2017-07-09 06:52:00+03	56100.00
D8D571	2017-07-11 16:30:00+03	87200.00
D8D5B2	2017-07-25 01:38:00+03	203000.00
D8D5D3	2017-07-11 22:55:00+03	29600.00
D8D5FA	2017-08-07 05:38:00+03	6800.00
D8D62F	2017-07-24 23:59:00+03	11000.00
D8D680	2017-07-03 23:27:00+03	56900.00
D8D778	2017-07-05 14:13:00+03	36800.00
D8D800	2017-07-20 07:25:00+03	24200.00
D8D829	2017-08-15 04:13:00+03	58000.00
D8D8B6	2017-07-30 13:38:00+03	139100.00
D8D8EC	2017-08-07 07:28:00+03	69000.00
D8D970	2017-07-16 07:48:00+03	89700.00
D8D974	2017-07-26 04:20:00+03	116900.00
D8D976	2017-08-03 22:27:00+03	55800.00
D8D9E0	2017-07-29 06:18:00+03	75200.00
D8DA19	2017-07-11 22:28:00+03	111600.00
D8DA6C	2017-07-09 21:45:00+03	48800.00
D8DA8C	2017-07-11 15:43:00+03	95600.00
D8DB04	2017-07-16 06:35:00+03	99300.00
D8DB65	2017-07-26 17:02:00+03	134100.00
D8DBA1	2017-07-28 22:13:00+03	64700.00
D8DBB4	2017-07-19 09:12:00+03	46000.00
D8DBDB	2017-08-04 19:03:00+03	151200.00
D8DBFA	2017-07-31 22:24:00+03	128800.00
D8DC3D	2017-08-03 09:07:00+03	100600.00
D8DC6E	2017-07-14 18:28:00+03	46300.00
D8DC7C	2017-07-19 23:40:00+03	257600.00
D8DD07	2017-07-11 03:56:00+03	14400.00
D8DD32	2017-07-07 09:08:00+03	11300.00
D8DD88	2017-08-01 06:17:00+03	111600.00
D8DDB7	2017-07-16 10:47:00+03	10800.00
D8DDBC	2017-07-03 13:58:00+03	46000.00
D8DDCD	2017-08-13 22:33:00+03	13400.00
D8DDD5	2017-06-26 05:25:00+03	12600.00
D8DDFB	2017-08-05 11:50:00+03	75800.00
D8DE1F	2017-06-30 12:58:00+03	38400.00
D8DE42	2017-08-05 16:37:00+03	75300.00
D8DF17	2017-07-16 23:49:00+03	46400.00
D8DF1F	2017-07-16 15:38:00+03	13400.00
D8DF2E	2017-08-11 20:11:00+03	79200.00
D8DFCC	2017-07-14 04:33:00+03	133100.00
D8DFD3	2017-07-11 04:18:00+03	21800.00
D8E008	2017-07-25 07:06:00+03	54800.00
D8E0AB	2017-08-07 05:45:00+03	40800.00
D8E0D0	2017-07-16 17:17:00+03	13000.00
D8E119	2017-07-15 02:18:00+03	12600.00
D8E11A	2017-07-01 14:56:00+03	23600.00
D8E12B	2017-08-10 13:29:00+03	65500.00
D8E14A	2017-07-06 03:40:00+03	26000.00
D8E1B0	2017-07-13 08:06:00+03	86800.00
D8E210	2017-07-30 18:13:00+03	89600.00
D8E238	2017-07-21 17:03:00+03	22000.00
D8E272	2017-08-11 19:43:00+03	164000.00
D8E2AB	2017-08-14 04:08:00+03	51800.00
D8E2CF	2017-08-05 01:45:00+03	398500.00
D8E2DB	2017-07-23 22:38:00+03	39300.00
D8E2E9	2017-08-10 22:12:00+03	47700.00
D8E31F	2017-08-01 17:37:00+03	8200.00
D8E326	2017-07-29 06:30:00+03	36200.00
D8E339	2017-07-26 13:51:00+03	174600.00
D8E35C	2017-08-03 21:11:00+03	12600.00
D8E382	2017-07-15 18:57:00+03	6800.00
D8E3B4	2017-08-03 22:57:00+03	94000.00
D8E3D8	2017-07-04 00:53:00+03	101200.00
D8E448	2017-08-09 09:32:00+03	48800.00
D8E4C6	2017-07-12 14:55:00+03	101900.00
D8E593	2017-08-15 00:18:00+03	36800.00
D8E64F	2017-07-10 16:50:00+03	85000.00
D8E671	2017-07-11 22:00:00+03	101200.00
D8E67D	2017-08-12 14:12:00+03	37100.00
D8E69C	2017-08-14 05:12:00+03	26700.00
D8E6AF	2017-08-14 07:28:00+03	56600.00
D8E78D	2017-08-11 09:31:00+03	12000.00
D8E810	2017-08-02 19:24:00+03	112000.00
D8E83D	2017-07-21 16:18:00+03	179500.00
D8E875	2017-07-17 02:52:00+03	16400.00
D8E89E	2017-08-12 22:19:00+03	58200.00
D8E8E3	2017-07-21 01:14:00+03	27200.00
D8E8F1	2017-08-03 09:32:00+03	56900.00
D8E922	2017-07-17 08:26:00+03	98400.00
D8E9B8	2017-07-12 00:43:00+03	99200.00
D8E9D7	2017-07-20 04:15:00+03	12000.00
D8E9E3	2017-07-29 23:34:00+03	36200.00
D8EA54	2017-08-01 07:19:00+03	44800.00
D8EA61	2017-07-22 05:28:00+03	56900.00
D8EA7C	2017-08-09 16:40:00+03	57600.00
D8EA80	2017-08-14 04:55:00+03	26000.00
D8EA89	2017-08-01 13:05:00+03	26700.00
D8EAEA	2017-07-03 13:46:00+03	109400.00
D8EB02	2017-08-09 07:11:00+03	148800.00
D8EB6E	2017-08-06 14:37:00+03	57800.00
D8EB78	2017-07-10 03:57:00+03	24000.00
D8EBB4	2017-07-08 17:34:00+03	27200.00
D8EC41	2017-08-01 04:37:00+03	173600.00
D8EC4E	2017-07-23 05:26:00+03	372500.00
D8ECE8	2017-07-21 06:19:00+03	114800.00
D8EDD2	2017-06-30 19:07:00+03	32900.00
D8EDE9	2017-07-28 18:32:00+03	48800.00
D8EE2D	2017-07-07 04:29:00+03	28000.00
D8EEC3	2017-08-14 18:25:00+03	81300.00
D8EEE1	2017-08-11 06:43:00+03	160400.00
D8EF90	2017-08-07 07:49:00+03	32800.00
D8EFAB	2017-07-30 03:23:00+03	7200.00
D8EFDF	2017-07-25 08:52:00+03	31600.00
D8F020	2017-07-29 01:27:00+03	111600.00
D8F09B	2017-07-21 07:52:00+03	103500.00
D8F0BB	2017-08-10 23:02:00+03	23200.00
D8F116	2017-08-13 05:02:00+03	19600.00
D8F14E	2017-07-27 04:48:00+03	15400.00
D8F1AC	2017-08-09 17:59:00+03	28800.00
D8F1E2	2017-08-06 22:28:00+03	56000.00
D8F1E5	2017-07-22 01:45:00+03	99300.00
D8F1EB	2017-07-30 14:52:00+03	131600.00
D8F220	2017-08-15 01:50:00+03	74800.00
D8F273	2017-08-13 23:22:00+03	369000.00
D8F2C6	2017-08-01 19:19:00+03	191800.00
D8F2CA	2017-07-09 13:55:00+03	117200.00
D8F2DA	2017-08-15 16:38:00+03	75900.00
D8F2F9	2017-08-02 21:21:00+03	84500.00
D8F329	2017-08-08 15:36:00+03	86600.00
D8F359	2017-07-23 07:55:00+03	75000.00
D8F37C	2017-07-28 04:50:00+03	75300.00
D8F3B1	2017-07-09 23:43:00+03	6800.00
D8F3C0	2017-08-14 00:09:00+03	26700.00
D8F3DE	2017-06-30 07:55:00+03	112600.00
D8F3EC	2017-08-05 01:44:00+03	243700.00
D8F406	2017-07-26 14:29:00+03	23200.00
D8F438	2017-07-03 17:59:00+03	95600.00
D8F43D	2017-08-15 09:11:00+03	33300.00
D8F4D3	2017-08-14 02:46:00+03	386300.00
D8F4FC	2017-07-10 03:08:00+03	12600.00
D8F5FA	2017-07-10 09:33:00+03	25200.00
D8F5FC	2017-08-04 09:53:00+03	90600.00
D8F679	2017-08-05 13:44:00+03	273300.00
D8F699	2017-08-13 09:46:00+03	63800.00
D8F69E	2017-08-13 12:51:00+03	52000.00
D8F72D	2017-07-31 23:24:00+03	105000.00
D8F738	2017-07-24 16:05:00+03	56000.00
D8F7DC	2017-08-02 22:57:00+03	112000.00
D8F7E5	2017-07-03 10:25:00+03	88600.00
D8F86D	2017-07-19 09:38:00+03	112000.00
D8F8AC	2017-08-11 21:07:00+03	28800.00
D8F92E	2017-08-07 23:59:00+03	90800.00
D8F941	2017-07-18 07:20:00+03	28800.00
D8F95C	2017-07-20 02:11:00+03	56000.00
D8F962	2017-07-21 20:32:00+03	61800.00
D8F97C	2017-08-07 07:09:00+03	135600.00
D8F981	2017-08-01 08:31:00+03	68400.00
D8F9E6	2017-07-26 23:55:00+03	408500.00
D8FA05	2017-07-13 06:42:00+03	39900.00
D8FA09	2017-08-12 11:11:00+03	56600.00
D8FA36	2017-08-13 22:21:00+03	37200.00
D8FA41	2017-07-19 04:39:00+03	37900.00
D8FAD8	2017-07-02 09:28:00+03	45200.00
D8FB45	2017-07-20 16:37:00+03	19800.00
D8FB8F	2017-07-24 13:16:00+03	137600.00
D8FC03	2017-07-09 11:10:00+03	43600.00
D8FC31	2017-07-23 15:50:00+03	32200.00
D8FCC5	2017-07-05 07:46:00+03	67900.00
D8FCD6	2017-07-17 06:50:00+03	65900.00
D8FCDD	2017-07-27 16:36:00+03	26200.00
D8FD54	2017-08-05 21:36:00+03	94000.00
D8FD88	2017-07-22 19:08:00+03	43600.00
D8FEDE	2017-08-06 02:50:00+03	168100.00
D8FF39	2017-07-10 18:32:00+03	95200.00
D8FF54	2017-07-21 22:41:00+03	136800.00
D8FFAC	2017-08-15 16:27:00+03	13400.00
D8FFB8	2017-07-06 05:26:00+03	144400.00
D8FFBB	2017-08-11 15:47:00+03	76100.00
D90014	2017-07-20 11:58:00+03	49200.00
D9009D	2017-07-15 08:48:00+03	50600.00
D900A4	2017-07-29 07:20:00+03	193100.00
D901C1	2017-07-14 12:48:00+03	92200.00
D901EA	2017-07-18 23:37:00+03	14800.00
D9021A	2017-07-07 01:09:00+03	149300.00
D9021C	2017-08-07 12:58:00+03	17800.00
D90238	2017-08-15 09:55:00+03	59300.00
D9023C	2017-07-03 12:49:00+03	25000.00
D9025E	2017-07-26 16:04:00+03	246000.00
D90260	2017-07-03 20:43:00+03	58000.00
D902C8	2017-07-23 05:58:00+03	85000.00
D90317	2017-07-01 19:02:00+03	38800.00
D903C8	2017-08-15 02:57:00+03	24300.00
D903F3	2017-06-28 14:19:00+03	26000.00
D904CC	2017-07-07 20:09:00+03	176800.00
D904E0	2017-07-23 07:54:00+03	181100.00
D9053D	2017-07-11 11:34:00+03	70200.00
D9053E	2017-07-15 06:46:00+03	26700.00
D9056B	2017-07-09 13:01:00+03	257600.00
D905B0	2017-07-20 01:28:00+03	11800.00
D905E8	2017-07-19 07:01:00+03	181400.00
D905EF	2017-08-09 07:20:00+03	70600.00
D90602	2017-08-04 02:16:00+03	99600.00
D90662	2017-06-30 09:28:00+03	78300.00
D906D9	2017-07-02 13:04:00+03	28000.00
D906FA	2017-07-31 02:09:00+03	101100.00
D90721	2017-07-27 19:10:00+03	52700.00
D90789	2017-07-20 11:45:00+03	48500.00
D9078A	2017-07-23 17:18:00+03	155000.00
D907A3	2017-08-12 06:43:00+03	22000.00
D907FD	2017-07-25 15:38:00+03	48800.00
D90831	2017-08-10 19:24:00+03	66000.00
D90852	2017-07-19 23:15:00+03	27600.00
D9088F	2017-08-02 21:26:00+03	46400.00
D9092A	2017-07-03 18:20:00+03	25600.00
D90A73	2017-07-07 18:21:00+03	156900.00
D90A76	2017-07-27 03:24:00+03	46900.00
D90A98	2017-07-15 00:56:00+03	124200.00
D90AED	2017-07-30 11:00:00+03	26000.00
D90AEF	2017-07-31 14:21:00+03	86000.00
D90AF4	2017-07-31 16:16:00+03	34000.00
D90B41	2017-08-03 21:47:00+03	28800.00
D90B4D	2017-07-15 16:38:00+03	58400.00
D90B5E	2017-07-07 00:45:00+03	55800.00
D90B66	2017-07-30 14:18:00+03	68000.00
D90B7C	2017-07-07 20:43:00+03	31700.00
D90BA3	2017-08-09 18:28:00+03	22000.00
D90BFB	2017-08-04 16:21:00+03	102100.00
D90C1D	2017-07-12 17:10:00+03	67400.00
D90C59	2017-08-06 11:11:00+03	42800.00
D90C62	2017-06-28 02:39:00+03	31400.00
D90C83	2017-08-10 03:07:00+03	14400.00
D90CA5	2017-07-28 21:25:00+03	67700.00
D90D52	2017-07-16 06:38:00+03	24000.00
D90D76	2017-08-05 19:57:00+03	28000.00
D90DBF	2017-07-22 13:14:00+03	52000.00
D90E11	2017-07-10 12:39:00+03	37900.00
D90E23	2017-07-06 08:30:00+03	38400.00
D90E3C	2017-07-06 19:44:00+03	41400.00
D90EE5	2017-07-12 20:38:00+03	57500.00
D90F06	2017-07-05 12:45:00+03	209100.00
D90F09	2017-08-07 06:48:00+03	41200.00
D90F72	2017-07-18 01:21:00+03	11000.00
D90F9B	2017-07-31 03:57:00+03	28800.00
D9101B	2017-07-21 08:44:00+03	73100.00
D9102B	2017-07-17 15:58:00+03	34000.00
D91064	2017-07-16 22:57:00+03	31200.00
D910B2	2017-06-28 15:43:00+03	22000.00
D9114D	2017-08-11 13:21:00+03	87300.00
D91156	2017-07-30 19:45:00+03	60700.00
D91169	2017-07-19 05:37:00+03	110300.00
D911CC	2017-07-22 00:12:00+03	58800.00
D911D1	2017-08-13 06:20:00+03	62000.00
D911E0	2017-07-06 04:14:00+03	92900.00
D9123F	2017-07-15 03:12:00+03	167400.00
D91253	2017-07-10 06:15:00+03	106700.00
D9127F	2017-07-17 17:23:00+03	19600.00
D912A4	2017-07-15 04:28:00+03	46300.00
D9132A	2017-07-20 22:49:00+03	272400.00
D91334	2017-08-11 22:18:00+03	13400.00
D91374	2017-07-15 00:48:00+03	234700.00
D91375	2017-07-28 21:40:00+03	15900.00
D91377	2017-07-25 06:26:00+03	79600.00
D913B2	2017-08-12 17:11:00+03	89600.00
D913F2	2017-07-11 22:38:00+03	14800.00
D91454	2017-07-27 16:52:00+03	14000.00
D91519	2017-08-11 15:03:00+03	48800.00
D9151E	2017-06-30 06:53:00+03	66600.00
D915BB	2017-08-09 14:14:00+03	11000.00
D915EC	2017-08-10 03:10:00+03	393000.00
D91634	2017-07-23 14:10:00+03	23200.00
D9166B	2017-07-03 10:20:00+03	28700.00
D91684	2017-07-06 02:11:00+03	55800.00
D916BB	2017-07-18 02:31:00+03	131600.00
D916BE	2017-07-09 22:37:00+03	24400.00
D91733	2017-08-06 08:06:00+03	23400.00
D91768	2017-08-12 03:40:00+03	26000.00
D917B2	2017-08-08 17:35:00+03	14700.00
D917B4	2017-07-27 09:57:00+03	185700.00
D9193D	2017-07-28 04:05:00+03	23400.00
D9194E	2017-08-09 01:42:00+03	101200.00
D91958	2017-07-23 09:49:00+03	31400.00
D919B4	2017-07-29 00:07:00+03	52100.00
D919FF	2017-07-11 04:53:00+03	27700.00
D91A32	2017-07-23 04:10:00+03	51900.00
D91A92	2017-08-03 22:48:00+03	100600.00
D91ACB	2017-07-12 05:04:00+03	52900.00
D91AFF	2017-07-16 17:35:00+03	26700.00
D91B7C	2017-07-26 00:02:00+03	41200.00
D91BB3	2017-06-29 10:58:00+03	67700.00
D91BC6	2017-08-02 16:03:00+03	25400.00
D91BE4	2017-07-03 11:44:00+03	88600.00
D91C36	2017-08-08 10:22:00+03	50000.00
D91C7D	2017-08-10 22:56:00+03	24400.00
D91CAA	2017-07-30 16:31:00+03	102100.00
D91CDB	2017-08-04 00:45:00+03	187900.00
D91D17	2017-08-06 14:39:00+03	136600.00
D91D28	2017-07-24 18:15:00+03	25900.00
D91D8B	2017-08-04 21:27:00+03	51600.00
D91DAD	2017-07-27 03:33:00+03	45200.00
D91E28	2017-07-22 10:58:00+03	90400.00
D91E5B	2017-07-18 01:25:00+03	22000.00
D91E7A	2017-08-06 09:01:00+03	193600.00
D91E80	2017-07-06 21:47:00+03	246000.00
D91EF4	2017-07-20 13:53:00+03	76600.00
D91F0A	2017-07-19 16:57:00+03	32800.00
D91F43	2017-08-06 08:30:00+03	92800.00
D91F51	2017-07-31 01:45:00+03	32800.00
D91F7F	2017-08-10 16:40:00+03	81200.00
D91FE0	2017-07-24 10:21:00+03	202400.00
D91FE4	2017-07-24 14:17:00+03	70700.00
D92010	2017-07-18 13:17:00+03	57700.00
D92043	2017-07-23 13:13:00+03	23600.00
D92134	2017-07-15 17:19:00+03	14800.00
D9214C	2017-07-12 21:17:00+03	46400.00
D9216E	2017-08-14 17:20:00+03	56000.00
D92182	2017-08-13 00:59:00+03	26200.00
D9219B	2017-07-26 14:38:00+03	112000.00
D92213	2017-07-09 12:02:00+03	80200.00
D9223D	2017-08-05 03:25:00+03	38800.00
D92242	2017-07-30 09:27:00+03	62900.00
D92262	2017-07-23 01:11:00+03	88500.00
D92265	2017-07-29 08:33:00+03	6000.00
D9231C	2017-07-30 12:43:00+03	42700.00
D9232E	2017-07-11 07:01:00+03	23600.00
D92349	2017-07-04 14:47:00+03	229900.00
D923CC	2017-07-11 01:51:00+03	24700.00
D92410	2017-08-15 13:27:00+03	48800.00
D9241E	2017-08-05 17:12:00+03	169300.00
D9244B	2017-08-10 02:22:00+03	277600.00
D92478	2017-07-03 09:56:00+03	167400.00
D924A0	2017-07-21 18:52:00+03	174400.00
D924BD	2017-08-14 16:45:00+03	6300.00
D924DC	2017-07-15 18:19:00+03	188000.00
D924DE	2017-07-24 00:40:00+03	64800.00
D924FD	2017-08-10 13:27:00+03	28000.00
D925A2	2017-07-28 09:44:00+03	259000.00
D925BB	2017-08-11 20:16:00+03	148200.00
D9268C	2017-07-01 02:33:00+03	39600.00
D926B5	2017-08-01 01:51:00+03	272000.00
D926C2	2017-08-14 18:04:00+03	372500.00
D92735	2017-07-24 07:26:00+03	18800.00
D92744	2017-07-01 07:48:00+03	20400.00
D9274F	2017-07-30 22:41:00+03	84500.00
D927A3	2017-07-13 18:40:00+03	28300.00
D927D5	2017-08-12 07:23:00+03	37200.00
D927DB	2017-08-07 19:33:00+03	169800.00
D92848	2017-07-04 14:35:00+03	38400.00
D9284E	2017-06-29 14:33:00+03	135400.00
D92889	2017-07-16 06:43:00+03	228000.00
D92913	2017-08-08 22:23:00+03	66800.00
D929A4	2017-07-13 03:00:00+03	185300.00
D929A9	2017-08-10 18:26:00+03	99200.00
D929AF	2017-07-20 22:20:00+03	33200.00
D929BA	2017-08-12 05:45:00+03	25100.00
D929E4	2017-08-05 19:50:00+03	40800.00
D929E9	2017-07-17 07:41:00+03	136800.00
D92A1B	2017-08-12 19:22:00+03	11600.00
D92A38	2017-07-03 09:32:00+03	111600.00
D92A4B	2017-07-31 12:54:00+03	143000.00
D92AA2	2017-07-23 20:11:00+03	28800.00
D92ACD	2017-07-21 00:22:00+03	26700.00
D92BF2	2017-07-31 04:58:00+03	22000.00
D92BF7	2017-07-11 14:05:00+03	21800.00
D92C23	2017-07-27 04:25:00+03	223200.00
D92C42	2017-08-01 05:34:00+03	30000.00
D92C4F	2017-07-25 02:09:00+03	11600.00
D92C6A	2017-07-12 00:16:00+03	271400.00
D92C98	2017-08-02 01:19:00+03	42800.00
D92CB5	2017-07-05 12:19:00+03	75300.00
D92CE8	2017-07-25 19:38:00+03	41600.00
D92D42	2017-07-12 20:03:00+03	26000.00
D92D43	2017-07-16 08:09:00+03	184300.00
D92D9E	2017-06-29 06:12:00+03	98000.00
D92E01	2017-07-24 13:25:00+03	369000.00
D92E1F	2017-07-06 14:37:00+03	83000.00
D92ED3	2017-07-11 15:24:00+03	81300.00
D92F07	2017-07-30 11:26:00+03	21800.00
D92F08	2017-08-11 07:15:00+03	246000.00
D92F20	2017-07-21 17:42:00+03	29600.00
D92FDF	2017-07-31 13:56:00+03	173500.00
D92FEF	2017-07-21 03:15:00+03	36200.00
D93027	2017-08-08 11:22:00+03	154800.00
D93051	2017-07-03 23:03:00+03	56600.00
D930AA	2017-08-14 23:38:00+03	47000.00
D930C5	2017-07-20 07:00:00+03	397100.00
D930E3	2017-07-31 08:32:00+03	202100.00
D93151	2017-07-26 06:14:00+03	155600.00
D9318B	2017-07-17 02:42:00+03	62600.00
D931CB	2017-08-14 12:14:00+03	43600.00
D931DC	2017-07-03 13:58:00+03	56900.00
D931F8	2017-08-04 08:30:00+03	55800.00
D932A0	2017-08-12 14:38:00+03	38800.00
D932ED	2017-07-06 22:05:00+03	339900.00
D9330A	2017-07-26 14:19:00+03	20200.00
D93342	2017-08-13 09:36:00+03	46000.00
D93359	2017-07-16 00:37:00+03	30900.00
D93458	2017-07-01 14:06:00+03	29600.00
D9347B	2017-07-07 17:19:00+03	173900.00
D934FF	2017-07-31 13:33:00+03	147100.00
D93566	2017-08-07 21:41:00+03	86400.00
D93584	2017-08-05 02:23:00+03	67900.00
D935FE	2017-07-28 19:28:00+03	252200.00
D93624	2017-08-11 18:54:00+03	78600.00
D93675	2017-07-01 17:16:00+03	40600.00
D93693	2017-07-25 20:17:00+03	33800.00
D936ED	2017-07-11 16:09:00+03	32700.00
D93737	2017-08-13 11:22:00+03	54800.00
D93794	2017-08-03 00:45:00+03	67200.00
D937BA	2017-08-05 00:31:00+03	449500.00
D937E1	2017-08-14 14:50:00+03	102100.00
D937E3	2017-08-02 01:22:00+03	175300.00
D93827	2017-08-05 09:56:00+03	43800.00
D9385B	2017-08-13 03:09:00+03	42800.00
D9385E	2017-07-23 16:51:00+03	25900.00
D9386A	2017-07-02 11:02:00+03	90000.00
D9389C	2017-07-12 15:48:00+03	265800.00
D938A3	2017-08-12 15:13:00+03	26700.00
D93946	2017-07-05 10:38:00+03	38600.00
D93A30	2017-07-21 02:20:00+03	22000.00
D93A69	2017-08-12 16:07:00+03	25800.00
D93A78	2017-07-07 08:36:00+03	40800.00
D93A99	2017-08-09 19:09:00+03	30200.00
D93AAD	2017-08-10 06:57:00+03	46400.00
D93B07	2017-07-28 02:26:00+03	49100.00
D93B14	2017-08-06 23:38:00+03	77500.00
D93B25	2017-07-12 19:03:00+03	24200.00
D93B38	2017-08-14 05:33:00+03	52400.00
D93B76	2017-07-12 05:39:00+03	46300.00
D93C27	2017-08-11 08:16:00+03	13700.00
D93CA4	2017-07-21 07:36:00+03	531300.00
D93CC0	2017-07-10 02:38:00+03	34700.00
D93D44	2017-08-15 09:48:00+03	97900.00
D93D5B	2017-08-10 02:27:00+03	55600.00
D93D69	2017-07-14 03:46:00+03	53700.00
D93DA0	2017-08-09 10:01:00+03	77900.00
D93DB6	2017-08-13 11:57:00+03	66600.00
D93DF7	2017-07-14 17:22:00+03	25200.00
D93E71	2017-08-05 03:20:00+03	51900.00
D93F2E	2017-08-09 08:51:00+03	80200.00
D93F30	2017-08-11 21:25:00+03	21600.00
D93FED	2017-07-05 04:02:00+03	11300.00
D94011	2017-08-11 16:21:00+03	98400.00
D94037	2017-07-05 00:46:00+03	49100.00
D9403C	2017-08-03 01:33:00+03	90200.00
D9405A	2017-07-24 13:36:00+03	58900.00
D9405F	2017-07-11 21:42:00+03	10700.00
D94081	2017-08-03 18:52:00+03	66600.00
D940B0	2017-07-04 08:37:00+03	27400.00
D940FD	2017-07-03 20:41:00+03	332800.00
D94111	2017-08-07 11:27:00+03	29600.00
D94124	2017-08-08 10:43:00+03	8000.00
D9414C	2017-08-06 17:28:00+03	25000.00
D94177	2017-07-20 14:53:00+03	11700.00
D941C9	2017-07-28 06:20:00+03	38400.00
D941F6	2017-08-08 19:05:00+03	88800.00
D94238	2017-07-22 19:50:00+03	29600.00
D94318	2017-08-11 23:58:00+03	23200.00
D94344	2017-07-25 10:37:00+03	70800.00
D94387	2017-07-24 11:15:00+03	70500.00
D943B7	2017-07-28 14:47:00+03	93900.00
D943DB	2017-08-02 00:24:00+03	23200.00
D943DD	2017-08-15 04:24:00+03	35800.00
D94408	2017-07-28 04:11:00+03	38600.00
D94498	2017-08-13 12:40:00+03	23200.00
D945F8	2017-07-27 23:36:00+03	124000.00
D94606	2017-07-13 15:14:00+03	50300.00
D9464A	2017-07-16 03:09:00+03	75800.00
D94655	2017-07-16 09:36:00+03	8400.00
D94668	2017-07-07 09:47:00+03	88600.00
D94673	2017-08-11 07:39:00+03	149200.00
D946A6	2017-07-26 05:02:00+03	50100.00
D946B1	2017-07-02 05:30:00+03	128800.00
D946DC	2017-07-04 03:19:00+03	45200.00
D94741	2017-07-30 13:11:00+03	123000.00
D94742	2017-07-22 20:27:00+03	55600.00
D94799	2017-07-31 17:02:00+03	56100.00
D94831	2017-07-19 22:22:00+03	65500.00
D94887	2017-07-12 08:44:00+03	266400.00
D948A3	2017-07-20 08:59:00+03	52000.00
D948B8	2017-07-15 19:39:00+03	58000.00
D948D2	2017-07-26 01:28:00+03	16400.00
D949E3	2017-08-12 20:35:00+03	24400.00
D94A32	2017-07-23 18:28:00+03	13400.00
D94A6E	2017-07-11 05:20:00+03	112000.00
D94AFC	2017-07-18 06:38:00+03	15800.00
D94B1C	2017-08-03 07:18:00+03	20200.00
D94B94	2017-07-28 00:44:00+03	49100.00
D94C32	2017-08-02 08:02:00+03	12600.00
D94CDE	2017-08-04 22:19:00+03	29600.00
D94D17	2017-07-14 17:12:00+03	32800.00
D94D3C	2017-07-12 16:20:00+03	106900.00
D94DC6	2017-08-01 05:14:00+03	26000.00
D94E5F	2017-07-29 15:28:00+03	73500.00
D94E60	2017-08-07 02:09:00+03	78600.00
D94E67	2017-08-11 10:15:00+03	38800.00
D94EBC	2017-07-08 18:13:00+03	44800.00
D94EDA	2017-08-07 04:29:00+03	56600.00
D94F82	2017-07-26 23:20:00+03	36800.00
D9500F	2017-07-02 20:30:00+03	81700.00
D95090	2017-07-11 00:45:00+03	57500.00
D950D2	2017-07-07 02:29:00+03	122000.00
D95185	2017-07-29 13:43:00+03	73900.00
D951A7	2017-06-29 19:58:00+03	26000.00
D951FD	2017-07-22 22:49:00+03	131600.00
D95207	2017-07-17 23:31:00+03	28800.00
D95229	2017-07-26 10:09:00+03	64500.00
D9533E	2017-07-17 03:55:00+03	73200.00
D9546C	2017-07-18 23:48:00+03	66600.00
D954E5	2017-07-27 22:43:00+03	74400.00
D95557	2017-07-25 09:42:00+03	45400.00
D9556F	2017-07-29 20:43:00+03	46400.00
D9559B	2017-08-07 11:38:00+03	23600.00
D95628	2017-07-16 22:24:00+03	21800.00
D95676	2017-08-03 07:40:00+03	24000.00
D95678	2017-07-02 18:52:00+03	25600.00
D95686	2017-08-09 02:20:00+03	62000.00
D956DB	2017-07-24 01:31:00+03	56000.00
D956E0	2017-07-13 10:22:00+03	42800.00
D9576A	2017-07-24 05:14:00+03	3400.00
D95792	2017-08-04 06:58:00+03	232800.00
D95802	2017-07-14 22:35:00+03	210200.00
D95856	2017-08-12 21:06:00+03	99700.00
D9589E	2017-07-25 18:30:00+03	196800.00
D958A0	2017-08-02 00:11:00+03	34600.00
D958F6	2017-08-10 03:13:00+03	29600.00
D959CC	2017-07-31 03:40:00+03	134200.00
D959FF	2017-07-28 17:36:00+03	148700.00
D95A15	2017-07-05 15:01:00+03	70600.00
D95A17	2017-08-10 21:20:00+03	14000.00
D95A22	2017-08-04 09:04:00+03	147000.00
D95A52	2017-07-31 13:51:00+03	276500.00
D95AC1	2017-08-12 03:36:00+03	109600.00
D95AC3	2017-07-08 07:17:00+03	47900.00
D95B38	2017-08-07 15:04:00+03	56000.00
D95B3C	2017-07-01 06:24:00+03	23600.00
D95B55	2017-07-04 10:34:00+03	32700.00
D95B7A	2017-08-02 13:33:00+03	23200.00
D95BC2	2017-08-09 02:05:00+03	15800.00
D95BD6	2017-08-13 09:10:00+03	27300.00
D95C06	2017-07-26 22:08:00+03	55800.00
D95CC7	2017-07-08 00:55:00+03	100600.00
D95CE3	2017-07-29 06:58:00+03	187800.00
D95D21	2017-08-05 10:41:00+03	114700.00
D95D38	2017-08-07 23:25:00+03	21400.00
D95D5A	2017-07-27 13:58:00+03	64800.00
D95D8B	2017-07-06 10:28:00+03	72400.00
D95DB2	2017-08-10 05:07:00+03	112600.00
D95DCE	2017-07-26 18:29:00+03	59300.00
D95DEA	2017-07-10 08:16:00+03	113000.00
D95E7A	2017-07-08 04:41:00+03	7200.00
D95EA0	2017-08-11 12:15:00+03	13700.00
D95ED8	2017-07-21 13:34:00+03	32700.00
D95EDB	2017-07-29 09:37:00+03	46400.00
D95EF1	2017-06-29 05:16:00+03	405100.00
D95F0E	2017-08-13 11:13:00+03	78100.00
D95F29	2017-07-04 10:12:00+03	167400.00
D95F2B	2017-07-23 17:31:00+03	23600.00
D9609E	2017-07-03 15:37:00+03	29200.00
D960A9	2017-08-11 12:22:00+03	51200.00
D960D8	2017-07-19 15:30:00+03	173900.00
D960E5	2017-08-12 15:52:00+03	148200.00
D960EA	2017-07-20 12:25:00+03	101000.00
D96100	2017-08-05 09:17:00+03	64300.00
D96118	2017-08-04 00:11:00+03	134400.00
D96138	2017-07-25 22:30:00+03	139400.00
D96151	2017-07-16 00:50:00+03	70200.00
D9619D	2017-07-07 03:52:00+03	294200.00
D961D6	2017-06-28 22:44:00+03	67200.00
D9625B	2017-08-07 11:28:00+03	137100.00
D96327	2017-08-11 04:01:00+03	54800.00
D9649F	2017-08-01 11:48:00+03	97900.00
D964E9	2017-07-06 08:40:00+03	46000.00
D96543	2017-08-11 03:35:00+03	27400.00
D96572	2017-08-13 15:13:00+03	134600.00
D965CD	2017-07-30 13:15:00+03	72000.00
D965D2	2017-08-03 07:02:00+03	52800.00
D965DC	2017-07-20 03:25:00+03	23200.00
D96645	2017-07-20 19:51:00+03	19100.00
D96659	2017-07-16 09:08:00+03	75600.00
D96687	2017-08-07 18:17:00+03	133200.00
D966B9	2017-07-31 07:54:00+03	77600.00
D966C3	2017-08-14 21:59:00+03	262200.00
D966E2	2017-07-03 22:36:00+03	41800.00
D9670C	2017-07-30 23:40:00+03	11700.00
D96715	2017-07-04 11:11:00+03	23600.00
D96743	2017-07-01 22:11:00+03	76100.00
D96767	2017-07-12 19:32:00+03	21800.00
D9679D	2017-07-01 11:37:00+03	75300.00
D967B1	2017-07-05 05:25:00+03	76400.00
D968C5	2017-07-02 14:18:00+03	266400.00
D96962	2017-07-19 00:09:00+03	32800.00
D969D4	2017-08-14 14:59:00+03	14700.00
D969F7	2017-08-07 18:52:00+03	173200.00
D96A89	2017-07-23 11:38:00+03	67700.00
D96A91	2017-07-17 08:07:00+03	6700.00
D96A98	2017-07-06 13:35:00+03	10800.00
D96AA3	2017-07-07 10:46:00+03	20900.00
D96AA7	2017-08-05 22:30:00+03	62700.00
D96AB9	2017-07-27 16:49:00+03	6000.00
D96B10	2017-07-17 14:28:00+03	139800.00
D96B2B	2017-07-12 18:14:00+03	67100.00
D96BA7	2017-07-08 19:21:00+03	8400.00
D96BD9	2017-07-02 12:38:00+03	372500.00
D96BFA	2017-08-06 16:28:00+03	154800.00
D96C17	2017-07-12 08:54:00+03	15000.00
D96C28	2017-06-29 01:07:00+03	101200.00
D96C38	2017-08-13 19:09:00+03	40000.00
D96C6F	2017-07-08 09:30:00+03	133100.00
D96C86	2017-07-13 03:42:00+03	46000.00
D96D00	2017-08-13 11:23:00+03	101200.00
D96D42	2017-07-26 20:51:00+03	83700.00
D96D58	2017-07-16 02:45:00+03	48500.00
D96D60	2017-07-03 13:52:00+03	258400.00
D96DA0	2017-07-22 17:18:00+03	135400.00
D96DAC	2017-08-03 01:42:00+03	30400.00
D96DD8	2017-07-29 19:21:00+03	130600.00
D96E3F	2017-08-07 03:19:00+03	58600.00
D96E5E	2017-06-29 09:55:00+03	79600.00
D96E65	2017-07-13 06:04:00+03	30800.00
D96E73	2017-07-19 01:46:00+03	16400.00
D96E8C	2017-07-04 13:27:00+03	7200.00
D96EC0	2017-07-27 07:14:00+03	62600.00
D96EC5	2017-07-15 07:18:00+03	149700.00
D96F20	2017-07-28 16:09:00+03	73400.00
D96F25	2017-08-13 08:41:00+03	22600.00
D96F3A	2017-07-16 03:14:00+03	14700.00
D96FAC	2017-08-14 21:01:00+03	187600.00
D96FD6	2017-07-08 16:53:00+03	65900.00
D97010	2017-07-11 10:51:00+03	55800.00
D97020	2017-07-27 08:00:00+03	26000.00
D97021	2017-07-13 05:34:00+03	78300.00
D9704E	2017-07-02 01:21:00+03	38400.00
D9704F	2017-08-13 16:02:00+03	39200.00
D9708B	2017-07-10 15:47:00+03	45600.00
D97096	2017-07-21 05:43:00+03	178900.00
D9709B	2017-08-14 02:42:00+03	36700.00
D97155	2017-08-11 07:34:00+03	15400.00
D971C5	2017-08-04 06:23:00+03	47800.00
D971E0	2017-08-13 00:14:00+03	48200.00
D971E6	2017-06-27 15:41:00+03	23200.00
D9720C	2017-07-09 01:29:00+03	114800.00
D97212	2017-07-27 22:57:00+03	159800.00
D972C1	2017-08-06 18:39:00+03	28000.00
D972D7	2017-08-12 16:29:00+03	246000.00
D972D8	2017-07-07 04:35:00+03	97700.00
D972E5	2017-08-08 09:38:00+03	52100.00
D972F6	2017-07-31 04:41:00+03	95300.00
D9734B	2017-08-01 07:37:00+03	201200.00
D9743F	2017-07-23 00:19:00+03	56600.00
D9747F	2017-07-19 11:33:00+03	65900.00
D974FC	2017-08-02 12:27:00+03	40800.00
D9753C	2017-08-10 03:36:00+03	123000.00
D9753D	2017-08-12 23:15:00+03	136400.00
D97558	2017-07-26 18:39:00+03	14300.00
D975A8	2017-07-17 16:44:00+03	88900.00
D975AB	2017-07-15 00:19:00+03	42700.00
D975E5	2017-07-26 21:36:00+03	13600.00
D97649	2017-08-11 15:51:00+03	81700.00
D97651	2017-07-20 12:47:00+03	26800.00
D977BB	2017-07-09 19:22:00+03	56000.00
D977FE	2017-08-09 22:55:00+03	123000.00
D9780B	2017-08-13 07:46:00+03	79300.00
D97846	2017-08-14 16:43:00+03	26000.00
D978C1	2017-08-14 11:18:00+03	47600.00
D97919	2017-07-04 05:31:00+03	354400.00
D97927	2017-07-04 11:35:00+03	48300.00
D97928	2017-07-08 13:09:00+03	222800.00
D97A59	2017-07-16 20:02:00+03	73100.00
D97A8E	2017-07-12 13:50:00+03	13600.00
D97AD8	2017-07-03 08:05:00+03	20400.00
D97B01	2017-07-25 17:49:00+03	277900.00
D97B38	2017-07-30 22:15:00+03	20400.00
D97B4D	2017-07-04 01:13:00+03	155600.00
D97BC9	2017-07-04 07:50:00+03	381800.00
D97BDF	2017-07-15 18:30:00+03	100600.00
D97BFB	2017-08-10 00:58:00+03	56600.00
D97CCA	2017-08-04 22:44:00+03	8000.00
D97CFE	2017-07-05 14:18:00+03	14000.00
D97D4F	2017-07-30 13:13:00+03	14400.00
D97D8A	2017-08-13 12:14:00+03	29600.00
D97D9C	2017-06-30 22:30:00+03	28000.00
D97F01	2017-08-12 05:59:00+03	230000.00
D97F20	2017-07-21 17:37:00+03	136200.00
D97F3D	2017-07-27 02:10:00+03	136200.00
D97F75	2017-07-22 14:08:00+03	28000.00
D97F7D	2017-07-09 08:51:00+03	13400.00
D97FD7	2017-07-31 16:21:00+03	127300.00
D9800C	2017-07-04 19:39:00+03	12600.00
D98013	2017-08-15 14:25:00+03	50000.00
D98021	2017-07-17 07:27:00+03	16400.00
D980BE	2017-08-06 03:09:00+03	201800.00
D980CE	2017-08-09 19:11:00+03	140300.00
D980D3	2017-08-04 15:43:00+03	81600.00
D980F1	2017-07-03 23:25:00+03	44500.00
D98100	2017-08-08 04:03:00+03	58400.00
D98101	2017-08-01 11:36:00+03	189200.00
D9813B	2017-07-25 19:00:00+03	109700.00
D98160	2017-07-29 11:00:00+03	31000.00
D98185	2017-06-30 21:17:00+03	12000.00
D9818D	2017-07-04 08:47:00+03	94400.00
D9824C	2017-07-05 19:45:00+03	9200.00
D98288	2017-07-09 21:21:00+03	56000.00
D9828F	2017-08-14 19:52:00+03	231200.00
D982B0	2017-07-25 11:26:00+03	61500.00
D982DD	2017-07-12 22:12:00+03	7200.00
D98366	2017-08-10 17:52:00+03	20400.00
D9837F	2017-07-21 04:16:00+03	95200.00
D9839F	2017-07-28 21:03:00+03	122000.00
D98412	2017-08-03 10:29:00+03	42400.00
D98465	2017-08-12 17:25:00+03	199700.00
D9848E	2017-07-29 02:07:00+03	109000.00
D98496	2017-07-02 18:09:00+03	61400.00
D984C2	2017-07-10 16:10:00+03	92900.00
D984D9	2017-07-12 10:30:00+03	27300.00
D98516	2017-07-11 10:32:00+03	29600.00
D98521	2017-07-20 19:27:00+03	123600.00
D9854E	2017-07-29 21:38:00+03	24800.00
D98574	2017-07-03 13:58:00+03	17800.00
D985A6	2017-07-22 10:45:00+03	47200.00
D985D6	2017-07-28 22:29:00+03	44000.00
D9866E	2017-08-09 20:04:00+03	148200.00
D986B6	2017-07-17 15:20:00+03	23400.00
D986B9	2017-08-07 11:51:00+03	92800.00
D986EC	2017-07-14 07:00:00+03	265800.00
D98703	2017-07-07 04:03:00+03	40800.00
D9870D	2017-07-13 03:46:00+03	67000.00
D9872F	2017-08-11 19:00:00+03	27800.00
D9878A	2017-07-10 11:01:00+03	33300.00
D98811	2017-08-01 06:23:00+03	9800.00
D98826	2017-07-31 08:04:00+03	135200.00
D9883E	2017-07-14 19:05:00+03	139300.00
D9884E	2017-07-24 10:17:00+03	111600.00
D9886E	2017-08-06 17:55:00+03	25600.00
D9889C	2017-07-05 22:22:00+03	16400.00
D98916	2017-06-30 23:43:00+03	28700.00
D98924	2017-08-02 03:02:00+03	50000.00
D98939	2017-08-08 21:47:00+03	37200.00
D98976	2017-07-01 02:44:00+03	56000.00
D989D9	2017-07-01 18:10:00+03	52000.00
D98AEF	2017-08-08 16:09:00+03	62600.00
D98B15	2017-07-16 16:02:00+03	25000.00
D98B1B	2017-08-11 13:23:00+03	40400.00
D98B31	2017-08-06 18:40:00+03	24400.00
D98B9B	2017-07-18 11:02:00+03	400400.00
D98C5F	2017-07-25 06:05:00+03	39900.00
D98D8D	2017-07-28 21:55:00+03	159200.00
D98D9B	2017-08-03 09:32:00+03	28000.00
D98DDC	2017-07-10 07:14:00+03	55800.00
D98DE3	2017-08-07 06:20:00+03	23200.00
D98DF2	2017-06-30 05:10:00+03	52000.00
D98E2F	2017-08-10 06:37:00+03	8200.00
D98EAB	2017-07-20 12:04:00+03	56000.00
D98EE7	2017-08-02 05:43:00+03	30200.00
D98F01	2017-08-13 13:09:00+03	23600.00
D98F4E	2017-07-05 07:51:00+03	6700.00
D98F77	2017-07-11 19:09:00+03	93400.00
D98F80	2017-07-06 02:31:00+03	12600.00
D98FB8	2017-07-28 04:21:00+03	104000.00
D98FC3	2017-07-17 03:09:00+03	32800.00
D98FE8	2017-07-21 09:29:00+03	138400.00
D9906C	2017-08-15 17:19:00+03	26700.00
D991DF	2017-08-12 00:53:00+03	171100.00
D991F2	2017-07-27 09:22:00+03	27200.00
D99229	2017-06-30 20:16:00+03	27800.00
D992C3	2017-08-04 05:28:00+03	6700.00
D99353	2017-07-24 05:44:00+03	142200.00
D99364	2017-07-04 21:23:00+03	52800.00
D99366	2017-08-02 07:03:00+03	37900.00
D99386	2017-08-09 05:40:00+03	37200.00
D993AE	2017-07-23 18:29:00+03	135900.00
D9940C	2017-08-04 12:36:00+03	113800.00
D9943C	2017-07-21 01:28:00+03	28000.00
D99459	2017-08-13 22:21:00+03	85700.00
D9946A	2017-07-28 14:20:00+03	103200.00
D9948D	2017-07-11 17:53:00+03	187900.00
D994A2	2017-07-26 22:46:00+03	40300.00
D994D4	2017-07-12 06:36:00+03	19600.00
D99513	2017-07-11 21:39:00+03	42800.00
D99543	2017-07-18 00:55:00+03	11000.00
D99618	2017-08-06 17:10:00+03	34300.00
D996D1	2017-08-13 11:08:00+03	79900.00
D9977F	2017-07-11 14:55:00+03	167400.00
D997DE	2017-07-31 04:06:00+03	26700.00
D9980B	2017-08-01 09:02:00+03	49200.00
D99855	2017-07-09 05:20:00+03	91300.00
D99891	2017-07-03 01:10:00+03	22100.00
D998A2	2017-06-30 13:42:00+03	235700.00
D998BC	2017-07-08 14:59:00+03	69900.00
D998DB	2017-07-29 12:12:00+03	111600.00
D99900	2017-08-08 12:50:00+03	43200.00
D999A6	2017-07-07 21:53:00+03	117200.00
D99A31	2017-07-19 13:08:00+03	412400.00
D99A48	2017-08-11 22:24:00+03	56900.00
D99AE9	2017-07-24 02:25:00+03	54800.00
D99AEA	2017-07-03 12:31:00+03	40200.00
D99B0A	2017-07-14 20:20:00+03	39100.00
D99B19	2017-07-18 19:27:00+03	6800.00
D99B47	2017-07-08 02:47:00+03	118300.00
D99B6C	2017-07-04 22:14:00+03	65900.00
D99B73	2017-07-12 17:57:00+03	6800.00
D99B8A	2017-06-29 23:50:00+03	17000.00
D99BB1	2017-08-07 00:49:00+03	42600.00
D99BC7	2017-07-11 08:57:00+03	16000.00
D99BCC	2017-07-04 10:38:00+03	224000.00
D99BD8	2017-07-30 05:19:00+03	99900.00
D99C03	2017-07-24 13:10:00+03	30800.00
D99C2B	2017-07-22 07:44:00+03	91500.00
D99C4B	2017-08-01 15:18:00+03	56000.00
D99C53	2017-08-07 01:49:00+03	25200.00
D99C69	2017-08-10 07:57:00+03	25400.00
D99C7B	2017-08-15 08:20:00+03	147400.00
D99D9E	2017-08-05 01:15:00+03	137100.00
D99DA5	2017-07-14 21:16:00+03	48500.00
D99E3E	2017-08-14 05:51:00+03	75300.00
D99E42	2017-07-04 10:00:00+03	50700.00
D99FBD	2017-08-15 10:38:00+03	14400.00
D99FED	2017-07-13 18:58:00+03	28000.00
D9A088	2017-07-04 14:59:00+03	43200.00
D9A08D	2017-07-31 11:16:00+03	79900.00
D9A108	2017-08-07 00:23:00+03	27200.00
D9A12F	2017-07-08 16:48:00+03	6800.00
D9A160	2017-07-01 12:26:00+03	238300.00
D9A195	2017-06-30 17:24:00+03	40200.00
D9A1B9	2017-08-12 13:42:00+03	85000.00
D9A1FF	2017-07-19 00:29:00+03	6800.00
D9A281	2017-07-18 15:09:00+03	32700.00
D9A28F	2017-08-04 17:33:00+03	281500.00
D9A2A4	2017-07-19 19:05:00+03	99200.00
D9A2CC	2017-08-13 10:28:00+03	97400.00
D9A345	2017-08-06 04:53:00+03	186900.00
D9A372	2017-07-25 06:30:00+03	99200.00
D9A39C	2017-07-02 13:43:00+03	47500.00
D9A3E8	2017-08-02 13:32:00+03	23600.00
D9A3F0	2017-08-07 21:00:00+03	452900.00
D9A3F8	2017-07-10 15:10:00+03	39800.00
D9A411	2017-08-12 08:18:00+03	40100.00
D9A4DB	2017-07-16 22:33:00+03	29600.00
D9A536	2017-07-17 15:33:00+03	16400.00
D9A584	2017-07-22 12:37:00+03	26000.00
D9A617	2017-07-08 16:36:00+03	42200.00
D9A61B	2017-07-07 11:32:00+03	45200.00
D9A652	2017-08-01 07:25:00+03	14000.00
D9A67F	2017-08-14 06:25:00+03	119000.00
D9A699	2017-07-27 22:03:00+03	38600.00
D9A6CC	2017-08-12 13:21:00+03	26800.00
D9A6CF	2017-07-28 00:34:00+03	68100.00
D9A6E7	2017-08-02 05:56:00+03	56000.00
D9A714	2017-07-19 20:45:00+03	243600.00
D9A761	2017-08-06 16:52:00+03	116800.00
D9A7A1	2017-07-23 09:39:00+03	48800.00
D9A7D5	2017-07-25 06:52:00+03	77100.00
D9A7DA	2017-07-29 03:05:00+03	141600.00
D9A7EB	2017-07-11 15:28:00+03	18600.00
D9A880	2017-07-14 07:15:00+03	62600.00
D9A8AB	2017-07-08 17:37:00+03	65400.00
D9A921	2017-08-08 12:41:00+03	167400.00
D9A95B	2017-08-14 06:25:00+03	120400.00
D9A9D3	2017-08-11 01:08:00+03	13200.00
D9AA00	2017-07-03 03:02:00+03	41500.00
D9AA9B	2017-07-28 23:11:00+03	36800.00
D9AB16	2017-06-27 05:25:00+03	14800.00
D9AB48	2017-08-07 15:46:00+03	6800.00
D9AB83	2017-07-28 01:58:00+03	18600.00
D9AB93	2017-07-29 18:29:00+03	34400.00
D9AC9F	2017-07-06 11:30:00+03	29600.00
D9AD03	2017-07-12 22:53:00+03	49900.00
D9AD0A	2017-07-30 10:03:00+03	13400.00
D9AD1E	2017-07-05 18:47:00+03	14000.00
D9AD20	2017-07-26 05:36:00+03	14400.00
D9AD5F	2017-07-11 04:25:00+03	26000.00
D9AD89	2017-08-13 00:44:00+03	273000.00
D9AD8F	2017-08-08 10:58:00+03	246200.00
D9AD91	2017-08-05 02:48:00+03	68600.00
D9ADB8	2017-08-12 08:06:00+03	67600.00
D9AE1A	2017-07-29 06:37:00+03	8000.00
D9AE2C	2017-06-30 07:11:00+03	67400.00
D9AEBC	2017-08-09 14:10:00+03	55800.00
D9AEEA	2017-07-11 00:09:00+03	39600.00
D9AF40	2017-07-09 18:13:00+03	14800.00
D9AFAB	2017-08-14 11:07:00+03	97700.00
D9B00A	2017-08-02 15:17:00+03	28000.00
D9B075	2017-07-13 04:39:00+03	202300.00
D9B12C	2017-07-11 04:12:00+03	75600.00
D9B166	2017-07-30 19:36:00+03	25900.00
D9B1F5	2017-07-26 02:09:00+03	62600.00
D9B1FC	2017-08-15 02:18:00+03	97700.00
D9B27B	2017-07-21 08:17:00+03	28000.00
D9B2CE	2017-08-01 15:09:00+03	45200.00
D9B330	2017-08-11 19:57:00+03	23200.00
D9B339	2017-08-08 01:03:00+03	87900.00
D9B368	2017-07-27 19:34:00+03	14800.00
D9B3D3	2017-07-08 15:22:00+03	92900.00
D9B416	2017-08-09 15:24:00+03	170000.00
D9B423	2017-07-22 13:14:00+03	7300.00
D9B488	2017-08-10 06:09:00+03	369000.00
D9B49D	2017-07-12 08:24:00+03	33100.00
D9B4CF	2017-07-29 13:13:00+03	8400.00
D9B4E5	2017-07-30 00:03:00+03	24800.00
D9B5A7	2017-07-01 13:19:00+03	16400.00
D9B5B4	2017-07-29 14:14:00+03	59900.00
D9B5E0	2017-08-01 05:41:00+03	52700.00
D9B611	2017-07-14 05:21:00+03	68100.00
D9B618	2017-07-23 09:00:00+03	78600.00
D9B6AF	2017-08-11 22:46:00+03	241100.00
D9B6CC	2017-07-24 19:10:00+03	13400.00
D9B6D0	2017-07-24 04:47:00+03	39800.00
D9B6D2	2017-07-13 18:23:00+03	39200.00
D9B6E8	2017-07-30 12:15:00+03	26000.00
D9B6F8	2017-07-19 22:02:00+03	25800.00
D9B716	2017-08-02 07:11:00+03	38800.00
D9B87A	2017-07-15 05:22:00+03	135400.00
D9B937	2017-07-13 04:18:00+03	85000.00
D9B94E	2017-08-14 04:47:00+03	28800.00
D9B968	2017-07-18 04:19:00+03	56100.00
D9B9C3	2017-08-05 00:36:00+03	111600.00
D9B9E2	2017-07-16 18:34:00+03	400000.00
D9BB0C	2017-07-15 22:49:00+03	48800.00
D9BB20	2017-06-27 15:47:00+03	6700.00
D9BB42	2017-08-02 22:04:00+03	36000.00
D9BB56	2017-07-23 06:26:00+03	46300.00
D9BB59	2017-07-15 08:44:00+03	18600.00
D9BB5C	2017-07-12 03:21:00+03	38600.00
D9BB6C	2017-08-15 01:30:00+03	46500.00
D9BB7B	2017-07-27 20:52:00+03	123000.00
D9BBE1	2017-07-21 18:35:00+03	6700.00
D9BCB1	2017-07-22 01:13:00+03	64700.00
D9BD03	2017-07-15 03:47:00+03	27800.00
D9BD0D	2017-07-30 18:15:00+03	28200.00
D9BD15	2017-07-25 17:01:00+03	27200.00
D9BDA2	2017-07-28 12:30:00+03	24400.00
D9BDC5	2017-07-28 11:07:00+03	58200.00
D9BDC7	2017-08-14 19:09:00+03	48800.00
D9BDDC	2017-07-03 14:39:00+03	21800.00
D9BDDF	2017-08-04 16:05:00+03	40100.00
D9BDFD	2017-07-28 02:51:00+03	23900.00
D9BE40	2017-07-10 05:33:00+03	28000.00
D9BE69	2017-07-23 03:06:00+03	103500.00
D9BE76	2017-07-13 04:50:00+03	135400.00
D9BE9A	2017-07-12 05:51:00+03	56000.00
D9BEFB	2017-08-13 19:50:00+03	70600.00
D9BF68	2017-08-13 09:27:00+03	142600.00
D9BFA4	2017-07-27 23:02:00+03	72900.00
D9BFEE	2017-07-26 15:33:00+03	40800.00
D9C078	2017-07-17 16:58:00+03	58900.00
D9C090	2017-08-08 04:00:00+03	166100.00
D9C0E0	2017-08-12 20:19:00+03	520600.00
D9C0F3	2017-07-06 04:16:00+03	295400.00
D9C173	2017-08-05 15:39:00+03	131600.00
D9C1BE	2017-08-05 04:16:00+03	30200.00
D9C1C8	2017-07-12 12:35:00+03	116800.00
D9C1CC	2017-08-01 05:45:00+03	38400.00
D9C1DC	2017-08-09 04:44:00+03	31600.00
D9C219	2017-07-13 08:39:00+03	265700.00
D9C2C7	2017-07-06 21:24:00+03	123000.00
D9C330	2017-07-22 11:11:00+03	62100.00
D9C349	2017-07-24 02:21:00+03	71200.00
D9C357	2017-08-08 15:24:00+03	260900.00
D9C3CC	2017-07-23 05:32:00+03	21800.00
D9C3D8	2017-07-16 09:38:00+03	81600.00
D9C403	2017-07-30 11:44:00+03	112000.00
D9C447	2017-08-05 20:08:00+03	46800.00
D9C485	2017-07-05 12:23:00+03	51900.00
D9C4B9	2017-07-17 06:16:00+03	56000.00
D9C5CA	2017-08-14 07:36:00+03	60300.00
D9C5FE	2017-08-06 18:38:00+03	58800.00
D9C6C1	2017-07-05 06:13:00+03	56000.00
D9C6C3	2017-08-07 01:25:00+03	28800.00
D9C6E6	2017-08-09 00:42:00+03	119700.00
D9C6F9	2017-07-07 06:54:00+03	113300.00
D9C768	2017-07-06 22:34:00+03	271100.00
D9C7A7	2017-07-24 16:30:00+03	28000.00
D9C85A	2017-07-19 08:54:00+03	68100.00
D9C85B	2017-07-17 11:44:00+03	43600.00
D9C873	2017-08-14 16:50:00+03	13300.00
D9C9E3	2017-07-19 00:06:00+03	32800.00
D9CA6B	2017-08-08 06:36:00+03	44800.00
D9CB34	2017-07-21 12:09:00+03	123600.00
D9CB80	2017-07-16 04:47:00+03	43200.00
D9CB83	2017-08-01 06:43:00+03	54600.00
D9CB9B	2017-07-26 06:47:00+03	85400.00
D9CBFB	2017-07-06 12:43:00+03	516800.00
D9CC88	2017-08-01 17:17:00+03	88600.00
D9CCC9	2017-08-02 20:51:00+03	21200.00
D9CCE2	2017-07-16 22:19:00+03	28800.00
D9CD13	2017-07-23 21:28:00+03	34000.00
D9CD27	2017-07-27 22:55:00+03	64900.00
D9CD9F	2017-07-17 06:26:00+03	51900.00
D9CDAB	2017-07-06 06:29:00+03	24800.00
D9CDAF	2017-08-05 23:48:00+03	244200.00
D9CDF2	2017-06-27 07:27:00+03	93900.00
D9CE04	2017-07-31 05:54:00+03	39800.00
D9CE3C	2017-08-02 18:41:00+03	30000.00
D9CE44	2017-07-18 03:10:00+03	26600.00
D9CEAC	2017-07-26 13:12:00+03	25400.00
D9CECB	2017-07-14 04:19:00+03	34000.00
D9CF3C	2017-07-22 21:07:00+03	98400.00
D9CF7F	2017-07-15 04:37:00+03	53300.00
D9CFAB	2017-07-28 03:28:00+03	55800.00
D9CFD4	2017-08-01 18:02:00+03	18800.00
D9D016	2017-07-05 16:08:00+03	56000.00
D9D091	2017-07-11 07:10:00+03	145600.00
D9D1B5	2017-07-08 13:23:00+03	57500.00
D9D20F	2017-07-21 11:44:00+03	68100.00
D9D264	2017-07-23 14:44:00+03	86600.00
D9D279	2017-08-15 04:57:00+03	18600.00
D9D27B	2017-07-21 10:57:00+03	21400.00
D9D298	2017-07-10 15:45:00+03	122200.00
D9D2C4	2017-07-16 15:50:00+03	28300.00
D9D2F2	2017-07-22 12:20:00+03	6000.00
D9D31F	2017-07-25 08:28:00+03	24800.00
D9D336	2017-07-12 08:32:00+03	34000.00
D9D33D	2017-07-08 09:14:00+03	54300.00
D9D3C3	2017-07-22 13:12:00+03	70800.00
D9D477	2017-08-13 04:56:00+03	26000.00
D9D489	2017-07-10 02:32:00+03	177600.00
D9D4D8	2017-07-25 22:20:00+03	21600.00
D9D532	2017-07-16 22:48:00+03	59800.00
D9D55E	2017-07-31 10:10:00+03	73200.00
D9D575	2017-07-04 05:18:00+03	23200.00
D9D5F9	2017-07-14 21:15:00+03	30200.00
D9D5FD	2017-07-06 14:02:00+03	94000.00
D9D620	2017-08-09 22:06:00+03	21400.00
D9D64D	2017-07-11 11:43:00+03	46200.00
D9D676	2017-07-26 02:56:00+03	57500.00
D9D68A	2017-07-18 01:22:00+03	87200.00
D9D697	2017-07-14 22:58:00+03	120600.00
D9D6D0	2017-07-31 20:09:00+03	13600.00
D9D758	2017-08-07 09:24:00+03	123000.00
D9D77D	2017-07-01 04:14:00+03	28600.00
D9D7D9	2017-06-30 00:11:00+03	57400.00
D9D7DC	2017-08-14 00:29:00+03	23400.00
D9D857	2017-07-19 05:50:00+03	46400.00
D9D92E	2017-07-07 05:31:00+03	39800.00
D9D933	2017-08-14 23:21:00+03	14000.00
D9D981	2017-07-14 07:25:00+03	47400.00
D9DA70	2017-08-13 18:29:00+03	72000.00
D9DAD0	2017-07-03 04:47:00+03	14000.00
D9DB10	2017-08-08 05:15:00+03	41200.00
D9DB15	2017-07-08 17:02:00+03	67000.00
D9DB67	2017-08-04 00:39:00+03	269600.00
D9DB83	2017-08-05 14:49:00+03	90800.00
D9DBA4	2017-08-05 01:26:00+03	15000.00
D9DBAA	2017-07-29 03:52:00+03	27200.00
D9DC5F	2017-07-11 20:57:00+03	205600.00
D9DC62	2017-07-22 10:55:00+03	93800.00
D9DCD8	2017-07-29 13:01:00+03	36400.00
D9DCDA	2017-07-09 15:08:00+03	146000.00
D9DDD5	2017-07-26 20:19:00+03	40000.00
D9DE85	2017-07-02 19:59:00+03	55800.00
D9DF6A	2017-08-14 04:55:00+03	47100.00
D9DFB8	2017-08-01 13:49:00+03	22400.00
D9E0B4	2017-07-22 16:16:00+03	75300.00
D9E0D9	2017-07-14 12:11:00+03	31000.00
D9E1A4	2017-07-19 19:55:00+03	169300.00
D9E1C4	2017-07-11 10:07:00+03	21800.00
D9E238	2017-07-12 01:17:00+03	54300.00
D9E245	2017-07-09 17:51:00+03	30400.00
D9E260	2017-07-13 18:36:00+03	19500.00
D9E2B8	2017-07-30 00:33:00+03	23600.00
D9E32D	2017-07-23 21:46:00+03	48800.00
D9E381	2017-07-05 22:12:00+03	54000.00
D9E3AC	2017-07-26 08:48:00+03	46000.00
D9E3B7	2017-08-03 22:14:00+03	36800.00
D9E3BB	2017-07-22 05:45:00+03	88400.00
D9E400	2017-07-12 01:09:00+03	24400.00
D9E461	2017-07-02 02:18:00+03	99000.00
D9E465	2017-08-03 18:42:00+03	99200.00
D9E46F	2017-07-09 09:17:00+03	26000.00
D9E480	2017-07-22 19:31:00+03	86600.00
D9E52F	2017-07-23 03:00:00+03	98300.00
D9E5BD	2017-08-15 13:51:00+03	59800.00
D9E622	2017-06-30 01:19:00+03	19500.00
D9E629	2017-08-14 19:58:00+03	56000.00
D9E642	2017-08-04 06:47:00+03	34800.00
D9E657	2017-07-30 13:59:00+03	78100.00
D9E66A	2017-07-19 18:15:00+03	35700.00
D9E6FC	2017-08-09 09:56:00+03	16400.00
D9E707	2017-07-26 17:53:00+03	58600.00
D9E721	2017-07-16 14:18:00+03	8200.00
D9E767	2017-07-31 10:57:00+03	157100.00
D9E78E	2017-07-20 01:31:00+03	23900.00
D9E7AB	2017-08-11 00:49:00+03	32700.00
D9E81F	2017-08-11 06:06:00+03	13600.00
D9E828	2017-08-06 09:10:00+03	72400.00
D9E864	2017-08-13 13:27:00+03	128800.00
D9E895	2017-07-31 17:15:00+03	68400.00
D9E8E0	2017-08-01 16:39:00+03	58800.00
D9E910	2017-08-11 08:48:00+03	49500.00
D9E96C	2017-07-02 19:10:00+03	112000.00
D9E978	2017-07-20 00:42:00+03	66000.00
D9E98A	2017-08-08 02:05:00+03	48800.00
D9E9C0	2017-08-03 07:34:00+03	28000.00
D9E9E0	2017-08-10 20:47:00+03	30800.00
D9EA01	2017-08-13 23:29:00+03	32700.00
D9EA04	2017-07-02 18:29:00+03	33100.00
D9EA89	2017-07-13 18:03:00+03	50600.00
D9EAB1	2017-07-24 13:57:00+03	168000.00
D9EABA	2017-07-19 01:42:00+03	57300.00
D9EAF3	2017-08-10 23:46:00+03	260300.00
D9EB31	2017-08-04 22:24:00+03	32700.00
D9EB9C	2017-08-01 11:33:00+03	53400.00
D9EBB3	2017-07-14 16:48:00+03	135600.00
D9EBD0	2017-07-24 19:32:00+03	81200.00
D9EBEC	2017-08-11 21:17:00+03	92000.00
D9EC0A	2017-08-10 16:33:00+03	187600.00
D9EC40	2017-07-22 01:50:00+03	23600.00
D9EC55	2017-07-24 09:36:00+03	67000.00
D9EC73	2017-07-07 15:09:00+03	13400.00
D9EC85	2017-07-11 23:52:00+03	38800.00
D9ECBC	2017-07-16 11:34:00+03	40000.00
D9ECD6	2017-08-08 12:43:00+03	81300.00
D9ED02	2017-07-09 10:37:00+03	20700.00
D9ED03	2017-07-31 08:39:00+03	516800.00
D9ED24	2017-08-15 12:12:00+03	173200.00
D9ED68	2017-08-06 07:22:00+03	62800.00
D9EDAC	2017-08-12 06:46:00+03	40000.00
D9EDE0	2017-07-31 18:56:00+03	31600.00
D9EE35	2017-07-01 20:08:00+03	66800.00
D9EE5F	2017-07-17 15:50:00+03	40000.00
D9EE99	2017-08-06 04:59:00+03	46400.00
D9EEB2	2017-07-11 15:48:00+03	10700.00
D9EF07	2017-07-20 01:52:00+03	377100.00
D9EFA1	2017-07-01 06:42:00+03	54500.00
D9F0CD	2017-08-14 05:09:00+03	58200.00
D9F123	2017-07-23 14:48:00+03	14000.00
D9F131	2017-07-10 21:00:00+03	46000.00
D9F14E	2017-07-31 02:44:00+03	199200.00
D9F15A	2017-06-30 11:50:00+03	68400.00
D9F191	2017-08-08 04:40:00+03	109000.00
D9F1E1	2017-07-31 05:44:00+03	68000.00
D9F216	2017-07-10 19:23:00+03	377100.00
D9F21B	2017-08-13 13:12:00+03	214900.00
D9F254	2017-08-05 22:29:00+03	61900.00
D9F270	2017-07-18 16:50:00+03	26000.00
D9F28C	2017-07-23 06:51:00+03	173700.00
D9F2D4	2017-08-01 14:38:00+03	26000.00
D9F2E5	2017-08-13 10:53:00+03	30100.00
D9F2FF	2017-07-12 16:18:00+03	43100.00
D9F334	2017-07-08 13:28:00+03	52700.00
D9F355	2017-08-06 02:08:00+03	38800.00
D9F35A	2017-07-28 01:16:00+03	46200.00
D9F3C8	2017-08-07 11:35:00+03	75600.00
D9F3FD	2017-07-28 11:09:00+03	69400.00
D9F43E	2017-08-10 14:38:00+03	20200.00
D9F451	2017-07-12 09:32:00+03	29300.00
D9F461	2017-07-09 21:49:00+03	62800.00
D9F465	2017-07-22 17:18:00+03	135600.00
D9F567	2017-07-09 14:36:00+03	46700.00
D9F5B4	2017-07-05 06:52:00+03	24400.00
D9F610	2017-08-12 13:13:00+03	59400.00
D9F612	2017-08-03 19:06:00+03	181600.00
D9F687	2017-08-10 22:18:00+03	6300.00
D9F6CB	2017-07-21 07:08:00+03	106900.00
D9F74D	2017-07-10 00:43:00+03	141300.00
D9F864	2017-08-12 17:11:00+03	139800.00
D9F901	2017-07-08 17:19:00+03	77000.00
D9F90B	2017-08-03 03:57:00+03	76100.00
D9F92B	2017-08-06 11:09:00+03	396500.00
D9F973	2017-08-14 23:58:00+03	25600.00
D9F987	2017-08-09 20:28:00+03	370800.00
D9F9B0	2017-07-20 18:44:00+03	169300.00
D9F9C5	2017-07-17 13:15:00+03	36200.00
D9F9C9	2017-07-31 10:30:00+03	46200.00
D9F9E1	2017-07-05 13:05:00+03	289200.00
D9FAD0	2017-08-06 11:26:00+03	36200.00
D9FAD3	2017-07-28 21:33:00+03	57800.00
D9FADE	2017-08-11 08:48:00+03	133100.00
D9FB25	2017-07-27 05:41:00+03	19600.00
D9FB39	2017-08-05 15:10:00+03	63900.00
D9FB44	2017-07-11 14:21:00+03	96300.00
D9FB63	2017-07-07 08:50:00+03	148200.00
D9FBA3	2017-07-10 13:26:00+03	84100.00
D9FBFA	2017-07-30 08:57:00+03	135600.00
D9FC09	2017-07-13 10:55:00+03	25600.00
D9FC3B	2017-08-14 11:07:00+03	42800.00
D9FC44	2017-07-20 01:47:00+03	75600.00
D9FC63	2017-07-23 10:58:00+03	12200.00
D9FC80	2017-07-23 08:48:00+03	91500.00
D9FC88	2017-07-03 21:41:00+03	57600.00
D9FCCB	2017-07-14 16:07:00+03	136600.00
D9FDF2	2017-07-17 03:38:00+03	94200.00
D9FDF3	2017-07-21 22:59:00+03	73500.00
D9FEC3	2017-07-09 23:41:00+03	28000.00
D9FF49	2017-08-11 01:49:00+03	100700.00
D9FF6A	2017-08-03 00:46:00+03	31600.00
D9FF6E	2017-08-10 12:50:00+03	48100.00
D9FF75	2017-08-06 15:12:00+03	60400.00
D9FF87	2017-07-19 07:19:00+03	29600.00
D9FFC1	2017-07-23 13:11:00+03	291500.00
D9FFD7	2017-07-10 14:31:00+03	132800.00
DA008D	2017-07-27 18:28:00+03	26000.00
DA0139	2017-08-05 08:33:00+03	43500.00
DA01E3	2017-07-01 02:42:00+03	31800.00
DA01F9	2017-07-11 14:42:00+03	16800.00
DA033B	2017-07-14 00:30:00+03	43400.00
DA0434	2017-08-01 11:51:00+03	36900.00
DA046A	2017-07-07 06:37:00+03	123000.00
DA049B	2017-07-08 13:24:00+03	23200.00
DA04B6	2017-07-21 23:06:00+03	99800.00
DA04FE	2017-07-12 12:43:00+03	38600.00
DA0528	2017-07-25 14:33:00+03	56000.00
DA052D	2017-07-11 10:00:00+03	57800.00
DA052F	2017-07-17 12:51:00+03	34000.00
DA0585	2017-07-05 19:26:00+03	30900.00
DA0590	2017-08-07 13:53:00+03	65300.00
DA05C3	2017-07-23 18:26:00+03	51900.00
DA0617	2017-08-05 22:11:00+03	38800.00
DA0619	2017-07-13 03:28:00+03	270800.00
DA066A	2017-07-04 00:05:00+03	77000.00
DA067B	2017-07-29 18:33:00+03	32200.00
DA0726	2017-08-03 07:25:00+03	398500.00
DA079F	2017-07-09 20:42:00+03	133700.00
DA07E2	2017-08-05 14:32:00+03	47400.00
DA07E7	2017-07-16 06:34:00+03	61800.00
DA0822	2017-07-19 13:58:00+03	52000.00
DA0858	2017-07-08 20:51:00+03	56600.00
DA092A	2017-08-14 18:57:00+03	46400.00
DA0989	2017-07-22 02:22:00+03	46800.00
DA099E	2017-08-14 04:10:00+03	28800.00
DA09BC	2017-08-14 18:56:00+03	40800.00
DA0A16	2017-07-18 07:08:00+03	92700.00
DA0A6C	2017-07-08 06:34:00+03	271200.00
DA0A8E	2017-08-11 22:24:00+03	184900.00
DA0B6E	2017-08-11 18:36:00+03	148200.00
DA0B80	2017-07-14 03:21:00+03	6900.00
DA0B9A	2017-07-15 17:41:00+03	36200.00
DA0B9F	2017-07-06 15:12:00+03	12200.00
DA0BA8	2017-07-21 01:34:00+03	381400.00
DA0BB5	2017-07-30 05:27:00+03	20200.00
DA0C00	2017-08-07 14:43:00+03	133100.00
DA0C26	2017-07-14 18:13:00+03	36900.00
DA0C37	2017-08-05 02:17:00+03	88100.00
DA0C99	2017-07-10 08:16:00+03	194800.00
DA0CCA	2017-07-05 06:24:00+03	181600.00
DA0D02	2017-08-03 14:51:00+03	67700.00
DA0D2B	2017-08-06 13:13:00+03	14800.00
DA0D30	2017-08-08 15:52:00+03	51200.00
DA0DBE	2017-08-01 20:08:00+03	58400.00
DA0DDC	2017-07-23 06:45:00+03	34400.00
DA0DF0	2017-07-25 20:03:00+03	59800.00
DA0E0D	2017-07-27 15:16:00+03	271100.00
DA0F11	2017-07-10 02:58:00+03	81300.00
DA0F43	2017-06-29 06:04:00+03	285300.00
DA0FED	2017-08-03 23:19:00+03	35500.00
DA1058	2017-07-24 23:13:00+03	6000.00
DA1098	2017-07-12 13:15:00+03	51200.00
DA10C9	2017-07-01 15:59:00+03	100600.00
DA113F	2017-07-30 17:34:00+03	204200.00
DA1191	2017-07-05 11:42:00+03	23400.00
DA11CE	2017-07-26 13:00:00+03	88800.00
DA11E1	2017-07-29 17:32:00+03	15100.00
DA1235	2017-08-04 17:27:00+03	80900.00
DA1264	2017-06-28 17:53:00+03	28000.00
DA1286	2017-08-03 03:39:00+03	86400.00
DA1299	2017-07-30 11:06:00+03	27200.00
DA12D5	2017-08-09 08:14:00+03	75600.00
DA12E1	2017-07-23 23:04:00+03	22000.00
DA135D	2017-08-06 21:14:00+03	50600.00
DA1399	2017-07-27 09:58:00+03	48800.00
DA13BD	2017-07-09 23:38:00+03	212800.00
DA13FF	2017-08-05 04:57:00+03	61500.00
DA1480	2017-08-09 20:11:00+03	64700.00
DA150C	2017-07-17 22:45:00+03	46000.00
DA1557	2017-08-11 22:01:00+03	24700.00
DA15C9	2017-08-08 06:34:00+03	243600.00
DA1626	2017-08-01 15:41:00+03	258400.00
DA163D	2017-07-30 03:03:00+03	26700.00
DA16D7	2017-07-26 20:00:00+03	73200.00
DA16D8	2017-07-06 06:09:00+03	27200.00
DA16F4	2017-07-10 17:45:00+03	93900.00
DA1723	2017-07-07 21:32:00+03	86800.00
DA1751	2017-07-21 06:19:00+03	68800.00
DA1759	2017-07-27 18:29:00+03	31400.00
DA17BC	2017-07-21 02:17:00+03	19600.00
DA17BE	2017-07-15 01:59:00+03	23900.00
DA183D	2017-07-24 20:06:00+03	35800.00
DA1853	2017-07-06 20:03:00+03	166000.00
DA1860	2017-07-13 08:24:00+03	123000.00
DA18B5	2017-07-28 10:10:00+03	31600.00
DA1955	2017-08-12 04:02:00+03	252200.00
DA198D	2017-08-15 11:50:00+03	87700.00
DA199C	2017-07-09 00:31:00+03	169900.00
DA19E0	2017-07-04 02:04:00+03	89100.00
DA1A3D	2017-07-24 10:12:00+03	159400.00
DA1A66	2017-07-27 11:20:00+03	20200.00
DA1A7B	2017-08-11 03:38:00+03	75600.00
DA1AEA	2017-08-02 19:15:00+03	136800.00
DA1AF6	2017-07-20 03:53:00+03	10800.00
DA1B0F	2017-08-12 10:08:00+03	40400.00
DA1B1B	2017-08-11 17:34:00+03	202400.00
DA1B25	2017-08-08 16:17:00+03	23200.00
DA1B4F	2017-07-19 11:02:00+03	11600.00
DA1B51	2017-07-08 07:03:00+03	22000.00
DA1B57	2017-07-27 06:22:00+03	100400.00
DA1BBD	2017-07-01 05:31:00+03	108000.00
DA1C08	2017-08-14 09:59:00+03	231400.00
DA1C60	2017-08-02 04:44:00+03	73600.00
DA1C94	2017-08-12 18:26:00+03	56600.00
DA1CC6	2017-07-12 22:59:00+03	67600.00
DA1D4F	2017-07-26 19:12:00+03	25200.00
DA1DD6	2017-07-01 20:56:00+03	134400.00
DA1E6E	2017-07-20 14:50:00+03	83000.00
DA1F02	2017-07-28 12:47:00+03	59800.00
DA1F3C	2017-08-11 07:18:00+03	61500.00
DA2046	2017-08-08 02:41:00+03	248300.00
DA2085	2017-06-30 00:08:00+03	169900.00
DA20A6	2017-07-18 09:55:00+03	31000.00
DA20F9	2017-08-03 21:35:00+03	34600.00
DA2198	2017-06-26 02:42:00+03	49700.00
DA219A	2017-07-26 12:47:00+03	48400.00
DA21F0	2017-08-11 12:31:00+03	28800.00
DA21FC	2017-08-03 20:29:00+03	30700.00
DA22D4	2017-07-12 02:27:00+03	73500.00
DA22E1	2017-08-12 14:53:00+03	106200.00
DA23D7	2017-08-05 11:32:00+03	131100.00
DA2427	2017-08-06 15:44:00+03	31700.00
DA2446	2017-08-12 07:11:00+03	177200.00
DA246A	2017-07-31 08:52:00+03	40800.00
DA24DA	2017-07-07 14:45:00+03	28800.00
DA24E4	2017-08-04 13:46:00+03	45100.00
DA24FF	2017-07-06 20:00:00+03	44800.00
DA25C0	2017-06-29 12:18:00+03	15400.00
DA25EB	2017-07-16 21:54:00+03	103600.00
DA2682	2017-07-30 18:06:00+03	26000.00
DA26A0	2017-07-04 16:51:00+03	69500.00
DA2751	2017-07-08 14:17:00+03	43800.00
DA2755	2017-07-11 00:39:00+03	23200.00
DA2769	2017-08-13 01:48:00+03	91600.00
DA27AA	2017-07-21 11:27:00+03	70700.00
DA27B2	2017-07-04 14:25:00+03	39600.00
DA2806	2017-08-03 16:44:00+03	24500.00
DA2840	2017-07-18 11:06:00+03	18600.00
DA28E3	2017-08-13 11:55:00+03	230400.00
DA2911	2017-07-28 15:11:00+03	71900.00
DA291C	2017-06-29 01:40:00+03	26000.00
DA2939	2017-07-15 19:21:00+03	46200.00
DA2996	2017-08-05 03:08:00+03	15900.00
DA29A3	2017-07-06 13:02:00+03	40000.00
DA2A0A	2017-08-14 23:18:00+03	61800.00
DA2A31	2017-08-13 04:22:00+03	29600.00
DA2A6A	2017-07-27 19:28:00+03	23200.00
DA2B0E	2017-08-07 01:29:00+03	155600.00
DA2B31	2017-07-05 17:24:00+03	114800.00
DA2B54	2017-07-06 03:56:00+03	207200.00
DA2B6D	2017-08-07 13:30:00+03	49900.00
DA2B9C	2017-07-06 10:00:00+03	16400.00
DA2C64	2017-08-15 11:47:00+03	52700.00
DA2C82	2017-07-15 15:46:00+03	89600.00
DA2C83	2017-07-22 09:12:00+03	56000.00
DA2CA4	2017-08-13 09:22:00+03	99200.00
DA2CE3	2017-07-23 22:24:00+03	23400.00
DA2D15	2017-08-12 21:39:00+03	43600.00
DA2D21	2017-07-26 07:14:00+03	46200.00
DA2D4F	2017-08-05 06:06:00+03	157100.00
DA2DA5	2017-07-23 01:14:00+03	158100.00
DA2DAF	2017-07-07 15:30:00+03	174900.00
DA2DC2	2017-07-02 09:30:00+03	56000.00
DA2DFA	2017-07-05 05:38:00+03	7400.00
DA2E06	2017-07-05 19:58:00+03	63500.00
DA2E17	2017-07-16 14:25:00+03	100600.00
DA2E31	2017-08-08 00:16:00+03	207200.00
DA2EA4	2017-07-24 18:23:00+03	6700.00
DA2EB3	2017-06-30 22:44:00+03	28700.00
DA2EEC	2017-07-10 18:35:00+03	48100.00
DA2F04	2017-07-01 18:02:00+03	89700.00
DA2F4D	2017-07-25 06:42:00+03	26800.00
DA2F61	2017-07-23 20:47:00+03	32700.00
DA2F78	2017-07-23 15:34:00+03	28800.00
DA2FCB	2017-08-04 13:34:00+03	6300.00
DA2FD6	2017-08-14 06:59:00+03	173900.00
DA2FE6	2017-07-02 09:36:00+03	29600.00
DA302F	2017-07-12 01:47:00+03	60700.00
DA3084	2017-07-09 22:22:00+03	123000.00
DA30E8	2017-08-07 02:22:00+03	61200.00
DA3104	2017-07-14 06:05:00+03	150000.00
DA3109	2017-07-16 18:37:00+03	96800.00
DA313B	2017-08-10 18:25:00+03	87900.00
DA3157	2017-07-17 22:29:00+03	135400.00
DA3177	2017-08-05 19:56:00+03	23200.00
DA3189	2017-07-21 08:01:00+03	46400.00
DA3202	2017-08-06 17:35:00+03	89200.00
DA3241	2017-07-24 13:19:00+03	63500.00
DA329B	2017-08-05 04:27:00+03	47000.00
DA32B6	2017-08-14 09:02:00+03	59300.00
DA32E2	2017-07-08 11:46:00+03	239900.00
DA33A8	2017-07-17 03:20:00+03	40000.00
DA33D2	2017-07-26 18:16:00+03	133200.00
DA342D	2017-08-14 23:39:00+03	91600.00
DA3475	2017-07-18 02:22:00+03	49600.00
DA3476	2017-07-22 00:45:00+03	8400.00
DA34D1	2017-07-19 00:26:00+03	46200.00
DA353D	2017-08-12 18:04:00+03	81200.00
DA3561	2017-08-09 00:40:00+03	201800.00
DA35F5	2017-07-12 10:53:00+03	170700.00
DA3629	2017-07-26 05:08:00+03	172100.00
DA363D	2017-07-26 07:17:00+03	34000.00
DA3672	2017-07-23 16:31:00+03	89900.00
DA36A3	2017-07-21 08:26:00+03	25400.00
DA36EE	2017-07-30 07:31:00+03	56000.00
DA3701	2017-07-25 19:10:00+03	79300.00
DA3793	2017-08-07 14:07:00+03	136200.00
DA37AF	2017-08-13 20:33:00+03	57600.00
DA37CB	2017-07-21 13:54:00+03	112000.00
DA37F8	2017-07-26 11:19:00+03	131800.00
DA3893	2017-07-30 15:30:00+03	28600.00
DA38CD	2017-08-11 16:12:00+03	133100.00
DA38FF	2017-08-13 14:14:00+03	23600.00
DA3915	2017-07-03 16:51:00+03	124200.00
DA3929	2017-07-14 14:07:00+03	81800.00
DA39C3	2017-07-26 01:52:00+03	67600.00
DA39EB	2017-07-11 10:16:00+03	32800.00
DA3A60	2017-07-15 02:36:00+03	29400.00
DA3ACE	2017-07-31 17:38:00+03	279000.00
DA3B76	2017-07-13 11:08:00+03	14400.00
DA3B7B	2017-08-03 04:06:00+03	355200.00
DA3B8B	2017-08-04 03:34:00+03	23400.00
DA3B8E	2017-07-10 22:33:00+03	30200.00
DA3C00	2017-07-27 18:52:00+03	66600.00
DA3C04	2017-07-04 12:15:00+03	27800.00
DA3C0B	2017-07-11 18:37:00+03	80200.00
DA3C16	2017-07-16 21:57:00+03	54700.00
DA3C66	2017-07-26 22:44:00+03	56900.00
DA3C9D	2017-07-20 19:14:00+03	131100.00
DA3D37	2017-08-09 01:39:00+03	10800.00
DA3D76	2017-08-04 07:37:00+03	12400.00
DA3D90	2017-07-15 12:38:00+03	62100.00
DA3DA6	2017-07-30 18:02:00+03	50600.00
DA3E0C	2017-07-22 02:25:00+03	46200.00
DA3F08	2017-07-02 00:24:00+03	89700.00
DA3F0F	2017-07-25 22:53:00+03	37000.00
DA3F7F	2017-07-09 17:07:00+03	44000.00
DA3FCF	2017-07-14 02:56:00+03	271100.00
DA4042	2017-07-10 19:13:00+03	47600.00
DA40FD	2017-08-08 07:24:00+03	342100.00
DA4175	2017-08-10 03:46:00+03	16400.00
DA4193	2017-07-28 09:15:00+03	86400.00
DA419A	2017-08-04 19:03:00+03	144700.00
DA41D2	2017-08-04 09:50:00+03	18000.00
DA4236	2017-08-06 01:44:00+03	46400.00
DA4251	2017-07-30 22:28:00+03	13400.00
DA42B5	2017-07-11 01:58:00+03	6700.00
DA4310	2017-07-08 02:15:00+03	12400.00
DA4311	2017-08-01 23:28:00+03	92600.00
DA432D	2017-07-07 09:03:00+03	149500.00
DA4353	2017-07-10 11:14:00+03	47100.00
DA43F4	2017-07-19 15:58:00+03	24400.00
DA4429	2017-07-11 02:34:00+03	6000.00
DA4460	2017-07-20 12:24:00+03	49600.00
DA44B1	2017-08-12 22:10:00+03	30300.00
DA44C3	2017-07-26 08:40:00+03	92800.00
DA44F8	2017-07-18 12:51:00+03	288600.00
DA450B	2017-07-12 22:05:00+03	18600.00
DA4521	2017-06-30 02:02:00+03	39500.00
DA4563	2017-07-08 09:16:00+03	14400.00
DA45DF	2017-07-31 07:24:00+03	96200.00
DA4637	2017-07-24 17:49:00+03	43900.00
DA46E1	2017-08-07 00:20:00+03	26700.00
DA46EB	2017-08-01 15:11:00+03	85200.00
DA46ED	2017-07-20 14:53:00+03	30800.00
DA478D	2017-07-28 05:51:00+03	123200.00
DA483E	2017-07-14 07:31:00+03	39800.00
DA4865	2017-08-04 02:17:00+03	182000.00
DA48D9	2017-08-14 01:36:00+03	69500.00
DA48E1	2017-07-03 19:15:00+03	96800.00
DA4911	2017-08-14 10:30:00+03	31600.00
DA494F	2017-07-04 19:23:00+03	8000.00
DA4960	2017-07-21 03:26:00+03	39800.00
DA4961	2017-06-30 06:14:00+03	132800.00
DA4963	2017-07-12 11:47:00+03	136200.00
DA49AB	2017-07-26 12:25:00+03	56000.00
DA49EE	2017-07-21 01:56:00+03	37900.00
DA4A1C	2017-07-31 01:28:00+03	95600.00
DA4A4E	2017-07-26 11:06:00+03	147400.00
DA4A5D	2017-08-03 14:22:00+03	59200.00
DA4A61	2017-07-25 16:22:00+03	206000.00
DA4A71	2017-07-24 23:17:00+03	111600.00
DA4B06	2017-08-08 13:07:00+03	18000.00
DA4B4E	2017-07-12 13:38:00+03	99200.00
DA4BEF	2017-06-25 20:55:00+03	28800.00
DA4C4D	2017-07-29 23:05:00+03	56000.00
DA4C7D	2017-08-09 06:36:00+03	23900.00
DA4C8F	2017-07-31 20:05:00+03	31400.00
DA4CA5	2017-07-22 22:22:00+03	69400.00
DA4D12	2017-07-28 05:35:00+03	6700.00
DA4D23	2017-07-01 03:38:00+03	97900.00
DA4D8B	2017-07-24 23:25:00+03	24800.00
DA4D92	2017-08-15 17:25:00+03	62800.00
DA4D9D	2017-07-12 20:45:00+03	21800.00
DA4DCE	2017-07-20 10:13:00+03	38600.00
DA4DDA	2017-07-30 19:19:00+03	97900.00
DA4E7E	2017-08-08 16:22:00+03	123000.00
DA4E91	2017-08-08 21:31:00+03	189700.00
DA4E99	2017-07-29 21:44:00+03	136200.00
DA4ECC	2017-08-07 06:19:00+03	65500.00
DA4EF6	2017-07-18 01:18:00+03	157200.00
DA4F08	2017-07-09 05:01:00+03	9800.00
DA4FDC	2017-07-17 14:32:00+03	123000.00
DA5029	2017-07-24 12:04:00+03	265700.00
DA506A	2017-07-25 05:57:00+03	105000.00
DA507E	2017-08-13 07:18:00+03	170200.00
DA50E3	2017-07-31 11:07:00+03	28800.00
DA5123	2017-07-07 18:43:00+03	8600.00
DA518C	2017-08-13 12:56:00+03	8000.00
DA51AB	2017-08-10 18:55:00+03	20400.00
DA51E9	2017-08-10 01:29:00+03	21400.00
DA51F7	2017-07-03 02:26:00+03	124400.00
DA5200	2017-07-25 10:58:00+03	6700.00
DA5242	2017-08-13 02:30:00+03	56000.00
DA52A2	2017-08-11 08:18:00+03	64500.00
DA52D2	2017-07-21 04:14:00+03	57500.00
DA531A	2017-07-06 14:28:00+03	190700.00
DA5331	2017-08-10 09:55:00+03	90000.00
DA5387	2017-07-04 09:36:00+03	204500.00
DA53B0	2017-08-07 09:43:00+03	21700.00
DA53D1	2017-07-03 15:02:00+03	138000.00
DA53EF	2017-07-30 19:33:00+03	54000.00
DA53F6	2017-07-16 12:01:00+03	199700.00
DA541A	2017-07-15 20:27:00+03	13400.00
DA5481	2017-08-13 09:08:00+03	25200.00
DA5484	2017-07-30 13:51:00+03	42700.00
DA54CF	2017-08-06 02:18:00+03	12600.00
DA5508	2017-08-02 02:23:00+03	24400.00
DA5585	2017-07-07 22:47:00+03	23900.00
DA55B3	2017-07-18 05:19:00+03	395000.00
DA56C5	2017-07-31 17:59:00+03	68800.00
DA56E3	2017-08-06 18:07:00+03	151800.00
DA5717	2017-07-12 14:09:00+03	23600.00
DA571E	2017-08-03 03:58:00+03	112000.00
DA5765	2017-07-18 09:17:00+03	133200.00
DA57B4	2017-07-04 03:13:00+03	174400.00
DA57DE	2017-07-25 18:07:00+03	56000.00
DA5800	2017-08-06 05:55:00+03	64700.00
DA5889	2017-07-11 14:56:00+03	101200.00
DA5891	2017-08-05 12:43:00+03	231400.00
DA593C	2017-08-03 05:59:00+03	34600.00
DA5A04	2017-07-05 12:25:00+03	22400.00
DA5BCD	2017-07-10 13:05:00+03	46000.00
DA5BDF	2017-07-26 19:03:00+03	47000.00
DA5C5C	2017-07-29 23:56:00+03	136000.00
DA5CD4	2017-07-25 14:52:00+03	67400.00
DA5CE4	2017-07-25 23:50:00+03	68300.00
DA5CEF	2017-07-11 04:50:00+03	64800.00
DA5D0D	2017-07-28 11:30:00+03	99200.00
DA5D19	2017-07-04 22:16:00+03	67600.00
DA5DB2	2017-07-01 23:18:00+03	67600.00
DA5E24	2017-06-28 13:43:00+03	57800.00
DA5E2F	2017-08-09 12:35:00+03	113200.00
DA5E31	2017-08-07 04:39:00+03	31400.00
DA5E36	2017-08-11 14:44:00+03	58600.00
DA5E46	2017-07-27 04:14:00+03	165500.00
DA5EA8	2017-07-20 23:56:00+03	114300.00
DA5EDF	2017-08-15 11:49:00+03	46000.00
DA5EE4	2017-07-15 05:35:00+03	38800.00
DA5F23	2017-07-12 18:43:00+03	33800.00
DA5FD7	2017-08-09 20:02:00+03	42800.00
DA5FEB	2017-07-10 07:06:00+03	25000.00
DA6047	2017-07-10 20:34:00+03	271200.00
DA6066	2017-08-04 14:26:00+03	14400.00
DA60EE	2017-07-03 23:16:00+03	61800.00
DA6145	2017-08-10 13:28:00+03	11000.00
DA6168	2017-07-08 09:18:00+03	103500.00
DA616F	2017-08-08 01:34:00+03	46000.00
DA622E	2017-08-12 13:11:00+03	192400.00
DA6230	2017-07-17 18:47:00+03	47100.00
DA6318	2017-07-13 11:41:00+03	46000.00
DA637E	2017-07-05 14:24:00+03	223200.00
DA63BA	2017-07-06 15:54:00+03	25200.00
DA63CC	2017-07-09 19:58:00+03	14800.00
DA6472	2017-07-11 15:20:00+03	26200.00
DA649F	2017-07-24 05:46:00+03	73200.00
DA64C1	2017-08-04 23:39:00+03	23200.00
DA6507	2017-07-22 16:47:00+03	130300.00
DA6541	2017-08-09 21:44:00+03	71200.00
DA65B8	2017-07-24 05:51:00+03	39400.00
DA65F4	2017-07-05 02:12:00+03	18800.00
DA664A	2017-07-17 09:07:00+03	63700.00
DA66A9	2017-07-24 14:12:00+03	24400.00
DA6700	2017-07-10 02:06:00+03	47400.00
DA6786	2017-07-08 14:09:00+03	135400.00
DA67D8	2017-07-04 22:28:00+03	8600.00
DA67EA	2017-07-08 20:37:00+03	131100.00
DA6824	2017-07-13 12:44:00+03	123000.00
DA6829	2017-08-02 18:51:00+03	12000.00
DA6904	2017-08-05 05:36:00+03	134600.00
DA6A12	2017-08-14 09:23:00+03	188500.00
DA6AA7	2017-07-13 03:39:00+03	39400.00
DA6B16	2017-07-21 13:40:00+03	61800.00
DA6B6F	2017-08-13 15:58:00+03	86400.00
DA6C14	2017-08-11 18:45:00+03	139000.00
DA6C74	2017-07-23 12:27:00+03	24800.00
DA6CEF	2017-07-11 17:17:00+03	43600.00
DA6D3F	2017-07-16 18:08:00+03	29200.00
DA6D91	2017-08-03 20:40:00+03	291000.00
DA6DE1	2017-08-14 21:42:00+03	120800.00
DA6DE8	2017-07-19 10:45:00+03	27400.00
DA6DED	2017-07-18 07:40:00+03	34000.00
DA6DFD	2017-07-27 23:18:00+03	52700.00
DA6E58	2017-06-29 13:53:00+03	14700.00
DA6E9D	2017-07-12 16:11:00+03	92800.00
DA6EA6	2017-08-03 09:18:00+03	28000.00
DA6EB1	2017-07-23 14:02:00+03	38900.00
DA6ED0	2017-06-29 02:42:00+03	65300.00
DA6F10	2017-08-12 19:43:00+03	176400.00
DA6F3B	2017-07-10 02:41:00+03	54500.00
DA6F85	2017-07-07 19:18:00+03	22300.00
DA6FCD	2017-07-03 21:07:00+03	58400.00
DA7045	2017-07-15 00:11:00+03	220700.00
DA706B	2017-07-08 08:32:00+03	6600.00
DA7086	2017-07-27 18:30:00+03	35200.00
DA70B8	2017-07-07 14:04:00+03	8200.00
DA70BF	2017-07-28 11:20:00+03	25900.00
DA70C1	2017-07-13 21:11:00+03	154300.00
DA7103	2017-07-20 08:25:00+03	24300.00
DA7124	2017-07-03 06:12:00+03	89600.00
DA713B	2017-08-10 05:51:00+03	30800.00
DA714B	2017-07-16 00:57:00+03	131900.00
DA71D0	2017-07-30 01:15:00+03	15000.00
DA71F4	2017-07-21 11:22:00+03	46000.00
DA72BC	2017-07-04 03:23:00+03	31200.00
DA72F2	2017-07-20 06:23:00+03	114800.00
DA7350	2017-07-30 16:18:00+03	69600.00
DA7368	2017-07-23 14:41:00+03	49800.00
DA73D5	2017-07-06 22:13:00+03	6000.00
DA73E6	2017-08-13 04:50:00+03	15000.00
DA73F0	2017-07-31 00:47:00+03	27200.00
DA7446	2017-07-26 13:40:00+03	26000.00
DA7478	2017-08-01 06:16:00+03	14000.00
DA74CD	2017-07-23 18:21:00+03	43000.00
DA74D1	2017-07-31 13:37:00+03	15000.00
DA74F7	2017-08-12 19:32:00+03	26700.00
DA7542	2017-07-22 05:16:00+03	47200.00
DA7561	2017-07-24 19:01:00+03	20200.00
DA7579	2017-08-11 14:09:00+03	133200.00
DA757D	2017-07-23 11:24:00+03	56600.00
DA7599	2017-08-07 12:45:00+03	136200.00
DA75BF	2017-06-29 17:23:00+03	27000.00
DA75F1	2017-07-13 11:46:00+03	21800.00
DA7648	2017-08-15 05:34:00+03	94000.00
DA7656	2017-08-05 10:22:00+03	39800.00
DA7660	2017-08-12 03:40:00+03	169800.00
DA7661	2017-08-03 15:25:00+03	12400.00
DA7680	2017-07-30 12:20:00+03	28800.00
DA76C3	2017-07-22 21:36:00+03	120900.00
DA76C4	2017-08-13 05:17:00+03	22000.00
DA779F	2017-07-10 19:26:00+03	12400.00
DA77F2	2017-07-10 19:33:00+03	56000.00
DA792A	2017-07-23 00:41:00+03	86300.00
DA798E	2017-07-20 07:25:00+03	19600.00
DA7ACA	2017-08-14 12:29:00+03	60800.00
DA7B15	2017-08-02 22:39:00+03	38800.00
DA7B3B	2017-07-26 00:37:00+03	190200.00
DA7B40	2017-08-02 15:50:00+03	28800.00
DA7B7C	2017-07-16 01:35:00+03	44600.00
DA7BA4	2017-07-27 08:09:00+03	37200.00
DA7C29	2017-07-11 16:35:00+03	33300.00
DA7C44	2017-07-06 12:29:00+03	15000.00
DA7CB1	2017-08-08 02:32:00+03	126700.00
DA7CCD	2017-07-09 09:08:00+03	118600.00
DA7CD9	2017-07-14 23:41:00+03	6000.00
DA7D75	2017-07-14 17:22:00+03	67800.00
DA7E16	2017-08-07 15:29:00+03	93700.00
DA7E1E	2017-07-08 05:44:00+03	106800.00
DA7E2A	2017-08-14 09:27:00+03	25800.00
DA7E74	2017-06-29 16:23:00+03	23500.00
DA7FD8	2017-07-21 18:12:00+03	169900.00
DA7FF6	2017-07-14 14:20:00+03	48800.00
DA80BB	2017-08-05 03:06:00+03	103200.00
DA80C5	2017-07-21 11:42:00+03	20000.00
DA8235	2017-08-02 15:01:00+03	32700.00
DA82A2	2017-08-02 14:54:00+03	24400.00
DA835F	2017-07-15 16:31:00+03	24800.00
DA838B	2017-08-01 03:53:00+03	14000.00
DA842A	2017-07-21 15:36:00+03	28000.00
DA844D	2017-07-18 07:42:00+03	30700.00
DA8467	2017-08-02 13:20:00+03	24400.00
DA8468	2017-07-25 11:47:00+03	25400.00
DA8477	2017-08-14 05:38:00+03	8200.00
DA8564	2017-08-06 17:21:00+03	46300.00
DA85C9	2017-08-09 11:50:00+03	67200.00
DA85FC	2017-08-09 10:32:00+03	6600.00
DA8661	2017-07-22 14:22:00+03	46300.00
DA867D	2017-08-13 16:36:00+03	21800.00
DA86BA	2017-07-04 23:58:00+03	16800.00
DA86ED	2017-07-05 18:27:00+03	135400.00
DA871F	2017-07-11 00:08:00+03	102800.00
DA8758	2017-07-22 16:59:00+03	30900.00
DA8773	2017-07-30 09:43:00+03	41900.00
DA8787	2017-07-31 06:22:00+03	97900.00
DA87A0	2017-07-28 22:32:00+03	55800.00
DA87CF	2017-07-29 03:46:00+03	7400.00
DA87FB	2017-07-04 05:10:00+03	32800.00
DA8807	2017-07-11 20:51:00+03	85000.00
DA887F	2017-07-18 20:33:00+03	70700.00
DA8888	2017-07-18 20:41:00+03	46700.00
DA88AB	2017-08-13 14:12:00+03	13600.00
DA88B0	2017-08-11 11:04:00+03	149200.00
DA8911	2017-07-24 15:21:00+03	28000.00
DA8956	2017-08-03 14:39:00+03	23200.00
DA897F	2017-07-19 11:51:00+03	182000.00
DA89A9	2017-07-30 09:34:00+03	134700.00
DA89BA	2017-07-22 20:08:00+03	89700.00
DA8A6E	2017-07-14 23:19:00+03	37700.00
DA8AD3	2017-08-12 10:57:00+03	25100.00
DA8AF7	2017-07-27 21:14:00+03	47200.00
DA8B1A	2017-07-14 10:31:00+03	100200.00
DA8CB4	2017-07-31 11:59:00+03	265700.00
DA8CCA	2017-07-06 06:26:00+03	21800.00
DA8D2F	2017-07-02 21:54:00+03	16400.00
DA8DC6	2017-08-01 07:06:00+03	51200.00
DA8DDA	2017-08-07 19:26:00+03	39800.00
DA8E4F	2017-07-23 18:52:00+03	10600.00
DA8EE1	2017-08-09 05:39:00+03	61800.00
DA8F06	2017-07-15 21:52:00+03	14400.00
DA8F09	2017-08-03 13:45:00+03	168200.00
DA8F48	2017-07-04 22:44:00+03	78600.00
DA8F63	2017-07-23 12:40:00+03	199700.00
DA8FBF	2017-07-30 16:53:00+03	44000.00
DA8FCC	2017-07-13 09:12:00+03	56000.00
DA8FD5	2017-07-27 20:20:00+03	49600.00
DA8FF5	2017-08-06 07:41:00+03	114800.00
DA9005	2017-08-11 19:29:00+03	103500.00
DA9015	2017-07-06 06:06:00+03	58400.00
DA903E	2017-07-01 09:29:00+03	60600.00
DA9055	2017-07-16 01:32:00+03	19600.00
DA9078	2017-07-02 20:45:00+03	65900.00
DA9120	2017-08-14 05:43:00+03	64700.00
DA915F	2017-06-30 19:26:00+03	89600.00
DA91B2	2017-08-10 04:25:00+03	33600.00
DA91D1	2017-06-30 05:05:00+03	112000.00
DA9230	2017-07-16 17:42:00+03	24400.00
DA92B8	2017-07-30 22:14:00+03	69400.00
DA92C6	2017-08-08 00:26:00+03	64600.00
DA92E4	2017-08-10 14:37:00+03	39200.00
DA935F	2017-07-31 18:13:00+03	12600.00
DA93AB	2017-07-16 19:50:00+03	58200.00
DA93BC	2017-08-10 22:20:00+03	41300.00
DA944F	2017-07-05 13:14:00+03	72300.00
DA9472	2017-07-25 14:53:00+03	46500.00
DA9483	2017-07-25 06:30:00+03	20700.00
DA949F	2017-07-21 20:41:00+03	31900.00
DA94BA	2017-08-04 01:41:00+03	56600.00
DA94EB	2017-07-03 02:03:00+03	46000.00
DA9535	2017-07-29 23:28:00+03	56000.00
DA95C3	2017-07-07 06:45:00+03	27200.00
DA9614	2017-07-14 13:27:00+03	35200.00
DA961B	2017-08-13 08:40:00+03	73600.00
DA968F	2017-07-01 08:09:00+03	93000.00
DA9709	2017-07-24 08:34:00+03	59200.00
DA970B	2017-07-04 19:49:00+03	22000.00
DA974A	2017-07-05 11:10:00+03	47100.00
DA98FB	2017-08-09 11:35:00+03	542300.00
DA9961	2017-07-03 16:32:00+03	47500.00
DA9997	2017-08-04 07:56:00+03	11200.00
DA9999	2017-08-12 05:57:00+03	92800.00
DA99C5	2017-07-25 00:17:00+03	93900.00
DA9A24	2017-08-06 04:10:00+03	65800.00
DA9ABB	2017-07-31 17:21:00+03	160700.00
DA9AE6	2017-07-03 14:49:00+03	114400.00
DA9B50	2017-07-21 02:09:00+03	51600.00
DA9BC4	2017-08-08 04:30:00+03	19800.00
DA9C30	2017-08-01 23:56:00+03	34000.00
DA9CB3	2017-07-13 08:19:00+03	67900.00
DA9D25	2017-08-09 18:01:00+03	45200.00
DA9D85	2017-08-11 23:15:00+03	94000.00
DA9DC6	2017-08-04 20:59:00+03	81300.00
DA9DF5	2017-07-15 21:12:00+03	49000.00
DA9E0F	2017-07-28 22:25:00+03	55800.00
DA9E21	2017-07-01 11:17:00+03	79600.00
DA9E46	2017-07-27 06:09:00+03	53600.00
DA9E59	2017-07-29 15:47:00+03	51800.00
DA9FAE	2017-07-05 22:11:00+03	100200.00
DA9FB2	2017-07-12 02:44:00+03	53000.00
DA9FD2	2017-08-10 06:38:00+03	86100.00
DA9FE1	2017-07-19 01:37:00+03	92800.00
DAA007	2017-08-07 05:11:00+03	35800.00
DAA040	2017-08-07 12:46:00+03	169300.00
DAA05F	2017-08-11 14:12:00+03	266400.00
DAA0C9	2017-08-09 15:48:00+03	14000.00
DAA135	2017-07-26 00:56:00+03	20200.00
DAA1AF	2017-07-17 07:01:00+03	47400.00
DAA1C5	2017-07-14 23:37:00+03	26000.00
DAA249	2017-08-13 09:56:00+03	23600.00
DAA266	2017-08-08 10:57:00+03	123600.00
DAA275	2017-07-24 00:51:00+03	8000.00
DAA318	2017-07-27 08:09:00+03	10600.00
DAA3F4	2017-08-04 06:34:00+03	170100.00
DAA423	2017-08-02 09:19:00+03	91600.00
DAA4A4	2017-08-15 17:16:00+03	18400.00
DAA4A7	2017-07-20 07:06:00+03	47100.00
DAA4A9	2017-07-29 10:35:00+03	92800.00
DAA531	2017-07-19 00:50:00+03	6000.00
DAA53E	2017-08-14 11:13:00+03	54400.00
DAA595	2017-08-03 10:55:00+03	47200.00
DAA599	2017-07-04 21:37:00+03	93500.00
DAA5AF	2017-07-04 18:07:00+03	25100.00
DAA5F5	2017-07-08 00:41:00+03	63300.00
DAA5FA	2017-07-05 23:25:00+03	199600.00
DAA643	2017-07-11 04:10:00+03	99200.00
DAA699	2017-07-12 20:00:00+03	123600.00
DAA6B0	2017-07-14 19:01:00+03	10600.00
DAA6C8	2017-07-19 23:00:00+03	125200.00
DAA807	2017-07-27 01:23:00+03	28800.00
DAA838	2017-07-13 04:46:00+03	46700.00
DAA83C	2017-07-18 17:59:00+03	98400.00
DAA857	2017-07-19 06:08:00+03	26600.00
DAA860	2017-08-07 19:34:00+03	150600.00
DAA897	2017-08-10 15:39:00+03	57300.00
DAA899	2017-07-22 01:04:00+03	135400.00
DAA89C	2017-07-16 03:02:00+03	81300.00
DAA9A7	2017-07-24 21:56:00+03	62600.00
DAA9EF	2017-07-24 18:41:00+03	76800.00
DAAA1B	2017-07-09 04:47:00+03	8000.00
DAAA27	2017-07-21 02:26:00+03	14400.00
DAAA82	2017-08-12 13:10:00+03	57500.00
DAAA87	2017-07-06 19:39:00+03	55600.00
DAAB9A	2017-07-05 15:14:00+03	22600.00
DAAC07	2017-08-04 14:42:00+03	21800.00
DAAC2E	2017-08-05 23:55:00+03	26000.00
DAAC54	2017-07-27 17:58:00+03	119500.00
DAAC68	2017-07-20 19:34:00+03	22200.00
DAAC8C	2017-07-11 10:19:00+03	32800.00
DAAD1B	2017-07-09 12:14:00+03	88900.00
DAAD27	2017-07-21 08:21:00+03	56000.00
DAAD6F	2017-07-27 08:22:00+03	246000.00
DAADC4	2017-07-29 04:57:00+03	80700.00
DAAE00	2017-07-05 22:22:00+03	56000.00
DAAE27	2017-07-23 02:22:00+03	232000.00
DAAE2D	2017-07-03 21:06:00+03	12000.00
DAAEA8	2017-07-22 19:32:00+03	86300.00
DAAEF1	2017-08-09 00:42:00+03	75700.00
DAAF5F	2017-08-01 16:57:00+03	36200.00
DAAFB2	2017-08-08 09:38:00+03	19600.00
DAAFC5	2017-08-11 15:42:00+03	16400.00
DAB005	2017-07-19 21:17:00+03	94100.00
DAB018	2017-07-07 15:35:00+03	144400.00
DAB026	2017-07-26 03:00:00+03	200600.00
DAB060	2017-07-17 03:36:00+03	66800.00
DAB078	2017-08-09 15:44:00+03	24800.00
DAB09A	2017-07-13 10:52:00+03	6000.00
DAB0A0	2017-08-11 10:29:00+03	136200.00
DAB0C4	2017-07-14 13:40:00+03	138100.00
DAB0FD	2017-07-27 00:29:00+03	48400.00
DAB11B	2017-07-28 19:19:00+03	57400.00
DAB188	2017-07-31 07:01:00+03	169000.00
DAB191	2017-08-07 05:29:00+03	28000.00
DAB1B3	2017-08-07 23:35:00+03	76100.00
DAB1C0	2017-07-31 06:37:00+03	26000.00
DAB1CF	2017-07-14 19:20:00+03	14900.00
DAB212	2017-08-04 08:46:00+03	103900.00
DAB25D	2017-07-11 08:41:00+03	48800.00
DAB299	2017-07-28 03:13:00+03	57400.00
DAB2B2	2017-08-15 08:04:00+03	273300.00
DAB2BB	2017-07-21 11:02:00+03	47400.00
DAB2C3	2017-08-15 00:25:00+03	28000.00
DAB2C7	2017-07-16 05:51:00+03	90600.00
DAB2D9	2017-08-06 05:12:00+03	67600.00
DAB343	2017-07-01 21:51:00+03	60400.00
DAB3D8	2017-06-29 16:48:00+03	26800.00
DAB403	2017-08-13 19:24:00+03	16400.00
DAB438	2017-08-07 21:40:00+03	60800.00
DAB49C	2017-08-06 13:46:00+03	67700.00
DAB502	2017-07-19 00:11:00+03	115600.00
DAB52D	2017-07-12 12:09:00+03	95200.00
DAB5E4	2017-07-22 08:46:00+03	291000.00
DAB606	2017-08-09 09:14:00+03	6700.00
DAB60B	2017-07-10 03:15:00+03	223700.00
DAB610	2017-06-30 15:38:00+03	26600.00
DAB659	2017-08-14 03:20:00+03	31600.00
DAB6AD	2017-07-12 19:07:00+03	57600.00
DAB702	2017-07-20 09:41:00+03	68800.00
DAB75B	2017-06-29 10:33:00+03	36000.00
DAB798	2017-08-07 10:15:00+03	102800.00
DAB809	2017-07-06 12:50:00+03	215500.00
DAB8E9	2017-06-28 03:15:00+03	33600.00
DAB8EF	2017-08-11 11:26:00+03	23400.00
DAB8FF	2017-07-06 21:07:00+03	123000.00
DAB97D	2017-07-30 18:55:00+03	111600.00
DAB9B0	2017-08-05 22:14:00+03	159000.00
DAB9DB	2017-07-21 15:51:00+03	54800.00
DABA7E	2017-08-05 04:43:00+03	42400.00
DABADF	2017-07-07 10:13:00+03	40600.00
DABAE7	2017-08-13 16:25:00+03	23600.00
DABB13	2017-08-07 08:49:00+03	24400.00
DABB15	2017-08-12 18:07:00+03	20600.00
DABB84	2017-07-30 15:08:00+03	42000.00
DABB8F	2017-07-22 06:01:00+03	92800.00
DABB9A	2017-07-04 11:01:00+03	118600.00
DABBC0	2017-07-02 05:41:00+03	19600.00
DABBE4	2017-07-28 06:28:00+03	25600.00
DABC12	2017-07-12 19:30:00+03	273400.00
DABC44	2017-07-12 05:07:00+03	233700.00
DABC85	2017-07-25 18:17:00+03	71600.00
DABC89	2017-08-12 18:20:00+03	24800.00
DABCAB	2017-07-07 10:36:00+03	15400.00
DABCAE	2017-07-04 12:06:00+03	55800.00
DABCB9	2017-08-07 21:55:00+03	37900.00
DABCCE	2017-08-02 03:51:00+03	315000.00
DABD04	2017-07-25 13:20:00+03	157100.00
DABD06	2017-07-15 09:43:00+03	24000.00
DABD2A	2017-07-27 13:26:00+03	50600.00
DABD99	2017-07-11 02:06:00+03	67200.00
DABE4D	2017-07-31 09:53:00+03	42400.00
DABE57	2017-08-01 12:38:00+03	47000.00
DABEEF	2017-07-25 16:22:00+03	23600.00
DABF00	2017-08-05 12:35:00+03	49100.00
DABF25	2017-07-13 19:02:00+03	265700.00
DABF75	2017-07-16 19:42:00+03	89700.00
DABF98	2017-08-13 12:55:00+03	128800.00
DABFBA	2017-07-26 07:01:00+03	52000.00
DAC024	2017-07-07 00:23:00+03	67400.00
DAC030	2017-07-02 11:29:00+03	156500.00
DAC071	2017-06-28 12:15:00+03	75600.00
DAC0D7	2017-08-06 16:57:00+03	123000.00
DAC10A	2017-07-11 11:13:00+03	14400.00
DAC13A	2017-07-25 09:08:00+03	47200.00
DAC1A9	2017-08-11 09:24:00+03	23200.00
DAC25E	2017-07-21 03:47:00+03	531400.00
DAC27F	2017-07-24 16:55:00+03	21400.00
DAC294	2017-08-11 09:04:00+03	205600.00
DAC2AA	2017-07-21 19:20:00+03	102100.00
DAC2E0	2017-08-15 11:41:00+03	48400.00
DAC2E3	2017-07-06 01:44:00+03	84200.00
DAC2EB	2017-07-03 06:37:00+03	39800.00
DAC2F7	2017-07-26 13:07:00+03	14400.00
DAC366	2017-07-26 18:09:00+03	33000.00
DAC389	2017-08-14 17:19:00+03	14000.00
DAC3B3	2017-07-20 21:29:00+03	73500.00
DAC40E	2017-07-11 21:01:00+03	27200.00
DAC46F	2017-07-14 16:44:00+03	46900.00
DAC4E8	2017-07-15 17:46:00+03	27300.00
DAC505	2017-07-06 03:52:00+03	23600.00
DAC572	2017-07-02 13:03:00+03	98400.00
DAC615	2017-07-18 20:58:00+03	56000.00
DAC64D	2017-07-03 16:16:00+03	12400.00
DAC715	2017-07-18 14:08:00+03	38400.00
DAC742	2017-08-11 05:04:00+03	26600.00
DAC79A	2017-07-24 13:37:00+03	36200.00
DAC7D8	2017-08-04 23:06:00+03	32200.00
DAC842	2017-07-10 23:08:00+03	79800.00
DAC86B	2017-07-04 02:22:00+03	24800.00
DAC8BA	2017-08-04 18:57:00+03	29600.00
DAC8E0	2017-07-07 09:03:00+03	6000.00
DAC907	2017-07-18 10:12:00+03	28000.00
DAC91E	2017-07-09 09:24:00+03	28000.00
DAC9A5	2017-07-15 09:46:00+03	410200.00
DAC9AE	2017-07-06 23:25:00+03	28000.00
DAC9C8	2017-08-04 13:53:00+03	184000.00
DAC9D1	2017-08-03 00:14:00+03	16400.00
DACA58	2017-07-14 04:50:00+03	56900.00
DACAE7	2017-07-10 18:09:00+03	46400.00
DACB3F	2017-07-30 09:16:00+03	73300.00
DACB8C	2017-08-13 22:54:00+03	57400.00
DACB90	2017-07-24 22:42:00+03	28000.00
DACB9D	2017-07-06 00:54:00+03	56600.00
DACC09	2017-08-14 04:39:00+03	24300.00
DACC10	2017-08-13 13:33:00+03	86800.00
DACC14	2017-07-08 17:38:00+03	52000.00
DACC5D	2017-08-14 15:38:00+03	117600.00
DACC84	2017-08-13 18:34:00+03	68800.00
DACCD1	2017-07-04 04:36:00+03	8200.00
DACCFC	2017-07-13 15:01:00+03	71500.00
DACD30	2017-08-14 00:30:00+03	249200.00
DACD8E	2017-06-28 11:55:00+03	170000.00
DACD99	2017-07-20 01:01:00+03	93500.00
DACDC7	2017-08-02 02:59:00+03	101100.00
DACDF3	2017-07-20 13:42:00+03	97100.00
DACDF6	2017-07-21 17:38:00+03	34000.00
DACE7B	2017-07-29 07:21:00+03	42700.00
DACE9D	2017-07-11 03:04:00+03	145300.00
DACF6D	2017-08-15 10:42:00+03	95500.00
DACF78	2017-08-06 10:17:00+03	131600.00
DACF9F	2017-07-04 20:04:00+03	11600.00
DACFFD	2017-07-22 06:26:00+03	76100.00
DAD013	2017-07-08 22:59:00+03	13600.00
DAD031	2017-08-11 17:42:00+03	60400.00
DAD037	2017-08-13 01:25:00+03	58600.00
DAD071	2017-08-08 12:59:00+03	14400.00
DAD0FB	2017-08-03 05:02:00+03	270200.00
DAD101	2017-08-07 22:22:00+03	65900.00
DAD112	2017-07-22 16:52:00+03	40000.00
DAD12A	2017-06-29 18:14:00+03	136700.00
DAD1C4	2017-07-14 17:35:00+03	149500.00
DAD1FA	2017-07-01 06:29:00+03	46400.00
DAD204	2017-08-15 15:16:00+03	24000.00
DAD21F	2017-07-02 11:07:00+03	15800.00
DAD230	2017-07-08 09:10:00+03	283100.00
DAD23E	2017-07-26 21:17:00+03	102100.00
DAD245	2017-08-14 12:12:00+03	73300.00
DAD268	2017-07-21 05:08:00+03	24700.00
DAD2F5	2017-07-27 20:47:00+03	29400.00
DAD2FF	2017-07-14 19:11:00+03	36800.00
DAD349	2017-07-11 00:13:00+03	28000.00
DAD35D	2017-08-12 22:03:00+03	33300.00
DAD368	2017-07-02 09:01:00+03	50000.00
DAD3C5	2017-07-17 10:44:00+03	282300.00
DAD3E8	2017-08-12 06:04:00+03	113100.00
DAD3EA	2017-07-13 04:37:00+03	24400.00
DAD44C	2017-07-05 04:45:00+03	85000.00
DAD4DA	2017-07-13 05:02:00+03	84100.00
DAD4EF	2017-07-04 15:36:00+03	40800.00
DAD56F	2017-07-08 14:06:00+03	100000.00
DAD5AB	2017-07-20 14:48:00+03	258400.00
DAD5AC	2017-07-04 14:00:00+03	96400.00
DAD64D	2017-07-25 00:21:00+03	191200.00
DAD6BD	2017-07-12 17:58:00+03	6000.00
DAD6D9	2017-07-03 03:49:00+03	84100.00
DAD759	2017-07-26 09:05:00+03	136200.00
DAD75B	2017-08-14 21:39:00+03	102100.00
DAD790	2017-08-11 04:57:00+03	69900.00
DAD7A0	2017-07-29 23:39:00+03	54000.00
DAD7D3	2017-07-14 19:20:00+03	22000.00
DAD807	2017-07-19 22:33:00+03	50600.00
DAD822	2017-08-12 21:08:00+03	12600.00
DAD837	2017-07-13 16:12:00+03	37900.00
DAD8C4	2017-07-28 17:37:00+03	39400.00
DAD8D0	2017-07-03 05:39:00+03	55800.00
DAD8FD	2017-07-16 05:44:00+03	56600.00
DAD90C	2017-07-04 00:13:00+03	339900.00
DAD914	2017-07-04 00:18:00+03	246000.00
DAD970	2017-07-15 19:04:00+03	258400.00
DAD976	2017-07-12 04:37:00+03	24400.00
DAD9C4	2017-07-31 04:21:00+03	57500.00
DAD9C6	2017-07-11 20:39:00+03	27400.00
DAD9CC	2017-08-03 07:36:00+03	29600.00
DADA4A	2017-07-09 18:16:00+03	162300.00
DADA51	2017-07-31 14:38:00+03	31800.00
DADA71	2017-07-28 08:20:00+03	27300.00
DADA7E	2017-08-13 14:51:00+03	87000.00
DADA8E	2017-07-24 07:25:00+03	56000.00
DADAAE	2017-07-28 02:03:00+03	128400.00
DADBA9	2017-08-04 09:47:00+03	54300.00
DADBB3	2017-07-24 17:48:00+03	55500.00
DADC3F	2017-08-09 23:28:00+03	32300.00
DADC78	2017-08-03 10:29:00+03	58600.00
DADC7D	2017-07-09 23:11:00+03	135400.00
DADCBA	2017-07-26 09:56:00+03	12000.00
DADD76	2017-08-01 08:46:00+03	110500.00
DADD9A	2017-07-05 13:57:00+03	48800.00
DADDDD	2017-08-04 16:35:00+03	42800.00
DADE3E	2017-07-05 19:12:00+03	73400.00
DADEC3	2017-08-12 11:41:00+03	7200.00
DADEEC	2017-07-25 08:15:00+03	19800.00
DADEF3	2017-07-20 05:37:00+03	86300.00
DADF52	2017-08-02 21:54:00+03	207700.00
DADF85	2017-07-15 01:24:00+03	16400.00
DAE03F	2017-07-16 01:25:00+03	55400.00
DAE06C	2017-08-06 08:36:00+03	87000.00
DAE07B	2017-07-24 17:00:00+03	23500.00
DAE0C6	2017-07-06 23:36:00+03	26000.00
DAE0E1	2017-07-01 03:47:00+03	14400.00
DAE239	2017-08-04 12:33:00+03	14400.00
DAE2B6	2017-08-03 20:42:00+03	139800.00
DAE478	2017-07-21 21:18:00+03	117600.00
DAE560	2017-07-14 22:33:00+03	73600.00
DAE56E	2017-07-16 11:35:00+03	42700.00
DAE5A3	2017-07-29 03:00:00+03	549100.00
DAE5E2	2017-08-02 16:15:00+03	56000.00
DAE60E	2017-08-05 04:47:00+03	36000.00
DAE635	2017-08-02 10:30:00+03	50400.00
DAE652	2017-07-06 10:36:00+03	68800.00
DAE654	2017-08-06 03:31:00+03	20200.00
DAE6A9	2017-08-08 15:54:00+03	54300.00
DAE6C8	2017-08-09 13:41:00+03	40800.00
DAE6DF	2017-07-13 15:14:00+03	53600.00
DAE727	2017-06-27 08:00:00+03	64400.00
DAE7AB	2017-07-13 15:30:00+03	68400.00
DAE7DE	2017-07-03 04:02:00+03	398500.00
DAE7E0	2017-07-04 08:50:00+03	38400.00
DAE8DA	2017-08-11 02:36:00+03	30000.00
DAE8F5	2017-07-15 05:55:00+03	135400.00
DAE955	2017-08-09 05:39:00+03	35200.00
DAEA54	2017-08-03 06:34:00+03	45600.00
DAEB49	2017-07-18 20:21:00+03	58400.00
DAEB79	2017-08-08 15:09:00+03	51600.00
DAEB8F	2017-07-24 17:03:00+03	6700.00
DAEBEE	2017-06-30 02:01:00+03	139400.00
DAEC04	2017-07-06 11:16:00+03	113700.00
DAEC5C	2017-07-19 08:28:00+03	63400.00
DAEC75	2017-07-03 22:34:00+03	11600.00
DAECCD	2017-07-20 07:12:00+03	45100.00
DAED06	2017-08-12 12:44:00+03	28600.00
DAED27	2017-07-03 16:27:00+03	36900.00
DAED6E	2017-08-10 20:04:00+03	133100.00
DAEDA2	2017-07-03 04:47:00+03	59800.00
DAEE7A	2017-07-09 00:31:00+03	55800.00
DAEEC3	2017-08-02 22:32:00+03	92900.00
DAEF16	2017-08-08 09:30:00+03	56900.00
DAEF2C	2017-07-31 18:42:00+03	140800.00
DAEF70	2017-07-28 22:32:00+03	10800.00
DAEF86	2017-07-25 07:39:00+03	59800.00
DAEF90	2017-07-14 08:44:00+03	25600.00
DAF038	2017-07-16 14:35:00+03	39800.00
DAF04D	2017-07-23 09:15:00+03	50400.00
DAF172	2017-07-26 21:32:00+03	24200.00
DAF1A2	2017-07-05 13:23:00+03	92600.00
DAF1E9	2017-07-02 19:04:00+03	50400.00
DAF225	2017-07-21 08:07:00+03	42900.00
DAF25E	2017-07-23 02:09:00+03	62000.00
DAF293	2017-07-30 07:42:00+03	44500.00
DAF2E8	2017-07-14 07:34:00+03	23200.00
DAF30E	2017-07-15 23:56:00+03	12600.00
DAF349	2017-07-03 13:10:00+03	70600.00
DAF358	2017-07-29 20:14:00+03	32200.00
DAF37E	2017-07-25 19:53:00+03	88500.00
DAF3B7	2017-07-13 03:47:00+03	135400.00
DAF421	2017-07-20 12:08:00+03	58800.00
DAF464	2017-07-23 09:04:00+03	27800.00
DAF4A7	2017-07-07 09:14:00+03	135600.00
DAF4F9	2017-07-05 22:56:00+03	39200.00
DAF528	2017-07-23 14:48:00+03	53600.00
DAF5B3	2017-07-22 16:22:00+03	20000.00
DAF639	2017-07-15 19:25:00+03	70600.00
DAF66E	2017-07-21 05:20:00+03	69500.00
DAF6B2	2017-07-27 03:58:00+03	134600.00
DAF731	2017-07-04 22:20:00+03	142000.00
DAF744	2017-07-22 20:41:00+03	51600.00
DAF792	2017-07-25 22:19:00+03	577200.00
DAF79E	2017-07-18 17:19:00+03	68800.00
DAF7EC	2017-07-04 22:28:00+03	105000.00
DAF805	2017-07-22 13:37:00+03	62800.00
DAF815	2017-07-31 02:13:00+03	83000.00
DAF81C	2017-07-05 16:31:00+03	284700.00
DAF8AD	2017-07-11 12:14:00+03	68400.00
DAF910	2017-07-21 02:02:00+03	111900.00
DAF96B	2017-06-27 16:46:00+03	48800.00
DAFA4A	2017-08-03 03:35:00+03	44600.00
DAFA4B	2017-07-18 02:32:00+03	42800.00
DAFA72	2017-07-28 22:13:00+03	12400.00
DAFA8D	2017-08-15 14:00:00+03	8200.00
DAFAC8	2017-07-19 06:55:00+03	169900.00
DAFAD9	2017-07-07 22:45:00+03	27900.00
DAFAF3	2017-07-07 14:25:00+03	138500.00
DAFB0D	2017-07-19 05:03:00+03	98400.00
DAFBC8	2017-08-13 04:28:00+03	86600.00
DAFBEA	2017-07-22 13:15:00+03	200500.00
DAFC27	2017-08-02 15:08:00+03	73600.00
DAFC2A	2017-07-19 09:01:00+03	138000.00
DAFC72	2017-07-07 20:33:00+03	503000.00
DAFC81	2017-08-08 21:06:00+03	18600.00
DAFD58	2017-07-23 20:50:00+03	6300.00
DAFD5A	2017-08-01 15:20:00+03	53300.00
DAFD63	2017-08-15 04:50:00+03	31200.00
DAFD7E	2017-07-30 00:14:00+03	21800.00
DAFDB9	2017-07-25 20:09:00+03	58000.00
DAFDE4	2017-07-09 17:03:00+03	112000.00
DAFDFF	2017-07-10 23:30:00+03	33800.00
DAFE1E	2017-08-07 23:27:00+03	18400.00
DAFE27	2017-08-10 18:14:00+03	23600.00
DAFEAC	2017-08-07 11:36:00+03	68800.00
DAFF4A	2017-07-24 11:09:00+03	25200.00
DAFF60	2017-07-30 13:41:00+03	142800.00
DAFFB1	2017-08-07 20:56:00+03	23600.00
DAFFB4	2017-08-15 11:53:00+03	28800.00
DAFFD3	2017-07-08 06:37:00+03	48200.00
DAFFDD	2017-07-03 22:59:00+03	43200.00
DAFFE0	2017-07-26 03:10:00+03	46000.00
DB0004	2017-08-12 18:00:00+03	88600.00
DB00AE	2017-08-02 13:59:00+03	99300.00
DB00B8	2017-07-29 07:45:00+03	84400.00
DB00B9	2017-07-14 13:10:00+03	27200.00
DB00BA	2017-07-22 03:16:00+03	29200.00
DB00C0	2017-07-24 14:15:00+03	146800.00
DB00F7	2017-07-23 17:39:00+03	56000.00
DB013C	2017-07-03 05:01:00+03	46400.00
DB0154	2017-08-09 15:57:00+03	61800.00
DB016A	2017-08-14 12:40:00+03	56000.00
DB0183	2017-08-04 23:51:00+03	90400.00
DB01E6	2017-07-03 01:47:00+03	28000.00
DB01EF	2017-07-22 19:04:00+03	58600.00
DB0204	2017-07-22 16:34:00+03	40100.00
DB021A	2017-08-04 12:45:00+03	23200.00
DB022A	2017-07-03 18:55:00+03	23200.00
DB0245	2017-08-01 22:18:00+03	67200.00
DB0261	2017-07-31 14:58:00+03	51900.00
DB0263	2017-07-07 03:53:00+03	85000.00
DB0297	2017-08-04 19:13:00+03	136600.00
DB02C3	2017-07-24 13:01:00+03	73500.00
DB0309	2017-07-08 18:32:00+03	52300.00
DB0319	2017-07-19 09:52:00+03	141600.00
DB0380	2017-07-11 13:53:00+03	41600.00
DB03AB	2017-07-31 11:50:00+03	23200.00
DB03AC	2017-07-16 22:16:00+03	49100.00
DB0450	2017-07-24 04:29:00+03	115800.00
DB04D7	2017-07-04 04:53:00+03	85000.00
DB04EF	2017-07-19 18:55:00+03	170200.00
DB04FA	2017-07-11 20:04:00+03	54500.00
DB051E	2017-08-07 00:50:00+03	6000.00
DB0537	2017-08-08 13:40:00+03	28800.00
DB0547	2017-07-25 01:33:00+03	67900.00
DB0564	2017-07-22 10:47:00+03	85600.00
DB056B	2017-07-02 22:30:00+03	130100.00
DB0587	2017-08-02 03:29:00+03	56000.00
DB0598	2017-08-10 12:06:00+03	117900.00
DB05AC	2017-08-10 21:14:00+03	12000.00
DB05CF	2017-07-10 02:54:00+03	46500.00
DB05E1	2017-08-14 06:34:00+03	39800.00
DB0619	2017-07-11 19:37:00+03	18600.00
DB0683	2017-08-15 17:29:00+03	53400.00
DB06B3	2017-07-14 04:56:00+03	112000.00
DB06B8	2017-06-30 22:10:00+03	28000.00
DB06E7	2017-08-12 23:39:00+03	24000.00
DB076B	2017-07-16 23:48:00+03	22400.00
DB080F	2017-07-15 11:13:00+03	31200.00
DB0833	2017-06-27 14:53:00+03	61900.00
DB085C	2017-08-12 11:40:00+03	63700.00
DB086A	2017-07-08 22:20:00+03	94800.00
DB08A4	2017-07-03 10:57:00+03	229400.00
DB08AA	2017-08-15 11:20:00+03	32900.00
DB08AB	2017-07-14 03:48:00+03	193700.00
DB0900	2017-08-14 06:55:00+03	13200.00
DB09CB	2017-08-10 13:02:00+03	40800.00
DB0A07	2017-07-05 15:45:00+03	28000.00
DB0A4E	2017-08-13 15:50:00+03	64700.00
DB0A94	2017-06-30 09:24:00+03	133200.00
DB0AB1	2017-07-25 05:48:00+03	12400.00
DB0AB8	2017-07-26 03:24:00+03	12600.00
DB0AD5	2017-08-13 05:34:00+03	28800.00
DB0AFB	2017-07-23 07:11:00+03	96200.00
DB0B1D	2017-08-15 03:08:00+03	137700.00
DB0B5E	2017-07-05 05:18:00+03	56600.00
DB0BC1	2017-07-30 21:51:00+03	16400.00
DB0C95	2017-07-05 05:45:00+03	108900.00
DB0CF8	2017-08-10 06:36:00+03	46200.00
DB0DD4	2017-07-23 04:26:00+03	46400.00
DB0E2F	2017-07-09 12:45:00+03	81600.00
DB0EBB	2017-06-30 15:24:00+03	29600.00
DB0EF2	2017-07-03 09:25:00+03	69500.00
DB0EF7	2017-07-31 22:38:00+03	28700.00
DB0F78	2017-07-09 12:09:00+03	56000.00
DB0F8F	2017-08-06 03:14:00+03	272900.00
DB0FE1	2017-07-01 03:46:00+03	108100.00
DB100E	2017-07-06 07:55:00+03	52800.00
DB102E	2017-07-04 13:17:00+03	83600.00
DB1035	2017-07-19 15:50:00+03	64700.00
DB10CC	2017-08-11 22:25:00+03	58900.00
DB10F1	2017-07-06 15:46:00+03	185700.00
DB114C	2017-08-07 21:29:00+03	23600.00
DB1192	2017-07-13 09:52:00+03	84000.00
DB1197	2017-08-10 05:43:00+03	85000.00
DB121D	2017-08-02 15:10:00+03	181600.00
DB12AE	2017-07-10 11:47:00+03	40800.00
DB12C6	2017-07-01 08:41:00+03	56000.00
DB12D6	2017-07-11 12:09:00+03	55800.00
DB137D	2017-08-14 17:22:00+03	86300.00
DB13D6	2017-08-01 22:36:00+03	20800.00
DB14E9	2017-08-05 05:25:00+03	68800.00
DB14F7	2017-07-05 18:55:00+03	28300.00
DB1591	2017-07-26 00:14:00+03	55800.00
DB15E8	2017-07-25 20:32:00+03	18600.00
DB1611	2017-07-14 22:59:00+03	51600.00
DB1685	2017-07-14 21:45:00+03	21000.00
DB16D9	2017-07-10 09:44:00+03	48400.00
DB16F6	2017-07-25 14:32:00+03	131600.00
DB1718	2017-08-08 00:41:00+03	313200.00
DB1726	2017-07-26 06:53:00+03	158500.00
DB1754	2017-08-13 14:12:00+03	42700.00
DB1766	2017-08-02 22:11:00+03	48800.00
DB17AA	2017-07-01 06:20:00+03	56100.00
DB17DB	2017-07-17 17:45:00+03	48500.00
DB183B	2017-07-30 09:31:00+03	89700.00
DB18AD	2017-07-24 13:22:00+03	14400.00
DB18B6	2017-08-13 05:30:00+03	34000.00
DB18BA	2017-07-04 08:24:00+03	6000.00
DB18D3	2017-07-02 12:00:00+03	105100.00
DB197B	2017-07-13 17:19:00+03	69500.00
DB19E5	2017-08-01 03:26:00+03	21500.00
DB1A38	2017-08-08 09:00:00+03	54300.00
DB1A6C	2017-07-16 11:44:00+03	138500.00
DB1ADC	2017-07-25 14:14:00+03	136000.00
DB1B30	2017-07-18 04:45:00+03	117600.00
DB1B3B	2017-07-24 12:11:00+03	192700.00
DB1B45	2017-08-13 22:43:00+03	168000.00
DB1B58	2017-07-20 00:35:00+03	14000.00
DB1BC9	2017-07-22 14:51:00+03	139300.00
DB1BEA	2017-07-13 02:31:00+03	38400.00
DB1C2C	2017-08-04 04:34:00+03	12400.00
DB1C33	2017-07-23 23:35:00+03	12600.00
DB1C86	2017-07-11 06:09:00+03	119500.00
DB1C9B	2017-08-08 10:23:00+03	67000.00
DB1D12	2017-07-23 21:32:00+03	18600.00
DB1D30	2017-07-03 23:28:00+03	103200.00
DB1D3D	2017-08-01 12:01:00+03	115700.00
DB1D63	2017-07-12 07:11:00+03	75300.00
DB1E17	2017-07-19 08:27:00+03	46400.00
DB1E47	2017-07-25 20:49:00+03	332900.00
DB1E96	2017-08-12 20:14:00+03	66600.00
DB1EA2	2017-08-08 18:13:00+03	106400.00
DB1EA4	2017-07-27 15:54:00+03	98200.00
DB1EBE	2017-07-25 23:52:00+03	140300.00
DB1EC9	2017-07-22 19:23:00+03	358600.00
DB1ED1	2017-06-27 20:43:00+03	53600.00
DB1F62	2017-07-12 14:26:00+03	38600.00
DB1FD0	2017-07-18 23:22:00+03	43600.00
DB204D	2017-07-27 16:32:00+03	65500.00
DB2077	2017-08-05 23:48:00+03	28000.00
DB2105	2017-08-11 03:53:00+03	112300.00
DB2127	2017-08-09 19:06:00+03	199700.00
DB2159	2017-08-04 20:52:00+03	51900.00
DB2184	2017-08-10 15:25:00+03	55600.00
DB21C4	2017-08-13 17:04:00+03	199700.00
DB21C8	2017-08-09 01:26:00+03	16400.00
DB21DC	2017-07-12 08:56:00+03	26700.00
DB2204	2017-07-02 10:51:00+03	55800.00
DB2206	2017-06-27 00:01:00+03	26000.00
DB2263	2017-08-14 04:39:00+03	40400.00
DB2285	2017-07-14 05:12:00+03	67000.00
DB2291	2017-07-17 08:36:00+03	58400.00
DB22BD	2017-08-05 02:57:00+03	107800.00
DB22CA	2017-07-26 07:35:00+03	23600.00
DB22E2	2017-08-11 07:45:00+03	31400.00
DB23C2	2017-07-18 18:48:00+03	108000.00
DB23D8	2017-07-28 19:33:00+03	91200.00
DB23D9	2017-08-15 03:30:00+03	95900.00
DB2456	2017-07-31 09:52:00+03	76600.00
DB24A4	2017-08-01 12:41:00+03	38800.00
DB2537	2017-08-14 12:28:00+03	26700.00
DB25F2	2017-07-03 02:27:00+03	92500.00
DB26E7	2017-07-01 08:36:00+03	124200.00
DB2776	2017-07-27 22:12:00+03	25000.00
DB2794	2017-08-06 00:56:00+03	32400.00
DB27F3	2017-08-06 23:16:00+03	113300.00
DB2861	2017-08-10 11:57:00+03	98400.00
DB28AC	2017-07-03 03:26:00+03	132800.00
DB28C1	2017-08-15 06:32:00+03	49400.00
DB28C4	2017-08-13 15:00:00+03	88900.00
DB28DF	2017-07-06 19:05:00+03	23600.00
DB296E	2017-07-12 14:25:00+03	71000.00
DB2987	2017-07-03 11:04:00+03	134300.00
DB2A06	2017-07-10 10:05:00+03	56900.00
DB2A4C	2017-07-16 02:38:00+03	32700.00
DB2A4D	2017-08-12 05:00:00+03	180000.00
DB2A4F	2017-07-29 06:58:00+03	15400.00
DB2A89	2017-07-23 09:46:00+03	54500.00
DB2A9C	2017-07-29 14:50:00+03	8400.00
DB2AB7	2017-07-16 14:24:00+03	31600.00
DB2ACE	2017-07-31 15:49:00+03	46400.00
DB2B71	2017-07-24 08:20:00+03	107200.00
DB2B99	2017-07-08 21:51:00+03	25600.00
DB2C45	2017-07-07 05:15:00+03	140900.00
DB2C50	2017-07-10 17:26:00+03	34000.00
DB2C51	2017-07-08 03:40:00+03	53600.00
DB2CB4	2017-08-05 21:22:00+03	46400.00
DB2CEB	2017-08-14 01:44:00+03	213200.00
DB2D08	2017-07-20 11:43:00+03	52300.00
DB2D87	2017-08-11 05:51:00+03	14700.00
DB2E92	2017-08-14 13:05:00+03	14600.00
DB2EA6	2017-07-25 10:14:00+03	27200.00
DB2EC0	2017-07-21 21:48:00+03	37800.00
DB2FCA	2017-07-27 06:29:00+03	73500.00
DB3077	2017-07-08 07:23:00+03	21600.00
DB3094	2017-08-02 00:10:00+03	186900.00
DB30AA	2017-07-10 03:40:00+03	42100.00
DB30E9	2017-07-14 23:43:00+03	170800.00
DB310B	2017-08-11 03:33:00+03	61900.00
DB316B	2017-08-02 22:57:00+03	56600.00
DB31E7	2017-07-15 13:10:00+03	14400.00
DB320C	2017-07-11 08:53:00+03	19600.00
DB3230	2017-07-02 00:41:00+03	29600.00
DB3275	2017-08-07 18:16:00+03	25600.00
DB330A	2017-07-05 00:35:00+03	138400.00
DB330E	2017-07-17 17:25:00+03	18700.00
DB3310	2017-08-05 08:06:00+03	16400.00
DB331B	2017-07-18 18:09:00+03	75300.00
DB33CA	2017-08-15 09:35:00+03	19600.00
DB33CB	2017-08-14 19:10:00+03	29600.00
DB344E	2017-07-19 13:56:00+03	46400.00
DB3467	2017-08-14 08:55:00+03	169000.00
DB34A1	2017-07-31 08:11:00+03	13000.00
DB34CF	2017-07-25 10:40:00+03	95600.00
DB34D0	2017-07-03 03:59:00+03	136800.00
DB34F6	2017-07-30 20:31:00+03	362600.00
DB3516	2017-08-10 09:46:00+03	36600.00
DB352A	2017-07-13 00:12:00+03	83600.00
DB355D	2017-07-16 03:05:00+03	260300.00
DB357C	2017-07-08 07:32:00+03	77900.00
DB3583	2017-07-31 00:37:00+03	58600.00
DB3590	2017-07-23 11:39:00+03	56000.00
DB35A2	2017-08-15 09:15:00+03	75300.00
DB35CF	2017-07-29 02:14:00+03	77200.00
DB365C	2017-07-06 18:50:00+03	110500.00
DB3679	2017-07-10 12:33:00+03	30800.00
DB36DC	2017-07-14 13:47:00+03	50100.00
DB36F6	2017-07-31 03:53:00+03	74800.00
DB372D	2017-07-05 15:47:00+03	37400.00
DB379D	2017-07-03 11:04:00+03	69100.00
DB37A2	2017-08-02 11:48:00+03	23400.00
DB381F	2017-07-16 23:21:00+03	301800.00
DB3826	2017-08-03 08:36:00+03	117600.00
DB38C0	2017-07-18 11:13:00+03	20200.00
DB38FE	2017-07-25 09:15:00+03	24200.00
DB391E	2017-07-21 04:55:00+03	118600.00
DB3961	2017-07-31 14:37:00+03	26000.00
DB3983	2017-07-08 10:13:00+03	86400.00
DB39B3	2017-07-22 12:48:00+03	23600.00
DB39F3	2017-07-06 19:49:00+03	112000.00
DB39F7	2017-07-16 01:47:00+03	111600.00
DB3A0C	2017-07-22 16:26:00+03	15000.00
DB3A3E	2017-07-17 16:04:00+03	89700.00
DB3B23	2017-08-13 07:10:00+03	102000.00
DB3B88	2017-08-08 14:46:00+03	58800.00
DB3B95	2017-08-08 16:01:00+03	66600.00
DB3CA2	2017-08-02 16:10:00+03	94300.00
DB3CD2	2017-07-30 23:50:00+03	86000.00
DB3CD7	2017-08-08 18:43:00+03	23600.00
DB3D07	2017-07-12 01:37:00+03	37100.00
DB3D08	2017-07-18 11:06:00+03	136200.00
DB3D14	2017-08-14 06:02:00+03	37200.00
DB3D58	2017-07-30 01:31:00+03	105200.00
DB3D80	2017-08-14 00:49:00+03	26800.00
DB3D99	2017-08-14 18:24:00+03	135700.00
DB3E36	2017-08-15 13:34:00+03	55500.00
DB3EAB	2017-08-01 20:18:00+03	69500.00
DB3F06	2017-07-03 03:38:00+03	23600.00
DB3F2C	2017-08-07 20:12:00+03	44500.00
DB3F78	2017-07-18 16:36:00+03	12600.00
DB3FE7	2017-07-18 18:50:00+03	44800.00
DB3FFD	2017-08-12 02:31:00+03	23200.00
DB4040	2017-07-28 04:56:00+03	26000.00
DB4043	2017-07-08 23:05:00+03	99200.00
DB4058	2017-08-07 20:49:00+03	129300.00
DB4074	2017-07-29 22:29:00+03	117200.00
DB40B5	2017-08-11 22:11:00+03	28000.00
DB4124	2017-08-11 00:19:00+03	27200.00
DB4127	2017-07-11 17:51:00+03	7400.00
DB41BF	2017-07-30 12:27:00+03	119600.00
DB42CC	2017-08-07 19:05:00+03	95600.00
DB42F6	2017-08-07 00:54:00+03	11800.00
DB4308	2017-07-18 18:23:00+03	77200.00
DB430E	2017-07-23 00:49:00+03	26000.00
DB4355	2017-08-11 01:08:00+03	8400.00
DB4476	2017-06-29 11:03:00+03	180000.00
DB4586	2017-08-12 11:25:00+03	43600.00
DB45A3	2017-07-28 08:56:00+03	137900.00
DB45BC	2017-07-20 01:48:00+03	45200.00
DB45C9	2017-07-06 22:36:00+03	89700.00
DB45CB	2017-08-15 10:46:00+03	40000.00
DB45DC	2017-07-12 15:25:00+03	55800.00
DB460E	2017-08-05 21:38:00+03	160200.00
DB4628	2017-07-02 13:05:00+03	44000.00
DB4679	2017-08-05 01:47:00+03	48800.00
DB46C8	2017-08-12 15:13:00+03	3700.00
DB46D8	2017-08-01 17:56:00+03	21200.00
DB46FB	2017-08-15 04:47:00+03	36200.00
DB4706	2017-07-08 01:51:00+03	110400.00
DB4772	2017-08-08 09:30:00+03	205900.00
DB4797	2017-07-15 17:32:00+03	24400.00
DB47CC	2017-07-29 03:41:00+03	51600.00
DB47DF	2017-07-11 02:48:00+03	30000.00
DB4807	2017-08-02 03:29:00+03	36400.00
DB4826	2017-07-09 05:16:00+03	46000.00
DB483F	2017-08-14 23:28:00+03	13700.00
DB4846	2017-08-02 16:18:00+03	81600.00
DB48BD	2017-07-29 08:03:00+03	116700.00
DB48CD	2017-07-14 06:52:00+03	168000.00
DB4931	2017-07-13 14:50:00+03	46400.00
DB493C	2017-08-07 23:30:00+03	37900.00
DB4998	2017-08-12 17:41:00+03	198600.00
DB49DC	2017-07-11 17:06:00+03	46300.00
DB49E6	2017-08-14 12:41:00+03	59800.00
DB4A42	2017-08-13 02:13:00+03	52000.00
DB4A43	2017-07-14 16:21:00+03	55000.00
DB4A8C	2017-07-20 13:17:00+03	56000.00
DB4B07	2017-08-01 21:14:00+03	86400.00
DB4B18	2017-07-02 04:01:00+03	30200.00
DB4B2F	2017-08-08 01:59:00+03	6800.00
DB4B46	2017-08-10 09:26:00+03	155600.00
DB4B57	2017-07-09 00:33:00+03	14000.00
DB4B6D	2017-07-16 11:27:00+03	43200.00
DB4C55	2017-06-30 20:31:00+03	70700.00
DB4C85	2017-06-27 16:23:00+03	88000.00
DB4CA1	2017-08-04 07:23:00+03	37000.00
DB4CAD	2017-07-21 22:08:00+03	56900.00
DB4CBC	2017-08-01 20:31:00+03	29400.00
DB4CD9	2017-07-07 22:00:00+03	194000.00
DB4D07	2017-08-06 16:27:00+03	42400.00
DB4D1D	2017-07-13 06:55:00+03	114800.00
DB4D48	2017-07-30 00:03:00+03	37600.00
DB4D5A	2017-08-07 01:45:00+03	128800.00
DB4D92	2017-08-13 11:04:00+03	51900.00
DB4DA9	2017-07-20 20:42:00+03	70700.00
DB4ECC	2017-08-01 11:30:00+03	28300.00
DB4F5C	2017-08-08 10:06:00+03	56200.00
DB4F94	2017-08-11 08:35:00+03	62600.00
DB4FB4	2017-07-02 14:02:00+03	258000.00
DB4FC4	2017-07-15 08:07:00+03	23100.00
DB4FCD	2017-08-04 20:23:00+03	81300.00
DB5039	2017-07-29 02:26:00+03	46200.00
DB5089	2017-08-09 21:30:00+03	32900.00
DB50FA	2017-07-16 09:24:00+03	83000.00
DB5146	2017-07-22 15:32:00+03	38800.00
DB5218	2017-07-23 01:25:00+03	66600.00
DB5287	2017-08-10 02:33:00+03	24400.00
DB5297	2017-07-11 06:26:00+03	94800.00
DB52C4	2017-07-16 16:58:00+03	83300.00
DB5300	2017-07-11 17:13:00+03	58900.00
DB537B	2017-07-18 12:00:00+03	34600.00
DB53A5	2017-07-01 17:49:00+03	8000.00
DB53D2	2017-08-10 17:55:00+03	57500.00
DB53FC	2017-07-09 10:21:00+03	20500.00
DB5454	2017-07-09 01:04:00+03	303500.00
DB5477	2017-07-20 17:00:00+03	92700.00
DB54F2	2017-08-03 20:43:00+03	23900.00
DB54F6	2017-08-11 02:42:00+03	123000.00
DB5594	2017-07-06 06:09:00+03	136800.00
DB55E3	2017-07-09 20:54:00+03	176500.00
DB5613	2017-07-11 09:54:00+03	110200.00
DB56A1	2017-07-09 10:34:00+03	31100.00
DB56AE	2017-08-12 12:52:00+03	102100.00
DB5719	2017-08-05 16:12:00+03	54500.00
DB5722	2017-07-30 15:18:00+03	85200.00
DB5753	2017-07-22 22:00:00+03	167500.00
DB5797	2017-07-30 11:08:00+03	58900.00
DB5806	2017-08-15 12:09:00+03	65500.00
DB5823	2017-08-10 15:59:00+03	55800.00
DB584F	2017-07-17 19:44:00+03	25800.00
DB58A9	2017-08-15 04:22:00+03	8400.00
DB58BA	2017-08-02 19:35:00+03	180200.00
DB58FA	2017-07-28 22:16:00+03	112000.00
DB5965	2017-07-10 11:43:00+03	24400.00
DB5989	2017-08-14 15:42:00+03	129600.00
DB598D	2017-08-10 18:41:00+03	124200.00
DB599F	2017-07-04 23:46:00+03	23600.00
DB59BD	2017-07-31 16:59:00+03	88200.00
DB59BF	2017-07-09 16:46:00+03	49300.00
DB59DF	2017-07-03 17:48:00+03	22000.00
DB5A58	2017-07-13 02:39:00+03	56900.00
DB5AB6	2017-07-04 15:02:00+03	56600.00
DB5B7D	2017-08-14 09:43:00+03	142800.00
DB5BA5	2017-07-21 11:42:00+03	26000.00
DB5BAC	2017-07-23 00:52:00+03	86400.00
DB5BF1	2017-08-08 05:05:00+03	88500.00
DB5C16	2017-07-17 15:11:00+03	19600.00
DB5C1C	2017-07-03 15:45:00+03	24800.00
DB5C21	2017-08-10 21:44:00+03	44000.00
DB5C37	2017-08-13 19:22:00+03	120100.00
DB5C3A	2017-07-28 07:54:00+03	141600.00
DB5CFF	2017-08-13 13:43:00+03	199800.00
DB5D3A	2017-07-21 18:28:00+03	174000.00
DB5D4F	2017-08-04 02:37:00+03	6000.00
DB5D82	2017-07-17 19:23:00+03	44600.00
DB5D8E	2017-08-04 19:25:00+03	53600.00
DB5D9A	2017-07-18 06:33:00+03	93900.00
DB5DBD	2017-07-07 21:31:00+03	46500.00
DB5DE0	2017-07-30 14:01:00+03	68800.00
DB5E00	2017-07-25 10:08:00+03	92600.00
DB5E34	2017-07-29 04:41:00+03	25000.00
DB5E4B	2017-07-08 08:26:00+03	40800.00
DB5E55	2017-07-04 08:46:00+03	92000.00
DB5E74	2017-07-30 03:38:00+03	47100.00
DB5F39	2017-08-06 03:46:00+03	53800.00
DB5F3A	2017-07-22 13:20:00+03	129600.00
DB5F9D	2017-07-23 21:17:00+03	6300.00
DB5FB6	2017-07-07 22:40:00+03	167400.00
DB5FF3	2017-07-26 13:56:00+03	40000.00
DB5FF5	2017-07-26 23:33:00+03	52000.00
DB6021	2017-07-24 21:09:00+03	28000.00
DB6031	2017-07-13 10:31:00+03	115800.00
DB6033	2017-08-14 19:20:00+03	26000.00
DB60B3	2017-07-18 06:13:00+03	61700.00
DB60BE	2017-07-08 17:11:00+03	92000.00
DB60DE	2017-08-11 12:49:00+03	39500.00
DB60FB	2017-07-07 16:28:00+03	47100.00
DB6115	2017-07-09 16:12:00+03	60400.00
DB6116	2017-07-22 05:33:00+03	68400.00
DB6199	2017-07-08 01:50:00+03	28800.00
DB61BA	2017-07-19 13:56:00+03	22000.00
DB61BB	2017-07-19 19:38:00+03	105600.00
DB61CC	2017-07-07 09:08:00+03	23600.00
DB6260	2017-07-15 20:02:00+03	26000.00
DB6276	2017-07-26 00:00:00+03	8200.00
DB62EA	2017-07-18 01:59:00+03	141600.00
DB62F3	2017-07-06 03:40:00+03	81600.00
DB630E	2017-07-19 01:12:00+03	94000.00
DB6376	2017-07-11 14:22:00+03	53400.00
DB6399	2017-06-30 20:07:00+03	55600.00
DB64D2	2017-08-03 22:50:00+03	99200.00
DB64FD	2017-08-08 04:22:00+03	18000.00
DB650C	2017-07-28 19:15:00+03	116800.00
DB652B	2017-07-02 22:10:00+03	27600.00
DB652C	2017-07-04 20:48:00+03	91700.00
DB6560	2017-08-13 04:30:00+03	93600.00
DB659F	2017-08-02 13:30:00+03	53700.00
DB65C7	2017-07-19 01:35:00+03	119600.00
DB664C	2017-07-11 08:49:00+03	40200.00
DB664E	2017-07-25 12:28:00+03	133200.00
DB66AF	2017-07-13 19:59:00+03	29400.00
DB66EE	2017-07-24 17:17:00+03	34400.00
DB6735	2017-07-11 05:45:00+03	41600.00
DB6761	2017-08-13 01:29:00+03	37100.00
DB6764	2017-07-08 12:39:00+03	15000.00
DB67A3	2017-07-04 05:27:00+03	45200.00
DB67A5	2017-07-06 15:43:00+03	18000.00
DB680F	2017-07-03 10:16:00+03	189900.00
DB6810	2017-07-28 01:05:00+03	81600.00
DB682D	2017-08-12 13:54:00+03	44800.00
DB6872	2017-07-20 21:03:00+03	99700.00
DB6891	2017-07-21 16:52:00+03	13400.00
DB68D5	2017-07-29 14:48:00+03	19600.00
DB691D	2017-07-27 05:09:00+03	20400.00
DB6971	2017-08-15 16:01:00+03	57700.00
DB698B	2017-08-02 18:50:00+03	35200.00
DB69D1	2017-06-28 10:43:00+03	16400.00
DB69DA	2017-07-19 05:31:00+03	18600.00
DB6A7D	2017-07-18 11:00:00+03	20200.00
DB6A8B	2017-07-20 20:34:00+03	61400.00
DB6BC6	2017-07-17 01:38:00+03	24800.00
DB6C0B	2017-06-26 23:48:00+03	46300.00
DB6C60	2017-07-18 01:19:00+03	123000.00
DB6C71	2017-08-09 04:24:00+03	99200.00
DB6C79	2017-08-02 16:16:00+03	65200.00
DB6C89	2017-08-15 06:45:00+03	16400.00
DB6CC4	2017-07-06 21:52:00+03	26200.00
DB6CC7	2017-07-09 22:51:00+03	27300.00
DB6D3A	2017-08-10 09:10:00+03	42500.00
DB6D73	2017-08-02 18:16:00+03	27200.00
DB6DD0	2017-08-10 11:34:00+03	160100.00
DB6E05	2017-08-11 00:12:00+03	47200.00
DB6E55	2017-07-23 18:10:00+03	117600.00
DB6E6D	2017-07-20 08:25:00+03	29500.00
DB6EA3	2017-07-23 11:37:00+03	85700.00
DB6EB8	2017-07-19 06:23:00+03	26000.00
DB6F48	2017-08-06 06:26:00+03	19600.00
DB6F60	2017-07-17 11:39:00+03	132800.00
DB6F75	2017-08-06 09:06:00+03	59800.00
DB6F98	2017-08-01 18:33:00+03	117700.00
DB7018	2017-08-13 01:41:00+03	11700.00
DB7019	2017-07-15 23:04:00+03	223200.00
DB704B	2017-07-23 14:51:00+03	38800.00
DB70AB	2017-07-03 06:51:00+03	117200.00
DB70E3	2017-07-04 14:56:00+03	46400.00
DB7136	2017-07-19 11:47:00+03	28000.00
DB7156	2017-07-05 17:17:00+03	86300.00
DB7187	2017-07-09 01:57:00+03	18000.00
DB7266	2017-07-07 07:35:00+03	149300.00
DB7288	2017-07-19 09:29:00+03	32700.00
DB72A9	2017-08-10 02:37:00+03	16400.00
DB72B6	2017-08-01 21:09:00+03	87200.00
DB72B9	2017-07-27 08:10:00+03	29600.00
DB72DF	2017-08-11 05:10:00+03	18100.00
DB72F5	2017-08-01 06:55:00+03	184500.00
DB7305	2017-07-23 14:27:00+03	22000.00
DB730E	2017-07-25 22:45:00+03	68400.00
DB7350	2017-08-03 08:30:00+03	28000.00
DB7388	2017-08-11 16:58:00+03	28800.00
DB7389	2017-06-29 03:36:00+03	91100.00
DB7390	2017-07-18 09:40:00+03	70700.00
DB739B	2017-08-06 05:49:00+03	104000.00
DB73B5	2017-08-10 12:41:00+03	43200.00
DB73FA	2017-07-18 13:10:00+03	56600.00
DB7427	2017-07-21 02:18:00+03	46500.00
DB742E	2017-07-10 22:54:00+03	64500.00
DB7515	2017-07-04 06:18:00+03	79600.00
DB75CC	2017-08-05 03:08:00+03	43100.00
DB75D3	2017-08-13 13:06:00+03	13400.00
DB75E1	2017-08-03 19:11:00+03	21400.00
DB7671	2017-07-09 03:18:00+03	42700.00
DB7687	2017-07-14 11:57:00+03	78300.00
DB76EB	2017-08-09 18:31:00+03	113700.00
DB778E	2017-08-14 06:54:00+03	12200.00
DB77A7	2017-07-04 00:58:00+03	26800.00
DB7819	2017-07-29 19:41:00+03	12600.00
DB784B	2017-07-01 16:03:00+03	50600.00
DB7856	2017-08-11 15:39:00+03	70500.00
DB787C	2017-07-20 02:04:00+03	99300.00
DB7884	2017-07-11 02:32:00+03	13600.00
DB79D1	2017-07-30 08:28:00+03	67600.00
DB7B6C	2017-07-15 02:37:00+03	68800.00
DB7BF7	2017-07-03 08:22:00+03	51600.00
DB7C3E	2017-07-23 08:52:00+03	68400.00
DB7C3F	2017-07-07 02:10:00+03	53000.00
DB7D06	2017-08-04 13:58:00+03	155800.00
DB7D09	2017-07-10 08:06:00+03	135400.00
DB7D5C	2017-08-13 19:03:00+03	123000.00
DB7D76	2017-08-11 00:35:00+03	56600.00
DB7E00	2017-07-13 03:55:00+03	67000.00
DB7E0E	2017-07-31 13:53:00+03	25800.00
DB7E17	2017-07-28 22:22:00+03	159800.00
DB7E3D	2017-06-29 23:08:00+03	125200.00
DB7ED4	2017-07-15 11:46:00+03	37200.00
DB7F0D	2017-07-29 21:13:00+03	31500.00
DB7F17	2017-08-06 02:49:00+03	25600.00
DB7F77	2017-07-10 12:01:00+03	81600.00
DB7FB9	2017-07-02 08:50:00+03	66600.00
DB804C	2017-07-22 01:47:00+03	92800.00
DB8102	2017-07-13 07:58:00+03	48800.00
DB81B2	2017-07-07 20:37:00+03	124200.00
DB81E6	2017-08-05 00:12:00+03	13200.00
DB8228	2017-07-25 04:25:00+03	34000.00
DB822B	2017-08-12 03:55:00+03	8600.00
DB82D4	2017-07-28 14:53:00+03	16400.00
DB835B	2017-07-13 10:06:00+03	100600.00
DB837C	2017-07-24 03:14:00+03	37900.00
DB838A	2017-07-30 17:18:00+03	31000.00
DB83A9	2017-07-03 11:46:00+03	13400.00
DB83BF	2017-07-06 09:49:00+03	34000.00
DB83CF	2017-08-10 05:10:00+03	147200.00
DB83FD	2017-06-29 19:53:00+03	57600.00
DB8404	2017-07-07 07:57:00+03	43600.00
DB8416	2017-07-20 01:00:00+03	13400.00
DB8430	2017-08-02 06:17:00+03	177200.00
DB8481	2017-08-06 03:49:00+03	114400.00
DB849B	2017-07-23 15:24:00+03	57600.00
DB84C8	2017-07-26 12:44:00+03	435900.00
DB84CF	2017-07-19 19:21:00+03	22000.00
DB84DE	2017-08-13 23:02:00+03	103400.00
DB8574	2017-08-14 03:42:00+03	37900.00
DB85CE	2017-08-12 10:33:00+03	48800.00
DB85F2	2017-08-02 18:13:00+03	41300.00
DB866C	2017-08-05 00:51:00+03	45200.00
DB8679	2017-07-09 19:49:00+03	8800.00
DB8690	2017-08-02 02:15:00+03	76900.00
DB8693	2017-07-01 10:24:00+03	234000.00
DB8715	2017-07-31 21:51:00+03	95200.00
DB8717	2017-08-01 15:19:00+03	26000.00
DB87C6	2017-07-10 14:07:00+03	146400.00
DB87EE	2017-07-18 05:59:00+03	48100.00
DB8800	2017-08-01 09:36:00+03	55800.00
DB8842	2017-08-07 20:29:00+03	26200.00
DB886C	2017-07-19 04:51:00+03	40800.00
DB8946	2017-07-06 05:45:00+03	29400.00
DB894C	2017-07-15 11:57:00+03	387300.00
DB8976	2017-08-08 00:42:00+03	167500.00
DB898D	2017-08-08 08:04:00+03	37900.00
DB89AF	2017-08-03 13:22:00+03	38800.00
DB89B6	2017-07-06 12:50:00+03	21400.00
DB89CD	2017-07-13 09:52:00+03	133900.00
DB89ED	2017-07-08 09:14:00+03	112000.00
DB8A07	2017-07-24 04:11:00+03	105000.00
DB8A08	2017-07-16 01:18:00+03	12400.00
DB8A09	2017-07-11 15:06:00+03	85000.00
DB8AAA	2017-07-02 13:53:00+03	55800.00
DB8B81	2017-07-08 19:24:00+03	23200.00
DB8B8C	2017-07-01 12:06:00+03	12600.00
DB8BB0	2017-07-28 23:09:00+03	89700.00
DB8BBA	2017-07-08 11:14:00+03	25600.00
DB8BBE	2017-07-29 05:58:00+03	203500.00
DB8C0A	2017-06-28 12:06:00+03	21800.00
DB8C22	2017-08-03 19:41:00+03	203000.00
DB8C62	2017-08-03 04:25:00+03	81200.00
DB8CC8	2017-07-11 18:57:00+03	46300.00
DB8DD4	2017-08-14 13:02:00+03	16800.00
DB8DD5	2017-08-12 11:38:00+03	24700.00
DB8E7F	2017-07-19 09:22:00+03	149300.00
DB8E82	2017-08-05 06:00:00+03	23200.00
DB8ECC	2017-07-24 11:24:00+03	135400.00
DB8EDD	2017-07-10 14:06:00+03	248500.00
DB8EFE	2017-07-09 21:28:00+03	28000.00
DB8FD4	2017-07-07 05:10:00+03	67200.00
DB9016	2017-07-25 07:18:00+03	81300.00
DB9132	2017-07-26 09:05:00+03	57600.00
DB913D	2017-08-03 18:17:00+03	47100.00
DB9157	2017-07-23 13:42:00+03	16400.00
DB91CB	2017-07-27 13:39:00+03	57800.00
DB91F5	2017-07-24 02:41:00+03	12600.00
DB923D	2017-07-21 02:53:00+03	112600.00
DB9240	2017-07-22 03:12:00+03	56000.00
DB92A3	2017-08-10 04:36:00+03	130400.00
DB92DB	2017-07-10 07:15:00+03	69600.00
DB9313	2017-07-23 20:17:00+03	17600.00
DB932E	2017-07-27 11:14:00+03	25800.00
DB937C	2017-08-05 18:07:00+03	13600.00
DB944A	2017-07-01 12:39:00+03	89600.00
DB945E	2017-08-09 18:11:00+03	136100.00
DB94B3	2017-07-14 09:58:00+03	21400.00
DB94B6	2017-07-20 13:44:00+03	43200.00
DB9564	2017-07-10 22:40:00+03	61600.00
DB9594	2017-07-08 16:25:00+03	39300.00
DB95AD	2017-08-03 02:23:00+03	89800.00
DB95BE	2017-07-12 09:55:00+03	66600.00
DB961C	2017-07-15 15:40:00+03	174400.00
DB965F	2017-08-11 16:01:00+03	38800.00
DB969F	2017-07-13 08:52:00+03	56600.00
DB96A7	2017-07-07 16:14:00+03	40200.00
DB96CB	2017-07-26 07:10:00+03	52000.00
DB97BD	2017-08-05 05:27:00+03	92400.00
DB97E5	2017-08-11 14:47:00+03	52700.00
DB9810	2017-07-25 12:37:00+03	173900.00
DB9831	2017-07-08 19:30:00+03	24400.00
DB9842	2017-07-06 07:31:00+03	99200.00
DB9858	2017-07-13 10:59:00+03	56000.00
DB9890	2017-08-10 03:02:00+03	36800.00
DB98B2	2017-07-14 21:44:00+03	96800.00
DB98EA	2017-07-15 21:31:00+03	31600.00
DB994F	2017-07-06 12:46:00+03	156000.00
DB996B	2017-08-11 02:30:00+03	91100.00
DB9A5D	2017-08-09 07:57:00+03	56100.00
DB9AAF	2017-08-13 06:12:00+03	57600.00
DB9AD7	2017-07-01 03:30:00+03	89700.00
DB9B01	2017-07-25 00:37:00+03	136500.00
DB9B5D	2017-08-03 15:12:00+03	92900.00
DB9BB6	2017-08-11 23:14:00+03	38400.00
DB9BBA	2017-08-12 09:43:00+03	62100.00
DB9BED	2017-07-02 17:13:00+03	62900.00
DB9C8D	2017-07-03 17:27:00+03	22200.00
DB9CC7	2017-07-24 18:59:00+03	69500.00
DB9CDD	2017-07-30 21:00:00+03	257500.00
DB9D04	2017-07-13 14:30:00+03	46400.00
DB9D3B	2017-07-11 09:08:00+03	20500.00
DB9D49	2017-07-04 21:21:00+03	32700.00
DB9D9B	2017-07-13 06:44:00+03	41600.00
DB9D9F	2017-08-14 07:17:00+03	28000.00
DB9DDA	2017-07-12 20:09:00+03	135000.00
DB9DFB	2017-07-30 04:46:00+03	67100.00
DB9E27	2017-08-12 08:45:00+03	68000.00
DB9EBC	2017-08-11 10:34:00+03	121400.00
DB9F8A	2017-08-08 09:17:00+03	58200.00
DB9F9E	2017-07-07 12:44:00+03	8000.00
DB9FFB	2017-07-25 09:51:00+03	58600.00
DBA01E	2017-08-02 18:02:00+03	115100.00
DBA064	2017-07-06 15:26:00+03	30200.00
DBA07F	2017-08-06 12:01:00+03	36200.00
DBA0AD	2017-07-14 01:37:00+03	53600.00
DBA0E6	2017-07-15 12:28:00+03	166000.00
DBA0EF	2017-07-04 13:04:00+03	25100.00
DBA0F6	2017-07-05 13:57:00+03	63800.00
DBA100	2017-07-13 21:41:00+03	325500.00
DBA123	2017-08-02 15:29:00+03	26000.00
DBA1B6	2017-07-11 02:54:00+03	6600.00
DBA1FA	2017-07-29 15:38:00+03	27400.00
DBA2F3	2017-07-10 05:11:00+03	94400.00
DBA304	2017-07-10 00:12:00+03	195600.00
DBA367	2017-08-08 19:21:00+03	43000.00
DBA36B	2017-07-06 02:49:00+03	19600.00
DBA391	2017-08-04 18:28:00+03	133100.00
DBA3B2	2017-07-11 22:21:00+03	47000.00
DBA3F3	2017-07-19 23:51:00+03	28800.00
DBA403	2017-07-10 08:12:00+03	69500.00
DBA435	2017-07-20 03:09:00+03	204000.00
DBA443	2017-08-12 20:49:00+03	118400.00
DBA45B	2017-07-15 15:32:00+03	89000.00
DBA480	2017-08-15 08:08:00+03	10800.00
DBA4AB	2017-07-07 19:56:00+03	30200.00
DBA559	2017-06-30 09:01:00+03	40400.00
DBA56B	2017-07-14 05:36:00+03	67000.00
DBA57F	2017-07-22 20:36:00+03	136500.00
DBA583	2017-07-21 12:25:00+03	47400.00
DBA5AF	2017-07-15 20:39:00+03	112600.00
DBA606	2017-08-15 11:09:00+03	58800.00
DBA610	2017-07-18 01:18:00+03	20800.00
DBA612	2017-08-11 07:09:00+03	55800.00
DBA662	2017-07-11 02:50:00+03	68000.00
DBA67E	2017-07-24 17:38:00+03	111600.00
DBA681	2017-08-11 10:35:00+03	28800.00
DBA6AC	2017-08-02 19:30:00+03	67600.00
DBA71D	2017-07-07 06:33:00+03	27400.00
DBA721	2017-08-03 08:06:00+03	45200.00
DBA72B	2017-07-25 17:51:00+03	102100.00
DBA73D	2017-07-23 16:47:00+03	25100.00
DBA748	2017-07-23 09:57:00+03	69000.00
DBA788	2017-08-10 06:27:00+03	64300.00
DBA792	2017-07-19 12:46:00+03	200500.00
DBA829	2017-07-20 22:03:00+03	326300.00
DBA87C	2017-07-13 00:30:00+03	40600.00
DBA8BB	2017-06-28 01:46:00+03	119700.00
DBA8D1	2017-08-10 09:08:00+03	51900.00
DBA8DD	2017-07-05 04:52:00+03	60400.00
DBA8E9	2017-06-30 06:28:00+03	15000.00
DBA8F3	2017-07-23 18:28:00+03	21000.00
DBA904	2017-07-06 01:01:00+03	6800.00
DBA95D	2017-07-07 19:27:00+03	89600.00
DBA982	2017-07-18 12:48:00+03	49100.00
DBAA01	2017-07-28 16:20:00+03	53300.00
DBAA58	2017-07-07 03:56:00+03	40400.00
DBAA7D	2017-07-30 10:46:00+03	12000.00
DBAAA1	2017-07-01 20:11:00+03	18000.00
DBAAB9	2017-07-31 07:51:00+03	27000.00
DBAB14	2017-08-10 07:52:00+03	41400.00
DBAB2D	2017-08-11 12:35:00+03	66000.00
DBAB44	2017-07-20 05:21:00+03	187600.00
DBAB78	2017-08-09 20:59:00+03	500100.00
DBABCE	2017-07-29 05:51:00+03	27200.00
DBABCF	2017-08-01 03:10:00+03	43200.00
DBAC1D	2017-07-21 04:36:00+03	46200.00
DBAC32	2017-07-24 19:59:00+03	19600.00
DBAD26	2017-07-24 13:29:00+03	211600.00
DBAD32	2017-08-05 12:40:00+03	84100.00
DBAD46	2017-07-30 13:52:00+03	67700.00
DBAD6A	2017-07-27 15:29:00+03	72400.00
DBAD6C	2017-08-07 23:34:00+03	64700.00
DBAD80	2017-07-03 06:41:00+03	6000.00
DBADC4	2017-07-14 15:34:00+03	26000.00
DBADCE	2017-08-14 19:35:00+03	28800.00
DBAE17	2017-07-26 10:19:00+03	188000.00
DBAE29	2017-08-09 11:05:00+03	89700.00
DBAE73	2017-08-15 02:29:00+03	13400.00
DBAE8B	2017-07-22 05:48:00+03	19600.00
DBAE8D	2017-08-15 08:16:00+03	37100.00
DBAE91	2017-07-26 19:48:00+03	80800.00
DBAE97	2017-07-14 16:43:00+03	57600.00
DBAEAF	2017-07-06 09:17:00+03	64700.00
DBAED7	2017-08-13 23:43:00+03	193700.00
DBAEE1	2017-07-05 08:07:00+03	217900.00
DBAEFE	2017-07-08 12:02:00+03	246000.00
DBAF04	2017-07-23 00:36:00+03	50600.00
DBB000	2017-08-14 20:14:00+03	55400.00
DBB02E	2017-07-28 12:16:00+03	28000.00
DBB038	2017-08-07 16:39:00+03	55800.00
DBB06A	2017-07-21 04:49:00+03	35600.00
DBB0CC	2017-07-19 15:58:00+03	111700.00
DBB0EC	2017-08-04 13:55:00+03	40200.00
DBB0FB	2017-07-16 02:48:00+03	60200.00
DBB0FF	2017-07-13 09:15:00+03	492000.00
DBB138	2017-07-30 02:55:00+03	20400.00
DBB197	2017-08-12 08:38:00+03	85000.00
DBB1CB	2017-08-05 09:23:00+03	129600.00
DBB1CC	2017-07-08 14:53:00+03	80300.00
DBB1DA	2017-08-02 05:20:00+03	16400.00
DBB1E5	2017-08-10 16:57:00+03	52000.00
DBB1E8	2017-08-10 17:11:00+03	16400.00
DBB1F6	2017-07-11 10:28:00+03	147100.00
DBB1FA	2017-07-14 23:11:00+03	46000.00
DBB202	2017-07-20 23:11:00+03	191700.00
DBB2D7	2017-07-31 04:24:00+03	68800.00
DBB306	2017-08-08 04:55:00+03	142400.00
DBB362	2017-07-18 13:19:00+03	36200.00
DBB37B	2017-07-24 05:28:00+03	21200.00
DBB380	2017-07-28 06:43:00+03	8000.00
DBB3A9	2017-08-10 20:36:00+03	63600.00
DBB4B0	2017-07-06 10:31:00+03	77900.00
DBB632	2017-07-01 22:34:00+03	22000.00
DBB6CB	2017-07-12 17:16:00+03	70600.00
DBB72A	2017-07-17 16:43:00+03	59000.00
DBB736	2017-08-06 19:34:00+03	12400.00
DBB768	2017-08-08 05:34:00+03	24600.00
DBB774	2017-07-13 18:22:00+03	114200.00
DBB777	2017-08-01 08:45:00+03	56600.00
DBB7C8	2017-08-06 01:19:00+03	77200.00
DBB809	2017-08-11 02:46:00+03	103500.00
DBB830	2017-07-05 02:31:00+03	238300.00
DBB836	2017-07-10 12:10:00+03	404100.00
DBB8A1	2017-07-25 12:59:00+03	135600.00
DBB8AA	2017-08-13 17:44:00+03	24300.00
DBB8E2	2017-07-06 23:13:00+03	58200.00
DBB8FB	2017-08-01 01:08:00+03	47400.00
DBB92C	2017-08-02 21:32:00+03	89600.00
DBB935	2017-07-10 08:40:00+03	21500.00
DBB9B5	2017-08-08 05:18:00+03	68800.00
DBB9C8	2017-06-29 17:23:00+03	57500.00
DBB9E4	2017-07-05 20:38:00+03	15000.00
DBBA2E	2017-07-02 21:04:00+03	6000.00
DBBA8A	2017-08-04 14:13:00+03	140900.00
DBBB76	2017-08-01 10:30:00+03	31200.00
DBBBC9	2017-07-18 05:39:00+03	55800.00
DBBBD9	2017-07-22 10:45:00+03	46400.00
DBBC1D	2017-07-26 07:49:00+03	53600.00
DBBCB4	2017-08-02 18:30:00+03	112000.00
DBBCD8	2017-07-29 09:36:00+03	20200.00
DBBCF1	2017-07-14 00:28:00+03	221600.00
DBBCFD	2017-07-25 12:21:00+03	55800.00
DBBD8B	2017-07-08 20:18:00+03	35800.00
DBBD90	2017-07-07 14:09:00+03	57600.00
DBBDCD	2017-07-18 09:31:00+03	88400.00
DBBDE2	2017-08-15 10:29:00+03	45800.00
DBBE5F	2017-08-14 19:54:00+03	14000.00
DBBE73	2017-07-06 08:01:00+03	99200.00
DBBEA2	2017-07-23 18:28:00+03	51900.00
DBBEC3	2017-08-15 15:17:00+03	20400.00
DBBF42	2017-07-01 01:14:00+03	25600.00
DBBFAF	2017-08-03 06:52:00+03	19600.00
DBC04C	2017-07-20 14:55:00+03	60600.00
DBC0E4	2017-07-21 21:14:00+03	131600.00
DBC0EB	2017-07-06 01:34:00+03	28400.00
DBC15A	2017-08-03 20:42:00+03	30000.00
DBC18C	2017-07-25 20:54:00+03	290500.00
DBC195	2017-07-05 17:20:00+03	23600.00
DBC196	2017-07-25 00:47:00+03	53500.00
DBC1FA	2017-07-11 07:55:00+03	111600.00
DBC22D	2017-08-07 06:02:00+03	25600.00
DBC29B	2017-07-27 14:33:00+03	46000.00
DBC2C7	2017-08-03 16:59:00+03	185300.00
DBC2D5	2017-07-02 05:45:00+03	18600.00
DBC30D	2017-07-12 03:46:00+03	76600.00
DBC337	2017-07-21 07:11:00+03	23100.00
DBC39A	2017-07-11 23:37:00+03	55800.00
DBC40E	2017-07-29 04:19:00+03	202300.00
DBC4D3	2017-08-14 09:04:00+03	55400.00
DBC526	2017-07-26 06:54:00+03	66000.00
DBC52D	2017-08-07 06:05:00+03	266400.00
DBC55B	2017-07-11 08:43:00+03	112000.00
DBC583	2017-07-30 14:34:00+03	89600.00
DBC586	2017-07-27 20:43:00+03	36200.00
DBC593	2017-08-05 08:31:00+03	39200.00
DBC5BB	2017-08-04 01:53:00+03	25700.00
DBC632	2017-08-09 12:58:00+03	13000.00
DBC63E	2017-07-16 18:55:00+03	53600.00
DBC68E	2017-07-18 21:10:00+03	57600.00
DBC6F2	2017-07-15 23:47:00+03	75600.00
DBC77B	2017-07-30 12:40:00+03	32800.00
DBC783	2017-07-19 09:52:00+03	98100.00
DBC7A0	2017-08-14 02:46:00+03	86200.00
DBC7B2	2017-08-02 13:32:00+03	22000.00
DBC7B4	2017-07-21 23:41:00+03	46200.00
DBC7F6	2017-08-12 05:06:00+03	236700.00
DBC81F	2017-07-30 05:34:00+03	13000.00
DBC839	2017-07-08 23:45:00+03	65600.00
DBC84C	2017-08-08 12:31:00+03	66600.00
DBC85A	2017-07-05 05:49:00+03	86400.00
DBC85B	2017-07-20 00:41:00+03	111600.00
DBC8F9	2017-07-01 21:51:00+03	29100.00
DBC906	2017-07-08 08:45:00+03	35600.00
DBC90F	2017-08-02 12:23:00+03	26000.00
DBC943	2017-07-04 11:44:00+03	40400.00
DBC951	2017-08-11 03:11:00+03	73600.00
DBC98B	2017-08-01 19:32:00+03	56000.00
DBC98C	2017-07-13 12:10:00+03	234700.00
DBCA29	2017-07-15 18:34:00+03	100600.00
DBCA48	2017-07-27 05:05:00+03	119600.00
DBCA86	2017-07-10 19:37:00+03	23400.00
DBCB25	2017-07-09 00:17:00+03	161200.00
DBCB42	2017-08-12 02:58:00+03	27200.00
DBCBBC	2017-08-01 13:33:00+03	83200.00
DBCBEF	2017-08-12 17:59:00+03	40900.00
DBCC27	2017-07-08 08:32:00+03	13400.00
DBCC42	2017-08-10 07:43:00+03	6300.00
DBCC79	2017-06-30 17:27:00+03	36600.00
DBCCB9	2017-07-25 02:06:00+03	46300.00
DBCCF1	2017-07-16 04:27:00+03	248300.00
DBCD0F	2017-08-09 10:49:00+03	285000.00
DBCD9B	2017-07-22 04:42:00+03	52800.00
DBCE0C	2017-08-05 14:25:00+03	51600.00
DBCE11	2017-08-05 20:18:00+03	31200.00
DBCE30	2017-07-17 17:06:00+03	6800.00
DBCEA8	2017-08-04 08:58:00+03	116400.00
DBCF46	2017-08-06 04:48:00+03	55500.00
DBCFD2	2017-07-19 04:27:00+03	75300.00
DBCFE3	2017-08-14 03:57:00+03	74100.00
DBCFFA	2017-07-14 08:27:00+03	14400.00
DBD004	2017-07-03 01:04:00+03	75600.00
DBD021	2017-07-15 16:00:00+03	110300.00
DBD0BD	2017-08-13 06:08:00+03	64300.00
DBD147	2017-08-15 03:06:00+03	23200.00
DBD1E5	2017-08-03 23:45:00+03	102100.00
DBD1EC	2017-07-28 16:52:00+03	56000.00
DBD33D	2017-08-12 02:14:00+03	75100.00
DBD357	2017-07-04 20:18:00+03	91200.00
DBD36B	2017-07-06 17:03:00+03	14000.00
DBD39F	2017-08-13 16:32:00+03	295500.00
DBD3A3	2017-07-27 04:15:00+03	15100.00
DBD3C6	2017-07-31 15:22:00+03	195600.00
DBD3C9	2017-07-30 00:44:00+03	32700.00
DBD452	2017-07-28 01:51:00+03	53700.00
DBD4B2	2017-08-09 05:00:00+03	73600.00
DBD4FF	2017-07-04 22:35:00+03	70500.00
DBD53D	2017-08-04 16:05:00+03	36200.00
DBD55A	2017-07-12 02:32:00+03	79600.00
DBD585	2017-07-22 02:22:00+03	97600.00
DBD5B6	2017-08-05 06:50:00+03	137600.00
DBD5E1	2017-07-09 13:00:00+03	38600.00
DBD5F7	2017-07-07 13:25:00+03	56600.00
DBD632	2017-06-28 08:21:00+03	28800.00
DBD653	2017-08-09 11:49:00+03	46400.00
DBD697	2017-07-24 14:50:00+03	156100.00
DBD6DA	2017-08-05 04:00:00+03	12600.00
DBD70B	2017-06-28 14:32:00+03	48800.00
DBD70D	2017-08-12 11:11:00+03	174600.00
DBD721	2017-07-04 16:14:00+03	58600.00
DBD72F	2017-07-09 21:56:00+03	133100.00
DBD794	2017-07-21 08:44:00+03	27800.00
DBD8C3	2017-08-02 09:24:00+03	52400.00
DBD8FF	2017-07-29 01:50:00+03	266400.00
DBD918	2017-07-15 20:18:00+03	166100.00
DBD93F	2017-07-14 16:41:00+03	37200.00
DBD99E	2017-08-14 16:45:00+03	78800.00
DBD9BC	2017-07-22 07:34:00+03	26700.00
DBDA15	2017-07-15 05:42:00+03	32700.00
DBDAA2	2017-08-04 19:21:00+03	31600.00
DBDB88	2017-08-09 11:29:00+03	28800.00
DBDC58	2017-07-24 11:46:00+03	48800.00
DBDC72	2017-07-18 17:55:00+03	6800.00
DBDCAC	2017-07-16 19:23:00+03	144400.00
DBDCFF	2017-08-10 05:52:00+03	23100.00
DBDD04	2017-07-08 09:12:00+03	24400.00
DBDD52	2017-07-15 06:40:00+03	17000.00
DBDD95	2017-07-23 02:20:00+03	19600.00
DBDDA4	2017-07-09 19:55:00+03	27200.00
DBDDDB	2017-08-02 06:01:00+03	20200.00
DBDE01	2017-08-04 18:47:00+03	22000.00
DBDE20	2017-08-13 11:57:00+03	187600.00
DBDF35	2017-07-31 15:02:00+03	185400.00
DBDF68	2017-08-05 04:29:00+03	56000.00
DBDFE5	2017-07-19 13:00:00+03	56000.00
DBDFFE	2017-07-14 02:19:00+03	44000.00
DBE12D	2017-07-25 15:07:00+03	38400.00
DBE17B	2017-07-26 02:23:00+03	28000.00
DBE1EF	2017-07-10 05:19:00+03	51800.00
DBE207	2017-07-09 18:37:00+03	104600.00
DBE214	2017-08-01 05:00:00+03	230000.00
DBE33B	2017-07-11 21:37:00+03	60300.00
DBE375	2017-06-30 20:47:00+03	27200.00
DBE3A2	2017-07-19 08:18:00+03	93400.00
DBE3EB	2017-07-21 20:59:00+03	17200.00
DBE3F4	2017-08-14 01:06:00+03	27200.00
DBE435	2017-07-16 15:15:00+03	160400.00
DBE446	2017-08-02 07:52:00+03	50600.00
DBE450	2017-06-27 11:44:00+03	33100.00
DBE484	2017-07-31 21:58:00+03	26000.00
DBE4F7	2017-07-28 06:27:00+03	133200.00
DBE54C	2017-08-09 05:46:00+03	23200.00
DBE54E	2017-07-12 19:58:00+03	72400.00
DBE567	2017-07-13 11:13:00+03	39800.00
DBE5A9	2017-08-04 01:18:00+03	89200.00
DBE60E	2017-08-02 09:59:00+03	14400.00
DBE61A	2017-07-23 12:46:00+03	58700.00
DBE6EE	2017-07-03 03:13:00+03	167200.00
DBE70D	2017-07-27 19:05:00+03	112000.00
DBE7F2	2017-08-04 19:56:00+03	228700.00
DBE7F7	2017-07-19 15:10:00+03	25700.00
DBE845	2017-07-06 09:29:00+03	41600.00
DBE874	2017-07-29 04:57:00+03	128800.00
DBE894	2017-08-08 09:18:00+03	35300.00
DBE91E	2017-07-06 13:03:00+03	43000.00
DBE95F	2017-08-07 11:58:00+03	6600.00
DBE9BD	2017-07-17 12:06:00+03	86400.00
DBEA25	2017-07-08 05:55:00+03	56000.00
DBEA2A	2017-08-02 09:35:00+03	59800.00
DBEAB6	2017-07-06 05:22:00+03	45200.00
DBEAE0	2017-07-04 03:59:00+03	337400.00
DBEB01	2017-07-06 08:37:00+03	56600.00
DBEB72	2017-08-12 11:36:00+03	12400.00
DBEBCF	2017-08-04 21:23:00+03	169300.00
DBEBF1	2017-07-19 01:21:00+03	28800.00
DBEC19	2017-07-10 17:55:00+03	43200.00
DBEC1D	2017-06-28 10:37:00+03	66600.00
DBEC2C	2017-07-03 20:36:00+03	95300.00
DBEC9E	2017-08-03 06:08:00+03	21600.00
DBECD3	2017-08-06 21:53:00+03	55800.00
DBEDD3	2017-07-25 00:59:00+03	57500.00
DBEE14	2017-07-28 19:17:00+03	38600.00
DBEE6D	2017-07-03 08:00:00+03	25600.00
DBEE6E	2017-07-10 15:28:00+03	42900.00
DBEEB9	2017-07-03 11:45:00+03	112000.00
DBEEC7	2017-07-28 07:40:00+03	74400.00
DBEF0F	2017-08-15 11:36:00+03	68800.00
DBEF99	2017-08-06 11:28:00+03	33300.00
DBEFCB	2017-07-12 22:56:00+03	61800.00
DBEFF8	2017-07-09 09:10:00+03	25800.00
DBF017	2017-08-09 16:26:00+03	97700.00
DBF01C	2017-07-16 16:03:00+03	348800.00
DBF048	2017-07-17 16:46:00+03	101500.00
DBF07E	2017-07-19 22:37:00+03	23200.00
DBF0CC	2017-07-08 23:20:00+03	96800.00
DBF0EB	2017-08-06 15:58:00+03	135600.00
DBF0EF	2017-08-03 05:11:00+03	21200.00
DBF0F4	2017-07-31 03:21:00+03	96300.00
DBF13D	2017-08-12 07:23:00+03	13400.00
DBF1B4	2017-08-11 09:23:00+03	47000.00
DBF1FE	2017-07-14 21:28:00+03	58200.00
DBF214	2017-07-21 10:19:00+03	57600.00
DBF230	2017-07-12 03:58:00+03	28300.00
DBF23A	2017-08-12 05:04:00+03	12000.00
DBF242	2017-07-21 21:37:00+03	146300.00
DBF2E4	2017-08-03 13:29:00+03	26000.00
DBF32C	2017-07-13 20:13:00+03	67800.00
DBF32F	2017-08-06 00:27:00+03	27200.00
DBF392	2017-08-07 11:29:00+03	168500.00
DBF3A5	2017-07-21 07:34:00+03	316700.00
DBF3CC	2017-07-04 08:26:00+03	153200.00
DBF3FD	2017-06-26 23:11:00+03	265800.00
DBF49D	2017-08-05 05:55:00+03	80400.00
DBF4A2	2017-07-12 12:52:00+03	29600.00
DBF4AF	2017-07-09 08:34:00+03	114800.00
DBF4BF	2017-07-21 05:54:00+03	98600.00
DBF4C1	2017-07-01 11:27:00+03	26800.00
DBF51B	2017-07-21 15:43:00+03	136800.00
DBF546	2017-07-13 06:06:00+03	39200.00
DBF567	2017-07-23 11:02:00+03	246000.00
DBF591	2017-07-23 11:27:00+03	55600.00
DBF59E	2017-07-12 17:08:00+03	74800.00
DBF5C7	2017-07-10 14:34:00+03	24500.00
DBF5D8	2017-06-28 15:48:00+03	51200.00
DBF5E4	2017-08-08 15:45:00+03	6800.00
DBF5FF	2017-07-14 03:24:00+03	67100.00
DBF651	2017-07-09 20:06:00+03	51200.00
DBF68D	2017-07-09 04:35:00+03	23600.00
DBF6A2	2017-07-11 12:00:00+03	37200.00
DBF6B8	2017-07-08 23:22:00+03	24400.00
DBF6D6	2017-07-13 12:53:00+03	29600.00
DBF714	2017-07-20 01:29:00+03	59200.00
DBF72A	2017-07-07 12:28:00+03	33800.00
DBF736	2017-07-23 08:23:00+03	113200.00
DBF759	2017-07-29 07:11:00+03	54500.00
DBF763	2017-08-08 13:12:00+03	64500.00
DBF887	2017-07-04 07:43:00+03	106800.00
DBF8D5	2017-07-07 21:02:00+03	18600.00
DBF907	2017-07-08 13:21:00+03	210000.00
DBF911	2017-07-17 11:27:00+03	10600.00
DBF932	2017-07-15 19:23:00+03	51400.00
DBF955	2017-07-14 00:12:00+03	27300.00
DBF98C	2017-07-24 23:53:00+03	19600.00
DBFA3D	2017-07-07 14:31:00+03	89600.00
DBFA50	2017-07-04 06:14:00+03	181600.00
DBFAED	2017-07-06 03:03:00+03	21800.00
DBFB11	2017-08-12 15:12:00+03	42600.00
DBFB38	2017-08-15 06:58:00+03	170700.00
DBFB75	2017-07-10 18:42:00+03	84100.00
DBFB89	2017-07-09 11:33:00+03	116700.00
DBFBAC	2017-07-18 15:44:00+03	49400.00
DBFBC0	2017-08-03 20:18:00+03	56600.00
DBFBEB	2017-07-18 23:59:00+03	70600.00
DBFC74	2017-08-01 04:16:00+03	59800.00
DBFCB8	2017-08-07 04:04:00+03	8200.00
DBFD03	2017-07-25 23:40:00+03	99200.00
DBFD38	2017-07-30 08:18:00+03	46300.00
DBFD87	2017-07-07 13:45:00+03	6900.00
DBFDC1	2017-07-03 08:30:00+03	32800.00
DBFDC6	2017-07-24 22:50:00+03	43500.00
DBFDE3	2017-08-06 17:21:00+03	100700.00
DBFDEE	2017-07-09 22:20:00+03	16400.00
DBFE81	2017-07-27 01:53:00+03	37200.00
DBFEF2	2017-08-12 21:41:00+03	19600.00
DBFF12	2017-07-19 00:18:00+03	36800.00
DBFF75	2017-07-14 19:53:00+03	272400.00
DBFFA1	2017-07-28 07:30:00+03	133500.00
DBFFC9	2017-07-28 20:14:00+03	14000.00
DBFFD4	2017-08-06 10:50:00+03	101200.00
DC0013	2017-07-12 08:06:00+03	48500.00
DC0028	2017-07-22 00:00:00+03	6600.00
DC006F	2017-08-07 13:25:00+03	66700.00
DC007B	2017-07-12 12:09:00+03	28000.00
DC00FD	2017-07-06 11:48:00+03	109600.00
DC0100	2017-07-26 01:01:00+03	129200.00
DC011C	2017-08-15 05:21:00+03	21400.00
DC014D	2017-08-08 13:21:00+03	47600.00
DC0168	2017-08-13 15:48:00+03	48700.00
DC01C3	2017-07-25 16:59:00+03	70000.00
DC01F8	2017-07-28 16:11:00+03	54300.00
DC021C	2017-07-04 08:24:00+03	46200.00
DC0247	2017-08-15 14:42:00+03	67700.00
DC029D	2017-07-11 14:26:00+03	33600.00
DC02D9	2017-08-08 16:28:00+03	17800.00
DC02EC	2017-08-09 23:17:00+03	24400.00
DC031A	2017-08-09 10:01:00+03	283700.00
DC0395	2017-07-10 21:51:00+03	24800.00
DC039D	2017-08-05 14:28:00+03	89100.00
DC03E3	2017-07-20 01:27:00+03	28800.00
DC049B	2017-07-06 01:36:00+03	25600.00
DC04AE	2017-07-31 19:34:00+03	25400.00
DC04AF	2017-08-04 20:43:00+03	16400.00
DC0583	2017-07-13 06:06:00+03	19600.00
DC059A	2017-07-31 15:24:00+03	28800.00
DC0612	2017-07-14 02:34:00+03	69100.00
DC06F2	2017-07-08 01:21:00+03	202900.00
DC077E	2017-07-03 21:21:00+03	12600.00
DC07DE	2017-07-12 06:56:00+03	42700.00
DC0803	2017-07-03 05:01:00+03	75400.00
DC080B	2017-07-28 11:30:00+03	119400.00
DC080E	2017-07-29 08:02:00+03	186900.00
DC0812	2017-08-03 05:48:00+03	24400.00
DC084C	2017-07-06 09:58:00+03	51800.00
DC08CF	2017-07-26 00:53:00+03	6700.00
DC08FD	2017-07-29 06:06:00+03	24800.00
DC090C	2017-08-01 08:20:00+03	52300.00
DC096E	2017-07-26 23:36:00+03	111600.00
DC09BA	2017-07-03 05:22:00+03	55800.00
DC0B0F	2017-07-15 05:05:00+03	47200.00
DC0B4B	2017-07-14 15:25:00+03	30000.00
DC0BF4	2017-08-07 00:44:00+03	91300.00
DC0C08	2017-08-03 06:50:00+03	67200.00
DC0C0E	2017-07-22 13:19:00+03	55800.00
DC0C20	2017-07-07 07:34:00+03	40800.00
DC0D06	2017-08-12 15:29:00+03	35700.00
DC0D6F	2017-08-08 10:39:00+03	39100.00
DC0D8A	2017-08-12 23:31:00+03	39600.00
DC0D8B	2017-08-05 05:12:00+03	49800.00
DC0DB4	2017-07-04 04:52:00+03	68400.00
DC0E9A	2017-07-22 01:57:00+03	413400.00
DC0F4E	2017-07-29 13:53:00+03	24400.00
DC1026	2017-07-21 03:07:00+03	15100.00
DC10E2	2017-07-13 20:08:00+03	77900.00
DC1100	2017-07-05 03:30:00+03	273600.00
DC1112	2017-08-07 09:16:00+03	290400.00
DC111B	2017-08-03 14:35:00+03	67600.00
DC1131	2017-07-09 13:43:00+03	28000.00
DC1176	2017-07-08 19:15:00+03	75600.00
DC1206	2017-07-01 12:48:00+03	23200.00
DC1259	2017-07-15 19:21:00+03	115600.00
DC1283	2017-07-13 06:41:00+03	136600.00
DC12CE	2017-07-13 12:25:00+03	17000.00
DC13E8	2017-08-09 02:44:00+03	38400.00
DC1425	2017-07-04 16:11:00+03	167400.00
DC1443	2017-08-10 14:19:00+03	12000.00
DC145A	2017-08-14 01:06:00+03	97700.00
DC1495	2017-07-08 01:19:00+03	234900.00
DC1505	2017-07-19 20:51:00+03	14400.00
DC150E	2017-08-10 20:59:00+03	11700.00
DC1552	2017-07-31 03:35:00+03	46400.00
DC1553	2017-07-27 17:57:00+03	32400.00
DC1554	2017-08-07 07:47:00+03	6700.00
DC158C	2017-07-25 09:15:00+03	16400.00
DC15C3	2017-07-30 07:54:00+03	285900.00
DC15E1	2017-08-05 03:29:00+03	27000.00
DC15F5	2017-08-08 04:29:00+03	531300.00
DC16A3	2017-08-12 03:23:00+03	385000.00
DC178E	2017-07-28 06:27:00+03	131600.00
DC1894	2017-08-11 14:56:00+03	26000.00
DC18E1	2017-07-14 06:31:00+03	130900.00
DC18E7	2017-08-08 01:53:00+03	131600.00
DC193A	2017-07-11 10:52:00+03	52300.00
DC1999	2017-07-16 04:42:00+03	69400.00
DC1A05	2017-08-07 13:28:00+03	25800.00
DC1A73	2017-07-13 22:04:00+03	85000.00
DC1BA7	2017-07-06 06:35:00+03	26000.00
DC1C69	2017-07-22 14:42:00+03	6000.00
DC1C9D	2017-07-11 10:54:00+03	307900.00
DC1CF8	2017-08-13 01:01:00+03	51600.00
DC1D49	2017-07-30 09:31:00+03	30200.00
DC1D55	2017-08-06 20:10:00+03	101200.00
DC1D88	2017-07-27 21:16:00+03	64500.00
DC1D9C	2017-08-04 05:30:00+03	123000.00
DC1E10	2017-07-18 00:24:00+03	31400.00
DC1E23	2017-07-15 23:48:00+03	113200.00
DC1E3F	2017-07-09 06:18:00+03	30200.00
DC1E52	2017-07-02 10:02:00+03	28000.00
DC1EB0	2017-07-26 02:25:00+03	59800.00
DC1F51	2017-07-30 04:15:00+03	65100.00
DC1F55	2017-07-21 02:21:00+03	56000.00
DC1F66	2017-08-02 22:58:00+03	255600.00
DC1FAE	2017-07-31 01:01:00+03	62700.00
DC1FCC	2017-07-27 10:44:00+03	137400.00
DC1FDA	2017-07-27 19:34:00+03	50100.00
DC206C	2017-08-10 05:29:00+03	111900.00
DC2090	2017-07-03 21:54:00+03	48500.00
DC20BC	2017-07-24 17:50:00+03	40400.00
DC2100	2017-06-29 02:29:00+03	14700.00
DC21A8	2017-07-30 19:16:00+03	75300.00
DC226D	2017-07-14 08:52:00+03	51600.00
DC227A	2017-07-30 03:45:00+03	381400.00
DC22EF	2017-07-29 16:43:00+03	58700.00
DC239B	2017-07-15 06:23:00+03	56100.00
DC23A1	2017-07-18 10:30:00+03	134400.00
DC23D1	2017-07-24 15:04:00+03	111600.00
DC2452	2017-07-28 00:11:00+03	147700.00
DC245E	2017-08-10 12:00:00+03	77600.00
DC24E5	2017-08-12 13:58:00+03	31100.00
DC2502	2017-08-12 13:44:00+03	52000.00
DC253E	2017-08-12 01:19:00+03	40000.00
DC2547	2017-07-13 09:40:00+03	86300.00
DC2566	2017-07-07 09:09:00+03	34000.00
DC258C	2017-07-27 12:45:00+03	258400.00
DC2597	2017-07-29 22:10:00+03	97400.00
DC25BD	2017-07-23 05:04:00+03	155600.00
DC2647	2017-07-23 09:49:00+03	12600.00
DC2648	2017-07-18 09:23:00+03	112000.00
DC266A	2017-08-13 06:59:00+03	28800.00
DC2684	2017-07-23 18:51:00+03	114500.00
DC268C	2017-07-29 12:31:00+03	132800.00
DC26A1	2017-08-09 11:53:00+03	33300.00
DC2715	2017-08-07 22:29:00+03	47200.00
DC271E	2017-08-05 11:44:00+03	6000.00
DC2736	2017-08-10 12:42:00+03	8000.00
DC27A4	2017-07-21 03:55:00+03	79900.00
DC27B0	2017-06-27 12:13:00+03	53800.00
DC27DF	2017-08-03 03:17:00+03	56100.00
DC27FD	2017-07-05 13:40:00+03	62600.00
DC27FF	2017-08-08 21:59:00+03	271200.00
DC2852	2017-07-23 21:43:00+03	90400.00
DC285B	2017-07-11 07:16:00+03	133200.00
DC2881	2017-07-09 08:37:00+03	15000.00
DC289C	2017-08-07 18:24:00+03	115900.00
DC28A3	2017-07-16 05:11:00+03	46400.00
DC28F7	2017-07-06 10:55:00+03	193200.00
DC2962	2017-07-07 16:50:00+03	66600.00
DC29BD	2017-07-09 09:19:00+03	70700.00
DC2A01	2017-07-10 15:31:00+03	42800.00
DC2A20	2017-08-04 15:24:00+03	95100.00
DC2A2F	2017-07-30 06:06:00+03	44500.00
DC2A4C	2017-07-05 09:44:00+03	123000.00
DC2A6E	2017-07-22 01:01:00+03	123000.00
DC2B06	2017-07-27 12:01:00+03	18600.00
DC2B09	2017-08-14 14:15:00+03	56000.00
DC2B74	2017-08-01 04:23:00+03	44800.00
DC2BC5	2017-07-16 17:27:00+03	28800.00
DC2C22	2017-08-09 16:59:00+03	77000.00
DC2C2A	2017-07-28 09:06:00+03	46000.00
DC2C32	2017-08-07 11:05:00+03	51900.00
DC2C67	2017-07-02 13:10:00+03	56000.00
DC2C68	2017-07-21 12:51:00+03	43400.00
DC2CC1	2017-07-09 08:39:00+03	133100.00
DC2CD0	2017-08-01 15:47:00+03	89200.00
DC2D15	2017-08-05 03:09:00+03	404300.00
DC2DF2	2017-07-14 08:01:00+03	26000.00
DC2E19	2017-08-08 01:19:00+03	26800.00
DC2E23	2017-08-14 15:14:00+03	52100.00
DC2EB4	2017-07-31 04:44:00+03	32700.00
DC2EE6	2017-07-01 19:55:00+03	88100.00
DC2F10	2017-08-02 04:59:00+03	105900.00
DC2F11	2017-07-23 07:51:00+03	62000.00
DC2F54	2017-07-26 07:26:00+03	112000.00
DC2F96	2017-07-24 02:33:00+03	7400.00
DC2FBA	2017-08-14 02:31:00+03	22200.00
DC2FE4	2017-08-10 11:49:00+03	44000.00
DC301A	2017-08-10 07:00:00+03	96300.00
DC3071	2017-08-15 06:22:00+03	60400.00
DC30B6	2017-07-23 08:37:00+03	56000.00
DC30F8	2017-08-01 21:03:00+03	93800.00
DC315C	2017-07-28 14:41:00+03	145100.00
DC315E	2017-07-20 23:12:00+03	35600.00
DC316A	2017-06-28 23:09:00+03	8000.00
DC316D	2017-07-06 10:56:00+03	47500.00
DC31A6	2017-07-18 07:42:00+03	249100.00
DC3252	2017-07-06 10:01:00+03	69500.00
DC3258	2017-07-10 10:00:00+03	92600.00
DC325F	2017-07-10 23:15:00+03	85600.00
DC32BA	2017-07-12 00:33:00+03	78600.00
DC3307	2017-07-25 19:54:00+03	25600.00
DC3335	2017-08-08 10:53:00+03	31900.00
DC3396	2017-07-13 18:15:00+03	48300.00
DC33D9	2017-07-28 06:28:00+03	24800.00
DC3442	2017-08-02 05:33:00+03	135600.00
DC345C	2017-07-23 19:28:00+03	22600.00
DC34A6	2017-08-11 09:13:00+03	378700.00
DC34B7	2017-07-11 01:37:00+03	28800.00
DC34D0	2017-08-06 23:35:00+03	34600.00
DC3570	2017-07-27 18:54:00+03	58000.00
DC3642	2017-07-20 20:57:00+03	48500.00
DC369E	2017-07-04 12:25:00+03	135400.00
DC3744	2017-08-10 04:01:00+03	131600.00
DC374D	2017-08-06 17:15:00+03	270800.00
DC37A8	2017-07-03 09:40:00+03	42400.00
DC37DD	2017-07-30 11:44:00+03	54500.00
DC38AC	2017-07-04 10:09:00+03	65900.00
DC39D5	2017-08-14 18:45:00+03	50600.00
DC3A0F	2017-07-20 11:02:00+03	31000.00
DC3AB9	2017-08-06 12:00:00+03	25200.00
DC3AC6	2017-07-09 05:30:00+03	26000.00
DC3AEF	2017-07-25 19:12:00+03	28800.00
DC3B14	2017-08-14 13:07:00+03	12600.00
DC3BAC	2017-07-24 15:51:00+03	80000.00
DC3CA3	2017-08-07 14:43:00+03	68800.00
DC3CC5	2017-08-05 15:51:00+03	102200.00
DC3D73	2017-08-12 21:07:00+03	29000.00
DC3DAA	2017-07-27 19:07:00+03	97900.00
DC3E26	2017-07-13 17:48:00+03	126800.00
DC3E35	2017-08-13 06:59:00+03	51900.00
DC3E78	2017-07-20 18:29:00+03	393800.00
DC3E8C	2017-07-20 12:23:00+03	133100.00
DC3EA1	2017-07-23 18:45:00+03	46000.00
DC3EF0	2017-07-13 03:32:00+03	30200.00
DC3F2E	2017-08-07 20:08:00+03	101200.00
DC3F53	2017-07-24 08:22:00+03	156300.00
DC3F8D	2017-07-18 00:26:00+03	57700.00
DC3F8E	2017-07-10 09:40:00+03	40000.00
DC3FE7	2017-08-06 18:14:00+03	23200.00
DC3FFC	2017-07-17 16:15:00+03	61800.00
DC3FFD	2017-07-23 06:40:00+03	105900.00
DC4011	2017-08-15 05:35:00+03	167400.00
DC4015	2017-07-26 04:29:00+03	31900.00
DC404C	2017-07-05 16:19:00+03	132800.00
DC40C2	2017-07-21 00:55:00+03	67300.00
DC417A	2017-07-05 03:34:00+03	55800.00
DC41C4	2017-07-24 02:52:00+03	186900.00
DC41C7	2017-08-03 22:50:00+03	46400.00
DC41EB	2017-06-30 20:21:00+03	30200.00
DC42F6	2017-07-15 05:42:00+03	227200.00
DC4304	2017-07-01 08:20:00+03	59200.00
DC4325	2017-07-06 06:38:00+03	117500.00
DC4331	2017-07-10 12:07:00+03	49800.00
DC4467	2017-07-19 06:38:00+03	74800.00
DC4468	2017-08-01 10:27:00+03	56000.00
DC44DC	2017-08-09 00:37:00+03	184300.00
DC44DF	2017-07-12 08:58:00+03	46300.00
DC44FF	2017-08-04 16:52:00+03	154500.00
DC450F	2017-07-20 10:16:00+03	93700.00
DC4525	2017-08-06 15:54:00+03	208500.00
DC45E8	2017-07-01 19:02:00+03	32900.00
DC45F5	2017-07-14 03:32:00+03	24800.00
DC4676	2017-08-10 19:33:00+03	28800.00
DC46E9	2017-08-06 12:29:00+03	185000.00
DC46F7	2017-07-15 16:25:00+03	27200.00
DC471D	2017-08-14 09:02:00+03	179200.00
DC47CB	2017-08-04 14:07:00+03	92900.00
DC4842	2017-08-08 05:39:00+03	154400.00
DC4879	2017-08-05 04:48:00+03	21000.00
DC4889	2017-07-15 07:24:00+03	6300.00
DC48C3	2017-07-15 16:05:00+03	35200.00
DC48CE	2017-08-09 21:58:00+03	312600.00
DC4909	2017-08-04 14:22:00+03	229900.00
DC492D	2017-08-04 22:26:00+03	36800.00
DC49BE	2017-08-11 23:33:00+03	27600.00
DC4A14	2017-07-12 21:37:00+03	92400.00
DC4A1A	2017-08-09 01:36:00+03	134700.00
DC4A42	2017-07-07 22:45:00+03	21800.00
DC4A53	2017-08-12 08:05:00+03	40400.00
DC4A54	2017-07-10 23:18:00+03	45600.00
DC4B02	2017-07-26 04:06:00+03	28000.00
DC4B03	2017-07-20 16:03:00+03	28000.00
DC4B28	2017-07-22 06:32:00+03	64700.00
DC4B43	2017-07-25 10:38:00+03	25400.00
DC4B6D	2017-07-25 09:42:00+03	291700.00
DC4BCD	2017-07-20 18:21:00+03	81700.00
DC4C0F	2017-07-14 18:45:00+03	111600.00
DC4C27	2017-07-17 18:48:00+03	68400.00
DC4CD1	2017-07-24 17:40:00+03	73500.00
DC4CDB	2017-07-15 02:53:00+03	25100.00
DC4CF9	2017-08-10 00:22:00+03	48800.00
DC4D16	2017-06-28 21:19:00+03	132800.00
DC4D36	2017-08-08 14:38:00+03	68800.00
DC4DA0	2017-07-17 23:20:00+03	82200.00
DC4DB0	2017-07-22 23:44:00+03	8200.00
DC4DBC	2017-07-21 04:25:00+03	97700.00
DC4DC6	2017-08-13 20:10:00+03	273600.00
DC4DCF	2017-07-18 03:04:00+03	57500.00
DC4E73	2017-07-19 18:58:00+03	28800.00
DC4F21	2017-07-07 22:22:00+03	393600.00
DC4F9B	2017-07-05 07:01:00+03	148200.00
DC4FC6	2017-08-07 08:15:00+03	170000.00
DC5040	2017-08-07 23:07:00+03	55800.00
DC5045	2017-08-02 08:30:00+03	111500.00
DC5066	2017-08-15 12:15:00+03	65700.00
DC508A	2017-08-14 18:23:00+03	28800.00
DC50F1	2017-08-09 16:18:00+03	47400.00
DC5106	2017-07-29 04:13:00+03	78100.00
DC5136	2017-07-25 16:25:00+03	119500.00
DC515C	2017-07-15 18:40:00+03	40700.00
DC51B5	2017-07-30 01:39:00+03	133200.00
DC51DB	2017-07-29 23:48:00+03	47100.00
DC51E4	2017-07-31 08:39:00+03	44000.00
DC5246	2017-07-06 15:00:00+03	24400.00
DC5251	2017-07-28 21:16:00+03	46200.00
DC5262	2017-07-05 11:03:00+03	94000.00
DC529D	2017-07-08 12:03:00+03	46300.00
DC52B0	2017-07-22 09:42:00+03	42700.00
DC52ED	2017-07-26 11:24:00+03	113200.00
DC5361	2017-07-15 19:51:00+03	115600.00
DC537D	2017-08-10 04:10:00+03	25400.00
DC5442	2017-07-10 08:25:00+03	18100.00
DC5456	2017-07-01 23:23:00+03	273000.00
DC548B	2017-07-21 00:23:00+03	67800.00
DC54BF	2017-07-05 12:02:00+03	105000.00
DC54E1	2017-07-28 17:59:00+03	46400.00
DC5542	2017-07-19 00:54:00+03	58800.00
DC5549	2017-08-14 11:36:00+03	82000.00
DC554D	2017-08-03 14:45:00+03	34000.00
DC5591	2017-07-04 18:37:00+03	16400.00
DC5599	2017-08-12 23:33:00+03	96800.00
DC55C1	2017-07-04 11:30:00+03	202300.00
DC5612	2017-07-09 01:43:00+03	62900.00
DC5616	2017-08-11 02:00:00+03	262900.00
DC562C	2017-07-20 08:07:00+03	31600.00
DC563A	2017-08-14 11:05:00+03	45200.00
DC5645	2017-08-12 15:47:00+03	372500.00
DC566B	2017-08-02 04:58:00+03	42900.00
DC5686	2017-08-09 21:26:00+03	8400.00
DC569D	2017-07-03 22:59:00+03	18600.00
DC56FD	2017-07-14 13:56:00+03	68800.00
DC5716	2017-07-20 12:49:00+03	99200.00
DC57EB	2017-07-09 19:00:00+03	15900.00
DC5872	2017-07-05 22:45:00+03	131100.00
DC58F6	2017-07-14 03:29:00+03	23600.00
DC5943	2017-07-02 16:44:00+03	77200.00
DC5958	2017-06-29 16:57:00+03	56000.00
DC5967	2017-07-25 23:44:00+03	55600.00
DC5A1F	2017-08-10 12:57:00+03	98400.00
DC5B31	2017-07-28 04:22:00+03	59200.00
DC5B75	2017-07-27 23:51:00+03	25800.00
DC5B83	2017-07-06 18:14:00+03	21000.00
DC5C3F	2017-07-14 11:46:00+03	45600.00
DC5CBA	2017-07-13 07:43:00+03	83000.00
DC5CE5	2017-07-28 17:49:00+03	16400.00
DC5D30	2017-07-27 10:36:00+03	83700.00
DC5DBA	2017-06-30 10:09:00+03	106400.00
DC5E2D	2017-08-10 17:49:00+03	53100.00
DC5E39	2017-08-07 01:22:00+03	93500.00
DC5EE6	2017-07-17 20:21:00+03	13600.00
DC5EEF	2017-08-02 16:00:00+03	48800.00
DC5F13	2017-08-02 07:14:00+03	44500.00
DC5F16	2017-07-31 02:08:00+03	35600.00
DC5F1A	2017-07-13 13:55:00+03	67400.00
DC5F24	2017-07-17 10:13:00+03	69400.00
DC5F3A	2017-07-25 05:14:00+03	112600.00
DC5F65	2017-07-12 07:15:00+03	75300.00
DC5F94	2017-07-05 01:29:00+03	28000.00
DC5FCF	2017-07-15 08:07:00+03	46400.00
DC5FD6	2017-08-09 05:57:00+03	47400.00
DC6067	2017-07-12 08:25:00+03	246000.00
DC607A	2017-07-02 19:43:00+03	82300.00
DC613A	2017-08-10 14:44:00+03	14000.00
DC616C	2017-07-17 14:21:00+03	23400.00
DC6175	2017-07-25 10:34:00+03	85000.00
DC6197	2017-07-07 20:22:00+03	42200.00
DC61E6	2017-08-12 10:46:00+03	56000.00
DC61ED	2017-08-12 09:48:00+03	66000.00
DC6210	2017-07-16 04:54:00+03	65900.00
DC6273	2017-08-09 07:45:00+03	19600.00
DC6285	2017-07-09 15:23:00+03	126000.00
DC62C5	2017-07-04 04:48:00+03	56900.00
DC62C6	2017-07-29 19:24:00+03	67900.00
DC6345	2017-06-28 02:41:00+03	34000.00
DC644E	2017-07-13 19:40:00+03	59800.00
DC64A6	2017-08-08 11:48:00+03	32700.00
DC6567	2017-08-08 01:24:00+03	90400.00
DC65DD	2017-08-11 06:06:00+03	38800.00
DC660C	2017-07-25 18:36:00+03	37700.00
DC6654	2017-07-07 06:08:00+03	9200.00
DC6784	2017-07-24 04:45:00+03	49600.00
DC6788	2017-08-08 17:15:00+03	45100.00
DC67E5	2017-08-06 08:37:00+03	52900.00
DC686D	2017-07-13 20:16:00+03	27300.00
DC689F	2017-07-15 16:02:00+03	117600.00
DC68A1	2017-08-05 12:14:00+03	62900.00
DC68CD	2017-07-25 22:54:00+03	28800.00
DC68FF	2017-08-12 21:08:00+03	46400.00
DC6920	2017-07-04 18:07:00+03	157600.00
DC6924	2017-07-22 22:06:00+03	94200.00
DC6946	2017-07-20 12:48:00+03	83000.00
DC696D	2017-08-08 00:32:00+03	47400.00
DC69F4	2017-07-09 18:05:00+03	14000.00
DC6A26	2017-07-23 05:03:00+03	88800.00
DC6A60	2017-08-10 00:10:00+03	14400.00
DC6A75	2017-07-16 14:41:00+03	16400.00
DC6ADD	2017-07-30 23:24:00+03	28000.00
DC6B96	2017-08-06 21:28:00+03	125700.00
DC6BC7	2017-07-24 20:10:00+03	93600.00
DC6BC8	2017-07-04 03:31:00+03	111600.00
DC6BDF	2017-08-13 19:01:00+03	105000.00
DC6BE6	2017-07-24 22:06:00+03	6000.00
DC6BFF	2017-07-10 23:53:00+03	18800.00
DC6CF8	2017-08-02 21:40:00+03	54000.00
DC6DC6	2017-08-08 04:52:00+03	40600.00
DC6DE8	2017-08-12 02:55:00+03	132700.00
DC6DEE	2017-08-14 12:24:00+03	82500.00
DC6E24	2017-08-06 10:49:00+03	6300.00
DC6E32	2017-07-30 08:59:00+03	23600.00
DC6ECE	2017-07-16 14:14:00+03	100600.00
DC6ED6	2017-07-21 17:51:00+03	28800.00
DC6F8F	2017-07-01 21:19:00+03	254900.00
DC6FC5	2017-07-15 19:45:00+03	21400.00
DC6FD0	2017-08-08 21:58:00+03	116800.00
DC7015	2017-07-14 20:02:00+03	66600.00
DC701F	2017-07-30 17:20:00+03	19600.00
DC7058	2017-08-06 15:33:00+03	18600.00
DC709B	2017-07-13 22:50:00+03	46400.00
DC70A9	2017-08-02 08:46:00+03	31600.00
DC70CB	2017-08-15 12:47:00+03	62300.00
DC717F	2017-07-18 16:49:00+03	123000.00
DC720D	2017-07-14 18:45:00+03	27300.00
DC7238	2017-07-14 02:50:00+03	26600.00
DC723D	2017-07-25 21:15:00+03	56100.00
DC7265	2017-08-11 05:57:00+03	112700.00
DC7310	2017-08-02 16:31:00+03	47300.00
DC7311	2017-07-11 01:59:00+03	29600.00
DC733C	2017-07-05 16:13:00+03	69500.00
DC7380	2017-08-14 23:27:00+03	26000.00
DC73B7	2017-08-12 04:55:00+03	149000.00
DC73C0	2017-07-26 10:52:00+03	60400.00
DC74A7	2017-07-23 12:03:00+03	68800.00
DC74E3	2017-07-03 18:39:00+03	84000.00
DC74F9	2017-07-05 00:01:00+03	225200.00
DC756B	2017-06-30 10:29:00+03	40600.00
DC7577	2017-08-02 08:14:00+03	201800.00
DC7608	2017-07-11 09:39:00+03	46400.00
DC760A	2017-07-06 03:37:00+03	34200.00
DC764E	2017-07-18 10:02:00+03	56000.00
DC7662	2017-07-30 14:57:00+03	13400.00
DC76C8	2017-07-21 02:11:00+03	115700.00
DC7715	2017-07-04 21:28:00+03	48000.00
DC771A	2017-07-28 19:29:00+03	48000.00
DC7728	2017-07-26 06:18:00+03	36200.00
DC7747	2017-08-09 19:33:00+03	43600.00
DC778B	2017-07-22 18:02:00+03	52400.00
DC77E6	2017-07-17 03:01:00+03	133200.00
DC77F2	2017-07-04 21:13:00+03	25300.00
DC781B	2017-08-08 01:22:00+03	51000.00
DC787A	2017-07-07 19:30:00+03	58100.00
DC78A7	2017-08-04 20:08:00+03	246000.00
DC78F9	2017-07-26 18:56:00+03	133200.00
DC7915	2017-07-10 13:43:00+03	29500.00
DC7952	2017-07-28 03:33:00+03	60300.00
DC7953	2017-08-13 00:37:00+03	65200.00
DC79A2	2017-07-14 06:24:00+03	31600.00
DC79BD	2017-07-08 09:45:00+03	34000.00
DC7AAB	2017-07-19 08:28:00+03	111700.00
DC7B20	2017-07-09 02:51:00+03	155600.00
DC7BB0	2017-08-13 16:54:00+03	175300.00
DC7BDB	2017-07-25 16:12:00+03	47200.00
DC7C38	2017-07-14 15:25:00+03	22000.00
DC7C3F	2017-07-26 18:43:00+03	6800.00
DC7C81	2017-07-06 20:12:00+03	28800.00
DC7CD0	2017-07-26 15:16:00+03	67900.00
DC7CE0	2017-07-16 22:58:00+03	47000.00
DC7CF4	2017-07-08 22:41:00+03	11600.00
DC7CFA	2017-07-22 16:47:00+03	28000.00
DC7D70	2017-07-11 05:19:00+03	45600.00
DC7DD2	2017-08-12 13:18:00+03	8000.00
DC7E1D	2017-07-12 21:10:00+03	46400.00
DC7E20	2017-07-22 14:11:00+03	77900.00
DC7E28	2017-07-18 06:34:00+03	16400.00
DC7E5C	2017-07-08 17:45:00+03	53300.00
DC7E85	2017-07-15 05:39:00+03	26000.00
DC7E99	2017-07-12 01:58:00+03	61800.00
DC7EE6	2017-07-19 14:36:00+03	26500.00
DC7EEF	2017-07-10 09:20:00+03	19600.00
DC7EFA	2017-08-12 00:15:00+03	223200.00
DC7F29	2017-07-16 08:37:00+03	188000.00
DC7F62	2017-08-08 13:04:00+03	138000.00
DC7FB7	2017-08-03 02:32:00+03	79900.00
DC8012	2017-08-02 08:22:00+03	68100.00
DC801D	2017-07-29 17:19:00+03	40800.00
DC8040	2017-07-12 15:14:00+03	78300.00
DC808C	2017-08-05 20:39:00+03	45100.00
DC80CA	2017-07-19 00:23:00+03	51600.00
DC8206	2017-07-06 20:52:00+03	58600.00
DC82F3	2017-08-07 04:19:00+03	56100.00
DC83AE	2017-07-03 16:35:00+03	42700.00
DC83C8	2017-07-21 20:55:00+03	28000.00
DC842D	2017-08-11 23:30:00+03	23200.00
DC84BA	2017-07-24 07:23:00+03	97700.00
DC8571	2017-07-03 13:51:00+03	57400.00
DC8596	2017-08-11 22:41:00+03	29100.00
DC85FA	2017-08-13 22:49:00+03	37000.00
DC8627	2017-08-14 21:50:00+03	43000.00
DC8637	2017-07-03 14:56:00+03	48500.00
DC866E	2017-07-08 09:38:00+03	200500.00
DC869E	2017-07-03 06:18:00+03	52600.00
DC86CA	2017-07-11 03:48:00+03	77000.00
DC86DD	2017-08-14 03:17:00+03	25900.00
DC8708	2017-08-06 04:42:00+03	260300.00
DC8791	2017-07-23 12:59:00+03	28800.00
DC87B9	2017-06-28 14:54:00+03	13200.00
DC8828	2017-08-09 07:10:00+03	85600.00
DC88AF	2017-07-18 18:24:00+03	46000.00
DC88B3	2017-07-07 11:55:00+03	131600.00
DC88C1	2017-08-13 05:07:00+03	128800.00
DC8915	2017-07-18 08:02:00+03	136500.00
DC8933	2017-07-03 06:22:00+03	21400.00
DC8937	2017-07-29 08:55:00+03	155500.00
DC893F	2017-07-07 12:01:00+03	177700.00
DC896D	2017-07-15 09:11:00+03	73500.00
DC8989	2017-07-11 15:57:00+03	43400.00
DC8A15	2017-07-10 23:46:00+03	63000.00
DC8A52	2017-08-15 14:00:00+03	162200.00
DC8A62	2017-08-13 17:22:00+03	40600.00
DC8B83	2017-08-07 04:04:00+03	40800.00
DC8BE8	2017-07-05 04:54:00+03	99700.00
DC8BF5	2017-07-03 04:15:00+03	15700.00
DC8C15	2017-07-16 20:53:00+03	11600.00
DC8C24	2017-07-14 13:24:00+03	6400.00
DC8C41	2017-06-29 15:59:00+03	37200.00
DC8C53	2017-07-31 05:41:00+03	97700.00
DC8C6C	2017-07-14 01:29:00+03	28200.00
DC8C6E	2017-07-06 20:15:00+03	56600.00
DC8C8F	2017-08-10 09:02:00+03	132800.00
DC8C95	2017-07-31 13:13:00+03	23200.00
DC8CF3	2017-07-29 11:49:00+03	62600.00
DC8DA1	2017-08-11 09:21:00+03	4100.00
DC8DBC	2017-08-04 11:35:00+03	81200.00
DC8DD4	2017-07-22 18:12:00+03	157000.00
DC8DE1	2017-08-05 14:56:00+03	140300.00
DC8E60	2017-07-20 16:38:00+03	46900.00
DC8E66	2017-07-05 01:20:00+03	133200.00
DC8EAB	2017-07-10 13:42:00+03	28000.00
DC8EDF	2017-07-02 15:03:00+03	65600.00
DC8F15	2017-07-23 05:06:00+03	85000.00
DC8F4C	2017-08-13 07:57:00+03	47000.00
DC8FB6	2017-08-10 10:50:00+03	39400.00
DC9020	2017-07-16 04:57:00+03	35600.00
DC90CA	2017-07-11 02:00:00+03	42400.00
DC917F	2017-07-29 22:10:00+03	153300.00
DC9210	2017-08-03 00:07:00+03	59200.00
DC9227	2017-07-07 17:48:00+03	21000.00
DC925A	2017-08-11 21:55:00+03	48800.00
DC9266	2017-08-06 10:58:00+03	24400.00
DC9328	2017-07-12 04:20:00+03	62100.00
DC9356	2017-07-25 23:00:00+03	155600.00
DC935B	2017-07-29 15:00:00+03	27200.00
DC9360	2017-07-13 11:42:00+03	38600.00
DC9368	2017-06-29 08:44:00+03	229400.00
DC946F	2017-08-02 22:33:00+03	38400.00
DC9473	2017-07-05 11:13:00+03	117200.00
DC9511	2017-08-10 10:02:00+03	26700.00
DC95BE	2017-07-20 00:33:00+03	196800.00
DC967E	2017-08-14 11:11:00+03	169900.00
DC968D	2017-07-01 05:31:00+03	21400.00
DC96C4	2017-08-12 17:53:00+03	12600.00
DC96D1	2017-07-22 06:38:00+03	54800.00
DC96D8	2017-08-06 02:44:00+03	46200.00
DC96E1	2017-07-21 16:22:00+03	32200.00
DC970A	2017-07-14 09:44:00+03	30000.00
DC9796	2017-08-08 04:37:00+03	56000.00
DC97A2	2017-08-09 14:58:00+03	34600.00
DC97DE	2017-08-05 12:32:00+03	203900.00
DC9823	2017-07-04 18:39:00+03	23600.00
DC9906	2017-08-04 20:44:00+03	7400.00
DC9946	2017-07-20 07:20:00+03	40200.00
DC9973	2017-08-05 04:12:00+03	54800.00
DC99A5	2017-08-13 23:47:00+03	23600.00
DC99E9	2017-08-09 19:50:00+03	83000.00
DC9A3E	2017-07-26 20:57:00+03	62600.00
DC9A77	2017-07-22 02:57:00+03	30800.00
DC9AC9	2017-07-21 16:56:00+03	47700.00
DC9AD2	2017-07-23 01:09:00+03	27200.00
DC9AFB	2017-08-06 00:51:00+03	59300.00
DC9B1C	2017-07-06 02:32:00+03	49200.00
DC9B5D	2017-08-10 02:32:00+03	60400.00
DC9B7A	2017-08-14 18:25:00+03	18600.00
DC9B7B	2017-07-19 11:59:00+03	139300.00
DC9BA9	2017-07-17 13:09:00+03	13600.00
DC9C4E	2017-08-07 14:23:00+03	73600.00
DC9C5C	2017-07-31 15:06:00+03	66600.00
DC9C60	2017-07-26 06:12:00+03	240600.00
DC9C78	2017-07-03 11:38:00+03	50800.00
DC9CA1	2017-07-01 04:51:00+03	128800.00
DC9D09	2017-07-04 03:37:00+03	26000.00
DC9D98	2017-07-05 07:18:00+03	130300.00
DC9DC5	2017-07-11 21:17:00+03	131100.00
DC9E33	2017-07-10 20:54:00+03	14400.00
DC9E63	2017-07-10 12:57:00+03	99200.00
DC9F01	2017-08-03 17:18:00+03	135200.00
DC9F20	2017-08-12 18:27:00+03	48800.00
DC9F3F	2017-08-11 13:51:00+03	290300.00
DC9F4A	2017-07-23 06:17:00+03	393000.00
DC9F4F	2017-07-08 23:34:00+03	44800.00
DC9F67	2017-07-20 01:30:00+03	266200.00
DC9F7A	2017-08-04 08:04:00+03	78700.00
DC9FC6	2017-07-18 21:02:00+03	52800.00
DC9FDD	2017-07-22 23:59:00+03	88900.00
DCA0B1	2017-07-17 01:42:00+03	68000.00
DCA171	2017-07-30 03:46:00+03	126400.00
DCA1A5	2017-07-07 15:02:00+03	45200.00
DCA1E5	2017-08-09 10:29:00+03	46400.00
DCA21F	2017-07-16 22:49:00+03	14000.00
DCA270	2017-07-18 19:12:00+03	43200.00
DCA376	2017-08-05 01:13:00+03	29600.00
DCA382	2017-07-09 08:54:00+03	18600.00
DCA3C6	2017-07-10 05:08:00+03	23200.00
DCA486	2017-07-31 00:15:00+03	186200.00
DCA4BF	2017-07-23 03:32:00+03	59100.00
DCA4FB	2017-07-15 03:23:00+03	54400.00
DCA505	2017-07-26 23:17:00+03	58200.00
DCA50A	2017-07-16 07:09:00+03	106800.00
DCA52C	2017-07-03 09:01:00+03	283100.00
DCA565	2017-08-03 01:48:00+03	12600.00
DCA5A8	2017-07-11 07:35:00+03	87100.00
DCA5AA	2017-08-02 17:07:00+03	13400.00
DCA5DD	2017-08-13 14:20:00+03	24600.00
DCA60D	2017-08-13 11:08:00+03	34000.00
DCA637	2017-06-30 03:18:00+03	28800.00
DCA63F	2017-08-01 07:42:00+03	55800.00
DCA665	2017-08-14 19:58:00+03	54000.00
DCA6FB	2017-07-12 21:04:00+03	49900.00
DCA71E	2017-07-05 02:35:00+03	46500.00
DCA78D	2017-07-31 17:40:00+03	54800.00
DCA83D	2017-07-13 16:51:00+03	27300.00
DCA853	2017-07-25 06:50:00+03	46400.00
DCA858	2017-07-23 16:36:00+03	112600.00
DCA870	2017-08-15 08:42:00+03	72400.00
DCA875	2017-08-11 17:15:00+03	38400.00
DCA89E	2017-07-05 10:54:00+03	657200.00
DCA8BC	2017-08-01 13:05:00+03	13400.00
DCA903	2017-07-28 06:24:00+03	78300.00
DCA90C	2017-07-16 02:26:00+03	60800.00
DCA911	2017-07-08 12:51:00+03	99200.00
DCA92C	2017-07-23 20:14:00+03	42400.00
DCA967	2017-07-17 15:20:00+03	186900.00
DCA9A0	2017-07-13 02:22:00+03	22000.00
DCA9AE	2017-08-14 11:57:00+03	266500.00
DCA9E6	2017-07-25 11:23:00+03	101200.00
DCAA11	2017-07-15 16:07:00+03	25200.00
DCAA5A	2017-07-28 17:42:00+03	37700.00
DCAA67	2017-07-22 14:15:00+03	67600.00
DCAA78	2017-07-14 05:43:00+03	14400.00
DCAA87	2017-07-14 09:49:00+03	58800.00
DCAAFE	2017-07-16 03:52:00+03	128800.00
DCAB16	2017-07-31 20:20:00+03	30200.00
DCAB73	2017-07-16 19:13:00+03	26800.00
DCAB8A	2017-07-08 11:12:00+03	23600.00
DCABD2	2017-07-16 00:54:00+03	41800.00
DCAC01	2017-07-22 04:57:00+03	68800.00
DCAC09	2017-08-03 12:13:00+03	27300.00
DCAC30	2017-07-13 19:30:00+03	101900.00
DCAC99	2017-08-02 04:20:00+03	13200.00
DCACA1	2017-06-30 23:22:00+03	28000.00
DCAD01	2017-07-06 15:22:00+03	43300.00
DCAD72	2017-07-02 05:19:00+03	17200.00
DCADB6	2017-08-08 00:20:00+03	52900.00
DCAE00	2017-07-11 11:50:00+03	95200.00
DCAE07	2017-08-09 11:11:00+03	70200.00
DCAE18	2017-07-12 12:06:00+03	82500.00
DCAE44	2017-07-25 03:48:00+03	27200.00
DCAE64	2017-08-14 12:30:00+03	69000.00
DCAE84	2017-07-20 06:02:00+03	187600.00
DCAEBF	2017-08-04 19:36:00+03	58600.00
DCAEDC	2017-08-01 13:03:00+03	114700.00
DCAF11	2017-08-02 22:21:00+03	111600.00
DCAF2D	2017-08-03 15:22:00+03	46400.00
DCAF43	2017-07-03 16:39:00+03	57600.00
DCAF51	2017-07-19 02:11:00+03	24400.00
DCAFCD	2017-08-01 05:38:00+03	56000.00
DCAFDD	2017-07-14 15:36:00+03	106400.00
DCB03D	2017-07-06 22:20:00+03	76800.00
DCB062	2017-07-26 12:39:00+03	73300.00
DCB06E	2017-07-29 22:09:00+03	43900.00
DCB081	2017-07-29 15:27:00+03	32700.00
DCB0A2	2017-07-14 07:59:00+03	10800.00
DCB0D4	2017-06-30 07:57:00+03	292800.00
DCB0D7	2017-07-24 07:42:00+03	13700.00
DCB10D	2017-07-21 10:52:00+03	181600.00
DCB145	2017-07-09 03:45:00+03	50100.00
DCB153	2017-08-02 08:44:00+03	85400.00
DCB181	2017-08-04 15:00:00+03	38800.00
DCB1CB	2017-06-30 06:46:00+03	59200.00
DCB1DA	2017-08-09 08:11:00+03	30200.00
DCB20B	2017-07-21 08:45:00+03	28800.00
DCB215	2017-07-04 11:23:00+03	12400.00
DCB2C3	2017-08-05 02:24:00+03	107800.00
DCB2E6	2017-07-24 23:08:00+03	114400.00
DCB2F0	2017-08-12 07:31:00+03	19600.00
DCB2F8	2017-07-22 17:58:00+03	25600.00
DCB330	2017-07-14 08:26:00+03	56000.00
DCB332	2017-07-14 21:20:00+03	26000.00
DCB380	2017-07-11 05:31:00+03	90100.00
DCB3E2	2017-07-18 13:18:00+03	89600.00
DCB3EB	2017-08-06 22:27:00+03	104000.00
DCB417	2017-07-04 14:56:00+03	100600.00
DCB49D	2017-07-15 05:08:00+03	52000.00
DCB4E4	2017-08-04 22:43:00+03	272300.00
DCB514	2017-08-03 20:24:00+03	11600.00
DCB52C	2017-08-10 09:34:00+03	56900.00
DCB54E	2017-08-10 17:11:00+03	413400.00
DCB55E	2017-08-13 23:47:00+03	28800.00
DCB560	2017-07-29 12:46:00+03	112000.00
DCB573	2017-07-07 19:56:00+03	145300.00
DCB649	2017-08-01 03:21:00+03	35300.00
DCB6D0	2017-08-09 06:17:00+03	53600.00
DCB782	2017-08-10 17:00:00+03	12000.00
DCB7FB	2017-07-27 15:52:00+03	34000.00
DCB804	2017-07-14 06:50:00+03	6400.00
DCB826	2017-07-11 21:15:00+03	13700.00
DCB891	2017-07-05 02:00:00+03	47100.00
DCB8F6	2017-07-03 09:18:00+03	90800.00
DCB945	2017-07-12 03:25:00+03	27800.00
DCB97C	2017-07-29 01:04:00+03	167500.00
DCB9C8	2017-08-07 15:00:00+03	51200.00
DCBA1A	2017-07-05 21:31:00+03	70700.00
DCBA29	2017-08-11 21:37:00+03	12000.00
DCBA9A	2017-07-23 13:45:00+03	67200.00
DCBAD6	2017-07-20 17:41:00+03	118300.00
DCBAFC	2017-07-09 00:50:00+03	27300.00
DCBB69	2017-07-23 20:37:00+03	81600.00
DCBB7B	2017-06-30 20:08:00+03	90800.00
DCBBC7	2017-07-28 05:04:00+03	98300.00
DCBBDD	2017-07-11 01:46:00+03	35200.00
DCBBEE	2017-07-19 16:15:00+03	25800.00
DCBC0B	2017-08-08 09:04:00+03	39900.00
DCBC27	2017-07-11 20:52:00+03	64200.00
DCBC6C	2017-08-03 07:56:00+03	30200.00
DCBCB8	2017-07-02 08:43:00+03	118400.00
DCBCBC	2017-07-09 22:52:00+03	153900.00
DCBCDA	2017-08-08 00:45:00+03	24300.00
DCBD56	2017-07-15 17:02:00+03	96800.00
DCBD79	2017-07-14 08:25:00+03	29600.00
DCBDA2	2017-07-30 14:38:00+03	124200.00
DCBDE2	2017-08-13 11:16:00+03	36200.00
DCBDE7	2017-08-03 16:19:00+03	26200.00
DCBE22	2017-07-12 04:47:00+03	62700.00
DCBE2E	2017-07-24 19:54:00+03	28700.00
DCBE42	2017-08-10 11:16:00+03	88800.00
DCBE68	2017-07-28 19:57:00+03	93600.00
DCBF70	2017-07-11 22:08:00+03	46400.00
DCBF83	2017-06-29 03:38:00+03	45400.00
DCBF9A	2017-07-11 23:10:00+03	7200.00
DCBFCC	2017-07-15 08:52:00+03	468000.00
DCC05C	2017-08-06 00:49:00+03	61400.00
DCC0C8	2017-07-20 15:35:00+03	136200.00
DCC109	2017-07-10 06:19:00+03	54400.00
DCC15A	2017-07-24 18:39:00+03	129200.00
DCC253	2017-07-08 05:56:00+03	70400.00
DCC287	2017-06-30 06:35:00+03	82900.00
DCC2A4	2017-07-06 11:23:00+03	82900.00
DCC2D5	2017-07-29 10:44:00+03	57600.00
DCC369	2017-08-13 19:30:00+03	54500.00
DCC383	2017-07-04 10:29:00+03	46400.00
DCC3AF	2017-08-10 04:00:00+03	46000.00
DCC41E	2017-08-01 18:21:00+03	22000.00
DCC423	2017-07-27 10:38:00+03	20200.00
DCC424	2017-08-10 12:47:00+03	87900.00
DCC445	2017-07-22 11:40:00+03	59800.00
DCC483	2017-07-30 19:10:00+03	18000.00
DCC4BB	2017-07-09 14:14:00+03	83600.00
DCC4D6	2017-07-28 16:41:00+03	28800.00
DCC4E5	2017-07-29 23:44:00+03	38900.00
DCC51B	2017-07-30 22:32:00+03	35800.00
DCC520	2017-08-07 09:52:00+03	22000.00
DCC546	2017-08-05 17:05:00+03	6300.00
DCC5B3	2017-07-09 16:43:00+03	300400.00
DCC5BF	2017-08-15 13:53:00+03	73600.00
DCC5FA	2017-07-10 13:05:00+03	32500.00
DCC656	2017-07-23 13:18:00+03	175600.00
DCC6A8	2017-07-28 02:19:00+03	7400.00
DCC6B4	2017-08-14 01:01:00+03	57500.00
DCC726	2017-07-04 00:55:00+03	132800.00
DCC73F	2017-07-28 21:34:00+03	69000.00
DCC7CA	2017-07-26 10:48:00+03	33400.00
DCC7CC	2017-07-29 01:21:00+03	16400.00
DCC862	2017-08-10 04:57:00+03	57600.00
DCC90A	2017-07-30 20:55:00+03	25600.00
DCC916	2017-07-10 13:59:00+03	61400.00
DCC9A0	2017-07-24 18:45:00+03	77900.00
DCC9CE	2017-08-15 05:59:00+03	13400.00
DCC9ED	2017-08-14 08:40:00+03	36500.00
DCCA8C	2017-07-10 09:23:00+03	67200.00
DCCAC4	2017-08-15 11:48:00+03	29200.00
DCCADF	2017-06-29 02:34:00+03	30200.00
DCCAED	2017-07-05 22:13:00+03	97800.00
DCCB14	2017-08-06 15:29:00+03	21400.00
DCCBA8	2017-07-17 00:10:00+03	147000.00
DCCBB5	2017-08-15 17:51:00+03	34200.00
DCCBBB	2017-07-13 01:17:00+03	64400.00
DCCBE2	2017-07-31 11:50:00+03	27800.00
DCCC16	2017-08-12 01:32:00+03	32700.00
DCCC67	2017-07-31 05:26:00+03	135200.00
DCCC88	2017-07-26 06:24:00+03	12600.00
DCCC9E	2017-07-12 02:35:00+03	60400.00
DCCCC6	2017-07-24 10:40:00+03	88500.00
DCCCF8	2017-07-16 08:36:00+03	160100.00
DCCCFF	2017-07-01 11:20:00+03	105600.00
DCCD38	2017-08-14 09:58:00+03	173600.00
DCCE3F	2017-07-29 02:52:00+03	119800.00
DCCE50	2017-07-21 06:30:00+03	25400.00
DCCE95	2017-07-13 21:14:00+03	12600.00
DCCEDD	2017-08-12 08:22:00+03	23400.00
DCCEFD	2017-07-21 14:35:00+03	87000.00
DCCF02	2017-08-13 18:33:00+03	47600.00
DCCF24	2017-07-26 16:28:00+03	86600.00
DCCFF3	2017-08-12 09:47:00+03	132800.00
DCD038	2017-07-10 23:44:00+03	66000.00
DCD054	2017-07-26 14:55:00+03	23600.00
DCD058	2017-07-17 04:29:00+03	58600.00
DCD082	2017-07-15 03:59:00+03	15000.00
DCD0FB	2017-07-30 02:00:00+03	12600.00
DCD10D	2017-07-24 08:37:00+03	81300.00
DCD111	2017-08-03 07:10:00+03	75000.00
DCD135	2017-07-02 12:03:00+03	55800.00
DCD18C	2017-07-22 16:20:00+03	65800.00
DCD1BA	2017-07-21 17:31:00+03	81800.00
DCD218	2017-07-04 01:00:00+03	31600.00
DCD266	2017-07-26 12:02:00+03	6000.00
DCD27C	2017-07-12 17:34:00+03	162700.00
DCD2D3	2017-07-15 21:42:00+03	20400.00
DCD335	2017-08-06 15:03:00+03	6000.00
DCD383	2017-08-12 05:58:00+03	44800.00
DCD43D	2017-08-08 11:12:00+03	22000.00
DCD440	2017-07-04 01:53:00+03	52000.00
DCD47F	2017-08-14 11:28:00+03	68100.00
DCD589	2017-08-02 02:29:00+03	102100.00
DCD657	2017-07-18 05:20:00+03	70800.00
DCD67F	2017-07-07 05:46:00+03	30400.00
DCD680	2017-08-11 16:57:00+03	92800.00
DCD6A8	2017-08-04 04:38:00+03	114800.00
DCD70B	2017-07-20 21:41:00+03	67000.00
DCD7AD	2017-07-25 22:41:00+03	10800.00
DCD7AF	2017-08-11 01:56:00+03	246000.00
DCD7B9	2017-07-14 10:12:00+03	136500.00
DCD88A	2017-07-22 21:25:00+03	123000.00
DCD8B6	2017-07-06 18:02:00+03	29600.00
DCD8BA	2017-08-02 06:53:00+03	54800.00
DCD943	2017-07-28 22:33:00+03	234300.00
DCD95B	2017-07-31 03:16:00+03	42000.00
DCD975	2017-08-01 03:06:00+03	106600.00
DCD98C	2017-07-18 17:51:00+03	92700.00
DCDA00	2017-07-24 16:08:00+03	44800.00
DCDA86	2017-08-15 10:58:00+03	135400.00
DCDA8F	2017-07-26 19:36:00+03	40600.00
DCDB67	2017-08-02 17:25:00+03	162200.00
DCDB69	2017-08-06 06:23:00+03	59800.00
DCDB76	2017-07-30 00:36:00+03	26700.00
DCDB7D	2017-07-23 08:01:00+03	177600.00
DCDC08	2017-08-01 02:57:00+03	35200.00
DCDC22	2017-07-28 09:56:00+03	382000.00
DCDC2B	2017-08-02 16:17:00+03	44800.00
DCDC79	2017-07-11 10:54:00+03	47000.00
DCDC8A	2017-07-07 08:18:00+03	137900.00
DCDC8B	2017-06-27 11:58:00+03	73800.00
DCDCE5	2017-07-23 06:21:00+03	117600.00
DCDDB4	2017-08-03 14:19:00+03	117200.00
DCDE4A	2017-07-28 01:08:00+03	55000.00
DCDE61	2017-08-14 20:02:00+03	28000.00
DCDE62	2017-08-04 16:43:00+03	133200.00
DCDEA2	2017-07-16 11:50:00+03	55200.00
DCDEB6	2017-08-12 22:58:00+03	46400.00
DCDEBD	2017-08-06 01:20:00+03	23200.00
DCDFB0	2017-07-20 16:10:00+03	32900.00
DCDFFF	2017-07-01 17:56:00+03	65900.00
DCE00A	2017-07-08 11:48:00+03	6700.00
DCE0E0	2017-07-29 08:03:00+03	34600.00
DCE143	2017-06-30 08:27:00+03	167500.00
DCE193	2017-07-14 04:41:00+03	46000.00
DCE1FB	2017-07-16 01:04:00+03	72400.00
DCE207	2017-07-29 02:23:00+03	61800.00
DCE232	2017-07-27 19:11:00+03	28000.00
DCE24C	2017-08-15 11:31:00+03	94700.00
DCE278	2017-07-30 13:28:00+03	61800.00
DCE286	2017-07-12 11:49:00+03	31600.00
DCE2D8	2017-07-23 09:32:00+03	59200.00
DCE39E	2017-07-30 08:19:00+03	149300.00
DCE436	2017-08-05 17:25:00+03	38800.00
DCE4A8	2017-08-07 23:32:00+03	29200.00
DCE575	2017-07-26 21:47:00+03	106000.00
DCE5A3	2017-08-09 01:07:00+03	117000.00
DCE5C5	2017-07-27 00:57:00+03	75800.00
DCE66F	2017-07-28 16:31:00+03	32400.00
DCE6C6	2017-08-12 23:53:00+03	30000.00
DCE6EE	2017-08-04 01:35:00+03	28000.00
DCE763	2017-07-23 06:34:00+03	69000.00
DCE790	2017-07-14 22:03:00+03	265600.00
DCE7C0	2017-07-09 07:51:00+03	29400.00
DCE7F4	2017-07-06 07:11:00+03	44000.00
DCE7F5	2017-07-10 23:20:00+03	23200.00
DCE8BC	2017-07-05 08:41:00+03	73600.00
DCE995	2017-07-16 23:54:00+03	21800.00
DCE9B7	2017-08-11 23:33:00+03	89600.00
DCEA04	2017-07-07 19:58:00+03	56600.00
DCEA2C	2017-07-12 16:57:00+03	25000.00
DCEA63	2017-07-14 21:06:00+03	111600.00
DCEA96	2017-07-17 08:39:00+03	72800.00
DCEABC	2017-07-26 12:11:00+03	28000.00
DCEAF0	2017-07-15 15:41:00+03	14000.00
DCEB0D	2017-08-02 02:36:00+03	32200.00
DCEB12	2017-07-28 23:07:00+03	29600.00
DCEB4A	2017-07-06 12:49:00+03	16800.00
DCEB98	2017-07-05 18:56:00+03	17000.00
DCEC1B	2017-07-08 02:23:00+03	246000.00
DCEC25	2017-06-30 22:05:00+03	92000.00
DCEC77	2017-08-13 08:57:00+03	15900.00
DCECA4	2017-07-05 03:32:00+03	32800.00
DCED1E	2017-08-14 09:30:00+03	13400.00
DCED33	2017-07-10 14:21:00+03	410800.00
DCED4D	2017-07-24 11:24:00+03	58600.00
DCED6C	2017-08-13 10:56:00+03	55800.00
DCED90	2017-08-03 00:56:00+03	206400.00
DCEF39	2017-07-15 01:41:00+03	46300.00
DCEF86	2017-07-25 05:51:00+03	117800.00
DCEF96	2017-07-09 18:59:00+03	75800.00
DCEF97	2017-08-13 18:40:00+03	46500.00
DCEFC0	2017-08-15 14:19:00+03	101200.00
DCEFC1	2017-07-28 16:37:00+03	58900.00
DCEFC6	2017-08-11 17:40:00+03	23200.00
DCEFE4	2017-07-27 17:18:00+03	55800.00
DCEFEC	2017-07-22 10:54:00+03	24600.00
DCF099	2017-07-09 04:49:00+03	59300.00
DCF0A2	2017-08-03 22:15:00+03	96400.00
DCF0D3	2017-07-20 20:08:00+03	14400.00
DCF100	2017-08-02 22:27:00+03	21500.00
DCF12C	2017-07-05 14:52:00+03	23200.00
DCF141	2017-07-11 07:55:00+03	84300.00
DCF142	2017-07-07 06:59:00+03	18800.00
DCF177	2017-07-04 22:02:00+03	39000.00
DCF1D2	2017-08-03 06:17:00+03	181400.00
DCF205	2017-08-15 05:40:00+03	422700.00
DCF24C	2017-07-21 02:04:00+03	48800.00
DCF281	2017-08-11 13:40:00+03	83200.00
DCF2D6	2017-08-02 10:38:00+03	132800.00
DCF2DE	2017-07-20 19:44:00+03	136000.00
DCF372	2017-07-18 05:53:00+03	97600.00
DCF38C	2017-07-05 22:01:00+03	31900.00
DCF398	2017-06-29 07:33:00+03	29400.00
DCF3F5	2017-07-13 03:04:00+03	59200.00
DCF407	2017-07-15 10:53:00+03	67400.00
DCF434	2017-08-01 01:40:00+03	12200.00
DCF4A5	2017-07-03 23:56:00+03	63200.00
DCF4B6	2017-07-20 10:15:00+03	17200.00
DCF4C9	2017-07-22 00:51:00+03	23200.00
DCF4D2	2017-08-01 13:47:00+03	200000.00
DCF4DE	2017-07-14 19:32:00+03	12600.00
DCF59F	2017-07-09 10:57:00+03	93600.00
DCF5D0	2017-08-13 05:31:00+03	103000.00
DCF653	2017-08-05 05:08:00+03	57500.00
DCF683	2017-07-30 02:31:00+03	68100.00
DCF699	2017-07-27 20:35:00+03	23600.00
DCF6C0	2017-07-05 14:53:00+03	69900.00
DCF6F0	2017-07-14 12:33:00+03	66600.00
DCF716	2017-07-11 05:52:00+03	47400.00
DCF752	2017-08-13 23:25:00+03	125600.00
DCF762	2017-08-09 08:43:00+03	127100.00
DCF76E	2017-07-02 21:13:00+03	67600.00
DCF7CC	2017-08-01 00:54:00+03	52900.00
DCF824	2017-07-10 03:01:00+03	20200.00
DCF88B	2017-08-09 18:37:00+03	67600.00
DCF8D0	2017-07-10 07:47:00+03	147900.00
DCF93D	2017-07-25 13:32:00+03	115800.00
DCF965	2017-08-09 03:49:00+03	59800.00
DCF988	2017-07-09 04:13:00+03	51300.00
DCF9AF	2017-07-04 00:23:00+03	39200.00
DCF9C1	2017-07-18 23:59:00+03	35300.00
DCF9C2	2017-07-03 02:51:00+03	132800.00
DCF9D7	2017-08-10 17:31:00+03	24400.00
DCFA71	2017-07-04 18:13:00+03	54500.00
DCFA7D	2017-08-08 00:24:00+03	46400.00
DCFAAD	2017-08-09 16:40:00+03	113900.00
DCFB3C	2017-07-30 05:55:00+03	47800.00
DCFB7A	2017-07-06 04:08:00+03	80400.00
DCFBA6	2017-07-07 11:14:00+03	7400.00
DCFBC5	2017-07-27 14:31:00+03	77600.00
DCFBED	2017-07-25 03:28:00+03	94700.00
DCFC57	2017-07-31 10:29:00+03	60400.00
DCFC92	2017-07-11 16:13:00+03	46300.00
DCFD2F	2017-07-20 22:03:00+03	159800.00
DCFD3E	2017-08-07 11:07:00+03	28800.00
DCFD86	2017-07-01 15:00:00+03	23400.00
DCFDD9	2017-08-03 08:12:00+03	91800.00
DCFE02	2017-07-26 20:44:00+03	31400.00
DCFE05	2017-07-02 16:32:00+03	59800.00
DCFE0C	2017-07-23 21:24:00+03	56000.00
DCFE81	2017-07-31 10:34:00+03	45200.00
DCFEB9	2017-07-12 09:20:00+03	277800.00
DCFEC4	2017-08-15 02:43:00+03	52900.00
DCFEE8	2017-07-02 06:48:00+03	29600.00
DCFF60	2017-07-20 18:30:00+03	79400.00
DCFF7A	2017-07-21 15:56:00+03	18000.00
DCFFB1	2017-08-03 12:03:00+03	58600.00
DD001D	2017-07-28 12:15:00+03	15000.00
DD0029	2017-07-20 03:23:00+03	52300.00
DD0095	2017-07-26 05:54:00+03	90300.00
DD00B6	2017-08-01 02:39:00+03	84100.00
DD00CC	2017-08-02 20:20:00+03	11600.00
DD0100	2017-07-14 09:53:00+03	100200.00
DD0109	2017-07-11 01:18:00+03	43000.00
DD0146	2017-07-28 13:19:00+03	185600.00
DD01C6	2017-07-24 08:21:00+03	66600.00
DD01E0	2017-07-29 11:24:00+03	12400.00
DD01EE	2017-08-03 21:02:00+03	31100.00
DD0207	2017-08-09 20:25:00+03	23400.00
DD0246	2017-08-01 15:37:00+03	28000.00
DD0311	2017-07-06 20:49:00+03	33100.00
DD0315	2017-07-12 04:39:00+03	24700.00
DD0339	2017-07-07 06:01:00+03	95700.00
DD033B	2017-08-01 07:40:00+03	23600.00
DD0345	2017-07-16 08:37:00+03	37900.00
DD039F	2017-07-11 15:11:00+03	28700.00
DD03AD	2017-07-30 11:06:00+03	165500.00
DD040B	2017-07-17 13:23:00+03	28000.00
DD0424	2017-07-09 04:55:00+03	57800.00
DD0453	2017-08-13 18:07:00+03	71000.00
DD04B2	2017-07-23 23:07:00+03	131100.00
DD04C7	2017-07-30 10:24:00+03	24700.00
DD04F0	2017-08-01 22:05:00+03	138600.00
DD052A	2017-07-16 09:23:00+03	24200.00
DD0540	2017-07-29 04:51:00+03	34100.00
DD057E	2017-07-07 14:15:00+03	22000.00
DD059C	2017-07-11 08:17:00+03	19600.00
DD05A7	2017-07-29 14:10:00+03	234100.00
DD05BA	2017-08-04 23:26:00+03	28000.00
DD05EA	2017-08-09 01:06:00+03	19600.00
DD05ED	2017-07-20 02:49:00+03	47000.00
DD05F9	2017-07-25 11:29:00+03	20200.00
DD0615	2017-07-06 14:31:00+03	258400.00
DD0649	2017-08-09 18:52:00+03	111600.00
DD0682	2017-07-31 13:14:00+03	92000.00
DD0699	2017-07-05 11:34:00+03	35700.00
DD0719	2017-07-16 16:23:00+03	107100.00
DD074B	2017-08-15 07:07:00+03	166900.00
DD074C	2017-08-02 12:30:00+03	62600.00
DD0775	2017-07-07 07:52:00+03	25600.00
DD07A7	2017-07-04 23:00:00+03	13400.00
DD07C9	2017-07-07 18:18:00+03	26000.00
DD07F6	2017-08-12 03:43:00+03	56000.00
DD08A0	2017-07-31 08:01:00+03	34000.00
DD08B4	2017-08-15 10:54:00+03	103400.00
DD08D6	2017-07-12 10:47:00+03	57600.00
DD0908	2017-07-05 02:57:00+03	24700.00
DD0927	2017-08-10 00:11:00+03	44600.00
DD0959	2017-08-14 02:47:00+03	67600.00
DD09EC	2017-07-21 14:31:00+03	191900.00
DD0A2C	2017-07-30 09:40:00+03	27800.00
DD0A37	2017-07-24 00:44:00+03	22600.00
DD0A53	2017-08-06 05:06:00+03	36200.00
DD0A9B	2017-07-10 18:49:00+03	12600.00
DD0ADE	2017-07-30 19:10:00+03	14000.00
DD0AFB	2017-07-09 19:19:00+03	118900.00
DD0B1D	2017-08-01 05:07:00+03	6300.00
DD0B5D	2017-07-26 01:48:00+03	106600.00
DD0B75	2017-07-04 23:30:00+03	29100.00
DD0C1C	2017-07-31 12:36:00+03	56000.00
DD0C61	2017-08-07 09:25:00+03	55800.00
DD0C82	2017-07-26 01:49:00+03	11700.00
DD0CB8	2017-07-27 17:17:00+03	179400.00
DD0CF7	2017-08-04 05:24:00+03	141600.00
DD0D54	2017-08-09 14:55:00+03	67100.00
DD0D72	2017-08-11 06:52:00+03	34000.00
DD0DB7	2017-07-16 13:57:00+03	88400.00
DD0DC2	2017-07-10 02:25:00+03	16400.00
DD0DCF	2017-07-18 23:18:00+03	31100.00
DD0DD4	2017-07-10 21:16:00+03	78300.00
DD0E0F	2017-06-29 17:53:00+03	48800.00
DD0E3A	2017-06-29 05:22:00+03	201200.00
DD0E69	2017-07-20 02:03:00+03	58800.00
DD0ECC	2017-07-18 03:01:00+03	46200.00
DD0F25	2017-07-28 13:37:00+03	199700.00
DD0F3C	2017-07-12 01:19:00+03	38600.00
DD0F82	2017-07-01 11:40:00+03	51200.00
DD0F86	2017-08-05 07:27:00+03	116000.00
DD0F8B	2017-07-09 23:13:00+03	66800.00
DD0FC9	2017-07-25 07:01:00+03	29400.00
DD1034	2017-07-06 14:22:00+03	54500.00
DD1077	2017-07-31 14:57:00+03	28000.00
DD1082	2017-08-04 06:00:00+03	23400.00
DD1096	2017-07-08 04:32:00+03	136500.00
DD1147	2017-08-03 14:18:00+03	54400.00
DD1152	2017-07-17 18:06:00+03	13200.00
DD1153	2017-07-26 08:26:00+03	48800.00
DD11C2	2017-07-22 11:06:00+03	21200.00
DD123D	2017-07-05 13:08:00+03	46700.00
DD1257	2017-07-25 16:01:00+03	30900.00
DD1277	2017-07-29 16:11:00+03	130100.00
DD131E	2017-08-07 06:59:00+03	57800.00
DD13D8	2017-07-29 15:22:00+03	6300.00
DD1417	2017-08-09 17:38:00+03	73100.00
DD1461	2017-08-08 05:26:00+03	37900.00
DD1465	2017-07-15 03:34:00+03	38400.00
DD1468	2017-08-07 13:24:00+03	56000.00
DD14A8	2017-07-29 04:02:00+03	36400.00
DD153D	2017-07-29 12:39:00+03	28000.00
DD1594	2017-07-02 02:36:00+03	46400.00
DD160B	2017-07-12 01:10:00+03	143900.00
DD1661	2017-07-21 18:03:00+03	56000.00
DD1696	2017-07-26 15:49:00+03	28000.00
DD1739	2017-07-27 23:59:00+03	96300.00
DD17E7	2017-07-18 14:31:00+03	25600.00
DD185B	2017-07-10 02:38:00+03	93900.00
DD18AA	2017-07-14 19:28:00+03	46200.00
DD18C0	2017-07-15 03:35:00+03	58200.00
DD18F8	2017-07-22 14:45:00+03	56600.00
DD1903	2017-08-08 00:57:00+03	46900.00
DD1928	2017-07-21 12:26:00+03	35000.00
DD194C	2017-07-07 08:58:00+03	23200.00
DD195E	2017-07-14 19:40:00+03	22000.00
DD19AD	2017-07-28 15:00:00+03	407000.00
DD19D8	2017-07-26 05:32:00+03	23200.00
DD1B4E	2017-08-03 22:40:00+03	75600.00
DD1B5D	2017-08-05 00:49:00+03	47600.00
DD1BB3	2017-07-25 23:35:00+03	81300.00
DD1BE6	2017-07-05 06:19:00+03	55800.00
DD1C06	2017-08-06 19:26:00+03	69900.00
DD1C08	2017-07-29 21:26:00+03	38600.00
DD1C67	2017-07-31 16:50:00+03	26200.00
DD1C72	2017-07-05 15:54:00+03	39600.00
DD1CB7	2017-07-17 12:37:00+03	26000.00
DD1CD1	2017-07-22 02:28:00+03	53200.00
DD1D31	2017-07-12 10:41:00+03	115100.00
DD1D50	2017-08-01 12:28:00+03	71900.00
DD1D66	2017-08-12 16:56:00+03	6800.00
DD1D8F	2017-07-29 09:44:00+03	124200.00
DD1DCD	2017-08-05 05:21:00+03	57400.00
DD1E24	2017-07-11 09:01:00+03	19800.00
DD1E9B	2017-07-23 22:04:00+03	73600.00
DD1F26	2017-08-01 12:32:00+03	48800.00
DD1F2B	2017-08-15 14:45:00+03	131100.00
DD1F88	2017-08-15 04:52:00+03	242700.00
DD1F90	2017-07-07 13:13:00+03	99200.00
DD1FC4	2017-07-30 09:59:00+03	69100.00
DD1FC6	2017-07-27 02:03:00+03	57500.00
DD1FE3	2017-07-09 06:07:00+03	129200.00
DD200A	2017-07-18 21:00:00+03	58800.00
DD2018	2017-07-31 03:36:00+03	68300.00
DD2039	2017-07-27 10:42:00+03	12600.00
DD20C8	2017-08-11 17:58:00+03	23400.00
DD20D1	2017-08-08 14:16:00+03	120400.00
DD20D8	2017-07-29 20:33:00+03	20200.00
DD20F3	2017-07-20 12:31:00+03	13200.00
DD210D	2017-07-13 15:38:00+03	27600.00
DD211E	2017-08-05 06:07:00+03	156500.00
DD2175	2017-07-22 19:29:00+03	40800.00
DD2184	2017-07-11 06:27:00+03	65300.00
DD21F9	2017-07-15 00:56:00+03	85000.00
DD225A	2017-07-29 05:39:00+03	36200.00
DD2268	2017-07-17 08:53:00+03	139800.00
DD2275	2017-08-12 07:32:00+03	273600.00
DD22E9	2017-07-11 13:25:00+03	273200.00
DD22EC	2017-07-24 12:54:00+03	61800.00
DD231E	2017-07-05 03:36:00+03	97500.00
DD239C	2017-08-15 15:24:00+03	98400.00
DD239D	2017-08-03 00:02:00+03	6000.00
DD240F	2017-08-13 23:44:00+03	81300.00
DD24E2	2017-07-23 18:47:00+03	23400.00
DD2535	2017-07-24 05:12:00+03	169300.00
DD2671	2017-08-03 02:16:00+03	94000.00
DD2683	2017-07-22 15:50:00+03	185800.00
DD26BC	2017-08-12 03:47:00+03	89600.00
DD26EA	2017-08-13 10:42:00+03	6800.00
DD2741	2017-08-11 03:31:00+03	24200.00
DD279A	2017-07-13 17:54:00+03	399600.00
DD280D	2017-07-29 14:39:00+03	15000.00
DD28AD	2017-08-13 07:28:00+03	82000.00
DD28F3	2017-07-09 13:45:00+03	56000.00
DD2921	2017-06-29 10:27:00+03	123100.00
DD29D1	2017-08-04 19:51:00+03	57600.00
DD2A2B	2017-08-06 20:29:00+03	167400.00
DD2A98	2017-07-16 00:47:00+03	57600.00
DD2AA7	2017-08-02 01:56:00+03	56100.00
DD2AFD	2017-08-12 20:08:00+03	66300.00
DD2B03	2017-07-25 12:11:00+03	135400.00
DD2B1D	2017-07-20 15:44:00+03	8200.00
DD2B6E	2017-07-12 21:50:00+03	128800.00
DD2C07	2017-08-10 14:12:00+03	24000.00
DD2C6F	2017-07-13 14:45:00+03	95500.00
DD2C95	2017-07-24 18:25:00+03	35200.00
DD2D36	2017-07-02 08:31:00+03	13600.00
DD2D99	2017-06-29 01:33:00+03	94600.00
DD2DCC	2017-06-27 19:43:00+03	133200.00
DD2DEB	2017-07-16 04:20:00+03	68800.00
DD2E28	2017-07-09 07:39:00+03	114400.00
DD2E94	2017-07-20 15:02:00+03	85000.00
DD2F15	2017-07-04 15:48:00+03	20400.00
DD2F1D	2017-07-13 05:00:00+03	384400.00
DD2FA8	2017-07-02 01:06:00+03	20500.00
DD3007	2017-07-10 23:42:00+03	112000.00
DD3009	2017-08-08 12:06:00+03	89700.00
DD301E	2017-07-05 03:49:00+03	51900.00
DD3039	2017-08-02 09:50:00+03	78600.00
DD3062	2017-07-10 03:27:00+03	65000.00
DD3079	2017-07-15 23:22:00+03	187600.00
DD3084	2017-07-23 06:53:00+03	69500.00
DD30B4	2017-07-22 08:11:00+03	48400.00
DD30F2	2017-07-02 20:07:00+03	26000.00
DD30FF	2017-07-15 16:35:00+03	47500.00
DD311F	2017-08-01 16:24:00+03	113700.00
DD31A2	2017-07-18 13:04:00+03	271100.00
DD31BE	2017-07-04 20:50:00+03	46300.00
DD3223	2017-07-10 00:19:00+03	291000.00
DD3241	2017-07-28 15:47:00+03	134700.00
DD3296	2017-07-13 08:18:00+03	46300.00
DD329E	2017-08-08 04:48:00+03	16400.00
DD334E	2017-07-31 04:10:00+03	25800.00
DD3363	2017-08-13 07:45:00+03	31600.00
DD33BB	2017-07-21 14:12:00+03	212800.00
DD342F	2017-07-23 00:40:00+03	55800.00
DD3467	2017-07-27 14:48:00+03	14000.00
DD348B	2017-07-27 02:13:00+03	6300.00
DD34E4	2017-07-03 13:01:00+03	26000.00
DD3589	2017-07-14 04:24:00+03	100600.00
DD358C	2017-07-20 22:28:00+03	93900.00
DD35A8	2017-07-05 21:12:00+03	8200.00
DD35AC	2017-07-15 07:43:00+03	36200.00
DD35C6	2017-08-06 06:08:00+03	92700.00
DD35E0	2017-08-03 13:38:00+03	135400.00
DD35E9	2017-08-02 17:20:00+03	133200.00
DD36F8	2017-07-27 14:04:00+03	136500.00
DD37BC	2017-07-15 18:23:00+03	15400.00
DD37CD	2017-07-26 04:31:00+03	47200.00
DD3809	2017-07-03 05:34:00+03	39700.00
DD3826	2017-07-15 19:55:00+03	136800.00
DD382B	2017-07-06 22:44:00+03	68100.00
DD3840	2017-07-11 14:42:00+03	124300.00
DD38CA	2017-07-04 16:49:00+03	20400.00
DD38F1	2017-07-07 01:11:00+03	51900.00
DD3971	2017-07-19 21:01:00+03	32200.00
DD398A	2017-07-08 14:02:00+03	36800.00
DD399C	2017-07-02 00:26:00+03	45200.00
DD39C9	2017-07-28 00:22:00+03	125700.00
DD3A27	2017-08-01 01:07:00+03	62600.00
DD3A34	2017-07-21 06:35:00+03	56000.00
DD3A83	2017-07-11 17:21:00+03	81700.00
DD3A8C	2017-07-30 04:48:00+03	49300.00
DD3AE7	2017-07-24 17:05:00+03	53600.00
DD3AF6	2017-07-22 17:44:00+03	31000.00
DD3B41	2017-07-24 00:15:00+03	105100.00
DD3B82	2017-08-05 23:05:00+03	47000.00
DD3BAA	2017-07-24 02:06:00+03	20000.00
DD3BBF	2017-08-12 06:36:00+03	133200.00
DD3BD6	2017-08-15 11:14:00+03	65500.00
DD3BED	2017-07-03 00:20:00+03	306600.00
DD3C3F	2017-07-26 09:51:00+03	52000.00
DD3C6F	2017-07-05 13:48:00+03	68100.00
DD3C8C	2017-07-04 04:00:00+03	19600.00
DD3CB9	2017-07-30 06:37:00+03	484200.00
DD3CBF	2017-08-12 11:39:00+03	19200.00
DD3CD4	2017-08-04 03:52:00+03	72700.00
DD3D6B	2017-07-12 11:21:00+03	32700.00
DD3D77	2017-07-05 05:06:00+03	20200.00
DD3D9F	2017-08-01 17:59:00+03	46400.00
DD3DB9	2017-07-14 14:32:00+03	269200.00
DD3DC6	2017-08-02 07:49:00+03	256400.00
DD3E75	2017-08-06 02:13:00+03	65500.00
DD3F24	2017-07-04 01:07:00+03	174600.00
DD3F58	2017-08-14 19:27:00+03	12000.00
DD3F80	2017-07-22 16:11:00+03	40200.00
DD402B	2017-07-04 19:01:00+03	51400.00
DD4037	2017-07-26 00:34:00+03	115000.00
DD403B	2017-07-15 10:51:00+03	24300.00
DD4159	2017-07-01 19:28:00+03	23200.00
DD4167	2017-08-04 09:44:00+03	26000.00
DD4191	2017-07-09 10:17:00+03	92800.00
DD4199	2017-08-10 16:46:00+03	42800.00
DD41A9	2017-08-06 17:22:00+03	199800.00
DD41C7	2017-08-03 03:19:00+03	136600.00
DD41CD	2017-07-14 20:58:00+03	24400.00
DD41DF	2017-07-24 16:24:00+03	56000.00
DD424F	2017-07-18 05:06:00+03	112000.00
DD4251	2017-08-15 10:40:00+03	97200.00
DD427A	2017-08-07 10:33:00+03	73500.00
DD42FE	2017-07-10 04:01:00+03	47100.00
DD432D	2017-07-12 11:24:00+03	52000.00
DD4374	2017-07-04 00:46:00+03	55800.00
DD43AC	2017-07-31 21:14:00+03	9200.00
DD43AF	2017-07-07 06:51:00+03	56000.00
DD43C2	2017-07-30 05:01:00+03	108200.00
DD43EF	2017-08-05 02:17:00+03	18000.00
DD43FC	2017-08-08 08:18:00+03	265800.00
DD4492	2017-07-13 19:17:00+03	40200.00
DD4510	2017-06-27 23:20:00+03	92100.00
DD4573	2017-08-10 11:49:00+03	57600.00
DD45D0	2017-07-22 03:11:00+03	62600.00
DD4651	2017-07-17 19:13:00+03	53600.00
DD4686	2017-08-05 02:53:00+03	46400.00
DD46CE	2017-08-06 03:22:00+03	27800.00
DD4730	2017-07-30 12:41:00+03	26000.00
DD47BF	2017-08-07 12:11:00+03	124000.00
DD4848	2017-08-15 02:02:00+03	56000.00
DD48E3	2017-08-08 04:10:00+03	246000.00
DD4956	2017-07-16 13:06:00+03	81900.00
DD4973	2017-08-04 17:52:00+03	127300.00
DD497A	2017-07-09 21:56:00+03	43400.00
DD4993	2017-07-22 16:40:00+03	67600.00
DD4A02	2017-07-27 17:53:00+03	56000.00
DD4A91	2017-07-15 05:50:00+03	56600.00
DD4BD9	2017-07-08 05:59:00+03	56000.00
DD4C11	2017-07-26 21:51:00+03	260300.00
DD4CBA	2017-08-01 01:19:00+03	10600.00
DD4D5B	2017-08-03 13:16:00+03	133900.00
DD4D7D	2017-07-10 11:32:00+03	48400.00
DD4DE0	2017-07-12 10:01:00+03	22000.00
DD4E0F	2017-08-09 04:22:00+03	275100.00
DD4EAD	2017-08-14 18:17:00+03	12600.00
DD4EE5	2017-08-05 12:11:00+03	40800.00
DD4F70	2017-07-29 00:04:00+03	62800.00
DD4F78	2017-08-15 17:27:00+03	28000.00
DD4F87	2017-08-08 05:47:00+03	69500.00
DD4FD9	2017-08-12 04:34:00+03	87100.00
DD501E	2017-07-10 03:33:00+03	393000.00
DD5097	2017-07-09 11:51:00+03	168000.00
DD50C3	2017-07-19 07:25:00+03	113600.00
DD5120	2017-08-15 02:51:00+03	166300.00
DD512E	2017-07-13 21:07:00+03	34000.00
DD517B	2017-07-07 15:34:00+03	21800.00
DD51CF	2017-07-01 11:58:00+03	64500.00
DD5307	2017-08-12 12:38:00+03	136200.00
DD5336	2017-07-27 11:22:00+03	64300.00
DD5339	2017-08-06 00:25:00+03	67400.00
DD533C	2017-08-07 08:12:00+03	22000.00
DD537B	2017-07-16 23:03:00+03	283100.00
DD537E	2017-08-08 09:25:00+03	37900.00
DD538C	2017-07-14 02:39:00+03	97900.00
DD53AC	2017-08-03 23:36:00+03	31100.00
DD53C5	2017-07-19 22:23:00+03	58200.00
DD53C9	2017-08-05 18:46:00+03	35600.00
DD53EF	2017-07-01 05:21:00+03	133100.00
DD5471	2017-07-19 10:58:00+03	46400.00
DD547D	2017-07-06 11:16:00+03	189200.00
DD5480	2017-07-29 23:54:00+03	26200.00
DD54F7	2017-08-04 22:38:00+03	198900.00
DD5558	2017-07-23 15:50:00+03	105000.00
DD5591	2017-07-27 15:50:00+03	58600.00
DD5593	2017-08-12 14:20:00+03	88900.00
DD5594	2017-07-20 21:59:00+03	26100.00
DD560A	2017-08-12 16:23:00+03	39200.00
DD56C3	2017-07-26 05:45:00+03	29600.00
DD572F	2017-07-24 12:12:00+03	119000.00
DD5737	2017-07-08 09:56:00+03	132800.00
DD5739	2017-07-25 17:25:00+03	29600.00
DD5758	2017-08-09 21:54:00+03	64600.00
DD5788	2017-08-08 21:13:00+03	28800.00
DD57AF	2017-07-17 21:36:00+03	132800.00
DD57BC	2017-07-26 08:31:00+03	111600.00
DD57E9	2017-07-13 09:06:00+03	172100.00
DD5854	2017-07-12 20:02:00+03	12600.00
DD58F0	2017-07-09 10:29:00+03	96300.00
DD58F5	2017-07-04 08:46:00+03	243600.00
DD5913	2017-07-19 05:48:00+03	77600.00
DD595A	2017-08-10 02:37:00+03	23200.00
DD5988	2017-08-12 23:04:00+03	14400.00
DD59B1	2017-07-12 21:00:00+03	354400.00
DD59E2	2017-07-23 01:09:00+03	52400.00
DD5A37	2017-07-25 23:02:00+03	50100.00
DD5A7D	2017-08-06 08:38:00+03	81700.00
DD5AF5	2017-07-14 03:12:00+03	36700.00
DD5B22	2017-07-21 00:33:00+03	40000.00
DD5B93	2017-07-16 04:24:00+03	28000.00
DD5BB2	2017-07-06 06:56:00+03	58600.00
DD5BCD	2017-08-07 15:08:00+03	21800.00
DD5BF2	2017-07-06 11:01:00+03	55600.00
DD5C17	2017-07-31 16:13:00+03	12400.00
DD5C74	2017-07-14 13:49:00+03	65900.00
DD5C78	2017-07-06 05:52:00+03	67200.00
DD5C7B	2017-08-15 17:19:00+03	57500.00
DD5C9B	2017-08-03 02:42:00+03	12800.00
DD5CCC	2017-07-06 06:04:00+03	57600.00
DD5CE3	2017-07-08 01:04:00+03	119500.00
DD5CF1	2017-07-19 10:03:00+03	50000.00
DD5D12	2017-08-02 19:54:00+03	47000.00
DD5D48	2017-07-15 06:42:00+03	34000.00
DD5D67	2017-07-13 20:28:00+03	27200.00
DD5D6D	2017-08-12 22:16:00+03	52400.00
DD5D82	2017-07-03 16:44:00+03	138100.00
DD5DAE	2017-07-08 14:24:00+03	6300.00
DD5DB5	2017-07-14 03:21:00+03	278400.00
DD5DEA	2017-07-08 03:15:00+03	42400.00
DD5E13	2017-08-06 14:03:00+03	62000.00
DD5E43	2017-07-19 06:24:00+03	19600.00
DD5E60	2017-08-01 02:01:00+03	39000.00
DD5E7B	2017-07-06 17:54:00+03	21800.00
DD5E9F	2017-07-29 11:51:00+03	70800.00
DD5ED1	2017-08-02 04:21:00+03	12600.00
DD5F54	2017-07-21 00:42:00+03	38600.00
DD5FA8	2017-07-03 22:29:00+03	104000.00
DD5FAE	2017-07-03 15:09:00+03	46500.00
DD5FE7	2017-08-15 03:11:00+03	39300.00
DD6012	2017-07-02 19:43:00+03	17600.00
DD608E	2017-07-16 22:33:00+03	53200.00
DD609E	2017-07-18 16:17:00+03	38600.00
DD60C0	2017-07-31 23:41:00+03	107500.00
DD613F	2017-08-03 09:40:00+03	62200.00
DD6158	2017-07-27 18:39:00+03	21800.00
DD619E	2017-07-18 10:25:00+03	16400.00
DD6228	2017-07-16 16:25:00+03	124200.00
DD6248	2017-08-01 13:54:00+03	266400.00
DD6289	2017-07-29 19:23:00+03	61800.00
DD62DC	2017-08-12 23:12:00+03	23400.00
DD62F5	2017-07-31 05:57:00+03	24000.00
DD6373	2017-08-13 23:54:00+03	62600.00
DD63C6	2017-08-04 19:50:00+03	229900.00
DD63F2	2017-07-06 06:48:00+03	38200.00
DD6418	2017-07-13 01:04:00+03	71900.00
DD642C	2017-08-13 00:35:00+03	20200.00
DD6439	2017-07-14 10:34:00+03	171700.00
DD6474	2017-07-23 23:04:00+03	133100.00
DD6485	2017-08-11 01:27:00+03	26000.00
DD64E3	2017-08-12 22:33:00+03	87000.00
DD6517	2017-08-14 14:09:00+03	14000.00
DD6561	2017-07-18 23:48:00+03	77200.00
DD658F	2017-07-05 17:31:00+03	28000.00
DD65BF	2017-07-02 02:42:00+03	85600.00
DD65C1	2017-07-28 21:45:00+03	40400.00
DD65D8	2017-07-17 16:06:00+03	13400.00
DD664D	2017-08-11 09:51:00+03	37200.00
DD674A	2017-08-08 15:44:00+03	52600.00
DD6762	2017-08-14 23:14:00+03	25900.00
DD67AD	2017-08-05 11:35:00+03	70600.00
DD67CB	2017-08-04 18:17:00+03	6000.00
DD6815	2017-08-01 00:18:00+03	31600.00
DD6827	2017-07-03 06:44:00+03	154800.00
DD684C	2017-07-31 10:34:00+03	54300.00
DD6850	2017-08-02 17:37:00+03	124200.00
DD6896	2017-07-07 22:32:00+03	27200.00
DD6933	2017-08-12 04:09:00+03	12600.00
DD693F	2017-07-13 11:12:00+03	48800.00
DD69C6	2017-07-19 06:03:00+03	128900.00
DD6A00	2017-07-02 03:45:00+03	16000.00
DD6A25	2017-08-06 04:36:00+03	19600.00
DD6A70	2017-08-07 15:42:00+03	16400.00
DD6A8D	2017-07-11 16:11:00+03	39500.00
DD6AA0	2017-07-15 06:29:00+03	24400.00
DD6AB1	2017-08-12 10:52:00+03	8200.00
DD6AB4	2017-07-16 13:41:00+03	61800.00
DD6BF3	2017-07-24 04:22:00+03	22000.00
DD6BF6	2017-07-24 07:11:00+03	37700.00
DD6BFD	2017-06-27 01:23:00+03	26000.00
DD6C8B	2017-07-18 15:49:00+03	41400.00
DD6C93	2017-07-09 23:41:00+03	58800.00
DD6C98	2017-07-02 17:42:00+03	36200.00
DD6D01	2017-07-22 01:02:00+03	137200.00
DD6E20	2017-07-09 01:43:00+03	14400.00
DD6E24	2017-07-04 08:08:00+03	8000.00
DD6E50	2017-08-11 16:04:00+03	32300.00
DD6E75	2017-07-17 19:25:00+03	244400.00
DD6E77	2017-07-13 06:31:00+03	89700.00
DD6F02	2017-07-29 20:16:00+03	23600.00
DD6F19	2017-07-14 22:14:00+03	13400.00
DD6F22	2017-08-03 14:07:00+03	56900.00
DD6F30	2017-08-12 21:11:00+03	39800.00
DD6F72	2017-07-03 16:37:00+03	131800.00
DD6F8E	2017-07-10 14:43:00+03	122000.00
DD6FEE	2017-07-26 07:43:00+03	135600.00
DD7018	2017-08-11 23:36:00+03	46000.00
DD705C	2017-07-29 08:27:00+03	73500.00
DD707C	2017-07-30 17:25:00+03	28000.00
DD70FF	2017-07-13 10:24:00+03	31600.00
DD715B	2017-07-09 09:34:00+03	69500.00
DD715C	2017-07-29 16:34:00+03	189200.00
DD7163	2017-08-08 05:40:00+03	112000.00
DD716C	2017-08-13 14:35:00+03	46900.00
DD716E	2017-08-01 18:49:00+03	121400.00
DD7183	2017-08-14 11:15:00+03	246000.00
DD71D2	2017-08-05 23:01:00+03	26000.00
DD725D	2017-08-09 00:22:00+03	47000.00
DD726B	2017-07-01 21:00:00+03	18600.00
DD72CA	2017-07-12 11:09:00+03	193300.00
DD730F	2017-07-31 18:14:00+03	170000.00
DD741A	2017-07-14 04:30:00+03	95200.00
DD747A	2017-08-04 06:37:00+03	58900.00
DD747B	2017-07-16 10:21:00+03	254500.00
DD749E	2017-07-26 04:59:00+03	47200.00
DD74B3	2017-07-12 18:21:00+03	117600.00
DD7553	2017-07-20 19:28:00+03	86800.00
DD75BB	2017-07-27 05:06:00+03	73100.00
DD763E	2017-07-18 01:20:00+03	37200.00
DD768E	2017-08-08 00:16:00+03	6700.00
DD76BB	2017-07-14 14:06:00+03	69100.00
DD76C2	2017-08-06 11:54:00+03	123000.00
DD7709	2017-08-05 01:21:00+03	81200.00
DD7767	2017-08-01 02:57:00+03	80000.00
DD77A7	2017-07-20 02:29:00+03	270700.00
DD77EE	2017-07-26 06:22:00+03	117700.00
DD77F6	2017-07-18 00:04:00+03	14000.00
DD7819	2017-08-11 12:26:00+03	99200.00
DD784E	2017-07-15 11:59:00+03	55800.00
DD789F	2017-08-10 16:40:00+03	492000.00
DD78BE	2017-07-15 06:49:00+03	35600.00
DD78C1	2017-06-30 09:59:00+03	112000.00
DD78D6	2017-07-14 12:18:00+03	18000.00
DD78EA	2017-07-04 02:25:00+03	36200.00
DD78FD	2017-07-05 12:12:00+03	101200.00
DD795F	2017-07-10 07:40:00+03	52700.00
DD7A61	2017-06-27 07:53:00+03	102100.00
DD7A96	2017-08-15 04:39:00+03	44800.00
DD7B47	2017-07-07 00:18:00+03	56000.00
DD7B96	2017-07-02 04:55:00+03	29600.00
DD7BA4	2017-08-10 13:15:00+03	46400.00
DD7BDE	2017-07-20 09:37:00+03	69500.00
DD7C1A	2017-08-13 05:08:00+03	99300.00
DD7C20	2017-07-11 06:49:00+03	65600.00
DD7C51	2017-08-03 13:24:00+03	86300.00
DD7C59	2017-07-16 06:06:00+03	62600.00
DD7CE1	2017-07-20 13:29:00+03	111600.00
DD7D82	2017-07-18 10:55:00+03	6800.00
DD7D96	2017-06-30 14:45:00+03	142400.00
DD7DC1	2017-07-25 08:14:00+03	56000.00
DD7E34	2017-08-05 07:37:00+03	57800.00
DD7E74	2017-08-01 14:00:00+03	24400.00
DD7ECD	2017-07-08 14:16:00+03	27200.00
DD7F33	2017-08-02 07:46:00+03	27200.00
DD7F85	2017-07-26 17:34:00+03	36800.00
DD7F91	2017-07-13 20:55:00+03	99300.00
DD7FB4	2017-07-04 12:18:00+03	19300.00
DD7FD0	2017-07-28 09:02:00+03	37200.00
DD7FD3	2017-07-22 20:19:00+03	71800.00
DD7FD5	2017-08-13 13:58:00+03	83000.00
DD7FEA	2017-07-13 15:33:00+03	21800.00
DD8025	2017-08-01 13:33:00+03	27300.00
DD80B6	2017-07-12 07:02:00+03	21800.00
DD8125	2017-07-27 16:43:00+03	90800.00
DD8243	2017-07-20 10:32:00+03	39800.00
DD8251	2017-07-18 12:53:00+03	135200.00
DD8274	2017-07-31 08:25:00+03	80200.00
DD8276	2017-07-15 13:49:00+03	40800.00
DD8292	2017-08-12 07:46:00+03	44000.00
DD82A2	2017-07-30 02:13:00+03	36000.00
DD8357	2017-07-30 18:33:00+03	112000.00
DD8368	2017-07-29 11:06:00+03	142300.00
DD8391	2017-07-12 12:59:00+03	25800.00
DD8395	2017-07-25 04:23:00+03	113900.00
DD83B7	2017-07-14 06:34:00+03	41200.00
DD8402	2017-07-24 02:59:00+03	64500.00
DD840B	2017-07-04 21:35:00+03	26000.00
DD84AA	2017-07-05 14:02:00+03	119600.00
DD84B9	2017-08-12 21:08:00+03	36200.00
DD84BD	2017-07-05 19:40:00+03	121400.00
DD84E4	2017-07-26 09:42:00+03	153300.00
DD84F5	2017-07-02 02:32:00+03	139400.00
DD8533	2017-07-02 20:17:00+03	136000.00
DD8534	2017-07-08 18:41:00+03	88100.00
DD8550	2017-07-03 10:10:00+03	46800.00
DD8589	2017-08-02 13:51:00+03	271100.00
DD8593	2017-07-14 14:59:00+03	111600.00
DD85B0	2017-08-12 22:52:00+03	124000.00
DD85D5	2017-07-16 21:16:00+03	59800.00
DD85D9	2017-07-24 01:14:00+03	105600.00
DD8616	2017-07-22 14:44:00+03	25600.00
DD868F	2017-08-15 01:12:00+03	15400.00
DD86B1	2017-07-04 19:41:00+03	56600.00
DD86ED	2017-08-15 14:37:00+03	199300.00
DD86F7	2017-08-13 12:28:00+03	52400.00
DD8722	2017-08-04 17:57:00+03	137600.00
DD8729	2017-07-17 19:53:00+03	38200.00
DD8736	2017-07-09 00:29:00+03	249200.00
DD87E8	2017-07-16 17:18:00+03	43200.00
DD87EC	2017-07-06 02:06:00+03	94000.00
DD87FE	2017-07-10 03:16:00+03	218200.00
DD885A	2017-07-31 17:35:00+03	24700.00
DD885F	2017-08-08 09:48:00+03	100400.00
DD8884	2017-08-08 06:08:00+03	62700.00
DD888C	2017-07-30 19:24:00+03	14400.00
DD88F5	2017-06-30 12:08:00+03	42400.00
DD8904	2017-07-04 02:26:00+03	12600.00
DD8953	2017-07-08 03:03:00+03	16400.00
DD89F4	2017-07-23 03:20:00+03	23400.00
DD8AB1	2017-07-02 17:32:00+03	23900.00
DD8ADD	2017-08-07 20:57:00+03	14400.00
DD8AF0	2017-08-14 20:54:00+03	13700.00
DD8B0C	2017-07-10 06:52:00+03	50700.00
DD8B12	2017-07-27 06:33:00+03	20400.00
DD8B18	2017-07-25 11:35:00+03	56000.00
DD8B4E	2017-07-06 01:55:00+03	75600.00
DD8B75	2017-07-21 11:06:00+03	84500.00
DD8BDD	2017-07-19 02:06:00+03	102200.00
DD8BE4	2017-08-14 03:21:00+03	79700.00
DD8C14	2017-07-14 06:08:00+03	65900.00
DD8C7E	2017-07-07 17:40:00+03	43200.00
DD8C99	2017-08-08 11:52:00+03	248400.00
DD8CA9	2017-07-13 00:58:00+03	23200.00
DD8CBB	2017-07-02 05:10:00+03	100200.00
DD8D4A	2017-07-12 15:50:00+03	100000.00
DD8DD8	2017-07-29 15:55:00+03	135400.00
DD8DE0	2017-07-30 12:04:00+03	21800.00
DD8E1A	2017-08-09 09:24:00+03	49800.00
DD8E26	2017-08-01 23:42:00+03	335500.00
DD8E76	2017-07-15 19:52:00+03	85400.00
DD8E88	2017-07-13 21:17:00+03	50100.00
DD8F3D	2017-07-03 15:59:00+03	387400.00
DD8FD6	2017-07-05 13:27:00+03	26000.00
DD8FF5	2017-08-12 00:28:00+03	125200.00
DD9005	2017-07-01 21:44:00+03	55800.00
DD9008	2017-07-19 19:47:00+03	113800.00
DD90FD	2017-07-06 19:21:00+03	146500.00
DD9105	2017-08-02 05:32:00+03	74000.00
DD9112	2017-08-07 20:51:00+03	29600.00
DD9113	2017-08-07 05:39:00+03	135400.00
DD9140	2017-07-24 09:02:00+03	123000.00
DD9168	2017-08-08 21:52:00+03	48500.00
DD916F	2017-06-30 01:23:00+03	52800.00
DD9175	2017-08-05 08:06:00+03	53300.00
DD9205	2017-08-14 14:03:00+03	24000.00
DD920D	2017-07-05 16:34:00+03	31600.00
DD923D	2017-08-10 09:33:00+03	62700.00
DD9248	2017-07-31 08:33:00+03	24800.00
DD9258	2017-07-14 00:18:00+03	37900.00
DD9281	2017-08-07 16:49:00+03	283200.00
DD928A	2017-08-07 07:13:00+03	33100.00
DD9299	2017-07-11 04:57:00+03	50100.00
DD92BD	2017-07-01 16:46:00+03	14800.00
DD9311	2017-07-19 21:07:00+03	23600.00
DD9348	2017-08-14 16:51:00+03	51300.00
DD935C	2017-07-10 00:07:00+03	45100.00
DD939F	2017-07-29 17:03:00+03	43500.00
DD93C2	2017-08-08 05:56:00+03	48800.00
DD93C5	2017-07-25 14:22:00+03	46400.00
DD93D2	2017-07-14 08:52:00+03	234100.00
DD9427	2017-06-30 00:18:00+03	16400.00
DD9468	2017-07-25 10:35:00+03	106800.00
DD94AD	2017-08-04 08:45:00+03	35600.00
DD959F	2017-08-14 12:45:00+03	23200.00
DD9663	2017-07-12 10:13:00+03	79900.00
DD9701	2017-07-02 09:24:00+03	47200.00
DD9783	2017-07-16 10:01:00+03	83000.00
DD97BB	2017-07-10 16:24:00+03	399600.00
DD9831	2017-07-04 03:22:00+03	32800.00
DD9836	2017-07-28 08:08:00+03	69000.00
DD9888	2017-08-11 21:58:00+03	47200.00
DD98DC	2017-07-19 13:07:00+03	39200.00
DD98FB	2017-08-13 11:44:00+03	246000.00
DD9902	2017-07-31 16:50:00+03	58400.00
DD9942	2017-08-05 15:33:00+03	85600.00
DD9966	2017-08-02 21:35:00+03	73300.00
DD998F	2017-07-31 11:36:00+03	32200.00
DD99B3	2017-08-07 23:29:00+03	38800.00
DD99C6	2017-07-02 19:47:00+03	59800.00
DD9A40	2017-07-10 08:38:00+03	23600.00
DD9A4A	2017-08-09 17:03:00+03	108600.00
DD9A52	2017-07-13 04:02:00+03	54400.00
DD9A5F	2017-08-13 18:12:00+03	15700.00
DD9A90	2017-07-05 02:24:00+03	14000.00
DD9AC6	2017-07-07 09:10:00+03	70500.00
DD9B03	2017-07-26 05:17:00+03	33600.00
DD9B25	2017-07-24 00:35:00+03	44800.00
DD9B60	2017-07-06 15:57:00+03	49600.00
DD9BB5	2017-07-30 17:23:00+03	19000.00
DD9C28	2017-08-10 15:06:00+03	27700.00
DD9C42	2017-07-18 14:00:00+03	45400.00
DD9C46	2017-07-20 18:07:00+03	124800.00
DD9CFF	2017-07-22 20:04:00+03	198800.00
DD9D14	2017-08-12 11:25:00+03	168700.00
DD9D32	2017-07-07 19:11:00+03	43600.00
DD9D97	2017-07-28 15:38:00+03	23200.00
DD9E09	2017-08-14 15:21:00+03	25600.00
DD9E13	2017-08-05 08:12:00+03	73200.00
DD9E93	2017-07-31 10:17:00+03	99200.00
DD9F59	2017-08-02 12:13:00+03	136200.00
DD9F60	2017-07-15 07:04:00+03	92000.00
DD9FA7	2017-07-13 00:23:00+03	22000.00
DD9FAE	2017-07-31 16:20:00+03	6000.00
DD9FDF	2017-07-21 19:38:00+03	47100.00
DDA011	2017-08-03 03:59:00+03	61400.00
DDA024	2017-07-12 00:03:00+03	16400.00
DDA08F	2017-08-01 13:37:00+03	28000.00
DDA0C6	2017-07-16 09:47:00+03	13600.00
DDA133	2017-07-02 13:31:00+03	25000.00
DDA1BF	2017-07-10 03:07:00+03	135400.00
DDA1FB	2017-07-29 20:53:00+03	83000.00
DDA203	2017-07-01 17:27:00+03	56000.00
DDA212	2017-08-12 21:33:00+03	26000.00
DDA216	2017-07-20 13:18:00+03	85000.00
DDA252	2017-08-05 21:38:00+03	55800.00
DDA2E3	2017-08-04 10:49:00+03	35200.00
DDA37A	2017-08-05 10:58:00+03	65400.00
DDA412	2017-07-12 19:12:00+03	34700.00
DDA47A	2017-07-10 00:43:00+03	28800.00
DDA55D	2017-07-25 09:02:00+03	107400.00
DDA579	2017-07-18 15:00:00+03	199300.00
DDA57A	2017-07-16 18:46:00+03	16400.00
DDA5DF	2017-07-26 12:31:00+03	28800.00
DDA600	2017-07-09 16:53:00+03	8200.00
DDA606	2017-07-07 17:45:00+03	43200.00
DDA620	2017-08-12 22:01:00+03	37200.00
DDA640	2017-06-30 07:32:00+03	57600.00
DDA707	2017-07-16 15:20:00+03	38600.00
DDA726	2017-08-11 00:54:00+03	41200.00
DDA72A	2017-07-02 19:09:00+03	32900.00
DDA84A	2017-06-30 12:35:00+03	35300.00
DDA85E	2017-07-04 04:29:00+03	43300.00
DDA88D	2017-08-10 19:29:00+03	39800.00
DDA8D9	2017-07-13 17:45:00+03	47200.00
DDA8FB	2017-08-10 11:12:00+03	101200.00
DDA94A	2017-08-03 13:10:00+03	55800.00
DDA96B	2017-07-02 20:24:00+03	44800.00
DDA987	2017-08-01 06:51:00+03	85000.00
DDA9A7	2017-07-09 04:23:00+03	57600.00
DDAA6C	2017-07-08 04:34:00+03	32100.00
DDAA87	2017-07-14 19:31:00+03	136200.00
DDAB39	2017-07-09 04:36:00+03	89800.00
DDAB59	2017-08-11 10:14:00+03	58400.00
DDAB6B	2017-08-08 02:21:00+03	129200.00
DDABD7	2017-07-14 10:01:00+03	31100.00
DDABD8	2017-07-19 10:41:00+03	42800.00
DDAC15	2017-07-19 15:19:00+03	106400.00
DDAC27	2017-07-28 16:01:00+03	24400.00
DDAC47	2017-07-13 09:56:00+03	34400.00
DDAC65	2017-08-14 14:49:00+03	15400.00
DDAD0F	2017-08-03 02:16:00+03	99200.00
DDAD14	2017-07-23 18:13:00+03	100500.00
DDAD26	2017-07-04 02:50:00+03	139800.00
DDAD30	2017-08-09 00:41:00+03	46300.00
DDAD41	2017-08-15 07:41:00+03	46900.00
DDADA7	2017-07-07 16:57:00+03	69900.00
DDADF8	2017-07-28 03:17:00+03	493300.00
DDAE54	2017-07-31 19:19:00+03	26000.00
DDAE67	2017-07-23 08:38:00+03	115400.00
DDAE6C	2017-08-10 11:36:00+03	38400.00
DDAED2	2017-07-08 03:36:00+03	58600.00
DDAEEC	2017-08-11 22:00:00+03	27200.00
DDAF14	2017-07-02 22:18:00+03	266400.00
DDAF2C	2017-08-15 10:52:00+03	45400.00
DDAF54	2017-07-12 06:58:00+03	35200.00
DDAFFC	2017-07-03 05:26:00+03	6700.00
DDB070	2017-08-08 15:38:00+03	37200.00
DDB072	2017-07-04 23:49:00+03	119500.00
DDB07D	2017-07-23 03:30:00+03	293700.00
DDB09C	2017-07-25 13:27:00+03	25400.00
DDB0C7	2017-07-07 12:48:00+03	23600.00
DDB184	2017-07-24 04:00:00+03	24400.00
DDB1BB	2017-07-19 21:29:00+03	15000.00
DDB1BE	2017-08-13 12:31:00+03	15400.00
DDB1F8	2017-08-06 14:53:00+03	59900.00
DDB212	2017-07-31 04:45:00+03	69500.00
DDB309	2017-07-09 04:49:00+03	246000.00
DDB314	2017-07-30 19:44:00+03	29600.00
DDB340	2017-08-08 09:37:00+03	34700.00
DDB34E	2017-07-02 12:53:00+03	90400.00
DDB381	2017-08-15 05:04:00+03	36000.00
DDB3A1	2017-07-26 01:07:00+03	284400.00
DDB3B3	2017-08-07 23:09:00+03	12400.00
DDB421	2017-07-05 03:47:00+03	55800.00
DDB456	2017-07-29 12:53:00+03	31100.00
DDB47C	2017-08-02 16:36:00+03	27200.00
DDB495	2017-06-29 19:22:00+03	6800.00
DDB498	2017-07-28 09:43:00+03	136200.00
DDB4CB	2017-07-31 06:18:00+03	20200.00
DDB511	2017-07-07 22:23:00+03	132800.00
DDB544	2017-07-10 22:37:00+03	46300.00
DDB5B2	2017-08-14 23:13:00+03	28800.00
DDB5BC	2017-08-07 07:15:00+03	34000.00
DDB629	2017-07-11 14:13:00+03	131100.00
DDB65C	2017-07-02 11:19:00+03	149700.00
DDB687	2017-07-09 01:54:00+03	123700.00
DDB68C	2017-07-30 16:58:00+03	28000.00
DDB6CC	2017-08-14 16:06:00+03	14800.00
DDB6E9	2017-07-22 03:56:00+03	28800.00
DDB829	2017-07-12 06:39:00+03	198300.00
DDB893	2017-08-01 03:49:00+03	60900.00
DDB90D	2017-08-11 18:31:00+03	288000.00
DDB98F	2017-07-31 13:13:00+03	170000.00
DDB990	2017-08-06 08:18:00+03	69700.00
DDB9A5	2017-08-14 16:41:00+03	146400.00
DDBAE0	2017-07-02 03:00:00+03	38600.00
DDBB12	2017-08-15 06:13:00+03	134400.00
DDBB76	2017-08-13 10:49:00+03	66900.00
DDBBE2	2017-07-05 19:46:00+03	24200.00
DDBC18	2017-07-24 04:24:00+03	40800.00
DDBC41	2017-07-06 17:05:00+03	36600.00
DDBC78	2017-07-18 05:28:00+03	36400.00
DDBC82	2017-07-23 22:15:00+03	29600.00
DDBD4A	2017-08-14 21:29:00+03	62600.00
DDBD4F	2017-06-29 06:28:00+03	12600.00
DDBD58	2017-07-12 19:24:00+03	67200.00
DDBD83	2017-07-08 19:28:00+03	6800.00
DDBE26	2017-07-03 04:14:00+03	101200.00
DDBE4F	2017-08-03 03:27:00+03	46400.00
DDBE78	2017-07-06 02:50:00+03	122300.00
DDBEF9	2017-07-16 02:13:00+03	66600.00
DDBF23	2017-07-20 06:58:00+03	27200.00
DDBFC1	2017-07-09 11:53:00+03	231300.00
DDBFC4	2017-08-04 01:42:00+03	114800.00
DDBFCE	2017-07-19 07:54:00+03	37400.00
DDBFE9	2017-07-04 22:49:00+03	81700.00
DDC00F	2017-07-14 16:36:00+03	132800.00
DDC077	2017-07-29 10:17:00+03	162300.00
DDC12B	2017-07-01 12:47:00+03	152200.00
DDC167	2017-07-27 01:55:00+03	137600.00
DDC1B6	2017-08-08 16:10:00+03	166900.00
DDC1BC	2017-08-09 06:48:00+03	24400.00
DDC218	2017-08-07 04:50:00+03	266400.00
DDC24B	2017-07-07 06:56:00+03	57500.00
DDC270	2017-07-25 09:41:00+03	65900.00
DDC276	2017-08-01 14:47:00+03	12400.00
DDC2ED	2017-07-19 20:28:00+03	21400.00
DDC376	2017-08-03 22:31:00+03	173500.00
DDC3A4	2017-08-01 03:20:00+03	55600.00
DDC3B4	2017-07-21 10:38:00+03	12400.00
DDC415	2017-07-09 23:08:00+03	121400.00
DDC469	2017-07-06 07:16:00+03	70700.00
DDC4E1	2017-07-16 01:34:00+03	127900.00
DDC4F2	2017-08-05 11:36:00+03	41400.00
DDC52B	2017-07-26 22:04:00+03	133700.00
DDC52C	2017-08-06 23:28:00+03	254900.00
DDC5E4	2017-07-09 16:54:00+03	57700.00
DDC611	2017-08-04 02:42:00+03	28400.00
DDC615	2017-07-09 07:13:00+03	9800.00
DDC63A	2017-06-26 11:19:00+03	203400.00
DDC67C	2017-07-20 19:47:00+03	8200.00
DDC6F6	2017-08-10 15:43:00+03	273000.00
DDC6FD	2017-08-11 00:32:00+03	50600.00
DDC765	2017-08-15 09:50:00+03	13400.00
DDC789	2017-07-16 04:34:00+03	32800.00
DDC7D1	2017-07-15 12:48:00+03	26000.00
DDC7D2	2017-07-10 09:14:00+03	229000.00
DDC7F5	2017-07-25 14:50:00+03	128800.00
DDC7FF	2017-07-25 09:22:00+03	39200.00
DDC81A	2017-08-14 23:51:00+03	61800.00
DDC877	2017-07-27 00:22:00+03	248300.00
DDC8AE	2017-07-25 00:39:00+03	289300.00
DDC8CC	2017-07-19 18:26:00+03	94000.00
DDC9E8	2017-08-11 08:45:00+03	68700.00
DDCA43	2017-08-10 01:20:00+03	114300.00
DDCA96	2017-07-22 15:26:00+03	22600.00
DDCA9B	2017-08-04 12:57:00+03	123000.00
DDCABC	2017-07-25 06:28:00+03	49800.00
DDCAEA	2017-08-09 00:10:00+03	63300.00
DDCB14	2017-07-21 06:41:00+03	38600.00
DDCB1E	2017-08-10 12:47:00+03	25100.00
DDCB9D	2017-07-05 17:42:00+03	65900.00
DDCC1E	2017-08-04 15:29:00+03	56000.00
DDCC87	2017-08-04 21:32:00+03	78100.00
DDCCC4	2017-07-07 21:25:00+03	69500.00
DDCCC7	2017-07-22 21:08:00+03	24400.00
DDCCEE	2017-08-01 08:17:00+03	142800.00
DDCD1A	2017-07-12 01:10:00+03	32800.00
DDCD42	2017-07-30 12:43:00+03	26700.00
DDCD62	2017-08-10 00:38:00+03	103700.00
DDCD6E	2017-07-19 19:01:00+03	88200.00
DDCD77	2017-08-15 17:52:00+03	18900.00
DDCD8A	2017-07-05 00:54:00+03	46300.00
DDCDCF	2017-07-14 08:41:00+03	40800.00
DDCE63	2017-06-29 02:58:00+03	46400.00
DDCE72	2017-07-03 01:01:00+03	369000.00
DDCE92	2017-07-30 17:42:00+03	15400.00
DDCEEF	2017-07-12 15:03:00+03	12600.00
DDD004	2017-07-26 15:05:00+03	56600.00
DDD044	2017-07-26 19:38:00+03	466800.00
DDD0FA	2017-08-04 14:20:00+03	45200.00
DDD172	2017-07-23 13:12:00+03	136100.00
DDD1DB	2017-08-05 07:15:00+03	29600.00
DDD210	2017-07-25 13:34:00+03	68000.00
DDD27A	2017-08-12 14:15:00+03	157100.00
DDD303	2017-08-10 04:40:00+03	8000.00
DDD32E	2017-07-18 12:41:00+03	25100.00
DDD347	2017-07-11 15:56:00+03	62900.00
DDD349	2017-08-05 03:10:00+03	272300.00
DDD384	2017-07-14 06:35:00+03	20000.00
DDD393	2017-07-20 02:28:00+03	57500.00
DDD398	2017-07-01 00:00:00+03	37900.00
DDD451	2017-07-25 14:18:00+03	25600.00
DDD46A	2017-08-08 23:27:00+03	89700.00
DDD48C	2017-08-06 07:29:00+03	39800.00
DDD4AB	2017-07-16 02:44:00+03	23200.00
DDD4D7	2017-07-19 05:03:00+03	43600.00
DDD55C	2017-07-16 00:36:00+03	146400.00
DDD56E	2017-07-30 00:02:00+03	89100.00
DDD597	2017-06-28 12:55:00+03	29400.00
DDD674	2017-07-13 13:55:00+03	16800.00
DDD691	2017-07-23 01:21:00+03	35800.00
DDD6A0	2017-07-10 03:22:00+03	66600.00
DDD6F6	2017-07-14 21:26:00+03	129000.00
DDD751	2017-07-03 07:35:00+03	14000.00
DDD82A	2017-07-06 19:02:00+03	399600.00
DDD859	2017-07-20 04:39:00+03	260900.00
DDD88E	2017-08-02 00:05:00+03	135200.00
DDD8B7	2017-07-01 07:53:00+03	123000.00
DDD8D8	2017-08-03 19:21:00+03	28000.00
DDD9BA	2017-07-14 06:07:00+03	65900.00
DDDA22	2017-07-23 13:08:00+03	54800.00
DDDA2A	2017-07-26 00:53:00+03	52000.00
DDDA33	2017-08-10 15:59:00+03	28000.00
DDDA7D	2017-07-20 23:18:00+03	127200.00
DDDACA	2017-08-12 23:22:00+03	22600.00
DDDAE5	2017-08-15 12:41:00+03	38200.00
DDDAE8	2017-06-29 19:53:00+03	57700.00
DDDB11	2017-07-20 07:13:00+03	34000.00
DDDB63	2017-08-08 12:05:00+03	223200.00
DDDB9D	2017-08-11 13:45:00+03	49300.00
DDDB9E	2017-07-27 23:20:00+03	23600.00
DDDBB6	2017-08-06 15:44:00+03	57600.00
DDDBC8	2017-08-09 07:55:00+03	26500.00
DDDC7F	2017-08-09 02:27:00+03	76600.00
DDDC81	2017-07-15 09:08:00+03	139400.00
DDDC8A	2017-07-10 16:52:00+03	22000.00
DDDCB0	2017-08-04 23:03:00+03	62000.00
DDDD20	2017-07-18 20:44:00+03	27200.00
DDDD9A	2017-08-11 18:42:00+03	135400.00
DDDDFF	2017-07-07 17:26:00+03	51000.00
DDDE32	2017-08-06 21:16:00+03	51900.00
DDDEE7	2017-07-23 11:21:00+03	76600.00
DDDEF8	2017-07-27 22:08:00+03	63400.00
DDDF5D	2017-07-16 01:18:00+03	28600.00
DDDFA4	2017-07-17 11:25:00+03	48800.00
DDDFC2	2017-07-04 04:01:00+03	76600.00
DDE076	2017-07-06 08:44:00+03	56000.00
DDE079	2017-08-06 15:03:00+03	45200.00
DDE087	2017-08-02 15:08:00+03	123000.00
DDE0BC	2017-07-30 04:34:00+03	18600.00
DDE0F4	2017-07-04 09:12:00+03	276900.00
DDE138	2017-07-25 00:03:00+03	114700.00
DDE152	2017-08-03 08:14:00+03	28800.00
DDE166	2017-07-15 10:43:00+03	146600.00
DDE1E6	2017-07-31 19:47:00+03	132800.00
DDE216	2017-07-21 14:21:00+03	32800.00
DDE235	2017-07-04 13:59:00+03	26200.00
DDE239	2017-08-05 10:09:00+03	11000.00
DDE276	2017-07-30 02:34:00+03	282300.00
DDE2A2	2017-08-08 06:17:00+03	69500.00
DDE2B0	2017-07-23 16:25:00+03	62600.00
DDE2D3	2017-07-08 14:25:00+03	202800.00
DDE387	2017-07-12 06:37:00+03	46200.00
DDE3B4	2017-08-06 20:54:00+03	23600.00
DDE3D4	2017-08-06 11:06:00+03	28000.00
DDE3E6	2017-07-20 23:58:00+03	44000.00
DDE408	2017-08-10 14:06:00+03	23200.00
DDE4A4	2017-08-14 12:24:00+03	97900.00
DDE4DA	2017-07-26 12:21:00+03	135600.00
DDE52E	2017-07-18 20:42:00+03	166100.00
DDE53C	2017-08-04 03:39:00+03	101900.00
DDE5F9	2017-07-21 23:41:00+03	24400.00
DDE65F	2017-07-12 02:46:00+03	35600.00
DDE724	2017-07-18 01:15:00+03	56000.00
DDE728	2017-07-04 20:11:00+03	118500.00
DDE79D	2017-06-30 07:55:00+03	89000.00
DDE803	2017-07-26 08:19:00+03	64300.00
DDE83F	2017-07-10 03:03:00+03	67200.00
DDE850	2017-07-08 19:15:00+03	12300.00
DDE87A	2017-08-14 00:20:00+03	52300.00
DDE98C	2017-07-29 00:30:00+03	26000.00
DDE9D7	2017-07-31 16:59:00+03	46000.00
DDEA0A	2017-07-25 07:15:00+03	25200.00
DDEA53	2017-07-30 08:11:00+03	25400.00
DDEA55	2017-07-24 03:00:00+03	43000.00
DDEA93	2017-07-22 15:03:00+03	59300.00
DDEACA	2017-07-14 18:35:00+03	12000.00
DDEB22	2017-08-11 14:39:00+03	18400.00
DDEB5E	2017-08-03 22:45:00+03	32800.00
DDEB7E	2017-08-04 04:59:00+03	45400.00
DDEBB3	2017-07-09 11:14:00+03	52800.00
DDEBBD	2017-08-02 13:20:00+03	27900.00
DDEBE9	2017-07-21 14:17:00+03	73300.00
DDEBFB	2017-07-11 23:18:00+03	11600.00
DDEC1D	2017-07-22 03:26:00+03	75800.00
DDEC31	2017-06-29 22:59:00+03	26000.00
DDEC5D	2017-08-02 07:05:00+03	47200.00
DDEE56	2017-07-12 17:48:00+03	92000.00
DDEE62	2017-07-06 07:47:00+03	22000.00
DDEE8C	2017-07-25 20:35:00+03	27200.00
DDEED5	2017-08-05 07:10:00+03	93700.00
DDEF12	2017-07-16 13:47:00+03	27200.00
DDEF55	2017-07-24 13:25:00+03	24400.00
DDEFAD	2017-07-30 17:54:00+03	56900.00
DDEFDC	2017-08-04 21:20:00+03	51900.00
DDEFFC	2017-07-19 17:19:00+03	22400.00
DDF03B	2017-08-15 12:24:00+03	25400.00
DDF090	2017-07-24 18:03:00+03	46500.00
DDF0EE	2017-07-24 14:36:00+03	242700.00
DDF10E	2017-07-12 09:08:00+03	126300.00
DDF136	2017-07-05 05:35:00+03	32800.00
DDF192	2017-06-28 17:12:00+03	48800.00
DDF293	2017-07-31 21:20:00+03	234700.00
DDF2A0	2017-08-09 14:31:00+03	16400.00
DDF32F	2017-07-10 14:32:00+03	132800.00
DDF361	2017-07-23 14:16:00+03	103200.00
DDF364	2017-07-27 07:37:00+03	25800.00
DDF367	2017-07-31 04:00:00+03	85000.00
DDF3C6	2017-07-25 07:23:00+03	53200.00
DDF3F9	2017-08-12 12:35:00+03	58200.00
DDF4EE	2017-08-01 14:16:00+03	47400.00
DDF548	2017-07-26 09:35:00+03	179200.00
DDF5F7	2017-08-05 00:49:00+03	135200.00
DDF661	2017-07-15 16:42:00+03	46800.00
DDF6A5	2017-08-10 05:45:00+03	13600.00
DDF6D1	2017-07-07 07:00:00+03	24800.00
DDF789	2017-07-04 11:12:00+03	123000.00
DDF7BD	2017-08-05 08:37:00+03	130900.00
DDF7C4	2017-07-12 17:55:00+03	131100.00
DDF86D	2017-07-11 20:41:00+03	85000.00
DDF87F	2017-08-01 20:59:00+03	173500.00
DDF891	2017-07-01 13:11:00+03	43000.00
DDF8AE	2017-07-19 18:29:00+03	35600.00
DDF8B2	2017-07-27 11:20:00+03	28000.00
DDF8B5	2017-07-12 19:59:00+03	59800.00
DDF8E0	2017-08-01 11:06:00+03	64700.00
DDF8F5	2017-08-11 10:30:00+03	45200.00
DDF937	2017-08-13 18:19:00+03	20100.00
DDF981	2017-07-27 03:42:00+03	13400.00
DDF9A7	2017-07-12 05:17:00+03	52600.00
DDFA45	2017-08-04 15:08:00+03	28600.00
DDFA6B	2017-07-07 09:22:00+03	87400.00
DDFA7A	2017-07-06 19:05:00+03	301800.00
DDFACD	2017-08-14 08:44:00+03	105400.00
DDFAF8	2017-07-02 02:18:00+03	85000.00
DDFB03	2017-07-06 20:13:00+03	212900.00
DDFB72	2017-07-27 06:44:00+03	398600.00
DDFB8C	2017-08-05 09:30:00+03	28000.00
DDFC91	2017-08-10 09:13:00+03	46800.00
DDFCB2	2017-08-11 02:38:00+03	294000.00
DDFCBD	2017-08-13 01:45:00+03	62000.00
DDFCC8	2017-08-01 17:22:00+03	58300.00
DDFCD4	2017-07-14 23:04:00+03	22000.00
DDFD85	2017-08-04 02:56:00+03	88900.00
DDFDAF	2017-07-23 17:55:00+03	132800.00
DDFDEE	2017-06-27 03:50:00+03	14800.00
DDFDF5	2017-07-11 10:55:00+03	73300.00
DDFE4E	2017-07-12 16:35:00+03	12600.00
DDFE5C	2017-07-26 01:54:00+03	23400.00
DDFE68	2017-07-23 05:16:00+03	103800.00
DDFE91	2017-08-12 20:40:00+03	26700.00
DDFE93	2017-08-03 05:00:00+03	29600.00
DDFEB2	2017-08-05 16:37:00+03	67000.00
DDFEE6	2017-07-02 22:04:00+03	46000.00
DDFF6A	2017-07-20 00:21:00+03	30400.00
DDFFC6	2017-07-09 23:45:00+03	9300.00
DE003D	2017-08-12 00:09:00+03	55800.00
DE0088	2017-07-20 04:06:00+03	265700.00
DE00A3	2017-07-18 13:52:00+03	36200.00
DE00CB	2017-07-10 03:08:00+03	67600.00
DE00E7	2017-07-31 05:58:00+03	14400.00
DE00FF	2017-08-08 00:42:00+03	393600.00
DE0138	2017-07-25 10:28:00+03	23200.00
DE018C	2017-07-06 21:31:00+03	21400.00
DE01BE	2017-07-11 05:02:00+03	23400.00
DE01F5	2017-08-09 18:09:00+03	48800.00
DE0262	2017-07-02 10:48:00+03	35200.00
DE026C	2017-08-12 15:24:00+03	39200.00
DE02D9	2017-08-10 15:27:00+03	31100.00
DE0305	2017-07-08 09:05:00+03	18800.00
DE0310	2017-08-12 05:08:00+03	102100.00
DE032F	2017-07-27 11:58:00+03	14400.00
DE03DF	2017-07-21 21:24:00+03	40000.00
DE03F9	2017-08-12 23:56:00+03	80000.00
DE049B	2017-07-09 12:56:00+03	26000.00
DE054B	2017-07-21 11:33:00+03	135200.00
DE056D	2017-07-27 15:57:00+03	69100.00
DE0573	2017-08-14 10:20:00+03	153300.00
DE063D	2017-07-07 14:41:00+03	152500.00
DE0694	2017-07-10 11:09:00+03	13200.00
DE06EA	2017-07-19 09:28:00+03	16800.00
DE0715	2017-07-11 12:26:00+03	198600.00
DE0763	2017-07-31 14:37:00+03	142400.00
DE07DF	2017-08-03 14:31:00+03	62800.00
DE0819	2017-08-06 22:27:00+03	39000.00
DE0823	2017-07-29 11:38:00+03	369000.00
DE0853	2017-08-09 20:12:00+03	63200.00
DE0856	2017-07-02 04:14:00+03	73100.00
DE0870	2017-07-16 00:03:00+03	43700.00
DE08D4	2017-07-26 21:45:00+03	52800.00
DE0900	2017-08-12 07:24:00+03	18000.00
DE093B	2017-07-25 01:24:00+03	12600.00
DE0A0F	2017-07-17 07:12:00+03	10600.00
DE0A24	2017-07-07 02:02:00+03	21200.00
DE0A6A	2017-07-14 22:52:00+03	103000.00
DE0AB7	2017-08-01 18:36:00+03	21400.00
DE0B4B	2017-07-26 17:03:00+03	70700.00
DE0BA8	2017-08-11 23:44:00+03	27300.00
DE0BDC	2017-07-17 04:00:00+03	92400.00
DE0BF6	2017-08-02 20:56:00+03	69600.00
DE0CA0	2017-06-29 11:51:00+03	99900.00
DE0CF9	2017-07-18 02:48:00+03	36200.00
DE0DA0	2017-08-06 17:43:00+03	110300.00
DE0DA8	2017-07-08 02:38:00+03	23600.00
DE0DDE	2017-07-26 05:08:00+03	55800.00
DE0E02	2017-07-22 21:37:00+03	284800.00
DE0E34	2017-07-29 19:59:00+03	56900.00
DE0EC7	2017-08-11 12:39:00+03	50300.00
DE0ECF	2017-08-05 23:59:00+03	7400.00
DE0EFB	2017-07-03 17:44:00+03	28800.00
DE0F2E	2017-07-28 09:31:00+03	393800.00
DE0F9C	2017-07-15 15:49:00+03	98100.00
DE0FB4	2017-06-30 09:48:00+03	65600.00
DE0FDE	2017-07-09 05:26:00+03	163200.00
DE1019	2017-07-04 18:02:00+03	77000.00
DE105D	2017-07-18 07:50:00+03	101200.00
DE10BF	2017-07-22 03:47:00+03	25800.00
DE1183	2017-08-12 09:05:00+03	36200.00
DE118E	2017-07-03 17:05:00+03	19600.00
DE11DF	2017-08-15 02:30:00+03	295300.00
DE11FD	2017-07-08 01:41:00+03	42800.00
DE1235	2017-07-02 07:21:00+03	29400.00
DE128C	2017-07-14 18:35:00+03	56000.00
DE12C2	2017-07-25 12:26:00+03	48800.00
DE12C3	2017-07-21 14:43:00+03	40100.00
DE12E4	2017-07-28 17:44:00+03	152500.00
DE1315	2017-07-16 13:49:00+03	26000.00
DE131E	2017-07-21 04:51:00+03	26200.00
DE1337	2017-08-02 20:27:00+03	83900.00
DE13C0	2017-08-05 15:20:00+03	6300.00
DE13C5	2017-08-04 10:01:00+03	55800.00
DE13F1	2017-08-05 03:40:00+03	133900.00
DE145E	2017-08-07 08:11:00+03	266200.00
DE147D	2017-07-02 01:03:00+03	36200.00
DE14E4	2017-07-14 11:17:00+03	29600.00
DE1520	2017-08-13 09:00:00+03	88500.00
DE153D	2017-07-28 10:00:00+03	75600.00
DE1565	2017-08-03 09:42:00+03	131600.00
DE1574	2017-07-13 19:13:00+03	31600.00
DE159A	2017-07-25 21:00:00+03	29200.00
DE15E8	2017-08-07 09:46:00+03	65900.00
DE169A	2017-07-02 16:49:00+03	6000.00
DE1745	2017-07-02 10:43:00+03	47100.00
DE186C	2017-08-09 19:15:00+03	170300.00
DE188F	2017-07-20 23:26:00+03	24400.00
DE1897	2017-07-15 00:50:00+03	13400.00
DE18BE	2017-08-10 21:35:00+03	169900.00
DE18CE	2017-08-09 21:06:00+03	246000.00
DE195F	2017-08-10 10:17:00+03	100600.00
DE19D4	2017-07-15 03:05:00+03	53400.00
DE19F5	2017-06-29 11:34:00+03	38800.00
DE1A30	2017-08-02 08:55:00+03	105400.00
DE1A3E	2017-08-15 17:07:00+03	8200.00
DE1A49	2017-07-12 03:53:00+03	306200.00
DE1AB5	2017-08-07 10:37:00+03	67000.00
DE1B03	2017-07-19 05:05:00+03	36800.00
DE1B20	2017-08-05 12:28:00+03	49100.00
DE1BCE	2017-08-11 13:27:00+03	22000.00
DE1BCF	2017-08-15 03:11:00+03	13600.00
DE1C51	2017-08-09 05:20:00+03	12600.00
DE1D0D	2017-07-20 02:27:00+03	51800.00
DE1D38	2017-06-30 09:38:00+03	6300.00
DE1D4C	2017-07-05 07:29:00+03	53500.00
DE1D71	2017-08-12 03:36:00+03	67200.00
DE1D97	2017-07-21 09:10:00+03	23200.00
DE1DA3	2017-07-11 06:33:00+03	35400.00
DE1E5C	2017-07-12 03:16:00+03	454500.00
DE1E77	2017-07-18 01:28:00+03	51900.00
DE1E81	2017-07-16 04:58:00+03	81200.00
DE1E87	2017-07-24 01:23:00+03	136800.00
DE1E8C	2017-07-22 13:32:00+03	160100.00
DE20F3	2017-07-31 19:41:00+03	62600.00
DE21F8	2017-08-06 23:29:00+03	37200.00
DE2253	2017-06-26 22:42:00+03	34000.00
DE2295	2017-07-21 18:38:00+03	233700.00
DE2306	2017-07-10 21:01:00+03	37100.00
DE2307	2017-07-01 09:09:00+03	64100.00
DE2368	2017-07-26 04:39:00+03	24400.00
DE23B1	2017-07-16 01:00:00+03	67000.00
DE23B5	2017-07-16 04:13:00+03	92000.00
DE23C3	2017-08-08 22:52:00+03	177600.00
DE23C9	2017-08-01 10:40:00+03	52400.00
DE23E3	2017-07-14 22:30:00+03	86400.00
DE23F4	2017-07-14 11:57:00+03	194200.00
DE2415	2017-08-12 07:15:00+03	44000.00
DE246D	2017-07-24 00:24:00+03	26000.00
DE2492	2017-07-13 02:23:00+03	64100.00
DE24E8	2017-08-05 03:29:00+03	67200.00
DE24F5	2017-08-06 04:01:00+03	29100.00
DE2507	2017-08-15 07:47:00+03	199100.00
DE2512	2017-08-05 15:14:00+03	27200.00
DE268F	2017-07-04 05:25:00+03	23200.00
DE26C0	2017-07-08 22:32:00+03	111600.00
DE2751	2017-08-06 02:57:00+03	70500.00
DE2771	2017-07-04 09:48:00+03	43800.00
DE27C7	2017-07-07 14:30:00+03	25200.00
DE27EA	2017-08-02 16:55:00+03	89800.00
DE27F4	2017-07-16 13:29:00+03	189200.00
DE28AA	2017-07-03 09:48:00+03	119500.00
DE28DA	2017-07-29 15:58:00+03	23000.00
DE2929	2017-07-29 20:47:00+03	26000.00
DE292D	2017-06-29 16:02:00+03	105000.00
DE29DE	2017-07-15 23:08:00+03	49500.00
DE2A00	2017-08-12 23:06:00+03	27200.00
DE2A71	2017-07-17 09:54:00+03	26700.00
DE2B75	2017-07-14 18:31:00+03	75300.00
DE2BEA	2017-07-05 22:13:00+03	40000.00
DE2C59	2017-08-13 14:12:00+03	27300.00
DE2D01	2017-07-27 03:10:00+03	136800.00
DE2D03	2017-08-04 07:14:00+03	93400.00
DE2D16	2017-07-09 22:24:00+03	64000.00
DE2D40	2017-07-23 13:12:00+03	36400.00
DE2D7C	2017-07-02 23:11:00+03	94800.00
DE2D97	2017-08-02 07:58:00+03	27400.00
DE2DDC	2017-07-04 18:29:00+03	28800.00
DE2E3D	2017-08-06 03:28:00+03	185600.00
DE2E64	2017-08-04 10:25:00+03	103100.00
DE2E83	2017-07-06 19:52:00+03	213200.00
DE2EE7	2017-08-07 04:27:00+03	30200.00
DE2F65	2017-07-10 17:47:00+03	32700.00
DE2F6D	2017-08-06 02:27:00+03	420500.00
DE2FBC	2017-07-13 16:50:00+03	41200.00
DE2FC5	2017-07-21 10:57:00+03	13700.00
DE3025	2017-07-29 06:50:00+03	24400.00
DE305A	2017-07-06 17:10:00+03	25000.00
DE30A2	2017-08-09 00:08:00+03	112000.00
DE30D6	2017-08-12 14:36:00+03	84500.00
DE311E	2017-08-07 18:44:00+03	59800.00
DE312F	2017-08-05 03:26:00+03	167400.00
DE316F	2017-07-12 19:26:00+03	100000.00
DE3172	2017-07-30 15:48:00+03	29600.00
DE31C9	2017-07-29 00:24:00+03	136500.00
DE329E	2017-08-08 21:46:00+03	81900.00
DE32EA	2017-07-16 05:47:00+03	39300.00
DE3311	2017-07-18 18:39:00+03	18000.00
DE337D	2017-07-18 13:19:00+03	132800.00
DE339C	2017-07-24 05:43:00+03	73400.00
DE33A9	2017-08-07 06:11:00+03	67600.00
DE33AC	2017-07-20 19:30:00+03	80500.00
DE33F9	2017-07-20 13:55:00+03	40600.00
DE33FE	2017-07-02 09:38:00+03	6300.00
DE342C	2017-07-11 20:42:00+03	89700.00
DE3448	2017-07-30 15:09:00+03	111600.00
DE34F8	2017-07-17 15:22:00+03	25200.00
DE3502	2017-07-20 10:37:00+03	99300.00
DE3566	2017-08-09 04:51:00+03	29600.00
DE3569	2017-07-24 22:59:00+03	56000.00
DE3588	2017-07-19 04:45:00+03	147300.00
DE35C1	2017-07-11 17:45:00+03	18400.00
DE35E5	2017-07-08 23:54:00+03	105000.00
DE362C	2017-07-22 01:30:00+03	97700.00
DE3669	2017-07-23 18:22:00+03	47400.00
DE367D	2017-08-15 09:45:00+03	92000.00
DE36BC	2017-07-27 02:18:00+03	13400.00
DE3704	2017-07-15 05:19:00+03	52000.00
DE3712	2017-08-12 07:14:00+03	48100.00
DE37CD	2017-08-05 19:48:00+03	88600.00
DE388E	2017-07-04 17:05:00+03	57600.00
DE38C0	2017-07-26 02:56:00+03	202700.00
DE393C	2017-07-10 13:08:00+03	64600.00
DE398F	2017-07-03 20:03:00+03	66000.00
DE39E3	2017-08-06 22:44:00+03	23400.00
DE39E6	2017-07-31 16:25:00+03	9800.00
DE3A19	2017-07-30 20:07:00+03	65500.00
DE3A2A	2017-07-24 21:17:00+03	28800.00
DE3A59	2017-07-29 20:49:00+03	34800.00
DE3A6E	2017-08-06 07:01:00+03	282300.00
DE3A8C	2017-06-27 09:21:00+03	36200.00
DE3AC6	2017-07-08 13:08:00+03	124000.00
DE3AE2	2017-08-03 21:23:00+03	141000.00
DE3AEA	2017-07-31 07:49:00+03	23400.00
DE3AEF	2017-07-23 11:20:00+03	99300.00
DE3B0E	2017-07-05 13:48:00+03	135600.00
DE3B59	2017-06-30 06:07:00+03	68400.00
DE3B7F	2017-07-21 03:08:00+03	187800.00
DE3B8D	2017-07-28 19:22:00+03	337900.00
DE3C63	2017-08-09 13:41:00+03	38800.00
DE3C92	2017-08-06 06:33:00+03	76800.00
DE3CA0	2017-07-05 13:20:00+03	65900.00
DE3CCB	2017-07-04 14:19:00+03	161500.00
DE3D62	2017-07-25 03:41:00+03	204200.00
DE3D86	2017-07-15 12:51:00+03	59300.00
DE3DA5	2017-08-02 12:58:00+03	12400.00
DE3DE1	2017-07-30 14:54:00+03	39200.00
DE3DEE	2017-08-07 01:27:00+03	50800.00
DE3E1A	2017-07-10 04:10:00+03	25200.00
DE3E64	2017-07-28 18:20:00+03	39300.00
DE3E78	2017-07-18 05:52:00+03	194300.00
DE3EA6	2017-07-04 21:12:00+03	6200.00
DE3EC4	2017-07-30 10:32:00+03	90000.00
DE3EE9	2017-08-05 06:01:00+03	44000.00
DE3F11	2017-07-15 07:41:00+03	23600.00
DE3F4D	2017-07-29 03:22:00+03	112000.00
DE3FE9	2017-08-11 07:11:00+03	25000.00
DE3FFE	2017-07-03 05:22:00+03	58400.00
DE4007	2017-07-13 09:49:00+03	32700.00
DE4028	2017-08-02 14:07:00+03	47300.00
DE406A	2017-07-21 20:06:00+03	21400.00
DE40BF	2017-07-10 14:09:00+03	64300.00
DE40CF	2017-07-24 15:11:00+03	40000.00
DE410D	2017-08-01 15:23:00+03	92800.00
DE412E	2017-08-11 17:13:00+03	59300.00
DE4173	2017-08-03 00:34:00+03	51600.00
DE41B8	2017-07-01 19:17:00+03	26000.00
DE4205	2017-07-09 09:58:00+03	43600.00
DE4211	2017-07-25 15:45:00+03	49200.00
DE4215	2017-07-04 17:38:00+03	34000.00
DE4279	2017-07-30 13:13:00+03	45200.00
DE42A0	2017-07-24 14:35:00+03	55800.00
DE42AC	2017-07-09 15:54:00+03	34000.00
DE42FF	2017-07-15 19:49:00+03	22000.00
DE4312	2017-07-25 01:27:00+03	29600.00
DE435A	2017-07-26 17:15:00+03	27700.00
DE438C	2017-07-21 11:20:00+03	32800.00
DE4393	2017-08-13 08:20:00+03	49100.00
DE4398	2017-08-01 18:10:00+03	92400.00
DE4409	2017-07-22 23:55:00+03	105100.00
DE4466	2017-08-07 06:14:00+03	218000.00
DE446C	2017-07-17 18:09:00+03	114400.00
DE446D	2017-07-13 15:13:00+03	56000.00
DE4479	2017-08-04 11:13:00+03	6700.00
DE44AD	2017-07-23 23:02:00+03	75600.00
DE4512	2017-07-11 09:24:00+03	64800.00
DE451F	2017-08-05 09:24:00+03	62000.00
DE4521	2017-07-13 21:57:00+03	118600.00
DE452A	2017-08-01 02:49:00+03	307500.00
DE453D	2017-07-01 06:58:00+03	80800.00
DE457C	2017-08-15 16:30:00+03	21400.00
DE4589	2017-07-22 13:03:00+03	50000.00
DE458D	2017-07-09 11:22:00+03	28800.00
DE45C9	2017-07-02 09:51:00+03	72200.00
DE4603	2017-07-20 18:32:00+03	46300.00
DE4711	2017-07-13 12:35:00+03	174600.00
DE475A	2017-07-27 16:46:00+03	9800.00
DE4856	2017-07-19 23:42:00+03	53600.00
DE486B	2017-07-27 22:40:00+03	81700.00
DE48AD	2017-07-22 09:51:00+03	84100.00
DE48EF	2017-07-30 17:20:00+03	174000.00
DE48FF	2017-07-28 06:48:00+03	23200.00
DE491D	2017-07-18 16:12:00+03	25400.00
DE495A	2017-07-29 21:53:00+03	92400.00
DE4963	2017-08-11 04:36:00+03	60000.00
DE498B	2017-07-18 00:26:00+03	30400.00
DE49BF	2017-08-03 03:48:00+03	56900.00
DE49F6	2017-07-26 15:40:00+03	32700.00
DE4A5A	2017-07-08 22:15:00+03	56000.00
DE4AF8	2017-07-18 17:44:00+03	6800.00
DE4AFB	2017-07-30 13:25:00+03	23600.00
DE4B0D	2017-07-16 03:00:00+03	12600.00
DE4B14	2017-08-06 23:08:00+03	39200.00
DE4B30	2017-07-12 18:50:00+03	24700.00
DE4B84	2017-07-01 15:43:00+03	34000.00
DE4BAD	2017-08-07 05:42:00+03	116000.00
DE4BDE	2017-08-03 07:21:00+03	47500.00
DE4BEC	2017-08-04 02:35:00+03	23200.00
DE4C0F	2017-07-25 14:17:00+03	78800.00
DE4C11	2017-07-28 14:57:00+03	14000.00
DE4CAA	2017-07-09 09:47:00+03	114900.00
DE4D05	2017-07-23 19:43:00+03	8200.00
DE4D19	2017-07-11 21:53:00+03	86600.00
DE4D25	2017-08-13 04:31:00+03	115900.00
DE4D83	2017-08-09 06:08:00+03	51900.00
DE4D9D	2017-07-10 10:13:00+03	124200.00
DE4DA1	2017-08-05 04:31:00+03	17600.00
DE4E11	2017-08-03 01:56:00+03	28800.00
DE4E61	2017-07-30 23:48:00+03	66600.00
DE4E6A	2017-07-08 18:34:00+03	45400.00
DE4E81	2017-08-01 15:21:00+03	32900.00
DE4EAE	2017-07-04 03:07:00+03	55800.00
DE4EDF	2017-07-26 01:07:00+03	55800.00
DE4F2D	2017-07-16 04:14:00+03	46200.00
DE4F75	2017-08-04 18:51:00+03	25400.00
DE4FCB	2017-07-04 13:33:00+03	55800.00
DE5058	2017-07-16 03:09:00+03	25600.00
DE506D	2017-07-28 05:07:00+03	68100.00
DE50BC	2017-07-30 18:47:00+03	36200.00
DE5107	2017-07-24 16:57:00+03	135600.00
DE5124	2017-08-06 03:12:00+03	154500.00
DE5162	2017-07-29 16:32:00+03	56100.00
DE5166	2017-07-28 00:41:00+03	52400.00
DE51AE	2017-07-06 12:56:00+03	111600.00
DE5298	2017-07-24 01:29:00+03	63800.00
DE52BE	2017-07-26 00:02:00+03	25400.00
DE530A	2017-08-08 23:58:00+03	275900.00
DE5378	2017-07-18 20:01:00+03	36200.00
DE5394	2017-07-18 02:57:00+03	54800.00
DE5426	2017-07-17 17:59:00+03	146600.00
DE542A	2017-07-17 10:57:00+03	8600.00
DE5464	2017-08-11 03:03:00+03	229500.00
DE5491	2017-07-25 07:30:00+03	187800.00
DE54B7	2017-07-21 09:44:00+03	111600.00
DE54B9	2017-06-29 14:36:00+03	8000.00
DE54C2	2017-07-29 08:26:00+03	73300.00
DE54E9	2017-07-19 00:30:00+03	115600.00
DE550D	2017-07-16 00:51:00+03	15000.00
DE552E	2017-07-14 01:19:00+03	26800.00
DE5575	2017-07-06 18:20:00+03	55800.00
DE55CA	2017-07-15 17:10:00+03	48400.00
DE568E	2017-08-05 01:29:00+03	113200.00
DE56B6	2017-08-05 17:54:00+03	49500.00
DE56CC	2017-08-07 10:38:00+03	11700.00
DE571D	2017-08-08 18:21:00+03	12400.00
DE574A	2017-08-11 06:36:00+03	196800.00
DE5776	2017-07-02 11:12:00+03	73600.00
DE578B	2017-07-26 11:24:00+03	224000.00
DE57A1	2017-07-21 01:46:00+03	16400.00
DE57CA	2017-07-28 16:05:00+03	153300.00
DE57FE	2017-08-05 17:59:00+03	20400.00
DE5891	2017-07-07 07:18:00+03	17200.00
DE5895	2017-07-21 16:28:00+03	404600.00
DE589B	2017-07-05 10:15:00+03	29600.00
DE58D0	2017-07-27 00:23:00+03	46200.00
DE5911	2017-07-28 02:09:00+03	85400.00
DE5921	2017-08-02 19:02:00+03	56600.00
DE593C	2017-07-04 10:23:00+03	26700.00
DE594B	2017-08-08 10:24:00+03	133200.00
DE5988	2017-08-06 21:05:00+03	378400.00
DE5989	2017-08-03 21:38:00+03	167900.00
DE5A16	2017-08-11 17:08:00+03	92800.00
DE5A18	2017-08-12 01:54:00+03	84100.00
DE5A26	2017-08-13 15:08:00+03	55800.00
DE5A67	2017-08-04 23:28:00+03	258400.00
DE5A7C	2017-07-29 11:08:00+03	24400.00
DE5B76	2017-07-31 03:00:00+03	97800.00
DE5B8B	2017-07-17 10:50:00+03	118400.00
DE5BCE	2017-08-03 20:08:00+03	166100.00
DE5C23	2017-07-19 11:21:00+03	78300.00
DE5C42	2017-07-03 23:18:00+03	149200.00
DE5D08	2017-08-14 23:58:00+03	146300.00
DE5D61	2017-07-20 23:25:00+03	73800.00
DE5DE2	2017-07-30 21:04:00+03	38500.00
DE5DE4	2017-07-05 11:03:00+03	30200.00
DE5E52	2017-08-02 02:57:00+03	88200.00
DE5F12	2017-07-29 04:52:00+03	58700.00
DE5F24	2017-07-01 22:19:00+03	59700.00
DE5F3A	2017-07-30 19:23:00+03	21400.00
DE5F41	2017-07-31 13:29:00+03	46400.00
DE5F62	2017-07-21 16:14:00+03	81100.00
DE5F86	2017-08-06 23:11:00+03	26700.00
DE5FB5	2017-07-29 04:07:00+03	50000.00
DE6001	2017-07-07 09:34:00+03	28000.00
DE6028	2017-07-02 22:19:00+03	71600.00
DE602D	2017-07-31 21:18:00+03	73400.00
DE6034	2017-07-04 19:42:00+03	36800.00
DE611D	2017-07-06 20:30:00+03	82300.00
DE616E	2017-07-10 03:59:00+03	13600.00
DE61D0	2017-08-03 14:07:00+03	48900.00
DE6242	2017-08-10 02:47:00+03	14000.00
DE6257	2017-07-28 12:11:00+03	273000.00
DE62DB	2017-07-23 11:20:00+03	109600.00
DE62EC	2017-07-09 01:44:00+03	6300.00
DE6301	2017-08-06 02:43:00+03	44300.00
DE6306	2017-08-15 06:23:00+03	48200.00
DE634E	2017-07-13 17:52:00+03	25600.00
DE6353	2017-08-14 14:43:00+03	70700.00
DE6362	2017-06-30 07:12:00+03	123000.00
DE63CC	2017-08-09 05:22:00+03	40800.00
DE642B	2017-07-08 16:32:00+03	37100.00
DE646F	2017-07-21 12:02:00+03	16400.00
DE6496	2017-08-06 03:41:00+03	10800.00
DE6499	2017-08-09 21:30:00+03	31600.00
DE64B1	2017-08-10 05:29:00+03	105600.00
DE64EF	2017-07-05 20:53:00+03	54000.00
DE656B	2017-08-15 08:20:00+03	92600.00
DE6582	2017-07-30 20:42:00+03	75600.00
DE65D4	2017-07-31 16:30:00+03	173500.00
DE662D	2017-07-22 04:44:00+03	80400.00
DE6638	2017-07-19 21:29:00+03	88500.00
DE6684	2017-07-02 06:29:00+03	153300.00
DE66CE	2017-07-02 05:00:00+03	69500.00
DE66CF	2017-08-03 05:44:00+03	260300.00
DE671F	2017-07-14 15:55:00+03	93800.00
DE6770	2017-07-04 14:32:00+03	191300.00
DE67CE	2017-06-30 01:15:00+03	42800.00
DE67E2	2017-07-09 09:01:00+03	40000.00
DE69BD	2017-07-31 07:06:00+03	68000.00
DE6A01	2017-07-12 20:35:00+03	6700.00
DE6A04	2017-07-19 20:44:00+03	34000.00
DE6A62	2017-08-01 13:18:00+03	14000.00
DE6A92	2017-08-12 11:32:00+03	55800.00
DE6A9F	2017-07-20 00:01:00+03	26000.00
DE6AC8	2017-07-25 09:58:00+03	104800.00
DE6B4A	2017-08-10 00:49:00+03	32400.00
DE6BC5	2017-07-21 13:45:00+03	137800.00
DE6C59	2017-08-10 00:16:00+03	406700.00
DE6D53	2017-08-06 12:18:00+03	34000.00
DE6DC0	2017-08-09 16:49:00+03	144300.00
DE6DD3	2017-08-14 02:08:00+03	49900.00
DE6DE0	2017-08-01 19:24:00+03	52600.00
DE6DF8	2017-07-03 19:19:00+03	14400.00
DE6E29	2017-08-03 05:48:00+03	95500.00
DE6EC7	2017-07-27 15:12:00+03	59400.00
DE6EE4	2017-08-04 17:00:00+03	25600.00
DE6EFD	2017-07-06 21:19:00+03	125700.00
DE702A	2017-07-24 12:03:00+03	32900.00
DE703D	2017-07-17 18:30:00+03	30000.00
DE7045	2017-08-13 02:30:00+03	56600.00
DE705E	2017-08-01 20:52:00+03	35800.00
DE70ED	2017-07-28 07:04:00+03	77200.00
DE70FA	2017-08-14 10:22:00+03	77900.00
DE7197	2017-07-16 05:57:00+03	20200.00
DE71D5	2017-08-14 01:14:00+03	68100.00
DE720A	2017-07-08 23:24:00+03	29400.00
DE725F	2017-07-11 09:19:00+03	131600.00
DE72A2	2017-07-28 13:48:00+03	52000.00
DE72EF	2017-07-03 07:22:00+03	46900.00
DE7311	2017-08-07 05:52:00+03	23200.00
DE7383	2017-08-12 11:17:00+03	13800.00
DE73AC	2017-08-06 17:36:00+03	178800.00
DE73E7	2017-07-23 11:01:00+03	58600.00
DE7462	2017-07-15 00:11:00+03	47800.00
DE747D	2017-07-16 03:31:00+03	190700.00
DE749D	2017-07-16 22:42:00+03	179500.00
DE74C8	2017-07-24 17:34:00+03	355200.00
DE74CA	2017-08-14 11:08:00+03	30100.00
DE74CB	2017-08-02 02:20:00+03	39800.00
DE7548	2017-07-29 00:00:00+03	187600.00
DE766A	2017-08-05 18:43:00+03	48500.00
DE7675	2017-07-25 23:11:00+03	58900.00
DE7680	2017-08-07 10:02:00+03	8000.00
DE76DB	2017-08-15 12:28:00+03	135400.00
DE777A	2017-08-05 04:17:00+03	25600.00
DE7789	2017-07-07 10:54:00+03	242700.00
DE77FF	2017-08-09 23:16:00+03	57500.00
DE7809	2017-07-03 10:11:00+03	66600.00
DE7827	2017-08-04 05:46:00+03	117700.00
DE785B	2017-07-17 19:22:00+03	33600.00
DE7876	2017-07-27 09:56:00+03	67200.00
DE7880	2017-07-09 00:48:00+03	410400.00
DE78B4	2017-07-06 09:01:00+03	17800.00
DE78E3	2017-07-28 03:49:00+03	43300.00
DE78F2	2017-08-15 07:02:00+03	30200.00
DE792A	2017-08-12 05:47:00+03	29600.00
DE79A1	2017-07-11 19:55:00+03	68000.00
DE79D0	2017-07-11 05:40:00+03	56600.00
DE7A2D	2017-08-01 14:16:00+03	46300.00
DE7AAF	2017-07-04 09:02:00+03	42800.00
DE7AB6	2017-08-03 07:12:00+03	136500.00
DE7B21	2017-07-18 15:05:00+03	125200.00
DE7B68	2017-07-17 14:32:00+03	67200.00
DE7BF0	2017-08-01 06:36:00+03	53200.00
DE7C2F	2017-07-16 20:12:00+03	28800.00
DE7C74	2017-07-27 18:42:00+03	85200.00
DE7CA3	2017-07-12 01:44:00+03	57700.00
DE7CCD	2017-07-11 02:43:00+03	46400.00
DE7CD1	2017-07-07 05:38:00+03	93000.00
DE7D36	2017-07-30 07:09:00+03	75300.00
DE7D74	2017-08-03 05:54:00+03	51300.00
DE7DEF	2017-08-07 09:24:00+03	75300.00
DE7DFD	2017-07-05 06:27:00+03	139400.00
DE7E09	2017-07-24 04:03:00+03	64500.00
DE7E40	2017-07-04 02:25:00+03	72200.00
DE7E97	2017-07-23 12:38:00+03	56600.00
DE7EB6	2017-07-26 12:25:00+03	67700.00
DE7FDB	2017-08-03 21:27:00+03	566100.00
DE8098	2017-07-05 14:39:00+03	122500.00
DE80BE	2017-08-03 17:29:00+03	241500.00
DE8185	2017-07-09 12:44:00+03	12600.00
DE8186	2017-07-03 22:24:00+03	88100.00
DE81D5	2017-08-11 15:45:00+03	206000.00
DE8221	2017-07-14 03:56:00+03	54800.00
DE8281	2017-07-09 20:27:00+03	369000.00
DE82C0	2017-07-03 08:53:00+03	94000.00
DE82DD	2017-08-02 02:12:00+03	23200.00
DE82E0	2017-07-07 12:17:00+03	100600.00
DE830E	2017-07-28 12:17:00+03	43200.00
DE833C	2017-07-23 11:36:00+03	40800.00
DE8343	2017-07-21 11:47:00+03	126600.00
DE8369	2017-07-06 20:42:00+03	45200.00
DE839D	2017-08-03 11:35:00+03	170700.00
DE83A5	2017-07-19 12:43:00+03	14400.00
DE842F	2017-08-06 14:46:00+03	123000.00
DE8430	2017-07-24 15:26:00+03	14000.00
DE847A	2017-07-14 12:28:00+03	46300.00
DE848F	2017-08-14 00:50:00+03	100000.00
DE84D6	2017-07-27 19:49:00+03	72800.00
DE8510	2017-07-21 12:23:00+03	134400.00
DE8511	2017-07-10 13:20:00+03	157700.00
DE8529	2017-07-22 03:05:00+03	55800.00
DE852D	2017-08-05 01:58:00+03	31000.00
DE8583	2017-08-08 12:16:00+03	57300.00
DE85E7	2017-07-26 05:26:00+03	56600.00
DE86A7	2017-07-07 06:30:00+03	35800.00
DE86FF	2017-08-15 11:45:00+03	26000.00
DE8700	2017-08-05 05:53:00+03	393800.00
DE8701	2017-07-09 22:16:00+03	56600.00
DE8733	2017-08-15 09:01:00+03	56000.00
DE877B	2017-07-13 14:45:00+03	34000.00
DE87AC	2017-07-13 19:56:00+03	154400.00
DE87E4	2017-07-31 00:41:00+03	23100.00
DE8882	2017-08-09 15:18:00+03	56000.00
DE8929	2017-08-01 00:45:00+03	95200.00
DE8940	2017-07-24 19:44:00+03	99200.00
DE89FA	2017-07-30 13:09:00+03	78500.00
DE8A5C	2017-08-03 07:03:00+03	26700.00
DE8A74	2017-08-08 23:33:00+03	49100.00
DE8B16	2017-08-14 21:03:00+03	129200.00
DE8B3C	2017-08-14 10:59:00+03	199600.00
DE8BB1	2017-07-28 10:30:00+03	112000.00
DE8BBC	2017-07-24 04:08:00+03	45300.00
DE8BBD	2017-07-17 19:35:00+03	6700.00
DE8BC5	2017-08-02 22:06:00+03	40800.00
DE8BC8	2017-08-12 21:23:00+03	57500.00
DE8C0B	2017-07-08 05:16:00+03	116800.00
DE8C6C	2017-07-09 05:01:00+03	80500.00
DE8C76	2017-07-29 23:30:00+03	65500.00
DE8C9C	2017-08-07 18:35:00+03	29600.00
DE8CB3	2017-06-30 13:33:00+03	13000.00
DE8CE4	2017-07-24 10:33:00+03	25000.00
DE8CFD	2017-08-14 21:18:00+03	49300.00
DE8E67	2017-07-29 20:54:00+03	99700.00
DE8E7C	2017-07-25 00:44:00+03	6700.00
DE8F8D	2017-07-15 12:47:00+03	74400.00
DE9036	2017-08-02 15:38:00+03	38200.00
DE907C	2017-08-07 09:49:00+03	45000.00
DE9085	2017-07-20 03:35:00+03	123700.00
DE90E9	2017-07-10 07:51:00+03	91800.00
DE90F6	2017-07-31 10:58:00+03	56000.00
DE913A	2017-08-09 13:59:00+03	63400.00
DE9159	2017-08-05 14:48:00+03	32800.00
DE9175	2017-08-10 17:54:00+03	123000.00
DE91A5	2017-08-02 02:24:00+03	43500.00
DE91D6	2017-08-01 15:10:00+03	78900.00
DE9219	2017-07-19 06:03:00+03	14000.00
DE9270	2017-08-13 09:20:00+03	49500.00
DE9336	2017-07-18 11:20:00+03	18600.00
DE9371	2017-07-23 13:26:00+03	28000.00
DE937F	2017-07-21 09:28:00+03	133200.00
DE93CB	2017-08-06 16:52:00+03	81300.00
DE93DA	2017-07-11 13:35:00+03	46200.00
DE940F	2017-07-10 06:07:00+03	89600.00
DE9441	2017-07-14 11:12:00+03	68400.00
DE948A	2017-07-14 13:56:00+03	69600.00
DE94CD	2017-07-27 02:56:00+03	6700.00
DE956E	2017-06-28 10:07:00+03	61200.00
DE95C3	2017-08-08 10:55:00+03	47000.00
DE95D0	2017-07-22 11:56:00+03	28000.00
DE95D5	2017-07-07 22:57:00+03	46200.00
DE961F	2017-07-16 04:09:00+03	40600.00
DE9623	2017-07-14 14:57:00+03	65600.00
DE9658	2017-07-06 00:31:00+03	63300.00
DE96C9	2017-07-25 17:44:00+03	59200.00
DE9795	2017-08-05 10:11:00+03	143100.00
DE97AC	2017-08-11 14:29:00+03	37900.00
DE97C1	2017-08-10 05:53:00+03	26000.00
DE97D4	2017-07-27 06:03:00+03	55800.00
DE9883	2017-08-13 23:12:00+03	61800.00
DE991D	2017-07-01 14:59:00+03	20400.00
DE993C	2017-07-04 00:09:00+03	8600.00
DE995F	2017-07-24 03:00:00+03	57600.00
DE9961	2017-07-18 03:28:00+03	85000.00
DE999B	2017-08-11 02:39:00+03	15300.00
DE99E2	2017-07-10 11:12:00+03	56000.00
DE99E7	2017-08-09 20:50:00+03	23600.00
DE99F2	2017-08-14 20:07:00+03	29100.00
DE9A4C	2017-08-02 19:10:00+03	85000.00
DE9A53	2017-08-13 06:27:00+03	22400.00
DE9A88	2017-07-11 09:28:00+03	286100.00
DE9A9B	2017-07-12 23:51:00+03	69600.00
DE9AAA	2017-07-12 16:14:00+03	13800.00
DE9AAD	2017-08-14 21:11:00+03	23600.00
DE9ACA	2017-08-03 12:50:00+03	89600.00
DE9B04	2017-08-08 06:02:00+03	27300.00
DE9B3C	2017-07-25 09:21:00+03	37900.00
DE9B54	2017-08-11 10:16:00+03	20600.00
DE9B71	2017-07-26 20:53:00+03	31600.00
DE9C0E	2017-07-27 00:05:00+03	42800.00
DE9C11	2017-08-10 23:48:00+03	213200.00
DE9C97	2017-07-31 18:11:00+03	23400.00
DE9D6E	2017-07-26 15:35:00+03	272400.00
DE9D81	2017-07-21 11:29:00+03	18300.00
DE9DE4	2017-07-20 15:53:00+03	23600.00
DE9E0B	2017-08-10 04:23:00+03	29600.00
DE9E34	2017-08-13 20:54:00+03	16400.00
DE9E3D	2017-08-11 22:06:00+03	59200.00
DE9EE1	2017-08-06 15:33:00+03	12600.00
DE9F0C	2017-08-08 13:52:00+03	54800.00
DE9F34	2017-08-01 08:41:00+03	106600.00
DE9F64	2017-07-02 19:44:00+03	46400.00
DE9F7F	2017-06-25 04:11:00+03	40200.00
DE9FA1	2017-07-23 04:45:00+03	44000.00
DEA00B	2017-07-14 18:14:00+03	55800.00
DEA034	2017-07-12 16:50:00+03	6700.00
DEA047	2017-07-29 13:23:00+03	76600.00
DEA094	2017-08-14 11:53:00+03	192600.00
DEA0C0	2017-08-14 22:27:00+03	59800.00
DEA109	2017-08-11 16:33:00+03	14000.00
DEA110	2017-07-17 21:25:00+03	24800.00
DEA11C	2017-08-13 00:50:00+03	23400.00
DEA13B	2017-07-28 02:09:00+03	26000.00
DEA147	2017-07-10 11:14:00+03	532800.00
DEA156	2017-07-13 15:43:00+03	89600.00
DEA1F7	2017-07-12 09:44:00+03	120100.00
DEA25A	2017-07-20 13:27:00+03	35600.00
DEA2CF	2017-07-12 00:52:00+03	66600.00
DEA356	2017-06-29 03:23:00+03	124200.00
DEA35A	2017-07-20 23:06:00+03	23200.00
DEA3BB	2017-08-12 02:59:00+03	39800.00
DEA3D2	2017-07-29 09:00:00+03	40400.00
DEA470	2017-08-07 13:03:00+03	39800.00
DEA476	2017-08-05 14:47:00+03	44000.00
DEA491	2017-08-03 04:47:00+03	47000.00
DEA4AF	2017-07-06 18:14:00+03	37200.00
DEA5ED	2017-08-10 19:26:00+03	92000.00
DEA642	2017-07-28 22:12:00+03	15100.00
DEA67E	2017-07-04 00:57:00+03	83600.00
DEA6F8	2017-07-05 02:58:00+03	323800.00
DEA7A6	2017-06-30 20:16:00+03	38600.00
DEA7C6	2017-08-11 20:08:00+03	139400.00
DEA7F2	2017-07-04 14:06:00+03	173600.00
DEA876	2017-08-08 17:14:00+03	147700.00
DEA891	2017-08-12 23:47:00+03	23600.00
DEA909	2017-08-10 17:01:00+03	55800.00
DEA925	2017-07-19 14:11:00+03	26800.00
DEA9C8	2017-07-18 10:53:00+03	11600.00
DEA9E5	2017-08-12 07:39:00+03	79400.00
DEAA08	2017-07-30 15:01:00+03	32800.00
DEAA95	2017-08-13 17:31:00+03	7300.00
DEAA9A	2017-08-13 00:10:00+03	16000.00
DEAAB5	2017-08-07 04:44:00+03	101700.00
DEAADD	2017-07-22 13:00:00+03	52000.00
DEAB7B	2017-07-07 04:29:00+03	99300.00
DEAC40	2017-08-04 05:36:00+03	272400.00
DEAC43	2017-07-24 04:54:00+03	45200.00
DEAC8A	2017-08-06 01:52:00+03	27200.00
DEAC90	2017-07-06 19:45:00+03	22000.00
DEAD22	2017-08-03 22:09:00+03	44000.00
DEAD5E	2017-07-23 21:48:00+03	20200.00
DEADA2	2017-07-29 12:24:00+03	391500.00
DEADB7	2017-07-04 13:14:00+03	27900.00
DEADD7	2017-07-05 02:22:00+03	57600.00
DEADDF	2017-07-23 14:20:00+03	35300.00
DEADE8	2017-08-02 19:41:00+03	88400.00
DEAE16	2017-08-06 17:54:00+03	38800.00
DEAE1B	2017-06-29 07:56:00+03	46300.00
DEAE3B	2017-07-15 12:30:00+03	55800.00
DEAE4F	2017-07-16 17:22:00+03	69800.00
DEAE72	2017-08-10 11:13:00+03	84500.00
DEAFA4	2017-07-31 02:39:00+03	28000.00
DEAFBC	2017-07-04 09:22:00+03	55800.00
DEB014	2017-07-02 04:56:00+03	44500.00
DEB0B8	2017-08-09 20:29:00+03	7400.00
DEB182	2017-08-11 19:50:00+03	74400.00
DEB18B	2017-08-07 07:22:00+03	25600.00
DEB1A3	2017-07-07 18:52:00+03	125200.00
DEB201	2017-07-09 10:26:00+03	32200.00
DEB25D	2017-07-31 06:26:00+03	18800.00
DEB307	2017-07-09 06:52:00+03	246800.00
DEB350	2017-07-05 17:57:00+03	99700.00
DEB361	2017-08-03 17:04:00+03	38600.00
DEB3B3	2017-08-09 09:11:00+03	16400.00
DEB3FF	2017-07-12 07:06:00+03	31600.00
DEB425	2017-07-08 10:12:00+03	111600.00
DEB4B6	2017-07-18 13:16:00+03	56600.00
DEB4DF	2017-07-15 16:05:00+03	316100.00
DEB516	2017-08-06 08:27:00+03	28800.00
DEB547	2017-07-23 22:44:00+03	99200.00
DEB54B	2017-08-06 04:51:00+03	56000.00
DEB563	2017-08-04 04:14:00+03	110700.00
DEB5AE	2017-08-10 14:08:00+03	86400.00
DEB614	2017-08-05 13:50:00+03	85000.00
DEB61B	2017-06-30 10:35:00+03	286500.00
DEB61C	2017-07-14 19:05:00+03	38600.00
DEB659	2017-07-05 04:13:00+03	229900.00
DEB660	2017-07-28 09:57:00+03	44000.00
DEB695	2017-07-11 10:19:00+03	46000.00
DEB6A7	2017-07-04 14:24:00+03	16400.00
DEB737	2017-06-29 01:49:00+03	15400.00
DEB74C	2017-07-31 06:46:00+03	26800.00
DEB775	2017-08-14 22:16:00+03	15700.00
DEB799	2017-07-27 20:36:00+03	38800.00
DEB7BD	2017-07-18 06:10:00+03	21400.00
DEB7F8	2017-07-15 04:27:00+03	25900.00
DEB8DE	2017-07-31 16:48:00+03	398500.00
DEB8FB	2017-07-26 06:25:00+03	39200.00
DEB932	2017-07-03 07:53:00+03	28000.00
DEB963	2017-07-09 19:39:00+03	44800.00
DEB9B9	2017-07-08 09:35:00+03	60400.00
DEBA1C	2017-08-11 23:47:00+03	56600.00
DEBA24	2017-07-24 15:30:00+03	200300.00
DEBA9E	2017-07-12 18:07:00+03	258400.00
DEBAA4	2017-07-07 14:11:00+03	40800.00
DEBACD	2017-07-02 13:26:00+03	24400.00
DEBAD9	2017-07-24 18:23:00+03	12600.00
DEBAF7	2017-07-31 15:40:00+03	47000.00
DEBAF8	2017-07-25 15:17:00+03	23200.00
DEBB0F	2017-07-25 13:32:00+03	54800.00
DEBB2D	2017-07-23 16:52:00+03	124300.00
DEBB52	2017-07-31 18:17:00+03	128800.00
DEBB74	2017-07-21 04:23:00+03	155500.00
DEBC24	2017-07-14 01:00:00+03	38600.00
DEBC93	2017-08-07 04:44:00+03	141500.00
DEBD58	2017-06-30 23:47:00+03	28000.00
DEBD5E	2017-08-10 05:12:00+03	26000.00
DEBD70	2017-08-02 10:56:00+03	24600.00
DEBDFB	2017-07-25 14:14:00+03	24400.00
DEBE19	2017-08-05 11:00:00+03	28800.00
DEBEFF	2017-07-18 08:01:00+03	73200.00
DEBF38	2017-07-24 12:29:00+03	66600.00
DEBF90	2017-08-02 09:18:00+03	44500.00
DEBFD9	2017-08-11 17:26:00+03	56000.00
DEC0AD	2017-07-29 15:25:00+03	65300.00
DEC0B6	2017-07-14 16:56:00+03	67600.00
DEC0C5	2017-07-29 16:53:00+03	149100.00
DEC0E3	2017-08-02 02:12:00+03	75600.00
DEC0EB	2017-08-15 03:47:00+03	100700.00
DEC136	2017-08-03 14:53:00+03	37900.00
DEC146	2017-07-18 10:21:00+03	26600.00
DEC167	2017-07-02 22:18:00+03	34100.00
DEC1A3	2017-08-06 16:32:00+03	45200.00
DEC2E3	2017-07-15 17:42:00+03	406700.00
DEC2E9	2017-08-07 03:52:00+03	48800.00
DEC305	2017-07-11 17:45:00+03	211600.00
DEC31E	2017-07-22 06:41:00+03	13200.00
DEC328	2017-07-27 11:13:00+03	115800.00
DEC372	2017-07-13 14:00:00+03	55800.00
DEC37C	2017-07-20 11:36:00+03	28800.00
DEC393	2017-07-14 07:07:00+03	67200.00
DEC3B9	2017-07-23 07:39:00+03	51200.00
DEC3E1	2017-07-08 15:40:00+03	46000.00
DEC3F5	2017-08-05 22:11:00+03	47100.00
DEC40B	2017-07-21 09:45:00+03	68400.00
DEC443	2017-07-19 19:48:00+03	43600.00
DEC475	2017-07-19 20:34:00+03	137600.00
DEC4BE	2017-07-24 17:31:00+03	135400.00
DEC4C5	2017-08-01 19:15:00+03	46400.00
DEC620	2017-07-09 13:38:00+03	8200.00
DEC62A	2017-07-21 06:33:00+03	49100.00
DEC6D4	2017-07-09 07:21:00+03	31600.00
DEC6FF	2017-07-01 16:59:00+03	52300.00
DEC751	2017-07-04 03:35:00+03	10600.00
DEC7BB	2017-08-06 09:23:00+03	49200.00
DEC7C4	2017-06-28 11:01:00+03	30200.00
DEC7D4	2017-08-14 13:55:00+03	40800.00
DEC7F3	2017-07-21 17:00:00+03	101800.00
DEC809	2017-08-01 00:50:00+03	406200.00
DEC821	2017-07-22 21:07:00+03	15100.00
DEC834	2017-08-11 05:47:00+03	14000.00
DEC835	2017-08-14 12:35:00+03	43900.00
DEC8B9	2017-07-14 23:02:00+03	51200.00
DEC8E2	2017-08-01 00:42:00+03	69800.00
DEC938	2017-06-29 09:41:00+03	151500.00
DEC989	2017-07-19 05:00:00+03	132800.00
DEC9F9	2017-08-14 20:29:00+03	30000.00
DECA1B	2017-08-04 17:31:00+03	566300.00
DECA41	2017-07-06 03:52:00+03	117600.00
DECAA8	2017-07-06 20:50:00+03	56000.00
DECAF2	2017-08-09 02:58:00+03	188000.00
DECB0A	2017-07-02 06:30:00+03	27200.00
DECB18	2017-07-30 02:52:00+03	32800.00
DECB7F	2017-07-26 15:07:00+03	55600.00
DECBF8	2017-07-21 18:44:00+03	34000.00
DECC3F	2017-08-01 18:20:00+03	69500.00
DECC77	2017-08-15 07:40:00+03	18400.00
DECCDB	2017-08-15 08:31:00+03	23600.00
DECCE0	2017-07-04 13:11:00+03	6300.00
DECD0D	2017-08-15 07:23:00+03	6700.00
DECD70	2017-07-30 22:10:00+03	6700.00
DECD88	2017-08-06 05:22:00+03	284400.00
DECDDB	2017-07-08 13:45:00+03	79900.00
DECE18	2017-08-12 23:56:00+03	54800.00
DECE31	2017-07-06 09:30:00+03	283100.00
DECEC6	2017-07-19 14:50:00+03	131800.00
DECEF6	2017-08-07 22:36:00+03	64400.00
DECF02	2017-07-26 22:45:00+03	85600.00
DECF2B	2017-08-13 10:33:00+03	111600.00
DECF65	2017-07-12 20:19:00+03	46800.00
DED002	2017-07-17 12:31:00+03	73300.00
DED030	2017-07-11 03:43:00+03	28800.00
DED033	2017-07-13 16:53:00+03	417200.00
DED03F	2017-08-07 15:56:00+03	136600.00
DED061	2017-07-07 19:21:00+03	12600.00
DED09D	2017-08-13 05:11:00+03	53600.00
DED0F7	2017-08-07 00:09:00+03	75300.00
DED0FF	2017-07-16 00:49:00+03	21400.00
DED114	2017-07-29 03:29:00+03	111600.00
DED13A	2017-07-04 00:51:00+03	21400.00
DED14C	2017-07-09 16:35:00+03	40800.00
DED1B2	2017-08-06 04:48:00+03	258400.00
DED1C9	2017-08-03 07:38:00+03	36200.00
DED20A	2017-07-25 03:19:00+03	7400.00
DED27D	2017-08-12 10:01:00+03	12400.00
DED28F	2017-08-15 13:36:00+03	42700.00
DED3A6	2017-07-20 14:04:00+03	31700.00
DED3CA	2017-07-04 21:30:00+03	55800.00
DED3D2	2017-07-07 14:20:00+03	158500.00
DED3F9	2017-07-26 18:30:00+03	132800.00
DED418	2017-07-28 23:21:00+03	67600.00
DED42A	2017-08-14 06:07:00+03	51900.00
DED459	2017-07-08 21:47:00+03	57500.00
DED4A8	2017-08-08 03:05:00+03	48800.00
DED4EC	2017-07-27 08:08:00+03	24800.00
DED50E	2017-08-14 08:53:00+03	31100.00
DED5F0	2017-08-09 00:16:00+03	116700.00
DED624	2017-07-31 15:14:00+03	133200.00
DED6BA	2017-07-15 21:39:00+03	54400.00
DED75E	2017-07-24 19:13:00+03	43400.00
DED7C1	2017-08-14 17:58:00+03	40400.00
DED7D2	2017-08-13 17:31:00+03	270700.00
DED834	2017-07-10 08:59:00+03	38800.00
DED848	2017-08-05 18:58:00+03	89400.00
DED894	2017-08-15 09:38:00+03	35800.00
DED8DC	2017-08-08 15:48:00+03	375200.00
DED8F2	2017-06-29 08:01:00+03	46000.00
DED96B	2017-07-11 04:18:00+03	80300.00
DED9F0	2017-07-27 03:40:00+03	29600.00
DEDA62	2017-08-10 21:57:00+03	92000.00
DEDAA7	2017-07-05 04:35:00+03	38400.00
DEDAD5	2017-08-11 06:55:00+03	23200.00
DEDAF3	2017-07-08 16:09:00+03	6300.00
DEDB09	2017-07-10 23:27:00+03	73600.00
DEDB13	2017-08-10 04:03:00+03	40400.00
DEDB2A	2017-08-10 16:11:00+03	43500.00
DEDB6D	2017-07-06 12:33:00+03	56000.00
DEDC18	2017-08-13 09:26:00+03	57600.00
DEDC52	2017-07-26 11:17:00+03	78300.00
DEDC9C	2017-07-23 04:22:00+03	19600.00
DEDCB1	2017-07-07 10:01:00+03	18000.00
DEDCE2	2017-07-01 09:24:00+03	75700.00
DEDD2B	2017-07-16 02:00:00+03	44800.00
DEDD39	2017-08-02 08:11:00+03	30200.00
DEDD73	2017-07-12 03:47:00+03	64500.00
DEDE52	2017-07-18 10:39:00+03	121400.00
DEDF2A	2017-07-04 15:45:00+03	56000.00
DEDF9F	2017-07-28 23:44:00+03	63200.00
DEDFAB	2017-07-10 19:08:00+03	81900.00
DEE02C	2017-07-24 04:42:00+03	35200.00
DEE02D	2017-07-21 08:57:00+03	62600.00
DEE05C	2017-06-30 04:04:00+03	32800.00
DEE061	2017-08-06 02:55:00+03	31000.00
DEE070	2017-08-09 09:22:00+03	48800.00
DEE12F	2017-07-21 15:13:00+03	32800.00
DEE1AB	2017-07-23 02:15:00+03	123000.00
DEE1C9	2017-08-15 14:11:00+03	56000.00
DEE1DA	2017-08-04 06:40:00+03	70500.00
DEE1EE	2017-07-27 04:00:00+03	31600.00
DEE206	2017-07-27 01:05:00+03	56100.00
DEE230	2017-07-21 14:48:00+03	10700.00
DEE23A	2017-07-28 03:35:00+03	56600.00
DEE270	2017-07-04 11:50:00+03	25600.00
DEE287	2017-08-04 00:34:00+03	155600.00
DEE2AA	2017-07-31 07:27:00+03	87900.00
DEE2B6	2017-07-11 14:12:00+03	16800.00
DEE2C3	2017-08-04 00:17:00+03	113200.00
DEE2F6	2017-07-25 14:55:00+03	548900.00
DEE335	2017-08-05 18:44:00+03	258400.00
DEE338	2017-08-04 14:52:00+03	28000.00
DEE33E	2017-07-31 00:07:00+03	37700.00
DEE369	2017-07-13 08:26:00+03	395100.00
DEE3C9	2017-07-16 10:18:00+03	70400.00
DEE3DA	2017-07-19 04:48:00+03	44600.00
DEE3FD	2017-07-02 00:13:00+03	394300.00
DEE401	2017-06-29 09:56:00+03	69000.00
DEE408	2017-08-01 05:43:00+03	246000.00
DEE40C	2017-07-14 11:18:00+03	205600.00
DEE457	2017-07-05 12:51:00+03	66000.00
DEE494	2017-07-01 01:52:00+03	59900.00
DEE49E	2017-08-06 22:47:00+03	118300.00
DEE4ED	2017-08-06 04:33:00+03	26000.00
DEE50E	2017-08-08 15:17:00+03	102100.00
DEE592	2017-07-23 14:21:00+03	68100.00
DEE5B7	2017-08-12 01:11:00+03	36000.00
DEE5F1	2017-08-12 07:37:00+03	20200.00
DEE623	2017-07-24 05:50:00+03	58000.00
DEE650	2017-07-05 00:06:00+03	66600.00
DEE66C	2017-08-13 16:29:00+03	94800.00
DEE675	2017-07-11 12:12:00+03	14800.00
DEE6D0	2017-07-23 07:05:00+03	123000.00
DEE6D6	2017-08-08 13:56:00+03	20200.00
DEE6FB	2017-07-12 05:26:00+03	49600.00
DEE736	2017-07-05 17:12:00+03	13600.00
DEE77D	2017-08-09 04:50:00+03	66600.00
DEE78E	2017-08-04 16:24:00+03	60400.00
DEE7B4	2017-08-06 17:22:00+03	392100.00
DEE7B9	2017-07-26 06:55:00+03	52000.00
DEE7C9	2017-07-07 11:27:00+03	26700.00
DEE88E	2017-07-06 22:15:00+03	61500.00
DEE897	2017-08-11 23:04:00+03	52700.00
DEE8A8	2017-07-14 07:32:00+03	29400.00
DEE939	2017-08-02 20:37:00+03	12600.00
DEE94A	2017-08-01 12:19:00+03	57600.00
DEE94D	2017-07-02 13:13:00+03	32900.00
DEE97D	2017-07-24 13:35:00+03	11800.00
DEE993	2017-07-27 14:21:00+03	119700.00
DEE995	2017-07-23 14:27:00+03	44800.00
DEE9AD	2017-07-07 17:08:00+03	139200.00
DEE9C5	2017-07-20 16:40:00+03	56000.00
DEEA01	2017-08-06 00:27:00+03	81600.00
DEEA1C	2017-07-23 02:04:00+03	167400.00
DEEA20	2017-07-13 01:59:00+03	30400.00
DEEA3B	2017-07-02 13:11:00+03	9800.00
DEEACC	2017-08-14 11:09:00+03	32800.00
DEEAF0	2017-08-11 15:50:00+03	38200.00
DEEB0E	2017-07-05 20:17:00+03	76600.00
DEEB9F	2017-07-14 08:29:00+03	311200.00
DEEBB7	2017-07-02 09:07:00+03	56000.00
DEEBC5	2017-07-21 05:33:00+03	28000.00
DEEBE8	2017-07-28 15:15:00+03	119600.00
DEEBED	2017-07-11 06:29:00+03	291300.00
DEEC1D	2017-07-29 20:40:00+03	10600.00
DEEC97	2017-07-30 19:53:00+03	75300.00
DEECD3	2017-06-28 06:25:00+03	133900.00
DEED2E	2017-08-13 11:45:00+03	56100.00
DEEDAD	2017-07-17 04:38:00+03	30800.00
DEEE0B	2017-07-28 22:32:00+03	109600.00
DEEE1B	2017-07-09 11:51:00+03	81700.00
DEEF6F	2017-07-31 06:58:00+03	86700.00
DEEF7C	2017-07-07 13:57:00+03	60600.00
DEF01A	2017-07-12 17:13:00+03	229400.00
DEF01E	2017-08-04 15:03:00+03	23200.00
DEF022	2017-07-05 10:21:00+03	30000.00
DEF033	2017-08-05 17:53:00+03	17200.00
DEF0DB	2017-07-21 09:01:00+03	27800.00
DEF109	2017-07-13 04:54:00+03	25000.00
DEF10F	2017-07-02 02:24:00+03	29600.00
DEF125	2017-07-14 03:41:00+03	59800.00
DEF1E0	2017-08-03 01:08:00+03	56000.00
DEF1E9	2017-08-10 01:38:00+03	161800.00
DEF201	2017-07-27 20:48:00+03	303900.00
DEF21D	2017-08-15 01:33:00+03	35200.00
DEF260	2017-08-10 00:21:00+03	154400.00
DEF271	2017-07-30 08:14:00+03	19600.00
DEF28A	2017-08-10 10:12:00+03	325500.00
DEF2B6	2017-07-14 16:41:00+03	19000.00
DEF2C1	2017-07-16 12:38:00+03	21400.00
DEF2EB	2017-08-11 00:05:00+03	86400.00
DEF2F9	2017-08-13 05:51:00+03	67300.00
DEF2FA	2017-07-03 22:01:00+03	46400.00
DEF38C	2017-07-14 01:52:00+03	123000.00
DEF39E	2017-08-01 00:18:00+03	88800.00
DEF3D7	2017-07-11 14:17:00+03	89600.00
DEF3DC	2017-08-06 07:17:00+03	542200.00
DEF3F1	2017-07-03 10:09:00+03	26300.00
DEF424	2017-07-23 15:07:00+03	7400.00
DEF435	2017-08-05 08:40:00+03	52000.00
DEF472	2017-08-12 11:07:00+03	26000.00
DEF52A	2017-08-13 00:46:00+03	168100.00
DEF55A	2017-08-05 09:15:00+03	45100.00
DEF561	2017-07-09 11:26:00+03	135600.00
DEF5A3	2017-08-05 04:48:00+03	81600.00
DEF5D1	2017-07-25 11:37:00+03	42800.00
DEF60D	2017-07-03 15:29:00+03	65900.00
DEF641	2017-08-11 05:25:00+03	57600.00
DEF653	2017-08-04 20:38:00+03	25200.00
DEF694	2017-07-21 11:25:00+03	81400.00
DEF6B6	2017-07-14 00:03:00+03	85900.00
DEF6D3	2017-07-27 23:33:00+03	133200.00
DEF6E7	2017-07-09 13:02:00+03	10600.00
DEF748	2017-08-06 09:40:00+03	10800.00
DEF74F	2017-07-16 04:22:00+03	92800.00
DEF76D	2017-07-21 10:38:00+03	56100.00
DEF789	2017-07-24 05:07:00+03	454500.00
DEF7A2	2017-07-03 00:37:00+03	131100.00
DEF7B3	2017-08-05 22:16:00+03	188000.00
DEF7C4	2017-08-12 04:29:00+03	65900.00
DEF7C5	2017-07-13 04:37:00+03	40800.00
DEF891	2017-07-28 06:56:00+03	87200.00
DEF986	2017-08-01 11:12:00+03	123000.00
DEF9BC	2017-08-06 15:41:00+03	56000.00
DEFA24	2017-07-26 02:16:00+03	94500.00
DEFA92	2017-07-26 21:51:00+03	17600.00
DEFAF7	2017-07-30 23:45:00+03	68100.00
DEFAFC	2017-08-03 19:57:00+03	21200.00
DEFB0E	2017-08-02 14:37:00+03	66600.00
DEFB18	2017-08-06 17:17:00+03	58200.00
DEFB36	2017-07-03 22:48:00+03	46400.00
DEFB53	2017-07-30 03:01:00+03	257500.00
DEFB59	2017-08-07 10:40:00+03	29000.00
DEFB6D	2017-07-24 10:40:00+03	240600.00
DEFB7C	2017-08-12 20:13:00+03	560600.00
DEFC85	2017-06-29 11:28:00+03	59200.00
DEFCCA	2017-07-30 04:36:00+03	44600.00
DEFD1C	2017-08-13 19:44:00+03	26000.00
DEFD30	2017-07-20 19:56:00+03	6000.00
DEFDD0	2017-08-12 22:59:00+03	65400.00
DEFDEE	2017-07-28 16:22:00+03	18800.00
DEFE07	2017-07-24 09:59:00+03	52900.00
DEFEC8	2017-07-25 01:48:00+03	136200.00
DEFF1F	2017-07-19 10:04:00+03	153200.00
DEFF46	2017-08-02 07:58:00+03	123000.00
DEFFBC	2017-07-19 23:22:00+03	46500.00
DEFFF0	2017-08-04 07:42:00+03	32800.00
DEFFFE	2017-07-04 08:19:00+03	38600.00
DF0133	2017-07-10 08:34:00+03	14000.00
DF013B	2017-08-13 07:09:00+03	10700.00
DF014D	2017-08-08 18:00:00+03	21800.00
DF0175	2017-07-08 06:03:00+03	11600.00
DF01C3	2017-06-29 22:47:00+03	54400.00
DF02CA	2017-07-07 01:09:00+03	94400.00
DF032D	2017-07-01 02:20:00+03	43100.00
DF03CD	2017-07-23 16:27:00+03	48500.00
DF03F3	2017-07-30 06:28:00+03	33100.00
DF0434	2017-07-05 04:51:00+03	67700.00
DF0449	2017-07-31 18:05:00+03	92900.00
DF0470	2017-07-07 07:04:00+03	8200.00
DF0515	2017-08-08 23:39:00+03	92700.00
DF0578	2017-07-20 08:53:00+03	119700.00
DF0621	2017-08-15 06:22:00+03	50200.00
DF0652	2017-08-14 11:07:00+03	42200.00
DF06CF	2017-08-03 18:21:00+03	116800.00
DF072A	2017-07-06 14:50:00+03	43600.00
DF073B	2017-08-13 15:58:00+03	372600.00
DF077E	2017-07-17 04:04:00+03	28000.00
DF0786	2017-07-18 13:37:00+03	21000.00
DF07F5	2017-07-07 04:40:00+03	77200.00
DF08AA	2017-07-01 11:13:00+03	14000.00
DF0963	2017-07-06 17:19:00+03	266400.00
DF099C	2017-07-06 23:08:00+03	29200.00
DF0A44	2017-08-12 22:02:00+03	44000.00
DF0A50	2017-07-10 07:19:00+03	62700.00
DF0A8D	2017-08-14 16:16:00+03	160800.00
DF0ADF	2017-08-05 02:54:00+03	153800.00
DF0B03	2017-07-15 00:58:00+03	399600.00
DF0B12	2017-08-09 03:35:00+03	39600.00
DF0B34	2017-08-14 03:50:00+03	26700.00
DF0B72	2017-07-03 20:24:00+03	372500.00
DF0BA5	2017-07-10 13:22:00+03	37200.00
DF0BE2	2017-07-20 16:04:00+03	85000.00
DF0C0B	2017-07-15 06:20:00+03	54800.00
DF0C79	2017-07-20 14:11:00+03	39100.00
DF0C7A	2017-08-15 05:55:00+03	12000.00
DF0CB0	2017-08-03 02:51:00+03	111600.00
DF0CB8	2017-07-24 02:00:00+03	24800.00
DF0CF9	2017-07-05 03:51:00+03	74400.00
DF0E07	2017-08-03 22:28:00+03	51800.00
DF0E44	2017-07-16 09:47:00+03	22300.00
DF0E66	2017-07-21 20:16:00+03	56600.00
DF0E86	2017-08-05 16:20:00+03	24800.00
DF0EFA	2017-07-14 03:03:00+03	95600.00
DF0EFB	2017-07-12 00:00:00+03	143800.00
DF0FC0	2017-08-03 06:04:00+03	8000.00
DF0FF5	2017-07-08 15:05:00+03	372500.00
DF1047	2017-07-21 03:18:00+03	111600.00
DF10A3	2017-07-24 21:03:00+03	12600.00
DF10F0	2017-07-26 19:38:00+03	67700.00
DF113A	2017-07-18 21:08:00+03	36900.00
DF11E1	2017-08-10 09:17:00+03	364600.00
DF1200	2017-07-28 05:34:00+03	52000.00
DF12AE	2017-07-16 18:33:00+03	54000.00
DF12CB	2017-07-05 14:35:00+03	79600.00
DF12CE	2017-08-06 20:28:00+03	54000.00
DF12D8	2017-07-14 05:37:00+03	71200.00
DF12EA	2017-07-08 21:00:00+03	185500.00
DF1315	2017-07-16 16:01:00+03	24400.00
DF1323	2017-07-18 08:41:00+03	36200.00
DF135B	2017-07-10 00:14:00+03	91800.00
DF1376	2017-08-13 00:46:00+03	45200.00
DF1379	2017-07-15 10:14:00+03	70500.00
DF1388	2017-07-12 07:31:00+03	179400.00
DF1402	2017-08-11 19:15:00+03	63300.00
DF1409	2017-08-12 10:34:00+03	24400.00
DF149C	2017-07-10 16:26:00+03	131100.00
DF14D1	2017-07-02 14:54:00+03	27300.00
DF1546	2017-07-13 18:57:00+03	37900.00
DF156C	2017-08-13 08:15:00+03	24300.00
DF157C	2017-07-16 09:08:00+03	24400.00
DF1596	2017-08-03 22:37:00+03	56600.00
DF159D	2017-07-28 05:48:00+03	40000.00
DF15F8	2017-08-02 04:54:00+03	174200.00
DF1661	2017-08-14 19:45:00+03	178000.00
DF16DC	2017-07-21 10:42:00+03	37900.00
DF170F	2017-08-10 19:04:00+03	75700.00
DF17EC	2017-07-07 20:20:00+03	87000.00
DF1831	2017-07-03 07:34:00+03	32800.00
DF189D	2017-07-08 08:15:00+03	38600.00
DF1925	2017-07-14 12:09:00+03	52000.00
DF1990	2017-08-03 12:25:00+03	21200.00
DF19AD	2017-07-27 23:58:00+03	56000.00
DF19F1	2017-07-28 17:04:00+03	102100.00
DF1A5F	2017-07-07 17:56:00+03	40600.00
DF1B02	2017-07-08 18:59:00+03	150600.00
DF1B1A	2017-07-11 08:18:00+03	79400.00
DF1B36	2017-07-04 00:39:00+03	57400.00
DF1B83	2017-08-02 17:59:00+03	28000.00
DF1CDA	2017-07-22 11:16:00+03	85700.00
DF1CE8	2017-07-19 13:47:00+03	47400.00
DF1D53	2017-08-12 09:46:00+03	47600.00
DF1D80	2017-08-01 08:15:00+03	32800.00
DF1D91	2017-07-23 05:17:00+03	45200.00
DF1DA3	2017-08-04 01:37:00+03	117200.00
DF1E06	2017-07-12 11:47:00+03	235700.00
DF1E31	2017-07-10 01:04:00+03	116200.00
DF1E46	2017-07-15 18:22:00+03	73000.00
DF1E75	2017-07-16 15:20:00+03	24400.00
DF1E76	2017-07-12 11:06:00+03	81600.00
DF1EAD	2017-07-14 14:09:00+03	51600.00
DF1EBB	2017-08-14 15:46:00+03	112000.00
DF1ECB	2017-07-22 20:51:00+03	121500.00
DF1EF3	2017-08-08 02:36:00+03	282300.00
DF1FA8	2017-07-20 14:13:00+03	163500.00
DF1FE6	2017-08-15 14:45:00+03	222800.00
DF2006	2017-07-26 07:52:00+03	96800.00
DF2035	2017-07-21 03:07:00+03	67600.00
DF2050	2017-07-08 04:34:00+03	199700.00
DF2061	2017-08-15 01:52:00+03	144300.00
DF2075	2017-08-07 03:13:00+03	31600.00
DF207D	2017-07-16 01:20:00+03	62900.00
DF208C	2017-07-19 14:53:00+03	56100.00
DF212A	2017-08-05 13:55:00+03	158500.00
DF2135	2017-08-02 11:32:00+03	6800.00
DF213C	2017-07-28 09:06:00+03	28800.00
DF2154	2017-08-02 19:31:00+03	68400.00
DF21D1	2017-07-21 03:35:00+03	40000.00
DF21E5	2017-07-28 00:34:00+03	55800.00
DF221E	2017-07-23 09:33:00+03	55800.00
DF2263	2017-07-14 08:07:00+03	49800.00
DF226B	2017-07-13 16:34:00+03	38400.00
DF227B	2017-07-30 22:42:00+03	45200.00
DF228F	2017-07-22 19:47:00+03	6700.00
DF22DD	2017-07-06 05:46:00+03	381600.00
DF231C	2017-08-09 21:27:00+03	49600.00
DF232E	2017-07-02 03:26:00+03	289700.00
DF2351	2017-08-08 03:16:00+03	84500.00
DF2355	2017-08-08 14:05:00+03	44000.00
DF2358	2017-08-02 10:44:00+03	246000.00
DF23A3	2017-07-30 05:44:00+03	70600.00
DF23C9	2017-07-13 19:34:00+03	76800.00
DF23D4	2017-07-20 06:25:00+03	402800.00
DF23F3	2017-07-11 03:49:00+03	14800.00
DF2455	2017-07-29 16:19:00+03	81500.00
DF2456	2017-07-11 14:47:00+03	30200.00
DF246F	2017-08-09 14:24:00+03	88600.00
DF2477	2017-08-14 19:20:00+03	8200.00
DF249D	2017-07-24 12:44:00+03	99300.00
DF24EE	2017-08-08 06:12:00+03	73200.00
DF2568	2017-08-10 08:13:00+03	135200.00
DF2574	2017-07-01 06:56:00+03	205400.00
DF258A	2017-07-24 23:28:00+03	28800.00
DF2606	2017-07-21 17:29:00+03	40600.00
DF2630	2017-07-24 20:14:00+03	61800.00
DF2680	2017-07-24 21:22:00+03	372300.00
DF26FB	2017-07-04 00:00:00+03	187800.00
DF27A8	2017-07-17 22:58:00+03	27600.00
DF2806	2017-08-06 16:38:00+03	40400.00
DF288E	2017-08-13 13:37:00+03	85500.00
DF2891	2017-07-08 05:52:00+03	14400.00
DF28A3	2017-07-01 14:16:00+03	73600.00
DF28AD	2017-08-12 03:36:00+03	46000.00
DF28BF	2017-07-25 09:37:00+03	217600.00
DF28C1	2017-07-13 19:11:00+03	199600.00
DF28F6	2017-08-15 01:32:00+03	69500.00
DF2930	2017-07-11 22:25:00+03	14000.00
DF2937	2017-08-07 18:50:00+03	43000.00
DF2948	2017-07-18 03:42:00+03	111600.00
DF2996	2017-07-14 09:04:00+03	15700.00
DF2999	2017-07-23 13:53:00+03	160700.00
DF2A3D	2017-07-15 01:17:00+03	38600.00
DF2A84	2017-07-28 05:34:00+03	61800.00
DF2ABA	2017-07-11 21:51:00+03	152200.00
DF2AD5	2017-07-18 05:26:00+03	64400.00
DF2AE4	2017-08-02 12:43:00+03	17000.00
DF2B44	2017-08-10 15:34:00+03	22000.00
DF2B4A	2017-07-22 17:57:00+03	16400.00
DF2B7A	2017-08-11 01:21:00+03	133200.00
DF2B7D	2017-07-22 10:18:00+03	10800.00
DF2BDC	2017-07-26 12:02:00+03	25800.00
DF2BE3	2017-08-04 01:26:00+03	91800.00
DF2C76	2017-08-14 14:15:00+03	62600.00
DF2C79	2017-08-06 14:19:00+03	48200.00
DF2C94	2017-07-19 23:13:00+03	63400.00
DF2CC9	2017-07-17 06:55:00+03	122800.00
DF2D35	2017-08-14 23:25:00+03	69800.00
DF2D46	2017-07-26 18:22:00+03	50100.00
DF2D9B	2017-07-26 08:03:00+03	29400.00
DF2F10	2017-08-08 09:11:00+03	40800.00
DF2FA5	2017-06-30 21:25:00+03	67500.00
DF3049	2017-07-06 04:55:00+03	56200.00
DF3078	2017-07-06 02:21:00+03	40400.00
DF3081	2017-07-14 04:32:00+03	34000.00
DF308C	2017-08-06 22:22:00+03	26800.00
DF30B0	2017-07-24 23:09:00+03	68400.00
DF30EB	2017-07-04 07:53:00+03	28000.00
DF30FD	2017-08-01 18:25:00+03	87600.00
DF311A	2017-08-05 07:17:00+03	53500.00
DF3150	2017-07-23 03:28:00+03	73300.00
DF3189	2017-07-25 23:11:00+03	24400.00
DF3192	2017-07-26 15:27:00+03	277900.00
DF31F3	2017-08-14 10:28:00+03	53300.00
DF3305	2017-08-12 16:30:00+03	56600.00
DF3334	2017-07-17 09:56:00+03	111600.00
DF333B	2017-07-19 15:15:00+03	16800.00
DF3375	2017-07-18 12:31:00+03	53300.00
DF339B	2017-08-01 03:19:00+03	88900.00
DF33DF	2017-07-14 16:11:00+03	136200.00
DF33E2	2017-08-06 10:29:00+03	103200.00
DF33EA	2017-07-12 14:40:00+03	73600.00
DF340F	2017-06-30 04:25:00+03	71900.00
DF3438	2017-08-08 10:06:00+03	20200.00
DF3441	2017-08-11 18:51:00+03	187100.00
DF347D	2017-07-31 22:24:00+03	119500.00
DF34AB	2017-08-03 22:14:00+03	136200.00
DF34F7	2017-07-29 13:27:00+03	13000.00
DF3530	2017-08-01 14:47:00+03	67200.00
DF3547	2017-07-24 17:10:00+03	16800.00
DF3562	2017-08-15 13:53:00+03	25600.00
DF357E	2017-07-11 10:17:00+03	23200.00
DF3592	2017-08-14 23:25:00+03	23600.00
DF359B	2017-07-28 23:54:00+03	37900.00
DF35A8	2017-07-08 06:46:00+03	27200.00
DF35AB	2017-07-15 13:43:00+03	43800.00
DF361F	2017-08-02 16:50:00+03	89200.00
DF3622	2017-06-29 03:52:00+03	136700.00
DF3632	2017-08-13 18:47:00+03	99200.00
DF366C	2017-08-15 05:07:00+03	35800.00
DF36BC	2017-07-24 14:05:00+03	8000.00
DF36DB	2017-08-06 02:32:00+03	64800.00
DF3713	2017-07-14 03:32:00+03	31600.00
DF3783	2017-08-08 11:54:00+03	21400.00
DF37D9	2017-07-30 20:37:00+03	58600.00
DF382B	2017-07-03 05:12:00+03	41200.00
DF3850	2017-08-08 00:21:00+03	68000.00
DF3893	2017-08-08 20:30:00+03	66000.00
DF3901	2017-07-12 01:01:00+03	235700.00
DF394C	2017-07-27 03:55:00+03	53200.00
DF3968	2017-07-07 05:19:00+03	69500.00
DF39EB	2017-07-30 19:57:00+03	77800.00
DF3AA8	2017-07-07 21:52:00+03	54800.00
DF3B08	2017-07-22 16:19:00+03	31400.00
DF3B43	2017-07-13 04:44:00+03	273600.00
DF3B75	2017-07-29 06:10:00+03	265700.00
DF3B78	2017-07-31 23:10:00+03	43100.00
DF3B88	2017-07-05 22:31:00+03	25800.00
DF3BEA	2017-07-13 19:55:00+03	265700.00
DF3C4E	2017-08-03 15:59:00+03	254600.00
DF3C96	2017-08-02 06:34:00+03	189200.00
DF3CC2	2017-08-10 22:10:00+03	34200.00
DF3CCB	2017-07-29 21:27:00+03	47500.00
DF3CF6	2017-07-18 04:43:00+03	144900.00
DF3CF8	2017-08-05 11:01:00+03	122300.00
DF3D2A	2017-07-21 10:06:00+03	58000.00
DF3D47	2017-08-05 07:04:00+03	75600.00
DF3D54	2017-08-13 02:19:00+03	46400.00
DF3D8F	2017-07-15 18:26:00+03	160200.00
DF3DBF	2017-08-14 20:53:00+03	91600.00
DF3DFB	2017-08-09 23:25:00+03	50600.00
DF3E2E	2017-07-31 05:08:00+03	28000.00
DF3E86	2017-07-25 08:18:00+03	273400.00
DF3EF0	2017-08-06 07:21:00+03	28000.00
DF3EFD	2017-08-03 22:01:00+03	101100.00
DF3F0E	2017-07-16 03:03:00+03	28800.00
DF3F3A	2017-07-26 10:47:00+03	20500.00
DF3FE5	2017-08-12 05:13:00+03	104000.00
DF3FF6	2017-08-08 02:30:00+03	66600.00
DF400F	2017-07-13 08:14:00+03	64600.00
DF409D	2017-08-10 20:04:00+03	56000.00
DF4131	2017-07-01 05:31:00+03	58400.00
DF4170	2017-07-10 20:43:00+03	57600.00
DF418F	2017-08-14 15:05:00+03	111700.00
DF41B6	2017-07-18 07:17:00+03	46400.00
DF41C8	2017-07-11 22:15:00+03	47000.00
DF41DC	2017-07-09 09:47:00+03	64500.00
DF42B3	2017-07-10 23:46:00+03	154500.00
DF435F	2017-08-01 19:19:00+03	78500.00
DF43A0	2017-07-14 00:26:00+03	49600.00
DF43DE	2017-07-13 21:42:00+03	58200.00
DF4427	2017-08-09 21:38:00+03	62700.00
DF444C	2017-08-09 17:25:00+03	24600.00
DF445F	2017-08-11 14:02:00+03	96400.00
DF447A	2017-07-31 15:29:00+03	24400.00
DF4498	2017-07-24 07:43:00+03	23600.00
DF4537	2017-07-31 06:45:00+03	80800.00
DF45D2	2017-08-07 10:22:00+03	27700.00
DF4611	2017-07-24 17:46:00+03	137300.00
DF4615	2017-08-07 19:33:00+03	70800.00
DF4644	2017-07-29 03:27:00+03	68100.00
DF469E	2017-08-01 12:00:00+03	42600.00
DF46A0	2017-08-13 07:42:00+03	121400.00
DF46B5	2017-08-03 22:54:00+03	136800.00
DF46C8	2017-07-12 23:21:00+03	56000.00
DF47D1	2017-08-10 20:15:00+03	13200.00
DF47DB	2017-07-05 06:31:00+03	112000.00
DF47ED	2017-07-22 06:58:00+03	28000.00
DF47F3	2017-07-17 23:34:00+03	127800.00
DF481D	2017-08-11 01:30:00+03	73300.00
DF486C	2017-08-13 10:28:00+03	281500.00
DF4979	2017-07-12 12:52:00+03	50900.00
DF49A1	2017-07-11 01:50:00+03	50000.00
DF49B7	2017-08-07 09:52:00+03	36600.00
DF4A01	2017-07-17 08:22:00+03	92000.00
DF4A3E	2017-08-10 18:00:00+03	46000.00
DF4A40	2017-08-04 02:53:00+03	87200.00
DF4A72	2017-08-10 09:56:00+03	94400.00
DF4A87	2017-07-12 15:21:00+03	53700.00
DF4B01	2017-07-13 21:47:00+03	66600.00
DF4B3A	2017-08-11 13:36:00+03	23600.00
DF4B75	2017-08-12 09:29:00+03	55800.00
DF4D0B	2017-07-26 04:06:00+03	13400.00
DF4D28	2017-07-15 06:02:00+03	28000.00
DF4D4F	2017-07-26 22:02:00+03	58900.00
DF4D6C	2017-08-06 09:21:00+03	23400.00
DF4DD9	2017-07-01 19:30:00+03	23900.00
DF4E00	2017-07-21 00:01:00+03	209700.00
DF4E0A	2017-07-01 23:13:00+03	62800.00
DF4E2E	2017-07-10 19:18:00+03	74200.00
DF4E69	2017-07-07 16:32:00+03	25000.00
DF4E9B	2017-07-30 17:52:00+03	171100.00
DF4F34	2017-08-03 06:00:00+03	94000.00
DF4FD5	2017-07-29 03:46:00+03	135800.00
DF4FF4	2017-07-18 02:42:00+03	67100.00
DF5008	2017-07-21 16:15:00+03	57400.00
DF5036	2017-07-27 13:11:00+03	23200.00
DF5059	2017-07-09 02:56:00+03	111600.00
DF505E	2017-07-20 00:43:00+03	48400.00
DF5079	2017-07-22 20:05:00+03	28800.00
DF507A	2017-08-04 03:32:00+03	136200.00
DF5090	2017-08-11 03:23:00+03	36000.00
DF50A1	2017-07-31 11:37:00+03	142800.00
DF50A8	2017-07-16 18:29:00+03	246000.00
DF50C1	2017-08-12 07:50:00+03	6000.00
DF50F2	2017-07-07 14:13:00+03	101200.00
DF5161	2017-07-10 07:48:00+03	145900.00
DF5170	2017-08-07 09:54:00+03	134400.00
DF5185	2017-07-08 12:30:00+03	65600.00
DF51DF	2017-08-09 14:41:00+03	84200.00
DF51EE	2017-07-02 19:26:00+03	64500.00
DF5214	2017-07-16 11:47:00+03	39700.00
DF5262	2017-07-18 01:10:00+03	210000.00
DF5295	2017-07-18 05:14:00+03	37300.00
DF5299	2017-08-12 07:03:00+03	40800.00
DF52F4	2017-08-01 04:34:00+03	70100.00
DF52F9	2017-08-03 05:58:00+03	12300.00
DF532B	2017-07-17 03:03:00+03	202300.00
DF5365	2017-08-10 07:22:00+03	49300.00
DF537A	2017-07-17 06:19:00+03	29600.00
DF540A	2017-07-19 03:47:00+03	496700.00
DF5470	2017-08-03 14:09:00+03	41600.00
DF5479	2017-08-02 09:24:00+03	44800.00
DF551D	2017-08-04 12:13:00+03	62600.00
DF557E	2017-08-09 02:03:00+03	81600.00
DF55B8	2017-07-05 19:00:00+03	91600.00
DF55CA	2017-07-21 11:35:00+03	26200.00
DF5682	2017-08-05 17:07:00+03	272000.00
DF56C3	2017-08-12 03:31:00+03	27400.00
DF56DC	2017-07-10 14:02:00+03	27400.00
DF56E2	2017-07-21 06:01:00+03	64100.00
DF56FB	2017-07-20 08:50:00+03	14000.00
DF5741	2017-07-20 14:12:00+03	62600.00
DF575F	2017-07-12 19:45:00+03	68400.00
DF579B	2017-07-28 14:58:00+03	45500.00
DF57AD	2017-07-18 23:01:00+03	177800.00
DF57BD	2017-08-12 14:42:00+03	28800.00
DF57FC	2017-08-01 06:57:00+03	26700.00
DF5828	2017-07-30 00:43:00+03	17800.00
DF5829	2017-08-04 02:44:00+03	93000.00
DF5832	2017-07-16 12:30:00+03	30400.00
DF58B5	2017-07-26 11:20:00+03	63400.00
DF58EB	2017-07-19 02:04:00+03	56000.00
DF591B	2017-07-29 22:29:00+03	44000.00
DF5948	2017-08-05 18:11:00+03	131100.00
DF5957	2017-07-30 03:01:00+03	35200.00
DF5960	2017-08-02 07:09:00+03	67900.00
DF5969	2017-07-11 13:40:00+03	32700.00
DF5988	2017-07-17 04:59:00+03	55800.00
DF5990	2017-07-25 23:30:00+03	260300.00
DF59B0	2017-08-02 16:35:00+03	27800.00
DF5A88	2017-08-14 06:53:00+03	111700.00
DF5AB4	2017-07-10 22:39:00+03	252200.00
DF5ACF	2017-08-05 07:08:00+03	14400.00
DF5B3A	2017-07-14 05:39:00+03	30200.00
DF5C20	2017-08-03 15:03:00+03	7800.00
DF5CDE	2017-08-11 12:35:00+03	119400.00
DF5CFC	2017-08-10 15:10:00+03	46200.00
DF5D39	2017-07-28 14:17:00+03	558200.00
DF5D4E	2017-08-09 11:22:00+03	36200.00
DF5D56	2017-06-30 22:39:00+03	6300.00
DF5D67	2017-07-24 21:15:00+03	27200.00
DF5E5D	2017-07-12 23:33:00+03	14400.00
DF5E90	2017-07-28 18:43:00+03	56000.00
DF5EB1	2017-07-22 17:40:00+03	45400.00
DF5F29	2017-07-04 05:31:00+03	16400.00
DF5F68	2017-07-19 07:34:00+03	26000.00
DF5FC5	2017-08-01 20:23:00+03	28800.00
DF5FF9	2017-08-01 22:06:00+03	15200.00
DF6028	2017-08-15 09:21:00+03	26800.00
DF602F	2017-07-20 05:59:00+03	45500.00
DF60BC	2017-07-07 22:01:00+03	28800.00
DF6150	2017-07-27 10:15:00+03	25200.00
DF6154	2017-08-11 12:16:00+03	37600.00
DF616C	2017-07-20 05:57:00+03	123700.00
DF61E7	2017-07-25 16:13:00+03	56100.00
DF6206	2017-07-25 23:55:00+03	21600.00
DF6222	2017-07-09 07:56:00+03	28000.00
DF6271	2017-07-17 23:37:00+03	48800.00
DF628E	2017-07-14 07:23:00+03	61800.00
DF62B4	2017-07-23 18:43:00+03	134800.00
DF6302	2017-07-01 12:42:00+03	101400.00
DF6339	2017-07-06 20:02:00+03	200200.00
DF6349	2017-08-01 23:39:00+03	18000.00
DF6460	2017-07-06 02:19:00+03	43200.00
DF646D	2017-08-09 08:17:00+03	133100.00
DF6483	2017-07-09 12:14:00+03	199700.00
DF649A	2017-07-18 15:42:00+03	38400.00
DF64EF	2017-08-04 12:03:00+03	46200.00
DF6550	2017-07-15 08:55:00+03	258400.00
DF657A	2017-08-14 16:22:00+03	369000.00
DF6583	2017-07-17 20:00:00+03	111700.00
DF65C9	2017-07-19 09:27:00+03	6800.00
DF65D6	2017-08-10 03:00:00+03	136800.00
DF66E3	2017-07-02 16:38:00+03	56900.00
DF6734	2017-07-23 22:53:00+03	28000.00
DF6751	2017-07-31 18:25:00+03	88500.00
DF6778	2017-07-05 21:55:00+03	101500.00
DF67AE	2017-08-10 15:43:00+03	11600.00
DF680A	2017-08-14 00:38:00+03	36600.00
DF6821	2017-08-13 14:00:00+03	16400.00
DF6870	2017-08-12 19:56:00+03	75200.00
DF68AE	2017-07-03 16:25:00+03	70800.00
DF68AF	2017-07-25 08:26:00+03	29600.00
DF69B5	2017-08-06 13:36:00+03	40300.00
DF69B7	2017-07-20 07:52:00+03	134000.00
DF69E0	2017-07-17 21:04:00+03	31400.00
DF6A78	2017-07-09 22:16:00+03	272400.00
DF6AAD	2017-08-08 19:10:00+03	59800.00
DF6B2A	2017-08-12 02:34:00+03	47400.00
DF6B84	2017-07-09 06:05:00+03	75600.00
DF6BB6	2017-07-30 19:37:00+03	174000.00
DF6C08	2017-07-10 05:37:00+03	79000.00
DF6C4F	2017-08-14 19:27:00+03	62300.00
DF6CD1	2017-07-20 05:08:00+03	22000.00
DF6D43	2017-08-12 22:10:00+03	71800.00
DF6D5D	2017-07-22 15:31:00+03	35600.00
DF6D84	2017-08-10 23:27:00+03	95700.00
DF6D8A	2017-08-13 10:21:00+03	30200.00
DF6DA4	2017-08-08 12:27:00+03	116900.00
DF6E4A	2017-07-31 08:34:00+03	32200.00
DF6E54	2017-07-29 14:35:00+03	25600.00
DF6EAE	2017-07-25 09:31:00+03	65000.00
DF6FA2	2017-08-11 19:33:00+03	61500.00
DF6FAA	2017-07-09 01:06:00+03	31400.00
DF6FD5	2017-07-23 17:28:00+03	44800.00
DF6FFD	2017-07-20 11:18:00+03	87600.00
DF7012	2017-07-22 22:06:00+03	6000.00
DF7053	2017-07-09 05:54:00+03	88500.00
DF7070	2017-07-10 17:12:00+03	86300.00
DF7126	2017-07-14 15:30:00+03	13200.00
DF718C	2017-07-15 12:14:00+03	101200.00
DF71B1	2017-06-28 15:39:00+03	100600.00
DF7228	2017-08-13 09:56:00+03	51900.00
DF7274	2017-08-05 18:42:00+03	23100.00
DF728E	2017-08-06 13:30:00+03	169600.00
DF7297	2017-07-24 00:00:00+03	105900.00
DF729B	2017-08-04 23:02:00+03	11300.00
DF72A8	2017-08-08 23:29:00+03	10700.00
DF72A9	2017-06-30 03:29:00+03	62700.00
DF7341	2017-08-05 04:20:00+03	24800.00
DF7372	2017-07-26 17:23:00+03	21400.00
DF7408	2017-08-05 16:06:00+03	91500.00
DF744C	2017-08-13 05:52:00+03	153300.00
DF745D	2017-07-06 16:18:00+03	38800.00
DF749A	2017-07-10 20:21:00+03	496600.00
DF74CC	2017-07-25 23:49:00+03	27900.00
DF74E0	2017-07-29 16:35:00+03	14000.00
DF74EC	2017-08-13 06:47:00+03	60800.00
DF74FF	2017-07-27 19:12:00+03	39300.00
DF7551	2017-07-05 04:02:00+03	77900.00
DF7576	2017-07-07 12:49:00+03	58000.00
DF7599	2017-07-24 15:54:00+03	14000.00
DF759E	2017-07-15 03:40:00+03	36400.00
DF75B6	2017-08-14 12:48:00+03	95700.00
DF75C9	2017-08-11 00:41:00+03	46800.00
DF75D4	2017-08-11 14:51:00+03	23200.00
DF7601	2017-08-07 11:33:00+03	56000.00
DF7611	2017-07-28 22:39:00+03	67200.00
DF7632	2017-07-29 13:48:00+03	47400.00
DF7656	2017-07-10 13:40:00+03	14800.00
DF7657	2017-07-26 04:20:00+03	246000.00
DF7715	2017-08-05 04:19:00+03	14400.00
DF7753	2017-07-17 03:05:00+03	17600.00
DF7766	2017-07-05 00:08:00+03	52600.00
DF777B	2017-08-09 21:10:00+03	56000.00
DF77D7	2017-07-19 04:01:00+03	103900.00
DF77F7	2017-07-24 10:44:00+03	26200.00
DF7834	2017-08-06 08:49:00+03	75300.00
DF785C	2017-07-15 08:23:00+03	18000.00
DF7885	2017-07-13 02:19:00+03	67200.00
DF7927	2017-08-07 11:03:00+03	48800.00
DF792B	2017-07-03 11:05:00+03	284400.00
DF7A0F	2017-07-20 18:17:00+03	120700.00
DF7A1F	2017-07-07 14:19:00+03	24300.00
DF7A50	2017-07-14 11:31:00+03	43200.00
DF7A7E	2017-06-27 08:02:00+03	49500.00
DF7B1D	2017-08-01 07:31:00+03	106400.00
DF7B7A	2017-07-29 18:20:00+03	84100.00
DF7B7C	2017-08-03 17:16:00+03	278400.00
DF7B98	2017-07-14 13:50:00+03	47200.00
DF7BA1	2017-08-13 02:17:00+03	27300.00
DF7BAF	2017-07-30 10:12:00+03	14800.00
DF7BD5	2017-08-04 06:14:00+03	14400.00
DF7BED	2017-07-16 07:12:00+03	28000.00
DF7CA9	2017-07-19 10:41:00+03	70800.00
DF7CCA	2017-08-10 05:19:00+03	26000.00
DF7D03	2017-08-11 02:25:00+03	202600.00
DF7DCF	2017-07-04 16:18:00+03	24400.00
DF7E2C	2017-08-10 09:57:00+03	53400.00
DF7ECA	2017-07-10 07:53:00+03	30000.00
DF7ED4	2017-07-09 13:45:00+03	43200.00
DF7ED5	2017-08-10 08:34:00+03	400600.00
DF7F49	2017-08-01 22:14:00+03	22600.00
DF7F72	2017-08-02 06:42:00+03	48800.00
DF7F8A	2017-08-06 13:40:00+03	8400.00
DF7FCC	2017-07-24 01:47:00+03	23200.00
DF7FF9	2017-07-12 06:49:00+03	129700.00
DF8019	2017-07-21 02:06:00+03	24400.00
DF8088	2017-08-04 17:16:00+03	99700.00
DF80B0	2017-07-08 06:59:00+03	70600.00
DF812F	2017-07-26 03:08:00+03	99300.00
DF814B	2017-07-06 01:28:00+03	84000.00
DF81A4	2017-08-04 07:36:00+03	86600.00
DF81CF	2017-07-24 21:16:00+03	36000.00
DF8200	2017-08-03 00:41:00+03	26700.00
DF822B	2017-07-26 04:52:00+03	13400.00
DF82A0	2017-07-10 21:52:00+03	59800.00
DF82BF	2017-07-10 14:15:00+03	37900.00
DF82C1	2017-08-02 04:01:00+03	56100.00
DF82D4	2017-07-26 00:00:00+03	280400.00
DF82E0	2017-07-18 08:58:00+03	172300.00
DF82FF	2017-08-09 06:53:00+03	26000.00
DF834A	2017-07-23 04:46:00+03	18600.00
DF83A6	2017-08-07 07:17:00+03	34000.00
DF83A8	2017-07-20 01:30:00+03	41900.00
DF83D9	2017-07-21 16:11:00+03	54300.00
DF8487	2017-08-10 06:24:00+03	92000.00
DF855A	2017-07-02 17:14:00+03	46500.00
DF8591	2017-07-03 03:41:00+03	246000.00
DF859C	2017-08-01 19:04:00+03	29400.00
DF85C9	2017-08-14 09:55:00+03	408500.00
DF85D7	2017-08-06 18:33:00+03	122000.00
DF85E3	2017-08-10 03:06:00+03	28800.00
DF85FB	2017-08-04 19:02:00+03	93900.00
DF8635	2017-07-11 15:26:00+03	68100.00
DF864A	2017-07-26 00:09:00+03	12000.00
DF86AB	2017-07-31 15:42:00+03	107700.00
DF86F7	2017-07-01 18:59:00+03	74400.00
DF86FF	2017-07-16 04:35:00+03	76400.00
DF8704	2017-07-09 12:09:00+03	19600.00
DF875D	2017-07-02 18:35:00+03	542200.00
DF87AB	2017-07-21 20:54:00+03	23200.00
DF882B	2017-07-25 17:16:00+03	38600.00
DF8833	2017-06-30 11:17:00+03	137600.00
DF88B9	2017-08-09 18:13:00+03	75700.00
DF88C3	2017-08-12 19:15:00+03	37700.00
DF8916	2017-07-03 10:40:00+03	16400.00
DF8917	2017-08-08 13:14:00+03	94200.00
DF8980	2017-07-14 22:39:00+03	88600.00
DF8981	2017-08-15 01:42:00+03	26100.00
DF898C	2017-07-30 10:13:00+03	29000.00
DF89B9	2017-07-06 23:41:00+03	336100.00
DF89C3	2017-08-07 08:22:00+03	46800.00
DF89E8	2017-07-27 19:50:00+03	52000.00
DF8A0C	2017-07-21 05:34:00+03	40600.00
DF8A9E	2017-08-12 00:30:00+03	21800.00
DF8AA9	2017-08-12 15:09:00+03	15000.00
DF8AF6	2017-07-02 04:32:00+03	28000.00
DF8B23	2017-07-04 23:06:00+03	136500.00
DF8B52	2017-07-03 06:43:00+03	25800.00
DF8C03	2017-07-10 07:24:00+03	6000.00
DF8C16	2017-07-21 14:56:00+03	62600.00
DF8C3B	2017-08-09 18:52:00+03	52000.00
DF8C45	2017-08-12 06:47:00+03	57500.00
DF8C6E	2017-07-27 10:10:00+03	37900.00
DF8CBD	2017-07-22 13:17:00+03	34400.00
DF8CBF	2017-06-26 07:50:00+03	50800.00
DF8D30	2017-07-13 18:54:00+03	88500.00
DF8D44	2017-07-21 07:00:00+03	131600.00
DF8D7E	2017-08-09 20:43:00+03	28000.00
DF8D83	2017-07-04 22:55:00+03	125400.00
DF8DB6	2017-07-14 23:53:00+03	43700.00
DF8E8F	2017-07-07 19:39:00+03	266400.00
DF8E9B	2017-07-22 23:07:00+03	49700.00
DF8ECE	2017-07-22 13:14:00+03	273600.00
DF8EF0	2017-07-05 13:21:00+03	28400.00
DF8F40	2017-07-20 14:56:00+03	10800.00
DF8F5D	2017-07-13 00:51:00+03	50600.00
DF8F76	2017-08-02 18:41:00+03	26000.00
DF8FCA	2017-07-24 04:53:00+03	23200.00
DF9034	2017-08-05 17:09:00+03	65900.00
DF9051	2017-08-09 13:49:00+03	58600.00
DF9052	2017-08-02 02:56:00+03	54800.00
DF9066	2017-07-30 15:54:00+03	300800.00
DF906A	2017-08-01 22:36:00+03	273300.00
DF9080	2017-07-05 20:23:00+03	67000.00
DF90D1	2017-07-09 05:01:00+03	6700.00
DF9152	2017-07-08 23:04:00+03	54500.00
DF917E	2017-07-23 22:02:00+03	25600.00
DF917F	2017-07-27 14:33:00+03	51600.00
DF91AE	2017-07-18 13:01:00+03	178100.00
DF91EF	2017-06-29 22:13:00+03	13200.00
DF9213	2017-08-15 08:34:00+03	66300.00
DF92A6	2017-07-04 15:49:00+03	20200.00
DF9360	2017-07-24 07:31:00+03	55800.00
DF93A4	2017-07-11 10:49:00+03	28800.00
DF9439	2017-08-14 17:42:00+03	36800.00
DF944E	2017-07-31 18:48:00+03	166100.00
DF949B	2017-07-21 02:43:00+03	23200.00
DF94D6	2017-07-22 03:05:00+03	167400.00
DF951E	2017-07-31 03:59:00+03	56700.00
DF956D	2017-08-01 16:24:00+03	31600.00
DF95A8	2017-07-10 22:58:00+03	68400.00
DF95B3	2017-08-08 07:07:00+03	70600.00
DF9617	2017-07-04 21:57:00+03	31600.00
DF963E	2017-07-03 07:15:00+03	139200.00
DF9682	2017-08-06 03:30:00+03	46400.00
DF9693	2017-07-28 14:47:00+03	28800.00
DF96C2	2017-07-10 08:30:00+03	62000.00
DF96D9	2017-08-01 05:44:00+03	27900.00
DF9736	2017-08-04 15:08:00+03	40800.00
DF9744	2017-07-07 14:05:00+03	28000.00
DF978F	2017-07-02 13:09:00+03	66600.00
DF97F3	2017-07-06 08:03:00+03	60400.00
DF9802	2017-07-14 19:15:00+03	78200.00
DF9900	2017-08-14 00:31:00+03	16400.00
DF9945	2017-07-12 08:19:00+03	8200.00
DF995F	2017-07-11 12:15:00+03	36000.00
DF99F3	2017-07-22 05:34:00+03	34600.00
DF99F9	2017-06-30 17:56:00+03	62000.00
DF9A08	2017-08-01 07:31:00+03	44000.00
DF9A41	2017-07-11 09:01:00+03	72800.00
DF9A4B	2017-08-11 10:20:00+03	20600.00
DF9A6E	2017-08-10 01:53:00+03	135400.00
DF9ADB	2017-07-02 11:44:00+03	25400.00
DF9ADF	2017-07-19 11:05:00+03	162200.00
DF9B10	2017-07-24 05:36:00+03	64700.00
DF9B9E	2017-08-07 10:09:00+03	75600.00
DF9BB5	2017-07-10 09:22:00+03	24200.00
DF9BC8	2017-07-29 03:09:00+03	38400.00
DF9BF9	2017-07-22 14:28:00+03	12000.00
DF9C22	2017-08-10 09:38:00+03	258300.00
DF9C59	2017-07-28 06:55:00+03	192300.00
DF9CA2	2017-08-14 10:08:00+03	155600.00
DF9CD6	2017-08-12 10:06:00+03	145300.00
DF9CF0	2017-08-01 20:49:00+03	90200.00
DF9D93	2017-07-10 15:26:00+03	108600.00
DF9DB4	2017-07-23 18:42:00+03	111300.00
DF9DDA	2017-08-14 22:47:00+03	34100.00
DF9DF6	2017-07-20 08:32:00+03	24200.00
DF9DF7	2017-07-22 14:41:00+03	89600.00
DF9E31	2017-07-23 19:55:00+03	114800.00
DF9E95	2017-07-01 07:54:00+03	115800.00
DF9E96	2017-08-02 18:12:00+03	7300.00
DF9EC3	2017-07-24 00:17:00+03	357600.00
DF9ED2	2017-08-01 13:00:00+03	31600.00
DF9F57	2017-08-09 13:41:00+03	67900.00
DF9F6B	2017-07-11 18:16:00+03	23600.00
DF9FE9	2017-07-01 21:09:00+03	46400.00
DFA020	2017-07-09 00:56:00+03	20400.00
DFA03C	2017-07-09 12:36:00+03	54800.00
DFA08A	2017-08-13 07:04:00+03	8200.00
DFA08C	2017-08-15 07:33:00+03	81600.00
DFA0BF	2017-08-07 11:01:00+03	23200.00
DFA0C6	2017-07-22 09:59:00+03	11600.00
DFA0DE	2017-08-02 23:20:00+03	10800.00
DFA0FA	2017-07-01 14:53:00+03	54000.00
DFA136	2017-07-16 11:48:00+03	78700.00
DFA15B	2017-07-27 10:38:00+03	70800.00
DFA167	2017-06-29 23:57:00+03	68400.00
DFA18D	2017-07-25 07:55:00+03	283100.00
DFA19C	2017-07-21 12:17:00+03	47400.00
DFA1AC	2017-07-20 01:56:00+03	61500.00
DFA1AE	2017-07-04 10:12:00+03	28300.00
DFA22B	2017-07-13 23:12:00+03	70800.00
DFA249	2017-07-15 01:49:00+03	246000.00
DFA25D	2017-08-04 09:11:00+03	63200.00
DFA2AB	2017-08-08 23:16:00+03	66600.00
DFA2E0	2017-08-05 08:53:00+03	147300.00
DFA354	2017-07-28 14:15:00+03	43600.00
DFA36B	2017-07-13 18:18:00+03	119300.00
DFA40E	2017-07-19 20:32:00+03	213200.00
DFA47C	2017-07-28 13:11:00+03	41200.00
DFA484	2017-07-10 22:51:00+03	27300.00
DFA488	2017-07-12 13:42:00+03	59200.00
DFA4B3	2017-07-30 17:55:00+03	76800.00
DFA4B5	2017-08-14 08:41:00+03	25100.00
DFA508	2017-07-30 23:07:00+03	26000.00
DFA514	2017-07-10 22:06:00+03	46000.00
DFA631	2017-07-04 20:18:00+03	369000.00
DFA66B	2017-07-16 07:22:00+03	31400.00
DFA764	2017-07-30 07:22:00+03	57500.00
DFA7A3	2017-07-27 21:01:00+03	6700.00
DFA909	2017-07-09 17:56:00+03	47400.00
DFA92E	2017-08-04 05:24:00+03	111600.00
DFA933	2017-07-06 10:31:00+03	15000.00
DFAA10	2017-07-21 19:05:00+03	38400.00
DFAA45	2017-07-21 18:17:00+03	111600.00
DFAA65	2017-07-31 19:11:00+03	12600.00
DFAA86	2017-07-28 22:02:00+03	11600.00
DFAB3B	2017-08-03 01:36:00+03	48900.00
DFAB3D	2017-07-22 02:51:00+03	16800.00
DFAB41	2017-08-09 19:24:00+03	91300.00
DFABA1	2017-08-08 13:51:00+03	119300.00
DFAC0B	2017-07-22 02:16:00+03	23600.00
DFAC3D	2017-07-25 15:30:00+03	77200.00
DFAC7C	2017-07-10 09:05:00+03	246000.00
DFACC0	2017-07-28 10:12:00+03	28000.00
DFAD3F	2017-08-10 01:49:00+03	19600.00
DFADBC	2017-08-01 16:46:00+03	128800.00
DFADD6	2017-08-01 11:37:00+03	35600.00
DFAE43	2017-07-23 19:49:00+03	41800.00
DFAE93	2017-08-15 07:32:00+03	67600.00
DFAEC0	2017-08-03 15:40:00+03	20000.00
DFAF03	2017-07-10 11:18:00+03	38400.00
DFAF72	2017-07-03 15:53:00+03	37600.00
DFB060	2017-07-14 01:45:00+03	53700.00
DFB090	2017-08-01 19:15:00+03	223200.00
DFB0D5	2017-07-20 14:54:00+03	123000.00
DFB0E9	2017-07-21 19:41:00+03	56000.00
DFB139	2017-08-07 20:12:00+03	14000.00
DFB165	2017-07-08 00:25:00+03	85000.00
DFB24B	2017-07-04 00:50:00+03	7200.00
DFB2B5	2017-08-03 03:14:00+03	32900.00
DFB2D8	2017-08-05 17:35:00+03	43300.00
DFB2E6	2017-07-31 06:37:00+03	106200.00
DFB313	2017-07-10 10:49:00+03	35300.00
DFB351	2017-08-03 22:38:00+03	53600.00
DFB38D	2017-07-12 13:51:00+03	55800.00
DFB399	2017-08-11 04:45:00+03	63500.00
DFB39E	2017-07-11 15:11:00+03	35200.00
DFB3BB	2017-08-13 07:09:00+03	38800.00
DFB515	2017-07-29 15:15:00+03	43100.00
DFB5AA	2017-07-01 11:33:00+03	6300.00
DFB5BE	2017-07-23 13:37:00+03	52000.00
DFB5C9	2017-08-04 10:49:00+03	77400.00
DFB5F7	2017-07-27 16:38:00+03	35800.00
DFB71F	2017-07-19 17:23:00+03	56000.00
DFB731	2017-07-15 15:30:00+03	156300.00
DFB782	2017-07-25 09:52:00+03	53600.00
DFB79B	2017-07-13 03:09:00+03	89700.00
DFB7D5	2017-08-09 13:44:00+03	27800.00
DFB803	2017-07-16 21:39:00+03	50000.00
DFB864	2017-07-25 16:06:00+03	49600.00
DFB86A	2017-06-30 12:25:00+03	38500.00
DFB89D	2017-07-22 19:29:00+03	92900.00
DFB8B9	2017-08-03 11:29:00+03	51600.00
DFB8E2	2017-07-08 00:55:00+03	36400.00
DFB92C	2017-07-20 03:31:00+03	94000.00
DFB942	2017-08-08 19:59:00+03	38900.00
DFB96C	2017-08-03 15:13:00+03	57500.00
DFB99A	2017-07-24 21:34:00+03	62600.00
DFB99E	2017-07-14 09:12:00+03	85300.00
DFB9E5	2017-08-14 19:38:00+03	397700.00
DFB9F2	2017-07-11 20:32:00+03	25600.00
DFB9FD	2017-08-01 02:50:00+03	99300.00
DFBA3D	2017-07-09 07:47:00+03	8200.00
DFBA45	2017-07-19 23:03:00+03	133200.00
DFBAD2	2017-07-28 12:49:00+03	73100.00
DFBAEF	2017-07-08 16:03:00+03	48800.00
DFBAFE	2017-07-03 10:04:00+03	75600.00
DFBB42	2017-08-15 09:49:00+03	70600.00
DFBBAC	2017-07-24 15:06:00+03	43400.00
DFBBC2	2017-08-01 04:20:00+03	100600.00
DFBBD9	2017-08-05 06:28:00+03	87100.00
DFBC1F	2017-07-21 15:11:00+03	40000.00
DFBC3A	2017-07-06 03:11:00+03	6600.00
DFBC40	2017-07-05 12:02:00+03	11800.00
DFBC52	2017-07-26 21:56:00+03	85000.00
DFBC56	2017-07-24 03:36:00+03	75600.00
DFBC8A	2017-07-29 10:55:00+03	23200.00
DFBC98	2017-07-19 22:02:00+03	16400.00
DFBD89	2017-06-28 13:28:00+03	40400.00
DFBDCC	2017-08-03 13:24:00+03	49100.00
DFBE1D	2017-07-11 07:02:00+03	30200.00
DFBE4F	2017-07-22 11:27:00+03	47400.00
DFBE62	2017-08-07 09:37:00+03	35600.00
DFBE7C	2017-07-23 11:46:00+03	114300.00
DFBE81	2017-08-07 20:03:00+03	9200.00
DFBE8C	2017-07-21 20:59:00+03	28000.00
DFBEFF	2017-07-22 12:24:00+03	65400.00
DFBF18	2017-08-13 14:28:00+03	13400.00
DFBF77	2017-07-08 20:27:00+03	43200.00
DFBFDB	2017-07-24 06:08:00+03	59000.00
DFBFE5	2017-07-22 03:01:00+03	58800.00
DFBFFB	2017-08-11 12:17:00+03	40000.00
DFBFFD	2017-07-08 11:49:00+03	59800.00
DFC00F	2017-08-15 11:09:00+03	76800.00
DFC033	2017-08-01 06:20:00+03	155600.00
DFC0A5	2017-07-27 22:48:00+03	64200.00
DFC128	2017-07-24 00:57:00+03	20200.00
DFC14C	2017-08-10 17:45:00+03	45500.00
DFC18F	2017-07-27 19:13:00+03	30800.00
DFC1A3	2017-07-25 02:09:00+03	31600.00
DFC1B6	2017-08-12 04:00:00+03	55800.00
DFC201	2017-07-26 14:16:00+03	24200.00
DFC278	2017-08-14 20:12:00+03	70600.00
DFC2AB	2017-07-18 23:56:00+03	398500.00
DFC363	2017-07-05 12:11:00+03	13400.00
DFC3A3	2017-07-27 08:22:00+03	60200.00
DFC410	2017-07-18 11:49:00+03	95600.00
DFC459	2017-07-18 13:50:00+03	48800.00
DFC48E	2017-07-04 19:48:00+03	117200.00
DFC495	2017-07-18 17:45:00+03	190400.00
DFC4A0	2017-07-14 19:42:00+03	142400.00
DFC4E3	2017-07-11 16:16:00+03	136200.00
DFC539	2017-08-04 23:36:00+03	52000.00
DFC554	2017-07-07 05:05:00+03	234300.00
DFC58B	2017-07-28 19:30:00+03	56600.00
DFC5B0	2017-08-06 21:01:00+03	90800.00
DFC691	2017-07-14 17:39:00+03	21400.00
DFC69A	2017-07-16 22:33:00+03	36200.00
DFC722	2017-08-15 05:23:00+03	44800.00
DFC727	2017-08-11 10:58:00+03	26000.00
DFC791	2017-08-14 02:02:00+03	112000.00
DFC79E	2017-07-22 14:58:00+03	89200.00
DFC7E0	2017-08-11 20:51:00+03	46200.00
DFC801	2017-07-24 05:51:00+03	27200.00
DFC839	2017-08-14 07:39:00+03	94400.00
DFC856	2017-08-14 20:36:00+03	42800.00
DFC874	2017-07-26 16:26:00+03	71400.00
DFC90B	2017-07-02 10:32:00+03	66600.00
DFC935	2017-07-02 23:19:00+03	43900.00
DFC969	2017-07-31 09:27:00+03	26000.00
DFC980	2017-07-13 07:50:00+03	136800.00
DFC98A	2017-08-05 08:10:00+03	111600.00
DFC9FB	2017-07-19 16:19:00+03	187600.00
DFCA03	2017-07-22 20:45:00+03	125700.00
DFCA5C	2017-06-30 16:02:00+03	56600.00
DFCA8E	2017-07-23 14:32:00+03	67600.00
DFCAC2	2017-07-30 11:23:00+03	27300.00
DFCC6E	2017-07-01 19:49:00+03	6700.00
DFCD70	2017-07-03 15:28:00+03	133200.00
DFCDA2	2017-07-02 14:33:00+03	173900.00
DFCDBD	2017-07-12 02:41:00+03	44300.00
DFCDDA	2017-07-25 14:51:00+03	55800.00
DFCE2E	2017-07-18 13:19:00+03	11600.00
DFCE43	2017-07-19 10:50:00+03	100300.00
DFCE5E	2017-07-03 04:24:00+03	123000.00
DFCEC7	2017-07-13 15:13:00+03	12600.00
DFCEDC	2017-08-11 20:02:00+03	75300.00
DFCEF9	2017-07-20 11:45:00+03	55800.00
DFCF7A	2017-07-30 09:26:00+03	16400.00
DFD003	2017-07-01 10:28:00+03	43800.00
DFD027	2017-06-29 05:29:00+03	119500.00
DFD031	2017-07-12 15:34:00+03	16400.00
DFD0D4	2017-07-29 15:15:00+03	46800.00
DFD0DE	2017-07-06 15:43:00+03	121500.00
DFD13A	2017-07-20 00:47:00+03	47800.00
DFD1D2	2017-07-16 20:20:00+03	17800.00
DFD22E	2017-07-29 22:29:00+03	21800.00
DFD27F	2017-08-11 11:11:00+03	246000.00
DFD2D9	2017-07-13 09:30:00+03	23200.00
DFD2DA	2017-07-24 10:00:00+03	24400.00
DFD2F6	2017-07-01 00:16:00+03	144400.00
DFD303	2017-07-21 17:16:00+03	137700.00
DFD321	2017-07-07 06:17:00+03	34000.00
DFD372	2017-07-12 20:53:00+03	43200.00
DFD3EF	2017-07-19 18:15:00+03	128800.00
DFD425	2017-07-31 00:02:00+03	48800.00
DFD447	2017-07-23 08:16:00+03	28800.00
DFD4C1	2017-08-01 16:08:00+03	20400.00
DFD4DC	2017-08-02 04:26:00+03	255600.00
DFD53B	2017-07-06 10:12:00+03	114400.00
DFD545	2017-06-30 14:46:00+03	85000.00
DFD54D	2017-07-07 00:03:00+03	42700.00
DFD55E	2017-08-05 12:21:00+03	265700.00
DFD561	2017-07-29 23:29:00+03	6700.00
DFD5AA	2017-08-06 16:17:00+03	160000.00
DFD5DB	2017-07-22 16:33:00+03	138100.00
DFD611	2017-08-12 19:54:00+03	44000.00
DFD630	2017-07-04 14:41:00+03	14800.00
DFD667	2017-07-12 09:55:00+03	30200.00
DFD69F	2017-07-06 15:44:00+03	55600.00
DFD6E0	2017-08-03 19:30:00+03	27200.00
DFD76C	2017-08-04 01:29:00+03	174900.00
DFD81A	2017-07-18 20:36:00+03	46500.00
DFD822	2017-08-05 09:17:00+03	37600.00
DFD825	2017-07-12 05:53:00+03	95000.00
DFD881	2017-08-11 17:32:00+03	48800.00
DFD931	2017-08-12 03:33:00+03	112000.00
DFD938	2017-08-14 03:22:00+03	31100.00
DFD97A	2017-07-17 07:35:00+03	257500.00
DFD97E	2017-07-03 05:47:00+03	43900.00
DFD9B9	2017-07-19 03:31:00+03	47600.00
DFD9CF	2017-07-18 07:48:00+03	31900.00
DFD9DF	2017-08-02 02:00:00+03	140300.00
DFDA49	2017-07-20 10:44:00+03	37900.00
DFDA5C	2017-08-09 08:48:00+03	136800.00
DFDAC8	2017-06-29 16:08:00+03	136200.00
DFDB25	2017-06-28 23:07:00+03	81900.00
DFDB28	2017-08-12 23:32:00+03	65500.00
DFDB62	2017-08-02 08:25:00+03	35000.00
DFDBC4	2017-07-07 12:01:00+03	103500.00
DFDBEE	2017-07-14 18:23:00+03	89600.00
DFDBF4	2017-08-05 14:31:00+03	7400.00
DFDC3E	2017-08-06 15:07:00+03	99600.00
DFDC81	2017-08-12 12:24:00+03	40800.00
DFDCEC	2017-08-14 17:21:00+03	112200.00
DFDD1E	2017-07-16 23:46:00+03	34000.00
DFDD2B	2017-08-06 01:07:00+03	31200.00
DFDD89	2017-07-16 02:35:00+03	138000.00
DFDD8F	2017-07-16 01:16:00+03	67800.00
DFDDDB	2017-07-30 12:45:00+03	111000.00
DFDE13	2017-07-25 16:51:00+03	6000.00
DFDE2A	2017-08-14 15:31:00+03	54800.00
DFDE2B	2017-06-28 06:14:00+03	145300.00
DFDEB8	2017-08-01 09:28:00+03	198400.00
DFDECD	2017-08-14 10:20:00+03	67600.00
DFDF38	2017-08-08 01:01:00+03	46300.00
DFDF66	2017-07-18 07:56:00+03	53300.00
DFDF79	2017-07-02 11:06:00+03	115900.00
DFDF96	2017-07-21 13:41:00+03	6600.00
DFDFB5	2017-07-18 10:47:00+03	83000.00
DFDFD1	2017-08-05 11:36:00+03	47200.00
DFE012	2017-08-01 08:12:00+03	89700.00
DFE042	2017-07-04 01:18:00+03	75500.00
DFE058	2017-08-09 23:55:00+03	14400.00
DFE124	2017-07-21 02:19:00+03	56000.00
DFE159	2017-07-23 01:01:00+03	66000.00
DFE18D	2017-06-30 15:52:00+03	31100.00
DFE256	2017-07-20 08:12:00+03	102100.00
DFE2C3	2017-07-04 03:00:00+03	114900.00
DFE2CA	2017-08-05 20:14:00+03	132800.00
DFE2EE	2017-07-27 02:13:00+03	135400.00
DFE35E	2017-07-19 01:56:00+03	24200.00
DFE362	2017-08-08 21:55:00+03	52000.00
DFE37C	2017-07-20 09:30:00+03	71600.00
DFE39E	2017-07-25 13:35:00+03	44800.00
DFE439	2017-07-17 03:11:00+03	81500.00
DFE43C	2017-08-04 11:17:00+03	26800.00
DFE44F	2017-08-11 22:10:00+03	109200.00
DFE4AD	2017-07-21 07:49:00+03	139700.00
DFE4B0	2017-08-12 07:24:00+03	85700.00
DFE4B4	2017-07-10 07:13:00+03	58800.00
DFE4D7	2017-07-22 14:08:00+03	6000.00
DFE56C	2017-07-19 23:15:00+03	84500.00
DFE5AF	2017-08-02 16:14:00+03	41600.00
DFE5EA	2017-07-13 22:35:00+03	66300.00
DFE63E	2017-07-02 10:34:00+03	68800.00
DFE66D	2017-07-07 13:25:00+03	43600.00
DFE6F6	2017-08-13 22:19:00+03	54400.00
DFE717	2017-06-30 23:26:00+03	52100.00
DFE72D	2017-07-09 16:22:00+03	21200.00
DFE73A	2017-08-04 23:34:00+03	55800.00
DFE758	2017-07-06 08:06:00+03	26000.00
DFE759	2017-07-13 03:50:00+03	111700.00
DFE76E	2017-07-29 06:03:00+03	65800.00
DFE78E	2017-07-20 08:57:00+03	12000.00
DFE7AA	2017-07-21 01:06:00+03	29600.00
DFE7CA	2017-07-10 00:56:00+03	136800.00
DFE7F5	2017-06-30 01:23:00+03	67200.00
DFE8B2	2017-07-24 08:36:00+03	27300.00
DFE8ED	2017-08-14 05:23:00+03	111600.00
DFE8F9	2017-07-18 17:24:00+03	28000.00
DFE9C9	2017-07-03 21:06:00+03	6000.00
DFE9CA	2017-07-14 03:35:00+03	24500.00
DFE9D9	2017-07-10 07:33:00+03	14400.00
DFE9E6	2017-08-13 15:21:00+03	59300.00
DFEA62	2017-08-04 03:03:00+03	20600.00
DFEAA4	2017-08-13 16:48:00+03	30800.00
DFEAB0	2017-08-12 15:57:00+03	86400.00
DFEAE8	2017-08-03 03:20:00+03	136200.00
DFEB16	2017-07-19 10:00:00+03	120800.00
DFEB33	2017-07-13 06:25:00+03	101200.00
DFEB45	2017-07-07 03:49:00+03	44000.00
DFEBBA	2017-06-30 14:27:00+03	193900.00
DFEC11	2017-08-08 00:24:00+03	88200.00
DFEC57	2017-07-23 23:13:00+03	112000.00
DFEC8E	2017-07-07 21:25:00+03	20500.00
DFECB3	2017-07-24 19:35:00+03	22000.00
DFECCC	2017-07-07 01:26:00+03	54000.00
DFED6E	2017-07-13 12:59:00+03	47400.00
DFED78	2017-08-04 16:57:00+03	131100.00
DFED80	2017-07-12 03:54:00+03	78000.00
DFED8F	2017-07-07 05:35:00+03	16400.00
DFEDC9	2017-07-15 10:42:00+03	67700.00
DFEE16	2017-08-04 16:32:00+03	26800.00
DFEE63	2017-07-25 08:16:00+03	70600.00
DFEF11	2017-07-08 10:36:00+03	55800.00
DFEF4E	2017-08-02 03:06:00+03	38400.00
DFEF99	2017-08-09 21:06:00+03	22600.00
DFF026	2017-08-06 05:08:00+03	133200.00
DFF03F	2017-06-29 12:11:00+03	56000.00
DFF045	2017-07-14 03:27:00+03	50600.00
DFF06F	2017-07-05 10:07:00+03	35200.00
DFF19C	2017-08-13 04:35:00+03	70800.00
DFF1AF	2017-07-13 01:56:00+03	28800.00
DFF1BD	2017-07-26 11:34:00+03	110000.00
DFF1DB	2017-06-30 11:30:00+03	35200.00
DFF207	2017-08-05 22:00:00+03	12600.00
DFF289	2017-07-19 12:35:00+03	11600.00
DFF2BE	2017-07-25 19:02:00+03	57400.00
DFF336	2017-07-04 23:21:00+03	20000.00
DFF34B	2017-07-12 06:05:00+03	10600.00
DFF3B2	2017-08-06 01:41:00+03	98400.00
DFF3D3	2017-07-18 13:03:00+03	78300.00
DFF3D7	2017-07-21 15:26:00+03	92400.00
DFF459	2017-07-03 17:22:00+03	65900.00
DFF4E7	2017-07-21 14:53:00+03	52000.00
DFF556	2017-08-06 01:46:00+03	36800.00
DFF587	2017-07-26 19:17:00+03	56000.00
DFF5E4	2017-07-15 23:00:00+03	54600.00
DFF606	2017-07-19 18:00:00+03	187600.00
DFF67C	2017-07-14 23:36:00+03	64700.00
DFF6A3	2017-07-22 19:30:00+03	67800.00
DFF6CA	2017-08-02 09:05:00+03	18600.00
DFF6D5	2017-08-02 16:13:00+03	209700.00
DFF6EF	2017-08-05 10:08:00+03	37200.00
DFF82C	2017-07-05 13:09:00+03	49200.00
DFF87C	2017-07-11 19:57:00+03	12400.00
DFF8DC	2017-07-19 08:51:00+03	46000.00
DFF92D	2017-06-30 02:11:00+03	44800.00
DFF98F	2017-07-30 08:46:00+03	44800.00
DFF993	2017-06-29 16:56:00+03	124300.00
DFF9A6	2017-07-23 00:30:00+03	40000.00
DFF9D8	2017-07-29 17:03:00+03	23400.00
DFF9E9	2017-07-26 04:06:00+03	238900.00
DFF9FA	2017-07-10 18:38:00+03	160700.00
DFFA48	2017-07-23 02:56:00+03	40800.00
DFFB36	2017-07-09 13:32:00+03	40400.00
DFFB5C	2017-07-14 10:59:00+03	30100.00
DFFB6A	2017-08-15 03:24:00+03	23200.00
DFFBC5	2017-08-03 11:32:00+03	65900.00
DFFC02	2017-07-10 08:32:00+03	21400.00
DFFC3E	2017-07-19 00:10:00+03	56000.00
DFFCBC	2017-08-11 06:51:00+03	160700.00
DFFCD8	2017-07-23 09:00:00+03	24700.00
DFFD79	2017-07-23 05:43:00+03	45400.00
DFFD82	2017-07-10 09:42:00+03	139300.00
DFFD91	2017-07-06 02:03:00+03	11600.00
DFFDEC	2017-07-04 21:54:00+03	131100.00
DFFE44	2017-06-27 07:25:00+03	31600.00
DFFE4F	2017-07-06 16:15:00+03	131100.00
DFFE77	2017-07-26 08:44:00+03	81600.00
DFFF3E	2017-07-24 02:26:00+03	7800.00
DFFF43	2017-08-13 02:19:00+03	59000.00
DFFFE2	2017-07-31 22:48:00+03	92400.00
E0004D	2017-08-12 20:43:00+03	57500.00
E000A5	2017-08-03 14:50:00+03	47400.00
E0011E	2017-07-04 01:36:00+03	24400.00
E00146	2017-07-24 11:45:00+03	32400.00
E0014F	2017-07-26 21:26:00+03	51900.00
E0019C	2017-07-04 11:28:00+03	64800.00
E001A3	2017-08-01 13:51:00+03	65200.00
E00231	2017-07-27 07:14:00+03	31600.00
E002C4	2017-07-20 22:16:00+03	40800.00
E002C9	2017-07-07 01:05:00+03	52000.00
E002F5	2017-07-10 07:00:00+03	392700.00
E00346	2017-07-09 09:10:00+03	13200.00
E00353	2017-07-24 18:15:00+03	71800.00
E00383	2017-07-22 06:50:00+03	112600.00
E003A0	2017-07-11 17:34:00+03	169600.00
E00425	2017-07-15 00:40:00+03	152400.00
E0047B	2017-07-03 09:16:00+03	276000.00
E0049D	2017-08-02 12:13:00+03	309700.00
E00529	2017-07-05 14:14:00+03	19800.00
E00536	2017-07-22 16:31:00+03	47100.00
E005DE	2017-07-20 08:49:00+03	515000.00
E00624	2017-07-27 23:23:00+03	28000.00
E00651	2017-07-04 20:01:00+03	102100.00
E0066A	2017-07-16 20:26:00+03	24400.00
E00687	2017-07-17 09:05:00+03	56100.00
E0068D	2017-08-04 18:17:00+03	25400.00
E006D3	2017-08-11 02:08:00+03	79900.00
E00715	2017-07-14 06:03:00+03	19800.00
E0074C	2017-07-02 08:47:00+03	503000.00
E0076E	2017-07-14 05:02:00+03	25000.00
E007EB	2017-07-26 22:23:00+03	12600.00
E00814	2017-07-31 23:41:00+03	71600.00
E0082B	2017-07-27 04:35:00+03	213200.00
E0082C	2017-08-08 14:28:00+03	7400.00
E00830	2017-08-01 07:02:00+03	62600.00
E00831	2017-07-01 21:14:00+03	56000.00
E0086B	2017-07-28 04:04:00+03	52000.00
E00875	2017-07-24 09:35:00+03	248400.00
E008A2	2017-07-10 23:25:00+03	22000.00
E008BC	2017-07-16 13:23:00+03	75200.00
E008C3	2017-08-11 03:20:00+03	98500.00
E00923	2017-07-03 11:18:00+03	38600.00
E00945	2017-07-17 15:49:00+03	100600.00
E009F8	2017-07-07 03:02:00+03	75600.00
E00A67	2017-07-10 03:03:00+03	83000.00
E00ABF	2017-07-06 19:18:00+03	92400.00
E00AF2	2017-08-07 06:50:00+03	58800.00
E00B4E	2017-07-12 13:02:00+03	12600.00
E00B86	2017-07-14 17:15:00+03	38200.00
E00BF3	2017-07-28 02:57:00+03	58800.00
E00C2E	2017-07-13 18:38:00+03	61500.00
E00C69	2017-07-17 18:12:00+03	38600.00
E00C84	2017-08-04 15:28:00+03	108900.00
E00C8A	2017-07-08 08:21:00+03	49800.00
E00CB1	2017-07-26 13:29:00+03	55700.00
E00CB3	2017-08-01 11:44:00+03	96600.00
E00CC6	2017-07-25 23:19:00+03	54100.00
E00CCA	2017-08-14 20:54:00+03	218200.00
E00CFA	2017-08-03 23:13:00+03	137600.00
E00D54	2017-07-21 15:27:00+03	6700.00
E00D68	2017-07-18 12:38:00+03	56000.00
E00D7D	2017-08-13 13:33:00+03	12800.00
E00D81	2017-07-19 19:40:00+03	64500.00
E00E13	2017-08-14 17:01:00+03	26000.00
E00E8D	2017-07-09 23:42:00+03	21200.00
E00EDF	2017-07-19 00:39:00+03	155600.00
E00F1E	2017-08-13 15:30:00+03	115400.00
E00F31	2017-07-08 04:38:00+03	63200.00
E00F34	2017-07-30 00:15:00+03	65500.00
E0102D	2017-07-10 06:33:00+03	191200.00
E010A9	2017-07-05 13:37:00+03	61800.00
E010BE	2017-08-03 18:32:00+03	23200.00
E010C8	2017-07-27 02:59:00+03	37900.00
E010E6	2017-08-13 07:55:00+03	37200.00
E01118	2017-08-02 08:15:00+03	55800.00
E0112D	2017-08-02 15:54:00+03	55500.00
E011D0	2017-07-05 09:56:00+03	254700.00
E01249	2017-08-08 10:37:00+03	56200.00
E01284	2017-07-11 08:36:00+03	23200.00
E01285	2017-08-14 05:38:00+03	68400.00
E013BC	2017-07-20 23:35:00+03	56100.00
E013CD	2017-08-10 00:05:00+03	62900.00
E01423	2017-07-24 07:17:00+03	23400.00
E01473	2017-07-16 18:48:00+03	27800.00
E014DE	2017-08-14 09:43:00+03	205400.00
E01504	2017-07-03 09:49:00+03	204700.00
E01598	2017-07-02 09:13:00+03	25600.00
E015D8	2017-08-04 00:02:00+03	46300.00
E0165B	2017-08-10 05:51:00+03	260300.00
E01677	2017-07-14 11:46:00+03	69800.00
E016B2	2017-08-07 21:26:00+03	32900.00
E016DF	2017-08-13 04:41:00+03	75300.00
E016F3	2017-07-22 06:44:00+03	172100.00
E01778	2017-07-11 08:56:00+03	44800.00
E0178D	2017-07-20 03:41:00+03	40000.00
E01845	2017-08-05 02:04:00+03	65900.00
E01877	2017-08-11 13:03:00+03	56000.00
E018F4	2017-07-30 04:15:00+03	81700.00
E018F7	2017-07-18 10:58:00+03	26200.00
E01909	2017-07-16 13:58:00+03	156500.00
E0193E	2017-08-02 21:34:00+03	28000.00
E0194E	2017-08-09 06:55:00+03	132800.00
E01978	2017-08-10 16:21:00+03	393000.00
E019BE	2017-07-31 03:31:00+03	75300.00
E019CA	2017-08-12 03:18:00+03	56000.00
E01A31	2017-08-10 05:09:00+03	284400.00
E01A6D	2017-08-09 02:58:00+03	67600.00
E01ADD	2017-07-01 19:49:00+03	32400.00
E01B58	2017-07-16 06:12:00+03	46400.00
E01BA1	2017-07-05 05:42:00+03	65900.00
E01BB9	2017-07-27 21:59:00+03	19600.00
E01C11	2017-07-17 00:41:00+03	64800.00
E01C2A	2017-06-25 09:26:00+03	56600.00
E01C3B	2017-07-25 14:11:00+03	93200.00
E01DCD	2017-07-10 22:05:00+03	44600.00
E01DDE	2017-07-11 22:59:00+03	149800.00
E01F34	2017-07-19 18:50:00+03	45200.00
E01F5D	2017-07-09 01:25:00+03	28000.00
E01FC0	2017-08-05 18:21:00+03	68000.00
E01FF9	2017-08-10 06:36:00+03	32800.00
E020C7	2017-08-13 22:27:00+03	77000.00
E020CD	2017-07-30 10:15:00+03	27700.00
E020DD	2017-08-09 10:33:00+03	21800.00
E0213C	2017-07-06 13:19:00+03	34400.00
E0216A	2017-07-02 14:42:00+03	37800.00
E02191	2017-08-14 13:12:00+03	138500.00
E021A5	2017-07-10 19:55:00+03	271100.00
E021AD	2017-07-25 22:41:00+03	6700.00
E02218	2017-07-02 18:10:00+03	62000.00
E0221B	2017-07-07 22:22:00+03	30200.00
E02243	2017-08-15 00:50:00+03	283100.00
E02256	2017-08-10 05:57:00+03	99700.00
E02259	2017-07-22 18:40:00+03	29600.00
E022AC	2017-08-14 11:03:00+03	49200.00
E022E0	2017-07-30 04:53:00+03	96300.00
E02304	2017-08-05 12:48:00+03	22000.00
E02311	2017-07-21 13:33:00+03	48900.00
E02329	2017-07-10 18:27:00+03	117600.00
E02355	2017-07-03 15:32:00+03	65000.00
E02399	2017-08-04 17:52:00+03	46800.00
E023C3	2017-07-29 20:08:00+03	56100.00
E023FB	2017-07-23 09:16:00+03	29800.00
E02408	2017-06-27 17:51:00+03	56900.00
E02419	2017-08-03 02:45:00+03	12400.00
E02429	2017-07-25 10:12:00+03	40000.00
E02442	2017-08-12 17:14:00+03	67800.00
E0245A	2017-08-09 05:24:00+03	21200.00
E0246C	2017-07-24 04:57:00+03	49800.00
E024BC	2017-08-09 14:11:00+03	86300.00
E024C5	2017-07-08 23:26:00+03	42400.00
E0252B	2017-07-08 19:42:00+03	36400.00
E02538	2017-07-28 19:06:00+03	51000.00
E0256B	2017-07-25 13:45:00+03	112000.00
E025EC	2017-08-11 17:32:00+03	67200.00
E0267A	2017-06-29 12:27:00+03	62600.00
E0267D	2017-07-08 20:00:00+03	19600.00
E026AC	2017-07-27 07:43:00+03	12600.00
E026C3	2017-07-06 09:13:00+03	89600.00
E026C4	2017-07-12 10:58:00+03	21400.00
E02708	2017-08-13 22:19:00+03	65400.00
E0276A	2017-07-19 11:03:00+03	25200.00
E027ED	2017-07-04 23:48:00+03	14400.00
E02895	2017-07-26 08:21:00+03	167400.00
E028AB	2017-07-11 07:35:00+03	58100.00
E028B2	2017-07-18 13:50:00+03	112600.00
E0291E	2017-08-07 23:45:00+03	67600.00
E02956	2017-08-01 10:21:00+03	19600.00
E02A72	2017-07-03 05:27:00+03	42800.00
E02B2C	2017-08-09 10:18:00+03	40400.00
E02B57	2017-07-10 03:44:00+03	36200.00
E02BDE	2017-07-20 13:54:00+03	123000.00
E02BE3	2017-07-29 22:55:00+03	44000.00
E02C59	2017-07-12 12:44:00+03	28000.00
E02C65	2017-07-10 06:30:00+03	16400.00
E02C9A	2017-06-25 10:41:00+03	130300.00
E02CDE	2017-07-10 15:01:00+03	60200.00
E02D32	2017-08-08 08:01:00+03	42600.00
E02D4E	2017-07-28 20:50:00+03	14400.00
E02DA0	2017-07-24 08:35:00+03	357600.00
E02E16	2017-07-17 09:54:00+03	139100.00
E02E60	2017-08-02 03:13:00+03	131600.00
E02E63	2017-07-08 20:37:00+03	61800.00
E02E78	2017-08-05 04:39:00+03	26800.00
E02EE3	2017-06-29 04:51:00+03	52000.00
E02F3A	2017-08-13 19:43:00+03	98200.00
E02F7A	2017-07-11 17:30:00+03	14800.00
E02FE4	2017-07-08 19:24:00+03	269400.00
E02FE7	2017-07-10 22:07:00+03	64000.00
E0304B	2017-07-03 20:06:00+03	103500.00
E03077	2017-08-06 23:24:00+03	53300.00
E030A3	2017-07-18 19:26:00+03	75600.00
E030CB	2017-07-03 06:19:00+03	37600.00
E03105	2017-08-01 17:36:00+03	93900.00
E03146	2017-07-26 16:13:00+03	202700.00
E0314C	2017-07-06 08:53:00+03	96800.00
E03151	2017-07-28 00:40:00+03	96100.00
E03184	2017-08-06 12:57:00+03	170100.00
E031DD	2017-07-29 13:17:00+03	29600.00
E032B6	2017-07-31 20:47:00+03	82800.00
E03315	2017-07-28 01:40:00+03	29600.00
E03378	2017-07-07 12:04:00+03	136800.00
E0338D	2017-08-13 22:25:00+03	31400.00
E0338E	2017-08-15 13:49:00+03	33100.00
E033A4	2017-08-07 10:54:00+03	131100.00
E033AE	2017-07-29 02:32:00+03	36200.00
E033E0	2017-08-15 02:00:00+03	28000.00
E03436	2017-07-19 13:53:00+03	57500.00
E0346F	2017-08-04 11:15:00+03	58400.00
E034AD	2017-08-12 13:54:00+03	49100.00
E034F9	2017-08-06 06:05:00+03	52400.00
E034FC	2017-07-04 11:24:00+03	56000.00
E0355F	2017-06-23 18:41:00+03	55800.00
E03561	2017-07-26 02:55:00+03	135600.00
E03571	2017-07-26 21:01:00+03	13700.00
E03572	2017-08-09 06:44:00+03	87700.00
E03589	2017-07-24 09:21:00+03	55800.00
E0358D	2017-07-19 16:21:00+03	73200.00
E0360E	2017-08-11 13:30:00+03	16400.00
E03639	2017-06-29 05:32:00+03	155600.00
E0370A	2017-07-31 17:39:00+03	30800.00
E03770	2017-07-13 05:38:00+03	23900.00
E037BC	2017-07-13 12:16:00+03	369000.00
E037C1	2017-07-02 08:06:00+03	56000.00
E037E4	2017-07-02 13:52:00+03	196100.00
E0380A	2017-07-23 08:52:00+03	8600.00
E03829	2017-07-31 22:43:00+03	8200.00
E03869	2017-07-24 04:11:00+03	100600.00
E03876	2017-08-11 11:11:00+03	66600.00
E03884	2017-07-01 03:57:00+03	49100.00
E03900	2017-07-18 07:40:00+03	57700.00
E03919	2017-08-04 16:25:00+03	51600.00
E03920	2017-07-26 07:15:00+03	44800.00
E03923	2017-07-26 15:52:00+03	96800.00
E03959	2017-08-14 11:52:00+03	46500.00
E039C3	2017-08-15 14:10:00+03	28800.00
E03A56	2017-07-13 23:51:00+03	66600.00
E03A99	2017-06-30 10:58:00+03	52000.00
E03AB1	2017-07-23 08:31:00+03	56000.00
E03B7A	2017-08-03 12:10:00+03	169900.00
E03BB5	2017-08-05 13:04:00+03	13000.00
E03C20	2017-07-27 14:41:00+03	26100.00
E03C25	2017-08-05 19:37:00+03	46200.00
E03C27	2017-08-03 08:17:00+03	24000.00
E03CEF	2017-07-15 14:32:00+03	81300.00
E03D0E	2017-07-14 21:53:00+03	185600.00
E03D1E	2017-08-12 03:12:00+03	26000.00
E03D43	2017-07-08 02:15:00+03	97200.00
E03D9F	2017-07-07 03:20:00+03	62600.00
E03DF2	2017-07-04 23:30:00+03	82200.00
E03E06	2017-07-05 22:39:00+03	65100.00
E03E32	2017-07-26 08:29:00+03	216300.00
E03F11	2017-07-25 17:47:00+03	20800.00
E03F6E	2017-08-05 02:41:00+03	28800.00
E03F9D	2017-08-11 15:46:00+03	63400.00
E03FD0	2017-07-04 05:08:00+03	99300.00
E0407A	2017-08-03 08:24:00+03	84200.00
E040EA	2017-07-11 15:21:00+03	51200.00
E040EC	2017-08-12 05:16:00+03	56000.00
E04106	2017-07-27 17:44:00+03	22000.00
E04167	2017-07-25 15:45:00+03	43600.00
E041AA	2017-07-04 19:57:00+03	74600.00
E04221	2017-07-23 12:13:00+03	111600.00
E04228	2017-08-12 09:40:00+03	28800.00
E04260	2017-07-28 14:42:00+03	192400.00
E042A1	2017-07-29 19:27:00+03	49800.00
E042D1	2017-07-27 11:32:00+03	12400.00
E042E3	2017-08-09 11:54:00+03	94200.00
E043A6	2017-07-25 01:23:00+03	129700.00
E043C8	2017-07-16 15:41:00+03	34000.00
E04462	2017-07-02 08:11:00+03	26000.00
E044A0	2017-08-14 03:02:00+03	138400.00
E044A6	2017-08-12 06:58:00+03	172700.00
E044DD	2017-07-12 19:00:00+03	67300.00
E044E2	2017-07-12 12:45:00+03	34700.00
E04508	2017-08-02 19:16:00+03	39300.00
E045B8	2017-07-06 15:54:00+03	67700.00
E04639	2017-08-06 09:35:00+03	184300.00
E0463C	2017-07-25 15:56:00+03	84500.00
E04649	2017-07-22 03:45:00+03	246000.00
E04651	2017-07-18 11:53:00+03	30200.00
E04690	2017-07-22 06:05:00+03	44800.00
E046B6	2017-07-08 17:00:00+03	61800.00
E046CA	2017-07-26 21:34:00+03	32700.00
E046D9	2017-07-12 06:52:00+03	85000.00
E04705	2017-07-19 21:00:00+03	28000.00
E04742	2017-08-06 13:04:00+03	387600.00
E04779	2017-08-02 18:49:00+03	34100.00
E0477C	2017-07-09 18:48:00+03	71900.00
E04788	2017-08-12 19:58:00+03	68800.00
E04794	2017-07-18 10:36:00+03	270200.00
E04795	2017-07-16 17:01:00+03	221800.00
E047CC	2017-08-07 21:23:00+03	271200.00
E047DC	2017-07-22 23:59:00+03	16400.00
E047DD	2017-07-22 18:41:00+03	90800.00
E0480B	2017-07-02 20:26:00+03	49700.00
E04810	2017-07-08 19:46:00+03	39300.00
E04839	2017-08-01 15:37:00+03	28800.00
E04888	2017-07-03 22:41:00+03	269300.00
E0491F	2017-07-03 22:26:00+03	58100.00
E0496D	2017-08-02 04:42:00+03	28800.00
E049BA	2017-06-25 15:08:00+03	65900.00
E049C1	2017-08-01 23:26:00+03	177600.00
E049CE	2017-08-02 23:15:00+03	42400.00
E049D5	2017-07-12 03:21:00+03	93500.00
E049E0	2017-07-12 08:22:00+03	29400.00
E049E4	2017-07-24 06:48:00+03	119500.00
E049F3	2017-06-27 14:19:00+03	41200.00
E04A3F	2017-06-27 17:17:00+03	15100.00
E04AFC	2017-07-28 11:56:00+03	27800.00
E04B13	2017-08-03 09:41:00+03	85000.00
E04B5E	2017-07-14 14:12:00+03	243600.00
E04B7F	2017-07-18 20:52:00+03	95200.00
E04B9B	2017-08-07 01:38:00+03	369000.00
E04B9E	2017-08-05 15:15:00+03	283100.00
E04BDC	2017-08-10 11:04:00+03	49100.00
E04C39	2017-07-26 04:52:00+03	112000.00
E04C8F	2017-08-01 18:34:00+03	67000.00
E04CA9	2017-07-22 03:06:00+03	12600.00
E04D5D	2017-07-23 05:39:00+03	14400.00
E04D67	2017-08-02 10:45:00+03	110000.00
E04D98	2017-07-12 03:15:00+03	55800.00
E04DA0	2017-07-06 00:11:00+03	234600.00
E04DEA	2017-07-12 10:37:00+03	16300.00
E04DF5	2017-07-03 17:06:00+03	167400.00
E04E09	2017-08-12 18:21:00+03	46400.00
E04E5A	2017-08-08 12:03:00+03	18400.00
E04E86	2017-08-10 04:16:00+03	29400.00
E04ED3	2017-08-14 16:02:00+03	54500.00
E04EF9	2017-07-08 11:12:00+03	59600.00
E04F06	2017-08-07 03:46:00+03	64600.00
E04F07	2017-07-20 03:25:00+03	38200.00
E04F11	2017-08-02 12:24:00+03	6000.00
E04FA9	2017-07-02 20:21:00+03	52000.00
E05098	2017-07-16 10:00:00+03	43500.00
E050FB	2017-08-03 11:55:00+03	45100.00
E0516F	2017-07-15 01:14:00+03	25400.00
E0518A	2017-08-05 07:56:00+03	39200.00
E05196	2017-08-05 14:34:00+03	48800.00
E05198	2017-07-03 09:05:00+03	12600.00
E051D9	2017-08-13 15:31:00+03	112000.00
E0520B	2017-08-12 06:40:00+03	92100.00
E05291	2017-07-10 20:32:00+03	6300.00
E05293	2017-08-10 02:55:00+03	260900.00
E052A7	2017-07-26 07:24:00+03	34000.00
E052D5	2017-07-21 02:42:00+03	6600.00
E052DC	2017-07-04 04:25:00+03	45200.00
E05321	2017-07-23 22:56:00+03	69500.00
E05329	2017-07-10 01:58:00+03	54300.00
E05335	2017-07-08 18:55:00+03	84000.00
E0533B	2017-07-16 20:06:00+03	20800.00
E05351	2017-07-19 07:09:00+03	80400.00
E05355	2017-07-02 09:24:00+03	6800.00
E0538B	2017-07-12 05:43:00+03	114400.00
E053C8	2017-07-18 04:49:00+03	145100.00
E053CF	2017-07-08 14:48:00+03	20400.00
E0540F	2017-07-03 03:30:00+03	37600.00
E0545C	2017-08-15 09:32:00+03	129000.00
E05480	2017-07-19 01:56:00+03	28300.00
E054F3	2017-08-07 04:09:00+03	119600.00
E0550A	2017-07-11 09:15:00+03	36600.00
E0558B	2017-07-14 01:46:00+03	283100.00
E0567F	2017-07-03 09:29:00+03	23600.00
E056AE	2017-07-08 07:10:00+03	28800.00
E056E8	2017-07-02 23:24:00+03	46400.00
E05703	2017-07-26 21:33:00+03	60400.00
E0570B	2017-07-19 17:37:00+03	196000.00
E05739	2017-07-12 03:13:00+03	50600.00
E0573A	2017-07-21 15:28:00+03	59300.00
E05778	2017-08-12 19:17:00+03	65500.00
E057C1	2017-07-08 10:42:00+03	399600.00
E057ED	2017-07-05 14:54:00+03	176600.00
E057F3	2017-07-20 21:00:00+03	205600.00
E05809	2017-08-10 17:08:00+03	77600.00
E0580E	2017-07-25 08:35:00+03	6800.00
E05888	2017-07-16 08:32:00+03	23400.00
E05894	2017-08-13 23:05:00+03	50800.00
E058EE	2017-07-09 16:38:00+03	6000.00
E0591E	2017-07-06 23:54:00+03	77200.00
E0592A	2017-08-11 19:39:00+03	47600.00
E059D7	2017-07-15 17:14:00+03	35900.00
E05A28	2017-07-27 10:05:00+03	121400.00
E05A3A	2017-07-24 15:39:00+03	47100.00
E05A68	2017-08-02 00:38:00+03	129000.00
E05ABB	2017-07-03 17:41:00+03	28000.00
E05BC0	2017-07-26 23:05:00+03	121400.00
E05BC7	2017-08-10 07:18:00+03	71600.00
E05C65	2017-08-13 01:53:00+03	55700.00
E05C73	2017-07-21 01:26:00+03	23100.00
E05C77	2017-07-04 10:37:00+03	147700.00
E05C86	2017-07-07 12:02:00+03	66600.00
E05C8F	2017-08-13 20:32:00+03	70800.00
E05D20	2017-07-01 01:17:00+03	47700.00
E05D29	2017-07-06 15:40:00+03	67400.00
E05D61	2017-07-21 14:51:00+03	149200.00
E05DA6	2017-08-09 17:40:00+03	6700.00
E05DBA	2017-08-02 20:05:00+03	40100.00
E05E0E	2017-08-14 14:38:00+03	14000.00
E05E33	2017-07-26 22:20:00+03	100600.00
E05E45	2017-07-21 00:56:00+03	75300.00
E05E8E	2017-07-05 11:39:00+03	24400.00
E05F18	2017-08-11 19:51:00+03	16400.00
E05F43	2017-07-18 09:05:00+03	23400.00
E05F63	2017-07-18 19:31:00+03	98400.00
E05F71	2017-08-13 03:44:00+03	38400.00
E05FBE	2017-06-28 03:53:00+03	128800.00
E05FFB	2017-07-19 23:17:00+03	56900.00
E0602A	2017-08-13 22:06:00+03	46400.00
E0602D	2017-08-08 04:20:00+03	38000.00
E0603E	2017-08-12 10:50:00+03	6700.00
E06061	2017-07-14 20:45:00+03	93900.00
E0607C	2017-08-07 19:07:00+03	136200.00
E060F2	2017-07-27 02:14:00+03	86600.00
E06101	2017-08-03 18:14:00+03	295400.00
E0613C	2017-07-12 12:26:00+03	35200.00
E0618B	2017-07-07 19:31:00+03	58000.00
E061AC	2017-07-06 11:54:00+03	147200.00
E061B3	2017-07-20 17:21:00+03	7400.00
E061B7	2017-07-17 07:19:00+03	89000.00
E06238	2017-07-11 10:23:00+03	270700.00
E06253	2017-07-03 10:27:00+03	71000.00
E06280	2017-07-13 11:59:00+03	87900.00
E062A5	2017-07-06 21:58:00+03	95000.00
E062BD	2017-07-23 01:10:00+03	48500.00
E062D3	2017-08-04 12:12:00+03	130400.00
E0631D	2017-07-17 12:16:00+03	24400.00
E0634B	2017-07-14 10:18:00+03	109600.00
E06373	2017-08-06 20:09:00+03	21400.00
E0637C	2017-08-15 14:09:00+03	42600.00
E063BA	2017-07-20 09:27:00+03	73300.00
E063BF	2017-07-12 17:39:00+03	83000.00
E063F7	2017-08-04 06:00:00+03	116500.00
E06480	2017-07-16 15:30:00+03	66000.00
E064A7	2017-07-27 11:49:00+03	73600.00
E064DF	2017-07-29 11:22:00+03	301600.00
E0653C	2017-07-22 20:09:00+03	461700.00
E06559	2017-08-08 10:45:00+03	28800.00
E06585	2017-07-16 13:12:00+03	72200.00
E065C4	2017-07-19 16:01:00+03	83200.00
E06614	2017-07-25 19:53:00+03	153200.00
E0668E	2017-08-13 01:07:00+03	14800.00
E0669D	2017-07-18 10:47:00+03	21400.00
E066B8	2017-08-15 09:15:00+03	55800.00
E066C0	2017-08-06 11:52:00+03	16400.00
E066DC	2017-07-22 08:59:00+03	50600.00
E06728	2017-07-26 15:10:00+03	204200.00
E06734	2017-06-28 03:09:00+03	16400.00
E067A3	2017-07-23 07:27:00+03	51200.00
E067B5	2017-07-22 20:32:00+03	6700.00
E067B6	2017-07-17 05:54:00+03	19600.00
E0682E	2017-07-17 15:51:00+03	539400.00
E0685E	2017-08-10 01:11:00+03	775800.00
E068DA	2017-07-04 20:01:00+03	166000.00
E068ED	2017-08-10 01:24:00+03	48700.00
E06933	2017-08-07 23:05:00+03	201400.00
E06988	2017-07-17 20:41:00+03	46200.00
E069B4	2017-07-09 04:42:00+03	128000.00
E069E9	2017-08-11 18:13:00+03	95700.00
E06A37	2017-07-18 09:33:00+03	22000.00
E06A6F	2017-08-06 08:28:00+03	23600.00
E06A88	2017-08-14 14:17:00+03	89600.00
E06B25	2017-08-12 15:12:00+03	19600.00
E06B59	2017-07-14 20:57:00+03	132800.00
E06B84	2017-07-28 06:11:00+03	177200.00
E06B89	2017-07-05 23:26:00+03	143900.00
E06BE8	2017-07-14 09:53:00+03	52700.00
E06BF0	2017-07-15 15:19:00+03	25200.00
E06BF2	2017-07-31 00:38:00+03	113600.00
E06C0A	2017-07-23 20:24:00+03	24400.00
E06CF6	2017-07-01 06:38:00+03	30200.00
E06D26	2017-08-06 02:38:00+03	136200.00
E06D5F	2017-07-11 23:08:00+03	125000.00
E06D61	2017-07-26 12:19:00+03	65500.00
E06D96	2017-07-02 14:39:00+03	25200.00
E06DA1	2017-06-30 10:29:00+03	91500.00
E06DA9	2017-07-23 05:46:00+03	101700.00
E06E71	2017-08-04 15:59:00+03	71900.00
E06E80	2017-07-23 04:01:00+03	147100.00
E06E88	2017-07-20 21:22:00+03	27200.00
E06E90	2017-08-01 16:25:00+03	29600.00
E06EA1	2017-07-05 18:48:00+03	89700.00
E06F15	2017-07-04 10:39:00+03	61600.00
E06F74	2017-08-14 09:00:00+03	36200.00
E06F8F	2017-08-11 13:45:00+03	88000.00
E06FA8	2017-08-02 23:29:00+03	84100.00
E07050	2017-07-10 18:25:00+03	28000.00
E07083	2017-07-20 03:42:00+03	97900.00
E070C4	2017-08-11 13:07:00+03	271400.00
E070FC	2017-08-04 10:08:00+03	48300.00
E07142	2017-08-13 16:41:00+03	28300.00
E07145	2017-07-08 04:33:00+03	73300.00
E0716D	2017-07-12 17:38:00+03	61000.00
E071A1	2017-07-28 22:25:00+03	229400.00
E071E5	2017-08-04 14:01:00+03	231900.00
E07209	2017-07-27 06:21:00+03	62600.00
E07227	2017-07-22 13:19:00+03	248400.00
E07254	2017-07-11 17:58:00+03	63200.00
E07270	2017-08-13 01:51:00+03	112000.00
E07313	2017-08-14 14:09:00+03	38000.00
E07315	2017-07-19 10:05:00+03	32200.00
E073EA	2017-07-26 09:29:00+03	55800.00
E073FD	2017-07-21 07:15:00+03	37900.00
E07402	2017-08-13 22:42:00+03	62300.00
E07434	2017-08-05 22:52:00+03	58800.00
E074BC	2017-08-08 02:23:00+03	26200.00
E07576	2017-07-11 02:23:00+03	37900.00
E075BC	2017-07-06 22:59:00+03	50000.00
E076F9	2017-08-12 11:35:00+03	25600.00
E0770C	2017-08-13 10:18:00+03	108000.00
E0771C	2017-07-28 19:30:00+03	18000.00
E07738	2017-07-12 08:29:00+03	162500.00
E07785	2017-07-14 17:13:00+03	73200.00
E0779F	2017-08-13 00:11:00+03	79800.00
E077B8	2017-07-22 21:28:00+03	27200.00
E07800	2017-07-28 10:21:00+03	37900.00
E07835	2017-08-14 13:53:00+03	13800.00
E0783A	2017-07-30 16:27:00+03	23200.00
E0789D	2017-08-10 16:23:00+03	10800.00
E07924	2017-07-21 04:47:00+03	40000.00
E0794C	2017-08-03 19:17:00+03	49800.00
E07959	2017-07-25 16:55:00+03	40100.00
E07993	2017-07-21 06:56:00+03	27200.00
E079B9	2017-07-08 19:06:00+03	26000.00
E079E6	2017-06-29 08:32:00+03	167400.00
E07A16	2017-08-09 01:57:00+03	42000.00
E07A55	2017-08-06 15:12:00+03	14000.00
E07AA9	2017-07-28 15:26:00+03	46400.00
E07AAB	2017-07-17 02:20:00+03	21400.00
E07AB1	2017-08-14 09:15:00+03	39300.00
E07AC3	2017-07-22 06:03:00+03	29600.00
E07B0A	2017-08-08 20:33:00+03	125400.00
E07B2E	2017-07-23 18:16:00+03	23200.00
E07BC9	2017-07-13 10:10:00+03	42000.00
E07BD5	2017-08-12 15:01:00+03	39800.00
E07C22	2017-07-09 07:01:00+03	14000.00
E07CB7	2017-08-13 02:29:00+03	50000.00
E07CD2	2017-08-04 06:25:00+03	83700.00
E07CE0	2017-07-28 14:54:00+03	15900.00
E07CED	2017-07-08 15:14:00+03	96800.00
E07CFE	2017-07-02 00:27:00+03	19600.00
E07DAA	2017-08-14 21:14:00+03	65900.00
E07DB8	2017-07-13 08:02:00+03	32800.00
E07DCB	2017-07-25 12:31:00+03	28800.00
E07DDE	2017-07-05 21:49:00+03	108700.00
E07E5F	2017-06-29 10:30:00+03	65000.00
E07E85	2017-07-25 00:36:00+03	169900.00
E07EA2	2017-07-13 01:06:00+03	40800.00
E07EA6	2017-07-17 14:33:00+03	47100.00
E07EB4	2017-08-13 15:21:00+03	90600.00
E07EF2	2017-07-04 07:58:00+03	369000.00
E07F04	2017-08-10 04:59:00+03	117200.00
E07F4A	2017-08-10 14:47:00+03	98300.00
E07F87	2017-06-28 05:27:00+03	48500.00
E07F8E	2017-07-07 02:46:00+03	100600.00
E07FA3	2017-07-30 09:17:00+03	58600.00
E07FEC	2017-07-03 07:56:00+03	153200.00
E0802F	2017-07-08 10:55:00+03	15000.00
E08037	2017-07-31 19:16:00+03	28000.00
E0805B	2017-07-30 07:37:00+03	68100.00
E08076	2017-08-07 08:35:00+03	130400.00
E0808B	2017-07-10 02:42:00+03	52000.00
E08090	2017-07-04 10:14:00+03	183200.00
E080C1	2017-07-28 18:05:00+03	92800.00
E080E7	2017-08-07 02:31:00+03	23200.00
E080EA	2017-07-24 18:36:00+03	40800.00
E0810A	2017-08-07 17:21:00+03	55000.00
E08115	2017-07-15 03:29:00+03	99300.00
E08141	2017-07-27 12:04:00+03	54000.00
E08153	2017-07-26 05:34:00+03	23200.00
E0818C	2017-07-03 09:19:00+03	106900.00
E081D9	2017-07-03 14:27:00+03	34000.00
E08273	2017-07-22 01:19:00+03	121400.00
E0829D	2017-08-15 17:01:00+03	15900.00
E083C0	2017-07-25 16:30:00+03	57600.00
E0841C	2017-07-18 18:55:00+03	57600.00
E08449	2017-08-05 19:39:00+03	57600.00
E0847D	2017-07-21 01:29:00+03	246000.00
E08511	2017-08-02 09:17:00+03	23200.00
E08552	2017-07-14 13:08:00+03	22000.00
E085B9	2017-07-27 03:32:00+03	29600.00
E085E1	2017-07-16 23:34:00+03	135000.00
E0864B	2017-07-04 09:38:00+03	37100.00
E08668	2017-07-05 12:20:00+03	35800.00
E086BC	2017-07-13 23:52:00+03	102000.00
E086C7	2017-07-26 13:56:00+03	86800.00
E08781	2017-07-08 11:06:00+03	44000.00
E08787	2017-07-04 03:40:00+03	56000.00
E08791	2017-07-19 16:30:00+03	21800.00
E08798	2017-07-04 18:06:00+03	192400.00
E087C7	2017-07-22 07:07:00+03	105400.00
E087F1	2017-07-21 11:18:00+03	55600.00
E08815	2017-07-04 03:26:00+03	53700.00
E0881F	2017-07-08 22:08:00+03	28000.00
E08831	2017-07-26 00:23:00+03	40300.00
E0883D	2017-07-18 00:56:00+03	15100.00
E0888C	2017-07-11 19:13:00+03	28800.00
E088DD	2017-08-13 10:33:00+03	67700.00
E088E0	2017-07-10 00:26:00+03	29400.00
E08910	2017-07-15 01:40:00+03	199700.00
E08957	2017-08-09 00:02:00+03	93000.00
E08963	2017-07-14 19:43:00+03	122800.00
E089C7	2017-08-11 23:34:00+03	99200.00
E089DD	2017-07-13 19:00:00+03	43200.00
E08A5B	2017-07-12 10:57:00+03	74400.00
E08A6C	2017-07-14 23:43:00+03	155700.00
E08B6F	2017-08-07 07:24:00+03	160400.00
E08BBE	2017-08-07 04:28:00+03	35400.00
E08C03	2017-07-14 02:46:00+03	39800.00
E08C49	2017-08-11 07:34:00+03	95600.00
E08C6C	2017-07-20 08:19:00+03	37600.00
E08C7D	2017-07-30 20:09:00+03	23200.00
E08CB7	2017-07-08 07:11:00+03	88000.00
E08CD6	2017-07-08 00:32:00+03	24400.00
E08CEC	2017-08-04 11:15:00+03	28000.00
E08D0F	2017-07-29 09:26:00+03	15100.00
E08D67	2017-07-02 17:14:00+03	46400.00
E08D82	2017-07-22 05:40:00+03	29000.00
E08D88	2017-07-22 20:25:00+03	7400.00
E08E02	2017-08-14 03:25:00+03	135600.00
E08E06	2017-07-13 06:26:00+03	406700.00
E08EDA	2017-07-04 01:04:00+03	139000.00
E08EDE	2017-07-15 09:40:00+03	25600.00
E08F53	2017-08-14 17:24:00+03	31600.00
E08F93	2017-07-01 08:56:00+03	14000.00
E08FB3	2017-08-03 05:43:00+03	40400.00
E08FC0	2017-06-29 21:35:00+03	43900.00
E0902C	2017-07-02 06:36:00+03	12600.00
E0906B	2017-08-10 08:37:00+03	78600.00
E0911B	2017-08-03 07:03:00+03	46400.00
E0915C	2017-08-14 22:12:00+03	38200.00
E09172	2017-08-12 12:27:00+03	24700.00
E091A0	2017-08-06 08:50:00+03	16400.00
E09200	2017-07-16 10:45:00+03	66600.00
E0922D	2017-07-24 16:27:00+03	112000.00
E09278	2017-07-30 19:03:00+03	58400.00
E09296	2017-08-12 00:09:00+03	83300.00
E092D8	2017-07-29 17:31:00+03	22000.00
E09330	2017-07-12 04:58:00+03	6700.00
E09385	2017-07-20 10:18:00+03	115100.00
E0942F	2017-08-04 06:39:00+03	14000.00
E09455	2017-07-29 14:00:00+03	79600.00
E09491	2017-08-13 02:28:00+03	10800.00
E094AA	2017-07-20 08:28:00+03	6000.00
E0954D	2017-07-03 23:23:00+03	108000.00
E0955C	2017-07-24 10:51:00+03	139400.00
E095B7	2017-07-28 00:53:00+03	61800.00
E095C5	2017-08-02 03:57:00+03	62600.00
E095D6	2017-07-12 03:10:00+03	36500.00
E09607	2017-07-23 08:05:00+03	64700.00
E09621	2017-08-08 14:51:00+03	56900.00
E09660	2017-07-21 23:33:00+03	24400.00
E09678	2017-07-23 06:40:00+03	46200.00
E096A6	2017-07-14 22:23:00+03	56700.00
E096B8	2017-07-03 00:00:00+03	15600.00
E096D4	2017-07-21 11:06:00+03	13600.00
E096E2	2017-07-09 13:34:00+03	30000.00
E09731	2017-08-09 21:44:00+03	10100.00
E09767	2017-08-09 00:41:00+03	35400.00
E097E7	2017-07-30 03:40:00+03	55800.00
E0981F	2017-07-10 01:26:00+03	105000.00
E098A9	2017-07-01 13:47:00+03	38200.00
E098B4	2017-08-14 15:46:00+03	42800.00
E098EE	2017-08-12 08:39:00+03	67600.00
E09945	2017-07-18 03:13:00+03	67000.00
E09948	2017-07-13 17:04:00+03	16400.00
E0994A	2017-08-13 03:02:00+03	25600.00
E099B2	2017-07-14 15:04:00+03	23600.00
E09A19	2017-07-30 13:49:00+03	7200.00
E09A74	2017-07-04 01:26:00+03	145300.00
E09A95	2017-07-31 11:14:00+03	65400.00
E09AF6	2017-08-09 09:31:00+03	55000.00
E09B23	2017-07-05 21:25:00+03	92800.00
E09B7E	2017-07-09 21:56:00+03	124200.00
E09B85	2017-08-14 00:11:00+03	57300.00
E09BA1	2017-07-10 00:44:00+03	23600.00
E09BF8	2017-07-04 20:09:00+03	86800.00
E09C0B	2017-07-27 13:43:00+03	39200.00
E09C9E	2017-07-08 22:27:00+03	46000.00
E09D01	2017-08-05 01:39:00+03	105400.00
E09D07	2017-08-09 07:24:00+03	114900.00
E09D1D	2017-07-09 15:14:00+03	239100.00
E09D3C	2017-07-10 17:05:00+03	124200.00
E09D62	2017-07-26 20:31:00+03	42800.00
E09D99	2017-08-13 00:32:00+03	46300.00
E09D9E	2017-08-06 19:27:00+03	14400.00
E09EA2	2017-07-29 05:59:00+03	39600.00
E09EAB	2017-07-01 10:12:00+03	70100.00
E09EFC	2017-07-31 07:45:00+03	39800.00
E09F15	2017-08-04 15:56:00+03	75600.00
E09F18	2017-08-15 16:29:00+03	85000.00
E09F49	2017-08-01 19:49:00+03	31400.00
E09F5D	2017-07-18 18:29:00+03	118200.00
E09F78	2017-07-17 11:19:00+03	35800.00
E09FA2	2017-08-15 11:08:00+03	60000.00
E09FAD	2017-08-01 13:03:00+03	148900.00
E0A000	2017-07-24 22:43:00+03	57800.00
E0A035	2017-08-14 21:59:00+03	85400.00
E0A0A1	2017-08-04 16:48:00+03	123000.00
E0A0A8	2017-08-09 13:25:00+03	37900.00
E0A132	2017-07-02 19:01:00+03	100200.00
E0A145	2017-07-14 19:36:00+03	36500.00
E0A167	2017-08-12 16:37:00+03	98800.00
E0A176	2017-07-01 21:18:00+03	13600.00
E0A17D	2017-07-12 08:08:00+03	41600.00
E0A1A3	2017-08-10 19:27:00+03	15800.00
E0A251	2017-07-29 17:46:00+03	55600.00
E0A255	2017-07-27 02:28:00+03	55600.00
E0A27D	2017-07-10 18:40:00+03	13200.00
E0A28D	2017-07-11 01:39:00+03	32700.00
E0A2BB	2017-07-12 10:09:00+03	39200.00
E0A2C5	2017-07-04 22:10:00+03	29600.00
E0A2D3	2017-07-20 03:30:00+03	34100.00
E0A2F0	2017-08-05 20:30:00+03	24800.00
E0A2F3	2017-07-26 12:22:00+03	30900.00
E0A314	2017-08-12 00:35:00+03	43100.00
E0A341	2017-07-27 02:02:00+03	43200.00
E0A39A	2017-07-23 03:23:00+03	114100.00
E0A3D6	2017-07-03 17:19:00+03	73600.00
E0A3E4	2017-08-03 20:16:00+03	51900.00
E0A43D	2017-08-03 21:45:00+03	76600.00
E0A457	2017-06-25 23:11:00+03	13000.00
E0A473	2017-07-01 15:46:00+03	38800.00
E0A4A5	2017-07-22 00:37:00+03	28000.00
E0A4AD	2017-08-14 00:33:00+03	40100.00
E0A55E	2017-07-31 21:30:00+03	44700.00
E0A560	2017-07-04 18:32:00+03	26200.00
E0A5A1	2017-08-12 17:31:00+03	55800.00
E0A600	2017-08-06 09:22:00+03	91500.00
E0A64A	2017-08-11 11:45:00+03	68800.00
E0A683	2017-07-15 17:12:00+03	271400.00
E0A6E2	2017-07-01 06:23:00+03	125600.00
E0A6EF	2017-07-23 09:36:00+03	16400.00
E0A71A	2017-08-06 04:08:00+03	75300.00
E0A7D9	2017-08-04 01:44:00+03	77500.00
E0A7E7	2017-07-03 09:47:00+03	57800.00
E0A80C	2017-07-21 02:04:00+03	37600.00
E0A860	2017-07-19 22:22:00+03	40800.00
E0A8CE	2017-06-29 11:32:00+03	64500.00
E0A936	2017-07-21 00:53:00+03	32700.00
E0A99D	2017-07-20 16:05:00+03	135400.00
E0A9D2	2017-07-31 04:04:00+03	56000.00
E0A9DA	2017-07-23 02:19:00+03	26000.00
E0A9DC	2017-08-01 23:34:00+03	53600.00
E0AAAD	2017-08-13 09:25:00+03	135400.00
E0AAC0	2017-07-14 06:08:00+03	47600.00
E0AACA	2017-07-26 20:12:00+03	34000.00
E0AB37	2017-07-12 03:08:00+03	27200.00
E0ABF6	2017-07-26 22:04:00+03	44000.00
E0AC4A	2017-07-03 15:21:00+03	12000.00
E0ACCC	2017-06-26 23:09:00+03	54100.00
E0AD10	2017-07-27 15:34:00+03	125600.00
E0AD17	2017-08-14 02:06:00+03	6000.00
E0AD25	2017-08-02 14:57:00+03	154500.00
E0AD5F	2017-07-11 19:49:00+03	119700.00
E0AD67	2017-08-01 12:34:00+03	61800.00
E0AD91	2017-08-11 02:15:00+03	23200.00
E0ADC9	2017-08-12 14:31:00+03	87900.00
E0AE52	2017-07-26 02:54:00+03	116400.00
E0AEAF	2017-08-02 23:13:00+03	56600.00
E0AEF8	2017-08-09 08:07:00+03	58000.00
E0AF0D	2017-06-30 18:05:00+03	28800.00
E0AF47	2017-07-19 01:46:00+03	93900.00
E0AF4C	2017-07-24 12:55:00+03	49900.00
E0AF6E	2017-07-14 14:14:00+03	25800.00
E0AF87	2017-07-30 01:27:00+03	123000.00
E0AF9C	2017-07-07 12:21:00+03	103900.00
E0AFD0	2017-07-08 12:55:00+03	121400.00
E0AFD3	2017-08-01 06:15:00+03	35500.00
E0B007	2017-07-22 14:52:00+03	37700.00
E0B042	2017-07-11 10:03:00+03	6000.00
E0B084	2017-08-08 15:33:00+03	27200.00
E0B098	2017-08-08 01:58:00+03	43900.00
E0B0B1	2017-07-23 13:50:00+03	124200.00
E0B0E7	2017-08-10 17:30:00+03	26000.00
E0B156	2017-08-01 03:53:00+03	14400.00
E0B15D	2017-07-02 01:48:00+03	28000.00
E0B163	2017-08-03 00:46:00+03	78200.00
E0B17D	2017-07-03 08:10:00+03	41800.00
E0B1D1	2017-07-21 19:23:00+03	89700.00
E0B277	2017-08-14 10:45:00+03	240500.00
E0B27B	2017-06-29 22:47:00+03	168000.00
E0B27D	2017-07-29 04:51:00+03	114800.00
E0B2D4	2017-07-21 23:23:00+03	119600.00
E0B322	2017-07-03 02:26:00+03	123000.00
E0B3B0	2017-07-16 13:15:00+03	11300.00
E0B3E0	2017-08-13 23:05:00+03	98400.00
E0B434	2017-08-10 03:24:00+03	20200.00
E0B447	2017-07-18 06:02:00+03	258400.00
E0B536	2017-08-11 05:35:00+03	123000.00
E0B5C6	2017-07-30 03:11:00+03	88600.00
E0B5E3	2017-07-22 09:49:00+03	77200.00
E0B5F7	2017-07-03 18:36:00+03	283100.00
E0B602	2017-08-06 04:46:00+03	65900.00
E0B611	2017-07-14 07:53:00+03	39200.00
E0B61E	2017-07-30 07:58:00+03	16400.00
E0B64E	2017-07-17 02:10:00+03	105100.00
E0B674	2017-07-17 10:11:00+03	28000.00
E0B77A	2017-07-01 01:27:00+03	14400.00
E0B7E6	2017-07-04 18:27:00+03	23200.00
E0B889	2017-06-29 00:44:00+03	47500.00
E0B893	2017-08-07 01:11:00+03	46800.00
E0B8A5	2017-07-05 01:54:00+03	369000.00
E0B8BC	2017-08-02 15:37:00+03	57600.00
E0B8C5	2017-07-12 21:06:00+03	22000.00
E0B8DC	2017-08-13 07:18:00+03	21400.00
E0B913	2017-07-28 07:42:00+03	27800.00
E0B95F	2017-07-23 19:23:00+03	89200.00
E0B9F3	2017-07-20 05:38:00+03	49100.00
E0BAAD	2017-08-07 20:41:00+03	78300.00
E0BAAE	2017-07-04 15:29:00+03	48800.00
E0BAE8	2017-08-11 11:12:00+03	23200.00
E0BAFF	2017-07-20 05:53:00+03	79600.00
E0BB01	2017-08-06 06:33:00+03	55800.00
E0BB20	2017-07-29 05:23:00+03	9200.00
E0BB75	2017-07-31 14:36:00+03	36200.00
E0BB89	2017-07-15 09:32:00+03	22600.00
E0BB9E	2017-07-18 06:33:00+03	22000.00
E0BBBC	2017-06-29 19:36:00+03	23600.00
E0BBE9	2017-07-10 07:23:00+03	24400.00
E0BC28	2017-07-04 08:19:00+03	68800.00
E0BC8A	2017-08-01 11:10:00+03	16400.00
E0BCB4	2017-07-09 12:35:00+03	20800.00
E0BD28	2017-07-04 10:38:00+03	266400.00
E0BD64	2017-07-06 00:02:00+03	69900.00
E0BD8B	2017-08-15 08:33:00+03	75300.00
E0BDBA	2017-07-06 05:49:00+03	19600.00
E0BDC6	2017-08-11 17:24:00+03	58600.00
E0BE5B	2017-08-14 05:55:00+03	24400.00
E0BE79	2017-07-22 20:06:00+03	21800.00
E0BEB6	2017-08-15 09:14:00+03	175400.00
E0BECF	2017-07-20 08:11:00+03	103200.00
E0BF73	2017-08-01 18:58:00+03	84800.00
E0BFB4	2017-07-15 17:17:00+03	38600.00
E0BFED	2017-07-17 16:20:00+03	99800.00
E0BFFB	2017-07-07 18:25:00+03	13200.00
E0C010	2017-07-03 17:02:00+03	28400.00
E0C047	2017-07-09 20:00:00+03	99200.00
E0C054	2017-07-05 09:22:00+03	32700.00
E0C0C1	2017-07-26 07:29:00+03	64600.00
E0C0F2	2017-08-11 00:12:00+03	124200.00
E0C104	2017-08-14 00:37:00+03	25200.00
E0C119	2017-07-25 05:19:00+03	318200.00
E0C127	2017-08-14 09:56:00+03	41800.00
E0C148	2017-08-13 10:23:00+03	39200.00
E0C1B8	2017-07-25 02:06:00+03	34000.00
E0C1CA	2017-07-30 20:21:00+03	114700.00
E0C1F1	2017-08-07 03:02:00+03	75300.00
E0C23A	2017-08-13 11:20:00+03	92400.00
E0C2A3	2017-08-07 10:45:00+03	86500.00
E0C2D5	2017-08-07 23:23:00+03	12200.00
E0C2FC	2017-07-13 16:42:00+03	31400.00
E0C36B	2017-07-22 02:51:00+03	38500.00
E0C380	2017-08-12 14:06:00+03	314400.00
E0C39F	2017-07-06 08:10:00+03	22100.00
E0C3B7	2017-07-11 04:55:00+03	241300.00
E0C3DA	2017-07-11 06:59:00+03	52800.00
E0C3DD	2017-07-14 07:43:00+03	54900.00
E0C3EC	2017-08-13 02:05:00+03	269400.00
E0C437	2017-07-16 19:19:00+03	79600.00
E0C44E	2017-08-10 06:24:00+03	93900.00
E0C478	2017-08-15 06:18:00+03	11800.00
E0C4C8	2017-07-12 01:13:00+03	48700.00
E0C4E8	2017-07-03 15:55:00+03	182300.00
E0C51D	2017-08-08 17:07:00+03	96900.00
E0C5A4	2017-08-05 19:31:00+03	141000.00
E0C5BF	2017-07-28 20:31:00+03	28000.00
E0C618	2017-07-09 04:22:00+03	82900.00
E0C663	2017-07-28 14:22:00+03	23200.00
E0C699	2017-07-06 05:52:00+03	15000.00
E0C6CE	2017-07-15 02:11:00+03	81700.00
E0C6F9	2017-07-24 14:45:00+03	86300.00
E0C6FC	2017-07-17 12:48:00+03	66000.00
E0C70F	2017-07-05 10:52:00+03	47100.00
E0C7AE	2017-07-20 08:59:00+03	26600.00
E0C7E9	2017-07-31 02:11:00+03	31400.00
E0C7FF	2017-07-15 03:48:00+03	11800.00
E0C802	2017-07-10 03:57:00+03	202500.00
E0C807	2017-07-06 02:21:00+03	147100.00
E0C80F	2017-07-05 07:07:00+03	44800.00
E0C829	2017-08-01 15:14:00+03	124200.00
E0C830	2017-07-07 01:23:00+03	42800.00
E0C85A	2017-08-05 09:23:00+03	56000.00
E0C85E	2017-08-08 12:58:00+03	169900.00
E0C9FB	2017-07-09 12:24:00+03	62000.00
E0CA00	2017-07-25 14:31:00+03	57800.00
E0CA07	2017-07-03 09:09:00+03	89700.00
E0CA20	2017-08-03 15:27:00+03	40800.00
E0CA70	2017-07-07 19:12:00+03	29800.00
E0CA85	2017-08-06 07:51:00+03	28800.00
E0CBCF	2017-08-03 00:27:00+03	6700.00
E0CBF4	2017-07-28 14:57:00+03	80800.00
E0CC23	2017-07-12 23:32:00+03	28800.00
E0CC2C	2017-07-16 12:18:00+03	93900.00
E0CC3D	2017-08-09 01:51:00+03	68000.00
E0CC80	2017-07-10 04:37:00+03	28800.00
E0CCC2	2017-07-28 05:16:00+03	134000.00
E0CCD8	2017-07-26 06:45:00+03	13600.00
E0CD0C	2017-08-04 04:36:00+03	205400.00
E0CDCC	2017-07-01 11:59:00+03	167500.00
E0CDFC	2017-08-10 01:37:00+03	64700.00
E0CE13	2017-08-13 22:56:00+03	142800.00
E0CE2A	2017-07-31 09:02:00+03	154500.00
E0CE51	2017-07-13 00:55:00+03	47400.00
E0CE99	2017-07-26 05:36:00+03	28800.00
E0CEA0	2017-08-06 15:12:00+03	32200.00
E0CF3D	2017-07-14 06:55:00+03	280000.00
E0CF6B	2017-06-25 15:45:00+03	121400.00
E0CFA1	2017-07-20 03:25:00+03	16400.00
E0CFED	2017-08-02 02:09:00+03	223200.00
E0D001	2017-07-19 02:13:00+03	60800.00
E0D011	2017-08-07 02:37:00+03	175400.00
E0D022	2017-07-23 21:25:00+03	133200.00
E0D040	2017-07-26 14:14:00+03	32700.00
E0D10A	2017-07-11 08:26:00+03	28800.00
E0D125	2017-07-29 02:43:00+03	36600.00
E0D157	2017-08-14 05:19:00+03	207200.00
E0D186	2017-07-07 08:47:00+03	7200.00
E0D201	2017-07-25 11:53:00+03	73500.00
E0D24D	2017-08-08 04:38:00+03	21800.00
E0D299	2017-08-10 06:49:00+03	75600.00
E0D2D7	2017-07-07 21:41:00+03	40000.00
E0D321	2017-07-02 16:20:00+03	111900.00
E0D322	2017-08-03 10:00:00+03	24700.00
E0D33E	2017-07-26 09:52:00+03	44000.00
E0D35C	2017-07-18 19:44:00+03	23900.00
E0D379	2017-08-06 01:51:00+03	28700.00
E0D3D0	2017-07-27 08:21:00+03	25400.00
E0D467	2017-07-10 12:58:00+03	42000.00
E0D482	2017-08-13 10:42:00+03	41200.00
E0D489	2017-07-06 06:01:00+03	90000.00
E0D48C	2017-07-06 05:31:00+03	59000.00
E0D4BF	2017-07-08 18:07:00+03	36200.00
E0D4F6	2017-08-06 22:12:00+03	193900.00
E0D4FC	2017-07-04 12:26:00+03	21200.00
E0D500	2017-08-11 14:21:00+03	21800.00
E0D536	2017-07-07 01:05:00+03	17000.00
E0D571	2017-07-02 07:21:00+03	270700.00
E0D58E	2017-07-25 20:08:00+03	135400.00
E0D5BE	2017-08-01 08:33:00+03	666000.00
E0D5D6	2017-08-15 08:40:00+03	56000.00
E0D5FE	2017-08-13 08:23:00+03	56000.00
E0D62D	2017-08-15 10:10:00+03	18100.00
E0D649	2017-08-08 20:41:00+03	6700.00
E0D655	2017-08-12 05:04:00+03	29400.00
E0D6B5	2017-08-08 21:49:00+03	63200.00
E0D6FF	2017-08-01 07:17:00+03	42700.00
E0D74E	2017-07-11 01:10:00+03	106100.00
E0D755	2017-07-15 04:45:00+03	14000.00
E0D786	2017-07-20 12:00:00+03	46800.00
E0D798	2017-07-18 10:05:00+03	54500.00
E0D79B	2017-08-01 03:44:00+03	30400.00
E0D7A8	2017-07-12 22:25:00+03	131100.00
E0D7DC	2017-08-11 13:27:00+03	202600.00
E0D813	2017-06-30 19:32:00+03	16400.00
E0D842	2017-07-14 16:42:00+03	85000.00
E0D8C2	2017-07-20 20:02:00+03	23200.00
E0D8F0	2017-08-05 20:41:00+03	55800.00
E0D8F8	2017-07-07 21:39:00+03	54800.00
E0D926	2017-08-04 07:37:00+03	73000.00
E0D977	2017-08-05 03:04:00+03	24400.00
E0D9B7	2017-07-05 14:25:00+03	56100.00
E0D9F2	2017-07-07 06:37:00+03	8200.00
E0DA1B	2017-08-12 09:46:00+03	70600.00
E0DA7C	2017-07-05 13:25:00+03	265700.00
E0DA9D	2017-08-14 08:07:00+03	55800.00
E0DAC7	2017-08-15 11:09:00+03	54800.00
E0DAF5	2017-07-24 19:35:00+03	258400.00
E0DAF8	2017-07-31 07:22:00+03	167400.00
E0DB98	2017-07-06 08:33:00+03	37400.00
E0DC11	2017-08-08 13:16:00+03	46500.00
E0DC19	2017-06-26 04:28:00+03	68400.00
E0DC25	2017-08-09 04:07:00+03	145300.00
E0DCA1	2017-08-03 01:45:00+03	92400.00
E0DCCF	2017-08-14 00:25:00+03	11800.00
E0DD09	2017-07-07 00:02:00+03	14600.00
E0DD59	2017-08-13 12:06:00+03	49500.00
E0DD66	2017-08-04 21:24:00+03	207200.00
E0DDC4	2017-07-01 08:27:00+03	41400.00
E0DE4B	2017-08-07 08:46:00+03	65500.00
E0DE58	2017-07-30 07:59:00+03	116400.00
E0DEDF	2017-08-09 09:59:00+03	57600.00
E0DF55	2017-07-28 04:17:00+03	183100.00
E0DF7F	2017-07-28 16:14:00+03	57400.00
E0DF82	2017-07-10 07:26:00+03	40800.00
E0E00F	2017-07-11 05:48:00+03	112000.00
E0E0A8	2017-07-09 23:42:00+03	21800.00
E0E0B8	2017-07-09 06:01:00+03	135400.00
E0E173	2017-07-22 05:46:00+03	68800.00
E0E187	2017-07-03 22:34:00+03	27200.00
E0E1F4	2017-07-05 19:40:00+03	21800.00
E0E216	2017-07-17 00:13:00+03	7400.00
E0E222	2017-07-31 00:48:00+03	136500.00
E0E237	2017-08-13 16:02:00+03	8000.00
E0E23E	2017-07-17 23:32:00+03	36200.00
E0E2ED	2017-07-18 21:47:00+03	18900.00
E0E2EF	2017-07-27 23:27:00+03	63200.00
E0E2FD	2017-07-13 01:37:00+03	6700.00
E0E360	2017-07-08 02:06:00+03	22000.00
E0E3AB	2017-08-09 18:02:00+03	69600.00
E0E3C0	2017-08-12 06:17:00+03	116400.00
E0E3CB	2017-07-18 05:09:00+03	56600.00
E0E3F8	2017-07-27 22:18:00+03	19600.00
E0E46C	2017-07-01 18:57:00+03	47200.00
E0E4B7	2017-07-05 16:26:00+03	19100.00
E0E4BB	2017-07-02 18:32:00+03	52000.00
E0E544	2017-07-17 19:14:00+03	25600.00
E0E54A	2017-08-02 08:20:00+03	166000.00
E0E60E	2017-07-19 11:52:00+03	51300.00
E0E699	2017-07-03 09:48:00+03	136500.00
E0E6AF	2017-07-10 07:36:00+03	191000.00
E0E6D3	2017-07-31 23:59:00+03	57400.00
E0E765	2017-07-25 09:18:00+03	88000.00
E0E79C	2017-07-24 03:40:00+03	270800.00
E0E7A2	2017-07-18 01:19:00+03	123000.00
E0E7F4	2017-07-03 03:33:00+03	48400.00
E0E84D	2017-07-05 13:35:00+03	21400.00
E0E868	2017-07-16 02:59:00+03	95700.00
E0E86E	2017-08-14 05:57:00+03	26200.00
E0E877	2017-08-11 08:04:00+03	24000.00
E0E89E	2017-07-05 17:58:00+03	25800.00
E0E8C9	2017-07-19 04:51:00+03	200500.00
E0E8F5	2017-07-24 02:58:00+03	33800.00
E0E905	2017-07-02 07:01:00+03	100200.00
E0E915	2017-08-09 16:37:00+03	538000.00
E0E91E	2017-07-28 00:49:00+03	42000.00
E0E9E1	2017-07-09 03:01:00+03	81300.00
E0EAF5	2017-07-28 09:16:00+03	101200.00
E0EB05	2017-07-12 07:22:00+03	56900.00
E0EBA7	2017-08-15 12:37:00+03	257500.00
E0EBB1	2017-08-11 17:11:00+03	151200.00
E0EBE4	2017-07-24 08:36:00+03	129200.00
E0EC06	2017-07-14 22:43:00+03	58800.00
E0EC20	2017-07-14 22:11:00+03	236900.00
E0EC68	2017-08-13 01:53:00+03	36000.00
E0ECBA	2017-07-11 08:52:00+03	31000.00
E0ED13	2017-07-13 12:55:00+03	75600.00
E0ED57	2017-07-06 22:41:00+03	29400.00
E0ED8F	2017-08-12 16:09:00+03	14700.00
E0EEF7	2017-08-03 14:45:00+03	108500.00
E0EF4C	2017-08-04 23:15:00+03	136200.00
E0EF7F	2017-07-22 12:26:00+03	61600.00
E0EFB1	2017-07-26 06:12:00+03	12000.00
E0EFDA	2017-07-12 11:48:00+03	12000.00
E0EFE3	2017-07-30 10:22:00+03	7400.00
E0F17A	2017-07-21 11:10:00+03	136200.00
E0F189	2017-08-02 08:45:00+03	29200.00
E0F1FC	2017-07-13 05:48:00+03	130400.00
E0F29A	2017-08-09 00:11:00+03	65500.00
E0F2A4	2017-07-10 04:06:00+03	205200.00
E0F2E3	2017-07-12 16:46:00+03	75300.00
E0F301	2017-07-26 21:26:00+03	52000.00
E0F34C	2017-07-07 06:47:00+03	18600.00
E0F382	2017-07-10 21:01:00+03	49600.00
E0F3BF	2017-07-27 04:33:00+03	369000.00
E0F3C6	2017-07-07 23:59:00+03	46400.00
E0F3ED	2017-07-19 02:32:00+03	62600.00
E0F415	2017-07-20 07:09:00+03	21600.00
E0F41E	2017-08-06 09:32:00+03	33100.00
E0F421	2017-07-09 03:46:00+03	96800.00
E0F422	2017-07-10 12:45:00+03	28800.00
E0F467	2017-08-10 02:05:00+03	81700.00
E0F509	2017-07-19 15:26:00+03	47100.00
E0F5B0	2017-07-12 00:36:00+03	73600.00
E0F5D5	2017-08-06 20:08:00+03	79600.00
E0F5D6	2017-07-31 06:20:00+03	46400.00
E0F629	2017-08-15 08:19:00+03	47900.00
E0F659	2017-06-29 06:09:00+03	50800.00
E0F65A	2017-08-05 16:38:00+03	24000.00
E0F6A9	2017-08-04 20:34:00+03	43900.00
E0F6BD	2017-08-02 05:54:00+03	54300.00
E0F6F5	2017-07-15 11:44:00+03	16800.00
E0F712	2017-07-16 03:59:00+03	13600.00
E0F71A	2017-07-01 23:55:00+03	30200.00
E0F753	2017-08-04 03:50:00+03	185500.00
E0F7A7	2017-08-06 11:29:00+03	189200.00
E0F7B2	2017-07-13 11:47:00+03	172800.00
E0F7E2	2017-07-15 02:09:00+03	31600.00
E0F82A	2017-07-15 02:39:00+03	59900.00
E0F83C	2017-07-01 23:13:00+03	33100.00
E0F842	2017-07-22 19:20:00+03	46400.00
E0F8B1	2017-07-06 00:01:00+03	19600.00
E0F8D3	2017-08-04 03:18:00+03	98000.00
E0F9AE	2017-07-14 10:10:00+03	113200.00
E0FA01	2017-07-28 12:39:00+03	6700.00
E0FA09	2017-08-12 00:19:00+03	50000.00
E0FA30	2017-07-04 07:10:00+03	51900.00
E0FADC	2017-07-23 10:43:00+03	12400.00
E0FB2D	2017-08-10 06:10:00+03	105100.00
E0FB3C	2017-08-09 13:30:00+03	43500.00
E0FB46	2017-07-29 16:38:00+03	20200.00
E0FB89	2017-07-27 13:09:00+03	116900.00
E0FC0C	2017-07-19 04:04:00+03	25600.00
E0FC7E	2017-08-14 16:14:00+03	57500.00
E0FCAB	2017-07-12 02:12:00+03	52000.00
E0FCE6	2017-07-09 10:38:00+03	23200.00
E0FDEF	2017-08-03 22:37:00+03	202900.00
E0FE65	2017-07-16 20:13:00+03	13400.00
E0FE89	2017-07-17 03:02:00+03	28800.00
E0FEE0	2017-07-15 04:33:00+03	25900.00
E0FEE9	2017-07-27 14:16:00+03	37900.00
E0FF37	2017-07-15 04:56:00+03	33300.00
E0FF51	2017-08-05 06:23:00+03	27200.00
E0FFC4	2017-08-01 23:09:00+03	25600.00
E0FFDB	2017-07-28 18:52:00+03	73000.00
E100A4	2017-07-11 16:35:00+03	77200.00
E100E4	2017-06-30 15:33:00+03	52000.00
E100EE	2017-07-27 13:35:00+03	192300.00
E10144	2017-07-10 20:25:00+03	88400.00
E10159	2017-08-02 14:34:00+03	157300.00
E10208	2017-06-30 23:07:00+03	272400.00
E10221	2017-07-29 04:37:00+03	66600.00
E1023A	2017-08-13 08:49:00+03	47400.00
E10247	2017-08-11 13:40:00+03	28000.00
E1024A	2017-07-31 12:38:00+03	58800.00
E10266	2017-07-20 22:46:00+03	73500.00
E102A4	2017-07-26 09:08:00+03	120000.00
E1031D	2017-08-10 17:46:00+03	88800.00
E1034F	2017-07-22 16:06:00+03	123000.00
E103D9	2017-08-13 22:56:00+03	65500.00
E103F0	2017-07-20 20:57:00+03	88600.00
E103F5	2017-07-19 03:39:00+03	12600.00
E104C8	2017-06-29 00:54:00+03	42400.00
E104FE	2017-07-20 15:42:00+03	28400.00
E1056C	2017-07-03 04:45:00+03	84500.00
E10670	2017-07-14 16:05:00+03	52700.00
E1070A	2017-07-12 15:27:00+03	78000.00
E1070E	2017-06-29 13:02:00+03	128800.00
E10724	2017-08-01 10:19:00+03	90400.00
E107A7	2017-07-23 04:13:00+03	31000.00
E107EA	2017-07-08 18:19:00+03	13400.00
E1080E	2017-07-10 10:45:00+03	121800.00
E10879	2017-08-06 05:36:00+03	83700.00
E1089A	2017-07-16 20:37:00+03	171100.00
E108D1	2017-08-12 20:03:00+03	23200.00
E1098E	2017-07-22 18:48:00+03	112000.00
E109C7	2017-07-04 05:44:00+03	36200.00
E10A18	2017-07-18 02:12:00+03	8400.00
E10A77	2017-07-09 19:12:00+03	81300.00
E10ABE	2017-07-02 16:42:00+03	16300.00
E10BB0	2017-07-21 07:21:00+03	38500.00
E10BBE	2017-07-09 20:58:00+03	174300.00
E10C65	2017-06-30 19:03:00+03	133200.00
E10D46	2017-07-10 10:41:00+03	37100.00
E10DB5	2017-08-03 10:05:00+03	34700.00
E10DBC	2017-07-05 09:55:00+03	35300.00
E10E21	2017-08-14 03:43:00+03	92600.00
E10E2F	2017-08-08 00:12:00+03	17800.00
E10E9A	2017-07-09 20:03:00+03	23600.00
E10EB3	2017-08-14 08:08:00+03	6300.00
E10EBD	2017-07-20 16:43:00+03	136000.00
E10EF6	2017-08-06 23:11:00+03	16400.00
E10F20	2017-07-30 14:11:00+03	54500.00
E10F4A	2017-07-13 20:32:00+03	123000.00
E10F65	2017-08-03 18:39:00+03	21800.00
E10F72	2017-08-11 07:00:00+03	135200.00
E10F77	2017-07-19 00:38:00+03	100600.00
E10FD4	2017-07-03 19:11:00+03	372500.00
E10FE5	2017-07-11 02:44:00+03	54100.00
E11074	2017-08-05 22:14:00+03	26200.00
E110C1	2017-08-05 09:52:00+03	67200.00
E11100	2017-07-29 00:45:00+03	116000.00
E111E9	2017-07-08 01:29:00+03	273400.00
E11212	2017-07-12 19:18:00+03	73300.00
E11268	2017-07-07 14:51:00+03	123000.00
E112BC	2017-07-28 06:41:00+03	34200.00
E112C3	2017-07-06 02:25:00+03	55800.00
E112DC	2017-07-31 05:16:00+03	76400.00
E112F5	2017-07-01 00:07:00+03	21500.00
E1134E	2017-08-03 18:03:00+03	69100.00
E1135A	2017-07-08 12:38:00+03	111600.00
E1135B	2017-07-18 05:29:00+03	12600.00
E113B3	2017-07-08 03:29:00+03	187600.00
E113D1	2017-08-10 09:18:00+03	147900.00
E113EA	2017-07-08 22:40:00+03	114300.00
E11459	2017-08-10 18:51:00+03	189200.00
E1148C	2017-07-03 06:20:00+03	79600.00
E1150A	2017-07-24 19:56:00+03	24000.00
E115BB	2017-07-07 20:44:00+03	75600.00
E11697	2017-07-18 05:12:00+03	56000.00
E116A0	2017-07-09 04:33:00+03	25400.00
E116CA	2017-07-13 18:06:00+03	65500.00
E11727	2017-08-04 04:48:00+03	182200.00
E1172D	2017-06-28 03:39:00+03	113300.00
E11730	2017-07-08 08:25:00+03	73300.00
E1173B	2017-08-15 01:01:00+03	213800.00
E11767	2017-08-14 07:42:00+03	114800.00
E117B7	2017-07-30 16:51:00+03	36200.00
E1180A	2017-07-31 15:13:00+03	21600.00
E1182F	2017-07-29 06:17:00+03	29600.00
E1194A	2017-07-05 17:27:00+03	111600.00
E1197B	2017-07-11 20:15:00+03	20700.00
E119FA	2017-07-15 22:14:00+03	194800.00
E11A05	2017-08-06 11:27:00+03	90800.00
E11A0A	2017-07-20 07:21:00+03	25600.00
E11A30	2017-07-27 21:01:00+03	183300.00
E11A70	2017-07-06 18:18:00+03	11300.00
E11A8E	2017-08-01 11:13:00+03	149300.00
E11A91	2017-08-01 18:19:00+03	112000.00
E11A95	2017-07-11 07:55:00+03	65900.00
E11AFE	2017-07-15 04:34:00+03	35600.00
E11B26	2017-08-09 18:07:00+03	156200.00
E11B3E	2017-08-12 12:19:00+03	76800.00
E11BBF	2017-07-06 20:10:00+03	112000.00
E11BD2	2017-06-29 19:52:00+03	79800.00
E11BF2	2017-07-11 18:16:00+03	6000.00
E11BFD	2017-07-02 12:22:00+03	22000.00
E11C30	2017-07-06 07:34:00+03	23400.00
E11CAA	2017-07-22 01:05:00+03	50600.00
E11DCF	2017-08-12 20:15:00+03	56600.00
E11E1D	2017-07-18 23:46:00+03	45200.00
E11EFB	2017-07-23 12:44:00+03	131100.00
E11F16	2017-07-19 04:06:00+03	84100.00
E11F44	2017-07-01 10:32:00+03	89600.00
E11F6C	2017-07-15 11:16:00+03	28800.00
E12008	2017-07-21 05:29:00+03	87200.00
E1202D	2017-07-22 11:04:00+03	83300.00
E120D9	2017-07-11 17:15:00+03	115600.00
E1211E	2017-07-14 00:28:00+03	46000.00
E12191	2017-07-05 02:48:00+03	112000.00
E12194	2017-07-08 23:09:00+03	444000.00
E121F1	2017-08-10 00:41:00+03	57600.00
E1221F	2017-08-03 21:02:00+03	122400.00
E122CB	2017-07-11 10:19:00+03	137600.00
E122EF	2017-06-27 22:07:00+03	32700.00
E12324	2017-07-25 11:41:00+03	55800.00
E12327	2017-08-14 20:50:00+03	48400.00
E12345	2017-07-05 23:02:00+03	13400.00
E1237B	2017-07-20 04:34:00+03	43600.00
E1239B	2017-07-31 07:26:00+03	41800.00
E123C9	2017-07-23 22:06:00+03	34000.00
E123D3	2017-07-08 06:19:00+03	35300.00
E12414	2017-07-09 12:02:00+03	24400.00
E12427	2017-07-07 08:05:00+03	46400.00
E1245E	2017-07-01 16:20:00+03	57600.00
E124F7	2017-07-31 07:11:00+03	193600.00
E1251E	2017-07-25 10:46:00+03	28800.00
E12523	2017-07-14 22:49:00+03	6300.00
E1254E	2017-07-10 03:31:00+03	32800.00
E1257F	2017-07-21 06:37:00+03	29600.00
E125D4	2017-07-08 10:55:00+03	58400.00
E125DF	2017-07-20 12:59:00+03	17800.00
E12603	2017-08-15 06:19:00+03	43900.00
E1268C	2017-08-11 20:25:00+03	129700.00
E12694	2017-07-03 17:34:00+03	6700.00
E126D9	2017-07-08 01:36:00+03	12600.00
E126FF	2017-07-17 20:06:00+03	46400.00
E12771	2017-08-12 16:47:00+03	13400.00
E127DD	2017-08-10 07:32:00+03	157400.00
E127FC	2017-07-20 06:01:00+03	121900.00
E12871	2017-08-14 02:19:00+03	120900.00
E128BE	2017-08-02 07:47:00+03	94900.00
E12923	2017-08-14 23:46:00+03	87000.00
E12982	2017-07-28 07:26:00+03	84100.00
E129AE	2017-07-25 20:32:00+03	21400.00
E12A31	2017-07-31 20:53:00+03	27000.00
E12A55	2017-07-17 10:12:00+03	103900.00
E12A91	2017-07-22 05:45:00+03	16400.00
E12AD6	2017-07-20 13:17:00+03	70200.00
E12B31	2017-07-08 13:15:00+03	82600.00
E12BC8	2017-07-12 19:59:00+03	258400.00
E12BD2	2017-08-08 08:33:00+03	131100.00
E12C3E	2017-07-04 02:40:00+03	55800.00
E12C4B	2017-07-08 03:33:00+03	52900.00
E12C7B	2017-07-26 04:26:00+03	22200.00
E12C8E	2017-07-31 12:52:00+03	73300.00
E12C95	2017-07-03 11:53:00+03	15800.00
E12CA1	2017-08-06 07:27:00+03	62600.00
E12CBA	2017-07-15 08:32:00+03	283100.00
E12CD6	2017-07-22 00:20:00+03	23200.00
E12CE6	2017-08-11 10:39:00+03	43000.00
E12CEA	2017-08-07 23:30:00+03	26700.00
E12D52	2017-07-23 00:22:00+03	51800.00
E12DEC	2017-07-11 02:27:00+03	75600.00
E12E53	2017-07-27 22:03:00+03	40000.00
E12EBD	2017-07-10 04:46:00+03	119500.00
E12F21	2017-07-19 14:40:00+03	65100.00
E12F2C	2017-08-07 10:56:00+03	77600.00
E12F49	2017-07-24 02:02:00+03	86800.00
E12F57	2017-08-11 15:58:00+03	133100.00
E12F5B	2017-07-08 03:57:00+03	75800.00
E12F96	2017-07-05 07:20:00+03	139400.00
E12FFF	2017-07-07 15:59:00+03	37900.00
E1301C	2017-07-04 02:18:00+03	65900.00
E13078	2017-08-08 05:36:00+03	102100.00
E130D0	2017-07-18 01:49:00+03	23200.00
E130EE	2017-08-15 02:02:00+03	12000.00
E130F7	2017-08-15 13:50:00+03	13700.00
E13176	2017-07-06 10:52:00+03	56600.00
E1318F	2017-07-08 11:30:00+03	81300.00
E13397	2017-08-04 06:16:00+03	50100.00
E1339D	2017-07-10 00:24:00+03	18500.00
E133D8	2017-08-10 03:36:00+03	123000.00
E13420	2017-07-27 02:18:00+03	139300.00
E1343D	2017-07-15 11:22:00+03	198400.00
E135BF	2017-07-24 23:20:00+03	31000.00
E13654	2017-08-06 22:57:00+03	47800.00
E1366A	2017-08-02 00:50:00+03	49300.00
E1366E	2017-08-12 00:44:00+03	74900.00
E1367B	2017-07-16 17:27:00+03	60600.00
E1369C	2017-08-15 03:48:00+03	24000.00
E13838	2017-08-08 22:22:00+03	43600.00
E138EB	2017-08-07 13:51:00+03	87200.00
E138FB	2017-07-18 22:35:00+03	37900.00
E13977	2017-07-18 04:13:00+03	90400.00
E139A0	2017-08-13 01:27:00+03	26500.00
E13A4B	2017-08-12 05:34:00+03	84500.00
E13A4C	2017-07-28 14:58:00+03	131600.00
E13AE0	2017-07-18 21:13:00+03	112000.00
E13B4D	2017-07-09 20:35:00+03	95200.00
E13B4E	2017-07-12 00:46:00+03	39900.00
E13BE8	2017-07-05 01:47:00+03	114800.00
E13BF6	2017-07-11 10:45:00+03	40400.00
E13BFC	2017-08-05 00:26:00+03	74900.00
E13C3D	2017-07-22 12:19:00+03	61800.00
E13C50	2017-08-11 22:28:00+03	76600.00
E13C7D	2017-07-08 13:23:00+03	179300.00
E13CEE	2017-07-15 20:27:00+03	85500.00
E13CEF	2017-08-12 20:00:00+03	17800.00
E13D2A	2017-08-11 11:59:00+03	75600.00
E13D6A	2017-08-12 10:51:00+03	38400.00
E13DF6	2017-08-07 00:58:00+03	154100.00
E13E26	2017-07-24 18:23:00+03	112000.00
E13E5D	2017-07-24 12:30:00+03	8600.00
E13E89	2017-07-23 19:11:00+03	33300.00
E13EF2	2017-07-07 18:15:00+03	92000.00
E13EF7	2017-08-06 22:01:00+03	75300.00
E13F1E	2017-07-01 00:15:00+03	67600.00
E14006	2017-07-20 23:20:00+03	66600.00
E14023	2017-08-01 16:02:00+03	184300.00
E140A7	2017-07-03 20:02:00+03	12400.00
E140F4	2017-07-23 09:03:00+03	32400.00
E1410E	2017-07-06 02:28:00+03	12000.00
E14155	2017-08-15 12:19:00+03	26000.00
E14222	2017-07-28 04:15:00+03	39500.00
E142A1	2017-07-28 15:41:00+03	28800.00
E142B2	2017-08-14 06:03:00+03	56900.00
E14374	2017-07-29 20:34:00+03	86400.00
E143BD	2017-06-30 23:34:00+03	66600.00
E143C1	2017-07-07 04:33:00+03	62200.00
E143CC	2017-06-30 06:47:00+03	101200.00
E143EA	2017-08-12 01:52:00+03	6800.00
E143EF	2017-07-06 18:25:00+03	16400.00
E14410	2017-07-09 15:11:00+03	24400.00
E14465	2017-08-08 12:48:00+03	35100.00
E1447F	2017-07-14 07:55:00+03	152900.00
E144DF	2017-08-09 09:10:00+03	81600.00
E1452F	2017-08-15 12:40:00+03	272300.00
E1453F	2017-08-14 01:16:00+03	67100.00
E14556	2017-07-22 08:27:00+03	174300.00
E145C5	2017-07-15 08:13:00+03	32400.00
E145CE	2017-07-31 11:56:00+03	195900.00
E145D8	2017-08-01 01:10:00+03	28000.00
E145DD	2017-06-30 13:41:00+03	64400.00
E14606	2017-08-09 22:51:00+03	213500.00
E14614	2017-08-12 08:19:00+03	21400.00
E14674	2017-07-22 07:50:00+03	166100.00
E14686	2017-07-11 04:29:00+03	62100.00
E14715	2017-07-22 02:40:00+03	25600.00
E14737	2017-08-03 08:01:00+03	77200.00
E1473B	2017-08-09 12:37:00+03	155600.00
E14746	2017-08-05 12:45:00+03	33100.00
E14778	2017-07-18 07:58:00+03	50600.00
E148A0	2017-07-25 07:28:00+03	18600.00
E148B3	2017-07-10 18:34:00+03	55800.00
E148B7	2017-08-07 19:51:00+03	37600.00
E148EE	2017-07-26 05:54:00+03	246000.00
E14905	2017-08-01 01:04:00+03	466800.00
E1491C	2017-08-14 10:10:00+03	30200.00
E149A4	2017-07-04 08:37:00+03	133100.00
E149B7	2017-07-19 21:12:00+03	97900.00
E14A3F	2017-07-04 17:11:00+03	40600.00
E14A63	2017-07-07 23:15:00+03	49600.00
E14ACA	2017-08-05 03:49:00+03	31100.00
E14ADD	2017-08-03 07:27:00+03	26800.00
E14B6B	2017-07-08 00:57:00+03	30900.00
E14B7F	2017-07-06 21:06:00+03	42800.00
E14BE0	2017-07-15 06:07:00+03	39800.00
E14C06	2017-07-22 02:59:00+03	46300.00
E14CCD	2017-07-18 12:42:00+03	95300.00
E14D3D	2017-07-17 10:55:00+03	265600.00
E14D44	2017-08-12 09:56:00+03	8000.00
E14D9D	2017-08-04 04:21:00+03	114800.00
E14DDF	2017-07-17 15:07:00+03	25800.00
E14E91	2017-07-31 15:03:00+03	32800.00
E14EC2	2017-07-22 13:11:00+03	418400.00
E14EC3	2017-07-06 00:14:00+03	21200.00
E14F13	2017-08-12 05:40:00+03	110000.00
E14FA5	2017-07-10 14:38:00+03	77500.00
E15030	2017-08-06 16:19:00+03	40400.00
E15041	2017-07-14 10:08:00+03	10800.00
E15054	2017-07-09 12:08:00+03	26000.00
E15063	2017-07-28 22:25:00+03	99200.00
E15098	2017-07-06 09:28:00+03	20400.00
E15103	2017-08-14 11:41:00+03	6000.00
E1512B	2017-07-20 05:54:00+03	76300.00
E1515C	2017-06-30 12:13:00+03	144000.00
E15169	2017-07-14 22:07:00+03	26400.00
E15188	2017-08-14 07:07:00+03	108000.00
E1518F	2017-08-12 02:27:00+03	135600.00
E151A3	2017-07-30 05:01:00+03	57400.00
E151AC	2017-07-23 19:17:00+03	86400.00
E1521D	2017-07-10 21:16:00+03	43400.00
E15222	2017-08-05 04:11:00+03	399600.00
E15238	2017-07-21 06:09:00+03	108900.00
E15266	2017-07-12 03:11:00+03	29200.00
E1527A	2017-07-24 01:29:00+03	206400.00
E1529E	2017-07-24 23:20:00+03	246000.00
E152A0	2017-07-27 22:53:00+03	55800.00
E15306	2017-08-09 22:11:00+03	126400.00
E15335	2017-08-03 11:12:00+03	123000.00
E1538A	2017-08-03 16:54:00+03	28800.00
E15407	2017-07-03 11:50:00+03	65900.00
E15421	2017-07-01 05:55:00+03	31600.00
E1542A	2017-06-25 09:36:00+03	159100.00
E15468	2017-08-03 12:59:00+03	145200.00
E15469	2017-07-25 03:16:00+03	444000.00
E154D6	2017-07-01 05:24:00+03	12000.00
E15577	2017-08-06 08:09:00+03	28000.00
E1559A	2017-07-12 16:51:00+03	28300.00
E155B5	2017-08-08 07:48:00+03	46000.00
E15629	2017-08-01 22:22:00+03	16400.00
E15659	2017-07-26 06:37:00+03	16400.00
E15698	2017-08-03 04:23:00+03	34400.00
E156A1	2017-08-12 06:31:00+03	56800.00
E15786	2017-07-17 09:41:00+03	63200.00
E15807	2017-07-23 05:24:00+03	235700.00
E15831	2017-08-01 05:58:00+03	189800.00
E15848	2017-07-02 05:29:00+03	79100.00
E1584A	2017-08-09 17:53:00+03	26700.00
E158B5	2017-06-29 05:27:00+03	40800.00
E158E5	2017-08-15 02:22:00+03	25700.00
E158FD	2017-07-25 07:29:00+03	406600.00
E15986	2017-07-07 08:48:00+03	58900.00
E15990	2017-07-29 19:33:00+03	169600.00
E159DB	2017-07-27 02:20:00+03	14000.00
E15A0E	2017-06-30 04:26:00+03	56000.00
E15A73	2017-07-23 03:24:00+03	134400.00
E15A95	2017-08-06 09:52:00+03	27700.00
E15AF2	2017-07-03 05:46:00+03	29400.00
E15BA1	2017-07-19 06:51:00+03	24500.00
E15BB2	2017-07-13 00:47:00+03	123000.00
E15BFE	2017-07-08 11:12:00+03	46200.00
E15C0E	2017-07-24 09:41:00+03	118100.00
E15C43	2017-08-04 00:55:00+03	283300.00
E15D40	2017-08-10 18:33:00+03	28700.00
E15D5F	2017-07-18 01:56:00+03	50000.00
E15D66	2017-08-07 20:56:00+03	24700.00
E15DE5	2017-07-06 05:19:00+03	60400.00
E15DF3	2017-07-10 08:54:00+03	52900.00
E15F34	2017-07-09 11:55:00+03	25400.00
E15F62	2017-08-09 12:17:00+03	125000.00
E15FAB	2017-07-25 22:11:00+03	53400.00
E15FB2	2017-08-03 06:35:00+03	46400.00
E15FC2	2017-08-01 13:45:00+03	16400.00
E15FCD	2017-07-04 21:33:00+03	369000.00
E15FD1	2017-07-31 10:31:00+03	17000.00
E1600F	2017-07-16 22:52:00+03	112000.00
E16010	2017-08-07 11:45:00+03	112000.00
E16042	2017-07-28 06:35:00+03	169900.00
E16064	2017-07-12 20:00:00+03	47200.00
E16092	2017-08-14 03:28:00+03	6700.00
E161A0	2017-08-07 15:14:00+03	59100.00
E161EE	2017-07-18 08:36:00+03	51200.00
E16243	2017-06-28 22:04:00+03	70100.00
E16281	2017-07-07 19:51:00+03	246000.00
E162EC	2017-07-02 06:06:00+03	14800.00
E16307	2017-07-04 02:30:00+03	38800.00
E16343	2017-07-13 08:54:00+03	30200.00
E1634E	2017-08-13 01:17:00+03	14400.00
E16371	2017-07-03 18:59:00+03	73400.00
E1638C	2017-08-07 23:06:00+03	67800.00
E16390	2017-07-16 22:08:00+03	73600.00
E163DC	2017-06-28 21:50:00+03	81300.00
E16419	2017-07-25 19:51:00+03	95600.00
E164E7	2017-08-11 23:00:00+03	40000.00
E16554	2017-08-01 09:50:00+03	6700.00
E16584	2017-07-16 17:28:00+03	67200.00
E165F4	2017-08-02 17:39:00+03	38800.00
E1665E	2017-08-03 16:37:00+03	23200.00
E1666E	2017-06-27 17:45:00+03	18300.00
E1672D	2017-08-05 12:12:00+03	46400.00
E16771	2017-07-30 03:57:00+03	76800.00
E16777	2017-07-20 21:02:00+03	49600.00
E1677F	2017-07-08 10:23:00+03	59200.00
E1678D	2017-07-10 20:18:00+03	111600.00
E16849	2017-07-16 21:32:00+03	28000.00
E1687D	2017-07-19 11:07:00+03	133200.00
E16885	2017-07-31 04:19:00+03	43200.00
E168FB	2017-08-07 18:44:00+03	195000.00
E16975	2017-07-21 00:40:00+03	38100.00
E16977	2017-07-29 15:12:00+03	199800.00
E16978	2017-07-08 21:43:00+03	76600.00
E16A09	2017-06-29 23:02:00+03	54800.00
E16A0A	2017-07-28 05:37:00+03	50400.00
E16A55	2017-07-14 07:55:00+03	64500.00
E16A67	2017-08-14 18:52:00+03	86600.00
E16AD6	2017-07-14 14:48:00+03	43600.00
E16AFD	2017-08-08 18:53:00+03	27700.00
E16B21	2017-07-29 13:41:00+03	75300.00
E16B40	2017-06-27 06:37:00+03	28800.00
E16B47	2017-07-12 20:50:00+03	75600.00
E16B64	2017-07-11 13:30:00+03	117200.00
E16B88	2017-08-13 15:59:00+03	55800.00
E16BA5	2017-07-02 18:27:00+03	114400.00
E16C0E	2017-07-29 01:02:00+03	89600.00
E16C51	2017-07-17 00:13:00+03	432500.00
E16D49	2017-07-31 14:29:00+03	56000.00
E16D7A	2017-08-15 07:03:00+03	37000.00
E16D7C	2017-08-07 10:43:00+03	242100.00
E16D91	2017-07-29 08:16:00+03	67300.00
E16DBA	2017-07-02 19:00:00+03	73600.00
E16DD9	2017-07-17 01:32:00+03	25200.00
E16E9C	2017-08-13 06:35:00+03	562900.00
E16E9E	2017-08-12 08:41:00+03	163600.00
E16F10	2017-07-24 22:02:00+03	106400.00
E16F62	2017-08-10 10:44:00+03	78600.00
E16F6A	2017-08-11 04:13:00+03	59100.00
E16F94	2017-07-18 19:05:00+03	124200.00
E16FA4	2017-07-01 06:01:00+03	15800.00
E17041	2017-07-06 08:26:00+03	56600.00
E17068	2017-07-09 11:23:00+03	62700.00
E17079	2017-07-16 09:50:00+03	128000.00
E17081	2017-07-19 08:48:00+03	32900.00
E17092	2017-07-03 18:46:00+03	214200.00
E170C3	2017-06-29 01:55:00+03	24700.00
E170D1	2017-08-12 07:09:00+03	17200.00
E170D5	2017-08-07 06:22:00+03	29600.00
E17166	2017-07-21 04:38:00+03	133200.00
E171B4	2017-08-15 03:25:00+03	38200.00
E171B5	2017-06-28 02:32:00+03	128800.00
E1722D	2017-07-18 09:31:00+03	27200.00
E17254	2017-07-20 12:45:00+03	246000.00
E1725D	2017-07-20 20:27:00+03	59000.00
E1726F	2017-08-14 10:39:00+03	16400.00
E17286	2017-07-16 06:16:00+03	23400.00
E17318	2017-07-28 23:22:00+03	93900.00
E1733C	2017-08-12 22:25:00+03	66600.00
E17363	2017-07-20 21:02:00+03	75600.00
E1737C	2017-08-02 20:12:00+03	16400.00
E173F9	2017-07-14 22:31:00+03	155600.00
E1740D	2017-07-17 12:38:00+03	188700.00
E1745F	2017-07-10 17:21:00+03	47900.00
E174C4	2017-07-19 00:01:00+03	16400.00
E1750C	2017-07-08 00:24:00+03	46700.00
E175B5	2017-08-12 22:21:00+03	32200.00
E175E6	2017-07-31 14:33:00+03	23200.00
E175E7	2017-07-22 11:26:00+03	45200.00
E17690	2017-08-15 08:23:00+03	36200.00
E176A6	2017-08-04 00:28:00+03	50800.00
E176B4	2017-08-06 07:11:00+03	28200.00
E176F0	2017-08-02 13:55:00+03	150600.00
E176F1	2017-08-10 04:09:00+03	36700.00
E17718	2017-07-03 15:08:00+03	46300.00
E1774B	2017-07-30 23:36:00+03	46300.00
E177D0	2017-08-08 05:39:00+03	28800.00
E177E0	2017-07-24 20:01:00+03	6700.00
E177E8	2017-07-31 19:50:00+03	65100.00
E17817	2017-07-04 01:52:00+03	58000.00
E17818	2017-07-07 04:39:00+03	201200.00
E17854	2017-07-18 12:21:00+03	17800.00
E1786D	2017-07-14 14:58:00+03	7300.00
E178DB	2017-07-14 03:52:00+03	27800.00
E1790F	2017-07-27 15:23:00+03	265600.00
E17912	2017-08-05 07:41:00+03	119000.00
E17918	2017-08-14 02:26:00+03	480600.00
E17923	2017-08-05 14:46:00+03	52000.00
E1794B	2017-07-11 01:51:00+03	161200.00
E1794F	2017-07-23 06:53:00+03	36600.00
E1795E	2017-07-24 17:04:00+03	35200.00
E1798A	2017-08-01 01:25:00+03	156000.00
E17A2F	2017-07-11 07:41:00+03	88000.00
E17A4A	2017-08-02 22:53:00+03	98300.00
E17A72	2017-08-09 11:05:00+03	87000.00
E17AB9	2017-08-03 07:15:00+03	88900.00
E17AC1	2017-08-03 11:34:00+03	61800.00
E17ACB	2017-07-22 04:41:00+03	23200.00
E17C0C	2017-07-28 18:44:00+03	267100.00
E17C2F	2017-07-21 20:21:00+03	49200.00
E17D20	2017-07-06 13:51:00+03	29400.00
E17D7D	2017-07-31 03:03:00+03	28000.00
E17E0A	2017-08-02 21:36:00+03	142400.00
E17E1B	2017-07-16 00:25:00+03	77600.00
E17E2D	2017-07-04 20:46:00+03	36700.00
E17E87	2017-07-14 14:16:00+03	52400.00
E17EA9	2017-08-15 00:34:00+03	71400.00
E17F3C	2017-07-22 21:17:00+03	64800.00
E17F75	2017-08-09 13:11:00+03	21800.00
E17F87	2017-08-14 17:14:00+03	111600.00
E17FD5	2017-07-24 12:25:00+03	99700.00
E1800B	2017-07-27 22:41:00+03	67600.00
E18027	2017-08-12 20:15:00+03	40400.00
E18093	2017-07-10 18:03:00+03	91500.00
E18113	2017-08-05 01:53:00+03	13400.00
E1812A	2017-08-07 01:27:00+03	18600.00
E18131	2017-07-01 20:06:00+03	162200.00
E18165	2017-06-28 02:31:00+03	49200.00
E1816E	2017-07-23 16:45:00+03	86800.00
E18193	2017-07-11 22:27:00+03	88900.00
E181A4	2017-07-15 07:32:00+03	46200.00
E181CD	2017-07-12 13:21:00+03	40800.00
E181FB	2017-07-10 14:21:00+03	23200.00
E18208	2017-07-19 09:09:00+03	103500.00
E182A5	2017-07-12 17:10:00+03	75300.00
E1831B	2017-07-07 08:17:00+03	201200.00
E1832B	2017-07-13 08:03:00+03	56000.00
E1834F	2017-07-25 14:52:00+03	36200.00
E1836A	2017-08-02 10:08:00+03	14900.00
E18475	2017-07-20 19:30:00+03	26800.00
E18487	2017-07-31 13:57:00+03	26800.00
E184ED	2017-07-04 18:31:00+03	28000.00
E18516	2017-08-08 16:47:00+03	67200.00
E1852A	2017-07-28 18:55:00+03	50600.00
E185B3	2017-08-09 04:15:00+03	95200.00
E185C2	2017-07-31 00:37:00+03	13400.00
E1869F	2017-08-03 09:56:00+03	196000.00
E186C2	2017-07-13 00:46:00+03	20200.00
E186DA	2017-07-13 00:36:00+03	18000.00
E186DF	2017-08-04 05:32:00+03	43500.00
E186F6	2017-08-11 16:41:00+03	59600.00
E1870B	2017-08-04 12:37:00+03	57600.00
E1872A	2017-07-31 08:34:00+03	202700.00
E18744	2017-07-11 16:53:00+03	39600.00
E18854	2017-08-03 07:49:00+03	15400.00
E189B5	2017-08-05 20:26:00+03	65200.00
E189DC	2017-07-22 09:19:00+03	94700.00
E18A0B	2017-07-09 05:04:00+03	14000.00
E18A38	2017-08-02 04:28:00+03	28000.00
E18A6E	2017-08-13 19:35:00+03	133200.00
E18AD2	2017-08-09 07:59:00+03	14000.00
E18B0F	2017-08-15 08:38:00+03	128700.00
E18B32	2017-07-13 05:29:00+03	18700.00
E18B9A	2017-07-05 01:26:00+03	6300.00
E18BC4	2017-07-05 03:13:00+03	24300.00
E18BE6	2017-07-29 09:54:00+03	85000.00
E18C24	2017-07-29 06:00:00+03	28000.00
E18CD8	2017-07-31 18:03:00+03	17200.00
E18CE6	2017-07-20 01:58:00+03	27300.00
E18D0B	2017-08-15 00:14:00+03	125800.00
E18D0C	2017-07-08 21:27:00+03	21500.00
E18D53	2017-08-11 04:03:00+03	229000.00
E18DB1	2017-07-30 06:28:00+03	86800.00
E18DDC	2017-07-07 04:20:00+03	61800.00
E18DE4	2017-07-16 08:14:00+03	52100.00
E18E07	2017-07-24 13:57:00+03	98100.00
E18E51	2017-07-26 21:42:00+03	62000.00
E18E70	2017-07-02 11:40:00+03	62700.00
E18E86	2017-07-21 01:43:00+03	68200.00
E18EB2	2017-07-16 03:40:00+03	28800.00
E18EB4	2017-08-05 13:51:00+03	52100.00
E18ED3	2017-08-09 10:01:00+03	10800.00
E18F75	2017-07-20 13:11:00+03	136400.00
E18F88	2017-07-14 23:53:00+03	13600.00
E18FA3	2017-07-23 10:07:00+03	135000.00
E18FD8	2017-07-30 00:37:00+03	73200.00
E18FFF	2017-07-31 16:08:00+03	53700.00
E1902D	2017-07-22 22:45:00+03	58700.00
E190AC	2017-07-27 09:38:00+03	57600.00
E1911B	2017-08-15 14:18:00+03	83700.00
E19130	2017-07-21 19:35:00+03	39200.00
E19187	2017-08-05 14:39:00+03	269400.00
E1918F	2017-08-14 02:56:00+03	26700.00
E19202	2017-08-12 06:56:00+03	13300.00
E1923B	2017-07-11 05:16:00+03	103100.00
E1927E	2017-08-08 12:00:00+03	39800.00
E1930C	2017-08-01 03:14:00+03	98000.00
E19353	2017-07-07 02:06:00+03	32800.00
E193A4	2017-07-11 03:50:00+03	90300.00
E193D5	2017-07-03 15:41:00+03	204500.00
E193E3	2017-07-20 12:45:00+03	26800.00
E194E9	2017-08-09 10:46:00+03	99300.00
E195B4	2017-07-14 10:33:00+03	23900.00
E195C7	2017-07-22 13:38:00+03	270800.00
E195CD	2017-08-10 09:12:00+03	26000.00
E19649	2017-07-07 07:41:00+03	28800.00
E1967F	2017-07-29 22:38:00+03	285000.00
E19683	2017-07-15 20:47:00+03	96800.00
E19692	2017-07-08 16:41:00+03	120600.00
E19708	2017-07-03 13:10:00+03	36200.00
E197DB	2017-08-02 16:58:00+03	10700.00
E197F9	2017-07-25 08:21:00+03	9200.00
E19835	2017-07-21 02:34:00+03	41200.00
E1986D	2017-07-11 09:52:00+03	36200.00
E1999D	2017-08-13 00:44:00+03	23200.00
E19A73	2017-08-10 03:43:00+03	6700.00
E19AF3	2017-08-10 15:52:00+03	28800.00
E19B01	2017-08-11 06:39:00+03	84100.00
E19B1E	2017-08-10 06:20:00+03	73600.00
E19B6F	2017-07-26 12:20:00+03	492000.00
E19B82	2017-08-06 20:39:00+03	34600.00
E19BA5	2017-07-20 18:37:00+03	118200.00
E19C04	2017-08-14 10:43:00+03	75600.00
E19C1F	2017-08-04 11:04:00+03	50800.00
E19C25	2017-08-02 06:20:00+03	11700.00
E19C71	2017-07-01 08:54:00+03	57400.00
E19C85	2017-08-02 22:22:00+03	85700.00
E19E3A	2017-07-18 15:56:00+03	38400.00
E19E4B	2017-08-12 09:06:00+03	173800.00
E19EAA	2017-07-04 15:03:00+03	12600.00
E19EC3	2017-08-13 04:05:00+03	118200.00
E19EE9	2017-07-21 14:37:00+03	61800.00
E19FA8	2017-08-06 09:15:00+03	147100.00
E1A045	2017-07-06 17:05:00+03	34100.00
E1A091	2017-07-15 11:16:00+03	160400.00
E1A0DB	2017-07-09 20:49:00+03	29400.00
E1A0F4	2017-08-06 15:48:00+03	110500.00
E1A102	2017-07-02 21:02:00+03	41200.00
E1A120	2017-07-21 19:21:00+03	12400.00
E1A13E	2017-07-19 01:35:00+03	52400.00
E1A166	2017-07-08 16:20:00+03	25800.00
E1A19B	2017-06-30 01:59:00+03	133200.00
E1A201	2017-08-08 16:24:00+03	149500.00
E1A284	2017-08-05 00:52:00+03	55000.00
E1A337	2017-07-12 08:19:00+03	7400.00
E1A36A	2017-08-07 13:37:00+03	119300.00
E1A3B8	2017-07-15 18:15:00+03	36200.00
E1A51C	2017-07-28 05:46:00+03	459900.00
E1A522	2017-07-14 23:43:00+03	88100.00
E1A540	2017-07-23 00:20:00+03	13600.00
E1A546	2017-07-11 18:52:00+03	399600.00
E1A5E2	2017-08-12 10:50:00+03	63500.00
E1A5FB	2017-07-04 06:18:00+03	25600.00
E1A5FE	2017-07-24 06:44:00+03	179400.00
E1A680	2017-08-06 20:30:00+03	99300.00
E1A690	2017-08-07 17:34:00+03	109600.00
E1A6F8	2017-07-09 22:15:00+03	133200.00
E1A726	2017-08-12 00:12:00+03	57600.00
E1A727	2017-07-14 23:15:00+03	40000.00
E1A74D	2017-07-08 05:23:00+03	262200.00
E1A7C3	2017-07-04 17:20:00+03	19600.00
E1A82B	2017-07-21 13:08:00+03	137400.00
E1A8DF	2017-06-30 04:40:00+03	46400.00
E1A8F0	2017-07-13 17:37:00+03	36200.00
E1A900	2017-08-06 21:31:00+03	203300.00
E1A93E	2017-07-14 15:20:00+03	73900.00
E1A9CD	2017-07-28 22:56:00+03	6000.00
E1A9DD	2017-08-02 09:31:00+03	29500.00
E1A9EA	2017-07-10 16:55:00+03	10800.00
E1AA85	2017-07-07 23:23:00+03	136800.00
E1AA8C	2017-07-19 05:33:00+03	145300.00
E1AAB5	2017-07-12 14:41:00+03	54400.00
E1AAD1	2017-08-13 14:05:00+03	229400.00
E1AB28	2017-08-06 00:11:00+03	131100.00
E1AB68	2017-08-08 04:07:00+03	47000.00
E1ABAF	2017-07-27 08:56:00+03	15000.00
E1ABB5	2017-07-12 13:16:00+03	248300.00
E1ABC9	2017-07-05 05:22:00+03	421100.00
E1ABD4	2017-08-04 06:27:00+03	18000.00
E1AC02	2017-08-05 09:01:00+03	47000.00
E1AC88	2017-08-13 18:01:00+03	246000.00
E1AD4D	2017-07-25 07:19:00+03	40800.00
E1AD7B	2017-07-18 19:37:00+03	52900.00
E1ADB2	2017-08-13 18:21:00+03	114700.00
E1AE09	2017-07-20 13:56:00+03	60600.00
E1AE68	2017-07-06 11:50:00+03	57600.00
E1AE8A	2017-07-28 10:01:00+03	28000.00
E1AEC7	2017-07-18 21:15:00+03	46500.00
E1AF25	2017-07-29 03:56:00+03	26500.00
E1AF2A	2017-08-03 06:19:00+03	38200.00
E1AF7E	2017-08-14 07:46:00+03	49500.00
E1AF9D	2017-08-02 22:30:00+03	78600.00
E1AFE8	2017-08-07 21:54:00+03	422900.00
E1B061	2017-07-05 23:44:00+03	69500.00
E1B0AD	2017-08-13 07:06:00+03	136200.00
E1B0E6	2017-08-15 09:34:00+03	24000.00
E1B10F	2017-07-26 13:27:00+03	151200.00
E1B129	2017-07-12 02:59:00+03	224000.00
E1B155	2017-07-22 23:54:00+03	28000.00
E1B174	2017-08-01 02:23:00+03	73200.00
E1B237	2017-07-09 03:01:00+03	28000.00
E1B2BB	2017-07-22 23:47:00+03	83000.00
E1B2CB	2017-07-11 10:55:00+03	31600.00
E1B2D9	2017-07-07 18:22:00+03	26000.00
E1B340	2017-07-27 23:00:00+03	21000.00
E1B36D	2017-08-08 16:19:00+03	64500.00
E1B3D6	2017-08-15 08:09:00+03	28800.00
E1B469	2017-07-06 23:00:00+03	93400.00
E1B4AA	2017-07-26 13:49:00+03	93900.00
E1B4EC	2017-07-16 12:35:00+03	199700.00
E1B50C	2017-07-08 21:19:00+03	79200.00
E1B60C	2017-07-24 20:26:00+03	37700.00
E1B638	2017-07-11 14:32:00+03	8200.00
E1B68C	2017-08-12 00:56:00+03	133100.00
E1B708	2017-08-04 07:01:00+03	72400.00
E1B71A	2017-08-11 12:57:00+03	56600.00
E1B741	2017-07-31 07:16:00+03	73600.00
E1B774	2017-07-15 14:44:00+03	68600.00
E1B798	2017-07-10 02:46:00+03	82000.00
E1B7B6	2017-07-22 06:58:00+03	7300.00
E1B7DD	2017-08-12 10:18:00+03	52600.00
E1B82F	2017-08-09 09:36:00+03	107200.00
E1B83C	2017-07-18 07:48:00+03	69100.00
E1B86C	2017-08-06 16:02:00+03	25600.00
E1B929	2017-07-01 17:29:00+03	54400.00
E1B97C	2017-08-07 17:14:00+03	43200.00
E1B989	2017-07-23 14:04:00+03	38400.00
E1BA07	2017-08-13 01:17:00+03	53600.00
E1BA29	2017-08-08 16:52:00+03	27300.00
E1BA39	2017-07-26 03:22:00+03	21400.00
E1BA3B	2017-08-14 20:09:00+03	124200.00
E1BA3D	2017-07-12 02:39:00+03	91600.00
E1BA5C	2017-07-08 02:44:00+03	62900.00
E1BB22	2017-07-30 20:25:00+03	7400.00
E1BBA7	2017-07-22 10:17:00+03	21800.00
E1BC1F	2017-07-10 19:31:00+03	31400.00
E1BC54	2017-07-19 10:10:00+03	76800.00
E1BC65	2017-08-12 10:59:00+03	26000.00
E1BC68	2017-07-31 11:37:00+03	83600.00
E1BC89	2017-07-18 12:35:00+03	25600.00
E1BCAD	2017-07-24 07:51:00+03	14400.00
E1BD6C	2017-08-14 12:31:00+03	90200.00
E1BE2E	2017-07-01 10:22:00+03	27300.00
E1BE9D	2017-07-30 02:03:00+03	123000.00
E1BF04	2017-07-03 05:40:00+03	4400.00
E1BF26	2017-07-31 00:13:00+03	23400.00
E1BF44	2017-08-08 23:33:00+03	56000.00
E1BF47	2017-07-22 03:33:00+03	132800.00
E1BF54	2017-07-07 00:37:00+03	51900.00
E1BF61	2017-07-11 17:22:00+03	149000.00
E1BF6E	2017-08-07 04:40:00+03	26000.00
E1BF77	2017-07-06 08:18:00+03	23400.00
E1C047	2017-07-17 00:38:00+03	55100.00
E1C069	2017-08-11 20:30:00+03	204100.00
E1C08A	2017-08-11 19:26:00+03	85000.00
E1C0CC	2017-07-26 00:12:00+03	40300.00
E1C152	2017-08-12 05:27:00+03	15400.00
E1C18C	2017-07-11 03:53:00+03	73200.00
E1C195	2017-08-09 11:01:00+03	65500.00
E1C1FE	2017-07-29 20:38:00+03	6000.00
E1C20D	2017-08-10 03:29:00+03	20400.00
E1C2CA	2017-08-09 05:34:00+03	170700.00
E1C308	2017-07-22 00:25:00+03	25400.00
E1C351	2017-07-21 02:38:00+03	88600.00
E1C36A	2017-08-10 02:46:00+03	111600.00
E1C36D	2017-08-07 21:32:00+03	94400.00
E1C376	2017-08-03 21:13:00+03	32200.00
E1C43E	2017-08-10 04:08:00+03	21800.00
E1C487	2017-07-08 08:26:00+03	49600.00
E1C527	2017-07-26 02:58:00+03	45200.00
E1C57C	2017-08-13 22:58:00+03	131600.00
E1C654	2017-07-14 21:34:00+03	39300.00
E1C6AE	2017-08-02 09:45:00+03	34000.00
E1C6AF	2017-08-06 22:01:00+03	32800.00
E1C6DD	2017-08-15 04:21:00+03	57300.00
E1C792	2017-07-14 09:23:00+03	57700.00
E1C7A5	2017-07-26 04:20:00+03	123000.00
E1C7BF	2017-07-31 03:45:00+03	46000.00
E1C7E7	2017-08-07 21:13:00+03	38600.00
E1C803	2017-07-06 12:29:00+03	25100.00
E1C81C	2017-08-13 14:49:00+03	68800.00
E1C838	2017-08-05 21:13:00+03	43600.00
E1C8C8	2017-08-13 19:57:00+03	13400.00
E1C8CE	2017-07-07 04:12:00+03	34000.00
E1C8DA	2017-08-14 06:52:00+03	31200.00
E1C927	2017-07-13 04:24:00+03	27900.00
E1C9B1	2017-08-13 15:10:00+03	68800.00
E1C9E6	2017-08-13 18:06:00+03	111600.00
E1C9EF	2017-07-29 06:48:00+03	28000.00
E1CA15	2017-07-12 01:03:00+03	80200.00
E1CA2C	2017-07-02 21:52:00+03	8400.00
E1CA52	2017-08-10 17:50:00+03	56900.00
E1CA58	2017-08-11 16:06:00+03	270000.00
E1CA5A	2017-07-17 08:11:00+03	492000.00
E1CB29	2017-06-30 12:30:00+03	46400.00
E1CB63	2017-07-24 19:50:00+03	85500.00
E1CB8C	2017-07-06 12:55:00+03	92000.00
E1CBC0	2017-07-06 20:16:00+03	48800.00
E1CBE7	2017-08-11 20:03:00+03	30200.00
E1CC19	2017-08-01 17:10:00+03	6000.00
E1CC20	2017-07-09 10:21:00+03	135400.00
E1CC61	2017-08-11 10:27:00+03	10600.00
E1CCA1	2017-07-16 01:41:00+03	75300.00
E1CCB4	2017-07-10 09:51:00+03	46000.00
E1CD2D	2017-08-08 20:50:00+03	87900.00
E1CE11	2017-07-20 04:00:00+03	42200.00
E1CE34	2017-07-22 14:25:00+03	11700.00
E1CE36	2017-07-09 23:22:00+03	70800.00
E1CE6B	2017-08-08 14:00:00+03	61500.00
E1CE85	2017-08-02 18:30:00+03	46000.00
E1CEBD	2017-07-31 11:34:00+03	291300.00
E1CEE5	2017-07-29 10:46:00+03	54000.00
E1CF56	2017-08-13 12:38:00+03	66600.00
E1CF7B	2017-07-24 11:21:00+03	68000.00
E1D06F	2017-07-21 11:29:00+03	79500.00
E1D084	2017-07-31 12:17:00+03	56200.00
E1D0FE	2017-08-14 23:39:00+03	38600.00
E1D130	2017-07-12 04:28:00+03	24000.00
E1D155	2017-08-02 10:16:00+03	40400.00
E1D160	2017-07-26 18:17:00+03	56900.00
E1D1CE	2017-07-30 12:45:00+03	31200.00
E1D218	2017-07-09 08:27:00+03	37600.00
E1D239	2017-07-31 05:27:00+03	23200.00
E1D261	2017-07-27 11:19:00+03	23200.00
E1D27D	2017-07-13 05:27:00+03	44500.00
E1D284	2017-08-10 12:02:00+03	106300.00
E1D28D	2017-07-07 21:42:00+03	120400.00
E1D28E	2017-08-08 05:27:00+03	57800.00
E1D2BD	2017-06-30 09:51:00+03	135400.00
E1D2C2	2017-07-05 02:41:00+03	24400.00
E1D2C9	2017-08-03 10:20:00+03	248400.00
E1D2E6	2017-08-09 11:27:00+03	140800.00
E1D31F	2017-08-03 18:33:00+03	92000.00
E1D428	2017-07-13 12:30:00+03	112000.00
E1D435	2017-07-09 16:08:00+03	25000.00
E1D453	2017-08-11 12:18:00+03	81700.00
E1D470	2017-07-10 16:57:00+03	160700.00
E1D582	2017-07-19 01:03:00+03	45400.00
E1D5A8	2017-07-23 07:29:00+03	67600.00
E1D5B3	2017-08-15 13:04:00+03	300700.00
E1D615	2017-08-02 07:58:00+03	532600.00
E1D619	2017-07-04 17:21:00+03	133200.00
E1D768	2017-08-15 00:17:00+03	8400.00
E1D7AE	2017-08-03 00:13:00+03	30200.00
E1D806	2017-08-04 20:41:00+03	178000.00
E1D824	2017-08-05 12:56:00+03	27200.00
E1D855	2017-07-28 07:04:00+03	81600.00
E1D87B	2017-08-14 05:47:00+03	28000.00
E1D8DA	2017-07-17 17:16:00+03	68100.00
E1DA8E	2017-08-04 04:10:00+03	37200.00
E1DAE4	2017-07-24 05:44:00+03	25100.00
E1DB2B	2017-07-04 22:07:00+03	39300.00
E1DB5D	2017-07-20 21:51:00+03	136200.00
E1DB61	2017-07-06 13:11:00+03	21800.00
E1DBA6	2017-07-09 20:39:00+03	23200.00
E1DBCB	2017-07-17 06:11:00+03	153200.00
E1DC37	2017-07-05 22:49:00+03	77000.00
E1DC3C	2017-07-12 06:09:00+03	73200.00
E1DC44	2017-07-03 23:48:00+03	114400.00
E1DCB6	2017-08-09 15:28:00+03	59800.00
E1DD7F	2017-07-12 14:54:00+03	30400.00
E1DD90	2017-07-31 10:39:00+03	23600.00
E1DD9B	2017-07-14 04:24:00+03	26700.00
E1DDAB	2017-08-14 07:11:00+03	94500.00
E1DDC9	2017-07-26 10:24:00+03	29800.00
E1DE98	2017-08-01 18:59:00+03	30200.00
E1DF35	2017-07-06 10:12:00+03	55800.00
E1DF5B	2017-08-03 13:28:00+03	52100.00
E1DF5F	2017-07-27 23:20:00+03	189800.00
E1DFBE	2017-07-11 02:13:00+03	36200.00
E1DFC4	2017-06-30 17:53:00+03	56600.00
E1DFC9	2017-07-18 18:28:00+03	64500.00
E1DFDE	2017-07-15 22:43:00+03	28800.00
E1DFE3	2017-07-26 02:56:00+03	62900.00
E1DFF2	2017-08-01 06:07:00+03	29200.00
E1E005	2017-08-12 00:54:00+03	52900.00
E1E018	2017-07-02 07:01:00+03	26000.00
E1E05B	2017-07-01 20:14:00+03	65900.00
E1E116	2017-07-30 09:20:00+03	28000.00
E1E146	2017-07-17 23:52:00+03	70800.00
E1E17B	2017-08-05 02:19:00+03	54800.00
E1E199	2017-08-03 19:24:00+03	56000.00
E1E1A2	2017-07-28 22:09:00+03	56100.00
E1E1AE	2017-07-20 08:46:00+03	18400.00
E1E250	2017-07-31 14:47:00+03	39200.00
E1E266	2017-07-22 23:37:00+03	22000.00
E1E2D2	2017-07-02 15:02:00+03	113300.00
E1E325	2017-07-24 02:54:00+03	53400.00
E1E32C	2017-07-20 16:49:00+03	72000.00
E1E374	2017-07-02 06:13:00+03	23600.00
E1E38E	2017-07-23 05:07:00+03	83000.00
E1E3A3	2017-07-28 06:09:00+03	20500.00
E1E3B9	2017-07-06 22:35:00+03	85700.00
E1E426	2017-08-10 14:38:00+03	55800.00
E1E438	2017-08-10 23:00:00+03	254600.00
E1E490	2017-08-15 08:15:00+03	48700.00
E1E4F9	2017-08-07 00:10:00+03	31600.00
E1E510	2017-07-25 00:18:00+03	51000.00
E1E51C	2017-07-05 00:10:00+03	27200.00
E1E522	2017-07-08 13:50:00+03	24400.00
E1E530	2017-08-07 21:00:00+03	184300.00
E1E55E	2017-07-05 20:03:00+03	55800.00
E1E5BA	2017-08-12 10:44:00+03	36800.00
E1E672	2017-08-09 06:26:00+03	19500.00
E1E688	2017-07-24 04:35:00+03	67600.00
E1E68E	2017-07-30 23:57:00+03	247700.00
E1E6CB	2017-08-10 01:01:00+03	6000.00
E1E6FC	2017-08-03 03:42:00+03	22000.00
E1E741	2017-07-31 21:32:00+03	36800.00
E1E747	2017-07-25 00:24:00+03	111600.00
E1E790	2017-07-04 05:57:00+03	48800.00
E1E7B5	2017-07-18 04:41:00+03	26000.00
E1E7F9	2017-07-05 14:45:00+03	40800.00
E1E859	2017-08-02 11:02:00+03	55700.00
E1E878	2017-07-23 23:59:00+03	603600.00
E1E87B	2017-07-21 08:31:00+03	54500.00
E1E87F	2017-08-10 00:13:00+03	41600.00
E1E8D1	2017-08-13 19:43:00+03	142300.00
E1E920	2017-07-10 04:17:00+03	49800.00
E1E976	2017-07-21 10:41:00+03	205000.00
E1E9A9	2017-07-11 20:04:00+03	58600.00
E1E9AF	2017-07-30 11:38:00+03	54800.00
E1E9DF	2017-07-24 01:52:00+03	102100.00
E1E9E0	2017-07-09 10:02:00+03	252100.00
E1E9E5	2017-08-12 00:51:00+03	20400.00
E1E9F8	2017-08-14 16:18:00+03	19600.00
E1EA4C	2017-07-16 09:08:00+03	55800.00
E1EAB2	2017-08-04 11:33:00+03	69900.00
E1EAD6	2017-08-05 06:19:00+03	28800.00
E1EB20	2017-07-10 04:37:00+03	203500.00
E1EB3C	2017-07-24 15:03:00+03	51600.00
E1EBAD	2017-07-01 21:17:00+03	47000.00
E1EBE9	2017-08-05 13:44:00+03	129600.00
E1EC4D	2017-07-16 12:43:00+03	129500.00
E1EC6E	2017-07-14 20:05:00+03	85000.00
E1EC8E	2017-07-20 08:03:00+03	64400.00
E1ED0C	2017-07-06 16:10:00+03	26000.00
E1EDBA	2017-07-06 15:05:00+03	50400.00
E1EE06	2017-08-11 08:10:00+03	286100.00
E1EE5D	2017-08-03 02:03:00+03	8000.00
E1EE69	2017-07-09 17:02:00+03	161100.00
E1EE6C	2017-07-18 01:26:00+03	198400.00
E1EE81	2017-08-15 15:22:00+03	93500.00
E1EE87	2017-07-06 08:48:00+03	424800.00
E1EEC8	2017-07-13 09:43:00+03	47600.00
E1EEFB	2017-08-09 05:54:00+03	84100.00
E1EF10	2017-07-20 10:48:00+03	31600.00
E1EF1E	2017-06-30 22:46:00+03	114800.00
E1EF8C	2017-07-16 12:04:00+03	21000.00
E1EFCC	2017-08-13 04:11:00+03	55800.00
E1EFDF	2017-07-23 13:16:00+03	68100.00
E1F023	2017-07-12 22:39:00+03	207000.00
E1F024	2017-08-04 18:51:00+03	59300.00
E1F027	2017-07-05 08:43:00+03	86800.00
E1F049	2017-07-21 03:01:00+03	73100.00
E1F05E	2017-08-02 15:56:00+03	39300.00
E1F072	2017-07-09 08:25:00+03	56600.00
E1F0B9	2017-08-05 10:42:00+03	12400.00
E1F0C3	2017-07-06 15:15:00+03	16400.00
E1F0E2	2017-07-08 20:52:00+03	40600.00
E1F102	2017-07-24 20:07:00+03	90600.00
E1F117	2017-07-26 20:06:00+03	73500.00
E1F162	2017-07-20 05:59:00+03	61400.00
E1F21F	2017-08-13 09:51:00+03	26000.00
E1F249	2017-07-30 03:47:00+03	32200.00
E1F289	2017-07-14 20:39:00+03	26000.00
E1F293	2017-08-06 15:12:00+03	298500.00
E1F32C	2017-08-09 00:17:00+03	59000.00
E1F3EE	2017-08-10 06:10:00+03	21200.00
E1F40C	2017-08-03 06:15:00+03	26000.00
E1F479	2017-08-08 01:49:00+03	65400.00
E1F4A8	2017-07-14 13:01:00+03	31400.00
E1F52D	2017-07-30 22:41:00+03	132700.00
E1F535	2017-07-16 18:32:00+03	26800.00
E1F540	2017-07-26 19:20:00+03	56000.00
E1F55F	2017-08-15 00:45:00+03	28000.00
E1F5F7	2017-07-21 19:44:00+03	43100.00
E1F666	2017-07-14 12:33:00+03	117600.00
E1F699	2017-07-17 00:46:00+03	38400.00
E1F6C4	2017-07-06 11:00:00+03	86500.00
E1F708	2017-07-04 19:43:00+03	58800.00
E1F753	2017-07-08 07:41:00+03	38200.00
E1F76A	2017-07-25 00:11:00+03	71600.00
E1F7A9	2017-07-24 13:38:00+03	39200.00
E1F7CA	2017-07-06 22:04:00+03	38600.00
E1F7CE	2017-07-23 02:44:00+03	135400.00
E1F7ED	2017-07-22 14:40:00+03	135000.00
E1F7FA	2017-07-20 19:39:00+03	46400.00
E1F8A9	2017-07-25 10:05:00+03	23100.00
E1F8FE	2017-07-28 17:16:00+03	56000.00
E1F932	2017-07-20 03:04:00+03	36800.00
E1F947	2017-07-29 06:59:00+03	81200.00
E1FA5A	2017-08-07 21:00:00+03	14000.00
E1FA94	2017-07-20 12:10:00+03	46900.00
E1FAC9	2017-07-20 04:55:00+03	76600.00
E1FAD6	2017-08-05 18:27:00+03	112000.00
E1FAF5	2017-07-27 17:37:00+03	62800.00
E1FB1B	2017-07-03 11:43:00+03	28600.00
E1FB91	2017-07-24 18:44:00+03	8200.00
E1FBA6	2017-07-22 17:22:00+03	94800.00
E1FBBB	2017-08-08 13:47:00+03	182000.00
E1FBC9	2017-07-11 15:08:00+03	157200.00
E1FBF0	2017-07-15 11:32:00+03	31000.00
E1FBF2	2017-07-28 15:15:00+03	72400.00
E1FD3D	2017-07-02 01:46:00+03	123000.00
E1FDA6	2017-07-05 21:28:00+03	68900.00
E1FDDA	2017-07-14 11:42:00+03	20400.00
E1FE38	2017-07-04 04:10:00+03	50800.00
E1FE59	2017-07-01 16:46:00+03	23400.00
E1FE86	2017-07-23 05:59:00+03	103500.00
E1FE8B	2017-07-15 01:30:00+03	81300.00
E1FEBF	2017-08-11 15:58:00+03	94000.00
E1FED2	2017-07-19 09:24:00+03	81500.00
E1FF1E	2017-08-01 02:55:00+03	88500.00
E1FF33	2017-07-16 19:44:00+03	33200.00
E1FF8A	2017-07-05 21:44:00+03	8000.00
E1FF9A	2017-07-14 08:00:00+03	77900.00
E1FFC9	2017-07-13 23:01:00+03	29600.00
E20001	2017-06-29 19:50:00+03	31600.00
E2000C	2017-07-25 04:45:00+03	85000.00
E20020	2017-07-30 14:00:00+03	198600.00
E2002D	2017-07-04 23:44:00+03	38800.00
E200BD	2017-07-27 00:54:00+03	23600.00
E200C9	2017-08-05 01:40:00+03	9800.00
E20105	2017-07-08 17:50:00+03	83200.00
E2018A	2017-07-14 23:03:00+03	57500.00
E20192	2017-07-21 07:11:00+03	47100.00
E2019A	2017-07-27 06:01:00+03	115400.00
E201B3	2017-07-26 04:25:00+03	133200.00
E201D3	2017-07-30 17:02:00+03	385000.00
E201DB	2017-07-28 14:26:00+03	31400.00
E2021F	2017-08-14 14:03:00+03	56000.00
E202BB	2017-08-04 13:37:00+03	13600.00
E20353	2017-07-17 22:32:00+03	126300.00
E203EF	2017-08-01 03:51:00+03	42800.00
E203F0	2017-07-19 23:26:00+03	37900.00
E203FA	2017-08-09 13:52:00+03	56000.00
E20406	2017-08-10 12:03:00+03	15400.00
E2048B	2017-08-03 19:23:00+03	84500.00
E2049D	2017-07-14 20:30:00+03	56000.00
E204CA	2017-07-25 04:10:00+03	88500.00
E204D8	2017-06-30 22:09:00+03	199700.00
E204E9	2017-08-02 19:30:00+03	45200.00
E20547	2017-07-19 02:48:00+03	25600.00
E20581	2017-07-05 10:44:00+03	53600.00
E20594	2017-08-14 12:41:00+03	62000.00
E205A0	2017-07-21 13:47:00+03	146400.00
E205D4	2017-06-28 03:56:00+03	65500.00
E205DA	2017-07-06 07:48:00+03	22600.00
E2060D	2017-07-17 15:36:00+03	75100.00
E2066B	2017-07-16 09:53:00+03	25000.00
E20687	2017-07-13 18:42:00+03	44600.00
E206E9	2017-08-11 04:12:00+03	8200.00
E206EF	2017-07-16 03:07:00+03	46800.00
E206F0	2017-08-13 16:27:00+03	98200.00
E206FF	2017-08-15 05:24:00+03	16400.00
E2073E	2017-07-09 16:23:00+03	58400.00
E20755	2017-07-04 14:16:00+03	46000.00
E2077A	2017-07-26 18:47:00+03	86800.00
E208BC	2017-08-12 22:27:00+03	29100.00
E208DB	2017-08-05 20:50:00+03	203000.00
E208E1	2017-07-09 19:49:00+03	28800.00
E20925	2017-07-24 08:19:00+03	23600.00
E2095F	2017-07-26 22:06:00+03	59000.00
E20991	2017-07-20 17:32:00+03	26800.00
E20A6F	2017-07-06 22:14:00+03	174000.00
E20AA2	2017-08-11 02:33:00+03	100000.00
E20AD8	2017-08-05 09:52:00+03	24400.00
E20AE7	2017-07-12 10:21:00+03	89100.00
E20AF7	2017-08-14 16:04:00+03	94800.00
E20B03	2017-07-27 13:36:00+03	79200.00
E20B56	2017-08-02 23:49:00+03	67900.00
E20BA0	2017-07-28 17:37:00+03	118600.00
E20BF4	2017-07-06 01:55:00+03	36800.00
E20BF9	2017-07-30 04:20:00+03	26800.00
E20C10	2017-08-15 11:00:00+03	246000.00
E20CFD	2017-08-07 07:13:00+03	155600.00
E20D92	2017-07-19 04:27:00+03	31400.00
E20E2D	2017-07-21 10:13:00+03	76100.00
E20E58	2017-07-30 09:58:00+03	43200.00
E20E59	2017-07-18 15:24:00+03	83000.00
E20E5C	2017-08-13 09:50:00+03	73100.00
E20E71	2017-08-02 05:34:00+03	49900.00
E20E86	2017-07-30 04:39:00+03	56000.00
E20EA7	2017-07-10 18:19:00+03	283100.00
E20EA9	2017-07-17 03:06:00+03	14400.00
E20F09	2017-08-07 17:27:00+03	70500.00
E20F71	2017-08-02 07:56:00+03	125700.00
E20FEC	2017-07-19 09:06:00+03	81800.00
E21035	2017-07-17 08:59:00+03	17800.00
E21036	2017-08-09 09:13:00+03	114300.00
E21056	2017-07-05 12:31:00+03	65900.00
E210C4	2017-07-02 02:55:00+03	66600.00
E2110D	2017-07-08 02:15:00+03	88000.00
E2111D	2017-07-05 14:01:00+03	64800.00
E2113C	2017-08-02 18:34:00+03	28800.00
E21177	2017-07-13 20:20:00+03	162600.00
E211C9	2017-08-08 21:18:00+03	13600.00
E21210	2017-07-29 15:40:00+03	7400.00
E21213	2017-06-30 19:32:00+03	73900.00
E21214	2017-07-15 21:10:00+03	61800.00
E21228	2017-07-09 13:20:00+03	29400.00
E2122A	2017-07-17 20:26:00+03	148300.00
E2129B	2017-08-14 01:36:00+03	291000.00
E212C0	2017-07-28 10:16:00+03	59200.00
E212E1	2017-07-28 11:36:00+03	78900.00
E212EB	2017-07-13 17:56:00+03	190700.00
E21355	2017-08-07 16:18:00+03	54800.00
E21393	2017-08-13 02:39:00+03	40400.00
E213F7	2017-07-27 06:36:00+03	193200.00
E21434	2017-08-13 00:18:00+03	21200.00
E2149A	2017-07-30 13:55:00+03	79600.00
E214A9	2017-08-13 15:57:00+03	166000.00
E21531	2017-07-17 17:37:00+03	23200.00
E21536	2017-07-09 21:16:00+03	18300.00
E215C3	2017-08-06 18:05:00+03	73500.00
E215DD	2017-07-19 08:14:00+03	157400.00
E215F0	2017-08-03 03:03:00+03	27300.00
E2161E	2017-07-21 16:04:00+03	198100.00
E21650	2017-08-07 14:17:00+03	192200.00
E2169E	2017-07-25 03:32:00+03	28000.00
E216B6	2017-07-24 00:44:00+03	55800.00
E216CC	2017-07-19 21:39:00+03	93700.00
E216D2	2017-07-16 00:27:00+03	496700.00
E21710	2017-07-25 08:23:00+03	67400.00
E2173D	2017-07-05 14:04:00+03	67400.00
E217AA	2017-08-11 07:27:00+03	104800.00
E217E0	2017-06-26 22:04:00+03	60400.00
E21812	2017-07-30 00:15:00+03	302000.00
E21841	2017-07-20 10:58:00+03	49100.00
E2188A	2017-07-26 13:11:00+03	121400.00
E21896	2017-07-06 07:36:00+03	111600.00
E218B2	2017-08-04 17:50:00+03	26800.00
E218CF	2017-07-25 07:44:00+03	26700.00
E21957	2017-07-19 18:37:00+03	52000.00
E21958	2017-07-01 20:52:00+03	406000.00
E21974	2017-08-11 16:21:00+03	274200.00
E21978	2017-08-07 13:36:00+03	120800.00
E219A5	2017-07-18 13:20:00+03	52000.00
E219AB	2017-07-12 12:33:00+03	23600.00
E219CE	2017-08-06 07:47:00+03	125200.00
E21A43	2017-07-09 11:31:00+03	57600.00
E21A74	2017-07-15 14:46:00+03	43500.00
E21A83	2017-06-28 17:56:00+03	23200.00
E21B2B	2017-08-01 10:07:00+03	52700.00
E21B69	2017-07-06 22:16:00+03	59300.00
E21BCF	2017-08-08 08:38:00+03	6300.00
E21C3E	2017-07-16 04:27:00+03	266400.00
E21C4E	2017-08-06 17:45:00+03	66600.00
E21C76	2017-07-20 03:16:00+03	32700.00
E21C98	2017-08-12 21:07:00+03	77200.00
E21D3E	2017-07-02 13:52:00+03	44600.00
E21D58	2017-08-12 06:06:00+03	37700.00
E21D8E	2017-07-26 04:14:00+03	28000.00
E21E3A	2017-07-16 19:45:00+03	47700.00
E21E4A	2017-06-28 05:23:00+03	169900.00
E21E64	2017-08-11 14:38:00+03	40000.00
E21F54	2017-07-23 12:06:00+03	58600.00
E22059	2017-08-08 23:03:00+03	55000.00
E2207D	2017-07-29 11:41:00+03	40800.00
E220D2	2017-08-11 17:51:00+03	40000.00
E220E2	2017-06-28 00:01:00+03	73400.00
E220FF	2017-07-05 23:36:00+03	144100.00
E221E2	2017-08-03 09:41:00+03	66800.00
E221E4	2017-07-29 09:26:00+03	93900.00
E221E5	2017-08-14 01:06:00+03	27800.00
E221EF	2017-07-20 02:33:00+03	59000.00
E2221F	2017-07-14 08:48:00+03	103800.00
E22242	2017-07-21 10:21:00+03	48800.00
E22279	2017-08-08 02:31:00+03	38000.00
E22283	2017-07-10 14:47:00+03	60700.00
E222B3	2017-08-10 13:45:00+03	39200.00
E22324	2017-08-11 03:33:00+03	123900.00
E2232B	2017-07-13 09:22:00+03	60800.00
E22331	2017-08-01 05:12:00+03	53800.00
E22344	2017-06-29 21:43:00+03	6000.00
E22353	2017-08-14 00:05:00+03	134400.00
E2238F	2017-07-18 13:48:00+03	111600.00
E223D6	2017-07-21 23:53:00+03	53300.00
E223FB	2017-07-27 22:01:00+03	24400.00
E22408	2017-07-24 14:41:00+03	23200.00
E22450	2017-07-24 17:41:00+03	317000.00
E2245E	2017-07-05 17:31:00+03	15200.00
E224D2	2017-08-15 12:23:00+03	105400.00
E2250E	2017-08-10 17:07:00+03	37100.00
E2254D	2017-07-09 20:08:00+03	42400.00
E2256F	2017-08-07 08:50:00+03	20400.00
E2258D	2017-08-14 12:16:00+03	133200.00
E225FF	2017-07-02 08:07:00+03	70900.00
E22609	2017-07-19 18:29:00+03	136800.00
E22674	2017-08-07 19:15:00+03	48500.00
E22691	2017-07-18 07:02:00+03	117700.00
E226B6	2017-07-25 12:18:00+03	58800.00
E226FC	2017-08-09 07:52:00+03	7400.00
E2270B	2017-06-30 02:01:00+03	28600.00
E22778	2017-07-16 07:06:00+03	67600.00
E22805	2017-07-29 13:41:00+03	33500.00
E22973	2017-07-20 12:48:00+03	64800.00
E22A1C	2017-06-28 11:13:00+03	55800.00
E22A39	2017-08-12 22:54:00+03	24800.00
E22A3D	2017-08-13 07:32:00+03	13600.00
E22A42	2017-07-07 04:10:00+03	9800.00
E22A45	2017-07-13 12:17:00+03	51200.00
E22A70	2017-08-15 02:55:00+03	28800.00
E22AFE	2017-07-23 17:18:00+03	38400.00
E22B2C	2017-07-27 17:11:00+03	46400.00
E22BB8	2017-07-31 01:51:00+03	75600.00
E22BD8	2017-07-17 13:55:00+03	398500.00
E22BED	2017-08-02 13:01:00+03	24800.00
E22C46	2017-07-02 20:36:00+03	50800.00
E22CD7	2017-07-18 13:39:00+03	64700.00
E22D08	2017-08-14 21:26:00+03	286100.00
E22D12	2017-08-13 05:17:00+03	89700.00
E22D63	2017-08-06 23:39:00+03	398400.00
E22D74	2017-07-17 17:07:00+03	44800.00
E22D9C	2017-07-12 04:22:00+03	34000.00
E22E20	2017-07-11 03:38:00+03	59300.00
E22E73	2017-08-14 05:36:00+03	203700.00
E22E8F	2017-07-09 17:07:00+03	8000.00
E22EAF	2017-07-12 11:17:00+03	112000.00
E22F46	2017-08-05 18:17:00+03	34000.00
E22F48	2017-08-09 03:43:00+03	23200.00
E22F8B	2017-07-31 15:02:00+03	184600.00
E22F9B	2017-07-19 17:02:00+03	153200.00
E22FDA	2017-07-21 18:01:00+03	302400.00
E22FEF	2017-07-07 19:08:00+03	28000.00
E23007	2017-07-22 16:18:00+03	103200.00
E23046	2017-08-08 12:04:00+03	469400.00
E2309F	2017-07-04 19:30:00+03	44600.00
E230E6	2017-07-11 05:46:00+03	101200.00
E230E9	2017-08-05 08:31:00+03	39300.00
E230F0	2017-07-31 20:04:00+03	75600.00
E23129	2017-08-08 22:22:00+03	40800.00
E23151	2017-07-24 14:07:00+03	112000.00
E23172	2017-07-27 06:14:00+03	159800.00
E231D2	2017-07-24 15:29:00+03	23600.00
E231E4	2017-08-10 03:00:00+03	40000.00
E23206	2017-07-23 13:13:00+03	12600.00
E2322B	2017-07-24 06:32:00+03	28000.00
E23232	2017-07-03 03:03:00+03	56200.00
E23326	2017-08-05 16:09:00+03	40100.00
E2334A	2017-07-28 13:32:00+03	56000.00
E233DB	2017-07-07 04:34:00+03	249200.00
E2346E	2017-07-06 17:14:00+03	149300.00
E2348B	2017-07-10 06:38:00+03	57800.00
E23496	2017-08-06 02:36:00+03	132800.00
E234BC	2017-07-11 22:29:00+03	84400.00
E234DB	2017-08-12 20:11:00+03	23200.00
E23501	2017-08-07 04:31:00+03	38800.00
E23572	2017-08-05 04:17:00+03	12000.00
E23576	2017-08-13 03:50:00+03	28800.00
E23580	2017-07-30 03:46:00+03	38300.00
E23584	2017-08-03 20:29:00+03	98300.00
E235C3	2017-08-14 18:17:00+03	86300.00
E235D3	2017-08-15 07:16:00+03	64700.00
E23613	2017-07-26 08:35:00+03	85000.00
E23756	2017-07-25 04:53:00+03	26000.00
E23790	2017-07-16 18:14:00+03	147800.00
E237F2	2017-07-21 04:09:00+03	123900.00
E2388A	2017-07-26 06:04:00+03	56000.00
E238E5	2017-07-29 15:18:00+03	123000.00
E2392B	2017-07-24 21:16:00+03	28800.00
E23956	2017-08-06 17:22:00+03	13400.00
E239E7	2017-07-16 16:51:00+03	69900.00
E23A19	2017-07-04 16:56:00+03	47400.00
E23A41	2017-07-06 07:55:00+03	111700.00
E23A47	2017-07-12 08:28:00+03	116000.00
E23A53	2017-08-14 17:05:00+03	217900.00
E23A58	2017-08-10 20:56:00+03	167400.00
E23AB1	2017-07-26 19:27:00+03	26700.00
E23AB6	2017-07-26 23:02:00+03	26700.00
E23ABF	2017-07-18 09:11:00+03	180000.00
E23ACB	2017-07-02 21:34:00+03	6300.00
E23ADB	2017-08-08 09:34:00+03	75600.00
E23B35	2017-07-27 23:05:00+03	383200.00
E23B3C	2017-07-25 01:27:00+03	38600.00
E23C00	2017-08-06 11:19:00+03	536100.00
E23C5A	2017-07-12 12:40:00+03	27300.00
E23C93	2017-08-07 04:20:00+03	88800.00
E23C9E	2017-07-11 19:00:00+03	89100.00
E23D00	2017-08-06 12:14:00+03	55800.00
E23D09	2017-08-14 13:20:00+03	12000.00
E23D8C	2017-08-09 12:04:00+03	36900.00
E23D99	2017-08-12 21:39:00+03	43200.00
E23E1F	2017-08-05 18:55:00+03	80000.00
E23E8F	2017-08-05 02:35:00+03	47200.00
E23EB3	2017-08-12 18:34:00+03	46000.00
E23F77	2017-07-07 01:16:00+03	136100.00
E23F88	2017-08-08 18:45:00+03	75300.00
E23F99	2017-07-08 15:44:00+03	72200.00
E23FA2	2017-08-10 06:18:00+03	70400.00
E23FBC	2017-08-05 03:27:00+03	55800.00
E24019	2017-07-26 18:30:00+03	51600.00
E24037	2017-08-13 12:25:00+03	42600.00
E24087	2017-07-10 18:09:00+03	34000.00
E240E8	2017-08-08 14:51:00+03	104800.00
E241A5	2017-07-27 10:06:00+03	29600.00
E24226	2017-08-11 22:40:00+03	52000.00
E24231	2017-07-20 10:28:00+03	103000.00
E2428A	2017-07-21 04:18:00+03	38800.00
E242EF	2017-07-02 11:16:00+03	134800.00
E242F2	2017-07-04 15:14:00+03	25000.00
E24315	2017-07-16 02:16:00+03	16400.00
E2433F	2017-07-17 07:07:00+03	54400.00
E243AA	2017-08-10 22:21:00+03	20800.00
E243BC	2017-07-26 19:35:00+03	64800.00
E24421	2017-08-12 21:50:00+03	185300.00
E2448B	2017-08-09 22:33:00+03	34000.00
E244A8	2017-07-28 10:26:00+03	6800.00
E2451D	2017-07-08 07:50:00+03	47500.00
E24562	2017-07-22 08:20:00+03	23600.00
E24623	2017-08-15 03:37:00+03	40000.00
E2466B	2017-07-17 08:50:00+03	6800.00
E24681	2017-07-04 06:58:00+03	22000.00
E24693	2017-08-12 23:34:00+03	77900.00
E246F4	2017-07-08 20:21:00+03	38400.00
E247C3	2017-08-03 17:05:00+03	68400.00
E247F5	2017-07-30 18:12:00+03	30200.00
E248BA	2017-08-15 12:50:00+03	62000.00
E248BD	2017-07-18 03:56:00+03	93900.00
E248F1	2017-07-23 14:56:00+03	44000.00
E24963	2017-07-18 00:43:00+03	55800.00
E24977	2017-07-23 06:32:00+03	28000.00
E24987	2017-07-23 04:38:00+03	26000.00
E249EA	2017-07-01 09:19:00+03	31000.00
E24A86	2017-07-25 15:30:00+03	102300.00
E24AC2	2017-07-28 21:27:00+03	50000.00
E24ADC	2017-07-17 02:08:00+03	85000.00
E24AF4	2017-08-07 04:53:00+03	52400.00
E24B1D	2017-07-31 22:14:00+03	67400.00
E24B57	2017-07-13 00:55:00+03	26800.00
E24B74	2017-07-05 15:38:00+03	67600.00
E24BA8	2017-08-11 19:42:00+03	56000.00
E24C09	2017-07-05 01:51:00+03	11700.00
E24C68	2017-07-27 14:46:00+03	47200.00
E24C86	2017-07-06 20:50:00+03	25400.00
E24CBC	2017-07-09 10:33:00+03	169600.00
E24DB2	2017-07-14 15:04:00+03	266400.00
E24DE7	2017-08-15 01:06:00+03	396500.00
E24DF4	2017-08-10 09:16:00+03	51800.00
E24E0F	2017-08-03 16:43:00+03	42700.00
E24E15	2017-07-09 06:46:00+03	40800.00
E24E29	2017-08-12 17:51:00+03	35800.00
E24EE1	2017-07-01 15:13:00+03	190100.00
E24EE9	2017-08-10 05:01:00+03	71000.00
E24EEF	2017-08-01 10:53:00+03	68600.00
E24F4B	2017-07-22 00:30:00+03	40800.00
E24F5C	2017-07-28 15:02:00+03	37100.00
E24F7E	2017-07-23 14:32:00+03	44000.00
E24FCB	2017-07-12 12:17:00+03	118600.00
E24FE4	2017-08-02 14:41:00+03	135200.00
E25057	2017-08-06 13:26:00+03	123000.00
E25066	2017-07-31 19:57:00+03	42800.00
E2508C	2017-08-03 20:29:00+03	27300.00
E2511C	2017-07-08 22:46:00+03	57400.00
E2514B	2017-07-30 05:15:00+03	54300.00
E251A3	2017-07-23 19:50:00+03	125200.00
E251B8	2017-08-13 05:53:00+03	67000.00
E251EB	2017-07-08 02:52:00+03	61500.00
E25209	2017-08-04 22:44:00+03	57500.00
E2520E	2017-07-05 19:00:00+03	57400.00
E25336	2017-07-25 05:48:00+03	23000.00
E2534D	2017-07-19 11:09:00+03	17200.00
E253AB	2017-07-10 21:11:00+03	56600.00
E253BE	2017-08-04 00:44:00+03	39400.00
E25439	2017-07-09 09:40:00+03	381400.00
E254C1	2017-07-10 23:11:00+03	6000.00
E25549	2017-07-30 10:51:00+03	25100.00
E25550	2017-07-26 22:39:00+03	20500.00
E25587	2017-07-05 08:42:00+03	117200.00
E255BD	2017-07-04 10:07:00+03	325500.00
E2562E	2017-07-07 13:40:00+03	7400.00
E25632	2017-07-29 11:45:00+03	21800.00
E2565A	2017-07-14 13:51:00+03	100600.00
E25692	2017-08-05 02:06:00+03	189700.00
E256FD	2017-07-14 04:49:00+03	12400.00
E25700	2017-07-18 19:10:00+03	119700.00
E25728	2017-07-14 12:50:00+03	14000.00
E25784	2017-08-15 05:15:00+03	226000.00
E25794	2017-08-09 17:45:00+03	151000.00
E257E4	2017-08-05 03:52:00+03	47800.00
E2580E	2017-06-27 18:00:00+03	57400.00
E2587A	2017-07-28 16:35:00+03	121300.00
E258B4	2017-07-15 08:37:00+03	72800.00
E2593D	2017-08-02 10:45:00+03	23200.00
E25999	2017-08-07 00:51:00+03	52300.00
E25A8A	2017-07-13 12:26:00+03	133200.00
E25A9D	2017-07-15 00:39:00+03	84500.00
E25AD2	2017-08-15 08:53:00+03	120700.00
E25B67	2017-07-26 03:47:00+03	129600.00
E25BB0	2017-07-18 17:13:00+03	6400.00
E25BBB	2017-07-13 00:36:00+03	47000.00
E25BBC	2017-08-09 20:02:00+03	54600.00
E25BE0	2017-07-30 02:11:00+03	148500.00
E25BFC	2017-07-07 15:22:00+03	28000.00
E25CB9	2017-07-22 18:57:00+03	37200.00
E25CC3	2017-07-13 18:02:00+03	28000.00
E25CE8	2017-07-13 20:35:00+03	172100.00
E25CF5	2017-07-15 00:00:00+03	73300.00
E25D2A	2017-08-03 22:38:00+03	168000.00
E25D55	2017-08-08 12:21:00+03	11700.00
E25DDB	2017-07-07 17:00:00+03	51800.00
E25E29	2017-08-09 19:01:00+03	101200.00
E25E2E	2017-07-11 21:53:00+03	140300.00
E25EA5	2017-07-17 09:32:00+03	67900.00
E25EAF	2017-08-10 16:47:00+03	25800.00
E25EFD	2017-06-28 15:44:00+03	28800.00
E25FD1	2017-07-18 08:21:00+03	99700.00
E26003	2017-07-09 07:18:00+03	426800.00
E26007	2017-08-06 14:26:00+03	11600.00
E26064	2017-08-13 12:46:00+03	29600.00
E26082	2017-08-12 07:05:00+03	45300.00
E2608B	2017-08-12 07:23:00+03	293700.00
E260A7	2017-07-20 22:45:00+03	75300.00
E26113	2017-08-02 00:29:00+03	123000.00
E26133	2017-08-14 19:11:00+03	114900.00
E26243	2017-08-10 10:13:00+03	44800.00
E2632E	2017-08-11 05:27:00+03	26800.00
E2634D	2017-08-15 02:35:00+03	17600.00
E263B8	2017-07-28 07:33:00+03	22100.00
E263FA	2017-07-20 05:47:00+03	52900.00
E26435	2017-07-14 09:36:00+03	61900.00
E26452	2017-08-14 17:14:00+03	21800.00
E26461	2017-08-14 17:01:00+03	69500.00
E26472	2017-07-25 20:40:00+03	130100.00
E264BB	2017-08-08 00:29:00+03	25400.00
E264E7	2017-08-14 10:49:00+03	74400.00
E26551	2017-07-09 04:46:00+03	46400.00
E26597	2017-08-15 15:50:00+03	15000.00
E265B9	2017-07-04 16:46:00+03	55800.00
E265D4	2017-07-23 18:42:00+03	23600.00
E26628	2017-06-29 07:58:00+03	133100.00
E26632	2017-08-09 12:38:00+03	101200.00
E2664C	2017-08-10 11:30:00+03	55800.00
E26655	2017-08-03 13:06:00+03	23600.00
E26672	2017-07-30 16:51:00+03	67100.00
E266A6	2017-07-23 04:54:00+03	26600.00
E266CD	2017-07-21 09:50:00+03	26800.00
E266DA	2017-07-06 02:07:00+03	170500.00
E26760	2017-07-01 17:12:00+03	193600.00
E26773	2017-07-05 08:21:00+03	131100.00
E26778	2017-07-03 09:34:00+03	59300.00
E267CC	2017-07-09 14:13:00+03	95600.00
E26860	2017-07-11 12:22:00+03	23200.00
E26888	2017-07-02 07:18:00+03	29600.00
E268CC	2017-07-12 12:12:00+03	37200.00
E268D2	2017-08-06 08:49:00+03	23100.00
E2692E	2017-08-04 09:38:00+03	46000.00
E2693B	2017-08-15 09:28:00+03	56000.00
E2694A	2017-06-29 23:43:00+03	58400.00
E26956	2017-07-26 17:16:00+03	53600.00
E269A7	2017-07-17 16:50:00+03	23200.00
E269B5	2017-08-11 10:48:00+03	92000.00
E269BE	2017-08-03 05:59:00+03	55800.00
E269DE	2017-07-11 17:25:00+03	28000.00
E269F9	2017-07-15 12:10:00+03	173400.00
E26A00	2017-07-25 23:07:00+03	12600.00
E26A04	2017-07-01 21:25:00+03	135400.00
E26A46	2017-07-24 14:12:00+03	38000.00
E26AE2	2017-07-13 17:53:00+03	135400.00
E26B31	2017-07-04 00:45:00+03	58000.00
E26B69	2017-08-01 04:05:00+03	47200.00
E26C60	2017-07-19 14:45:00+03	89600.00
E26D2B	2017-07-30 08:52:00+03	56000.00
E26D34	2017-07-23 14:05:00+03	402400.00
E26D3B	2017-07-21 11:23:00+03	51800.00
E26DAF	2017-07-17 12:26:00+03	46300.00
E26DC7	2017-07-26 23:21:00+03	130400.00
E26E09	2017-07-31 16:30:00+03	28800.00
E26E36	2017-07-15 00:41:00+03	46300.00
E26E4D	2017-07-23 00:30:00+03	55800.00
E26EA1	2017-07-22 15:10:00+03	108000.00
E26EF3	2017-07-18 01:04:00+03	18700.00
E26F01	2017-08-04 03:35:00+03	55800.00
E26F73	2017-07-08 05:41:00+03	8400.00
E26FC4	2017-08-04 08:55:00+03	64500.00
E26FFE	2017-06-27 16:37:00+03	265600.00
E27052	2017-07-10 09:23:00+03	381400.00
E27057	2017-07-23 01:42:00+03	25800.00
E27114	2017-08-02 18:31:00+03	190800.00
E27165	2017-07-16 03:00:00+03	52000.00
E2726C	2017-08-05 08:40:00+03	95600.00
E27283	2017-07-24 02:16:00+03	81700.00
E272D7	2017-07-07 01:40:00+03	107000.00
E27322	2017-07-07 13:41:00+03	211800.00
E2734D	2017-07-23 06:10:00+03	29300.00
E2735E	2017-06-28 02:46:00+03	141000.00
E273B5	2017-07-28 16:03:00+03	66000.00
E2746C	2017-07-19 01:26:00+03	51600.00
E2746E	2017-08-05 21:50:00+03	28800.00
E27487	2017-07-04 16:30:00+03	133200.00
E27522	2017-07-21 23:29:00+03	30400.00
E2755B	2017-07-11 04:48:00+03	67200.00
E27564	2017-08-10 13:57:00+03	55700.00
E2756A	2017-07-04 16:12:00+03	92900.00
E27599	2017-08-10 06:19:00+03	122000.00
E275DE	2017-07-10 19:54:00+03	6000.00
E27617	2017-07-01 04:41:00+03	77600.00
E27641	2017-07-14 22:06:00+03	60400.00
E2768E	2017-08-02 21:10:00+03	39600.00
E2770A	2017-07-05 22:14:00+03	99000.00
E277D1	2017-07-20 13:47:00+03	47000.00
E2783E	2017-07-04 01:54:00+03	28800.00
E2785F	2017-07-20 12:36:00+03	538000.00
E27870	2017-07-21 03:57:00+03	65700.00
E278DB	2017-07-19 18:16:00+03	29200.00
E27AC8	2017-08-08 04:23:00+03	84100.00
E27AD5	2017-08-08 10:43:00+03	7400.00
E27B16	2017-07-13 05:24:00+03	329400.00
E27BB0	2017-07-07 03:57:00+03	133200.00
E27BD7	2017-07-06 21:30:00+03	13400.00
E27C2C	2017-07-22 20:15:00+03	92700.00
E27C5B	2017-08-05 15:18:00+03	75600.00
E27C5D	2017-08-14 11:43:00+03	48800.00
E27CA5	2017-07-20 11:14:00+03	271200.00
E27CEC	2017-07-04 17:07:00+03	91500.00
E27D68	2017-07-26 18:43:00+03	47200.00
E27D7D	2017-07-28 22:03:00+03	25400.00
E27E08	2017-07-12 14:11:00+03	30200.00
E27E1C	2017-06-28 08:38:00+03	234400.00
E27E1F	2017-07-04 07:28:00+03	67700.00
E27E4C	2017-07-25 23:28:00+03	58800.00
E27ECE	2017-07-23 00:08:00+03	94900.00
E27F24	2017-08-11 03:12:00+03	184300.00
E27F28	2017-07-15 01:35:00+03	106400.00
E27F43	2017-08-15 11:35:00+03	68800.00
E27F92	2017-07-09 15:42:00+03	105400.00
E27FAE	2017-06-30 04:12:00+03	107400.00
E27FD0	2017-08-12 08:03:00+03	28800.00
E28064	2017-08-15 11:33:00+03	41400.00
E28091	2017-08-14 09:31:00+03	260900.00
E280AB	2017-08-07 22:38:00+03	94000.00
E280D5	2017-07-31 23:57:00+03	77300.00
E280FC	2017-08-02 05:09:00+03	149500.00
E2812B	2017-06-29 04:35:00+03	111700.00
E28138	2017-06-30 14:59:00+03	25600.00
E28159	2017-08-07 13:11:00+03	187400.00
E28177	2017-06-30 00:14:00+03	111600.00
E28189	2017-07-31 18:32:00+03	67600.00
E281B1	2017-07-16 21:06:00+03	28000.00
E28274	2017-08-10 02:53:00+03	54000.00
E282C1	2017-08-12 16:31:00+03	61000.00
E283F1	2017-08-13 00:13:00+03	56100.00
E283FB	2017-08-08 05:03:00+03	175800.00
E28475	2017-07-05 03:31:00+03	102700.00
E28490	2017-07-20 17:12:00+03	75200.00
E28543	2017-08-02 10:15:00+03	22000.00
E28559	2017-07-05 03:13:00+03	25600.00
E28603	2017-07-23 17:35:00+03	56000.00
E28613	2017-07-20 06:08:00+03	40000.00
E2861B	2017-08-05 04:50:00+03	64400.00
E28624	2017-08-05 08:37:00+03	306600.00
E28664	2017-08-03 15:52:00+03	89700.00
E28686	2017-07-19 20:32:00+03	31400.00
E286C1	2017-08-03 02:36:00+03	83000.00
E286EE	2017-07-23 18:37:00+03	14000.00
E286FB	2017-06-27 03:54:00+03	112000.00
E28730	2017-08-04 02:02:00+03	65300.00
E2873D	2017-08-03 22:23:00+03	13000.00
E2877D	2017-07-19 03:50:00+03	75300.00
E2878D	2017-07-01 19:42:00+03	25200.00
E287BD	2017-07-26 14:14:00+03	44000.00
E28815	2017-07-02 09:11:00+03	102100.00
E2882A	2017-07-20 07:29:00+03	82400.00
E2882D	2017-08-14 16:04:00+03	29600.00
E2896E	2017-08-02 13:27:00+03	56000.00
E2898B	2017-07-10 07:41:00+03	75600.00
E289C1	2017-08-08 23:17:00+03	47800.00
E28AB7	2017-07-24 08:37:00+03	36600.00
E28AE6	2017-08-13 23:42:00+03	39200.00
E28B48	2017-07-14 04:34:00+03	46200.00
E28B88	2017-08-15 04:39:00+03	193300.00
E28B8A	2017-08-03 11:16:00+03	23200.00
E28BA6	2017-07-09 10:52:00+03	81200.00
E28C25	2017-07-11 12:11:00+03	156600.00
E28C7C	2017-08-02 22:52:00+03	43400.00
E28C85	2017-08-11 07:28:00+03	246000.00
E28D23	2017-07-08 11:56:00+03	43500.00
E28D75	2017-07-23 10:17:00+03	246000.00
E28D92	2017-07-25 07:25:00+03	135400.00
E28DB4	2017-07-20 00:14:00+03	56600.00
E28F16	2017-07-23 16:45:00+03	133200.00
E28F29	2017-07-16 04:19:00+03	232800.00
E28F42	2017-06-30 17:48:00+03	53400.00
E28F5F	2017-07-27 09:36:00+03	80100.00
E28F73	2017-08-01 18:48:00+03	23200.00
E28FC4	2017-07-09 14:57:00+03	28300.00
E2901D	2017-07-07 00:25:00+03	17200.00
E29053	2017-08-07 12:41:00+03	209200.00
E29060	2017-07-17 01:47:00+03	101200.00
E2908D	2017-07-05 10:13:00+03	55800.00
E290B2	2017-07-25 08:36:00+03	202100.00
E29109	2017-07-17 22:05:00+03	286700.00
E2911D	2017-07-28 06:43:00+03	189800.00
E2917F	2017-08-15 16:31:00+03	112000.00
E29196	2017-07-24 21:33:00+03	37000.00
E291D3	2017-07-10 06:53:00+03	22000.00
E291EC	2017-07-07 04:46:00+03	266400.00
E29233	2017-07-11 04:43:00+03	135400.00
E29297	2017-08-12 07:44:00+03	76800.00
E2932B	2017-08-04 02:30:00+03	185300.00
E2932D	2017-07-16 21:02:00+03	26000.00
E2933E	2017-07-28 17:56:00+03	42000.00
E2935D	2017-08-10 23:35:00+03	54000.00
E29381	2017-07-13 20:19:00+03	168000.00
E29382	2017-07-21 14:35:00+03	59300.00
E293C5	2017-08-15 11:49:00+03	406200.00
E293D1	2017-07-07 16:01:00+03	178700.00
E293E0	2017-07-16 10:59:00+03	52700.00
E29403	2017-07-23 18:09:00+03	46000.00
E29405	2017-08-12 10:12:00+03	43400.00
E29457	2017-07-29 18:52:00+03	42600.00
E2945D	2017-07-18 05:23:00+03	24600.00
E29467	2017-07-25 10:19:00+03	14400.00
E294B2	2017-07-12 14:46:00+03	39300.00
E294C2	2017-07-11 19:35:00+03	6200.00
E294C6	2017-08-05 08:57:00+03	21800.00
E29564	2017-08-14 16:52:00+03	177200.00
E29568	2017-08-11 18:42:00+03	44600.00
E29598	2017-06-25 22:53:00+03	24400.00
E295BF	2017-07-06 13:11:00+03	111600.00
E2967D	2017-07-09 20:43:00+03	9800.00
E2967F	2017-07-30 11:22:00+03	187600.00
E2976C	2017-07-23 17:07:00+03	264000.00
E29799	2017-07-25 19:10:00+03	130200.00
E297A2	2017-07-27 05:36:00+03	6000.00
E29819	2017-07-17 21:03:00+03	36000.00
E29820	2017-08-12 16:04:00+03	7200.00
E29828	2017-07-24 10:33:00+03	50600.00
E29856	2017-08-02 14:53:00+03	229600.00
E298D1	2017-08-14 19:09:00+03	21800.00
E29929	2017-08-02 18:29:00+03	29600.00
E299AE	2017-06-30 23:08:00+03	13400.00
E299B1	2017-08-15 09:33:00+03	73500.00
E299DA	2017-08-07 02:57:00+03	31300.00
E29A5C	2017-08-15 16:50:00+03	59800.00
E29A63	2017-07-26 14:54:00+03	81700.00
E29A82	2017-07-30 22:56:00+03	22000.00
E29AA4	2017-08-03 23:07:00+03	54500.00
E29AA6	2017-07-18 20:41:00+03	398500.00
E29AE6	2017-08-06 13:55:00+03	46000.00
E29B0F	2017-07-14 22:06:00+03	38800.00
E29B5B	2017-07-20 18:22:00+03	95700.00
E29B92	2017-07-13 21:14:00+03	101200.00
E29BD4	2017-07-09 20:50:00+03	56000.00
E29C37	2017-08-08 13:33:00+03	14000.00
E29C52	2017-07-20 23:03:00+03	246000.00
E29C53	2017-07-04 05:17:00+03	44600.00
E29C63	2017-07-10 11:09:00+03	25000.00
E29C77	2017-07-15 18:33:00+03	42800.00
E29CDA	2017-08-06 07:11:00+03	76600.00
E29D08	2017-08-08 04:57:00+03	35200.00
E29D20	2017-07-24 07:58:00+03	53600.00
E29DBC	2017-07-22 10:46:00+03	144700.00
E29DCF	2017-07-30 22:45:00+03	58600.00
E29DDD	2017-07-14 17:26:00+03	6000.00
E29E37	2017-08-15 08:49:00+03	58600.00
E29E81	2017-07-05 08:05:00+03	48100.00
E29EBF	2017-07-16 18:44:00+03	37900.00
E29EF1	2017-07-15 01:27:00+03	90400.00
E29F4B	2017-07-17 10:31:00+03	8200.00
E29F68	2017-07-07 03:37:00+03	112600.00
E29F83	2017-08-10 08:06:00+03	89200.00
E29FDE	2017-07-31 18:43:00+03	65500.00
E2A000	2017-07-20 16:50:00+03	14000.00
E2A074	2017-07-25 23:20:00+03	125400.00
E2A0A1	2017-08-09 22:26:00+03	62600.00
E2A138	2017-07-21 20:13:00+03	76600.00
E2A13E	2017-07-21 22:27:00+03	135400.00
E2A183	2017-08-12 04:24:00+03	55800.00
E2A193	2017-07-26 13:26:00+03	99300.00
E2A1B2	2017-08-11 18:52:00+03	39600.00
E2A1C2	2017-08-02 08:09:00+03	173600.00
E2A209	2017-07-20 17:21:00+03	103500.00
E2A230	2017-07-26 11:44:00+03	99700.00
E2A263	2017-07-08 10:30:00+03	43500.00
E2A277	2017-07-10 18:25:00+03	46500.00
E2A2A4	2017-08-06 18:51:00+03	91000.00
E2A2CA	2017-08-06 09:06:00+03	26700.00
E2A336	2017-07-09 00:12:00+03	48800.00
E2A35C	2017-07-18 02:58:00+03	13800.00
E2A397	2017-07-10 19:34:00+03	24800.00
E2A3CC	2017-07-13 22:32:00+03	11000.00
E2A419	2017-08-10 07:41:00+03	39200.00
E2A427	2017-08-07 19:22:00+03	83200.00
E2A46F	2017-07-24 20:22:00+03	153300.00
E2A4A9	2017-08-10 16:28:00+03	110500.00
E2A4DA	2017-08-07 13:25:00+03	64700.00
E2A4FD	2017-07-27 13:27:00+03	148500.00
E2A553	2017-08-14 04:28:00+03	14400.00
E2A5DC	2017-08-05 14:11:00+03	80800.00
E2A64A	2017-07-24 16:35:00+03	28000.00
E2A69D	2017-07-13 02:23:00+03	63200.00
E2A798	2017-08-13 19:52:00+03	143100.00
E2A7C7	2017-07-15 09:39:00+03	47600.00
E2A82F	2017-07-09 12:55:00+03	67600.00
E2A878	2017-08-11 10:40:00+03	59800.00
E2A8C1	2017-07-21 19:00:00+03	15800.00
E2A95F	2017-07-27 15:53:00+03	16000.00
E2A9B5	2017-07-07 09:11:00+03	112000.00
E2A9B8	2017-07-31 07:10:00+03	281500.00
E2A9D0	2017-07-09 16:47:00+03	25200.00
E2AA81	2017-07-14 10:44:00+03	224000.00
E2AAC7	2017-07-24 07:51:00+03	75600.00
E2AAFF	2017-08-08 21:49:00+03	37900.00
E2AB83	2017-08-15 08:03:00+03	133700.00
E2ABAE	2017-07-15 02:19:00+03	22000.00
E2ACBE	2017-07-27 10:08:00+03	32200.00
E2AD20	2017-07-20 06:40:00+03	70700.00
E2AD2D	2017-07-21 00:19:00+03	18000.00
E2AD5B	2017-07-30 18:42:00+03	26000.00
E2ADD5	2017-07-07 12:07:00+03	92800.00
E2AE36	2017-07-05 14:11:00+03	14000.00
E2AEB2	2017-08-01 09:20:00+03	135600.00
E2AF46	2017-08-13 11:49:00+03	56000.00
E2AF4E	2017-08-14 07:16:00+03	16600.00
E2AF50	2017-07-01 18:34:00+03	14800.00
E2AF83	2017-07-13 21:30:00+03	272600.00
E2AFCB	2017-07-26 19:50:00+03	16400.00
E2AFFA	2017-08-02 16:09:00+03	47200.00
E2AFFE	2017-08-04 04:36:00+03	66600.00
E2B008	2017-07-29 01:08:00+03	129200.00
E2B070	2017-07-08 22:34:00+03	70100.00
E2B100	2017-07-26 18:34:00+03	49600.00
E2B101	2017-07-20 10:19:00+03	111600.00
E2B152	2017-07-25 14:02:00+03	131600.00
E2B15F	2017-07-27 20:13:00+03	8400.00
E2B164	2017-07-26 11:16:00+03	39600.00
E2B16D	2017-08-08 15:28:00+03	135400.00
E2B17D	2017-08-08 16:31:00+03	46200.00
E2B20E	2017-07-11 22:22:00+03	46000.00
E2B210	2017-08-11 00:45:00+03	304800.00
E2B22B	2017-07-19 21:28:00+03	173500.00
E2B22F	2017-08-13 09:57:00+03	57900.00
E2B252	2017-07-21 18:45:00+03	54400.00
E2B25D	2017-07-27 20:00:00+03	34000.00
E2B365	2017-07-11 23:42:00+03	123000.00
E2B41F	2017-07-16 03:26:00+03	27200.00
E2B480	2017-07-25 04:11:00+03	28800.00
E2B4C4	2017-08-02 06:28:00+03	23400.00
E2B4D1	2017-08-13 17:44:00+03	54100.00
E2B4DA	2017-07-26 21:34:00+03	46300.00
E2B4ED	2017-07-13 08:00:00+03	90000.00
E2B532	2017-06-30 17:52:00+03	87000.00
E2B572	2017-07-25 17:44:00+03	106400.00
E2B5E4	2017-07-26 13:03:00+03	47000.00
E2B616	2017-07-31 12:01:00+03	20400.00
E2B675	2017-07-09 19:36:00+03	26300.00
E2B676	2017-08-14 17:16:00+03	53100.00
E2B697	2017-08-09 19:50:00+03	139200.00
E2B6DE	2017-07-28 08:04:00+03	45100.00
E2B707	2017-08-03 13:02:00+03	127200.00
E2B713	2017-07-01 05:49:00+03	68000.00
E2B771	2017-08-15 03:26:00+03	44600.00
E2B77E	2017-08-06 15:10:00+03	54500.00
E2B79F	2017-07-21 09:55:00+03	67000.00
E2B7B7	2017-07-02 07:30:00+03	22400.00
E2B81A	2017-07-04 18:38:00+03	66000.00
E2B8FC	2017-08-02 13:24:00+03	54800.00
E2B922	2017-07-28 20:00:00+03	124300.00
E2B9A5	2017-08-01 21:22:00+03	94000.00
E2BA36	2017-08-07 02:21:00+03	68400.00
E2BA8A	2017-07-19 14:41:00+03	139200.00
E2BAAA	2017-07-22 19:01:00+03	108000.00
E2BAB8	2017-07-11 21:27:00+03	13800.00
E2BAC3	2017-07-23 08:30:00+03	32800.00
E2BAC7	2017-08-07 02:50:00+03	119800.00
E2BADF	2017-07-14 21:25:00+03	282000.00
E2BB2D	2017-08-06 11:08:00+03	91500.00
E2BB6C	2017-07-18 19:19:00+03	99300.00
E2BB80	2017-08-13 18:20:00+03	47100.00
E2BBA4	2017-07-16 12:59:00+03	88000.00
E2BBD1	2017-07-26 03:56:00+03	20600.00
E2BBE3	2017-08-01 18:12:00+03	176800.00
E2BC9C	2017-08-14 16:49:00+03	79800.00
E2BCA1	2017-08-05 09:13:00+03	31400.00
E2BCA5	2017-07-09 02:33:00+03	26000.00
E2BCE1	2017-07-31 09:02:00+03	37100.00
E2BCE2	2017-06-30 01:13:00+03	14800.00
E2BD0C	2017-07-29 05:53:00+03	37900.00
E2BD19	2017-08-07 19:09:00+03	258400.00
E2BD82	2017-08-02 01:21:00+03	236100.00
E2BD88	2017-07-14 00:22:00+03	48400.00
E2BD8B	2017-07-02 18:46:00+03	174800.00
E2BE56	2017-07-01 14:05:00+03	6300.00
E2BE62	2017-07-20 09:23:00+03	111700.00
E2BEA2	2017-08-14 22:37:00+03	132800.00
E2BEB8	2017-07-08 22:58:00+03	48400.00
E2BF17	2017-07-27 00:15:00+03	30800.00
E2BF67	2017-07-12 07:58:00+03	59800.00
E2BF76	2017-08-02 13:37:00+03	615000.00
E2C024	2017-07-21 23:22:00+03	58900.00
E2C05D	2017-08-06 14:30:00+03	7800.00
E2C088	2017-08-14 20:09:00+03	135600.00
E2C092	2017-07-17 11:04:00+03	28000.00
E2C0F8	2017-08-14 04:07:00+03	12600.00
E2C15B	2017-07-27 14:45:00+03	215500.00
E2C190	2017-08-08 20:06:00+03	92000.00
E2C1A7	2017-07-04 04:31:00+03	62800.00
E2C1A9	2017-07-11 07:34:00+03	143400.00
E2C1B5	2017-08-01 05:16:00+03	273000.00
E2C1EE	2017-08-03 13:52:00+03	85400.00
E2C213	2017-07-16 19:25:00+03	15100.00
E2C227	2017-07-09 22:24:00+03	295400.00
E2C2CB	2017-07-21 09:12:00+03	28800.00
E2C387	2017-08-07 14:57:00+03	15000.00
E2C424	2017-08-08 17:17:00+03	22000.00
E2C427	2017-07-20 06:24:00+03	51900.00
E2C44D	2017-08-09 11:22:00+03	73600.00
E2C4C5	2017-07-09 23:45:00+03	59800.00
E2C4E0	2017-07-18 18:13:00+03	32900.00
E2C54A	2017-07-16 07:37:00+03	63700.00
E2C568	2017-07-05 09:40:00+03	73500.00
E2C589	2017-08-02 12:15:00+03	48800.00
E2C60E	2017-07-05 09:01:00+03	35600.00
E2C61E	2017-07-14 22:36:00+03	357200.00
E2C66C	2017-07-29 22:19:00+03	39500.00
E2C69C	2017-08-07 07:29:00+03	257500.00
E2C6A1	2017-07-17 11:58:00+03	32800.00
E2C6BE	2017-07-17 09:09:00+03	13800.00
E2C6C1	2017-07-04 21:15:00+03	68100.00
E2C6E3	2017-07-22 11:48:00+03	50400.00
E2C73A	2017-08-08 00:22:00+03	16400.00
E2C767	2017-07-16 22:16:00+03	22400.00
E2C78A	2017-07-08 21:16:00+03	88400.00
E2C7C5	2017-07-03 11:33:00+03	27800.00
E2C7E3	2017-07-15 17:23:00+03	26700.00
E2C7F7	2017-08-10 07:03:00+03	92800.00
E2C815	2017-07-13 17:42:00+03	27300.00
E2C842	2017-08-11 18:02:00+03	48200.00
E2C848	2017-07-14 18:31:00+03	28000.00
E2C851	2017-07-26 09:44:00+03	67200.00
E2C886	2017-07-31 11:46:00+03	266400.00
E2C8CA	2017-07-22 09:38:00+03	86400.00
E2C8CB	2017-07-01 22:23:00+03	80900.00
E2C8F8	2017-08-15 05:49:00+03	18800.00
E2C916	2017-07-25 02:42:00+03	15200.00
E2C92E	2017-07-10 12:28:00+03	70500.00
E2C93E	2017-08-09 04:37:00+03	193900.00
E2C9AF	2017-07-09 10:49:00+03	133200.00
E2C9C8	2017-08-12 21:33:00+03	47200.00
E2C9EE	2017-07-17 00:02:00+03	65100.00
E2CA07	2017-07-16 21:40:00+03	6300.00
E2CA3B	2017-07-24 23:58:00+03	13000.00
E2CA4C	2017-07-18 03:31:00+03	36200.00
E2CA60	2017-07-25 00:51:00+03	67600.00
E2CA81	2017-08-06 01:06:00+03	85000.00
E2CABA	2017-07-31 04:42:00+03	55800.00
E2CB69	2017-07-30 06:46:00+03	65900.00
E2CB6A	2017-07-22 03:44:00+03	25400.00
E2CBD9	2017-08-11 20:37:00+03	66000.00
E2CBEE	2017-06-27 15:58:00+03	52100.00
E2CC04	2017-07-28 22:17:00+03	56000.00
E2CC09	2017-07-19 20:02:00+03	261400.00
E2CC20	2017-06-30 13:15:00+03	23600.00
E2CC70	2017-08-04 09:12:00+03	31900.00
E2CC85	2017-07-22 01:34:00+03	32700.00
E2CC88	2017-07-18 06:02:00+03	52700.00
E2CD08	2017-07-22 12:06:00+03	88500.00
E2CD13	2017-07-06 17:01:00+03	379600.00
E2CD5E	2017-08-13 18:48:00+03	29200.00
E2CD73	2017-08-12 13:12:00+03	56600.00
E2CDDE	2017-07-16 23:49:00+03	62000.00
E2CDFB	2017-07-17 19:34:00+03	66600.00
E2CE06	2017-07-01 07:23:00+03	102100.00
E2CEBC	2017-07-04 18:24:00+03	49500.00
E2CF40	2017-08-04 17:18:00+03	49600.00
E2CF84	2017-07-21 18:16:00+03	58000.00
E2CF91	2017-08-01 20:15:00+03	157500.00
E2CFBD	2017-07-26 23:38:00+03	69500.00
E2D012	2017-07-26 02:29:00+03	56000.00
E2D01C	2017-07-19 00:39:00+03	16400.00
E2D03C	2017-08-12 11:15:00+03	66600.00
E2D059	2017-08-04 15:44:00+03	177200.00
E2D08A	2017-07-25 22:02:00+03	64800.00
E2D0A9	2017-07-08 22:58:00+03	46900.00
E2D0B9	2017-08-11 00:29:00+03	38500.00
E2D0FC	2017-07-27 01:47:00+03	38600.00
E2D12B	2017-08-04 13:23:00+03	128800.00
E2D143	2017-07-05 03:33:00+03	55800.00
E2D1B3	2017-07-02 22:16:00+03	52300.00
E2D1C3	2017-06-29 07:06:00+03	152500.00
E2D246	2017-08-14 05:50:00+03	72400.00
E2D298	2017-07-29 09:56:00+03	23400.00
E2D29E	2017-07-23 13:39:00+03	75900.00
E2D305	2017-07-31 16:31:00+03	25900.00
E2D399	2017-07-03 10:23:00+03	73200.00
E2D3C5	2017-08-04 07:17:00+03	30900.00
E2D434	2017-07-21 14:38:00+03	75300.00
E2D435	2017-08-03 16:55:00+03	47200.00
E2D471	2017-07-27 22:10:00+03	112000.00
E2D47E	2017-08-13 20:15:00+03	26000.00
E2D481	2017-07-04 21:22:00+03	66300.00
E2D503	2017-07-08 08:10:00+03	15400.00
E2D517	2017-07-06 22:17:00+03	105600.00
E2D529	2017-07-02 14:05:00+03	6600.00
E2D574	2017-07-16 11:28:00+03	92400.00
E2D5AF	2017-07-09 03:59:00+03	175300.00
E2D5D4	2017-07-17 16:45:00+03	45100.00
E2D657	2017-07-13 18:27:00+03	25200.00
E2D671	2017-07-13 15:42:00+03	63800.00
E2D672	2017-07-19 15:05:00+03	52000.00
E2D77C	2017-07-29 01:49:00+03	56900.00
E2D781	2017-07-20 12:05:00+03	28800.00
E2D7E4	2017-07-30 21:05:00+03	111700.00
E2D813	2017-08-13 20:50:00+03	27300.00
E2D848	2017-08-03 04:21:00+03	175000.00
E2D858	2017-07-04 07:10:00+03	46000.00
E2D8CD	2017-07-30 17:59:00+03	34000.00
E2D91C	2017-08-15 11:02:00+03	145600.00
E2D920	2017-07-24 17:19:00+03	28300.00
E2D969	2017-08-05 12:48:00+03	43100.00
E2D9FA	2017-07-11 05:41:00+03	40800.00
E2DA20	2017-07-07 20:38:00+03	94300.00
E2DA4E	2017-08-02 03:12:00+03	26000.00
E2DAD8	2017-07-09 02:29:00+03	57600.00
E2DAE1	2017-07-08 05:41:00+03	113700.00
E2DB51	2017-07-05 02:29:00+03	73300.00
E2DB67	2017-07-19 04:47:00+03	14000.00
E2DBAC	2017-07-27 04:26:00+03	123000.00
E2DBEE	2017-08-03 20:47:00+03	54400.00
E2DC08	2017-07-27 21:21:00+03	23200.00
E2DC42	2017-07-18 17:25:00+03	114800.00
E2DC74	2017-07-21 08:30:00+03	64700.00
E2DC84	2017-08-08 18:39:00+03	112000.00
E2DD2E	2017-07-18 19:53:00+03	92000.00
E2DD8B	2017-07-09 13:43:00+03	139300.00
E2DD93	2017-07-18 18:18:00+03	36200.00
E2DDAF	2017-07-22 14:15:00+03	21700.00
E2DDD0	2017-07-25 16:23:00+03	67600.00
E2DDDC	2017-08-03 21:48:00+03	55800.00
E2DDE3	2017-08-02 10:46:00+03	61800.00
E2DE8E	2017-07-02 12:55:00+03	32800.00
E2DF04	2017-07-30 00:41:00+03	3400.00
E2DF31	2017-08-11 18:40:00+03	8200.00
E2DF8B	2017-06-29 15:15:00+03	57800.00
E2DF96	2017-07-10 21:07:00+03	98400.00
E2DFCC	2017-07-23 09:10:00+03	126300.00
E2E032	2017-07-20 23:11:00+03	31200.00
E2E063	2017-06-30 08:44:00+03	107000.00
E2E0CA	2017-08-08 20:20:00+03	325500.00
E2E1F5	2017-08-13 07:00:00+03	142800.00
E2E225	2017-07-06 20:20:00+03	64800.00
E2E241	2017-07-15 08:04:00+03	242300.00
E2E294	2017-08-07 19:21:00+03	51800.00
E2E2DB	2017-08-09 11:20:00+03	30900.00
E2E300	2017-08-02 02:32:00+03	117700.00
E2E391	2017-08-02 22:56:00+03	100400.00
E2E3B4	2017-06-29 15:33:00+03	107200.00
E2E3F8	2017-06-27 17:04:00+03	133900.00
E2E41B	2017-07-04 22:16:00+03	69600.00
E2E421	2017-07-09 14:12:00+03	170500.00
E2E443	2017-08-15 11:18:00+03	62000.00
E2E467	2017-07-13 20:27:00+03	85500.00
E2E472	2017-06-30 18:49:00+03	9800.00
E2E4AB	2017-08-10 04:16:00+03	58900.00
E2E535	2017-08-15 00:25:00+03	25000.00
E2E536	2017-07-25 14:47:00+03	430500.00
E2E57C	2017-07-20 23:53:00+03	64400.00
E2E5C8	2017-08-03 00:07:00+03	16400.00
E2E633	2017-07-14 23:46:00+03	28000.00
E2E643	2017-07-01 16:10:00+03	246000.00
E2E6F0	2017-07-08 19:55:00+03	17800.00
E2E6F9	2017-08-07 10:59:00+03	23200.00
E2E72F	2017-07-03 22:53:00+03	83400.00
E2E734	2017-07-15 19:46:00+03	12600.00
E2E76D	2017-07-20 08:10:00+03	15000.00
E2E7DE	2017-08-10 19:37:00+03	521200.00
E2E7E6	2017-08-04 22:30:00+03	123000.00
E2E884	2017-08-07 05:04:00+03	13400.00
E2E886	2017-07-05 11:44:00+03	170000.00
E2E8A0	2017-07-20 10:47:00+03	123000.00
E2E8A6	2017-08-14 07:50:00+03	25600.00
E2E8DE	2017-07-11 05:05:00+03	65300.00
E2E8EA	2017-07-05 08:33:00+03	47500.00
E2E8EB	2017-07-05 14:17:00+03	94400.00
E2E955	2017-07-04 17:27:00+03	44000.00
E2E994	2017-07-25 16:47:00+03	131100.00
E2E9A1	2017-07-17 12:47:00+03	52700.00
E2E9E0	2017-08-14 07:18:00+03	40100.00
E2EA06	2017-07-13 14:09:00+03	44800.00
E2EAAF	2017-07-17 00:37:00+03	36200.00
E2EB0D	2017-07-15 01:00:00+03	62600.00
E2EB2C	2017-08-15 00:43:00+03	55800.00
E2EB30	2017-07-24 03:14:00+03	167400.00
E2EB59	2017-08-11 01:07:00+03	81300.00
E2EBB6	2017-08-03 11:57:00+03	131100.00
E2EBDA	2017-07-05 00:35:00+03	66600.00
E2EBDD	2017-07-22 01:51:00+03	23600.00
E2EC64	2017-07-09 16:17:00+03	6700.00
E2ECB1	2017-07-26 19:47:00+03	35800.00
E2ECC7	2017-08-04 04:49:00+03	55800.00
E2ECD9	2017-07-19 01:42:00+03	30000.00
E2EDC3	2017-07-31 06:02:00+03	28000.00
E2EE38	2017-08-08 05:26:00+03	14000.00
E2EE52	2017-08-01 17:18:00+03	34000.00
E2EE72	2017-07-06 09:27:00+03	12600.00
E2EEC9	2017-07-09 07:48:00+03	22200.00
E2EF67	2017-07-05 14:22:00+03	32800.00
E2EF6C	2017-07-28 08:20:00+03	75300.00
E2EF6D	2017-07-15 07:57:00+03	58800.00
E2F07D	2017-07-29 02:23:00+03	125200.00
E2F14B	2017-07-11 13:16:00+03	111600.00
E2F14D	2017-07-25 21:33:00+03	40200.00
E2F15A	2017-08-09 12:25:00+03	131100.00
E2F189	2017-07-12 22:33:00+03	50000.00
E2F241	2017-07-30 17:45:00+03	28000.00
E2F261	2017-07-11 23:07:00+03	54500.00
E2F26D	2017-07-19 20:43:00+03	100300.00
E2F272	2017-07-10 12:22:00+03	158000.00
E2F2BA	2017-07-08 06:38:00+03	32200.00
E2F2C5	2017-07-14 10:34:00+03	75300.00
E2F2DB	2017-08-12 11:44:00+03	70200.00
E2F2F2	2017-07-17 02:04:00+03	25200.00
E2F33E	2017-07-16 08:00:00+03	18600.00
E2F358	2017-07-13 05:58:00+03	67900.00
E2F3B2	2017-08-14 10:17:00+03	18400.00
E2F3C2	2017-07-25 02:28:00+03	47600.00
E2F40F	2017-07-07 16:55:00+03	89700.00
E2F438	2017-07-10 08:14:00+03	42900.00
E2F466	2017-07-30 02:52:00+03	18000.00
E2F476	2017-07-27 23:29:00+03	204100.00
E2F491	2017-07-10 23:25:00+03	51600.00
E2F4C0	2017-07-28 09:13:00+03	28800.00
E2F4DC	2017-07-18 05:14:00+03	62700.00
E2F565	2017-07-06 19:56:00+03	16400.00
E2F57D	2017-07-29 06:30:00+03	48100.00
E2F5E0	2017-07-18 03:44:00+03	51900.00
E2F623	2017-07-31 22:26:00+03	92800.00
E2F636	2017-08-14 16:40:00+03	24200.00
E2F63A	2017-07-15 05:27:00+03	67600.00
E2F6AA	2017-08-09 03:54:00+03	133900.00
E2F6FF	2017-07-02 02:49:00+03	55800.00
E2F726	2017-07-19 17:47:00+03	26500.00
E2F781	2017-08-05 11:11:00+03	137000.00
E2F7B8	2017-08-11 04:00:00+03	53600.00
E2F7FA	2017-07-25 00:57:00+03	206400.00
E2F807	2017-08-14 01:45:00+03	44000.00
E2F866	2017-07-09 07:20:00+03	25000.00
E2F867	2017-07-17 06:16:00+03	76400.00
E2F8FE	2017-08-07 06:37:00+03	136400.00
E2F913	2017-07-05 07:37:00+03	70500.00
E2F950	2017-08-05 02:08:00+03	92800.00
E2FA1F	2017-07-25 04:33:00+03	12000.00
E2FA48	2017-08-11 13:53:00+03	78300.00
E2FA56	2017-08-08 06:56:00+03	13400.00
E2FA66	2017-07-13 12:39:00+03	28000.00
E2FA75	2017-07-09 08:45:00+03	95600.00
E2FA78	2017-08-13 21:30:00+03	496700.00
E2FAAF	2017-07-16 02:04:00+03	58500.00
E2FAF3	2017-08-07 13:46:00+03	45500.00
E2FB8A	2017-07-17 05:21:00+03	81600.00
E2FB9C	2017-07-01 23:41:00+03	56300.00
E2FCB7	2017-07-31 16:37:00+03	70700.00
E2FCD2	2017-08-08 17:29:00+03	28800.00
E2FD69	2017-07-25 09:37:00+03	48500.00
E2FDD2	2017-08-09 12:03:00+03	189200.00
E2FDF7	2017-07-18 11:30:00+03	43000.00
E2FE10	2017-07-02 01:20:00+03	89700.00
E2FE3F	2017-07-18 16:33:00+03	89700.00
E2FE8D	2017-07-17 07:56:00+03	90400.00
E2FED3	2017-07-07 01:09:00+03	56000.00
E2FF00	2017-08-10 16:26:00+03	28000.00
E2FF4A	2017-07-07 09:19:00+03	131600.00
E2FF56	2017-08-15 10:42:00+03	90400.00
E2FF7C	2017-08-10 06:43:00+03	40000.00
E2FFE2	2017-07-28 06:55:00+03	114800.00
E30052	2017-07-08 17:05:00+03	30800.00
E300AB	2017-07-29 16:31:00+03	109200.00
E300AC	2017-08-01 11:59:00+03	40800.00
E300BE	2017-07-02 20:26:00+03	38600.00
E30123	2017-07-26 05:48:00+03	36800.00
E3012C	2017-08-08 14:14:00+03	29600.00
E3020C	2017-08-01 05:12:00+03	99200.00
E30297	2017-08-02 12:30:00+03	54900.00
E30298	2017-07-02 03:49:00+03	57400.00
E302D4	2017-07-06 11:30:00+03	75300.00
E30301	2017-07-17 12:40:00+03	179400.00
E30390	2017-07-24 11:00:00+03	112200.00
E30402	2017-07-19 23:05:00+03	289600.00
E3041A	2017-07-09 06:06:00+03	43400.00
E3043F	2017-06-30 23:22:00+03	85000.00
E3044B	2017-08-10 16:00:00+03	58800.00
E30462	2017-07-19 00:32:00+03	270800.00
E3048D	2017-07-21 06:50:00+03	25100.00
E30493	2017-07-10 19:03:00+03	155400.00
E304F8	2017-06-27 19:43:00+03	97800.00
E30507	2017-07-14 09:25:00+03	59800.00
E305B8	2017-07-04 17:01:00+03	25200.00
E305E9	2017-08-14 04:52:00+03	28800.00
E30637	2017-07-11 23:52:00+03	99600.00
E306B0	2017-07-29 11:58:00+03	74900.00
E30719	2017-08-04 08:13:00+03	67600.00
E30841	2017-08-12 11:49:00+03	266200.00
E30863	2017-08-12 12:55:00+03	8200.00
E308A4	2017-08-14 08:32:00+03	31400.00
E308A9	2017-08-12 16:41:00+03	120100.00
E308CF	2017-07-10 12:13:00+03	7400.00
E308F1	2017-07-04 00:40:00+03	76600.00
E3098C	2017-08-03 22:16:00+03	96400.00
E309EA	2017-07-31 07:01:00+03	112000.00
E309F5	2017-07-10 17:00:00+03	23400.00
E30A3B	2017-07-24 10:52:00+03	26200.00
E30A4B	2017-08-15 02:33:00+03	44400.00
E30A9E	2017-07-18 08:47:00+03	23600.00
E30AAA	2017-07-27 00:46:00+03	10700.00
E30ACF	2017-07-25 14:36:00+03	651900.00
E30AD4	2017-07-15 18:01:00+03	45100.00
E30AFD	2017-07-08 11:14:00+03	92700.00
E30B24	2017-07-20 22:11:00+03	33800.00
E30B37	2017-06-28 22:52:00+03	22600.00
E30B7D	2017-07-12 17:40:00+03	6800.00
E30C2A	2017-08-05 15:50:00+03	65600.00
E30C30	2017-07-28 22:48:00+03	51900.00
E30C70	2017-08-08 05:13:00+03	20000.00
E30CFF	2017-07-20 15:07:00+03	73600.00
E30D41	2017-07-01 04:23:00+03	28000.00
E30DA3	2017-07-22 14:02:00+03	225200.00
E30DE6	2017-08-09 07:00:00+03	23600.00
E30DF3	2017-08-04 01:51:00+03	246000.00
E30E4B	2017-06-28 16:31:00+03	44600.00
E30E50	2017-07-04 02:45:00+03	136800.00
E30EB4	2017-08-01 19:48:00+03	36200.00
E30EB5	2017-07-05 21:19:00+03	133100.00
E30F45	2017-07-04 07:02:00+03	41600.00
E30F86	2017-08-06 04:22:00+03	56600.00
E3100A	2017-07-31 13:14:00+03	37100.00
E31084	2017-07-15 06:26:00+03	14000.00
E31113	2017-07-04 08:15:00+03	27900.00
E3114A	2017-08-15 10:15:00+03	36100.00
E31192	2017-07-23 10:39:00+03	63300.00
E311F4	2017-07-22 11:12:00+03	140400.00
E31203	2017-07-11 14:29:00+03	9200.00
E31221	2017-08-09 20:39:00+03	145000.00
E31222	2017-08-02 12:26:00+03	121700.00
E31263	2017-08-11 18:48:00+03	47400.00
E3126C	2017-07-29 07:58:00+03	10700.00
E31275	2017-07-19 14:41:00+03	542200.00
E31309	2017-07-08 01:09:00+03	47400.00
E3133D	2017-07-24 07:27:00+03	43200.00
E313EC	2017-08-04 15:29:00+03	14000.00
E3141E	2017-08-08 22:52:00+03	23600.00
E314A3	2017-08-01 22:15:00+03	97900.00
E314FA	2017-06-30 03:15:00+03	19500.00
E31586	2017-07-25 14:07:00+03	38200.00
E315B1	2017-07-07 23:24:00+03	59800.00
E315FF	2017-07-07 08:28:00+03	55800.00
E31654	2017-07-16 01:35:00+03	59300.00
E316A3	2017-08-12 08:05:00+03	32800.00
E316B6	2017-07-29 08:04:00+03	71800.00
E316DC	2017-07-29 02:56:00+03	75600.00
E31712	2017-08-14 17:14:00+03	147100.00
E31751	2017-06-30 08:55:00+03	68800.00
E3175F	2017-07-03 02:32:00+03	93700.00
E31775	2017-07-12 05:23:00+03	88200.00
E317BB	2017-07-30 21:50:00+03	160700.00
E317CC	2017-08-06 09:05:00+03	149700.00
E317DF	2017-07-16 06:44:00+03	6700.00
E31879	2017-07-13 05:12:00+03	62600.00
E31887	2017-07-14 06:46:00+03	201200.00
E318D4	2017-07-19 23:52:00+03	59800.00
E3198F	2017-07-29 02:14:00+03	28800.00
E319B2	2017-07-10 19:08:00+03	38800.00
E319FE	2017-07-20 19:34:00+03	325800.00
E31A25	2017-07-05 00:44:00+03	47400.00
E31A91	2017-07-23 04:23:00+03	23200.00
E31B55	2017-07-25 20:46:00+03	62800.00
E31B5E	2017-08-01 19:19:00+03	52800.00
E31B7A	2017-08-15 01:18:00+03	47400.00
E31BA9	2017-07-09 04:06:00+03	26000.00
E31BD4	2017-07-22 09:23:00+03	46200.00
E31BF6	2017-07-08 02:15:00+03	43200.00
E31C17	2017-07-20 10:37:00+03	21800.00
E31C62	2017-07-19 00:22:00+03	145100.00
E31CC7	2017-08-08 15:44:00+03	39800.00
E31CCF	2017-07-22 10:27:00+03	17200.00
E31CE1	2017-07-26 13:58:00+03	446100.00
E31D24	2017-07-01 07:07:00+03	23600.00
E31DAE	2017-08-05 13:36:00+03	112000.00
E31E2E	2017-07-20 00:05:00+03	14300.00
E31EBE	2017-07-24 07:15:00+03	18600.00
E31EC7	2017-08-02 14:02:00+03	6300.00
E31EC8	2017-08-15 05:43:00+03	85000.00
E31ED2	2017-08-02 11:28:00+03	26000.00
E31F40	2017-07-19 09:50:00+03	50800.00
E31F66	2017-07-21 03:35:00+03	52800.00
E31FBF	2017-07-27 22:59:00+03	21200.00
E32069	2017-07-16 15:37:00+03	15100.00
E32087	2017-07-28 01:11:00+03	30400.00
E320CD	2017-07-24 06:48:00+03	202300.00
E32109	2017-07-19 13:36:00+03	50800.00
E3212F	2017-07-31 04:13:00+03	100200.00
E3217D	2017-08-11 14:18:00+03	58000.00
E321AA	2017-07-08 14:58:00+03	307500.00
E321B1	2017-08-11 20:02:00+03	46300.00
E321D7	2017-07-24 00:14:00+03	160000.00
E321FE	2017-08-04 03:06:00+03	88000.00
E32247	2017-07-17 00:28:00+03	100200.00
E32285	2017-07-15 18:46:00+03	75300.00
E3230A	2017-07-05 21:19:00+03	133200.00
E32312	2017-08-04 16:22:00+03	65200.00
E323E5	2017-08-01 09:39:00+03	30600.00
E3245B	2017-08-05 13:16:00+03	115500.00
E32460	2017-07-04 05:46:00+03	47200.00
E32477	2017-08-06 15:48:00+03	24800.00
E32519	2017-07-25 08:25:00+03	80200.00
E3251E	2017-08-03 23:02:00+03	139300.00
E32574	2017-07-09 00:07:00+03	179500.00
E3257A	2017-07-26 08:29:00+03	92800.00
E32621	2017-07-31 15:16:00+03	92600.00
E32633	2017-07-06 05:31:00+03	68800.00
E32678	2017-07-01 04:52:00+03	130500.00
E3267F	2017-08-12 04:23:00+03	8000.00
E32694	2017-06-29 13:53:00+03	78300.00
E32712	2017-07-25 08:02:00+03	243600.00
E3280F	2017-07-16 13:48:00+03	61800.00
E32839	2017-08-04 13:48:00+03	97700.00
E3283D	2017-08-05 20:43:00+03	71000.00
E32841	2017-07-12 13:19:00+03	28000.00
E3287D	2017-07-17 08:37:00+03	45700.00
E32882	2017-07-04 13:44:00+03	492000.00
E3288D	2017-07-24 17:21:00+03	49800.00
E328BF	2017-07-24 00:48:00+03	67300.00
E328FD	2017-08-09 13:08:00+03	10800.00
E32902	2017-07-30 07:31:00+03	97400.00
E32912	2017-08-06 00:52:00+03	31600.00
E3293E	2017-07-24 23:37:00+03	39200.00
E3298E	2017-07-11 00:49:00+03	138600.00
E329A7	2017-08-11 23:24:00+03	48900.00
E32A08	2017-08-03 07:05:00+03	113700.00
E32AEA	2017-08-13 00:42:00+03	11000.00
E32AEC	2017-08-09 22:12:00+03	101100.00
E32B18	2017-07-05 15:19:00+03	46900.00
E32B5F	2017-07-30 02:51:00+03	154500.00
E32B78	2017-07-18 11:39:00+03	23200.00
E32B92	2017-07-03 05:58:00+03	182300.00
E32BB5	2017-08-09 18:44:00+03	82900.00
E32BB6	2017-07-20 10:56:00+03	14800.00
E32BF4	2017-08-07 19:14:00+03	47800.00
E32BFD	2017-08-11 13:36:00+03	24800.00
E32C63	2017-08-07 20:46:00+03	6600.00
E32C65	2017-07-30 07:10:00+03	98400.00
E32C85	2017-08-05 12:58:00+03	81500.00
E32C98	2017-07-12 14:35:00+03	14800.00
E32D01	2017-07-16 07:56:00+03	124100.00
E32D33	2017-07-08 14:30:00+03	657200.00
E32D58	2017-07-31 06:40:00+03	60700.00
E32DA7	2017-07-19 20:30:00+03	72600.00
E32DD6	2017-07-28 16:19:00+03	24400.00
E32DF9	2017-07-05 16:10:00+03	68800.00
E32E02	2017-08-01 03:33:00+03	74800.00
E32E25	2017-07-10 17:35:00+03	28000.00
E32E5B	2017-07-29 21:38:00+03	29600.00
E32E73	2017-08-15 01:04:00+03	88100.00
E32E95	2017-07-05 11:59:00+03	13400.00
E32ED7	2017-07-12 06:29:00+03	79600.00
E32EE9	2017-07-27 12:44:00+03	16400.00
E32EFA	2017-07-29 11:47:00+03	47800.00
E32FD9	2017-07-12 10:54:00+03	135400.00
E32FEC	2017-07-23 11:45:00+03	51600.00
E3309B	2017-07-09 11:57:00+03	85000.00
E330D7	2017-07-19 17:47:00+03	62600.00
E330E5	2017-08-08 15:47:00+03	55800.00
E3311C	2017-07-10 09:11:00+03	64800.00
E3314A	2017-07-18 08:26:00+03	95600.00
E33163	2017-07-05 15:08:00+03	89200.00
E331DA	2017-07-04 10:28:00+03	27000.00
E331FD	2017-07-23 15:03:00+03	6000.00
E3326B	2017-08-01 22:16:00+03	98400.00
E33308	2017-07-28 07:16:00+03	52700.00
E3338D	2017-08-10 13:16:00+03	26800.00
E333AA	2017-06-28 12:30:00+03	145900.00
E333AD	2017-07-24 17:10:00+03	17800.00
E33486	2017-07-09 06:20:00+03	372500.00
E33488	2017-07-20 09:25:00+03	135100.00
E334F1	2017-07-13 11:09:00+03	102100.00
E3354E	2017-07-10 07:44:00+03	62800.00
E33596	2017-07-06 07:31:00+03	16800.00
E3360B	2017-07-16 02:51:00+03	258400.00
E3364B	2017-07-17 13:12:00+03	111600.00
E336FA	2017-07-13 07:29:00+03	144400.00
E33745	2017-08-08 05:37:00+03	19600.00
E338C3	2017-08-15 00:42:00+03	65400.00
E3399B	2017-08-07 07:39:00+03	15800.00
E339F2	2017-07-15 16:31:00+03	28800.00
E33A6B	2017-07-06 17:08:00+03	61800.00
E33AF9	2017-07-30 23:44:00+03	13200.00
E33B83	2017-07-30 04:46:00+03	38400.00
E33BCF	2017-07-08 02:07:00+03	193600.00
E33C03	2017-07-29 06:29:00+03	40000.00
E33C20	2017-06-27 15:59:00+03	92800.00
E33C25	2017-07-30 14:46:00+03	85000.00
E33C50	2017-08-12 00:22:00+03	54600.00
E33C6D	2017-08-10 11:44:00+03	34000.00
E33CF8	2017-07-09 08:31:00+03	116400.00
E33D06	2017-08-11 12:20:00+03	75600.00
E33D46	2017-07-27 23:40:00+03	27200.00
E33D9E	2017-08-02 04:49:00+03	12000.00
E33DA0	2017-07-19 00:48:00+03	21400.00
E33DD4	2017-07-06 03:12:00+03	380700.00
E33E09	2017-08-05 09:10:00+03	25100.00
E33E13	2017-08-14 15:57:00+03	21600.00
E33E2B	2017-07-06 15:24:00+03	99800.00
E33E4F	2017-07-02 01:07:00+03	6700.00
E33E67	2017-07-29 21:58:00+03	51900.00
E33E9B	2017-08-12 04:20:00+03	6700.00
E33F75	2017-07-29 20:00:00+03	64500.00
E33FDF	2017-08-04 13:06:00+03	137100.00
E34070	2017-07-19 11:07:00+03	46400.00
E34091	2017-08-12 07:22:00+03	42400.00
E34095	2017-07-09 01:48:00+03	101200.00
E340C9	2017-08-08 20:26:00+03	123000.00
E340CF	2017-08-04 15:08:00+03	32700.00
E341D1	2017-08-15 00:31:00+03	153100.00
E34248	2017-08-09 15:39:00+03	24800.00
E34252	2017-08-11 21:06:00+03	92600.00
E343A8	2017-08-01 14:51:00+03	46000.00
E343CA	2017-07-14 06:34:00+03	24700.00
E3443F	2017-07-12 13:11:00+03	45100.00
E344A6	2017-07-18 14:09:00+03	78500.00
E344C1	2017-07-19 18:41:00+03	92800.00
E34543	2017-08-05 10:58:00+03	87200.00
E3454D	2017-07-21 10:48:00+03	123000.00
E34597	2017-07-18 02:01:00+03	6700.00
E3462C	2017-07-25 21:44:00+03	28800.00
E346A1	2017-07-05 14:17:00+03	296700.00
E346C9	2017-08-05 00:12:00+03	136800.00
E34723	2017-08-07 08:00:00+03	46700.00
E34752	2017-07-25 07:54:00+03	71100.00
E347A8	2017-08-12 06:10:00+03	15800.00
E34848	2017-07-02 23:54:00+03	100000.00
E3487B	2017-07-29 14:48:00+03	393800.00
E34888	2017-08-12 20:31:00+03	48800.00
E348F1	2017-07-27 18:16:00+03	67200.00
E34917	2017-07-20 20:54:00+03	37900.00
E3491F	2017-08-12 05:00:00+03	38600.00
E34920	2017-07-11 08:41:00+03	251700.00
E34940	2017-07-05 17:48:00+03	55800.00
E349A3	2017-06-30 22:38:00+03	63500.00
E349CF	2017-07-16 11:31:00+03	29500.00
E34A3B	2017-07-05 23:35:00+03	496600.00
E34A8D	2017-07-27 12:02:00+03	35200.00
E34A98	2017-07-14 00:45:00+03	74400.00
E34A99	2017-07-08 08:08:00+03	23400.00
E34A9F	2017-07-27 14:37:00+03	28000.00
E34AA3	2017-08-04 04:15:00+03	24400.00
E34B83	2017-07-18 11:08:00+03	64600.00
E34BF4	2017-07-07 19:26:00+03	133600.00
E34C04	2017-07-16 06:48:00+03	65000.00
E34C85	2017-07-23 09:49:00+03	99300.00
E34C9D	2017-07-05 04:05:00+03	13400.00
E34D2A	2017-07-10 17:01:00+03	55800.00
E34D7E	2017-08-02 00:04:00+03	6000.00
E34D9F	2017-08-15 04:50:00+03	58700.00
E34E0E	2017-07-09 16:21:00+03	48800.00
E34E76	2017-07-30 04:03:00+03	64300.00
E34EAF	2017-07-19 11:08:00+03	119300.00
E34EE9	2017-07-16 17:57:00+03	59300.00
E34EFD	2017-08-07 00:09:00+03	139000.00
E34F74	2017-08-15 01:31:00+03	111600.00
E34F76	2017-07-29 18:44:00+03	133200.00
E34F78	2017-07-15 11:18:00+03	155600.00
E34F88	2017-07-14 01:08:00+03	233000.00
E34F9D	2017-08-15 09:40:00+03	66000.00
E34FE6	2017-07-04 11:43:00+03	18800.00
E34FE9	2017-07-20 22:49:00+03	246000.00
E35073	2017-07-23 06:45:00+03	124200.00
E350E9	2017-08-11 12:34:00+03	10100.00
E3512B	2017-07-30 03:59:00+03	12000.00
E3513E	2017-07-27 16:50:00+03	50700.00
E35188	2017-08-02 09:07:00+03	94000.00
E351EA	2017-07-23 00:23:00+03	59800.00
E3520B	2017-08-05 05:37:00+03	119500.00
E35225	2017-07-11 19:30:00+03	61500.00
E352AC	2017-07-31 04:54:00+03	23600.00
E352C6	2017-08-05 18:15:00+03	114800.00
E35401	2017-07-11 10:40:00+03	44800.00
E35403	2017-08-08 12:25:00+03	46400.00
E3540D	2017-06-28 10:41:00+03	29600.00
E3542F	2017-08-14 01:05:00+03	66700.00
E35476	2017-07-18 18:27:00+03	174600.00
E354EF	2017-07-15 13:56:00+03	37100.00
E35509	2017-07-29 16:08:00+03	20400.00
E35577	2017-07-23 13:02:00+03	56000.00
E35592	2017-07-23 12:39:00+03	125200.00
E355B4	2017-08-07 09:38:00+03	30400.00
E355BA	2017-07-29 13:59:00+03	131100.00
E355D8	2017-07-20 19:46:00+03	55800.00
E35603	2017-07-30 18:05:00+03	103600.00
E35611	2017-08-14 00:41:00+03	55100.00
E3566C	2017-08-13 02:05:00+03	13600.00
E356EB	2017-07-29 18:16:00+03	204200.00
E356FD	2017-07-04 18:07:00+03	52400.00
E35731	2017-07-29 17:14:00+03	99300.00
E357D4	2017-07-19 00:17:00+03	136100.00
E357DE	2017-08-13 06:03:00+03	87900.00
E3585E	2017-08-05 05:51:00+03	102100.00
E3588C	2017-07-31 15:11:00+03	67100.00
E358B8	2017-07-09 04:25:00+03	73900.00
E358C3	2017-08-12 21:27:00+03	28000.00
E358D6	2017-06-29 00:08:00+03	28000.00
E358DD	2017-07-28 14:20:00+03	86500.00
E358EE	2017-07-27 09:14:00+03	14400.00
E35963	2017-07-06 10:40:00+03	16400.00
E359A2	2017-07-17 21:40:00+03	31100.00
E359A3	2017-08-04 12:16:00+03	47000.00
E359DA	2017-08-09 20:53:00+03	81600.00
E35A3C	2017-07-27 10:42:00+03	117200.00
E35A42	2017-07-07 23:16:00+03	94000.00
E35A49	2017-07-09 11:26:00+03	9800.00
E35A7E	2017-07-05 18:25:00+03	33000.00
E35AA4	2017-07-29 10:36:00+03	16400.00
E35AAC	2017-07-17 11:09:00+03	41300.00
E35AD1	2017-07-26 10:32:00+03	92000.00
E35AD3	2017-07-14 17:48:00+03	68800.00
E35AE1	2017-08-12 02:15:00+03	85000.00
E35AFD	2017-07-30 16:53:00+03	68400.00
E35B15	2017-07-06 19:26:00+03	21400.00
E35B29	2017-08-13 23:01:00+03	55600.00
E35B88	2017-07-19 18:23:00+03	26100.00
E35BAE	2017-07-11 08:39:00+03	43200.00
E35BCE	2017-07-27 07:20:00+03	413400.00
E35C54	2017-07-17 19:49:00+03	73600.00
E35C5B	2017-07-04 20:15:00+03	26200.00
E35C89	2017-08-10 21:01:00+03	58000.00
E35CDE	2017-08-05 09:34:00+03	28000.00
E35CFF	2017-07-07 19:27:00+03	26000.00
E35D76	2017-07-14 20:39:00+03	73200.00
E35DDF	2017-07-06 09:52:00+03	22200.00
E35DFD	2017-08-09 06:55:00+03	47400.00
E35E3E	2017-07-03 16:21:00+03	265800.00
E35E81	2017-08-08 17:02:00+03	8200.00
E35E96	2017-07-26 04:19:00+03	19600.00
E35EB4	2017-08-09 13:35:00+03	27400.00
E35EF9	2017-08-13 15:28:00+03	25600.00
E35EFA	2017-07-24 10:23:00+03	23600.00
E35F61	2017-07-11 09:12:00+03	23200.00
E35F62	2017-08-06 03:28:00+03	102100.00
E35F6C	2017-08-12 02:27:00+03	13400.00
E35FCE	2017-08-09 08:36:00+03	66300.00
E35FEC	2017-07-12 15:26:00+03	130300.00
E35FFB	2017-07-13 08:16:00+03	253800.00
E36054	2017-07-18 04:30:00+03	69500.00
E3609F	2017-08-09 20:00:00+03	24600.00
E36196	2017-06-27 14:02:00+03	121400.00
E361EF	2017-07-17 22:38:00+03	28000.00
E36237	2017-07-14 09:12:00+03	193100.00
E362A8	2017-07-19 07:25:00+03	21400.00
E362CD	2017-08-07 12:16:00+03	39300.00
E362E6	2017-07-16 01:24:00+03	45200.00
E362ED	2017-06-29 17:23:00+03	113000.00
E362F3	2017-07-12 09:33:00+03	84500.00
E362FC	2017-07-28 21:32:00+03	28800.00
E36300	2017-08-06 13:39:00+03	13400.00
E363C4	2017-07-31 12:14:00+03	57800.00
E363EE	2017-07-06 02:44:00+03	136500.00
E36486	2017-07-15 18:51:00+03	42800.00
E3648B	2017-08-15 12:44:00+03	58000.00
E364C9	2017-07-24 19:22:00+03	23600.00
E364FB	2017-07-05 23:44:00+03	56900.00
E36510	2017-07-30 00:49:00+03	202400.00
E36515	2017-08-03 14:57:00+03	86200.00
E36524	2017-07-11 16:12:00+03	52100.00
E36531	2017-07-05 11:45:00+03	44000.00
E3653D	2017-08-11 09:27:00+03	92000.00
E36584	2017-07-20 04:51:00+03	54600.00
E3658C	2017-08-05 22:24:00+03	37700.00
E365E6	2017-07-15 20:36:00+03	246000.00
E3667B	2017-08-09 03:50:00+03	76400.00
E3667D	2017-07-13 22:52:00+03	84800.00
E366BB	2017-07-10 23:18:00+03	42700.00
E366C8	2017-07-26 02:08:00+03	143400.00
E366E3	2017-08-03 06:59:00+03	106400.00
E36751	2017-06-30 20:11:00+03	131800.00
E36771	2017-08-12 03:03:00+03	42800.00
E367D1	2017-08-04 03:32:00+03	32700.00
E367DF	2017-07-27 04:14:00+03	28000.00
E3682A	2017-08-14 21:36:00+03	6700.00
E36831	2017-07-22 18:12:00+03	50000.00
E36843	2017-07-25 20:18:00+03	88600.00
E3685F	2017-08-04 21:33:00+03	67600.00
E3690A	2017-08-05 23:46:00+03	150000.00
E36939	2017-08-05 22:31:00+03	66600.00
E369CE	2017-07-02 09:05:00+03	56000.00
E36A3F	2017-08-10 02:12:00+03	44300.00
E36A59	2017-08-09 21:04:00+03	131600.00
E36B0E	2017-08-08 08:00:00+03	46400.00
E36B20	2017-07-06 12:40:00+03	28800.00
E36B2A	2017-08-06 09:45:00+03	43400.00
E36B71	2017-08-03 01:31:00+03	56000.00
E36BA7	2017-07-16 00:12:00+03	14800.00
E36BC3	2017-08-13 15:32:00+03	52700.00
E36BED	2017-08-13 07:18:00+03	40800.00
E36C14	2017-07-07 14:48:00+03	27200.00
E36C7A	2017-07-11 05:03:00+03	26800.00
E36C99	2017-07-13 12:14:00+03	23100.00
E36CEC	2017-07-16 08:32:00+03	125200.00
E36D1E	2017-07-07 09:54:00+03	11600.00
E36D2D	2017-07-01 20:51:00+03	85000.00
E36D32	2017-07-02 21:28:00+03	47000.00
E36D65	2017-08-02 22:04:00+03	54800.00
E36DE6	2017-08-06 17:45:00+03	32700.00
E36F16	2017-07-06 16:00:00+03	28800.00
E36F5F	2017-07-24 07:20:00+03	31400.00
E36F91	2017-07-21 10:21:00+03	19600.00
E36F9C	2017-06-27 03:21:00+03	57400.00
E36FBA	2017-07-24 04:13:00+03	63800.00
E36FDB	2017-07-29 04:27:00+03	46800.00
E36FE7	2017-07-08 19:58:00+03	21400.00
E37005	2017-07-22 19:58:00+03	36200.00
E3707E	2017-08-01 23:24:00+03	29600.00
E3708A	2017-07-10 19:25:00+03	31600.00
E37094	2017-08-03 17:02:00+03	56900.00
E370B1	2017-07-27 09:33:00+03	26200.00
E370E7	2017-07-19 20:28:00+03	55800.00
E37106	2017-07-16 10:30:00+03	136200.00
E3716C	2017-08-08 11:36:00+03	133100.00
E37203	2017-08-11 16:12:00+03	151000.00
E37262	2017-07-12 22:09:00+03	41400.00
E37293	2017-08-03 01:27:00+03	12600.00
E372E0	2017-07-02 16:01:00+03	35200.00
E372E7	2017-07-27 19:14:00+03	57400.00
E37353	2017-08-01 04:49:00+03	55600.00
E37363	2017-07-03 08:54:00+03	139300.00
E373BF	2017-07-27 01:50:00+03	52300.00
E373C5	2017-07-09 23:09:00+03	120900.00
E373C8	2017-07-24 08:59:00+03	258400.00
E373D5	2017-07-15 15:36:00+03	265600.00
E3742B	2017-07-12 20:16:00+03	147300.00
E374A8	2017-08-14 16:27:00+03	57800.00
E3751F	2017-08-12 16:47:00+03	120800.00
E375CD	2017-08-08 12:32:00+03	27200.00
E37605	2017-08-11 02:37:00+03	135000.00
E37652	2017-08-11 16:47:00+03	123000.00
E3766A	2017-07-20 17:30:00+03	26800.00
E3768D	2017-07-22 09:01:00+03	71400.00
E376AB	2017-07-30 03:39:00+03	406800.00
E3775D	2017-08-10 12:51:00+03	146300.00
E377B8	2017-08-10 08:22:00+03	114200.00
E37812	2017-07-27 22:40:00+03	133200.00
E37826	2017-08-07 15:37:00+03	28700.00
E37874	2017-07-27 04:12:00+03	133100.00
E378E9	2017-08-07 12:33:00+03	101800.00
E378ED	2017-07-24 09:37:00+03	50600.00
E37932	2017-07-24 20:03:00+03	53300.00
E37943	2017-07-27 13:12:00+03	93000.00
E37951	2017-07-10 22:44:00+03	17200.00
E3798B	2017-07-25 02:11:00+03	46400.00
E379B2	2017-07-27 05:33:00+03	98400.00
E379C6	2017-06-28 03:57:00+03	122300.00
E379ED	2017-07-28 02:12:00+03	130400.00
E37A45	2017-07-06 19:12:00+03	44800.00
E37A8C	2017-08-08 14:10:00+03	26000.00
E37B56	2017-07-04 12:05:00+03	79800.00
E37B96	2017-07-12 07:01:00+03	119000.00
E37B9A	2017-07-10 18:25:00+03	70200.00
E37B9C	2017-07-15 15:32:00+03	27200.00
E37BFE	2017-07-21 09:03:00+03	28000.00
E37C1D	2017-07-16 15:17:00+03	26800.00
E37C2E	2017-07-03 18:13:00+03	49100.00
E37C52	2017-08-03 11:47:00+03	133200.00
E37C6C	2017-08-05 12:37:00+03	92100.00
E37CBF	2017-07-23 19:20:00+03	70700.00
E37CD8	2017-07-30 16:06:00+03	28800.00
E37CDE	2017-07-31 15:01:00+03	56100.00
E37E6D	2017-07-23 18:19:00+03	62700.00
E37EDD	2017-07-08 12:31:00+03	37900.00
E37EE7	2017-07-07 10:31:00+03	65900.00
E37F55	2017-07-21 15:16:00+03	131400.00
E37F92	2017-08-13 02:49:00+03	23200.00
E37FC9	2017-07-27 18:24:00+03	27300.00
E38003	2017-07-12 09:41:00+03	193200.00
E3802D	2017-07-22 21:51:00+03	81300.00
E3804E	2017-07-15 10:29:00+03	39300.00
E38055	2017-08-07 19:33:00+03	65900.00
E380B5	2017-08-14 15:28:00+03	24700.00
E380DA	2017-07-27 00:09:00+03	138600.00
E38106	2017-08-08 22:52:00+03	47400.00
E38170	2017-08-10 04:27:00+03	107800.00
E381EA	2017-07-16 06:46:00+03	35700.00
E38234	2017-08-14 17:29:00+03	60600.00
E3823D	2017-07-28 23:22:00+03	40800.00
E3824E	2017-07-05 19:00:00+03	187800.00
E3825E	2017-08-05 18:24:00+03	12400.00
E382EE	2017-08-10 05:29:00+03	32400.00
E382FE	2017-07-07 21:42:00+03	282300.00
E3839E	2017-07-20 13:20:00+03	278400.00
E3842F	2017-07-24 11:23:00+03	144200.00
E38432	2017-08-03 07:03:00+03	113300.00
E38464	2017-08-10 09:19:00+03	96100.00
E384CD	2017-08-02 21:11:00+03	13800.00
E384F9	2017-06-29 21:10:00+03	34800.00
E3852C	2017-07-18 06:15:00+03	39200.00
E38530	2017-07-27 10:46:00+03	81600.00
E3855F	2017-08-13 07:51:00+03	31800.00
E385CF	2017-07-08 07:29:00+03	55800.00
E385D2	2017-07-16 18:51:00+03	36200.00
E385D5	2017-07-05 04:56:00+03	28300.00
E38626	2017-07-20 22:19:00+03	345800.00
E3863B	2017-07-27 13:44:00+03	47600.00
E386E1	2017-08-14 13:03:00+03	45400.00
E38785	2017-07-24 03:33:00+03	26200.00
E3879F	2017-07-04 13:27:00+03	46000.00
E387E8	2017-07-27 15:43:00+03	37900.00
E38812	2017-08-07 03:09:00+03	150600.00
E38839	2017-07-14 17:11:00+03	12600.00
E3887C	2017-07-26 00:33:00+03	24400.00
E3895A	2017-07-30 04:42:00+03	283100.00
E389D2	2017-07-08 09:15:00+03	113700.00
E389F5	2017-08-04 17:59:00+03	133900.00
E38A2E	2017-07-31 08:27:00+03	46900.00
E38A89	2017-08-11 17:14:00+03	24000.00
E38AAA	2017-07-31 05:06:00+03	35700.00
E38AB4	2017-07-10 11:36:00+03	14000.00
E38B13	2017-08-04 08:35:00+03	46000.00
E38B52	2017-07-26 13:49:00+03	176400.00
E38B7F	2017-08-12 17:12:00+03	48300.00
E38B98	2017-07-02 08:47:00+03	78800.00
E38BA2	2017-08-02 19:53:00+03	90000.00
E38BB8	2017-07-12 17:41:00+03	65900.00
E38BE3	2017-07-09 00:21:00+03	85600.00
E38C46	2017-08-10 01:28:00+03	122600.00
E38C4C	2017-07-16 10:21:00+03	233700.00
E38CDD	2017-08-01 16:02:00+03	65500.00
E38CE0	2017-08-03 22:43:00+03	88100.00
E38D2A	2017-08-13 13:43:00+03	31600.00
E38D79	2017-07-24 23:32:00+03	16800.00
E38D92	2017-07-31 09:23:00+03	189800.00
E38DA0	2017-06-30 11:27:00+03	89600.00
E38DC1	2017-07-18 17:12:00+03	95200.00
E38E12	2017-08-03 14:37:00+03	88400.00
E38E58	2017-07-04 04:17:00+03	201200.00
E38E7D	2017-07-10 22:58:00+03	77600.00
E38EAE	2017-07-13 22:07:00+03	47100.00
E38F08	2017-08-01 04:16:00+03	56000.00
E38F3F	2017-07-13 15:16:00+03	23600.00
E38FCC	2017-07-06 05:09:00+03	73500.00
E38FCF	2017-07-18 12:26:00+03	54000.00
E38FD0	2017-08-08 07:17:00+03	23200.00
E39020	2017-08-05 17:18:00+03	8000.00
E390AC	2017-08-02 10:43:00+03	114300.00
E390C4	2017-07-23 04:22:00+03	68800.00
E39114	2017-08-07 02:25:00+03	46000.00
E39142	2017-07-13 20:28:00+03	271400.00
E3914E	2017-08-09 12:58:00+03	63200.00
E39177	2017-07-04 04:06:00+03	92800.00
E391B4	2017-08-10 11:26:00+03	104600.00
E391CD	2017-07-05 12:15:00+03	99300.00
E392F2	2017-07-01 13:17:00+03	44400.00
E39319	2017-07-22 07:28:00+03	58800.00
E39355	2017-07-04 13:09:00+03	71400.00
E39424	2017-08-07 19:14:00+03	40400.00
E39439	2017-08-13 05:01:00+03	28800.00
E394E4	2017-07-19 10:26:00+03	136500.00
E394F9	2017-06-29 14:43:00+03	56000.00
E3950F	2017-07-15 04:07:00+03	48800.00
E39605	2017-07-24 01:52:00+03	135600.00
E3964A	2017-08-08 11:59:00+03	114900.00
E3966B	2017-07-26 07:23:00+03	68900.00
E39673	2017-07-02 14:49:00+03	54000.00
E39688	2017-08-08 19:50:00+03	136800.00
E396E4	2017-07-17 17:37:00+03	50800.00
E396E8	2017-07-05 11:32:00+03	26000.00
E396F0	2017-08-11 17:31:00+03	56000.00
E396F1	2017-07-24 17:40:00+03	14000.00
E396F9	2017-07-18 17:43:00+03	59200.00
E39713	2017-08-11 00:34:00+03	99200.00
E39742	2017-07-27 01:31:00+03	90400.00
E3979B	2017-08-07 19:20:00+03	273300.00
E39830	2017-07-27 15:46:00+03	24400.00
E39841	2017-07-29 03:53:00+03	24800.00
E3994F	2017-08-06 15:46:00+03	254900.00
E39962	2017-08-06 13:46:00+03	23200.00
E3996C	2017-08-13 15:00:00+03	11900.00
E39992	2017-08-13 00:57:00+03	229800.00
E39A4E	2017-07-08 23:45:00+03	16400.00
E39A59	2017-07-20 13:43:00+03	34000.00
E39AAE	2017-08-05 07:06:00+03	6900.00
E39AEB	2017-07-26 08:00:00+03	23200.00
E39B41	2017-07-24 12:58:00+03	84000.00
E39BE1	2017-07-16 01:03:00+03	49600.00
E39C1B	2017-07-06 15:53:00+03	14700.00
E39CB2	2017-06-29 21:55:00+03	46800.00
E39CB9	2017-06-30 01:17:00+03	32400.00
E39D3C	2017-06-27 21:41:00+03	378400.00
E39D44	2017-07-15 13:05:00+03	109600.00
E39D9D	2017-07-23 16:01:00+03	36200.00
E39DDE	2017-07-17 01:08:00+03	14000.00
E39DED	2017-08-03 02:18:00+03	56000.00
E39E30	2017-07-19 12:53:00+03	91300.00
E39E5F	2017-07-16 13:06:00+03	23600.00
E39EC5	2017-07-23 04:51:00+03	38800.00
E39EE8	2017-08-03 01:57:00+03	26700.00
E39F48	2017-07-27 12:02:00+03	132700.00
E39F79	2017-07-13 11:08:00+03	52700.00
E39FD2	2017-08-02 06:47:00+03	130600.00
E39FD3	2017-07-11 15:32:00+03	46000.00
E39FD4	2017-07-17 18:38:00+03	123000.00
E3A010	2017-08-01 14:56:00+03	153300.00
E3A025	2017-07-23 10:34:00+03	134000.00
E3A042	2017-08-12 07:55:00+03	12600.00
E3A063	2017-07-19 09:54:00+03	9200.00
E3A078	2017-08-02 16:24:00+03	35200.00
E3A10A	2017-07-07 18:23:00+03	25600.00
E3A130	2017-07-13 21:14:00+03	28000.00
E3A202	2017-08-13 06:13:00+03	6700.00
E3A20E	2017-07-18 03:56:00+03	6700.00
E3A291	2017-08-10 02:25:00+03	83000.00
E3A2C8	2017-06-27 11:53:00+03	84300.00
E3A2D1	2017-06-27 12:25:00+03	14400.00
E3A2DA	2017-08-03 09:42:00+03	174900.00
E3A2F5	2017-07-29 04:07:00+03	53600.00
E3A335	2017-07-02 04:01:00+03	25000.00
E3A33C	2017-07-22 17:54:00+03	48800.00
E3A373	2017-08-13 10:03:00+03	32400.00
E3A3A2	2017-08-12 16:41:00+03	44300.00
E3A447	2017-07-16 21:57:00+03	56000.00
E3A4A9	2017-08-04 12:18:00+03	135600.00
E3A537	2017-08-07 08:14:00+03	14000.00
E3A56E	2017-08-14 23:05:00+03	51900.00
E3A577	2017-07-17 20:27:00+03	24200.00
E3A578	2017-07-24 22:24:00+03	410200.00
E3A5A4	2017-08-14 21:56:00+03	49100.00
E3A5AF	2017-07-05 12:04:00+03	139000.00
E3A5C0	2017-08-10 19:56:00+03	51900.00
E3A5C3	2017-08-05 16:15:00+03	31400.00
E3A5DB	2017-08-13 20:15:00+03	246000.00
E3A5EF	2017-08-11 18:10:00+03	43200.00
E3A61A	2017-07-07 01:27:00+03	50900.00
E3A694	2017-08-08 05:40:00+03	36400.00
E3A6A4	2017-07-15 00:52:00+03	8200.00
E3A702	2017-07-14 07:13:00+03	33100.00
E3A798	2017-07-20 15:37:00+03	116900.00
E3A809	2017-07-12 20:54:00+03	88400.00
E3A85C	2017-07-25 12:26:00+03	13400.00
E3A937	2017-07-27 04:21:00+03	64200.00
E3A973	2017-07-26 14:10:00+03	32700.00
E3A985	2017-07-28 11:05:00+03	114400.00
E3A99E	2017-07-16 01:41:00+03	433300.00
E3AA5F	2017-07-06 15:04:00+03	192400.00
E3AA69	2017-07-11 11:20:00+03	16400.00
E3AAAC	2017-08-12 20:01:00+03	56000.00
E3AB13	2017-07-17 12:20:00+03	112000.00
E3AB4F	2017-07-14 07:34:00+03	133200.00
E3AB8E	2017-07-11 20:02:00+03	61800.00
E3AC23	2017-08-14 19:34:00+03	57800.00
E3AC37	2017-08-06 18:00:00+03	88900.00
E3AC63	2017-07-11 14:23:00+03	271400.00
E3AC8F	2017-08-10 15:01:00+03	42800.00
E3ACE3	2017-07-14 08:08:00+03	54400.00
E3ACE9	2017-07-17 18:56:00+03	48500.00
E3ACEF	2017-08-07 18:01:00+03	131100.00
E3AE21	2017-07-17 21:14:00+03	24400.00
E3AE5A	2017-07-31 16:44:00+03	6300.00
E3AE65	2017-08-13 13:46:00+03	40800.00
E3AF0E	2017-08-15 01:56:00+03	56900.00
E3AF23	2017-07-30 18:11:00+03	57800.00
E3AF36	2017-08-09 14:47:00+03	70600.00
E3AF51	2017-07-22 04:01:00+03	28000.00
E3AF56	2017-08-03 20:43:00+03	170700.00
E3AF9D	2017-07-31 08:57:00+03	66000.00
E3AFAD	2017-08-12 00:53:00+03	26800.00
E3B022	2017-08-02 23:23:00+03	88600.00
E3B04B	2017-08-10 19:51:00+03	199700.00
E3B064	2017-07-10 03:54:00+03	29400.00
E3B09C	2017-07-13 19:43:00+03	38200.00
E3B103	2017-07-19 15:19:00+03	382300.00
E3B187	2017-08-06 11:22:00+03	93000.00
E3B1C8	2017-07-15 11:39:00+03	265700.00
E3B1CC	2017-08-09 06:13:00+03	14000.00
E3B21A	2017-07-11 09:16:00+03	89700.00
E3B2A3	2017-07-25 02:10:00+03	135200.00
E3B2DB	2017-07-01 14:41:00+03	39300.00
E3B2F4	2017-08-09 20:59:00+03	133200.00
E3B324	2017-07-28 23:06:00+03	50000.00
E3B32D	2017-07-05 13:24:00+03	82000.00
E3B348	2017-07-13 12:17:00+03	88800.00
E3B3EC	2017-07-29 05:52:00+03	13200.00
E3B410	2017-07-31 04:59:00+03	52000.00
E3B439	2017-07-15 14:16:00+03	31600.00
E3B45B	2017-07-05 12:19:00+03	73300.00
E3B518	2017-07-08 23:01:00+03	26600.00
E3B52A	2017-08-07 20:06:00+03	113000.00
E3B53E	2017-07-02 03:10:00+03	68000.00
E3B556	2017-08-03 10:52:00+03	28800.00
E3B5CE	2017-07-08 00:44:00+03	28800.00
E3B5DB	2017-07-24 11:46:00+03	44400.00
E3B643	2017-07-14 08:29:00+03	69500.00
E3B735	2017-07-24 15:06:00+03	75300.00
E3B744	2017-08-05 01:58:00+03	70600.00
E3B74B	2017-07-20 04:39:00+03	97900.00
E3B776	2017-07-05 16:31:00+03	106900.00
E3B781	2017-07-20 18:08:00+03	30600.00
E3B7A6	2017-07-16 22:18:00+03	28000.00
E3B7BB	2017-07-14 20:43:00+03	33800.00
E3B83D	2017-07-27 07:29:00+03	40800.00
E3B84B	2017-07-10 22:19:00+03	117200.00
E3B853	2017-07-05 00:50:00+03	75800.00
E3B995	2017-07-04 10:33:00+03	23200.00
E3B9AB	2017-08-06 08:08:00+03	48800.00
E3B9E4	2017-07-05 23:33:00+03	23200.00
E3B9FA	2017-07-26 10:24:00+03	40600.00
E3BB45	2017-08-08 09:32:00+03	46300.00
E3BBF4	2017-07-19 20:33:00+03	116400.00
E3BBF8	2017-07-22 19:32:00+03	30200.00
E3BC07	2017-07-31 05:58:00+03	22600.00
E3BC3E	2017-07-14 21:51:00+03	44000.00
E3BC66	2017-07-06 17:06:00+03	65100.00
E3BC87	2017-06-28 22:58:00+03	233800.00
E3BC9F	2017-07-06 15:19:00+03	246000.00
E3BCA2	2017-07-31 14:57:00+03	16400.00
E3BCB3	2017-08-11 07:07:00+03	189800.00
E3BD32	2017-07-04 00:44:00+03	7300.00
E3BDBC	2017-08-01 14:15:00+03	54500.00
E3BDD4	2017-07-24 09:51:00+03	26000.00
E3BDE4	2017-07-12 04:23:00+03	29600.00
E3BDEF	2017-07-08 23:50:00+03	39300.00
E3BDF7	2017-07-20 13:35:00+03	279000.00
E3BE5E	2017-07-09 00:37:00+03	79600.00
E3BEB0	2017-07-13 19:01:00+03	109000.00
E3BF0C	2017-07-13 03:36:00+03	25400.00
E3BFE7	2017-08-10 02:24:00+03	54500.00
E3C083	2017-08-13 16:23:00+03	35600.00
E3C0A5	2017-07-08 01:32:00+03	58700.00
E3C0F7	2017-07-16 08:28:00+03	55800.00
E3C128	2017-08-08 14:31:00+03	63500.00
E3C12F	2017-08-13 11:04:00+03	59800.00
E3C14E	2017-08-06 04:12:00+03	151000.00
E3C15C	2017-08-01 11:30:00+03	18600.00
E3C1AD	2017-08-06 03:43:00+03	120700.00
E3C1E8	2017-07-13 16:22:00+03	137900.00
E3C224	2017-07-27 15:46:00+03	13400.00
E3C22A	2017-07-03 22:04:00+03	400000.00
E3C2A7	2017-07-08 22:42:00+03	38600.00
E3C2B5	2017-07-01 21:12:00+03	12600.00
E3C314	2017-07-13 22:56:00+03	100600.00
E3C32C	2017-07-31 11:22:00+03	142400.00
E3C35E	2017-06-29 22:01:00+03	38400.00
E3C367	2017-07-02 03:57:00+03	257600.00
E3C422	2017-07-31 16:15:00+03	36200.00
E3C442	2017-08-12 12:35:00+03	23600.00
E3C461	2017-08-05 07:52:00+03	28800.00
E3C468	2017-08-06 05:57:00+03	198400.00
E3C47A	2017-07-12 03:37:00+03	106900.00
E3C4C6	2017-07-29 21:43:00+03	61800.00
E3C4E6	2017-08-01 22:42:00+03	257600.00
E3C529	2017-07-07 00:41:00+03	14400.00
E3C52C	2017-08-13 19:06:00+03	121700.00
E3C589	2017-07-01 23:08:00+03	54300.00
E3C60A	2017-07-26 21:51:00+03	81600.00
E3C61A	2017-08-07 20:33:00+03	118600.00
E3C663	2017-08-11 19:43:00+03	46500.00
E3C6C8	2017-07-09 06:07:00+03	56600.00
E3C6F5	2017-07-05 12:12:00+03	133200.00
E3C707	2017-07-26 01:02:00+03	12600.00
E3C726	2017-07-30 02:02:00+03	36200.00
E3C751	2017-07-13 00:59:00+03	26000.00
E3C804	2017-08-06 00:30:00+03	243700.00
E3C828	2017-08-03 16:58:00+03	28000.00
E3C89E	2017-07-25 18:26:00+03	266400.00
E3C8C4	2017-07-18 05:28:00+03	126000.00
E3C910	2017-07-06 05:27:00+03	73600.00
E3C946	2017-07-21 23:17:00+03	28000.00
E3C996	2017-06-26 05:27:00+03	176400.00
E3CA5F	2017-08-15 12:24:00+03	51800.00
E3CA85	2017-07-19 08:06:00+03	136200.00
E3CA8C	2017-07-25 21:38:00+03	43200.00
E3CAA5	2017-07-23 11:54:00+03	55800.00
E3CAA7	2017-07-06 23:23:00+03	58000.00
E3CABC	2017-07-14 13:47:00+03	31400.00
E3CAFE	2017-08-11 00:45:00+03	13400.00
E3CB0C	2017-07-17 12:35:00+03	135600.00
E3CB9D	2017-07-22 11:55:00+03	111600.00
E3CBB2	2017-07-28 14:04:00+03	27200.00
E3CC3E	2017-07-09 01:38:00+03	386300.00
E3CC76	2017-07-12 16:42:00+03	399600.00
E3CCAB	2017-07-21 19:42:00+03	46800.00
E3CD0E	2017-07-31 14:37:00+03	57400.00
E3CD14	2017-07-08 23:00:00+03	187900.00
E3CE68	2017-07-13 03:32:00+03	21800.00
E3CEB0	2017-07-04 03:03:00+03	56100.00
E3CEB3	2017-07-07 14:26:00+03	199700.00
E3CEE8	2017-07-30 19:15:00+03	136200.00
E3CF22	2017-07-18 03:48:00+03	68000.00
E3CF37	2017-08-15 14:17:00+03	81700.00
E3CF40	2017-07-15 07:10:00+03	135600.00
E3CF9A	2017-08-12 23:37:00+03	34000.00
E3D019	2017-07-20 05:03:00+03	205600.00
E3D01F	2017-07-21 00:23:00+03	81300.00
E3D027	2017-07-24 20:18:00+03	84000.00
E3D031	2017-07-24 10:50:00+03	192100.00
E3D053	2017-07-11 11:40:00+03	28000.00
E3D06A	2017-07-29 19:33:00+03	24200.00
E3D0D4	2017-07-03 02:35:00+03	21200.00
E3D0EF	2017-07-31 01:43:00+03	49800.00
E3D154	2017-08-06 22:31:00+03	12400.00
E3D167	2017-07-29 21:49:00+03	165800.00
E3D188	2017-07-11 06:17:00+03	100200.00
E3D193	2017-07-25 12:51:00+03	23200.00
E3D1C8	2017-07-09 17:57:00+03	81700.00
E3D217	2017-08-11 01:56:00+03	154800.00
E3D26F	2017-07-07 04:23:00+03	84900.00
E3D290	2017-07-28 12:00:00+03	26800.00
E3D2AE	2017-07-18 08:36:00+03	177200.00
E3D369	2017-07-04 15:18:00+03	136400.00
E3D39C	2017-07-03 16:18:00+03	24400.00
E3D3D4	2017-08-12 02:41:00+03	39500.00
E3D411	2017-07-08 08:06:00+03	7200.00
E3D44E	2017-08-08 01:47:00+03	14400.00
E3D479	2017-07-21 19:57:00+03	47100.00
E3D47B	2017-07-04 04:37:00+03	125200.00
E3D4A1	2017-07-23 11:29:00+03	23600.00
E3D4AB	2017-07-17 09:24:00+03	24800.00
E3D4C9	2017-07-03 04:01:00+03	16400.00
E3D573	2017-07-01 12:35:00+03	80300.00
E3D58F	2017-07-16 06:39:00+03	100600.00
E3D5BF	2017-08-02 00:18:00+03	40600.00
E3D611	2017-07-13 23:06:00+03	73600.00
E3D616	2017-08-06 03:24:00+03	93700.00
E3D65F	2017-08-11 03:09:00+03	19600.00
E3D6A8	2017-08-14 07:55:00+03	13400.00
E3D757	2017-07-22 00:50:00+03	12000.00
E3D789	2017-08-12 22:40:00+03	123000.00
E3D79C	2017-07-06 14:26:00+03	40800.00
E3D7DB	2017-08-05 18:04:00+03	132800.00
E3D84C	2017-08-13 16:16:00+03	45200.00
E3D8E6	2017-07-31 03:47:00+03	83300.00
E3D9A7	2017-08-05 01:09:00+03	85000.00
E3D9BA	2017-07-11 21:44:00+03	140900.00
E3D9E4	2017-08-08 06:59:00+03	112000.00
E3D9F1	2017-07-07 02:32:00+03	6000.00
E3DA0A	2017-07-14 15:30:00+03	47400.00
E3DA38	2017-07-31 02:23:00+03	6000.00
E3DA4F	2017-07-20 08:31:00+03	273100.00
E3DA51	2017-08-04 00:47:00+03	43900.00
E3DADE	2017-07-31 21:27:00+03	6700.00
E3DAE4	2017-07-10 16:01:00+03	48800.00
E3DB16	2017-08-11 18:03:00+03	36800.00
E3DBE2	2017-08-01 03:18:00+03	46400.00
E3DBEE	2017-07-13 05:51:00+03	148200.00
E3DCD6	2017-08-04 19:24:00+03	21400.00
E3DCF7	2017-08-09 04:57:00+03	10700.00
E3DD28	2017-08-05 11:31:00+03	21800.00
E3DD32	2017-07-09 18:33:00+03	106400.00
E3DD83	2017-08-04 16:59:00+03	85000.00
E3DDAF	2017-06-30 15:31:00+03	23600.00
E3DE40	2017-07-18 07:33:00+03	81700.00
E3DEF1	2017-07-14 04:26:00+03	49600.00
E3DF0D	2017-08-11 01:45:00+03	61800.00
E3DF47	2017-08-12 21:32:00+03	269200.00
E3DF48	2017-07-23 14:19:00+03	123000.00
E3DF6D	2017-08-02 15:33:00+03	70500.00
E3DF6E	2017-07-08 15:48:00+03	13700.00
E3DFA8	2017-08-06 02:56:00+03	53400.00
E3DFB6	2017-07-21 05:35:00+03	34700.00
E3DFEF	2017-08-06 20:03:00+03	14000.00
E3E015	2017-07-01 09:04:00+03	13200.00
E3E030	2017-08-06 00:54:00+03	55800.00
E3E042	2017-08-08 12:01:00+03	23200.00
E3E079	2017-07-14 05:59:00+03	31600.00
E3E0B7	2017-07-30 10:14:00+03	56000.00
E3E0C5	2017-08-14 19:10:00+03	81300.00
E3E14A	2017-07-03 08:05:00+03	31400.00
E3E19E	2017-08-15 16:27:00+03	268000.00
E3E2D3	2017-07-26 12:19:00+03	62600.00
E3E2FE	2017-07-29 01:19:00+03	26800.00
E3E30A	2017-08-03 21:33:00+03	289500.00
E3E321	2017-07-05 11:57:00+03	44500.00
E3E351	2017-06-28 20:54:00+03	350200.00
E3E3C6	2017-07-06 01:28:00+03	62600.00
E3E3FE	2017-07-14 05:02:00+03	62600.00
E3E442	2017-07-30 10:15:00+03	12000.00
E3E46B	2017-08-12 04:12:00+03	97700.00
E3E479	2017-08-13 10:55:00+03	26700.00
E3E4C2	2017-08-11 21:31:00+03	19000.00
E3E4D8	2017-08-08 09:19:00+03	26000.00
E3E4EF	2017-07-04 19:20:00+03	39600.00
E3E4F6	2017-08-08 23:31:00+03	41600.00
E3E525	2017-07-08 07:23:00+03	248300.00
E3E560	2017-07-15 12:07:00+03	36200.00
E3E57C	2017-07-09 08:35:00+03	59800.00
E3E5A1	2017-07-30 09:34:00+03	421800.00
E3E5C8	2017-08-08 19:30:00+03	20200.00
E3E5D2	2017-07-20 09:58:00+03	55800.00
E3E5D6	2017-08-13 16:56:00+03	55800.00
E3E5DD	2017-07-26 17:30:00+03	131600.00
E3E5EC	2017-07-01 07:13:00+03	131800.00
E3E603	2017-07-18 14:10:00+03	29600.00
E3E615	2017-07-15 01:47:00+03	47000.00
E3E630	2017-07-26 03:45:00+03	147700.00
E3E69D	2017-07-22 09:35:00+03	33200.00
E3E72D	2017-08-07 19:00:00+03	240300.00
E3E73C	2017-07-31 09:37:00+03	57500.00
E3E879	2017-08-14 12:50:00+03	27200.00
E3E893	2017-07-06 07:41:00+03	31200.00
E3E8DB	2017-07-17 11:53:00+03	23100.00
E3E961	2017-07-30 04:33:00+03	15000.00
E3E999	2017-07-23 15:18:00+03	26000.00
E3E9C7	2017-07-25 20:39:00+03	30400.00
E3E9EB	2017-08-14 09:29:00+03	13400.00
E3EA12	2017-07-27 15:39:00+03	25200.00
E3EA51	2017-07-28 17:40:00+03	8000.00
E3EA9B	2017-07-24 10:51:00+03	34200.00
E3EAF7	2017-07-13 19:22:00+03	31600.00
E3EAFE	2017-07-12 06:55:00+03	71900.00
E3EB03	2017-07-21 05:10:00+03	14800.00
E3EB10	2017-08-13 17:02:00+03	36200.00
E3EB27	2017-07-21 17:03:00+03	143000.00
E3EBFE	2017-07-10 11:12:00+03	40800.00
E3EC45	2017-07-12 10:37:00+03	13300.00
E3EC7F	2017-07-12 14:20:00+03	62600.00
E3EC8A	2017-08-12 11:30:00+03	189200.00
E3ECE9	2017-07-03 09:20:00+03	385000.00
E3ED23	2017-07-13 14:15:00+03	21400.00
E3ED42	2017-07-24 05:51:00+03	242200.00
E3ED6B	2017-07-08 01:09:00+03	181600.00
E3EE5A	2017-07-13 23:35:00+03	37900.00
E3EEAE	2017-07-10 15:15:00+03	47000.00
E3EEEB	2017-08-06 10:46:00+03	131800.00
E3EF0A	2017-08-09 03:50:00+03	22000.00
E3EF31	2017-07-10 06:57:00+03	73100.00
E3EFD9	2017-06-27 11:23:00+03	105100.00
E3EFDB	2017-07-19 04:11:00+03	11600.00
E3F00D	2017-08-03 06:31:00+03	120700.00
E3F012	2017-08-13 00:58:00+03	62600.00
E3F076	2017-07-04 04:39:00+03	109600.00
E3F081	2017-07-25 10:52:00+03	69500.00
E3F0DD	2017-07-08 05:43:00+03	13400.00
E3F286	2017-07-04 20:16:00+03	55800.00
E3F2B8	2017-07-21 06:00:00+03	6800.00
E3F2D5	2017-08-04 07:55:00+03	132800.00
E3F2DE	2017-08-05 14:26:00+03	56000.00
E3F2E6	2017-08-10 23:58:00+03	38900.00
E3F31E	2017-08-12 02:39:00+03	54400.00
E3F338	2017-08-14 08:48:00+03	36600.00
E3F373	2017-07-15 14:46:00+03	153200.00
E3F388	2017-08-08 07:59:00+03	123600.00
E3F3C2	2017-07-19 00:13:00+03	234400.00
E3F3F2	2017-07-23 00:42:00+03	26000.00
E3F423	2017-07-24 01:22:00+03	111600.00
E3F447	2017-07-20 11:19:00+03	111600.00
E3F45A	2017-07-25 13:38:00+03	70800.00
E3F502	2017-07-22 01:14:00+03	201800.00
E3F63C	2017-08-12 12:51:00+03	46200.00
E3F6C8	2017-07-03 15:57:00+03	10600.00
E3F777	2017-08-11 08:07:00+03	81600.00
E3F7D7	2017-08-09 10:21:00+03	24800.00
E3F880	2017-08-14 23:18:00+03	34000.00
E3F888	2017-07-03 10:09:00+03	115900.00
E3F904	2017-08-10 17:04:00+03	32800.00
E3F97F	2017-07-31 16:04:00+03	26200.00
E3FAB4	2017-07-07 13:28:00+03	139100.00
E3FB22	2017-07-28 00:20:00+03	43800.00
E3FB73	2017-08-03 01:16:00+03	9800.00
E3FB74	2017-07-20 02:32:00+03	85000.00
E3FB8D	2017-07-05 12:56:00+03	81700.00
E3FBB3	2017-08-12 00:05:00+03	18900.00
E3FBD1	2017-08-04 00:05:00+03	8400.00
E3FC52	2017-08-06 18:34:00+03	59800.00
E3FC98	2017-07-19 08:21:00+03	128800.00
E3FCA6	2017-07-26 23:56:00+03	58400.00
E3FCCF	2017-07-04 07:16:00+03	14800.00
E3FCFE	2017-07-24 10:23:00+03	25000.00
E3FD4B	2017-07-05 22:40:00+03	30000.00
E3FDC3	2017-07-20 12:13:00+03	68800.00
E3FE11	2017-08-13 07:36:00+03	37900.00
E3FE60	2017-07-17 02:03:00+03	28000.00
E3FE66	2017-08-03 05:41:00+03	94700.00
E3FE90	2017-07-15 06:39:00+03	183200.00
E3FEDA	2017-08-09 05:59:00+03	68800.00
E3FEF5	2017-08-05 13:48:00+03	47800.00
E3FF32	2017-07-24 16:06:00+03	133200.00
E3FF33	2017-07-24 09:55:00+03	19600.00
E3FF49	2017-07-28 01:04:00+03	73600.00
E3FF56	2017-07-16 06:42:00+03	83000.00
E3FF6B	2017-07-05 19:39:00+03	41600.00
E4005A	2017-08-09 06:26:00+03	8000.00
E4006C	2017-08-01 22:04:00+03	100600.00
E400A2	2017-08-05 03:53:00+03	85000.00
E400C3	2017-07-08 12:04:00+03	138900.00
E400D5	2017-07-12 19:43:00+03	28000.00
E400FC	2017-07-22 15:56:00+03	42800.00
E40133	2017-08-05 17:08:00+03	24400.00
E40157	2017-08-07 11:57:00+03	257500.00
E40161	2017-07-02 14:58:00+03	57600.00
E401A1	2017-07-29 08:47:00+03	16400.00
E40200	2017-08-11 13:19:00+03	106100.00
E4020F	2017-07-29 03:28:00+03	58400.00
E40258	2017-08-10 13:39:00+03	73600.00
E40281	2017-07-10 17:16:00+03	97600.00
E402A6	2017-07-08 02:40:00+03	23200.00
E402B7	2017-07-14 17:09:00+03	118500.00
E40301	2017-08-13 12:09:00+03	92000.00
E4035D	2017-08-07 18:05:00+03	86500.00
E4036D	2017-07-27 23:35:00+03	38400.00
E40373	2017-08-09 00:30:00+03	98400.00
E403A7	2017-07-07 16:34:00+03	23400.00
E403CB	2017-08-09 07:57:00+03	40800.00
E403CD	2017-07-30 23:33:00+03	14000.00
E4046A	2017-07-10 20:09:00+03	21500.00
E404BE	2017-07-02 19:42:00+03	91200.00
E404E2	2017-07-28 20:39:00+03	32200.00
E4050B	2017-07-05 14:17:00+03	75300.00
E40525	2017-08-14 13:18:00+03	67200.00
E40532	2017-07-28 08:10:00+03	36800.00
E405DB	2017-08-10 05:27:00+03	43500.00
E40614	2017-06-26 16:52:00+03	95700.00
E40671	2017-07-06 15:25:00+03	91100.00
E40682	2017-08-14 12:27:00+03	167400.00
E406BC	2017-08-11 13:50:00+03	32700.00
E406C8	2017-07-17 22:10:00+03	47100.00
E406DE	2017-07-07 11:42:00+03	25400.00
E40713	2017-07-23 03:51:00+03	103600.00
E4072B	2017-08-06 11:27:00+03	27900.00
E4073B	2017-07-08 09:18:00+03	209900.00
E407E5	2017-08-13 23:29:00+03	25600.00
E407EE	2017-07-15 11:52:00+03	53600.00
E40831	2017-07-10 16:39:00+03	15100.00
E4083D	2017-07-22 18:11:00+03	73500.00
E4084D	2017-07-29 04:56:00+03	37200.00
E40941	2017-07-28 00:28:00+03	26200.00
E409D5	2017-08-11 17:35:00+03	56000.00
E409ED	2017-08-10 23:26:00+03	44000.00
E40A2C	2017-07-14 01:08:00+03	134400.00
E40A2D	2017-07-16 03:15:00+03	15700.00
E40AC7	2017-08-11 16:40:00+03	22000.00
E40C0E	2017-07-14 16:29:00+03	117700.00
E40C7E	2017-07-04 20:03:00+03	50600.00
E40C96	2017-08-09 23:41:00+03	42600.00
E40C9D	2017-07-19 04:49:00+03	102200.00
E40CD0	2017-08-14 19:57:00+03	143000.00
E40CFE	2017-07-29 13:01:00+03	73600.00
E40D14	2017-07-23 10:39:00+03	12600.00
E40D1D	2017-08-05 15:43:00+03	135400.00
E40D21	2017-07-29 16:37:00+03	78800.00
E40D36	2017-06-30 23:40:00+03	70900.00
E40E0A	2017-07-05 00:43:00+03	91900.00
E40E21	2017-07-06 02:50:00+03	61800.00
E40E3D	2017-07-24 14:39:00+03	25000.00
E40E76	2017-07-22 15:37:00+03	57600.00
E40EA6	2017-08-09 07:15:00+03	147400.00
E40ED8	2017-07-20 16:44:00+03	58700.00
E40EF4	2017-08-07 14:52:00+03	66000.00
E40F8B	2017-07-02 05:32:00+03	23400.00
E40F9A	2017-08-07 09:35:00+03	79800.00
E40F9D	2017-07-09 08:55:00+03	25600.00
E40FA0	2017-07-08 19:32:00+03	80000.00
E40FDD	2017-08-09 10:46:00+03	16400.00
E4100A	2017-07-18 13:22:00+03	15800.00
E4101C	2017-07-08 19:55:00+03	54800.00
E41028	2017-08-07 15:02:00+03	107200.00
E41040	2017-08-08 12:46:00+03	96800.00
E41067	2017-07-31 10:19:00+03	23600.00
E4108A	2017-06-29 13:35:00+03	32800.00
E410B4	2017-07-19 05:35:00+03	65200.00
E41131	2017-07-30 21:29:00+03	128800.00
E4114B	2017-08-15 10:02:00+03	36000.00
E41169	2017-07-20 09:17:00+03	14000.00
E411D4	2017-07-30 18:51:00+03	188000.00
E412E3	2017-07-30 11:05:00+03	52000.00
E41344	2017-08-05 05:18:00+03	46000.00
E41374	2017-07-19 21:06:00+03	46300.00
E413E8	2017-08-01 16:08:00+03	39800.00
E41439	2017-07-13 19:05:00+03	20200.00
E41454	2017-08-03 17:28:00+03	83900.00
E41468	2017-08-12 12:36:00+03	137600.00
E4146F	2017-07-07 13:02:00+03	63200.00
E41557	2017-07-06 03:15:00+03	44000.00
E415D4	2017-07-29 23:03:00+03	37200.00
E415D6	2017-07-14 13:44:00+03	26800.00
E41648	2017-07-12 15:39:00+03	6300.00
E41651	2017-07-14 23:13:00+03	266400.00
E41667	2017-07-05 04:06:00+03	57600.00
E41688	2017-07-18 15:53:00+03	66600.00
E416DE	2017-08-10 01:31:00+03	28000.00
E416E5	2017-08-06 09:31:00+03	12600.00
E417C1	2017-08-13 16:09:00+03	19600.00
E41819	2017-08-14 06:42:00+03	100200.00
E41865	2017-08-05 05:46:00+03	53400.00
E418E5	2017-07-25 17:55:00+03	260300.00
E418EB	2017-07-07 05:53:00+03	19600.00
E419A8	2017-07-30 12:14:00+03	24400.00
E419DF	2017-08-01 00:14:00+03	42700.00
E41A1E	2017-07-02 12:52:00+03	24400.00
E41A42	2017-08-10 17:44:00+03	21800.00
E41ADC	2017-07-14 05:33:00+03	24400.00
E41B06	2017-07-09 10:30:00+03	62600.00
E41B49	2017-08-09 20:57:00+03	49100.00
E41B74	2017-07-13 18:37:00+03	23600.00
E41B96	2017-08-08 17:50:00+03	13700.00
E41BAA	2017-08-10 04:40:00+03	23200.00
E41BAB	2017-07-20 00:47:00+03	46400.00
E41C72	2017-08-01 21:26:00+03	99700.00
E41C7C	2017-08-09 00:06:00+03	75600.00
E41D07	2017-07-22 00:41:00+03	181100.00
E41D46	2017-08-12 00:43:00+03	56600.00
E41D6C	2017-08-03 14:41:00+03	281100.00
E41D6D	2017-07-15 01:10:00+03	46300.00
E41D7E	2017-07-30 16:27:00+03	277800.00
E41E16	2017-07-23 19:54:00+03	92800.00
E41E75	2017-06-29 23:18:00+03	87100.00
E41F06	2017-07-16 05:05:00+03	224000.00
E41F94	2017-07-09 04:58:00+03	232800.00
E42063	2017-08-13 22:51:00+03	59600.00
E42073	2017-07-17 13:52:00+03	47400.00
E420CE	2017-08-09 23:38:00+03	17800.00
E42130	2017-08-03 03:28:00+03	32700.00
E421E9	2017-07-08 17:42:00+03	80000.00
E42258	2017-07-21 10:31:00+03	133200.00
E4232D	2017-07-14 23:50:00+03	28000.00
E42378	2017-08-10 06:06:00+03	44400.00
E423C5	2017-08-06 00:32:00+03	26000.00
E42400	2017-08-04 08:25:00+03	79200.00
E4242F	2017-07-24 14:36:00+03	159000.00
E4244A	2017-07-18 17:37:00+03	65900.00
E424B3	2017-08-02 10:49:00+03	31400.00
E424D1	2017-07-03 11:19:00+03	25200.00
E42507	2017-07-25 21:56:00+03	32700.00
E42512	2017-07-04 17:21:00+03	17600.00
E4252A	2017-06-29 02:30:00+03	136800.00
E42542	2017-08-05 20:35:00+03	15400.00
E42558	2017-07-23 11:02:00+03	66600.00
E42561	2017-08-05 15:31:00+03	123000.00
E42563	2017-07-08 18:08:00+03	27200.00
E42595	2017-07-22 13:56:00+03	49100.00
E425E1	2017-07-30 19:45:00+03	43200.00
E425E5	2017-07-01 03:18:00+03	87700.00
E425F6	2017-07-29 17:35:00+03	28800.00
E4268C	2017-07-07 11:10:00+03	34000.00
E426CB	2017-08-04 22:34:00+03	46400.00
E42712	2017-07-13 15:35:00+03	6000.00
E42786	2017-07-14 15:10:00+03	99900.00
E4279D	2017-07-09 09:32:00+03	22000.00
E427BB	2017-08-08 16:27:00+03	41600.00
E427DE	2017-08-14 05:59:00+03	50400.00
E427F2	2017-07-13 02:46:00+03	42800.00
E4280A	2017-07-12 17:36:00+03	31000.00
E42880	2017-07-14 08:59:00+03	112000.00
E4290C	2017-07-06 04:19:00+03	48300.00
E4292B	2017-07-25 07:30:00+03	19600.00
E42935	2017-07-22 04:56:00+03	39200.00
E42996	2017-08-12 23:06:00+03	26000.00
E429AD	2017-08-09 05:28:00+03	16400.00
E429B4	2017-07-11 00:45:00+03	40600.00
E429CD	2017-08-03 00:09:00+03	136800.00
E42A3B	2017-07-29 16:53:00+03	27800.00
E42A69	2017-07-04 07:52:00+03	48800.00
E42AC1	2017-08-12 12:45:00+03	24300.00
E42AD5	2017-07-31 17:09:00+03	57600.00
E42B4B	2017-07-23 19:11:00+03	100200.00
E42BB5	2017-07-19 07:41:00+03	48800.00
E42BF0	2017-06-29 20:36:00+03	44800.00
E42BF8	2017-08-13 00:54:00+03	12600.00
E42C0E	2017-08-08 15:35:00+03	27800.00
E42C66	2017-07-14 04:47:00+03	21400.00
E42CF7	2017-07-06 16:02:00+03	99200.00
E42D79	2017-08-12 07:47:00+03	63500.00
E42DA2	2017-08-03 17:10:00+03	28000.00
E42DD1	2017-07-29 19:52:00+03	28800.00
E42F38	2017-07-29 17:29:00+03	88000.00
E42F46	2017-07-05 04:54:00+03	150600.00
E42F89	2017-07-23 03:09:00+03	25600.00
E42FC1	2017-07-07 23:11:00+03	8400.00
E43032	2017-07-13 00:31:00+03	67600.00
E4306E	2017-08-04 14:37:00+03	103600.00
E430EB	2017-07-05 20:45:00+03	39300.00
E43115	2017-08-04 01:48:00+03	80300.00
E43174	2017-07-29 14:10:00+03	241500.00
E43199	2017-08-09 05:20:00+03	47000.00
E431B0	2017-07-26 06:49:00+03	97700.00
E431CC	2017-08-08 05:17:00+03	40800.00
E431F6	2017-07-03 01:17:00+03	43600.00
E43207	2017-08-15 03:15:00+03	117600.00
E4320D	2017-07-11 00:07:00+03	35600.00
E4326B	2017-08-06 05:06:00+03	157100.00
E432AA	2017-07-16 21:32:00+03	30300.00
E432EE	2017-07-28 07:07:00+03	72400.00
E43308	2017-07-03 23:52:00+03	27900.00
E433E8	2017-08-12 04:43:00+03	22400.00
E4341E	2017-07-10 13:04:00+03	43400.00
E43436	2017-08-11 21:00:00+03	46000.00
E43439	2017-06-30 10:27:00+03	52800.00
E43479	2017-07-18 09:27:00+03	67200.00
E4348C	2017-07-05 11:22:00+03	62000.00
E434B6	2017-07-05 00:04:00+03	46400.00
E434DB	2017-07-13 16:16:00+03	55600.00
E434E9	2017-07-15 14:28:00+03	49900.00
E435BF	2017-07-08 20:42:00+03	79200.00
E435D4	2017-07-31 02:00:00+03	131300.00
E436A0	2017-07-15 05:18:00+03	12600.00
E436AA	2017-08-08 14:37:00+03	26000.00
E43700	2017-07-24 17:10:00+03	152900.00
E43704	2017-08-10 19:34:00+03	6300.00
E43706	2017-07-22 09:53:00+03	300200.00
E43718	2017-07-28 16:32:00+03	73000.00
E43793	2017-08-11 21:40:00+03	139300.00
E43796	2017-07-08 13:01:00+03	64600.00
E437D7	2017-07-24 11:59:00+03	12600.00
E437E3	2017-07-15 11:06:00+03	23200.00
E4380A	2017-08-05 17:11:00+03	166100.00
E4389A	2017-07-27 15:17:00+03	40800.00
E438C1	2017-08-04 16:05:00+03	114400.00
E438DC	2017-07-15 16:52:00+03	123000.00
E43903	2017-08-13 16:48:00+03	44000.00
E43928	2017-07-31 17:37:00+03	77600.00
E43933	2017-07-08 13:18:00+03	24200.00
E4398D	2017-07-29 19:28:00+03	13400.00
E439B0	2017-07-20 22:00:00+03	128600.00
E439EB	2017-07-17 02:54:00+03	42900.00
E43A4C	2017-08-07 21:34:00+03	6000.00
E43A8C	2017-08-09 06:25:00+03	334800.00
E43B53	2017-07-06 06:42:00+03	35200.00
E43B57	2017-08-08 08:46:00+03	12400.00
E43B9B	2017-07-23 01:44:00+03	13200.00
E43BB2	2017-07-26 10:00:00+03	203400.00
E43BD2	2017-08-14 17:12:00+03	18000.00
E43BE3	2017-08-03 19:49:00+03	86600.00
E43BE9	2017-07-20 03:47:00+03	135100.00
E43C04	2017-07-28 21:13:00+03	393800.00
E43C15	2017-08-12 05:39:00+03	123000.00
E43C23	2017-08-01 23:48:00+03	23600.00
E43C2B	2017-08-08 13:18:00+03	6700.00
E43C51	2017-07-06 10:17:00+03	135400.00
E43CAA	2017-07-17 05:33:00+03	29500.00
E43CB1	2017-08-06 12:46:00+03	32800.00
E43CB8	2017-08-12 18:01:00+03	125200.00
E43CE0	2017-07-28 12:40:00+03	18800.00
E43CF6	2017-08-09 03:23:00+03	48000.00
E43D37	2017-08-08 12:10:00+03	32800.00
E43D40	2017-07-26 19:28:00+03	105500.00
E43DB6	2017-07-11 05:15:00+03	76400.00
E43DCE	2017-07-25 20:36:00+03	65200.00
E43EB0	2017-07-21 00:47:00+03	59200.00
E43ECC	2017-08-09 17:27:00+03	43200.00
E43F00	2017-07-05 02:13:00+03	74400.00
E43F12	2017-08-07 23:49:00+03	96300.00
E44000	2017-07-10 00:29:00+03	184000.00
E4403B	2017-07-28 09:44:00+03	136800.00
E44043	2017-07-02 21:16:00+03	46400.00
E440DA	2017-07-21 19:13:00+03	42600.00
E440F3	2017-08-13 14:14:00+03	113300.00
E440F6	2017-07-08 07:58:00+03	81800.00
E440F7	2017-08-10 17:04:00+03	34400.00
E44186	2017-07-30 13:37:00+03	43600.00
E441CD	2017-07-08 02:35:00+03	129500.00
E442B4	2017-07-07 15:12:00+03	50600.00
E44345	2017-07-11 02:14:00+03	8400.00
E44351	2017-07-21 11:00:00+03	65900.00
E44370	2017-07-27 05:55:00+03	160100.00
E443FF	2017-07-08 05:33:00+03	140900.00
E44412	2017-07-13 03:00:00+03	12600.00
E4443F	2017-07-17 00:47:00+03	104000.00
E44449	2017-08-12 00:33:00+03	26200.00
E4445C	2017-07-05 09:37:00+03	56000.00
E444D3	2017-07-31 16:35:00+03	29100.00
E444F3	2017-07-10 20:28:00+03	46400.00
E445A2	2017-08-09 21:28:00+03	67300.00
E445AE	2017-08-14 12:36:00+03	36200.00
E445E6	2017-07-04 12:30:00+03	26200.00
E4460B	2017-07-05 08:13:00+03	25600.00
E4461F	2017-07-17 20:14:00+03	246000.00
E4463F	2017-07-04 16:57:00+03	52000.00
E44640	2017-07-27 10:20:00+03	106800.00
E446AB	2017-08-09 19:03:00+03	21800.00
E446BC	2017-08-04 06:23:00+03	77600.00
E446C6	2017-08-02 13:40:00+03	162400.00
E44704	2017-08-10 06:02:00+03	291000.00
E44708	2017-07-18 03:01:00+03	40000.00
E4479C	2017-08-08 22:55:00+03	36200.00
E447A1	2017-08-10 23:16:00+03	122800.00
E44806	2017-07-16 11:56:00+03	56000.00
E44820	2017-07-12 09:42:00+03	373500.00
E44825	2017-07-02 14:50:00+03	59800.00
E448A0	2017-07-19 07:50:00+03	81700.00
E4492F	2017-07-29 10:46:00+03	67800.00
E44952	2017-07-22 11:32:00+03	61800.00
E4496C	2017-07-06 18:00:00+03	548100.00
E44980	2017-07-09 01:07:00+03	22000.00
E44983	2017-07-09 15:53:00+03	32800.00
E449B0	2017-08-04 22:35:00+03	55600.00
E449C4	2017-07-30 17:08:00+03	34000.00
E44A75	2017-08-12 11:46:00+03	124200.00
E44A84	2017-07-22 00:44:00+03	46400.00
E44A95	2017-07-17 22:56:00+03	29400.00
E44B6B	2017-07-13 13:41:00+03	8000.00
E44B7F	2017-07-05 15:31:00+03	16400.00
E44C08	2017-07-04 11:27:00+03	79900.00
E44C2C	2017-07-07 03:26:00+03	68100.00
E44C31	2017-08-06 21:08:00+03	187100.00
E44C74	2017-07-07 21:25:00+03	54800.00
E44CC8	2017-08-03 12:40:00+03	332800.00
E44CCF	2017-07-07 03:26:00+03	67900.00
E44CD0	2017-07-24 07:35:00+03	75600.00
E44CF7	2017-07-22 09:08:00+03	6300.00
E44D3F	2017-07-26 13:42:00+03	34000.00
E44DB0	2017-07-24 02:43:00+03	30600.00
E44DE0	2017-07-14 02:16:00+03	232800.00
E44DEA	2017-07-29 15:09:00+03	6700.00
E44E15	2017-08-13 09:39:00+03	104600.00
E44E71	2017-07-16 13:22:00+03	64100.00
E44EAD	2017-07-01 05:37:00+03	85000.00
E44EAF	2017-08-07 21:57:00+03	48800.00
E44F12	2017-08-10 00:18:00+03	7200.00
E44F60	2017-06-30 10:48:00+03	12600.00
E44F8B	2017-08-12 23:33:00+03	85600.00
E44FF7	2017-07-10 15:03:00+03	112000.00
E45038	2017-07-23 07:30:00+03	25100.00
E45084	2017-08-12 00:30:00+03	43200.00
E450EF	2017-07-07 12:58:00+03	37500.00
E45181	2017-07-05 05:15:00+03	92900.00
E451F7	2017-07-30 20:31:00+03	167200.00
E451F8	2017-07-14 14:11:00+03	130000.00
E4524A	2017-07-22 05:22:00+03	81500.00
E4525A	2017-06-30 01:12:00+03	59100.00
E4531F	2017-08-14 03:09:00+03	82000.00
E45345	2017-07-29 06:30:00+03	14400.00
E453C0	2017-08-04 16:37:00+03	182300.00
E45494	2017-08-03 12:45:00+03	54800.00
E4549A	2017-08-12 15:03:00+03	47200.00
E4550A	2017-07-27 09:22:00+03	6200.00
E4554A	2017-07-04 01:31:00+03	131600.00
E4559E	2017-08-15 03:58:00+03	57700.00
E455C5	2017-07-21 00:16:00+03	52300.00
E4567D	2017-08-09 16:31:00+03	32400.00
E456CD	2017-07-09 21:29:00+03	56000.00
E4570E	2017-08-13 08:14:00+03	46400.00
E45752	2017-08-05 20:10:00+03	24800.00
E45770	2017-07-28 18:50:00+03	133600.00
E457E7	2017-07-25 11:33:00+03	32200.00
E45836	2017-07-25 15:33:00+03	89600.00
E458C0	2017-07-16 22:07:00+03	216900.00
E4590C	2017-07-07 20:41:00+03	22000.00
E4591A	2017-07-17 00:52:00+03	261000.00
E45952	2017-08-11 11:09:00+03	21800.00
E45953	2017-07-22 04:55:00+03	81600.00
E459C3	2017-08-08 06:22:00+03	15700.00
E459E9	2017-08-06 16:26:00+03	21400.00
E459F2	2017-08-12 02:30:00+03	59400.00
E459FF	2017-07-25 02:17:00+03	81900.00
E45A05	2017-07-17 00:58:00+03	68800.00
E45A31	2017-07-16 00:41:00+03	61800.00
E45A81	2017-08-10 10:08:00+03	72400.00
E45ABA	2017-07-17 23:53:00+03	18600.00
E45AC7	2017-07-26 01:58:00+03	31600.00
E45AEF	2017-08-07 08:06:00+03	48200.00
E45AF9	2017-07-12 02:06:00+03	25100.00
E45B12	2017-07-23 17:47:00+03	76400.00
E45B87	2017-08-15 01:04:00+03	123900.00
E45BC0	2017-07-08 02:50:00+03	111600.00
E45C0A	2017-06-25 01:14:00+03	48800.00
E45C29	2017-07-27 22:16:00+03	50800.00
E45D10	2017-07-03 16:56:00+03	57400.00
E45D2C	2017-07-15 23:19:00+03	38600.00
E45D83	2017-07-11 23:26:00+03	23600.00
E45D87	2017-08-12 20:38:00+03	46000.00
E45DCA	2017-08-08 20:59:00+03	14400.00
E45DCC	2017-07-17 18:34:00+03	47000.00
E45DCD	2017-07-21 00:57:00+03	14000.00
E45EBC	2017-08-06 08:05:00+03	393000.00
E45EF4	2017-07-15 18:25:00+03	167400.00
E45F34	2017-07-23 06:54:00+03	119500.00
E45F96	2017-07-28 22:11:00+03	181600.00
E45FA6	2017-08-13 09:50:00+03	29600.00
E45FCB	2017-07-11 20:10:00+03	66300.00
E45FD1	2017-07-13 22:01:00+03	45100.00
E45FD6	2017-08-07 13:35:00+03	45200.00
E45FE2	2017-08-05 08:05:00+03	25900.00
E45FEE	2017-08-09 19:35:00+03	6000.00
E46014	2017-07-29 06:06:00+03	111600.00
E46035	2017-07-20 03:07:00+03	48400.00
E46120	2017-08-09 17:48:00+03	173600.00
E4621A	2017-08-08 12:10:00+03	102100.00
E46285	2017-07-11 13:23:00+03	50200.00
E4629B	2017-08-01 15:35:00+03	6000.00
E462A7	2017-07-16 00:03:00+03	78100.00
E462BA	2017-08-08 10:17:00+03	144000.00
E462D2	2017-07-11 08:48:00+03	87900.00
E462DD	2017-07-21 18:14:00+03	79600.00
E4630E	2017-07-26 14:40:00+03	27400.00
E4630F	2017-07-27 13:15:00+03	6700.00
E4639C	2017-07-21 00:28:00+03	28800.00
E46419	2017-07-04 09:19:00+03	122000.00
E46449	2017-07-25 16:07:00+03	49600.00
E464C9	2017-07-30 15:52:00+03	68000.00
E46527	2017-07-27 16:08:00+03	134300.00
E4654C	2017-07-01 02:11:00+03	189200.00
E46557	2017-07-12 16:11:00+03	68100.00
E465C5	2017-07-21 13:31:00+03	49100.00
E465F4	2017-07-21 07:27:00+03	132800.00
E46653	2017-08-06 20:44:00+03	132800.00
E46697	2017-07-20 14:45:00+03	62900.00
E466AF	2017-07-21 11:57:00+03	41600.00
E466DB	2017-08-13 11:09:00+03	24000.00
E46719	2017-07-03 19:04:00+03	166000.00
E46729	2017-07-10 11:45:00+03	289800.00
E46753	2017-07-05 20:41:00+03	55800.00
E467B1	2017-06-30 16:18:00+03	318200.00
E467B4	2017-07-28 19:53:00+03	46000.00
E467DF	2017-08-06 22:16:00+03	62800.00
E467F9	2017-07-29 00:45:00+03	159800.00
E468AB	2017-07-13 18:36:00+03	55600.00
E468B9	2017-08-09 21:47:00+03	43600.00
E468E2	2017-08-14 12:49:00+03	26800.00
E4691F	2017-07-26 01:15:00+03	105600.00
E469B2	2017-08-14 21:19:00+03	492000.00
E46A0A	2017-08-01 19:45:00+03	147700.00
E46A78	2017-07-03 04:55:00+03	69100.00
E46AB7	2017-08-03 12:15:00+03	185300.00
E46B3D	2017-07-05 14:36:00+03	133100.00
E46B4C	2017-07-06 07:08:00+03	59800.00
E46B4E	2017-08-06 00:46:00+03	81300.00
E46CB1	2017-07-08 02:34:00+03	223700.00
E46D06	2017-07-06 07:42:00+03	70700.00
E46D0B	2017-07-30 08:34:00+03	28000.00
E46D3B	2017-07-22 16:01:00+03	26000.00
E46D81	2017-07-28 14:23:00+03	75300.00
E46DB6	2017-08-02 05:35:00+03	111600.00
E46F5E	2017-07-06 13:26:00+03	96300.00
E46F6E	2017-07-26 21:51:00+03	30000.00
E46F8F	2017-08-10 21:37:00+03	48300.00
E47008	2017-08-08 03:25:00+03	90800.00
E47040	2017-07-16 00:40:00+03	36200.00
E4709F	2017-07-04 22:45:00+03	69700.00
E470D9	2017-08-11 23:52:00+03	23400.00
E4713E	2017-08-13 01:12:00+03	32800.00
E4714E	2017-08-08 17:31:00+03	70800.00
E47180	2017-08-10 20:53:00+03	72200.00
E47183	2017-06-29 14:51:00+03	85000.00
E471EF	2017-08-05 06:06:00+03	56000.00
E47204	2017-07-24 01:26:00+03	40000.00
E47209	2017-07-06 03:15:00+03	48100.00
E4720E	2017-08-14 21:33:00+03	23400.00
E47216	2017-08-08 23:48:00+03	50600.00
E472B4	2017-08-01 13:01:00+03	68100.00
E472DB	2017-07-18 01:11:00+03	96100.00
E47328	2017-08-05 12:53:00+03	44800.00
E4733E	2017-08-09 15:44:00+03	13400.00
E47374	2017-08-06 23:01:00+03	54500.00
E47378	2017-07-21 18:45:00+03	72200.00
E473C6	2017-07-25 02:23:00+03	21400.00
E473DD	2017-07-10 13:33:00+03	34000.00
E473F8	2017-08-14 10:10:00+03	386400.00
E47432	2017-08-12 20:26:00+03	46000.00
E4745F	2017-07-28 13:41:00+03	43500.00
E47465	2017-08-06 18:36:00+03	62400.00
E4746A	2017-07-01 13:21:00+03	20200.00
E4757B	2017-08-04 01:25:00+03	32800.00
E475C7	2017-07-28 11:56:00+03	71600.00
E475D6	2017-08-04 22:23:00+03	13000.00
E47608	2017-08-04 06:45:00+03	58600.00
E476A7	2017-07-26 19:54:00+03	131600.00
E476C6	2017-07-09 15:36:00+03	12600.00
E47764	2017-08-05 08:39:00+03	46400.00
E4777B	2017-08-01 13:00:00+03	38800.00
E4777D	2017-07-16 10:41:00+03	31700.00
E477BE	2017-07-27 17:11:00+03	50800.00
E477D9	2017-07-01 20:30:00+03	246000.00
E47805	2017-08-02 19:34:00+03	17800.00
E47853	2017-07-22 22:30:00+03	185100.00
E478D8	2017-07-31 06:08:00+03	131900.00
E47918	2017-08-02 22:13:00+03	12600.00
E47938	2017-07-06 20:34:00+03	70700.00
E479E2	2017-07-23 09:47:00+03	98400.00
E479E7	2017-07-18 08:35:00+03	71600.00
E47A35	2017-07-19 01:17:00+03	67400.00
E47A36	2017-08-07 12:19:00+03	49100.00
E47A50	2017-07-19 21:00:00+03	28000.00
E47A9D	2017-07-23 07:27:00+03	115000.00
E47ACA	2017-08-13 13:55:00+03	135000.00
E47B00	2017-07-28 14:37:00+03	8000.00
E47B33	2017-08-03 00:10:00+03	185000.00
E47B3F	2017-07-06 10:45:00+03	86600.00
E47B92	2017-07-29 09:15:00+03	188000.00
E47BD8	2017-08-14 15:25:00+03	139000.00
E47BFB	2017-07-30 00:10:00+03	73600.00
E47C05	2017-07-06 09:08:00+03	99700.00
E47C2D	2017-07-29 04:25:00+03	147700.00
E47C4F	2017-08-15 10:35:00+03	96300.00
E47C83	2017-07-18 17:21:00+03	44800.00
E47CCB	2017-07-07 02:26:00+03	47400.00
E47D10	2017-07-24 17:54:00+03	8200.00
E47D12	2017-07-14 17:23:00+03	149300.00
E47D23	2017-07-10 15:48:00+03	202300.00
E47D38	2017-07-26 07:44:00+03	131600.00
E47D50	2017-07-16 04:38:00+03	189800.00
E47DFB	2017-07-11 17:56:00+03	94000.00
E47E39	2017-08-12 03:10:00+03	55800.00
E47E53	2017-07-24 14:54:00+03	75600.00
E47E77	2017-07-14 00:01:00+03	23200.00
E47EA9	2017-07-31 16:19:00+03	53500.00
E47EE5	2017-07-16 02:49:00+03	55800.00
E47F00	2017-07-06 15:40:00+03	35600.00
E47F28	2017-07-21 09:35:00+03	174500.00
E47F45	2017-07-25 15:18:00+03	23200.00
E47F57	2017-07-30 12:35:00+03	170700.00
E47F5A	2017-08-05 07:48:00+03	56100.00
E47F67	2017-08-07 13:58:00+03	170800.00
E47FA2	2017-07-12 02:45:00+03	39300.00
E48007	2017-07-10 11:10:00+03	16400.00
E48058	2017-07-26 12:10:00+03	30700.00
E48079	2017-07-13 13:32:00+03	84500.00
E4808A	2017-08-01 20:25:00+03	40400.00
E480BA	2017-07-29 14:42:00+03	105100.00
E480D3	2017-08-15 00:11:00+03	29600.00
E480E2	2017-07-20 16:54:00+03	133100.00
E480F1	2017-08-09 11:09:00+03	108500.00
E4815A	2017-07-30 22:14:00+03	24000.00
E481B2	2017-07-21 14:52:00+03	70100.00
E481B4	2017-08-10 06:09:00+03	38800.00
E48208	2017-07-09 04:28:00+03	147000.00
E4822A	2017-07-08 13:08:00+03	271100.00
E482A0	2017-08-14 20:59:00+03	90700.00
E482E1	2017-07-07 15:33:00+03	40000.00
E4831F	2017-07-04 10:20:00+03	23400.00
E48324	2017-07-31 17:15:00+03	48500.00
E48362	2017-07-11 02:03:00+03	84000.00
E48386	2017-07-11 05:58:00+03	101200.00
E483A7	2017-07-02 21:59:00+03	30800.00
E483D5	2017-08-11 11:57:00+03	199600.00
E48489	2017-08-13 06:58:00+03	194700.00
E484C8	2017-07-10 20:31:00+03	115600.00
E4850A	2017-07-25 17:20:00+03	43200.00
E4852F	2017-08-15 16:26:00+03	46300.00
E48539	2017-07-14 23:28:00+03	6300.00
E4855C	2017-07-14 15:33:00+03	164400.00
E485A5	2017-07-19 19:58:00+03	172300.00
E485B6	2017-07-10 16:24:00+03	47000.00
E485D5	2017-07-04 05:27:00+03	213200.00
E4866E	2017-08-14 03:31:00+03	26000.00
E48677	2017-07-04 22:12:00+03	164700.00
E4867A	2017-07-21 00:49:00+03	6000.00
E486B6	2017-08-07 03:31:00+03	67600.00
E486D7	2017-07-12 16:44:00+03	69000.00
E486EC	2017-07-07 00:49:00+03	25600.00
E486FD	2017-08-12 23:30:00+03	77000.00
E486FF	2017-07-25 13:13:00+03	28800.00
E48702	2017-08-09 05:20:00+03	44000.00
E4873C	2017-07-05 16:20:00+03	126700.00
E4878C	2017-07-12 23:46:00+03	44800.00
E48791	2017-07-11 08:55:00+03	80900.00
E487AA	2017-07-06 16:07:00+03	92000.00
E487EB	2017-07-08 17:54:00+03	12600.00
E487EC	2017-07-19 15:37:00+03	49800.00
E487F0	2017-07-17 15:19:00+03	133200.00
E4881D	2017-08-05 11:05:00+03	13400.00
E48887	2017-08-04 21:15:00+03	46000.00
E488A7	2017-07-08 07:57:00+03	92400.00
E488D0	2017-07-20 13:19:00+03	58600.00
E4891E	2017-07-29 08:08:00+03	67600.00
E4896F	2017-08-10 05:09:00+03	20400.00
E4897D	2017-07-09 05:23:00+03	67600.00
E4897F	2017-08-05 09:02:00+03	59800.00
E489A2	2017-07-20 23:28:00+03	36200.00
E489D7	2017-08-05 19:54:00+03	46000.00
E48A2F	2017-07-07 12:53:00+03	54400.00
E48A74	2017-07-19 04:35:00+03	31400.00
E48AB6	2017-08-15 07:38:00+03	47800.00
E48B0C	2017-07-25 16:56:00+03	57500.00
E48B23	2017-07-08 19:38:00+03	32800.00
E48B83	2017-07-07 17:29:00+03	208200.00
E48C48	2017-07-06 06:39:00+03	73400.00
E48CAE	2017-07-13 18:55:00+03	75300.00
E48D26	2017-07-07 17:48:00+03	241500.00
E48D2E	2017-07-31 20:43:00+03	29600.00
E48D40	2017-07-01 07:06:00+03	209900.00
E48D98	2017-07-16 11:00:00+03	56000.00
E48DE2	2017-08-02 16:58:00+03	6000.00
E48E2C	2017-08-04 21:12:00+03	62600.00
E48ECD	2017-07-02 07:27:00+03	83500.00
E48F0B	2017-07-23 09:53:00+03	150600.00
E48F4B	2017-07-16 01:32:00+03	53500.00
E48F81	2017-07-07 02:26:00+03	185600.00
E48FA1	2017-07-02 18:39:00+03	10700.00
E48FEB	2017-07-30 21:19:00+03	55600.00
E4909D	2017-08-10 16:43:00+03	131100.00
E490A1	2017-08-10 16:53:00+03	12400.00
E490CA	2017-07-27 00:10:00+03	147000.00
E490CB	2017-07-11 10:17:00+03	73300.00
E490DA	2017-08-06 14:46:00+03	46800.00
E490F7	2017-07-07 00:46:00+03	20000.00
E49168	2017-07-29 01:11:00+03	129700.00
E49192	2017-07-06 20:23:00+03	46900.00
E491B5	2017-07-28 10:24:00+03	23400.00
E49219	2017-07-30 20:57:00+03	36600.00
E49263	2017-07-15 11:58:00+03	92800.00
E49279	2017-08-10 04:22:00+03	104700.00
E4927A	2017-08-13 12:23:00+03	99000.00
E492A3	2017-07-21 17:13:00+03	67000.00
E4934A	2017-07-10 13:42:00+03	28300.00
E4942A	2017-08-05 14:41:00+03	34000.00
E49435	2017-07-25 04:00:00+03	27200.00
E49442	2017-08-13 07:33:00+03	73600.00
E49496	2017-07-04 06:57:00+03	10600.00
E49580	2017-07-31 02:06:00+03	36200.00
E49595	2017-07-22 11:58:00+03	75300.00
E495C5	2017-07-20 12:46:00+03	54800.00
E4963B	2017-08-13 04:21:00+03	50000.00
E49644	2017-07-08 19:39:00+03	85000.00
E4964C	2017-08-12 01:45:00+03	79000.00
E49668	2017-07-04 23:55:00+03	28000.00
E496AC	2017-07-03 01:27:00+03	156500.00
E496EB	2017-08-02 21:07:00+03	69500.00
E496FD	2017-07-30 02:42:00+03	126400.00
E49725	2017-07-14 09:10:00+03	22000.00
E4977C	2017-07-19 19:39:00+03	51800.00
E497D0	2017-07-03 13:57:00+03	193500.00
E497F0	2017-08-09 22:55:00+03	198400.00
E4980C	2017-07-17 15:20:00+03	23400.00
E49838	2017-07-28 10:39:00+03	13000.00
E49870	2017-07-07 10:26:00+03	33600.00
E49890	2017-07-13 18:04:00+03	29400.00
E49908	2017-07-13 11:51:00+03	114800.00
E49930	2017-07-01 12:51:00+03	22000.00
E4993C	2017-07-20 23:29:00+03	56000.00
E49954	2017-08-01 20:37:00+03	128800.00
E4997E	2017-07-01 22:50:00+03	40000.00
E499A1	2017-08-02 11:05:00+03	39800.00
E499A6	2017-07-08 07:03:00+03	29600.00
E499B8	2017-08-13 17:09:00+03	75800.00
E499ED	2017-07-08 09:47:00+03	39600.00
E49A56	2017-08-01 14:47:00+03	189200.00
E49A82	2017-07-10 03:24:00+03	28000.00
E49B79	2017-07-13 03:24:00+03	21400.00
E49BED	2017-07-31 21:30:00+03	46400.00
E49C21	2017-07-28 22:23:00+03	34100.00
E49C30	2017-07-21 21:14:00+03	59800.00
E49C83	2017-07-21 04:31:00+03	58600.00
E49C93	2017-08-07 10:57:00+03	47000.00
E49CA2	2017-08-14 18:47:00+03	53100.00
E49CB0	2017-07-11 20:56:00+03	94000.00
E49D60	2017-07-30 03:38:00+03	124200.00
E49D71	2017-08-04 05:34:00+03	46000.00
E49D90	2017-07-13 21:41:00+03	55800.00
E49DCF	2017-08-01 05:19:00+03	64200.00
E49E1E	2017-08-06 23:58:00+03	67600.00
E49E76	2017-08-07 17:36:00+03	94000.00
E49EE3	2017-07-19 13:54:00+03	24400.00
E49F03	2017-07-21 12:33:00+03	114200.00
E49F24	2017-08-11 06:17:00+03	26000.00
E49F5B	2017-07-18 19:45:00+03	75300.00
E49F74	2017-07-22 11:43:00+03	19600.00
E49FB6	2017-08-14 00:33:00+03	247700.00
E4A007	2017-07-26 02:14:00+03	271200.00
E4A02E	2017-07-26 00:40:00+03	128800.00
E4A06B	2017-08-03 02:35:00+03	25400.00
E4A13B	2017-07-20 04:15:00+03	65600.00
E4A17A	2017-07-09 20:47:00+03	40400.00
E4A317	2017-07-28 08:55:00+03	111600.00
E4A429	2017-07-19 04:46:00+03	6700.00
E4A466	2017-08-11 10:07:00+03	146300.00
E4A486	2017-08-15 02:52:00+03	187800.00
E4A4B3	2017-07-05 02:23:00+03	189800.00
E4A4E4	2017-08-12 14:04:00+03	95700.00
E4A52A	2017-08-10 22:09:00+03	97900.00
E4A594	2017-07-18 11:36:00+03	123600.00
E4A5AD	2017-06-29 23:05:00+03	116800.00
E4A683	2017-07-30 04:33:00+03	34600.00
E4A6D0	2017-07-01 10:56:00+03	28000.00
E4A6ED	2017-07-06 08:05:00+03	132800.00
E4A6F7	2017-07-26 17:31:00+03	65200.00
E4A718	2017-07-08 21:02:00+03	94200.00
E4A728	2017-08-03 09:06:00+03	147800.00
E4A72A	2017-07-24 04:24:00+03	100600.00
E4A73D	2017-07-11 05:57:00+03	516800.00
E4A796	2017-07-16 22:31:00+03	86600.00
E4A7A4	2017-08-15 13:42:00+03	246000.00
E4A7BA	2017-07-31 03:43:00+03	92800.00
E4A7FA	2017-08-15 06:36:00+03	43500.00
E4A7FC	2017-07-29 04:21:00+03	39200.00
E4A7FD	2017-08-07 19:33:00+03	52800.00
E4A804	2017-08-07 02:50:00+03	163100.00
E4A837	2017-08-11 19:47:00+03	23600.00
E4A862	2017-07-12 02:55:00+03	88600.00
E4A890	2017-07-30 11:04:00+03	101200.00
E4A915	2017-07-11 08:20:00+03	64700.00
E4A9E0	2017-08-02 08:03:00+03	67700.00
E4AA28	2017-07-31 12:58:00+03	160800.00
E4AA3D	2017-07-14 16:00:00+03	32800.00
E4AA59	2017-08-11 03:06:00+03	86500.00
E4AA64	2017-08-02 10:05:00+03	259000.00
E4AADC	2017-08-02 11:11:00+03	133200.00
E4AADD	2017-07-06 03:59:00+03	56000.00
E4AB04	2017-07-05 07:21:00+03	225200.00
E4AB05	2017-07-29 22:00:00+03	20000.00
E4AB4A	2017-07-11 09:45:00+03	23600.00
E4AB77	2017-08-06 03:06:00+03	167500.00
E4AB8E	2017-07-26 08:00:00+03	54800.00
E4AB95	2017-08-08 06:08:00+03	48500.00
E4ABA8	2017-07-11 22:04:00+03	28800.00
E4ABEB	2017-07-08 08:54:00+03	35600.00
E4AC35	2017-07-14 03:01:00+03	67400.00
E4ACBE	2017-08-08 22:29:00+03	147600.00
E4ACC2	2017-07-30 18:40:00+03	47800.00
E4ACC4	2017-08-11 16:14:00+03	19600.00
E4ACCC	2017-07-18 10:59:00+03	137700.00
E4ACFE	2017-08-14 21:37:00+03	13400.00
E4ADAE	2017-08-13 19:55:00+03	67100.00
E4ADE7	2017-07-28 10:00:00+03	20400.00
E4ADF4	2017-07-05 13:59:00+03	62000.00
E4AE01	2017-07-15 21:46:00+03	50600.00
E4AE3E	2017-07-07 18:59:00+03	69500.00
E4AE5A	2017-07-18 22:57:00+03	55100.00
E4AEAD	2017-07-04 07:05:00+03	398500.00
E4AF6B	2017-08-03 18:48:00+03	14000.00
E4AFC2	2017-08-01 04:29:00+03	23400.00
E4AFC3	2017-07-03 06:56:00+03	45200.00
E4B012	2017-07-15 08:44:00+03	97700.00
E4B019	2017-07-20 05:14:00+03	96100.00
E4B03E	2017-07-16 08:27:00+03	72800.00
E4B041	2017-08-13 20:12:00+03	226200.00
E4B05A	2017-07-10 17:04:00+03	51900.00
E4B07F	2017-08-02 09:30:00+03	136200.00
E4B0E1	2017-08-12 06:01:00+03	94900.00
E4B0F1	2017-07-26 11:51:00+03	14400.00
E4B121	2017-07-24 18:53:00+03	7400.00
E4B1DE	2017-07-13 16:45:00+03	28800.00
E4B1E5	2017-08-04 20:02:00+03	25800.00
E4B21E	2017-08-05 19:52:00+03	55800.00
E4B24D	2017-07-01 03:25:00+03	32700.00
E4B254	2017-08-10 20:04:00+03	52400.00
E4B278	2017-08-14 01:03:00+03	21400.00
E4B293	2017-08-10 07:55:00+03	38400.00
E4B344	2017-08-12 08:56:00+03	54000.00
E4B348	2017-08-15 12:09:00+03	28000.00
E4B367	2017-07-31 16:52:00+03	135400.00
E4B3A0	2017-06-28 21:13:00+03	69500.00
E4B41E	2017-08-04 16:55:00+03	111600.00
E4B447	2017-08-09 23:26:00+03	18000.00
E4B454	2017-07-22 17:35:00+03	19600.00
E4B4FB	2017-08-12 02:58:00+03	8000.00
E4B51E	2017-08-05 15:20:00+03	40000.00
E4B520	2017-07-03 15:31:00+03	238000.00
E4B560	2017-07-21 15:39:00+03	75300.00
E4B57A	2017-08-15 15:47:00+03	242600.00
E4B622	2017-07-24 04:17:00+03	40000.00
E4B633	2017-07-27 03:04:00+03	67200.00
E4B65A	2017-07-14 04:06:00+03	6600.00
E4B666	2017-08-01 22:50:00+03	45000.00
E4B6CB	2017-06-30 11:48:00+03	24200.00
E4B6F3	2017-07-01 17:34:00+03	93700.00
E4B703	2017-06-29 16:27:00+03	69500.00
E4B723	2017-07-31 04:53:00+03	10600.00
E4B72B	2017-07-15 17:56:00+03	13000.00
E4B740	2017-07-08 21:27:00+03	14000.00
E4B74C	2017-07-13 05:43:00+03	27800.00
E4B77E	2017-07-13 16:15:00+03	44600.00
E4B789	2017-08-11 22:50:00+03	43200.00
E4B7D1	2017-07-14 14:24:00+03	46400.00
E4B80B	2017-06-28 20:29:00+03	27600.00
E4B821	2017-08-15 08:29:00+03	24400.00
E4B82C	2017-07-09 10:13:00+03	26900.00
E4B82D	2017-07-05 15:41:00+03	55800.00
E4B830	2017-08-13 18:29:00+03	75800.00
E4B84F	2017-07-02 01:01:00+03	55800.00
E4B89E	2017-08-10 12:39:00+03	25000.00
E4B909	2017-08-10 17:23:00+03	167800.00
E4B915	2017-08-02 03:57:00+03	173800.00
E4B99E	2017-07-15 23:44:00+03	19600.00
E4BA46	2017-08-12 08:11:00+03	37600.00
E4BAA0	2017-06-29 01:15:00+03	123000.00
E4BADC	2017-07-05 08:56:00+03	76600.00
E4BB5B	2017-07-26 01:21:00+03	76400.00
E4BB7D	2017-07-30 01:18:00+03	57600.00
E4BBA6	2017-07-24 03:18:00+03	27800.00
E4BBB6	2017-06-29 09:50:00+03	369000.00
E4BBB9	2017-07-27 18:20:00+03	29400.00
E4BBD2	2017-06-28 17:58:00+03	55800.00
E4BE08	2017-07-27 01:40:00+03	39500.00
E4BE5C	2017-07-30 00:48:00+03	39200.00
E4BE68	2017-07-21 21:35:00+03	132800.00
E4BF08	2017-07-08 04:27:00+03	47500.00
E4BF69	2017-07-20 18:50:00+03	37200.00
E4BF6C	2017-07-17 04:34:00+03	271100.00
E4BF84	2017-07-06 02:08:00+03	140000.00
E4BFA4	2017-07-02 18:33:00+03	50600.00
E4C022	2017-07-17 02:32:00+03	39400.00
E4C024	2017-07-02 06:24:00+03	50400.00
E4C0B5	2017-07-14 16:14:00+03	75600.00
E4C0CD	2017-07-10 11:45:00+03	91700.00
E4C0D4	2017-07-13 23:48:00+03	27800.00
E4C10F	2017-08-08 07:35:00+03	37900.00
E4C138	2017-07-14 17:19:00+03	13200.00
E4C1D2	2017-08-11 06:14:00+03	83000.00
E4C294	2017-07-03 02:54:00+03	101200.00
E4C2B8	2017-08-02 10:08:00+03	117600.00
E4C2C2	2017-07-19 15:10:00+03	60400.00
E4C2D7	2017-07-23 23:38:00+03	46400.00
E4C365	2017-08-07 05:19:00+03	56100.00
E4C393	2017-08-06 19:13:00+03	318800.00
E4C4A2	2017-07-10 03:07:00+03	23400.00
E4C4F4	2017-07-07 05:54:00+03	68000.00
E4C553	2017-06-30 07:55:00+03	147700.00
E4C56A	2017-08-03 15:43:00+03	135400.00
E4C5AF	2017-08-07 04:01:00+03	77500.00
E4C5D1	2017-07-11 04:07:00+03	118500.00
E4C5E2	2017-07-23 01:18:00+03	128800.00
E4C5FD	2017-07-21 15:10:00+03	223200.00
E4C640	2017-07-22 09:17:00+03	67800.00
E4C66C	2017-08-08 08:32:00+03	50800.00
E4C66E	2017-08-11 02:07:00+03	26300.00
E4C748	2017-07-04 23:33:00+03	108100.00
E4C77B	2017-08-03 03:44:00+03	111600.00
E4C7AE	2017-07-14 02:58:00+03	59800.00
E4C80B	2017-08-15 02:13:00+03	67100.00
E4C818	2017-08-14 07:53:00+03	35400.00
E4C822	2017-07-10 19:45:00+03	46800.00
E4C868	2017-07-25 19:19:00+03	44600.00
E4C915	2017-07-27 06:08:00+03	6000.00
E4C92A	2017-08-14 06:29:00+03	4200.00
E4C98E	2017-08-08 10:20:00+03	169900.00
E4C995	2017-07-30 15:32:00+03	31600.00
E4C9B8	2017-07-19 04:09:00+03	12600.00
E4CA81	2017-07-09 08:07:00+03	6000.00
E4CAC9	2017-08-10 04:08:00+03	385000.00
E4CAD8	2017-07-14 00:07:00+03	56000.00
E4CAEA	2017-08-14 07:20:00+03	187400.00
E4CAFE	2017-07-14 20:25:00+03	26800.00
E4CB3D	2017-07-30 11:18:00+03	114100.00
E4CB62	2017-08-10 18:52:00+03	14400.00
E4CBD4	2017-07-06 06:03:00+03	103500.00
E4CC22	2017-07-14 06:50:00+03	72600.00
E4CC46	2017-07-02 05:51:00+03	99300.00
E4CC53	2017-08-10 02:38:00+03	96500.00
E4CC78	2017-08-03 12:55:00+03	112000.00
E4CCB0	2017-08-14 17:20:00+03	68000.00
E4CD06	2017-08-10 11:48:00+03	52700.00
E4CD8F	2017-07-10 13:38:00+03	272400.00
E4CD92	2017-06-28 17:51:00+03	64600.00
E4CD9A	2017-08-01 17:39:00+03	28800.00
E4CECE	2017-07-24 19:31:00+03	27200.00
E4CEE7	2017-07-15 17:35:00+03	12600.00
E4CEF5	2017-08-05 06:57:00+03	19800.00
E4CF53	2017-07-30 22:11:00+03	113200.00
E4CF90	2017-07-08 11:08:00+03	29800.00
E4D000	2017-07-22 18:02:00+03	23200.00
E4D085	2017-07-19 20:45:00+03	14000.00
E4D153	2017-08-14 13:01:00+03	24400.00
E4D158	2017-07-13 23:33:00+03	73500.00
E4D162	2017-07-28 19:06:00+03	46500.00
E4D207	2017-07-22 02:00:00+03	57300.00
E4D216	2017-07-16 11:39:00+03	124000.00
E4D22F	2017-07-25 10:32:00+03	35800.00
E4D289	2017-07-27 13:33:00+03	80900.00
E4D293	2017-07-05 00:00:00+03	130400.00
E4D2C6	2017-07-25 22:01:00+03	68400.00
E4D306	2017-08-08 02:09:00+03	92100.00
E4D353	2017-07-07 21:59:00+03	43100.00
E4D386	2017-07-20 06:18:00+03	86600.00
E4D3B8	2017-07-22 21:21:00+03	206100.00
E4D3E5	2017-07-20 17:25:00+03	58000.00
E4D3E9	2017-06-30 06:58:00+03	31100.00
E4D42A	2017-07-14 11:42:00+03	28000.00
E4D44B	2017-08-04 10:51:00+03	24400.00
E4D45E	2017-07-28 03:07:00+03	133600.00
E4D4A1	2017-08-04 07:20:00+03	30000.00
E4D4DF	2017-07-02 12:43:00+03	265700.00
E4D4F3	2017-07-31 13:26:00+03	142400.00
E4D5B9	2017-07-14 23:53:00+03	152500.00
E4D5BC	2017-07-27 20:10:00+03	124200.00
E4D6C4	2017-07-10 21:04:00+03	38200.00
E4D768	2017-08-07 13:27:00+03	47100.00
E4D7C8	2017-06-28 15:26:00+03	86600.00
E4D867	2017-07-29 23:15:00+03	46200.00
E4D89D	2017-07-01 16:31:00+03	113200.00
E4D8DF	2017-07-31 09:18:00+03	79900.00
E4D94F	2017-07-21 13:16:00+03	75600.00
E4D968	2017-08-13 07:17:00+03	134400.00
E4DA22	2017-07-04 17:32:00+03	117700.00
E4DA25	2017-07-07 12:04:00+03	39300.00
E4DA4D	2017-08-01 07:12:00+03	12600.00
E4DA5C	2017-08-13 07:22:00+03	114800.00
E4DA88	2017-08-11 16:09:00+03	498200.00
E4DABB	2017-07-11 08:31:00+03	18100.00
E4DAE0	2017-07-12 16:35:00+03	56900.00
E4DB40	2017-08-15 11:25:00+03	123000.00
E4DB69	2017-08-09 09:16:00+03	133100.00
E4DBEC	2017-07-23 12:22:00+03	46400.00
E4DBF1	2017-07-09 18:02:00+03	129200.00
E4DBFF	2017-07-31 09:14:00+03	64500.00
E4DCA2	2017-07-02 17:01:00+03	26800.00
E4DCCF	2017-08-04 05:43:00+03	26000.00
E4DE59	2017-08-02 06:10:00+03	41800.00
E4DE9B	2017-07-19 15:42:00+03	29100.00
E4DF0D	2017-07-09 15:15:00+03	46000.00
E4DF76	2017-07-15 05:49:00+03	36200.00
E4E020	2017-08-08 18:56:00+03	131100.00
E4E0B5	2017-06-28 14:50:00+03	86400.00
E4E0BA	2017-06-27 17:48:00+03	22000.00
E4E141	2017-07-04 11:50:00+03	73300.00
E4E146	2017-07-10 12:47:00+03	12600.00
E4E155	2017-07-04 04:55:00+03	246000.00
E4E16C	2017-07-11 17:29:00+03	31900.00
E4E18F	2017-08-11 14:44:00+03	56000.00
E4E271	2017-07-23 23:44:00+03	20400.00
E4E2EC	2017-08-14 00:51:00+03	28700.00
E4E2FF	2017-08-14 18:18:00+03	68400.00
E4E32D	2017-07-23 18:55:00+03	10600.00
E4E34D	2017-07-20 09:23:00+03	28000.00
E4E418	2017-07-16 02:09:00+03	73100.00
E4E43A	2017-08-11 10:10:00+03	47000.00
E4E482	2017-07-17 08:34:00+03	6000.00
E4E4E8	2017-07-23 17:27:00+03	29600.00
E4E4ED	2017-07-16 03:00:00+03	52300.00
E4E517	2017-07-10 09:23:00+03	223200.00
E4E695	2017-08-06 08:01:00+03	242900.00
E4E69C	2017-07-24 20:14:00+03	124300.00
E4E6AE	2017-08-04 10:42:00+03	59200.00
E4E6DB	2017-07-31 02:16:00+03	72400.00
E4E71B	2017-08-10 22:06:00+03	26800.00
E4E75E	2017-07-26 03:28:00+03	46300.00
E4E762	2017-07-21 00:59:00+03	25800.00
E4E792	2017-07-14 04:46:00+03	38800.00
E4E881	2017-07-09 19:34:00+03	114800.00
E4E8EF	2017-07-01 10:37:00+03	91300.00
E4E8FA	2017-07-07 23:36:00+03	48400.00
E4E922	2017-07-19 22:14:00+03	61600.00
E4E99F	2017-07-22 20:49:00+03	90400.00
E4E9F6	2017-07-22 22:03:00+03	12000.00
E4EA44	2017-07-19 00:47:00+03	14000.00
E4EA7D	2017-08-02 13:01:00+03	73300.00
E4EAC4	2017-08-04 22:20:00+03	122400.00
E4EAE1	2017-07-08 22:56:00+03	184300.00
E4EB0A	2017-07-31 01:01:00+03	147700.00
E4EB79	2017-08-11 12:54:00+03	67400.00
E4EC06	2017-08-02 06:43:00+03	642800.00
E4ECEF	2017-08-11 04:58:00+03	6000.00
E4ED3A	2017-08-14 11:38:00+03	22600.00
E4ED68	2017-07-11 10:29:00+03	27000.00
E4ED80	2017-07-18 19:26:00+03	47400.00
E4ED88	2017-07-07 13:51:00+03	22400.00
E4EDB1	2017-07-09 20:37:00+03	170000.00
E4EDEA	2017-07-14 08:10:00+03	13000.00
E4EE1C	2017-08-03 18:13:00+03	100600.00
E4EE62	2017-07-16 09:46:00+03	43600.00
E4EE86	2017-07-20 20:21:00+03	93500.00
E4EE99	2017-08-05 16:57:00+03	55800.00
E4EE9A	2017-06-30 09:24:00+03	249900.00
E4EEA9	2017-08-10 10:37:00+03	52600.00
E4EEEB	2017-08-06 10:33:00+03	28000.00
E4EF37	2017-07-08 14:28:00+03	27200.00
E4EF3B	2017-07-10 04:56:00+03	41400.00
E4EF66	2017-07-31 13:12:00+03	56900.00
E4EF67	2017-08-02 00:40:00+03	81600.00
E4F042	2017-07-15 08:45:00+03	12600.00
E4F083	2017-07-05 01:11:00+03	28000.00
E4F0A4	2017-07-06 22:28:00+03	23100.00
E4F0ED	2017-08-09 14:07:00+03	118500.00
E4F120	2017-08-04 03:08:00+03	35200.00
E4F183	2017-07-18 00:51:00+03	89000.00
E4F29C	2017-07-29 04:05:00+03	47000.00
E4F2AE	2017-07-14 15:26:00+03	56000.00
E4F2C6	2017-08-05 08:48:00+03	70400.00
E4F33E	2017-07-03 07:23:00+03	77000.00
E4F35E	2017-08-09 06:59:00+03	31600.00
E4F373	2017-07-18 19:43:00+03	54500.00
E4F39C	2017-08-14 18:13:00+03	54000.00
E4F3BA	2017-07-11 14:49:00+03	55800.00
E4F3C8	2017-08-01 00:10:00+03	29600.00
E4F3EC	2017-07-24 08:11:00+03	87100.00
E4F401	2017-07-22 12:27:00+03	72600.00
E4F412	2017-07-18 16:01:00+03	111600.00
E4F44B	2017-08-07 00:08:00+03	69200.00
E4F4A9	2017-07-12 22:15:00+03	31600.00
E4F51E	2017-08-13 02:48:00+03	46400.00
E4F571	2017-08-06 07:41:00+03	28000.00
E4F5E6	2017-07-04 14:10:00+03	193900.00
E4F5F4	2017-07-07 22:14:00+03	28000.00
E4F604	2017-07-03 14:37:00+03	54800.00
E4F63F	2017-07-17 05:25:00+03	28000.00
E4F686	2017-07-08 18:31:00+03	51800.00
E4F6A7	2017-07-29 13:16:00+03	56600.00
E4F6BC	2017-07-18 15:16:00+03	31100.00
E4F81F	2017-08-11 03:41:00+03	260900.00
E4F857	2017-08-02 18:38:00+03	28000.00
E4F88F	2017-08-02 03:58:00+03	51600.00
E4F8CC	2017-07-15 23:50:00+03	115700.00
E4F908	2017-07-19 05:25:00+03	73000.00
E4F931	2017-06-28 10:30:00+03	85000.00
E4F968	2017-07-07 03:47:00+03	180800.00
E4FA57	2017-08-11 16:16:00+03	13400.00
E4FA59	2017-08-08 21:51:00+03	153000.00
E4FA9C	2017-07-16 00:23:00+03	36200.00
E4FAB9	2017-07-12 03:33:00+03	139500.00
E4FAC3	2017-08-04 19:28:00+03	34000.00
E4FB2D	2017-07-16 11:00:00+03	56000.00
E4FB44	2017-07-11 08:57:00+03	14800.00
E4FBA6	2017-07-19 06:44:00+03	32800.00
E4FBC1	2017-07-05 05:44:00+03	79800.00
E4FBF5	2017-08-07 02:38:00+03	84600.00
E4FC1D	2017-08-01 04:43:00+03	23600.00
E4FC2D	2017-08-13 08:17:00+03	52400.00
E4FC2F	2017-07-02 21:50:00+03	31600.00
E4FC30	2017-07-27 13:23:00+03	149300.00
E4FCD5	2017-07-06 16:03:00+03	24400.00
E4FD39	2017-07-23 11:37:00+03	57400.00
E4FD86	2017-07-27 22:30:00+03	20200.00
E4FD8B	2017-08-11 19:19:00+03	43800.00
E4FE3B	2017-08-13 06:28:00+03	11000.00
E4FE3E	2017-08-08 10:37:00+03	17800.00
E4FE45	2017-08-09 03:49:00+03	48400.00
E4FE9B	2017-07-20 00:52:00+03	20500.00
E4FEA5	2017-08-11 20:36:00+03	103800.00
E4FEB7	2017-08-10 14:12:00+03	37600.00
E4FEE6	2017-07-23 12:29:00+03	201200.00
E4FF0F	2017-08-01 21:07:00+03	63200.00
E4FF1F	2017-07-23 01:24:00+03	21800.00
E4FF73	2017-08-01 05:08:00+03	48800.00
E4FFDE	2017-07-30 06:25:00+03	65900.00
E50078	2017-07-20 06:16:00+03	8200.00
E50085	2017-08-05 11:31:00+03	36200.00
E50088	2017-07-02 08:38:00+03	153300.00
E500DB	2017-08-07 10:06:00+03	40000.00
E500F1	2017-07-27 22:11:00+03	34000.00
E50100	2017-07-22 17:11:00+03	266400.00
E50149	2017-07-23 17:59:00+03	40600.00
E50176	2017-06-30 22:48:00+03	75300.00
E5017A	2017-07-27 10:46:00+03	64400.00
E50234	2017-08-07 03:49:00+03	47400.00
E50276	2017-07-03 09:18:00+03	32700.00
E5034C	2017-07-07 16:17:00+03	67600.00
E50371	2017-08-02 21:51:00+03	37200.00
E503EF	2017-07-19 18:01:00+03	72200.00
E5042C	2017-07-25 05:16:00+03	12600.00
E5045C	2017-08-08 14:21:00+03	99200.00
E504A5	2017-08-13 00:59:00+03	47000.00
E504AF	2017-08-11 06:52:00+03	133200.00
E504B3	2017-07-03 20:51:00+03	46400.00
E5050E	2017-07-17 04:34:00+03	23600.00
E50516	2017-08-13 08:02:00+03	35200.00
E5051D	2017-07-10 17:03:00+03	129200.00
E5058C	2017-07-15 14:38:00+03	21600.00
E50597	2017-08-13 03:34:00+03	48200.00
E505C9	2017-07-27 17:11:00+03	32400.00
E50615	2017-08-08 03:30:00+03	111600.00
E5062F	2017-08-04 20:55:00+03	56000.00
E50675	2017-08-06 05:50:00+03	394800.00
E50685	2017-08-01 15:22:00+03	11600.00
E506AC	2017-08-09 04:31:00+03	31100.00
E506FE	2017-06-28 04:53:00+03	29200.00
E5072D	2017-07-04 16:39:00+03	53300.00
E507A1	2017-08-03 14:12:00+03	214100.00
E507BB	2017-07-07 16:20:00+03	369000.00
E5080F	2017-08-09 09:34:00+03	55900.00
E50918	2017-08-06 15:19:00+03	35600.00
E5091D	2017-08-12 16:46:00+03	131600.00
E509DB	2017-08-14 02:35:00+03	43600.00
E509F2	2017-07-29 04:50:00+03	26700.00
E50A0D	2017-07-29 00:17:00+03	10600.00
E50AB3	2017-08-09 14:56:00+03	57500.00
E50ABD	2017-07-06 05:05:00+03	76300.00
E50AEB	2017-07-16 10:05:00+03	67200.00
E50B2B	2017-07-14 04:19:00+03	31600.00
E50B7E	2017-08-14 10:58:00+03	36700.00
E50C0A	2017-08-04 00:01:00+03	37900.00
E50C3D	2017-08-11 20:10:00+03	23200.00
E50C58	2017-07-11 11:01:00+03	73900.00
E50C97	2017-08-12 13:41:00+03	40800.00
E50CBC	2017-07-20 13:39:00+03	44700.00
E50D31	2017-07-04 03:14:00+03	33200.00
E50D54	2017-07-29 16:09:00+03	36200.00
E50E5F	2017-08-13 05:15:00+03	248400.00
E50EA2	2017-07-09 13:13:00+03	178300.00
E50F21	2017-07-09 20:37:00+03	153200.00
E50F2A	2017-07-08 19:58:00+03	46200.00
E50F3B	2017-07-13 17:47:00+03	24800.00
E50F80	2017-08-11 20:23:00+03	70400.00
E50FD8	2017-07-10 06:54:00+03	107300.00
E51023	2017-07-23 07:34:00+03	108500.00
E5107A	2017-07-24 15:52:00+03	62600.00
E510C4	2017-07-12 23:29:00+03	168200.00
E510C6	2017-07-28 21:58:00+03	269300.00
E51149	2017-08-11 03:18:00+03	63200.00
E51192	2017-07-06 23:23:00+03	46300.00
E511D6	2017-08-04 19:23:00+03	31200.00
E511F6	2017-07-01 13:22:00+03	372600.00
E5121A	2017-07-12 20:05:00+03	101200.00
E5125C	2017-07-16 23:21:00+03	93900.00
E512EA	2017-07-13 15:10:00+03	50100.00
E5139F	2017-07-05 00:06:00+03	135300.00
E513B5	2017-07-27 00:02:00+03	11600.00
E5141D	2017-08-08 09:19:00+03	40400.00
E5143B	2017-07-21 18:05:00+03	67700.00
E51482	2017-07-08 13:28:00+03	45200.00
E514FC	2017-07-16 02:34:00+03	12400.00
E5151B	2017-07-14 09:49:00+03	43400.00
E51550	2017-07-15 08:43:00+03	69500.00
E51568	2017-07-02 12:42:00+03	28000.00
E51582	2017-07-16 12:29:00+03	63400.00
E515AF	2017-07-28 02:57:00+03	46400.00
E515CF	2017-07-03 07:01:00+03	62600.00
E51616	2017-08-13 00:35:00+03	123800.00
E51674	2017-07-10 03:27:00+03	202400.00
E51694	2017-07-02 23:53:00+03	37900.00
E516A3	2017-07-05 23:43:00+03	46200.00
E516DF	2017-08-06 20:39:00+03	503600.00
E516F0	2017-08-01 22:20:00+03	66600.00
E516FB	2017-07-20 10:38:00+03	266200.00
E5172D	2017-07-27 18:22:00+03	47600.00
E51731	2017-07-06 15:26:00+03	38800.00
E5176B	2017-08-11 16:20:00+03	254900.00
E51795	2017-08-12 17:02:00+03	332200.00
E517B0	2017-08-05 07:32:00+03	135600.00
E51864	2017-07-12 19:17:00+03	51200.00
E518A5	2017-07-04 06:28:00+03	92700.00
E518FE	2017-08-12 17:12:00+03	46800.00
E51962	2017-07-12 23:50:00+03	46400.00
E51963	2017-07-27 02:40:00+03	46000.00
E5197D	2017-07-31 04:08:00+03	541500.00
E51988	2017-08-04 03:33:00+03	127700.00
E519B6	2017-08-10 17:32:00+03	37900.00
E519D0	2017-07-30 04:48:00+03	75600.00
E519E0	2017-08-14 03:12:00+03	29600.00
E519ED	2017-07-06 22:34:00+03	266400.00
E519F6	2017-07-13 20:51:00+03	21200.00
E51A49	2017-06-30 18:12:00+03	55800.00
E51A5C	2017-07-03 20:12:00+03	51900.00
E51A60	2017-07-24 06:48:00+03	69900.00
E51A9E	2017-07-20 03:08:00+03	204200.00
E51AB3	2017-08-09 08:18:00+03	46400.00
E51ABA	2017-07-20 12:28:00+03	44500.00
E51AC2	2017-07-16 20:54:00+03	167400.00
E51B82	2017-07-08 03:47:00+03	67200.00
E51BF6	2017-08-07 08:04:00+03	50000.00
E51C33	2017-07-05 09:56:00+03	43900.00
E51C5C	2017-07-27 01:07:00+03	40000.00
E51CB3	2017-07-14 15:51:00+03	14000.00
E51D36	2017-07-26 06:19:00+03	12200.00
E51D45	2017-07-08 15:34:00+03	42700.00
E51D97	2017-07-11 13:22:00+03	12400.00
E51E17	2017-07-28 02:46:00+03	48600.00
E51E2C	2017-08-07 07:51:00+03	81600.00
E51E3B	2017-07-03 23:29:00+03	37100.00
E51E5C	2017-08-02 16:27:00+03	46200.00
E51E9B	2017-08-11 01:11:00+03	19600.00
E51EAA	2017-08-07 08:00:00+03	248400.00
E51EAF	2017-08-14 12:08:00+03	31200.00
E51EC2	2017-07-23 14:52:00+03	131100.00
E51F2C	2017-07-24 03:03:00+03	47000.00
E51F72	2017-07-31 04:06:00+03	24400.00
E51FBB	2017-08-13 17:11:00+03	22800.00
E51FC5	2017-08-15 16:20:00+03	151200.00
E51FE8	2017-07-07 13:20:00+03	52800.00
E5203E	2017-08-02 02:02:00+03	32700.00
E520A3	2017-07-03 20:35:00+03	30000.00
E520FD	2017-08-03 23:03:00+03	133600.00
E5210E	2017-07-26 22:56:00+03	101800.00
E521A4	2017-07-10 01:22:00+03	198400.00
E521BA	2017-08-02 01:58:00+03	28000.00
E521E8	2017-07-08 14:54:00+03	42400.00
E521EF	2017-08-04 12:49:00+03	54800.00
E5220E	2017-07-21 23:32:00+03	102000.00
E52244	2017-07-17 07:58:00+03	14000.00
E5224C	2017-07-13 22:47:00+03	74800.00
E52363	2017-08-12 08:23:00+03	58600.00
E523EF	2017-08-14 07:35:00+03	38500.00
E52433	2017-08-01 09:14:00+03	10600.00
E524A7	2017-08-14 10:39:00+03	65200.00
E524F1	2017-07-19 13:31:00+03	37900.00
E5251B	2017-07-14 06:22:00+03	184000.00
E52526	2017-07-17 13:11:00+03	117600.00
E52527	2017-06-29 09:59:00+03	139000.00
E5254C	2017-07-03 11:04:00+03	52100.00
E52557	2017-07-25 18:47:00+03	58800.00
E52595	2017-06-27 05:18:00+03	52900.00
E525FC	2017-07-03 15:53:00+03	31600.00
E5264C	2017-06-25 23:17:00+03	32800.00
E52670	2017-07-27 19:53:00+03	58500.00
E526A6	2017-08-13 11:59:00+03	88800.00
E526A8	2017-07-31 18:30:00+03	87000.00
E526B2	2017-07-29 15:01:00+03	12400.00
E5270E	2017-06-29 04:22:00+03	9200.00
E52738	2017-08-02 11:20:00+03	40800.00
E52747	2017-07-18 13:00:00+03	29400.00
E52752	2017-07-09 15:21:00+03	250600.00
E5280C	2017-07-29 00:42:00+03	496700.00
E52839	2017-06-29 05:11:00+03	125400.00
E52867	2017-07-22 19:15:00+03	26000.00
E528AE	2017-07-19 16:19:00+03	23600.00
E528D5	2017-07-27 17:36:00+03	48800.00
E528FE	2017-07-17 18:47:00+03	38800.00
E52904	2017-07-19 15:02:00+03	21400.00
E529C1	2017-08-15 09:33:00+03	133100.00
E52A83	2017-08-10 05:55:00+03	62700.00
E52AEB	2017-08-14 16:22:00+03	16400.00
E52B0D	2017-08-10 18:40:00+03	73600.00
E52B1B	2017-07-24 09:30:00+03	132800.00
E52B36	2017-07-31 18:49:00+03	58600.00
E52B50	2017-08-14 05:14:00+03	56600.00
E52B58	2017-08-14 12:51:00+03	29400.00
E52B86	2017-07-17 12:31:00+03	54300.00
E52B95	2017-08-03 06:29:00+03	26000.00
E52BB0	2017-08-06 13:43:00+03	132800.00
E52BF5	2017-07-04 12:25:00+03	134700.00
E52BF6	2017-07-10 08:25:00+03	52700.00
E52C02	2017-07-04 02:59:00+03	40800.00
E52CD0	2017-08-06 23:57:00+03	240600.00
E52D01	2017-07-08 09:21:00+03	52000.00
E52D26	2017-08-12 22:36:00+03	56000.00
E52D5D	2017-08-06 22:44:00+03	133100.00
E52D86	2017-07-05 13:57:00+03	36700.00
E52D88	2017-07-04 23:35:00+03	111600.00
E52E3E	2017-07-02 08:32:00+03	60700.00
E52EE7	2017-08-13 14:54:00+03	56600.00
E52EFF	2017-07-03 01:54:00+03	95600.00
E52F97	2017-07-24 05:48:00+03	40800.00
E53017	2017-07-20 08:56:00+03	28800.00
E5306A	2017-07-16 10:25:00+03	135300.00
E530AB	2017-07-21 06:51:00+03	42800.00
E530F5	2017-07-12 21:26:00+03	26800.00
E530F6	2017-08-14 23:02:00+03	38800.00
E53152	2017-08-11 00:23:00+03	271100.00
E5315D	2017-08-09 04:01:00+03	42800.00
E5319C	2017-08-01 16:37:00+03	67300.00
E532AB	2017-07-19 03:33:00+03	102100.00
E532B8	2017-07-06 13:16:00+03	81700.00
E532C4	2017-07-02 08:02:00+03	24000.00
E532CB	2017-08-10 00:46:00+03	36200.00
E533CF	2017-07-23 09:10:00+03	22600.00
E533F4	2017-08-14 20:13:00+03	44300.00
E53472	2017-07-27 13:45:00+03	109600.00
E534C3	2017-08-09 03:22:00+03	49800.00
E5353A	2017-07-11 16:22:00+03	15000.00
E53577	2017-08-02 15:29:00+03	106600.00
E53598	2017-08-08 23:52:00+03	136500.00
E535AD	2017-07-17 12:00:00+03	72100.00
E5362E	2017-08-03 23:03:00+03	112600.00
E536F5	2017-07-24 15:26:00+03	108600.00
E536F6	2017-07-22 11:08:00+03	73500.00
E5375A	2017-07-10 14:02:00+03	24400.00
E53786	2017-08-06 17:30:00+03	26000.00
E537E2	2017-08-05 05:06:00+03	8400.00
E53806	2017-07-11 02:41:00+03	31400.00
E5381A	2017-07-21 10:35:00+03	28800.00
E538B2	2017-07-06 21:04:00+03	150600.00
E53950	2017-07-15 18:54:00+03	119600.00
E53976	2017-08-15 04:18:00+03	45100.00
E5397F	2017-08-03 23:26:00+03	16400.00
E539D8	2017-08-13 00:35:00+03	20400.00
E53A62	2017-08-03 19:47:00+03	47600.00
E53AC3	2017-07-28 05:54:00+03	44000.00
E53B10	2017-06-30 03:42:00+03	55800.00
E53B15	2017-07-06 01:09:00+03	34000.00
E53B20	2017-07-15 12:36:00+03	34000.00
E53B26	2017-08-14 16:30:00+03	25200.00
E53B41	2017-07-24 22:32:00+03	88400.00
E53B44	2017-08-14 13:20:00+03	123000.00
E53B62	2017-08-06 19:36:00+03	23600.00
E53BBD	2017-07-27 09:40:00+03	123000.00
E53BF7	2017-07-21 22:29:00+03	47400.00
E53C5A	2017-07-20 06:39:00+03	52600.00
E53CB8	2017-07-09 05:10:00+03	81600.00
E53CF7	2017-07-18 17:14:00+03	254900.00
E53D46	2017-07-15 13:32:00+03	102100.00
E53E29	2017-07-04 22:01:00+03	55500.00
E53E6C	2017-07-24 15:31:00+03	44800.00
E53EAA	2017-08-05 18:41:00+03	90400.00
E53EF3	2017-08-02 10:07:00+03	94200.00
E53F5D	2017-07-31 08:39:00+03	21000.00
E53F76	2017-08-06 00:42:00+03	24400.00
E53F91	2017-07-17 04:04:00+03	144300.00
E53FB6	2017-07-17 09:44:00+03	64600.00
E5400E	2017-07-27 12:06:00+03	49800.00
E54117	2017-07-24 18:55:00+03	45200.00
E54137	2017-07-03 12:17:00+03	50200.00
E541B9	2017-07-05 21:22:00+03	26000.00
E541F4	2017-07-08 14:28:00+03	64800.00
E54252	2017-08-01 05:47:00+03	24000.00
E54300	2017-07-29 08:27:00+03	51600.00
E5434B	2017-07-29 13:22:00+03	92800.00
E5436D	2017-08-10 22:27:00+03	54800.00
E543CD	2017-08-07 05:48:00+03	26000.00
E54410	2017-07-25 04:54:00+03	135400.00
E5441D	2017-08-14 03:17:00+03	50000.00
E54444	2017-08-04 08:48:00+03	14700.00
E54449	2017-08-05 16:34:00+03	30200.00
E5445C	2017-07-30 01:05:00+03	29200.00
E5447B	2017-07-29 16:16:00+03	25600.00
E54494	2017-08-12 17:07:00+03	52400.00
E544B5	2017-07-25 05:12:00+03	137100.00
E544EE	2017-07-22 08:39:00+03	29600.00
E544F4	2017-07-07 16:23:00+03	51900.00
E54554	2017-06-29 15:01:00+03	26200.00
E54566	2017-08-14 00:00:00+03	32700.00
E545AD	2017-08-14 01:56:00+03	23600.00
E545E8	2017-07-12 15:25:00+03	59100.00
E545EC	2017-07-18 14:42:00+03	56300.00
E545F0	2017-07-24 20:00:00+03	65100.00
E54622	2017-07-01 18:15:00+03	138400.00
E54662	2017-07-25 04:47:00+03	26000.00
E546B1	2017-07-04 06:16:00+03	62900.00
E546C2	2017-07-30 16:52:00+03	34000.00
E546F7	2017-07-10 01:29:00+03	73600.00
E54729	2017-07-07 08:29:00+03	26000.00
E5477C	2017-07-03 18:30:00+03	136000.00
E54791	2017-07-23 06:42:00+03	36100.00
E5479D	2017-08-05 02:17:00+03	135400.00
E547B1	2017-08-12 16:10:00+03	27800.00
E547C7	2017-07-13 05:52:00+03	38600.00
E5480F	2017-07-04 03:17:00+03	52100.00
E54843	2017-07-19 21:23:00+03	239100.00
E548C7	2017-08-04 09:15:00+03	260900.00
E548D0	2017-07-09 17:46:00+03	89200.00
E548E4	2017-08-02 13:34:00+03	70700.00
E54949	2017-07-29 08:20:00+03	29000.00
E5494B	2017-07-27 05:15:00+03	73900.00
E549B2	2017-07-27 00:48:00+03	52400.00
E54A62	2017-07-30 05:29:00+03	24400.00
E54AA7	2017-08-07 18:23:00+03	26700.00
E54BB1	2017-06-30 19:17:00+03	21400.00
E54BBA	2017-07-23 16:09:00+03	53100.00
E54BD0	2017-08-04 05:07:00+03	23600.00
E54BD2	2017-07-31 06:53:00+03	23600.00
E54C3B	2017-07-30 14:17:00+03	26000.00
E54C88	2017-08-12 12:22:00+03	7300.00
E54CA7	2017-07-29 02:27:00+03	76600.00
E54CB5	2017-07-22 08:19:00+03	260300.00
E54CE4	2017-08-10 17:08:00+03	161800.00
E54D1F	2017-07-16 15:42:00+03	66600.00
E54D64	2017-06-30 05:38:00+03	54800.00
E54DED	2017-08-05 04:21:00+03	75600.00
E54DF5	2017-07-03 06:55:00+03	101100.00
E54E2B	2017-08-10 20:25:00+03	24400.00
E54E30	2017-07-21 01:58:00+03	65700.00
E54E56	2017-07-12 16:11:00+03	42400.00
E54E77	2017-07-10 19:07:00+03	27300.00
E54EC8	2017-07-15 14:08:00+03	32800.00
E54EF5	2017-08-11 00:34:00+03	46300.00
E54F3D	2017-07-07 21:14:00+03	15200.00
E54F63	2017-08-13 05:06:00+03	19600.00
E54F92	2017-08-15 05:32:00+03	44800.00
E54FA1	2017-07-02 07:48:00+03	47400.00
E5500C	2017-07-20 17:13:00+03	51800.00
E55022	2017-07-24 05:57:00+03	122300.00
E5508A	2017-07-28 09:32:00+03	56900.00
E550C1	2017-08-05 02:00:00+03	38200.00
E55183	2017-07-09 07:26:00+03	73600.00
E55193	2017-08-15 14:11:00+03	46300.00
E5519C	2017-07-02 06:24:00+03	57700.00
E551AF	2017-08-09 23:33:00+03	92700.00
E551D6	2017-06-29 01:08:00+03	22000.00
E55249	2017-08-10 02:21:00+03	144400.00
E55265	2017-07-30 14:21:00+03	85200.00
E55297	2017-07-02 15:45:00+03	70700.00
E552EC	2017-07-31 00:09:00+03	27200.00
E55339	2017-07-30 13:53:00+03	26000.00
E55342	2017-08-08 00:09:00+03	164400.00
E553AE	2017-08-10 14:59:00+03	12600.00
E553BC	2017-08-07 01:50:00+03	40600.00
E5546D	2017-06-27 03:05:00+03	17600.00
E55491	2017-08-10 18:17:00+03	85600.00
E554B4	2017-08-14 04:49:00+03	27200.00
E554CD	2017-07-22 06:58:00+03	40000.00
E55542	2017-07-28 10:40:00+03	23200.00
E55555	2017-07-05 02:37:00+03	45100.00
E5556A	2017-08-06 08:16:00+03	28000.00
E5557B	2017-08-05 12:06:00+03	62800.00
E55588	2017-07-18 10:08:00+03	56600.00
E5568A	2017-07-09 21:57:00+03	55800.00
E556F7	2017-07-18 05:40:00+03	23600.00
E556FD	2017-07-04 20:24:00+03	66600.00
E55752	2017-07-08 18:18:00+03	36200.00
E55757	2017-08-04 09:57:00+03	25200.00
E55770	2017-08-15 08:19:00+03	56000.00
E5578A	2017-07-14 23:57:00+03	153300.00
E557D1	2017-08-15 09:30:00+03	23400.00
E557E9	2017-07-07 12:27:00+03	47100.00
E557F7	2017-07-25 01:33:00+03	56000.00
E55876	2017-08-03 09:30:00+03	73900.00
E55886	2017-08-13 23:09:00+03	21400.00
E55890	2017-08-02 00:17:00+03	106200.00
E558AC	2017-07-26 01:14:00+03	246000.00
E558C8	2017-07-28 12:29:00+03	35600.00
E55900	2017-08-09 20:00:00+03	75300.00
E559A2	2017-08-11 16:49:00+03	111600.00
E55A01	2017-08-04 21:07:00+03	47600.00
E55A50	2017-08-05 05:49:00+03	169900.00
E55AC7	2017-07-16 00:56:00+03	124200.00
E55ACA	2017-08-11 18:26:00+03	46400.00
E55B29	2017-08-14 09:12:00+03	186800.00
E55B78	2017-07-16 11:56:00+03	68900.00
E55BC5	2017-07-26 13:54:00+03	66500.00
E55D3E	2017-07-12 08:01:00+03	147700.00
E55DD3	2017-07-12 19:33:00+03	30800.00
E55EE3	2017-07-27 22:18:00+03	24200.00
E55F10	2017-07-19 10:14:00+03	7400.00
E55F65	2017-07-03 02:10:00+03	117600.00
E55FAF	2017-08-08 16:09:00+03	531600.00
E55FD5	2017-08-02 05:38:00+03	38600.00
E55FE0	2017-07-22 20:36:00+03	28800.00
E55FE1	2017-07-09 08:47:00+03	24400.00
E5600B	2017-07-24 04:57:00+03	28000.00
E56019	2017-08-07 03:28:00+03	4000.00
E56023	2017-07-06 14:29:00+03	90000.00
E56039	2017-08-15 17:41:00+03	38900.00
E56053	2017-07-28 02:00:00+03	54000.00
E5606A	2017-07-10 21:25:00+03	26800.00
E56072	2017-08-12 19:15:00+03	17600.00
E5616D	2017-07-31 06:15:00+03	23200.00
E56174	2017-07-16 06:46:00+03	72600.00
E561AA	2017-07-22 02:12:00+03	14400.00
E561B2	2017-08-01 20:04:00+03	22400.00
E561C5	2017-08-05 17:25:00+03	18000.00
E56207	2017-06-29 23:42:00+03	73600.00
E5620B	2017-07-11 21:22:00+03	29100.00
E56221	2017-08-01 07:13:00+03	46000.00
E56231	2017-07-27 09:36:00+03	248400.00
E56240	2017-07-17 06:26:00+03	38800.00
E5626A	2017-08-15 10:57:00+03	44800.00
E562F8	2017-07-09 21:36:00+03	6800.00
E56317	2017-08-09 19:44:00+03	8400.00
E56341	2017-07-04 02:50:00+03	14400.00
E56367	2017-07-29 17:48:00+03	14900.00
E563D7	2017-08-04 03:48:00+03	12600.00
E5640D	2017-07-23 12:50:00+03	77600.00
E56445	2017-07-29 17:36:00+03	111600.00
E56467	2017-08-09 12:49:00+03	25900.00
E56472	2017-08-07 18:11:00+03	113200.00
E5649A	2017-08-02 10:05:00+03	20600.00
E564E8	2017-07-31 17:52:00+03	13600.00
E56532	2017-08-05 19:49:00+03	202900.00
E56563	2017-08-12 11:30:00+03	562900.00
E565AB	2017-08-12 23:48:00+03	144900.00
E565D6	2017-08-08 22:05:00+03	34000.00
E5669F	2017-08-02 13:36:00+03	406100.00
E566FF	2017-07-11 05:22:00+03	39400.00
E56755	2017-07-23 21:42:00+03	131700.00
E567B6	2017-07-14 03:40:00+03	201200.00
E5681A	2017-07-23 05:48:00+03	67900.00
E56856	2017-07-19 09:13:00+03	135400.00
E5685A	2017-07-14 12:29:00+03	56000.00
E56898	2017-07-18 21:37:00+03	257600.00
E5690D	2017-08-11 02:10:00+03	55800.00
E56912	2017-08-06 05:28:00+03	196500.00
E5696B	2017-08-07 10:15:00+03	32700.00
E56995	2017-07-21 12:45:00+03	6000.00
E569D9	2017-07-18 05:25:00+03	8600.00
E56A36	2017-07-25 01:00:00+03	136200.00
E56A44	2017-07-01 07:15:00+03	25900.00
E56A6A	2017-08-04 00:18:00+03	140900.00
E56ACA	2017-08-09 05:32:00+03	172100.00
E56AF0	2017-08-01 22:29:00+03	68800.00
E56AF6	2017-07-22 19:07:00+03	28900.00
E56B1C	2017-07-02 00:42:00+03	203000.00
E56B4E	2017-07-24 08:33:00+03	22000.00
E56B81	2017-07-05 03:04:00+03	124200.00
E56C27	2017-08-01 22:42:00+03	48500.00
E56C55	2017-06-29 18:10:00+03	273400.00
E56C67	2017-07-02 03:34:00+03	177200.00
E56C7C	2017-08-09 17:44:00+03	109000.00
E56CD9	2017-08-15 16:38:00+03	67700.00
E56D2B	2017-08-10 23:51:00+03	385000.00
E56D46	2017-08-14 14:46:00+03	56800.00
E56DB9	2017-07-03 14:34:00+03	68400.00
E56DED	2017-07-19 09:25:00+03	12200.00
E56E28	2017-07-19 00:54:00+03	55600.00
E56E86	2017-08-14 08:30:00+03	83600.00
E56E94	2017-07-27 06:39:00+03	21000.00
E56F4E	2017-07-01 20:02:00+03	56600.00
E56F58	2017-07-22 08:56:00+03	64800.00
E56F8E	2017-07-30 06:41:00+03	25600.00
E570C5	2017-07-21 06:29:00+03	24200.00
E57220	2017-07-18 08:38:00+03	144400.00
E57225	2017-06-27 00:49:00+03	56000.00
E57281	2017-07-12 08:43:00+03	52000.00
E5728B	2017-07-16 16:16:00+03	28000.00
E572D4	2017-08-04 13:20:00+03	43800.00
E57357	2017-06-28 05:30:00+03	14000.00
E573B1	2017-07-03 08:00:00+03	265700.00
E573C9	2017-08-15 17:09:00+03	35600.00
E57406	2017-07-05 02:22:00+03	37900.00
E57481	2017-08-01 02:31:00+03	19600.00
E57498	2017-08-01 01:25:00+03	15400.00
E57572	2017-07-30 17:08:00+03	21800.00
E5758F	2017-07-26 15:30:00+03	97800.00
E575A8	2017-07-19 02:16:00+03	33300.00
E575FA	2017-07-21 05:37:00+03	42400.00
E57622	2017-07-20 01:24:00+03	19600.00
E57644	2017-08-14 00:39:00+03	92900.00
E57688	2017-07-18 08:13:00+03	57500.00
E576F9	2017-07-30 22:39:00+03	28800.00
E5775A	2017-06-29 22:59:00+03	43200.00
E5776D	2017-07-23 14:12:00+03	100600.00
E577DB	2017-07-29 01:04:00+03	85000.00
E57890	2017-07-29 09:04:00+03	268300.00
E578DA	2017-07-04 16:51:00+03	27200.00
E5791B	2017-08-05 08:22:00+03	66600.00
E57924	2017-08-02 14:24:00+03	52300.00
E579D2	2017-07-06 03:13:00+03	56000.00
E57A6D	2017-07-12 03:23:00+03	147700.00
E57A7A	2017-08-05 09:17:00+03	64100.00
E57AF1	2017-07-16 04:13:00+03	88400.00
E57B0F	2017-07-09 14:30:00+03	23400.00
E57BA1	2017-07-04 16:23:00+03	80700.00
E57BB3	2017-07-15 00:59:00+03	28000.00
E57C10	2017-07-01 18:47:00+03	28800.00
E57C27	2017-08-02 02:54:00+03	61900.00
E57C9D	2017-07-17 03:55:00+03	298000.00
E57CA4	2017-08-05 01:47:00+03	201200.00
E57CBA	2017-08-13 07:03:00+03	13800.00
E57D03	2017-08-05 09:40:00+03	25100.00
E57D05	2017-07-08 19:52:00+03	42600.00
E57D09	2017-07-22 09:31:00+03	30200.00
E57D0E	2017-07-04 18:45:00+03	135400.00
E57D1A	2017-08-12 18:55:00+03	26600.00
E57D9D	2017-07-08 16:21:00+03	19600.00
E57E15	2017-07-09 22:45:00+03	54900.00
E57E5D	2017-08-15 02:31:00+03	81700.00
E57E84	2017-06-30 00:52:00+03	24300.00
E57E8F	2017-07-15 20:53:00+03	8000.00
E57EEB	2017-07-23 19:07:00+03	62600.00
E57F0C	2017-07-02 04:13:00+03	64600.00
E57F20	2017-08-14 21:27:00+03	96800.00
E57FFB	2017-08-10 07:18:00+03	40000.00
E58070	2017-07-31 19:03:00+03	15200.00
E58074	2017-08-08 13:38:00+03	257500.00
E5811A	2017-08-06 10:29:00+03	95700.00
E5814C	2017-07-28 19:46:00+03	58800.00
E5816C	2017-07-26 04:09:00+03	46300.00
E58184	2017-07-21 21:15:00+03	42000.00
E58223	2017-07-25 17:01:00+03	26000.00
E58274	2017-08-09 08:41:00+03	6000.00
E5829F	2017-08-05 11:45:00+03	21800.00
E582D2	2017-07-15 04:48:00+03	55800.00
E58368	2017-08-09 14:09:00+03	133100.00
E583B9	2017-07-06 05:52:00+03	28000.00
E58467	2017-07-18 08:08:00+03	203400.00
E5848E	2017-06-29 21:54:00+03	18000.00
E58546	2017-07-26 02:33:00+03	54800.00
E58596	2017-08-03 09:10:00+03	46300.00
E58609	2017-07-12 04:09:00+03	81600.00
E58622	2017-07-19 23:36:00+03	63700.00
E58685	2017-08-14 12:10:00+03	46400.00
E5868A	2017-07-27 04:04:00+03	72000.00
E586E0	2017-07-08 03:13:00+03	67200.00
E586EF	2017-07-24 19:14:00+03	88500.00
E587A6	2017-07-17 01:20:00+03	149200.00
E5881D	2017-07-16 23:27:00+03	108500.00
E58832	2017-07-26 08:29:00+03	44500.00
E58841	2017-07-02 17:42:00+03	80100.00
E58857	2017-07-11 11:39:00+03	65600.00
E5886F	2017-07-06 02:41:00+03	133200.00
E58886	2017-08-02 21:30:00+03	28300.00
E588B4	2017-07-24 03:21:00+03	85000.00
E5892D	2017-06-30 12:15:00+03	104900.00
E58976	2017-08-09 00:10:00+03	79800.00
E589A1	2017-08-14 00:15:00+03	97700.00
E589A4	2017-08-04 01:41:00+03	52100.00
E58A0E	2017-07-31 04:52:00+03	28800.00
E58A7C	2017-08-05 12:30:00+03	101200.00
E58AA6	2017-07-29 22:18:00+03	223200.00
E58B66	2017-08-09 02:00:00+03	83600.00
E58B79	2017-07-23 01:45:00+03	68400.00
E58B8F	2017-07-06 17:26:00+03	15100.00
E58C72	2017-07-02 00:51:00+03	99300.00
E58C92	2017-07-31 22:29:00+03	24400.00
E58CE7	2017-08-15 06:51:00+03	149700.00
E58D22	2017-07-30 22:10:00+03	393800.00
E58D3A	2017-08-01 15:17:00+03	21800.00
E58D6D	2017-08-02 11:32:00+03	65800.00
E58E3B	2017-08-11 01:17:00+03	32800.00
E58E68	2017-07-03 03:23:00+03	48100.00
E58E8B	2017-07-21 00:44:00+03	28000.00
E58EA6	2017-07-10 05:37:00+03	47400.00
E58EF6	2017-08-06 23:32:00+03	20800.00
E58F20	2017-08-14 23:28:00+03	40800.00
E58F49	2017-08-02 08:38:00+03	55800.00
E58FD7	2017-08-04 04:37:00+03	62600.00
E59001	2017-08-15 06:52:00+03	16400.00
E5901C	2017-07-28 10:49:00+03	73200.00
E5908C	2017-08-06 04:54:00+03	31400.00
E59122	2017-07-09 00:49:00+03	78200.00
E59133	2017-07-26 13:11:00+03	266400.00
E59161	2017-07-04 14:43:00+03	123700.00
E59172	2017-07-18 04:59:00+03	65900.00
E591F1	2017-08-10 07:48:00+03	48900.00
E591F3	2017-08-12 18:43:00+03	129200.00
E5920B	2017-07-04 05:43:00+03	54800.00
E5927D	2017-07-25 01:04:00+03	119400.00
E592E5	2017-07-14 03:36:00+03	85000.00
E593A2	2017-08-09 11:59:00+03	127300.00
E593CC	2017-08-01 22:25:00+03	56000.00
E59405	2017-07-01 06:14:00+03	153300.00
E59472	2017-07-12 09:15:00+03	35300.00
E59476	2017-08-05 18:36:00+03	201200.00
E59491	2017-08-10 09:33:00+03	54600.00
E594A2	2017-07-28 23:49:00+03	12400.00
E594E7	2017-07-14 07:51:00+03	63800.00
E595AB	2017-07-10 09:01:00+03	10600.00
E595F4	2017-07-07 06:56:00+03	31400.00
E596F6	2017-07-21 01:55:00+03	46400.00
E59725	2017-08-12 20:00:00+03	53000.00
E5976E	2017-07-22 13:46:00+03	52000.00
E5978B	2017-07-19 01:47:00+03	120100.00
E597AB	2017-08-15 12:50:00+03	27900.00
E597C5	2017-07-04 17:43:00+03	86800.00
E597DB	2017-07-14 17:57:00+03	16000.00
E59800	2017-08-10 14:25:00+03	114500.00
E5983F	2017-07-19 16:39:00+03	42200.00
E5984E	2017-07-08 04:53:00+03	28300.00
E598D5	2017-07-27 01:28:00+03	54500.00
E598F0	2017-07-19 00:46:00+03	96300.00
E5990B	2017-07-23 13:36:00+03	56600.00
E59922	2017-07-02 19:33:00+03	40800.00
E5997F	2017-08-05 21:47:00+03	7300.00
E599B9	2017-07-14 05:47:00+03	34000.00
E599EE	2017-08-01 04:33:00+03	62600.00
E59A1C	2017-08-05 12:43:00+03	29400.00
E59A6B	2017-07-10 11:04:00+03	46000.00
E59AC1	2017-07-31 01:30:00+03	21200.00
E59AC6	2017-07-04 21:55:00+03	69500.00
E59AE9	2017-07-10 06:22:00+03	10600.00
E59AF2	2017-07-16 09:22:00+03	103900.00
E59AF3	2017-07-12 08:43:00+03	21500.00
E59C07	2017-08-10 09:43:00+03	68800.00
E59C17	2017-07-28 01:50:00+03	117600.00
E59C26	2017-07-03 11:31:00+03	46000.00
E59C89	2017-08-15 01:58:00+03	27600.00
E59C8E	2017-08-01 00:48:00+03	54300.00
E59CBF	2017-07-09 08:17:00+03	35200.00
E59D22	2017-08-07 08:55:00+03	35800.00
E59D60	2017-07-23 16:15:00+03	145300.00
E59D7C	2017-08-12 14:37:00+03	73500.00
E59D95	2017-07-02 17:40:00+03	35200.00
E59D9D	2017-08-02 07:52:00+03	97400.00
E59DA9	2017-07-10 06:26:00+03	213200.00
E59DB2	2017-08-04 05:05:00+03	56000.00
E59DFF	2017-07-11 23:01:00+03	34000.00
E59E05	2017-08-03 10:00:00+03	160700.00
E59E14	2017-08-04 07:00:00+03	46400.00
E59E69	2017-07-13 05:17:00+03	133200.00
E59EED	2017-08-11 06:37:00+03	6700.00
E59EFD	2017-07-16 09:16:00+03	24400.00
E59F55	2017-07-17 19:03:00+03	386300.00
E59F8D	2017-07-25 03:35:00+03	390400.00
E59FC5	2017-07-19 09:04:00+03	99300.00
E59FD9	2017-08-11 03:16:00+03	30200.00
E5A006	2017-07-18 00:44:00+03	92800.00
E5A039	2017-07-30 19:03:00+03	75600.00
E5A080	2017-08-11 00:11:00+03	40800.00
E5A084	2017-07-30 06:27:00+03	36200.00
E5A08C	2017-07-06 11:46:00+03	27200.00
E5A0DC	2017-07-29 11:11:00+03	56600.00
E5A12A	2017-07-24 14:07:00+03	21600.00
E5A16A	2017-07-16 03:59:00+03	68700.00
E5A16D	2017-07-22 16:50:00+03	77000.00
E5A194	2017-08-14 06:20:00+03	556600.00
E5A196	2017-07-11 09:02:00+03	54800.00
E5A1D1	2017-07-03 10:35:00+03	40300.00
E5A1E2	2017-07-24 06:34:00+03	179500.00
E5A22F	2017-07-02 13:25:00+03	30400.00
E5A2F3	2017-08-12 23:02:00+03	146300.00
E5A316	2017-08-01 18:38:00+03	43200.00
E5A363	2017-07-15 03:17:00+03	32800.00
E5A373	2017-08-15 16:09:00+03	75400.00
E5A37A	2017-07-22 18:44:00+03	57500.00
E5A37E	2017-08-13 19:32:00+03	70100.00
E5A425	2017-08-13 06:49:00+03	187800.00
E5A437	2017-07-10 19:43:00+03	65500.00
E5A468	2017-07-22 02:17:00+03	95300.00
E5A475	2017-07-16 13:06:00+03	60200.00
E5A49F	2017-07-25 13:43:00+03	44000.00
E5A4F4	2017-08-08 12:34:00+03	131100.00
E5A555	2017-07-22 17:29:00+03	55800.00
E5A57D	2017-08-06 04:28:00+03	69900.00
E5A5B4	2017-07-23 02:08:00+03	25000.00
E5A613	2017-07-01 12:03:00+03	182200.00
E5A6AC	2017-07-03 08:46:00+03	183400.00
E5A6E7	2017-07-06 13:32:00+03	466800.00
E5A777	2017-07-08 07:14:00+03	57400.00
E5A7B8	2017-07-01 16:17:00+03	21600.00
E5A82D	2017-07-02 11:31:00+03	13200.00
E5A847	2017-07-08 17:23:00+03	21800.00
E5A863	2017-08-03 03:03:00+03	24400.00
E5A8D1	2017-08-11 06:10:00+03	47200.00
E5A8DB	2017-08-07 04:53:00+03	50800.00
E5A8FD	2017-07-30 19:13:00+03	56000.00
E5A925	2017-07-12 03:12:00+03	26000.00
E5A932	2017-08-03 00:49:00+03	56600.00
E5A96C	2017-07-04 17:09:00+03	194000.00
E5A99A	2017-07-03 12:13:00+03	39600.00
E5A9BB	2017-07-11 10:16:00+03	99200.00
E5AA87	2017-07-15 19:07:00+03	52000.00
E5AAAE	2017-07-26 21:44:00+03	97900.00
E5AAC1	2017-07-21 12:32:00+03	30200.00
E5AADC	2017-07-09 04:29:00+03	12600.00
E5AAE2	2017-07-27 22:16:00+03	91000.00
E5AAE5	2017-08-02 16:20:00+03	53300.00
E5AB3C	2017-07-16 19:28:00+03	85500.00
E5ABDB	2017-07-12 03:37:00+03	57500.00
E5AC2A	2017-07-22 14:40:00+03	64700.00
E5ACEE	2017-07-20 07:12:00+03	73200.00
E5AD5F	2017-07-29 06:15:00+03	67200.00
E5AD6E	2017-07-21 12:14:00+03	23200.00
E5AD6F	2017-07-07 01:17:00+03	24700.00
E5ADA3	2017-07-13 14:48:00+03	118000.00
E5ADB7	2017-08-05 02:39:00+03	15000.00
E5AE4D	2017-08-15 06:06:00+03	106400.00
E5AE55	2017-07-19 04:53:00+03	21800.00
E5AE84	2017-07-29 23:27:00+03	202300.00
E5AEB7	2017-08-09 18:07:00+03	92400.00
E5AF04	2017-07-19 08:07:00+03	135600.00
E5AFA7	2017-07-18 02:55:00+03	47100.00
E5B016	2017-07-31 06:16:00+03	25000.00
E5B018	2017-07-26 00:18:00+03	28000.00
E5B04D	2017-08-09 07:22:00+03	101600.00
E5B0B8	2017-07-29 08:50:00+03	7400.00
E5B131	2017-07-08 14:12:00+03	18800.00
E5B154	2017-08-12 19:10:00+03	48800.00
E5B1CD	2017-07-21 03:16:00+03	19200.00
E5B1DA	2017-07-30 13:37:00+03	13000.00
E5B1E6	2017-08-15 04:18:00+03	26000.00
E5B1EA	2017-08-12 00:40:00+03	42800.00
E5B1ED	2017-08-06 17:17:00+03	393800.00
E5B1FE	2017-07-07 03:25:00+03	78200.00
E5B236	2017-08-03 16:36:00+03	69500.00
E5B249	2017-07-16 17:52:00+03	62100.00
E5B24F	2017-07-19 10:18:00+03	73500.00
E5B2DE	2017-07-17 02:53:00+03	37800.00
E5B327	2017-06-30 15:22:00+03	43400.00
E5B330	2017-08-11 17:40:00+03	62600.00
E5B351	2017-06-29 17:56:00+03	88700.00
E5B415	2017-07-01 15:21:00+03	12700.00
E5B468	2017-07-20 23:55:00+03	23200.00
E5B4B9	2017-08-06 11:59:00+03	87400.00
E5B4F4	2017-07-19 07:33:00+03	607600.00
E5B4FE	2017-07-14 14:54:00+03	281500.00
E5B51D	2017-07-28 19:48:00+03	130900.00
E5B5AA	2017-08-07 15:02:00+03	100600.00
E5B61E	2017-08-14 03:00:00+03	133700.00
E5B638	2017-07-18 15:19:00+03	293700.00
E5B6AC	2017-07-25 07:56:00+03	14000.00
E5B6F0	2017-07-13 01:10:00+03	26800.00
E5B6F9	2017-08-01 03:11:00+03	62800.00
E5B715	2017-08-11 10:43:00+03	57600.00
E5B764	2017-08-03 11:23:00+03	72200.00
E5B77D	2017-07-07 04:38:00+03	186900.00
E5B7B4	2017-07-06 05:41:00+03	28000.00
E5B7D1	2017-08-12 15:12:00+03	40800.00
E5B827	2017-07-13 10:00:00+03	94200.00
E5B829	2017-07-07 02:56:00+03	67600.00
E5B888	2017-07-22 11:02:00+03	121800.00
E5B894	2017-06-30 12:12:00+03	25200.00
E5B8B5	2017-08-02 10:34:00+03	296000.00
E5B8C3	2017-08-04 13:42:00+03	46400.00
E5B981	2017-08-01 06:45:00+03	94000.00
E5BA20	2017-08-11 00:24:00+03	79800.00
E5BA3F	2017-08-03 04:47:00+03	46200.00
E5BA50	2017-07-23 17:33:00+03	73300.00
E5BA6F	2017-07-20 08:57:00+03	75300.00
E5BA89	2017-07-21 21:36:00+03	89700.00
E5BAED	2017-08-02 03:08:00+03	8200.00
E5BB0F	2017-07-07 14:18:00+03	57400.00
E5BBAF	2017-07-21 04:01:00+03	399600.00
E5BC99	2017-07-14 08:50:00+03	198600.00
E5BCB2	2017-07-06 07:31:00+03	35200.00
E5BCBE	2017-07-01 11:28:00+03	169300.00
E5BCE1	2017-08-11 22:08:00+03	126000.00
E5BD28	2017-07-24 23:08:00+03	12000.00
E5BD39	2017-07-03 14:51:00+03	46400.00
E5BD52	2017-08-15 14:08:00+03	26600.00
E5BD6D	2017-07-12 07:25:00+03	95200.00
E5BDE1	2017-08-11 01:06:00+03	52000.00
E5BDE8	2017-08-02 16:32:00+03	41200.00
E5BDFC	2017-07-21 20:48:00+03	23600.00
E5BE69	2017-07-02 05:13:00+03	20800.00
E5BEC6	2017-07-29 20:27:00+03	23200.00
E5BEF9	2017-08-02 13:55:00+03	90400.00
E5BF17	2017-07-31 00:36:00+03	46900.00
E5BF1E	2017-07-13 10:07:00+03	123000.00
E5BF23	2017-07-16 03:11:00+03	29400.00
E5BF58	2017-07-20 11:28:00+03	65300.00
E5BF8C	2017-07-05 16:34:00+03	55900.00
E5C030	2017-08-05 05:29:00+03	47100.00
E5C03F	2017-08-06 10:45:00+03	6300.00
E5C058	2017-07-29 18:10:00+03	24000.00
E5C0D7	2017-07-14 11:09:00+03	62000.00
E5C184	2017-08-09 22:37:00+03	25600.00
E5C194	2017-07-28 00:09:00+03	44800.00
E5C1A5	2017-07-30 15:07:00+03	108900.00
E5C240	2017-07-10 13:31:00+03	10700.00
E5C27F	2017-07-13 07:28:00+03	112600.00
E5C2BF	2017-07-01 11:03:00+03	38600.00
E5C2F2	2017-07-09 11:20:00+03	13200.00
E5C2FA	2017-07-07 11:57:00+03	115600.00
E5C334	2017-07-20 22:33:00+03	7300.00
E5C389	2017-08-11 12:17:00+03	38600.00
E5C3CF	2017-07-09 20:19:00+03	40000.00
E5C3DC	2017-08-15 17:44:00+03	28800.00
E5C3E5	2017-07-16 12:03:00+03	32800.00
E5C41E	2017-07-10 22:18:00+03	320400.00
E5C44B	2017-08-05 05:20:00+03	168000.00
E5C47F	2017-07-02 19:58:00+03	24700.00
E5C4F6	2017-08-09 19:35:00+03	119000.00
E5C50A	2017-08-07 18:58:00+03	83000.00
E5C50D	2017-08-02 14:25:00+03	59800.00
E5C543	2017-08-06 18:30:00+03	47200.00
E5C566	2017-07-04 19:20:00+03	55800.00
E5C5CD	2017-08-12 18:31:00+03	408500.00
E5C65F	2017-07-09 22:34:00+03	112000.00
E5C670	2017-07-18 04:46:00+03	28800.00
E5C6E5	2017-08-12 01:00:00+03	66600.00
E5C75F	2017-07-08 04:39:00+03	54000.00
E5C78B	2017-07-05 20:47:00+03	29600.00
E5C7B2	2017-07-05 07:55:00+03	439800.00
E5C810	2017-08-05 12:55:00+03	133100.00
E5C88C	2017-07-13 20:30:00+03	4000.00
E5C8B0	2017-08-05 21:51:00+03	37900.00
E5C8C8	2017-07-16 06:52:00+03	191200.00
E5C94A	2017-07-26 04:10:00+03	35800.00
E5C989	2017-07-29 01:23:00+03	211100.00
E5C992	2017-07-18 23:35:00+03	36200.00
E5CA0A	2017-07-21 01:29:00+03	47000.00
E5CA4A	2017-08-06 00:54:00+03	24400.00
E5CAC0	2017-08-12 10:49:00+03	13400.00
E5CACC	2017-08-02 03:53:00+03	37000.00
E5CAD6	2017-07-26 03:59:00+03	85000.00
E5CAF1	2017-07-09 20:34:00+03	95000.00
E5CAFE	2017-08-09 00:22:00+03	23200.00
E5CB4D	2017-08-03 21:40:00+03	266400.00
E5CB7D	2017-08-12 10:45:00+03	7200.00
E5CBCB	2017-08-13 12:10:00+03	28800.00
E5CC39	2017-08-05 03:21:00+03	56100.00
E5CC85	2017-07-02 06:45:00+03	13300.00
E5CD10	2017-08-04 21:20:00+03	260900.00
E5CD20	2017-08-03 06:49:00+03	85400.00
E5CD84	2017-07-29 23:33:00+03	56600.00
E5CDA5	2017-07-08 12:52:00+03	79200.00
E5CDB1	2017-07-15 02:11:00+03	119400.00
E5CDD9	2017-07-03 20:59:00+03	57600.00
E5CDE3	2017-08-03 05:20:00+03	50000.00
E5CE06	2017-07-16 18:57:00+03	29200.00
E5CE18	2017-07-14 21:08:00+03	258400.00
E5CEDD	2017-07-09 20:04:00+03	63400.00
E5CF51	2017-07-21 12:12:00+03	118600.00
E5CF64	2017-07-28 14:33:00+03	49800.00
E5CF9C	2017-08-04 11:54:00+03	67900.00
E5D03A	2017-07-31 07:40:00+03	48700.00
E5D08D	2017-07-24 08:29:00+03	26800.00
E5D08F	2017-07-20 06:44:00+03	117800.00
E5D095	2017-07-11 10:02:00+03	31400.00
E5D0AC	2017-07-17 14:01:00+03	133200.00
E5D0B7	2017-07-25 23:52:00+03	66600.00
E5D112	2017-07-03 10:05:00+03	6900.00
E5D1D7	2017-08-11 16:35:00+03	26000.00
E5D243	2017-07-02 14:22:00+03	46400.00
E5D253	2017-08-04 02:52:00+03	26800.00
E5D27B	2017-07-15 11:45:00+03	41600.00
E5D2BD	2017-08-01 19:44:00+03	54300.00
E5D2CF	2017-07-25 02:31:00+03	148200.00
E5D2D1	2017-07-04 09:17:00+03	41400.00
E5D2F4	2017-07-15 16:53:00+03	48700.00
E5D34D	2017-07-25 07:08:00+03	51200.00
E5D351	2017-07-03 04:42:00+03	109000.00
E5D3BA	2017-07-17 02:04:00+03	154500.00
E5D3BB	2017-07-16 02:50:00+03	52900.00
E5D3E5	2017-07-03 20:14:00+03	429000.00
E5D457	2017-08-04 22:19:00+03	75300.00
E5D45C	2017-07-29 06:34:00+03	34000.00
E5D4D3	2017-07-09 21:11:00+03	56000.00
E5D4FA	2017-08-09 02:21:00+03	36800.00
E5D506	2017-08-09 22:55:00+03	87400.00
E5D55E	2017-08-08 11:17:00+03	73100.00
E5D5FE	2017-07-21 22:01:00+03	47400.00
E5D67D	2017-07-12 10:10:00+03	26800.00
E5D68B	2017-06-29 17:12:00+03	28300.00
E5D6B5	2017-08-09 22:46:00+03	48800.00
E5D6CD	2017-07-06 11:39:00+03	171000.00
E5D76A	2017-08-02 10:29:00+03	31900.00
E5D7CD	2017-08-11 08:39:00+03	22100.00
E5D818	2017-07-21 18:55:00+03	28800.00
E5D8DF	2017-07-15 17:27:00+03	48800.00
E5D90B	2017-07-26 23:24:00+03	81700.00
E5D919	2017-07-05 19:36:00+03	98800.00
E5D93C	2017-08-05 05:54:00+03	67200.00
E5D951	2017-08-12 00:17:00+03	7400.00
E5D9B7	2017-07-10 09:53:00+03	51800.00
E5D9BA	2017-08-01 15:15:00+03	47000.00
E5DA1B	2017-08-14 01:25:00+03	67200.00
E5DA50	2017-07-15 21:51:00+03	52900.00
E5DA9D	2017-07-31 03:04:00+03	68400.00
E5DB47	2017-07-30 08:29:00+03	105400.00
E5DBF1	2017-08-01 10:39:00+03	272400.00
E5DC37	2017-07-17 09:33:00+03	135600.00
E5DC52	2017-07-09 21:09:00+03	56000.00
E5DC7F	2017-08-06 16:20:00+03	64500.00
E5DC8E	2017-07-24 00:56:00+03	94000.00
E5DCD9	2017-07-22 05:50:00+03	100600.00
E5DD00	2017-07-29 07:35:00+03	51900.00
E5DD68	2017-07-17 20:16:00+03	133100.00
E5DDD9	2017-08-10 07:33:00+03	161600.00
E5DDED	2017-07-22 21:18:00+03	90800.00
E5DDEE	2017-07-15 18:31:00+03	56100.00
E5DDF3	2017-07-22 20:21:00+03	55800.00
E5DE79	2017-08-13 19:34:00+03	44000.00
E5DEA9	2017-07-16 12:28:00+03	93900.00
E5DF30	2017-07-15 00:53:00+03	47100.00
E5DF83	2017-07-02 00:39:00+03	56600.00
E5DFE6	2017-07-25 02:37:00+03	23400.00
E5DFF9	2017-07-16 16:00:00+03	50000.00
E5E011	2017-08-09 07:22:00+03	75300.00
E5E015	2017-07-22 04:06:00+03	627100.00
E5E018	2017-07-30 00:59:00+03	258600.00
E5E088	2017-07-15 00:31:00+03	28000.00
E5E096	2017-08-12 14:08:00+03	67600.00
E5E0AD	2017-07-24 18:55:00+03	67600.00
E5E0AF	2017-07-01 06:57:00+03	108500.00
E5E0E1	2017-07-06 03:20:00+03	59300.00
E5E0FE	2017-08-05 17:50:00+03	21800.00
E5E101	2017-07-31 15:16:00+03	55800.00
E5E14B	2017-07-02 17:01:00+03	119600.00
E5E187	2017-07-08 04:59:00+03	40400.00
E5E194	2017-06-23 13:28:00+03	283100.00
E5E229	2017-07-01 09:41:00+03	282600.00
E5E236	2017-07-20 18:17:00+03	84800.00
E5E260	2017-07-09 13:36:00+03	46000.00
E5E308	2017-07-28 16:36:00+03	52600.00
E5E32F	2017-08-11 21:37:00+03	74900.00
E5E33C	2017-07-19 14:07:00+03	124000.00
E5E378	2017-07-07 19:19:00+03	135200.00
E5E3C4	2017-08-14 00:09:00+03	46800.00
E5E3CC	2017-07-03 20:10:00+03	13400.00
E5E3E3	2017-08-12 23:48:00+03	89600.00
E5E42A	2017-07-26 04:54:00+03	45200.00
E5E450	2017-07-10 17:37:00+03	8200.00
E5E480	2017-07-20 10:14:00+03	75600.00
E5E4CA	2017-07-27 04:02:00+03	49800.00
E5E51A	2017-07-29 13:23:00+03	68000.00
E5E52F	2017-08-13 01:54:00+03	146000.00
E5E5BE	2017-07-05 03:03:00+03	51900.00
E5E5D7	2017-07-29 18:27:00+03	34000.00
E5E602	2017-07-23 04:49:00+03	89800.00
E5E620	2017-06-28 02:13:00+03	91800.00
E5E62F	2017-07-06 17:40:00+03	20900.00
E5E641	2017-08-09 02:37:00+03	12600.00
E5E65A	2017-07-21 13:54:00+03	14400.00
E5E682	2017-07-24 18:49:00+03	52800.00
E5E690	2017-08-11 19:55:00+03	102100.00
E5E70B	2017-07-26 15:25:00+03	56600.00
E5E786	2017-07-14 13:52:00+03	49800.00
E5E805	2017-07-18 20:32:00+03	55800.00
E5E88E	2017-07-21 17:24:00+03	84500.00
E5E890	2017-07-18 16:41:00+03	128800.00
E5E8B0	2017-07-28 11:41:00+03	58700.00
E5E8B7	2017-07-03 20:31:00+03	14000.00
E5E8B8	2017-08-03 12:12:00+03	62700.00
E5E8E5	2017-08-03 22:21:00+03	66600.00
E5E940	2017-08-14 09:10:00+03	41800.00
E5E97F	2017-07-11 02:53:00+03	23600.00
E5E9AF	2017-08-05 22:00:00+03	223200.00
E5E9ED	2017-07-20 22:24:00+03	92800.00
E5EA2D	2017-07-06 10:45:00+03	7400.00
E5EA5A	2017-08-03 07:54:00+03	81300.00
E5EADD	2017-07-28 02:49:00+03	25200.00
E5EAF8	2017-07-06 14:54:00+03	28000.00
E5EAFF	2017-07-30 14:30:00+03	46400.00
E5EB48	2017-07-20 20:22:00+03	69500.00
E5EBC5	2017-07-16 10:13:00+03	28800.00
E5EBFA	2017-07-29 20:47:00+03	413400.00
E5EC26	2017-07-10 05:20:00+03	24800.00
E5EC2A	2017-06-27 07:14:00+03	65900.00
E5ED19	2017-08-07 00:51:00+03	167400.00
E5ED2A	2017-07-05 17:17:00+03	14400.00
E5EDE1	2017-08-13 19:41:00+03	26700.00
E5EDE3	2017-07-04 23:14:00+03	75300.00
E5EE55	2017-07-18 03:49:00+03	338200.00
E5EEB4	2017-07-14 09:53:00+03	37800.00
E5EEDC	2017-07-12 19:48:00+03	47700.00
E5EF46	2017-07-01 05:28:00+03	78800.00
E5EFB9	2017-07-19 09:55:00+03	98400.00
E5F01B	2017-08-04 06:19:00+03	56000.00
E5F03C	2017-07-17 07:42:00+03	211400.00
E5F145	2017-08-03 02:35:00+03	14000.00
E5F147	2017-08-08 11:16:00+03	105400.00
E5F148	2017-07-08 14:02:00+03	13000.00
E5F195	2017-07-30 03:09:00+03	103500.00
E5F1BD	2017-07-22 22:56:00+03	21800.00
E5F242	2017-07-26 09:19:00+03	46000.00
E5F2EC	2017-08-04 02:15:00+03	8200.00
E5F300	2017-08-07 11:46:00+03	68400.00
E5F30D	2017-08-14 19:38:00+03	24600.00
E5F362	2017-08-10 17:20:00+03	29600.00
E5F37B	2017-07-21 09:30:00+03	57400.00
E5F3BE	2017-07-14 22:02:00+03	12600.00
E5F3F8	2017-07-01 03:01:00+03	44800.00
E5F4CA	2017-07-30 15:32:00+03	12000.00
E5F4FA	2017-07-19 09:55:00+03	38800.00
E5F541	2017-07-31 00:01:00+03	135600.00
E5F547	2017-08-07 00:04:00+03	113200.00
E5F5FA	2017-08-05 14:05:00+03	13200.00
E5F637	2017-08-08 17:20:00+03	85000.00
E5F69F	2017-08-10 07:56:00+03	56000.00
E5F6AA	2017-07-16 12:40:00+03	27900.00
E5F6B3	2017-07-29 21:08:00+03	56600.00
E5F6BB	2017-07-08 23:51:00+03	65400.00
E5F6E9	2017-08-12 04:13:00+03	66600.00
E5F6EA	2017-07-30 17:57:00+03	199800.00
E5F6F2	2017-08-14 20:48:00+03	68100.00
E5F6FB	2017-07-13 08:13:00+03	186900.00
E5F71D	2017-07-28 22:50:00+03	93200.00
E5F7AC	2017-07-02 13:34:00+03	36400.00
E5F7BD	2017-07-06 10:47:00+03	54500.00
E5F819	2017-07-30 11:43:00+03	18000.00
E5F833	2017-07-18 18:16:00+03	135400.00
E5F83F	2017-07-16 22:59:00+03	82100.00
E5F88B	2017-07-09 15:06:00+03	332200.00
E5F93F	2017-07-21 15:53:00+03	81300.00
E5F96D	2017-08-12 07:47:00+03	65500.00
E5F9B1	2017-07-28 15:05:00+03	100000.00
E5FA1B	2017-07-10 21:51:00+03	76200.00
E5FA49	2017-08-12 04:46:00+03	101200.00
E5FA5F	2017-07-07 15:22:00+03	224000.00
E5FA78	2017-07-30 16:15:00+03	19600.00
E5FAA1	2017-07-24 12:28:00+03	66300.00
E5FAE0	2017-08-05 04:04:00+03	38600.00
E5FAF7	2017-07-29 06:06:00+03	85000.00
E5FB03	2017-07-27 11:23:00+03	76000.00
E5FB91	2017-07-10 18:14:00+03	58200.00
E5FBB7	2017-08-09 11:09:00+03	89600.00
E5FBF6	2017-08-14 15:32:00+03	15000.00
E5FC84	2017-07-18 19:47:00+03	166100.00
E5FCE9	2017-07-03 17:03:00+03	67100.00
E5FD29	2017-08-03 04:36:00+03	47100.00
E5FD5B	2017-07-27 11:09:00+03	38800.00
E5FDCA	2017-07-04 10:39:00+03	29600.00
E5FE01	2017-07-23 18:12:00+03	52700.00
E5FE0B	2017-07-29 07:37:00+03	193700.00
E5FE84	2017-08-12 08:17:00+03	207300.00
E5FE9A	2017-07-06 21:31:00+03	199700.00
E5FEE0	2017-07-17 01:10:00+03	9800.00
E5FFA8	2017-07-01 18:04:00+03	44000.00
E5FFFC	2017-07-10 12:51:00+03	54800.00
E60005	2017-07-20 01:38:00+03	42100.00
E60015	2017-08-03 07:44:00+03	12400.00
E60072	2017-07-03 00:10:00+03	28800.00
E60078	2017-07-18 23:08:00+03	75300.00
E6009A	2017-07-31 10:28:00+03	40100.00
E600A3	2017-07-16 20:03:00+03	132300.00
E600F6	2017-07-17 19:14:00+03	190400.00
E600FC	2017-07-20 15:18:00+03	28800.00
E600FF	2017-07-24 11:00:00+03	34000.00
E6014D	2017-07-25 18:17:00+03	31600.00
E60191	2017-07-15 12:43:00+03	37800.00
E601F4	2017-08-11 16:20:00+03	147000.00
E60214	2017-07-26 22:03:00+03	32200.00
E60236	2017-08-13 03:52:00+03	31900.00
E60255	2017-07-10 06:52:00+03	229600.00
E60282	2017-07-03 11:04:00+03	266400.00
E6033C	2017-07-25 07:12:00+03	46400.00
E603EB	2017-06-28 23:54:00+03	201200.00
E6046B	2017-07-16 03:05:00+03	155600.00
E604F3	2017-07-27 00:44:00+03	124300.00
E6050C	2017-07-04 02:37:00+03	46500.00
E60579	2017-07-27 00:48:00+03	29100.00
E6058F	2017-08-10 21:37:00+03	297600.00
E6060F	2017-07-12 05:46:00+03	68000.00
E6063E	2017-08-06 18:38:00+03	115800.00
E606D9	2017-07-18 02:01:00+03	12000.00
E60745	2017-08-05 08:02:00+03	106400.00
E6077C	2017-08-13 17:54:00+03	27400.00
E607B9	2017-08-11 05:41:00+03	24400.00
E607BD	2017-07-18 06:26:00+03	147200.00
E60891	2017-07-12 08:34:00+03	26000.00
E608A8	2017-07-17 05:21:00+03	42400.00
E608EB	2017-07-27 15:43:00+03	82900.00
E608FC	2017-07-17 04:41:00+03	47000.00
E6091B	2017-08-12 17:37:00+03	88800.00
E60996	2017-07-07 10:04:00+03	13600.00
E609D8	2017-08-01 16:52:00+03	52400.00
E60A5A	2017-07-12 23:41:00+03	29200.00
E60AEA	2017-08-03 07:17:00+03	86300.00
E60B2D	2017-08-12 20:59:00+03	132200.00
E60B32	2017-08-03 03:47:00+03	56000.00
E60B5B	2017-07-03 18:14:00+03	136200.00
E60BEC	2017-07-31 11:03:00+03	408500.00
E60C4E	2017-08-03 16:52:00+03	664300.00
E60C7D	2017-08-02 20:59:00+03	266400.00
E60C9A	2017-06-29 08:25:00+03	59900.00
E60D28	2017-07-03 16:35:00+03	37200.00
E60DA4	2017-08-02 13:33:00+03	85600.00
E60DBE	2017-07-31 17:23:00+03	93900.00
E60E3D	2017-08-15 17:26:00+03	56200.00
E60EB3	2017-07-04 07:38:00+03	7400.00
E60F63	2017-07-24 08:36:00+03	8200.00
E60F8A	2017-07-12 18:03:00+03	57500.00
E61007	2017-07-21 17:13:00+03	60800.00
E61015	2017-07-13 00:54:00+03	68100.00
E61016	2017-08-08 23:28:00+03	133200.00
E61038	2017-07-19 09:33:00+03	40800.00
E6105B	2017-07-02 23:32:00+03	84500.00
E6106A	2017-08-04 07:55:00+03	70800.00
E610E0	2017-08-01 20:40:00+03	36500.00
E61141	2017-07-23 17:48:00+03	40800.00
E61180	2017-07-30 19:18:00+03	56000.00
E61192	2017-07-28 09:59:00+03	6000.00
E611A5	2017-07-19 03:13:00+03	63200.00
E611BA	2017-07-03 22:15:00+03	124000.00
E611C3	2017-08-06 15:48:00+03	12600.00
E61207	2017-07-09 17:46:00+03	170500.00
E6120F	2017-07-27 14:06:00+03	399600.00
E61241	2017-07-17 03:37:00+03	123000.00
E61253	2017-07-28 03:35:00+03	278500.00
E612B2	2017-08-09 05:49:00+03	16400.00
E612D3	2017-07-18 09:34:00+03	46900.00
E6136F	2017-07-03 08:45:00+03	105000.00
E613D6	2017-08-12 04:55:00+03	21000.00
E613FF	2017-08-09 18:52:00+03	29400.00
E61492	2017-07-19 12:34:00+03	67800.00
E614AB	2017-08-04 10:35:00+03	63900.00
E6164F	2017-07-27 03:30:00+03	16400.00
E61694	2017-07-29 15:27:00+03	6000.00
E616B3	2017-07-19 18:37:00+03	108000.00
E616D2	2017-07-24 16:16:00+03	65500.00
E616DA	2017-08-03 00:19:00+03	18600.00
E616E4	2017-07-03 22:35:00+03	37200.00
E6172F	2017-07-01 05:23:00+03	29400.00
E61753	2017-07-08 18:50:00+03	122300.00
E617A6	2017-07-03 21:02:00+03	62100.00
E61810	2017-08-06 21:40:00+03	6700.00
E6181E	2017-06-30 05:19:00+03	46400.00
E6187B	2017-08-06 17:05:00+03	112000.00
E61958	2017-08-10 21:39:00+03	17800.00
E6195B	2017-07-19 21:04:00+03	56900.00
E61971	2017-07-10 03:31:00+03	102700.00
E61A3E	2017-07-17 12:33:00+03	355200.00
E61A69	2017-08-07 14:19:00+03	45200.00
E61AE8	2017-08-07 07:14:00+03	59000.00
E61B36	2017-07-17 09:08:00+03	64700.00
E61B64	2017-07-05 13:57:00+03	244600.00
E61B7A	2017-07-11 21:24:00+03	46000.00
E61C01	2017-08-10 03:11:00+03	129300.00
E61C0C	2017-07-29 18:47:00+03	73000.00
E61C56	2017-08-12 21:25:00+03	21400.00
E61C6B	2017-07-15 08:31:00+03	59800.00
E61CA0	2017-08-12 08:49:00+03	76800.00
E61CB3	2017-07-16 03:00:00+03	73200.00
E61CED	2017-08-01 11:23:00+03	113300.00
E61CF3	2017-07-21 13:32:00+03	58400.00
E61D0A	2017-07-17 20:31:00+03	73200.00
E61D7C	2017-08-02 05:06:00+03	39800.00
E61D92	2017-07-29 11:31:00+03	60700.00
E61DAC	2017-08-07 19:01:00+03	23200.00
E61E21	2017-07-28 14:55:00+03	53600.00
E61E50	2017-08-10 15:15:00+03	149100.00
E61E8F	2017-08-09 13:50:00+03	56000.00
E61F3F	2017-08-11 01:44:00+03	31400.00
E61FC9	2017-07-03 20:44:00+03	135600.00
E62053	2017-07-09 19:18:00+03	157100.00
E6205A	2017-07-30 09:33:00+03	40800.00
E620AE	2017-07-21 23:30:00+03	210600.00
E620F1	2017-08-06 14:57:00+03	58600.00
E6210A	2017-07-24 14:46:00+03	33100.00
E62125	2017-07-18 01:41:00+03	48300.00
E62136	2017-07-03 13:34:00+03	118400.00
E6213E	2017-08-06 01:25:00+03	46400.00
E62187	2017-08-03 12:06:00+03	69000.00
E62189	2017-08-13 07:52:00+03	70700.00
E621BB	2017-07-14 18:27:00+03	33100.00
E621E7	2017-07-14 13:04:00+03	40000.00
E621EF	2017-07-25 09:36:00+03	88900.00
E6226C	2017-07-06 03:40:00+03	42400.00
E622EC	2017-08-03 15:39:00+03	94200.00
E62382	2017-06-30 18:59:00+03	54800.00
E623CA	2017-07-31 19:22:00+03	14000.00
E623DD	2017-07-26 16:59:00+03	98300.00
E62423	2017-08-04 01:15:00+03	175400.00
E6244F	2017-07-16 01:16:00+03	38600.00
E6245C	2017-07-30 22:59:00+03	80300.00
E6245E	2017-07-21 14:41:00+03	13000.00
E624F2	2017-07-31 01:57:00+03	46800.00
E62544	2017-07-12 17:38:00+03	77000.00
E625A1	2017-07-28 09:07:00+03	177600.00
E625D4	2017-07-13 00:51:00+03	136200.00
E625E0	2017-07-24 20:40:00+03	98200.00
E625E4	2017-08-07 01:45:00+03	83300.00
E62658	2017-07-08 07:39:00+03	267700.00
E6266E	2017-06-29 06:08:00+03	21400.00
E626CE	2017-08-12 05:31:00+03	12600.00
E626F2	2017-07-09 09:17:00+03	56400.00
E626FA	2017-08-04 11:46:00+03	27300.00
E62786	2017-07-04 21:53:00+03	112000.00
E627FB	2017-07-26 13:16:00+03	44800.00
E62810	2017-07-12 12:03:00+03	31200.00
E6281F	2017-08-05 22:13:00+03	34000.00
E62838	2017-08-13 15:46:00+03	27200.00
E6285E	2017-07-03 17:21:00+03	16200.00
E62879	2017-07-25 19:04:00+03	71200.00
E628B6	2017-06-29 04:10:00+03	25600.00
E628C1	2017-08-01 05:17:00+03	94000.00
E628F4	2017-07-30 07:06:00+03	119300.00
E62933	2017-08-05 08:22:00+03	26000.00
E6296A	2017-08-14 14:34:00+03	26000.00
E629AE	2017-07-27 22:59:00+03	181200.00
E629CD	2017-08-01 04:50:00+03	55800.00
E62A33	2017-08-07 23:10:00+03	139200.00
E62A48	2017-07-17 17:57:00+03	24000.00
E62A6F	2017-07-23 14:14:00+03	49200.00
E62A72	2017-06-27 20:00:00+03	37900.00
E62AB5	2017-08-01 17:24:00+03	23200.00
E62AF1	2017-07-18 21:10:00+03	117200.00
E62B76	2017-07-28 08:18:00+03	55800.00
E62B95	2017-07-03 11:01:00+03	67600.00
E62BA0	2017-07-27 21:38:00+03	184000.00
E62C5C	2017-08-11 02:36:00+03	49600.00
E62C8C	2017-07-10 07:22:00+03	26000.00
E62C97	2017-07-26 19:13:00+03	184500.00
E62CB0	2017-08-13 07:31:00+03	75100.00
E62CC6	2017-07-18 02:42:00+03	55800.00
E62D93	2017-07-13 04:24:00+03	31600.00
E62DC5	2017-07-28 05:21:00+03	34000.00
E62DD5	2017-07-29 09:38:00+03	114200.00
E62DF2	2017-07-04 23:21:00+03	8200.00
E62DF5	2017-07-13 06:23:00+03	75300.00
E62E0F	2017-07-03 01:07:00+03	56600.00
E62E2F	2017-07-19 03:07:00+03	23200.00
E62E33	2017-07-21 07:17:00+03	62100.00
E62F01	2017-07-19 02:59:00+03	14000.00
E62F20	2017-06-30 04:21:00+03	45100.00
E62FA8	2017-08-02 08:15:00+03	28000.00
E62FDA	2017-07-13 09:26:00+03	67200.00
E62FDC	2017-07-30 14:48:00+03	54700.00
E63025	2017-08-10 17:23:00+03	46400.00
E6302A	2017-07-24 13:04:00+03	23400.00
E6305A	2017-07-29 15:32:00+03	271100.00
E63075	2017-07-27 06:14:00+03	13400.00
E63087	2017-07-19 15:00:00+03	24600.00
E630F7	2017-08-13 20:47:00+03	403000.00
E63129	2017-07-25 08:30:00+03	28800.00
E6313C	2017-07-05 20:23:00+03	168900.00
E63156	2017-07-01 03:01:00+03	50100.00
E63168	2017-07-27 13:52:00+03	124200.00
E631B9	2017-07-08 09:15:00+03	13200.00
E6320F	2017-07-25 15:56:00+03	6600.00
E63308	2017-07-24 07:34:00+03	13400.00
E63315	2017-07-12 20:23:00+03	39800.00
E633A9	2017-07-25 18:23:00+03	28300.00
E63430	2017-07-20 12:34:00+03	56000.00
E6345D	2017-07-25 20:26:00+03	10600.00
E63499	2017-08-02 12:52:00+03	140500.00
E634C8	2017-07-21 16:05:00+03	135400.00
E6353F	2017-08-13 09:28:00+03	28800.00
E63560	2017-07-17 19:42:00+03	168000.00
E6356F	2017-07-26 23:04:00+03	20200.00
E635D9	2017-08-03 14:28:00+03	8200.00
E63611	2017-08-10 07:05:00+03	29600.00
E63616	2017-07-13 13:08:00+03	246000.00
E63649	2017-07-03 02:15:00+03	87100.00
E636AF	2017-07-16 01:23:00+03	28000.00
E63701	2017-07-06 21:39:00+03	136600.00
E6373B	2017-07-29 21:20:00+03	77600.00
E63750	2017-07-06 20:12:00+03	47000.00
E6375A	2017-07-12 23:41:00+03	22600.00
E637A5	2017-08-12 07:11:00+03	42800.00
E63842	2017-07-17 03:01:00+03	51900.00
E638CE	2017-08-06 14:40:00+03	44800.00
E638D2	2017-07-29 03:38:00+03	39200.00
E638E1	2017-06-30 13:50:00+03	85600.00
E63958	2017-07-05 20:31:00+03	6700.00
E6395E	2017-07-21 07:27:00+03	24300.00
E639E4	2017-08-10 21:14:00+03	133200.00
E639F9	2017-07-02 07:53:00+03	26800.00
E63A06	2017-08-14 03:23:00+03	6000.00
E63A62	2017-07-18 16:31:00+03	23400.00
E63A67	2017-06-29 15:08:00+03	6400.00
E63A69	2017-08-04 12:59:00+03	65500.00
E63ABB	2017-07-26 19:37:00+03	26200.00
E63B7B	2017-07-02 03:04:00+03	67600.00
E63C25	2017-08-13 14:50:00+03	61900.00
E63C3E	2017-07-08 17:41:00+03	9800.00
E63C40	2017-08-13 01:59:00+03	77200.00
E63CD8	2017-07-27 15:14:00+03	28800.00
E63D7E	2017-07-24 06:07:00+03	92800.00
E63DFA	2017-07-18 03:43:00+03	44700.00
E63E06	2017-07-19 15:42:00+03	30700.00
E63E0A	2017-07-09 23:13:00+03	100600.00
E63E32	2017-07-26 02:07:00+03	84500.00
E63E86	2017-07-25 13:15:00+03	173200.00
E63E94	2017-07-18 21:26:00+03	14000.00
E63EB3	2017-07-10 17:59:00+03	60800.00
E63EB6	2017-08-15 16:22:00+03	139100.00
E63ED1	2017-07-23 07:23:00+03	23600.00
E63F22	2017-07-05 01:21:00+03	33000.00
E63F73	2017-07-19 13:59:00+03	531400.00
E63F88	2017-07-24 14:17:00+03	47400.00
E6403E	2017-08-10 04:50:00+03	26700.00
E6406C	2017-07-12 11:40:00+03	44800.00
E6408F	2017-07-17 08:02:00+03	46400.00
E640C3	2017-08-08 23:34:00+03	39800.00
E640F7	2017-07-12 11:25:00+03	117000.00
E640FD	2017-07-28 14:19:00+03	94300.00
E6416C	2017-07-12 13:03:00+03	165400.00
E64172	2017-07-25 01:45:00+03	136200.00
E641FD	2017-08-14 23:16:00+03	47100.00
E64295	2017-07-19 02:07:00+03	133200.00
E642C6	2017-07-22 06:48:00+03	31600.00
E64308	2017-07-08 17:29:00+03	47100.00
E6430F	2017-08-11 08:34:00+03	47100.00
E64322	2017-08-09 10:30:00+03	47000.00
E643A0	2017-08-11 21:32:00+03	93700.00
E643C4	2017-08-02 07:16:00+03	52400.00
E643FF	2017-07-06 00:52:00+03	48800.00
E64416	2017-08-10 07:04:00+03	26800.00
E6441A	2017-07-28 03:49:00+03	56000.00
E64471	2017-08-13 15:39:00+03	18800.00
E64528	2017-07-11 22:07:00+03	199700.00
E64559	2017-07-03 03:53:00+03	26800.00
E6456D	2017-07-14 06:07:00+03	73100.00
E645A9	2017-08-10 00:33:00+03	37800.00
E645E5	2017-08-01 04:18:00+03	111600.00
E646FA	2017-08-05 08:00:00+03	6800.00
E6470B	2017-08-12 17:26:00+03	149000.00
E647AD	2017-08-04 18:02:00+03	90400.00
E64811	2017-07-31 21:39:00+03	467000.00
E6483B	2017-07-19 18:31:00+03	68900.00
E6484A	2017-08-07 17:44:00+03	27300.00
E64863	2017-08-04 23:47:00+03	58200.00
E6486D	2017-07-09 08:16:00+03	58900.00
E648B0	2017-06-29 01:35:00+03	54800.00
E648F9	2017-07-30 14:26:00+03	70700.00
E64945	2017-07-21 22:04:00+03	109700.00
E64947	2017-07-08 11:33:00+03	21400.00
E649AD	2017-07-18 03:48:00+03	69500.00
E649DF	2017-07-09 17:06:00+03	37500.00
E64A23	2017-08-10 15:20:00+03	62100.00
E64A62	2017-08-03 09:59:00+03	106400.00
E64A76	2017-07-26 08:44:00+03	270800.00
E64B0B	2017-07-17 04:52:00+03	29000.00
E64B56	2017-07-18 21:42:00+03	130800.00
E64B8C	2017-07-03 16:00:00+03	56600.00
E64B8F	2017-06-25 18:06:00+03	62600.00
E64B9A	2017-08-12 16:01:00+03	43000.00
E64C24	2017-07-31 11:57:00+03	393800.00
E64CE5	2017-08-09 15:49:00+03	52500.00
E64CF5	2017-07-05 08:46:00+03	246000.00
E64DDE	2017-07-19 12:57:00+03	89800.00
E64DF7	2017-07-26 01:15:00+03	23600.00
E64E2E	2017-07-06 18:36:00+03	29600.00
E64E55	2017-07-30 20:01:00+03	23200.00
E64E79	2017-07-27 13:09:00+03	63700.00
E64EB6	2017-08-02 01:43:00+03	151000.00
E64F01	2017-06-29 15:59:00+03	87000.00
E64F25	2017-07-23 02:48:00+03	47400.00
E64F3F	2017-08-01 13:32:00+03	29400.00
E64F50	2017-08-02 20:37:00+03	140100.00
E64FA1	2017-07-11 21:00:00+03	193100.00
E65012	2017-08-14 20:47:00+03	66600.00
E65024	2017-08-15 07:09:00+03	85700.00
E65033	2017-07-27 15:28:00+03	47000.00
E6504D	2017-07-21 20:21:00+03	28800.00
E6506A	2017-08-13 05:30:00+03	28700.00
E650AC	2017-07-02 23:20:00+03	26700.00
E650D7	2017-07-19 21:03:00+03	81600.00
E650D8	2017-07-10 13:34:00+03	133200.00
E650E4	2017-08-06 01:02:00+03	31400.00
E65104	2017-07-31 20:01:00+03	114300.00
E6512B	2017-07-24 13:13:00+03	18700.00
E6519C	2017-06-30 23:44:00+03	28000.00
E651A5	2017-08-02 11:28:00+03	44300.00
E651B4	2017-07-10 23:26:00+03	270700.00
E651B9	2017-08-01 12:05:00+03	173500.00
E6522E	2017-07-11 07:19:00+03	111600.00
E65249	2017-08-15 10:00:00+03	39800.00
E65277	2017-08-12 09:21:00+03	61800.00
E65283	2017-08-13 07:12:00+03	39700.00
E652A9	2017-07-09 03:26:00+03	21800.00
E652EB	2017-06-30 14:53:00+03	23200.00
E65366	2017-07-13 22:12:00+03	116000.00
E65394	2017-08-03 04:05:00+03	47100.00
E653DC	2017-08-07 02:39:00+03	21400.00
E6541B	2017-07-18 14:03:00+03	67400.00
E65421	2017-08-12 09:26:00+03	38600.00
E65423	2017-07-28 13:16:00+03	192400.00
E654C6	2017-08-15 12:28:00+03	23000.00
E65572	2017-08-05 15:27:00+03	57500.00
E65584	2017-07-03 23:43:00+03	209700.00
E655AD	2017-07-21 23:13:00+03	6000.00
E655B7	2017-07-25 18:00:00+03	74900.00
E655ED	2017-08-03 04:21:00+03	115600.00
E655EF	2017-07-01 22:41:00+03	99200.00
E65641	2017-07-31 10:02:00+03	152700.00
E656A6	2017-07-02 05:19:00+03	23200.00
E65781	2017-08-10 00:30:00+03	46200.00
E65805	2017-08-04 15:41:00+03	82300.00
E65848	2017-08-13 17:43:00+03	21800.00
E65858	2017-07-07 21:00:00+03	140900.00
E6588C	2017-08-01 12:39:00+03	69700.00
E65891	2017-07-08 04:21:00+03	28800.00
E658EB	2017-07-19 04:07:00+03	12600.00
E65969	2017-07-20 23:42:00+03	40400.00
E65981	2017-07-26 14:55:00+03	55800.00
E659D4	2017-07-15 11:46:00+03	20400.00
E659F7	2017-07-26 19:18:00+03	9800.00
E659F9	2017-07-01 21:51:00+03	128400.00
E65A3D	2017-07-08 07:12:00+03	40800.00
E65A87	2017-07-04 08:17:00+03	93700.00
E65AFF	2017-08-14 10:29:00+03	25600.00
E65B1D	2017-07-21 21:16:00+03	46300.00
E65B98	2017-07-13 19:50:00+03	88500.00
E65B9F	2017-07-06 03:01:00+03	177400.00
E65C70	2017-08-08 20:05:00+03	105800.00
E65C80	2017-07-05 01:45:00+03	206700.00
E65CED	2017-07-05 23:17:00+03	52800.00
E65D45	2017-07-20 05:06:00+03	25700.00
E65DC4	2017-07-10 21:35:00+03	14400.00
E65DD0	2017-08-02 01:48:00+03	55800.00
E65E16	2017-08-15 00:41:00+03	56900.00
E65E5F	2017-07-10 15:34:00+03	31200.00
E65E6D	2017-07-17 06:41:00+03	6700.00
E65E70	2017-07-14 18:03:00+03	46400.00
E65E7F	2017-08-10 23:34:00+03	118300.00
E65ED6	2017-07-15 04:15:00+03	82900.00
E65F77	2017-08-14 21:30:00+03	54800.00
E65FBF	2017-07-31 10:39:00+03	21800.00
E6602D	2017-07-12 05:54:00+03	14400.00
E66031	2017-07-03 06:46:00+03	214900.00
E6603D	2017-07-31 01:21:00+03	123000.00
E6617B	2017-07-19 08:09:00+03	124200.00
E66181	2017-07-12 20:18:00+03	39800.00
E66186	2017-07-06 23:22:00+03	93900.00
E661E1	2017-07-05 05:26:00+03	119600.00
E6625F	2017-08-07 23:32:00+03	192700.00
E6626E	2017-07-27 21:23:00+03	28600.00
E66286	2017-07-25 23:37:00+03	27800.00
E6639D	2017-07-13 13:29:00+03	246000.00
E6639F	2017-08-12 16:20:00+03	22000.00
E663AE	2017-08-10 11:46:00+03	73500.00
E663D9	2017-07-10 12:34:00+03	99200.00
E663E3	2017-08-03 18:20:00+03	13400.00
E66400	2017-07-26 09:13:00+03	35500.00
E664B7	2017-07-14 11:54:00+03	124300.00
E664DD	2017-07-09 10:11:00+03	136800.00
E664E9	2017-07-25 12:10:00+03	62600.00
E66504	2017-07-03 18:30:00+03	133100.00
E66522	2017-06-30 15:32:00+03	46200.00
E66537	2017-06-29 09:19:00+03	14000.00
E66555	2017-07-10 06:06:00+03	21200.00
E66596	2017-07-30 14:19:00+03	38400.00
E6659C	2017-07-16 22:48:00+03	69900.00
E665BB	2017-07-06 21:16:00+03	61800.00
E6665F	2017-07-27 09:38:00+03	23200.00
E6667D	2017-07-03 00:18:00+03	44500.00
E666DD	2017-08-05 01:40:00+03	11600.00
E666F9	2017-07-05 15:30:00+03	364600.00
E66748	2017-08-12 06:09:00+03	30700.00
E6679A	2017-07-21 15:55:00+03	29400.00
E667C8	2017-07-29 18:44:00+03	76600.00
E6682E	2017-07-15 01:06:00+03	24400.00
E66855	2017-07-29 19:26:00+03	37200.00
E6687E	2017-07-19 19:02:00+03	34000.00
E668A5	2017-07-11 15:02:00+03	6000.00
E668BA	2017-07-01 08:13:00+03	73400.00
E66908	2017-07-29 17:52:00+03	133100.00
E6695D	2017-08-05 09:18:00+03	55800.00
E669B8	2017-07-19 07:07:00+03	20600.00
E669DC	2017-07-08 10:20:00+03	64800.00
E66A1A	2017-07-02 12:17:00+03	47400.00
E66A59	2017-07-23 23:10:00+03	85000.00
E66A6E	2017-07-31 21:49:00+03	57400.00
E66B02	2017-08-04 01:47:00+03	85000.00
E66BB5	2017-07-07 15:24:00+03	100600.00
E66BDC	2017-07-07 06:34:00+03	31500.00
E66C0D	2017-07-20 06:33:00+03	496600.00
E66C3E	2017-08-10 06:10:00+03	47800.00
E66C41	2017-08-06 12:46:00+03	94900.00
E66C6D	2017-07-12 17:47:00+03	22000.00
E66C7B	2017-07-15 16:19:00+03	124900.00
E66C95	2017-07-14 08:35:00+03	85600.00
E66CAA	2017-08-13 07:03:00+03	252200.00
E66CC9	2017-07-31 13:04:00+03	30800.00
E66D48	2017-07-19 14:00:00+03	132800.00
E66DA7	2017-07-19 07:04:00+03	122300.00
E66DA8	2017-07-11 12:04:00+03	199700.00
E66DAE	2017-06-28 20:50:00+03	188000.00
E66DB2	2017-08-05 04:38:00+03	73200.00
E66DE0	2017-08-04 17:19:00+03	67200.00
E66DE7	2017-07-30 01:26:00+03	157100.00
E66EF0	2017-08-08 01:06:00+03	28000.00
E66EF1	2017-08-04 07:21:00+03	56100.00
E66EF2	2017-07-20 03:43:00+03	56600.00
E66EF7	2017-07-26 00:39:00+03	51400.00
E66F0E	2017-06-30 02:03:00+03	114700.00
E66F3E	2017-07-04 04:54:00+03	40400.00
E66FB6	2017-08-13 10:52:00+03	46200.00
E66FD4	2017-07-26 21:03:00+03	99200.00
E66FDC	2017-07-26 08:55:00+03	25600.00
E6700A	2017-07-21 04:24:00+03	65500.00
E67069	2017-07-23 03:49:00+03	12400.00
E67077	2017-06-29 14:44:00+03	119400.00
E670E8	2017-07-13 06:45:00+03	90000.00
E670FB	2017-07-16 20:26:00+03	55800.00
E67149	2017-08-03 23:59:00+03	25600.00
E67181	2017-07-05 01:44:00+03	92800.00
E6718A	2017-07-13 17:57:00+03	64100.00
E671A6	2017-07-09 23:27:00+03	14000.00
E671B2	2017-08-15 12:12:00+03	53900.00
E671D3	2017-07-09 07:26:00+03	14400.00
E67282	2017-07-15 18:11:00+03	68800.00
E672CB	2017-08-04 08:01:00+03	31400.00
E672F8	2017-07-19 14:39:00+03	61800.00
E67338	2017-07-25 07:25:00+03	43200.00
E67347	2017-07-13 01:18:00+03	38800.00
E67360	2017-07-20 21:09:00+03	30400.00
E6736B	2017-07-25 10:00:00+03	40400.00
E67383	2017-08-09 03:01:00+03	139500.00
E67388	2017-08-09 16:55:00+03	25800.00
E673D7	2017-08-14 19:57:00+03	50300.00
E67409	2017-08-11 02:04:00+03	246000.00
E6744B	2017-06-29 12:45:00+03	47400.00
E6746C	2017-07-17 07:20:00+03	516800.00
E67481	2017-07-28 19:26:00+03	46400.00
E674A8	2017-07-31 00:41:00+03	60300.00
E674BB	2017-08-08 07:45:00+03	26000.00
E67524	2017-07-24 05:31:00+03	40800.00
E67595	2017-08-01 16:00:00+03	11000.00
E675FB	2017-08-07 15:22:00+03	29600.00
E67614	2017-07-17 20:20:00+03	88500.00
E6762D	2017-08-12 09:02:00+03	23200.00
E67661	2017-07-07 09:49:00+03	14400.00
E67691	2017-08-15 06:23:00+03	36200.00
E676DD	2017-07-07 08:22:00+03	6800.00
E67710	2017-07-23 18:37:00+03	68800.00
E6774D	2017-07-22 08:06:00+03	66100.00
E67789	2017-07-15 20:11:00+03	8000.00
E677D3	2017-07-03 13:51:00+03	35800.00
E67879	2017-08-02 17:37:00+03	67600.00
E6788E	2017-07-21 05:20:00+03	30200.00
E678A5	2017-08-06 02:53:00+03	42800.00
E678F5	2017-08-07 11:40:00+03	79400.00
E67908	2017-08-02 23:51:00+03	20400.00
E679C6	2017-08-09 01:47:00+03	40800.00
E679DC	2017-08-11 10:21:00+03	55000.00
E679F8	2017-07-02 15:02:00+03	21200.00
E67A28	2017-07-24 15:36:00+03	75300.00
E67B41	2017-08-04 21:23:00+03	64700.00
E67B89	2017-08-05 19:05:00+03	23400.00
E67BE7	2017-08-01 07:07:00+03	162200.00
E67C27	2017-07-16 20:35:00+03	3700.00
E67C8D	2017-08-10 00:03:00+03	13600.00
E67CD5	2017-08-14 13:17:00+03	38400.00
E67CDF	2017-07-10 03:17:00+03	81800.00
E67D00	2017-06-30 18:43:00+03	52000.00
E67D17	2017-07-22 19:34:00+03	37400.00
E67D69	2017-07-25 22:00:00+03	31800.00
E67DAF	2017-07-30 00:24:00+03	73900.00
E67DC9	2017-07-11 22:31:00+03	48500.00
E67DD9	2017-08-08 08:53:00+03	406100.00
E67E39	2017-07-08 01:54:00+03	167400.00
E67EAC	2017-07-25 09:15:00+03	3400.00
E67ED9	2017-08-14 01:38:00+03	13400.00
E67EF8	2017-07-13 11:17:00+03	29600.00
E67F16	2017-07-11 01:26:00+03	39400.00
E67F18	2017-08-05 03:17:00+03	28800.00
E6800E	2017-08-04 21:41:00+03	53400.00
E68037	2017-07-12 12:22:00+03	56600.00
E68049	2017-08-11 11:16:00+03	198400.00
E68091	2017-08-03 04:43:00+03	20400.00
E680A1	2017-07-09 02:35:00+03	18300.00
E680A9	2017-08-07 22:10:00+03	57400.00
E680B3	2017-07-23 20:14:00+03	101100.00
E680F6	2017-06-29 12:05:00+03	28000.00
E681F0	2017-07-09 21:52:00+03	37100.00
E6822E	2017-07-04 08:24:00+03	6000.00
E682C0	2017-07-23 21:06:00+03	41200.00
E682D3	2017-08-01 11:04:00+03	73200.00
E682FC	2017-07-16 21:02:00+03	46200.00
E68307	2017-07-31 13:47:00+03	20400.00
E68344	2017-07-18 23:00:00+03	167400.00
E6834D	2017-08-05 20:06:00+03	26000.00
E6834E	2017-07-23 11:23:00+03	107500.00
E6838A	2017-06-28 14:08:00+03	55800.00
E683AC	2017-07-06 15:41:00+03	84100.00
E68453	2017-08-09 13:00:00+03	166900.00
E68479	2017-07-15 03:15:00+03	10800.00
E684CE	2017-06-28 01:28:00+03	65300.00
E684E2	2017-08-14 21:27:00+03	42100.00
E68512	2017-07-16 23:42:00+03	6700.00
E6854A	2017-08-15 04:31:00+03	32800.00
E68577	2017-07-23 19:06:00+03	85000.00
E68593	2017-07-15 13:36:00+03	29200.00
E685AB	2017-07-13 04:57:00+03	80900.00
E685CE	2017-08-14 20:43:00+03	46400.00
E6864F	2017-08-02 15:10:00+03	28800.00
E6867A	2017-08-01 17:25:00+03	179300.00
E68736	2017-07-05 04:46:00+03	21800.00
E6878B	2017-07-03 14:25:00+03	6800.00
E687C6	2017-07-24 17:45:00+03	40000.00
E688B4	2017-08-12 09:16:00+03	149500.00
E68A60	2017-08-02 07:44:00+03	73200.00
E68AC2	2017-08-14 02:58:00+03	93200.00
E68ADB	2017-08-05 16:41:00+03	50600.00
E68B22	2017-07-29 06:41:00+03	58600.00
E68B74	2017-08-11 19:34:00+03	119500.00
E68BE5	2017-07-29 10:40:00+03	101200.00
E68BF1	2017-07-03 14:59:00+03	37200.00
E68C5C	2017-07-05 07:57:00+03	58800.00
E68C74	2017-07-16 19:20:00+03	79900.00
E68C8C	2017-07-08 01:58:00+03	61800.00
E68C9C	2017-07-23 07:29:00+03	57500.00
E68CA1	2017-08-09 06:39:00+03	46400.00
E68D3B	2017-07-22 07:22:00+03	81300.00
E68D42	2017-07-22 16:26:00+03	49600.00
E68DB7	2017-07-30 14:42:00+03	58400.00
E68DE8	2017-07-28 21:29:00+03	102100.00
E68E3E	2017-07-24 02:10:00+03	70200.00
E68E55	2017-08-05 03:56:00+03	44000.00
E68EEB	2017-07-22 03:29:00+03	12600.00
E68F04	2017-07-18 16:57:00+03	145700.00
E6900E	2017-07-24 04:22:00+03	26700.00
E6919B	2017-07-30 19:01:00+03	28000.00
E691BB	2017-08-12 01:19:00+03	28000.00
E691C5	2017-07-26 06:42:00+03	26000.00
E691FF	2017-07-08 17:36:00+03	87800.00
E69227	2017-06-30 12:40:00+03	23400.00
E69261	2017-07-10 04:08:00+03	174400.00
E69393	2017-08-11 01:41:00+03	74200.00
E693AB	2017-08-13 14:02:00+03	39900.00
E693D4	2017-07-29 23:07:00+03	6700.00
E693ED	2017-07-27 15:43:00+03	31600.00
E69441	2017-07-08 16:01:00+03	137600.00
E6945D	2017-07-20 00:21:00+03	178800.00
E694E7	2017-07-17 16:56:00+03	9800.00
E69515	2017-07-06 03:26:00+03	33500.00
E695FE	2017-08-10 20:58:00+03	129000.00
E69609	2017-07-27 04:46:00+03	133200.00
E6960A	2017-07-25 08:34:00+03	24400.00
E69620	2017-07-05 01:25:00+03	92000.00
E6963E	2017-08-09 20:41:00+03	123200.00
E6965F	2017-07-24 03:12:00+03	84000.00
E696C3	2017-08-02 10:57:00+03	66600.00
E6970B	2017-07-10 04:37:00+03	201200.00
E6978E	2017-08-15 00:10:00+03	53400.00
E6979C	2017-07-06 08:12:00+03	119400.00
E697B9	2017-07-28 13:30:00+03	51900.00
E697C9	2017-07-04 09:45:00+03	126300.00
E6981B	2017-07-18 20:42:00+03	66600.00
E69844	2017-07-23 04:10:00+03	151000.00
E69868	2017-06-29 10:16:00+03	89800.00
E69915	2017-07-15 03:34:00+03	137600.00
E6994B	2017-07-12 00:22:00+03	133200.00
E6997E	2017-08-07 06:01:00+03	133200.00
E69997	2017-07-30 11:48:00+03	112000.00
E699D7	2017-07-27 01:17:00+03	37200.00
E699DB	2017-07-06 18:27:00+03	69000.00
E699EC	2017-08-02 05:41:00+03	46200.00
E69A05	2017-08-01 18:55:00+03	21800.00
E69A08	2017-07-16 05:57:00+03	64700.00
E69AD8	2017-07-09 11:39:00+03	173500.00
E69B2E	2017-07-15 15:28:00+03	73500.00
E69B48	2017-08-11 01:48:00+03	43000.00
E69B4F	2017-07-26 14:55:00+03	40800.00
E69B53	2017-07-24 08:15:00+03	187800.00
E69B7B	2017-08-01 03:06:00+03	6700.00
E69BF7	2017-07-29 04:25:00+03	35200.00
E69BFE	2017-07-16 23:40:00+03	38400.00
E69C0C	2017-07-20 05:14:00+03	168000.00
E69C34	2017-08-15 14:42:00+03	68800.00
E69C8C	2017-07-14 19:34:00+03	94700.00
E69CCF	2017-08-03 10:09:00+03	26400.00
E69CD5	2017-08-15 15:53:00+03	369000.00
E69CE0	2017-08-15 02:46:00+03	32700.00
E69D08	2017-08-04 08:06:00+03	43600.00
E69D92	2017-08-01 19:58:00+03	83500.00
E69D98	2017-07-18 14:02:00+03	54800.00
E69DA8	2017-07-06 15:32:00+03	189800.00
E69DC4	2017-08-12 12:42:00+03	32100.00
E69E13	2017-07-04 10:15:00+03	6000.00
E69EA7	2017-08-11 23:07:00+03	56000.00
E69F03	2017-07-27 23:26:00+03	167500.00
E69F10	2017-08-11 09:09:00+03	118600.00
E69F2B	2017-07-27 16:06:00+03	12600.00
E69F2C	2017-07-20 22:25:00+03	23200.00
E69F47	2017-07-01 09:33:00+03	136100.00
E69F48	2017-08-14 14:09:00+03	46200.00
E69F73	2017-07-22 23:28:00+03	246000.00
E69FD0	2017-06-30 14:04:00+03	51900.00
E69FE4	2017-07-08 04:51:00+03	112000.00
E6A0A9	2017-07-16 20:12:00+03	92700.00
E6A0B4	2017-07-07 03:05:00+03	58000.00
E6A0D3	2017-07-14 13:22:00+03	23200.00
E6A12E	2017-07-16 03:04:00+03	55900.00
E6A149	2017-07-27 20:53:00+03	73300.00
E6A152	2017-08-14 18:35:00+03	23600.00
E6A1F0	2017-07-21 07:14:00+03	18300.00
E6A220	2017-08-11 19:19:00+03	393800.00
E6A226	2017-07-31 09:27:00+03	393000.00
E6A23C	2017-07-30 00:40:00+03	29600.00
E6A2AA	2017-07-06 11:48:00+03	75600.00
E6A2D5	2017-07-31 11:48:00+03	26800.00
E6A322	2017-07-29 22:15:00+03	47400.00
E6A356	2017-08-03 14:11:00+03	47000.00
E6A36E	2017-08-07 11:07:00+03	14800.00
E6A3A7	2017-07-02 22:15:00+03	53800.00
E6A3AC	2017-07-01 15:35:00+03	60800.00
E6A3CC	2017-08-03 09:40:00+03	94000.00
E6A3DA	2017-07-29 03:47:00+03	25800.00
E6A3E4	2017-08-08 06:19:00+03	162300.00
E6A3F9	2017-07-06 06:16:00+03	55600.00
E6A42E	2017-07-06 23:58:00+03	29500.00
E6A43B	2017-08-01 20:01:00+03	52000.00
E6A464	2017-07-22 21:58:00+03	15800.00
E6A4FE	2017-06-30 09:37:00+03	56000.00
E6A531	2017-07-18 07:40:00+03	28800.00
E6A53B	2017-07-09 21:05:00+03	38400.00
E6A5BC	2017-08-03 04:02:00+03	158800.00
E6A5BE	2017-07-24 01:25:00+03	65900.00
E6A610	2017-08-14 20:08:00+03	30900.00
E6A676	2017-07-22 13:37:00+03	28800.00
E6A680	2017-07-21 09:07:00+03	24400.00
E6A6EC	2017-08-08 16:47:00+03	52800.00
E6A6EF	2017-07-20 11:15:00+03	56000.00
E6A78F	2017-07-17 18:59:00+03	68800.00
E6A7EF	2017-07-03 18:12:00+03	260300.00
E6A84C	2017-07-17 07:49:00+03	26000.00
E6A858	2017-07-10 21:41:00+03	116900.00
E6A881	2017-06-28 08:46:00+03	62600.00
E6A8B0	2017-07-13 12:34:00+03	84000.00
E6A8B6	2017-07-09 05:47:00+03	325500.00
E6A8EE	2017-08-10 18:50:00+03	139500.00
E6A903	2017-07-05 23:38:00+03	21400.00
E6A908	2017-07-30 23:12:00+03	115700.00
E6A97C	2017-08-05 01:32:00+03	277000.00
E6A988	2017-07-27 06:51:00+03	48800.00
E6A991	2017-08-13 01:32:00+03	28000.00
E6A9AB	2017-08-01 17:56:00+03	13600.00
E6A9EC	2017-07-25 17:56:00+03	55600.00
E6AA21	2017-07-30 22:36:00+03	109200.00
E6AA78	2017-07-27 19:01:00+03	76600.00
E6AA7F	2017-08-10 09:36:00+03	28800.00
E6AACC	2017-07-24 19:24:00+03	6300.00
E6AAEC	2017-08-09 03:11:00+03	170800.00
E6AB9B	2017-07-29 12:45:00+03	6700.00
E6ABB1	2017-08-08 20:53:00+03	45100.00
E6ABE8	2017-07-01 00:24:00+03	17800.00
E6AC23	2017-07-17 08:48:00+03	135600.00
E6AC49	2017-07-01 18:27:00+03	135600.00
E6AC6C	2017-07-28 06:57:00+03	14800.00
E6AC8F	2017-07-13 17:54:00+03	224000.00
E6ACA9	2017-08-13 11:32:00+03	152900.00
E6ACF8	2017-07-28 14:57:00+03	88100.00
E6AD04	2017-08-12 04:22:00+03	54000.00
E6AD8F	2017-06-28 15:14:00+03	22400.00
E6AE31	2017-07-07 19:30:00+03	419100.00
E6AE97	2017-08-08 01:07:00+03	92900.00
E6AEEE	2017-07-17 14:16:00+03	6000.00
E6AEF1	2017-07-05 08:57:00+03	111600.00
E6AF31	2017-08-15 02:17:00+03	52400.00
E6AF48	2017-07-16 19:48:00+03	137100.00
E6AF73	2017-07-22 21:43:00+03	68800.00
E6AF95	2017-07-29 05:40:00+03	57400.00
E6AFCC	2017-07-24 16:27:00+03	16400.00
E6AFEB	2017-06-30 23:53:00+03	63700.00
E6AFF8	2017-07-23 08:56:00+03	21400.00
E6B010	2017-08-10 06:55:00+03	19600.00
E6B035	2017-07-03 04:01:00+03	62600.00
E6B05E	2017-07-27 09:49:00+03	54000.00
E6B0D4	2017-07-20 10:19:00+03	67100.00
E6B103	2017-07-05 10:11:00+03	62600.00
E6B105	2017-07-27 17:39:00+03	27200.00
E6B1FE	2017-07-05 00:33:00+03	94900.00
E6B204	2017-07-06 13:22:00+03	90800.00
E6B240	2017-07-16 07:49:00+03	49100.00
E6B2B2	2017-07-16 09:59:00+03	38400.00
E6B2BE	2017-06-23 02:31:00+03	44000.00
E6B328	2017-07-17 06:15:00+03	6700.00
E6B39F	2017-07-26 18:22:00+03	6000.00
E6B40C	2017-07-05 07:23:00+03	78300.00
E6B42A	2017-08-13 17:03:00+03	28800.00
E6B4B2	2017-07-24 23:05:00+03	49100.00
E6B4EF	2017-07-21 11:58:00+03	105200.00
E6B533	2017-07-06 10:39:00+03	411400.00
E6B53F	2017-07-28 12:17:00+03	80200.00
E6B543	2017-08-14 15:04:00+03	96400.00
E6B57E	2017-08-04 21:29:00+03	141600.00
E6B58F	2017-08-15 16:54:00+03	60900.00
E6B5B6	2017-07-25 12:35:00+03	57400.00
E6B5B8	2017-07-31 00:54:00+03	62000.00
E6B5E1	2017-07-27 14:43:00+03	98400.00
E6B600	2017-07-04 01:17:00+03	26000.00
E6B60B	2017-07-16 06:50:00+03	6300.00
E6B649	2017-07-28 18:01:00+03	31600.00
E6B664	2017-07-11 07:06:00+03	80000.00
E6B674	2017-07-26 17:18:00+03	101200.00
E6B67F	2017-08-10 11:57:00+03	227400.00
E6B72B	2017-07-13 15:14:00+03	289800.00
E6B736	2017-07-25 21:21:00+03	46200.00
E6B7D9	2017-07-19 08:08:00+03	50300.00
E6B7FB	2017-07-15 23:38:00+03	55800.00
E6B80C	2017-07-21 03:23:00+03	57500.00
E6B849	2017-07-28 15:20:00+03	167400.00
E6B894	2017-07-19 01:52:00+03	100600.00
E6B8ED	2017-07-31 15:32:00+03	13600.00
E6B8F9	2017-07-14 08:40:00+03	492000.00
E6B955	2017-06-29 18:59:00+03	248400.00
E6B97F	2017-08-07 05:23:00+03	76400.00
E6B9A0	2017-08-02 13:03:00+03	79700.00
E6B9BB	2017-07-22 05:24:00+03	60800.00
E6BA10	2017-07-25 02:30:00+03	26000.00
E6BA35	2017-07-09 18:06:00+03	14000.00
E6BA8B	2017-07-28 02:07:00+03	67600.00
E6BB0F	2017-07-25 15:02:00+03	36800.00
E6BC16	2017-08-10 13:59:00+03	95200.00
E6BC4F	2017-08-03 05:22:00+03	57400.00
E6BC72	2017-07-08 20:06:00+03	46200.00
E6BCC9	2017-08-13 08:42:00+03	29900.00
E6BCDB	2017-08-06 05:41:00+03	369000.00
E6BD4F	2017-08-14 05:53:00+03	66600.00
E6BD51	2017-08-01 08:21:00+03	393800.00
E6BDB9	2017-07-02 15:29:00+03	55800.00
E6BDC0	2017-08-11 11:53:00+03	48500.00
E6BDE6	2017-08-05 03:21:00+03	47400.00
E6BDED	2017-06-29 09:37:00+03	132800.00
E6BE0A	2017-08-15 11:07:00+03	55800.00
E6BE66	2017-07-13 01:36:00+03	92800.00
E6BEC8	2017-07-06 13:42:00+03	16400.00
E6BF0C	2017-07-21 21:55:00+03	96800.00
E6BF16	2017-08-04 05:33:00+03	48900.00
E6BF36	2017-07-30 11:47:00+03	20800.00
E6BF82	2017-07-04 22:26:00+03	22400.00
E6BF8A	2017-07-07 21:02:00+03	27200.00
E6BFEA	2017-07-18 08:47:00+03	36900.00
E6C038	2017-08-05 21:29:00+03	31700.00
E6C03D	2017-07-15 12:06:00+03	60700.00
E6C052	2017-07-16 21:08:00+03	46200.00
E6C08E	2017-07-07 15:15:00+03	68400.00
E6C0D0	2017-07-06 04:04:00+03	28800.00
E6C136	2017-07-30 08:19:00+03	269100.00
E6C191	2017-07-20 07:48:00+03	7400.00
E6C1CA	2017-07-08 04:48:00+03	17800.00
E6C220	2017-07-23 09:35:00+03	119600.00
E6C2A2	2017-08-02 13:41:00+03	85600.00
E6C2D2	2017-08-15 13:07:00+03	55100.00
E6C38A	2017-07-20 00:45:00+03	111700.00
E6C39D	2017-07-09 04:03:00+03	44500.00
E6C3A8	2017-07-27 22:53:00+03	26700.00
E6C448	2017-08-08 00:17:00+03	132800.00
E6C4AA	2017-07-13 06:22:00+03	106400.00
E6C51E	2017-07-28 09:53:00+03	78300.00
E6C58A	2017-08-01 16:30:00+03	369000.00
E6C5EA	2017-07-30 19:26:00+03	31400.00
E6C63A	2017-07-21 16:28:00+03	90400.00
E6C64C	2017-08-01 09:39:00+03	136400.00
E6C6CF	2017-08-15 13:48:00+03	8200.00
E6C6F4	2017-07-28 18:23:00+03	27900.00
E6C6FD	2017-08-01 02:07:00+03	68000.00
E6C715	2017-08-07 08:20:00+03	85000.00
E6C758	2017-07-29 22:39:00+03	124200.00
E6C7A1	2017-07-25 15:42:00+03	30400.00
E6C7A6	2017-08-03 11:21:00+03	406700.00
E6C7E4	2017-08-11 20:35:00+03	28800.00
E6C7F4	2017-07-28 18:01:00+03	35200.00
E6C7F7	2017-08-14 02:31:00+03	130400.00
E6C843	2017-07-02 06:56:00+03	90000.00
E6C8BD	2017-07-06 19:04:00+03	48800.00
E6C925	2017-07-01 03:57:00+03	40100.00
E6C943	2017-07-13 00:44:00+03	63700.00
E6C970	2017-07-15 23:44:00+03	23200.00
E6C9D8	2017-08-14 02:58:00+03	120800.00
E6CA0F	2017-07-24 06:13:00+03	27800.00
E6CA20	2017-08-09 19:22:00+03	25400.00
E6CAF0	2017-07-06 04:23:00+03	168700.00
E6CB1B	2017-07-18 03:44:00+03	46200.00
E6CB6D	2017-08-03 10:23:00+03	62700.00
E6CBC9	2017-06-30 13:22:00+03	84000.00
E6CC15	2017-08-05 04:01:00+03	120000.00
E6CC2D	2017-08-06 01:53:00+03	44600.00
E6CC38	2017-07-25 11:59:00+03	76600.00
E6CC82	2017-08-09 20:04:00+03	133100.00
E6CC8F	2017-07-16 07:28:00+03	48800.00
E6CCAF	2017-07-13 20:26:00+03	199600.00
E6CCB9	2017-07-29 13:33:00+03	114700.00
E6CCBA	2017-07-05 01:00:00+03	58900.00
E6CCD3	2017-08-14 11:24:00+03	53100.00
E6CCF5	2017-07-06 09:03:00+03	172100.00
E6CCFE	2017-08-04 10:07:00+03	119500.00
E6CD0F	2017-07-30 12:50:00+03	48500.00
E6CD35	2017-07-16 00:56:00+03	31600.00
E6CD52	2017-08-13 19:36:00+03	168000.00
E6CDB6	2017-08-09 20:27:00+03	47500.00
E6CDDB	2017-07-24 18:59:00+03	185800.00
E6CE24	2017-07-27 16:01:00+03	28800.00
E6CEF0	2017-07-29 13:50:00+03	10600.00
E6CEF8	2017-07-21 06:04:00+03	44000.00
E6CF02	2017-07-31 22:00:00+03	6000.00
E6CF0A	2017-06-30 09:28:00+03	23200.00
E6CF46	2017-08-05 23:00:00+03	31100.00
E6CF8E	2017-08-02 11:23:00+03	6000.00
E6CFA2	2017-08-15 14:21:00+03	6000.00
E6CFAC	2017-07-03 23:23:00+03	4000.00
E6CFC0	2017-06-29 02:29:00+03	194900.00
E6CFCD	2017-07-22 20:24:00+03	72800.00
E6D00A	2017-07-19 19:54:00+03	98200.00
E6D017	2017-07-19 11:18:00+03	23600.00
E6D0F7	2017-07-01 19:41:00+03	112000.00
E6D10B	2017-08-11 04:39:00+03	123000.00
E6D1D9	2017-07-02 12:49:00+03	56000.00
E6D1F7	2017-07-16 05:40:00+03	24200.00
E6D220	2017-07-03 10:05:00+03	196500.00
E6D2F2	2017-07-16 05:40:00+03	51600.00
E6D2F6	2017-08-11 21:38:00+03	28000.00
E6D306	2017-08-01 01:33:00+03	44600.00
E6D348	2017-08-01 21:33:00+03	46300.00
E6D402	2017-07-16 11:39:00+03	16000.00
E6D47B	2017-07-23 13:57:00+03	16400.00
E6D4AA	2017-07-07 20:24:00+03	59300.00
E6D4E0	2017-07-27 12:00:00+03	32800.00
E6D501	2017-07-05 07:55:00+03	134400.00
E6D50C	2017-08-07 22:59:00+03	105200.00
E6D525	2017-07-18 18:23:00+03	6900.00
E6D562	2017-08-01 10:48:00+03	48400.00
E6D581	2017-08-01 04:02:00+03	57400.00
E6D5AA	2017-07-23 03:47:00+03	47900.00
E6D5FD	2017-08-08 03:43:00+03	67200.00
E6D638	2017-08-08 19:26:00+03	40400.00
E6D645	2017-08-07 08:31:00+03	116700.00
E6D6B4	2017-07-04 20:10:00+03	75800.00
E6D6BF	2017-08-14 11:04:00+03	54800.00
E6D724	2017-08-12 10:49:00+03	74800.00
E6D747	2017-07-18 12:01:00+03	257500.00
E6D81C	2017-07-22 08:04:00+03	133800.00
E6D85A	2017-08-10 13:04:00+03	51900.00
E6D866	2017-08-12 10:54:00+03	52900.00
E6D875	2017-07-25 10:59:00+03	43200.00
E6D8D7	2017-08-12 06:07:00+03	63700.00
E6D8F1	2017-08-10 20:00:00+03	31100.00
E6D913	2017-07-13 11:53:00+03	36200.00
E6D938	2017-07-08 22:17:00+03	111600.00
E6D9DF	2017-07-19 23:35:00+03	192700.00
E6D9FB	2017-07-23 18:15:00+03	68800.00
E6DAC0	2017-07-04 20:42:00+03	55800.00
E6DAC5	2017-08-12 10:38:00+03	266400.00
E6DACD	2017-07-03 14:01:00+03	394800.00
E6DAF1	2017-06-30 09:02:00+03	26100.00
E6DB42	2017-07-23 16:04:00+03	34100.00
E6DC19	2017-07-27 03:16:00+03	52600.00
E6DCF7	2017-07-25 20:22:00+03	90800.00
E6DD1D	2017-08-03 14:44:00+03	129700.00
E6DDB2	2017-07-12 03:35:00+03	28400.00
E6DE1E	2017-08-12 21:37:00+03	55500.00
E6DE2D	2017-08-04 04:00:00+03	201600.00
E6DE3C	2017-08-03 05:07:00+03	28000.00
E6DE8B	2017-07-06 01:28:00+03	36200.00
E6DEA4	2017-08-12 01:41:00+03	10800.00
E6DEAF	2017-07-07 07:23:00+03	74000.00
E6DEBD	2017-08-05 16:52:00+03	38000.00
E6DEE2	2017-08-12 13:22:00+03	38800.00
E6DEE4	2017-08-10 15:01:00+03	50400.00
E6DF1F	2017-07-21 18:42:00+03	295400.00
E6DF65	2017-07-28 05:34:00+03	49200.00
E6E013	2017-07-06 19:47:00+03	56000.00
E6E026	2017-07-12 07:45:00+03	51900.00
E6E02E	2017-08-13 11:59:00+03	66600.00
E6E046	2017-08-15 15:38:00+03	344100.00
E6E093	2017-07-22 20:59:00+03	29800.00
E6E0B4	2017-07-07 14:29:00+03	19600.00
E6E0BF	2017-07-16 14:07:00+03	86800.00
E6E179	2017-08-11 03:41:00+03	55800.00
E6E19A	2017-07-13 06:45:00+03	56000.00
E6E1CD	2017-07-11 14:27:00+03	56600.00
E6E1EE	2017-08-10 03:29:00+03	112300.00
E6E24F	2017-07-10 06:25:00+03	62600.00
E6E26B	2017-07-18 11:59:00+03	18300.00
E6E273	2017-08-02 01:46:00+03	36200.00
E6E2F5	2017-07-17 06:46:00+03	46400.00
E6E2FC	2017-08-01 07:14:00+03	100600.00
E6E30A	2017-07-05 08:10:00+03	50000.00
E6E382	2017-07-17 21:28:00+03	39200.00
E6E483	2017-07-04 19:52:00+03	41400.00
E6E51E	2017-07-27 14:48:00+03	500100.00
E6E535	2017-08-08 06:59:00+03	141600.00
E6E5F8	2017-08-10 03:46:00+03	51600.00
E6E631	2017-08-02 16:29:00+03	23200.00
E6E6B8	2017-08-06 00:18:00+03	103900.00
E6E6CA	2017-08-06 20:24:00+03	22600.00
E6E6FA	2017-07-24 22:54:00+03	10600.00
E6E70A	2017-07-20 18:14:00+03	154100.00
E6E741	2017-07-04 14:30:00+03	12400.00
E6E772	2017-08-10 11:48:00+03	141600.00
E6E797	2017-07-18 06:59:00+03	94000.00
E6E79D	2017-07-23 05:12:00+03	17000.00
E6E824	2017-07-05 01:48:00+03	60400.00
E6E8EA	2017-07-20 15:44:00+03	39400.00
E6E901	2017-07-17 14:52:00+03	46000.00
E6E916	2017-08-14 23:22:00+03	28000.00
E6E98A	2017-07-08 13:59:00+03	26700.00
E6E998	2017-08-06 19:41:00+03	98600.00
E6EA1A	2017-07-17 10:15:00+03	56100.00
E6EA1C	2017-07-13 14:18:00+03	47500.00
E6EA38	2017-06-29 16:11:00+03	151200.00
E6EA43	2017-08-11 13:47:00+03	73300.00
E6EA56	2017-07-25 11:45:00+03	47000.00
E6EA69	2017-07-22 22:14:00+03	91700.00
E6EB10	2017-08-06 05:10:00+03	97800.00
E6EB94	2017-07-14 09:57:00+03	420500.00
E6EBC0	2017-07-25 06:40:00+03	40800.00
E6EC2F	2017-07-25 00:14:00+03	56600.00
E6ECAF	2017-08-11 18:21:00+03	123600.00
E6ED94	2017-08-14 07:50:00+03	6300.00
E6EDD9	2017-07-24 10:47:00+03	45100.00
E6EDE0	2017-07-31 09:12:00+03	28800.00
E6EE23	2017-07-18 04:27:00+03	64700.00
E6EE85	2017-07-19 19:24:00+03	179500.00
E6EE91	2017-07-24 20:25:00+03	17800.00
E6EE92	2017-08-14 17:05:00+03	39800.00
E6EEA6	2017-07-21 20:06:00+03	39700.00
E6EEB1	2017-07-21 22:58:00+03	102300.00
E6EEC3	2017-07-09 06:39:00+03	16400.00
E6EF12	2017-08-01 02:37:00+03	92800.00
E6EF1B	2017-08-14 06:06:00+03	6600.00
E6EF28	2017-07-26 13:53:00+03	20200.00
E6EF66	2017-07-31 18:38:00+03	73300.00
E6EF91	2017-08-12 00:18:00+03	28800.00
E6EFC6	2017-07-24 08:36:00+03	84000.00
E6EFF0	2017-07-18 02:54:00+03	135600.00
E6F01F	2017-07-26 08:31:00+03	24400.00
E6F050	2017-07-12 06:54:00+03	32800.00
E6F100	2017-07-17 06:40:00+03	93500.00
E6F103	2017-08-03 05:45:00+03	73900.00
E6F11B	2017-07-29 07:32:00+03	39500.00
E6F121	2017-08-07 14:39:00+03	325500.00
E6F12D	2017-07-06 17:32:00+03	46500.00
E6F1AC	2017-08-12 23:08:00+03	56000.00
E6F1B0	2017-07-04 15:11:00+03	142400.00
E6F226	2017-08-05 23:19:00+03	112000.00
E6F246	2017-07-12 17:12:00+03	57800.00
E6F2A8	2017-07-04 19:49:00+03	29800.00
E6F2B0	2017-06-28 05:26:00+03	139800.00
E6F314	2017-07-14 16:13:00+03	199300.00
E6F31E	2017-08-15 11:32:00+03	56600.00
E6F32F	2017-07-01 10:35:00+03	46400.00
E6F349	2017-06-28 18:23:00+03	49500.00
E6F375	2017-08-12 09:45:00+03	130200.00
E6F398	2017-07-25 20:10:00+03	92900.00
E6F447	2017-07-12 00:08:00+03	100600.00
E6F49A	2017-07-30 16:38:00+03	22100.00
E6F4B3	2017-07-13 16:55:00+03	21400.00
E6F4DB	2017-07-15 22:04:00+03	47200.00
E6F542	2017-08-10 17:09:00+03	46000.00
E6F5DF	2017-08-04 04:18:00+03	28000.00
E6F5E9	2017-07-08 05:36:00+03	36800.00
E6F65E	2017-08-14 01:15:00+03	54000.00
E6F6B3	2017-07-09 08:36:00+03	25100.00
E6F777	2017-07-25 23:27:00+03	52000.00
E6F84B	2017-07-18 23:53:00+03	6700.00
E6F85E	2017-07-16 17:45:00+03	25600.00
E6F8CA	2017-07-10 23:59:00+03	114800.00
E6F95E	2017-07-25 09:45:00+03	71200.00
E6F9CA	2017-08-14 02:00:00+03	6800.00
E6F9D5	2017-07-23 11:34:00+03	135400.00
E6F9D9	2017-06-28 13:38:00+03	46400.00
E6FA4E	2017-08-05 11:44:00+03	12600.00
E6FA53	2017-07-27 11:20:00+03	258400.00
E6FAB9	2017-07-19 16:15:00+03	22000.00
E6FB17	2017-07-31 10:38:00+03	89600.00
E6FB18	2017-07-03 10:24:00+03	31600.00
E6FBB1	2017-07-12 17:53:00+03	243700.00
E6FC14	2017-08-10 17:04:00+03	12000.00
E6FC38	2017-07-25 13:14:00+03	115800.00
E6FC6B	2017-07-03 16:44:00+03	26000.00
E6FC9B	2017-07-19 21:49:00+03	451900.00
E6FD20	2017-08-06 09:06:00+03	52900.00
E6FD28	2017-08-13 18:59:00+03	50600.00
E6FD2D	2017-08-03 00:01:00+03	46400.00
E6FD52	2017-07-19 19:53:00+03	272400.00
E6FDFB	2017-07-30 15:48:00+03	62600.00
E6FE14	2017-07-02 01:24:00+03	42600.00
E6FE50	2017-07-28 09:51:00+03	55800.00
E6FE8C	2017-08-12 02:29:00+03	37200.00
E6FE8E	2017-08-05 12:19:00+03	132800.00
E6FEB3	2017-07-31 19:53:00+03	81700.00
E6FEFD	2017-07-02 20:50:00+03	37200.00
E6FF13	2017-07-29 16:12:00+03	88600.00
E6FF2E	2017-07-20 05:01:00+03	119800.00
E6FF48	2017-08-06 21:50:00+03	46400.00
E6FF5A	2017-07-24 02:57:00+03	13400.00
E6FF5D	2017-08-03 08:09:00+03	16400.00
E6FFC4	2017-07-09 07:35:00+03	15000.00
E6FFD1	2017-08-13 08:46:00+03	58900.00
E6FFFE	2017-08-07 16:34:00+03	121300.00
E70004	2017-08-01 23:45:00+03	46900.00
E70015	2017-07-27 07:35:00+03	26000.00
E7008A	2017-08-04 16:26:00+03	64400.00
E700B3	2017-07-13 08:08:00+03	23400.00
E700E0	2017-07-18 16:34:00+03	28800.00
E70118	2017-07-27 02:35:00+03	58800.00
E701A5	2017-07-13 03:17:00+03	38500.00
E701AF	2017-07-12 01:14:00+03	46400.00
E701C4	2017-07-14 16:36:00+03	155600.00
E701D1	2017-07-18 21:20:00+03	265800.00
E70205	2017-07-25 13:41:00+03	54500.00
E70233	2017-07-08 07:57:00+03	38800.00
E70289	2017-07-19 18:58:00+03	86400.00
E70341	2017-08-04 23:15:00+03	26000.00
E70357	2017-08-13 22:23:00+03	70700.00
E70364	2017-07-07 13:00:00+03	46200.00
E7038E	2017-08-01 22:24:00+03	58400.00
E703A0	2017-08-01 23:14:00+03	31900.00
E703B6	2017-07-21 06:28:00+03	67200.00
E703D0	2017-07-07 02:14:00+03	30000.00
E703D8	2017-08-06 16:19:00+03	36600.00
E7041C	2017-07-09 16:26:00+03	23900.00
E70427	2017-08-15 07:43:00+03	56000.00
E70442	2017-08-08 17:01:00+03	393000.00
E70457	2017-07-19 06:31:00+03	44800.00
E7047F	2017-07-28 10:47:00+03	18300.00
E70485	2017-07-11 19:32:00+03	20400.00
E704A0	2017-07-07 01:08:00+03	67200.00
E704BB	2017-07-04 09:00:00+03	8400.00
E704D4	2017-08-03 08:22:00+03	125400.00
E70513	2017-08-12 08:39:00+03	198600.00
E7056D	2017-07-18 03:43:00+03	62900.00
E705C7	2017-08-14 20:51:00+03	13600.00
E70627	2017-08-12 21:22:00+03	49800.00
E70628	2017-07-31 07:27:00+03	111600.00
E70689	2017-08-13 17:50:00+03	43600.00
E7068B	2017-07-10 09:28:00+03	20400.00
E7069F	2017-07-28 01:34:00+03	56000.00
E706C5	2017-07-17 23:33:00+03	170800.00
E7071F	2017-07-13 18:14:00+03	34000.00
E7073B	2017-07-29 22:19:00+03	32700.00
E707C2	2017-08-15 00:07:00+03	12000.00
E70812	2017-07-14 17:43:00+03	67200.00
E70840	2017-07-03 19:45:00+03	95200.00
E708A3	2017-08-14 13:41:00+03	14800.00
E708C4	2017-08-02 17:56:00+03	41600.00
E708CF	2017-07-27 21:00:00+03	6700.00
E708D6	2017-07-03 13:31:00+03	159300.00
E708E0	2017-08-03 14:15:00+03	16400.00
E70938	2017-08-09 10:38:00+03	46300.00
E7096E	2017-07-14 20:05:00+03	133200.00
E70975	2017-08-02 18:07:00+03	135200.00
E709E9	2017-08-10 03:15:00+03	17800.00
E70A0D	2017-07-14 19:06:00+03	131100.00
E70A57	2017-07-26 15:11:00+03	49200.00
E70A58	2017-07-22 16:32:00+03	103800.00
E70AA6	2017-07-31 23:49:00+03	25600.00
E70AFB	2017-07-29 09:59:00+03	26700.00
E70B26	2017-08-13 08:46:00+03	6000.00
E70B46	2017-06-30 16:31:00+03	62800.00
E70B79	2017-07-17 18:16:00+03	144400.00
E70B8C	2017-07-08 11:23:00+03	8400.00
E70B90	2017-07-16 14:02:00+03	88600.00
E70BE1	2017-07-01 09:00:00+03	101800.00
E70BFA	2017-07-08 11:14:00+03	26000.00
E70C20	2017-07-02 17:52:00+03	26000.00
E70C51	2017-07-16 20:03:00+03	25100.00
E70CD9	2017-08-14 13:44:00+03	147200.00
E70DDF	2017-07-29 08:01:00+03	71900.00
E70E02	2017-07-08 01:57:00+03	23200.00
E70E79	2017-07-23 20:46:00+03	102300.00
E70E8A	2017-07-27 04:55:00+03	112000.00
E70F05	2017-07-30 04:53:00+03	397700.00
E70F3F	2017-08-15 13:08:00+03	29500.00
E71037	2017-07-30 08:12:00+03	131100.00
E71046	2017-08-03 00:45:00+03	58000.00
E710DE	2017-07-23 05:47:00+03	19600.00
E7113A	2017-07-14 15:16:00+03	92700.00
E7117F	2017-08-09 01:42:00+03	65600.00
E71183	2017-07-07 11:55:00+03	14400.00
E7119E	2017-07-27 08:50:00+03	13600.00
E711AF	2017-08-04 02:59:00+03	72400.00
E711DA	2017-07-28 19:03:00+03	39400.00
E7121B	2017-07-26 14:42:00+03	89200.00
E71310	2017-07-30 06:29:00+03	15900.00
E7137D	2017-08-14 03:07:00+03	129200.00
E713B9	2017-07-18 22:25:00+03	266400.00
E713C8	2017-07-22 12:29:00+03	282300.00
E713D5	2017-08-05 14:27:00+03	62600.00
E713E7	2017-07-06 18:09:00+03	30200.00
E713F2	2017-08-02 21:14:00+03	89200.00
E71446	2017-08-06 17:19:00+03	26200.00
E71455	2017-07-11 15:52:00+03	69400.00
E7145D	2017-08-02 02:35:00+03	44000.00
E714AD	2017-07-23 16:36:00+03	62600.00
E714CC	2017-07-06 18:03:00+03	49700.00
E71602	2017-07-30 03:39:00+03	89600.00
E7161F	2017-08-02 20:37:00+03	46000.00
E7162F	2017-07-27 13:37:00+03	51800.00
E71642	2017-07-19 05:15:00+03	14800.00
E71667	2017-08-15 00:47:00+03	19600.00
E7167E	2017-07-14 03:39:00+03	53600.00
E716E5	2017-07-18 03:03:00+03	28000.00
E71722	2017-08-10 11:15:00+03	49100.00
E7173E	2017-08-04 11:52:00+03	48800.00
E71760	2017-07-13 04:11:00+03	26000.00
E71798	2017-07-16 13:59:00+03	89000.00
E717A0	2017-06-28 02:19:00+03	56100.00
E717AF	2017-07-12 08:31:00+03	29500.00
E717DC	2017-07-30 22:34:00+03	339300.00
E71838	2017-07-07 00:58:00+03	54800.00
E71858	2017-07-28 08:48:00+03	31100.00
E7186F	2017-08-05 13:58:00+03	48800.00
E718D2	2017-07-28 07:13:00+03	137600.00
E71909	2017-07-09 11:24:00+03	89700.00
E7192B	2017-07-09 12:53:00+03	25200.00
E71966	2017-08-14 09:26:00+03	13600.00
E7199E	2017-07-28 22:31:00+03	56000.00
E719DC	2017-07-27 12:49:00+03	38600.00
E719EE	2017-07-21 03:39:00+03	14400.00
E719F6	2017-07-27 01:06:00+03	72300.00
E71A5C	2017-08-08 04:01:00+03	30000.00
E71A73	2017-07-01 09:51:00+03	125200.00
E71AAC	2017-07-19 05:53:00+03	54800.00
E71B94	2017-07-12 10:45:00+03	26000.00
E71BDC	2017-07-30 22:03:00+03	116100.00
E71BE4	2017-07-18 12:36:00+03	8200.00
E71BFE	2017-07-06 21:27:00+03	60400.00
E71C04	2017-07-21 16:58:00+03	89600.00
E71C84	2017-07-05 16:47:00+03	348800.00
E71CE1	2017-06-25 23:53:00+03	205800.00
E71D0D	2017-07-13 10:02:00+03	161200.00
E71D28	2017-07-02 12:13:00+03	172000.00
E71DC5	2017-08-11 00:21:00+03	271400.00
E71DE8	2017-08-13 20:48:00+03	452900.00
E71E11	2017-08-06 13:25:00+03	47100.00
E71EE9	2017-08-12 10:15:00+03	96900.00
E71FD6	2017-08-13 13:04:00+03	95200.00
E7200C	2017-08-11 05:20:00+03	111600.00
E720B0	2017-07-20 23:03:00+03	12200.00
E72137	2017-07-09 10:24:00+03	86400.00
E72148	2017-07-24 18:28:00+03	73600.00
E72150	2017-07-10 15:41:00+03	97800.00
E7215A	2017-07-12 17:47:00+03	139800.00
E72162	2017-07-31 22:48:00+03	57600.00
E721E0	2017-08-06 08:23:00+03	75300.00
E7220A	2017-07-18 07:33:00+03	58600.00
E7225F	2017-07-28 19:23:00+03	303500.00
E7232E	2017-08-03 02:12:00+03	56000.00
E72348	2017-07-01 13:55:00+03	24400.00
E72364	2017-08-06 08:39:00+03	114400.00
E72365	2017-08-08 18:48:00+03	69500.00
E72374	2017-07-21 17:21:00+03	55800.00
E72379	2017-07-12 21:02:00+03	99600.00
E7238E	2017-07-19 15:31:00+03	56000.00
E72423	2017-07-27 15:56:00+03	202600.00
E7245E	2017-07-25 00:25:00+03	201800.00
E72478	2017-08-08 05:19:00+03	30200.00
E72486	2017-07-14 06:35:00+03	106400.00
E7249A	2017-07-15 12:49:00+03	65500.00
E724B6	2017-08-04 22:22:00+03	54400.00
E724FF	2017-08-06 15:33:00+03	32200.00
E7254F	2017-07-15 07:32:00+03	75300.00
E7264E	2017-08-09 03:39:00+03	68800.00
E7266E	2017-06-29 03:42:00+03	14000.00
E726CB	2017-07-25 21:05:00+03	113600.00
E7272E	2017-07-14 14:57:00+03	32800.00
E72753	2017-07-30 09:28:00+03	58000.00
E72774	2017-07-14 16:20:00+03	81700.00
E7278E	2017-07-11 12:01:00+03	125900.00
E72879	2017-07-11 11:28:00+03	20000.00
E728A2	2017-07-15 07:18:00+03	136100.00
E72968	2017-07-17 21:47:00+03	168000.00
E72A00	2017-07-12 07:59:00+03	103900.00
E72A33	2017-08-10 17:15:00+03	28000.00
E72A7A	2017-08-06 05:21:00+03	24800.00
E72A82	2017-07-31 09:14:00+03	58400.00
E72A86	2017-08-13 10:32:00+03	112600.00
E72A89	2017-08-01 17:29:00+03	38400.00
E72A8E	2017-07-25 16:13:00+03	23600.00
E72AAF	2017-08-03 00:25:00+03	38400.00
E72ACE	2017-08-03 20:20:00+03	35200.00
E72B4E	2017-07-04 07:13:00+03	31600.00
E72B5F	2017-07-04 01:06:00+03	89600.00
E72B71	2017-07-30 08:28:00+03	56000.00
E72BD9	2017-08-08 00:18:00+03	79800.00
E72BFD	2017-07-24 11:47:00+03	396500.00
E72C3B	2017-07-30 12:33:00+03	50000.00
E72C70	2017-08-13 04:54:00+03	73600.00
E72CA7	2017-07-17 18:11:00+03	37900.00
E72CA8	2017-06-29 23:30:00+03	123000.00
E72CF9	2017-07-28 14:10:00+03	65900.00
E72D18	2017-07-06 15:13:00+03	234000.00
E72D74	2017-07-10 09:54:00+03	89700.00
E72D91	2017-07-15 14:29:00+03	24700.00
E72DB2	2017-08-13 09:21:00+03	37100.00
E72DFB	2017-07-12 06:40:00+03	57300.00
E72E04	2017-08-09 18:08:00+03	53400.00
E72E0E	2017-08-07 12:10:00+03	40800.00
E72E36	2017-08-14 02:39:00+03	26700.00
E72E88	2017-08-02 21:13:00+03	142000.00
E72EA2	2017-07-25 19:18:00+03	112000.00
E72EBA	2017-08-14 12:37:00+03	56900.00
E72F35	2017-07-08 05:04:00+03	122800.00
E72F3C	2017-07-31 18:11:00+03	12400.00
E72F3F	2017-07-16 12:29:00+03	398500.00
E72FA8	2017-07-13 15:15:00+03	23200.00
E72FC3	2017-07-18 03:47:00+03	42000.00
E73036	2017-08-10 14:30:00+03	46400.00
E730F9	2017-08-05 13:53:00+03	37900.00
E7311F	2017-07-26 17:21:00+03	38400.00
E7314B	2017-08-10 00:11:00+03	12600.00
E7317E	2017-07-04 20:54:00+03	69100.00
E7317F	2017-07-11 01:53:00+03	53500.00
E73244	2017-08-15 16:02:00+03	81700.00
E7325B	2017-07-08 09:54:00+03	42800.00
E73287	2017-07-21 15:32:00+03	6000.00
E732B0	2017-07-24 10:27:00+03	30200.00
E732C8	2017-08-07 02:29:00+03	39300.00
E732D1	2017-08-03 16:10:00+03	14000.00
E73399	2017-08-06 18:02:00+03	110500.00
E733A6	2017-08-08 18:08:00+03	56000.00
E7344F	2017-07-13 22:23:00+03	66600.00
E734F2	2017-07-01 12:11:00+03	6000.00
E73540	2017-07-01 20:19:00+03	18900.00
E73564	2017-08-04 00:17:00+03	57300.00
E735CF	2017-08-04 03:32:00+03	23600.00
E735F9	2017-07-25 12:21:00+03	81600.00
E7365D	2017-07-13 12:59:00+03	47500.00
E73667	2017-07-07 10:40:00+03	116000.00
E7366A	2017-07-08 13:03:00+03	147700.00
E73680	2017-07-03 22:31:00+03	65800.00
E7368B	2017-08-03 05:04:00+03	34000.00
E7370E	2017-07-29 03:49:00+03	79600.00
E73771	2017-07-15 12:03:00+03	29300.00
E73782	2017-07-05 04:54:00+03	33600.00
E737A4	2017-08-13 10:02:00+03	63200.00
E737DF	2017-08-05 02:10:00+03	48300.00
E73846	2017-07-11 16:01:00+03	36000.00
E73880	2017-07-30 02:34:00+03	93700.00
E7389C	2017-08-03 05:15:00+03	132800.00
E7389D	2017-08-05 22:52:00+03	24400.00
E738AE	2017-08-04 16:26:00+03	24400.00
E738B4	2017-07-21 17:52:00+03	44800.00
E738E2	2017-08-08 02:09:00+03	86300.00
E738F3	2017-07-17 02:43:00+03	62900.00
E7392F	2017-07-02 10:54:00+03	37900.00
E739CE	2017-07-18 05:12:00+03	44000.00
E739D9	2017-07-13 20:22:00+03	46400.00
E73AD2	2017-07-29 08:03:00+03	48800.00
E73B42	2017-08-12 16:46:00+03	78000.00
E73B5E	2017-08-02 20:54:00+03	28000.00
E73B7E	2017-07-31 19:00:00+03	59800.00
E73BB6	2017-08-03 12:22:00+03	393000.00
E73BC1	2017-08-02 08:59:00+03	52600.00
E73BF4	2017-08-06 05:21:00+03	13400.00
E73C4A	2017-07-20 06:22:00+03	38600.00
E73C81	2017-06-30 08:18:00+03	119500.00
E73CA2	2017-07-08 16:00:00+03	43200.00
E73D94	2017-08-13 04:35:00+03	81600.00
E73D98	2017-07-12 14:15:00+03	35200.00
E73DD5	2017-07-04 10:36:00+03	31400.00
E73DD7	2017-08-11 08:20:00+03	95300.00
E73E07	2017-08-14 09:59:00+03	14000.00
E73E75	2017-08-06 21:47:00+03	134800.00
E73EB7	2017-07-07 07:03:00+03	89600.00
E73EB8	2017-08-11 23:01:00+03	19100.00
E73F15	2017-08-14 05:19:00+03	98200.00
E73F56	2017-08-13 05:30:00+03	26700.00
E73F5A	2017-07-31 08:01:00+03	53300.00
E73FF0	2017-08-04 10:58:00+03	269000.00
E74098	2017-06-26 23:55:00+03	323800.00
E7411A	2017-07-27 10:44:00+03	195800.00
E7415C	2017-08-01 17:07:00+03	58700.00
E74173	2017-07-05 12:45:00+03	32700.00
E7418C	2017-07-17 00:34:00+03	8400.00
E74195	2017-08-12 21:58:00+03	66000.00
E7419F	2017-08-09 19:43:00+03	92600.00
E74289	2017-08-15 09:03:00+03	25600.00
E742BE	2017-07-19 20:02:00+03	38800.00
E74358	2017-08-09 16:50:00+03	163500.00
E74377	2017-07-19 02:31:00+03	35800.00
E743A9	2017-08-12 22:49:00+03	234600.00
E7441D	2017-08-01 19:10:00+03	73600.00
E7444F	2017-08-02 06:04:00+03	89600.00
E74495	2017-07-13 09:34:00+03	73300.00
E74499	2017-08-11 16:32:00+03	389000.00
E744B5	2017-07-17 23:09:00+03	140200.00
E745AF	2017-08-06 15:58:00+03	94400.00
E74600	2017-07-09 02:36:00+03	43400.00
E74651	2017-08-02 22:44:00+03	172600.00
E74670	2017-07-19 08:43:00+03	27300.00
E7468E	2017-08-09 01:20:00+03	63000.00
E7469E	2017-07-04 18:09:00+03	131600.00
E746F3	2017-08-03 21:13:00+03	52000.00
E74769	2017-07-26 21:33:00+03	48500.00
E7477F	2017-07-08 01:39:00+03	48800.00
E747DE	2017-07-01 18:55:00+03	26700.00
E74802	2017-07-31 13:03:00+03	46300.00
E7480C	2017-07-15 02:10:00+03	34100.00
E7485A	2017-07-09 05:26:00+03	92900.00
E74872	2017-07-05 06:06:00+03	38200.00
E748A5	2017-07-19 06:24:00+03	92900.00
E748C7	2017-07-01 11:39:00+03	68800.00
E74A9D	2017-07-11 19:02:00+03	22000.00
E74AA1	2017-07-20 23:37:00+03	45200.00
E74AC7	2017-08-13 19:05:00+03	381800.00
E74AC9	2017-07-25 05:04:00+03	122400.00
E74B02	2017-08-03 11:24:00+03	24000.00
E74B70	2017-07-22 11:15:00+03	55800.00
E74BA2	2017-07-14 10:53:00+03	42700.00
E74BC7	2017-07-10 06:36:00+03	28000.00
E74CBC	2017-07-20 16:31:00+03	38500.00
E74CF6	2017-08-13 02:32:00+03	142200.00
E74D5D	2017-07-25 05:52:00+03	66000.00
E74D7F	2017-07-03 02:34:00+03	112000.00
E74E03	2017-08-10 13:12:00+03	123000.00
E74E62	2017-08-08 02:45:00+03	38400.00
E74E9A	2017-08-02 13:00:00+03	26600.00
E74EF5	2017-07-02 02:31:00+03	23600.00
E74F1A	2017-07-08 12:47:00+03	87800.00
E74F35	2017-07-21 07:05:00+03	52400.00
E74F3E	2017-07-07 20:21:00+03	26800.00
E74F76	2017-08-05 04:05:00+03	42900.00
E74FB1	2017-07-05 19:16:00+03	123000.00
E74FE6	2017-06-29 18:47:00+03	23200.00
E7505F	2017-07-01 21:59:00+03	77800.00
E7506A	2017-06-29 07:23:00+03	234700.00
E750C5	2017-08-11 18:30:00+03	55800.00
E75112	2017-07-17 12:03:00+03	67200.00
E7511E	2017-07-21 08:35:00+03	483500.00
E751C5	2017-07-05 05:51:00+03	121400.00
E751DE	2017-07-22 18:57:00+03	40800.00
E751E6	2017-08-06 09:18:00+03	24400.00
E75211	2017-08-14 22:23:00+03	38600.00
E75228	2017-08-10 02:12:00+03	92400.00
E7523F	2017-07-09 11:28:00+03	103000.00
E7525D	2017-07-31 23:57:00+03	25400.00
E752B5	2017-07-23 08:45:00+03	28800.00
E752E4	2017-08-02 13:34:00+03	201200.00
E752E6	2017-08-12 04:04:00+03	95000.00
E752F5	2017-08-12 07:59:00+03	97500.00
E75302	2017-07-09 06:36:00+03	68100.00
E7537C	2017-08-14 18:59:00+03	75600.00
E75390	2017-07-29 16:13:00+03	38600.00
E75414	2017-08-10 22:48:00+03	108900.00
E75422	2017-07-03 02:55:00+03	46400.00
E75442	2017-08-04 03:01:00+03	16400.00
E75455	2017-07-15 13:04:00+03	66000.00
E7545E	2017-08-04 08:45:00+03	48500.00
E7550C	2017-07-22 06:17:00+03	55800.00
E75532	2017-07-22 09:16:00+03	124000.00
E755FB	2017-07-23 09:49:00+03	32800.00
E7562A	2017-08-05 09:46:00+03	51000.00
E75662	2017-07-05 13:41:00+03	89200.00
E75685	2017-08-08 07:47:00+03	47200.00
E756B5	2017-07-19 22:17:00+03	114800.00
E756B9	2017-07-21 15:41:00+03	38400.00
E756BA	2017-08-01 12:49:00+03	24400.00
E756D0	2017-07-30 23:04:00+03	207100.00
E75843	2017-07-31 15:27:00+03	160200.00
E75895	2017-08-14 15:47:00+03	88100.00
E758E5	2017-07-28 12:19:00+03	61800.00
E758F3	2017-07-27 22:14:00+03	134800.00
E759C9	2017-07-25 18:08:00+03	25400.00
E759D1	2017-07-20 07:09:00+03	35600.00
E75A2C	2017-08-01 01:49:00+03	20200.00
E75A4C	2017-08-14 09:48:00+03	79600.00
E75A77	2017-07-18 18:51:00+03	86800.00
E75A7F	2017-07-24 17:49:00+03	28000.00
E75AAB	2017-07-30 01:34:00+03	45300.00
E75AB9	2017-08-11 11:11:00+03	62800.00
E75B11	2017-08-10 00:40:00+03	84000.00
E75B43	2017-08-05 06:33:00+03	402400.00
E75B9D	2017-07-25 17:58:00+03	532800.00
E75BAF	2017-07-12 16:38:00+03	37900.00
E75BBC	2017-07-30 10:47:00+03	52400.00
E75C13	2017-07-13 17:43:00+03	201200.00
E75D34	2017-07-16 22:36:00+03	58600.00
E75DBE	2017-07-25 18:11:00+03	177500.00
E75E3C	2017-07-18 01:11:00+03	28300.00
E75E89	2017-07-06 03:54:00+03	38600.00
E75EF5	2017-07-25 19:29:00+03	86600.00
E75F10	2017-07-13 00:41:00+03	9000.00
E75F5A	2017-07-28 07:14:00+03	75300.00
E75FB7	2017-07-21 12:24:00+03	32700.00
E75FC9	2017-08-07 22:10:00+03	369000.00
E7604C	2017-07-05 18:44:00+03	13400.00
E7609A	2017-08-05 12:44:00+03	272900.00
E76186	2017-07-02 00:10:00+03	73200.00
E76187	2017-07-03 03:42:00+03	289800.00
E761CF	2017-07-31 14:29:00+03	25900.00
E76215	2017-08-12 14:53:00+03	30200.00
E76257	2017-07-25 12:49:00+03	29800.00
E7626A	2017-07-09 01:45:00+03	106400.00
E76286	2017-08-03 21:25:00+03	112600.00
E762BE	2017-08-13 00:30:00+03	81200.00
E76336	2017-07-11 22:44:00+03	56000.00
E7633A	2017-08-01 18:29:00+03	14000.00
E7634D	2017-07-04 05:38:00+03	57500.00
E76368	2017-08-14 12:24:00+03	55800.00
E763D5	2017-07-18 14:26:00+03	26000.00
E76497	2017-08-01 22:42:00+03	12000.00
E764BD	2017-07-02 18:28:00+03	16000.00
E764E6	2017-07-20 05:21:00+03	21800.00
E76515	2017-07-13 16:27:00+03	23600.00
E7652C	2017-07-01 22:42:00+03	123000.00
E7653C	2017-07-17 23:02:00+03	38400.00
E7657A	2017-07-03 18:55:00+03	24600.00
E76580	2017-07-31 06:04:00+03	36800.00
E76585	2017-08-02 06:10:00+03	26500.00
E765FB	2017-07-03 15:16:00+03	79700.00
E766E0	2017-08-04 06:42:00+03	40800.00
E7674E	2017-08-12 22:12:00+03	81500.00
E7675E	2017-07-22 10:27:00+03	123000.00
E7676B	2017-07-15 19:14:00+03	81600.00
E76792	2017-07-12 06:28:00+03	66600.00
E7679C	2017-07-10 01:05:00+03	99200.00
E767CE	2017-07-27 08:08:00+03	41400.00
E7685E	2017-07-08 07:06:00+03	55800.00
E76896	2017-07-15 13:12:00+03	99300.00
E768A4	2017-07-31 03:12:00+03	174400.00
E768D3	2017-08-09 21:04:00+03	164400.00
E768FA	2017-08-11 16:18:00+03	112000.00
E76959	2017-08-08 04:17:00+03	14800.00
E76A52	2017-07-17 07:17:00+03	137300.00
E76AA0	2017-07-27 09:04:00+03	115900.00
E76AAD	2017-08-09 14:36:00+03	111600.00
E76BFC	2017-07-16 09:09:00+03	78600.00
E76DE7	2017-07-21 11:49:00+03	40800.00
E76DFD	2017-07-20 03:23:00+03	28000.00
E76DFE	2017-08-14 00:59:00+03	96400.00
E76E2C	2017-08-07 15:13:00+03	25100.00
E76E2D	2017-08-10 20:42:00+03	133200.00
E76E67	2017-07-25 19:16:00+03	6900.00
E76E6F	2017-07-18 19:31:00+03	132800.00
E76E81	2017-08-12 11:12:00+03	43200.00
E76E91	2017-07-22 03:06:00+03	369000.00
E76F36	2017-07-13 03:18:00+03	201200.00
E76F40	2017-07-11 05:58:00+03	27600.00
E76FF5	2017-07-11 03:59:00+03	38400.00
E77008	2017-07-09 08:51:00+03	16800.00
E7706D	2017-07-06 20:49:00+03	67600.00
E7706E	2017-07-28 21:19:00+03	39800.00
E77080	2017-08-07 20:19:00+03	47900.00
E7709F	2017-07-17 14:39:00+03	171000.00
E770AF	2017-08-10 10:23:00+03	12600.00
E770B5	2017-07-16 13:02:00+03	7300.00
E7710F	2017-07-07 22:37:00+03	55800.00
E77173	2017-08-04 23:15:00+03	55600.00
E77182	2017-08-09 16:17:00+03	48400.00
E771EC	2017-07-30 11:27:00+03	47500.00
E7726B	2017-08-10 19:24:00+03	93900.00
E7726F	2017-08-04 02:10:00+03	66600.00
E772B3	2017-08-07 11:48:00+03	31900.00
E772F4	2017-08-12 16:11:00+03	72200.00
E77309	2017-07-31 04:13:00+03	39300.00
E77357	2017-07-07 22:49:00+03	133100.00
E77421	2017-07-14 23:55:00+03	12200.00
E77452	2017-08-03 23:14:00+03	37400.00
E774B9	2017-07-12 14:15:00+03	75300.00
E774C5	2017-08-09 23:18:00+03	53300.00
E774D7	2017-07-12 17:14:00+03	44100.00
E7752C	2017-07-06 11:00:00+03	30000.00
E7757F	2017-07-27 00:30:00+03	20500.00
E77580	2017-07-14 10:27:00+03	58600.00
E77598	2017-07-05 02:10:00+03	176300.00
E775BF	2017-07-30 07:01:00+03	123900.00
E77623	2017-08-07 08:12:00+03	133000.00
E77624	2017-08-14 19:16:00+03	6800.00
E77666	2017-07-23 17:29:00+03	303900.00
E7766C	2017-07-03 22:27:00+03	15100.00
E776B2	2017-07-26 11:14:00+03	92800.00
E776CB	2017-08-05 00:11:00+03	16800.00
E776E9	2017-07-31 14:23:00+03	122700.00
E776F1	2017-07-15 04:49:00+03	33300.00
E777A2	2017-07-25 02:19:00+03	22400.00
E77811	2017-08-13 15:13:00+03	168000.00
E77835	2017-07-29 04:24:00+03	34800.00
E778BE	2017-07-08 07:31:00+03	14400.00
E778C3	2017-07-23 08:42:00+03	112000.00
E778C5	2017-08-07 17:22:00+03	34400.00
E779A4	2017-08-14 23:31:00+03	25100.00
E77A46	2017-07-29 19:21:00+03	67200.00
E77A72	2017-07-04 02:02:00+03	46000.00
E77AB5	2017-08-13 22:11:00+03	91900.00
E77B0A	2017-07-17 00:38:00+03	80300.00
E77B0B	2017-07-12 06:07:00+03	166500.00
E77B2A	2017-07-25 05:18:00+03	148300.00
E77B7D	2017-08-11 14:36:00+03	12600.00
E77BC2	2017-07-05 05:29:00+03	56000.00
E77BE9	2017-07-25 05:39:00+03	246000.00
E77C42	2017-08-01 23:39:00+03	505300.00
E77C53	2017-08-11 12:08:00+03	131100.00
E77C94	2017-07-09 20:20:00+03	56600.00
E77CB0	2017-07-12 01:59:00+03	6700.00
E77CB3	2017-07-26 07:18:00+03	19100.00
E77CE8	2017-07-04 05:21:00+03	48800.00
E77CFD	2017-07-19 12:15:00+03	75300.00
E77D33	2017-08-15 01:39:00+03	28000.00
E77D39	2017-07-18 05:07:00+03	31600.00
E77D49	2017-07-11 18:44:00+03	23600.00
E77D4C	2017-07-26 08:21:00+03	32500.00
E77E03	2017-07-26 22:01:00+03	22000.00
E77F26	2017-07-04 09:00:00+03	66600.00
E77FB4	2017-07-10 20:10:00+03	44800.00
E78070	2017-07-20 11:40:00+03	272300.00
E78080	2017-08-09 15:08:00+03	46400.00
E780A3	2017-07-06 05:19:00+03	22600.00
E780C1	2017-07-18 05:34:00+03	43000.00
E78118	2017-07-02 08:57:00+03	62700.00
E78123	2017-07-11 02:54:00+03	12600.00
E78130	2017-08-10 10:09:00+03	28800.00
E7816E	2017-08-09 16:30:00+03	133200.00
E781E0	2017-08-01 14:54:00+03	71900.00
E781E7	2017-07-21 20:49:00+03	115700.00
E7826E	2017-08-07 18:28:00+03	80500.00
E78278	2017-07-07 21:50:00+03	68800.00
E7827E	2017-08-15 02:38:00+03	78200.00
E78293	2017-08-05 20:56:00+03	6800.00
E782FB	2017-08-04 13:28:00+03	13200.00
E782FF	2017-07-11 22:44:00+03	35600.00
E7831E	2017-07-22 01:27:00+03	44700.00
E783A4	2017-07-27 06:46:00+03	258400.00
E783B6	2017-07-15 04:55:00+03	77200.00
E78445	2017-07-15 05:38:00+03	43100.00
E78459	2017-06-30 15:09:00+03	40800.00
E7847F	2017-08-03 15:11:00+03	19600.00
E78484	2017-07-01 18:33:00+03	110400.00
E784C2	2017-08-02 06:02:00+03	69800.00
E784FA	2017-07-14 17:36:00+03	67200.00
E7852B	2017-07-25 23:43:00+03	6300.00
E7857C	2017-07-26 03:45:00+03	147800.00
E785AF	2017-08-14 09:09:00+03	23200.00
E785F5	2017-08-04 03:56:00+03	32700.00
E78605	2017-07-16 18:27:00+03	6700.00
E78638	2017-07-21 00:48:00+03	47200.00
E78648	2017-08-10 14:37:00+03	132800.00
E7865B	2017-06-30 07:26:00+03	51400.00
E786AF	2017-08-03 02:35:00+03	59600.00
E786E0	2017-07-06 00:41:00+03	57200.00
E78720	2017-07-08 20:36:00+03	123400.00
E7872B	2017-07-30 00:31:00+03	41800.00
E78755	2017-08-03 04:24:00+03	15400.00
E78796	2017-07-07 08:28:00+03	37900.00
E787BD	2017-07-28 07:54:00+03	112100.00
E7885D	2017-08-07 14:09:00+03	112000.00
E78901	2017-07-13 05:27:00+03	40400.00
E78912	2017-06-30 08:39:00+03	28000.00
E78913	2017-07-08 18:46:00+03	92400.00
E7891D	2017-07-07 20:09:00+03	96800.00
E7892F	2017-07-01 14:19:00+03	123700.00
E78935	2017-07-01 21:47:00+03	61800.00
E78968	2017-06-28 10:44:00+03	67600.00
E789E9	2017-08-05 04:37:00+03	154500.00
E78A7F	2017-08-15 02:27:00+03	59300.00
E78A86	2017-06-30 20:24:00+03	56600.00
E78A9E	2017-07-09 08:03:00+03	32200.00
E78B70	2017-07-10 14:50:00+03	246000.00
E78BA0	2017-07-21 23:11:00+03	56600.00
E78BA2	2017-07-21 14:32:00+03	8400.00
E78C11	2017-08-08 21:45:00+03	61800.00
E78C52	2017-07-21 12:17:00+03	89600.00
E78CA4	2017-07-18 11:47:00+03	6700.00
E78CB3	2017-08-02 23:27:00+03	47000.00
E78CD4	2017-07-04 17:20:00+03	266400.00
E78CFC	2017-07-20 08:20:00+03	316400.00
E78D32	2017-07-08 22:24:00+03	31400.00
E78D69	2017-08-09 17:05:00+03	61800.00
E78DB1	2017-07-29 09:20:00+03	45800.00
E78DB7	2017-08-08 16:04:00+03	25800.00
E78DBF	2017-07-20 14:44:00+03	28700.00
E78E29	2017-07-20 15:07:00+03	300300.00
E78E52	2017-07-04 03:53:00+03	122000.00
E78E9A	2017-07-15 11:25:00+03	23600.00
E78F81	2017-07-07 19:10:00+03	36900.00
E78FD5	2017-08-14 04:36:00+03	43900.00
E79076	2017-08-06 00:18:00+03	294400.00
E790BC	2017-08-14 09:11:00+03	12600.00
E79103	2017-07-05 13:46:00+03	398300.00
E7910A	2017-08-12 07:38:00+03	24400.00
E7916F	2017-08-12 01:56:00+03	27200.00
E79179	2017-07-05 16:24:00+03	93500.00
E791EE	2017-08-06 17:06:00+03	47200.00
E79277	2017-07-12 19:27:00+03	136200.00
E79292	2017-07-13 09:27:00+03	185800.00
E79297	2017-07-06 07:31:00+03	59200.00
E792E7	2017-08-10 16:17:00+03	43100.00
E79305	2017-07-15 14:07:00+03	44600.00
E79364	2017-07-10 02:19:00+03	16400.00
E79380	2017-07-07 04:39:00+03	90800.00
E793EA	2017-08-06 08:01:00+03	46400.00
E793EC	2017-07-29 02:59:00+03	134700.00
E79413	2017-07-29 23:05:00+03	24000.00
E7943B	2017-06-30 21:54:00+03	12800.00
E79468	2017-07-18 17:10:00+03	8200.00
E79489	2017-08-07 02:22:00+03	155600.00
E79492	2017-08-05 09:55:00+03	58700.00
E794AD	2017-08-09 08:45:00+03	24400.00
E794B8	2017-08-06 21:53:00+03	103200.00
E79535	2017-07-09 19:53:00+03	201000.00
E79547	2017-07-07 10:57:00+03	19600.00
E79588	2017-07-16 07:52:00+03	17600.00
E795F4	2017-07-11 14:12:00+03	28000.00
E79665	2017-08-14 22:47:00+03	252200.00
E796FB	2017-07-15 11:06:00+03	192800.00
E796FF	2017-07-04 04:11:00+03	98000.00
E7973F	2017-07-04 16:00:00+03	38400.00
E797B2	2017-07-22 02:46:00+03	65900.00
E797F0	2017-06-29 14:20:00+03	24300.00
E79835	2017-08-11 08:03:00+03	27900.00
E79865	2017-07-15 16:05:00+03	28800.00
E798BE	2017-06-26 19:44:00+03	20200.00
E79927	2017-07-26 13:59:00+03	28800.00
E7995B	2017-07-20 03:26:00+03	16400.00
E799A0	2017-08-07 02:27:00+03	95200.00
E799C8	2017-08-14 11:11:00+03	87800.00
E799E9	2017-07-18 07:08:00+03	115000.00
E79A10	2017-07-22 17:39:00+03	23200.00
E79A4F	2017-08-05 03:01:00+03	73400.00
E79ABE	2017-07-31 11:41:00+03	64100.00
E79B2F	2017-08-04 02:29:00+03	41800.00
E79B49	2017-08-13 20:17:00+03	143800.00
E79C46	2017-07-23 17:02:00+03	12400.00
E79CA9	2017-07-18 21:28:00+03	91700.00
E79CBB	2017-08-13 17:11:00+03	120900.00
E79CC3	2017-07-17 03:33:00+03	25400.00
E79CF3	2017-07-07 07:57:00+03	199600.00
E79D0E	2017-07-25 04:41:00+03	55800.00
E79D62	2017-07-10 07:57:00+03	84500.00
E79DAC	2017-07-23 16:59:00+03	22000.00
E79DC0	2017-08-04 00:14:00+03	46400.00
E79E50	2017-07-01 05:41:00+03	78300.00
E79E5A	2017-07-11 04:52:00+03	43600.00
E79E72	2017-07-05 03:35:00+03	6600.00
E79ED2	2017-07-27 04:58:00+03	174600.00
E79EEE	2017-08-06 20:10:00+03	133100.00
E79F07	2017-07-14 05:43:00+03	46200.00
E79F69	2017-08-07 10:59:00+03	105400.00
E79F85	2017-07-31 21:25:00+03	24800.00
E79F86	2017-08-06 23:13:00+03	18600.00
E79F88	2017-07-29 10:00:00+03	28000.00
E79FAC	2017-07-08 01:31:00+03	194800.00
E79FBF	2017-08-01 21:58:00+03	7400.00
E79FD2	2017-07-02 02:54:00+03	136200.00
E7A037	2017-08-11 06:10:00+03	26800.00
E7A04C	2017-07-27 13:54:00+03	98300.00
E7A063	2017-07-01 01:58:00+03	59800.00
E7A117	2017-08-13 22:13:00+03	123000.00
E7A125	2017-07-01 05:46:00+03	39500.00
E7A136	2017-08-09 21:04:00+03	23600.00
E7A160	2017-08-13 11:03:00+03	59200.00
E7A196	2017-07-04 08:08:00+03	82200.00
E7A1C2	2017-08-08 02:18:00+03	91100.00
E7A1EF	2017-07-14 21:41:00+03	30400.00
E7A214	2017-07-20 15:19:00+03	42800.00
E7A272	2017-06-27 22:52:00+03	119600.00
E7A27E	2017-08-03 11:47:00+03	88900.00
E7A29C	2017-08-08 07:25:00+03	38200.00
E7A29D	2017-08-15 16:35:00+03	39200.00
E7A2AC	2017-07-22 17:15:00+03	99200.00
E7A2D5	2017-07-04 19:20:00+03	40400.00
E7A33A	2017-08-01 02:41:00+03	25600.00
E7A386	2017-07-27 15:46:00+03	48300.00
E7A409	2017-07-27 19:41:00+03	35800.00
E7A430	2017-07-29 09:21:00+03	56900.00
E7A48B	2017-08-10 21:51:00+03	38600.00
E7A4C1	2017-07-23 09:43:00+03	47400.00
E7A51B	2017-07-03 05:30:00+03	446100.00
E7A557	2017-08-12 18:12:00+03	28800.00
E7A559	2017-07-08 05:56:00+03	23600.00
E7A5CF	2017-07-04 02:39:00+03	124000.00
E7A5F7	2017-07-09 23:41:00+03	131200.00
E7A606	2017-07-12 18:46:00+03	67600.00
E7A611	2017-07-09 23:01:00+03	191000.00
E7A625	2017-08-05 09:11:00+03	40800.00
E7A667	2017-08-15 12:46:00+03	139700.00
E7A68C	2017-07-02 15:21:00+03	41800.00
E7A6D5	2017-08-01 21:35:00+03	46400.00
E7A6DB	2017-07-31 04:37:00+03	30200.00
E7A6F7	2017-06-27 16:01:00+03	81300.00
E7A6F9	2017-07-12 04:06:00+03	8200.00
E7A745	2017-08-01 17:00:00+03	28800.00
E7A768	2017-07-20 10:22:00+03	33600.00
E7A76F	2017-07-22 14:13:00+03	45900.00
E7A7A4	2017-07-16 23:49:00+03	123000.00
E7A874	2017-07-11 00:58:00+03	149400.00
E7A8D3	2017-08-11 18:19:00+03	24400.00
E7A8E0	2017-07-28 13:55:00+03	47700.00
E7A8EE	2017-07-14 23:10:00+03	166100.00
E7A925	2017-08-08 13:58:00+03	67400.00
E7A92F	2017-07-21 23:45:00+03	195600.00
E7A940	2017-08-14 20:43:00+03	92900.00
E7A98E	2017-07-20 12:22:00+03	96200.00
E7A991	2017-08-15 04:32:00+03	14400.00
E7AA0F	2017-07-30 22:28:00+03	151200.00
E7AA10	2017-07-29 06:56:00+03	111600.00
E7AABB	2017-07-16 01:30:00+03	57400.00
E7AACA	2017-07-16 16:37:00+03	28400.00
E7AAE3	2017-08-09 12:08:00+03	42800.00
E7ABF6	2017-07-18 21:56:00+03	19600.00
E7ABFD	2017-08-09 00:20:00+03	87400.00
E7AC24	2017-06-30 05:48:00+03	47300.00
E7AC8B	2017-07-26 19:53:00+03	12600.00
E7ACD8	2017-08-10 16:13:00+03	195800.00
E7ACF5	2017-08-13 05:44:00+03	66600.00
E7AD38	2017-08-12 17:19:00+03	62700.00
E7AD71	2017-07-03 13:57:00+03	249100.00
E7AD81	2017-07-31 10:36:00+03	16400.00
E7ADD6	2017-08-07 13:31:00+03	43200.00
E7ADF4	2017-08-14 04:16:00+03	92100.00
E7AE5D	2017-08-08 06:14:00+03	52800.00
E7AE85	2017-08-10 22:14:00+03	92000.00
E7AE99	2017-07-20 10:36:00+03	10800.00
E7AED5	2017-07-10 19:50:00+03	73300.00
E7AF01	2017-08-15 16:55:00+03	7400.00
E7AF2A	2017-08-14 00:22:00+03	81300.00
E7AF5A	2017-07-25 14:25:00+03	89600.00
E7AFF3	2017-07-27 09:01:00+03	8400.00
E7AFFA	2017-07-10 19:46:00+03	50700.00
E7AFFC	2017-07-17 08:21:00+03	10600.00
E7B04A	2017-07-03 12:33:00+03	14800.00
E7B091	2017-07-17 05:22:00+03	47100.00
E7B0A2	2017-08-10 04:12:00+03	67100.00
E7B0E4	2017-08-06 05:36:00+03	32700.00
E7B119	2017-07-18 10:14:00+03	30000.00
E7B131	2017-07-26 12:03:00+03	58600.00
E7B1C8	2017-08-14 17:49:00+03	16400.00
E7B262	2017-08-10 04:48:00+03	58800.00
E7B266	2017-07-25 02:55:00+03	30800.00
E7B286	2017-08-07 01:22:00+03	37900.00
E7B2D1	2017-07-07 17:01:00+03	109100.00
E7B33B	2017-08-06 09:34:00+03	34700.00
E7B360	2017-07-31 19:40:00+03	77900.00
E7B3C4	2017-07-24 01:53:00+03	73300.00
E7B42F	2017-07-18 16:23:00+03	11600.00
E7B43B	2017-07-01 17:04:00+03	8400.00
E7B4A2	2017-07-22 09:06:00+03	76600.00
E7B4F6	2017-07-14 16:12:00+03	63000.00
E7B507	2017-07-05 21:17:00+03	89700.00
E7B54A	2017-08-11 16:54:00+03	20400.00
E7B59C	2017-07-07 08:10:00+03	147100.00
E7B5AC	2017-07-18 17:45:00+03	52000.00
E7B5C8	2017-08-12 18:55:00+03	42000.00
E7B5E1	2017-08-05 10:51:00+03	101500.00
E7B66F	2017-07-06 03:03:00+03	28800.00
E7B68D	2017-08-12 16:02:00+03	36000.00
E7B6BF	2017-08-10 16:01:00+03	62300.00
E7B6D4	2017-07-09 04:27:00+03	25600.00
E7B70B	2017-07-08 03:34:00+03	129400.00
E7B714	2017-08-10 02:09:00+03	34400.00
E7B748	2017-07-03 03:07:00+03	492000.00
E7B752	2017-07-20 07:17:00+03	34000.00
E7B79A	2017-07-25 20:17:00+03	103100.00
E7B82E	2017-07-16 09:37:00+03	64700.00
E7B87E	2017-07-13 05:34:00+03	60000.00
E7B933	2017-07-21 21:23:00+03	62600.00
E7B935	2017-07-27 17:27:00+03	75300.00
E7B93D	2017-08-13 17:52:00+03	69000.00
E7B96B	2017-07-20 17:07:00+03	141300.00
E7B980	2017-07-02 09:38:00+03	46000.00
E7B98D	2017-07-08 15:03:00+03	31600.00
E7BA13	2017-08-15 02:11:00+03	93500.00
E7BA17	2017-08-02 20:57:00+03	83000.00
E7BAF4	2017-08-09 17:24:00+03	123000.00
E7BB90	2017-07-21 02:23:00+03	24700.00
E7BBAA	2017-08-10 16:22:00+03	47600.00
E7BBDA	2017-08-09 10:40:00+03	59800.00
E7BBE6	2017-07-02 05:45:00+03	29600.00
E7BBFA	2017-08-03 07:14:00+03	40800.00
E7BC1B	2017-07-03 09:21:00+03	12600.00
E7BC4D	2017-07-18 19:28:00+03	32700.00
E7BC6C	2017-08-08 08:54:00+03	120000.00
E7BD86	2017-07-29 02:54:00+03	43500.00
E7BD88	2017-08-10 20:01:00+03	46800.00
E7BECB	2017-08-14 17:36:00+03	13400.00
E7BF0B	2017-07-17 08:17:00+03	29600.00
E7BF25	2017-08-11 14:29:00+03	56000.00
E7BF44	2017-07-19 15:52:00+03	18600.00
E7BF47	2017-07-05 08:27:00+03	73500.00
E7BF52	2017-07-06 06:51:00+03	36200.00
E7BF8F	2017-07-02 17:57:00+03	227000.00
E7BFDD	2017-07-06 09:57:00+03	44600.00
E7C027	2017-07-20 20:06:00+03	28000.00
E7C052	2017-07-12 03:22:00+03	131900.00
E7C08E	2017-07-24 13:23:00+03	44800.00
E7C10E	2017-07-16 21:57:00+03	105000.00
E7C16B	2017-07-05 12:37:00+03	92800.00
E7C1DC	2017-07-02 14:15:00+03	47200.00
E7C251	2017-07-05 10:06:00+03	46200.00
E7C324	2017-07-07 23:21:00+03	67100.00
E7C34E	2017-07-05 22:31:00+03	47800.00
E7C3B5	2017-07-08 19:59:00+03	199900.00
E7C3C3	2017-07-17 17:53:00+03	38600.00
E7C429	2017-08-06 02:56:00+03	26000.00
E7C42B	2017-07-17 04:58:00+03	273000.00
E7C42F	2017-07-19 16:44:00+03	47200.00
E7C43A	2017-07-28 06:51:00+03	26000.00
E7C452	2017-08-05 07:30:00+03	52800.00
E7C45F	2017-07-13 00:12:00+03	198400.00
E7C47E	2017-08-03 03:18:00+03	42800.00
E7C529	2017-08-06 08:39:00+03	189800.00
E7C57F	2017-08-15 05:38:00+03	29400.00
E7C59E	2017-07-22 14:57:00+03	146200.00
E7C5C6	2017-07-22 11:57:00+03	54600.00
E7C613	2017-07-21 07:31:00+03	24400.00
E7C6FF	2017-07-14 00:23:00+03	49200.00
E7C716	2017-07-13 20:12:00+03	111600.00
E7C733	2017-07-08 01:36:00+03	23400.00
E7C735	2017-06-29 21:31:00+03	46400.00
E7C75A	2017-08-04 20:57:00+03	47400.00
E7C811	2017-07-17 06:16:00+03	196300.00
E7C85A	2017-08-14 02:14:00+03	51600.00
E7C87D	2017-07-26 22:04:00+03	57400.00
E7C890	2017-08-15 03:52:00+03	398300.00
E7C89B	2017-07-04 11:27:00+03	13400.00
E7C8F1	2017-07-26 18:11:00+03	73200.00
E7C90A	2017-07-12 04:35:00+03	89200.00
E7C90E	2017-07-07 10:14:00+03	66000.00
E7C93F	2017-06-30 04:09:00+03	132800.00
E7C984	2017-07-05 10:35:00+03	79000.00
E7C9B8	2017-07-26 04:04:00+03	43200.00
E7CA05	2017-07-16 09:09:00+03	38600.00
E7CA3F	2017-07-28 00:00:00+03	56000.00
E7CA62	2017-07-11 03:55:00+03	34000.00
E7CA9F	2017-07-27 06:17:00+03	44000.00
E7CAA5	2017-08-10 11:45:00+03	79900.00
E7CB2C	2017-08-15 14:07:00+03	16800.00
E7CB4A	2017-07-24 12:52:00+03	46400.00
E7CB8F	2017-07-03 10:54:00+03	160400.00
E7CBC6	2017-07-21 19:45:00+03	75800.00
E7CBC9	2017-07-29 19:49:00+03	91600.00
E7CC0A	2017-07-28 22:02:00+03	7400.00
E7CCF3	2017-07-20 00:47:00+03	67600.00
E7CD3D	2017-07-06 13:06:00+03	42800.00
E7CD5F	2017-07-14 13:56:00+03	56000.00
E7CE0D	2017-08-10 15:23:00+03	55800.00
E7CE1D	2017-08-05 06:48:00+03	67600.00
E7CE21	2017-08-03 11:23:00+03	500100.00
E7CEB7	2017-08-09 15:58:00+03	79900.00
E7CED1	2017-08-03 12:07:00+03	112000.00
E7CEDF	2017-08-13 18:38:00+03	35700.00
E7CEE6	2017-08-09 22:48:00+03	132800.00
E7CF30	2017-07-05 05:23:00+03	14400.00
E7CF5B	2017-07-12 12:31:00+03	16400.00
E7D002	2017-07-23 02:50:00+03	40600.00
E7D04E	2017-08-13 07:31:00+03	133200.00
E7D07F	2017-07-07 11:05:00+03	119600.00
E7D0D4	2017-07-04 06:16:00+03	69000.00
E7D11B	2017-07-08 23:13:00+03	103800.00
E7D143	2017-07-16 22:30:00+03	46000.00
E7D149	2017-08-14 06:52:00+03	26000.00
E7D187	2017-07-02 20:07:00+03	31600.00
E7D242	2017-07-15 23:40:00+03	206200.00
E7D243	2017-08-14 16:01:00+03	125600.00
E7D269	2017-08-12 04:02:00+03	35600.00
E7D2DF	2017-07-23 05:08:00+03	46400.00
E7D349	2017-07-07 22:23:00+03	56000.00
E7D34D	2017-07-08 10:24:00+03	97500.00
E7D3EF	2017-08-08 15:47:00+03	70700.00
E7D43D	2017-07-14 08:10:00+03	168000.00
E7D463	2017-07-26 15:52:00+03	6800.00
E7D46A	2017-07-12 16:28:00+03	123000.00
E7D481	2017-08-11 20:34:00+03	57300.00
E7D4B1	2017-08-13 23:20:00+03	26700.00
E7D563	2017-08-04 04:59:00+03	77900.00
E7D5D4	2017-07-25 19:17:00+03	129700.00
E7D5F8	2017-08-08 21:02:00+03	81800.00
E7D66D	2017-07-14 01:27:00+03	28000.00
E7D675	2017-07-10 22:33:00+03	123000.00
E7D677	2017-07-26 00:48:00+03	39300.00
E7D67B	2017-07-30 10:55:00+03	28000.00
E7D6C4	2017-08-03 13:02:00+03	47100.00
E7D6DC	2017-07-16 12:56:00+03	33000.00
E7D712	2017-08-13 11:09:00+03	90600.00
E7D729	2017-07-01 06:10:00+03	198600.00
E7D826	2017-07-02 05:00:00+03	181000.00
E7D8C0	2017-07-27 14:35:00+03	53600.00
E7D92B	2017-06-29 03:56:00+03	38600.00
E7D93A	2017-07-27 04:54:00+03	23600.00
E7DA28	2017-07-31 04:52:00+03	106700.00
E7DA2D	2017-07-18 03:57:00+03	58000.00
E7DA97	2017-07-09 01:07:00+03	61800.00
E7DAB7	2017-07-18 13:33:00+03	25000.00
E7DB01	2017-07-07 21:15:00+03	116000.00
E7DB4B	2017-07-28 13:50:00+03	93900.00
E7DB9A	2017-07-08 19:48:00+03	81600.00
E7DB9F	2017-07-31 02:52:00+03	45200.00
E7DBBD	2017-07-25 18:40:00+03	193900.00
E7DBCA	2017-08-11 15:03:00+03	28000.00
E7DC0F	2017-07-21 09:17:00+03	68100.00
E7DC3A	2017-08-07 01:53:00+03	26000.00
E7DC69	2017-08-04 06:10:00+03	28000.00
E7DC96	2017-07-30 01:04:00+03	28000.00
E7DCC4	2017-07-24 04:37:00+03	91200.00
E7DD89	2017-07-05 11:57:00+03	37900.00
E7DD8E	2017-08-07 08:06:00+03	58000.00
E7DDFB	2017-08-12 16:33:00+03	96800.00
E7DEE9	2017-08-01 16:05:00+03	265600.00
E7DEEB	2017-07-14 22:12:00+03	135600.00
E7DF4C	2017-08-03 03:46:00+03	16400.00
E7DF65	2017-07-28 06:17:00+03	131800.00
E7DF75	2017-07-11 18:26:00+03	51000.00
E7DF85	2017-07-15 08:40:00+03	18000.00
E7DFFC	2017-08-07 15:09:00+03	60700.00
E7E03D	2017-07-25 10:58:00+03	122800.00
E7E045	2017-07-03 18:37:00+03	38400.00
E7E0F0	2017-07-18 10:07:00+03	26200.00
E7E1C3	2017-07-02 09:42:00+03	52000.00
E7E21A	2017-07-29 23:22:00+03	186600.00
E7E2A0	2017-07-05 18:38:00+03	56000.00
E7E2DF	2017-08-05 12:07:00+03	58800.00
E7E3D8	2017-07-01 11:52:00+03	47600.00
E7E43A	2017-07-06 00:49:00+03	50000.00
E7E570	2017-07-26 01:06:00+03	62800.00
E7E5A3	2017-07-09 13:37:00+03	132800.00
E7E650	2017-07-11 14:56:00+03	149500.00
E7E682	2017-08-12 09:39:00+03	75300.00
E7E687	2017-07-28 05:13:00+03	118100.00
E7E6B9	2017-08-15 11:21:00+03	39000.00
E7E733	2017-07-12 15:43:00+03	55800.00
E7E765	2017-07-24 08:28:00+03	23900.00
E7E77B	2017-07-13 04:12:00+03	43000.00
E7E7D1	2017-08-10 04:19:00+03	391300.00
E7E85F	2017-07-12 22:51:00+03	39200.00
E7E897	2017-08-08 19:35:00+03	47100.00
E7E8D7	2017-08-05 05:46:00+03	40800.00
E7E8E9	2017-08-12 06:10:00+03	6300.00
E7E8F8	2017-07-15 17:01:00+03	85000.00
E7E8FC	2017-07-22 18:14:00+03	85000.00
E7E938	2017-07-15 09:53:00+03	65800.00
E7E9A1	2017-07-10 21:06:00+03	72800.00
E7E9AC	2017-08-06 05:08:00+03	22000.00
E7E9CA	2017-08-08 19:51:00+03	46400.00
E7E9E6	2017-07-18 20:01:00+03	75600.00
E7EA36	2017-07-14 04:55:00+03	56000.00
E7EA3B	2017-07-24 05:08:00+03	48400.00
E7EA52	2017-08-13 07:23:00+03	103800.00
E7EA7E	2017-08-07 12:24:00+03	43200.00
E7EA9F	2017-08-03 14:12:00+03	139300.00
E7EAF4	2017-08-12 04:55:00+03	136800.00
E7EC12	2017-07-18 15:20:00+03	55600.00
E7EC1A	2017-07-17 11:05:00+03	31400.00
E7ECA0	2017-08-06 08:41:00+03	67700.00
E7ECC9	2017-07-09 10:19:00+03	24400.00
E7ECDC	2017-08-14 18:52:00+03	266200.00
E7ED32	2017-08-07 12:00:00+03	43600.00
E7ED39	2017-07-21 11:04:00+03	101500.00
E7EDD3	2017-07-20 12:31:00+03	85000.00
E7EE15	2017-07-28 11:54:00+03	25200.00
E7EE72	2017-07-14 15:00:00+03	17200.00
E7EE81	2017-06-29 23:36:00+03	19600.00
E7EE91	2017-08-03 05:41:00+03	97900.00
E7EF2B	2017-08-04 04:31:00+03	58800.00
E7EF57	2017-08-13 03:13:00+03	26800.00
E7EF62	2017-07-07 07:28:00+03	13700.00
E7EF86	2017-08-03 05:15:00+03	79600.00
E7EFFB	2017-08-14 02:40:00+03	25000.00
E7F05E	2017-08-12 12:05:00+03	88000.00
E7F0E1	2017-07-17 21:00:00+03	47400.00
E7F11B	2017-07-13 13:02:00+03	85200.00
E7F14D	2017-07-31 05:09:00+03	96800.00
E7F22E	2017-07-02 05:28:00+03	28800.00
E7F235	2017-07-01 17:33:00+03	19800.00
E7F24E	2017-07-03 22:02:00+03	203500.00
E7F2FC	2017-07-24 17:06:00+03	6300.00
E7F327	2017-08-06 15:50:00+03	127900.00
E7F362	2017-08-02 13:46:00+03	26000.00
E7F381	2017-07-29 00:13:00+03	56000.00
E7F3A6	2017-08-14 05:23:00+03	25100.00
E7F426	2017-08-15 11:53:00+03	76400.00
E7F4C2	2017-08-09 17:51:00+03	49100.00
E7F4F4	2017-06-30 08:44:00+03	114500.00
E7F542	2017-08-08 05:34:00+03	56000.00
E7F569	2017-07-13 12:57:00+03	135400.00
E7F575	2017-08-07 12:40:00+03	160700.00
E7F5F8	2017-07-18 10:26:00+03	43100.00
E7F616	2017-07-22 20:52:00+03	38600.00
E7F628	2017-07-29 10:05:00+03	399600.00
E7F678	2017-07-19 22:30:00+03	71900.00
E7F692	2017-08-07 07:24:00+03	75600.00
E7F6E9	2017-07-20 03:09:00+03	800500.00
E7F6F6	2017-08-07 23:23:00+03	399600.00
E7F770	2017-07-11 19:40:00+03	14800.00
E7F810	2017-08-01 13:30:00+03	57500.00
E7F817	2017-08-03 15:49:00+03	232300.00
E7F82C	2017-07-22 14:35:00+03	6800.00
E7F890	2017-08-04 10:56:00+03	28800.00
E7F8C0	2017-07-06 02:55:00+03	237400.00
E7F912	2017-07-30 02:15:00+03	56600.00
E7F928	2017-07-08 10:03:00+03	101100.00
E7F947	2017-07-02 08:38:00+03	85200.00
E7F956	2017-07-16 01:22:00+03	136200.00
E7F98A	2017-07-04 23:01:00+03	27200.00
E7F98D	2017-07-24 10:18:00+03	73600.00
E7F9E3	2017-07-28 17:51:00+03	8200.00
E7FA0E	2017-07-17 01:54:00+03	44600.00
E7FA38	2017-08-15 17:43:00+03	32400.00
E7FA8D	2017-07-22 09:53:00+03	26600.00
E7FA95	2017-07-29 03:58:00+03	26300.00
E7FAC2	2017-07-19 04:46:00+03	46200.00
E7FB17	2017-06-29 17:56:00+03	153200.00
E7FB7D	2017-07-12 06:13:00+03	117600.00
E7FBF8	2017-07-10 18:38:00+03	135400.00
E7FC15	2017-07-02 05:15:00+03	43600.00
E7FC2B	2017-08-15 00:44:00+03	108300.00
E7FC33	2017-07-28 03:31:00+03	27200.00
E7FC4E	2017-07-23 15:10:00+03	29200.00
E7FC7A	2017-07-25 15:42:00+03	75300.00
E7FD15	2017-07-08 09:45:00+03	55800.00
E7FD24	2017-07-16 00:08:00+03	44200.00
E7FD58	2017-07-14 12:44:00+03	49100.00
E7FDB7	2017-07-28 12:45:00+03	49100.00
E7FDEF	2017-07-29 20:25:00+03	28800.00
E7FE08	2017-07-16 05:06:00+03	166300.00
E7FE1D	2017-08-06 22:41:00+03	65300.00
E7FE85	2017-07-25 12:31:00+03	13200.00
E7FEB4	2017-08-01 02:17:00+03	56000.00
E7FEC1	2017-07-08 17:11:00+03	23200.00
E7FECB	2017-06-25 21:26:00+03	28000.00
E7FF0A	2017-08-13 02:13:00+03	72400.00
E7FFA8	2017-07-09 10:18:00+03	75300.00
E7FFF7	2017-07-05 17:06:00+03	246000.00
E7FFF9	2017-07-29 15:46:00+03	172400.00
E80040	2017-07-19 01:18:00+03	83500.00
E80068	2017-07-08 15:05:00+03	25200.00
E800AC	2017-07-28 21:35:00+03	81300.00
E80112	2017-06-30 09:09:00+03	27300.00
E80126	2017-07-19 05:55:00+03	75000.00
E8012D	2017-07-29 13:50:00+03	42800.00
E8013E	2017-06-29 11:54:00+03	49300.00
E80173	2017-08-12 04:37:00+03	56000.00
E8018E	2017-08-10 20:24:00+03	38800.00
E801B5	2017-07-28 13:31:00+03	46000.00
E801E6	2017-06-30 18:33:00+03	480600.00
E801F0	2017-08-13 09:37:00+03	54100.00
E80257	2017-08-03 07:07:00+03	117600.00
E80296	2017-07-17 16:38:00+03	37200.00
E802AE	2017-07-07 00:30:00+03	68400.00
E802CC	2017-08-03 00:03:00+03	12400.00
E80315	2017-07-03 22:39:00+03	174400.00
E803FB	2017-07-15 05:21:00+03	70000.00
E80442	2017-07-24 02:37:00+03	48800.00
E80491	2017-07-22 12:16:00+03	7400.00
E804BE	2017-07-07 16:30:00+03	224400.00
E804EB	2017-08-13 18:48:00+03	193100.00
E80503	2017-07-07 20:51:00+03	73300.00
E8054E	2017-07-27 02:26:00+03	23100.00
E80580	2017-07-11 03:54:00+03	39300.00
E80647	2017-08-07 07:14:00+03	22000.00
E8066B	2017-07-07 22:01:00+03	23600.00
E806AF	2017-07-05 04:08:00+03	47600.00
E806DA	2017-07-08 20:28:00+03	28000.00
E8079E	2017-08-13 08:12:00+03	48600.00
E8080F	2017-07-11 07:14:00+03	37900.00
E80817	2017-07-30 09:45:00+03	20200.00
E8084A	2017-07-07 23:18:00+03	186900.00
E80868	2017-08-12 01:34:00+03	176400.00
E80895	2017-08-05 04:01:00+03	73600.00
E8089B	2017-07-30 20:26:00+03	11700.00
E808A8	2017-08-13 22:35:00+03	21400.00
E80913	2017-08-05 06:07:00+03	26000.00
E80916	2017-08-14 04:44:00+03	28700.00
E8094A	2017-08-12 18:13:00+03	44800.00
E809CB	2017-07-11 01:08:00+03	19600.00
E80A37	2017-07-29 09:52:00+03	20200.00
E80A46	2017-08-02 23:29:00+03	24700.00
E80A53	2017-08-01 11:18:00+03	93300.00
E80A77	2017-07-10 21:45:00+03	25600.00
E80A8E	2017-07-18 14:27:00+03	170000.00
E80AE9	2017-07-28 23:12:00+03	101500.00
E80AEE	2017-08-10 00:36:00+03	86400.00
E80B1B	2017-08-01 04:37:00+03	28000.00
E80B4F	2017-07-03 17:44:00+03	109600.00
E80B76	2017-07-20 10:45:00+03	50000.00
E80BB3	2017-07-06 10:09:00+03	62200.00
E80BE3	2017-07-23 04:14:00+03	172200.00
E80C28	2017-07-30 09:38:00+03	43200.00
E80C65	2017-08-12 00:10:00+03	58000.00
E80CDB	2017-07-09 19:00:00+03	76100.00
E80CFE	2017-07-08 14:28:00+03	427400.00
E80D24	2017-07-27 21:09:00+03	159100.00
E80D31	2017-07-10 13:13:00+03	14400.00
E80DE1	2017-07-28 22:38:00+03	52000.00
E80E00	2017-07-29 23:16:00+03	270200.00
E80E44	2017-07-04 00:53:00+03	45300.00
E80E5E	2017-07-24 11:44:00+03	45400.00
E80F3C	2017-08-15 01:07:00+03	64700.00
E80F76	2017-08-09 12:03:00+03	155300.00
E80FD8	2017-07-15 09:48:00+03	265600.00
E80FE5	2017-08-13 11:12:00+03	36800.00
E81019	2017-08-14 23:55:00+03	14000.00
E8104A	2017-07-20 13:30:00+03	95600.00
E8106D	2017-07-06 07:38:00+03	23200.00
E81115	2017-08-06 07:42:00+03	8200.00
E81127	2017-08-03 22:41:00+03	111600.00
E8112D	2017-08-10 21:30:00+03	132800.00
E811ED	2017-08-10 16:59:00+03	46900.00
E811F5	2017-08-06 16:30:00+03	62900.00
E8121D	2017-07-16 23:15:00+03	74900.00
E81228	2017-08-02 22:09:00+03	45100.00
E8122A	2017-07-18 13:09:00+03	65500.00
E81257	2017-08-13 20:45:00+03	53600.00
E8132D	2017-08-14 20:50:00+03	313500.00
E81337	2017-08-05 05:32:00+03	84500.00
E8133E	2017-07-06 19:46:00+03	31100.00
E8136C	2017-07-05 13:20:00+03	158400.00
E81413	2017-08-02 00:15:00+03	96800.00
E81480	2017-07-01 05:17:00+03	32900.00
E81485	2017-08-14 13:35:00+03	24000.00
E8149C	2017-07-23 08:47:00+03	70100.00
E814AC	2017-07-19 13:19:00+03	122600.00
E814D7	2017-08-10 19:22:00+03	79900.00
E814F3	2017-08-04 04:26:00+03	119500.00
E8152C	2017-07-23 14:35:00+03	46400.00
E81530	2017-08-08 14:52:00+03	86300.00
E815C4	2017-07-09 04:26:00+03	56000.00
E815D2	2017-08-02 12:48:00+03	320300.00
E815F2	2017-08-14 09:48:00+03	112000.00
E81675	2017-07-20 02:38:00+03	59000.00
E81687	2017-07-12 13:14:00+03	271200.00
E816B4	2017-08-12 05:12:00+03	29400.00
E816D3	2017-07-24 20:15:00+03	55800.00
E816E5	2017-07-20 18:43:00+03	47000.00
E81717	2017-08-12 22:55:00+03	136200.00
E81751	2017-08-10 07:46:00+03	43200.00
E8177F	2017-07-21 13:37:00+03	28800.00
E817A4	2017-07-29 21:47:00+03	45100.00
E817B6	2017-08-02 12:09:00+03	56600.00
E817E9	2017-07-27 16:38:00+03	17800.00
E8180C	2017-07-02 04:30:00+03	136800.00
E8182C	2017-07-22 16:29:00+03	21400.00
E8187F	2017-08-13 01:38:00+03	28800.00
E818E1	2017-07-27 13:04:00+03	25200.00
E818E4	2017-08-10 03:45:00+03	119700.00
E818F6	2017-07-19 11:07:00+03	67600.00
E81942	2017-07-12 23:31:00+03	66000.00
E8196D	2017-07-16 05:06:00+03	15000.00
E819A5	2017-08-10 08:52:00+03	39800.00
E819D3	2017-07-15 09:15:00+03	6000.00
E819F9	2017-07-19 16:36:00+03	6000.00
E81A24	2017-08-07 17:55:00+03	83800.00
E81A35	2017-08-04 16:15:00+03	119500.00
E81B1A	2017-08-01 11:05:00+03	46000.00
E81B39	2017-08-13 23:43:00+03	13400.00
E81B76	2017-07-21 14:35:00+03	134200.00
E81B82	2017-08-14 12:34:00+03	51300.00
E81B8A	2017-08-01 08:12:00+03	258400.00
E81B91	2017-07-31 05:28:00+03	29400.00
E81BC6	2017-07-26 12:32:00+03	19800.00
E81C3A	2017-07-23 08:13:00+03	89700.00
E81C58	2017-07-18 14:00:00+03	46000.00
E81C92	2017-08-03 05:54:00+03	9800.00
E81C9A	2017-07-31 18:10:00+03	94000.00
E81CCD	2017-07-11 22:07:00+03	19600.00
E81CF6	2017-08-04 18:28:00+03	46300.00
E81D7F	2017-07-25 15:35:00+03	21200.00
E81D9A	2017-07-09 20:44:00+03	241300.00
E81DE7	2017-08-09 11:50:00+03	26800.00
E81E3A	2017-08-05 12:30:00+03	40000.00
E81E66	2017-08-12 02:25:00+03	11600.00
E81EBC	2017-07-06 23:56:00+03	39500.00
E81EE6	2017-07-24 22:46:00+03	27200.00
E81F12	2017-07-21 19:40:00+03	72400.00
E81F19	2017-07-23 06:41:00+03	28000.00
E81F92	2017-07-24 18:43:00+03	34000.00
E81FF1	2017-08-08 12:13:00+03	145300.00
E82001	2017-08-02 16:24:00+03	51800.00
E82069	2017-07-17 18:02:00+03	36400.00
E820A0	2017-08-05 03:59:00+03	32400.00
E821FD	2017-07-18 10:18:00+03	177200.00
E8220C	2017-07-14 12:42:00+03	13200.00
E82264	2017-07-16 10:03:00+03	27200.00
E8229F	2017-08-01 08:45:00+03	93900.00
E8231D	2017-08-07 05:42:00+03	369000.00
E82325	2017-08-03 15:18:00+03	58800.00
E8235F	2017-08-08 06:42:00+03	60800.00
E823B6	2017-07-24 16:17:00+03	38800.00
E823E6	2017-07-03 19:19:00+03	177600.00
E823EB	2017-08-15 15:59:00+03	284700.00
E823FE	2017-07-18 12:16:00+03	6700.00
E82405	2017-07-18 13:56:00+03	15200.00
E8241C	2017-07-21 10:38:00+03	77200.00
E8241D	2017-08-04 02:16:00+03	112000.00
E82461	2017-07-18 06:25:00+03	58400.00
E82487	2017-07-14 10:36:00+03	42400.00
E824DB	2017-07-02 17:47:00+03	65900.00
E8251D	2017-07-25 15:30:00+03	47000.00
E82537	2017-08-08 21:32:00+03	28000.00
E82577	2017-06-28 05:52:00+03	99200.00
E825C4	2017-08-06 12:29:00+03	124200.00
E825CA	2017-07-26 18:25:00+03	56000.00
E825E1	2017-08-05 16:28:00+03	166900.00
E82622	2017-07-07 14:12:00+03	27200.00
E82648	2017-07-24 19:40:00+03	58200.00
E82698	2017-07-25 00:48:00+03	78000.00
E826A7	2017-07-10 10:59:00+03	64600.00
E826AC	2017-07-04 10:10:00+03	124200.00
E826BE	2017-07-02 09:02:00+03	47400.00
E82720	2017-07-10 23:59:00+03	23200.00
E8272D	2017-07-15 22:37:00+03	45500.00
E82758	2017-08-01 12:57:00+03	58400.00
E8275C	2017-07-21 07:01:00+03	117600.00
E827A8	2017-08-15 17:13:00+03	48800.00
E827AF	2017-07-21 11:30:00+03	27900.00
E827B1	2017-08-13 02:36:00+03	160700.00
E8281D	2017-08-11 12:51:00+03	42700.00
E82829	2017-07-03 16:56:00+03	39900.00
E82837	2017-08-05 07:04:00+03	260300.00
E82875	2017-07-27 01:33:00+03	137700.00
E8288E	2017-07-24 01:19:00+03	23900.00
E82983	2017-08-03 10:05:00+03	6000.00
E8299A	2017-07-15 12:43:00+03	92400.00
E829CF	2017-07-14 23:43:00+03	21400.00
E82A47	2017-07-03 20:20:00+03	55800.00
E82A4B	2017-07-11 13:50:00+03	76600.00
E82A63	2017-07-08 06:23:00+03	78300.00
E82AE3	2017-08-13 05:30:00+03	246000.00
E82C02	2017-07-31 15:44:00+03	26600.00
E82C8C	2017-07-08 01:58:00+03	28800.00
E82C8D	2017-08-10 06:31:00+03	123000.00
E82C9F	2017-08-14 13:55:00+03	56000.00
E82D0C	2017-07-09 11:47:00+03	43300.00
E82DDA	2017-08-09 10:45:00+03	47700.00
E82E18	2017-08-05 22:25:00+03	26000.00
E82E71	2017-08-01 10:10:00+03	40800.00
E82ECE	2017-08-01 00:48:00+03	23200.00
E82EDB	2017-08-04 15:34:00+03	82900.00
E82EE3	2017-08-13 10:24:00+03	38400.00
E83015	2017-07-28 21:57:00+03	88000.00
E83037	2017-07-15 17:52:00+03	37200.00
E83092	2017-07-18 13:19:00+03	24300.00
E8309B	2017-07-30 02:02:00+03	11600.00
E83129	2017-07-03 16:29:00+03	46500.00
E83138	2017-07-08 06:20:00+03	20400.00
E83172	2017-07-08 14:06:00+03	30200.00
E8325D	2017-07-22 21:12:00+03	54500.00
E83278	2017-07-07 00:04:00+03	136800.00
E83289	2017-08-09 08:43:00+03	123400.00
E8328C	2017-07-22 10:47:00+03	17600.00
E83295	2017-08-07 19:49:00+03	44600.00
E832D0	2017-08-09 18:15:00+03	35600.00
E83352	2017-07-10 03:54:00+03	42700.00
E8335D	2017-08-08 01:52:00+03	95000.00
E83364	2017-07-06 16:30:00+03	77900.00
E83366	2017-07-09 13:53:00+03	72300.00
E83372	2017-08-10 15:03:00+03	112000.00
E83376	2017-06-27 19:01:00+03	100200.00
E83383	2017-08-08 00:32:00+03	21800.00
E833BA	2017-08-05 02:20:00+03	101800.00
E83407	2017-07-20 08:43:00+03	135000.00
E83484	2017-07-10 20:31:00+03	31100.00
E834A1	2017-08-10 01:50:00+03	102100.00
E834A4	2017-07-25 14:05:00+03	166100.00
E83545	2017-07-29 01:07:00+03	19600.00
E83575	2017-07-21 04:59:00+03	46300.00
E835A2	2017-08-04 16:30:00+03	167400.00
E835B7	2017-08-07 08:20:00+03	39200.00
E835E8	2017-06-26 19:14:00+03	35200.00
E8361F	2017-07-23 05:56:00+03	246000.00
E8363B	2017-07-07 10:23:00+03	80000.00
E836A0	2017-07-10 20:51:00+03	34200.00
E836B0	2017-07-28 03:42:00+03	25000.00
E836D4	2017-07-04 15:20:00+03	92800.00
E83724	2017-07-11 19:22:00+03	78600.00
E838C5	2017-08-14 03:12:00+03	68700.00
E838EF	2017-07-18 19:47:00+03	141600.00
E8390B	2017-07-09 04:33:00+03	48800.00
E8390C	2017-07-01 22:09:00+03	15000.00
E8391B	2017-07-31 14:43:00+03	38400.00
E8393B	2017-07-13 05:20:00+03	49800.00
E83992	2017-08-09 18:46:00+03	24800.00
E839DB	2017-08-04 10:49:00+03	53400.00
E83A02	2017-08-12 08:32:00+03	258600.00
E83A55	2017-07-10 01:01:00+03	62600.00
E83AD0	2017-08-15 12:44:00+03	84300.00
E83AE7	2017-07-27 08:07:00+03	13400.00
E83B0C	2017-08-13 10:02:00+03	16400.00
E83B47	2017-07-20 08:05:00+03	76600.00
E83BA4	2017-07-06 04:39:00+03	92800.00
E83BB6	2017-08-12 02:34:00+03	135600.00
E83BC8	2017-07-17 17:03:00+03	115100.00
E83BE9	2017-07-20 18:59:00+03	12600.00
E83C74	2017-07-19 16:05:00+03	79800.00
E83D5A	2017-07-11 08:49:00+03	67200.00
E83DA5	2017-07-06 13:41:00+03	56000.00
E83DDD	2017-07-09 17:56:00+03	61900.00
E83DE4	2017-07-18 06:43:00+03	176200.00
E83E48	2017-07-27 11:57:00+03	83000.00
E83E91	2017-07-31 09:53:00+03	90800.00
E83F1C	2017-07-09 06:45:00+03	34000.00
E83F1F	2017-07-29 15:26:00+03	199700.00
E8409D	2017-07-22 05:44:00+03	62600.00
E84111	2017-07-20 04:22:00+03	62600.00
E84148	2017-07-11 17:34:00+03	22100.00
E8415C	2017-07-25 08:02:00+03	159200.00
E841B1	2017-07-06 18:27:00+03	67600.00
E841CB	2017-07-26 04:22:00+03	47400.00
E84244	2017-07-14 11:50:00+03	79600.00
E84248	2017-08-06 16:26:00+03	132800.00
E842D5	2017-07-05 20:09:00+03	92000.00
E84301	2017-07-26 20:05:00+03	97000.00
E84322	2017-07-10 22:58:00+03	56600.00
E843A8	2017-07-21 20:38:00+03	36600.00
E843B0	2017-07-23 21:45:00+03	61800.00
E843DB	2017-07-08 12:59:00+03	92900.00
E84410	2017-07-24 20:40:00+03	38000.00
E8446E	2017-07-27 18:10:00+03	40800.00
E844A1	2017-07-23 17:06:00+03	16400.00
E844EC	2017-08-04 21:21:00+03	96800.00
E84509	2017-07-19 06:20:00+03	265700.00
E84530	2017-07-10 17:30:00+03	155600.00
E84598	2017-07-31 01:42:00+03	64600.00
E845F8	2017-07-30 19:32:00+03	188000.00
E84604	2017-07-14 10:14:00+03	242200.00
E8464E	2017-07-06 07:13:00+03	66000.00
E84662	2017-07-02 10:49:00+03	123000.00
E84688	2017-08-04 00:19:00+03	420300.00
E846BB	2017-07-07 01:40:00+03	66800.00
E846ED	2017-06-28 06:02:00+03	64700.00
E84738	2017-07-14 10:14:00+03	26800.00
E84753	2017-08-11 12:52:00+03	63800.00
E8476E	2017-07-15 15:23:00+03	44800.00
E84791	2017-07-20 01:22:00+03	51300.00
E84865	2017-07-06 16:55:00+03	85000.00
E848D3	2017-08-07 22:20:00+03	48300.00
E8491A	2017-07-02 01:52:00+03	140900.00
E849B3	2017-08-15 16:57:00+03	26700.00
E849E6	2017-07-02 05:27:00+03	24400.00
E84A02	2017-08-01 12:36:00+03	73600.00
E84A2D	2017-08-15 07:22:00+03	16400.00
E84AA7	2017-08-02 14:55:00+03	99200.00
E84B2A	2017-07-04 14:11:00+03	28800.00
E84B4E	2017-07-30 22:46:00+03	67200.00
E84B52	2017-07-16 15:41:00+03	6600.00
E84B8C	2017-07-16 00:51:00+03	55900.00
E84BC4	2017-08-05 06:34:00+03	47200.00
E84BC6	2017-07-19 04:00:00+03	46300.00
E84C06	2017-07-05 02:44:00+03	6700.00
E84C34	2017-07-06 00:18:00+03	184300.00
E84CB4	2017-07-14 01:48:00+03	53200.00
E84CC7	2017-07-23 18:12:00+03	66600.00
E84D0D	2017-07-15 21:33:00+03	153300.00
E84D20	2017-07-23 16:31:00+03	36000.00
E84D2F	2017-07-26 08:40:00+03	38600.00
E84D3D	2017-07-17 03:16:00+03	59800.00
E84D73	2017-07-17 09:59:00+03	34000.00
E84D85	2017-07-01 11:34:00+03	15900.00
E84D93	2017-07-29 01:11:00+03	64000.00
E84E1E	2017-07-11 14:35:00+03	93800.00
E84E3E	2017-07-23 03:42:00+03	75600.00
E84E70	2017-08-13 14:50:00+03	86800.00
E84E99	2017-07-29 00:44:00+03	19400.00
E84ECB	2017-07-12 18:08:00+03	26000.00
E84F2A	2017-07-09 15:08:00+03	40400.00
E84F38	2017-07-05 00:56:00+03	133200.00
E84F6C	2017-07-25 23:56:00+03	124300.00
E84F78	2017-08-14 09:30:00+03	53600.00
E84F83	2017-07-20 02:25:00+03	34600.00
E84FB6	2017-08-10 17:04:00+03	208100.00
E85046	2017-07-12 21:52:00+03	59800.00
E8513A	2017-08-02 08:12:00+03	23600.00
E8513C	2017-08-09 14:32:00+03	170000.00
E85156	2017-07-08 10:20:00+03	22000.00
E85187	2017-07-27 08:42:00+03	57800.00
E85196	2017-07-04 22:28:00+03	23600.00
E851DC	2017-08-11 14:48:00+03	86400.00
E851FD	2017-07-27 03:58:00+03	73300.00
E85267	2017-08-04 23:26:00+03	55800.00
E852AB	2017-07-20 23:21:00+03	62900.00
E852D1	2017-08-10 12:37:00+03	203100.00
E8531F	2017-08-14 21:35:00+03	49200.00
E85349	2017-07-07 22:04:00+03	112600.00
E8536F	2017-07-16 01:24:00+03	109400.00
E853A9	2017-07-15 18:24:00+03	20200.00
E85452	2017-08-07 09:24:00+03	43200.00
E85479	2017-07-04 21:31:00+03	58000.00
E8549F	2017-07-04 02:41:00+03	189200.00
E854A8	2017-07-11 14:51:00+03	135200.00
E854B7	2017-07-20 04:21:00+03	44500.00
E85549	2017-07-23 16:21:00+03	26000.00
E85593	2017-08-06 07:21:00+03	111600.00
E855E2	2017-07-05 14:41:00+03	17600.00
E85606	2017-07-09 01:13:00+03	99200.00
E85615	2017-07-30 00:23:00+03	43200.00
E85620	2017-08-15 17:16:00+03	75600.00
E8564F	2017-07-08 22:08:00+03	73900.00
E85684	2017-08-08 15:50:00+03	11800.00
E85746	2017-07-27 06:10:00+03	185600.00
E85755	2017-08-09 21:14:00+03	27400.00
E85762	2017-07-18 22:49:00+03	89200.00
E8576A	2017-07-11 06:56:00+03	150600.00
E85797	2017-07-21 02:07:00+03	68800.00
E857E5	2017-08-05 19:40:00+03	122500.00
E85811	2017-07-01 05:07:00+03	27700.00
E8584E	2017-08-02 01:00:00+03	28200.00
E858B4	2017-07-19 17:52:00+03	59900.00
E858C6	2017-07-13 13:42:00+03	36200.00
E858D1	2017-08-06 13:44:00+03	11200.00
E8593E	2017-07-14 11:39:00+03	12600.00
E859C0	2017-07-25 03:17:00+03	17000.00
E85A53	2017-07-29 08:29:00+03	88000.00
E85AD9	2017-08-15 05:36:00+03	130400.00
E85AF1	2017-07-15 06:08:00+03	73400.00
E85B63	2017-07-19 23:20:00+03	12400.00
E85B9D	2017-08-02 01:23:00+03	542200.00
E85C66	2017-08-09 08:15:00+03	23200.00
E85CB5	2017-07-28 08:39:00+03	33600.00
E85CC4	2017-08-15 15:30:00+03	37900.00
E85CC9	2017-07-27 00:37:00+03	154500.00
E85CEF	2017-07-12 20:03:00+03	20600.00
E85DA5	2017-07-31 17:20:00+03	208000.00
E85E09	2017-07-30 01:58:00+03	113200.00
E85E21	2017-07-29 10:10:00+03	27600.00
E85E4B	2017-08-02 20:54:00+03	10800.00
E85E55	2017-07-26 06:41:00+03	10800.00
E85EBD	2017-07-24 16:26:00+03	38800.00
E85ED7	2017-07-15 09:09:00+03	56000.00
E85EEA	2017-07-04 06:26:00+03	13400.00
E85F08	2017-08-01 22:41:00+03	269400.00
E85F16	2017-07-18 14:47:00+03	45500.00
E85F62	2017-07-31 21:59:00+03	30200.00
E85F99	2017-07-15 05:48:00+03	12600.00
E85FCB	2017-07-31 13:20:00+03	92600.00
E85FE3	2017-08-02 01:20:00+03	9300.00
E85FF2	2017-08-15 05:06:00+03	23200.00
E86055	2017-07-21 10:25:00+03	25600.00
E8607B	2017-08-13 16:41:00+03	35200.00
E8607E	2017-07-19 17:30:00+03	27200.00
E8608B	2017-08-06 12:35:00+03	40400.00
E860DE	2017-08-12 09:48:00+03	30200.00
E86100	2017-07-17 00:18:00+03	6600.00
E86154	2017-08-01 20:51:00+03	22000.00
E861A2	2017-07-20 00:42:00+03	59300.00
E861A4	2017-08-01 07:13:00+03	25600.00
E861CF	2017-07-05 09:19:00+03	46200.00
E8624A	2017-07-08 03:51:00+03	6000.00
E862A3	2017-07-23 00:48:00+03	46300.00
E862C9	2017-07-09 19:34:00+03	37100.00
E862DB	2017-08-06 16:00:00+03	30800.00
E86312	2017-08-02 15:31:00+03	25000.00
E8636C	2017-07-01 01:17:00+03	371700.00
E863C8	2017-07-19 18:16:00+03	56000.00
E863DD	2017-07-09 12:10:00+03	114300.00
E8642B	2017-07-03 14:28:00+03	6700.00
E86482	2017-07-16 21:16:00+03	21000.00
E864AD	2017-07-08 00:09:00+03	28000.00
E864CC	2017-08-12 00:44:00+03	31700.00
E864D0	2017-07-13 07:18:00+03	137400.00
E864E1	2017-08-14 18:13:00+03	21400.00
E864F3	2017-08-12 19:51:00+03	77000.00
E8651A	2017-07-28 02:57:00+03	54200.00
E8653F	2017-07-03 19:46:00+03	481300.00
E86580	2017-07-03 04:38:00+03	119500.00
E86590	2017-07-06 18:32:00+03	70200.00
E865B0	2017-07-25 17:26:00+03	131600.00
E865CC	2017-07-22 22:57:00+03	27200.00
E86600	2017-07-04 22:45:00+03	65600.00
E8661C	2017-07-12 18:23:00+03	39200.00
E86691	2017-07-19 19:08:00+03	30200.00
E866B0	2017-07-02 11:41:00+03	43200.00
E866C8	2017-07-07 07:48:00+03	140900.00
E866CD	2017-06-30 11:19:00+03	12000.00
E8675F	2017-08-11 19:42:00+03	76800.00
E8676F	2017-08-03 03:00:00+03	31800.00
E86786	2017-07-26 14:16:00+03	14000.00
E86797	2017-07-05 22:15:00+03	39500.00
E867B2	2017-07-04 06:32:00+03	28000.00
E867BA	2017-07-27 19:54:00+03	114700.00
E8684E	2017-07-27 06:54:00+03	26000.00
E86852	2017-07-09 11:53:00+03	50600.00
E86860	2017-07-22 22:33:00+03	133100.00
E8686C	2017-08-13 06:57:00+03	199700.00
E868B1	2017-07-12 06:27:00+03	132800.00
E8699C	2017-08-04 00:03:00+03	70800.00
E8699E	2017-08-15 12:13:00+03	82200.00
E869C6	2017-08-14 16:36:00+03	66600.00
E86A22	2017-07-29 03:38:00+03	246000.00
E86B43	2017-07-12 02:51:00+03	136500.00
E86BEA	2017-08-15 13:36:00+03	156600.00
E86BF9	2017-08-07 19:23:00+03	38600.00
E86C21	2017-08-10 09:31:00+03	57500.00
E86C73	2017-08-15 00:40:00+03	42700.00
E86C9B	2017-07-12 14:30:00+03	28000.00
E86CBC	2017-08-13 09:33:00+03	55800.00
E86CED	2017-07-06 19:57:00+03	70700.00
E86CF6	2017-07-20 16:54:00+03	93000.00
E86D6B	2017-06-30 21:44:00+03	270800.00
E86D82	2017-07-29 14:17:00+03	23200.00
E86DA6	2017-07-06 15:09:00+03	164400.00
E86DAC	2017-07-11 08:18:00+03	6800.00
E86E52	2017-07-05 19:31:00+03	265700.00
E86E8A	2017-07-18 17:36:00+03	124200.00
E86EC8	2017-07-30 14:53:00+03	63500.00
E86F31	2017-07-07 20:46:00+03	58700.00
E86F78	2017-07-26 18:13:00+03	266400.00
E86F7B	2017-08-07 04:39:00+03	56000.00
E86F8F	2017-07-16 00:51:00+03	40200.00
E8700F	2017-08-05 07:44:00+03	192700.00
E87013	2017-07-03 09:54:00+03	30100.00
E87068	2017-08-08 14:56:00+03	116000.00
E8706F	2017-07-05 12:32:00+03	31400.00
E8709B	2017-07-13 06:41:00+03	47700.00
E870B3	2017-08-02 02:48:00+03	30200.00
E870D3	2017-07-19 07:35:00+03	185600.00
E87115	2017-07-07 17:24:00+03	52000.00
E87117	2017-07-11 16:18:00+03	28800.00
E8718F	2017-08-03 01:06:00+03	25400.00
E871AE	2017-08-08 17:21:00+03	398400.00
E87285	2017-08-07 00:19:00+03	13600.00
E872D8	2017-07-31 19:00:00+03	73500.00
E87307	2017-07-17 05:59:00+03	67000.00
E87397	2017-08-13 20:25:00+03	55600.00
E8739A	2017-08-14 05:30:00+03	123000.00
E873C5	2017-08-01 02:07:00+03	26000.00
E87407	2017-07-14 20:57:00+03	7400.00
E87465	2017-07-21 01:42:00+03	14400.00
E874EA	2017-07-07 17:06:00+03	28000.00
E8753F	2017-08-11 06:23:00+03	112400.00
E875AC	2017-07-16 04:04:00+03	117200.00
E87640	2017-07-15 14:54:00+03	99200.00
E87643	2017-07-07 04:06:00+03	69600.00
E87681	2017-07-10 01:56:00+03	12600.00
E876C7	2017-08-08 05:26:00+03	80000.00
E876EA	2017-07-20 14:18:00+03	20200.00
E877EB	2017-07-26 06:33:00+03	37200.00
E877FB	2017-07-03 10:45:00+03	406700.00
E8781F	2017-07-18 07:26:00+03	20200.00
E87821	2017-08-13 03:47:00+03	65900.00
E87851	2017-06-30 03:25:00+03	112000.00
E87896	2017-08-13 20:14:00+03	85000.00
E878BD	2017-07-16 20:07:00+03	53400.00
E878ED	2017-07-16 00:46:00+03	85500.00
E8793A	2017-08-14 21:05:00+03	43200.00
E8797E	2017-08-09 16:55:00+03	27200.00
E879DF	2017-07-31 05:08:00+03	6700.00
E879EC	2017-07-09 15:20:00+03	111600.00
E879F5	2017-07-01 13:49:00+03	58400.00
E87A00	2017-07-31 11:03:00+03	177600.00
E87A1F	2017-07-05 23:35:00+03	111600.00
E87A61	2017-08-05 10:43:00+03	135200.00
E87AC3	2017-07-19 06:36:00+03	136500.00
E87AC4	2017-07-24 01:24:00+03	94000.00
E87B8C	2017-08-11 16:28:00+03	59200.00
E87B9A	2017-07-10 03:06:00+03	27200.00
E87BA7	2017-07-25 22:01:00+03	177400.00
E87C18	2017-07-06 23:01:00+03	112000.00
E87CE9	2017-07-10 13:00:00+03	26000.00
E87CFD	2017-07-09 03:39:00+03	19600.00
E87D92	2017-08-09 12:04:00+03	44000.00
E87E3C	2017-07-03 21:08:00+03	188100.00
E87E8A	2017-08-11 00:47:00+03	66600.00
E87F8E	2017-08-08 23:38:00+03	78300.00
E87FC1	2017-08-12 16:47:00+03	22000.00
E87FF4	2017-07-19 12:09:00+03	272300.00
E8800E	2017-08-15 13:33:00+03	73500.00
E88024	2017-07-13 01:48:00+03	33400.00
E8803F	2017-07-21 03:33:00+03	102100.00
E88060	2017-08-08 16:34:00+03	27200.00
E880E4	2017-06-30 13:55:00+03	75000.00
E88133	2017-08-15 06:32:00+03	12600.00
E88174	2017-07-10 16:38:00+03	24300.00
E88194	2017-08-04 14:36:00+03	67900.00
E88198	2017-06-29 22:52:00+03	406200.00
E8821B	2017-08-07 22:06:00+03	123600.00
E88249	2017-07-12 14:38:00+03	46400.00
E882AF	2017-07-14 22:41:00+03	106400.00
E882E7	2017-07-13 18:45:00+03	95700.00
E8831A	2017-08-06 18:41:00+03	89700.00
E883BB	2017-08-08 03:06:00+03	105600.00
E883FD	2017-08-08 22:57:00+03	325500.00
E8840C	2017-07-15 06:47:00+03	168000.00
E88411	2017-07-16 21:22:00+03	168000.00
E88440	2017-07-28 06:47:00+03	88800.00
E8844C	2017-08-04 05:05:00+03	33800.00
E88463	2017-08-06 07:44:00+03	16000.00
E884CA	2017-07-15 16:53:00+03	54400.00
E88501	2017-07-25 21:32:00+03	56000.00
E88505	2017-07-13 23:40:00+03	93600.00
E88531	2017-07-04 17:47:00+03	28000.00
E88584	2017-07-31 20:01:00+03	58600.00
E8859E	2017-07-06 02:52:00+03	56000.00
E885C6	2017-07-08 11:28:00+03	82400.00
E88631	2017-07-08 11:27:00+03	13600.00
E88679	2017-08-09 17:18:00+03	72400.00
E8869D	2017-07-13 14:08:00+03	90600.00
E88733	2017-07-27 15:16:00+03	58000.00
E88771	2017-07-11 00:09:00+03	100600.00
E8877D	2017-07-11 05:56:00+03	47000.00
E887B1	2017-08-14 15:10:00+03	257500.00
E887EE	2017-07-12 11:41:00+03	26000.00
E887FF	2017-08-09 03:45:00+03	38600.00
E88844	2017-07-29 11:49:00+03	140900.00
E88846	2017-07-03 16:41:00+03	73600.00
E8884D	2017-07-22 21:49:00+03	23100.00
E88850	2017-07-14 22:25:00+03	16400.00
E888C1	2017-07-07 07:41:00+03	177200.00
E888F2	2017-08-13 20:12:00+03	69600.00
E88900	2017-07-04 03:36:00+03	158300.00
E88937	2017-07-26 04:03:00+03	10600.00
E88942	2017-08-02 08:52:00+03	78300.00
E88947	2017-08-01 20:14:00+03	20000.00
E889C5	2017-07-11 07:00:00+03	184200.00
E88A06	2017-07-30 20:50:00+03	37500.00
E88A0F	2017-08-09 01:17:00+03	14000.00
E88A23	2017-06-29 01:24:00+03	20800.00
E88A46	2017-07-31 05:27:00+03	117200.00
E88A6E	2017-08-09 11:19:00+03	23400.00
E88A71	2017-07-29 06:53:00+03	51200.00
E88A76	2017-07-15 01:13:00+03	86400.00
E88A9D	2017-07-26 20:31:00+03	92100.00
E88AD0	2017-07-30 05:14:00+03	20400.00
E88BE2	2017-07-10 10:50:00+03	60400.00
E88BF9	2017-08-08 00:11:00+03	6700.00
E88C3F	2017-08-01 05:22:00+03	311200.00
E88C84	2017-07-18 01:43:00+03	92800.00
E88CD0	2017-08-15 02:36:00+03	47400.00
E88CE6	2017-08-08 14:00:00+03	49200.00
E88D1B	2017-07-13 02:54:00+03	62800.00
E88D30	2017-07-11 14:37:00+03	26200.00
E88D96	2017-07-30 17:13:00+03	27900.00
E88DB2	2017-06-30 03:38:00+03	175300.00
E88DDE	2017-08-07 00:07:00+03	35200.00
E88E1A	2017-07-02 10:41:00+03	68800.00
E88E24	2017-08-15 01:36:00+03	68800.00
E88F4E	2017-08-05 14:55:00+03	283100.00
E88F55	2017-07-07 03:15:00+03	41600.00
E88F68	2017-07-22 08:38:00+03	143700.00
E88F70	2017-07-04 07:23:00+03	56000.00
E89027	2017-08-15 04:56:00+03	10800.00
E890F0	2017-07-14 07:00:00+03	52900.00
E89131	2017-07-12 21:34:00+03	111600.00
E89151	2017-06-27 03:12:00+03	92800.00
E891D1	2017-07-18 18:37:00+03	84000.00
E891E1	2017-07-20 17:55:00+03	85800.00
E891F3	2017-07-15 04:45:00+03	112000.00
E89209	2017-08-13 08:28:00+03	28800.00
E89239	2017-07-10 10:40:00+03	17200.00
E89278	2017-07-02 08:06:00+03	32200.00
E892E2	2017-08-04 03:59:00+03	85000.00
E892F0	2017-07-14 14:46:00+03	43300.00
E892FB	2017-07-16 06:44:00+03	101200.00
E89414	2017-07-03 23:56:00+03	133200.00
E894CA	2017-08-09 10:16:00+03	188100.00
E894DB	2017-07-25 20:04:00+03	167400.00
E89510	2017-08-12 04:32:00+03	411700.00
E89557	2017-07-14 12:52:00+03	10800.00
E895B1	2017-07-20 14:28:00+03	6000.00
E8960F	2017-07-07 01:06:00+03	103600.00
E8962C	2017-08-03 19:35:00+03	60600.00
E89652	2017-07-25 04:10:00+03	24400.00
E8965C	2017-07-18 23:05:00+03	135400.00
E89676	2017-08-07 06:01:00+03	81200.00
E896DF	2017-07-29 14:20:00+03	18600.00
E896F5	2017-08-10 19:55:00+03	21400.00
E89715	2017-08-02 03:43:00+03	23200.00
E89792	2017-07-25 20:27:00+03	40800.00
E897F1	2017-07-25 22:15:00+03	26200.00
E89887	2017-07-23 13:07:00+03	37900.00
E898AE	2017-07-03 07:37:00+03	49200.00
E8992A	2017-08-02 18:14:00+03	52800.00
E89950	2017-06-28 01:56:00+03	17600.00
E8998C	2017-07-02 15:17:00+03	11600.00
E899BC	2017-07-30 12:29:00+03	92600.00
E899E0	2017-06-30 07:34:00+03	283100.00
E899F5	2017-07-05 04:18:00+03	111600.00
E89A67	2017-07-20 17:09:00+03	180000.00
E89AB4	2017-07-20 13:55:00+03	93700.00
E89B02	2017-07-05 04:35:00+03	8400.00
E89BF9	2017-08-05 00:26:00+03	66800.00
E89C05	2017-07-21 11:00:00+03	21200.00
E89CA7	2017-07-13 01:59:00+03	57800.00
E89CC2	2017-07-13 21:10:00+03	69500.00
E89CEE	2017-08-10 13:04:00+03	799800.00
E89D39	2017-08-08 12:23:00+03	125700.00
E89D61	2017-07-28 07:38:00+03	21800.00
E89D6D	2017-07-13 09:43:00+03	34000.00
E89D85	2017-06-26 01:11:00+03	55800.00
E89DAB	2017-07-16 15:27:00+03	63200.00
E89DE1	2017-07-14 19:40:00+03	47100.00
E89E22	2017-07-03 17:54:00+03	85700.00
E89E32	2017-07-07 07:40:00+03	136800.00
E89E3E	2017-08-06 20:02:00+03	72600.00
E89E88	2017-07-10 21:22:00+03	62600.00
E89F11	2017-08-15 15:38:00+03	130600.00
E89F28	2017-08-01 06:44:00+03	105600.00
E89F5D	2017-07-23 14:26:00+03	177200.00
E89F80	2017-07-28 03:57:00+03	246000.00
E89FBB	2017-07-07 06:40:00+03	14400.00
E89FF0	2017-07-28 09:43:00+03	94400.00
E8A02B	2017-07-03 20:46:00+03	31400.00
E8A07A	2017-08-05 00:02:00+03	100200.00
E8A087	2017-07-15 13:53:00+03	207200.00
E8A0A8	2017-08-02 04:51:00+03	73600.00
E8A0AB	2017-07-26 03:10:00+03	15900.00
E8A10F	2017-08-02 17:48:00+03	261500.00
E8A113	2017-07-19 10:51:00+03	83000.00
E8A164	2017-07-04 03:25:00+03	16400.00
E8A1AA	2017-08-05 23:07:00+03	51900.00
E8A1F1	2017-07-30 06:41:00+03	87200.00
E8A1F5	2017-07-31 00:12:00+03	17000.00
E8A230	2017-07-26 00:49:00+03	199800.00
E8A249	2017-08-09 19:58:00+03	28800.00
E8A24B	2017-07-09 00:01:00+03	73300.00
E8A28A	2017-07-27 14:43:00+03	102600.00
E8A28D	2017-08-06 02:51:00+03	26000.00
E8A2AB	2017-07-31 13:02:00+03	26000.00
E8A2CF	2017-08-15 03:46:00+03	133600.00
E8A2EF	2017-07-07 04:57:00+03	48500.00
E8A32C	2017-07-22 03:12:00+03	40700.00
E8A336	2017-07-20 12:30:00+03	154800.00
E8A35E	2017-07-10 04:28:00+03	106400.00
E8A364	2017-08-09 02:10:00+03	46400.00
E8A37E	2017-08-11 10:14:00+03	454600.00
E8A3E2	2017-07-02 06:33:00+03	46400.00
E8A486	2017-07-31 16:46:00+03	135400.00
E8A492	2017-07-05 04:11:00+03	133100.00
E8A4B9	2017-06-28 09:28:00+03	11100.00
E8A570	2017-08-13 03:51:00+03	28800.00
E8A5A4	2017-07-14 11:12:00+03	32800.00
E8A60B	2017-07-09 10:33:00+03	33000.00
E8A613	2017-07-15 09:11:00+03	167400.00
E8A638	2017-08-05 05:24:00+03	156500.00
E8A666	2017-06-30 14:58:00+03	46200.00
E8A68A	2017-07-13 01:33:00+03	14000.00
E8A744	2017-08-07 02:20:00+03	54800.00
E8A765	2017-07-25 23:50:00+03	42800.00
E8A78B	2017-07-27 19:34:00+03	40100.00
E8A796	2017-07-20 16:28:00+03	43100.00
E8A7BC	2017-08-07 21:01:00+03	62600.00
E8A7EE	2017-07-02 07:23:00+03	18800.00
E8A7FA	2017-08-05 05:28:00+03	67600.00
E8A870	2017-08-10 22:57:00+03	31000.00
E8A8BE	2017-07-07 05:01:00+03	88000.00
E8A8BF	2017-07-23 19:55:00+03	98300.00
E8A90E	2017-07-24 06:07:00+03	133200.00
E8A947	2017-07-05 01:58:00+03	35300.00
E8A9CC	2017-08-01 02:50:00+03	381000.00
E8AA21	2017-07-17 14:28:00+03	147700.00
E8AABC	2017-08-08 19:05:00+03	29800.00
E8AAD4	2017-07-11 00:07:00+03	23200.00
E8AAF9	2017-07-06 18:32:00+03	24400.00
E8AB6A	2017-07-11 23:22:00+03	31600.00
E8AB82	2017-07-28 23:54:00+03	25100.00
E8ABCE	2017-08-11 19:45:00+03	289800.00
E8AC7F	2017-08-14 08:51:00+03	65500.00
E8ACB4	2017-07-02 09:59:00+03	92000.00
E8ACBB	2017-07-06 00:36:00+03	94000.00
E8ACCC	2017-07-25 15:47:00+03	112600.00
E8ACEC	2017-07-03 15:16:00+03	21800.00
E8AD62	2017-08-11 07:53:00+03	313800.00
E8AD6A	2017-08-02 12:59:00+03	119300.00
E8AD93	2017-07-31 00:03:00+03	98100.00
E8AE01	2017-07-07 21:22:00+03	31400.00
E8AE60	2017-07-18 02:08:00+03	111600.00
E8AE93	2017-07-02 15:54:00+03	47100.00
E8AEA6	2017-07-04 11:24:00+03	93600.00
E8AEEF	2017-07-26 22:35:00+03	88500.00
E8AF5C	2017-07-05 22:17:00+03	47000.00
E8AF67	2017-07-27 12:40:00+03	40800.00
E8AFC8	2017-07-19 01:18:00+03	54500.00
E8AFE5	2017-08-12 20:10:00+03	102100.00
E8AFED	2017-08-15 11:03:00+03	604500.00
E8B008	2017-07-04 12:12:00+03	29200.00
E8B016	2017-08-11 05:15:00+03	71900.00
E8B04F	2017-07-18 16:07:00+03	73200.00
E8B11D	2017-08-08 17:10:00+03	28800.00
E8B11F	2017-07-25 03:48:00+03	13600.00
E8B129	2017-08-11 17:10:00+03	40800.00
E8B171	2017-08-01 07:48:00+03	36200.00
E8B17F	2017-08-02 17:30:00+03	412400.00
E8B1B5	2017-07-27 13:16:00+03	10800.00
E8B1BE	2017-08-12 12:49:00+03	29600.00
E8B1C8	2017-07-07 04:18:00+03	25400.00
E8B1CF	2017-07-14 00:25:00+03	24400.00
E8B1D4	2017-07-11 15:13:00+03	27400.00
E8B1E1	2017-07-12 18:59:00+03	36200.00
E8B21A	2017-07-30 17:04:00+03	66000.00
E8B264	2017-08-04 06:48:00+03	266400.00
E8B2E8	2017-07-15 22:35:00+03	24300.00
E8B305	2017-08-05 22:59:00+03	6300.00
E8B308	2017-08-02 02:47:00+03	56000.00
E8B5D1	2017-08-03 00:45:00+03	266400.00
E8B5E6	2017-07-24 16:20:00+03	75600.00
E8B5FD	2017-07-31 20:04:00+03	196000.00
E8B631	2017-07-07 08:02:00+03	97900.00
E8B646	2017-07-26 15:10:00+03	524600.00
E8B6AE	2017-07-04 22:45:00+03	246000.00
E8B758	2017-07-10 15:22:00+03	18700.00
E8B783	2017-07-20 04:17:00+03	136200.00
E8B7CA	2017-07-14 11:02:00+03	38600.00
E8B83D	2017-08-14 18:16:00+03	248300.00
E8B8B3	2017-08-01 06:26:00+03	28000.00
E8B8DA	2017-08-12 02:03:00+03	23600.00
E8B92E	2017-08-13 15:48:00+03	354400.00
E8B93C	2017-07-09 02:39:00+03	28800.00
E8B93F	2017-07-26 20:26:00+03	183100.00
E8B95C	2017-07-17 21:20:00+03	43200.00
E8B996	2017-07-12 08:33:00+03	12600.00
E8BA31	2017-08-10 18:16:00+03	56100.00
E8BAA9	2017-07-08 22:58:00+03	66600.00
E8BAC7	2017-07-27 05:47:00+03	45200.00
E8BAE1	2017-08-09 08:12:00+03	46700.00
E8BB28	2017-06-30 15:26:00+03	26800.00
E8BB45	2017-07-30 16:46:00+03	92800.00
E8BB52	2017-07-22 12:15:00+03	32800.00
E8BB69	2017-07-07 07:30:00+03	72700.00
E8BC93	2017-07-12 13:34:00+03	39200.00
E8BCFC	2017-06-30 20:03:00+03	6800.00
E8BDF1	2017-07-20 05:24:00+03	76100.00
E8BE16	2017-08-10 16:51:00+03	187800.00
E8BE42	2017-08-08 03:55:00+03	30200.00
E8BE5A	2017-08-01 02:06:00+03	29600.00
E8BE7A	2017-07-03 08:12:00+03	47100.00
E8BE9A	2017-07-20 07:07:00+03	64800.00
E8BEE0	2017-07-22 23:49:00+03	79600.00
E8BF06	2017-07-20 00:42:00+03	30800.00
E8BF15	2017-08-09 08:56:00+03	40600.00
E8BF2E	2017-08-05 21:34:00+03	19600.00
E8BF52	2017-07-20 00:42:00+03	16800.00
E8BF5E	2017-08-11 20:08:00+03	31800.00
E8BF85	2017-07-15 09:00:00+03	516800.00
E8BFC8	2017-07-13 07:33:00+03	40000.00
E8BFD5	2017-07-02 18:02:00+03	56000.00
E8C039	2017-07-10 12:26:00+03	13400.00
E8C03A	2017-08-05 22:52:00+03	28600.00
E8C0B0	2017-07-22 17:36:00+03	58000.00
E8C0FC	2017-07-30 12:08:00+03	23600.00
E8C133	2017-07-07 20:31:00+03	68400.00
E8C142	2017-06-30 09:29:00+03	45200.00
E8C165	2017-07-08 09:37:00+03	173300.00
E8C17E	2017-07-31 01:28:00+03	27200.00
E8C1F1	2017-07-20 02:40:00+03	14800.00
E8C221	2017-08-15 06:29:00+03	99700.00
E8C22D	2017-08-09 10:33:00+03	23200.00
E8C27B	2017-08-08 22:30:00+03	28000.00
E8C299	2017-08-06 21:54:00+03	159300.00
E8C2F5	2017-07-09 10:03:00+03	36200.00
E8C2FE	2017-07-29 19:25:00+03	59900.00
E8C32D	2017-07-30 15:17:00+03	260900.00
E8C355	2017-08-11 17:03:00+03	12600.00
E8C361	2017-07-13 09:07:00+03	50600.00
E8C3D7	2017-07-23 11:46:00+03	56000.00
E8C420	2017-07-15 00:20:00+03	134400.00
E8C440	2017-07-06 00:20:00+03	32800.00
E8C44D	2017-07-27 11:00:00+03	195000.00
E8C475	2017-07-11 13:40:00+03	114700.00
E8C4D2	2017-08-01 14:39:00+03	10800.00
E8C5D0	2017-07-21 18:40:00+03	15900.00
E8C5E5	2017-07-30 17:29:00+03	88800.00
E8C5EF	2017-07-13 15:29:00+03	39100.00
E8C5FF	2017-07-13 04:15:00+03	233000.00
E8C663	2017-08-09 22:29:00+03	54800.00
E8C670	2017-07-29 09:15:00+03	39800.00
E8C77C	2017-08-02 19:33:00+03	66400.00
E8C82E	2017-08-14 18:09:00+03	58700.00
E8C840	2017-07-10 04:52:00+03	52000.00
E8C857	2017-07-16 04:29:00+03	56000.00
E8C87A	2017-08-09 10:38:00+03	13600.00
E8C881	2017-07-26 08:40:00+03	273400.00
E8C8A8	2017-07-17 15:53:00+03	111600.00
E8C8D9	2017-08-11 14:01:00+03	6700.00
E8C8E7	2017-08-12 21:38:00+03	56000.00
E8C8EA	2017-08-03 05:16:00+03	109000.00
E8C8ED	2017-07-18 09:23:00+03	203900.00
E8C933	2017-08-08 10:07:00+03	26000.00
E8CA27	2017-07-13 23:00:00+03	88800.00
E8CA2F	2017-07-16 04:33:00+03	12400.00
E8CA87	2017-08-15 07:41:00+03	26000.00
E8CABF	2017-07-20 20:25:00+03	49100.00
E8CAD0	2017-08-13 10:19:00+03	29400.00
E8CC3B	2017-07-03 03:54:00+03	31600.00
E8CC60	2017-07-23 21:36:00+03	200400.00
E8CC71	2017-07-13 02:18:00+03	48500.00
E8CC75	2017-07-06 17:13:00+03	111600.00
E8CC77	2017-07-14 20:11:00+03	395000.00
E8CC8C	2017-07-07 10:24:00+03	69500.00
E8CCEC	2017-07-19 16:35:00+03	187600.00
E8CD1F	2017-08-11 10:54:00+03	19600.00
E8CD61	2017-07-21 19:11:00+03	63200.00
E8CDA9	2017-07-25 18:17:00+03	135400.00
E8CDC4	2017-08-04 23:44:00+03	37800.00
E8CDD9	2017-08-11 02:55:00+03	73100.00
E8CE08	2017-07-24 09:49:00+03	153300.00
E8CE8E	2017-08-06 13:12:00+03	26000.00
E8CEA7	2017-07-31 20:00:00+03	28000.00
E8CED0	2017-07-07 23:09:00+03	67000.00
E8CF28	2017-07-23 22:23:00+03	16400.00
E8CF3B	2017-07-20 20:46:00+03	39200.00
E8CF9B	2017-07-02 23:53:00+03	23600.00
E8CFB5	2017-07-06 09:10:00+03	148200.00
E8CFBA	2017-08-04 07:14:00+03	342700.00
E8D005	2017-07-24 14:49:00+03	7200.00
E8D053	2017-07-27 20:02:00+03	375200.00
E8D054	2017-08-15 03:55:00+03	25100.00
E8D07D	2017-07-12 05:45:00+03	42000.00
E8D08B	2017-08-15 03:00:00+03	6700.00
E8D17B	2017-07-24 07:52:00+03	94800.00
E8D19C	2017-07-26 00:32:00+03	27300.00
E8D1DD	2017-07-07 23:50:00+03	16400.00
E8D25B	2017-08-06 15:08:00+03	44800.00
E8D286	2017-07-20 09:46:00+03	55800.00
E8D37E	2017-08-12 12:32:00+03	91100.00
E8D3C7	2017-07-29 08:15:00+03	123000.00
E8D42B	2017-07-11 20:23:00+03	13600.00
E8D43A	2017-08-15 12:39:00+03	23400.00
E8D4BE	2017-06-29 12:04:00+03	113100.00
E8D511	2017-07-15 22:36:00+03	58600.00
E8D519	2017-08-04 15:14:00+03	65900.00
E8D583	2017-08-11 21:29:00+03	92400.00
E8D612	2017-07-03 17:33:00+03	37600.00
E8D660	2017-07-14 17:30:00+03	23600.00
E8D69E	2017-08-03 06:55:00+03	89700.00
E8D734	2017-07-25 17:59:00+03	27200.00
E8D77F	2017-07-26 00:01:00+03	73300.00
E8D7C0	2017-07-22 02:17:00+03	67700.00
E8D811	2017-08-07 05:47:00+03	100600.00
E8D8B6	2017-07-23 23:57:00+03	258400.00
E8D8E2	2017-07-18 01:11:00+03	24400.00
E8D903	2017-07-12 14:09:00+03	123600.00
E8D92E	2017-07-01 06:52:00+03	85000.00
E8D948	2017-07-24 20:42:00+03	186000.00
E8D96F	2017-07-09 05:51:00+03	103500.00
E8D9D9	2017-08-07 23:23:00+03	22000.00
E8DA17	2017-08-09 10:10:00+03	35200.00
E8DA18	2017-07-15 23:36:00+03	100800.00
E8DA38	2017-07-16 11:19:00+03	10800.00
E8DA81	2017-07-26 14:44:00+03	225900.00
E8DA86	2017-06-27 21:01:00+03	13000.00
E8DA90	2017-08-07 19:01:00+03	46800.00
E8DAB5	2017-07-09 22:27:00+03	58400.00
E8DB30	2017-07-12 19:14:00+03	15000.00
E8DB46	2017-07-07 06:59:00+03	56600.00
E8DC5B	2017-07-02 11:30:00+03	70600.00
E8DC77	2017-08-10 07:25:00+03	92800.00
E8DCB8	2017-07-23 23:52:00+03	32800.00
E8DD03	2017-07-23 03:25:00+03	6300.00
E8DD52	2017-07-02 17:10:00+03	44200.00
E8DD6E	2017-07-21 18:08:00+03	113900.00
E8DE21	2017-08-12 03:35:00+03	22000.00
E8DE43	2017-07-09 23:56:00+03	119700.00
E8DE7E	2017-08-10 21:15:00+03	111600.00
E8DE80	2017-08-14 08:48:00+03	43200.00
E8DEA0	2017-06-28 23:04:00+03	88500.00
E8DEBD	2017-07-10 20:08:00+03	28000.00
E8DEC5	2017-07-18 04:37:00+03	114800.00
E8DECE	2017-07-22 19:53:00+03	39200.00
E8DEFD	2017-08-02 22:42:00+03	98400.00
E8DF42	2017-07-30 05:12:00+03	13700.00
E8DF63	2017-07-15 12:34:00+03	27800.00
E8DFE2	2017-07-20 21:20:00+03	62600.00
E8E032	2017-07-31 15:12:00+03	67600.00
E8E034	2017-07-19 19:40:00+03	23600.00
E8E067	2017-07-24 07:41:00+03	90400.00
E8E096	2017-07-27 10:11:00+03	58800.00
E8E0D7	2017-07-14 10:51:00+03	303200.00
E8E11F	2017-07-30 21:32:00+03	20200.00
E8E17B	2017-07-20 14:48:00+03	84100.00
E8E19F	2017-07-26 00:49:00+03	64800.00
E8E1CF	2017-08-09 08:46:00+03	20400.00
E8E1E9	2017-07-29 19:16:00+03	51900.00
E8E22C	2017-07-30 17:12:00+03	11300.00
E8E231	2017-08-01 23:44:00+03	43500.00
E8E241	2017-07-20 13:09:00+03	68400.00
E8E266	2017-07-28 01:07:00+03	28000.00
E8E2D2	2017-08-01 02:48:00+03	28000.00
E8E32F	2017-08-10 00:44:00+03	56000.00
E8E3C7	2017-07-08 20:47:00+03	432600.00
E8E3F1	2017-08-07 02:38:00+03	31200.00
E8E3F4	2017-08-11 12:59:00+03	208100.00
E8E44A	2017-07-23 10:24:00+03	318300.00
E8E49B	2017-08-09 04:33:00+03	122300.00
E8E4C9	2017-07-19 14:06:00+03	86600.00
E8E4F9	2017-08-02 07:23:00+03	166000.00
E8E509	2017-07-20 01:43:00+03	119600.00
E8E523	2017-07-30 20:16:00+03	6000.00
E8E53C	2017-07-03 02:45:00+03	56600.00
E8E581	2017-07-31 06:43:00+03	51600.00
E8E5CB	2017-07-24 06:05:00+03	38800.00
E8E611	2017-07-17 21:43:00+03	58200.00
E8E61A	2017-07-30 23:37:00+03	39600.00
E8E63A	2017-07-04 19:59:00+03	15800.00
E8E668	2017-08-06 04:54:00+03	30200.00
E8E6A5	2017-07-12 03:08:00+03	693500.00
E8E6F3	2017-07-23 10:34:00+03	139100.00
E8E700	2017-07-31 18:10:00+03	43500.00
E8E71B	2017-07-20 03:55:00+03	89600.00
E8E74F	2017-08-07 12:31:00+03	58800.00
E8E7A5	2017-07-10 10:19:00+03	246000.00
E8E7C1	2017-07-20 03:55:00+03	67100.00
E8E7C4	2017-08-12 04:41:00+03	69500.00
E8E7F1	2017-08-13 11:51:00+03	92700.00
E8E876	2017-08-01 10:25:00+03	87100.00
E8E882	2017-07-03 07:51:00+03	316000.00
E8E890	2017-07-21 06:38:00+03	23200.00
E8E91E	2017-07-30 16:58:00+03	93900.00
E8E954	2017-08-03 01:00:00+03	32800.00
E8E96E	2017-08-06 00:48:00+03	114800.00
E8E97E	2017-07-16 09:14:00+03	264600.00
E8E989	2017-07-21 02:37:00+03	57600.00
E8E9B2	2017-08-10 07:17:00+03	103600.00
E8EA10	2017-07-25 10:36:00+03	246000.00
E8EA74	2017-07-11 14:25:00+03	252200.00
E8EAA9	2017-08-11 02:45:00+03	140900.00
E8EABC	2017-07-16 15:20:00+03	43200.00
E8EB8F	2017-08-05 13:57:00+03	46200.00
E8EB93	2017-08-09 03:48:00+03	8600.00
E8EBD7	2017-07-01 07:03:00+03	124200.00
E8EC07	2017-07-09 16:12:00+03	73600.00
E8EC5D	2017-07-15 07:46:00+03	117200.00
E8EC66	2017-07-01 12:48:00+03	23200.00
E8EC6B	2017-07-30 00:22:00+03	55800.00
E8ECF1	2017-08-08 11:17:00+03	56000.00
E8ED08	2017-07-28 10:18:00+03	48300.00
E8ED80	2017-07-13 15:52:00+03	67600.00
E8ED94	2017-07-02 13:01:00+03	43600.00
E8EE82	2017-07-28 09:15:00+03	73300.00
E8EEEB	2017-07-07 02:53:00+03	27200.00
E8EF2E	2017-08-08 07:56:00+03	26000.00
E8EF35	2017-07-24 12:44:00+03	316200.00
E8EF47	2017-07-30 22:19:00+03	55800.00
E8F042	2017-07-17 20:32:00+03	81300.00
E8F046	2017-07-01 08:41:00+03	57300.00
E8F09D	2017-08-11 10:01:00+03	75600.00
E8F164	2017-07-10 21:58:00+03	24400.00
E8F1BD	2017-07-05 21:52:00+03	90800.00
E8F1F6	2017-07-09 17:58:00+03	265700.00
E8F236	2017-08-15 11:27:00+03	9800.00
E8F339	2017-08-10 09:12:00+03	55800.00
E8F3F5	2017-08-15 11:08:00+03	43900.00
E8F424	2017-08-08 15:16:00+03	32100.00
E8F459	2017-06-30 06:59:00+03	46900.00
E8F4E0	2017-08-01 12:39:00+03	28000.00
E8F4F6	2017-07-07 11:38:00+03	50600.00
E8F534	2017-08-09 00:41:00+03	62600.00
E8F543	2017-08-05 14:33:00+03	135600.00
E8F5CE	2017-08-01 22:46:00+03	23200.00
E8F622	2017-07-05 07:43:00+03	52700.00
E8F670	2017-08-12 20:50:00+03	101200.00
E8F67E	2017-07-10 13:12:00+03	78100.00
E8F6D1	2017-08-14 22:09:00+03	78500.00
E8F736	2017-07-22 20:22:00+03	40000.00
E8F80C	2017-07-16 15:00:00+03	51200.00
E8F850	2017-08-09 07:11:00+03	73500.00
E8F861	2017-07-26 09:53:00+03	138900.00
E8F8CC	2017-08-12 16:35:00+03	25200.00
E8F8D1	2017-07-11 21:23:00+03	46000.00
E8F8E3	2017-07-19 00:05:00+03	97900.00
E8F917	2017-08-08 23:48:00+03	21200.00
E8F939	2017-07-26 13:59:00+03	25600.00
E8F96C	2017-07-12 09:21:00+03	17000.00
E8F9CD	2017-08-14 11:44:00+03	133100.00
E8F9E3	2017-07-30 01:54:00+03	265700.00
E8FA32	2017-07-21 06:09:00+03	15000.00
E8FA37	2017-07-26 00:46:00+03	38600.00
E8FA68	2017-07-28 12:56:00+03	19600.00
E8FA89	2017-08-08 12:42:00+03	179500.00
E8FAB3	2017-07-22 13:28:00+03	83000.00
E8FAB9	2017-07-29 09:11:00+03	45200.00
E8FAF0	2017-08-12 04:42:00+03	43400.00
E8FB46	2017-08-02 05:39:00+03	56600.00
E8FB99	2017-06-24 23:59:00+03	77000.00
E8FBD0	2017-07-24 01:04:00+03	41400.00
E8FBF2	2017-07-26 00:14:00+03	49400.00
E8FCAD	2017-07-12 22:28:00+03	49800.00
E8FD45	2017-08-01 23:52:00+03	64700.00
E8FD65	2017-08-15 13:15:00+03	8200.00
E8FD9E	2017-07-10 08:43:00+03	49400.00
E8FDB9	2017-08-01 21:32:00+03	55800.00
E8FF75	2017-07-31 12:59:00+03	13600.00
E9003E	2017-08-08 21:02:00+03	6700.00
E9007A	2017-07-02 10:45:00+03	270800.00
E900B8	2017-07-19 13:44:00+03	136200.00
E900ED	2017-07-16 11:05:00+03	49600.00
E9011E	2017-07-21 05:29:00+03	57800.00
E90132	2017-07-05 06:25:00+03	21400.00
E90147	2017-08-11 20:24:00+03	73200.00
E901BF	2017-07-04 12:08:00+03	66600.00
E9020D	2017-07-23 19:57:00+03	40400.00
E90226	2017-07-26 03:14:00+03	59800.00
E90287	2017-07-05 15:22:00+03	50800.00
E902A7	2017-07-20 22:44:00+03	72400.00
E902CE	2017-07-06 23:59:00+03	32700.00
E903A6	2017-07-15 08:56:00+03	64000.00
E903D7	2017-07-28 12:24:00+03	40400.00
E903EE	2017-08-14 00:57:00+03	118800.00
E903F0	2017-08-13 17:18:00+03	39100.00
E90421	2017-08-05 21:14:00+03	32800.00
E90444	2017-08-15 14:32:00+03	27300.00
E90478	2017-07-19 18:39:00+03	58400.00
E904C9	2017-07-22 04:51:00+03	86600.00
E90533	2017-08-14 08:31:00+03	22600.00
E9054D	2017-07-02 17:23:00+03	99300.00
E90556	2017-08-02 00:57:00+03	49100.00
E90573	2017-07-21 01:42:00+03	55800.00
E905AB	2017-07-06 08:51:00+03	74400.00
E905B4	2017-08-06 00:41:00+03	103300.00
E905E1	2017-08-13 12:34:00+03	167400.00
E90613	2017-07-24 08:27:00+03	32800.00
E90670	2017-07-26 11:11:00+03	65200.00
E906BC	2017-07-23 21:30:00+03	28800.00
E90743	2017-08-10 02:01:00+03	137700.00
E907F8	2017-08-01 07:04:00+03	179200.00
E90836	2017-07-05 04:44:00+03	39400.00
E90857	2017-07-17 15:27:00+03	58000.00
E90876	2017-07-16 05:36:00+03	20400.00
E90884	2017-07-13 00:11:00+03	93700.00
E90893	2017-08-09 18:09:00+03	25000.00
E9089C	2017-07-06 16:52:00+03	84100.00
E908AB	2017-07-07 02:13:00+03	25200.00
E908F2	2017-08-11 14:05:00+03	112000.00
E90918	2017-07-31 13:05:00+03	85000.00
E90941	2017-07-23 17:54:00+03	40800.00
E90948	2017-07-21 16:29:00+03	48500.00
E909D0	2017-07-13 19:20:00+03	306600.00
E90A01	2017-07-09 23:56:00+03	30700.00
E90A93	2017-07-29 20:07:00+03	88100.00
E90AEC	2017-07-05 07:59:00+03	28000.00
E90B46	2017-08-05 18:48:00+03	91800.00
E90B86	2017-07-24 00:12:00+03	39200.00
E90BF1	2017-07-07 19:41:00+03	285600.00
E90C31	2017-07-18 13:02:00+03	57600.00
E90C45	2017-07-10 02:47:00+03	57500.00
E90C54	2017-07-26 20:53:00+03	119500.00
E90C75	2017-08-01 17:23:00+03	47000.00
E90C7F	2017-07-30 03:13:00+03	40800.00
E90E40	2017-06-25 03:49:00+03	34000.00
E90E75	2017-08-06 10:22:00+03	56000.00
E90EFD	2017-08-08 09:55:00+03	66400.00
E90F18	2017-07-26 14:24:00+03	133100.00
E90F1E	2017-07-28 17:37:00+03	15700.00
E90F88	2017-07-02 15:39:00+03	24300.00
E90F8F	2017-07-28 03:31:00+03	168700.00
E90FDF	2017-07-11 19:01:00+03	61200.00
E9102D	2017-07-27 06:15:00+03	138100.00
E910CE	2017-07-21 06:06:00+03	86400.00
E91179	2017-08-08 03:09:00+03	26200.00
E91215	2017-08-05 03:23:00+03	26000.00
E9129B	2017-07-28 13:12:00+03	410800.00
E91323	2017-07-11 16:58:00+03	43100.00
E91338	2017-08-14 23:48:00+03	130900.00
E9134D	2017-08-14 02:08:00+03	67600.00
E9136B	2017-07-27 02:55:00+03	34400.00
E91441	2017-08-05 03:53:00+03	29600.00
E914F7	2017-07-19 22:25:00+03	12400.00
E9150B	2017-08-07 23:00:00+03	37900.00
E9150C	2017-07-02 14:16:00+03	55800.00
E91523	2017-08-13 04:59:00+03	157400.00
E9159B	2017-07-07 04:30:00+03	163100.00
E916F1	2017-07-10 13:04:00+03	38800.00
E91708	2017-08-15 00:36:00+03	86200.00
E9173B	2017-08-12 20:19:00+03	14400.00
E91795	2017-07-17 22:13:00+03	37200.00
E917D1	2017-07-27 11:56:00+03	15000.00
E917D5	2017-08-03 10:45:00+03	43900.00
E91821	2017-08-11 11:49:00+03	83700.00
E9182F	2017-07-21 03:59:00+03	14000.00
E91845	2017-07-02 04:33:00+03	33200.00
E9187C	2017-07-14 19:22:00+03	25600.00
E91881	2017-07-15 02:50:00+03	50800.00
E9188D	2017-07-24 17:40:00+03	16800.00
E918B9	2017-07-13 07:34:00+03	57700.00
E91917	2017-08-10 21:53:00+03	50200.00
E91928	2017-08-06 20:18:00+03	143100.00
E91967	2017-08-01 22:42:00+03	88900.00
E91A60	2017-07-04 01:29:00+03	380200.00
E91A83	2017-07-18 18:25:00+03	61800.00
E91A91	2017-07-08 20:10:00+03	53700.00
E91AC9	2017-07-13 03:46:00+03	311900.00
E91B14	2017-07-08 11:44:00+03	67600.00
E91B15	2017-08-01 08:22:00+03	59800.00
E91B1F	2017-08-10 21:42:00+03	82900.00
E91BB0	2017-07-06 17:38:00+03	68200.00
E91C02	2017-08-01 00:09:00+03	65100.00
E91C15	2017-07-07 00:15:00+03	25600.00
E91C8D	2017-08-13 12:00:00+03	59600.00
E91CEC	2017-07-15 14:14:00+03	67400.00
E91D01	2017-07-16 14:13:00+03	36200.00
E91D33	2017-07-02 09:10:00+03	22200.00
E91D5B	2017-08-15 09:28:00+03	16400.00
E91D5F	2017-07-29 20:37:00+03	39200.00
E91D6C	2017-07-14 05:22:00+03	55800.00
E91DA6	2017-08-04 11:49:00+03	16400.00
E91DBA	2017-07-12 21:04:00+03	58400.00
E91DBB	2017-07-19 16:10:00+03	40900.00
E91DDA	2017-08-12 03:20:00+03	67100.00
E91E30	2017-07-24 17:14:00+03	55800.00
E91E3D	2017-07-16 15:35:00+03	248400.00
E91EB9	2017-07-12 10:26:00+03	66600.00
E91EFA	2017-08-12 19:09:00+03	74900.00
E91F17	2017-07-20 15:06:00+03	40600.00
E91F2F	2017-07-17 21:21:00+03	56100.00
E91F38	2017-07-17 10:45:00+03	18000.00
E91F73	2017-07-05 15:33:00+03	52000.00
E91F7B	2017-08-11 19:55:00+03	26200.00
E91F8D	2017-08-14 08:53:00+03	112000.00
E91F90	2017-07-23 23:39:00+03	38400.00
E91FA1	2017-07-14 16:55:00+03	99000.00
E91FF9	2017-08-07 22:14:00+03	38600.00
E91FFA	2017-07-29 00:21:00+03	92100.00
E9207E	2017-07-09 02:30:00+03	59800.00
E920A4	2017-07-08 00:49:00+03	208800.00
E920DF	2017-07-06 06:41:00+03	40800.00
E920FA	2017-07-20 20:28:00+03	97900.00
E92121	2017-07-14 03:15:00+03	41400.00
E9224D	2017-07-22 01:29:00+03	112000.00
E92260	2017-07-25 06:00:00+03	399600.00
E922B4	2017-08-10 18:42:00+03	62100.00
E922BE	2017-07-25 12:38:00+03	23100.00
E922D8	2017-07-30 14:41:00+03	56600.00
E922F5	2017-08-13 22:31:00+03	58600.00
E92358	2017-07-09 04:09:00+03	149300.00
E9236E	2017-07-02 01:57:00+03	56000.00
E923CD	2017-07-22 12:14:00+03	108100.00
E92496	2017-07-17 15:56:00+03	281500.00
E924B6	2017-07-17 16:26:00+03	187600.00
E92548	2017-07-08 10:29:00+03	135400.00
E92596	2017-07-07 04:45:00+03	6700.00
E925B9	2017-07-10 02:42:00+03	28800.00
E925DB	2017-07-22 16:28:00+03	233000.00
E92619	2017-08-13 10:42:00+03	135400.00
E9266F	2017-08-13 08:37:00+03	32800.00
E926D2	2017-07-23 15:07:00+03	55800.00
E926EE	2017-08-13 15:13:00+03	44000.00
E926F3	2017-08-12 01:33:00+03	67600.00
E92726	2017-07-04 12:12:00+03	8200.00
E92765	2017-07-27 17:35:00+03	26800.00
E927E6	2017-07-07 18:00:00+03	84500.00
E9281D	2017-07-16 11:09:00+03	46000.00
E928DB	2017-08-09 12:55:00+03	111600.00
E928EB	2017-07-11 15:18:00+03	61800.00
E92929	2017-08-05 02:12:00+03	8000.00
E9296D	2017-07-16 10:50:00+03	26800.00
E92998	2017-07-25 14:04:00+03	99700.00
E92A11	2017-07-12 12:30:00+03	61800.00
E92A12	2017-07-13 01:31:00+03	27300.00
E92A26	2017-07-11 00:14:00+03	16400.00
E92A78	2017-07-10 04:31:00+03	65000.00
E92AFE	2017-08-01 10:51:00+03	56600.00
E92B01	2017-07-22 19:16:00+03	131600.00
E92B68	2017-07-20 01:54:00+03	54000.00
E92B6A	2017-07-29 05:28:00+03	99200.00
E92B8B	2017-08-03 02:27:00+03	58000.00
E92C1A	2017-08-10 02:59:00+03	57400.00
E92C36	2017-07-18 18:34:00+03	46700.00
E92D2C	2017-08-01 18:58:00+03	57500.00
E92D47	2017-07-05 07:08:00+03	15000.00
E92D4C	2017-07-15 01:41:00+03	149400.00
E92D56	2017-07-31 02:36:00+03	67500.00
E92D93	2017-07-17 07:51:00+03	101200.00
E92DD3	2017-07-02 16:21:00+03	63200.00
E92E3B	2017-08-11 17:01:00+03	136200.00
E92ECA	2017-06-29 03:12:00+03	55800.00
E92F11	2017-08-09 13:25:00+03	18600.00
E92F16	2017-07-21 07:18:00+03	163300.00
E92F82	2017-07-13 03:36:00+03	78300.00
E92FF8	2017-07-26 01:44:00+03	22000.00
E93041	2017-07-11 17:05:00+03	38600.00
E930B4	2017-07-27 09:38:00+03	83000.00
E93149	2017-07-06 14:30:00+03	70500.00
E9314A	2017-07-20 03:21:00+03	396100.00
E93159	2017-07-20 08:37:00+03	393000.00
E931B7	2017-07-10 15:33:00+03	13400.00
E9320A	2017-07-14 12:59:00+03	66600.00
E932DC	2017-07-02 06:37:00+03	188800.00
E9332E	2017-08-04 19:35:00+03	46400.00
E93347	2017-07-20 22:41:00+03	56900.00
E9334F	2017-07-25 06:08:00+03	76800.00
E93362	2017-07-06 06:41:00+03	24200.00
E93372	2017-07-06 11:29:00+03	78200.00
E933D3	2017-07-20 21:35:00+03	77200.00
E933DA	2017-07-27 14:59:00+03	21400.00
E933E7	2017-07-31 08:41:00+03	112600.00
E933F4	2017-07-15 02:03:00+03	115800.00
E9346E	2017-07-22 03:29:00+03	27600.00
E9347E	2017-08-08 07:42:00+03	42800.00
E934A2	2017-07-16 15:36:00+03	41200.00
E934B8	2017-07-26 19:10:00+03	67600.00
E934F3	2017-07-12 15:20:00+03	47800.00
E93537	2017-08-03 18:34:00+03	22000.00
E93574	2017-08-14 16:01:00+03	109400.00
E9357C	2017-07-10 12:14:00+03	114900.00
E935E7	2017-08-03 01:18:00+03	28000.00
E93637	2017-07-30 13:16:00+03	22200.00
E9365B	2017-08-07 13:29:00+03	170000.00
E936A4	2017-08-05 18:54:00+03	103500.00
E936DC	2017-07-13 05:04:00+03	47000.00
E9377C	2017-07-01 04:15:00+03	87300.00
E937FA	2017-07-14 04:20:00+03	199200.00
E93806	2017-07-25 09:19:00+03	45100.00
E9387A	2017-07-29 23:37:00+03	54500.00
E93912	2017-07-08 20:30:00+03	116000.00
E93931	2017-07-01 13:57:00+03	34400.00
E93970	2017-07-15 11:55:00+03	40800.00
E93A36	2017-08-14 20:58:00+03	43800.00
E93A51	2017-07-09 01:28:00+03	20600.00
E93B1F	2017-07-17 17:30:00+03	106700.00
E93B42	2017-07-21 12:24:00+03	49500.00
E93B5A	2017-08-01 00:08:00+03	16400.00
E93B90	2017-07-26 16:51:00+03	16400.00
E93BE2	2017-07-12 22:14:00+03	73400.00
E93C33	2017-07-27 23:31:00+03	38600.00
E93C95	2017-07-29 03:41:00+03	59800.00
E93CBC	2017-08-12 06:22:00+03	56000.00
E93D25	2017-08-13 09:36:00+03	43400.00
E93D44	2017-06-30 13:48:00+03	27900.00
E93D67	2017-08-15 13:28:00+03	48700.00
E93D6D	2017-08-12 11:57:00+03	88900.00
E93DE1	2017-07-20 17:26:00+03	7400.00
E93E2B	2017-07-30 05:51:00+03	31600.00
E93E5F	2017-07-13 18:03:00+03	23200.00
E93E81	2017-07-27 00:06:00+03	135400.00
E93E91	2017-07-11 11:14:00+03	125400.00
E93EF7	2017-07-21 23:37:00+03	123000.00
E93F12	2017-07-23 17:01:00+03	34000.00
E93F44	2017-08-10 11:34:00+03	23200.00
E93F77	2017-07-09 13:31:00+03	67200.00
E93F78	2017-08-03 12:39:00+03	28800.00
E93FE6	2017-08-08 16:30:00+03	270700.00
E9402E	2017-08-01 06:46:00+03	38400.00
E9409E	2017-07-24 15:38:00+03	114200.00
E940CB	2017-07-16 07:11:00+03	35700.00
E94102	2017-07-03 01:58:00+03	96400.00
E94106	2017-08-06 12:59:00+03	48600.00
E941A9	2017-07-07 12:03:00+03	61800.00
E941AF	2017-07-04 16:26:00+03	23200.00
E941C0	2017-07-03 03:36:00+03	230900.00
E94206	2017-07-28 14:30:00+03	397500.00
E94272	2017-07-14 05:39:00+03	119800.00
E94281	2017-08-01 21:57:00+03	43900.00
E942B3	2017-08-03 09:40:00+03	14000.00
E9437C	2017-06-27 14:27:00+03	27300.00
E9438C	2017-08-11 15:56:00+03	8400.00
E943E4	2017-06-28 15:31:00+03	62700.00
E94460	2017-07-30 03:32:00+03	22400.00
E94489	2017-07-25 20:41:00+03	28800.00
E94495	2017-08-01 19:45:00+03	43000.00
E9451C	2017-07-12 09:54:00+03	56600.00
E9452E	2017-07-11 04:19:00+03	14400.00
E94555	2017-08-14 01:18:00+03	21800.00
E94670	2017-08-09 18:45:00+03	67600.00
E9468B	2017-07-21 07:01:00+03	23600.00
E946A6	2017-07-03 06:02:00+03	111600.00
E946EC	2017-07-29 13:09:00+03	40600.00
E946F4	2017-07-15 04:50:00+03	257600.00
E94731	2017-07-18 20:35:00+03	16000.00
E947A5	2017-07-09 12:30:00+03	23400.00
E94814	2017-07-07 02:54:00+03	10800.00
E94825	2017-07-28 13:56:00+03	39300.00
E94872	2017-07-18 21:31:00+03	67200.00
E9490A	2017-08-05 23:46:00+03	13800.00
E94933	2017-07-02 14:39:00+03	36200.00
E949A6	2017-08-13 11:50:00+03	26000.00
E949F0	2017-08-13 03:01:00+03	12400.00
E94A4D	2017-07-19 10:22:00+03	42700.00
E94AD7	2017-08-05 23:01:00+03	6300.00
E94B1E	2017-07-19 07:28:00+03	56600.00
E94B7E	2017-07-08 10:31:00+03	38600.00
E94BAD	2017-07-12 15:53:00+03	102800.00
E94BEE	2017-07-31 06:25:00+03	36700.00
E94D97	2017-07-31 08:32:00+03	37900.00
E94DE9	2017-08-11 18:51:00+03	6300.00
E94DFB	2017-07-11 21:46:00+03	46400.00
E94E11	2017-08-01 04:22:00+03	8000.00
E94E21	2017-07-04 18:30:00+03	163100.00
E94E31	2017-07-21 22:18:00+03	266400.00
E94E36	2017-08-09 19:10:00+03	114400.00
E94E3C	2017-07-26 04:00:00+03	40600.00
E94EB8	2017-06-29 05:28:00+03	32500.00
E94ED0	2017-07-04 20:25:00+03	75800.00
E94EE2	2017-07-06 00:08:00+03	53600.00
E94F20	2017-07-07 14:10:00+03	65900.00
E94F22	2017-06-29 02:34:00+03	68400.00
E94F24	2017-07-30 18:37:00+03	31100.00
E94F26	2017-08-01 09:47:00+03	184000.00
E94FB7	2017-07-29 04:24:00+03	25800.00
E95006	2017-07-13 14:47:00+03	8000.00
E9506E	2017-07-30 15:00:00+03	143400.00
E950CB	2017-07-05 22:56:00+03	133100.00
E950F6	2017-07-10 16:18:00+03	7400.00
E9510C	2017-07-14 22:43:00+03	136200.00
E95171	2017-07-25 13:34:00+03	141100.00
E951B9	2017-07-05 06:38:00+03	6300.00
E95238	2017-07-02 21:59:00+03	639800.00
E95289	2017-07-11 12:03:00+03	55800.00
E95291	2017-07-19 03:26:00+03	131600.00
E952C9	2017-07-18 21:10:00+03	14800.00
E952EB	2017-06-30 11:32:00+03	25000.00
E95309	2017-07-25 16:46:00+03	38200.00
E9534C	2017-07-12 23:13:00+03	30200.00
E95350	2017-07-14 08:32:00+03	32700.00
E95377	2017-08-14 14:13:00+03	75600.00
E95388	2017-07-31 20:47:00+03	46400.00
E953B3	2017-07-05 20:17:00+03	28000.00
E9545A	2017-07-19 10:22:00+03	38600.00
E954DF	2017-07-15 21:45:00+03	131600.00
E9555E	2017-07-02 04:46:00+03	93900.00
E95579	2017-07-27 22:55:00+03	46400.00
E955B2	2017-07-07 18:41:00+03	54800.00
E955E7	2017-08-03 02:27:00+03	113000.00
E955FD	2017-08-10 02:21:00+03	13400.00
E956D3	2017-08-03 10:04:00+03	32800.00
E95706	2017-07-20 16:20:00+03	45200.00
E95717	2017-07-20 10:06:00+03	54800.00
E95773	2017-08-01 13:14:00+03	34000.00
E957BE	2017-06-30 13:05:00+03	148200.00
E957D5	2017-07-08 05:55:00+03	72200.00
E95872	2017-08-12 19:36:00+03	43700.00
E9587F	2017-07-11 15:54:00+03	66200.00
E958DA	2017-08-03 22:50:00+03	49100.00
E958DC	2017-08-07 03:32:00+03	53400.00
E958F4	2017-07-01 09:25:00+03	170000.00
E959A8	2017-07-04 18:05:00+03	46000.00
E95A16	2017-07-02 22:39:00+03	28800.00
E95A32	2017-07-14 19:57:00+03	29600.00
E95A63	2017-07-24 05:10:00+03	81600.00
E95A98	2017-07-22 15:09:00+03	141600.00
E95AB8	2017-07-26 17:22:00+03	81000.00
E95AC3	2017-07-02 10:56:00+03	103500.00
E95AE2	2017-07-30 09:33:00+03	22000.00
E95B6B	2017-07-13 13:15:00+03	75600.00
E95BF7	2017-07-23 04:38:00+03	64800.00
E95BFF	2017-07-14 21:02:00+03	136200.00
E95C1B	2017-07-24 22:06:00+03	28800.00
E95C46	2017-08-14 13:33:00+03	65900.00
E95C4F	2017-08-07 15:04:00+03	177200.00
E95C7B	2017-08-09 09:55:00+03	12400.00
E95C9F	2017-08-03 18:56:00+03	65600.00
E95CC1	2017-07-04 20:23:00+03	31400.00
E95D24	2017-07-15 20:46:00+03	24400.00
E95D31	2017-07-29 17:20:00+03	21400.00
E95D6F	2017-08-07 03:16:00+03	341900.00
E95E47	2017-07-17 13:35:00+03	86800.00
E95E7C	2017-07-19 19:53:00+03	26000.00
E95ED5	2017-07-26 00:30:00+03	13000.00
E95EF7	2017-07-14 07:04:00+03	44500.00
E95EF8	2017-07-10 06:42:00+03	39800.00
E95F68	2017-07-18 05:49:00+03	153000.00
E95F78	2017-06-30 20:38:00+03	46000.00
E95F7E	2017-08-04 01:16:00+03	131000.00
E95FDD	2017-07-25 21:16:00+03	40800.00
E9600E	2017-08-08 05:56:00+03	46000.00
E96038	2017-07-20 07:17:00+03	26000.00
E960B1	2017-08-10 04:32:00+03	32900.00
E96137	2017-07-12 09:35:00+03	49100.00
E961AF	2017-08-14 00:54:00+03	27200.00
E96214	2017-07-28 19:37:00+03	26000.00
E96246	2017-07-08 11:26:00+03	135200.00
E96269	2017-08-14 05:44:00+03	66700.00
E962B0	2017-06-28 09:00:00+03	69000.00
E962C4	2017-08-02 17:04:00+03	68400.00
E962CF	2017-08-09 16:09:00+03	14000.00
E962DF	2017-08-06 10:17:00+03	246000.00
E96312	2017-07-01 09:00:00+03	24400.00
E96363	2017-08-12 12:04:00+03	68800.00
E963EE	2017-07-30 10:33:00+03	32800.00
E96445	2017-07-07 13:50:00+03	136200.00
E96452	2017-06-30 10:48:00+03	65300.00
E9647C	2017-07-04 01:16:00+03	134700.00
E964A0	2017-07-19 07:00:00+03	47600.00
E964E4	2017-07-28 21:23:00+03	85600.00
E964FA	2017-07-26 21:08:00+03	56600.00
E9653B	2017-07-02 22:24:00+03	90800.00
E96554	2017-07-12 20:02:00+03	42400.00
E966EC	2017-07-18 20:08:00+03	49100.00
E966F0	2017-08-05 09:48:00+03	46800.00
E966FF	2017-07-19 05:59:00+03	116400.00
E96750	2017-08-11 20:57:00+03	156500.00
E96792	2017-08-07 23:32:00+03	13400.00
E967C6	2017-06-29 07:11:00+03	97900.00
E9680E	2017-07-18 14:08:00+03	35200.00
E96847	2017-07-18 18:35:00+03	29400.00
E9684C	2017-07-21 04:31:00+03	67200.00
E96879	2017-07-06 16:58:00+03	69500.00
E968D5	2017-07-21 13:15:00+03	283100.00
E968DE	2017-07-14 02:17:00+03	29000.00
E96940	2017-07-22 11:36:00+03	29400.00
E969DC	2017-08-07 01:21:00+03	131600.00
E96A40	2017-07-19 19:44:00+03	26700.00
E96A42	2017-07-29 10:21:00+03	12600.00
E96C13	2017-08-03 10:46:00+03	23200.00
E96C72	2017-07-08 03:56:00+03	52400.00
E96CEF	2017-07-29 20:27:00+03	24800.00
E96CFC	2017-08-05 11:37:00+03	32700.00
E96D00	2017-07-15 22:44:00+03	58800.00
E96D22	2017-07-15 19:39:00+03	39800.00
E96D7B	2017-07-13 10:51:00+03	89700.00
E96DF3	2017-08-14 18:03:00+03	135000.00
E96E44	2017-08-12 19:16:00+03	46000.00
E96E75	2017-07-18 14:42:00+03	105700.00
E96EA2	2017-07-16 15:00:00+03	52800.00
E96ED2	2017-07-15 06:25:00+03	31400.00
E96EE8	2017-08-07 09:21:00+03	90600.00
E96F2B	2017-07-11 17:19:00+03	32800.00
E96FDB	2017-07-19 21:34:00+03	47400.00
E97002	2017-07-31 09:47:00+03	32700.00
E9702E	2017-08-02 13:29:00+03	28800.00
E9710C	2017-06-27 12:09:00+03	141600.00
E97136	2017-07-16 14:12:00+03	32800.00
E97167	2017-06-29 20:44:00+03	12400.00
E971A4	2017-08-15 14:14:00+03	39700.00
E971A6	2017-07-11 10:43:00+03	46400.00
E971FD	2017-07-17 11:39:00+03	54000.00
E9722E	2017-08-08 14:39:00+03	102400.00
E9728D	2017-07-29 13:33:00+03	12000.00
E9728F	2017-07-31 03:12:00+03	26200.00
E9734C	2017-07-30 09:56:00+03	46400.00
E9738E	2017-07-04 15:47:00+03	50400.00
E973E8	2017-07-07 22:12:00+03	50000.00
E973F6	2017-07-17 04:29:00+03	115000.00
E973F8	2017-07-26 22:24:00+03	66400.00
E974E2	2017-07-31 16:43:00+03	23200.00
E974FE	2017-07-18 21:13:00+03	68800.00
E9756E	2017-07-04 08:35:00+03	16400.00
E975A6	2017-07-14 01:39:00+03	32100.00
E97608	2017-07-09 04:50:00+03	98400.00
E97632	2017-08-11 01:56:00+03	56000.00
E9767E	2017-08-11 10:26:00+03	93900.00
E976B2	2017-07-07 02:01:00+03	83400.00
E9773C	2017-07-06 05:29:00+03	43200.00
E97749	2017-08-14 14:11:00+03	135200.00
E9774F	2017-07-30 08:32:00+03	49000.00
E9775D	2017-07-29 16:12:00+03	128300.00
E97768	2017-07-16 09:52:00+03	6300.00
E9778C	2017-07-18 05:53:00+03	23400.00
E97834	2017-07-13 07:17:00+03	47700.00
E978D8	2017-07-16 12:36:00+03	57400.00
E978E3	2017-07-15 15:03:00+03	43200.00
E97939	2017-08-12 13:39:00+03	46400.00
E97975	2017-07-05 09:38:00+03	32400.00
E979C9	2017-07-13 23:31:00+03	179200.00
E979D9	2017-08-10 16:56:00+03	249100.00
E979EF	2017-07-31 13:20:00+03	102400.00
E979FF	2017-07-16 01:36:00+03	12600.00
E97A0F	2017-07-27 06:01:00+03	40100.00
E97A18	2017-07-20 03:03:00+03	72400.00
E97A1B	2017-07-27 04:56:00+03	8200.00
E97A20	2017-08-12 11:51:00+03	44500.00
E97A52	2017-07-11 21:59:00+03	46400.00
E97A58	2017-07-17 10:18:00+03	106400.00
E97AA5	2017-08-04 09:30:00+03	48100.00
E97B43	2017-08-10 02:08:00+03	62600.00
E97B5F	2017-08-08 19:14:00+03	79600.00
E97B82	2017-08-11 13:01:00+03	12000.00
E97B8F	2017-07-23 04:51:00+03	21800.00
E97BF2	2017-07-12 01:06:00+03	73900.00
E97C47	2017-07-14 01:00:00+03	61800.00
E97C5B	2017-07-09 05:12:00+03	137700.00
E97C60	2017-07-25 10:30:00+03	56000.00
E97CEE	2017-07-13 03:06:00+03	65400.00
E97CFA	2017-07-14 04:41:00+03	6700.00
E97D54	2017-07-03 07:09:00+03	187800.00
E97D6D	2017-07-29 05:51:00+03	25800.00
E97D79	2017-07-27 10:56:00+03	123000.00
E97D8B	2017-07-31 02:03:00+03	56100.00
E97DF2	2017-07-09 20:32:00+03	27400.00
E97E74	2017-08-13 04:46:00+03	20800.00
E97E9F	2017-08-14 03:23:00+03	327000.00
E97EC2	2017-07-16 08:54:00+03	30400.00
E97F13	2017-08-15 13:49:00+03	12000.00
E97F1F	2017-08-01 16:44:00+03	39200.00
E97F64	2017-07-29 17:17:00+03	123000.00
E97F75	2017-07-14 20:03:00+03	67000.00
E97F96	2017-07-28 09:47:00+03	19600.00
E97FE1	2017-07-25 04:28:00+03	60400.00
E9804B	2017-07-15 14:40:00+03	50000.00
E9806D	2017-07-19 02:18:00+03	23200.00
E980CE	2017-07-13 18:13:00+03	23200.00
E9811C	2017-07-31 06:11:00+03	87200.00
E9814D	2017-07-16 10:49:00+03	291000.00
E9818E	2017-07-16 00:31:00+03	47100.00
E98291	2017-07-19 04:55:00+03	25100.00
E982AE	2017-07-30 01:37:00+03	246000.00
E98317	2017-07-04 15:35:00+03	11700.00
E9833C	2017-08-13 13:34:00+03	14800.00
E98366	2017-08-13 05:07:00+03	15000.00
E983A8	2017-08-01 03:09:00+03	93900.00
E98451	2017-08-02 22:20:00+03	45200.00
E98468	2017-08-09 06:11:00+03	32800.00
E9846A	2017-07-18 18:32:00+03	26800.00
E984B8	2017-08-14 11:17:00+03	24400.00
E984BC	2017-06-30 07:17:00+03	23600.00
E984D3	2017-07-09 21:46:00+03	20400.00
E984E0	2017-06-29 09:40:00+03	21400.00
E984E8	2017-08-05 04:37:00+03	24000.00
E98573	2017-08-05 21:39:00+03	46400.00
E9857A	2017-08-10 20:56:00+03	57500.00
E985EF	2017-08-01 03:16:00+03	20500.00
E98622	2017-08-07 14:09:00+03	44700.00
E98629	2017-07-19 10:38:00+03	87000.00
E986A9	2017-07-03 03:03:00+03	88600.00
E986C2	2017-07-27 08:48:00+03	60700.00
E986DA	2017-08-13 18:25:00+03	94300.00
E986E3	2017-08-11 11:38:00+03	36200.00
E98785	2017-07-15 10:32:00+03	40600.00
E98799	2017-08-13 02:35:00+03	70700.00
E987D4	2017-07-27 17:02:00+03	89600.00
E987F2	2017-07-04 06:03:00+03	131800.00
E987FE	2017-07-05 16:36:00+03	86500.00
E98804	2017-06-30 18:21:00+03	108000.00
E98820	2017-07-11 17:49:00+03	71900.00
E9886F	2017-08-01 11:31:00+03	88600.00
E988B9	2017-08-05 08:17:00+03	46300.00
E988BE	2017-07-17 20:33:00+03	28000.00
E98968	2017-07-23 04:54:00+03	12600.00
E98976	2017-07-02 19:42:00+03	255600.00
E98978	2017-06-29 21:46:00+03	168000.00
E989B1	2017-07-30 19:20:00+03	11000.00
E98A13	2017-07-22 11:26:00+03	112000.00
E98A70	2017-08-13 15:16:00+03	272300.00
E98A8E	2017-08-07 11:29:00+03	13400.00
E98ACD	2017-07-07 10:17:00+03	21000.00
E98B67	2017-08-07 09:21:00+03	81300.00
E98BDF	2017-07-11 10:50:00+03	46200.00
E98C23	2017-07-04 00:46:00+03	19900.00
E98C24	2017-08-08 16:14:00+03	406100.00
E98C50	2017-07-15 14:41:00+03	100000.00
E98C67	2017-08-14 12:08:00+03	23400.00
E98C6B	2017-07-16 20:34:00+03	67200.00
E98CF0	2017-08-02 21:25:00+03	27800.00
E98D11	2017-07-27 16:28:00+03	23600.00
E98D1F	2017-07-10 02:50:00+03	21400.00
E98D66	2017-07-23 12:24:00+03	65900.00
E98D89	2017-08-08 06:07:00+03	29600.00
E98E01	2017-08-13 03:09:00+03	28800.00
E98E0F	2017-07-10 18:16:00+03	59100.00
E98E26	2017-07-26 01:39:00+03	336100.00
E98EB4	2017-07-14 00:24:00+03	148200.00
E98EEB	2017-08-10 04:04:00+03	48100.00
E98FE0	2017-07-26 02:35:00+03	250600.00
E98FF6	2017-07-11 20:52:00+03	66600.00
E9901C	2017-07-29 20:10:00+03	27200.00
E99046	2017-08-10 16:56:00+03	30200.00
E99063	2017-07-04 11:11:00+03	195000.00
E990D7	2017-08-04 16:10:00+03	27700.00
E9912F	2017-07-31 15:07:00+03	140500.00
E99139	2017-07-21 02:46:00+03	69400.00
E99140	2017-07-06 16:58:00+03	94900.00
E99179	2017-07-01 18:11:00+03	167400.00
E99182	2017-08-15 15:30:00+03	56100.00
E9922E	2017-07-21 02:28:00+03	6700.00
E9925D	2017-07-10 19:45:00+03	87200.00
E99275	2017-07-06 04:46:00+03	31600.00
E992D7	2017-07-21 03:18:00+03	44100.00
E9931B	2017-07-06 03:44:00+03	23600.00
E99357	2017-08-02 21:58:00+03	12600.00
E99363	2017-07-18 16:45:00+03	24200.00
E99377	2017-07-28 13:36:00+03	40000.00
E993B7	2017-08-04 18:42:00+03	85600.00
E99482	2017-07-06 03:35:00+03	75600.00
E9948D	2017-07-17 03:36:00+03	8200.00
E9949B	2017-07-03 06:29:00+03	73200.00
E9952A	2017-07-10 07:36:00+03	68900.00
E995C7	2017-07-16 03:53:00+03	68100.00
E995DB	2017-06-28 06:03:00+03	61300.00
E99615	2017-06-25 03:27:00+03	237200.00
E99641	2017-07-19 00:42:00+03	92800.00
E9967E	2017-07-02 15:30:00+03	46800.00
E9969B	2017-08-14 01:03:00+03	21000.00
E996A7	2017-08-06 06:48:00+03	37600.00
E996B6	2017-07-21 22:59:00+03	117600.00
E996E9	2017-08-14 06:16:00+03	47100.00
E996FB	2017-07-04 13:34:00+03	23400.00
E99702	2017-08-08 12:37:00+03	44700.00
E99749	2017-08-07 14:03:00+03	79900.00
E99791	2017-08-11 17:00:00+03	23600.00
E9981F	2017-07-15 10:24:00+03	62800.00
E99870	2017-07-26 01:42:00+03	150600.00
E9989F	2017-08-14 21:07:00+03	40800.00
E998AA	2017-06-29 13:31:00+03	36200.00
E998B1	2017-07-04 18:10:00+03	40400.00
E998E1	2017-07-31 14:07:00+03	55800.00
E9990F	2017-07-16 04:05:00+03	12600.00
E99979	2017-08-15 01:06:00+03	23600.00
E99A06	2017-08-02 16:14:00+03	28000.00
E99A2C	2017-07-26 05:12:00+03	56000.00
E99A35	2017-07-13 17:52:00+03	126000.00
E99AA2	2017-07-31 21:38:00+03	110300.00
E99AEC	2017-08-09 05:54:00+03	47600.00
E99B94	2017-07-12 02:50:00+03	22600.00
E99BF5	2017-08-01 15:07:00+03	50600.00
E99C73	2017-07-25 00:52:00+03	125200.00
E99C74	2017-08-11 10:20:00+03	231800.00
E99C9E	2017-07-24 06:05:00+03	167400.00
E99CED	2017-07-02 03:57:00+03	71900.00
E99D00	2017-07-22 10:28:00+03	46400.00
E99D14	2017-07-04 04:49:00+03	57600.00
E99D6F	2017-07-06 09:32:00+03	6800.00
E99D85	2017-08-03 05:13:00+03	41400.00
E99D93	2017-07-15 19:38:00+03	146300.00
E99E1F	2017-07-02 06:18:00+03	38400.00
E99E42	2017-08-13 15:06:00+03	166100.00
E99E45	2017-07-04 18:15:00+03	135400.00
E99EAD	2017-08-03 21:48:00+03	56000.00
E99EBD	2017-08-13 18:24:00+03	43900.00
E99EE2	2017-07-25 01:44:00+03	48400.00
E99F38	2017-07-25 13:57:00+03	47100.00
E99F6E	2017-07-02 20:57:00+03	32700.00
E99FFA	2017-07-04 05:46:00+03	93900.00
E99FFE	2017-08-03 05:59:00+03	11900.00
E9A0D8	2017-07-17 17:30:00+03	117800.00
E9A0E2	2017-07-11 05:39:00+03	26800.00
E9A13B	2017-07-30 01:10:00+03	26800.00
E9A14A	2017-07-30 21:44:00+03	285000.00
E9A151	2017-07-22 11:13:00+03	99600.00
E9A15B	2017-07-11 05:58:00+03	252000.00
E9A1CA	2017-08-06 06:35:00+03	27400.00
E9A1EC	2017-07-26 01:45:00+03	54800.00
E9A22B	2017-08-13 20:07:00+03	42100.00
E9A28D	2017-07-05 05:47:00+03	88500.00
E9A2EF	2017-07-26 09:14:00+03	67400.00
E9A31B	2017-07-17 15:57:00+03	224000.00
E9A36F	2017-08-01 22:36:00+03	72000.00
E9A382	2017-07-30 09:03:00+03	71400.00
E9A3A0	2017-08-09 05:33:00+03	56000.00
E9A3B1	2017-08-11 11:21:00+03	191400.00
E9A3BD	2017-07-09 11:49:00+03	46000.00
E9A3F4	2017-07-23 17:08:00+03	110400.00
E9A44F	2017-07-29 14:59:00+03	166000.00
E9A490	2017-08-13 16:33:00+03	35800.00
E9A49A	2017-07-15 13:40:00+03	229900.00
E9A4DD	2017-07-30 07:55:00+03	35400.00
E9A521	2017-08-09 13:39:00+03	281500.00
E9A525	2017-08-07 18:06:00+03	42700.00
E9A52B	2017-08-02 23:53:00+03	136500.00
E9A5C6	2017-07-06 05:18:00+03	133200.00
E9A5FF	2017-07-22 04:25:00+03	26200.00
E9A683	2017-07-20 23:04:00+03	99200.00
E9A68F	2017-08-10 01:19:00+03	38600.00
E9A693	2017-07-17 11:31:00+03	31900.00
E9A6EC	2017-07-04 16:52:00+03	59800.00
E9A737	2017-08-14 16:45:00+03	16400.00
E9A78F	2017-07-16 19:47:00+03	167400.00
E9A7AF	2017-07-01 05:07:00+03	14800.00
E9A7CD	2017-07-23 22:41:00+03	47000.00
E9A7D9	2017-07-05 02:46:00+03	18000.00
E9A802	2017-07-02 23:12:00+03	30400.00
E9A850	2017-07-11 08:22:00+03	58200.00
E9A870	2017-08-01 05:27:00+03	40000.00
E9A872	2017-07-18 05:09:00+03	112000.00
E9A886	2017-08-07 21:42:00+03	58000.00
E9A8CD	2017-07-10 18:36:00+03	88100.00
E9A8CE	2017-08-09 11:20:00+03	135400.00
E9A919	2017-07-17 23:18:00+03	104600.00
E9A939	2017-08-15 05:32:00+03	84100.00
E9A953	2017-07-13 17:03:00+03	27200.00
E9A96A	2017-07-18 02:56:00+03	56600.00
E9A97C	2017-08-10 21:52:00+03	36200.00
E9AA2C	2017-07-01 05:30:00+03	67600.00
E9AA3E	2017-08-13 20:25:00+03	50900.00
E9AA78	2017-07-17 17:15:00+03	39800.00
E9AA8B	2017-07-16 12:01:00+03	51500.00
E9AAB1	2017-07-03 04:50:00+03	242700.00
E9AACA	2017-06-30 04:00:00+03	29600.00
E9AAEC	2017-08-12 19:12:00+03	27200.00
E9AB2B	2017-08-05 01:23:00+03	11600.00
E9AB32	2017-08-14 03:59:00+03	68800.00
E9AB48	2017-07-18 12:31:00+03	27200.00
E9AB53	2017-07-03 09:10:00+03	55600.00
E9AC2D	2017-07-05 14:19:00+03	30800.00
E9AC6C	2017-07-14 12:57:00+03	63000.00
E9ACC0	2017-08-11 07:17:00+03	13400.00
E9ACDB	2017-08-14 20:57:00+03	48100.00
E9AD3C	2017-07-16 02:19:00+03	58400.00
E9ADAE	2017-08-04 00:15:00+03	6600.00
E9AEC7	2017-07-12 20:31:00+03	64800.00
E9AED1	2017-07-12 23:27:00+03	84000.00
E9AF53	2017-07-25 04:49:00+03	265800.00
E9AF5A	2017-07-07 07:39:00+03	130400.00
E9AF5B	2017-08-01 17:23:00+03	22000.00
E9AFD7	2017-08-13 04:27:00+03	26700.00
E9AFFA	2017-07-10 01:12:00+03	79900.00
E9B057	2017-07-08 00:48:00+03	46800.00
E9B061	2017-07-03 15:15:00+03	26000.00
E9B0D5	2017-07-11 11:50:00+03	124400.00
E9B109	2017-07-08 08:18:00+03	289800.00
E9B10A	2017-07-16 15:26:00+03	191700.00
E9B12E	2017-08-01 16:25:00+03	27200.00
E9B1A6	2017-08-12 14:40:00+03	149300.00
E9B1B1	2017-07-24 07:52:00+03	21400.00
E9B2C3	2017-07-12 10:47:00+03	193300.00
E9B313	2017-08-10 16:05:00+03	53200.00
E9B318	2017-07-06 16:07:00+03	99200.00
E9B339	2017-07-28 15:44:00+03	46800.00
E9B390	2017-07-01 20:25:00+03	17200.00
E9B3B3	2017-07-17 22:51:00+03	143100.00
E9B48C	2017-07-08 21:49:00+03	56000.00
E9B4A7	2017-07-11 20:24:00+03	6700.00
E9B52F	2017-08-03 09:42:00+03	81600.00
E9B59F	2017-07-19 22:07:00+03	49800.00
E9B5B4	2017-08-02 00:10:00+03	422700.00
E9B5DC	2017-08-08 00:03:00+03	10300.00
E9B62E	2017-06-30 07:20:00+03	55800.00
E9B668	2017-08-14 02:14:00+03	171900.00
E9B66D	2017-08-09 01:13:00+03	25400.00
E9B70C	2017-07-17 10:04:00+03	50600.00
E9B757	2017-07-31 16:56:00+03	36200.00
E9B7C7	2017-07-28 06:53:00+03	32200.00
E9B7E4	2017-07-28 22:10:00+03	43700.00
E9B889	2017-08-13 00:40:00+03	16400.00
E9B89F	2017-07-13 12:41:00+03	23200.00
E9B91F	2017-08-08 15:54:00+03	14400.00
E9B92E	2017-07-01 11:08:00+03	369000.00
E9B983	2017-07-21 03:10:00+03	48800.00
E9B9A1	2017-08-09 03:29:00+03	66600.00
E9B9A8	2017-07-14 00:25:00+03	28000.00
E9BAA5	2017-07-14 17:50:00+03	12600.00
E9BAB3	2017-08-01 06:44:00+03	106400.00
E9BB1B	2017-08-07 22:22:00+03	6300.00
E9BB26	2017-07-19 23:30:00+03	31400.00
E9BBC3	2017-08-08 16:44:00+03	81500.00
E9BC7B	2017-07-05 04:06:00+03	219300.00
E9BCFC	2017-07-17 17:12:00+03	50900.00
E9BD04	2017-07-21 17:11:00+03	283100.00
E9BD5B	2017-06-30 10:38:00+03	99200.00
E9BE17	2017-07-10 21:40:00+03	24800.00
E9BE53	2017-08-05 22:26:00+03	22000.00
E9BE65	2017-07-06 10:19:00+03	25800.00
E9BE7A	2017-07-04 15:06:00+03	16400.00
E9BE9D	2017-07-18 12:14:00+03	191000.00
E9BF11	2017-07-22 00:01:00+03	24700.00
E9BF93	2017-07-28 20:16:00+03	23200.00
E9BFB7	2017-08-09 22:38:00+03	199600.00
E9BFBB	2017-08-12 12:03:00+03	54800.00
E9C025	2017-08-11 14:29:00+03	56600.00
E9C091	2017-08-12 04:45:00+03	112000.00
E9C0C7	2017-07-15 05:39:00+03	248500.00
E9C0E5	2017-07-24 16:51:00+03	29500.00
E9C158	2017-07-30 19:53:00+03	20200.00
E9C173	2017-07-30 22:43:00+03	30200.00
E9C1F6	2017-08-13 01:06:00+03	123000.00
E9C208	2017-06-30 05:58:00+03	52400.00
E9C23C	2017-07-06 04:49:00+03	60000.00
E9C250	2017-08-06 16:32:00+03	63200.00
E9C2F1	2017-07-16 11:39:00+03	54300.00
E9C2F9	2017-07-10 02:09:00+03	6000.00
E9C376	2017-07-26 04:38:00+03	117100.00
E9C3D6	2017-07-19 03:24:00+03	56600.00
E9C402	2017-07-23 05:47:00+03	8400.00
E9C405	2017-08-12 14:46:00+03	12000.00
E9C40C	2017-07-11 11:55:00+03	43500.00
E9C42C	2017-08-15 00:20:00+03	266400.00
E9C449	2017-07-29 17:03:00+03	31000.00
E9C486	2017-08-15 11:58:00+03	36100.00
E9C4C7	2017-07-23 19:06:00+03	134900.00
E9C4D1	2017-07-31 07:15:00+03	156300.00
E9C4FE	2017-07-28 15:20:00+03	39300.00
E9C551	2017-07-20 12:05:00+03	6600.00
E9C558	2017-07-23 02:37:00+03	14000.00
E9C5BB	2017-08-12 05:15:00+03	179500.00
E9C5C8	2017-08-03 04:27:00+03	47200.00
E9C5FA	2017-07-13 22:16:00+03	26000.00
E9C63B	2017-08-07 02:43:00+03	46200.00
E9C674	2017-08-05 21:47:00+03	226200.00
E9C6A3	2017-08-09 03:32:00+03	22600.00
E9C72B	2017-07-04 03:10:00+03	38200.00
E9C74D	2017-07-18 23:30:00+03	43300.00
E9C76B	2017-07-27 23:21:00+03	89600.00
E9C7A9	2017-08-01 00:32:00+03	40800.00
E9C7BC	2017-07-05 09:14:00+03	26800.00
E9C7C4	2017-08-13 20:58:00+03	42800.00
E9C7DB	2017-07-23 15:38:00+03	64700.00
E9C80C	2017-07-04 07:27:00+03	30200.00
E9C847	2017-08-01 05:23:00+03	27300.00
E9C8CE	2017-07-24 02:24:00+03	13800.00
E9C8ED	2017-07-17 15:29:00+03	21400.00
E9C936	2017-08-11 02:28:00+03	77900.00
E9C94B	2017-07-18 08:01:00+03	277000.00
E9C994	2017-07-26 10:32:00+03	55800.00
E9C9FE	2017-07-21 17:44:00+03	39200.00
E9CA0D	2017-07-05 05:54:00+03	14400.00
E9CB8D	2017-07-15 13:02:00+03	23200.00
E9CB94	2017-07-10 03:43:00+03	57400.00
E9CBE6	2017-08-07 22:23:00+03	68000.00
E9CC02	2017-07-26 01:55:00+03	23400.00
E9CC31	2017-08-12 00:33:00+03	58800.00
E9CC57	2017-08-09 16:31:00+03	31100.00
E9CCCB	2017-08-04 11:11:00+03	39800.00
E9CCEA	2017-07-20 14:03:00+03	8600.00
E9CCFB	2017-08-15 11:04:00+03	133700.00
E9CE92	2017-07-16 01:19:00+03	162200.00
E9CECE	2017-08-06 07:20:00+03	85800.00
E9CF32	2017-07-07 08:24:00+03	198600.00
E9CF59	2017-08-12 20:02:00+03	98400.00
E9CF92	2017-07-28 03:33:00+03	133100.00
E9CFAC	2017-08-12 06:47:00+03	137800.00
E9CFD8	2017-07-28 05:12:00+03	432500.00
E9CFE4	2017-08-07 13:23:00+03	108200.00
E9CFFF	2017-07-21 01:47:00+03	75300.00
E9D006	2017-07-17 22:03:00+03	67200.00
E9D064	2017-07-22 19:30:00+03	410800.00
E9D129	2017-07-24 13:24:00+03	51400.00
E9D135	2017-07-07 08:58:00+03	67000.00
E9D14E	2017-07-06 12:41:00+03	100600.00
E9D16D	2017-07-01 14:12:00+03	531400.00
E9D1CD	2017-07-18 20:42:00+03	141800.00
E9D21F	2017-07-17 13:56:00+03	62700.00
E9D223	2017-07-01 20:47:00+03	28800.00
E9D22C	2017-08-01 17:40:00+03	48800.00
E9D243	2017-07-20 21:58:00+03	58600.00
E9D264	2017-08-08 08:51:00+03	49200.00
E9D301	2017-07-27 17:32:00+03	115900.00
E9D32A	2017-07-29 11:31:00+03	111600.00
E9D331	2017-08-08 11:38:00+03	105600.00
E9D35C	2017-07-01 03:17:00+03	65900.00
E9D368	2017-08-08 18:30:00+03	71300.00
E9D376	2017-07-12 15:25:00+03	46000.00
E9D40A	2017-08-02 18:36:00+03	60600.00
E9D437	2017-07-22 17:12:00+03	47100.00
E9D50C	2017-07-10 19:16:00+03	97000.00
E9D53E	2017-08-04 11:56:00+03	266400.00
E9D599	2017-07-23 14:08:00+03	290600.00
E9D62D	2017-07-03 03:39:00+03	136100.00
E9D62F	2017-07-25 03:18:00+03	35200.00
E9D6AD	2017-08-10 23:05:00+03	116000.00
E9D6B6	2017-07-08 12:45:00+03	62700.00
E9D6C3	2017-07-06 23:18:00+03	19600.00
E9D6F7	2017-07-12 22:08:00+03	26100.00
E9D72B	2017-07-30 02:11:00+03	12400.00
E9D76D	2017-07-13 06:45:00+03	30400.00
E9D76E	2017-08-02 19:04:00+03	74800.00
E9D778	2017-08-01 09:43:00+03	88800.00
E9D77E	2017-07-22 13:35:00+03	27200.00
E9D780	2017-08-14 13:31:00+03	48000.00
E9D78E	2017-08-12 14:11:00+03	144700.00
E9D7AB	2017-07-11 23:09:00+03	191200.00
E9D7F4	2017-06-30 23:39:00+03	38200.00
E9D7F7	2017-07-23 23:21:00+03	369000.00
E9D88A	2017-07-23 05:01:00+03	14800.00
E9D93D	2017-08-13 23:34:00+03	12600.00
E9D976	2017-08-12 17:31:00+03	44800.00
E9D9A2	2017-08-02 22:32:00+03	48700.00
E9DA19	2017-07-01 22:46:00+03	50600.00
E9DA31	2017-07-19 18:34:00+03	99300.00
E9DA59	2017-07-21 09:37:00+03	26200.00
E9DA5E	2017-07-13 14:12:00+03	20200.00
E9DAB4	2017-08-08 03:49:00+03	65300.00
E9DAB7	2017-07-14 23:39:00+03	24400.00
E9DB1E	2017-07-16 08:32:00+03	38600.00
E9DB41	2017-07-20 12:51:00+03	119700.00
E9DB50	2017-07-23 22:26:00+03	119800.00
E9DB5F	2017-07-31 09:32:00+03	123000.00
E9DB7A	2017-08-14 08:16:00+03	21800.00
E9DBBC	2017-07-20 20:03:00+03	97800.00
E9DBF2	2017-07-17 08:46:00+03	133200.00
E9DC19	2017-07-31 18:42:00+03	36200.00
E9DC61	2017-07-25 05:42:00+03	46400.00
E9DC65	2017-06-30 06:15:00+03	67200.00
E9DC94	2017-07-01 22:42:00+03	28100.00
E9DD13	2017-08-12 17:43:00+03	238800.00
E9DD2D	2017-07-31 00:02:00+03	21400.00
E9DD36	2017-07-08 23:01:00+03	62800.00
E9DD65	2017-07-28 13:47:00+03	206400.00
E9DD9D	2017-07-16 04:12:00+03	26800.00
E9DDE0	2017-08-08 22:57:00+03	60400.00
E9DE3D	2017-08-14 23:42:00+03	22000.00
E9DEA2	2017-08-09 21:38:00+03	85000.00
E9DEDD	2017-07-23 17:49:00+03	3700.00
E9DF8D	2017-08-05 01:17:00+03	155200.00
E9DF8E	2017-07-27 14:25:00+03	32200.00
E9DFAE	2017-08-13 19:21:00+03	28800.00
E9DFB7	2017-08-02 05:57:00+03	87400.00
E9DFEC	2017-07-21 12:32:00+03	149200.00
E9E02D	2017-07-26 05:42:00+03	26800.00
E9E0AF	2017-07-15 19:55:00+03	28800.00
E9E0FD	2017-06-29 19:35:00+03	25200.00
E9E117	2017-08-01 23:42:00+03	7400.00
E9E15A	2017-07-01 07:59:00+03	3400.00
E9E180	2017-07-06 18:05:00+03	73600.00
E9E1EF	2017-07-04 13:28:00+03	198400.00
E9E20A	2017-07-12 13:24:00+03	199700.00
E9E2B9	2017-06-30 13:41:00+03	20400.00
E9E2CD	2017-07-13 07:24:00+03	28800.00
E9E34D	2017-07-27 15:25:00+03	266400.00
E9E382	2017-07-23 14:55:00+03	43600.00
E9E38E	2017-07-02 14:38:00+03	35800.00
E9E397	2017-07-30 20:19:00+03	50600.00
E9E39D	2017-07-04 16:19:00+03	25000.00
E9E442	2017-08-05 09:56:00+03	30000.00
E9E518	2017-07-03 12:12:00+03	167400.00
E9E56B	2017-07-25 20:37:00+03	28000.00
E9E5A6	2017-08-05 17:19:00+03	266200.00
E9E5DE	2017-07-14 06:00:00+03	23200.00
E9E60A	2017-07-28 00:55:00+03	232200.00
E9E675	2017-07-17 11:36:00+03	135200.00
E9E69A	2017-08-14 15:04:00+03	73500.00
E9E6B4	2017-08-15 06:11:00+03	27200.00
E9E6EB	2017-08-03 04:40:00+03	189800.00
E9E704	2017-06-30 16:35:00+03	36200.00
E9E74D	2017-07-03 19:47:00+03	55800.00
E9E784	2017-07-15 00:45:00+03	38800.00
E9E7CE	2017-08-14 15:30:00+03	56000.00
E9E7D8	2017-07-04 12:15:00+03	91500.00
E9E832	2017-08-09 14:40:00+03	62600.00
E9E836	2017-07-25 01:36:00+03	66600.00
E9E87A	2017-07-04 19:56:00+03	26700.00
E9E8FB	2017-07-30 00:43:00+03	104000.00
E9E915	2017-08-07 05:24:00+03	78600.00
E9E924	2017-08-14 01:09:00+03	182600.00
E9E99F	2017-08-14 22:17:00+03	64300.00
E9E9F0	2017-07-24 05:26:00+03	58700.00
E9EA83	2017-07-12 05:28:00+03	42800.00
E9EACF	2017-07-19 18:38:00+03	39800.00
E9EAE1	2017-07-20 23:00:00+03	94000.00
E9EB10	2017-07-19 12:39:00+03	43100.00
E9EB4A	2017-08-01 20:21:00+03	56900.00
E9EB90	2017-07-11 16:51:00+03	112000.00
E9EBB6	2017-08-09 18:38:00+03	67200.00
E9EBCB	2017-07-12 08:13:00+03	185100.00
E9EBE5	2017-07-02 04:36:00+03	139500.00
E9EBE7	2017-07-30 07:56:00+03	16400.00
E9EBEB	2017-07-22 07:29:00+03	42000.00
E9EC1C	2017-07-16 00:26:00+03	124200.00
E9EC4C	2017-07-20 07:06:00+03	22600.00
E9EC64	2017-08-08 02:49:00+03	28000.00
E9EDEC	2017-07-28 20:53:00+03	69500.00
E9EE3B	2017-07-05 01:39:00+03	67900.00
E9EE5A	2017-08-15 16:33:00+03	221000.00
E9EEEB	2017-07-08 04:15:00+03	162600.00
E9EF0E	2017-07-25 01:01:00+03	52400.00
E9EF1F	2017-07-11 10:20:00+03	68400.00
E9EF34	2017-06-30 10:10:00+03	26000.00
E9EFB4	2017-08-13 15:55:00+03	56100.00
E9EFCB	2017-07-09 21:05:00+03	64500.00
E9F00C	2017-07-14 15:23:00+03	43900.00
E9F01B	2017-07-25 12:58:00+03	26100.00
E9F036	2017-07-01 19:39:00+03	62800.00
E9F049	2017-08-09 05:53:00+03	87400.00
E9F068	2017-08-14 14:38:00+03	51900.00
E9F0A3	2017-08-08 06:52:00+03	27300.00
E9F0A8	2017-07-11 10:40:00+03	123000.00
E9F0B4	2017-08-06 04:15:00+03	101400.00
E9F0BF	2017-07-26 17:20:00+03	48500.00
E9F0DA	2017-07-17 06:57:00+03	118900.00
E9F14F	2017-07-26 17:17:00+03	21200.00
E9F19F	2017-08-07 11:16:00+03	166100.00
E9F1A9	2017-08-01 15:10:00+03	34000.00
E9F1E7	2017-08-04 11:57:00+03	67700.00
E9F1FE	2017-07-09 00:28:00+03	95200.00
E9F21D	2017-07-06 13:43:00+03	8400.00
E9F2C2	2017-07-30 12:36:00+03	114300.00
E9F2CB	2017-07-17 16:56:00+03	271400.00
E9F2ED	2017-07-29 17:57:00+03	29800.00
E9F357	2017-07-26 17:46:00+03	40800.00
E9F35E	2017-08-14 12:46:00+03	99300.00
E9F39A	2017-08-13 12:08:00+03	25600.00
E9F39E	2017-08-06 12:00:00+03	58800.00
E9F39F	2017-08-12 13:58:00+03	136200.00
E9F3AF	2017-07-18 11:00:00+03	89700.00
E9F3DC	2017-08-14 14:13:00+03	46800.00
E9F3E7	2017-08-05 16:04:00+03	48800.00
E9F405	2017-07-27 14:49:00+03	109600.00
E9F44D	2017-07-07 10:58:00+03	160700.00
E9F4A0	2017-07-21 02:18:00+03	133100.00
E9F4A6	2017-07-05 13:18:00+03	12400.00
E9F4A8	2017-07-30 06:53:00+03	133700.00
E9F4AE	2017-07-31 09:57:00+03	75300.00
E9F513	2017-07-15 13:27:00+03	56100.00
E9F535	2017-07-06 05:50:00+03	42700.00
E9F56E	2017-07-16 10:20:00+03	6400.00
E9F597	2017-07-26 20:24:00+03	37900.00
E9F5C8	2017-07-16 21:50:00+03	27900.00
E9F5D1	2017-08-04 20:27:00+03	620800.00
E9F5FB	2017-08-12 08:11:00+03	50800.00
E9F63A	2017-07-22 12:08:00+03	18600.00
E9F67F	2017-07-29 09:44:00+03	22000.00
E9F70F	2017-07-27 14:37:00+03	44000.00
E9F726	2017-08-08 05:35:00+03	46300.00
E9F727	2017-08-14 15:31:00+03	79900.00
E9F743	2017-07-11 14:42:00+03	67600.00
E9F793	2017-07-02 23:39:00+03	13400.00
E9F7F4	2017-07-10 01:42:00+03	37200.00
E9F7F9	2017-07-29 05:08:00+03	51900.00
E9F84C	2017-07-18 11:22:00+03	61800.00
E9F884	2017-07-27 01:54:00+03	74300.00
E9F888	2017-07-05 09:34:00+03	128800.00
E9F90B	2017-08-07 08:29:00+03	203400.00
E9F93B	2017-08-10 00:46:00+03	58000.00
E9F973	2017-07-23 06:41:00+03	21400.00
E9F9C0	2017-07-07 22:12:00+03	141900.00
E9F9EE	2017-08-04 01:38:00+03	65900.00
E9FA1E	2017-08-02 05:50:00+03	64700.00
E9FA40	2017-07-30 17:03:00+03	47100.00
E9FA9E	2017-08-01 11:20:00+03	58600.00
E9FAF7	2017-08-13 22:35:00+03	23200.00
E9FB0F	2017-08-06 02:40:00+03	14000.00
E9FB90	2017-07-29 08:44:00+03	189200.00
E9FBE8	2017-07-03 07:56:00+03	40400.00
E9FC19	2017-08-11 22:40:00+03	51400.00
E9FC40	2017-07-10 20:54:00+03	64800.00
E9FC68	2017-08-04 03:23:00+03	67500.00
E9FD27	2017-07-19 20:18:00+03	56100.00
E9FD71	2017-07-05 09:25:00+03	172600.00
E9FD97	2017-07-09 21:45:00+03	38300.00
E9FEA8	2017-08-03 07:52:00+03	56000.00
E9FEC9	2017-08-10 14:48:00+03	111600.00
E9FEDF	2017-07-20 01:11:00+03	131100.00
E9FEE0	2017-06-26 05:23:00+03	30000.00
E9FEE9	2017-07-11 19:18:00+03	411100.00
E9FF36	2017-07-28 00:48:00+03	54500.00
E9FFA4	2017-07-13 06:36:00+03	78600.00
E9FFC4	2017-07-09 03:08:00+03	96800.00
E9FFF0	2017-07-20 16:54:00+03	271400.00
E9FFFF	2017-07-17 07:27:00+03	87100.00
EA0054	2017-08-05 07:00:00+03	16400.00
EA0065	2017-07-09 15:22:00+03	6300.00
EA0095	2017-08-06 22:48:00+03	27200.00
EA00A1	2017-06-30 12:28:00+03	116000.00
EA00BA	2017-07-31 05:47:00+03	25400.00
EA0181	2017-07-31 01:42:00+03	85800.00
EA01B1	2017-07-24 22:40:00+03	182300.00
EA01F4	2017-07-19 09:07:00+03	254900.00
EA01FC	2017-07-07 16:56:00+03	16400.00
EA024E	2017-07-23 14:00:00+03	30900.00
EA02B2	2017-07-04 05:50:00+03	178800.00
EA033F	2017-07-16 04:22:00+03	40000.00
EA03CC	2017-07-19 14:36:00+03	57800.00
EA0445	2017-08-10 22:46:00+03	32200.00
EA048F	2017-08-04 06:32:00+03	124300.00
EA055C	2017-07-10 03:21:00+03	19600.00
EA058E	2017-07-28 12:51:00+03	28000.00
EA05BF	2017-07-03 03:54:00+03	14800.00
EA05E5	2017-08-05 14:06:00+03	14800.00
EA0632	2017-07-29 22:02:00+03	13400.00
EA06DD	2017-08-13 00:46:00+03	34400.00
EA0757	2017-07-08 02:07:00+03	13400.00
EA0763	2017-07-12 14:19:00+03	50100.00
EA079D	2017-08-08 10:30:00+03	44000.00
EA07A7	2017-07-18 17:32:00+03	56600.00
EA07AD	2017-07-31 19:06:00+03	46000.00
EA07BC	2017-07-17 19:47:00+03	16400.00
EA085E	2017-07-29 23:01:00+03	71000.00
EA0866	2017-07-24 06:35:00+03	66600.00
EA08B5	2017-07-31 21:45:00+03	23400.00
EA0915	2017-08-14 06:52:00+03	116000.00
EA0919	2017-07-27 19:51:00+03	23600.00
EA092D	2017-07-04 13:13:00+03	56000.00
EA0932	2017-08-12 06:58:00+03	16400.00
EA0942	2017-08-13 17:42:00+03	36000.00
EA09A6	2017-08-10 09:24:00+03	28800.00
EA09BF	2017-07-19 14:58:00+03	135400.00
EA0A7C	2017-07-16 05:28:00+03	28000.00
EA0AC8	2017-07-13 19:54:00+03	248400.00
EA0ACC	2017-06-29 18:15:00+03	102800.00
EA0AE4	2017-07-23 06:15:00+03	49700.00
EA0B5F	2017-08-14 01:00:00+03	135200.00
EA0B7D	2017-08-13 04:39:00+03	19600.00
EA0B8B	2017-07-14 06:07:00+03	423300.00
EA0BDC	2017-07-11 20:29:00+03	58400.00
EA0C03	2017-07-27 13:22:00+03	48500.00
EA0C3F	2017-07-19 11:18:00+03	25100.00
EA0C45	2017-08-10 12:07:00+03	130200.00
EA0C83	2017-08-10 22:03:00+03	114800.00
EA0CAC	2017-08-05 21:39:00+03	43600.00
EA0CBE	2017-07-07 06:47:00+03	75300.00
EA0CE5	2017-08-15 12:49:00+03	14400.00
EA0D3A	2017-07-11 22:04:00+03	67600.00
EA0D58	2017-07-06 17:35:00+03	49200.00
EA0D66	2017-08-07 21:38:00+03	28800.00
EA0D80	2017-08-06 06:28:00+03	260900.00
EA0D8A	2017-07-08 15:39:00+03	56000.00
EA0DEE	2017-07-10 19:55:00+03	16400.00
EA0DFC	2017-08-08 13:33:00+03	423400.00
EA0E0C	2017-07-26 14:31:00+03	83000.00
EA0E48	2017-08-07 19:20:00+03	31600.00
EA0E6E	2017-08-07 05:35:00+03	75300.00
EA0EEF	2017-07-03 12:01:00+03	46800.00
EA0EFA	2017-08-12 18:52:00+03	25200.00
EA0EFF	2017-07-31 10:49:00+03	8400.00
EA0F38	2017-08-10 11:43:00+03	118700.00
EA0F6F	2017-07-04 12:40:00+03	30400.00
EA0F9A	2017-08-02 01:04:00+03	8200.00
EA1066	2017-08-15 05:27:00+03	65400.00
EA116F	2017-07-20 03:05:00+03	46300.00
EA11C3	2017-08-04 06:33:00+03	29600.00
EA11EB	2017-07-14 18:44:00+03	13200.00
EA126E	2017-07-19 11:22:00+03	115600.00
EA1291	2017-07-24 13:45:00+03	14400.00
EA132F	2017-08-14 01:39:00+03	24400.00
EA1365	2017-08-06 00:56:00+03	223200.00
EA13EC	2017-07-13 09:17:00+03	83000.00
EA1405	2017-08-09 22:04:00+03	85700.00
EA142F	2017-08-06 03:17:00+03	52700.00
EA145F	2017-08-15 00:04:00+03	79200.00
EA1461	2017-08-11 13:52:00+03	63200.00
EA1472	2017-08-04 08:05:00+03	49600.00
EA149A	2017-07-19 13:01:00+03	139000.00
EA156A	2017-07-13 21:07:00+03	105600.00
EA1590	2017-08-14 12:39:00+03	15600.00
EA15B0	2017-07-26 02:09:00+03	312000.00
EA15DB	2017-07-06 08:11:00+03	105600.00
EA15DE	2017-07-22 15:52:00+03	85800.00
EA15E5	2017-08-09 22:06:00+03	51500.00
EA15EF	2017-07-16 10:38:00+03	325800.00
EA16CF	2017-07-16 13:19:00+03	185600.00
EA16F4	2017-08-10 01:24:00+03	101200.00
EA1723	2017-08-14 17:11:00+03	42600.00
EA17AA	2017-08-09 04:16:00+03	55800.00
EA17F2	2017-08-13 05:27:00+03	136200.00
EA17FA	2017-07-21 23:37:00+03	67000.00
EA1823	2017-07-14 04:10:00+03	81700.00
EA1826	2017-07-20 09:34:00+03	22000.00
EA188D	2017-07-19 13:29:00+03	92800.00
EA18D9	2017-07-04 08:57:00+03	29100.00
EA192B	2017-07-28 10:27:00+03	46300.00
EA192F	2017-07-12 22:09:00+03	200500.00
EA1958	2017-07-10 20:56:00+03	56000.00
EA19F3	2017-07-11 12:14:00+03	270800.00
EA19FD	2017-07-15 09:55:00+03	91200.00
EA1A06	2017-07-11 01:29:00+03	60400.00
EA1A26	2017-08-13 22:07:00+03	24400.00
EA1ABA	2017-07-22 01:31:00+03	22000.00
EA1B5A	2017-07-29 07:09:00+03	6800.00
EA1B6B	2017-07-30 18:08:00+03	71200.00
EA1B7A	2017-07-31 12:07:00+03	6700.00
EA1BFC	2017-08-14 12:48:00+03	34600.00
EA1C8E	2017-08-08 06:36:00+03	129900.00
EA1CEB	2017-08-06 21:38:00+03	28600.00
EA1CF7	2017-07-09 19:54:00+03	320400.00
EA1CFE	2017-08-12 18:44:00+03	151400.00
EA1D11	2017-07-30 03:55:00+03	28200.00
EA1DB3	2017-08-11 03:45:00+03	9200.00
EA1E43	2017-08-06 11:26:00+03	42800.00
EA1E47	2017-07-01 19:45:00+03	103200.00
EA1E4F	2017-07-08 08:48:00+03	14000.00
EA1EC4	2017-07-16 12:26:00+03	47100.00
EA1F20	2017-07-27 23:16:00+03	139300.00
EA1F2A	2017-08-12 01:06:00+03	48800.00
EA1F42	2017-07-09 03:42:00+03	23200.00
EA1F6A	2017-07-27 21:09:00+03	80000.00
EA1F7E	2017-07-08 06:46:00+03	125100.00
EA2041	2017-07-03 11:54:00+03	136800.00
EA20AF	2017-08-15 09:38:00+03	13400.00
EA2101	2017-08-11 11:28:00+03	47400.00
EA2127	2017-08-12 20:58:00+03	28800.00
EA214D	2017-06-29 18:51:00+03	28000.00
EA2150	2017-07-17 14:49:00+03	68100.00
EA2175	2017-07-15 18:31:00+03	67000.00
EA219D	2017-07-25 16:06:00+03	44600.00
EA21BF	2017-08-02 16:09:00+03	62100.00
EA21D6	2017-07-03 07:50:00+03	47400.00
EA21E1	2017-07-08 10:36:00+03	139200.00
EA2239	2017-07-04 15:04:00+03	160400.00
EA223C	2017-07-01 20:51:00+03	55800.00
EA22B3	2017-07-18 01:38:00+03	58900.00
EA2324	2017-07-25 09:53:00+03	36100.00
EA2335	2017-08-05 23:52:00+03	6300.00
EA2343	2017-07-27 13:07:00+03	257500.00
EA2346	2017-08-03 15:10:00+03	130900.00
EA238E	2017-07-07 09:57:00+03	90100.00
EA23B2	2017-08-14 13:45:00+03	148200.00
EA23F6	2017-08-09 23:57:00+03	90800.00
EA24EF	2017-07-23 07:18:00+03	55800.00
EA2501	2017-08-10 13:42:00+03	39100.00
EA2639	2017-08-13 05:18:00+03	129600.00
EA264E	2017-07-05 02:04:00+03	43200.00
EA2681	2017-07-22 16:38:00+03	144400.00
EA2690	2017-07-08 04:22:00+03	66800.00
EA26AA	2017-07-22 14:56:00+03	80900.00
EA2707	2017-07-28 16:58:00+03	139400.00
EA275B	2017-08-04 11:48:00+03	133200.00
EA2801	2017-08-03 05:51:00+03	58400.00
EA282F	2017-08-06 19:26:00+03	114400.00
EA2841	2017-08-14 00:57:00+03	88000.00
EA28A9	2017-07-28 14:09:00+03	30200.00
EA29A0	2017-07-24 18:50:00+03	30900.00
EA29D9	2017-07-27 10:48:00+03	40600.00
EA29DB	2017-07-20 01:45:00+03	258400.00
EA29EF	2017-07-19 06:59:00+03	147900.00
EA2A4D	2017-07-27 21:27:00+03	14700.00
EA2AEA	2017-07-04 00:01:00+03	56100.00
EA2C30	2017-08-11 23:27:00+03	26000.00
EA2CCE	2017-08-13 16:47:00+03	133200.00
EA2D7E	2017-07-30 01:33:00+03	15800.00
EA2E13	2017-07-15 05:07:00+03	71900.00
EA2E14	2017-08-02 22:20:00+03	16400.00
EA2EDA	2017-07-28 19:46:00+03	26100.00
EA2EFB	2017-07-24 21:43:00+03	19600.00
EA2EFE	2017-07-04 05:19:00+03	13600.00
EA2F80	2017-08-05 07:59:00+03	26000.00
EA300F	2017-07-19 07:17:00+03	179400.00
EA301B	2017-08-12 17:31:00+03	37200.00
EA3044	2017-08-05 12:44:00+03	61500.00
EA3154	2017-07-30 17:56:00+03	56000.00
EA31AE	2017-08-14 20:57:00+03	82500.00
EA31B6	2017-07-16 01:10:00+03	126700.00
EA31D9	2017-07-31 05:35:00+03	273000.00
EA31E4	2017-07-13 14:46:00+03	23200.00
EA3202	2017-08-05 15:02:00+03	92300.00
EA320C	2017-07-27 09:51:00+03	54000.00
EA326D	2017-07-29 15:18:00+03	144400.00
EA3281	2017-08-06 14:42:00+03	95200.00
EA32A5	2017-07-23 00:38:00+03	166000.00
EA32C9	2017-08-02 16:51:00+03	7300.00
EA3317	2017-08-15 12:49:00+03	49700.00
EA333C	2017-07-25 23:32:00+03	49800.00
EA339A	2017-07-26 04:10:00+03	197800.00
EA33BE	2017-08-09 23:21:00+03	80000.00
EA3431	2017-08-01 07:37:00+03	139300.00
EA3439	2017-08-14 00:00:00+03	26000.00
EA344B	2017-06-29 04:46:00+03	115800.00
EA3531	2017-07-23 14:55:00+03	173200.00
EA3539	2017-07-22 16:07:00+03	13200.00
EA3544	2017-07-12 09:45:00+03	182300.00
EA358E	2017-07-08 05:16:00+03	51800.00
EA35CA	2017-08-07 14:41:00+03	76100.00
EA35F1	2017-08-01 08:02:00+03	14000.00
EA36A1	2017-07-19 15:19:00+03	12600.00
EA36F3	2017-08-01 15:34:00+03	133200.00
EA37FE	2017-07-28 03:32:00+03	179400.00
EA3852	2017-06-26 19:56:00+03	114400.00
EA385D	2017-06-29 20:18:00+03	51800.00
EA3875	2017-06-30 16:24:00+03	80200.00
EA38C1	2017-07-26 23:05:00+03	121000.00
EA3954	2017-08-12 05:23:00+03	16400.00
EA3959	2017-07-10 02:36:00+03	248500.00
EA3974	2017-07-13 04:57:00+03	15400.00
EA3984	2017-07-31 01:00:00+03	22800.00
EA39DB	2017-07-04 16:01:00+03	36200.00
EA39E1	2017-07-03 02:07:00+03	37900.00
EA3A0C	2017-08-13 13:55:00+03	36200.00
EA3A9D	2017-08-05 12:05:00+03	31400.00
EA3B50	2017-07-24 14:20:00+03	26000.00
EA3B55	2017-07-18 17:54:00+03	42700.00
EA3B85	2017-08-07 18:21:00+03	532800.00
EA3B86	2017-07-12 17:22:00+03	75300.00
EA3C39	2017-07-26 01:19:00+03	20600.00
EA3CB8	2017-07-16 07:44:00+03	106400.00
EA3CC1	2017-08-06 09:21:00+03	52900.00
EA3D65	2017-08-04 10:44:00+03	129200.00
EA3D66	2017-07-09 22:54:00+03	18000.00
EA3DD1	2017-07-09 15:41:00+03	23600.00
EA3E21	2017-07-23 02:17:00+03	89200.00
EA3E80	2017-07-20 13:32:00+03	51900.00
EA3E9A	2017-07-26 07:49:00+03	35200.00
EA3F21	2017-07-03 06:09:00+03	44000.00
EA3F25	2017-07-11 19:15:00+03	87300.00
EA3F58	2017-08-15 16:15:00+03	8200.00
EA3F5C	2017-08-06 07:53:00+03	51600.00
EA3F62	2017-07-12 21:35:00+03	92600.00
EA3F78	2017-07-02 10:52:00+03	44800.00
EA3F94	2017-07-25 18:31:00+03	6000.00
EA3F95	2017-08-12 05:02:00+03	28800.00
EA3FB6	2017-06-30 19:02:00+03	28000.00
EA3FDD	2017-07-05 01:43:00+03	11800.00
EA3FEC	2017-08-09 12:24:00+03	112000.00
EA4064	2017-07-19 07:05:00+03	181000.00
EA4144	2017-07-21 21:18:00+03	170000.00
EA4216	2017-07-25 10:21:00+03	85000.00
EA4281	2017-07-19 10:30:00+03	37200.00
EA428C	2017-07-09 00:36:00+03	44600.00
EA42BC	2017-07-15 22:47:00+03	36200.00
EA431F	2017-07-06 06:23:00+03	55800.00
EA43A0	2017-07-29 12:09:00+03	167500.00
EA43CB	2017-07-20 12:02:00+03	55800.00
EA43F3	2017-08-14 07:43:00+03	62800.00
EA441C	2017-07-23 07:30:00+03	7400.00
EA4425	2017-08-11 07:17:00+03	95100.00
EA4433	2017-08-01 17:19:00+03	135200.00
EA4448	2017-07-17 22:40:00+03	19600.00
EA4481	2017-07-22 23:48:00+03	12400.00
EA44B7	2017-07-06 17:23:00+03	187800.00
EA456B	2017-08-03 19:49:00+03	40800.00
EA45A1	2017-07-23 07:26:00+03	49900.00
EA45A5	2017-07-06 04:47:00+03	37900.00
EA45BA	2017-08-14 10:26:00+03	39800.00
EA460E	2017-08-14 11:11:00+03	65000.00
EA4683	2017-07-19 18:53:00+03	43000.00
EA46B5	2017-07-29 19:21:00+03	144400.00
EA46E4	2017-07-21 22:23:00+03	260900.00
EA46EF	2017-08-02 18:24:00+03	33100.00
EA471D	2017-07-23 02:32:00+03	131100.00
EA472D	2017-08-02 20:28:00+03	66600.00
EA47C4	2017-08-13 09:33:00+03	23200.00
EA47EB	2017-07-02 10:45:00+03	73600.00
EA47F4	2017-08-07 17:22:00+03	136000.00
EA47F7	2017-08-09 12:57:00+03	147000.00
EA4811	2017-08-08 03:40:00+03	85000.00
EA4813	2017-07-29 11:49:00+03	50000.00
EA481E	2017-07-13 00:47:00+03	26000.00
EA4849	2017-07-11 15:20:00+03	25100.00
EA4856	2017-07-10 05:05:00+03	56900.00
EA48EE	2017-08-01 09:30:00+03	48800.00
EA4911	2017-07-03 02:48:00+03	38400.00
EA4941	2017-07-31 09:48:00+03	38200.00
EA49C3	2017-08-14 22:57:00+03	32200.00
EA49CB	2017-07-05 07:32:00+03	38300.00
EA4A03	2017-07-17 10:21:00+03	99200.00
EA4A67	2017-07-17 13:36:00+03	45000.00
EA4AAE	2017-08-03 23:13:00+03	46000.00
EA4AB2	2017-08-12 14:34:00+03	49600.00
EA4B0C	2017-08-13 22:56:00+03	48100.00
EA4B39	2017-07-24 03:34:00+03	132800.00
EA4B7F	2017-07-07 02:47:00+03	132800.00
EA4BB4	2017-07-15 13:32:00+03	25200.00
EA4BC3	2017-07-01 17:03:00+03	229900.00
EA4C44	2017-07-07 11:44:00+03	151200.00
EA4C65	2017-07-15 18:06:00+03	12600.00
EA4D53	2017-07-04 15:53:00+03	106400.00
EA4DA5	2017-07-14 21:13:00+03	258300.00
EA4DD1	2017-08-09 09:01:00+03	84300.00
EA4E09	2017-07-17 14:14:00+03	13400.00
EA4E0D	2017-08-14 23:32:00+03	38800.00
EA4E5B	2017-07-08 05:05:00+03	28700.00
EA4EBB	2017-07-23 01:19:00+03	11800.00
EA4EC3	2017-08-15 00:43:00+03	160100.00
EA4EE8	2017-08-02 13:37:00+03	23600.00
EA4F1F	2017-07-10 13:49:00+03	43000.00
EA4F4C	2017-07-16 07:43:00+03	90400.00
EA4FA3	2017-07-23 12:04:00+03	111600.00
EA4FF3	2017-07-14 20:44:00+03	92000.00
EA502B	2017-07-02 16:27:00+03	57700.00
EA502D	2017-07-31 07:00:00+03	16400.00
EA5036	2017-07-19 23:11:00+03	67000.00
EA50B7	2017-08-07 10:09:00+03	67200.00
EA51B8	2017-08-06 14:03:00+03	45500.00
EA5216	2017-07-08 00:34:00+03	40000.00
EA5222	2017-07-13 21:15:00+03	40800.00
EA526D	2017-07-27 12:20:00+03	56000.00
EA52AE	2017-07-22 18:38:00+03	56000.00
EA52C3	2017-08-05 05:41:00+03	59200.00
EA5307	2017-07-16 23:43:00+03	96400.00
EA530B	2017-08-14 14:13:00+03	46400.00
EA535E	2017-06-29 10:55:00+03	49800.00
EA5368	2017-06-29 21:51:00+03	132800.00
EA5384	2017-08-12 09:03:00+03	28800.00
EA53A7	2017-07-07 17:25:00+03	40300.00
EA53C0	2017-07-06 04:41:00+03	153200.00
EA53C3	2017-07-17 23:13:00+03	132800.00
EA53D6	2017-08-10 11:10:00+03	23900.00
EA541A	2017-07-03 20:40:00+03	24400.00
EA5455	2017-07-18 09:26:00+03	117600.00
EA54AC	2017-06-24 17:24:00+03	83500.00
EA54B3	2017-08-10 13:05:00+03	66000.00
EA54C7	2017-07-22 13:10:00+03	54900.00
EA556D	2017-08-08 23:45:00+03	93700.00
EA55E4	2017-07-23 07:37:00+03	85000.00
EA5625	2017-08-13 00:03:00+03	136900.00
EA569C	2017-08-11 11:32:00+03	14000.00
EA56A0	2017-07-27 00:10:00+03	281500.00
EA56A9	2017-07-21 16:48:00+03	143900.00
EA56DC	2017-07-11 19:29:00+03	23200.00
EA56F8	2017-08-01 20:23:00+03	35200.00
EA56FD	2017-08-08 05:19:00+03	46000.00
EA5709	2017-08-03 08:04:00+03	56000.00
EA5749	2017-07-06 10:42:00+03	19200.00
EA57C3	2017-07-19 10:07:00+03	59000.00
EA5886	2017-07-05 07:43:00+03	29600.00
EA5889	2017-07-24 20:26:00+03	310600.00
EA597B	2017-08-09 16:48:00+03	34200.00
EA59FB	2017-07-05 13:35:00+03	100000.00
EA5A06	2017-07-23 08:09:00+03	37700.00
EA5A1B	2017-07-15 10:05:00+03	11700.00
EA5A34	2017-07-21 17:06:00+03	137800.00
EA5ABC	2017-07-18 11:29:00+03	8000.00
EA5B23	2017-07-12 17:40:00+03	133700.00
EA5B9B	2017-07-13 08:45:00+03	50000.00
EA5BDA	2017-07-17 20:06:00+03	44800.00
EA5C02	2017-07-26 19:42:00+03	67800.00
EA5C09	2017-07-13 05:22:00+03	87100.00
EA5C5D	2017-07-21 23:21:00+03	70600.00
EA5C92	2017-08-12 04:42:00+03	36200.00
EA5CF6	2017-07-20 01:54:00+03	56200.00
EA5CF8	2017-08-05 03:31:00+03	24000.00
EA5D13	2017-07-26 05:49:00+03	20200.00
EA5D30	2017-07-18 12:49:00+03	123000.00
EA5DD9	2017-08-03 06:48:00+03	64800.00
EA5E12	2017-07-11 23:38:00+03	52400.00
EA5E5D	2017-07-28 06:20:00+03	12600.00
EA5EC5	2017-08-01 16:09:00+03	28800.00
EA5EF6	2017-08-12 22:08:00+03	136500.00
EA5EF7	2017-08-11 14:25:00+03	140800.00
EA5EFE	2017-07-08 07:34:00+03	81600.00
EA5F2C	2017-08-02 10:05:00+03	46300.00
EA5F32	2017-07-12 21:30:00+03	46000.00
EA5F6B	2017-07-11 08:29:00+03	101200.00
EA5F7A	2017-08-10 13:32:00+03	28800.00
EA5F81	2017-07-17 16:27:00+03	51100.00
EA5FF8	2017-07-07 21:24:00+03	102100.00
EA6003	2017-07-28 07:34:00+03	128300.00
EA600B	2017-07-10 14:06:00+03	51900.00
EA6078	2017-07-28 05:05:00+03	28000.00
EA607C	2017-07-08 20:16:00+03	123000.00
EA6150	2017-06-27 03:37:00+03	36200.00
EA6158	2017-07-16 05:00:00+03	20000.00
EA61D2	2017-07-28 23:53:00+03	167400.00
EA625E	2017-08-07 22:45:00+03	139800.00
EA6290	2017-08-07 18:13:00+03	46500.00
EA6312	2017-07-13 07:02:00+03	47400.00
EA6319	2017-07-07 00:38:00+03	58200.00
EA6328	2017-08-12 14:13:00+03	46000.00
EA633E	2017-07-18 14:36:00+03	18000.00
EA640A	2017-08-13 18:46:00+03	24400.00
EA64B4	2017-07-26 04:21:00+03	36200.00
EA6516	2017-08-08 03:12:00+03	6700.00
EA658B	2017-07-23 08:08:00+03	47000.00
EA663C	2017-07-07 11:17:00+03	38800.00
EA6643	2017-07-02 19:24:00+03	76600.00
EA6680	2017-08-02 09:00:00+03	25600.00
EA66BE	2017-08-08 20:06:00+03	95200.00
EA66E1	2017-07-24 02:28:00+03	36200.00
EA672F	2017-07-08 05:27:00+03	198100.00
EA67A9	2017-08-13 16:17:00+03	27200.00
EA67E2	2017-07-12 00:11:00+03	26700.00
EA6801	2017-07-27 12:50:00+03	21800.00
EA6854	2017-07-28 13:28:00+03	91100.00
EA6890	2017-08-12 18:44:00+03	32800.00
EA697C	2017-08-08 05:55:00+03	398600.00
EA6995	2017-07-29 12:38:00+03	42700.00
EA69BE	2017-08-10 17:51:00+03	146300.00
EA69BF	2017-07-25 21:10:00+03	189800.00
EA6A54	2017-08-03 17:10:00+03	44800.00
EA6A6D	2017-08-03 01:34:00+03	56100.00
EA6A9C	2017-08-06 15:05:00+03	49100.00
EA6AED	2017-07-30 20:15:00+03	26800.00
EA6AF4	2017-07-01 18:00:00+03	87200.00
EA6B32	2017-07-09 10:33:00+03	6800.00
EA6B49	2017-08-01 22:17:00+03	43000.00
EA6B58	2017-08-11 02:49:00+03	46400.00
EA6BEF	2017-07-06 13:02:00+03	23200.00
EA6BF2	2017-07-18 10:41:00+03	44000.00
EA6C33	2017-06-27 05:41:00+03	42600.00
EA6C4A	2017-07-18 18:01:00+03	24200.00
EA6C59	2017-08-07 09:39:00+03	6700.00
EA6C93	2017-07-26 09:08:00+03	19600.00
EA6D14	2017-06-24 02:57:00+03	70800.00
EA6D9D	2017-07-26 21:28:00+03	21800.00
EA6DB0	2017-07-24 21:08:00+03	23600.00
EA6E70	2017-08-03 09:54:00+03	13600.00
EA6EB1	2017-07-19 16:03:00+03	259100.00
EA6ECC	2017-08-01 21:27:00+03	67200.00
EA6F21	2017-07-27 06:53:00+03	8200.00
EA6F31	2017-07-27 09:02:00+03	51800.00
EA6F4D	2017-07-18 02:37:00+03	40100.00
EA6F55	2017-08-06 16:43:00+03	92900.00
EA6F58	2017-07-28 18:37:00+03	86800.00
EA6F69	2017-06-30 09:27:00+03	141000.00
EA6F7E	2017-07-11 18:44:00+03	20000.00
EA7092	2017-08-06 13:11:00+03	54500.00
EA70A5	2017-07-22 22:20:00+03	79000.00
EA70D1	2017-07-19 09:47:00+03	58800.00
EA70DB	2017-07-22 00:54:00+03	271400.00
EA712A	2017-06-29 20:05:00+03	69700.00
EA713E	2017-07-11 08:25:00+03	25000.00
EA716A	2017-07-17 08:49:00+03	42000.00
EA717B	2017-08-08 17:06:00+03	28000.00
EA7186	2017-07-10 15:44:00+03	123000.00
EA7190	2017-07-05 11:53:00+03	42800.00
EA7193	2017-06-28 06:51:00+03	179500.00
EA71AC	2017-07-26 00:37:00+03	54800.00
EA7236	2017-07-29 02:43:00+03	24800.00
EA7244	2017-08-07 13:46:00+03	88600.00
EA7292	2017-07-11 15:47:00+03	40600.00
EA72A5	2017-08-13 05:06:00+03	153300.00
EA72B5	2017-07-22 18:11:00+03	125200.00
EA72BB	2017-08-06 09:41:00+03	105600.00
EA72E3	2017-08-05 10:21:00+03	142400.00
EA72FC	2017-08-10 07:46:00+03	46200.00
EA7363	2017-08-03 06:36:00+03	140900.00
EA7377	2017-07-16 18:07:00+03	15000.00
EA7432	2017-08-08 09:29:00+03	406100.00
EA7440	2017-07-20 03:07:00+03	54400.00
EA7451	2017-07-27 15:00:00+03	148200.00
EA7464	2017-07-04 16:46:00+03	58200.00
EA74D2	2017-07-28 08:13:00+03	14000.00
EA74F6	2017-07-07 20:43:00+03	24800.00
EA751E	2017-07-24 20:43:00+03	35600.00
EA753F	2017-07-02 12:02:00+03	38400.00
EA7562	2017-07-19 13:41:00+03	75000.00
EA7591	2017-07-10 19:05:00+03	137600.00
EA759A	2017-07-27 17:09:00+03	400100.00
EA75AD	2017-07-13 16:56:00+03	177600.00
EA75C5	2017-07-21 20:29:00+03	14400.00
EA75F2	2017-07-11 03:25:00+03	56600.00
EA75FD	2017-07-27 00:39:00+03	24700.00
EA7628	2017-07-29 07:25:00+03	36800.00
EA769E	2017-08-13 13:42:00+03	90400.00
EA76B8	2017-08-03 19:24:00+03	43900.00
EA76ED	2017-08-08 10:09:00+03	50600.00
EA775F	2017-07-30 02:36:00+03	22000.00
EA7775	2017-08-12 03:45:00+03	26000.00
EA77B6	2017-08-11 14:55:00+03	65100.00
EA77C3	2017-07-14 14:52:00+03	19600.00
EA77D1	2017-07-16 00:06:00+03	6700.00
EA7866	2017-08-11 22:28:00+03	50400.00
EA787D	2017-07-21 10:24:00+03	23200.00
EA78C7	2017-07-09 13:36:00+03	18000.00
EA78D4	2017-08-14 20:29:00+03	55800.00
EA78DD	2017-07-31 15:20:00+03	38600.00
EA78ED	2017-07-03 10:12:00+03	16800.00
EA7929	2017-07-10 04:52:00+03	48300.00
EA797F	2017-08-02 10:16:00+03	90600.00
EA79A5	2017-07-12 07:16:00+03	69500.00
EA79C5	2017-07-18 05:20:00+03	25000.00
EA79D7	2017-07-26 17:03:00+03	39200.00
EA7A4C	2017-07-30 22:02:00+03	59000.00
EA7A7A	2017-08-02 18:48:00+03	25600.00
EA7ABA	2017-08-13 18:17:00+03	12000.00
EA7AEC	2017-07-25 08:38:00+03	99200.00
EA7B22	2017-07-09 07:41:00+03	46400.00
EA7B51	2017-07-06 10:18:00+03	30400.00
EA7BF9	2017-07-09 10:17:00+03	30200.00
EA7C7F	2017-08-06 23:34:00+03	265400.00
EA7C9B	2017-07-20 05:35:00+03	147000.00
EA7CDE	2017-07-27 20:38:00+03	329100.00
EA7D77	2017-08-13 21:00:00+03	71400.00
EA7D84	2017-07-09 13:52:00+03	260900.00
EA7DAA	2017-07-31 09:11:00+03	48800.00
EA7DD2	2017-07-19 13:33:00+03	38600.00
EA7EA7	2017-08-03 19:06:00+03	38400.00
EA7EBB	2017-07-18 19:31:00+03	44600.00
EA7F0A	2017-07-02 04:31:00+03	248300.00
EA7F4D	2017-07-05 23:28:00+03	144000.00
EA7F56	2017-07-13 22:30:00+03	71900.00
EA7F6F	2017-07-14 17:54:00+03	22000.00
EA7FD5	2017-07-05 07:49:00+03	69500.00
EA801F	2017-07-08 09:27:00+03	78800.00
EA8060	2017-07-26 21:03:00+03	64500.00
EA8172	2017-07-16 00:44:00+03	8000.00
EA8199	2017-07-20 03:17:00+03	34000.00
EA81BB	2017-07-08 04:57:00+03	55600.00
EA81DD	2017-08-05 06:19:00+03	57200.00
EA81EB	2017-07-14 22:04:00+03	281500.00
EA81F3	2017-07-22 01:26:00+03	128400.00
EA8224	2017-07-23 11:02:00+03	73900.00
EA8277	2017-07-06 08:58:00+03	82900.00
EA82F4	2017-08-10 18:15:00+03	46300.00
EA83E0	2017-07-16 17:34:00+03	106400.00
EA8406	2017-07-09 01:30:00+03	122800.00
EA840F	2017-07-13 00:52:00+03	13200.00
EA8416	2017-07-18 06:38:00+03	60800.00
EA8494	2017-07-19 07:36:00+03	84100.00
EA84BF	2017-07-31 22:29:00+03	37900.00
EA84F7	2017-07-27 10:07:00+03	46400.00
EA84FA	2017-07-23 07:26:00+03	30300.00
EA852D	2017-08-06 23:22:00+03	42600.00
EA8531	2017-07-21 09:33:00+03	51800.00
EA856E	2017-08-06 19:23:00+03	89700.00
EA857E	2017-07-22 15:21:00+03	56000.00
EA858C	2017-07-14 15:05:00+03	35300.00
EA861C	2017-08-05 15:44:00+03	51200.00
EA8665	2017-08-12 14:57:00+03	24000.00
EA86C3	2017-07-23 12:33:00+03	37900.00
EA8743	2017-07-31 13:17:00+03	98400.00
EA87BD	2017-08-03 23:48:00+03	28000.00
EA8837	2017-06-29 20:14:00+03	36200.00
EA8888	2017-06-29 23:43:00+03	101500.00
EA88E3	2017-08-09 04:14:00+03	54800.00
EA895B	2017-08-08 03:24:00+03	41800.00
EA8970	2017-07-13 15:04:00+03	24800.00
EA8A1B	2017-07-19 02:47:00+03	382500.00
EA8A5B	2017-07-15 20:07:00+03	16400.00
EA8AA7	2017-07-30 04:28:00+03	26000.00
EA8AD2	2017-08-08 10:34:00+03	86500.00
EA8B8F	2017-07-05 00:19:00+03	187600.00
EA8BEF	2017-08-13 12:45:00+03	12000.00
EA8CA4	2017-07-28 07:24:00+03	86800.00
EA8CD1	2017-06-29 08:09:00+03	112000.00
EA8CD2	2017-07-25 22:11:00+03	129400.00
EA8CEB	2017-07-15 13:05:00+03	23400.00
EA8D4A	2017-08-09 21:29:00+03	64800.00
EA8D4C	2017-07-09 18:16:00+03	81700.00
EA8D61	2017-07-31 11:55:00+03	136000.00
EA8D75	2017-07-22 12:11:00+03	55600.00
EA8D77	2017-07-12 07:01:00+03	27200.00
EA8DF5	2017-08-05 00:16:00+03	30400.00
EA8E67	2017-07-13 22:44:00+03	116400.00
EA8EE0	2017-07-13 01:02:00+03	10700.00
EA8EFC	2017-07-14 14:08:00+03	24500.00
EA8F34	2017-07-11 23:26:00+03	93500.00
EA8F72	2017-07-29 13:24:00+03	46000.00
EA8FD6	2017-07-30 18:29:00+03	31500.00
EA8FFB	2017-08-14 06:10:00+03	56000.00
EA9058	2017-08-04 16:37:00+03	22400.00
EA9091	2017-07-05 22:21:00+03	303500.00
EA90B9	2017-07-17 14:51:00+03	17800.00
EA90DA	2017-07-16 13:07:00+03	67600.00
EA9162	2017-08-05 21:48:00+03	9200.00
EA91AA	2017-08-06 17:54:00+03	39600.00
EA91C8	2017-08-06 18:36:00+03	170200.00
EA91E2	2017-07-18 03:29:00+03	22000.00
EA927A	2017-07-15 23:01:00+03	46000.00
EA92A1	2017-08-08 23:33:00+03	51900.00
EA92BA	2017-07-13 22:21:00+03	13600.00
EA92C9	2017-07-28 16:05:00+03	173900.00
EA930D	2017-08-14 09:53:00+03	28800.00
EA9344	2017-07-01 03:02:00+03	40000.00
EA93B4	2017-07-12 06:43:00+03	533900.00
EA93FA	2017-08-04 18:42:00+03	58200.00
EA946E	2017-08-14 20:52:00+03	65500.00
EA9487	2017-07-15 00:39:00+03	89000.00
EA94F4	2017-07-06 09:52:00+03	113000.00
EA9502	2017-07-23 17:14:00+03	49200.00
EA953F	2017-07-21 23:23:00+03	37900.00
EA9560	2017-06-29 01:31:00+03	25200.00
EA956D	2017-07-07 05:53:00+03	99200.00
EA959D	2017-08-08 02:45:00+03	144300.00
EA9622	2017-07-04 03:37:00+03	24800.00
EA963C	2017-07-05 06:44:00+03	93900.00
EA9644	2017-07-30 23:01:00+03	62900.00
EA964E	2017-08-06 01:24:00+03	23400.00
EA96DA	2017-07-21 19:12:00+03	169000.00
EA96FF	2017-07-13 20:16:00+03	110500.00
EA9718	2017-07-24 21:20:00+03	75600.00
EA973E	2017-07-09 18:00:00+03	15700.00
EA9740	2017-08-03 19:11:00+03	66000.00
EA9742	2017-07-07 00:07:00+03	56000.00
EA9750	2017-08-02 23:03:00+03	79600.00
EA975F	2017-07-06 09:51:00+03	70800.00
EA9778	2017-07-25 19:01:00+03	258000.00
EA977A	2017-08-06 22:39:00+03	64800.00
EA9849	2017-07-21 07:04:00+03	28700.00
EA984F	2017-08-15 11:26:00+03	20600.00
EA9850	2017-07-29 03:08:00+03	27200.00
EA9938	2017-07-07 06:36:00+03	54500.00
EA9A04	2017-07-10 16:47:00+03	28000.00
EA9A48	2017-07-31 15:22:00+03	24400.00
EA9A57	2017-06-30 15:42:00+03	64800.00
EA9B0F	2017-07-31 08:24:00+03	6200.00
EA9B2D	2017-07-10 21:01:00+03	107100.00
EA9BE4	2017-07-28 01:02:00+03	28800.00
EA9BE9	2017-07-05 06:39:00+03	210000.00
EA9BF6	2017-07-16 00:33:00+03	6800.00
EA9CF0	2017-07-17 13:40:00+03	51600.00
EA9D3F	2017-08-02 19:02:00+03	35300.00
EA9DD0	2017-08-10 04:48:00+03	270600.00
EA9DF0	2017-08-01 15:46:00+03	62800.00
EA9DFF	2017-07-09 03:47:00+03	66600.00
EA9F05	2017-07-31 10:43:00+03	84500.00
EA9F6A	2017-07-23 11:19:00+03	54000.00
EA9FC1	2017-07-04 20:44:00+03	41600.00
EAA07A	2017-07-21 01:19:00+03	28800.00
EAA0F6	2017-07-08 19:24:00+03	69000.00
EAA10F	2017-08-10 06:28:00+03	6700.00
EAA12E	2017-08-08 10:23:00+03	37600.00
EAA13C	2017-07-24 06:24:00+03	16400.00
EAA15E	2017-07-05 19:00:00+03	93800.00
EAA1CF	2017-08-08 18:11:00+03	139300.00
EAA20B	2017-08-11 10:39:00+03	39900.00
EAA20F	2017-07-18 05:06:00+03	85000.00
EAA2C1	2017-07-05 11:14:00+03	11300.00
EAA2D6	2017-07-29 08:51:00+03	70800.00
EAA335	2017-07-04 14:49:00+03	44000.00
EAA39F	2017-07-07 15:27:00+03	24800.00
EAA488	2017-08-09 03:03:00+03	10600.00
EAA4A1	2017-07-09 07:06:00+03	20200.00
EAA507	2017-07-31 13:24:00+03	16400.00
EAA59E	2017-07-06 22:43:00+03	81400.00
EAA5CB	2017-08-15 02:54:00+03	57500.00
EAA618	2017-07-13 07:49:00+03	66800.00
EAA67E	2017-08-01 21:02:00+03	143600.00
EAA6AA	2017-07-03 18:33:00+03	33400.00
EAA6C3	2017-07-02 12:45:00+03	241200.00
EAA6C7	2017-07-30 10:38:00+03	122100.00
EAA722	2017-08-08 10:45:00+03	32700.00
EAA75D	2017-07-28 20:09:00+03	14000.00
EAA7F9	2017-07-07 08:09:00+03	39300.00
EAA81E	2017-07-12 18:52:00+03	31600.00
EAA838	2017-07-28 12:30:00+03	12700.00
EAA871	2017-08-03 00:01:00+03	183300.00
EAA888	2017-08-15 12:09:00+03	55800.00
EAA9F2	2017-07-20 00:31:00+03	14800.00
EAAA0C	2017-07-29 21:55:00+03	48100.00
EAAA3C	2017-08-01 23:06:00+03	94300.00
EAAAB7	2017-08-03 18:21:00+03	46000.00
EAAAD5	2017-07-08 22:32:00+03	187600.00
EAAADF	2017-07-29 18:08:00+03	10800.00
EAAB01	2017-07-29 22:58:00+03	88100.00
EAAB0F	2017-08-11 16:10:00+03	86400.00
EAAB24	2017-08-05 21:21:00+03	102300.00
EAAB26	2017-07-27 20:38:00+03	58400.00
EAAB46	2017-08-03 12:34:00+03	89700.00
EAAB71	2017-07-15 03:20:00+03	157700.00
EAAB76	2017-07-15 05:07:00+03	32900.00
EAAC34	2017-08-05 13:27:00+03	35600.00
EAAC3C	2017-07-05 09:31:00+03	49300.00
EAAC6F	2017-08-03 14:57:00+03	21800.00
EAAC8B	2017-07-18 23:17:00+03	71300.00
EAACB5	2017-07-22 13:56:00+03	8200.00
EAACDE	2017-07-28 23:45:00+03	28800.00
EAACEB	2017-07-09 00:11:00+03	13400.00
EAAD04	2017-07-30 21:03:00+03	58200.00
EAAD6A	2017-07-21 16:57:00+03	49800.00
EAAE11	2017-08-04 07:29:00+03	126400.00
EAAE7D	2017-07-22 16:05:00+03	81600.00
EAAF19	2017-07-30 08:28:00+03	99200.00
EAAF1E	2017-07-23 18:49:00+03	31400.00
EAAF53	2017-07-10 02:32:00+03	265600.00
EAAF64	2017-07-05 13:28:00+03	48500.00
EAAFA0	2017-07-12 21:19:00+03	76600.00
EAAFBA	2017-07-10 23:10:00+03	26600.00
EAAFC4	2017-07-25 22:10:00+03	564000.00
EAB074	2017-07-12 08:18:00+03	37900.00
EAB1F1	2017-07-13 18:05:00+03	129700.00
EAB1FB	2017-07-08 16:14:00+03	97900.00
EAB200	2017-07-29 08:42:00+03	28000.00
EAB209	2017-07-27 03:34:00+03	123900.00
EAB251	2017-07-25 12:57:00+03	30000.00
EAB2F0	2017-07-19 07:12:00+03	135000.00
EAB2F2	2017-08-07 13:29:00+03	29600.00
EAB33F	2017-06-30 16:24:00+03	28000.00
EAB3DF	2017-06-26 19:17:00+03	39300.00
EAB477	2017-07-29 02:35:00+03	47400.00
EAB4CC	2017-07-03 21:33:00+03	59600.00
EAB50B	2017-07-28 07:34:00+03	406100.00
EAB5BA	2017-08-14 17:31:00+03	68400.00
EAB5F0	2017-07-24 00:17:00+03	51300.00
EAB631	2017-08-02 17:01:00+03	21400.00
EAB68A	2017-08-04 08:25:00+03	68800.00
EAB7CA	2017-07-18 18:37:00+03	6700.00
EAB7DD	2017-07-28 01:39:00+03	24300.00
EAB819	2017-07-18 01:02:00+03	131100.00
EAB898	2017-07-05 12:04:00+03	11600.00
EAB8B0	2017-08-13 17:18:00+03	52000.00
EAB8B7	2017-08-13 00:35:00+03	64500.00
EAB8FE	2017-06-30 18:45:00+03	60700.00
EAB93F	2017-07-06 22:54:00+03	29800.00
EAB973	2017-07-14 09:07:00+03	30900.00
EAB9B2	2017-08-03 17:05:00+03	52700.00
EABA15	2017-08-04 06:56:00+03	40800.00
EABA94	2017-08-07 19:20:00+03	317600.00
EABAC7	2017-07-15 16:33:00+03	28000.00
EABAC9	2017-07-22 01:24:00+03	99200.00
EABAE8	2017-08-11 06:31:00+03	39100.00
EABB18	2017-07-13 11:41:00+03	56000.00
EABB20	2017-08-11 20:50:00+03	56100.00
EABB49	2017-08-08 07:49:00+03	222300.00
EABB4C	2017-07-08 14:53:00+03	40000.00
EABB81	2017-07-14 02:51:00+03	87700.00
EABB82	2017-08-12 07:16:00+03	36200.00
EABB93	2017-08-11 03:55:00+03	17200.00
EABB97	2017-07-12 04:03:00+03	12400.00
EABBA6	2017-07-21 08:56:00+03	55800.00
EABBF1	2017-07-24 16:51:00+03	22000.00
EABC2C	2017-07-16 02:24:00+03	54500.00
EABC8B	2017-08-10 06:17:00+03	40300.00
EABCC6	2017-07-11 09:58:00+03	83300.00
EABCD0	2017-08-14 05:40:00+03	97900.00
EABD03	2017-07-27 05:09:00+03	23200.00
EABD14	2017-07-13 06:29:00+03	290400.00
EABD31	2017-08-07 21:39:00+03	117100.00
EABD55	2017-07-25 00:11:00+03	52400.00
EABDDF	2017-07-10 09:40:00+03	12600.00
EABE54	2017-07-14 05:31:00+03	23600.00
EABEE9	2017-08-09 01:42:00+03	49100.00
EABF2F	2017-06-29 20:39:00+03	137800.00
EABF9B	2017-08-05 07:34:00+03	169600.00
EABFD0	2017-07-13 12:43:00+03	77900.00
EAC02F	2017-07-07 22:34:00+03	56200.00
EAC069	2017-08-14 21:52:00+03	37100.00
EAC0A0	2017-07-05 23:47:00+03	44800.00
EAC0D3	2017-07-13 07:32:00+03	132800.00
EAC0E4	2017-07-22 09:30:00+03	48800.00
EAC103	2017-07-26 06:26:00+03	22400.00
EAC170	2017-07-13 13:10:00+03	121400.00
EAC17B	2017-07-20 21:39:00+03	28800.00
EAC18B	2017-08-08 12:56:00+03	32000.00
EAC23D	2017-08-05 15:52:00+03	32300.00
EAC266	2017-07-14 21:34:00+03	56100.00
EAC321	2017-07-15 04:22:00+03	23200.00
EAC33D	2017-07-14 16:25:00+03	79900.00
EAC344	2017-07-22 08:40:00+03	125100.00
EAC42E	2017-08-12 09:15:00+03	76200.00
EAC471	2017-06-27 21:23:00+03	37700.00
EAC472	2017-08-09 05:52:00+03	22000.00
EAC530	2017-08-06 20:18:00+03	13200.00
EAC58C	2017-08-02 22:15:00+03	58800.00
EAC59E	2017-07-26 22:30:00+03	19600.00
EAC5F2	2017-07-27 23:31:00+03	75300.00
EAC63A	2017-08-12 23:21:00+03	54400.00
EAC704	2017-08-15 01:24:00+03	28300.00
EAC76D	2017-07-13 17:02:00+03	25600.00
EAC793	2017-07-16 08:56:00+03	92800.00
EAC80E	2017-07-23 02:21:00+03	85000.00
EAC83E	2017-07-23 21:52:00+03	84100.00
EAC846	2017-08-10 16:29:00+03	123000.00
EAC848	2017-08-12 04:44:00+03	7400.00
EAC869	2017-07-02 08:48:00+03	136500.00
EAC894	2017-07-24 00:37:00+03	29600.00
EAC8BA	2017-08-04 19:26:00+03	47200.00
EAC91B	2017-07-06 03:45:00+03	22000.00
EACA2D	2017-07-26 11:04:00+03	6000.00
EACA44	2017-07-15 02:46:00+03	72400.00
EACA77	2017-07-19 17:01:00+03	49200.00
EACA9F	2017-07-18 20:51:00+03	56200.00
EACAC3	2017-08-14 17:23:00+03	260900.00
EACAD4	2017-08-10 04:17:00+03	47000.00
EACB67	2017-07-26 20:33:00+03	89100.00
EACC64	2017-08-15 01:38:00+03	372500.00
EACE17	2017-07-15 06:49:00+03	105000.00
EACE29	2017-07-15 15:34:00+03	33300.00
EACF0A	2017-07-17 11:35:00+03	127900.00
EACF76	2017-08-07 05:20:00+03	27300.00
EACF88	2017-08-12 03:44:00+03	123000.00
EACFC8	2017-07-15 15:07:00+03	28800.00
EACFF6	2017-08-11 08:42:00+03	203300.00
EAD005	2017-07-03 00:52:00+03	37100.00
EAD09C	2017-07-06 08:44:00+03	88600.00
EAD140	2017-08-11 11:27:00+03	28000.00
EAD162	2017-08-15 01:47:00+03	40100.00
EAD1B5	2017-07-06 19:23:00+03	78300.00
EAD1CD	2017-08-03 03:50:00+03	69500.00
EAD1D1	2017-07-08 00:03:00+03	131100.00
EAD26E	2017-08-11 14:05:00+03	57400.00
EAD2DD	2017-08-12 14:27:00+03	76800.00
EAD2F1	2017-07-30 17:06:00+03	137600.00
EAD2F7	2017-07-20 22:53:00+03	62700.00
EAD334	2017-07-06 16:22:00+03	8200.00
EAD361	2017-07-04 14:21:00+03	58800.00
EAD364	2017-07-10 23:40:00+03	243600.00
EAD386	2017-07-01 07:12:00+03	248300.00
EAD3BE	2017-07-08 01:44:00+03	79600.00
EAD456	2017-08-03 23:40:00+03	246000.00
EAD45A	2017-07-07 07:40:00+03	47200.00
EAD467	2017-07-02 12:01:00+03	28000.00
EAD46B	2017-07-27 12:28:00+03	135400.00
EAD490	2017-08-06 00:26:00+03	69500.00
EAD4F7	2017-07-21 03:18:00+03	170000.00
EAD533	2017-08-04 10:58:00+03	21800.00
EAD57A	2017-07-03 19:02:00+03	17800.00
EAD5EB	2017-08-04 10:52:00+03	27700.00
EAD5FE	2017-07-01 18:21:00+03	86300.00
EAD607	2017-08-01 02:40:00+03	163600.00
EAD60A	2017-08-06 05:09:00+03	32900.00
EAD697	2017-07-03 01:04:00+03	47000.00
EAD69E	2017-07-29 22:37:00+03	32400.00
EAD70E	2017-07-08 01:36:00+03	9800.00
EAD768	2017-08-11 19:48:00+03	42800.00
EAD76D	2017-08-05 23:44:00+03	130300.00
EAD7D9	2017-07-14 19:32:00+03	12400.00
EAD818	2017-08-01 13:32:00+03	14900.00
EAD8A6	2017-08-14 22:23:00+03	44800.00
EAD929	2017-08-07 13:34:00+03	64600.00
EAD94A	2017-08-08 00:55:00+03	50000.00
EAD970	2017-08-09 21:24:00+03	37200.00
EAD97F	2017-07-24 06:25:00+03	51600.00
EAD9A0	2017-08-06 20:32:00+03	6700.00
EAD9A3	2017-08-10 04:36:00+03	39500.00
EAD9E4	2017-07-16 21:03:00+03	19600.00
EADA15	2017-07-28 05:03:00+03	66600.00
EADA40	2017-08-04 20:55:00+03	115300.00
EADA50	2017-07-21 09:47:00+03	28000.00
EADA79	2017-07-18 13:27:00+03	93900.00
EADAF5	2017-07-19 18:02:00+03	52700.00
EADB11	2017-08-08 13:40:00+03	27200.00
EADB4C	2017-08-09 23:09:00+03	102600.00
EADBF7	2017-07-02 04:30:00+03	147700.00
EADC0A	2017-08-05 07:22:00+03	57500.00
EADC2D	2017-08-09 12:14:00+03	26000.00
EADC37	2017-07-31 00:27:00+03	77200.00
EADC52	2017-07-01 19:32:00+03	101600.00
EADC5C	2017-07-20 20:27:00+03	14400.00
EADCA1	2017-07-24 08:30:00+03	184300.00
EADCB7	2017-07-10 20:57:00+03	36000.00
EADCED	2017-08-04 01:22:00+03	13700.00
EADCF2	2017-08-13 18:06:00+03	23200.00
EADDA6	2017-08-02 23:54:00+03	265200.00
EADE18	2017-07-24 20:05:00+03	55800.00
EADE5A	2017-07-25 07:14:00+03	67600.00
EADE7E	2017-06-29 09:38:00+03	109200.00
EADF49	2017-08-08 18:01:00+03	15100.00
EADFE1	2017-08-07 14:26:00+03	19600.00
EAE030	2017-07-12 09:39:00+03	193200.00
EAE044	2017-06-30 03:51:00+03	9300.00
EAE06E	2017-07-27 06:12:00+03	67800.00
EAE079	2017-06-29 12:19:00+03	68800.00
EAE093	2017-07-11 08:17:00+03	15100.00
EAE0D9	2017-07-22 10:40:00+03	38800.00
EAE0DD	2017-07-09 18:08:00+03	47200.00
EAE16F	2017-07-20 09:03:00+03	57500.00
EAE173	2017-07-30 06:48:00+03	30800.00
EAE1B6	2017-08-14 20:10:00+03	126500.00
EAE1D0	2017-07-07 04:18:00+03	46300.00
EAE1E8	2017-07-01 10:37:00+03	14800.00
EAE244	2017-07-20 10:07:00+03	78300.00
EAE264	2017-07-26 15:18:00+03	48800.00
EAE272	2017-07-18 12:47:00+03	94200.00
EAE288	2017-08-12 21:52:00+03	88600.00
EAE2CA	2017-07-12 10:37:00+03	91500.00
EAE2D8	2017-07-27 02:42:00+03	93800.00
EAE336	2017-08-15 17:05:00+03	40600.00
EAE34C	2017-08-05 17:30:00+03	24400.00
EAE36F	2017-08-13 07:50:00+03	57400.00
EAE3F3	2017-07-24 23:45:00+03	44800.00
EAE428	2017-07-02 11:46:00+03	47000.00
EAE455	2017-07-08 04:16:00+03	76400.00
EAE468	2017-07-29 22:47:00+03	40400.00
EAE49E	2017-07-12 20:16:00+03	25600.00
EAE4C2	2017-07-29 23:04:00+03	26800.00
EAE4CD	2017-08-06 04:36:00+03	153900.00
EAE4F1	2017-07-27 09:06:00+03	72800.00
EAE4F8	2017-07-11 11:55:00+03	42800.00
EAE52B	2017-08-08 02:25:00+03	52400.00
EAE53C	2017-08-05 10:02:00+03	32600.00
EAE545	2017-07-13 00:24:00+03	46000.00
EAE548	2017-08-02 12:55:00+03	46900.00
EAE553	2017-07-09 01:23:00+03	100600.00
EAE5D4	2017-08-11 08:34:00+03	8200.00
EAE60B	2017-07-29 10:57:00+03	114700.00
EAE647	2017-08-03 08:38:00+03	40600.00
EAE665	2017-07-25 13:18:00+03	177600.00
EAE681	2017-07-11 16:44:00+03	55400.00
EAE6B5	2017-08-12 05:24:00+03	62600.00
EAE704	2017-08-07 19:50:00+03	25200.00
EAE71A	2017-08-13 21:27:00+03	53600.00
EAE735	2017-07-13 21:15:00+03	29300.00
EAE7A6	2017-08-14 20:23:00+03	18600.00
EAE8D1	2017-07-26 10:18:00+03	25000.00
EAE947	2017-07-23 07:17:00+03	28800.00
EAE94F	2017-08-15 07:46:00+03	88800.00
EAE9A7	2017-08-14 05:59:00+03	28200.00
EAEA0B	2017-08-10 08:25:00+03	26000.00
EAEA10	2017-07-30 06:13:00+03	65000.00
EAEA2D	2017-07-04 07:18:00+03	101800.00
EAEA7D	2017-08-04 12:59:00+03	81700.00
EAEA7F	2017-07-07 11:39:00+03	199700.00
EAEAA1	2017-07-02 12:31:00+03	89600.00
EAEAC2	2017-08-09 15:58:00+03	23200.00
EAEBAA	2017-07-27 16:26:00+03	46300.00
EAEBC6	2017-08-03 12:17:00+03	141400.00
EAEBDA	2017-07-22 12:15:00+03	27300.00
EAEBEC	2017-08-14 20:31:00+03	69400.00
EAEBFF	2017-07-15 11:07:00+03	38500.00
EAEC03	2017-07-04 15:47:00+03	86400.00
EAEC27	2017-07-28 13:37:00+03	47400.00
EAEC28	2017-07-18 05:30:00+03	23100.00
EAEC31	2017-07-13 21:43:00+03	101200.00
EAEC7A	2017-08-08 21:35:00+03	44600.00
EAECA0	2017-07-18 01:04:00+03	81600.00
EAECA5	2017-07-06 01:02:00+03	24400.00
EAECBF	2017-07-31 12:54:00+03	26000.00
EAECD6	2017-07-24 02:19:00+03	9800.00
EAECDB	2017-08-06 06:57:00+03	38400.00
EAED5D	2017-07-11 03:52:00+03	258300.00
EAEDE5	2017-08-03 09:37:00+03	25600.00
EAEE7B	2017-07-10 08:04:00+03	196000.00
EAEF52	2017-07-28 10:07:00+03	132000.00
EAEF58	2017-07-31 18:03:00+03	104900.00
EAEFE1	2017-07-18 03:36:00+03	107500.00
EAF05D	2017-07-13 17:05:00+03	32300.00
EAF079	2017-08-15 09:25:00+03	384900.00
EAF099	2017-07-03 03:27:00+03	125400.00
EAF0FA	2017-08-01 20:13:00+03	89700.00
EAF10F	2017-07-30 14:34:00+03	78300.00
EAF12E	2017-07-09 07:25:00+03	123000.00
EAF184	2017-06-28 21:28:00+03	58800.00
EAF1C2	2017-08-14 17:29:00+03	123500.00
EAF1D8	2017-08-03 05:40:00+03	40200.00
EAF1E2	2017-08-09 18:16:00+03	81600.00
EAF258	2017-07-18 09:04:00+03	88800.00
EAF28F	2017-08-03 05:10:00+03	542100.00
EAF2A8	2017-08-06 00:04:00+03	83000.00
EAF347	2017-08-02 01:20:00+03	28000.00
EAF3A6	2017-08-15 10:19:00+03	78000.00
EAF3AA	2017-07-20 01:03:00+03	58800.00
EAF3EE	2017-08-14 19:03:00+03	37700.00
EAF417	2017-07-13 01:00:00+03	30200.00
EAF430	2017-07-26 11:23:00+03	66400.00
EAF45E	2017-07-06 17:02:00+03	129600.00
EAF465	2017-07-27 04:08:00+03	14800.00
EAF48B	2017-08-13 16:45:00+03	37600.00
EAF497	2017-07-16 04:28:00+03	6300.00
EAF531	2017-07-08 05:24:00+03	284300.00
EAF538	2017-07-03 14:04:00+03	47100.00
EAF546	2017-07-22 03:30:00+03	39300.00
EAF559	2017-08-11 19:37:00+03	47000.00
EAF5A6	2017-08-05 16:16:00+03	48700.00
EAF5D1	2017-06-30 10:50:00+03	78500.00
EAF5DF	2017-07-06 02:33:00+03	44600.00
EAF629	2017-07-03 14:00:00+03	29400.00
EAF793	2017-07-09 07:12:00+03	36400.00
EAF7D1	2017-08-05 09:37:00+03	56200.00
EAF84A	2017-08-15 15:29:00+03	37200.00
EAF908	2017-08-14 15:41:00+03	14000.00
EAF95E	2017-07-19 15:09:00+03	92700.00
EAF982	2017-07-29 06:19:00+03	149200.00
EAF9EE	2017-07-27 20:29:00+03	55900.00
EAFA3F	2017-07-18 19:57:00+03	80800.00
EAFAF8	2017-08-07 05:02:00+03	40800.00
EAFB17	2017-08-05 10:29:00+03	128100.00
EAFBCF	2017-07-23 01:09:00+03	173300.00
EAFC0B	2017-07-18 09:29:00+03	6000.00
EAFC55	2017-08-04 19:12:00+03	34100.00
EAFC58	2017-07-11 21:04:00+03	80000.00
EAFC89	2017-08-12 01:46:00+03	6300.00
EAFD16	2017-08-04 02:46:00+03	16400.00
EAFD5C	2017-07-09 20:48:00+03	87800.00
EAFD6F	2017-07-17 10:50:00+03	26500.00
EAFD9F	2017-08-03 10:02:00+03	113900.00
EAFDC1	2017-08-11 01:19:00+03	664100.00
EAFE5D	2017-08-11 12:09:00+03	34300.00
EAFEA7	2017-07-25 07:33:00+03	133100.00
EAFEC1	2017-07-16 02:49:00+03	177200.00
EAFEFA	2017-07-05 19:01:00+03	36200.00
EAFF02	2017-07-15 17:38:00+03	131100.00
EAFF4F	2017-08-08 02:42:00+03	27600.00
EAFF93	2017-08-04 05:21:00+03	13400.00
EAFF99	2017-07-28 11:22:00+03	93900.00
EAFFC6	2017-08-14 23:23:00+03	72200.00
EAFFCC	2017-07-06 09:31:00+03	142400.00
EAFFDF	2017-07-29 18:35:00+03	78600.00
EB0023	2017-07-27 14:26:00+03	34800.00
EB0095	2017-06-28 14:28:00+03	95600.00
EB0106	2017-07-19 09:45:00+03	492000.00
EB0136	2017-07-29 10:29:00+03	100600.00
EB016F	2017-07-10 12:21:00+03	167400.00
EB0177	2017-07-03 09:31:00+03	49200.00
EB01B6	2017-08-01 07:02:00+03	88000.00
EB01D2	2017-07-03 01:58:00+03	23200.00
EB01E6	2017-07-02 12:45:00+03	67200.00
EB0223	2017-07-09 01:36:00+03	283600.00
EB029A	2017-07-02 00:09:00+03	46500.00
EB02A8	2017-07-13 11:56:00+03	23200.00
EB02A9	2017-07-03 06:31:00+03	26000.00
EB02E5	2017-07-18 00:17:00+03	67000.00
EB030A	2017-08-15 12:40:00+03	193700.00
EB0334	2017-07-15 10:10:00+03	13400.00
EB03CF	2017-07-10 05:36:00+03	20400.00
EB04C0	2017-07-28 16:57:00+03	48800.00
EB04D5	2017-08-04 05:08:00+03	133200.00
EB04E9	2017-07-01 08:50:00+03	112000.00
EB053A	2017-08-10 21:28:00+03	60400.00
EB053B	2017-07-16 01:03:00+03	28000.00
EB0548	2017-07-08 13:46:00+03	27200.00
EB0583	2017-07-15 19:00:00+03	42800.00
EB0616	2017-07-13 23:14:00+03	53200.00
EB06BF	2017-08-08 03:32:00+03	27700.00
EB0747	2017-07-10 16:57:00+03	99300.00
EB07A0	2017-07-09 11:07:00+03	38600.00
EB0812	2017-07-21 03:44:00+03	92800.00
EB0821	2017-08-15 05:38:00+03	193600.00
EB082F	2017-07-09 23:45:00+03	99300.00
EB0850	2017-07-12 10:46:00+03	25400.00
EB085E	2017-07-15 16:07:00+03	369000.00
EB0891	2017-07-18 20:59:00+03	22000.00
EB0912	2017-07-11 22:00:00+03	105100.00
EB0948	2017-08-05 13:16:00+03	246100.00
EB09BA	2017-07-05 23:34:00+03	41800.00
EB0ABD	2017-08-09 11:21:00+03	37200.00
EB0B30	2017-07-13 21:08:00+03	125200.00
EB0B66	2017-07-07 15:29:00+03	108000.00
EB0B6E	2017-07-26 07:45:00+03	12000.00
EB0BC4	2017-07-02 21:51:00+03	129200.00
EB0BDB	2017-08-15 17:58:00+03	18400.00
EB0C45	2017-08-04 09:10:00+03	13200.00
EB0C4A	2017-07-08 22:50:00+03	296700.00
EB0CC8	2017-07-11 09:05:00+03	25100.00
EB0CE9	2017-07-17 21:24:00+03	32700.00
EB0D68	2017-07-10 01:55:00+03	58600.00
EB0D75	2017-07-29 06:26:00+03	46400.00
EB0DB9	2017-07-13 08:36:00+03	37100.00
EB0DE5	2017-07-15 14:07:00+03	57500.00
EB0E72	2017-07-27 08:37:00+03	28800.00
EB0EB1	2017-07-16 00:16:00+03	36800.00
EB0F2F	2017-08-07 11:58:00+03	22000.00
EB0FB2	2017-06-28 13:15:00+03	68800.00
EB0FB9	2017-06-25 20:01:00+03	51800.00
EB0FBD	2017-08-12 18:33:00+03	167500.00
EB0FD3	2017-07-21 06:02:00+03	54800.00
EB1041	2017-08-06 02:41:00+03	265800.00
EB107C	2017-08-04 08:09:00+03	23200.00
EB1100	2017-07-12 08:15:00+03	83000.00
EB1110	2017-07-26 03:52:00+03	46400.00
EB112A	2017-07-01 22:02:00+03	16400.00
EB1197	2017-07-12 06:46:00+03	15000.00
EB11BB	2017-07-06 08:02:00+03	6700.00
EB11CA	2017-07-24 03:52:00+03	531400.00
EB1247	2017-07-01 08:58:00+03	54600.00
EB12A7	2017-08-01 17:58:00+03	293100.00
EB12E7	2017-07-22 10:46:00+03	46400.00
EB12F3	2017-08-13 10:06:00+03	133200.00
EB1329	2017-08-14 10:10:00+03	48800.00
EB13A6	2017-08-06 20:55:00+03	135600.00
EB13EE	2017-07-09 05:57:00+03	67600.00
EB13F5	2017-07-26 08:30:00+03	40600.00
EB1460	2017-07-23 08:23:00+03	37900.00
EB1470	2017-07-04 00:09:00+03	203800.00
EB14D7	2017-07-11 22:47:00+03	12600.00
EB153D	2017-08-15 16:30:00+03	128800.00
EB156F	2017-08-12 14:01:00+03	136300.00
EB15BB	2017-08-11 11:02:00+03	15900.00
EB15BE	2017-07-19 16:19:00+03	45200.00
EB15DB	2017-07-22 00:37:00+03	134400.00
EB160A	2017-07-28 00:47:00+03	14900.00
EB1702	2017-07-29 14:56:00+03	37100.00
EB1783	2017-08-12 01:44:00+03	26000.00
EB178F	2017-06-29 06:39:00+03	38200.00
EB17CE	2017-07-24 14:36:00+03	27500.00
EB17E4	2017-08-01 03:28:00+03	47100.00
EB1832	2017-08-03 06:37:00+03	93400.00
EB1879	2017-08-04 09:01:00+03	34000.00
EB187E	2017-08-11 03:00:00+03	122800.00
EB18AD	2017-07-26 11:53:00+03	136800.00
EB18DD	2017-08-03 18:15:00+03	19600.00
EB18EC	2017-07-27 22:44:00+03	23600.00
EB18ED	2017-08-04 14:30:00+03	93100.00
EB18FD	2017-08-06 01:22:00+03	108000.00
EB19E5	2017-08-11 06:18:00+03	46900.00
EB1ACF	2017-08-08 01:27:00+03	42800.00
EB1B97	2017-07-21 05:53:00+03	6300.00
EB1BAB	2017-08-13 12:59:00+03	22200.00
EB1BEA	2017-07-10 18:21:00+03	54000.00
EB1BED	2017-07-29 09:07:00+03	12600.00
EB1C1D	2017-07-17 22:38:00+03	54500.00
EB1C4F	2017-08-04 11:11:00+03	21400.00
EB1C54	2017-08-05 13:05:00+03	126300.00
EB1CA2	2017-08-06 13:16:00+03	6000.00
EB1D1E	2017-07-15 13:53:00+03	8200.00
EB1D39	2017-08-06 10:33:00+03	179400.00
EB1D77	2017-07-23 13:01:00+03	28800.00
EB1E23	2017-06-29 09:12:00+03	11300.00
EB1E86	2017-08-11 11:51:00+03	59800.00
EB1EFE	2017-07-10 04:53:00+03	126500.00
EB1F37	2017-08-12 01:29:00+03	25100.00
EB1F83	2017-07-14 10:57:00+03	21200.00
EB1FB6	2017-07-16 04:57:00+03	86300.00
EB2001	2017-07-28 05:42:00+03	64800.00
EB2003	2017-07-15 19:29:00+03	111600.00
EB2036	2017-07-30 18:40:00+03	111600.00
EB203B	2017-07-28 23:44:00+03	70600.00
EB2040	2017-08-06 01:53:00+03	27200.00
EB20DA	2017-07-27 19:16:00+03	94800.00
EB2162	2017-08-06 19:15:00+03	37200.00
EB21D2	2017-07-14 21:45:00+03	15400.00
EB21E7	2017-07-13 09:35:00+03	23900.00
EB21FB	2017-07-08 23:39:00+03	64900.00
EB228E	2017-07-21 20:17:00+03	10600.00
EB2304	2017-07-20 12:09:00+03	30200.00
EB23C8	2017-07-14 07:03:00+03	46200.00
EB24AD	2017-07-12 08:11:00+03	15800.00
EB24BE	2017-07-25 09:43:00+03	30900.00
EB2542	2017-08-07 05:30:00+03	119500.00
EB25AC	2017-07-21 09:13:00+03	202000.00
EB2624	2017-08-08 00:58:00+03	37600.00
EB268F	2017-07-08 02:45:00+03	53800.00
EB26CB	2017-08-05 15:49:00+03	14400.00
EB26FC	2017-07-03 23:35:00+03	131000.00
EB2712	2017-07-14 18:11:00+03	15000.00
EB2714	2017-08-10 04:40:00+03	72400.00
EB2720	2017-07-20 19:05:00+03	86400.00
EB274C	2017-08-15 11:21:00+03	54500.00
EB2763	2017-07-22 12:05:00+03	47100.00
EB27A2	2017-08-07 03:35:00+03	44300.00
EB27C1	2017-08-06 14:15:00+03	67600.00
EB27CC	2017-07-26 21:28:00+03	109300.00
EB28A0	2017-08-08 04:36:00+03	44000.00
EB28F0	2017-08-01 06:09:00+03	56000.00
EB2912	2017-08-06 08:34:00+03	11600.00
EB2927	2017-08-10 19:36:00+03	40000.00
EB2928	2017-07-27 22:59:00+03	40800.00
EB295A	2017-08-10 14:09:00+03	168000.00
EB295F	2017-07-28 00:27:00+03	123000.00
EB29E8	2017-07-27 19:10:00+03	12400.00
EB29F4	2017-07-24 12:59:00+03	215600.00
EB2A87	2017-07-04 02:40:00+03	24000.00
EB2AD7	2017-08-05 17:05:00+03	73200.00
EB2B29	2017-07-21 13:19:00+03	45200.00
EB2C00	2017-07-03 12:53:00+03	78200.00
EB2C55	2017-07-02 17:20:00+03	21400.00
EB2C96	2017-08-12 08:50:00+03	7400.00
EB2CB3	2017-06-30 17:33:00+03	82900.00
EB2CCD	2017-07-16 23:47:00+03	21800.00
EB2D19	2017-07-19 10:23:00+03	14400.00
EB2D61	2017-08-15 07:50:00+03	48400.00
EB2D7F	2017-07-24 08:16:00+03	92800.00
EB2DA0	2017-07-16 05:38:00+03	50400.00
EB2DDB	2017-07-04 09:25:00+03	30400.00
EB2E2D	2017-08-14 16:51:00+03	63200.00
EB2E51	2017-08-13 11:41:00+03	56000.00
EB2ECB	2017-08-09 05:33:00+03	65900.00
EB2ED3	2017-07-09 05:08:00+03	128900.00
EB2EF9	2017-07-10 18:14:00+03	123000.00
EB2F4B	2017-06-30 08:32:00+03	20200.00
EB2FC8	2017-07-11 20:30:00+03	57300.00
EB3050	2017-07-17 22:33:00+03	402700.00
EB312F	2017-08-09 15:45:00+03	30000.00
EB3173	2017-07-10 15:46:00+03	57400.00
EB317C	2017-07-14 16:53:00+03	23200.00
EB31B1	2017-07-24 05:53:00+03	70700.00
EB320B	2017-07-06 05:53:00+03	139300.00
EB32A1	2017-08-01 00:03:00+03	131100.00
EB32BE	2017-07-19 07:34:00+03	35200.00
EB32DB	2017-07-13 11:16:00+03	30900.00
EB332E	2017-07-25 00:14:00+03	35700.00
EB334F	2017-08-02 06:21:00+03	76200.00
EB337A	2017-07-06 20:23:00+03	44500.00
EB33D2	2017-07-19 22:44:00+03	55800.00
EB3474	2017-07-12 11:54:00+03	249100.00
EB34DC	2017-08-06 18:13:00+03	39600.00
EB34F1	2017-08-15 16:23:00+03	148800.00
EB3551	2017-07-18 14:35:00+03	166700.00
EB358E	2017-07-27 07:41:00+03	40100.00
EB35B6	2017-07-18 06:35:00+03	94500.00
EB35B7	2017-08-10 06:12:00+03	6000.00
EB35D1	2017-07-14 23:01:00+03	398500.00
EB36CF	2017-07-14 22:46:00+03	118900.00
EB36FF	2017-07-09 20:58:00+03	78000.00
EB3707	2017-07-25 20:03:00+03	18600.00
EB3782	2017-07-03 21:31:00+03	18600.00
EB3799	2017-07-13 11:57:00+03	23200.00
EB37C8	2017-08-07 06:06:00+03	28800.00
EB381C	2017-07-17 22:43:00+03	33300.00
EB3909	2017-07-21 17:08:00+03	70700.00
EB39BE	2017-07-01 18:56:00+03	125400.00
EB3A13	2017-08-04 07:32:00+03	28800.00
EB3A46	2017-07-12 09:03:00+03	20000.00
EB3A55	2017-07-23 16:02:00+03	29400.00
EB3A86	2017-07-29 10:29:00+03	46200.00
EB3A88	2017-07-25 16:42:00+03	28000.00
EB3A8C	2017-07-03 00:40:00+03	95200.00
EB3AC0	2017-08-08 13:10:00+03	32800.00
EB3AD1	2017-07-18 15:31:00+03	134400.00
EB3B24	2017-07-09 13:22:00+03	103600.00
EB3B28	2017-07-30 10:51:00+03	155500.00
EB3B95	2017-07-08 08:01:00+03	57600.00
EB3B9A	2017-07-28 20:22:00+03	187600.00
EB3BA7	2017-07-04 17:19:00+03	105200.00
EB3BDD	2017-07-05 10:09:00+03	81900.00
EB3C0C	2017-07-20 21:34:00+03	23400.00
EB3CB0	2017-08-13 18:54:00+03	60700.00
EB3CB4	2017-07-11 06:53:00+03	55800.00
EB3D21	2017-08-13 17:04:00+03	152900.00
EB3D45	2017-07-15 02:12:00+03	33300.00
EB3D85	2017-08-07 11:56:00+03	67600.00
EB3DC1	2017-07-12 22:21:00+03	62600.00
EB3F17	2017-07-04 01:47:00+03	55700.00
EB3F6C	2017-08-07 21:25:00+03	53600.00
EB3F7F	2017-08-13 12:38:00+03	48500.00
EB3F9A	2017-07-05 18:28:00+03	116800.00
EB3FAB	2017-07-11 04:06:00+03	24800.00
EB3FB4	2017-07-08 05:29:00+03	94000.00
EB3FD1	2017-08-06 21:46:00+03	28800.00
EB4098	2017-07-12 09:05:00+03	165500.00
EB411A	2017-07-04 16:22:00+03	27300.00
EB4120	2017-07-25 08:32:00+03	166000.00
EB4129	2017-08-01 11:37:00+03	26000.00
EB41A9	2017-08-02 13:49:00+03	26000.00
EB41B4	2017-08-11 19:51:00+03	17200.00
EB4226	2017-07-03 17:02:00+03	26000.00
EB42B8	2017-07-24 08:54:00+03	118500.00
EB4346	2017-07-04 00:53:00+03	202300.00
EB437D	2017-07-02 08:25:00+03	166900.00
EB4396	2017-08-03 16:15:00+03	20400.00
EB43DC	2017-08-09 04:03:00+03	8200.00
EB442A	2017-08-05 07:12:00+03	112600.00
EB442C	2017-07-22 05:37:00+03	23600.00
EB44A0	2017-07-31 16:30:00+03	55800.00
EB4504	2017-07-07 13:04:00+03	161800.00
EB452B	2017-07-11 12:01:00+03	172600.00
EB4580	2017-08-15 13:08:00+03	88000.00
EB463E	2017-07-23 12:40:00+03	46400.00
EB465D	2017-07-11 14:29:00+03	57400.00
EB469D	2017-08-09 15:11:00+03	38600.00
EB46C3	2017-07-27 12:58:00+03	39800.00
EB4768	2017-07-26 10:42:00+03	39300.00
EB4773	2017-07-19 19:48:00+03	35800.00
EB47B6	2017-07-22 17:07:00+03	56000.00
EB4805	2017-07-30 09:50:00+03	64600.00
EB4827	2017-07-12 12:13:00+03	46200.00
EB4899	2017-07-16 03:38:00+03	63400.00
EB48B5	2017-07-30 19:27:00+03	38800.00
EB48C7	2017-08-12 18:10:00+03	119600.00
EB48C9	2017-07-11 04:52:00+03	66000.00
EB48ED	2017-08-04 10:42:00+03	56000.00
EB491D	2017-08-04 00:10:00+03	28000.00
EB496C	2017-08-02 14:32:00+03	8400.00
EB4A0A	2017-08-11 01:35:00+03	272400.00
EB4A30	2017-07-28 11:36:00+03	62200.00
EB4A4D	2017-08-02 07:00:00+03	75300.00
EB4AEF	2017-08-15 16:46:00+03	55800.00
EB4B11	2017-08-12 13:03:00+03	51800.00
EB4B19	2017-06-27 23:07:00+03	53800.00
EB4B5B	2017-07-30 17:28:00+03	65900.00
EB4B89	2017-08-01 08:16:00+03	203000.00
EB4BFD	2017-07-17 09:54:00+03	21400.00
EB4C58	2017-07-02 15:41:00+03	108500.00
EB4CA0	2017-08-12 04:58:00+03	18600.00
EB4CAC	2017-07-14 21:35:00+03	66600.00
EB4D54	2017-07-05 14:42:00+03	277900.00
EB4D70	2017-07-25 14:44:00+03	10600.00
EB4D9A	2017-07-18 16:40:00+03	6000.00
EB4DB8	2017-07-06 12:58:00+03	64500.00
EB4DCF	2017-07-25 23:01:00+03	35200.00
EB4E0A	2017-07-28 16:55:00+03	24400.00
EB4E70	2017-08-02 14:19:00+03	69000.00
EB4E97	2017-07-07 06:53:00+03	21200.00
EB4E9B	2017-08-15 08:35:00+03	27900.00
EB4EEE	2017-08-13 19:34:00+03	78400.00
EB4F35	2017-07-30 13:18:00+03	55800.00
EB4FC0	2017-08-08 18:42:00+03	148200.00
EB4FF1	2017-07-30 20:15:00+03	37900.00
EB5018	2017-08-08 08:38:00+03	70200.00
EB5073	2017-07-23 02:28:00+03	23200.00
EB5079	2017-07-13 06:27:00+03	153300.00
EB50BB	2017-07-19 18:56:00+03	168000.00
EB50C3	2017-07-03 11:00:00+03	46300.00
EB5109	2017-08-10 20:27:00+03	52000.00
EB5111	2017-07-04 00:47:00+03	56000.00
EB515E	2017-08-13 05:59:00+03	31000.00
EB51CE	2017-07-03 08:20:00+03	8400.00
EB520B	2017-07-28 16:37:00+03	16400.00
EB523C	2017-08-12 07:26:00+03	20600.00
EB5272	2017-07-31 05:42:00+03	92700.00
EB527C	2017-08-08 05:47:00+03	46000.00
EB52B0	2017-07-19 06:47:00+03	81700.00
EB5348	2017-08-15 02:05:00+03	25600.00
EB53C9	2017-08-13 12:38:00+03	405000.00
EB53D1	2017-07-25 03:05:00+03	56000.00
EB5419	2017-07-27 03:53:00+03	8200.00
EB547D	2017-06-28 13:16:00+03	103800.00
EB5497	2017-08-12 00:22:00+03	114600.00
EB54BE	2017-07-12 21:41:00+03	24400.00
EB552D	2017-07-18 17:14:00+03	304100.00
EB556A	2017-07-30 16:25:00+03	54600.00
EB55F3	2017-07-16 02:55:00+03	40400.00
EB5640	2017-08-10 15:24:00+03	14400.00
EB568B	2017-08-07 11:55:00+03	198400.00
EB578A	2017-08-09 12:59:00+03	332700.00
EB5797	2017-08-06 21:30:00+03	99200.00
EB57BC	2017-08-02 04:45:00+03	25400.00
EB57E2	2017-08-01 00:16:00+03	49300.00
EB57E5	2017-07-07 12:26:00+03	125200.00
EB5805	2017-08-04 18:36:00+03	90400.00
EB584C	2017-07-19 02:24:00+03	19600.00
EB5865	2017-08-11 19:40:00+03	58600.00
EB5879	2017-08-13 00:28:00+03	7800.00
EB587D	2017-07-12 13:01:00+03	108700.00
EB58E9	2017-07-13 14:05:00+03	58600.00
EB59A0	2017-07-14 20:12:00+03	136200.00
EB59A4	2017-07-28 13:42:00+03	28000.00
EB59E5	2017-08-15 14:45:00+03	60400.00
EB59F8	2017-07-13 00:08:00+03	89400.00
EB5A20	2017-07-22 01:06:00+03	56000.00
EB5A3C	2017-07-25 16:41:00+03	114800.00
EB5A49	2017-08-08 23:39:00+03	199700.00
EB5A9E	2017-07-13 01:24:00+03	49500.00
EB5AD0	2017-08-08 20:43:00+03	124100.00
EB5AF8	2017-07-17 08:25:00+03	50800.00
EB5B3C	2017-07-12 21:14:00+03	62600.00
EB5B4B	2017-08-15 12:40:00+03	88500.00
EB5B61	2017-07-22 10:54:00+03	7400.00
EB5B67	2017-08-06 15:12:00+03	100600.00
EB5BA5	2017-08-07 00:13:00+03	53300.00
EB5BD4	2017-08-06 03:27:00+03	67000.00
EB5BF3	2017-07-21 07:45:00+03	19600.00
EB5CB2	2017-07-08 00:19:00+03	42700.00
EB5CEC	2017-08-03 19:41:00+03	16400.00
EB5D0F	2017-07-09 05:40:00+03	29600.00
EB5E04	2017-08-04 02:54:00+03	27200.00
EB5E0B	2017-08-01 11:25:00+03	58600.00
EB5E41	2017-07-04 17:44:00+03	68800.00
EB5E75	2017-07-13 14:14:00+03	28800.00
EB5FCE	2017-07-28 05:01:00+03	35200.00
EB5FD9	2017-07-21 16:50:00+03	14400.00
EB60C4	2017-07-12 05:45:00+03	71200.00
EB611D	2017-07-19 07:13:00+03	39700.00
EB615C	2017-08-09 18:32:00+03	49100.00
EB622E	2017-07-04 15:49:00+03	32800.00
EB627D	2017-07-30 15:11:00+03	28800.00
EB628A	2017-07-28 02:04:00+03	100700.00
EB62AF	2017-08-10 01:11:00+03	23200.00
EB62BD	2017-07-07 01:53:00+03	54800.00
EB62D4	2017-07-13 00:59:00+03	65500.00
EB62DC	2017-07-09 05:58:00+03	70400.00
EB636A	2017-08-11 21:57:00+03	127100.00
EB63B7	2017-08-02 12:56:00+03	42000.00
EB63CD	2017-07-01 01:04:00+03	64800.00
EB63DA	2017-06-28 06:57:00+03	28000.00
EB645B	2017-07-02 12:31:00+03	64600.00
EB6477	2017-08-15 02:08:00+03	47400.00
EB6516	2017-07-31 20:25:00+03	52700.00
EB6578	2017-07-04 20:23:00+03	95000.00
EB65FC	2017-07-20 22:08:00+03	37100.00
EB663D	2017-08-03 14:18:00+03	6000.00
EB6679	2017-07-12 12:55:00+03	40000.00
EB66A5	2017-07-08 04:06:00+03	8200.00
EB66CE	2017-08-04 06:19:00+03	56000.00
EB6718	2017-07-22 22:01:00+03	131100.00
EB6778	2017-08-12 09:18:00+03	58600.00
EB67AC	2017-08-14 16:10:00+03	83000.00
EB6826	2017-08-05 16:54:00+03	28000.00
EB684E	2017-07-27 08:31:00+03	27200.00
EB689D	2017-07-20 11:22:00+03	80300.00
EB689E	2017-07-09 04:59:00+03	668700.00
EB68B1	2017-07-25 10:14:00+03	46500.00
EB68D5	2017-08-09 00:08:00+03	18400.00
EB68E1	2017-07-18 05:37:00+03	24300.00
EB68ED	2017-08-10 19:37:00+03	36500.00
EB68F9	2017-07-28 06:39:00+03	55800.00
EB6925	2017-07-11 02:07:00+03	84500.00
EB6932	2017-07-21 00:40:00+03	36600.00
EB6934	2017-07-20 00:00:00+03	23200.00
EB6961	2017-06-27 09:14:00+03	14400.00
EB69AC	2017-07-28 12:40:00+03	14000.00
EB6AB0	2017-07-01 12:50:00+03	131600.00
EB6AC2	2017-07-27 06:25:00+03	65200.00
EB6ACD	2017-07-30 20:43:00+03	86500.00
EB6B48	2017-07-16 12:02:00+03	105400.00
EB6B7B	2017-07-25 20:09:00+03	51300.00
EB6BC3	2017-08-09 17:49:00+03	38400.00
EB6BCC	2017-07-21 02:09:00+03	400900.00
EB6C10	2017-07-31 22:47:00+03	103000.00
EB6D18	2017-07-05 11:01:00+03	42700.00
EB6D2C	2017-07-06 23:20:00+03	32700.00
EB6D6A	2017-07-03 01:52:00+03	44800.00
EB6D7C	2017-07-27 20:03:00+03	37200.00
EB6DAB	2017-08-04 07:42:00+03	161500.00
EB6DAC	2017-07-06 23:44:00+03	47200.00
EB6DDC	2017-08-08 01:04:00+03	57100.00
EB6E35	2017-07-08 11:01:00+03	37900.00
EB6EBD	2017-07-22 04:39:00+03	17000.00
EB6F64	2017-08-05 19:46:00+03	6700.00
EB6F6C	2017-07-18 22:16:00+03	40300.00
EB6F6D	2017-07-12 17:54:00+03	68800.00
EB701D	2017-07-26 10:41:00+03	25600.00
EB7050	2017-07-20 13:53:00+03	56000.00
EB7065	2017-07-27 08:53:00+03	24400.00
EB70DD	2017-07-07 07:30:00+03	38600.00
EB70F4	2017-07-24 09:08:00+03	75200.00
EB70F7	2017-07-28 09:40:00+03	92800.00
EB7281	2017-07-10 15:49:00+03	121400.00
EB7287	2017-07-14 12:37:00+03	25100.00
EB7317	2017-08-11 07:09:00+03	30000.00
EB731C	2017-08-07 02:27:00+03	46400.00
EB734E	2017-08-05 13:20:00+03	169900.00
EB73C3	2017-07-01 12:41:00+03	145500.00
EB73ED	2017-07-21 02:47:00+03	33300.00
EB7484	2017-07-31 14:26:00+03	38600.00
EB749D	2017-07-19 08:17:00+03	55800.00
EB74A2	2017-08-11 17:20:00+03	265600.00
EB74AD	2017-07-08 19:28:00+03	47600.00
EB756E	2017-08-10 22:44:00+03	56800.00
EB7580	2017-08-01 10:30:00+03	148400.00
EB75AE	2017-08-14 03:43:00+03	148200.00
EB75D8	2017-07-19 22:51:00+03	6000.00
EB760C	2017-08-05 10:06:00+03	37900.00
EB763F	2017-07-06 14:12:00+03	24700.00
EB7654	2017-07-31 15:59:00+03	56000.00
EB7699	2017-07-01 02:31:00+03	59800.00
EB76E4	2017-07-12 10:46:00+03	50800.00
EB772F	2017-07-31 13:20:00+03	40600.00
EB77DD	2017-08-15 15:24:00+03	137800.00
EB77FE	2017-07-24 08:10:00+03	28000.00
EB7805	2017-08-08 21:21:00+03	62600.00
EB7816	2017-07-30 16:26:00+03	33100.00
EB782D	2017-07-16 21:06:00+03	50600.00
EB786B	2017-08-09 10:51:00+03	65900.00
EB786C	2017-07-16 06:14:00+03	63200.00
EB7897	2017-07-20 13:53:00+03	119700.00
EB789F	2017-07-10 13:51:00+03	142300.00
EB7966	2017-07-05 03:22:00+03	15900.00
EB79BC	2017-08-06 06:00:00+03	100200.00
EB79D7	2017-07-19 05:35:00+03	25600.00
EB7A6C	2017-07-10 15:35:00+03	56000.00
EB7AAA	2017-07-31 03:26:00+03	168000.00
EB7B66	2017-07-22 21:12:00+03	50800.00
EB7BAF	2017-07-26 06:03:00+03	67200.00
EB7C48	2017-07-21 23:24:00+03	182000.00
EB7C67	2017-07-22 23:48:00+03	51300.00
EB7C6A	2017-07-10 01:52:00+03	124200.00
EB7C96	2017-07-04 17:38:00+03	37900.00
EB7CBD	2017-07-26 21:06:00+03	13400.00
EB7CDD	2017-07-21 02:13:00+03	21200.00
EB7CF0	2017-08-01 22:56:00+03	66000.00
EB7D42	2017-08-13 18:50:00+03	80400.00
EB7DB9	2017-08-07 13:51:00+03	272400.00
EB7E68	2017-08-15 04:27:00+03	26700.00
EB7EFB	2017-07-02 06:08:00+03	46200.00
EB7F83	2017-07-21 01:53:00+03	15700.00
EB7F8B	2017-07-11 09:05:00+03	113100.00
EB7FDC	2017-08-02 10:08:00+03	71000.00
EB7FE9	2017-07-25 21:57:00+03	40200.00
EB8013	2017-07-10 19:45:00+03	56000.00
EB803C	2017-07-02 05:47:00+03	62800.00
EB8089	2017-08-13 05:02:00+03	19800.00
EB80DE	2017-07-02 09:26:00+03	36200.00
EB80F7	2017-07-03 23:01:00+03	56000.00
EB811A	2017-08-11 18:18:00+03	76600.00
EB811B	2017-08-13 21:34:00+03	12000.00
EB816B	2017-08-12 12:34:00+03	87900.00
EB818C	2017-07-31 23:27:00+03	45100.00
EB8258	2017-07-16 10:37:00+03	40800.00
EB825C	2017-08-05 15:41:00+03	65900.00
EB8299	2017-07-12 03:12:00+03	16400.00
EB829C	2017-06-30 02:38:00+03	139300.00
EB82AE	2017-08-09 02:40:00+03	38400.00
EB82D8	2017-07-26 10:19:00+03	191000.00
EB831F	2017-07-03 17:56:00+03	13400.00
EB833E	2017-07-02 18:48:00+03	16400.00
EB83B5	2017-07-07 07:00:00+03	55800.00
EB8417	2017-07-09 21:48:00+03	14000.00
EB8486	2017-07-12 10:27:00+03	101200.00
EB84BB	2017-07-22 12:30:00+03	65900.00
EB84EA	2017-08-05 23:40:00+03	42000.00
EB8517	2017-08-12 09:10:00+03	181200.00
EB85CA	2017-08-13 19:05:00+03	41900.00
EB85D6	2017-08-01 17:24:00+03	123000.00
EB860B	2017-07-25 16:14:00+03	55800.00
EB8628	2017-07-25 05:40:00+03	88600.00
EB867B	2017-08-06 01:16:00+03	47000.00
EB86C6	2017-07-25 00:40:00+03	55800.00
EB8777	2017-08-04 15:01:00+03	107700.00
EB8795	2017-07-08 23:26:00+03	105600.00
EB87FD	2017-07-08 22:24:00+03	13600.00
EB882B	2017-08-15 06:12:00+03	41100.00
EB8869	2017-07-11 22:25:00+03	23600.00
EB8878	2017-07-29 11:39:00+03	121400.00
EB88B1	2017-07-09 16:34:00+03	70700.00
EB88DA	2017-08-09 13:33:00+03	10600.00
EB88F3	2017-08-04 10:42:00+03	31600.00
EB890C	2017-08-02 21:48:00+03	26000.00
EB896D	2017-08-06 08:57:00+03	103800.00
EB8971	2017-07-26 17:29:00+03	65600.00
EB8981	2017-07-03 03:37:00+03	12000.00
EB8991	2017-07-22 13:29:00+03	23600.00
EB899E	2017-07-28 23:06:00+03	246000.00
EB89BB	2017-07-31 02:23:00+03	69400.00
EB8A0D	2017-07-07 04:18:00+03	64300.00
EB8A12	2017-07-07 18:57:00+03	58600.00
EB8A8C	2017-07-12 01:38:00+03	7400.00
EB8AB8	2017-07-17 02:31:00+03	21400.00
EB8AE8	2017-08-04 20:09:00+03	168000.00
EB8AFA	2017-08-03 05:11:00+03	93600.00
EB8B04	2017-07-11 05:59:00+03	199700.00
EB8B29	2017-08-04 17:24:00+03	89500.00
EB8B42	2017-08-14 15:25:00+03	179400.00
EB8B58	2017-07-04 21:50:00+03	68400.00
EB8C19	2017-08-03 11:56:00+03	6600.00
EB8D45	2017-07-14 21:56:00+03	88500.00
EB8DC1	2017-07-12 09:07:00+03	81900.00
EB8DF5	2017-07-12 02:41:00+03	63300.00
EB8E09	2017-07-14 16:47:00+03	40800.00
EB8E60	2017-07-07 03:02:00+03	244200.00
EB8E73	2017-07-06 01:28:00+03	30200.00
EB8E97	2017-07-27 09:42:00+03	51300.00
EB8F17	2017-07-20 16:39:00+03	54500.00
EB8F86	2017-08-12 03:05:00+03	61800.00
EB8FB9	2017-07-16 05:27:00+03	84100.00
EB8FE0	2017-06-30 22:10:00+03	32800.00
EB8FE3	2017-07-29 10:22:00+03	33300.00
EB8FE9	2017-06-29 01:33:00+03	23600.00
EB901D	2017-07-07 08:16:00+03	137800.00
EB9071	2017-07-25 20:50:00+03	64300.00
EB9084	2017-08-10 10:03:00+03	35200.00
EB9089	2017-07-01 10:38:00+03	390400.00
EB90BB	2017-07-11 19:14:00+03	6800.00
EB90D1	2017-08-11 02:30:00+03	354400.00
EB90DB	2017-07-13 04:23:00+03	26600.00
EB9115	2017-07-24 21:16:00+03	123000.00
EB9119	2017-07-11 04:10:00+03	92800.00
EB915F	2017-07-08 23:59:00+03	28800.00
EB917A	2017-07-16 02:57:00+03	40000.00
EB9189	2017-07-30 08:37:00+03	111600.00
EB91A4	2017-07-27 17:30:00+03	49200.00
EB91D9	2017-07-31 08:04:00+03	56900.00
EB91EB	2017-07-02 19:51:00+03	41600.00
EB91FA	2017-08-03 06:12:00+03	123000.00
EB9253	2017-07-25 19:04:00+03	92600.00
EB9286	2017-07-23 15:23:00+03	87300.00
EB92BA	2017-08-13 21:14:00+03	22100.00
EB92C4	2017-08-10 20:09:00+03	38800.00
EB92F7	2017-08-11 04:44:00+03	26200.00
EB930C	2017-07-26 11:23:00+03	51600.00
EB9345	2017-07-01 11:46:00+03	22000.00
EB9367	2017-08-05 19:21:00+03	84100.00
EB9405	2017-08-08 02:14:00+03	21800.00
EB941F	2017-07-11 02:44:00+03	66600.00
EB9438	2017-07-05 16:17:00+03	37700.00
EB943A	2017-08-13 22:25:00+03	36700.00
EB9452	2017-08-02 02:04:00+03	47400.00
EB945F	2017-08-15 02:00:00+03	23200.00
EB947A	2017-07-09 14:26:00+03	14800.00
EB9499	2017-07-23 20:53:00+03	39300.00
EB94A7	2017-07-26 11:06:00+03	55800.00
EB94AF	2017-07-25 13:53:00+03	66800.00
EB953D	2017-07-30 03:03:00+03	81300.00
EB955B	2017-08-12 07:59:00+03	104000.00
EB95AB	2017-07-17 22:08:00+03	59800.00
EB95C0	2017-08-08 14:52:00+03	14400.00
EB95CF	2017-07-06 05:55:00+03	22000.00
EB95DA	2017-07-02 12:57:00+03	112000.00
EB964A	2017-07-06 10:11:00+03	118800.00
EB9676	2017-07-13 02:52:00+03	65900.00
EB9685	2017-07-29 21:01:00+03	128800.00
EB9688	2017-07-25 10:16:00+03	20200.00
EB96C7	2017-07-22 17:13:00+03	6300.00
EB96D5	2017-07-07 19:49:00+03	102800.00
EB971E	2017-07-23 01:10:00+03	100600.00
EB9737	2017-07-19 02:01:00+03	86300.00
EB9748	2017-07-17 10:48:00+03	25200.00
EB9760	2017-06-30 14:15:00+03	93900.00
EB97E2	2017-08-08 04:01:00+03	133100.00
EB987B	2017-07-16 05:14:00+03	58000.00
EB98B3	2017-07-21 00:00:00+03	52800.00
EB9917	2017-08-03 21:12:00+03	39900.00
EB9919	2017-07-27 09:22:00+03	136600.00
EB9929	2017-07-15 21:12:00+03	59900.00
EB9951	2017-07-07 19:00:00+03	46800.00
EB9988	2017-08-03 03:28:00+03	14800.00
EB9AFB	2017-07-11 08:23:00+03	115700.00
EB9B53	2017-08-04 06:22:00+03	496700.00
EB9B76	2017-07-13 12:15:00+03	40800.00
EB9B84	2017-07-17 15:11:00+03	40000.00
EB9B8F	2017-07-12 20:26:00+03	51600.00
EB9C39	2017-07-11 15:19:00+03	15000.00
EB9C79	2017-08-06 18:11:00+03	24000.00
EB9C81	2017-08-10 06:36:00+03	25600.00
EB9CEE	2017-08-09 15:47:00+03	24000.00
EB9D04	2017-07-25 04:10:00+03	48500.00
EB9D28	2017-08-10 01:12:00+03	38400.00
EB9D5D	2017-07-25 07:00:00+03	58000.00
EB9DA8	2017-08-14 17:37:00+03	52600.00
EB9E0B	2017-07-01 23:30:00+03	14000.00
EB9E1F	2017-07-28 16:35:00+03	83700.00
EB9E2E	2017-08-07 02:20:00+03	94700.00
EB9E42	2017-08-11 07:28:00+03	133200.00
EB9E60	2017-07-11 20:11:00+03	14000.00
EB9E76	2017-06-29 18:29:00+03	23100.00
EB9E8C	2017-07-25 10:32:00+03	23200.00
EB9F4E	2017-07-13 13:55:00+03	6800.00
EB9F81	2017-07-31 11:11:00+03	46900.00
EB9FEF	2017-08-09 11:34:00+03	56000.00
EBA06B	2017-07-29 15:55:00+03	56600.00
EBA06F	2017-07-30 09:27:00+03	61900.00
EBA0A6	2017-06-30 15:12:00+03	56000.00
EBA0DC	2017-06-30 19:51:00+03	93400.00
EBA0E4	2017-08-07 23:29:00+03	123900.00
EBA0E6	2017-07-15 16:44:00+03	503600.00
EBA125	2017-07-12 09:45:00+03	67300.00
EBA145	2017-08-06 08:08:00+03	6800.00
EBA17C	2017-08-01 23:52:00+03	65900.00
EBA1DB	2017-07-25 05:05:00+03	102200.00
EBA1EA	2017-07-14 14:29:00+03	81300.00
EBA20D	2017-07-21 02:40:00+03	112000.00
EBA31D	2017-08-10 10:35:00+03	50400.00
EBA3A5	2017-08-01 09:00:00+03	28800.00
EBA438	2017-07-24 08:12:00+03	47100.00
EBA439	2017-07-09 13:04:00+03	28800.00
EBA44C	2017-07-14 03:24:00+03	30200.00
EBA464	2017-08-11 19:45:00+03	69500.00
EBA46F	2017-07-22 03:11:00+03	66600.00
EBA471	2017-08-06 21:47:00+03	59900.00
EBA4B9	2017-07-08 17:29:00+03	229800.00
EBA4D2	2017-07-23 09:49:00+03	38600.00
EBA4F7	2017-08-10 17:10:00+03	18600.00
EBA4FA	2017-08-14 18:03:00+03	257500.00
EBA504	2017-08-09 22:37:00+03	24400.00
EBA53B	2017-08-01 15:23:00+03	135400.00
EBA557	2017-08-02 22:35:00+03	72400.00
EBA571	2017-07-13 17:25:00+03	26000.00
EBA592	2017-07-01 18:44:00+03	56000.00
EBA5F9	2017-07-06 23:46:00+03	312900.00
EBA64C	2017-08-09 22:32:00+03	8600.00
EBA68E	2017-07-05 17:54:00+03	180800.00
EBA6D1	2017-07-09 05:21:00+03	6600.00
EBA6D6	2017-07-09 05:07:00+03	123000.00
EBA71A	2017-07-27 07:17:00+03	23600.00
EBA71E	2017-08-01 21:05:00+03	36400.00
EBA749	2017-07-10 17:38:00+03	155600.00
EBA789	2017-07-07 20:29:00+03	266400.00
EBA799	2017-08-06 04:00:00+03	10600.00
EBA806	2017-08-11 20:22:00+03	13300.00
EBA82E	2017-07-24 09:24:00+03	58600.00
EBA855	2017-07-03 19:03:00+03	33200.00
EBA89B	2017-08-08 00:26:00+03	42900.00
EBA8EF	2017-07-16 04:25:00+03	26000.00
EBA963	2017-07-15 02:20:00+03	67600.00
EBA967	2017-07-24 12:19:00+03	73600.00
EBA98E	2017-07-06 19:27:00+03	201600.00
EBA9E0	2017-08-03 20:32:00+03	56000.00
EBAA00	2017-08-14 19:21:00+03	265700.00
EBAAB3	2017-07-11 07:20:00+03	58700.00
EBAAC0	2017-07-21 13:22:00+03	128900.00
EBAB12	2017-07-31 19:13:00+03	28800.00
EBAB38	2017-07-26 19:53:00+03	43200.00
EBAB48	2017-07-10 20:53:00+03	45200.00
EBABDE	2017-08-11 10:01:00+03	260300.00
EBABDF	2017-07-23 07:26:00+03	21500.00
EBAC06	2017-07-07 13:47:00+03	13600.00
EBAC4F	2017-08-09 22:20:00+03	81700.00
EBAC6F	2017-07-26 23:36:00+03	232800.00
EBAC7D	2017-07-04 03:05:00+03	58000.00
EBAC84	2017-07-01 14:43:00+03	66600.00
EBAD23	2017-07-15 21:03:00+03	51800.00
EBADB5	2017-08-13 13:46:00+03	42400.00
EBAE3E	2017-08-03 04:02:00+03	62200.00
EBAE61	2017-07-24 19:17:00+03	111700.00
EBAF40	2017-07-29 07:03:00+03	47200.00
EBAF54	2017-08-09 20:29:00+03	25400.00
EBAFC4	2017-08-09 07:40:00+03	23600.00
EBAFDD	2017-07-25 12:34:00+03	8200.00
EBB057	2017-08-07 07:57:00+03	43700.00
EBB05B	2017-07-31 05:15:00+03	46400.00
EBB06F	2017-08-03 17:22:00+03	26200.00
EBB078	2017-07-05 08:09:00+03	270800.00
EBB083	2017-07-25 17:30:00+03	64800.00
EBB0C7	2017-07-03 01:19:00+03	55800.00
EBB16D	2017-07-27 19:07:00+03	46400.00
EBB17C	2017-07-06 05:13:00+03	276500.00
EBB201	2017-06-29 01:27:00+03	7200.00
EBB215	2017-07-27 20:08:00+03	635200.00
EBB24A	2017-07-27 10:50:00+03	98300.00
EBB292	2017-08-06 11:36:00+03	56600.00
EBB2E8	2017-08-09 02:43:00+03	56200.00
EBB35B	2017-07-27 04:03:00+03	25400.00
EBB3B4	2017-07-30 10:57:00+03	119500.00
EBB3DC	2017-07-14 19:24:00+03	6400.00
EBB3E8	2017-07-20 10:52:00+03	89600.00
EBB491	2017-08-14 03:22:00+03	23600.00
EBB494	2017-07-14 17:53:00+03	17800.00
EBB4EE	2017-07-11 07:21:00+03	79000.00
EBB515	2017-07-31 18:22:00+03	26800.00
EBB522	2017-07-28 23:58:00+03	46700.00
EBB554	2017-07-01 22:34:00+03	54200.00
EBB581	2017-07-03 18:52:00+03	135400.00
EBB588	2017-07-28 23:18:00+03	59200.00
EBB594	2017-08-10 18:52:00+03	70500.00
EBB5CB	2017-08-12 04:27:00+03	58600.00
EBB639	2017-08-12 22:39:00+03	125700.00
EBB6C0	2017-07-06 09:23:00+03	44000.00
EBB6C6	2017-07-19 00:18:00+03	199800.00
EBB6D5	2017-07-30 22:18:00+03	145100.00
EBB6DA	2017-08-13 17:59:00+03	55100.00
EBB757	2017-08-11 10:16:00+03	229900.00
EBB7C0	2017-07-25 00:56:00+03	19600.00
EBB7E2	2017-07-09 15:23:00+03	141300.00
EBB827	2017-07-19 21:25:00+03	140900.00
EBB828	2017-08-09 13:53:00+03	58000.00
EBB873	2017-08-11 09:14:00+03	75300.00
EBB8E2	2017-08-13 19:04:00+03	31400.00
EBB92A	2017-07-17 14:56:00+03	262600.00
EBB955	2017-07-27 19:23:00+03	46400.00
EBB970	2017-07-13 17:01:00+03	202100.00
EBB998	2017-07-11 02:55:00+03	56100.00
EBB9C6	2017-08-03 11:49:00+03	18000.00
EBB9C7	2017-07-20 01:20:00+03	37700.00
EBBA0B	2017-07-16 20:52:00+03	135600.00
EBBA38	2017-07-14 11:31:00+03	106900.00
EBBAB4	2017-07-08 21:44:00+03	67600.00
EBBAD9	2017-07-02 19:36:00+03	52300.00
EBBADA	2017-07-20 09:54:00+03	265700.00
EBBAE6	2017-07-12 07:30:00+03	23600.00
EBBAF0	2017-08-06 00:47:00+03	57500.00
EBBB38	2017-07-12 13:09:00+03	31700.00
EBBC08	2017-08-04 13:07:00+03	66600.00
EBBC68	2017-08-12 14:41:00+03	38500.00
EBBC6F	2017-06-30 10:41:00+03	266400.00
EBBC9C	2017-08-09 09:31:00+03	21800.00
EBBCC8	2017-08-06 11:31:00+03	50200.00
EBBD2A	2017-07-24 15:40:00+03	31600.00
EBBDE0	2017-08-12 00:31:00+03	58800.00
EBBDE5	2017-07-02 06:34:00+03	131800.00
EBBDF6	2017-07-10 09:18:00+03	35800.00
EBBDFD	2017-07-03 08:10:00+03	77900.00
EBBE11	2017-08-14 03:27:00+03	54400.00
EBBE50	2017-07-30 07:38:00+03	23200.00
EBBE66	2017-07-03 19:03:00+03	76600.00
EBBE78	2017-08-08 00:49:00+03	43800.00
EBBE83	2017-07-09 11:22:00+03	17000.00
EBBEAD	2017-07-08 23:10:00+03	37200.00
EBBEC2	2017-08-13 22:26:00+03	19600.00
EBBECB	2017-07-17 21:52:00+03	144700.00
EBBF11	2017-08-01 11:53:00+03	85000.00
EBBF4D	2017-08-02 00:26:00+03	96800.00
EBBF69	2017-08-04 05:31:00+03	97900.00
EBBF90	2017-08-08 00:42:00+03	55800.00
EBBFE6	2017-07-19 12:36:00+03	75300.00
EBC00C	2017-07-11 17:15:00+03	56600.00
EBC096	2017-08-08 15:20:00+03	12400.00
EBC0F3	2017-07-02 04:10:00+03	31200.00
EBC100	2017-07-23 18:18:00+03	31100.00
EBC101	2017-08-01 02:26:00+03	46300.00
EBC11B	2017-07-14 03:03:00+03	56000.00
EBC15B	2017-07-20 06:21:00+03	20200.00
EBC15E	2017-08-08 12:02:00+03	95600.00
EBC15F	2017-08-07 06:29:00+03	66700.00
EBC1AA	2017-08-14 14:17:00+03	21600.00
EBC1C3	2017-07-27 23:38:00+03	95600.00
EBC1D9	2017-07-27 01:43:00+03	817000.00
EBC215	2017-07-08 15:27:00+03	18800.00
EBC258	2017-07-16 12:18:00+03	46800.00
EBC2D9	2017-07-05 00:26:00+03	19600.00
EBC2F9	2017-08-04 18:03:00+03	65800.00
EBC31B	2017-07-23 10:03:00+03	30300.00
EBC323	2017-08-04 03:27:00+03	57400.00
EBC346	2017-07-16 19:18:00+03	28000.00
EBC349	2017-07-19 02:41:00+03	152700.00
EBC355	2017-07-29 23:06:00+03	155000.00
EBC36F	2017-07-27 06:22:00+03	8200.00
EBC38E	2017-08-13 19:53:00+03	20400.00
EBC3AD	2017-06-28 12:37:00+03	37100.00
EBC3EB	2017-07-03 10:54:00+03	117600.00
EBC432	2017-07-21 15:19:00+03	51600.00
EBC468	2017-07-02 06:33:00+03	73000.00
EBC476	2017-08-12 08:28:00+03	82000.00
EBC477	2017-07-09 06:04:00+03	14400.00
EBC4A3	2017-08-09 04:16:00+03	133200.00
EBC4C0	2017-07-10 19:57:00+03	8200.00
EBC4CB	2017-08-04 00:22:00+03	199700.00
EBC4F5	2017-07-02 22:44:00+03	66600.00
EBC505	2017-08-12 03:49:00+03	23200.00
EBC57C	2017-08-07 02:15:00+03	150500.00
EBC5CB	2017-08-02 05:51:00+03	48800.00
EBC5D0	2017-08-02 04:15:00+03	37900.00
EBC5F8	2017-07-23 19:05:00+03	26000.00
EBC697	2017-08-14 23:39:00+03	36200.00
EBC6D9	2017-08-02 21:15:00+03	109200.00
EBC715	2017-07-17 11:33:00+03	23600.00
EBC716	2017-07-07 20:03:00+03	24400.00
EBC729	2017-07-27 04:27:00+03	28800.00
EBC7BD	2017-08-14 05:17:00+03	59300.00
EBC7E4	2017-08-12 20:02:00+03	47100.00
EBC84A	2017-07-29 08:10:00+03	20400.00
EBCA6C	2017-08-02 22:43:00+03	31200.00
EBCA93	2017-08-11 21:55:00+03	71200.00
EBCAA8	2017-07-05 12:17:00+03	47500.00
EBCADB	2017-07-25 00:19:00+03	29800.00
EBCB2B	2017-08-08 01:45:00+03	44100.00
EBCB49	2017-07-06 11:23:00+03	26000.00
EBCB5D	2017-07-30 20:24:00+03	25600.00
EBCB60	2017-07-13 20:24:00+03	27200.00
EBCB71	2017-07-21 19:45:00+03	56000.00
EBCB7F	2017-08-02 01:32:00+03	30400.00
EBCBDF	2017-08-07 14:50:00+03	137400.00
EBCBEE	2017-07-23 21:46:00+03	75600.00
EBCC1B	2017-07-14 02:22:00+03	271200.00
EBCC68	2017-08-08 10:02:00+03	28000.00
EBCCA2	2017-08-14 14:34:00+03	34100.00
EBCCB1	2017-07-10 10:13:00+03	36800.00
EBCCE7	2017-07-21 17:07:00+03	110300.00
EBCD30	2017-07-10 21:27:00+03	112600.00
EBCE0D	2017-07-05 18:59:00+03	68800.00
EBCE28	2017-07-24 17:14:00+03	40800.00
EBCE2A	2017-07-25 08:13:00+03	75300.00
EBCE3D	2017-08-14 23:45:00+03	52000.00
EBCE3F	2017-08-06 13:09:00+03	13500.00
EBCE4C	2017-08-03 02:55:00+03	27900.00
EBCE5D	2017-08-06 00:47:00+03	54300.00
EBCEBD	2017-08-10 19:24:00+03	41400.00
EBCEBE	2017-07-30 19:55:00+03	65400.00
EBCF43	2017-08-11 07:04:00+03	28800.00
EBCF92	2017-07-27 04:36:00+03	199800.00
EBCFC4	2017-07-12 13:00:00+03	67100.00
EBD03F	2017-07-24 19:48:00+03	51000.00
EBD04D	2017-08-13 21:54:00+03	23200.00
EBD050	2017-08-11 11:55:00+03	166400.00
EBD0BB	2017-07-19 06:05:00+03	66200.00
EBD13F	2017-06-30 06:38:00+03	29600.00
EBD1AC	2017-07-01 05:41:00+03	50000.00
EBD235	2017-07-13 17:06:00+03	46400.00
EBD26A	2017-07-05 23:01:00+03	136800.00
EBD283	2017-08-07 16:32:00+03	168300.00
EBD2E3	2017-08-12 23:43:00+03	100600.00
EBD34D	2017-07-11 21:50:00+03	128700.00
EBD381	2017-07-25 14:23:00+03	94000.00
EBD3DD	2017-08-05 09:09:00+03	58200.00
EBD456	2017-07-10 12:42:00+03	36900.00
EBD482	2017-07-15 21:15:00+03	496700.00
EBD48B	2017-07-07 23:25:00+03	43500.00
EBD4BE	2017-07-06 10:09:00+03	27200.00
EBD500	2017-08-13 11:33:00+03	24000.00
EBD51E	2017-07-21 01:53:00+03	36900.00
EBD573	2017-07-23 01:47:00+03	117900.00
EBD5AA	2017-08-06 20:46:00+03	51900.00
EBD5CA	2017-06-24 09:54:00+03	91600.00
EBD5F4	2017-07-15 03:32:00+03	46000.00
EBD62D	2017-07-14 12:15:00+03	23900.00
EBD648	2017-08-05 12:31:00+03	56600.00
EBD666	2017-07-17 20:38:00+03	44600.00
EBD684	2017-07-12 19:21:00+03	28000.00
EBD6D1	2017-08-05 07:04:00+03	24000.00
EBD707	2017-07-18 05:28:00+03	40000.00
EBD75C	2017-07-16 14:35:00+03	61500.00
EBD77C	2017-07-01 09:38:00+03	8000.00
EBD7C3	2017-07-16 09:56:00+03	56000.00
EBD7CE	2017-07-19 09:47:00+03	112000.00
EBD7E6	2017-07-12 22:28:00+03	46400.00
EBD840	2017-07-20 16:54:00+03	63700.00
EBD88D	2017-08-05 17:24:00+03	234300.00
EBD8AB	2017-07-21 16:26:00+03	29600.00
EBD8BC	2017-08-06 14:43:00+03	36200.00
EBD8BD	2017-08-08 00:49:00+03	111600.00
EBD8C7	2017-07-20 15:14:00+03	36600.00
EBD938	2017-07-30 19:38:00+03	9200.00
EBD952	2017-07-09 11:00:00+03	60100.00
EBD98E	2017-08-03 18:43:00+03	56000.00
EBD9AB	2017-07-30 14:01:00+03	44600.00
EBDA69	2017-07-31 21:17:00+03	59400.00
EBDA9A	2017-06-30 04:07:00+03	59800.00
EBDAA5	2017-08-03 21:09:00+03	67100.00
EBDB1B	2017-07-03 00:50:00+03	38400.00
EBDB21	2017-08-07 11:13:00+03	22000.00
EBDB7D	2017-07-31 21:45:00+03	27200.00
EBDBAB	2017-08-14 17:15:00+03	13600.00
EBDBBE	2017-07-21 02:55:00+03	72200.00
EBDBC6	2017-07-06 01:41:00+03	58400.00
EBDCB5	2017-08-06 02:19:00+03	95200.00
EBDCD0	2017-08-05 13:52:00+03	67400.00
EBDD31	2017-08-10 13:05:00+03	99800.00
EBDD47	2017-07-16 08:25:00+03	185800.00
EBDDE3	2017-07-14 18:20:00+03	24400.00
EBDDEA	2017-07-26 23:05:00+03	131100.00
EBDE04	2017-07-10 21:17:00+03	83000.00
EBDE7B	2017-07-17 17:03:00+03	18600.00
EBDEA3	2017-07-03 23:35:00+03	83000.00
EBDEAB	2017-07-07 15:38:00+03	119600.00
EBDF88	2017-08-12 13:42:00+03	60000.00
EBDF9B	2017-07-03 17:03:00+03	23600.00
EBDFCF	2017-06-25 17:33:00+03	113300.00
EBE01B	2017-06-28 13:43:00+03	68100.00
EBE02B	2017-08-03 00:43:00+03	17600.00
EBE0EE	2017-06-26 11:27:00+03	24400.00
EBE1C1	2017-07-13 19:39:00+03	89200.00
EBE1CC	2017-08-13 04:33:00+03	88600.00
EBE1DE	2017-08-13 11:39:00+03	21200.00
EBE1F9	2017-07-18 08:18:00+03	40800.00
EBE229	2017-08-11 16:12:00+03	111600.00
EBE22D	2017-08-15 01:29:00+03	81700.00
EBE283	2017-08-12 06:34:00+03	170000.00
EBE28F	2017-07-09 04:50:00+03	148200.00
EBE326	2017-07-05 00:35:00+03	16400.00
EBE390	2017-07-11 20:40:00+03	147200.00
EBE39F	2017-07-19 03:27:00+03	10800.00
EBE3D5	2017-08-05 15:50:00+03	88600.00
EBE3FA	2017-07-03 10:39:00+03	21800.00
EBE409	2017-07-29 12:26:00+03	16400.00
EBE41D	2017-06-29 09:13:00+03	56100.00
EBE4A9	2017-08-13 07:32:00+03	37900.00
EBE52D	2017-07-05 15:15:00+03	25400.00
EBE53E	2017-07-21 14:26:00+03	50400.00
EBE568	2017-07-22 05:34:00+03	56000.00
EBE569	2017-07-25 06:42:00+03	92000.00
EBE585	2017-07-06 13:32:00+03	6400.00
EBE5E5	2017-07-27 02:15:00+03	75500.00
EBE5ED	2017-07-17 18:46:00+03	38600.00
EBE6DB	2017-06-28 23:49:00+03	26000.00
EBE751	2017-08-01 18:14:00+03	26800.00
EBE803	2017-07-15 01:10:00+03	65400.00
EBE80F	2017-07-23 16:10:00+03	94000.00
EBE85F	2017-08-03 07:17:00+03	64800.00
EBE879	2017-07-21 01:36:00+03	56000.00
EBE8B7	2017-07-01 20:28:00+03	272400.00
EBE8F2	2017-08-01 19:17:00+03	19600.00
EBE96A	2017-07-27 23:31:00+03	23600.00
EBE994	2017-06-28 17:28:00+03	123000.00
EBE998	2017-07-09 22:40:00+03	11800.00
EBE99C	2017-07-01 16:10:00+03	100700.00
EBE9A7	2017-07-11 07:13:00+03	57500.00
EBE9B7	2017-07-13 15:39:00+03	16000.00
EBEA51	2017-08-02 19:19:00+03	108200.00
EBEA93	2017-08-12 05:17:00+03	6300.00
EBEAF6	2017-07-19 05:29:00+03	136600.00
EBEB18	2017-08-12 01:31:00+03	26300.00
EBEB36	2017-08-08 13:02:00+03	87000.00
EBEB59	2017-07-09 17:15:00+03	14000.00
EBEBA5	2017-08-15 02:30:00+03	47800.00
EBEBF2	2017-08-01 20:52:00+03	50900.00
EBEC09	2017-07-18 16:45:00+03	186900.00
EBEC24	2017-08-11 05:29:00+03	125200.00
EBECAC	2017-08-13 02:14:00+03	92800.00
EBECF6	2017-08-08 12:37:00+03	35600.00
EBED69	2017-07-24 04:53:00+03	47700.00
EBED86	2017-07-21 05:00:00+03	58700.00
EBEE0B	2017-08-08 11:03:00+03	72400.00
EBEE4B	2017-07-07 21:23:00+03	30200.00
EBEEDA	2017-07-23 00:47:00+03	62600.00
EBEF5E	2017-08-11 22:03:00+03	56600.00
EBEF6F	2017-08-12 04:49:00+03	92100.00
EBEFAA	2017-08-12 13:00:00+03	28800.00
EBEFD7	2017-08-14 21:09:00+03	20300.00
EBEFDF	2017-06-29 11:03:00+03	43200.00
EBF000	2017-08-04 16:36:00+03	31100.00
EBF04D	2017-07-28 21:27:00+03	55800.00
EBF081	2017-07-05 07:18:00+03	149200.00
EBF08E	2017-07-25 17:17:00+03	40400.00
EBF0B4	2017-07-18 07:55:00+03	57800.00
EBF0D0	2017-08-07 17:04:00+03	71900.00
EBF0DA	2017-07-30 02:06:00+03	18300.00
EBF158	2017-08-04 12:55:00+03	49600.00
EBF168	2017-07-26 14:23:00+03	54400.00
EBF1A5	2017-08-09 15:33:00+03	111100.00
EBF1BE	2017-08-04 16:45:00+03	199800.00
EBF20F	2017-07-06 06:32:00+03	59400.00
EBF21C	2017-08-11 04:57:00+03	137700.00
EBF260	2017-07-02 01:35:00+03	92800.00
EBF270	2017-08-13 01:33:00+03	27200.00
EBF27B	2017-08-01 06:22:00+03	45200.00
EBF2E3	2017-06-27 05:48:00+03	63400.00
EBF2F5	2017-08-11 20:01:00+03	52700.00
EBF32A	2017-08-15 13:42:00+03	23000.00
EBF35E	2017-07-08 13:22:00+03	37600.00
EBF3B9	2017-08-10 15:23:00+03	26800.00
EBF3CF	2017-07-04 18:18:00+03	28800.00
EBF48F	2017-07-05 12:43:00+03	40000.00
EBF4DC	2017-08-06 13:35:00+03	28000.00
EBF4F5	2017-07-08 07:07:00+03	28000.00
EBF516	2017-08-12 11:59:00+03	62600.00
EBF54E	2017-08-15 01:12:00+03	72200.00
EBF567	2017-07-14 13:44:00+03	24400.00
EBF574	2017-08-04 18:41:00+03	122300.00
EBF5E2	2017-08-06 14:49:00+03	36400.00
EBF61C	2017-07-09 03:37:00+03	35600.00
EBF62D	2017-07-29 14:00:00+03	65400.00
EBF639	2017-07-25 19:58:00+03	174600.00
EBF67F	2017-07-19 11:29:00+03	64200.00
EBF6F5	2017-08-06 00:51:00+03	20500.00
EBF724	2017-07-24 23:43:00+03	11800.00
EBF77A	2017-08-01 13:14:00+03	23200.00
EBF77D	2017-07-22 19:33:00+03	26000.00
EBF7E2	2017-07-29 19:37:00+03	19800.00
EBF84B	2017-07-17 05:53:00+03	56000.00
EBF88D	2017-07-11 00:15:00+03	70800.00
EBF899	2017-07-24 10:08:00+03	70500.00
EBF8D0	2017-07-12 20:49:00+03	50000.00
EBF910	2017-07-10 10:12:00+03	47200.00
EBF92E	2017-08-14 05:04:00+03	142400.00
EBF93A	2017-08-06 21:09:00+03	270800.00
EBF975	2017-07-09 18:32:00+03	56900.00
EBF980	2017-07-03 11:40:00+03	38500.00
EBF987	2017-08-08 13:48:00+03	536100.00
EBF9B7	2017-08-14 23:26:00+03	133200.00
EBF9DD	2017-08-08 00:41:00+03	11600.00
EBFA1C	2017-07-14 01:54:00+03	32700.00
EBFA9A	2017-07-21 09:34:00+03	46400.00
EBFACB	2017-07-11 08:53:00+03	11600.00
EBFB8B	2017-07-28 14:28:00+03	202600.00
EBFB8E	2017-07-09 11:01:00+03	38400.00
EBFBD2	2017-07-11 00:30:00+03	56000.00
EBFC48	2017-07-27 15:57:00+03	42400.00
EBFCA4	2017-06-29 03:36:00+03	242100.00
EBFCB9	2017-07-28 20:03:00+03	46400.00
EBFCEC	2017-08-12 08:31:00+03	343300.00
EBFD26	2017-08-07 14:04:00+03	46200.00
EBFD27	2017-07-26 09:24:00+03	101200.00
EBFD8C	2017-07-21 22:18:00+03	39400.00
EBFDA3	2017-07-17 06:16:00+03	31100.00
EBFDFE	2017-06-27 08:25:00+03	50100.00
EBFE51	2017-08-10 16:02:00+03	65900.00
EBFE7D	2017-07-06 00:53:00+03	45200.00
EBFE8A	2017-07-26 10:08:00+03	81200.00
EBFED0	2017-08-03 23:33:00+03	23400.00
EBFF2B	2017-07-06 05:08:00+03	37900.00
EBFFDA	2017-08-10 06:03:00+03	90800.00
EBFFF3	2017-08-06 08:08:00+03	62000.00
EBFFF7	2017-08-15 04:45:00+03	81600.00
EC0021	2017-07-08 03:34:00+03	44800.00
EC0069	2017-08-09 08:24:00+03	46300.00
EC009E	2017-07-21 16:00:00+03	49200.00
EC00BA	2017-08-05 21:20:00+03	60700.00
EC00C8	2017-07-20 07:03:00+03	63700.00
EC0111	2017-07-29 22:28:00+03	43000.00
EC018E	2017-07-18 07:51:00+03	133100.00
EC01EC	2017-07-23 20:26:00+03	46400.00
EC023D	2017-07-26 08:30:00+03	168700.00
EC029D	2017-07-10 07:44:00+03	40000.00
EC02C0	2017-08-11 15:47:00+03	27800.00
EC02D2	2017-07-10 09:09:00+03	49100.00
EC031C	2017-07-17 06:23:00+03	92800.00
EC0359	2017-07-05 17:37:00+03	94000.00
EC038E	2017-08-03 17:31:00+03	47200.00
EC040C	2017-07-18 06:46:00+03	155600.00
EC0435	2017-07-14 04:11:00+03	42700.00
EC043F	2017-07-10 06:33:00+03	43000.00
EC047A	2017-07-28 00:12:00+03	46300.00
EC04B2	2017-08-12 23:13:00+03	46400.00
EC0509	2017-08-01 19:00:00+03	40800.00
EC051F	2017-08-11 16:01:00+03	56000.00
EC059C	2017-08-03 15:10:00+03	56000.00
EC05E2	2017-08-09 21:15:00+03	28000.00
EC063C	2017-07-13 07:42:00+03	115800.00
EC066C	2017-08-08 02:55:00+03	38400.00
EC0677	2017-07-23 21:44:00+03	155600.00
EC06B1	2017-07-08 15:30:00+03	140500.00
EC06C7	2017-07-30 12:11:00+03	183300.00
EC0717	2017-08-11 22:35:00+03	61800.00
EC07CB	2017-08-14 01:18:00+03	25800.00
EC08A5	2017-07-14 11:28:00+03	52000.00
EC08B3	2017-07-04 17:07:00+03	54300.00
EC0900	2017-07-12 00:33:00+03	28000.00
EC0906	2017-07-22 17:55:00+03	31600.00
EC090C	2017-07-25 05:56:00+03	27300.00
EC0959	2017-08-07 18:11:00+03	11600.00
EC095F	2017-07-22 19:38:00+03	62100.00
EC09BF	2017-07-02 13:04:00+03	55800.00
EC0A1B	2017-07-14 19:01:00+03	40800.00
EC0A27	2017-07-01 15:28:00+03	28000.00
EC0A36	2017-07-16 11:08:00+03	147700.00
EC0A4B	2017-08-11 07:35:00+03	24400.00
EC0A5B	2017-07-05 20:24:00+03	24000.00
EC0A86	2017-08-10 20:34:00+03	117200.00
EC0A94	2017-07-10 23:44:00+03	42700.00
EC0AB3	2017-07-11 10:58:00+03	96300.00
EC0AC9	2017-08-08 00:17:00+03	18500.00
EC0AE7	2017-08-01 11:07:00+03	22000.00
EC0AED	2017-07-19 04:02:00+03	339800.00
EC0B1D	2017-08-01 03:00:00+03	25200.00
EC0B64	2017-08-05 16:31:00+03	75300.00
EC0B8A	2017-07-07 08:41:00+03	40600.00
EC0BD1	2017-07-10 08:26:00+03	6300.00
EC0BFE	2017-08-11 16:56:00+03	8200.00
EC0C07	2017-07-22 11:12:00+03	477100.00
EC0CC9	2017-07-23 05:59:00+03	199200.00
EC0CDD	2017-07-29 12:41:00+03	92800.00
EC0D22	2017-08-13 12:27:00+03	100000.00
EC0D2D	2017-07-03 03:30:00+03	96400.00
EC0D37	2017-08-03 01:36:00+03	64800.00
EC0D58	2017-08-03 09:59:00+03	63200.00
EC0D91	2017-07-15 07:46:00+03	75300.00
EC0E45	2017-07-12 19:38:00+03	32800.00
EC0E9D	2017-07-13 00:23:00+03	92400.00
EC0EB4	2017-07-14 10:06:00+03	67600.00
EC0EBE	2017-07-23 16:38:00+03	175500.00
EC0EF1	2017-07-15 19:48:00+03	134400.00
EC0F3F	2017-08-12 07:49:00+03	32600.00
EC0F9C	2017-07-01 21:10:00+03	38200.00
EC0FDB	2017-08-04 16:12:00+03	36200.00
EC1023	2017-07-10 21:35:00+03	28800.00
EC1043	2017-08-14 15:29:00+03	53600.00
EC105C	2017-08-04 20:08:00+03	406700.00
EC10C1	2017-08-11 07:54:00+03	77200.00
EC110B	2017-07-14 16:15:00+03	46000.00
EC119F	2017-08-01 12:56:00+03	56000.00
EC11A8	2017-07-01 12:24:00+03	23200.00
EC11A9	2017-07-02 07:26:00+03	48800.00
EC11B0	2017-08-12 03:23:00+03	3700.00
EC11B7	2017-07-15 10:51:00+03	283100.00
EC1210	2017-08-15 03:54:00+03	11600.00
EC127B	2017-07-12 21:51:00+03	14800.00
EC12A4	2017-07-14 14:34:00+03	103800.00
EC132D	2017-08-06 13:22:00+03	10800.00
EC1334	2017-07-31 16:00:00+03	84500.00
EC1351	2017-08-09 03:04:00+03	58800.00
EC138A	2017-08-02 04:22:00+03	38600.00
EC139D	2017-07-16 15:10:00+03	50800.00
EC1403	2017-07-05 05:17:00+03	13400.00
EC1417	2017-08-02 22:37:00+03	50000.00
EC1421	2017-08-14 13:05:00+03	56000.00
EC1497	2017-07-26 10:45:00+03	18500.00
EC14A3	2017-07-22 08:09:00+03	14000.00
EC14B6	2017-07-10 15:12:00+03	50400.00
EC154F	2017-07-28 18:43:00+03	6800.00
EC156B	2017-07-15 17:45:00+03	40800.00
EC1571	2017-08-09 12:42:00+03	49200.00
EC1573	2017-07-18 10:50:00+03	274600.00
EC15A3	2017-08-11 08:17:00+03	43200.00
EC15C6	2017-08-02 16:52:00+03	15000.00
EC15CF	2017-07-28 14:01:00+03	6000.00
EC15ED	2017-08-05 13:23:00+03	26000.00
EC1635	2017-08-07 06:07:00+03	114400.00
EC16AF	2017-08-14 22:08:00+03	40800.00
EC16BF	2017-07-26 05:11:00+03	38300.00
EC170F	2017-07-08 23:48:00+03	26000.00
EC17E2	2017-07-29 12:19:00+03	24500.00
EC17EE	2017-07-17 16:25:00+03	101700.00
EC1866	2017-07-13 17:00:00+03	39600.00
EC18A5	2017-07-20 18:17:00+03	46000.00
EC18C1	2017-07-12 20:33:00+03	76600.00
EC18C9	2017-08-14 14:06:00+03	66600.00
EC1912	2017-07-19 03:57:00+03	62000.00
EC1916	2017-07-03 14:29:00+03	81300.00
EC1925	2017-08-07 23:53:00+03	66600.00
EC1946	2017-08-10 02:35:00+03	271100.00
EC1963	2017-08-10 13:09:00+03	14700.00
EC1A76	2017-08-02 11:01:00+03	92800.00
EC1AD1	2017-08-01 13:35:00+03	43500.00
EC1B05	2017-07-31 02:46:00+03	29600.00
EC1B97	2017-08-11 15:19:00+03	29800.00
EC1BF4	2017-08-03 04:06:00+03	79900.00
EC1C03	2017-07-18 16:31:00+03	40000.00
EC1C88	2017-07-03 15:31:00+03	122800.00
EC1C8A	2017-08-03 12:49:00+03	28800.00
EC1D60	2017-07-16 12:51:00+03	59200.00
EC1DDD	2017-07-31 11:01:00+03	6300.00
EC1E49	2017-07-17 12:50:00+03	38400.00
EC1E8B	2017-08-07 14:50:00+03	12400.00
EC1EAA	2017-07-26 20:50:00+03	37200.00
EC1FAC	2017-07-28 03:09:00+03	19600.00
EC1FCC	2017-07-25 09:25:00+03	40000.00
EC2000	2017-07-10 08:52:00+03	101500.00
EC201D	2017-07-10 19:19:00+03	112000.00
EC205E	2017-07-18 14:53:00+03	58000.00
EC2084	2017-07-28 07:03:00+03	64700.00
EC2097	2017-08-12 17:24:00+03	30000.00
EC20C5	2017-07-15 07:33:00+03	83000.00
EC2103	2017-07-07 04:29:00+03	10600.00
EC212F	2017-07-27 09:46:00+03	18500.00
EC2186	2017-07-14 17:59:00+03	218200.00
EC229D	2017-07-30 03:39:00+03	135400.00
EC22A9	2017-07-22 11:09:00+03	51900.00
EC22E6	2017-07-03 16:46:00+03	46300.00
EC2301	2017-07-15 12:21:00+03	67200.00
EC230F	2017-07-18 21:41:00+03	74400.00
EC232D	2017-07-23 19:48:00+03	90800.00
EC233B	2017-07-21 10:34:00+03	40800.00
EC234F	2017-07-03 03:28:00+03	223700.00
EC2369	2017-07-15 19:34:00+03	71900.00
EC23DC	2017-07-06 14:48:00+03	64700.00
EC23EC	2017-07-05 06:03:00+03	75500.00
EC23EE	2017-07-21 06:04:00+03	152600.00
EC244C	2017-08-12 10:21:00+03	27400.00
EC24B7	2017-07-21 23:25:00+03	46800.00
EC24E6	2017-07-10 23:38:00+03	59200.00
EC24FC	2017-07-13 17:28:00+03	58200.00
EC253C	2017-07-27 11:32:00+03	67600.00
EC2566	2017-08-09 00:47:00+03	189200.00
EC2595	2017-07-21 21:52:00+03	170300.00
EC25D0	2017-07-10 08:04:00+03	38400.00
EC25DD	2017-07-15 00:46:00+03	31100.00
EC25E6	2017-08-09 11:14:00+03	58800.00
EC2624	2017-08-05 04:51:00+03	21400.00
EC26E3	2017-07-02 06:12:00+03	21200.00
EC26E4	2017-06-28 05:37:00+03	57300.00
EC271D	2017-08-02 20:10:00+03	46000.00
EC272D	2017-08-01 22:57:00+03	52000.00
EC274D	2017-07-20 07:07:00+03	177000.00
EC27F4	2017-07-28 10:18:00+03	111600.00
EC283A	2017-07-19 23:43:00+03	70400.00
EC287C	2017-07-03 08:04:00+03	21800.00
EC28B6	2017-07-06 15:58:00+03	42800.00
EC28BE	2017-07-16 10:05:00+03	18800.00
EC28F3	2017-08-01 01:10:00+03	369000.00
EC28F7	2017-08-01 02:48:00+03	123000.00
EC29BE	2017-07-17 23:39:00+03	67900.00
EC2A76	2017-07-13 00:48:00+03	59800.00
EC2A84	2017-07-02 17:49:00+03	73200.00
EC2ACF	2017-07-29 14:24:00+03	147100.00
EC2AF5	2017-07-09 19:01:00+03	57600.00
EC2B06	2017-07-13 13:34:00+03	132800.00
EC2BB7	2017-06-28 06:23:00+03	52000.00
EC2BF8	2017-07-05 21:31:00+03	82900.00
EC2C42	2017-08-05 07:55:00+03	88000.00
EC2C69	2017-08-13 19:57:00+03	98100.00
EC2CC3	2017-07-16 04:11:00+03	128800.00
EC2DEC	2017-07-16 02:54:00+03	27300.00
EC2E28	2017-08-03 09:26:00+03	25800.00
EC2EA4	2017-08-13 00:46:00+03	16400.00
EC2F08	2017-07-16 10:55:00+03	258400.00
EC2F55	2017-07-31 03:35:00+03	56000.00
EC2F87	2017-08-01 02:47:00+03	51800.00
EC2FD6	2017-06-30 14:04:00+03	69900.00
EC300E	2017-08-09 14:49:00+03	40000.00
EC3011	2017-08-09 18:20:00+03	31600.00
EC304E	2017-08-03 19:56:00+03	248400.00
EC30B2	2017-07-24 23:42:00+03	72200.00
EC30CF	2017-07-05 18:43:00+03	27200.00
EC3104	2017-08-13 18:34:00+03	41800.00
EC3130	2017-07-21 03:22:00+03	23600.00
EC3140	2017-07-15 09:25:00+03	6000.00
EC3173	2017-07-04 09:56:00+03	57500.00
EC31A9	2017-07-09 21:10:00+03	26000.00
EC31DF	2017-08-08 11:58:00+03	80900.00
EC3269	2017-08-03 18:05:00+03	57600.00
EC3315	2017-08-10 05:34:00+03	31100.00
EC3345	2017-08-12 02:40:00+03	82900.00
EC336B	2017-06-29 04:43:00+03	47400.00
EC33B3	2017-07-08 11:15:00+03	54800.00
EC33E0	2017-08-12 19:11:00+03	61800.00
EC3404	2017-07-24 13:13:00+03	23200.00
EC34A2	2017-07-28 11:25:00+03	47400.00
EC3528	2017-07-04 02:36:00+03	29600.00
EC355F	2017-08-09 14:42:00+03	82800.00
EC35B2	2017-08-05 17:46:00+03	68800.00
EC361C	2017-07-27 11:39:00+03	4000.00
EC3621	2017-08-06 13:13:00+03	61400.00
EC3651	2017-06-28 16:36:00+03	38600.00
EC3674	2017-07-05 22:55:00+03	55800.00
EC3717	2017-07-07 01:02:00+03	75700.00
EC3725	2017-08-05 17:19:00+03	92800.00
EC3729	2017-08-07 01:20:00+03	229400.00
EC3759	2017-08-08 12:34:00+03	84500.00
EC3776	2017-08-10 03:36:00+03	54800.00
EC37B6	2017-07-10 09:08:00+03	55800.00
EC3846	2017-07-19 15:58:00+03	66600.00
EC3884	2017-07-27 05:05:00+03	108600.00
EC38EA	2017-08-01 21:46:00+03	45200.00
EC3935	2017-08-11 06:39:00+03	25600.00
EC39B1	2017-08-05 04:40:00+03	28800.00
EC3A79	2017-08-14 09:23:00+03	96300.00
EC3AED	2017-07-16 07:21:00+03	46800.00
EC3AFA	2017-07-18 08:43:00+03	23200.00
EC3B02	2017-07-29 06:32:00+03	299200.00
EC3B2A	2017-07-04 06:44:00+03	111600.00
EC3B86	2017-08-09 21:26:00+03	56000.00
EC3B92	2017-07-19 19:43:00+03	92700.00
EC3BAC	2017-08-15 00:58:00+03	72400.00
EC3BF8	2017-07-01 21:19:00+03	86000.00
EC3C1D	2017-08-07 20:56:00+03	46400.00
EC3C21	2017-07-17 09:26:00+03	193200.00
EC3C6B	2017-07-18 09:22:00+03	133200.00
EC3D09	2017-07-16 09:35:00+03	58900.00
EC3D22	2017-07-09 12:39:00+03	139500.00
EC3D62	2017-07-14 01:31:00+03	28000.00
EC3D70	2017-07-30 20:10:00+03	135400.00
EC3D93	2017-07-28 23:33:00+03	113700.00
EC3DAE	2017-06-30 22:37:00+03	40300.00
EC3DB8	2017-07-05 00:54:00+03	137100.00
EC3E9C	2017-08-06 10:29:00+03	23200.00
EC3ED8	2017-08-05 19:45:00+03	76600.00
EC3EDD	2017-08-05 00:00:00+03	65100.00
EC3F0A	2017-07-26 20:20:00+03	31900.00
EC3F0B	2017-07-15 07:02:00+03	265700.00
EC3F28	2017-08-15 11:48:00+03	56100.00
EC3FFC	2017-07-26 23:39:00+03	56000.00
EC4046	2017-07-07 10:50:00+03	23200.00
EC406F	2017-08-03 09:51:00+03	47400.00
EC407B	2017-07-18 21:18:00+03	49100.00
EC4117	2017-07-18 08:01:00+03	42800.00
EC4161	2017-08-10 02:28:00+03	68400.00
EC416A	2017-08-07 05:54:00+03	94300.00
EC4191	2017-08-11 02:30:00+03	108500.00
EC4197	2017-07-15 20:46:00+03	7300.00
EC41D6	2017-07-10 10:50:00+03	20600.00
EC41E4	2017-08-05 17:37:00+03	26200.00
EC4221	2017-07-14 04:45:00+03	57600.00
EC4231	2017-07-29 23:17:00+03	394900.00
EC4253	2017-07-22 03:35:00+03	131100.00
EC4274	2017-08-06 04:43:00+03	135600.00
EC4318	2017-07-20 18:41:00+03	296400.00
EC432D	2017-07-20 08:46:00+03	100600.00
EC4341	2017-07-16 21:19:00+03	44800.00
EC439C	2017-07-24 00:52:00+03	25600.00
EC43F9	2017-08-09 19:50:00+03	53600.00
EC447E	2017-08-03 06:24:00+03	20200.00
EC4481	2017-07-23 07:24:00+03	51900.00
EC4489	2017-07-12 12:01:00+03	114300.00
EC463E	2017-07-06 05:28:00+03	13600.00
EC4693	2017-08-13 23:54:00+03	369000.00
EC46E9	2017-08-04 11:31:00+03	332600.00
EC46FA	2017-06-30 07:00:00+03	67700.00
EC4717	2017-07-19 02:40:00+03	20000.00
EC4782	2017-07-24 23:57:00+03	116400.00
EC47C1	2017-07-19 10:48:00+03	191200.00
EC47FA	2017-07-09 05:33:00+03	109600.00
EC4833	2017-08-04 00:04:00+03	102800.00
EC4853	2017-07-16 09:10:00+03	46200.00
EC4898	2017-07-18 03:43:00+03	393000.00
EC48C8	2017-07-25 17:32:00+03	265600.00
EC4922	2017-07-26 19:50:00+03	14000.00
EC4946	2017-07-20 06:44:00+03	76600.00
EC494E	2017-08-14 02:13:00+03	57500.00
EC4973	2017-08-14 08:59:00+03	47300.00
EC49A2	2017-07-10 20:21:00+03	140600.00
EC49B6	2017-07-01 23:16:00+03	25800.00
EC4A3D	2017-07-14 05:47:00+03	32500.00
EC4A5C	2017-07-27 19:23:00+03	29400.00
EC4A79	2017-07-25 22:55:00+03	59300.00
EC4A7E	2017-07-21 16:28:00+03	184000.00
EC4A85	2017-08-03 00:09:00+03	29600.00
EC4A9B	2017-08-15 00:12:00+03	24400.00
EC4AE3	2017-07-19 12:56:00+03	23500.00
EC4AF8	2017-08-08 06:52:00+03	31600.00
EC4B68	2017-08-07 19:36:00+03	59800.00
EC4B71	2017-07-15 08:44:00+03	35800.00
EC4B7B	2017-07-13 16:48:00+03	29400.00
EC4B90	2017-07-09 01:03:00+03	26000.00
EC4C24	2017-07-25 02:54:00+03	58000.00
EC4CA5	2017-07-15 13:46:00+03	19600.00
EC4D34	2017-07-16 20:03:00+03	24400.00
EC4D64	2017-07-02 07:18:00+03	42800.00
EC4D73	2017-07-16 15:35:00+03	69000.00
EC4D74	2017-08-10 19:02:00+03	56900.00
EC4D84	2017-07-09 01:39:00+03	46400.00
EC4E0B	2017-07-14 12:09:00+03	22000.00
EC4E75	2017-07-01 02:38:00+03	59800.00
EC4E81	2017-07-27 01:17:00+03	77000.00
EC4EAD	2017-07-19 12:09:00+03	49400.00
EC4F2B	2017-07-15 09:52:00+03	261500.00
EC4F34	2017-08-14 12:23:00+03	37600.00
EC4F35	2017-07-14 14:58:00+03	46000.00
EC4F56	2017-07-18 11:08:00+03	91500.00
EC4F73	2017-07-28 07:29:00+03	48800.00
EC4F89	2017-07-08 17:13:00+03	191000.00
EC4F8D	2017-07-24 07:24:00+03	97600.00
EC4FCD	2017-07-20 11:22:00+03	79800.00
EC4FF9	2017-07-12 08:33:00+03	28000.00
EC503F	2017-08-02 08:40:00+03	8200.00
EC5084	2017-08-01 16:14:00+03	31600.00
EC50D5	2017-08-14 08:10:00+03	124200.00
EC50F7	2017-07-30 05:54:00+03	91600.00
EC5117	2017-08-05 11:23:00+03	203100.00
EC5153	2017-07-13 03:38:00+03	13800.00
EC519C	2017-07-27 22:36:00+03	48800.00
EC519F	2017-08-02 04:50:00+03	223200.00
EC51C8	2017-07-21 06:35:00+03	70100.00
EC5213	2017-08-11 23:14:00+03	57600.00
EC5256	2017-07-08 22:50:00+03	36200.00
EC5294	2017-07-31 02:57:00+03	6000.00
EC53B0	2017-07-20 03:35:00+03	56000.00
EC53CE	2017-08-14 14:33:00+03	670900.00
EC5447	2017-07-15 16:30:00+03	31400.00
EC5526	2017-08-04 22:30:00+03	6900.00
EC5529	2017-08-08 09:14:00+03	193500.00
EC55AC	2017-08-06 22:06:00+03	30800.00
EC55CA	2017-07-20 06:18:00+03	67900.00
EC55DE	2017-07-09 00:09:00+03	26800.00
EC5648	2017-08-09 06:49:00+03	103500.00
EC566A	2017-07-29 16:23:00+03	78600.00
EC5717	2017-06-30 10:27:00+03	39200.00
EC576B	2017-07-08 15:05:00+03	258400.00
EC57F3	2017-08-14 03:26:00+03	101200.00
EC5821	2017-07-07 18:33:00+03	306200.00
EC5836	2017-06-30 15:21:00+03	136500.00
EC58A5	2017-07-30 20:39:00+03	112000.00
EC5927	2017-08-13 23:08:00+03	420500.00
EC5948	2017-08-08 00:24:00+03	23200.00
EC594F	2017-07-04 23:52:00+03	146100.00
EC596A	2017-07-04 05:26:00+03	56900.00
EC5975	2017-08-12 03:57:00+03	136800.00
EC5979	2017-07-16 10:04:00+03	246000.00
EC59B0	2017-08-07 15:17:00+03	102100.00
EC59F7	2017-07-20 03:00:00+03	6300.00
EC5A33	2017-07-10 13:39:00+03	6300.00
EC5B13	2017-07-05 21:10:00+03	25100.00
EC5BD2	2017-07-11 10:09:00+03	25600.00
EC5CE9	2017-07-10 23:48:00+03	65500.00
EC5D9D	2017-07-18 03:54:00+03	99200.00
EC5DA0	2017-08-01 17:47:00+03	21800.00
EC5E39	2017-07-07 21:10:00+03	40600.00
EC5E63	2017-08-05 13:12:00+03	25600.00
EC5E7F	2017-07-19 06:40:00+03	13600.00
EC5F3C	2017-07-09 16:57:00+03	27800.00
EC5FDD	2017-07-19 17:36:00+03	52300.00
EC5FE2	2017-07-13 07:06:00+03	284300.00
EC602D	2017-07-29 12:57:00+03	46400.00
EC60BA	2017-07-16 15:37:00+03	32800.00
EC60E6	2017-07-26 19:04:00+03	115600.00
EC6131	2017-07-23 04:57:00+03	13000.00
EC617D	2017-08-04 22:38:00+03	12600.00
EC61EC	2017-07-22 19:33:00+03	30800.00
EC61F4	2017-08-07 22:21:00+03	22000.00
EC62AB	2017-07-07 21:39:00+03	55000.00
EC6336	2017-07-15 09:30:00+03	7400.00
EC6380	2017-08-11 07:43:00+03	82900.00
EC643D	2017-07-25 02:34:00+03	28800.00
EC649D	2017-08-14 04:48:00+03	65900.00
EC64DC	2017-07-27 22:17:00+03	169900.00
EC651F	2017-07-13 21:39:00+03	86400.00
EC6527	2017-07-16 16:14:00+03	90800.00
EC6545	2017-07-12 07:00:00+03	28000.00
EC655E	2017-07-14 01:51:00+03	21500.00
EC657A	2017-07-04 12:38:00+03	123000.00
EC65D0	2017-07-19 21:02:00+03	134700.00
EC662D	2017-07-13 12:19:00+03	125000.00
EC6637	2017-07-21 21:51:00+03	246000.00
EC668D	2017-07-05 16:58:00+03	81700.00
EC678A	2017-07-23 22:56:00+03	51800.00
EC67AD	2017-08-12 14:04:00+03	23600.00
EC67CD	2017-07-16 02:14:00+03	120400.00
EC684D	2017-07-08 01:47:00+03	89700.00
EC6888	2017-07-04 22:16:00+03	133200.00
EC689E	2017-07-30 10:17:00+03	86400.00
EC68E1	2017-07-21 21:11:00+03	12000.00
EC690B	2017-08-01 11:37:00+03	173600.00
EC69D8	2017-08-12 02:26:00+03	40100.00
EC69EF	2017-07-22 17:49:00+03	46400.00
EC6A43	2017-08-08 17:37:00+03	67400.00
EC6A54	2017-07-04 11:22:00+03	136200.00
EC6AD8	2017-07-06 15:23:00+03	155600.00
EC6B0A	2017-08-11 19:40:00+03	36200.00
EC6B4A	2017-07-13 05:41:00+03	67600.00
EC6BB0	2017-08-11 13:57:00+03	46200.00
EC6CF3	2017-07-30 14:07:00+03	57500.00
EC6CFE	2017-08-02 09:34:00+03	47400.00
EC6D16	2017-07-05 06:27:00+03	56600.00
EC6D44	2017-08-11 03:30:00+03	55800.00
EC6D77	2017-06-30 19:15:00+03	45200.00
EC6E0F	2017-07-03 02:47:00+03	29600.00
EC6E15	2017-07-17 05:30:00+03	37200.00
EC6E31	2017-08-09 14:47:00+03	57600.00
EC6E37	2017-08-14 17:25:00+03	60300.00
EC6E48	2017-08-12 04:37:00+03	28800.00
EC6E86	2017-07-21 18:33:00+03	124200.00
EC6F24	2017-07-08 14:30:00+03	366800.00
EC6F76	2017-08-11 22:50:00+03	38600.00
EC6F90	2017-07-05 20:24:00+03	172200.00
EC6FF2	2017-08-13 02:59:00+03	33000.00
EC6FFE	2017-06-29 11:56:00+03	8200.00
EC7024	2017-07-26 18:11:00+03	28000.00
EC7044	2017-08-12 19:29:00+03	37700.00
EC7096	2017-07-18 04:22:00+03	135600.00
EC70EB	2017-07-07 18:02:00+03	14000.00
EC7109	2017-07-22 11:25:00+03	170000.00
EC7117	2017-07-14 12:37:00+03	99400.00
EC714C	2017-07-16 00:46:00+03	27200.00
EC7169	2017-08-02 15:06:00+03	73100.00
EC7182	2017-07-06 18:27:00+03	12600.00
EC71BF	2017-07-08 04:05:00+03	45200.00
EC71CF	2017-07-24 17:53:00+03	23200.00
EC7251	2017-07-21 10:33:00+03	112400.00
EC727A	2017-07-14 12:00:00+03	28000.00
EC727D	2017-07-19 15:45:00+03	51300.00
EC72DD	2017-08-08 01:08:00+03	48800.00
EC72EB	2017-08-14 21:04:00+03	23200.00
EC731A	2017-08-14 16:51:00+03	11000.00
EC7346	2017-08-07 07:45:00+03	102300.00
EC7376	2017-07-21 22:35:00+03	26000.00
EC7438	2017-08-10 16:45:00+03	100000.00
EC74D3	2017-08-14 04:00:00+03	59000.00
EC751F	2017-08-14 13:10:00+03	25700.00
EC7525	2017-07-29 05:55:00+03	47400.00
EC75E4	2017-07-20 15:02:00+03	93700.00
EC7633	2017-07-15 23:29:00+03	79900.00
EC76A6	2017-07-11 17:26:00+03	83900.00
EC76B1	2017-07-31 18:58:00+03	55800.00
EC77A1	2017-07-09 18:32:00+03	23200.00
EC77D8	2017-07-23 18:43:00+03	38600.00
EC7812	2017-07-06 10:29:00+03	147100.00
EC783D	2017-07-18 18:19:00+03	81200.00
EC7870	2017-07-07 18:00:00+03	43400.00
EC7871	2017-07-18 09:10:00+03	16400.00
EC78DC	2017-07-07 02:29:00+03	48700.00
EC78F0	2017-07-26 00:30:00+03	47400.00
EC7910	2017-07-15 11:51:00+03	6000.00
EC793C	2017-07-26 14:31:00+03	52200.00
EC7974	2017-07-19 22:27:00+03	98400.00
EC7978	2017-08-09 05:14:00+03	90800.00
EC799A	2017-08-07 15:36:00+03	10800.00
EC799E	2017-07-06 15:45:00+03	20200.00
EC79E3	2017-07-27 14:04:00+03	64800.00
EC7A0D	2017-08-14 08:14:00+03	44300.00
EC7A2C	2017-07-13 15:20:00+03	84500.00
EC7A3F	2017-07-30 03:50:00+03	77900.00
EC7BBC	2017-07-14 13:59:00+03	25400.00
EC7BF4	2017-08-15 09:15:00+03	26000.00
EC7C12	2017-07-04 14:46:00+03	135600.00
EC7C8F	2017-07-16 15:07:00+03	62600.00
EC7CC0	2017-08-08 16:59:00+03	122500.00
EC7CD0	2017-07-10 07:15:00+03	28000.00
EC7CF2	2017-08-06 00:26:00+03	122700.00
EC7D0A	2017-08-07 17:31:00+03	55800.00
EC7D10	2017-08-04 18:55:00+03	229900.00
EC7D1B	2017-07-17 11:09:00+03	56100.00
EC7D2E	2017-08-11 19:23:00+03	67000.00
EC7D5E	2017-07-09 21:33:00+03	29400.00
EC7DD0	2017-08-12 12:33:00+03	30900.00
EC7EA8	2017-07-09 08:27:00+03	23600.00
EC7EDA	2017-07-02 16:13:00+03	946800.00
EC7EFC	2017-07-13 00:36:00+03	111700.00
EC7F35	2017-08-06 23:26:00+03	81600.00
EC7F7F	2017-07-04 20:54:00+03	26700.00
EC7FFE	2017-07-30 14:46:00+03	254600.00
EC801A	2017-07-15 03:35:00+03	28000.00
EC801C	2017-07-18 01:28:00+03	43600.00
EC804D	2017-08-10 15:01:00+03	131100.00
EC8078	2017-08-11 02:06:00+03	73600.00
EC80B8	2017-07-24 06:08:00+03	67200.00
EC8110	2017-08-06 02:23:00+03	20500.00
EC811F	2017-08-10 23:48:00+03	15700.00
EC81C3	2017-08-14 04:45:00+03	23200.00
EC8240	2017-07-23 04:09:00+03	28800.00
EC8268	2017-08-05 15:54:00+03	94000.00
EC826E	2017-07-08 15:59:00+03	51900.00
EC8294	2017-07-19 14:18:00+03	132800.00
EC82B1	2017-08-08 10:34:00+03	128800.00
EC8382	2017-07-24 21:19:00+03	52700.00
EC83E8	2017-08-04 11:29:00+03	102800.00
EC8406	2017-07-17 16:21:00+03	28800.00
EC84E1	2017-07-25 20:19:00+03	26700.00
EC8508	2017-07-24 22:51:00+03	75100.00
EC850D	2017-08-05 02:26:00+03	27200.00
EC85FC	2017-08-09 18:54:00+03	43800.00
EC85FE	2017-07-13 08:27:00+03	58900.00
EC860C	2017-07-23 16:59:00+03	31100.00
EC864D	2017-06-30 15:57:00+03	99200.00
EC8668	2017-07-04 09:23:00+03	148200.00
EC866A	2017-07-18 23:25:00+03	29600.00
EC86A8	2017-07-20 23:30:00+03	90000.00
EC86E6	2017-07-18 23:26:00+03	39700.00
EC878E	2017-07-25 03:26:00+03	63500.00
EC8807	2017-08-10 20:08:00+03	68000.00
EC8819	2017-08-06 20:34:00+03	33400.00
EC8900	2017-07-21 16:31:00+03	28000.00
EC8939	2017-08-12 12:50:00+03	13400.00
EC89C0	2017-08-08 05:17:00+03	46400.00
EC89CF	2017-07-01 14:31:00+03	11700.00
EC89F4	2017-08-06 23:56:00+03	49200.00
EC8A4E	2017-07-12 22:41:00+03	78300.00
EC8A8A	2017-08-15 03:06:00+03	15000.00
EC8ADC	2017-07-01 22:05:00+03	140500.00
EC8AEC	2017-08-08 13:22:00+03	77000.00
EC8BAA	2017-07-06 22:15:00+03	52000.00
EC8BFB	2017-08-10 05:31:00+03	71200.00
EC8C48	2017-07-17 01:14:00+03	44100.00
EC8C88	2017-07-22 04:23:00+03	10600.00
EC8CBA	2017-08-11 18:26:00+03	42800.00
EC8CD8	2017-07-16 15:07:00+03	35400.00
EC8D64	2017-08-06 23:00:00+03	15400.00
EC8D99	2017-08-10 17:28:00+03	56000.00
EC8DBF	2017-07-06 12:33:00+03	112000.00
EC8DD8	2017-07-17 21:11:00+03	27500.00
EC8DFD	2017-07-11 10:18:00+03	49100.00
EC8E24	2017-07-05 09:23:00+03	21800.00
EC8E31	2017-07-08 23:26:00+03	223200.00
EC8E62	2017-07-18 23:07:00+03	123000.00
EC8F15	2017-07-08 02:24:00+03	44700.00
EC8F70	2017-07-07 03:34:00+03	19600.00
EC8F77	2017-07-03 20:30:00+03	28600.00
EC8FD0	2017-08-10 21:00:00+03	176400.00
EC900F	2017-07-14 01:08:00+03	108900.00
EC9020	2017-07-10 20:29:00+03	23400.00
EC904F	2017-07-19 22:47:00+03	109600.00
EC914F	2017-07-02 22:09:00+03	25800.00
EC91EA	2017-07-04 12:33:00+03	18300.00
EC924F	2017-07-16 23:36:00+03	61500.00
EC9301	2017-07-12 15:39:00+03	37900.00
EC9342	2017-07-23 11:09:00+03	93000.00
EC9369	2017-08-15 12:43:00+03	206400.00
EC937E	2017-08-05 09:21:00+03	27200.00
EC93AA	2017-08-08 15:10:00+03	53600.00
EC93DE	2017-07-17 22:13:00+03	258300.00
EC9484	2017-07-16 09:00:00+03	18700.00
EC94B4	2017-07-30 05:39:00+03	37900.00
EC94BB	2017-08-01 13:52:00+03	393800.00
EC94BC	2017-07-19 09:08:00+03	206300.00
EC9574	2017-07-20 20:47:00+03	13200.00
EC9598	2017-07-15 15:41:00+03	265600.00
EC95A3	2017-08-12 16:43:00+03	52400.00
EC9630	2017-07-17 01:42:00+03	29600.00
EC967A	2017-07-16 21:14:00+03	51100.00
EC96D1	2017-08-02 17:07:00+03	143000.00
EC96D9	2017-07-26 21:30:00+03	39200.00
EC96DB	2017-07-29 12:54:00+03	43200.00
EC96ED	2017-08-01 07:46:00+03	93700.00
EC9765	2017-07-19 17:11:00+03	57500.00
EC9776	2017-07-26 02:09:00+03	54000.00
EC97C8	2017-07-31 04:07:00+03	62800.00
EC97EE	2017-08-02 19:19:00+03	28600.00
EC982E	2017-07-11 19:54:00+03	112000.00
EC984C	2017-08-04 02:07:00+03	24400.00
EC9874	2017-07-26 05:12:00+03	51900.00
EC98A1	2017-07-24 00:30:00+03	14100.00
EC98AA	2017-07-01 12:08:00+03	57800.00
EC9944	2017-07-28 10:35:00+03	108600.00
EC9964	2017-08-15 04:29:00+03	9800.00
EC996F	2017-07-04 19:24:00+03	9800.00
EC998C	2017-08-04 22:50:00+03	51800.00
EC9A20	2017-07-19 00:20:00+03	54800.00
EC9A61	2017-07-31 11:08:00+03	86600.00
EC9A6E	2017-07-31 06:36:00+03	47100.00
EC9B87	2017-08-11 12:17:00+03	54000.00
EC9B88	2017-08-15 00:58:00+03	54800.00
EC9C32	2017-08-04 16:01:00+03	21400.00
EC9C70	2017-07-21 00:15:00+03	166100.00
EC9CC5	2017-07-28 03:13:00+03	265800.00
EC9CEF	2017-08-13 18:57:00+03	57600.00
EC9D0F	2017-07-09 07:45:00+03	38400.00
EC9D5E	2017-07-17 22:22:00+03	22100.00
EC9D6E	2017-07-26 19:45:00+03	62600.00
EC9D7E	2017-08-02 04:46:00+03	24400.00
EC9DC4	2017-07-21 09:14:00+03	167400.00
EC9DE0	2017-07-22 20:18:00+03	46000.00
EC9E01	2017-08-15 01:25:00+03	12000.00
EC9E49	2017-07-14 02:17:00+03	46300.00
EC9EAA	2017-07-13 17:15:00+03	55800.00
EC9F39	2017-08-04 15:00:00+03	52400.00
EC9F3E	2017-06-28 01:19:00+03	22600.00
EC9F57	2017-08-05 17:22:00+03	6600.00
EC9F8B	2017-07-17 05:34:00+03	411200.00
EC9FE6	2017-07-03 20:29:00+03	43200.00
ECA022	2017-07-20 12:24:00+03	44800.00
ECA09D	2017-08-01 01:37:00+03	16400.00
ECA0AD	2017-07-21 06:31:00+03	56600.00
ECA0D7	2017-07-03 20:48:00+03	35800.00
ECA0F0	2017-07-19 22:12:00+03	58600.00
ECA16F	2017-08-02 17:31:00+03	55800.00
ECA203	2017-07-20 15:45:00+03	46000.00
ECA270	2017-07-10 01:46:00+03	125400.00
ECA289	2017-07-23 14:52:00+03	38000.00
ECA2F6	2017-08-11 13:11:00+03	50700.00
ECA30C	2017-08-04 08:00:00+03	32700.00
ECA33D	2017-08-15 16:41:00+03	33800.00
ECA349	2017-08-04 08:37:00+03	188900.00
ECA362	2017-07-12 01:04:00+03	12600.00
ECA3E9	2017-07-07 13:11:00+03	78600.00
ECA462	2017-07-10 06:05:00+03	47200.00
ECA4C0	2017-07-18 18:58:00+03	84100.00
ECA4E5	2017-08-09 01:23:00+03	228600.00
ECA513	2017-07-02 05:20:00+03	64700.00
ECA55A	2017-07-04 16:00:00+03	34600.00
ECA59C	2017-08-05 11:03:00+03	27800.00
ECA5A9	2017-08-13 08:57:00+03	34400.00
ECA5C5	2017-08-11 10:28:00+03	177600.00
ECA5EE	2017-08-05 19:03:00+03	80300.00
ECA615	2017-07-06 06:17:00+03	14400.00
ECA657	2017-08-11 02:39:00+03	98300.00
ECA673	2017-07-13 18:35:00+03	84500.00
ECA6A7	2017-07-27 04:08:00+03	49500.00
ECA6C0	2017-07-29 06:28:00+03	103800.00
ECA6D7	2017-07-07 12:11:00+03	32400.00
ECA6F5	2017-07-16 03:04:00+03	218000.00
ECA7C5	2017-08-07 05:02:00+03	123600.00
ECA85E	2017-06-29 08:35:00+03	77200.00
ECA862	2017-07-14 08:35:00+03	12400.00
ECA8DC	2017-08-08 06:34:00+03	133200.00
ECA942	2017-07-18 05:00:00+03	54500.00
ECA97C	2017-08-03 17:16:00+03	57500.00
ECA997	2017-07-30 03:40:00+03	40800.00
ECA9F0	2017-07-19 02:13:00+03	23200.00
ECAA08	2017-08-04 06:42:00+03	22000.00
ECAADA	2017-07-21 18:54:00+03	96200.00
ECAAF7	2017-08-03 18:52:00+03	132400.00
ECAAFD	2017-07-17 16:51:00+03	20200.00
ECAB11	2017-07-16 13:32:00+03	12000.00
ECAB30	2017-07-25 19:18:00+03	57500.00
ECAB44	2017-07-07 22:22:00+03	28800.00
ECAB8D	2017-07-06 09:54:00+03	23200.00
ECAC17	2017-08-03 13:46:00+03	28800.00
ECAC1B	2017-07-22 21:37:00+03	24200.00
ECAC21	2017-07-01 17:06:00+03	97900.00
ECAC98	2017-07-20 16:16:00+03	77600.00
ECACE1	2017-07-20 08:20:00+03	81300.00
ECACEA	2017-07-30 05:35:00+03	56100.00
ECACF6	2017-07-07 15:24:00+03	135400.00
ECACFB	2017-07-30 17:42:00+03	67700.00
ECAD56	2017-07-24 02:11:00+03	37200.00
ECADB5	2017-07-29 12:16:00+03	49200.00
ECAE38	2017-07-07 23:49:00+03	42800.00
ECAE92	2017-08-01 02:01:00+03	127000.00
ECAF25	2017-08-02 19:11:00+03	13400.00
ECAF5F	2017-08-06 18:34:00+03	169900.00
ECAF75	2017-06-30 14:07:00+03	266400.00
ECAFCE	2017-08-07 00:39:00+03	78300.00
ECB04B	2017-08-11 07:08:00+03	187800.00
ECB090	2017-07-04 10:40:00+03	6800.00
ECB09A	2017-07-31 12:21:00+03	61800.00
ECB0B5	2017-07-28 06:04:00+03	6000.00
ECB10B	2017-07-19 19:40:00+03	46500.00
ECB110	2017-07-08 01:37:00+03	72400.00
ECB134	2017-07-15 20:28:00+03	189200.00
ECB198	2017-07-17 09:14:00+03	67600.00
ECB1A9	2017-07-25 12:53:00+03	14800.00
ECB1D7	2017-08-04 02:47:00+03	67800.00
ECB258	2017-07-24 15:53:00+03	136800.00
ECB27F	2017-08-13 19:03:00+03	23600.00
ECB297	2017-07-09 23:57:00+03	86300.00
ECB2A4	2017-08-04 06:24:00+03	24400.00
ECB2B7	2017-07-14 02:36:00+03	56000.00
ECB2CE	2017-07-12 23:43:00+03	51900.00
ECB2DA	2017-07-29 02:29:00+03	111600.00
ECB33C	2017-08-01 11:32:00+03	15400.00
ECB3A6	2017-07-26 22:50:00+03	17800.00
ECB3AF	2017-08-12 19:07:00+03	67900.00
ECB3B9	2017-07-13 11:52:00+03	55800.00
ECB3F1	2017-08-07 07:09:00+03	246000.00
ECB406	2017-06-28 19:06:00+03	26100.00
ECB408	2017-08-09 10:51:00+03	54000.00
ECB477	2017-08-09 01:30:00+03	75300.00
ECB4F5	2017-07-23 12:46:00+03	119500.00
ECB509	2017-07-18 09:04:00+03	67800.00
ECB550	2017-06-28 23:19:00+03	48500.00
ECB570	2017-07-31 06:10:00+03	40800.00
ECB57A	2017-07-25 18:50:00+03	133200.00
ECB5A9	2017-08-02 01:05:00+03	23400.00
ECB5CB	2017-07-15 02:23:00+03	232400.00
ECB5E6	2017-08-14 15:02:00+03	76800.00
ECB5E9	2017-07-03 18:28:00+03	136200.00
ECB61E	2017-07-26 08:12:00+03	266400.00
ECB626	2017-07-28 17:21:00+03	163500.00
ECB638	2017-07-09 04:05:00+03	233700.00
ECB63B	2017-07-12 10:00:00+03	198600.00
ECB673	2017-08-10 23:53:00+03	35800.00
ECB6F6	2017-08-06 09:01:00+03	37200.00
ECB6FA	2017-07-11 07:24:00+03	128900.00
ECB733	2017-08-08 00:44:00+03	59200.00
ECB7B1	2017-08-15 09:34:00+03	65900.00
ECB88D	2017-07-22 05:01:00+03	84500.00
ECB8A0	2017-08-12 10:53:00+03	31200.00
ECB8A5	2017-07-18 21:37:00+03	59200.00
ECB936	2017-07-27 01:01:00+03	52300.00
ECB96C	2017-07-03 04:09:00+03	111600.00
ECB99F	2017-07-22 11:14:00+03	184300.00
ECB9B2	2017-08-12 22:33:00+03	132800.00
ECBA04	2017-07-08 00:55:00+03	21400.00
ECBA38	2017-07-21 09:54:00+03	39800.00
ECBA4B	2017-08-09 18:50:00+03	124200.00
ECBA57	2017-07-16 16:05:00+03	22000.00
ECBA59	2017-07-30 15:13:00+03	86400.00
ECBA92	2017-07-01 01:56:00+03	135400.00
ECBBA7	2017-07-17 00:17:00+03	199100.00
ECBCB6	2017-08-05 13:50:00+03	62600.00
ECBCDA	2017-08-11 22:15:00+03	23200.00
ECBCE8	2017-07-24 11:52:00+03	80400.00
ECBD8A	2017-07-24 04:13:00+03	26000.00
ECBD94	2017-06-26 20:00:00+03	72800.00
ECBD9C	2017-08-02 20:48:00+03	59800.00
ECBDA8	2017-08-13 03:59:00+03	50100.00
ECBE19	2017-08-14 19:38:00+03	35300.00
ECBED5	2017-07-16 20:15:00+03	64400.00
ECBF37	2017-07-29 10:07:00+03	64500.00
ECBF4A	2017-08-08 00:20:00+03	91200.00
ECBF52	2017-07-09 12:39:00+03	93900.00
ECBF56	2017-07-28 02:24:00+03	27400.00
ECBF69	2017-07-05 16:45:00+03	40000.00
ECBF89	2017-07-07 01:20:00+03	12000.00
ECBF94	2017-08-03 02:03:00+03	49900.00
ECC05B	2017-07-27 22:01:00+03	539500.00
ECC06E	2017-07-20 06:29:00+03	32700.00
ECC100	2017-08-01 15:45:00+03	33800.00
ECC118	2017-08-07 08:33:00+03	55700.00
ECC158	2017-07-29 12:19:00+03	293900.00
ECC187	2017-06-29 23:41:00+03	22600.00
ECC1DC	2017-07-02 07:10:00+03	32700.00
ECC1E2	2017-08-02 23:53:00+03	37400.00
ECC1EF	2017-08-05 15:24:00+03	26000.00
ECC237	2017-08-05 18:19:00+03	46000.00
ECC28E	2017-08-04 04:28:00+03	43600.00
ECC296	2017-07-30 21:41:00+03	269000.00
ECC333	2017-07-14 04:19:00+03	141700.00
ECC3C1	2017-07-05 22:54:00+03	111600.00
ECC3F9	2017-08-07 07:37:00+03	15800.00
ECC3FC	2017-07-07 20:14:00+03	75200.00
ECC426	2017-07-20 10:01:00+03	24400.00
ECC430	2017-07-01 00:30:00+03	65500.00
ECC4B0	2017-07-07 03:09:00+03	120100.00
ECC52C	2017-08-07 18:58:00+03	112600.00
ECC569	2017-07-26 13:10:00+03	20600.00
ECC5C0	2017-07-13 12:20:00+03	266400.00
ECC5E5	2017-07-29 02:49:00+03	89600.00
ECC601	2017-08-15 10:11:00+03	254900.00
ECC677	2017-07-11 17:11:00+03	326200.00
ECC6E6	2017-08-13 09:31:00+03	67200.00
ECC6FE	2017-07-09 05:15:00+03	177200.00
ECC726	2017-08-14 22:29:00+03	100000.00
ECC736	2017-07-25 16:50:00+03	16400.00
ECC73E	2017-07-29 10:01:00+03	100600.00
ECC75E	2017-08-07 13:00:00+03	40100.00
ECC7BE	2017-07-10 17:01:00+03	35400.00
ECC7FB	2017-08-14 14:58:00+03	67000.00
ECC81C	2017-08-05 16:50:00+03	63400.00
ECC89C	2017-07-21 22:16:00+03	16400.00
ECC8BC	2017-08-13 20:54:00+03	34000.00
ECC8C8	2017-07-08 09:08:00+03	58700.00
ECC8E7	2017-07-08 09:32:00+03	66600.00
ECC8F3	2017-07-21 18:42:00+03	12400.00
ECC98C	2017-07-13 06:39:00+03	48800.00
ECC9E0	2017-07-23 19:55:00+03	67200.00
ECC9F9	2017-07-10 11:08:00+03	273400.00
ECCA1D	2017-08-11 15:01:00+03	25000.00
ECCA4B	2017-07-24 09:48:00+03	65900.00
ECCA5F	2017-08-01 09:13:00+03	28000.00
ECCAE4	2017-07-23 16:03:00+03	44500.00
ECCB41	2017-08-05 05:02:00+03	116000.00
ECCB44	2017-07-12 12:10:00+03	133200.00
ECCBBA	2017-07-26 23:01:00+03	16400.00
ECCC06	2017-07-27 08:44:00+03	277900.00
ECCC26	2017-08-10 02:46:00+03	492000.00
ECCC7D	2017-07-29 04:42:00+03	207000.00
ECCC97	2017-06-30 08:00:00+03	14400.00
ECCC99	2017-07-29 17:58:00+03	23600.00
ECCCD0	2017-07-29 17:24:00+03	187900.00
ECCCD4	2017-07-21 17:55:00+03	110500.00
ECCD2A	2017-07-27 13:47:00+03	68000.00
ECCD98	2017-07-27 13:55:00+03	29200.00
ECCDF8	2017-07-10 13:50:00+03	38400.00
ECCE1F	2017-07-12 11:22:00+03	31200.00
ECCE26	2017-07-07 13:34:00+03	135400.00
ECCE28	2017-08-03 06:15:00+03	84500.00
ECCE3D	2017-08-09 23:06:00+03	406700.00
ECCE4B	2017-07-24 14:02:00+03	65900.00
ECCE80	2017-07-18 07:47:00+03	80800.00
ECCED8	2017-06-30 21:07:00+03	43500.00
ECCEEE	2017-08-12 03:56:00+03	25200.00
ECCEF9	2017-07-04 22:01:00+03	246000.00
ECCF20	2017-08-07 13:01:00+03	28300.00
ECCF2F	2017-08-14 04:40:00+03	160200.00
ECCF3F	2017-08-12 20:33:00+03	12600.00
ECCF8A	2017-07-29 15:48:00+03	27200.00
ECD012	2017-07-25 08:27:00+03	67600.00
ECD035	2017-07-07 18:31:00+03	32800.00
ECD038	2017-07-19 07:20:00+03	28000.00
ECD076	2017-07-19 09:51:00+03	52800.00
ECD0DF	2017-07-16 07:46:00+03	60700.00
ECD181	2017-07-24 16:47:00+03	12600.00
ECD1BA	2017-07-18 23:47:00+03	16300.00
ECD1F4	2017-07-06 01:23:00+03	123000.00
ECD1FA	2017-08-14 07:52:00+03	180000.00
ECD222	2017-07-28 01:57:00+03	26000.00
ECD2A0	2017-07-16 10:17:00+03	202400.00
ECD34C	2017-07-09 15:47:00+03	123400.00
ECD34F	2017-08-13 23:08:00+03	55800.00
ECD374	2017-08-13 07:52:00+03	55800.00
ECD410	2017-07-27 04:51:00+03	40000.00
ECD4EF	2017-07-30 07:11:00+03	40400.00
ECD4F1	2017-08-15 02:57:00+03	47400.00
ECD556	2017-07-30 02:33:00+03	20200.00
ECD583	2017-07-04 14:06:00+03	136800.00
ECD67B	2017-07-31 15:10:00+03	47600.00
ECD70F	2017-08-04 08:55:00+03	32700.00
ECD74E	2017-07-24 09:29:00+03	22000.00
ECD7D8	2017-08-09 09:30:00+03	47200.00
ECD7DA	2017-08-04 09:27:00+03	57500.00
ECD7EF	2017-06-30 17:37:00+03	52600.00
ECD7F8	2017-07-11 08:26:00+03	11000.00
ECD82D	2017-08-04 23:24:00+03	37200.00
ECD83B	2017-07-10 03:49:00+03	13400.00
ECD8BF	2017-07-13 19:33:00+03	39400.00
ECD90B	2017-07-16 18:36:00+03	68800.00
ECD919	2017-08-14 21:49:00+03	6300.00
ECD96B	2017-07-14 05:13:00+03	40200.00
ECD99D	2017-07-05 23:32:00+03	47000.00
ECDA1C	2017-07-26 12:29:00+03	111600.00
ECDA1F	2017-07-18 06:35:00+03	10600.00
ECDA20	2017-07-22 17:40:00+03	56000.00
ECDACC	2017-08-08 04:18:00+03	258400.00
ECDB0B	2017-07-15 04:37:00+03	22600.00
ECDB85	2017-07-18 04:13:00+03	54500.00
ECDBFA	2017-08-09 07:10:00+03	88100.00
ECDC02	2017-07-09 07:57:00+03	59100.00
ECDC06	2017-07-11 02:13:00+03	179400.00
ECDC6A	2017-07-07 10:24:00+03	29000.00
ECDC6B	2017-07-29 06:22:00+03	112000.00
ECDC80	2017-06-30 16:39:00+03	106100.00
ECDC8D	2017-08-14 03:13:00+03	87100.00
ECDC96	2017-07-30 08:39:00+03	21400.00
ECDCAE	2017-07-06 18:41:00+03	406700.00
ECDCB1	2017-08-14 20:38:00+03	67700.00
ECDD00	2017-08-06 01:28:00+03	23200.00
ECDD9F	2017-08-15 12:43:00+03	206400.00
ECDDB8	2017-07-04 15:01:00+03	112600.00
ECDDE5	2017-08-10 16:15:00+03	85000.00
ECDE19	2017-08-06 17:08:00+03	91500.00
ECDEDD	2017-08-01 22:33:00+03	66600.00
ECDF3E	2017-07-18 20:52:00+03	91800.00
ECDF6D	2017-07-21 10:19:00+03	12200.00
ECDFDE	2017-08-09 05:41:00+03	59900.00
ECDFE8	2017-07-07 11:26:00+03	226400.00
ECE013	2017-07-10 18:31:00+03	37100.00
ECE0B1	2017-08-13 22:33:00+03	489100.00
ECE0F4	2017-08-01 18:18:00+03	72300.00
ECE157	2017-07-04 05:38:00+03	112000.00
ECE17A	2017-08-11 00:00:00+03	40200.00
ECE1CC	2017-07-08 09:33:00+03	56600.00
ECE205	2017-08-03 20:41:00+03	24400.00
ECE22B	2017-08-09 03:41:00+03	133200.00
ECE22C	2017-07-27 04:21:00+03	93900.00
ECE24A	2017-07-06 23:07:00+03	49100.00
ECE26A	2017-07-04 19:43:00+03	32800.00
ECE297	2017-07-19 18:50:00+03	49400.00
ECE2B5	2017-07-09 20:39:00+03	23600.00
ECE2B7	2017-07-27 21:10:00+03	115300.00
ECE2CD	2017-07-19 10:17:00+03	111500.00
ECE2E7	2017-08-14 23:08:00+03	37900.00
ECE307	2017-07-26 22:16:00+03	142800.00
ECE30F	2017-07-22 04:04:00+03	12600.00
ECE366	2017-07-04 16:06:00+03	26000.00
ECE3D7	2017-07-27 07:44:00+03	30200.00
ECE402	2017-07-15 00:45:00+03	42800.00
ECE419	2017-07-13 12:03:00+03	60200.00
ECE423	2017-07-10 05:30:00+03	11600.00
ECE45A	2017-07-30 21:21:00+03	28000.00
ECE48B	2017-07-13 18:29:00+03	134600.00
ECE491	2017-07-12 02:42:00+03	26600.00
ECE49C	2017-08-05 19:39:00+03	55800.00
ECE4AC	2017-08-05 19:26:00+03	112000.00
ECE4E2	2017-07-13 11:47:00+03	57500.00
ECE4EF	2017-07-13 18:48:00+03	65500.00
ECE53D	2017-08-05 17:55:00+03	32700.00
ECE56F	2017-08-04 08:10:00+03	27200.00
ECE5A6	2017-07-06 17:45:00+03	117600.00
ECE5C7	2017-07-23 01:07:00+03	120800.00
ECE5E2	2017-07-21 18:10:00+03	13400.00
ECE5F3	2017-07-03 22:15:00+03	29400.00
ECE60D	2017-07-16 23:28:00+03	62600.00
ECE78E	2017-07-19 13:35:00+03	132500.00
ECE7B0	2017-08-08 20:47:00+03	122400.00
ECE81A	2017-07-01 11:49:00+03	79900.00
ECE86A	2017-07-24 09:38:00+03	37900.00
ECE8CD	2017-07-26 17:09:00+03	186900.00
ECE8FE	2017-07-14 03:02:00+03	47500.00
ECE90E	2017-08-02 16:52:00+03	29400.00
ECE944	2017-07-14 18:49:00+03	54800.00
ECE96F	2017-07-25 15:32:00+03	102100.00
ECE9EB	2017-07-28 01:08:00+03	128600.00
ECE9FD	2017-07-18 10:46:00+03	89800.00
ECEA01	2017-07-16 05:34:00+03	115700.00
ECEA1B	2017-08-08 13:18:00+03	57400.00
ECEA42	2017-07-13 23:53:00+03	29600.00
ECEB44	2017-07-05 02:24:00+03	50600.00
ECEB4E	2017-07-27 01:53:00+03	90800.00
ECEB5F	2017-07-07 08:41:00+03	144400.00
ECEBA1	2017-07-27 08:19:00+03	58700.00
ECEBF2	2017-07-26 18:58:00+03	47200.00
ECEC32	2017-07-30 07:11:00+03	244100.00
ECEC57	2017-08-14 07:52:00+03	102300.00
ECEC84	2017-07-23 23:56:00+03	92900.00
ECEC99	2017-07-31 08:49:00+03	56100.00
ECECD6	2017-07-18 14:49:00+03	406700.00
ECED25	2017-08-08 17:22:00+03	92100.00
ECED6F	2017-07-05 20:21:00+03	37100.00
ECEDE6	2017-07-23 10:03:00+03	65500.00
ECEE13	2017-07-27 22:43:00+03	99200.00
ECEE7A	2017-07-16 12:50:00+03	56100.00
ECEE9D	2017-07-17 10:16:00+03	60400.00
ECEECC	2017-07-08 01:05:00+03	47400.00
ECEEFB	2017-07-03 07:52:00+03	203100.00
ECEF4D	2017-07-08 18:57:00+03	73600.00
ECEF4F	2017-07-05 09:10:00+03	49400.00
ECEF75	2017-08-04 11:19:00+03	153200.00
ECEFE1	2017-08-14 21:52:00+03	26800.00
ECF00E	2017-07-11 01:35:00+03	246000.00
ECF09A	2017-08-15 12:21:00+03	31000.00
ECF0D2	2017-07-05 04:38:00+03	88900.00
ECF0FE	2017-07-31 18:16:00+03	6800.00
ECF10D	2017-07-21 19:57:00+03	29400.00
ECF14E	2017-08-15 12:46:00+03	6700.00
ECF162	2017-08-13 21:56:00+03	74800.00
ECF191	2017-07-06 00:44:00+03	95600.00
ECF1CB	2017-07-26 07:08:00+03	45100.00
ECF1E1	2017-08-13 17:20:00+03	20200.00
ECF271	2017-07-09 17:46:00+03	55800.00
ECF2D3	2017-07-24 19:38:00+03	6000.00
ECF2D9	2017-08-06 15:57:00+03	50200.00
ECF348	2017-08-05 16:52:00+03	109600.00
ECF359	2017-07-06 21:40:00+03	99300.00
ECF3AF	2017-08-04 10:28:00+03	89600.00
ECF430	2017-07-29 02:16:00+03	190200.00
ECF499	2017-07-11 23:28:00+03	59800.00
ECF4CD	2017-07-21 04:40:00+03	40000.00
ECF4DC	2017-07-31 06:24:00+03	187800.00
ECF4DD	2017-07-02 17:02:00+03	135000.00
ECF4F7	2017-07-16 11:33:00+03	75300.00
ECF4FC	2017-07-29 23:07:00+03	24400.00
ECF541	2017-07-12 02:57:00+03	168000.00
ECF544	2017-08-02 15:35:00+03	70800.00
ECF569	2017-07-03 22:26:00+03	477600.00
ECF5E4	2017-07-10 14:46:00+03	13400.00
ECF613	2017-07-07 13:16:00+03	16400.00
ECF654	2017-07-31 04:39:00+03	67400.00
ECF6CD	2017-08-15 17:34:00+03	60600.00
ECF6D7	2017-08-07 08:02:00+03	35900.00
ECF703	2017-07-29 17:30:00+03	75300.00
ECF712	2017-07-04 23:07:00+03	29600.00
ECF7C6	2017-08-14 01:49:00+03	29600.00
ECF7D3	2017-08-01 03:13:00+03	26800.00
ECF857	2017-07-24 08:39:00+03	54400.00
ECF861	2017-07-27 10:26:00+03	148200.00
ECF87F	2017-07-02 13:41:00+03	29600.00
ECF8B2	2017-07-07 05:11:00+03	34200.00
ECF8E8	2017-08-09 19:35:00+03	15400.00
ECF92B	2017-07-22 17:27:00+03	8200.00
ECF9C3	2017-08-14 18:34:00+03	46300.00
ECFA43	2017-08-04 04:52:00+03	231700.00
ECFADC	2017-08-11 14:35:00+03	13000.00
ECFAE6	2017-07-10 04:05:00+03	86600.00
ECFB2D	2017-07-03 15:28:00+03	16400.00
ECFB56	2017-08-06 19:38:00+03	79000.00
ECFB70	2017-07-10 21:43:00+03	64300.00
ECFB7C	2017-07-25 16:55:00+03	8400.00
ECFD48	2017-07-09 04:23:00+03	61800.00
ECFD70	2017-08-10 22:47:00+03	246000.00
ECFD7A	2017-08-09 14:16:00+03	11700.00
ECFDBE	2017-07-27 14:07:00+03	38300.00
ECFE08	2017-07-07 18:03:00+03	96900.00
ECFE19	2017-08-05 14:12:00+03	53400.00
ECFE34	2017-07-16 19:42:00+03	108500.00
ECFE7A	2017-08-15 09:15:00+03	96800.00
ECFEAB	2017-07-07 18:51:00+03	202000.00
ECFEAE	2017-07-22 05:31:00+03	28000.00
ECFECA	2017-08-06 00:21:00+03	178200.00
ECFF5E	2017-07-18 11:09:00+03	39300.00
ECFF7E	2017-07-23 04:36:00+03	38800.00
ECFFCE	2017-07-09 18:09:00+03	20200.00
ECFFD7	2017-08-07 18:49:00+03	69600.00
ED004B	2017-08-14 17:08:00+03	26000.00
ED012C	2017-08-10 07:45:00+03	94700.00
ED016F	2017-07-23 17:32:00+03	111600.00
ED01CD	2017-07-20 23:19:00+03	94000.00
ED0211	2017-07-05 23:20:00+03	23600.00
ED0223	2017-07-25 14:45:00+03	54800.00
ED0242	2017-08-06 12:29:00+03	36800.00
ED0315	2017-08-08 22:40:00+03	188000.00
ED03A2	2017-07-27 14:27:00+03	128800.00
ED0400	2017-06-29 23:17:00+03	42800.00
ED04F1	2017-07-15 04:09:00+03	46200.00
ED059F	2017-08-13 04:29:00+03	22400.00
ED05AC	2017-08-15 04:55:00+03	57500.00
ED05F3	2017-07-07 15:30:00+03	26700.00
ED062C	2017-08-12 00:21:00+03	26000.00
ED066B	2017-07-27 12:23:00+03	48400.00
ED06A1	2017-08-11 06:18:00+03	85000.00
ED06C0	2017-07-19 09:16:00+03	55800.00
ED0803	2017-08-02 09:02:00+03	48800.00
ED0822	2017-07-22 10:00:00+03	106200.00
ED082F	2017-07-07 13:47:00+03	266400.00
ED0833	2017-07-21 17:23:00+03	83000.00
ED084A	2017-07-11 01:23:00+03	8000.00
ED0881	2017-08-07 16:35:00+03	46900.00
ED08A1	2017-07-12 21:16:00+03	39300.00
ED08DB	2017-07-12 00:09:00+03	80400.00
ED08DD	2017-07-24 20:55:00+03	23600.00
ED08F5	2017-07-20 04:43:00+03	25400.00
ED08FE	2017-07-13 21:43:00+03	138300.00
ED0903	2017-08-05 07:14:00+03	189200.00
ED0911	2017-07-04 18:11:00+03	24200.00
ED0946	2017-07-16 17:35:00+03	27300.00
ED096A	2017-07-14 10:35:00+03	156000.00
ED09B3	2017-07-17 13:34:00+03	46800.00
ED09C7	2017-07-05 09:12:00+03	182000.00
ED09E2	2017-07-15 17:04:00+03	14000.00
ED09E4	2017-07-06 16:39:00+03	119400.00
ED0A95	2017-07-08 18:26:00+03	27200.00
ED0AB2	2017-07-20 14:20:00+03	10600.00
ED0AB4	2017-07-18 17:34:00+03	62600.00
ED0ADA	2017-07-15 21:58:00+03	43600.00
ED0B09	2017-08-13 07:29:00+03	28000.00
ED0B18	2017-07-08 05:41:00+03	28000.00
ED0B31	2017-08-14 12:27:00+03	100600.00
ED0B3F	2017-07-01 12:35:00+03	41800.00
ED0B4C	2017-08-12 12:12:00+03	18600.00
ED0B8A	2017-08-04 14:19:00+03	199600.00
ED0B90	2017-07-21 16:58:00+03	93900.00
ED0C3F	2017-08-09 14:34:00+03	58400.00
ED0C92	2017-07-01 09:45:00+03	70700.00
ED0CB2	2017-07-26 21:04:00+03	29600.00
ED0CC4	2017-08-05 18:36:00+03	66600.00
ED0D0E	2017-07-14 16:45:00+03	248400.00
ED0D1C	2017-07-24 20:33:00+03	56000.00
ED0D1E	2017-07-24 13:20:00+03	7400.00
ED0D7A	2017-07-17 14:57:00+03	66000.00
ED0E22	2017-07-31 19:21:00+03	13300.00
ED0E35	2017-08-02 02:23:00+03	21800.00
ED0E74	2017-07-16 17:00:00+03	62600.00
ED0F4B	2017-08-15 09:34:00+03	21800.00
ED0F62	2017-08-08 14:06:00+03	57400.00
ED0F9E	2017-07-15 22:34:00+03	13800.00
ED0FB2	2017-08-08 22:52:00+03	37900.00
ED0FDB	2017-07-31 06:28:00+03	83000.00
ED1027	2017-07-04 12:24:00+03	7200.00
ED107D	2017-07-25 00:28:00+03	46400.00
ED11D8	2017-07-31 01:22:00+03	184300.00
ED1232	2017-07-31 19:49:00+03	77000.00
ED1267	2017-07-05 09:08:00+03	93800.00
ED1269	2017-07-26 20:48:00+03	48800.00
ED1281	2017-07-26 14:18:00+03	12400.00
ED140A	2017-07-05 08:16:00+03	99300.00
ED1470	2017-07-15 13:40:00+03	95900.00
ED147E	2017-07-12 10:27:00+03	39900.00
ED1492	2017-07-16 18:07:00+03	66600.00
ED14C4	2017-08-02 07:11:00+03	75600.00
ED1502	2017-07-18 06:02:00+03	22100.00
ED1531	2017-06-30 03:42:00+03	196800.00
ED156F	2017-08-11 13:02:00+03	248400.00
ED1574	2017-07-26 16:43:00+03	248300.00
ED1635	2017-07-04 19:48:00+03	32800.00
ED165A	2017-08-08 06:21:00+03	17800.00
ED165E	2017-07-07 14:39:00+03	432500.00
ED1701	2017-07-31 20:16:00+03	24000.00
ED1703	2017-07-13 00:09:00+03	37900.00
ED1708	2017-07-04 18:14:00+03	49600.00
ED1733	2017-07-24 17:49:00+03	37700.00
ED1884	2017-07-14 10:27:00+03	30200.00
ED188D	2017-08-11 02:47:00+03	12000.00
ED18AA	2017-08-12 09:29:00+03	26000.00
ED18BB	2017-08-04 03:34:00+03	48800.00
ED18DA	2017-07-10 23:01:00+03	266400.00
ED1968	2017-07-03 20:25:00+03	101200.00
ED19D0	2017-07-25 09:00:00+03	24800.00
ED19D7	2017-07-20 07:26:00+03	83000.00
ED1A0A	2017-07-23 12:59:00+03	15000.00
ED1A11	2017-07-02 15:31:00+03	56100.00
ED1A44	2017-07-08 16:03:00+03	48100.00
ED1A65	2017-07-25 18:15:00+03	39500.00
ED1AAD	2017-08-07 20:21:00+03	36000.00
ED1B44	2017-07-31 19:50:00+03	64800.00
ED1B5A	2017-08-08 03:19:00+03	25200.00
ED1B70	2017-07-26 01:48:00+03	271400.00
ED1B71	2017-08-02 11:29:00+03	6000.00
ED1BA3	2017-07-18 08:13:00+03	410500.00
ED1C45	2017-07-03 07:27:00+03	119400.00
ED1C86	2017-08-03 16:39:00+03	137100.00
ED1CCD	2017-08-07 13:29:00+03	149400.00
ED1CD4	2017-07-21 18:01:00+03	246000.00
ED1DDC	2017-07-15 07:06:00+03	15900.00
ED1E08	2017-07-09 20:25:00+03	14400.00
ED1E11	2017-08-14 11:48:00+03	53200.00
ED1E30	2017-07-10 00:01:00+03	185600.00
ED1E49	2017-07-01 22:13:00+03	77000.00
ED1E7E	2017-07-18 06:07:00+03	46200.00
ED1EAA	2017-07-24 15:56:00+03	131600.00
ED1EDD	2017-08-14 15:40:00+03	69700.00
ED1EE4	2017-07-08 08:44:00+03	28800.00
ED1EFE	2017-07-25 22:10:00+03	615000.00
ED1F8F	2017-08-15 08:40:00+03	54500.00
ED1FE8	2017-07-19 16:54:00+03	55800.00
ED1FEF	2017-07-22 02:12:00+03	36700.00
ED200D	2017-08-06 03:28:00+03	117600.00
ED2010	2017-07-13 07:14:00+03	13600.00
ED2071	2017-08-03 07:01:00+03	213200.00
ED2080	2017-07-17 00:53:00+03	56000.00
ED2117	2017-08-12 03:02:00+03	56000.00
ED2120	2017-07-05 04:41:00+03	49100.00
ED2137	2017-08-10 16:32:00+03	314400.00
ED2159	2017-07-27 11:03:00+03	46200.00
ED21D4	2017-08-11 20:03:00+03	38800.00
ED21F3	2017-07-18 12:08:00+03	132800.00
ED2206	2017-07-14 02:32:00+03	95600.00
ED2220	2017-08-14 12:50:00+03	75600.00
ED2231	2017-07-31 23:01:00+03	29400.00
ED2248	2017-08-02 06:54:00+03	51300.00
ED2255	2017-07-06 20:10:00+03	28800.00
ED225B	2017-07-03 10:21:00+03	121400.00
ED2279	2017-07-19 01:39:00+03	67200.00
ED22BC	2017-08-15 16:22:00+03	43600.00
ED22D3	2017-07-18 16:11:00+03	68400.00
ED233D	2017-07-05 03:23:00+03	10600.00
ED237B	2017-08-03 02:51:00+03	13600.00
ED2404	2017-07-01 18:46:00+03	23200.00
ED240C	2017-07-17 15:12:00+03	96800.00
ED2492	2017-07-07 23:23:00+03	48800.00
ED24B3	2017-08-07 22:35:00+03	36600.00
ED2515	2017-07-03 02:42:00+03	13400.00
ED2568	2017-07-16 07:59:00+03	25100.00
ED25D6	2017-07-11 12:28:00+03	114500.00
ED2625	2017-07-24 09:07:00+03	63300.00
ED2628	2017-07-02 05:26:00+03	86800.00
ED26B9	2017-08-13 11:06:00+03	114700.00
ED2709	2017-07-14 02:35:00+03	26800.00
ED272A	2017-07-18 23:55:00+03	70100.00
ED2732	2017-07-05 05:12:00+03	12400.00
ED277A	2017-08-15 13:12:00+03	23600.00
ED27BC	2017-08-05 16:01:00+03	100600.00
ED27D6	2017-07-04 19:26:00+03	129000.00
ED2800	2017-07-03 14:15:00+03	20200.00
ED281C	2017-06-30 09:56:00+03	42700.00
ED2878	2017-07-19 12:05:00+03	114700.00
ED2884	2017-07-27 23:56:00+03	117300.00
ED2927	2017-08-09 06:22:00+03	84500.00
ED2931	2017-07-09 21:38:00+03	50300.00
ED2969	2017-08-12 13:46:00+03	47000.00
ED2970	2017-07-09 01:29:00+03	102100.00
ED298F	2017-07-31 09:41:00+03	11000.00
ED29A2	2017-07-20 04:27:00+03	22000.00
ED29A5	2017-07-07 02:02:00+03	118200.00
ED29A8	2017-07-14 14:23:00+03	332100.00
ED29B7	2017-08-04 10:26:00+03	58600.00
ED2A44	2017-07-04 06:26:00+03	46400.00
ED2A4F	2017-08-09 05:10:00+03	44800.00
ED2B94	2017-08-07 16:04:00+03	23400.00
ED2BD2	2017-08-14 21:26:00+03	60700.00
ED2BDA	2017-08-04 06:49:00+03	201800.00
ED2C76	2017-07-01 07:30:00+03	67200.00
ED2CE2	2017-07-30 06:35:00+03	83000.00
ED2DD9	2017-07-05 04:21:00+03	58600.00
ED2DFD	2017-08-04 19:28:00+03	31100.00
ED2E8F	2017-07-10 00:20:00+03	94100.00
ED2ECB	2017-07-27 05:32:00+03	32600.00
ED2F25	2017-07-28 05:47:00+03	218000.00
ED2F9E	2017-07-09 08:36:00+03	87100.00
ED3016	2017-08-06 06:45:00+03	24400.00
ED3081	2017-07-28 02:58:00+03	57900.00
ED30A9	2017-08-04 07:49:00+03	95200.00
ED30BD	2017-08-10 20:00:00+03	115800.00
ED3100	2017-07-26 16:42:00+03	68800.00
ED3116	2017-08-12 18:34:00+03	131800.00
ED3128	2017-07-12 17:13:00+03	17800.00
ED3168	2017-07-02 20:46:00+03	176600.00
ED3180	2017-07-31 06:35:00+03	27800.00
ED3190	2017-07-30 09:42:00+03	83000.00
ED31BC	2017-08-06 03:05:00+03	28800.00
ED3200	2017-07-05 14:22:00+03	64700.00
ED3243	2017-07-14 15:34:00+03	28000.00
ED329E	2017-07-26 04:56:00+03	77800.00
ED32B9	2017-07-03 12:01:00+03	17800.00
ED32C4	2017-08-13 00:23:00+03	16500.00
ED32DE	2017-08-09 09:54:00+03	24400.00
ED32F3	2017-08-14 01:10:00+03	58200.00
ED332A	2017-08-12 13:18:00+03	141100.00
ED3359	2017-07-13 13:20:00+03	85600.00
ED335B	2017-08-11 05:43:00+03	86400.00
ED336A	2017-07-16 22:30:00+03	46000.00
ED3377	2017-08-01 14:46:00+03	148800.00
ED33B1	2017-07-14 01:26:00+03	96300.00
ED33C3	2017-07-20 17:57:00+03	20700.00
ED3498	2017-06-29 18:42:00+03	31200.00
ED34A0	2017-07-20 00:06:00+03	6800.00
ED34BA	2017-08-14 07:10:00+03	38600.00
ED34D2	2017-07-17 16:03:00+03	29600.00
ED351F	2017-07-06 09:57:00+03	54800.00
ED3555	2017-08-09 14:48:00+03	28800.00
ED3568	2017-07-18 08:48:00+03	15400.00
ED35CC	2017-08-11 00:28:00+03	56000.00
ED35EF	2017-07-26 20:56:00+03	59800.00
ED3629	2017-07-25 00:44:00+03	103200.00
ED363A	2017-08-13 15:34:00+03	18600.00
ED3642	2017-08-06 15:52:00+03	59200.00
ED3644	2017-08-14 00:25:00+03	136800.00
ED368F	2017-08-07 09:28:00+03	15100.00
ED369E	2017-07-08 20:46:00+03	52300.00
ED372F	2017-08-10 17:18:00+03	31600.00
ED377E	2017-07-29 16:25:00+03	31600.00
ED37A6	2017-07-14 22:51:00+03	27800.00
ED37B1	2017-07-17 19:11:00+03	54700.00
ED37F0	2017-06-30 05:32:00+03	75600.00
ED3813	2017-08-07 20:33:00+03	167400.00
ED3825	2017-08-12 05:28:00+03	95300.00
ED38AD	2017-07-10 03:31:00+03	63200.00
ED393E	2017-07-15 00:17:00+03	28000.00
ED39A5	2017-08-08 13:47:00+03	56900.00
ED39D9	2017-08-14 23:19:00+03	86600.00
ED3A06	2017-07-26 16:29:00+03	13500.00
ED3A0D	2017-08-09 19:44:00+03	12600.00
ED3A16	2017-07-08 01:20:00+03	54400.00
ED3A17	2017-07-16 07:31:00+03	38600.00
ED3A1C	2017-08-12 13:03:00+03	64100.00
ED3A34	2017-08-05 02:05:00+03	13600.00
ED3A83	2017-06-28 17:24:00+03	23600.00
ED3AB7	2017-08-02 01:50:00+03	30300.00
ED3AF9	2017-07-17 06:55:00+03	40400.00
ED3B45	2017-07-06 15:03:00+03	9200.00
ED3B72	2017-07-11 18:11:00+03	51500.00
ED3B9D	2017-07-20 22:39:00+03	131100.00
ED3BB0	2017-07-21 14:04:00+03	28600.00
ED3BE6	2017-08-11 18:31:00+03	23600.00
ED3C2D	2017-07-20 07:24:00+03	46300.00
ED3C34	2017-08-15 17:21:00+03	266400.00
ED3CA1	2017-07-22 18:40:00+03	94000.00
ED3D5B	2017-08-12 15:24:00+03	168000.00
ED3E99	2017-08-13 01:06:00+03	44500.00
ED3EB9	2017-08-04 09:22:00+03	24400.00
ED3F1D	2017-07-14 01:09:00+03	88300.00
ED3F3B	2017-08-06 04:30:00+03	86800.00
ED3F5C	2017-07-04 21:38:00+03	136800.00
ED3F84	2017-08-11 22:17:00+03	122700.00
ED3F8E	2017-07-16 01:06:00+03	101200.00
ED4050	2017-08-02 13:39:00+03	178800.00
ED406F	2017-08-12 04:22:00+03	70600.00
ED414C	2017-07-23 08:45:00+03	89600.00
ED4151	2017-07-02 18:30:00+03	43700.00
ED41B0	2017-08-13 00:00:00+03	295500.00
ED41DA	2017-08-01 22:29:00+03	67100.00
ED4274	2017-07-23 07:18:00+03	133200.00
ED4278	2017-07-22 15:59:00+03	58900.00
ED42A7	2017-07-25 11:06:00+03	32800.00
ED4304	2017-08-05 20:54:00+03	101900.00
ED4339	2017-07-20 14:58:00+03	333400.00
ED43E9	2017-07-02 00:45:00+03	16800.00
ED43F4	2017-08-13 07:01:00+03	136800.00
ED43FA	2017-06-29 18:54:00+03	206700.00
ED440B	2017-07-30 02:09:00+03	28800.00
ED445A	2017-08-06 02:15:00+03	20200.00
ED4492	2017-07-16 03:30:00+03	67000.00
ED4563	2017-07-18 06:43:00+03	124200.00
ED45B5	2017-06-30 01:57:00+03	58000.00
ED45E0	2017-07-20 05:41:00+03	31400.00
ED465A	2017-07-18 02:05:00+03	112100.00
ED46A6	2017-07-19 13:39:00+03	28000.00
ED46B6	2017-08-09 01:40:00+03	198100.00
ED46BC	2017-07-10 20:34:00+03	88500.00
ED46C8	2017-08-13 20:22:00+03	397100.00
ED46E3	2017-07-07 06:00:00+03	49100.00
ED4784	2017-07-16 22:09:00+03	14800.00
ED47AA	2017-08-04 06:48:00+03	47000.00
ED47D5	2017-07-07 13:07:00+03	82000.00
ED4801	2017-07-25 22:37:00+03	113800.00
ED48A7	2017-07-02 07:42:00+03	39200.00
ED48E3	2017-07-09 11:08:00+03	293300.00
ED495C	2017-08-02 02:17:00+03	75300.00
ED497C	2017-07-11 20:28:00+03	37200.00
ED49A2	2017-08-07 21:00:00+03	43100.00
ED49BB	2017-08-01 02:47:00+03	6300.00
ED4A0E	2017-08-02 20:45:00+03	28800.00
ED4A35	2017-08-12 12:11:00+03	48200.00
ED4A6B	2017-08-04 12:05:00+03	70000.00
ED4A87	2017-08-01 03:25:00+03	34000.00
ED4AC2	2017-07-15 07:22:00+03	44000.00
ED4AF8	2017-07-16 05:14:00+03	34000.00
ED4B67	2017-07-26 11:21:00+03	70700.00
ED4B9C	2017-07-15 21:35:00+03	159800.00
ED4BB1	2017-08-08 08:14:00+03	52000.00
ED4C02	2017-07-06 15:10:00+03	23600.00
ED4C2E	2017-08-12 00:50:00+03	65200.00
ED4C54	2017-08-04 16:01:00+03	56100.00
ED4C90	2017-07-18 00:33:00+03	32800.00
ED4C93	2017-07-30 12:42:00+03	77600.00
ED4CB7	2017-07-16 04:03:00+03	242600.00
ED4D14	2017-07-30 14:52:00+03	53600.00
ED4DDC	2017-07-12 06:31:00+03	85000.00
ED4DE1	2017-08-14 02:42:00+03	18400.00
ED4DE6	2017-07-20 17:22:00+03	31600.00
ED4E11	2017-08-08 22:31:00+03	99300.00
ED4E22	2017-08-14 14:20:00+03	131600.00
ED4E8A	2017-08-07 15:25:00+03	10800.00
ED4E8F	2017-07-13 18:11:00+03	131100.00
ED4F42	2017-07-16 11:30:00+03	88900.00
ED4F9E	2017-07-07 11:15:00+03	138900.00
ED501D	2017-07-10 13:05:00+03	23200.00
ED5037	2017-07-17 19:52:00+03	32800.00
ED5096	2017-08-05 15:07:00+03	67800.00
ED509F	2017-07-21 13:42:00+03	60400.00
ED512E	2017-07-29 21:52:00+03	23200.00
ED5140	2017-08-05 10:54:00+03	28000.00
ED5151	2017-07-23 01:33:00+03	33000.00
ED51F7	2017-07-17 01:12:00+03	21600.00
ED527B	2017-07-28 05:25:00+03	41200.00
ED52C9	2017-07-28 22:42:00+03	66200.00
ED52DC	2017-07-13 12:47:00+03	56000.00
ED52DE	2017-07-26 23:58:00+03	16400.00
ED52EC	2017-07-22 23:15:00+03	242300.00
ED5307	2017-07-10 00:06:00+03	25200.00
ED534F	2017-08-15 04:43:00+03	95600.00
ED53AF	2017-07-27 13:14:00+03	78800.00
ED53B6	2017-07-01 10:05:00+03	73600.00
ED5414	2017-07-27 14:26:00+03	16400.00
ED54A3	2017-08-01 08:19:00+03	46000.00
ED54E5	2017-07-22 10:55:00+03	62700.00
ED5567	2017-08-05 16:22:00+03	6000.00
ED559F	2017-08-11 06:11:00+03	40000.00
ED55CE	2017-07-19 14:25:00+03	46200.00
ED5616	2017-08-02 10:09:00+03	31700.00
ED566B	2017-07-06 14:03:00+03	37700.00
ED568A	2017-07-22 16:06:00+03	21800.00
ED5767	2017-07-24 08:59:00+03	40800.00
ED5793	2017-07-12 12:21:00+03	84100.00
ED57A8	2017-07-07 02:37:00+03	116800.00
ED57BB	2017-07-05 05:35:00+03	174000.00
ED5845	2017-08-03 05:06:00+03	24200.00
ED5862	2017-08-15 02:03:00+03	62900.00
ED58C2	2017-08-10 15:58:00+03	369000.00
ED58CE	2017-08-06 05:01:00+03	21200.00
ED58D5	2017-08-05 01:28:00+03	33200.00
ED58E1	2017-08-04 05:08:00+03	28000.00
ED5984	2017-08-01 09:39:00+03	265700.00
ED5A6E	2017-07-17 15:55:00+03	53400.00
ED5AAC	2017-07-08 16:33:00+03	88700.00
ED5ABA	2017-08-07 09:32:00+03	36800.00
ED5ABE	2017-08-14 23:41:00+03	49500.00
ED5AE8	2017-07-06 21:14:00+03	75600.00
ED5B07	2017-07-23 04:23:00+03	62800.00
ED5B61	2017-07-01 18:03:00+03	67100.00
ED5B96	2017-08-06 14:23:00+03	16400.00
ED5BA2	2017-07-16 04:11:00+03	10800.00
ED5BFD	2017-07-29 11:12:00+03	136600.00
ED5C48	2017-07-13 00:25:00+03	41600.00
ED5C6D	2017-07-27 15:48:00+03	111700.00
ED5C72	2017-07-29 15:39:00+03	147100.00
ED5CC2	2017-07-24 03:28:00+03	58200.00
ED5CC8	2017-07-15 09:52:00+03	119700.00
ED5CE4	2017-08-06 08:10:00+03	133100.00
ED5D25	2017-08-14 10:44:00+03	6600.00
ED5D34	2017-07-14 15:20:00+03	36800.00
ED5D4D	2017-08-05 04:25:00+03	27900.00
ED5D58	2017-08-09 15:18:00+03	7200.00
ED5DD9	2017-07-16 04:34:00+03	27800.00
ED5DEE	2017-08-13 08:12:00+03	56600.00
ED5EB4	2017-08-08 13:18:00+03	91900.00
ED5ED6	2017-07-31 14:58:00+03	55800.00
ED5F0B	2017-08-02 22:44:00+03	59800.00
ED5F0E	2017-07-19 04:43:00+03	112000.00
ED6006	2017-07-18 12:08:00+03	189200.00
ED6008	2017-07-12 00:07:00+03	59900.00
ED603F	2017-07-21 02:01:00+03	46300.00
ED6065	2017-07-15 06:35:00+03	69900.00
ED6072	2017-08-10 16:50:00+03	62800.00
ED6099	2017-07-12 10:39:00+03	185000.00
ED60A2	2017-08-12 15:40:00+03	152000.00
ED60C9	2017-07-04 03:12:00+03	57600.00
ED6137	2017-07-25 11:13:00+03	37100.00
ED614D	2017-07-02 00:38:00+03	112600.00
ED61B5	2017-07-22 13:06:00+03	23900.00
ED626E	2017-07-09 19:55:00+03	21800.00
ED62D6	2017-07-19 08:31:00+03	40000.00
ED6311	2017-07-04 22:15:00+03	74900.00
ED6354	2017-08-14 22:10:00+03	25600.00
ED6375	2017-07-10 06:08:00+03	68400.00
ED6383	2017-07-11 18:25:00+03	52800.00
ED63A1	2017-08-02 14:27:00+03	165000.00
ED6419	2017-08-09 05:36:00+03	202800.00
ED644E	2017-08-05 13:40:00+03	15400.00
ED6479	2017-07-24 17:40:00+03	100600.00
ED64AA	2017-06-29 10:12:00+03	32800.00
ED64F6	2017-08-03 00:39:00+03	67400.00
ED6514	2017-06-30 13:42:00+03	31400.00
ED6519	2017-07-05 02:55:00+03	12600.00
ED651F	2017-07-14 14:46:00+03	76800.00
ED6533	2017-07-26 11:31:00+03	396500.00
ED65B8	2017-08-12 20:58:00+03	202800.00
ED65D7	2017-07-07 00:51:00+03	155600.00
ED6697	2017-08-06 03:19:00+03	139800.00
ED66C3	2017-07-14 18:25:00+03	27200.00
ED66C6	2017-08-01 14:40:00+03	68800.00
ED66DE	2017-07-13 23:11:00+03	25400.00
ED6743	2017-07-16 19:40:00+03	30200.00
ED6785	2017-07-27 23:06:00+03	34000.00
ED678A	2017-08-06 12:02:00+03	21400.00
ED683F	2017-07-02 13:50:00+03	135300.00
ED6867	2017-08-15 04:18:00+03	38600.00
ED6872	2017-07-05 12:37:00+03	46200.00
ED687C	2017-07-20 02:18:00+03	12600.00
ED6882	2017-08-15 12:39:00+03	36600.00
ED689D	2017-07-10 10:55:00+03	199700.00
ED68B8	2017-07-12 22:44:00+03	12200.00
ED68D3	2017-08-08 14:21:00+03	75300.00
ED68E4	2017-07-24 01:41:00+03	305000.00
ED6939	2017-08-05 03:42:00+03	58000.00
ED693D	2017-08-07 14:38:00+03	27200.00
ED6999	2017-07-09 14:59:00+03	53300.00
ED6AD1	2017-07-08 10:45:00+03	25800.00
ED6AD7	2017-07-11 03:28:00+03	49100.00
ED6AE4	2017-07-11 18:19:00+03	27200.00
ED6B11	2017-08-06 12:02:00+03	106100.00
ED6B1E	2017-08-05 02:51:00+03	72000.00
ED6B20	2017-08-03 03:12:00+03	18600.00
ED6B2B	2017-07-23 19:44:00+03	190500.00
ED6B37	2017-07-19 03:20:00+03	33100.00
ED6B41	2017-07-04 11:36:00+03	56000.00
ED6B63	2017-08-13 11:18:00+03	135200.00
ED6BBB	2017-07-11 13:52:00+03	81800.00
ED6C7B	2017-07-06 19:27:00+03	128800.00
ED6C9D	2017-08-06 04:31:00+03	31400.00
ED6CE3	2017-07-23 15:52:00+03	28000.00
ED6CEF	2017-07-26 08:56:00+03	142300.00
ED6D43	2017-08-07 10:49:00+03	40600.00
ED6D57	2017-07-19 22:18:00+03	65900.00
ED6D61	2017-07-01 12:02:00+03	131600.00
ED6DEC	2017-07-06 05:42:00+03	19600.00
ED6E1B	2017-07-05 17:05:00+03	8000.00
ED6E8D	2017-07-27 20:42:00+03	9800.00
ED6EFD	2017-07-28 01:42:00+03	44800.00
ED6F2D	2017-07-04 23:35:00+03	532700.00
ED6F37	2017-07-14 17:20:00+03	34000.00
ED6FE0	2017-07-15 12:49:00+03	54800.00
ED70E4	2017-07-02 18:48:00+03	40000.00
ED70F4	2017-08-02 10:11:00+03	8000.00
ED7118	2017-07-02 04:56:00+03	6000.00
ED7164	2017-07-13 00:51:00+03	31300.00
ED71F5	2017-08-15 11:16:00+03	26800.00
ED71FC	2017-07-28 16:57:00+03	172600.00
ED7214	2017-07-28 06:06:00+03	57500.00
ED721D	2017-08-06 07:28:00+03	27200.00
ED7233	2017-07-22 08:30:00+03	119500.00
ED725F	2017-08-08 01:16:00+03	61800.00
ED728D	2017-07-20 18:22:00+03	28800.00
ED730A	2017-07-20 04:57:00+03	89700.00
ED732B	2017-07-28 23:32:00+03	31800.00
ED735C	2017-07-08 19:09:00+03	99200.00
ED738B	2017-07-17 06:41:00+03	172100.00
ED739D	2017-07-22 23:56:00+03	20600.00
ED73E2	2017-07-14 16:29:00+03	65400.00
ED7403	2017-07-23 09:33:00+03	101200.00
ED7413	2017-08-12 18:50:00+03	14300.00
ED7447	2017-07-29 08:43:00+03	45200.00
ED7488	2017-08-09 00:24:00+03	99300.00
ED74E5	2017-07-29 03:54:00+03	48400.00
ED751E	2017-07-27 02:25:00+03	164400.00
ED753E	2017-07-05 09:27:00+03	26000.00
ED7572	2017-08-13 15:28:00+03	68800.00
ED7582	2017-07-09 23:55:00+03	226200.00
ED75FD	2017-08-11 01:29:00+03	40800.00
ED763A	2017-08-01 11:51:00+03	79500.00
ED76DD	2017-08-03 16:44:00+03	72600.00
ED770C	2017-07-10 04:28:00+03	50000.00
ED7774	2017-07-25 11:35:00+03	59800.00
ED7790	2017-07-04 17:20:00+03	75600.00
ED7795	2017-07-11 18:42:00+03	57800.00
ED77B3	2017-07-03 19:45:00+03	24800.00
ED77B6	2017-07-21 17:04:00+03	112000.00
ED77FD	2017-07-20 01:03:00+03	73000.00
ED7801	2017-07-31 05:35:00+03	77000.00
ED7802	2017-07-17 00:46:00+03	54800.00
ED7817	2017-07-18 22:05:00+03	136000.00
ED78B0	2017-07-31 05:50:00+03	64400.00
ED78F6	2017-07-30 17:40:00+03	369000.00
ED78FA	2017-08-14 04:28:00+03	39800.00
ED7942	2017-07-03 19:14:00+03	157400.00
ED798C	2017-07-23 14:22:00+03	30200.00
ED79CF	2017-07-09 11:31:00+03	25200.00
ED7A01	2017-07-13 01:01:00+03	100300.00
ED7A13	2017-08-14 22:13:00+03	32400.00
ED7A82	2017-08-05 04:44:00+03	42800.00
ED7AAD	2017-07-12 09:10:00+03	12000.00
ED7AC9	2017-08-07 18:07:00+03	123000.00
ED7B5F	2017-07-17 00:43:00+03	11800.00
ED7B6C	2017-07-05 11:03:00+03	68100.00
ED7C4F	2017-07-15 14:30:00+03	23400.00
ED7C7F	2017-07-11 11:25:00+03	25200.00
ED7D0D	2017-08-10 00:29:00+03	206400.00
ED7D29	2017-07-30 20:04:00+03	102100.00
ED7D32	2017-07-13 19:56:00+03	94700.00
ED7D62	2017-06-30 07:32:00+03	92800.00
ED7EBA	2017-08-02 20:53:00+03	100600.00
ED7EBC	2017-07-06 08:30:00+03	43600.00
ED7F0F	2017-07-11 19:45:00+03	178200.00
ED7F36	2017-08-02 19:50:00+03	55800.00
ED7F77	2017-08-06 13:45:00+03	13000.00
ED7FC7	2017-08-15 08:06:00+03	14400.00
ED80A2	2017-07-18 14:11:00+03	58600.00
ED80CC	2017-07-22 05:14:00+03	119800.00
ED8103	2017-07-03 20:06:00+03	89600.00
ED810E	2017-08-14 21:16:00+03	31200.00
ED81BD	2017-08-07 05:34:00+03	202700.00
ED81E4	2017-07-15 11:47:00+03	23600.00
ED81F5	2017-07-12 11:06:00+03	163500.00
ED8276	2017-08-08 00:15:00+03	90800.00
ED8286	2017-07-16 19:57:00+03	14000.00
ED82AB	2017-08-07 19:47:00+03	56000.00
ED82CD	2017-07-05 06:27:00+03	21600.00
ED82E6	2017-07-15 18:25:00+03	37900.00
ED82EB	2017-07-11 04:09:00+03	196100.00
ED82F0	2017-08-05 13:20:00+03	81700.00
ED830A	2017-08-14 09:18:00+03	12000.00
ED830B	2017-08-13 17:44:00+03	12400.00
ED8323	2017-07-03 22:03:00+03	98600.00
ED8324	2017-07-31 03:26:00+03	86300.00
ED8358	2017-07-08 11:50:00+03	47400.00
ED8378	2017-07-15 14:26:00+03	45000.00
ED845A	2017-08-10 07:28:00+03	54000.00
ED847A	2017-07-23 17:22:00+03	158000.00
ED851F	2017-07-20 22:50:00+03	46000.00
ED854E	2017-07-22 12:57:00+03	28000.00
ED8556	2017-07-07 10:09:00+03	36800.00
ED8561	2017-08-15 17:17:00+03	149500.00
ED85BE	2017-08-07 14:23:00+03	58700.00
ED85F2	2017-08-07 15:33:00+03	19600.00
ED860C	2017-08-11 10:09:00+03	26000.00
ED8661	2017-07-09 18:16:00+03	73600.00
ED8669	2017-07-24 05:52:00+03	48800.00
ED8685	2017-08-05 13:38:00+03	14800.00
ED869D	2017-07-10 01:55:00+03	25700.00
ED86A7	2017-07-02 12:57:00+03	36400.00
ED86B9	2017-08-11 05:43:00+03	6300.00
ED8780	2017-08-13 11:44:00+03	260300.00
ED8790	2017-07-27 02:33:00+03	64800.00
ED87F4	2017-07-17 04:48:00+03	75700.00
ED8828	2017-07-07 21:14:00+03	113600.00
ED884A	2017-07-31 21:11:00+03	185300.00
ED88B9	2017-08-02 20:35:00+03	103200.00
ED88BC	2017-08-13 12:38:00+03	37900.00
ED8909	2017-07-03 11:35:00+03	98300.00
ED8950	2017-07-03 19:11:00+03	39200.00
ED89C9	2017-07-30 00:41:00+03	19600.00
ED8A6A	2017-07-12 09:47:00+03	36200.00
ED8A8C	2017-08-05 00:12:00+03	35400.00
ED8AA7	2017-07-01 08:55:00+03	44800.00
ED8AB2	2017-07-31 04:22:00+03	18800.00
ED8ACB	2017-08-13 08:04:00+03	30800.00
ED8ACC	2017-07-15 03:11:00+03	316600.00
ED8AF9	2017-07-27 17:33:00+03	35200.00
ED8B2B	2017-07-12 13:20:00+03	88600.00
ED8B36	2017-07-09 12:20:00+03	340500.00
ED8B49	2017-07-12 16:18:00+03	22000.00
ED8B61	2017-07-18 08:29:00+03	26800.00
ED8B68	2017-08-14 08:41:00+03	8200.00
ED8B6C	2017-07-20 08:47:00+03	57700.00
ED8BBA	2017-07-19 12:15:00+03	24400.00
ED8C5C	2017-07-11 07:02:00+03	18800.00
ED8C78	2017-08-10 06:53:00+03	39200.00
ED8C7E	2017-08-04 19:18:00+03	47400.00
ED8C9B	2017-07-09 01:57:00+03	191400.00
ED8D04	2017-08-04 01:38:00+03	23200.00
ED8D17	2017-08-07 12:07:00+03	32800.00
ED8D5C	2017-08-08 03:22:00+03	71300.00
ED8DA2	2017-08-09 22:35:00+03	50000.00
ED8DC8	2017-07-03 21:06:00+03	8000.00
ED8DE4	2017-07-13 13:07:00+03	249100.00
ED8E01	2017-07-04 07:35:00+03	199600.00
ED8E18	2017-08-08 23:03:00+03	57500.00
ED8E63	2017-07-02 17:47:00+03	60400.00
ED8E75	2017-08-04 21:05:00+03	53500.00
ED8EFA	2017-08-11 10:35:00+03	15900.00
ED8F41	2017-08-01 06:46:00+03	380200.00
ED8F6A	2017-07-15 11:53:00+03	54800.00
ED8F6B	2017-07-28 02:24:00+03	258400.00
ED8F71	2017-07-25 06:24:00+03	98400.00
ED8FBD	2017-07-28 14:05:00+03	27000.00
ED9002	2017-08-10 09:31:00+03	40800.00
ED905B	2017-07-31 18:05:00+03	70600.00
ED9104	2017-07-17 22:32:00+03	184200.00
ED911B	2017-07-17 10:39:00+03	178800.00
ED91A4	2017-08-09 22:13:00+03	48100.00
ED91C0	2017-07-30 04:17:00+03	40800.00
ED9222	2017-08-02 07:53:00+03	7800.00
ED922A	2017-07-05 22:30:00+03	123400.00
ED923B	2017-08-15 12:51:00+03	168700.00
ED9275	2017-08-08 14:30:00+03	22200.00
ED92B9	2017-07-10 04:06:00+03	105600.00
ED92C1	2017-08-04 09:48:00+03	101200.00
ED92D6	2017-07-21 07:11:00+03	56600.00
ED93B0	2017-06-30 15:28:00+03	115600.00
ED93D1	2017-07-01 19:25:00+03	46000.00
ED93FB	2017-07-12 21:49:00+03	140900.00
ED940E	2017-08-11 04:13:00+03	88500.00
ED9415	2017-07-13 06:05:00+03	133200.00
ED946F	2017-07-14 08:30:00+03	25600.00
ED949F	2017-08-12 12:51:00+03	266400.00
ED94BB	2017-08-01 19:53:00+03	36200.00
ED94EA	2017-08-11 05:09:00+03	32700.00
ED9541	2017-08-15 00:24:00+03	84900.00
ED95FA	2017-07-06 05:00:00+03	57600.00
ED9651	2017-08-14 02:18:00+03	19600.00
ED9694	2017-08-11 00:48:00+03	13600.00
ED96E6	2017-07-31 05:51:00+03	58400.00
ED970E	2017-08-07 12:30:00+03	86600.00
ED9742	2017-07-12 20:07:00+03	19500.00
ED9747	2017-06-30 14:54:00+03	58600.00
ED974E	2017-07-22 06:03:00+03	42800.00
ED97B0	2017-08-11 19:06:00+03	28800.00
ED97BE	2017-06-27 11:53:00+03	75300.00
ED97CE	2017-07-18 13:43:00+03	40600.00
ED983F	2017-07-12 03:32:00+03	24400.00
ED989A	2017-07-07 02:07:00+03	134000.00
ED98AA	2017-08-12 14:43:00+03	57500.00
ED98C1	2017-07-09 08:56:00+03	93000.00
ED994D	2017-07-25 05:34:00+03	114300.00
ED9953	2017-07-28 17:29:00+03	37900.00
ED9974	2017-08-13 01:03:00+03	6000.00
ED99D2	2017-07-28 02:19:00+03	24200.00
ED99FB	2017-07-25 07:25:00+03	277800.00
ED9B38	2017-07-09 11:16:00+03	26700.00
ED9B88	2017-07-14 23:05:00+03	243300.00
ED9BDB	2017-07-25 13:30:00+03	47700.00
ED9C81	2017-08-07 07:00:00+03	399600.00
ED9C9F	2017-08-08 11:35:00+03	30000.00
ED9CB3	2017-07-27 11:55:00+03	25000.00
ED9CB8	2017-08-04 06:05:00+03	46200.00
ED9D18	2017-08-01 01:29:00+03	62800.00
ED9D4A	2017-08-01 16:51:00+03	38500.00
ED9E2A	2017-07-05 20:43:00+03	94000.00
ED9E64	2017-08-02 15:47:00+03	67200.00
ED9E84	2017-07-18 07:03:00+03	270800.00
ED9F35	2017-07-13 02:45:00+03	339900.00
ED9F98	2017-07-08 17:08:00+03	19600.00
ED9FA9	2017-07-03 23:44:00+03	46000.00
EDA038	2017-08-13 01:34:00+03	6000.00
EDA081	2017-08-02 15:43:00+03	226200.00
EDA0B7	2017-07-28 22:32:00+03	43700.00
EDA0BA	2017-07-30 04:05:00+03	67900.00
EDA0E6	2017-07-08 02:49:00+03	24400.00
EDA10A	2017-07-20 09:03:00+03	26000.00
EDA1A7	2017-07-13 10:30:00+03	64700.00
EDA1C2	2017-08-04 22:05:00+03	111600.00
EDA1F3	2017-07-25 04:19:00+03	28000.00
EDA231	2017-07-20 16:57:00+03	91600.00
EDA2A5	2017-07-14 02:00:00+03	24800.00
EDA2DE	2017-07-31 12:21:00+03	6700.00
EDA2F9	2017-07-29 15:06:00+03	228500.00
EDA33D	2017-08-15 02:53:00+03	40100.00
EDA3DD	2017-07-07 16:16:00+03	17600.00
EDA3F9	2017-07-14 12:01:00+03	158000.00
EDA40F	2017-08-13 19:00:00+03	135200.00
EDA425	2017-08-06 11:31:00+03	19600.00
EDA526	2017-08-12 09:03:00+03	12600.00
EDA55D	2017-08-05 13:21:00+03	8400.00
EDA5E1	2017-07-13 13:14:00+03	90700.00
EDA629	2017-08-07 06:01:00+03	23200.00
EDA686	2017-07-12 20:45:00+03	174400.00
EDA6B9	2017-08-11 15:20:00+03	27400.00
EDA6F0	2017-07-19 23:24:00+03	57600.00
EDA70F	2017-07-21 15:18:00+03	177200.00
EDA713	2017-08-07 08:24:00+03	22400.00
EDA722	2017-07-02 11:44:00+03	38200.00
EDA75B	2017-07-18 11:02:00+03	46400.00
EDA77E	2017-07-30 04:30:00+03	50600.00
EDA7F6	2017-07-07 15:25:00+03	83700.00
EDA85A	2017-07-16 02:45:00+03	313800.00
EDA85C	2017-07-30 22:21:00+03	43200.00
EDA87B	2017-08-03 09:48:00+03	56900.00
EDA8DE	2017-07-15 14:26:00+03	136600.00
EDA8FA	2017-08-05 22:49:00+03	69500.00
EDA905	2017-07-05 03:58:00+03	273600.00
EDA909	2017-08-06 12:46:00+03	46000.00
EDA957	2017-07-09 10:33:00+03	57700.00
EDA960	2017-08-13 08:35:00+03	273400.00
EDA962	2017-07-25 16:43:00+03	66600.00
EDA99B	2017-07-19 01:14:00+03	66600.00
EDA9C7	2017-07-14 00:42:00+03	25400.00
EDA9C9	2017-06-28 21:14:00+03	11000.00
EDAA78	2017-07-10 05:17:00+03	22100.00
EDAA7D	2017-08-06 09:17:00+03	58200.00
EDAADB	2017-08-13 02:30:00+03	250800.00
EDAAFA	2017-08-11 20:23:00+03	49100.00
EDAB00	2017-07-17 21:22:00+03	56900.00
EDAB08	2017-08-11 08:05:00+03	67600.00
EDAB45	2017-07-21 00:45:00+03	99200.00
EDAB57	2017-07-20 00:56:00+03	33600.00
EDAB92	2017-07-02 00:35:00+03	49600.00
EDABAA	2017-07-23 09:47:00+03	44800.00
EDABB5	2017-07-19 18:49:00+03	36200.00
EDAC38	2017-08-13 17:26:00+03	21200.00
EDAC51	2017-07-31 23:40:00+03	26000.00
EDACC4	2017-07-11 03:25:00+03	106400.00
EDACE5	2017-07-03 07:31:00+03	126200.00
EDACF1	2017-08-05 17:59:00+03	135600.00
EDAD15	2017-08-15 15:20:00+03	33100.00
EDAE09	2017-07-19 05:34:00+03	27900.00
EDAE32	2017-07-18 05:54:00+03	133100.00
EDAE33	2017-07-28 11:12:00+03	106100.00
EDB001	2017-08-07 12:17:00+03	36400.00
EDB01E	2017-07-02 13:54:00+03	66600.00
EDB0BB	2017-07-27 10:20:00+03	261500.00
EDB0E2	2017-07-27 08:45:00+03	28000.00
EDB10B	2017-07-10 14:35:00+03	60300.00
EDB1C0	2017-07-14 23:11:00+03	22000.00
EDB225	2017-07-15 01:57:00+03	7400.00
EDB24D	2017-08-07 14:18:00+03	40000.00
EDB261	2017-07-13 07:15:00+03	53600.00
EDB277	2017-08-14 12:48:00+03	53600.00
EDB2CE	2017-08-07 06:54:00+03	93900.00
EDB2D0	2017-08-13 20:41:00+03	62900.00
EDB301	2017-08-06 08:06:00+03	369000.00
EDB38D	2017-07-17 14:51:00+03	79900.00
EDB390	2017-07-24 00:54:00+03	88500.00
EDB397	2017-07-22 05:32:00+03	258000.00
EDB3B1	2017-07-11 20:32:00+03	272400.00
EDB3E8	2017-08-14 07:10:00+03	27200.00
EDB43D	2017-07-24 16:41:00+03	46400.00
EDB488	2017-08-03 21:11:00+03	54400.00
EDB4E4	2017-08-07 15:53:00+03	169900.00
EDB58E	2017-07-13 16:47:00+03	85000.00
EDB5A1	2017-07-23 13:24:00+03	46400.00
EDB65C	2017-07-25 21:59:00+03	288600.00
EDB6FA	2017-07-15 19:40:00+03	17000.00
EDB717	2017-07-19 18:07:00+03	35800.00
EDB73B	2017-08-09 09:19:00+03	270800.00
EDB78D	2017-08-15 03:59:00+03	28300.00
EDB7DE	2017-07-30 23:05:00+03	82800.00
EDB813	2017-07-11 03:21:00+03	45400.00
EDB816	2017-07-04 03:02:00+03	28800.00
EDB83E	2017-07-12 12:46:00+03	167400.00
EDB842	2017-08-07 22:20:00+03	26800.00
EDB8A7	2017-07-12 16:37:00+03	46000.00
EDB93D	2017-08-12 14:35:00+03	26300.00
EDB95A	2017-07-13 12:44:00+03	24400.00
EDB9A9	2017-08-12 02:59:00+03	149000.00
EDB9BB	2017-07-25 01:27:00+03	48100.00
EDB9D1	2017-07-14 16:56:00+03	44000.00
EDBA07	2017-08-07 10:39:00+03	59800.00
EDBA4B	2017-07-29 11:17:00+03	129200.00
EDBA77	2017-08-08 11:04:00+03	92300.00
EDBA78	2017-08-08 18:40:00+03	110300.00
EDBB3E	2017-08-09 21:17:00+03	85600.00
EDBB4A	2017-07-15 17:00:00+03	27200.00
EDBB71	2017-07-27 11:37:00+03	73200.00
EDBB7D	2017-07-22 06:32:00+03	28800.00
EDBBFB	2017-07-19 23:24:00+03	57100.00
EDBC3F	2017-08-13 01:33:00+03	30200.00
EDBC89	2017-07-03 16:16:00+03	46000.00
EDBC8A	2017-07-23 12:52:00+03	99200.00
EDBCA0	2017-07-09 07:59:00+03	153200.00
EDBCAA	2017-07-01 01:29:00+03	80000.00
EDBCE7	2017-08-11 07:18:00+03	46300.00
EDBD0C	2017-07-15 04:24:00+03	16400.00
EDBE41	2017-07-22 02:02:00+03	113800.00
EDBE43	2017-08-05 06:51:00+03	37600.00
EDBE56	2017-08-08 12:40:00+03	301800.00
EDBE76	2017-07-31 13:08:00+03	36600.00
EDBEE0	2017-07-27 16:01:00+03	122700.00
EDBF3A	2017-07-04 19:25:00+03	94300.00
EDBF48	2017-07-26 16:26:00+03	58600.00
EDBFCA	2017-07-17 18:40:00+03	28000.00
EDC125	2017-07-24 04:56:00+03	136000.00
EDC25C	2017-07-30 15:45:00+03	120100.00
EDC2A5	2017-08-07 17:39:00+03	56000.00
EDC2B6	2017-07-16 12:09:00+03	131600.00
EDC2C9	2017-07-11 10:18:00+03	36200.00
EDC2D3	2017-07-03 16:34:00+03	80900.00
EDC3A1	2017-08-15 08:45:00+03	84500.00
EDC451	2017-07-09 23:14:00+03	43200.00
EDC452	2017-07-22 07:57:00+03	26000.00
EDC458	2017-08-01 02:07:00+03	48700.00
EDC475	2017-08-11 19:14:00+03	36200.00
EDC492	2017-07-18 11:28:00+03	48700.00
EDC58B	2017-07-28 20:51:00+03	15100.00
EDC6A3	2017-07-11 23:25:00+03	130900.00
EDC7A9	2017-07-13 08:32:00+03	37100.00
EDC7DE	2017-07-23 06:44:00+03	70800.00
EDC7E8	2017-08-13 07:51:00+03	38800.00
EDC815	2017-08-13 08:27:00+03	70700.00
EDC82C	2017-07-30 12:52:00+03	6800.00
EDC830	2017-07-11 11:33:00+03	44800.00
EDC8BD	2017-08-06 00:02:00+03	266400.00
EDC8CF	2017-07-27 18:02:00+03	38500.00
EDC967	2017-07-07 22:53:00+03	117200.00
EDC9B7	2017-08-13 13:39:00+03	143100.00
EDC9FE	2017-08-09 11:34:00+03	272300.00
EDCA10	2017-07-26 15:28:00+03	14400.00
EDCA2F	2017-06-29 08:55:00+03	92600.00
EDCA84	2017-07-14 09:01:00+03	56000.00
EDCB06	2017-07-17 23:54:00+03	32800.00
EDCB70	2017-08-02 23:58:00+03	46000.00
EDCB75	2017-07-29 23:48:00+03	30400.00
EDCBA6	2017-08-10 00:34:00+03	61300.00
EDCBC9	2017-08-02 02:30:00+03	6300.00
EDCC66	2017-07-10 04:17:00+03	187800.00
EDCC87	2017-08-04 15:51:00+03	81600.00
EDCD1D	2017-07-25 19:59:00+03	110500.00
EDCD42	2017-07-20 01:57:00+03	55100.00
EDCD57	2017-07-21 18:53:00+03	79600.00
EDCD5B	2017-07-23 08:05:00+03	39200.00
EDCDBB	2017-07-25 11:22:00+03	83700.00
EDCDE3	2017-08-01 18:49:00+03	78100.00
EDCDFA	2017-08-13 09:28:00+03	6000.00
EDCE0A	2017-07-26 17:31:00+03	101200.00
EDCE61	2017-08-13 14:05:00+03	97900.00
EDCE9F	2017-07-21 03:20:00+03	103400.00
EDCF01	2017-08-13 16:19:00+03	32700.00
EDCF0F	2017-07-17 17:32:00+03	36100.00
EDCF11	2017-08-09 15:21:00+03	68800.00
EDCF53	2017-07-15 21:42:00+03	92100.00
EDCF62	2017-08-09 23:50:00+03	105600.00
EDCFDD	2017-07-29 05:43:00+03	304800.00
EDD01C	2017-07-18 02:28:00+03	298000.00
EDD083	2017-07-24 10:09:00+03	114500.00
EDD0EA	2017-07-10 10:03:00+03	73800.00
EDD156	2017-08-02 05:38:00+03	28800.00
EDD1BE	2017-07-27 20:21:00+03	86800.00
EDD1C0	2017-07-15 15:29:00+03	36400.00
EDD1F5	2017-07-03 13:18:00+03	13400.00
EDD221	2017-07-29 18:13:00+03	214900.00
EDD28D	2017-07-18 08:58:00+03	249300.00
EDD2CD	2017-06-28 15:31:00+03	44000.00
EDD2E0	2017-07-18 07:46:00+03	81300.00
EDD35E	2017-07-16 02:40:00+03	271200.00
EDD384	2017-07-20 16:20:00+03	88600.00
EDD3BB	2017-08-10 08:33:00+03	26700.00
EDD3D8	2017-07-05 22:49:00+03	182300.00
EDD3D9	2017-08-01 11:21:00+03	69500.00
EDD407	2017-08-08 11:19:00+03	79800.00
EDD409	2017-07-04 05:53:00+03	28800.00
EDD456	2017-06-30 13:29:00+03	31600.00
EDD47A	2017-08-14 09:41:00+03	57600.00
EDD4C5	2017-07-27 08:18:00+03	66600.00
EDD500	2017-08-01 23:47:00+03	155600.00
EDD51B	2017-07-05 16:47:00+03	189100.00
EDD527	2017-07-19 15:11:00+03	243700.00
EDD58A	2017-06-29 02:56:00+03	140900.00
EDD58F	2017-07-31 12:02:00+03	433100.00
EDD64C	2017-07-09 10:27:00+03	56900.00
EDD662	2017-07-19 12:38:00+03	48800.00
EDD687	2017-07-14 06:35:00+03	68400.00
EDD6D6	2017-07-29 23:50:00+03	205500.00
EDD789	2017-07-23 21:47:00+03	59800.00
EDD7D4	2017-08-09 04:30:00+03	229900.00
EDD828	2017-08-01 16:11:00+03	28800.00
EDD849	2017-08-07 01:08:00+03	56200.00
EDD84C	2017-07-01 12:35:00+03	178800.00
EDD874	2017-08-11 13:36:00+03	12600.00
EDD8CE	2017-07-26 05:37:00+03	246000.00
EDD8E8	2017-08-01 12:15:00+03	59800.00
EDD998	2017-07-08 03:37:00+03	26000.00
EDD9CF	2017-07-27 02:45:00+03	15900.00
EDDA4D	2017-07-28 06:33:00+03	89600.00
EDDA88	2017-07-11 01:54:00+03	134400.00
EDDAA9	2017-08-14 22:49:00+03	129000.00
EDDABE	2017-07-16 22:03:00+03	131600.00
EDDAC0	2017-07-29 05:13:00+03	16400.00
EDDAC2	2017-08-06 09:30:00+03	123900.00
EDDB18	2017-07-13 22:01:00+03	46300.00
EDDB81	2017-08-13 10:54:00+03	55600.00
EDDB8D	2017-07-14 06:30:00+03	12600.00
EDDBB3	2017-07-21 13:24:00+03	266400.00
EDDBFC	2017-08-06 04:31:00+03	134700.00
EDDC06	2017-07-13 06:12:00+03	21400.00
EDDC8F	2017-08-11 13:10:00+03	31200.00
EDDC93	2017-07-23 17:47:00+03	255600.00
EDDD21	2017-07-10 17:51:00+03	189200.00
EDDD86	2017-07-07 13:29:00+03	120200.00
EDDD9D	2017-07-16 03:45:00+03	39300.00
EDDDBE	2017-08-07 16:32:00+03	43200.00
EDDDC2	2017-07-07 14:11:00+03	26000.00
EDDDE9	2017-08-08 21:28:00+03	260300.00
EDDE8D	2017-07-02 10:51:00+03	52300.00
EDDE9F	2017-07-15 10:55:00+03	66600.00
EDDEEA	2017-08-15 08:52:00+03	63400.00
EDDF27	2017-08-08 10:45:00+03	43700.00
EDDF3F	2017-07-29 10:41:00+03	135200.00
EDDFD9	2017-08-11 23:27:00+03	102100.00
EDE04A	2017-07-10 07:50:00+03	73500.00
EDE062	2017-08-03 09:50:00+03	110700.00
EDE0FA	2017-07-06 16:03:00+03	28800.00
EDE125	2017-07-23 23:54:00+03	16400.00
EDE184	2017-07-11 07:23:00+03	44800.00
EDE1B9	2017-07-27 20:39:00+03	25200.00
EDE1DE	2017-07-04 12:53:00+03	50200.00
EDE222	2017-07-04 16:32:00+03	34000.00
EDE229	2017-07-10 18:07:00+03	123000.00
EDE238	2017-06-28 02:55:00+03	24400.00
EDE255	2017-07-09 01:58:00+03	58900.00
EDE266	2017-07-26 09:49:00+03	14800.00
EDE292	2017-07-25 16:23:00+03	125200.00
EDE2CC	2017-08-05 22:41:00+03	49400.00
EDE30C	2017-07-22 19:14:00+03	91200.00
EDE34E	2017-07-24 10:38:00+03	13000.00
EDE3D2	2017-07-13 22:49:00+03	13400.00
EDE402	2017-07-24 14:38:00+03	61900.00
EDE418	2017-07-02 09:07:00+03	65900.00
EDE45D	2017-07-17 13:12:00+03	46300.00
EDE4A1	2017-07-17 01:54:00+03	59300.00
EDE4E8	2017-07-07 12:35:00+03	37100.00
EDE4FA	2017-07-27 08:49:00+03	31400.00
EDE51A	2017-07-18 01:14:00+03	114800.00
EDE55F	2017-08-03 11:07:00+03	23900.00
EDE574	2017-07-14 07:47:00+03	69500.00
EDE5D1	2017-07-30 05:21:00+03	131600.00
EDE5E5	2017-08-10 01:52:00+03	28800.00
EDE5E6	2017-07-17 20:31:00+03	43100.00
EDE615	2017-07-24 15:46:00+03	28300.00
EDE624	2017-07-31 15:54:00+03	30900.00
EDE63A	2017-07-11 01:09:00+03	15400.00
EDE683	2017-08-08 12:23:00+03	21400.00
EDE68D	2017-08-13 16:21:00+03	133200.00
EDE6D9	2017-07-05 09:31:00+03	32900.00
EDE6DD	2017-07-05 02:26:00+03	97900.00
EDE6DE	2017-07-05 01:53:00+03	65500.00
EDE6E1	2017-07-27 12:33:00+03	28000.00
EDE711	2017-07-10 19:25:00+03	46000.00
EDE716	2017-07-09 09:59:00+03	187600.00
EDE727	2017-07-28 00:06:00+03	22000.00
EDE730	2017-07-09 10:13:00+03	43400.00
EDE758	2017-07-31 15:31:00+03	56600.00
EDE7A7	2017-06-27 04:40:00+03	73300.00
EDE7AD	2017-08-14 08:26:00+03	133200.00
EDE877	2017-07-11 16:06:00+03	113200.00
EDE88C	2017-08-04 02:13:00+03	55600.00
EDE8D5	2017-07-11 03:25:00+03	133100.00
EDE8EE	2017-07-29 07:18:00+03	111600.00
EDE950	2017-08-11 12:52:00+03	28000.00
EDE996	2017-07-29 19:31:00+03	65500.00
EDE9DB	2017-07-18 09:58:00+03	28800.00
EDEA1D	2017-08-08 01:52:00+03	111600.00
EDEA3E	2017-07-31 12:36:00+03	44000.00
EDEA8A	2017-07-22 21:44:00+03	36600.00
EDEAB9	2017-07-23 14:44:00+03	26400.00
EDEB10	2017-07-12 08:53:00+03	24600.00
EDEB31	2017-07-23 01:04:00+03	75300.00
EDEB48	2017-07-15 22:34:00+03	92800.00
EDEB6B	2017-08-01 00:55:00+03	56000.00
EDEB77	2017-07-29 01:18:00+03	27200.00
EDEB90	2017-07-25 05:58:00+03	23200.00
EDEBC0	2017-08-01 23:01:00+03	22100.00
EDEC22	2017-06-30 18:47:00+03	24600.00
EDEC85	2017-07-06 03:07:00+03	23600.00
EDEC86	2017-07-05 22:53:00+03	26000.00
EDECBE	2017-08-02 03:26:00+03	10800.00
EDECEC	2017-07-01 13:25:00+03	89600.00
EDED42	2017-07-08 18:18:00+03	42800.00
EDEDAF	2017-07-08 22:50:00+03	24500.00
EDEDB1	2017-07-27 16:22:00+03	115900.00
EDEDE6	2017-07-22 10:18:00+03	283100.00
EDEDF0	2017-08-01 12:00:00+03	123000.00
EDEE53	2017-07-10 13:15:00+03	28000.00
EDEE76	2017-07-01 00:31:00+03	289800.00
EDEE9D	2017-07-24 15:07:00+03	79300.00
EDEEAB	2017-07-05 18:10:00+03	54500.00
EDEEB4	2017-07-16 22:58:00+03	46800.00
EDEF28	2017-08-15 12:06:00+03	68800.00
EDEF4A	2017-07-22 11:21:00+03	23200.00
EDEFD1	2017-08-06 04:34:00+03	223200.00
EDF058	2017-07-14 23:48:00+03	207000.00
EDF05C	2017-07-12 13:15:00+03	28800.00
EDF062	2017-07-24 20:46:00+03	193600.00
EDF09E	2017-08-12 03:31:00+03	74900.00
EDF0C7	2017-07-09 18:26:00+03	15000.00
EDF10E	2017-07-08 18:32:00+03	129700.00
EDF164	2017-08-11 15:16:00+03	203400.00
EDF192	2017-07-11 05:49:00+03	41800.00
EDF1AE	2017-07-28 11:33:00+03	16400.00
EDF1BF	2017-07-14 01:41:00+03	67400.00
EDF1FD	2017-07-11 01:24:00+03	30200.00
EDF242	2017-07-07 16:56:00+03	81300.00
EDF27E	2017-08-03 09:41:00+03	111600.00
EDF2F0	2017-08-13 23:23:00+03	3400.00
EDF300	2017-07-01 15:40:00+03	97900.00
EDF358	2017-07-31 04:00:00+03	290400.00
EDF3E4	2017-08-12 13:03:00+03	136600.00
EDF3F7	2017-07-30 18:23:00+03	133100.00
EDF49D	2017-07-24 01:10:00+03	113600.00
EDF502	2017-08-07 15:43:00+03	43600.00
EDF596	2017-08-02 16:31:00+03	21400.00
EDF5D3	2017-06-28 07:42:00+03	118900.00
EDF5EA	2017-07-18 19:42:00+03	87200.00
EDF5EC	2017-08-12 05:45:00+03	13600.00
EDF648	2017-07-28 08:24:00+03	143600.00
EDF746	2017-08-09 19:10:00+03	40800.00
EDF74F	2017-07-21 01:03:00+03	77200.00
EDF79D	2017-07-08 06:27:00+03	6600.00
EDF7AB	2017-07-07 14:15:00+03	31400.00
EDF830	2017-07-26 11:37:00+03	454500.00
EDF84A	2017-07-12 19:55:00+03	48400.00
EDF8C9	2017-07-19 19:12:00+03	203100.00
EDF8E4	2017-07-30 06:51:00+03	48800.00
EDF95C	2017-08-06 05:13:00+03	63200.00
EDF969	2017-07-29 00:06:00+03	51600.00
EDF985	2017-07-09 03:28:00+03	60800.00
EDF9C2	2017-07-22 08:35:00+03	39200.00
EDFA3A	2017-07-25 04:15:00+03	86800.00
EDFA55	2017-07-30 11:47:00+03	89200.00
EDFA9B	2017-08-07 08:35:00+03	69700.00
EDFADC	2017-07-20 15:22:00+03	50600.00
EDFB15	2017-07-23 21:52:00+03	21000.00
EDFB55	2017-08-01 22:54:00+03	44800.00
EDFB56	2017-07-10 02:11:00+03	56600.00
EDFB87	2017-07-30 14:46:00+03	6300.00
EDFB9B	2017-07-17 08:27:00+03	103900.00
EDFBA8	2017-08-05 11:34:00+03	131100.00
EDFCBB	2017-08-06 11:58:00+03	14400.00
EDFD14	2017-07-15 17:51:00+03	59800.00
EDFD19	2017-07-08 11:40:00+03	23200.00
EDFD78	2017-07-29 15:40:00+03	62000.00
EDFD9F	2017-07-12 09:26:00+03	122300.00
EDFDC3	2017-07-05 07:10:00+03	72200.00
EDFE04	2017-07-29 20:57:00+03	68400.00
EDFE12	2017-08-12 16:26:00+03	26800.00
EDFEEE	2017-07-24 16:44:00+03	42000.00
EDFEF3	2017-07-19 21:55:00+03	532800.00
EDFFE5	2017-07-23 19:22:00+03	6900.00
EE0006	2017-07-28 22:15:00+03	42800.00
EE0014	2017-08-03 10:08:00+03	43900.00
EE0047	2017-07-05 09:28:00+03	106900.00
EE0097	2017-07-29 12:55:00+03	23200.00
EE00F8	2017-08-15 09:47:00+03	54800.00
EE0117	2017-08-01 12:47:00+03	97700.00
EE012E	2017-07-12 13:41:00+03	34700.00
EE0143	2017-07-29 01:13:00+03	152500.00
EE0166	2017-07-24 02:01:00+03	38400.00
EE0193	2017-07-12 00:59:00+03	20200.00
EE0213	2017-07-12 01:24:00+03	100000.00
EE022D	2017-08-08 09:11:00+03	26800.00
EE0250	2017-08-11 04:22:00+03	15700.00
EE0268	2017-07-27 01:41:00+03	81800.00
EE02B1	2017-08-08 15:58:00+03	146300.00
EE02E7	2017-07-27 06:39:00+03	112000.00
EE0331	2017-07-29 21:21:00+03	181600.00
EE03CA	2017-08-04 00:01:00+03	56000.00
EE0403	2017-07-29 07:44:00+03	6700.00
EE0425	2017-06-30 20:06:00+03	199700.00
EE042E	2017-08-05 05:54:00+03	34000.00
EE042F	2017-08-12 16:58:00+03	199200.00
EE044E	2017-07-04 04:08:00+03	81600.00
EE047B	2017-07-05 00:41:00+03	396300.00
EE04FF	2017-06-30 12:09:00+03	62600.00
EE0502	2017-08-14 01:36:00+03	170800.00
EE0503	2017-07-05 16:14:00+03	28600.00
EE05F3	2017-06-25 09:49:00+03	79600.00
EE060C	2017-07-15 11:47:00+03	48800.00
EE062B	2017-07-10 04:47:00+03	166000.00
EE063B	2017-07-10 04:12:00+03	42800.00
EE0653	2017-07-14 00:50:00+03	22000.00
EE065D	2017-07-14 07:30:00+03	6700.00
EE0662	2017-07-03 03:45:00+03	12000.00
EE0663	2017-08-15 04:27:00+03	193600.00
EE06A7	2017-07-16 08:32:00+03	265200.00
EE0727	2017-07-29 15:13:00+03	62800.00
EE072B	2017-06-26 14:19:00+03	109300.00
EE0754	2017-07-09 11:57:00+03	101200.00
EE0764	2017-07-16 15:32:00+03	99300.00
EE07D2	2017-08-11 12:30:00+03	67100.00
EE07F9	2017-08-02 00:03:00+03	59300.00
EE080E	2017-08-15 10:03:00+03	100800.00
EE0823	2017-07-10 14:10:00+03	119400.00
EE084B	2017-07-24 03:32:00+03	258400.00
EE0869	2017-06-27 02:46:00+03	56100.00
EE0872	2017-07-16 02:25:00+03	67600.00
EE08AE	2017-08-09 19:22:00+03	93600.00
EE08F4	2017-07-16 05:35:00+03	34100.00
EE0901	2017-07-07 04:37:00+03	28000.00
EE092F	2017-08-12 17:38:00+03	12600.00
EE094E	2017-08-04 11:55:00+03	28000.00
EE0955	2017-07-31 16:48:00+03	489100.00
EE09E4	2017-08-08 16:44:00+03	15400.00
EE09F7	2017-07-16 01:28:00+03	28800.00
EE0A0A	2017-08-03 20:45:00+03	133200.00
EE0A30	2017-08-02 08:31:00+03	13400.00
EE0A48	2017-07-10 17:10:00+03	16400.00
EE0ACF	2017-07-17 11:19:00+03	24400.00
EE0ADD	2017-07-25 21:43:00+03	190700.00
EE0B1C	2017-08-11 23:56:00+03	36800.00
EE0B27	2017-08-08 14:49:00+03	232800.00
EE0B37	2017-07-02 09:22:00+03	75600.00
EE0B58	2017-07-15 21:21:00+03	155400.00
EE0B89	2017-07-31 23:50:00+03	27400.00
EE0BB8	2017-07-15 18:03:00+03	97200.00
EE0C14	2017-07-14 23:00:00+03	46300.00
EE0C1E	2017-08-07 20:30:00+03	35200.00
EE0C5F	2017-08-11 00:48:00+03	142300.00
EE0C78	2017-07-23 05:09:00+03	26800.00
EE0C86	2017-07-07 17:08:00+03	123000.00
EE0CC1	2017-07-05 09:11:00+03	81200.00
EE0CD8	2017-08-02 05:43:00+03	399600.00
EE0CE5	2017-07-18 05:55:00+03	24300.00
EE0CEE	2017-07-02 13:34:00+03	25600.00
EE0D60	2017-08-10 11:52:00+03	76600.00
EE0DCA	2017-08-09 23:17:00+03	62900.00
EE0DD2	2017-08-13 02:47:00+03	54600.00
EE0DE4	2017-07-15 03:03:00+03	23200.00
EE0DE9	2017-07-06 17:14:00+03	125400.00
EE0DEC	2017-07-31 20:23:00+03	28000.00
EE0E73	2017-08-12 10:48:00+03	176800.00
EE0E83	2017-08-12 02:21:00+03	133200.00
EE0E86	2017-07-26 19:30:00+03	125000.00
EE0EEE	2017-08-14 23:53:00+03	22400.00
EE0F6A	2017-08-09 22:58:00+03	96400.00
EE0FC2	2017-06-30 17:54:00+03	25800.00
EE101E	2017-08-13 14:05:00+03	13000.00
EE1035	2017-08-07 22:28:00+03	90600.00
EE1061	2017-08-08 04:48:00+03	32100.00
EE11A7	2017-07-21 04:43:00+03	46000.00
EE1268	2017-07-08 10:52:00+03	133100.00
EE1282	2017-07-19 07:09:00+03	65900.00
EE12A2	2017-07-07 21:15:00+03	6800.00
EE12DC	2017-07-24 11:54:00+03	127200.00
EE12E4	2017-08-06 09:29:00+03	31500.00
EE130C	2017-08-09 07:19:00+03	31600.00
EE13B7	2017-08-15 07:40:00+03	48400.00
EE13CF	2017-07-07 01:58:00+03	96100.00
EE1427	2017-07-20 19:02:00+03	74800.00
EE1494	2017-08-05 02:55:00+03	257700.00
EE14C5	2017-07-15 07:48:00+03	59300.00
EE14FE	2017-08-15 03:52:00+03	153300.00
EE154A	2017-07-17 23:16:00+03	51800.00
EE1552	2017-08-09 13:16:00+03	66800.00
EE157D	2017-08-13 08:19:00+03	27200.00
EE158F	2017-07-14 12:29:00+03	84100.00
EE1590	2017-07-31 19:42:00+03	27800.00
EE15E7	2017-08-02 02:25:00+03	55800.00
EE15E8	2017-07-20 09:52:00+03	32900.00
EE1625	2017-07-02 08:07:00+03	27400.00
EE16F2	2017-07-31 20:26:00+03	32800.00
EE173D	2017-08-14 04:59:00+03	153300.00
EE175F	2017-07-10 11:40:00+03	24400.00
EE177E	2017-07-29 17:43:00+03	23200.00
EE1788	2017-07-20 06:38:00+03	82900.00
EE17AB	2017-07-30 21:03:00+03	12600.00
EE17BE	2017-08-11 12:21:00+03	80600.00
EE17ED	2017-07-31 23:19:00+03	161000.00
EE1810	2017-07-25 15:35:00+03	56000.00
EE1859	2017-07-23 22:20:00+03	87800.00
EE1910	2017-07-03 18:09:00+03	11700.00
EE1A57	2017-08-14 09:43:00+03	44800.00
EE1A91	2017-07-15 09:10:00+03	29800.00
EE1AF7	2017-07-30 05:12:00+03	86600.00
EE1AF9	2017-08-10 23:05:00+03	39800.00
EE1AFB	2017-07-20 22:28:00+03	53300.00
EE1B15	2017-07-08 14:21:00+03	147700.00
EE1B59	2017-07-29 21:02:00+03	28000.00
EE1B8A	2017-08-02 17:33:00+03	53300.00
EE1B97	2017-07-11 22:27:00+03	12600.00
EE1C08	2017-07-12 00:05:00+03	12000.00
EE1C39	2017-07-27 02:18:00+03	56000.00
EE1C7B	2017-08-11 19:25:00+03	13400.00
EE1C9D	2017-08-10 23:48:00+03	398300.00
EE1CA3	2017-07-07 02:26:00+03	57100.00
EE1D12	2017-08-07 00:14:00+03	37100.00
EE1D30	2017-07-03 23:38:00+03	21800.00
EE1D6E	2017-07-28 17:08:00+03	27200.00
EE1D6F	2017-07-19 19:59:00+03	266400.00
EE1D79	2017-07-25 18:37:00+03	66600.00
EE1DB7	2017-07-23 19:12:00+03	174600.00
EE1DFC	2017-08-07 17:13:00+03	20200.00
EE1E45	2017-07-16 18:40:00+03	8000.00
EE1E9F	2017-08-10 00:26:00+03	181600.00
EE1EB5	2017-08-14 05:30:00+03	111700.00
EE1EB7	2017-08-01 21:15:00+03	11700.00
EE1F0E	2017-07-10 04:59:00+03	191200.00
EE1F86	2017-07-26 11:57:00+03	51900.00
EE1FE7	2017-08-12 10:38:00+03	6700.00
EE2015	2017-08-02 03:54:00+03	33000.00
EE2056	2017-07-29 19:17:00+03	24200.00
EE2095	2017-08-09 16:08:00+03	30200.00
EE20E8	2017-07-02 12:43:00+03	75100.00
EE210F	2017-07-19 15:40:00+03	40800.00
EE2117	2017-08-10 15:30:00+03	23200.00
EE215F	2017-07-20 00:20:00+03	25600.00
EE220B	2017-07-25 09:26:00+03	24400.00
EE2223	2017-07-03 10:56:00+03	66300.00
EE2281	2017-07-27 22:54:00+03	94800.00
EE2285	2017-07-03 21:11:00+03	135400.00
EE2287	2017-07-13 04:54:00+03	149400.00
EE22BC	2017-07-02 03:35:00+03	46300.00
EE236F	2017-07-17 19:31:00+03	261500.00
EE237A	2017-07-18 23:11:00+03	30000.00
EE239A	2017-07-22 22:55:00+03	31000.00
EE23BC	2017-07-04 10:46:00+03	65500.00
EE241A	2017-07-19 10:34:00+03	269200.00
EE2502	2017-07-23 22:21:00+03	93900.00
EE250B	2017-07-25 03:53:00+03	6800.00
EE25A5	2017-07-12 15:48:00+03	46400.00
EE25B8	2017-07-28 10:46:00+03	29400.00
EE25BB	2017-07-11 17:29:00+03	25400.00
EE25E2	2017-07-13 21:23:00+03	114900.00
EE267B	2017-07-19 01:05:00+03	41500.00
EE284E	2017-07-27 20:28:00+03	95200.00
EE2866	2017-07-16 21:44:00+03	31200.00
EE2869	2017-06-28 04:05:00+03	28000.00
EE286C	2017-07-20 17:03:00+03	34000.00
EE2871	2017-07-16 14:10:00+03	41300.00
EE28AD	2017-07-07 23:45:00+03	31400.00
EE28C7	2017-08-04 06:53:00+03	44800.00
EE290A	2017-07-11 15:42:00+03	67800.00
EE297A	2017-07-07 03:41:00+03	68800.00
EE2A5C	2017-08-01 04:36:00+03	28800.00
EE2A7A	2017-07-27 19:25:00+03	81600.00
EE2C2E	2017-07-09 12:12:00+03	170500.00
EE2C76	2017-07-10 04:12:00+03	24600.00
EE2C96	2017-07-09 19:55:00+03	25000.00
EE2C98	2017-07-26 09:25:00+03	135600.00
EE2CA5	2017-07-23 11:39:00+03	49100.00
EE2CF4	2017-07-13 01:11:00+03	111600.00
EE2D4B	2017-08-03 03:43:00+03	399600.00
EE2DBF	2017-07-01 21:35:00+03	117800.00
EE2E18	2017-07-18 04:20:00+03	42700.00
EE2E20	2017-07-18 17:05:00+03	31400.00
EE2E2F	2017-07-17 13:40:00+03	208100.00
EE2E40	2017-07-28 00:49:00+03	13400.00
EE2F21	2017-08-01 15:59:00+03	35200.00
EE2F5B	2017-07-12 01:27:00+03	46800.00
EE30BB	2017-07-02 23:52:00+03	283000.00
EE30C3	2017-07-26 06:28:00+03	66600.00
EE30FA	2017-08-05 11:24:00+03	10600.00
EE3103	2017-07-10 23:28:00+03	28800.00
EE3117	2017-07-18 23:27:00+03	114400.00
EE314F	2017-06-30 13:54:00+03	198300.00
EE3170	2017-08-08 12:25:00+03	12400.00
EE3186	2017-08-03 23:39:00+03	149600.00
EE318F	2017-07-05 23:32:00+03	185300.00
EE31BB	2017-08-04 14:42:00+03	136200.00
EE3201	2017-07-27 07:59:00+03	69500.00
EE3230	2017-08-09 12:33:00+03	21400.00
EE323B	2017-08-02 05:20:00+03	396500.00
EE3241	2017-07-31 01:52:00+03	108300.00
EE324F	2017-07-25 18:39:00+03	242700.00
EE3256	2017-07-22 12:54:00+03	48100.00
EE325E	2017-08-07 11:46:00+03	55600.00
EE3267	2017-08-13 17:22:00+03	128800.00
EE3310	2017-07-22 21:05:00+03	6700.00
EE3323	2017-07-18 17:26:00+03	23600.00
EE3344	2017-07-24 14:19:00+03	13000.00
EE3389	2017-08-03 20:26:00+03	282600.00
EE33BD	2017-08-01 00:39:00+03	75300.00
EE33C3	2017-07-04 14:46:00+03	40000.00
EE33D4	2017-07-03 18:45:00+03	31400.00
EE33E3	2017-07-01 21:20:00+03	55800.00
EE342D	2017-07-21 14:21:00+03	52000.00
EE344D	2017-07-10 08:02:00+03	139200.00
EE344E	2017-08-12 21:41:00+03	187800.00
EE34AF	2017-08-01 11:29:00+03	179400.00
EE34C6	2017-07-16 18:36:00+03	56200.00
EE3506	2017-08-13 22:52:00+03	85400.00
EE3510	2017-08-14 01:06:00+03	24000.00
EE357B	2017-08-09 22:40:00+03	31700.00
EE3613	2017-07-18 13:43:00+03	67900.00
EE3667	2017-08-01 03:27:00+03	136200.00
EE3670	2017-07-17 14:37:00+03	20200.00
EE36B6	2017-08-05 20:11:00+03	38800.00
EE36DE	2017-07-18 04:05:00+03	81300.00
EE3702	2017-07-29 21:28:00+03	137600.00
EE377F	2017-07-12 06:02:00+03	100600.00
EE3822	2017-08-13 14:57:00+03	40100.00
EE398E	2017-08-05 13:05:00+03	44400.00
EE399F	2017-08-04 08:14:00+03	172100.00
EE3A4C	2017-07-12 19:08:00+03	14400.00
EE3A51	2017-07-14 05:55:00+03	10600.00
EE3A53	2017-07-08 16:23:00+03	195800.00
EE3A68	2017-07-13 15:44:00+03	167400.00
EE3A84	2017-08-15 03:01:00+03	43500.00
EE3A99	2017-07-31 00:17:00+03	21800.00
EE3A9B	2017-08-10 03:07:00+03	75000.00
EE3AB6	2017-07-15 00:00:00+03	27200.00
EE3B35	2017-07-22 10:28:00+03	98200.00
EE3B7C	2017-08-06 03:29:00+03	124200.00
EE3B88	2017-07-15 09:45:00+03	47400.00
EE3C2F	2017-07-30 23:13:00+03	37200.00
EE3C7B	2017-08-14 22:31:00+03	49800.00
EE3C88	2017-08-11 06:33:00+03	25400.00
EE3CB2	2017-08-05 03:56:00+03	131600.00
EE3CCF	2017-06-30 01:40:00+03	55600.00
EE3CF3	2017-07-08 23:03:00+03	132800.00
EE3D02	2017-07-01 08:28:00+03	285600.00
EE3D45	2017-07-21 12:56:00+03	186900.00
EE3D54	2017-07-21 14:36:00+03	15000.00
EE3DDF	2017-07-13 16:49:00+03	53300.00
EE3DF5	2017-07-28 22:10:00+03	68800.00
EE3E70	2017-08-10 01:49:00+03	75800.00
EE3E90	2017-06-30 12:00:00+03	201200.00
EE3F21	2017-08-04 04:06:00+03	16100.00
EE3F82	2017-07-16 02:14:00+03	116800.00
EE3FCB	2017-07-04 01:02:00+03	89600.00
EE401F	2017-06-26 21:17:00+03	67400.00
EE40EB	2017-08-10 01:45:00+03	43900.00
EE4113	2017-07-07 03:45:00+03	43100.00
EE4121	2017-08-08 08:40:00+03	73300.00
EE4199	2017-07-17 04:42:00+03	191000.00
EE41A0	2017-07-10 01:10:00+03	51900.00
EE4247	2017-07-10 11:45:00+03	40600.00
EE426A	2017-08-10 11:03:00+03	73200.00
EE4277	2017-08-13 01:51:00+03	75600.00
EE42E0	2017-07-29 07:01:00+03	136200.00
EE42EE	2017-07-25 01:56:00+03	92600.00
EE42F5	2017-07-18 19:40:00+03	23200.00
EE43B2	2017-08-07 14:03:00+03	46000.00
EE43B3	2017-08-05 18:24:00+03	124200.00
EE43C4	2017-07-29 03:25:00+03	246000.00
EE43F5	2017-07-15 07:23:00+03	24300.00
EE4406	2017-07-09 14:38:00+03	48800.00
EE441A	2017-07-29 20:54:00+03	184300.00
EE442C	2017-08-07 17:03:00+03	26000.00
EE44AF	2017-07-10 11:22:00+03	26800.00
EE4528	2017-07-13 07:02:00+03	99200.00
EE456C	2017-07-19 07:03:00+03	29400.00
EE4593	2017-07-30 00:59:00+03	90400.00
EE45AE	2017-07-16 16:51:00+03	46400.00
EE45D0	2017-08-08 03:11:00+03	28300.00
EE4654	2017-07-22 23:52:00+03	27800.00
EE46AD	2017-07-27 13:28:00+03	47000.00
EE46B9	2017-08-08 18:57:00+03	40800.00
EE473A	2017-07-10 03:43:00+03	169500.00
EE47AB	2017-07-30 10:44:00+03	200500.00
EE47C9	2017-07-29 16:19:00+03	30000.00
EE47D3	2017-07-21 11:00:00+03	57600.00
EE4858	2017-07-05 05:53:00+03	6000.00
EE4891	2017-06-30 15:05:00+03	48800.00
EE4921	2017-08-02 18:03:00+03	102100.00
EE4924	2017-07-24 17:34:00+03	169600.00
EE49A5	2017-07-01 16:56:00+03	42000.00
EE49B2	2017-07-16 11:15:00+03	99200.00
EE49C8	2017-07-02 17:23:00+03	30000.00
EE49F7	2017-07-18 10:35:00+03	6300.00
EE4A33	2017-07-31 06:39:00+03	36200.00
EE4A46	2017-07-12 01:29:00+03	286900.00
EE4A6D	2017-07-21 02:11:00+03	23600.00
EE4A83	2017-08-03 00:08:00+03	60700.00
EE4B15	2017-08-09 17:17:00+03	27200.00
EE4B17	2017-07-04 20:07:00+03	133100.00
EE4B3B	2017-08-11 05:28:00+03	53000.00
EE4C09	2017-08-08 02:46:00+03	26000.00
EE4C29	2017-08-12 09:43:00+03	21400.00
EE4C83	2017-08-03 03:44:00+03	37900.00
EE4C95	2017-08-14 00:38:00+03	27200.00
EE4CB5	2017-08-05 15:09:00+03	37900.00
EE4CF6	2017-08-06 19:20:00+03	67600.00
EE4D17	2017-08-15 11:25:00+03	69000.00
EE4E9D	2017-08-07 15:48:00+03	100600.00
EE4EA6	2017-08-01 08:15:00+03	23200.00
EE4F33	2017-08-12 15:01:00+03	23600.00
EE4F4F	2017-08-05 08:18:00+03	39200.00
EE4F73	2017-07-05 10:23:00+03	25600.00
EE4F8B	2017-07-24 11:28:00+03	18900.00
EE4FD4	2017-07-09 08:08:00+03	48800.00
EE4FEF	2017-07-13 21:40:00+03	113800.00
EE5004	2017-07-30 16:59:00+03	167400.00
EE5040	2017-07-11 15:29:00+03	92000.00
EE5090	2017-07-09 17:11:00+03	21800.00
EE5165	2017-08-08 01:43:00+03	65900.00
EE5182	2017-07-29 18:17:00+03	123600.00
EE51CB	2017-08-13 14:20:00+03	81800.00
EE51EE	2017-07-25 19:44:00+03	15100.00
EE51FB	2017-08-14 02:39:00+03	47000.00
EE51FC	2017-07-01 11:17:00+03	123000.00
EE5221	2017-07-01 03:05:00+03	130400.00
EE5324	2017-08-02 05:21:00+03	131600.00
EE536E	2017-08-12 04:42:00+03	55600.00
EE5373	2017-08-14 23:49:00+03	23200.00
EE538C	2017-07-05 19:45:00+03	13600.00
EE53AC	2017-07-22 15:52:00+03	24800.00
EE53B0	2017-08-03 01:50:00+03	136200.00
EE53D5	2017-07-28 06:54:00+03	147900.00
EE53D8	2017-07-25 03:31:00+03	54800.00
EE543F	2017-07-01 00:21:00+03	61800.00
EE5453	2017-08-02 14:11:00+03	154500.00
EE54BA	2017-07-13 04:01:00+03	189800.00
EE54C1	2017-07-29 19:59:00+03	119500.00
EE54C2	2017-07-02 13:43:00+03	91600.00
EE54E5	2017-08-03 13:40:00+03	78300.00
EE5511	2017-07-28 18:34:00+03	167400.00
EE5518	2017-07-31 06:05:00+03	47200.00
EE5523	2017-07-13 08:18:00+03	19800.00
EE5579	2017-08-13 01:45:00+03	161600.00
EE557F	2017-07-24 01:53:00+03	73100.00
EE55A2	2017-07-11 04:47:00+03	8400.00
EE55D6	2017-08-15 05:25:00+03	21400.00
EE55E9	2017-07-07 06:20:00+03	205400.00
EE560E	2017-08-07 07:01:00+03	153200.00
EE5613	2017-07-09 16:00:00+03	133100.00
EE5681	2017-07-27 08:09:00+03	12400.00
EE5683	2017-07-14 14:46:00+03	26800.00
EE569D	2017-07-16 16:05:00+03	53400.00
EE569E	2017-08-09 23:22:00+03	58600.00
EE572A	2017-07-06 15:12:00+03	13600.00
EE5739	2017-07-20 18:45:00+03	64900.00
EE579A	2017-08-08 09:40:00+03	123000.00
EE5883	2017-06-28 10:26:00+03	147700.00
EE588F	2017-08-13 10:36:00+03	22000.00
EE58CF	2017-08-09 18:55:00+03	167400.00
EE58FC	2017-07-06 15:59:00+03	73500.00
EE5921	2017-08-14 14:35:00+03	6000.00
EE5949	2017-07-23 13:34:00+03	51900.00
EE5987	2017-07-07 23:51:00+03	46400.00
EE5988	2017-08-09 10:53:00+03	40200.00
EE59A6	2017-07-18 13:21:00+03	182100.00
EE5A35	2017-07-31 16:48:00+03	23400.00
EE5A3C	2017-07-08 02:18:00+03	6700.00
EE5A88	2017-07-22 15:17:00+03	146800.00
EE5AAD	2017-07-28 23:44:00+03	28800.00
EE5B28	2017-07-14 06:17:00+03	170700.00
EE5B78	2017-07-11 11:56:00+03	14000.00
EE5BA1	2017-07-17 07:15:00+03	123000.00
EE5BC8	2017-08-02 13:24:00+03	132800.00
EE5C08	2017-06-28 21:36:00+03	16400.00
EE5C25	2017-07-06 12:01:00+03	85300.00
EE5C60	2017-07-12 07:43:00+03	84000.00
EE5C83	2017-08-10 01:12:00+03	68800.00
EE5C9D	2017-08-01 22:24:00+03	106800.00
EE5CBF	2017-08-01 07:08:00+03	19600.00
EE5D0C	2017-07-03 04:12:00+03	31200.00
EE5D14	2017-07-25 16:11:00+03	266400.00
EE5D99	2017-07-02 12:09:00+03	6800.00
EE5DDE	2017-07-26 01:36:00+03	89600.00
EE5DED	2017-07-24 02:30:00+03	83000.00
EE5E3B	2017-08-01 04:44:00+03	182500.00
EE5E8B	2017-08-14 07:43:00+03	43000.00
EE5EA7	2017-07-12 08:34:00+03	40100.00
EE5F08	2017-07-13 18:51:00+03	53000.00
EE5F5D	2017-07-06 17:51:00+03	12400.00
EE5F91	2017-07-24 14:45:00+03	48800.00
EE5FC9	2017-08-01 22:30:00+03	135400.00
EE5FE2	2017-07-10 19:15:00+03	6700.00
EE6015	2017-07-05 16:02:00+03	30200.00
EE6082	2017-07-12 18:12:00+03	111600.00
EE614E	2017-08-05 07:12:00+03	46300.00
EE6229	2017-08-09 20:11:00+03	75800.00
EE626E	2017-07-30 08:56:00+03	81700.00
EE6294	2017-07-26 02:13:00+03	31400.00
EE6438	2017-07-19 17:23:00+03	168000.00
EE6441	2017-07-22 05:06:00+03	191900.00
EE6473	2017-08-01 10:14:00+03	65900.00
EE64A8	2017-08-08 13:19:00+03	203500.00
EE64C2	2017-07-04 11:12:00+03	87800.00
EE6537	2017-06-28 10:54:00+03	28800.00
EE655D	2017-07-20 03:00:00+03	22000.00
EE658A	2017-08-04 01:29:00+03	23200.00
EE6593	2017-08-14 07:54:00+03	281500.00
EE659C	2017-07-13 15:45:00+03	139800.00
EE65B6	2017-07-12 01:51:00+03	13400.00
EE65CA	2017-07-22 05:38:00+03	13400.00
EE65DE	2017-07-19 11:20:00+03	28800.00
EE663A	2017-08-04 09:20:00+03	67600.00
EE6650	2017-07-30 15:24:00+03	82900.00
EE66CD	2017-07-29 17:50:00+03	59700.00
EE6744	2017-08-15 03:46:00+03	40100.00
EE6775	2017-07-19 16:11:00+03	117600.00
EE67E1	2017-08-07 15:19:00+03	270100.00
EE67EB	2017-07-13 18:28:00+03	27000.00
EE681C	2017-07-05 02:19:00+03	52400.00
EE689D	2017-08-14 14:49:00+03	79600.00
EE6999	2017-07-25 16:13:00+03	67600.00
EE69A6	2017-07-16 17:13:00+03	81600.00
EE69EC	2017-07-21 12:44:00+03	121400.00
EE6A13	2017-07-16 03:04:00+03	92700.00
EE6A43	2017-08-14 17:46:00+03	19600.00
EE6ADD	2017-08-02 11:32:00+03	112000.00
EE6AFE	2017-07-30 07:17:00+03	29600.00
EE6BBB	2017-07-10 09:19:00+03	199600.00
EE6C04	2017-07-16 22:37:00+03	32800.00
EE6C93	2017-08-15 00:37:00+03	93900.00
EE6CC3	2017-08-01 09:50:00+03	23600.00
EE6CCC	2017-08-04 10:31:00+03	65500.00
EE6CDB	2017-07-09 17:53:00+03	55500.00
EE6D3C	2017-07-02 22:35:00+03	55100.00
EE6D59	2017-07-23 07:13:00+03	23100.00
EE6D6C	2017-08-06 16:35:00+03	12200.00
EE6DDF	2017-07-31 12:06:00+03	67600.00
EE6F1E	2017-07-06 16:18:00+03	114800.00
EE6F74	2017-07-22 06:11:00+03	24000.00
EE6FC3	2017-07-28 04:31:00+03	124300.00
EE6FD0	2017-07-07 04:21:00+03	36600.00
EE7014	2017-08-11 18:12:00+03	65900.00
EE706B	2017-07-11 19:14:00+03	31600.00
EE7104	2017-07-21 22:46:00+03	116400.00
EE7170	2017-07-28 03:21:00+03	73600.00
EE71B3	2017-07-25 05:44:00+03	302400.00
EE71B6	2017-07-15 07:45:00+03	12400.00
EE71BD	2017-07-01 10:43:00+03	29800.00
EE724D	2017-08-09 03:49:00+03	69500.00
EE72D9	2017-07-02 20:01:00+03	52000.00
EE72E5	2017-07-16 16:19:00+03	131600.00
EE72EB	2017-07-08 07:08:00+03	46200.00
EE72FC	2017-07-25 06:51:00+03	53400.00
EE7374	2017-07-13 17:55:00+03	68400.00
EE7432	2017-07-10 17:00:00+03	422300.00
EE745E	2017-08-01 14:10:00+03	50000.00
EE7469	2017-08-01 13:26:00+03	72000.00
EE748E	2017-08-01 07:59:00+03	135600.00
EE74FC	2017-08-08 02:51:00+03	48800.00
EE75BF	2017-07-18 07:33:00+03	67700.00
EE7604	2017-07-03 18:47:00+03	131000.00
EE7610	2017-08-14 03:30:00+03	62400.00
EE7666	2017-08-12 18:00:00+03	16400.00
EE768F	2017-08-11 01:21:00+03	55800.00
EE7692	2017-08-14 13:11:00+03	270800.00
EE76A8	2017-08-13 13:13:00+03	111600.00
EE76F5	2017-07-19 20:13:00+03	266400.00
EE770F	2017-08-02 02:00:00+03	23200.00
EE7710	2017-07-31 15:28:00+03	38400.00
EE7715	2017-07-30 11:19:00+03	53600.00
EE773D	2017-07-30 16:30:00+03	70700.00
EE7774	2017-07-04 22:51:00+03	73300.00
EE779B	2017-07-08 05:39:00+03	204200.00
EE77F5	2017-07-18 22:06:00+03	27900.00
EE781F	2017-08-06 23:34:00+03	133200.00
EE7821	2017-07-09 21:36:00+03	97800.00
EE7839	2017-08-15 08:03:00+03	49500.00
EE7892	2017-07-28 21:56:00+03	22100.00
EE78CE	2017-07-20 08:07:00+03	14000.00
EE795A	2017-08-07 07:00:00+03	44800.00
EE799E	2017-08-08 05:39:00+03	96800.00
EE79EF	2017-07-03 18:34:00+03	111600.00
EE7A51	2017-08-01 03:32:00+03	99200.00
EE7A6D	2017-07-27 05:51:00+03	23600.00
EE7A7B	2017-08-05 16:17:00+03	38600.00
EE7B50	2017-07-23 23:54:00+03	80400.00
EE7B5A	2017-07-16 14:40:00+03	64800.00
EE7B85	2017-07-29 16:51:00+03	21400.00
EE7B8C	2017-07-27 17:11:00+03	40800.00
EE7C72	2017-08-07 10:15:00+03	73600.00
EE7C99	2017-06-28 09:50:00+03	41900.00
EE7CB4	2017-07-25 19:11:00+03	139100.00
EE7CC0	2017-07-11 05:49:00+03	39600.00
EE7CC3	2017-07-23 19:26:00+03	40800.00
EE7D18	2017-07-04 05:34:00+03	11800.00
EE7D3D	2017-08-09 18:52:00+03	99200.00
EE7D67	2017-07-12 17:14:00+03	61900.00
EE7DD5	2017-07-08 10:18:00+03	95600.00
EE7DF3	2017-08-12 02:32:00+03	55800.00
EE7E55	2017-08-09 00:55:00+03	37100.00
EE7EEC	2017-08-03 20:47:00+03	58600.00
EE7EFC	2017-07-15 17:05:00+03	246000.00
EE7F13	2017-07-21 18:48:00+03	30000.00
EE7F40	2017-07-04 22:22:00+03	66600.00
EE7F7A	2017-08-15 14:33:00+03	15900.00
EE7F80	2017-07-03 05:45:00+03	40800.00
EE7FAD	2017-07-11 09:36:00+03	55800.00
EE7FE0	2017-07-11 02:52:00+03	14400.00
EE7FE3	2017-07-07 13:01:00+03	32600.00
EE8003	2017-07-02 18:32:00+03	24400.00
EE801A	2017-07-29 19:26:00+03	545900.00
EE808B	2017-07-18 22:15:00+03	24600.00
EE80C9	2017-08-02 01:26:00+03	12400.00
EE80EB	2017-08-15 08:46:00+03	40000.00
EE8102	2017-07-25 12:42:00+03	26600.00
EE812D	2017-07-05 01:20:00+03	26000.00
EE814E	2017-08-05 12:41:00+03	38300.00
EE81B8	2017-07-21 16:31:00+03	6800.00
EE8246	2017-07-06 14:38:00+03	34000.00
EE826D	2017-08-06 12:36:00+03	134400.00
EE828C	2017-07-05 22:31:00+03	43600.00
EE82A5	2017-08-11 09:04:00+03	25400.00
EE82E3	2017-08-03 15:55:00+03	123000.00
EE82E6	2017-08-06 22:19:00+03	35500.00
EE82F9	2017-08-07 23:26:00+03	36200.00
EE82FC	2017-07-16 04:07:00+03	6200.00
EE8300	2017-07-29 16:17:00+03	61500.00
EE830B	2017-08-14 10:32:00+03	44800.00
EE8333	2017-07-20 18:22:00+03	62100.00
EE83A9	2017-08-14 04:33:00+03	24800.00
EE83E2	2017-07-26 05:06:00+03	98000.00
EE8417	2017-07-13 20:09:00+03	30400.00
EE845D	2017-06-29 07:44:00+03	62100.00
EE84A5	2017-07-31 06:22:00+03	131000.00
EE84E0	2017-07-20 08:08:00+03	72200.00
EE8528	2017-08-02 06:04:00+03	37900.00
EE8535	2017-07-12 23:04:00+03	20200.00
EE856C	2017-08-10 07:39:00+03	81300.00
EE8582	2017-07-31 21:45:00+03	19800.00
EE858B	2017-07-04 12:31:00+03	101200.00
EE8659	2017-07-16 15:32:00+03	291000.00
EE866D	2017-07-21 11:43:00+03	12400.00
EE8670	2017-07-19 11:07:00+03	60400.00
EE867A	2017-08-02 22:15:00+03	67000.00
EE86A6	2017-07-11 10:44:00+03	62600.00
EE86C4	2017-08-14 09:51:00+03	393000.00
EE8740	2017-07-23 01:26:00+03	82200.00
EE8743	2017-08-03 18:01:00+03	8600.00
EE8747	2017-07-11 22:41:00+03	78200.00
EE8750	2017-07-25 07:45:00+03	56000.00
EE8754	2017-07-03 10:08:00+03	6800.00
EE879C	2017-07-30 08:35:00+03	81300.00
EE87C7	2017-08-14 20:38:00+03	131600.00
EE8800	2017-07-31 19:13:00+03	46700.00
EE887C	2017-07-21 01:31:00+03	8200.00
EE88CF	2017-07-15 02:43:00+03	113700.00
EE88EC	2017-07-01 04:34:00+03	198400.00
EE892E	2017-07-11 05:59:00+03	36000.00
EE897A	2017-07-30 21:31:00+03	43500.00
EE8A33	2017-08-02 16:34:00+03	28800.00
EE8A50	2017-08-14 20:31:00+03	36400.00
EE8AAE	2017-08-03 14:09:00+03	82900.00
EE8ACA	2017-06-30 12:47:00+03	26100.00
EE8AE4	2017-07-14 00:14:00+03	156400.00
EE8AFB	2017-08-14 20:09:00+03	48400.00
EE8AFD	2017-08-08 13:25:00+03	59400.00
EE8B55	2017-08-09 05:59:00+03	81700.00
EE8B5B	2017-06-29 05:53:00+03	25600.00
EE8B71	2017-07-20 02:41:00+03	23200.00
EE8B91	2017-07-16 18:12:00+03	246000.00
EE8BEC	2017-08-04 20:47:00+03	24400.00
EE8C01	2017-07-27 20:55:00+03	21400.00
EE8CCC	2017-07-11 05:31:00+03	29100.00
EE8CD5	2017-07-20 18:34:00+03	81700.00
EE8CEE	2017-07-10 04:55:00+03	92200.00
EE8CFA	2017-07-17 03:14:00+03	131100.00
EE8D0E	2017-07-22 21:42:00+03	105200.00
EE8D6A	2017-06-29 14:42:00+03	11000.00
EE8DB3	2017-08-03 20:54:00+03	137400.00
EE8DB5	2017-08-13 20:16:00+03	75300.00
EE8DB8	2017-07-17 02:21:00+03	155600.00
EE8DDC	2017-07-18 00:51:00+03	67900.00
EE8DE2	2017-07-23 15:40:00+03	14000.00
EE8E3F	2017-07-06 12:46:00+03	68000.00
EE8F1F	2017-08-06 19:24:00+03	126800.00
EE8F86	2017-08-09 15:52:00+03	29400.00
EE8FD7	2017-07-30 13:27:00+03	83700.00
EE900E	2017-07-14 07:29:00+03	32200.00
EE9017	2017-07-07 15:49:00+03	34000.00
EE90AD	2017-08-10 18:29:00+03	87100.00
EE9121	2017-07-28 20:39:00+03	268800.00
EE9158	2017-07-22 02:03:00+03	157100.00
EE91F8	2017-07-29 21:55:00+03	16400.00
EE922A	2017-08-12 01:18:00+03	258400.00
EE9238	2017-08-06 06:30:00+03	38400.00
EE9258	2017-07-05 19:42:00+03	11600.00
EE92C4	2017-08-05 20:56:00+03	120700.00
EE935D	2017-07-06 11:55:00+03	44900.00
EE939A	2017-07-13 19:15:00+03	201600.00
EE9455	2017-08-08 12:38:00+03	47400.00
EE9497	2017-07-25 23:37:00+03	47600.00
EE94B6	2017-07-25 21:23:00+03	46200.00
EE94DC	2017-07-28 15:10:00+03	52300.00
EE94E7	2017-07-21 06:49:00+03	24400.00
EE9559	2017-07-24 07:28:00+03	28800.00
EE95B7	2017-07-15 05:43:00+03	19600.00
EE95C3	2017-08-04 14:46:00+03	55000.00
EE9617	2017-07-22 02:11:00+03	35800.00
EE9669	2017-08-06 10:18:00+03	72400.00
EE9686	2017-08-12 08:18:00+03	131100.00
EE968A	2017-07-17 05:09:00+03	85000.00
EE9694	2017-07-25 04:51:00+03	12600.00
EE969D	2017-07-02 18:18:00+03	21400.00
EE96A0	2017-06-29 01:20:00+03	99200.00
EE96BC	2017-07-09 16:00:00+03	81700.00
EE9741	2017-07-12 21:17:00+03	6000.00
EE97EC	2017-07-04 06:21:00+03	28000.00
EE97F0	2017-07-28 05:14:00+03	75600.00
EE9812	2017-07-09 00:08:00+03	90100.00
EE9837	2017-07-11 03:35:00+03	71600.00
EE9913	2017-07-16 21:16:00+03	26000.00
EE9A7F	2017-07-28 21:03:00+03	398500.00
EE9AB7	2017-07-26 07:13:00+03	17600.00
EE9ABF	2017-07-09 13:09:00+03	189800.00
EE9AD4	2017-07-16 21:36:00+03	26800.00
EE9AD6	2017-07-13 12:59:00+03	24400.00
EE9B05	2017-07-13 02:15:00+03	113600.00
EE9B9B	2017-07-16 08:36:00+03	92700.00
EE9BA5	2017-08-04 16:56:00+03	13600.00
EE9BC6	2017-07-08 21:06:00+03	203000.00
EE9BF3	2017-08-11 15:28:00+03	265800.00
EE9C6B	2017-07-09 06:41:00+03	14000.00
EE9CB0	2017-08-15 07:47:00+03	261500.00
EE9D36	2017-08-14 03:39:00+03	60600.00
EE9D64	2017-08-12 22:26:00+03	18000.00
EE9D78	2017-07-05 16:15:00+03	398600.00
EE9DA2	2017-08-02 16:56:00+03	12000.00
EE9DE4	2017-07-08 03:05:00+03	28000.00
EE9E00	2017-07-13 23:53:00+03	25600.00
EE9E23	2017-08-15 08:27:00+03	7400.00
EE9E34	2017-07-22 14:43:00+03	27800.00
EE9EA3	2017-07-31 02:27:00+03	136100.00
EE9EEA	2017-07-16 14:50:00+03	24600.00
EE9F3F	2017-07-04 21:20:00+03	56000.00
EE9F7C	2017-07-04 12:25:00+03	16400.00
EEA018	2017-08-05 10:12:00+03	50600.00
EEA027	2017-08-02 06:02:00+03	615000.00
EEA06D	2017-08-12 13:15:00+03	12600.00
EEA0A5	2017-07-04 01:23:00+03	15400.00
EEA121	2017-07-07 20:48:00+03	21400.00
EEA14C	2017-08-07 20:06:00+03	81300.00
EEA14F	2017-08-05 00:17:00+03	28000.00
EEA159	2017-08-05 13:27:00+03	21800.00
EEA162	2017-08-07 11:25:00+03	52000.00
EEA1B5	2017-08-10 02:29:00+03	96400.00
EEA293	2017-07-24 14:02:00+03	129200.00
EEA2BC	2017-06-28 10:45:00+03	202600.00
EEA31B	2017-07-05 19:54:00+03	86300.00
EEA328	2017-07-18 03:21:00+03	101500.00
EEA360	2017-08-02 20:11:00+03	103300.00
EEA393	2017-08-13 11:41:00+03	135400.00
EEA3B3	2017-07-25 05:34:00+03	61800.00
EEA3C9	2017-07-15 15:24:00+03	56200.00
EEA446	2017-08-06 04:54:00+03	76000.00
EEA454	2017-08-14 23:27:00+03	136200.00
EEA466	2017-07-07 05:27:00+03	224000.00
EEA56F	2017-07-04 05:49:00+03	109800.00
EEA576	2017-07-30 12:45:00+03	61800.00
EEA5AC	2017-07-25 02:56:00+03	52800.00
EEA5C3	2017-08-11 04:16:00+03	383200.00
EEA5E4	2017-07-17 23:17:00+03	115600.00
EEA612	2017-07-06 19:36:00+03	64500.00
EEA622	2017-08-15 12:07:00+03	37700.00
EEA636	2017-08-15 09:43:00+03	57500.00
EEA6A7	2017-07-07 23:30:00+03	111600.00
EEA6D0	2017-08-04 04:39:00+03	187800.00
EEA70A	2017-07-28 08:15:00+03	51800.00
EEA71A	2017-08-12 10:10:00+03	29600.00
EEA736	2017-07-25 02:22:00+03	13400.00
EEA775	2017-07-06 01:17:00+03	65300.00
EEA823	2017-08-09 07:57:00+03	63700.00
EEA83F	2017-08-01 08:44:00+03	46400.00
EEA925	2017-07-04 21:04:00+03	22600.00
EEA97D	2017-07-22 12:31:00+03	147900.00
EEA9CE	2017-07-09 03:06:00+03	67400.00
EEA9D6	2017-08-06 10:41:00+03	64100.00
EEA9DA	2017-08-12 12:41:00+03	233700.00
EEAA2A	2017-07-06 01:57:00+03	21400.00
EEAA4A	2017-07-10 18:38:00+03	61200.00
EEAA70	2017-06-27 21:52:00+03	90800.00
EEAAC1	2017-07-24 20:47:00+03	134400.00
EEAAEB	2017-07-09 23:37:00+03	134700.00
EEAAFB	2017-07-25 22:18:00+03	184300.00
EEAB54	2017-07-10 12:56:00+03	39000.00
EEAB86	2017-08-14 22:18:00+03	149100.00
EEABB3	2017-08-08 02:30:00+03	55500.00
EEABF3	2017-07-13 01:25:00+03	56600.00
EEAC2D	2017-08-09 03:11:00+03	8000.00
EEAC58	2017-08-09 06:48:00+03	37200.00
EEAC62	2017-07-18 14:48:00+03	63200.00
EEAC6D	2017-08-01 18:43:00+03	65900.00
EEAC7A	2017-08-02 19:31:00+03	198400.00
EEACBD	2017-07-23 10:48:00+03	60200.00
EEACE2	2017-08-05 07:59:00+03	67600.00
EEACEB	2017-07-14 02:03:00+03	26000.00
EEAD0A	2017-07-28 10:22:00+03	24400.00
EEAD17	2017-08-09 14:09:00+03	32700.00
EEADBF	2017-07-03 01:06:00+03	130000.00
EEAE01	2017-08-09 01:46:00+03	13600.00
EEAE39	2017-07-03 18:43:00+03	52000.00
EEAE8A	2017-08-01 10:28:00+03	11600.00
EEAE8F	2017-08-15 14:33:00+03	105900.00
EEAE99	2017-08-04 12:03:00+03	103600.00
EEAEB5	2017-07-03 03:37:00+03	110800.00
EEAEF1	2017-07-30 10:30:00+03	46000.00
EEAEF9	2017-08-01 18:57:00+03	29600.00
EEAF34	2017-07-10 19:26:00+03	39400.00
EEAF43	2017-07-02 20:14:00+03	35200.00
EEAF50	2017-07-21 21:34:00+03	38600.00
EEAF8F	2017-07-08 07:07:00+03	75600.00
EEAFA7	2017-07-19 13:07:00+03	26000.00
EEAFDF	2017-08-08 02:59:00+03	11600.00
EEAFFF	2017-07-21 17:17:00+03	136600.00
EEB027	2017-07-12 19:59:00+03	14800.00
EEB047	2017-08-06 12:14:00+03	55800.00
EEB071	2017-07-10 01:09:00+03	44600.00
EEB078	2017-07-05 06:43:00+03	70200.00
EEB07A	2017-08-12 17:45:00+03	56700.00
EEB088	2017-07-26 17:50:00+03	24800.00
EEB089	2017-07-30 14:33:00+03	73300.00
EEB0D6	2017-07-27 19:36:00+03	28000.00
EEB126	2017-07-01 23:19:00+03	40600.00
EEB134	2017-07-16 01:00:00+03	67400.00
EEB162	2017-07-24 23:30:00+03	67600.00
EEB19C	2017-08-03 19:19:00+03	124200.00
EEB1E1	2017-07-21 04:17:00+03	57800.00
EEB1E2	2017-08-10 04:52:00+03	153300.00
EEB1F2	2017-08-15 16:09:00+03	59200.00
EEB24E	2017-07-20 23:25:00+03	147700.00
EEB285	2017-07-28 13:27:00+03	131100.00
EEB2B2	2017-07-31 03:46:00+03	6700.00
EEB310	2017-07-18 07:44:00+03	133800.00
EEB367	2017-08-04 14:14:00+03	38600.00
EEB3F5	2017-08-08 13:33:00+03	22000.00
EEB45D	2017-07-17 18:30:00+03	38200.00
EEB49E	2017-08-13 00:54:00+03	9800.00
EEB4BE	2017-07-29 12:04:00+03	57300.00
EEB59B	2017-07-10 10:14:00+03	114900.00
EEB600	2017-07-29 01:57:00+03	47000.00
EEB605	2017-08-11 10:10:00+03	14800.00
EEB616	2017-07-30 19:14:00+03	13000.00
EEB64C	2017-07-24 14:02:00+03	282000.00
EEB667	2017-08-12 19:01:00+03	26200.00
EEB676	2017-07-07 07:39:00+03	74500.00
EEB6E7	2017-07-09 22:27:00+03	72400.00
EEB6FB	2017-07-20 05:11:00+03	206400.00
EEB70B	2017-06-25 07:46:00+03	136800.00
EEB784	2017-07-26 07:39:00+03	26000.00
EEB7A0	2017-07-02 20:54:00+03	17200.00
EEB7A2	2017-07-03 21:12:00+03	36800.00
EEB7DB	2017-07-04 09:46:00+03	57800.00
EEB7E0	2017-07-05 18:46:00+03	113800.00
EEB7EA	2017-07-03 21:49:00+03	251300.00
EEB7F1	2017-07-21 03:50:00+03	49200.00
EEB81A	2017-07-14 20:52:00+03	48800.00
EEB863	2017-07-25 13:44:00+03	55800.00
EEB8A3	2017-07-27 16:44:00+03	25600.00
EEB8BD	2017-07-18 07:15:00+03	64200.00
EEB8EF	2017-08-01 09:59:00+03	119300.00
EEB949	2017-07-04 00:22:00+03	23200.00
EEB94A	2017-08-14 18:56:00+03	12600.00
EEB99B	2017-07-11 05:27:00+03	16400.00
EEB9DD	2017-08-10 22:02:00+03	89600.00
EEB9F3	2017-07-01 19:34:00+03	44800.00
EEB9F4	2017-08-15 02:06:00+03	37200.00
EEBA67	2017-07-18 20:45:00+03	369000.00
EEBA95	2017-08-02 22:12:00+03	56000.00
EEBAFE	2017-08-03 12:16:00+03	28000.00
EEBBB8	2017-07-04 01:33:00+03	55800.00
EEBBD8	2017-07-11 09:48:00+03	61800.00
EEBBDE	2017-08-08 10:10:00+03	109600.00
EEBC92	2017-07-10 07:29:00+03	32700.00
EEBD5C	2017-07-02 22:12:00+03	31000.00
EEBE08	2017-07-14 21:18:00+03	306200.00
EEBE14	2017-08-10 23:29:00+03	483400.00
EEBE20	2017-08-14 11:20:00+03	136200.00
EEBE92	2017-08-08 10:10:00+03	26000.00
EEBED1	2017-07-26 05:28:00+03	28800.00
EEBF57	2017-07-29 16:05:00+03	37200.00
EEBFCA	2017-07-10 18:33:00+03	167400.00
EEC0AC	2017-07-27 11:40:00+03	101200.00
EEC104	2017-08-02 13:08:00+03	133900.00
EEC159	2017-08-04 07:49:00+03	46000.00
EEC15D	2017-07-16 06:57:00+03	193600.00
EEC186	2017-07-14 10:11:00+03	27900.00
EEC221	2017-08-12 02:50:00+03	398500.00
EEC234	2017-07-31 13:21:00+03	289800.00
EEC282	2017-07-17 17:36:00+03	111600.00
EEC2B0	2017-07-28 00:43:00+03	43800.00
EEC2BE	2017-08-10 19:21:00+03	83000.00
EEC2C1	2017-08-09 13:01:00+03	11800.00
EEC2FE	2017-07-01 03:06:00+03	13600.00
EEC306	2017-07-28 23:28:00+03	54000.00
EEC316	2017-07-31 21:35:00+03	75600.00
EEC322	2017-08-01 10:59:00+03	52000.00
EEC35B	2017-07-14 22:28:00+03	28800.00
EEC377	2017-07-30 12:03:00+03	24400.00
EEC388	2017-07-17 06:23:00+03	26800.00
EEC3BB	2017-07-22 21:17:00+03	100800.00
EEC3C8	2017-08-04 16:49:00+03	78300.00
EEC3DA	2017-07-05 09:14:00+03	30700.00
EEC41E	2017-08-02 14:58:00+03	56000.00
EEC420	2017-07-09 18:03:00+03	409100.00
EEC431	2017-06-30 11:19:00+03	304800.00
EEC449	2017-08-08 05:53:00+03	153300.00
EEC460	2017-08-01 02:41:00+03	57600.00
EEC467	2017-07-25 20:41:00+03	20400.00
EEC4BE	2017-08-11 09:35:00+03	102900.00
EEC544	2017-08-11 06:52:00+03	186900.00
EEC58E	2017-08-11 04:00:00+03	31000.00
EEC597	2017-07-30 23:59:00+03	198400.00
EEC5B5	2017-07-10 21:22:00+03	150000.00
EEC5D9	2017-07-19 09:49:00+03	87000.00
EEC5DA	2017-07-15 12:25:00+03	32400.00
EEC5DE	2017-07-24 16:22:00+03	24400.00
EEC607	2017-07-14 02:34:00+03	112000.00
EEC61F	2017-07-09 15:41:00+03	25600.00
EEC623	2017-07-16 10:02:00+03	94300.00
EEC646	2017-07-24 10:52:00+03	46300.00
EEC686	2017-06-28 07:25:00+03	23600.00
EEC69A	2017-06-29 18:29:00+03	62000.00
EEC69D	2017-07-15 18:08:00+03	64600.00
EEC6BB	2017-08-15 08:43:00+03	7300.00
EEC70B	2017-07-17 10:23:00+03	14000.00
EEC750	2017-07-08 08:37:00+03	84800.00
EEC76D	2017-08-06 11:50:00+03	69000.00
EEC798	2017-07-16 19:39:00+03	37900.00
EEC7A6	2017-07-08 19:33:00+03	16400.00
EEC7B0	2017-07-28 03:44:00+03	153000.00
EEC7FA	2017-08-09 21:14:00+03	266400.00
EEC816	2017-07-04 03:40:00+03	51600.00
EEC82D	2017-07-29 16:27:00+03	39600.00
EEC84B	2017-06-28 14:13:00+03	58600.00
EEC86B	2017-08-05 10:50:00+03	43900.00
EEC8CC	2017-07-10 17:58:00+03	46400.00
EEC903	2017-07-29 10:32:00+03	167400.00
EEC98F	2017-08-07 09:25:00+03	13200.00
EEC9FC	2017-08-09 20:05:00+03	112000.00
EECA40	2017-07-02 09:49:00+03	62600.00
EECA49	2017-08-13 04:57:00+03	42800.00
EECA67	2017-07-01 23:24:00+03	56900.00
EECB47	2017-07-11 10:56:00+03	54800.00
EECB86	2017-07-31 10:17:00+03	75600.00
EECBA1	2017-08-11 13:48:00+03	36200.00
EECBEF	2017-08-03 15:46:00+03	154800.00
EECC28	2017-07-03 11:25:00+03	3700.00
EECC30	2017-07-15 13:42:00+03	56600.00
EECC78	2017-08-01 08:34:00+03	109300.00
EECC99	2017-08-14 11:12:00+03	46400.00
EECCDB	2017-08-15 08:34:00+03	8200.00
EECD20	2017-07-29 13:12:00+03	89200.00
EECD64	2017-07-28 09:01:00+03	55800.00
EECE66	2017-08-09 15:59:00+03	57400.00
EECEDB	2017-08-10 14:52:00+03	24700.00
EECF9F	2017-07-29 22:37:00+03	42800.00
EECFBC	2017-07-06 15:15:00+03	169000.00
EED034	2017-08-09 23:08:00+03	43900.00
EED07B	2017-07-07 03:20:00+03	161000.00
EED08D	2017-07-19 17:27:00+03	65500.00
EED0AB	2017-08-07 21:35:00+03	101200.00
EED0C3	2017-07-23 23:48:00+03	31600.00
EED124	2017-08-05 18:27:00+03	211100.00
EED1EC	2017-07-02 05:20:00+03	153300.00
EED202	2017-07-10 05:23:00+03	56600.00
EED207	2017-08-09 01:59:00+03	8400.00
EED237	2017-07-11 03:06:00+03	27400.00
EED258	2017-07-28 11:14:00+03	6300.00
EED28B	2017-07-12 19:41:00+03	65900.00
EED2B7	2017-08-01 04:35:00+03	46400.00
EED35E	2017-07-10 06:55:00+03	73500.00
EED3FA	2017-08-12 06:41:00+03	67600.00
EED410	2017-08-06 17:25:00+03	135400.00
EED446	2017-08-15 11:24:00+03	27600.00
EED46F	2017-07-16 01:49:00+03	278400.00
EED48C	2017-07-02 06:56:00+03	134000.00
EED5E3	2017-07-10 08:46:00+03	6300.00
EED65B	2017-07-09 20:29:00+03	135600.00
EED677	2017-07-16 01:00:00+03	14400.00
EED720	2017-07-05 10:34:00+03	6600.00
EED765	2017-08-15 12:49:00+03	43900.00
EED7BB	2017-07-12 16:03:00+03	28800.00
EED7C6	2017-07-18 21:12:00+03	129200.00
EED836	2017-08-06 00:51:00+03	39800.00
EED8A9	2017-07-18 04:01:00+03	143100.00
EED8C7	2017-08-02 22:13:00+03	18800.00
EED903	2017-07-23 16:28:00+03	101200.00
EED90A	2017-08-09 15:18:00+03	16400.00
EED92C	2017-07-22 06:22:00+03	56000.00
EED946	2017-07-21 06:32:00+03	26000.00
EED99E	2017-07-02 06:28:00+03	36400.00
EED9D0	2017-07-26 13:07:00+03	123000.00
EEDA63	2017-08-03 01:56:00+03	86000.00
EEDA77	2017-07-28 12:04:00+03	105000.00
EEDAAF	2017-07-01 05:51:00+03	131800.00
EEDAF0	2017-08-13 16:37:00+03	36600.00
EEDBFB	2017-08-01 22:02:00+03	50800.00
EEDC5F	2017-08-12 14:22:00+03	14000.00
EEDD23	2017-08-08 17:56:00+03	30000.00
EEDD46	2017-08-14 23:28:00+03	62900.00
EEDD55	2017-08-06 04:55:00+03	55800.00
EEDD65	2017-08-05 11:26:00+03	116700.00
EEDD96	2017-07-26 06:33:00+03	96800.00
EEDDC2	2017-08-03 18:53:00+03	89600.00
EEDDC3	2017-07-07 07:05:00+03	92200.00
EEDDD6	2017-07-08 22:56:00+03	51900.00
EEDDE6	2017-08-08 18:35:00+03	44000.00
EEDDEC	2017-07-22 18:21:00+03	19600.00
EEDE02	2017-08-12 22:53:00+03	56800.00
EEDE78	2017-07-16 13:12:00+03	290400.00
EEDE94	2017-08-02 21:55:00+03	109600.00
EEDEA1	2017-07-11 10:44:00+03	28000.00
EEDEA5	2017-07-26 11:41:00+03	99200.00
EEDF25	2017-07-19 05:59:00+03	27800.00
EEDF2D	2017-08-14 03:16:00+03	111600.00
EEDF8C	2017-07-10 08:43:00+03	124300.00
EEDFA2	2017-08-11 04:46:00+03	68800.00
EEDFA9	2017-07-30 07:08:00+03	135400.00
EEDFC6	2017-08-07 20:53:00+03	72200.00
EEDFDE	2017-08-14 09:41:00+03	6000.00
EEE021	2017-07-25 04:25:00+03	13600.00
EEE024	2017-07-02 06:09:00+03	57700.00
EEE036	2017-07-13 22:07:00+03	28000.00
EEE060	2017-08-07 22:12:00+03	100700.00
EEE070	2017-07-28 19:58:00+03	19600.00
EEE08A	2017-07-02 20:23:00+03	36200.00
EEE0B8	2017-07-23 21:33:00+03	43200.00
EEE145	2017-08-13 07:02:00+03	68800.00
EEE19D	2017-07-03 19:19:00+03	14000.00
EEE19F	2017-07-12 21:13:00+03	67200.00
EEE1CD	2017-08-14 16:50:00+03	17000.00
EEE1D9	2017-08-11 19:57:00+03	41600.00
EEE1F1	2017-07-27 01:14:00+03	123000.00
EEE1F2	2017-08-06 18:24:00+03	118300.00
EEE23B	2017-07-15 03:08:00+03	13400.00
EEE274	2017-08-11 07:54:00+03	92000.00
EEE275	2017-08-02 19:15:00+03	64700.00
EEE294	2017-07-30 21:37:00+03	64200.00
EEE407	2017-07-10 02:54:00+03	56000.00
EEE433	2017-07-28 21:52:00+03	124200.00
EEE496	2017-08-15 00:35:00+03	32200.00
EEE4A1	2017-08-08 07:41:00+03	154500.00
EEE592	2017-08-06 23:24:00+03	163500.00
EEE5C5	2017-07-10 12:58:00+03	33100.00
EEE67A	2017-08-01 02:05:00+03	38600.00
EEE6AD	2017-08-11 14:08:00+03	11100.00
EEE6CF	2017-08-11 09:08:00+03	560100.00
EEE73B	2017-08-14 21:02:00+03	165700.00
EEE795	2017-07-27 18:53:00+03	14400.00
EEE7A3	2017-07-08 21:17:00+03	123000.00
EEE821	2017-07-28 13:14:00+03	88400.00
EEE824	2017-07-22 08:15:00+03	246000.00
EEE85B	2017-07-08 22:44:00+03	15100.00
EEE88A	2017-08-03 02:04:00+03	80400.00
EEE8A5	2017-08-02 15:52:00+03	35700.00
EEE8C8	2017-07-24 10:28:00+03	18600.00
EEE8ED	2017-08-11 23:49:00+03	36700.00
EEE92C	2017-07-11 21:01:00+03	174900.00
EEE941	2017-07-03 08:08:00+03	67600.00
EEE94A	2017-08-04 17:54:00+03	133200.00
EEE962	2017-07-11 02:36:00+03	76300.00
EEE9BD	2017-07-02 17:07:00+03	40400.00
EEE9C7	2017-07-28 23:44:00+03	23200.00
EEEA30	2017-07-24 00:57:00+03	40800.00
EEEAB7	2017-07-09 04:40:00+03	191500.00
EEEAEB	2017-07-09 00:57:00+03	43000.00
EEEB0D	2017-07-21 17:58:00+03	59000.00
EEEB17	2017-08-04 16:47:00+03	55000.00
EEEB61	2017-06-28 03:27:00+03	94700.00
EEEC6C	2017-07-18 20:37:00+03	124200.00
EEEC7F	2017-07-13 18:53:00+03	131100.00
EEEC97	2017-08-03 00:30:00+03	168700.00
EEECA1	2017-07-23 21:47:00+03	34000.00
EEEDC0	2017-08-15 09:50:00+03	131600.00
EEEDEC	2017-07-15 23:31:00+03	532800.00
EEEEC4	2017-08-09 08:53:00+03	15800.00
EEEED2	2017-07-06 06:18:00+03	43200.00
EEEF50	2017-07-14 17:32:00+03	92800.00
EEEF9A	2017-07-03 00:35:00+03	6700.00
EEEFA7	2017-07-24 08:02:00+03	63800.00
EEEFC1	2017-07-25 10:55:00+03	26000.00
EEF00E	2017-08-14 10:55:00+03	48800.00
EEF01D	2017-08-13 11:25:00+03	50100.00
EEF029	2017-07-09 04:47:00+03	28800.00
EEF02F	2017-07-02 01:07:00+03	44800.00
EEF056	2017-08-01 14:45:00+03	17600.00
EEF085	2017-08-14 02:13:00+03	12000.00
EEF097	2017-07-14 21:34:00+03	272400.00
EEF09F	2017-07-02 23:59:00+03	492000.00
EEF0C4	2017-07-07 16:38:00+03	47100.00
EEF0EB	2017-07-14 11:19:00+03	15800.00
EEF117	2017-08-01 05:08:00+03	68400.00
EEF17C	2017-07-15 00:33:00+03	165000.00
EEF20E	2017-07-14 04:09:00+03	24800.00
EEF237	2017-07-02 01:35:00+03	28000.00
EEF289	2017-08-13 09:22:00+03	43200.00
EEF2EC	2017-07-24 17:30:00+03	14000.00
EEF2ED	2017-08-14 05:14:00+03	20300.00
EEF2F3	2017-07-13 17:24:00+03	30200.00
EEF313	2017-07-20 23:48:00+03	48300.00
EEF317	2017-07-04 13:52:00+03	36200.00
EEF355	2017-08-09 08:55:00+03	31600.00
EEF367	2017-08-04 14:37:00+03	270800.00
EEF36B	2017-07-19 17:26:00+03	69900.00
EEF3F4	2017-08-07 11:16:00+03	34000.00
EEF405	2017-07-11 19:25:00+03	168000.00
EEF412	2017-07-21 13:38:00+03	56600.00
EEF43B	2017-07-26 19:50:00+03	55800.00
EEF452	2017-08-13 20:26:00+03	81200.00
EEF4B0	2017-08-15 16:07:00+03	21200.00
EEF4B7	2017-07-19 01:25:00+03	64700.00
EEF4C2	2017-07-08 10:58:00+03	65500.00
EEF569	2017-08-08 04:13:00+03	142300.00
EEF588	2017-07-14 15:15:00+03	141600.00
EEF5A7	2017-07-08 00:12:00+03	14800.00
EEF5CC	2017-08-07 01:51:00+03	50800.00
EEF650	2017-07-14 21:52:00+03	205300.00
EEF67D	2017-08-10 19:00:00+03	133200.00
EEF686	2017-07-20 02:30:00+03	75600.00
EEF716	2017-07-27 01:20:00+03	67700.00
EEF755	2017-07-31 22:37:00+03	55800.00
EEF75D	2017-07-23 12:54:00+03	30400.00
EEF79A	2017-07-09 20:49:00+03	25400.00
EEF84E	2017-07-18 09:03:00+03	62800.00
EEF88A	2017-07-12 13:33:00+03	86300.00
EEF8B3	2017-07-13 07:55:00+03	39400.00
EEF981	2017-07-25 06:36:00+03	56600.00
EEF991	2017-08-01 20:58:00+03	46400.00
EEF9A4	2017-06-28 22:05:00+03	20900.00
EEF9D1	2017-07-17 02:19:00+03	246000.00
EEFA39	2017-07-13 14:02:00+03	43000.00
EEFA42	2017-07-28 22:00:00+03	159100.00
EEFA78	2017-07-25 15:59:00+03	61900.00
EEFAE6	2017-07-29 08:21:00+03	28000.00
EEFB21	2017-08-03 10:29:00+03	93700.00
EEFB32	2017-07-16 03:36:00+03	26000.00
EEFB5F	2017-08-08 07:41:00+03	76500.00
EEFB76	2017-08-12 22:15:00+03	27700.00
EEFBA0	2017-08-06 17:49:00+03	54600.00
EEFC21	2017-07-24 11:26:00+03	181100.00
EEFC5D	2017-07-16 07:57:00+03	57500.00
EEFC74	2017-07-26 21:07:00+03	184200.00
EEFD52	2017-08-09 16:26:00+03	9200.00
EEFDD4	2017-07-07 18:00:00+03	56000.00
EEFDE1	2017-07-18 01:41:00+03	90600.00
EEFE4A	2017-07-08 11:53:00+03	89600.00
EEFE59	2017-07-17 09:40:00+03	22000.00
EEFED2	2017-07-06 15:27:00+03	197400.00
EEFF12	2017-07-12 16:44:00+03	205500.00
EEFF2F	2017-08-14 20:32:00+03	61800.00
EEFF3F	2017-07-05 22:16:00+03	67800.00
EEFF6B	2017-07-11 15:18:00+03	26000.00
EEFF9E	2017-07-13 06:39:00+03	26000.00
EEFFA2	2017-08-05 00:36:00+03	58600.00
EEFFCF	2017-07-13 01:13:00+03	47000.00
EEFFD0	2017-08-13 04:22:00+03	91000.00
EF000A	2017-08-08 05:37:00+03	24000.00
EF0052	2017-07-18 02:51:00+03	119600.00
EF008D	2017-07-23 11:11:00+03	35600.00
EF00D7	2017-08-04 16:48:00+03	91000.00
EF00FC	2017-08-07 05:20:00+03	199200.00
EF01E3	2017-08-06 03:07:00+03	51300.00
EF01FF	2017-07-12 11:27:00+03	81700.00
EF023B	2017-08-12 19:50:00+03	26800.00
EF02BC	2017-07-30 08:39:00+03	93700.00
EF031B	2017-08-05 19:05:00+03	142500.00
EF0332	2017-08-15 11:09:00+03	40100.00
EF0370	2017-07-17 14:21:00+03	58200.00
EF0404	2017-07-31 20:15:00+03	38600.00
EF040E	2017-07-23 10:34:00+03	116000.00
EF0437	2017-08-13 00:40:00+03	20100.00
EF048D	2017-07-22 00:57:00+03	42400.00
EF0498	2017-08-11 14:56:00+03	22100.00
EF053E	2017-08-05 15:01:00+03	128800.00
EF0547	2017-08-13 04:32:00+03	30200.00
EF0557	2017-08-02 05:42:00+03	15800.00
EF05D3	2017-08-12 23:12:00+03	15200.00
EF05DF	2017-07-16 19:01:00+03	26800.00
EF0648	2017-08-03 14:20:00+03	69500.00
EF0684	2017-07-18 22:47:00+03	170400.00
EF06A6	2017-08-03 22:59:00+03	48500.00
EF06ED	2017-07-20 17:55:00+03	135600.00
EF0702	2017-07-04 14:04:00+03	167200.00
EF0768	2017-08-15 09:34:00+03	106400.00
EF07B5	2017-08-03 05:22:00+03	32800.00
EF07E0	2017-07-24 14:18:00+03	46200.00
EF0814	2017-07-24 19:50:00+03	22400.00
EF084E	2017-08-01 16:25:00+03	18800.00
EF0863	2017-08-02 08:17:00+03	153900.00
EF0879	2017-07-23 18:21:00+03	12400.00
EF08D3	2017-07-25 21:45:00+03	92000.00
EF093B	2017-07-16 19:41:00+03	75300.00
EF0961	2017-07-21 08:13:00+03	229300.00
EF0976	2017-07-29 19:56:00+03	184300.00
EF09A7	2017-07-11 21:33:00+03	6600.00
EF0A4B	2017-08-04 17:17:00+03	6900.00
EF0A90	2017-07-02 04:25:00+03	187400.00
EF0AF5	2017-07-19 05:52:00+03	101100.00
EF0B0C	2017-08-07 20:40:00+03	249200.00
EF0B21	2017-07-29 19:46:00+03	34000.00
EF0B43	2017-07-11 21:17:00+03	20600.00
EF0B88	2017-07-23 03:23:00+03	28000.00
EF0BB0	2017-07-30 02:01:00+03	31000.00
EF0BCA	2017-08-12 00:12:00+03	198400.00
EF0C11	2017-08-08 13:36:00+03	25100.00
EF0C57	2017-07-09 08:37:00+03	56600.00
EF0CAA	2017-08-14 01:24:00+03	31600.00
EF0CEE	2017-07-30 23:34:00+03	23100.00
EF0CEF	2017-07-04 20:24:00+03	52400.00
EF0D3B	2017-07-09 12:52:00+03	57600.00
EF0D5D	2017-07-04 14:44:00+03	26000.00
EF0DAF	2017-07-16 15:11:00+03	134100.00
EF0DD0	2017-08-01 15:52:00+03	406700.00
EF0DF1	2017-08-07 16:40:00+03	87800.00
EF0E43	2017-07-21 19:19:00+03	57600.00
EF0E95	2017-08-08 05:33:00+03	83900.00
EF0EBB	2017-07-14 14:07:00+03	24800.00
EF0ED4	2017-07-25 00:03:00+03	92800.00
EF0F1E	2017-07-06 19:55:00+03	12000.00
EF0F2D	2017-08-06 11:13:00+03	112000.00
EF0F35	2017-08-15 15:19:00+03	39800.00
EF0FC0	2017-07-30 02:30:00+03	66600.00
EF1014	2017-07-07 00:42:00+03	199700.00
EF1021	2017-08-11 02:48:00+03	242600.00
EF104E	2017-08-03 03:12:00+03	29400.00
EF1074	2017-07-07 18:20:00+03	66600.00
EF10B0	2017-06-30 14:17:00+03	56700.00
EF10F2	2017-07-10 20:16:00+03	35800.00
EF10F9	2017-07-06 15:47:00+03	49600.00
EF1155	2017-08-14 01:42:00+03	70100.00
EF1157	2017-07-17 02:36:00+03	21200.00
EF115C	2017-07-29 09:27:00+03	405000.00
EF1165	2017-07-18 12:53:00+03	134700.00
EF116E	2017-07-08 21:44:00+03	63200.00
EF11C3	2017-08-06 15:10:00+03	84100.00
EF11CF	2017-08-05 02:33:00+03	272400.00
EF1242	2017-07-26 21:27:00+03	73300.00
EF12C6	2017-07-08 18:38:00+03	52700.00
EF12D4	2017-07-15 02:18:00+03	13400.00
EF12EE	2017-07-16 15:25:00+03	95100.00
EF1303	2017-08-14 17:41:00+03	56000.00
EF1369	2017-07-15 15:33:00+03	81600.00
EF1393	2017-06-26 19:01:00+03	56200.00
EF1422	2017-07-04 11:38:00+03	88600.00
EF14A4	2017-07-14 23:53:00+03	56000.00
EF14C5	2017-08-10 20:16:00+03	135000.00
EF14DF	2017-07-15 10:00:00+03	43800.00
EF14E0	2017-07-14 06:16:00+03	68200.00
EF1504	2017-07-12 02:32:00+03	28000.00
EF1507	2017-07-20 12:25:00+03	35800.00
EF15B1	2017-08-15 02:28:00+03	52900.00
EF163E	2017-08-10 18:20:00+03	12000.00
EF174B	2017-07-16 21:05:00+03	28800.00
EF1774	2017-06-29 17:02:00+03	89700.00
EF1824	2017-07-25 16:34:00+03	91300.00
EF1841	2017-07-02 23:56:00+03	54100.00
EF18FF	2017-07-04 17:14:00+03	75000.00
EF1922	2017-08-08 18:11:00+03	94900.00
EF1924	2017-08-06 21:57:00+03	178800.00
EF193A	2017-07-04 13:53:00+03	88600.00
EF1971	2017-07-26 08:15:00+03	86800.00
EF1981	2017-07-30 02:48:00+03	128800.00
EF19BB	2017-07-29 00:25:00+03	117200.00
EF1A81	2017-08-15 04:11:00+03	101700.00
EF1A95	2017-07-10 03:46:00+03	99200.00
EF1ACC	2017-07-27 23:51:00+03	32800.00
EF1B15	2017-07-16 03:27:00+03	28000.00
EF1B3B	2017-08-03 18:11:00+03	51200.00
EF1B4B	2017-07-01 23:27:00+03	271100.00
EF1B90	2017-08-08 18:34:00+03	123000.00
EF1BAC	2017-07-08 08:17:00+03	6600.00
EF1BE1	2017-08-06 10:44:00+03	81500.00
EF1BE6	2017-07-28 00:43:00+03	31600.00
EF1C1E	2017-08-07 09:37:00+03	6700.00
EF1C5F	2017-07-05 17:24:00+03	28800.00
EF1C62	2017-07-02 20:27:00+03	46500.00
EF1C73	2017-07-10 00:00:00+03	111900.00
EF1C8B	2017-08-03 22:58:00+03	152600.00
EF1D57	2017-07-13 03:14:00+03	73900.00
EF1D5B	2017-08-12 07:39:00+03	40600.00
EF1E5A	2017-06-27 20:07:00+03	105100.00
EF1E9C	2017-07-29 10:46:00+03	54500.00
EF1F4D	2017-08-01 14:56:00+03	101600.00
EF1F52	2017-07-01 02:19:00+03	114600.00
EF1FDB	2017-07-28 06:57:00+03	41200.00
EF1FEE	2017-08-06 02:28:00+03	40000.00
EF2034	2017-07-29 11:04:00+03	46400.00
EF207E	2017-08-05 13:12:00+03	70700.00
EF2095	2017-07-24 01:20:00+03	75500.00
EF21C8	2017-07-28 17:57:00+03	23200.00
EF2211	2017-07-12 07:41:00+03	31700.00
EF221A	2017-08-14 19:39:00+03	25100.00
EF221C	2017-07-16 19:01:00+03	7400.00
EF2228	2017-07-27 07:53:00+03	21400.00
EF2272	2017-08-11 12:57:00+03	55800.00
EF22BD	2017-07-21 11:44:00+03	62900.00
EF2359	2017-08-01 11:06:00+03	223200.00
EF2365	2017-07-09 03:20:00+03	28800.00
EF23EB	2017-07-29 03:57:00+03	84500.00
EF2413	2017-08-08 05:09:00+03	56600.00
EF2495	2017-07-15 02:03:00+03	65000.00
EF2558	2017-07-10 17:15:00+03	81600.00
EF2583	2017-07-05 13:16:00+03	28800.00
EF25EB	2017-07-21 07:21:00+03	27200.00
EF2631	2017-08-02 07:47:00+03	7200.00
EF2636	2017-07-08 00:53:00+03	26800.00
EF271A	2017-07-22 21:31:00+03	19600.00
EF271C	2017-07-07 02:24:00+03	97200.00
EF2738	2017-08-14 13:59:00+03	516000.00
EF2745	2017-07-21 08:57:00+03	125100.00
EF274D	2017-07-06 16:19:00+03	80900.00
EF2777	2017-08-12 16:33:00+03	87800.00
EF27E3	2017-07-04 19:20:00+03	46400.00
EF2804	2017-08-13 01:24:00+03	27700.00
EF280C	2017-06-29 03:09:00+03	21800.00
EF2815	2017-07-11 12:17:00+03	28000.00
EF2869	2017-07-13 19:53:00+03	131200.00
EF2878	2017-07-22 18:06:00+03	270400.00
EF28C5	2017-07-02 09:41:00+03	135600.00
EF28EB	2017-08-01 01:10:00+03	32400.00
EF2965	2017-07-09 20:15:00+03	23200.00
EF29C6	2017-07-26 15:37:00+03	201800.00
EF29FC	2017-07-19 06:30:00+03	76100.00
EF2A19	2017-08-10 15:52:00+03	39200.00
EF2B0F	2017-07-11 05:10:00+03	34200.00
EF2B24	2017-07-10 17:22:00+03	23200.00
EF2B86	2017-07-25 01:37:00+03	42400.00
EF2BA0	2017-08-04 16:43:00+03	120900.00
EF2C0E	2017-07-03 11:15:00+03	38400.00
EF2C85	2017-08-10 19:47:00+03	58200.00
EF2C8F	2017-07-23 00:20:00+03	123000.00
EF2CBC	2017-08-11 04:24:00+03	12600.00
EF2CE6	2017-08-11 03:21:00+03	85400.00
EF2DD9	2017-08-13 07:51:00+03	67200.00
EF2E7A	2017-07-01 21:29:00+03	74400.00
EF2ECC	2017-08-08 06:38:00+03	351400.00
EF2EE4	2017-08-01 16:42:00+03	56900.00
EF2EEB	2017-06-28 01:31:00+03	66600.00
EF2EFF	2017-07-02 18:50:00+03	393800.00
EF2F3C	2017-07-28 21:34:00+03	136200.00
EF2F95	2017-08-14 17:28:00+03	75300.00
EF2FB0	2017-08-09 15:57:00+03	67600.00
EF2FB8	2017-07-01 11:48:00+03	85000.00
EF300F	2017-07-25 15:48:00+03	58600.00
EF3050	2017-07-18 09:51:00+03	22000.00
EF305A	2017-08-14 22:37:00+03	147100.00
EF3115	2017-07-16 12:10:00+03	11600.00
EF3133	2017-08-13 03:34:00+03	40200.00
EF319B	2017-08-08 07:11:00+03	40000.00
EF31CA	2017-08-08 06:50:00+03	272300.00
EF31E2	2017-08-04 23:25:00+03	42800.00
EF3266	2017-08-09 08:41:00+03	43200.00
EF32E0	2017-08-06 02:26:00+03	46300.00
EF3347	2017-07-22 19:32:00+03	40400.00
EF3393	2017-08-12 12:22:00+03	44800.00
EF339E	2017-07-28 18:30:00+03	46300.00
EF33BF	2017-07-31 13:52:00+03	166100.00
EF33FC	2017-08-04 03:30:00+03	96300.00
EF3422	2017-07-24 12:43:00+03	25900.00
EF3431	2017-07-08 13:55:00+03	32800.00
EF3446	2017-07-27 23:23:00+03	21800.00
EF3473	2017-08-15 11:58:00+03	92000.00
EF3486	2017-07-11 13:59:00+03	47200.00
EF3497	2017-07-13 04:18:00+03	59100.00
EF349B	2017-08-14 20:12:00+03	531300.00
EF349C	2017-07-11 12:33:00+03	313800.00
EF34AE	2017-08-13 19:43:00+03	111900.00
EF34ED	2017-08-14 05:00:00+03	115700.00
EF3552	2017-07-09 22:18:00+03	87800.00
EF359F	2017-07-29 10:57:00+03	14400.00
EF362B	2017-07-18 07:06:00+03	40900.00
EF365B	2017-07-10 19:32:00+03	28600.00
EF368A	2017-07-06 09:15:00+03	83000.00
EF36A4	2017-07-14 23:28:00+03	130400.00
EF3719	2017-07-29 22:30:00+03	74800.00
EF3786	2017-08-07 04:27:00+03	57400.00
EF3799	2017-07-24 14:18:00+03	101200.00
EF3810	2017-07-15 01:42:00+03	410400.00
EF381F	2017-07-01 20:14:00+03	44000.00
EF3849	2017-08-12 11:20:00+03	88000.00
EF38FD	2017-07-26 14:00:00+03	113300.00
EF391C	2017-08-03 23:10:00+03	84000.00
EF393D	2017-08-07 06:20:00+03	136200.00
EF3982	2017-07-15 12:19:00+03	59100.00
EF3A26	2017-08-09 02:57:00+03	81500.00
EF3A87	2017-07-05 23:15:00+03	105200.00
EF3A9E	2017-08-04 19:37:00+03	199800.00
EF3AAF	2017-08-11 09:50:00+03	84000.00
EF3AB5	2017-08-15 17:54:00+03	79200.00
EF3ACA	2017-07-11 10:48:00+03	24400.00
EF3AE6	2017-07-25 22:25:00+03	56000.00
EF3B72	2017-07-10 07:55:00+03	137600.00
EF3B7D	2017-07-20 12:30:00+03	28000.00
EF3B82	2017-07-20 07:09:00+03	159800.00
EF3B94	2017-08-15 12:27:00+03	40800.00
EF3BA1	2017-08-05 19:35:00+03	95200.00
EF3C52	2017-07-28 17:03:00+03	84700.00
EF3C5B	2017-07-01 19:11:00+03	55800.00
EF3CE1	2017-07-02 15:34:00+03	111600.00
EF3D5A	2017-07-10 10:31:00+03	68800.00
EF3D81	2017-07-19 03:57:00+03	47400.00
EF3DDE	2017-07-10 09:08:00+03	43500.00
EF3E00	2017-08-15 10:56:00+03	73300.00
EF3E3F	2017-07-10 03:57:00+03	63700.00
EF3E6B	2017-07-10 00:24:00+03	67600.00
EF3EA9	2017-08-06 19:22:00+03	110500.00
EF3EE3	2017-07-02 21:11:00+03	46400.00
EF3F89	2017-07-15 05:38:00+03	53300.00
EF4005	2017-07-29 23:11:00+03	28000.00
EF4009	2017-08-08 09:13:00+03	28000.00
EF4034	2017-08-01 11:42:00+03	69900.00
EF405C	2017-07-26 05:04:00+03	32800.00
EF40C3	2017-07-03 13:53:00+03	430700.00
EF40D8	2017-07-12 07:12:00+03	55800.00
EF40F2	2017-07-12 01:24:00+03	92000.00
EF410E	2017-08-09 14:15:00+03	26800.00
EF413E	2017-07-17 10:08:00+03	23200.00
EF4170	2017-07-31 04:14:00+03	21400.00
EF418C	2017-06-29 03:59:00+03	406100.00
EF4194	2017-08-05 21:04:00+03	112000.00
EF41A8	2017-07-27 10:21:00+03	131600.00
EF41BD	2017-07-21 06:56:00+03	149200.00
EF4220	2017-08-04 21:43:00+03	46000.00
EF4226	2017-07-23 23:09:00+03	67700.00
EF4272	2017-07-18 12:16:00+03	23400.00
EF4292	2017-08-11 03:11:00+03	165600.00
EF42C3	2017-07-21 00:17:00+03	25400.00
EF42CD	2017-07-30 03:03:00+03	23200.00
EF42DB	2017-06-27 01:10:00+03	31100.00
EF430D	2017-07-26 17:01:00+03	105000.00
EF4319	2017-08-07 10:51:00+03	26600.00
EF4389	2017-08-12 02:53:00+03	134800.00
EF43DB	2017-07-17 01:33:00+03	137400.00
EF4451	2017-08-07 05:16:00+03	62600.00
EF4471	2017-08-09 03:02:00+03	49800.00
EF4478	2017-07-24 08:40:00+03	86800.00
EF4489	2017-07-22 22:22:00+03	141600.00
EF44C2	2017-08-02 17:34:00+03	133200.00
EF44D3	2017-08-14 23:44:00+03	167300.00
EF45C6	2017-07-21 15:25:00+03	76400.00
EF4600	2017-07-17 05:00:00+03	73600.00
EF4610	2017-07-05 23:18:00+03	27400.00
EF466A	2017-07-06 22:29:00+03	55800.00
EF467C	2017-07-19 12:08:00+03	92900.00
EF4718	2017-07-09 09:42:00+03	146800.00
EF4732	2017-07-29 01:40:00+03	43200.00
EF4743	2017-07-12 11:34:00+03	58200.00
EF4781	2017-08-14 15:56:00+03	36700.00
EF479A	2017-08-08 11:17:00+03	34000.00
EF479E	2017-08-02 15:58:00+03	1035100.00
EF47F9	2017-08-07 12:19:00+03	57500.00
EF4837	2017-08-15 03:50:00+03	29200.00
EF48E1	2017-07-08 17:40:00+03	46000.00
EF48FC	2017-07-10 06:26:00+03	54800.00
EF4957	2017-07-15 10:11:00+03	58000.00
EF4ABC	2017-07-07 23:56:00+03	265700.00
EF4ADB	2017-07-26 21:30:00+03	66600.00
EF4AE3	2017-08-07 11:40:00+03	189200.00
EF4B07	2017-07-21 01:25:00+03	47000.00
EF4B23	2017-07-18 22:09:00+03	242700.00
EF4C12	2017-08-09 12:50:00+03	257600.00
EF4C3E	2017-07-14 12:36:00+03	100600.00
EF4C83	2017-07-26 06:14:00+03	27200.00
EF4C8C	2017-08-05 01:05:00+03	116000.00
EF4CDD	2017-07-14 14:43:00+03	55800.00
EF4D32	2017-08-04 01:53:00+03	35200.00
EF4DFD	2017-07-20 14:07:00+03	24800.00
EF4E0A	2017-07-30 17:21:00+03	56600.00
EF4E3A	2017-07-24 01:24:00+03	6700.00
EF4E7D	2017-08-07 10:53:00+03	81600.00
EF4EA5	2017-07-19 16:24:00+03	24200.00
EF4EDD	2017-07-30 10:22:00+03	66600.00
EF4EF1	2017-07-02 04:43:00+03	75600.00
EF4F28	2017-08-14 23:57:00+03	50800.00
EF4F30	2017-08-07 12:01:00+03	29600.00
EF4F56	2017-08-10 19:27:00+03	83000.00
EF4F83	2017-07-27 18:37:00+03	265700.00
EF4FDD	2017-08-09 14:42:00+03	13400.00
EF5074	2017-07-09 01:56:00+03	12400.00
EF5091	2017-07-06 23:02:00+03	133200.00
EF50AC	2017-07-16 20:26:00+03	21000.00
EF51C2	2017-07-23 08:18:00+03	32700.00
EF51EB	2017-08-06 11:41:00+03	113200.00
EF5220	2017-07-15 08:19:00+03	28800.00
EF524D	2017-07-15 15:43:00+03	28000.00
EF52B8	2017-08-08 23:57:00+03	196800.00
EF52DD	2017-08-15 10:21:00+03	13200.00
EF5380	2017-07-27 20:48:00+03	61800.00
EF5399	2017-07-14 06:17:00+03	55800.00
EF53A5	2017-07-25 18:50:00+03	28300.00
EF53AB	2017-07-08 06:15:00+03	84300.00
EF5442	2017-07-04 23:49:00+03	27900.00
EF5468	2017-08-01 15:31:00+03	12400.00
EF54BE	2017-08-04 01:54:00+03	52000.00
EF5576	2017-07-07 23:54:00+03	21800.00
EF5583	2017-06-28 10:25:00+03	6000.00
EF55C6	2017-07-19 21:19:00+03	31600.00
EF55E9	2017-07-17 05:37:00+03	124200.00
EF5645	2017-08-06 14:35:00+03	24400.00
EF564E	2017-07-09 11:46:00+03	31000.00
EF56B1	2017-08-13 22:50:00+03	60700.00
EF5709	2017-07-06 07:35:00+03	26000.00
EF574A	2017-07-05 02:18:00+03	199200.00
EF575C	2017-07-28 19:18:00+03	29600.00
EF577C	2017-08-04 00:08:00+03	94000.00
EF57D4	2017-07-27 03:25:00+03	15900.00
EF57E1	2017-08-15 09:46:00+03	37100.00
EF5837	2017-07-24 08:11:00+03	36800.00
EF5841	2017-07-10 05:17:00+03	28000.00
EF58B5	2017-07-04 04:43:00+03	123000.00
EF58F5	2017-08-03 15:57:00+03	124300.00
EF59DE	2017-07-30 05:56:00+03	658400.00
EF5A6E	2017-08-10 22:57:00+03	32200.00
EF5BD7	2017-08-11 18:58:00+03	126900.00
EF5C91	2017-07-06 08:25:00+03	20200.00
EF5CA4	2017-08-10 22:42:00+03	30200.00
EF5CB1	2017-07-25 03:32:00+03	67600.00
EF5D10	2017-08-14 21:18:00+03	35800.00
EF5D68	2017-07-09 04:45:00+03	28800.00
EF5DED	2017-07-07 22:07:00+03	92800.00
EF5E06	2017-07-09 09:13:00+03	417200.00
EF5E16	2017-07-29 17:53:00+03	48600.00
EF5EA6	2017-08-12 06:29:00+03	6000.00
EF5F09	2017-08-13 09:29:00+03	272400.00
EF5F26	2017-08-13 14:04:00+03	26600.00
EF5F6C	2017-08-06 00:09:00+03	100600.00
EF606F	2017-08-14 14:17:00+03	38800.00
EF6085	2017-07-28 15:09:00+03	248300.00
EF6089	2017-07-21 06:54:00+03	75600.00
EF60A5	2017-07-02 04:02:00+03	27900.00
EF6139	2017-07-18 17:19:00+03	666000.00
EF613A	2017-07-19 14:06:00+03	25800.00
EF6177	2017-07-29 13:10:00+03	271400.00
EF619B	2017-07-24 02:24:00+03	58800.00
EF628D	2017-08-13 11:07:00+03	66000.00
EF62D5	2017-08-11 18:05:00+03	176500.00
EF62DF	2017-08-13 01:07:00+03	77000.00
EF634F	2017-07-10 14:21:00+03	301800.00
EF6375	2017-08-15 08:26:00+03	27200.00
EF63FC	2017-07-10 03:22:00+03	37200.00
EF64A3	2017-07-28 15:15:00+03	133600.00
EF6522	2017-07-25 07:38:00+03	59100.00
EF655D	2017-07-13 18:49:00+03	66600.00
EF656E	2017-07-09 06:24:00+03	28700.00
EF65C2	2017-07-27 17:05:00+03	12000.00
EF65D0	2017-07-17 07:27:00+03	56000.00
EF6677	2017-08-13 03:01:00+03	55600.00
EF669F	2017-08-13 02:07:00+03	10800.00
EF66C0	2017-07-02 08:12:00+03	38600.00
EF66CC	2017-07-21 16:33:00+03	6600.00
EF66E9	2017-08-09 10:51:00+03	250100.00
EF674C	2017-07-22 10:24:00+03	97700.00
EF6789	2017-07-22 03:44:00+03	44000.00
EF6824	2017-07-14 21:08:00+03	18000.00
EF686D	2017-07-09 21:38:00+03	151000.00
EF68FE	2017-07-21 03:30:00+03	65000.00
EF690A	2017-07-02 12:48:00+03	27800.00
EF69AA	2017-07-13 12:47:00+03	27200.00
EF69B9	2017-08-11 08:50:00+03	171000.00
EF69D1	2017-08-07 12:21:00+03	99300.00
EF6A4A	2017-07-23 06:30:00+03	38200.00
EF6A5B	2017-07-07 05:22:00+03	10100.00
EF6AB8	2017-08-02 14:44:00+03	28800.00
EF6AE3	2017-08-07 04:42:00+03	71000.00
EF6B48	2017-07-19 05:55:00+03	166100.00
EF6BB8	2017-08-09 09:55:00+03	189200.00
EF6C11	2017-07-20 09:20:00+03	67400.00
EF6CD0	2017-08-06 21:28:00+03	86600.00
EF6CF8	2017-07-06 10:51:00+03	61800.00
EF6D14	2017-06-29 04:42:00+03	31600.00
EF6D46	2017-08-07 02:25:00+03	43700.00
EF6D76	2017-07-01 13:42:00+03	40800.00
EF6ED3	2017-08-07 11:12:00+03	166900.00
EF6ED8	2017-08-01 17:01:00+03	89700.00
EF6F71	2017-08-13 19:30:00+03	41200.00
EF6F93	2017-08-14 19:09:00+03	39200.00
EF70A7	2017-07-27 08:19:00+03	242600.00
EF70B3	2017-07-29 15:43:00+03	28000.00
EF70F6	2017-07-08 18:46:00+03	22000.00
EF714C	2017-08-11 04:06:00+03	19600.00
EF7188	2017-07-26 02:29:00+03	65900.00
EF71AC	2017-07-09 03:24:00+03	369000.00
EF71DE	2017-08-07 16:54:00+03	58400.00
EF71F8	2017-07-04 09:34:00+03	52700.00
EF7219	2017-08-13 10:00:00+03	40000.00
EF7229	2017-07-25 09:37:00+03	57600.00
EF7287	2017-07-19 13:51:00+03	132800.00
EF72C2	2017-08-12 18:05:00+03	14000.00
EF7334	2017-08-13 16:26:00+03	37900.00
EF738A	2017-07-21 22:27:00+03	47600.00
EF73BA	2017-07-04 22:09:00+03	67600.00
EF73F4	2017-07-30 03:08:00+03	128800.00
EF743B	2017-07-26 07:13:00+03	72000.00
EF7490	2017-07-25 21:50:00+03	115300.00
EF74AE	2017-08-12 23:06:00+03	120700.00
EF74C0	2017-07-07 09:01:00+03	28800.00
EF74CB	2017-07-13 10:26:00+03	131900.00
EF75C0	2017-07-17 06:08:00+03	98400.00
EF7659	2017-08-07 02:13:00+03	36200.00
EF76C6	2017-07-16 10:13:00+03	85000.00
EF77B1	2017-07-30 06:08:00+03	60800.00
EF77B6	2017-08-04 18:01:00+03	193600.00
EF77E1	2017-07-09 01:43:00+03	111600.00
EF7844	2017-08-15 06:06:00+03	36200.00
EF785A	2017-06-30 12:25:00+03	162700.00
EF7866	2017-08-02 15:45:00+03	40800.00
EF7936	2017-07-10 20:44:00+03	12600.00
EF7953	2017-07-04 09:46:00+03	6000.00
EF799E	2017-08-10 05:01:00+03	38400.00
EF7A15	2017-07-16 19:17:00+03	23200.00
EF7A25	2017-07-06 12:45:00+03	44600.00
EF7A86	2017-07-31 01:56:00+03	56600.00
EF7A9A	2017-07-16 11:38:00+03	56000.00
EF7B52	2017-07-10 12:45:00+03	111700.00
EF7B55	2017-08-10 01:59:00+03	14400.00
EF7B73	2017-07-01 13:02:00+03	26000.00
EF7B7F	2017-07-14 09:43:00+03	86600.00
EF7B93	2017-07-06 19:27:00+03	8000.00
EF7C20	2017-06-28 17:43:00+03	23200.00
EF7C83	2017-07-21 03:45:00+03	199700.00
EF7C9A	2017-08-08 19:38:00+03	204700.00
EF7CEB	2017-07-29 18:17:00+03	84500.00
EF7DD3	2017-08-11 15:59:00+03	23200.00
EF7DF0	2017-07-07 05:59:00+03	27800.00
EF7DFB	2017-08-09 08:17:00+03	68400.00
EF7E62	2017-07-04 01:05:00+03	80300.00
EF7EC7	2017-08-12 01:29:00+03	75300.00
EF7ECE	2017-07-09 09:38:00+03	143200.00
EF7F3E	2017-08-15 09:49:00+03	26000.00
EF7F6C	2017-07-11 12:47:00+03	58900.00
EF7F90	2017-07-09 00:53:00+03	59300.00
EF7FDB	2017-08-10 03:57:00+03	99200.00
EF808B	2017-07-22 18:20:00+03	94000.00
EF80E8	2017-07-04 12:28:00+03	46400.00
EF80E9	2017-07-12 13:05:00+03	45200.00
EF811F	2017-07-04 01:12:00+03	28800.00
EF8131	2017-07-27 06:41:00+03	48400.00
EF8149	2017-07-08 02:43:00+03	101100.00
EF81D6	2017-07-14 10:03:00+03	28800.00
EF8205	2017-07-02 15:25:00+03	16400.00
EF822C	2017-07-10 08:25:00+03	65400.00
EF8235	2017-08-09 15:21:00+03	89700.00
EF8279	2017-08-08 17:18:00+03	51900.00
EF82A2	2017-08-05 18:13:00+03	21400.00
EF82E5	2017-08-12 22:31:00+03	23600.00
EF82FF	2017-07-15 14:42:00+03	24300.00
EF836F	2017-07-19 18:38:00+03	11800.00
EF83B5	2017-07-12 08:18:00+03	49100.00
EF83C6	2017-07-08 22:24:00+03	45200.00
EF840F	2017-07-28 08:52:00+03	24400.00
EF841C	2017-08-06 19:18:00+03	122300.00
EF8467	2017-07-11 09:43:00+03	70400.00
EF84B6	2017-08-12 20:19:00+03	109700.00
EF84D1	2017-07-31 02:13:00+03	60400.00
EF8511	2017-08-04 17:09:00+03	32200.00
EF854F	2017-07-09 03:25:00+03	119800.00
EF8560	2017-08-06 03:38:00+03	50000.00
EF8578	2017-07-18 19:18:00+03	37200.00
EF8581	2017-07-28 15:14:00+03	43200.00
EF8582	2017-07-28 04:51:00+03	23200.00
EF8621	2017-07-18 09:25:00+03	61900.00
EF8622	2017-06-30 23:40:00+03	51600.00
EF8659	2017-07-11 08:28:00+03	66800.00
EF8677	2017-07-23 19:07:00+03	84500.00
EF867F	2017-08-01 21:33:00+03	54800.00
EF86AD	2017-07-07 07:49:00+03	56000.00
EF86DF	2017-08-05 18:36:00+03	24400.00
EF86EE	2017-07-02 16:26:00+03	13400.00
EF8707	2017-07-17 23:22:00+03	38400.00
EF8747	2017-08-02 14:49:00+03	71000.00
EF87AC	2017-07-18 19:23:00+03	26000.00
EF87BB	2017-08-10 19:44:00+03	52900.00
EF8852	2017-08-11 13:15:00+03	75500.00
EF88AF	2017-07-09 06:03:00+03	12400.00
EF88CB	2017-07-11 18:32:00+03	6000.00
EF8981	2017-08-04 02:49:00+03	47500.00
EF8998	2017-07-31 21:10:00+03	46800.00
EF89D5	2017-07-23 18:10:00+03	26000.00
EF89DD	2017-07-12 08:02:00+03	28800.00
EF8A35	2017-06-29 16:30:00+03	77600.00
EF8A39	2017-08-10 11:43:00+03	25600.00
EF8A47	2017-08-09 21:41:00+03	137400.00
EF8A84	2017-08-02 00:50:00+03	92400.00
EF8B0C	2017-07-19 16:05:00+03	61200.00
EF8CA5	2017-07-20 19:21:00+03	101200.00
EF8D0C	2017-08-11 17:40:00+03	55800.00
EF8D34	2017-07-01 11:53:00+03	23200.00
EF8D49	2017-07-15 23:19:00+03	50600.00
EF8D55	2017-06-28 16:14:00+03	67600.00
EF8D67	2017-08-11 03:07:00+03	63300.00
EF8D81	2017-07-03 16:45:00+03	139400.00
EF8D91	2017-07-16 12:09:00+03	173500.00
EF8E4A	2017-07-27 15:06:00+03	23600.00
EF8E62	2017-08-11 01:18:00+03	32800.00
EF8E91	2017-07-10 15:37:00+03	22000.00
EF8E96	2017-06-27 03:34:00+03	24400.00
EF8ED0	2017-08-12 15:40:00+03	19800.00
EF8ED1	2017-07-31 03:01:00+03	54400.00
EF8F0F	2017-07-10 13:51:00+03	9200.00
EF8F13	2017-08-05 11:32:00+03	28800.00
EF8F25	2017-07-21 02:18:00+03	265600.00
EF8F2C	2017-08-14 16:53:00+03	28800.00
EF8F47	2017-07-13 06:05:00+03	30200.00
EF8F80	2017-07-11 07:24:00+03	81900.00
EF8F87	2017-08-03 16:42:00+03	15000.00
EF8F90	2017-07-26 02:46:00+03	138000.00
EF9055	2017-08-03 05:58:00+03	19800.00
EF9066	2017-08-12 10:52:00+03	44600.00
EF911D	2017-07-03 22:40:00+03	46400.00
EF914F	2017-07-05 18:03:00+03	50700.00
EF9164	2017-07-27 11:53:00+03	71000.00
EF9172	2017-07-17 06:41:00+03	24800.00
EF9193	2017-07-05 04:59:00+03	67200.00
EF919C	2017-07-13 11:01:00+03	153100.00
EF91A5	2017-07-25 08:28:00+03	147700.00
EF91D5	2017-07-01 00:52:00+03	32700.00
EF91F7	2017-07-05 05:36:00+03	28000.00
EF9218	2017-08-10 15:26:00+03	85000.00
EF923C	2017-07-11 07:52:00+03	156600.00
EF9270	2017-08-01 09:00:00+03	28800.00
EF9271	2017-08-12 23:59:00+03	123000.00
EF9284	2017-08-08 19:47:00+03	32700.00
EF92A0	2017-07-04 11:54:00+03	38800.00
EF939C	2017-07-19 16:46:00+03	250100.00
EF93DE	2017-08-03 17:19:00+03	131100.00
EF948C	2017-07-19 23:40:00+03	34200.00
EF94CC	2017-08-15 05:58:00+03	50600.00
EF94CE	2017-07-09 00:48:00+03	286100.00
EF95E7	2017-08-07 02:19:00+03	137700.00
EF971A	2017-07-05 00:53:00+03	27200.00
EF9738	2017-07-01 14:39:00+03	86400.00
EF975A	2017-07-21 23:01:00+03	68400.00
EF9792	2017-07-14 05:55:00+03	31000.00
EF97C7	2017-07-07 01:04:00+03	74900.00
EF9966	2017-07-01 23:00:00+03	26000.00
EF9973	2017-07-30 09:59:00+03	22200.00
EF9975	2017-07-18 17:26:00+03	58600.00
EF9999	2017-08-14 19:59:00+03	39100.00
EF99B3	2017-08-02 14:09:00+03	26600.00
EF99DA	2017-07-30 16:00:00+03	95600.00
EF99DC	2017-07-25 13:15:00+03	25600.00
EF99E0	2017-08-06 02:24:00+03	127100.00
EF99EB	2017-07-03 05:10:00+03	36100.00
EF9A9D	2017-07-05 20:17:00+03	96900.00
EF9AA7	2017-08-03 01:24:00+03	65500.00
EF9AAD	2017-07-20 06:19:00+03	75600.00
EF9AC0	2017-07-28 07:19:00+03	23200.00
EF9B26	2017-07-03 23:29:00+03	75800.00
EF9B49	2017-07-27 15:50:00+03	44000.00
EF9B59	2017-08-04 14:37:00+03	23600.00
EF9B74	2017-07-05 02:14:00+03	73100.00
EF9B7D	2017-07-16 22:27:00+03	24200.00
EF9BD4	2017-07-20 03:55:00+03	349200.00
EF9C9A	2017-08-10 07:19:00+03	166000.00
EF9CD3	2017-07-28 19:59:00+03	123000.00
EF9CDB	2017-08-07 01:28:00+03	162500.00
EF9E79	2017-07-02 13:05:00+03	116400.00
EF9EDE	2017-07-03 18:12:00+03	7400.00
EF9EED	2017-07-08 21:12:00+03	26000.00
EF9F18	2017-07-21 08:48:00+03	60900.00
EF9F26	2017-08-06 04:44:00+03	71900.00
EF9FC0	2017-07-24 00:18:00+03	7400.00
EF9FC3	2017-08-15 16:32:00+03	34600.00
EF9FD4	2017-07-24 00:31:00+03	43600.00
EF9FD5	2017-08-01 09:20:00+03	280800.00
EF9FF4	2017-08-13 12:34:00+03	89600.00
EFA00A	2017-07-21 06:28:00+03	120900.00
EFA069	2017-07-07 09:10:00+03	28700.00
EFA0BE	2017-07-13 05:19:00+03	94800.00
EFA0DB	2017-08-09 16:47:00+03	28800.00
EFA0FA	2017-07-22 22:49:00+03	43500.00
EFA104	2017-07-12 13:45:00+03	44800.00
EFA105	2017-08-05 01:55:00+03	339800.00
EFA116	2017-08-07 21:08:00+03	16400.00
EFA125	2017-07-17 07:59:00+03	59200.00
EFA133	2017-07-15 23:59:00+03	169600.00
EFA180	2017-08-05 20:13:00+03	37200.00
EFA1B1	2017-07-09 23:59:00+03	28000.00
EFA1BA	2017-07-29 22:11:00+03	271200.00
EFA1C0	2017-07-28 03:44:00+03	68000.00
EFA229	2017-07-05 04:40:00+03	66600.00
EFA247	2017-07-28 09:33:00+03	48500.00
EFA26A	2017-07-02 09:26:00+03	30900.00
EFA276	2017-07-19 11:05:00+03	147100.00
EFA28E	2017-07-31 09:41:00+03	77900.00
EFA2F4	2017-07-30 00:15:00+03	57500.00
EFA31B	2017-07-27 23:29:00+03	80900.00
EFA324	2017-07-20 02:22:00+03	101200.00
EFA334	2017-08-09 16:47:00+03	81000.00
EFA362	2017-07-19 13:49:00+03	236300.00
EFA36E	2017-07-29 15:00:00+03	28000.00
EFA3BD	2017-07-30 19:34:00+03	133500.00
EFA3DB	2017-07-30 07:01:00+03	177600.00
EFA40A	2017-07-19 16:26:00+03	66600.00
EFA47D	2017-08-04 15:42:00+03	9300.00
EFA49C	2017-08-09 05:07:00+03	12400.00
EFA4CC	2017-07-16 12:03:00+03	46400.00
EFA502	2017-06-30 09:00:00+03	36000.00
EFA550	2017-08-08 03:07:00+03	20200.00
EFA553	2017-08-01 18:23:00+03	54100.00
EFA588	2017-08-12 12:24:00+03	55800.00
EFA5A6	2017-07-24 21:36:00+03	15200.00
EFA5D9	2017-06-29 20:26:00+03	58400.00
EFA63C	2017-08-06 11:59:00+03	103500.00
EFA645	2017-07-28 04:50:00+03	221900.00
EFA649	2017-07-12 08:26:00+03	22000.00
EFA66C	2017-07-01 10:23:00+03	52700.00
EFA6E9	2017-08-13 18:10:00+03	235500.00
EFA7A0	2017-07-27 17:38:00+03	46000.00
EFA7C8	2017-08-15 03:32:00+03	59300.00
EFA815	2017-07-21 06:30:00+03	6400.00
EFA856	2017-07-09 22:41:00+03	58800.00
EFA879	2017-08-02 03:25:00+03	23200.00
EFA8E6	2017-06-30 20:09:00+03	28800.00
EFA94E	2017-08-09 16:58:00+03	76100.00
EFA953	2017-08-15 05:17:00+03	128800.00
EFA95A	2017-07-28 23:18:00+03	174600.00
EFA984	2017-08-07 01:01:00+03	46400.00
EFA99B	2017-08-14 17:50:00+03	30200.00
EFA9A6	2017-08-02 15:54:00+03	21800.00
EFA9B5	2017-07-28 02:00:00+03	36700.00
EFA9B6	2017-07-03 23:56:00+03	17800.00
EFA9E2	2017-07-04 22:18:00+03	56600.00
EFAA42	2017-06-26 16:32:00+03	45100.00
EFAA4D	2017-07-23 02:03:00+03	396500.00
EFAB0D	2017-08-07 13:30:00+03	23100.00
EFAB9E	2017-08-04 08:35:00+03	79800.00
EFABB8	2017-08-07 05:43:00+03	119600.00
EFABD0	2017-07-17 20:31:00+03	42800.00
EFABE0	2017-07-29 01:54:00+03	24200.00
EFABED	2017-07-24 08:34:00+03	20200.00
EFAC0D	2017-07-15 15:11:00+03	35700.00
EFAC3E	2017-08-04 14:20:00+03	27200.00
EFAC45	2017-07-04 18:11:00+03	229600.00
EFAC46	2017-07-25 13:06:00+03	38600.00
EFAC54	2017-08-09 21:27:00+03	138500.00
EFACAF	2017-07-19 17:12:00+03	28800.00
EFACF4	2017-08-12 05:53:00+03	23200.00
EFAD36	2017-07-17 11:12:00+03	25800.00
EFAD40	2017-07-22 21:14:00+03	57600.00
EFAD69	2017-07-16 13:45:00+03	77000.00
EFADF1	2017-07-17 02:19:00+03	43600.00
EFAE9B	2017-08-10 00:05:00+03	112000.00
EFAF83	2017-07-03 05:17:00+03	18300.00
EFAF95	2017-07-29 03:40:00+03	28600.00
EFAFCD	2017-07-30 05:48:00+03	123000.00
EFAFEA	2017-06-29 23:44:00+03	97000.00
EFB01A	2017-08-09 20:00:00+03	38200.00
EFB05E	2017-07-30 02:44:00+03	116900.00
EFB0B5	2017-07-19 17:21:00+03	62000.00
EFB0D6	2017-08-05 02:00:00+03	56900.00
EFB162	2017-07-04 12:20:00+03	11700.00
EFB18E	2017-07-26 01:03:00+03	156400.00
EFB1F9	2017-07-06 00:41:00+03	109200.00
EFB226	2017-07-07 22:42:00+03	135200.00
EFB230	2017-08-07 10:57:00+03	85000.00
EFB234	2017-08-04 06:03:00+03	60700.00
EFB2E2	2017-07-06 12:25:00+03	46000.00
EFB2EE	2017-07-08 09:23:00+03	40000.00
EFB331	2017-07-05 20:19:00+03	79600.00
EFB3E3	2017-07-24 10:04:00+03	68100.00
EFB405	2017-07-31 20:09:00+03	110600.00
EFB431	2017-08-14 19:05:00+03	109400.00
EFB4FD	2017-07-03 16:18:00+03	39300.00
EFB538	2017-07-19 09:23:00+03	28000.00
EFB55D	2017-07-13 08:33:00+03	100600.00
EFB567	2017-07-01 22:51:00+03	22000.00
EFB5F9	2017-07-20 06:09:00+03	168000.00
EFB617	2017-07-11 12:29:00+03	169500.00
EFB627	2017-08-08 06:02:00+03	28000.00
EFB71F	2017-07-30 19:51:00+03	113100.00
EFB722	2017-07-10 17:00:00+03	32700.00
EFB767	2017-08-07 13:05:00+03	50800.00
EFB76D	2017-07-30 06:23:00+03	88300.00
EFB7A1	2017-08-13 07:08:00+03	14000.00
EFB7D3	2017-07-27 08:17:00+03	51800.00
EFB809	2017-07-20 03:23:00+03	23200.00
EFB826	2017-08-01 11:36:00+03	85600.00
EFB8B0	2017-07-15 23:03:00+03	4000.00
EFB8E8	2017-07-17 15:11:00+03	31400.00
EFB8F2	2017-08-08 13:07:00+03	84500.00
EFB912	2017-08-09 05:33:00+03	31600.00
EFBA15	2017-07-08 06:35:00+03	50900.00
EFBA2E	2017-07-22 19:34:00+03	54400.00
EFBA81	2017-08-03 03:12:00+03	22600.00
EFBAA3	2017-08-04 22:19:00+03	53100.00
EFBB09	2017-07-12 13:21:00+03	372500.00
EFBB37	2017-07-15 05:13:00+03	51800.00
EFBBA4	2017-07-23 10:57:00+03	28800.00
EFBBD4	2017-07-17 05:59:00+03	37400.00
EFBBE7	2017-08-04 06:13:00+03	46400.00
EFBBE9	2017-08-02 10:55:00+03	30400.00
EFBC15	2017-07-30 13:16:00+03	75600.00
EFBC18	2017-07-10 22:07:00+03	68800.00
EFBC59	2017-08-13 21:56:00+03	156300.00
EFBC9C	2017-07-01 23:06:00+03	81300.00
EFBD1A	2017-07-11 01:41:00+03	13400.00
EFBD1E	2017-07-17 01:40:00+03	193900.00
EFBD47	2017-07-28 10:42:00+03	12600.00
EFBDBD	2017-07-09 17:01:00+03	139400.00
EFBDCE	2017-07-27 12:25:00+03	42800.00
EFBE25	2017-07-16 18:14:00+03	38600.00
EFBE48	2017-08-02 21:25:00+03	28000.00
EFBECF	2017-07-06 09:36:00+03	38600.00
EFBED7	2017-07-09 04:43:00+03	246000.00
EFBF03	2017-07-26 02:44:00+03	43500.00
EFBF05	2017-07-28 05:59:00+03	67000.00
EFBF10	2017-08-10 04:02:00+03	125100.00
EFBF5A	2017-07-17 21:38:00+03	28800.00
EFBFA2	2017-07-26 18:41:00+03	68800.00
EFBFAF	2017-07-26 21:11:00+03	169900.00
EFBFD1	2017-07-01 01:03:00+03	48800.00
EFBFF4	2017-08-11 09:59:00+03	155000.00
EFC01D	2017-07-26 02:35:00+03	37900.00
EFC023	2017-07-08 21:16:00+03	123000.00
EFC02F	2017-08-10 22:23:00+03	22000.00
EFC045	2017-07-25 09:14:00+03	124200.00
EFC04C	2017-07-25 13:25:00+03	23200.00
EFC057	2017-08-09 01:01:00+03	47400.00
EFC082	2017-06-29 22:48:00+03	93900.00
EFC139	2017-07-20 09:55:00+03	35000.00
EFC170	2017-08-02 12:29:00+03	29600.00
EFC1DD	2017-08-13 15:54:00+03	13600.00
EFC205	2017-07-31 07:40:00+03	81600.00
EFC233	2017-07-03 03:33:00+03	86400.00
EFC28F	2017-08-04 02:57:00+03	14900.00
EFC33D	2017-08-03 04:44:00+03	112000.00
EFC366	2017-08-05 18:21:00+03	46400.00
EFC392	2017-07-28 16:05:00+03	19000.00
EFC475	2017-08-09 16:46:00+03	123000.00
EFC524	2017-08-15 03:53:00+03	42800.00
EFC56E	2017-07-26 20:08:00+03	56100.00
EFC570	2017-07-03 01:36:00+03	117600.00
EFC5B6	2017-08-12 06:36:00+03	51200.00
EFC5FC	2017-08-05 13:25:00+03	47200.00
EFC66E	2017-07-23 15:05:00+03	69700.00
EFC692	2017-08-12 20:29:00+03	133600.00
EFC693	2017-08-10 08:11:00+03	534300.00
EFC697	2017-08-14 02:04:00+03	98700.00
EFC750	2017-07-13 05:51:00+03	18600.00
EFC836	2017-07-20 19:44:00+03	43600.00
EFC885	2017-08-11 11:34:00+03	136200.00
EFC919	2017-07-12 21:55:00+03	25400.00
EFC9C7	2017-06-30 14:06:00+03	61800.00
EFCA04	2017-07-28 12:47:00+03	44000.00
EFCA9C	2017-07-17 23:28:00+03	48500.00
EFCAB2	2017-07-11 09:24:00+03	43500.00
EFCAD9	2017-08-02 11:24:00+03	43500.00
EFCAE5	2017-07-02 21:28:00+03	47000.00
EFCAF9	2017-06-29 23:24:00+03	35200.00
EFCB35	2017-07-08 01:18:00+03	29200.00
EFCB9A	2017-07-13 00:41:00+03	56000.00
EFCC58	2017-07-04 16:07:00+03	31100.00
EFCC59	2017-07-29 23:01:00+03	16000.00
EFCC82	2017-08-11 03:17:00+03	12200.00
EFCCF9	2017-08-10 21:28:00+03	25800.00
EFCF3B	2017-07-11 05:39:00+03	46000.00
EFCF7B	2017-08-01 20:40:00+03	40000.00
EFCF80	2017-08-06 13:53:00+03	135000.00
EFCFCB	2017-08-11 03:41:00+03	75800.00
EFD034	2017-07-28 07:28:00+03	114800.00
EFD044	2017-07-20 00:39:00+03	37900.00
EFD0EF	2017-07-26 04:09:00+03	39400.00
EFD0FF	2017-07-29 05:19:00+03	34000.00
EFD11C	2017-08-14 05:07:00+03	95900.00
EFD234	2017-07-29 06:11:00+03	60400.00
EFD261	2017-08-06 03:18:00+03	65900.00
EFD276	2017-07-24 03:24:00+03	41600.00
EFD280	2017-07-19 15:35:00+03	133100.00
EFD2D0	2017-08-09 10:50:00+03	31300.00
EFD2DD	2017-08-07 19:55:00+03	128800.00
EFD343	2017-07-15 07:34:00+03	31000.00
EFD34F	2017-07-14 00:40:00+03	187600.00
EFD405	2017-08-05 09:45:00+03	46000.00
EFD43D	2017-07-01 23:09:00+03	44600.00
EFD4F2	2017-08-10 18:41:00+03	77900.00
EFD520	2017-08-10 21:31:00+03	47200.00
EFD543	2017-07-19 06:01:00+03	54800.00
EFD6A8	2017-07-17 01:52:00+03	41600.00
EFD6D0	2017-07-11 15:42:00+03	29400.00
EFD728	2017-07-24 12:15:00+03	46200.00
EFD731	2017-07-25 02:04:00+03	170500.00
EFD75F	2017-07-12 19:18:00+03	130400.00
EFD77B	2017-08-03 01:27:00+03	14400.00
EFD781	2017-07-23 03:08:00+03	28000.00
EFD7B2	2017-07-29 10:46:00+03	132600.00
EFD7CC	2017-07-25 20:38:00+03	28800.00
EFD7F7	2017-08-02 14:40:00+03	167400.00
EFD810	2017-07-25 21:46:00+03	28300.00
EFD828	2017-07-15 16:18:00+03	106400.00
EFD873	2017-07-12 09:19:00+03	59200.00
EFD881	2017-07-04 01:37:00+03	178400.00
EFD89E	2017-07-24 12:44:00+03	68800.00
EFD8E2	2017-07-03 18:21:00+03	132800.00
EFD97F	2017-07-16 21:48:00+03	28000.00
EFD9E4	2017-07-17 00:53:00+03	64500.00
EFD9EB	2017-07-30 02:57:00+03	139300.00
EFDB2F	2017-07-30 08:17:00+03	113700.00
EFDB89	2017-07-15 21:53:00+03	99600.00
EFDBA3	2017-07-19 01:32:00+03	89700.00
EFDC31	2017-07-25 20:16:00+03	67900.00
EFDCBF	2017-08-13 16:57:00+03	123600.00
EFDD20	2017-07-06 11:13:00+03	46000.00
EFDD41	2017-08-03 14:43:00+03	27200.00
EFDD9A	2017-08-13 12:25:00+03	128800.00
EFDDE5	2017-07-20 15:21:00+03	8000.00
EFDE18	2017-07-18 17:26:00+03	47500.00
EFDE50	2017-08-12 03:02:00+03	27200.00
EFDE7C	2017-08-04 18:08:00+03	46400.00
EFDE7E	2017-07-20 19:43:00+03	16400.00
EFDE8B	2017-08-03 07:12:00+03	14000.00
EFDE97	2017-07-13 05:40:00+03	271200.00
EFDEAE	2017-08-13 15:13:00+03	21800.00
EFDEF3	2017-07-02 09:52:00+03	149600.00
EFDF08	2017-07-03 12:41:00+03	23600.00
EFDF20	2017-08-06 07:14:00+03	28800.00
EFDF22	2017-07-28 18:34:00+03	56000.00
EFDF2E	2017-07-27 08:26:00+03	170800.00
EFDF57	2017-07-23 09:22:00+03	135600.00
EFDF72	2017-08-14 22:00:00+03	110100.00
EFDF84	2017-07-09 04:40:00+03	6000.00
EFDF94	2017-07-19 08:51:00+03	181300.00
EFDFDA	2017-08-11 03:50:00+03	69500.00
EFE080	2017-08-07 11:18:00+03	92400.00
EFE0CC	2017-07-03 14:51:00+03	13600.00
EFE0E1	2017-07-30 17:07:00+03	185700.00
EFE131	2017-07-15 09:22:00+03	57600.00
EFE19F	2017-07-16 02:06:00+03	89700.00
EFE1DF	2017-07-06 21:42:00+03	77500.00
EFE1E0	2017-08-10 13:35:00+03	10800.00
EFE2EB	2017-07-10 07:21:00+03	103300.00
EFE38C	2017-08-08 15:50:00+03	40400.00
EFE3B5	2017-07-22 18:25:00+03	24400.00
EFE41C	2017-08-07 23:55:00+03	136800.00
EFE44D	2017-07-19 13:54:00+03	46800.00
EFE4A2	2017-07-11 06:08:00+03	116700.00
EFE562	2017-07-26 04:25:00+03	51300.00
EFE56B	2017-07-15 02:59:00+03	126900.00
EFE666	2017-08-13 05:33:00+03	70700.00
EFE6EE	2017-07-21 16:07:00+03	35400.00
EFE74A	2017-07-23 22:05:00+03	47400.00
EFE756	2017-07-21 22:04:00+03	46400.00
EFE787	2017-07-19 13:06:00+03	32200.00
EFE821	2017-08-13 02:21:00+03	54800.00
EFE8C1	2017-07-19 11:06:00+03	160200.00
EFE8D9	2017-06-29 22:38:00+03	170400.00
EFE8E9	2017-06-29 23:08:00+03	71400.00
EFE922	2017-08-04 16:21:00+03	42800.00
EFE944	2017-07-01 02:35:00+03	252200.00
EFE964	2017-08-09 17:30:00+03	18800.00
EFE9BB	2017-07-03 14:04:00+03	190700.00
EFE9F9	2017-07-23 09:10:00+03	88600.00
EFEB19	2017-07-15 12:43:00+03	278400.00
EFEB88	2017-08-14 18:46:00+03	20000.00
EFEB9E	2017-07-13 05:41:00+03	92800.00
EFEBA3	2017-08-03 01:52:00+03	37900.00
EFEBB9	2017-08-03 23:08:00+03	36900.00
EFEC34	2017-07-03 09:11:00+03	50000.00
EFEC72	2017-07-30 12:07:00+03	57200.00
EFEC9D	2017-07-13 00:41:00+03	54400.00
EFECE7	2017-07-18 11:44:00+03	44000.00
EFED27	2017-07-22 06:53:00+03	66600.00
EFED42	2017-07-03 02:41:00+03	88600.00
EFED65	2017-08-11 10:40:00+03	68800.00
EFEDF3	2017-08-02 04:32:00+03	44000.00
EFEDF4	2017-07-15 21:14:00+03	43900.00
EFEE1B	2017-07-22 00:44:00+03	23600.00
EFEE7B	2017-08-10 02:14:00+03	21200.00
EFEE96	2017-08-13 15:49:00+03	49900.00
EFEF4F	2017-07-27 08:25:00+03	535600.00
EFEF5A	2017-07-17 13:18:00+03	223100.00
EFEF68	2017-07-18 23:49:00+03	91200.00
EFEFEA	2017-08-06 02:34:00+03	100000.00
EFEFFD	2017-07-19 11:41:00+03	100600.00
EFF02E	2017-07-09 14:06:00+03	114400.00
EFF06A	2017-07-09 07:11:00+03	27000.00
EFF0E0	2017-07-27 07:35:00+03	133200.00
EFF117	2017-08-09 23:10:00+03	103800.00
EFF153	2017-07-12 17:54:00+03	231300.00
EFF154	2017-07-17 19:55:00+03	14700.00
EFF1BF	2017-07-28 06:28:00+03	13600.00
EFF1C8	2017-08-08 08:55:00+03	80400.00
EFF22D	2017-06-27 09:31:00+03	103200.00
EFF22F	2017-07-04 17:27:00+03	13000.00
EFF298	2017-07-02 03:11:00+03	52900.00
EFF2FC	2017-07-08 13:10:00+03	81600.00
EFF31C	2017-07-01 21:40:00+03	28000.00
EFF3B7	2017-08-13 19:38:00+03	22600.00
EFF3BD	2017-08-09 09:42:00+03	55800.00
EFF3FB	2017-07-28 14:32:00+03	36800.00
EFF43C	2017-07-26 12:10:00+03	66000.00
EFF44B	2017-07-09 17:47:00+03	28000.00
EFF498	2017-07-06 17:05:00+03	192700.00
EFF4A4	2017-08-14 18:12:00+03	113200.00
EFF4AB	2017-07-26 10:26:00+03	34000.00
EFF4D9	2017-07-28 15:14:00+03	236000.00
EFF4EE	2017-07-12 02:59:00+03	112000.00
EFF527	2017-07-05 15:31:00+03	6700.00
EFF538	2017-08-14 16:46:00+03	66600.00
EFF56B	2017-06-24 02:51:00+03	56000.00
EFF57A	2017-07-15 12:47:00+03	69600.00
EFF589	2017-08-15 03:53:00+03	154400.00
EFF600	2017-07-19 20:58:00+03	7300.00
EFF64F	2017-08-10 22:00:00+03	129600.00
EFF6FC	2017-07-05 18:04:00+03	19600.00
EFF708	2017-08-06 18:12:00+03	39100.00
EFF7CD	2017-08-01 12:27:00+03	269300.00
EFF813	2017-07-20 02:46:00+03	24000.00
EFF877	2017-07-17 09:54:00+03	111600.00
EFF87D	2017-07-18 06:24:00+03	21400.00
EFF915	2017-07-30 16:37:00+03	37900.00
EFF95A	2017-08-14 12:11:00+03	258400.00
EFFA26	2017-08-06 06:26:00+03	179500.00
EFFA4A	2017-07-21 05:29:00+03	95200.00
EFFAD2	2017-07-09 14:44:00+03	71900.00
EFFADE	2017-08-07 09:55:00+03	62800.00
EFFAF8	2017-07-31 00:53:00+03	176800.00
EFFB06	2017-08-08 19:22:00+03	47600.00
EFFB15	2017-06-28 15:12:00+03	75600.00
EFFB52	2017-08-14 05:13:00+03	21800.00
EFFB57	2017-08-12 10:56:00+03	272900.00
EFFB9C	2017-07-22 12:40:00+03	56000.00
EFFBE3	2017-07-14 14:23:00+03	91500.00
EFFC31	2017-07-17 05:11:00+03	23200.00
EFFC47	2017-07-09 13:11:00+03	60700.00
EFFC5F	2017-07-04 02:29:00+03	41800.00
EFFC7A	2017-07-15 07:09:00+03	14800.00
EFFCB0	2017-07-11 08:24:00+03	52000.00
EFFD0A	2017-08-09 17:54:00+03	48200.00
EFFD3A	2017-08-07 04:25:00+03	43000.00
EFFDD4	2017-08-07 19:21:00+03	38400.00
EFFE9A	2017-07-17 23:38:00+03	47400.00
EFFEC7	2017-08-14 23:13:00+03	14400.00
EFFEEE	2017-07-23 09:14:00+03	89700.00
EFFEFA	2017-08-12 20:29:00+03	25600.00
F0003B	2017-07-21 04:08:00+03	38600.00
F0004F	2017-07-28 23:36:00+03	131600.00
F000CF	2017-07-25 23:38:00+03	135000.00
F000F3	2017-08-09 14:25:00+03	76800.00
F0011D	2017-07-26 05:03:00+03	64400.00
F00122	2017-07-13 06:51:00+03	47000.00
F00147	2017-08-14 05:32:00+03	152400.00
F00180	2017-06-29 18:10:00+03	57600.00
F001D0	2017-08-11 05:49:00+03	166000.00
F002E7	2017-07-11 09:30:00+03	66600.00
F002E8	2017-07-28 01:52:00+03	13800.00
F0032D	2017-07-31 18:08:00+03	32800.00
F00347	2017-07-26 07:22:00+03	21400.00
F00357	2017-08-15 11:57:00+03	44000.00
F00365	2017-07-05 17:56:00+03	85000.00
F00442	2017-06-30 03:34:00+03	26000.00
F004A8	2017-08-06 10:48:00+03	368800.00
F004EB	2017-07-24 06:10:00+03	31600.00
F0052A	2017-07-06 21:27:00+03	25600.00
F005A0	2017-08-03 20:44:00+03	57600.00
F005D8	2017-07-23 09:05:00+03	36900.00
F00627	2017-07-20 13:33:00+03	62600.00
F00675	2017-07-14 00:08:00+03	132600.00
F007FD	2017-07-04 16:39:00+03	260900.00
F00808	2017-08-15 04:21:00+03	213200.00
F0083E	2017-08-15 00:37:00+03	199800.00
F00849	2017-08-09 07:34:00+03	135600.00
F0084C	2017-07-21 16:59:00+03	70500.00
F00889	2017-08-11 08:01:00+03	43100.00
F008A9	2017-07-15 19:40:00+03	46200.00
F008D5	2017-07-30 02:57:00+03	24600.00
F008F8	2017-07-25 07:27:00+03	87900.00
F00983	2017-07-05 00:49:00+03	38400.00
F00A08	2017-07-31 09:07:00+03	22000.00
F00A3B	2017-08-15 11:16:00+03	31800.00
F00A3C	2017-07-06 10:28:00+03	15000.00
F00A97	2017-08-07 11:25:00+03	20400.00
F00AD0	2017-07-16 14:49:00+03	149200.00
F00ADD	2017-07-24 21:30:00+03	31100.00
F00AF9	2017-07-14 14:31:00+03	56000.00
F00B58	2017-07-23 18:06:00+03	14400.00
F00B8C	2017-08-15 09:05:00+03	48000.00
F00BA9	2017-07-29 16:13:00+03	17000.00
F00BAA	2017-07-11 11:06:00+03	170600.00
F00BDF	2017-08-03 03:43:00+03	25400.00
F00C09	2017-07-26 17:27:00+03	23600.00
F00C0C	2017-07-11 07:19:00+03	40800.00
F00CCC	2017-07-29 20:34:00+03	20400.00
F00D27	2017-08-05 14:56:00+03	9800.00
F00D4E	2017-07-20 00:53:00+03	26000.00
F00D8F	2017-08-09 08:37:00+03	68800.00
F00DBE	2017-07-20 23:05:00+03	6000.00
F00E06	2017-08-10 19:32:00+03	24200.00
F00E3D	2017-07-12 00:28:00+03	159200.00
F00E64	2017-08-11 02:20:00+03	101200.00
F00E75	2017-07-29 18:15:00+03	50600.00
F00E7A	2017-07-28 19:54:00+03	43900.00
F00E8C	2017-07-02 00:06:00+03	265700.00
F00F4C	2017-07-03 02:56:00+03	68000.00
F00F66	2017-07-13 16:24:00+03	38000.00
F00F82	2017-07-02 04:07:00+03	85000.00
F00F9F	2017-07-30 01:19:00+03	40800.00
F0109D	2017-08-04 16:46:00+03	101200.00
F010B9	2017-07-24 07:35:00+03	40800.00
F01156	2017-08-13 03:38:00+03	21000.00
F01168	2017-07-17 01:18:00+03	38800.00
F01171	2017-08-04 01:54:00+03	23200.00
F01185	2017-07-11 21:21:00+03	278200.00
F011C0	2017-07-16 16:21:00+03	28000.00
F011E6	2017-07-26 16:46:00+03	166100.00
F01220	2017-07-12 07:52:00+03	56600.00
F01290	2017-08-09 16:41:00+03	265800.00
F0129F	2017-07-04 04:27:00+03	265800.00
F012BA	2017-08-06 05:40:00+03	125200.00
F012EC	2017-06-30 05:37:00+03	61500.00
F012F2	2017-07-13 06:20:00+03	28600.00
F01380	2017-08-06 00:33:00+03	34000.00
F013BF	2017-07-13 17:15:00+03	74800.00
F013D6	2017-07-23 20:58:00+03	56600.00
F01402	2017-07-31 17:07:00+03	46500.00
F01407	2017-07-11 07:04:00+03	12600.00
F01448	2017-08-14 10:43:00+03	56100.00
F014D4	2017-07-07 05:29:00+03	56000.00
F0150F	2017-08-07 04:03:00+03	26000.00
F01548	2017-08-10 19:26:00+03	89200.00
F015A4	2017-07-20 11:15:00+03	56000.00
F015C7	2017-07-22 05:37:00+03	18300.00
F01685	2017-07-04 16:27:00+03	14000.00
F0175F	2017-07-18 19:31:00+03	32400.00
F01762	2017-08-09 08:32:00+03	179300.00
F017CA	2017-07-26 21:53:00+03	47100.00
F017CB	2017-07-10 19:35:00+03	100400.00
F01832	2017-07-27 10:18:00+03	20200.00
F0185A	2017-08-05 17:26:00+03	21400.00
F018C2	2017-07-13 00:59:00+03	149300.00
F01905	2017-08-04 06:44:00+03	31600.00
F01909	2017-08-14 08:04:00+03	133100.00
F01926	2017-08-12 20:24:00+03	32800.00
F0192F	2017-08-05 19:40:00+03	7400.00
F01940	2017-07-31 18:15:00+03	73600.00
F01A4F	2017-08-05 16:56:00+03	109400.00
F01A71	2017-07-11 05:48:00+03	20200.00
F01AF9	2017-07-19 08:58:00+03	65900.00
F01B38	2017-07-08 01:01:00+03	39500.00
F01B70	2017-08-09 17:14:00+03	6300.00
F01BE9	2017-07-30 19:00:00+03	46500.00
F01C3E	2017-07-25 20:22:00+03	8000.00
F01D0B	2017-07-05 20:09:00+03	14000.00
F01D0E	2017-08-09 03:46:00+03	27200.00
F01DDC	2017-07-13 05:11:00+03	36200.00
F01DF4	2017-08-01 01:52:00+03	24800.00
F01E3A	2017-07-21 01:18:00+03	21400.00
F01E7C	2017-08-06 19:54:00+03	54400.00
F01E82	2017-08-05 06:34:00+03	118400.00
F01EB4	2017-07-11 01:09:00+03	112000.00
F01EF3	2017-07-07 20:32:00+03	26700.00
F01F67	2017-07-22 06:56:00+03	23600.00
F01FA4	2017-07-12 22:02:00+03	17000.00
F01FEA	2017-07-08 07:26:00+03	38400.00
F01FEF	2017-07-13 02:31:00+03	54500.00
F01FF8	2017-08-02 15:53:00+03	23200.00
F02038	2017-07-18 17:48:00+03	51600.00
F02068	2017-07-30 20:35:00+03	64500.00
F020AE	2017-08-08 06:38:00+03	56600.00
F020C6	2017-08-02 09:41:00+03	44500.00
F02133	2017-08-13 07:34:00+03	45100.00
F02154	2017-08-11 00:18:00+03	68800.00
F02173	2017-07-04 23:45:00+03	123000.00
F0219E	2017-07-05 04:22:00+03	46200.00
F021B5	2017-07-04 17:40:00+03	81200.00
F02272	2017-07-21 17:34:00+03	106400.00
F02288	2017-07-18 17:54:00+03	46400.00
F0229B	2017-07-25 17:45:00+03	12000.00
F02358	2017-08-05 05:33:00+03	120000.00
F023E1	2017-07-10 17:05:00+03	39200.00
F023E2	2017-07-02 01:51:00+03	80000.00
F02402	2017-07-27 04:00:00+03	34000.00
F02471	2017-07-31 00:23:00+03	160700.00
F0248B	2017-07-12 03:31:00+03	203000.00
F024AB	2017-08-07 03:14:00+03	29800.00
F024AF	2017-07-05 03:09:00+03	49200.00
F024EE	2017-07-14 07:16:00+03	43500.00
F02562	2017-07-09 10:36:00+03	27200.00
F02567	2017-08-05 16:02:00+03	57400.00
F0257F	2017-08-06 23:46:00+03	185500.00
F02592	2017-07-09 15:55:00+03	131100.00
F025AC	2017-08-14 15:04:00+03	49500.00
F025D8	2017-07-27 08:03:00+03	24700.00
F025E5	2017-07-25 05:26:00+03	187400.00
F0260A	2017-08-05 05:17:00+03	57400.00
F02656	2017-08-09 04:54:00+03	62700.00
F026B2	2017-07-22 00:52:00+03	23200.00
F02732	2017-07-28 09:31:00+03	295400.00
F0273B	2017-07-07 10:45:00+03	68700.00
F0277D	2017-07-10 08:26:00+03	46400.00
F027B7	2017-08-08 16:35:00+03	234700.00
F02833	2017-07-12 21:39:00+03	28000.00
F028A2	2017-08-10 03:36:00+03	57400.00
F029A4	2017-07-09 16:00:00+03	12400.00
F029D2	2017-08-08 22:24:00+03	246000.00
F02A0E	2017-07-18 00:38:00+03	94200.00
F02AF9	2017-07-17 00:41:00+03	28000.00
F02B7F	2017-08-13 09:24:00+03	11000.00
F02C20	2017-06-29 21:58:00+03	24400.00
F02C34	2017-07-03 19:16:00+03	176800.00
F02C3B	2017-08-07 02:48:00+03	62700.00
F02C3E	2017-07-21 08:59:00+03	29600.00
F02D22	2017-07-19 20:59:00+03	58600.00
F02DB8	2017-07-15 10:18:00+03	114300.00
F02E7C	2017-07-21 05:43:00+03	79000.00
F02E8A	2017-08-05 10:51:00+03	8200.00
F02ECC	2017-08-07 14:46:00+03	243600.00
F02F6C	2017-08-12 11:17:00+03	33100.00
F02FB6	2017-07-28 08:05:00+03	52400.00
F02FB9	2017-08-14 09:12:00+03	67200.00
F02FDF	2017-08-11 01:01:00+03	170700.00
F02FFD	2017-07-04 14:15:00+03	160400.00
F0306C	2017-07-16 08:02:00+03	95700.00
F030C7	2017-07-08 23:52:00+03	112000.00
F030CC	2017-07-09 14:17:00+03	7400.00
F0310D	2017-08-13 05:19:00+03	44000.00
F0313A	2017-07-04 23:28:00+03	132800.00
F03252	2017-08-02 13:37:00+03	62000.00
F03272	2017-06-30 12:15:00+03	201200.00
F032F5	2017-07-10 07:53:00+03	16400.00
F0333B	2017-07-07 03:09:00+03	664100.00
F03354	2017-08-05 21:21:00+03	46400.00
F0337F	2017-07-26 00:39:00+03	266400.00
F03384	2017-07-03 14:25:00+03	110500.00
F03386	2017-07-27 06:59:00+03	188100.00
F033B8	2017-08-08 02:08:00+03	105600.00
F033ED	2017-08-05 13:23:00+03	24700.00
F033F4	2017-07-18 17:27:00+03	68800.00
F03414	2017-07-16 20:23:00+03	26000.00
F0341F	2017-07-18 15:27:00+03	28000.00
F0350E	2017-07-22 13:58:00+03	55800.00
F03530	2017-08-11 17:26:00+03	155600.00
F03577	2017-07-30 14:19:00+03	65900.00
F036C8	2017-08-09 23:38:00+03	135400.00
F036E9	2017-06-27 04:48:00+03	125200.00
F03729	2017-07-10 22:25:00+03	84000.00
F03756	2017-07-27 07:01:00+03	38500.00
F03795	2017-08-09 17:58:00+03	243600.00
F037F6	2017-06-25 03:12:00+03	75300.00
F0385E	2017-07-27 02:32:00+03	43200.00
F038D8	2017-07-12 14:10:00+03	28300.00
F03993	2017-08-04 10:05:00+03	52400.00
F03A0D	2017-08-11 06:38:00+03	73600.00
F03A16	2017-07-15 04:08:00+03	54600.00
F03ACE	2017-08-09 10:41:00+03	15900.00
F03AD9	2017-08-07 10:52:00+03	21600.00
F03AFA	2017-08-15 02:29:00+03	36700.00
F03B3F	2017-07-30 05:21:00+03	32700.00
F03B7B	2017-07-28 17:30:00+03	24400.00
F03B83	2017-08-04 06:11:00+03	108900.00
F03B8E	2017-07-06 23:09:00+03	46000.00
F03B90	2017-07-12 07:07:00+03	68000.00
F03BAE	2017-08-01 23:33:00+03	201200.00
F03BFD	2017-07-08 10:42:00+03	25600.00
F03C1D	2017-08-09 05:16:00+03	38800.00
F03CC7	2017-07-17 14:57:00+03	51900.00
F03CC9	2017-07-18 02:16:00+03	522200.00
F03D19	2017-07-14 21:50:00+03	40400.00
F03D3A	2017-07-22 12:12:00+03	20600.00
F03D53	2017-08-14 19:13:00+03	50800.00
F03D9F	2017-08-04 01:14:00+03	14000.00
F03DC0	2017-07-02 22:40:00+03	14000.00
F03DE4	2017-07-14 01:16:00+03	24400.00
F03E1B	2017-07-21 15:54:00+03	23400.00
F03E1E	2017-07-01 20:57:00+03	189100.00
F03E43	2017-07-10 07:26:00+03	47000.00
F03EB5	2017-08-04 06:15:00+03	28000.00
F03F4D	2017-07-24 07:23:00+03	118500.00
F03FA3	2017-07-20 01:33:00+03	59800.00
F03FAF	2017-07-08 08:33:00+03	57400.00
F04013	2017-07-28 14:09:00+03	99200.00
F04032	2017-08-14 13:45:00+03	62900.00
F0407E	2017-08-08 12:41:00+03	27300.00
F04096	2017-07-26 11:29:00+03	19800.00
F040B9	2017-07-11 16:50:00+03	47500.00
F040E1	2017-08-07 07:46:00+03	14000.00
F0410E	2017-07-10 22:17:00+03	63000.00
F04174	2017-07-08 20:46:00+03	68100.00
F041D6	2017-07-12 20:47:00+03	20200.00
F041E0	2017-07-05 04:20:00+03	67300.00
F041FA	2017-08-09 22:46:00+03	62600.00
F0421C	2017-08-13 04:33:00+03	13200.00
F04248	2017-08-05 15:23:00+03	9300.00
F0425B	2017-08-04 03:59:00+03	297000.00
F0425F	2017-07-13 23:35:00+03	179400.00
F042A6	2017-07-26 07:09:00+03	42800.00
F042CC	2017-07-20 00:42:00+03	46400.00
F042DB	2017-07-18 01:07:00+03	92400.00
F042E7	2017-08-09 18:27:00+03	62600.00
F042F0	2017-07-28 21:14:00+03	57600.00
F043EB	2017-08-13 06:44:00+03	39300.00
F04416	2017-08-07 08:57:00+03	394400.00
F04426	2017-07-07 19:25:00+03	81300.00
F0445E	2017-08-05 10:53:00+03	28800.00
F04472	2017-08-14 08:21:00+03	36200.00
F044AF	2017-07-15 19:54:00+03	44100.00
F04524	2017-07-05 00:46:00+03	76400.00
F0452B	2017-08-10 19:55:00+03	181600.00
F045E2	2017-08-07 23:23:00+03	23200.00
F045EE	2017-07-09 19:51:00+03	28800.00
F0466B	2017-08-10 02:49:00+03	69500.00
F0478D	2017-07-01 00:03:00+03	249200.00
F047E3	2017-07-17 06:00:00+03	123000.00
F04816	2017-07-05 16:57:00+03	57600.00
F0482B	2017-07-03 06:06:00+03	45100.00
F0483C	2017-07-21 01:12:00+03	30400.00
F04842	2017-07-01 06:44:00+03	32400.00
F0484B	2017-07-03 15:51:00+03	66600.00
F0484D	2017-08-03 12:46:00+03	148200.00
F04877	2017-07-04 04:20:00+03	25900.00
F0487E	2017-08-01 08:34:00+03	15100.00
F048BB	2017-07-13 14:02:00+03	73300.00
F048D9	2017-07-24 18:59:00+03	25400.00
F04942	2017-07-05 08:46:00+03	59800.00
F0494A	2017-08-04 03:17:00+03	88600.00
F04963	2017-08-03 21:57:00+03	21200.00
F0496D	2017-07-17 01:29:00+03	24300.00
F049AB	2017-07-11 22:17:00+03	49100.00
F049C4	2017-07-07 10:34:00+03	56100.00
F049D8	2017-08-02 16:42:00+03	89500.00
F049E1	2017-07-12 16:29:00+03	68000.00
F049E8	2017-07-24 12:44:00+03	42600.00
F04A0E	2017-07-28 21:55:00+03	39400.00
F04A1D	2017-08-08 03:55:00+03	413400.00
F04A3B	2017-08-14 10:35:00+03	36600.00
F04A5D	2017-08-13 15:46:00+03	23400.00
F04A66	2017-07-04 03:51:00+03	273400.00
F04A8C	2017-07-17 23:36:00+03	23200.00
F04B53	2017-07-25 18:37:00+03	289400.00
F04B63	2017-07-29 20:19:00+03	202100.00
F04C20	2017-07-13 14:38:00+03	129300.00
F04C5E	2017-07-14 22:45:00+03	31600.00
F04C96	2017-07-31 09:54:00+03	32800.00
F04C9C	2017-07-08 17:37:00+03	114500.00
F04CF7	2017-07-12 11:18:00+03	24400.00
F04D7F	2017-07-25 04:55:00+03	16400.00
F04D80	2017-07-15 21:32:00+03	109200.00
F04DC5	2017-07-08 05:59:00+03	40000.00
F04DDD	2017-07-20 16:16:00+03	40200.00
F04DF8	2017-07-23 14:13:00+03	46400.00
F04E3C	2017-07-11 21:36:00+03	169800.00
F04E4E	2017-08-14 20:55:00+03	196800.00
F04E6B	2017-08-12 22:37:00+03	56000.00
F04F9F	2017-08-06 17:14:00+03	25800.00
F04FAF	2017-07-24 14:11:00+03	73600.00
F04FC7	2017-07-29 11:21:00+03	31200.00
F04FFF	2017-08-02 05:07:00+03	46000.00
F0503B	2017-08-13 01:02:00+03	369000.00
F0503F	2017-07-30 06:40:00+03	28800.00
F05089	2017-07-26 00:06:00+03	115600.00
F05143	2017-07-24 23:02:00+03	6800.00
F05148	2017-08-07 07:03:00+03	138900.00
F0514E	2017-08-13 01:08:00+03	55800.00
F05161	2017-06-30 17:44:00+03	89800.00
F0521B	2017-07-20 07:28:00+03	76100.00
F05278	2017-07-03 01:25:00+03	81600.00
F05313	2017-08-15 13:54:00+03	20000.00
F05396	2017-08-04 15:06:00+03	59200.00
F053F3	2017-07-26 01:31:00+03	39800.00
F05436	2017-07-04 03:20:00+03	137600.00
F0543F	2017-06-30 17:33:00+03	168600.00
F05493	2017-07-19 08:00:00+03	123000.00
F05522	2017-07-07 04:57:00+03	23400.00
F055F2	2017-07-04 04:09:00+03	69200.00
F05612	2017-07-18 06:02:00+03	70800.00
F05613	2017-08-06 12:07:00+03	86400.00
F0564F	2017-08-05 12:07:00+03	35600.00
F0567E	2017-08-07 11:23:00+03	51300.00
F056C1	2017-07-13 03:03:00+03	35600.00
F056ED	2017-07-18 23:48:00+03	80900.00
F05700	2017-07-19 06:31:00+03	36600.00
F0575B	2017-07-11 17:56:00+03	28800.00
F05773	2017-07-22 04:06:00+03	32400.00
F057C2	2017-07-19 19:02:00+03	54800.00
F057EE	2017-07-28 22:19:00+03	77700.00
F05808	2017-08-11 05:23:00+03	58000.00
F05848	2017-07-17 07:30:00+03	112600.00
F05875	2017-07-06 23:58:00+03	12600.00
F058EF	2017-08-12 12:31:00+03	50300.00
F0592C	2017-07-23 21:11:00+03	31100.00
F05953	2017-07-23 17:23:00+03	24400.00
F0599D	2017-07-22 23:15:00+03	147200.00
F059C0	2017-07-11 10:03:00+03	282100.00
F05A31	2017-07-18 10:37:00+03	86800.00
F05A36	2017-07-08 11:19:00+03	38600.00
F05A56	2017-07-13 09:34:00+03	93900.00
F05AD8	2017-07-06 20:26:00+03	50200.00
F05B7B	2017-07-17 01:02:00+03	54800.00
F05BCC	2017-07-24 19:40:00+03	112400.00
F05C66	2017-08-07 15:36:00+03	47000.00
F05C6B	2017-07-20 21:06:00+03	21800.00
F05CAE	2017-07-20 12:04:00+03	53600.00
F05CDC	2017-07-15 13:13:00+03	94500.00
F05CEE	2017-08-08 10:38:00+03	111600.00
F05D05	2017-07-25 14:00:00+03	62800.00
F05D5A	2017-07-25 05:55:00+03	12400.00
F05D93	2017-07-09 11:27:00+03	164700.00
F05DCE	2017-07-19 13:42:00+03	82800.00
F05E2B	2017-07-03 06:12:00+03	105100.00
F05EAA	2017-07-15 21:41:00+03	56000.00
F05EAF	2017-07-01 03:15:00+03	47500.00
F05F10	2017-07-14 22:15:00+03	64500.00
F05F3F	2017-07-24 06:25:00+03	72200.00
F05F89	2017-07-10 04:04:00+03	45200.00
F05F8D	2017-08-05 08:11:00+03	22600.00
F05FAF	2017-08-14 01:43:00+03	99200.00
F05FD1	2017-07-12 05:46:00+03	200500.00
F05FFC	2017-07-04 07:05:00+03	139300.00
F0600F	2017-08-05 00:31:00+03	56000.00
F0602D	2017-07-31 05:11:00+03	87800.00
F06039	2017-07-12 15:23:00+03	35600.00
F060CA	2017-07-10 00:27:00+03	25700.00
F0612B	2017-08-09 13:51:00+03	73600.00
F0614C	2017-07-26 18:10:00+03	24400.00
F061C8	2017-06-30 11:25:00+03	227400.00
F061E1	2017-08-06 01:00:00+03	52000.00
F061F0	2017-08-15 05:04:00+03	29600.00
F06274	2017-07-18 20:06:00+03	16400.00
F062AD	2017-07-26 09:44:00+03	54800.00
F062B5	2017-08-09 16:01:00+03	26800.00
F062B6	2017-06-30 10:28:00+03	142400.00
F062EB	2017-08-02 08:15:00+03	6000.00
F06332	2017-07-24 23:12:00+03	133200.00
F0639C	2017-08-13 12:54:00+03	239800.00
F063E1	2017-07-31 09:50:00+03	265600.00
F0648A	2017-08-14 01:06:00+03	169900.00
F06494	2017-07-21 01:10:00+03	6000.00
F064BD	2017-07-17 18:05:00+03	28700.00
F064D7	2017-07-03 05:18:00+03	105500.00
F06568	2017-08-14 05:33:00+03	54400.00
F06571	2017-07-30 04:42:00+03	58000.00
F06572	2017-06-28 11:25:00+03	40000.00
F06584	2017-07-10 20:58:00+03	67600.00
F06651	2017-08-12 15:16:00+03	152500.00
F066A5	2017-07-18 19:24:00+03	29600.00
F066B6	2017-07-06 23:01:00+03	28800.00
F066DC	2017-07-30 10:25:00+03	20200.00
F066E2	2017-07-20 08:27:00+03	174600.00
F066EA	2017-07-10 04:40:00+03	316100.00
F066FA	2017-07-25 07:17:00+03	56000.00
F0676E	2017-07-19 08:09:00+03	39900.00
F067E3	2017-08-13 17:03:00+03	137900.00
F067E5	2017-07-03 08:26:00+03	56000.00
F06818	2017-07-06 20:26:00+03	44100.00
F06889	2017-07-17 23:26:00+03	212900.00
F068AD	2017-07-07 12:29:00+03	56600.00
F068E0	2017-07-14 03:11:00+03	177600.00
F0692F	2017-07-27 01:39:00+03	49600.00
F0693B	2017-07-26 17:25:00+03	82900.00
F0695B	2017-07-26 20:37:00+03	32800.00
F069BA	2017-07-24 22:40:00+03	33200.00
F06A85	2017-07-10 07:13:00+03	44800.00
F06ACF	2017-07-30 13:30:00+03	45000.00
F06AD0	2017-08-06 09:28:00+03	187600.00
F06AF4	2017-07-06 17:32:00+03	14000.00
F06B01	2017-08-11 01:41:00+03	35200.00
F06B20	2017-08-04 08:12:00+03	175200.00
F06B3A	2017-07-08 00:45:00+03	99300.00
F06B3E	2017-07-21 21:38:00+03	54800.00
F06BA1	2017-07-10 09:24:00+03	28800.00
F06C8E	2017-08-07 12:29:00+03	135400.00
F06CDB	2017-08-13 14:54:00+03	135100.00
F06D2D	2017-07-25 15:40:00+03	6000.00
F06DAE	2017-06-30 02:14:00+03	315200.00
F06DC9	2017-07-30 12:57:00+03	73000.00
F06DDD	2017-07-26 12:46:00+03	41600.00
F06E21	2017-07-21 23:55:00+03	99200.00
F06E4F	2017-07-13 01:18:00+03	20200.00
F06EA8	2017-07-28 01:05:00+03	40600.00
F06EF7	2017-07-09 10:33:00+03	91400.00
F06EFB	2017-07-13 18:53:00+03	185800.00
F0701F	2017-07-22 06:11:00+03	31700.00
F07029	2017-07-22 16:25:00+03	40000.00
F0703D	2017-08-15 15:52:00+03	23500.00
F07053	2017-07-19 20:59:00+03	86500.00
F070CD	2017-07-20 01:31:00+03	32700.00
F070E8	2017-07-14 00:28:00+03	198900.00
F071A9	2017-08-07 05:37:00+03	66100.00
F071D6	2017-07-03 07:56:00+03	196900.00
F071F5	2017-08-01 20:52:00+03	92400.00
F07206	2017-07-03 21:52:00+03	113200.00
F0724E	2017-07-11 19:41:00+03	69000.00
F07281	2017-08-02 06:28:00+03	146400.00
F07298	2017-07-21 06:55:00+03	78300.00
F0729A	2017-07-25 22:21:00+03	62700.00
F0733F	2017-07-14 03:37:00+03	138100.00
F073B1	2017-06-29 06:00:00+03	115000.00
F073DC	2017-07-23 19:33:00+03	42400.00
F07406	2017-07-05 16:31:00+03	46000.00
F07439	2017-07-07 16:14:00+03	46300.00
F07477	2017-07-31 19:35:00+03	8000.00
F0747F	2017-07-11 11:58:00+03	142400.00
F07488	2017-06-29 14:40:00+03	117000.00
F074B2	2017-08-10 18:50:00+03	56600.00
F07501	2017-07-04 04:47:00+03	77900.00
F07510	2017-07-19 18:33:00+03	48800.00
F0751A	2017-06-29 01:09:00+03	31600.00
F07580	2017-07-29 18:21:00+03	16400.00
F0758A	2017-06-27 09:28:00+03	24200.00
F07596	2017-07-22 12:04:00+03	133100.00
F075C4	2017-07-24 11:24:00+03	136800.00
F07605	2017-07-20 19:13:00+03	44800.00
F07631	2017-07-02 07:27:00+03	36200.00
F07642	2017-07-17 16:34:00+03	31900.00
F0765E	2017-08-14 15:00:00+03	65900.00
F07695	2017-08-04 18:35:00+03	44800.00
F076CB	2017-07-17 00:22:00+03	133200.00
F07714	2017-07-31 23:23:00+03	34400.00
F07734	2017-08-13 09:20:00+03	20100.00
F07746	2017-07-24 10:37:00+03	35200.00
F077CB	2017-07-29 02:43:00+03	27200.00
F077CD	2017-07-07 21:52:00+03	35200.00
F07889	2017-07-03 00:50:00+03	13400.00
F078E1	2017-07-11 02:16:00+03	24500.00
F0790C	2017-07-25 16:12:00+03	56000.00
F07950	2017-07-24 05:56:00+03	25200.00
F07971	2017-08-05 23:55:00+03	21400.00
F07A60	2017-07-16 17:57:00+03	25200.00
F07AC5	2017-08-05 22:20:00+03	174700.00
F07AE7	2017-07-18 05:07:00+03	50700.00
F07AED	2017-07-26 05:03:00+03	229800.00
F07AF1	2017-07-12 17:44:00+03	25400.00
F07B3E	2017-07-19 11:36:00+03	123000.00
F07B72	2017-07-18 14:48:00+03	123000.00
F07B8D	2017-07-09 03:05:00+03	124200.00
F07BBF	2017-08-05 04:06:00+03	43200.00
F07BC5	2017-07-05 06:30:00+03	66000.00
F07C46	2017-07-29 09:04:00+03	21500.00
F07CDF	2017-07-30 16:31:00+03	14300.00
F07CF1	2017-08-12 12:51:00+03	90800.00
F07D3F	2017-07-24 05:44:00+03	82900.00
F07D79	2017-07-06 16:32:00+03	73200.00
F07DE7	2017-08-14 12:04:00+03	40100.00
F07DEC	2017-07-02 06:07:00+03	28000.00
F07E05	2017-08-11 14:27:00+03	28600.00
F07E06	2017-07-02 03:39:00+03	51900.00
F07E15	2017-08-09 21:13:00+03	66600.00
F07E4E	2017-07-18 07:58:00+03	32200.00
F07E5B	2017-08-05 21:32:00+03	46500.00
F07E5E	2017-07-29 17:20:00+03	6700.00
F07ECA	2017-07-27 10:00:00+03	88000.00
F07ED1	2017-07-27 08:28:00+03	129700.00
F07EE8	2017-08-10 00:12:00+03	92800.00
F07F03	2017-07-10 21:31:00+03	46700.00
F07F21	2017-07-19 11:52:00+03	45100.00
F07F47	2017-08-05 16:01:00+03	42800.00
F07FFD	2017-07-18 07:51:00+03	105600.00
F08024	2017-07-07 13:36:00+03	42800.00
F08032	2017-07-03 06:57:00+03	199700.00
F08040	2017-07-21 09:48:00+03	30400.00
F08076	2017-06-28 11:51:00+03	51900.00
F080DC	2017-07-24 16:40:00+03	24400.00
F080F4	2017-07-22 08:17:00+03	43200.00
F081A9	2017-07-29 19:02:00+03	46200.00
F082B6	2017-08-06 20:28:00+03	384800.00
F082F1	2017-08-09 23:07:00+03	41600.00
F0831E	2017-07-16 21:15:00+03	124200.00
F08331	2017-08-11 05:07:00+03	12200.00
F0833D	2017-07-04 20:02:00+03	22000.00
F0838C	2017-08-14 13:01:00+03	15000.00
F08396	2017-07-14 07:48:00+03	134600.00
F083BF	2017-08-10 17:18:00+03	38600.00
F08411	2017-07-28 09:47:00+03	38200.00
F0841E	2017-08-13 03:15:00+03	122300.00
F08422	2017-08-07 17:45:00+03	50600.00
F0845C	2017-07-25 07:59:00+03	57500.00
F0846D	2017-08-12 08:31:00+03	88600.00
F084BD	2017-07-17 15:48:00+03	26700.00
F0851E	2017-08-08 04:41:00+03	189800.00
F08568	2017-07-07 11:07:00+03	31600.00
F085A5	2017-07-29 16:16:00+03	13400.00
F085AD	2017-08-05 09:35:00+03	62700.00
F085B0	2017-08-08 09:16:00+03	10800.00
F085EA	2017-07-08 14:40:00+03	30200.00
F085EC	2017-07-03 03:21:00+03	31200.00
F085F4	2017-07-15 11:42:00+03	344900.00
F08621	2017-08-11 11:48:00+03	82300.00
F08653	2017-08-05 06:38:00+03	243600.00
F08666	2017-07-25 11:47:00+03	29600.00
F08668	2017-07-16 18:01:00+03	89600.00
F086DE	2017-07-24 16:42:00+03	203000.00
F0875E	2017-07-17 00:34:00+03	6700.00
F08779	2017-07-29 08:41:00+03	97500.00
F087BB	2017-07-13 10:26:00+03	15400.00
F087E8	2017-07-26 17:08:00+03	40300.00
F08852	2017-08-12 01:59:00+03	162500.00
F08865	2017-08-05 09:41:00+03	32400.00
F0889A	2017-07-02 16:41:00+03	26900.00
F0890E	2017-08-02 19:52:00+03	47400.00
F08972	2017-07-05 05:23:00+03	532800.00
F08A3A	2017-08-11 01:22:00+03	24400.00
F08A44	2017-07-21 05:58:00+03	134400.00
F08A88	2017-07-18 06:21:00+03	273600.00
F08B2E	2017-07-22 02:52:00+03	201200.00
F08C98	2017-07-15 20:54:00+03	41600.00
F08CBD	2017-08-14 14:03:00+03	130200.00
F08CDA	2017-07-14 17:33:00+03	31200.00
F08CE8	2017-07-25 23:26:00+03	96800.00
F08D6D	2017-08-10 18:16:00+03	76400.00
F08DF5	2017-07-13 14:43:00+03	35600.00
F08E18	2017-07-18 10:50:00+03	36200.00
F08EEF	2017-07-24 23:59:00+03	23200.00
F08F01	2017-08-10 16:36:00+03	3700.00
F08F07	2017-07-27 20:35:00+03	48500.00
F08F1B	2017-07-11 20:09:00+03	13000.00
F08F8E	2017-07-23 14:57:00+03	43400.00
F08FEE	2017-08-08 19:03:00+03	14400.00
F09032	2017-07-31 02:15:00+03	46400.00
F09071	2017-07-21 01:33:00+03	21800.00
F09116	2017-08-13 05:05:00+03	198400.00
F091F9	2017-07-07 19:49:00+03	25400.00
F0921D	2017-07-26 10:17:00+03	8000.00
F09231	2017-07-01 02:47:00+03	27800.00
F09261	2017-07-18 01:51:00+03	90400.00
F09273	2017-07-17 04:25:00+03	29100.00
F09376	2017-07-16 08:32:00+03	23900.00
F093F6	2017-07-25 07:57:00+03	11000.00
F09428	2017-08-08 02:00:00+03	13400.00
F094AF	2017-07-06 20:22:00+03	23200.00
F094CD	2017-07-22 20:12:00+03	23600.00
F09527	2017-07-29 17:08:00+03	67200.00
F09532	2017-07-19 04:08:00+03	26800.00
F09600	2017-08-09 03:31:00+03	26000.00
F0960E	2017-08-06 12:38:00+03	36600.00
F0964B	2017-07-31 02:11:00+03	22000.00
F096BC	2017-07-10 05:05:00+03	55800.00
F09701	2017-07-30 23:36:00+03	146700.00
F09725	2017-08-08 22:11:00+03	67600.00
F0977C	2017-08-14 14:03:00+03	28300.00
F0978E	2017-07-05 02:11:00+03	132000.00
F09820	2017-08-05 16:54:00+03	129700.00
F098DB	2017-07-14 18:42:00+03	24000.00
F098E4	2017-07-02 21:12:00+03	54800.00
F098F2	2017-07-03 22:15:00+03	131100.00
F09997	2017-08-15 00:38:00+03	29600.00
F099FB	2017-08-13 07:13:00+03	43900.00
F09A39	2017-07-28 10:12:00+03	56900.00
F09A7B	2017-07-14 22:50:00+03	66600.00
F09ABA	2017-07-02 16:33:00+03	35200.00
F09BF6	2017-08-09 23:19:00+03	177200.00
F09CB2	2017-07-23 21:25:00+03	56000.00
F09CB7	2017-07-01 12:53:00+03	27700.00
F09CF4	2017-07-04 13:18:00+03	123000.00
F09D24	2017-07-14 14:22:00+03	48800.00
F09D58	2017-07-12 13:16:00+03	131600.00
F09D6E	2017-07-24 00:54:00+03	136500.00
F09D8B	2017-08-01 10:22:00+03	270200.00
F09DBC	2017-07-13 21:32:00+03	26700.00
F09E83	2017-07-02 05:02:00+03	8200.00
F09E98	2017-07-23 12:47:00+03	14000.00
F09EE8	2017-07-10 22:30:00+03	64800.00
F09EFB	2017-08-05 16:21:00+03	54800.00
F09F0F	2017-07-01 18:55:00+03	22400.00
F09F18	2017-06-29 23:54:00+03	44800.00
F09F21	2017-07-03 04:09:00+03	284400.00
F09F50	2017-06-28 08:18:00+03	56000.00
F09F65	2017-08-04 14:00:00+03	46400.00
F09F84	2017-07-14 12:51:00+03	69500.00
F09FA1	2017-08-04 17:42:00+03	30200.00
F09FA3	2017-07-05 18:59:00+03	63200.00
F09FDB	2017-08-14 03:42:00+03	133200.00
F09FE2	2017-07-06 07:07:00+03	12000.00
F0A029	2017-07-18 08:57:00+03	96800.00
F0A060	2017-07-11 03:05:00+03	46200.00
F0A068	2017-07-13 18:40:00+03	23600.00
F0A08A	2017-07-29 02:16:00+03	36200.00
F0A126	2017-08-02 13:00:00+03	23400.00
F0A148	2017-08-06 16:02:00+03	34200.00
F0A1B8	2017-08-04 06:17:00+03	103200.00
F0A1C3	2017-08-04 15:10:00+03	40800.00
F0A1C7	2017-08-12 16:32:00+03	30200.00
F0A1D2	2017-07-14 23:55:00+03	14000.00
F0A1E7	2017-07-21 15:23:00+03	6000.00
F0A215	2017-07-19 19:39:00+03	385000.00
F0A228	2017-07-22 04:07:00+03	26000.00
F0A286	2017-08-14 02:44:00+03	13400.00
F0A2B6	2017-08-10 06:27:00+03	12600.00
F0A2BA	2017-07-26 21:41:00+03	81200.00
F0A2F1	2017-08-09 12:11:00+03	24700.00
F0A2F5	2017-07-02 03:12:00+03	50800.00
F0A366	2017-07-03 19:07:00+03	101800.00
F0A394	2017-08-08 19:41:00+03	29600.00
F0A3D2	2017-08-09 07:41:00+03	99300.00
F0A3D3	2017-07-27 12:50:00+03	23200.00
F0A410	2017-07-10 15:50:00+03	246000.00
F0A518	2017-07-08 12:55:00+03	6000.00
F0A51A	2017-06-27 01:09:00+03	102200.00
F0A5C8	2017-07-15 09:32:00+03	28000.00
F0A5EC	2017-07-15 10:01:00+03	58000.00
F0A67B	2017-08-15 15:14:00+03	14400.00
F0A67F	2017-07-18 21:48:00+03	281500.00
F0A6AB	2017-07-07 09:03:00+03	55600.00
F0A6F0	2017-07-23 20:11:00+03	27900.00
F0A780	2017-07-20 10:05:00+03	111500.00
F0A7AE	2017-07-03 22:05:00+03	113700.00
F0A7E0	2017-07-13 08:53:00+03	35200.00
F0A88A	2017-07-01 01:47:00+03	65200.00
F0A8A6	2017-08-02 12:47:00+03	98200.00
F0A8CC	2017-06-27 06:41:00+03	26800.00
F0A97C	2017-07-17 15:22:00+03	73600.00
F0A9F9	2017-08-11 09:49:00+03	19800.00
F0AA41	2017-07-20 17:47:00+03	134400.00
F0AA93	2017-07-06 17:59:00+03	89200.00
F0AA94	2017-07-20 11:56:00+03	55800.00
F0AAA1	2017-08-06 19:37:00+03	8200.00
F0AAC6	2017-08-04 01:44:00+03	18100.00
F0AAEB	2017-07-26 23:13:00+03	69600.00
F0AB78	2017-07-12 13:09:00+03	58800.00
F0ABA3	2017-07-19 02:41:00+03	50800.00
F0ABD2	2017-07-12 01:53:00+03	155600.00
F0ABE5	2017-07-19 13:02:00+03	62200.00
F0ABEF	2017-07-17 12:56:00+03	122600.00
F0AC39	2017-07-18 13:53:00+03	88600.00
F0AC5A	2017-07-04 03:20:00+03	141700.00
F0ACDE	2017-07-21 19:12:00+03	47000.00
F0ACF7	2017-07-07 03:15:00+03	30000.00
F0AD1B	2017-08-06 15:04:00+03	532800.00
F0AD5C	2017-07-14 08:25:00+03	57800.00
F0ADDF	2017-07-13 09:29:00+03	8200.00
F0ADF7	2017-07-30 16:54:00+03	123000.00
F0AE59	2017-07-17 12:11:00+03	206600.00
F0AE68	2017-08-01 20:18:00+03	169900.00
F0AE95	2017-07-13 03:37:00+03	136200.00
F0AE9E	2017-07-02 18:39:00+03	7400.00
F0AECB	2017-07-01 17:01:00+03	193600.00
F0AF67	2017-07-28 21:20:00+03	166000.00
F0AF76	2017-07-10 21:37:00+03	87700.00
F0AF7D	2017-07-13 04:38:00+03	67200.00
F0AFA0	2017-07-25 02:16:00+03	135600.00
F0AFAC	2017-08-02 17:11:00+03	243700.00
F0AFAF	2017-07-27 12:03:00+03	159800.00
F0B115	2017-08-08 05:54:00+03	32900.00
F0B125	2017-08-03 23:36:00+03	23600.00
F0B1CB	2017-07-25 06:17:00+03	28000.00
F0B239	2017-07-23 04:23:00+03	23600.00
F0B2F9	2017-07-02 15:47:00+03	30200.00
F0B33F	2017-07-27 05:48:00+03	41600.00
F0B388	2017-07-31 15:27:00+03	134200.00
F0B399	2017-07-15 07:51:00+03	399600.00
F0B407	2017-07-07 23:15:00+03	6300.00
F0B503	2017-07-16 11:04:00+03	69500.00
F0B51D	2017-07-25 13:59:00+03	43200.00
F0B522	2017-07-20 13:24:00+03	21200.00
F0B64A	2017-07-01 07:08:00+03	14400.00
F0B67E	2017-07-12 22:33:00+03	18000.00
F0B6CE	2017-07-18 13:46:00+03	56200.00
F0B6ED	2017-07-19 05:51:00+03	57400.00
F0B711	2017-07-22 11:29:00+03	66300.00
F0B754	2017-08-05 09:28:00+03	23200.00
F0B774	2017-07-27 23:44:00+03	41600.00
F0B7CD	2017-08-10 15:00:00+03	35200.00
F0B80E	2017-07-27 03:32:00+03	34000.00
F0B82D	2017-08-04 20:44:00+03	65900.00
F0B867	2017-07-14 20:23:00+03	66800.00
F0B879	2017-07-06 15:32:00+03	31600.00
F0B8EA	2017-08-12 20:27:00+03	26200.00
F0B94B	2017-07-27 13:50:00+03	146000.00
F0B965	2017-07-27 12:15:00+03	26000.00
F0B9BD	2017-07-28 04:33:00+03	171400.00
F0B9D1	2017-07-18 18:33:00+03	199200.00
F0BA13	2017-07-22 16:23:00+03	60700.00
F0BA3A	2017-07-27 17:54:00+03	133700.00
F0BA84	2017-08-12 13:51:00+03	168000.00
F0BA97	2017-07-31 18:01:00+03	67600.00
F0BAD9	2017-07-16 18:55:00+03	26800.00
F0BBA4	2017-08-04 05:22:00+03	54500.00
F0BBD4	2017-07-26 04:50:00+03	47000.00
F0BC00	2017-07-19 13:31:00+03	52400.00
F0BC15	2017-08-07 13:09:00+03	30200.00
F0BC3D	2017-07-28 19:54:00+03	6800.00
F0BCCC	2017-08-05 00:47:00+03	15000.00
F0BD20	2017-07-30 05:32:00+03	70700.00
F0BDE1	2017-07-25 10:12:00+03	13200.00
F0BDFC	2017-08-14 23:12:00+03	21800.00
F0BE07	2017-07-17 04:46:00+03	37200.00
F0BE0F	2017-07-20 08:32:00+03	26800.00
F0BE2A	2017-07-08 19:34:00+03	31200.00
F0BE34	2017-08-13 03:05:00+03	152000.00
F0BE36	2017-07-04 02:46:00+03	28700.00
F0BE45	2017-08-01 17:53:00+03	52700.00
F0BEE1	2017-08-02 02:45:00+03	65900.00
F0BF07	2017-08-06 14:58:00+03	11600.00
F0BFA0	2017-07-08 22:11:00+03	44000.00
F0BFA4	2017-07-28 03:37:00+03	50100.00
F0C01A	2017-07-22 20:49:00+03	28800.00
F0C022	2017-08-08 13:54:00+03	91800.00
F0C098	2017-07-27 16:00:00+03	26000.00
F0C1CB	2017-07-26 07:22:00+03	26800.00
F0C1F8	2017-07-30 09:59:00+03	67600.00
F0C247	2017-07-08 08:39:00+03	46000.00
F0C250	2017-07-28 20:52:00+03	115800.00
F0C25A	2017-07-08 00:47:00+03	24400.00
F0C2AB	2017-08-12 14:06:00+03	260900.00
F0C2C5	2017-07-31 07:26:00+03	28000.00
F0C2D0	2017-08-14 17:21:00+03	47500.00
F0C2EB	2017-08-15 11:06:00+03	25600.00
F0C38F	2017-06-28 14:41:00+03	63800.00
F0C464	2017-08-10 03:48:00+03	8000.00
F0C4F1	2017-08-04 06:02:00+03	64700.00
F0C521	2017-07-11 22:08:00+03	51900.00
F0C52E	2017-08-08 05:23:00+03	69900.00
F0C58E	2017-07-20 23:50:00+03	84500.00
F0C6A0	2017-06-27 17:15:00+03	22200.00
F0C6A1	2017-07-12 14:13:00+03	198600.00
F0C6CA	2017-07-07 11:02:00+03	116800.00
F0C6D2	2017-07-08 08:34:00+03	36800.00
F0C6E7	2017-07-29 16:09:00+03	46700.00
F0C6F9	2017-08-12 20:50:00+03	54000.00
F0C739	2017-07-21 04:39:00+03	38400.00
F0C812	2017-08-05 02:30:00+03	51900.00
F0C85D	2017-07-20 17:34:00+03	62600.00
F0C88F	2017-06-29 02:08:00+03	52900.00
F0C8A0	2017-07-20 11:57:00+03	266200.00
F0C8D6	2017-08-15 10:00:00+03	278500.00
F0C8EB	2017-07-05 13:10:00+03	53600.00
F0C937	2017-08-02 17:44:00+03	50600.00
F0C9EB	2017-07-21 07:05:00+03	89700.00
F0CA84	2017-08-01 16:23:00+03	58200.00
F0CB00	2017-07-23 03:29:00+03	29200.00
F0CB24	2017-07-11 15:16:00+03	292800.00
F0CB69	2017-07-30 21:41:00+03	139400.00
F0CB99	2017-07-21 21:17:00+03	23400.00
F0CBAC	2017-07-14 21:18:00+03	111600.00
F0CC36	2017-08-10 22:04:00+03	291200.00
F0CC71	2017-08-10 00:55:00+03	139300.00
F0CC97	2017-08-15 04:40:00+03	101200.00
F0CCA6	2017-08-10 02:00:00+03	73200.00
F0CCB8	2017-07-04 12:22:00+03	131600.00
F0CCC8	2017-08-02 09:19:00+03	30000.00
F0CD3B	2017-08-15 16:19:00+03	37200.00
F0CD47	2017-07-10 09:28:00+03	32600.00
F0CD5C	2017-08-07 00:09:00+03	26100.00
F0CDA1	2017-06-30 10:41:00+03	23200.00
F0CDDA	2017-08-14 16:19:00+03	4000.00
F0CDE3	2017-07-29 11:35:00+03	55800.00
F0CE31	2017-07-23 01:58:00+03	73600.00
F0CE43	2017-07-21 13:50:00+03	29600.00
F0CE4F	2017-07-09 10:33:00+03	61800.00
F0CE5E	2017-07-08 21:16:00+03	33000.00
F0CE73	2017-07-13 14:23:00+03	14000.00
F0CF47	2017-08-11 10:36:00+03	137600.00
F0CF64	2017-07-26 08:58:00+03	44800.00
F0CFA8	2017-08-06 06:10:00+03	23200.00
F0CFF0	2017-07-25 10:40:00+03	56000.00
F0D080	2017-08-09 23:32:00+03	81300.00
F0D087	2017-08-04 14:18:00+03	97900.00
F0D0C1	2017-07-08 04:22:00+03	55800.00
F0D0E4	2017-07-31 02:20:00+03	62100.00
F0D148	2017-08-02 08:46:00+03	27900.00
F0D152	2017-07-25 16:56:00+03	32800.00
F0D16B	2017-07-07 22:38:00+03	11600.00
F0D181	2017-07-20 09:51:00+03	46000.00
F0D1C3	2017-08-12 14:49:00+03	66000.00
F0D259	2017-07-12 00:59:00+03	103700.00
F0D3CF	2017-07-11 10:39:00+03	168000.00
F0D42A	2017-08-14 20:23:00+03	38400.00
F0D48D	2017-06-30 02:34:00+03	23200.00
F0D490	2017-07-07 18:10:00+03	7300.00
F0D495	2017-07-16 23:55:00+03	56000.00
F0D544	2017-07-19 11:04:00+03	37900.00
F0D556	2017-08-11 18:15:00+03	123000.00
F0D61F	2017-08-07 13:36:00+03	113900.00
F0D63F	2017-07-15 00:31:00+03	63300.00
F0D654	2017-08-04 02:12:00+03	14400.00
F0D67D	2017-07-16 17:17:00+03	37900.00
F0D69D	2017-07-31 08:07:00+03	9800.00
F0D707	2017-08-14 08:01:00+03	260900.00
F0D729	2017-07-13 21:46:00+03	81900.00
F0D740	2017-07-05 04:06:00+03	99200.00
F0D849	2017-07-26 01:13:00+03	47800.00
F0D84D	2017-07-02 19:15:00+03	28000.00
F0D895	2017-07-22 17:48:00+03	44800.00
F0D8A3	2017-07-21 11:02:00+03	58000.00
F0D8A4	2017-07-23 10:04:00+03	95200.00
F0D8A9	2017-07-10 00:47:00+03	48100.00
F0D8D1	2017-08-09 00:38:00+03	6700.00
F0D8D9	2017-07-26 23:21:00+03	27800.00
F0D8E9	2017-07-19 09:54:00+03	52000.00
F0D99B	2017-07-07 02:23:00+03	36200.00
F0D9D7	2017-07-11 00:35:00+03	27900.00
F0DA15	2017-08-09 11:19:00+03	115600.00
F0DA75	2017-08-03 01:11:00+03	56000.00
F0DA8A	2017-07-26 05:44:00+03	24700.00
F0DACC	2017-07-16 16:37:00+03	12600.00
F0DADE	2017-07-30 20:14:00+03	16400.00
F0DAEE	2017-08-04 04:24:00+03	249100.00
F0DB5D	2017-08-06 02:24:00+03	128800.00
F0DB70	2017-07-11 16:13:00+03	129700.00
F0DBD0	2017-08-04 06:33:00+03	43800.00
F0DBF0	2017-08-03 11:07:00+03	119500.00
F0DC1B	2017-07-28 23:28:00+03	7200.00
F0DC42	2017-08-09 13:29:00+03	76200.00
F0DC44	2017-08-09 20:02:00+03	39300.00
F0DC45	2017-07-23 15:48:00+03	6300.00
F0DC49	2017-07-08 09:01:00+03	55800.00
F0DCAC	2017-07-19 12:53:00+03	96300.00
F0DCB7	2017-07-09 12:43:00+03	54800.00
F0DD94	2017-08-08 19:38:00+03	30200.00
F0DDCB	2017-07-24 22:55:00+03	44100.00
F0DDDB	2017-08-12 18:13:00+03	17600.00
F0DE1B	2017-07-04 12:52:00+03	12600.00
F0DE6C	2017-07-25 04:12:00+03	90400.00
F0DE8C	2017-07-14 01:09:00+03	13000.00
F0DE9C	2017-08-13 12:10:00+03	32200.00
F0DECE	2017-08-02 15:13:00+03	99700.00
F0DF45	2017-07-23 06:11:00+03	59900.00
F0DF6C	2017-08-03 01:51:00+03	53400.00
F0DF9D	2017-07-17 03:50:00+03	27900.00
F0E035	2017-07-19 20:24:00+03	27200.00
F0E16F	2017-07-24 14:02:00+03	109000.00
F0E183	2017-08-06 19:49:00+03	28800.00
F0E187	2017-07-16 22:27:00+03	64800.00
F0E297	2017-07-20 14:34:00+03	167500.00
F0E2A1	2017-07-23 13:37:00+03	87000.00
F0E36A	2017-08-10 17:45:00+03	31500.00
F0E3A0	2017-07-04 12:35:00+03	29100.00
F0E3AA	2017-07-12 02:09:00+03	48800.00
F0E3E9	2017-08-12 05:51:00+03	27200.00
F0E491	2017-07-04 18:28:00+03	47000.00
F0E4F1	2017-08-05 01:14:00+03	120900.00
F0E4F4	2017-08-03 00:28:00+03	27400.00
F0E565	2017-07-28 17:56:00+03	75600.00
F0E5F0	2017-08-04 01:55:00+03	47400.00
F0E635	2017-07-16 06:45:00+03	59400.00
F0E63A	2017-07-04 06:35:00+03	89700.00
F0E6B7	2017-07-12 20:47:00+03	89600.00
F0E6EB	2017-08-09 06:01:00+03	36200.00
F0E70F	2017-08-03 11:16:00+03	38500.00
F0E878	2017-07-13 11:07:00+03	106900.00
F0E879	2017-07-06 02:40:00+03	133100.00
F0E87A	2017-07-27 15:10:00+03	74800.00
F0E89D	2017-08-13 12:21:00+03	38600.00
F0E8D7	2017-08-14 01:46:00+03	243700.00
F0E940	2017-08-01 05:38:00+03	155500.00
F0E993	2017-07-08 18:05:00+03	26800.00
F0E9A4	2017-08-01 16:08:00+03	24400.00
F0E9E3	2017-07-20 17:05:00+03	27300.00
F0EA44	2017-08-02 15:30:00+03	68800.00
F0EAA6	2017-08-01 05:15:00+03	53300.00
F0EAAB	2017-08-03 04:34:00+03	119800.00
F0EB27	2017-07-09 14:25:00+03	131800.00
F0EB41	2017-08-01 07:07:00+03	49800.00
F0EB6C	2017-08-01 15:55:00+03	125400.00
F0EBD1	2017-07-13 23:58:00+03	28800.00
F0EC22	2017-08-12 13:22:00+03	68100.00
F0ECB0	2017-08-15 01:04:00+03	95700.00
F0ED2A	2017-07-25 05:36:00+03	94100.00
F0ED8F	2017-07-20 23:17:00+03	67100.00
F0ED92	2017-08-04 11:27:00+03	128800.00
F0EE0F	2017-07-27 03:42:00+03	12000.00
F0EE49	2017-07-06 21:33:00+03	67400.00
F0EEE2	2017-07-17 19:04:00+03	47100.00
F0EF25	2017-07-22 15:59:00+03	114900.00
F0EF31	2017-07-16 18:16:00+03	24400.00
F0EF3F	2017-07-18 05:06:00+03	135000.00
F0EF6B	2017-07-19 14:45:00+03	128800.00
F0F017	2017-07-24 08:14:00+03	85300.00
F0F075	2017-07-04 04:30:00+03	46000.00
F0F0A8	2017-07-09 13:15:00+03	28000.00
F0F0C7	2017-07-29 16:42:00+03	31900.00
F0F0E7	2017-07-15 17:03:00+03	398500.00
F0F10A	2017-07-12 16:27:00+03	36200.00
F0F123	2017-07-20 11:48:00+03	42400.00
F0F13C	2017-08-14 22:58:00+03	111900.00
F0F18D	2017-08-10 18:32:00+03	34800.00
F0F19B	2017-07-17 22:35:00+03	6000.00
F0F1A6	2017-07-22 16:45:00+03	37700.00
F0F238	2017-08-12 08:13:00+03	86700.00
F0F29B	2017-08-07 04:07:00+03	46400.00
F0F29F	2017-07-11 22:02:00+03	20600.00
F0F2C0	2017-07-03 21:00:00+03	26000.00
F0F330	2017-08-07 17:29:00+03	484300.00
F0F357	2017-07-25 19:17:00+03	36800.00
F0F3AB	2017-07-07 22:31:00+03	38800.00
F0F3BF	2017-07-02 19:05:00+03	50000.00
F0F443	2017-07-19 19:46:00+03	399600.00
F0F4A2	2017-06-30 20:51:00+03	10100.00
F0F4CF	2017-07-30 21:07:00+03	24400.00
F0F4D3	2017-07-26 04:27:00+03	18000.00
F0F525	2017-07-03 22:29:00+03	112100.00
F0F580	2017-07-25 17:24:00+03	244100.00
F0F5BD	2017-07-18 01:28:00+03	59300.00
F0F5D8	2017-08-13 12:04:00+03	27800.00
F0F63E	2017-07-08 08:52:00+03	266400.00
F0F68F	2017-07-09 07:54:00+03	66600.00
F0F6BE	2017-07-05 05:46:00+03	56000.00
F0F6FD	2017-08-12 06:48:00+03	53800.00
F0F70D	2017-08-08 13:58:00+03	28800.00
F0F73B	2017-07-02 05:30:00+03	67600.00
F0F74F	2017-08-10 00:36:00+03	198300.00
F0F79C	2017-07-14 14:17:00+03	185700.00
F0F7D2	2017-07-20 06:51:00+03	15700.00
F0F816	2017-07-26 18:10:00+03	152900.00
F0F834	2017-07-29 09:55:00+03	24400.00
F0F866	2017-07-14 22:54:00+03	179500.00
F0F8F7	2017-08-09 14:44:00+03	57400.00
F0F96A	2017-07-03 17:20:00+03	20800.00
F0F96C	2017-08-14 19:28:00+03	13600.00
F0FA52	2017-07-21 07:18:00+03	67600.00
F0FAC3	2017-07-13 14:24:00+03	226200.00
F0FB00	2017-08-08 20:06:00+03	140500.00
F0FB8F	2017-07-26 22:40:00+03	23400.00
F0FBCA	2017-07-16 22:20:00+03	84800.00
F0FC08	2017-07-05 10:00:00+03	85700.00
F0FC14	2017-07-04 21:32:00+03	209700.00
F0FC6C	2017-08-06 04:10:00+03	29200.00
F0FC7D	2017-07-27 08:07:00+03	6800.00
F0FD3E	2017-08-03 06:09:00+03	51900.00
F0FD73	2017-07-26 22:57:00+03	73300.00
F0FDDC	2017-08-04 10:17:00+03	48700.00
F0FE07	2017-07-16 08:04:00+03	68800.00
F0FE0C	2017-07-22 03:11:00+03	110300.00
F0FEDD	2017-07-30 20:31:00+03	75600.00
F0FEEB	2017-07-05 22:44:00+03	66600.00
F0FF6C	2017-07-14 22:49:00+03	81500.00
F0FF8F	2017-08-06 02:08:00+03	98400.00
F10030	2017-08-02 12:25:00+03	40400.00
F100A3	2017-08-04 03:19:00+03	393800.00
F100EB	2017-08-15 02:24:00+03	88500.00
F10150	2017-08-01 08:18:00+03	89200.00
F101BF	2017-08-15 11:23:00+03	78500.00
F101E5	2017-07-15 14:50:00+03	56000.00
F1022A	2017-07-12 08:41:00+03	74300.00
F10327	2017-08-06 23:47:00+03	110500.00
F10334	2017-07-04 01:57:00+03	111600.00
F10375	2017-07-29 18:06:00+03	34000.00
F10384	2017-07-12 08:44:00+03	21200.00
F10446	2017-08-11 11:52:00+03	101200.00
F10453	2017-07-21 22:34:00+03	32800.00
F1045B	2017-07-24 10:31:00+03	324500.00
F10574	2017-07-15 15:40:00+03	210600.00
F1058F	2017-08-09 13:17:00+03	57600.00
F10690	2017-07-15 18:29:00+03	55800.00
F106A0	2017-07-07 04:30:00+03	52900.00
F106CF	2017-07-08 19:15:00+03	46400.00
F107B7	2017-07-23 06:20:00+03	66600.00
F10831	2017-07-21 09:43:00+03	30200.00
F10833	2017-08-07 13:07:00+03	82900.00
F10885	2017-08-02 11:12:00+03	56000.00
F108A8	2017-07-05 14:55:00+03	266400.00
F108B7	2017-07-16 14:50:00+03	58600.00
F108C1	2017-08-07 07:10:00+03	11600.00
F108E4	2017-07-22 23:57:00+03	50600.00
F1091F	2017-07-10 10:06:00+03	131600.00
F10937	2017-07-04 21:39:00+03	34000.00
F10951	2017-07-14 18:44:00+03	133900.00
F10981	2017-08-14 20:50:00+03	243700.00
F109B3	2017-07-14 04:27:00+03	55800.00
F109E3	2017-07-08 19:22:00+03	46700.00
F10A39	2017-08-07 22:15:00+03	53600.00
F10A49	2017-07-15 10:18:00+03	40100.00
F10A61	2017-08-04 08:32:00+03	48900.00
F10B1E	2017-07-09 22:25:00+03	35400.00
F10B94	2017-08-03 19:12:00+03	87200.00
F10B9F	2017-08-08 21:50:00+03	39800.00
F10BF1	2017-08-14 07:24:00+03	28800.00
F10C20	2017-07-23 12:44:00+03	32800.00
F10C5C	2017-07-06 08:32:00+03	31600.00
F10C6D	2017-08-08 14:58:00+03	35500.00
F10C86	2017-07-21 08:12:00+03	54500.00
F10C9B	2017-07-29 18:27:00+03	38100.00
F10CC3	2017-07-11 14:20:00+03	25000.00
F10D57	2017-07-26 11:40:00+03	23600.00
F10E18	2017-08-06 21:21:00+03	141000.00
F10E30	2017-07-29 07:20:00+03	23600.00
F10E60	2017-07-02 00:12:00+03	35800.00
F10E8A	2017-07-27 13:25:00+03	68000.00
F10F22	2017-07-18 13:17:00+03	125600.00
F10F4E	2017-07-29 16:20:00+03	77000.00
F10F5F	2017-07-06 19:16:00+03	75300.00
F10F6E	2017-07-30 01:31:00+03	18000.00
F1102B	2017-08-05 10:33:00+03	27200.00
F11074	2017-08-12 05:59:00+03	40600.00
F1113C	2017-07-02 10:45:00+03	38700.00
F11153	2017-07-20 01:33:00+03	108000.00
F1115C	2017-07-30 03:16:00+03	64700.00
F11207	2017-07-15 17:12:00+03	34000.00
F11211	2017-07-06 08:36:00+03	123000.00
F1124B	2017-08-04 08:16:00+03	54800.00
F112F9	2017-07-10 03:37:00+03	69600.00
F11350	2017-07-15 21:23:00+03	18500.00
F1135C	2017-07-29 14:15:00+03	128800.00
F113FA	2017-07-11 15:20:00+03	30800.00
F1140F	2017-07-28 23:19:00+03	122500.00
F1142B	2017-07-05 23:22:00+03	23200.00
F11441	2017-07-12 18:49:00+03	38800.00
F1146A	2017-07-25 09:35:00+03	386400.00
F114BC	2017-08-10 15:55:00+03	22000.00
F114E1	2017-07-08 18:14:00+03	23600.00
F11565	2017-07-02 16:07:00+03	246000.00
F115C5	2017-07-08 19:44:00+03	61600.00
F115CC	2017-08-08 01:13:00+03	43200.00
F115F8	2017-08-07 20:35:00+03	100600.00
F11727	2017-07-18 01:24:00+03	23200.00
F117B2	2017-07-04 13:52:00+03	24000.00
F117BF	2017-07-16 15:41:00+03	12400.00
F117F8	2017-07-08 11:44:00+03	28000.00
F118CC	2017-07-08 12:26:00+03	116800.00
F1190B	2017-08-15 10:12:00+03	18400.00
F1191D	2017-07-05 01:48:00+03	43100.00
F11A89	2017-07-27 17:26:00+03	56100.00
F11AEF	2017-07-11 20:02:00+03	174000.00
F11AFD	2017-08-06 00:42:00+03	111600.00
F11B31	2017-08-09 04:59:00+03	24000.00
F11B39	2017-08-06 20:24:00+03	68900.00
F11B89	2017-07-27 14:35:00+03	193300.00
F11C2D	2017-07-28 10:34:00+03	72800.00
F11C35	2017-08-04 01:16:00+03	114400.00
F11C56	2017-07-12 03:46:00+03	27300.00
F11C7C	2017-08-07 06:49:00+03	173400.00
F11D44	2017-08-06 19:38:00+03	8000.00
F11D58	2017-08-06 05:00:00+03	16400.00
F11E00	2017-07-23 09:41:00+03	49400.00
F11E2A	2017-07-12 10:38:00+03	28300.00
F11E86	2017-07-12 09:20:00+03	26000.00
F11EE8	2017-07-13 07:30:00+03	516800.00
F11EEE	2017-07-01 20:37:00+03	75600.00
F11F23	2017-07-18 15:05:00+03	50800.00
F11F52	2017-06-30 01:44:00+03	54600.00
F11FA9	2017-07-24 01:13:00+03	39800.00
F11FD0	2017-08-05 20:21:00+03	113800.00
F11FD1	2017-07-13 09:10:00+03	28000.00
F11FF9	2017-08-06 15:33:00+03	29000.00
F12024	2017-08-14 04:53:00+03	47400.00
F1202B	2017-08-05 15:20:00+03	154500.00
F120DC	2017-08-02 07:27:00+03	89700.00
F120F7	2017-08-14 13:26:00+03	55700.00
F121DF	2017-07-20 00:21:00+03	36200.00
F1226D	2017-08-14 06:40:00+03	29600.00
F1227D	2017-08-14 21:07:00+03	75300.00
F122B0	2017-07-06 16:20:00+03	81900.00
F122F9	2017-07-06 05:44:00+03	73500.00
F1232E	2017-08-08 12:05:00+03	57500.00
F12409	2017-07-15 10:19:00+03	14400.00
F12411	2017-08-08 19:25:00+03	85200.00
F1241E	2017-07-31 08:02:00+03	42000.00
F12496	2017-07-24 00:24:00+03	144900.00
F124AE	2017-07-30 04:56:00+03	98600.00
F124F2	2017-08-05 20:14:00+03	80000.00
F1250E	2017-08-12 18:59:00+03	36200.00
F125E3	2017-07-29 10:18:00+03	410500.00
F125F6	2017-08-14 04:50:00+03	57600.00
F12604	2017-07-03 21:27:00+03	169300.00
F12620	2017-07-10 00:13:00+03	87500.00
F12626	2017-07-07 13:02:00+03	58000.00
F12662	2017-07-10 15:13:00+03	131600.00
F1266A	2017-08-15 07:29:00+03	201800.00
F126CB	2017-07-11 00:20:00+03	72400.00
F126FE	2017-07-05 01:21:00+03	52000.00
F12740	2017-07-12 21:34:00+03	134400.00
F127BA	2017-08-10 06:24:00+03	88500.00
F127D0	2017-07-09 02:15:00+03	62600.00
F128B6	2017-07-17 17:32:00+03	111600.00
F12915	2017-07-12 06:57:00+03	28000.00
F1292B	2017-07-22 22:49:00+03	24800.00
F12947	2017-08-05 19:27:00+03	26200.00
F1294B	2017-08-14 01:16:00+03	107500.00
F129C9	2017-07-13 04:33:00+03	32800.00
F129F5	2017-08-04 18:46:00+03	180800.00
F12A56	2017-07-15 05:08:00+03	83000.00
F12A67	2017-08-01 10:11:00+03	57500.00
F12A9D	2017-08-07 03:13:00+03	97700.00
F12AB5	2017-08-09 17:15:00+03	181100.00
F12B16	2017-07-29 12:44:00+03	64800.00
F12B96	2017-07-20 21:45:00+03	32800.00
F12B98	2017-07-09 14:23:00+03	47600.00
F12C2C	2017-07-24 17:26:00+03	40000.00
F12CEA	2017-07-02 21:31:00+03	45500.00
F12D12	2017-08-06 21:13:00+03	29200.00
F12D23	2017-07-31 00:21:00+03	28000.00
F12D29	2017-07-12 01:01:00+03	31400.00
F12D3F	2017-07-30 04:27:00+03	55800.00
F12D4D	2017-07-13 10:33:00+03	20200.00
F12D85	2017-07-11 03:39:00+03	57800.00
F12DD1	2017-07-17 03:54:00+03	24400.00
F12DEE	2017-07-23 01:22:00+03	28800.00
F12E32	2017-07-31 12:45:00+03	62400.00
F12E62	2017-08-14 10:36:00+03	50800.00
F12E73	2017-07-26 19:28:00+03	205600.00
F12EE5	2017-07-23 11:56:00+03	56900.00
F12EEB	2017-07-10 12:18:00+03	55800.00
F12F99	2017-07-27 14:12:00+03	40800.00
F13031	2017-07-20 06:24:00+03	532800.00
F1309C	2017-07-19 06:18:00+03	36000.00
F130D9	2017-08-04 02:55:00+03	167400.00
F13171	2017-07-10 09:16:00+03	36200.00
F13221	2017-07-20 12:50:00+03	123000.00
F13263	2017-06-28 17:04:00+03	57300.00
F13276	2017-07-21 13:50:00+03	109800.00
F1328B	2017-07-12 22:42:00+03	27800.00
F1329C	2017-08-12 21:33:00+03	170700.00
F132C1	2017-08-04 17:58:00+03	280000.00
F132F9	2017-07-14 02:06:00+03	55800.00
F13383	2017-07-20 00:41:00+03	262200.00
F133B5	2017-07-11 06:41:00+03	133600.00
F13437	2017-08-08 10:59:00+03	39200.00
F13451	2017-06-29 18:19:00+03	46400.00
F134AC	2017-07-08 21:18:00+03	38600.00
F1350E	2017-08-03 12:36:00+03	100000.00
F13516	2017-07-12 00:09:00+03	23200.00
F1358D	2017-07-07 07:39:00+03	42900.00
F13674	2017-07-29 11:23:00+03	130400.00
F136AA	2017-07-16 22:18:00+03	39000.00
F136BA	2017-07-21 19:37:00+03	259100.00
F1370F	2017-07-11 17:46:00+03	161800.00
F13723	2017-08-09 05:39:00+03	68100.00
F1374C	2017-07-21 07:04:00+03	168700.00
F13756	2017-07-14 12:56:00+03	16400.00
F13788	2017-07-23 11:50:00+03	76600.00
F13837	2017-07-27 08:46:00+03	75600.00
F13876	2017-07-14 21:28:00+03	22000.00
F138B2	2017-08-15 11:25:00+03	44000.00
F138D0	2017-07-12 00:34:00+03	56000.00
F13925	2017-07-28 18:58:00+03	46400.00
F139BA	2017-08-11 09:18:00+03	15900.00
F139CF	2017-07-10 15:18:00+03	36200.00
F139D3	2017-07-01 00:00:00+03	375200.00
F139E6	2017-08-10 07:42:00+03	55600.00
F13A1D	2017-07-16 15:45:00+03	125200.00
F13A24	2017-07-19 19:14:00+03	16400.00
F13A37	2017-07-31 09:10:00+03	190400.00
F13A40	2017-07-27 22:29:00+03	132800.00
F13ACD	2017-07-08 00:56:00+03	135000.00
F13AF4	2017-06-25 12:30:00+03	56900.00
F13B3D	2017-07-06 19:35:00+03	56100.00
F13B4C	2017-08-01 04:59:00+03	20900.00
F13B91	2017-08-10 22:07:00+03	72400.00
F13B9A	2017-07-28 13:54:00+03	28000.00
F13BE7	2017-08-08 23:32:00+03	124200.00
F13BFB	2017-07-30 20:48:00+03	340600.00
F13C2F	2017-07-16 17:50:00+03	147500.00
F13D02	2017-07-10 21:59:00+03	58600.00
F13D57	2017-07-27 11:05:00+03	28800.00
F13D91	2017-06-27 09:08:00+03	38800.00
F13E82	2017-07-04 20:11:00+03	24200.00
F13E87	2017-07-24 18:46:00+03	12600.00
F13F13	2017-06-30 17:04:00+03	75000.00
F13FA4	2017-07-13 03:59:00+03	131600.00
F13FD2	2017-08-14 05:00:00+03	21800.00
F14050	2017-07-31 07:53:00+03	38400.00
F14074	2017-08-11 16:40:00+03	36800.00
F14085	2017-08-11 05:15:00+03	55800.00
F140F6	2017-07-01 23:22:00+03	130400.00
F14110	2017-07-08 13:30:00+03	25800.00
F14127	2017-07-27 18:23:00+03	47400.00
F1417F	2017-08-03 20:30:00+03	119400.00
F141A4	2017-08-07 19:49:00+03	27300.00
F141AE	2017-07-06 02:25:00+03	131600.00
F141F7	2017-07-08 15:47:00+03	40800.00
F14225	2017-08-02 06:40:00+03	43100.00
F1429E	2017-07-01 17:19:00+03	43400.00
F142B0	2017-08-06 07:03:00+03	135400.00
F142FD	2017-07-07 15:50:00+03	87000.00
F1435A	2017-07-27 21:25:00+03	108700.00
F14377	2017-07-25 04:59:00+03	70600.00
F143B6	2017-06-27 12:23:00+03	74400.00
F143F0	2017-08-12 14:12:00+03	47500.00
F1444A	2017-07-18 18:41:00+03	46500.00
F14457	2017-07-21 19:34:00+03	25400.00
F14468	2017-07-06 12:39:00+03	39800.00
F14501	2017-07-25 04:07:00+03	114800.00
F14522	2017-07-24 06:11:00+03	16800.00
F14549	2017-07-19 02:10:00+03	40000.00
F1458B	2017-08-13 18:27:00+03	57500.00
F14601	2017-07-07 16:24:00+03	56000.00
F1461F	2017-07-29 08:29:00+03	100600.00
F14633	2017-08-04 19:27:00+03	98700.00
F14644	2017-07-29 13:23:00+03	131600.00
F146CE	2017-07-19 09:56:00+03	124000.00
F146E3	2017-08-14 22:12:00+03	67300.00
F14743	2017-07-22 08:25:00+03	62000.00
F14764	2017-07-19 23:16:00+03	100600.00
F1479B	2017-07-01 06:06:00+03	48800.00
F14836	2017-07-11 17:36:00+03	35200.00
F14838	2017-07-23 03:59:00+03	23400.00
F14868	2017-07-13 11:04:00+03	260300.00
F148C1	2017-08-07 03:21:00+03	93000.00
F148C7	2017-07-06 20:03:00+03	43600.00
F148CF	2017-08-04 07:09:00+03	86600.00
F14909	2017-08-03 16:23:00+03	281500.00
F149AA	2017-07-09 18:12:00+03	54800.00
F149D3	2017-07-02 03:30:00+03	62600.00
F149ED	2017-07-18 00:18:00+03	73200.00
F149F8	2017-07-22 22:48:00+03	147100.00
F14A14	2017-07-09 06:02:00+03	75300.00
F14A30	2017-07-11 00:48:00+03	87200.00
F14B02	2017-07-27 02:27:00+03	31400.00
F14B04	2017-07-05 03:03:00+03	97900.00
F14B45	2017-08-12 03:37:00+03	84700.00
F14B4E	2017-07-03 19:59:00+03	26000.00
F14B6D	2017-07-27 10:35:00+03	12000.00
F14B7C	2017-06-29 13:19:00+03	112000.00
F14C0B	2017-07-07 07:26:00+03	123000.00
F14C18	2017-07-15 06:59:00+03	96300.00
F14C34	2017-08-10 03:41:00+03	42600.00
F14C4B	2017-08-15 15:19:00+03	10800.00
F14C58	2017-08-14 08:47:00+03	92800.00
F14C7A	2017-08-14 18:06:00+03	72400.00
F14C91	2017-08-15 14:31:00+03	77400.00
F14CBA	2017-07-23 07:35:00+03	14000.00
F14CC9	2017-07-02 09:01:00+03	112000.00
F14D34	2017-07-14 03:54:00+03	77200.00
F14D9E	2017-07-03 03:24:00+03	14800.00
F14DB1	2017-07-16 09:02:00+03	159500.00
F14E26	2017-08-02 17:09:00+03	47200.00
F14E54	2017-07-20 01:05:00+03	52700.00
F14E6E	2017-08-03 12:09:00+03	112600.00
F14E77	2017-07-28 15:22:00+03	48000.00
F14F3A	2017-07-20 15:50:00+03	80800.00
F14F76	2017-08-01 19:09:00+03	344400.00
F14F81	2017-07-30 04:30:00+03	193600.00
F14F90	2017-07-15 10:27:00+03	199700.00
F14FC1	2017-08-04 13:41:00+03	28000.00
F14FE6	2017-07-01 18:33:00+03	29200.00
F15034	2017-07-08 22:53:00+03	99600.00
F1505D	2017-07-31 22:32:00+03	94000.00
F1508F	2017-07-23 15:34:00+03	295400.00
F150A5	2017-07-06 20:35:00+03	24400.00
F1511C	2017-07-26 06:30:00+03	21800.00
F15192	2017-07-17 14:15:00+03	42600.00
F151C3	2017-07-22 21:56:00+03	13400.00
F151F4	2017-07-10 23:34:00+03	67000.00
F15214	2017-08-11 21:51:00+03	246000.00
F1522D	2017-07-29 23:33:00+03	124200.00
F15278	2017-07-01 13:53:00+03	74700.00
F152C5	2017-07-23 11:29:00+03	502800.00
F153CA	2017-07-01 22:14:00+03	66600.00
F15498	2017-07-21 11:58:00+03	84100.00
F154FB	2017-07-14 00:42:00+03	8200.00
F15581	2017-07-22 02:33:00+03	28800.00
F155AC	2017-07-17 05:23:00+03	64100.00
F155E9	2017-07-04 09:03:00+03	147700.00
F15600	2017-08-02 21:25:00+03	119600.00
F15650	2017-07-28 11:10:00+03	24400.00
F15684	2017-08-14 21:41:00+03	16400.00
F15691	2017-07-20 16:18:00+03	34100.00
F156CA	2017-07-05 16:05:00+03	15200.00
F156D1	2017-07-15 13:46:00+03	56200.00
F156EB	2017-07-23 06:13:00+03	43100.00
F1571E	2017-07-27 06:00:00+03	36200.00
F15735	2017-07-19 12:31:00+03	63600.00
F15771	2017-08-11 20:08:00+03	29900.00
F1578C	2017-07-13 20:37:00+03	40600.00
F157AA	2017-07-09 21:55:00+03	97700.00
F157F7	2017-08-08 12:57:00+03	52900.00
F158D8	2017-07-30 17:49:00+03	148200.00
F15931	2017-08-07 21:59:00+03	10800.00
F15955	2017-08-04 08:15:00+03	40000.00
F1595D	2017-07-11 12:40:00+03	85400.00
F159F8	2017-08-06 01:57:00+03	97700.00
F15A0E	2017-07-28 00:11:00+03	13400.00
F15A39	2017-07-04 10:32:00+03	56000.00
F15AF1	2017-07-13 20:23:00+03	8200.00
F15BB5	2017-07-03 14:27:00+03	65500.00
F15BEB	2017-07-03 09:25:00+03	32700.00
F15C76	2017-07-31 03:38:00+03	38800.00
F15C8B	2017-08-08 06:50:00+03	85700.00
F15CB6	2017-07-23 22:41:00+03	24400.00
F15CB9	2017-08-03 21:17:00+03	38400.00
F15DC7	2017-08-15 08:27:00+03	60200.00
F15DE1	2017-08-07 07:15:00+03	47200.00
F15E0E	2017-06-24 15:52:00+03	31400.00
F15E16	2017-07-01 04:14:00+03	73300.00
F15E3D	2017-08-05 03:48:00+03	55800.00
F15E61	2017-07-12 11:01:00+03	29600.00
F15EE2	2017-07-13 12:40:00+03	99300.00
F15F92	2017-07-22 04:09:00+03	113600.00
F15FC8	2017-07-29 19:15:00+03	119500.00
F16028	2017-08-02 22:36:00+03	141600.00
F160D8	2017-07-24 00:19:00+03	258400.00
F16106	2017-07-10 10:40:00+03	29400.00
F1614B	2017-07-24 19:08:00+03	24000.00
F16153	2017-08-08 00:16:00+03	8000.00
F16197	2017-07-11 07:14:00+03	40200.00
F1619A	2017-07-09 06:52:00+03	325500.00
F161A5	2017-08-04 10:30:00+03	12600.00
F162B0	2017-07-19 12:12:00+03	6700.00
F162B8	2017-07-10 20:18:00+03	38800.00
F162DC	2017-08-02 12:39:00+03	68800.00
F16314	2017-07-17 06:37:00+03	59600.00
F16340	2017-07-06 01:06:00+03	24000.00
F16341	2017-08-11 06:14:00+03	169300.00
F1638F	2017-07-18 11:00:00+03	68800.00
F16398	2017-07-20 18:49:00+03	78000.00
F163A4	2017-08-08 01:26:00+03	411900.00
F163B1	2017-07-22 19:09:00+03	42600.00
F16400	2017-07-08 08:14:00+03	126600.00
F1641E	2017-07-07 02:54:00+03	37200.00
F164B3	2017-07-30 12:51:00+03	134400.00
F164C9	2017-07-16 09:33:00+03	23200.00
F1655F	2017-08-02 23:16:00+03	148800.00
F165A9	2017-08-08 12:30:00+03	56000.00
F16627	2017-07-02 10:06:00+03	108200.00
F16631	2017-08-06 23:16:00+03	77000.00
F16676	2017-07-05 06:41:00+03	38600.00
F16697	2017-07-25 05:29:00+03	31000.00
F1669A	2017-08-09 02:27:00+03	56000.00
F16720	2017-07-31 22:44:00+03	19600.00
F16864	2017-08-13 23:00:00+03	408500.00
F1688F	2017-07-07 21:37:00+03	101200.00
F16897	2017-08-02 00:58:00+03	46200.00
F16950	2017-07-16 07:27:00+03	397700.00
F1697F	2017-08-13 00:20:00+03	92800.00
F16A26	2017-07-21 00:16:00+03	37100.00
F16A4F	2017-08-08 17:27:00+03	129700.00
F16AF5	2017-07-05 18:03:00+03	23200.00
F16B8F	2017-07-13 15:40:00+03	24400.00
F16B9C	2017-07-11 10:52:00+03	193900.00
F16BA7	2017-07-14 10:34:00+03	46400.00
F16C05	2017-07-29 01:36:00+03	25800.00
F16C1A	2017-07-13 07:56:00+03	54600.00
F16C61	2017-07-05 09:36:00+03	6000.00
F16C64	2017-06-27 16:31:00+03	62200.00
F16C6F	2017-07-24 14:02:00+03	23200.00
F16C9D	2017-08-01 11:14:00+03	8200.00
F16D0B	2017-07-27 17:15:00+03	131600.00
F16E1C	2017-07-06 07:11:00+03	78300.00
F16E28	2017-07-06 21:22:00+03	75100.00
F16E5C	2017-07-28 13:09:00+03	9300.00
F16E64	2017-08-14 02:13:00+03	49900.00
F16E86	2017-07-03 21:05:00+03	35200.00
F16EAC	2017-07-05 01:41:00+03	48100.00
F16ED5	2017-07-21 11:46:00+03	128000.00
F16EDD	2017-08-15 16:20:00+03	75800.00
F16EE7	2017-07-22 15:59:00+03	20800.00
F16F5E	2017-07-17 04:43:00+03	92800.00
F16FFA	2017-07-07 23:07:00+03	20600.00
F1700F	2017-07-10 02:38:00+03	56000.00
F170D5	2017-08-10 12:49:00+03	43900.00
F170F6	2017-08-14 05:58:00+03	55800.00
F17144	2017-07-16 13:48:00+03	57500.00
F17163	2017-07-30 10:48:00+03	89600.00
F1717A	2017-07-16 16:29:00+03	98400.00
F17181	2017-08-07 00:41:00+03	93700.00
F1718D	2017-08-14 08:01:00+03	36100.00
F171D6	2017-07-17 10:16:00+03	42800.00
F171E1	2017-06-30 05:05:00+03	54800.00
F1720C	2017-07-18 07:25:00+03	265800.00
F1722B	2017-07-02 12:40:00+03	12400.00
F17268	2017-07-26 10:41:00+03	46000.00
F172B1	2017-07-05 21:59:00+03	136200.00
F172C1	2017-08-15 14:31:00+03	75300.00
F17331	2017-08-07 21:49:00+03	136200.00
F17377	2017-07-30 23:59:00+03	58600.00
F173A6	2017-07-23 02:28:00+03	6700.00
F1743F	2017-08-04 21:32:00+03	147700.00
F17478	2017-06-28 03:30:00+03	56000.00
F17498	2017-07-25 21:15:00+03	52000.00
F1753B	2017-07-01 04:47:00+03	108300.00
F1756E	2017-07-20 17:15:00+03	27300.00
F17578	2017-07-11 02:33:00+03	73600.00
F1757F	2017-08-14 23:42:00+03	27800.00
F1758B	2017-08-02 10:17:00+03	28000.00
F175BF	2017-08-14 08:57:00+03	26800.00
F17601	2017-08-11 01:37:00+03	78200.00
F17699	2017-08-13 19:47:00+03	30200.00
F17743	2017-08-12 10:18:00+03	66600.00
F1775A	2017-07-09 15:00:00+03	130400.00
F17762	2017-08-14 16:29:00+03	78800.00
F17793	2017-08-10 11:44:00+03	437700.00
F177B5	2017-07-02 04:06:00+03	14400.00
F177DA	2017-08-13 14:28:00+03	61800.00
F177FF	2017-08-14 21:00:00+03	55800.00
F1782A	2017-07-15 06:13:00+03	89700.00
F17838	2017-06-30 00:01:00+03	432600.00
F178B9	2017-07-07 16:17:00+03	25400.00
F178EA	2017-07-19 18:37:00+03	92700.00
F178F8	2017-08-02 18:07:00+03	57200.00
F17961	2017-08-13 05:09:00+03	73000.00
F17979	2017-07-06 03:59:00+03	14800.00
F1797D	2017-08-13 14:55:00+03	28800.00
F17989	2017-07-04 08:26:00+03	83300.00
F1799B	2017-07-20 18:50:00+03	6300.00
F179B1	2017-07-19 02:22:00+03	126400.00
F17A0A	2017-07-31 15:12:00+03	80000.00
F17A47	2017-07-28 09:09:00+03	9800.00
F17A7D	2017-08-14 04:18:00+03	62600.00
F17AC0	2017-08-03 10:04:00+03	214900.00
F17ACB	2017-06-29 09:04:00+03	55800.00
F17AD5	2017-08-02 18:55:00+03	46300.00
F17AE2	2017-08-08 01:36:00+03	67200.00
F17AF4	2017-07-03 09:13:00+03	13000.00
F17AFE	2017-08-01 09:56:00+03	14400.00
F17B47	2017-08-04 03:21:00+03	38700.00
F17B5E	2017-07-24 04:59:00+03	92700.00
F17BF0	2017-07-19 01:21:00+03	84600.00
F17C00	2017-08-08 13:55:00+03	56900.00
F17C3E	2017-07-18 03:54:00+03	58400.00
F17C5A	2017-08-05 02:09:00+03	123000.00
F17CDD	2017-07-19 22:31:00+03	32800.00
F17D04	2017-08-07 16:02:00+03	117800.00
F17D40	2017-07-29 23:23:00+03	46400.00
F17DB9	2017-07-27 22:21:00+03	70700.00
F17E67	2017-07-17 07:05:00+03	102100.00
F17E7D	2017-08-06 22:02:00+03	129800.00
F17E97	2017-07-11 17:50:00+03	16400.00
F17F1D	2017-07-23 07:36:00+03	19600.00
F17FF2	2017-08-13 00:10:00+03	6700.00
F18073	2017-07-29 07:53:00+03	83200.00
F180C0	2017-08-05 11:19:00+03	36100.00
F180D3	2017-07-16 21:55:00+03	13400.00
F18108	2017-08-15 10:51:00+03	85800.00
F1812F	2017-08-08 10:44:00+03	6700.00
F181AE	2017-07-04 04:07:00+03	98800.00
F1825F	2017-07-26 05:12:00+03	19600.00
F1827E	2017-07-16 17:03:00+03	14300.00
F18280	2017-07-22 03:40:00+03	152400.00
F182B8	2017-08-06 09:00:00+03	86800.00
F182E5	2017-07-18 15:50:00+03	14000.00
F182EF	2017-08-15 05:48:00+03	291000.00
F18305	2017-07-27 00:48:00+03	102100.00
F18347	2017-07-18 01:22:00+03	31100.00
F1834F	2017-07-14 05:58:00+03	51900.00
F1837C	2017-08-12 19:15:00+03	48900.00
F1839D	2017-07-11 21:50:00+03	158500.00
F183C0	2017-07-04 22:01:00+03	14400.00
F18457	2017-07-22 07:38:00+03	6800.00
F184D1	2017-08-02 16:44:00+03	27400.00
F18504	2017-07-28 23:51:00+03	81800.00
F18647	2017-07-04 21:41:00+03	16400.00
F1869D	2017-07-15 07:12:00+03	133900.00
F186A5	2017-08-13 16:30:00+03	95200.00
F186AC	2017-08-11 01:44:00+03	44800.00
F186CC	2017-07-16 03:04:00+03	238300.00
F1871B	2017-07-16 15:20:00+03	10700.00
F1875C	2017-07-27 03:25:00+03	81600.00
F18760	2017-07-31 07:05:00+03	42800.00
F18762	2017-07-01 18:07:00+03	26800.00
F18766	2017-07-19 07:54:00+03	51600.00
F18800	2017-07-26 04:07:00+03	76600.00
F1880D	2017-07-31 19:13:00+03	162700.00
F18868	2017-07-12 22:48:00+03	73500.00
F18889	2017-07-20 10:53:00+03	19800.00
F188A3	2017-08-13 22:23:00+03	130400.00
F188A5	2017-08-06 23:35:00+03	28000.00
F188C5	2017-07-24 02:34:00+03	26000.00
F188F2	2017-08-13 18:52:00+03	132800.00
F189D2	2017-07-25 19:59:00+03	23600.00
F189DB	2017-08-12 06:21:00+03	26800.00
F18A58	2017-07-27 06:14:00+03	53700.00
F18AA7	2017-07-10 15:05:00+03	13600.00
F18ACE	2017-07-31 17:24:00+03	28000.00
F18B63	2017-08-02 16:45:00+03	43400.00
F18C2A	2017-07-27 13:51:00+03	37900.00
F18C5A	2017-07-03 09:24:00+03	38800.00
F18C5E	2017-07-28 23:18:00+03	7400.00
F18C94	2017-07-14 09:52:00+03	113900.00
F18C9A	2017-08-07 02:39:00+03	249300.00
F18CD9	2017-07-24 14:12:00+03	28000.00
F18CEF	2017-07-18 02:28:00+03	26000.00
F18D66	2017-07-30 23:33:00+03	265700.00
F18DA1	2017-06-30 01:39:00+03	20000.00
F18DE4	2017-08-09 05:04:00+03	51900.00
F18DEB	2017-07-20 01:18:00+03	29600.00
F18E57	2017-07-01 20:34:00+03	52000.00
F18F17	2017-08-14 22:55:00+03	60400.00
F18F3F	2017-08-10 17:49:00+03	25100.00
F18F95	2017-08-14 05:25:00+03	69000.00
F18FFC	2017-08-11 12:15:00+03	66600.00
F19049	2017-07-09 15:52:00+03	166100.00
F1909B	2017-07-12 20:42:00+03	23200.00
F190EA	2017-07-11 05:31:00+03	53500.00
F1912A	2017-07-19 21:12:00+03	19600.00
F191DB	2017-07-08 02:07:00+03	19600.00
F19225	2017-07-25 17:45:00+03	23600.00
F19261	2017-08-03 03:46:00+03	57400.00
F1929C	2017-08-15 10:01:00+03	70700.00
F192B7	2017-07-07 05:16:00+03	201800.00
F192E5	2017-07-24 19:51:00+03	49100.00
F192EA	2017-08-05 21:30:00+03	69500.00
F19368	2017-07-10 17:11:00+03	60900.00
F19378	2017-08-02 19:51:00+03	24400.00
F193CF	2017-07-01 11:27:00+03	111600.00
F19443	2017-07-28 17:16:00+03	9800.00
F19505	2017-07-04 17:30:00+03	26000.00
F1951E	2017-07-27 15:17:00+03	13200.00
F195C3	2017-08-12 03:42:00+03	70500.00
F195ED	2017-06-30 22:40:00+03	15800.00
F1963B	2017-07-08 04:07:00+03	66800.00
F196E6	2017-08-15 03:34:00+03	31200.00
F196F2	2017-07-22 11:47:00+03	147000.00
F1970E	2017-07-10 15:43:00+03	32200.00
F1974A	2017-07-09 08:19:00+03	398500.00
F1974D	2017-08-14 13:25:00+03	14400.00
F19781	2017-08-12 23:07:00+03	12000.00
F198BE	2017-08-04 18:20:00+03	33300.00
F198C0	2017-07-07 02:57:00+03	47000.00
F198CF	2017-07-23 15:30:00+03	23600.00
F19903	2017-07-29 22:19:00+03	454500.00
F1992E	2017-08-01 12:59:00+03	269500.00
F19939	2017-07-19 17:33:00+03	23200.00
F19954	2017-08-05 02:01:00+03	13600.00
F1995E	2017-07-01 00:22:00+03	135400.00
F1996D	2017-07-09 20:46:00+03	42100.00
F199C3	2017-07-13 23:08:00+03	54400.00
F199D8	2017-08-06 05:18:00+03	24800.00
F19A19	2017-07-27 03:30:00+03	192900.00
F19A3C	2017-07-28 21:11:00+03	29600.00
F19A50	2017-07-09 13:31:00+03	22600.00
F19A8B	2017-08-14 14:26:00+03	12100.00
F19AD9	2017-07-26 19:51:00+03	30200.00
F19B06	2017-07-20 21:21:00+03	44800.00
F19B6F	2017-07-25 05:35:00+03	201200.00
F19B9D	2017-08-03 07:33:00+03	62600.00
F19BF3	2017-08-14 13:38:00+03	77900.00
F19C09	2017-08-08 19:49:00+03	123000.00
F19C46	2017-07-14 15:56:00+03	107700.00
F19C5F	2017-07-30 08:13:00+03	75300.00
F19D2E	2017-07-09 06:47:00+03	36200.00
F19D4B	2017-07-22 15:58:00+03	46400.00
F19D85	2017-07-01 18:26:00+03	22800.00
F19D88	2017-07-26 15:44:00+03	81700.00
F19DAF	2017-08-01 11:04:00+03	46300.00
F19DCF	2017-08-03 05:02:00+03	27200.00
F19DE5	2017-08-03 13:45:00+03	73600.00
F19E3E	2017-07-19 06:42:00+03	28000.00
F19EB0	2017-08-05 14:02:00+03	92800.00
F19F06	2017-07-14 12:10:00+03	55400.00
F19F10	2017-06-29 03:45:00+03	76600.00
F19F49	2017-07-17 12:14:00+03	76400.00
F19F5E	2017-08-05 15:42:00+03	49800.00
F19FF9	2017-08-11 20:23:00+03	13700.00
F19FFE	2017-07-04 10:46:00+03	65000.00
F1A001	2017-08-01 05:58:00+03	26700.00
F1A048	2017-07-26 20:29:00+03	87000.00
F1A067	2017-07-06 07:04:00+03	25000.00
F1A0AB	2017-07-18 07:53:00+03	19600.00
F1A12B	2017-07-09 15:55:00+03	75800.00
F1A14E	2017-08-02 17:53:00+03	118100.00
F1A183	2017-07-01 23:23:00+03	63500.00
F1A185	2017-08-13 02:43:00+03	265700.00
F1A21C	2017-07-23 16:43:00+03	16400.00
F1A392	2017-08-05 15:00:00+03	113700.00
F1A3B0	2017-07-31 20:30:00+03	52000.00
F1A3F9	2017-07-07 11:09:00+03	204700.00
F1A422	2017-07-10 20:22:00+03	43600.00
F1A450	2017-06-30 08:10:00+03	24700.00
F1A4DB	2017-07-10 09:24:00+03	24400.00
F1A51B	2017-07-22 00:34:00+03	47000.00
F1A526	2017-07-26 02:16:00+03	266400.00
F1A536	2017-08-14 06:41:00+03	92800.00
F1A580	2017-08-07 03:33:00+03	91700.00
F1A582	2017-08-14 15:47:00+03	28800.00
F1A5EC	2017-08-08 19:29:00+03	200400.00
F1A5F3	2017-08-03 01:50:00+03	70600.00
F1A6D0	2017-07-02 00:13:00+03	46200.00
F1A754	2017-07-02 08:38:00+03	20500.00
F1A7B1	2017-07-11 01:58:00+03	133200.00
F1A80D	2017-08-13 11:11:00+03	22400.00
F1A819	2017-07-01 04:06:00+03	68400.00
F1A887	2017-07-04 00:36:00+03	28000.00
F1A88A	2017-07-19 12:16:00+03	79200.00
F1A890	2017-07-08 09:57:00+03	114900.00
F1A8EA	2017-07-12 09:26:00+03	54800.00
F1A994	2017-07-29 13:31:00+03	62000.00
F1A9D9	2017-07-07 05:37:00+03	46200.00
F1AA02	2017-07-17 05:49:00+03	86600.00
F1AA0C	2017-07-10 22:48:00+03	35700.00
F1AA35	2017-07-08 09:18:00+03	24800.00
F1AAA3	2017-08-11 03:52:00+03	28000.00
F1AAB7	2017-07-18 09:02:00+03	266400.00
F1AAC4	2017-07-26 20:38:00+03	64700.00
F1AAFF	2017-08-02 17:36:00+03	88500.00
F1AB61	2017-07-17 04:36:00+03	76600.00
F1AB81	2017-07-16 00:58:00+03	37900.00
F1AB95	2017-07-23 05:25:00+03	21400.00
F1ABA1	2017-08-14 03:48:00+03	36000.00
F1ABB6	2017-08-07 12:30:00+03	52400.00
F1ABCD	2017-08-14 13:41:00+03	272300.00
F1AC0B	2017-07-21 04:39:00+03	12600.00
F1ACA8	2017-07-30 15:17:00+03	67200.00
F1ACBB	2017-07-10 08:50:00+03	73400.00
F1ACD4	2017-07-19 04:24:00+03	28000.00
F1AD1F	2017-07-25 16:51:00+03	64800.00
F1AD58	2017-08-13 14:52:00+03	16400.00
F1ADC2	2017-07-17 15:03:00+03	28200.00
F1ADD0	2017-07-24 17:43:00+03	64700.00
F1AE25	2017-07-10 07:10:00+03	21400.00
F1AE6E	2017-07-11 06:42:00+03	115700.00
F1AE8C	2017-07-21 15:01:00+03	24400.00
F1AEC2	2017-07-15 06:18:00+03	166000.00
F1AF22	2017-08-10 03:52:00+03	38600.00
F1AF5B	2017-07-20 08:33:00+03	6200.00
F1AF75	2017-07-12 22:23:00+03	32700.00
F1AFDC	2017-07-31 21:20:00+03	20400.00
F1B025	2017-07-17 20:57:00+03	26000.00
F1B02E	2017-07-03 02:51:00+03	124200.00
F1B035	2017-07-14 14:00:00+03	46300.00
F1B060	2017-07-25 08:49:00+03	52000.00
F1B062	2017-07-04 02:17:00+03	132200.00
F1B0A5	2017-07-02 07:24:00+03	141700.00
F1B0F3	2017-07-31 05:25:00+03	179400.00
F1B106	2017-08-15 09:25:00+03	84000.00
F1B10C	2017-08-03 01:10:00+03	54900.00
F1B1BA	2017-07-03 12:25:00+03	82600.00
F1B20E	2017-08-15 12:04:00+03	13600.00
F1B260	2017-08-14 23:25:00+03	12400.00
F1B265	2017-08-10 23:32:00+03	109900.00
F1B30F	2017-07-24 14:45:00+03	30200.00
F1B321	2017-08-12 04:21:00+03	36200.00
F1B330	2017-07-21 20:25:00+03	26000.00
F1B3A1	2017-08-07 02:10:00+03	56100.00
F1B422	2017-08-15 16:35:00+03	14000.00
F1B451	2017-07-09 05:22:00+03	47400.00
F1B468	2017-07-08 02:50:00+03	8200.00
F1B4A0	2017-07-14 04:22:00+03	8400.00
F1B599	2017-08-15 03:36:00+03	24000.00
F1B5E5	2017-08-06 10:24:00+03	63700.00
F1B5E6	2017-07-14 01:06:00+03	296400.00
F1B615	2017-07-20 14:48:00+03	42700.00
F1B624	2017-07-17 04:49:00+03	136800.00
F1B633	2017-07-26 05:26:00+03	58200.00
F1B67D	2017-07-22 23:51:00+03	48800.00
F1B682	2017-07-12 15:44:00+03	27200.00
F1B6A9	2017-07-02 04:02:00+03	28800.00
F1B746	2017-07-27 00:21:00+03	111600.00
F1B74D	2017-07-08 23:44:00+03	69400.00
F1B7FB	2017-07-08 20:02:00+03	32700.00
F1B813	2017-07-30 18:42:00+03	59800.00
F1B864	2017-08-02 22:16:00+03	71900.00
F1B876	2017-08-11 05:04:00+03	134400.00
F1B87E	2017-07-09 22:31:00+03	265600.00
F1B8BF	2017-08-15 16:13:00+03	311200.00
F1B8C5	2017-07-23 20:07:00+03	9800.00
F1B8CF	2017-07-05 17:58:00+03	6000.00
F1B913	2017-06-29 13:47:00+03	26700.00
F1B926	2017-07-27 09:41:00+03	95200.00
F1B946	2017-07-12 13:58:00+03	55800.00
F1BA00	2017-08-06 19:23:00+03	36800.00
F1BA76	2017-07-07 05:43:00+03	13000.00
F1BA96	2017-08-02 11:35:00+03	90000.00
F1BAF1	2017-07-01 17:35:00+03	46200.00
F1BB43	2017-07-09 18:08:00+03	11600.00
F1BDD4	2017-08-15 16:15:00+03	39500.00
F1BE15	2017-08-12 08:24:00+03	55000.00
F1BE4B	2017-07-17 04:55:00+03	175300.00
F1BE90	2017-08-11 11:15:00+03	136200.00
F1BEB5	2017-07-29 08:01:00+03	89600.00
F1BEDC	2017-06-29 00:26:00+03	89700.00
F1BEF8	2017-08-11 05:44:00+03	75600.00
F1BF29	2017-07-04 22:23:00+03	63700.00
F1BF83	2017-07-03 18:57:00+03	14300.00
F1BF85	2017-08-07 08:49:00+03	32200.00
F1C008	2017-07-08 10:53:00+03	26000.00
F1C051	2017-07-08 03:35:00+03	115700.00
F1C062	2017-08-15 06:26:00+03	27600.00
F1C111	2017-07-12 02:45:00+03	269400.00
F1C129	2017-08-14 14:55:00+03	24400.00
F1C17C	2017-07-23 21:48:00+03	18000.00
F1C1AF	2017-07-09 20:57:00+03	223200.00
F1C1B3	2017-07-16 15:39:00+03	10700.00
F1C1FB	2017-08-06 15:00:00+03	69400.00
F1C20E	2017-07-10 08:42:00+03	28800.00
F1C219	2017-07-10 07:41:00+03	93900.00
F1C222	2017-07-10 22:11:00+03	6700.00
F1C296	2017-07-12 11:02:00+03	21800.00
F1C2A5	2017-07-23 08:07:00+03	21000.00
F1C2A8	2017-06-29 08:42:00+03	8200.00
F1C2DD	2017-07-29 11:26:00+03	123000.00
F1C322	2017-07-19 03:08:00+03	54100.00
F1C389	2017-07-17 17:21:00+03	62800.00
F1C3E3	2017-07-19 15:15:00+03	240600.00
F1C449	2017-07-24 00:46:00+03	51900.00
F1C496	2017-07-22 10:41:00+03	90400.00
F1C4BB	2017-07-31 06:24:00+03	53400.00
F1C518	2017-07-05 01:36:00+03	35200.00
F1C53B	2017-08-14 15:45:00+03	93000.00
F1C560	2017-07-24 02:17:00+03	92800.00
F1C5AE	2017-08-15 02:43:00+03	118100.00
F1C614	2017-07-27 23:39:00+03	8000.00
F1C631	2017-07-30 16:22:00+03	47400.00
F1C663	2017-08-04 05:34:00+03	12600.00
F1C676	2017-07-31 02:37:00+03	12000.00
F1C68F	2017-08-03 22:58:00+03	119800.00
F1C6A1	2017-07-22 02:51:00+03	16800.00
F1C7CE	2017-07-25 02:58:00+03	23200.00
F1C81A	2017-07-13 16:45:00+03	136500.00
F1C83E	2017-06-29 20:42:00+03	55800.00
F1C84B	2017-06-30 01:33:00+03	26600.00
F1C858	2017-07-23 23:59:00+03	60700.00
F1C8C0	2017-08-13 03:00:00+03	161600.00
F1C8E7	2017-07-02 07:25:00+03	81600.00
F1C902	2017-07-18 08:46:00+03	60400.00
F1C94F	2017-07-03 22:44:00+03	115900.00
F1C972	2017-08-12 02:25:00+03	144300.00
F1C978	2017-08-09 05:27:00+03	58800.00
F1C9E5	2017-07-04 22:23:00+03	28800.00
F1CA8D	2017-07-09 16:16:00+03	129600.00
F1CB05	2017-07-04 11:18:00+03	168000.00
F1CB76	2017-08-08 17:08:00+03	43900.00
F1CBA2	2017-07-23 06:11:00+03	160600.00
F1CBCF	2017-08-10 10:24:00+03	59800.00
F1CC02	2017-07-19 00:59:00+03	6800.00
F1CC2B	2017-07-27 22:10:00+03	55800.00
F1CC35	2017-07-03 16:29:00+03	135200.00
F1CC47	2017-07-07 12:11:00+03	64100.00
F1CC87	2017-08-06 18:16:00+03	22400.00
F1CC88	2017-08-10 00:02:00+03	69500.00
F1CCF8	2017-07-31 19:22:00+03	62700.00
F1CD04	2017-07-04 07:53:00+03	59400.00
F1CD16	2017-07-24 05:47:00+03	70800.00
F1CDB3	2017-06-28 21:22:00+03	51600.00
F1CDB8	2017-07-19 11:25:00+03	55500.00
F1CDE1	2017-08-05 10:47:00+03	28800.00
F1CDE3	2017-07-28 12:08:00+03	58600.00
F1CE1A	2017-07-05 06:32:00+03	27300.00
F1CE40	2017-07-20 11:47:00+03	28000.00
F1CE42	2017-08-15 12:21:00+03	28000.00
F1CE5D	2017-08-05 23:06:00+03	25400.00
F1CFFA	2017-08-10 15:10:00+03	134700.00
F1D02A	2017-07-02 07:13:00+03	54800.00
F1D085	2017-07-31 17:26:00+03	155600.00
F1D0A1	2017-08-08 02:35:00+03	6000.00
F1D0D8	2017-07-18 20:52:00+03	15000.00
F1D0DC	2017-07-18 13:57:00+03	135400.00
F1D13F	2017-07-27 08:21:00+03	116900.00
F1D16E	2017-08-04 16:55:00+03	72200.00
F1D182	2017-08-01 21:49:00+03	52000.00
F1D19D	2017-07-13 18:34:00+03	67700.00
F1D1F8	2017-07-20 12:32:00+03	67600.00
F1D341	2017-07-03 17:13:00+03	56600.00
F1D372	2017-08-08 20:12:00+03	48400.00
F1D3DA	2017-08-02 02:57:00+03	80200.00
F1D3EF	2017-07-02 21:16:00+03	44600.00
F1D403	2017-07-26 17:16:00+03	29600.00
F1D41E	2017-07-09 15:25:00+03	38400.00
F1D4B5	2017-08-07 10:01:00+03	111600.00
F1D4DF	2017-08-03 10:36:00+03	267700.00
F1D4EF	2017-07-14 07:16:00+03	20600.00
F1D544	2017-07-12 01:13:00+03	32800.00
F1D553	2017-08-06 01:56:00+03	14700.00
F1D558	2017-08-04 18:58:00+03	155600.00
F1D5D2	2017-07-15 19:49:00+03	36600.00
F1D614	2017-08-02 15:13:00+03	105000.00
F1D62D	2017-08-13 06:57:00+03	56000.00
F1D689	2017-07-01 13:12:00+03	43600.00
F1D6D6	2017-07-14 18:40:00+03	6300.00
F1D6F1	2017-07-24 16:57:00+03	46400.00
F1D754	2017-08-01 15:58:00+03	67600.00
F1D796	2017-08-01 12:33:00+03	258400.00
F1D887	2017-07-27 11:33:00+03	21600.00
F1D909	2017-07-18 23:20:00+03	27200.00
F1D963	2017-07-13 18:05:00+03	22400.00
F1D972	2017-07-25 10:00:00+03	102100.00
F1D995	2017-08-13 00:01:00+03	16400.00
F1DA46	2017-07-11 13:07:00+03	34000.00
F1DA50	2017-08-15 10:18:00+03	118600.00
F1DB44	2017-08-01 20:41:00+03	137900.00
F1DB75	2017-07-19 09:50:00+03	62700.00
F1DBE2	2017-07-06 23:57:00+03	33800.00
F1DC2B	2017-08-10 09:19:00+03	28000.00
F1DC5B	2017-07-02 17:08:00+03	116400.00
F1DC9C	2017-08-02 18:14:00+03	87600.00
F1DD7C	2017-08-15 14:35:00+03	93800.00
F1DDC1	2017-07-08 16:54:00+03	286700.00
F1DE42	2017-08-11 22:54:00+03	105100.00
F1DE43	2017-07-30 21:58:00+03	24000.00
F1DEDE	2017-07-08 15:03:00+03	24400.00
F1DF0D	2017-07-26 02:07:00+03	57600.00
F1DF27	2017-08-09 22:51:00+03	40000.00
F1DF3A	2017-07-28 17:23:00+03	50600.00
F1DF69	2017-08-11 03:21:00+03	28000.00
F1DF87	2017-08-03 10:29:00+03	25100.00
F1DFA0	2017-06-30 22:52:00+03	86800.00
F1DFCF	2017-07-17 21:06:00+03	20800.00
F1E093	2017-07-10 21:03:00+03	16400.00
F1E14B	2017-07-24 19:18:00+03	67400.00
F1E14C	2017-07-01 17:09:00+03	23400.00
F1E168	2017-08-02 15:41:00+03	88200.00
F1E178	2017-08-05 13:05:00+03	42400.00
F1E27F	2017-08-11 11:55:00+03	77200.00
F1E2B2	2017-07-31 10:48:00+03	135200.00
F1E378	2017-07-30 17:40:00+03	28800.00
F1E384	2017-07-09 02:26:00+03	68100.00
F1E392	2017-07-16 14:40:00+03	84100.00
F1E3A4	2017-07-15 05:38:00+03	27200.00
F1E44E	2017-08-03 03:27:00+03	28000.00
F1E45F	2017-06-29 15:48:00+03	62600.00
F1E486	2017-07-17 19:03:00+03	289800.00
F1E4D1	2017-08-04 19:39:00+03	27200.00
F1E504	2017-07-04 05:18:00+03	115600.00
F1E50A	2017-08-02 19:55:00+03	22000.00
F1E573	2017-08-03 03:06:00+03	32800.00
F1E58D	2017-07-06 09:08:00+03	110500.00
F1E594	2017-07-11 18:23:00+03	14000.00
F1E5B7	2017-08-10 04:16:00+03	6000.00
F1E60D	2017-07-01 23:58:00+03	25000.00
F1E614	2017-08-04 07:11:00+03	26000.00
F1E6B1	2017-07-14 22:55:00+03	16400.00
F1E6B8	2017-07-18 05:49:00+03	67900.00
F1E7D1	2017-07-09 12:59:00+03	19600.00
F1E7EA	2017-08-13 22:40:00+03	52700.00
F1E870	2017-08-12 16:28:00+03	271200.00
F1E87B	2017-08-10 11:38:00+03	23600.00
F1E882	2017-08-09 03:07:00+03	258400.00
F1E89C	2017-08-09 10:02:00+03	95200.00
F1E8BE	2017-07-14 08:15:00+03	28000.00
F1E93D	2017-07-10 22:46:00+03	26000.00
F1E962	2017-08-15 12:42:00+03	173400.00
F1EA10	2017-08-08 10:40:00+03	15400.00
F1EA3A	2017-07-18 13:10:00+03	67600.00
F1EA85	2017-07-31 09:26:00+03	81600.00
F1EAC2	2017-08-10 01:18:00+03	283100.00
F1EAEE	2017-07-14 16:49:00+03	120700.00
F1EB14	2017-08-10 12:30:00+03	6700.00
F1EB2F	2017-07-18 23:38:00+03	153300.00
F1EB4A	2017-08-12 23:24:00+03	60200.00
F1EB70	2017-08-08 10:18:00+03	111200.00
F1EB8A	2017-07-28 16:19:00+03	42700.00
F1EBA7	2017-07-06 18:36:00+03	24400.00
F1EBBA	2017-08-08 15:24:00+03	54000.00
F1EBCC	2017-08-08 13:07:00+03	55800.00
F1EC67	2017-07-23 23:00:00+03	83000.00
F1ECD4	2017-08-12 12:19:00+03	97600.00
F1ED33	2017-07-06 13:48:00+03	24400.00
F1ED4D	2017-07-19 12:57:00+03	18000.00
F1EDD6	2017-07-09 06:02:00+03	45100.00
F1EE1A	2017-08-09 08:53:00+03	92800.00
F1EE35	2017-08-05 15:47:00+03	12600.00
F1EE36	2017-07-24 22:57:00+03	23600.00
F1EE4A	2017-07-04 10:25:00+03	36400.00
F1EEC4	2017-08-07 22:11:00+03	66300.00
F1EED6	2017-07-31 20:53:00+03	28000.00
F1EF27	2017-08-05 02:26:00+03	248300.00
F1EF59	2017-08-07 16:11:00+03	90400.00
F1EF6E	2017-07-30 22:01:00+03	155600.00
F1EFAF	2017-08-15 07:09:00+03	134700.00
F1EFB9	2017-08-06 19:07:00+03	6300.00
F1F035	2017-07-08 16:38:00+03	31400.00
F1F0A4	2017-08-13 16:11:00+03	64300.00
F1F0BE	2017-08-14 01:08:00+03	153200.00
F1F0EB	2017-07-15 05:23:00+03	21800.00
F1F108	2017-06-30 15:34:00+03	29600.00
F1F183	2017-06-27 14:45:00+03	56000.00
F1F1E2	2017-07-09 02:49:00+03	65900.00
F1F23E	2017-08-03 04:41:00+03	24400.00
F1F25D	2017-07-27 01:29:00+03	21000.00
F1F276	2017-07-06 13:24:00+03	168000.00
F1F2D3	2017-08-07 01:06:00+03	92700.00
F1F35B	2017-08-07 23:35:00+03	355200.00
F1F367	2017-07-07 22:34:00+03	56900.00
F1F390	2017-07-30 12:16:00+03	135400.00
F1F397	2017-07-13 08:47:00+03	27200.00
F1F3AA	2017-07-06 23:44:00+03	26000.00
F1F42B	2017-08-13 09:04:00+03	18900.00
F1F4DE	2017-08-06 13:09:00+03	28000.00
F1F54B	2017-07-23 13:25:00+03	6800.00
F1F5A9	2017-07-28 07:38:00+03	8800.00
F1F60D	2017-07-21 17:40:00+03	25400.00
F1F664	2017-07-14 03:11:00+03	57400.00
F1F693	2017-07-17 06:28:00+03	81300.00
F1F719	2017-08-03 22:53:00+03	114700.00
F1F741	2017-08-01 05:52:00+03	18000.00
F1F749	2017-07-04 02:47:00+03	6000.00
F1F7D9	2017-07-13 17:27:00+03	61800.00
F1F7F3	2017-08-11 09:03:00+03	167400.00
F1F80A	2017-08-08 11:56:00+03	173900.00
F1F858	2017-07-05 13:01:00+03	371200.00
F1F87F	2017-07-23 15:33:00+03	28000.00
F1F8E2	2017-08-01 15:46:00+03	57600.00
F1F8F9	2017-07-25 14:39:00+03	95700.00
F1F94B	2017-07-14 02:31:00+03	59800.00
F1F989	2017-08-04 02:34:00+03	21400.00
F1FA03	2017-07-08 00:58:00+03	122000.00
F1FA1F	2017-08-05 14:45:00+03	133100.00
F1FA28	2017-07-30 09:52:00+03	301800.00
F1FA2B	2017-07-31 16:17:00+03	26700.00
F1FA5C	2017-07-04 18:36:00+03	53800.00
F1FAC0	2017-07-27 22:48:00+03	119800.00
F1FAE6	2017-07-27 23:16:00+03	55800.00
F1FB44	2017-07-31 06:12:00+03	323600.00
F1FB4F	2017-07-15 04:09:00+03	12600.00
F1FBC1	2017-08-12 10:53:00+03	35600.00
F1FC03	2017-07-17 14:06:00+03	55800.00
F1FC0C	2017-07-08 10:27:00+03	52700.00
F1FC4A	2017-08-02 17:18:00+03	62600.00
F1FC6D	2017-07-02 21:07:00+03	136800.00
F1FC8F	2017-08-02 23:46:00+03	51800.00
F1FCB5	2017-07-23 01:45:00+03	6700.00
F1FCF5	2017-07-21 16:37:00+03	94000.00
F1FDE0	2017-08-06 08:00:00+03	101000.00
F1FDED	2017-07-30 03:56:00+03	34100.00
F1FE32	2017-06-27 00:06:00+03	87400.00
F1FEA1	2017-07-03 23:07:00+03	21400.00
F1FF52	2017-08-01 11:48:00+03	6700.00
F1FF57	2017-07-14 20:28:00+03	283700.00
F1FFAE	2017-07-29 10:16:00+03	57800.00
F1FFD7	2017-08-06 05:29:00+03	279200.00
F20009	2017-07-17 21:06:00+03	73500.00
F20027	2017-07-21 15:25:00+03	28800.00
F2007E	2017-08-05 20:23:00+03	63200.00
F2009A	2017-07-24 23:50:00+03	28800.00
F2009B	2017-07-07 14:59:00+03	51600.00
F2009E	2017-07-04 19:27:00+03	123000.00
F2015E	2017-08-05 13:58:00+03	44600.00
F2017A	2017-07-15 12:44:00+03	131900.00
F20189	2017-08-08 00:46:00+03	123400.00
F20196	2017-08-04 18:00:00+03	77600.00
F20203	2017-07-19 00:35:00+03	26000.00
F20284	2017-07-12 19:58:00+03	18000.00
F20323	2017-07-15 11:05:00+03	49900.00
F20344	2017-08-09 03:11:00+03	40000.00
F20393	2017-08-01 02:10:00+03	99200.00
F203EE	2017-07-05 07:40:00+03	71100.00
F2040A	2017-08-10 04:42:00+03	20400.00
F2040C	2017-07-28 19:29:00+03	92900.00
F2045D	2017-08-03 22:38:00+03	40800.00
F2047B	2017-08-08 23:11:00+03	30200.00
F20495	2017-07-07 03:11:00+03	12600.00
F204AC	2017-07-17 11:51:00+03	105600.00
F20536	2017-07-13 17:43:00+03	246000.00
F2057B	2017-07-17 01:18:00+03	23200.00
F2058E	2017-07-13 04:12:00+03	6600.00
F2063D	2017-07-13 05:09:00+03	30200.00
F2063E	2017-08-11 10:24:00+03	32500.00
F2067E	2017-07-15 16:50:00+03	54800.00
F20689	2017-07-30 08:27:00+03	174600.00
F206BB	2017-08-08 22:18:00+03	24200.00
F206CE	2017-08-07 06:39:00+03	32800.00
F20742	2017-08-01 00:15:00+03	112600.00
F20762	2017-08-04 06:58:00+03	61800.00
F20769	2017-07-25 06:08:00+03	52700.00
F20784	2017-07-27 03:34:00+03	75200.00
F20788	2017-07-16 23:35:00+03	131600.00
F207EA	2017-07-15 06:11:00+03	93000.00
F20835	2017-07-01 10:44:00+03	14700.00
F20867	2017-07-06 03:00:00+03	48800.00
F20878	2017-07-27 02:06:00+03	6300.00
F20924	2017-07-11 12:56:00+03	20400.00
F20954	2017-07-31 09:29:00+03	22000.00
F20A89	2017-07-19 08:14:00+03	31600.00
F20AB9	2017-06-28 10:32:00+03	99200.00
F20AEA	2017-07-20 11:02:00+03	47400.00
F20B5D	2017-06-29 18:30:00+03	76600.00
F20B6F	2017-07-08 22:44:00+03	28800.00
F20BBE	2017-08-09 18:15:00+03	153300.00
F20BD7	2017-08-11 12:41:00+03	84500.00
F20BE7	2017-07-28 03:44:00+03	289800.00
F20BEB	2017-08-05 18:52:00+03	26000.00
F20C66	2017-07-11 21:57:00+03	56000.00
F20CE9	2017-07-17 01:09:00+03	162400.00
F20CFB	2017-08-11 05:28:00+03	135400.00
F20D1E	2017-07-23 17:44:00+03	33300.00
F20D30	2017-07-11 20:10:00+03	37700.00
F20E0D	2017-07-31 09:16:00+03	46500.00
F20E90	2017-08-11 14:58:00+03	24000.00
F20EBD	2017-07-13 08:37:00+03	13200.00
F20EC4	2017-08-06 10:08:00+03	131600.00
F20F07	2017-08-11 01:27:00+03	45200.00
F20F61	2017-07-09 16:27:00+03	23200.00
F20F6E	2017-07-20 15:10:00+03	7300.00
F20F9B	2017-07-10 23:11:00+03	40400.00
F20FA6	2017-06-29 03:08:00+03	68900.00
F20FC6	2017-08-06 04:17:00+03	55000.00
F21022	2017-08-07 05:25:00+03	84200.00
F2103C	2017-07-13 16:47:00+03	115600.00
F2106D	2017-07-18 13:52:00+03	72800.00
F2107E	2017-08-14 11:42:00+03	288900.00
F210D6	2017-07-18 03:35:00+03	148800.00
F21112	2017-07-21 18:30:00+03	57500.00
F21122	2017-07-19 18:23:00+03	23600.00
F211F3	2017-08-08 18:41:00+03	44600.00
F2121E	2017-07-17 02:13:00+03	73500.00
F21276	2017-07-19 02:34:00+03	29400.00
F2128D	2017-07-10 10:46:00+03	62000.00
F212CF	2017-08-02 13:25:00+03	168700.00
F212D0	2017-07-16 09:19:00+03	35200.00
F21331	2017-07-10 18:40:00+03	55800.00
F21457	2017-08-11 23:30:00+03	34400.00
F214A4	2017-07-06 06:34:00+03	148300.00
F214F8	2017-07-15 18:12:00+03	103500.00
F214F9	2017-08-13 00:54:00+03	25400.00
F2150E	2017-07-06 12:57:00+03	62700.00
F21524	2017-07-11 00:28:00+03	55100.00
F2152D	2017-07-01 01:23:00+03	66600.00
F21532	2017-07-16 23:13:00+03	65300.00
F215E3	2017-07-20 07:19:00+03	84100.00
F21618	2017-08-11 07:03:00+03	28000.00
F2164B	2017-08-07 23:04:00+03	223200.00
F2169E	2017-08-03 12:17:00+03	14000.00
F216E0	2017-08-03 17:42:00+03	8200.00
F216FA	2017-07-11 11:06:00+03	23900.00
F21736	2017-08-01 17:35:00+03	54400.00
F21840	2017-07-17 13:31:00+03	138000.00
F218DC	2017-08-11 08:57:00+03	26800.00
F2190F	2017-08-11 10:55:00+03	171000.00
F2192B	2017-07-31 02:21:00+03	113700.00
F2193D	2017-08-14 23:30:00+03	52600.00
F2194F	2017-07-29 03:33:00+03	56100.00
F219F8	2017-08-06 18:51:00+03	27200.00
F21A0C	2017-07-23 18:44:00+03	90400.00
F21A7F	2017-07-27 04:27:00+03	58400.00
F21AAB	2017-08-06 20:59:00+03	65800.00
F21B05	2017-07-05 07:23:00+03	198400.00
F21B0B	2017-07-01 15:22:00+03	24200.00
F21B15	2017-07-05 22:41:00+03	23500.00
F21BCE	2017-07-06 21:26:00+03	28000.00
F21BDB	2017-07-23 13:54:00+03	78300.00
F21BFA	2017-08-14 08:54:00+03	66100.00
F21C2A	2017-07-14 05:57:00+03	69600.00
F21C6E	2017-07-13 00:59:00+03	97800.00
F21C97	2017-07-28 14:02:00+03	123000.00
F21C99	2017-08-07 12:45:00+03	8200.00
F21CBA	2017-08-14 19:04:00+03	89600.00
F21CE5	2017-07-12 05:25:00+03	62600.00
F21CF8	2017-07-07 13:25:00+03	39600.00
F21D02	2017-08-12 06:12:00+03	274200.00
F21DE4	2017-07-09 04:01:00+03	738000.00
F21DED	2017-07-31 21:20:00+03	136500.00
F21DFF	2017-06-30 23:36:00+03	68400.00
F21E03	2017-07-10 13:26:00+03	70600.00
F21E18	2017-08-02 13:16:00+03	257600.00
F21E3E	2017-07-21 05:45:00+03	38600.00
F21E3F	2017-08-10 06:32:00+03	40600.00
F21E94	2017-08-12 05:35:00+03	46300.00
F21EAE	2017-08-11 01:06:00+03	168000.00
F21EB9	2017-08-13 13:31:00+03	33100.00
F21EC8	2017-08-12 23:04:00+03	35200.00
F21EDF	2017-07-30 08:26:00+03	38600.00
F21EF7	2017-08-03 04:42:00+03	46200.00
F21FAD	2017-07-23 05:15:00+03	265200.00
F21FBA	2017-08-10 00:54:00+03	127800.00
F21FC6	2017-07-08 17:39:00+03	12200.00
F22017	2017-07-07 01:31:00+03	66600.00
F22060	2017-08-13 06:11:00+03	23200.00
F22090	2017-07-04 08:24:00+03	115100.00
F22096	2017-07-03 07:15:00+03	169900.00
F220BA	2017-07-21 09:15:00+03	92800.00
F221EE	2017-07-25 14:57:00+03	50600.00
F2221B	2017-08-03 16:37:00+03	90400.00
F2225A	2017-08-08 10:18:00+03	135400.00
F2229A	2017-07-14 20:07:00+03	28800.00
F222A0	2017-08-14 08:46:00+03	18300.00
F222B4	2017-07-06 04:39:00+03	46400.00
F222D8	2017-08-02 21:12:00+03	36200.00
F2232A	2017-08-10 22:45:00+03	132800.00
F22336	2017-08-02 16:08:00+03	23200.00
F22350	2017-07-14 05:16:00+03	28000.00
F2236C	2017-07-14 07:11:00+03	95700.00
F2236F	2017-07-19 16:24:00+03	18000.00
F223C7	2017-07-20 18:09:00+03	34000.00
F22426	2017-07-31 04:45:00+03	28000.00
F2245C	2017-07-01 07:25:00+03	9200.00
F224DF	2017-07-09 19:55:00+03	123000.00
F224E4	2017-07-26 15:15:00+03	66800.00
F2255F	2017-07-11 02:19:00+03	56600.00
F22582	2017-08-14 22:04:00+03	260300.00
F22583	2017-07-27 01:54:00+03	90800.00
F22588	2017-07-04 15:36:00+03	83400.00
F22589	2017-08-14 22:57:00+03	37900.00
F225D4	2017-08-14 11:47:00+03	10700.00
F225D6	2017-07-15 08:07:00+03	28800.00
F2265B	2017-07-01 10:23:00+03	69400.00
F2265F	2017-07-12 06:21:00+03	69500.00
F2269D	2017-07-13 21:22:00+03	124200.00
F22721	2017-07-07 13:49:00+03	246000.00
F22786	2017-06-30 23:38:00+03	89200.00
F227C4	2017-06-28 22:22:00+03	133700.00
F2280C	2017-07-31 17:55:00+03	52000.00
F2280E	2017-08-14 12:29:00+03	48900.00
F22820	2017-07-30 05:52:00+03	23600.00
F22828	2017-08-06 18:45:00+03	61800.00
F2282A	2017-08-11 09:27:00+03	133100.00
F2287A	2017-07-12 19:44:00+03	108500.00
F2288F	2017-08-01 22:41:00+03	134700.00
F228B5	2017-07-27 20:23:00+03	250400.00
F228C0	2017-07-15 20:40:00+03	54500.00
F228D5	2017-08-10 05:01:00+03	23600.00
F22903	2017-08-03 04:02:00+03	115600.00
F229DB	2017-07-21 02:05:00+03	13700.00
F229E4	2017-06-30 14:02:00+03	131100.00
F22A03	2017-08-10 01:47:00+03	46400.00
F22A22	2017-08-09 18:09:00+03	24800.00
F22A2D	2017-07-23 08:31:00+03	9200.00
F22A37	2017-08-12 18:17:00+03	86100.00
F22A9B	2017-07-20 15:08:00+03	112000.00
F22AAA	2017-07-04 23:59:00+03	115000.00
F22AEF	2017-08-14 16:29:00+03	28800.00
F22B25	2017-07-02 06:49:00+03	28000.00
F22B32	2017-07-22 21:13:00+03	25600.00
F22B45	2017-08-06 12:57:00+03	28000.00
F22B64	2017-07-03 04:56:00+03	70700.00
F22BC4	2017-07-11 03:06:00+03	55800.00
F22BC8	2017-07-12 09:59:00+03	47000.00
F22C23	2017-07-15 02:51:00+03	61800.00
F22C38	2017-08-05 22:04:00+03	27200.00
F22C8D	2017-07-27 20:03:00+03	133100.00
F22CA6	2017-07-06 15:28:00+03	325600.00
F22D81	2017-08-01 20:19:00+03	7400.00
F22DE0	2017-07-27 03:45:00+03	71900.00
F22E13	2017-07-18 23:40:00+03	53300.00
F22E4F	2017-08-10 22:36:00+03	21600.00
F22EBB	2017-07-27 04:20:00+03	71600.00
F22F41	2017-07-20 00:45:00+03	46300.00
F22F9A	2017-07-30 19:25:00+03	12000.00
F22FBE	2017-07-27 16:02:00+03	61800.00
F23085	2017-07-08 06:33:00+03	112000.00
F230DA	2017-07-22 09:54:00+03	100600.00
F230EF	2017-07-27 23:27:00+03	12600.00
F23137	2017-07-30 07:30:00+03	56100.00
F23153	2017-07-13 03:20:00+03	199200.00
F23177	2017-08-09 04:18:00+03	89700.00
F2320F	2017-08-10 23:26:00+03	15400.00
F2321A	2017-07-24 23:32:00+03	265600.00
F23245	2017-07-11 10:46:00+03	66600.00
F23247	2017-07-19 15:30:00+03	67000.00
F23257	2017-07-15 18:04:00+03	67600.00
F2326C	2017-07-10 19:43:00+03	76900.00
F2330E	2017-08-12 03:43:00+03	23200.00
F23319	2017-07-10 09:06:00+03	14400.00
F23334	2017-08-11 12:42:00+03	22100.00
F2333B	2017-07-26 00:45:00+03	46300.00
F2339E	2017-08-15 05:51:00+03	46300.00
F23472	2017-08-10 23:43:00+03	33100.00
F2348C	2017-07-26 23:38:00+03	95200.00
F23497	2017-06-27 10:48:00+03	98400.00
F234A7	2017-07-12 07:11:00+03	23600.00
F234F7	2017-07-28 15:56:00+03	54400.00
F23501	2017-08-02 23:34:00+03	52400.00
F23511	2017-08-07 15:59:00+03	189800.00
F23674	2017-07-26 20:50:00+03	143600.00
F23717	2017-07-09 17:02:00+03	118100.00
F2375A	2017-07-13 01:59:00+03	55500.00
F237B0	2017-07-13 08:11:00+03	57500.00
F237E1	2017-08-14 18:35:00+03	33000.00
F2381D	2017-08-04 15:44:00+03	47800.00
F2384C	2017-08-06 22:10:00+03	59200.00
F2386D	2017-07-02 22:16:00+03	11700.00
F238CF	2017-07-13 20:02:00+03	138000.00
F238E7	2017-07-25 01:13:00+03	41600.00
F238EC	2017-07-18 10:43:00+03	136000.00
F23938	2017-07-20 06:55:00+03	15700.00
F2394A	2017-07-21 22:17:00+03	156500.00
F239B0	2017-07-25 17:22:00+03	52000.00
F239F5	2017-07-08 19:54:00+03	47100.00
F23A06	2017-07-15 18:06:00+03	20200.00
F23A25	2017-07-09 13:27:00+03	6800.00
F23A86	2017-07-06 21:18:00+03	36200.00
F23A93	2017-08-02 11:16:00+03	129400.00
F23B2C	2017-08-06 15:05:00+03	44800.00
F23B2E	2017-07-31 05:01:00+03	85000.00
F23B38	2017-07-18 16:19:00+03	246000.00
F23B44	2017-07-13 22:51:00+03	67000.00
F23B6B	2017-07-15 01:11:00+03	39800.00
F23B88	2017-07-26 02:54:00+03	99200.00
F23C01	2017-07-20 00:20:00+03	68100.00
F23C20	2017-07-21 18:33:00+03	43000.00
F23C5A	2017-07-22 02:55:00+03	46300.00
F23C66	2017-08-03 09:35:00+03	54800.00
F23C73	2017-08-03 06:50:00+03	67600.00
F23C77	2017-07-06 08:50:00+03	167400.00
F23CCC	2017-07-05 10:44:00+03	65600.00
F23CDE	2017-07-23 04:05:00+03	83600.00
F23CDF	2017-08-03 05:55:00+03	68000.00
F23D27	2017-08-03 07:22:00+03	34200.00
F23D8B	2017-07-08 03:50:00+03	270700.00
F23DC8	2017-08-01 07:44:00+03	19600.00
F23E23	2017-08-13 17:51:00+03	112000.00
F23E2C	2017-07-31 08:18:00+03	49100.00
F23EA4	2017-08-08 20:35:00+03	86800.00
F23EAC	2017-07-07 13:47:00+03	47500.00
F23ED0	2017-07-13 16:07:00+03	11600.00
F23EDF	2017-07-19 14:40:00+03	43900.00
F23F00	2017-08-06 12:41:00+03	39100.00
F23F15	2017-07-20 07:07:00+03	19600.00
F23F34	2017-08-14 07:56:00+03	21400.00
F23F61	2017-07-08 15:38:00+03	23500.00
F2402C	2017-07-16 21:13:00+03	18600.00
F24106	2017-07-21 10:03:00+03	18500.00
F24119	2017-08-03 15:34:00+03	38500.00
F24128	2017-08-01 16:59:00+03	50000.00
F2416C	2017-07-01 17:06:00+03	141600.00
F241A7	2017-07-21 10:46:00+03	67600.00
F241E1	2017-08-07 23:47:00+03	28800.00
F24252	2017-08-02 16:38:00+03	46400.00
F242DF	2017-07-31 15:31:00+03	6700.00
F242E3	2017-08-05 09:28:00+03	54500.00
F242F4	2017-07-31 04:57:00+03	40000.00
F24354	2017-07-12 03:14:00+03	57500.00
F243A1	2017-08-14 16:41:00+03	73200.00
F243C6	2017-07-10 17:07:00+03	270000.00
F2442C	2017-08-13 17:58:00+03	59800.00
F2443D	2017-06-24 13:37:00+03	13000.00
F24490	2017-08-12 22:36:00+03	12000.00
F244C1	2017-07-11 18:59:00+03	100000.00
F244D3	2017-07-18 08:21:00+03	56000.00
F244E0	2017-07-25 06:10:00+03	26000.00
F24578	2017-07-24 21:37:00+03	58600.00
F24625	2017-08-12 09:41:00+03	24400.00
F24671	2017-07-30 18:11:00+03	35800.00
F2467F	2017-07-03 06:29:00+03	67200.00
F24692	2017-08-06 01:01:00+03	23200.00
F24694	2017-07-28 14:18:00+03	57700.00
F246B5	2017-07-06 11:26:00+03	50000.00
F246D1	2017-07-03 18:20:00+03	67700.00
F24718	2017-08-15 02:55:00+03	48100.00
F2477D	2017-07-22 02:02:00+03	22000.00
F247AF	2017-07-18 16:52:00+03	119600.00
F247D7	2017-08-15 09:37:00+03	149000.00
F2487B	2017-07-20 02:42:00+03	131600.00
F248C5	2017-08-02 10:03:00+03	276800.00
F248CB	2017-07-14 16:52:00+03	6800.00
F24907	2017-08-02 15:46:00+03	35800.00
F24916	2017-07-31 18:19:00+03	27800.00
F24984	2017-08-14 13:15:00+03	9200.00
F24989	2017-08-03 16:10:00+03	80000.00
F24996	2017-08-10 05:52:00+03	6300.00
F2499E	2017-08-14 14:25:00+03	39200.00
F249A5	2017-08-12 08:41:00+03	22000.00
F249CA	2017-07-13 11:04:00+03	140500.00
F24A14	2017-07-30 04:09:00+03	24700.00
F24A59	2017-08-11 15:24:00+03	369000.00
F24A8C	2017-07-26 14:17:00+03	71900.00
F24B0F	2017-08-02 21:06:00+03	135600.00
F24B54	2017-08-05 23:54:00+03	16400.00
F24B9D	2017-07-28 03:12:00+03	62800.00
F24BA8	2017-08-06 11:13:00+03	25000.00
F24BEA	2017-07-17 06:23:00+03	81600.00
F24C03	2017-08-15 00:14:00+03	48800.00
F24C82	2017-07-10 21:31:00+03	31000.00
F24C8C	2017-07-26 15:58:00+03	87300.00
F24CC0	2017-07-22 19:58:00+03	58800.00
F24CD7	2017-07-12 01:42:00+03	15100.00
F24D9A	2017-08-09 14:44:00+03	185600.00
F24E99	2017-08-11 01:58:00+03	55600.00
F24EA2	2017-07-23 16:09:00+03	43200.00
F24F0B	2017-08-14 02:11:00+03	73100.00
F24F23	2017-07-08 14:47:00+03	28800.00
F24F46	2017-07-05 00:33:00+03	38800.00
F24F6A	2017-08-07 16:04:00+03	248500.00
F24FEE	2017-07-24 20:39:00+03	23200.00
F2502E	2017-07-01 04:04:00+03	27700.00
F25034	2017-07-07 02:59:00+03	49000.00
F2503C	2017-08-10 22:11:00+03	399600.00
F25059	2017-07-01 05:45:00+03	68600.00
F250BC	2017-07-21 06:21:00+03	22000.00
F25125	2017-08-11 15:22:00+03	182300.00
F2516E	2017-08-06 01:38:00+03	290500.00
F2516F	2017-07-02 18:16:00+03	89600.00
F25198	2017-07-13 17:33:00+03	89600.00
F251DC	2017-07-19 00:16:00+03	27300.00
F251FA	2017-07-15 08:19:00+03	95000.00
F25262	2017-07-25 14:05:00+03	285700.00
F25264	2017-07-14 19:33:00+03	114800.00
F25328	2017-07-03 00:00:00+03	57600.00
F25435	2017-07-08 00:17:00+03	277800.00
F25448	2017-07-30 02:35:00+03	95300.00
F25464	2017-07-13 14:08:00+03	12000.00
F254B0	2017-07-09 04:54:00+03	67600.00
F254FA	2017-07-22 17:43:00+03	252000.00
F25504	2017-08-03 00:36:00+03	51800.00
F2552E	2017-08-15 17:06:00+03	72400.00
F25591	2017-08-02 22:43:00+03	40100.00
F25592	2017-07-12 07:23:00+03	82500.00
F255DB	2017-07-09 09:42:00+03	23600.00
F25620	2017-07-23 15:24:00+03	10600.00
F256BC	2017-08-04 02:58:00+03	52000.00
F2577F	2017-07-25 18:24:00+03	109600.00
F257CD	2017-08-05 15:45:00+03	270800.00
F2583F	2017-08-12 22:24:00+03	52900.00
F25890	2017-07-09 00:51:00+03	23200.00
F259E3	2017-07-22 09:03:00+03	86800.00
F25A28	2017-08-04 21:57:00+03	28300.00
F25A31	2017-07-15 00:49:00+03	62800.00
F25A38	2017-08-02 15:28:00+03	11800.00
F25AFF	2017-07-08 00:50:00+03	141100.00
F25B15	2017-07-09 14:28:00+03	188100.00
F25B26	2017-07-02 17:06:00+03	69500.00
F25B38	2017-08-11 03:04:00+03	131100.00
F25B61	2017-07-07 06:11:00+03	44600.00
F25C18	2017-07-15 23:29:00+03	29600.00
F25C27	2017-07-03 02:33:00+03	13400.00
F25C29	2017-07-24 19:53:00+03	270800.00
F25C3A	2017-08-13 13:59:00+03	112000.00
F25CAD	2017-08-13 15:31:00+03	29400.00
F25D2E	2017-07-01 11:34:00+03	148200.00
F25D57	2017-08-08 02:23:00+03	44600.00
F25DD0	2017-08-06 00:40:00+03	37900.00
F25DD2	2017-08-10 07:55:00+03	31600.00
F25DEF	2017-07-03 03:29:00+03	98200.00
F25E3B	2017-07-28 15:46:00+03	86600.00
F25EC4	2017-07-26 15:42:00+03	26200.00
F25ED0	2017-07-26 16:48:00+03	133200.00
F25F43	2017-07-06 18:01:00+03	44800.00
F25F63	2017-07-24 22:53:00+03	193700.00
F26074	2017-07-24 00:45:00+03	25600.00
F260AA	2017-08-14 00:17:00+03	250400.00
F260BA	2017-08-10 05:03:00+03	97800.00
F261B0	2017-07-16 03:59:00+03	24300.00
F261C1	2017-07-02 17:30:00+03	62600.00
F261FA	2017-08-01 22:10:00+03	369000.00
F26273	2017-07-07 13:57:00+03	193200.00
F26288	2017-07-02 01:06:00+03	23600.00
F26293	2017-07-14 03:41:00+03	152900.00
F2635D	2017-08-01 00:15:00+03	23600.00
F26388	2017-07-03 00:49:00+03	191200.00
F26389	2017-07-14 00:47:00+03	43000.00
F263B5	2017-08-11 19:43:00+03	103100.00
F2648A	2017-08-13 07:16:00+03	240600.00
F264BE	2017-07-21 12:50:00+03	64400.00
F264F2	2017-07-19 09:16:00+03	43200.00
F2650F	2017-07-19 09:11:00+03	54800.00
F26597	2017-08-06 09:56:00+03	37900.00
F265B1	2017-07-15 11:06:00+03	13400.00
F265BB	2017-07-14 22:25:00+03	67800.00
F265F5	2017-08-09 02:21:00+03	147100.00
F26620	2017-06-30 09:45:00+03	135600.00
F26633	2017-07-09 09:08:00+03	169300.00
F2672A	2017-08-10 23:36:00+03	47100.00
F26773	2017-08-11 07:48:00+03	31600.00
F26779	2017-08-13 15:48:00+03	23100.00
F2678E	2017-06-29 13:11:00+03	398600.00
F267C0	2017-07-22 05:40:00+03	38000.00
F2687C	2017-07-29 10:48:00+03	40400.00
F26916	2017-07-30 10:50:00+03	37900.00
F2691A	2017-06-29 17:11:00+03	40800.00
F2694A	2017-07-10 21:47:00+03	29200.00
F2695A	2017-08-03 14:49:00+03	24200.00
F269EF	2017-08-14 04:08:00+03	13200.00
F26A32	2017-07-23 00:07:00+03	19800.00
F26A33	2017-07-10 06:34:00+03	50000.00
F26AD6	2017-08-10 09:41:00+03	31400.00
F26B22	2017-07-07 22:40:00+03	36400.00
F26B71	2017-07-15 21:05:00+03	27400.00
F26BC0	2017-07-12 15:08:00+03	95200.00
F26BC8	2017-08-07 09:21:00+03	52000.00
F26BCA	2017-07-17 07:00:00+03	27800.00
F26BFE	2017-08-12 21:12:00+03	52700.00
F26C41	2017-07-05 12:22:00+03	246000.00
F26CC9	2017-07-19 05:04:00+03	13600.00
F26D26	2017-07-23 04:12:00+03	130000.00
F26D4D	2017-08-11 08:16:00+03	61800.00
F26D9C	2017-07-30 13:43:00+03	8400.00
F26ED6	2017-08-06 08:24:00+03	32800.00
F26F2C	2017-08-10 13:28:00+03	284400.00
F26F33	2017-07-15 19:22:00+03	82600.00
F26F51	2017-07-22 22:57:00+03	174600.00
F26F64	2017-07-15 04:06:00+03	65600.00
F26F9D	2017-07-28 03:32:00+03	67600.00
F26FAE	2017-07-09 14:41:00+03	111600.00
F26FD0	2017-07-06 06:02:00+03	72800.00
F26FD9	2017-07-27 21:20:00+03	35200.00
F2701B	2017-07-03 03:31:00+03	84100.00
F2702E	2017-08-14 04:05:00+03	167500.00
F2705D	2017-07-25 07:55:00+03	16400.00
F27080	2017-07-22 22:08:00+03	384900.00
F270E3	2017-07-05 22:16:00+03	47000.00
F27146	2017-08-07 01:20:00+03	136200.00
F2715A	2017-08-01 12:44:00+03	6000.00
F27224	2017-08-06 02:08:00+03	22400.00
F272DC	2017-07-01 23:39:00+03	25200.00
F2739A	2017-08-08 00:09:00+03	52000.00
F273FB	2017-07-18 04:04:00+03	611700.00
F27460	2017-07-10 17:57:00+03	16800.00
F274B7	2017-07-14 20:16:00+03	62600.00
F274E2	2017-07-14 10:07:00+03	31400.00
F27523	2017-07-30 04:04:00+03	27200.00
F275B2	2017-08-10 11:59:00+03	67600.00
F275F2	2017-07-09 12:41:00+03	31400.00
F275F4	2017-07-02 04:52:00+03	27600.00
F276C8	2017-07-24 04:21:00+03	43200.00
F276EB	2017-06-29 23:06:00+03	100600.00
F27760	2017-07-16 19:05:00+03	22000.00
F277B8	2017-06-29 14:39:00+03	49700.00
F277FF	2017-07-30 04:46:00+03	66900.00
F27860	2017-07-28 10:00:00+03	77200.00
F27879	2017-07-24 05:30:00+03	266400.00
F278B0	2017-08-13 18:59:00+03	68800.00
F278B2	2017-08-08 18:44:00+03	117600.00
F278C2	2017-08-05 13:15:00+03	91200.00
F278C7	2017-08-15 05:51:00+03	106600.00
F278D5	2017-07-18 03:34:00+03	9200.00
F27915	2017-06-29 14:55:00+03	13400.00
F279F0	2017-07-09 10:22:00+03	47200.00
F27A26	2017-07-30 22:17:00+03	36200.00
F27A7C	2017-07-14 21:15:00+03	14400.00
F27AD7	2017-08-08 03:32:00+03	40000.00
F27B1C	2017-07-14 20:38:00+03	65900.00
F27B51	2017-07-28 18:49:00+03	28800.00
F27BD8	2017-08-01 09:29:00+03	136200.00
F27BFF	2017-07-29 03:48:00+03	123600.00
F27CED	2017-07-18 11:23:00+03	12600.00
F27D2A	2017-08-08 14:43:00+03	67600.00
F27D30	2017-07-03 06:36:00+03	13000.00
F27D5F	2017-08-08 09:13:00+03	151200.00
F27D63	2017-07-12 16:34:00+03	63200.00
F27DE8	2017-07-10 17:12:00+03	53300.00
F27E26	2017-07-22 15:50:00+03	535300.00
F27F08	2017-07-18 04:29:00+03	28800.00
F27F45	2017-07-09 03:56:00+03	41400.00
F27F52	2017-08-01 10:29:00+03	75600.00
F27F7C	2017-08-07 18:36:00+03	56100.00
F27FDA	2017-07-06 05:52:00+03	95300.00
F28031	2017-07-17 02:52:00+03	23200.00
F28038	2017-07-19 02:21:00+03	87300.00
F28066	2017-07-30 21:13:00+03	28000.00
F28073	2017-08-14 17:14:00+03	26800.00
F28096	2017-07-28 01:01:00+03	13300.00
F280F6	2017-07-02 17:09:00+03	28000.00
F280F8	2017-06-28 22:01:00+03	98400.00
F280FF	2017-08-02 01:40:00+03	164600.00
F28171	2017-07-10 16:55:00+03	52000.00
F281D3	2017-07-24 09:20:00+03	179300.00
F28304	2017-07-25 22:51:00+03	27800.00
F28326	2017-07-18 06:18:00+03	64200.00
F2841E	2017-07-08 05:12:00+03	13300.00
F28423	2017-06-29 11:30:00+03	136400.00
F28429	2017-07-30 21:40:00+03	123000.00
F2843B	2017-07-17 16:31:00+03	123600.00
F2843F	2017-07-28 16:11:00+03	40800.00
F28513	2017-07-12 23:21:00+03	12400.00
F28599	2017-07-26 23:26:00+03	148200.00
F28644	2017-07-04 02:36:00+03	110000.00
F2869F	2017-07-29 14:15:00+03	23900.00
F286B6	2017-07-16 05:03:00+03	19600.00
F286B8	2017-07-14 06:38:00+03	19600.00
F286C2	2017-08-07 23:31:00+03	23600.00
F286D7	2017-07-22 06:55:00+03	83300.00
F286DD	2017-07-31 02:29:00+03	68800.00
F286F1	2017-07-28 05:40:00+03	125400.00
F28710	2017-07-29 12:04:00+03	31600.00
F2876C	2017-07-02 00:55:00+03	26800.00
F287C8	2017-07-18 03:46:00+03	24400.00
F287DD	2017-07-19 20:09:00+03	85000.00
F2882A	2017-07-02 01:07:00+03	46300.00
F28879	2017-07-13 07:10:00+03	106400.00
F288A4	2017-07-05 12:14:00+03	6300.00
F288B7	2017-08-06 06:41:00+03	28800.00
F288C2	2017-08-05 12:28:00+03	87000.00
F28968	2017-08-09 22:17:00+03	75300.00
F289EF	2017-07-29 19:30:00+03	80100.00
F28A15	2017-08-08 10:01:00+03	136200.00
F28A54	2017-07-16 00:32:00+03	255600.00
F28A86	2017-08-14 11:35:00+03	77400.00
F28A99	2017-07-16 20:09:00+03	13600.00
F28AA0	2017-07-13 15:35:00+03	46300.00
F28AB7	2017-06-28 03:40:00+03	56100.00
F28B81	2017-07-25 18:37:00+03	40000.00
F28BDE	2017-08-09 14:15:00+03	68800.00
F28D14	2017-07-23 19:30:00+03	149400.00
F28D1C	2017-07-18 12:07:00+03	13600.00
F28DF3	2017-07-15 08:54:00+03	57700.00
F28E27	2017-07-25 04:06:00+03	16800.00
F28E5C	2017-08-09 12:06:00+03	27900.00
F28E85	2017-07-13 19:18:00+03	24700.00
F28F1D	2017-07-19 19:25:00+03	23200.00
F28F46	2017-07-06 17:45:00+03	47100.00
F28F5A	2017-06-30 20:19:00+03	24400.00
F28F77	2017-07-21 22:40:00+03	194300.00
F28FF6	2017-07-05 11:37:00+03	24400.00
F28FFD	2017-07-20 00:35:00+03	110500.00
F2903A	2017-08-05 19:48:00+03	199800.00
F2904B	2017-07-27 04:24:00+03	93900.00
F2907B	2017-07-23 20:24:00+03	49600.00
F2911C	2017-07-12 22:16:00+03	196800.00
F2916B	2017-07-07 09:36:00+03	39000.00
F291E8	2017-08-07 11:22:00+03	49200.00
F29223	2017-07-09 10:54:00+03	92400.00
F29270	2017-08-07 17:47:00+03	103500.00
F29274	2017-07-09 20:40:00+03	246000.00
F2935E	2017-07-27 05:51:00+03	48400.00
F29379	2017-06-29 00:48:00+03	47800.00
F293C7	2017-07-17 10:30:00+03	149800.00
F293D5	2017-07-05 17:49:00+03	88100.00
F29484	2017-07-15 11:56:00+03	135400.00
F294C3	2017-07-30 07:22:00+03	47400.00
F29525	2017-08-01 19:31:00+03	45200.00
F295FA	2017-08-05 09:57:00+03	160800.00
F29623	2017-07-27 18:45:00+03	56000.00
F29671	2017-07-02 16:52:00+03	28800.00
F2967B	2017-08-11 10:58:00+03	189200.00
F296B4	2017-08-01 03:50:00+03	22000.00
F29703	2017-07-13 16:49:00+03	13600.00
F29743	2017-07-14 19:55:00+03	18600.00
F297BE	2017-07-19 06:27:00+03	32800.00
F297E3	2017-07-20 00:24:00+03	57600.00
F29825	2017-07-17 06:19:00+03	28000.00
F2984F	2017-07-21 09:19:00+03	26000.00
F29856	2017-06-29 18:08:00+03	90800.00
F29975	2017-07-03 12:33:00+03	57800.00
F29987	2017-07-13 16:11:00+03	69600.00
F299B3	2017-07-05 03:16:00+03	111600.00
F29A47	2017-08-11 22:03:00+03	28800.00
F29A54	2017-08-11 00:22:00+03	80000.00
F29A90	2017-07-25 10:14:00+03	86800.00
F29AB8	2017-08-08 11:54:00+03	37900.00
F29ABB	2017-07-31 16:12:00+03	40800.00
F29B06	2017-07-20 12:34:00+03	52100.00
F29B12	2017-07-07 12:02:00+03	69000.00
F29B6D	2017-07-27 16:30:00+03	48800.00
F29B9E	2017-07-22 05:26:00+03	50200.00
F29C09	2017-08-08 10:28:00+03	35800.00
F29C2C	2017-07-16 07:30:00+03	39600.00
F29C63	2017-07-03 22:03:00+03	16800.00
F29CC8	2017-07-30 19:03:00+03	28000.00
F29CD3	2017-08-07 09:51:00+03	63500.00
F29D3A	2017-07-16 00:32:00+03	75300.00
F29D8C	2017-08-11 20:41:00+03	117600.00
F29D8E	2017-08-05 18:43:00+03	29600.00
F29DC2	2017-07-17 10:25:00+03	127300.00
F29DDF	2017-07-22 19:15:00+03	12600.00
F29E14	2017-07-14 17:18:00+03	23200.00
F29E2B	2017-07-07 20:29:00+03	177200.00
F29ECB	2017-08-09 19:35:00+03	28000.00
F29EFB	2017-08-12 16:07:00+03	112000.00
F29F1A	2017-07-16 05:25:00+03	49100.00
F29F40	2017-07-16 21:45:00+03	31600.00
F29F48	2017-07-16 19:54:00+03	25600.00
F29F70	2017-07-11 05:55:00+03	23400.00
F29F7B	2017-07-16 22:52:00+03	60300.00
F29F96	2017-07-28 15:09:00+03	71600.00
F29FB0	2017-07-09 07:29:00+03	36800.00
F29FDD	2017-06-30 08:52:00+03	163600.00
F29FE3	2017-08-04 16:19:00+03	24800.00
F2A033	2017-07-11 12:22:00+03	16400.00
F2A03A	2017-07-13 14:21:00+03	73200.00
F2A060	2017-07-28 21:11:00+03	24400.00
F2A0A5	2017-07-07 10:46:00+03	47400.00
F2A120	2017-08-07 22:33:00+03	7400.00
F2A149	2017-07-06 03:04:00+03	23400.00
F2A163	2017-07-12 11:58:00+03	70800.00
F2A177	2017-07-29 13:23:00+03	193700.00
F2A18D	2017-08-05 15:53:00+03	47400.00
F2A1AD	2017-08-12 09:37:00+03	133100.00
F2A1FD	2017-07-27 23:15:00+03	26800.00
F2A1FE	2017-06-30 10:18:00+03	101200.00
F2A22C	2017-07-06 03:14:00+03	193100.00
F2A293	2017-07-20 15:14:00+03	324700.00
F2A29B	2017-07-11 10:49:00+03	67600.00
F2A2DE	2017-06-30 03:44:00+03	42400.00
F2A2E5	2017-07-06 20:59:00+03	67100.00
F2A313	2017-08-11 23:19:00+03	48800.00
F2A373	2017-07-20 21:16:00+03	18100.00
F2A391	2017-07-25 09:57:00+03	36200.00
F2A3BB	2017-07-16 06:29:00+03	90000.00
F2A4B8	2017-07-14 03:27:00+03	58600.00
F2A4E8	2017-08-14 04:03:00+03	119500.00
F2A54E	2017-08-08 12:28:00+03	79200.00
F2A550	2017-07-10 00:50:00+03	152200.00
F2A57A	2017-08-12 11:06:00+03	54000.00
F2A619	2017-07-26 12:54:00+03	24000.00
F2A665	2017-08-15 00:24:00+03	99500.00
F2A66E	2017-07-20 22:06:00+03	29600.00
F2A674	2017-08-04 19:44:00+03	22000.00
F2A686	2017-07-10 05:54:00+03	109600.00
F2A6C5	2017-07-24 06:43:00+03	16300.00
F2A738	2017-07-31 03:08:00+03	16800.00
F2A7EA	2017-07-16 06:22:00+03	28000.00
F2A82A	2017-07-01 05:30:00+03	25900.00
F2A886	2017-07-26 20:03:00+03	65600.00
F2A8A7	2017-07-26 20:55:00+03	111600.00
F2A903	2017-07-12 22:30:00+03	45700.00
F2A911	2017-08-09 00:36:00+03	56900.00
F2A951	2017-07-23 11:08:00+03	398500.00
F2A979	2017-07-14 21:17:00+03	83000.00
F2AA41	2017-07-22 22:17:00+03	13800.00
F2AA75	2017-07-22 08:04:00+03	38600.00
F2AA91	2017-07-28 16:08:00+03	269200.00
F2AA99	2017-08-11 04:37:00+03	91500.00
F2AABC	2017-07-10 00:25:00+03	40800.00
F2AAD0	2017-07-13 14:43:00+03	41200.00
F2AB5C	2017-07-29 07:27:00+03	29100.00
F2AB8F	2017-07-09 17:36:00+03	39800.00
F2ABC4	2017-08-01 15:23:00+03	7200.00
F2ABDD	2017-07-04 20:15:00+03	25800.00
F2AC5C	2017-08-15 06:55:00+03	80000.00
F2ACD1	2017-08-04 15:23:00+03	68400.00
F2AD39	2017-07-01 09:31:00+03	38400.00
F2AD67	2017-08-10 09:48:00+03	30000.00
F2AD77	2017-07-07 08:46:00+03	109600.00
F2ADA1	2017-07-15 11:40:00+03	40600.00
F2ADA4	2017-08-10 12:01:00+03	69600.00
F2ADB5	2017-07-17 05:00:00+03	27300.00
F2ADC7	2017-07-09 03:19:00+03	26000.00
F2ADD1	2017-08-14 00:28:00+03	27300.00
F2ADDB	2017-08-07 09:50:00+03	289800.00
F2ADE6	2017-06-30 21:34:00+03	86800.00
F2AE3C	2017-08-13 23:07:00+03	74400.00
F2AE66	2017-07-31 03:05:00+03	75300.00
F2AF0A	2017-06-26 03:26:00+03	23900.00
F2AFDE	2017-07-26 15:17:00+03	31600.00
F2B046	2017-07-17 00:08:00+03	112000.00
F2B07B	2017-07-14 03:18:00+03	56600.00
F2B084	2017-08-13 07:41:00+03	275400.00
F2B0F0	2017-07-18 15:36:00+03	14000.00
F2B112	2017-07-31 06:21:00+03	390400.00
F2B117	2017-07-21 08:52:00+03	61900.00
F2B1C8	2017-07-26 22:39:00+03	120600.00
F2B1EC	2017-07-20 03:08:00+03	28300.00
F2B26C	2017-07-15 23:13:00+03	26000.00
F2B2FD	2017-07-27 13:08:00+03	420200.00
F2B2FF	2017-08-11 13:07:00+03	21800.00
F2B326	2017-06-29 22:13:00+03	21400.00
F2B380	2017-08-06 10:00:00+03	29400.00
F2B463	2017-07-28 19:13:00+03	62600.00
F2B4A6	2017-08-01 13:37:00+03	81300.00
F2B4F5	2017-07-15 00:37:00+03	47800.00
F2B537	2017-08-04 16:49:00+03	17800.00
F2B53E	2017-07-21 21:19:00+03	40000.00
F2B553	2017-08-09 06:29:00+03	98400.00
F2B568	2017-08-06 07:11:00+03	92800.00
F2B5A5	2017-08-05 17:10:00+03	131100.00
F2B5DB	2017-08-09 22:35:00+03	27400.00
F2B6A3	2017-08-14 21:36:00+03	184800.00
F2B6D8	2017-07-05 22:43:00+03	63200.00
F2B6FE	2017-07-04 00:46:00+03	56000.00
F2B71F	2017-07-23 19:36:00+03	19800.00
F2B792	2017-08-13 10:15:00+03	65900.00
F2B7C7	2017-08-12 06:37:00+03	25200.00
F2B802	2017-08-08 19:06:00+03	39300.00
F2B813	2017-07-13 09:35:00+03	125200.00
F2B829	2017-07-15 07:38:00+03	53400.00
F2B84D	2017-07-09 14:09:00+03	49600.00
F2B8CE	2017-08-11 13:11:00+03	50600.00
F2B923	2017-07-25 05:55:00+03	46400.00
F2B92D	2017-07-02 21:46:00+03	77500.00
F2BA00	2017-07-25 12:06:00+03	106100.00
F2BA2B	2017-07-04 09:03:00+03	16400.00
F2BAB9	2017-07-24 00:30:00+03	289800.00
F2BAFD	2017-07-16 16:49:00+03	23200.00
F2BB02	2017-07-27 06:41:00+03	32800.00
F2BB35	2017-07-16 18:17:00+03	68800.00
F2BB4B	2017-07-17 08:00:00+03	12600.00
F2BB54	2017-07-06 19:21:00+03	81600.00
F2BBC0	2017-08-05 03:26:00+03	25200.00
F2BBC1	2017-07-07 03:11:00+03	177200.00
F2BC05	2017-07-12 21:12:00+03	55800.00
F2BC34	2017-07-27 06:20:00+03	313800.00
F2BC44	2017-07-15 06:16:00+03	260900.00
F2BC7F	2017-07-11 14:51:00+03	28000.00
F2BCE4	2017-07-04 06:25:00+03	93900.00
F2BCFE	2017-07-29 03:18:00+03	100600.00
F2BD26	2017-07-15 12:40:00+03	75300.00
F2BD3A	2017-07-31 09:16:00+03	43500.00
F2BDE3	2017-07-22 05:58:00+03	83000.00
F2BE58	2017-07-31 22:59:00+03	184300.00
F2BF1D	2017-08-15 09:26:00+03	87900.00
F2BF63	2017-07-02 17:50:00+03	94000.00
F2C000	2017-07-17 17:06:00+03	213800.00
F2C03E	2017-07-16 07:48:00+03	61500.00
F2C05F	2017-07-20 10:02:00+03	67200.00
F2C078	2017-07-24 19:45:00+03	24700.00
F2C0DA	2017-07-11 03:04:00+03	39900.00
F2C0F2	2017-07-17 08:45:00+03	54500.00
F2C0FF	2017-07-01 06:20:00+03	162400.00
F2C122	2017-07-01 12:28:00+03	133200.00
F2C165	2017-07-17 04:09:00+03	53600.00
F2C169	2017-07-06 05:28:00+03	265700.00
F2C1A0	2017-08-02 16:44:00+03	39100.00
F2C1D5	2017-06-29 22:34:00+03	74400.00
F2C1E9	2017-07-08 09:24:00+03	57400.00
F2C202	2017-07-26 02:37:00+03	384400.00
F2C3AD	2017-07-06 04:19:00+03	27700.00
F2C3DA	2017-07-07 22:42:00+03	29800.00
F2C402	2017-07-06 15:02:00+03	119600.00
F2C423	2017-07-26 02:18:00+03	85000.00
F2C451	2017-07-17 17:40:00+03	132800.00
F2C471	2017-08-12 06:50:00+03	129500.00
F2C474	2017-07-29 09:21:00+03	56900.00
F2C4AC	2017-08-14 12:06:00+03	246000.00
F2C4C1	2017-07-15 14:06:00+03	55800.00
F2C51E	2017-07-29 16:55:00+03	23400.00
F2C54C	2017-08-08 02:32:00+03	56100.00
F2C566	2017-07-29 18:13:00+03	23200.00
F2C573	2017-08-03 10:07:00+03	22100.00
F2C574	2017-07-14 00:19:00+03	65600.00
F2C581	2017-07-17 03:32:00+03	139300.00
F2C59F	2017-08-11 03:20:00+03	26000.00
F2C642	2017-07-22 18:43:00+03	57500.00
F2C65E	2017-07-24 21:50:00+03	39600.00
F2C716	2017-07-05 20:38:00+03	72800.00
F2C756	2017-07-09 04:38:00+03	117700.00
F2C75A	2017-07-27 17:54:00+03	29800.00
F2C7B3	2017-08-02 08:57:00+03	53300.00
F2C7B9	2017-07-04 21:34:00+03	23400.00
F2C7F6	2017-08-14 02:29:00+03	85000.00
F2C828	2017-07-29 19:46:00+03	303500.00
F2C92D	2017-07-20 12:14:00+03	16400.00
F2C957	2017-08-03 02:47:00+03	73600.00
F2C99B	2017-07-13 18:10:00+03	145300.00
F2C9A1	2017-07-23 16:39:00+03	26700.00
F2CA0F	2017-07-20 15:26:00+03	56000.00
F2CA50	2017-08-09 02:17:00+03	42800.00
F2CABB	2017-08-10 20:01:00+03	46900.00
F2CAC0	2017-07-17 22:16:00+03	24800.00
F2CB00	2017-07-27 07:12:00+03	23600.00
F2CB10	2017-07-11 13:55:00+03	42900.00
F2CB22	2017-08-07 14:47:00+03	12200.00
F2CB23	2017-07-08 06:58:00+03	18900.00
F2CB42	2017-08-02 22:14:00+03	47000.00
F2CB48	2017-07-22 00:42:00+03	203800.00
F2CB8E	2017-07-11 12:07:00+03	9800.00
F2CBE1	2017-07-19 04:39:00+03	113700.00
F2CBEB	2017-07-29 01:49:00+03	48500.00
F2CBFD	2017-08-09 22:22:00+03	33100.00
F2CC05	2017-07-23 06:43:00+03	17200.00
F2CC07	2017-08-12 16:31:00+03	28300.00
F2CC59	2017-08-01 20:36:00+03	23200.00
F2CC6A	2017-07-21 15:27:00+03	23600.00
F2CCC3	2017-07-19 00:39:00+03	23400.00
F2CCD6	2017-07-02 21:58:00+03	26800.00
F2CCE0	2017-07-16 01:14:00+03	273600.00
F2CCFF	2017-07-07 23:38:00+03	173200.00
F2CD12	2017-07-11 12:19:00+03	34000.00
F2CDE9	2017-07-09 14:31:00+03	258400.00
F2CDFC	2017-08-09 22:51:00+03	135200.00
F2CE14	2017-08-14 03:26:00+03	12000.00
F2CE2E	2017-07-11 13:59:00+03	35600.00
F2CE36	2017-07-17 01:40:00+03	46400.00
F2CE6B	2017-07-09 14:52:00+03	75600.00
F2CF1F	2017-07-14 20:22:00+03	32400.00
F2CF57	2017-07-22 12:27:00+03	26000.00
F2D021	2017-08-06 21:08:00+03	46200.00
F2D074	2017-07-21 04:10:00+03	39000.00
F2D0A0	2017-07-24 22:21:00+03	29600.00
F2D0FF	2017-08-09 09:59:00+03	14000.00
F2D204	2017-07-05 23:40:00+03	75300.00
F2D205	2017-07-10 00:03:00+03	38600.00
F2D208	2017-07-03 04:30:00+03	119700.00
F2D223	2017-07-28 10:23:00+03	26000.00
F2D271	2017-07-20 08:09:00+03	125600.00
F2D282	2017-07-10 11:19:00+03	91000.00
F2D2B8	2017-08-13 10:38:00+03	27200.00
F2D2F0	2017-07-10 15:42:00+03	19000.00
F2D335	2017-07-30 10:42:00+03	111600.00
F2D363	2017-07-24 19:38:00+03	25100.00
F2D403	2017-08-04 23:18:00+03	50600.00
F2D42E	2017-07-16 16:03:00+03	23600.00
F2D437	2017-07-26 01:05:00+03	29200.00
F2D472	2017-07-13 17:25:00+03	41800.00
F2D498	2017-07-26 21:15:00+03	43200.00
F2D4A0	2017-07-24 12:51:00+03	25400.00
F2D4D4	2017-07-29 14:34:00+03	75200.00
F2D53B	2017-07-28 01:12:00+03	132800.00
F2D58D	2017-07-20 18:59:00+03	66600.00
F2D617	2017-07-22 19:46:00+03	27600.00
F2D62E	2017-07-21 07:03:00+03	49600.00
F2D68B	2017-08-08 12:05:00+03	65900.00
F2D6A6	2017-07-21 10:35:00+03	66000.00
F2D6F4	2017-07-26 23:16:00+03	62800.00
F2D796	2017-07-25 22:57:00+03	55000.00
F2D827	2017-07-02 10:09:00+03	112000.00
F2D869	2017-08-15 09:34:00+03	38200.00
F2D8BE	2017-08-07 08:01:00+03	11300.00
F2D92F	2017-07-20 05:49:00+03	62600.00
F2D935	2017-07-08 06:48:00+03	64500.00
F2D969	2017-08-14 16:54:00+03	92900.00
F2D98C	2017-07-21 03:36:00+03	28000.00
F2D994	2017-08-06 15:47:00+03	28800.00
F2D9AF	2017-06-28 11:33:00+03	28800.00
F2DA09	2017-08-03 00:42:00+03	6700.00
F2DA6E	2017-08-13 03:20:00+03	81300.00
F2DAC9	2017-07-31 12:21:00+03	6000.00
F2DACB	2017-07-04 04:20:00+03	60400.00
F2DADB	2017-07-22 23:24:00+03	21800.00
F2DB09	2017-07-18 09:36:00+03	39500.00
F2DB1B	2017-06-29 10:12:00+03	139100.00
F2DB1F	2017-08-13 02:24:00+03	103900.00
F2DB27	2017-06-30 10:30:00+03	65900.00
F2DB33	2017-07-23 07:22:00+03	67200.00
F2DB72	2017-07-06 19:07:00+03	42400.00
F2DBB7	2017-08-04 04:53:00+03	182300.00
F2DBCF	2017-08-11 14:44:00+03	150600.00
F2DCA5	2017-07-15 06:02:00+03	103800.00
F2DCD0	2017-07-10 22:13:00+03	34000.00
F2DCF8	2017-07-09 11:06:00+03	17000.00
F2DD60	2017-08-06 23:03:00+03	25900.00
F2DDD0	2017-07-27 09:09:00+03	39200.00
F2DDE5	2017-07-22 03:25:00+03	35200.00
F2DE17	2017-08-07 11:38:00+03	50000.00
F2DE26	2017-08-01 09:09:00+03	178000.00
F2DE28	2017-07-03 18:07:00+03	46000.00
F2DE2B	2017-06-27 16:44:00+03	67700.00
F2DE37	2017-08-03 01:58:00+03	72600.00
F2DE51	2017-07-01 02:07:00+03	40000.00
F2DEA3	2017-08-13 10:54:00+03	83900.00
F2DED0	2017-08-11 02:25:00+03	278000.00
F2DF35	2017-08-11 17:34:00+03	36000.00
F2DF5F	2017-07-28 22:06:00+03	57300.00
F2E015	2017-08-04 16:51:00+03	115900.00
F2E067	2017-07-25 11:31:00+03	154800.00
F2E06B	2017-07-10 02:27:00+03	40800.00
F2E0E8	2017-08-10 21:49:00+03	26000.00
F2E172	2017-07-13 17:05:00+03	272600.00
F2E17E	2017-07-04 18:00:00+03	51900.00
F2E1C4	2017-08-13 12:16:00+03	25800.00
F2E1F8	2017-08-11 08:21:00+03	86200.00
F2E20E	2017-07-30 18:20:00+03	102100.00
F2E25D	2017-07-08 22:09:00+03	47800.00
F2E267	2017-07-17 23:35:00+03	16000.00
F2E276	2017-08-01 02:32:00+03	73600.00
F2E2D6	2017-08-06 06:20:00+03	70900.00
F2E31B	2017-07-09 22:15:00+03	24400.00
F2E383	2017-07-06 08:42:00+03	35900.00
F2E3F5	2017-07-01 01:11:00+03	83700.00
F2E41D	2017-07-23 21:16:00+03	11600.00
F2E45B	2017-07-23 02:12:00+03	27200.00
F2E46C	2017-07-13 12:16:00+03	26800.00
F2E4E1	2017-08-05 22:15:00+03	56600.00
F2E4E8	2017-07-02 16:23:00+03	70700.00
F2E50D	2017-07-17 06:46:00+03	348800.00
F2E518	2017-08-15 15:35:00+03	102100.00
F2E558	2017-08-04 19:36:00+03	182900.00
F2E55B	2017-07-20 04:36:00+03	48400.00
F2E686	2017-07-12 02:23:00+03	81700.00
F2E687	2017-08-02 08:48:00+03	25100.00
F2E6D6	2017-08-14 06:44:00+03	18100.00
F2E6FF	2017-07-30 06:37:00+03	35600.00
F2E7FD	2017-07-25 19:43:00+03	78500.00
F2E802	2017-07-31 15:11:00+03	46700.00
F2E853	2017-07-16 06:08:00+03	59600.00
F2E8CE	2017-08-04 04:00:00+03	135400.00
F2E8D6	2017-07-11 20:08:00+03	20400.00
F2E9C1	2017-08-06 15:49:00+03	28800.00
F2EA4C	2017-07-18 12:14:00+03	46200.00
F2EA8A	2017-08-08 00:54:00+03	42800.00
F2EAE6	2017-07-07 09:56:00+03	21800.00
F2EB39	2017-07-12 04:22:00+03	64500.00
F2EC55	2017-08-13 20:53:00+03	28000.00
F2EC58	2017-08-15 01:47:00+03	56000.00
F2EC6C	2017-08-11 14:27:00+03	7400.00
F2ECAB	2017-07-25 19:51:00+03	58200.00
F2ECB3	2017-08-13 20:21:00+03	24000.00
F2ECBB	2017-08-01 13:00:00+03	56100.00
F2ED0D	2017-07-15 03:04:00+03	58600.00
F2ED2A	2017-08-11 22:23:00+03	69500.00
F2EDA4	2017-07-05 08:00:00+03	38600.00
F2EE15	2017-08-06 18:28:00+03	23600.00
F2EE1F	2017-07-27 13:18:00+03	49500.00
F2EE4E	2017-08-11 12:14:00+03	11000.00
F2EE7F	2017-07-22 07:58:00+03	57600.00
F2EE8E	2017-06-28 19:58:00+03	97900.00
F2EEF7	2017-07-05 14:18:00+03	65100.00
F2EF4D	2017-07-23 18:29:00+03	64700.00
F2EFD7	2017-07-12 01:29:00+03	29000.00
F2F03D	2017-07-05 11:56:00+03	6600.00
F2F06D	2017-07-21 02:25:00+03	55800.00
F2F0F8	2017-07-26 04:33:00+03	6800.00
F2F121	2017-07-16 11:58:00+03	143200.00
F2F1B1	2017-08-13 23:16:00+03	68400.00
F2F1D6	2017-08-11 20:30:00+03	170900.00
F2F280	2017-08-09 04:16:00+03	25100.00
F2F2B2	2017-07-16 11:28:00+03	153300.00
F2F323	2017-07-15 19:25:00+03	135400.00
F2F39C	2017-07-01 13:51:00+03	57600.00
F2F3B9	2017-08-05 05:50:00+03	33200.00
F2F3D8	2017-08-08 03:49:00+03	59300.00
F2F40C	2017-07-27 08:45:00+03	46300.00
F2F40F	2017-07-14 10:48:00+03	22000.00
F2F410	2017-07-31 17:19:00+03	26000.00
F2F450	2017-07-09 05:29:00+03	117700.00
F2F463	2017-08-04 10:41:00+03	147700.00
F2F5D7	2017-08-12 04:21:00+03	35700.00
F2F5F3	2017-07-09 15:59:00+03	57500.00
F2F630	2017-07-29 19:21:00+03	280700.00
F2F679	2017-07-07 18:09:00+03	23600.00
F2F6AD	2017-08-04 19:23:00+03	62800.00
F2F6F3	2017-07-10 00:37:00+03	24200.00
F2F744	2017-07-30 09:41:00+03	59300.00
F2F794	2017-08-13 01:04:00+03	59300.00
F2F7AC	2017-07-30 07:22:00+03	12600.00
F2F7BC	2017-08-07 19:11:00+03	58600.00
F2F823	2017-07-23 04:33:00+03	14000.00
F2F885	2017-07-20 12:23:00+03	266400.00
F2F886	2017-08-09 23:09:00+03	146600.00
F2F8A3	2017-08-02 17:57:00+03	55800.00
F2F8DC	2017-07-10 08:56:00+03	25800.00
F2F900	2017-07-02 05:04:00+03	73300.00
F2F986	2017-07-24 22:05:00+03	27200.00
F2F9D2	2017-08-04 14:53:00+03	24200.00
F2FA41	2017-08-13 08:42:00+03	47600.00
F2FA4A	2017-08-15 05:09:00+03	26000.00
F2FA86	2017-07-28 04:05:00+03	125100.00
F2FA8F	2017-07-13 22:24:00+03	16400.00
F2FACD	2017-08-05 04:35:00+03	24400.00
F2FADD	2017-07-28 23:27:00+03	39000.00
F2FAE7	2017-07-17 17:25:00+03	58600.00
F2FB16	2017-07-26 23:52:00+03	26000.00
F2FB1C	2017-08-04 19:54:00+03	46000.00
F2FB3E	2017-07-16 09:08:00+03	103600.00
F2FB63	2017-07-20 16:23:00+03	398600.00
F2FB9C	2017-07-01 02:05:00+03	101800.00
F2FBC9	2017-08-12 18:01:00+03	35400.00
F2FBD0	2017-08-08 23:19:00+03	43900.00
F2FBE8	2017-08-09 05:10:00+03	186000.00
F2FC0B	2017-07-31 17:42:00+03	90400.00
F2FC1E	2017-08-15 11:35:00+03	68400.00
F2FC42	2017-08-15 05:27:00+03	40200.00
F2FC46	2017-08-05 20:32:00+03	273600.00
F2FC6B	2017-07-29 04:01:00+03	8400.00
F2FC9E	2017-07-31 17:58:00+03	52300.00
F2FD01	2017-07-26 06:33:00+03	85000.00
F2FD14	2017-08-12 02:52:00+03	46400.00
F2FD30	2017-08-15 07:21:00+03	226000.00
F2FDF9	2017-07-10 17:20:00+03	28000.00
F2FE44	2017-07-26 05:58:00+03	31400.00
F2FE55	2017-07-24 02:03:00+03	170000.00
F2FE70	2017-07-23 00:24:00+03	248300.00
F2FEA4	2017-08-10 01:19:00+03	40800.00
F2FEC6	2017-07-05 18:08:00+03	223700.00
F2FEE4	2017-07-16 17:58:00+03	75600.00
F2FEE7	2017-07-21 21:21:00+03	25600.00
F2FEE9	2017-07-25 21:23:00+03	146300.00
F2FF01	2017-07-05 12:46:00+03	99900.00
F2FF5E	2017-07-18 05:36:00+03	176600.00
F2FF63	2017-07-23 07:31:00+03	66300.00
F2FFB0	2017-07-11 14:58:00+03	55800.00
F2FFB7	2017-07-22 14:45:00+03	181600.00
F30007	2017-07-17 14:34:00+03	23400.00
F30039	2017-08-02 06:50:00+03	35600.00
F3003D	2017-08-04 14:47:00+03	96400.00
F300D1	2017-07-11 07:28:00+03	99200.00
F300FF	2017-07-04 10:04:00+03	22600.00
F3011F	2017-08-05 06:55:00+03	44800.00
F30187	2017-07-29 14:27:00+03	40100.00
F3018E	2017-07-24 00:37:00+03	7400.00
F301EA	2017-07-10 14:06:00+03	61800.00
F30211	2017-07-19 21:17:00+03	114400.00
F3024B	2017-08-07 07:55:00+03	25600.00
F3024C	2017-08-08 00:48:00+03	101100.00
F302D4	2017-08-04 03:50:00+03	159100.00
F30316	2017-08-05 10:09:00+03	56000.00
F30337	2017-07-08 21:51:00+03	85000.00
F303B5	2017-07-19 04:28:00+03	118600.00
F303B9	2017-08-12 18:08:00+03	48800.00
F303FA	2017-08-09 19:53:00+03	24400.00
F30420	2017-07-01 12:15:00+03	363800.00
F30478	2017-08-08 03:43:00+03	156300.00
F3047F	2017-07-15 14:33:00+03	184300.00
F3048C	2017-07-16 22:19:00+03	56000.00
F304CB	2017-08-13 13:53:00+03	23500.00
F30584	2017-07-15 18:29:00+03	62000.00
F3058D	2017-07-30 23:56:00+03	188000.00
F305D3	2017-08-15 06:01:00+03	55800.00
F30619	2017-07-16 03:11:00+03	6700.00
F30621	2017-07-24 13:54:00+03	28800.00
F30684	2017-07-22 10:54:00+03	37900.00
F30688	2017-07-16 05:16:00+03	19600.00
F306C7	2017-08-04 21:53:00+03	17200.00
F306C9	2017-07-13 07:19:00+03	25000.00
F30702	2017-08-12 02:28:00+03	71900.00
F30726	2017-08-13 23:14:00+03	32800.00
F30824	2017-07-19 03:02:00+03	40600.00
F3084C	2017-08-03 15:45:00+03	78600.00
F3089D	2017-07-24 07:03:00+03	24800.00
F308DF	2017-08-06 04:32:00+03	99300.00
F30904	2017-07-24 07:22:00+03	20400.00
F30929	2017-07-15 09:44:00+03	38400.00
F30973	2017-07-30 23:15:00+03	66600.00
F309DB	2017-08-06 07:29:00+03	6600.00
F309DF	2017-07-17 05:31:00+03	100600.00
F309EC	2017-07-30 14:31:00+03	57600.00
F30A16	2017-08-08 21:10:00+03	57600.00
F30A75	2017-07-14 22:53:00+03	653700.00
F30AF2	2017-07-11 07:33:00+03	56900.00
F30B17	2017-07-10 03:20:00+03	96200.00
F30B5B	2017-07-21 13:43:00+03	40000.00
F30BA6	2017-07-26 15:42:00+03	71200.00
F30BC0	2017-08-15 11:34:00+03	142200.00
F30BC4	2017-06-29 07:35:00+03	56000.00
F30BF3	2017-07-30 02:58:00+03	88900.00
F30C19	2017-08-15 03:22:00+03	81500.00
F30C27	2017-07-01 10:02:00+03	77200.00
F30C8A	2017-08-15 03:00:00+03	78400.00
F30C9B	2017-08-05 00:15:00+03	38800.00
F30CDB	2017-08-14 13:24:00+03	49800.00
F30D25	2017-08-02 16:04:00+03	66200.00
F30D36	2017-07-26 08:48:00+03	48200.00
F30D76	2017-07-19 22:04:00+03	28000.00
F30D9C	2017-07-21 09:21:00+03	93900.00
F30DB9	2017-07-22 05:17:00+03	105400.00
F30DC1	2017-08-11 17:12:00+03	246000.00
F30DF1	2017-07-12 21:58:00+03	59800.00
F30E27	2017-07-21 19:01:00+03	90300.00
F30E3C	2017-08-12 03:47:00+03	27600.00
F30E3F	2017-07-16 01:12:00+03	28000.00
F30E56	2017-07-17 06:48:00+03	201200.00
F30EE4	2017-07-17 21:45:00+03	20400.00
F30EE7	2017-07-20 05:38:00+03	85000.00
F30EEE	2017-08-13 19:27:00+03	55800.00
F30EF0	2017-07-19 00:21:00+03	43700.00
F30EF9	2017-07-10 00:26:00+03	246000.00
F30F07	2017-08-08 05:48:00+03	27600.00
F30F24	2017-08-07 05:48:00+03	8000.00
F30F2E	2017-07-20 03:55:00+03	82200.00
F30F38	2017-08-15 06:01:00+03	58400.00
F30F57	2017-07-31 02:38:00+03	88000.00
F30F60	2017-07-03 03:51:00+03	30400.00
F30F68	2017-08-13 19:59:00+03	40100.00
F310AE	2017-07-25 20:57:00+03	13000.00
F310BB	2017-08-05 16:28:00+03	119600.00
F310C5	2017-08-11 02:54:00+03	48800.00
F31161	2017-07-24 20:34:00+03	54400.00
F31190	2017-07-13 05:44:00+03	24400.00
F3119A	2017-08-07 11:41:00+03	28000.00
F311BE	2017-08-07 19:31:00+03	62800.00
F311EC	2017-08-13 22:07:00+03	67800.00
F312F0	2017-08-04 19:39:00+03	23200.00
F3130A	2017-07-10 09:01:00+03	90800.00
F3132E	2017-07-26 10:00:00+03	7400.00
F31357	2017-07-24 04:24:00+03	53000.00
F313DD	2017-07-03 04:37:00+03	30900.00
F313F8	2017-08-15 07:59:00+03	77000.00
F313FF	2017-07-12 17:38:00+03	35200.00
F3147B	2017-08-06 16:23:00+03	122800.00
F31574	2017-07-20 00:44:00+03	16300.00
F31577	2017-07-13 08:44:00+03	240600.00
F315E4	2017-07-30 20:37:00+03	41600.00
F315ED	2017-07-05 13:16:00+03	46200.00
F315EE	2017-07-30 05:31:00+03	12200.00
F316B3	2017-07-24 18:36:00+03	51800.00
F3175A	2017-07-05 00:47:00+03	85600.00
F31764	2017-08-06 03:35:00+03	29600.00
F317B5	2017-08-12 02:20:00+03	27900.00
F31813	2017-07-09 00:03:00+03	236700.00
F31823	2017-08-06 16:49:00+03	24700.00
F31855	2017-07-08 17:28:00+03	73400.00
F318B2	2017-07-24 18:45:00+03	89200.00
F318B5	2017-07-16 16:26:00+03	20500.00
F3191D	2017-07-31 22:18:00+03	36200.00
F3193E	2017-07-13 04:45:00+03	23600.00
F3194A	2017-07-18 16:02:00+03	405000.00
F31979	2017-07-28 10:41:00+03	80800.00
F3197C	2017-08-07 15:44:00+03	36200.00
F319A6	2017-07-27 01:33:00+03	92400.00
F319D2	2017-07-30 14:15:00+03	14000.00
F319DE	2017-07-15 08:19:00+03	85200.00
F31A08	2017-07-17 18:14:00+03	57500.00
F31A3E	2017-08-05 01:30:00+03	43900.00
F31B1A	2017-08-05 06:37:00+03	94200.00
F31B38	2017-07-29 16:19:00+03	86100.00
F31B5B	2017-08-08 11:27:00+03	20000.00
F31B7D	2017-07-30 12:00:00+03	111600.00
F31B89	2017-07-15 21:29:00+03	33100.00
F31B99	2017-07-07 12:52:00+03	34000.00
F31BAD	2017-07-31 17:49:00+03	84500.00
F31BDA	2017-08-07 09:28:00+03	43900.00
F31BEB	2017-07-28 16:54:00+03	35200.00
F31C07	2017-07-03 12:47:00+03	161600.00
F31C15	2017-08-08 19:15:00+03	73300.00
F31C61	2017-07-15 00:24:00+03	493900.00
F31C91	2017-07-23 22:02:00+03	114300.00
F31C98	2017-07-06 17:03:00+03	44000.00
F31CA1	2017-07-06 00:16:00+03	47100.00
F31CA4	2017-08-05 16:26:00+03	92700.00
F31D52	2017-08-14 18:52:00+03	26000.00
F31D9A	2017-07-29 11:07:00+03	46300.00
F31DB2	2017-07-10 03:16:00+03	142400.00
F31DF1	2017-07-06 23:44:00+03	30900.00
F31DFC	2017-08-08 12:45:00+03	138100.00
F31E49	2017-07-17 03:54:00+03	385700.00
F31E4C	2017-08-15 13:55:00+03	101200.00
F31E51	2017-08-07 05:26:00+03	27200.00
F31E77	2017-07-29 07:11:00+03	6000.00
F31E86	2017-08-15 03:57:00+03	496600.00
F31E8B	2017-07-10 05:49:00+03	46800.00
F31F03	2017-07-30 08:02:00+03	32800.00
F31F50	2017-07-18 03:40:00+03	31400.00
F31F85	2017-07-21 01:45:00+03	106000.00
F31F88	2017-08-05 07:41:00+03	82800.00
F31FA3	2017-07-12 17:23:00+03	99200.00
F31FA9	2017-07-01 17:43:00+03	318800.00
F31FE6	2017-07-06 12:49:00+03	57600.00
F31FE8	2017-07-04 02:51:00+03	66600.00
F31FEA	2017-07-12 10:29:00+03	139200.00
F31FF4	2017-07-18 18:22:00+03	125100.00
F32076	2017-08-12 06:37:00+03	8000.00
F32079	2017-07-26 11:41:00+03	51600.00
F320C9	2017-08-06 20:10:00+03	23600.00
F32113	2017-07-22 23:25:00+03	55800.00
F3211C	2017-08-11 20:18:00+03	132800.00
F32209	2017-07-24 21:21:00+03	38500.00
F3226E	2017-06-30 18:03:00+03	100600.00
F32283	2017-07-29 15:11:00+03	7200.00
F3228F	2017-07-24 18:37:00+03	49200.00
F32292	2017-08-11 21:35:00+03	59300.00
F3229A	2017-07-21 04:04:00+03	25000.00
F322BD	2017-07-29 23:45:00+03	18000.00
F322C4	2017-07-29 03:20:00+03	102100.00
F3232F	2017-08-13 08:44:00+03	15000.00
F3235B	2017-07-17 11:35:00+03	418400.00
F3235F	2017-07-19 06:54:00+03	40400.00
F323A9	2017-08-07 15:28:00+03	46200.00
F323B3	2017-07-25 20:01:00+03	66000.00
F323BA	2017-08-07 09:40:00+03	224000.00
F323F5	2017-08-08 02:00:00+03	54800.00
F3242B	2017-06-28 12:20:00+03	25600.00
F32445	2017-07-04 17:55:00+03	36200.00
F3247B	2017-08-09 15:02:00+03	173200.00
F324C9	2017-08-15 04:25:00+03	54000.00
F324E3	2017-07-22 09:11:00+03	29600.00
F32586	2017-08-04 07:27:00+03	25600.00
F325D6	2017-07-25 09:02:00+03	266400.00
F325F3	2017-07-15 22:16:00+03	163600.00
F32645	2017-07-28 06:25:00+03	38800.00
F3269C	2017-07-15 02:23:00+03	86800.00
F326E5	2017-08-01 19:36:00+03	113200.00
F326E7	2017-08-12 05:55:00+03	55800.00
F32716	2017-07-30 23:35:00+03	498200.00
F32762	2017-08-10 21:37:00+03	54400.00
F327CA	2017-07-29 00:38:00+03	132800.00
F327E7	2017-08-03 20:17:00+03	6800.00
F327FB	2017-07-05 01:16:00+03	49000.00
F32800	2017-07-22 22:00:00+03	223200.00
F3288A	2017-07-11 01:51:00+03	64800.00
F328A7	2017-08-04 05:33:00+03	23200.00
F328FA	2017-08-01 00:53:00+03	20200.00
F32900	2017-08-01 18:57:00+03	59200.00
F3298D	2017-07-23 14:03:00+03	122300.00
F32A1E	2017-07-11 09:22:00+03	56000.00
F32A22	2017-07-26 09:07:00+03	83700.00
F32A64	2017-07-22 01:08:00+03	28000.00
F32BDD	2017-08-12 05:45:00+03	23100.00
F32BEA	2017-07-23 14:22:00+03	62800.00
F32BEC	2017-07-07 15:26:00+03	29600.00
F32BF0	2017-07-02 13:20:00+03	25800.00
F32C0B	2017-07-05 22:16:00+03	13400.00
F32C96	2017-08-03 08:14:00+03	8200.00
F32CC7	2017-06-29 05:52:00+03	93900.00
F32D0D	2017-07-11 14:12:00+03	6800.00
F32D3E	2017-07-22 19:25:00+03	113200.00
F32D75	2017-08-13 05:55:00+03	27200.00
F32DA1	2017-07-02 21:44:00+03	28000.00
F32E7A	2017-07-07 08:38:00+03	283100.00
F32EA7	2017-08-02 13:28:00+03	14000.00
F32F3A	2017-07-21 01:17:00+03	15100.00
F32F3D	2017-08-02 17:58:00+03	16400.00
F32F82	2017-07-21 11:59:00+03	112000.00
F32F94	2017-08-06 19:27:00+03	23200.00
F32FEC	2017-07-11 17:54:00+03	28000.00
F3306F	2017-07-21 00:44:00+03	27200.00
F330B3	2017-07-14 03:56:00+03	6000.00
F330CE	2017-07-30 17:30:00+03	25600.00
F3312E	2017-07-16 16:55:00+03	23600.00
F33150	2017-08-12 10:46:00+03	58200.00
F33158	2017-06-30 12:32:00+03	40800.00
F33182	2017-07-20 17:33:00+03	118900.00
F33193	2017-08-03 15:05:00+03	56000.00
F331F8	2017-07-24 10:16:00+03	12600.00
F3327F	2017-07-03 20:17:00+03	24400.00
F332AC	2017-08-09 00:03:00+03	68000.00
F332DC	2017-07-11 11:18:00+03	6000.00
F33374	2017-07-14 02:40:00+03	154400.00
F333DD	2017-07-18 19:33:00+03	22200.00
F333E2	2017-08-03 22:24:00+03	69500.00
F33409	2017-07-08 17:41:00+03	55800.00
F33410	2017-08-10 16:50:00+03	16400.00
F33443	2017-07-28 08:56:00+03	26800.00
F33449	2017-07-12 05:01:00+03	13400.00
F33458	2017-07-22 05:22:00+03	27200.00
F3345D	2017-08-01 13:25:00+03	190400.00
F33480	2017-07-20 20:53:00+03	26000.00
F33591	2017-08-04 21:09:00+03	89400.00
F3367D	2017-07-04 03:24:00+03	532800.00
F336DD	2017-08-01 12:33:00+03	151000.00
F3372C	2017-08-08 16:20:00+03	26200.00
F33746	2017-07-01 20:53:00+03	6000.00
F3375A	2017-08-13 09:47:00+03	29600.00
F33790	2017-07-08 23:52:00+03	46200.00
F337C3	2017-07-27 09:38:00+03	64400.00
F337E9	2017-07-28 03:59:00+03	28000.00
F337EC	2017-07-03 00:32:00+03	42700.00
F3388C	2017-08-14 17:17:00+03	78800.00
F338CC	2017-07-10 15:25:00+03	6700.00
F33934	2017-07-13 14:11:00+03	248300.00
F33993	2017-08-02 04:52:00+03	46000.00
F339E7	2017-07-09 01:55:00+03	45200.00
F339EE	2017-07-17 20:24:00+03	51800.00
F339FC	2017-07-11 10:00:00+03	246000.00
F33A04	2017-07-26 06:12:00+03	39400.00
F33A41	2017-07-01 06:17:00+03	71900.00
F33A58	2017-08-13 07:57:00+03	68100.00
F33A69	2017-07-05 10:49:00+03	53600.00
F33B12	2017-08-14 06:52:00+03	113200.00
F33B2C	2017-07-18 18:14:00+03	53200.00
F33B8C	2017-07-08 05:14:00+03	117600.00
F33BA9	2017-08-09 22:46:00+03	25200.00
F33BF8	2017-07-26 03:21:00+03	80400.00
F33C02	2017-07-15 03:15:00+03	114800.00
F33C54	2017-08-11 04:43:00+03	46000.00
F33C88	2017-07-04 15:17:00+03	62100.00
F33CA6	2017-07-06 17:57:00+03	30200.00
F33CC5	2017-07-07 02:50:00+03	40800.00
F33CDE	2017-07-15 10:31:00+03	28000.00
F33D11	2017-07-19 19:00:00+03	186500.00
F33D3F	2017-07-02 22:46:00+03	18000.00
F33DBD	2017-07-10 19:25:00+03	26000.00
F33DF5	2017-07-22 13:52:00+03	23200.00
F33DFD	2017-07-28 05:54:00+03	23200.00
F33E00	2017-08-09 07:27:00+03	202100.00
F33E3C	2017-08-02 12:12:00+03	34000.00
F33EAF	2017-07-03 09:59:00+03	79600.00
F33F30	2017-07-02 03:29:00+03	55800.00
F33F31	2017-07-01 22:21:00+03	57400.00
F33F4D	2017-08-12 14:46:00+03	41200.00
F33FC2	2017-07-08 21:58:00+03	254900.00
F34013	2017-06-30 11:41:00+03	38800.00
F34015	2017-07-14 05:35:00+03	42800.00
F34079	2017-08-15 12:07:00+03	24800.00
F3407E	2017-07-07 03:52:00+03	6600.00
F340FA	2017-07-21 02:46:00+03	73600.00
F34114	2017-08-13 07:45:00+03	31200.00
F341C6	2017-08-04 01:35:00+03	266200.00
F34261	2017-08-05 04:30:00+03	46000.00
F34299	2017-08-09 21:42:00+03	314400.00
F342D6	2017-07-10 21:33:00+03	27200.00
F342F3	2017-07-08 04:23:00+03	20000.00
F3430E	2017-07-29 05:22:00+03	65000.00
F34313	2017-07-25 20:28:00+03	28700.00
F34318	2017-07-12 13:02:00+03	40800.00
F34357	2017-08-02 06:10:00+03	39300.00
F3435D	2017-07-15 20:27:00+03	13700.00
F343BE	2017-08-08 02:33:00+03	46200.00
F344B3	2017-07-10 10:10:00+03	42800.00
F344DF	2017-08-12 20:19:00+03	74700.00
F344F2	2017-08-11 03:54:00+03	32200.00
F34580	2017-07-06 14:24:00+03	48500.00
F345AE	2017-08-03 09:31:00+03	142900.00
F345FB	2017-08-11 11:34:00+03	54800.00
F34609	2017-08-10 09:31:00+03	168000.00
F34620	2017-08-04 01:36:00+03	39500.00
F34657	2017-08-14 10:34:00+03	26000.00
F3466F	2017-08-14 05:05:00+03	28000.00
F346D7	2017-07-30 07:29:00+03	28000.00
F3473F	2017-07-15 15:34:00+03	305300.00
F3475A	2017-07-15 10:42:00+03	91500.00
F348B4	2017-08-12 14:15:00+03	133200.00
F34936	2017-08-04 13:15:00+03	14400.00
F34972	2017-07-23 19:14:00+03	125400.00
F349DA	2017-07-22 14:13:00+03	140400.00
F349FA	2017-07-28 22:53:00+03	83700.00
F349FB	2017-08-15 12:15:00+03	56600.00
F34AA3	2017-07-20 01:19:00+03	39400.00
F34AAA	2017-07-23 10:33:00+03	40800.00
F34AD5	2017-08-05 19:18:00+03	44000.00
F34B4F	2017-08-07 09:09:00+03	23600.00
F34B71	2017-08-02 05:25:00+03	339800.00
F34B88	2017-08-05 16:18:00+03	224300.00
F34B89	2017-07-08 02:33:00+03	68900.00
F34C15	2017-07-23 19:47:00+03	84000.00
F34C19	2017-07-11 07:23:00+03	63200.00
F34C89	2017-07-22 03:53:00+03	248400.00
F34CA1	2017-07-20 14:56:00+03	37900.00
F34D25	2017-07-15 12:17:00+03	23200.00
F34DB6	2017-07-01 15:22:00+03	44200.00
F34E08	2017-08-11 16:18:00+03	42100.00
F34E6B	2017-08-14 12:29:00+03	36200.00
F34E87	2017-07-11 00:42:00+03	172000.00
F34EB7	2017-07-03 11:56:00+03	380700.00
F34EF2	2017-07-24 04:27:00+03	206100.00
F34F2C	2017-07-09 17:25:00+03	51400.00
F34FC2	2017-08-01 19:54:00+03	20200.00
F34FEA	2017-07-07 00:55:00+03	99200.00
F3511E	2017-07-25 16:17:00+03	14400.00
F35180	2017-07-16 19:01:00+03	46400.00
F351B0	2017-08-05 03:16:00+03	15800.00
F351CE	2017-08-09 13:54:00+03	29600.00
F3522E	2017-08-10 20:42:00+03	39200.00
F352B0	2017-08-10 23:25:00+03	85000.00
F352B8	2017-07-09 08:24:00+03	163600.00
F3531E	2017-08-13 01:30:00+03	55800.00
F35345	2017-07-31 08:46:00+03	18900.00
F35397	2017-07-25 13:54:00+03	46000.00
F353CE	2017-07-25 18:54:00+03	92800.00
F353DB	2017-07-08 22:29:00+03	167900.00
F35441	2017-08-12 05:19:00+03	61800.00
F354DB	2017-08-12 22:23:00+03	89700.00
F3550F	2017-07-20 03:18:00+03	56600.00
F35535	2017-07-02 17:46:00+03	39100.00
F3556E	2017-08-12 21:36:00+03	62000.00
F355A5	2017-07-26 23:27:00+03	24800.00
F35651	2017-08-11 05:56:00+03	71900.00
F3569C	2017-07-14 00:02:00+03	43600.00
F356AF	2017-08-12 07:52:00+03	12600.00
F356EC	2017-08-08 09:07:00+03	14400.00
F35750	2017-07-18 04:54:00+03	73300.00
F35794	2017-07-02 12:43:00+03	51200.00
F357FA	2017-08-02 15:45:00+03	10600.00
F35807	2017-08-14 19:59:00+03	6700.00
F3583F	2017-08-10 05:15:00+03	51300.00
F358E6	2017-08-14 21:09:00+03	43200.00
F35944	2017-07-30 01:36:00+03	83000.00
F3594F	2017-08-03 07:33:00+03	277600.00
F3596E	2017-07-30 11:16:00+03	48800.00
F35998	2017-07-09 01:54:00+03	185000.00
F359F4	2017-08-12 06:24:00+03	28800.00
F35A09	2017-08-08 20:17:00+03	69000.00
F35A13	2017-07-23 09:09:00+03	14400.00
F35A62	2017-07-29 01:50:00+03	169300.00
F35A65	2017-08-03 00:01:00+03	67500.00
F35A9B	2017-08-14 17:35:00+03	21800.00
F35B9F	2017-08-13 01:14:00+03	119600.00
F35DB5	2017-07-24 18:02:00+03	24400.00
F35DFC	2017-07-29 20:40:00+03	51600.00
F35E0C	2017-08-10 01:39:00+03	65100.00
F35E0D	2017-08-07 08:46:00+03	139400.00
F35E1A	2017-07-06 08:58:00+03	56000.00
F35E1E	2017-07-01 15:08:00+03	47500.00
F35E38	2017-07-17 16:36:00+03	179300.00
F35E39	2017-07-19 05:47:00+03	10100.00
F35F27	2017-07-07 17:00:00+03	59800.00
F35F2B	2017-08-08 18:13:00+03	114800.00
F35F6C	2017-08-02 07:25:00+03	66600.00
F35F99	2017-07-24 17:13:00+03	42000.00
F35FB6	2017-08-14 09:44:00+03	90000.00
F36016	2017-08-01 12:26:00+03	136200.00
F360C1	2017-07-14 10:26:00+03	28000.00
F360E0	2017-07-28 22:27:00+03	26000.00
F360EF	2017-08-07 10:23:00+03	81700.00
F3612D	2017-07-15 12:59:00+03	49600.00
F3612E	2017-08-04 18:39:00+03	81800.00
F36159	2017-08-14 16:31:00+03	89600.00
F361AC	2017-08-01 04:13:00+03	36200.00
F3628A	2017-07-19 15:50:00+03	12600.00
F362F9	2017-08-08 18:53:00+03	26000.00
F3630B	2017-07-22 17:50:00+03	48500.00
F36332	2017-07-18 00:06:00+03	86300.00
F36352	2017-08-01 20:17:00+03	24400.00
F3642E	2017-08-14 21:40:00+03	81500.00
F364AC	2017-07-06 23:05:00+03	45200.00
F364CC	2017-07-18 03:08:00+03	21600.00
F364DB	2017-08-13 22:40:00+03	32800.00
F364F1	2017-07-20 14:33:00+03	96300.00
F36540	2017-07-05 07:19:00+03	89200.00
F3654D	2017-07-07 05:00:00+03	56000.00
F365BA	2017-07-22 11:30:00+03	54800.00
F36605	2017-07-07 15:48:00+03	102300.00
F3662E	2017-08-02 07:05:00+03	55800.00
F36645	2017-07-14 16:47:00+03	135600.00
F3665C	2017-08-02 00:05:00+03	66000.00
F36711	2017-07-11 01:16:00+03	36800.00
F36768	2017-07-02 23:41:00+03	69600.00
F367B9	2017-07-05 06:52:00+03	123400.00
F367F4	2017-07-09 11:02:00+03	43200.00
F36837	2017-07-18 09:44:00+03	51800.00
F36891	2017-07-22 16:40:00+03	73200.00
F368B6	2017-07-09 16:22:00+03	20800.00
F36909	2017-07-25 19:08:00+03	51000.00
F3694A	2017-07-12 21:46:00+03	95000.00
F3694D	2017-07-07 10:06:00+03	96800.00
F36960	2017-07-23 15:01:00+03	82400.00
F36963	2017-08-06 01:14:00+03	69000.00
F36988	2017-07-07 16:00:00+03	83000.00
F3698B	2017-08-15 14:22:00+03	130100.00
F369E4	2017-07-14 08:47:00+03	45100.00
F36A3C	2017-08-14 22:16:00+03	12600.00
F36A6D	2017-07-11 18:37:00+03	135600.00
F36A74	2017-07-27 23:13:00+03	75600.00
F36AB3	2017-07-04 08:23:00+03	166100.00
F36ADB	2017-07-30 11:32:00+03	13000.00
F36AFE	2017-06-30 06:42:00+03	169400.00
F36B3C	2017-08-15 14:18:00+03	64800.00
F36B4F	2017-07-04 03:11:00+03	28800.00
F36BE1	2017-07-26 11:42:00+03	56000.00
F36C3D	2017-08-10 19:34:00+03	40200.00
F36C73	2017-07-16 05:02:00+03	57400.00
F36C9C	2017-07-17 03:22:00+03	56000.00
F36CA7	2017-07-29 05:34:00+03	46900.00
F36CEA	2017-07-11 00:37:00+03	90400.00
F36CEB	2017-07-29 18:49:00+03	66000.00
F36D72	2017-07-31 02:31:00+03	23600.00
F36D98	2017-07-31 00:29:00+03	28600.00
F36DF0	2017-07-09 03:03:00+03	23200.00
F36E1F	2017-07-04 16:52:00+03	364600.00
F36E47	2017-08-05 10:30:00+03	58800.00
F36F35	2017-07-08 07:48:00+03	89600.00
F36F96	2017-07-14 15:43:00+03	283100.00
F36FFE	2017-07-23 06:43:00+03	12700.00
F37003	2017-07-15 19:54:00+03	23600.00
F3708F	2017-08-03 22:53:00+03	65500.00
F370FE	2017-08-08 20:19:00+03	145200.00
F37191	2017-07-26 08:12:00+03	539400.00
F371DD	2017-07-07 10:08:00+03	27200.00
F3727E	2017-07-10 18:42:00+03	39300.00
F37357	2017-07-27 12:16:00+03	109500.00
F3736A	2017-07-21 00:20:00+03	651600.00
F37458	2017-07-22 14:31:00+03	149300.00
F374D8	2017-07-31 22:52:00+03	43500.00
F374E4	2017-08-02 10:53:00+03	40400.00
F37508	2017-08-01 18:04:00+03	254900.00
F3752A	2017-07-26 18:19:00+03	135400.00
F375AA	2017-07-09 07:51:00+03	92800.00
F37616	2017-08-05 18:16:00+03	51200.00
F3761D	2017-07-02 13:08:00+03	95000.00
F37749	2017-07-21 07:48:00+03	18800.00
F37794	2017-08-08 07:07:00+03	19600.00
F377C5	2017-07-16 12:53:00+03	59300.00
F377E5	2017-07-23 05:20:00+03	136800.00
F377E7	2017-07-21 11:54:00+03	199200.00
F37833	2017-07-30 09:17:00+03	229000.00
F3787F	2017-08-03 04:21:00+03	81600.00
F37892	2017-07-07 20:52:00+03	55800.00
F378BE	2017-07-28 14:51:00+03	133200.00
F378E8	2017-08-02 01:37:00+03	20400.00
F37931	2017-07-30 19:29:00+03	28800.00
F379BD	2017-07-20 16:19:00+03	40000.00
F379BE	2017-08-05 04:57:00+03	21400.00
F37A21	2017-07-28 23:51:00+03	62600.00
F37A4E	2017-08-15 16:19:00+03	13800.00
F37A84	2017-07-25 17:21:00+03	31400.00
F37ACD	2017-07-09 14:06:00+03	132800.00
F37AD4	2017-08-06 09:41:00+03	46900.00
F37B7B	2017-07-22 00:39:00+03	40000.00
F37C04	2017-07-24 03:20:00+03	29600.00
F37C38	2017-07-08 16:37:00+03	28000.00
F37C49	2017-08-05 05:37:00+03	12400.00
F37C99	2017-07-14 20:00:00+03	40000.00
F37CBC	2017-07-30 03:36:00+03	44600.00
F37CC0	2017-07-16 23:08:00+03	125200.00
F37E0F	2017-07-31 23:49:00+03	66600.00
F37E31	2017-08-13 10:19:00+03	185200.00
F37E38	2017-07-08 02:49:00+03	26000.00
F37E42	2017-07-07 00:01:00+03	35600.00
F37EAF	2017-07-14 05:06:00+03	94000.00
F37EB6	2017-07-23 14:10:00+03	50100.00
F37F39	2017-07-13 21:33:00+03	131600.00
F37F40	2017-07-04 14:21:00+03	47000.00
F37F4E	2017-07-10 09:24:00+03	92000.00
F37F57	2017-08-10 02:59:00+03	51300.00
F37FA4	2017-06-29 01:54:00+03	35600.00
F37FAA	2017-07-06 20:55:00+03	46700.00
F37FFC	2017-08-08 03:31:00+03	51600.00
F38064	2017-07-26 01:08:00+03	6200.00
F38070	2017-08-06 23:57:00+03	30900.00
F3807C	2017-07-10 14:48:00+03	56900.00
F38096	2017-07-22 10:24:00+03	199400.00
F3809B	2017-07-01 08:01:00+03	129600.00
F380AD	2017-07-09 13:37:00+03	43200.00
F380DD	2017-08-08 20:58:00+03	58900.00
F380E7	2017-08-08 10:18:00+03	26700.00
F38149	2017-07-23 10:53:00+03	181400.00
F38180	2017-07-28 09:13:00+03	11600.00
F381CC	2017-07-09 23:55:00+03	6700.00
F381E5	2017-07-08 19:20:00+03	10700.00
F381EF	2017-07-09 04:19:00+03	22000.00
F38261	2017-07-27 05:41:00+03	145600.00
F382F9	2017-07-25 05:57:00+03	60400.00
F38304	2017-06-30 05:17:00+03	48700.00
F38363	2017-07-18 05:36:00+03	67200.00
F383BB	2017-07-15 08:51:00+03	86500.00
F383BD	2017-08-06 17:12:00+03	107400.00
F38413	2017-08-06 15:03:00+03	46500.00
F38429	2017-07-14 08:37:00+03	40000.00
F3846D	2017-07-10 12:07:00+03	25400.00
F3849C	2017-07-19 16:34:00+03	49000.00
F384F6	2017-07-12 19:44:00+03	51900.00
F3853D	2017-07-14 06:27:00+03	78300.00
F3855B	2017-08-13 19:32:00+03	16800.00
F38599	2017-07-15 00:26:00+03	11300.00
F385BB	2017-07-14 13:05:00+03	121400.00
F385E1	2017-07-13 05:19:00+03	66600.00
F38661	2017-07-08 17:23:00+03	70400.00
F38687	2017-07-06 20:10:00+03	79200.00
F386B1	2017-08-09 04:16:00+03	45500.00
F38700	2017-07-28 06:11:00+03	69600.00
F38723	2017-08-10 00:38:00+03	39200.00
F38780	2017-07-20 11:01:00+03	66800.00
F387B4	2017-07-27 12:08:00+03	43500.00
F38827	2017-07-18 09:13:00+03	58400.00
F38952	2017-08-07 01:57:00+03	23200.00
F3898D	2017-07-05 03:16:00+03	301800.00
F389B0	2017-08-05 21:41:00+03	532800.00
F389F6	2017-07-05 20:17:00+03	75200.00
F38AEE	2017-07-26 10:27:00+03	188900.00
F38AFF	2017-08-01 03:12:00+03	11800.00
F38B28	2017-07-12 19:13:00+03	10100.00
F38B2E	2017-08-04 14:25:00+03	28000.00
F38B5F	2017-07-27 01:41:00+03	401700.00
F38C39	2017-06-30 17:16:00+03	265600.00
F38C62	2017-08-15 03:56:00+03	40100.00
F38CAF	2017-07-28 20:46:00+03	32700.00
F38CF2	2017-08-14 17:01:00+03	19600.00
F38D53	2017-07-10 18:01:00+03	271200.00
F38D6F	2017-07-08 14:06:00+03	182500.00
F38E5D	2017-07-01 23:11:00+03	198400.00
F38E96	2017-07-02 09:32:00+03	199700.00
F38F19	2017-08-09 03:13:00+03	20200.00
F38F5C	2017-07-23 06:14:00+03	128800.00
F38F63	2017-07-19 07:17:00+03	36200.00
F38FB4	2017-07-12 09:12:00+03	24800.00
F38FC6	2017-07-10 05:45:00+03	58700.00
F38FDF	2017-07-31 04:29:00+03	56000.00
F3906C	2017-07-19 02:47:00+03	248500.00
F39070	2017-07-20 13:39:00+03	38200.00
F39151	2017-08-03 00:15:00+03	52800.00
F39186	2017-08-06 03:31:00+03	101800.00
F391CB	2017-07-10 07:40:00+03	28800.00
F391F2	2017-08-08 01:48:00+03	178800.00
F39211	2017-08-13 01:42:00+03	67000.00
F39212	2017-07-26 10:26:00+03	32900.00
F39240	2017-08-01 01:16:00+03	263800.00
F39254	2017-08-04 02:04:00+03	29600.00
F3925D	2017-07-09 00:43:00+03	94000.00
F3927B	2017-08-06 13:58:00+03	16400.00
F392F8	2017-07-04 09:30:00+03	44600.00
F39370	2017-07-27 09:01:00+03	45200.00
F393E9	2017-08-15 11:03:00+03	26700.00
F3943B	2017-07-16 17:04:00+03	6700.00
F3944C	2017-07-04 03:28:00+03	39800.00
F39456	2017-07-15 04:52:00+03	51900.00
F394CE	2017-07-13 01:50:00+03	66600.00
F39527	2017-07-10 05:51:00+03	30200.00
F3953E	2017-08-14 14:41:00+03	47000.00
F3956A	2017-07-06 02:42:00+03	56000.00
F39585	2017-08-12 09:50:00+03	85000.00
F395BD	2017-07-20 20:41:00+03	101200.00
F39636	2017-07-06 15:48:00+03	23200.00
F3969F	2017-07-28 11:47:00+03	28800.00
F396F9	2017-07-02 06:52:00+03	25000.00
F396FB	2017-07-15 03:42:00+03	74800.00
F3972D	2017-07-07 15:00:00+03	91800.00
F3973D	2017-08-03 17:55:00+03	70700.00
F3973E	2017-07-09 01:53:00+03	16400.00
F39740	2017-07-31 17:32:00+03	202600.00
F39761	2017-07-12 08:59:00+03	23600.00
F397C8	2017-08-05 09:18:00+03	397100.00
F39815	2017-07-08 15:30:00+03	166100.00
F39824	2017-08-06 13:43:00+03	52300.00
F3983B	2017-07-21 13:22:00+03	40000.00
F3985A	2017-07-17 10:37:00+03	6000.00
F39862	2017-08-11 00:58:00+03	174600.00
F39897	2017-07-09 16:15:00+03	152500.00
F398A5	2017-08-06 09:55:00+03	26800.00
F398C7	2017-07-09 11:39:00+03	28800.00
F398E6	2017-08-06 14:05:00+03	14400.00
F399E6	2017-08-07 15:21:00+03	58700.00
F39A2F	2017-08-12 05:42:00+03	63900.00
F39A46	2017-08-14 12:00:00+03	46400.00
F39A8D	2017-08-07 08:49:00+03	270800.00
F39AC9	2017-08-13 00:49:00+03	81300.00
F39B78	2017-08-13 10:03:00+03	68900.00
F39B84	2017-08-05 09:36:00+03	46700.00
F39BD3	2017-07-04 07:20:00+03	542200.00
F39BDF	2017-07-09 07:03:00+03	46700.00
F39CD2	2017-08-14 20:01:00+03	68800.00
F39CF4	2017-07-30 18:02:00+03	73100.00
F39CFC	2017-07-07 18:39:00+03	67000.00
F39D34	2017-08-08 07:22:00+03	136500.00
F39D86	2017-07-14 05:52:00+03	62600.00
F39DD2	2017-07-31 09:45:00+03	386300.00
F39DE0	2017-07-21 07:40:00+03	34000.00
F39DE2	2017-07-21 07:44:00+03	26800.00
F39E07	2017-07-28 01:46:00+03	85000.00
F39E1B	2017-08-02 20:28:00+03	79600.00
F39E31	2017-06-28 01:32:00+03	86500.00
F39E36	2017-07-30 02:57:00+03	131100.00
F39E66	2017-08-05 19:29:00+03	48800.00
F39E74	2017-07-26 10:41:00+03	24400.00
F39E95	2017-08-14 03:01:00+03	43000.00
F39F2C	2017-08-11 20:10:00+03	111700.00
F39F52	2017-07-21 21:31:00+03	36800.00
F39F88	2017-08-07 04:04:00+03	136200.00
F39FAC	2017-07-10 17:08:00+03	52000.00
F39FE0	2017-08-02 15:06:00+03	37900.00
F3A014	2017-07-29 17:44:00+03	24400.00
F3A07E	2017-08-06 20:31:00+03	189800.00
F3A081	2017-07-31 18:43:00+03	14800.00
F3A08F	2017-08-06 22:47:00+03	8600.00
F3A096	2017-07-24 05:26:00+03	115600.00
F3A0A7	2017-08-15 15:43:00+03	28700.00
F3A0F7	2017-07-21 14:08:00+03	68100.00
F3A130	2017-07-25 21:17:00+03	34000.00
F3A16F	2017-07-11 14:52:00+03	36600.00
F3A18D	2017-07-25 12:50:00+03	8200.00
F3A257	2017-07-12 08:03:00+03	111600.00
F3A29D	2017-08-13 06:44:00+03	97200.00
F3A2E6	2017-08-06 10:19:00+03	400900.00
F3A30A	2017-07-22 12:35:00+03	56000.00
F3A321	2017-07-17 13:38:00+03	92700.00
F3A334	2017-08-07 16:35:00+03	123700.00
F3A341	2017-07-22 12:37:00+03	176800.00
F3A36B	2017-08-09 00:26:00+03	124200.00
F3A379	2017-08-04 16:05:00+03	50600.00
F3A385	2017-08-09 22:59:00+03	134400.00
F3A387	2017-07-28 02:45:00+03	58200.00
F3A3C2	2017-07-29 19:39:00+03	410200.00
F3A3DF	2017-07-26 10:44:00+03	12400.00
F3A422	2017-07-20 12:17:00+03	34000.00
F3A471	2017-07-09 09:53:00+03	6700.00
F3A4CF	2017-07-04 02:17:00+03	30200.00
F3A54D	2017-08-15 09:03:00+03	99200.00
F3A5A6	2017-07-23 08:51:00+03	51600.00
F3A5B2	2017-07-22 08:05:00+03	23200.00
F3A5C5	2017-08-01 11:44:00+03	86400.00
F3A605	2017-07-12 14:01:00+03	46400.00
F3A607	2017-07-01 21:25:00+03	14000.00
F3A612	2017-07-08 14:19:00+03	52300.00
F3A631	2017-07-18 11:18:00+03	38600.00
F3A647	2017-07-23 05:03:00+03	100000.00
F3A655	2017-08-12 20:44:00+03	126100.00
F3A6BD	2017-07-29 03:06:00+03	21200.00
F3A6FE	2017-07-30 23:02:00+03	52300.00
F3A73E	2017-07-06 04:05:00+03	49100.00
F3A768	2017-07-24 11:08:00+03	73600.00
F3A770	2017-08-08 06:25:00+03	26000.00
F3A79B	2017-07-04 04:33:00+03	28000.00
F3A7B9	2017-07-04 22:18:00+03	258400.00
F3A7FF	2017-08-11 12:06:00+03	11600.00
F3A863	2017-08-03 22:43:00+03	170100.00
F3A888	2017-08-15 15:01:00+03	135600.00
F3A8A5	2017-07-29 09:14:00+03	38800.00
F3A8B5	2017-07-14 22:25:00+03	111100.00
F3A8E6	2017-07-24 04:53:00+03	29600.00
F3A8F8	2017-08-10 12:44:00+03	54800.00
F3A929	2017-07-25 06:04:00+03	36600.00
F3A978	2017-07-30 07:43:00+03	122600.00
F3A9AA	2017-07-23 14:57:00+03	23200.00
F3A9B7	2017-07-03 17:04:00+03	91100.00
F3A9C2	2017-07-17 22:47:00+03	75600.00
F3AA04	2017-08-04 07:18:00+03	46700.00
F3AA0A	2017-07-20 21:10:00+03	56000.00
F3AA59	2017-08-03 15:10:00+03	146900.00
F3AA7A	2017-08-06 06:42:00+03	168000.00
F3AA9B	2017-07-19 12:36:00+03	185500.00
F3AADC	2017-07-24 18:23:00+03	12400.00
F3AB0C	2017-07-03 09:45:00+03	23200.00
F3AB6B	2017-07-31 10:16:00+03	36600.00
F3AB71	2017-07-19 07:56:00+03	12400.00
F3AB8B	2017-07-09 17:00:00+03	33600.00
F3AC16	2017-07-10 06:15:00+03	125000.00
F3AC38	2017-08-14 23:30:00+03	21400.00
F3AC3B	2017-08-01 03:34:00+03	372500.00
F3AC77	2017-08-11 15:21:00+03	38400.00
F3ACA5	2017-07-05 00:17:00+03	30000.00
F3ACD3	2017-08-05 22:58:00+03	54800.00
F3AD77	2017-07-08 15:25:00+03	12400.00
F3ADFA	2017-08-15 02:43:00+03	51300.00
F3AE04	2017-08-10 20:40:00+03	52800.00
F3AE32	2017-07-16 11:14:00+03	26700.00
F3AE3E	2017-07-29 05:04:00+03	15000.00
F3AEA0	2017-07-03 20:51:00+03	188000.00
F3AEFE	2017-07-24 05:27:00+03	136700.00
F3AF54	2017-07-18 05:08:00+03	62900.00
F3AF80	2017-06-30 12:29:00+03	40600.00
F3AFCE	2017-07-05 19:46:00+03	90000.00
F3AFF8	2017-07-25 06:15:00+03	24400.00
F3AFFC	2017-07-04 07:48:00+03	38800.00
F3B001	2017-07-28 02:12:00+03	369000.00
F3B004	2017-07-31 09:43:00+03	28000.00
F3B04F	2017-07-23 14:17:00+03	81500.00
F3B093	2017-07-05 05:49:00+03	32600.00
F3B0EB	2017-07-16 13:54:00+03	27800.00
F3B127	2017-07-20 00:39:00+03	46400.00
F3B139	2017-07-28 17:21:00+03	58200.00
F3B158	2017-06-28 20:47:00+03	36200.00
F3B1BE	2017-07-04 13:54:00+03	55800.00
F3B206	2017-07-30 04:36:00+03	92200.00
F3B211	2017-07-10 08:22:00+03	101100.00
F3B253	2017-08-06 13:06:00+03	12000.00
F3B268	2017-07-17 18:24:00+03	24400.00
F3B29B	2017-07-31 13:51:00+03	12400.00
F3B319	2017-07-30 06:16:00+03	35700.00
F3B324	2017-08-14 18:13:00+03	69500.00
F3B330	2017-08-14 01:54:00+03	34800.00
F3B333	2017-07-21 14:54:00+03	13400.00
F3B345	2017-07-17 22:33:00+03	67100.00
F3B359	2017-08-11 14:49:00+03	69500.00
F3B361	2017-07-31 20:07:00+03	252200.00
F3B3D7	2017-08-10 07:43:00+03	23600.00
F3B3EE	2017-07-15 07:25:00+03	43800.00
F3B3FC	2017-08-07 02:54:00+03	72300.00
F3B430	2017-07-30 07:45:00+03	62600.00
F3B452	2017-07-12 10:18:00+03	79900.00
F3B467	2017-07-15 13:27:00+03	135400.00
F3B488	2017-07-30 22:32:00+03	32800.00
F3B4A5	2017-08-12 04:05:00+03	90800.00
F3B54C	2017-07-10 05:46:00+03	125600.00
F3B564	2017-07-17 04:39:00+03	113700.00
F3B57C	2017-08-09 18:56:00+03	136200.00
F3B5BC	2017-08-05 10:28:00+03	28800.00
F3B5C5	2017-08-07 19:59:00+03	118300.00
F3B5D6	2017-07-12 16:32:00+03	281500.00
F3B60D	2017-07-24 17:44:00+03	9200.00
F3B676	2017-08-11 02:34:00+03	50800.00
F3B699	2017-07-13 06:38:00+03	26800.00
F3B6A8	2017-08-12 12:28:00+03	14000.00
F3B6B7	2017-07-29 09:02:00+03	91500.00
F3B6C1	2017-08-10 05:50:00+03	22000.00
F3B74C	2017-07-23 16:46:00+03	22000.00
F3B76E	2017-07-02 20:32:00+03	48800.00
F3B7CE	2017-07-13 18:09:00+03	83700.00
F3B7DE	2017-07-28 16:42:00+03	44800.00
F3B801	2017-08-14 22:21:00+03	19600.00
F3B82C	2017-07-03 22:01:00+03	52800.00
F3B83D	2017-07-29 14:23:00+03	92600.00
F3B8ED	2017-08-02 01:32:00+03	69500.00
F3B954	2017-07-07 13:11:00+03	270600.00
F3B994	2017-08-15 02:52:00+03	102000.00
F3B9DC	2017-07-05 01:52:00+03	39200.00
F3B9F5	2017-07-09 20:12:00+03	26800.00
F3BA51	2017-07-27 22:25:00+03	12600.00
F3BA52	2017-06-28 00:27:00+03	167400.00
F3BA56	2017-08-03 12:43:00+03	26000.00
F3BA9D	2017-08-01 04:07:00+03	90400.00
F3BAD5	2017-07-22 20:28:00+03	29100.00
F3BAE8	2017-08-13 17:20:00+03	94400.00
F3BBA9	2017-07-24 07:56:00+03	136700.00
F3BBBA	2017-07-26 01:46:00+03	12200.00
F3BC23	2017-08-08 14:32:00+03	62800.00
F3BC35	2017-07-18 13:40:00+03	11900.00
F3BCEA	2017-08-12 12:49:00+03	35600.00
F3BD52	2017-07-30 18:45:00+03	26800.00
F3BDC1	2017-08-14 04:04:00+03	68800.00
F3BE14	2017-08-06 15:00:00+03	6700.00
F3BE9D	2017-07-22 04:31:00+03	14800.00
F3BEB2	2017-08-10 10:38:00+03	47000.00
F3BF57	2017-08-09 03:56:00+03	123000.00
F3C05D	2017-07-20 05:58:00+03	65300.00
F3C126	2017-07-21 13:11:00+03	23600.00
F3C16B	2017-07-11 14:01:00+03	52800.00
F3C1A3	2017-08-12 17:58:00+03	79000.00
F3C1EE	2017-08-14 04:59:00+03	27400.00
F3C24E	2017-08-06 20:37:00+03	37400.00
F3C2C8	2017-08-08 19:41:00+03	112000.00
F3C305	2017-07-25 16:40:00+03	56800.00
F3C401	2017-08-07 06:43:00+03	153300.00
F3C418	2017-07-09 17:20:00+03	100600.00
F3C427	2017-07-16 05:59:00+03	41600.00
F3C4BC	2017-07-29 19:50:00+03	369000.00
F3C53F	2017-07-11 06:43:00+03	29900.00
F3C54B	2017-07-26 19:24:00+03	185600.00
F3C5BE	2017-07-27 08:39:00+03	113300.00
F3C5CD	2017-07-14 17:33:00+03	62600.00
F3C5D3	2017-08-10 17:49:00+03	26700.00
F3C60E	2017-07-14 21:48:00+03	46400.00
F3C64F	2017-07-17 10:33:00+03	248400.00
F3C653	2017-08-10 22:17:00+03	13600.00
F3C6A1	2017-07-26 19:24:00+03	6600.00
F3C6C5	2017-08-09 11:47:00+03	199700.00
F3C74A	2017-07-05 01:07:00+03	12400.00
F3C787	2017-08-04 01:28:00+03	20000.00
F3C794	2017-08-13 06:07:00+03	25300.00
F3C7B7	2017-08-12 07:04:00+03	46000.00
F3C830	2017-08-14 18:28:00+03	27200.00
F3C853	2017-08-15 00:27:00+03	15000.00
F3C888	2017-07-14 07:26:00+03	13600.00
F3C8D3	2017-07-12 15:35:00+03	29600.00
F3C8E2	2017-07-24 06:08:00+03	55600.00
F3C913	2017-08-10 20:37:00+03	12600.00
F3C943	2017-08-06 16:41:00+03	8200.00
F3C96D	2017-08-07 21:18:00+03	97900.00
F3C97A	2017-07-29 14:04:00+03	19600.00
F3C9A2	2017-07-22 20:57:00+03	123600.00
F3C9EE	2017-07-11 06:21:00+03	80300.00
F3CA46	2017-07-09 08:40:00+03	31000.00
F3CA78	2017-07-04 18:42:00+03	98000.00
F3CA8F	2017-07-06 20:31:00+03	163100.00
F3CB11	2017-07-09 01:27:00+03	19600.00
F3CB9B	2017-07-15 11:02:00+03	28000.00
F3CBA2	2017-08-12 19:10:00+03	10600.00
F3CBB6	2017-07-03 18:17:00+03	92900.00
F3CC0A	2017-08-13 23:26:00+03	55800.00
F3CCA3	2017-07-29 23:07:00+03	369000.00
F3CD83	2017-07-16 01:18:00+03	49100.00
F3CDE8	2017-07-27 11:16:00+03	57600.00
F3CE2E	2017-07-31 08:15:00+03	39100.00
F3CEA9	2017-08-05 06:02:00+03	28000.00
F3CEBB	2017-07-30 06:16:00+03	49800.00
F3CEC8	2017-07-24 10:24:00+03	24400.00
F3CED3	2017-08-08 15:34:00+03	27200.00
F3CEE9	2017-07-12 23:42:00+03	12400.00
F3CFA2	2017-08-09 00:50:00+03	128600.00
F3CFBF	2017-07-26 05:48:00+03	61800.00
F3CFD7	2017-08-02 09:40:00+03	28800.00
F3CFD9	2017-07-01 17:53:00+03	139300.00
F3CFE2	2017-07-25 14:45:00+03	86500.00
F3D018	2017-07-12 01:04:00+03	27900.00
F3D04F	2017-07-10 15:57:00+03	93900.00
F3D06A	2017-08-05 07:37:00+03	87700.00
F3D089	2017-07-09 23:54:00+03	84000.00
F3D0D8	2017-07-18 12:51:00+03	92000.00
F3D0DF	2017-07-18 08:24:00+03	93900.00
F3D0EF	2017-08-03 06:38:00+03	133100.00
F3D153	2017-07-25 05:10:00+03	46400.00
F3D15C	2017-07-06 10:12:00+03	24400.00
F3D189	2017-08-05 05:42:00+03	43600.00
F3D203	2017-07-08 11:15:00+03	260900.00
F3D236	2017-07-01 14:44:00+03	133200.00
F3D2A5	2017-08-11 02:31:00+03	21400.00
F3D2B4	2017-08-02 18:09:00+03	23600.00
F3D2C2	2017-08-09 12:52:00+03	68800.00
F3D302	2017-07-05 01:19:00+03	190400.00
F3D30D	2017-07-14 22:25:00+03	46500.00
F3D317	2017-07-12 05:42:00+03	23600.00
F3D379	2017-07-28 17:55:00+03	132800.00
F3D42F	2017-06-29 16:27:00+03	57700.00
F3D456	2017-07-24 00:42:00+03	48600.00
F3D4C2	2017-08-11 22:03:00+03	6000.00
F3D518	2017-07-29 15:10:00+03	129700.00
F3D52D	2017-07-30 08:07:00+03	186900.00
F3D5DB	2017-07-14 15:36:00+03	125400.00
F3D654	2017-08-06 13:35:00+03	103900.00
F3D694	2017-07-21 20:35:00+03	24400.00
F3D6C7	2017-07-14 14:08:00+03	137900.00
F3D6EE	2017-08-02 04:43:00+03	26000.00
F3D6FF	2017-07-12 21:47:00+03	88500.00
F3D773	2017-07-02 16:06:00+03	82900.00
F3D7AB	2017-08-07 12:56:00+03	38800.00
F3D7C3	2017-07-29 11:47:00+03	11800.00
F3D7CC	2017-07-25 02:59:00+03	132800.00
F3D7FD	2017-07-08 09:33:00+03	13600.00
F3D7FF	2017-08-07 08:27:00+03	156300.00
F3D812	2017-07-02 13:42:00+03	26000.00
F3D823	2017-08-06 02:26:00+03	182300.00
F3D840	2017-08-09 13:50:00+03	80700.00
F3D85E	2017-07-22 15:51:00+03	94000.00
F3D879	2017-07-19 21:28:00+03	112000.00
F3D87B	2017-07-27 09:44:00+03	28000.00
F3D892	2017-08-09 12:56:00+03	22000.00
F3D8AA	2017-07-25 17:07:00+03	78400.00
F3D901	2017-08-07 20:55:00+03	99600.00
F3D902	2017-07-07 03:33:00+03	15900.00
F3D912	2017-07-02 18:36:00+03	12600.00
F3D96C	2017-08-03 05:39:00+03	68800.00
F3D982	2017-08-04 02:18:00+03	39300.00
F3D9B2	2017-07-15 09:16:00+03	46000.00
F3D9FF	2017-07-04 19:56:00+03	49100.00
F3DA29	2017-07-27 17:00:00+03	81300.00
F3DA77	2017-07-12 17:20:00+03	103500.00
F3DB0D	2017-07-02 06:48:00+03	33100.00
F3DB83	2017-07-16 03:34:00+03	32800.00
F3DBB0	2017-07-24 00:07:00+03	129200.00
F3DC09	2017-08-12 17:13:00+03	55800.00
F3DD41	2017-06-28 05:18:00+03	19600.00
F3DD6B	2017-07-24 15:14:00+03	98000.00
F3DDE3	2017-07-09 06:11:00+03	115400.00
F3DE0A	2017-07-05 05:30:00+03	54800.00
F3DE12	2017-07-25 17:05:00+03	6700.00
F3DE41	2017-07-05 00:53:00+03	3400.00
F3DE8E	2017-07-14 19:37:00+03	38600.00
F3DEC5	2017-06-29 22:03:00+03	13000.00
F3DF35	2017-08-10 08:29:00+03	57600.00
F3DF43	2017-08-04 13:05:00+03	55800.00
F3DFAE	2017-08-02 07:55:00+03	137700.00
F3E05C	2017-08-12 13:17:00+03	28000.00
F3E05E	2017-07-04 17:51:00+03	99200.00
F3E072	2017-08-07 22:52:00+03	16400.00
F3E0AF	2017-07-11 20:42:00+03	58200.00
F3E0B6	2017-07-01 09:47:00+03	21800.00
F3E0CF	2017-07-12 18:04:00+03	28800.00
F3E13E	2017-07-17 05:18:00+03	81300.00
F3E166	2017-07-18 03:50:00+03	339300.00
F3E1A8	2017-07-18 13:28:00+03	115900.00
F3E1E9	2017-07-07 00:49:00+03	18300.00
F3E208	2017-07-06 13:24:00+03	393800.00
F3E27F	2017-07-08 06:44:00+03	129400.00
F3E2D0	2017-07-19 07:28:00+03	189700.00
F3E349	2017-07-11 01:05:00+03	67200.00
F3E3FB	2017-07-01 05:25:00+03	24800.00
F3E44F	2017-07-07 10:43:00+03	20400.00
F3E4F9	2017-06-29 07:05:00+03	179500.00
F3E522	2017-08-01 07:56:00+03	123900.00
F3E523	2017-07-11 02:53:00+03	277000.00
F3E5AF	2017-07-28 19:48:00+03	102300.00
F3E5CB	2017-07-02 01:19:00+03	8200.00
F3E655	2017-08-15 08:02:00+03	13400.00
F3E680	2017-08-11 00:09:00+03	54000.00
F3E70E	2017-07-03 17:52:00+03	93600.00
F3E72C	2017-07-14 10:22:00+03	35200.00
F3E74C	2017-07-20 04:14:00+03	26000.00
F3E824	2017-07-22 01:36:00+03	46300.00
F3E82E	2017-07-06 01:55:00+03	21200.00
F3E860	2017-07-23 01:10:00+03	113700.00
F3E892	2017-07-27 21:49:00+03	37900.00
F3E923	2017-08-03 18:41:00+03	39600.00
F3E947	2017-07-23 01:34:00+03	92900.00
F3E959	2017-07-09 22:39:00+03	253300.00
F3E99F	2017-06-27 21:35:00+03	12400.00
F3E9EA	2017-07-31 01:09:00+03	27600.00
F3E9EE	2017-07-06 03:07:00+03	36200.00
F3EA13	2017-08-15 06:44:00+03	36200.00
F3EABF	2017-08-13 06:12:00+03	26000.00
F3EADF	2017-07-03 13:02:00+03	157000.00
F3EAF3	2017-08-11 10:11:00+03	62800.00
F3EB6C	2017-08-05 05:31:00+03	290600.00
F3EB85	2017-07-11 01:32:00+03	38600.00
F3EBA0	2017-07-16 13:03:00+03	123000.00
F3EC0F	2017-08-06 22:38:00+03	144400.00
F3EC31	2017-08-15 02:25:00+03	170200.00
F3EC38	2017-07-31 16:07:00+03	260300.00
F3EC62	2017-07-22 18:12:00+03	94700.00
F3EC68	2017-07-30 12:32:00+03	67200.00
F3EC9E	2017-08-14 19:54:00+03	107300.00
F3ECC2	2017-07-29 09:06:00+03	30800.00
F3ED09	2017-08-05 10:20:00+03	136200.00
F3ED2E	2017-07-07 05:52:00+03	14400.00
F3ED4B	2017-08-11 21:36:00+03	41000.00
F3EDD5	2017-08-14 04:56:00+03	127700.00
F3EDD8	2017-07-12 21:06:00+03	28800.00
F3EDF3	2017-08-11 09:23:00+03	56000.00
F3EEDF	2017-07-23 03:37:00+03	46400.00
F3EFF2	2017-07-30 19:06:00+03	67200.00
F3F001	2017-08-09 14:51:00+03	381400.00
F3F0B0	2017-07-08 18:38:00+03	52000.00
F3F0C3	2017-07-25 20:09:00+03	67600.00
F3F0DC	2017-08-07 05:06:00+03	21000.00
F3F14B	2017-08-06 17:57:00+03	23600.00
F3F153	2017-07-10 11:40:00+03	53400.00
F3F16B	2017-08-03 19:35:00+03	28000.00
F3F16D	2017-08-13 05:45:00+03	56000.00
F3F194	2017-07-13 08:20:00+03	28000.00
F3F1B8	2017-07-21 20:47:00+03	136800.00
F3F30A	2017-08-07 16:04:00+03	78400.00
F3F321	2017-08-14 00:01:00+03	104000.00
F3F3EE	2017-07-29 19:49:00+03	85000.00
F3F40C	2017-08-08 14:15:00+03	44100.00
F3F43F	2017-08-04 19:32:00+03	75300.00
F3F44B	2017-07-22 14:20:00+03	53700.00
F3F48E	2017-07-09 08:51:00+03	66000.00
F3F4B1	2017-08-12 10:06:00+03	193600.00
F3F4DC	2017-07-03 18:25:00+03	98400.00
F3F5A3	2017-08-07 15:46:00+03	259800.00
F3F60A	2017-07-17 01:09:00+03	26200.00
F3F629	2017-08-06 07:55:00+03	25600.00
F3F695	2017-08-05 23:28:00+03	50300.00
F3F6BD	2017-08-05 16:01:00+03	71600.00
F3F6DC	2017-07-02 20:03:00+03	65900.00
F3F711	2017-07-04 23:52:00+03	40000.00
F3F726	2017-07-13 22:24:00+03	72200.00
F3F73A	2017-07-27 11:09:00+03	46400.00
F3F740	2017-08-08 20:03:00+03	155600.00
F3F75A	2017-07-19 22:20:00+03	93900.00
F3F7C8	2017-08-01 13:04:00+03	50600.00
F3F80C	2017-07-17 05:01:00+03	147700.00
F3F8BE	2017-08-13 23:51:00+03	27200.00
F3F8C8	2017-07-24 17:33:00+03	92400.00
F3F8DC	2017-07-11 19:26:00+03	24400.00
F3F952	2017-07-09 07:48:00+03	99200.00
F3F985	2017-07-20 00:06:00+03	73200.00
F3F98D	2017-07-04 21:30:00+03	40700.00
F3F9A0	2017-06-30 07:43:00+03	46400.00
F3FA17	2017-07-22 06:03:00+03	67600.00
F3FA26	2017-07-15 04:28:00+03	102100.00
F3FA6F	2017-07-20 05:02:00+03	114500.00
F3FACE	2017-07-10 21:29:00+03	170000.00
F3FAD9	2017-07-16 23:31:00+03	53500.00
F3FB42	2017-07-30 15:24:00+03	119500.00
F3FB90	2017-07-08 22:41:00+03	57800.00
F3FC30	2017-07-02 21:29:00+03	71600.00
F3FCA3	2017-08-07 08:17:00+03	24000.00
F3FD99	2017-07-04 10:39:00+03	123000.00
F3FDAB	2017-07-30 17:35:00+03	67600.00
F3FDB8	2017-07-07 01:43:00+03	131100.00
F3FDE1	2017-07-14 01:18:00+03	29400.00
F3FE48	2017-07-11 22:36:00+03	143100.00
F3FE79	2017-07-13 23:52:00+03	23200.00
F3FEA6	2017-08-05 10:10:00+03	15000.00
F3FEC4	2017-08-08 21:42:00+03	81300.00
F3FEDB	2017-08-10 03:38:00+03	115900.00
F3FF1E	2017-07-25 10:19:00+03	271100.00
F3FF47	2017-08-02 06:27:00+03	12600.00
F3FFE1	2017-07-08 21:55:00+03	46400.00
F3FFF4	2017-08-10 00:59:00+03	92800.00
F3FFFD	2017-07-06 12:45:00+03	25800.00
F40043	2017-07-06 09:55:00+03	73500.00
F4004C	2017-07-28 23:00:00+03	73600.00
F4009C	2017-08-14 05:36:00+03	92700.00
F400C0	2017-07-19 10:27:00+03	6600.00
F4013B	2017-07-19 08:52:00+03	65500.00
F40198	2017-07-07 04:56:00+03	40000.00
F401D4	2017-08-05 10:48:00+03	38800.00
F401E6	2017-07-03 05:07:00+03	28000.00
F40201	2017-08-09 13:39:00+03	46400.00
F4023C	2017-08-13 08:38:00+03	62800.00
F4023F	2017-08-01 07:04:00+03	53400.00
F4029E	2017-07-03 05:00:00+03	36200.00
F40310	2017-07-09 07:40:00+03	36200.00
F40355	2017-08-11 05:48:00+03	182800.00
F4035B	2017-08-02 14:29:00+03	25800.00
F40391	2017-08-08 02:46:00+03	118600.00
F403FB	2017-07-24 16:54:00+03	6800.00
F40414	2017-07-26 21:13:00+03	124200.00
F40415	2017-08-07 01:34:00+03	94400.00
F40434	2017-07-25 03:51:00+03	266400.00
F40441	2017-07-14 17:03:00+03	52000.00
F4053A	2017-07-11 21:28:00+03	31300.00
F405CA	2017-07-30 12:02:00+03	99200.00
F4060F	2017-07-27 08:54:00+03	46400.00
F40666	2017-08-07 13:15:00+03	11000.00
F406BA	2017-07-06 00:18:00+03	57600.00
F406D2	2017-07-28 18:41:00+03	26700.00
F4071A	2017-07-15 22:12:00+03	68400.00
F4071B	2017-08-06 12:32:00+03	192400.00
F4071D	2017-07-11 20:22:00+03	6700.00
F40733	2017-08-13 14:09:00+03	40000.00
F4075B	2017-07-15 06:53:00+03	23200.00
F407DA	2017-07-11 18:45:00+03	24800.00
F40802	2017-08-07 23:28:00+03	88900.00
F4080F	2017-07-07 15:35:00+03	108200.00
F4081B	2017-07-06 19:07:00+03	15000.00
F4089C	2017-08-03 22:18:00+03	28800.00
F408AA	2017-08-06 17:50:00+03	152900.00
F408FC	2017-07-01 12:48:00+03	21800.00
F4097E	2017-08-14 19:42:00+03	169600.00
F409CB	2017-08-07 13:40:00+03	95600.00
F40A31	2017-07-30 05:51:00+03	85400.00
F40A34	2017-07-11 05:02:00+03	43100.00
F40A40	2017-06-29 18:06:00+03	98800.00
F40ABF	2017-08-01 16:21:00+03	31000.00
F40B19	2017-07-01 08:50:00+03	16400.00
F40B4D	2017-07-02 11:08:00+03	26000.00
F40B57	2017-07-03 01:06:00+03	97900.00
F40BE2	2017-07-20 17:05:00+03	58000.00
F40C49	2017-08-13 06:49:00+03	31600.00
F40C68	2017-08-10 18:06:00+03	81200.00
F40C7B	2017-07-31 15:23:00+03	398600.00
F40C92	2017-07-27 23:23:00+03	123600.00
F40C9C	2017-08-07 17:24:00+03	6000.00
F40CA7	2017-08-01 13:21:00+03	103200.00
F40D30	2017-07-11 16:48:00+03	28800.00
F40D56	2017-07-26 19:07:00+03	15000.00
F40DC0	2017-07-29 06:26:00+03	65200.00
F40E01	2017-08-13 13:23:00+03	42800.00
F40E1E	2017-07-09 10:04:00+03	227600.00
F40E74	2017-07-29 10:10:00+03	32800.00
F40F23	2017-08-08 21:30:00+03	26300.00
F40F63	2017-07-19 19:56:00+03	46000.00
F40FD0	2017-07-15 17:54:00+03	67600.00
F40FDC	2017-08-03 07:13:00+03	123000.00
F41078	2017-08-06 13:24:00+03	93900.00
F41084	2017-07-11 14:25:00+03	85600.00
F410D9	2017-07-12 05:31:00+03	66600.00
F410F2	2017-07-15 19:23:00+03	40800.00
F410F4	2017-07-18 09:38:00+03	67200.00
F41110	2017-07-05 19:06:00+03	11000.00
F41182	2017-07-20 04:47:00+03	58600.00
F411AF	2017-07-18 13:10:00+03	6800.00
F411E1	2017-08-05 18:35:00+03	89600.00
F41248	2017-07-27 04:19:00+03	28000.00
F41285	2017-07-06 09:46:00+03	97900.00
F412BB	2017-07-31 08:46:00+03	16400.00
F412BD	2017-07-27 00:34:00+03	64600.00
F412D5	2017-07-21 04:26:00+03	240600.00
F412DD	2017-06-30 15:21:00+03	266400.00
F412E6	2017-07-11 16:51:00+03	132800.00
F412EF	2017-07-27 13:32:00+03	126300.00
F41341	2017-07-24 03:20:00+03	15000.00
F41418	2017-08-02 11:03:00+03	282000.00
F41493	2017-07-16 04:37:00+03	99200.00
F414E5	2017-07-12 09:36:00+03	49800.00
F41562	2017-08-04 05:28:00+03	46200.00
F4159E	2017-07-13 02:24:00+03	160200.00
F415DB	2017-07-29 05:49:00+03	55800.00
F415E4	2017-08-11 00:49:00+03	65600.00
F416AE	2017-07-28 20:04:00+03	87100.00
F416C0	2017-07-30 16:24:00+03	56000.00
F416DA	2017-07-27 14:36:00+03	158200.00
F416F9	2017-07-06 17:03:00+03	86300.00
F4175D	2017-08-08 14:28:00+03	48800.00
F41798	2017-07-12 15:00:00+03	102300.00
F417A9	2017-07-23 20:30:00+03	154500.00
F417FA	2017-07-30 06:43:00+03	12000.00
F41829	2017-07-04 00:14:00+03	113700.00
F41844	2017-07-30 14:03:00+03	88100.00
F4184C	2017-07-04 22:45:00+03	25400.00
F418A6	2017-08-09 15:16:00+03	103000.00
F41978	2017-07-02 16:33:00+03	26700.00
F41992	2017-08-06 22:21:00+03	40800.00
F419B6	2017-07-10 05:30:00+03	56000.00
F419BE	2017-06-30 18:42:00+03	6300.00
F419F0	2017-08-12 14:07:00+03	65900.00
F41B52	2017-07-25 12:46:00+03	6600.00
F41B7D	2017-07-29 00:21:00+03	75600.00
F41BEE	2017-08-11 06:39:00+03	19800.00
F41C85	2017-07-16 21:27:00+03	23200.00
F41C8F	2017-07-02 11:59:00+03	44600.00
F41CE0	2017-08-15 08:01:00+03	54400.00
F41CF7	2017-07-19 14:49:00+03	266400.00
F41D8F	2017-08-12 17:01:00+03	26800.00
F41D97	2017-07-19 02:50:00+03	70800.00
F41DBE	2017-08-10 18:48:00+03	71200.00
F41DE2	2017-07-03 23:18:00+03	27700.00
F41E24	2017-08-05 22:32:00+03	110100.00
F41E33	2017-07-05 08:05:00+03	133200.00
F41EEF	2017-07-01 06:02:00+03	16400.00
F41F61	2017-08-03 02:07:00+03	112000.00
F41FCE	2017-07-13 17:27:00+03	40100.00
F42013	2017-07-27 06:44:00+03	86500.00
F42031	2017-07-15 13:24:00+03	67600.00
F42039	2017-07-01 17:23:00+03	11600.00
F42094	2017-07-17 00:47:00+03	62700.00
F420A0	2017-08-11 04:59:00+03	44800.00
F420D4	2017-07-18 14:56:00+03	13800.00
F420DF	2017-07-10 18:13:00+03	66600.00
F420ED	2017-07-18 06:16:00+03	193200.00
F4211C	2017-07-02 21:50:00+03	29600.00
F42120	2017-08-10 19:24:00+03	39800.00
F42122	2017-08-07 16:54:00+03	83000.00
F4214C	2017-07-05 04:40:00+03	7400.00
F42170	2017-08-07 05:59:00+03	37200.00
F421F6	2017-08-07 09:03:00+03	6800.00
F42256	2017-07-22 07:43:00+03	71800.00
F422C7	2017-07-18 14:01:00+03	39500.00
F42322	2017-07-15 01:40:00+03	32700.00
F4239D	2017-07-21 03:59:00+03	17800.00
F423B7	2017-08-14 15:55:00+03	12600.00
F423CB	2017-07-16 10:05:00+03	27900.00
F4245C	2017-08-03 17:36:00+03	31400.00
F4248F	2017-07-25 07:08:00+03	28000.00
F424B6	2017-07-19 10:18:00+03	28000.00
F424BD	2017-07-05 13:10:00+03	47200.00
F424E0	2017-08-03 18:05:00+03	228500.00
F4255A	2017-07-16 20:22:00+03	49600.00
F42635	2017-08-14 05:49:00+03	103800.00
F42654	2017-07-08 23:21:00+03	113800.00
F42706	2017-08-08 00:25:00+03	189800.00
F42730	2017-07-16 03:21:00+03	28800.00
F42768	2017-07-30 20:34:00+03	38300.00
F427C3	2017-07-25 03:05:00+03	290600.00
F427E0	2017-07-31 07:55:00+03	257500.00
F42848	2017-07-13 11:20:00+03	168200.00
F42876	2017-07-08 21:30:00+03	105100.00
F4287E	2017-07-11 23:39:00+03	101800.00
F428AB	2017-07-02 15:51:00+03	58800.00
F428CB	2017-07-21 07:52:00+03	73500.00
F428CD	2017-07-31 08:50:00+03	90800.00
F428F9	2017-08-03 14:38:00+03	12000.00
F4290D	2017-07-25 16:08:00+03	27800.00
F42938	2017-08-04 09:55:00+03	40900.00
F42944	2017-07-28 23:08:00+03	30200.00
F4299F	2017-07-09 07:56:00+03	59800.00
F429B7	2017-08-06 17:16:00+03	54800.00
F42A12	2017-07-07 00:52:00+03	35700.00
F42A18	2017-08-11 22:25:00+03	101200.00
F42A4A	2017-07-10 03:30:00+03	51300.00
F42AE6	2017-07-09 03:59:00+03	53600.00
F42B0A	2017-07-17 23:05:00+03	24400.00
F42B17	2017-07-01 04:02:00+03	67700.00
F42B75	2017-07-27 11:05:00+03	26700.00
F42B7D	2017-07-03 15:32:00+03	14000.00
F42BCB	2017-07-31 07:39:00+03	75000.00
F42BF1	2017-07-16 01:04:00+03	173500.00
F42C1F	2017-07-11 05:31:00+03	12600.00
F42C30	2017-07-21 00:21:00+03	56000.00
F42C51	2017-07-22 03:00:00+03	32200.00
F42C74	2017-07-25 15:52:00+03	214800.00
F42CCE	2017-08-13 20:24:00+03	76600.00
F42D12	2017-08-04 02:49:00+03	151200.00
F42D82	2017-07-03 16:12:00+03	136800.00
F42DDA	2017-07-31 23:24:00+03	54800.00
F42E3A	2017-07-30 20:27:00+03	58400.00
F42EDB	2017-07-18 03:08:00+03	79800.00
F42EF7	2017-07-01 14:28:00+03	52100.00
F42F53	2017-08-10 04:55:00+03	155600.00
F42FC1	2017-08-11 22:51:00+03	24300.00
F42FE1	2017-07-09 13:18:00+03	49200.00
F4304A	2017-07-07 22:20:00+03	28000.00
F43095	2017-08-13 13:17:00+03	139300.00
F4309B	2017-07-29 13:30:00+03	41600.00
F430A4	2017-07-03 12:48:00+03	12600.00
F430A5	2017-08-08 23:47:00+03	88100.00
F430D1	2017-08-05 19:07:00+03	39600.00
F430FC	2017-08-10 22:57:00+03	104800.00
F4313E	2017-08-10 05:40:00+03	46500.00
F43154	2017-07-28 09:07:00+03	28000.00
F43179	2017-08-05 14:58:00+03	29600.00
F4319B	2017-07-01 05:52:00+03	67000.00
F43284	2017-06-30 04:22:00+03	93900.00
F4329A	2017-07-31 17:53:00+03	89100.00
F432B9	2017-08-02 11:04:00+03	88400.00
F432E6	2017-07-25 01:40:00+03	123000.00
F4335D	2017-07-06 03:48:00+03	43900.00
F433A0	2017-08-04 15:26:00+03	61800.00
F434C4	2017-08-03 12:22:00+03	21400.00
F434CF	2017-07-16 23:05:00+03	14600.00
F434F8	2017-07-19 10:05:00+03	83100.00
F43524	2017-07-18 10:11:00+03	67400.00
F43604	2017-08-09 17:56:00+03	103100.00
F43616	2017-07-27 21:31:00+03	50600.00
F4364D	2017-07-14 17:40:00+03	89600.00
F43659	2017-07-28 13:15:00+03	137600.00
F4365F	2017-07-09 23:25:00+03	12600.00
F4374A	2017-08-11 17:51:00+03	16400.00
F43753	2017-07-15 17:24:00+03	168000.00
F4376B	2017-07-09 11:11:00+03	72000.00
F43775	2017-07-21 13:34:00+03	53400.00
F437DC	2017-07-11 14:41:00+03	47600.00
F43827	2017-07-16 14:17:00+03	136200.00
F43853	2017-07-04 19:32:00+03	48800.00
F4385E	2017-07-14 04:32:00+03	67700.00
F43931	2017-07-11 05:12:00+03	16400.00
F4394E	2017-08-01 12:00:00+03	30800.00
F43964	2017-08-12 09:40:00+03	44500.00
F439B9	2017-08-15 13:48:00+03	285000.00
F439EA	2017-08-12 04:45:00+03	24400.00
F43ADB	2017-07-08 05:18:00+03	37900.00
F43AF8	2017-07-26 00:31:00+03	266400.00
F43B38	2017-08-02 02:59:00+03	11000.00
F43B8C	2017-08-08 11:47:00+03	134400.00
F43B9F	2017-08-01 03:15:00+03	24400.00
F43BA0	2017-07-24 03:33:00+03	33000.00
F43BEE	2017-08-01 23:28:00+03	43100.00
F43C54	2017-08-15 17:47:00+03	25100.00
F43CBD	2017-08-13 18:20:00+03	109600.00
F43CDD	2017-08-10 21:42:00+03	43600.00
F43CF3	2017-08-15 16:28:00+03	36800.00
F43CF4	2017-07-10 07:08:00+03	48800.00
F43D20	2017-07-16 21:57:00+03	23200.00
F43D22	2017-07-22 09:17:00+03	203000.00
F43DF3	2017-07-04 22:17:00+03	24400.00
F43E11	2017-08-11 19:15:00+03	223200.00
F43EB6	2017-08-07 14:27:00+03	56600.00
F43F8D	2017-08-06 22:59:00+03	93900.00
F43FFC	2017-07-23 23:44:00+03	59800.00
F44003	2017-07-02 23:02:00+03	105000.00
F44045	2017-07-15 18:57:00+03	119500.00
F4405E	2017-08-04 23:40:00+03	111600.00
F440E1	2017-08-02 06:29:00+03	11600.00
F440E4	2017-08-12 02:39:00+03	58400.00
F440EE	2017-08-13 05:51:00+03	19600.00
F440F9	2017-07-31 16:17:00+03	40800.00
F4413A	2017-08-09 22:27:00+03	83200.00
F44169	2017-07-22 22:31:00+03	32800.00
F44177	2017-08-12 18:46:00+03	46400.00
F441BA	2017-07-28 03:19:00+03	129700.00
F441DF	2017-08-05 04:38:00+03	8200.00
F4422A	2017-07-13 02:25:00+03	64400.00
F442AF	2017-07-07 14:06:00+03	89600.00
F44313	2017-07-08 07:43:00+03	67600.00
F44318	2017-07-26 20:32:00+03	46300.00
F4431A	2017-07-26 02:33:00+03	14000.00
F44429	2017-07-30 08:14:00+03	159200.00
F44459	2017-08-14 09:30:00+03	81900.00
F44466	2017-07-26 12:18:00+03	79600.00
F4446A	2017-08-15 17:52:00+03	59200.00
F44489	2017-08-10 06:22:00+03	14800.00
F444F5	2017-07-12 12:25:00+03	21600.00
F44513	2017-07-18 20:54:00+03	14400.00
F44514	2017-07-11 07:45:00+03	58400.00
F44575	2017-08-04 08:33:00+03	68100.00
F44639	2017-07-05 11:19:00+03	54200.00
F4464B	2017-07-02 12:52:00+03	13400.00
F44669	2017-07-24 02:24:00+03	68100.00
F44683	2017-07-23 00:12:00+03	136600.00
F446A2	2017-08-02 17:39:00+03	87300.00
F446B0	2017-07-18 21:15:00+03	29600.00
F446B1	2017-08-12 13:07:00+03	23400.00
F446C2	2017-08-11 06:00:00+03	17200.00
F446C8	2017-07-30 16:37:00+03	46700.00
F4470C	2017-07-10 12:36:00+03	94800.00
F447B5	2017-08-08 16:38:00+03	39800.00
F447C0	2017-08-02 18:14:00+03	97800.00
F447DC	2017-07-15 07:42:00+03	43500.00
F4484A	2017-07-10 10:43:00+03	58400.00
F44853	2017-07-31 07:57:00+03	58400.00
F4487D	2017-08-15 06:24:00+03	273400.00
F44919	2017-07-20 01:06:00+03	9300.00
F4493F	2017-07-18 22:38:00+03	47400.00
F449D6	2017-08-14 01:22:00+03	224000.00
F44A15	2017-07-12 16:17:00+03	134800.00
F44A2E	2017-07-14 19:28:00+03	23600.00
F44A85	2017-07-31 12:56:00+03	50000.00
F44A93	2017-07-14 09:34:00+03	55800.00
F44AF8	2017-07-22 23:22:00+03	187900.00
F44B06	2017-08-04 21:04:00+03	56000.00
F44B1F	2017-08-14 00:38:00+03	55800.00
F44B4C	2017-08-11 03:42:00+03	23600.00
F44BB8	2017-08-11 15:37:00+03	25200.00
F44BC8	2017-07-03 12:59:00+03	40800.00
F44BCB	2017-08-06 04:50:00+03	12400.00
F44BFA	2017-07-21 00:25:00+03	28000.00
F44C0C	2017-08-15 08:06:00+03	117000.00
F44C21	2017-08-02 23:45:00+03	215500.00
F44C4E	2017-08-15 08:28:00+03	51300.00
F44C66	2017-08-12 15:54:00+03	85000.00
F44C6C	2017-06-26 14:54:00+03	133600.00
F44CC0	2017-07-26 13:41:00+03	13200.00
F44CE1	2017-07-29 06:56:00+03	179300.00
F44CF7	2017-07-30 06:45:00+03	78200.00
F44D02	2017-07-10 06:00:00+03	44500.00
F44D94	2017-07-09 15:26:00+03	13200.00
F44D98	2017-07-16 05:32:00+03	42200.00
F44DDF	2017-07-31 22:12:00+03	42900.00
F44E19	2017-07-30 14:26:00+03	93900.00
F44E3F	2017-07-10 19:46:00+03	40000.00
F44F3B	2017-07-21 04:54:00+03	55800.00
F4503E	2017-07-14 11:40:00+03	12000.00
F45045	2017-08-03 04:54:00+03	86400.00
F450B0	2017-07-22 01:15:00+03	150900.00
F45104	2017-07-28 19:50:00+03	542600.00
F4517F	2017-07-23 13:47:00+03	133200.00
F45184	2017-07-08 22:43:00+03	12000.00
F451AA	2017-07-19 07:10:00+03	270800.00
F452E5	2017-07-18 17:42:00+03	76800.00
F452EA	2017-08-02 01:10:00+03	203400.00
F4530C	2017-07-28 10:53:00+03	282800.00
F4533A	2017-07-17 07:53:00+03	4000.00
F45347	2017-07-11 00:19:00+03	117200.00
F4534F	2017-08-13 17:05:00+03	57100.00
F4537B	2017-08-12 11:52:00+03	94000.00
F4540F	2017-08-11 15:21:00+03	90400.00
F4543C	2017-07-29 10:25:00+03	14800.00
F45468	2017-07-17 21:41:00+03	230400.00
F45469	2017-08-14 09:02:00+03	90400.00
F454CD	2017-07-16 01:43:00+03	26600.00
F454F6	2017-08-10 01:38:00+03	39200.00
F45503	2017-07-25 22:58:00+03	133100.00
F45510	2017-07-04 11:58:00+03	6700.00
F45512	2017-08-11 13:18:00+03	106000.00
F45576	2017-08-03 08:29:00+03	111000.00
F45589	2017-08-09 14:59:00+03	23600.00
F455A7	2017-08-04 20:07:00+03	20100.00
F45617	2017-07-25 18:12:00+03	56000.00
F45632	2017-07-22 17:33:00+03	133700.00
F456B2	2017-08-11 23:18:00+03	27800.00
F456BB	2017-07-30 06:27:00+03	12000.00
F4570D	2017-08-06 15:57:00+03	55800.00
F45721	2017-07-24 05:42:00+03	36200.00
F4579F	2017-07-10 04:13:00+03	38600.00
F457C9	2017-08-06 14:39:00+03	51900.00
F45806	2017-07-22 18:14:00+03	65000.00
F45887	2017-08-04 20:41:00+03	134400.00
F458B6	2017-07-27 03:33:00+03	6700.00
F45934	2017-08-12 09:38:00+03	67500.00
F4593B	2017-07-14 14:39:00+03	68600.00
F45965	2017-07-27 09:39:00+03	18000.00
F45A1D	2017-07-27 10:20:00+03	95600.00
F45A75	2017-06-27 20:48:00+03	265700.00
F45ABE	2017-08-07 04:02:00+03	89900.00
F45AF5	2017-08-03 14:47:00+03	124100.00
F45AF7	2017-07-29 12:12:00+03	134700.00
F45B25	2017-07-31 15:18:00+03	410400.00
F45B2D	2017-07-29 04:21:00+03	14800.00
F45B58	2017-08-11 04:50:00+03	56900.00
F45BF2	2017-08-03 00:48:00+03	179300.00
F45C79	2017-08-14 00:25:00+03	25000.00
F45C8D	2017-07-24 01:25:00+03	38600.00
F45C8E	2017-07-29 08:56:00+03	107500.00
F45DAD	2017-07-02 10:21:00+03	64400.00
F45DFD	2017-07-28 16:31:00+03	75600.00
F45E51	2017-07-21 16:21:00+03	109300.00
F45E52	2017-08-02 20:56:00+03	128800.00
F45E73	2017-08-11 09:52:00+03	77200.00
F45EBE	2017-08-14 16:42:00+03	6000.00
F45EC9	2017-07-07 12:14:00+03	26800.00
F45ED7	2017-08-03 15:21:00+03	37600.00
F45F1D	2017-08-08 18:51:00+03	22100.00
F45F7B	2017-08-12 20:22:00+03	70800.00
F46039	2017-06-30 17:01:00+03	152400.00
F46064	2017-08-02 23:25:00+03	81600.00
F460BD	2017-07-16 21:10:00+03	14000.00
F460DD	2017-07-05 05:30:00+03	39200.00
F460F5	2017-07-24 04:01:00+03	47000.00
F46102	2017-07-06 03:12:00+03	99700.00
F46143	2017-07-10 23:59:00+03	56600.00
F4615B	2017-07-22 06:15:00+03	45100.00
F461AB	2017-08-05 05:46:00+03	57400.00
F461E4	2017-07-07 15:29:00+03	120000.00
F461F7	2017-08-11 19:31:00+03	8200.00
F46248	2017-07-13 21:06:00+03	62200.00
F463E5	2017-07-26 05:24:00+03	42700.00
F46405	2017-08-11 21:52:00+03	57600.00
F4640D	2017-06-28 13:26:00+03	26000.00
F4640F	2017-07-08 07:08:00+03	38200.00
F46411	2017-07-01 10:16:00+03	113500.00
F46420	2017-08-08 22:10:00+03	176300.00
F4646F	2017-08-12 08:29:00+03	42600.00
F464CD	2017-08-02 16:08:00+03	162200.00
F464D2	2017-07-12 17:19:00+03	48800.00
F464F8	2017-07-12 18:22:00+03	396500.00
F46531	2017-07-23 23:10:00+03	26200.00
F46569	2017-07-15 00:43:00+03	20000.00
F4657F	2017-07-20 03:31:00+03	258900.00
F465A6	2017-08-10 10:01:00+03	22000.00
F465BD	2017-07-09 06:38:00+03	42800.00
F4662B	2017-07-15 19:00:00+03	203000.00
F4662D	2017-08-09 07:55:00+03	112000.00
F46646	2017-08-11 14:52:00+03	182300.00
F46666	2017-07-05 09:10:00+03	129700.00
F4669F	2017-07-24 21:56:00+03	44800.00
F466A4	2017-08-04 12:54:00+03	242700.00
F466BF	2017-07-02 04:41:00+03	55800.00
F46754	2017-08-03 16:33:00+03	34800.00
F46772	2017-08-01 20:20:00+03	37600.00
F4678E	2017-07-27 15:02:00+03	24400.00
F467C9	2017-07-22 14:52:00+03	272300.00
F4682C	2017-08-06 14:16:00+03	42700.00
F46833	2017-08-01 12:20:00+03	182100.00
F4686D	2017-07-13 11:20:00+03	39200.00
F468D3	2017-08-03 00:30:00+03	176900.00
F46963	2017-07-08 22:49:00+03	39200.00
F46977	2017-07-18 03:42:00+03	58600.00
F469A9	2017-08-01 19:21:00+03	56600.00
F469BE	2017-07-25 15:01:00+03	20200.00
F469C1	2017-07-26 10:50:00+03	31000.00
F469FB	2017-07-14 17:01:00+03	266400.00
F46A15	2017-07-07 17:46:00+03	68100.00
F46A6B	2017-07-21 13:39:00+03	111600.00
F46A9A	2017-07-31 07:07:00+03	111600.00
F46AB8	2017-08-14 21:45:00+03	48800.00
F46BAA	2017-07-27 07:32:00+03	142300.00
F46C0C	2017-07-03 06:29:00+03	82900.00
F46C5B	2017-08-08 00:16:00+03	47200.00
F46C7B	2017-07-22 00:24:00+03	142000.00
F46CF3	2017-07-14 17:53:00+03	63600.00
F46CF7	2017-07-28 10:44:00+03	58800.00
F46DC5	2017-07-31 13:30:00+03	41600.00
F46DD9	2017-07-25 13:50:00+03	23200.00
F46DFD	2017-08-15 03:01:00+03	19600.00
F46E3E	2017-07-03 20:48:00+03	39300.00
F46E92	2017-08-01 10:22:00+03	67700.00
F46E95	2017-07-28 07:44:00+03	113800.00
F46EBF	2017-07-11 06:16:00+03	242300.00
F46EE9	2017-08-05 13:05:00+03	14000.00
F46F22	2017-08-04 10:33:00+03	114800.00
F46F8C	2017-07-04 11:45:00+03	28800.00
F46F9D	2017-07-20 10:23:00+03	16400.00
F46FDA	2017-07-15 18:17:00+03	124200.00
F46FEE	2017-07-16 11:23:00+03	45100.00
F4708A	2017-07-15 17:41:00+03	131100.00
F47098	2017-08-08 10:21:00+03	36800.00
F47211	2017-07-12 06:28:00+03	57600.00
F47246	2017-07-12 18:27:00+03	62000.00
F47269	2017-07-08 19:20:00+03	54000.00
F4726D	2017-07-24 23:48:00+03	25000.00
F4728D	2017-08-14 09:48:00+03	128600.00
F472C0	2017-08-11 21:09:00+03	166000.00
F472C5	2017-08-02 10:41:00+03	58000.00
F472EF	2017-08-13 23:07:00+03	100000.00
F4732B	2017-08-01 14:59:00+03	265600.00
F47337	2017-07-12 21:27:00+03	38400.00
F47359	2017-07-19 09:29:00+03	112000.00
F473C8	2017-08-03 07:09:00+03	101100.00
F473EC	2017-07-16 08:28:00+03	28000.00
F473F9	2017-07-11 17:30:00+03	78000.00
F4740B	2017-08-06 08:47:00+03	28000.00
F4741B	2017-07-16 10:44:00+03	412700.00
F47473	2017-07-20 13:55:00+03	135600.00
F474AD	2017-08-11 16:57:00+03	18400.00
F474F2	2017-07-19 16:24:00+03	21400.00
F47505	2017-07-25 08:16:00+03	159800.00
F4751A	2017-08-15 01:11:00+03	112000.00
F47541	2017-08-06 11:58:00+03	117700.00
F47588	2017-07-21 13:03:00+03	65300.00
F475C1	2017-08-05 18:23:00+03	109800.00
F475C4	2017-07-29 22:45:00+03	90600.00
F475FC	2017-08-13 04:45:00+03	47200.00
F47603	2017-08-09 23:11:00+03	22000.00
F47669	2017-06-28 01:33:00+03	56000.00
F476AC	2017-07-14 15:41:00+03	111600.00
F476AD	2017-07-24 06:34:00+03	135400.00
F476BF	2017-08-05 02:00:00+03	21600.00
F47724	2017-07-14 23:12:00+03	23600.00
F4772B	2017-07-27 18:50:00+03	119300.00
F477A4	2017-07-26 06:10:00+03	93700.00
F477A6	2017-07-09 13:39:00+03	16400.00
F47802	2017-08-11 20:45:00+03	199800.00
F47837	2017-07-25 11:26:00+03	58900.00
F4784F	2017-07-12 11:58:00+03	78000.00
F47855	2017-08-14 04:54:00+03	52700.00
F47887	2017-07-15 08:44:00+03	260300.00
F478F3	2017-07-16 02:09:00+03	294400.00
F478FE	2017-07-25 18:47:00+03	78400.00
F4792F	2017-07-23 21:19:00+03	68800.00
F4793B	2017-07-28 07:34:00+03	57800.00
F47959	2017-06-27 00:07:00+03	35600.00
F47A25	2017-08-05 15:14:00+03	123000.00
F47A4F	2017-08-13 03:19:00+03	179300.00
F47A6C	2017-07-10 11:49:00+03	136200.00
F47AB4	2017-08-08 05:58:00+03	37200.00
F47AB8	2017-08-01 09:09:00+03	210000.00
F47AF9	2017-07-18 06:51:00+03	69500.00
F47B02	2017-08-10 03:21:00+03	29600.00
F47B82	2017-07-06 17:31:00+03	45500.00
F47C6A	2017-07-27 17:24:00+03	35200.00
F47CCA	2017-07-30 09:18:00+03	39600.00
F47CDC	2017-07-05 15:17:00+03	34800.00
F47CF3	2017-07-20 14:03:00+03	69500.00
F47D9A	2017-07-08 19:21:00+03	56000.00
F47DDA	2017-07-04 06:21:00+03	100600.00
F47DF5	2017-07-24 05:42:00+03	57600.00
F47E22	2017-07-23 21:29:00+03	151200.00
F47E27	2017-08-03 06:46:00+03	21800.00
F47EB7	2017-08-07 15:36:00+03	130300.00
F47F2D	2017-08-01 22:45:00+03	21500.00
F47F2F	2017-07-14 04:08:00+03	43600.00
F47FBE	2017-07-03 18:48:00+03	50000.00
F47FC6	2017-08-10 04:10:00+03	52000.00
F47FD8	2017-07-23 09:37:00+03	16400.00
F4802D	2017-07-09 07:19:00+03	58900.00
F48039	2017-07-01 02:13:00+03	182800.00
F4805F	2017-07-13 05:23:00+03	25600.00
F4808D	2017-07-29 08:09:00+03	68800.00
F480DE	2017-07-14 05:46:00+03	23400.00
F480FD	2017-08-14 10:49:00+03	26800.00
F4810D	2017-07-11 19:03:00+03	22000.00
F4816C	2017-07-23 18:33:00+03	71200.00
F48187	2017-07-10 00:04:00+03	53500.00
F481A9	2017-08-04 21:28:00+03	53300.00
F481B8	2017-07-14 16:14:00+03	18100.00
F481F2	2017-07-16 10:18:00+03	15100.00
F481F5	2017-07-11 16:59:00+03	240600.00
F4820B	2017-08-13 00:58:00+03	154700.00
F4820F	2017-07-20 08:24:00+03	28000.00
F48241	2017-08-06 08:34:00+03	107400.00
F48254	2017-08-06 14:41:00+03	9200.00
F482A3	2017-07-17 20:54:00+03	49900.00
F482F2	2017-08-04 22:41:00+03	12400.00
F4831C	2017-07-26 11:39:00+03	6600.00
F48340	2017-08-11 02:53:00+03	22000.00
F4835D	2017-07-10 14:56:00+03	246000.00
F48374	2017-07-31 17:56:00+03	153300.00
F4838E	2017-07-09 13:36:00+03	42800.00
F48396	2017-08-04 23:13:00+03	63700.00
F483F2	2017-08-04 02:34:00+03	29400.00
F4840B	2017-07-23 20:29:00+03	59200.00
F48411	2017-07-27 09:09:00+03	189800.00
F48413	2017-08-13 03:12:00+03	83600.00
F48438	2017-08-12 07:49:00+03	42700.00
F484AA	2017-07-29 17:16:00+03	179500.00
F484D2	2017-07-14 07:59:00+03	53400.00
F4851F	2017-07-07 02:38:00+03	37100.00
F48554	2017-07-07 05:41:00+03	14800.00
F48556	2017-07-25 10:15:00+03	46400.00
F48563	2017-08-14 12:29:00+03	75300.00
F485BF	2017-06-30 09:52:00+03	62600.00
F485F4	2017-08-08 07:01:00+03	136800.00
F4864F	2017-08-12 15:26:00+03	12600.00
F48675	2017-07-10 16:17:00+03	258400.00
F48728	2017-07-24 15:33:00+03	50000.00
F4873B	2017-07-11 00:01:00+03	48100.00
F4873E	2017-07-29 05:21:00+03	57400.00
F48787	2017-08-05 10:56:00+03	44800.00
F487FE	2017-07-17 15:59:00+03	20500.00
F4880A	2017-07-09 23:00:00+03	62800.00
F4882D	2017-07-26 00:59:00+03	64800.00
F4887F	2017-07-04 17:31:00+03	44800.00
F48903	2017-08-06 06:15:00+03	43200.00
F48935	2017-07-06 08:37:00+03	31400.00
F48941	2017-07-30 04:31:00+03	58200.00
F48A2B	2017-07-01 04:57:00+03	526800.00
F48A3E	2017-07-28 15:21:00+03	66600.00
F48A4D	2017-08-12 04:51:00+03	57800.00
F48A8E	2017-07-11 17:04:00+03	182300.00
F48ABF	2017-07-16 02:04:00+03	24700.00
F48B1F	2017-08-12 19:48:00+03	18100.00
F48B9C	2017-07-11 09:09:00+03	205200.00
F48BF4	2017-07-18 07:27:00+03	59300.00
F48C21	2017-07-16 22:19:00+03	128800.00
F48C7B	2017-08-06 03:16:00+03	42400.00
F48CCA	2017-07-18 20:28:00+03	25600.00
F48CE6	2017-07-08 14:29:00+03	190400.00
F48CEB	2017-07-05 15:29:00+03	123000.00
F48D64	2017-08-08 18:02:00+03	115800.00
F48DB0	2017-08-05 09:30:00+03	28800.00
F48DB6	2017-07-18 22:51:00+03	521200.00
F48DB8	2017-07-17 05:56:00+03	28600.00
F48DE9	2017-07-19 08:41:00+03	73600.00
F48E1C	2017-08-11 07:39:00+03	45200.00
F48E55	2017-07-16 05:06:00+03	38800.00
F48E9C	2017-07-08 16:00:00+03	7200.00
F48EB7	2017-07-23 04:37:00+03	46400.00
F48ECF	2017-07-05 03:28:00+03	37500.00
F48F1F	2017-08-11 16:20:00+03	40000.00
F48F96	2017-07-05 22:10:00+03	59800.00
F48F9B	2017-08-14 10:56:00+03	12000.00
F48FF0	2017-07-16 06:39:00+03	31400.00
F49071	2017-07-08 14:00:00+03	23200.00
F490D4	2017-07-09 09:34:00+03	88400.00
F49146	2017-08-09 14:51:00+03	135000.00
F4917F	2017-07-28 13:15:00+03	28800.00
F49224	2017-08-12 09:56:00+03	28000.00
F49258	2017-08-02 12:17:00+03	29600.00
F492B8	2017-08-14 11:05:00+03	46900.00
F492C4	2017-07-29 02:18:00+03	46400.00
F492D9	2017-07-18 15:27:00+03	64600.00
F49320	2017-08-03 06:15:00+03	21200.00
F49324	2017-07-24 20:58:00+03	73500.00
F4936F	2017-07-14 20:11:00+03	55300.00
F493E5	2017-07-25 21:02:00+03	6200.00
F49412	2017-08-08 09:17:00+03	131100.00
F49446	2017-06-28 10:56:00+03	81000.00
F494AA	2017-07-06 16:10:00+03	29200.00
F494BD	2017-06-30 16:57:00+03	47200.00
F494F1	2017-08-09 23:08:00+03	56000.00
F49611	2017-06-29 22:30:00+03	57400.00
F4963F	2017-07-12 06:06:00+03	54500.00
F496DB	2017-08-04 16:24:00+03	120900.00
F49716	2017-08-05 14:29:00+03	40000.00
F4974D	2017-07-16 19:23:00+03	81700.00
F4978F	2017-08-07 12:05:00+03	137700.00
F49798	2017-08-05 07:43:00+03	386300.00
F497E5	2017-08-15 17:55:00+03	22100.00
F4981C	2017-08-13 03:55:00+03	36200.00
F49875	2017-07-17 12:25:00+03	76600.00
F498F7	2017-08-06 09:35:00+03	229600.00
F49911	2017-07-09 22:12:00+03	82200.00
F49922	2017-07-20 12:26:00+03	31900.00
F49993	2017-06-29 05:04:00+03	167500.00
F499AD	2017-07-22 02:08:00+03	20200.00
F49A4B	2017-07-18 05:51:00+03	54800.00
F49A7B	2017-07-19 19:28:00+03	28000.00
F49A94	2017-07-21 08:50:00+03	25100.00
F49AD5	2017-07-08 09:23:00+03	170700.00
F49B09	2017-08-03 03:38:00+03	197900.00
F49B25	2017-08-06 10:00:00+03	25600.00
F49B64	2017-08-14 19:45:00+03	26800.00
F49B88	2017-08-11 03:12:00+03	93500.00
F49BDE	2017-07-25 19:39:00+03	266400.00
F49BE9	2017-07-29 21:43:00+03	26000.00
F49C45	2017-08-04 01:57:00+03	181600.00
F49C4F	2017-07-27 07:19:00+03	16400.00
F49C73	2017-07-21 16:46:00+03	23400.00
F49C85	2017-07-29 09:01:00+03	103800.00
F49CBD	2017-08-14 20:11:00+03	6800.00
F49CEB	2017-08-05 14:06:00+03	246000.00
F49D15	2017-08-06 21:36:00+03	28300.00
F49D7F	2017-07-23 19:15:00+03	29200.00
F49D85	2017-07-23 04:19:00+03	46400.00
F49DB9	2017-07-22 22:04:00+03	59000.00
F49DCE	2017-07-17 05:02:00+03	49300.00
F49E1E	2017-08-10 16:36:00+03	22000.00
F49E39	2017-07-01 10:26:00+03	41400.00
F49E3A	2017-07-24 10:48:00+03	90600.00
F49E64	2017-08-05 21:42:00+03	85700.00
F49E87	2017-08-15 09:52:00+03	26800.00
F49EC1	2017-07-23 17:29:00+03	20500.00
F49FAA	2017-08-10 02:42:00+03	35600.00
F49FB9	2017-07-17 04:54:00+03	112000.00
F49FED	2017-08-07 05:54:00+03	47000.00
F4A0BD	2017-08-09 04:01:00+03	91300.00
F4A0C1	2017-07-24 09:57:00+03	378700.00
F4A0EB	2017-08-11 22:48:00+03	70600.00
F4A0F8	2017-07-12 18:36:00+03	119600.00
F4A102	2017-08-08 19:46:00+03	26000.00
F4A157	2017-07-20 16:58:00+03	46400.00
F4A1CD	2017-07-11 21:59:00+03	47400.00
F4A220	2017-07-05 04:56:00+03	53400.00
F4A24A	2017-07-20 14:16:00+03	43600.00
F4A26A	2017-07-27 07:43:00+03	30200.00
F4A302	2017-08-13 06:18:00+03	38000.00
F4A33C	2017-08-01 12:08:00+03	106600.00
F4A350	2017-07-27 00:50:00+03	28000.00
F4A36C	2017-07-30 00:09:00+03	125500.00
F4A372	2017-07-19 05:54:00+03	8400.00
F4A39B	2017-08-09 01:48:00+03	14000.00
F4A3A7	2017-07-07 04:33:00+03	83600.00
F4A3B0	2017-07-14 02:20:00+03	14400.00
F4A3B9	2017-06-26 01:40:00+03	27000.00
F4A406	2017-08-05 00:51:00+03	54300.00
F4A43E	2017-08-04 09:27:00+03	68000.00
F4A43F	2017-07-21 04:06:00+03	28000.00
F4A444	2017-07-18 17:36:00+03	25900.00
F4A480	2017-07-16 09:16:00+03	37200.00
F4A4CD	2017-08-14 10:49:00+03	18600.00
F4A515	2017-07-06 17:44:00+03	66600.00
F4A52B	2017-07-05 21:10:00+03	38800.00
F4A5F5	2017-08-11 02:53:00+03	18800.00
F4A628	2017-07-10 15:55:00+03	120300.00
F4A677	2017-08-12 11:41:00+03	264600.00
F4A770	2017-07-23 23:53:00+03	65300.00
F4A7B8	2017-07-17 00:24:00+03	40100.00
F4A7E5	2017-08-09 06:23:00+03	90400.00
F4A817	2017-08-08 10:27:00+03	16400.00
F4A821	2017-07-27 02:43:00+03	77900.00
F4A853	2017-08-04 08:09:00+03	13800.00
F4A881	2017-07-31 20:16:00+03	156600.00
F4A8A5	2017-08-06 10:39:00+03	52900.00
F4A8BE	2017-08-08 03:26:00+03	124200.00
F4A8F7	2017-07-19 06:30:00+03	113700.00
F4A90F	2017-08-15 16:03:00+03	101200.00
F4A913	2017-07-28 13:39:00+03	56600.00
F4A949	2017-07-14 07:55:00+03	37200.00
F4A973	2017-07-18 12:57:00+03	131600.00
F4A989	2017-07-27 08:26:00+03	86800.00
F4A9C3	2017-08-01 21:14:00+03	23200.00
F4A9DE	2017-08-14 20:35:00+03	170000.00
F4A9E6	2017-08-09 20:06:00+03	78800.00
F4AA1D	2017-08-06 19:44:00+03	20400.00
F4AA37	2017-07-10 18:18:00+03	26000.00
F4AA8A	2017-07-14 04:01:00+03	240600.00
F4AAB1	2017-08-14 22:07:00+03	127000.00
F4AB1C	2017-08-11 15:57:00+03	20600.00
F4AB65	2017-07-04 02:23:00+03	31800.00
F4AB7F	2017-07-29 01:47:00+03	34000.00
F4ABC3	2017-07-08 15:27:00+03	44600.00
F4AC50	2017-08-02 17:18:00+03	46400.00
F4ACAA	2017-07-23 23:11:00+03	54400.00
F4ACBD	2017-07-06 13:41:00+03	134400.00
F4ACD3	2017-07-29 07:57:00+03	137600.00
F4AD01	2017-07-16 15:27:00+03	406600.00
F4AD21	2017-08-13 18:52:00+03	327000.00
F4AD8E	2017-07-23 05:14:00+03	6000.00
F4ADA6	2017-07-10 05:51:00+03	6800.00
F4AE65	2017-07-12 22:14:00+03	44100.00
F4AE67	2017-08-11 00:12:00+03	8200.00
F4AE80	2017-08-15 03:09:00+03	18600.00
F4AEAA	2017-07-17 05:40:00+03	28800.00
F4AF24	2017-08-10 08:07:00+03	57800.00
F4AF38	2017-08-14 23:07:00+03	31200.00
F4AF80	2017-07-05 01:18:00+03	61800.00
F4AFA2	2017-07-20 00:25:00+03	78200.00
F4AFC9	2017-07-03 11:12:00+03	36100.00
F4B00B	2017-08-09 21:34:00+03	16400.00
F4B022	2017-07-21 01:42:00+03	38600.00
F4B0D9	2017-07-30 17:08:00+03	58000.00
F4B157	2017-07-18 23:45:00+03	258400.00
F4B1AD	2017-07-16 22:30:00+03	26000.00
F4B1C2	2017-08-05 20:21:00+03	145700.00
F4B1C7	2017-08-10 17:08:00+03	8200.00
F4B1D0	2017-08-03 07:26:00+03	46800.00
F4B1E3	2017-08-11 06:03:00+03	39200.00
F4B273	2017-06-29 23:22:00+03	57500.00
F4B290	2017-07-23 13:46:00+03	80400.00
F4B2B6	2017-08-04 13:00:00+03	55800.00
F4B2E3	2017-07-06 03:45:00+03	56000.00
F4B371	2017-07-18 16:59:00+03	65500.00
F4B402	2017-07-12 07:50:00+03	29600.00
F4B419	2017-08-10 19:37:00+03	46000.00
F4B45F	2017-07-06 10:12:00+03	65500.00
F4B493	2017-07-06 05:33:00+03	52800.00
F4B4C3	2017-08-06 16:19:00+03	67400.00
F4B4DA	2017-07-18 20:16:00+03	189800.00
F4B507	2017-06-30 10:03:00+03	136000.00
F4B51F	2017-07-18 01:34:00+03	68400.00
F4B658	2017-07-09 07:13:00+03	77900.00
F4B6BF	2017-08-14 03:11:00+03	38800.00
F4B6C9	2017-07-12 10:45:00+03	46400.00
F4B6E8	2017-07-02 14:29:00+03	95600.00
F4B703	2017-08-11 21:31:00+03	33000.00
F4B773	2017-07-28 09:19:00+03	174300.00
F4B779	2017-07-14 10:30:00+03	47600.00
F4B7F1	2017-07-25 04:33:00+03	56600.00
F4B82B	2017-07-01 18:35:00+03	124100.00
F4B87C	2017-07-10 20:19:00+03	33800.00
F4B8C8	2017-07-25 02:56:00+03	96300.00
F4B8D7	2017-07-06 15:10:00+03	112000.00
F4B8DA	2017-07-15 20:28:00+03	65900.00
F4B8F8	2017-08-02 13:56:00+03	96300.00
F4B8FB	2017-08-09 08:44:00+03	67200.00
F4B953	2017-07-31 13:04:00+03	12400.00
F4B9DB	2017-08-04 03:43:00+03	23200.00
F4BA13	2017-08-01 02:05:00+03	23200.00
F4BA1C	2017-07-18 03:50:00+03	56000.00
F4BA20	2017-08-07 16:41:00+03	25800.00
F4BAE4	2017-07-23 02:15:00+03	123000.00
F4BAFC	2017-08-12 22:11:00+03	23200.00
F4BB0A	2017-08-09 12:09:00+03	136200.00
F4BB57	2017-07-25 06:34:00+03	167400.00
F4BB7D	2017-08-08 18:30:00+03	36900.00
F4BB92	2017-07-19 04:26:00+03	272400.00
F4BB98	2017-07-03 03:29:00+03	187600.00
F4BBA3	2017-07-09 20:48:00+03	32600.00
F4BBB7	2017-08-13 18:05:00+03	23200.00
F4BC0E	2017-07-03 00:37:00+03	50600.00
F4BCEE	2017-08-08 03:21:00+03	56900.00
F4BD09	2017-07-09 22:37:00+03	67200.00
F4BD0D	2017-08-04 21:18:00+03	123000.00
F4BD65	2017-07-18 05:39:00+03	25000.00
F4BDE6	2017-08-10 09:16:00+03	166100.00
F4BDF4	2017-06-30 11:48:00+03	59800.00
F4BE28	2017-08-09 02:17:00+03	38400.00
F4BE77	2017-08-05 23:18:00+03	53000.00
F4BED9	2017-07-22 17:41:00+03	271100.00
F4BEEF	2017-07-27 18:39:00+03	59800.00
F4BF95	2017-08-13 03:53:00+03	39300.00
F4BF99	2017-07-23 22:51:00+03	58200.00
F4BFBD	2017-07-11 03:21:00+03	102700.00
F4C00B	2017-07-09 09:22:00+03	89600.00
F4C0AD	2017-08-03 05:44:00+03	290500.00
F4C0CB	2017-07-18 09:14:00+03	48800.00
F4C0DD	2017-07-18 13:24:00+03	380700.00
F4C105	2017-07-26 12:15:00+03	24400.00
F4C188	2017-07-23 22:54:00+03	74100.00
F4C2C1	2017-07-18 18:53:00+03	90800.00
F4C2D4	2017-07-11 09:56:00+03	48100.00
F4C2E5	2017-07-10 21:08:00+03	65700.00
F4C50A	2017-08-09 06:57:00+03	153300.00
F4C527	2017-07-05 00:47:00+03	66600.00
F4C573	2017-06-30 21:45:00+03	99300.00
F4C57A	2017-08-07 21:28:00+03	54800.00
F4C588	2017-07-09 03:36:00+03	27900.00
F4C5DA	2017-07-12 10:56:00+03	26800.00
F4C629	2017-07-23 08:21:00+03	92800.00
F4C673	2017-07-01 14:36:00+03	114200.00
F4C6C7	2017-07-25 23:59:00+03	96800.00
F4C765	2017-08-01 06:29:00+03	25600.00
F4C780	2017-08-10 14:49:00+03	179500.00
F4C784	2017-07-01 07:39:00+03	13400.00
F4C797	2017-07-09 21:21:00+03	26000.00
F4C7E1	2017-07-19 22:23:00+03	52400.00
F4C7FC	2017-08-10 22:11:00+03	6000.00
F4C812	2017-06-24 09:33:00+03	195600.00
F4C880	2017-07-09 20:15:00+03	144000.00
F4C8D0	2017-07-25 09:20:00+03	39500.00
F4C8E7	2017-07-22 13:34:00+03	38400.00
F4C91C	2017-08-11 06:29:00+03	46400.00
F4C953	2017-08-03 17:09:00+03	136200.00
F4C95F	2017-06-30 09:28:00+03	269200.00
F4C972	2017-06-27 17:25:00+03	50400.00
F4C9A2	2017-07-08 21:23:00+03	135600.00
F4C9C9	2017-07-31 16:16:00+03	92000.00
F4C9D9	2017-07-08 16:20:00+03	81300.00
F4C9E4	2017-08-15 05:00:00+03	199700.00
F4C9FD	2017-07-07 21:19:00+03	94800.00
F4CAF6	2017-07-29 14:37:00+03	280000.00
F4CBC4	2017-07-23 10:23:00+03	24400.00
F4CC07	2017-07-03 14:03:00+03	62700.00
F4CC85	2017-07-05 17:19:00+03	48300.00
F4CCA7	2017-07-02 22:31:00+03	20200.00
F4CCCE	2017-08-08 19:41:00+03	239000.00
F4CD07	2017-07-14 13:48:00+03	28000.00
F4CDFE	2017-06-24 11:30:00+03	86600.00
F4CE1D	2017-07-10 10:24:00+03	544700.00
F4CE40	2017-08-05 10:38:00+03	114200.00
F4CE5C	2017-08-13 15:51:00+03	16400.00
F4CE64	2017-07-10 07:17:00+03	37200.00
F4CEFF	2017-07-24 04:04:00+03	14000.00
F4CF27	2017-08-01 10:32:00+03	16400.00
F4CFA6	2017-08-08 08:55:00+03	99700.00
F4D05C	2017-07-27 01:20:00+03	31400.00
F4D18A	2017-07-08 15:29:00+03	75300.00
F4D196	2017-07-03 07:37:00+03	51600.00
F4D1CE	2017-07-22 11:28:00+03	52100.00
F4D1D6	2017-07-08 14:26:00+03	27900.00
F4D1F9	2017-07-31 11:39:00+03	46800.00
F4D209	2017-07-09 23:53:00+03	67300.00
F4D20E	2017-08-07 09:51:00+03	36200.00
F4D251	2017-07-10 17:03:00+03	136200.00
F4D301	2017-08-06 02:37:00+03	246000.00
F4D32B	2017-07-22 20:45:00+03	135400.00
F4D385	2017-08-15 17:37:00+03	37000.00
F4D389	2017-07-04 23:38:00+03	31600.00
F4D429	2017-07-06 19:33:00+03	130900.00
F4D468	2017-07-17 06:19:00+03	52300.00
F4D46C	2017-06-29 04:04:00+03	28800.00
F4D477	2017-08-13 14:32:00+03	119800.00
F4D47C	2017-08-02 06:49:00+03	27800.00
F4D4E2	2017-07-26 07:11:00+03	60000.00
F4D4F7	2017-07-31 17:14:00+03	136800.00
F4D50F	2017-07-10 06:49:00+03	67600.00
F4D532	2017-07-15 03:36:00+03	95600.00
F4D537	2017-08-15 09:11:00+03	304100.00
F4D638	2017-08-11 03:59:00+03	25600.00
F4D6BB	2017-07-03 20:11:00+03	20800.00
F4D6D4	2017-07-21 00:08:00+03	31100.00
F4D6FA	2017-08-02 00:10:00+03	29600.00
F4D725	2017-07-10 22:09:00+03	68000.00
F4D735	2017-07-06 12:13:00+03	112000.00
F4D753	2017-07-08 18:09:00+03	90400.00
F4D78E	2017-07-11 03:00:00+03	65000.00
F4D796	2017-07-16 15:04:00+03	136200.00
F4D7CC	2017-08-04 03:21:00+03	20200.00
F4D7F5	2017-08-03 12:45:00+03	46200.00
F4D7F9	2017-07-06 12:02:00+03	16400.00
F4D8CC	2017-08-14 14:04:00+03	26800.00
F4DAA1	2017-07-10 05:01:00+03	17200.00
F4DB23	2017-07-16 09:26:00+03	369000.00
F4DB32	2017-08-12 16:29:00+03	74800.00
F4DB83	2017-08-01 16:16:00+03	31200.00
F4DB91	2017-07-25 06:39:00+03	66600.00
F4DCB5	2017-08-04 23:42:00+03	62000.00
F4DCF4	2017-07-07 16:29:00+03	29600.00
F4DD4C	2017-08-14 20:01:00+03	67600.00
F4DD50	2017-08-11 06:32:00+03	111600.00
F4DD99	2017-07-07 09:08:00+03	82500.00
F4DDFC	2017-07-17 05:36:00+03	26000.00
F4DEDE	2017-07-14 18:35:00+03	75600.00
F4DF07	2017-07-01 13:58:00+03	63700.00
F4DF68	2017-07-31 00:07:00+03	75600.00
F4DFE6	2017-07-20 15:42:00+03	70700.00
F4E094	2017-08-11 05:02:00+03	12400.00
F4E0A1	2017-07-25 21:24:00+03	199700.00
F4E0F3	2017-08-09 19:45:00+03	140900.00
F4E0FF	2017-07-21 14:19:00+03	47000.00
F4E12D	2017-07-13 19:41:00+03	240600.00
F4E13D	2017-07-22 04:15:00+03	135400.00
F4E1BD	2017-07-12 00:58:00+03	17200.00
F4E1C1	2017-07-22 23:52:00+03	41200.00
F4E1D8	2017-08-14 13:14:00+03	381400.00
F4E1D9	2017-08-06 15:19:00+03	24400.00
F4E206	2017-07-12 06:19:00+03	87000.00
F4E20A	2017-08-10 10:35:00+03	13400.00
F4E254	2017-07-03 16:51:00+03	86800.00
F4E2A2	2017-08-04 00:58:00+03	45400.00
F4E382	2017-08-07 14:51:00+03	103500.00
F4E3EF	2017-08-01 09:16:00+03	112000.00
F4E3FE	2017-07-17 06:44:00+03	72400.00
F4E400	2017-07-13 00:05:00+03	43200.00
F4E419	2017-08-02 20:54:00+03	67200.00
F4E44C	2017-08-03 04:39:00+03	101200.00
F4E472	2017-08-12 19:54:00+03	58000.00
F4E47A	2017-07-24 13:21:00+03	130100.00
F4E48B	2017-07-15 08:18:00+03	34600.00
F4E4EB	2017-07-27 12:50:00+03	96300.00
F4E4F4	2017-07-20 23:03:00+03	28800.00
F4E581	2017-07-03 02:08:00+03	48000.00
F4E58D	2017-07-12 16:35:00+03	199300.00
F4E599	2017-07-26 07:30:00+03	38600.00
F4E5A9	2017-07-18 04:23:00+03	28000.00
F4E5C5	2017-07-16 14:04:00+03	47000.00
F4E5C6	2017-08-01 12:54:00+03	18100.00
F4E5F8	2017-08-03 19:23:00+03	56000.00
F4E665	2017-08-11 22:05:00+03	75600.00
F4E687	2017-07-25 08:02:00+03	24800.00
F4E6AF	2017-08-05 04:11:00+03	265700.00
F4E6BB	2017-08-12 20:12:00+03	25100.00
F4E70D	2017-07-31 11:53:00+03	10600.00
F4E786	2017-07-13 09:01:00+03	389000.00
F4E7A1	2017-08-09 05:10:00+03	59800.00
F4E7CD	2017-07-30 05:34:00+03	66600.00
F4E7DE	2017-07-03 06:47:00+03	96300.00
F4E7E0	2017-07-06 22:04:00+03	36200.00
F4E7F8	2017-07-13 16:04:00+03	47700.00
F4E871	2017-07-24 05:02:00+03	83300.00
F4E986	2017-07-17 21:15:00+03	270700.00
F4E9F1	2017-07-25 19:13:00+03	24700.00
F4EA00	2017-07-21 05:42:00+03	89700.00
F4EA31	2017-08-12 03:05:00+03	17800.00
F4EA44	2017-08-04 13:11:00+03	59800.00
F4EA64	2017-08-14 08:46:00+03	108600.00
F4EA78	2017-08-13 02:32:00+03	41600.00
F4EAAE	2017-07-05 12:59:00+03	131600.00
F4EAFC	2017-08-03 19:15:00+03	79200.00
F4EB0C	2017-08-08 00:59:00+03	65500.00
F4EB12	2017-07-12 21:52:00+03	103900.00
F4EB1A	2017-07-10 04:39:00+03	15000.00
F4EB95	2017-08-01 16:07:00+03	123000.00
F4EBA8	2017-07-05 17:01:00+03	85000.00
F4EC69	2017-07-10 16:33:00+03	64700.00
F4EC88	2017-08-10 22:02:00+03	77200.00
F4ECD0	2017-07-20 05:21:00+03	185500.00
F4ED39	2017-08-06 10:24:00+03	78300.00
F4ED64	2017-08-14 05:32:00+03	38200.00
F4ED91	2017-07-07 01:09:00+03	28800.00
F4ED94	2017-07-06 22:08:00+03	68800.00
F4EE0D	2017-08-11 19:35:00+03	59200.00
F4EE47	2017-07-25 07:56:00+03	61800.00
F4EE5A	2017-07-09 01:27:00+03	135600.00
F4EF1F	2017-07-24 21:20:00+03	148200.00
F4EF37	2017-07-23 08:09:00+03	33200.00
F4EF41	2017-08-14 07:09:00+03	57700.00
F4EF5F	2017-08-09 19:07:00+03	46000.00
F4EFB1	2017-06-30 21:06:00+03	65700.00
F4EFB4	2017-07-23 18:38:00+03	67600.00
F4EFE2	2017-07-20 18:57:00+03	106100.00
F4EFF0	2017-08-05 06:04:00+03	16400.00
F4EFF7	2017-07-19 20:37:00+03	26800.00
F4F0DE	2017-07-05 20:19:00+03	46400.00
F4F16F	2017-07-24 15:25:00+03	12600.00
F4F178	2017-07-15 21:01:00+03	72400.00
F4F1BA	2017-07-21 14:12:00+03	57800.00
F4F26A	2017-07-13 18:22:00+03	70700.00
F4F2AA	2017-07-25 09:09:00+03	19600.00
F4F2B9	2017-07-03 15:52:00+03	38800.00
F4F429	2017-08-11 11:07:00+03	283100.00
F4F469	2017-06-29 23:58:00+03	90200.00
F4F497	2017-07-10 09:48:00+03	38800.00
F4F4D0	2017-08-03 00:50:00+03	42800.00
F4F4D2	2017-08-13 20:46:00+03	230600.00
F4F4D4	2017-07-30 11:08:00+03	83600.00
F4F4EA	2017-08-12 21:50:00+03	28000.00
F4F529	2017-07-21 18:00:00+03	131100.00
F4F52D	2017-07-02 09:58:00+03	135600.00
F4F540	2017-07-25 05:37:00+03	111600.00
F4F54D	2017-08-07 22:31:00+03	56000.00
F4F5DE	2017-06-28 14:59:00+03	42800.00
F4F5E8	2017-07-25 01:41:00+03	24400.00
F4F5EB	2017-07-16 00:05:00+03	393800.00
F4F678	2017-07-31 14:27:00+03	89900.00
F4F6DD	2017-07-11 04:12:00+03	12400.00
F4F7B3	2017-08-10 07:56:00+03	61500.00
F4F7E9	2017-07-26 08:26:00+03	42800.00
F4F816	2017-07-02 02:30:00+03	100600.00
F4F840	2017-07-28 06:00:00+03	64700.00
F4F869	2017-07-14 01:32:00+03	29600.00
F4F8D4	2017-08-14 08:51:00+03	7400.00
F4F915	2017-08-02 13:14:00+03	107500.00
F4F929	2017-07-14 20:32:00+03	103200.00
F4F9BF	2017-07-04 10:17:00+03	40800.00
F4FAF2	2017-07-26 00:52:00+03	56000.00
F4FAFD	2017-07-04 09:54:00+03	14800.00
F4FB5A	2017-07-16 07:38:00+03	12000.00
F4FB7A	2017-07-09 21:43:00+03	15000.00
F4FB9F	2017-07-25 07:35:00+03	44800.00
F4FBB4	2017-06-28 13:12:00+03	139800.00
F4FBC3	2017-08-11 03:12:00+03	31300.00
F4FBC7	2017-08-06 09:02:00+03	152900.00
F4FBDF	2017-07-03 14:11:00+03	61800.00
F4FC02	2017-07-29 03:07:00+03	66400.00
F4FC1E	2017-07-28 15:55:00+03	226000.00
F4FC52	2017-08-03 00:43:00+03	170000.00
F4FC59	2017-07-14 18:55:00+03	70600.00
F4FC74	2017-08-07 22:57:00+03	12200.00
F4FCB8	2017-07-06 03:21:00+03	68800.00
F4FCC8	2017-08-02 11:03:00+03	92000.00
F4FCD2	2017-07-11 21:55:00+03	78100.00
F4FCF5	2017-07-21 00:23:00+03	47700.00
F4FCFD	2017-07-20 23:31:00+03	12600.00
F4FD50	2017-07-09 22:07:00+03	86600.00
F4FD82	2017-08-05 18:03:00+03	92700.00
F4FD84	2017-08-14 10:09:00+03	92800.00
F4FDC5	2017-08-05 13:16:00+03	6700.00
F4FDDF	2017-08-01 23:24:00+03	35200.00
F4FE22	2017-07-04 03:10:00+03	56000.00
F4FE3F	2017-07-12 23:45:00+03	20400.00
F4FE49	2017-08-02 11:20:00+03	86800.00
F4FE92	2017-07-02 15:12:00+03	70800.00
F4FEC2	2017-07-01 09:36:00+03	28000.00
F4FF71	2017-08-03 05:33:00+03	28000.00
F4FF75	2017-07-27 17:52:00+03	170700.00
F4FF93	2017-07-28 19:08:00+03	43500.00
F4FFDA	2017-08-01 19:01:00+03	81700.00
F5002F	2017-07-27 20:56:00+03	44000.00
F5003B	2017-08-12 17:57:00+03	8400.00
F5008A	2017-07-10 01:21:00+03	94200.00
F50093	2017-07-18 00:47:00+03	56100.00
F500D6	2017-07-28 08:32:00+03	131600.00
F500EB	2017-07-17 08:28:00+03	22900.00
F5012A	2017-08-02 05:08:00+03	85700.00
F5018B	2017-07-12 21:32:00+03	16800.00
F501C6	2017-07-14 06:32:00+03	120800.00
F501F5	2017-07-26 17:41:00+03	42800.00
F50208	2017-07-20 22:08:00+03	61800.00
F50212	2017-08-02 15:47:00+03	54000.00
F5024F	2017-07-06 14:23:00+03	153900.00
F502F6	2017-07-18 21:21:00+03	38600.00
F50359	2017-07-31 06:47:00+03	16000.00
F50379	2017-07-26 04:36:00+03	29000.00
F5038F	2017-07-14 12:34:00+03	32800.00
F503FD	2017-07-05 12:36:00+03	64800.00
F504A4	2017-07-11 09:16:00+03	270800.00
F504A7	2017-08-01 14:24:00+03	46300.00
F504C0	2017-08-10 20:45:00+03	265600.00
F5053F	2017-08-06 15:30:00+03	68400.00
F505E4	2017-07-17 08:08:00+03	27200.00
F505FE	2017-08-01 01:46:00+03	11800.00
F5061A	2017-07-07 22:57:00+03	13400.00
F5063A	2017-07-09 09:56:00+03	21400.00
F50669	2017-07-11 08:00:00+03	43200.00
F50686	2017-07-13 21:34:00+03	65900.00
F506B5	2017-08-13 20:29:00+03	85000.00
F506BB	2017-08-11 14:20:00+03	59000.00
F506BC	2017-07-09 14:05:00+03	48800.00
F50701	2017-08-08 04:54:00+03	85000.00
F50722	2017-08-08 01:35:00+03	36200.00
F50746	2017-07-06 20:34:00+03	29600.00
F50749	2017-08-05 21:46:00+03	58400.00
F5075C	2017-07-29 22:53:00+03	30000.00
F5078A	2017-07-02 14:42:00+03	39600.00
F507CD	2017-07-01 22:53:00+03	44800.00
F507D1	2017-07-05 08:44:00+03	38200.00
F50894	2017-07-12 01:25:00+03	21400.00
F508B9	2017-07-17 19:56:00+03	26600.00
F508FC	2017-08-13 05:25:00+03	66100.00
F50A2D	2017-07-11 19:33:00+03	32200.00
F50A3F	2017-07-02 08:28:00+03	177200.00
F50B04	2017-08-07 11:38:00+03	133100.00
F50BD8	2017-07-08 18:38:00+03	141800.00
F50C12	2017-08-03 08:41:00+03	194400.00
F50C37	2017-07-23 06:13:00+03	85400.00
F50C9B	2017-07-18 06:45:00+03	72600.00
F50D16	2017-07-19 19:40:00+03	378400.00
F50D81	2017-07-18 22:00:00+03	72200.00
F50D85	2017-08-10 22:41:00+03	85000.00
F50DDC	2017-07-16 18:52:00+03	93900.00
F50E41	2017-08-02 04:51:00+03	67600.00
F50E88	2017-07-12 05:24:00+03	179500.00
F50EB3	2017-07-06 23:26:00+03	101800.00
F50EE9	2017-07-18 17:49:00+03	18700.00
F50EF6	2017-07-31 13:05:00+03	75600.00
F50F1C	2017-07-21 19:28:00+03	42700.00
F50F46	2017-08-09 09:52:00+03	118400.00
F50F49	2017-07-10 16:53:00+03	119500.00
F50F6B	2017-07-07 06:52:00+03	103200.00
F50F6C	2017-07-31 23:17:00+03	81700.00
F50F9F	2017-08-04 08:02:00+03	27800.00
F50FD2	2017-07-02 14:59:00+03	95200.00
F50FD9	2017-07-01 05:38:00+03	37100.00
F50FEC	2017-08-03 15:49:00+03	28800.00
F51009	2017-07-16 10:36:00+03	43200.00
F510DD	2017-07-04 19:55:00+03	52700.00
F51115	2017-08-04 20:47:00+03	62800.00
F5114E	2017-07-17 17:12:00+03	38200.00
F51151	2017-07-11 12:16:00+03	40600.00
F5118B	2017-07-12 08:27:00+03	122800.00
F511D4	2017-07-24 08:19:00+03	35800.00
F5127A	2017-07-08 06:08:00+03	42700.00
F512B4	2017-07-05 10:13:00+03	26100.00
F512CE	2017-07-23 11:45:00+03	173900.00
F51375	2017-07-26 12:30:00+03	55800.00
F513F5	2017-08-06 18:45:00+03	26000.00
F51433	2017-07-15 18:40:00+03	98400.00
F51442	2017-07-23 17:26:00+03	72200.00
F51457	2017-07-02 20:30:00+03	36200.00
F51474	2017-07-05 08:51:00+03	23900.00
F514DB	2017-07-22 01:41:00+03	31000.00
F514DF	2017-07-23 23:23:00+03	67200.00
F51503	2017-08-06 21:11:00+03	101400.00
F51654	2017-07-15 02:15:00+03	95500.00
F51671	2017-08-06 12:25:00+03	29600.00
F5168D	2017-07-11 16:53:00+03	154500.00
F516AB	2017-08-14 19:45:00+03	46200.00
F516B9	2017-06-29 12:38:00+03	40400.00
F516BB	2017-07-13 09:05:00+03	118100.00
F516CE	2017-07-23 17:01:00+03	55800.00
F517A1	2017-07-04 12:21:00+03	87700.00
F517B9	2017-07-12 10:12:00+03	112000.00
F517D8	2017-07-08 17:28:00+03	106400.00
F517EF	2017-07-25 20:10:00+03	10600.00
F51829	2017-08-10 23:11:00+03	66000.00
F51838	2017-08-02 06:43:00+03	36200.00
F518E3	2017-07-01 05:02:00+03	406000.00
F51937	2017-07-25 11:03:00+03	232200.00
F5193E	2017-07-16 12:18:00+03	92100.00
F519BA	2017-07-13 04:01:00+03	27200.00
F519FF	2017-08-11 13:42:00+03	135600.00
F51AC5	2017-07-27 21:12:00+03	44600.00
F51AE4	2017-07-21 03:19:00+03	59800.00
F51B1F	2017-07-17 04:00:00+03	12200.00
F51B62	2017-07-18 12:05:00+03	81200.00
F51B6E	2017-08-15 17:54:00+03	117500.00
F51B9B	2017-07-19 01:51:00+03	35200.00
F51BB1	2017-08-14 20:34:00+03	177600.00
F51C17	2017-07-14 22:44:00+03	101000.00
F51C23	2017-08-04 17:57:00+03	24000.00
F51CAF	2017-08-04 02:51:00+03	189200.00
F51D2C	2017-07-05 03:33:00+03	71000.00
F51D7C	2017-08-08 15:42:00+03	32700.00
F51D92	2017-07-08 07:07:00+03	271100.00
F51DEE	2017-07-29 20:33:00+03	14000.00
F51E33	2017-08-12 14:05:00+03	46400.00
F51E8F	2017-08-11 04:32:00+03	66600.00
F51EA5	2017-08-15 08:16:00+03	48800.00
F51ECA	2017-07-28 19:02:00+03	123000.00
F51EF7	2017-07-05 20:33:00+03	57500.00
F51F7D	2017-08-04 03:02:00+03	28300.00
F51F90	2017-07-12 14:48:00+03	23200.00
F51FC6	2017-08-07 06:00:00+03	301800.00
F52019	2017-07-10 16:41:00+03	122800.00
F5207E	2017-07-23 20:18:00+03	23400.00
F520C5	2017-07-16 01:33:00+03	28800.00
F520D1	2017-06-26 11:24:00+03	79600.00
F5210B	2017-07-17 14:46:00+03	28000.00
F52114	2017-07-12 06:04:00+03	259800.00
F5219C	2017-07-31 03:34:00+03	135400.00
F521C6	2017-07-06 14:34:00+03	169600.00
F5221C	2017-07-16 23:13:00+03	52400.00
F522BD	2017-07-31 02:04:00+03	66000.00
F5234C	2017-08-09 21:33:00+03	135900.00
F52387	2017-07-28 02:23:00+03	56000.00
F523BB	2017-08-03 15:15:00+03	78300.00
F523C4	2017-07-13 06:21:00+03	48800.00
F523FE	2017-08-10 21:29:00+03	55800.00
F5240D	2017-07-09 18:20:00+03	138600.00
F52417	2017-07-08 21:49:00+03	92900.00
F524D5	2017-07-30 14:57:00+03	406800.00
F52515	2017-08-10 14:34:00+03	23600.00
F525A4	2017-07-04 16:14:00+03	71900.00
F52611	2017-07-29 16:50:00+03	14000.00
F5261C	2017-07-02 19:21:00+03	114400.00
F52638	2017-08-09 23:07:00+03	540000.00
F526F1	2017-08-12 17:47:00+03	6300.00
F52782	2017-07-11 18:18:00+03	137600.00
F52860	2017-08-11 05:53:00+03	103600.00
F528C4	2017-07-15 15:28:00+03	248400.00
F5292D	2017-07-14 02:44:00+03	100200.00
F52966	2017-07-31 07:19:00+03	6700.00
F529A4	2017-08-11 07:04:00+03	240500.00
F529C7	2017-08-04 10:11:00+03	56000.00
F529CA	2017-08-01 01:52:00+03	64200.00
F529EE	2017-07-30 04:36:00+03	92600.00
F52A68	2017-07-15 07:43:00+03	62600.00
F52A7F	2017-08-14 23:13:00+03	22000.00
F52AD2	2017-07-21 06:55:00+03	89100.00
F52B8A	2017-07-04 17:56:00+03	47400.00
F52B9F	2017-07-22 17:29:00+03	13400.00
F52BB2	2017-08-12 21:48:00+03	68400.00
F52BEA	2017-08-06 07:03:00+03	38800.00
F52C21	2017-08-02 19:33:00+03	33200.00
F52C3A	2017-07-02 04:48:00+03	23600.00
F52DB9	2017-07-31 00:03:00+03	39200.00
F52E29	2017-07-31 20:27:00+03	84000.00
F52E43	2017-08-13 09:14:00+03	111600.00
F52E4A	2017-07-15 16:52:00+03	67400.00
F52E8A	2017-08-15 14:22:00+03	68100.00
F52EBA	2017-06-30 02:59:00+03	24300.00
F52F30	2017-07-17 02:17:00+03	52400.00
F52F70	2017-07-31 22:29:00+03	69900.00
F52F79	2017-07-25 16:01:00+03	112000.00
F52F7D	2017-07-18 02:42:00+03	189200.00
F52FCE	2017-07-28 10:14:00+03	73300.00
F52FD2	2017-08-04 00:31:00+03	171900.00
F5305E	2017-07-14 05:17:00+03	205600.00
F5309B	2017-08-03 20:12:00+03	118500.00
F530C4	2017-08-06 14:18:00+03	25600.00
F53114	2017-07-21 17:35:00+03	87000.00
F5312F	2017-07-29 21:38:00+03	49400.00
F5315D	2017-07-26 22:26:00+03	85600.00
F5318A	2017-08-08 03:55:00+03	59800.00
F5327B	2017-07-26 10:33:00+03	56600.00
F5327E	2017-07-11 13:49:00+03	22000.00
F53288	2017-06-26 18:40:00+03	53200.00
F53291	2017-08-06 18:57:00+03	13200.00
F532C2	2017-08-08 20:36:00+03	56000.00
F533A3	2017-08-07 05:35:00+03	38600.00
F533D0	2017-08-14 14:37:00+03	76100.00
F5342E	2017-07-16 16:21:00+03	87000.00
F5343B	2017-07-04 05:25:00+03	23200.00
F53442	2017-08-08 16:06:00+03	531400.00
F534E3	2017-07-03 13:45:00+03	36200.00
F534F8	2017-08-08 18:05:00+03	145100.00
F534FC	2017-08-11 23:10:00+03	146300.00
F535BA	2017-08-09 14:59:00+03	56100.00
F536A8	2017-07-04 13:15:00+03	7400.00
F536A9	2017-07-26 04:02:00+03	402400.00
F536B2	2017-07-21 19:57:00+03	89600.00
F536FA	2017-08-08 01:36:00+03	42800.00
F53706	2017-08-02 01:44:00+03	36200.00
F53738	2017-07-29 03:25:00+03	94300.00
F53746	2017-08-02 18:45:00+03	63400.00
F537F9	2017-07-11 04:41:00+03	62600.00
F5381C	2017-07-24 02:50:00+03	81600.00
F53889	2017-07-22 23:31:00+03	52000.00
F538D5	2017-08-14 14:31:00+03	115400.00
F538E1	2017-08-09 07:49:00+03	116000.00
F538E4	2017-07-08 09:58:00+03	28000.00
F5392F	2017-08-14 03:10:00+03	81200.00
F53961	2017-08-07 06:57:00+03	10800.00
F53A04	2017-07-14 06:14:00+03	40400.00
F53A0A	2017-08-08 00:00:00+03	29600.00
F53A1C	2017-07-07 08:18:00+03	92600.00
F53A54	2017-07-25 11:32:00+03	55800.00
F53A9E	2017-08-11 03:18:00+03	26800.00
F53AF4	2017-07-01 15:50:00+03	271400.00
F53B06	2017-07-07 05:23:00+03	31400.00
F53B12	2017-07-08 17:08:00+03	14400.00
F53B18	2017-07-10 11:46:00+03	69400.00
F53B2F	2017-07-30 06:47:00+03	148100.00
F53B78	2017-07-12 04:13:00+03	73600.00
F53B84	2017-07-20 03:21:00+03	46000.00
F53BFB	2017-07-04 23:35:00+03	52000.00
F53C7F	2017-08-04 10:12:00+03	73600.00
F53C88	2017-07-16 07:25:00+03	56000.00
F53CD9	2017-07-18 08:16:00+03	46200.00
F53D1F	2017-07-29 03:15:00+03	12600.00
F53D7D	2017-08-02 18:43:00+03	177200.00
F53D96	2017-08-09 15:37:00+03	135600.00
F53DCF	2017-08-04 16:29:00+03	8200.00
F53DD1	2017-08-15 11:32:00+03	23200.00
F53E18	2017-08-10 13:18:00+03	43700.00
F53E85	2017-07-26 11:45:00+03	83600.00
F53EB4	2017-07-17 06:52:00+03	118900.00
F53F1D	2017-07-28 09:12:00+03	53500.00
F53FE8	2017-07-05 22:05:00+03	14000.00
F54017	2017-07-10 07:03:00+03	45200.00
F54021	2017-07-24 16:08:00+03	59800.00
F540E5	2017-07-25 19:53:00+03	12400.00
F54125	2017-07-08 13:35:00+03	113300.00
F5419D	2017-08-12 20:53:00+03	69900.00
F5419F	2017-07-29 23:09:00+03	435400.00
F541AC	2017-08-11 08:58:00+03	19600.00
F54207	2017-07-30 23:44:00+03	23900.00
F54263	2017-07-10 12:03:00+03	58600.00
F542DD	2017-07-21 20:34:00+03	69700.00
F5439F	2017-07-14 00:06:00+03	84100.00
F543A3	2017-07-15 19:23:00+03	185700.00
F54415	2017-07-20 09:17:00+03	14700.00
F5446D	2017-07-01 12:44:00+03	12000.00
F54487	2017-07-19 16:57:00+03	29600.00
F544A7	2017-07-31 02:50:00+03	64800.00
F544FB	2017-07-12 18:15:00+03	29600.00
F54530	2017-07-02 03:17:00+03	43200.00
F545C4	2017-08-11 12:03:00+03	21400.00
F545C7	2017-07-30 07:19:00+03	272300.00
F54619	2017-07-23 21:15:00+03	94900.00
F54625	2017-07-10 04:09:00+03	76400.00
F5465F	2017-07-24 15:21:00+03	18000.00
F547D5	2017-08-05 19:00:00+03	193600.00
F548B0	2017-07-27 12:13:00+03	13400.00
F54935	2017-07-20 18:33:00+03	66800.00
F54936	2017-07-22 20:11:00+03	26000.00
F5493D	2017-08-06 03:52:00+03	20400.00
F54940	2017-07-22 21:00:00+03	185800.00
F5494C	2017-08-06 07:01:00+03	189800.00
F5496F	2017-07-05 23:28:00+03	54500.00
F549C4	2017-08-07 17:57:00+03	36200.00
F54A29	2017-07-30 21:25:00+03	131100.00
F54A36	2017-07-30 01:24:00+03	290400.00
F54A4B	2017-08-14 21:44:00+03	89600.00
F54AD5	2017-07-24 16:51:00+03	47000.00
F54ADE	2017-08-14 00:07:00+03	113600.00
F54B50	2017-06-30 19:16:00+03	20200.00
F54BC5	2017-07-25 05:45:00+03	51800.00
F54BC7	2017-08-07 11:00:00+03	7400.00
F54C3A	2017-07-01 03:19:00+03	36200.00
F54C8F	2017-08-04 06:18:00+03	100600.00
F54CB1	2017-07-17 05:29:00+03	75000.00
F54CC1	2017-08-10 16:01:00+03	131100.00
F54D37	2017-08-13 22:03:00+03	35700.00
F54DAA	2017-07-02 03:45:00+03	116400.00
F54DEF	2017-07-26 14:10:00+03	280000.00
F54E66	2017-07-04 05:15:00+03	115100.00
F54EAB	2017-07-28 01:29:00+03	40900.00
F54EB1	2017-08-02 13:57:00+03	23400.00
F54EB7	2017-07-13 11:00:00+03	24000.00
F54F14	2017-08-15 16:00:00+03	20400.00
F54F2D	2017-07-24 02:41:00+03	55800.00
F54F38	2017-07-11 03:45:00+03	39600.00
F54F5E	2017-07-18 15:40:00+03	20200.00
F54F6D	2017-07-03 15:09:00+03	124200.00
F54FA6	2017-08-02 05:21:00+03	62700.00
F54FD4	2017-08-15 05:46:00+03	47800.00
F5500B	2017-07-22 20:58:00+03	43200.00
F5501A	2017-08-02 17:33:00+03	62600.00
F5501C	2017-08-09 07:18:00+03	40800.00
F55041	2017-08-05 07:23:00+03	114400.00
F550CD	2017-07-11 19:05:00+03	79900.00
F550E1	2017-08-15 07:14:00+03	6800.00
F550FA	2017-07-21 08:24:00+03	10100.00
F55116	2017-07-18 08:18:00+03	223200.00
F55195	2017-07-07 20:56:00+03	11000.00
F55199	2017-07-25 13:24:00+03	23200.00
F551C4	2017-07-19 15:59:00+03	32700.00
F551E1	2017-08-14 22:47:00+03	131600.00
F55205	2017-07-24 14:58:00+03	28000.00
F55212	2017-07-23 14:25:00+03	6800.00
F552B9	2017-08-06 19:31:00+03	40600.00
F552BB	2017-07-09 10:09:00+03	28800.00
F552D8	2017-07-19 19:50:00+03	116700.00
F55368	2017-08-06 01:24:00+03	47000.00
F5538B	2017-07-17 21:40:00+03	103900.00
F55399	2017-07-21 06:20:00+03	44800.00
F553E7	2017-07-18 05:25:00+03	24800.00
F55457	2017-07-16 12:46:00+03	21400.00
F55501	2017-07-13 21:31:00+03	28000.00
F55541	2017-07-25 13:24:00+03	70600.00
F55587	2017-08-13 06:57:00+03	42700.00
F555F2	2017-07-24 09:57:00+03	51900.00
F5568E	2017-08-10 06:10:00+03	73300.00
F556B2	2017-07-16 04:25:00+03	226200.00
F5574C	2017-07-28 04:18:00+03	130500.00
F55751	2017-07-09 12:21:00+03	45100.00
F55774	2017-08-07 13:15:00+03	68900.00
F55783	2017-08-08 22:38:00+03	23600.00
F5579E	2017-07-24 15:39:00+03	28800.00
F557A0	2017-07-06 19:05:00+03	36600.00
F557AE	2017-07-21 16:09:00+03	28800.00
F557D4	2017-08-03 00:57:00+03	278100.00
F557E5	2017-07-21 07:35:00+03	11600.00
F5584F	2017-07-14 03:25:00+03	257600.00
F5586F	2017-07-05 22:50:00+03	26000.00
F55879	2017-08-01 23:51:00+03	36200.00
F558E6	2017-08-12 20:48:00+03	55800.00
F558F6	2017-07-22 11:09:00+03	62600.00
F55952	2017-08-09 10:42:00+03	56600.00
F55972	2017-07-28 03:11:00+03	40000.00
F559A0	2017-07-06 12:40:00+03	62100.00
F559A7	2017-07-25 21:24:00+03	31200.00
F55A0E	2017-07-14 02:08:00+03	28000.00
F55AF2	2017-08-01 09:39:00+03	179300.00
F55B24	2017-08-13 15:57:00+03	36900.00
F55BDA	2017-07-20 22:10:00+03	57600.00
F55C0B	2017-07-15 10:03:00+03	41800.00
F55C68	2017-07-07 03:57:00+03	122400.00
F55C6D	2017-07-04 06:02:00+03	272300.00
F55D8A	2017-07-30 14:17:00+03	56000.00
F55DE3	2017-07-12 11:27:00+03	97600.00
F55E0A	2017-07-25 21:52:00+03	71200.00
F55E0B	2017-07-15 13:13:00+03	23600.00
F55E79	2017-08-08 11:35:00+03	247300.00
F55E83	2017-07-16 13:46:00+03	133100.00
F55E93	2017-07-20 15:54:00+03	48800.00
F55E97	2017-07-03 22:24:00+03	271200.00
F55EE4	2017-07-26 08:20:00+03	23400.00
F55EFC	2017-07-22 07:03:00+03	14000.00
F55F8B	2017-07-28 13:59:00+03	12000.00
F55FE3	2017-08-12 21:57:00+03	12000.00
F56054	2017-07-29 11:27:00+03	99300.00
F560F2	2017-07-20 12:10:00+03	112000.00
F56170	2017-07-22 06:35:00+03	25100.00
F5619E	2017-08-05 03:39:00+03	25200.00
F56227	2017-08-14 10:33:00+03	69700.00
F5624D	2017-08-09 19:40:00+03	26300.00
F56257	2017-08-15 08:29:00+03	20800.00
F5627B	2017-07-29 15:36:00+03	56000.00
F562A8	2017-07-04 05:35:00+03	80500.00
F562B2	2017-07-02 12:49:00+03	99200.00
F562C5	2017-07-14 06:25:00+03	219200.00
F56308	2017-07-13 05:49:00+03	178800.00
F56309	2017-08-05 22:29:00+03	169800.00
F5632D	2017-08-14 02:32:00+03	303500.00
F56339	2017-08-01 06:00:00+03	38400.00
F5633E	2017-08-15 09:09:00+03	129200.00
F5634F	2017-08-09 12:37:00+03	136200.00
F56438	2017-07-11 22:04:00+03	51600.00
F564A3	2017-07-16 09:21:00+03	154300.00
F564BB	2017-07-14 07:25:00+03	33000.00
F564F9	2017-08-08 01:38:00+03	68100.00
F56524	2017-07-05 03:01:00+03	58900.00
F5656D	2017-07-10 18:49:00+03	56000.00
F5658C	2017-07-12 16:55:00+03	85000.00
F5658F	2017-07-24 03:34:00+03	54600.00
F565DC	2017-08-06 20:47:00+03	25400.00
F5662E	2017-07-04 19:14:00+03	406700.00
F56655	2017-07-06 13:09:00+03	60200.00
F5665B	2017-07-07 10:25:00+03	42400.00
F56698	2017-07-10 19:52:00+03	90400.00
F566CB	2017-07-07 02:37:00+03	112000.00
F56767	2017-07-20 04:11:00+03	33100.00
F5676A	2017-07-28 05:14:00+03	133100.00
F567EA	2017-07-31 10:48:00+03	97500.00
F5685A	2017-07-20 17:37:00+03	54400.00
F56891	2017-07-20 01:09:00+03	49200.00
F568BD	2017-08-13 21:46:00+03	81700.00
F56918	2017-07-08 03:23:00+03	54800.00
F5695B	2017-07-13 21:33:00+03	72400.00
F5696B	2017-08-15 00:41:00+03	7300.00
F5696F	2017-08-01 06:37:00+03	48800.00
F569F2	2017-07-22 16:38:00+03	40100.00
F56AF2	2017-07-27 09:57:00+03	26800.00
F56AF7	2017-08-12 16:07:00+03	48800.00
F56B2E	2017-07-28 15:25:00+03	191200.00
F56B9A	2017-07-07 05:22:00+03	26200.00
F56D0C	2017-07-19 23:23:00+03	133200.00
F56D3C	2017-08-13 03:55:00+03	28000.00
F56D89	2017-08-03 05:30:00+03	32800.00
F56DC5	2017-07-21 03:39:00+03	85000.00
F56DEC	2017-08-07 19:49:00+03	105400.00
F56E3C	2017-07-16 18:57:00+03	28800.00
F56E40	2017-07-24 04:12:00+03	40800.00
F56F01	2017-07-02 22:22:00+03	111600.00
F56F11	2017-07-23 15:39:00+03	22000.00
F56F1A	2017-07-18 15:30:00+03	171400.00
F56F1E	2017-07-21 10:52:00+03	23400.00
F56F3E	2017-07-03 19:36:00+03	68100.00
F5718A	2017-07-17 02:37:00+03	6700.00
F571D6	2017-07-25 00:12:00+03	115000.00
F57211	2017-07-11 01:58:00+03	28000.00
F57233	2017-07-17 20:00:00+03	50400.00
F57246	2017-07-29 02:38:00+03	68600.00
F57266	2017-07-10 03:05:00+03	234700.00
F57283	2017-07-16 07:08:00+03	38400.00
F57296	2017-08-01 12:08:00+03	11800.00
F572BA	2017-07-25 01:21:00+03	81200.00
F5733E	2017-08-03 08:36:00+03	136200.00
F5737A	2017-07-17 12:31:00+03	218000.00
F573DF	2017-08-07 11:57:00+03	23200.00
F573FD	2017-07-11 12:36:00+03	26200.00
F57408	2017-07-27 02:32:00+03	23600.00
F57431	2017-08-02 03:29:00+03	78200.00
F5746A	2017-07-15 05:47:00+03	28800.00
F57499	2017-07-12 22:41:00+03	30200.00
F574B7	2017-08-06 04:27:00+03	37600.00
F574D8	2017-08-15 04:39:00+03	92100.00
F574FC	2017-06-30 03:09:00+03	88800.00
F5754B	2017-07-23 13:20:00+03	32800.00
F57587	2017-08-13 11:06:00+03	56000.00
F575E5	2017-08-04 04:23:00+03	59000.00
F57600	2017-08-08 17:08:00+03	79800.00
F5761F	2017-08-09 09:32:00+03	68400.00
F5769A	2017-08-04 02:14:00+03	58700.00
F576AC	2017-08-05 00:31:00+03	95200.00
F576C0	2017-08-11 01:30:00+03	38600.00
F576C2	2017-07-20 16:11:00+03	27900.00
F5770B	2017-08-15 13:08:00+03	39000.00
F57715	2017-07-05 07:46:00+03	58600.00
F577B9	2017-08-03 03:54:00+03	141600.00
F577FB	2017-07-19 19:07:00+03	28800.00
F5785A	2017-08-04 10:12:00+03	340200.00
F57882	2017-08-10 08:11:00+03	27200.00
F578E6	2017-07-05 22:37:00+03	38800.00
F57916	2017-06-28 17:58:00+03	28000.00
F579BC	2017-07-06 02:06:00+03	28000.00
F579DF	2017-07-26 18:14:00+03	66600.00
F57A28	2017-08-08 05:48:00+03	28000.00
F57A64	2017-07-24 18:21:00+03	145300.00
F57AAA	2017-07-21 20:35:00+03	47200.00
F57AC1	2017-06-29 15:40:00+03	23200.00
F57AE4	2017-07-25 00:29:00+03	246000.00
F57B1A	2017-07-20 14:56:00+03	98400.00
F57B65	2017-07-23 11:50:00+03	104000.00
F57BA1	2017-07-22 06:52:00+03	40000.00
F57BBB	2017-07-31 15:16:00+03	114400.00
F57BF2	2017-07-05 12:37:00+03	32800.00
F57C61	2017-07-19 05:00:00+03	49100.00
F57C79	2017-07-04 09:30:00+03	28800.00
F57CF4	2017-07-21 19:03:00+03	58200.00
F57D3A	2017-07-25 14:09:00+03	57600.00
F57D46	2017-07-12 21:25:00+03	112000.00
F57D5C	2017-08-12 09:05:00+03	207300.00
F57D8D	2017-08-03 10:43:00+03	67600.00
F57D9C	2017-08-07 02:25:00+03	163900.00
F57DBF	2017-07-15 06:51:00+03	56000.00
F57DD7	2017-07-15 21:41:00+03	25100.00
F57E0E	2017-07-28 13:34:00+03	51600.00
F57E18	2017-08-04 21:12:00+03	301100.00
F57E3E	2017-07-23 06:29:00+03	6000.00
F57E52	2017-07-08 17:04:00+03	532800.00
F57EB3	2017-08-11 17:03:00+03	105800.00
F57EFA	2017-07-23 16:25:00+03	57500.00
F57F0B	2017-08-10 09:24:00+03	28000.00
F57F27	2017-07-08 10:03:00+03	79500.00
F57F29	2017-07-03 15:32:00+03	193000.00
F57F36	2017-07-16 11:50:00+03	196100.00
F57F5E	2017-08-09 02:05:00+03	64400.00
F57F7F	2017-07-31 21:12:00+03	54800.00
F57FA3	2017-07-30 14:41:00+03	52000.00
F57FBD	2017-08-02 20:15:00+03	24200.00
F57FC8	2017-07-17 11:35:00+03	72800.00
F57FED	2017-07-04 12:57:00+03	43500.00
F58021	2017-07-21 08:02:00+03	57500.00
F58148	2017-07-09 02:26:00+03	6800.00
F581A8	2017-07-07 05:29:00+03	33100.00
F58205	2017-08-01 04:37:00+03	62600.00
F58229	2017-07-16 22:45:00+03	76600.00
F5825B	2017-07-20 23:26:00+03	56000.00
F5825E	2017-07-11 17:45:00+03	46900.00
F58275	2017-07-05 11:00:00+03	32800.00
F58290	2017-07-09 13:06:00+03	55800.00
F582C5	2017-07-15 18:07:00+03	166100.00
F58301	2017-07-04 23:35:00+03	51200.00
F58358	2017-07-15 03:02:00+03	36200.00
F583B4	2017-07-20 15:46:00+03	43500.00
F583CB	2017-08-13 10:24:00+03	93900.00
F583D8	2017-08-01 16:06:00+03	22000.00
F5841A	2017-08-03 23:44:00+03	145100.00
F58421	2017-08-11 18:59:00+03	47100.00
F58472	2017-08-08 07:15:00+03	273600.00
F58478	2017-07-04 00:10:00+03	56000.00
F584A6	2017-08-08 08:46:00+03	66000.00
F5850F	2017-07-07 07:40:00+03	6800.00
F5851E	2017-07-22 04:30:00+03	113300.00
F5854B	2017-07-25 17:42:00+03	141100.00
F58581	2017-08-14 07:24:00+03	76800.00
F585B4	2017-07-27 16:42:00+03	185800.00
F585B5	2017-07-26 14:25:00+03	61400.00
F585D0	2017-08-03 16:31:00+03	42400.00
F585E0	2017-07-16 06:08:00+03	67200.00
F5866E	2017-08-08 00:16:00+03	81600.00
F586BF	2017-07-21 21:40:00+03	58800.00
F5870A	2017-08-14 03:28:00+03	18400.00
F58724	2017-07-05 15:27:00+03	147700.00
F5873F	2017-07-08 04:05:00+03	12000.00
F587E8	2017-07-08 13:39:00+03	77900.00
F58886	2017-07-30 23:25:00+03	15000.00
F588AF	2017-07-27 17:37:00+03	186500.00
F58915	2017-07-08 02:09:00+03	43900.00
F58920	2017-07-01 20:45:00+03	48800.00
F58943	2017-08-05 20:36:00+03	57400.00
F58955	2017-07-02 17:10:00+03	65900.00
F58972	2017-08-04 16:02:00+03	47100.00
F589C4	2017-07-31 02:03:00+03	50000.00
F589CF	2017-07-05 13:16:00+03	62600.00
F589E6	2017-07-22 00:59:00+03	75300.00
F58A5F	2017-07-25 23:02:00+03	56000.00
F58AD8	2017-07-20 21:40:00+03	23200.00
F58B3A	2017-06-30 12:47:00+03	303500.00
F58B6A	2017-08-07 18:40:00+03	40800.00
F58BF4	2017-08-12 23:08:00+03	16400.00
F58C0C	2017-07-27 06:00:00+03	24400.00
F58C2B	2017-08-08 05:40:00+03	148300.00
F58C2E	2017-07-05 13:58:00+03	111600.00
F58C6F	2017-07-28 18:32:00+03	137100.00
F58C9A	2017-07-05 05:55:00+03	27300.00
F58CFC	2017-08-12 13:56:00+03	26800.00
F58D2A	2017-07-27 19:18:00+03	14000.00
F58D4D	2017-07-28 18:57:00+03	96300.00
F58D70	2017-07-14 10:57:00+03	100600.00
F58DE4	2017-08-14 11:20:00+03	56000.00
F58E1B	2017-07-18 04:40:00+03	116400.00
F58E91	2017-07-07 02:12:00+03	33100.00
F58ED8	2017-07-13 16:08:00+03	133300.00
F58F01	2017-08-13 20:01:00+03	135600.00
F58F13	2017-07-29 18:42:00+03	34000.00
F58F23	2017-08-04 09:04:00+03	37200.00
F58F94	2017-08-08 22:21:00+03	9200.00
F59004	2017-07-21 06:40:00+03	380700.00
F59084	2017-08-09 01:06:00+03	26000.00
F5908D	2017-07-31 05:33:00+03	51600.00
F590AA	2017-07-19 18:10:00+03	36000.00
F590C7	2017-08-13 04:33:00+03	92800.00
F590F3	2017-08-04 23:29:00+03	173500.00
F5916C	2017-07-01 00:29:00+03	28800.00
F5924B	2017-07-17 21:41:00+03	51900.00
F59250	2017-08-04 04:46:00+03	13600.00
F59258	2017-07-21 06:32:00+03	89700.00
F59260	2017-08-04 11:10:00+03	26200.00
F5927F	2017-07-09 23:01:00+03	8000.00
F592C4	2017-08-03 15:54:00+03	192400.00
F5936F	2017-08-07 16:11:00+03	47600.00
F59371	2017-07-13 12:41:00+03	25200.00
F593CD	2017-07-09 16:39:00+03	25000.00
F5944C	2017-07-06 05:15:00+03	40800.00
F5947F	2017-08-03 00:11:00+03	113800.00
F594B7	2017-07-03 18:42:00+03	176800.00
F594F8	2017-07-20 02:06:00+03	153300.00
F594FB	2017-08-05 03:05:00+03	35600.00
F59513	2017-08-06 12:24:00+03	52800.00
F5959F	2017-08-09 19:45:00+03	113800.00
F595A9	2017-07-28 11:24:00+03	114700.00
F595C2	2017-06-29 11:01:00+03	82900.00
F595E7	2017-07-25 08:12:00+03	21800.00
F5966A	2017-08-08 19:32:00+03	54100.00
F59673	2017-07-04 14:03:00+03	105600.00
F5967C	2017-08-11 05:53:00+03	290800.00
F596BC	2017-07-28 15:11:00+03	46500.00
F596E6	2017-08-05 20:12:00+03	154500.00
F59781	2017-08-04 07:09:00+03	203800.00
F5982D	2017-08-03 18:53:00+03	37200.00
F59835	2017-07-19 20:45:00+03	16400.00
F59842	2017-07-14 05:15:00+03	46300.00
F59843	2017-07-26 21:54:00+03	45400.00
F59859	2017-07-17 11:59:00+03	28800.00
F59903	2017-07-04 10:56:00+03	135400.00
F59905	2017-08-09 12:37:00+03	11300.00
F59961	2017-08-13 20:45:00+03	27800.00
F59968	2017-07-23 21:20:00+03	36200.00
F59970	2017-08-06 01:41:00+03	67600.00
F59990	2017-07-06 18:07:00+03	58000.00
F59A0E	2017-07-11 11:53:00+03	42400.00
F59A17	2017-08-09 16:56:00+03	76000.00
F59A21	2017-07-08 23:10:00+03	25800.00
F59A3B	2017-08-02 05:56:00+03	134000.00
F59A4F	2017-08-01 20:35:00+03	235700.00
F59A5C	2017-07-16 12:06:00+03	33300.00
F59A8C	2017-08-03 00:19:00+03	266400.00
F59AB2	2017-07-20 00:22:00+03	83200.00
F59B1A	2017-07-30 05:11:00+03	75300.00
F59C0D	2017-07-30 08:12:00+03	46400.00
F59C7F	2017-07-04 19:57:00+03	26000.00
F59C82	2017-08-13 19:21:00+03	92100.00
F59C93	2017-08-13 13:47:00+03	105200.00
F59CB4	2017-08-04 20:18:00+03	8200.00
F59CCC	2017-07-22 20:07:00+03	75300.00
F59CD6	2017-08-03 13:35:00+03	28600.00
F59CD9	2017-08-11 00:24:00+03	94900.00
F59CE3	2017-08-02 11:39:00+03	23400.00
F59D66	2017-07-03 06:40:00+03	259000.00
F59D7C	2017-07-07 18:48:00+03	89600.00
F59DB5	2017-07-10 05:30:00+03	28300.00
F59DB7	2017-08-06 15:46:00+03	23600.00
F59DE6	2017-07-02 06:40:00+03	115600.00
F59E0C	2017-07-12 23:42:00+03	73600.00
F59E20	2017-07-02 22:21:00+03	266400.00
F59E79	2017-07-23 19:13:00+03	56000.00
F59E87	2017-07-09 07:41:00+03	265600.00
F59EB0	2017-08-02 20:31:00+03	75300.00
F59EF7	2017-07-06 13:13:00+03	6000.00
F59F19	2017-07-10 17:14:00+03	89700.00
F59F69	2017-08-02 07:34:00+03	48800.00
F59F70	2017-07-22 18:24:00+03	55800.00
F59F7C	2017-07-22 04:47:00+03	111600.00
F59F8D	2017-07-04 20:13:00+03	136800.00
F5A00B	2017-07-19 06:49:00+03	69400.00
F5A048	2017-07-31 22:06:00+03	69000.00
F5A04F	2017-08-03 00:34:00+03	21200.00
F5A0E4	2017-07-30 05:32:00+03	27800.00
F5A0E6	2017-07-08 17:30:00+03	27200.00
F5A10D	2017-07-17 16:07:00+03	24800.00
F5A1B8	2017-07-21 18:03:00+03	46300.00
F5A1F5	2017-07-08 20:45:00+03	100200.00
F5A1F9	2017-08-14 03:03:00+03	60400.00
F5A23D	2017-07-12 10:42:00+03	72700.00
F5A26E	2017-07-14 20:16:00+03	273600.00
F5A311	2017-07-30 05:51:00+03	99200.00
F5A321	2017-08-04 23:36:00+03	57100.00
F5A333	2017-08-05 21:40:00+03	199700.00
F5A335	2017-07-05 19:25:00+03	178300.00
F5A347	2017-07-03 01:20:00+03	34400.00
F5A34E	2017-08-14 02:23:00+03	42700.00
F5A36C	2017-07-20 00:58:00+03	31600.00
F5A3F3	2017-07-17 09:59:00+03	40000.00
F5A449	2017-07-27 18:15:00+03	6700.00
F5A467	2017-06-29 13:13:00+03	196800.00
F5A480	2017-08-02 10:10:00+03	75200.00
F5A492	2017-08-07 14:12:00+03	28800.00
F5A499	2017-07-27 04:18:00+03	25400.00
F5A4B6	2017-07-10 08:10:00+03	180000.00
F5A524	2017-08-06 23:09:00+03	57700.00
F5A52C	2017-07-14 03:34:00+03	118700.00
F5A55C	2017-07-08 10:34:00+03	47600.00
F5A581	2017-07-16 21:17:00+03	29400.00
F5A5AA	2017-08-05 04:31:00+03	46400.00
F5A5B5	2017-07-27 18:00:00+03	89600.00
F5A650	2017-08-15 06:36:00+03	43000.00
F5A6D6	2017-07-30 09:54:00+03	185500.00
F5A6D7	2017-07-12 18:28:00+03	80300.00
F5A75C	2017-07-23 16:33:00+03	56600.00
F5A75F	2017-07-18 02:57:00+03	75100.00
F5A76E	2017-08-05 01:57:00+03	226200.00
F5A77C	2017-07-25 10:41:00+03	16000.00
F5A784	2017-07-03 15:03:00+03	86400.00
F5A794	2017-08-11 17:45:00+03	46400.00
F5A7AE	2017-07-06 00:04:00+03	84000.00
F5A7C5	2017-08-10 16:17:00+03	69600.00
F5A7C7	2017-08-05 12:46:00+03	30200.00
F5A80F	2017-07-24 09:12:00+03	96800.00
F5A83D	2017-07-10 02:38:00+03	21400.00
F5A847	2017-07-15 05:08:00+03	61200.00
F5A979	2017-08-05 07:10:00+03	34800.00
F5A9DA	2017-08-12 21:05:00+03	81700.00
F5A9E4	2017-07-26 05:51:00+03	66000.00
F5A9EB	2017-07-20 15:49:00+03	260300.00
F5AA48	2017-08-04 09:17:00+03	55800.00
F5AA4D	2017-08-13 12:44:00+03	54100.00
F5AA7A	2017-07-25 16:35:00+03	32700.00
F5AA81	2017-08-06 23:58:00+03	56000.00
F5AA85	2017-07-16 13:53:00+03	70500.00
F5AA98	2017-07-02 01:58:00+03	12400.00
F5AADB	2017-08-07 03:05:00+03	265800.00
F5AAF5	2017-07-30 04:16:00+03	40800.00
F5AB11	2017-07-19 06:21:00+03	88100.00
F5AB80	2017-08-10 17:54:00+03	28000.00
F5AC73	2017-08-10 02:09:00+03	164400.00
F5ACAF	2017-07-29 17:46:00+03	56900.00
F5ACF1	2017-08-02 03:55:00+03	23900.00
F5AD32	2017-07-26 19:32:00+03	58900.00
F5AE18	2017-08-12 05:47:00+03	75600.00
F5AEA5	2017-08-01 05:15:00+03	12400.00
F5AEE9	2017-07-27 11:09:00+03	47200.00
F5AF33	2017-08-04 10:23:00+03	44000.00
F5AF51	2017-07-04 17:11:00+03	28000.00
F5AF69	2017-07-08 16:25:00+03	123000.00
F5AF7D	2017-08-05 02:54:00+03	86300.00
F5AFD3	2017-08-10 04:13:00+03	27600.00
F5B01C	2017-07-12 03:41:00+03	71400.00
F5B091	2017-08-02 05:17:00+03	28300.00
F5B0B5	2017-07-24 19:07:00+03	36000.00
F5B0BF	2017-07-15 15:33:00+03	56000.00
F5B0E8	2017-07-14 17:16:00+03	136600.00
F5B182	2017-07-19 08:53:00+03	40000.00
F5B220	2017-08-03 20:40:00+03	136800.00
F5B270	2017-06-30 15:56:00+03	43100.00
F5B272	2017-07-10 13:12:00+03	105100.00
F5B2A1	2017-07-02 19:58:00+03	23500.00
F5B2B8	2017-07-27 23:34:00+03	316800.00
F5B2CF	2017-08-15 17:45:00+03	73500.00
F5B34F	2017-08-04 20:44:00+03	664200.00
F5B368	2017-07-12 11:52:00+03	34000.00
F5B38A	2017-07-20 06:29:00+03	105000.00
F5B38F	2017-08-12 11:16:00+03	105000.00
F5B40A	2017-08-10 17:34:00+03	115900.00
F5B44E	2017-07-10 22:37:00+03	113000.00
F5B456	2017-07-27 13:25:00+03	31600.00
F5B45C	2017-07-21 18:54:00+03	54500.00
F5B4BA	2017-08-03 20:06:00+03	95600.00
F5B4E1	2017-08-13 17:33:00+03	47400.00
F5B4FF	2017-08-04 18:47:00+03	13600.00
F5B576	2017-07-15 02:28:00+03	28800.00
F5B586	2017-08-15 16:48:00+03	13400.00
F5B587	2017-08-02 07:27:00+03	39300.00
F5B5A6	2017-07-13 09:54:00+03	66000.00
F5B6C0	2017-07-22 17:34:00+03	136000.00
F5B6F5	2017-07-13 17:55:00+03	26800.00
F5B6F6	2017-08-11 14:26:00+03	249200.00
F5B70A	2017-07-19 23:32:00+03	23600.00
F5B730	2017-08-15 13:56:00+03	75300.00
F5B768	2017-08-07 11:03:00+03	39300.00
F5B7B2	2017-08-15 13:39:00+03	58800.00
F5B7B4	2017-08-15 05:01:00+03	54500.00
F5B7DB	2017-07-15 21:35:00+03	35300.00
F5B803	2017-08-04 19:45:00+03	124200.00
F5B842	2017-07-22 02:55:00+03	135100.00
F5B875	2017-07-20 18:05:00+03	16800.00
F5B882	2017-08-09 17:02:00+03	32200.00
F5B888	2017-08-10 19:48:00+03	55800.00
F5B90F	2017-07-19 07:27:00+03	146000.00
F5B972	2017-07-18 01:26:00+03	93000.00
F5B98D	2017-07-14 01:02:00+03	79900.00
F5B9E4	2017-07-18 05:30:00+03	124200.00
F5B9EF	2017-07-04 18:44:00+03	56600.00
F5B9FB	2017-07-05 04:24:00+03	13600.00
F5BA8C	2017-07-27 04:34:00+03	50000.00
F5BB19	2017-08-09 14:47:00+03	81700.00
F5BB29	2017-07-11 05:12:00+03	51200.00
F5BC19	2017-07-04 08:20:00+03	90400.00
F5BCC7	2017-07-08 12:23:00+03	138000.00
F5BD25	2017-07-11 23:13:00+03	10600.00
F5BE7F	2017-07-03 07:32:00+03	12600.00
F5BECF	2017-08-11 10:28:00+03	137700.00
F5C002	2017-08-03 15:32:00+03	68800.00
F5C003	2017-08-05 06:36:00+03	53800.00
F5C054	2017-07-21 15:35:00+03	58400.00
F5C07E	2017-07-05 17:57:00+03	67600.00
F5C087	2017-07-07 20:26:00+03	239100.00
F5C105	2017-07-08 16:58:00+03	270700.00
F5C108	2017-07-14 23:49:00+03	28800.00
F5C183	2017-08-09 04:34:00+03	23100.00
F5C18B	2017-07-20 14:35:00+03	89100.00
F5C1B5	2017-07-31 07:24:00+03	136200.00
F5C1CD	2017-07-27 09:56:00+03	33100.00
F5C1F5	2017-07-09 19:21:00+03	103500.00
F5C204	2017-07-19 00:19:00+03	75600.00
F5C297	2017-07-08 20:16:00+03	47100.00
F5C2F6	2017-08-13 04:51:00+03	14000.00
F5C306	2017-07-09 19:38:00+03	139200.00
F5C353	2017-08-06 00:39:00+03	43100.00
F5C388	2017-07-05 12:01:00+03	305000.00
F5C3A8	2017-07-30 13:32:00+03	89700.00
F5C3E1	2017-08-09 02:53:00+03	26000.00
F5C3E9	2017-07-27 13:21:00+03	73600.00
F5C46D	2017-07-26 16:07:00+03	38400.00
F5C5BC	2017-07-31 21:21:00+03	107000.00
F5C5BD	2017-07-09 22:03:00+03	8200.00
F5C61E	2017-08-11 17:31:00+03	19600.00
F5C653	2017-08-07 09:38:00+03	137800.00
F5C66A	2017-07-11 06:28:00+03	30200.00
F5C67C	2017-08-15 01:56:00+03	114300.00
F5C6C5	2017-07-21 20:14:00+03	6700.00
F5C6D0	2017-07-12 06:03:00+03	123000.00
F5C74C	2017-07-05 10:36:00+03	124200.00
F5C79F	2017-08-13 05:36:00+03	86400.00
F5C7A0	2017-08-05 08:17:00+03	48800.00
F5C80D	2017-07-19 13:46:00+03	36200.00
F5C81C	2017-07-18 05:59:00+03	7300.00
F5C834	2017-07-28 03:47:00+03	92800.00
F5C83E	2017-07-13 01:19:00+03	169600.00
F5C83F	2017-07-28 08:41:00+03	369000.00
F5C840	2017-08-05 14:36:00+03	88400.00
F5C89B	2017-07-24 00:55:00+03	108500.00
F5C8F5	2017-08-14 08:10:00+03	6000.00
F5C997	2017-08-09 06:20:00+03	135000.00
F5C9AE	2017-07-07 08:09:00+03	254600.00
F5CA85	2017-08-07 09:19:00+03	288300.00
F5CB2F	2017-07-24 14:36:00+03	137800.00
F5CB62	2017-07-27 16:20:00+03	40800.00
F5CB8E	2017-07-11 08:34:00+03	68100.00
F5CC22	2017-08-14 10:57:00+03	248400.00
F5CC40	2017-08-04 03:56:00+03	111600.00
F5CC4B	2017-08-07 21:26:00+03	46300.00
F5CCDB	2017-07-16 03:21:00+03	31600.00
F5CCDD	2017-07-10 11:36:00+03	47600.00
F5CCE8	2017-08-10 09:00:00+03	67900.00
F5CD47	2017-07-22 18:06:00+03	122800.00
F5CD9E	2017-07-07 23:39:00+03	46000.00
F5CDB6	2017-08-13 21:48:00+03	120000.00
F5CE08	2017-07-22 05:33:00+03	11600.00
F5CE1E	2017-07-05 15:39:00+03	64700.00
F5CE6C	2017-07-09 11:34:00+03	59300.00
F5CEF1	2017-07-24 00:48:00+03	44600.00
F5CF06	2017-07-03 09:45:00+03	406700.00
F5CF5B	2017-07-31 13:12:00+03	7400.00
F5CFAE	2017-07-28 00:44:00+03	6700.00
F5CFD1	2017-07-27 04:38:00+03	189200.00
F5CFFE	2017-08-05 13:39:00+03	55600.00
F5D024	2017-08-10 10:07:00+03	21400.00
F5D045	2017-08-12 05:04:00+03	8000.00
F5D056	2017-08-04 13:29:00+03	26800.00
F5D066	2017-08-02 15:07:00+03	90800.00
F5D06C	2017-08-01 03:27:00+03	361600.00
F5D092	2017-08-06 12:36:00+03	23600.00
F5D0EA	2017-07-23 21:44:00+03	73500.00
F5D129	2017-08-04 12:45:00+03	100000.00
F5D227	2017-07-27 01:52:00+03	47000.00
F5D29C	2017-08-08 07:42:00+03	88600.00
F5D2E8	2017-08-02 14:39:00+03	155600.00
F5D308	2017-08-07 05:02:00+03	68000.00
F5D31C	2017-07-02 03:09:00+03	94000.00
F5D339	2017-07-18 10:34:00+03	6700.00
F5D354	2017-08-03 19:33:00+03	42800.00
F5D3DC	2017-07-19 05:07:00+03	50400.00
F5D517	2017-08-09 08:12:00+03	170200.00
F5D53B	2017-07-11 21:22:00+03	12400.00
F5D549	2017-08-08 19:23:00+03	169900.00
F5D54A	2017-07-14 20:05:00+03	105600.00
F5D598	2017-07-20 03:59:00+03	30600.00
F5D5B1	2017-08-15 06:56:00+03	123000.00
F5D5B6	2017-07-14 07:35:00+03	71600.00
F5D5CE	2017-08-08 02:24:00+03	69600.00
F5D5D0	2017-07-08 00:02:00+03	56600.00
F5D5DF	2017-07-09 05:20:00+03	229400.00
F5D603	2017-07-24 12:34:00+03	46400.00
F5D60B	2017-07-16 17:32:00+03	8000.00
F5D633	2017-07-24 16:46:00+03	121400.00
F5D658	2017-07-13 15:51:00+03	23600.00
F5D67F	2017-07-06 18:57:00+03	100600.00
F5D688	2017-08-09 20:15:00+03	182300.00
F5D6C4	2017-08-05 08:57:00+03	48500.00
F5D7FA	2017-08-05 08:09:00+03	58900.00
F5D835	2017-08-13 17:04:00+03	73000.00
F5D922	2017-07-02 06:31:00+03	95000.00
F5D935	2017-07-19 01:32:00+03	100600.00
F5D940	2017-07-05 02:08:00+03	20200.00
F5D958	2017-08-11 15:33:00+03	386300.00
F5D997	2017-07-13 13:43:00+03	63700.00
F5D9F3	2017-08-03 23:18:00+03	135400.00
F5DA0B	2017-08-09 13:48:00+03	117200.00
F5DAB4	2017-07-13 03:50:00+03	59300.00
F5DB94	2017-08-14 23:17:00+03	168700.00
F5DC14	2017-07-21 14:12:00+03	24400.00
F5DC5A	2017-08-13 16:23:00+03	37700.00
F5DD29	2017-07-17 21:13:00+03	25600.00
F5DD40	2017-07-16 11:09:00+03	132800.00
F5DD8F	2017-08-12 15:33:00+03	46300.00
F5DDE1	2017-07-28 16:33:00+03	24000.00
F5DEB2	2017-07-02 17:36:00+03	97200.00
F5DEDA	2017-08-07 04:59:00+03	167400.00
F5DF19	2017-08-04 19:51:00+03	28000.00
F5DF2F	2017-08-04 05:21:00+03	125200.00
F5DF68	2017-07-20 16:23:00+03	23600.00
F5DFF7	2017-07-27 07:10:00+03	375200.00
F5E016	2017-07-07 08:54:00+03	134000.00
F5E0AA	2017-07-18 00:04:00+03	23600.00
F5E0BF	2017-07-18 18:23:00+03	72300.00
F5E0D8	2017-07-06 21:34:00+03	69500.00
F5E127	2017-08-11 01:46:00+03	66800.00
F5E12C	2017-08-09 22:17:00+03	121400.00
F5E148	2017-07-23 22:28:00+03	46400.00
F5E171	2017-07-30 22:29:00+03	56000.00
F5E180	2017-08-13 15:01:00+03	26000.00
F5E1A9	2017-07-31 05:54:00+03	14400.00
F5E267	2017-08-05 09:18:00+03	40400.00
F5E2DD	2017-07-04 19:53:00+03	189200.00
F5E2E0	2017-08-02 15:54:00+03	29600.00
F5E31C	2017-07-10 14:35:00+03	47400.00
F5E33F	2017-07-20 23:34:00+03	165500.00
F5E358	2017-07-16 05:59:00+03	24400.00
F5E367	2017-07-22 20:09:00+03	33200.00
F5E3D1	2017-08-12 16:15:00+03	22400.00
F5E3E6	2017-07-23 07:19:00+03	67600.00
F5E425	2017-07-20 04:57:00+03	226200.00
F5E479	2017-07-02 13:09:00+03	20400.00
F5E48A	2017-07-16 10:44:00+03	18000.00
F5E579	2017-07-17 18:51:00+03	86400.00
F5E593	2017-08-11 03:10:00+03	6800.00
F5E5A6	2017-08-02 23:04:00+03	13600.00
F5E5A7	2017-08-02 00:17:00+03	37100.00
F5E5E7	2017-08-07 10:16:00+03	14000.00
F5E678	2017-07-31 14:32:00+03	84100.00
F5E72E	2017-08-04 19:10:00+03	260300.00
F5E7B8	2017-08-04 15:03:00+03	44000.00
F5E84F	2017-07-22 10:21:00+03	62600.00
F5E86E	2017-07-06 22:24:00+03	189200.00
F5E874	2017-07-16 23:26:00+03	55800.00
F5E8F4	2017-07-09 11:14:00+03	33300.00
F5E938	2017-07-25 10:50:00+03	26600.00
F5E959	2017-07-06 13:29:00+03	38600.00
F5E9A3	2017-08-13 17:18:00+03	34000.00
F5E9A5	2017-08-10 23:25:00+03	24400.00
F5EA1B	2017-07-23 03:14:00+03	19200.00
F5EA31	2017-07-26 12:45:00+03	12600.00
F5EA71	2017-08-13 23:38:00+03	54400.00
F5EAA1	2017-07-15 01:33:00+03	270000.00
F5EAE3	2017-07-02 13:06:00+03	52000.00
F5EAE8	2017-07-10 17:47:00+03	79000.00
F5EB6A	2017-07-29 12:24:00+03	92600.00
F5EB7E	2017-07-06 22:32:00+03	21800.00
F5EBA4	2017-06-30 05:41:00+03	55800.00
F5EBC5	2017-07-28 12:56:00+03	24400.00
F5EBE1	2017-08-07 20:44:00+03	70100.00
F5EC35	2017-07-19 21:20:00+03	230000.00
F5EC3E	2017-07-22 03:27:00+03	6000.00
F5EC64	2017-07-18 08:02:00+03	134700.00
F5EC66	2017-07-13 17:24:00+03	119500.00
F5EC81	2017-08-03 03:05:00+03	33600.00
F5EC89	2017-07-12 23:36:00+03	25600.00
F5ECAD	2017-08-01 18:08:00+03	46800.00
F5ED7A	2017-07-14 13:41:00+03	61800.00
F5ED89	2017-08-08 05:18:00+03	31600.00
F5EE23	2017-08-06 15:37:00+03	32200.00
F5EEB8	2017-08-02 12:48:00+03	37900.00
F5EEF5	2017-08-02 17:38:00+03	26200.00
F5EEF7	2017-07-22 10:02:00+03	84500.00
F5EEF9	2017-08-02 01:09:00+03	86400.00
F5EEFE	2017-07-28 23:42:00+03	36200.00
F5EF22	2017-07-03 19:28:00+03	257500.00
F5EF29	2017-07-29 19:27:00+03	27200.00
F5EF87	2017-08-03 23:13:00+03	24200.00
F5EFCD	2017-07-23 23:14:00+03	23200.00
F5F025	2017-08-14 00:12:00+03	19600.00
F5F058	2017-08-12 01:35:00+03	8200.00
F5F072	2017-08-06 09:59:00+03	119600.00
F5F0BC	2017-07-23 06:47:00+03	38600.00
F5F11D	2017-08-08 08:36:00+03	14000.00
F5F133	2017-07-12 21:20:00+03	85000.00
F5F170	2017-08-12 21:46:00+03	56900.00
F5F1BC	2017-07-15 21:01:00+03	55400.00
F5F1EA	2017-07-20 21:45:00+03	42600.00
F5F213	2017-07-06 17:33:00+03	52400.00
F5F2AB	2017-07-07 22:12:00+03	65900.00
F5F320	2017-08-01 02:24:00+03	102100.00
F5F372	2017-07-09 07:02:00+03	92100.00
F5F39A	2017-07-09 14:14:00+03	13600.00
F5F3ED	2017-08-15 11:59:00+03	52300.00
F5F41C	2017-07-06 13:45:00+03	48500.00
F5F4B8	2017-07-14 01:39:00+03	26800.00
F5F4BC	2017-08-11 07:34:00+03	47400.00
F5F517	2017-07-22 20:04:00+03	57500.00
F5F51E	2017-07-31 09:19:00+03	49100.00
F5F520	2017-07-12 02:44:00+03	45200.00
F5F54C	2017-07-08 22:44:00+03	28800.00
F5F584	2017-07-06 08:25:00+03	93900.00
F5F5B4	2017-08-14 17:58:00+03	246000.00
F5F5D9	2017-07-07 01:33:00+03	40600.00
F5F654	2017-08-11 11:25:00+03	203400.00
F5F6D8	2017-08-11 14:32:00+03	39800.00
F5F6DE	2017-07-05 04:54:00+03	23600.00
F5F70F	2017-08-13 06:36:00+03	16400.00
F5F718	2017-07-30 06:46:00+03	354400.00
F5F726	2017-08-02 22:32:00+03	67600.00
F5F784	2017-07-25 15:59:00+03	12400.00
F5F844	2017-08-14 01:01:00+03	10800.00
F5F936	2017-07-22 15:09:00+03	133200.00
F5F9BE	2017-07-24 14:45:00+03	193600.00
F5F9C1	2017-07-15 18:27:00+03	13700.00
F5FA0E	2017-07-01 03:46:00+03	21800.00
F5FA34	2017-07-10 07:43:00+03	36800.00
F5FA35	2017-08-15 15:39:00+03	57500.00
F5FA61	2017-08-14 12:46:00+03	83200.00
F5FA80	2017-07-09 15:51:00+03	32400.00
F5FAAB	2017-07-07 03:15:00+03	78200.00
F5FAFC	2017-07-27 04:20:00+03	67000.00
F5FB4C	2017-07-02 14:34:00+03	90600.00
F5FBAF	2017-07-24 06:30:00+03	449700.00
F5FBD5	2017-08-10 13:41:00+03	103600.00
F5FBF1	2017-07-23 21:01:00+03	203000.00
F5FC62	2017-08-08 10:39:00+03	31900.00
F5FD5D	2017-07-23 10:42:00+03	125200.00
F5FD8C	2017-07-05 17:50:00+03	53600.00
F5FD97	2017-08-13 05:40:00+03	80500.00
F5FD98	2017-07-04 12:09:00+03	20200.00
F5FDA2	2017-07-13 08:47:00+03	36800.00
F5FDCB	2017-07-19 01:42:00+03	17000.00
F5FDF5	2017-07-11 08:06:00+03	20000.00
F5FE0A	2017-07-06 19:02:00+03	25400.00
F5FE36	2017-08-10 11:49:00+03	179700.00
F5FE8B	2017-07-08 16:19:00+03	29200.00
F5FE91	2017-07-27 01:36:00+03	14000.00
F5FF18	2017-07-27 15:24:00+03	136600.00
F5FF28	2017-06-29 13:48:00+03	15900.00
F5FFC0	2017-07-08 07:19:00+03	163600.00
F5FFD9	2017-08-12 02:23:00+03	117600.00
F60041	2017-07-25 00:18:00+03	38800.00
F600B3	2017-08-15 14:03:00+03	24100.00
F600B9	2017-07-04 22:00:00+03	57800.00
F600C8	2017-07-09 06:58:00+03	58200.00
F60183	2017-07-14 22:04:00+03	191200.00
F601D6	2017-07-24 00:04:00+03	89000.00
F60211	2017-08-13 09:48:00+03	71300.00
F60245	2017-08-10 23:59:00+03	54800.00
F60280	2017-07-01 07:06:00+03	125500.00
F6028A	2017-07-24 11:23:00+03	52400.00
F602A8	2017-08-08 17:40:00+03	57700.00
F602AF	2017-08-06 09:11:00+03	95200.00
F6032F	2017-08-15 04:20:00+03	24400.00
F60342	2017-07-09 09:20:00+03	28300.00
F60347	2017-07-14 12:16:00+03	46400.00
F6039C	2017-08-14 04:34:00+03	123600.00
F6039E	2017-08-04 21:30:00+03	14400.00
F603BF	2017-08-13 22:51:00+03	23600.00
F60401	2017-07-26 10:11:00+03	36200.00
F6043F	2017-07-31 13:59:00+03	13400.00
F6045A	2017-07-18 11:27:00+03	56000.00
F6048F	2017-07-23 13:32:00+03	46800.00
F604B6	2017-07-17 00:13:00+03	254600.00
F604CA	2017-07-01 01:34:00+03	136200.00
F604D9	2017-07-13 09:32:00+03	52000.00
F605B8	2017-08-05 03:14:00+03	28800.00
F6063A	2017-07-21 15:09:00+03	68800.00
F60666	2017-07-22 18:43:00+03	6300.00
F60683	2017-07-13 22:39:00+03	67900.00
F606A2	2017-07-30 04:14:00+03	28700.00
F607C6	2017-07-08 22:06:00+03	23900.00
F60801	2017-08-01 17:49:00+03	47400.00
F6080A	2017-08-14 20:38:00+03	59800.00
F6080E	2017-07-13 02:14:00+03	63900.00
F608DB	2017-08-12 15:13:00+03	65000.00
F608F1	2017-08-08 21:38:00+03	24400.00
F60916	2017-07-04 08:00:00+03	44000.00
F6096B	2017-07-13 22:50:00+03	77400.00
F6097A	2017-08-03 21:45:00+03	78300.00
F609AA	2017-07-08 08:42:00+03	53500.00
F609FB	2017-07-29 02:33:00+03	116000.00
F60A09	2017-07-23 00:31:00+03	67200.00
F60A0C	2017-07-07 03:40:00+03	44800.00
F60A54	2017-07-03 08:46:00+03	38800.00
F60A5E	2017-07-06 17:33:00+03	43000.00
F60AD0	2017-07-24 17:09:00+03	98400.00
F60AEB	2017-08-08 10:46:00+03	36200.00
F60B66	2017-08-15 07:40:00+03	117000.00
F60BBA	2017-07-14 04:37:00+03	7400.00
F60BC2	2017-08-12 03:07:00+03	43900.00
F60BEA	2017-08-04 23:44:00+03	69600.00
F60BF6	2017-06-28 02:30:00+03	88900.00
F60C63	2017-07-22 08:47:00+03	24000.00
F60CA7	2017-08-13 03:53:00+03	399600.00
F60D13	2017-07-01 23:40:00+03	147000.00
F60D22	2017-07-22 17:26:00+03	92300.00
F60D47	2017-07-23 19:37:00+03	37200.00
F60D48	2017-07-19 00:04:00+03	204500.00
F60DAB	2017-07-03 07:31:00+03	160200.00
F60DAF	2017-08-15 17:07:00+03	48800.00
F60DC0	2017-07-23 04:29:00+03	51300.00
F60DD2	2017-08-01 12:15:00+03	130400.00
F60E1D	2017-07-06 09:10:00+03	162800.00
F60E2B	2017-07-26 00:02:00+03	63200.00
F60E4D	2017-07-25 23:15:00+03	57600.00
F60E4E	2017-08-07 14:22:00+03	201800.00
F60E5A	2017-07-30 08:29:00+03	13700.00
F60E70	2017-08-05 17:25:00+03	59800.00
F60ED2	2017-08-09 15:19:00+03	24700.00
F60F09	2017-07-21 08:40:00+03	32700.00
F60F48	2017-08-10 02:59:00+03	137600.00
F60FB3	2017-08-03 15:44:00+03	26000.00
F60FCE	2017-07-19 02:34:00+03	49100.00
F61015	2017-07-12 15:14:00+03	23600.00
F61078	2017-07-01 16:40:00+03	46000.00
F61091	2017-07-07 10:37:00+03	83000.00
F610AA	2017-07-18 01:29:00+03	13200.00
F61102	2017-08-07 02:01:00+03	111700.00
F61108	2017-08-07 17:08:00+03	125200.00
F61136	2017-07-07 11:56:00+03	12600.00
F61143	2017-07-25 17:58:00+03	26000.00
F6114D	2017-08-07 10:15:00+03	20200.00
F6114F	2017-07-16 18:11:00+03	48400.00
F61215	2017-08-01 19:29:00+03	84800.00
F6124A	2017-07-30 09:27:00+03	14400.00
F61278	2017-07-08 19:28:00+03	109200.00
F612C2	2017-07-13 02:24:00+03	51900.00
F6132B	2017-07-01 11:23:00+03	76600.00
F61333	2017-08-05 09:43:00+03	32800.00
F61360	2017-07-28 01:58:00+03	180000.00
F61371	2017-07-04 02:02:00+03	134400.00
F613B7	2017-08-06 23:17:00+03	304100.00
F6142B	2017-08-09 13:01:00+03	23600.00
F6153F	2017-08-14 01:06:00+03	26700.00
F615BF	2017-07-03 23:40:00+03	27200.00
F6166C	2017-08-06 06:02:00+03	70200.00
F616CD	2017-07-05 15:48:00+03	103100.00
F6173B	2017-08-09 19:25:00+03	26000.00
F61809	2017-08-07 12:37:00+03	66600.00
F61836	2017-08-01 17:35:00+03	99200.00
F618C9	2017-08-01 02:17:00+03	46400.00
F6193A	2017-07-18 21:42:00+03	36200.00
F6193F	2017-07-27 01:01:00+03	27200.00
F61993	2017-08-10 00:48:00+03	7400.00
F619FE	2017-07-09 21:57:00+03	269600.00
F61A71	2017-08-05 21:34:00+03	96800.00
F61AE9	2017-08-03 21:34:00+03	6000.00
F61B20	2017-07-06 20:18:00+03	136800.00
F61B4A	2017-07-28 02:03:00+03	88100.00
F61B68	2017-07-29 02:50:00+03	21400.00
F61BC9	2017-07-02 21:38:00+03	13400.00
F61BF2	2017-08-12 23:48:00+03	83000.00
F61C88	2017-08-06 17:33:00+03	185600.00
F61CE5	2017-08-01 20:09:00+03	186900.00
F61CFC	2017-06-28 09:16:00+03	31400.00
F61D13	2017-07-02 05:21:00+03	36800.00
F61D4D	2017-08-03 19:18:00+03	57500.00
F61DAC	2017-07-30 07:12:00+03	169600.00
F61E15	2017-08-07 23:35:00+03	81900.00
F61EE7	2017-07-14 06:39:00+03	68100.00
F61F21	2017-07-21 15:18:00+03	58000.00
F61F41	2017-08-11 09:27:00+03	129000.00
F61F59	2017-08-14 05:21:00+03	260300.00
F61F66	2017-08-12 22:46:00+03	49400.00
F61FCF	2017-08-06 22:27:00+03	28000.00
F61FDB	2017-07-02 18:41:00+03	136600.00
F62145	2017-07-17 16:47:00+03	23600.00
F62176	2017-06-30 06:14:00+03	23600.00
F62194	2017-08-06 14:46:00+03	23400.00
F621BC	2017-07-27 11:58:00+03	112000.00
F621FD	2017-08-11 20:16:00+03	163500.00
F62268	2017-08-10 01:32:00+03	27900.00
F6227D	2017-08-08 13:45:00+03	21800.00
F622FB	2017-08-09 18:37:00+03	58400.00
F6232D	2017-07-20 10:31:00+03	119500.00
F6238A	2017-07-18 16:03:00+03	21800.00
F6240A	2017-07-08 07:33:00+03	46400.00
F62422	2017-07-25 00:21:00+03	174600.00
F6247D	2017-08-08 20:12:00+03	202300.00
F624BD	2017-08-08 15:11:00+03	26000.00
F624E9	2017-08-05 21:48:00+03	39800.00
F624F4	2017-07-27 14:53:00+03	40800.00
F6251C	2017-08-02 01:35:00+03	26000.00
F62525	2017-07-26 03:29:00+03	70700.00
F6254D	2017-07-15 08:35:00+03	93500.00
F625F9	2017-07-09 07:48:00+03	31800.00
F62668	2017-07-09 04:27:00+03	28800.00
F6266E	2017-07-14 17:24:00+03	87600.00
F62680	2017-08-08 15:26:00+03	52700.00
F6268D	2017-08-12 17:11:00+03	396500.00
F6269A	2017-07-04 11:13:00+03	40400.00
F626C7	2017-08-06 12:05:00+03	535100.00
F62715	2017-07-30 12:38:00+03	34000.00
F6274B	2017-07-19 07:00:00+03	135600.00
F627D9	2017-07-15 00:24:00+03	73600.00
F62887	2017-07-12 14:01:00+03	262800.00
F628D2	2017-07-02 05:56:00+03	28700.00
F628D5	2017-07-23 13:12:00+03	118800.00
F62916	2017-08-10 14:47:00+03	93900.00
F62928	2017-08-03 03:08:00+03	92600.00
F6293E	2017-07-21 06:08:00+03	202100.00
F62946	2017-07-28 18:45:00+03	26800.00
F6295D	2017-08-06 05:54:00+03	51600.00
F62970	2017-08-07 03:00:00+03	117600.00
F629CB	2017-08-14 20:28:00+03	8000.00
F62A52	2017-07-15 05:38:00+03	72400.00
F62AAE	2017-07-02 13:47:00+03	72400.00
F62AE0	2017-07-18 21:22:00+03	47400.00
F62AE6	2017-08-06 16:28:00+03	55800.00
F62B13	2017-07-28 00:13:00+03	32400.00
F62B21	2017-08-01 21:42:00+03	24700.00
F62B24	2017-07-13 21:39:00+03	270000.00
F62B7E	2017-07-16 02:57:00+03	16800.00
F62BC3	2017-06-30 03:54:00+03	147100.00
F62D0F	2017-08-11 19:49:00+03	73100.00
F62D24	2017-08-12 13:25:00+03	52300.00
F62D64	2017-07-01 17:42:00+03	32700.00
F62DB2	2017-08-04 17:18:00+03	50000.00
F62DB3	2017-07-14 09:05:00+03	92800.00
F62E3A	2017-07-23 02:58:00+03	89600.00
F62E5B	2017-08-04 07:27:00+03	132800.00
F62E99	2017-07-19 09:14:00+03	78200.00
F62EAF	2017-08-12 12:17:00+03	118600.00
F62EB8	2017-08-06 07:25:00+03	123000.00
F62EC3	2017-07-22 21:30:00+03	46400.00
F62EC8	2017-07-30 13:20:00+03	67200.00
F62EF6	2017-07-30 23:57:00+03	26000.00
F62F0E	2017-07-15 05:54:00+03	37100.00
F62F13	2017-07-05 19:54:00+03	30200.00
F62F76	2017-07-19 06:36:00+03	40800.00
F63078	2017-08-11 17:08:00+03	32700.00
F6310A	2017-08-04 14:59:00+03	27200.00
F63131	2017-07-07 06:09:00+03	188500.00
F63169	2017-08-14 09:03:00+03	39200.00
F631D5	2017-07-30 14:03:00+03	125200.00
F631E6	2017-08-08 02:37:00+03	43600.00
F631ED	2017-07-12 16:54:00+03	64500.00
F63202	2017-07-13 09:02:00+03	178800.00
F63231	2017-07-11 06:10:00+03	38600.00
F63244	2017-07-14 23:10:00+03	44800.00
F632FA	2017-08-14 10:08:00+03	167500.00
F63309	2017-07-27 05:19:00+03	16400.00
F63313	2017-08-04 06:33:00+03	272400.00
F63344	2017-08-07 11:01:00+03	265600.00
F633C0	2017-07-22 02:28:00+03	57600.00
F63411	2017-08-13 15:40:00+03	49200.00
F634A0	2017-07-27 04:54:00+03	35600.00
F634B1	2017-08-04 19:59:00+03	14800.00
F634BE	2017-08-15 17:10:00+03	202400.00
F6365A	2017-08-04 03:05:00+03	83600.00
F636B3	2017-08-02 23:03:00+03	47800.00
F636CE	2017-07-17 21:22:00+03	69500.00
F636F5	2017-08-07 22:37:00+03	14300.00
F63707	2017-08-06 07:47:00+03	39200.00
F63739	2017-08-03 04:52:00+03	72400.00
F63789	2017-08-13 02:43:00+03	27200.00
F637A8	2017-07-15 06:39:00+03	486100.00
F637B2	2017-07-28 15:15:00+03	31400.00
F637BC	2017-07-13 19:18:00+03	3400.00
F637EF	2017-08-04 23:15:00+03	47700.00
F63830	2017-08-07 19:30:00+03	13000.00
F6386E	2017-07-24 17:28:00+03	14000.00
F63871	2017-08-13 18:41:00+03	20800.00
F638EF	2017-07-29 18:18:00+03	40600.00
F63933	2017-08-03 00:28:00+03	37200.00
F63939	2017-07-02 00:06:00+03	83700.00
F63951	2017-08-09 19:45:00+03	16800.00
F63953	2017-08-11 19:48:00+03	21800.00
F63958	2017-08-13 20:10:00+03	19300.00
F639A2	2017-08-06 01:31:00+03	16400.00
F639C9	2017-07-24 04:32:00+03	18000.00
F63A98	2017-07-20 13:40:00+03	28000.00
F63AA0	2017-07-25 17:55:00+03	85000.00
F63ACF	2017-08-14 00:27:00+03	68800.00
F63B6A	2017-08-09 03:08:00+03	16400.00
F63BB9	2017-07-26 21:05:00+03	18000.00
F63BD5	2017-07-22 04:08:00+03	75300.00
F63C80	2017-07-03 22:50:00+03	113300.00
F63CE1	2017-08-14 04:33:00+03	117000.00
F63CEF	2017-07-30 06:56:00+03	13400.00
F63D04	2017-07-31 20:19:00+03	47400.00
F63D10	2017-08-09 09:04:00+03	70500.00
F63D3C	2017-07-06 22:18:00+03	32200.00
F63D70	2017-07-14 08:23:00+03	48300.00
F63D75	2017-07-19 00:24:00+03	20400.00
F63D8D	2017-07-13 16:36:00+03	102100.00
F63E01	2017-08-14 20:16:00+03	134400.00
F63E0F	2017-07-15 06:15:00+03	27200.00
F63E31	2017-07-15 05:55:00+03	135600.00
F63F0D	2017-07-28 16:57:00+03	409600.00
F63F98	2017-07-05 18:15:00+03	43600.00
F640EF	2017-07-13 12:12:00+03	179300.00
F64136	2017-07-03 17:10:00+03	14000.00
F64188	2017-08-03 08:48:00+03	27400.00
F641B5	2017-07-21 23:41:00+03	60000.00
F641E2	2017-08-14 03:07:00+03	55100.00
F64237	2017-08-05 12:59:00+03	55800.00
F64242	2017-07-23 23:38:00+03	120800.00
F64271	2017-08-04 02:02:00+03	30000.00
F64298	2017-07-28 20:03:00+03	117600.00
F642A0	2017-07-05 05:49:00+03	28000.00
F642BC	2017-07-27 12:08:00+03	270800.00
F642CE	2017-06-26 06:20:00+03	47000.00
F64338	2017-08-15 02:46:00+03	187800.00
F6434C	2017-07-08 00:17:00+03	225800.00
F64356	2017-08-01 03:07:00+03	87200.00
F6435B	2017-08-15 10:09:00+03	28800.00
F643A3	2017-07-19 09:21:00+03	274200.00
F64411	2017-08-11 10:24:00+03	46000.00
F64449	2017-07-06 18:06:00+03	90800.00
F64574	2017-07-26 06:13:00+03	65500.00
F64577	2017-08-11 03:42:00+03	23200.00
F64593	2017-07-25 00:46:00+03	44800.00
F645B0	2017-07-11 12:48:00+03	21200.00
F645B3	2017-07-02 01:58:00+03	57400.00
F645D2	2017-07-05 03:07:00+03	66600.00
F64631	2017-07-29 04:20:00+03	57400.00
F6467B	2017-07-20 04:37:00+03	27900.00
F64680	2017-08-10 10:14:00+03	75300.00
F646C8	2017-08-01 18:12:00+03	41800.00
F646CC	2017-07-19 12:02:00+03	55800.00
F646E6	2017-07-14 13:35:00+03	48800.00
F646E9	2017-07-24 23:44:00+03	73500.00
F646EB	2017-07-20 12:16:00+03	20000.00
F64751	2017-07-25 03:52:00+03	21000.00
F64780	2017-07-16 23:43:00+03	13000.00
F647A2	2017-08-08 13:15:00+03	42900.00
F647FF	2017-07-03 01:14:00+03	40000.00
F64827	2017-08-04 02:00:00+03	25400.00
F6485D	2017-07-29 10:53:00+03	15000.00
F6485E	2017-08-14 19:01:00+03	32700.00
F64876	2017-07-07 23:55:00+03	68200.00
F6487D	2017-07-27 12:05:00+03	68100.00
F6489B	2017-07-12 01:50:00+03	56600.00
F648C4	2017-07-10 06:43:00+03	95200.00
F648E2	2017-07-02 14:09:00+03	10700.00
F648E4	2017-08-08 10:16:00+03	46000.00
F648E7	2017-07-04 01:17:00+03	56000.00
F64926	2017-08-05 02:05:00+03	81700.00
F64934	2017-08-13 15:33:00+03	46200.00
F6493C	2017-08-05 04:45:00+03	122200.00
F64967	2017-07-05 07:04:00+03	52700.00
F64978	2017-07-01 04:17:00+03	33100.00
F649AF	2017-07-16 15:21:00+03	46400.00
F649D0	2017-07-21 01:41:00+03	69600.00
F64AB0	2017-07-11 23:29:00+03	69500.00
F64AD5	2017-08-03 14:02:00+03	192300.00
F64AF6	2017-08-08 10:51:00+03	94400.00
F64AFB	2017-07-27 21:00:00+03	240600.00
F64B03	2017-07-25 05:58:00+03	58600.00
F64B0F	2017-07-08 04:24:00+03	69500.00
F64B7A	2017-08-11 19:51:00+03	52800.00
F64B85	2017-06-28 09:39:00+03	36200.00
F64BB6	2017-07-05 03:34:00+03	7200.00
F64C46	2017-08-06 14:59:00+03	60400.00
F64C7B	2017-07-08 17:40:00+03	25200.00
F64CA3	2017-07-14 09:09:00+03	25400.00
F64D41	2017-08-01 10:23:00+03	51900.00
F64D81	2017-07-25 18:38:00+03	86800.00
F64D90	2017-06-29 20:21:00+03	94800.00
F64DA2	2017-07-11 08:34:00+03	56600.00
F64DCD	2017-07-08 19:50:00+03	43200.00
F64DF7	2017-07-02 06:07:00+03	109600.00
F64E76	2017-07-05 14:48:00+03	175000.00
F64F6B	2017-07-21 11:02:00+03	135600.00
F64FB4	2017-07-31 15:34:00+03	105600.00
F64FD1	2017-07-06 06:38:00+03	32700.00
F6501F	2017-08-12 05:00:00+03	28800.00
F650B4	2017-07-05 23:48:00+03	26600.00
F650C9	2017-08-01 05:21:00+03	248400.00
F650D3	2017-07-08 20:02:00+03	123000.00
F6516A	2017-07-25 22:00:00+03	92900.00
F65197	2017-08-13 08:09:00+03	58800.00
F651C3	2017-07-18 12:44:00+03	11700.00
F65202	2017-08-08 05:22:00+03	182700.00
F65268	2017-08-10 14:06:00+03	133200.00
F65316	2017-08-05 16:20:00+03	186900.00
F6531C	2017-06-27 09:57:00+03	55800.00
F65348	2017-07-09 14:54:00+03	89200.00
F6534C	2017-07-16 05:01:00+03	103500.00
F653B1	2017-07-24 13:34:00+03	21800.00
F653E0	2017-07-08 22:38:00+03	10100.00
F653F9	2017-08-08 18:17:00+03	13400.00
F65426	2017-08-09 16:16:00+03	19600.00
F65436	2017-07-06 05:00:00+03	90600.00
F65489	2017-08-03 15:11:00+03	50600.00
F654A8	2017-08-05 12:55:00+03	103000.00
F65532	2017-07-11 18:29:00+03	289700.00
F65548	2017-08-12 12:57:00+03	8400.00
F655D7	2017-07-22 08:43:00+03	34000.00
F65637	2017-07-16 05:26:00+03	46400.00
F6563A	2017-07-16 03:40:00+03	32700.00
F65664	2017-07-12 05:49:00+03	35200.00
F656C7	2017-08-04 16:08:00+03	46000.00
F656DD	2017-08-07 08:17:00+03	83200.00
F65758	2017-08-15 06:17:00+03	44800.00
F65773	2017-08-03 15:47:00+03	153300.00
F65788	2017-07-24 12:38:00+03	50100.00
F658BB	2017-07-10 15:10:00+03	54800.00
F658D6	2017-07-26 10:19:00+03	73200.00
F658E4	2017-07-28 16:59:00+03	73200.00
F658E8	2017-07-24 09:57:00+03	103500.00
F6597C	2017-08-01 23:06:00+03	26000.00
F65983	2017-08-09 03:36:00+03	151800.00
F65985	2017-08-13 12:07:00+03	47000.00
F659FB	2017-07-20 23:11:00+03	43000.00
F65A21	2017-08-09 21:58:00+03	68800.00
F65A4A	2017-07-24 19:40:00+03	67600.00
F65A54	2017-07-06 12:36:00+03	38000.00
F65B37	2017-07-15 06:39:00+03	110300.00
F65BCE	2017-08-03 10:02:00+03	19600.00
F65C12	2017-07-26 14:27:00+03	67200.00
F65C4F	2017-07-19 13:15:00+03	32100.00
F65C68	2017-07-04 19:47:00+03	26000.00
F65CBF	2017-07-08 11:16:00+03	139100.00
F65D08	2017-08-13 15:08:00+03	36200.00
F65D10	2017-07-22 21:08:00+03	36800.00
F65D34	2017-07-29 18:26:00+03	36200.00
F65DC4	2017-07-22 18:03:00+03	16400.00
F65DC7	2017-08-13 22:51:00+03	56000.00
F65E87	2017-07-14 18:02:00+03	55800.00
F65F5A	2017-08-10 12:08:00+03	87900.00
F65FB9	2017-07-24 10:25:00+03	136800.00
F66053	2017-08-15 05:43:00+03	128700.00
F66054	2017-08-14 20:59:00+03	146300.00
F66167	2017-07-30 20:34:00+03	92800.00
F66172	2017-07-05 07:37:00+03	50300.00
F6617E	2017-08-05 07:52:00+03	209800.00
F661AE	2017-07-03 06:44:00+03	20400.00
F6625E	2017-06-28 06:17:00+03	58000.00
F66262	2017-07-08 20:09:00+03	6000.00
F6627C	2017-07-14 01:28:00+03	131600.00
F662B4	2017-07-27 00:38:00+03	16400.00
F662E9	2017-08-15 01:33:00+03	140300.00
F662F3	2017-08-09 08:14:00+03	106100.00
F6633E	2017-07-08 08:33:00+03	131100.00
F663CD	2017-07-30 04:15:00+03	136200.00
F66460	2017-08-08 20:59:00+03	41800.00
F66463	2017-08-09 03:01:00+03	87300.00
F66497	2017-06-27 23:27:00+03	113100.00
F664A4	2017-07-20 19:07:00+03	69900.00
F6651F	2017-07-17 06:57:00+03	64500.00
F6659F	2017-07-08 22:08:00+03	148100.00
F665BC	2017-07-27 03:54:00+03	60800.00
F66626	2017-08-08 13:11:00+03	134800.00
F6665B	2017-07-21 04:23:00+03	20000.00
F667B3	2017-07-22 04:56:00+03	55800.00
F66815	2017-07-11 19:04:00+03	46000.00
F66837	2017-08-09 12:40:00+03	270800.00
F6689D	2017-08-03 12:22:00+03	43500.00
F66908	2017-08-06 05:08:00+03	3700.00
F66915	2017-07-16 11:59:00+03	67200.00
F66939	2017-08-02 03:59:00+03	15000.00
F6694D	2017-07-24 14:03:00+03	31600.00
F66952	2017-07-09 21:41:00+03	139100.00
F66973	2017-07-03 00:34:00+03	106900.00
F66A33	2017-07-11 01:48:00+03	56600.00
F66AD2	2017-07-09 22:49:00+03	47100.00
F66B1A	2017-07-31 07:52:00+03	15000.00
F66B49	2017-07-20 22:26:00+03	243600.00
F66B53	2017-08-07 18:03:00+03	58600.00
F66B64	2017-07-25 19:44:00+03	94200.00
F66B88	2017-08-09 19:01:00+03	13700.00
F66B8E	2017-08-04 05:59:00+03	26000.00
F66D10	2017-08-11 11:14:00+03	48800.00
F66DB8	2017-07-19 09:40:00+03	56100.00
F66DD9	2017-07-11 08:52:00+03	271200.00
F66E38	2017-07-03 10:30:00+03	10800.00
F66EEA	2017-08-13 08:53:00+03	397700.00
F66EF9	2017-07-28 00:28:00+03	81200.00
F66F45	2017-08-02 14:44:00+03	10800.00
F66F65	2017-08-09 06:57:00+03	74300.00
F66F73	2017-07-17 16:42:00+03	398500.00
F66F84	2017-08-07 08:02:00+03	99200.00
F66FB3	2017-08-08 01:23:00+03	92800.00
F67004	2017-07-08 05:38:00+03	21800.00
F67048	2017-07-04 09:03:00+03	45200.00
F6706F	2017-07-03 09:25:00+03	43000.00
F67110	2017-07-07 18:36:00+03	101200.00
F67148	2017-07-05 04:36:00+03	68400.00
F67186	2017-06-29 17:21:00+03	40000.00
F6721C	2017-07-29 20:55:00+03	358200.00
F672B9	2017-07-18 19:50:00+03	67200.00
F672BF	2017-07-15 10:14:00+03	44000.00
F672DD	2017-08-13 01:42:00+03	64700.00
F67399	2017-08-07 13:25:00+03	39800.00
F673BC	2017-07-26 08:38:00+03	57200.00
F67405	2017-08-14 02:15:00+03	31600.00
F67424	2017-08-01 21:41:00+03	40800.00
F67426	2017-07-26 08:55:00+03	136200.00
F67434	2017-07-09 12:27:00+03	45100.00
F674C0	2017-08-10 03:01:00+03	89600.00
F674DF	2017-07-31 20:48:00+03	36200.00
F674E2	2017-06-30 02:17:00+03	24600.00
F674F7	2017-08-01 03:29:00+03	39300.00
F6753D	2017-07-13 20:10:00+03	27900.00
F6756D	2017-07-10 19:18:00+03	98100.00
F675CA	2017-08-13 10:38:00+03	166100.00
F67603	2017-07-12 01:52:00+03	25600.00
F6760A	2017-08-04 16:01:00+03	14800.00
F67667	2017-08-11 00:40:00+03	138500.00
F676A4	2017-08-02 05:26:00+03	58800.00
F6772C	2017-07-22 13:59:00+03	62000.00
F67855	2017-07-27 18:34:00+03	77900.00
F6785E	2017-07-24 20:55:00+03	46300.00
F678D6	2017-08-06 14:23:00+03	6800.00
F678E2	2017-06-29 14:38:00+03	62800.00
F67975	2017-08-10 04:24:00+03	25100.00
F679D1	2017-07-28 10:40:00+03	131800.00
F67AE7	2017-07-25 12:47:00+03	40800.00
F67B07	2017-07-16 06:29:00+03	23200.00
F67B5C	2017-07-29 00:39:00+03	344700.00
F67B6C	2017-07-03 10:51:00+03	53300.00
F67B81	2017-07-20 03:00:00+03	27900.00
F67B82	2017-08-02 12:30:00+03	184300.00
F67B90	2017-08-11 11:36:00+03	64500.00
F67BB5	2017-07-23 18:20:00+03	70700.00
F67BCC	2017-08-08 04:20:00+03	187800.00
F67BDA	2017-07-20 12:12:00+03	20000.00
F67BF6	2017-07-15 16:05:00+03	68800.00
F67C84	2017-07-21 22:49:00+03	46400.00
F67CBA	2017-07-21 11:26:00+03	64200.00
F67CC5	2017-07-28 17:59:00+03	57500.00
F67CD6	2017-07-22 18:50:00+03	26000.00
F67D0A	2017-07-10 01:02:00+03	24800.00
F67D3C	2017-07-23 10:07:00+03	62000.00
F67D99	2017-07-23 18:38:00+03	6000.00
F67DE8	2017-07-15 00:47:00+03	24400.00
F67E10	2017-08-10 07:52:00+03	28000.00
F67E86	2017-08-13 09:02:00+03	56600.00
F67E97	2017-08-03 00:37:00+03	87700.00
F67EAF	2017-07-28 09:57:00+03	42800.00
F67EC7	2017-07-24 12:36:00+03	21800.00
F67ECD	2017-07-04 15:46:00+03	38800.00
F67F38	2017-08-15 02:24:00+03	52000.00
F67FBE	2017-07-15 07:42:00+03	7800.00
F6804B	2017-07-05 14:33:00+03	53600.00
F6806D	2017-07-26 00:33:00+03	96800.00
F6806F	2017-08-11 02:20:00+03	36600.00
F6808A	2017-08-14 11:29:00+03	68000.00
F680B1	2017-07-25 22:18:00+03	266200.00
F6811C	2017-07-24 10:45:00+03	31600.00
F681AD	2017-07-01 07:57:00+03	187200.00
F681D2	2017-07-16 15:00:00+03	67600.00
F681EA	2017-07-01 00:32:00+03	144400.00
F68261	2017-08-10 03:20:00+03	28000.00
F68297	2017-08-15 05:18:00+03	138500.00
F682AE	2017-08-03 03:23:00+03	46000.00
F682B8	2017-07-04 08:41:00+03	25400.00
F682C5	2017-08-03 03:22:00+03	23600.00
F682E7	2017-07-10 04:54:00+03	135400.00
F68318	2017-08-11 19:14:00+03	257500.00
F68328	2017-08-06 18:13:00+03	65200.00
F68382	2017-08-03 19:13:00+03	42700.00
F6838C	2017-07-09 09:56:00+03	79800.00
F6839C	2017-08-11 21:45:00+03	147700.00
F6841D	2017-07-06 15:01:00+03	6600.00
F68430	2017-08-14 00:02:00+03	8200.00
F684A3	2017-08-04 22:46:00+03	21600.00
F684B9	2017-07-30 08:37:00+03	173900.00
F684CC	2017-07-07 22:44:00+03	26000.00
F68529	2017-08-10 22:59:00+03	24400.00
F6852E	2017-07-30 11:12:00+03	92900.00
F6854C	2017-07-05 16:19:00+03	34000.00
F685CA	2017-08-08 15:11:00+03	47000.00
F68609	2017-08-14 23:19:00+03	31200.00
F68632	2017-08-05 00:16:00+03	67000.00
F6866A	2017-07-01 19:21:00+03	277000.00
F686EE	2017-07-20 03:47:00+03	8000.00
F68715	2017-08-11 12:41:00+03	25600.00
F68729	2017-08-02 14:06:00+03	38700.00
F68755	2017-08-01 08:16:00+03	29400.00
F68768	2017-07-22 20:05:00+03	311900.00
F68787	2017-07-19 02:50:00+03	8200.00
F687D3	2017-07-21 19:29:00+03	116800.00
F6884D	2017-07-19 11:50:00+03	123000.00
F68882	2017-07-16 11:52:00+03	14400.00
F688B1	2017-07-28 03:34:00+03	19600.00
F688F0	2017-07-06 12:42:00+03	39500.00
F68901	2017-08-06 11:04:00+03	14400.00
F68907	2017-08-02 08:48:00+03	46300.00
F68A4B	2017-07-07 18:36:00+03	66600.00
F68A55	2017-08-14 09:35:00+03	24800.00
F68A83	2017-08-10 04:12:00+03	105200.00
F68AF1	2017-08-06 17:44:00+03	6700.00
F68AF6	2017-07-10 12:54:00+03	81300.00
F68B09	2017-07-08 01:08:00+03	265700.00
F68B39	2017-08-03 08:04:00+03	43800.00
F68B60	2017-07-12 13:54:00+03	27200.00
F68B8C	2017-07-09 21:06:00+03	13600.00
F68B9D	2017-07-07 10:11:00+03	18600.00
F68BED	2017-07-18 09:54:00+03	32800.00
F68BEF	2017-06-30 11:25:00+03	88100.00
F68C0A	2017-07-27 07:35:00+03	23400.00
F68C3C	2017-08-08 21:49:00+03	40800.00
F68C7E	2017-08-03 15:38:00+03	86800.00
F68CD6	2017-07-05 06:17:00+03	91500.00
F68CD7	2017-07-15 06:41:00+03	24700.00
F68CE2	2017-08-05 18:28:00+03	88000.00
F68CEF	2017-07-03 18:46:00+03	31000.00
F68D13	2017-07-09 09:06:00+03	56000.00
F68D59	2017-08-02 16:07:00+03	246000.00
F68D6C	2017-08-13 06:03:00+03	13400.00
F68D9C	2017-07-07 10:25:00+03	12700.00
F68DF1	2017-07-22 17:31:00+03	92400.00
F68E6B	2017-08-04 21:01:00+03	56000.00
F68E6D	2017-07-21 05:27:00+03	93800.00
F68E81	2017-07-04 05:40:00+03	369000.00
F68E8A	2017-07-07 11:52:00+03	301800.00
F68EA0	2017-07-30 08:16:00+03	28800.00
F68EE0	2017-07-24 04:46:00+03	136200.00
F68F0A	2017-08-03 21:56:00+03	39500.00
F68F46	2017-08-14 06:12:00+03	103500.00
F68F56	2017-07-05 15:05:00+03	56600.00
F68F9F	2017-08-08 16:36:00+03	42700.00
F6905A	2017-07-09 14:49:00+03	57700.00
F690B8	2017-08-15 14:39:00+03	28000.00
F69106	2017-08-14 06:32:00+03	29600.00
F69173	2017-08-08 20:59:00+03	90200.00
F69216	2017-07-17 09:38:00+03	23900.00
F6925A	2017-07-13 10:28:00+03	48500.00
F69284	2017-08-07 08:55:00+03	47800.00
F69293	2017-08-06 23:25:00+03	28000.00
F692F0	2017-08-02 13:06:00+03	47100.00
F692F6	2017-07-07 05:23:00+03	43200.00
F69373	2017-08-06 09:48:00+03	54000.00
F69377	2017-07-28 15:13:00+03	282000.00
F69382	2017-07-05 01:32:00+03	16400.00
F693A7	2017-08-10 13:44:00+03	270600.00
F693B4	2017-07-08 04:58:00+03	24400.00
F693E3	2017-07-19 13:40:00+03	393800.00
F69444	2017-08-15 17:12:00+03	23600.00
F6946C	2017-07-03 06:20:00+03	25600.00
F694C6	2017-07-31 08:50:00+03	24400.00
F695A0	2017-07-23 18:18:00+03	58200.00
F695C7	2017-08-12 09:54:00+03	72200.00
F69613	2017-07-19 18:08:00+03	52000.00
F696CF	2017-07-23 00:21:00+03	136800.00
F6973E	2017-08-04 16:11:00+03	66600.00
F697A8	2017-08-15 11:12:00+03	30200.00
F697BC	2017-07-10 06:51:00+03	186900.00
F69800	2017-08-14 21:38:00+03	8000.00
F698B1	2017-07-08 15:48:00+03	59800.00
F698BC	2017-07-07 03:34:00+03	19800.00
F698F0	2017-07-14 23:33:00+03	20200.00
F6998B	2017-07-27 01:17:00+03	27200.00
F6998E	2017-08-01 16:39:00+03	23400.00
F699AC	2017-08-07 04:08:00+03	59300.00
F699F4	2017-07-04 04:47:00+03	52800.00
F69AAC	2017-06-29 16:40:00+03	33300.00
F69AFE	2017-07-02 18:52:00+03	50400.00
F69B4D	2017-07-14 10:22:00+03	28600.00
F69B5B	2017-08-15 00:59:00+03	12400.00
F69B63	2017-07-29 06:35:00+03	32800.00
F69B6E	2017-07-28 09:04:00+03	36400.00
F69B70	2017-07-07 04:05:00+03	21800.00
F69B73	2017-08-11 07:10:00+03	56000.00
F69B8D	2017-07-27 22:33:00+03	62100.00
F69C1B	2017-07-03 21:46:00+03	15000.00
F69C62	2017-07-21 05:41:00+03	106200.00
F69C70	2017-07-04 23:49:00+03	174900.00
F69C77	2017-07-11 08:43:00+03	28000.00
F69C8C	2017-07-31 09:57:00+03	39800.00
F69CC5	2017-08-07 20:27:00+03	112600.00
F69CF7	2017-07-09 15:30:00+03	66000.00
F69D19	2017-07-29 03:27:00+03	155600.00
F69D27	2017-08-11 10:31:00+03	78100.00
F69D32	2017-07-30 15:50:00+03	20000.00
F69E1A	2017-07-19 20:23:00+03	69600.00
F69E54	2017-08-04 19:58:00+03	55800.00
F69E6A	2017-08-14 14:08:00+03	139700.00
F69E8B	2017-07-08 10:35:00+03	14400.00
F69EA5	2017-07-12 02:22:00+03	37600.00
F69EBD	2017-07-17 20:58:00+03	63000.00
F69EF9	2017-08-08 17:27:00+03	189800.00
F69F20	2017-08-07 04:34:00+03	34000.00
F69FE8	2017-07-31 06:44:00+03	123000.00
F6A03C	2017-07-15 00:16:00+03	92400.00
F6A046	2017-07-31 06:46:00+03	38400.00
F6A0E2	2017-07-28 16:44:00+03	40800.00
F6A0E5	2017-07-10 17:02:00+03	207400.00
F6A0E8	2017-07-29 23:18:00+03	46200.00
F6A110	2017-08-15 12:51:00+03	28000.00
F6A184	2017-07-26 03:05:00+03	28000.00
F6A196	2017-07-15 20:21:00+03	74800.00
F6A1EA	2017-07-20 23:08:00+03	37100.00
F6A1EB	2017-07-28 00:50:00+03	27800.00
F6A24D	2017-08-07 21:16:00+03	44600.00
F6A256	2017-08-15 12:50:00+03	38400.00
F6A280	2017-07-06 13:10:00+03	257500.00
F6A2A6	2017-08-03 07:42:00+03	265700.00
F6A2DD	2017-08-09 15:10:00+03	36200.00
F6A31C	2017-07-20 00:29:00+03	48300.00
F6A361	2017-07-11 03:09:00+03	30000.00
F6A38B	2017-07-28 23:27:00+03	67600.00
F6A3B2	2017-08-09 05:38:00+03	7400.00
F6A407	2017-07-19 10:39:00+03	37100.00
F6A425	2017-07-24 00:52:00+03	48800.00
F6A479	2017-07-07 06:30:00+03	19600.00
F6A488	2017-07-31 21:08:00+03	40000.00
F6A4A8	2017-07-30 16:19:00+03	128900.00
F6A4F9	2017-07-21 15:35:00+03	133200.00
F6A51A	2017-08-01 06:40:00+03	23200.00
F6A5A9	2017-07-25 18:35:00+03	15800.00
F6A5CA	2017-08-11 15:56:00+03	131800.00
F6A658	2017-07-24 00:09:00+03	30700.00
F6A677	2017-08-11 04:10:00+03	118100.00
F6A68B	2017-07-13 17:18:00+03	26000.00
F6A6BC	2017-07-29 00:54:00+03	73600.00
F6A6CB	2017-07-31 13:37:00+03	142200.00
F6A758	2017-07-01 14:06:00+03	256700.00
F6A75B	2017-08-06 23:41:00+03	58200.00
F6A768	2017-08-08 04:45:00+03	32800.00
F6A77C	2017-07-15 21:14:00+03	23200.00
F6A7DD	2017-07-07 11:03:00+03	229600.00
F6A7F2	2017-07-16 16:34:00+03	81200.00
F6A813	2017-07-03 22:39:00+03	142000.00
F6A847	2017-08-15 11:49:00+03	46000.00
F6A90D	2017-07-02 01:35:00+03	47200.00
F6A93C	2017-07-27 15:23:00+03	64100.00
F6A98B	2017-07-23 12:01:00+03	56000.00
F6AA04	2017-07-09 01:07:00+03	85000.00
F6AA16	2017-07-20 11:33:00+03	8000.00
F6AA4D	2017-07-13 21:52:00+03	56000.00
F6AABF	2017-07-24 15:11:00+03	14400.00
F6AAE3	2017-07-14 05:50:00+03	27900.00
F6AAE6	2017-07-31 13:44:00+03	143400.00
F6AB36	2017-07-06 21:42:00+03	12600.00
F6AB68	2017-07-08 05:15:00+03	92800.00
F6AB9F	2017-07-17 20:57:00+03	377100.00
F6ABB0	2017-08-07 04:52:00+03	246000.00
F6ABE2	2017-08-11 19:52:00+03	36500.00
F6ABED	2017-07-21 16:06:00+03	43500.00
F6AC43	2017-07-23 21:48:00+03	56000.00
F6AC87	2017-07-31 16:19:00+03	6800.00
F6ACE3	2017-07-29 04:06:00+03	60200.00
F6AD15	2017-07-26 21:52:00+03	40600.00
F6AD2A	2017-07-22 05:22:00+03	46400.00
F6AD78	2017-07-25 14:00:00+03	51200.00
F6AE50	2017-08-05 11:20:00+03	86200.00
F6AEA0	2017-07-11 17:36:00+03	398500.00
F6AEBB	2017-07-15 04:53:00+03	149700.00
F6AEFA	2017-08-10 04:18:00+03	22600.00
F6AF27	2017-07-15 10:25:00+03	14000.00
F6AFA5	2017-07-22 03:59:00+03	23100.00
F6AFCE	2017-08-05 14:40:00+03	54800.00
F6B001	2017-07-13 04:55:00+03	46400.00
F6B01D	2017-07-24 07:41:00+03	114700.00
F6B044	2017-08-13 06:34:00+03	133200.00
F6B04B	2017-07-27 06:50:00+03	46300.00
F6B0BA	2017-07-18 01:37:00+03	46400.00
F6B100	2017-08-14 03:51:00+03	67200.00
F6B155	2017-06-28 10:30:00+03	28800.00
F6B1A4	2017-08-11 08:00:00+03	76200.00
F6B1A7	2017-08-14 10:28:00+03	136200.00
F6B22D	2017-07-05 18:45:00+03	187600.00
F6B2C7	2017-07-02 22:50:00+03	6000.00
F6B2EB	2017-08-07 19:42:00+03	76400.00
F6B2F6	2017-07-26 16:33:00+03	27900.00
F6B34A	2017-07-30 06:41:00+03	117200.00
F6B3C9	2017-07-24 12:33:00+03	24400.00
F6B42F	2017-08-11 10:51:00+03	23200.00
F6B432	2017-07-14 09:39:00+03	44800.00
F6B442	2017-08-14 23:23:00+03	147000.00
F6B455	2017-07-24 07:17:00+03	48800.00
F6B4D3	2017-07-29 23:03:00+03	45200.00
F6B4FB	2017-08-10 13:18:00+03	57600.00
F6B511	2017-08-11 22:01:00+03	11100.00
F6B54B	2017-08-01 22:06:00+03	58800.00
F6B5A9	2017-07-26 02:18:00+03	54000.00
F6B5B7	2017-08-08 11:35:00+03	28800.00
F6B5E7	2017-07-13 02:05:00+03	46300.00
F6B5F7	2017-07-10 09:00:00+03	283100.00
F6B605	2017-06-30 15:44:00+03	194200.00
F6B60A	2017-07-31 20:07:00+03	67400.00
F6B610	2017-08-11 17:50:00+03	55800.00
F6B63E	2017-07-25 21:32:00+03	37900.00
F6B661	2017-08-07 15:05:00+03	28800.00
F6B724	2017-07-30 14:10:00+03	54800.00
F6B741	2017-07-06 05:48:00+03	20200.00
F6B77C	2017-08-15 17:11:00+03	48200.00
F6B794	2017-08-01 00:51:00+03	90800.00
F6B8BB	2017-07-21 21:40:00+03	87400.00
F6B90A	2017-07-18 19:55:00+03	27300.00
F6B927	2017-07-01 23:38:00+03	19600.00
F6B9CE	2017-07-31 09:34:00+03	62900.00
F6B9D4	2017-08-10 12:23:00+03	65400.00
F6BAA2	2017-08-13 19:43:00+03	56000.00
F6BB04	2017-08-11 23:08:00+03	24800.00
F6BBC1	2017-07-31 01:10:00+03	135000.00
F6BC1C	2017-07-30 13:53:00+03	89200.00
F6BCFC	2017-08-04 00:56:00+03	93600.00
F6BCFE	2017-07-03 06:25:00+03	48800.00
F6BD3A	2017-08-15 16:56:00+03	36200.00
F6BD52	2017-07-13 11:50:00+03	97800.00
F6BE05	2017-07-19 23:05:00+03	102100.00
F6BE24	2017-08-11 20:59:00+03	62800.00
F6BE28	2017-07-20 03:53:00+03	81700.00
F6BE63	2017-08-08 14:11:00+03	26000.00
F6BF42	2017-08-14 04:46:00+03	75300.00
F6BF6D	2017-07-14 22:12:00+03	56000.00
F6BF6F	2017-08-02 20:15:00+03	34600.00
F6BFBC	2017-08-04 19:03:00+03	491600.00
F6BFF0	2017-07-22 03:21:00+03	48700.00
F6C076	2017-08-15 04:22:00+03	62100.00
F6C17F	2017-08-03 01:12:00+03	29600.00
F6C1C0	2017-08-02 04:11:00+03	148300.00
F6C1D0	2017-07-28 21:35:00+03	135600.00
F6C1DE	2017-07-03 20:57:00+03	39600.00
F6C1E1	2017-07-19 20:13:00+03	25200.00
F6C25C	2017-07-11 14:15:00+03	6800.00
F6C261	2017-07-13 09:29:00+03	246000.00
F6C26A	2017-07-25 12:09:00+03	61900.00
F6C2FA	2017-08-04 16:37:00+03	28000.00
F6C320	2017-07-15 16:31:00+03	65000.00
F6C326	2017-07-24 03:17:00+03	69500.00
F6C33B	2017-08-13 15:32:00+03	153200.00
F6C347	2017-07-06 02:27:00+03	85000.00
F6C379	2017-07-08 10:02:00+03	135600.00
F6C389	2017-07-03 22:40:00+03	58600.00
F6C3CD	2017-07-19 20:04:00+03	384800.00
F6C3D3	2017-07-30 05:51:00+03	214900.00
F6C3D8	2017-08-06 05:13:00+03	36800.00
F6C426	2017-07-29 18:58:00+03	49800.00
F6C494	2017-08-12 05:58:00+03	95600.00
F6C4F0	2017-07-09 10:54:00+03	23200.00
F6C53C	2017-08-11 12:18:00+03	375200.00
F6C546	2017-07-15 10:38:00+03	136800.00
F6C5A0	2017-08-10 01:41:00+03	36400.00
F6C5C2	2017-07-03 04:56:00+03	22000.00
F6C661	2017-06-30 09:31:00+03	75300.00
F6C6C6	2017-07-16 18:40:00+03	85400.00
F6C6D6	2017-07-26 02:26:00+03	55800.00
F6C72B	2017-08-02 14:10:00+03	40800.00
F6C73B	2017-07-20 20:33:00+03	65900.00
F6C7A1	2017-08-03 14:37:00+03	92800.00
F6C7C7	2017-08-15 02:40:00+03	80500.00
F6C7D2	2017-07-07 00:26:00+03	42800.00
F6C7DD	2017-07-01 14:26:00+03	70600.00
F6C7FD	2017-07-02 11:02:00+03	65500.00
F6C808	2017-07-20 05:50:00+03	37100.00
F6C843	2017-07-26 20:50:00+03	85600.00
F6C862	2017-07-21 13:38:00+03	247300.00
F6C887	2017-07-03 05:51:00+03	23200.00
F6C88B	2017-08-09 04:08:00+03	114800.00
F6C8CE	2017-07-31 05:51:00+03	45200.00
F6C90E	2017-08-08 18:55:00+03	80800.00
F6C98D	2017-07-20 08:52:00+03	381400.00
F6C9DF	2017-07-13 06:49:00+03	20400.00
F6CA08	2017-07-22 23:07:00+03	46200.00
F6CA69	2017-07-15 22:17:00+03	47200.00
F6CA88	2017-06-30 10:14:00+03	24800.00
F6CB84	2017-08-09 15:20:00+03	179400.00
F6CC24	2017-07-28 17:03:00+03	104500.00
F6CC60	2017-08-05 05:02:00+03	88400.00
F6CC68	2017-08-01 04:19:00+03	19800.00
F6CC69	2017-07-29 19:37:00+03	16400.00
F6CCE5	2017-07-20 19:33:00+03	55800.00
F6CD05	2017-07-26 15:46:00+03	24700.00
F6CD51	2017-07-24 13:41:00+03	10600.00
F6CD7B	2017-08-15 10:07:00+03	13400.00
F6CD7E	2017-07-10 14:03:00+03	93900.00
F6CDA0	2017-07-24 09:52:00+03	307800.00
F6CDBE	2017-07-11 03:16:00+03	50400.00
F6CE9C	2017-07-08 15:54:00+03	58200.00
F6CF23	2017-08-13 13:26:00+03	241600.00
F6CF5E	2017-08-09 11:04:00+03	54000.00
F6CF61	2017-07-20 13:54:00+03	39300.00
F6CF7B	2017-07-29 23:56:00+03	46400.00
F6CFFF	2017-07-31 04:57:00+03	85000.00
F6D018	2017-08-15 05:37:00+03	37900.00
F6D071	2017-07-07 10:32:00+03	86800.00
F6D0A8	2017-07-05 04:09:00+03	55800.00
F6D0FA	2017-07-16 03:22:00+03	6800.00
F6D106	2017-07-20 07:17:00+03	229000.00
F6D124	2017-08-15 08:30:00+03	131600.00
F6D12E	2017-07-08 21:35:00+03	680800.00
F6D16B	2017-07-18 18:40:00+03	69900.00
F6D1A7	2017-08-13 17:36:00+03	132800.00
F6D1AB	2017-07-14 21:08:00+03	50100.00
F6D218	2017-08-14 09:55:00+03	61800.00
F6D220	2017-07-06 03:58:00+03	120000.00
F6D236	2017-06-30 07:36:00+03	35200.00
F6D253	2017-08-13 03:10:00+03	39800.00
F6D28B	2017-07-28 14:35:00+03	17600.00
F6D2CF	2017-06-27 17:09:00+03	26800.00
F6D330	2017-07-27 16:53:00+03	50800.00
F6D342	2017-07-25 00:13:00+03	40400.00
F6D349	2017-08-12 05:34:00+03	43000.00
F6D356	2017-07-26 01:40:00+03	26000.00
F6D3AD	2017-07-18 17:15:00+03	21400.00
F6D40C	2017-07-23 06:52:00+03	92600.00
F6D413	2017-08-14 18:10:00+03	192900.00
F6D418	2017-07-04 14:07:00+03	48700.00
F6D438	2017-08-08 08:18:00+03	90800.00
F6D456	2017-08-07 11:45:00+03	65900.00
F6D45B	2017-08-04 15:08:00+03	34000.00
F6D460	2017-08-03 01:33:00+03	28000.00
F6D4CC	2017-07-27 20:44:00+03	21400.00
F6D4D0	2017-07-30 09:14:00+03	34000.00
F6D589	2017-08-13 03:15:00+03	31400.00
F6D5F7	2017-07-13 03:52:00+03	14400.00
F6D65A	2017-07-02 01:35:00+03	55800.00
F6D68C	2017-07-27 19:52:00+03	25600.00
F6D695	2017-08-11 21:19:00+03	58800.00
F6D69C	2017-06-30 22:42:00+03	59000.00
F6D6B3	2017-07-14 17:15:00+03	23200.00
F6D744	2017-08-15 00:43:00+03	43900.00
F6D779	2017-08-08 02:54:00+03	36600.00
F6D795	2017-08-04 04:24:00+03	68600.00
F6D7AC	2017-07-08 06:09:00+03	75600.00
F6D816	2017-08-02 09:48:00+03	146300.00
F6D81D	2017-07-25 12:23:00+03	248300.00
F6D839	2017-07-09 22:04:00+03	99300.00
F6D87D	2017-08-02 05:57:00+03	46400.00
F6D88A	2017-06-30 13:20:00+03	40000.00
F6D8B3	2017-07-12 14:48:00+03	31100.00
F6D8BC	2017-07-05 21:38:00+03	24400.00
F6D8FD	2017-08-01 09:26:00+03	44800.00
F6D936	2017-07-15 17:46:00+03	13400.00
F6D988	2017-07-21 08:10:00+03	114800.00
F6D99C	2017-07-15 03:24:00+03	67200.00
F6D9D8	2017-08-05 12:03:00+03	23200.00
F6D9DF	2017-07-06 03:07:00+03	173900.00
F6DA44	2017-07-31 13:43:00+03	40400.00
F6DA45	2017-07-29 07:01:00+03	55800.00
F6DA57	2017-08-09 00:16:00+03	71200.00
F6DA8F	2017-08-10 07:43:00+03	26000.00
F6DB00	2017-07-22 13:05:00+03	61900.00
F6DB95	2017-07-03 23:26:00+03	13800.00
F6DBE6	2017-08-02 12:12:00+03	209700.00
F6DC02	2017-08-04 07:08:00+03	98400.00
F6DC2D	2017-07-11 16:14:00+03	47400.00
F6DC2E	2017-08-08 16:14:00+03	38600.00
F6DCB6	2017-07-23 23:14:00+03	24300.00
F6DCBF	2017-07-17 10:17:00+03	217600.00
F6DCC3	2017-07-12 10:06:00+03	23200.00
F6DD03	2017-07-28 11:14:00+03	29600.00
F6DD0B	2017-08-01 22:17:00+03	26000.00
F6DDC7	2017-08-01 12:00:00+03	64800.00
F6DDFF	2017-07-27 18:09:00+03	147400.00
F6DE4F	2017-08-06 11:11:00+03	126300.00
F6DE74	2017-07-06 02:36:00+03	36200.00
F6DE8F	2017-07-01 16:18:00+03	58500.00
F6DEF2	2017-07-26 07:18:00+03	6700.00
F6DF5E	2017-08-14 08:46:00+03	16000.00
F6DF6E	2017-07-25 18:18:00+03	7400.00
F6DFC9	2017-07-18 23:24:00+03	115900.00
F6DFCD	2017-08-09 16:01:00+03	103900.00
F6DFDD	2017-08-06 10:46:00+03	30000.00
F6DFEE	2017-07-18 04:25:00+03	61800.00
F6E02F	2017-08-13 20:17:00+03	8000.00
F6E068	2017-07-22 04:24:00+03	8000.00
F6E09D	2017-08-02 06:03:00+03	37900.00
F6E0FA	2017-07-24 02:01:00+03	413400.00
F6E121	2017-07-16 17:38:00+03	75600.00
F6E139	2017-07-22 00:51:00+03	62000.00
F6E1AA	2017-07-02 18:39:00+03	136800.00
F6E208	2017-07-01 12:13:00+03	70700.00
F6E246	2017-08-06 08:51:00+03	11800.00
F6E2AC	2017-07-18 11:34:00+03	46300.00
F6E2B9	2017-08-04 18:29:00+03	59800.00
F6E2CB	2017-08-13 21:15:00+03	28000.00
F6E2D4	2017-07-04 18:49:00+03	111600.00
F6E2F0	2017-07-08 04:42:00+03	28000.00
F6E313	2017-07-08 12:01:00+03	124300.00
F6E31E	2017-07-14 13:40:00+03	32400.00
F6E454	2017-07-16 00:37:00+03	15100.00
F6E49B	2017-07-12 14:21:00+03	26800.00
F6E4C4	2017-08-04 00:29:00+03	246000.00
F6E52A	2017-07-17 06:46:00+03	240500.00
F6E52B	2017-07-06 17:05:00+03	35200.00
F6E597	2017-07-26 23:13:00+03	11600.00
F6E5F9	2017-08-12 11:08:00+03	198200.00
F6E607	2017-07-11 16:03:00+03	78800.00
F6E62B	2017-07-02 23:15:00+03	40100.00
F6E630	2017-08-09 11:39:00+03	134000.00
F6E632	2017-07-15 20:12:00+03	285200.00
F6E645	2017-08-05 16:26:00+03	33600.00
F6E6C4	2017-08-09 06:01:00+03	49600.00
F6E6E1	2017-07-10 15:05:00+03	32800.00
F6E6E2	2017-07-30 10:29:00+03	138000.00
F6E736	2017-08-06 04:11:00+03	29600.00
F6E7A1	2017-07-30 15:47:00+03	64600.00
F6E7BC	2017-08-09 11:47:00+03	72400.00
F6E827	2017-07-08 15:20:00+03	89100.00
F6E831	2017-07-23 10:50:00+03	43800.00
F6E83D	2017-07-07 03:48:00+03	43000.00
F6E84C	2017-06-28 15:26:00+03	65900.00
F6E873	2017-07-13 02:15:00+03	26000.00
F6E8B0	2017-06-30 10:54:00+03	101200.00
F6E92D	2017-07-04 18:15:00+03	42400.00
F6E948	2017-07-28 03:12:00+03	13800.00
F6E950	2017-07-24 09:35:00+03	68400.00
F6E97C	2017-07-22 22:16:00+03	26000.00
F6E992	2017-07-15 13:41:00+03	271100.00
F6E9AC	2017-08-07 18:32:00+03	22000.00
F6EA14	2017-08-08 09:59:00+03	23600.00
F6EA3B	2017-06-30 23:25:00+03	179500.00
F6EA62	2017-08-12 11:25:00+03	47600.00
F6EAA4	2017-07-06 12:17:00+03	37900.00
F6EB4A	2017-08-03 09:28:00+03	139400.00
F6EB55	2017-07-04 17:44:00+03	57400.00
F6EB66	2017-08-02 10:40:00+03	12000.00
F6EC65	2017-08-07 13:31:00+03	81600.00
F6EDB0	2017-07-05 11:38:00+03	143600.00
F6EE60	2017-08-10 08:39:00+03	379000.00
F6EE9A	2017-07-17 01:07:00+03	23400.00
F6EEBB	2017-08-12 23:33:00+03	13200.00
F6EF92	2017-08-15 08:37:00+03	15900.00
F6EFA4	2017-07-15 15:18:00+03	32800.00
F6EFC3	2017-08-05 07:51:00+03	21200.00
F6EFD2	2017-08-15 05:42:00+03	44500.00
F6F02C	2017-07-18 03:35:00+03	68900.00
F6F038	2017-08-08 15:53:00+03	23200.00
F6F05E	2017-07-13 23:59:00+03	23200.00
F6F087	2017-08-12 14:28:00+03	55800.00
F6F0C2	2017-08-07 16:34:00+03	9200.00
F6F14C	2017-07-15 20:08:00+03	38400.00
F6F161	2017-07-11 04:18:00+03	54000.00
F6F163	2017-08-07 22:56:00+03	14000.00
F6F1D9	2017-07-29 19:27:00+03	81600.00
F6F1F0	2017-07-06 02:17:00+03	66000.00
F6F202	2017-08-03 00:57:00+03	26000.00
F6F290	2017-08-09 07:46:00+03	59600.00
F6F2BF	2017-07-27 13:27:00+03	56000.00
F6F2C7	2017-08-03 11:55:00+03	100600.00
F6F2D9	2017-08-09 04:33:00+03	53300.00
F6F31A	2017-07-06 18:11:00+03	28800.00
F6F327	2017-08-07 02:52:00+03	56000.00
F6F338	2017-08-14 16:42:00+03	92100.00
F6F33F	2017-07-23 05:36:00+03	134400.00
F6F36A	2017-07-16 14:14:00+03	75600.00
F6F430	2017-08-02 18:59:00+03	71200.00
F6F450	2017-07-19 11:32:00+03	58400.00
F6F4CF	2017-07-05 14:21:00+03	57600.00
F6F57E	2017-07-11 05:40:00+03	28800.00
F6F59C	2017-07-08 02:40:00+03	10800.00
F6F5AB	2017-07-15 03:52:00+03	6000.00
F6F6C9	2017-07-14 04:19:00+03	56000.00
F6F6E8	2017-07-13 00:07:00+03	45400.00
F6F754	2017-07-11 16:09:00+03	42800.00
F6F7B2	2017-07-01 04:42:00+03	119700.00
F6F7B4	2017-07-07 16:15:00+03	62600.00
F6F7F8	2017-07-20 10:48:00+03	46500.00
F6F853	2017-07-30 20:15:00+03	40800.00
F6F88C	2017-06-30 02:19:00+03	36200.00
F6F8F3	2017-08-02 06:20:00+03	115900.00
F6F8F8	2017-07-04 14:01:00+03	75300.00
F6F8FA	2017-07-29 12:24:00+03	155600.00
F6F8FD	2017-08-04 08:25:00+03	28800.00
F6F950	2017-07-23 22:15:00+03	167500.00
F6FA22	2017-07-21 12:48:00+03	28800.00
F6FA6B	2017-07-27 12:58:00+03	113500.00
F6FAC1	2017-07-25 17:16:00+03	62300.00
F6FAD5	2017-07-04 12:54:00+03	77200.00
F6FAFA	2017-07-03 22:34:00+03	47400.00
F6FB4A	2017-08-05 16:25:00+03	46200.00
F6FBA2	2017-08-09 14:48:00+03	95000.00
F6FBAA	2017-08-02 10:59:00+03	44500.00
F6FBAE	2017-08-10 04:12:00+03	51200.00
F6FBAF	2017-08-03 12:55:00+03	123600.00
F6FC09	2017-07-31 14:10:00+03	59500.00
F6FC5F	2017-07-25 02:19:00+03	86600.00
F6FC70	2017-08-15 04:13:00+03	144400.00
F6FC73	2017-07-01 17:22:00+03	79200.00
F6FC75	2017-07-17 08:08:00+03	94700.00
F6FCF4	2017-08-08 02:48:00+03	23600.00
F6FD16	2017-08-11 13:48:00+03	55600.00
F6FD3F	2017-07-29 01:08:00+03	28000.00
F6FD87	2017-08-04 09:00:00+03	27800.00
F6FD99	2017-08-01 07:15:00+03	276000.00
F6FDB6	2017-08-06 18:14:00+03	57400.00
F6FDBB	2017-07-26 15:39:00+03	41200.00
F6FDE3	2017-07-19 16:03:00+03	132000.00
F6FE28	2017-07-22 15:24:00+03	137600.00
F6FE2E	2017-07-08 21:07:00+03	38400.00
F6FE71	2017-08-02 10:16:00+03	99300.00
F6FEB7	2017-07-05 15:47:00+03	229000.00
F6FEC3	2017-07-14 15:27:00+03	20400.00
F6FF13	2017-07-24 21:57:00+03	24300.00
F6FF1F	2017-07-28 22:38:00+03	27900.00
F6FF2A	2017-07-06 16:36:00+03	6700.00
F6FF4A	2017-07-27 02:00:00+03	131100.00
F6FF87	2017-07-14 09:27:00+03	51600.00
F6FF9D	2017-08-03 18:52:00+03	50100.00
F6FFBD	2017-07-01 01:48:00+03	396500.00
F7007E	2017-07-23 18:31:00+03	28000.00
F7011D	2017-08-12 00:43:00+03	208500.00
F70123	2017-07-23 16:54:00+03	94000.00
F70195	2017-07-03 07:03:00+03	68400.00
F701D0	2017-07-14 01:29:00+03	24700.00
F7021F	2017-08-09 07:10:00+03	50600.00
F70238	2017-08-14 11:00:00+03	131600.00
F70250	2017-08-07 00:51:00+03	21200.00
F7025B	2017-08-02 10:02:00+03	45100.00
F70269	2017-07-15 15:10:00+03	89200.00
F702A8	2017-08-11 10:01:00+03	24000.00
F702BF	2017-07-16 01:50:00+03	32700.00
F7035F	2017-08-05 16:23:00+03	50100.00
F703D4	2017-07-01 12:03:00+03	41200.00
F70402	2017-08-05 17:09:00+03	272400.00
F7041F	2017-07-30 07:57:00+03	23200.00
F704A0	2017-07-18 12:33:00+03	66100.00
F704C1	2017-07-03 00:37:00+03	49400.00
F70527	2017-07-25 14:34:00+03	48800.00
F7057E	2017-06-27 14:36:00+03	20400.00
F705BF	2017-07-25 18:24:00+03	160200.00
F705FC	2017-07-25 15:24:00+03	51600.00
F70649	2017-07-06 21:24:00+03	112200.00
F70681	2017-08-14 08:58:00+03	43700.00
F706A0	2017-07-05 11:46:00+03	64600.00
F706E2	2017-07-28 04:35:00+03	37900.00
F70722	2017-07-18 21:11:00+03	39300.00
F70730	2017-08-08 21:31:00+03	198400.00
F707CF	2017-08-13 05:00:00+03	194900.00
F7082A	2017-07-04 19:30:00+03	106900.00
F7082C	2017-07-04 03:05:00+03	13400.00
F70831	2017-08-07 08:54:00+03	10800.00
F70890	2017-07-06 22:36:00+03	57800.00
F708C4	2017-07-10 02:33:00+03	111600.00
F708EF	2017-07-25 18:44:00+03	46500.00
F709B9	2017-08-08 02:31:00+03	49800.00
F709C3	2017-08-08 17:59:00+03	136100.00
F709F5	2017-07-07 09:58:00+03	29200.00
F70ACD	2017-08-06 20:57:00+03	131900.00
F70AFB	2017-08-08 21:06:00+03	119400.00
F70B4A	2017-08-08 10:23:00+03	38400.00
F70B7E	2017-08-06 06:52:00+03	81600.00
F70B9D	2017-07-10 17:58:00+03	26000.00
F70BB0	2017-07-28 11:01:00+03	28000.00
F70C13	2017-07-12 00:05:00+03	16400.00
F70CAA	2017-07-29 10:07:00+03	19600.00
F70CCC	2017-07-15 00:20:00+03	142000.00
F70D71	2017-08-06 10:40:00+03	65200.00
F70D9B	2017-07-23 15:11:00+03	165100.00
F70DA8	2017-07-31 01:50:00+03	40800.00
F70DB6	2017-08-04 07:58:00+03	147700.00
F70E3E	2017-07-06 04:54:00+03	28800.00
F70E71	2017-07-25 07:55:00+03	36200.00
F70E9F	2017-08-08 09:42:00+03	55800.00
F70EC6	2017-07-10 14:27:00+03	28000.00
F70EFC	2017-07-08 11:44:00+03	94700.00
F70F18	2017-07-14 13:56:00+03	72200.00
F70F3D	2017-07-15 00:38:00+03	82500.00
F70F51	2017-08-09 05:25:00+03	145300.00
F70F62	2017-08-04 17:44:00+03	159500.00
F70F79	2017-07-19 01:40:00+03	12600.00
F70F97	2017-08-05 03:24:00+03	61800.00
F7101D	2017-07-21 21:11:00+03	12600.00
F7104D	2017-07-24 04:02:00+03	13600.00
F71054	2017-07-25 21:38:00+03	21800.00
F71067	2017-08-04 00:47:00+03	266400.00
F710AD	2017-07-08 14:52:00+03	45900.00
F7113F	2017-08-05 20:24:00+03	156000.00
F7115D	2017-07-17 18:56:00+03	37900.00
F71164	2017-07-19 02:23:00+03	92800.00
F71180	2017-08-07 17:37:00+03	23600.00
F711A9	2017-08-02 18:55:00+03	56000.00
F711B4	2017-08-02 08:08:00+03	32200.00
F711D4	2017-08-09 16:30:00+03	62600.00
F711E2	2017-08-15 01:03:00+03	40600.00
F7122A	2017-07-05 14:00:00+03	146600.00
F71240	2017-07-07 05:26:00+03	23200.00
F7132D	2017-07-28 11:16:00+03	188200.00
F71356	2017-07-12 15:09:00+03	55800.00
F713B5	2017-08-14 06:27:00+03	28300.00
F7144B	2017-08-06 09:28:00+03	102100.00
F71464	2017-08-01 07:18:00+03	6700.00
F7147A	2017-08-14 07:50:00+03	70700.00
F7147E	2017-07-17 20:55:00+03	92000.00
F714A1	2017-07-25 15:40:00+03	26200.00
F714B8	2017-08-09 17:59:00+03	23400.00
F714D8	2017-08-10 10:50:00+03	60200.00
F71607	2017-08-15 03:54:00+03	33300.00
F71613	2017-07-25 08:52:00+03	63200.00
F71665	2017-08-12 23:38:00+03	40300.00
F71668	2017-08-13 13:15:00+03	246000.00
F716D3	2017-07-02 11:58:00+03	10800.00
F716F1	2017-07-21 01:34:00+03	44000.00
F71701	2017-07-13 02:53:00+03	21400.00
F71719	2017-08-01 07:20:00+03	35800.00
F717B4	2017-08-11 15:43:00+03	12600.00
F71821	2017-07-05 09:44:00+03	46000.00
F71897	2017-07-25 04:42:00+03	16800.00
F718B2	2017-07-16 22:28:00+03	6800.00
F718B9	2017-07-26 14:26:00+03	23600.00
F718D5	2017-07-27 20:58:00+03	47800.00
F718E9	2017-07-29 20:17:00+03	19600.00
F71907	2017-08-01 12:08:00+03	46400.00
F71922	2017-07-24 13:15:00+03	88500.00
F71945	2017-07-24 14:16:00+03	130900.00
F71946	2017-08-07 11:13:00+03	26000.00
F719F3	2017-06-26 04:35:00+03	92000.00
F71A0C	2017-08-12 10:50:00+03	37700.00
F71A43	2017-08-08 07:11:00+03	25600.00
F71A6B	2017-07-15 07:47:00+03	124200.00
F71A84	2017-08-03 11:53:00+03	93400.00
F71AEE	2017-07-15 02:35:00+03	86500.00
F71AF5	2017-07-14 12:38:00+03	23200.00
F71B0A	2017-07-30 12:06:00+03	258400.00
F71B2B	2017-07-15 21:41:00+03	37900.00
F71B7B	2017-08-08 04:01:00+03	43500.00
F71BB1	2017-07-30 15:48:00+03	73600.00
F71C2A	2017-07-30 05:07:00+03	41800.00
F71C39	2017-07-24 07:52:00+03	32700.00
F71C78	2017-07-04 15:51:00+03	278400.00
F71C7B	2017-07-24 13:46:00+03	75300.00
F71CB3	2017-08-03 05:03:00+03	68800.00
F71D52	2017-06-29 09:04:00+03	23900.00
F71D55	2017-08-12 09:40:00+03	31800.00
F71D67	2017-07-22 08:39:00+03	424800.00
F71DF0	2017-06-29 12:44:00+03	103200.00
F71E46	2017-08-06 06:14:00+03	66600.00
F71E52	2017-08-04 07:58:00+03	229900.00
F71E6C	2017-08-02 16:24:00+03	15100.00
F71E70	2017-07-23 03:43:00+03	100600.00
F71E81	2017-08-03 15:04:00+03	55600.00
F71E87	2017-08-02 07:53:00+03	133200.00
F71E93	2017-07-04 02:49:00+03	24200.00
F71F22	2017-07-14 11:42:00+03	90400.00
F71F71	2017-07-15 01:00:00+03	81700.00
F71FBB	2017-06-30 14:00:00+03	56600.00
F72018	2017-07-22 00:20:00+03	101200.00
F7201C	2017-07-17 07:21:00+03	57500.00
F72032	2017-07-15 09:01:00+03	37200.00
F72072	2017-07-07 21:14:00+03	34000.00
F7208D	2017-07-20 01:19:00+03	24800.00
F720C7	2017-07-20 06:33:00+03	119800.00
F720DC	2017-07-12 12:25:00+03	31600.00
F72103	2017-07-03 20:28:00+03	81600.00
F72145	2017-07-10 15:29:00+03	25100.00
F7220F	2017-07-07 22:11:00+03	99200.00
F72215	2017-08-10 12:42:00+03	93300.00
F7221A	2017-08-15 07:05:00+03	15000.00
F72250	2017-08-08 20:51:00+03	136600.00
F722C2	2017-08-02 05:28:00+03	12600.00
F722E3	2017-07-25 02:08:00+03	12000.00
F72310	2017-08-13 15:55:00+03	49200.00
F72342	2017-08-08 20:54:00+03	89700.00
F72388	2017-07-04 07:14:00+03	79000.00
F723A4	2017-08-11 22:44:00+03	81300.00
F7241E	2017-08-07 23:24:00+03	120900.00
F7243F	2017-07-09 20:57:00+03	24800.00
F724A0	2017-08-15 07:46:00+03	95700.00
F724E4	2017-07-27 17:56:00+03	26000.00
F72502	2017-07-26 20:25:00+03	54500.00
F72509	2017-07-22 04:44:00+03	36200.00
F72534	2017-07-25 12:27:00+03	42700.00
F72573	2017-08-03 07:07:00+03	68400.00
F725A9	2017-07-15 11:18:00+03	38600.00
F725AA	2017-07-01 23:34:00+03	49600.00
F72632	2017-07-14 15:06:00+03	36200.00
F72638	2017-06-29 20:05:00+03	57500.00
F7265F	2017-08-07 16:01:00+03	42800.00
F72771	2017-08-12 16:50:00+03	36000.00
F7277E	2017-08-10 08:32:00+03	28800.00
F727A9	2017-07-03 15:20:00+03	23400.00
F727CA	2017-07-05 15:26:00+03	25100.00
F727CB	2017-07-28 09:16:00+03	55400.00
F727F2	2017-07-26 05:33:00+03	10700.00
F727FD	2017-08-03 16:02:00+03	73500.00
F7283A	2017-07-29 02:26:00+03	55800.00
F7288B	2017-07-03 10:39:00+03	92000.00
F7291A	2017-08-09 15:20:00+03	66800.00
F72931	2017-08-02 07:01:00+03	58600.00
F7294A	2017-08-12 04:48:00+03	66400.00
F72983	2017-08-01 22:21:00+03	369000.00
F729D0	2017-07-13 09:26:00+03	14400.00
F72A3E	2017-07-17 00:20:00+03	51900.00
F72A58	2017-08-05 20:07:00+03	9800.00
F72A65	2017-08-08 17:13:00+03	52100.00
F72A66	2017-07-07 21:15:00+03	100600.00
F72A67	2017-07-07 11:24:00+03	81600.00
F72AA4	2017-08-12 10:20:00+03	58900.00
F72ACB	2017-07-28 09:27:00+03	277600.00
F72B49	2017-07-28 23:41:00+03	100700.00
F72B5B	2017-08-04 13:59:00+03	39000.00
F72B69	2017-07-28 01:34:00+03	36200.00
F72C1E	2017-07-25 11:55:00+03	246000.00
F72C38	2017-08-04 05:43:00+03	87100.00
F72C65	2017-07-31 15:55:00+03	479000.00
F72CF2	2017-08-13 07:37:00+03	12000.00
F72D0E	2017-07-15 21:23:00+03	48800.00
F72D11	2017-08-06 22:04:00+03	136200.00
F72D14	2017-06-30 01:39:00+03	64100.00
F72DAB	2017-07-23 03:04:00+03	173500.00
F72DE3	2017-07-16 01:02:00+03	101100.00
F72E11	2017-07-11 03:00:00+03	88400.00
F72E30	2017-07-14 16:18:00+03	63800.00
F72E31	2017-07-05 10:42:00+03	80900.00
F72E50	2017-07-28 16:32:00+03	101200.00
F72E68	2017-08-13 10:15:00+03	43600.00
F72E6F	2017-07-11 06:34:00+03	86500.00
F72F23	2017-07-26 04:29:00+03	12000.00
F72F27	2017-07-11 10:19:00+03	34000.00
F72F8D	2017-08-03 13:57:00+03	28000.00
F7301B	2017-08-14 16:00:00+03	92800.00
F7302B	2017-07-03 19:59:00+03	12600.00
F7309F	2017-07-26 00:50:00+03	86300.00
F73128	2017-07-19 19:43:00+03	290400.00
F73171	2017-08-05 16:51:00+03	248100.00
F73178	2017-07-23 11:42:00+03	99300.00
F731A6	2017-07-17 15:14:00+03	32800.00
F731D9	2017-08-09 15:22:00+03	136500.00
F73220	2017-08-10 04:05:00+03	21400.00
F7325D	2017-07-16 05:35:00+03	55900.00
F732D2	2017-07-13 00:54:00+03	57400.00
F73335	2017-07-24 06:15:00+03	67700.00
F73362	2017-07-02 12:05:00+03	32800.00
F7336E	2017-07-17 19:55:00+03	23200.00
F73383	2017-07-04 00:29:00+03	61800.00
F7338B	2017-08-15 14:49:00+03	61400.00
F733DD	2017-07-17 01:31:00+03	46400.00
F73421	2017-07-13 01:34:00+03	40000.00
F7344D	2017-07-15 00:44:00+03	84800.00
F73469	2017-07-22 05:17:00+03	40800.00
F7355C	2017-08-03 01:05:00+03	8400.00
F7359C	2017-08-15 12:13:00+03	35300.00
F735AC	2017-08-12 20:44:00+03	91200.00
F735CC	2017-07-19 05:10:00+03	46300.00
F735E8	2017-07-03 21:20:00+03	102000.00
F735EC	2017-07-25 00:39:00+03	161400.00
F7364A	2017-08-09 21:24:00+03	47200.00
F7364B	2017-07-25 02:30:00+03	584000.00
F73656	2017-07-02 00:55:00+03	38600.00
F73695	2017-07-17 15:18:00+03	73600.00
F736A6	2017-07-12 01:33:00+03	144400.00
F736B9	2017-07-22 20:25:00+03	32200.00
F736CE	2017-07-20 07:14:00+03	57300.00
F736EA	2017-07-12 04:05:00+03	13700.00
F73729	2017-06-26 01:07:00+03	81700.00
F7373B	2017-07-31 22:14:00+03	89200.00
F737EA	2017-07-19 09:48:00+03	372500.00
F737F5	2017-07-01 08:25:00+03	8400.00
F7380B	2017-08-04 17:40:00+03	149700.00
F7388C	2017-07-30 03:09:00+03	64400.00
F73891	2017-07-12 01:19:00+03	74800.00
F73898	2017-07-07 13:25:00+03	320500.00
F738B3	2017-07-18 06:55:00+03	133100.00
F738DC	2017-08-05 01:09:00+03	38600.00
F73983	2017-07-02 11:21:00+03	23400.00
F73A45	2017-08-13 12:16:00+03	73800.00
F73A81	2017-07-11 23:14:00+03	147200.00
F73A86	2017-08-06 11:28:00+03	62700.00
F73AA6	2017-07-09 05:31:00+03	56900.00
F73AEB	2017-07-15 06:06:00+03	95600.00
F73C63	2017-07-04 00:01:00+03	47400.00
F73C8A	2017-06-30 06:03:00+03	52800.00
F73CCF	2017-07-23 05:50:00+03	13700.00
F73D05	2017-07-18 08:54:00+03	57800.00
F73D85	2017-07-10 05:50:00+03	27200.00
F73DA8	2017-06-29 10:12:00+03	13600.00
F73DC1	2017-07-18 15:22:00+03	59800.00
F73E20	2017-08-14 22:47:00+03	58200.00
F73E25	2017-08-04 17:44:00+03	47000.00
F73EE0	2017-07-31 23:06:00+03	23600.00
F73F59	2017-07-21 10:18:00+03	61800.00
F73FD4	2017-08-07 19:35:00+03	75900.00
F73FDF	2017-07-10 16:21:00+03	6700.00
F73FE8	2017-08-15 04:59:00+03	24000.00
F73FF6	2017-08-01 20:34:00+03	33300.00
F7400C	2017-08-10 06:44:00+03	62600.00
F74074	2017-07-04 02:11:00+03	119600.00
F740D1	2017-07-14 00:11:00+03	46000.00
F74125	2017-08-15 11:10:00+03	28000.00
F7416F	2017-07-04 22:57:00+03	153200.00
F741CA	2017-08-13 23:27:00+03	81300.00
F741F5	2017-07-13 10:58:00+03	12000.00
F74284	2017-07-22 15:13:00+03	81600.00
F742B4	2017-08-09 20:51:00+03	48400.00
F74375	2017-07-20 14:11:00+03	20800.00
F743CB	2017-07-01 22:34:00+03	111600.00
F7445C	2017-08-05 01:57:00+03	67700.00
F7448C	2017-07-26 21:47:00+03	25100.00
F74517	2017-08-02 05:48:00+03	16800.00
F745ED	2017-06-30 21:22:00+03	265700.00
F745EF	2017-07-12 07:25:00+03	81600.00
F74658	2017-08-01 02:51:00+03	299200.00
F746AF	2017-08-12 10:18:00+03	40800.00
F746FA	2017-07-25 20:26:00+03	36400.00
F74711	2017-07-21 01:41:00+03	19800.00
F7475F	2017-07-06 02:28:00+03	92000.00
F74836	2017-08-11 23:04:00+03	26700.00
F74876	2017-07-15 16:23:00+03	16400.00
F74906	2017-07-18 19:02:00+03	100900.00
F74958	2017-07-10 04:38:00+03	174400.00
F7497F	2017-08-06 05:42:00+03	52700.00
F74980	2017-07-03 11:24:00+03	55800.00
F749EA	2017-07-25 04:13:00+03	84100.00
F749EF	2017-07-07 19:49:00+03	101200.00
F74A05	2017-08-13 11:53:00+03	134000.00
F74A18	2017-07-30 13:53:00+03	162600.00
F74A24	2017-08-02 00:57:00+03	55800.00
F74A96	2017-07-20 06:56:00+03	65300.00
F74AAA	2017-08-09 08:47:00+03	112600.00
F74B64	2017-08-07 22:58:00+03	248400.00
F74B77	2017-07-20 03:10:00+03	88900.00
F74B7D	2017-07-06 13:50:00+03	65500.00
F74B82	2017-07-10 10:02:00+03	163600.00
F74BCB	2017-06-30 19:48:00+03	47600.00
F74BD2	2017-07-19 02:01:00+03	51600.00
F74C2B	2017-07-08 01:52:00+03	39200.00
F74C52	2017-07-14 18:17:00+03	45100.00
F74C95	2017-07-31 04:56:00+03	43400.00
F74CFC	2017-07-11 16:38:00+03	108500.00
F74DBA	2017-07-24 17:12:00+03	41200.00
F74DE7	2017-07-05 07:26:00+03	43100.00
F74E1C	2017-08-13 20:40:00+03	277000.00
F74E65	2017-07-27 07:57:00+03	75300.00
F74F7F	2017-07-15 14:45:00+03	99700.00
F74FA0	2017-07-26 17:46:00+03	58900.00
F750BC	2017-08-07 07:05:00+03	55900.00
F750D8	2017-07-08 11:31:00+03	42400.00
F750E1	2017-07-26 13:17:00+03	18600.00
F75166	2017-07-19 18:06:00+03	90600.00
F751AB	2017-07-30 01:12:00+03	23600.00
F751C5	2017-07-23 18:22:00+03	19600.00
F75202	2017-07-06 20:26:00+03	149800.00
F75257	2017-06-27 17:36:00+03	56000.00
F7526C	2017-07-31 14:20:00+03	23200.00
F75285	2017-08-10 01:27:00+03	131600.00
F752F7	2017-08-11 02:39:00+03	25800.00
F7531B	2017-07-09 03:34:00+03	33200.00
F75378	2017-07-02 03:38:00+03	56000.00
F75383	2017-07-15 07:01:00+03	25200.00
F7538B	2017-08-07 08:26:00+03	52900.00
F754A1	2017-07-03 02:35:00+03	32700.00
F75531	2017-07-04 22:54:00+03	51300.00
F75561	2017-08-02 17:12:00+03	35900.00
F75584	2017-07-03 11:46:00+03	25200.00
F7559A	2017-07-26 18:11:00+03	56000.00
F755A4	2017-07-13 04:37:00+03	166100.00
F755AF	2017-08-07 21:16:00+03	18600.00
F755E3	2017-07-18 06:56:00+03	18400.00
F75635	2017-07-24 12:05:00+03	90400.00
F7569E	2017-08-07 07:17:00+03	17000.00
F756BD	2017-08-04 10:53:00+03	20400.00
F75772	2017-07-02 20:26:00+03	64700.00
F757A9	2017-08-04 03:08:00+03	90800.00
F757DD	2017-07-17 13:44:00+03	123000.00
F7580A	2017-08-08 18:14:00+03	39800.00
F758AB	2017-08-07 18:42:00+03	23200.00
F758B5	2017-07-07 05:44:00+03	28000.00
F758C1	2017-07-05 02:09:00+03	6800.00
F758EE	2017-07-21 16:37:00+03	158500.00
F75944	2017-06-28 16:49:00+03	85000.00
F7597F	2017-07-24 05:59:00+03	51900.00
F759B0	2017-07-14 00:39:00+03	385700.00
F759F4	2017-07-22 14:29:00+03	36200.00
F75AB5	2017-07-15 17:57:00+03	41200.00
F75AB7	2017-07-11 03:28:00+03	108300.00
F75B90	2017-08-12 13:40:00+03	46800.00
F75BA7	2017-08-06 20:41:00+03	155600.00
F75C74	2017-08-01 12:55:00+03	133100.00
F75C7F	2017-07-16 14:41:00+03	174000.00
F75C95	2017-07-31 04:37:00+03	14000.00
F75D0E	2017-07-27 13:56:00+03	106100.00
F75D27	2017-08-14 12:41:00+03	131100.00
F75D51	2017-08-02 22:13:00+03	31000.00
F75D5B	2017-07-08 14:22:00+03	188000.00
F75D7E	2017-07-31 05:01:00+03	118500.00
F75DC7	2017-07-29 10:17:00+03	56900.00
F75DCB	2017-07-03 17:32:00+03	103200.00
F75E48	2017-07-06 14:38:00+03	83600.00
F75E7E	2017-07-25 09:42:00+03	6800.00
F75EA8	2017-07-27 05:39:00+03	40800.00
F75F1F	2017-07-04 07:27:00+03	57500.00
F75F37	2017-07-16 17:29:00+03	92100.00
F75F3C	2017-07-21 00:53:00+03	6800.00
F75F5B	2017-08-14 14:23:00+03	26200.00
F75FC7	2017-07-23 02:46:00+03	246000.00
F760D4	2017-07-21 20:14:00+03	57600.00
F760DE	2017-07-04 03:35:00+03	39300.00
F76134	2017-07-09 01:03:00+03	73300.00
F7615E	2017-07-11 07:51:00+03	115900.00
F76183	2017-08-09 16:28:00+03	17200.00
F761C3	2017-08-04 02:05:00+03	81300.00
F76249	2017-07-08 08:03:00+03	57500.00
F7626D	2017-07-13 15:58:00+03	68400.00
F76312	2017-07-03 21:47:00+03	46200.00
F76371	2017-06-28 18:09:00+03	289800.00
F763A3	2017-07-15 12:22:00+03	43200.00
F763C8	2017-07-03 21:53:00+03	15000.00
F763D7	2017-07-03 12:31:00+03	56000.00
F763D9	2017-07-08 14:00:00+03	120700.00
F763DA	2017-08-02 17:02:00+03	58700.00
F763EE	2017-06-29 08:36:00+03	70100.00
F76407	2017-06-29 13:23:00+03	73200.00
F76410	2017-07-05 15:40:00+03	6000.00
F76466	2017-07-28 00:57:00+03	36600.00
F76487	2017-08-14 01:13:00+03	29600.00
F764D6	2017-07-09 10:25:00+03	38600.00
F764DB	2017-07-04 05:16:00+03	65400.00
F764DD	2017-07-25 20:32:00+03	67600.00
F76512	2017-07-22 23:36:00+03	27200.00
F76515	2017-07-05 06:39:00+03	67600.00
F76549	2017-08-10 01:07:00+03	55800.00
F765DD	2017-08-10 18:10:00+03	193600.00
F765E1	2017-07-29 22:59:00+03	86600.00
F7662A	2017-08-03 01:54:00+03	29600.00
F7665B	2017-07-07 12:11:00+03	46200.00
F7668B	2017-07-13 22:35:00+03	73600.00
F766FC	2017-08-07 13:39:00+03	396500.00
F76728	2017-07-16 18:44:00+03	23200.00
F76796	2017-08-12 03:58:00+03	40000.00
F767E4	2017-07-08 01:57:00+03	31600.00
F767FF	2017-07-01 20:12:00+03	44600.00
F7684A	2017-08-14 01:34:00+03	155600.00
F76852	2017-07-22 00:41:00+03	21400.00
F7687E	2017-07-04 02:42:00+03	36400.00
F76904	2017-08-01 07:02:00+03	20200.00
F76959	2017-08-09 11:33:00+03	241300.00
F769A2	2017-07-19 13:02:00+03	147000.00
F769EA	2017-08-12 20:46:00+03	299500.00
F76A24	2017-08-03 15:19:00+03	119500.00
F76AF0	2017-07-26 12:04:00+03	27800.00
F76BB8	2017-08-06 17:01:00+03	148800.00
F76BFF	2017-08-04 15:51:00+03	133200.00
F76C0C	2017-07-04 10:19:00+03	65500.00
F76C4B	2017-08-08 14:16:00+03	56600.00
F76C91	2017-07-09 22:08:00+03	90600.00
F76CCD	2017-08-06 22:05:00+03	58000.00
F76CD0	2017-08-14 13:48:00+03	119700.00
F76D11	2017-07-04 00:24:00+03	77600.00
F76D72	2017-07-23 02:13:00+03	14800.00
F76D84	2017-08-14 00:15:00+03	51800.00
F76D93	2017-08-14 17:29:00+03	79800.00
F76D98	2017-07-26 12:47:00+03	73300.00
F76E70	2017-07-16 04:48:00+03	48900.00
F76E9E	2017-07-10 10:12:00+03	63700.00
F76EA4	2017-07-27 00:32:00+03	61800.00
F76EFC	2017-07-09 07:40:00+03	399600.00
F76F3C	2017-07-21 13:22:00+03	28000.00
F76F49	2017-07-12 09:57:00+03	133900.00
F770E2	2017-08-01 18:32:00+03	24800.00
F770EB	2017-07-25 18:19:00+03	28000.00
F770F2	2017-07-24 13:36:00+03	124200.00
F7710C	2017-07-05 02:12:00+03	415300.00
F77186	2017-08-07 21:05:00+03	70800.00
F77199	2017-08-15 07:33:00+03	134400.00
F771AB	2017-07-29 09:20:00+03	18000.00
F77208	2017-07-07 19:18:00+03	147700.00
F772A8	2017-07-26 17:34:00+03	123600.00
F772EA	2017-07-09 02:19:00+03	93300.00
F772ED	2017-07-22 22:46:00+03	147800.00
F77347	2017-07-28 20:56:00+03	24000.00
F7736F	2017-08-13 17:03:00+03	27300.00
F7737B	2017-07-07 04:20:00+03	25600.00
F77393	2017-08-10 06:59:00+03	101800.00
F773E2	2017-07-10 15:15:00+03	55800.00
F77440	2017-08-15 15:37:00+03	78200.00
F77442	2017-07-19 19:47:00+03	16400.00
F7746F	2017-07-11 06:00:00+03	12600.00
F77476	2017-08-13 22:38:00+03	113200.00
F774AC	2017-07-23 08:40:00+03	36200.00
F774D9	2017-07-12 08:37:00+03	67500.00
F774F7	2017-08-03 05:08:00+03	110400.00
F7758B	2017-07-26 22:05:00+03	48100.00
F775C5	2017-07-28 23:43:00+03	62600.00
F77611	2017-08-14 01:34:00+03	25000.00
F77669	2017-08-09 18:17:00+03	35500.00
F776AA	2017-07-13 07:48:00+03	7200.00
F776C6	2017-08-09 16:32:00+03	31600.00
F776EF	2017-07-19 20:04:00+03	95700.00
F7770A	2017-08-12 19:41:00+03	56000.00
F77714	2017-07-28 06:00:00+03	70600.00
F77726	2017-08-09 22:59:00+03	172100.00
F7774E	2017-07-29 10:59:00+03	31600.00
F777C0	2017-07-28 12:21:00+03	57600.00
F7780C	2017-07-22 15:42:00+03	47000.00
F77842	2017-07-12 13:48:00+03	53600.00
F778E3	2017-07-01 01:32:00+03	224400.00
F778EB	2017-07-08 15:39:00+03	48800.00
F7792A	2017-07-25 06:37:00+03	56100.00
F77994	2017-08-08 12:01:00+03	88500.00
F77AD7	2017-07-07 18:54:00+03	18000.00
F77B55	2017-07-21 15:00:00+03	26000.00
F77B68	2017-08-05 05:18:00+03	74400.00
F77B6E	2017-07-28 01:52:00+03	121600.00
F77B7B	2017-07-02 05:32:00+03	14400.00
F77C0D	2017-07-14 22:06:00+03	44700.00
F77C1E	2017-08-08 06:36:00+03	20800.00
F77C4B	2017-07-30 06:12:00+03	66100.00
F77C64	2017-07-29 21:45:00+03	14000.00
F77C9C	2017-08-15 01:10:00+03	30000.00
F77CF4	2017-07-26 07:41:00+03	81600.00
F77CFB	2017-07-23 06:48:00+03	13000.00
F77D1E	2017-07-29 01:45:00+03	17600.00
F77DB0	2017-08-10 15:46:00+03	131900.00
F77DCD	2017-07-21 08:57:00+03	37700.00
F77E70	2017-07-28 02:18:00+03	119900.00
F77E96	2017-06-25 18:31:00+03	147200.00
F77F11	2017-07-13 21:51:00+03	59000.00
F77F93	2017-08-08 20:23:00+03	85000.00
F77F94	2017-07-30 12:25:00+03	61800.00
F78062	2017-08-01 21:41:00+03	47800.00
F780CF	2017-07-03 06:45:00+03	98400.00
F780DF	2017-07-13 04:51:00+03	135400.00
F78125	2017-07-09 05:28:00+03	35800.00
F78159	2017-08-15 10:00:00+03	27900.00
F7819D	2017-08-12 11:50:00+03	248300.00
F7822D	2017-07-30 14:14:00+03	139800.00
F7828F	2017-07-15 18:47:00+03	32700.00
F782AE	2017-08-13 14:48:00+03	49000.00
F7830A	2017-08-08 05:18:00+03	69500.00
F78318	2017-08-10 01:30:00+03	30200.00
F7831A	2017-07-13 10:51:00+03	21400.00
F7834C	2017-07-01 05:18:00+03	13000.00
F783C2	2017-08-01 14:11:00+03	25000.00
F783EC	2017-07-16 03:09:00+03	92800.00
F78418	2017-07-06 05:25:00+03	6000.00
F7842B	2017-07-22 17:32:00+03	162300.00
F784E3	2017-07-28 07:13:00+03	99000.00
F78515	2017-07-26 22:58:00+03	46400.00
F78581	2017-07-30 21:01:00+03	88500.00
F785B2	2017-07-21 03:54:00+03	56900.00
F785E2	2017-07-03 08:00:00+03	153300.00
F7866C	2017-07-25 06:12:00+03	23600.00
F78739	2017-07-20 02:13:00+03	26000.00
F78757	2017-08-02 03:16:00+03	139300.00
F787A4	2017-07-30 00:30:00+03	278200.00
F788C6	2017-07-13 10:26:00+03	128800.00
F7891E	2017-06-30 08:22:00+03	94000.00
F78938	2017-08-14 00:58:00+03	39200.00
F78970	2017-07-14 13:29:00+03	19600.00
F789B6	2017-07-23 06:39:00+03	20600.00
F789CB	2017-08-12 23:25:00+03	47000.00
F78A37	2017-08-11 21:49:00+03	114800.00
F78A46	2017-07-04 13:54:00+03	46500.00
F78AA7	2017-08-08 00:39:00+03	108000.00
F78B35	2017-07-20 22:55:00+03	14400.00
F78B75	2017-07-30 10:32:00+03	82900.00
F78BB9	2017-07-02 06:56:00+03	211100.00
F78BBA	2017-06-30 14:11:00+03	37900.00
F78BBC	2017-08-12 00:24:00+03	23200.00
F78BF5	2017-06-29 21:21:00+03	73600.00
F78C52	2017-08-14 04:34:00+03	14800.00
F78C7E	2017-07-20 00:34:00+03	80700.00
F78C84	2017-07-21 21:34:00+03	35300.00
F78C96	2017-07-10 05:19:00+03	26000.00
F78CE4	2017-07-04 14:36:00+03	67600.00
F78CEC	2017-07-15 22:07:00+03	75600.00
F78CFF	2017-08-13 17:55:00+03	65900.00
F78D52	2017-07-26 03:38:00+03	50800.00
F78D59	2017-07-20 12:22:00+03	54800.00
F78D5C	2017-07-16 08:09:00+03	36200.00
F78DF5	2017-07-13 19:40:00+03	29800.00
F78E3A	2017-07-11 01:59:00+03	64700.00
F78E55	2017-08-06 01:15:00+03	102100.00
F78E5D	2017-06-30 17:58:00+03	32700.00
F78E71	2017-07-08 00:56:00+03	27200.00
F78E7A	2017-07-19 03:56:00+03	31400.00
F78F4D	2017-07-16 03:10:00+03	121500.00
F78F57	2017-07-24 06:55:00+03	56000.00
F78F63	2017-08-10 11:24:00+03	16400.00
F7900C	2017-07-17 23:50:00+03	295100.00
F7901F	2017-07-14 11:30:00+03	35200.00
F7902F	2017-07-10 08:53:00+03	248500.00
F7906B	2017-08-09 11:25:00+03	16400.00
F79100	2017-07-02 18:45:00+03	283100.00
F79246	2017-07-24 03:58:00+03	132800.00
F79253	2017-07-11 19:23:00+03	16800.00
F792E1	2017-07-09 02:58:00+03	136200.00
F79399	2017-07-06 05:06:00+03	81200.00
F793CE	2017-07-17 16:46:00+03	76800.00
F7942B	2017-08-05 02:39:00+03	55800.00
F79462	2017-07-05 13:32:00+03	90800.00
F7946B	2017-08-01 22:49:00+03	18600.00
F794AD	2017-08-05 18:36:00+03	87000.00
F794E4	2017-08-06 21:18:00+03	22000.00
F7953A	2017-08-12 17:18:00+03	67200.00
F7958A	2017-07-19 08:24:00+03	71800.00
F79597	2017-07-06 12:36:00+03	30000.00
F79620	2017-07-22 08:52:00+03	82900.00
F79624	2017-08-02 06:31:00+03	62600.00
F79655	2017-07-31 14:23:00+03	92400.00
F79688	2017-07-28 00:00:00+03	16400.00
F796E2	2017-08-12 04:42:00+03	55700.00
F79705	2017-07-17 16:16:00+03	25000.00
F7970B	2017-07-09 05:16:00+03	8200.00
F79719	2017-07-10 23:35:00+03	73600.00
F7971B	2017-07-20 00:38:00+03	46400.00
F79752	2017-07-14 05:04:00+03	23200.00
F79758	2017-07-22 04:56:00+03	56000.00
F797BB	2017-07-19 11:37:00+03	130200.00
F7986F	2017-07-06 04:04:00+03	134700.00
F798A4	2017-07-17 20:29:00+03	10800.00
F798CE	2017-08-10 14:49:00+03	60700.00
F798D9	2017-07-18 17:02:00+03	57800.00
F79904	2017-07-19 12:51:00+03	112400.00
F79A2E	2017-07-30 08:00:00+03	55800.00
F79A3E	2017-08-12 00:50:00+03	29400.00
F79A8E	2017-08-03 05:09:00+03	201200.00
F79B06	2017-08-15 13:03:00+03	121800.00
F79B10	2017-08-11 19:31:00+03	142300.00
F79B19	2017-07-28 06:54:00+03	46400.00
F79C21	2017-08-09 04:32:00+03	101200.00
F79C8F	2017-07-16 09:30:00+03	25600.00
F79CCA	2017-07-01 07:55:00+03	52400.00
F79CDC	2017-07-24 02:28:00+03	55800.00
F79D15	2017-07-21 11:10:00+03	138100.00
F79D5B	2017-08-11 05:34:00+03	191500.00
F79D8F	2017-08-04 00:34:00+03	40700.00
F79E1D	2017-07-30 11:41:00+03	24400.00
F79E27	2017-07-30 17:18:00+03	46400.00
F79E5F	2017-07-04 17:15:00+03	167400.00
F79ECD	2017-07-26 22:24:00+03	101500.00
F79ED1	2017-08-06 13:04:00+03	25600.00
F79EDE	2017-07-21 00:48:00+03	29600.00
F79EFF	2017-08-13 15:30:00+03	68100.00
F79FCA	2017-08-14 05:09:00+03	136200.00
F79FE3	2017-07-23 21:30:00+03	56000.00
F7A035	2017-08-12 15:02:00+03	126600.00
F7A082	2017-07-24 21:07:00+03	31200.00
F7A08B	2017-07-24 14:14:00+03	55800.00
F7A0B0	2017-07-29 07:50:00+03	154000.00
F7A0D9	2017-07-03 08:33:00+03	53300.00
F7A10F	2017-07-25 08:27:00+03	96300.00
F7A118	2017-07-31 22:44:00+03	48800.00
F7A2B1	2017-08-04 22:27:00+03	27700.00
F7A31B	2017-08-15 09:24:00+03	113200.00
F7A33B	2017-07-18 19:56:00+03	57000.00
F7A3A6	2017-07-06 18:13:00+03	81700.00
F7A401	2017-07-01 07:55:00+03	75600.00
F7A4A6	2017-07-16 19:14:00+03	6800.00
F7A4EC	2017-07-21 14:11:00+03	32800.00
F7A503	2017-07-18 09:52:00+03	27800.00
F7A527	2017-07-15 08:45:00+03	12600.00
F7A531	2017-07-26 16:25:00+03	47200.00
F7A5B9	2017-08-15 12:51:00+03	38400.00
F7A5C8	2017-07-26 14:11:00+03	21800.00
F7A5ED	2017-07-23 16:42:00+03	112400.00
F7A5F6	2017-07-15 20:05:00+03	260900.00
F7A602	2017-07-16 13:06:00+03	32800.00
F7A652	2017-08-09 10:10:00+03	136800.00
F7A675	2017-08-12 23:06:00+03	234700.00
F7A703	2017-07-14 01:49:00+03	94700.00
F7A79C	2017-07-19 08:06:00+03	86600.00
F7A7A0	2017-08-11 12:46:00+03	23400.00
F7A7EF	2017-08-05 01:19:00+03	156000.00
F7A861	2017-07-05 01:46:00+03	25700.00
F7A86E	2017-08-08 07:51:00+03	85000.00
F7A938	2017-07-24 15:59:00+03	235300.00
F7A939	2017-07-14 06:25:00+03	154800.00
F7A940	2017-07-30 01:19:00+03	45200.00
F7A958	2017-07-29 07:17:00+03	34000.00
F7A9E5	2017-07-28 04:46:00+03	188900.00
F7A9E9	2017-07-15 03:55:00+03	55800.00
F7AA2D	2017-07-12 22:25:00+03	34400.00
F7AA68	2017-07-23 10:33:00+03	122100.00
F7AA96	2017-08-02 00:16:00+03	50000.00
F7AAFC	2017-08-09 09:31:00+03	34000.00
F7ACAA	2017-07-11 15:54:00+03	55800.00
F7ACB4	2017-08-06 11:43:00+03	38600.00
F7AD0C	2017-08-10 12:25:00+03	46800.00
F7AD78	2017-08-09 13:19:00+03	66600.00
F7AD8F	2017-07-23 06:14:00+03	111600.00
F7ADAD	2017-08-13 04:48:00+03	101200.00
F7ADC1	2017-08-06 04:44:00+03	42700.00
F7AE52	2017-07-29 20:58:00+03	96800.00
F7AE69	2017-07-26 10:22:00+03	13200.00
F7AE7B	2017-07-30 11:15:00+03	52700.00
F7AECB	2017-08-10 06:35:00+03	40400.00
F7AEF2	2017-07-18 14:24:00+03	169900.00
F7AF11	2017-08-10 01:56:00+03	21000.00
F7AF5E	2017-07-06 09:23:00+03	160100.00
F7AF61	2017-07-27 09:09:00+03	8400.00
F7B031	2017-07-11 20:15:00+03	68100.00
F7B04B	2017-07-07 08:13:00+03	28000.00
F7B072	2017-07-21 10:26:00+03	45400.00
F7B095	2017-07-01 08:53:00+03	30200.00
F7B117	2017-08-13 19:24:00+03	22000.00
F7B195	2017-08-06 08:37:00+03	26200.00
F7B19B	2017-07-12 23:41:00+03	396200.00
F7B1D0	2017-08-03 20:41:00+03	19600.00
F7B230	2017-07-28 02:33:00+03	93000.00
F7B241	2017-07-16 08:36:00+03	62400.00
F7B243	2017-07-25 13:19:00+03	40000.00
F7B26C	2017-08-06 17:03:00+03	88600.00
F7B26F	2017-08-08 09:05:00+03	32500.00
F7B2B0	2017-06-29 18:21:00+03	56000.00
F7B2CB	2017-08-15 12:37:00+03	153800.00
F7B2EA	2017-07-15 05:20:00+03	41600.00
F7B2EE	2017-07-25 18:29:00+03	123000.00
F7B359	2017-07-25 06:27:00+03	50600.00
F7B3B6	2017-07-14 22:38:00+03	78300.00
F7B3C4	2017-07-12 18:01:00+03	21200.00
F7B3CA	2017-07-22 01:40:00+03	47000.00
F7B3F2	2017-07-07 00:44:00+03	290900.00
F7B45D	2017-08-14 14:59:00+03	166100.00
F7B462	2017-07-01 18:55:00+03	63200.00
F7B49B	2017-07-18 05:45:00+03	46400.00
F7B4F1	2017-07-01 15:35:00+03	31600.00
F7B510	2017-07-15 13:02:00+03	31600.00
F7B51A	2017-07-16 16:02:00+03	40800.00
F7B528	2017-07-21 17:26:00+03	40800.00
F7B548	2017-07-17 09:57:00+03	39800.00
F7B558	2017-07-15 19:05:00+03	51400.00
F7B59D	2017-07-21 15:55:00+03	93800.00
F7B5A8	2017-08-14 19:46:00+03	16400.00
F7B5A9	2017-07-20 17:13:00+03	75600.00
F7B63E	2017-07-06 17:58:00+03	160700.00
F7B6B6	2017-08-09 01:50:00+03	40600.00
F7B707	2017-08-13 12:26:00+03	46800.00
F7B723	2017-07-24 06:34:00+03	515100.00
F7B72C	2017-07-20 02:30:00+03	32800.00
F7B7A9	2017-08-02 15:24:00+03	25300.00
F7B7EC	2017-08-08 08:18:00+03	109200.00
F7B812	2017-07-02 16:53:00+03	249700.00
F7B833	2017-08-11 19:26:00+03	41200.00
F7B8A9	2017-07-25 01:34:00+03	30200.00
F7B8DC	2017-07-26 01:06:00+03	28800.00
F7B936	2017-08-09 04:53:00+03	115600.00
F7B98F	2017-07-03 07:50:00+03	13400.00
F7B9A7	2017-07-08 14:19:00+03	12400.00
F7B9CC	2017-08-08 14:06:00+03	37900.00
F7BA0E	2017-07-06 04:32:00+03	28000.00
F7BA6B	2017-08-02 07:53:00+03	206400.00
F7BB01	2017-08-15 04:51:00+03	57500.00
F7BB11	2017-07-25 05:23:00+03	47500.00
F7BB54	2017-08-03 16:45:00+03	16400.00
F7BBD4	2017-08-02 10:51:00+03	32800.00
F7BBF7	2017-07-06 16:40:00+03	177200.00
F7BC50	2017-08-11 03:30:00+03	12000.00
F7BC61	2017-07-28 09:12:00+03	38400.00
F7BC6F	2017-07-14 12:20:00+03	23200.00
F7BCF5	2017-08-08 13:38:00+03	52000.00
F7BD80	2017-07-23 01:15:00+03	100800.00
F7BDEF	2017-08-11 15:31:00+03	175800.00
F7BE2A	2017-08-13 07:51:00+03	16400.00
F7BEA7	2017-07-16 21:45:00+03	31900.00
F7BF26	2017-07-09 17:24:00+03	92100.00
F7BF5D	2017-08-05 13:47:00+03	55800.00
F7BF8D	2017-07-13 00:21:00+03	195900.00
F7C00A	2017-07-14 13:36:00+03	257300.00
F7C078	2017-07-30 02:08:00+03	70100.00
F7C0A1	2017-07-13 02:04:00+03	70600.00
F7C0B5	2017-07-23 14:12:00+03	64500.00
F7C132	2017-08-03 04:05:00+03	26800.00
F7C13B	2017-07-10 20:37:00+03	8000.00
F7C229	2017-07-25 08:23:00+03	406700.00
F7C261	2017-08-04 23:30:00+03	20800.00
F7C2E6	2017-08-05 13:34:00+03	23600.00
F7C2E8	2017-08-04 20:21:00+03	56000.00
F7C339	2017-07-23 06:34:00+03	311600.00
F7C3DA	2017-07-26 09:40:00+03	238300.00
F7C423	2017-07-08 00:06:00+03	13600.00
F7C448	2017-07-17 08:18:00+03	71900.00
F7C487	2017-08-09 23:24:00+03	14400.00
F7C48D	2017-07-06 05:15:00+03	26000.00
F7C494	2017-07-05 20:02:00+03	166000.00
F7C4AE	2017-07-23 13:33:00+03	64800.00
F7C4B8	2017-07-03 05:48:00+03	92600.00
F7C4C5	2017-07-18 01:23:00+03	14400.00
F7C502	2017-07-17 22:40:00+03	85000.00
F7C521	2017-06-29 17:21:00+03	46400.00
F7C538	2017-08-11 04:08:00+03	56000.00
F7C5CF	2017-08-03 07:56:00+03	36200.00
F7C5FA	2017-07-24 01:51:00+03	16400.00
F7C617	2017-07-16 01:15:00+03	42000.00
F7C628	2017-07-15 07:19:00+03	125200.00
F7C62C	2017-08-04 12:55:00+03	26700.00
F7C64F	2017-07-06 20:43:00+03	47200.00
F7C677	2017-07-26 03:40:00+03	42800.00
F7C680	2017-07-13 08:43:00+03	28800.00
F7C68F	2017-07-18 17:05:00+03	111600.00
F7C6A6	2017-07-24 11:54:00+03	64600.00
F7C6F6	2017-07-01 02:00:00+03	48800.00
F7C7CA	2017-07-27 04:03:00+03	57600.00
F7C7EC	2017-08-01 04:19:00+03	59900.00
F7C7F6	2017-07-02 02:28:00+03	24800.00
F7C826	2017-07-18 11:50:00+03	29800.00
F7C87C	2017-07-28 11:31:00+03	133200.00
F7C8B6	2017-07-17 08:09:00+03	43400.00
F7C944	2017-08-01 21:19:00+03	24800.00
F7C983	2017-08-11 14:43:00+03	195600.00
F7CA16	2017-07-10 18:10:00+03	84500.00
F7CA34	2017-08-14 13:41:00+03	15800.00
F7CA5E	2017-07-22 21:51:00+03	61800.00
F7CA67	2017-08-07 17:25:00+03	46300.00
F7CA82	2017-08-09 15:52:00+03	8000.00
F7CAD8	2017-08-08 01:24:00+03	133100.00
F7CC03	2017-07-20 03:25:00+03	16400.00
F7CD0B	2017-07-09 07:20:00+03	66600.00
F7CD31	2017-07-18 08:35:00+03	111000.00
F7CD3B	2017-07-18 22:39:00+03	42800.00
F7CD9E	2017-07-27 06:36:00+03	37600.00
F7CDCC	2017-07-24 18:38:00+03	70200.00
F7CDEB	2017-07-23 11:51:00+03	31600.00
F7CE27	2017-07-07 14:24:00+03	76400.00
F7CE7E	2017-07-11 14:35:00+03	81800.00
F7CF11	2017-07-24 01:00:00+03	58900.00
F7CF2F	2017-07-12 23:41:00+03	28000.00
F7CF67	2017-07-16 20:41:00+03	24400.00
F7CF8A	2017-07-21 00:20:00+03	189200.00
F7CFAB	2017-07-14 10:03:00+03	394800.00
F7D071	2017-07-04 13:22:00+03	38400.00
F7D102	2017-07-24 14:58:00+03	44800.00
F7D11F	2017-07-04 20:22:00+03	141200.00
F7D194	2017-08-14 14:19:00+03	24400.00
F7D1B9	2017-08-04 08:45:00+03	174900.00
F7D1F1	2017-07-22 01:54:00+03	43600.00
F7D231	2017-07-17 21:25:00+03	114800.00
F7D232	2017-07-14 18:36:00+03	6600.00
F7D2F0	2017-07-07 20:32:00+03	79600.00
F7D313	2017-07-01 12:43:00+03	14400.00
F7D366	2017-08-11 14:12:00+03	40100.00
F7D395	2017-07-14 01:21:00+03	329700.00
F7D451	2017-07-09 10:44:00+03	28800.00
F7D454	2017-07-26 20:28:00+03	27800.00
F7D4DB	2017-08-05 22:01:00+03	50100.00
F7D4FD	2017-07-02 21:56:00+03	18000.00
F7D5FB	2017-07-09 15:22:00+03	40800.00
F7D650	2017-07-11 21:45:00+03	56000.00
F7D67E	2017-08-06 13:49:00+03	12600.00
F7D6DC	2017-08-05 14:20:00+03	54600.00
F7D71C	2017-08-15 13:42:00+03	39100.00
F7D728	2017-08-10 09:46:00+03	70800.00
F7D78A	2017-07-10 22:30:00+03	87500.00
F7D796	2017-08-05 06:26:00+03	22600.00
F7D7D7	2017-08-01 11:10:00+03	290400.00
F7D7F6	2017-07-09 16:11:00+03	22000.00
F7D830	2017-08-01 23:39:00+03	107400.00
F7D8CC	2017-07-10 21:04:00+03	40700.00
F7D8D1	2017-07-14 21:22:00+03	89200.00
F7D8F6	2017-07-19 19:26:00+03	21800.00
F7D964	2017-07-26 10:59:00+03	99300.00
F7D9A4	2017-07-07 10:40:00+03	13800.00
F7D9EA	2017-07-06 21:43:00+03	57300.00
F7D9F4	2017-08-05 01:21:00+03	25600.00
F7DA06	2017-08-13 23:29:00+03	58200.00
F7DA53	2017-08-09 21:08:00+03	75000.00
F7DAED	2017-07-09 19:13:00+03	124200.00
F7DB35	2017-07-28 05:24:00+03	112000.00
F7DC09	2017-07-21 05:38:00+03	26700.00
F7DC12	2017-08-05 04:40:00+03	38400.00
F7DCA9	2017-08-05 02:26:00+03	40000.00
F7DD1C	2017-07-07 08:14:00+03	87000.00
F7DD35	2017-07-23 01:29:00+03	13800.00
F7DD4B	2017-08-13 13:00:00+03	89200.00
F7DD81	2017-07-14 14:37:00+03	30400.00
F7DD98	2017-07-14 16:20:00+03	26500.00
F7DDC4	2017-07-15 10:02:00+03	92400.00
F7DDCA	2017-07-11 21:20:00+03	80000.00
F7DDEB	2017-07-06 01:49:00+03	133200.00
F7DE12	2017-07-29 11:14:00+03	40000.00
F7DE66	2017-08-04 22:01:00+03	133200.00
F7DE8C	2017-07-02 09:41:00+03	40100.00
F7DE99	2017-07-29 15:27:00+03	34000.00
F7DEDA	2017-07-09 07:36:00+03	35900.00
F7DF6E	2017-07-07 20:28:00+03	65600.00
F7E010	2017-07-08 20:29:00+03	100000.00
F7E026	2017-07-25 18:27:00+03	258400.00
F7E044	2017-07-30 11:40:00+03	108900.00
F7E070	2017-08-15 14:53:00+03	25600.00
F7E07E	2017-07-20 12:15:00+03	80000.00
F7E0D8	2017-07-13 12:57:00+03	29500.00
F7E0EC	2017-07-20 19:22:00+03	48700.00
F7E125	2017-07-25 07:02:00+03	28800.00
F7E13F	2017-08-13 05:39:00+03	89100.00
F7E14D	2017-08-11 00:39:00+03	86400.00
F7E186	2017-07-31 12:42:00+03	131100.00
F7E1C0	2017-08-05 06:57:00+03	133100.00
F7E1F6	2017-08-14 21:18:00+03	48800.00
F7E204	2017-07-08 16:27:00+03	54400.00
F7E226	2017-07-23 03:19:00+03	203100.00
F7E33B	2017-07-24 16:59:00+03	68100.00
F7E342	2017-07-28 03:15:00+03	6000.00
F7E3A0	2017-07-11 20:16:00+03	40300.00
F7E40C	2017-07-30 01:35:00+03	50400.00
F7E421	2017-07-27 13:42:00+03	100600.00
F7E43D	2017-07-28 02:55:00+03	40800.00
F7E4A2	2017-07-20 11:01:00+03	72400.00
F7E4BA	2017-07-23 23:49:00+03	28000.00
F7E573	2017-08-05 06:46:00+03	113600.00
F7E5A1	2017-07-29 05:08:00+03	30200.00
F7E5AD	2017-08-02 16:28:00+03	67900.00
F7E61D	2017-07-23 13:55:00+03	103900.00
F7E62C	2017-08-08 09:55:00+03	40400.00
F7E656	2017-08-04 09:46:00+03	133700.00
F7E68E	2017-07-10 11:28:00+03	61700.00
F7E69A	2017-08-05 03:42:00+03	40400.00
F7E741	2017-07-02 08:48:00+03	36800.00
F7E7DC	2017-07-18 00:34:00+03	129700.00
F7E7F9	2017-08-12 18:29:00+03	542300.00
F7E82E	2017-07-02 20:39:00+03	13400.00
F7E889	2017-07-22 03:53:00+03	8000.00
F7E91A	2017-08-04 19:23:00+03	13200.00
F7E94F	2017-07-09 05:06:00+03	19800.00
F7E9D2	2017-07-28 09:46:00+03	109000.00
F7E9D4	2017-07-19 05:51:00+03	44800.00
F7EA02	2017-07-22 12:07:00+03	81600.00
F7EA3A	2017-07-29 22:22:00+03	57800.00
F7EA91	2017-07-16 11:05:00+03	49500.00
F7EACE	2017-08-05 19:12:00+03	229900.00
F7EB20	2017-08-08 17:45:00+03	13000.00
F7EB68	2017-07-07 17:25:00+03	198400.00
F7EB6C	2017-07-12 09:49:00+03	75600.00
F7EB7A	2017-08-01 05:34:00+03	109800.00
F7EC2D	2017-08-08 00:29:00+03	25200.00
F7EC4E	2017-07-05 21:39:00+03	53700.00
F7EC62	2017-07-19 12:35:00+03	130400.00
F7ECAA	2017-08-12 00:37:00+03	21800.00
F7ECD4	2017-07-29 06:22:00+03	143100.00
F7ED01	2017-07-28 21:31:00+03	118100.00
F7EDB9	2017-07-27 21:41:00+03	57300.00
F7EDCD	2017-08-11 19:18:00+03	16400.00
F7EE0C	2017-07-09 14:15:00+03	26800.00
F7EE8B	2017-07-10 16:19:00+03	21800.00
F7EF13	2017-07-17 16:59:00+03	35800.00
F7EF58	2017-07-26 21:04:00+03	92800.00
F7EF79	2017-07-04 18:39:00+03	248300.00
F7EF8B	2017-07-13 02:58:00+03	40000.00
F7EFB0	2017-08-04 01:43:00+03	61800.00
F7EFCC	2017-08-15 01:23:00+03	24800.00
F7EFF3	2017-07-23 09:42:00+03	56100.00
F7EFF6	2017-08-06 11:56:00+03	28000.00
F7F035	2017-07-31 17:35:00+03	173300.00
F7F042	2017-07-17 23:00:00+03	93700.00
F7F0C8	2017-07-09 01:47:00+03	67200.00
F7F1A0	2017-08-07 08:00:00+03	67100.00
F7F21E	2017-08-10 00:10:00+03	105200.00
F7F23C	2017-07-15 19:44:00+03	90600.00
F7F25C	2017-07-11 21:17:00+03	39300.00
F7F29E	2017-08-07 16:41:00+03	60400.00
F7F2A3	2017-08-15 13:07:00+03	13400.00
F7F2AA	2017-08-08 10:20:00+03	23200.00
F7F2B8	2017-07-03 19:21:00+03	86200.00
F7F2CE	2017-07-26 05:57:00+03	141300.00
F7F35D	2017-07-15 11:10:00+03	30000.00
F7F423	2017-07-21 06:14:00+03	166100.00
F7F4DE	2017-07-25 01:33:00+03	61800.00
F7F4EA	2017-07-25 18:35:00+03	12600.00
F7F514	2017-08-13 17:29:00+03	88500.00
F7F533	2017-07-31 04:43:00+03	187400.00
F7F54A	2017-07-02 18:17:00+03	35700.00
F7F55F	2017-08-10 12:56:00+03	6800.00
F7F5A2	2017-08-07 22:56:00+03	50200.00
F7F5A4	2017-08-07 01:33:00+03	161300.00
F7F5C9	2017-08-08 15:13:00+03	62600.00
F7F5CA	2017-07-05 17:51:00+03	14800.00
F7F60A	2017-07-17 09:59:00+03	52000.00
F7F622	2017-07-10 17:04:00+03	60400.00
F7F6E0	2017-07-22 02:51:00+03	52400.00
F7F708	2017-07-01 01:56:00+03	42700.00
F7F873	2017-07-17 22:37:00+03	135600.00
F7F8C1	2017-08-06 14:58:00+03	40000.00
F7F8C2	2017-07-08 14:43:00+03	13400.00
F7F8E3	2017-07-17 07:25:00+03	266400.00
F7F92E	2017-07-10 14:03:00+03	47400.00
F7F97C	2017-07-29 19:10:00+03	23600.00
F7F98A	2017-08-09 04:23:00+03	69500.00
F7F9F5	2017-07-01 20:19:00+03	38800.00
F7FA1C	2017-07-04 15:23:00+03	155600.00
F7FA2D	2017-08-15 04:06:00+03	46300.00
F7FADC	2017-08-12 09:57:00+03	42800.00
F7FB71	2017-06-28 22:58:00+03	46000.00
F7FB89	2017-08-09 03:12:00+03	44800.00
F7FC7D	2017-08-14 01:45:00+03	12400.00
F7FCD0	2017-07-14 07:44:00+03	375200.00
F7FD3B	2017-07-01 00:55:00+03	133100.00
F7FD5C	2017-08-15 16:25:00+03	6700.00
F7FD8C	2017-07-01 21:03:00+03	123000.00
F7FD95	2017-08-03 05:46:00+03	23200.00
F7FD9C	2017-08-07 01:17:00+03	123000.00
F7FDAC	2017-07-14 05:23:00+03	27200.00
F7FE2D	2017-07-02 12:37:00+03	40100.00
F7FE3A	2017-07-18 15:26:00+03	46400.00
F7FEAD	2017-07-09 16:27:00+03	135600.00
F7FEC1	2017-08-08 19:33:00+03	55800.00
F7FED5	2017-08-12 10:34:00+03	185000.00
F7FEF4	2017-07-31 01:03:00+03	12400.00
F7FF52	2017-07-22 11:01:00+03	26200.00
F7FF64	2017-08-01 14:40:00+03	62600.00
F7FF78	2017-07-03 00:28:00+03	136500.00
F7FF9E	2017-08-15 13:04:00+03	13800.00
F7FFBA	2017-07-03 04:59:00+03	36200.00
F7FFD9	2017-08-03 13:46:00+03	12000.00
F7FFEB	2017-07-17 17:51:00+03	67200.00
F80019	2017-08-13 04:02:00+03	116400.00
F80069	2017-08-06 16:30:00+03	30200.00
F8015D	2017-06-30 05:21:00+03	57800.00
F80188	2017-08-15 10:32:00+03	84500.00
F801C5	2017-07-04 14:52:00+03	87000.00
F801EA	2017-07-29 22:26:00+03	96400.00
F80212	2017-07-01 20:57:00+03	13400.00
F8021E	2017-07-24 11:43:00+03	65900.00
F8023E	2017-07-21 03:27:00+03	112000.00
F8025C	2017-07-02 18:41:00+03	11800.00
F80299	2017-07-06 23:53:00+03	6600.00
F8029A	2017-07-27 06:58:00+03	13000.00
F802DC	2017-07-21 15:52:00+03	118800.00
F802F7	2017-07-04 22:11:00+03	72000.00
F80386	2017-08-06 08:48:00+03	33200.00
F80433	2017-08-09 07:39:00+03	26000.00
F8044F	2017-08-10 23:43:00+03	46400.00
F804F2	2017-07-08 06:11:00+03	52800.00
F80521	2017-08-07 10:01:00+03	35300.00
F80537	2017-07-22 18:43:00+03	46200.00
F8054B	2017-07-07 18:03:00+03	47000.00
F805C9	2017-08-05 17:35:00+03	92400.00
F80608	2017-07-08 10:02:00+03	56000.00
F80617	2017-08-11 01:35:00+03	121400.00
F806BD	2017-07-09 09:01:00+03	252200.00
F80762	2017-07-12 01:18:00+03	26200.00
F807A9	2017-07-14 16:59:00+03	81700.00
F808DB	2017-07-22 03:03:00+03	36800.00
F80935	2017-07-23 20:51:00+03	129600.00
F8093A	2017-08-09 19:31:00+03	8200.00
F8094E	2017-08-07 19:46:00+03	135000.00
F80965	2017-07-12 11:05:00+03	117600.00
F809A6	2017-08-05 14:22:00+03	135400.00
F80A4C	2017-07-31 09:28:00+03	85500.00
F80A98	2017-08-08 11:00:00+03	78300.00
F80AD9	2017-07-25 03:28:00+03	66400.00
F80B2F	2017-08-05 12:21:00+03	133200.00
F80BDE	2017-07-23 14:23:00+03	59200.00
F80BFC	2017-07-23 02:05:00+03	59700.00
F80C0C	2017-07-20 19:11:00+03	149300.00
F80C36	2017-07-09 02:40:00+03	23600.00
F80D05	2017-08-09 04:39:00+03	54800.00
F80D11	2017-07-17 14:05:00+03	67600.00
F80DC4	2017-07-10 07:45:00+03	55800.00
F80E1B	2017-07-26 08:35:00+03	68400.00
F80E4C	2017-07-10 06:32:00+03	131600.00
F80E61	2017-07-17 09:47:00+03	12000.00
F80F16	2017-07-15 04:37:00+03	222600.00
F80F25	2017-07-21 04:29:00+03	181000.00
F80FFE	2017-07-10 12:16:00+03	35800.00
F81015	2017-08-14 13:51:00+03	64300.00
F81033	2017-07-02 12:42:00+03	66000.00
F81049	2017-08-03 06:39:00+03	50400.00
F81074	2017-07-30 12:05:00+03	48100.00
F810BC	2017-07-31 01:04:00+03	60400.00
F81101	2017-07-29 00:28:00+03	38600.00
F8113E	2017-07-19 23:01:00+03	152500.00
F8115C	2017-08-08 15:26:00+03	122700.00
F8117F	2017-07-04 14:32:00+03	37000.00
F811AF	2017-07-12 04:08:00+03	41900.00
F811ED	2017-07-14 10:41:00+03	88800.00
F81205	2017-08-01 00:05:00+03	92600.00
F8121C	2017-07-02 10:17:00+03	7400.00
F8124A	2017-07-15 09:53:00+03	32800.00
F812CC	2017-08-08 12:27:00+03	90600.00
F812E5	2017-08-02 02:07:00+03	69600.00
F812EF	2017-07-13 06:31:00+03	75600.00
F812F4	2017-07-01 22:01:00+03	62600.00
F8132C	2017-08-08 22:48:00+03	68800.00
F81412	2017-07-20 13:07:00+03	59800.00
F81447	2017-07-09 13:32:00+03	22000.00
F81494	2017-07-25 00:15:00+03	229600.00
F8151B	2017-07-27 08:38:00+03	87000.00
F8152C	2017-07-10 16:15:00+03	56200.00
F815AB	2017-08-14 05:18:00+03	52400.00
F81623	2017-07-28 13:03:00+03	87200.00
F8162E	2017-07-27 16:14:00+03	226800.00
F81670	2017-08-01 01:22:00+03	111600.00
F81745	2017-08-08 20:43:00+03	85000.00
F81770	2017-07-06 06:26:00+03	47100.00
F81791	2017-08-13 15:18:00+03	28000.00
F817D9	2017-07-20 01:31:00+03	63200.00
F8180B	2017-07-05 21:13:00+03	56600.00
F81854	2017-08-12 04:11:00+03	7400.00
F818A0	2017-08-05 23:02:00+03	32200.00
F818B5	2017-07-26 20:06:00+03	49600.00
F8199C	2017-08-10 15:38:00+03	18600.00
F81A01	2017-07-20 15:49:00+03	26700.00
F81A46	2017-08-03 03:56:00+03	151200.00
F81A4A	2017-06-30 06:32:00+03	27200.00
F81AEE	2017-07-14 05:16:00+03	13400.00
F81BBE	2017-06-30 17:14:00+03	56000.00
F81BE5	2017-07-14 14:05:00+03	66600.00
F81C0C	2017-07-30 13:12:00+03	248300.00
F81C7E	2017-07-07 15:44:00+03	56000.00
F81CAC	2017-07-14 11:29:00+03	25400.00
F81CB6	2017-07-17 05:31:00+03	24400.00
F81CC4	2017-07-03 04:01:00+03	165500.00
F81CE6	2017-07-08 16:29:00+03	26800.00
F81CE7	2017-07-12 17:01:00+03	131600.00
F81D43	2017-07-31 09:56:00+03	87300.00
F81D90	2017-08-07 03:14:00+03	26700.00
F81D99	2017-08-11 08:04:00+03	24400.00
F81DAE	2017-07-11 22:26:00+03	14000.00
F81DCD	2017-07-16 20:52:00+03	40800.00
F81DF3	2017-08-10 17:38:00+03	189200.00
F81E05	2017-08-05 08:15:00+03	23200.00
F81E12	2017-08-03 20:52:00+03	42400.00
F81E43	2017-07-27 13:32:00+03	68800.00
F81E45	2017-07-25 06:06:00+03	46400.00
F81E64	2017-07-31 11:09:00+03	189800.00
F81E70	2017-08-09 06:16:00+03	124300.00
F81EEC	2017-07-19 04:31:00+03	6000.00
F81F15	2017-07-17 08:36:00+03	38800.00
F82039	2017-08-02 04:00:00+03	85000.00
F8203E	2017-07-22 21:55:00+03	96200.00
F82068	2017-08-10 11:14:00+03	94900.00
F820F0	2017-07-10 01:41:00+03	22000.00
F82122	2017-08-10 00:02:00+03	31200.00
F8212E	2017-07-09 19:03:00+03	27400.00
F8213B	2017-07-23 16:52:00+03	55800.00
F8214A	2017-07-07 21:30:00+03	67600.00
F82178	2017-07-14 22:55:00+03	23200.00
F8221A	2017-08-10 22:37:00+03	50400.00
F82278	2017-08-08 13:15:00+03	76400.00
F822AC	2017-07-27 12:12:00+03	115400.00
F822F2	2017-07-27 09:41:00+03	58600.00
F8232D	2017-07-05 10:43:00+03	56600.00
F823AA	2017-08-02 16:47:00+03	111000.00
F823C6	2017-07-08 12:35:00+03	85600.00
F823DD	2017-07-06 19:49:00+03	49100.00
F82400	2017-07-28 22:08:00+03	21800.00
F82447	2017-08-02 06:15:00+03	67600.00
F82481	2017-07-31 12:31:00+03	206400.00
F824E6	2017-07-19 03:11:00+03	27200.00
F825EE	2017-08-12 04:47:00+03	28800.00
F82602	2017-07-18 13:22:00+03	44800.00
F82618	2017-07-05 21:30:00+03	37800.00
F82620	2017-07-05 07:34:00+03	36200.00
F8267D	2017-07-23 18:38:00+03	48800.00
F82687	2017-07-21 21:01:00+03	39200.00
F82697	2017-07-01 11:02:00+03	242800.00
F82756	2017-07-26 14:47:00+03	265700.00
F827C8	2017-07-10 13:38:00+03	15800.00
F827FA	2017-08-06 01:35:00+03	114800.00
F82836	2017-07-08 06:47:00+03	75300.00
F82885	2017-07-05 07:29:00+03	29300.00
F8288D	2017-08-04 21:20:00+03	39500.00
F8288F	2017-08-12 01:49:00+03	481100.00
F828FC	2017-08-07 08:46:00+03	184200.00
F82906	2017-07-14 15:21:00+03	29600.00
F8296D	2017-07-07 11:01:00+03	106900.00
F8296F	2017-07-23 04:35:00+03	35800.00
F82A14	2017-07-21 16:32:00+03	85000.00
F82A4A	2017-07-01 11:05:00+03	72400.00
F82A73	2017-07-12 17:54:00+03	26000.00
F82A92	2017-07-31 14:20:00+03	43800.00
F82A93	2017-08-09 14:08:00+03	115100.00
F82AC0	2017-08-13 07:43:00+03	151200.00
F82B03	2017-07-23 02:13:00+03	23100.00
F82B1B	2017-07-03 15:11:00+03	8000.00
F82BF2	2017-07-10 23:41:00+03	66000.00
F82C03	2017-08-12 22:14:00+03	43200.00
F82C49	2017-07-23 12:32:00+03	272400.00
F82C4A	2017-07-12 16:15:00+03	178800.00
F82CA3	2017-07-09 11:56:00+03	21400.00
F82CAB	2017-07-20 22:05:00+03	56900.00
F82CB8	2017-07-14 02:10:00+03	48800.00
F82CD7	2017-08-06 23:52:00+03	254900.00
F82CF8	2017-07-22 14:34:00+03	79800.00
F82D05	2017-07-25 20:32:00+03	52000.00
F82D5C	2017-08-06 13:52:00+03	24700.00
F82DB2	2017-08-12 09:29:00+03	92900.00
F82DB5	2017-07-10 13:54:00+03	37900.00
F82DF2	2017-08-08 10:49:00+03	319400.00
F82E14	2017-07-14 19:46:00+03	30200.00
F82E8F	2017-07-20 04:19:00+03	25800.00
F82EC3	2017-07-04 13:49:00+03	13000.00
F82EC4	2017-07-17 15:15:00+03	92800.00
F82ECB	2017-08-04 12:24:00+03	46800.00
F82F30	2017-07-13 13:52:00+03	67200.00
F82F89	2017-08-15 06:36:00+03	93800.00
F82FCC	2017-07-15 09:41:00+03	131100.00
F82FF7	2017-07-11 20:08:00+03	35700.00
F83006	2017-07-20 10:41:00+03	86300.00
F83019	2017-07-12 02:50:00+03	64100.00
F8301C	2017-07-10 08:29:00+03	36800.00
F8301F	2017-08-11 00:50:00+03	111600.00
F83047	2017-08-04 22:11:00+03	149300.00
F8304B	2017-08-11 23:26:00+03	72400.00
F830EF	2017-07-24 09:52:00+03	144000.00
F830FB	2017-07-16 17:37:00+03	102100.00
F83101	2017-07-23 13:33:00+03	189200.00
F8313B	2017-07-30 10:59:00+03	106500.00
F83185	2017-08-08 07:43:00+03	106100.00
F8319B	2017-07-14 03:22:00+03	37100.00
F831BE	2017-07-11 12:07:00+03	51900.00
F8322C	2017-08-14 12:04:00+03	36200.00
F83299	2017-08-06 14:12:00+03	57500.00
F832DF	2017-07-28 07:24:00+03	16400.00
F83392	2017-08-12 14:26:00+03	115300.00
F8339E	2017-07-13 10:42:00+03	28800.00
F833C7	2017-07-22 12:24:00+03	13400.00
F83424	2017-07-22 06:01:00+03	48400.00
F83498	2017-08-10 18:15:00+03	28300.00
F834AA	2017-08-06 10:59:00+03	136700.00
F834C0	2017-07-24 02:36:00+03	67000.00
F834E2	2017-07-29 19:41:00+03	46400.00
F834E3	2017-08-13 05:49:00+03	213900.00
F83516	2017-07-13 13:27:00+03	57400.00
F8356E	2017-07-30 07:38:00+03	15900.00
F83577	2017-07-17 03:55:00+03	62000.00
F835D5	2017-06-30 17:23:00+03	85000.00
F835D6	2017-08-13 08:11:00+03	14400.00
F835D9	2017-07-29 04:58:00+03	44800.00
F8360B	2017-07-29 05:01:00+03	67100.00
F83624	2017-07-05 20:18:00+03	62800.00
F83689	2017-07-06 19:54:00+03	23600.00
F83697	2017-07-18 22:36:00+03	24600.00
F836A8	2017-08-01 04:07:00+03	48800.00
F836C2	2017-08-01 13:56:00+03	35200.00
F836CA	2017-08-06 22:54:00+03	21800.00
F836E8	2017-08-01 19:08:00+03	73200.00
F83734	2017-07-07 17:31:00+03	99200.00
F837C8	2017-07-16 22:46:00+03	135600.00
F837E6	2017-07-17 09:53:00+03	46400.00
F8380B	2017-06-30 09:40:00+03	25400.00
F83811	2017-07-09 07:14:00+03	185600.00
F83853	2017-07-20 03:10:00+03	75300.00
F838A9	2017-08-12 23:22:00+03	23600.00
F838B5	2017-08-01 16:29:00+03	202700.00
F8390D	2017-07-21 12:03:00+03	134900.00
F8394E	2017-06-30 03:37:00+03	32400.00
F83956	2017-07-23 22:38:00+03	26000.00
F839C3	2017-07-12 22:08:00+03	67700.00
F83A2C	2017-08-11 17:34:00+03	169300.00
F83A2F	2017-08-14 06:59:00+03	29600.00
F83A6F	2017-08-14 20:23:00+03	133200.00
F83AAD	2017-07-22 19:36:00+03	22200.00
F83AD4	2017-07-21 06:36:00+03	6000.00
F83BA4	2017-07-11 22:50:00+03	52000.00
F83C18	2017-07-16 01:44:00+03	86300.00
F83C73	2017-07-18 18:00:00+03	146300.00
F83CA6	2017-07-21 22:02:00+03	35200.00
F83CA7	2017-07-13 17:58:00+03	53600.00
F83D13	2017-07-07 08:16:00+03	48100.00
F83D46	2017-07-01 20:29:00+03	67600.00
F83DFB	2017-08-05 03:49:00+03	76600.00
F83E6B	2017-08-06 05:24:00+03	136200.00
F83E79	2017-07-28 12:37:00+03	43400.00
F83F7A	2017-07-23 20:47:00+03	89600.00
F83FBF	2017-08-15 15:30:00+03	12000.00
F83FF6	2017-07-21 08:27:00+03	172300.00
F840E5	2017-07-14 20:41:00+03	85600.00
F8413A	2017-07-21 23:12:00+03	72600.00
F8414A	2017-07-18 16:00:00+03	102100.00
F8416C	2017-08-07 00:35:00+03	64600.00
F84187	2017-08-04 07:38:00+03	169900.00
F841A5	2017-06-30 06:59:00+03	260300.00
F841BA	2017-07-31 16:35:00+03	32700.00
F84247	2017-08-02 13:07:00+03	31100.00
F84289	2017-07-24 09:25:00+03	89600.00
F84330	2017-08-13 20:50:00+03	42800.00
F8436B	2017-07-26 17:56:00+03	98400.00
F84373	2017-07-17 04:39:00+03	63400.00
F843F5	2017-07-25 15:13:00+03	23200.00
F8443D	2017-08-14 10:22:00+03	33200.00
F8448B	2017-07-29 16:10:00+03	23600.00
F844DB	2017-08-06 13:48:00+03	47600.00
F8451D	2017-07-31 02:09:00+03	101500.00
F845FD	2017-07-15 22:44:00+03	42400.00
F84629	2017-07-05 23:03:00+03	155900.00
F8464B	2017-07-31 03:47:00+03	26000.00
F846BB	2017-08-05 04:57:00+03	148500.00
F84800	2017-08-15 14:40:00+03	168000.00
F84840	2017-08-04 22:27:00+03	31100.00
F848FD	2017-08-14 02:33:00+03	67600.00
F8490B	2017-07-02 17:34:00+03	367700.00
F8495A	2017-07-14 21:08:00+03	286100.00
F84961	2017-07-18 01:25:00+03	123000.00
F8498A	2017-07-15 05:51:00+03	13400.00
F84993	2017-07-23 03:55:00+03	24400.00
F849B7	2017-08-11 08:53:00+03	115900.00
F84A05	2017-07-31 11:33:00+03	111600.00
F84A37	2017-07-28 13:25:00+03	63300.00
F84A5F	2017-07-17 22:55:00+03	44800.00
F84A6F	2017-07-20 11:28:00+03	47100.00
F84AA8	2017-07-15 04:44:00+03	84100.00
F84AB8	2017-07-07 20:45:00+03	29300.00
F84B40	2017-08-10 18:51:00+03	21800.00
F84BBE	2017-07-08 16:39:00+03	172100.00
F84BDD	2017-07-28 19:43:00+03	32700.00
F84BE1	2017-07-13 02:18:00+03	51900.00
F84BED	2017-08-06 15:20:00+03	61200.00
F84BEF	2017-07-29 09:57:00+03	115600.00
F84C0A	2017-07-29 15:25:00+03	65600.00
F84C52	2017-06-29 23:53:00+03	135400.00
F84C57	2017-08-01 18:53:00+03	48800.00
F84C7A	2017-08-02 07:41:00+03	17200.00
F84C89	2017-07-02 16:25:00+03	102100.00
F84CB5	2017-07-04 09:55:00+03	43200.00
F84CB7	2017-07-22 07:55:00+03	148200.00
F84D22	2017-08-02 19:58:00+03	143100.00
F84D3E	2017-07-26 05:48:00+03	245500.00
F84D47	2017-07-15 18:02:00+03	83300.00
F84DA1	2017-07-25 18:27:00+03	16400.00
F84E18	2017-07-04 12:30:00+03	6000.00
F84E2B	2017-07-27 09:35:00+03	56000.00
F84E31	2017-08-01 21:41:00+03	46000.00
F84E62	2017-06-29 23:10:00+03	46700.00
F84EED	2017-07-28 21:02:00+03	88800.00
F84F07	2017-07-14 03:17:00+03	68800.00
F84F36	2017-07-14 12:49:00+03	28000.00
F84F45	2017-06-29 01:24:00+03	54400.00
F84F47	2017-08-09 11:01:00+03	96200.00
F84F50	2017-07-14 06:41:00+03	98200.00
F8501E	2017-07-23 04:56:00+03	46200.00
F85033	2017-07-03 08:09:00+03	21500.00
F850CA	2017-08-10 23:33:00+03	30000.00
F850F8	2017-07-17 16:43:00+03	65500.00
F85167	2017-08-04 00:06:00+03	54500.00
F85222	2017-08-05 13:41:00+03	95600.00
F852A6	2017-07-07 05:33:00+03	55800.00
F852BC	2017-07-22 07:24:00+03	144400.00
F852D9	2017-07-05 15:03:00+03	59800.00
F85320	2017-08-02 18:36:00+03	28600.00
F85377	2017-07-22 05:59:00+03	17800.00
F8538B	2017-08-14 15:08:00+03	99300.00
F853B4	2017-08-06 15:37:00+03	79000.00
F853DA	2017-07-30 11:41:00+03	135400.00
F85462	2017-07-12 22:57:00+03	102600.00
F85552	2017-07-12 08:03:00+03	99300.00
F8555D	2017-08-13 10:42:00+03	73600.00
F855D7	2017-08-14 06:32:00+03	73400.00
F855DC	2017-08-10 00:52:00+03	114800.00
F855F2	2017-08-02 20:48:00+03	125600.00
F855FD	2017-08-01 15:28:00+03	101100.00
F85605	2017-07-10 09:52:00+03	28800.00
F85670	2017-07-11 07:38:00+03	52000.00
F8573C	2017-07-05 11:54:00+03	31100.00
F85747	2017-08-10 16:36:00+03	103600.00
F85748	2017-07-13 18:46:00+03	23600.00
F857BA	2017-07-27 04:30:00+03	68400.00
F8583B	2017-07-09 06:28:00+03	146600.00
F85855	2017-07-17 04:06:00+03	81800.00
F8585E	2017-07-26 21:37:00+03	88100.00
F8585F	2017-07-28 01:52:00+03	579600.00
F8586F	2017-07-23 01:36:00+03	56600.00
F85875	2017-08-11 01:00:00+03	175800.00
F85954	2017-08-03 05:46:00+03	13400.00
F85990	2017-08-03 20:12:00+03	88000.00
F85994	2017-07-13 12:19:00+03	83000.00
F859C1	2017-08-12 08:12:00+03	70800.00
F859CF	2017-08-14 11:54:00+03	643800.00
F85A0B	2017-08-06 17:28:00+03	21400.00
F85A1E	2017-08-08 16:06:00+03	60400.00
F85A64	2017-07-21 04:16:00+03	14000.00
F85AB8	2017-07-18 19:19:00+03	48800.00
F85B16	2017-08-09 15:28:00+03	49100.00
F85B26	2017-07-10 12:30:00+03	120900.00
F85B52	2017-08-06 17:29:00+03	28000.00
F85B5E	2017-07-09 12:08:00+03	70700.00
F85BB2	2017-07-08 01:22:00+03	34000.00
F85BCF	2017-07-31 17:40:00+03	169800.00
F85BDF	2017-07-27 18:37:00+03	6700.00
F85C2E	2017-07-07 16:32:00+03	131100.00
F85C8E	2017-07-15 18:52:00+03	25000.00
F85CA7	2017-07-28 23:09:00+03	106400.00
F85DDE	2017-07-10 16:39:00+03	125200.00
F85E71	2017-08-02 14:56:00+03	65600.00
F85EC8	2017-07-16 06:02:00+03	180600.00
F85F29	2017-07-22 00:16:00+03	23200.00
F85F6B	2017-07-24 02:07:00+03	31200.00
F85FF0	2017-06-30 02:40:00+03	80200.00
F85FF8	2017-07-22 04:57:00+03	52800.00
F8601F	2017-08-15 18:00:00+03	93400.00
F860A0	2017-07-06 07:32:00+03	39200.00
F860C7	2017-07-04 14:15:00+03	16400.00
F860E9	2017-07-07 14:52:00+03	46200.00
F8615C	2017-07-18 14:10:00+03	46200.00
F86165	2017-08-02 22:49:00+03	99200.00
F861BC	2017-07-14 04:10:00+03	67000.00
F861E1	2017-08-09 10:13:00+03	64100.00
F862DA	2017-07-05 20:37:00+03	85000.00
F862E2	2017-07-17 19:22:00+03	50400.00
F8635D	2017-07-11 19:20:00+03	193700.00
F86366	2017-08-06 20:53:00+03	67200.00
F86386	2017-07-26 14:56:00+03	23200.00
F86470	2017-08-12 00:37:00+03	57400.00
F86487	2017-07-18 16:34:00+03	86600.00
F864D0	2017-08-03 15:30:00+03	77500.00
F864DB	2017-07-28 02:54:00+03	36200.00
F864E3	2017-07-27 14:27:00+03	32700.00
F864F3	2017-08-12 17:45:00+03	123500.00
F865A7	2017-07-29 14:35:00+03	14400.00
F865F6	2017-08-09 05:25:00+03	81700.00
F8667C	2017-07-25 11:03:00+03	23200.00
F8667E	2017-07-03 09:09:00+03	44700.00
F86766	2017-08-01 14:32:00+03	20400.00
F867AD	2017-07-31 08:13:00+03	64800.00
F867CB	2017-07-07 11:10:00+03	52000.00
F867F0	2017-07-09 12:53:00+03	12600.00
F86812	2017-08-13 12:50:00+03	39800.00
F868A9	2017-07-31 21:23:00+03	46000.00
F868B1	2017-08-06 03:33:00+03	31100.00
F868F0	2017-07-19 19:12:00+03	28000.00
F86913	2017-08-10 07:55:00+03	67600.00
F8691E	2017-08-11 02:16:00+03	52000.00
F8694C	2017-08-14 03:26:00+03	64300.00
F8695C	2017-07-16 05:06:00+03	56600.00
F86967	2017-08-06 07:09:00+03	21400.00
F869A7	2017-07-04 10:08:00+03	38800.00
F86A09	2017-07-22 20:22:00+03	26800.00
F86A4A	2017-07-12 04:00:00+03	46300.00
F86A78	2017-07-07 13:54:00+03	131600.00
F86B21	2017-08-09 06:46:00+03	16400.00
F86B2B	2017-08-06 21:59:00+03	86300.00
F86B5A	2017-08-02 11:38:00+03	28000.00
F86BA9	2017-07-21 04:42:00+03	33600.00
F86BD4	2017-07-17 17:58:00+03	516600.00
F86BED	2017-07-11 04:40:00+03	27900.00
F86BF9	2017-07-03 23:28:00+03	32800.00
F86C07	2017-07-09 10:28:00+03	81300.00
F86C08	2017-08-09 12:02:00+03	81300.00
F86C54	2017-08-13 06:28:00+03	94000.00
F86C5F	2017-07-03 00:43:00+03	26000.00
F86C82	2017-07-04 09:46:00+03	48100.00
F86C88	2017-08-14 04:49:00+03	152500.00
F86CD9	2017-07-07 15:11:00+03	27200.00
F86CE2	2017-08-05 15:17:00+03	24400.00
F86CE9	2017-07-04 18:50:00+03	28000.00
F86D05	2017-07-16 07:41:00+03	34000.00
F86D18	2017-07-04 15:19:00+03	20000.00
F86D26	2017-08-14 04:30:00+03	38200.00
F86D3C	2017-08-01 08:43:00+03	74800.00
F86D82	2017-07-04 16:01:00+03	67900.00
F86DA7	2017-08-07 05:18:00+03	44600.00
F86E0B	2017-08-02 07:41:00+03	55800.00
F86E2C	2017-06-30 08:05:00+03	56000.00
F86E5B	2017-07-04 02:31:00+03	79900.00
F86E7D	2017-07-08 14:31:00+03	115900.00
F86EFE	2017-07-19 11:44:00+03	113200.00
F86F50	2017-08-04 00:41:00+03	324100.00
F86F5C	2017-08-13 12:34:00+03	56900.00
F86F67	2017-06-27 05:38:00+03	38600.00
F86F79	2017-08-06 14:05:00+03	136200.00
F86F7C	2017-08-11 04:37:00+03	135400.00
F86F93	2017-07-14 12:09:00+03	59800.00
F86FC9	2017-08-09 08:24:00+03	68400.00
F86FE3	2017-07-26 14:29:00+03	66600.00
F8704C	2017-07-22 16:00:00+03	14400.00
F8706C	2017-07-27 15:03:00+03	202300.00
F87089	2017-07-17 08:55:00+03	56000.00
F870C6	2017-07-14 06:01:00+03	171000.00
F870D4	2017-07-11 02:19:00+03	56600.00
F870D8	2017-07-22 16:53:00+03	124200.00
F87126	2017-07-03 22:45:00+03	64700.00
F87131	2017-07-21 13:08:00+03	50800.00
F87138	2017-07-04 17:17:00+03	23600.00
F8713D	2017-07-10 17:51:00+03	246000.00
F8713E	2017-08-12 11:54:00+03	186300.00
F87154	2017-07-27 06:49:00+03	77900.00
F87159	2017-07-28 19:57:00+03	67600.00
F8715C	2017-07-15 09:21:00+03	50400.00
F871C2	2017-08-04 15:30:00+03	52100.00
F871DE	2017-07-04 14:04:00+03	46900.00
F87223	2017-07-02 03:51:00+03	242700.00
F8725C	2017-07-22 17:17:00+03	17200.00
F8727D	2017-08-03 23:07:00+03	146300.00
F872B3	2017-07-21 00:48:00+03	55800.00
F872B9	2017-08-01 21:48:00+03	89700.00
F8736A	2017-08-03 22:18:00+03	48700.00
F87378	2017-07-20 20:04:00+03	148800.00
F873B8	2017-07-04 09:58:00+03	44800.00
F873CE	2017-07-13 20:50:00+03	82900.00
F873D3	2017-08-09 05:01:00+03	124200.00
F873FB	2017-07-04 20:32:00+03	142400.00
F87422	2017-07-27 11:15:00+03	7400.00
F8747C	2017-07-29 18:57:00+03	26300.00
F87553	2017-08-14 20:07:00+03	13400.00
F8756C	2017-07-31 20:47:00+03	41200.00
F8756E	2017-07-19 18:25:00+03	34000.00
F87592	2017-07-25 23:11:00+03	255600.00
F875A7	2017-07-15 17:49:00+03	75600.00
F875C4	2017-07-18 18:09:00+03	23200.00
F875CD	2017-08-10 03:18:00+03	55800.00
F875EF	2017-08-01 21:46:00+03	44600.00
F8760D	2017-08-01 16:13:00+03	107800.00
F876DA	2017-08-13 16:18:00+03	6600.00
F8777B	2017-07-14 11:46:00+03	105400.00
F8777D	2017-07-16 19:35:00+03	69200.00
F877B1	2017-08-08 19:58:00+03	162400.00
F877F7	2017-07-29 20:39:00+03	23200.00
F87803	2017-07-16 06:51:00+03	8200.00
F87821	2017-07-27 07:45:00+03	26000.00
F87853	2017-07-26 13:04:00+03	69500.00
F8787C	2017-07-24 02:52:00+03	60400.00
F87897	2017-07-29 01:49:00+03	40400.00
F8793D	2017-08-04 17:57:00+03	140900.00
F879C8	2017-07-26 14:24:00+03	132800.00
F879FF	2017-08-14 21:48:00+03	14700.00
F87A06	2017-07-12 12:24:00+03	55800.00
F87A08	2017-07-12 12:05:00+03	103500.00
F87A1B	2017-08-04 22:25:00+03	114800.00
F87A52	2017-08-15 04:54:00+03	18400.00
F87A74	2017-07-25 11:08:00+03	289800.00
F87A7F	2017-07-18 10:58:00+03	81400.00
F87AC5	2017-07-23 04:52:00+03	26000.00
F87AC6	2017-07-04 17:51:00+03	6700.00
F87AEB	2017-07-16 20:13:00+03	68500.00
F87B75	2017-08-07 15:14:00+03	85000.00
F87B84	2017-07-16 12:23:00+03	11600.00
F87BE1	2017-08-07 19:45:00+03	48700.00
F87C1C	2017-07-09 02:33:00+03	95000.00
F87C5C	2017-08-14 00:06:00+03	26800.00
F87C8B	2017-08-09 03:36:00+03	68900.00
F87CDE	2017-08-07 10:44:00+03	42400.00
F87CE3	2017-07-30 10:13:00+03	42800.00
F87D23	2017-07-29 03:12:00+03	108500.00
F87D4D	2017-07-23 15:04:00+03	114700.00
F87D57	2017-08-11 21:51:00+03	75900.00
F87DAA	2017-07-09 17:27:00+03	54500.00
F87DE6	2017-07-26 02:31:00+03	48300.00
F87E1C	2017-07-14 14:14:00+03	87600.00
F87E33	2017-08-15 14:02:00+03	21400.00
F87E51	2017-07-05 01:11:00+03	31900.00
F87E63	2017-07-24 06:49:00+03	39800.00
F87EED	2017-07-19 06:12:00+03	170000.00
F87F5C	2017-07-31 06:48:00+03	10800.00
F87FDC	2017-07-05 08:40:00+03	23200.00
F8801B	2017-07-09 08:00:00+03	125400.00
F8801D	2017-07-10 12:42:00+03	106100.00
F88026	2017-08-08 00:12:00+03	47000.00
F88037	2017-08-02 01:29:00+03	266400.00
F8808D	2017-07-31 01:45:00+03	410200.00
F8808E	2017-07-31 03:59:00+03	19600.00
F880A8	2017-07-03 18:46:00+03	50400.00
F880C8	2017-07-22 12:45:00+03	24400.00
F88101	2017-08-15 10:51:00+03	264400.00
F8810A	2017-08-09 03:17:00+03	6400.00
F88157	2017-08-04 07:19:00+03	25800.00
F8815B	2017-07-05 18:02:00+03	44000.00
F881C0	2017-07-03 15:00:00+03	153300.00
F881FC	2017-08-10 22:16:00+03	101200.00
F8824A	2017-07-09 17:39:00+03	135400.00
F88272	2017-07-03 14:46:00+03	87400.00
F8832F	2017-07-11 07:33:00+03	99900.00
F88334	2017-08-15 06:07:00+03	56600.00
F88352	2017-08-01 21:30:00+03	81200.00
F883DE	2017-08-09 03:04:00+03	25600.00
F88469	2017-07-08 05:22:00+03	78600.00
F88485	2017-07-21 18:49:00+03	40000.00
F884A5	2017-08-12 06:16:00+03	92800.00
F884F7	2017-07-18 14:13:00+03	131100.00
F884F8	2017-07-15 04:56:00+03	99200.00
F8859A	2017-07-04 21:11:00+03	254600.00
F885CF	2017-07-07 18:05:00+03	86400.00
F88603	2017-08-05 07:26:00+03	56600.00
F88665	2017-07-30 08:29:00+03	27800.00
F886C6	2017-07-04 02:28:00+03	133900.00
F886ED	2017-07-19 15:41:00+03	18800.00
F886F1	2017-07-11 09:17:00+03	57400.00
F8870C	2017-07-11 09:53:00+03	135600.00
F88717	2017-08-13 09:07:00+03	409100.00
F88765	2017-07-22 11:50:00+03	23600.00
F88790	2017-07-09 04:02:00+03	277600.00
F88794	2017-07-26 11:08:00+03	109000.00
F887B1	2017-08-03 03:36:00+03	55000.00
F887FC	2017-07-03 19:36:00+03	94700.00
F88803	2017-07-16 08:35:00+03	47200.00
F888CD	2017-08-03 05:05:00+03	103500.00
F88906	2017-07-19 05:59:00+03	55800.00
F8893D	2017-07-27 00:59:00+03	23200.00
F889E8	2017-07-31 21:33:00+03	85000.00
F88A2E	2017-06-30 09:38:00+03	46300.00
F88ADE	2017-07-13 15:19:00+03	18400.00
F88B60	2017-08-13 11:16:00+03	40800.00
F88B8E	2017-07-22 19:54:00+03	439500.00
F88BA4	2017-07-26 14:35:00+03	40200.00
F88BA9	2017-07-22 04:04:00+03	71600.00
F88BB8	2017-08-03 20:51:00+03	381000.00
F88BBD	2017-07-24 01:06:00+03	191200.00
F88BE2	2017-07-28 21:26:00+03	14400.00
F88C02	2017-07-23 22:00:00+03	302400.00
F88C0B	2017-07-18 13:13:00+03	167900.00
F88C4B	2017-08-12 01:36:00+03	31800.00
F88C6A	2017-08-11 08:40:00+03	94700.00
F88C83	2017-07-12 14:02:00+03	87200.00
F88CBD	2017-07-31 23:45:00+03	27800.00
F88CCE	2017-07-24 07:05:00+03	41200.00
F88CD2	2017-08-06 12:37:00+03	87200.00
F88D39	2017-07-02 16:50:00+03	57300.00
F88D79	2017-07-07 22:16:00+03	81700.00
F88E37	2017-07-25 10:30:00+03	70700.00
F88E3C	2017-07-19 16:46:00+03	43200.00
F88EB8	2017-07-16 14:01:00+03	28000.00
F88EE3	2017-07-20 14:37:00+03	21800.00
F88EEA	2017-08-03 22:23:00+03	24400.00
F88FD7	2017-08-13 11:28:00+03	13600.00
F88FF2	2017-07-18 09:06:00+03	141300.00
F89010	2017-07-07 06:47:00+03	55800.00
F89019	2017-08-03 14:07:00+03	70700.00
F8908F	2017-07-21 22:41:00+03	61900.00
F890A1	2017-08-01 23:21:00+03	52300.00
F89114	2017-07-17 00:08:00+03	46000.00
F8912A	2017-07-12 20:51:00+03	90200.00
F891D7	2017-08-01 10:28:00+03	67800.00
F891E5	2017-07-14 18:42:00+03	66000.00
F89266	2017-07-28 04:03:00+03	56000.00
F892D1	2017-06-28 04:02:00+03	220600.00
F89304	2017-08-08 14:30:00+03	11700.00
F89308	2017-07-21 00:16:00+03	95000.00
F89330	2017-07-06 19:01:00+03	59300.00
F89349	2017-08-13 18:26:00+03	92900.00
F89449	2017-07-11 00:35:00+03	66600.00
F89471	2017-07-28 19:58:00+03	36200.00
F89515	2017-08-06 18:49:00+03	28000.00
F89522	2017-08-09 02:56:00+03	23400.00
F89541	2017-08-05 09:39:00+03	126500.00
F89598	2017-07-11 03:25:00+03	56600.00
F895D3	2017-07-17 18:38:00+03	21400.00
F89677	2017-07-18 23:08:00+03	52100.00
F89684	2017-08-03 00:08:00+03	47700.00
F896C3	2017-08-09 20:37:00+03	26000.00
F896D4	2017-07-05 07:33:00+03	410200.00
F896DE	2017-07-20 04:46:00+03	28800.00
F896E2	2017-08-05 01:37:00+03	16400.00
F896FD	2017-07-24 12:29:00+03	148700.00
F896FF	2017-08-13 11:29:00+03	26800.00
F89752	2017-07-29 14:37:00+03	42700.00
F89768	2017-08-09 15:39:00+03	9800.00
F897F0	2017-07-12 01:20:00+03	29600.00
F898CB	2017-07-17 06:47:00+03	28000.00
F898D8	2017-08-15 09:37:00+03	68100.00
F89920	2017-08-05 17:01:00+03	15100.00
F89927	2017-07-22 12:21:00+03	46400.00
F8992D	2017-07-26 03:03:00+03	20600.00
F89941	2017-07-05 17:30:00+03	31400.00
F89966	2017-06-28 04:08:00+03	72800.00
F89972	2017-08-04 22:08:00+03	135400.00
F8999A	2017-08-14 21:32:00+03	14000.00
F899B0	2017-07-22 10:07:00+03	64600.00
F89A29	2017-07-19 02:59:00+03	8200.00
F89A53	2017-07-26 07:41:00+03	56600.00
F89A5A	2017-08-07 13:25:00+03	47700.00
F89AEC	2017-07-31 00:29:00+03	59800.00
F89B2B	2017-07-07 17:10:00+03	6800.00
F89B62	2017-07-31 21:00:00+03	23600.00
F89C66	2017-07-28 00:34:00+03	69600.00
F89C70	2017-07-13 01:01:00+03	59800.00
F89CB1	2017-07-30 23:50:00+03	22600.00
F89CD2	2017-08-01 01:32:00+03	411000.00
F89D0F	2017-07-08 10:36:00+03	84500.00
F89D3D	2017-07-25 20:58:00+03	60300.00
F89D88	2017-08-12 06:59:00+03	54000.00
F89DA3	2017-07-02 11:08:00+03	136200.00
F89DAB	2017-08-10 05:06:00+03	140400.00
F89E55	2017-08-08 19:14:00+03	136600.00
F89F6B	2017-07-17 07:45:00+03	122300.00
F89FDE	2017-08-09 17:55:00+03	42000.00
F89FF8	2017-08-11 21:09:00+03	13000.00
F8A053	2017-08-01 07:26:00+03	56600.00
F8A067	2017-07-20 10:51:00+03	61800.00
F8A092	2017-07-27 15:20:00+03	34000.00
F8A0BE	2017-07-16 11:19:00+03	49400.00
F8A0E9	2017-08-01 07:22:00+03	72200.00
F8A1C0	2017-07-11 04:48:00+03	40800.00
F8A267	2017-07-26 15:24:00+03	57400.00
F8A29F	2017-08-08 22:06:00+03	81200.00
F8A2C4	2017-08-03 01:09:00+03	204700.00
F8A302	2017-07-28 21:31:00+03	105100.00
F8A3C2	2017-07-19 16:12:00+03	61200.00
F8A3F2	2017-07-26 10:27:00+03	88200.00
F8A46F	2017-08-13 15:06:00+03	112200.00
F8A48F	2017-07-06 03:51:00+03	68400.00
F8A4EA	2017-08-08 22:12:00+03	189200.00
F8A50B	2017-07-18 18:09:00+03	133200.00
F8A544	2017-08-13 02:09:00+03	78300.00
F8A57C	2017-07-21 15:14:00+03	189200.00
F8A582	2017-08-05 16:30:00+03	106400.00
F8A58F	2017-08-14 11:07:00+03	53700.00
F8A5A0	2017-07-23 05:10:00+03	111600.00
F8A5CA	2017-08-12 09:41:00+03	28300.00
F8A5F8	2017-08-11 15:31:00+03	20600.00
F8A62D	2017-07-17 02:19:00+03	46300.00
F8A65B	2017-07-04 19:32:00+03	140600.00
F8A66E	2017-07-27 03:02:00+03	27800.00
F8A695	2017-08-02 00:23:00+03	37200.00
F8A697	2017-08-09 00:08:00+03	67900.00
F8A6AA	2017-07-30 19:48:00+03	27500.00
F8A6B8	2017-07-03 14:22:00+03	88100.00
F8A6E9	2017-08-06 01:00:00+03	8000.00
F8A721	2017-07-17 17:27:00+03	99200.00
F8A795	2017-08-09 08:44:00+03	12000.00
F8A7F5	2017-07-30 21:47:00+03	29800.00
F8A822	2017-07-26 21:49:00+03	168000.00
F8A88A	2017-07-10 01:23:00+03	128800.00
F8A93E	2017-08-14 05:05:00+03	66800.00
F8A944	2017-08-10 06:07:00+03	111600.00
F8A983	2017-07-13 01:04:00+03	168000.00
F8A9F5	2017-07-27 05:01:00+03	23200.00
F8AA25	2017-07-18 05:29:00+03	193600.00
F8AA39	2017-07-01 03:27:00+03	37200.00
F8AACC	2017-08-04 17:15:00+03	40800.00
F8AB00	2017-07-28 08:29:00+03	84100.00
F8AB09	2017-08-09 21:47:00+03	11600.00
F8AB3E	2017-08-02 03:24:00+03	81600.00
F8AB52	2017-08-02 20:14:00+03	26000.00
F8ABC5	2017-07-30 18:45:00+03	29600.00
F8ABD2	2017-08-05 23:31:00+03	28000.00
F8ABE0	2017-07-13 15:09:00+03	31600.00
F8AC7B	2017-07-12 00:27:00+03	61800.00
F8AC9D	2017-07-16 04:23:00+03	36100.00
F8ACE0	2017-08-02 08:58:00+03	160800.00
F8ACEA	2017-07-09 20:01:00+03	31400.00
F8AD04	2017-07-21 08:22:00+03	21800.00
F8AD05	2017-08-08 12:45:00+03	174000.00
F8AD8C	2017-08-10 01:09:00+03	265700.00
F8ADAE	2017-07-18 15:13:00+03	7400.00
F8ADB0	2017-07-17 02:45:00+03	36200.00
F8ADBB	2017-07-20 03:27:00+03	92600.00
F8ADEF	2017-07-21 07:27:00+03	81300.00
F8AE19	2017-08-11 12:01:00+03	80200.00
F8AE44	2017-07-05 19:04:00+03	24800.00
F8AE74	2017-07-10 09:04:00+03	17600.00
F8AEB8	2017-07-06 09:36:00+03	28800.00
F8AECD	2017-07-29 14:52:00+03	70400.00
F8AF69	2017-07-31 12:09:00+03	71000.00
F8AFA1	2017-08-01 06:28:00+03	46000.00
F8B04A	2017-08-04 06:13:00+03	41200.00
F8B12C	2017-07-29 22:28:00+03	46800.00
F8B13F	2017-07-10 21:50:00+03	12400.00
F8B1D9	2017-07-05 21:55:00+03	149800.00
F8B1E0	2017-08-09 03:40:00+03	69000.00
F8B21F	2017-08-02 23:46:00+03	56100.00
F8B28A	2017-08-12 09:28:00+03	57600.00
F8B2C5	2017-08-10 04:06:00+03	249100.00
F8B301	2017-08-12 10:24:00+03	65500.00
F8B370	2017-08-04 00:45:00+03	8200.00
F8B3B8	2017-08-04 09:21:00+03	39300.00
F8B3C7	2017-07-06 02:01:00+03	90400.00
F8B3FD	2017-07-26 12:38:00+03	38400.00
F8B40F	2017-07-11 11:10:00+03	56600.00
F8B482	2017-07-09 20:38:00+03	29600.00
F8B4DA	2017-07-29 07:09:00+03	27200.00
F8B525	2017-08-08 18:03:00+03	46000.00
F8B53D	2017-07-11 04:06:00+03	26000.00
F8B553	2017-07-24 02:24:00+03	9000.00
F8B5D4	2017-07-22 02:44:00+03	56600.00
F8B67C	2017-07-03 18:49:00+03	123000.00
F8B69B	2017-08-06 02:02:00+03	73600.00
F8B6EA	2017-07-08 17:57:00+03	67000.00
F8B6F1	2017-08-06 19:25:00+03	272300.00
F8B746	2017-07-30 11:52:00+03	42900.00
F8B74B	2017-07-06 19:09:00+03	56600.00
F8B775	2017-07-14 01:18:00+03	23600.00
F8B7CA	2017-07-01 03:46:00+03	57800.00
F8B7D3	2017-08-11 05:52:00+03	147000.00
F8B84A	2017-07-25 16:36:00+03	55800.00
F8B897	2017-07-11 22:05:00+03	22000.00
F8B89F	2017-07-12 15:37:00+03	43200.00
F8B8F2	2017-08-11 16:51:00+03	284400.00
F8BA40	2017-08-05 17:09:00+03	133200.00
F8BA54	2017-07-13 08:46:00+03	22000.00
F8BA7B	2017-08-02 16:37:00+03	22000.00
F8BA8A	2017-07-14 04:06:00+03	106400.00
F8BA9A	2017-07-10 17:05:00+03	147700.00
F8BAA3	2017-07-20 02:35:00+03	167400.00
F8BAC4	2017-07-14 21:22:00+03	23200.00
F8BAE4	2017-07-21 16:33:00+03	175300.00
F8BB3E	2017-07-26 14:05:00+03	26800.00
F8BBB9	2017-07-14 19:03:00+03	55600.00
F8BBC2	2017-08-01 09:31:00+03	16400.00
F8BC21	2017-06-28 13:40:00+03	58400.00
F8BC36	2017-08-10 21:12:00+03	30000.00
F8BCE4	2017-07-29 12:39:00+03	125300.00
F8BD54	2017-07-01 22:48:00+03	12400.00
F8BE18	2017-07-07 06:00:00+03	35800.00
F8BE73	2017-06-30 13:27:00+03	64200.00
F8BE7A	2017-07-31 05:26:00+03	47200.00
F8BED7	2017-08-02 22:17:00+03	90400.00
F8BF43	2017-08-09 20:16:00+03	15800.00
F8BF46	2017-06-27 06:04:00+03	78000.00
F8BF54	2017-07-13 21:06:00+03	40700.00
F8BFCE	2017-07-21 12:22:00+03	386300.00
F8BFD3	2017-07-09 23:23:00+03	60700.00
F8C088	2017-08-03 21:11:00+03	24800.00
F8C093	2017-07-06 03:12:00+03	99300.00
F8C099	2017-07-20 19:03:00+03	265700.00
F8C0C9	2017-08-01 18:37:00+03	58400.00
F8C0FF	2017-08-05 22:42:00+03	162300.00
F8C117	2017-07-11 10:14:00+03	68100.00
F8C11D	2017-07-16 07:42:00+03	43600.00
F8C151	2017-08-04 08:22:00+03	53500.00
F8C17A	2017-07-18 07:56:00+03	13200.00
F8C196	2017-07-23 15:17:00+03	66600.00
F8C1A1	2017-07-09 22:11:00+03	297000.00
F8C1FC	2017-08-11 09:30:00+03	26000.00
F8C2EC	2017-07-12 18:29:00+03	62800.00
F8C319	2017-07-17 03:48:00+03	55800.00
F8C31F	2017-07-03 18:54:00+03	29600.00
F8C345	2017-07-31 22:21:00+03	125400.00
F8C3E2	2017-07-08 05:28:00+03	101000.00
F8C3F2	2017-08-09 22:57:00+03	64700.00
F8C40B	2017-07-14 20:51:00+03	29600.00
F8C410	2017-07-08 01:45:00+03	59800.00
F8C412	2017-06-30 16:18:00+03	55800.00
F8C415	2017-07-06 12:16:00+03	48800.00
F8C495	2017-07-25 05:35:00+03	56000.00
F8C49F	2017-07-12 18:14:00+03	117200.00
F8C502	2017-06-27 01:22:00+03	64500.00
F8C5FE	2017-07-24 16:15:00+03	66000.00
F8C65A	2017-07-17 00:28:00+03	138000.00
F8C66C	2017-08-13 05:33:00+03	78000.00
F8C6AB	2017-07-06 02:26:00+03	40800.00
F8C6C9	2017-08-15 04:28:00+03	63700.00
F8C7A5	2017-07-16 18:54:00+03	40800.00
F8C854	2017-07-14 19:34:00+03	26800.00
F8C871	2017-07-22 21:23:00+03	105000.00
F8C885	2017-07-28 19:51:00+03	46800.00
F8C8A9	2017-07-18 13:30:00+03	29800.00
F8C8BE	2017-07-28 10:44:00+03	89700.00
F8C8C5	2017-08-02 22:41:00+03	155000.00
F8C8D6	2017-07-06 05:37:00+03	185700.00
F8C8DE	2017-08-04 15:06:00+03	30200.00
F8C8F3	2017-07-16 16:27:00+03	114300.00
F8C930	2017-07-03 07:12:00+03	44400.00
F8C9D1	2017-08-01 09:28:00+03	12600.00
F8C9F0	2017-07-17 09:04:00+03	75600.00
F8C9F1	2017-07-15 05:01:00+03	17000.00
F8CA2C	2017-08-01 21:32:00+03	67700.00
F8CA4D	2017-07-12 09:53:00+03	78800.00
F8CA65	2017-07-08 11:50:00+03	59800.00
F8CA6A	2017-07-19 02:58:00+03	111300.00
F8CAC4	2017-08-06 03:28:00+03	46400.00
F8CACA	2017-07-23 07:00:00+03	38400.00
F8CAF9	2017-07-14 14:46:00+03	56900.00
F8CB0D	2017-07-11 05:47:00+03	281500.00
F8CB50	2017-07-20 23:31:00+03	129600.00
F8CB5D	2017-07-14 03:07:00+03	48800.00
F8CB9D	2017-07-02 14:39:00+03	202100.00
F8CC5B	2017-07-29 19:32:00+03	101200.00
F8CCB0	2017-07-20 20:32:00+03	123000.00
F8CCFF	2017-07-31 03:06:00+03	35600.00
F8CD1E	2017-07-12 17:39:00+03	94800.00
F8CD21	2017-06-30 11:01:00+03	27000.00
F8CD4D	2017-08-13 17:03:00+03	61400.00
F8CD6D	2017-08-13 07:01:00+03	56600.00
F8CD97	2017-07-30 16:45:00+03	32700.00
F8CDC0	2017-07-26 18:23:00+03	22000.00
F8CEA5	2017-07-04 13:44:00+03	62800.00
F8CF01	2017-07-27 23:13:00+03	36600.00
F8CF27	2017-06-29 07:13:00+03	25200.00
F8D062	2017-07-07 00:59:00+03	16400.00
F8D07E	2017-07-17 22:13:00+03	23400.00
F8D086	2017-07-23 07:17:00+03	265600.00
F8D090	2017-08-08 10:07:00+03	54500.00
F8D0AF	2017-07-06 10:29:00+03	26700.00
F8D11C	2017-07-27 19:50:00+03	21800.00
F8D177	2017-08-02 06:49:00+03	38400.00
F8D1AC	2017-07-03 12:37:00+03	87200.00
F8D1BC	2017-07-11 08:38:00+03	148200.00
F8D1E2	2017-07-03 14:35:00+03	83000.00
F8D1F5	2017-07-30 23:29:00+03	36200.00
F8D1F7	2017-07-12 09:23:00+03	46300.00
F8D225	2017-07-29 21:37:00+03	86500.00
F8D22A	2017-08-11 01:53:00+03	369700.00
F8D268	2017-07-18 01:06:00+03	42900.00
F8D273	2017-07-15 06:44:00+03	70400.00
F8D35D	2017-06-28 01:27:00+03	122700.00
F8D3CD	2017-07-18 15:04:00+03	36800.00
F8D3F6	2017-07-20 14:36:00+03	55800.00
F8D461	2017-08-08 04:22:00+03	56900.00
F8D4B8	2017-07-29 13:06:00+03	94900.00
F8D62B	2017-08-11 16:55:00+03	12400.00
F8D669	2017-07-29 20:12:00+03	84000.00
F8D673	2017-07-15 18:53:00+03	101200.00
F8D679	2017-08-01 06:48:00+03	103500.00
F8D6AE	2017-07-18 16:25:00+03	17800.00
F8D6B1	2017-08-15 13:16:00+03	13400.00
F8D6F2	2017-07-30 05:45:00+03	25100.00
F8D70D	2017-08-11 03:48:00+03	60000.00
F8D778	2017-07-11 10:42:00+03	30400.00
F8D792	2017-07-31 02:13:00+03	21800.00
F8D7C5	2017-08-06 18:12:00+03	34600.00
F8D7CA	2017-07-06 04:40:00+03	50000.00
F8D7D5	2017-07-14 14:42:00+03	85000.00
F8D842	2017-07-03 10:27:00+03	84300.00
F8D8AF	2017-08-03 10:00:00+03	28000.00
F8D8CD	2017-08-15 04:40:00+03	32700.00
F8D921	2017-07-29 10:37:00+03	81500.00
F8D9A5	2017-07-09 23:30:00+03	20400.00
F8D9D6	2017-07-22 21:54:00+03	37200.00
F8D9E0	2017-08-07 11:09:00+03	153200.00
F8D9EA	2017-07-19 10:18:00+03	56100.00
F8D9F1	2017-07-13 00:39:00+03	22000.00
F8D9F5	2017-07-16 03:44:00+03	46300.00
F8DA72	2017-07-29 01:23:00+03	100400.00
F8DB2D	2017-07-03 14:54:00+03	46000.00
F8DB45	2017-07-04 22:04:00+03	76600.00
F8DC2F	2017-08-13 21:46:00+03	115600.00
F8DC94	2017-08-09 19:56:00+03	21400.00
F8DC97	2017-07-27 07:07:00+03	8600.00
F8DCDE	2017-08-12 11:50:00+03	78200.00
F8DCFA	2017-07-19 15:05:00+03	84100.00
F8DD25	2017-06-30 08:33:00+03	57100.00
F8DD9E	2017-07-01 21:38:00+03	37800.00
F8DDDA	2017-07-28 04:06:00+03	89500.00
F8DDEE	2017-07-15 15:49:00+03	164100.00
F8DE1B	2017-07-05 06:05:00+03	24600.00
F8DECD	2017-07-22 23:14:00+03	70500.00
F8DED6	2017-08-05 05:32:00+03	124200.00
F8DEED	2017-07-20 03:05:00+03	19600.00
F8DF53	2017-07-15 16:40:00+03	22600.00
F8DF97	2017-08-14 08:39:00+03	67100.00
F8DFEF	2017-07-31 02:57:00+03	419000.00
F8E08A	2017-07-21 06:48:00+03	58400.00
F8E096	2017-08-06 06:52:00+03	136800.00
F8E0CC	2017-07-07 05:18:00+03	25200.00
F8E0F9	2017-08-13 23:05:00+03	39500.00
F8E123	2017-08-01 19:25:00+03	43000.00
F8E12D	2017-08-11 19:01:00+03	48900.00
F8E158	2017-08-02 06:22:00+03	128300.00
F8E18B	2017-07-23 23:58:00+03	36200.00
F8E1A1	2017-07-27 21:37:00+03	68400.00
F8E1A6	2017-08-01 06:32:00+03	16400.00
F8E1BC	2017-06-29 16:16:00+03	32700.00
F8E1E7	2017-07-30 07:12:00+03	369000.00
F8E25F	2017-08-13 19:26:00+03	25400.00
F8E260	2017-07-05 07:06:00+03	31800.00
F8E26E	2017-08-10 02:04:00+03	105000.00
F8E281	2017-08-12 20:38:00+03	406700.00
F8E28D	2017-08-14 21:58:00+03	102100.00
F8E2A3	2017-07-02 23:19:00+03	28800.00
F8E2C1	2017-08-01 23:51:00+03	116700.00
F8E2E9	2017-07-10 14:41:00+03	10800.00
F8E35B	2017-08-07 06:24:00+03	37900.00
F8E36C	2017-07-21 10:18:00+03	133200.00
F8E389	2017-07-22 16:19:00+03	13000.00
F8E399	2017-07-01 13:20:00+03	40600.00
F8E39D	2017-07-30 13:21:00+03	65900.00
F8E3A9	2017-07-05 11:06:00+03	28000.00
F8E3BA	2017-08-09 16:26:00+03	266400.00
F8E437	2017-06-30 04:36:00+03	47000.00
F8E456	2017-07-11 00:22:00+03	197000.00
F8E4E0	2017-07-16 22:36:00+03	12400.00
F8E53D	2017-08-05 14:01:00+03	131600.00
F8E598	2017-08-15 07:54:00+03	106800.00
F8E5B2	2017-07-16 19:51:00+03	188000.00
F8E5D2	2017-08-13 09:59:00+03	521800.00
F8E600	2017-07-28 01:24:00+03	98400.00
F8E607	2017-07-19 15:51:00+03	51600.00
F8E66F	2017-07-02 12:27:00+03	60700.00
F8E671	2017-07-29 03:39:00+03	103500.00
F8E701	2017-08-09 02:30:00+03	127000.00
F8E72E	2017-07-12 00:24:00+03	78500.00
F8E74B	2017-06-30 03:28:00+03	8000.00
F8E758	2017-08-05 11:47:00+03	70500.00
F8E764	2017-08-14 19:10:00+03	124000.00
F8E770	2017-07-06 19:14:00+03	213200.00
F8E78A	2017-07-02 19:20:00+03	28800.00
F8E7B8	2017-07-19 18:24:00+03	369000.00
F8E821	2017-06-29 10:40:00+03	19600.00
F8E875	2017-07-26 14:37:00+03	24400.00
F8E885	2017-08-05 17:33:00+03	135400.00
F8E89F	2017-07-14 13:09:00+03	64800.00
F8E8B4	2017-07-19 12:36:00+03	60800.00
F8E8E8	2017-07-09 09:21:00+03	14000.00
F8E8F0	2017-07-03 09:24:00+03	40800.00
F8E8FB	2017-07-19 14:13:00+03	75600.00
F8E957	2017-08-12 19:25:00+03	37900.00
F8E96E	2017-06-27 19:53:00+03	109000.00
F8E9BF	2017-06-29 21:45:00+03	111400.00
F8E9CB	2017-07-07 01:47:00+03	18300.00
F8E9F7	2017-07-05 06:31:00+03	184300.00
F8EA01	2017-07-28 19:46:00+03	62800.00
F8EA62	2017-07-20 02:03:00+03	37900.00
F8EA66	2017-08-14 06:58:00+03	40200.00
F8EA94	2017-07-11 20:28:00+03	52400.00
F8EAA2	2017-07-16 18:50:00+03	73000.00
F8EAD0	2017-07-21 08:56:00+03	49600.00
F8EAED	2017-08-14 15:38:00+03	143900.00
F8EB43	2017-07-15 00:36:00+03	112000.00
F8EB64	2017-07-21 19:54:00+03	112000.00
F8EBAB	2017-08-05 12:58:00+03	26000.00
F8EBAF	2017-07-17 00:14:00+03	6300.00
F8EBD8	2017-07-02 21:08:00+03	140100.00
F8EC04	2017-07-04 23:04:00+03	24400.00
F8EC43	2017-07-17 03:40:00+03	77600.00
F8ECD7	2017-08-03 11:10:00+03	25100.00
F8ECDC	2017-08-11 14:08:00+03	26700.00
F8ED7C	2017-07-08 10:14:00+03	56000.00
F8EDC4	2017-08-01 08:43:00+03	14400.00
F8EE39	2017-07-15 19:22:00+03	156400.00
F8EE5F	2017-07-31 18:08:00+03	8200.00
F8EE89	2017-08-13 10:52:00+03	52800.00
F8EED3	2017-07-23 03:48:00+03	44800.00
F8EF1E	2017-07-18 18:10:00+03	27900.00
F8EF58	2017-08-01 06:34:00+03	64400.00
F8EF63	2017-08-08 18:42:00+03	87100.00
F8EFBA	2017-07-30 10:50:00+03	21800.00
F8EFCE	2017-07-03 19:48:00+03	14000.00
F8F008	2017-07-29 04:07:00+03	44000.00
F8F021	2017-08-09 09:30:00+03	61700.00
F8F03A	2017-07-19 06:42:00+03	47800.00
F8F045	2017-07-29 07:09:00+03	66600.00
F8F08C	2017-07-22 09:03:00+03	115600.00
F8F0F7	2017-07-08 19:41:00+03	105100.00
F8F12A	2017-08-13 06:14:00+03	125200.00
F8F176	2017-07-20 04:02:00+03	44000.00
F8F18A	2017-08-10 10:36:00+03	101600.00
F8F21D	2017-08-15 02:31:00+03	13400.00
F8F236	2017-08-14 22:43:00+03	27200.00
F8F253	2017-08-11 20:14:00+03	56600.00
F8F283	2017-07-19 07:56:00+03	138800.00
F8F309	2017-08-08 02:04:00+03	6700.00
F8F334	2017-07-12 10:34:00+03	56000.00
F8F37B	2017-08-01 20:47:00+03	66000.00
F8F3AE	2017-07-16 00:08:00+03	28800.00
F8F3D6	2017-08-14 17:01:00+03	147200.00
F8F431	2017-07-24 05:33:00+03	72400.00
F8F446	2017-06-30 04:05:00+03	30000.00
F8F46F	2017-07-28 06:51:00+03	39200.00
F8F490	2017-08-08 17:13:00+03	20100.00
F8F492	2017-07-14 16:05:00+03	354400.00
F8F4A3	2017-07-19 17:14:00+03	46200.00
F8F4DD	2017-07-17 19:03:00+03	111000.00
F8F4E2	2017-07-21 20:32:00+03	167900.00
F8F50C	2017-08-11 01:03:00+03	154500.00
F8F580	2017-07-28 18:53:00+03	73300.00
F8F5A1	2017-07-17 04:20:00+03	25800.00
F8F5BC	2017-07-10 18:09:00+03	36800.00
F8F629	2017-07-05 04:55:00+03	117900.00
F8F66B	2017-07-15 19:23:00+03	19600.00
F8F6B9	2017-07-26 05:26:00+03	70700.00
F8F6DE	2017-07-10 05:09:00+03	31900.00
F8F6E1	2017-08-14 02:52:00+03	67200.00
F8F707	2017-07-29 23:30:00+03	56900.00
F8F79A	2017-08-02 03:27:00+03	54500.00
F8F7F2	2017-08-07 00:12:00+03	58200.00
F8F8A4	2017-08-01 20:32:00+03	51600.00
F8F90F	2017-07-10 19:51:00+03	57600.00
F8F92F	2017-08-07 11:31:00+03	28700.00
F8F93A	2017-07-07 23:45:00+03	74600.00
F8F942	2017-07-26 10:21:00+03	91100.00
F8F947	2017-08-12 11:51:00+03	260900.00
F8F9EE	2017-08-10 22:55:00+03	47700.00
F8FA03	2017-06-30 05:50:00+03	114700.00
F8FA40	2017-07-06 18:31:00+03	221800.00
F8FAB3	2017-07-14 17:35:00+03	40000.00
F8FAD1	2017-07-18 17:16:00+03	101200.00
F8FB1A	2017-07-30 15:21:00+03	71200.00
F8FB35	2017-07-04 09:34:00+03	266400.00
F8FB4B	2017-07-30 23:01:00+03	73600.00
F8FBD6	2017-07-09 02:30:00+03	44000.00
F8FBE2	2017-07-29 18:44:00+03	165800.00
F8FBF3	2017-07-10 06:26:00+03	75600.00
F8FC07	2017-07-25 09:38:00+03	226400.00
F8FC64	2017-08-07 02:02:00+03	81600.00
F8FC7F	2017-07-10 22:16:00+03	167400.00
F8FC89	2017-08-01 04:07:00+03	58600.00
F8FCE7	2017-07-14 13:49:00+03	56000.00
F8FD1F	2017-07-16 16:56:00+03	90300.00
F8FD87	2017-07-16 07:27:00+03	75200.00
F8FDC2	2017-07-21 08:46:00+03	14400.00
F8FDCB	2017-08-07 02:36:00+03	100600.00
F8FE19	2017-07-09 20:29:00+03	43600.00
F8FE2C	2017-07-09 02:56:00+03	10800.00
F8FE2D	2017-07-11 02:01:00+03	233000.00
F8FE36	2017-08-07 11:39:00+03	61100.00
F8FEBB	2017-07-30 13:33:00+03	164800.00
F8FEDE	2017-08-12 04:59:00+03	120300.00
F8FF14	2017-07-12 14:07:00+03	100700.00
F8FFA4	2017-08-08 19:06:00+03	16400.00
F8FFFB	2017-07-28 02:18:00+03	78000.00
F900A0	2017-07-02 16:58:00+03	12600.00
F900A4	2017-07-24 22:11:00+03	49700.00
F900AB	2017-08-05 01:40:00+03	25600.00
F900AD	2017-08-01 18:21:00+03	75300.00
F900F8	2017-08-13 03:48:00+03	6600.00
F9011C	2017-07-18 09:34:00+03	52000.00
F90130	2017-07-01 09:19:00+03	40800.00
F90215	2017-07-18 03:51:00+03	8600.00
F902B7	2017-07-31 12:00:00+03	31600.00
F90314	2017-07-06 22:10:00+03	23200.00
F9034C	2017-07-03 18:16:00+03	114800.00
F9041C	2017-08-13 19:45:00+03	6700.00
F90435	2017-07-01 16:49:00+03	14800.00
F90443	2017-07-11 06:38:00+03	39500.00
F90467	2017-07-30 05:20:00+03	26400.00
F904EB	2017-07-14 20:36:00+03	97900.00
F9050F	2017-07-18 11:28:00+03	88500.00
F9053B	2017-07-28 20:52:00+03	164700.00
F90549	2017-07-08 19:21:00+03	68400.00
F9057D	2017-08-13 13:29:00+03	17000.00
F90585	2017-07-15 12:59:00+03	24300.00
F905AF	2017-07-14 12:34:00+03	24200.00
F905D3	2017-07-28 05:30:00+03	186900.00
F90603	2017-08-03 20:21:00+03	85000.00
F90605	2017-07-20 10:26:00+03	54800.00
F90622	2017-08-12 19:47:00+03	285500.00
F9063F	2017-07-11 23:59:00+03	54800.00
F90652	2017-07-05 01:06:00+03	46000.00
F906B0	2017-07-03 23:37:00+03	24700.00
F90722	2017-07-18 02:07:00+03	14300.00
F9079A	2017-07-06 17:08:00+03	48800.00
F907D6	2017-08-11 12:57:00+03	99200.00
F90853	2017-07-31 08:30:00+03	28800.00
F9085E	2017-07-22 05:58:00+03	63000.00
F908F5	2017-07-08 23:36:00+03	49100.00
F90973	2017-07-13 20:08:00+03	83600.00
F909D7	2017-08-09 12:24:00+03	283100.00
F90A4C	2017-08-01 00:21:00+03	28000.00
F90A62	2017-07-04 00:49:00+03	56200.00
F90A8D	2017-07-31 14:25:00+03	166900.00
F90AC5	2017-08-13 03:44:00+03	98000.00
F90AFA	2017-08-12 14:18:00+03	18500.00
F90B05	2017-07-17 20:03:00+03	123000.00
F90B33	2017-07-14 12:00:00+03	65500.00
F90B3A	2017-07-18 19:31:00+03	124200.00
F90B66	2017-08-01 08:07:00+03	12600.00
F90B8B	2017-07-27 07:55:00+03	240600.00
F90C3C	2017-07-20 12:46:00+03	92700.00
F90C7F	2017-08-12 20:17:00+03	136800.00
F90D86	2017-07-07 06:22:00+03	93700.00
F90D88	2017-07-18 23:00:00+03	112500.00
F90D98	2017-07-10 16:15:00+03	28300.00
F90DA6	2017-07-19 11:07:00+03	156300.00
F90DAF	2017-07-10 10:48:00+03	19000.00
F90DF5	2017-08-05 10:38:00+03	96800.00
F90DFB	2017-07-26 12:12:00+03	164000.00
F90E00	2017-08-14 17:51:00+03	89700.00
F90E1E	2017-07-22 10:32:00+03	33300.00
F90EB1	2017-07-22 05:53:00+03	99700.00
F90EE2	2017-07-26 23:12:00+03	27400.00
F90F03	2017-07-03 07:01:00+03	70100.00
F90F1E	2017-08-10 09:49:00+03	21400.00
F90F85	2017-07-04 01:32:00+03	106700.00
F90FFC	2017-07-10 10:58:00+03	39200.00
F9102D	2017-07-24 05:33:00+03	153800.00
F91061	2017-08-03 11:09:00+03	177200.00
F9111B	2017-07-17 08:15:00+03	266300.00
F91137	2017-07-11 18:11:00+03	29600.00
F911B3	2017-08-07 14:46:00+03	38600.00
F9120F	2017-07-01 12:00:00+03	28800.00
F91256	2017-07-19 01:35:00+03	114800.00
F912B0	2017-07-14 22:52:00+03	46400.00
F912C4	2017-07-04 20:24:00+03	257500.00
F912C6	2017-07-02 11:18:00+03	56200.00
F9136A	2017-07-21 19:53:00+03	100000.00
F91384	2017-07-02 07:45:00+03	57400.00
F913A2	2017-07-30 01:00:00+03	44800.00
F913A5	2017-07-29 14:56:00+03	15400.00
F9143C	2017-07-04 11:32:00+03	23200.00
F914AC	2017-06-28 13:32:00+03	81200.00
F91563	2017-08-06 19:54:00+03	36000.00
F9156B	2017-06-27 17:08:00+03	64600.00
F915B0	2017-08-11 19:10:00+03	266300.00
F915D3	2017-07-31 22:59:00+03	67100.00
F91607	2017-07-09 19:59:00+03	95600.00
F91623	2017-06-30 09:59:00+03	37900.00
F91648	2017-07-09 15:27:00+03	47000.00
F91673	2017-07-14 01:13:00+03	22000.00
F91756	2017-07-09 10:02:00+03	97800.00
F91768	2017-08-13 22:41:00+03	94200.00
F917D5	2017-08-10 16:59:00+03	99700.00
F91816	2017-07-13 02:11:00+03	16400.00
F9187A	2017-07-03 10:13:00+03	62600.00
F9188F	2017-08-01 20:07:00+03	59300.00
F918D1	2017-07-27 20:06:00+03	174300.00
F91959	2017-07-13 05:28:00+03	14800.00
F91961	2017-08-09 09:02:00+03	65900.00
F9196D	2017-08-10 07:07:00+03	69500.00
F9199D	2017-08-06 12:45:00+03	6700.00
F919A0	2017-08-01 00:55:00+03	4000.00
F91A07	2017-07-29 10:44:00+03	25600.00
F91A73	2017-08-01 12:33:00+03	9300.00
F91A8D	2017-07-06 04:53:00+03	24800.00
F91B23	2017-08-15 10:19:00+03	24400.00
F91B30	2017-07-14 02:12:00+03	43200.00
F91BBA	2017-08-01 01:34:00+03	37900.00
F91C0A	2017-06-30 23:16:00+03	34100.00
F91C54	2017-07-08 21:05:00+03	19800.00
F91C71	2017-07-01 17:35:00+03	22000.00
F91C90	2017-07-28 19:14:00+03	81700.00
F91C93	2017-08-11 10:29:00+03	111600.00
F91C9B	2017-08-07 22:48:00+03	114800.00
F91D31	2017-07-31 15:17:00+03	133200.00
F91D5E	2017-07-05 16:57:00+03	182400.00
F91D98	2017-07-31 03:30:00+03	51800.00
F91DA3	2017-07-21 07:47:00+03	26600.00
F91DED	2017-07-26 06:29:00+03	124100.00
F91DF5	2017-07-03 12:12:00+03	55800.00
F91DFD	2017-07-18 07:20:00+03	24800.00
F91E13	2017-08-08 21:55:00+03	52800.00
F91E66	2017-08-13 16:54:00+03	43200.00
F91E9A	2017-07-11 17:29:00+03	150400.00
F91EAB	2017-07-30 19:31:00+03	38800.00
F91EC6	2017-07-22 09:10:00+03	46200.00
F91F94	2017-07-06 00:58:00+03	37200.00
F92007	2017-08-11 21:40:00+03	26000.00
F92050	2017-07-17 01:07:00+03	12600.00
F92092	2017-07-23 02:03:00+03	14400.00
F920EA	2017-07-18 19:00:00+03	46400.00
F9215D	2017-07-11 18:21:00+03	50800.00
F92180	2017-07-31 13:23:00+03	21400.00
F9219E	2017-08-02 06:16:00+03	100600.00
F921C8	2017-08-03 21:07:00+03	56000.00
F92280	2017-08-15 06:41:00+03	70700.00
F922A2	2017-07-28 03:46:00+03	155600.00
F922E2	2017-07-08 02:29:00+03	21800.00
F92324	2017-08-01 16:45:00+03	56000.00
F92342	2017-06-29 06:55:00+03	67600.00
F923AF	2017-07-18 02:55:00+03	28000.00
F923BD	2017-08-01 15:49:00+03	67600.00
F923D2	2017-07-19 07:49:00+03	13400.00
F923DF	2017-07-06 18:55:00+03	160700.00
F92432	2017-07-24 15:17:00+03	67800.00
F924AA	2017-07-08 14:26:00+03	7400.00
F924D7	2017-08-08 02:09:00+03	18600.00
F92565	2017-07-30 19:33:00+03	10600.00
F9257F	2017-07-03 04:56:00+03	77500.00
F925EE	2017-07-19 11:30:00+03	22200.00
F92694	2017-07-20 16:10:00+03	135300.00
F926B1	2017-08-09 23:43:00+03	28000.00
F9276C	2017-08-02 02:40:00+03	229800.00
F927DE	2017-07-01 22:14:00+03	57600.00
F92803	2017-07-26 18:59:00+03	21400.00
F92818	2017-07-05 11:54:00+03	29600.00
F92894	2017-07-03 15:11:00+03	14000.00
F928DA	2017-07-10 06:28:00+03	27300.00
F92904	2017-07-04 19:57:00+03	29400.00
F92928	2017-07-10 14:52:00+03	87900.00
F92933	2017-08-12 22:01:00+03	63400.00
F9294C	2017-07-31 05:08:00+03	50400.00
F92959	2017-07-21 10:03:00+03	123600.00
F92967	2017-08-13 17:14:00+03	167400.00
F92992	2017-07-28 12:11:00+03	122000.00
F929B6	2017-07-13 20:36:00+03	194200.00
F929FB	2017-08-04 16:44:00+03	23200.00
F92A36	2017-08-10 14:18:00+03	59800.00
F92B0F	2017-07-12 11:47:00+03	73600.00
F92B1C	2017-08-05 18:41:00+03	14800.00
F92B30	2017-07-14 13:51:00+03	168700.00
F92B58	2017-07-04 11:06:00+03	23400.00
F92B6A	2017-08-12 02:11:00+03	30000.00
F92B73	2017-06-30 07:48:00+03	21400.00
F92BC9	2017-07-27 18:30:00+03	71900.00
F92DAE	2017-07-19 18:44:00+03	113200.00
F92DD6	2017-07-19 21:44:00+03	234700.00
F92DF4	2017-08-02 20:58:00+03	35800.00
F92E40	2017-08-15 05:42:00+03	27200.00
F92E6C	2017-08-15 05:42:00+03	109600.00
F92E8F	2017-07-18 06:24:00+03	268800.00
F92F59	2017-07-22 14:06:00+03	67600.00
F92FB5	2017-07-15 04:54:00+03	27900.00
F92FD8	2017-08-08 07:03:00+03	53400.00
F93011	2017-07-24 22:44:00+03	123600.00
F9311F	2017-08-12 23:18:00+03	49800.00
F93133	2017-07-09 16:56:00+03	65400.00
F9319F	2017-07-18 03:06:00+03	23600.00
F931A3	2017-08-02 01:50:00+03	19000.00
F931C1	2017-07-01 10:32:00+03	166100.00
F9321C	2017-08-02 03:20:00+03	46700.00
F93235	2017-08-11 00:44:00+03	59800.00
F93276	2017-07-21 11:37:00+03	18000.00
F93294	2017-07-09 22:24:00+03	127300.00
F932A8	2017-08-03 10:39:00+03	57600.00
F932B8	2017-07-17 13:38:00+03	266400.00
F932CE	2017-07-15 19:39:00+03	20400.00
F93309	2017-07-08 00:40:00+03	252400.00
F93335	2017-08-01 23:29:00+03	42800.00
F9334B	2017-07-23 14:25:00+03	73300.00
F933B5	2017-08-11 09:41:00+03	196100.00
F933E3	2017-07-25 20:42:00+03	46000.00
F934D4	2017-07-02 19:05:00+03	38600.00
F9350B	2017-08-03 00:14:00+03	61500.00
F93529	2017-06-26 23:28:00+03	55800.00
F93578	2017-08-12 16:21:00+03	24400.00
F93583	2017-07-23 22:06:00+03	25200.00
F935C4	2017-08-13 06:58:00+03	62600.00
F935DA	2017-07-29 18:08:00+03	57600.00
F9361B	2017-07-08 22:19:00+03	116800.00
F9363A	2017-08-13 06:59:00+03	54300.00
F936AB	2017-07-14 04:11:00+03	56100.00
F936AE	2017-07-05 15:56:00+03	38600.00
F937BA	2017-08-15 08:12:00+03	46800.00
F93803	2017-07-26 13:29:00+03	44300.00
F93837	2017-07-25 07:49:00+03	28800.00
F9383C	2017-06-26 03:41:00+03	61800.00
F93884	2017-07-29 22:21:00+03	56100.00
F938CF	2017-07-04 08:06:00+03	37700.00
F93923	2017-08-15 00:31:00+03	81400.00
F93930	2017-08-14 07:27:00+03	132700.00
F93949	2017-07-09 08:27:00+03	81200.00
F93977	2017-07-09 04:45:00+03	85500.00
F939C6	2017-07-03 10:43:00+03	111400.00
F939D7	2017-08-14 22:57:00+03	6800.00
F939ED	2017-07-05 13:18:00+03	39200.00
F93A0B	2017-07-24 11:08:00+03	112000.00
F93A3A	2017-07-25 21:22:00+03	111600.00
F93AA1	2017-08-03 21:11:00+03	38400.00
F93AC6	2017-07-30 20:35:00+03	67600.00
F93B10	2017-07-02 11:58:00+03	21000.00
F93B2C	2017-07-19 06:31:00+03	246000.00
F93B3B	2017-07-21 12:06:00+03	74400.00
F93BF1	2017-07-21 22:39:00+03	25600.00
F93C5C	2017-07-31 05:16:00+03	41600.00
F93CA1	2017-07-05 02:33:00+03	57600.00
F93CB0	2017-07-17 05:23:00+03	134900.00
F93D37	2017-08-03 03:19:00+03	93900.00
F93D63	2017-07-21 12:07:00+03	60400.00
F93D74	2017-07-06 08:08:00+03	188000.00
F93D9E	2017-07-17 02:09:00+03	24700.00
F93DAE	2017-07-24 02:37:00+03	28000.00
F93E00	2017-07-19 15:19:00+03	123600.00
F93E11	2017-07-21 01:42:00+03	59200.00
F93E5C	2017-07-05 20:55:00+03	23200.00
F93E69	2017-07-15 21:41:00+03	26700.00
F93ECC	2017-07-27 02:54:00+03	46500.00
F93EDA	2017-08-09 22:50:00+03	149300.00
F93EDF	2017-08-09 15:19:00+03	246000.00
F93EE5	2017-07-13 08:27:00+03	39500.00
F93EE9	2017-07-31 07:02:00+03	19800.00
F93F17	2017-07-22 02:30:00+03	220400.00
F9406B	2017-07-06 03:07:00+03	190400.00
F9407A	2017-07-24 14:29:00+03	26800.00
F94080	2017-07-11 05:58:00+03	44800.00
F940A5	2017-07-17 23:53:00+03	155600.00
F940C6	2017-08-01 09:30:00+03	14400.00
F940CD	2017-08-01 16:08:00+03	171600.00
F940EC	2017-06-28 10:07:00+03	57500.00
F9410A	2017-08-01 10:09:00+03	154500.00
F94127	2017-07-31 15:25:00+03	40700.00
F94129	2017-07-06 18:18:00+03	23100.00
F941D7	2017-08-10 05:52:00+03	165100.00
F9425F	2017-07-25 04:29:00+03	37900.00
F9426D	2017-07-11 00:34:00+03	36200.00
F942ED	2017-08-08 10:59:00+03	492000.00
F94308	2017-07-10 18:37:00+03	131900.00
F94334	2017-08-14 16:13:00+03	75000.00
F9437B	2017-08-08 04:31:00+03	30000.00
F9437D	2017-08-01 23:30:00+03	32800.00
F94384	2017-08-13 06:19:00+03	123000.00
F94386	2017-07-14 08:49:00+03	27200.00
F943C5	2017-07-25 08:53:00+03	26000.00
F943D8	2017-07-13 01:47:00+03	19600.00
F9441B	2017-08-10 09:42:00+03	44800.00
F94458	2017-07-30 16:34:00+03	54800.00
F94508	2017-07-13 12:09:00+03	13600.00
F94525	2017-08-02 12:09:00+03	45100.00
F94573	2017-07-29 23:32:00+03	99600.00
F94575	2017-07-21 09:45:00+03	23200.00
F945A1	2017-07-19 16:52:00+03	24700.00
F945AF	2017-07-24 07:08:00+03	66200.00
F945D3	2017-08-15 08:04:00+03	69600.00
F945EA	2017-08-13 09:42:00+03	67700.00
F94632	2017-06-28 05:49:00+03	516800.00
F94649	2017-07-13 23:35:00+03	12600.00
F9467A	2017-08-03 03:43:00+03	24200.00
F946DB	2017-07-13 20:07:00+03	55800.00
F94763	2017-08-08 13:43:00+03	100000.00
F947AA	2017-07-10 07:39:00+03	24400.00
F947BF	2017-08-10 14:34:00+03	8000.00
F94804	2017-08-01 12:16:00+03	66600.00
F9486A	2017-07-24 18:13:00+03	15700.00
F9492D	2017-07-08 23:08:00+03	113200.00
F94962	2017-07-25 06:14:00+03	55800.00
F94A26	2017-08-09 10:58:00+03	271200.00
F94A2A	2017-07-16 11:43:00+03	83000.00
F94A4C	2017-07-07 12:12:00+03	78600.00
F94A9A	2017-08-14 20:46:00+03	199300.00
F94AEC	2017-07-07 13:49:00+03	406100.00
F94B37	2017-07-26 10:07:00+03	116100.00
F94B41	2017-07-23 07:46:00+03	248300.00
F94B4D	2017-08-10 16:17:00+03	25600.00
F94B50	2017-07-22 05:36:00+03	103200.00
F94C1B	2017-07-17 08:15:00+03	48800.00
F94C38	2017-07-05 21:01:00+03	20200.00
F94C46	2017-08-15 11:49:00+03	88900.00
F94C84	2017-07-15 15:31:00+03	31700.00
F94CDA	2017-07-08 02:12:00+03	23600.00
F94CF5	2017-07-29 15:24:00+03	33100.00
F94D0B	2017-07-27 10:09:00+03	406700.00
F94D62	2017-07-17 03:40:00+03	64800.00
F94D77	2017-07-29 21:39:00+03	28000.00
F94D78	2017-07-27 11:27:00+03	24400.00
F94E36	2017-07-16 01:53:00+03	25200.00
F94E5E	2017-08-09 20:47:00+03	26000.00
F94E62	2017-07-15 14:12:00+03	123000.00
F94E69	2017-07-19 12:04:00+03	26700.00
F94E8D	2017-07-12 12:25:00+03	211100.00
F94EA1	2017-07-20 22:48:00+03	38400.00
F94EB0	2017-07-08 21:45:00+03	38700.00
F94F1B	2017-07-18 08:43:00+03	49400.00
F94F26	2017-07-28 06:59:00+03	58600.00
F94FA9	2017-07-22 14:34:00+03	132800.00
F94FE2	2017-07-23 05:54:00+03	60400.00
F9501A	2017-07-27 20:08:00+03	100200.00
F9502A	2017-08-07 15:50:00+03	64800.00
F95075	2017-07-10 02:52:00+03	50600.00
F95099	2017-08-11 17:38:00+03	123000.00
F9509D	2017-07-16 14:08:00+03	25200.00
F951AA	2017-08-11 07:46:00+03	26800.00
F951AC	2017-08-06 07:27:00+03	102100.00
F951F7	2017-07-16 14:38:00+03	21200.00
F9522D	2017-07-19 13:39:00+03	46400.00
F95251	2017-07-25 09:51:00+03	131100.00
F9528A	2017-07-07 15:41:00+03	175900.00
F9529E	2017-07-20 02:34:00+03	222400.00
F952B7	2017-07-11 06:37:00+03	109600.00
F952F8	2017-08-04 10:52:00+03	54800.00
F95306	2017-08-13 23:13:00+03	128800.00
F95307	2017-07-21 19:23:00+03	69300.00
F95344	2017-07-05 05:23:00+03	26000.00
F95382	2017-07-15 12:30:00+03	9800.00
F9542B	2017-07-10 23:25:00+03	26700.00
F95496	2017-07-30 18:04:00+03	102100.00
F954CF	2017-08-15 03:46:00+03	132800.00
F95650	2017-07-26 02:07:00+03	86300.00
F9569D	2017-08-12 11:27:00+03	45100.00
F956C8	2017-08-04 05:48:00+03	86400.00
F956E2	2017-08-01 06:48:00+03	73600.00
F95715	2017-08-11 16:59:00+03	21000.00
F9571D	2017-08-12 05:59:00+03	38000.00
F9576D	2017-08-11 01:14:00+03	271700.00
F95777	2017-07-23 18:15:00+03	144000.00
F95839	2017-07-15 00:27:00+03	73100.00
F95843	2017-07-28 09:36:00+03	12600.00
F9588F	2017-08-14 16:37:00+03	24000.00
F9596F	2017-07-05 18:30:00+03	32800.00
F959BA	2017-08-03 03:41:00+03	38500.00
F959EC	2017-07-24 23:40:00+03	369000.00
F95A0F	2017-07-27 03:05:00+03	23600.00
F95A96	2017-07-19 09:39:00+03	26300.00
F95AB0	2017-07-09 02:07:00+03	39800.00
F95ADB	2017-07-18 17:10:00+03	14400.00
F95B9C	2017-07-21 12:06:00+03	198400.00
F95C28	2017-07-14 15:27:00+03	75800.00
F95C3A	2017-07-21 12:02:00+03	21400.00
F95C44	2017-08-08 15:15:00+03	44700.00
F95C49	2017-08-06 18:41:00+03	21800.00
F95C58	2017-08-13 20:00:00+03	22000.00
F95C7C	2017-07-30 09:01:00+03	42600.00
F95C83	2017-08-09 22:20:00+03	81200.00
F95C8B	2017-08-11 04:25:00+03	54800.00
F95CCD	2017-08-13 14:07:00+03	46700.00
F95CE4	2017-08-13 18:31:00+03	27200.00
F95D04	2017-07-08 22:10:00+03	72200.00
F95D48	2017-08-01 20:04:00+03	65600.00
F95E3B	2017-08-04 07:39:00+03	26000.00
F95EC3	2017-08-11 03:40:00+03	29600.00
F95EC9	2017-08-01 23:06:00+03	122400.00
F95ED4	2017-08-08 15:43:00+03	31400.00
F95F0A	2017-08-13 10:39:00+03	136100.00
F95F2D	2017-07-12 15:09:00+03	89600.00
F95F92	2017-07-28 09:09:00+03	48800.00
F95F9F	2017-07-19 05:26:00+03	56000.00
F95FB6	2017-08-05 09:39:00+03	40000.00
F95FCF	2017-08-12 21:47:00+03	31000.00
F96080	2017-08-15 03:09:00+03	133900.00
F96090	2017-07-19 17:01:00+03	112000.00
F960B6	2017-07-10 20:09:00+03	136200.00
F960F1	2017-07-25 01:04:00+03	128800.00
F961D6	2017-07-23 22:30:00+03	46200.00
F96233	2017-08-11 10:21:00+03	79900.00
F9625B	2017-07-20 08:25:00+03	531400.00
F962AC	2017-08-05 10:10:00+03	137600.00
F96303	2017-07-09 00:26:00+03	46400.00
F9632A	2017-08-03 04:43:00+03	45200.00
F96332	2017-07-03 18:58:00+03	23200.00
F96352	2017-08-11 08:07:00+03	114800.00
F963B7	2017-07-18 00:51:00+03	44000.00
F963EC	2017-07-15 04:57:00+03	74900.00
F96424	2017-07-08 19:12:00+03	94000.00
F9642D	2017-07-25 11:02:00+03	52000.00
F96496	2017-07-20 22:10:00+03	147700.00
F964D4	2017-08-06 00:11:00+03	264200.00
F964DF	2017-08-09 09:44:00+03	11600.00
F9653E	2017-08-04 06:26:00+03	46000.00
F965A1	2017-07-04 15:40:00+03	38400.00
F965C3	2017-08-02 00:21:00+03	124200.00
F965F7	2017-07-15 10:00:00+03	48700.00
F966A8	2017-07-08 21:36:00+03	14000.00
F96707	2017-08-09 07:09:00+03	405600.00
F967A5	2017-06-27 02:54:00+03	43200.00
F967D1	2017-07-10 10:52:00+03	6300.00
F967FB	2017-08-13 07:58:00+03	56000.00
F96818	2017-08-14 18:19:00+03	136200.00
F9689F	2017-07-14 00:55:00+03	47000.00
F968C9	2017-07-27 20:54:00+03	69100.00
F968E6	2017-08-14 16:13:00+03	39000.00
F96923	2017-07-30 19:50:00+03	37600.00
F9693C	2017-07-24 04:27:00+03	31900.00
F9694D	2017-07-15 18:52:00+03	100600.00
F96957	2017-07-21 04:04:00+03	42800.00
F96983	2017-08-10 03:54:00+03	408500.00
F9698F	2017-07-02 19:09:00+03	112000.00
F96997	2017-07-20 04:01:00+03	24400.00
F969CD	2017-07-18 04:20:00+03	8200.00
F969EE	2017-07-11 22:34:00+03	170500.00
F969F0	2017-07-09 09:54:00+03	36600.00
F96A37	2017-07-29 19:26:00+03	24800.00
F96AA5	2017-07-03 18:30:00+03	85000.00
F96AC9	2017-08-05 05:39:00+03	80000.00
F96AD1	2017-07-26 11:57:00+03	28700.00
F96B52	2017-07-07 10:18:00+03	51600.00
F96B61	2017-07-09 01:44:00+03	37900.00
F96BB4	2017-07-13 10:50:00+03	23600.00
F96CC6	2017-08-06 04:35:00+03	8400.00
F96CE5	2017-07-06 21:33:00+03	104200.00
F96CF2	2017-07-17 16:27:00+03	62100.00
F96D7B	2017-07-14 12:30:00+03	12600.00
F96DC6	2017-08-15 01:25:00+03	43200.00
F96E3B	2017-07-21 15:59:00+03	26000.00
F96E7C	2017-07-27 22:10:00+03	6700.00
F96E89	2017-07-21 06:32:00+03	96300.00
F96E8A	2017-08-13 07:50:00+03	26700.00
F96EB5	2017-08-01 14:30:00+03	213200.00
F96FDA	2017-07-30 06:44:00+03	31700.00
F97024	2017-08-11 02:44:00+03	118400.00
F97057	2017-07-24 20:03:00+03	56000.00
F9709D	2017-07-29 22:58:00+03	47100.00
F970A4	2017-08-13 00:58:00+03	15000.00
F970BA	2017-07-02 00:45:00+03	86300.00
F970F9	2017-07-22 06:36:00+03	46000.00
F9710F	2017-07-10 11:43:00+03	32700.00
F97113	2017-06-29 22:39:00+03	129500.00
F9712F	2017-08-05 15:42:00+03	57600.00
F9715C	2017-07-24 17:41:00+03	187600.00
F97160	2017-08-14 03:54:00+03	83700.00
F971E9	2017-07-07 23:50:00+03	123000.00
F97283	2017-07-14 21:45:00+03	62600.00
F972C5	2017-08-04 13:51:00+03	24200.00
F97347	2017-08-05 09:24:00+03	6700.00
F97364	2017-07-15 12:16:00+03	24200.00
F973BB	2017-08-11 18:35:00+03	6800.00
F9744F	2017-08-02 00:42:00+03	86500.00
F9751A	2017-07-09 09:25:00+03	93900.00
F975C2	2017-06-30 21:05:00+03	26000.00
F975DB	2017-08-10 07:32:00+03	115100.00
F97694	2017-07-05 06:14:00+03	52000.00
F97695	2017-07-20 00:58:00+03	89500.00
F976AE	2017-07-17 12:18:00+03	53600.00
F976B2	2017-07-10 15:37:00+03	6000.00
F976C5	2017-07-20 17:48:00+03	57600.00
F97706	2017-07-18 15:45:00+03	224000.00
F9772F	2017-07-19 11:49:00+03	21800.00
F9774E	2017-07-04 21:20:00+03	50400.00
F97777	2017-08-09 17:31:00+03	82900.00
F977B1	2017-07-11 15:22:00+03	123600.00
F977BE	2017-07-26 18:55:00+03	20800.00
F97823	2017-07-07 20:35:00+03	46500.00
F97839	2017-07-12 22:21:00+03	90800.00
F97859	2017-07-25 20:07:00+03	143200.00
F9786A	2017-07-25 04:56:00+03	35600.00
F978B7	2017-07-28 16:00:00+03	24200.00
F9790A	2017-08-13 16:05:00+03	408500.00
F97950	2017-07-22 06:39:00+03	12600.00
F97988	2017-07-23 08:45:00+03	25600.00
F979DB	2017-08-06 22:50:00+03	81600.00
F97A13	2017-08-01 17:40:00+03	56600.00
F97A5A	2017-07-21 01:53:00+03	271100.00
F97A5E	2017-08-15 16:25:00+03	137700.00
F97A78	2017-08-13 19:39:00+03	14000.00
F97B3D	2017-07-21 23:43:00+03	56600.00
F97B4A	2017-08-06 21:59:00+03	48500.00
F97B55	2017-07-11 00:56:00+03	6700.00
F97B6F	2017-08-05 05:06:00+03	88900.00
F97BA4	2017-07-30 01:13:00+03	89700.00
F97BBC	2017-08-05 09:59:00+03	76600.00
F97BC0	2017-08-07 15:53:00+03	112600.00
F97CC5	2017-07-13 12:50:00+03	78600.00
F97CD5	2017-08-08 21:22:00+03	59800.00
F97D44	2017-07-01 22:35:00+03	125200.00
F97D93	2017-07-09 12:44:00+03	94800.00
F97E33	2017-08-08 05:48:00+03	57500.00
F97E51	2017-07-15 07:44:00+03	82900.00
F97E87	2017-07-21 08:58:00+03	242600.00
F97EC9	2017-07-03 04:54:00+03	23400.00
F97F27	2017-07-07 05:41:00+03	24800.00
F97FA8	2017-07-27 02:47:00+03	44800.00
F98008	2017-08-15 01:46:00+03	28800.00
F98014	2017-07-10 17:50:00+03	9800.00
F98021	2017-07-11 05:33:00+03	95600.00
F9804B	2017-07-19 08:57:00+03	208100.00
F98086	2017-07-04 13:34:00+03	81600.00
F980C5	2017-08-12 21:17:00+03	55800.00
F980ED	2017-08-11 17:37:00+03	26600.00
F98103	2017-07-03 06:51:00+03	46400.00
F98157	2017-08-11 19:32:00+03	23600.00
F9818B	2017-07-07 14:07:00+03	18800.00
F98191	2017-07-08 03:20:00+03	100000.00
F981A8	2017-07-09 10:01:00+03	24700.00
F981B3	2017-07-22 05:02:00+03	21800.00
F9821E	2017-07-21 11:28:00+03	49200.00
F9824B	2017-07-13 05:22:00+03	25400.00
F98297	2017-08-04 20:12:00+03	48800.00
F982BF	2017-07-20 14:49:00+03	21400.00
F982C9	2017-08-09 08:49:00+03	55800.00
F98334	2017-08-09 08:59:00+03	59700.00
F9836C	2017-08-10 22:41:00+03	18000.00
F983A0	2017-07-25 02:14:00+03	60400.00
F9843A	2017-07-01 18:45:00+03	271400.00
F98547	2017-07-14 10:47:00+03	110500.00
F9858F	2017-07-14 15:58:00+03	40600.00
F98592	2017-07-08 01:22:00+03	46400.00
F985FC	2017-08-05 01:09:00+03	103500.00
F9869E	2017-07-12 20:37:00+03	273400.00
F98730	2017-07-19 03:17:00+03	136400.00
F98743	2017-07-16 11:17:00+03	133100.00
F98774	2017-08-14 00:21:00+03	49800.00
F987B1	2017-07-24 10:29:00+03	28200.00
F987C9	2017-07-14 21:54:00+03	179400.00
F987D8	2017-08-07 07:36:00+03	139400.00
F987F0	2017-07-22 23:13:00+03	42800.00
F98839	2017-08-12 20:36:00+03	11000.00
F98857	2017-07-21 11:32:00+03	28600.00
F9888A	2017-08-01 02:41:00+03	26000.00
F98938	2017-07-10 17:24:00+03	46200.00
F98A37	2017-07-07 18:10:00+03	111600.00
F98A6C	2017-08-10 12:17:00+03	149600.00
F98A75	2017-08-12 00:11:00+03	47100.00
F98A7F	2017-08-09 21:14:00+03	70600.00
F98A93	2017-08-12 13:42:00+03	23600.00
F98B7A	2017-07-23 00:44:00+03	56100.00
F98B98	2017-08-12 10:49:00+03	64700.00
F98B99	2017-08-09 23:48:00+03	89700.00
F98BA1	2017-07-25 03:29:00+03	132800.00
F98C64	2017-07-27 08:17:00+03	67200.00
F98C8B	2017-08-02 10:14:00+03	59200.00
F98C9E	2017-07-14 16:49:00+03	40800.00
F98CD2	2017-07-20 12:05:00+03	31200.00
F98D8B	2017-08-14 19:54:00+03	24800.00
F98DE1	2017-08-07 12:27:00+03	57600.00
F98DEA	2017-07-12 05:55:00+03	185700.00
F98E30	2017-08-02 22:29:00+03	39900.00
F98E44	2017-08-07 23:37:00+03	23400.00
F98EF2	2017-07-30 15:09:00+03	135400.00
F98F0E	2017-08-15 00:43:00+03	75400.00
F98F2B	2017-07-16 15:57:00+03	63200.00
F98F82	2017-07-27 06:42:00+03	35800.00
F98F92	2017-07-07 14:04:00+03	56900.00
F98FDE	2017-07-25 13:48:00+03	44000.00
F98FEF	2017-07-14 11:16:00+03	54800.00
F98FF2	2017-07-03 17:00:00+03	53700.00
F9902F	2017-08-14 11:21:00+03	50600.00
F9904C	2017-07-06 08:51:00+03	11600.00
F99064	2017-08-15 13:38:00+03	48500.00
F99101	2017-07-10 04:06:00+03	101200.00
F9913E	2017-07-28 00:36:00+03	112000.00
F99175	2017-07-09 18:51:00+03	99300.00
F9919D	2017-07-12 18:48:00+03	23200.00
F991B0	2017-07-25 19:28:00+03	46400.00
F991BC	2017-08-08 07:12:00+03	21400.00
F991C0	2017-07-08 19:06:00+03	44800.00
F991F4	2017-08-05 23:08:00+03	32800.00
F9922D	2017-07-18 21:15:00+03	35600.00
F9924A	2017-06-25 21:38:00+03	53100.00
F9924B	2017-07-05 00:54:00+03	48800.00
F9929C	2017-08-08 03:20:00+03	46000.00
F993AE	2017-08-05 08:44:00+03	38800.00
F993AF	2017-07-14 17:28:00+03	56600.00
F993B6	2017-08-03 16:16:00+03	67100.00
F993DD	2017-08-02 08:05:00+03	44000.00
F994B3	2017-07-07 00:20:00+03	38100.00
F994C1	2017-07-28 04:42:00+03	39100.00
F9951A	2017-07-29 15:26:00+03	90800.00
F99533	2017-07-08 05:49:00+03	28600.00
F99582	2017-06-30 07:57:00+03	139300.00
F9960B	2017-07-13 22:10:00+03	56600.00
F9962B	2017-08-05 22:23:00+03	8400.00
F996BD	2017-07-02 08:20:00+03	57500.00
F99735	2017-07-17 17:45:00+03	92900.00
F99775	2017-07-06 17:28:00+03	114800.00
F997E3	2017-06-27 02:55:00+03	16400.00
F99828	2017-08-03 16:48:00+03	29600.00
F9983E	2017-07-25 13:11:00+03	66200.00
F9986A	2017-08-09 05:29:00+03	32800.00
F99891	2017-07-29 22:03:00+03	58600.00
F99973	2017-07-23 00:42:00+03	117400.00
F99A25	2017-06-30 22:25:00+03	46400.00
F99A51	2017-07-24 07:33:00+03	12400.00
F99AA2	2017-07-09 22:03:00+03	27200.00
F99ACF	2017-06-29 15:49:00+03	35300.00
F99B5F	2017-08-10 08:09:00+03	21800.00
F99BB1	2017-07-27 16:20:00+03	70700.00
F99C00	2017-07-31 19:47:00+03	99600.00
F99C01	2017-08-03 07:38:00+03	56000.00
F99C27	2017-07-21 23:26:00+03	61800.00
F99C45	2017-08-13 13:29:00+03	15000.00
F99CA3	2017-08-07 12:28:00+03	29600.00
F99CBC	2017-07-19 11:53:00+03	46400.00
F99CD7	2017-07-22 05:12:00+03	13400.00
F99D25	2017-07-17 12:42:00+03	6800.00
F99D2E	2017-08-04 08:17:00+03	8000.00
F99D65	2017-07-17 19:55:00+03	94900.00
F99D89	2017-07-28 05:56:00+03	55600.00
F99DD4	2017-08-08 17:21:00+03	70200.00
F99E78	2017-08-11 02:51:00+03	101500.00
F99E7C	2017-07-08 11:53:00+03	16400.00
F99E87	2017-07-31 18:21:00+03	55800.00
F99EF2	2017-08-04 23:08:00+03	131100.00
F99F07	2017-08-13 11:54:00+03	99200.00
F99F7A	2017-07-04 22:41:00+03	81900.00
F99FA9	2017-07-02 20:39:00+03	68800.00
F99FEF	2017-07-17 20:42:00+03	46000.00
F9A09E	2017-08-12 05:55:00+03	391300.00
F9A0F3	2017-07-30 04:29:00+03	22600.00
F9A104	2017-08-15 14:12:00+03	148200.00
F9A204	2017-08-02 01:33:00+03	60400.00
F9A223	2017-07-23 08:16:00+03	51600.00
F9A260	2017-07-27 02:05:00+03	10800.00
F9A2CE	2017-08-10 14:01:00+03	58400.00
F9A2E2	2017-08-13 07:08:00+03	56000.00
F9A34F	2017-07-08 11:06:00+03	68400.00
F9A3BE	2017-07-31 04:28:00+03	69600.00
F9A3DE	2017-07-19 21:53:00+03	23200.00
F9A41B	2017-07-22 18:13:00+03	101100.00
F9A436	2017-07-16 08:18:00+03	87000.00
F9A443	2017-07-31 19:26:00+03	40800.00
F9A47C	2017-07-26 04:39:00+03	70800.00
F9A47E	2017-07-03 22:45:00+03	99200.00
F9A5DC	2017-07-17 03:21:00+03	354400.00
F9A5E3	2017-07-30 12:13:00+03	184500.00
F9A67D	2017-07-26 10:57:00+03	78200.00
F9A6D5	2017-07-12 14:32:00+03	121400.00
F9A6E7	2017-08-02 18:51:00+03	68100.00
F9A75F	2017-08-02 09:44:00+03	98400.00
F9A767	2017-08-13 07:33:00+03	167500.00
F9A793	2017-08-09 03:45:00+03	98400.00
F9A7EB	2017-07-04 17:19:00+03	89700.00
F9A7F6	2017-07-31 11:31:00+03	130900.00
F9A833	2017-06-30 19:44:00+03	46200.00
F9A86F	2017-07-20 18:21:00+03	124200.00
F9A897	2017-08-11 19:41:00+03	37600.00
F9A98A	2017-07-09 18:15:00+03	34000.00
F9AA31	2017-07-28 15:14:00+03	59200.00
F9AA4C	2017-07-23 10:54:00+03	94900.00
F9AA9F	2017-07-15 08:07:00+03	6400.00
F9AAB0	2017-08-14 04:58:00+03	23600.00
F9AB00	2017-08-14 22:03:00+03	6300.00
F9AB44	2017-07-29 16:04:00+03	14400.00
F9AC35	2017-07-14 19:56:00+03	24200.00
F9AC60	2017-08-05 07:29:00+03	148300.00
F9AD04	2017-07-06 06:22:00+03	67600.00
F9AD3C	2017-07-26 11:03:00+03	16400.00
F9AE06	2017-07-09 08:09:00+03	64100.00
F9AE8A	2017-08-13 18:09:00+03	13600.00
F9AEE6	2017-07-07 08:44:00+03	260900.00
F9AF0C	2017-07-04 22:25:00+03	61800.00
F9AF32	2017-08-13 09:58:00+03	66600.00
F9AFE4	2017-07-29 14:57:00+03	56600.00
F9B04A	2017-07-23 00:45:00+03	59300.00
F9B04C	2017-08-02 18:40:00+03	11600.00
F9B074	2017-07-10 02:22:00+03	40800.00
F9B086	2017-08-12 04:36:00+03	92800.00
F9B0CC	2017-08-01 06:39:00+03	106400.00
F9B123	2017-08-14 04:36:00+03	102400.00
F9B13A	2017-07-19 17:26:00+03	201700.00
F9B170	2017-07-27 22:35:00+03	60400.00
F9B184	2017-08-06 07:11:00+03	37500.00
F9B187	2017-08-09 10:27:00+03	152200.00
F9B1FC	2017-08-08 07:41:00+03	133700.00
F9B20A	2017-07-16 22:43:00+03	23200.00
F9B22B	2017-08-12 07:57:00+03	122700.00
F9B22D	2017-08-03 06:27:00+03	44700.00
F9B291	2017-06-26 17:57:00+03	89000.00
F9B2A4	2017-08-03 13:25:00+03	128800.00
F9B2B2	2017-08-01 08:59:00+03	189200.00
F9B2D2	2017-08-13 23:53:00+03	84300.00
F9B340	2017-07-23 23:50:00+03	56000.00
F9B34B	2017-07-05 12:20:00+03	14400.00
F9B377	2017-07-13 03:07:00+03	8200.00
F9B3DD	2017-08-10 02:02:00+03	201200.00
F9B3F8	2017-07-19 05:25:00+03	31600.00
F9B442	2017-07-24 18:35:00+03	48400.00
F9B451	2017-08-10 15:34:00+03	47200.00
F9B472	2017-08-09 00:06:00+03	23900.00
F9B4AF	2017-07-31 02:30:00+03	95200.00
F9B4DA	2017-07-02 07:32:00+03	55800.00
F9B4E9	2017-07-06 21:25:00+03	92900.00
F9B671	2017-07-20 06:23:00+03	379000.00
F9B67A	2017-08-12 20:36:00+03	332700.00
F9B6A8	2017-07-17 11:14:00+03	28800.00
F9B746	2017-07-11 01:14:00+03	133200.00
F9B772	2017-08-05 03:43:00+03	67700.00
F9B799	2017-07-17 06:18:00+03	186000.00
F9B79E	2017-06-30 01:58:00+03	117700.00
F9B7C5	2017-08-04 17:51:00+03	134400.00
F9B7CF	2017-08-15 12:18:00+03	43000.00
F9B811	2017-07-27 01:08:00+03	26000.00
F9B8D4	2017-08-09 15:57:00+03	118100.00
F9B907	2017-07-11 04:21:00+03	64700.00
F9B911	2017-07-20 02:47:00+03	56100.00
F9B93A	2017-07-21 17:11:00+03	56000.00
F9B947	2017-08-12 00:58:00+03	29600.00
F9B96A	2017-06-27 07:52:00+03	46800.00
F9B9A8	2017-07-28 23:59:00+03	59800.00
F9BA0B	2017-07-01 00:26:00+03	52000.00
F9BA23	2017-08-14 16:18:00+03	26700.00
F9BA35	2017-07-21 10:46:00+03	160700.00
F9BA57	2017-07-03 15:06:00+03	90400.00
F9BA71	2017-07-02 19:55:00+03	42400.00
F9BA74	2017-07-07 09:37:00+03	23200.00
F9BA8D	2017-07-18 15:06:00+03	26000.00
F9BABB	2017-07-09 12:54:00+03	58200.00
F9BAC5	2017-07-15 02:36:00+03	36400.00
F9BAF1	2017-08-13 14:01:00+03	26000.00
F9BAFC	2017-08-12 18:29:00+03	66000.00
F9BB51	2017-07-02 10:16:00+03	23200.00
F9BB9D	2017-08-02 08:01:00+03	28000.00
F9BC3C	2017-08-11 00:06:00+03	55800.00
F9BC43	2017-08-01 16:35:00+03	80300.00
F9BC45	2017-07-23 13:45:00+03	28000.00
F9BC7F	2017-07-29 14:28:00+03	13400.00
F9BC83	2017-08-05 14:17:00+03	169900.00
F9BC94	2017-07-15 14:31:00+03	75600.00
F9BCF7	2017-07-18 06:42:00+03	28000.00
F9BD2C	2017-08-09 11:55:00+03	82900.00
F9BD55	2017-07-01 15:57:00+03	7400.00
F9BD59	2017-08-14 01:46:00+03	136800.00
F9BD91	2017-08-08 02:05:00+03	53400.00
F9BDEF	2017-07-02 00:51:00+03	18600.00
F9BE73	2017-07-27 02:06:00+03	64700.00
F9BEFB	2017-07-11 18:00:00+03	51600.00
F9BF0C	2017-07-24 03:13:00+03	123000.00
F9BF41	2017-08-11 09:15:00+03	61500.00
F9BF77	2017-07-12 05:18:00+03	70800.00
F9BF7C	2017-07-22 09:35:00+03	99300.00
F9BFAB	2017-07-25 20:50:00+03	6000.00
F9C03F	2017-07-20 22:39:00+03	58900.00
F9C094	2017-07-08 09:56:00+03	75600.00
F9C0D2	2017-07-05 22:25:00+03	12400.00
F9C0DE	2017-07-27 23:52:00+03	91100.00
F9C11E	2017-07-01 07:59:00+03	6000.00
F9C14A	2017-08-15 02:17:00+03	44500.00
F9C203	2017-08-07 20:39:00+03	58000.00
F9C25D	2017-08-03 03:03:00+03	66100.00
F9C289	2017-07-13 01:30:00+03	42700.00
F9C2C7	2017-07-23 05:57:00+03	45000.00
F9C2F2	2017-07-15 18:27:00+03	48800.00
F9C3C8	2017-07-28 08:04:00+03	8400.00
F9C3F9	2017-08-14 04:55:00+03	70600.00
F9C42C	2017-07-05 22:14:00+03	28700.00
F9C432	2017-07-22 18:01:00+03	28800.00
F9C461	2017-07-23 13:37:00+03	125200.00
F9C47D	2017-08-13 11:59:00+03	86600.00
F9C480	2017-07-21 14:06:00+03	136900.00
F9C499	2017-07-30 08:01:00+03	93900.00
F9C4B4	2017-07-03 06:45:00+03	27300.00
F9C4B8	2017-08-13 13:11:00+03	56000.00
F9C4DE	2017-08-14 01:45:00+03	46700.00
F9C513	2017-08-08 06:51:00+03	92200.00
F9C55A	2017-08-07 16:32:00+03	44600.00
F9C584	2017-07-18 03:13:00+03	21400.00
F9C5A5	2017-07-03 23:30:00+03	44600.00
F9C5AB	2017-08-04 04:57:00+03	26000.00
F9C5B3	2017-07-29 16:07:00+03	51600.00
F9C638	2017-08-13 17:35:00+03	92800.00
F9C673	2017-07-01 12:44:00+03	33300.00
F9C67F	2017-07-23 04:28:00+03	126000.00
F9C705	2017-07-27 23:59:00+03	26000.00
F9C7C0	2017-07-04 11:32:00+03	66600.00
F9C81E	2017-08-12 10:15:00+03	99200.00
F9C885	2017-07-14 02:25:00+03	99300.00
F9C8A0	2017-07-23 21:59:00+03	60300.00
F9C8AC	2017-07-01 02:59:00+03	104300.00
F9C8CB	2017-07-28 16:08:00+03	136800.00
F9C8DF	2017-08-07 02:42:00+03	148800.00
F9C8E7	2017-08-15 17:18:00+03	66600.00
F9C941	2017-07-28 18:56:00+03	10600.00
F9C967	2017-08-03 20:53:00+03	14000.00
F9C988	2017-08-06 21:01:00+03	260900.00
F9C9B5	2017-07-08 02:32:00+03	75300.00
F9C9EF	2017-07-18 11:43:00+03	39300.00
F9CA4C	2017-07-22 19:02:00+03	67600.00
F9CA6E	2017-07-21 14:34:00+03	12000.00
F9CA7B	2017-08-05 22:58:00+03	75300.00
F9CAC7	2017-07-01 21:44:00+03	195500.00
F9CAE3	2017-07-27 22:18:00+03	28800.00
F9CBF3	2017-07-26 15:49:00+03	27300.00
F9CC6F	2017-07-12 09:54:00+03	32900.00
F9CCD8	2017-08-12 01:46:00+03	39300.00
F9CD55	2017-07-26 07:28:00+03	55300.00
F9CD85	2017-08-06 01:41:00+03	36000.00
F9CDC2	2017-08-08 17:09:00+03	12600.00
F9CDD0	2017-08-01 07:25:00+03	63700.00
F9CECD	2017-07-31 03:47:00+03	66300.00
F9CEEA	2017-07-15 18:04:00+03	149300.00
F9CF43	2017-07-03 22:10:00+03	66600.00
F9CF5A	2017-07-03 23:57:00+03	26800.00
F9CFD1	2017-08-07 11:49:00+03	55800.00
F9CFFD	2017-07-11 18:52:00+03	40600.00
F9D06C	2017-08-08 13:06:00+03	56600.00
F9D074	2017-07-12 22:13:00+03	46200.00
F9D091	2017-08-14 12:33:00+03	28000.00
F9D0A3	2017-07-09 23:31:00+03	65500.00
F9D0AE	2017-07-10 10:17:00+03	58900.00
F9D0D6	2017-07-06 21:04:00+03	21800.00
F9D137	2017-07-21 14:41:00+03	133100.00
F9D17F	2017-07-06 01:31:00+03	16400.00
F9D1CD	2017-08-04 05:35:00+03	15700.00
F9D283	2017-08-01 15:46:00+03	69100.00
F9D2ED	2017-07-24 05:43:00+03	25100.00
F9D329	2017-07-19 01:54:00+03	99300.00
F9D330	2017-07-05 07:53:00+03	394800.00
F9D33F	2017-07-20 10:53:00+03	36800.00
F9D344	2017-07-19 14:07:00+03	23200.00
F9D350	2017-08-11 23:47:00+03	135000.00
F9D3A6	2017-06-30 10:30:00+03	23200.00
F9D408	2017-07-02 13:41:00+03	65000.00
F9D424	2017-08-02 06:59:00+03	28800.00
F9D489	2017-08-02 01:44:00+03	14000.00
F9D4AA	2017-07-09 10:31:00+03	118500.00
F9D4C6	2017-08-10 03:31:00+03	7400.00
F9D4D7	2017-07-03 19:52:00+03	31500.00
F9D506	2017-08-12 01:46:00+03	31800.00
F9D50F	2017-08-05 22:30:00+03	21500.00
F9D520	2017-07-07 14:02:00+03	188800.00
F9D624	2017-07-14 18:30:00+03	39300.00
F9D658	2017-08-09 23:07:00+03	28000.00
F9D66C	2017-08-11 21:17:00+03	37200.00
F9D68E	2017-07-19 00:37:00+03	202200.00
F9D6BA	2017-07-04 17:53:00+03	24400.00
F9D6FD	2017-07-27 20:33:00+03	82900.00
F9D72A	2017-07-28 17:35:00+03	102100.00
F9D765	2017-07-10 20:16:00+03	91500.00
F9D7BE	2017-07-17 10:12:00+03	59800.00
F9D813	2017-07-31 14:35:00+03	46300.00
F9D81C	2017-07-06 01:31:00+03	34400.00
F9D844	2017-08-14 01:19:00+03	21800.00
F9D85A	2017-07-21 13:19:00+03	28800.00
F9D8AC	2017-07-27 12:26:00+03	31600.00
F9D8C9	2017-08-06 03:24:00+03	34000.00
F9D8DE	2017-07-03 16:51:00+03	286600.00
F9D8EF	2017-07-30 13:54:00+03	55800.00
F9D8F3	2017-07-25 19:32:00+03	35600.00
F9D989	2017-07-31 21:33:00+03	276900.00
F9DAD0	2017-08-10 17:21:00+03	14400.00
F9DB0A	2017-07-20 06:19:00+03	28000.00
F9DC1C	2017-06-28 03:23:00+03	10700.00
F9DC62	2017-07-08 23:08:00+03	103500.00
F9DC7B	2017-08-08 17:45:00+03	22200.00
F9DCDB	2017-07-16 00:12:00+03	65500.00
F9DCF3	2017-07-31 22:50:00+03	112000.00
F9DD2A	2017-07-27 13:49:00+03	26200.00
F9DD30	2017-08-09 16:48:00+03	63800.00
F9DDE1	2017-07-30 00:00:00+03	78400.00
F9DDEB	2017-07-20 01:53:00+03	42400.00
F9DDF3	2017-08-07 14:53:00+03	124200.00
F9DDF5	2017-07-05 17:24:00+03	73500.00
F9DE09	2017-07-14 21:07:00+03	58200.00
F9DE31	2017-08-04 08:26:00+03	8200.00
F9DE71	2017-07-15 09:22:00+03	24400.00
F9DE82	2017-08-05 15:42:00+03	27200.00
F9DE96	2017-08-12 18:37:00+03	16400.00
F9DEFE	2017-07-22 00:59:00+03	146700.00
F9DFB4	2017-07-03 22:56:00+03	31600.00
F9E071	2017-08-12 05:54:00+03	23200.00
F9E0A2	2017-08-06 20:45:00+03	266400.00
F9E0C2	2017-08-07 14:17:00+03	160700.00
F9E0EE	2017-07-18 10:53:00+03	313800.00
F9E15B	2017-08-06 10:52:00+03	81700.00
F9E1D6	2017-07-31 22:18:00+03	212700.00
F9E271	2017-07-31 02:16:00+03	405000.00
F9E291	2017-07-02 03:10:00+03	54800.00
F9E306	2017-08-11 19:51:00+03	35200.00
F9E379	2017-06-28 07:17:00+03	32800.00
F9E3C3	2017-07-29 23:00:00+03	8200.00
F9E4EE	2017-07-30 18:46:00+03	21400.00
F9E512	2017-07-25 22:41:00+03	47100.00
F9E574	2017-07-18 18:08:00+03	43700.00
F9E585	2017-08-15 09:19:00+03	99900.00
F9E59A	2017-08-06 22:42:00+03	20000.00
F9E63E	2017-08-07 06:56:00+03	217600.00
F9E6C7	2017-07-31 04:24:00+03	26600.00
F9E7AC	2017-07-01 05:51:00+03	70700.00
F9E83D	2017-07-06 06:17:00+03	167500.00
F9E856	2017-08-13 13:37:00+03	35200.00
F9E857	2017-08-05 02:57:00+03	27300.00
F9E8C6	2017-08-15 05:53:00+03	102100.00
F9E91F	2017-07-10 00:05:00+03	21400.00
F9E95D	2017-07-26 06:16:00+03	13400.00
F9E976	2017-07-23 16:48:00+03	11700.00
F9E987	2017-08-04 02:22:00+03	20400.00
F9EA0F	2017-07-22 12:14:00+03	40400.00
F9EA5F	2017-07-26 12:27:00+03	42800.00
F9EAB0	2017-07-26 08:14:00+03	84500.00
F9EAB5	2017-08-08 10:21:00+03	258400.00
F9EABF	2017-08-03 01:35:00+03	102100.00
F9EAFA	2017-08-08 20:52:00+03	179500.00
F9EB2C	2017-08-04 07:12:00+03	34800.00
F9EB7C	2017-07-02 18:12:00+03	62700.00
F9EBCF	2017-07-12 20:20:00+03	6000.00
F9EBF2	2017-08-01 07:11:00+03	17600.00
F9EBFF	2017-07-17 04:21:00+03	98300.00
F9EC25	2017-07-21 03:05:00+03	45200.00
F9EC7D	2017-07-27 01:44:00+03	46400.00
F9EC7F	2017-07-29 15:21:00+03	144400.00
F9ED84	2017-08-10 11:24:00+03	46000.00
F9ED8B	2017-08-09 16:25:00+03	143100.00
F9EDCE	2017-07-24 00:17:00+03	46400.00
F9EDDE	2017-08-05 11:56:00+03	17800.00
F9EE2D	2017-07-25 00:53:00+03	49100.00
F9EE2E	2017-08-10 15:33:00+03	189200.00
F9EE7C	2017-07-08 14:19:00+03	29600.00
F9EF1B	2017-07-23 22:14:00+03	204100.00
F9EF65	2017-08-10 01:46:00+03	47100.00
F9EF6F	2017-08-09 14:20:00+03	135600.00
F9EF78	2017-07-15 03:04:00+03	81300.00
F9EF93	2017-07-03 13:08:00+03	58900.00
F9EFAE	2017-07-15 16:04:00+03	67200.00
F9F077	2017-08-08 18:55:00+03	57800.00
F9F0D7	2017-08-11 08:35:00+03	54000.00
F9F0E6	2017-07-29 09:05:00+03	170900.00
F9F201	2017-07-26 19:13:00+03	24400.00
F9F296	2017-08-08 22:59:00+03	166000.00
F9F2D1	2017-08-12 02:34:00+03	26000.00
F9F304	2017-07-21 08:47:00+03	32800.00
F9F33F	2017-07-23 21:27:00+03	8600.00
F9F341	2017-07-11 10:17:00+03	35200.00
F9F34C	2017-07-23 23:20:00+03	29400.00
F9F36E	2017-07-29 19:17:00+03	58600.00
F9F376	2017-07-22 13:05:00+03	23600.00
F9F3B7	2017-07-24 00:37:00+03	111600.00
F9F47C	2017-07-24 12:15:00+03	24400.00
F9F4DA	2017-07-06 16:44:00+03	40400.00
F9F4E2	2017-07-04 11:48:00+03	101200.00
F9F4EB	2017-07-01 23:57:00+03	6700.00
F9F519	2017-07-22 03:30:00+03	170200.00
F9F527	2017-07-17 07:35:00+03	68300.00
F9F57F	2017-07-25 13:02:00+03	6000.00
F9F58A	2017-07-23 01:54:00+03	81300.00
F9F5AC	2017-07-02 02:44:00+03	59200.00
F9F5B2	2017-07-25 08:32:00+03	40000.00
F9F5B6	2017-07-23 00:43:00+03	23400.00
F9F612	2017-07-24 00:58:00+03	166900.00
F9F62E	2017-07-20 19:01:00+03	147400.00
F9F630	2017-07-17 08:06:00+03	166000.00
F9F66F	2017-08-10 20:09:00+03	119500.00
F9F6C8	2017-08-14 00:07:00+03	35200.00
F9F6D5	2017-08-01 12:54:00+03	78400.00
F9F6DB	2017-07-13 00:29:00+03	27200.00
F9F707	2017-08-02 14:52:00+03	26700.00
F9F733	2017-07-03 10:14:00+03	28000.00
F9F744	2017-08-06 01:26:00+03	56900.00
F9F75A	2017-08-03 23:38:00+03	115000.00
F9F780	2017-07-01 08:40:00+03	21800.00
F9F818	2017-08-07 10:27:00+03	153200.00
F9F823	2017-07-31 04:16:00+03	31400.00
F9F87F	2017-08-12 04:37:00+03	135400.00
F9F8B6	2017-07-11 18:00:00+03	59000.00
F9F90A	2017-07-17 08:16:00+03	6700.00
F9F93C	2017-08-05 16:30:00+03	66600.00
F9F958	2017-08-15 14:08:00+03	47000.00
F9F966	2017-07-22 12:52:00+03	112000.00
F9F9A3	2017-07-12 22:49:00+03	86600.00
F9F9A6	2017-07-17 03:03:00+03	64200.00
F9FA53	2017-07-02 01:39:00+03	46800.00
F9FAD9	2017-08-12 05:12:00+03	50000.00
F9FB1A	2017-08-13 01:43:00+03	59800.00
F9FB27	2017-08-09 15:34:00+03	50600.00
F9FB4F	2017-07-12 09:08:00+03	56000.00
F9FB54	2017-07-11 03:11:00+03	37900.00
F9FB5E	2017-08-09 07:46:00+03	41000.00
F9FBD5	2017-07-03 07:46:00+03	6300.00
F9FC26	2017-07-15 02:34:00+03	87100.00
F9FC49	2017-08-14 19:38:00+03	56000.00
F9FC62	2017-07-28 22:26:00+03	16400.00
F9FC6E	2017-07-13 03:04:00+03	410200.00
F9FD9D	2017-07-19 12:36:00+03	18800.00
F9FDBA	2017-07-07 09:08:00+03	111600.00
F9FDD1	2017-08-12 18:50:00+03	141300.00
F9FDE4	2017-08-09 15:31:00+03	56000.00
F9FE11	2017-07-26 18:22:00+03	75600.00
F9FE5D	2017-07-11 16:47:00+03	117600.00
F9FEA7	2017-07-06 03:02:00+03	77200.00
F9FEC8	2017-08-13 21:24:00+03	47400.00
F9FED9	2017-07-23 04:50:00+03	56000.00
F9FF14	2017-07-13 02:15:00+03	132800.00
F9FF47	2017-08-02 07:35:00+03	28700.00
F9FF9A	2017-07-21 00:29:00+03	55800.00
F9FFC6	2017-07-04 06:03:00+03	75500.00
FA001B	2017-07-29 04:23:00+03	142400.00
FA0029	2017-07-28 03:45:00+03	107400.00
FA0040	2017-08-04 16:28:00+03	46000.00
FA0091	2017-07-27 11:34:00+03	44800.00
FA009F	2017-07-07 09:37:00+03	67600.00
FA00A3	2017-06-30 05:32:00+03	295400.00
FA00A6	2017-07-19 11:42:00+03	173500.00
FA00F0	2017-07-16 06:22:00+03	174800.00
FA0128	2017-06-29 15:57:00+03	6800.00
FA0169	2017-07-16 21:27:00+03	84100.00
FA018E	2017-07-16 19:12:00+03	40800.00
FA024A	2017-08-07 06:40:00+03	200800.00
FA026C	2017-07-21 23:08:00+03	159400.00
FA02E9	2017-07-06 06:22:00+03	68800.00
FA0385	2017-07-18 02:43:00+03	28800.00
FA03A1	2017-07-04 14:41:00+03	47000.00
FA03D1	2017-07-28 20:00:00+03	29400.00
FA0421	2017-07-27 09:00:00+03	92600.00
FA0443	2017-07-23 16:50:00+03	34600.00
FA0452	2017-07-11 19:05:00+03	58400.00
FA0465	2017-08-10 12:25:00+03	28000.00
FA046B	2017-07-19 14:12:00+03	106200.00
FA0475	2017-06-29 10:56:00+03	94000.00
FA0491	2017-08-04 02:55:00+03	27400.00
FA04E4	2017-07-09 11:24:00+03	92800.00
FA04F8	2017-07-15 14:45:00+03	28000.00
FA04FD	2017-07-29 16:37:00+03	31200.00
FA052B	2017-07-04 03:45:00+03	118600.00
FA0531	2017-08-03 00:43:00+03	136200.00
FA0571	2017-08-01 08:15:00+03	21200.00
FA05C0	2017-07-30 08:33:00+03	23600.00
FA05F1	2017-07-05 18:59:00+03	113700.00
FA0622	2017-08-14 20:28:00+03	112000.00
FA0704	2017-07-07 17:52:00+03	128800.00
FA077C	2017-07-15 00:46:00+03	33300.00
FA07F5	2017-06-26 18:30:00+03	27200.00
FA087A	2017-07-06 07:56:00+03	61800.00
FA08A5	2017-07-03 02:22:00+03	23200.00
FA08DB	2017-08-03 15:14:00+03	187800.00
FA08EA	2017-07-15 20:31:00+03	23600.00
FA0906	2017-07-02 22:36:00+03	73400.00
FA0912	2017-07-11 09:23:00+03	87000.00
FA096A	2017-08-11 19:27:00+03	28800.00
FA0991	2017-07-29 01:04:00+03	45100.00
FA0996	2017-08-06 17:21:00+03	131100.00
FA09AB	2017-07-23 15:10:00+03	56600.00
FA09B2	2017-07-28 17:21:00+03	115600.00
FA0A02	2017-06-29 20:19:00+03	29600.00
FA0A1A	2017-07-15 01:29:00+03	25200.00
FA0A20	2017-08-09 02:07:00+03	12400.00
FA0A6B	2017-08-13 17:28:00+03	303500.00
FA0A91	2017-07-30 12:16:00+03	28800.00
FA0AFC	2017-08-08 21:59:00+03	18600.00
FA0B08	2017-07-19 18:36:00+03	50100.00
FA0B3B	2017-08-10 15:10:00+03	209000.00
FA0B51	2017-08-10 23:57:00+03	32700.00
FA0C24	2017-07-02 09:58:00+03	13700.00
FA0C67	2017-07-29 02:31:00+03	27200.00
FA0CDF	2017-07-14 06:11:00+03	103500.00
FA0D55	2017-08-11 07:55:00+03	32800.00
FA0DFF	2017-07-29 18:40:00+03	40800.00
FA0E00	2017-08-06 12:02:00+03	89600.00
FA0E3A	2017-07-19 19:01:00+03	52300.00
FA0EC2	2017-07-03 19:54:00+03	124300.00
FA0EE6	2017-07-23 08:51:00+03	37900.00
FA0F01	2017-08-12 20:32:00+03	101900.00
FA0F6E	2017-07-12 09:48:00+03	8400.00
FA101E	2017-07-05 08:51:00+03	52700.00
FA1063	2017-08-12 04:59:00+03	23200.00
FA1083	2017-07-14 05:31:00+03	43800.00
FA10CC	2017-07-14 14:11:00+03	98400.00
FA10EE	2017-07-20 05:04:00+03	35200.00
FA112D	2017-07-26 03:46:00+03	47200.00
FA1139	2017-08-05 15:09:00+03	8000.00
FA1175	2017-07-25 11:24:00+03	67200.00
FA11A9	2017-08-06 09:01:00+03	266400.00
FA1216	2017-07-24 17:51:00+03	55800.00
FA121F	2017-08-07 16:51:00+03	31700.00
FA129C	2017-08-02 15:18:00+03	66600.00
FA12B7	2017-07-20 18:33:00+03	101700.00
FA12CB	2017-07-01 11:37:00+03	28000.00
FA1305	2017-08-06 01:44:00+03	78400.00
FA13E5	2017-07-15 09:13:00+03	442700.00
FA1400	2017-07-20 05:42:00+03	111600.00
FA1409	2017-08-08 19:25:00+03	38500.00
FA1442	2017-07-28 06:07:00+03	23200.00
FA14C3	2017-07-06 15:58:00+03	6700.00
FA14CC	2017-06-28 07:36:00+03	38800.00
FA14E7	2017-07-25 21:19:00+03	94500.00
FA1522	2017-07-20 17:59:00+03	59800.00
FA152A	2017-07-30 20:19:00+03	58000.00
FA153A	2017-08-09 23:23:00+03	68200.00
FA157E	2017-07-07 00:04:00+03	36000.00
FA1581	2017-07-18 14:04:00+03	67100.00
FA1610	2017-07-14 13:35:00+03	109000.00
FA164A	2017-07-07 17:51:00+03	471600.00
FA1693	2017-07-06 09:07:00+03	39400.00
FA16CE	2017-08-01 01:02:00+03	6800.00
FA16E6	2017-07-20 11:18:00+03	278400.00
FA170B	2017-07-01 18:02:00+03	58800.00
FA170D	2017-08-10 21:06:00+03	146000.00
FA1741	2017-07-20 10:26:00+03	6000.00
FA1774	2017-07-07 16:40:00+03	21400.00
FA1780	2017-07-07 22:14:00+03	39700.00
FA179C	2017-07-04 16:33:00+03	23200.00
FA1860	2017-08-11 23:23:00+03	28800.00
FA1864	2017-07-29 00:13:00+03	342100.00
FA18E0	2017-07-10 12:56:00+03	147300.00
FA1930	2017-07-22 13:40:00+03	39400.00
FA1932	2017-08-05 03:50:00+03	27400.00
FA196E	2017-08-14 01:13:00+03	66000.00
FA1A4B	2017-08-08 05:39:00+03	81900.00
FA1AB6	2017-08-08 07:06:00+03	65400.00
FA1B3F	2017-07-14 03:59:00+03	23200.00
FA1B5F	2017-06-29 20:10:00+03	32400.00
FA1B60	2017-08-05 04:06:00+03	80400.00
FA1B94	2017-07-03 12:09:00+03	44800.00
FA1C55	2017-07-17 18:07:00+03	95000.00
FA1C81	2017-07-27 23:40:00+03	137600.00
FA1C8D	2017-07-30 15:23:00+03	14400.00
FA1CCB	2017-08-12 23:18:00+03	67900.00
FA1D10	2017-07-02 08:27:00+03	21400.00
FA1D66	2017-07-20 20:39:00+03	31200.00
FA1DA5	2017-06-29 17:09:00+03	57800.00
FA1DAC	2017-08-05 02:08:00+03	73100.00
FA1DDC	2017-07-14 01:40:00+03	103500.00
FA1DFC	2017-07-01 09:03:00+03	55800.00
FA1E15	2017-07-30 02:09:00+03	46200.00
FA1E26	2017-07-13 01:10:00+03	20600.00
FA1E52	2017-07-22 08:42:00+03	73300.00
FA1E55	2017-07-14 13:46:00+03	113300.00
FA1E5B	2017-08-11 19:58:00+03	40800.00
FA1EBE	2017-07-21 22:32:00+03	61800.00
FA1ED9	2017-07-02 18:31:00+03	123000.00
FA1F3B	2017-07-26 09:01:00+03	28000.00
FA1F64	2017-08-14 07:31:00+03	29400.00
FA202E	2017-07-05 13:05:00+03	28000.00
FA203B	2017-07-14 09:35:00+03	24400.00
FA2065	2017-08-12 10:35:00+03	37800.00
FA20B5	2017-08-02 08:21:00+03	35200.00
FA20D3	2017-07-03 19:15:00+03	121400.00
FA20EA	2017-07-17 13:58:00+03	30200.00
FA213D	2017-07-02 17:32:00+03	88500.00
FA21AE	2017-07-02 23:34:00+03	81600.00
FA21FD	2017-08-07 04:24:00+03	25800.00
FA2223	2017-08-15 14:51:00+03	79300.00
FA225F	2017-07-28 08:59:00+03	24000.00
FA227C	2017-08-09 22:18:00+03	81600.00
FA22D1	2017-07-13 10:43:00+03	64800.00
FA22DC	2017-07-22 16:36:00+03	27200.00
FA2323	2017-07-17 15:26:00+03	167400.00
FA2379	2017-07-22 09:33:00+03	118200.00
FA2410	2017-08-13 02:00:00+03	24800.00
FA2420	2017-07-28 08:27:00+03	54500.00
FA2429	2017-07-14 04:18:00+03	57900.00
FA24D0	2017-08-12 15:03:00+03	248300.00
FA2552	2017-07-27 18:54:00+03	47600.00
FA255E	2017-07-22 18:01:00+03	53300.00
FA2571	2017-07-12 21:07:00+03	13600.00
FA259B	2017-07-09 19:50:00+03	85500.00
FA25C6	2017-07-07 03:42:00+03	73600.00
FA25E8	2017-07-16 06:07:00+03	99600.00
FA2637	2017-08-13 03:35:00+03	71900.00
FA2648	2017-07-17 23:28:00+03	14400.00
FA267E	2017-08-11 01:40:00+03	6800.00
FA26D6	2017-07-05 21:16:00+03	6800.00
FA276B	2017-08-05 04:17:00+03	94700.00
FA27AE	2017-07-24 21:51:00+03	21800.00
FA2870	2017-08-05 22:06:00+03	28000.00
FA28F7	2017-08-11 15:45:00+03	11000.00
FA2907	2017-08-15 17:19:00+03	134400.00
FA291A	2017-07-25 11:45:00+03	90800.00
FA294C	2017-07-26 08:40:00+03	7400.00
FA2968	2017-07-31 11:43:00+03	52000.00
FA29A8	2017-08-11 23:36:00+03	73200.00
FA29B0	2017-08-12 03:44:00+03	270800.00
FA29DC	2017-07-18 21:56:00+03	246000.00
FA2A0C	2017-07-28 18:17:00+03	122800.00
FA2A5F	2017-07-16 10:12:00+03	137200.00
FA2AB0	2017-08-12 10:41:00+03	111600.00
FA2AEC	2017-07-17 20:40:00+03	91500.00
FA2B34	2017-08-02 22:38:00+03	46000.00
FA2B45	2017-07-23 14:21:00+03	25900.00
FA2B57	2017-07-31 23:54:00+03	106400.00
FA2B71	2017-07-17 06:59:00+03	21600.00
FA2B78	2017-07-31 11:39:00+03	29600.00
FA2B9C	2017-07-08 17:52:00+03	58000.00
FA2BBB	2017-07-31 20:27:00+03	130000.00
FA2BD2	2017-07-20 11:18:00+03	39300.00
FA2C90	2017-08-15 02:39:00+03	26700.00
FA2CFB	2017-07-02 17:20:00+03	50800.00
FA2DB6	2017-08-13 06:24:00+03	13400.00
FA2DFE	2017-08-07 09:49:00+03	40600.00
FA2EE2	2017-06-29 06:54:00+03	408600.00
FA2F27	2017-08-10 02:28:00+03	52000.00
FA2F40	2017-07-27 16:51:00+03	124600.00
FA2F4D	2017-07-10 13:37:00+03	8200.00
FA2F7C	2017-07-20 19:15:00+03	23200.00
FA2F92	2017-08-10 11:01:00+03	81200.00
FA2FA4	2017-07-11 09:02:00+03	180000.00
FA2FB4	2017-08-05 08:03:00+03	51600.00
FA3023	2017-08-14 03:00:00+03	55200.00
FA310F	2017-08-12 10:03:00+03	56900.00
FA3123	2017-07-25 07:55:00+03	224000.00
FA3174	2017-07-30 02:38:00+03	103500.00
FA31B3	2017-07-07 05:49:00+03	75300.00
FA31EE	2017-08-07 19:51:00+03	131100.00
FA31F4	2017-08-04 13:55:00+03	139500.00
FA31FA	2017-07-02 17:23:00+03	54500.00
FA326A	2017-08-12 20:49:00+03	12000.00
FA32AE	2017-07-26 11:44:00+03	88800.00
FA32CE	2017-07-27 09:38:00+03	199600.00
FA337E	2017-08-06 10:03:00+03	6700.00
FA3469	2017-07-27 15:20:00+03	96300.00
FA3494	2017-07-26 21:22:00+03	23600.00
FA349B	2017-08-01 01:04:00+03	153800.00
FA34FC	2017-07-08 18:21:00+03	196000.00
FA3513	2017-08-12 05:38:00+03	75600.00
FA359A	2017-07-10 02:10:00+03	125200.00
FA35C7	2017-07-28 08:44:00+03	40800.00
FA361F	2017-08-02 22:03:00+03	49200.00
FA3625	2017-07-07 06:58:00+03	13400.00
FA3663	2017-07-23 23:02:00+03	26000.00
FA3664	2017-08-11 02:05:00+03	77600.00
FA3681	2017-08-01 09:50:00+03	23600.00
FA368A	2017-08-09 02:06:00+03	29400.00
FA36C9	2017-08-10 02:13:00+03	52700.00
FA379A	2017-07-30 13:50:00+03	47400.00
FA37A9	2017-07-19 03:37:00+03	244100.00
FA37D1	2017-08-10 09:50:00+03	133200.00
FA3808	2017-07-02 19:03:00+03	90400.00
FA380E	2017-07-31 15:38:00+03	59800.00
FA382F	2017-07-05 04:20:00+03	40800.00
FA38B4	2017-08-09 18:29:00+03	46700.00
FA38FA	2017-08-08 08:37:00+03	48400.00
FA3939	2017-07-15 17:22:00+03	44700.00
FA39F9	2017-07-24 19:19:00+03	68400.00
FA39FB	2017-08-09 22:43:00+03	224000.00
FA3A35	2017-07-31 14:19:00+03	31000.00
FA3A57	2017-08-12 04:19:00+03	84500.00
FA3A5C	2017-07-25 05:41:00+03	252200.00
FA3AF4	2017-08-03 12:34:00+03	32800.00
FA3AF5	2017-06-28 12:29:00+03	56000.00
FA3B6C	2017-07-23 20:05:00+03	56900.00
FA3B7C	2017-08-04 08:35:00+03	59200.00
FA3C16	2017-07-24 00:15:00+03	20000.00
FA3C2A	2017-07-01 09:07:00+03	32800.00
FA3C80	2017-08-12 13:30:00+03	26800.00
FA3C87	2017-07-28 04:38:00+03	38600.00
FA3D4E	2017-07-14 15:42:00+03	139400.00
FA3D73	2017-07-28 12:24:00+03	52800.00
FA3D8C	2017-08-02 23:54:00+03	23400.00
FA3DEC	2017-07-08 10:07:00+03	24700.00
FA3DED	2017-07-11 13:45:00+03	26000.00
FA3DF7	2017-07-27 00:35:00+03	17000.00
FA3DFC	2017-07-27 00:00:00+03	21800.00
FA3E5C	2017-07-13 16:46:00+03	111600.00
FA3E65	2017-07-20 05:32:00+03	17600.00
FA3E75	2017-07-19 17:39:00+03	38600.00
FA3EEF	2017-07-09 02:33:00+03	187600.00
FA3F02	2017-08-09 19:04:00+03	39400.00
FA3F68	2017-08-05 13:14:00+03	95100.00
FA3FD1	2017-07-17 02:22:00+03	60800.00
FA4000	2017-07-31 18:53:00+03	27200.00
FA404A	2017-08-15 11:44:00+03	15400.00
FA4099	2017-07-10 08:55:00+03	53400.00
FA4158	2017-08-15 06:26:00+03	34400.00
FA422A	2017-08-07 22:45:00+03	95600.00
FA425B	2017-07-21 00:17:00+03	28000.00
FA428E	2017-07-12 09:00:00+03	47000.00
FA42DC	2017-08-15 13:52:00+03	16400.00
FA4303	2017-07-09 11:52:00+03	65600.00
FA4379	2017-08-08 11:59:00+03	53600.00
FA43A1	2017-08-12 03:01:00+03	21400.00
FA43B3	2017-06-29 03:01:00+03	19600.00
FA4464	2017-07-04 03:05:00+03	22600.00
FA4478	2017-07-14 13:21:00+03	37800.00
FA44A8	2017-08-12 20:47:00+03	111600.00
FA44CA	2017-07-04 01:21:00+03	95700.00
FA44E6	2017-08-03 14:08:00+03	46400.00
FA44EA	2017-07-09 12:40:00+03	23600.00
FA4525	2017-07-12 02:18:00+03	56600.00
FA4605	2017-08-06 08:24:00+03	48400.00
FA460F	2017-07-04 00:39:00+03	101100.00
FA4648	2017-07-24 03:14:00+03	54200.00
FA4671	2017-07-21 04:49:00+03	66000.00
FA468C	2017-08-01 19:57:00+03	67600.00
FA46C0	2017-07-15 12:43:00+03	49700.00
FA4706	2017-07-14 04:00:00+03	28800.00
FA470A	2017-08-11 21:58:00+03	48800.00
FA477F	2017-07-28 01:30:00+03	114100.00
FA47D8	2017-07-22 06:15:00+03	56600.00
FA4815	2017-07-03 18:07:00+03	56100.00
FA4886	2017-07-30 09:00:00+03	81500.00
FA48EB	2017-07-12 12:13:00+03	271300.00
FA48FF	2017-07-01 11:24:00+03	24800.00
FA4958	2017-07-05 23:31:00+03	64400.00
FA4A36	2017-07-06 13:27:00+03	6800.00
FA4A74	2017-07-09 17:29:00+03	47000.00
FA4B0A	2017-07-06 12:36:00+03	115700.00
FA4B33	2017-07-29 07:01:00+03	137600.00
FA4B5A	2017-08-13 17:41:00+03	12000.00
FA4B5B	2017-06-28 14:37:00+03	72600.00
FA4BA0	2017-07-07 02:04:00+03	64700.00
FA4BD7	2017-08-03 00:51:00+03	125500.00
FA4CB1	2017-08-02 06:54:00+03	23200.00
FA4CB3	2017-07-26 01:52:00+03	11800.00
FA4CF9	2017-07-07 14:23:00+03	26300.00
FA4D14	2017-08-05 11:24:00+03	272400.00
FA4D29	2017-08-03 16:05:00+03	147700.00
FA4D37	2017-07-04 00:21:00+03	64800.00
FA4DBD	2017-08-14 10:20:00+03	75600.00
FA4E76	2017-07-16 01:13:00+03	81900.00
FA4EBB	2017-07-19 07:39:00+03	115900.00
FA4EC3	2017-07-11 08:49:00+03	46700.00
FA4EC5	2017-07-20 09:34:00+03	119800.00
FA4ECE	2017-07-10 02:59:00+03	12400.00
FA4F0E	2017-07-14 16:57:00+03	25600.00
FA4F30	2017-07-19 21:24:00+03	28600.00
FA4FD8	2017-08-01 04:59:00+03	91800.00
FA50B6	2017-08-04 09:22:00+03	64100.00
FA50E1	2017-07-22 17:03:00+03	85600.00
FA51DA	2017-07-14 19:33:00+03	14400.00
FA51DF	2017-07-20 03:58:00+03	33600.00
FA5218	2017-07-11 12:21:00+03	83700.00
FA5260	2017-07-09 04:34:00+03	57500.00
FA5269	2017-07-30 16:34:00+03	47400.00
FA536F	2017-07-17 20:56:00+03	40000.00
FA5377	2017-07-16 15:26:00+03	23200.00
FA53B5	2017-07-11 10:37:00+03	48800.00
FA53B7	2017-07-02 08:38:00+03	23900.00
FA53D4	2017-08-09 01:03:00+03	26700.00
FA53E2	2017-08-11 09:32:00+03	68800.00
FA5478	2017-06-28 17:03:00+03	67600.00
FA54C1	2017-08-01 10:20:00+03	325200.00
FA54FE	2017-08-01 18:09:00+03	118100.00
FA559A	2017-08-11 06:26:00+03	142400.00
FA55BD	2017-08-15 01:24:00+03	12000.00
FA55EE	2017-08-07 11:16:00+03	56600.00
FA56AD	2017-07-07 11:17:00+03	240600.00
FA56E5	2017-08-13 19:40:00+03	144400.00
FA570E	2017-08-06 14:22:00+03	62600.00
FA57A5	2017-08-14 06:00:00+03	58400.00
FA5817	2017-07-12 04:44:00+03	117000.00
FA5819	2017-07-22 00:36:00+03	12000.00
FA5822	2017-07-03 06:17:00+03	23600.00
FA583D	2017-08-12 00:20:00+03	46200.00
FA588D	2017-07-28 05:19:00+03	103300.00
FA5890	2017-07-07 13:11:00+03	16400.00
FA59A7	2017-08-15 11:56:00+03	216400.00
FA59AE	2017-07-24 02:57:00+03	25400.00
FA59C8	2017-08-10 18:01:00+03	74400.00
FA59F8	2017-07-27 22:57:00+03	45000.00
FA5A2A	2017-07-25 17:51:00+03	246000.00
FA5A47	2017-08-06 04:42:00+03	28800.00
FA5A61	2017-07-31 11:09:00+03	56000.00
FA5A64	2017-08-07 01:49:00+03	46300.00
FA5A92	2017-07-29 02:28:00+03	55800.00
FA5A9D	2017-08-03 14:17:00+03	25200.00
FA5AD6	2017-07-19 08:53:00+03	52400.00
FA5BCA	2017-07-20 02:21:00+03	119500.00
FA5BD6	2017-08-09 09:04:00+03	87000.00
FA5BDD	2017-07-02 11:36:00+03	13600.00
FA5BED	2017-07-20 18:46:00+03	254900.00
FA5C0C	2017-07-20 16:32:00+03	36200.00
FA5C5D	2017-07-30 13:31:00+03	22000.00
FA5CE9	2017-07-31 08:45:00+03	6700.00
FA5D3E	2017-07-01 22:23:00+03	77000.00
FA5D9E	2017-08-06 09:23:00+03	44000.00
FA5DBC	2017-08-15 02:42:00+03	31600.00
FA5DBD	2017-07-04 11:10:00+03	16400.00
FA5DEF	2017-07-01 00:34:00+03	123000.00
FA5E93	2017-08-02 05:30:00+03	89700.00
FA5EDA	2017-07-29 03:59:00+03	198400.00
FA5F65	2017-07-02 11:58:00+03	86400.00
FA5F7C	2017-07-15 16:14:00+03	186900.00
FA5F93	2017-07-22 16:13:00+03	419100.00
FA5FC4	2017-07-18 22:37:00+03	55800.00
FA5FD9	2017-08-10 22:23:00+03	28000.00
FA5FE6	2017-08-11 03:21:00+03	102100.00
FA6006	2017-07-09 17:11:00+03	366600.00
FA6040	2017-08-05 02:33:00+03	539400.00
FA604C	2017-08-02 15:00:00+03	34000.00
FA6097	2017-08-11 23:10:00+03	150600.00
FA60A9	2017-07-10 18:40:00+03	40800.00
FA6132	2017-08-09 16:36:00+03	22000.00
FA616D	2017-08-09 08:23:00+03	14400.00
FA616F	2017-07-21 22:23:00+03	95200.00
FA6187	2017-07-05 12:21:00+03	56600.00
FA6229	2017-08-08 08:35:00+03	21400.00
FA6267	2017-08-12 02:04:00+03	88600.00
FA62F2	2017-07-31 12:44:00+03	529200.00
FA6313	2017-08-11 21:03:00+03	67700.00
FA6372	2017-07-15 10:03:00+03	31600.00
FA6458	2017-08-04 07:56:00+03	12400.00
FA6512	2017-08-01 07:24:00+03	155600.00
FA6584	2017-07-27 02:02:00+03	89500.00
FA65B8	2017-08-03 16:45:00+03	191000.00
FA661C	2017-07-01 03:34:00+03	7400.00
FA667A	2017-07-17 19:32:00+03	257500.00
FA66CD	2017-07-15 09:31:00+03	22600.00
FA66DA	2017-07-11 14:00:00+03	103000.00
FA66ED	2017-07-19 23:34:00+03	14000.00
FA66F1	2017-07-01 10:41:00+03	58600.00
FA6708	2017-07-24 01:48:00+03	86300.00
FA6718	2017-07-12 14:45:00+03	17000.00
FA6723	2017-08-04 12:41:00+03	27900.00
FA6777	2017-07-20 15:28:00+03	27900.00
FA6810	2017-07-02 13:57:00+03	201200.00
FA68C9	2017-08-02 01:47:00+03	48400.00
FA6901	2017-07-14 05:36:00+03	201800.00
FA6920	2017-08-03 05:23:00+03	27200.00
FA6924	2017-08-07 00:53:00+03	22000.00
FA6942	2017-07-25 05:11:00+03	56600.00
FA6981	2017-07-17 23:01:00+03	79600.00
FA6984	2017-07-03 10:10:00+03	29600.00
FA6986	2017-07-05 12:16:00+03	26000.00
FA69C7	2017-07-14 08:28:00+03	135400.00
FA69D2	2017-07-07 13:35:00+03	54200.00
FA69FF	2017-07-26 03:57:00+03	272300.00
FA6A07	2017-07-27 10:47:00+03	440700.00
FA6A3F	2017-07-03 16:08:00+03	6000.00
FA6AAB	2017-08-13 04:19:00+03	21800.00
FA6AD2	2017-06-27 15:46:00+03	23200.00
FA6B76	2017-07-03 14:53:00+03	29600.00
FA6BC0	2017-07-10 07:24:00+03	37900.00
FA6C1E	2017-07-04 10:04:00+03	67200.00
FA6C3B	2017-08-09 06:51:00+03	24800.00
FA6C4C	2017-07-24 23:13:00+03	54500.00
FA6C52	2017-08-03 23:22:00+03	49600.00
FA6C70	2017-08-07 07:00:00+03	55800.00
FA6CFC	2017-07-04 00:02:00+03	168000.00
FA6D16	2017-07-16 14:16:00+03	13400.00
FA6D30	2017-07-04 10:58:00+03	301800.00
FA6D5E	2017-07-09 13:55:00+03	28800.00
FA6DA4	2017-07-30 10:46:00+03	12400.00
FA6DE2	2017-08-07 16:52:00+03	89700.00
FA6E40	2017-07-10 19:33:00+03	79200.00
FA6E68	2017-07-09 09:48:00+03	55800.00
FA6E6F	2017-08-08 11:09:00+03	62000.00
FA6E9D	2017-07-17 18:30:00+03	26000.00
FA6EEA	2017-07-29 01:33:00+03	44000.00
FA6F05	2017-07-22 10:39:00+03	136800.00
FA6F43	2017-07-17 20:17:00+03	40400.00
FA7004	2017-07-04 11:53:00+03	102100.00
FA7019	2017-08-09 04:14:00+03	43000.00
FA7028	2017-07-17 17:12:00+03	55800.00
FA702F	2017-07-27 21:24:00+03	48800.00
FA707E	2017-07-31 22:59:00+03	398500.00
FA707F	2017-08-03 04:53:00+03	70600.00
FA70C8	2017-07-09 15:50:00+03	65000.00
FA7188	2017-07-22 12:02:00+03	133200.00
FA71C0	2017-07-11 19:43:00+03	51200.00
FA71D7	2017-07-19 10:05:00+03	33300.00
FA7245	2017-08-10 13:10:00+03	193700.00
FA7284	2017-08-05 04:06:00+03	6000.00
FA7291	2017-07-27 07:09:00+03	199700.00
FA72BB	2017-08-11 15:27:00+03	35300.00
FA7301	2017-08-14 17:09:00+03	24400.00
FA7341	2017-07-04 06:02:00+03	30200.00
FA73A0	2017-08-07 21:47:00+03	40400.00
FA73A5	2017-07-25 10:07:00+03	24700.00
FA73E7	2017-07-29 08:16:00+03	24200.00
FA73F6	2017-07-23 09:14:00+03	70800.00
FA7403	2017-08-08 12:19:00+03	45400.00
FA745E	2017-08-08 09:55:00+03	26000.00
FA746B	2017-07-09 17:24:00+03	24200.00
FA7525	2017-07-25 18:02:00+03	69600.00
FA753B	2017-07-08 14:30:00+03	43600.00
FA75A8	2017-07-15 09:30:00+03	41600.00
FA75E6	2017-07-25 19:24:00+03	68800.00
FA75F1	2017-07-21 06:13:00+03	132500.00
FA75F3	2017-08-07 04:46:00+03	62900.00
FA7604	2017-08-02 08:06:00+03	101200.00
FA7676	2017-07-02 06:13:00+03	112600.00
FA76C1	2017-07-17 05:51:00+03	66600.00
FA76EE	2017-07-07 16:35:00+03	115600.00
FA7736	2017-08-01 07:40:00+03	135400.00
FA7744	2017-07-09 16:32:00+03	16400.00
FA7746	2017-07-29 01:29:00+03	32700.00
FA778A	2017-07-04 04:34:00+03	32900.00
FA77D4	2017-07-30 13:43:00+03	58600.00
FA77D7	2017-07-22 17:42:00+03	24400.00
FA77DB	2017-08-15 05:53:00+03	37900.00
FA7840	2017-08-11 09:02:00+03	331500.00
FA785E	2017-08-13 10:17:00+03	130400.00
FA7895	2017-07-03 01:16:00+03	47500.00
FA790A	2017-07-07 12:10:00+03	10800.00
FA7952	2017-07-20 06:25:00+03	56900.00
FA796C	2017-07-07 14:39:00+03	131100.00
FA79C6	2017-08-10 22:54:00+03	35600.00
FA7A2F	2017-08-15 03:32:00+03	93900.00
FA7A30	2017-08-02 23:40:00+03	100400.00
FA7A5B	2017-08-03 07:23:00+03	38800.00
FA7A6B	2017-07-21 11:58:00+03	265700.00
FA7B20	2017-08-04 03:11:00+03	57900.00
FA7B29	2017-06-30 22:04:00+03	24000.00
FA7BBE	2017-07-02 11:27:00+03	114700.00
FA7BEA	2017-07-24 08:03:00+03	24300.00
FA7C06	2017-07-10 05:09:00+03	116800.00
FA7C0E	2017-06-26 14:40:00+03	186900.00
FA7C5C	2017-07-26 08:07:00+03	10800.00
FA7CBF	2017-07-03 09:13:00+03	60700.00
FA7CF5	2017-08-13 08:53:00+03	282000.00
FA7D0D	2017-07-16 13:28:00+03	38800.00
FA7D62	2017-08-01 15:51:00+03	17000.00
FA7D7E	2017-07-07 04:41:00+03	66600.00
FA7E85	2017-07-31 16:23:00+03	136800.00
FA7FD5	2017-07-23 16:01:00+03	18800.00
FA80A3	2017-07-09 00:45:00+03	7200.00
FA8121	2017-07-06 18:08:00+03	153600.00
FA812D	2017-07-17 01:11:00+03	270800.00
FA816C	2017-07-03 00:45:00+03	38800.00
FA81AE	2017-08-03 03:22:00+03	19000.00
FA8213	2017-08-08 05:09:00+03	23200.00
FA8229	2017-07-24 04:51:00+03	454600.00
FA825D	2017-07-22 19:13:00+03	57600.00
FA82BA	2017-08-12 05:36:00+03	13700.00
FA82E5	2017-08-12 23:22:00+03	44800.00
FA832E	2017-08-01 18:36:00+03	147100.00
FA8363	2017-07-10 07:40:00+03	96800.00
FA83C4	2017-07-24 06:14:00+03	47600.00
FA8423	2017-08-06 23:17:00+03	67500.00
FA8467	2017-08-01 02:55:00+03	56000.00
FA848D	2017-07-07 20:38:00+03	46400.00
FA84E6	2017-08-13 00:28:00+03	79900.00
FA84F2	2017-08-12 21:13:00+03	46300.00
FA8548	2017-07-01 14:40:00+03	28000.00
FA854A	2017-07-18 17:00:00+03	55800.00
FA8588	2017-08-10 17:46:00+03	73200.00
FA861B	2017-08-04 14:39:00+03	65600.00
FA8658	2017-08-04 17:03:00+03	44000.00
FA8688	2017-07-02 19:50:00+03	21400.00
FA86B9	2017-07-10 12:05:00+03	106400.00
FA86C2	2017-08-11 00:04:00+03	18300.00
FA86F8	2017-07-29 19:10:00+03	56000.00
FA8703	2017-07-08 03:39:00+03	70600.00
FA879F	2017-08-02 19:53:00+03	28000.00
FA87AD	2017-06-27 03:29:00+03	68700.00
FA87DA	2017-08-05 09:00:00+03	95600.00
FA87E7	2017-07-05 05:48:00+03	31900.00
FA87F7	2017-07-23 16:10:00+03	46400.00
FA87F8	2017-07-07 08:44:00+03	67600.00
FA8813	2017-08-13 16:14:00+03	44800.00
FA88BC	2017-07-12 20:11:00+03	159000.00
FA8943	2017-08-06 06:46:00+03	46000.00
FA89B0	2017-07-12 08:03:00+03	36200.00
FA89DC	2017-07-15 11:10:00+03	111600.00
FA8A83	2017-07-06 05:21:00+03	67600.00
FA8AA7	2017-08-04 22:12:00+03	28800.00
FA8AEB	2017-08-08 05:14:00+03	13200.00
FA8B25	2017-08-14 13:53:00+03	225200.00
FA8B4E	2017-08-07 11:44:00+03	29000.00
FA8B70	2017-08-12 04:20:00+03	273500.00
FA8B8A	2017-08-07 09:11:00+03	27800.00
FA8BA2	2017-08-11 09:35:00+03	77300.00
FA8BF5	2017-08-06 07:49:00+03	246000.00
FA8C00	2017-08-13 01:59:00+03	13800.00
FA8C17	2017-07-18 21:12:00+03	40600.00
FA8C42	2017-07-19 13:08:00+03	41400.00
FA8C5F	2017-07-14 03:19:00+03	591600.00
FA8C7D	2017-07-17 04:40:00+03	46200.00
FA8D16	2017-08-02 15:54:00+03	48100.00
FA8D6B	2017-08-10 17:42:00+03	50800.00
FA8DC1	2017-08-10 20:45:00+03	91200.00
FA8DD2	2017-08-01 16:40:00+03	62600.00
FA8DE0	2017-08-09 06:12:00+03	39200.00
FA8DE1	2017-07-19 00:05:00+03	28800.00
FA8EBA	2017-07-11 23:49:00+03	92000.00
FA8ECE	2017-08-01 14:54:00+03	25600.00
FA8F15	2017-08-06 17:57:00+03	169000.00
FA8F2C	2017-06-28 14:29:00+03	41800.00
FA8F47	2017-07-06 06:52:00+03	52000.00
FA8FD2	2017-08-03 00:57:00+03	28000.00
FA9040	2017-07-30 17:08:00+03	22000.00
FA9094	2017-06-28 11:52:00+03	32800.00
FA90A1	2017-08-01 16:57:00+03	42700.00
FA90B2	2017-07-29 16:46:00+03	82300.00
FA90D2	2017-07-07 01:28:00+03	44800.00
FA90F4	2017-08-04 22:02:00+03	68500.00
FA9149	2017-08-08 10:14:00+03	121400.00
FA915D	2017-07-21 06:10:00+03	26300.00
FA916E	2017-07-21 18:32:00+03	57500.00
FA91F9	2017-08-05 14:58:00+03	112000.00
FA9234	2017-08-14 07:12:00+03	57600.00
FA9236	2017-08-02 05:14:00+03	174700.00
FA92E2	2017-08-04 17:16:00+03	64600.00
FA92EC	2017-07-28 23:40:00+03	31600.00
FA9320	2017-07-31 22:58:00+03	61800.00
FA9351	2017-08-07 16:24:00+03	73900.00
FA9361	2017-07-19 00:19:00+03	134700.00
FA93C0	2017-07-01 18:28:00+03	56000.00
FA9405	2017-07-15 03:20:00+03	44800.00
FA9440	2017-07-21 23:02:00+03	204500.00
FA94C1	2017-07-21 01:25:00+03	113200.00
FA94C9	2017-07-20 18:22:00+03	81300.00
FA9535	2017-07-16 22:27:00+03	76100.00
FA9577	2017-08-07 18:42:00+03	69100.00
FA95B2	2017-07-24 04:28:00+03	112600.00
FA95F8	2017-07-30 17:20:00+03	56000.00
FA9668	2017-08-02 12:56:00+03	20600.00
FA9723	2017-08-08 22:32:00+03	41500.00
FA9725	2017-07-05 18:30:00+03	67200.00
FA97BC	2017-08-11 06:21:00+03	43600.00
FA9872	2017-07-08 11:10:00+03	130400.00
FA9879	2017-07-04 16:14:00+03	48700.00
FA9884	2017-07-23 11:42:00+03	249000.00
FA9899	2017-07-09 09:19:00+03	56600.00
FA98F3	2017-08-12 01:03:00+03	112000.00
FA98F6	2017-07-13 14:23:00+03	30200.00
FA9984	2017-07-14 16:07:00+03	13400.00
FA99ED	2017-08-03 06:28:00+03	62600.00
FA99F1	2017-07-29 08:37:00+03	55800.00
FA9A18	2017-06-28 06:27:00+03	26000.00
FA9A50	2017-07-14 01:24:00+03	43500.00
FA9A67	2017-08-10 10:24:00+03	56000.00
FA9A85	2017-07-23 05:39:00+03	76600.00
FA9A96	2017-07-17 07:37:00+03	23200.00
FA9B26	2017-07-08 16:02:00+03	73900.00
FA9B5E	2017-07-06 08:03:00+03	188700.00
FA9B86	2017-08-08 08:24:00+03	120400.00
FA9BE7	2017-07-30 10:50:00+03	28800.00
FA9C25	2017-08-14 23:03:00+03	43600.00
FA9C58	2017-07-08 21:49:00+03	47100.00
FA9CF4	2017-07-15 13:35:00+03	270700.00
FA9D34	2017-07-19 20:41:00+03	156300.00
FA9D94	2017-07-06 00:16:00+03	66800.00
FA9E3C	2017-08-06 16:15:00+03	143100.00
FA9E56	2017-07-28 15:59:00+03	19100.00
FA9E6C	2017-07-31 05:19:00+03	38400.00
FA9F14	2017-07-20 06:56:00+03	36200.00
FA9F21	2017-07-07 06:59:00+03	40800.00
FA9F52	2017-08-14 01:12:00+03	57600.00
FA9FDA	2017-07-30 01:26:00+03	76800.00
FA9FF3	2017-08-11 01:57:00+03	28800.00
FA9FFA	2017-07-05 21:35:00+03	73900.00
FAA028	2017-08-14 02:14:00+03	28800.00
FAA034	2017-08-07 23:42:00+03	26000.00
FAA039	2017-08-11 12:49:00+03	34000.00
FAA057	2017-07-16 02:34:00+03	163100.00
FAA0B1	2017-07-10 12:13:00+03	262100.00
FAA0BE	2017-08-07 04:05:00+03	56900.00
FAA0BF	2017-07-12 17:04:00+03	73500.00
FAA173	2017-08-01 11:42:00+03	138900.00
FAA198	2017-07-31 03:24:00+03	38800.00
FAA259	2017-08-05 01:57:00+03	65400.00
FAA26E	2017-08-11 13:59:00+03	24400.00
FAA291	2017-07-26 14:48:00+03	54600.00
FAA295	2017-08-06 23:08:00+03	15000.00
FAA301	2017-07-04 17:59:00+03	14400.00
FAA31A	2017-07-06 08:07:00+03	23600.00
FAA32A	2017-07-05 23:01:00+03	139300.00
FAA34D	2017-07-16 20:59:00+03	152900.00
FAA3B7	2017-07-22 14:19:00+03	266400.00
FAA3F1	2017-08-08 14:44:00+03	28800.00
FAA418	2017-07-14 22:51:00+03	136600.00
FAA526	2017-07-09 07:23:00+03	132800.00
FAA539	2017-08-03 09:06:00+03	62600.00
FAA549	2017-08-05 03:40:00+03	53300.00
FAA582	2017-07-14 17:13:00+03	67600.00
FAA5C2	2017-07-15 16:57:00+03	48800.00
FAA5F1	2017-07-20 11:05:00+03	108800.00
FAA603	2017-08-13 06:28:00+03	57600.00
FAA623	2017-07-31 04:29:00+03	52000.00
FAA64A	2017-07-29 14:21:00+03	67000.00
FAA675	2017-07-11 06:40:00+03	14000.00
FAA687	2017-07-04 23:50:00+03	83600.00
FAA6C9	2017-08-06 08:31:00+03	179500.00
FAA731	2017-08-13 20:42:00+03	12400.00
FAA73C	2017-07-07 18:05:00+03	52000.00
FAA78F	2017-06-30 07:43:00+03	16800.00
FAA7ED	2017-07-15 00:32:00+03	29600.00
FAA855	2017-08-06 07:17:00+03	57700.00
FAA865	2017-07-30 09:39:00+03	46400.00
FAA895	2017-07-19 14:59:00+03	48300.00
FAA904	2017-07-27 11:36:00+03	15000.00
FAA946	2017-07-08 15:00:00+03	12600.00
FAA955	2017-07-13 20:22:00+03	40400.00
FAA973	2017-07-31 13:23:00+03	155600.00
FAA9D7	2017-07-16 02:04:00+03	97600.00
FAA9F2	2017-08-06 11:24:00+03	154300.00
FAAA95	2017-08-10 15:57:00+03	105600.00
FAAAE4	2017-08-09 01:52:00+03	185600.00
FAAB62	2017-07-16 03:38:00+03	56600.00
FAAB71	2017-07-30 07:09:00+03	29600.00
FAAB78	2017-08-08 04:43:00+03	25600.00
FAABF1	2017-07-25 20:02:00+03	23200.00
FAABF8	2017-07-15 05:02:00+03	23600.00
FAAC7F	2017-07-14 18:19:00+03	46400.00
FAACAB	2017-08-14 00:31:00+03	274200.00
FAAD7C	2017-08-02 04:12:00+03	286700.00
FAAD88	2017-07-05 00:17:00+03	25600.00
FAAE27	2017-08-10 00:55:00+03	6000.00
FAAE42	2017-08-11 12:27:00+03	92000.00
FAAE72	2017-07-04 21:02:00+03	68600.00
FAAE76	2017-08-01 21:52:00+03	44600.00
FAAE92	2017-07-13 19:55:00+03	29600.00
FAAEF3	2017-07-11 15:44:00+03	113600.00
FAAF2F	2017-07-25 12:33:00+03	22000.00
FAAF85	2017-07-12 06:36:00+03	117200.00
FAB00E	2017-07-12 19:05:00+03	51200.00
FAB0B5	2017-07-02 00:15:00+03	8200.00
FAB0FF	2017-07-13 10:38:00+03	99300.00
FAB18A	2017-07-28 09:04:00+03	89600.00
FAB1A4	2017-07-14 20:11:00+03	19000.00
FAB1AF	2017-08-12 08:45:00+03	37600.00
FAB1D8	2017-07-07 10:42:00+03	240600.00
FAB25F	2017-07-09 21:41:00+03	85000.00
FAB28C	2017-08-12 16:21:00+03	88800.00
FAB295	2017-08-03 18:36:00+03	78800.00
FAB2B9	2017-07-06 21:15:00+03	41500.00
FAB2BB	2017-07-10 04:44:00+03	73500.00
FAB2D6	2017-07-23 16:51:00+03	85000.00
FAB2FD	2017-07-28 10:29:00+03	209900.00
FAB34C	2017-08-04 03:54:00+03	161200.00
FAB379	2017-07-22 08:54:00+03	13400.00
FAB3C9	2017-08-14 15:18:00+03	19600.00
FAB40C	2017-07-23 18:04:00+03	59800.00
FAB44D	2017-07-17 02:56:00+03	6700.00
FAB47A	2017-08-12 11:59:00+03	21800.00
FAB48F	2017-07-15 04:51:00+03	187400.00
FAB4B5	2017-08-03 08:07:00+03	50000.00
FAB523	2017-08-05 11:43:00+03	80200.00
FAB52D	2017-07-04 04:18:00+03	13700.00
FAB575	2017-07-23 04:52:00+03	61800.00
FAB5EE	2017-08-01 11:06:00+03	85000.00
FAB61B	2017-07-15 17:20:00+03	23200.00
FAB678	2017-08-02 07:32:00+03	42400.00
FAB6FD	2017-07-04 21:08:00+03	28000.00
FAB73F	2017-07-03 00:16:00+03	22200.00
FAB74C	2017-07-13 22:13:00+03	63700.00
FAB768	2017-08-14 06:30:00+03	47000.00
FAB795	2017-07-18 09:02:00+03	155600.00
FAB79A	2017-07-04 06:58:00+03	46300.00
FAB903	2017-07-31 06:27:00+03	369000.00
FAB9A4	2017-08-01 18:19:00+03	85400.00
FABA87	2017-07-19 13:40:00+03	43000.00
FABAC4	2017-07-02 13:22:00+03	99200.00
FABB20	2017-08-05 08:47:00+03	42700.00
FABB7B	2017-07-15 05:57:00+03	13400.00
FABB8B	2017-07-21 22:39:00+03	14400.00
FABB8F	2017-07-23 19:59:00+03	75600.00
FABBCA	2017-07-21 08:06:00+03	254900.00
FABBF8	2017-08-09 22:02:00+03	189200.00
FABC87	2017-07-22 05:05:00+03	62800.00
FABCE2	2017-08-12 12:55:00+03	38400.00
FABCF4	2017-08-01 05:37:00+03	37200.00
FABCFE	2017-08-06 00:52:00+03	46400.00
FABD4F	2017-07-10 01:59:00+03	56000.00
FABD52	2017-08-08 10:23:00+03	28800.00
FABD6D	2017-08-11 01:56:00+03	24400.00
FABD89	2017-08-10 15:05:00+03	32800.00
FABD91	2017-07-27 07:50:00+03	403300.00
FABDAD	2017-07-03 09:47:00+03	54500.00
FABEBE	2017-07-03 01:29:00+03	199100.00
FABEF6	2017-07-26 06:26:00+03	67600.00
FABF02	2017-07-24 10:42:00+03	37600.00
FAC020	2017-07-30 14:35:00+03	32800.00
FAC06E	2017-07-12 12:28:00+03	42400.00
FAC0DA	2017-07-27 11:18:00+03	35200.00
FAC0E6	2017-07-12 13:20:00+03	201200.00
FAC154	2017-07-25 05:41:00+03	131100.00
FAC18A	2017-07-08 15:05:00+03	137200.00
FAC1D7	2017-07-03 14:36:00+03	26000.00
FAC263	2017-07-25 02:05:00+03	52100.00
FAC2AB	2017-07-19 10:01:00+03	25400.00
FAC2AC	2017-08-10 16:06:00+03	73600.00
FAC2D7	2017-08-12 17:15:00+03	85000.00
FAC2FA	2017-07-28 04:26:00+03	14000.00
FAC37A	2017-07-21 12:45:00+03	47400.00
FAC3CF	2017-07-23 19:43:00+03	12600.00
FAC3DE	2017-08-14 18:52:00+03	68000.00
FAC3F6	2017-08-01 06:56:00+03	14400.00
FAC418	2017-07-17 05:48:00+03	28000.00
FAC469	2017-06-30 05:13:00+03	134400.00
FAC490	2017-07-25 06:03:00+03	25600.00
FAC4C3	2017-07-13 19:58:00+03	47100.00
FAC4CE	2017-07-03 15:37:00+03	67000.00
FAC5AD	2017-07-12 12:29:00+03	8000.00
FAC630	2017-07-09 22:16:00+03	282000.00
FAC68D	2017-07-21 08:16:00+03	11000.00
FAC694	2017-07-25 17:44:00+03	137100.00
FAC6B7	2017-08-13 12:50:00+03	37900.00
FAC6E5	2017-07-25 13:57:00+03	58400.00
FAC725	2017-07-04 07:31:00+03	123000.00
FAC7C4	2017-07-18 14:49:00+03	29400.00
FAC816	2017-07-09 20:12:00+03	55800.00
FAC81C	2017-07-15 17:28:00+03	53600.00
FAC892	2017-07-13 13:43:00+03	30200.00
FAC8D9	2017-08-06 03:42:00+03	92800.00
FAC8E1	2017-07-23 02:29:00+03	25000.00
FAC930	2017-08-14 03:23:00+03	66700.00
FAC98A	2017-07-25 06:02:00+03	101700.00
FAC9A2	2017-07-24 03:38:00+03	103400.00
FAC9B1	2017-06-25 09:22:00+03	258400.00
FAC9F4	2017-08-10 23:57:00+03	39500.00
FACA09	2017-07-04 01:39:00+03	139800.00
FACA69	2017-07-09 13:30:00+03	56600.00
FACAA0	2017-07-10 15:31:00+03	37300.00
FACAD5	2017-07-14 14:12:00+03	47100.00
FACADF	2017-07-24 11:59:00+03	52300.00
FACB1D	2017-07-29 22:44:00+03	199700.00
FACB27	2017-08-14 01:11:00+03	63200.00
FACB38	2017-07-23 22:56:00+03	141600.00
FACBF1	2017-07-17 17:00:00+03	21400.00
FACC15	2017-08-10 13:50:00+03	179400.00
FACC41	2017-08-06 23:59:00+03	10600.00
FACC56	2017-07-01 20:53:00+03	104000.00
FACC66	2017-08-15 15:54:00+03	20200.00
FACC6F	2017-07-10 19:02:00+03	78100.00
FACCFF	2017-08-01 15:40:00+03	111600.00
FACD25	2017-08-02 22:21:00+03	131100.00
FACD26	2017-07-12 23:34:00+03	166100.00
FACE10	2017-07-31 21:18:00+03	123000.00
FACE13	2017-07-26 19:28:00+03	109200.00
FACE7B	2017-07-14 22:21:00+03	89700.00
FACE90	2017-07-31 18:50:00+03	136800.00
FACEA6	2017-07-26 05:17:00+03	46300.00
FACEEA	2017-07-26 12:59:00+03	43300.00
FACF2F	2017-07-26 14:58:00+03	74600.00
FACFA1	2017-08-08 00:25:00+03	65500.00
FAD003	2017-07-04 15:19:00+03	34200.00
FAD00E	2017-07-22 12:17:00+03	71200.00
FAD025	2017-08-05 18:26:00+03	6300.00
FAD04E	2017-07-11 16:37:00+03	89200.00
FAD08F	2017-07-17 17:16:00+03	70600.00
FAD0D1	2017-08-07 14:20:00+03	137100.00
FAD1A2	2017-07-10 22:43:00+03	56000.00
FAD207	2017-08-03 21:58:00+03	28000.00
FAD20E	2017-07-16 09:00:00+03	291300.00
FAD229	2017-08-08 03:16:00+03	68100.00
FAD252	2017-07-12 22:59:00+03	58800.00
FAD298	2017-08-14 00:07:00+03	29400.00
FAD2C6	2017-08-09 16:52:00+03	15900.00
FAD2F4	2017-07-17 06:14:00+03	75600.00
FAD307	2017-07-04 13:08:00+03	56600.00
FAD342	2017-08-09 07:35:00+03	59400.00
FAD3BA	2017-08-03 06:32:00+03	56600.00
FAD3C8	2017-07-13 19:00:00+03	59800.00
FAD3D6	2017-07-06 06:00:00+03	31200.00
FAD43F	2017-08-07 11:35:00+03	38800.00
FAD443	2017-08-06 19:18:00+03	118000.00
FAD467	2017-08-05 16:49:00+03	43600.00
FAD494	2017-07-25 19:42:00+03	74800.00
FAD4C5	2017-07-26 08:21:00+03	28000.00
FAD546	2017-07-30 08:28:00+03	34800.00
FAD54A	2017-07-13 22:52:00+03	12400.00
FAD56F	2017-08-05 08:36:00+03	76100.00
FAD577	2017-07-10 15:18:00+03	102100.00
FAD5B4	2017-08-09 18:33:00+03	428300.00
FAD5CA	2017-08-13 07:26:00+03	44600.00
FAD652	2017-08-08 15:11:00+03	60400.00
FAD6A4	2017-07-13 19:04:00+03	318000.00
FAD6DB	2017-08-07 05:07:00+03	125200.00
FAD6EE	2017-07-07 07:55:00+03	95200.00
FAD714	2017-07-06 23:21:00+03	67600.00
FAD776	2017-08-15 04:20:00+03	46500.00
FAD792	2017-07-14 06:57:00+03	260900.00
FAD7A7	2017-07-02 18:07:00+03	85000.00
FAD7BA	2017-08-11 06:17:00+03	80700.00
FAD7CF	2017-08-09 19:57:00+03	89200.00
FAD7DC	2017-07-21 16:36:00+03	136200.00
FAD802	2017-07-07 03:43:00+03	68400.00
FAD889	2017-08-12 05:22:00+03	532800.00
FAD8E0	2017-07-19 14:13:00+03	56000.00
FAD917	2017-08-12 04:59:00+03	73600.00
FAD918	2017-08-14 13:03:00+03	23200.00
FAD978	2017-07-19 10:29:00+03	131600.00
FADA63	2017-07-25 22:43:00+03	55800.00
FADB12	2017-07-06 06:24:00+03	25800.00
FADB29	2017-07-17 23:50:00+03	48800.00
FADBF8	2017-08-13 14:37:00+03	28800.00
FADBF9	2017-07-30 02:00:00+03	26700.00
FADC24	2017-07-30 08:45:00+03	24400.00
FADC26	2017-07-22 23:07:00+03	100600.00
FADC9D	2017-07-03 23:28:00+03	57500.00
FADCA1	2017-08-06 04:02:00+03	201200.00
FADD0D	2017-08-10 06:58:00+03	28000.00
FADD51	2017-08-03 18:04:00+03	260300.00
FADD68	2017-07-26 22:23:00+03	46400.00
FADDEB	2017-08-10 23:05:00+03	31600.00
FADDF1	2017-07-23 13:24:00+03	16400.00
FADE07	2017-07-06 02:54:00+03	331700.00
FADEA6	2017-07-18 18:36:00+03	135600.00
FADEB1	2017-08-01 09:07:00+03	98400.00
FADF73	2017-08-03 02:09:00+03	29400.00
FADF9C	2017-08-13 13:17:00+03	10700.00
FADFA0	2017-07-05 17:12:00+03	47500.00
FADFD8	2017-07-06 13:32:00+03	31600.00
FAE08B	2017-07-23 22:18:00+03	44600.00
FAE0FD	2017-07-10 08:21:00+03	29400.00
FAE12F	2017-07-23 20:00:00+03	12600.00
FAE153	2017-07-04 18:06:00+03	22100.00
FAE19B	2017-07-01 06:49:00+03	125600.00
FAE1B7	2017-07-15 00:08:00+03	75600.00
FAE1FE	2017-07-12 20:46:00+03	28000.00
FAE212	2017-07-18 09:11:00+03	207300.00
FAE2C2	2017-07-27 07:36:00+03	103800.00
FAE2F5	2017-07-17 01:32:00+03	29400.00
FAE35D	2017-07-18 15:14:00+03	40400.00
FAE3A9	2017-07-20 05:40:00+03	286100.00
FAE3E6	2017-08-03 03:13:00+03	62600.00
FAE41F	2017-07-30 02:55:00+03	43200.00
FAE42B	2017-08-01 00:54:00+03	6000.00
FAE430	2017-07-11 16:34:00+03	61800.00
FAE4C0	2017-08-09 06:19:00+03	67900.00
FAE578	2017-07-22 01:14:00+03	45000.00
FAE58C	2017-08-05 13:19:00+03	49200.00
FAE5DE	2017-08-06 09:33:00+03	64400.00
FAE5F7	2017-07-17 07:11:00+03	13600.00
FAE644	2017-07-03 02:49:00+03	22000.00
FAE72F	2017-07-08 00:04:00+03	40800.00
FAE7AF	2017-08-03 15:18:00+03	50900.00
FAE7E6	2017-07-03 13:45:00+03	53200.00
FAE835	2017-08-03 07:30:00+03	128800.00
FAE883	2017-08-01 00:26:00+03	265700.00
FAE8A6	2017-07-17 18:04:00+03	47200.00
FAE94F	2017-07-11 16:39:00+03	46400.00
FAE997	2017-08-14 20:34:00+03	47200.00
FAE9C2	2017-08-04 06:57:00+03	286800.00
FAE9CA	2017-07-18 22:48:00+03	44800.00
FAE9E2	2017-07-01 13:59:00+03	56600.00
FAEA18	2017-07-21 01:35:00+03	17600.00
FAEA33	2017-08-06 06:58:00+03	30600.00
FAEA56	2017-07-09 16:18:00+03	83200.00
FAEA67	2017-07-18 14:02:00+03	16400.00
FAEAB4	2017-08-12 20:42:00+03	58600.00
FAEABC	2017-08-09 17:52:00+03	160000.00
FAEB5F	2017-08-01 14:40:00+03	30000.00
FAEC0C	2017-07-17 16:55:00+03	111600.00
FAEC39	2017-07-22 08:47:00+03	29600.00
FAEC47	2017-08-07 21:16:00+03	66000.00
FAECD3	2017-08-05 10:07:00+03	43500.00
FAED3B	2017-07-03 18:00:00+03	87700.00
FAED4C	2017-07-05 21:44:00+03	23200.00
FAED84	2017-07-28 05:37:00+03	33800.00
FAED90	2017-06-29 12:28:00+03	56600.00
FAEDFC	2017-07-12 17:35:00+03	62000.00
FAEE31	2017-07-04 03:23:00+03	257500.00
FAEF83	2017-07-15 03:31:00+03	16400.00
FAEFA5	2017-08-02 15:36:00+03	123000.00
FAF019	2017-07-29 12:49:00+03	52600.00
FAF070	2017-07-12 11:48:00+03	42800.00
FAF0B1	2017-08-04 18:21:00+03	15800.00
FAF0B5	2017-07-29 04:35:00+03	21400.00
FAF167	2017-08-05 19:01:00+03	167400.00
FAF268	2017-07-13 05:59:00+03	28000.00
FAF305	2017-08-03 16:58:00+03	26800.00
FAF30D	2017-07-05 10:34:00+03	46400.00
FAF30F	2017-08-04 14:05:00+03	79100.00
FAF3A5	2017-07-19 05:47:00+03	91200.00
FAF3A8	2017-08-02 08:28:00+03	52700.00
FAF3B5	2017-08-08 21:36:00+03	24000.00
FAF3D2	2017-07-23 03:55:00+03	21800.00
FAF437	2017-07-04 00:46:00+03	78500.00
FAF46E	2017-08-04 10:45:00+03	32800.00
FAF46F	2017-07-20 18:04:00+03	49500.00
FAF4A6	2017-07-04 18:58:00+03	27200.00
FAF4EF	2017-07-07 18:43:00+03	39800.00
FAF580	2017-08-02 15:12:00+03	199700.00
FAF5AA	2017-07-30 11:56:00+03	11000.00
FAF5AB	2017-07-21 02:31:00+03	16800.00
FAF5C2	2017-07-08 09:00:00+03	30200.00
FAF5CA	2017-07-10 00:05:00+03	48800.00
FAF6BF	2017-08-11 22:28:00+03	52600.00
FAF6EE	2017-07-28 16:31:00+03	35200.00
FAF75F	2017-08-09 04:55:00+03	130900.00
FAF765	2017-07-15 07:16:00+03	66000.00
FAF785	2017-07-31 21:03:00+03	45200.00
FAF831	2017-07-02 16:03:00+03	40800.00
FAF842	2017-07-31 08:43:00+03	32700.00
FAF8BF	2017-07-11 10:01:00+03	47400.00
FAF8D7	2017-07-23 00:13:00+03	115900.00
FAF8EF	2017-07-29 00:13:00+03	68000.00
FAF90F	2017-07-10 00:27:00+03	31600.00
FAF930	2017-07-01 21:11:00+03	20200.00
FAF955	2017-08-06 13:13:00+03	30400.00
FAF95C	2017-08-09 03:02:00+03	46000.00
FAF97F	2017-07-15 18:36:00+03	58200.00
FAFA72	2017-07-23 00:38:00+03	372500.00
FAFAA1	2017-08-10 08:51:00+03	23600.00
FAFAA3	2017-07-01 23:28:00+03	25000.00
FAFB46	2017-07-02 03:43:00+03	10800.00
FAFBCF	2017-07-12 00:14:00+03	112000.00
FAFC73	2017-08-01 18:26:00+03	28000.00
FAFCA9	2017-07-10 08:23:00+03	23200.00
FAFD4D	2017-08-08 07:03:00+03	32400.00
FAFD72	2017-07-01 17:13:00+03	46000.00
FAFDD7	2017-08-12 22:46:00+03	67000.00
FAFE45	2017-07-30 11:23:00+03	51800.00
FAFF36	2017-07-29 20:36:00+03	14400.00
FAFF7F	2017-08-10 17:47:00+03	12400.00
FAFFA4	2017-07-02 14:41:00+03	44800.00
FAFFE8	2017-07-08 09:30:00+03	55500.00
FB002C	2017-07-21 08:45:00+03	20100.00
FB0034	2017-07-31 02:31:00+03	47000.00
FB00FC	2017-07-30 05:53:00+03	52000.00
FB0136	2017-07-15 17:34:00+03	77600.00
FB015B	2017-07-19 03:15:00+03	43600.00
FB016E	2017-08-01 15:38:00+03	88000.00
FB017C	2017-07-13 21:05:00+03	67000.00
FB01BE	2017-07-11 19:13:00+03	31100.00
FB0232	2017-08-12 02:28:00+03	26000.00
FB02CE	2017-07-23 01:12:00+03	94800.00
FB02FB	2017-07-12 21:28:00+03	138600.00
FB0368	2017-07-05 12:03:00+03	38600.00
FB0379	2017-07-25 04:29:00+03	21800.00
FB03B1	2017-08-04 09:57:00+03	44000.00
FB03BA	2017-07-13 23:58:00+03	20200.00
FB03DA	2017-07-13 21:52:00+03	38600.00
FB03E1	2017-07-16 14:17:00+03	48700.00
FB043E	2017-08-08 12:36:00+03	91800.00
FB046D	2017-08-13 12:50:00+03	12600.00
FB058D	2017-06-29 10:43:00+03	23200.00
FB05C3	2017-08-14 15:03:00+03	228400.00
FB05D7	2017-08-07 00:10:00+03	115600.00
FB0606	2017-07-18 23:14:00+03	27800.00
FB062E	2017-07-12 06:10:00+03	90000.00
FB063E	2017-07-23 14:18:00+03	227200.00
FB070F	2017-07-25 12:10:00+03	75300.00
FB0720	2017-08-08 01:28:00+03	199700.00
FB0734	2017-08-08 11:20:00+03	37100.00
FB075D	2017-07-29 01:29:00+03	40800.00
FB07DD	2017-06-30 14:07:00+03	20600.00
FB0819	2017-07-02 19:45:00+03	58600.00
FB087F	2017-08-06 01:50:00+03	106500.00
FB08C6	2017-08-03 13:02:00+03	17600.00
FB093D	2017-07-12 12:15:00+03	84100.00
FB096C	2017-08-01 17:10:00+03	11600.00
FB097D	2017-08-13 12:58:00+03	13400.00
FB0981	2017-07-02 04:44:00+03	170300.00
FB099C	2017-07-10 20:17:00+03	75300.00
FB09A8	2017-08-09 06:13:00+03	65500.00
FB09DE	2017-07-16 19:40:00+03	57600.00
FB0A1A	2017-07-29 07:26:00+03	31400.00
FB0A31	2017-08-02 14:19:00+03	25400.00
FB0A3D	2017-08-15 12:28:00+03	26000.00
FB0A80	2017-07-18 05:44:00+03	34000.00
FB0AA4	2017-07-24 11:26:00+03	28000.00
FB0B4D	2017-07-03 08:56:00+03	149300.00
FB0B52	2017-08-13 20:05:00+03	108200.00
FB0B98	2017-07-08 23:13:00+03	246000.00
FB0BBF	2017-08-02 01:43:00+03	46000.00
FB0C58	2017-07-05 23:28:00+03	35200.00
FB0C63	2017-08-08 10:50:00+03	68100.00
FB0CB3	2017-07-26 08:52:00+03	162000.00
FB0CEB	2017-07-29 20:13:00+03	86800.00
FB0D39	2017-08-08 09:23:00+03	56000.00
FB0D3F	2017-07-13 22:15:00+03	43500.00
FB0D96	2017-08-07 16:48:00+03	126600.00
FB0DAF	2017-07-04 14:12:00+03	12400.00
FB0E13	2017-08-02 11:42:00+03	62100.00
FB0E15	2017-07-21 14:01:00+03	136500.00
FB0E66	2017-07-07 09:02:00+03	85000.00
FB0EB8	2017-08-03 14:33:00+03	97500.00
FB0F84	2017-08-06 07:05:00+03	28800.00
FB0FAF	2017-08-03 01:18:00+03	19600.00
FB0FE4	2017-07-28 11:34:00+03	155600.00
FB0FE6	2017-07-02 19:19:00+03	288800.00
FB100C	2017-08-10 00:14:00+03	27900.00
FB1030	2017-07-09 23:57:00+03	295400.00
FB104E	2017-07-17 14:08:00+03	40600.00
FB1074	2017-08-13 16:00:00+03	101500.00
FB10CA	2017-07-06 02:02:00+03	46400.00
FB10FD	2017-08-14 05:36:00+03	28000.00
FB110C	2017-07-19 15:59:00+03	34000.00
FB11E5	2017-07-14 17:16:00+03	133200.00
FB11FF	2017-07-11 21:42:00+03	37500.00
FB12DF	2017-07-29 06:48:00+03	46200.00
FB12F7	2017-08-04 13:13:00+03	52000.00
FB136C	2017-07-30 06:34:00+03	301800.00
FB13AD	2017-07-10 08:30:00+03	10600.00
FB144B	2017-08-10 10:41:00+03	24800.00
FB145E	2017-07-07 07:30:00+03	92800.00
FB1496	2017-07-14 06:08:00+03	58600.00
FB14BB	2017-07-18 04:25:00+03	17200.00
FB14CB	2017-07-17 19:36:00+03	66800.00
FB14DF	2017-08-07 15:03:00+03	44500.00
FB1520	2017-07-15 02:49:00+03	34000.00
FB1588	2017-07-11 04:13:00+03	64400.00
FB15A5	2017-08-03 16:39:00+03	88100.00
FB15CE	2017-08-13 01:26:00+03	131600.00
FB1651	2017-07-06 18:55:00+03	65200.00
FB1693	2017-08-15 17:15:00+03	71200.00
FB16D7	2017-07-30 19:23:00+03	38800.00
FB172F	2017-08-15 01:47:00+03	66400.00
FB1763	2017-07-13 14:08:00+03	7300.00
FB17E0	2017-08-11 04:12:00+03	240600.00
FB1812	2017-07-19 06:20:00+03	159200.00
FB183A	2017-08-07 03:26:00+03	116400.00
FB1863	2017-07-09 23:08:00+03	201200.00
FB18E8	2017-08-13 23:59:00+03	25200.00
FB18F2	2017-07-25 03:59:00+03	105100.00
FB190C	2017-07-05 10:12:00+03	47600.00
FB1911	2017-07-26 22:11:00+03	547600.00
FB194F	2017-07-18 05:23:00+03	99900.00
FB1A00	2017-07-27 19:08:00+03	68800.00
FB1A3D	2017-08-09 09:03:00+03	51900.00
FB1A4B	2017-07-02 23:54:00+03	89700.00
FB1A4E	2017-07-18 02:17:00+03	19600.00
FB1A76	2017-07-23 05:09:00+03	266400.00
FB1AA8	2017-07-04 05:08:00+03	56900.00
FB1AB0	2017-08-01 22:14:00+03	92600.00
FB1B1F	2017-07-12 03:11:00+03	19600.00
FB1B71	2017-07-13 19:36:00+03	39500.00
FB1BB2	2017-07-25 05:46:00+03	55800.00
FB1BDE	2017-07-23 08:43:00+03	7400.00
FB1BDF	2017-08-01 02:20:00+03	77600.00
FB1BE1	2017-07-29 22:24:00+03	72200.00
FB1C10	2017-08-09 17:16:00+03	44600.00
FB1C17	2017-07-23 13:13:00+03	57400.00
FB1C63	2017-07-22 12:14:00+03	24400.00
FB1C71	2017-07-11 22:30:00+03	55800.00
FB1D48	2017-06-27 12:29:00+03	112000.00
FB1D94	2017-08-03 12:23:00+03	55800.00
FB1E0C	2017-07-25 11:34:00+03	121400.00
FB1E79	2017-07-26 11:27:00+03	130200.00
FB1E99	2017-08-05 08:53:00+03	48800.00
FB1E9B	2017-08-14 11:18:00+03	12200.00
FB1EB0	2017-07-16 13:19:00+03	65200.00
FB1EC1	2017-07-03 05:58:00+03	65200.00
FB1F16	2017-07-10 04:51:00+03	43800.00
FB1F6E	2017-07-06 07:22:00+03	55800.00
FB1F7B	2017-07-19 09:11:00+03	71600.00
FB1FD1	2017-07-16 00:28:00+03	143400.00
FB201A	2017-07-15 04:28:00+03	14400.00
FB2029	2017-08-15 01:08:00+03	81600.00
FB2040	2017-07-12 03:01:00+03	85400.00
FB20A2	2017-07-07 20:37:00+03	131100.00
FB20F1	2017-08-12 07:05:00+03	6000.00
FB2103	2017-08-01 05:11:00+03	255600.00
FB211A	2017-07-29 12:06:00+03	257600.00
FB217A	2017-07-14 10:46:00+03	99500.00
FB222C	2017-08-01 07:13:00+03	8400.00
FB22A1	2017-07-28 11:28:00+03	13200.00
FB22BE	2017-08-05 18:48:00+03	75300.00
FB22E3	2017-07-25 02:43:00+03	28800.00
FB2331	2017-07-12 11:20:00+03	18000.00
FB2366	2017-07-30 08:54:00+03	283100.00
FB2380	2017-07-03 10:05:00+03	53500.00
FB244B	2017-08-06 20:34:00+03	74400.00
FB248C	2017-07-20 21:34:00+03	11600.00
FB24C5	2017-07-08 06:20:00+03	63500.00
FB251C	2017-07-04 12:27:00+03	58800.00
FB255F	2017-08-02 10:40:00+03	6000.00
FB2599	2017-08-05 17:17:00+03	48800.00
FB25F8	2017-07-15 15:23:00+03	34600.00
FB2630	2017-08-14 08:16:00+03	71200.00
FB2653	2017-08-02 12:30:00+03	21800.00
FB2671	2017-07-27 03:12:00+03	19600.00
FB26BF	2017-08-08 04:19:00+03	94900.00
FB26D2	2017-07-24 14:20:00+03	7400.00
FB2734	2017-07-19 13:57:00+03	8200.00
FB276A	2017-07-25 23:48:00+03	80900.00
FB27BA	2017-07-30 14:11:00+03	89200.00
FB284D	2017-07-16 16:55:00+03	49800.00
FB2851	2017-08-01 02:19:00+03	81300.00
FB288F	2017-07-05 10:37:00+03	189300.00
FB28A1	2017-08-06 08:02:00+03	100200.00
FB28C7	2017-07-14 20:56:00+03	56000.00
FB28D4	2017-07-22 02:28:00+03	31600.00
FB2936	2017-07-10 11:01:00+03	54800.00
FB2938	2017-07-05 21:38:00+03	31600.00
FB2995	2017-08-12 21:34:00+03	121500.00
FB2A55	2017-07-23 05:49:00+03	306200.00
FB2A8C	2017-07-04 17:15:00+03	40200.00
FB2AB2	2017-08-08 07:08:00+03	124200.00
FB2ABA	2017-06-30 17:44:00+03	89100.00
FB2ABF	2017-07-29 07:57:00+03	21800.00
FB2B42	2017-08-05 15:15:00+03	13400.00
FB2B79	2017-07-04 15:21:00+03	29400.00
FB2BF2	2017-07-22 13:13:00+03	97900.00
FB2BF8	2017-08-14 13:59:00+03	117200.00
FB2C63	2017-07-28 14:58:00+03	39200.00
FB2C98	2017-07-08 20:10:00+03	91100.00
FB2D05	2017-07-13 05:24:00+03	14800.00
FB2D0E	2017-06-29 11:16:00+03	123000.00
FB2D35	2017-08-05 07:25:00+03	52600.00
FB2D50	2017-07-23 03:27:00+03	108600.00
FB2D57	2017-07-25 15:48:00+03	38400.00
FB2D66	2017-08-05 08:05:00+03	49400.00
FB2DE7	2017-08-11 13:28:00+03	101700.00
FB2E52	2017-08-09 19:20:00+03	66600.00
FB2E5D	2017-07-15 15:50:00+03	130900.00
FB2E92	2017-07-12 01:25:00+03	270000.00
FB2EAD	2017-07-26 15:45:00+03	37600.00
FB2F5A	2017-08-05 15:05:00+03	68800.00
FB2FBF	2017-07-08 11:05:00+03	147600.00
FB2FCE	2017-08-04 04:34:00+03	23100.00
FB300B	2017-07-20 04:45:00+03	133100.00
FB3028	2017-07-03 00:25:00+03	26000.00
FB3029	2017-07-09 08:07:00+03	28800.00
FB302D	2017-07-04 11:59:00+03	123000.00
FB3031	2017-07-30 00:02:00+03	155600.00
FB304C	2017-08-11 19:23:00+03	31900.00
FB3074	2017-07-03 21:56:00+03	28800.00
FB30C0	2017-07-12 04:11:00+03	70600.00
FB3138	2017-07-28 03:21:00+03	23400.00
FB31FE	2017-08-02 09:39:00+03	296100.00
FB3209	2017-06-30 12:02:00+03	121500.00
FB3262	2017-08-14 12:26:00+03	13400.00
FB3266	2017-08-08 18:42:00+03	193100.00
FB3280	2017-06-30 05:56:00+03	59800.00
FB32A9	2017-07-01 04:10:00+03	56000.00
FB32EB	2017-07-06 03:45:00+03	24400.00
FB32F3	2017-07-08 23:15:00+03	136500.00
FB3377	2017-07-25 09:29:00+03	38400.00
FB33B7	2017-07-18 22:20:00+03	54500.00
FB3477	2017-07-06 01:24:00+03	20800.00
FB3498	2017-07-07 02:01:00+03	22000.00
FB3587	2017-07-29 13:58:00+03	11600.00
FB35D5	2017-07-30 12:27:00+03	397700.00
FB35F6	2017-08-10 04:51:00+03	54500.00
FB360B	2017-07-19 04:00:00+03	6900.00
FB3617	2017-08-08 23:27:00+03	30200.00
FB3629	2017-06-27 14:35:00+03	43400.00
FB3639	2017-07-20 04:41:00+03	42800.00
FB366C	2017-08-05 06:57:00+03	116400.00
FB3704	2017-08-14 20:08:00+03	38800.00
FB3747	2017-08-05 15:56:00+03	59300.00
FB374C	2017-08-04 22:52:00+03	46800.00
FB37CB	2017-07-05 07:11:00+03	75300.00
FB37E8	2017-08-08 00:04:00+03	98700.00
FB37F4	2017-08-12 07:23:00+03	43200.00
FB3802	2017-07-06 03:11:00+03	370700.00
FB38C9	2017-07-15 14:26:00+03	243700.00
FB3901	2017-07-17 14:17:00+03	28000.00
FB39A1	2017-08-05 19:22:00+03	6600.00
FB39B6	2017-08-09 21:25:00+03	24400.00
FB39E4	2017-08-12 11:42:00+03	192800.00
FB39ED	2017-07-14 07:52:00+03	99200.00
FB3A10	2017-08-09 19:47:00+03	75300.00
FB3A3B	2017-07-15 22:45:00+03	99800.00
FB3A3D	2017-08-04 01:46:00+03	34000.00
FB3A7B	2017-07-10 20:30:00+03	18600.00
FB3B3E	2017-08-09 22:30:00+03	105000.00
FB3B64	2017-07-13 20:05:00+03	19800.00
FB3BCD	2017-07-25 04:40:00+03	17200.00
FB3BE9	2017-07-18 00:54:00+03	25400.00
FB3CF9	2017-08-11 08:18:00+03	21200.00
FB3D1A	2017-08-04 02:25:00+03	40300.00
FB3D2B	2017-08-06 05:32:00+03	49800.00
FB3D9D	2017-08-06 00:23:00+03	24700.00
FB3DA3	2017-07-01 11:16:00+03	42800.00
FB3E1A	2017-07-31 21:07:00+03	46400.00
FB3E8A	2017-08-13 11:59:00+03	21400.00
FB3ECE	2017-08-14 12:45:00+03	42800.00
FB3F07	2017-07-05 09:13:00+03	38200.00
FB3F40	2017-07-24 03:52:00+03	19600.00
FB3FBE	2017-07-01 10:40:00+03	63700.00
FB401D	2017-08-13 22:53:00+03	57500.00
FB401E	2017-08-10 22:30:00+03	53600.00
FB4077	2017-08-01 16:55:00+03	91500.00
FB407C	2017-07-08 01:41:00+03	210000.00
FB4103	2017-08-12 06:20:00+03	22000.00
FB4128	2017-08-09 12:58:00+03	68800.00
FB4148	2017-08-13 15:42:00+03	60400.00
FB41D1	2017-07-30 17:36:00+03	29500.00
FB41EC	2017-08-06 12:06:00+03	80200.00
FB42CA	2017-08-06 06:04:00+03	36200.00
FB42DD	2017-07-17 06:43:00+03	54300.00
FB42F2	2017-07-14 18:02:00+03	99300.00
FB4334	2017-07-17 16:38:00+03	369000.00
FB438F	2017-07-31 08:24:00+03	44000.00
FB4390	2017-08-06 17:32:00+03	31400.00
FB43D4	2017-08-12 07:40:00+03	44100.00
FB4465	2017-07-23 18:55:00+03	73600.00
FB4468	2017-08-06 08:47:00+03	62300.00
FB448A	2017-07-10 14:47:00+03	24400.00
FB4492	2017-08-07 14:30:00+03	70500.00
FB4494	2017-07-02 03:12:00+03	75300.00
FB44F5	2017-07-08 23:37:00+03	28000.00
FB44F7	2017-08-13 17:58:00+03	125600.00
FB457B	2017-08-06 14:00:00+03	45200.00
FB45F2	2017-07-20 13:24:00+03	14800.00
FB4607	2017-07-06 11:07:00+03	29500.00
FB461A	2017-07-08 17:36:00+03	73100.00
FB461C	2017-06-28 14:00:00+03	46000.00
FB4635	2017-07-12 13:44:00+03	52000.00
FB4643	2017-07-26 08:17:00+03	156300.00
FB46B2	2017-08-12 13:46:00+03	23600.00
FB46C2	2017-07-10 20:40:00+03	66600.00
FB46CD	2017-07-05 04:16:00+03	56000.00
FB46DC	2017-08-12 05:46:00+03	67000.00
FB46EC	2017-07-20 18:48:00+03	37400.00
FB4702	2017-06-27 19:21:00+03	49200.00
FB47A2	2017-08-06 15:00:00+03	47000.00
FB47B4	2017-07-26 21:36:00+03	58400.00
FB47D7	2017-08-15 15:14:00+03	30400.00
FB4803	2017-07-16 08:21:00+03	24800.00
FB4804	2017-08-12 14:04:00+03	29400.00
FB4824	2017-08-01 06:35:00+03	114800.00
FB4852	2017-07-05 07:36:00+03	111600.00
FB4863	2017-08-06 08:25:00+03	58400.00
FB48ED	2017-07-17 04:19:00+03	11700.00
FB4900	2017-07-01 21:14:00+03	61500.00
FB4914	2017-07-07 23:38:00+03	26000.00
FB4939	2017-07-12 09:16:00+03	20200.00
FB498E	2017-07-17 06:19:00+03	27900.00
FB49A1	2017-07-19 20:06:00+03	56600.00
FB49B5	2017-08-05 11:35:00+03	50600.00
FB49C7	2017-07-30 06:09:00+03	44500.00
FB49DB	2017-07-28 18:22:00+03	265800.00
FB49F3	2017-07-24 20:47:00+03	83000.00
FB4A4B	2017-07-10 08:32:00+03	241200.00
FB4AB8	2017-08-13 01:00:00+03	56000.00
FB4B0D	2017-07-10 17:25:00+03	23400.00
FB4B66	2017-08-06 06:43:00+03	153300.00
FB4BDC	2017-07-17 00:14:00+03	496600.00
FB4C0E	2017-07-18 09:24:00+03	94300.00
FB4C60	2017-07-27 05:37:00+03	36200.00
FB4C8D	2017-07-14 02:17:00+03	43200.00
FB4CF1	2017-07-30 14:30:00+03	133200.00
FB4D13	2017-07-03 09:18:00+03	7300.00
FB4D65	2017-07-09 11:19:00+03	16400.00
FB4E43	2017-07-04 12:03:00+03	199200.00
FB4E5A	2017-08-04 12:40:00+03	229600.00
FB4E95	2017-07-26 02:47:00+03	24300.00
FB4EE0	2017-08-14 01:27:00+03	10600.00
FB4F2E	2017-08-14 01:31:00+03	52400.00
FB5056	2017-08-11 20:44:00+03	46300.00
FB5086	2017-08-15 01:15:00+03	23600.00
FB508B	2017-08-04 16:31:00+03	143100.00
FB5090	2017-07-04 21:07:00+03	131600.00
FB50A7	2017-07-17 04:20:00+03	40800.00
FB50C4	2017-08-08 00:53:00+03	55800.00
FB5101	2017-07-22 09:51:00+03	13200.00
FB5115	2017-07-14 09:28:00+03	14000.00
FB5169	2017-07-10 10:04:00+03	26000.00
FB518B	2017-07-24 19:32:00+03	23200.00
FB519D	2017-07-10 14:02:00+03	96800.00
FB51BD	2017-07-15 01:36:00+03	31400.00
FB51C0	2017-06-23 22:23:00+03	143000.00
FB51D5	2017-08-11 22:34:00+03	133200.00
FB51F3	2017-08-01 18:12:00+03	80000.00
FB5204	2017-08-13 04:41:00+03	65800.00
FB5216	2017-07-28 08:44:00+03	111600.00
FB5235	2017-07-02 23:48:00+03	111600.00
FB52B1	2017-08-05 15:43:00+03	119500.00
FB52CF	2017-07-06 12:13:00+03	7300.00
FB5320	2017-07-09 08:59:00+03	11900.00
FB53CF	2017-06-30 16:45:00+03	114400.00
FB53EA	2017-08-07 20:54:00+03	379600.00
FB543D	2017-07-05 11:12:00+03	29400.00
FB544E	2017-08-04 20:22:00+03	281500.00
FB55D4	2017-07-16 09:59:00+03	13800.00
FB55E1	2017-07-18 23:09:00+03	56000.00
FB5605	2017-07-22 17:40:00+03	154400.00
FB5660	2017-07-13 13:04:00+03	25200.00
FB566D	2017-07-23 19:19:00+03	56600.00
FB5676	2017-08-13 10:15:00+03	160800.00
FB56DC	2017-07-29 06:06:00+03	265700.00
FB570D	2017-07-17 17:19:00+03	31600.00
FB5793	2017-07-10 14:38:00+03	29600.00
FB57F5	2017-07-18 03:11:00+03	114400.00
FB5837	2017-07-16 15:40:00+03	68100.00
FB5854	2017-07-26 15:48:00+03	38200.00
FB5860	2017-07-07 14:20:00+03	43600.00
FB5896	2017-06-30 23:17:00+03	61500.00
FB58B4	2017-08-10 22:04:00+03	75600.00
FB5906	2017-07-22 01:13:00+03	120800.00
FB598A	2017-07-06 07:49:00+03	8000.00
FB5997	2017-07-18 08:46:00+03	57500.00
FB59BC	2017-08-14 01:59:00+03	66600.00
FB59F9	2017-08-05 19:58:00+03	38400.00
FB5AF0	2017-08-02 01:26:00+03	32700.00
FB5B36	2017-07-14 22:24:00+03	15400.00
FB5B53	2017-07-13 06:54:00+03	23600.00
FB5BA2	2017-08-08 13:20:00+03	46400.00
FB5BE3	2017-07-14 17:41:00+03	123000.00
FB5C2E	2017-08-04 15:49:00+03	52000.00
FB5C80	2017-07-28 17:30:00+03	57700.00
FB5D47	2017-07-23 10:08:00+03	189300.00
FB5DD6	2017-08-11 13:05:00+03	210100.00
FB5F0C	2017-07-06 12:00:00+03	153300.00
FB5F19	2017-08-08 17:31:00+03	15400.00
FB5F80	2017-07-09 21:03:00+03	13400.00
FB5F93	2017-07-10 06:57:00+03	202800.00
FB5FFF	2017-07-16 06:14:00+03	24000.00
FB6020	2017-08-11 05:13:00+03	176600.00
FB606C	2017-08-03 11:03:00+03	86300.00
FB6105	2017-07-09 23:20:00+03	46000.00
FB614F	2017-08-11 14:13:00+03	62300.00
FB615C	2017-08-15 14:28:00+03	29100.00
FB6167	2017-07-18 00:35:00+03	22000.00
FB6174	2017-07-16 16:28:00+03	269100.00
FB6175	2017-07-27 01:15:00+03	290400.00
FB61D3	2017-07-09 15:42:00+03	46400.00
FB61D4	2017-07-21 14:54:00+03	28000.00
FB61DF	2017-08-07 21:39:00+03	23200.00
FB61E4	2017-08-06 20:01:00+03	103800.00
FB6235	2017-08-06 15:43:00+03	65900.00
FB6278	2017-08-14 07:24:00+03	26000.00
FB62E2	2017-07-22 13:46:00+03	32800.00
FB6360	2017-07-11 10:29:00+03	28000.00
FB63C9	2017-06-29 11:31:00+03	28800.00
FB63D1	2017-07-24 15:52:00+03	29600.00
FB63EF	2017-06-30 07:52:00+03	28000.00
FB640C	2017-07-24 00:32:00+03	57400.00
FB6415	2017-08-07 15:48:00+03	49800.00
FB641B	2017-08-08 12:00:00+03	6000.00
FB6425	2017-08-09 11:57:00+03	46400.00
FB646F	2017-08-03 17:27:00+03	29600.00
FB64A8	2017-08-01 16:30:00+03	10800.00
FB654C	2017-08-15 11:56:00+03	104600.00
FB65AA	2017-07-11 02:13:00+03	13800.00
FB65D8	2017-07-27 02:39:00+03	246000.00
FB6621	2017-07-30 16:27:00+03	35200.00
FB663E	2017-07-05 03:14:00+03	26000.00
FB668C	2017-08-04 19:06:00+03	35600.00
FB669E	2017-07-08 05:29:00+03	26000.00
FB6738	2017-07-08 07:41:00+03	305400.00
FB674F	2017-07-09 05:11:00+03	100200.00
FB67A2	2017-07-11 16:59:00+03	120400.00
FB67CA	2017-07-17 11:14:00+03	68100.00
FB67DB	2017-07-09 12:27:00+03	66600.00
FB67DE	2017-07-17 16:04:00+03	192100.00
FB6800	2017-07-02 23:02:00+03	58700.00
FB685F	2017-07-13 07:21:00+03	25600.00
FB6864	2017-07-02 12:58:00+03	265600.00
FB698A	2017-08-04 06:08:00+03	12000.00
FB698B	2017-06-26 05:20:00+03	85800.00
FB6ACE	2017-07-09 09:29:00+03	152900.00
FB6AD1	2017-07-02 14:03:00+03	60400.00
FB6AF2	2017-06-29 02:17:00+03	47800.00
FB6B6C	2017-07-29 09:11:00+03	114900.00
FB6C0E	2017-07-23 20:02:00+03	153300.00
FB6C2E	2017-07-19 01:36:00+03	28000.00
FB6C33	2017-07-19 16:29:00+03	39800.00
FB6C47	2017-07-26 01:48:00+03	46800.00
FB6C79	2017-07-13 00:01:00+03	47400.00
FB6CFE	2017-07-24 07:04:00+03	46200.00
FB6D3E	2017-07-23 05:39:00+03	25100.00
FB6E01	2017-07-21 05:12:00+03	94200.00
FB6E44	2017-07-23 13:37:00+03	59100.00
FB6E4E	2017-07-26 03:43:00+03	136200.00
FB6EAD	2017-08-04 18:15:00+03	23400.00
FB6F04	2017-07-10 07:51:00+03	47400.00
FB6F33	2017-08-02 14:29:00+03	363800.00
FB6FA7	2017-08-03 07:23:00+03	109400.00
FB6FB3	2017-08-15 00:27:00+03	19600.00
FB6FC4	2017-08-01 16:44:00+03	131600.00
FB6FEC	2017-07-16 06:49:00+03	56100.00
FB6FED	2017-07-05 16:24:00+03	79700.00
FB707D	2017-08-12 23:40:00+03	113100.00
FB7087	2017-07-02 10:05:00+03	135600.00
FB70A8	2017-08-09 07:04:00+03	15800.00
FB70FD	2017-06-25 16:25:00+03	64800.00
FB7124	2017-08-13 15:04:00+03	63600.00
FB7138	2017-07-24 07:56:00+03	99200.00
FB7191	2017-07-07 05:36:00+03	18600.00
FB71B9	2017-07-11 04:37:00+03	123000.00
FB728B	2017-07-18 10:58:00+03	40800.00
FB7290	2017-07-23 00:25:00+03	116000.00
FB7297	2017-07-17 21:11:00+03	54500.00
FB729A	2017-07-30 14:43:00+03	61800.00
FB72E9	2017-07-26 06:54:00+03	39800.00
FB72F3	2017-07-31 03:01:00+03	66100.00
FB731A	2017-08-14 22:13:00+03	56900.00
FB7336	2017-08-11 00:42:00+03	23600.00
FB733D	2017-08-04 18:40:00+03	136600.00
FB7356	2017-07-19 00:22:00+03	43500.00
FB7377	2017-07-06 03:20:00+03	69500.00
FB7388	2017-07-24 03:34:00+03	24400.00
FB73FB	2017-07-17 01:24:00+03	13400.00
FB7492	2017-08-02 16:29:00+03	43600.00
FB7568	2017-08-06 11:49:00+03	58400.00
FB7570	2017-07-23 12:49:00+03	46400.00
FB759C	2017-07-09 23:01:00+03	22000.00
FB75C7	2017-07-21 06:14:00+03	6000.00
FB7613	2017-08-07 03:58:00+03	21800.00
FB7648	2017-07-19 23:18:00+03	58200.00
FB7660	2017-07-14 12:18:00+03	131600.00
FB766D	2017-07-27 04:51:00+03	133100.00
FB76C2	2017-07-26 14:02:00+03	130000.00
FB7775	2017-07-30 16:45:00+03	282300.00
FB777B	2017-08-05 05:51:00+03	30200.00
FB77C7	2017-07-31 06:56:00+03	291000.00
FB77CF	2017-07-22 15:45:00+03	91600.00
FB780E	2017-08-01 09:52:00+03	55800.00
FB7894	2017-08-12 18:55:00+03	199300.00
FB78A3	2017-08-12 06:06:00+03	87200.00
FB78AB	2017-07-25 17:46:00+03	125400.00
FB7902	2017-08-05 22:43:00+03	56000.00
FB7986	2017-07-31 12:04:00+03	99200.00
FB7A12	2017-07-08 15:38:00+03	42800.00
FB7A1E	2017-07-18 03:14:00+03	258400.00
FB7A2B	2017-08-10 16:49:00+03	14000.00
FB7A36	2017-07-16 08:26:00+03	21800.00
FB7AAD	2017-07-12 22:30:00+03	32800.00
FB7AE5	2017-07-07 11:40:00+03	67600.00
FB7B16	2017-08-01 23:44:00+03	87000.00
FB7B3B	2017-07-29 05:51:00+03	73800.00
FB7BAB	2017-08-05 23:47:00+03	13600.00
FB7C12	2017-08-04 14:19:00+03	23200.00
FB7C62	2017-07-28 08:29:00+03	53200.00
FB7C6C	2017-06-29 11:35:00+03	111600.00
FB7CC9	2017-07-24 06:09:00+03	56100.00
FB7CE7	2017-07-13 13:43:00+03	148300.00
FB7D44	2017-07-19 12:02:00+03	123000.00
FB7D89	2017-07-15 12:08:00+03	21800.00
FB7D8A	2017-08-08 03:31:00+03	26000.00
FB7D99	2017-07-25 21:31:00+03	14300.00
FB7E53	2017-08-01 11:32:00+03	66600.00
FB7E8E	2017-08-13 15:22:00+03	16400.00
FB7EB4	2017-08-02 22:12:00+03	80700.00
FB7F90	2017-07-10 15:58:00+03	30800.00
FB7FAD	2017-07-09 22:03:00+03	25400.00
FB7FB2	2017-08-04 04:49:00+03	61500.00
FB7FB8	2017-07-03 21:00:00+03	24800.00
FB8118	2017-08-02 14:11:00+03	92000.00
FB8120	2017-08-13 03:12:00+03	272900.00
FB81B2	2017-07-30 04:56:00+03	40400.00
FB81B8	2017-07-15 02:59:00+03	26000.00
FB81F5	2017-07-16 01:50:00+03	8400.00
FB824D	2017-08-11 06:57:00+03	103700.00
FB8250	2017-07-06 03:35:00+03	86100.00
FB826B	2017-07-16 14:48:00+03	157200.00
FB828E	2017-08-04 17:46:00+03	155600.00
FB82B8	2017-07-09 16:12:00+03	47100.00
FB82D0	2017-07-05 10:41:00+03	57500.00
FB82E6	2017-07-19 02:24:00+03	99300.00
FB8306	2017-08-03 15:54:00+03	33100.00
FB83C7	2017-08-13 23:06:00+03	83000.00
FB83C8	2017-07-28 11:15:00+03	24400.00
FB83F7	2017-07-16 02:36:00+03	47000.00
FB841E	2017-07-19 11:43:00+03	27300.00
FB841F	2017-08-01 15:59:00+03	27200.00
FB84EB	2017-07-27 12:56:00+03	114400.00
FB84F1	2017-08-14 15:33:00+03	266800.00
FB8564	2017-07-06 23:21:00+03	192400.00
FB856E	2017-07-26 11:30:00+03	54800.00
FB85B7	2017-07-21 20:54:00+03	62200.00
FB863D	2017-07-14 23:17:00+03	6700.00
FB8656	2017-08-12 04:52:00+03	59100.00
FB8682	2017-08-11 08:35:00+03	21400.00
FB878E	2017-08-03 02:45:00+03	154500.00
FB879E	2017-07-19 10:25:00+03	44800.00
FB880F	2017-08-14 16:41:00+03	54000.00
FB8821	2017-07-10 13:22:00+03	21800.00
FB8868	2017-08-14 12:23:00+03	128900.00
FB8886	2017-08-15 00:28:00+03	11800.00
FB88E4	2017-08-14 15:32:00+03	112200.00
FB8910	2017-07-24 10:06:00+03	123000.00
FB8912	2017-07-18 13:49:00+03	64400.00
FB891A	2017-07-25 07:51:00+03	22000.00
FB8975	2017-07-26 13:21:00+03	21200.00
FB89F0	2017-07-04 01:55:00+03	115900.00
FB8A5B	2017-07-10 00:01:00+03	38400.00
FB8AB2	2017-07-19 00:32:00+03	191400.00
FB8B21	2017-07-27 21:16:00+03	151200.00
FB8B9B	2017-08-13 15:23:00+03	148200.00
FB8C1C	2017-08-06 14:51:00+03	209700.00
FB8C50	2017-07-17 20:29:00+03	260300.00
FB8C9A	2017-08-10 01:45:00+03	29600.00
FB8CB9	2017-08-12 07:04:00+03	10800.00
FB8CBC	2017-06-29 09:37:00+03	101200.00
FB8D0A	2017-08-11 18:51:00+03	28800.00
FB8D18	2017-07-18 19:50:00+03	6700.00
FB8D55	2017-07-02 05:00:00+03	198400.00
FB8D72	2017-08-12 08:32:00+03	143900.00
FB8E8A	2017-06-29 03:29:00+03	54400.00
FB8E8D	2017-07-12 06:08:00+03	98400.00
FB8F1E	2017-07-29 05:41:00+03	26800.00
FB8FD8	2017-08-11 23:04:00+03	57800.00
FB90F3	2017-07-26 13:14:00+03	57500.00
FB9103	2017-08-14 08:24:00+03	199600.00
FB9128	2017-07-04 06:20:00+03	133100.00
FB914F	2017-07-12 15:08:00+03	131900.00
FB9168	2017-07-28 03:37:00+03	44700.00
FB917A	2017-08-05 02:15:00+03	113600.00
FB9184	2017-07-21 18:52:00+03	60400.00
FB91AA	2017-07-22 15:17:00+03	125200.00
FB91D7	2017-07-07 12:59:00+03	77900.00
FB91F6	2017-07-09 13:06:00+03	37100.00
FB9238	2017-07-17 19:23:00+03	34600.00
FB923B	2017-07-23 08:00:00+03	108200.00
FB9240	2017-08-02 20:22:00+03	26800.00
FB925F	2017-08-10 01:16:00+03	124200.00
FB928C	2017-07-23 01:30:00+03	88500.00
FB92D5	2017-07-15 19:14:00+03	40800.00
FB933D	2017-07-30 23:22:00+03	80400.00
FB9367	2017-07-01 11:06:00+03	115300.00
FB936D	2017-08-05 02:57:00+03	133200.00
FB93B5	2017-07-07 05:10:00+03	170200.00
FB93EA	2017-07-03 01:50:00+03	246000.00
FB940C	2017-07-09 08:49:00+03	64900.00
FB9422	2017-07-08 04:50:00+03	42700.00
FB9473	2017-08-14 23:04:00+03	70100.00
FB94A4	2017-07-26 07:06:00+03	136800.00
FB94DF	2017-07-30 23:49:00+03	26000.00
FB94E1	2017-07-25 17:30:00+03	47100.00
FB9518	2017-07-26 00:51:00+03	175200.00
FB952E	2017-07-30 08:49:00+03	88100.00
FB955E	2017-07-05 23:03:00+03	47100.00
FB95D5	2017-07-19 06:53:00+03	406200.00
FB9623	2017-07-16 07:45:00+03	69000.00
FB9629	2017-07-21 20:38:00+03	55800.00
FB962A	2017-07-21 21:12:00+03	31200.00
FB987D	2017-07-18 06:41:00+03	99200.00
FB98AF	2017-07-04 05:48:00+03	89400.00
FB98DB	2017-07-26 21:35:00+03	114700.00
FB98E6	2017-07-17 14:41:00+03	25000.00
FB995A	2017-07-13 17:52:00+03	56000.00
FB9969	2017-07-01 02:07:00+03	101500.00
FB9980	2017-07-26 16:46:00+03	81900.00
FB9A4B	2017-06-29 03:04:00+03	103200.00
FB9A55	2017-08-13 19:25:00+03	37900.00
FB9A71	2017-07-22 01:35:00+03	136800.00
FB9A8B	2017-08-11 09:57:00+03	23200.00
FB9A9F	2017-07-13 07:23:00+03	69400.00
FB9AB3	2017-07-21 15:20:00+03	35200.00
FB9AC4	2017-07-07 08:25:00+03	89700.00
FB9B95	2017-07-29 14:59:00+03	28000.00
FB9BB1	2017-07-01 07:32:00+03	25900.00
FB9D2E	2017-07-06 12:12:00+03	65100.00
FB9E4B	2017-08-14 08:19:00+03	266400.00
FB9EBD	2017-08-02 14:08:00+03	114800.00
FB9F10	2017-08-12 03:01:00+03	31300.00
FB9F18	2017-08-10 17:36:00+03	15100.00
FB9F27	2017-08-15 12:14:00+03	9200.00
FB9F7E	2017-07-04 19:37:00+03	47400.00
FB9FA7	2017-08-01 06:29:00+03	35400.00
FB9FF1	2017-07-29 14:20:00+03	68800.00
FBA005	2017-07-10 04:15:00+03	37000.00
FBA02F	2017-08-07 18:59:00+03	369000.00
FBA066	2017-07-11 00:04:00+03	16400.00
FBA068	2017-08-02 01:16:00+03	6000.00
FBA0B0	2017-08-04 03:59:00+03	137600.00
FBA0DB	2017-08-02 17:25:00+03	31400.00
FBA0E2	2017-07-30 05:28:00+03	36200.00
FBA0E4	2017-08-05 17:05:00+03	88000.00
FBA113	2017-07-16 07:07:00+03	135100.00
FBA15F	2017-07-03 21:43:00+03	91600.00
FBA173	2017-07-12 04:01:00+03	191400.00
FBA18F	2017-07-11 22:39:00+03	78300.00
FBA1E3	2017-08-07 15:31:00+03	413500.00
FBA1EF	2017-07-09 14:33:00+03	55600.00
FBA20A	2017-07-24 13:08:00+03	56000.00
FBA211	2017-08-03 21:18:00+03	246000.00
FBA237	2017-06-27 21:48:00+03	92000.00
FBA2DC	2017-07-13 12:10:00+03	28300.00
FBA3B5	2017-07-14 03:30:00+03	123000.00
FBA3D4	2017-07-11 14:41:00+03	37300.00
FBA4B4	2017-07-29 19:01:00+03	6700.00
FBA505	2017-07-05 23:51:00+03	31600.00
FBA555	2017-07-23 03:46:00+03	6000.00
FBA620	2017-07-30 20:12:00+03	28000.00
FBA677	2017-07-15 15:15:00+03	70800.00
FBA6B9	2017-07-01 10:15:00+03	99200.00
FBA6D8	2017-07-03 11:04:00+03	25000.00
FBA701	2017-07-19 03:33:00+03	68200.00
FBA75B	2017-06-29 18:31:00+03	13700.00
FBA77B	2017-08-10 19:36:00+03	108500.00
FBA7ED	2017-07-06 05:43:00+03	43000.00
FBA7FB	2017-08-07 11:09:00+03	40400.00
FBA805	2017-08-02 01:50:00+03	38800.00
FBA851	2017-08-07 22:04:00+03	19600.00
FBA866	2017-07-25 11:55:00+03	111600.00
FBA889	2017-07-29 20:25:00+03	26000.00
FBA8CF	2017-07-09 04:40:00+03	14000.00
FBA8D2	2017-08-06 00:40:00+03	88100.00
FBA8EB	2017-07-26 10:28:00+03	16400.00
FBA958	2017-08-15 10:28:00+03	147700.00
FBA9E2	2017-07-08 16:12:00+03	26000.00
FBAA0C	2017-07-29 05:59:00+03	32200.00
FBAAD8	2017-07-13 10:00:00+03	39300.00
FBAAF1	2017-07-30 18:45:00+03	38200.00
FBAB1B	2017-08-15 00:47:00+03	18600.00
FBAB1E	2017-08-06 20:49:00+03	492000.00
FBAB3C	2017-07-26 14:15:00+03	21800.00
FBAB63	2017-07-08 20:44:00+03	66600.00
FBABAB	2017-07-28 23:32:00+03	89700.00
FBABB6	2017-07-05 01:48:00+03	174000.00
FBAC5E	2017-07-22 16:07:00+03	118100.00
FBAC7A	2017-06-28 10:12:00+03	100000.00
FBAD47	2017-08-07 17:04:00+03	117000.00
FBADBD	2017-07-26 12:49:00+03	66600.00
FBADE2	2017-07-17 05:46:00+03	66900.00
FBAE0F	2017-07-28 22:16:00+03	135400.00
FBAE7A	2017-08-09 05:13:00+03	40600.00
FBAE9A	2017-07-02 21:19:00+03	132800.00
FBAEDD	2017-07-28 23:53:00+03	20200.00
FBAF58	2017-08-03 22:20:00+03	23200.00
FBAF66	2017-07-07 19:58:00+03	62600.00
FBB03C	2017-07-26 09:48:00+03	73300.00
FBB09B	2017-07-22 21:57:00+03	48800.00
FBB0D7	2017-07-18 23:40:00+03	246000.00
FBB0DC	2017-06-30 09:15:00+03	21400.00
FBB102	2017-07-18 18:47:00+03	65200.00
FBB120	2017-07-08 20:06:00+03	18000.00
FBB17C	2017-08-09 16:08:00+03	128800.00
FBB185	2017-08-14 00:57:00+03	231900.00
FBB259	2017-07-27 12:55:00+03	46400.00
FBB26A	2017-07-07 17:59:00+03	135400.00
FBB276	2017-07-15 18:16:00+03	131600.00
FBB28A	2017-07-03 18:56:00+03	30800.00
FBB2F9	2017-08-10 19:43:00+03	70400.00
FBB33D	2017-07-23 07:28:00+03	115900.00
FBB36A	2017-07-30 13:49:00+03	15000.00
FBB3E2	2017-07-07 08:59:00+03	272300.00
FBB4DC	2017-07-11 09:09:00+03	163300.00
FBB50F	2017-07-27 00:34:00+03	26200.00
FBB53E	2017-08-07 17:34:00+03	81700.00
FBB5A6	2017-08-12 19:39:00+03	12400.00
FBB5BA	2017-07-20 06:35:00+03	65100.00
FBB5BE	2017-08-04 16:40:00+03	14400.00
FBB62D	2017-08-15 05:20:00+03	100300.00
FBB637	2017-08-10 04:10:00+03	31300.00
FBB641	2017-07-22 10:41:00+03	23200.00
FBB6B0	2017-07-19 09:27:00+03	115100.00
FBB6C5	2017-07-26 22:36:00+03	521200.00
FBB71E	2017-08-13 00:09:00+03	12400.00
FBB7B1	2017-08-12 09:04:00+03	81000.00
FBB7E9	2017-07-31 23:20:00+03	89100.00
FBB7FD	2017-07-03 15:59:00+03	6900.00
FBB834	2017-07-09 22:43:00+03	47900.00
FBB877	2017-07-20 21:35:00+03	131600.00
FBB89F	2017-08-09 22:48:00+03	38600.00
FBB8C9	2017-07-28 04:19:00+03	28000.00
FBB8FB	2017-07-10 20:37:00+03	55600.00
FBB9C9	2017-08-12 03:12:00+03	80900.00
FBB9DF	2017-07-06 19:52:00+03	38400.00
FBBA1B	2017-07-26 03:42:00+03	19800.00
FBBA1E	2017-08-10 22:07:00+03	29600.00
FBBA31	2017-07-23 20:35:00+03	131600.00
FBBA41	2017-07-22 08:02:00+03	92700.00
FBBA51	2017-07-03 16:13:00+03	16400.00
FBBA92	2017-08-09 13:02:00+03	75300.00
FBBAA1	2017-07-07 17:01:00+03	28000.00
FBBAA5	2017-08-01 13:15:00+03	50100.00
FBBB04	2017-07-31 15:10:00+03	119800.00
FBBB08	2017-08-15 10:59:00+03	15800.00
FBBB6A	2017-07-25 01:25:00+03	246000.00
FBBBA8	2017-07-31 17:18:00+03	46400.00
FBBBD0	2017-08-10 13:52:00+03	57800.00
FBBBF4	2017-08-02 20:51:00+03	21200.00
FBBBFB	2017-07-04 06:22:00+03	88600.00
FBBC2A	2017-07-20 02:18:00+03	46000.00
FBBC3A	2017-08-06 10:42:00+03	7400.00
FBBC62	2017-07-22 08:37:00+03	24400.00
FBBC7F	2017-07-07 23:01:00+03	265700.00
FBBC9A	2017-07-17 19:55:00+03	47200.00
FBBC9C	2017-07-16 18:44:00+03	75600.00
FBBCB8	2017-07-22 06:54:00+03	102100.00
FBBDB9	2017-08-07 05:18:00+03	23400.00
FBBDD4	2017-08-06 15:07:00+03	18800.00
FBBE33	2017-07-09 18:16:00+03	153300.00
FBBEB9	2017-07-03 21:19:00+03	47000.00
FBBED5	2017-08-09 19:22:00+03	23200.00
FBBED6	2017-07-08 02:07:00+03	251200.00
FBBF35	2017-07-30 13:48:00+03	8200.00
FBBF42	2017-08-10 12:24:00+03	76600.00
FBC012	2017-08-14 14:55:00+03	12600.00
FBC02A	2017-08-01 14:47:00+03	56000.00
FBC062	2017-07-16 06:37:00+03	55800.00
FBC06D	2017-08-01 08:48:00+03	117200.00
FBC09E	2017-06-30 13:43:00+03	168000.00
FBC0F0	2017-08-01 01:31:00+03	28700.00
FBC0F1	2017-08-04 02:25:00+03	58800.00
FBC0F5	2017-07-06 17:13:00+03	96200.00
FBC137	2017-07-20 10:39:00+03	90000.00
FBC16C	2017-08-06 20:59:00+03	6000.00
FBC183	2017-07-31 00:09:00+03	32900.00
FBC18F	2017-07-25 02:38:00+03	122800.00
FBC1A6	2017-06-30 09:28:00+03	271100.00
FBC204	2017-07-26 17:32:00+03	35600.00
FBC20F	2017-07-06 13:48:00+03	23200.00
FBC21B	2017-07-19 22:00:00+03	28000.00
FBC252	2017-07-31 14:56:00+03	28800.00
FBC26D	2017-07-11 18:29:00+03	49100.00
FBC273	2017-07-03 07:11:00+03	22600.00
FBC2BA	2017-08-01 19:56:00+03	54800.00
FBC340	2017-07-30 21:51:00+03	55800.00
FBC38E	2017-07-17 11:11:00+03	135400.00
FBC3C5	2017-07-02 01:27:00+03	34000.00
FBC45B	2017-08-04 15:11:00+03	28800.00
FBC4F2	2017-07-31 18:15:00+03	189200.00
FBC510	2017-07-05 04:01:00+03	76400.00
FBC520	2017-08-04 15:13:00+03	12200.00
FBC58C	2017-07-12 07:53:00+03	133100.00
FBC58F	2017-08-15 11:49:00+03	66600.00
FBC638	2017-08-08 14:08:00+03	68400.00
FBC6C3	2017-07-29 09:00:00+03	98400.00
FBC6E0	2017-07-10 02:54:00+03	22000.00
FBC759	2017-07-31 05:03:00+03	229400.00
FBC7A4	2017-07-31 19:54:00+03	61200.00
FBC807	2017-07-15 10:10:00+03	106400.00
FBC82F	2017-07-28 20:26:00+03	90400.00
FBC86D	2017-08-15 08:58:00+03	19600.00
FBC877	2017-07-24 11:07:00+03	134800.00
FBC88E	2017-08-15 12:40:00+03	270800.00
FBC893	2017-08-12 04:34:00+03	24400.00
FBC8CD	2017-07-25 01:31:00+03	25600.00
FBC8F6	2017-06-28 19:05:00+03	51300.00
FBC914	2017-07-31 09:08:00+03	29200.00
FBC97B	2017-07-30 04:00:00+03	65400.00
FBC9C7	2017-08-05 06:24:00+03	84800.00
FBC9DE	2017-08-05 12:28:00+03	15000.00
FBC9F4	2017-08-12 11:05:00+03	31100.00
FBCA2A	2017-08-03 03:55:00+03	46000.00
FBCA5D	2017-07-13 22:15:00+03	301800.00
FBCB34	2017-08-02 02:22:00+03	56200.00
FBCC16	2017-07-03 03:33:00+03	68000.00
FBCC1A	2017-07-26 21:23:00+03	191000.00
FBCC41	2017-07-12 23:36:00+03	6900.00
FBCC61	2017-07-10 11:59:00+03	81200.00
FBCC7F	2017-07-20 13:21:00+03	211500.00
FBCCC2	2017-07-08 05:04:00+03	83600.00
FBCCF6	2017-07-09 03:01:00+03	3400.00
FBCD4E	2017-08-13 15:17:00+03	24400.00
FBCDE2	2017-07-28 09:21:00+03	26800.00
FBCDF8	2017-08-12 07:06:00+03	70900.00
FBCE3A	2017-08-12 05:30:00+03	266400.00
FBCE89	2017-07-23 13:20:00+03	92000.00
FBCEB2	2017-07-25 01:05:00+03	398500.00
FBCEB6	2017-07-03 03:59:00+03	95300.00
FBCEC5	2017-08-05 05:45:00+03	58000.00
FBCF14	2017-08-05 01:01:00+03	32900.00
FBCF83	2017-08-14 01:24:00+03	52000.00
FBD069	2017-07-29 01:42:00+03	54400.00
FBD0BF	2017-08-05 03:59:00+03	19600.00
FBD0FB	2017-08-09 20:40:00+03	47400.00
FBD11C	2017-07-15 00:26:00+03	28000.00
FBD168	2017-06-24 01:58:00+03	130400.00
FBD24B	2017-07-13 09:30:00+03	67400.00
FBD26F	2017-07-18 21:24:00+03	56000.00
FBD29F	2017-07-09 06:26:00+03	49200.00
FBD2AF	2017-07-19 17:00:00+03	57600.00
FBD328	2017-07-18 02:15:00+03	43000.00
FBD346	2017-07-06 02:42:00+03	18000.00
FBD384	2017-07-04 16:04:00+03	182200.00
FBD389	2017-07-02 18:12:00+03	75600.00
FBD40D	2017-07-05 14:41:00+03	40000.00
FBD41C	2017-07-30 04:35:00+03	48800.00
FBD42B	2017-07-16 09:14:00+03	144500.00
FBD452	2017-07-15 21:50:00+03	48800.00
FBD4EE	2017-08-11 10:53:00+03	280200.00
FBD50D	2017-07-13 07:53:00+03	28000.00
FBD536	2017-07-13 12:19:00+03	142400.00
FBD549	2017-08-03 21:12:00+03	55500.00
FBD551	2017-07-16 09:53:00+03	56000.00
FBD586	2017-07-14 09:03:00+03	104400.00
FBD5B6	2017-07-18 13:05:00+03	46000.00
FBD60A	2017-07-23 14:45:00+03	40400.00
FBD67C	2017-07-18 06:24:00+03	72400.00
FBD697	2017-07-21 23:28:00+03	48300.00
FBD6A4	2017-07-22 08:08:00+03	6700.00
FBD779	2017-08-05 11:36:00+03	32400.00
FBD79F	2017-07-17 04:00:00+03	62600.00
FBD7B9	2017-07-09 19:04:00+03	56000.00
FBD7BC	2017-07-20 10:42:00+03	46000.00
FBD7D2	2017-07-06 20:10:00+03	91100.00
FBD831	2017-08-11 09:44:00+03	55800.00
FBD838	2017-08-14 05:53:00+03	139400.00
FBD850	2017-07-19 19:18:00+03	58800.00
FBD86D	2017-08-05 01:15:00+03	23600.00
FBD871	2017-08-09 06:33:00+03	47100.00
FBD882	2017-07-13 11:26:00+03	52400.00
FBD8A2	2017-08-08 05:05:00+03	12600.00
FBD8EF	2017-07-04 20:56:00+03	293500.00
FBD90D	2017-07-22 18:52:00+03	23200.00
FBD94F	2017-08-12 00:39:00+03	75600.00
FBD952	2017-07-07 05:59:00+03	34000.00
FBD960	2017-07-22 04:22:00+03	40800.00
FBD9FB	2017-08-02 07:34:00+03	43000.00
FBDA2E	2017-08-09 11:07:00+03	24000.00
FBDB22	2017-07-20 05:43:00+03	177600.00
FBDB9D	2017-06-29 01:18:00+03	46500.00
FBDBAE	2017-08-13 15:26:00+03	75300.00
FBDBB3	2017-07-30 12:51:00+03	309700.00
FBDBE8	2017-07-20 14:11:00+03	13700.00
FBDBEE	2017-08-05 17:09:00+03	11700.00
FBDC1B	2017-07-31 06:40:00+03	23600.00
FBDC33	2017-07-17 21:38:00+03	56600.00
FBDC3B	2017-07-14 22:43:00+03	38800.00
FBDCDB	2017-06-30 03:33:00+03	96800.00
FBDEAC	2017-07-08 05:24:00+03	61200.00
FBDEE5	2017-07-22 04:20:00+03	69000.00
FBDF9E	2017-08-13 06:48:00+03	68800.00
FBE06D	2017-07-05 10:32:00+03	31400.00
FBE0EB	2017-07-28 19:33:00+03	38600.00
FBE0F6	2017-07-16 21:10:00+03	81700.00
FBE130	2017-07-09 03:56:00+03	46400.00
FBE174	2017-07-10 11:04:00+03	6000.00
FBE18A	2017-07-04 19:20:00+03	14400.00
FBE1A0	2017-07-30 10:46:00+03	199700.00
FBE258	2017-07-19 01:45:00+03	58600.00
FBE267	2017-07-19 16:16:00+03	169900.00
FBE3A1	2017-08-01 03:08:00+03	26000.00
FBE3A5	2017-07-20 04:35:00+03	135600.00
FBE3AD	2017-07-05 04:04:00+03	131100.00
FBE3BE	2017-08-03 14:34:00+03	117100.00
FBE3D2	2017-07-09 22:29:00+03	92000.00
FBE40B	2017-08-03 04:57:00+03	56600.00
FBE414	2017-07-12 11:03:00+03	46500.00
FBE486	2017-06-30 09:52:00+03	66600.00
FBE4B1	2017-07-06 12:30:00+03	394400.00
FBE4D1	2017-08-10 13:41:00+03	369000.00
FBE502	2017-07-09 16:07:00+03	13400.00
FBE54B	2017-08-03 10:41:00+03	36800.00
FBE581	2017-07-10 15:25:00+03	20200.00
FBE599	2017-08-08 01:02:00+03	231900.00
FBE59C	2017-07-02 20:41:00+03	231300.00
FBE5D2	2017-08-14 13:21:00+03	168600.00
FBE5F0	2017-08-09 07:13:00+03	46300.00
FBE65C	2017-08-01 21:34:00+03	22000.00
FBE69F	2017-07-10 00:03:00+03	73300.00
FBE6C8	2017-07-24 18:25:00+03	40800.00
FBE6E7	2017-08-10 03:05:00+03	22000.00
FBE6FE	2017-07-21 06:57:00+03	69500.00
FBE709	2017-07-23 23:03:00+03	61900.00
FBE70C	2017-08-05 20:37:00+03	44400.00
FBE73E	2017-07-28 07:22:00+03	23200.00
FBE75E	2017-08-07 21:18:00+03	14800.00
FBE75F	2017-08-04 11:34:00+03	74400.00
FBE7D1	2017-08-05 04:07:00+03	72300.00
FBE816	2017-07-15 03:12:00+03	67600.00
FBE823	2017-07-06 05:52:00+03	99200.00
FBE835	2017-07-13 10:27:00+03	83400.00
FBE8CB	2017-08-14 06:21:00+03	154500.00
FBE8E8	2017-06-30 19:00:00+03	53600.00
FBE90E	2017-08-06 04:07:00+03	27200.00
FBE92D	2017-08-03 08:38:00+03	26800.00
FBE978	2017-08-03 19:09:00+03	40100.00
FBE97D	2017-07-10 21:22:00+03	128400.00
FBE99F	2017-08-11 21:01:00+03	48800.00
FBE9BC	2017-06-29 23:12:00+03	60400.00
FBE9C3	2017-07-25 12:27:00+03	62600.00
FBE9E0	2017-08-12 22:44:00+03	304800.00
FBEA58	2017-07-29 09:05:00+03	242700.00
FBEAC8	2017-07-06 06:11:00+03	46300.00
FBEAD1	2017-07-21 09:17:00+03	37900.00
FBEADB	2017-07-12 03:10:00+03	15800.00
FBEAE0	2017-07-26 00:38:00+03	126700.00
FBEB11	2017-08-04 05:28:00+03	46700.00
FBEB32	2017-07-20 22:53:00+03	75300.00
FBEB5D	2017-07-10 16:49:00+03	112000.00
FBEB6B	2017-07-12 05:45:00+03	57500.00
FBEB8F	2017-07-05 11:07:00+03	92000.00
FBEBB0	2017-07-24 21:01:00+03	21800.00
FBEBB2	2017-06-30 14:35:00+03	82000.00
FBEC2E	2017-07-13 02:36:00+03	30000.00
FBEC72	2017-07-20 00:36:00+03	75300.00
FBECD3	2017-08-07 04:36:00+03	57800.00
FBED40	2017-07-16 07:06:00+03	279800.00
FBEDB6	2017-08-08 01:06:00+03	56000.00
FBEDE6	2017-08-07 01:37:00+03	165000.00
FBEE1B	2017-08-14 19:17:00+03	39600.00
FBEE2C	2017-07-14 03:26:00+03	24400.00
FBEE38	2017-08-06 18:15:00+03	274200.00
FBEE4C	2017-08-15 11:16:00+03	56000.00
FBEE80	2017-07-30 02:00:00+03	61900.00
FBEE91	2017-07-16 09:36:00+03	22000.00
FBEEBA	2017-07-31 10:47:00+03	114800.00
FBEEC1	2017-07-29 17:14:00+03	56000.00
FBEF2E	2017-07-26 01:11:00+03	40800.00
FBEF33	2017-08-14 23:46:00+03	96800.00
FBEFD2	2017-08-08 06:04:00+03	73500.00
FBF032	2017-08-10 17:37:00+03	65400.00
FBF098	2017-07-04 04:51:00+03	91300.00
FBF099	2017-07-12 14:49:00+03	14000.00
FBF0F5	2017-08-14 04:24:00+03	42000.00
FBF0FC	2017-07-21 23:21:00+03	28800.00
FBF128	2017-07-01 08:23:00+03	58900.00
FBF12E	2017-07-20 05:51:00+03	79600.00
FBF1DC	2017-07-17 02:57:00+03	23400.00
FBF216	2017-07-05 01:58:00+03	77600.00
FBF2F5	2017-08-07 18:35:00+03	49700.00
FBF2F8	2017-08-04 14:38:00+03	15000.00
FBF2FD	2017-07-31 19:04:00+03	204200.00
FBF305	2017-07-15 06:07:00+03	28700.00
FBF35C	2017-08-09 17:58:00+03	120100.00
FBF378	2017-08-08 17:42:00+03	45400.00
FBF3CE	2017-08-02 17:22:00+03	240600.00
FBF3D9	2017-07-29 20:43:00+03	28800.00
FBF460	2017-08-06 06:59:00+03	31200.00
FBF4A1	2017-08-07 18:29:00+03	18900.00
FBF4DB	2017-08-02 13:49:00+03	15100.00
FBF4E0	2017-07-06 21:22:00+03	47000.00
FBF536	2017-07-27 20:47:00+03	36800.00
FBF5C5	2017-07-01 03:57:00+03	6000.00
FBF5D5	2017-07-12 07:54:00+03	67400.00
FBF68C	2017-07-24 00:46:00+03	74300.00
FBF69C	2017-07-20 18:08:00+03	162400.00
FBF719	2017-08-08 08:04:00+03	99200.00
FBF738	2017-07-25 22:39:00+03	16400.00
FBF765	2017-07-15 06:35:00+03	46300.00
FBF786	2017-07-22 00:30:00+03	23600.00
FBF78A	2017-07-21 14:32:00+03	46800.00
FBF7F2	2017-08-09 23:25:00+03	10700.00
FBF811	2017-08-03 15:27:00+03	46300.00
FBF83F	2017-07-18 06:15:00+03	51600.00
FBF845	2017-07-07 20:36:00+03	166000.00
FBF93F	2017-07-04 08:35:00+03	77600.00
FBF976	2017-07-11 00:38:00+03	12000.00
FBF9CC	2017-07-13 14:25:00+03	71800.00
FBF9E6	2017-07-12 20:27:00+03	21800.00
FBF9FF	2017-07-12 00:17:00+03	6300.00
FBFA1E	2017-08-13 01:45:00+03	48900.00
FBFA4F	2017-07-07 05:35:00+03	29600.00
FBFA7B	2017-07-24 23:45:00+03	344100.00
FBFA84	2017-08-02 15:01:00+03	50800.00
FBFAB0	2017-07-21 02:47:00+03	128800.00
FBFAB7	2017-07-11 17:56:00+03	21800.00
FBFAB9	2017-07-21 20:02:00+03	15100.00
FBFB24	2017-07-30 11:45:00+03	135600.00
FBFB26	2017-08-06 02:54:00+03	31300.00
FBFB28	2017-07-12 14:47:00+03	15200.00
FBFB5D	2017-07-28 16:42:00+03	39300.00
FBFB5F	2017-06-26 12:18:00+03	84500.00
FBFB7D	2017-07-10 17:36:00+03	245900.00
FBFB8D	2017-07-19 17:15:00+03	60400.00
FBFB9B	2017-08-05 12:06:00+03	57500.00
FBFBE8	2017-07-28 22:11:00+03	16400.00
FBFC18	2017-07-14 21:47:00+03	26800.00
FBFC77	2017-07-28 10:54:00+03	123000.00
FBFD67	2017-08-08 17:40:00+03	26400.00
FBFDF0	2017-07-12 07:49:00+03	32800.00
FBFE00	2017-07-30 18:38:00+03	131800.00
FBFE33	2017-08-10 20:41:00+03	56000.00
FBFF7E	2017-08-13 23:42:00+03	85000.00
FBFF88	2017-07-01 02:25:00+03	56600.00
FBFFD3	2017-07-06 14:42:00+03	28000.00
FC002A	2017-08-02 14:16:00+03	72200.00
FC0046	2017-07-11 03:47:00+03	66400.00
FC0092	2017-06-29 18:21:00+03	52700.00
FC00AA	2017-07-12 07:31:00+03	68100.00
FC00DE	2017-07-23 01:23:00+03	48800.00
FC0102	2017-08-09 08:11:00+03	37900.00
FC0119	2017-07-08 22:07:00+03	20400.00
FC013F	2017-08-12 02:27:00+03	46300.00
FC0207	2017-07-15 16:22:00+03	23600.00
FC024C	2017-07-29 10:32:00+03	37100.00
FC0296	2017-08-15 05:00:00+03	24000.00
FC02B4	2017-07-14 08:33:00+03	291000.00
FC02CF	2017-08-14 18:41:00+03	69900.00
FC038C	2017-07-18 00:33:00+03	62000.00
FC03C2	2017-08-09 00:44:00+03	56000.00
FC03EF	2017-07-26 15:38:00+03	19600.00
FC04ED	2017-07-03 02:47:00+03	26000.00
FC0610	2017-08-10 03:53:00+03	26800.00
FC06AB	2017-06-30 12:18:00+03	56000.00
FC06FC	2017-07-19 21:55:00+03	28000.00
FC0703	2017-07-26 09:46:00+03	13600.00
FC071D	2017-07-31 18:31:00+03	26200.00
FC074A	2017-08-02 01:30:00+03	58900.00
FC0788	2017-07-19 00:50:00+03	26700.00
FC07CA	2017-06-29 07:38:00+03	64200.00
FC07EA	2017-08-01 19:29:00+03	31600.00
FC07F2	2017-07-08 01:06:00+03	129200.00
FC0889	2017-08-14 05:12:00+03	95400.00
FC08C1	2017-07-27 16:37:00+03	26000.00
FC08C7	2017-07-17 04:25:00+03	75600.00
FC08CD	2017-07-01 19:52:00+03	128800.00
FC0942	2017-07-19 11:57:00+03	183000.00
FC09A7	2017-07-17 20:02:00+03	13000.00
FC0A38	2017-08-02 18:47:00+03	47000.00
FC0A47	2017-07-16 22:00:00+03	283700.00
FC0ABB	2017-08-14 02:14:00+03	46000.00
FC0AD3	2017-07-29 11:19:00+03	146300.00
FC0B3F	2017-08-14 06:37:00+03	93600.00
FC0B40	2017-07-23 15:06:00+03	37900.00
FC0B65	2017-08-15 06:00:00+03	20000.00
FC0B7F	2017-08-11 12:19:00+03	57800.00
FC0BC8	2017-07-20 05:49:00+03	130400.00
FC0BF6	2017-08-15 17:28:00+03	23600.00
FC0C00	2017-08-13 15:49:00+03	31400.00
FC0C57	2017-07-16 13:06:00+03	61900.00
FC0C73	2017-07-11 04:38:00+03	10600.00
FC0CB4	2017-07-27 13:47:00+03	54400.00
FC0CE1	2017-07-26 10:21:00+03	44500.00
FC0D1A	2017-07-28 16:34:00+03	99700.00
FC0D22	2017-07-18 20:45:00+03	28700.00
FC0D45	2017-07-28 09:30:00+03	75700.00
FC0E08	2017-08-05 10:56:00+03	135000.00
FC0E93	2017-08-02 05:45:00+03	25100.00
FC0F23	2017-07-15 12:20:00+03	56000.00
FC0F30	2017-07-06 21:36:00+03	26000.00
FC0F59	2017-07-02 00:03:00+03	47400.00
FC0F62	2017-07-15 03:08:00+03	68400.00
FC0F67	2017-07-30 14:07:00+03	133100.00
FC1004	2017-07-10 03:59:00+03	92000.00
FC101D	2017-08-08 00:55:00+03	27800.00
FC1061	2017-08-11 13:36:00+03	130700.00
FC108E	2017-08-04 01:05:00+03	46000.00
FC10B8	2017-07-16 06:54:00+03	111600.00
FC1117	2017-08-10 16:33:00+03	28000.00
FC114A	2017-07-20 07:47:00+03	124200.00
FC114F	2017-08-08 03:47:00+03	8200.00
FC1196	2017-07-15 19:11:00+03	147700.00
FC120D	2017-08-05 23:03:00+03	45200.00
FC1240	2017-07-26 09:59:00+03	26200.00
FC125D	2017-07-18 02:05:00+03	56000.00
FC1265	2017-07-06 02:42:00+03	37100.00
FC128D	2017-08-06 00:56:00+03	66600.00
FC1314	2017-07-09 10:21:00+03	246000.00
FC1427	2017-07-14 09:44:00+03	57500.00
FC1467	2017-07-12 18:48:00+03	21400.00
FC147D	2017-08-14 07:45:00+03	98800.00
FC1488	2017-08-14 06:47:00+03	92100.00
FC14AF	2017-07-07 07:16:00+03	31400.00
FC14FA	2017-07-10 18:07:00+03	16800.00
FC1513	2017-08-02 08:27:00+03	88600.00
FC1536	2017-07-23 07:36:00+03	31100.00
FC155D	2017-07-09 14:50:00+03	84500.00
FC156D	2017-07-30 08:09:00+03	56000.00
FC15AD	2017-07-12 01:58:00+03	40000.00
FC160B	2017-08-06 17:00:00+03	35700.00
FC161F	2017-07-29 17:04:00+03	56000.00
FC1620	2017-07-11 13:15:00+03	132800.00
FC1634	2017-07-29 12:52:00+03	86800.00
FC1677	2017-08-03 12:32:00+03	100600.00
FC167D	2017-07-09 18:14:00+03	31400.00
FC16B3	2017-08-06 00:21:00+03	101200.00
FC16E5	2017-07-15 14:10:00+03	23200.00
FC1735	2017-07-03 12:42:00+03	12600.00
FC174F	2017-08-03 11:19:00+03	44600.00
FC177D	2017-07-29 11:27:00+03	56900.00
FC179B	2017-07-02 16:11:00+03	46400.00
FC17C2	2017-08-04 00:54:00+03	46000.00
FC17F3	2017-08-07 05:27:00+03	56900.00
FC17F4	2017-08-09 23:49:00+03	37100.00
FC180A	2017-07-30 17:37:00+03	52700.00
FC1847	2017-07-09 03:52:00+03	68100.00
FC1903	2017-08-04 20:11:00+03	106900.00
FC197D	2017-08-02 06:29:00+03	27200.00
FC1A2C	2017-07-27 04:30:00+03	80300.00
FC1A3A	2017-08-08 15:22:00+03	12600.00
FC1A71	2017-08-10 06:38:00+03	96800.00
FC1A76	2017-07-17 21:47:00+03	106900.00
FC1A81	2017-07-07 18:56:00+03	111600.00
FC1A88	2017-08-08 23:20:00+03	24400.00
FC1AA6	2017-08-02 15:35:00+03	64800.00
FC1AF0	2017-07-14 04:04:00+03	67600.00
FC1B46	2017-07-20 21:11:00+03	277800.00
FC1BB2	2017-07-15 21:21:00+03	28600.00
FC1BB3	2017-08-01 11:32:00+03	99000.00
FC1BEC	2017-07-01 14:06:00+03	6700.00
FC1C45	2017-07-14 11:04:00+03	108400.00
FC1DF6	2017-08-04 21:18:00+03	46900.00
FC1E41	2017-07-04 04:31:00+03	95200.00
FC1E78	2017-07-19 15:16:00+03	22000.00
FC1E94	2017-07-19 05:43:00+03	154700.00
FC1EB3	2017-08-11 19:47:00+03	14000.00
FC1EB4	2017-07-03 05:51:00+03	40600.00
FC1F29	2017-07-13 22:53:00+03	18600.00
FC202D	2017-08-12 10:47:00+03	42800.00
FC2057	2017-07-26 21:21:00+03	55800.00
FC20D5	2017-07-30 08:07:00+03	135400.00
FC20DA	2017-08-14 13:34:00+03	25400.00
FC2168	2017-08-01 21:45:00+03	34200.00
FC2197	2017-07-10 06:04:00+03	28000.00
FC21D9	2017-06-30 01:34:00+03	61800.00
FC21E3	2017-07-11 06:23:00+03	28800.00
FC21FE	2017-07-02 03:57:00+03	136000.00
FC2220	2017-08-11 20:13:00+03	28000.00
FC2239	2017-07-15 07:57:00+03	30600.00
FC2243	2017-08-01 15:40:00+03	135400.00
FC227B	2017-08-11 05:26:00+03	112000.00
FC2281	2017-07-07 14:00:00+03	118600.00
FC230F	2017-07-17 12:37:00+03	66000.00
FC2324	2017-07-19 01:48:00+03	46300.00
FC2331	2017-08-07 02:19:00+03	133200.00
FC23A7	2017-08-14 15:14:00+03	158100.00
FC2422	2017-07-04 05:17:00+03	74100.00
FC242C	2017-08-14 20:50:00+03	32700.00
FC244D	2017-07-06 15:42:00+03	25600.00
FC2472	2017-07-10 11:31:00+03	52300.00
FC2473	2017-07-25 13:43:00+03	37200.00
FC24CA	2017-07-29 11:47:00+03	529200.00
FC24D2	2017-07-09 20:30:00+03	51600.00
FC24DD	2017-08-06 05:39:00+03	73500.00
FC2559	2017-08-10 06:49:00+03	23600.00
FC2565	2017-07-20 13:27:00+03	59100.00
FC2580	2017-07-07 07:06:00+03	65200.00
FC258C	2017-07-23 17:41:00+03	65000.00
FC2601	2017-08-07 15:27:00+03	129700.00
FC2653	2017-08-13 11:02:00+03	306500.00
FC2664	2017-08-10 07:26:00+03	49100.00
FC2672	2017-08-15 07:00:00+03	94000.00
FC270B	2017-08-10 11:02:00+03	70800.00
FC2713	2017-08-10 23:12:00+03	56000.00
FC274E	2017-07-08 05:34:00+03	108300.00
FC2793	2017-07-06 01:17:00+03	36200.00
FC27E2	2017-07-26 09:48:00+03	40800.00
FC2801	2017-07-30 22:16:00+03	276000.00
FC2862	2017-07-13 23:50:00+03	26000.00
FC2889	2017-07-29 14:01:00+03	66600.00
FC28B2	2017-07-30 14:25:00+03	42600.00
FC28F2	2017-07-27 16:10:00+03	12400.00
FC2908	2017-07-24 14:00:00+03	54500.00
FC2933	2017-08-08 08:09:00+03	136200.00
FC29C6	2017-07-23 14:48:00+03	28000.00
FC29ED	2017-06-27 12:47:00+03	114300.00
FC2A63	2017-08-04 05:36:00+03	111600.00
FC2AA3	2017-08-04 03:19:00+03	93900.00
FC2AC4	2017-08-01 07:06:00+03	85700.00
FC2B00	2017-07-07 03:08:00+03	114600.00
FC2B85	2017-07-24 08:20:00+03	28000.00
FC2BCF	2017-08-12 23:26:00+03	113800.00
FC2C4F	2017-08-06 00:01:00+03	101100.00
FC2C56	2017-08-15 12:14:00+03	69000.00
FC2C74	2017-07-12 20:47:00+03	66600.00
FC2C86	2017-07-13 01:13:00+03	48800.00
FC2CA0	2017-07-18 11:03:00+03	118500.00
FC2D56	2017-07-30 04:09:00+03	26000.00
FC2D62	2017-08-09 06:48:00+03	47100.00
FC2D84	2017-07-13 03:08:00+03	156400.00
FC2DAC	2017-08-12 10:39:00+03	188900.00
FC2E09	2017-08-04 20:49:00+03	139100.00
FC2E3B	2017-07-13 08:30:00+03	81300.00
FC2E52	2017-06-30 01:10:00+03	131000.00
FC2E58	2017-07-10 12:37:00+03	23200.00
FC2E59	2017-07-15 18:32:00+03	50600.00
FC2ECF	2017-08-03 00:01:00+03	79800.00
FC2F46	2017-08-02 08:00:00+03	26000.00
FC2F60	2017-08-02 07:00:00+03	85700.00
FC2F8A	2017-07-09 22:45:00+03	96400.00
FC2FCA	2017-08-11 08:09:00+03	56000.00
FC300C	2017-07-07 08:13:00+03	46200.00
FC311C	2017-07-20 15:36:00+03	62600.00
FC315D	2017-08-02 16:23:00+03	64700.00
FC31BB	2017-07-06 11:26:00+03	36200.00
FC326B	2017-07-10 09:12:00+03	12600.00
FC326E	2017-07-16 00:25:00+03	16400.00
FC32BA	2017-07-27 07:08:00+03	101200.00
FC32BE	2017-07-03 21:00:00+03	94000.00
FC33B0	2017-08-10 08:29:00+03	58400.00
FC33BA	2017-06-30 03:33:00+03	148800.00
FC3415	2017-07-30 23:48:00+03	49400.00
FC3480	2017-07-20 17:22:00+03	80800.00
FC3489	2017-07-09 20:39:00+03	26700.00
FC34CB	2017-08-05 08:35:00+03	135400.00
FC356B	2017-07-11 13:36:00+03	44000.00
FC358C	2017-07-11 18:13:00+03	87300.00
FC35D8	2017-07-19 01:53:00+03	46400.00
FC3651	2017-07-25 16:45:00+03	30200.00
FC36C6	2017-07-10 09:05:00+03	32800.00
FC3734	2017-07-21 11:37:00+03	23200.00
FC37A4	2017-07-15 11:52:00+03	133200.00
FC3844	2017-08-13 19:04:00+03	248300.00
FC3869	2017-08-06 14:23:00+03	27900.00
FC388B	2017-07-03 17:26:00+03	31000.00
FC38FA	2017-07-20 00:51:00+03	63700.00
FC3931	2017-07-28 02:42:00+03	94200.00
FC39BF	2017-07-20 16:07:00+03	47600.00
FC3A07	2017-06-28 18:59:00+03	92000.00
FC3A2B	2017-08-10 11:47:00+03	61800.00
FC3A7D	2017-07-09 23:58:00+03	40400.00
FC3A8B	2017-08-12 13:10:00+03	246000.00
FC3B62	2017-07-21 04:19:00+03	69500.00
FC3B8D	2017-07-20 06:50:00+03	47000.00
FC3BDC	2017-07-30 05:39:00+03	18600.00
FC3C44	2017-08-15 15:28:00+03	43600.00
FC3C6B	2017-08-13 15:17:00+03	27200.00
FC3C91	2017-07-10 22:58:00+03	219400.00
FC3CA4	2017-07-27 07:59:00+03	199600.00
FC3CEC	2017-08-03 00:48:00+03	31800.00
FC3CED	2017-07-03 03:46:00+03	34400.00
FC3CFD	2017-07-23 00:37:00+03	91100.00
FC3D1E	2017-07-04 04:48:00+03	28000.00
FC3D78	2017-07-25 18:00:00+03	7400.00
FC3DE3	2017-08-10 06:30:00+03	173600.00
FC3DF3	2017-08-03 15:12:00+03	265700.00
FC3E2B	2017-07-06 07:39:00+03	149000.00
FC3E40	2017-07-31 21:38:00+03	157900.00
FC3E48	2017-08-03 23:38:00+03	47900.00
FC3E88	2017-07-10 17:09:00+03	81300.00
FC3ED4	2017-07-01 18:59:00+03	89700.00
FC3F41	2017-07-27 15:58:00+03	21400.00
FC403F	2017-07-14 12:00:00+03	28000.00
FC4077	2017-08-06 13:34:00+03	136500.00
FC409C	2017-08-07 04:46:00+03	134700.00
FC40B6	2017-07-23 07:14:00+03	56000.00
FC40CE	2017-07-10 21:09:00+03	16400.00
FC40FB	2017-08-07 03:30:00+03	29300.00
FC4102	2017-08-09 05:36:00+03	100600.00
FC4129	2017-07-16 04:02:00+03	140000.00
FC4175	2017-07-05 13:53:00+03	139400.00
FC419E	2017-07-16 00:50:00+03	73100.00
FC41D0	2017-07-10 06:43:00+03	81600.00
FC423A	2017-08-12 13:23:00+03	67600.00
FC424B	2017-07-19 01:42:00+03	31000.00
FC425C	2017-08-12 09:20:00+03	230800.00
FC425E	2017-07-18 02:25:00+03	290600.00
FC42FB	2017-07-04 00:47:00+03	65900.00
FC432B	2017-07-23 18:40:00+03	70400.00
FC43DE	2017-07-02 04:52:00+03	65000.00
FC4415	2017-07-05 13:55:00+03	22600.00
FC445D	2017-08-07 20:26:00+03	93900.00
FC4464	2017-07-23 15:33:00+03	265600.00
FC44BA	2017-07-09 10:45:00+03	20800.00
FC4539	2017-08-09 23:26:00+03	36200.00
FC453A	2017-07-05 10:06:00+03	84500.00
FC454C	2017-07-29 00:00:00+03	70900.00
FC4565	2017-08-03 09:08:00+03	78900.00
FC456D	2017-07-10 21:16:00+03	78300.00
FC4597	2017-08-04 08:30:00+03	16400.00
FC45A2	2017-08-03 00:00:00+03	31400.00
FC45A4	2017-07-06 05:44:00+03	12000.00
FC4617	2017-07-08 12:20:00+03	12600.00
FC4643	2017-08-15 16:32:00+03	86600.00
FC465E	2017-08-12 11:35:00+03	170200.00
FC4674	2017-07-10 00:43:00+03	88400.00
FC46C0	2017-07-18 08:36:00+03	206900.00
FC46D9	2017-07-24 01:05:00+03	50800.00
FC46DB	2017-07-28 17:04:00+03	76800.00
FC46EA	2017-08-07 16:41:00+03	7400.00
FC473F	2017-07-24 12:40:00+03	51600.00
FC4762	2017-08-05 21:30:00+03	109000.00
FC4796	2017-07-17 02:19:00+03	160700.00
FC47AF	2017-06-30 06:09:00+03	36400.00
FC4883	2017-07-20 13:52:00+03	225200.00
FC48E5	2017-07-03 08:30:00+03	44800.00
FC490E	2017-08-03 08:36:00+03	40800.00
FC4932	2017-07-02 06:49:00+03	93600.00
FC4A24	2017-08-02 16:33:00+03	265800.00
FC4A28	2017-07-25 09:18:00+03	28800.00
FC4A61	2017-07-04 03:37:00+03	166300.00
FC4A9A	2017-07-10 15:08:00+03	54000.00
FC4AAF	2017-07-12 10:41:00+03	16400.00
FC4B2F	2017-07-13 05:46:00+03	198800.00
FC4B99	2017-07-17 02:47:00+03	92800.00
FC4BCB	2017-07-05 10:45:00+03	37900.00
FC4BDD	2017-08-03 22:14:00+03	21200.00
FC4BE7	2017-07-29 15:57:00+03	57400.00
FC4BEF	2017-08-06 03:08:00+03	112000.00
FC4BFE	2017-07-30 20:00:00+03	28300.00
FC4C09	2017-08-01 13:26:00+03	75500.00
FC4C47	2017-08-15 12:52:00+03	52300.00
FC4C5C	2017-07-24 00:48:00+03	45200.00
FC4C5D	2017-07-10 13:44:00+03	111600.00
FC4C9C	2017-07-12 00:21:00+03	57500.00
FC4CB3	2017-07-08 04:06:00+03	59800.00
FC4CF0	2017-07-15 03:54:00+03	27800.00
FC4D54	2017-07-01 10:37:00+03	28000.00
FC4D66	2017-07-30 22:00:00+03	15800.00
FC4D8F	2017-08-06 01:52:00+03	68000.00
FC4DBC	2017-08-10 16:53:00+03	68100.00
FC4DD2	2017-07-24 14:54:00+03	21800.00
FC4DE0	2017-08-15 01:08:00+03	127300.00
FC4DEB	2017-08-15 08:34:00+03	31100.00
FC4E26	2017-08-13 15:49:00+03	92900.00
FC4E7C	2017-07-19 20:26:00+03	40800.00
FC4E8A	2017-07-22 00:00:00+03	12600.00
FC4F13	2017-08-11 06:26:00+03	94700.00
FC4F70	2017-08-14 09:15:00+03	12400.00
FC4FB1	2017-07-16 01:14:00+03	103500.00
FC5002	2017-08-14 18:18:00+03	52000.00
FC501C	2017-07-08 16:07:00+03	24400.00
FC5057	2017-07-11 10:52:00+03	44000.00
FC506A	2017-08-13 17:57:00+03	148200.00
FC50F9	2017-07-26 23:36:00+03	46200.00
FC50FB	2017-07-05 16:23:00+03	532800.00
FC5109	2017-07-08 07:35:00+03	64500.00
FC5122	2017-07-31 19:35:00+03	56000.00
FC514F	2017-08-07 05:05:00+03	30000.00
FC5157	2017-07-06 08:08:00+03	9200.00
FC5162	2017-08-13 03:57:00+03	88000.00
FC520A	2017-08-14 04:00:00+03	30200.00
FC5217	2017-07-05 00:27:00+03	74800.00
FC523C	2017-08-06 23:17:00+03	131600.00
FC528F	2017-08-07 01:42:00+03	229900.00
FC52D6	2017-08-13 17:32:00+03	133100.00
FC5346	2017-08-05 03:05:00+03	22000.00
FC5358	2017-07-20 02:34:00+03	51900.00
FC535B	2017-07-16 13:01:00+03	96800.00
FC5456	2017-07-24 17:09:00+03	35900.00
FC5458	2017-07-07 11:38:00+03	43500.00
FC54CF	2017-08-02 18:06:00+03	265700.00
FC5537	2017-08-06 10:32:00+03	25200.00
FC55CC	2017-08-07 01:51:00+03	106100.00
FC55EC	2017-08-11 22:48:00+03	65400.00
FC55FE	2017-07-17 08:54:00+03	27200.00
FC5616	2017-07-22 14:28:00+03	40000.00
FC561E	2017-07-10 17:55:00+03	20200.00
FC5625	2017-07-28 20:24:00+03	88500.00
FC567D	2017-08-03 14:58:00+03	25400.00
FC56E0	2017-07-05 21:16:00+03	10800.00
FC5711	2017-08-01 15:02:00+03	59000.00
FC57A6	2017-08-01 14:33:00+03	39200.00
FC5800	2017-08-10 18:36:00+03	94700.00
FC5833	2017-08-08 12:49:00+03	230000.00
FC594C	2017-07-28 14:59:00+03	14300.00
FC5975	2017-08-05 20:55:00+03	59200.00
FC59C5	2017-07-24 05:44:00+03	11000.00
FC5A28	2017-07-26 08:46:00+03	240600.00
FC5A65	2017-07-15 09:16:00+03	32400.00
FC5AC5	2017-08-11 11:51:00+03	126300.00
FC5AFC	2017-08-13 18:02:00+03	56300.00
FC5B33	2017-07-13 01:34:00+03	189800.00
FC5B46	2017-08-13 05:23:00+03	58400.00
FC5B4B	2017-08-04 08:22:00+03	85700.00
FC5B74	2017-08-01 06:10:00+03	265800.00
FC5B8F	2017-07-21 18:21:00+03	61800.00
FC5B9F	2017-07-05 11:27:00+03	288800.00
FC5BEA	2017-08-15 03:10:00+03	53100.00
FC5C56	2017-07-05 18:16:00+03	201200.00
FC5C9C	2017-07-10 01:38:00+03	174000.00
FC5D44	2017-07-16 18:20:00+03	68400.00
FC5D8C	2017-07-24 19:41:00+03	47200.00
FC5D9A	2017-07-06 15:41:00+03	79300.00
FC5DD0	2017-08-10 08:39:00+03	27200.00
FC5DFA	2017-06-29 17:37:00+03	11700.00
FC5E00	2017-08-07 23:17:00+03	35800.00
FC5E52	2017-06-26 04:16:00+03	54400.00
FC5E73	2017-08-15 08:19:00+03	28000.00
FC5E88	2017-07-08 19:57:00+03	19600.00
FC5E9B	2017-07-17 05:51:00+03	69300.00
FC5EB5	2017-07-04 21:56:00+03	265700.00
FC5F17	2017-07-11 03:32:00+03	150700.00
FC5F22	2017-08-15 03:30:00+03	48200.00
FC5F43	2017-07-14 19:56:00+03	123000.00
FC5F60	2017-07-05 11:13:00+03	63600.00
FC5FBD	2017-07-18 22:12:00+03	112600.00
FC608E	2017-07-11 12:02:00+03	47500.00
FC610E	2017-07-04 14:54:00+03	113200.00
FC6184	2017-07-09 05:01:00+03	297600.00
FC61AA	2017-07-16 02:10:00+03	23400.00
FC61BE	2017-07-25 02:10:00+03	38600.00
FC61F7	2017-07-06 01:22:00+03	13300.00
FC620A	2017-08-02 18:52:00+03	20400.00
FC622B	2017-08-01 12:20:00+03	18600.00
FC623C	2017-07-20 08:18:00+03	13200.00
FC625C	2017-07-14 00:29:00+03	125600.00
FC62B1	2017-07-07 02:07:00+03	86600.00
FC62B9	2017-07-01 17:03:00+03	85000.00
FC6382	2017-07-12 02:31:00+03	50600.00
FC63E4	2017-07-29 03:13:00+03	44800.00
FC646E	2017-07-30 12:40:00+03	16400.00
FC649A	2017-07-18 13:35:00+03	84100.00
FC64C9	2017-07-25 00:01:00+03	60400.00
FC64DD	2017-07-12 06:09:00+03	26800.00
FC6578	2017-08-08 17:54:00+03	28000.00
FC660A	2017-07-22 00:55:00+03	6800.00
FC6633	2017-06-30 11:05:00+03	25000.00
FC666B	2017-07-17 14:53:00+03	75100.00
FC669A	2017-08-11 10:36:00+03	29100.00
FC67E0	2017-07-27 09:32:00+03	80400.00
FC67FC	2017-07-30 12:16:00+03	6300.00
FC680A	2017-07-08 12:53:00+03	56600.00
FC6863	2017-07-12 05:00:00+03	87100.00
FC6909	2017-07-22 02:40:00+03	38400.00
FC695B	2017-07-26 17:42:00+03	39700.00
FC6A61	2017-07-05 23:11:00+03	169900.00
FC6ADC	2017-07-20 02:18:00+03	213200.00
FC6AEC	2017-07-21 13:18:00+03	6000.00
FC6B00	2017-07-12 12:08:00+03	46400.00
FC6B1A	2017-08-02 13:08:00+03	43500.00
FC6B67	2017-08-04 10:50:00+03	23200.00
FC6B82	2017-07-04 16:46:00+03	166100.00
FC6F38	2017-08-02 11:43:00+03	35200.00
FC6F7A	2017-08-12 04:57:00+03	32100.00
FC6F7E	2017-07-05 02:04:00+03	22000.00
FC6F99	2017-07-17 04:10:00+03	62600.00
FC700B	2017-07-07 00:18:00+03	134400.00
FC702D	2017-07-09 05:56:00+03	147700.00
FC7042	2017-07-17 20:17:00+03	56000.00
FC7055	2017-07-14 15:47:00+03	169300.00
FC7084	2017-08-13 17:16:00+03	102600.00
FC7086	2017-07-21 04:00:00+03	92000.00
FC7089	2017-07-30 19:01:00+03	7400.00
FC7099	2017-07-23 06:59:00+03	46200.00
FC70A3	2017-07-18 00:40:00+03	32200.00
FC70C3	2017-07-25 00:54:00+03	54800.00
FC70F8	2017-08-13 18:59:00+03	86500.00
FC720F	2017-08-14 04:14:00+03	271200.00
FC7238	2017-07-16 19:19:00+03	168700.00
FC723D	2017-08-15 11:24:00+03	51700.00
FC725A	2017-07-08 11:50:00+03	44600.00
FC726C	2017-07-31 20:36:00+03	76400.00
FC7281	2017-07-27 02:45:00+03	25600.00
FC7315	2017-07-09 15:42:00+03	542300.00
FC7380	2017-07-08 16:14:00+03	30400.00
FC73C0	2017-07-05 06:26:00+03	166900.00
FC73F7	2017-08-01 11:17:00+03	42800.00
FC7449	2017-07-13 22:10:00+03	66600.00
FC74AD	2017-07-06 10:03:00+03	75900.00
FC74BE	2017-07-07 23:53:00+03	266400.00
FC74DE	2017-07-03 20:03:00+03	45100.00
FC7533	2017-08-14 09:43:00+03	15000.00
FC755D	2017-07-12 09:06:00+03	16400.00
FC75C2	2017-07-24 23:15:00+03	44000.00
FC7603	2017-07-11 09:38:00+03	24400.00
FC7624	2017-07-18 01:12:00+03	138800.00
FC77D6	2017-07-10 04:21:00+03	50400.00
FC77DC	2017-07-22 10:14:00+03	42400.00
FC7802	2017-07-31 18:36:00+03	51500.00
FC7803	2017-08-03 00:59:00+03	49200.00
FC7860	2017-07-31 10:37:00+03	45500.00
FC786B	2017-07-22 04:16:00+03	29200.00
FC786D	2017-07-30 08:44:00+03	58600.00
FC7883	2017-07-14 15:06:00+03	56000.00
FC78FC	2017-07-06 11:24:00+03	26200.00
FC7937	2017-07-31 02:44:00+03	16400.00
FC7943	2017-07-20 06:54:00+03	46400.00
FC7986	2017-07-21 01:00:00+03	139300.00
FC79E5	2017-08-01 14:48:00+03	151200.00
FC79ED	2017-07-17 15:28:00+03	119500.00
FC7B1D	2017-08-02 06:51:00+03	34400.00
FC7B96	2017-06-29 20:22:00+03	100600.00
FC7BD2	2017-07-06 01:27:00+03	74800.00
FC7C8A	2017-08-09 18:38:00+03	14400.00
FC7CB6	2017-07-13 17:45:00+03	187600.00
FC7CD3	2017-07-29 10:58:00+03	46300.00
FC7CD7	2017-07-01 23:47:00+03	283100.00
FC7D00	2017-08-06 12:26:00+03	19600.00
FC7D93	2017-07-16 10:33:00+03	34800.00
FC7DCE	2017-08-13 19:28:00+03	190800.00
FC7E2D	2017-07-18 02:40:00+03	271100.00
FC7E35	2017-08-10 04:08:00+03	19600.00
FC7E4E	2017-07-05 18:05:00+03	22000.00
FC7E5E	2017-07-30 15:53:00+03	25900.00
FC7E8F	2017-07-10 12:34:00+03	89600.00
FC7EDD	2017-07-21 19:09:00+03	399600.00
FC7F26	2017-07-26 18:26:00+03	44600.00
FC7F6B	2017-07-02 10:38:00+03	19600.00
FC802C	2017-08-01 22:48:00+03	88600.00
FC8030	2017-07-29 20:55:00+03	36200.00
FC8045	2017-07-06 11:47:00+03	10800.00
FC808A	2017-08-09 03:13:00+03	139700.00
FC80FB	2017-08-01 18:03:00+03	24000.00
FC8100	2017-07-31 20:53:00+03	82900.00
FC8126	2017-07-08 12:19:00+03	25000.00
FC81B0	2017-07-30 15:44:00+03	135200.00
FC81E8	2017-08-12 00:06:00+03	46500.00
FC8272	2017-07-11 09:36:00+03	92800.00
FC8320	2017-07-28 14:09:00+03	56000.00
FC8354	2017-07-04 12:30:00+03	63200.00
FC837C	2017-07-23 17:38:00+03	48800.00
FC8454	2017-08-04 18:48:00+03	56100.00
FC8476	2017-07-26 10:02:00+03	397700.00
FC847F	2017-07-06 20:41:00+03	134600.00
FC849C	2017-07-25 02:04:00+03	62900.00
FC8501	2017-07-08 02:21:00+03	273400.00
FC85B7	2017-07-10 06:24:00+03	68400.00
FC8762	2017-07-20 21:36:00+03	123000.00
FC87A7	2017-07-14 01:10:00+03	58900.00
FC87AB	2017-07-21 22:12:00+03	273600.00
FC87B5	2017-07-28 02:55:00+03	266300.00
FC87CB	2017-08-09 12:12:00+03	89700.00
FC8855	2017-08-09 00:23:00+03	201800.00
FC887A	2017-07-19 03:46:00+03	35200.00
FC88A7	2017-07-10 16:21:00+03	26000.00
FC88B9	2017-08-09 11:27:00+03	177200.00
FC88E1	2017-07-04 19:49:00+03	31400.00
FC88F4	2017-07-14 17:22:00+03	66600.00
FC892D	2017-08-15 01:31:00+03	103400.00
FC8931	2017-07-25 18:22:00+03	67400.00
FC8932	2017-07-23 19:15:00+03	143600.00
FC8939	2017-07-10 08:32:00+03	7400.00
FC8945	2017-08-15 12:21:00+03	267400.00
FC8983	2017-07-13 11:41:00+03	46000.00
FC8984	2017-07-10 11:41:00+03	53300.00
FC8989	2017-08-09 23:09:00+03	123000.00
FC8AAC	2017-07-07 05:46:00+03	89600.00
FC8AAF	2017-07-17 10:53:00+03	170500.00
FC8AC6	2017-08-14 12:19:00+03	31800.00
FC8ACB	2017-07-07 14:21:00+03	83000.00
FC8B84	2017-07-16 04:18:00+03	123000.00
FC8BBF	2017-08-03 03:30:00+03	54500.00
FC8C0C	2017-07-10 18:38:00+03	56000.00
FC8CA7	2017-08-13 16:22:00+03	24000.00
FC8D2B	2017-07-06 07:12:00+03	22000.00
FC8D57	2017-08-14 19:40:00+03	38800.00
FC8D68	2017-07-18 11:12:00+03	111000.00
FC8E5E	2017-07-13 03:31:00+03	32200.00
FC8E70	2017-08-08 02:36:00+03	193700.00
FC8E87	2017-07-12 02:58:00+03	33600.00
FC8E8B	2017-07-12 08:28:00+03	56000.00
FC8EA7	2017-08-06 23:36:00+03	53300.00
FC8EB1	2017-07-08 19:49:00+03	28800.00
FC8F18	2017-07-09 21:20:00+03	56600.00
FC8FF0	2017-07-22 10:34:00+03	66000.00
FC8FF6	2017-07-19 14:13:00+03	53300.00
FC9046	2017-07-25 13:02:00+03	124200.00
FC90A5	2017-07-12 09:50:00+03	67200.00
FC90C3	2017-07-17 18:41:00+03	24800.00
FC90CB	2017-08-10 02:56:00+03	70800.00
FC91C9	2017-08-14 22:51:00+03	130900.00
FC9234	2017-08-08 21:49:00+03	477500.00
FC9263	2017-08-08 00:35:00+03	265700.00
FC92A0	2017-08-05 08:28:00+03	66400.00
FC92BB	2017-08-07 16:17:00+03	81400.00
FC92DD	2017-06-30 20:34:00+03	12000.00
FC9368	2017-07-14 16:19:00+03	72600.00
FC9383	2017-07-26 18:11:00+03	155000.00
FC93A3	2017-08-07 00:46:00+03	132800.00
FC93FE	2017-08-14 02:45:00+03	38000.00
FC942B	2017-07-16 14:35:00+03	94300.00
FC943C	2017-07-04 21:13:00+03	46000.00
FC9450	2017-07-03 02:35:00+03	25400.00
FC946F	2017-08-09 11:58:00+03	190700.00
FC949B	2017-07-11 14:42:00+03	46900.00
FC94AE	2017-07-03 05:58:00+03	17600.00
FC94DB	2017-07-02 04:19:00+03	68000.00
FC9506	2017-07-28 20:26:00+03	67600.00
FC9508	2017-07-24 04:30:00+03	6700.00
FC9572	2017-07-31 09:18:00+03	28000.00
FC957D	2017-07-14 20:34:00+03	14800.00
FC960A	2017-07-19 03:59:00+03	31100.00
FC963F	2017-07-18 13:10:00+03	68800.00
FC9644	2017-07-12 20:35:00+03	29400.00
FC9649	2017-08-07 06:20:00+03	271100.00
FC9663	2017-07-08 01:09:00+03	30200.00
FC96BE	2017-07-12 04:02:00+03	369000.00
FC96D1	2017-08-13 21:29:00+03	54800.00
FC970D	2017-08-12 14:51:00+03	135400.00
FC979C	2017-08-11 16:57:00+03	30700.00
FC97AD	2017-08-13 16:06:00+03	92200.00
FC97FC	2017-07-03 17:40:00+03	112100.00
FC9823	2017-07-27 02:02:00+03	18300.00
FC984A	2017-08-09 03:48:00+03	47100.00
FC9894	2017-08-03 19:19:00+03	92800.00
FC98E0	2017-08-05 00:49:00+03	141200.00
FC98F1	2017-08-14 00:20:00+03	71100.00
FC9971	2017-07-29 03:22:00+03	25800.00
FC997A	2017-08-04 18:36:00+03	75600.00
FC999B	2017-07-05 16:24:00+03	30200.00
FC9A3D	2017-07-13 11:42:00+03	169000.00
FC9A4F	2017-07-27 04:55:00+03	40600.00
FC9A50	2017-07-08 10:34:00+03	15000.00
FC9A57	2017-07-30 17:02:00+03	66800.00
FC9A74	2017-08-12 05:28:00+03	32700.00
FC9A8A	2017-06-29 11:41:00+03	70100.00
FC9AEC	2017-07-26 08:35:00+03	130400.00
FC9B5E	2017-08-02 01:33:00+03	131100.00
FC9B6F	2017-07-09 09:55:00+03	6000.00
FC9BA0	2017-07-29 19:11:00+03	43900.00
FC9CE6	2017-08-13 08:22:00+03	54400.00
FC9E13	2017-07-23 14:45:00+03	68100.00
FC9E66	2017-07-13 10:44:00+03	50800.00
FC9E8F	2017-07-23 17:46:00+03	112000.00
FC9F13	2017-07-05 21:40:00+03	153400.00
FC9F81	2017-07-27 08:22:00+03	145600.00
FC9F86	2017-07-13 08:17:00+03	73600.00
FC9FAC	2017-07-15 19:51:00+03	27200.00
FCA0FC	2017-07-09 05:33:00+03	189200.00
FCA13C	2017-07-05 06:27:00+03	111600.00
FCA187	2017-06-28 11:30:00+03	14400.00
FCA1A0	2017-07-28 01:34:00+03	87000.00
FCA249	2017-07-11 01:28:00+03	262500.00
FCA26B	2017-07-23 21:16:00+03	56000.00
FCA2A3	2017-08-09 23:10:00+03	6200.00
FCA2AE	2017-07-25 21:22:00+03	99700.00
FCA310	2017-07-22 22:42:00+03	16400.00
FCA334	2017-07-17 23:21:00+03	37900.00
FCA352	2017-08-09 06:14:00+03	21800.00
FCA383	2017-08-14 01:39:00+03	54500.00
FCA40C	2017-08-13 23:40:00+03	56000.00
FCA40D	2017-08-13 05:49:00+03	123000.00
FCA418	2017-08-14 18:23:00+03	124200.00
FCA45E	2017-07-30 09:47:00+03	155700.00
FCA497	2017-07-14 15:05:00+03	257600.00
FCA502	2017-07-25 16:23:00+03	59800.00
FCA561	2017-07-03 23:18:00+03	76600.00
FCA58E	2017-07-29 13:36:00+03	44800.00
FCA596	2017-07-31 01:03:00+03	73600.00
FCA618	2017-08-08 20:02:00+03	28800.00
FCA693	2017-07-31 05:25:00+03	76400.00
FCA6F0	2017-07-27 19:59:00+03	102100.00
FCA75D	2017-07-22 01:09:00+03	195900.00
FCA792	2017-08-04 21:20:00+03	50300.00
FCA7B4	2017-07-09 19:35:00+03	541500.00
FCA817	2017-07-30 10:00:00+03	36000.00
FCA820	2017-08-13 13:29:00+03	89700.00
FCA82C	2017-07-16 02:47:00+03	84300.00
FCA894	2017-08-13 13:00:00+03	65900.00
FCA97B	2017-07-10 11:16:00+03	28000.00
FCA988	2017-07-22 11:17:00+03	6700.00
FCA9F9	2017-07-25 09:50:00+03	55500.00
FCAAC3	2017-07-20 18:25:00+03	72400.00
FCAB11	2017-07-08 15:21:00+03	84100.00
FCAB1C	2017-07-11 15:59:00+03	255000.00
FCAB58	2017-07-08 14:50:00+03	51800.00
FCAB90	2017-08-01 05:38:00+03	54300.00
FCAC17	2017-07-28 05:16:00+03	14700.00
FCAC3F	2017-07-12 09:50:00+03	26000.00
FCAC67	2017-07-03 05:07:00+03	18900.00
FCACDB	2017-08-04 20:04:00+03	7200.00
FCACE1	2017-07-16 11:40:00+03	40000.00
FCAD17	2017-07-19 20:58:00+03	100600.00
FCAD3E	2017-07-04 12:44:00+03	58600.00
FCADD2	2017-07-02 04:43:00+03	147100.00
FCAE3D	2017-07-20 05:12:00+03	125900.00
FCAE51	2017-08-07 01:54:00+03	18000.00
FCAE63	2017-07-15 10:14:00+03	92800.00
FCAE7B	2017-07-03 15:10:00+03	30200.00
FCAEE7	2017-07-29 14:33:00+03	56100.00
FCAEF6	2017-07-25 18:12:00+03	101200.00
FCAF1E	2017-07-05 17:45:00+03	23600.00
FCAF32	2017-07-18 11:11:00+03	52900.00
FCAF56	2017-07-21 07:15:00+03	133100.00
FCAF92	2017-06-29 23:03:00+03	52300.00
FCAFC5	2017-07-07 02:24:00+03	177200.00
FCB069	2017-07-14 16:14:00+03	133200.00
FCB094	2017-08-09 21:33:00+03	134000.00
FCB0FB	2017-07-31 12:52:00+03	95500.00
FCB17C	2017-07-17 23:05:00+03	68800.00
FCB196	2017-07-25 14:40:00+03	28800.00
FCB1AE	2017-08-02 16:35:00+03	67600.00
FCB1B8	2017-07-17 06:44:00+03	165800.00
FCB217	2017-07-11 20:44:00+03	104600.00
FCB224	2017-07-29 02:48:00+03	28000.00
FCB225	2017-07-08 06:16:00+03	47100.00
FCB23E	2017-07-19 02:11:00+03	100600.00
FCB251	2017-08-15 03:12:00+03	26700.00
FCB289	2017-07-07 23:17:00+03	90800.00
FCB389	2017-07-20 22:18:00+03	34000.00
FCB3C1	2017-07-29 15:22:00+03	246800.00
FCB3E2	2017-07-19 10:00:00+03	95600.00
FCB3E9	2017-08-08 06:18:00+03	18400.00
FCB400	2017-08-14 16:37:00+03	92800.00
FCB47F	2017-07-14 01:47:00+03	139100.00
FCB4A1	2017-07-18 16:16:00+03	369000.00
FCB4E0	2017-06-29 06:50:00+03	20400.00
FCB525	2017-08-13 09:21:00+03	18300.00
FCB530	2017-08-14 09:33:00+03	99200.00
FCB568	2017-08-06 10:39:00+03	47200.00
FCB593	2017-07-27 14:45:00+03	69900.00
FCB59B	2017-08-12 17:17:00+03	55500.00
FCB5D0	2017-06-28 05:08:00+03	44800.00
FCB612	2017-07-04 11:58:00+03	32800.00
FCB617	2017-08-06 10:08:00+03	378400.00
FCB629	2017-08-13 03:13:00+03	6000.00
FCB68E	2017-08-13 03:34:00+03	45200.00
FCB6AA	2017-07-24 17:54:00+03	24400.00
FCB6CD	2017-07-02 10:36:00+03	266400.00
FCB6DC	2017-08-11 03:20:00+03	69200.00
FCB6EF	2017-07-09 20:26:00+03	81600.00
FCB6FF	2017-08-05 04:17:00+03	10800.00
FCB7ED	2017-08-12 13:33:00+03	40200.00
FCB84D	2017-08-08 04:09:00+03	23400.00
FCB8A2	2017-07-03 10:24:00+03	58800.00
FCB8DC	2017-08-11 02:56:00+03	73600.00
FCB908	2017-07-28 01:56:00+03	42900.00
FCB913	2017-07-29 22:37:00+03	342400.00
FCB923	2017-08-04 21:36:00+03	40400.00
FCB999	2017-06-30 03:57:00+03	22100.00
FCB9F8	2017-06-29 12:13:00+03	14000.00
FCBA32	2017-07-20 14:01:00+03	23600.00
FCBA3A	2017-07-11 11:45:00+03	64000.00
FCBA9D	2017-07-06 09:44:00+03	36000.00
FCBAA5	2017-07-20 04:25:00+03	21800.00
FCBAEF	2017-08-03 10:36:00+03	266400.00
FCBB39	2017-08-01 20:00:00+03	88200.00
FCBB92	2017-07-05 15:50:00+03	193200.00
FCBB9B	2017-07-18 20:55:00+03	26400.00
FCBBCE	2017-07-26 13:27:00+03	6700.00
FCBBD9	2017-07-17 19:51:00+03	22600.00
FCBC59	2017-08-07 06:16:00+03	31000.00
FCBC66	2017-08-01 23:36:00+03	149000.00
FCBC68	2017-07-09 02:48:00+03	46000.00
FCBCF0	2017-08-07 12:01:00+03	26800.00
FCBCF7	2017-08-12 17:43:00+03	116900.00
FCBD53	2017-08-02 11:07:00+03	14000.00
FCBD79	2017-07-16 03:04:00+03	24400.00
FCBDF3	2017-07-01 11:07:00+03	56900.00
FCBE01	2017-07-24 21:31:00+03	23200.00
FCBE89	2017-08-10 22:23:00+03	42800.00
FCBF7F	2017-07-13 14:40:00+03	112600.00
FCBF9E	2017-07-01 14:30:00+03	12000.00
FCBFFF	2017-07-30 14:10:00+03	43900.00
FCC00C	2017-07-03 21:09:00+03	7200.00
FCC027	2017-07-25 21:44:00+03	28800.00
FCC0FA	2017-07-09 10:41:00+03	43000.00
FCC18D	2017-07-08 18:03:00+03	14000.00
FCC1A6	2017-08-13 09:04:00+03	32400.00
FCC1AD	2017-07-22 23:03:00+03	88600.00
FCC212	2017-07-01 11:16:00+03	38400.00
FCC245	2017-08-01 15:08:00+03	28000.00
FCC30C	2017-07-20 21:11:00+03	37900.00
FCC320	2017-07-31 13:13:00+03	90400.00
FCC374	2017-07-26 21:34:00+03	185000.00
FCC37A	2017-08-13 05:26:00+03	82100.00
FCC3B0	2017-07-10 19:49:00+03	14000.00
FCC3BB	2017-07-23 18:49:00+03	230000.00
FCC3BF	2017-07-27 14:09:00+03	77200.00
FCC3D6	2017-08-09 00:18:00+03	35800.00
FCC3DB	2017-08-01 13:09:00+03	29600.00
FCC4CE	2017-07-07 21:33:00+03	46000.00
FCC543	2017-08-06 19:00:00+03	87200.00
FCC56A	2017-07-05 07:34:00+03	103800.00
FCC5C4	2017-08-13 12:48:00+03	45200.00
FCC60A	2017-07-14 22:14:00+03	34200.00
FCC64C	2017-07-13 11:28:00+03	222000.00
FCC690	2017-08-08 17:04:00+03	77000.00
FCC6BC	2017-08-10 01:29:00+03	62200.00
FCC755	2017-07-24 17:42:00+03	119600.00
FCC764	2017-07-13 15:46:00+03	327500.00
FCC7AB	2017-07-30 20:32:00+03	67400.00
FCC82E	2017-08-03 03:01:00+03	193600.00
FCC848	2017-07-24 02:20:00+03	135400.00
FCC8F7	2017-07-15 08:12:00+03	169600.00
FCC974	2017-08-10 01:26:00+03	27200.00
FCC9AB	2017-07-14 22:53:00+03	28000.00
FCCA40	2017-08-02 02:23:00+03	60300.00
FCCA5E	2017-07-19 07:28:00+03	50000.00
FCCAF1	2017-07-12 21:45:00+03	28000.00
FCCB11	2017-08-04 01:01:00+03	77200.00
FCCB19	2017-07-31 19:14:00+03	139300.00
FCCB2D	2017-07-30 21:14:00+03	28000.00
FCCB4B	2017-07-29 19:12:00+03	23600.00
FCCB4E	2017-07-07 15:07:00+03	38800.00
FCCB8A	2017-07-24 08:32:00+03	26000.00
FCCBB7	2017-08-01 23:15:00+03	94700.00
FCCBE4	2017-07-22 03:11:00+03	28800.00
FCCBF3	2017-08-05 17:05:00+03	87200.00
FCCC0E	2017-07-21 19:23:00+03	32200.00
FCCCB1	2017-08-05 06:07:00+03	50100.00
FCCCDA	2017-07-21 07:19:00+03	167400.00
FCCD7A	2017-07-24 17:54:00+03	23200.00
FCCE20	2017-07-13 17:49:00+03	68100.00
FCCE4F	2017-06-29 08:34:00+03	133900.00
FCCE83	2017-07-10 12:38:00+03	114800.00
FCCEB2	2017-07-23 10:53:00+03	49700.00
FCCED8	2017-07-20 11:07:00+03	28800.00
FCCF74	2017-08-02 05:48:00+03	43200.00
FCCF7D	2017-07-24 04:57:00+03	155600.00
FCCF91	2017-07-24 06:08:00+03	86800.00
FCCFA1	2017-07-24 06:28:00+03	135600.00
FCD007	2017-07-10 16:11:00+03	31000.00
FCD02F	2017-08-14 12:07:00+03	306500.00
FCD048	2017-08-05 02:03:00+03	34600.00
FCD056	2017-08-11 09:42:00+03	22100.00
FCD073	2017-07-03 12:08:00+03	27700.00
FCD09A	2017-07-03 21:56:00+03	64800.00
FCD0D7	2017-07-14 17:35:00+03	544700.00
FCD0F6	2017-08-05 17:22:00+03	94700.00
FCD10D	2017-08-02 13:28:00+03	16000.00
FCD1FF	2017-08-02 23:30:00+03	25400.00
FCD200	2017-08-01 13:50:00+03	10800.00
FCD247	2017-07-11 07:20:00+03	35200.00
FCD274	2017-06-30 17:37:00+03	73200.00
FCD379	2017-08-05 12:36:00+03	29400.00
FCD3C0	2017-07-09 20:22:00+03	124200.00
FCD3E2	2017-07-02 21:11:00+03	64500.00
FCD408	2017-08-09 18:28:00+03	46400.00
FCD412	2017-08-05 19:15:00+03	46400.00
FCD447	2017-08-11 03:33:00+03	243700.00
FCD44D	2017-07-07 10:28:00+03	89600.00
FCD4E7	2017-07-24 08:05:00+03	8200.00
FCD525	2017-07-29 00:31:00+03	51200.00
FCD531	2017-08-09 00:30:00+03	134700.00
FCD56F	2017-07-10 17:28:00+03	128900.00
FCD5D5	2017-08-07 17:14:00+03	114300.00
FCD60F	2017-08-13 18:01:00+03	47200.00
FCD659	2017-07-18 20:30:00+03	25100.00
FCD65F	2017-08-14 00:06:00+03	62600.00
FCD678	2017-07-01 01:49:00+03	52000.00
FCD67C	2017-08-02 01:03:00+03	43000.00
FCD67E	2017-07-03 13:50:00+03	37200.00
FCD6B4	2017-06-29 03:24:00+03	88200.00
FCD7DA	2017-07-08 19:10:00+03	122800.00
FCD821	2017-07-13 05:20:00+03	69900.00
FCD854	2017-07-25 04:05:00+03	107500.00
FCD8D8	2017-07-29 05:55:00+03	27800.00
FCD972	2017-08-15 02:49:00+03	370200.00
FCD9A2	2017-07-11 23:30:00+03	22600.00
FCD9F5	2017-08-13 08:40:00+03	41900.00
FCDA26	2017-08-03 20:19:00+03	80000.00
FCDA36	2017-07-28 16:55:00+03	16800.00
FCDA40	2017-07-16 11:14:00+03	81300.00
FCDAED	2017-07-28 11:00:00+03	46400.00
FCDAF9	2017-07-28 05:09:00+03	26000.00
FCDB68	2017-08-02 00:30:00+03	66600.00
FCDBD7	2017-08-15 06:59:00+03	84300.00
FCDBE5	2017-07-04 19:19:00+03	136800.00
FCDBF5	2017-07-25 08:01:00+03	139200.00
FCDC30	2017-08-14 02:09:00+03	15000.00
FCDC66	2017-07-22 20:50:00+03	61800.00
FCDC84	2017-07-25 00:18:00+03	89600.00
FCDC85	2017-07-12 15:30:00+03	38000.00
FCDCDE	2017-08-09 11:36:00+03	19200.00
FCDCED	2017-07-15 13:24:00+03	39200.00
FCDD4F	2017-07-27 12:47:00+03	113000.00
FCDDC6	2017-07-29 00:25:00+03	39500.00
FCDE22	2017-07-16 17:27:00+03	29500.00
FCDEA9	2017-07-15 13:37:00+03	23600.00
FCDECC	2017-07-04 18:03:00+03	177200.00
FCDF0C	2017-07-13 01:29:00+03	248300.00
FCDF18	2017-08-10 13:38:00+03	64700.00
FCDF94	2017-07-17 22:47:00+03	119600.00
FCDFE1	2017-07-24 05:12:00+03	18000.00
FCDFE6	2017-07-30 18:43:00+03	117600.00
FCE013	2017-07-10 21:49:00+03	37900.00
FCE027	2017-07-23 18:31:00+03	40800.00
FCE028	2017-07-26 04:53:00+03	56600.00
FCE033	2017-08-01 14:51:00+03	43400.00
FCE039	2017-08-09 18:35:00+03	178800.00
FCE03C	2017-07-23 21:05:00+03	54300.00
FCE0CF	2017-08-01 10:26:00+03	31000.00
FCE1CC	2017-07-01 18:13:00+03	41400.00
FCE1DA	2017-07-13 01:34:00+03	6000.00
FCE200	2017-07-04 02:40:00+03	56900.00
FCE215	2017-07-30 00:14:00+03	26000.00
FCE220	2017-07-10 23:19:00+03	28600.00
FCE287	2017-08-05 18:10:00+03	54400.00
FCE2FA	2017-08-11 10:17:00+03	146300.00
FCE2FB	2017-07-01 08:39:00+03	75300.00
FCE32B	2017-07-22 06:55:00+03	32500.00
FCE348	2017-07-04 13:09:00+03	56900.00
FCE366	2017-07-04 04:22:00+03	46400.00
FCE38D	2017-08-14 16:25:00+03	3400.00
FCE3A3	2017-07-30 00:16:00+03	63700.00
FCE3AC	2017-08-03 01:25:00+03	93000.00
FCE42C	2017-06-30 17:53:00+03	21800.00
FCE4C4	2017-07-13 23:53:00+03	144400.00
FCE4D8	2017-08-14 13:42:00+03	36000.00
FCE512	2017-08-05 13:14:00+03	52700.00
FCE525	2017-07-27 07:08:00+03	60400.00
FCE542	2017-08-12 16:15:00+03	298500.00
FCE59B	2017-07-22 13:41:00+03	135300.00
FCE5F0	2017-07-18 07:33:00+03	148200.00
FCE5F2	2017-08-01 14:30:00+03	126000.00
FCE603	2017-07-15 02:17:00+03	55800.00
FCE610	2017-08-09 23:59:00+03	71000.00
FCE61A	2017-08-09 01:20:00+03	36800.00
FCE628	2017-06-29 07:20:00+03	48400.00
FCE691	2017-07-08 09:08:00+03	46200.00
FCE70D	2017-08-10 17:53:00+03	12600.00
FCE74C	2017-07-09 10:05:00+03	42800.00
FCE758	2017-06-28 10:37:00+03	14000.00
FCE762	2017-07-02 18:45:00+03	53400.00
FCE781	2017-08-06 09:56:00+03	85000.00
FCE7A9	2017-08-02 19:39:00+03	30200.00
FCE7AD	2017-07-22 11:34:00+03	112000.00
FCE804	2017-07-31 02:13:00+03	56000.00
FCE836	2017-07-03 15:44:00+03	75600.00
FCE874	2017-08-12 20:10:00+03	33200.00
FCE87B	2017-07-21 19:14:00+03	28300.00
FCE8A1	2017-07-28 10:28:00+03	165200.00
FCE8B0	2017-07-15 23:42:00+03	16400.00
FCE8F8	2017-07-05 05:35:00+03	126700.00
FCE90E	2017-07-31 03:27:00+03	35200.00
FCE918	2017-08-08 09:01:00+03	56000.00
FCE98B	2017-07-02 17:20:00+03	26000.00
FCE990	2017-08-13 05:50:00+03	35600.00
FCE9D8	2017-07-10 10:52:00+03	96300.00
FCEA75	2017-07-06 22:37:00+03	16800.00
FCEAB7	2017-07-20 05:06:00+03	59200.00
FCEADC	2017-07-15 14:54:00+03	139400.00
FCEAE9	2017-07-04 11:48:00+03	126300.00
FCEB8E	2017-07-29 17:00:00+03	6700.00
FCEBE0	2017-07-16 19:11:00+03	132800.00
FCEBEB	2017-07-10 19:03:00+03	14000.00
FCEBFA	2017-07-05 00:45:00+03	58200.00
FCEC5F	2017-07-21 17:11:00+03	259500.00
FCED34	2017-07-28 13:34:00+03	487100.00
FCED7E	2017-08-08 23:36:00+03	123000.00
FCEDE1	2017-07-09 21:53:00+03	55800.00
FCEE02	2017-07-16 13:40:00+03	46700.00
FCEE22	2017-08-09 06:01:00+03	22600.00
FCEE44	2017-07-13 14:17:00+03	156200.00
FCEEA4	2017-08-03 04:20:00+03	132800.00
FCEF5F	2017-08-01 11:59:00+03	66600.00
FCEFAA	2017-08-08 10:32:00+03	37700.00
FCF005	2017-07-29 08:26:00+03	15000.00
FCF039	2017-07-14 14:42:00+03	88900.00
FCF04C	2017-07-05 15:50:00+03	16800.00
FCF050	2017-07-05 12:24:00+03	201200.00
FCF108	2017-07-27 16:06:00+03	272400.00
FCF188	2017-07-17 01:41:00+03	69500.00
FCF260	2017-07-17 12:15:00+03	36200.00
FCF292	2017-08-14 06:21:00+03	23200.00
FCF2FC	2017-07-07 23:32:00+03	28000.00
FCF32C	2017-08-01 03:29:00+03	39200.00
FCF36A	2017-08-03 14:13:00+03	53600.00
FCF379	2017-07-16 14:04:00+03	21800.00
FCF3A4	2017-08-14 04:53:00+03	10600.00
FCF3C4	2017-07-09 23:42:00+03	133100.00
FCF3EB	2017-07-10 07:10:00+03	46400.00
FCF3FD	2017-07-23 17:54:00+03	88800.00
FCF41C	2017-07-19 14:39:00+03	23200.00
FCF483	2017-07-26 15:20:00+03	80000.00
FCF4AA	2017-08-03 00:58:00+03	81200.00
FCF4AF	2017-08-04 03:17:00+03	20000.00
FCF4B5	2017-07-19 03:45:00+03	52000.00
FCF4E2	2017-08-02 07:54:00+03	55800.00
FCF561	2017-07-25 09:44:00+03	134700.00
FCF566	2017-08-10 07:03:00+03	26000.00
FCF591	2017-07-15 00:18:00+03	266300.00
FCF5F7	2017-08-13 09:13:00+03	62600.00
FCF635	2017-07-26 09:31:00+03	38400.00
FCF64F	2017-07-16 22:02:00+03	47600.00
FCF67F	2017-07-17 06:05:00+03	42700.00
FCF689	2017-07-20 19:57:00+03	99200.00
FCF6E0	2017-07-11 04:18:00+03	149200.00
FCF72C	2017-07-19 02:10:00+03	10800.00
FCF77D	2017-07-20 01:33:00+03	43000.00
FCF7AA	2017-07-03 00:09:00+03	27800.00
FCF7DA	2017-07-29 15:00:00+03	12200.00
FCF7E4	2017-08-10 01:59:00+03	52900.00
FCF878	2017-07-22 16:44:00+03	20500.00
FCF8BA	2017-08-14 10:05:00+03	94400.00
FCF914	2017-07-11 05:19:00+03	141700.00
FCF960	2017-07-28 09:09:00+03	143100.00
FCF97A	2017-07-08 17:47:00+03	16400.00
FCF97C	2017-07-31 01:05:00+03	13700.00
FCF98E	2017-07-17 11:49:00+03	65200.00
FCF9AF	2017-07-20 21:22:00+03	93000.00
FCFA31	2017-07-13 17:37:00+03	21800.00
FCFAA3	2017-07-05 06:36:00+03	56000.00
FCFADD	2017-06-30 19:10:00+03	20200.00
FCFAFC	2017-07-05 21:05:00+03	191300.00
FCFB58	2017-07-17 06:13:00+03	270800.00
FCFB5D	2017-07-26 09:47:00+03	92700.00
FCFB7D	2017-07-09 05:55:00+03	62900.00
FCFB7E	2017-07-01 02:31:00+03	66600.00
FCFB86	2017-07-25 04:35:00+03	12600.00
FCFBA4	2017-07-23 13:56:00+03	17200.00
FCFBB0	2017-07-18 01:20:00+03	7400.00
FCFBC0	2017-07-21 10:14:00+03	24700.00
FCFBC3	2017-08-12 02:40:00+03	492000.00
FCFC07	2017-07-11 13:02:00+03	70800.00
FCFC2A	2017-07-11 19:36:00+03	55800.00
FCFC45	2017-07-09 01:01:00+03	35500.00
FCFCA5	2017-08-03 21:39:00+03	24800.00
FCFCC3	2017-07-31 11:02:00+03	28000.00
FCFCC4	2017-08-06 08:17:00+03	131100.00
FCFCCB	2017-08-08 03:01:00+03	23600.00
FCFCE8	2017-07-09 14:57:00+03	202100.00
FCFD05	2017-07-30 21:50:00+03	123000.00
FCFD35	2017-08-10 13:12:00+03	47800.00
FCFD64	2017-08-14 08:00:00+03	7400.00
FCFD8A	2017-07-31 18:10:00+03	61800.00
FCFD91	2017-07-02 15:26:00+03	131100.00
FCFD99	2017-08-14 12:22:00+03	124800.00
FCFD9B	2017-07-16 10:05:00+03	69500.00
FCFE04	2017-07-20 14:05:00+03	46400.00
FCFE14	2017-08-13 21:07:00+03	125400.00
FCFE59	2017-07-11 10:11:00+03	46300.00
FCFF05	2017-07-08 21:11:00+03	40800.00
FCFF06	2017-08-01 00:57:00+03	9200.00
FCFF10	2017-07-11 10:33:00+03	47700.00
FCFF2D	2017-08-11 01:46:00+03	13400.00
FCFF8B	2017-06-28 16:46:00+03	30800.00
FCFF9B	2017-07-14 15:07:00+03	23400.00
FCFFFD	2017-08-06 16:52:00+03	56000.00
FD0077	2017-07-21 00:30:00+03	80000.00
FD0091	2017-06-30 13:50:00+03	115600.00
FD0093	2017-08-12 20:23:00+03	37700.00
FD013E	2017-07-03 02:06:00+03	46400.00
FD014A	2017-08-14 14:52:00+03	85000.00
FD0185	2017-08-05 00:47:00+03	35300.00
FD01C4	2017-07-01 09:44:00+03	61500.00
FD01D2	2017-08-04 14:46:00+03	21400.00
FD01DD	2017-07-03 01:01:00+03	56600.00
FD0295	2017-07-15 04:12:00+03	96800.00
FD0302	2017-07-13 23:39:00+03	199200.00
FD0323	2017-08-14 16:23:00+03	91800.00
FD036E	2017-08-05 02:45:00+03	116700.00
FD038D	2017-07-17 09:51:00+03	51800.00
FD039F	2017-07-19 03:27:00+03	106400.00
FD03A7	2017-08-02 22:13:00+03	77800.00
FD03CF	2017-08-11 12:11:00+03	397700.00
FD03DA	2017-07-19 14:09:00+03	111600.00
FD03FD	2017-08-07 11:48:00+03	136000.00
FD043A	2017-07-03 20:58:00+03	147700.00
FD043F	2017-07-09 06:14:00+03	70700.00
FD0506	2017-07-28 11:43:00+03	99300.00
FD0515	2017-07-10 20:20:00+03	23200.00
FD0562	2017-08-12 05:31:00+03	86300.00
FD0565	2017-07-17 10:20:00+03	14400.00
FD05A0	2017-07-23 01:10:00+03	135000.00
FD063F	2017-07-04 18:42:00+03	154500.00
FD065D	2017-08-13 14:09:00+03	82900.00
FD06E1	2017-07-07 13:53:00+03	95100.00
FD070F	2017-07-19 10:29:00+03	26800.00
FD071B	2017-07-15 21:07:00+03	23600.00
FD07B0	2017-07-05 10:04:00+03	23200.00
FD07C2	2017-08-07 13:15:00+03	116400.00
FD082E	2017-07-26 00:19:00+03	75600.00
FD0836	2017-08-06 22:37:00+03	39300.00
FD087D	2017-06-27 09:32:00+03	37100.00
FD089F	2017-07-08 22:35:00+03	54100.00
FD08C8	2017-07-19 10:51:00+03	29200.00
FD097C	2017-07-29 00:19:00+03	54400.00
FD09E9	2017-06-30 06:02:00+03	16000.00
FD0A36	2017-07-20 14:23:00+03	6000.00
FD0A5B	2017-08-15 03:30:00+03	88600.00
FD0A93	2017-07-17 17:03:00+03	41600.00
FD0A99	2017-08-05 09:55:00+03	94100.00
FD0B43	2017-07-13 17:44:00+03	19600.00
FD0B7E	2017-08-11 23:43:00+03	24400.00
FD0BD3	2017-07-27 20:14:00+03	59300.00
FD0BD9	2017-07-05 17:55:00+03	46300.00
FD0BDA	2017-08-15 15:25:00+03	115900.00
FD0BFF	2017-08-14 04:25:00+03	105000.00
FD0C1B	2017-08-13 11:59:00+03	14400.00
FD0C7B	2017-08-11 22:45:00+03	131600.00
FD0CD5	2017-07-04 02:40:00+03	26000.00
FD0D47	2017-07-17 01:11:00+03	138900.00
FD0D48	2017-08-02 11:56:00+03	164400.00
FD0D67	2017-08-07 23:29:00+03	55800.00
FD0D79	2017-07-24 23:59:00+03	266400.00
FD0D7B	2017-07-16 23:03:00+03	69500.00
FD0D81	2017-07-14 20:53:00+03	39800.00
FD0D9C	2017-08-05 10:37:00+03	47400.00
FD0D9E	2017-07-27 15:51:00+03	20000.00
FD0DD9	2017-07-29 23:59:00+03	23900.00
FD0DE4	2017-08-04 16:38:00+03	49000.00
FD0E23	2017-08-11 19:31:00+03	81600.00
FD0E2D	2017-08-10 19:05:00+03	84500.00
FD0E36	2017-08-13 14:48:00+03	53600.00
FD0E3A	2017-07-09 07:20:00+03	46400.00
FD0E4D	2017-08-11 17:39:00+03	201200.00
FD0F7B	2017-07-31 03:12:00+03	75300.00
FD0FB2	2017-08-06 04:09:00+03	68400.00
FD0FD0	2017-07-31 17:39:00+03	40000.00
FD109C	2017-08-09 19:42:00+03	31600.00
FD10CA	2017-08-07 08:22:00+03	170200.00
FD111F	2017-08-04 14:26:00+03	31900.00
FD1145	2017-08-09 09:28:00+03	32500.00
FD1157	2017-08-11 17:00:00+03	23200.00
FD11CB	2017-08-12 18:31:00+03	25600.00
FD11CC	2017-07-11 12:14:00+03	36200.00
FD11EA	2017-07-27 20:28:00+03	48400.00
FD11FB	2017-07-29 05:23:00+03	55800.00
FD120D	2017-07-20 15:40:00+03	8000.00
FD12C6	2017-07-04 14:54:00+03	26800.00
FD1359	2017-07-18 08:12:00+03	18000.00
FD1381	2017-07-15 15:12:00+03	81700.00
FD1385	2017-07-17 03:02:00+03	75200.00
FD13C4	2017-07-05 13:32:00+03	92400.00
FD13CF	2017-07-20 21:46:00+03	387400.00
FD142D	2017-07-30 10:45:00+03	59300.00
FD1483	2017-08-04 16:53:00+03	129000.00
FD14A3	2017-07-24 20:44:00+03	31600.00
FD14F1	2017-08-13 18:25:00+03	82000.00
FD1537	2017-07-26 10:31:00+03	88100.00
FD154D	2017-07-16 20:11:00+03	14400.00
FD1592	2017-07-11 16:37:00+03	81300.00
FD1610	2017-07-01 18:25:00+03	70500.00
FD164A	2017-07-13 16:20:00+03	23400.00
FD16FD	2017-07-29 04:58:00+03	70700.00
FD1715	2017-07-11 12:15:00+03	59000.00
FD1778	2017-08-13 21:22:00+03	54500.00
FD177C	2017-07-25 16:30:00+03	57500.00
FD1781	2017-08-03 17:19:00+03	55900.00
FD17B2	2017-07-06 13:52:00+03	178800.00
FD1828	2017-08-12 15:45:00+03	63300.00
FD182F	2017-08-03 21:38:00+03	37100.00
FD18BA	2017-07-27 09:04:00+03	175200.00
FD1913	2017-07-03 20:14:00+03	81600.00
FD193E	2017-08-04 06:42:00+03	24200.00
FD19A0	2017-08-14 19:11:00+03	70200.00
FD19BB	2017-08-08 17:35:00+03	185600.00
FD1A0D	2017-07-02 16:10:00+03	40900.00
FD1ACB	2017-07-21 17:07:00+03	28000.00
FD1AFB	2017-07-21 10:02:00+03	257600.00
FD1BB6	2017-08-08 03:15:00+03	37400.00
FD1BC1	2017-07-22 09:24:00+03	88600.00
FD1D17	2017-08-03 19:52:00+03	26800.00
FD1D31	2017-07-08 05:28:00+03	11800.00
FD1DDB	2017-07-14 18:38:00+03	135100.00
FD1E53	2017-07-09 18:14:00+03	13600.00
FD1ECE	2017-07-13 10:25:00+03	32700.00
FD1EFF	2017-08-12 02:07:00+03	227400.00
FD1F1F	2017-07-19 17:22:00+03	18000.00
FD1F7A	2017-07-09 22:05:00+03	26700.00
FD2020	2017-08-05 12:19:00+03	23600.00
FD2030	2017-08-08 12:31:00+03	42700.00
FD2039	2017-07-19 03:32:00+03	36200.00
FD206F	2017-07-20 18:31:00+03	132800.00
FD2077	2017-07-09 20:11:00+03	30200.00
FD208A	2017-07-11 06:41:00+03	56000.00
FD2095	2017-08-14 23:44:00+03	38600.00
FD20BC	2017-07-05 12:26:00+03	57400.00
FD20CB	2017-07-25 07:08:00+03	23400.00
FD20D8	2017-08-10 18:06:00+03	133200.00
FD2104	2017-08-14 21:27:00+03	32800.00
FD2106	2017-08-14 18:16:00+03	189200.00
FD217C	2017-08-06 07:50:00+03	94000.00
FD21D5	2017-07-04 04:16:00+03	86300.00
FD220F	2017-08-14 19:32:00+03	83200.00
FD2219	2017-07-18 11:16:00+03	39500.00
FD221C	2017-07-31 19:00:00+03	44000.00
FD22AA	2017-07-29 14:59:00+03	102100.00
FD22D0	2017-07-26 17:49:00+03	38800.00
FD22D8	2017-08-01 07:20:00+03	73200.00
FD22DE	2017-07-07 09:38:00+03	20000.00
FD2335	2017-08-07 03:13:00+03	39300.00
FD23D9	2017-07-25 05:03:00+03	38600.00
FD2457	2017-08-15 15:51:00+03	56000.00
FD24D8	2017-08-11 05:31:00+03	40800.00
FD250F	2017-07-13 01:50:00+03	186900.00
FD2552	2017-07-12 01:57:00+03	6000.00
FD2589	2017-07-03 10:48:00+03	245800.00
FD258D	2017-08-11 16:36:00+03	18600.00
FD25A9	2017-07-31 01:35:00+03	93900.00
FD25DC	2017-08-08 17:35:00+03	114700.00
FD2684	2017-07-08 16:11:00+03	283100.00
FD2707	2017-07-24 23:49:00+03	65900.00
FD2731	2017-07-01 00:48:00+03	62200.00
FD2750	2017-07-28 13:33:00+03	142800.00
FD2772	2017-07-25 10:31:00+03	86600.00
FD27DB	2017-07-07 07:33:00+03	100600.00
FD2875	2017-08-04 07:59:00+03	40600.00
FD28C2	2017-07-03 03:55:00+03	201200.00
FD28DD	2017-08-09 13:30:00+03	44800.00
FD28EE	2017-08-09 10:02:00+03	99200.00
FD28FD	2017-08-14 02:57:00+03	44500.00
FD2901	2017-07-22 01:34:00+03	14400.00
FD2950	2017-07-18 14:38:00+03	135400.00
FD2981	2017-07-11 12:05:00+03	36800.00
FD29A1	2017-07-18 22:45:00+03	48400.00
FD29B2	2017-07-30 10:22:00+03	142800.00
FD29BE	2017-08-10 07:08:00+03	32200.00
FD2A00	2017-07-05 22:03:00+03	73500.00
FD2A5B	2017-07-28 02:25:00+03	35800.00
FD2A82	2017-07-08 02:42:00+03	31900.00
FD2A89	2017-08-08 13:28:00+03	18400.00
FD2A90	2017-07-07 10:50:00+03	27200.00
FD2A9D	2017-07-09 14:07:00+03	6700.00
FD2AB7	2017-07-20 18:31:00+03	135600.00
FD2AF5	2017-07-16 17:31:00+03	265800.00
FD2B5A	2017-08-14 11:46:00+03	113700.00
FD2BB8	2017-08-07 06:30:00+03	284400.00
FD2BD8	2017-08-06 11:51:00+03	59100.00
FD2C17	2017-07-07 05:23:00+03	44000.00
FD2C55	2017-08-07 15:45:00+03	180100.00
FD2C8B	2017-07-31 03:35:00+03	52000.00
FD2C99	2017-07-12 04:13:00+03	57800.00
FD2CB8	2017-07-04 03:40:00+03	87300.00
FD2CBD	2017-07-29 15:25:00+03	101200.00
FD2D26	2017-07-31 06:26:00+03	151200.00
FD2D5C	2017-07-07 04:11:00+03	99300.00
FD2DA6	2017-07-29 14:26:00+03	35200.00
FD2E35	2017-07-14 15:15:00+03	284400.00
FD2E4A	2017-07-31 03:40:00+03	44600.00
FD2E80	2017-07-01 01:36:00+03	23200.00
FD2E96	2017-07-20 13:28:00+03	12100.00
FD2EAE	2017-08-03 09:03:00+03	13400.00
FD2EC5	2017-07-23 15:29:00+03	24400.00
FD2ED4	2017-07-03 13:55:00+03	14000.00
FD2EF1	2017-07-08 08:42:00+03	28800.00
FD2F05	2017-07-19 23:55:00+03	8000.00
FD2F71	2017-07-15 18:49:00+03	45200.00
FD2F78	2017-07-26 19:07:00+03	46400.00
FD2F80	2017-07-06 17:10:00+03	30400.00
FD301D	2017-07-12 08:05:00+03	65900.00
FD303A	2017-08-14 15:12:00+03	102900.00
FD3071	2017-07-12 07:31:00+03	193100.00
FD3077	2017-08-08 10:36:00+03	111600.00
FD30B3	2017-08-08 02:43:00+03	28000.00
FD30E0	2017-08-13 04:38:00+03	51600.00
FD30F5	2017-07-10 04:27:00+03	120600.00
FD30FF	2017-06-29 05:35:00+03	201200.00
FD311C	2017-08-03 18:50:00+03	111700.00
FD31E0	2017-07-16 23:50:00+03	16800.00
FD3216	2017-07-01 23:01:00+03	33100.00
FD325A	2017-07-28 15:52:00+03	26700.00
FD32BD	2017-07-12 08:13:00+03	162800.00
FD3301	2017-08-05 13:09:00+03	40000.00
FD33F1	2017-07-05 04:11:00+03	31000.00
FD341C	2017-07-31 01:14:00+03	99600.00
FD3461	2017-07-26 00:39:00+03	73600.00
FD34B8	2017-08-06 11:57:00+03	137600.00
FD34E0	2017-07-10 22:31:00+03	12600.00
FD34EA	2017-07-13 12:43:00+03	14400.00
FD34F5	2017-08-01 10:19:00+03	260900.00
FD34FB	2017-07-05 07:27:00+03	46300.00
FD3504	2017-07-14 06:51:00+03	47400.00
FD35A0	2017-07-31 01:33:00+03	62900.00
FD35A1	2017-07-06 15:33:00+03	26000.00
FD35B5	2017-07-02 09:36:00+03	23400.00
FD3623	2017-07-08 09:13:00+03	46400.00
FD364C	2017-07-13 21:46:00+03	47100.00
FD3665	2017-07-17 13:50:00+03	73600.00
FD36B1	2017-08-13 10:13:00+03	168000.00
FD3710	2017-07-11 09:30:00+03	87200.00
FD374D	2017-07-07 06:39:00+03	302300.00
FD3766	2017-07-17 16:07:00+03	213200.00
FD3831	2017-07-29 21:47:00+03	38800.00
FD3844	2017-06-30 08:27:00+03	6600.00
FD386B	2017-08-12 21:22:00+03	102100.00
FD38D2	2017-07-08 16:21:00+03	21400.00
FD3903	2017-08-11 18:36:00+03	6600.00
FD3926	2017-08-05 16:50:00+03	44800.00
FD3930	2017-08-13 21:40:00+03	273000.00
FD3935	2017-07-18 17:45:00+03	20800.00
FD397F	2017-07-08 09:17:00+03	23200.00
FD39AC	2017-07-18 10:43:00+03	24400.00
FD39B3	2017-07-07 00:41:00+03	234600.00
FD39C2	2017-07-28 02:59:00+03	28000.00
FD3AFD	2017-07-29 14:31:00+03	26200.00
FD3B04	2017-08-08 17:16:00+03	30200.00
FD3B46	2017-07-07 22:24:00+03	42800.00
FD3B59	2017-08-13 08:28:00+03	32200.00
FD3B5D	2017-07-09 20:55:00+03	272000.00
FD3BA2	2017-07-08 00:11:00+03	56900.00
FD3BFE	2017-08-09 20:44:00+03	119500.00
FD3C1C	2017-07-31 10:53:00+03	6800.00
FD3C31	2017-07-30 22:04:00+03	47000.00
FD3C4F	2017-07-10 19:45:00+03	53300.00
FD3C93	2017-08-10 07:21:00+03	56000.00
FD3CA2	2017-08-14 11:30:00+03	22600.00
FD3CDE	2017-08-09 05:41:00+03	82900.00
FD3CFA	2017-07-18 04:46:00+03	111400.00
FD3D6C	2017-06-27 22:45:00+03	57600.00
FD3DA5	2017-08-03 23:47:00+03	57500.00
FD3DAE	2017-07-22 04:11:00+03	23600.00
FD3DE0	2017-08-01 10:18:00+03	132800.00
FD3E0B	2017-07-09 22:23:00+03	131100.00
FD3E2B	2017-07-30 22:14:00+03	52000.00
FD3F68	2017-07-15 02:16:00+03	7400.00
FD3F87	2017-07-05 20:35:00+03	34000.00
FD402A	2017-06-29 07:55:00+03	6000.00
FD4032	2017-08-12 14:26:00+03	90400.00
FD4033	2017-07-05 21:04:00+03	133200.00
FD4046	2017-08-12 16:43:00+03	16400.00
FD4062	2017-07-24 07:58:00+03	100600.00
FD4126	2017-07-26 23:09:00+03	81700.00
FD41B3	2017-07-31 11:08:00+03	139400.00
FD4242	2017-07-04 12:30:00+03	72400.00
FD4269	2017-07-09 05:33:00+03	123000.00
FD42A9	2017-07-13 09:59:00+03	260300.00
FD4335	2017-06-29 11:50:00+03	73200.00
FD434E	2017-07-30 04:02:00+03	321300.00
FD43D0	2017-06-24 15:37:00+03	64100.00
FD448E	2017-07-13 07:16:00+03	48800.00
FD44A0	2017-07-27 01:00:00+03	224000.00
FD4562	2017-08-03 18:46:00+03	43200.00
FD45CF	2017-07-15 21:15:00+03	191200.00
FD45D7	2017-07-08 12:28:00+03	57500.00
FD4650	2017-07-08 10:07:00+03	61500.00
FD4673	2017-07-23 11:42:00+03	62800.00
FD4677	2017-07-10 17:34:00+03	87400.00
FD46AF	2017-08-01 01:22:00+03	112000.00
FD46EF	2017-06-29 00:47:00+03	176800.00
FD4701	2017-07-19 21:42:00+03	142800.00
FD4839	2017-08-11 13:25:00+03	26200.00
FD487C	2017-08-11 10:07:00+03	55800.00
FD4887	2017-08-10 15:23:00+03	161800.00
FD48A2	2017-06-30 16:55:00+03	26700.00
FD4912	2017-08-02 04:16:00+03	126900.00
FD49AF	2017-07-13 17:26:00+03	31000.00
FD4A0B	2017-07-05 07:28:00+03	147900.00
FD4A23	2017-08-03 01:25:00+03	8000.00
FD4A48	2017-08-01 19:47:00+03	39000.00
FD4A76	2017-07-23 19:39:00+03	16400.00
FD4AA2	2017-07-02 16:31:00+03	135400.00
FD4AE5	2017-07-23 20:28:00+03	84500.00
FD4AE9	2017-08-12 13:17:00+03	306600.00
FD4B04	2017-08-12 15:36:00+03	325500.00
FD4B1E	2017-07-22 17:37:00+03	65100.00
FD4B65	2017-07-01 17:11:00+03	15700.00
FD4B90	2017-07-27 08:23:00+03	28800.00
FD4BBA	2017-08-07 10:45:00+03	27400.00
FD4BDE	2017-08-09 12:18:00+03	75300.00
FD4BE4	2017-08-15 08:32:00+03	28000.00
FD4C05	2017-08-13 01:47:00+03	49100.00
FD4C09	2017-08-09 20:52:00+03	98400.00
FD4C15	2017-07-30 11:57:00+03	123000.00
FD4C2E	2017-07-13 19:46:00+03	43500.00
FD4C37	2017-07-28 13:09:00+03	246400.00
FD4C38	2017-07-22 12:25:00+03	51600.00
FD4C3D	2017-08-13 03:57:00+03	65900.00
FD4C71	2017-07-29 13:34:00+03	22000.00
FD4C77	2017-07-09 16:30:00+03	106900.00
FD4C82	2017-08-07 21:03:00+03	11000.00
FD4CCC	2017-07-06 04:04:00+03	219400.00
FD4D2D	2017-07-17 11:39:00+03	143000.00
FD4DCE	2017-07-18 03:45:00+03	23400.00
FD4DD3	2017-07-18 23:38:00+03	12600.00
FD4DD8	2017-07-28 05:49:00+03	55800.00
FD4DEB	2017-07-14 22:19:00+03	77900.00
FD4DF9	2017-07-17 19:53:00+03	46400.00
FD4E06	2017-07-18 08:07:00+03	47000.00
FD4E87	2017-08-06 22:12:00+03	120400.00
FD4EB1	2017-07-23 04:03:00+03	22000.00
FD4F16	2017-07-16 02:02:00+03	61800.00
FD4F54	2017-07-19 03:27:00+03	29200.00
FD4F58	2017-07-12 20:21:00+03	6000.00
FD4FE9	2017-07-27 02:58:00+03	43700.00
FD4FEF	2017-06-30 22:58:00+03	67400.00
FD4FF6	2017-08-04 10:03:00+03	55800.00
FD503B	2017-08-07 03:39:00+03	108500.00
FD5051	2017-07-17 22:15:00+03	63700.00
FD5091	2017-07-22 06:06:00+03	111600.00
FD5170	2017-07-18 06:17:00+03	67600.00
FD51DB	2017-07-18 02:03:00+03	14400.00
FD51EA	2017-07-29 19:41:00+03	31600.00
FD527C	2017-07-30 08:16:00+03	11600.00
FD52D8	2017-07-31 21:06:00+03	99300.00
FD52E0	2017-08-06 21:14:00+03	66200.00
FD52FC	2017-07-21 00:17:00+03	409400.00
FD5353	2017-08-12 07:17:00+03	26000.00
FD5368	2017-08-02 03:19:00+03	31600.00
FD542D	2017-08-10 10:45:00+03	62800.00
FD5467	2017-07-07 21:05:00+03	198400.00
FD5476	2017-07-30 19:43:00+03	29500.00
FD548D	2017-08-02 19:45:00+03	67800.00
FD54A2	2017-07-17 10:43:00+03	88900.00
FD54B1	2017-08-01 14:34:00+03	56600.00
FD5502	2017-07-05 01:05:00+03	31600.00
FD550C	2017-07-17 09:24:00+03	21800.00
FD553D	2017-07-10 02:57:00+03	81700.00
FD559C	2017-07-04 04:08:00+03	30000.00
FD563A	2017-07-11 14:15:00+03	139400.00
FD5671	2017-07-10 18:40:00+03	25200.00
FD56A3	2017-07-23 10:25:00+03	54500.00
FD571F	2017-07-25 16:11:00+03	129800.00
FD5744	2017-07-01 17:32:00+03	206800.00
FD5761	2017-08-09 05:18:00+03	74000.00
FD5774	2017-08-05 17:53:00+03	17600.00
FD57E8	2017-07-02 20:10:00+03	57800.00
FD587D	2017-07-03 05:50:00+03	185300.00
FD592B	2017-08-15 11:35:00+03	62900.00
FD5981	2017-07-15 11:24:00+03	24300.00
FD598E	2017-08-06 23:05:00+03	12600.00
FD598F	2017-07-05 22:55:00+03	235200.00
FD59BA	2017-07-07 21:20:00+03	135600.00
FD5A0A	2017-07-20 12:20:00+03	228500.00
FD5A2F	2017-08-09 04:00:00+03	15400.00
FD5AB1	2017-08-08 22:23:00+03	246000.00
FD5AD1	2017-08-03 00:55:00+03	56000.00
FD5B2F	2017-08-03 17:20:00+03	133200.00
FD5BFC	2017-07-13 17:12:00+03	67300.00
FD5C4D	2017-07-24 21:26:00+03	73500.00
FD5C8F	2017-07-04 19:50:00+03	90500.00
FD5CA9	2017-07-10 19:56:00+03	40200.00
FD5CC9	2017-07-08 19:49:00+03	24800.00
FD5D99	2017-07-30 04:32:00+03	26200.00
FD5DE0	2017-07-30 06:54:00+03	25800.00
FD5E35	2017-08-09 04:42:00+03	34000.00
FD5E4B	2017-08-09 12:25:00+03	114700.00
FD5E60	2017-08-08 20:57:00+03	112000.00
FD5E8B	2017-07-19 00:10:00+03	37200.00
FD5E8F	2017-07-02 11:58:00+03	45200.00
FD5ED1	2017-07-02 21:12:00+03	68800.00
FD5EDE	2017-07-13 01:43:00+03	49400.00
FD5F26	2017-07-31 09:02:00+03	72400.00
FD5F61	2017-08-03 02:22:00+03	99200.00
FD5F71	2017-08-03 19:12:00+03	59300.00
FD5F78	2017-07-31 17:48:00+03	193700.00
FD5F8F	2017-08-02 16:41:00+03	43200.00
FD5FA1	2017-07-17 19:57:00+03	194300.00
FD6037	2017-07-24 15:05:00+03	188000.00
FD6069	2017-07-01 14:23:00+03	64500.00
FD608F	2017-08-10 07:21:00+03	24700.00
FD609D	2017-08-09 13:31:00+03	38800.00
FD60AB	2017-07-14 09:00:00+03	44500.00
FD60CB	2017-07-09 05:57:00+03	23400.00
FD60D0	2017-08-09 11:17:00+03	65800.00
FD621D	2017-08-13 03:39:00+03	148400.00
FD62A1	2017-07-27 10:11:00+03	123000.00
FD6317	2017-08-07 10:05:00+03	31600.00
FD6322	2017-07-26 22:32:00+03	26800.00
FD63CB	2017-08-10 04:31:00+03	115600.00
FD6401	2017-07-18 19:37:00+03	24400.00
FD6414	2017-08-01 04:45:00+03	50800.00
FD6448	2017-08-02 00:34:00+03	22000.00
FD6461	2017-07-18 03:51:00+03	169900.00
FD651B	2017-07-04 02:48:00+03	86300.00
FD6523	2017-07-15 22:49:00+03	81200.00
FD652A	2017-07-12 00:15:00+03	31400.00
FD6538	2017-07-02 09:52:00+03	23200.00
FD6545	2017-08-04 17:36:00+03	102300.00
FD6562	2017-07-14 05:53:00+03	58700.00
FD659E	2017-07-28 09:13:00+03	58600.00
FD65EC	2017-07-18 00:35:00+03	24700.00
FD65FD	2017-07-28 15:31:00+03	93600.00
FD6651	2017-07-11 09:23:00+03	22000.00
FD666F	2017-08-01 20:51:00+03	62600.00
FD670B	2017-08-10 03:37:00+03	53800.00
FD6749	2017-08-06 19:05:00+03	46000.00
FD67C4	2017-07-03 15:10:00+03	55100.00
FD67F6	2017-07-10 09:46:00+03	288200.00
FD6834	2017-08-07 20:26:00+03	281500.00
FD683E	2017-07-24 15:49:00+03	278600.00
FD6845	2017-06-27 03:28:00+03	99200.00
FD6865	2017-08-11 07:54:00+03	105800.00
FD68BB	2017-08-11 11:53:00+03	96500.00
FD68FC	2017-07-03 09:59:00+03	57600.00
FD6983	2017-07-25 05:17:00+03	46800.00
FD69B5	2017-07-07 07:45:00+03	92700.00
FD69DD	2017-07-18 11:54:00+03	260300.00
FD69F5	2017-07-20 05:21:00+03	6700.00
FD6A31	2017-07-03 14:36:00+03	396400.00
FD6A85	2017-08-02 14:51:00+03	29600.00
FD6AAA	2017-07-01 13:31:00+03	100600.00
FD6ACD	2017-08-11 04:05:00+03	23600.00
FD6AD9	2017-07-05 05:57:00+03	46200.00
FD6BEC	2017-07-12 16:16:00+03	40600.00
FD6C01	2017-07-27 16:50:00+03	25800.00
FD6C95	2017-08-02 03:57:00+03	57400.00
FD6CB7	2017-08-09 06:59:00+03	100200.00
FD6D3A	2017-07-14 20:38:00+03	75600.00
FD6D44	2017-06-30 18:03:00+03	248400.00
FD6D56	2017-07-31 03:05:00+03	289600.00
FD6DC1	2017-08-09 15:52:00+03	100600.00
FD6E0E	2017-07-02 12:24:00+03	57500.00
FD6E2A	2017-08-12 09:14:00+03	37200.00
FD6E7A	2017-07-08 06:55:00+03	46300.00
FD6ECC	2017-08-03 07:33:00+03	56100.00
FD6ECE	2017-07-13 06:21:00+03	6000.00
FD6F07	2017-07-01 03:54:00+03	10800.00
FD6F45	2017-07-06 02:01:00+03	40000.00
FD6FEB	2017-06-28 00:04:00+03	23600.00
FD703F	2017-07-23 20:42:00+03	70500.00
FD7061	2017-07-04 11:09:00+03	21800.00
FD70B8	2017-07-06 18:35:00+03	111600.00
FD70C3	2017-06-26 15:13:00+03	99200.00
FD7197	2017-07-10 20:38:00+03	42400.00
FD71B2	2017-07-05 10:30:00+03	7400.00
FD71BA	2017-07-11 19:47:00+03	87700.00
FD71BD	2017-07-06 05:59:00+03	47800.00
FD71C3	2017-08-05 09:52:00+03	16400.00
FD71DD	2017-07-01 03:11:00+03	31600.00
FD72BD	2017-08-11 23:42:00+03	42400.00
FD72C1	2017-07-14 07:21:00+03	114300.00
FD7349	2017-07-25 17:18:00+03	28800.00
FD73DD	2017-07-29 06:28:00+03	38800.00
FD7467	2017-07-25 05:09:00+03	112000.00
FD7503	2017-07-11 20:15:00+03	47100.00
FD750C	2017-07-03 16:54:00+03	64100.00
FD7511	2017-08-15 09:20:00+03	70100.00
FD751D	2017-07-13 14:59:00+03	86800.00
FD752F	2017-07-10 15:40:00+03	17200.00
FD754E	2017-07-19 06:37:00+03	69500.00
FD75B6	2017-08-10 00:35:00+03	27800.00
FD75C4	2017-08-13 15:02:00+03	51800.00
FD75FC	2017-06-30 14:55:00+03	74800.00
FD76D7	2017-07-12 22:34:00+03	119600.00
FD76DF	2017-07-24 21:39:00+03	72200.00
FD76E5	2017-08-01 01:57:00+03	46300.00
FD76EA	2017-08-15 04:18:00+03	16400.00
FD771D	2017-07-28 07:47:00+03	89700.00
FD777D	2017-07-25 14:06:00+03	23400.00
FD77E2	2017-07-15 01:46:00+03	57500.00
FD784D	2017-07-16 17:55:00+03	6700.00
FD787D	2017-07-06 01:15:00+03	99200.00
FD78A6	2017-07-17 19:54:00+03	52000.00
FD78AC	2017-07-28 12:14:00+03	39900.00
FD78C1	2017-06-26 07:14:00+03	50200.00
FD7962	2017-08-06 22:36:00+03	12400.00
FD7991	2017-08-03 15:13:00+03	40000.00
FD79FD	2017-07-22 09:13:00+03	142800.00
FD7A1E	2017-08-04 08:55:00+03	55800.00
FD7A63	2017-07-25 13:31:00+03	78600.00
FD7AA8	2017-07-29 20:21:00+03	118400.00
FD7AFA	2017-07-09 07:02:00+03	58600.00
FD7B15	2017-07-25 04:41:00+03	26000.00
FD7B3D	2017-07-20 01:14:00+03	84200.00
FD7B8A	2017-07-18 03:36:00+03	170800.00
FD7BB1	2017-07-12 04:44:00+03	76900.00
FD7D11	2017-08-15 02:10:00+03	108900.00
FD7D42	2017-07-27 22:49:00+03	12600.00
FD7E39	2017-07-14 16:05:00+03	409100.00
FD7ED0	2017-07-26 03:22:00+03	198900.00
FD7F24	2017-06-27 19:54:00+03	50800.00
FD7F25	2017-08-15 16:11:00+03	135400.00
FD7F3E	2017-08-13 09:13:00+03	255600.00
FD7F5A	2017-07-15 17:57:00+03	44800.00
FD7F6E	2017-07-21 06:37:00+03	3700.00
FD7F8D	2017-08-10 05:30:00+03	131000.00
FD7F96	2017-07-09 05:21:00+03	136800.00
FD7F99	2017-07-13 20:06:00+03	23200.00
FD7FCA	2017-07-30 21:10:00+03	23200.00
FD8069	2017-08-13 11:47:00+03	92800.00
FD806D	2017-07-11 10:11:00+03	135400.00
FD808D	2017-07-14 11:54:00+03	49900.00
FD80EE	2017-08-06 16:25:00+03	93900.00
FD8103	2017-07-14 12:12:00+03	228900.00
FD811B	2017-07-25 02:52:00+03	34000.00
FD8158	2017-07-30 22:23:00+03	135400.00
FD8189	2017-07-01 06:26:00+03	137100.00
FD8225	2017-07-11 10:50:00+03	13400.00
FD823F	2017-07-17 08:02:00+03	14800.00
FD8270	2017-08-06 00:05:00+03	86300.00
FD82CD	2017-07-22 23:35:00+03	27500.00
FD8386	2017-07-16 07:32:00+03	101200.00
FD83C9	2017-08-04 18:13:00+03	246000.00
FD83CB	2017-07-12 10:33:00+03	31700.00
FD83DF	2017-07-02 16:01:00+03	18600.00
FD843E	2017-06-26 07:54:00+03	664300.00
FD8443	2017-07-16 19:09:00+03	28000.00
FD84A0	2017-08-12 07:12:00+03	26800.00
FD84F1	2017-08-03 18:58:00+03	38800.00
FD84FF	2017-07-02 14:33:00+03	106600.00
FD8535	2017-07-23 23:32:00+03	113600.00
FD853B	2017-08-03 09:51:00+03	131200.00
FD854D	2017-07-11 09:54:00+03	56000.00
FD8550	2017-07-28 11:25:00+03	225800.00
FD8582	2017-08-06 08:06:00+03	36700.00
FD8583	2017-08-04 07:24:00+03	14000.00
FD8611	2017-07-19 11:26:00+03	218000.00
FD8617	2017-07-05 08:51:00+03	55800.00
FD862F	2017-07-21 13:09:00+03	44000.00
FD866D	2017-08-14 06:26:00+03	123000.00
FD86D2	2017-07-13 20:46:00+03	27200.00
FD86F5	2017-07-10 15:27:00+03	19600.00
FD8739	2017-07-30 19:47:00+03	11800.00
FD873A	2017-07-26 23:51:00+03	52700.00
FD878A	2017-07-04 10:24:00+03	22000.00
FD8806	2017-07-07 08:06:00+03	106800.00
FD885B	2017-07-01 18:39:00+03	14400.00
FD8896	2017-07-01 07:52:00+03	86300.00
FD8911	2017-07-10 10:25:00+03	31000.00
FD891C	2017-08-02 19:18:00+03	67600.00
FD8927	2017-07-03 04:58:00+03	43400.00
FD89E5	2017-07-20 17:08:00+03	68400.00
FD89EA	2017-08-15 07:00:00+03	189200.00
FD8A09	2017-07-23 12:01:00+03	37700.00
FD8A71	2017-08-14 23:08:00+03	46400.00
FD8A79	2017-07-18 12:42:00+03	46000.00
FD8A83	2017-08-15 13:16:00+03	21200.00
FD8AFA	2017-07-17 03:48:00+03	67900.00
FD8B1E	2017-07-13 04:13:00+03	61700.00
FD8B2E	2017-07-06 01:37:00+03	55800.00
FD8BDA	2017-08-13 12:05:00+03	54400.00
FD8C91	2017-07-21 03:14:00+03	119500.00
FD8CA7	2017-07-31 18:50:00+03	94000.00
FD8CC8	2017-07-15 19:46:00+03	53300.00
FD8CD2	2017-07-17 02:39:00+03	39300.00
FD8D49	2017-08-15 02:08:00+03	40800.00
FD8D4F	2017-06-26 06:46:00+03	194000.00
FD8DC4	2017-07-29 06:24:00+03	50100.00
FD8DDC	2017-08-06 03:44:00+03	51800.00
FD8DDD	2017-08-05 23:48:00+03	40600.00
FD8DE2	2017-07-15 13:05:00+03	39200.00
FD8E0F	2017-07-24 05:48:00+03	62800.00
FD8E67	2017-07-08 00:21:00+03	135600.00
FD8ED4	2017-07-16 09:44:00+03	59400.00
FD8EDF	2017-07-29 00:54:00+03	242200.00
FD8F78	2017-08-13 10:28:00+03	24400.00
FD9074	2017-07-28 04:03:00+03	56000.00
FD9092	2017-07-24 07:08:00+03	97800.00
FD909A	2017-07-02 02:44:00+03	92800.00
FD90A1	2017-07-29 10:14:00+03	12600.00
FD90BF	2017-07-03 21:49:00+03	118000.00
FD90E2	2017-08-07 10:50:00+03	117200.00
FD9109	2017-07-07 20:23:00+03	21800.00
FD91A3	2017-07-04 23:23:00+03	20200.00
FD920A	2017-06-29 11:08:00+03	68900.00
FD921E	2017-08-04 01:03:00+03	135400.00
FD9250	2017-07-16 13:13:00+03	46500.00
FD9260	2017-07-24 11:12:00+03	232000.00
FD92A1	2017-07-16 10:32:00+03	134800.00
FD92A8	2017-07-22 15:15:00+03	201200.00
FD9311	2017-07-13 00:19:00+03	114400.00
FD93BD	2017-07-10 09:29:00+03	58000.00
FD93FF	2017-08-14 00:52:00+03	46400.00
FD941A	2017-06-29 20:25:00+03	36200.00
FD9433	2017-07-11 16:22:00+03	344100.00
FD943D	2017-07-26 10:38:00+03	47400.00
FD943E	2017-08-08 01:27:00+03	86800.00
FD9468	2017-08-05 05:18:00+03	67600.00
FD94C7	2017-08-08 11:45:00+03	24400.00
FD956D	2017-07-24 15:56:00+03	97900.00
FD9618	2017-08-15 07:22:00+03	27200.00
FD961F	2017-07-26 01:22:00+03	234300.00
FD9632	2017-06-30 19:18:00+03	66600.00
FD9642	2017-08-14 14:08:00+03	56000.00
FD9657	2017-07-08 05:47:00+03	402400.00
FD9731	2017-07-04 10:33:00+03	77000.00
FD973B	2017-07-31 12:20:00+03	125200.00
FD9751	2017-07-08 10:09:00+03	273000.00
FD976D	2017-07-16 18:00:00+03	29000.00
FD98D3	2017-07-22 10:34:00+03	265600.00
FD9906	2017-07-24 14:27:00+03	22000.00
FD9933	2017-07-29 07:53:00+03	135400.00
FD9975	2017-08-12 00:23:00+03	16100.00
FD9A7E	2017-08-12 04:57:00+03	155600.00
FD9AC1	2017-07-03 06:08:00+03	30200.00
FD9B82	2017-07-17 18:01:00+03	39800.00
FD9BAC	2017-08-11 20:26:00+03	16400.00
FD9BD3	2017-06-28 05:12:00+03	235800.00
FD9C26	2017-07-14 16:04:00+03	67600.00
FD9CA5	2017-07-01 16:34:00+03	28700.00
FD9CCD	2017-07-03 14:58:00+03	65900.00
FD9CD5	2017-07-19 07:49:00+03	314600.00
FD9D3A	2017-07-16 16:25:00+03	23200.00
FD9D41	2017-07-24 23:28:00+03	99200.00
FD9D47	2017-07-20 19:44:00+03	13600.00
FD9D5A	2017-07-19 11:07:00+03	12600.00
FD9D63	2017-07-07 16:37:00+03	98400.00
FD9D9E	2017-07-18 15:33:00+03	71900.00
FD9E62	2017-07-14 08:13:00+03	103800.00
FD9EAC	2017-07-15 10:07:00+03	41200.00
FD9ED7	2017-07-06 17:24:00+03	133200.00
FD9F35	2017-07-28 01:15:00+03	111000.00
FD9F7C	2017-07-10 15:12:00+03	128800.00
FD9F8C	2017-07-29 19:11:00+03	87700.00
FD9F8D	2017-08-02 16:57:00+03	55800.00
FD9F90	2017-07-20 09:24:00+03	40800.00
FD9F93	2017-08-05 08:27:00+03	40800.00
FD9FAC	2017-08-13 21:34:00+03	135000.00
FDA04F	2017-08-09 22:10:00+03	24400.00
FDA05A	2017-07-07 22:48:00+03	21200.00
FDA09C	2017-07-16 17:11:00+03	78500.00
FDA0AB	2017-08-12 07:37:00+03	27900.00
FDA0AC	2017-08-06 08:57:00+03	57400.00
FDA100	2017-08-02 13:53:00+03	182300.00
FDA1C0	2017-07-24 09:33:00+03	135400.00
FDA27A	2017-07-03 20:36:00+03	64200.00
FDA29B	2017-07-19 04:58:00+03	47000.00
FDA2B5	2017-07-05 19:12:00+03	64500.00
FDA347	2017-08-07 14:52:00+03	7200.00
FDA36C	2017-07-19 22:17:00+03	98400.00
FDA3B0	2017-07-06 15:46:00+03	9800.00
FDA41E	2017-07-30 11:12:00+03	68100.00
FDA483	2017-07-08 00:20:00+03	156300.00
FDA4AA	2017-07-14 05:41:00+03	153900.00
FDA4D3	2017-07-04 12:12:00+03	114600.00
FDA57E	2017-07-16 02:33:00+03	51900.00
FDA589	2017-08-09 14:59:00+03	124200.00
FDA592	2017-07-13 06:22:00+03	123000.00
FDA5D9	2017-08-02 00:49:00+03	66400.00
FDA62A	2017-07-23 03:51:00+03	18400.00
FDA654	2017-08-15 02:50:00+03	65900.00
FDA6AD	2017-08-10 18:18:00+03	135200.00
FDA6D7	2017-07-11 15:40:00+03	22000.00
FDA75C	2017-08-03 06:07:00+03	35300.00
FDA785	2017-07-22 20:10:00+03	37600.00
FDA7F4	2017-07-20 09:45:00+03	46700.00
FDA86D	2017-07-29 03:46:00+03	69600.00
FDA8B8	2017-08-04 00:31:00+03	7400.00
FDA8FD	2017-08-15 02:08:00+03	62000.00
FDA975	2017-08-02 04:07:00+03	65400.00
FDA980	2017-07-25 11:40:00+03	79800.00
FDA9CF	2017-07-07 12:50:00+03	83000.00
FDA9DA	2017-08-03 19:10:00+03	35700.00
FDAA5B	2017-08-12 04:53:00+03	38400.00
FDAA5C	2017-07-27 12:32:00+03	66600.00
FDAA6F	2017-07-24 15:03:00+03	34000.00
FDAAD6	2017-08-10 08:49:00+03	55800.00
FDAB06	2017-08-05 22:38:00+03	40800.00
FDAB46	2017-06-30 14:30:00+03	19600.00
FDAB60	2017-07-14 15:23:00+03	133100.00
FDAB93	2017-07-07 18:20:00+03	42700.00
FDABC0	2017-08-02 03:06:00+03	44100.00
FDAC18	2017-08-11 14:09:00+03	29600.00
FDAC5E	2017-08-08 09:59:00+03	32700.00
FDAD43	2017-07-14 17:03:00+03	266400.00
FDADA4	2017-07-10 00:08:00+03	182400.00
FDADED	2017-07-17 22:33:00+03	67700.00
FDAE3D	2017-08-05 21:29:00+03	62600.00
FDAE67	2017-07-07 10:39:00+03	241300.00
FDAE8A	2017-07-07 18:20:00+03	369000.00
FDAF0E	2017-08-13 05:06:00+03	8200.00
FDAF15	2017-08-14 08:23:00+03	96800.00
FDAF2D	2017-08-08 15:57:00+03	288600.00
FDAF46	2017-07-08 13:27:00+03	168000.00
FDAF58	2017-07-31 17:39:00+03	28800.00
FDAF60	2017-07-23 19:03:00+03	174600.00
FDAFED	2017-07-06 22:24:00+03	16400.00
FDAFF0	2017-07-09 15:20:00+03	16400.00
FDB185	2017-08-10 02:10:00+03	24400.00
FDB190	2017-08-06 18:21:00+03	180700.00
FDB1EC	2017-08-11 15:38:00+03	315900.00
FDB212	2017-07-15 15:59:00+03	64700.00
FDB22F	2017-08-09 19:57:00+03	133100.00
FDB23F	2017-07-03 18:41:00+03	25100.00
FDB273	2017-08-11 01:59:00+03	118300.00
FDB27E	2017-07-09 04:18:00+03	87100.00
FDB28E	2017-07-18 17:56:00+03	65600.00
FDB28F	2017-07-23 16:20:00+03	27200.00
FDB293	2017-08-03 03:26:00+03	30700.00
FDB299	2017-07-17 12:53:00+03	99800.00
FDB2F8	2017-07-31 15:19:00+03	62800.00
FDB31D	2017-08-13 16:16:00+03	24200.00
FDB32C	2017-07-09 11:52:00+03	86300.00
FDB3BA	2017-08-15 15:51:00+03	12300.00
FDB451	2017-07-04 01:48:00+03	112000.00
FDB58F	2017-07-10 14:15:00+03	88800.00
FDB5A2	2017-07-19 14:45:00+03	377100.00
FDB5E6	2017-08-07 13:20:00+03	75600.00
FDB614	2017-07-12 11:48:00+03	56600.00
FDB6B6	2017-08-06 03:16:00+03	79400.00
FDB6BA	2017-07-12 05:27:00+03	51200.00
FDB721	2017-07-21 22:37:00+03	29800.00
FDB76D	2017-07-04 07:37:00+03	300200.00
FDB79F	2017-07-21 14:09:00+03	85000.00
FDB7A3	2017-07-07 10:04:00+03	95200.00
FDB85F	2017-07-14 12:11:00+03	119500.00
FDB8C2	2017-08-01 02:43:00+03	55800.00
FDB8FC	2017-08-08 05:49:00+03	35200.00
FDB920	2017-07-06 18:51:00+03	108500.00
FDB94E	2017-07-04 11:45:00+03	56000.00
FDB985	2017-08-15 15:53:00+03	13400.00
FDB9C1	2017-08-02 12:50:00+03	28800.00
FDBA74	2017-07-28 02:20:00+03	130900.00
FDBA75	2017-07-01 00:24:00+03	40300.00
FDBA89	2017-07-24 22:20:00+03	54800.00
FDBA92	2017-08-12 16:19:00+03	85600.00
FDBAA5	2017-07-12 12:26:00+03	57800.00
FDBAC3	2017-07-19 18:55:00+03	31600.00
FDBADF	2017-07-31 03:16:00+03	70600.00
FDBAFB	2017-07-30 10:09:00+03	142800.00
FDBB80	2017-08-03 23:04:00+03	14000.00
FDBBC8	2017-07-15 22:07:00+03	131600.00
FDBBCE	2017-07-09 15:27:00+03	76400.00
FDBBEA	2017-07-06 22:03:00+03	15900.00
FDBC23	2017-07-18 02:38:00+03	55000.00
FDBCB1	2017-08-07 00:39:00+03	195600.00
FDBCFE	2017-08-12 04:29:00+03	23200.00
FDBD11	2017-07-17 20:01:00+03	24400.00
FDBD44	2017-07-05 08:56:00+03	35600.00
FDBD51	2017-07-07 07:13:00+03	46000.00
FDBD6B	2017-08-06 19:54:00+03	75800.00
FDBD87	2017-07-31 21:20:00+03	24400.00
FDBDF0	2017-07-05 08:36:00+03	156300.00
FDBDF6	2017-07-25 16:40:00+03	45100.00
FDBE1A	2017-06-30 21:03:00+03	23200.00
FDBE1F	2017-07-20 14:48:00+03	46900.00
FDBE7C	2017-07-12 05:22:00+03	187600.00
FDBE87	2017-07-13 21:57:00+03	24700.00
FDBEA3	2017-08-05 15:04:00+03	10600.00
FDBEFA	2017-07-22 07:47:00+03	160100.00
FDBF7D	2017-08-15 15:50:00+03	10300.00
FDBFA1	2017-07-05 16:40:00+03	32700.00
FDBFB3	2017-08-04 16:43:00+03	53300.00
FDBFBF	2017-08-12 02:34:00+03	54800.00
FDC068	2017-07-22 12:50:00+03	15000.00
FDC07E	2017-07-08 11:03:00+03	28000.00
FDC0A2	2017-07-09 02:50:00+03	75000.00
FDC0C6	2017-07-17 18:26:00+03	168000.00
FDC157	2017-07-16 14:02:00+03	123700.00
FDC18A	2017-08-10 05:05:00+03	40000.00
FDC18B	2017-08-06 20:06:00+03	26200.00
FDC238	2017-08-09 12:52:00+03	40800.00
FDC260	2017-07-26 01:54:00+03	12600.00
FDC275	2017-08-14 07:47:00+03	12000.00
FDC2AF	2017-06-30 06:56:00+03	20000.00
FDC341	2017-07-12 00:23:00+03	32800.00
FDC35A	2017-07-24 23:08:00+03	10100.00
FDC36B	2017-08-11 11:24:00+03	55800.00
FDC375	2017-07-15 12:32:00+03	28000.00
FDC3D3	2017-07-20 02:07:00+03	134800.00
FDC3E6	2017-08-13 20:33:00+03	31600.00
FDC42C	2017-07-05 08:06:00+03	246000.00
FDC509	2017-07-04 16:13:00+03	50400.00
FDC510	2017-08-05 12:08:00+03	144700.00
FDC52E	2017-08-14 21:45:00+03	23400.00
FDC54F	2017-07-16 15:20:00+03	35800.00
FDC56B	2017-07-26 20:38:00+03	270700.00
FDC56C	2017-08-14 04:32:00+03	13600.00
FDC594	2017-07-10 01:13:00+03	66700.00
FDC5A6	2017-07-06 04:06:00+03	32800.00
FDC615	2017-07-31 07:54:00+03	51600.00
FDC62C	2017-07-26 23:46:00+03	69000.00
FDC665	2017-07-18 15:13:00+03	63700.00
FDC677	2017-07-19 01:15:00+03	24400.00
FDC6D5	2017-08-04 05:44:00+03	12600.00
FDC6E0	2017-07-07 14:43:00+03	26800.00
FDC76D	2017-07-11 01:12:00+03	99200.00
FDC7DA	2017-07-14 04:34:00+03	60400.00
FDC7E7	2017-07-29 03:52:00+03	32200.00
FDC839	2017-07-12 12:23:00+03	12600.00
FDC89B	2017-07-17 23:56:00+03	48400.00
FDC8DD	2017-08-06 02:27:00+03	49800.00
FDC935	2017-08-12 14:05:00+03	56000.00
FDC9E2	2017-07-09 17:24:00+03	67000.00
FDCA0C	2017-08-09 01:42:00+03	115700.00
FDCA17	2017-06-30 23:20:00+03	167400.00
FDCA4A	2017-08-04 02:38:00+03	80600.00
FDCA51	2017-07-23 14:58:00+03	59800.00
FDCA6E	2017-07-29 15:08:00+03	52000.00
FDCAD4	2017-07-09 04:54:00+03	48800.00
FDCAE0	2017-07-18 11:39:00+03	46200.00
FDCB0D	2017-07-18 01:25:00+03	13200.00
FDCB3D	2017-08-07 16:43:00+03	7400.00
FDCB45	2017-07-22 13:16:00+03	27200.00
FDCB7A	2017-08-04 07:51:00+03	38400.00
FDCBAA	2017-08-08 19:53:00+03	14000.00
FDCC75	2017-06-28 16:25:00+03	125000.00
FDCCB4	2017-07-06 15:41:00+03	13400.00
FDCCC1	2017-07-19 09:00:00+03	82900.00
FDCCE0	2017-07-28 15:37:00+03	80000.00
FDCD2F	2017-07-28 21:08:00+03	28800.00
FDCD81	2017-07-31 23:29:00+03	179600.00
FDCD95	2017-08-09 10:55:00+03	58400.00
FDCDB0	2017-07-05 20:10:00+03	64600.00
FDCDBB	2017-07-18 06:41:00+03	46400.00
FDCE1A	2017-08-08 22:07:00+03	55000.00
FDCE50	2017-07-31 07:20:00+03	43400.00
FDCFFA	2017-08-11 08:47:00+03	31700.00
FDD03D	2017-07-27 21:01:00+03	112000.00
FDD0CF	2017-07-20 01:26:00+03	40000.00
FDD0F0	2017-07-01 10:01:00+03	56600.00
FDD0F1	2017-07-19 10:59:00+03	20500.00
FDD113	2017-07-08 11:55:00+03	24200.00
FDD1C9	2017-07-02 14:33:00+03	90800.00
FDD1DC	2017-07-08 19:31:00+03	30200.00
FDD1E1	2017-08-13 10:14:00+03	58200.00
FDD21F	2017-07-10 23:26:00+03	109000.00
FDD278	2017-08-03 16:09:00+03	346800.00
FDD2C5	2017-07-20 02:22:00+03	46200.00
FDD2ED	2017-08-10 18:12:00+03	28000.00
FDD387	2017-08-09 04:40:00+03	50100.00
FDD388	2017-07-29 08:20:00+03	67700.00
FDD3BA	2017-08-04 06:03:00+03	115900.00
FDD441	2017-07-20 18:53:00+03	46000.00
FDD471	2017-08-02 06:15:00+03	134800.00
FDD4D5	2017-08-05 21:16:00+03	135400.00
FDD4DC	2017-07-23 02:47:00+03	39100.00
FDD4E6	2017-08-05 08:22:00+03	62600.00
FDD4F2	2017-07-01 13:42:00+03	16400.00
FDD577	2017-08-12 01:51:00+03	51300.00
FDD5D2	2017-06-28 15:47:00+03	73900.00
FDD5FD	2017-07-05 04:10:00+03	7400.00
FDD61B	2017-08-09 09:27:00+03	16400.00
FDD69B	2017-06-29 18:16:00+03	27200.00
FDD6CF	2017-07-22 09:39:00+03	48300.00
FDD6DF	2017-07-04 21:04:00+03	117200.00
FDD723	2017-07-10 02:51:00+03	73600.00
FDD725	2017-07-05 05:29:00+03	23400.00
FDD76D	2017-07-10 14:38:00+03	56100.00
FDD78C	2017-07-23 20:00:00+03	26700.00
FDD8E5	2017-08-07 23:33:00+03	143700.00
FDD944	2017-07-07 09:49:00+03	70700.00
FDD968	2017-07-10 14:08:00+03	27000.00
FDD976	2017-07-05 01:24:00+03	19300.00
FDD9AD	2017-07-11 08:58:00+03	84100.00
FDD9FA	2017-07-29 09:15:00+03	6000.00
FDDA2C	2017-08-13 16:06:00+03	45500.00
FDDA87	2017-07-24 13:23:00+03	92000.00
FDDAAD	2017-08-06 18:35:00+03	246000.00
FDDAB7	2017-08-10 14:06:00+03	78300.00
FDDADD	2017-07-23 00:44:00+03	49800.00
FDDBB3	2017-08-01 18:00:00+03	133200.00
FDDBDF	2017-06-29 07:18:00+03	56000.00
FDDBFD	2017-08-08 03:39:00+03	55800.00
FDDC28	2017-07-05 02:11:00+03	40800.00
FDDC46	2017-08-06 02:03:00+03	91900.00
FDDC53	2017-08-04 04:05:00+03	45100.00
FDDCC6	2017-07-15 10:11:00+03	94300.00
FDDD82	2017-07-14 17:52:00+03	24300.00
FDDDAA	2017-07-09 09:01:00+03	26300.00
FDDE19	2017-07-02 04:55:00+03	136200.00
FDDE3B	2017-07-22 01:54:00+03	56000.00
FDDE69	2017-06-26 12:50:00+03	148800.00
FDDF37	2017-08-13 12:55:00+03	48000.00
FDDFAE	2017-08-06 09:40:00+03	123000.00
FDDFCF	2017-07-07 16:50:00+03	37700.00
FDDFE8	2017-07-29 13:32:00+03	32700.00
FDE015	2017-07-01 20:03:00+03	33800.00
FDE023	2017-07-29 21:11:00+03	145300.00
FDE027	2017-08-12 04:09:00+03	100600.00
FDE044	2017-08-02 10:08:00+03	24700.00
FDE0AC	2017-06-27 15:11:00+03	51600.00
FDE0F1	2017-07-21 05:53:00+03	100000.00
FDE143	2017-07-31 12:56:00+03	26600.00
FDE1B2	2017-08-08 01:01:00+03	29600.00
FDE1E0	2017-08-01 02:14:00+03	193700.00
FDE1EC	2017-07-22 19:25:00+03	39200.00
FDE1F6	2017-07-20 16:45:00+03	135400.00
FDE269	2017-07-24 08:03:00+03	103500.00
FDE340	2017-08-06 07:53:00+03	27800.00
FDE34E	2017-07-01 19:45:00+03	22000.00
FDE3B9	2017-08-12 03:37:00+03	31400.00
FDE3C0	2017-07-16 08:33:00+03	318200.00
FDE3D7	2017-08-11 19:00:00+03	112000.00
FDE42F	2017-07-09 23:58:00+03	136800.00
FDE4CB	2017-08-12 22:18:00+03	28800.00
FDE63B	2017-07-27 13:47:00+03	271200.00
FDE647	2017-08-07 16:00:00+03	48700.00
FDE64B	2017-08-11 17:19:00+03	37200.00
FDE6C5	2017-07-03 07:17:00+03	52800.00
FDE769	2017-07-22 15:39:00+03	134600.00
FDE791	2017-07-27 20:20:00+03	73600.00
FDE7A1	2017-07-03 10:57:00+03	21400.00
FDE7A6	2017-06-27 05:39:00+03	98200.00
FDE839	2017-07-09 22:42:00+03	81900.00
FDE83A	2017-07-19 09:46:00+03	247800.00
FDE85F	2017-07-30 14:24:00+03	147700.00
FDE86C	2017-08-15 06:07:00+03	44800.00
FDE875	2017-07-09 04:28:00+03	67800.00
FDE8FB	2017-07-28 19:24:00+03	28800.00
FDE95D	2017-08-05 08:30:00+03	189800.00
FDE9DB	2017-07-11 14:48:00+03	66000.00
FDEA30	2017-07-06 00:49:00+03	19600.00
FDEA71	2017-08-04 07:34:00+03	44500.00
FDEAD8	2017-07-23 09:20:00+03	28000.00
FDEAEA	2017-08-11 04:46:00+03	79900.00
FDEAF1	2017-07-03 09:09:00+03	12600.00
FDEBF4	2017-08-08 23:11:00+03	37700.00
FDEC03	2017-07-09 01:33:00+03	57600.00
FDEC17	2017-08-11 11:51:00+03	78600.00
FDEC27	2017-07-17 11:28:00+03	45000.00
FDEC44	2017-07-24 03:15:00+03	177600.00
FDEC7C	2017-07-27 16:15:00+03	28800.00
FDECBB	2017-07-12 02:29:00+03	12600.00
FDECC4	2017-07-11 13:53:00+03	13600.00
FDED40	2017-07-08 08:56:00+03	49900.00
FDED56	2017-07-17 00:17:00+03	270200.00
FDED66	2017-07-31 02:36:00+03	26000.00
FDEE62	2017-06-28 11:01:00+03	66000.00
FDEEDC	2017-08-14 17:38:00+03	32800.00
FDEF61	2017-07-19 19:41:00+03	13400.00
FDEFB6	2017-07-31 13:14:00+03	26000.00
FDF038	2017-07-27 15:23:00+03	83600.00
FDF077	2017-07-01 08:43:00+03	26000.00
FDF091	2017-08-12 18:00:00+03	21500.00
FDF096	2017-07-30 11:03:00+03	133200.00
FDF0A2	2017-08-10 02:28:00+03	34000.00
FDF0C3	2017-07-16 11:06:00+03	19800.00
FDF0DC	2017-07-25 15:59:00+03	40800.00
FDF0E6	2017-08-04 08:01:00+03	64800.00
FDF10C	2017-07-10 02:17:00+03	25600.00
FDF145	2017-07-19 23:08:00+03	54000.00
FDF157	2017-08-13 21:46:00+03	101600.00
FDF1A6	2017-06-30 00:14:00+03	12000.00
FDF2DB	2017-07-31 18:54:00+03	28000.00
FDF325	2017-08-12 01:40:00+03	27200.00
FDF337	2017-07-13 07:49:00+03	14700.00
FDF3BC	2017-08-04 03:06:00+03	399600.00
FDF3C6	2017-08-10 11:40:00+03	64400.00
FDF425	2017-07-21 18:26:00+03	56100.00
FDF42E	2017-07-29 03:19:00+03	58800.00
FDF46A	2017-07-24 13:45:00+03	56000.00
FDF46D	2017-07-29 09:59:00+03	11600.00
FDF470	2017-07-18 20:19:00+03	32800.00
FDF49D	2017-07-16 18:36:00+03	31400.00
FDF4F0	2017-07-22 17:06:00+03	133100.00
FDF516	2017-07-09 23:02:00+03	89600.00
FDF550	2017-07-13 14:07:00+03	50600.00
FDF571	2017-07-22 14:46:00+03	26200.00
FDF618	2017-08-14 11:27:00+03	37200.00
FDF629	2017-07-01 12:06:00+03	29600.00
FDF630	2017-08-06 06:23:00+03	56000.00
FDF63B	2017-08-12 23:09:00+03	7400.00
FDF64D	2017-07-06 03:46:00+03	12100.00
FDF75A	2017-07-02 22:22:00+03	14000.00
FDF764	2017-07-11 13:55:00+03	31100.00
FDF807	2017-07-26 09:47:00+03	248300.00
FDF825	2017-08-02 14:10:00+03	6800.00
FDF8DE	2017-08-14 13:01:00+03	10800.00
FDF991	2017-07-29 23:59:00+03	62800.00
FDF9CE	2017-07-06 05:08:00+03	23200.00
FDFA5D	2017-06-28 08:33:00+03	28000.00
FDFA60	2017-07-26 00:03:00+03	20800.00
FDFABE	2017-08-07 10:30:00+03	13400.00
FDFAC9	2017-07-15 05:20:00+03	105400.00
FDFAF5	2017-08-12 17:48:00+03	22000.00
FDFB1A	2017-08-11 07:49:00+03	46400.00
FDFBA8	2017-07-01 23:37:00+03	288600.00
FDFBD9	2017-07-04 15:10:00+03	89700.00
FDFC17	2017-07-05 04:33:00+03	146300.00
FDFC46	2017-07-26 14:09:00+03	56100.00
FDFC5F	2017-08-04 05:48:00+03	175300.00
FDFCE2	2017-07-07 00:08:00+03	48100.00
FDFD1A	2017-07-24 03:43:00+03	53700.00
FDFD1F	2017-08-12 02:14:00+03	128800.00
FDFD7A	2017-08-05 19:32:00+03	26000.00
FDFD82	2017-08-01 00:57:00+03	130400.00
FDFD95	2017-07-21 18:57:00+03	57500.00
FDFDC6	2017-07-23 19:23:00+03	66000.00
FDFE0E	2017-08-11 01:03:00+03	28000.00
FDFE76	2017-07-23 05:28:00+03	75500.00
FDFE8C	2017-08-11 14:11:00+03	262500.00
FDFEC8	2017-08-12 04:32:00+03	393800.00
FDFF97	2017-08-02 16:01:00+03	70400.00
FDFFBC	2017-07-15 15:50:00+03	28000.00
FE0040	2017-08-06 11:20:00+03	27800.00
FE004B	2017-07-02 23:06:00+03	125000.00
FE0058	2017-08-13 20:21:00+03	67000.00
FE0059	2017-07-09 05:50:00+03	83600.00
FE005E	2017-08-10 18:11:00+03	56100.00
FE0083	2017-07-30 09:10:00+03	75300.00
FE00C9	2017-07-03 20:23:00+03	394800.00
FE00D0	2017-07-06 12:18:00+03	302600.00
FE0116	2017-08-11 19:17:00+03	38600.00
FE0159	2017-07-27 19:14:00+03	155600.00
FE0198	2017-07-28 10:59:00+03	12400.00
FE01C5	2017-07-02 05:49:00+03	15000.00
FE0258	2017-07-25 12:30:00+03	99300.00
FE0286	2017-07-08 20:43:00+03	117900.00
FE02DD	2017-07-16 01:19:00+03	19800.00
FE03BC	2017-07-03 01:52:00+03	46700.00
FE0409	2017-08-15 10:52:00+03	118300.00
FE0462	2017-06-25 07:13:00+03	17800.00
FE04F1	2017-07-12 15:04:00+03	56000.00
FE056F	2017-07-30 23:28:00+03	73900.00
FE0585	2017-08-13 11:55:00+03	44200.00
FE0589	2017-08-12 19:47:00+03	47000.00
FE059E	2017-07-11 09:54:00+03	271200.00
FE05A7	2017-07-30 21:53:00+03	75600.00
FE05BA	2017-07-16 06:40:00+03	90800.00
FE05E4	2017-07-03 19:29:00+03	21400.00
FE06D6	2017-07-27 14:34:00+03	191400.00
FE0778	2017-08-03 16:19:00+03	6800.00
FE0815	2017-07-23 10:34:00+03	43200.00
FE0865	2017-07-11 21:55:00+03	27200.00
FE089F	2017-07-14 21:46:00+03	60400.00
FE08AC	2017-07-31 22:46:00+03	6300.00
FE08AD	2017-08-07 07:45:00+03	28000.00
FE08C8	2017-08-15 05:35:00+03	37100.00
FE08C9	2017-08-11 03:10:00+03	88600.00
FE090E	2017-07-25 15:41:00+03	296400.00
FE0929	2017-07-05 05:51:00+03	26200.00
FE0942	2017-08-13 19:28:00+03	128800.00
FE0980	2017-06-27 07:10:00+03	67000.00
FE09DE	2017-07-17 15:17:00+03	51300.00
FE0A09	2017-07-15 13:49:00+03	56000.00
FE0A24	2017-07-19 15:11:00+03	24400.00
FE0A36	2017-07-18 15:06:00+03	369000.00
FE0A6F	2017-08-08 04:14:00+03	85000.00
FE0A8A	2017-07-26 03:20:00+03	96300.00
FE0B05	2017-08-02 17:27:00+03	72300.00
FE0BAC	2017-07-28 06:11:00+03	23200.00
FE0BE9	2017-07-17 16:22:00+03	532800.00
FE0C1A	2017-08-12 00:16:00+03	56000.00
FE0C76	2017-08-04 22:45:00+03	23600.00
FE0C90	2017-08-13 07:11:00+03	132800.00
FE0CAC	2017-08-04 08:55:00+03	139200.00
FE0CBC	2017-08-09 22:48:00+03	160100.00
FE0CD9	2017-07-07 07:51:00+03	27200.00
FE0D47	2017-08-06 14:21:00+03	40800.00
FE0E06	2017-06-29 07:36:00+03	73600.00
FE0E16	2017-07-10 12:43:00+03	91600.00
FE0E7A	2017-08-15 10:05:00+03	52000.00
FE0F46	2017-08-15 13:33:00+03	22100.00
FE0F57	2017-07-01 10:51:00+03	154800.00
FE0F92	2017-08-13 08:48:00+03	27600.00
FE0FB5	2017-08-11 04:45:00+03	14400.00
FE0FD2	2017-07-10 15:09:00+03	13400.00
FE1001	2017-07-06 04:48:00+03	83000.00
FE106D	2017-07-24 23:01:00+03	46400.00
FE1078	2017-08-03 14:58:00+03	24700.00
FE107F	2017-07-24 08:27:00+03	62600.00
FE1094	2017-07-28 06:11:00+03	52000.00
FE10A7	2017-07-25 06:02:00+03	133200.00
FE1119	2017-08-04 05:07:00+03	286100.00
FE1121	2017-08-07 14:12:00+03	393800.00
FE1169	2017-07-16 01:39:00+03	123000.00
FE1184	2017-08-14 18:59:00+03	18600.00
FE1190	2017-07-31 22:20:00+03	33300.00
FE119A	2017-07-24 10:52:00+03	38400.00
FE120B	2017-08-07 15:25:00+03	592600.00
FE1220	2017-08-14 12:46:00+03	47700.00
FE126B	2017-07-16 18:43:00+03	52000.00
FE126E	2017-07-22 09:07:00+03	49400.00
FE1299	2017-07-26 10:19:00+03	66600.00
FE129C	2017-08-05 22:10:00+03	57400.00
FE12CD	2017-07-22 19:25:00+03	66300.00
FE12E2	2017-07-18 16:15:00+03	55800.00
FE12F0	2017-07-07 05:58:00+03	106100.00
FE130D	2017-08-08 21:39:00+03	235700.00
FE1325	2017-07-18 19:14:00+03	96800.00
FE1348	2017-08-15 02:10:00+03	105400.00
FE1354	2017-08-02 14:19:00+03	58700.00
FE135D	2017-07-09 12:34:00+03	57600.00
FE137A	2017-07-19 15:32:00+03	3400.00
FE1388	2017-07-11 19:58:00+03	246000.00
FE1393	2017-07-27 09:25:00+03	61800.00
FE1420	2017-07-12 15:38:00+03	89700.00
FE144F	2017-08-02 17:58:00+03	92000.00
FE1469	2017-07-27 11:11:00+03	13400.00
FE14B9	2017-07-14 03:59:00+03	15700.00
FE14EE	2017-07-08 09:00:00+03	56900.00
FE1578	2017-07-11 20:04:00+03	46400.00
FE1579	2017-07-04 14:57:00+03	73000.00
FE157E	2017-07-31 04:14:00+03	42000.00
FE159C	2017-07-27 04:59:00+03	55800.00
FE15B0	2017-07-16 07:34:00+03	200500.00
FE15C1	2017-07-23 09:47:00+03	98800.00
FE15F8	2017-07-21 04:48:00+03	125200.00
FE16FC	2017-07-18 04:07:00+03	29200.00
FE173A	2017-07-31 13:53:00+03	38800.00
FE17EC	2017-07-07 03:09:00+03	25600.00
FE182E	2017-07-16 13:52:00+03	54800.00
FE1856	2017-07-11 19:38:00+03	87100.00
FE185C	2017-07-30 03:28:00+03	132300.00
FE187F	2017-07-26 10:49:00+03	25100.00
FE188F	2017-07-03 14:03:00+03	23200.00
FE18F9	2017-08-06 04:59:00+03	39100.00
FE1921	2017-08-05 04:16:00+03	198400.00
FE1965	2017-08-15 08:34:00+03	24000.00
FE1987	2017-07-27 09:24:00+03	63500.00
FE19A0	2017-07-24 03:46:00+03	30200.00
FE19B3	2017-08-03 01:34:00+03	398500.00
FE19E9	2017-07-27 01:10:00+03	193600.00
FE1A96	2017-07-20 22:41:00+03	67900.00
FE1AC0	2017-07-12 18:25:00+03	70700.00
FE1B10	2017-08-04 12:29:00+03	135000.00
FE1BAD	2017-07-10 01:25:00+03	242400.00
FE1BF4	2017-07-02 22:29:00+03	28800.00
FE1C11	2017-07-31 10:12:00+03	177200.00
FE1C1E	2017-07-14 18:10:00+03	45200.00
FE1C33	2017-07-29 20:27:00+03	44000.00
FE1C39	2017-07-31 02:30:00+03	55800.00
FE1C83	2017-07-23 22:19:00+03	67400.00
FE1C8A	2017-06-29 16:15:00+03	55800.00
FE1C8B	2017-08-13 11:53:00+03	28800.00
FE1CD7	2017-08-11 10:57:00+03	21800.00
FE1CDB	2017-07-05 05:10:00+03	75300.00
FE1D82	2017-07-09 09:16:00+03	90000.00
FE1D93	2017-07-29 23:19:00+03	13800.00
FE1D99	2017-07-13 15:57:00+03	55800.00
FE1DC5	2017-07-13 17:03:00+03	58800.00
FE1E3A	2017-07-26 17:42:00+03	23400.00
FE1E4D	2017-07-21 16:48:00+03	19600.00
FE1E78	2017-08-04 22:32:00+03	59800.00
FE1EC4	2017-08-07 07:03:00+03	55800.00
FE1EE3	2017-07-15 15:32:00+03	50000.00
FE1F12	2017-07-23 00:17:00+03	65400.00
FE1F8B	2017-07-05 03:49:00+03	148200.00
FE1FA2	2017-08-04 00:02:00+03	6000.00
FE1FAB	2017-07-15 03:22:00+03	369000.00
FE1FE9	2017-07-01 22:00:00+03	15700.00
FE1FF6	2017-08-01 10:16:00+03	61800.00
FE20AA	2017-07-26 09:23:00+03	157400.00
FE2115	2017-07-18 13:13:00+03	71900.00
FE21A3	2017-08-10 19:02:00+03	113000.00
FE223A	2017-07-20 18:29:00+03	148300.00
FE2257	2017-07-31 15:49:00+03	92400.00
FE2278	2017-07-07 05:54:00+03	185800.00
FE22E4	2017-07-11 10:18:00+03	51900.00
FE2346	2017-07-31 14:09:00+03	103500.00
FE236D	2017-07-25 07:50:00+03	327700.00
FE239F	2017-08-03 20:57:00+03	13600.00
FE23A7	2017-07-10 11:51:00+03	22000.00
FE2444	2017-07-03 23:09:00+03	106000.00
FE24E7	2017-07-28 19:48:00+03	12000.00
FE2586	2017-07-09 16:53:00+03	30000.00
FE25EE	2017-08-15 17:38:00+03	56300.00
FE2625	2017-07-17 19:31:00+03	41200.00
FE26CA	2017-07-03 11:33:00+03	14700.00
FE26F3	2017-07-04 10:45:00+03	224000.00
FE278C	2017-07-23 07:22:00+03	94000.00
FE27D1	2017-07-29 09:43:00+03	54500.00
FE27E5	2017-08-04 01:12:00+03	83800.00
FE27EC	2017-08-12 01:32:00+03	192400.00
FE2810	2017-07-28 12:31:00+03	133100.00
FE2856	2017-08-14 06:41:00+03	15800.00
FE286F	2017-07-08 06:46:00+03	108000.00
FE28B0	2017-08-04 12:24:00+03	133100.00
FE28BE	2017-08-07 00:37:00+03	182100.00
FE2929	2017-08-04 17:09:00+03	65400.00
FE2948	2017-08-13 00:17:00+03	56100.00
FE2996	2017-07-09 18:16:00+03	6000.00
FE2A40	2017-07-07 22:06:00+03	24400.00
FE2A5C	2017-08-04 20:04:00+03	43200.00
FE2A6A	2017-07-26 20:11:00+03	63500.00
FE2AB8	2017-07-16 16:17:00+03	26000.00
FE2AF9	2017-07-09 13:18:00+03	28000.00
FE2B0F	2017-08-14 08:02:00+03	20200.00
FE2B17	2017-07-30 23:27:00+03	11600.00
FE2B59	2017-08-11 15:15:00+03	83000.00
FE2BAF	2017-07-11 06:44:00+03	149000.00
FE2BCC	2017-08-03 18:17:00+03	51900.00
FE2BE4	2017-07-09 18:57:00+03	113200.00
FE2C09	2017-08-13 00:02:00+03	101200.00
FE2D72	2017-07-07 15:11:00+03	28000.00
FE2DBC	2017-07-21 10:39:00+03	26200.00
FE2DEA	2017-08-08 07:53:00+03	174800.00
FE2E56	2017-07-06 07:49:00+03	45200.00
FE2E82	2017-07-25 09:43:00+03	28800.00
FE2F2B	2017-06-29 18:11:00+03	21000.00
FE2F68	2017-07-09 00:04:00+03	24700.00
FE2FCA	2017-08-07 14:53:00+03	52100.00
FE3010	2017-07-04 10:44:00+03	23000.00
FE3040	2017-07-30 18:18:00+03	114500.00
FE30C6	2017-07-27 21:55:00+03	52000.00
FE3121	2017-08-13 12:51:00+03	92900.00
FE3140	2017-08-06 12:45:00+03	92400.00
FE3211	2017-07-11 17:56:00+03	46300.00
FE324A	2017-07-16 19:17:00+03	35700.00
FE3279	2017-08-12 17:00:00+03	21400.00
FE32BA	2017-07-14 08:51:00+03	32800.00
FE3301	2017-07-05 09:01:00+03	181400.00
FE3314	2017-08-09 00:18:00+03	53300.00
FE332F	2017-07-13 01:06:00+03	94000.00
FE3339	2017-07-28 15:42:00+03	22800.00
FE333D	2017-07-21 23:12:00+03	76800.00
FE3364	2017-07-18 21:24:00+03	86600.00
FE3368	2017-08-11 00:34:00+03	58600.00
FE3369	2017-07-24 05:30:00+03	92100.00
FE3384	2017-07-30 02:35:00+03	12000.00
FE339B	2017-08-03 23:44:00+03	51900.00
FE33C7	2017-08-12 04:51:00+03	67600.00
FE33F3	2017-07-01 09:37:00+03	87000.00
FE3413	2017-08-14 11:18:00+03	92000.00
FE3424	2017-07-10 08:02:00+03	89600.00
FE343F	2017-06-28 21:54:00+03	54800.00
FE3460	2017-08-07 08:37:00+03	73600.00
FE34F5	2017-08-12 13:22:00+03	28800.00
FE3524	2017-08-10 14:38:00+03	85000.00
FE3576	2017-08-01 12:05:00+03	26000.00
FE35AC	2017-08-05 03:22:00+03	73100.00
FE35B5	2017-06-30 02:50:00+03	101100.00
FE35BF	2017-07-07 16:56:00+03	147800.00
FE35D4	2017-08-14 12:43:00+03	41600.00
FE3628	2017-08-13 16:08:00+03	56600.00
FE3648	2017-07-18 11:16:00+03	64400.00
FE364B	2017-07-09 11:30:00+03	92400.00
FE36B5	2017-08-12 02:36:00+03	65900.00
FE36BB	2017-08-14 01:11:00+03	54000.00
FE36C4	2017-08-05 09:23:00+03	11600.00
FE371A	2017-07-28 15:12:00+03	28800.00
FE3725	2017-06-30 21:30:00+03	22000.00
FE3776	2017-07-16 14:25:00+03	37800.00
FE37E2	2017-08-04 15:16:00+03	105200.00
FE3806	2017-08-05 12:37:00+03	25400.00
FE3833	2017-08-12 06:42:00+03	14000.00
FE3880	2017-07-06 14:20:00+03	58800.00
FE38B9	2017-07-06 08:34:00+03	28600.00
FE38F5	2017-07-27 03:29:00+03	56000.00
FE3903	2017-08-07 00:53:00+03	145200.00
FE390C	2017-07-01 09:22:00+03	515100.00
FE390E	2017-07-11 12:05:00+03	15000.00
FE3920	2017-07-31 19:18:00+03	69900.00
FE3941	2017-07-09 18:58:00+03	14800.00
FE395F	2017-08-09 05:41:00+03	54000.00
FE3971	2017-08-13 03:29:00+03	46400.00
FE39A6	2017-07-11 12:48:00+03	28300.00
FE3A87	2017-07-12 11:33:00+03	54800.00
FE3A8C	2017-07-09 23:41:00+03	65900.00
FE3AC5	2017-07-17 01:16:00+03	7400.00
FE3B12	2017-07-12 15:43:00+03	70700.00
FE3B1D	2017-07-18 07:02:00+03	28000.00
FE3BB1	2017-07-24 07:16:00+03	32700.00
FE3BD0	2017-07-12 11:39:00+03	41200.00
FE3C10	2017-08-14 07:40:00+03	387400.00
FE3C17	2017-07-07 23:50:00+03	40800.00
FE3C61	2017-07-16 20:51:00+03	88900.00
FE3CBE	2017-08-04 07:22:00+03	542200.00
FE3CC7	2017-08-01 05:27:00+03	54400.00
FE3D6A	2017-08-03 15:31:00+03	110500.00
FE3E04	2017-08-09 04:52:00+03	51900.00
FE3E0F	2017-08-11 21:40:00+03	84500.00
FE3E18	2017-07-27 08:41:00+03	10800.00
FE3E45	2017-07-21 07:18:00+03	78600.00
FE3E5F	2017-08-10 09:48:00+03	62000.00
FE3EB4	2017-07-19 12:19:00+03	147000.00
FE3EC7	2017-08-02 05:06:00+03	28000.00
FE3EF1	2017-07-27 02:18:00+03	25900.00
FE3F14	2017-07-19 00:01:00+03	56000.00
FE3F6E	2017-08-07 23:55:00+03	23200.00
FE3F8E	2017-07-23 11:31:00+03	67600.00
FE3FE6	2017-07-29 23:17:00+03	22000.00
FE3FF1	2017-08-07 09:33:00+03	78100.00
FE4014	2017-08-12 21:45:00+03	65100.00
FE401B	2017-08-03 02:14:00+03	7600.00
FE401F	2017-08-10 02:28:00+03	56100.00
FE4032	2017-08-13 13:19:00+03	25200.00
FE4064	2017-07-17 11:32:00+03	133100.00
FE4077	2017-07-05 15:38:00+03	13400.00
FE4086	2017-07-30 00:45:00+03	16400.00
FE40B3	2017-07-04 17:13:00+03	60700.00
FE40F3	2017-07-28 05:38:00+03	94700.00
FE4146	2017-07-10 08:25:00+03	46000.00
FE41CD	2017-08-11 11:49:00+03	189800.00
FE4224	2017-08-04 02:02:00+03	112000.00
FE423B	2017-07-28 14:22:00+03	56000.00
FE4243	2017-07-31 00:39:00+03	21600.00
FE425C	2017-07-16 23:11:00+03	114600.00
FE427D	2017-07-17 23:51:00+03	36800.00
FE42B7	2017-07-26 20:28:00+03	38400.00
FE42BD	2017-08-13 00:32:00+03	68400.00
FE42E1	2017-08-06 19:29:00+03	131100.00
FE43B0	2017-07-04 14:48:00+03	35600.00
FE448A	2017-08-06 16:14:00+03	46400.00
FE44C6	2017-08-06 18:51:00+03	22000.00
FE44EB	2017-07-08 19:38:00+03	57600.00
FE4505	2017-08-15 11:00:00+03	77200.00
FE454B	2017-07-11 12:03:00+03	117000.00
FE4592	2017-08-04 16:34:00+03	59800.00
FE45F1	2017-08-13 16:57:00+03	137400.00
FE4604	2017-07-07 14:02:00+03	25800.00
FE464E	2017-08-10 03:28:00+03	64100.00
FE4688	2017-07-26 00:13:00+03	68800.00
FE46E5	2017-07-12 01:52:00+03	62600.00
FE46ED	2017-08-09 01:54:00+03	70700.00
FE46F7	2017-07-19 02:25:00+03	47400.00
FE471F	2017-07-07 07:57:00+03	31900.00
FE4732	2017-07-15 15:06:00+03	57500.00
FE4738	2017-08-14 00:33:00+03	93400.00
FE478B	2017-08-08 20:48:00+03	102100.00
FE4795	2017-07-25 17:30:00+03	47500.00
FE47A0	2017-07-05 05:54:00+03	62600.00
FE4813	2017-08-10 01:42:00+03	11800.00
FE48B2	2017-08-09 05:58:00+03	56000.00
FE48EE	2017-07-04 08:50:00+03	59200.00
FE4916	2017-08-06 07:21:00+03	77900.00
FE4954	2017-08-02 10:33:00+03	28000.00
FE495B	2017-07-10 15:17:00+03	59300.00
FE498E	2017-07-16 06:52:00+03	66600.00
FE49FD	2017-08-07 22:27:00+03	28000.00
FE4A19	2017-07-11 14:15:00+03	25400.00
FE4A42	2017-08-10 22:31:00+03	15700.00
FE4AC3	2017-08-11 04:04:00+03	29800.00
FE4B20	2017-07-25 08:37:00+03	94700.00
FE4B6B	2017-07-16 23:38:00+03	534300.00
FE4BE5	2017-07-04 22:59:00+03	53700.00
FE4BF0	2017-07-11 14:44:00+03	117600.00
FE4C32	2017-07-17 01:29:00+03	81700.00
FE4C72	2017-07-03 21:02:00+03	27200.00
FE4CA7	2017-08-15 00:46:00+03	47500.00
FE4CE2	2017-07-10 09:05:00+03	31600.00
FE4D30	2017-07-03 13:23:00+03	29600.00
FE4D4F	2017-07-22 11:00:00+03	16400.00
FE4DBD	2017-08-13 03:07:00+03	57500.00
FE4E0A	2017-08-05 10:43:00+03	136800.00
FE4E19	2017-07-20 12:09:00+03	24800.00
FE4E3F	2017-08-04 16:40:00+03	36400.00
FE4E4A	2017-07-25 12:33:00+03	65900.00
FE4EA5	2017-06-27 05:43:00+03	19000.00
FE4ED3	2017-08-08 23:20:00+03	92000.00
FE4F55	2017-08-10 02:17:00+03	65600.00
FE4FCD	2017-08-05 07:04:00+03	6700.00
FE503A	2017-08-04 12:45:00+03	81800.00
FE50D1	2017-07-28 10:35:00+03	152900.00
FE513F	2017-07-07 05:05:00+03	29600.00
FE51B4	2017-07-21 08:29:00+03	80900.00
FE5219	2017-07-17 01:29:00+03	28700.00
FE529C	2017-07-05 01:11:00+03	46000.00
FE52D4	2017-07-20 12:50:00+03	12600.00
FE5302	2017-08-06 19:34:00+03	23200.00
FE537A	2017-07-18 02:35:00+03	400000.00
FE53BA	2017-06-29 02:34:00+03	8000.00
FE53C6	2017-07-25 07:23:00+03	21800.00
FE53F9	2017-07-22 12:58:00+03	14000.00
FE545D	2017-08-12 09:15:00+03	19600.00
FE5497	2017-07-30 19:27:00+03	67500.00
FE54B8	2017-07-02 22:14:00+03	21400.00
FE54C5	2017-07-28 07:24:00+03	103500.00
FE54FB	2017-08-09 02:49:00+03	78300.00
FE5549	2017-07-08 13:56:00+03	47200.00
FE5562	2017-07-21 19:19:00+03	135400.00
FE559E	2017-07-15 21:21:00+03	24800.00
FE55A0	2017-08-13 23:48:00+03	58200.00
FE55AA	2017-07-30 22:21:00+03	251700.00
FE55F1	2017-07-14 06:27:00+03	113200.00
FE55F4	2017-07-16 10:37:00+03	131100.00
FE5602	2017-07-31 17:09:00+03	56000.00
FE569C	2017-07-30 03:45:00+03	102600.00
FE5701	2017-07-03 04:23:00+03	12600.00
FE5726	2017-07-12 06:34:00+03	21400.00
FE57BC	2017-07-02 01:05:00+03	144400.00
FE57D0	2017-08-14 22:46:00+03	67700.00
FE58B1	2017-07-28 08:25:00+03	79600.00
FE5947	2017-08-12 02:19:00+03	180600.00
FE5974	2017-07-19 17:45:00+03	116300.00
FE5A27	2017-08-07 22:24:00+03	377400.00
FE5AB9	2017-07-20 08:58:00+03	245400.00
FE5ABB	2017-07-20 14:15:00+03	86400.00
FE5B08	2017-08-08 06:02:00+03	57600.00
FE5B35	2017-06-30 04:11:00+03	61400.00
FE5B38	2017-08-03 12:48:00+03	54400.00
FE5C45	2017-07-12 11:56:00+03	48800.00
FE5CBE	2017-07-27 11:40:00+03	44000.00
FE5CFF	2017-07-30 06:31:00+03	169300.00
FE5D09	2017-08-02 08:33:00+03	600900.00
FE5D2A	2017-07-23 15:08:00+03	44000.00
FE5D35	2017-08-09 04:36:00+03	7400.00
FE5D4D	2017-07-23 03:26:00+03	102800.00
FE5D72	2017-07-14 13:26:00+03	27200.00
FE5DB6	2017-06-30 07:48:00+03	117000.00
FE5DC6	2017-07-05 18:26:00+03	47400.00
FE5DD4	2017-08-02 18:52:00+03	23500.00
FE5E2A	2017-07-18 11:15:00+03	139300.00
FE5E79	2017-07-24 21:18:00+03	24800.00
FE5EB3	2017-07-27 03:55:00+03	6000.00
FE5FC9	2017-08-09 08:43:00+03	73200.00
FE5FCF	2017-07-30 00:36:00+03	28700.00
FE6040	2017-07-19 14:40:00+03	26000.00
FE609E	2017-07-09 19:13:00+03	16000.00
FE60CC	2017-07-09 20:22:00+03	98400.00
FE6116	2017-08-11 10:27:00+03	179400.00
FE611C	2017-07-20 09:05:00+03	23600.00
FE613A	2017-08-12 11:57:00+03	28800.00
FE61C6	2017-08-08 22:24:00+03	136800.00
FE6200	2017-07-12 12:16:00+03	29600.00
FE626A	2017-07-09 18:39:00+03	26200.00
FE630A	2017-07-19 11:39:00+03	154800.00
FE630B	2017-08-07 20:46:00+03	65900.00
FE635F	2017-08-07 13:17:00+03	71500.00
FE6401	2017-07-31 23:54:00+03	25600.00
FE640E	2017-08-07 04:01:00+03	28000.00
FE643C	2017-07-19 02:47:00+03	131100.00
FE644A	2017-08-09 22:34:00+03	266400.00
FE6479	2017-07-16 01:09:00+03	28800.00
FE6495	2017-07-09 10:34:00+03	49600.00
FE64DD	2017-07-16 03:07:00+03	46400.00
FE64E9	2017-07-23 03:32:00+03	56000.00
FE6501	2017-07-07 13:22:00+03	72400.00
FE6533	2017-07-08 15:48:00+03	557300.00
FE6582	2017-08-14 10:10:00+03	6000.00
FE65A0	2017-07-07 01:41:00+03	59800.00
FE65D6	2017-08-13 05:06:00+03	47900.00
FE65F5	2017-08-10 04:02:00+03	57500.00
FE6605	2017-08-09 04:04:00+03	56000.00
FE667C	2017-07-02 18:38:00+03	28800.00
FE6729	2017-08-07 03:04:00+03	46000.00
FE6790	2017-07-22 23:20:00+03	90400.00
FE67AE	2017-07-12 02:03:00+03	23600.00
FE67D7	2017-07-13 19:39:00+03	50600.00
FE67E8	2017-08-01 15:17:00+03	98200.00
FE686D	2017-08-07 19:56:00+03	47700.00
FE6879	2017-08-11 20:25:00+03	162100.00
FE68E7	2017-07-12 04:06:00+03	101500.00
FE68F3	2017-07-26 14:42:00+03	21200.00
FE69A4	2017-07-09 08:54:00+03	14400.00
FE6A24	2017-08-15 15:45:00+03	68800.00
FE6A2F	2017-07-13 04:23:00+03	58600.00
FE6A67	2017-08-14 06:55:00+03	65200.00
FE6AA8	2017-07-10 19:22:00+03	208200.00
FE6AB3	2017-07-10 05:48:00+03	46400.00
FE6B63	2017-07-17 19:01:00+03	26200.00
FE6B70	2017-07-21 04:35:00+03	17600.00
FE6BC3	2017-07-18 12:47:00+03	36200.00
FE6C43	2017-07-06 05:10:00+03	189100.00
FE6CDD	2017-07-29 10:42:00+03	136200.00
FE6D44	2017-07-18 11:54:00+03	40100.00
FE6D8C	2017-07-13 05:15:00+03	23400.00
FE6D8E	2017-07-21 14:56:00+03	45200.00
FE6D95	2017-08-12 07:07:00+03	47400.00
FE6DEB	2017-07-23 17:02:00+03	212000.00
FE6E13	2017-07-09 12:31:00+03	62800.00
FE6E18	2017-07-07 14:20:00+03	111100.00
FE6E1B	2017-07-12 07:55:00+03	23600.00
FE6E42	2017-07-09 14:57:00+03	119700.00
FE6E88	2017-07-06 15:36:00+03	159800.00
FE6EE7	2017-08-11 22:30:00+03	40800.00
FE6F0B	2017-08-12 12:52:00+03	8200.00
FE6FFB	2017-08-02 08:25:00+03	57400.00
FE7042	2017-08-06 17:39:00+03	6800.00
FE708E	2017-07-20 18:52:00+03	87200.00
FE7103	2017-08-12 01:45:00+03	40800.00
FE7116	2017-08-07 07:53:00+03	7300.00
FE7143	2017-07-20 00:31:00+03	38600.00
FE7149	2017-08-15 10:53:00+03	57000.00
FE7180	2017-07-21 19:32:00+03	32100.00
FE726E	2017-07-13 13:23:00+03	14800.00
FE7328	2017-08-15 10:17:00+03	32800.00
FE7368	2017-07-30 06:25:00+03	123600.00
FE738D	2017-07-06 09:54:00+03	136200.00
FE73C4	2017-08-03 10:19:00+03	112000.00
FE73F4	2017-07-20 14:17:00+03	53600.00
FE7410	2017-08-03 10:08:00+03	8400.00
FE744A	2017-08-06 13:59:00+03	21400.00
FE7455	2017-06-30 14:26:00+03	143100.00
FE7480	2017-08-10 22:50:00+03	8000.00
FE74A2	2017-07-03 15:29:00+03	123000.00
FE74AA	2017-08-06 00:08:00+03	7400.00
FE74B4	2017-07-03 06:25:00+03	133200.00
FE760A	2017-07-07 12:39:00+03	52000.00
FE7665	2017-06-28 22:10:00+03	13400.00
FE7666	2017-07-09 22:27:00+03	403900.00
FE766B	2017-07-31 23:01:00+03	226200.00
FE7693	2017-07-07 18:59:00+03	85700.00
FE76BA	2017-08-10 06:57:00+03	10600.00
FE76BD	2017-07-05 22:11:00+03	321600.00
FE7710	2017-07-26 19:03:00+03	12600.00
FE7712	2017-07-15 05:56:00+03	68100.00
FE77A9	2017-08-10 11:07:00+03	134400.00
FE7843	2017-07-24 01:15:00+03	46400.00
FE784E	2017-07-09 10:48:00+03	67500.00
FE78A8	2017-07-29 19:35:00+03	86800.00
FE78AF	2017-07-28 21:10:00+03	121200.00
FE796F	2017-07-07 18:04:00+03	75300.00
FE797A	2017-08-02 10:50:00+03	28800.00
FE79C3	2017-08-10 01:26:00+03	22000.00
FE79D8	2017-07-13 07:44:00+03	67000.00
FE7A0B	2017-08-01 09:01:00+03	229900.00
FE7A0F	2017-08-03 05:09:00+03	14400.00
FE7A28	2017-07-26 23:46:00+03	398500.00
FE7AC1	2017-07-09 18:55:00+03	357000.00
FE7B21	2017-08-04 15:02:00+03	25800.00
FE7B61	2017-07-07 01:29:00+03	31600.00
FE7C08	2017-07-08 16:52:00+03	67600.00
FE7C26	2017-07-03 18:25:00+03	86800.00
FE7CB0	2017-07-16 23:21:00+03	67300.00
FE7CB7	2017-08-10 13:05:00+03	23200.00
FE7D80	2017-07-23 15:29:00+03	107200.00
FE7D93	2017-08-14 01:12:00+03	59000.00
FE7E18	2017-07-03 17:44:00+03	266200.00
FE7E68	2017-07-11 07:23:00+03	93300.00
FE7ED8	2017-08-06 17:47:00+03	65400.00
FE7EF6	2017-08-15 00:02:00+03	51800.00
FE7F02	2017-08-12 10:38:00+03	66600.00
FE7F53	2017-07-18 01:46:00+03	101200.00
FE7F5F	2017-07-15 16:12:00+03	152200.00
FE7FB9	2017-07-22 16:13:00+03	47600.00
FE7FFD	2017-07-15 10:58:00+03	100200.00
FE8000	2017-07-03 19:15:00+03	35800.00
FE801B	2017-08-08 03:44:00+03	18300.00
FE8021	2017-08-09 04:56:00+03	31200.00
FE8075	2017-07-30 03:30:00+03	29600.00
FE80A4	2017-06-29 21:46:00+03	46400.00
FE80AC	2017-07-06 01:47:00+03	68200.00
FE8103	2017-07-30 01:09:00+03	12000.00
FE811C	2017-07-25 22:13:00+03	42400.00
FE8149	2017-07-11 04:09:00+03	15400.00
FE8257	2017-07-11 14:18:00+03	26000.00
FE826A	2017-07-16 12:42:00+03	73500.00
FE82AB	2017-07-09 10:34:00+03	42800.00
FE832A	2017-07-27 16:37:00+03	38600.00
FE833D	2017-07-03 01:59:00+03	80500.00
FE8373	2017-08-06 18:30:00+03	95100.00
FE839B	2017-07-27 18:53:00+03	24400.00
FE8428	2017-08-12 05:07:00+03	16400.00
FE8430	2017-08-12 15:49:00+03	241300.00
FE8467	2017-07-01 19:56:00+03	280600.00
FE846D	2017-07-14 21:49:00+03	58200.00
FE8498	2017-07-16 03:49:00+03	12600.00
FE84BB	2017-08-06 04:38:00+03	135600.00
FE84E9	2017-08-11 08:46:00+03	28000.00
FE8582	2017-08-03 06:20:00+03	87000.00
FE858D	2017-07-17 03:04:00+03	40800.00
FE85D0	2017-07-11 11:20:00+03	78600.00
FE85D2	2017-07-17 05:42:00+03	131100.00
FE862C	2017-07-17 10:18:00+03	124200.00
FE8666	2017-07-19 11:18:00+03	13600.00
FE86A4	2017-07-23 08:53:00+03	22100.00
FE86AF	2017-07-25 00:38:00+03	58400.00
FE86B0	2017-07-12 12:39:00+03	138500.00
FE870E	2017-07-27 07:03:00+03	122800.00
FE8770	2017-07-11 14:37:00+03	65500.00
FE8790	2017-08-05 00:05:00+03	111600.00
FE8793	2017-08-05 04:30:00+03	13400.00
FE87DC	2017-07-25 23:25:00+03	47000.00
FE87FD	2017-08-05 19:11:00+03	199600.00
FE88CA	2017-08-11 11:46:00+03	114800.00
FE88FC	2017-08-06 00:57:00+03	58400.00
FE8911	2017-07-13 17:50:00+03	108000.00
FE8913	2017-08-13 19:51:00+03	75600.00
FE894B	2017-07-05 13:14:00+03	51900.00
FE8955	2017-07-31 05:18:00+03	71000.00
FE895F	2017-07-18 00:53:00+03	202100.00
FE8978	2017-07-14 18:32:00+03	36100.00
FE8981	2017-08-14 22:19:00+03	37000.00
FE89CD	2017-07-20 21:46:00+03	80000.00
FE8A58	2017-08-04 17:59:00+03	131600.00
FE8A74	2017-08-05 21:26:00+03	28000.00
FE8AB0	2017-08-02 12:03:00+03	386200.00
FE8AC6	2017-07-17 08:20:00+03	84500.00
FE8B25	2017-07-20 03:48:00+03	101800.00
FE8B30	2017-06-29 18:12:00+03	14000.00
FE8B6E	2017-07-15 09:14:00+03	120800.00
FE8B93	2017-07-01 06:45:00+03	148700.00
FE8BF0	2017-07-22 01:48:00+03	133700.00
FE8C21	2017-08-14 22:22:00+03	166100.00
FE8C3A	2017-08-14 11:15:00+03	22000.00
FE8C62	2017-08-01 23:11:00+03	37700.00
FE8CC4	2017-08-14 07:18:00+03	36800.00
FE8CF3	2017-07-15 08:37:00+03	83700.00
FE8D1C	2017-07-22 03:32:00+03	56000.00
FE8D41	2017-07-18 16:46:00+03	25600.00
FE8D58	2017-08-13 02:32:00+03	73600.00
FE8DC3	2017-07-05 10:06:00+03	66600.00
FE8DC9	2017-07-29 01:25:00+03	172700.00
FE8EAF	2017-07-22 19:43:00+03	112000.00
FE8EB1	2017-08-09 20:19:00+03	21200.00
FE8EB5	2017-08-09 20:40:00+03	27200.00
FE8EC3	2017-07-26 20:54:00+03	25800.00
FE8F71	2017-08-15 02:57:00+03	43500.00
FE8F7B	2017-08-09 14:08:00+03	103300.00
FE8F8C	2017-07-25 02:19:00+03	59000.00
FE8F8F	2017-08-08 01:13:00+03	259100.00
FE8FC2	2017-08-11 20:25:00+03	54500.00
FE9084	2017-07-31 03:09:00+03	126500.00
FE90BF	2017-08-07 21:59:00+03	260300.00
FE90EC	2017-07-12 08:26:00+03	66300.00
FE90ED	2017-07-20 06:44:00+03	43000.00
FE917B	2017-08-08 11:15:00+03	130400.00
FE9186	2017-08-10 17:20:00+03	56600.00
FE922E	2017-07-06 07:14:00+03	69000.00
FE92C5	2017-06-28 23:29:00+03	62000.00
FE932E	2017-07-03 15:43:00+03	17000.00
FE93B0	2017-07-22 18:08:00+03	67000.00
FE93DA	2017-07-29 08:25:00+03	67200.00
FE9415	2017-08-06 20:33:00+03	65900.00
FE942F	2017-08-13 08:49:00+03	48800.00
FE9438	2017-07-18 07:59:00+03	26300.00
FE94F9	2017-08-06 07:07:00+03	67600.00
FE9507	2017-07-04 20:00:00+03	116100.00
FE9532	2017-08-15 03:26:00+03	51900.00
FE9533	2017-08-03 19:17:00+03	132800.00
FE955C	2017-07-06 12:37:00+03	92800.00
FE9588	2017-08-04 20:44:00+03	28800.00
FE95A6	2017-07-21 09:21:00+03	11600.00
FE9655	2017-08-04 17:43:00+03	471400.00
FE9667	2017-08-02 22:31:00+03	68800.00
FE96C4	2017-08-01 23:33:00+03	40800.00
FE96D9	2017-06-29 13:50:00+03	24600.00
FE970C	2017-08-10 19:30:00+03	88100.00
FE9761	2017-08-11 08:34:00+03	26000.00
FE979B	2017-06-30 15:49:00+03	12200.00
FE983A	2017-07-18 22:07:00+03	31600.00
FE98A3	2017-07-12 14:43:00+03	12200.00
FE98C4	2017-08-14 03:01:00+03	24200.00
FE9947	2017-07-21 10:44:00+03	153300.00
FE9995	2017-07-19 10:00:00+03	27200.00
FE99CB	2017-08-11 03:40:00+03	32700.00
FE99D4	2017-08-14 22:52:00+03	123000.00
FE99DE	2017-08-08 20:10:00+03	102600.00
FE9A53	2017-07-11 10:41:00+03	39600.00
FE9A7D	2017-08-05 16:11:00+03	138800.00
FE9A91	2017-07-10 05:14:00+03	216500.00
FE9A92	2017-07-31 14:33:00+03	246000.00
FE9AB2	2017-07-13 05:03:00+03	136200.00
FE9AB3	2017-08-14 17:56:00+03	23200.00
FE9AD3	2017-08-12 15:44:00+03	56600.00
FE9AE8	2017-07-26 05:22:00+03	50600.00
FE9B28	2017-07-10 14:43:00+03	21800.00
FE9BAA	2017-07-02 09:21:00+03	94200.00
FE9BCE	2017-08-12 20:35:00+03	396500.00
FE9BD9	2017-07-08 08:16:00+03	94700.00
FE9C07	2017-07-19 04:37:00+03	150600.00
FE9C50	2017-07-15 19:46:00+03	181200.00
FE9C51	2017-07-04 01:00:00+03	70500.00
FE9C59	2017-07-29 17:41:00+03	21400.00
FE9C6D	2017-07-15 17:18:00+03	117600.00
FE9CB3	2017-08-12 03:14:00+03	41500.00
FE9CF4	2017-07-23 04:27:00+03	89800.00
FE9D80	2017-07-19 11:03:00+03	44600.00
FE9E07	2017-07-17 04:28:00+03	36600.00
FE9E6C	2017-07-20 00:13:00+03	56100.00
FE9F43	2017-07-28 06:40:00+03	42400.00
FE9F61	2017-07-03 07:26:00+03	24400.00
FEA009	2017-08-09 15:47:00+03	56000.00
FEA00C	2017-07-09 06:58:00+03	81300.00
FEA044	2017-07-13 04:21:00+03	354400.00
FEA0A3	2017-08-14 23:28:00+03	82500.00
FEA0E3	2017-07-15 18:07:00+03	92000.00
FEA0EA	2017-08-14 16:22:00+03	6000.00
FEA0FD	2017-07-26 00:22:00+03	24800.00
FEA116	2017-07-20 04:49:00+03	26000.00
FEA1D3	2017-07-03 12:15:00+03	156500.00
FEA235	2017-07-29 17:16:00+03	61800.00
FEA23A	2017-07-25 22:56:00+03	62100.00
FEA257	2017-07-23 04:42:00+03	99300.00
FEA283	2017-07-12 14:26:00+03	23200.00
FEA340	2017-07-05 17:00:00+03	23200.00
FEA349	2017-07-27 09:03:00+03	232200.00
FEA37C	2017-06-29 11:39:00+03	112600.00
FEA3E3	2017-08-13 08:52:00+03	55800.00
FEA442	2017-07-11 00:06:00+03	39500.00
FEA44B	2017-07-21 21:04:00+03	51600.00
FEA456	2017-08-06 06:21:00+03	36200.00
FEA47B	2017-08-03 14:16:00+03	8200.00
FEA4B9	2017-07-21 04:00:00+03	39200.00
FEA551	2017-07-01 07:04:00+03	66600.00
FEA579	2017-08-02 10:09:00+03	72400.00
FEA5AB	2017-07-11 00:08:00+03	111600.00
FEA5F2	2017-07-21 17:03:00+03	46400.00
FEA630	2017-07-10 20:54:00+03	56600.00
FEA632	2017-07-09 08:55:00+03	40800.00
FEA674	2017-08-02 08:33:00+03	112000.00
FEA6A5	2017-07-04 11:19:00+03	26600.00
FEA6E6	2017-07-09 20:18:00+03	116000.00
FEA706	2017-07-03 04:03:00+03	56000.00
FEA707	2017-07-06 19:08:00+03	38400.00
FEA74D	2017-07-01 14:00:00+03	159100.00
FEA755	2017-07-16 23:12:00+03	38200.00
FEA76A	2017-08-10 19:35:00+03	117600.00
FEA775	2017-07-26 02:08:00+03	28800.00
FEA7BE	2017-08-08 10:47:00+03	98200.00
FEA7EE	2017-08-06 21:47:00+03	116000.00
FEA7FB	2017-08-14 03:32:00+03	52700.00
FEA815	2017-07-27 16:06:00+03	90400.00
FEA868	2017-07-12 02:32:00+03	94000.00
FEA8A0	2017-07-20 15:36:00+03	243600.00
FEA8EE	2017-06-29 00:15:00+03	46300.00
FEA92F	2017-08-13 13:20:00+03	89700.00
FEA96D	2017-08-09 18:23:00+03	15100.00
FEA98A	2017-08-15 01:20:00+03	155500.00
FEAA41	2017-07-16 13:37:00+03	34000.00
FEAA88	2017-07-08 06:32:00+03	21200.00
FEAA9E	2017-08-10 12:12:00+03	32700.00
FEAAB9	2017-07-27 06:09:00+03	27600.00
FEAB9D	2017-08-12 18:03:00+03	64700.00
FEABBF	2017-08-11 15:31:00+03	21400.00
FEABC2	2017-08-05 13:16:00+03	47000.00
FEABFA	2017-07-13 11:33:00+03	103600.00
FEAC12	2017-08-04 22:04:00+03	18600.00
FEACF8	2017-07-20 23:26:00+03	51600.00
FEAD2F	2017-08-10 13:10:00+03	32700.00
FEADD1	2017-07-29 07:20:00+03	362800.00
FEADDC	2017-08-11 13:15:00+03	79000.00
FEAE6B	2017-08-10 00:35:00+03	25800.00
FEAEBA	2017-07-19 18:15:00+03	58200.00
FEAED4	2017-07-16 18:34:00+03	26200.00
FEAEE4	2017-07-17 03:08:00+03	53400.00
FEAF79	2017-08-11 21:46:00+03	26000.00
FEAF99	2017-08-06 16:19:00+03	15000.00
FEAFD3	2017-08-08 05:57:00+03	29800.00
FEB036	2017-07-18 14:38:00+03	14000.00
FEB037	2017-07-09 07:31:00+03	63900.00
FEB043	2017-07-31 11:51:00+03	139200.00
FEB089	2017-07-07 03:22:00+03	20400.00
FEB0AD	2017-08-03 02:36:00+03	73600.00
FEB0B4	2017-08-14 13:57:00+03	40400.00
FEB0D2	2017-07-07 22:12:00+03	290500.00
FEB0DE	2017-07-11 17:11:00+03	60000.00
FEB0E7	2017-08-01 07:54:00+03	53200.00
FEB12B	2017-08-12 20:55:00+03	103900.00
FEB14B	2017-08-13 10:18:00+03	35200.00
FEB15A	2017-08-15 07:54:00+03	14900.00
FEB16C	2017-07-25 19:23:00+03	19600.00
FEB18D	2017-07-22 18:37:00+03	56600.00
FEB1A6	2017-08-03 04:00:00+03	174900.00
FEB1E0	2017-07-13 14:50:00+03	56100.00
FEB228	2017-07-16 02:43:00+03	25400.00
FEB388	2017-07-01 17:30:00+03	202100.00
FEB3AC	2017-08-11 23:02:00+03	82600.00
FEB3B5	2017-07-08 15:56:00+03	49100.00
FEB3E9	2017-07-09 16:28:00+03	117200.00
FEB449	2017-07-17 13:52:00+03	40000.00
FEB4D4	2017-07-23 08:01:00+03	81700.00
FEB542	2017-07-21 13:25:00+03	13400.00
FEB55A	2017-07-23 07:49:00+03	7400.00
FEB583	2017-07-31 09:19:00+03	51900.00
FEB58D	2017-07-05 19:26:00+03	189800.00
FEB5C3	2017-07-21 22:46:00+03	395500.00
FEB631	2017-07-04 18:20:00+03	28000.00
FEB654	2017-07-02 04:41:00+03	24700.00
FEB66E	2017-07-16 07:31:00+03	57100.00
FEB670	2017-08-06 16:44:00+03	128800.00
FEB716	2017-08-01 15:25:00+03	254900.00
FEB73E	2017-08-02 18:26:00+03	81700.00
FEB752	2017-07-06 04:01:00+03	257300.00
FEB791	2017-07-13 18:46:00+03	12000.00
FEB7A4	2017-07-10 02:24:00+03	28800.00
FEB7BB	2017-07-06 16:42:00+03	47000.00
FEB7E1	2017-08-04 19:51:00+03	62800.00
FEB808	2017-08-06 19:15:00+03	13600.00
FEB825	2017-07-17 06:52:00+03	46800.00
FEB8EA	2017-07-03 13:27:00+03	136800.00
FEB8F2	2017-07-16 01:30:00+03	85000.00
FEB915	2017-07-21 13:22:00+03	62800.00
FEB91C	2017-07-12 23:30:00+03	16400.00
FEB94C	2017-07-20 19:02:00+03	23200.00
FEB95B	2017-07-27 10:03:00+03	64600.00
FEB98E	2017-07-26 17:44:00+03	58500.00
FEB9BD	2017-07-03 20:39:00+03	666000.00
FEBA04	2017-07-24 07:49:00+03	118200.00
FEBA5C	2017-07-31 05:12:00+03	14000.00
FEBA7A	2017-07-08 23:30:00+03	81600.00
FEBAE4	2017-07-27 15:26:00+03	7400.00
FEBB4A	2017-07-17 07:29:00+03	131100.00
FEBB6A	2017-07-03 16:28:00+03	68800.00
FEBB77	2017-07-10 23:47:00+03	22000.00
FEBBE1	2017-08-02 00:02:00+03	22000.00
FEBBE2	2017-08-01 15:19:00+03	128400.00
FEBCFD	2017-07-14 12:26:00+03	83600.00
FEBD0A	2017-07-11 04:35:00+03	246000.00
FEBD16	2017-07-14 23:17:00+03	51600.00
FEBDA5	2017-06-28 05:15:00+03	24400.00
FEBDBA	2017-07-20 16:09:00+03	126300.00
FEBE34	2017-07-05 19:13:00+03	103900.00
FEBE6C	2017-07-30 14:19:00+03	369000.00
FEBEB2	2017-07-17 13:46:00+03	24800.00
FEBEF0	2017-07-02 21:46:00+03	35700.00
FEBF4C	2017-07-16 13:43:00+03	218100.00
FEBF50	2017-08-15 07:01:00+03	36800.00
FEBF92	2017-08-09 18:28:00+03	123000.00
FEC002	2017-07-05 22:45:00+03	23400.00
FEC04A	2017-08-08 17:41:00+03	66600.00
FEC051	2017-07-16 18:40:00+03	38500.00
FEC071	2017-08-13 05:25:00+03	103200.00
FEC0F7	2017-08-12 21:50:00+03	69500.00
FEC0FA	2017-07-18 13:59:00+03	21800.00
FEC11C	2017-07-24 08:24:00+03	65800.00
FEC19E	2017-07-23 05:17:00+03	68800.00
FEC1AE	2017-07-31 00:12:00+03	69500.00
FEC1B5	2017-07-04 06:43:00+03	67800.00
FEC1BE	2017-07-28 21:38:00+03	8400.00
FEC1CA	2017-08-03 10:31:00+03	55800.00
FEC1D1	2017-07-21 20:20:00+03	85400.00
FEC21C	2017-07-17 14:10:00+03	25400.00
FEC268	2017-08-01 07:27:00+03	168600.00
FEC2B6	2017-08-12 21:19:00+03	50800.00
FEC36B	2017-07-18 08:22:00+03	89200.00
FEC36F	2017-07-31 13:30:00+03	258400.00
FEC3B3	2017-07-21 13:43:00+03	18000.00
FEC408	2017-08-10 04:11:00+03	38600.00
FEC439	2017-08-07 02:51:00+03	8200.00
FEC447	2017-06-27 02:47:00+03	32800.00
FEC467	2017-07-20 13:36:00+03	49600.00
FEC46F	2017-07-02 17:48:00+03	260900.00
FEC4A9	2017-07-06 16:11:00+03	167400.00
FEC4EA	2017-07-12 13:39:00+03	26000.00
FEC516	2017-07-29 14:52:00+03	56700.00
FEC53B	2017-08-15 08:28:00+03	21800.00
FEC562	2017-07-06 18:14:00+03	79900.00
FEC5E0	2017-08-15 03:27:00+03	36600.00
FEC640	2017-07-14 01:43:00+03	52000.00
FEC72A	2017-07-19 11:25:00+03	24500.00
FEC8F8	2017-07-04 13:07:00+03	64400.00
FEC927	2017-07-20 01:53:00+03	271400.00
FEC947	2017-07-24 20:02:00+03	119000.00
FEC965	2017-08-02 05:25:00+03	56600.00
FEC9A7	2017-06-28 22:30:00+03	42800.00
FEC9EF	2017-07-30 15:20:00+03	125200.00
FEC9FF	2017-08-07 08:59:00+03	123600.00
FECA37	2017-07-13 13:59:00+03	399600.00
FECA44	2017-07-14 15:49:00+03	12600.00
FECA4F	2017-07-27 15:51:00+03	28800.00
FECAE1	2017-07-05 16:21:00+03	139100.00
FECB62	2017-07-05 14:21:00+03	18600.00
FECB74	2017-07-19 23:55:00+03	6700.00
FECB75	2017-07-22 10:52:00+03	26700.00
FECBCC	2017-08-10 18:48:00+03	84500.00
FECBCD	2017-07-29 20:01:00+03	63200.00
FECBFC	2017-06-29 03:02:00+03	141400.00
FECCBA	2017-08-10 13:27:00+03	58400.00
FECCEA	2017-08-14 12:58:00+03	189200.00
FECD1C	2017-08-05 04:00:00+03	28800.00
FECD62	2017-07-29 10:22:00+03	54400.00
FECD80	2017-07-28 04:35:00+03	57600.00
FECD82	2017-07-08 15:57:00+03	79900.00
FECDA5	2017-07-17 13:01:00+03	51000.00
FECE4A	2017-07-31 07:18:00+03	28800.00
FECEFC	2017-07-30 14:41:00+03	102600.00
FECF13	2017-07-09 15:37:00+03	46300.00
FECF23	2017-08-01 23:04:00+03	88600.00
FECF2D	2017-07-21 07:02:00+03	136200.00
FECF3D	2017-08-03 06:57:00+03	177200.00
FECF43	2017-06-30 10:13:00+03	46000.00
FECF67	2017-08-09 11:06:00+03	52000.00
FECFBF	2017-07-30 12:14:00+03	26000.00
FECFC4	2017-08-10 12:06:00+03	65900.00
FED0AA	2017-07-31 18:35:00+03	81600.00
FED0C9	2017-07-30 22:31:00+03	112600.00
FED0F2	2017-07-02 18:47:00+03	115600.00
FED104	2017-07-02 20:19:00+03	112000.00
FED14D	2017-08-15 02:42:00+03	169600.00
FED182	2017-07-01 22:53:00+03	38800.00
FED23A	2017-07-30 13:13:00+03	105600.00
FED23E	2017-07-28 03:37:00+03	46400.00
FED26A	2017-07-01 14:51:00+03	15000.00
FED27C	2017-07-10 08:21:00+03	21400.00
FED284	2017-08-15 05:07:00+03	39500.00
FED29F	2017-08-11 01:26:00+03	19800.00
FED314	2017-08-13 23:17:00+03	156500.00
FED3B7	2017-07-28 01:56:00+03	56000.00
FED445	2017-07-28 07:48:00+03	58900.00
FED488	2017-07-23 17:58:00+03	76600.00
FED4F0	2017-08-10 12:58:00+03	171100.00
FED50D	2017-07-14 05:47:00+03	91400.00
FED517	2017-08-03 07:33:00+03	54500.00
FED542	2017-07-31 15:51:00+03	97900.00
FED61B	2017-08-12 10:19:00+03	39200.00
FED635	2017-07-22 15:44:00+03	18000.00
FED675	2017-08-03 03:19:00+03	38800.00
FED697	2017-07-17 07:34:00+03	58800.00
FED6D0	2017-08-15 04:02:00+03	117600.00
FED6EB	2017-07-23 00:27:00+03	136200.00
FED6FC	2017-07-31 23:53:00+03	23200.00
FED713	2017-08-08 23:59:00+03	99700.00
FED7DA	2017-07-17 13:28:00+03	63200.00
FED828	2017-07-06 23:59:00+03	48800.00
FED871	2017-07-09 22:15:00+03	46200.00
FED8ED	2017-07-09 17:26:00+03	28000.00
FED8F1	2017-08-07 16:51:00+03	246000.00
FED925	2017-07-22 11:04:00+03	26600.00
FED93C	2017-08-15 12:16:00+03	14000.00
FED95F	2017-07-09 22:45:00+03	115800.00
FED9CB	2017-07-31 05:21:00+03	26800.00
FEDA26	2017-07-06 07:46:00+03	77000.00
FEDA92	2017-07-08 14:35:00+03	35400.00
FEDAA4	2017-07-24 03:30:00+03	70800.00
FEDB91	2017-08-04 01:21:00+03	35500.00
FEDB95	2017-08-04 22:53:00+03	40600.00
FEDC31	2017-06-29 17:58:00+03	193600.00
FEDCB2	2017-07-23 05:25:00+03	25600.00
FEDCD6	2017-08-12 02:28:00+03	40800.00
FEDCF4	2017-08-02 06:05:00+03	12400.00
FEDD28	2017-08-07 00:30:00+03	30000.00
FEDDE2	2017-07-30 20:47:00+03	58800.00
FEDDE8	2017-07-18 19:36:00+03	42800.00
FEDDF5	2017-08-04 21:20:00+03	32400.00
FEDEAE	2017-07-29 02:34:00+03	117200.00
FEDEE3	2017-08-07 15:50:00+03	16800.00
FEDF4E	2017-07-08 18:11:00+03	34100.00
FEDF61	2017-07-19 16:23:00+03	272400.00
FEDFCD	2017-07-10 18:06:00+03	34200.00
FEE020	2017-08-03 21:19:00+03	14400.00
FEE04A	2017-07-30 17:33:00+03	86400.00
FEE062	2017-08-09 12:32:00+03	71600.00
FEE07A	2017-07-26 12:33:00+03	137100.00
FEE08B	2017-08-12 06:58:00+03	31600.00
FEE0B7	2017-07-02 19:55:00+03	57500.00
FEE118	2017-07-17 23:20:00+03	198300.00
FEE11E	2017-07-15 04:18:00+03	28000.00
FEE13B	2017-07-06 10:07:00+03	63800.00
FEE153	2017-08-10 10:55:00+03	23100.00
FEE175	2017-06-27 06:32:00+03	33500.00
FEE1E1	2017-08-02 22:32:00+03	57500.00
FEE267	2017-07-01 13:23:00+03	67600.00
FEE2A1	2017-07-26 00:23:00+03	8400.00
FEE30E	2017-08-11 15:29:00+03	248300.00
FEE361	2017-07-08 00:02:00+03	32300.00
FEE3BE	2017-08-02 18:36:00+03	115100.00
FEE3C1	2017-08-15 06:34:00+03	157000.00
FEE3C7	2017-07-17 10:17:00+03	25200.00
FEE490	2017-07-24 19:55:00+03	71900.00
FEE58C	2017-07-20 16:56:00+03	79800.00
FEE58E	2017-07-23 03:46:00+03	24700.00
FEE640	2017-07-02 21:27:00+03	63200.00
FEE70F	2017-07-28 22:08:00+03	223200.00
FEE771	2017-07-06 06:21:00+03	23200.00
FEE78E	2017-07-16 13:05:00+03	196000.00
FEE78F	2017-07-25 17:44:00+03	16400.00
FEE7C9	2017-08-04 07:20:00+03	283100.00
FEE7D0	2017-07-16 06:21:00+03	135900.00
FEE7EC	2017-08-09 13:46:00+03	58600.00
FEE842	2017-07-30 13:06:00+03	14700.00
FEE849	2017-08-12 23:59:00+03	50700.00
FEE85F	2017-07-30 06:49:00+03	40400.00
FEE87F	2017-07-24 13:11:00+03	43500.00
FEE8A7	2017-07-19 19:34:00+03	144400.00
FEE8D9	2017-08-06 07:10:00+03	118200.00
FEE8FB	2017-07-25 03:33:00+03	96300.00
FEE918	2017-08-04 23:39:00+03	122100.00
FEE982	2017-08-08 03:19:00+03	135400.00
FEEA0E	2017-08-01 10:56:00+03	39500.00
FEEA12	2017-07-13 10:31:00+03	115800.00
FEEA27	2017-07-27 21:42:00+03	207300.00
FEEA2D	2017-07-30 07:00:00+03	20000.00
FEEA87	2017-07-05 20:54:00+03	136800.00
FEEAC4	2017-07-28 00:12:00+03	44000.00
FEEB7D	2017-08-08 08:52:00+03	31400.00
FEEC89	2017-08-03 01:10:00+03	67600.00
FEECDD	2017-07-22 08:26:00+03	31200.00
FEECFA	2017-08-09 11:22:00+03	369000.00
FEED08	2017-07-29 23:02:00+03	49800.00
FEED23	2017-07-03 03:52:00+03	13800.00
FEED34	2017-08-05 03:37:00+03	168000.00
FEED5C	2017-07-28 19:53:00+03	74800.00
FEEEC0	2017-07-21 07:48:00+03	20200.00
FEEF02	2017-07-03 15:13:00+03	62400.00
FEEF5E	2017-07-09 00:57:00+03	66600.00
FEEF8F	2017-08-09 18:13:00+03	48800.00
FEEFF6	2017-07-21 22:09:00+03	123000.00
FEF0A4	2017-07-17 23:01:00+03	50000.00
FEF0B7	2017-08-07 02:46:00+03	29600.00
FEF103	2017-07-18 21:17:00+03	24000.00
FEF1E3	2017-07-13 21:52:00+03	76600.00
FEF1EC	2017-07-20 03:32:00+03	111700.00
FEF285	2017-08-05 12:26:00+03	317400.00
FEF2CD	2017-07-25 11:39:00+03	183600.00
FEF2EC	2017-07-07 21:48:00+03	28000.00
FEF313	2017-07-28 06:27:00+03	187600.00
FEF329	2017-07-02 05:06:00+03	121400.00
FEF343	2017-07-05 11:20:00+03	46000.00
FEF346	2017-07-12 21:35:00+03	179400.00
FEF357	2017-07-20 14:04:00+03	79100.00
FEF3AA	2017-08-08 00:15:00+03	143800.00
FEF3CD	2017-07-11 01:37:00+03	6000.00
FEF3CE	2017-08-12 11:20:00+03	24200.00
FEF3D0	2017-08-04 02:30:00+03	24600.00
FEF3FF	2017-07-04 20:15:00+03	94800.00
FEF42C	2017-08-10 15:28:00+03	24400.00
FEF448	2017-07-20 21:10:00+03	30900.00
FEF465	2017-07-27 05:09:00+03	64000.00
FEF469	2017-07-17 18:00:00+03	119200.00
FEF486	2017-07-22 09:19:00+03	39500.00
FEF494	2017-07-07 01:05:00+03	168000.00
FEF4A0	2017-08-09 02:48:00+03	26000.00
FEF4B0	2017-07-06 06:25:00+03	21400.00
FEF4B6	2017-07-03 10:55:00+03	38600.00
FEF512	2017-08-05 14:25:00+03	117600.00
FEF529	2017-08-02 03:18:00+03	28000.00
FEF578	2017-07-29 20:01:00+03	12600.00
FEF5F1	2017-07-29 13:31:00+03	369000.00
FEF63A	2017-07-26 13:10:00+03	46000.00
FEF741	2017-07-31 15:07:00+03	40800.00
FEF7F7	2017-07-28 04:02:00+03	42800.00
FEF90B	2017-07-15 13:15:00+03	16400.00
FEF91F	2017-08-10 01:27:00+03	254600.00
FEF95E	2017-07-11 07:28:00+03	92400.00
FEF9BF	2017-08-03 14:41:00+03	46200.00
FEFA6E	2017-07-25 15:16:00+03	13400.00
FEFAEC	2017-08-09 14:10:00+03	24000.00
FEFAFF	2017-07-26 09:09:00+03	57500.00
FEFB12	2017-07-10 10:30:00+03	12600.00
FEFB4E	2017-08-07 10:51:00+03	271200.00
FEFBA0	2017-07-14 18:43:00+03	155600.00
FEFC02	2017-08-15 01:47:00+03	25100.00
FEFC33	2017-07-05 07:22:00+03	100000.00
FEFC88	2017-08-05 12:38:00+03	51300.00
FEFC8F	2017-08-04 13:09:00+03	109600.00
FEFCC7	2017-06-30 21:33:00+03	187600.00
FEFD0F	2017-07-16 11:13:00+03	118100.00
FEFD38	2017-08-03 02:32:00+03	167400.00
FEFD60	2017-07-09 10:50:00+03	13700.00
FEFD67	2017-08-06 19:41:00+03	255000.00
FEFDA0	2017-08-03 15:41:00+03	136200.00
FEFDE8	2017-07-28 12:56:00+03	87300.00
FEFE29	2017-08-10 13:53:00+03	8000.00
FEFE37	2017-07-08 18:06:00+03	47400.00
FEFE67	2017-08-10 03:48:00+03	103200.00
FEFEAB	2017-07-11 13:15:00+03	16400.00
FEFECD	2017-07-21 15:09:00+03	39500.00
FEFF0B	2017-06-27 01:10:00+03	8200.00
FEFF3B	2017-07-19 17:02:00+03	16400.00
FEFF43	2017-07-31 13:05:00+03	28000.00
FEFF59	2017-06-29 05:44:00+03	52000.00
FEFF6E	2017-08-07 19:48:00+03	53800.00
FEFFAB	2017-08-11 22:00:00+03	39300.00
FEFFAD	2017-07-30 13:38:00+03	54000.00
FF001E	2017-08-01 03:12:00+03	83300.00
FF0058	2017-06-30 23:55:00+03	56000.00
FF0096	2017-07-09 17:06:00+03	46400.00
FF00CB	2017-08-04 05:28:00+03	57400.00
FF012E	2017-07-30 09:22:00+03	37200.00
FF0147	2017-08-11 06:11:00+03	31400.00
FF01D2	2017-07-08 02:48:00+03	93500.00
FF0240	2017-08-03 14:02:00+03	40400.00
FF02BF	2017-08-15 04:04:00+03	143800.00
FF031A	2017-07-11 11:08:00+03	58400.00
FF0327	2017-07-11 15:07:00+03	73500.00
FF0331	2017-07-24 07:06:00+03	84100.00
FF034C	2017-07-08 06:45:00+03	75200.00
FF037B	2017-07-05 06:53:00+03	518000.00
FF037D	2017-07-21 12:25:00+03	46000.00
FF0392	2017-07-16 03:39:00+03	30400.00
FF039F	2017-08-09 19:47:00+03	59000.00
FF0410	2017-08-03 06:34:00+03	118000.00
FF041B	2017-07-30 02:50:00+03	116400.00
FF0440	2017-07-09 05:51:00+03	30400.00
FF0489	2017-07-26 18:18:00+03	124200.00
FF04AF	2017-07-13 16:30:00+03	36900.00
FF04B3	2017-08-06 05:12:00+03	86400.00
FF04BB	2017-07-28 05:56:00+03	62600.00
FF0510	2017-07-22 04:32:00+03	100200.00
FF0602	2017-08-09 19:33:00+03	13400.00
FF060B	2017-07-05 07:11:00+03	190700.00
FF068A	2017-08-15 12:31:00+03	27400.00
FF06A3	2017-08-06 02:18:00+03	48800.00
FF06BD	2017-07-14 10:42:00+03	9200.00
FF0747	2017-07-29 19:23:00+03	270200.00
FF0774	2017-07-23 06:32:00+03	82100.00
FF0862	2017-08-01 03:15:00+03	26200.00
FF08CF	2017-07-19 12:42:00+03	63200.00
FF0916	2017-07-22 00:51:00+03	27200.00
FF0961	2017-08-15 17:58:00+03	6000.00
FF09B5	2017-07-06 20:17:00+03	57600.00
FF09CC	2017-07-03 17:25:00+03	99000.00
FF09D2	2017-07-11 05:08:00+03	27200.00
FF09FA	2017-07-27 10:03:00+03	43300.00
FF0A79	2017-07-24 21:26:00+03	40200.00
FF0AD4	2017-07-12 17:31:00+03	123000.00
FF0AF2	2017-07-21 14:54:00+03	121700.00
FF0B0A	2017-07-31 10:02:00+03	39100.00
FF0B97	2017-07-08 05:12:00+03	40400.00
FF0BCD	2017-07-30 09:33:00+03	47000.00
FF0BEA	2017-07-15 13:49:00+03	38800.00
FF0C2A	2017-08-07 08:41:00+03	21400.00
FF0C39	2017-06-28 17:06:00+03	55500.00
FF0C47	2017-07-20 11:33:00+03	23400.00
FF0C91	2017-08-11 22:58:00+03	28000.00
FF0D36	2017-07-26 20:41:00+03	69500.00
FF0DD5	2017-07-26 16:04:00+03	12000.00
FF0DEE	2017-08-08 13:56:00+03	35200.00
FF0E19	2017-08-15 01:59:00+03	40900.00
FF0E44	2017-08-01 02:08:00+03	56000.00
FF0EC9	2017-07-16 00:16:00+03	71500.00
FF0EFD	2017-07-04 10:50:00+03	59400.00
FF0F34	2017-08-11 20:57:00+03	24300.00
FF0F73	2017-06-30 13:46:00+03	121500.00
FF0FDA	2017-08-09 11:42:00+03	85700.00
FF1013	2017-07-07 06:12:00+03	29600.00
FF1058	2017-07-03 17:14:00+03	23100.00
FF106E	2017-07-20 20:13:00+03	182200.00
FF1087	2017-07-19 23:45:00+03	76600.00
FF10E0	2017-08-09 08:09:00+03	70200.00
FF1110	2017-07-30 16:22:00+03	86600.00
FF1141	2017-07-18 06:44:00+03	47100.00
FF114D	2017-08-01 01:51:00+03	45400.00
FF1160	2017-07-25 18:29:00+03	22000.00
FF1161	2017-07-18 10:29:00+03	311200.00
FF11CB	2017-08-08 03:24:00+03	111600.00
FF11F3	2017-07-08 16:35:00+03	55800.00
FF1263	2017-08-08 19:41:00+03	49600.00
FF1365	2017-08-12 02:10:00+03	18600.00
FF1366	2017-07-19 19:58:00+03	184500.00
FF1383	2017-07-26 08:49:00+03	88000.00
FF138D	2017-08-14 20:42:00+03	24800.00
FF139B	2017-08-15 09:53:00+03	128900.00
FF145F	2017-07-07 13:30:00+03	69800.00
FF14B5	2017-08-09 22:17:00+03	40700.00
FF14D0	2017-08-12 13:57:00+03	81900.00
FF155D	2017-07-12 16:32:00+03	49800.00
FF15E4	2017-07-09 13:41:00+03	40800.00
FF1638	2017-08-14 01:54:00+03	27800.00
FF180D	2017-07-12 11:50:00+03	37900.00
FF1880	2017-08-10 07:15:00+03	38800.00
FF1888	2017-07-26 17:48:00+03	9200.00
FF188E	2017-08-06 14:40:00+03	44000.00
FF18C2	2017-07-03 20:10:00+03	226900.00
FF18CC	2017-07-29 17:58:00+03	44800.00
FF1902	2017-07-20 12:11:00+03	99700.00
FF1965	2017-07-08 07:02:00+03	23400.00
FF19BA	2017-07-31 19:31:00+03	34000.00
FF1A33	2017-07-14 22:47:00+03	128800.00
FF1A54	2017-07-27 06:20:00+03	25200.00
FF1AEB	2017-07-11 20:29:00+03	18800.00
FF1B07	2017-08-06 05:43:00+03	45100.00
FF1B49	2017-06-30 02:48:00+03	69400.00
FF1B4A	2017-07-31 21:23:00+03	16400.00
FF1BC2	2017-07-01 01:39:00+03	37900.00
FF1C1B	2017-07-15 10:57:00+03	54000.00
FF1C52	2017-07-26 03:50:00+03	28200.00
FF1C7F	2017-08-05 22:42:00+03	21800.00
FF1C8C	2017-08-13 04:37:00+03	54000.00
FF1C9A	2017-08-10 09:30:00+03	84100.00
FF1C9B	2017-07-20 13:44:00+03	44800.00
FF1D10	2017-08-09 13:06:00+03	60400.00
FF1D54	2017-07-31 20:31:00+03	47100.00
FF1D68	2017-08-09 15:10:00+03	24000.00
FF1D7E	2017-08-12 22:57:00+03	24700.00
FF1D84	2017-07-04 00:31:00+03	28000.00
FF1E01	2017-08-13 10:24:00+03	100200.00
FF1E0B	2017-07-09 19:25:00+03	16400.00
FF1E61	2017-08-07 09:59:00+03	123000.00
FF1E72	2017-08-14 01:12:00+03	43900.00
FF1EAA	2017-08-01 13:22:00+03	53200.00
FF1EFC	2017-07-05 16:50:00+03	35200.00
FF1F2B	2017-07-11 19:55:00+03	6700.00
FF1F55	2017-07-02 12:31:00+03	76400.00
FF1F90	2017-07-10 07:23:00+03	155600.00
FF1FDF	2017-07-29 05:31:00+03	23900.00
FF2002	2017-07-01 20:06:00+03	14000.00
FF2072	2017-07-15 18:27:00+03	24400.00
FF20CE	2017-07-11 02:00:00+03	150600.00
FF20F7	2017-08-11 21:34:00+03	46000.00
FF2132	2017-08-04 04:53:00+03	170700.00
FF2134	2017-08-07 16:38:00+03	22000.00
FF21B2	2017-07-13 13:01:00+03	155600.00
FF21D6	2017-06-30 08:59:00+03	40400.00
FF2220	2017-08-01 21:01:00+03	65900.00
FF2239	2017-07-18 02:51:00+03	193600.00
FF2243	2017-07-09 19:46:00+03	15800.00
FF226B	2017-08-14 07:12:00+03	26000.00
FF227E	2017-07-16 02:30:00+03	23600.00
FF2295	2017-08-09 11:11:00+03	32800.00
FF22A6	2017-08-08 04:41:00+03	40100.00
FF22EB	2017-07-06 05:45:00+03	95400.00
FF22FD	2017-07-05 01:21:00+03	56900.00
FF2314	2017-07-24 22:23:00+03	23200.00
FF231D	2017-07-09 10:13:00+03	36600.00
FF234A	2017-08-09 07:05:00+03	150600.00
FF2369	2017-07-04 06:49:00+03	69500.00
FF2379	2017-08-03 12:41:00+03	88900.00
FF23DF	2017-07-27 06:06:00+03	101200.00
FF2419	2017-08-10 22:43:00+03	115800.00
FF241C	2017-07-22 10:13:00+03	65900.00
FF2434	2017-07-16 17:58:00+03	56000.00
FF2444	2017-08-10 08:20:00+03	54800.00
FF2459	2017-07-29 22:25:00+03	62100.00
FF2493	2017-07-10 12:06:00+03	32800.00
FF249C	2017-07-03 23:13:00+03	43000.00
FF2500	2017-07-14 00:28:00+03	118600.00
FF254B	2017-07-09 07:55:00+03	63100.00
FF25D0	2017-08-04 17:13:00+03	26000.00
FF25ED	2017-07-01 05:48:00+03	38800.00
FF2608	2017-08-14 05:22:00+03	9200.00
FF266D	2017-07-08 08:51:00+03	674600.00
FF2742	2017-08-12 22:19:00+03	25200.00
FF2794	2017-08-10 22:40:00+03	492000.00
FF27D5	2017-08-12 14:14:00+03	42800.00
FF27DF	2017-07-20 06:38:00+03	62600.00
FF27FB	2017-08-14 17:03:00+03	92800.00
FF2857	2017-07-31 11:18:00+03	176800.00
FF2882	2017-07-30 02:37:00+03	179300.00
FF289F	2017-08-15 12:17:00+03	166100.00
FF2949	2017-07-15 20:54:00+03	68000.00
FF29C0	2017-07-09 07:41:00+03	93600.00
FF2A42	2017-07-04 10:01:00+03	6000.00
FF2ADE	2017-07-30 16:40:00+03	23600.00
FF2AEE	2017-07-19 07:01:00+03	114300.00
FF2AF4	2017-08-09 16:39:00+03	21800.00
FF2B50	2017-08-08 21:18:00+03	12600.00
FF2BEB	2017-08-11 22:00:00+03	47000.00
FF2C14	2017-07-16 08:07:00+03	87000.00
FF2C45	2017-07-21 13:39:00+03	31200.00
FF2C4B	2017-07-07 03:50:00+03	123000.00
FF2C7E	2017-07-15 15:24:00+03	18400.00
FF2CFA	2017-07-06 10:55:00+03	132200.00
FF2D81	2017-07-21 03:30:00+03	185600.00
FF2DA3	2017-07-23 22:58:00+03	51500.00
FF2DBF	2017-07-10 16:18:00+03	100600.00
FF2E8B	2017-07-02 13:02:00+03	111600.00
FF2EAD	2017-08-10 04:07:00+03	64200.00
FF2EB3	2017-07-23 04:09:00+03	60800.00
FF2F05	2017-08-03 05:02:00+03	15800.00
FF2F43	2017-07-21 08:50:00+03	23600.00
FF2F4B	2017-06-30 02:09:00+03	30900.00
FF2F57	2017-07-07 13:47:00+03	29200.00
FF2FCA	2017-07-22 23:54:00+03	46400.00
FF2FE2	2017-08-03 15:40:00+03	65600.00
FF3089	2017-07-12 15:20:00+03	84000.00
FF30DB	2017-07-13 18:31:00+03	123600.00
FF3145	2017-07-02 08:51:00+03	53300.00
FF315B	2017-07-26 19:37:00+03	133200.00
FF3179	2017-07-07 07:34:00+03	65500.00
FF3182	2017-07-11 15:20:00+03	20000.00
FF31B3	2017-07-03 09:05:00+03	24400.00
FF31DF	2017-08-09 06:13:00+03	27200.00
FF320B	2017-08-10 11:18:00+03	147200.00
FF3234	2017-08-03 12:41:00+03	46000.00
FF3253	2017-07-02 00:43:00+03	65600.00
FF3268	2017-07-10 11:45:00+03	14400.00
FF330E	2017-08-01 03:40:00+03	30200.00
FF3333	2017-08-07 15:07:00+03	13600.00
FF3353	2017-08-03 18:32:00+03	82900.00
FF3374	2017-07-02 21:13:00+03	22400.00
FF346E	2017-07-14 05:10:00+03	32200.00
FF3476	2017-08-14 19:57:00+03	60000.00
FF34C0	2017-08-13 04:08:00+03	19600.00
FF34C6	2017-07-17 11:54:00+03	44800.00
FF34F3	2017-08-02 03:15:00+03	56000.00
FF351F	2017-07-19 04:41:00+03	65900.00
FF3535	2017-07-09 01:27:00+03	28800.00
FF354F	2017-07-29 07:32:00+03	99700.00
FF3570	2017-07-06 01:16:00+03	25800.00
FF35B7	2017-08-02 05:41:00+03	598400.00
FF35CB	2017-07-30 20:26:00+03	65300.00
FF35D2	2017-07-14 17:27:00+03	56000.00
FF35D7	2017-08-11 15:38:00+03	66000.00
FF3614	2017-07-04 00:39:00+03	97000.00
FF362D	2017-07-17 06:57:00+03	39800.00
FF3670	2017-07-16 06:35:00+03	112300.00
FF368D	2017-08-09 15:00:00+03	19600.00
FF36C6	2017-07-17 19:55:00+03	14800.00
FF36EA	2017-07-26 08:49:00+03	55800.00
FF36F5	2017-08-09 13:16:00+03	81200.00
FF3701	2017-07-28 16:51:00+03	23200.00
FF3758	2017-07-05 13:37:00+03	123000.00
FF3762	2017-06-29 21:27:00+03	58000.00
FF379A	2017-07-06 15:24:00+03	28800.00
FF37D7	2017-08-14 05:46:00+03	65500.00
FF37E3	2017-07-22 07:57:00+03	30000.00
FF37FC	2017-07-20 15:10:00+03	76900.00
FF3888	2017-07-31 08:50:00+03	81600.00
FF38C7	2017-07-22 20:55:00+03	62500.00
FF38E3	2017-07-13 03:59:00+03	28800.00
FF3924	2017-08-04 13:20:00+03	48800.00
FF3959	2017-07-10 06:18:00+03	38000.00
FF3974	2017-08-10 11:57:00+03	73600.00
FF3994	2017-07-29 23:20:00+03	21400.00
FF39B9	2017-07-29 01:17:00+03	188500.00
FF39BB	2017-08-08 02:03:00+03	13600.00
FF39EA	2017-07-12 19:34:00+03	138400.00
FF3A15	2017-07-09 14:55:00+03	20400.00
FF3A25	2017-07-31 23:13:00+03	61800.00
FF3B33	2017-08-04 09:05:00+03	10600.00
FF3B43	2017-08-06 05:45:00+03	45100.00
FF3B4C	2017-08-14 05:01:00+03	383200.00
FF3B6B	2017-07-06 16:23:00+03	92900.00
FF3BA7	2017-08-12 20:09:00+03	43000.00
FF3BA9	2017-07-05 09:59:00+03	249000.00
FF3BD9	2017-07-03 09:57:00+03	183100.00
FF3BEE	2017-08-01 12:22:00+03	68800.00
FF3C33	2017-08-01 20:30:00+03	62400.00
FF3C3C	2017-07-20 04:56:00+03	36200.00
FF3C48	2017-07-25 13:44:00+03	11600.00
FF3CB1	2017-08-10 19:22:00+03	124200.00
FF3CFB	2017-07-30 13:59:00+03	48800.00
FF3D12	2017-07-15 05:12:00+03	28800.00
FF3D89	2017-06-28 14:51:00+03	26000.00
FF3D8C	2017-07-15 19:26:00+03	520600.00
FF3E49	2017-08-12 03:15:00+03	59600.00
FF3E50	2017-07-29 18:39:00+03	29400.00
FF3E9C	2017-07-13 23:19:00+03	75100.00
FF3EBE	2017-07-13 22:15:00+03	21400.00
FF3EFD	2017-08-12 14:15:00+03	59600.00
FF3F0D	2017-08-01 06:52:00+03	294200.00
FF3F17	2017-07-20 09:52:00+03	103200.00
FF3F41	2017-07-02 16:25:00+03	111900.00
FF3F6E	2017-07-03 15:28:00+03	38400.00
FF3FC0	2017-07-26 08:35:00+03	89700.00
FF401A	2017-07-29 17:02:00+03	13600.00
FF4072	2017-07-27 23:50:00+03	57600.00
FF409A	2017-07-15 10:47:00+03	86700.00
FF4136	2017-08-07 00:30:00+03	329700.00
FF4149	2017-08-11 14:15:00+03	20200.00
FF4182	2017-08-09 16:27:00+03	67200.00
FF4213	2017-08-03 12:02:00+03	24800.00
FF426F	2017-08-03 19:16:00+03	49800.00
FF42C3	2017-07-10 03:20:00+03	32700.00
FF42D5	2017-08-06 10:36:00+03	29200.00
FF42FA	2017-08-02 08:02:00+03	43200.00
FF43B8	2017-07-11 01:54:00+03	40600.00
FF43D9	2017-08-11 09:29:00+03	65100.00
FF4482	2017-08-04 16:42:00+03	406700.00
FF44B2	2017-07-05 07:47:00+03	68400.00
FF4550	2017-07-23 05:43:00+03	32200.00
FF4581	2017-07-03 09:23:00+03	14900.00
FF45D3	2017-08-11 00:30:00+03	92400.00
FF4620	2017-07-22 17:14:00+03	23600.00
FF4641	2017-07-20 13:49:00+03	119600.00
FF464F	2017-07-19 02:16:00+03	114800.00
FF466B	2017-07-29 10:36:00+03	17000.00
FF4694	2017-07-04 11:59:00+03	32800.00
FF469A	2017-08-15 07:57:00+03	6700.00
FF46D2	2017-07-05 22:16:00+03	40200.00
FF46D5	2017-07-21 19:54:00+03	26000.00
FF47C6	2017-08-07 01:29:00+03	28800.00
FF4825	2017-08-08 00:02:00+03	6600.00
FF482C	2017-07-07 21:27:00+03	23200.00
FF485C	2017-07-01 20:10:00+03	83600.00
FF4870	2017-07-28 10:57:00+03	32500.00
FF48A1	2017-07-14 03:25:00+03	94400.00
FF48D0	2017-07-26 10:59:00+03	194600.00
FF48EB	2017-08-12 01:09:00+03	48300.00
FF48FA	2017-07-27 08:28:00+03	64400.00
FF490E	2017-08-02 16:41:00+03	24700.00
FF49D9	2017-07-13 19:27:00+03	55500.00
FF4AC8	2017-08-03 17:03:00+03	23200.00
FF4AEC	2017-07-24 13:39:00+03	93400.00
FF4AF1	2017-07-27 20:19:00+03	31400.00
FF4AFB	2017-07-30 23:28:00+03	10800.00
FF4B16	2017-08-03 12:23:00+03	24400.00
FF4B63	2017-08-15 05:03:00+03	6600.00
FF4C36	2017-08-08 18:02:00+03	258400.00
FF4C4C	2017-08-05 14:01:00+03	6700.00
FF4C4F	2017-07-16 02:55:00+03	40600.00
FF4C51	2017-08-10 12:53:00+03	24800.00
FF4C8D	2017-07-03 22:40:00+03	56000.00
FF4CA8	2017-07-10 00:26:00+03	80400.00
FF4CEB	2017-07-24 04:16:00+03	68400.00
FF4D1A	2017-07-31 13:05:00+03	44600.00
FF4D33	2017-07-16 05:15:00+03	53300.00
FF4E63	2017-07-05 06:08:00+03	23400.00
FF4E6C	2017-07-25 21:31:00+03	50200.00
FF4E8C	2017-08-15 05:00:00+03	42500.00
FF4EBE	2017-08-04 12:56:00+03	39600.00
FF4EFF	2017-08-15 02:56:00+03	30700.00
FF4FCA	2017-08-03 22:04:00+03	16800.00
FF500A	2017-07-01 19:37:00+03	65600.00
FF503B	2017-07-11 12:11:00+03	87000.00
FF50E5	2017-07-14 12:59:00+03	21600.00
FF5100	2017-07-19 03:59:00+03	34000.00
FF5167	2017-08-03 04:24:00+03	39500.00
FF516F	2017-06-26 03:31:00+03	21400.00
FF51E4	2017-08-11 20:41:00+03	77600.00
FF51FC	2017-08-12 18:28:00+03	12600.00
FF520B	2017-07-19 09:36:00+03	206800.00
FF523C	2017-08-11 10:09:00+03	26800.00
FF523E	2017-07-13 03:06:00+03	273600.00
FF528A	2017-07-12 14:56:00+03	16800.00
FF52A9	2017-07-25 17:00:00+03	121800.00
FF53A5	2017-08-07 11:30:00+03	52000.00
FF53A8	2017-07-02 04:03:00+03	49200.00
FF53B8	2017-08-15 16:26:00+03	62400.00
FF53C6	2017-08-04 17:59:00+03	56900.00
FF5400	2017-07-16 11:10:00+03	26000.00
FF5445	2017-07-14 01:29:00+03	12600.00
FF5447	2017-07-04 09:50:00+03	27200.00
FF5470	2017-08-04 00:36:00+03	52900.00
FF5473	2017-08-06 12:20:00+03	76500.00
FF5552	2017-07-28 00:39:00+03	46900.00
FF5561	2017-08-08 22:10:00+03	67000.00
FF5572	2017-07-08 06:55:00+03	194800.00
FF562A	2017-08-13 15:00:00+03	12600.00
FF5665	2017-07-27 17:59:00+03	135600.00
FF56BA	2017-08-13 22:00:00+03	81700.00
FF56E0	2017-07-20 01:59:00+03	7200.00
FF5731	2017-08-02 18:58:00+03	89700.00
FF574D	2017-07-25 22:43:00+03	24700.00
FF57A8	2017-08-15 05:04:00+03	58400.00
FF57A9	2017-08-09 02:03:00+03	354400.00
FF5877	2017-07-25 00:18:00+03	76200.00
FF58CA	2017-07-09 10:49:00+03	74900.00
FF5903	2017-07-27 16:06:00+03	97700.00
FF5976	2017-07-30 12:08:00+03	55800.00
FF59C9	2017-07-08 00:39:00+03	57400.00
FF5A05	2017-08-06 23:39:00+03	301800.00
FF5A3B	2017-08-07 03:44:00+03	31900.00
FF5A9C	2017-07-05 18:50:00+03	58000.00
FF5AC6	2017-07-26 01:02:00+03	29600.00
FF5AD3	2017-07-15 08:45:00+03	68000.00
FF5ADD	2017-08-06 11:56:00+03	94800.00
FF5B00	2017-07-08 11:20:00+03	92900.00
FF5B0A	2017-07-16 01:43:00+03	115700.00
FF5B31	2017-06-29 14:47:00+03	82400.00
FF5B39	2017-07-16 12:42:00+03	30000.00
FF5B8D	2017-07-05 08:52:00+03	12600.00
FF5BB0	2017-07-16 14:43:00+03	147700.00
FF5CCD	2017-07-12 03:45:00+03	6700.00
FF5D33	2017-07-04 13:55:00+03	56100.00
FF5D3E	2017-08-13 07:12:00+03	56000.00
FF5D60	2017-08-04 04:35:00+03	63200.00
FF5D73	2017-08-09 14:18:00+03	40000.00
FF5D7D	2017-07-11 01:52:00+03	29500.00
FF5DB4	2017-07-27 03:11:00+03	25800.00
FF5E27	2017-08-10 00:21:00+03	255000.00
FF5E2D	2017-07-26 11:09:00+03	415100.00
FF5E39	2017-07-12 05:57:00+03	251300.00
FF5E5A	2017-08-07 21:54:00+03	153200.00
FF5E6A	2017-07-23 22:25:00+03	21600.00
FF5E88	2017-08-02 00:30:00+03	23200.00
FF5EA8	2017-08-05 18:13:00+03	14800.00
FF5F59	2017-07-30 15:16:00+03	15000.00
FF5F6A	2017-07-11 20:10:00+03	6400.00
FF5F8E	2017-08-05 05:52:00+03	59800.00
FF5F93	2017-07-11 14:34:00+03	96200.00
FF5FC3	2017-07-25 12:13:00+03	26000.00
FF5FC6	2017-08-01 03:48:00+03	75300.00
FF5FCA	2017-07-03 01:23:00+03	31600.00
FF6014	2017-07-10 12:34:00+03	186900.00
FF6031	2017-07-31 03:14:00+03	70700.00
FF605A	2017-07-25 20:14:00+03	112000.00
FF60BF	2017-07-22 10:53:00+03	101200.00
FF60CA	2017-08-09 22:42:00+03	66600.00
FF6137	2017-08-11 22:17:00+03	207200.00
FF6138	2017-07-16 05:04:00+03	9800.00
FF61A2	2017-07-07 12:05:00+03	20400.00
FF61BB	2017-07-29 05:22:00+03	52900.00
FF61BF	2017-08-01 00:47:00+03	257600.00
FF61D0	2017-07-08 18:31:00+03	131400.00
FF62CA	2017-07-29 13:17:00+03	246000.00
FF62CE	2017-07-23 18:04:00+03	88300.00
FF6323	2017-08-06 02:32:00+03	84100.00
FF633C	2017-08-09 06:13:00+03	153300.00
FF6384	2017-08-07 00:50:00+03	133900.00
FF63B0	2017-07-26 23:47:00+03	37900.00
FF64ED	2017-08-10 14:48:00+03	24800.00
FF651E	2017-07-18 17:55:00+03	71900.00
FF6608	2017-07-18 21:50:00+03	14700.00
FF663C	2017-07-21 11:51:00+03	67600.00
FF6674	2017-07-12 01:41:00+03	325600.00
FF668B	2017-08-15 08:58:00+03	26800.00
FF66E0	2017-08-12 08:23:00+03	94000.00
FF6713	2017-07-31 09:39:00+03	48700.00
FF672B	2017-07-04 21:23:00+03	115000.00
FF6742	2017-08-08 14:07:00+03	14000.00
FF6789	2017-07-16 02:07:00+03	70600.00
FF67B5	2017-07-20 15:11:00+03	202600.00
FF6811	2017-08-08 01:25:00+03	69600.00
FF686A	2017-07-24 17:02:00+03	102100.00
FF6891	2017-07-30 21:17:00+03	38800.00
FF690A	2017-07-04 11:17:00+03	22000.00
FF6955	2017-07-12 06:32:00+03	92900.00
FF69BE	2017-07-22 14:18:00+03	369000.00
FF69D4	2017-07-09 12:35:00+03	248400.00
FF69DA	2017-08-11 08:42:00+03	88500.00
FF6A96	2017-08-12 15:32:00+03	129400.00
FF6ADA	2017-08-05 19:17:00+03	25000.00
FF6B81	2017-07-23 20:02:00+03	185600.00
FF6B8A	2017-07-29 14:03:00+03	109600.00
FF6B98	2017-08-07 06:45:00+03	59600.00
FF6B9C	2017-07-23 00:21:00+03	75300.00
FF6BCB	2017-07-21 17:20:00+03	12600.00
FF6C44	2017-07-22 04:07:00+03	16400.00
FF6C62	2017-07-15 18:07:00+03	184500.00
FF6C86	2017-07-11 09:29:00+03	17600.00
FF6CE5	2017-07-30 00:11:00+03	133700.00
FF6CF3	2017-08-01 18:00:00+03	44000.00
FF6D15	2017-07-29 06:02:00+03	106200.00
FF6DBF	2017-07-25 12:26:00+03	39800.00
FF6DDA	2017-07-30 21:34:00+03	48800.00
FF6E5C	2017-07-23 13:26:00+03	56900.00
FF6EBE	2017-08-11 13:15:00+03	664300.00
FF6EF3	2017-07-25 16:10:00+03	15900.00
FF6F17	2017-07-13 19:57:00+03	29400.00
FF6F61	2017-07-17 09:00:00+03	112000.00
FF6FC8	2017-07-31 05:50:00+03	97800.00
FF6FE1	2017-07-29 17:08:00+03	14000.00
FF6FF3	2017-07-12 23:07:00+03	14800.00
FF70F7	2017-07-13 23:47:00+03	8000.00
FF7103	2017-07-25 16:33:00+03	26800.00
FF712B	2017-07-04 14:06:00+03	14400.00
FF718F	2017-07-23 02:21:00+03	406200.00
FF7228	2017-07-05 10:37:00+03	38600.00
FF7251	2017-07-11 04:52:00+03	56600.00
FF7294	2017-07-19 13:24:00+03	100000.00
FF72D9	2017-06-30 22:30:00+03	160700.00
FF72DB	2017-07-09 23:22:00+03	61500.00
FF72EF	2017-07-12 07:19:00+03	31400.00
FF734C	2017-07-11 14:11:00+03	93400.00
FF73D3	2017-07-04 06:45:00+03	50400.00
FF73EB	2017-07-05 16:28:00+03	45200.00
FF73FA	2017-07-03 01:41:00+03	51300.00
FF741C	2017-07-27 14:12:00+03	432800.00
FF7532	2017-08-06 22:00:00+03	8200.00
FF753F	2017-07-14 12:53:00+03	62700.00
FF7570	2017-08-09 05:07:00+03	54000.00
FF75EF	2017-08-01 11:18:00+03	68800.00
FF7655	2017-07-16 23:18:00+03	27400.00
FF766D	2017-07-10 05:02:00+03	25800.00
FF7699	2017-07-26 06:19:00+03	99700.00
FF76B1	2017-06-29 00:25:00+03	100600.00
FF7725	2017-07-05 19:42:00+03	19600.00
FF7775	2017-07-15 05:03:00+03	96100.00
FF7793	2017-08-10 03:23:00+03	112000.00
FF785E	2017-07-11 01:57:00+03	136200.00
FF7902	2017-07-12 07:20:00+03	19600.00
FF7A1A	2017-08-05 09:46:00+03	119600.00
FF7A4F	2017-08-01 18:18:00+03	24000.00
FF7ABC	2017-07-12 17:46:00+03	81900.00
FF7C45	2017-07-20 14:25:00+03	140100.00
FF7C85	2017-08-12 06:01:00+03	32800.00
FF7C8E	2017-07-15 08:07:00+03	40100.00
FF7CB5	2017-07-17 01:56:00+03	93900.00
FF7D57	2017-07-06 13:45:00+03	12600.00
FF7D7A	2017-07-22 13:52:00+03	104800.00
FF7DAA	2017-08-06 13:50:00+03	120400.00
FF7DBD	2017-07-21 00:12:00+03	12600.00
FF7DC7	2017-07-11 16:24:00+03	16800.00
FF7DC8	2017-07-06 14:44:00+03	56200.00
FF7DDD	2017-07-15 18:35:00+03	60800.00
FF7DFC	2017-07-26 21:11:00+03	28000.00
FF7E80	2017-08-10 18:53:00+03	66600.00
FF7EBF	2017-08-05 03:30:00+03	23600.00
FF7F50	2017-08-11 21:10:00+03	207700.00
FF7F65	2017-07-25 23:36:00+03	265700.00
FF7F7C	2017-08-09 07:48:00+03	84000.00
FF7FE9	2017-07-03 09:56:00+03	38400.00
FF8034	2017-07-10 12:30:00+03	106800.00
FF80F7	2017-06-29 23:13:00+03	155400.00
FF8101	2017-08-04 21:45:00+03	56000.00
FF814C	2017-07-23 11:40:00+03	182500.00
FF81FA	2017-07-02 01:02:00+03	202100.00
FF8285	2017-07-08 14:56:00+03	75600.00
FF82B3	2017-08-03 13:51:00+03	44800.00
FF82B7	2017-07-31 18:53:00+03	67700.00
FF82CF	2017-07-10 12:57:00+03	43400.00
FF82DE	2017-07-16 09:46:00+03	58600.00
FF8331	2017-08-13 20:09:00+03	52400.00
FF837B	2017-07-24 13:55:00+03	73500.00
FF8388	2017-07-15 20:49:00+03	23400.00
FF83F1	2017-07-16 00:42:00+03	272400.00
FF8431	2017-07-12 08:21:00+03	45100.00
FF8439	2017-07-22 15:52:00+03	54500.00
FF8456	2017-07-15 22:30:00+03	31600.00
FF8476	2017-06-30 07:58:00+03	32600.00
FF84A2	2017-07-19 23:42:00+03	43200.00
FF84C4	2017-08-13 02:22:00+03	61200.00
FF84DF	2017-08-14 13:32:00+03	27200.00
FF84E5	2017-07-14 19:33:00+03	6000.00
FF84FC	2017-08-04 19:24:00+03	265700.00
FF8519	2017-06-29 01:13:00+03	163100.00
FF8553	2017-07-12 02:52:00+03	91600.00
FF8571	2017-08-02 04:41:00+03	30000.00
FF8579	2017-07-21 14:50:00+03	54800.00
FF859F	2017-08-06 21:12:00+03	79300.00
FF85FB	2017-07-18 00:34:00+03	28000.00
FF8624	2017-07-11 02:33:00+03	14400.00
FF8625	2017-07-16 17:21:00+03	114100.00
FF863B	2017-08-14 04:34:00+03	48700.00
FF8642	2017-07-20 04:11:00+03	62700.00
FF8646	2017-07-08 12:21:00+03	27900.00
FF86CB	2017-07-20 19:58:00+03	56200.00
FF86E1	2017-06-28 23:55:00+03	50300.00
FF8767	2017-07-26 01:43:00+03	6300.00
FF876E	2017-07-13 15:43:00+03	167400.00
FF87B1	2017-07-30 22:32:00+03	167500.00
FF8822	2017-07-06 16:38:00+03	131600.00
FF8834	2017-07-26 14:03:00+03	248400.00
FF888B	2017-07-17 12:35:00+03	47100.00
FF888E	2017-08-12 20:24:00+03	134400.00
FF88BC	2017-07-08 07:26:00+03	23200.00
FF8976	2017-06-30 23:02:00+03	74300.00
FF8991	2017-07-26 00:44:00+03	81600.00
FF89A0	2017-08-08 04:30:00+03	23600.00
FF89C4	2017-07-10 22:38:00+03	15400.00
FF89D7	2017-07-14 11:02:00+03	56000.00
FF8A25	2017-07-29 21:04:00+03	56000.00
FF8A47	2017-07-29 23:17:00+03	31100.00
FF8A84	2017-07-18 13:48:00+03	40000.00
FF8B79	2017-08-15 14:59:00+03	83400.00
FF8B7B	2017-08-02 17:49:00+03	59300.00
FF8C3C	2017-07-18 09:53:00+03	28000.00
FF8C8D	2017-07-24 03:49:00+03	58500.00
FF8DDF	2017-07-10 20:05:00+03	26000.00
FF8E24	2017-07-10 17:08:00+03	15000.00
FF8E84	2017-07-18 22:07:00+03	38200.00
FF8EA2	2017-08-11 19:37:00+03	23600.00
FF8EC8	2017-08-07 09:19:00+03	56000.00
FF8EEB	2017-07-01 07:03:00+03	136800.00
FF8FCC	2017-07-29 19:08:00+03	21000.00
FF9025	2017-07-15 18:00:00+03	92700.00
FF9069	2017-07-20 18:20:00+03	68800.00
FF90BA	2017-07-24 04:31:00+03	15400.00
FF90CB	2017-07-13 03:09:00+03	40800.00
FF90FF	2017-08-04 13:08:00+03	90000.00
FF912B	2017-07-02 07:39:00+03	29600.00
FF913C	2017-08-09 06:00:00+03	26000.00
FF9155	2017-07-12 10:40:00+03	111700.00
FF9163	2017-07-28 06:50:00+03	30800.00
FF9184	2017-07-31 01:28:00+03	124200.00
FF91A3	2017-08-14 05:19:00+03	39800.00
FF9275	2017-08-04 23:37:00+03	35600.00
FF92A2	2017-07-26 04:30:00+03	75800.00
FF92B8	2017-07-23 10:06:00+03	6000.00
FF9314	2017-08-04 01:56:00+03	171900.00
FF9372	2017-08-09 21:15:00+03	40000.00
FF93F1	2017-08-10 22:37:00+03	166100.00
FF941D	2017-08-02 18:00:00+03	19600.00
FF941F	2017-07-05 03:54:00+03	75600.00
FF9429	2017-08-02 05:44:00+03	47000.00
FF947A	2017-07-08 23:54:00+03	31200.00
FF9540	2017-07-19 15:55:00+03	12200.00
FF9551	2017-07-28 00:20:00+03	46500.00
FF9594	2017-07-17 11:13:00+03	13800.00
FF959B	2017-07-26 04:50:00+03	57400.00
FF95AE	2017-08-09 01:51:00+03	65900.00
FF95E4	2017-07-23 08:54:00+03	149200.00
FF9618	2017-08-10 04:42:00+03	112000.00
FF9697	2017-08-08 21:06:00+03	144400.00
FF96C5	2017-07-11 20:24:00+03	103500.00
FF96C7	2017-07-30 13:03:00+03	32200.00
FF96EE	2017-07-27 05:15:00+03	23200.00
FF9713	2017-07-27 17:52:00+03	101200.00
FF9749	2017-07-10 06:48:00+03	111600.00
FF9763	2017-07-13 17:43:00+03	62100.00
FF97A1	2017-07-22 05:26:00+03	75600.00
FF97C3	2017-08-01 17:42:00+03	8000.00
FF9814	2017-08-02 04:46:00+03	50000.00
FF9866	2017-07-04 00:16:00+03	147700.00
FF986D	2017-07-24 11:07:00+03	44800.00
FF98B8	2017-07-24 05:14:00+03	42700.00
FF98D8	2017-08-13 18:06:00+03	13200.00
FF990B	2017-07-07 04:34:00+03	160500.00
FF994A	2017-07-20 18:53:00+03	42800.00
FF9965	2017-07-09 21:37:00+03	25400.00
FF9983	2017-07-04 21:02:00+03	66600.00
FF99AD	2017-07-17 20:40:00+03	43600.00
FF99C7	2017-08-09 09:09:00+03	144300.00
FF9A57	2017-07-29 11:27:00+03	6000.00
FF9A5D	2017-07-30 04:58:00+03	19600.00
FF9A8C	2017-08-02 06:32:00+03	53600.00
FF9A9C	2017-07-07 19:48:00+03	21800.00
FF9ABD	2017-07-27 15:14:00+03	86500.00
FF9AE0	2017-07-19 17:54:00+03	25900.00
FF9B19	2017-08-13 21:34:00+03	51700.00
FF9B2C	2017-08-11 22:26:00+03	31000.00
FF9B3F	2017-07-01 12:37:00+03	64500.00
FF9BB1	2017-07-11 19:56:00+03	36800.00
FF9C06	2017-07-31 20:23:00+03	69500.00
FF9C28	2017-07-25 00:27:00+03	67200.00
FF9C44	2017-08-09 07:26:00+03	260300.00
FF9C4C	2017-06-28 05:41:00+03	70500.00
FF9CBE	2017-07-07 00:21:00+03	39600.00
FF9CDC	2017-07-30 03:17:00+03	316700.00
FF9D30	2017-08-04 09:54:00+03	168000.00
FF9D39	2017-07-21 12:52:00+03	60000.00
FF9D56	2017-07-03 09:12:00+03	43600.00
FF9DEC	2017-07-12 13:42:00+03	14400.00
FF9DFA	2017-08-06 21:12:00+03	14400.00
FF9E13	2017-07-16 14:17:00+03	67700.00
FF9EFD	2017-07-12 07:16:00+03	56000.00
FF9F03	2017-07-25 03:15:00+03	111700.00
FF9F09	2017-08-11 22:16:00+03	23200.00
FF9F71	2017-07-26 02:33:00+03	56000.00
FF9FDA	2017-07-27 22:16:00+03	38600.00
FFA00E	2017-08-10 04:07:00+03	29400.00
FFA01D	2017-08-08 08:26:00+03	290400.00
FFA124	2017-07-22 04:01:00+03	111700.00
FFA176	2017-07-19 15:01:00+03	36200.00
FFA17D	2017-06-27 19:39:00+03	90600.00
FFA1A2	2017-07-09 07:20:00+03	103500.00
FFA1E8	2017-07-26 19:37:00+03	6700.00
FFA222	2017-08-02 07:33:00+03	61800.00
FFA262	2017-07-19 21:04:00+03	253200.00
FFA2CB	2017-08-02 07:45:00+03	75300.00
FFA333	2017-07-06 07:27:00+03	61800.00
FFA3C1	2017-07-15 21:32:00+03	90400.00
FFA3DF	2017-08-06 04:07:00+03	26000.00
FFA3ED	2017-07-27 09:17:00+03	532800.00
FFA426	2017-08-01 19:17:00+03	157100.00
FFA45B	2017-08-11 10:19:00+03	44200.00
FFA476	2017-08-04 23:00:00+03	54500.00
FFA4AC	2017-08-08 04:58:00+03	21400.00
FFA4C5	2017-07-09 09:48:00+03	67800.00
FFA4C8	2017-08-08 08:23:00+03	59300.00
FFA56A	2017-08-07 13:13:00+03	42000.00
FFA574	2017-07-30 11:36:00+03	43000.00
FFA5A0	2017-07-30 02:38:00+03	77500.00
FFA5E4	2017-08-04 00:21:00+03	68100.00
FFA631	2017-07-27 12:41:00+03	69500.00
FFA63A	2017-07-03 01:54:00+03	19600.00
FFA653	2017-07-22 09:28:00+03	58800.00
FFA6B1	2017-07-31 23:51:00+03	48500.00
FFA6C4	2017-07-09 19:17:00+03	13600.00
FFA6C9	2017-07-05 08:51:00+03	12600.00
FFA737	2017-07-05 06:30:00+03	101000.00
FFA751	2017-08-05 12:51:00+03	133200.00
FFA7AC	2017-08-14 12:13:00+03	56000.00
FFA800	2017-08-05 00:33:00+03	56000.00
FFA84D	2017-07-17 11:31:00+03	79200.00
FFA899	2017-07-16 08:30:00+03	101200.00
FFA89F	2017-08-07 16:25:00+03	148200.00
FFA8B3	2017-07-29 10:01:00+03	56900.00
FFA8BC	2017-07-27 00:04:00+03	147700.00
FFA930	2017-07-13 07:38:00+03	68800.00
FFA946	2017-07-21 13:36:00+03	58600.00
FFA952	2017-07-06 01:09:00+03	47000.00
FFA974	2017-07-30 12:14:00+03	110300.00
FFA9AC	2017-08-05 14:40:00+03	248400.00
FFAA30	2017-07-30 19:18:00+03	47400.00
FFAA40	2017-07-08 08:49:00+03	8200.00
FFAAB0	2017-08-08 09:31:00+03	111600.00
FFAAEF	2017-08-03 07:43:00+03	19800.00
FFAB70	2017-07-25 09:02:00+03	34000.00
FFAB86	2017-07-27 12:10:00+03	16400.00
FFABA3	2017-07-28 14:06:00+03	20400.00
FFABD4	2017-07-25 02:21:00+03	26500.00
FFAC26	2017-07-31 08:39:00+03	29600.00
FFAC3C	2017-08-07 13:13:00+03	57500.00
FFAC61	2017-07-20 23:28:00+03	59800.00
FFAC65	2017-07-23 07:03:00+03	147700.00
FFACFB	2017-08-06 02:44:00+03	47200.00
FFAD18	2017-06-30 12:28:00+03	52300.00
FFAD23	2017-07-25 21:33:00+03	124300.00
FFAD34	2017-07-29 05:33:00+03	58400.00
FFAD44	2017-07-16 13:05:00+03	31700.00
FFAD6C	2017-07-14 00:09:00+03	40200.00
FFAD76	2017-07-07 01:05:00+03	30200.00
FFADF2	2017-07-03 07:26:00+03	185800.00
FFAE0E	2017-07-03 06:49:00+03	147000.00
FFAE15	2017-08-04 01:04:00+03	185000.00
FFAE40	2017-07-18 16:56:00+03	133200.00
FFAED7	2017-07-22 09:22:00+03	24200.00
FFAEE4	2017-08-08 06:08:00+03	299100.00
FFAF4D	2017-08-15 08:27:00+03	115400.00
FFAF9B	2017-07-18 01:55:00+03	112800.00
FFAFA8	2017-07-27 05:59:00+03	14400.00
FFAFAB	2017-07-07 12:57:00+03	23600.00
FFAFE0	2017-08-06 12:51:00+03	266400.00
FFB033	2017-07-06 16:39:00+03	48000.00
FFB097	2017-07-14 03:21:00+03	80100.00
FFB11A	2017-07-21 09:22:00+03	26000.00
FFB18D	2017-07-01 06:51:00+03	21800.00
FFB1A7	2017-07-10 03:32:00+03	77000.00
FFB1B9	2017-07-07 22:01:00+03	8000.00
FFB23D	2017-07-17 01:47:00+03	532800.00
FFB2FC	2017-07-06 07:51:00+03	66000.00
FFB2FF	2017-07-19 05:58:00+03	69000.00
FFB33F	2017-08-11 11:42:00+03	92700.00
FFB35C	2017-08-06 15:29:00+03	15000.00
FFB371	2017-06-27 11:12:00+03	21400.00
FFB3BD	2017-06-29 09:56:00+03	14400.00
FFB422	2017-07-17 15:52:00+03	92400.00
FFB463	2017-07-15 01:41:00+03	60600.00
FFB47E	2017-07-19 05:42:00+03	12600.00
FFB4D0	2017-07-03 23:10:00+03	8200.00
FFB52A	2017-07-04 11:47:00+03	276800.00
FFB531	2017-07-07 06:31:00+03	64400.00
FFB564	2017-08-04 13:41:00+03	27200.00
FFB584	2017-07-06 05:21:00+03	81200.00
FFB58A	2017-07-11 15:54:00+03	133200.00
FFB5DD	2017-08-06 01:25:00+03	393000.00
FFB5E2	2017-07-23 11:06:00+03	187900.00
FFB6D8	2017-08-04 06:39:00+03	29600.00
FFB6DB	2017-07-09 23:40:00+03	16400.00
FFB788	2017-07-09 22:12:00+03	148200.00
FFB80B	2017-07-24 03:08:00+03	135400.00
FFB8EE	2017-07-25 19:37:00+03	108000.00
FFB8F9	2017-07-10 02:40:00+03	30200.00
FFB910	2017-08-01 17:45:00+03	25900.00
FFB91D	2017-07-16 14:52:00+03	39800.00
FFB93B	2017-08-07 17:46:00+03	123600.00
FFB976	2017-07-22 19:57:00+03	15000.00
FFB9D5	2017-07-14 17:38:00+03	74700.00
FFB9F4	2017-07-30 10:53:00+03	239900.00
FFBA46	2017-07-08 10:48:00+03	136600.00
FFBA83	2017-08-04 03:00:00+03	29600.00
FFBAB2	2017-07-02 16:07:00+03	40000.00
FFBB15	2017-07-19 13:39:00+03	443000.00
FFBB19	2017-08-10 16:57:00+03	29600.00
FFBB78	2017-07-11 00:43:00+03	21800.00
FFBBF8	2017-08-13 03:06:00+03	28800.00
FFBC14	2017-07-01 03:07:00+03	75300.00
FFBC5B	2017-07-10 17:16:00+03	41400.00
FFBCC7	2017-07-19 01:01:00+03	121800.00
FFBCD8	2017-07-28 17:16:00+03	13700.00
FFBD28	2017-08-14 17:39:00+03	88000.00
FFBD4F	2017-07-13 06:44:00+03	10600.00
FFBD68	2017-07-17 18:35:00+03	27200.00
FFBD71	2017-07-06 07:36:00+03	24800.00
FFBDBE	2017-07-27 11:28:00+03	32800.00
FFBF1D	2017-07-11 09:20:00+03	57800.00
FFBF46	2017-07-01 08:14:00+03	43200.00
FFBF8B	2017-07-01 03:12:00+03	24700.00
FFBFB9	2017-08-07 14:57:00+03	140900.00
FFC045	2017-08-14 19:54:00+03	112000.00
FFC058	2017-08-03 14:36:00+03	14000.00
FFC05B	2017-08-10 03:26:00+03	12000.00
FFC069	2017-07-27 03:06:00+03	28000.00
FFC0AB	2017-07-16 00:18:00+03	43200.00
FFC156	2017-07-09 12:13:00+03	33300.00
FFC168	2017-07-01 11:45:00+03	40200.00
FFC169	2017-08-13 05:11:00+03	63900.00
FFC1BE	2017-08-02 17:49:00+03	225800.00
FFC1D8	2017-08-03 13:23:00+03	46200.00
FFC1D9	2017-07-08 01:33:00+03	169300.00
FFC1E6	2017-08-03 23:34:00+03	432500.00
FFC211	2017-07-16 17:40:00+03	58800.00
FFC26B	2017-08-03 16:21:00+03	27400.00
FFC289	2017-07-25 01:34:00+03	54500.00
FFC38B	2017-07-19 23:04:00+03	101200.00
FFC452	2017-07-27 22:51:00+03	48600.00
FFC495	2017-08-07 03:31:00+03	12600.00
FFC4A9	2017-07-29 23:47:00+03	188900.00
FFC4CC	2017-07-12 21:29:00+03	101200.00
FFC513	2017-07-01 22:04:00+03	54800.00
FFC541	2017-07-26 06:04:00+03	11600.00
FFC5BA	2017-07-21 06:59:00+03	92900.00
FFC620	2017-07-19 13:21:00+03	43600.00
FFC664	2017-08-12 18:49:00+03	21000.00
FFC67D	2017-07-18 13:29:00+03	52400.00
FFC682	2017-07-15 19:02:00+03	33300.00
FFC68C	2017-07-18 17:44:00+03	44700.00
FFC6FD	2017-07-27 10:58:00+03	55800.00
FFC70F	2017-07-09 12:14:00+03	260900.00
FFC746	2017-07-02 12:11:00+03	27200.00
FFC79E	2017-08-15 05:27:00+03	195300.00
FFC7E3	2017-07-26 13:32:00+03	28800.00
FFC7F9	2017-07-04 18:23:00+03	6800.00
FFC81E	2017-07-16 22:36:00+03	98400.00
FFC84F	2017-07-10 00:40:00+03	7300.00
FFC86C	2017-08-10 09:04:00+03	38600.00
FFC8B5	2017-08-12 21:31:00+03	54500.00
FFC8CB	2017-08-03 10:57:00+03	57800.00
FFC8DB	2017-08-15 08:25:00+03	103800.00
FFC96E	2017-07-31 00:53:00+03	70600.00
FFC98A	2017-08-02 03:43:00+03	47000.00
FFC9B9	2017-07-18 23:21:00+03	76600.00
FFCA10	2017-08-11 06:37:00+03	102100.00
FFCA81	2017-07-03 11:42:00+03	29100.00
FFCA9B	2017-08-02 12:37:00+03	167500.00
FFCAA9	2017-07-07 03:38:00+03	29600.00
FFCABD	2017-07-26 10:49:00+03	25600.00
FFCAC1	2017-07-26 19:58:00+03	28000.00
FFCB44	2017-07-11 16:10:00+03	172800.00
FFCB52	2017-07-10 12:56:00+03	167400.00
FFCB5E	2017-07-14 18:08:00+03	73600.00
FFCB70	2017-07-07 19:28:00+03	58600.00
FFCB87	2017-06-30 07:44:00+03	43000.00
FFCBA8	2017-07-15 04:50:00+03	23600.00
FFCBAF	2017-07-27 01:52:00+03	69500.00
FFCC1A	2017-07-13 04:09:00+03	50700.00
FFCC7A	2017-07-14 03:09:00+03	26000.00
FFCCA2	2017-07-30 14:36:00+03	44800.00
FFCCAD	2017-07-06 18:02:00+03	32800.00
FFCCF6	2017-07-25 07:01:00+03	9800.00
FFCD34	2017-07-07 16:14:00+03	24800.00
FFCDE8	2017-08-02 03:38:00+03	59300.00
FFCDEB	2017-07-14 17:35:00+03	65900.00
FFCE62	2017-07-12 00:21:00+03	75300.00
FFCEF2	2017-07-30 00:04:00+03	23900.00
FFCF05	2017-07-13 01:38:00+03	86600.00
FFCF55	2017-07-18 17:48:00+03	31100.00
FFCF7B	2017-08-13 04:31:00+03	32800.00
FFCFDB	2017-07-18 13:13:00+03	89600.00
FFD002	2017-07-26 23:31:00+03	100600.00
FFD013	2017-07-04 17:33:00+03	73600.00
FFD025	2017-06-30 13:54:00+03	40800.00
FFD033	2017-07-06 10:38:00+03	286300.00
FFD05D	2017-07-10 14:23:00+03	57800.00
FFD0C2	2017-08-07 07:34:00+03	133100.00
FFD0DA	2017-07-01 01:30:00+03	167400.00
FFD123	2017-07-28 18:04:00+03	67200.00
FFD136	2017-07-02 01:41:00+03	18100.00
FFD16B	2017-08-09 01:45:00+03	17800.00
FFD230	2017-08-14 12:19:00+03	67200.00
FFD25F	2017-07-11 03:55:00+03	27300.00
FFD297	2017-07-24 14:30:00+03	50600.00
FFD2C5	2017-08-08 05:20:00+03	97100.00
FFD2EC	2017-07-01 09:10:00+03	149600.00
FFD371	2017-07-31 18:49:00+03	19800.00
FFD3C1	2017-07-06 08:10:00+03	23600.00
FFD3D8	2017-08-13 01:19:00+03	23600.00
FFD41D	2017-07-21 03:15:00+03	21500.00
FFD44F	2017-08-07 23:11:00+03	7400.00
FFD451	2017-07-05 12:28:00+03	131100.00
FFD46D	2017-08-05 17:56:00+03	75600.00
FFD49B	2017-08-01 11:30:00+03	7200.00
FFD5C3	2017-07-06 03:10:00+03	44000.00
FFD61F	2017-07-21 19:17:00+03	38800.00
FFD658	2017-07-18 20:56:00+03	43000.00
FFD65F	2017-07-21 15:08:00+03	43500.00
FFD69E	2017-07-11 02:46:00+03	6000.00
FFD6E4	2017-07-05 15:09:00+03	36800.00
FFD6E5	2017-08-14 07:46:00+03	26800.00
FFD76F	2017-08-14 22:58:00+03	15000.00
FFD7A0	2017-07-12 17:39:00+03	84500.00
FFD7A8	2017-07-11 23:07:00+03	29400.00
FFD7AF	2017-07-11 18:36:00+03	92900.00
FFD7EE	2017-07-10 01:31:00+03	105000.00
FFD7FA	2017-07-30 03:14:00+03	22600.00
FFD85C	2017-07-14 02:33:00+03	106100.00
FFD8A6	2017-08-08 08:22:00+03	149300.00
FFD8C8	2017-07-04 08:36:00+03	73500.00
FFD8D0	2017-08-12 06:07:00+03	35800.00
FFD9C5	2017-08-06 19:30:00+03	22000.00
FFD9C9	2017-07-21 05:49:00+03	271200.00
FFD9E7	2017-07-02 22:50:00+03	65900.00
FFDA56	2017-08-14 07:12:00+03	386300.00
FFDA76	2017-07-05 13:58:00+03	75800.00
FFDB11	2017-07-31 03:25:00+03	37900.00
FFDB1E	2017-07-11 05:33:00+03	28800.00
FFDBF5	2017-07-17 12:03:00+03	21400.00
FFDC2B	2017-08-02 04:02:00+03	34000.00
FFDC4C	2017-07-17 10:48:00+03	109600.00
FFDC55	2017-07-08 16:18:00+03	65200.00
FFDC86	2017-08-12 17:51:00+03	29400.00
FFDCCB	2017-08-10 00:04:00+03	67200.00
FFDCEE	2017-07-16 15:47:00+03	8200.00
FFDD4D	2017-07-20 19:45:00+03	135200.00
FFDE20	2017-07-01 22:18:00+03	25600.00
FFDE2A	2017-07-16 02:24:00+03	291000.00
FFDE7D	2017-07-04 21:27:00+03	89700.00
FFDECD	2017-07-03 17:52:00+03	170800.00
FFDECF	2017-07-31 17:15:00+03	31700.00
FFE069	2017-08-12 05:20:00+03	26800.00
FFE0BE	2017-08-10 06:57:00+03	28800.00
FFE0F1	2017-07-01 11:25:00+03	56000.00
FFE129	2017-07-31 15:30:00+03	133100.00
FFE12B	2017-07-23 07:46:00+03	66800.00
FFE143	2017-08-04 11:54:00+03	56600.00
FFE152	2017-07-16 05:06:00+03	71800.00
FFE217	2017-08-02 04:41:00+03	27200.00
FFE229	2017-08-12 03:42:00+03	25900.00
FFE24C	2017-07-09 08:00:00+03	56000.00
FFE278	2017-08-08 18:08:00+03	83100.00
FFE28D	2017-07-11 06:19:00+03	26000.00
FFE31C	2017-08-08 11:11:00+03	65100.00
FFE33F	2017-07-05 23:43:00+03	30700.00
FFE36C	2017-07-19 14:24:00+03	86300.00
FFE376	2017-07-09 08:18:00+03	116400.00
FFE3D1	2017-08-14 15:30:00+03	68400.00
FFE456	2017-07-19 06:29:00+03	20200.00
FFE482	2017-07-26 10:54:00+03	59700.00
FFE4E6	2017-07-28 01:15:00+03	147200.00
FFE55F	2017-08-11 20:55:00+03	6000.00
FFE57B	2017-08-13 14:43:00+03	46300.00
FFE581	2017-07-13 02:55:00+03	12600.00
FFE5A9	2017-07-06 18:28:00+03	55800.00
FFE5EF	2017-08-12 20:26:00+03	65200.00
FFE62B	2017-07-11 05:57:00+03	45100.00
FFE638	2017-08-14 12:52:00+03	19600.00
FFE691	2017-07-29 21:33:00+03	52000.00
FFE6C7	2017-07-30 05:05:00+03	75800.00
FFE6D2	2017-08-02 04:42:00+03	123800.00
FFE6D3	2017-07-16 14:50:00+03	10600.00
FFE6FD	2017-07-31 20:20:00+03	58000.00
FFE703	2017-07-13 10:11:00+03	184800.00
FFE7E4	2017-07-29 10:37:00+03	85900.00
FFE82B	2017-07-27 23:59:00+03	43200.00
FFE845	2017-08-08 11:53:00+03	208200.00
FFE89A	2017-08-11 00:19:00+03	67600.00
FFE94B	2017-07-13 15:45:00+03	109900.00
FFE998	2017-07-11 17:04:00+03	148200.00
FFEA04	2017-08-11 12:49:00+03	62600.00
FFEA06	2017-07-12 12:27:00+03	95300.00
FFEA76	2017-07-06 11:41:00+03	68400.00
FFEAEA	2017-08-14 04:04:00+03	23600.00
FFEB09	2017-07-29 21:21:00+03	13400.00
FFEB1E	2017-08-12 02:23:00+03	54500.00
FFEB23	2017-07-11 05:11:00+03	57500.00
FFEB24	2017-08-06 17:20:00+03	22400.00
FFEB66	2017-08-14 14:47:00+03	71900.00
FFEB98	2017-07-11 18:34:00+03	187600.00
FFEC35	2017-07-04 21:57:00+03	106800.00
FFEC6A	2017-08-05 18:22:00+03	32200.00
FFEC85	2017-08-07 04:03:00+03	46000.00
FFEC95	2017-08-09 02:30:00+03	187800.00
FFEC9D	2017-07-16 17:49:00+03	15900.00
FFECC2	2017-07-08 21:35:00+03	96800.00
FFED56	2017-07-24 01:29:00+03	16400.00
FFED9A	2017-07-20 06:42:00+03	28400.00
FFEDBB	2017-08-15 17:06:00+03	212800.00
FFEE40	2017-08-01 14:45:00+03	50800.00
FFEE90	2017-08-04 00:43:00+03	81600.00
FFEEF2	2017-07-18 20:13:00+03	35900.00
FFEF0F	2017-07-30 14:12:00+03	132800.00
FFEFA8	2017-08-05 11:39:00+03	408500.00
FFEFBB	2017-08-02 01:36:00+03	56000.00
FFF09A	2017-07-04 16:56:00+03	46000.00
FFF0D0	2017-08-01 08:23:00+03	7400.00
FFF0F6	2017-08-10 11:41:00+03	163000.00
FFF0FC	2017-08-09 03:59:00+03	34000.00
FFF106	2017-07-07 01:01:00+03	32800.00
FFF109	2017-07-25 04:56:00+03	24000.00
FFF160	2017-07-28 08:54:00+03	19600.00
FFF1F9	2017-07-10 22:49:00+03	98100.00
FFF1FD	2017-08-01 21:05:00+03	82900.00
FFF22E	2017-07-24 11:04:00+03	57900.00
FFF278	2017-07-24 23:47:00+03	46200.00
FFF281	2017-06-28 10:07:00+03	78000.00
FFF2BD	2017-07-18 16:52:00+03	66000.00
FFF2E9	2017-07-09 03:11:00+03	66600.00
FFF30C	2017-07-03 20:30:00+03	35700.00
FFF329	2017-08-10 23:23:00+03	86300.00
FFF37D	2017-08-11 21:56:00+03	26000.00
FFF3AE	2017-08-08 03:40:00+03	50100.00
FFF3B4	2017-07-06 14:51:00+03	68800.00
FFF419	2017-07-06 11:16:00+03	27300.00
FFF474	2017-07-13 07:09:00+03	248300.00
FFF4D3	2017-07-12 05:07:00+03	15800.00
FFF58D	2017-08-13 12:48:00+03	58800.00
FFF595	2017-08-08 00:58:00+03	289300.00
FFF5B5	2017-07-17 16:07:00+03	86400.00
FFF5F5	2017-07-20 23:57:00+03	103400.00
FFF637	2017-07-28 04:46:00+03	396500.00
FFF642	2017-07-10 09:25:00+03	6000.00
FFF6CF	2017-07-15 23:20:00+03	94900.00
FFF6D4	2017-08-01 01:45:00+03	6700.00
FFF753	2017-08-10 12:17:00+03	58900.00
FFF776	2017-07-19 23:14:00+03	54800.00
FFF812	2017-07-14 23:24:00+03	67200.00
FFF840	2017-08-02 17:16:00+03	43600.00
FFF86A	2017-07-07 11:46:00+03	21800.00
FFF8EF	2017-07-03 20:38:00+03	21400.00
FFF9C8	2017-07-18 18:32:00+03	40000.00
FFF9DD	2017-07-10 18:36:00+03	99300.00
FFF9E3	2017-07-06 19:52:00+03	48800.00
FFF9F0	2017-07-14 02:23:00+03	23600.00
FFFA21	2017-07-08 11:47:00+03	119700.00
FFFA4C	2017-07-15 08:41:00+03	190400.00
FFFA64	2017-07-21 11:56:00+03	17200.00
FFFA98	2017-08-02 00:03:00+03	199700.00
FFFB18	2017-07-15 13:01:00+03	261500.00
FFFB27	2017-08-12 20:06:00+03	64700.00
FFFB2E	2017-07-24 16:32:00+03	16400.00
FFFB39	2017-08-11 18:44:00+03	14400.00
FFFBC6	2017-08-10 07:18:00+03	38200.00
FFFBC7	2017-08-05 18:07:00+03	50800.00
FFFC1A	2017-08-12 11:29:00+03	95300.00
FFFC22	2017-07-24 07:29:00+03	268600.00
FFFC75	2017-08-14 08:11:00+03	68800.00
FFFC8A	2017-08-12 16:15:00+03	75600.00
FFFC8C	2017-08-07 14:23:00+03	24400.00
FFFCC2	2017-07-17 01:07:00+03	99200.00
FFFCCC	2017-07-26 20:44:00+03	112000.00
FFFE39	2017-07-21 23:25:00+03	34000.00
FFFE47	2017-08-09 03:56:00+03	212800.00
FFFE7B	2017-07-25 22:49:00+03	139200.00
FFFEA6	2017-07-30 18:10:00+03	56000.00
FFFEF3	2017-07-17 07:23:00+03	56000.00
FFFF2C	2017-08-08 05:55:00+03	10800.00
FFFF43	2017-07-20 20:42:00+03	78500.00
FFFFA8	2017-08-08 04:45:00+03	28800.00
FFFFF7	2017-07-01 22:12:00+03	73600.00
\.


--
-- Data for Name: flights; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY flights (flight_id, flight_no, scheduled_departure, scheduled_arrival, departure_airport, arrival_airport, status, aircraft_code, actual_departure, actual_arrival) FROM stdin;
1185	PG0134	2017-09-10 09:50:00+03	2017-09-10 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
3979	PG0052	2017-08-25 14:50:00+03	2017-08-25 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
4739	PG0561	2017-09-05 12:30:00+03	2017-09-05 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
5502	PG0529	2017-09-12 09:50:00+03	2017-09-12 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
6938	PG0461	2017-09-04 12:25:00+03	2017-09-04 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
7784	PG0667	2017-09-10 15:00:00+03	2017-09-10 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
9478	PG0360	2017-08-28 09:00:00+03	2017-08-28 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
11085	PG0569	2017-08-24 15:05:00+03	2017-08-24 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11847	PG0498	2017-09-12 10:15:00+03	2017-09-12 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
12012	PG0621	2017-08-26 16:05:00+03	2017-08-26 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
13113	PG0612	2017-08-18 16:25:00+03	2017-08-18 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
14806	PG0676	2017-09-06 07:05:00+03	2017-09-06 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
16837	PG0010	2017-09-05 12:25:00+03	2017-09-05 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
17173	PG0059	2017-09-14 12:25:00+03	2017-09-14 14:45:00+03	SCW	NBC	Cancelled	CN1	\N	\N
19807	PG0035	2017-09-11 06:35:00+03	2017-09-11 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
23609	PG0648	2017-08-31 11:35:00+03	2017-08-31 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23695	PG0388	2017-08-26 10:55:00+03	2017-08-26 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23780	PG0098	2017-09-02 06:50:00+03	2017-09-02 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23945	PG0076	2017-09-05 09:15:00+03	2017-09-05 11:50:00+03	EYK	DME	Scheduled	CR2	\N	\N
24705	PG0632	2017-08-26 15:00:00+03	2017-08-26 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
25382	PG0556	2017-08-31 09:05:00+03	2017-08-31 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
26057	PG0467	2017-08-26 15:45:00+03	2017-08-26 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
27580	PG0483	2017-09-12 07:20:00+03	2017-09-12 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
29272	PG0334	2017-09-05 16:20:00+03	2017-09-05 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29440	PG0065	2017-09-02 12:15:00+03	2017-09-02 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
32658	PG0674	2017-08-19 09:35:00+03	2017-08-19 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
1	PG0405	2017-07-16 09:35:00+03	2017-07-16 10:30:00+03	DME	LED	Arrived	321	2017-07-16 09:44:00+03	2017-07-16 10:39:00+03
2	PG0404	2017-08-05 19:05:00+03	2017-08-05 20:00:00+03	DME	LED	Arrived	321	2017-08-05 19:06:00+03	2017-08-05 20:01:00+03
3	PG0405	2017-08-05 09:35:00+03	2017-08-05 10:30:00+03	DME	LED	Arrived	321	2017-08-05 09:39:00+03	2017-08-05 10:34:00+03
4	PG0402	2017-09-09 12:25:00+03	2017-09-09 13:20:00+03	DME	LED	Scheduled	321	\N	\N
5	PG0405	2017-08-16 09:35:00+03	2017-08-16 10:30:00+03	DME	LED	On Time	321	\N	\N
6	PG0404	2017-08-16 19:05:00+03	2017-08-16 20:00:00+03	DME	LED	Scheduled	321	\N	\N
7	PG0403	2017-08-16 11:25:00+03	2017-08-16 12:20:00+03	DME	LED	Delayed	321	\N	\N
8	PG0402	2017-08-16 12:25:00+03	2017-08-16 13:20:00+03	DME	LED	On Time	321	\N	\N
9	PG0405	2017-08-25 09:35:00+03	2017-08-25 10:30:00+03	DME	LED	Scheduled	321	\N	\N
10	PG0402	2017-08-23 12:25:00+03	2017-08-23 13:20:00+03	DME	LED	Scheduled	321	\N	\N
11	PG0403	2017-08-23 11:25:00+03	2017-08-23 12:20:00+03	DME	LED	Scheduled	321	\N	\N
12	PG0404	2017-08-23 19:05:00+03	2017-08-23 20:00:00+03	DME	LED	Scheduled	321	\N	\N
13	PG0405	2017-08-23 09:35:00+03	2017-08-23 10:30:00+03	DME	LED	Scheduled	321	\N	\N
14	PG0402	2017-08-06 12:25:00+03	2017-08-06 13:20:00+03	DME	LED	Arrived	321	2017-08-06 12:28:00+03	2017-08-06 13:23:00+03
15	PG0402	2017-07-28 12:25:00+03	2017-07-28 13:20:00+03	DME	LED	Arrived	321	2017-07-28 12:31:00+03	2017-07-28 13:26:00+03
16	PG0403	2017-08-06 11:25:00+03	2017-08-06 12:20:00+03	DME	LED	Arrived	321	2017-08-06 11:27:00+03	2017-08-06 12:22:00+03
17	PG0404	2017-08-06 19:05:00+03	2017-08-06 20:00:00+03	DME	LED	Arrived	321	2017-08-06 19:05:00+03	2017-08-06 20:00:00+03
18	PG0405	2017-08-06 09:35:00+03	2017-08-06 10:30:00+03	DME	LED	Arrived	321	2017-08-06 09:39:00+03	2017-08-06 10:35:00+03
19	PG0403	2017-07-28 11:25:00+03	2017-07-28 12:20:00+03	DME	LED	Arrived	321	2017-07-28 11:27:00+03	2017-07-28 12:22:00+03
20	PG0403	2017-07-26 11:25:00+03	2017-07-26 12:20:00+03	DME	LED	Arrived	321	2017-07-26 11:28:00+03	2017-07-26 12:23:00+03
21	PG0405	2017-07-19 09:35:00+03	2017-07-19 10:30:00+03	DME	LED	Arrived	321	2017-07-19 09:36:00+03	2017-07-19 10:31:00+03
22	PG0404	2017-07-19 19:05:00+03	2017-07-19 20:00:00+03	DME	LED	Arrived	321	2017-07-19 19:06:00+03	2017-07-19 20:00:00+03
23	PG0403	2017-07-19 11:25:00+03	2017-07-19 12:20:00+03	DME	LED	Arrived	321	2017-07-19 11:29:00+03	2017-07-19 12:25:00+03
24	PG0402	2017-07-19 12:25:00+03	2017-07-19 13:20:00+03	DME	LED	Arrived	321	2017-07-19 12:29:00+03	2017-07-19 13:24:00+03
25	PG0404	2017-07-28 19:05:00+03	2017-07-28 20:00:00+03	DME	LED	Arrived	321	2017-07-28 19:11:00+03	2017-07-28 20:06:00+03
26	PG0405	2017-08-12 09:35:00+03	2017-08-12 10:30:00+03	DME	LED	Arrived	321	2017-08-12 12:41:00+03	2017-08-12 13:37:00+03
27	PG0404	2017-08-12 19:05:00+03	2017-08-12 20:00:00+03	DME	LED	Arrived	321	2017-08-12 19:07:00+03	2017-08-12 20:02:00+03
28	PG0405	2017-09-03 09:35:00+03	2017-09-03 10:30:00+03	DME	LED	Scheduled	321	\N	\N
29	PG0403	2017-08-12 11:25:00+03	2017-08-12 12:20:00+03	DME	LED	Arrived	321	2017-08-12 11:28:00+03	2017-08-12 12:23:00+03
30	PG0402	2017-08-12 12:25:00+03	2017-08-12 13:20:00+03	DME	LED	Arrived	321	2017-08-12 12:28:00+03	2017-08-12 13:23:00+03
31	PG0404	2017-09-03 19:05:00+03	2017-09-03 20:00:00+03	DME	LED	Scheduled	321	\N	\N
32	PG0403	2017-09-03 11:25:00+03	2017-09-03 12:20:00+03	DME	LED	Scheduled	321	\N	\N
33	PG0402	2017-09-03 12:25:00+03	2017-09-03 13:20:00+03	DME	LED	Scheduled	321	\N	\N
34	PG0402	2017-08-07 12:25:00+03	2017-08-07 13:20:00+03	DME	LED	Arrived	321	2017-08-07 12:29:00+03	2017-08-07 13:24:00+03
35	PG0403	2017-08-07 11:25:00+03	2017-08-07 12:20:00+03	DME	LED	Arrived	321	2017-08-07 11:29:00+03	2017-08-07 12:24:00+03
36	PG0404	2017-08-07 19:05:00+03	2017-08-07 20:00:00+03	DME	LED	Arrived	321	2017-08-07 19:09:00+03	2017-08-07 20:04:00+03
37	PG0405	2017-08-07 09:35:00+03	2017-08-07 10:30:00+03	DME	LED	Arrived	321	2017-08-07 09:38:00+03	2017-08-07 10:34:00+03
38	PG0405	2017-07-28 09:35:00+03	2017-07-28 10:30:00+03	DME	LED	Arrived	321	2017-07-28 09:36:00+03	2017-07-28 10:30:00+03
39	PG0405	2017-09-08 09:35:00+03	2017-09-08 10:30:00+03	DME	LED	Scheduled	321	\N	\N
40	PG0402	2017-09-13 12:25:00+03	2017-09-13 13:20:00+03	DME	LED	Scheduled	321	\N	\N
41	PG0403	2017-09-13 11:25:00+03	2017-09-13 12:20:00+03	DME	LED	Scheduled	321	\N	\N
42	PG0404	2017-09-13 19:05:00+03	2017-09-13 20:00:00+03	DME	LED	Scheduled	321	\N	\N
43	PG0405	2017-09-13 09:35:00+03	2017-09-13 10:30:00+03	DME	LED	Scheduled	321	\N	\N
44	PG0404	2017-09-08 19:05:00+03	2017-09-08 20:00:00+03	DME	LED	Scheduled	321	\N	\N
45	PG0403	2017-09-08 11:25:00+03	2017-09-08 12:20:00+03	DME	LED	Scheduled	321	\N	\N
46	PG0405	2017-08-15 09:35:00+03	2017-08-15 10:30:00+03	DME	LED	Arrived	321	2017-08-15 09:38:00+03	2017-08-15 10:33:00+03
47	PG0404	2017-08-15 19:05:00+03	2017-08-15 20:00:00+03	DME	LED	On Time	321	\N	\N
48	PG0403	2017-08-15 11:25:00+03	2017-08-15 12:20:00+03	DME	LED	Arrived	321	2017-08-15 11:30:00+03	2017-08-15 12:25:00+03
49	PG0402	2017-08-15 12:25:00+03	2017-08-15 13:20:00+03	DME	LED	Arrived	321	2017-08-15 12:28:00+03	2017-08-15 13:24:00+03
50	PG0402	2017-08-08 12:25:00+03	2017-08-08 13:20:00+03	DME	LED	Arrived	321	2017-08-08 12:26:00+03	2017-08-08 13:21:00+03
51	PG0403	2017-08-08 11:25:00+03	2017-08-08 12:20:00+03	DME	LED	Arrived	321	2017-08-08 11:25:00+03	2017-08-08 12:20:00+03
52	PG0404	2017-08-08 19:05:00+03	2017-08-08 20:00:00+03	DME	LED	Arrived	321	2017-08-08 22:05:00+03	2017-08-08 22:59:00+03
53	PG0405	2017-08-08 09:35:00+03	2017-08-08 10:30:00+03	DME	LED	Arrived	321	2017-08-08 09:35:00+03	2017-08-08 10:30:00+03
54	PG0405	2017-07-18 09:35:00+03	2017-07-18 10:30:00+03	DME	LED	Arrived	321	2017-07-18 09:40:00+03	2017-07-18 10:35:00+03
55	PG0404	2017-07-18 19:05:00+03	2017-07-18 20:00:00+03	DME	LED	Arrived	321	2017-07-18 19:08:00+03	2017-07-18 20:03:00+03
56	PG0403	2017-07-18 11:25:00+03	2017-07-18 12:20:00+03	DME	LED	Arrived	321	2017-07-18 14:48:00+03	2017-07-18 15:43:00+03
57	PG0402	2017-07-18 12:25:00+03	2017-07-18 13:20:00+03	DME	LED	Arrived	321	2017-07-18 12:29:00+03	2017-07-18 13:24:00+03
58	PG0402	2017-09-08 12:25:00+03	2017-09-08 13:20:00+03	DME	LED	Scheduled	321	\N	\N
59	PG0402	2017-07-26 12:25:00+03	2017-07-26 13:20:00+03	DME	LED	Arrived	321	2017-07-26 12:28:00+03	2017-07-26 13:23:00+03
60	PG0402	2017-07-16 12:25:00+03	2017-07-16 13:20:00+03	DME	LED	Arrived	321	2017-07-16 12:27:00+03	2017-07-16 13:22:00+03
61	PG0403	2017-07-16 11:25:00+03	2017-07-16 12:20:00+03	DME	LED	Arrived	321	2017-07-16 15:15:00+03	2017-07-16 16:10:00+03
62	PG0404	2017-07-16 19:05:00+03	2017-07-16 20:00:00+03	DME	LED	Arrived	321	2017-07-16 19:08:00+03	2017-07-16 20:03:00+03
63	PG0402	2017-08-30 12:25:00+03	2017-08-30 13:20:00+03	DME	LED	Scheduled	321	\N	\N
64	PG0403	2017-08-30 11:25:00+03	2017-08-30 12:20:00+03	DME	LED	Scheduled	321	\N	\N
65	PG0405	2017-09-02 09:35:00+03	2017-09-02 10:30:00+03	DME	LED	Scheduled	321	\N	\N
66	PG0404	2017-09-02 19:05:00+03	2017-09-02 20:00:00+03	DME	LED	Scheduled	321	\N	\N
67	PG0404	2017-07-26 19:05:00+03	2017-07-26 20:00:00+03	DME	LED	Arrived	321	2017-07-26 19:06:00+03	2017-07-26 20:01:00+03
68	PG0403	2017-09-02 11:25:00+03	2017-09-02 12:20:00+03	DME	LED	Scheduled	321	\N	\N
69	PG0402	2017-09-02 12:25:00+03	2017-09-02 13:20:00+03	DME	LED	Scheduled	321	\N	\N
70	PG0404	2017-08-30 19:05:00+03	2017-08-30 20:00:00+03	DME	LED	Scheduled	321	\N	\N
71	PG0405	2017-08-30 09:35:00+03	2017-08-30 10:30:00+03	DME	LED	Scheduled	321	\N	\N
72	PG0402	2017-08-09 12:25:00+03	2017-08-09 13:20:00+03	DME	LED	Arrived	321	2017-08-09 12:27:00+03	2017-08-09 13:23:00+03
73	PG0403	2017-08-09 11:25:00+03	2017-08-09 12:20:00+03	DME	LED	Arrived	321	2017-08-09 11:30:00+03	2017-08-09 12:27:00+03
74	PG0404	2017-08-09 19:05:00+03	2017-08-09 20:00:00+03	DME	LED	Arrived	321	2017-08-09 22:18:00+03	2017-08-09 23:13:00+03
75	PG0405	2017-08-09 09:35:00+03	2017-08-09 10:30:00+03	DME	LED	Arrived	321	2017-08-09 09:39:00+03	2017-08-09 10:35:00+03
76	PG0405	2017-09-09 09:35:00+03	2017-09-09 10:30:00+03	DME	LED	Scheduled	321	\N	\N
77	PG0402	2017-08-21 12:25:00+03	2017-08-21 13:20:00+03	DME	LED	Scheduled	321	\N	\N
78	PG0402	2017-09-14 12:25:00+03	2017-09-14 13:20:00+03	DME	LED	Scheduled	321	\N	\N
79	PG0403	2017-09-14 11:25:00+03	2017-09-14 12:20:00+03	DME	LED	Scheduled	321	\N	\N
80	PG0404	2017-09-14 19:05:00+03	2017-09-14 20:00:00+03	DME	LED	Scheduled	321	\N	\N
81	PG0405	2017-09-14 09:35:00+03	2017-09-14 10:30:00+03	DME	LED	Scheduled	321	\N	\N
82	PG0402	2017-08-13 12:25:00+03	2017-08-13 13:20:00+03	DME	LED	Arrived	321	2017-08-13 12:30:00+03	2017-08-13 13:25:00+03
83	PG0402	2017-08-10 12:25:00+03	2017-08-10 13:20:00+03	DME	LED	Arrived	321	2017-08-10 15:54:00+03	2017-08-10 16:51:00+03
84	PG0403	2017-08-10 11:25:00+03	2017-08-10 12:20:00+03	DME	LED	Arrived	321	2017-08-10 11:28:00+03	2017-08-10 12:23:00+03
85	PG0404	2017-08-10 19:05:00+03	2017-08-10 20:00:00+03	DME	LED	Arrived	321	2017-08-10 19:10:00+03	2017-08-10 20:06:00+03
86	PG0405	2017-08-10 09:35:00+03	2017-08-10 10:30:00+03	DME	LED	Arrived	321	2017-08-10 09:37:00+03	2017-08-10 10:33:00+03
87	PG0405	2017-07-17 09:35:00+03	2017-07-17 10:30:00+03	DME	LED	Arrived	321	2017-07-17 09:40:00+03	2017-07-17 10:36:00+03
88	PG0404	2017-07-17 19:05:00+03	2017-07-17 20:00:00+03	DME	LED	Arrived	321	2017-07-17 19:06:00+03	2017-07-17 20:02:00+03
89	PG0403	2017-07-17 11:25:00+03	2017-07-17 12:20:00+03	DME	LED	Arrived	321	2017-07-17 11:30:00+03	2017-07-17 12:25:00+03
90	PG0402	2017-07-17 12:25:00+03	2017-07-17 13:20:00+03	DME	LED	Arrived	321	2017-07-17 12:25:00+03	2017-07-17 13:20:00+03
91	PG0405	2017-08-14 09:35:00+03	2017-08-14 10:30:00+03	DME	LED	Arrived	321	2017-08-14 09:37:00+03	2017-08-14 10:33:00+03
92	PG0404	2017-08-14 19:05:00+03	2017-08-14 20:00:00+03	DME	LED	Arrived	321	2017-08-14 19:05:00+03	2017-08-14 20:00:00+03
93	PG0403	2017-08-14 11:25:00+03	2017-08-14 12:20:00+03	DME	LED	Arrived	321	2017-08-14 11:26:00+03	2017-08-14 12:21:00+03
94	PG0402	2017-08-24 12:25:00+03	2017-08-24 13:20:00+03	DME	LED	Scheduled	321	\N	\N
95	PG0403	2017-08-24 11:25:00+03	2017-08-24 12:20:00+03	DME	LED	Scheduled	321	\N	\N
96	PG0402	2017-08-14 12:25:00+03	2017-08-14 13:20:00+03	DME	LED	Arrived	321	2017-08-14 12:30:00+03	2017-08-14 13:25:00+03
97	PG0404	2017-08-24 19:05:00+03	2017-08-24 20:00:00+03	DME	LED	Scheduled	321	\N	\N
98	PG0405	2017-08-24 09:35:00+03	2017-08-24 10:30:00+03	DME	LED	Scheduled	321	\N	\N
99	PG0403	2017-08-21 11:25:00+03	2017-08-21 12:20:00+03	DME	LED	Scheduled	321	\N	\N
100	PG0402	2017-09-10 12:25:00+03	2017-09-10 13:20:00+03	DME	LED	Scheduled	321	\N	\N
101	PG0405	2017-09-01 09:35:00+03	2017-09-01 10:30:00+03	DME	LED	Scheduled	321	\N	\N
102	PG0404	2017-09-01 19:05:00+03	2017-09-01 20:00:00+03	DME	LED	Scheduled	321	\N	\N
103	PG0403	2017-09-01 11:25:00+03	2017-09-01 12:20:00+03	DME	LED	Scheduled	321	\N	\N
104	PG0402	2017-09-01 12:25:00+03	2017-09-01 13:20:00+03	DME	LED	Scheduled	321	\N	\N
105	PG0403	2017-09-10 11:25:00+03	2017-09-10 12:20:00+03	DME	LED	Scheduled	321	\N	\N
106	PG0402	2017-08-11 12:25:00+03	2017-08-11 13:20:00+03	DME	LED	Arrived	321	2017-08-11 12:27:00+03	2017-08-11 13:23:00+03
107	PG0403	2017-08-11 11:25:00+03	2017-08-11 12:20:00+03	DME	LED	Arrived	321	2017-08-11 11:27:00+03	2017-08-11 12:21:00+03
108	PG0404	2017-08-11 19:05:00+03	2017-08-11 20:00:00+03	DME	LED	Arrived	321	2017-08-11 19:10:00+03	2017-08-11 20:04:00+03
109	PG0405	2017-08-11 09:35:00+03	2017-08-11 10:30:00+03	DME	LED	Arrived	321	2017-08-11 09:36:00+03	2017-08-11 10:31:00+03
110	PG0403	2017-08-13 11:25:00+03	2017-08-13 12:20:00+03	DME	LED	Arrived	321	2017-08-13 11:28:00+03	2017-08-13 12:23:00+03
111	PG0404	2017-09-10 19:05:00+03	2017-09-10 20:00:00+03	DME	LED	Scheduled	321	\N	\N
112	PG0405	2017-09-10 09:35:00+03	2017-09-10 10:30:00+03	DME	LED	Scheduled	321	\N	\N
113	PG0404	2017-08-13 19:05:00+03	2017-08-13 20:00:00+03	DME	LED	Arrived	321	2017-08-13 19:07:00+03	2017-08-13 20:02:00+03
114	PG0405	2017-08-13 09:35:00+03	2017-08-13 10:30:00+03	DME	LED	Arrived	321	2017-08-13 09:39:00+03	2017-08-13 10:34:00+03
115	PG0402	2017-08-31 12:25:00+03	2017-08-31 13:20:00+03	DME	LED	Scheduled	321	\N	\N
116	PG0403	2017-08-31 11:25:00+03	2017-08-31 12:20:00+03	DME	LED	Scheduled	321	\N	\N
117	PG0405	2017-08-27 09:35:00+03	2017-08-27 10:30:00+03	DME	LED	Scheduled	321	\N	\N
118	PG0404	2017-08-21 19:05:00+03	2017-08-21 20:00:00+03	DME	LED	Scheduled	321	\N	\N
119	PG0404	2017-08-27 19:05:00+03	2017-08-27 20:00:00+03	DME	LED	Scheduled	321	\N	\N
120	PG0404	2017-08-31 19:05:00+03	2017-08-31 20:00:00+03	DME	LED	Scheduled	321	\N	\N
121	PG0405	2017-08-31 09:35:00+03	2017-08-31 10:30:00+03	DME	LED	Scheduled	321	\N	\N
122	PG0405	2017-08-21 09:35:00+03	2017-08-21 10:30:00+03	DME	LED	Scheduled	321	\N	\N
123	PG0402	2017-07-29 12:25:00+03	2017-07-29 13:20:00+03	DME	LED	Arrived	321	2017-07-29 12:27:00+03	2017-07-29 13:22:00+03
124	PG0403	2017-07-29 11:25:00+03	2017-07-29 12:20:00+03	DME	LED	Arrived	321	2017-07-29 11:25:00+03	2017-07-29 12:20:00+03
125	PG0404	2017-07-29 19:05:00+03	2017-07-29 20:00:00+03	DME	LED	Arrived	321	2017-07-29 19:07:00+03	2017-07-29 20:02:00+03
126	PG0405	2017-07-29 09:35:00+03	2017-07-29 10:30:00+03	DME	LED	Arrived	321	2017-07-29 09:37:00+03	2017-07-29 10:31:00+03
127	PG0403	2017-08-27 11:25:00+03	2017-08-27 12:20:00+03	DME	LED	Scheduled	321	\N	\N
128	PG0402	2017-08-27 12:25:00+03	2017-08-27 13:20:00+03	DME	LED	Scheduled	321	\N	\N
129	PG0405	2017-07-24 09:35:00+03	2017-07-24 10:30:00+03	DME	LED	Arrived	321	2017-07-24 09:41:00+03	2017-07-24 10:36:00+03
130	PG0404	2017-07-24 19:05:00+03	2017-07-24 20:00:00+03	DME	LED	Arrived	321	2017-07-24 19:05:00+03	2017-07-24 20:00:00+03
131	PG0403	2017-07-24 11:25:00+03	2017-07-24 12:20:00+03	DME	LED	Arrived	321	2017-07-24 11:28:00+03	2017-07-24 12:23:00+03
132	PG0402	2017-07-24 12:25:00+03	2017-07-24 13:20:00+03	DME	LED	Arrived	321	2017-07-24 12:29:00+03	2017-07-24 13:24:00+03
133	PG0405	2017-08-19 09:35:00+03	2017-08-19 10:30:00+03	DME	LED	Scheduled	321	\N	\N
134	PG0404	2017-08-19 19:05:00+03	2017-08-19 20:00:00+03	DME	LED	Scheduled	321	\N	\N
135	PG0403	2017-08-19 11:25:00+03	2017-08-19 12:20:00+03	DME	LED	Scheduled	321	\N	\N
136	PG0402	2017-08-19 12:25:00+03	2017-08-19 13:20:00+03	DME	LED	Scheduled	321	\N	\N
137	PG0404	2017-08-25 19:05:00+03	2017-08-25 20:00:00+03	DME	LED	Scheduled	321	\N	\N
138	PG0405	2017-09-07 09:35:00+03	2017-09-07 10:30:00+03	DME	LED	Scheduled	321	\N	\N
139	PG0402	2017-07-30 12:25:00+03	2017-07-30 13:20:00+03	DME	LED	Arrived	321	2017-07-30 12:30:00+03	2017-07-30 13:25:00+03
140	PG0403	2017-07-30 11:25:00+03	2017-07-30 12:20:00+03	DME	LED	Arrived	321	2017-07-30 11:27:00+03	2017-07-30 12:22:00+03
141	PG0404	2017-07-30 19:05:00+03	2017-07-30 20:00:00+03	DME	LED	Arrived	321	2017-07-30 19:10:00+03	2017-07-30 20:06:00+03
142	PG0405	2017-07-30 09:35:00+03	2017-07-30 10:30:00+03	DME	LED	Arrived	321	2017-07-30 09:35:00+03	2017-07-30 10:30:00+03
143	PG0404	2017-09-07 19:05:00+03	2017-09-07 20:00:00+03	DME	LED	Scheduled	321	\N	\N
144	PG0403	2017-09-07 11:25:00+03	2017-09-07 12:20:00+03	DME	LED	Scheduled	321	\N	\N
145	PG0402	2017-09-07 12:25:00+03	2017-09-07 13:20:00+03	DME	LED	Scheduled	321	\N	\N
146	PG0403	2017-08-25 11:25:00+03	2017-08-25 12:20:00+03	DME	LED	Scheduled	321	\N	\N
147	PG0402	2017-08-28 12:25:00+03	2017-08-28 13:20:00+03	DME	LED	Scheduled	321	\N	\N
148	PG0403	2017-08-28 11:25:00+03	2017-08-28 12:20:00+03	DME	LED	Scheduled	321	\N	\N
149	PG0404	2017-08-28 19:05:00+03	2017-08-28 20:00:00+03	DME	LED	Scheduled	321	\N	\N
150	PG0405	2017-08-28 09:35:00+03	2017-08-28 10:30:00+03	DME	LED	Scheduled	321	\N	\N
151	PG0405	2017-08-20 09:35:00+03	2017-08-20 10:30:00+03	DME	LED	Scheduled	321	\N	\N
152	PG0405	2017-07-23 09:35:00+03	2017-07-23 10:30:00+03	DME	LED	Arrived	321	2017-07-23 09:38:00+03	2017-07-23 10:32:00+03
153	PG0404	2017-07-23 19:05:00+03	2017-07-23 20:00:00+03	DME	LED	Arrived	321	2017-07-23 19:07:00+03	2017-07-23 20:02:00+03
154	PG0403	2017-07-23 11:25:00+03	2017-07-23 12:20:00+03	DME	LED	Arrived	321	2017-07-23 11:29:00+03	2017-07-23 12:24:00+03
155	PG0402	2017-07-23 12:25:00+03	2017-07-23 13:20:00+03	DME	LED	Arrived	321	2017-07-23 12:28:00+03	2017-07-23 13:24:00+03
156	PG0404	2017-08-20 19:05:00+03	2017-08-20 20:00:00+03	DME	LED	Scheduled	321	\N	\N
157	PG0402	2017-07-31 12:25:00+03	2017-07-31 13:20:00+03	DME	LED	Arrived	321	2017-07-31 12:32:00+03	2017-07-31 13:26:00+03
158	PG0403	2017-07-31 11:25:00+03	2017-07-31 12:20:00+03	DME	LED	Arrived	321	2017-07-31 11:26:00+03	2017-07-31 12:21:00+03
159	PG0404	2017-07-31 19:05:00+03	2017-07-31 20:00:00+03	DME	LED	Arrived	321	2017-07-31 19:05:00+03	2017-07-31 20:00:00+03
160	PG0405	2017-07-31 09:35:00+03	2017-07-31 10:30:00+03	DME	LED	Arrived	321	2017-07-31 09:40:00+03	2017-07-31 10:36:00+03
161	PG0403	2017-08-20 11:25:00+03	2017-08-20 12:20:00+03	DME	LED	Scheduled	321	\N	\N
162	PG0405	2017-08-18 09:35:00+03	2017-08-18 10:30:00+03	DME	LED	Scheduled	321	\N	\N
163	PG0402	2017-08-20 12:25:00+03	2017-08-20 13:20:00+03	DME	LED	Scheduled	321	\N	\N
164	PG0404	2017-08-18 19:05:00+03	2017-08-18 20:00:00+03	DME	LED	Scheduled	321	\N	\N
165	PG0403	2017-08-18 11:25:00+03	2017-08-18 12:20:00+03	DME	LED	Scheduled	321	\N	\N
166	PG0402	2017-08-18 12:25:00+03	2017-08-18 13:20:00+03	DME	LED	Scheduled	321	\N	\N
167	PG0402	2017-07-27 12:25:00+03	2017-07-27 13:20:00+03	DME	LED	Arrived	321	2017-07-27 12:26:00+03	2017-07-27 13:21:00+03
168	PG0405	2017-09-06 09:35:00+03	2017-09-06 10:30:00+03	DME	LED	Scheduled	321	\N	\N
169	PG0404	2017-09-06 19:05:00+03	2017-09-06 20:00:00+03	DME	LED	Scheduled	321	\N	\N
170	PG0403	2017-09-06 11:25:00+03	2017-09-06 12:20:00+03	DME	LED	Scheduled	321	\N	\N
171	PG0402	2017-09-06 12:25:00+03	2017-09-06 13:20:00+03	DME	LED	Scheduled	321	\N	\N
172	PG0402	2017-09-11 12:25:00+03	2017-09-11 13:20:00+03	DME	LED	Scheduled	321	\N	\N
173	PG0402	2017-08-01 12:25:00+03	2017-08-01 13:20:00+03	DME	LED	Arrived	321	2017-08-01 12:28:00+03	2017-08-01 13:22:00+03
174	PG0403	2017-08-01 11:25:00+03	2017-08-01 12:20:00+03	DME	LED	Arrived	321	2017-08-01 11:32:00+03	2017-08-01 12:28:00+03
175	PG0404	2017-08-01 19:05:00+03	2017-08-01 20:00:00+03	DME	LED	Arrived	321	2017-08-01 19:08:00+03	2017-08-01 20:04:00+03
176	PG0405	2017-08-01 09:35:00+03	2017-08-01 10:30:00+03	DME	LED	Arrived	321	2017-08-01 09:39:00+03	2017-08-01 10:33:00+03
177	PG0403	2017-09-11 11:25:00+03	2017-09-11 12:20:00+03	DME	LED	Scheduled	321	\N	\N
178	PG0404	2017-09-11 19:05:00+03	2017-09-11 20:00:00+03	DME	LED	Scheduled	321	\N	\N
179	PG0405	2017-09-11 09:35:00+03	2017-09-11 10:30:00+03	DME	LED	Scheduled	321	\N	\N
180	PG0403	2017-07-27 11:25:00+03	2017-07-27 12:20:00+03	DME	LED	Arrived	321	2017-07-27 11:27:00+03	2017-07-27 12:22:00+03
181	PG0404	2017-07-27 19:05:00+03	2017-07-27 20:00:00+03	DME	LED	Arrived	321	2017-07-27 19:07:00+03	2017-07-27 20:02:00+03
182	PG0405	2017-07-22 09:35:00+03	2017-07-22 10:30:00+03	DME	LED	Arrived	321	2017-07-22 09:39:00+03	2017-07-22 10:34:00+03
183	PG0405	2017-07-27 09:35:00+03	2017-07-27 10:30:00+03	DME	LED	Arrived	321	2017-07-27 09:37:00+03	2017-07-27 10:33:00+03
184	PG0404	2017-07-22 19:05:00+03	2017-07-22 20:00:00+03	DME	LED	Arrived	321	2017-07-22 19:06:00+03	2017-07-22 20:01:00+03
185	PG0403	2017-07-22 11:25:00+03	2017-07-22 12:20:00+03	DME	LED	Arrived	321	2017-07-22 11:30:00+03	2017-07-22 12:26:00+03
186	PG0402	2017-07-22 12:25:00+03	2017-07-22 13:20:00+03	DME	LED	Arrived	321	2017-07-22 12:28:00+03	2017-07-22 13:24:00+03
187	PG0402	2017-08-22 12:25:00+03	2017-08-22 13:20:00+03	DME	LED	Scheduled	321	\N	\N
188	PG0403	2017-08-22 11:25:00+03	2017-08-22 12:20:00+03	DME	LED	Scheduled	321	\N	\N
189	PG0404	2017-08-22 19:05:00+03	2017-08-22 20:00:00+03	DME	LED	Scheduled	321	\N	\N
190	PG0405	2017-08-22 09:35:00+03	2017-08-22 10:30:00+03	DME	LED	Scheduled	321	\N	\N
191	PG0402	2017-08-02 12:25:00+03	2017-08-02 13:20:00+03	DME	LED	Arrived	321	2017-08-02 15:42:00+03	2017-08-02 16:37:00+03
192	PG0403	2017-08-02 11:25:00+03	2017-08-02 12:20:00+03	DME	LED	Arrived	321	2017-08-02 11:27:00+03	2017-08-02 12:22:00+03
193	PG0404	2017-08-02 19:05:00+03	2017-08-02 20:00:00+03	DME	LED	Arrived	321	2017-08-02 21:59:00+03	2017-08-02 22:53:00+03
194	PG0405	2017-08-02 09:35:00+03	2017-08-02 10:30:00+03	DME	LED	Arrived	321	2017-08-02 09:38:00+03	2017-08-02 10:34:00+03
195	PG0402	2017-08-25 12:25:00+03	2017-08-25 13:20:00+03	DME	LED	Scheduled	321	\N	\N
196	PG0404	2017-09-09 19:05:00+03	2017-09-09 20:00:00+03	DME	LED	Scheduled	321	\N	\N
197	PG0405	2017-09-05 09:35:00+03	2017-09-05 10:30:00+03	DME	LED	Scheduled	321	\N	\N
198	PG0404	2017-09-05 19:05:00+03	2017-09-05 20:00:00+03	DME	LED	Scheduled	321	\N	\N
199	PG0403	2017-09-05 11:25:00+03	2017-09-05 12:20:00+03	DME	LED	Scheduled	321	\N	\N
200	PG0402	2017-09-05 12:25:00+03	2017-09-05 13:20:00+03	DME	LED	Scheduled	321	\N	\N
201	PG0405	2017-08-17 09:35:00+03	2017-08-17 10:30:00+03	DME	LED	Scheduled	321	\N	\N
202	PG0404	2017-08-17 19:05:00+03	2017-08-17 20:00:00+03	DME	LED	Scheduled	321	\N	\N
203	PG0403	2017-08-17 11:25:00+03	2017-08-17 12:20:00+03	DME	LED	Scheduled	321	\N	\N
204	PG0402	2017-08-17 12:25:00+03	2017-08-17 13:20:00+03	DME	LED	Scheduled	321	\N	\N
205	PG0402	2017-08-03 12:25:00+03	2017-08-03 13:20:00+03	DME	LED	Arrived	321	2017-08-03 12:29:00+03	2017-08-03 13:24:00+03
206	PG0403	2017-08-03 11:25:00+03	2017-08-03 12:20:00+03	DME	LED	Arrived	321	2017-08-03 11:28:00+03	2017-08-03 12:23:00+03
207	PG0404	2017-08-03 19:05:00+03	2017-08-03 20:00:00+03	DME	LED	Arrived	321	2017-08-03 19:10:00+03	2017-08-03 20:04:00+03
208	PG0405	2017-08-03 09:35:00+03	2017-08-03 10:30:00+03	DME	LED	Arrived	321	2017-08-03 09:37:00+03	2017-08-03 10:31:00+03
209	PG0405	2017-07-25 09:35:00+03	2017-07-25 10:30:00+03	DME	LED	Arrived	321	2017-07-25 09:43:00+03	2017-07-25 10:38:00+03
210	PG0405	2017-07-21 09:35:00+03	2017-07-21 10:30:00+03	DME	LED	Arrived	321	2017-07-21 09:39:00+03	2017-07-21 10:35:00+03
211	PG0404	2017-07-21 19:05:00+03	2017-07-21 20:00:00+03	DME	LED	Arrived	321	2017-07-21 19:07:00+03	2017-07-21 20:01:00+03
212	PG0403	2017-07-21 11:25:00+03	2017-07-21 12:20:00+03	DME	LED	Arrived	321	2017-07-21 11:28:00+03	2017-07-21 12:23:00+03
213	PG0402	2017-07-21 12:25:00+03	2017-07-21 13:20:00+03	DME	LED	Arrived	321	2017-07-21 12:29:00+03	2017-07-21 13:24:00+03
214	PG0404	2017-07-25 19:05:00+03	2017-07-25 20:00:00+03	DME	LED	Arrived	321	2017-07-25 19:10:00+03	2017-07-25 20:05:00+03
215	PG0405	2017-08-26 09:35:00+03	2017-08-26 10:30:00+03	DME	LED	Scheduled	321	\N	\N
216	PG0404	2017-08-26 19:05:00+03	2017-08-26 20:00:00+03	DME	LED	Scheduled	321	\N	\N
217	PG0403	2017-08-26 11:25:00+03	2017-08-26 12:20:00+03	DME	LED	Scheduled	321	\N	\N
218	PG0402	2017-08-26 12:25:00+03	2017-08-26 13:20:00+03	DME	LED	Scheduled	321	\N	\N
219	PG0403	2017-07-25 11:25:00+03	2017-07-25 12:20:00+03	DME	LED	Arrived	321	2017-07-25 11:29:00+03	2017-07-25 12:24:00+03
220	PG0402	2017-07-25 12:25:00+03	2017-07-25 13:20:00+03	DME	LED	Arrived	321	2017-07-25 12:28:00+03	2017-07-25 13:23:00+03
221	PG0402	2017-08-04 12:25:00+03	2017-08-04 13:20:00+03	DME	LED	Arrived	321	2017-08-04 12:29:00+03	2017-08-04 13:24:00+03
222	PG0403	2017-08-04 11:25:00+03	2017-08-04 12:20:00+03	DME	LED	Arrived	321	2017-08-04 11:29:00+03	2017-08-04 12:24:00+03
223	PG0404	2017-08-04 19:05:00+03	2017-08-04 20:00:00+03	DME	LED	Arrived	321	2017-08-04 19:06:00+03	2017-08-04 20:02:00+03
224	PG0405	2017-08-04 09:35:00+03	2017-08-04 10:30:00+03	DME	LED	Arrived	321	2017-08-04 09:37:00+03	2017-08-04 10:32:00+03
225	PG0402	2017-09-12 12:25:00+03	2017-09-12 13:20:00+03	DME	LED	Scheduled	321	\N	\N
226	PG0403	2017-09-12 11:25:00+03	2017-09-12 12:20:00+03	DME	LED	Scheduled	321	\N	\N
227	PG0404	2017-09-12 19:05:00+03	2017-09-12 20:00:00+03	DME	LED	Scheduled	321	\N	\N
228	PG0405	2017-09-12 09:35:00+03	2017-09-12 10:30:00+03	DME	LED	Scheduled	321	\N	\N
229	PG0405	2017-07-26 09:35:00+03	2017-07-26 10:30:00+03	DME	LED	Arrived	321	2017-07-26 09:35:00+03	2017-07-26 10:31:00+03
230	PG0402	2017-08-29 12:25:00+03	2017-08-29 13:20:00+03	DME	LED	Scheduled	321	\N	\N
231	PG0403	2017-08-29 11:25:00+03	2017-08-29 12:20:00+03	DME	LED	Scheduled	321	\N	\N
232	PG0404	2017-08-29 19:05:00+03	2017-08-29 20:00:00+03	DME	LED	Scheduled	321	\N	\N
233	PG0405	2017-08-29 09:35:00+03	2017-08-29 10:30:00+03	DME	LED	Scheduled	321	\N	\N
234	PG0403	2017-09-09 11:25:00+03	2017-09-09 12:20:00+03	DME	LED	Scheduled	321	\N	\N
235	PG0405	2017-09-04 09:35:00+03	2017-09-04 10:30:00+03	DME	LED	Scheduled	321	\N	\N
236	PG0404	2017-09-04 19:05:00+03	2017-09-04 20:00:00+03	DME	LED	Scheduled	321	\N	\N
237	PG0403	2017-09-04 11:25:00+03	2017-09-04 12:20:00+03	DME	LED	Scheduled	321	\N	\N
238	PG0402	2017-09-04 12:25:00+03	2017-09-04 13:20:00+03	DME	LED	Scheduled	321	\N	\N
239	PG0405	2017-07-20 09:35:00+03	2017-07-20 10:30:00+03	DME	LED	Arrived	321	2017-07-20 09:38:00+03	2017-07-20 10:33:00+03
240	PG0404	2017-07-20 19:05:00+03	2017-07-20 20:00:00+03	DME	LED	Arrived	321	2017-07-20 19:10:00+03	2017-07-20 20:06:00+03
241	PG0403	2017-07-20 11:25:00+03	2017-07-20 12:20:00+03	DME	LED	Arrived	321	2017-07-20 11:25:00+03	2017-07-20 12:20:00+03
242	PG0402	2017-07-20 12:25:00+03	2017-07-20 13:20:00+03	DME	LED	Arrived	321	2017-07-20 12:26:00+03	2017-07-20 13:20:00+03
243	PG0402	2017-08-05 12:25:00+03	2017-08-05 13:20:00+03	DME	LED	Arrived	321	2017-08-05 12:26:00+03	2017-08-05 13:20:00+03
244	PG0403	2017-08-05 11:25:00+03	2017-08-05 12:20:00+03	DME	LED	Arrived	321	2017-08-05 11:33:00+03	2017-08-05 12:28:00+03
245	PG0222	2017-07-18 11:05:00+03	2017-07-18 14:30:00+03	DME	OVB	Arrived	773	2017-07-18 11:06:00+03	2017-07-18 14:32:00+03
246	PG0222	2017-09-05 11:05:00+03	2017-09-05 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
247	PG0222	2017-08-07 11:05:00+03	2017-08-07 14:30:00+03	DME	OVB	Arrived	773	2017-08-07 11:09:00+03	2017-08-07 14:35:00+03
248	PG0222	2017-09-08 11:05:00+03	2017-09-08 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
249	PG0222	2017-08-13 11:05:00+03	2017-08-13 14:30:00+03	DME	OVB	Arrived	773	2017-08-13 11:06:00+03	2017-08-13 14:32:00+03
250	PG0222	2017-08-02 11:05:00+03	2017-08-02 14:30:00+03	DME	OVB	Arrived	773	2017-08-02 11:09:00+03	2017-08-02 14:36:00+03
251	PG0222	2017-07-19 11:05:00+03	2017-07-19 14:30:00+03	DME	OVB	Arrived	773	2017-07-19 11:08:00+03	2017-07-19 14:32:00+03
252	PG0222	2017-09-04 11:05:00+03	2017-09-04 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
253	PG0222	2017-09-13 11:05:00+03	2017-09-13 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
254	PG0222	2017-09-12 11:05:00+03	2017-09-12 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
255	PG0222	2017-07-20 11:05:00+03	2017-07-20 14:30:00+03	DME	OVB	Arrived	773	2017-07-20 11:11:00+03	2017-07-20 14:34:00+03
256	PG0222	2017-08-27 11:05:00+03	2017-08-27 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
257	PG0222	2017-09-11 11:05:00+03	2017-09-11 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
258	PG0222	2017-07-23 11:05:00+03	2017-07-23 14:30:00+03	DME	OVB	Arrived	773	2017-07-23 11:09:00+03	2017-07-23 14:36:00+03
259	PG0222	2017-07-29 11:05:00+03	2017-07-29 14:30:00+03	DME	OVB	Arrived	773	2017-07-29 11:08:00+03	2017-07-29 14:37:00+03
260	PG0222	2017-08-17 11:05:00+03	2017-08-17 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
261	PG0222	2017-08-24 11:05:00+03	2017-08-24 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
262	PG0222	2017-09-14 11:05:00+03	2017-09-14 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
263	PG0222	2017-09-02 11:05:00+03	2017-09-02 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
264	PG0222	2017-09-03 11:05:00+03	2017-09-03 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
265	PG0222	2017-07-28 11:05:00+03	2017-07-28 14:30:00+03	DME	OVB	Arrived	773	2017-07-28 14:40:00+03	2017-07-28 18:02:00+03
266	PG0222	2017-07-22 11:05:00+03	2017-07-22 14:30:00+03	DME	OVB	Arrived	773	2017-07-22 11:05:00+03	2017-07-22 14:30:00+03
267	PG0222	2017-08-20 11:05:00+03	2017-08-20 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
268	PG0222	2017-08-05 11:05:00+03	2017-08-05 14:30:00+03	DME	OVB	Arrived	773	2017-08-05 11:06:00+03	2017-08-05 14:30:00+03
269	PG0222	2017-08-25 11:05:00+03	2017-08-25 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
270	PG0222	2017-08-22 11:05:00+03	2017-08-22 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
271	PG0222	2017-08-10 11:05:00+03	2017-08-10 14:30:00+03	DME	OVB	Arrived	773	2017-08-10 14:09:00+03	2017-08-10 17:34:00+03
272	PG0222	2017-07-26 11:05:00+03	2017-07-26 14:30:00+03	DME	OVB	Arrived	773	2017-07-26 11:10:00+03	2017-07-26 14:36:00+03
273	PG0222	2017-08-01 11:05:00+03	2017-08-01 14:30:00+03	DME	OVB	Arrived	773	2017-08-01 11:10:00+03	2017-08-01 14:37:00+03
274	PG0222	2017-08-28 11:05:00+03	2017-08-28 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
275	PG0222	2017-08-03 11:05:00+03	2017-08-03 14:30:00+03	DME	OVB	Arrived	773	2017-08-03 11:07:00+03	2017-08-03 14:29:00+03
276	PG0222	2017-08-08 11:05:00+03	2017-08-08 14:30:00+03	DME	OVB	Arrived	773	2017-08-08 11:12:00+03	2017-08-08 14:36:00+03
277	PG0222	2017-07-16 11:05:00+03	2017-07-16 14:30:00+03	DME	OVB	Arrived	773	2017-07-16 11:06:00+03	2017-07-16 14:31:00+03
278	PG0222	2017-07-21 11:05:00+03	2017-07-21 14:30:00+03	DME	OVB	Arrived	773	2017-07-21 11:07:00+03	2017-07-21 14:30:00+03
279	PG0222	2017-07-24 11:05:00+03	2017-07-24 14:30:00+03	DME	OVB	Arrived	773	2017-07-24 11:05:00+03	2017-07-24 14:31:00+03
280	PG0222	2017-09-09 11:05:00+03	2017-09-09 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
281	PG0222	2017-08-15 11:05:00+03	2017-08-15 14:30:00+03	DME	OVB	Arrived	773	2017-08-15 11:08:00+03	2017-08-15 14:34:00+03
282	PG0222	2017-07-30 11:05:00+03	2017-07-30 14:30:00+03	DME	OVB	Arrived	773	2017-07-30 11:07:00+03	2017-07-30 14:29:00+03
283	PG0222	2017-08-19 11:05:00+03	2017-08-19 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
284	PG0222	2017-08-21 11:05:00+03	2017-08-21 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
285	PG0222	2017-08-31 11:05:00+03	2017-08-31 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
286	PG0222	2017-08-04 11:05:00+03	2017-08-04 14:30:00+03	DME	OVB	Arrived	773	2017-08-04 11:08:00+03	2017-08-04 14:31:00+03
287	PG0222	2017-08-30 11:05:00+03	2017-08-30 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
288	PG0222	2017-07-17 11:05:00+03	2017-07-17 14:30:00+03	DME	OVB	Arrived	773	2017-07-17 11:10:00+03	2017-07-17 14:36:00+03
289	PG0222	2017-08-12 11:05:00+03	2017-08-12 14:30:00+03	DME	OVB	Arrived	773	2017-08-12 11:08:00+03	2017-08-12 14:36:00+03
290	PG0222	2017-08-23 11:05:00+03	2017-08-23 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
291	PG0222	2017-09-10 11:05:00+03	2017-09-10 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
292	PG0222	2017-08-11 11:05:00+03	2017-08-11 14:30:00+03	DME	OVB	Arrived	773	2017-08-11 11:05:00+03	2017-08-11 14:26:00+03
293	PG0222	2017-08-29 11:05:00+03	2017-08-29 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
294	PG0222	2017-08-18 11:05:00+03	2017-08-18 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
295	PG0222	2017-07-25 11:05:00+03	2017-07-25 14:30:00+03	DME	OVB	Arrived	773	2017-07-25 11:10:00+03	2017-07-25 14:36:00+03
296	PG0222	2017-09-06 11:05:00+03	2017-09-06 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
297	PG0222	2017-08-14 11:05:00+03	2017-08-14 14:30:00+03	DME	OVB	Arrived	773	2017-08-14 11:09:00+03	2017-08-14 14:37:00+03
298	PG0222	2017-08-06 11:05:00+03	2017-08-06 14:30:00+03	DME	OVB	Arrived	773	2017-08-06 11:08:00+03	2017-08-06 14:35:00+03
299	PG0222	2017-09-07 11:05:00+03	2017-09-07 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
300	PG0222	2017-08-26 11:05:00+03	2017-08-26 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
301	PG0222	2017-08-09 11:05:00+03	2017-08-09 14:30:00+03	DME	OVB	Arrived	773	2017-08-09 11:08:00+03	2017-08-09 14:31:00+03
302	PG0222	2017-07-27 11:05:00+03	2017-07-27 14:30:00+03	DME	OVB	Arrived	773	2017-07-27 11:07:00+03	2017-07-27 14:34:00+03
303	PG0222	2017-09-01 11:05:00+03	2017-09-01 14:30:00+03	DME	OVB	Scheduled	773	\N	\N
304	PG0222	2017-08-16 11:05:00+03	2017-08-16 14:30:00+03	DME	OVB	On Time	773	\N	\N
305	PG0222	2017-07-31 11:05:00+03	2017-07-31 14:30:00+03	DME	OVB	Arrived	773	2017-07-31 11:10:00+03	2017-07-31 14:36:00+03
306	PG0202	2017-08-12 10:40:00+03	2017-08-12 11:35:00+03	DME	KZN	Arrived	321	2017-08-12 10:43:00+03	2017-08-12 11:37:00+03
307	PG0202	2017-07-26 10:40:00+03	2017-07-26 11:35:00+03	DME	KZN	Arrived	321	2017-07-26 10:41:00+03	2017-07-26 11:36:00+03
308	PG0202	2017-07-27 10:40:00+03	2017-07-27 11:35:00+03	DME	KZN	Arrived	321	2017-07-27 10:43:00+03	2017-07-27 11:38:00+03
309	PG0202	2017-09-09 10:40:00+03	2017-09-09 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
310	PG0202	2017-08-21 10:40:00+03	2017-08-21 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
311	PG0202	2017-08-20 10:40:00+03	2017-08-20 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
312	PG0202	2017-07-28 10:40:00+03	2017-07-28 11:35:00+03	DME	KZN	Arrived	321	2017-07-28 10:46:00+03	2017-07-28 11:40:00+03
313	PG0202	2017-08-13 10:40:00+03	2017-08-13 11:35:00+03	DME	KZN	Arrived	321	2017-08-13 10:43:00+03	2017-08-13 11:38:00+03
314	PG0202	2017-09-10 10:40:00+03	2017-09-10 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
315	PG0202	2017-07-25 10:40:00+03	2017-07-25 11:35:00+03	DME	KZN	Arrived	321	2017-07-25 10:42:00+03	2017-07-25 11:37:00+03
316	PG0202	2017-09-08 10:40:00+03	2017-09-08 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
317	PG0202	2017-07-29 10:40:00+03	2017-07-29 11:35:00+03	DME	KZN	Arrived	321	2017-07-29 10:42:00+03	2017-07-29 11:38:00+03
318	PG0202	2017-08-28 10:40:00+03	2017-08-28 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
319	PG0202	2017-08-27 10:40:00+03	2017-08-27 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
320	PG0202	2017-07-24 10:40:00+03	2017-07-24 11:35:00+03	DME	KZN	Arrived	321	2017-07-24 10:43:00+03	2017-07-24 11:38:00+03
321	PG0202	2017-07-30 10:40:00+03	2017-07-30 11:35:00+03	DME	KZN	Arrived	321	2017-07-30 10:41:00+03	2017-07-30 11:36:00+03
322	PG0202	2017-08-19 10:40:00+03	2017-08-19 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
323	PG0202	2017-09-07 10:40:00+03	2017-09-07 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
324	PG0202	2017-07-31 10:40:00+03	2017-07-31 11:35:00+03	DME	KZN	Arrived	321	2017-07-31 14:25:00+03	2017-07-31 15:20:00+03
325	PG0202	2017-09-11 10:40:00+03	2017-09-11 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
326	PG0202	2017-07-23 10:40:00+03	2017-07-23 11:35:00+03	DME	KZN	Arrived	321	2017-07-23 10:42:00+03	2017-07-23 11:37:00+03
327	PG0202	2017-08-22 10:40:00+03	2017-08-22 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
328	PG0202	2017-08-01 10:40:00+03	2017-08-01 11:35:00+03	DME	KZN	Arrived	321	2017-08-01 10:43:00+03	2017-08-01 11:38:00+03
329	PG0202	2017-08-18 10:40:00+03	2017-08-18 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
330	PG0202	2017-09-06 10:40:00+03	2017-09-06 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
331	PG0202	2017-07-16 10:40:00+03	2017-07-16 11:35:00+03	DME	KZN	Arrived	321	2017-07-16 13:37:00+03	2017-07-16 14:32:00+03
332	PG0202	2017-08-02 10:40:00+03	2017-08-02 11:35:00+03	DME	KZN	Arrived	321	2017-08-02 10:43:00+03	2017-08-02 11:38:00+03
333	PG0202	2017-07-22 10:40:00+03	2017-07-22 11:35:00+03	DME	KZN	Arrived	321	2017-07-22 13:57:00+03	2017-07-22 14:51:00+03
334	PG0202	2017-08-29 10:40:00+03	2017-08-29 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
335	PG0202	2017-08-03 10:40:00+03	2017-08-03 11:35:00+03	DME	KZN	Arrived	321	2017-08-03 10:41:00+03	2017-08-03 11:36:00+03
336	PG0202	2017-09-12 10:40:00+03	2017-09-12 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
337	PG0202	2017-09-05 10:40:00+03	2017-09-05 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
338	PG0202	2017-08-17 10:40:00+03	2017-08-17 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
339	PG0202	2017-08-04 10:40:00+03	2017-08-04 11:35:00+03	DME	KZN	Arrived	321	2017-08-04 10:43:00+03	2017-08-04 11:37:00+03
340	PG0202	2017-07-21 10:40:00+03	2017-07-21 11:35:00+03	DME	KZN	Arrived	321	2017-07-21 10:44:00+03	2017-07-21 11:40:00+03
341	PG0202	2017-08-23 10:40:00+03	2017-08-23 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
342	PG0202	2017-08-05 10:40:00+03	2017-08-05 11:35:00+03	DME	KZN	Arrived	321	2017-08-05 10:43:00+03	2017-08-05 11:37:00+03
343	PG0202	2017-09-04 10:40:00+03	2017-09-04 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
344	PG0202	2017-07-20 10:40:00+03	2017-07-20 11:35:00+03	DME	KZN	Arrived	321	2017-07-20 10:42:00+03	2017-07-20 11:37:00+03
345	PG0202	2017-08-25 10:40:00+03	2017-08-25 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
346	PG0202	2017-08-06 10:40:00+03	2017-08-06 11:35:00+03	DME	KZN	Arrived	321	2017-08-06 13:31:00+03	2017-08-06 14:26:00+03
347	PG0202	2017-08-31 10:40:00+03	2017-08-31 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
348	PG0202	2017-08-26 10:40:00+03	2017-08-26 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
349	PG0202	2017-08-16 10:40:00+03	2017-08-16 11:35:00+03	DME	KZN	On Time	321	\N	\N
350	PG0202	2017-09-13 10:40:00+03	2017-09-13 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
351	PG0202	2017-08-07 10:40:00+03	2017-08-07 11:35:00+03	DME	KZN	Arrived	321	2017-08-07 10:45:00+03	2017-08-07 11:38:00+03
352	PG0202	2017-07-19 10:40:00+03	2017-07-19 11:35:00+03	DME	KZN	Arrived	321	2017-07-19 10:43:00+03	2017-07-19 11:39:00+03
353	PG0202	2017-08-30 10:40:00+03	2017-08-30 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
354	PG0202	2017-09-03 10:40:00+03	2017-09-03 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
355	PG0202	2017-08-08 10:40:00+03	2017-08-08 11:35:00+03	DME	KZN	Arrived	321	2017-08-08 10:43:00+03	2017-08-08 11:38:00+03
356	PG0202	2017-08-15 10:40:00+03	2017-08-15 11:35:00+03	DME	KZN	Arrived	321	2017-08-15 10:44:00+03	2017-08-15 11:39:00+03
357	PG0202	2017-08-09 10:40:00+03	2017-08-09 11:35:00+03	DME	KZN	Arrived	321	2017-08-09 10:43:00+03	2017-08-09 11:38:00+03
358	PG0202	2017-07-18 10:40:00+03	2017-07-18 11:35:00+03	DME	KZN	Arrived	321	2017-07-18 10:43:00+03	2017-07-18 11:39:00+03
359	PG0202	2017-08-24 10:40:00+03	2017-08-24 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
360	PG0202	2017-09-14 10:40:00+03	2017-09-14 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
361	PG0202	2017-09-02 10:40:00+03	2017-09-02 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
362	PG0202	2017-08-10 10:40:00+03	2017-08-10 11:35:00+03	DME	KZN	Arrived	321	2017-08-10 10:41:00+03	2017-08-10 11:36:00+03
363	PG0202	2017-07-17 10:40:00+03	2017-07-17 11:35:00+03	DME	KZN	Arrived	321	2017-07-17 10:40:00+03	2017-07-17 11:35:00+03
364	PG0202	2017-08-11 10:40:00+03	2017-08-11 11:35:00+03	DME	KZN	Arrived	321	2017-08-11 10:44:00+03	2017-08-11 11:39:00+03
365	PG0202	2017-08-14 10:40:00+03	2017-08-14 11:35:00+03	DME	KZN	Arrived	321	2017-08-14 10:44:00+03	2017-08-14 11:39:00+03
366	PG0202	2017-09-01 10:40:00+03	2017-09-01 11:35:00+03	DME	KZN	Scheduled	321	\N	\N
367	PG0273	2017-09-10 09:50:00+03	2017-09-10 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
368	PG0273	2017-08-25 09:50:00+03	2017-08-25 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
369	PG0273	2017-08-31 09:50:00+03	2017-08-31 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
370	PG0273	2017-07-16 09:50:00+03	2017-07-16 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-16 09:53:00+03	2017-07-16 11:54:00+03
371	PG0273	2017-08-12 09:50:00+03	2017-08-12 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-12 09:52:00+03	2017-08-12 11:51:00+03
372	PG0273	2017-08-13 09:50:00+03	2017-08-13 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-13 09:52:00+03	2017-08-13 11:53:00+03
373	PG0273	2017-09-01 09:50:00+03	2017-09-01 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
374	PG0273	2017-08-11 09:50:00+03	2017-08-11 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-11 09:51:00+03	2017-08-11 11:50:00+03
375	PG0273	2017-08-14 09:50:00+03	2017-08-14 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-14 09:52:00+03	2017-08-14 11:53:00+03
376	PG0273	2017-07-17 09:50:00+03	2017-07-17 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-17 09:53:00+03	2017-07-17 11:52:00+03
377	PG0273	2017-08-10 09:50:00+03	2017-08-10 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-10 09:54:00+03	2017-08-10 11:53:00+03
378	PG0273	2017-08-24 09:50:00+03	2017-08-24 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
379	PG0273	2017-09-14 09:50:00+03	2017-09-14 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
380	PG0273	2017-09-02 09:50:00+03	2017-09-02 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
381	PG0273	2017-08-09 09:50:00+03	2017-08-09 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-09 09:52:00+03	2017-08-09 11:50:00+03
382	PG0273	2017-07-18 09:50:00+03	2017-07-18 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-18 09:52:00+03	2017-07-18 11:50:00+03
383	PG0273	2017-08-15 09:50:00+03	2017-08-15 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-15 09:52:00+03	2017-08-15 11:51:00+03
384	PG0273	2017-08-30 09:50:00+03	2017-08-30 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
385	PG0273	2017-08-08 09:50:00+03	2017-08-08 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-08 13:09:00+03	2017-08-08 15:09:00+03
386	PG0273	2017-09-03 09:50:00+03	2017-09-03 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
387	PG0273	2017-07-19 09:50:00+03	2017-07-19 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-19 09:53:00+03	2017-07-19 11:52:00+03
388	PG0273	2017-08-07 09:50:00+03	2017-08-07 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-07 09:53:00+03	2017-08-07 11:54:00+03
389	PG0273	2017-09-13 09:50:00+03	2017-09-13 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
390	PG0273	2017-08-16 09:50:00+03	2017-08-16 11:50:00+03	DME	CEK	Delayed	SU9	\N	\N
391	PG0273	2017-08-06 09:50:00+03	2017-08-06 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-06 09:55:00+03	2017-08-06 11:54:00+03
392	PG0273	2017-07-20 09:50:00+03	2017-07-20 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-20 13:18:00+03	2017-07-20 15:17:00+03
393	PG0273	2017-08-23 09:50:00+03	2017-08-23 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
394	PG0273	2017-09-04 09:50:00+03	2017-09-04 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
395	PG0273	2017-08-26 09:50:00+03	2017-08-26 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
396	PG0273	2017-08-05 09:50:00+03	2017-08-05 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-05 09:54:00+03	2017-08-05 11:55:00+03
397	PG0273	2017-08-04 09:50:00+03	2017-08-04 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-04 09:51:00+03	2017-08-04 11:50:00+03
398	PG0273	2017-09-12 09:50:00+03	2017-09-12 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
399	PG0273	2017-07-21 09:50:00+03	2017-07-21 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-21 09:53:00+03	2017-07-21 11:53:00+03
400	PG0273	2017-08-17 09:50:00+03	2017-08-17 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
401	PG0273	2017-08-29 09:50:00+03	2017-08-29 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
402	PG0273	2017-09-05 09:50:00+03	2017-09-05 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
403	PG0273	2017-08-03 09:50:00+03	2017-08-03 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-03 09:51:00+03	2017-08-03 11:50:00+03
404	PG0273	2017-07-22 09:50:00+03	2017-07-22 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-22 09:55:00+03	2017-07-22 11:54:00+03
405	PG0273	2017-08-02 09:50:00+03	2017-08-02 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-02 09:58:00+03	2017-08-02 12:00:00+03
406	PG0273	2017-09-06 09:50:00+03	2017-09-06 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
407	PG0273	2017-08-18 09:50:00+03	2017-08-18 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
408	PG0273	2017-08-22 09:50:00+03	2017-08-22 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
409	PG0273	2017-08-01 09:50:00+03	2017-08-01 11:50:00+03	DME	CEK	Arrived	SU9	2017-08-01 09:53:00+03	2017-08-01 11:52:00+03
410	PG0273	2017-09-11 09:50:00+03	2017-09-11 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
411	PG0273	2017-07-23 09:50:00+03	2017-07-23 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-23 09:53:00+03	2017-07-23 11:53:00+03
412	PG0273	2017-07-31 09:50:00+03	2017-07-31 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-31 09:54:00+03	2017-07-31 11:56:00+03
413	PG0273	2017-09-07 09:50:00+03	2017-09-07 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
414	PG0273	2017-07-30 09:50:00+03	2017-07-30 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-30 09:52:00+03	2017-07-30 11:53:00+03
415	PG0273	2017-08-19 09:50:00+03	2017-08-19 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
416	PG0273	2017-07-24 09:50:00+03	2017-07-24 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-24 12:03:00+03	2017-07-24 14:03:00+03
417	PG0273	2017-08-28 09:50:00+03	2017-08-28 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
418	PG0273	2017-07-29 09:50:00+03	2017-07-29 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-29 09:54:00+03	2017-07-29 11:54:00+03
419	PG0273	2017-09-08 09:50:00+03	2017-09-08 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
420	PG0273	2017-08-27 09:50:00+03	2017-08-27 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
421	PG0273	2017-08-21 09:50:00+03	2017-08-21 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
422	PG0273	2017-07-28 09:50:00+03	2017-07-28 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-28 09:50:00+03	2017-07-28 11:51:00+03
423	PG0273	2017-07-25 09:50:00+03	2017-07-25 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-25 09:52:00+03	2017-07-25 11:52:00+03
424	PG0273	2017-08-20 09:50:00+03	2017-08-20 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
425	PG0273	2017-07-27 09:50:00+03	2017-07-27 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-27 09:51:00+03	2017-07-27 11:51:00+03
426	PG0273	2017-09-09 09:50:00+03	2017-09-09 11:50:00+03	DME	CEK	Scheduled	SU9	\N	\N
427	PG0273	2017-07-26 09:50:00+03	2017-07-26 11:50:00+03	DME	CEK	Arrived	SU9	2017-07-26 09:52:00+03	2017-07-26 11:52:00+03
428	PG0216	2017-09-11 14:10:00+03	2017-09-11 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
429	PG0216	2017-08-09 14:10:00+03	2017-08-09 15:15:00+03	DME	KUF	Arrived	763	2017-08-09 14:16:00+03	2017-08-09 15:21:00+03
430	PG0216	2017-07-31 14:10:00+03	2017-07-31 15:15:00+03	DME	KUF	Arrived	763	2017-07-31 14:12:00+03	2017-07-31 15:16:00+03
431	PG0216	2017-09-04 14:10:00+03	2017-09-04 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
432	PG0216	2017-08-21 14:10:00+03	2017-08-21 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
433	PG0216	2017-08-06 14:10:00+03	2017-08-06 15:15:00+03	DME	KUF	Arrived	763	2017-08-06 14:14:00+03	2017-08-06 15:19:00+03
434	PG0216	2017-08-02 14:10:00+03	2017-08-02 15:15:00+03	DME	KUF	Arrived	763	2017-08-02 14:13:00+03	2017-08-02 15:18:00+03
435	PG0216	2017-07-26 14:10:00+03	2017-07-26 15:15:00+03	DME	KUF	Arrived	763	2017-07-26 14:12:00+03	2017-07-26 15:16:00+03
436	PG0216	2017-08-15 14:10:00+03	2017-08-15 15:15:00+03	DME	KUF	Arrived	763	2017-08-15 14:12:00+03	2017-08-15 15:16:00+03
437	PG0216	2017-08-22 14:10:00+03	2017-08-22 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
438	PG0216	2017-07-24 14:10:00+03	2017-07-24 15:15:00+03	DME	KUF	Arrived	763	2017-07-24 14:16:00+03	2017-07-24 15:22:00+03
439	PG0216	2017-09-02 14:10:00+03	2017-09-02 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
440	PG0216	2017-07-18 14:10:00+03	2017-07-18 15:15:00+03	DME	KUF	Arrived	763	2017-07-18 14:12:00+03	2017-07-18 15:17:00+03
441	PG0216	2017-07-28 14:10:00+03	2017-07-28 15:15:00+03	DME	KUF	Arrived	763	2017-07-28 17:42:00+03	2017-07-28 18:47:00+03
442	PG0216	2017-08-01 14:10:00+03	2017-08-01 15:15:00+03	DME	KUF	Arrived	763	2017-08-01 14:16:00+03	2017-08-01 15:20:00+03
443	PG0216	2017-07-21 14:10:00+03	2017-07-21 15:15:00+03	DME	KUF	Arrived	763	2017-07-21 14:12:00+03	2017-07-21 15:16:00+03
444	PG0216	2017-09-01 14:10:00+03	2017-09-01 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
445	PG0216	2017-08-18 14:10:00+03	2017-08-18 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
446	PG0216	2017-09-07 14:10:00+03	2017-09-07 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
447	PG0216	2017-07-29 14:10:00+03	2017-07-29 15:15:00+03	DME	KUF	Arrived	763	2017-07-29 14:16:00+03	2017-07-29 15:21:00+03
448	PG0216	2017-08-24 14:10:00+03	2017-08-24 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
449	PG0216	2017-09-03 14:10:00+03	2017-09-03 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
450	PG0216	2017-08-25 14:10:00+03	2017-08-25 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
451	PG0216	2017-07-22 14:10:00+03	2017-07-22 15:15:00+03	DME	KUF	Arrived	763	2017-07-22 14:13:00+03	2017-07-22 15:18:00+03
452	PG0216	2017-08-20 14:10:00+03	2017-08-20 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
453	PG0216	2017-08-10 14:10:00+03	2017-08-10 15:15:00+03	DME	KUF	Arrived	763	2017-08-10 14:10:00+03	2017-08-10 15:15:00+03
454	PG0216	2017-08-19 14:10:00+03	2017-08-19 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
455	PG0216	2017-08-12 14:10:00+03	2017-08-12 15:15:00+03	DME	KUF	Arrived	763	2017-08-12 14:13:00+03	2017-08-12 15:18:00+03
456	PG0216	2017-09-09 14:10:00+03	2017-09-09 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
457	PG0216	2017-09-10 14:10:00+03	2017-09-10 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
458	PG0216	2017-08-11 14:10:00+03	2017-08-11 15:15:00+03	DME	KUF	Arrived	763	2017-08-11 14:13:00+03	2017-08-11 15:18:00+03
459	PG0216	2017-08-17 14:10:00+03	2017-08-17 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
460	PG0216	2017-09-14 14:10:00+03	2017-09-14 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
461	PG0216	2017-07-25 14:10:00+03	2017-07-25 15:15:00+03	DME	KUF	Arrived	763	2017-07-25 14:13:00+03	2017-07-25 15:17:00+03
462	PG0216	2017-08-05 14:10:00+03	2017-08-05 15:15:00+03	DME	KUF	Arrived	763	2017-08-05 14:11:00+03	2017-08-05 15:16:00+03
463	PG0216	2017-08-27 14:10:00+03	2017-08-27 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
464	PG0216	2017-09-08 14:10:00+03	2017-09-08 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
465	PG0216	2017-07-19 14:10:00+03	2017-07-19 15:15:00+03	DME	KUF	Arrived	763	2017-07-19 14:12:00+03	2017-07-19 15:18:00+03
466	PG0216	2017-09-06 14:10:00+03	2017-09-06 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
467	PG0216	2017-09-13 14:10:00+03	2017-09-13 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
468	PG0216	2017-08-30 14:10:00+03	2017-08-30 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
469	PG0216	2017-08-14 14:10:00+03	2017-08-14 15:15:00+03	DME	KUF	Arrived	763	2017-08-14 14:14:00+03	2017-08-14 15:18:00+03
470	PG0216	2017-08-13 14:10:00+03	2017-08-13 15:15:00+03	DME	KUF	Arrived	763	2017-08-13 14:15:00+03	2017-08-13 15:19:00+03
471	PG0216	2017-07-23 14:10:00+03	2017-07-23 15:15:00+03	DME	KUF	Arrived	763	2017-07-23 14:13:00+03	2017-07-23 15:18:00+03
472	PG0216	2017-08-28 14:10:00+03	2017-08-28 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
473	PG0216	2017-08-04 14:10:00+03	2017-08-04 15:15:00+03	DME	KUF	Arrived	763	2017-08-04 14:11:00+03	2017-08-04 15:16:00+03
474	PG0216	2017-08-07 14:10:00+03	2017-08-07 15:15:00+03	DME	KUF	Arrived	763	2017-08-07 14:13:00+03	2017-08-07 15:18:00+03
475	PG0216	2017-07-20 14:10:00+03	2017-07-20 15:15:00+03	DME	KUF	Arrived	763	2017-07-20 14:12:00+03	2017-07-20 15:17:00+03
476	PG0216	2017-07-30 14:10:00+03	2017-07-30 15:15:00+03	DME	KUF	Arrived	763	2017-07-30 14:12:00+03	2017-07-30 15:16:00+03
477	PG0216	2017-08-23 14:10:00+03	2017-08-23 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
478	PG0216	2017-07-16 14:10:00+03	2017-07-16 15:15:00+03	DME	KUF	Arrived	763	2017-07-16 14:11:00+03	2017-07-16 15:15:00+03
479	PG0216	2017-08-08 14:10:00+03	2017-08-08 15:15:00+03	DME	KUF	Arrived	763	2017-08-08 14:15:00+03	2017-08-08 15:20:00+03
480	PG0216	2017-07-27 14:10:00+03	2017-07-27 15:15:00+03	DME	KUF	Arrived	763	2017-07-27 14:12:00+03	2017-07-27 15:16:00+03
481	PG0216	2017-09-05 14:10:00+03	2017-09-05 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
482	PG0216	2017-08-03 14:10:00+03	2017-08-03 15:15:00+03	DME	KUF	Arrived	763	2017-08-03 14:11:00+03	2017-08-03 15:16:00+03
483	PG0216	2017-08-16 14:10:00+03	2017-08-16 15:15:00+03	DME	KUF	On Time	763	\N	\N
484	PG0216	2017-09-12 14:10:00+03	2017-09-12 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
485	PG0216	2017-08-29 14:10:00+03	2017-08-29 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
486	PG0216	2017-08-31 14:10:00+03	2017-08-31 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
487	PG0216	2017-07-17 14:10:00+03	2017-07-17 15:15:00+03	DME	KUF	Arrived	763	2017-07-17 14:10:00+03	2017-07-17 15:17:00+03
488	PG0216	2017-08-26 14:10:00+03	2017-08-26 15:15:00+03	DME	KUF	Scheduled	763	\N	\N
489	PG0213	2017-08-18 19:20:00+03	2017-08-18 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
490	PG0213	2017-07-22 19:20:00+03	2017-07-22 20:35:00+03	DME	ROV	Arrived	321	2017-07-22 19:26:00+03	2017-07-22 20:39:00+03
491	PG0212	2017-08-01 18:20:00+03	2017-08-01 19:35:00+03	DME	ROV	Arrived	321	2017-08-01 18:27:00+03	2017-08-01 19:42:00+03
492	PG0213	2017-08-31 19:20:00+03	2017-08-31 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
493	PG0213	2017-08-01 19:20:00+03	2017-08-01 20:35:00+03	DME	ROV	Arrived	321	2017-08-01 19:26:00+03	2017-08-01 20:41:00+03
494	PG0213	2017-08-30 19:20:00+03	2017-08-30 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
495	PG0213	2017-09-10 19:20:00+03	2017-09-10 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
496	PG0213	2017-07-20 19:20:00+03	2017-07-20 20:35:00+03	DME	ROV	Arrived	321	2017-07-20 19:21:00+03	2017-07-20 20:36:00+03
497	PG0212	2017-09-10 18:20:00+03	2017-09-10 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
498	PG0213	2017-07-16 19:20:00+03	2017-07-16 20:35:00+03	DME	ROV	Arrived	321	2017-07-16 19:27:00+03	2017-07-16 20:42:00+03
499	PG0212	2017-09-04 18:20:00+03	2017-09-04 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
500	PG0213	2017-09-04 19:20:00+03	2017-09-04 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
501	PG0213	2017-08-03 19:20:00+03	2017-08-03 20:35:00+03	DME	ROV	Arrived	321	2017-08-03 19:23:00+03	2017-08-03 20:40:00+03
502	PG0213	2017-08-28 19:20:00+03	2017-08-28 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
503	PG0213	2017-07-31 19:20:00+03	2017-07-31 20:35:00+03	DME	ROV	Arrived	321	2017-07-31 19:21:00+03	2017-07-31 20:35:00+03
504	PG0213	2017-07-28 19:20:00+03	2017-07-28 20:35:00+03	DME	ROV	Arrived	321	2017-07-28 19:24:00+03	2017-07-28 20:40:00+03
505	PG0212	2017-07-28 18:20:00+03	2017-07-28 19:35:00+03	DME	ROV	Arrived	321	2017-07-28 18:26:00+03	2017-07-28 19:41:00+03
506	PG0212	2017-08-28 18:20:00+03	2017-08-28 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
507	PG0212	2017-08-03 18:20:00+03	2017-08-03 19:35:00+03	DME	ROV	Arrived	321	2017-08-03 18:25:00+03	2017-08-03 19:40:00+03
508	PG0212	2017-07-18 18:20:00+03	2017-07-18 19:35:00+03	DME	ROV	Arrived	321	2017-07-18 18:21:00+03	2017-07-18 19:36:00+03
509	PG0213	2017-07-18 19:20:00+03	2017-07-18 20:35:00+03	DME	ROV	Arrived	321	2017-07-18 19:22:00+03	2017-07-18 20:37:00+03
510	PG0213	2017-09-02 19:20:00+03	2017-09-02 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
511	PG0212	2017-09-02 18:20:00+03	2017-09-02 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
512	PG0212	2017-07-31 18:20:00+03	2017-07-31 19:35:00+03	DME	ROV	Arrived	321	2017-07-31 18:21:00+03	2017-07-31 19:36:00+03
513	PG0212	2017-08-06 18:20:00+03	2017-08-06 19:35:00+03	DME	ROV	Arrived	321	2017-08-06 18:21:00+03	2017-08-06 19:36:00+03
514	PG0213	2017-07-24 19:20:00+03	2017-07-24 20:35:00+03	DME	ROV	Arrived	321	2017-07-24 19:22:00+03	2017-07-24 20:36:00+03
515	PG0213	2017-08-02 19:20:00+03	2017-08-02 20:35:00+03	DME	ROV	Arrived	321	2017-08-02 19:21:00+03	2017-08-02 20:37:00+03
516	PG0212	2017-08-02 18:20:00+03	2017-08-02 19:35:00+03	DME	ROV	Arrived	321	2017-08-02 18:23:00+03	2017-08-02 19:38:00+03
517	PG0213	2017-07-26 19:20:00+03	2017-07-26 20:35:00+03	DME	ROV	Arrived	321	2017-07-26 19:22:00+03	2017-07-26 20:37:00+03
518	PG0212	2017-07-24 18:20:00+03	2017-07-24 19:35:00+03	DME	ROV	Arrived	321	2017-07-24 18:23:00+03	2017-07-24 19:40:00+03
519	PG0212	2017-07-26 18:20:00+03	2017-07-26 19:35:00+03	DME	ROV	Arrived	321	2017-07-26 18:23:00+03	2017-07-26 19:37:00+03
520	PG0213	2017-08-06 19:20:00+03	2017-08-06 20:35:00+03	DME	ROV	Arrived	321	2017-08-06 19:22:00+03	2017-08-06 20:37:00+03
521	PG0213	2017-09-14 19:20:00+03	2017-09-14 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
522	PG0212	2017-09-11 18:20:00+03	2017-09-11 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
523	PG0213	2017-08-09 19:20:00+03	2017-08-09 20:35:00+03	DME	ROV	Arrived	321	2017-08-09 19:24:00+03	2017-08-09 20:39:00+03
524	PG0213	2017-09-11 19:20:00+03	2017-09-11 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
525	PG0212	2017-08-09 18:20:00+03	2017-08-09 19:35:00+03	DME	ROV	Arrived	321	2017-08-09 18:24:00+03	2017-08-09 19:40:00+03
526	PG0212	2017-07-30 18:20:00+03	2017-07-30 19:35:00+03	DME	ROV	Arrived	321	2017-07-30 18:22:00+03	2017-07-30 19:37:00+03
527	PG0212	2017-09-12 18:20:00+03	2017-09-12 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
528	PG0213	2017-09-12 19:20:00+03	2017-09-12 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
529	PG0212	2017-09-14 18:20:00+03	2017-09-14 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
530	PG0213	2017-08-21 19:20:00+03	2017-08-21 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
531	PG0212	2017-08-12 18:20:00+03	2017-08-12 19:35:00+03	DME	ROV	Arrived	321	2017-08-12 18:21:00+03	2017-08-12 19:36:00+03
532	PG0213	2017-07-30 19:20:00+03	2017-07-30 20:35:00+03	DME	ROV	Arrived	321	2017-07-30 19:24:00+03	2017-07-30 20:39:00+03
533	PG0212	2017-07-16 18:20:00+03	2017-07-16 19:35:00+03	DME	ROV	Arrived	321	2017-07-16 18:27:00+03	2017-07-16 19:41:00+03
534	PG0212	2017-08-08 18:20:00+03	2017-08-08 19:35:00+03	DME	ROV	Arrived	321	2017-08-08 18:26:00+03	2017-08-08 19:41:00+03
535	PG0213	2017-08-08 19:20:00+03	2017-08-08 20:35:00+03	DME	ROV	Arrived	321	2017-08-08 19:24:00+03	2017-08-08 20:38:00+03
536	PG0212	2017-07-19 18:20:00+03	2017-07-19 19:35:00+03	DME	ROV	Arrived	321	2017-07-19 18:22:00+03	2017-07-19 19:38:00+03
537	PG0213	2017-09-05 19:20:00+03	2017-09-05 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
538	PG0212	2017-09-05 18:20:00+03	2017-09-05 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
539	PG0213	2017-07-19 19:20:00+03	2017-07-19 20:35:00+03	DME	ROV	Arrived	321	2017-07-19 19:24:00+03	2017-07-19 20:38:00+03
540	PG0213	2017-08-26 19:20:00+03	2017-08-26 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
541	PG0212	2017-08-21 18:20:00+03	2017-08-21 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
542	PG0212	2017-08-26 18:20:00+03	2017-08-26 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
543	PG0213	2017-08-23 19:20:00+03	2017-08-23 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
544	PG0212	2017-07-20 18:20:00+03	2017-07-20 19:35:00+03	DME	ROV	Arrived	321	2017-07-20 18:23:00+03	2017-07-20 19:38:00+03
545	PG0212	2017-08-13 18:20:00+03	2017-08-13 19:35:00+03	DME	ROV	Arrived	321	2017-08-13 18:23:00+03	2017-08-13 19:37:00+03
546	PG0213	2017-08-13 19:20:00+03	2017-08-13 20:35:00+03	DME	ROV	Arrived	321	2017-08-13 19:23:00+03	2017-08-13 20:37:00+03
547	PG0212	2017-08-24 18:20:00+03	2017-08-24 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
548	PG0213	2017-08-29 19:20:00+03	2017-08-29 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
549	PG0212	2017-08-23 18:20:00+03	2017-08-23 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
550	PG0213	2017-08-07 19:20:00+03	2017-08-07 20:35:00+03	DME	ROV	Arrived	321	2017-08-07 19:24:00+03	2017-08-07 20:39:00+03
551	PG0212	2017-08-07 18:20:00+03	2017-08-07 19:35:00+03	DME	ROV	Arrived	321	2017-08-07 18:22:00+03	2017-08-07 19:37:00+03
552	PG0212	2017-08-27 18:20:00+03	2017-08-27 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
553	PG0212	2017-09-06 18:20:00+03	2017-09-06 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
554	PG0213	2017-09-06 19:20:00+03	2017-09-06 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
555	PG0212	2017-08-14 18:20:00+03	2017-08-14 19:35:00+03	DME	ROV	Arrived	321	2017-08-14 18:23:00+03	2017-08-14 19:37:00+03
556	PG0213	2017-08-14 19:20:00+03	2017-08-14 20:35:00+03	DME	ROV	Arrived	321	2017-08-14 22:00:00+03	2017-08-14 23:15:00+03
557	PG0213	2017-08-27 19:20:00+03	2017-08-27 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
558	PG0213	2017-07-23 19:20:00+03	2017-07-23 20:35:00+03	DME	ROV	Arrived	321	2017-07-23 19:23:00+03	2017-07-23 20:38:00+03
559	PG0212	2017-09-07 18:20:00+03	2017-09-07 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
560	PG0212	2017-07-23 18:20:00+03	2017-07-23 19:35:00+03	DME	ROV	Arrived	321	2017-07-23 18:22:00+03	2017-07-23 19:37:00+03
561	PG0212	2017-08-20 18:20:00+03	2017-08-20 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
562	PG0213	2017-08-05 19:20:00+03	2017-08-05 20:35:00+03	DME	ROV	Arrived	321	2017-08-05 19:23:00+03	2017-08-05 20:38:00+03
563	PG0213	2017-08-12 19:20:00+03	2017-08-12 20:35:00+03	DME	ROV	Arrived	321	2017-08-12 19:24:00+03	2017-08-12 20:40:00+03
564	PG0213	2017-08-20 19:20:00+03	2017-08-20 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
565	PG0212	2017-08-30 18:20:00+03	2017-08-30 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
566	PG0212	2017-08-10 18:20:00+03	2017-08-10 19:35:00+03	DME	ROV	Arrived	321	2017-08-10 18:22:00+03	2017-08-10 19:37:00+03
567	PG0212	2017-08-05 18:20:00+03	2017-08-05 19:35:00+03	DME	ROV	Arrived	321	2017-08-05 20:59:00+03	2017-08-05 22:14:00+03
568	PG0213	2017-08-11 19:20:00+03	2017-08-11 20:35:00+03	DME	ROV	Arrived	321	2017-08-11 19:22:00+03	2017-08-11 20:36:00+03
569	PG0213	2017-08-17 19:20:00+03	2017-08-17 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
570	PG0212	2017-08-11 18:20:00+03	2017-08-11 19:35:00+03	DME	ROV	Arrived	321	2017-08-11 18:22:00+03	2017-08-11 19:36:00+03
571	PG0213	2017-08-10 19:20:00+03	2017-08-10 20:35:00+03	DME	ROV	Arrived	321	2017-08-10 22:58:00+03	2017-08-11 00:12:00+03
572	PG0212	2017-08-17 18:20:00+03	2017-08-17 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
573	PG0212	2017-09-01 18:20:00+03	2017-09-01 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
574	PG0213	2017-09-07 19:20:00+03	2017-09-07 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
575	PG0212	2017-08-29 18:20:00+03	2017-08-29 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
576	PG0212	2017-08-31 18:20:00+03	2017-08-31 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
577	PG0213	2017-09-09 19:20:00+03	2017-09-09 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
578	PG0212	2017-08-18 18:20:00+03	2017-08-18 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
579	PG0212	2017-09-09 18:20:00+03	2017-09-09 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
580	PG0212	2017-08-25 18:20:00+03	2017-08-25 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
581	PG0213	2017-07-29 19:20:00+03	2017-07-29 20:35:00+03	DME	ROV	Arrived	321	2017-07-29 19:23:00+03	2017-07-29 20:39:00+03
582	PG0212	2017-07-29 18:20:00+03	2017-07-29 19:35:00+03	DME	ROV	Arrived	321	2017-07-29 18:24:00+03	2017-07-29 19:38:00+03
583	PG0212	2017-09-03 18:20:00+03	2017-09-03 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
584	PG0213	2017-08-19 19:20:00+03	2017-08-19 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
585	PG0212	2017-07-17 18:20:00+03	2017-07-17 19:35:00+03	DME	ROV	Arrived	321	2017-07-17 18:27:00+03	2017-07-17 19:42:00+03
586	PG0213	2017-07-17 19:20:00+03	2017-07-17 20:35:00+03	DME	ROV	Arrived	321	2017-07-17 19:23:00+03	2017-07-17 20:36:00+03
587	PG0213	2017-07-21 19:20:00+03	2017-07-21 20:35:00+03	DME	ROV	Arrived	321	2017-07-21 19:26:00+03	2017-07-21 20:41:00+03
588	PG0212	2017-07-21 18:20:00+03	2017-07-21 19:35:00+03	DME	ROV	Arrived	321	2017-07-21 18:24:00+03	2017-07-21 19:40:00+03
589	PG0212	2017-08-19 18:20:00+03	2017-08-19 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
590	PG0212	2017-07-27 18:20:00+03	2017-07-27 19:35:00+03	DME	ROV	Arrived	321	2017-07-27 18:26:00+03	2017-07-27 19:42:00+03
591	PG0213	2017-07-25 19:20:00+03	2017-07-25 20:35:00+03	DME	ROV	Arrived	321	2017-07-25 19:22:00+03	2017-07-25 20:37:00+03
592	PG0212	2017-08-04 18:20:00+03	2017-08-04 19:35:00+03	DME	ROV	Arrived	321	2017-08-04 18:25:00+03	2017-08-04 19:40:00+03
593	PG0213	2017-07-27 19:20:00+03	2017-07-27 20:35:00+03	DME	ROV	Arrived	321	2017-07-27 19:21:00+03	2017-07-27 20:36:00+03
594	PG0213	2017-08-04 19:20:00+03	2017-08-04 20:35:00+03	DME	ROV	Arrived	321	2017-08-04 19:22:00+03	2017-08-04 20:37:00+03
595	PG0212	2017-07-22 18:20:00+03	2017-07-22 19:35:00+03	DME	ROV	Arrived	321	2017-07-22 18:23:00+03	2017-07-22 19:37:00+03
596	PG0212	2017-08-15 18:20:00+03	2017-08-15 19:35:00+03	DME	ROV	Delayed	321	\N	\N
597	PG0213	2017-09-01 19:20:00+03	2017-09-01 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
598	PG0213	2017-08-25 19:20:00+03	2017-08-25 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
599	PG0212	2017-07-25 18:20:00+03	2017-07-25 19:35:00+03	DME	ROV	Arrived	321	2017-07-25 18:22:00+03	2017-07-25 19:37:00+03
600	PG0212	2017-09-08 18:20:00+03	2017-09-08 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
601	PG0213	2017-09-08 19:20:00+03	2017-09-08 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
602	PG0213	2017-09-13 19:20:00+03	2017-09-13 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
603	PG0212	2017-09-13 18:20:00+03	2017-09-13 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
604	PG0213	2017-08-15 19:20:00+03	2017-08-15 20:35:00+03	DME	ROV	On Time	321	\N	\N
605	PG0212	2017-08-22 18:20:00+03	2017-08-22 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
606	PG0213	2017-08-22 19:20:00+03	2017-08-22 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
607	PG0213	2017-08-16 19:20:00+03	2017-08-16 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
608	PG0212	2017-08-16 18:20:00+03	2017-08-16 19:35:00+03	DME	ROV	Scheduled	321	\N	\N
609	PG0213	2017-08-24 19:20:00+03	2017-08-24 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
610	PG0213	2017-09-03 19:20:00+03	2017-09-03 20:35:00+03	DME	ROV	Scheduled	321	\N	\N
611	PG0416	2017-09-12 19:20:00+03	2017-09-12 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
612	PG0416	2017-09-04 19:20:00+03	2017-09-04 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
613	PG0416	2017-08-19 19:20:00+03	2017-08-19 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
614	PG0416	2017-08-18 19:20:00+03	2017-08-18 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
615	PG0416	2017-07-28 19:20:00+03	2017-07-28 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-28 19:25:00+03	2017-07-28 20:01:00+03
616	PG0416	2017-07-17 19:20:00+03	2017-07-17 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-17 19:24:00+03	2017-07-17 19:59:00+03
617	PG0416	2017-08-31 19:20:00+03	2017-08-31 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
618	PG0416	2017-08-30 19:20:00+03	2017-08-30 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
619	PG0416	2017-08-10 19:20:00+03	2017-08-10 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-10 19:23:00+03	2017-08-10 19:58:00+03
620	PG0416	2017-07-25 19:20:00+03	2017-07-25 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-25 19:22:00+03	2017-07-25 19:57:00+03
621	PG0416	2017-08-28 19:20:00+03	2017-08-28 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
622	PG0416	2017-08-12 19:20:00+03	2017-08-12 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-12 19:23:00+03	2017-08-12 19:58:00+03
623	PG0416	2017-07-30 19:20:00+03	2017-07-30 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-30 19:24:00+03	2017-07-30 19:59:00+03
624	PG0416	2017-09-13 19:20:00+03	2017-09-13 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
625	PG0416	2017-08-01 19:20:00+03	2017-08-01 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-01 19:22:00+03	2017-08-01 19:57:00+03
626	PG0416	2017-08-29 19:20:00+03	2017-08-29 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
627	PG0416	2017-08-21 19:20:00+03	2017-08-21 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
628	PG0416	2017-08-08 19:20:00+03	2017-08-08 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-08 19:23:00+03	2017-08-08 19:58:00+03
629	PG0416	2017-08-17 19:20:00+03	2017-08-17 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
630	PG0416	2017-07-23 19:20:00+03	2017-07-23 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-23 19:24:00+03	2017-07-23 19:59:00+03
631	PG0416	2017-08-20 19:20:00+03	2017-08-20 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
632	PG0416	2017-09-10 19:20:00+03	2017-09-10 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
633	PG0416	2017-09-06 19:20:00+03	2017-09-06 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
634	PG0416	2017-08-06 19:20:00+03	2017-08-06 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-06 19:23:00+03	2017-08-06 19:58:00+03
635	PG0416	2017-08-07 19:20:00+03	2017-08-07 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-07 19:25:00+03	2017-08-07 20:00:00+03
636	PG0416	2017-09-01 19:20:00+03	2017-09-01 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
637	PG0416	2017-09-11 19:20:00+03	2017-09-11 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
638	PG0416	2017-09-09 19:20:00+03	2017-09-09 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
639	PG0416	2017-09-05 19:20:00+03	2017-09-05 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
640	PG0416	2017-08-03 19:20:00+03	2017-08-03 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-03 19:26:00+03	2017-08-03 20:01:00+03
641	PG0416	2017-09-08 19:20:00+03	2017-09-08 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
642	PG0416	2017-07-24 19:20:00+03	2017-07-24 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-24 19:22:00+03	2017-07-24 19:57:00+03
643	PG0416	2017-09-02 19:20:00+03	2017-09-02 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
644	PG0416	2017-07-31 19:20:00+03	2017-07-31 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-31 19:24:00+03	2017-07-31 19:59:00+03
645	PG0416	2017-08-14 19:20:00+03	2017-08-14 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-14 19:26:00+03	2017-08-14 20:01:00+03
646	PG0416	2017-08-13 19:20:00+03	2017-08-13 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-13 19:23:00+03	2017-08-13 19:58:00+03
647	PG0416	2017-08-05 19:20:00+03	2017-08-05 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-05 19:23:00+03	2017-08-05 19:57:00+03
648	PG0416	2017-07-19 19:20:00+03	2017-07-19 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-19 19:22:00+03	2017-07-19 19:56:00+03
649	PG0416	2017-08-24 19:20:00+03	2017-08-24 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
650	PG0416	2017-07-26 19:20:00+03	2017-07-26 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-26 19:22:00+03	2017-07-26 19:57:00+03
651	PG0416	2017-07-29 19:20:00+03	2017-07-29 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-29 19:26:00+03	2017-07-29 20:01:00+03
652	PG0416	2017-09-14 19:20:00+03	2017-09-14 19:55:00+03	DME	VOZ	Cancelled	CR2	\N	\N
653	PG0416	2017-08-16 19:20:00+03	2017-08-16 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
654	PG0416	2017-08-25 19:20:00+03	2017-08-25 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
655	PG0416	2017-09-07 19:20:00+03	2017-09-07 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
656	PG0416	2017-08-22 19:20:00+03	2017-08-22 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
657	PG0416	2017-09-03 19:20:00+03	2017-09-03 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
658	PG0416	2017-07-22 19:20:00+03	2017-07-22 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-22 19:21:00+03	2017-07-22 19:56:00+03
659	PG0416	2017-08-15 19:20:00+03	2017-08-15 19:55:00+03	DME	VOZ	On Time	CR2	\N	\N
660	PG0416	2017-08-26 19:20:00+03	2017-08-26 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
661	PG0416	2017-08-04 19:20:00+03	2017-08-04 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-04 19:25:00+03	2017-08-04 20:00:00+03
662	PG0416	2017-08-11 19:20:00+03	2017-08-11 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-11 19:24:00+03	2017-08-11 19:58:00+03
663	PG0416	2017-07-21 19:20:00+03	2017-07-21 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-21 19:21:00+03	2017-07-21 19:56:00+03
664	PG0416	2017-08-27 19:20:00+03	2017-08-27 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
665	PG0416	2017-07-20 19:20:00+03	2017-07-20 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-20 19:27:00+03	2017-07-20 20:02:00+03
666	PG0416	2017-07-18 19:20:00+03	2017-07-18 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-18 19:22:00+03	2017-07-18 19:57:00+03
667	PG0416	2017-08-09 19:20:00+03	2017-08-09 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-09 19:23:00+03	2017-08-09 19:57:00+03
668	PG0416	2017-08-02 19:20:00+03	2017-08-02 19:55:00+03	DME	VOZ	Arrived	CR2	2017-08-02 19:22:00+03	2017-08-02 19:57:00+03
669	PG0416	2017-07-16 19:20:00+03	2017-07-16 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-16 19:23:00+03	2017-07-16 19:58:00+03
670	PG0416	2017-07-27 19:20:00+03	2017-07-27 19:55:00+03	DME	VOZ	Arrived	CR2	2017-07-27 19:23:00+03	2017-07-27 19:58:00+03
671	PG0416	2017-08-23 19:20:00+03	2017-08-23 19:55:00+03	DME	VOZ	Scheduled	CR2	\N	\N
672	PG0055	2017-08-10 14:10:00+03	2017-08-10 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-10 14:11:00+03	2017-08-10 15:26:00+03
673	PG0054	2017-08-06 17:05:00+03	2017-08-06 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-06 17:07:00+03	2017-08-06 18:22:00+03
674	PG0055	2017-07-28 14:10:00+03	2017-07-28 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-28 14:13:00+03	2017-07-28 15:29:00+03
675	PG0054	2017-08-08 17:05:00+03	2017-08-08 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-08 17:08:00+03	2017-08-08 18:23:00+03
676	PG0055	2017-08-23 14:10:00+03	2017-08-23 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
677	PG0055	2017-09-14 14:10:00+03	2017-09-14 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
678	PG0054	2017-08-05 17:05:00+03	2017-08-05 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-05 17:08:00+03	2017-08-05 18:23:00+03
679	PG0055	2017-08-20 14:10:00+03	2017-08-20 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
680	PG0055	2017-07-19 14:10:00+03	2017-07-19 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-19 14:12:00+03	2017-07-19 15:28:00+03
681	PG0054	2017-07-21 17:05:00+03	2017-07-21 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-21 17:09:00+03	2017-07-21 18:26:00+03
682	PG0055	2017-07-21 14:10:00+03	2017-07-21 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-21 14:13:00+03	2017-07-21 15:28:00+03
683	PG0054	2017-08-15 17:05:00+03	2017-08-15 18:20:00+03	DME	TBW	Departed	CN1	2017-08-15 17:09:00+03	\N
684	PG0055	2017-09-01 14:10:00+03	2017-09-01 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
685	PG0055	2017-07-26 14:10:00+03	2017-07-26 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-26 14:13:00+03	2017-07-26 15:28:00+03
686	PG0054	2017-08-19 17:05:00+03	2017-08-19 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
687	PG0054	2017-09-10 17:05:00+03	2017-09-10 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
688	PG0054	2017-07-26 17:05:00+03	2017-07-26 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-26 17:08:00+03	2017-07-26 18:22:00+03
689	PG0054	2017-08-18 17:05:00+03	2017-08-18 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
690	PG0055	2017-09-10 14:10:00+03	2017-09-10 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
691	PG0055	2017-08-18 14:10:00+03	2017-08-18 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
692	PG0055	2017-08-24 14:10:00+03	2017-08-24 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
693	PG0055	2017-09-09 14:10:00+03	2017-09-09 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
694	PG0054	2017-09-06 17:05:00+03	2017-09-06 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
695	PG0055	2017-07-30 14:10:00+03	2017-07-30 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-30 14:12:00+03	2017-07-30 15:27:00+03
696	PG0054	2017-09-09 17:05:00+03	2017-09-09 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
697	PG0055	2017-07-24 14:10:00+03	2017-07-24 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-24 14:18:00+03	2017-07-24 15:35:00+03
698	PG0055	2017-09-02 14:10:00+03	2017-09-02 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
699	PG0055	2017-08-28 14:10:00+03	2017-08-28 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
700	PG0054	2017-07-28 17:05:00+03	2017-07-28 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-28 17:08:00+03	2017-07-28 18:24:00+03
701	PG0054	2017-08-26 17:05:00+03	2017-08-26 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
702	PG0055	2017-08-12 14:10:00+03	2017-08-12 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-12 14:12:00+03	2017-08-12 15:27:00+03
703	PG0054	2017-09-12 17:05:00+03	2017-09-12 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
704	PG0054	2017-08-14 17:05:00+03	2017-08-14 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-14 17:05:00+03	2017-08-14 18:20:00+03
705	PG0054	2017-08-29 17:05:00+03	2017-08-29 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
706	PG0055	2017-08-16 14:10:00+03	2017-08-16 15:25:00+03	DME	TBW	On Time	CN1	\N	\N
707	PG0054	2017-08-01 17:05:00+03	2017-08-01 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-01 17:08:00+03	2017-08-01 18:22:00+03
708	PG0054	2017-08-21 17:05:00+03	2017-08-21 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
709	PG0055	2017-08-14 14:10:00+03	2017-08-14 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-14 14:13:00+03	2017-08-14 15:28:00+03
710	PG0055	2017-08-29 14:10:00+03	2017-08-29 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
711	PG0055	2017-08-07 14:10:00+03	2017-08-07 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-07 14:11:00+03	2017-08-07 15:26:00+03
712	PG0055	2017-08-09 14:10:00+03	2017-08-09 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-09 14:12:00+03	2017-08-09 15:27:00+03
713	PG0055	2017-08-15 14:10:00+03	2017-08-15 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-15 14:12:00+03	2017-08-15 15:27:00+03
714	PG0054	2017-08-12 17:05:00+03	2017-08-12 18:20:00+03	DME	TBW	Cancelled	CN1	2017-08-12 17:07:00+03	2017-08-12 18:21:00+03
715	PG0055	2017-08-22 14:10:00+03	2017-08-22 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
716	PG0054	2017-09-08 17:05:00+03	2017-09-08 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
717	PG0054	2017-08-28 17:05:00+03	2017-08-28 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
718	PG0055	2017-08-01 14:10:00+03	2017-08-01 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-01 16:56:00+03	2017-08-01 18:10:00+03
719	PG0055	2017-08-21 14:10:00+03	2017-08-21 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
720	PG0054	2017-09-14 17:05:00+03	2017-09-14 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
721	PG0054	2017-08-09 17:05:00+03	2017-08-09 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-09 17:09:00+03	2017-08-09 18:23:00+03
722	PG0054	2017-07-29 17:05:00+03	2017-07-29 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-29 17:08:00+03	2017-07-29 18:24:00+03
723	PG0054	2017-08-17 17:05:00+03	2017-08-17 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
724	PG0055	2017-07-29 14:10:00+03	2017-07-29 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-29 14:11:00+03	2017-07-29 15:25:00+03
725	PG0054	2017-08-23 17:05:00+03	2017-08-23 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
726	PG0055	2017-08-06 14:10:00+03	2017-08-06 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-06 14:13:00+03	2017-08-06 15:28:00+03
727	PG0055	2017-09-08 14:10:00+03	2017-09-08 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
728	PG0055	2017-07-16 14:10:00+03	2017-07-16 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-16 14:13:00+03	2017-07-16 15:28:00+03
729	PG0055	2017-09-07 14:10:00+03	2017-09-07 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
730	PG0055	2017-08-31 14:10:00+03	2017-08-31 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
731	PG0054	2017-08-31 17:05:00+03	2017-08-31 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
732	PG0054	2017-09-07 17:05:00+03	2017-09-07 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
733	PG0055	2017-07-22 14:10:00+03	2017-07-22 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-22 14:15:00+03	2017-07-22 15:30:00+03
734	PG0054	2017-07-22 17:05:00+03	2017-07-22 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-22 17:08:00+03	2017-07-22 18:22:00+03
735	PG0055	2017-08-02 14:10:00+03	2017-08-02 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-02 14:16:00+03	2017-08-02 15:32:00+03
736	PG0055	2017-08-25 14:10:00+03	2017-08-25 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
737	PG0055	2017-07-31 14:10:00+03	2017-07-31 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-31 14:12:00+03	2017-07-31 15:27:00+03
738	PG0054	2017-09-13 17:05:00+03	2017-09-13 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
739	PG0055	2017-09-13 14:10:00+03	2017-09-13 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
740	PG0055	2017-09-12 14:10:00+03	2017-09-12 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
741	PG0054	2017-08-02 17:05:00+03	2017-08-02 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-02 17:07:00+03	2017-08-02 18:23:00+03
742	PG0055	2017-08-30 14:10:00+03	2017-08-30 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
743	PG0054	2017-09-02 17:05:00+03	2017-09-02 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
744	PG0055	2017-09-11 14:10:00+03	2017-09-11 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
745	PG0054	2017-07-17 17:05:00+03	2017-07-17 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-17 17:08:00+03	2017-07-17 18:24:00+03
746	PG0054	2017-09-11 17:05:00+03	2017-09-11 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
747	PG0054	2017-08-30 17:05:00+03	2017-08-30 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
748	PG0054	2017-08-03 17:05:00+03	2017-08-03 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-03 17:07:00+03	2017-08-03 18:23:00+03
749	PG0054	2017-07-30 17:05:00+03	2017-07-30 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-30 17:07:00+03	2017-07-30 18:22:00+03
750	PG0054	2017-07-18 17:05:00+03	2017-07-18 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-18 17:10:00+03	2017-07-18 18:25:00+03
751	PG0054	2017-07-31 17:05:00+03	2017-07-31 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-31 17:08:00+03	2017-07-31 18:23:00+03
752	PG0054	2017-08-25 17:05:00+03	2017-08-25 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
753	PG0054	2017-07-16 17:05:00+03	2017-07-16 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-16 17:06:00+03	2017-07-16 18:21:00+03
754	PG0055	2017-07-23 14:10:00+03	2017-07-23 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-23 14:14:00+03	2017-07-23 15:30:00+03
755	PG0054	2017-08-24 17:05:00+03	2017-08-24 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
756	PG0055	2017-09-05 14:10:00+03	2017-09-05 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
757	PG0055	2017-07-17 14:10:00+03	2017-07-17 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-17 14:16:00+03	2017-07-17 15:32:00+03
758	PG0054	2017-09-05 17:05:00+03	2017-09-05 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
759	PG0054	2017-08-07 17:05:00+03	2017-08-07 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-07 19:49:00+03	2017-08-07 21:03:00+03
760	PG0055	2017-08-17 14:10:00+03	2017-08-17 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
761	PG0054	2017-09-01 17:05:00+03	2017-09-01 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
762	PG0054	2017-08-20 17:05:00+03	2017-08-20 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
763	PG0054	2017-08-27 17:05:00+03	2017-08-27 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
764	PG0054	2017-07-23 17:05:00+03	2017-07-23 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-23 17:07:00+03	2017-07-23 18:21:00+03
765	PG0054	2017-08-22 17:05:00+03	2017-08-22 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
766	PG0054	2017-08-16 17:05:00+03	2017-08-16 18:20:00+03	DME	TBW	On Time	CN1	\N	\N
767	PG0055	2017-07-18 14:10:00+03	2017-07-18 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-18 14:16:00+03	2017-07-18 15:30:00+03
768	PG0055	2017-08-03 14:10:00+03	2017-08-03 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-03 14:12:00+03	2017-08-03 15:28:00+03
769	PG0054	2017-08-04 17:05:00+03	2017-08-04 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-04 17:05:00+03	2017-08-04 18:21:00+03
770	PG0055	2017-08-08 14:10:00+03	2017-08-08 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-08 14:13:00+03	2017-08-08 15:28:00+03
771	PG0055	2017-08-04 14:10:00+03	2017-08-04 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-04 14:12:00+03	2017-08-04 15:26:00+03
772	PG0054	2017-07-27 17:05:00+03	2017-07-27 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-27 17:08:00+03	2017-07-27 18:24:00+03
773	PG0055	2017-09-04 14:10:00+03	2017-09-04 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
774	PG0055	2017-07-25 14:10:00+03	2017-07-25 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-25 14:14:00+03	2017-07-25 15:29:00+03
775	PG0055	2017-08-26 14:10:00+03	2017-08-26 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
776	PG0054	2017-07-25 17:05:00+03	2017-07-25 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-25 17:10:00+03	2017-07-25 18:26:00+03
777	PG0055	2017-09-06 14:10:00+03	2017-09-06 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
778	PG0054	2017-08-13 17:05:00+03	2017-08-13 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-13 17:09:00+03	2017-08-13 18:24:00+03
779	PG0055	2017-09-03 14:10:00+03	2017-09-03 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
780	PG0055	2017-07-20 14:10:00+03	2017-07-20 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-20 18:12:00+03	2017-07-20 19:27:00+03
781	PG0055	2017-08-11 14:10:00+03	2017-08-11 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-11 14:14:00+03	2017-08-11 15:29:00+03
782	PG0054	2017-09-03 17:05:00+03	2017-09-03 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
783	PG0054	2017-08-11 17:05:00+03	2017-08-11 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-11 17:08:00+03	2017-08-11 18:21:00+03
784	PG0055	2017-08-27 14:10:00+03	2017-08-27 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
785	PG0054	2017-07-20 17:05:00+03	2017-07-20 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-20 17:06:00+03	2017-07-20 18:22:00+03
786	PG0055	2017-07-27 14:10:00+03	2017-07-27 15:25:00+03	DME	TBW	Arrived	CN1	2017-07-27 14:15:00+03	2017-07-27 15:29:00+03
787	PG0055	2017-08-13 14:10:00+03	2017-08-13 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-13 14:13:00+03	2017-08-13 15:28:00+03
788	PG0054	2017-07-24 17:05:00+03	2017-07-24 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-24 17:09:00+03	2017-07-24 18:24:00+03
789	PG0055	2017-08-19 14:10:00+03	2017-08-19 15:25:00+03	DME	TBW	Scheduled	CN1	\N	\N
790	PG0054	2017-07-19 17:05:00+03	2017-07-19 18:20:00+03	DME	TBW	Arrived	CN1	2017-07-19 17:08:00+03	2017-07-19 18:25:00+03
791	PG0054	2017-09-04 17:05:00+03	2017-09-04 18:20:00+03	DME	TBW	Scheduled	CN1	\N	\N
792	PG0054	2017-08-10 17:05:00+03	2017-08-10 18:20:00+03	DME	TBW	Arrived	CN1	2017-08-10 17:07:00+03	2017-08-10 18:22:00+03
793	PG0055	2017-08-05 14:10:00+03	2017-08-05 15:25:00+03	DME	TBW	Arrived	CN1	2017-08-05 14:14:00+03	2017-08-05 15:28:00+03
794	PG0045	2017-08-20 11:45:00+03	2017-08-20 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
795	PG0045	2017-08-06 11:45:00+03	2017-08-06 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-06 11:48:00+03	2017-08-06 13:53:00+03
796	PG0045	2017-08-15 11:45:00+03	2017-08-15 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-15 11:47:00+03	2017-08-15 13:52:00+03
797	PG0045	2017-07-30 11:45:00+03	2017-07-30 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-30 11:48:00+03	2017-07-30 13:54:00+03
798	PG0045	2017-07-22 11:45:00+03	2017-07-22 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-22 11:49:00+03	2017-07-22 13:53:00+03
799	PG0045	2017-09-12 11:45:00+03	2017-09-12 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
800	PG0045	2017-07-19 11:45:00+03	2017-07-19 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-19 11:47:00+03	2017-07-19 13:54:00+03
801	PG0045	2017-08-03 11:45:00+03	2017-08-03 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-03 11:48:00+03	2017-08-03 13:53:00+03
802	PG0045	2017-08-18 11:45:00+03	2017-08-18 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
803	PG0045	2017-09-08 11:45:00+03	2017-09-08 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
804	PG0045	2017-08-29 11:45:00+03	2017-08-29 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
805	PG0045	2017-08-31 11:45:00+03	2017-08-31 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
806	PG0045	2017-07-17 11:45:00+03	2017-07-17 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-17 11:47:00+03	2017-07-17 13:52:00+03
807	PG0045	2017-09-14 11:45:00+03	2017-09-14 13:50:00+03	DME	GRV	Cancelled	CR2	\N	\N
808	PG0045	2017-07-27 11:45:00+03	2017-07-27 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-27 11:47:00+03	2017-07-27 13:54:00+03
809	PG0045	2017-08-02 11:45:00+03	2017-08-02 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-02 11:46:00+03	2017-08-02 13:50:00+03
810	PG0045	2017-08-26 11:45:00+03	2017-08-26 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
811	PG0045	2017-08-04 11:45:00+03	2017-08-04 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-04 11:48:00+03	2017-08-04 13:53:00+03
812	PG0045	2017-08-25 11:45:00+03	2017-08-25 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
813	PG0045	2017-09-03 11:45:00+03	2017-09-03 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
814	PG0045	2017-08-24 11:45:00+03	2017-08-24 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
815	PG0045	2017-08-21 11:45:00+03	2017-08-21 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
816	PG0045	2017-07-26 11:45:00+03	2017-07-26 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-26 11:49:00+03	2017-07-26 13:55:00+03
817	PG0045	2017-08-16 11:45:00+03	2017-08-16 13:50:00+03	DME	GRV	On Time	CR2	\N	\N
818	PG0045	2017-08-11 11:45:00+03	2017-08-11 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-11 11:46:00+03	2017-08-11 13:51:00+03
819	PG0045	2017-08-07 11:45:00+03	2017-08-07 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-07 11:45:00+03	2017-08-07 13:50:00+03
820	PG0045	2017-08-23 11:45:00+03	2017-08-23 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
821	PG0045	2017-07-24 11:45:00+03	2017-07-24 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-24 11:48:00+03	2017-07-24 13:51:00+03
822	PG0045	2017-09-05 11:45:00+03	2017-09-05 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
823	PG0045	2017-07-16 11:45:00+03	2017-07-16 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-16 11:48:00+03	2017-07-16 13:54:00+03
824	PG0045	2017-07-21 11:45:00+03	2017-07-21 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-21 11:51:00+03	2017-07-21 13:57:00+03
825	PG0045	2017-08-30 11:45:00+03	2017-08-30 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
826	PG0045	2017-09-10 11:45:00+03	2017-09-10 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
827	PG0045	2017-08-17 11:45:00+03	2017-08-17 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
828	PG0045	2017-07-23 11:45:00+03	2017-07-23 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-23 11:47:00+03	2017-07-23 13:53:00+03
829	PG0045	2017-07-29 11:45:00+03	2017-07-29 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-29 11:50:00+03	2017-07-29 13:55:00+03
830	PG0045	2017-08-05 11:45:00+03	2017-08-05 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-05 11:47:00+03	2017-08-05 13:53:00+03
831	PG0045	2017-09-09 11:45:00+03	2017-09-09 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
832	PG0045	2017-09-11 11:45:00+03	2017-09-11 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
833	PG0045	2017-09-02 11:45:00+03	2017-09-02 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
834	PG0045	2017-08-08 11:45:00+03	2017-08-08 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-08 11:48:00+03	2017-08-08 13:53:00+03
835	PG0045	2017-08-09 11:45:00+03	2017-08-09 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-09 11:48:00+03	2017-08-09 13:54:00+03
836	PG0045	2017-09-04 11:45:00+03	2017-09-04 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
837	PG0045	2017-08-01 11:45:00+03	2017-08-01 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-01 11:46:00+03	2017-08-01 13:51:00+03
838	PG0045	2017-07-25 11:45:00+03	2017-07-25 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-25 11:50:00+03	2017-07-25 13:54:00+03
839	PG0045	2017-09-01 11:45:00+03	2017-09-01 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
840	PG0045	2017-07-31 11:45:00+03	2017-07-31 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-31 15:12:00+03	2017-07-31 17:15:00+03
841	PG0045	2017-07-28 11:45:00+03	2017-07-28 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-28 11:47:00+03	2017-07-28 13:52:00+03
842	PG0045	2017-07-20 11:45:00+03	2017-07-20 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-20 11:48:00+03	2017-07-20 13:54:00+03
843	PG0045	2017-08-10 11:45:00+03	2017-08-10 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-10 11:51:00+03	2017-08-10 13:56:00+03
844	PG0045	2017-08-22 11:45:00+03	2017-08-22 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
845	PG0045	2017-08-27 11:45:00+03	2017-08-27 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
846	PG0045	2017-08-19 11:45:00+03	2017-08-19 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
847	PG0045	2017-09-13 11:45:00+03	2017-09-13 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
848	PG0045	2017-09-07 11:45:00+03	2017-09-07 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
849	PG0045	2017-08-13 11:45:00+03	2017-08-13 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-13 11:49:00+03	2017-08-13 13:54:00+03
850	PG0045	2017-08-12 11:45:00+03	2017-08-12 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-12 11:49:00+03	2017-08-12 13:54:00+03
851	PG0045	2017-08-14 11:45:00+03	2017-08-14 13:50:00+03	DME	GRV	Arrived	CR2	2017-08-14 11:49:00+03	2017-08-14 13:53:00+03
852	PG0045	2017-07-18 11:45:00+03	2017-07-18 13:50:00+03	DME	GRV	Arrived	CR2	2017-07-18 11:48:00+03	2017-07-18 13:52:00+03
853	PG0045	2017-09-06 11:45:00+03	2017-09-06 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
854	PG0045	2017-08-28 11:45:00+03	2017-08-28 13:50:00+03	DME	GRV	Scheduled	CR2	\N	\N
855	PG0341	2017-08-09 10:50:00+03	2017-08-09 11:55:00+03	DME	PES	Arrived	CR2	2017-08-09 10:54:00+03	2017-08-09 12:00:00+03
856	PG0341	2017-07-28 10:50:00+03	2017-07-28 11:55:00+03	DME	PES	Arrived	CR2	2017-07-28 10:54:00+03	2017-07-28 11:59:00+03
857	PG0341	2017-08-19 10:50:00+03	2017-08-19 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
858	PG0341	2017-09-02 10:50:00+03	2017-09-02 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
859	PG0341	2017-09-14 10:50:00+03	2017-09-14 11:55:00+03	DME	PES	Cancelled	CR2	\N	\N
860	PG0341	2017-08-14 10:50:00+03	2017-08-14 11:55:00+03	DME	PES	Arrived	CR2	2017-08-14 10:54:00+03	2017-08-14 11:58:00+03
861	PG0341	2017-07-21 10:50:00+03	2017-07-21 11:55:00+03	DME	PES	Arrived	CR2	2017-07-21 10:53:00+03	2017-07-21 11:57:00+03
862	PG0341	2017-07-17 10:50:00+03	2017-07-17 11:55:00+03	DME	PES	Arrived	CR2	2017-07-17 10:52:00+03	2017-07-17 11:56:00+03
863	PG0341	2017-07-29 10:50:00+03	2017-07-29 11:55:00+03	DME	PES	Arrived	CR2	2017-07-29 10:53:00+03	2017-07-29 11:59:00+03
864	PG0341	2017-08-18 10:50:00+03	2017-08-18 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
865	PG0341	2017-08-11 10:50:00+03	2017-08-11 11:55:00+03	DME	PES	Arrived	CR2	2017-08-11 10:52:00+03	2017-08-11 11:57:00+03
866	PG0341	2017-08-05 10:50:00+03	2017-08-05 11:55:00+03	DME	PES	Arrived	CR2	2017-08-05 10:55:00+03	2017-08-05 12:00:00+03
867	PG0341	2017-08-22 10:50:00+03	2017-08-22 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
868	PG0341	2017-09-01 10:50:00+03	2017-09-01 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
869	PG0341	2017-09-08 10:50:00+03	2017-09-08 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
870	PG0341	2017-07-19 10:50:00+03	2017-07-19 11:55:00+03	DME	PES	Arrived	CR2	2017-07-19 10:53:00+03	2017-07-19 11:58:00+03
871	PG0341	2017-07-26 10:50:00+03	2017-07-26 11:55:00+03	DME	PES	Arrived	CR2	2017-07-26 10:51:00+03	2017-07-26 11:56:00+03
872	PG0341	2017-08-27 10:50:00+03	2017-08-27 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
873	PG0341	2017-09-12 10:50:00+03	2017-09-12 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
874	PG0341	2017-08-29 10:50:00+03	2017-08-29 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
875	PG0341	2017-08-04 10:50:00+03	2017-08-04 11:55:00+03	DME	PES	Arrived	CR2	2017-08-04 10:54:00+03	2017-08-04 11:59:00+03
876	PG0341	2017-09-11 10:50:00+03	2017-09-11 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
877	PG0341	2017-08-20 10:50:00+03	2017-08-20 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
878	PG0341	2017-08-01 10:50:00+03	2017-08-01 11:55:00+03	DME	PES	Arrived	CR2	2017-08-01 10:53:00+03	2017-08-01 11:58:00+03
879	PG0341	2017-08-02 10:50:00+03	2017-08-02 11:55:00+03	DME	PES	Arrived	CR2	2017-08-02 10:51:00+03	2017-08-02 11:56:00+03
880	PG0341	2017-09-07 10:50:00+03	2017-09-07 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
881	PG0341	2017-08-26 10:50:00+03	2017-08-26 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
882	PG0341	2017-08-25 10:50:00+03	2017-08-25 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
883	PG0341	2017-09-06 10:50:00+03	2017-09-06 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
884	PG0341	2017-08-28 10:50:00+03	2017-08-28 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
885	PG0341	2017-08-03 10:50:00+03	2017-08-03 11:55:00+03	DME	PES	Arrived	CR2	2017-08-03 10:55:00+03	2017-08-03 12:00:00+03
886	PG0341	2017-08-10 10:50:00+03	2017-08-10 11:55:00+03	DME	PES	Arrived	CR2	2017-08-10 10:55:00+03	2017-08-10 11:59:00+03
887	PG0341	2017-09-05 10:50:00+03	2017-09-05 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
888	PG0341	2017-08-13 10:50:00+03	2017-08-13 11:55:00+03	DME	PES	Arrived	CR2	2017-08-13 14:09:00+03	2017-08-13 15:15:00+03
889	PG0341	2017-08-12 10:50:00+03	2017-08-12 11:55:00+03	DME	PES	Arrived	CR2	2017-08-12 10:52:00+03	2017-08-12 11:57:00+03
890	PG0341	2017-08-23 10:50:00+03	2017-08-23 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
891	PG0341	2017-09-03 10:50:00+03	2017-09-03 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
892	PG0341	2017-09-13 10:50:00+03	2017-09-13 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
893	PG0341	2017-07-31 10:50:00+03	2017-07-31 11:55:00+03	DME	PES	Arrived	CR2	2017-07-31 10:53:00+03	2017-07-31 11:58:00+03
894	PG0341	2017-07-23 10:50:00+03	2017-07-23 11:55:00+03	DME	PES	Arrived	CR2	2017-07-23 10:56:00+03	2017-07-23 12:00:00+03
895	PG0341	2017-07-22 10:50:00+03	2017-07-22 11:55:00+03	DME	PES	Arrived	CR2	2017-07-22 10:50:00+03	2017-07-22 11:55:00+03
896	PG0341	2017-08-21 10:50:00+03	2017-08-21 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
897	PG0341	2017-07-20 10:50:00+03	2017-07-20 11:55:00+03	DME	PES	Arrived	CR2	2017-07-20 10:54:00+03	2017-07-20 11:59:00+03
898	PG0341	2017-08-16 10:50:00+03	2017-08-16 11:55:00+03	DME	PES	On Time	CR2	\N	\N
899	PG0341	2017-07-18 10:50:00+03	2017-07-18 11:55:00+03	DME	PES	Arrived	CR2	2017-07-18 10:54:00+03	2017-07-18 11:58:00+03
900	PG0341	2017-08-24 10:50:00+03	2017-08-24 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
901	PG0341	2017-09-04 10:50:00+03	2017-09-04 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
902	PG0341	2017-08-07 10:50:00+03	2017-08-07 11:55:00+03	DME	PES	Arrived	CR2	2017-08-07 10:51:00+03	2017-08-07 11:56:00+03
903	PG0341	2017-07-25 10:50:00+03	2017-07-25 11:55:00+03	DME	PES	Arrived	CR2	2017-07-25 10:53:00+03	2017-07-25 11:59:00+03
904	PG0341	2017-08-06 10:50:00+03	2017-08-06 11:55:00+03	DME	PES	Arrived	CR2	2017-08-06 13:56:00+03	2017-08-06 15:01:00+03
905	PG0341	2017-08-15 10:50:00+03	2017-08-15 11:55:00+03	DME	PES	Arrived	CR2	2017-08-15 10:51:00+03	2017-08-15 11:56:00+03
906	PG0341	2017-07-27 10:50:00+03	2017-07-27 11:55:00+03	DME	PES	Arrived	CR2	2017-07-27 10:53:00+03	2017-07-27 11:57:00+03
907	PG0341	2017-08-08 10:50:00+03	2017-08-08 11:55:00+03	DME	PES	Arrived	CR2	2017-08-08 10:51:00+03	2017-08-08 11:56:00+03
908	PG0341	2017-08-17 10:50:00+03	2017-08-17 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
909	PG0341	2017-09-10 10:50:00+03	2017-09-10 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
910	PG0341	2017-07-30 10:50:00+03	2017-07-30 11:55:00+03	DME	PES	Arrived	CR2	2017-07-30 10:53:00+03	2017-07-30 11:58:00+03
911	PG0341	2017-08-31 10:50:00+03	2017-08-31 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
912	PG0341	2017-07-16 10:50:00+03	2017-07-16 11:55:00+03	DME	PES	Arrived	CR2	2017-07-16 10:52:00+03	2017-07-16 11:58:00+03
913	PG0341	2017-09-09 10:50:00+03	2017-09-09 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
914	PG0341	2017-07-24 10:50:00+03	2017-07-24 11:55:00+03	DME	PES	Arrived	CR2	2017-07-24 10:54:00+03	2017-07-24 11:59:00+03
915	PG0341	2017-08-30 10:50:00+03	2017-08-30 11:55:00+03	DME	PES	Scheduled	CR2	\N	\N
916	PG0368	2017-09-05 15:35:00+03	2017-09-05 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
917	PG0368	2017-08-03 15:35:00+03	2017-08-03 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-03 15:41:00+03	2017-08-03 18:55:00+03
918	PG0368	2017-08-31 15:35:00+03	2017-08-31 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
919	PG0368	2017-08-04 15:35:00+03	2017-08-04 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-04 15:37:00+03	2017-08-04 18:48:00+03
920	PG0368	2017-08-05 15:35:00+03	2017-08-05 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-05 15:40:00+03	2017-08-05 18:53:00+03
921	PG0368	2017-09-04 15:35:00+03	2017-09-04 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
922	PG0368	2017-09-10 15:35:00+03	2017-09-10 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
923	PG0368	2017-07-16 15:35:00+03	2017-07-16 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-16 15:36:00+03	2017-07-16 18:46:00+03
924	PG0368	2017-07-26 15:35:00+03	2017-07-26 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-26 18:31:00+03	2017-07-26 21:43:00+03
925	PG0368	2017-07-29 15:35:00+03	2017-07-29 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-29 15:38:00+03	2017-07-29 18:51:00+03
926	PG0368	2017-08-24 15:35:00+03	2017-08-24 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
927	PG0368	2017-08-22 15:35:00+03	2017-08-22 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
928	PG0368	2017-07-27 15:35:00+03	2017-07-27 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-27 15:42:00+03	2017-07-27 18:58:00+03
929	PG0368	2017-08-13 15:35:00+03	2017-08-13 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-13 15:36:00+03	2017-08-13 18:49:00+03
930	PG0368	2017-07-22 15:35:00+03	2017-07-22 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-22 15:38:00+03	2017-07-22 18:54:00+03
931	PG0368	2017-07-19 15:35:00+03	2017-07-19 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-19 15:36:00+03	2017-07-19 18:54:00+03
932	PG0368	2017-08-01 15:35:00+03	2017-08-01 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-01 15:38:00+03	2017-08-01 18:54:00+03
933	PG0368	2017-09-01 15:35:00+03	2017-09-01 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
934	PG0368	2017-09-02 15:35:00+03	2017-09-02 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
935	PG0368	2017-09-14 15:35:00+03	2017-09-14 18:50:00+03	DME	NJC	Cancelled	CR2	\N	\N
936	PG0368	2017-08-25 15:35:00+03	2017-08-25 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
937	PG0368	2017-09-08 15:35:00+03	2017-09-08 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
938	PG0368	2017-07-23 15:35:00+03	2017-07-23 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-23 15:42:00+03	2017-07-23 18:59:00+03
939	PG0368	2017-08-09 15:35:00+03	2017-08-09 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-09 15:37:00+03	2017-08-09 18:51:00+03
940	PG0368	2017-07-21 15:35:00+03	2017-07-21 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-21 15:36:00+03	2017-07-21 18:55:00+03
941	PG0368	2017-07-18 15:35:00+03	2017-07-18 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-18 15:36:00+03	2017-07-18 18:49:00+03
942	PG0368	2017-08-11 15:35:00+03	2017-08-11 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-11 15:37:00+03	2017-08-11 18:53:00+03
943	PG0368	2017-07-31 15:35:00+03	2017-07-31 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-31 15:38:00+03	2017-07-31 18:52:00+03
944	PG0368	2017-08-12 15:35:00+03	2017-08-12 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-12 15:39:00+03	2017-08-12 18:52:00+03
945	PG0368	2017-08-02 15:35:00+03	2017-08-02 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-02 15:41:00+03	2017-08-02 18:59:00+03
946	PG0368	2017-09-03 15:35:00+03	2017-09-03 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
947	PG0368	2017-08-07 15:35:00+03	2017-08-07 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-07 15:36:00+03	2017-08-07 18:54:00+03
948	PG0368	2017-07-17 15:35:00+03	2017-07-17 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-17 15:40:00+03	2017-07-17 18:59:00+03
949	PG0368	2017-08-18 15:35:00+03	2017-08-18 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
950	PG0368	2017-07-25 15:35:00+03	2017-07-25 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-25 15:38:00+03	2017-07-25 18:52:00+03
951	PG0368	2017-08-08 15:35:00+03	2017-08-08 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-08 15:38:00+03	2017-08-08 18:53:00+03
952	PG0368	2017-08-20 15:35:00+03	2017-08-20 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
953	PG0368	2017-07-24 15:35:00+03	2017-07-24 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-24 15:37:00+03	2017-07-24 18:56:00+03
954	PG0368	2017-09-13 15:35:00+03	2017-09-13 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
955	PG0368	2017-08-06 15:35:00+03	2017-08-06 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-06 19:29:00+03	2017-08-06 22:49:00+03
956	PG0368	2017-08-29 15:35:00+03	2017-08-29 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
957	PG0368	2017-08-10 15:35:00+03	2017-08-10 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-10 15:37:00+03	2017-08-10 18:51:00+03
958	PG0368	2017-08-17 15:35:00+03	2017-08-17 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
959	PG0368	2017-08-19 15:35:00+03	2017-08-19 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
960	PG0368	2017-08-26 15:35:00+03	2017-08-26 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
961	PG0368	2017-08-21 15:35:00+03	2017-08-21 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
962	PG0368	2017-09-12 15:35:00+03	2017-09-12 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
963	PG0368	2017-09-11 15:35:00+03	2017-09-11 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
964	PG0368	2017-08-23 15:35:00+03	2017-08-23 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
965	PG0368	2017-09-09 15:35:00+03	2017-09-09 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
966	PG0368	2017-07-30 15:35:00+03	2017-07-30 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-30 15:38:00+03	2017-07-30 18:54:00+03
967	PG0368	2017-08-16 15:35:00+03	2017-08-16 18:50:00+03	DME	NJC	On Time	CR2	\N	\N
968	PG0368	2017-08-28 15:35:00+03	2017-08-28 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
969	PG0368	2017-09-06 15:35:00+03	2017-09-06 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
970	PG0368	2017-07-20 15:35:00+03	2017-07-20 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-20 15:39:00+03	2017-07-20 18:50:00+03
971	PG0368	2017-08-14 15:35:00+03	2017-08-14 18:50:00+03	DME	NJC	Arrived	CR2	2017-08-14 15:36:00+03	2017-08-14 18:52:00+03
972	PG0368	2017-08-15 15:35:00+03	2017-08-15 18:50:00+03	DME	NJC	Departed	CR2	2017-08-15 15:38:00+03	\N
973	PG0368	2017-08-27 15:35:00+03	2017-08-27 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
974	PG0368	2017-09-07 15:35:00+03	2017-09-07 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
975	PG0368	2017-07-28 15:35:00+03	2017-07-28 18:50:00+03	DME	NJC	Arrived	CR2	2017-07-28 15:39:00+03	2017-07-28 18:52:00+03
976	PG0368	2017-08-30 15:35:00+03	2017-08-30 18:50:00+03	DME	NJC	Scheduled	CR2	\N	\N
977	PG0335	2017-08-20 09:30:00+03	2017-08-20 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
978	PG0335	2017-09-11 09:30:00+03	2017-09-11 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
979	PG0335	2017-07-17 09:30:00+03	2017-07-17 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-17 09:32:00+03	2017-07-17 11:34:00+03
980	PG0335	2017-09-10 09:30:00+03	2017-09-10 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
981	PG0335	2017-07-16 09:30:00+03	2017-07-16 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-16 09:31:00+03	2017-07-16 11:37:00+03
982	PG0335	2017-08-27 09:30:00+03	2017-08-27 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
983	PG0335	2017-08-28 09:30:00+03	2017-08-28 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
984	PG0335	2017-09-12 09:30:00+03	2017-09-12 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
985	PG0335	2017-07-27 09:30:00+03	2017-07-27 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-27 09:34:00+03	2017-07-27 11:39:00+03
986	PG0335	2017-08-14 09:30:00+03	2017-08-14 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-14 09:32:00+03	2017-08-14 11:37:00+03
987	PG0335	2017-08-25 09:30:00+03	2017-08-25 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
988	PG0335	2017-08-31 09:30:00+03	2017-08-31 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
989	PG0335	2017-08-04 09:30:00+03	2017-08-04 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-04 09:33:00+03	2017-08-04 11:38:00+03
990	PG0335	2017-08-29 09:30:00+03	2017-08-29 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
991	PG0335	2017-09-06 09:30:00+03	2017-09-06 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
992	PG0335	2017-07-26 09:30:00+03	2017-07-26 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-26 09:34:00+03	2017-07-26 11:39:00+03
993	PG0335	2017-08-10 09:30:00+03	2017-08-10 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-10 09:36:00+03	2017-08-10 11:41:00+03
994	PG0335	2017-08-15 09:30:00+03	2017-08-15 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-15 09:32:00+03	2017-08-15 11:37:00+03
995	PG0335	2017-08-24 09:30:00+03	2017-08-24 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
996	PG0335	2017-09-02 09:30:00+03	2017-09-02 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
997	PG0335	2017-07-18 09:30:00+03	2017-07-18 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-18 09:31:00+03	2017-07-18 11:37:00+03
998	PG0335	2017-08-06 09:30:00+03	2017-08-06 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-06 09:33:00+03	2017-08-06 11:36:00+03
999	PG0335	2017-07-24 09:30:00+03	2017-07-24 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-24 09:32:00+03	2017-07-24 11:38:00+03
1000	PG0335	2017-08-08 09:30:00+03	2017-08-08 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-08 09:34:00+03	2017-08-08 11:42:00+03
1001	PG0335	2017-07-30 09:30:00+03	2017-07-30 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-30 09:34:00+03	2017-07-30 11:38:00+03
1002	PG0335	2017-09-14 09:30:00+03	2017-09-14 11:35:00+03	DME	JOK	Cancelled	CN1	\N	\N
1003	PG0335	2017-08-21 09:30:00+03	2017-08-21 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1004	PG0335	2017-08-22 09:30:00+03	2017-08-22 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1005	PG0335	2017-09-08 09:30:00+03	2017-09-08 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1006	PG0335	2017-07-21 09:30:00+03	2017-07-21 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-21 09:33:00+03	2017-07-21 11:40:00+03
1007	PG0335	2017-08-11 09:30:00+03	2017-08-11 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-11 09:33:00+03	2017-08-11 11:40:00+03
1008	PG0335	2017-07-29 09:30:00+03	2017-07-29 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-29 09:32:00+03	2017-07-29 11:36:00+03
1009	PG0335	2017-07-19 09:30:00+03	2017-07-19 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-19 09:33:00+03	2017-07-19 11:38:00+03
1010	PG0335	2017-09-01 09:30:00+03	2017-09-01 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1011	PG0335	2017-08-05 09:30:00+03	2017-08-05 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-05 09:32:00+03	2017-08-05 11:36:00+03
1012	PG0335	2017-09-09 09:30:00+03	2017-09-09 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1013	PG0335	2017-08-09 09:30:00+03	2017-08-09 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-09 09:33:00+03	2017-08-09 11:38:00+03
1014	PG0335	2017-08-17 09:30:00+03	2017-08-17 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1015	PG0335	2017-08-12 09:30:00+03	2017-08-12 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-12 09:34:00+03	2017-08-12 11:37:00+03
1016	PG0335	2017-08-07 09:30:00+03	2017-08-07 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-07 09:35:00+03	2017-08-07 11:43:00+03
1017	PG0335	2017-09-04 09:30:00+03	2017-09-04 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1018	PG0335	2017-07-20 09:30:00+03	2017-07-20 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-20 09:33:00+03	2017-07-20 11:38:00+03
1019	PG0335	2017-07-25 09:30:00+03	2017-07-25 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-25 09:34:00+03	2017-07-25 11:41:00+03
1020	PG0335	2017-07-23 09:30:00+03	2017-07-23 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-23 09:32:00+03	2017-07-23 11:40:00+03
1021	PG0335	2017-08-13 09:30:00+03	2017-08-13 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-13 09:33:00+03	2017-08-13 11:37:00+03
1022	PG0335	2017-07-22 09:30:00+03	2017-07-22 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-22 09:30:00+03	2017-07-22 11:36:00+03
1023	PG0335	2017-08-16 09:30:00+03	2017-08-16 11:35:00+03	DME	JOK	On Time	CN1	\N	\N
1024	PG0335	2017-09-13 09:30:00+03	2017-09-13 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1025	PG0335	2017-07-31 09:30:00+03	2017-07-31 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-31 09:34:00+03	2017-07-31 11:38:00+03
1026	PG0335	2017-09-05 09:30:00+03	2017-09-05 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1027	PG0335	2017-08-19 09:30:00+03	2017-08-19 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1028	PG0335	2017-09-03 09:30:00+03	2017-09-03 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1029	PG0335	2017-08-23 09:30:00+03	2017-08-23 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1030	PG0335	2017-07-28 09:30:00+03	2017-07-28 11:35:00+03	DME	JOK	Arrived	CN1	2017-07-28 12:39:00+03	2017-07-28 14:44:00+03
1031	PG0335	2017-08-03 09:30:00+03	2017-08-03 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-03 09:32:00+03	2017-08-03 11:38:00+03
1032	PG0335	2017-08-01 09:30:00+03	2017-08-01 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-01 09:32:00+03	2017-08-01 11:35:00+03
1033	PG0335	2017-08-02 09:30:00+03	2017-08-02 11:35:00+03	DME	JOK	Arrived	CN1	2017-08-02 09:31:00+03	2017-08-02 11:36:00+03
1034	PG0335	2017-09-07 09:30:00+03	2017-09-07 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1035	PG0335	2017-08-18 09:30:00+03	2017-08-18 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1036	PG0335	2017-08-30 09:30:00+03	2017-08-30 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1037	PG0335	2017-08-26 09:30:00+03	2017-08-26 11:35:00+03	DME	JOK	Scheduled	CN1	\N	\N
1038	PG0517	2017-09-04 10:30:00+03	2017-09-04 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1039	PG0517	2017-08-28 10:30:00+03	2017-08-28 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1040	PG0517	2017-08-13 10:30:00+03	2017-08-13 11:50:00+03	DME	SCW	Arrived	763	2017-08-13 10:31:00+03	2017-08-13 11:50:00+03
1041	PG0517	2017-09-01 10:30:00+03	2017-09-01 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1042	PG0517	2017-09-08 10:30:00+03	2017-09-08 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1043	PG0517	2017-09-10 10:30:00+03	2017-09-10 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1044	PG0517	2017-08-25 10:30:00+03	2017-08-25 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1045	PG0517	2017-07-30 10:30:00+03	2017-07-30 11:50:00+03	DME	SCW	Arrived	763	2017-07-30 10:31:00+03	2017-07-30 11:50:00+03
1046	PG0517	2017-07-22 10:30:00+03	2017-07-22 11:50:00+03	DME	SCW	Arrived	763	2017-07-22 10:34:00+03	2017-07-22 11:54:00+03
1047	PG0517	2017-07-23 10:30:00+03	2017-07-23 11:50:00+03	DME	SCW	Arrived	763	2017-07-23 10:33:00+03	2017-07-23 11:54:00+03
1048	PG0517	2017-09-02 10:30:00+03	2017-09-02 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1049	PG0517	2017-08-04 10:30:00+03	2017-08-04 11:50:00+03	DME	SCW	Arrived	763	2017-08-04 10:31:00+03	2017-08-04 11:51:00+03
1050	PG0517	2017-07-18 10:30:00+03	2017-07-18 11:50:00+03	DME	SCW	Arrived	763	2017-07-18 10:33:00+03	2017-07-18 11:52:00+03
1051	PG0517	2017-07-29 10:30:00+03	2017-07-29 11:50:00+03	DME	SCW	Arrived	763	2017-07-29 10:32:00+03	2017-07-29 11:52:00+03
1052	PG0517	2017-09-05 10:30:00+03	2017-09-05 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1053	PG0517	2017-09-07 10:30:00+03	2017-09-07 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1054	PG0517	2017-08-26 10:30:00+03	2017-08-26 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1055	PG0517	2017-08-31 10:30:00+03	2017-08-31 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1056	PG0517	2017-09-06 10:30:00+03	2017-09-06 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1057	PG0517	2017-07-26 10:30:00+03	2017-07-26 11:50:00+03	DME	SCW	Arrived	763	2017-07-26 13:49:00+03	2017-07-26 15:09:00+03
1058	PG0517	2017-08-17 10:30:00+03	2017-08-17 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1059	PG0517	2017-08-21 10:30:00+03	2017-08-21 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1060	PG0517	2017-08-15 10:30:00+03	2017-08-15 11:50:00+03	DME	SCW	Arrived	763	2017-08-15 10:34:00+03	2017-08-15 11:55:00+03
1061	PG0517	2017-08-03 10:30:00+03	2017-08-03 11:50:00+03	DME	SCW	Arrived	763	2017-08-03 10:31:00+03	2017-08-03 11:52:00+03
1062	PG0517	2017-08-08 10:30:00+03	2017-08-08 11:50:00+03	DME	SCW	Arrived	763	2017-08-08 10:32:00+03	2017-08-08 11:52:00+03
1063	PG0517	2017-08-09 10:30:00+03	2017-08-09 11:50:00+03	DME	SCW	Arrived	763	2017-08-09 10:32:00+03	2017-08-09 11:52:00+03
1064	PG0517	2017-07-27 10:30:00+03	2017-07-27 11:50:00+03	DME	SCW	Arrived	763	2017-07-27 10:32:00+03	2017-07-27 11:52:00+03
1065	PG0517	2017-07-28 10:30:00+03	2017-07-28 11:50:00+03	DME	SCW	Arrived	763	2017-07-28 10:33:00+03	2017-07-28 11:54:00+03
1066	PG0517	2017-07-25 10:30:00+03	2017-07-25 11:50:00+03	DME	SCW	Arrived	763	2017-07-25 10:31:00+03	2017-07-25 11:51:00+03
1067	PG0517	2017-08-06 10:30:00+03	2017-08-06 11:50:00+03	DME	SCW	Arrived	763	2017-08-06 10:31:00+03	2017-08-06 11:51:00+03
1068	PG0517	2017-08-01 10:30:00+03	2017-08-01 11:50:00+03	DME	SCW	Arrived	763	2017-08-01 10:34:00+03	2017-08-01 11:53:00+03
1069	PG0517	2017-08-20 10:30:00+03	2017-08-20 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1070	PG0517	2017-09-03 10:30:00+03	2017-09-03 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1071	PG0517	2017-08-12 10:30:00+03	2017-08-12 11:50:00+03	DME	SCW	Arrived	763	2017-08-12 10:31:00+03	2017-08-12 11:51:00+03
1072	PG0517	2017-08-02 10:30:00+03	2017-08-02 11:50:00+03	DME	SCW	Arrived	763	2017-08-02 10:33:00+03	2017-08-02 11:52:00+03
1073	PG0517	2017-09-14 10:30:00+03	2017-09-14 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1074	PG0517	2017-08-24 10:30:00+03	2017-08-24 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1075	PG0517	2017-08-22 10:30:00+03	2017-08-22 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1076	PG0517	2017-07-17 10:30:00+03	2017-07-17 11:50:00+03	DME	SCW	Arrived	763	2017-07-17 10:31:00+03	2017-07-17 11:52:00+03
1077	PG0517	2017-07-19 10:30:00+03	2017-07-19 11:50:00+03	DME	SCW	Arrived	763	2017-07-19 10:34:00+03	2017-07-19 11:54:00+03
1078	PG0517	2017-08-11 10:30:00+03	2017-08-11 11:50:00+03	DME	SCW	Arrived	763	2017-08-11 10:31:00+03	2017-08-11 11:51:00+03
1079	PG0517	2017-08-05 10:30:00+03	2017-08-05 11:50:00+03	DME	SCW	Arrived	763	2017-08-05 10:35:00+03	2017-08-05 11:53:00+03
1080	PG0517	2017-08-18 10:30:00+03	2017-08-18 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1081	PG0517	2017-07-20 10:30:00+03	2017-07-20 11:50:00+03	DME	SCW	Arrived	763	2017-07-20 10:34:00+03	2017-07-20 11:53:00+03
1082	PG0517	2017-09-11 10:30:00+03	2017-09-11 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1083	PG0517	2017-07-24 10:30:00+03	2017-07-24 11:50:00+03	DME	SCW	Arrived	763	2017-07-24 10:34:00+03	2017-07-24 11:54:00+03
1084	PG0517	2017-08-27 10:30:00+03	2017-08-27 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1085	PG0517	2017-08-19 10:30:00+03	2017-08-19 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1086	PG0517	2017-08-07 10:30:00+03	2017-08-07 11:50:00+03	DME	SCW	Arrived	763	2017-08-07 10:34:00+03	2017-08-07 11:53:00+03
1087	PG0517	2017-09-12 10:30:00+03	2017-09-12 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1088	PG0517	2017-08-29 10:30:00+03	2017-08-29 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1089	PG0517	2017-07-31 10:30:00+03	2017-07-31 11:50:00+03	DME	SCW	Arrived	763	2017-07-31 10:38:00+03	2017-07-31 11:57:00+03
1090	PG0517	2017-07-16 10:30:00+03	2017-07-16 11:50:00+03	DME	SCW	Arrived	763	2017-07-16 10:35:00+03	2017-07-16 11:57:00+03
1091	PG0517	2017-07-21 10:30:00+03	2017-07-21 11:50:00+03	DME	SCW	Arrived	763	2017-07-21 10:34:00+03	2017-07-21 11:54:00+03
1092	PG0517	2017-09-09 10:30:00+03	2017-09-09 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1093	PG0517	2017-08-30 10:30:00+03	2017-08-30 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1094	PG0517	2017-08-14 10:30:00+03	2017-08-14 11:50:00+03	DME	SCW	Arrived	763	2017-08-14 10:34:00+03	2017-08-14 11:55:00+03
1095	PG0517	2017-09-13 10:30:00+03	2017-09-13 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1096	PG0517	2017-08-23 10:30:00+03	2017-08-23 11:50:00+03	DME	SCW	Scheduled	763	\N	\N
1097	PG0517	2017-08-10 10:30:00+03	2017-08-10 11:50:00+03	DME	SCW	Arrived	763	2017-08-10 10:33:00+03	2017-08-10 11:54:00+03
1098	PG0517	2017-08-16 10:30:00+03	2017-08-16 11:50:00+03	DME	SCW	On Time	763	\N	\N
1099	PG0136	2017-09-10 15:30:00+03	2017-09-10 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1100	PG0136	2017-08-25 15:30:00+03	2017-08-25 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1101	PG0136	2017-07-17 15:30:00+03	2017-07-17 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-17 15:32:00+03	2017-07-17 17:34:00+03
1102	PG0136	2017-08-29 15:30:00+03	2017-08-29 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1103	PG0136	2017-08-15 15:30:00+03	2017-08-15 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-15 15:35:00+03	2017-08-15 17:38:00+03
1104	PG0136	2017-08-31 15:30:00+03	2017-08-31 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1105	PG0136	2017-07-27 15:30:00+03	2017-07-27 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-27 15:34:00+03	2017-07-27 17:35:00+03
1106	PG0136	2017-07-24 15:30:00+03	2017-07-24 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-24 15:33:00+03	2017-07-24 17:35:00+03
1107	PG0136	2017-08-13 15:30:00+03	2017-08-13 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-13 15:32:00+03	2017-08-13 17:32:00+03
1108	PG0136	2017-09-14 15:30:00+03	2017-09-14 17:30:00+03	DME	NAL	Cancelled	CR2	\N	\N
1109	PG0136	2017-08-07 15:30:00+03	2017-08-07 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-07 15:32:00+03	2017-08-07 17:31:00+03
1110	PG0136	2017-09-03 15:30:00+03	2017-09-03 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1111	PG0136	2017-07-28 15:30:00+03	2017-07-28 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-28 15:30:00+03	2017-07-28 17:30:00+03
1112	PG0136	2017-08-14 15:30:00+03	2017-08-14 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-14 15:33:00+03	2017-08-14 17:33:00+03
1113	PG0136	2017-08-04 15:30:00+03	2017-08-04 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-04 15:32:00+03	2017-08-04 17:31:00+03
1114	PG0136	2017-08-08 15:30:00+03	2017-08-08 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-08 15:33:00+03	2017-08-08 17:34:00+03
1115	PG0136	2017-09-05 15:30:00+03	2017-09-05 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1116	PG0136	2017-08-03 15:30:00+03	2017-08-03 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-03 15:32:00+03	2017-08-03 17:33:00+03
1117	PG0136	2017-08-11 15:30:00+03	2017-08-11 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-11 15:32:00+03	2017-08-11 17:33:00+03
1118	PG0136	2017-08-05 15:30:00+03	2017-08-05 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-05 15:32:00+03	2017-08-05 17:32:00+03
1119	PG0136	2017-09-04 15:30:00+03	2017-09-04 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1120	PG0136	2017-07-29 15:30:00+03	2017-07-29 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-29 15:34:00+03	2017-07-29 17:34:00+03
1121	PG0136	2017-08-19 15:30:00+03	2017-08-19 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1122	PG0136	2017-08-12 15:30:00+03	2017-08-12 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-12 15:34:00+03	2017-08-12 17:34:00+03
1123	PG0136	2017-07-25 15:30:00+03	2017-07-25 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-25 15:35:00+03	2017-07-25 17:35:00+03
1124	PG0136	2017-08-06 15:30:00+03	2017-08-06 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-06 15:34:00+03	2017-08-06 17:33:00+03
1125	PG0136	2017-07-22 15:30:00+03	2017-07-22 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-22 15:31:00+03	2017-07-22 17:30:00+03
1126	PG0136	2017-08-16 15:30:00+03	2017-08-16 17:30:00+03	DME	NAL	On Time	CR2	\N	\N
1127	PG0136	2017-07-16 15:30:00+03	2017-07-16 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-16 15:32:00+03	2017-07-16 17:31:00+03
1128	PG0136	2017-09-06 15:30:00+03	2017-09-06 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1129	PG0136	2017-08-20 15:30:00+03	2017-08-20 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1130	PG0136	2017-07-30 15:30:00+03	2017-07-30 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-30 15:32:00+03	2017-07-30 17:31:00+03
1131	PG0136	2017-07-31 15:30:00+03	2017-07-31 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-31 15:33:00+03	2017-07-31 17:33:00+03
1132	PG0136	2017-07-19 15:30:00+03	2017-07-19 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-19 15:31:00+03	2017-07-19 17:31:00+03
1133	PG0136	2017-08-22 15:30:00+03	2017-08-22 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1134	PG0136	2017-07-21 15:30:00+03	2017-07-21 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-21 15:32:00+03	2017-07-21 17:33:00+03
1135	PG0136	2017-08-28 15:30:00+03	2017-08-28 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1136	PG0136	2017-09-01 15:30:00+03	2017-09-01 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1137	PG0136	2017-08-26 15:30:00+03	2017-08-26 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1138	PG0136	2017-07-23 15:30:00+03	2017-07-23 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-23 15:34:00+03	2017-07-23 17:36:00+03
1139	PG0136	2017-08-27 15:30:00+03	2017-08-27 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1140	PG0136	2017-07-18 15:30:00+03	2017-07-18 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-18 15:32:00+03	2017-07-18 17:33:00+03
1141	PG0136	2017-09-09 15:30:00+03	2017-09-09 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1142	PG0136	2017-08-17 15:30:00+03	2017-08-17 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1143	PG0136	2017-07-20 15:30:00+03	2017-07-20 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-20 15:33:00+03	2017-07-20 17:33:00+03
1144	PG0136	2017-09-12 15:30:00+03	2017-09-12 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1145	PG0136	2017-08-21 15:30:00+03	2017-08-21 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1146	PG0136	2017-09-13 15:30:00+03	2017-09-13 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1147	PG0136	2017-08-01 15:30:00+03	2017-08-01 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-01 15:34:00+03	2017-08-01 17:36:00+03
1148	PG0136	2017-09-07 15:30:00+03	2017-09-07 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1149	PG0136	2017-07-26 15:30:00+03	2017-07-26 17:30:00+03	DME	NAL	Arrived	CR2	2017-07-26 15:35:00+03	2017-07-26 17:36:00+03
1150	PG0136	2017-08-10 15:30:00+03	2017-08-10 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-10 15:35:00+03	2017-08-10 17:36:00+03
1151	PG0136	2017-08-18 15:30:00+03	2017-08-18 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1152	PG0136	2017-09-02 15:30:00+03	2017-09-02 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1153	PG0136	2017-09-08 15:30:00+03	2017-09-08 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1154	PG0136	2017-08-02 15:30:00+03	2017-08-02 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-02 15:33:00+03	2017-08-02 17:34:00+03
1155	PG0136	2017-09-11 15:30:00+03	2017-09-11 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1156	PG0136	2017-08-30 15:30:00+03	2017-08-30 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1157	PG0136	2017-08-24 15:30:00+03	2017-08-24 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1158	PG0136	2017-08-09 15:30:00+03	2017-08-09 17:30:00+03	DME	NAL	Arrived	CR2	2017-08-09 15:33:00+03	2017-08-09 17:34:00+03
1159	PG0136	2017-08-23 15:30:00+03	2017-08-23 17:30:00+03	DME	NAL	Scheduled	CR2	\N	\N
1160	PG0134	2017-09-04 09:50:00+03	2017-09-04 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1161	PG0134	2017-08-26 09:50:00+03	2017-08-26 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1162	PG0134	2017-07-19 09:50:00+03	2017-07-19 14:55:00+03	DME	BTK	Arrived	319	2017-07-19 09:54:00+03	2017-07-19 15:00:00+03
1163	PG0134	2017-08-29 09:50:00+03	2017-08-29 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1164	PG0134	2017-09-12 09:50:00+03	2017-09-12 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1165	PG0134	2017-09-06 09:50:00+03	2017-09-06 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1166	PG0134	2017-07-22 09:50:00+03	2017-07-22 14:55:00+03	DME	BTK	Arrived	319	2017-07-22 09:53:00+03	2017-07-22 14:59:00+03
1167	PG0134	2017-08-14 09:50:00+03	2017-08-14 14:55:00+03	DME	BTK	Arrived	319	2017-08-14 09:55:00+03	2017-08-14 15:05:00+03
1168	PG0134	2017-08-02 09:50:00+03	2017-08-02 14:55:00+03	DME	BTK	Arrived	319	2017-08-02 09:54:00+03	2017-08-02 15:00:00+03
1169	PG0134	2017-08-18 09:50:00+03	2017-08-18 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1170	PG0134	2017-07-26 09:50:00+03	2017-07-26 14:55:00+03	DME	BTK	Arrived	319	2017-07-26 09:55:00+03	2017-07-26 15:04:00+03
1171	PG0134	2017-07-27 09:50:00+03	2017-07-27 14:55:00+03	DME	BTK	Arrived	319	2017-07-27 09:53:00+03	2017-07-27 15:03:00+03
1172	PG0134	2017-07-17 09:50:00+03	2017-07-17 14:55:00+03	DME	BTK	Arrived	319	2017-07-17 09:53:00+03	2017-07-17 14:55:00+03
1173	PG0134	2017-09-01 09:50:00+03	2017-09-01 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1174	PG0134	2017-08-04 09:50:00+03	2017-08-04 14:55:00+03	DME	BTK	Arrived	319	2017-08-04 09:52:00+03	2017-08-04 15:01:00+03
1175	PG0134	2017-08-11 09:50:00+03	2017-08-11 14:55:00+03	DME	BTK	Arrived	319	2017-08-11 09:52:00+03	2017-08-11 14:54:00+03
1176	PG0134	2017-09-05 09:50:00+03	2017-09-05 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1177	PG0134	2017-07-21 09:50:00+03	2017-07-21 14:55:00+03	DME	BTK	Arrived	319	2017-07-21 09:52:00+03	2017-07-21 14:58:00+03
1178	PG0134	2017-08-17 09:50:00+03	2017-08-17 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1179	PG0134	2017-09-09 09:50:00+03	2017-09-09 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1180	PG0134	2017-08-21 09:50:00+03	2017-08-21 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1181	PG0134	2017-08-23 09:50:00+03	2017-08-23 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1182	PG0134	2017-08-01 09:50:00+03	2017-08-01 14:55:00+03	DME	BTK	Arrived	319	2017-08-01 09:52:00+03	2017-08-01 15:01:00+03
1183	PG0134	2017-07-23 09:50:00+03	2017-07-23 14:55:00+03	DME	BTK	Arrived	319	2017-07-23 09:54:00+03	2017-07-23 14:56:00+03
1184	PG0134	2017-08-05 09:50:00+03	2017-08-05 14:55:00+03	DME	BTK	Arrived	319	2017-08-05 09:55:00+03	2017-08-05 14:54:00+03
1186	PG0134	2017-08-10 09:50:00+03	2017-08-10 14:55:00+03	DME	BTK	Arrived	319	2017-08-10 09:51:00+03	2017-08-10 15:02:00+03
1187	PG0134	2017-09-02 09:50:00+03	2017-09-02 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1188	PG0134	2017-07-28 09:50:00+03	2017-07-28 14:55:00+03	DME	BTK	Arrived	319	2017-07-28 09:52:00+03	2017-07-28 15:00:00+03
1189	PG0134	2017-08-20 09:50:00+03	2017-08-20 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1190	PG0134	2017-08-22 09:50:00+03	2017-08-22 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1191	PG0134	2017-09-07 09:50:00+03	2017-09-07 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1192	PG0134	2017-09-14 09:50:00+03	2017-09-14 14:55:00+03	DME	BTK	Cancelled	319	\N	\N
1193	PG0134	2017-08-25 09:50:00+03	2017-08-25 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1194	PG0134	2017-07-18 09:50:00+03	2017-07-18 14:55:00+03	DME	BTK	Arrived	319	2017-07-18 09:55:00+03	2017-07-18 14:59:00+03
1195	PG0134	2017-09-11 09:50:00+03	2017-09-11 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1196	PG0134	2017-08-06 09:50:00+03	2017-08-06 14:55:00+03	DME	BTK	Arrived	319	2017-08-06 09:52:00+03	2017-08-06 14:58:00+03
1197	PG0134	2017-07-31 09:50:00+03	2017-07-31 14:55:00+03	DME	BTK	Arrived	319	2017-07-31 09:53:00+03	2017-07-31 15:01:00+03
1198	PG0134	2017-07-20 09:50:00+03	2017-07-20 14:55:00+03	DME	BTK	Arrived	319	2017-07-20 09:58:00+03	2017-07-20 15:01:00+03
1199	PG0134	2017-07-25 09:50:00+03	2017-07-25 14:55:00+03	DME	BTK	Arrived	319	2017-07-25 09:53:00+03	2017-07-25 14:57:00+03
1200	PG0134	2017-08-31 09:50:00+03	2017-08-31 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1201	PG0134	2017-08-15 09:50:00+03	2017-08-15 14:55:00+03	DME	BTK	Arrived	319	2017-08-15 09:52:00+03	2017-08-15 15:00:00+03
1202	PG0134	2017-08-09 09:50:00+03	2017-08-09 14:55:00+03	DME	BTK	Arrived	319	2017-08-09 09:53:00+03	2017-08-09 14:59:00+03
1203	PG0134	2017-08-03 09:50:00+03	2017-08-03 14:55:00+03	DME	BTK	Arrived	319	2017-08-03 09:51:00+03	2017-08-03 14:58:00+03
1204	PG0134	2017-09-13 09:50:00+03	2017-09-13 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1205	PG0134	2017-08-24 09:50:00+03	2017-08-24 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1206	PG0134	2017-08-28 09:50:00+03	2017-08-28 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1207	PG0134	2017-08-19 09:50:00+03	2017-08-19 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1208	PG0134	2017-08-16 09:50:00+03	2017-08-16 14:55:00+03	DME	BTK	On Time	319	\N	\N
1209	PG0134	2017-07-29 09:50:00+03	2017-07-29 14:55:00+03	DME	BTK	Arrived	319	2017-07-29 09:56:00+03	2017-07-29 15:02:00+03
1210	PG0134	2017-08-27 09:50:00+03	2017-08-27 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1211	PG0134	2017-08-07 09:50:00+03	2017-08-07 14:55:00+03	DME	BTK	Arrived	319	2017-08-07 09:53:00+03	2017-08-07 14:58:00+03
1212	PG0134	2017-07-24 09:50:00+03	2017-07-24 14:55:00+03	DME	BTK	Arrived	319	2017-07-24 09:52:00+03	2017-07-24 15:01:00+03
1213	PG0134	2017-08-12 09:50:00+03	2017-08-12 14:55:00+03	DME	BTK	Arrived	319	2017-08-12 09:53:00+03	2017-08-12 15:02:00+03
1214	PG0134	2017-07-16 09:50:00+03	2017-07-16 14:55:00+03	DME	BTK	Arrived	319	2017-07-16 09:54:00+03	2017-07-16 15:05:00+03
1215	PG0134	2017-09-08 09:50:00+03	2017-09-08 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1216	PG0134	2017-08-30 09:50:00+03	2017-08-30 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1217	PG0134	2017-08-13 09:50:00+03	2017-08-13 14:55:00+03	DME	BTK	Arrived	319	2017-08-13 09:52:00+03	2017-08-13 15:00:00+03
1218	PG0134	2017-09-03 09:50:00+03	2017-09-03 14:55:00+03	DME	BTK	Scheduled	319	\N	\N
1219	PG0134	2017-08-08 09:50:00+03	2017-08-08 14:55:00+03	DME	BTK	Arrived	319	2017-08-08 09:53:00+03	2017-08-08 14:54:00+03
1220	PG0134	2017-07-30 09:50:00+03	2017-07-30 14:55:00+03	DME	BTK	Arrived	319	2017-07-30 09:54:00+03	2017-07-30 15:00:00+03
1221	PG0005	2017-08-15 15:40:00+03	2017-08-15 17:45:00+03	DME	PKV	Delayed	CN1	\N	\N
1222	PG0005	2017-07-16 15:40:00+03	2017-07-16 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-16 15:44:00+03	2017-07-16 17:50:00+03
1223	PG0005	2017-08-20 15:40:00+03	2017-08-20 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1224	PG0005	2017-08-11 15:40:00+03	2017-08-11 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-11 15:42:00+03	2017-08-11 17:47:00+03
1225	PG0005	2017-08-04 15:40:00+03	2017-08-04 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-04 15:42:00+03	2017-08-04 17:47:00+03
1226	PG0005	2017-08-29 15:40:00+03	2017-08-29 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1227	PG0005	2017-08-13 15:40:00+03	2017-08-13 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-13 15:43:00+03	2017-08-13 17:49:00+03
1228	PG0005	2017-07-21 15:40:00+03	2017-07-21 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-21 15:44:00+03	2017-07-21 17:51:00+03
1229	PG0005	2017-09-05 15:40:00+03	2017-09-05 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1230	PG0005	2017-09-10 15:40:00+03	2017-09-10 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1231	PG0005	2017-08-25 15:40:00+03	2017-08-25 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1232	PG0005	2017-09-08 15:40:00+03	2017-09-08 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1233	PG0005	2017-07-30 15:40:00+03	2017-07-30 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-30 15:41:00+03	2017-07-30 17:46:00+03
1234	PG0005	2017-08-01 15:40:00+03	2017-08-01 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-01 15:45:00+03	2017-08-01 17:50:00+03
1235	PG0005	2017-09-03 15:40:00+03	2017-09-03 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1236	PG0005	2017-08-22 15:40:00+03	2017-08-22 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1237	PG0005	2017-07-25 15:40:00+03	2017-07-25 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-25 15:40:00+03	2017-07-25 17:46:00+03
1238	PG0005	2017-08-27 15:40:00+03	2017-08-27 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1239	PG0005	2017-09-01 15:40:00+03	2017-09-01 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1240	PG0005	2017-07-23 15:40:00+03	2017-07-23 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-23 15:42:00+03	2017-07-23 17:46:00+03
1241	PG0005	2017-09-12 15:40:00+03	2017-09-12 17:45:00+03	DME	PKV	Cancelled	CN1	\N	\N
1242	PG0005	2017-08-08 15:40:00+03	2017-08-08 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-08 15:43:00+03	2017-08-08 17:48:00+03
1243	PG0005	2017-08-06 15:40:00+03	2017-08-06 17:45:00+03	DME	PKV	Arrived	CN1	2017-08-06 15:45:00+03	2017-08-06 17:49:00+03
1244	PG0005	2017-07-28 15:40:00+03	2017-07-28 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-28 15:43:00+03	2017-07-28 17:45:00+03
1245	PG0005	2017-08-18 15:40:00+03	2017-08-18 17:45:00+03	DME	PKV	Scheduled	CN1	\N	\N
1246	PG0005	2017-07-18 15:40:00+03	2017-07-18 17:45:00+03	DME	PKV	Arrived	CN1	2017-07-18 15:42:00+03	2017-07-18 17:48:00+03
1247	PG0168	2017-09-13 20:05:00+03	2017-09-14 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1248	PG0168	2017-09-11 20:05:00+03	2017-09-12 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1249	PG0168	2017-07-23 20:05:00+03	2017-07-24 04:55:00+03	DME	UUS	Arrived	319	2017-07-23 20:11:00+03	2017-07-24 05:00:00+03
1250	PG0168	2017-08-05 20:05:00+03	2017-08-06 04:55:00+03	DME	UUS	Arrived	319	2017-08-05 20:07:00+03	2017-08-06 04:50:00+03
1251	PG0168	2017-09-12 20:05:00+03	2017-09-13 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1252	PG0168	2017-07-17 20:05:00+03	2017-07-18 04:55:00+03	DME	UUS	Arrived	319	2017-07-17 20:05:00+03	2017-07-18 04:47:00+03
1253	PG0168	2017-07-18 20:05:00+03	2017-07-19 04:55:00+03	DME	UUS	Arrived	319	2017-07-18 20:08:00+03	2017-07-19 04:56:00+03
1254	PG0168	2017-07-27 20:05:00+03	2017-07-28 04:55:00+03	DME	UUS	Arrived	319	2017-07-27 20:09:00+03	2017-07-28 04:57:00+03
1255	PG0168	2017-07-28 20:05:00+03	2017-07-29 04:55:00+03	DME	UUS	Arrived	319	2017-07-28 20:12:00+03	2017-07-29 05:01:00+03
1256	PG0168	2017-08-28 20:05:00+03	2017-08-29 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1257	PG0168	2017-09-07 20:05:00+03	2017-09-08 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1258	PG0168	2017-08-11 20:05:00+03	2017-08-12 04:55:00+03	DME	UUS	Arrived	319	2017-08-11 20:08:00+03	2017-08-12 04:54:00+03
1259	PG0168	2017-08-04 20:05:00+03	2017-08-05 04:55:00+03	DME	UUS	Arrived	319	2017-08-04 20:12:00+03	2017-08-05 05:12:00+03
1260	PG0168	2017-08-03 20:05:00+03	2017-08-04 04:55:00+03	DME	UUS	Arrived	319	2017-08-03 20:05:00+03	2017-08-04 04:49:00+03
1261	PG0168	2017-08-26 20:05:00+03	2017-08-27 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1262	PG0168	2017-07-31 20:05:00+03	2017-08-01 04:55:00+03	DME	UUS	Arrived	319	2017-07-31 20:10:00+03	2017-08-01 05:06:00+03
1263	PG0168	2017-09-14 20:05:00+03	2017-09-15 04:55:00+03	DME	UUS	Cancelled	319	\N	\N
1264	PG0168	2017-08-25 20:05:00+03	2017-08-26 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1265	PG0168	2017-08-30 20:05:00+03	2017-08-31 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1266	PG0168	2017-07-20 20:05:00+03	2017-07-21 04:55:00+03	DME	UUS	Arrived	319	2017-07-20 20:08:00+03	2017-07-21 05:08:00+03
1267	PG0168	2017-07-29 20:05:00+03	2017-07-30 04:55:00+03	DME	UUS	Arrived	319	2017-07-29 20:09:00+03	2017-07-30 04:55:00+03
1268	PG0168	2017-08-21 20:05:00+03	2017-08-22 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1269	PG0168	2017-08-13 20:05:00+03	2017-08-14 04:55:00+03	DME	UUS	Arrived	319	2017-08-13 20:10:00+03	2017-08-14 04:57:00+03
1270	PG0168	2017-08-17 20:05:00+03	2017-08-18 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1271	PG0168	2017-08-29 20:05:00+03	2017-08-30 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1272	PG0168	2017-08-01 20:05:00+03	2017-08-02 04:55:00+03	DME	UUS	Arrived	319	2017-08-01 20:05:00+03	2017-08-02 05:01:00+03
1273	PG0168	2017-08-23 20:05:00+03	2017-08-24 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1274	PG0168	2017-07-21 20:05:00+03	2017-07-22 04:55:00+03	DME	UUS	Arrived	319	2017-07-21 20:08:00+03	2017-07-22 05:09:00+03
1275	PG0168	2017-08-27 20:05:00+03	2017-08-28 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1276	PG0168	2017-08-20 20:05:00+03	2017-08-21 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1277	PG0168	2017-08-02 20:05:00+03	2017-08-03 04:55:00+03	DME	UUS	Arrived	319	2017-08-02 20:06:00+03	2017-08-03 04:49:00+03
1278	PG0168	2017-08-06 20:05:00+03	2017-08-07 04:55:00+03	DME	UUS	Arrived	319	2017-08-06 20:10:00+03	2017-08-07 04:51:00+03
1279	PG0168	2017-08-16 20:05:00+03	2017-08-17 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1280	PG0168	2017-09-10 20:05:00+03	2017-09-11 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1281	PG0168	2017-08-08 20:05:00+03	2017-08-09 04:55:00+03	DME	UUS	Arrived	319	2017-08-08 20:09:00+03	2017-08-09 04:57:00+03
1282	PG0168	2017-09-02 20:05:00+03	2017-09-03 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1283	PG0168	2017-08-19 20:05:00+03	2017-08-20 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1284	PG0168	2017-07-30 20:05:00+03	2017-07-31 04:55:00+03	DME	UUS	Arrived	319	2017-07-30 20:08:00+03	2017-07-31 05:02:00+03
1285	PG0168	2017-09-08 20:05:00+03	2017-09-09 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1286	PG0168	2017-09-06 20:05:00+03	2017-09-07 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1287	PG0168	2017-07-16 20:05:00+03	2017-07-17 04:55:00+03	DME	UUS	Arrived	319	2017-07-16 20:08:00+03	2017-07-17 05:00:00+03
1288	PG0168	2017-08-22 20:05:00+03	2017-08-23 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1289	PG0168	2017-08-14 20:05:00+03	2017-08-15 04:55:00+03	DME	UUS	Arrived	319	2017-08-14 20:07:00+03	2017-08-15 04:53:00+03
1290	PG0168	2017-07-26 20:05:00+03	2017-07-27 04:55:00+03	DME	UUS	Arrived	319	2017-07-26 20:06:00+03	2017-07-27 04:50:00+03
1291	PG0168	2017-09-09 20:05:00+03	2017-09-10 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1292	PG0168	2017-09-01 20:05:00+03	2017-09-02 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1293	PG0168	2017-08-31 20:05:00+03	2017-09-01 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1294	PG0168	2017-07-24 20:05:00+03	2017-07-25 04:55:00+03	DME	UUS	Arrived	319	2017-07-24 20:06:00+03	2017-07-25 04:59:00+03
1295	PG0168	2017-07-22 20:05:00+03	2017-07-23 04:55:00+03	DME	UUS	Arrived	319	2017-07-22 20:07:00+03	2017-07-23 04:56:00+03
1296	PG0168	2017-08-09 20:05:00+03	2017-08-10 04:55:00+03	DME	UUS	Arrived	319	2017-08-09 20:09:00+03	2017-08-10 04:52:00+03
1297	PG0168	2017-09-03 20:05:00+03	2017-09-04 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1298	PG0168	2017-08-24 20:05:00+03	2017-08-25 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1299	PG0168	2017-09-04 20:05:00+03	2017-09-05 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1300	PG0168	2017-08-18 20:05:00+03	2017-08-19 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1301	PG0168	2017-08-10 20:05:00+03	2017-08-11 04:55:00+03	DME	UUS	Arrived	319	2017-08-10 20:09:00+03	2017-08-11 04:55:00+03
1302	PG0168	2017-07-19 20:05:00+03	2017-07-20 04:55:00+03	DME	UUS	Arrived	319	2017-07-19 20:07:00+03	2017-07-20 04:51:00+03
1303	PG0168	2017-08-07 20:05:00+03	2017-08-08 04:55:00+03	DME	UUS	Arrived	319	2017-08-07 20:07:00+03	2017-08-08 05:03:00+03
1304	PG0168	2017-08-15 20:05:00+03	2017-08-16 04:55:00+03	DME	UUS	On Time	319	\N	\N
1305	PG0168	2017-08-12 20:05:00+03	2017-08-13 04:55:00+03	DME	UUS	Arrived	319	2017-08-12 20:07:00+03	2017-08-13 04:55:00+03
1306	PG0168	2017-07-25 20:05:00+03	2017-07-26 04:55:00+03	DME	UUS	Arrived	319	2017-07-25 20:06:00+03	2017-07-26 04:54:00+03
1307	PG0168	2017-09-05 20:05:00+03	2017-09-06 04:55:00+03	DME	UUS	Scheduled	319	\N	\N
1308	PG0144	2017-07-29 17:45:00+03	2017-07-30 02:35:00+03	DME	PKC	Arrived	763	2017-07-29 17:47:00+03	2017-07-30 02:35:00+03
1309	PG0144	2017-09-04 17:45:00+03	2017-09-05 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1310	PG0144	2017-08-03 17:45:00+03	2017-08-04 02:35:00+03	DME	PKC	Arrived	763	2017-08-03 17:51:00+03	2017-08-04 02:37:00+03
1311	PG0144	2017-08-14 17:45:00+03	2017-08-15 02:35:00+03	DME	PKC	Arrived	763	2017-08-14 17:49:00+03	2017-08-15 02:40:00+03
1312	PG0144	2017-08-26 17:45:00+03	2017-08-27 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1313	PG0144	2017-07-22 17:45:00+03	2017-07-23 02:35:00+03	DME	PKC	Arrived	763	2017-07-22 17:51:00+03	2017-07-23 02:48:00+03
1314	PG0144	2017-07-31 17:45:00+03	2017-08-01 02:35:00+03	DME	PKC	Arrived	763	2017-07-31 17:47:00+03	2017-08-01 02:31:00+03
1315	PG0144	2017-07-17 17:45:00+03	2017-07-18 02:35:00+03	DME	PKC	Arrived	763	2017-07-17 17:46:00+03	2017-07-18 02:40:00+03
1316	PG0144	2017-09-14 17:45:00+03	2017-09-15 02:35:00+03	DME	PKC	Cancelled	763	\N	\N
1317	PG0144	2017-08-07 17:45:00+03	2017-08-08 02:35:00+03	DME	PKC	Arrived	763	2017-08-07 17:48:00+03	2017-08-08 02:41:00+03
1318	PG0144	2017-08-17 17:45:00+03	2017-08-18 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1319	PG0144	2017-07-27 17:45:00+03	2017-07-28 02:35:00+03	DME	PKC	Arrived	763	2017-07-27 17:48:00+03	2017-07-28 02:34:00+03
1320	PG0144	2017-09-09 17:45:00+03	2017-09-10 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1321	PG0144	2017-08-12 17:45:00+03	2017-08-13 02:35:00+03	DME	PKC	Arrived	763	2017-08-12 17:51:00+03	2017-08-13 02:40:00+03
1322	PG0144	2017-07-20 17:45:00+03	2017-07-21 02:35:00+03	DME	PKC	Arrived	763	2017-07-20 17:48:00+03	2017-07-21 02:38:00+03
1323	PG0144	2017-08-19 17:45:00+03	2017-08-20 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1324	PG0144	2017-08-10 17:45:00+03	2017-08-11 02:35:00+03	DME	PKC	Arrived	763	2017-08-10 17:47:00+03	2017-08-11 02:32:00+03
1325	PG0144	2017-08-31 17:45:00+03	2017-09-01 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1326	PG0144	2017-08-05 17:45:00+03	2017-08-06 02:35:00+03	DME	PKC	Arrived	763	2017-08-05 17:47:00+03	2017-08-06 02:33:00+03
1327	PG0144	2017-08-28 17:45:00+03	2017-08-29 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1328	PG0144	2017-09-02 17:45:00+03	2017-09-03 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1329	PG0144	2017-09-11 17:45:00+03	2017-09-12 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1330	PG0144	2017-08-24 17:45:00+03	2017-08-25 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1331	PG0144	2017-09-07 17:45:00+03	2017-09-08 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1332	PG0144	2017-07-24 17:45:00+03	2017-07-25 02:35:00+03	DME	PKC	Arrived	763	2017-07-24 17:47:00+03	2017-07-25 02:38:00+03
1333	PG0144	2017-08-21 17:45:00+03	2017-08-22 02:35:00+03	DME	PKC	Scheduled	763	\N	\N
1334	PG0519	2017-09-02 11:05:00+03	2017-09-02 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1335	PG0519	2017-07-29 11:05:00+03	2017-07-29 15:30:00+03	DME	ABA	Arrived	319	2017-07-29 11:08:00+03	2017-07-29 15:29:00+03
1336	PG0519	2017-08-26 11:05:00+03	2017-08-26 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1337	PG0519	2017-08-19 11:05:00+03	2017-08-19 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1338	PG0519	2017-08-15 11:05:00+03	2017-08-15 15:30:00+03	DME	ABA	Arrived	319	2017-08-15 11:10:00+03	2017-08-15 15:40:00+03
1339	PG0519	2017-08-01 11:05:00+03	2017-08-01 15:30:00+03	DME	ABA	Arrived	319	2017-08-01 11:06:00+03	2017-08-01 15:36:00+03
1340	PG0519	2017-08-29 11:05:00+03	2017-08-29 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1341	PG0519	2017-07-18 11:05:00+03	2017-07-18 15:30:00+03	DME	ABA	Arrived	319	2017-07-18 11:08:00+03	2017-07-18 15:32:00+03
1342	PG0519	2017-08-05 11:05:00+03	2017-08-05 15:30:00+03	DME	ABA	Arrived	319	2017-08-05 11:08:00+03	2017-08-05 15:37:00+03
1343	PG0519	2017-08-12 11:05:00+03	2017-08-12 15:30:00+03	DME	ABA	Arrived	319	2017-08-12 11:07:00+03	2017-08-12 15:30:00+03
1344	PG0519	2017-07-25 11:05:00+03	2017-07-25 15:30:00+03	DME	ABA	Arrived	319	2017-07-25 11:09:00+03	2017-07-25 15:32:00+03
1345	PG0519	2017-07-22 11:05:00+03	2017-07-22 15:30:00+03	DME	ABA	Arrived	319	2017-07-22 11:12:00+03	2017-07-22 15:40:00+03
1346	PG0519	2017-09-05 11:05:00+03	2017-09-05 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1347	PG0519	2017-09-12 11:05:00+03	2017-09-12 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1348	PG0519	2017-09-09 11:05:00+03	2017-09-09 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1349	PG0519	2017-08-22 11:05:00+03	2017-08-22 15:30:00+03	DME	ABA	Scheduled	319	\N	\N
1350	PG0519	2017-08-08 11:05:00+03	2017-08-08 15:30:00+03	DME	ABA	Arrived	319	2017-08-08 11:07:00+03	2017-08-08 15:33:00+03
1351	PG0164	2017-09-01 15:25:00+03	2017-09-01 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1352	PG0164	2017-08-12 15:25:00+03	2017-08-12 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-12 15:26:00+03	2017-08-12 18:35:00+03
1353	PG0164	2017-07-21 15:25:00+03	2017-07-21 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-21 15:29:00+03	2017-07-21 18:37:00+03
1354	PG0164	2017-08-17 15:25:00+03	2017-08-17 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1355	PG0164	2017-09-09 15:25:00+03	2017-09-09 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1356	PG0164	2017-08-19 15:25:00+03	2017-08-19 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1357	PG0164	2017-07-19 15:25:00+03	2017-07-19 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-19 15:28:00+03	2017-07-19 18:35:00+03
1358	PG0164	2017-08-16 15:25:00+03	2017-08-16 18:35:00+03	DME	NUX	On Time	SU9	\N	\N
1359	PG0164	2017-09-14 15:25:00+03	2017-09-14 18:35:00+03	DME	NUX	Cancelled	SU9	\N	\N
1360	PG0164	2017-09-07 15:25:00+03	2017-09-07 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1361	PG0164	2017-07-22 15:25:00+03	2017-07-22 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-22 18:12:00+03	2017-07-22 21:22:00+03
1362	PG0164	2017-09-03 15:25:00+03	2017-09-03 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1363	PG0164	2017-09-12 15:25:00+03	2017-09-12 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1364	PG0164	2017-09-11 15:25:00+03	2017-09-11 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1365	PG0164	2017-07-18 15:25:00+03	2017-07-18 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-18 15:27:00+03	2017-07-18 18:36:00+03
1366	PG0164	2017-08-29 15:25:00+03	2017-08-29 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1367	PG0164	2017-07-28 15:25:00+03	2017-07-28 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-28 15:28:00+03	2017-07-28 18:38:00+03
1368	PG0164	2017-07-16 15:25:00+03	2017-07-16 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-16 15:28:00+03	2017-07-16 18:39:00+03
1369	PG0164	2017-08-30 15:25:00+03	2017-08-30 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1370	PG0164	2017-08-20 15:25:00+03	2017-08-20 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1371	PG0164	2017-08-08 15:25:00+03	2017-08-08 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-08 15:30:00+03	2017-08-08 18:38:00+03
1372	PG0164	2017-07-31 15:25:00+03	2017-07-31 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-31 15:28:00+03	2017-07-31 18:38:00+03
1373	PG0164	2017-09-02 15:25:00+03	2017-09-02 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1374	PG0164	2017-07-30 15:25:00+03	2017-07-30 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-30 15:26:00+03	2017-07-30 18:37:00+03
1375	PG0164	2017-08-02 15:25:00+03	2017-08-02 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-02 15:26:00+03	2017-08-02 18:35:00+03
1376	PG0164	2017-09-06 15:25:00+03	2017-09-06 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1377	PG0164	2017-08-14 15:25:00+03	2017-08-14 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-14 15:29:00+03	2017-08-14 18:40:00+03
1378	PG0164	2017-08-31 15:25:00+03	2017-08-31 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1379	PG0164	2017-09-10 15:25:00+03	2017-09-10 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1380	PG0164	2017-08-22 15:25:00+03	2017-08-22 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1381	PG0164	2017-07-26 15:25:00+03	2017-07-26 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-26 15:30:00+03	2017-07-26 18:40:00+03
1382	PG0164	2017-08-27 15:25:00+03	2017-08-27 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1383	PG0164	2017-08-18 15:25:00+03	2017-08-18 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1384	PG0164	2017-07-24 15:25:00+03	2017-07-24 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-24 15:26:00+03	2017-07-24 18:38:00+03
1385	PG0164	2017-08-09 15:25:00+03	2017-08-09 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-09 15:27:00+03	2017-08-09 18:34:00+03
1386	PG0164	2017-08-24 15:25:00+03	2017-08-24 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1387	PG0164	2017-09-08 15:25:00+03	2017-09-08 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1388	PG0164	2017-08-10 15:25:00+03	2017-08-10 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-10 15:27:00+03	2017-08-10 18:40:00+03
1389	PG0164	2017-08-26 15:25:00+03	2017-08-26 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1390	PG0164	2017-08-15 15:25:00+03	2017-08-15 18:35:00+03	DME	NUX	Departed	SU9	2017-08-15 15:32:00+03	\N
1391	PG0164	2017-08-07 15:25:00+03	2017-08-07 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-07 15:29:00+03	2017-08-07 18:37:00+03
1392	PG0164	2017-09-05 15:25:00+03	2017-09-05 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1393	PG0164	2017-07-17 15:25:00+03	2017-07-17 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-17 15:29:00+03	2017-07-17 18:42:00+03
1394	PG0164	2017-08-05 15:25:00+03	2017-08-05 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-05 15:30:00+03	2017-08-05 18:38:00+03
1395	PG0164	2017-07-20 15:25:00+03	2017-07-20 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-20 15:27:00+03	2017-07-20 18:34:00+03
1396	PG0164	2017-07-23 15:25:00+03	2017-07-23 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-23 15:27:00+03	2017-07-23 18:37:00+03
1397	PG0164	2017-07-27 15:25:00+03	2017-07-27 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-27 15:28:00+03	2017-07-27 18:36:00+03
1398	PG0164	2017-07-25 15:25:00+03	2017-07-25 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-25 15:27:00+03	2017-07-25 18:38:00+03
1399	PG0164	2017-09-04 15:25:00+03	2017-09-04 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1400	PG0164	2017-08-11 15:25:00+03	2017-08-11 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-11 15:27:00+03	2017-08-11 18:37:00+03
1401	PG0164	2017-08-04 15:25:00+03	2017-08-04 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-04 15:30:00+03	2017-08-04 18:38:00+03
1402	PG0164	2017-08-25 15:25:00+03	2017-08-25 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1403	PG0164	2017-08-13 15:25:00+03	2017-08-13 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-13 15:31:00+03	2017-08-13 18:38:00+03
1404	PG0164	2017-08-28 15:25:00+03	2017-08-28 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1405	PG0164	2017-08-21 15:25:00+03	2017-08-21 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1406	PG0164	2017-08-06 15:25:00+03	2017-08-06 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-06 15:29:00+03	2017-08-06 18:41:00+03
1407	PG0164	2017-08-03 15:25:00+03	2017-08-03 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-03 15:31:00+03	2017-08-03 18:43:00+03
1408	PG0164	2017-07-29 15:25:00+03	2017-07-29 18:35:00+03	DME	NUX	Arrived	SU9	2017-07-29 19:53:00+03	2017-07-29 23:00:00+03
1409	PG0164	2017-08-01 15:25:00+03	2017-08-01 18:35:00+03	DME	NUX	Arrived	SU9	2017-08-01 18:53:00+03	2017-08-01 22:02:00+03
1410	PG0164	2017-09-13 15:25:00+03	2017-09-13 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1411	PG0164	2017-08-23 15:25:00+03	2017-08-23 18:35:00+03	DME	NUX	Scheduled	SU9	\N	\N
1412	PG0509	2017-07-21 09:15:00+03	2017-07-21 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-21 09:20:00+03	2017-07-21 10:50:00+03
1413	PG0509	2017-09-08 09:15:00+03	2017-09-08 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1414	PG0509	2017-08-09 09:15:00+03	2017-08-09 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-09 09:18:00+03	2017-08-09 10:47:00+03
1415	PG0509	2017-08-31 09:15:00+03	2017-08-31 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1416	PG0509	2017-08-05 09:15:00+03	2017-08-05 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-05 09:16:00+03	2017-08-05 10:47:00+03
1417	PG0509	2017-08-21 09:15:00+03	2017-08-21 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1418	PG0509	2017-08-02 09:15:00+03	2017-08-02 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-02 09:16:00+03	2017-08-02 10:47:00+03
1419	PG0509	2017-07-28 09:15:00+03	2017-07-28 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-28 09:18:00+03	2017-07-28 10:48:00+03
1420	PG0509	2017-07-23 09:15:00+03	2017-07-23 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-23 09:19:00+03	2017-07-23 10:49:00+03
1421	PG0509	2017-08-16 09:15:00+03	2017-08-16 10:45:00+03	DME	ESL	On Time	SU9	\N	\N
1422	PG0509	2017-08-28 09:15:00+03	2017-08-28 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1423	PG0509	2017-08-30 09:15:00+03	2017-08-30 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1424	PG0509	2017-07-31 09:15:00+03	2017-07-31 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-31 09:17:00+03	2017-07-31 10:48:00+03
1425	PG0509	2017-08-12 09:15:00+03	2017-08-12 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-12 09:16:00+03	2017-08-12 10:46:00+03
1426	PG0509	2017-08-29 09:15:00+03	2017-08-29 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1427	PG0509	2017-08-18 09:15:00+03	2017-08-18 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1428	PG0509	2017-09-12 09:15:00+03	2017-09-12 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1429	PG0509	2017-07-20 09:15:00+03	2017-07-20 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-20 09:17:00+03	2017-07-20 10:47:00+03
1430	PG0509	2017-07-17 09:15:00+03	2017-07-17 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-17 09:19:00+03	2017-07-17 10:50:00+03
1431	PG0509	2017-09-02 09:15:00+03	2017-09-02 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1432	PG0509	2017-08-14 09:15:00+03	2017-08-14 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-14 09:19:00+03	2017-08-14 10:49:00+03
1433	PG0509	2017-09-10 09:15:00+03	2017-09-10 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1434	PG0509	2017-09-04 09:15:00+03	2017-09-04 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1435	PG0509	2017-07-25 09:15:00+03	2017-07-25 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-25 09:20:00+03	2017-07-25 10:50:00+03
1436	PG0509	2017-07-27 09:15:00+03	2017-07-27 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-27 09:15:00+03	2017-07-27 10:45:00+03
1437	PG0509	2017-08-15 09:15:00+03	2017-08-15 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-15 09:23:00+03	2017-08-15 10:53:00+03
1438	PG0509	2017-09-06 09:15:00+03	2017-09-06 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1439	PG0509	2017-08-06 09:15:00+03	2017-08-06 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-06 09:19:00+03	2017-08-06 10:49:00+03
1440	PG0509	2017-08-04 09:15:00+03	2017-08-04 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-04 09:16:00+03	2017-08-04 10:47:00+03
1441	PG0509	2017-08-10 09:15:00+03	2017-08-10 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-10 09:20:00+03	2017-08-10 10:51:00+03
1442	PG0509	2017-07-30 09:15:00+03	2017-07-30 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-30 09:17:00+03	2017-07-30 10:48:00+03
1443	PG0509	2017-07-19 09:15:00+03	2017-07-19 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-19 09:19:00+03	2017-07-19 10:49:00+03
1444	PG0509	2017-08-25 09:15:00+03	2017-08-25 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1445	PG0509	2017-08-08 09:15:00+03	2017-08-08 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-08 09:17:00+03	2017-08-08 10:46:00+03
1446	PG0509	2017-09-01 09:15:00+03	2017-09-01 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1447	PG0509	2017-09-03 09:15:00+03	2017-09-03 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1448	PG0509	2017-09-09 09:15:00+03	2017-09-09 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1449	PG0509	2017-07-18 09:15:00+03	2017-07-18 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-18 09:19:00+03	2017-07-18 10:49:00+03
1450	PG0509	2017-08-13 09:15:00+03	2017-08-13 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-13 09:17:00+03	2017-08-13 10:47:00+03
1451	PG0509	2017-08-01 09:15:00+03	2017-08-01 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-01 09:15:00+03	2017-08-01 10:44:00+03
1452	PG0509	2017-07-16 09:15:00+03	2017-07-16 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-16 09:20:00+03	2017-07-16 10:50:00+03
1453	PG0509	2017-08-07 09:15:00+03	2017-08-07 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-07 09:18:00+03	2017-08-07 10:48:00+03
1454	PG0509	2017-07-22 09:15:00+03	2017-07-22 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-22 09:20:00+03	2017-07-22 10:49:00+03
1455	PG0509	2017-08-23 09:15:00+03	2017-08-23 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1456	PG0509	2017-09-13 09:15:00+03	2017-09-13 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1457	PG0509	2017-08-19 09:15:00+03	2017-08-19 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1458	PG0509	2017-07-24 09:15:00+03	2017-07-24 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-24 09:18:00+03	2017-07-24 10:46:00+03
1459	PG0509	2017-08-24 09:15:00+03	2017-08-24 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1460	PG0509	2017-09-14 09:15:00+03	2017-09-14 10:45:00+03	DME	ESL	Cancelled	SU9	\N	\N
1461	PG0509	2017-09-11 09:15:00+03	2017-09-11 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1462	PG0509	2017-07-26 09:15:00+03	2017-07-26 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-26 09:17:00+03	2017-07-26 10:47:00+03
1463	PG0509	2017-09-07 09:15:00+03	2017-09-07 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1464	PG0509	2017-08-20 09:15:00+03	2017-08-20 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1465	PG0509	2017-08-27 09:15:00+03	2017-08-27 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1466	PG0509	2017-08-03 09:15:00+03	2017-08-03 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-03 09:18:00+03	2017-08-03 10:48:00+03
1467	PG0509	2017-08-11 09:15:00+03	2017-08-11 10:45:00+03	DME	ESL	Arrived	SU9	2017-08-11 09:20:00+03	2017-08-11 10:49:00+03
1468	PG0509	2017-08-26 09:15:00+03	2017-08-26 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1469	PG0509	2017-07-29 09:15:00+03	2017-07-29 10:45:00+03	DME	ESL	Arrived	SU9	2017-07-29 09:20:00+03	2017-07-29 10:50:00+03
1470	PG0509	2017-08-17 09:15:00+03	2017-08-17 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1471	PG0509	2017-08-22 09:15:00+03	2017-08-22 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1472	PG0509	2017-09-05 09:15:00+03	2017-09-05 10:45:00+03	DME	ESL	Scheduled	SU9	\N	\N
1473	PG0709	2017-08-28 20:20:00+03	2017-08-29 03:00:00+03	DME	CNN	Scheduled	319	\N	\N
1474	PG0709	2017-07-31 20:20:00+03	2017-08-01 03:00:00+03	DME	CNN	Arrived	319	2017-07-31 20:22:00+03	2017-08-01 03:07:00+03
1475	PG0709	2017-08-07 20:20:00+03	2017-08-08 03:00:00+03	DME	CNN	Arrived	319	2017-08-07 20:24:00+03	2017-08-08 03:03:00+03
1476	PG0709	2017-09-11 20:20:00+03	2017-09-12 03:00:00+03	DME	CNN	Scheduled	319	\N	\N
1477	PG0709	2017-08-21 20:20:00+03	2017-08-22 03:00:00+03	DME	CNN	Scheduled	319	\N	\N
1478	PG0709	2017-07-17 20:20:00+03	2017-07-18 03:00:00+03	DME	CNN	Arrived	319	2017-07-17 20:26:00+03	2017-07-18 03:05:00+03
1479	PG0709	2017-07-24 20:20:00+03	2017-07-25 03:00:00+03	DME	CNN	Arrived	319	2017-07-24 20:23:00+03	2017-07-25 03:00:00+03
1480	PG0709	2017-09-04 20:20:00+03	2017-09-05 03:00:00+03	DME	CNN	Scheduled	319	\N	\N
1481	PG0709	2017-08-14 20:20:00+03	2017-08-15 03:00:00+03	DME	CNN	Arrived	319	2017-08-14 20:21:00+03	2017-08-15 03:01:00+03
1482	PG0210	2017-08-07 18:00:00+03	2017-08-07 19:50:00+03	DME	MRV	Arrived	733	2017-08-07 18:05:00+03	2017-08-07 19:53:00+03
1483	PG0210	2017-08-08 18:00:00+03	2017-08-08 19:50:00+03	DME	MRV	Arrived	733	2017-08-08 21:22:00+03	2017-08-08 23:14:00+03
1484	PG0210	2017-08-12 18:00:00+03	2017-08-12 19:50:00+03	DME	MRV	Arrived	733	2017-08-12 18:03:00+03	2017-08-12 19:54:00+03
1485	PG0210	2017-09-12 18:00:00+03	2017-09-12 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1486	PG0210	2017-07-19 18:00:00+03	2017-07-19 19:50:00+03	DME	MRV	Arrived	733	2017-07-19 18:04:00+03	2017-07-19 19:54:00+03
1487	PG0210	2017-08-01 18:00:00+03	2017-08-01 19:50:00+03	DME	MRV	Arrived	733	2017-08-01 18:06:00+03	2017-08-01 19:56:00+03
1488	PG0210	2017-09-08 18:00:00+03	2017-09-08 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1489	PG0210	2017-08-16 18:00:00+03	2017-08-16 19:50:00+03	DME	MRV	On Time	733	\N	\N
1490	PG0210	2017-08-03 18:00:00+03	2017-08-03 19:50:00+03	DME	MRV	Arrived	733	2017-08-03 18:03:00+03	2017-08-03 19:53:00+03
1491	PG0210	2017-07-28 18:00:00+03	2017-07-28 19:50:00+03	DME	MRV	Arrived	733	2017-07-28 18:04:00+03	2017-07-28 19:54:00+03
1492	PG0210	2017-08-22 18:00:00+03	2017-08-22 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1493	PG0210	2017-07-27 18:00:00+03	2017-07-27 19:50:00+03	DME	MRV	Arrived	733	2017-07-27 18:03:00+03	2017-07-27 19:54:00+03
1494	PG0210	2017-07-18 18:00:00+03	2017-07-18 19:50:00+03	DME	MRV	Arrived	733	2017-07-18 18:07:00+03	2017-07-18 19:58:00+03
1495	PG0210	2017-07-25 18:00:00+03	2017-07-25 19:50:00+03	DME	MRV	Arrived	733	2017-07-25 18:05:00+03	2017-07-25 19:54:00+03
1496	PG0210	2017-09-13 18:00:00+03	2017-09-13 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1497	PG0210	2017-08-19 18:00:00+03	2017-08-19 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1498	PG0210	2017-08-04 18:00:00+03	2017-08-04 19:50:00+03	DME	MRV	Arrived	733	2017-08-04 18:02:00+03	2017-08-04 19:53:00+03
1499	PG0210	2017-07-21 18:00:00+03	2017-07-21 19:50:00+03	DME	MRV	Arrived	733	2017-07-21 18:01:00+03	2017-07-21 19:50:00+03
1500	PG0210	2017-09-03 18:00:00+03	2017-09-03 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1501	PG0210	2017-07-29 18:00:00+03	2017-07-29 19:50:00+03	DME	MRV	Arrived	733	2017-07-29 18:05:00+03	2017-07-29 19:56:00+03
1502	PG0210	2017-07-17 18:00:00+03	2017-07-17 19:50:00+03	DME	MRV	Arrived	733	2017-07-17 18:03:00+03	2017-07-17 19:53:00+03
1503	PG0210	2017-08-15 18:00:00+03	2017-08-15 19:50:00+03	DME	MRV	On Time	733	\N	\N
1504	PG0210	2017-09-09 18:00:00+03	2017-09-09 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1505	PG0210	2017-08-29 18:00:00+03	2017-08-29 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1506	PG0210	2017-09-04 18:00:00+03	2017-09-04 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1507	PG0210	2017-08-18 18:00:00+03	2017-08-18 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1508	PG0210	2017-07-20 18:00:00+03	2017-07-20 19:50:00+03	DME	MRV	Arrived	733	2017-07-20 18:05:00+03	2017-07-20 19:54:00+03
1509	PG0210	2017-08-17 18:00:00+03	2017-08-17 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1510	PG0210	2017-07-22 18:00:00+03	2017-07-22 19:50:00+03	DME	MRV	Arrived	733	2017-07-22 18:03:00+03	2017-07-22 19:53:00+03
1511	PG0210	2017-08-25 18:00:00+03	2017-08-25 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1512	PG0210	2017-08-11 18:00:00+03	2017-08-11 19:50:00+03	DME	MRV	Arrived	733	2017-08-11 18:05:00+03	2017-08-11 19:54:00+03
1513	PG0210	2017-08-28 18:00:00+03	2017-08-28 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1514	PG0210	2017-08-05 18:00:00+03	2017-08-05 19:50:00+03	DME	MRV	Arrived	733	2017-08-05 18:01:00+03	2017-08-05 19:52:00+03
1515	PG0210	2017-08-10 18:00:00+03	2017-08-10 19:50:00+03	DME	MRV	Arrived	733	2017-08-10 18:04:00+03	2017-08-10 19:53:00+03
1516	PG0210	2017-09-01 18:00:00+03	2017-09-01 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1517	PG0210	2017-08-20 18:00:00+03	2017-08-20 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1518	PG0210	2017-07-23 18:00:00+03	2017-07-23 19:50:00+03	DME	MRV	Arrived	733	2017-07-23 18:03:00+03	2017-07-23 19:52:00+03
1519	PG0210	2017-09-07 18:00:00+03	2017-09-07 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1520	PG0210	2017-09-10 18:00:00+03	2017-09-10 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1521	PG0210	2017-07-16 18:00:00+03	2017-07-16 19:50:00+03	DME	MRV	Arrived	733	2017-07-16 18:01:00+03	2017-07-16 19:50:00+03
1522	PG0210	2017-09-02 18:00:00+03	2017-09-02 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1523	PG0210	2017-08-23 18:00:00+03	2017-08-23 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1524	PG0210	2017-09-06 18:00:00+03	2017-09-06 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1525	PG0210	2017-08-02 18:00:00+03	2017-08-02 19:50:00+03	DME	MRV	Arrived	733	2017-08-02 18:07:00+03	2017-08-02 19:56:00+03
1526	PG0210	2017-07-26 18:00:00+03	2017-07-26 19:50:00+03	DME	MRV	Arrived	733	2017-07-26 18:03:00+03	2017-07-26 19:51:00+03
1527	PG0210	2017-08-14 18:00:00+03	2017-08-14 19:50:00+03	DME	MRV	Arrived	733	2017-08-14 18:03:00+03	2017-08-14 19:51:00+03
1528	PG0210	2017-08-26 18:00:00+03	2017-08-26 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1529	PG0210	2017-08-06 18:00:00+03	2017-08-06 19:50:00+03	DME	MRV	Arrived	733	2017-08-06 18:04:00+03	2017-08-06 19:54:00+03
1530	PG0210	2017-07-24 18:00:00+03	2017-07-24 19:50:00+03	DME	MRV	Arrived	733	2017-07-24 18:04:00+03	2017-07-24 19:53:00+03
1531	PG0210	2017-08-13 18:00:00+03	2017-08-13 19:50:00+03	DME	MRV	Arrived	733	2017-08-13 18:00:00+03	2017-08-13 19:52:00+03
1532	PG0210	2017-08-21 18:00:00+03	2017-08-21 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1533	PG0210	2017-08-27 18:00:00+03	2017-08-27 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1534	PG0210	2017-08-30 18:00:00+03	2017-08-30 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1535	PG0210	2017-09-14 18:00:00+03	2017-09-14 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1536	PG0210	2017-09-11 18:00:00+03	2017-09-11 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1537	PG0210	2017-08-09 18:00:00+03	2017-08-09 19:50:00+03	DME	MRV	Arrived	733	2017-08-09 18:07:00+03	2017-08-09 19:56:00+03
1538	PG0210	2017-08-31 18:00:00+03	2017-08-31 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1539	PG0210	2017-07-30 18:00:00+03	2017-07-30 19:50:00+03	DME	MRV	Arrived	733	2017-07-30 18:03:00+03	2017-07-30 19:52:00+03
1540	PG0210	2017-07-31 18:00:00+03	2017-07-31 19:50:00+03	DME	MRV	Arrived	733	2017-07-31 18:02:00+03	2017-07-31 19:51:00+03
1541	PG0210	2017-08-24 18:00:00+03	2017-08-24 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1542	PG0210	2017-09-05 18:00:00+03	2017-09-05 19:50:00+03	DME	MRV	Scheduled	733	\N	\N
1543	PG0124	2017-09-01 11:30:00+03	2017-09-01 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1544	PG0124	2017-09-12 11:30:00+03	2017-09-12 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1545	PG0124	2017-08-08 11:30:00+03	2017-08-08 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-08 11:35:00+03	2017-08-08 15:24:00+03
1546	PG0124	2017-08-04 11:30:00+03	2017-08-04 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-04 11:34:00+03	2017-08-04 15:24:00+03
1547	PG0124	2017-09-04 11:30:00+03	2017-09-04 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1548	PG0124	2017-07-18 11:30:00+03	2017-07-18 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-18 11:31:00+03	2017-07-18 15:22:00+03
1549	PG0124	2017-07-25 11:30:00+03	2017-07-25 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-25 11:33:00+03	2017-07-25 15:22:00+03
1550	PG0124	2017-08-02 11:30:00+03	2017-08-02 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-02 11:31:00+03	2017-08-02 15:22:00+03
1551	PG0124	2017-08-16 11:30:00+03	2017-08-16 15:20:00+03	DME	NSK	On Time	SU9	\N	\N
1552	PG0124	2017-07-20 11:30:00+03	2017-07-20 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-20 11:35:00+03	2017-07-20 15:20:00+03
1553	PG0124	2017-07-31 11:30:00+03	2017-07-31 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-31 11:32:00+03	2017-07-31 15:22:00+03
1554	PG0124	2017-07-24 11:30:00+03	2017-07-24 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-24 11:33:00+03	2017-07-24 15:23:00+03
1555	PG0124	2017-07-29 11:30:00+03	2017-07-29 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-29 11:33:00+03	2017-07-29 15:22:00+03
1556	PG0124	2017-08-21 11:30:00+03	2017-08-21 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1557	PG0124	2017-08-06 11:30:00+03	2017-08-06 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-06 11:35:00+03	2017-08-06 15:25:00+03
1558	PG0124	2017-07-21 11:30:00+03	2017-07-21 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-21 11:34:00+03	2017-07-21 15:24:00+03
1559	PG0124	2017-08-23 11:30:00+03	2017-08-23 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1560	PG0124	2017-09-09 11:30:00+03	2017-09-09 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1561	PG0124	2017-08-19 11:30:00+03	2017-08-19 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1562	PG0124	2017-08-17 11:30:00+03	2017-08-17 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1563	PG0124	2017-07-19 11:30:00+03	2017-07-19 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-19 11:31:00+03	2017-07-19 15:21:00+03
1564	PG0124	2017-08-27 11:30:00+03	2017-08-27 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1565	PG0124	2017-08-30 11:30:00+03	2017-08-30 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1566	PG0124	2017-07-22 11:30:00+03	2017-07-22 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-22 11:31:00+03	2017-07-22 15:22:00+03
1567	PG0124	2017-07-16 11:30:00+03	2017-07-16 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-16 11:31:00+03	2017-07-16 15:18:00+03
1568	PG0124	2017-09-07 11:30:00+03	2017-09-07 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1569	PG0124	2017-09-11 11:30:00+03	2017-09-11 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1570	PG0124	2017-08-09 11:30:00+03	2017-08-09 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-09 11:31:00+03	2017-08-09 15:21:00+03
1571	PG0124	2017-09-02 11:30:00+03	2017-09-02 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1572	PG0124	2017-08-03 11:30:00+03	2017-08-03 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-03 11:32:00+03	2017-08-03 15:22:00+03
1573	PG0124	2017-08-26 11:30:00+03	2017-08-26 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1574	PG0124	2017-08-13 11:30:00+03	2017-08-13 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-13 11:33:00+03	2017-08-13 15:26:00+03
1575	PG0124	2017-07-23 11:30:00+03	2017-07-23 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-23 11:37:00+03	2017-07-23 15:27:00+03
1576	PG0124	2017-08-15 11:30:00+03	2017-08-15 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-15 11:30:00+03	2017-08-15 15:22:00+03
1577	PG0124	2017-09-14 11:30:00+03	2017-09-14 15:20:00+03	DME	NSK	Cancelled	SU9	\N	\N
1578	PG0124	2017-08-07 11:30:00+03	2017-08-07 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-07 11:32:00+03	2017-08-07 15:21:00+03
1579	PG0124	2017-07-26 11:30:00+03	2017-07-26 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-26 11:33:00+03	2017-07-26 15:28:00+03
1580	PG0124	2017-09-05 11:30:00+03	2017-09-05 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1581	PG0124	2017-08-11 11:30:00+03	2017-08-11 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-11 11:35:00+03	2017-08-11 15:25:00+03
1582	PG0124	2017-07-28 11:30:00+03	2017-07-28 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-28 11:35:00+03	2017-07-28 15:29:00+03
1583	PG0124	2017-09-06 11:30:00+03	2017-09-06 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1584	PG0124	2017-09-08 11:30:00+03	2017-09-08 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1585	PG0124	2017-08-01 11:30:00+03	2017-08-01 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-01 11:32:00+03	2017-08-01 15:20:00+03
1586	PG0124	2017-08-14 11:30:00+03	2017-08-14 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-14 11:30:00+03	2017-08-14 15:22:00+03
1587	PG0124	2017-09-13 11:30:00+03	2017-09-13 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1588	PG0124	2017-08-29 11:30:00+03	2017-08-29 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1589	PG0124	2017-09-03 11:30:00+03	2017-09-03 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1590	PG0124	2017-08-24 11:30:00+03	2017-08-24 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1591	PG0124	2017-08-31 11:30:00+03	2017-08-31 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1592	PG0124	2017-07-30 11:30:00+03	2017-07-30 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-30 11:33:00+03	2017-07-30 15:25:00+03
1593	PG0124	2017-07-27 11:30:00+03	2017-07-27 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-27 11:32:00+03	2017-07-27 15:22:00+03
1594	PG0124	2017-08-05 11:30:00+03	2017-08-05 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-05 11:35:00+03	2017-08-05 15:26:00+03
1595	PG0124	2017-08-10 11:30:00+03	2017-08-10 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-10 11:30:00+03	2017-08-10 15:19:00+03
1596	PG0124	2017-08-12 11:30:00+03	2017-08-12 15:20:00+03	DME	NSK	Arrived	SU9	2017-08-12 11:32:00+03	2017-08-12 15:16:00+03
1597	PG0124	2017-08-18 11:30:00+03	2017-08-18 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1598	PG0124	2017-08-28 11:30:00+03	2017-08-28 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1599	PG0124	2017-07-17 11:30:00+03	2017-07-17 15:20:00+03	DME	NSK	Arrived	SU9	2017-07-17 11:32:00+03	2017-07-17 15:22:00+03
1600	PG0124	2017-08-25 11:30:00+03	2017-08-25 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1601	PG0124	2017-09-10 11:30:00+03	2017-09-10 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1602	PG0124	2017-08-22 11:30:00+03	2017-08-22 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1603	PG0124	2017-08-20 11:30:00+03	2017-08-20 15:20:00+03	DME	NSK	Scheduled	SU9	\N	\N
1604	PG0629	2017-08-06 13:15:00+03	2017-08-06 15:30:00+03	DME	USK	Arrived	CR2	2017-08-06 13:20:00+03	2017-08-06 15:36:00+03
1605	PG0629	2017-07-30 13:15:00+03	2017-07-30 15:30:00+03	DME	USK	Arrived	CR2	2017-07-30 13:19:00+03	2017-07-30 15:37:00+03
1606	PG0629	2017-08-20 13:15:00+03	2017-08-20 15:30:00+03	DME	USK	Scheduled	CR2	\N	\N
1607	PG0629	2017-08-27 13:15:00+03	2017-08-27 15:30:00+03	DME	USK	Scheduled	CR2	\N	\N
1608	PG0629	2017-07-23 13:15:00+03	2017-07-23 15:30:00+03	DME	USK	Arrived	CR2	2017-07-23 13:18:00+03	2017-07-23 15:34:00+03
1609	PG0629	2017-09-10 13:15:00+03	2017-09-10 15:30:00+03	DME	USK	Scheduled	CR2	\N	\N
1610	PG0629	2017-08-13 13:15:00+03	2017-08-13 15:30:00+03	DME	USK	Arrived	CR2	2017-08-13 13:18:00+03	2017-08-13 15:31:00+03
1611	PG0629	2017-07-16 13:15:00+03	2017-07-16 15:30:00+03	DME	USK	Arrived	CR2	2017-07-16 13:17:00+03	2017-07-16 15:31:00+03
1612	PG0629	2017-09-03 13:15:00+03	2017-09-03 15:30:00+03	DME	USK	Scheduled	CR2	\N	\N
1613	PG0112	2017-08-12 11:30:00+03	2017-08-12 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-12 11:32:00+03	2017-08-12 13:43:00+03
1614	PG0112	2017-07-17 11:30:00+03	2017-07-17 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-17 11:36:00+03	2017-07-17 13:47:00+03
1615	PG0112	2017-07-24 11:30:00+03	2017-07-24 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-24 11:31:00+03	2017-07-24 13:41:00+03
1616	PG0112	2017-07-27 11:30:00+03	2017-07-27 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-27 11:30:00+03	2017-07-27 13:41:00+03
1617	PG0112	2017-08-05 11:30:00+03	2017-08-05 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-05 11:36:00+03	2017-08-05 13:48:00+03
1618	PG0112	2017-09-02 11:30:00+03	2017-09-02 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1619	PG0112	2017-08-26 11:30:00+03	2017-08-26 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1620	PG0112	2017-08-14 11:30:00+03	2017-08-14 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-14 11:38:00+03	2017-08-14 13:47:00+03
1621	PG0112	2017-08-19 11:30:00+03	2017-08-19 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1622	PG0112	2017-07-20 11:30:00+03	2017-07-20 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-20 11:32:00+03	2017-07-20 13:43:00+03
1623	PG0112	2017-09-07 11:30:00+03	2017-09-07 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1624	PG0112	2017-08-07 11:30:00+03	2017-08-07 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-07 11:33:00+03	2017-08-07 13:44:00+03
1625	PG0112	2017-08-31 11:30:00+03	2017-08-31 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1626	PG0112	2017-09-09 11:30:00+03	2017-09-09 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1627	PG0112	2017-09-04 11:30:00+03	2017-09-04 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1628	PG0112	2017-09-11 11:30:00+03	2017-09-11 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1629	PG0112	2017-07-31 11:30:00+03	2017-07-31 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-31 11:31:00+03	2017-07-31 13:41:00+03
1630	PG0112	2017-08-28 11:30:00+03	2017-08-28 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1631	PG0112	2017-08-03 11:30:00+03	2017-08-03 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-03 11:34:00+03	2017-08-03 13:43:00+03
1632	PG0112	2017-08-10 11:30:00+03	2017-08-10 13:40:00+03	DME	NNM	Arrived	CR2	2017-08-10 11:32:00+03	2017-08-10 13:45:00+03
1633	PG0112	2017-09-14 11:30:00+03	2017-09-14 13:40:00+03	DME	NNM	Cancelled	CR2	\N	\N
1634	PG0112	2017-08-24 11:30:00+03	2017-08-24 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1635	PG0112	2017-07-22 11:30:00+03	2017-07-22 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-22 11:30:00+03	2017-07-22 13:39:00+03
1636	PG0112	2017-08-21 11:30:00+03	2017-08-21 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1637	PG0112	2017-07-29 11:30:00+03	2017-07-29 13:40:00+03	DME	NNM	Arrived	CR2	2017-07-29 11:32:00+03	2017-07-29 13:41:00+03
1638	PG0112	2017-08-17 11:30:00+03	2017-08-17 13:40:00+03	DME	NNM	Scheduled	CR2	\N	\N
1639	PG0095	2017-08-19 10:45:00+03	2017-08-19 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1640	PG0095	2017-08-05 10:45:00+03	2017-08-05 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-05 10:47:00+03	2017-08-05 13:00:00+03
1641	PG0095	2017-08-01 10:45:00+03	2017-08-01 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-01 10:48:00+03	2017-08-01 13:06:00+03
1642	PG0095	2017-07-22 10:45:00+03	2017-07-22 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-22 10:50:00+03	2017-07-22 13:03:00+03
1643	PG0095	2017-08-14 10:45:00+03	2017-08-14 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-14 10:47:00+03	2017-08-14 13:04:00+03
1644	PG0095	2017-07-18 10:45:00+03	2017-07-18 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-18 10:47:00+03	2017-07-18 13:02:00+03
1645	PG0095	2017-09-07 10:45:00+03	2017-09-07 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1646	PG0095	2017-07-24 10:45:00+03	2017-07-24 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-24 10:48:00+03	2017-07-24 13:05:00+03
1647	PG0095	2017-07-30 10:45:00+03	2017-07-30 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-30 10:49:00+03	2017-07-30 13:02:00+03
1648	PG0095	2017-08-26 10:45:00+03	2017-08-26 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1649	PG0095	2017-09-06 10:45:00+03	2017-09-06 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1650	PG0095	2017-08-07 10:45:00+03	2017-08-07 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-07 10:49:00+03	2017-08-07 13:06:00+03
1651	PG0095	2017-08-08 10:45:00+03	2017-08-08 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-08 10:48:00+03	2017-08-08 13:05:00+03
1652	PG0095	2017-08-27 10:45:00+03	2017-08-27 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1653	PG0095	2017-08-03 10:45:00+03	2017-08-03 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-03 10:45:00+03	2017-08-03 12:58:00+03
1654	PG0095	2017-07-16 10:45:00+03	2017-07-16 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-16 10:48:00+03	2017-07-16 13:04:00+03
1655	PG0095	2017-09-04 10:45:00+03	2017-09-04 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1656	PG0095	2017-07-31 10:45:00+03	2017-07-31 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-31 10:50:00+03	2017-07-31 13:04:00+03
1657	PG0095	2017-07-27 10:45:00+03	2017-07-27 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-27 10:48:00+03	2017-07-27 13:02:00+03
1658	PG0095	2017-08-15 10:45:00+03	2017-08-15 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-15 10:47:00+03	2017-08-15 13:01:00+03
1659	PG0095	2017-08-29 10:45:00+03	2017-08-29 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1660	PG0095	2017-09-14 10:45:00+03	2017-09-14 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1661	PG0095	2017-07-28 10:45:00+03	2017-07-28 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-28 10:46:00+03	2017-07-28 12:59:00+03
1662	PG0095	2017-08-22 10:45:00+03	2017-08-22 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1663	PG0095	2017-09-08 10:45:00+03	2017-09-08 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1664	PG0095	2017-07-17 10:45:00+03	2017-07-17 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-17 10:52:00+03	2017-07-17 13:07:00+03
1665	PG0095	2017-08-18 10:45:00+03	2017-08-18 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1666	PG0095	2017-08-28 10:45:00+03	2017-08-28 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1667	PG0095	2017-09-03 10:45:00+03	2017-09-03 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1668	PG0095	2017-08-20 10:45:00+03	2017-08-20 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1669	PG0095	2017-07-20 10:45:00+03	2017-07-20 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-20 10:45:00+03	2017-07-20 13:00:00+03
1670	PG0095	2017-08-31 10:45:00+03	2017-08-31 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1671	PG0095	2017-09-11 10:45:00+03	2017-09-11 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1672	PG0095	2017-07-26 10:45:00+03	2017-07-26 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-26 10:46:00+03	2017-07-26 13:02:00+03
1673	PG0095	2017-09-12 10:45:00+03	2017-09-12 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1674	PG0095	2017-09-02 10:45:00+03	2017-09-02 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1675	PG0095	2017-08-09 10:45:00+03	2017-08-09 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-09 10:47:00+03	2017-08-09 13:01:00+03
1676	PG0095	2017-08-04 10:45:00+03	2017-08-04 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-04 10:48:00+03	2017-08-04 13:03:00+03
1677	PG0095	2017-08-13 10:45:00+03	2017-08-13 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-13 14:15:00+03	2017-08-13 16:29:00+03
1678	PG0095	2017-08-12 10:45:00+03	2017-08-12 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-12 10:45:00+03	2017-08-12 13:00:00+03
1679	PG0095	2017-09-01 10:45:00+03	2017-09-01 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1680	PG0095	2017-09-13 10:45:00+03	2017-09-13 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1681	PG0095	2017-07-29 10:45:00+03	2017-07-29 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-29 10:50:00+03	2017-07-29 13:05:00+03
1682	PG0095	2017-09-09 10:45:00+03	2017-09-09 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1683	PG0095	2017-07-19 10:45:00+03	2017-07-19 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-19 10:49:00+03	2017-07-19 13:04:00+03
1684	PG0095	2017-08-16 10:45:00+03	2017-08-16 13:00:00+03	DME	URJ	On Time	SU9	\N	\N
1685	PG0095	2017-08-17 10:45:00+03	2017-08-17 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1686	PG0095	2017-09-05 10:45:00+03	2017-09-05 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1687	PG0095	2017-07-25 10:45:00+03	2017-07-25 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-25 13:53:00+03	2017-07-25 16:08:00+03
1688	PG0095	2017-08-10 10:45:00+03	2017-08-10 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-10 10:46:00+03	2017-08-10 13:00:00+03
1689	PG0095	2017-08-02 10:45:00+03	2017-08-02 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-02 10:45:00+03	2017-08-02 13:00:00+03
1690	PG0095	2017-08-30 10:45:00+03	2017-08-30 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1691	PG0095	2017-08-23 10:45:00+03	2017-08-23 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1692	PG0095	2017-08-21 10:45:00+03	2017-08-21 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1693	PG0095	2017-09-10 10:45:00+03	2017-09-10 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1694	PG0095	2017-08-11 10:45:00+03	2017-08-11 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-11 13:50:00+03	2017-08-11 16:07:00+03
1695	PG0095	2017-07-21 10:45:00+03	2017-07-21 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-21 10:47:00+03	2017-07-21 13:02:00+03
1696	PG0095	2017-08-25 10:45:00+03	2017-08-25 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1697	PG0095	2017-08-06 10:45:00+03	2017-08-06 13:00:00+03	DME	URJ	Arrived	SU9	2017-08-06 10:50:00+03	2017-08-06 13:05:00+03
1698	PG0095	2017-07-23 10:45:00+03	2017-07-23 13:00:00+03	DME	URJ	Arrived	SU9	2017-07-23 10:47:00+03	2017-07-23 13:01:00+03
1699	PG0095	2017-08-24 10:45:00+03	2017-08-24 13:00:00+03	DME	URJ	Scheduled	SU9	\N	\N
1700	PG0315	2017-08-14 17:40:00+03	2017-08-15 01:55:00+03	DME	DYR	Arrived	319	2017-08-14 17:41:00+03	2017-08-15 02:07:00+03
1701	PG0315	2017-07-31 17:40:00+03	2017-08-01 01:55:00+03	DME	DYR	Arrived	319	2017-07-31 17:41:00+03	2017-08-01 01:54:00+03
1702	PG0315	2017-07-17 17:40:00+03	2017-07-18 01:55:00+03	DME	DYR	Arrived	319	2017-07-17 17:44:00+03	2017-07-18 01:58:00+03
1703	PG0315	2017-09-04 17:40:00+03	2017-09-05 01:55:00+03	DME	DYR	Scheduled	319	\N	\N
1704	PG0315	2017-07-24 17:40:00+03	2017-07-25 01:55:00+03	DME	DYR	Arrived	319	2017-07-24 17:43:00+03	2017-07-25 02:00:00+03
1705	PG0315	2017-09-11 17:40:00+03	2017-09-12 01:55:00+03	DME	DYR	Scheduled	319	\N	\N
1706	PG0315	2017-08-21 17:40:00+03	2017-08-22 01:55:00+03	DME	DYR	Scheduled	319	\N	\N
1707	PG0315	2017-08-28 17:40:00+03	2017-08-29 01:55:00+03	DME	DYR	Scheduled	319	\N	\N
1708	PG0315	2017-08-07 17:40:00+03	2017-08-08 01:55:00+03	DME	DYR	Arrived	319	2017-08-07 17:41:00+03	2017-08-08 01:55:00+03
1709	PG0239	2017-07-23 09:05:00+03	2017-07-23 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-23 09:07:00+03	2017-07-23 11:43:00+03
1710	PG0239	2017-09-01 09:05:00+03	2017-09-01 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1711	PG0239	2017-09-09 09:05:00+03	2017-09-09 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1712	PG0239	2017-08-11 09:05:00+03	2017-08-11 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-11 09:08:00+03	2017-08-11 11:41:00+03
1713	PG0239	2017-08-25 09:05:00+03	2017-08-25 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1714	PG0239	2017-08-14 09:05:00+03	2017-08-14 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-14 09:11:00+03	2017-08-14 11:45:00+03
1715	PG0239	2017-07-17 09:05:00+03	2017-07-17 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-17 09:07:00+03	2017-07-17 11:40:00+03
1716	PG0239	2017-07-27 09:05:00+03	2017-07-27 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-27 12:08:00+03	2017-07-27 14:44:00+03
1717	PG0239	2017-08-12 09:05:00+03	2017-08-12 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-12 09:10:00+03	2017-08-12 11:44:00+03
1718	PG0239	2017-08-20 09:05:00+03	2017-08-20 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1719	PG0239	2017-07-26 09:05:00+03	2017-07-26 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-26 09:13:00+03	2017-07-26 11:48:00+03
1720	PG0239	2017-08-10 09:05:00+03	2017-08-10 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-10 09:07:00+03	2017-08-10 11:44:00+03
1721	PG0239	2017-09-02 09:05:00+03	2017-09-02 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1722	PG0239	2017-09-14 09:05:00+03	2017-09-14 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1723	PG0239	2017-07-28 09:05:00+03	2017-07-28 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-28 09:08:00+03	2017-07-28 11:42:00+03
1724	PG0239	2017-08-21 09:05:00+03	2017-08-21 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1725	PG0239	2017-08-24 09:05:00+03	2017-08-24 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1726	PG0239	2017-07-25 09:05:00+03	2017-07-25 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-25 09:08:00+03	2017-07-25 11:41:00+03
1727	PG0239	2017-09-10 09:05:00+03	2017-09-10 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1728	PG0239	2017-08-09 09:05:00+03	2017-08-09 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-09 12:21:00+03	2017-08-09 14:54:00+03
1729	PG0239	2017-07-18 09:05:00+03	2017-07-18 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-18 09:08:00+03	2017-07-18 11:41:00+03
1730	PG0239	2017-08-27 09:05:00+03	2017-08-27 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1731	PG0239	2017-08-15 09:05:00+03	2017-08-15 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-15 09:08:00+03	2017-08-15 11:43:00+03
1732	PG0239	2017-09-08 09:05:00+03	2017-09-08 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1733	PG0239	2017-07-29 09:05:00+03	2017-07-29 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-29 09:07:00+03	2017-07-29 11:43:00+03
1734	PG0239	2017-08-30 09:05:00+03	2017-08-30 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1735	PG0239	2017-08-08 09:05:00+03	2017-08-08 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-08 09:07:00+03	2017-08-08 11:42:00+03
1736	PG0239	2017-09-03 09:05:00+03	2017-09-03 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1737	PG0239	2017-08-28 09:05:00+03	2017-08-28 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1738	PG0239	2017-07-19 09:05:00+03	2017-07-19 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-19 09:10:00+03	2017-07-19 11:45:00+03
1739	PG0239	2017-07-24 09:05:00+03	2017-07-24 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-24 12:37:00+03	2017-07-24 15:14:00+03
1740	PG0239	2017-08-07 09:05:00+03	2017-08-07 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-07 09:06:00+03	2017-08-07 11:40:00+03
1741	PG0239	2017-07-30 09:05:00+03	2017-07-30 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-30 09:07:00+03	2017-07-30 11:42:00+03
1742	PG0239	2017-08-19 09:05:00+03	2017-08-19 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1743	PG0239	2017-09-13 09:05:00+03	2017-09-13 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1744	PG0239	2017-08-31 09:05:00+03	2017-08-31 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1745	PG0239	2017-09-07 09:05:00+03	2017-09-07 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1746	PG0239	2017-08-16 09:05:00+03	2017-08-16 11:40:00+03	DME	HMA	On Time	SU9	\N	\N
1747	PG0239	2017-08-06 09:05:00+03	2017-08-06 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-06 09:06:00+03	2017-08-06 11:41:00+03
1748	PG0239	2017-08-26 09:05:00+03	2017-08-26 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1749	PG0239	2017-07-31 09:05:00+03	2017-07-31 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-31 09:08:00+03	2017-07-31 11:43:00+03
1750	PG0239	2017-07-20 09:05:00+03	2017-07-20 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-20 09:08:00+03	2017-07-20 11:42:00+03
1751	PG0239	2017-09-04 09:05:00+03	2017-09-04 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1752	PG0239	2017-08-23 09:05:00+03	2017-08-23 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1753	PG0239	2017-08-13 09:05:00+03	2017-08-13 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-13 09:09:00+03	2017-08-13 11:42:00+03
1754	PG0239	2017-08-05 09:05:00+03	2017-08-05 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-05 09:09:00+03	2017-08-05 11:45:00+03
1755	PG0239	2017-09-11 09:05:00+03	2017-09-11 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1756	PG0239	2017-08-01 09:05:00+03	2017-08-01 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-01 09:08:00+03	2017-08-01 11:43:00+03
1757	PG0239	2017-08-22 09:05:00+03	2017-08-22 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1758	PG0239	2017-08-04 09:05:00+03	2017-08-04 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-04 09:11:00+03	2017-08-04 11:48:00+03
1759	PG0239	2017-08-18 09:05:00+03	2017-08-18 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1760	PG0239	2017-07-21 09:05:00+03	2017-07-21 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-21 09:08:00+03	2017-07-21 11:43:00+03
1761	PG0239	2017-09-06 09:05:00+03	2017-09-06 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1762	PG0239	2017-08-17 09:05:00+03	2017-08-17 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1763	PG0239	2017-09-12 09:05:00+03	2017-09-12 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1764	PG0239	2017-07-16 09:05:00+03	2017-07-16 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-16 09:05:00+03	2017-07-16 11:39:00+03
1765	PG0239	2017-09-05 09:05:00+03	2017-09-05 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1766	PG0239	2017-08-29 09:05:00+03	2017-08-29 11:40:00+03	DME	HMA	Scheduled	SU9	\N	\N
1767	PG0239	2017-08-02 09:05:00+03	2017-08-02 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-02 09:09:00+03	2017-08-02 11:44:00+03
1768	PG0239	2017-08-03 09:05:00+03	2017-08-03 11:40:00+03	DME	HMA	Arrived	SU9	2017-08-03 09:07:00+03	2017-08-03 11:43:00+03
1769	PG0239	2017-07-22 09:05:00+03	2017-07-22 11:40:00+03	DME	HMA	Arrived	SU9	2017-07-22 09:10:00+03	2017-07-22 11:43:00+03
1770	PG0541	2017-09-13 11:15:00+03	2017-09-13 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1771	PG0542	2017-09-13 13:35:00+03	2017-09-13 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1772	PG0542	2017-08-19 13:35:00+03	2017-08-19 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1773	PG0541	2017-08-18 11:15:00+03	2017-08-18 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1774	PG0541	2017-08-28 11:15:00+03	2017-08-28 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1775	PG0541	2017-09-02 11:15:00+03	2017-09-02 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1776	PG0541	2017-08-31 11:15:00+03	2017-08-31 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1777	PG0542	2017-09-02 13:35:00+03	2017-09-02 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1778	PG0542	2017-08-22 13:35:00+03	2017-08-22 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1779	PG0541	2017-09-10 11:15:00+03	2017-09-10 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1780	PG0542	2017-08-28 13:35:00+03	2017-08-28 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1781	PG0541	2017-08-22 11:15:00+03	2017-08-22 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1782	PG0541	2017-08-30 11:15:00+03	2017-08-30 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1783	PG0542	2017-08-30 13:35:00+03	2017-08-30 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1784	PG0542	2017-09-09 13:35:00+03	2017-09-09 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1785	PG0542	2017-08-14 13:35:00+03	2017-08-14 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-14 13:37:00+03	2017-08-14 15:45:00+03
1786	PG0541	2017-08-14 11:15:00+03	2017-08-14 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-14 11:22:00+03	2017-08-14 13:31:00+03
1787	PG0541	2017-08-06 11:15:00+03	2017-08-06 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-06 11:15:00+03	2017-08-06 13:27:00+03
1788	PG0542	2017-08-07 13:35:00+03	2017-08-07 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-07 13:38:00+03	2017-08-07 15:50:00+03
1789	PG0542	2017-08-06 13:35:00+03	2017-08-06 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-06 13:36:00+03	2017-08-06 15:44:00+03
1790	PG0542	2017-08-23 13:35:00+03	2017-08-23 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1791	PG0541	2017-08-23 11:15:00+03	2017-08-23 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1792	PG0542	2017-07-30 13:35:00+03	2017-07-30 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-30 13:35:00+03	2017-07-30 15:43:00+03
1793	PG0541	2017-07-30 11:15:00+03	2017-07-30 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-30 11:21:00+03	2017-07-30 13:30:00+03
1794	PG0542	2017-08-31 13:35:00+03	2017-08-31 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1795	PG0541	2017-08-07 11:15:00+03	2017-08-07 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-07 11:16:00+03	2017-08-07 13:26:00+03
1796	PG0542	2017-07-16 13:35:00+03	2017-07-16 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-16 13:41:00+03	2017-07-16 15:50:00+03
1797	PG0542	2017-07-17 13:35:00+03	2017-07-17 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-17 13:39:00+03	2017-07-17 15:51:00+03
1798	PG0541	2017-07-17 11:15:00+03	2017-07-17 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-17 11:19:00+03	2017-07-17 13:30:00+03
1799	PG0542	2017-07-19 13:35:00+03	2017-07-19 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-19 13:38:00+03	2017-07-19 15:49:00+03
1800	PG0541	2017-07-19 11:15:00+03	2017-07-19 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-19 11:17:00+03	2017-07-19 13:26:00+03
1801	PG0542	2017-09-06 13:35:00+03	2017-09-06 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1802	PG0541	2017-09-09 11:15:00+03	2017-09-09 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1803	PG0541	2017-07-20 11:15:00+03	2017-07-20 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-20 11:17:00+03	2017-07-20 13:26:00+03
1804	PG0541	2017-07-22 11:15:00+03	2017-07-22 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-22 11:19:00+03	2017-07-22 13:31:00+03
1805	PG0542	2017-07-20 13:35:00+03	2017-07-20 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-20 13:38:00+03	2017-07-20 15:48:00+03
1806	PG0541	2017-09-06 11:15:00+03	2017-09-06 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1807	PG0542	2017-07-22 13:35:00+03	2017-07-22 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-22 13:37:00+03	2017-07-22 15:46:00+03
1808	PG0542	2017-09-10 13:35:00+03	2017-09-10 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1809	PG0541	2017-07-28 11:15:00+03	2017-07-28 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-28 11:17:00+03	2017-07-28 13:28:00+03
1810	PG0541	2017-09-04 11:15:00+03	2017-09-04 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1811	PG0542	2017-08-01 13:35:00+03	2017-08-01 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-01 13:38:00+03	2017-08-01 15:48:00+03
1812	PG0542	2017-09-04 13:35:00+03	2017-09-04 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1813	PG0541	2017-08-26 11:15:00+03	2017-08-26 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1814	PG0541	2017-08-01 11:15:00+03	2017-08-01 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-01 11:16:00+03	2017-08-01 13:27:00+03
1815	PG0542	2017-07-28 13:35:00+03	2017-07-28 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-28 13:36:00+03	2017-07-28 15:46:00+03
1816	PG0542	2017-09-03 13:35:00+03	2017-09-03 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1817	PG0542	2017-07-27 13:35:00+03	2017-07-27 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-27 13:38:00+03	2017-07-27 15:47:00+03
1818	PG0541	2017-07-27 11:15:00+03	2017-07-27 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-27 11:19:00+03	2017-07-27 13:29:00+03
1819	PG0541	2017-07-16 11:15:00+03	2017-07-16 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-16 11:18:00+03	2017-07-16 13:27:00+03
1820	PG0541	2017-09-14 11:15:00+03	2017-09-14 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1821	PG0541	2017-07-24 11:15:00+03	2017-07-24 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-24 11:19:00+03	2017-07-24 13:28:00+03
1822	PG0541	2017-09-03 11:15:00+03	2017-09-03 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1823	PG0542	2017-09-14 13:35:00+03	2017-09-14 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1824	PG0542	2017-08-26 13:35:00+03	2017-08-26 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1825	PG0542	2017-08-08 13:35:00+03	2017-08-08 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-08 13:36:00+03	2017-08-08 15:46:00+03
1826	PG0541	2017-07-25 11:15:00+03	2017-07-25 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-25 14:29:00+03	2017-07-25 16:40:00+03
1827	PG0542	2017-07-24 13:35:00+03	2017-07-24 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-24 13:39:00+03	2017-07-24 15:50:00+03
1828	PG0541	2017-08-08 11:15:00+03	2017-08-08 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-08 11:21:00+03	2017-08-08 13:32:00+03
1829	PG0542	2017-07-25 13:35:00+03	2017-07-25 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-25 13:36:00+03	2017-07-25 15:48:00+03
1830	PG0541	2017-08-19 11:15:00+03	2017-08-19 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1831	PG0542	2017-09-08 13:35:00+03	2017-09-08 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1832	PG0541	2017-08-15 11:15:00+03	2017-08-15 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-15 11:18:00+03	2017-08-15 13:29:00+03
1833	PG0541	2017-08-02 11:15:00+03	2017-08-02 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-02 11:17:00+03	2017-08-02 13:26:00+03
1834	PG0542	2017-08-02 13:35:00+03	2017-08-02 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-02 13:39:00+03	2017-08-02 15:49:00+03
1835	PG0541	2017-09-01 11:15:00+03	2017-09-01 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1836	PG0542	2017-09-01 13:35:00+03	2017-09-01 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1837	PG0542	2017-08-25 13:35:00+03	2017-08-25 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1838	PG0541	2017-08-25 11:15:00+03	2017-08-25 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1839	PG0541	2017-08-12 11:15:00+03	2017-08-12 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-12 11:18:00+03	2017-08-12 13:26:00+03
1840	PG0542	2017-08-12 13:35:00+03	2017-08-12 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-12 13:35:00+03	2017-08-12 15:44:00+03
1841	PG0542	2017-08-10 13:35:00+03	2017-08-10 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-10 13:36:00+03	2017-08-10 15:47:00+03
1842	PG0541	2017-08-10 11:15:00+03	2017-08-10 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-10 11:20:00+03	2017-08-10 13:31:00+03
1843	PG0542	2017-08-04 13:35:00+03	2017-08-04 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-04 16:36:00+03	2017-08-04 18:45:00+03
1844	PG0542	2017-07-18 13:35:00+03	2017-07-18 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-18 13:41:00+03	2017-07-18 15:50:00+03
1845	PG0541	2017-08-04 11:15:00+03	2017-08-04 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-04 11:17:00+03	2017-08-04 13:25:00+03
1846	PG0541	2017-07-18 11:15:00+03	2017-07-18 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-18 11:19:00+03	2017-07-18 13:27:00+03
1847	PG0541	2017-07-26 11:15:00+03	2017-07-26 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-26 11:19:00+03	2017-07-26 13:30:00+03
1848	PG0541	2017-08-09 11:15:00+03	2017-08-09 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-09 11:18:00+03	2017-08-09 13:28:00+03
1849	PG0542	2017-08-09 13:35:00+03	2017-08-09 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-09 13:40:00+03	2017-08-09 15:50:00+03
1850	PG0542	2017-07-29 13:35:00+03	2017-07-29 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-29 13:39:00+03	2017-07-29 15:48:00+03
1851	PG0541	2017-07-29 11:15:00+03	2017-07-29 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-29 11:16:00+03	2017-07-29 13:25:00+03
1852	PG0541	2017-07-23 11:15:00+03	2017-07-23 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-23 11:20:00+03	2017-07-23 13:29:00+03
1853	PG0542	2017-07-26 13:35:00+03	2017-07-26 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-26 13:39:00+03	2017-07-26 15:48:00+03
1854	PG0542	2017-07-21 13:35:00+03	2017-07-21 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-21 13:35:00+03	2017-07-21 15:47:00+03
1855	PG0541	2017-07-21 11:15:00+03	2017-07-21 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-21 11:16:00+03	2017-07-21 13:25:00+03
1856	PG0542	2017-08-05 13:35:00+03	2017-08-05 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-05 13:36:00+03	2017-08-05 15:47:00+03
1857	PG0541	2017-08-05 11:15:00+03	2017-08-05 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-05 11:20:00+03	2017-08-05 13:32:00+03
1858	PG0542	2017-09-07 13:35:00+03	2017-09-07 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1859	PG0541	2017-09-05 11:15:00+03	2017-09-05 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1860	PG0541	2017-09-07 11:15:00+03	2017-09-07 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1861	PG0542	2017-08-29 13:35:00+03	2017-08-29 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1862	PG0541	2017-08-29 11:15:00+03	2017-08-29 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1863	PG0542	2017-08-17 13:35:00+03	2017-08-17 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1864	PG0542	2017-09-05 13:35:00+03	2017-09-05 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1865	PG0541	2017-08-17 11:15:00+03	2017-08-17 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1866	PG0541	2017-08-21 11:15:00+03	2017-08-21 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1867	PG0542	2017-08-11 13:35:00+03	2017-08-11 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-11 13:40:00+03	2017-08-11 15:52:00+03
1868	PG0542	2017-08-13 13:35:00+03	2017-08-13 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-13 13:35:00+03	2017-08-13 15:45:00+03
1869	PG0542	2017-07-23 13:35:00+03	2017-07-23 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-23 13:39:00+03	2017-07-23 15:50:00+03
1870	PG0541	2017-08-11 11:15:00+03	2017-08-11 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-11 11:18:00+03	2017-08-11 13:27:00+03
1871	PG0542	2017-08-15 13:35:00+03	2017-08-15 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-15 13:39:00+03	2017-08-15 15:50:00+03
1872	PG0541	2017-08-16 11:15:00+03	2017-08-16 13:25:00+03	DME	OVS	On Time	SU9	\N	\N
1873	PG0542	2017-08-16 13:35:00+03	2017-08-16 15:45:00+03	DME	OVS	On Time	SU9	\N	\N
1874	PG0542	2017-08-20 13:35:00+03	2017-08-20 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1875	PG0541	2017-08-20 11:15:00+03	2017-08-20 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1876	PG0542	2017-09-11 13:35:00+03	2017-09-11 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1877	PG0541	2017-09-11 11:15:00+03	2017-09-11 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1878	PG0542	2017-08-21 13:35:00+03	2017-08-21 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1879	PG0541	2017-08-03 11:15:00+03	2017-08-03 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-03 11:18:00+03	2017-08-03 13:26:00+03
1880	PG0542	2017-08-03 13:35:00+03	2017-08-03 15:45:00+03	DME	OVS	Arrived	SU9	2017-08-03 13:38:00+03	2017-08-03 15:47:00+03
1881	PG0541	2017-08-13 11:15:00+03	2017-08-13 13:25:00+03	DME	OVS	Arrived	SU9	2017-08-13 14:36:00+03	2017-08-13 16:47:00+03
1882	PG0542	2017-08-18 13:35:00+03	2017-08-18 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1883	PG0541	2017-09-08 11:15:00+03	2017-09-08 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1884	PG0541	2017-07-31 11:15:00+03	2017-07-31 13:25:00+03	DME	OVS	Arrived	SU9	2017-07-31 11:18:00+03	2017-07-31 13:26:00+03
1885	PG0542	2017-08-24 13:35:00+03	2017-08-24 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1886	PG0541	2017-08-24 11:15:00+03	2017-08-24 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1887	PG0541	2017-08-27 11:15:00+03	2017-08-27 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1888	PG0542	2017-08-27 13:35:00+03	2017-08-27 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1889	PG0542	2017-09-12 13:35:00+03	2017-09-12 15:45:00+03	DME	OVS	Scheduled	SU9	\N	\N
1890	PG0541	2017-09-12 11:15:00+03	2017-09-12 13:25:00+03	DME	OVS	Scheduled	SU9	\N	\N
1891	PG0542	2017-07-31 13:35:00+03	2017-07-31 15:45:00+03	DME	OVS	Arrived	SU9	2017-07-31 13:37:00+03	2017-07-31 15:47:00+03
1892	PG0639	2017-07-20 14:50:00+03	2017-07-20 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-20 14:55:00+03	2017-07-20 18:00:00+03
1893	PG0639	2017-09-06 14:50:00+03	2017-09-06 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1894	PG0639	2017-08-19 14:50:00+03	2017-08-19 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1895	PG0639	2017-07-24 14:50:00+03	2017-07-24 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-24 14:54:00+03	2017-07-24 17:57:00+03
1896	PG0639	2017-09-04 14:50:00+03	2017-09-04 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1897	PG0639	2017-09-05 14:50:00+03	2017-09-05 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1898	PG0639	2017-07-19 14:50:00+03	2017-07-19 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-19 14:55:00+03	2017-07-19 18:02:00+03
1899	PG0639	2017-08-10 14:50:00+03	2017-08-10 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-10 14:51:00+03	2017-08-10 17:58:00+03
1900	PG0639	2017-09-12 14:50:00+03	2017-09-12 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1901	PG0639	2017-09-02 14:50:00+03	2017-09-02 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1902	PG0639	2017-07-27 14:50:00+03	2017-07-27 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-27 14:53:00+03	2017-07-27 17:56:00+03
1903	PG0639	2017-07-22 14:50:00+03	2017-07-22 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-22 14:56:00+03	2017-07-22 18:03:00+03
1904	PG0639	2017-07-17 14:50:00+03	2017-07-17 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-17 14:52:00+03	2017-07-17 17:56:00+03
1905	PG0639	2017-09-09 14:50:00+03	2017-09-09 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1906	PG0639	2017-08-30 14:50:00+03	2017-08-30 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1907	PG0639	2017-08-25 14:50:00+03	2017-08-25 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1908	PG0639	2017-08-29 14:50:00+03	2017-08-29 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1909	PG0639	2017-07-25 14:50:00+03	2017-07-25 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-25 14:53:00+03	2017-07-25 17:55:00+03
1910	PG0639	2017-08-31 14:50:00+03	2017-08-31 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1911	PG0639	2017-08-06 14:50:00+03	2017-08-06 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-06 14:53:00+03	2017-08-06 17:58:00+03
1912	PG0639	2017-09-03 14:50:00+03	2017-09-03 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1913	PG0639	2017-08-11 14:50:00+03	2017-08-11 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-11 18:23:00+03	2017-08-11 21:27:00+03
1914	PG0639	2017-07-29 14:50:00+03	2017-07-29 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-29 14:53:00+03	2017-07-29 17:57:00+03
1915	PG0639	2017-09-01 14:50:00+03	2017-09-01 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1916	PG0639	2017-08-13 14:50:00+03	2017-08-13 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-13 14:51:00+03	2017-08-13 17:55:00+03
1917	PG0639	2017-09-10 14:50:00+03	2017-09-10 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1918	PG0639	2017-08-26 14:50:00+03	2017-08-26 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1919	PG0639	2017-09-14 14:50:00+03	2017-09-14 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1920	PG0639	2017-08-28 14:50:00+03	2017-08-28 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1921	PG0639	2017-08-24 14:50:00+03	2017-08-24 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1922	PG0639	2017-08-05 14:50:00+03	2017-08-05 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-05 14:51:00+03	2017-08-05 17:56:00+03
1923	PG0639	2017-07-18 14:50:00+03	2017-07-18 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-18 14:52:00+03	2017-07-18 17:56:00+03
1924	PG0639	2017-08-12 14:50:00+03	2017-08-12 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-12 14:55:00+03	2017-08-12 18:01:00+03
1925	PG0639	2017-08-04 14:50:00+03	2017-08-04 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-04 14:56:00+03	2017-08-04 17:59:00+03
1926	PG0639	2017-08-16 14:50:00+03	2017-08-16 17:55:00+03	DME	NYM	On Time	CR2	\N	\N
1927	PG0639	2017-09-07 14:50:00+03	2017-09-07 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1928	PG0639	2017-07-30 14:50:00+03	2017-07-30 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-30 14:54:00+03	2017-07-30 18:00:00+03
1929	PG0639	2017-07-23 14:50:00+03	2017-07-23 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-23 14:52:00+03	2017-07-23 17:53:00+03
1930	PG0639	2017-07-26 14:50:00+03	2017-07-26 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-26 14:50:00+03	2017-07-26 17:55:00+03
1931	PG0639	2017-09-13 14:50:00+03	2017-09-13 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1932	PG0639	2017-08-18 14:50:00+03	2017-08-18 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1933	PG0639	2017-08-23 14:50:00+03	2017-08-23 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1934	PG0639	2017-07-31 14:50:00+03	2017-07-31 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-31 14:51:00+03	2017-07-31 17:59:00+03
1935	PG0639	2017-08-17 14:50:00+03	2017-08-17 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1936	PG0639	2017-08-07 14:50:00+03	2017-08-07 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-07 14:54:00+03	2017-08-07 17:58:00+03
1937	PG0639	2017-08-09 14:50:00+03	2017-08-09 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-09 14:53:00+03	2017-08-09 17:58:00+03
1938	PG0639	2017-09-08 14:50:00+03	2017-09-08 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1939	PG0639	2017-07-28 14:50:00+03	2017-07-28 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-28 14:52:00+03	2017-07-28 17:57:00+03
1940	PG0639	2017-08-02 14:50:00+03	2017-08-02 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-02 14:53:00+03	2017-08-02 17:58:00+03
1941	PG0639	2017-08-01 14:50:00+03	2017-08-01 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-01 14:53:00+03	2017-08-01 17:55:00+03
1942	PG0639	2017-07-21 14:50:00+03	2017-07-21 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-21 14:54:00+03	2017-07-21 17:58:00+03
1943	PG0639	2017-07-16 14:50:00+03	2017-07-16 17:55:00+03	DME	NYM	Arrived	CR2	2017-07-16 14:52:00+03	2017-07-16 17:58:00+03
1944	PG0639	2017-09-11 14:50:00+03	2017-09-11 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1945	PG0639	2017-08-08 14:50:00+03	2017-08-08 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-08 14:56:00+03	2017-08-08 17:59:00+03
1946	PG0639	2017-08-27 14:50:00+03	2017-08-27 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1947	PG0639	2017-08-22 14:50:00+03	2017-08-22 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1948	PG0639	2017-08-14 14:50:00+03	2017-08-14 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-14 14:52:00+03	2017-08-14 17:58:00+03
1949	PG0639	2017-08-03 14:50:00+03	2017-08-03 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-03 14:51:00+03	2017-08-03 17:55:00+03
1950	PG0639	2017-08-21 14:50:00+03	2017-08-21 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1951	PG0639	2017-08-20 14:50:00+03	2017-08-20 17:55:00+03	DME	NYM	Scheduled	CR2	\N	\N
1952	PG0639	2017-08-15 14:50:00+03	2017-08-15 17:55:00+03	DME	NYM	Arrived	CR2	2017-08-15 14:54:00+03	2017-08-15 18:00:00+03
1953	PG0289	2017-08-21 17:25:00+03	2017-08-21 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1954	PG0289	2017-08-31 17:25:00+03	2017-08-31 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1955	PG0289	2017-07-24 17:25:00+03	2017-07-24 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-24 17:29:00+03	2017-07-24 20:15:00+03
1956	PG0289	2017-08-03 17:25:00+03	2017-08-03 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-03 17:31:00+03	2017-08-03 20:19:00+03
1957	PG0289	2017-07-22 17:25:00+03	2017-07-22 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-22 17:28:00+03	2017-07-22 20:10:00+03
1958	PG0289	2017-09-03 17:25:00+03	2017-09-03 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1959	PG0289	2017-08-02 17:25:00+03	2017-08-02 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-02 17:29:00+03	2017-08-02 20:14:00+03
1960	PG0289	2017-08-28 17:25:00+03	2017-08-28 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1961	PG0289	2017-08-19 17:25:00+03	2017-08-19 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1962	PG0289	2017-09-05 17:25:00+03	2017-09-05 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1963	PG0289	2017-09-01 17:25:00+03	2017-09-01 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1964	PG0289	2017-08-17 17:25:00+03	2017-08-17 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1965	PG0289	2017-07-19 17:25:00+03	2017-07-19 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-19 17:26:00+03	2017-07-19 20:12:00+03
1966	PG0289	2017-09-09 17:25:00+03	2017-09-09 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1967	PG0289	2017-08-07 17:25:00+03	2017-08-07 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-07 21:15:00+03	2017-08-07 23:59:00+03
1968	PG0289	2017-08-29 17:25:00+03	2017-08-29 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1969	PG0289	2017-08-11 17:25:00+03	2017-08-11 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-11 17:30:00+03	2017-08-11 20:17:00+03
1970	PG0289	2017-07-21 17:25:00+03	2017-07-21 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-21 17:28:00+03	2017-07-21 20:10:00+03
1971	PG0289	2017-09-13 17:25:00+03	2017-09-13 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1972	PG0289	2017-07-29 17:25:00+03	2017-07-29 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-29 17:27:00+03	2017-07-29 20:12:00+03
1973	PG0289	2017-07-26 17:25:00+03	2017-07-26 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-26 17:31:00+03	2017-07-26 20:16:00+03
1974	PG0289	2017-09-06 17:25:00+03	2017-09-06 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1975	PG0289	2017-08-08 17:25:00+03	2017-08-08 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-08 17:26:00+03	2017-08-08 20:12:00+03
1976	PG0289	2017-07-30 17:25:00+03	2017-07-30 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-30 17:28:00+03	2017-07-30 20:13:00+03
1977	PG0289	2017-09-12 17:25:00+03	2017-09-12 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1978	PG0289	2017-08-14 17:25:00+03	2017-08-14 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-14 17:28:00+03	2017-08-14 20:13:00+03
1979	PG0289	2017-07-27 17:25:00+03	2017-07-27 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-27 17:29:00+03	2017-07-27 20:14:00+03
1980	PG0289	2017-08-04 17:25:00+03	2017-08-04 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-04 17:26:00+03	2017-08-04 20:12:00+03
1981	PG0289	2017-08-13 17:25:00+03	2017-08-13 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-13 17:26:00+03	2017-08-13 20:13:00+03
1982	PG0289	2017-07-17 17:25:00+03	2017-07-17 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-17 17:29:00+03	2017-07-17 20:14:00+03
1983	PG0289	2017-08-22 17:25:00+03	2017-08-22 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1984	PG0289	2017-08-18 17:25:00+03	2017-08-18 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1985	PG0289	2017-08-30 17:25:00+03	2017-08-30 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1986	PG0289	2017-08-01 17:25:00+03	2017-08-01 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-01 17:28:00+03	2017-08-01 20:12:00+03
1987	PG0289	2017-08-15 17:25:00+03	2017-08-15 20:10:00+03	DME	VKT	Departed	CR2	2017-08-15 17:29:00+03	\N
1988	PG0289	2017-08-20 17:25:00+03	2017-08-20 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1989	PG0289	2017-09-11 17:25:00+03	2017-09-11 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1990	PG0289	2017-08-10 17:25:00+03	2017-08-10 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-10 17:30:00+03	2017-08-10 20:16:00+03
1991	PG0289	2017-08-05 17:25:00+03	2017-08-05 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-05 17:30:00+03	2017-08-05 20:15:00+03
1992	PG0289	2017-09-07 17:25:00+03	2017-09-07 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1993	PG0289	2017-08-26 17:25:00+03	2017-08-26 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1994	PG0289	2017-07-16 17:25:00+03	2017-07-16 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-16 17:29:00+03	2017-07-16 20:14:00+03
1995	PG0289	2017-08-24 17:25:00+03	2017-08-24 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1996	PG0289	2017-07-23 17:25:00+03	2017-07-23 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-23 17:26:00+03	2017-07-23 20:09:00+03
1997	PG0289	2017-08-25 17:25:00+03	2017-08-25 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1998	PG0289	2017-09-04 17:25:00+03	2017-09-04 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
1999	PG0289	2017-07-20 17:25:00+03	2017-07-20 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-20 17:28:00+03	2017-07-20 20:12:00+03
2000	PG0289	2017-07-31 17:25:00+03	2017-07-31 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-31 17:28:00+03	2017-07-31 20:12:00+03
2001	PG0289	2017-08-23 17:25:00+03	2017-08-23 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
2002	PG0289	2017-09-08 17:25:00+03	2017-09-08 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
2003	PG0289	2017-07-25 17:25:00+03	2017-07-25 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-25 17:28:00+03	2017-07-25 20:13:00+03
2004	PG0289	2017-08-27 17:25:00+03	2017-08-27 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
2005	PG0289	2017-08-16 17:25:00+03	2017-08-16 20:10:00+03	DME	VKT	On Time	CR2	\N	\N
2006	PG0289	2017-08-06 17:25:00+03	2017-08-06 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-06 17:29:00+03	2017-08-06 20:16:00+03
2007	PG0289	2017-07-28 17:25:00+03	2017-07-28 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-28 17:28:00+03	2017-07-28 20:11:00+03
2008	PG0289	2017-09-02 17:25:00+03	2017-09-02 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
2009	PG0289	2017-09-10 17:25:00+03	2017-09-10 20:10:00+03	DME	VKT	Scheduled	CR2	\N	\N
2010	PG0289	2017-07-18 17:25:00+03	2017-07-18 20:10:00+03	DME	VKT	Arrived	CR2	2017-07-18 17:31:00+03	2017-07-18 20:17:00+03
2011	PG0289	2017-09-14 17:25:00+03	2017-09-14 20:10:00+03	DME	VKT	Cancelled	CR2	\N	\N
2012	PG0289	2017-08-12 17:25:00+03	2017-08-12 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-12 17:27:00+03	2017-08-12 20:15:00+03
2013	PG0289	2017-08-09 17:25:00+03	2017-08-09 20:10:00+03	DME	VKT	Arrived	CR2	2017-08-09 17:29:00+03	2017-08-09 20:13:00+03
2014	PG0019	2017-08-27 18:10:00+03	2017-08-27 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2015	PG0019	2017-07-29 18:10:00+03	2017-07-29 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-29 18:14:00+03	2017-07-29 19:34:00+03
2016	PG0019	2017-08-01 18:10:00+03	2017-08-01 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-01 18:13:00+03	2017-08-01 19:32:00+03
2017	PG0019	2017-08-14 18:10:00+03	2017-08-14 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-14 18:11:00+03	2017-08-14 19:31:00+03
2018	PG0019	2017-09-04 18:10:00+03	2017-09-04 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2019	PG0019	2017-07-18 18:10:00+03	2017-07-18 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-18 18:12:00+03	2017-07-18 19:31:00+03
2020	PG0019	2017-08-12 18:10:00+03	2017-08-12 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-12 18:13:00+03	2017-08-12 19:35:00+03
2021	PG0019	2017-08-19 18:10:00+03	2017-08-19 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2022	PG0019	2017-09-12 18:10:00+03	2017-09-12 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2023	PG0019	2017-08-03 18:10:00+03	2017-08-03 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-03 18:10:00+03	2017-08-03 19:30:00+03
2024	PG0019	2017-09-06 18:10:00+03	2017-09-06 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2025	PG0019	2017-09-08 18:10:00+03	2017-09-08 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2026	PG0019	2017-08-10 18:10:00+03	2017-08-10 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-10 18:10:00+03	2017-08-10 19:29:00+03
2027	PG0019	2017-09-07 18:10:00+03	2017-09-07 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2028	PG0019	2017-09-14 18:10:00+03	2017-09-14 19:30:00+03	DME	UUA	Cancelled	CR2	\N	\N
2029	PG0019	2017-09-01 18:10:00+03	2017-09-01 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2030	PG0019	2017-08-30 18:10:00+03	2017-08-30 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2031	PG0019	2017-07-19 18:10:00+03	2017-07-19 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-19 18:10:00+03	2017-07-19 19:31:00+03
2032	PG0019	2017-07-17 18:10:00+03	2017-07-17 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-17 21:17:00+03	2017-07-17 22:38:00+03
2033	PG0019	2017-08-31 18:10:00+03	2017-08-31 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2034	PG0019	2017-07-25 18:10:00+03	2017-07-25 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-25 18:12:00+03	2017-07-25 19:33:00+03
2035	PG0019	2017-07-28 18:10:00+03	2017-07-28 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-28 18:16:00+03	2017-07-28 19:38:00+03
2036	PG0019	2017-08-21 18:10:00+03	2017-08-21 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2037	PG0019	2017-08-02 18:10:00+03	2017-08-02 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-02 18:15:00+03	2017-08-02 19:36:00+03
2038	PG0019	2017-09-11 18:10:00+03	2017-09-11 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2039	PG0019	2017-07-27 18:10:00+03	2017-07-27 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-27 18:11:00+03	2017-07-27 19:31:00+03
2040	PG0019	2017-08-04 18:10:00+03	2017-08-04 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-04 18:13:00+03	2017-08-04 19:32:00+03
2041	PG0019	2017-08-29 18:10:00+03	2017-08-29 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2042	PG0019	2017-08-07 18:10:00+03	2017-08-07 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-07 18:12:00+03	2017-08-07 19:33:00+03
2043	PG0019	2017-08-26 18:10:00+03	2017-08-26 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2044	PG0019	2017-09-13 18:10:00+03	2017-09-13 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2045	PG0019	2017-08-13 18:10:00+03	2017-08-13 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-13 18:12:00+03	2017-08-13 19:32:00+03
2046	PG0019	2017-08-17 18:10:00+03	2017-08-17 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2047	PG0019	2017-09-10 18:10:00+03	2017-09-10 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2048	PG0019	2017-09-05 18:10:00+03	2017-09-05 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2049	PG0019	2017-08-25 18:10:00+03	2017-08-25 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2050	PG0019	2017-08-11 18:10:00+03	2017-08-11 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-11 18:11:00+03	2017-08-11 19:32:00+03
2051	PG0019	2017-08-15 18:10:00+03	2017-08-15 19:30:00+03	DME	UUA	On Time	CR2	\N	\N
2052	PG0019	2017-08-05 18:10:00+03	2017-08-05 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-05 18:15:00+03	2017-08-05 19:33:00+03
2053	PG0019	2017-07-21 18:10:00+03	2017-07-21 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-21 18:13:00+03	2017-07-21 19:33:00+03
2054	PG0019	2017-08-06 18:10:00+03	2017-08-06 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-06 18:17:00+03	2017-08-06 19:37:00+03
2055	PG0019	2017-07-16 18:10:00+03	2017-07-16 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-16 18:15:00+03	2017-07-16 19:35:00+03
2056	PG0019	2017-08-16 18:10:00+03	2017-08-16 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2057	PG0019	2017-07-20 18:10:00+03	2017-07-20 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-20 18:11:00+03	2017-07-20 19:33:00+03
2058	PG0019	2017-09-03 18:10:00+03	2017-09-03 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2059	PG0019	2017-07-26 18:10:00+03	2017-07-26 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-26 18:13:00+03	2017-07-26 19:32:00+03
2060	PG0019	2017-09-02 18:10:00+03	2017-09-02 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2061	PG0019	2017-08-20 18:10:00+03	2017-08-20 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2062	PG0019	2017-07-23 18:10:00+03	2017-07-23 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-23 18:10:00+03	2017-07-23 19:29:00+03
2063	PG0019	2017-08-28 18:10:00+03	2017-08-28 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2064	PG0019	2017-07-22 18:10:00+03	2017-07-22 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-22 18:16:00+03	2017-07-22 19:35:00+03
2065	PG0019	2017-07-24 18:10:00+03	2017-07-24 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-24 18:13:00+03	2017-07-24 19:33:00+03
2066	PG0019	2017-08-23 18:10:00+03	2017-08-23 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2067	PG0019	2017-08-22 18:10:00+03	2017-08-22 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2068	PG0019	2017-08-24 18:10:00+03	2017-08-24 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2069	PG0019	2017-07-30 18:10:00+03	2017-07-30 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-30 18:11:00+03	2017-07-30 19:30:00+03
2070	PG0019	2017-08-08 18:10:00+03	2017-08-08 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-08 18:13:00+03	2017-08-08 19:34:00+03
2071	PG0019	2017-09-09 18:10:00+03	2017-09-09 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2072	PG0019	2017-07-31 18:10:00+03	2017-07-31 19:30:00+03	DME	UUA	Arrived	CR2	2017-07-31 18:11:00+03	2017-07-31 19:30:00+03
2073	PG0019	2017-08-18 18:10:00+03	2017-08-18 19:30:00+03	DME	UUA	Scheduled	CR2	\N	\N
2074	PG0019	2017-08-09 18:10:00+03	2017-08-09 19:30:00+03	DME	UUA	Arrived	CR2	2017-08-09 18:15:00+03	2017-08-09 19:36:00+03
2075	PG0249	2017-07-23 14:35:00+03	2017-07-23 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-23 14:40:00+03	2017-07-23 16:25:00+03
2076	PG0249	2017-09-03 14:35:00+03	2017-09-03 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2077	PG0249	2017-08-15 14:35:00+03	2017-08-15 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-15 14:39:00+03	2017-08-15 16:24:00+03
2078	PG0249	2017-08-27 14:35:00+03	2017-08-27 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2079	PG0249	2017-07-16 14:35:00+03	2017-07-16 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-16 14:36:00+03	2017-07-16 16:23:00+03
2080	PG0249	2017-09-10 14:35:00+03	2017-09-10 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2081	PG0249	2017-08-20 14:35:00+03	2017-08-20 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2082	PG0249	2017-07-28 14:35:00+03	2017-07-28 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-28 14:38:00+03	2017-07-28 16:25:00+03
2083	PG0249	2017-07-18 14:35:00+03	2017-07-18 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-18 14:37:00+03	2017-07-18 16:22:00+03
2084	PG0249	2017-08-25 14:35:00+03	2017-08-25 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2085	PG0249	2017-08-01 14:35:00+03	2017-08-01 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-01 14:37:00+03	2017-08-01 16:22:00+03
2086	PG0249	2017-08-22 14:35:00+03	2017-08-22 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2087	PG0249	2017-09-01 14:35:00+03	2017-09-01 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2088	PG0249	2017-08-18 14:35:00+03	2017-08-18 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2089	PG0249	2017-08-04 14:35:00+03	2017-08-04 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-04 14:37:00+03	2017-08-04 16:20:00+03
2090	PG0249	2017-08-29 14:35:00+03	2017-08-29 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2091	PG0249	2017-07-21 14:35:00+03	2017-07-21 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-21 14:37:00+03	2017-07-21 16:21:00+03
2092	PG0249	2017-08-11 14:35:00+03	2017-08-11 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-11 14:35:00+03	2017-08-11 16:21:00+03
2093	PG0249	2017-08-08 14:35:00+03	2017-08-08 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-08 14:36:00+03	2017-08-08 16:22:00+03
2094	PG0249	2017-09-12 14:35:00+03	2017-09-12 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2095	PG0249	2017-09-08 14:35:00+03	2017-09-08 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2096	PG0249	2017-08-13 14:35:00+03	2017-08-13 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-13 14:37:00+03	2017-08-13 16:22:00+03
2097	PG0249	2017-09-05 14:35:00+03	2017-09-05 16:20:00+03	DME	GDZ	Scheduled	CR2	\N	\N
2098	PG0249	2017-07-30 14:35:00+03	2017-07-30 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-30 14:38:00+03	2017-07-30 16:24:00+03
2099	PG0249	2017-07-25 14:35:00+03	2017-07-25 16:20:00+03	DME	GDZ	Arrived	CR2	2017-07-25 14:36:00+03	2017-07-25 16:20:00+03
2100	PG0249	2017-08-06 14:35:00+03	2017-08-06 16:20:00+03	DME	GDZ	Arrived	CR2	2017-08-06 14:37:00+03	2017-08-06 16:23:00+03
2101	PG0075	2017-07-31 10:55:00+03	2017-07-31 13:30:00+03	DME	EYK	Arrived	CR2	2017-07-31 10:56:00+03	2017-07-31 13:31:00+03
2102	PG0075	2017-09-04 10:55:00+03	2017-09-04 13:30:00+03	DME	EYK	Scheduled	CR2	\N	\N
2103	PG0075	2017-08-21 10:55:00+03	2017-08-21 13:30:00+03	DME	EYK	Scheduled	CR2	\N	\N
2104	PG0075	2017-09-11 10:55:00+03	2017-09-11 13:30:00+03	DME	EYK	Cancelled	CR2	\N	\N
2105	PG0075	2017-08-14 10:55:00+03	2017-08-14 13:30:00+03	DME	EYK	Arrived	CR2	2017-08-14 10:59:00+03	2017-08-14 13:34:00+03
2106	PG0075	2017-07-17 10:55:00+03	2017-07-17 13:30:00+03	DME	EYK	Arrived	CR2	2017-07-17 10:58:00+03	2017-07-17 13:34:00+03
2107	PG0075	2017-08-28 10:55:00+03	2017-08-28 13:30:00+03	DME	EYK	Scheduled	CR2	\N	\N
2108	PG0075	2017-08-07 10:55:00+03	2017-08-07 13:30:00+03	DME	EYK	Arrived	CR2	2017-08-07 10:58:00+03	2017-08-07 13:33:00+03
2109	PG0075	2017-07-24 10:55:00+03	2017-07-24 13:30:00+03	DME	EYK	Arrived	CR2	2017-07-24 11:00:00+03	2017-07-24 13:39:00+03
2110	PG0220	2017-08-23 18:05:00+03	2017-08-23 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2111	PG0220	2017-09-05 18:05:00+03	2017-09-05 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2112	PG0220	2017-07-23 18:05:00+03	2017-07-23 19:35:00+03	DME	KRR	Arrived	763	2017-07-23 18:08:00+03	2017-07-23 19:38:00+03
2113	PG0220	2017-07-18 18:05:00+03	2017-07-18 19:35:00+03	DME	KRR	Arrived	763	2017-07-18 18:08:00+03	2017-07-18 19:38:00+03
2114	PG0220	2017-08-14 18:05:00+03	2017-08-14 19:35:00+03	DME	KRR	Arrived	763	2017-08-14 18:08:00+03	2017-08-14 19:38:00+03
2115	PG0220	2017-08-15 18:05:00+03	2017-08-15 19:35:00+03	DME	KRR	On Time	763	\N	\N
2116	PG0220	2017-07-24 18:05:00+03	2017-07-24 19:35:00+03	DME	KRR	Arrived	763	2017-07-24 18:07:00+03	2017-07-24 19:37:00+03
2117	PG0220	2017-09-06 18:05:00+03	2017-09-06 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2118	PG0220	2017-07-22 18:05:00+03	2017-07-22 19:35:00+03	DME	KRR	Arrived	763	2017-07-22 18:06:00+03	2017-07-22 19:34:00+03
2119	PG0220	2017-08-16 18:05:00+03	2017-08-16 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2120	PG0220	2017-08-08 18:05:00+03	2017-08-08 19:35:00+03	DME	KRR	Arrived	763	2017-08-08 18:09:00+03	2017-08-08 19:38:00+03
2121	PG0220	2017-09-11 18:05:00+03	2017-09-11 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2122	PG0220	2017-08-17 18:05:00+03	2017-08-17 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2123	PG0220	2017-09-09 18:05:00+03	2017-09-09 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2124	PG0220	2017-08-11 18:05:00+03	2017-08-11 19:35:00+03	DME	KRR	Arrived	763	2017-08-11 18:09:00+03	2017-08-11 19:40:00+03
2125	PG0220	2017-07-26 18:05:00+03	2017-07-26 19:35:00+03	DME	KRR	Arrived	763	2017-07-26 18:07:00+03	2017-07-26 19:37:00+03
2126	PG0220	2017-08-02 18:05:00+03	2017-08-02 19:35:00+03	DME	KRR	Arrived	763	2017-08-02 18:09:00+03	2017-08-02 19:40:00+03
2127	PG0220	2017-08-03 18:05:00+03	2017-08-03 19:35:00+03	DME	KRR	Arrived	763	2017-08-03 18:09:00+03	2017-08-03 19:40:00+03
2128	PG0220	2017-08-30 18:05:00+03	2017-08-30 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2129	PG0220	2017-08-21 18:05:00+03	2017-08-21 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2130	PG0220	2017-07-30 18:05:00+03	2017-07-30 19:35:00+03	DME	KRR	Arrived	763	2017-07-30 18:06:00+03	2017-07-30 19:35:00+03
2131	PG0220	2017-08-06 18:05:00+03	2017-08-06 19:35:00+03	DME	KRR	Arrived	763	2017-08-06 18:10:00+03	2017-08-06 19:41:00+03
2132	PG0220	2017-09-02 18:05:00+03	2017-09-02 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2133	PG0220	2017-09-03 18:05:00+03	2017-09-03 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2134	PG0220	2017-08-05 18:05:00+03	2017-08-05 19:35:00+03	DME	KRR	Arrived	763	2017-08-05 18:09:00+03	2017-08-05 19:38:00+03
2135	PG0220	2017-08-31 18:05:00+03	2017-08-31 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2136	PG0220	2017-08-28 18:05:00+03	2017-08-28 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2137	PG0220	2017-09-07 18:05:00+03	2017-09-07 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2138	PG0220	2017-07-28 18:05:00+03	2017-07-28 19:35:00+03	DME	KRR	Arrived	763	2017-07-28 18:07:00+03	2017-07-28 19:37:00+03
2139	PG0220	2017-08-10 18:05:00+03	2017-08-10 19:35:00+03	DME	KRR	Arrived	763	2017-08-10 18:11:00+03	2017-08-10 19:41:00+03
2140	PG0220	2017-07-16 18:05:00+03	2017-07-16 19:35:00+03	DME	KRR	Arrived	763	2017-07-16 18:08:00+03	2017-07-16 19:38:00+03
2141	PG0220	2017-08-29 18:05:00+03	2017-08-29 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2142	PG0220	2017-07-19 18:05:00+03	2017-07-19 19:35:00+03	DME	KRR	Arrived	763	2017-07-19 18:08:00+03	2017-07-19 19:38:00+03
2143	PG0220	2017-08-20 18:05:00+03	2017-08-20 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2144	PG0220	2017-09-04 18:05:00+03	2017-09-04 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2145	PG0220	2017-08-25 18:05:00+03	2017-08-25 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2146	PG0220	2017-08-13 18:05:00+03	2017-08-13 19:35:00+03	DME	KRR	Arrived	763	2017-08-13 18:08:00+03	2017-08-13 19:39:00+03
2147	PG0220	2017-08-07 18:05:00+03	2017-08-07 19:35:00+03	DME	KRR	Arrived	763	2017-08-07 18:08:00+03	2017-08-07 19:39:00+03
2148	PG0220	2017-08-12 18:05:00+03	2017-08-12 19:35:00+03	DME	KRR	Arrived	763	2017-08-12 18:08:00+03	2017-08-12 19:37:00+03
2149	PG0220	2017-08-24 18:05:00+03	2017-08-24 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2150	PG0220	2017-08-18 18:05:00+03	2017-08-18 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2151	PG0220	2017-09-01 18:05:00+03	2017-09-01 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2152	PG0220	2017-07-21 18:05:00+03	2017-07-21 19:35:00+03	DME	KRR	Arrived	763	2017-07-21 18:07:00+03	2017-07-21 19:39:00+03
2153	PG0220	2017-07-17 18:05:00+03	2017-07-17 19:35:00+03	DME	KRR	Arrived	763	2017-07-17 18:06:00+03	2017-07-17 19:35:00+03
2154	PG0220	2017-08-09 18:05:00+03	2017-08-09 19:35:00+03	DME	KRR	Arrived	763	2017-08-09 18:08:00+03	2017-08-09 19:36:00+03
2155	PG0220	2017-09-10 18:05:00+03	2017-09-10 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2156	PG0220	2017-07-27 18:05:00+03	2017-07-27 19:35:00+03	DME	KRR	Arrived	763	2017-07-27 18:08:00+03	2017-07-27 19:38:00+03
2157	PG0220	2017-07-20 18:05:00+03	2017-07-20 19:35:00+03	DME	KRR	Arrived	763	2017-07-20 18:07:00+03	2017-07-20 19:37:00+03
2158	PG0220	2017-09-14 18:05:00+03	2017-09-14 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2159	PG0220	2017-08-26 18:05:00+03	2017-08-26 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2160	PG0220	2017-08-04 18:05:00+03	2017-08-04 19:35:00+03	DME	KRR	Arrived	763	2017-08-04 18:06:00+03	2017-08-04 19:36:00+03
2161	PG0220	2017-07-25 18:05:00+03	2017-07-25 19:35:00+03	DME	KRR	Arrived	763	2017-07-25 18:06:00+03	2017-07-25 19:38:00+03
2162	PG0220	2017-09-13 18:05:00+03	2017-09-13 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2163	PG0220	2017-08-22 18:05:00+03	2017-08-22 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2164	PG0220	2017-08-27 18:05:00+03	2017-08-27 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2165	PG0220	2017-08-19 18:05:00+03	2017-08-19 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2166	PG0220	2017-07-29 18:05:00+03	2017-07-29 19:35:00+03	DME	KRR	Arrived	763	2017-07-29 18:09:00+03	2017-07-29 19:41:00+03
2167	PG0220	2017-09-08 18:05:00+03	2017-09-08 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2168	PG0220	2017-08-01 18:05:00+03	2017-08-01 19:35:00+03	DME	KRR	Arrived	763	2017-08-01 18:06:00+03	2017-08-01 19:36:00+03
2169	PG0220	2017-07-31 18:05:00+03	2017-07-31 19:35:00+03	DME	KRR	Arrived	763	2017-07-31 18:08:00+03	2017-07-31 19:37:00+03
2170	PG0220	2017-09-12 18:05:00+03	2017-09-12 19:35:00+03	DME	KRR	Scheduled	763	\N	\N
2171	PG0645	2017-07-18 16:05:00+03	2017-07-18 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-18 16:08:00+03	2017-07-18 17:08:00+03
2172	PG0645	2017-08-15 16:05:00+03	2017-08-15 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-15 16:08:00+03	2017-08-15 17:08:00+03
2173	PG0645	2017-07-29 16:05:00+03	2017-07-29 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-29 16:08:00+03	2017-07-29 17:08:00+03
2174	PG0645	2017-08-25 16:05:00+03	2017-08-25 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2175	PG0645	2017-07-20 16:05:00+03	2017-07-20 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-20 16:07:00+03	2017-07-20 17:07:00+03
2176	PG0645	2017-09-05 16:05:00+03	2017-09-05 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2177	PG0645	2017-07-23 16:05:00+03	2017-07-23 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-23 16:09:00+03	2017-07-23 17:09:00+03
2178	PG0645	2017-08-08 16:05:00+03	2017-08-08 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-08 19:13:00+03	2017-08-08 20:13:00+03
2179	PG0645	2017-07-26 16:05:00+03	2017-07-26 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-26 16:09:00+03	2017-07-26 17:09:00+03
2180	PG0645	2017-09-11 16:05:00+03	2017-09-11 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2181	PG0645	2017-08-05 16:05:00+03	2017-08-05 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-05 19:29:00+03	2017-08-05 20:28:00+03
2182	PG0645	2017-09-06 16:05:00+03	2017-09-06 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2183	PG0645	2017-08-06 16:05:00+03	2017-08-06 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-06 16:07:00+03	2017-08-06 17:07:00+03
2184	PG0645	2017-09-09 16:05:00+03	2017-09-09 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2185	PG0645	2017-07-25 16:05:00+03	2017-07-25 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-25 16:08:00+03	2017-07-25 17:08:00+03
2186	PG0645	2017-07-22 16:05:00+03	2017-07-22 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-22 16:11:00+03	2017-07-22 17:11:00+03
2187	PG0645	2017-09-13 16:05:00+03	2017-09-13 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2188	PG0645	2017-09-14 16:05:00+03	2017-09-14 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2189	PG0645	2017-08-10 16:05:00+03	2017-08-10 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-10 16:08:00+03	2017-08-10 17:08:00+03
2190	PG0645	2017-08-19 16:05:00+03	2017-08-19 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2191	PG0645	2017-09-12 16:05:00+03	2017-09-12 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2192	PG0645	2017-08-12 16:05:00+03	2017-08-12 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-12 16:06:00+03	2017-08-12 17:06:00+03
2193	PG0645	2017-08-31 16:05:00+03	2017-08-31 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2194	PG0645	2017-08-16 16:05:00+03	2017-08-16 17:05:00+03	DME	RTW	On Time	CR2	\N	\N
2195	PG0645	2017-08-29 16:05:00+03	2017-08-29 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2196	PG0645	2017-07-17 16:05:00+03	2017-07-17 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-17 16:05:00+03	2017-07-17 17:06:00+03
2197	PG0645	2017-08-22 16:05:00+03	2017-08-22 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2198	PG0645	2017-08-27 16:05:00+03	2017-08-27 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2199	PG0645	2017-07-19 16:05:00+03	2017-07-19 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-19 16:09:00+03	2017-07-19 17:09:00+03
2200	PG0645	2017-08-04 16:05:00+03	2017-08-04 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-04 16:07:00+03	2017-08-04 17:06:00+03
2201	PG0645	2017-07-30 16:05:00+03	2017-07-30 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-30 16:08:00+03	2017-07-30 17:08:00+03
2202	PG0645	2017-08-14 16:05:00+03	2017-08-14 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-14 16:08:00+03	2017-08-14 17:09:00+03
2203	PG0645	2017-08-24 16:05:00+03	2017-08-24 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2204	PG0645	2017-08-09 16:05:00+03	2017-08-09 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-09 16:11:00+03	2017-08-09 17:11:00+03
2205	PG0645	2017-08-02 16:05:00+03	2017-08-02 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-02 16:07:00+03	2017-08-02 17:07:00+03
2206	PG0645	2017-08-17 16:05:00+03	2017-08-17 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2207	PG0645	2017-09-10 16:05:00+03	2017-09-10 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2208	PG0645	2017-08-01 16:05:00+03	2017-08-01 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-01 16:09:00+03	2017-08-01 17:09:00+03
2209	PG0645	2017-07-24 16:05:00+03	2017-07-24 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-24 16:08:00+03	2017-07-24 17:08:00+03
2210	PG0645	2017-08-28 16:05:00+03	2017-08-28 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2211	PG0645	2017-07-28 16:05:00+03	2017-07-28 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-28 16:09:00+03	2017-07-28 17:10:00+03
2212	PG0645	2017-08-23 16:05:00+03	2017-08-23 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2213	PG0645	2017-07-31 16:05:00+03	2017-07-31 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-31 16:10:00+03	2017-07-31 17:09:00+03
2214	PG0645	2017-08-07 16:05:00+03	2017-08-07 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-07 16:08:00+03	2017-08-07 17:09:00+03
2215	PG0645	2017-08-26 16:05:00+03	2017-08-26 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2216	PG0645	2017-08-20 16:05:00+03	2017-08-20 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2217	PG0645	2017-09-08 16:05:00+03	2017-09-08 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2218	PG0645	2017-07-21 16:05:00+03	2017-07-21 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-21 16:08:00+03	2017-07-21 17:09:00+03
2219	PG0645	2017-08-18 16:05:00+03	2017-08-18 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2220	PG0645	2017-08-03 16:05:00+03	2017-08-03 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-03 16:06:00+03	2017-08-03 17:07:00+03
2221	PG0645	2017-09-01 16:05:00+03	2017-09-01 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2222	PG0645	2017-09-02 16:05:00+03	2017-09-02 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2223	PG0645	2017-09-03 16:05:00+03	2017-09-03 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2224	PG0645	2017-09-04 16:05:00+03	2017-09-04 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2225	PG0645	2017-08-13 16:05:00+03	2017-08-13 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-13 16:07:00+03	2017-08-13 17:08:00+03
2226	PG0645	2017-09-07 16:05:00+03	2017-09-07 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2227	PG0645	2017-07-27 16:05:00+03	2017-07-27 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-27 16:09:00+03	2017-07-27 17:09:00+03
2228	PG0645	2017-08-30 16:05:00+03	2017-08-30 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2229	PG0645	2017-08-11 16:05:00+03	2017-08-11 17:05:00+03	DME	RTW	Arrived	CR2	2017-08-11 16:07:00+03	2017-08-11 17:07:00+03
2230	PG0645	2017-08-21 16:05:00+03	2017-08-21 17:05:00+03	DME	RTW	Scheduled	CR2	\N	\N
2231	PG0645	2017-07-16 16:05:00+03	2017-07-16 17:05:00+03	DME	RTW	Arrived	CR2	2017-07-16 16:09:00+03	2017-07-16 17:08:00+03
2232	PG0072	2017-09-09 09:55:00+03	2017-09-09 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2233	PG0072	2017-08-08 09:55:00+03	2017-08-08 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-08 09:58:00+03	2017-08-08 13:54:00+03
2234	PG0072	2017-08-26 09:55:00+03	2017-08-26 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2235	PG0072	2017-08-31 09:55:00+03	2017-08-31 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2236	PG0072	2017-08-24 09:55:00+03	2017-08-24 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2237	PG0072	2017-07-29 09:55:00+03	2017-07-29 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-29 10:00:00+03	2017-07-29 13:57:00+03
2238	PG0072	2017-08-19 09:55:00+03	2017-08-19 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2239	PG0072	2017-07-25 09:55:00+03	2017-07-25 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-25 09:57:00+03	2017-07-25 13:50:00+03
2240	PG0072	2017-07-20 09:55:00+03	2017-07-20 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-20 09:59:00+03	2017-07-20 13:57:00+03
2241	PG0072	2017-08-22 09:55:00+03	2017-08-22 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2242	PG0072	2017-08-15 09:55:00+03	2017-08-15 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-15 10:05:00+03	2017-08-15 14:03:00+03
2243	PG0072	2017-07-18 09:55:00+03	2017-07-18 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-18 09:59:00+03	2017-07-18 13:56:00+03
2244	PG0072	2017-09-07 09:55:00+03	2017-09-07 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2245	PG0072	2017-09-14 09:55:00+03	2017-09-14 13:50:00+03	DME	BAX	Cancelled	SU9	\N	\N
2246	PG0072	2017-08-10 09:55:00+03	2017-08-10 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-10 09:59:00+03	2017-08-10 13:56:00+03
2247	PG0072	2017-09-02 09:55:00+03	2017-09-02 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2248	PG0072	2017-08-01 09:55:00+03	2017-08-01 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-01 09:57:00+03	2017-08-01 13:51:00+03
2249	PG0072	2017-08-05 09:55:00+03	2017-08-05 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-05 10:00:00+03	2017-08-05 13:51:00+03
2250	PG0072	2017-08-17 09:55:00+03	2017-08-17 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2251	PG0072	2017-09-05 09:55:00+03	2017-09-05 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2252	PG0072	2017-08-12 09:55:00+03	2017-08-12 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-12 09:58:00+03	2017-08-12 13:49:00+03
2253	PG0072	2017-09-12 09:55:00+03	2017-09-12 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2254	PG0072	2017-07-27 09:55:00+03	2017-07-27 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-27 10:00:00+03	2017-07-27 13:59:00+03
2255	PG0072	2017-07-22 09:55:00+03	2017-07-22 13:50:00+03	DME	BAX	Arrived	SU9	2017-07-22 09:57:00+03	2017-07-22 13:51:00+03
2256	PG0072	2017-08-03 09:55:00+03	2017-08-03 13:50:00+03	DME	BAX	Arrived	SU9	2017-08-03 10:00:00+03	2017-08-03 13:56:00+03
2257	PG0072	2017-08-29 09:55:00+03	2017-08-29 13:50:00+03	DME	BAX	Scheduled	SU9	\N	\N
2258	PG0605	2017-09-02 18:40:00+03	2017-09-02 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2259	PG0605	2017-08-05 18:40:00+03	2017-08-05 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-05 21:46:00+03	2017-08-05 22:42:00+03
2260	PG0605	2017-08-29 18:40:00+03	2017-08-29 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2261	PG0605	2017-07-18 18:40:00+03	2017-07-18 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-18 18:43:00+03	2017-07-18 19:37:00+03
2262	PG0605	2017-07-28 18:40:00+03	2017-07-28 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-28 18:43:00+03	2017-07-28 19:39:00+03
2263	PG0605	2017-07-27 18:40:00+03	2017-07-27 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-27 18:43:00+03	2017-07-27 19:38:00+03
2264	PG0605	2017-08-23 18:40:00+03	2017-08-23 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2265	PG0605	2017-08-01 18:40:00+03	2017-08-01 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-01 18:45:00+03	2017-08-01 19:40:00+03
2266	PG0605	2017-09-07 18:40:00+03	2017-09-07 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2267	PG0605	2017-08-08 18:40:00+03	2017-08-08 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-08 18:43:00+03	2017-08-08 19:38:00+03
2268	PG0605	2017-09-13 18:40:00+03	2017-09-13 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2269	PG0605	2017-08-16 18:40:00+03	2017-08-16 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2270	PG0605	2017-08-06 18:40:00+03	2017-08-06 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-06 18:41:00+03	2017-08-06 19:36:00+03
2271	PG0605	2017-08-31 18:40:00+03	2017-08-31 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2272	PG0605	2017-08-04 18:40:00+03	2017-08-04 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-04 18:42:00+03	2017-08-04 19:37:00+03
2273	PG0605	2017-09-12 18:40:00+03	2017-09-12 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2274	PG0605	2017-09-09 18:40:00+03	2017-09-09 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2275	PG0605	2017-08-11 18:40:00+03	2017-08-11 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-11 18:43:00+03	2017-08-11 19:38:00+03
2276	PG0605	2017-09-06 18:40:00+03	2017-09-06 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2277	PG0605	2017-07-24 18:40:00+03	2017-07-24 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-24 18:42:00+03	2017-07-24 19:38:00+03
2278	PG0605	2017-09-11 18:40:00+03	2017-09-11 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2279	PG0605	2017-08-27 18:40:00+03	2017-08-27 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2280	PG0605	2017-09-03 18:40:00+03	2017-09-03 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2281	PG0605	2017-08-09 18:40:00+03	2017-08-09 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-09 18:44:00+03	2017-08-09 19:39:00+03
2282	PG0605	2017-09-04 18:40:00+03	2017-09-04 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2283	PG0605	2017-07-31 18:40:00+03	2017-07-31 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-31 18:44:00+03	2017-07-31 19:39:00+03
2284	PG0605	2017-08-13 18:40:00+03	2017-08-13 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-13 18:40:00+03	2017-08-13 19:35:00+03
2285	PG0605	2017-08-26 18:40:00+03	2017-08-26 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2286	PG0605	2017-08-21 18:40:00+03	2017-08-21 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2287	PG0605	2017-07-20 18:40:00+03	2017-07-20 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-20 18:43:00+03	2017-07-20 19:38:00+03
2288	PG0605	2017-08-15 18:40:00+03	2017-08-15 19:35:00+03	DME	ULV	On Time	SU9	\N	\N
2289	PG0605	2017-08-22 18:40:00+03	2017-08-22 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2290	PG0605	2017-08-17 18:40:00+03	2017-08-17 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2291	PG0605	2017-08-02 18:40:00+03	2017-08-02 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-02 18:43:00+03	2017-08-02 19:39:00+03
2292	PG0605	2017-08-28 18:40:00+03	2017-08-28 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2293	PG0605	2017-09-01 18:40:00+03	2017-09-01 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2294	PG0605	2017-07-16 18:40:00+03	2017-07-16 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-16 18:43:00+03	2017-07-16 19:38:00+03
2295	PG0605	2017-08-25 18:40:00+03	2017-08-25 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2296	PG0605	2017-08-19 18:40:00+03	2017-08-19 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2297	PG0605	2017-08-12 18:40:00+03	2017-08-12 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-12 18:44:00+03	2017-08-12 19:38:00+03
2298	PG0605	2017-07-19 18:40:00+03	2017-07-19 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-19 18:45:00+03	2017-07-19 19:39:00+03
2299	PG0605	2017-07-17 18:40:00+03	2017-07-17 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-17 21:57:00+03	2017-07-17 22:51:00+03
2300	PG0605	2017-07-30 18:40:00+03	2017-07-30 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-30 18:46:00+03	2017-07-30 19:42:00+03
2301	PG0605	2017-09-08 18:40:00+03	2017-09-08 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2302	PG0605	2017-08-24 18:40:00+03	2017-08-24 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2303	PG0605	2017-08-10 18:40:00+03	2017-08-10 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-10 18:40:00+03	2017-08-10 19:35:00+03
2304	PG0605	2017-08-30 18:40:00+03	2017-08-30 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2305	PG0605	2017-08-14 18:40:00+03	2017-08-14 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-14 22:42:00+03	2017-08-14 23:37:00+03
2306	PG0605	2017-07-22 18:40:00+03	2017-07-22 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-22 18:42:00+03	2017-07-22 19:37:00+03
2307	PG0605	2017-08-03 18:40:00+03	2017-08-03 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-03 18:51:00+03	2017-08-03 19:47:00+03
2308	PG0605	2017-07-25 18:40:00+03	2017-07-25 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-25 18:42:00+03	2017-07-25 19:36:00+03
2309	PG0605	2017-09-05 18:40:00+03	2017-09-05 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2310	PG0605	2017-07-21 18:40:00+03	2017-07-21 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-21 18:43:00+03	2017-07-21 19:38:00+03
2311	PG0605	2017-09-14 18:40:00+03	2017-09-14 19:35:00+03	DME	ULV	Cancelled	SU9	\N	\N
2312	PG0605	2017-07-26 18:40:00+03	2017-07-26 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-26 18:44:00+03	2017-07-26 19:38:00+03
2313	PG0605	2017-07-29 18:40:00+03	2017-07-29 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-29 18:42:00+03	2017-07-29 19:37:00+03
2314	PG0605	2017-08-07 18:40:00+03	2017-08-07 19:35:00+03	DME	ULV	Arrived	SU9	2017-08-07 18:40:00+03	2017-08-07 19:35:00+03
2315	PG0605	2017-08-20 18:40:00+03	2017-08-20 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2316	PG0605	2017-08-18 18:40:00+03	2017-08-18 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2317	PG0605	2017-09-10 18:40:00+03	2017-09-10 19:35:00+03	DME	ULV	Scheduled	SU9	\N	\N
2318	PG0605	2017-07-23 18:40:00+03	2017-07-23 19:35:00+03	DME	ULV	Arrived	SU9	2017-07-23 18:41:00+03	2017-07-23 19:36:00+03
2319	PG0208	2017-08-02 20:40:00+03	2017-08-03 04:40:00+03	DME	KHV	Arrived	763	2017-08-02 20:44:00+03	2017-08-03 04:38:00+03
2320	PG0208	2017-09-11 20:40:00+03	2017-09-12 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2321	PG0208	2017-08-15 20:40:00+03	2017-08-16 04:40:00+03	DME	KHV	On Time	763	\N	\N
2322	PG0208	2017-08-09 20:40:00+03	2017-08-10 04:40:00+03	DME	KHV	Arrived	763	2017-08-09 20:42:00+03	2017-08-10 04:41:00+03
2323	PG0208	2017-07-16 20:40:00+03	2017-07-17 04:40:00+03	DME	KHV	Arrived	763	2017-07-16 20:42:00+03	2017-07-17 04:45:00+03
2324	PG0208	2017-07-18 20:40:00+03	2017-07-19 04:40:00+03	DME	KHV	Arrived	763	2017-07-18 20:43:00+03	2017-07-19 04:45:00+03
2325	PG0208	2017-08-13 20:40:00+03	2017-08-14 04:40:00+03	DME	KHV	Arrived	763	2017-08-13 20:45:00+03	2017-08-14 04:47:00+03
2326	PG0208	2017-07-28 20:40:00+03	2017-07-29 04:40:00+03	DME	KHV	Arrived	763	2017-07-28 20:41:00+03	2017-07-29 04:41:00+03
2327	PG0208	2017-09-03 20:40:00+03	2017-09-04 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2328	PG0208	2017-09-08 20:40:00+03	2017-09-09 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2329	PG0208	2017-07-29 20:40:00+03	2017-07-30 04:40:00+03	DME	KHV	Arrived	763	2017-07-29 20:42:00+03	2017-07-30 04:47:00+03
2330	PG0208	2017-08-07 20:40:00+03	2017-08-08 04:40:00+03	DME	KHV	Arrived	763	2017-08-07 20:43:00+03	2017-08-08 04:42:00+03
2331	PG0208	2017-07-22 20:40:00+03	2017-07-23 04:40:00+03	DME	KHV	Arrived	763	2017-07-22 20:47:00+03	2017-07-23 04:50:00+03
2332	PG0208	2017-08-03 20:40:00+03	2017-08-04 04:40:00+03	DME	KHV	Arrived	763	2017-08-04 00:03:00+03	2017-08-04 08:07:00+03
2333	PG0208	2017-09-13 20:40:00+03	2017-09-14 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2334	PG0208	2017-08-29 20:40:00+03	2017-08-30 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2335	PG0208	2017-07-21 20:40:00+03	2017-07-22 04:40:00+03	DME	KHV	Arrived	763	2017-07-21 20:42:00+03	2017-07-22 04:50:00+03
2336	PG0208	2017-08-04 20:40:00+03	2017-08-05 04:40:00+03	DME	KHV	Arrived	763	2017-08-04 20:42:00+03	2017-08-05 04:37:00+03
2337	PG0208	2017-08-17 20:40:00+03	2017-08-18 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2338	PG0208	2017-08-01 20:40:00+03	2017-08-02 04:40:00+03	DME	KHV	Arrived	763	2017-08-01 20:43:00+03	2017-08-02 04:46:00+03
2339	PG0208	2017-08-18 20:40:00+03	2017-08-19 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2340	PG0208	2017-08-27 20:40:00+03	2017-08-28 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2341	PG0208	2017-08-24 20:40:00+03	2017-08-25 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2342	PG0208	2017-07-19 20:40:00+03	2017-07-20 04:40:00+03	DME	KHV	Arrived	763	2017-07-19 20:41:00+03	2017-07-20 04:30:00+03
2343	PG0208	2017-08-11 20:40:00+03	2017-08-12 04:40:00+03	DME	KHV	Arrived	763	2017-08-11 20:41:00+03	2017-08-12 04:34:00+03
2344	PG0208	2017-08-25 20:40:00+03	2017-08-26 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2345	PG0208	2017-08-30 20:40:00+03	2017-08-31 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2346	PG0208	2017-08-08 20:40:00+03	2017-08-09 04:40:00+03	DME	KHV	Arrived	763	2017-08-08 20:44:00+03	2017-08-09 04:43:00+03
2347	PG0208	2017-08-22 20:40:00+03	2017-08-23 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2348	PG0208	2017-08-12 20:40:00+03	2017-08-13 04:40:00+03	DME	KHV	Arrived	763	2017-08-12 20:42:00+03	2017-08-13 04:28:00+03
2349	PG0208	2017-07-30 20:40:00+03	2017-07-31 04:40:00+03	DME	KHV	Arrived	763	2017-07-30 20:44:00+03	2017-07-31 04:45:00+03
2350	PG0208	2017-07-25 20:40:00+03	2017-07-26 04:40:00+03	DME	KHV	Arrived	763	2017-07-25 20:45:00+03	2017-07-26 04:53:00+03
2351	PG0208	2017-08-14 20:40:00+03	2017-08-15 04:40:00+03	DME	KHV	Arrived	763	2017-08-14 20:42:00+03	2017-08-15 04:41:00+03
2352	PG0208	2017-09-06 20:40:00+03	2017-09-07 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2353	PG0208	2017-09-14 20:40:00+03	2017-09-15 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2354	PG0208	2017-08-05 20:40:00+03	2017-08-06 04:40:00+03	DME	KHV	Arrived	763	2017-08-05 20:42:00+03	2017-08-06 04:37:00+03
2355	PG0208	2017-07-31 20:40:00+03	2017-08-01 04:40:00+03	DME	KHV	Arrived	763	2017-07-31 20:41:00+03	2017-08-01 04:36:00+03
2356	PG0208	2017-08-10 20:40:00+03	2017-08-11 04:40:00+03	DME	KHV	Arrived	763	2017-08-10 20:46:00+03	2017-08-11 04:54:00+03
2357	PG0208	2017-08-19 20:40:00+03	2017-08-20 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2358	PG0208	2017-07-27 20:40:00+03	2017-07-28 04:40:00+03	DME	KHV	Arrived	763	2017-07-27 20:40:00+03	2017-07-28 04:33:00+03
2359	PG0208	2017-08-23 20:40:00+03	2017-08-24 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2360	PG0208	2017-09-05 20:40:00+03	2017-09-06 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2361	PG0208	2017-07-20 20:40:00+03	2017-07-21 04:40:00+03	DME	KHV	Arrived	763	2017-07-20 20:43:00+03	2017-07-21 04:45:00+03
2362	PG0208	2017-07-23 20:40:00+03	2017-07-24 04:40:00+03	DME	KHV	Arrived	763	2017-07-23 23:58:00+03	2017-07-24 08:01:00+03
2363	PG0208	2017-08-20 20:40:00+03	2017-08-21 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2364	PG0208	2017-08-16 20:40:00+03	2017-08-17 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2365	PG0208	2017-07-24 20:40:00+03	2017-07-25 04:40:00+03	DME	KHV	Arrived	763	2017-07-24 20:43:00+03	2017-07-25 04:36:00+03
2366	PG0208	2017-08-21 20:40:00+03	2017-08-22 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2367	PG0208	2017-09-09 20:40:00+03	2017-09-10 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2368	PG0208	2017-09-07 20:40:00+03	2017-09-08 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2369	PG0208	2017-08-26 20:40:00+03	2017-08-27 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2370	PG0208	2017-07-17 20:40:00+03	2017-07-18 04:40:00+03	DME	KHV	Arrived	763	2017-07-17 20:42:00+03	2017-07-18 04:45:00+03
2371	PG0208	2017-08-31 20:40:00+03	2017-09-01 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2372	PG0208	2017-09-01 20:40:00+03	2017-09-02 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2373	PG0208	2017-08-06 20:40:00+03	2017-08-07 04:40:00+03	DME	KHV	Arrived	763	2017-08-06 20:42:00+03	2017-08-07 04:41:00+03
2374	PG0208	2017-09-12 20:40:00+03	2017-09-13 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2375	PG0208	2017-08-28 20:40:00+03	2017-08-29 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2376	PG0208	2017-07-26 20:40:00+03	2017-07-27 04:40:00+03	DME	KHV	Arrived	763	2017-07-26 20:45:00+03	2017-07-27 04:44:00+03
2377	PG0208	2017-09-10 20:40:00+03	2017-09-11 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2378	PG0208	2017-09-04 20:40:00+03	2017-09-05 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2379	PG0208	2017-09-02 20:40:00+03	2017-09-03 04:40:00+03	DME	KHV	Scheduled	763	\N	\N
2380	PG0657	2017-09-02 16:15:00+03	2017-09-02 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2381	PG0657	2017-07-25 16:15:00+03	2017-07-25 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-25 16:19:00+03	2017-07-25 18:36:00+03
2382	PG0657	2017-07-22 16:15:00+03	2017-07-22 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-22 16:19:00+03	2017-07-22 18:34:00+03
2383	PG0657	2017-08-10 16:15:00+03	2017-08-10 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-10 16:21:00+03	2017-08-10 18:38:00+03
2384	PG0657	2017-08-30 16:15:00+03	2017-08-30 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2385	PG0657	2017-09-07 16:15:00+03	2017-09-07 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2386	PG0657	2017-08-28 16:15:00+03	2017-08-28 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2387	PG0657	2017-08-25 16:15:00+03	2017-08-25 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2388	PG0657	2017-09-11 16:15:00+03	2017-09-11 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2389	PG0657	2017-08-17 16:15:00+03	2017-08-17 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2390	PG0657	2017-09-05 16:15:00+03	2017-09-05 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2391	PG0657	2017-07-29 16:15:00+03	2017-07-29 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-29 16:21:00+03	2017-07-29 18:38:00+03
2392	PG0657	2017-08-19 16:15:00+03	2017-08-19 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2393	PG0657	2017-09-12 16:15:00+03	2017-09-12 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2394	PG0657	2017-07-28 16:15:00+03	2017-07-28 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-28 16:19:00+03	2017-07-28 18:34:00+03
2395	PG0657	2017-08-05 16:15:00+03	2017-08-05 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-05 16:18:00+03	2017-08-05 18:32:00+03
2396	PG0657	2017-08-18 16:15:00+03	2017-08-18 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2397	PG0657	2017-08-20 16:15:00+03	2017-08-20 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2398	PG0657	2017-07-21 16:15:00+03	2017-07-21 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-21 16:19:00+03	2017-07-21 18:34:00+03
2399	PG0657	2017-08-02 16:15:00+03	2017-08-02 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-02 16:15:00+03	2017-08-02 18:30:00+03
2400	PG0657	2017-09-13 16:15:00+03	2017-09-13 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2401	PG0657	2017-08-23 16:15:00+03	2017-08-23 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2402	PG0657	2017-07-19 16:15:00+03	2017-07-19 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-19 16:16:00+03	2017-07-19 18:32:00+03
2403	PG0657	2017-08-14 16:15:00+03	2017-08-14 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-14 16:18:00+03	2017-08-14 18:35:00+03
2404	PG0657	2017-07-30 16:15:00+03	2017-07-30 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-30 16:16:00+03	2017-07-30 18:30:00+03
2405	PG0657	2017-08-09 16:15:00+03	2017-08-09 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-09 16:19:00+03	2017-08-09 18:32:00+03
2406	PG0657	2017-07-17 16:15:00+03	2017-07-17 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-17 16:18:00+03	2017-07-17 18:37:00+03
2407	PG0657	2017-08-11 16:15:00+03	2017-08-11 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-11 16:19:00+03	2017-08-11 18:34:00+03
2408	PG0657	2017-07-26 16:15:00+03	2017-07-26 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-26 16:17:00+03	2017-07-26 18:31:00+03
2409	PG0657	2017-08-22 16:15:00+03	2017-08-22 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2410	PG0657	2017-08-13 16:15:00+03	2017-08-13 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-13 16:21:00+03	2017-08-13 18:36:00+03
2411	PG0657	2017-09-03 16:15:00+03	2017-09-03 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2412	PG0657	2017-07-16 16:15:00+03	2017-07-16 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-16 16:22:00+03	2017-07-16 18:36:00+03
2413	PG0657	2017-08-03 16:15:00+03	2017-08-03 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-03 16:16:00+03	2017-08-03 18:32:00+03
2414	PG0657	2017-08-08 16:15:00+03	2017-08-08 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-08 16:20:00+03	2017-08-08 18:36:00+03
2415	PG0657	2017-09-06 16:15:00+03	2017-09-06 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2416	PG0657	2017-07-23 16:15:00+03	2017-07-23 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-23 16:20:00+03	2017-07-23 18:36:00+03
2417	PG0657	2017-08-21 16:15:00+03	2017-08-21 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2418	PG0657	2017-08-07 16:15:00+03	2017-08-07 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-07 16:21:00+03	2017-08-07 18:35:00+03
2419	PG0657	2017-08-24 16:15:00+03	2017-08-24 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2420	PG0657	2017-07-31 16:15:00+03	2017-07-31 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-31 16:18:00+03	2017-07-31 18:31:00+03
2421	PG0657	2017-09-08 16:15:00+03	2017-09-08 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2422	PG0657	2017-07-27 16:15:00+03	2017-07-27 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-27 16:19:00+03	2017-07-27 18:33:00+03
2423	PG0657	2017-08-29 16:15:00+03	2017-08-29 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2424	PG0657	2017-08-06 16:15:00+03	2017-08-06 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-06 16:20:00+03	2017-08-06 18:37:00+03
2425	PG0657	2017-08-27 16:15:00+03	2017-08-27 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2426	PG0657	2017-08-15 16:15:00+03	2017-08-15 18:30:00+03	DME	MCX	Departed	CR2	2017-08-15 16:18:00+03	\N
2427	PG0657	2017-08-16 16:15:00+03	2017-08-16 18:30:00+03	DME	MCX	On Time	CR2	\N	\N
2428	PG0657	2017-07-24 16:15:00+03	2017-07-24 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-24 16:17:00+03	2017-07-24 18:32:00+03
2429	PG0657	2017-08-01 16:15:00+03	2017-08-01 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-01 16:17:00+03	2017-08-01 18:30:00+03
2430	PG0657	2017-08-31 16:15:00+03	2017-08-31 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2431	PG0657	2017-07-18 16:15:00+03	2017-07-18 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-18 16:21:00+03	2017-07-18 18:35:00+03
2432	PG0657	2017-08-04 16:15:00+03	2017-08-04 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-04 16:15:00+03	2017-08-04 18:29:00+03
2433	PG0657	2017-09-10 16:15:00+03	2017-09-10 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2434	PG0657	2017-09-14 16:15:00+03	2017-09-14 18:30:00+03	DME	MCX	Cancelled	CR2	\N	\N
2435	PG0657	2017-08-12 16:15:00+03	2017-08-12 18:30:00+03	DME	MCX	Arrived	CR2	2017-08-12 16:21:00+03	2017-08-12 18:38:00+03
2436	PG0657	2017-07-20 16:15:00+03	2017-07-20 18:30:00+03	DME	MCX	Arrived	CR2	2017-07-20 16:18:00+03	2017-07-20 18:33:00+03
2437	PG0657	2017-09-04 16:15:00+03	2017-09-04 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2438	PG0657	2017-09-01 16:15:00+03	2017-09-01 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2439	PG0657	2017-08-26 16:15:00+03	2017-08-26 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2440	PG0657	2017-09-09 16:15:00+03	2017-09-09 18:30:00+03	DME	MCX	Scheduled	CR2	\N	\N
2441	PG0142	2017-09-12 13:00:00+03	2017-09-12 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2442	PG0142	2017-07-20 13:00:00+03	2017-07-20 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-20 13:04:00+03	2017-07-20 16:54:00+03
2443	PG0142	2017-09-02 13:00:00+03	2017-09-02 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2444	PG0142	2017-08-26 13:00:00+03	2017-08-26 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2445	PG0142	2017-07-27 13:00:00+03	2017-07-27 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-27 13:06:00+03	2017-07-27 16:54:00+03
2446	PG0142	2017-08-05 13:00:00+03	2017-08-05 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-05 13:00:00+03	2017-08-05 16:53:00+03
2447	PG0142	2017-07-25 13:00:00+03	2017-07-25 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-25 13:06:00+03	2017-07-25 16:57:00+03
2448	PG0142	2017-08-01 13:00:00+03	2017-08-01 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-01 13:02:00+03	2017-08-01 16:51:00+03
2449	PG0142	2017-08-22 13:00:00+03	2017-08-22 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2450	PG0142	2017-07-18 13:00:00+03	2017-07-18 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-18 13:03:00+03	2017-07-18 16:52:00+03
2451	PG0142	2017-09-14 13:00:00+03	2017-09-14 16:50:00+03	DME	TOF	Cancelled	SU9	\N	\N
2452	PG0142	2017-08-29 13:00:00+03	2017-08-29 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2453	PG0142	2017-08-03 13:00:00+03	2017-08-03 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-03 13:03:00+03	2017-08-03 16:55:00+03
2454	PG0142	2017-08-08 13:00:00+03	2017-08-08 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-08 13:03:00+03	2017-08-08 16:54:00+03
2455	PG0142	2017-09-07 13:00:00+03	2017-09-07 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2456	PG0142	2017-08-12 13:00:00+03	2017-08-12 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-12 13:01:00+03	2017-08-12 16:56:00+03
2457	PG0142	2017-09-05 13:00:00+03	2017-09-05 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2458	PG0142	2017-08-10 13:00:00+03	2017-08-10 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-10 13:04:00+03	2017-08-10 16:54:00+03
2459	PG0142	2017-08-24 13:00:00+03	2017-08-24 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2460	PG0142	2017-08-31 13:00:00+03	2017-08-31 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2461	PG0142	2017-08-15 13:00:00+03	2017-08-15 16:50:00+03	DME	TOF	Arrived	SU9	2017-08-15 13:04:00+03	2017-08-15 16:58:00+03
2462	PG0142	2017-07-22 13:00:00+03	2017-07-22 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-22 13:03:00+03	2017-07-22 16:53:00+03
2463	PG0142	2017-08-19 13:00:00+03	2017-08-19 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2464	PG0142	2017-07-29 13:00:00+03	2017-07-29 16:50:00+03	DME	TOF	Arrived	SU9	2017-07-29 15:21:00+03	2017-07-29 19:10:00+03
2465	PG0142	2017-09-09 13:00:00+03	2017-09-09 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2466	PG0142	2017-08-17 13:00:00+03	2017-08-17 16:50:00+03	DME	TOF	Scheduled	SU9	\N	\N
2467	PG0482	2017-08-17 09:20:00+03	2017-08-17 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2468	PG0482	2017-08-10 09:20:00+03	2017-08-10 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-10 09:25:00+03	2017-08-10 13:23:00+03
2469	PG0482	2017-08-08 09:20:00+03	2017-08-08 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-08 09:21:00+03	2017-08-08 13:22:00+03
2470	PG0482	2017-09-05 09:20:00+03	2017-09-05 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2471	PG0482	2017-09-14 09:20:00+03	2017-09-14 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2472	PG0482	2017-08-13 09:20:00+03	2017-08-13 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-13 09:20:00+03	2017-08-13 13:22:00+03
2473	PG0482	2017-08-15 09:20:00+03	2017-08-15 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-15 09:20:00+03	2017-08-15 13:18:00+03
2474	PG0482	2017-08-27 09:20:00+03	2017-08-27 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2475	PG0482	2017-08-29 09:20:00+03	2017-08-29 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2476	PG0482	2017-08-24 09:20:00+03	2017-08-24 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2477	PG0482	2017-08-01 09:20:00+03	2017-08-01 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-01 09:24:00+03	2017-08-01 13:20:00+03
2478	PG0482	2017-07-23 09:20:00+03	2017-07-23 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-23 09:22:00+03	2017-07-23 13:22:00+03
2479	PG0482	2017-07-30 09:20:00+03	2017-07-30 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-30 09:23:00+03	2017-07-30 13:22:00+03
2480	PG0482	2017-07-27 09:20:00+03	2017-07-27 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-27 09:24:00+03	2017-07-27 13:24:00+03
2481	PG0482	2017-08-31 09:20:00+03	2017-08-31 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2482	PG0482	2017-09-10 09:20:00+03	2017-09-10 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2483	PG0482	2017-09-03 09:20:00+03	2017-09-03 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2484	PG0482	2017-08-06 09:20:00+03	2017-08-06 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-06 09:21:00+03	2017-08-06 13:16:00+03
2485	PG0482	2017-07-16 09:20:00+03	2017-07-16 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-16 09:25:00+03	2017-07-16 13:28:00+03
2486	PG0482	2017-07-20 09:20:00+03	2017-07-20 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-20 09:23:00+03	2017-07-20 13:22:00+03
2487	PG0482	2017-07-25 09:20:00+03	2017-07-25 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-25 09:23:00+03	2017-07-25 13:20:00+03
2488	PG0482	2017-09-12 09:20:00+03	2017-09-12 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2489	PG0482	2017-09-07 09:20:00+03	2017-09-07 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2490	PG0482	2017-08-03 09:20:00+03	2017-08-03 13:20:00+03	DME	KEJ	Arrived	SU9	2017-08-03 09:23:00+03	2017-08-03 13:24:00+03
2491	PG0482	2017-07-18 09:20:00+03	2017-07-18 13:20:00+03	DME	KEJ	Arrived	SU9	2017-07-18 09:21:00+03	2017-07-18 13:21:00+03
2492	PG0482	2017-08-20 09:20:00+03	2017-08-20 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2493	PG0482	2017-08-22 09:20:00+03	2017-08-22 13:20:00+03	DME	KEJ	Scheduled	SU9	\N	\N
2494	PG0607	2017-07-24 16:15:00+03	2017-07-24 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-24 16:19:00+03	2017-07-24 18:05:00+03
2495	PG0607	2017-08-01 16:15:00+03	2017-08-01 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-01 16:18:00+03	2017-08-01 18:03:00+03
2496	PG0607	2017-08-04 16:15:00+03	2017-08-04 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-04 19:49:00+03	2017-08-04 21:34:00+03
2497	PG0607	2017-08-02 16:15:00+03	2017-08-02 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-02 16:20:00+03	2017-08-02 18:05:00+03
2498	PG0607	2017-08-15 16:15:00+03	2017-08-15 18:00:00+03	DME	ASF	Departed	CR2	2017-08-15 16:18:00+03	\N
2499	PG0607	2017-09-03 16:15:00+03	2017-09-03 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2500	PG0607	2017-07-31 16:15:00+03	2017-07-31 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-31 16:15:00+03	2017-07-31 18:00:00+03
2501	PG0607	2017-09-05 16:15:00+03	2017-09-05 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2502	PG0607	2017-07-29 16:15:00+03	2017-07-29 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-29 16:17:00+03	2017-07-29 18:01:00+03
2503	PG0607	2017-08-14 16:15:00+03	2017-08-14 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-14 16:17:00+03	2017-08-14 18:03:00+03
2504	PG0607	2017-09-04 16:15:00+03	2017-09-04 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2505	PG0607	2017-08-22 16:15:00+03	2017-08-22 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2506	PG0607	2017-09-12 16:15:00+03	2017-09-12 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2507	PG0607	2017-09-06 16:15:00+03	2017-09-06 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2508	PG0607	2017-08-03 16:15:00+03	2017-08-03 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-03 16:17:00+03	2017-08-03 18:03:00+03
2509	PG0607	2017-07-22 16:15:00+03	2017-07-22 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-22 16:17:00+03	2017-07-22 18:02:00+03
2510	PG0607	2017-08-17 16:15:00+03	2017-08-17 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2511	PG0607	2017-08-20 16:15:00+03	2017-08-20 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2512	PG0607	2017-08-08 16:15:00+03	2017-08-08 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-08 16:20:00+03	2017-08-08 18:04:00+03
2513	PG0607	2017-09-13 16:15:00+03	2017-09-13 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2514	PG0607	2017-08-23 16:15:00+03	2017-08-23 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2515	PG0607	2017-08-09 16:15:00+03	2017-08-09 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-09 16:16:00+03	2017-08-09 18:01:00+03
2516	PG0607	2017-08-06 16:15:00+03	2017-08-06 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-06 16:18:00+03	2017-08-06 18:04:00+03
2517	PG0607	2017-07-20 16:15:00+03	2017-07-20 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-20 19:37:00+03	2017-07-20 21:24:00+03
2518	PG0607	2017-08-19 16:15:00+03	2017-08-19 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2519	PG0607	2017-08-28 16:15:00+03	2017-08-28 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2520	PG0607	2017-07-18 16:15:00+03	2017-07-18 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-18 16:16:00+03	2017-07-18 17:59:00+03
2521	PG0607	2017-07-23 16:15:00+03	2017-07-23 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-23 16:16:00+03	2017-07-23 17:59:00+03
2522	PG0607	2017-09-11 16:15:00+03	2017-09-11 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2523	PG0607	2017-08-16 16:15:00+03	2017-08-16 18:00:00+03	DME	ASF	On Time	CR2	\N	\N
2524	PG0607	2017-07-28 16:15:00+03	2017-07-28 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-28 16:16:00+03	2017-07-28 18:02:00+03
2525	PG0607	2017-07-16 16:15:00+03	2017-07-16 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-16 16:18:00+03	2017-07-16 18:04:00+03
2526	PG0607	2017-09-09 16:15:00+03	2017-09-09 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2527	PG0607	2017-07-27 16:15:00+03	2017-07-27 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-27 16:16:00+03	2017-07-27 17:59:00+03
2528	PG0607	2017-08-31 16:15:00+03	2017-08-31 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2529	PG0607	2017-07-26 16:15:00+03	2017-07-26 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-26 16:21:00+03	2017-07-26 18:05:00+03
2530	PG0607	2017-08-18 16:15:00+03	2017-08-18 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2531	PG0607	2017-08-29 16:15:00+03	2017-08-29 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2532	PG0607	2017-08-24 16:15:00+03	2017-08-24 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2533	PG0607	2017-09-08 16:15:00+03	2017-09-08 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2534	PG0607	2017-07-30 16:15:00+03	2017-07-30 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-30 16:17:00+03	2017-07-30 18:00:00+03
2535	PG0607	2017-09-02 16:15:00+03	2017-09-02 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2536	PG0607	2017-08-07 16:15:00+03	2017-08-07 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-07 16:18:00+03	2017-08-07 18:04:00+03
2537	PG0607	2017-09-07 16:15:00+03	2017-09-07 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2538	PG0607	2017-08-13 16:15:00+03	2017-08-13 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-13 16:17:00+03	2017-08-13 18:02:00+03
2539	PG0607	2017-09-01 16:15:00+03	2017-09-01 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2540	PG0607	2017-07-17 16:15:00+03	2017-07-17 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-17 16:17:00+03	2017-07-17 18:02:00+03
2541	PG0607	2017-08-11 16:15:00+03	2017-08-11 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-11 16:19:00+03	2017-08-11 18:03:00+03
2542	PG0607	2017-07-25 16:15:00+03	2017-07-25 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-25 16:19:00+03	2017-07-25 18:04:00+03
2543	PG0607	2017-07-21 16:15:00+03	2017-07-21 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-21 16:17:00+03	2017-07-21 18:01:00+03
2544	PG0607	2017-08-25 16:15:00+03	2017-08-25 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2545	PG0607	2017-08-12 16:15:00+03	2017-08-12 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-12 16:17:00+03	2017-08-12 18:00:00+03
2546	PG0607	2017-07-19 16:15:00+03	2017-07-19 18:00:00+03	DME	ASF	Arrived	CR2	2017-07-19 16:18:00+03	2017-07-19 18:05:00+03
2547	PG0607	2017-09-10 16:15:00+03	2017-09-10 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2548	PG0607	2017-08-10 16:15:00+03	2017-08-10 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-10 16:18:00+03	2017-08-10 18:02:00+03
2549	PG0607	2017-08-21 16:15:00+03	2017-08-21 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2550	PG0607	2017-08-30 16:15:00+03	2017-08-30 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2551	PG0607	2017-08-27 16:15:00+03	2017-08-27 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2552	PG0607	2017-09-14 16:15:00+03	2017-09-14 18:00:00+03	DME	ASF	Cancelled	CR2	\N	\N
2553	PG0607	2017-08-05 16:15:00+03	2017-08-05 18:00:00+03	DME	ASF	Arrived	CR2	2017-08-05 16:21:00+03	2017-08-05 18:06:00+03
2554	PG0607	2017-08-26 16:15:00+03	2017-08-26 18:00:00+03	DME	ASF	Scheduled	CR2	\N	\N
2555	PG0029	2017-09-09 09:40:00+03	2017-09-09 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2556	PG0030	2017-09-12 11:55:00+03	2017-09-12 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2557	PG0029	2017-07-31 09:40:00+03	2017-07-31 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-31 09:43:00+03	2017-07-31 11:27:00+03
2558	PG0030	2017-07-31 11:55:00+03	2017-07-31 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-31 12:03:00+03	2017-07-31 13:48:00+03
2559	PG0030	2017-07-19 11:55:00+03	2017-07-19 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-19 12:00:00+03	2017-07-19 13:44:00+03
2560	PG0029	2017-07-25 09:40:00+03	2017-07-25 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-25 09:45:00+03	2017-07-25 11:29:00+03
2561	PG0029	2017-07-19 09:40:00+03	2017-07-19 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-19 09:44:00+03	2017-07-19 11:27:00+03
2562	PG0030	2017-08-12 11:55:00+03	2017-08-12 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-12 11:57:00+03	2017-08-12 13:41:00+03
2563	PG0029	2017-07-29 09:40:00+03	2017-07-29 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-29 09:41:00+03	2017-07-29 11:26:00+03
2564	PG0030	2017-07-29 11:55:00+03	2017-07-29 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-29 12:00:00+03	2017-07-29 13:46:00+03
2565	PG0030	2017-09-08 11:55:00+03	2017-09-08 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2566	PG0030	2017-09-07 11:55:00+03	2017-09-07 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2567	PG0029	2017-08-18 09:40:00+03	2017-08-18 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2568	PG0030	2017-08-29 11:55:00+03	2017-08-29 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2569	PG0029	2017-07-17 09:40:00+03	2017-07-17 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-17 09:44:00+03	2017-07-17 11:29:00+03
2570	PG0030	2017-07-17 11:55:00+03	2017-07-17 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-17 11:55:00+03	2017-07-17 13:40:00+03
2571	PG0029	2017-09-07 09:40:00+03	2017-09-07 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2572	PG0029	2017-08-10 09:40:00+03	2017-08-10 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-10 09:40:00+03	2017-08-10 11:22:00+03
2573	PG0030	2017-08-10 11:55:00+03	2017-08-10 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-10 11:59:00+03	2017-08-10 13:43:00+03
2574	PG0030	2017-09-03 11:55:00+03	2017-09-03 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2575	PG0029	2017-07-16 09:40:00+03	2017-07-16 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-16 09:41:00+03	2017-07-16 11:27:00+03
2576	PG0029	2017-08-28 09:40:00+03	2017-08-28 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2577	PG0029	2017-07-27 09:40:00+03	2017-07-27 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-27 09:42:00+03	2017-07-27 11:27:00+03
2578	PG0030	2017-07-27 11:55:00+03	2017-07-27 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-27 11:56:00+03	2017-07-27 13:41:00+03
2579	PG0029	2017-08-22 09:40:00+03	2017-08-22 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2580	PG0030	2017-09-05 11:55:00+03	2017-09-05 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2581	PG0029	2017-08-29 09:40:00+03	2017-08-29 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2582	PG0030	2017-09-11 11:55:00+03	2017-09-11 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2583	PG0030	2017-08-28 11:55:00+03	2017-08-28 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2584	PG0029	2017-09-11 09:40:00+03	2017-09-11 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2585	PG0029	2017-08-12 09:40:00+03	2017-08-12 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-12 09:41:00+03	2017-08-12 11:26:00+03
2586	PG0030	2017-09-01 11:55:00+03	2017-09-01 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2587	PG0030	2017-09-06 11:55:00+03	2017-09-06 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2588	PG0030	2017-08-22 11:55:00+03	2017-08-22 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2589	PG0030	2017-07-28 11:55:00+03	2017-07-28 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-28 11:58:00+03	2017-07-28 13:41:00+03
2590	PG0029	2017-07-28 09:40:00+03	2017-07-28 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-28 09:47:00+03	2017-07-28 11:33:00+03
2591	PG0029	2017-07-20 09:40:00+03	2017-07-20 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-20 09:45:00+03	2017-07-20 11:29:00+03
2592	PG0029	2017-09-05 09:40:00+03	2017-09-05 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2593	PG0029	2017-08-14 09:40:00+03	2017-08-14 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-14 09:41:00+03	2017-08-14 11:27:00+03
2594	PG0030	2017-07-20 11:55:00+03	2017-07-20 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-20 11:57:00+03	2017-07-20 13:42:00+03
2595	PG0030	2017-08-24 11:55:00+03	2017-08-24 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2596	PG0030	2017-08-08 11:55:00+03	2017-08-08 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-08 11:57:00+03	2017-08-08 13:40:00+03
2597	PG0030	2017-08-26 11:55:00+03	2017-08-26 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2598	PG0029	2017-08-06 09:40:00+03	2017-08-06 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-06 09:41:00+03	2017-08-06 11:26:00+03
2599	PG0030	2017-08-06 11:55:00+03	2017-08-06 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-06 11:56:00+03	2017-08-06 13:40:00+03
2600	PG0029	2017-08-15 09:40:00+03	2017-08-15 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-15 09:41:00+03	2017-08-15 11:26:00+03
2601	PG0029	2017-08-30 09:40:00+03	2017-08-30 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2602	PG0030	2017-08-30 11:55:00+03	2017-08-30 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2603	PG0030	2017-08-25 11:55:00+03	2017-08-25 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2604	PG0030	2017-08-31 11:55:00+03	2017-08-31 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2605	PG0029	2017-08-31 09:40:00+03	2017-08-31 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2606	PG0030	2017-08-15 11:55:00+03	2017-08-15 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-15 15:18:00+03	2017-08-15 17:03:00+03
2607	PG0029	2017-08-16 09:40:00+03	2017-08-16 11:25:00+03	DME	PEZ	On Time	CN1	\N	\N
2608	PG0030	2017-08-19 11:55:00+03	2017-08-19 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2609	PG0029	2017-09-14 09:40:00+03	2017-09-14 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2610	PG0029	2017-09-13 09:40:00+03	2017-09-13 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2611	PG0029	2017-09-01 09:40:00+03	2017-09-01 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2612	PG0030	2017-08-14 11:55:00+03	2017-08-14 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-14 11:58:00+03	2017-08-14 13:43:00+03
2613	PG0029	2017-08-01 09:40:00+03	2017-08-01 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-01 09:42:00+03	2017-08-01 11:26:00+03
2614	PG0030	2017-08-01 11:55:00+03	2017-08-01 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-01 11:56:00+03	2017-08-01 13:42:00+03
2615	PG0030	2017-08-16 11:55:00+03	2017-08-16 13:40:00+03	DME	PEZ	On Time	CN1	\N	\N
2616	PG0030	2017-08-02 11:55:00+03	2017-08-02 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-02 11:59:00+03	2017-08-02 13:44:00+03
2617	PG0029	2017-08-04 09:40:00+03	2017-08-04 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-04 09:44:00+03	2017-08-04 11:27:00+03
2618	PG0029	2017-08-02 09:40:00+03	2017-08-02 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-02 09:44:00+03	2017-08-02 11:29:00+03
2619	PG0030	2017-09-09 11:55:00+03	2017-09-09 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2620	PG0030	2017-08-04 11:55:00+03	2017-08-04 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-04 11:56:00+03	2017-08-04 13:38:00+03
2621	PG0030	2017-07-30 11:55:00+03	2017-07-30 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-30 11:58:00+03	2017-07-30 13:43:00+03
2622	PG0029	2017-07-21 09:40:00+03	2017-07-21 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-21 09:41:00+03	2017-07-21 11:28:00+03
2623	PG0030	2017-07-21 11:55:00+03	2017-07-21 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-21 11:58:00+03	2017-07-21 13:44:00+03
2624	PG0030	2017-09-02 11:55:00+03	2017-09-02 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2625	PG0029	2017-09-02 09:40:00+03	2017-09-02 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2626	PG0029	2017-08-20 09:40:00+03	2017-08-20 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2627	PG0029	2017-08-08 09:40:00+03	2017-08-08 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-08 09:41:00+03	2017-08-08 11:26:00+03
2628	PG0029	2017-07-24 09:40:00+03	2017-07-24 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-24 09:42:00+03	2017-07-24 11:26:00+03
2629	PG0030	2017-07-24 11:55:00+03	2017-07-24 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-24 11:59:00+03	2017-07-24 13:44:00+03
2630	PG0030	2017-08-13 11:55:00+03	2017-08-13 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-13 11:57:00+03	2017-08-13 13:43:00+03
2631	PG0030	2017-08-11 11:55:00+03	2017-08-11 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-11 11:58:00+03	2017-08-11 13:42:00+03
2632	PG0029	2017-08-21 09:40:00+03	2017-08-21 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2633	PG0029	2017-08-13 09:40:00+03	2017-08-13 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-13 09:44:00+03	2017-08-13 11:28:00+03
2634	PG0030	2017-08-21 11:55:00+03	2017-08-21 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2635	PG0029	2017-08-26 09:40:00+03	2017-08-26 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2636	PG0030	2017-08-05 11:55:00+03	2017-08-05 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-05 11:57:00+03	2017-08-05 13:42:00+03
2637	PG0029	2017-08-05 09:40:00+03	2017-08-05 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-05 09:43:00+03	2017-08-05 11:29:00+03
2638	PG0029	2017-07-30 09:40:00+03	2017-07-30 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-30 09:41:00+03	2017-07-30 11:28:00+03
2639	PG0029	2017-08-27 09:40:00+03	2017-08-27 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2640	PG0030	2017-08-20 11:55:00+03	2017-08-20 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2641	PG0030	2017-08-27 11:55:00+03	2017-08-27 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2642	PG0030	2017-07-22 11:55:00+03	2017-07-22 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-22 11:57:00+03	2017-07-22 13:44:00+03
2643	PG0029	2017-07-22 09:40:00+03	2017-07-22 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-22 09:41:00+03	2017-07-22 11:26:00+03
2644	PG0029	2017-08-11 09:40:00+03	2017-08-11 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-11 09:43:00+03	2017-08-11 11:30:00+03
2645	PG0030	2017-07-16 11:55:00+03	2017-07-16 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-16 12:00:00+03	2017-07-16 13:46:00+03
2646	PG0029	2017-08-17 09:40:00+03	2017-08-17 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2647	PG0030	2017-08-17 11:55:00+03	2017-08-17 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2648	PG0030	2017-07-26 11:55:00+03	2017-07-26 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-26 14:45:00+03	2017-07-26 16:32:00+03
2649	PG0029	2017-08-07 09:40:00+03	2017-08-07 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-07 09:42:00+03	2017-08-07 11:25:00+03
2650	PG0030	2017-08-07 11:55:00+03	2017-08-07 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-07 15:50:00+03	2017-08-07 17:36:00+03
2651	PG0029	2017-08-24 09:40:00+03	2017-08-24 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2652	PG0030	2017-09-10 11:55:00+03	2017-09-10 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2653	PG0029	2017-08-23 09:40:00+03	2017-08-23 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2654	PG0030	2017-08-23 11:55:00+03	2017-08-23 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2655	PG0030	2017-07-23 11:55:00+03	2017-07-23 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-23 11:55:00+03	2017-07-23 13:40:00+03
2656	PG0029	2017-07-23 09:40:00+03	2017-07-23 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-23 09:44:00+03	2017-07-23 11:29:00+03
2657	PG0029	2017-09-10 09:40:00+03	2017-09-10 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2658	PG0029	2017-07-26 09:40:00+03	2017-07-26 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-26 12:31:00+03	2017-07-26 14:16:00+03
2659	PG0029	2017-09-03 09:40:00+03	2017-09-03 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2660	PG0030	2017-07-18 11:55:00+03	2017-07-18 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-18 11:57:00+03	2017-07-18 13:41:00+03
2661	PG0029	2017-08-03 09:40:00+03	2017-08-03 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-03 09:42:00+03	2017-08-03 11:27:00+03
2662	PG0029	2017-07-18 09:40:00+03	2017-07-18 11:25:00+03	DME	PEZ	Arrived	CN1	2017-07-18 09:44:00+03	2017-07-18 11:28:00+03
2663	PG0029	2017-09-06 09:40:00+03	2017-09-06 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2664	PG0030	2017-07-25 11:55:00+03	2017-07-25 13:40:00+03	DME	PEZ	Arrived	CN1	2017-07-25 11:57:00+03	2017-07-25 13:41:00+03
2665	PG0029	2017-08-19 09:40:00+03	2017-08-19 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2666	PG0029	2017-09-08 09:40:00+03	2017-09-08 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2667	PG0029	2017-09-04 09:40:00+03	2017-09-04 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2668	PG0030	2017-09-04 11:55:00+03	2017-09-04 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2669	PG0030	2017-09-13 11:55:00+03	2017-09-13 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2670	PG0030	2017-08-03 11:55:00+03	2017-08-03 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-03 11:57:00+03	2017-08-03 13:41:00+03
2671	PG0029	2017-08-09 09:40:00+03	2017-08-09 11:25:00+03	DME	PEZ	Arrived	CN1	2017-08-09 09:44:00+03	2017-08-09 11:30:00+03
2672	PG0030	2017-08-09 11:55:00+03	2017-08-09 13:40:00+03	DME	PEZ	Arrived	CN1	2017-08-09 11:56:00+03	2017-08-09 13:39:00+03
2673	PG0029	2017-08-25 09:40:00+03	2017-08-25 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2674	PG0030	2017-09-14 11:55:00+03	2017-09-14 13:40:00+03	DME	PEZ	Cancelled	CN1	\N	\N
2675	PG0029	2017-09-12 09:40:00+03	2017-09-12 11:25:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2676	PG0030	2017-08-18 11:55:00+03	2017-08-18 13:40:00+03	DME	PEZ	Scheduled	CN1	\N	\N
2677	PG0085	2017-07-30 13:05:00+03	2017-07-30 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-30 13:05:00+03	2017-07-30 14:10:00+03
2678	PG0085	2017-07-21 13:05:00+03	2017-07-21 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-21 13:09:00+03	2017-07-21 14:14:00+03
2679	PG0085	2017-08-04 13:05:00+03	2017-08-04 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-04 13:09:00+03	2017-08-04 14:14:00+03
2680	PG0085	2017-08-11 13:05:00+03	2017-08-11 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-11 13:08:00+03	2017-08-11 14:12:00+03
2681	PG0085	2017-07-23 13:05:00+03	2017-07-23 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-23 13:08:00+03	2017-07-23 14:12:00+03
2682	PG0085	2017-09-06 13:05:00+03	2017-09-06 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2683	PG0085	2017-08-30 13:05:00+03	2017-08-30 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2684	PG0085	2017-08-18 13:05:00+03	2017-08-18 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2685	PG0085	2017-09-13 13:05:00+03	2017-09-13 14:10:00+03	DME	LPK	Cancelled	CN1	\N	\N
2686	PG0085	2017-08-16 13:05:00+03	2017-08-16 14:10:00+03	DME	LPK	On Time	CN1	\N	\N
2687	PG0085	2017-08-25 13:05:00+03	2017-08-25 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2688	PG0085	2017-09-08 13:05:00+03	2017-09-08 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2689	PG0085	2017-07-19 13:05:00+03	2017-07-19 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-19 16:33:00+03	2017-07-19 17:37:00+03
2690	PG0085	2017-08-02 13:05:00+03	2017-08-02 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-02 13:08:00+03	2017-08-02 14:13:00+03
2691	PG0085	2017-08-06 13:05:00+03	2017-08-06 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-06 13:09:00+03	2017-08-06 14:14:00+03
2692	PG0085	2017-08-13 13:05:00+03	2017-08-13 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-13 13:09:00+03	2017-08-13 14:15:00+03
2693	PG0085	2017-09-03 13:05:00+03	2017-09-03 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2694	PG0085	2017-08-20 13:05:00+03	2017-08-20 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2695	PG0085	2017-07-26 13:05:00+03	2017-07-26 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-26 13:08:00+03	2017-07-26 14:13:00+03
2696	PG0085	2017-09-01 13:05:00+03	2017-09-01 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2697	PG0085	2017-08-27 13:05:00+03	2017-08-27 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2698	PG0085	2017-07-16 13:05:00+03	2017-07-16 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-16 13:07:00+03	2017-07-16 14:12:00+03
2699	PG0085	2017-09-10 13:05:00+03	2017-09-10 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2700	PG0085	2017-08-23 13:05:00+03	2017-08-23 14:10:00+03	DME	LPK	Scheduled	CN1	\N	\N
2701	PG0085	2017-08-09 13:05:00+03	2017-08-09 14:10:00+03	DME	LPK	Arrived	CN1	2017-08-09 13:07:00+03	2017-08-09 14:12:00+03
2702	PG0085	2017-07-28 13:05:00+03	2017-07-28 14:10:00+03	DME	LPK	Arrived	CN1	2017-07-28 13:08:00+03	2017-07-28 14:13:00+03
2703	PG0593	2017-08-23 15:50:00+03	2017-08-23 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2704	PG0593	2017-08-14 15:50:00+03	2017-08-14 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-14 15:54:00+03	2017-08-14 18:26:00+03
2705	PG0593	2017-08-01 15:50:00+03	2017-08-01 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-01 15:51:00+03	2017-08-01 18:19:00+03
2706	PG0593	2017-09-12 15:50:00+03	2017-09-12 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2707	PG0593	2017-09-14 15:50:00+03	2017-09-14 18:20:00+03	DME	KVX	Cancelled	CN1	\N	\N
2708	PG0593	2017-08-07 15:50:00+03	2017-08-07 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-07 15:51:00+03	2017-08-07 18:21:00+03
2709	PG0593	2017-07-27 15:50:00+03	2017-07-27 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-27 15:51:00+03	2017-07-27 18:21:00+03
2710	PG0593	2017-08-24 15:50:00+03	2017-08-24 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2711	PG0593	2017-08-12 15:50:00+03	2017-08-12 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-12 15:51:00+03	2017-08-12 18:20:00+03
2712	PG0593	2017-09-13 15:50:00+03	2017-09-13 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2713	PG0593	2017-08-17 15:50:00+03	2017-08-17 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2714	PG0593	2017-08-28 15:50:00+03	2017-08-28 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2715	PG0593	2017-07-26 15:50:00+03	2017-07-26 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-26 15:55:00+03	2017-07-26 18:23:00+03
2716	PG0593	2017-09-02 15:50:00+03	2017-09-02 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2717	PG0593	2017-07-28 15:50:00+03	2017-07-28 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-28 15:52:00+03	2017-07-28 18:22:00+03
2718	PG0593	2017-07-20 15:50:00+03	2017-07-20 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-20 15:53:00+03	2017-07-20 18:21:00+03
2719	PG0593	2017-09-05 15:50:00+03	2017-09-05 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2720	PG0593	2017-08-08 15:50:00+03	2017-08-08 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-08 15:52:00+03	2017-08-08 18:23:00+03
2721	PG0593	2017-08-29 15:50:00+03	2017-08-29 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2722	PG0593	2017-08-15 15:50:00+03	2017-08-15 18:20:00+03	DME	KVX	Departed	CN1	2017-08-15 15:51:00+03	\N
2723	PG0593	2017-07-21 15:50:00+03	2017-07-21 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-21 15:52:00+03	2017-07-21 18:25:00+03
2724	PG0593	2017-09-07 15:50:00+03	2017-09-07 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2725	PG0593	2017-07-16 15:50:00+03	2017-07-16 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-16 15:53:00+03	2017-07-16 18:21:00+03
2726	PG0593	2017-08-06 15:50:00+03	2017-08-06 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-06 15:55:00+03	2017-08-06 18:26:00+03
2727	PG0593	2017-08-26 15:50:00+03	2017-08-26 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2728	PG0593	2017-09-06 15:50:00+03	2017-09-06 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2729	PG0593	2017-08-21 15:50:00+03	2017-08-21 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2730	PG0593	2017-09-10 15:50:00+03	2017-09-10 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2731	PG0593	2017-08-09 15:50:00+03	2017-08-09 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-09 15:50:00+03	2017-08-09 18:22:00+03
2732	PG0593	2017-08-11 15:50:00+03	2017-08-11 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-11 15:54:00+03	2017-08-11 18:25:00+03
2733	PG0593	2017-09-04 15:50:00+03	2017-09-04 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2734	PG0593	2017-07-18 15:50:00+03	2017-07-18 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-18 15:52:00+03	2017-07-18 18:21:00+03
2735	PG0593	2017-08-22 15:50:00+03	2017-08-22 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2736	PG0593	2017-09-03 15:50:00+03	2017-09-03 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2737	PG0593	2017-08-16 15:50:00+03	2017-08-16 18:20:00+03	DME	KVX	Delayed	CN1	\N	\N
2738	PG0593	2017-08-05 15:50:00+03	2017-08-05 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-05 19:26:00+03	2017-08-05 21:56:00+03
2739	PG0593	2017-07-23 15:50:00+03	2017-07-23 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-23 15:53:00+03	2017-07-23 18:23:00+03
2740	PG0593	2017-08-02 15:50:00+03	2017-08-02 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-02 15:53:00+03	2017-08-02 18:23:00+03
2741	PG0593	2017-08-25 15:50:00+03	2017-08-25 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2742	PG0593	2017-08-20 15:50:00+03	2017-08-20 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2743	PG0593	2017-07-29 15:50:00+03	2017-07-29 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-29 15:54:00+03	2017-07-29 18:24:00+03
2744	PG0593	2017-08-19 15:50:00+03	2017-08-19 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2745	PG0593	2017-07-19 15:50:00+03	2017-07-19 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-19 15:55:00+03	2017-07-19 18:27:00+03
2746	PG0593	2017-07-31 15:50:00+03	2017-07-31 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-31 15:51:00+03	2017-07-31 18:20:00+03
2747	PG0593	2017-07-24 15:50:00+03	2017-07-24 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-24 15:53:00+03	2017-07-24 18:21:00+03
2748	PG0593	2017-08-03 15:50:00+03	2017-08-03 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-03 15:53:00+03	2017-08-03 18:23:00+03
2749	PG0593	2017-09-08 15:50:00+03	2017-09-08 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2750	PG0593	2017-08-30 15:50:00+03	2017-08-30 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2751	PG0593	2017-08-04 15:50:00+03	2017-08-04 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-04 15:53:00+03	2017-08-04 18:23:00+03
2752	PG0593	2017-07-25 15:50:00+03	2017-07-25 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-25 15:54:00+03	2017-07-25 18:24:00+03
2753	PG0593	2017-07-30 15:50:00+03	2017-07-30 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-30 15:53:00+03	2017-07-30 18:23:00+03
2754	PG0593	2017-07-22 15:50:00+03	2017-07-22 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-22 15:53:00+03	2017-07-22 18:22:00+03
2755	PG0593	2017-08-31 15:50:00+03	2017-08-31 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2756	PG0593	2017-08-18 15:50:00+03	2017-08-18 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2757	PG0593	2017-08-10 15:50:00+03	2017-08-10 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-10 15:57:00+03	2017-08-10 18:26:00+03
2758	PG0593	2017-07-17 15:50:00+03	2017-07-17 18:20:00+03	DME	KVX	Arrived	CN1	2017-07-17 15:51:00+03	2017-07-17 18:22:00+03
2759	PG0593	2017-08-27 15:50:00+03	2017-08-27 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2760	PG0593	2017-08-13 15:50:00+03	2017-08-13 18:20:00+03	DME	KVX	Arrived	CN1	2017-08-13 15:52:00+03	2017-08-13 18:23:00+03
2761	PG0593	2017-09-01 15:50:00+03	2017-09-01 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2762	PG0593	2017-09-09 15:50:00+03	2017-09-09 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2763	PG0593	2017-09-11 15:50:00+03	2017-09-11 18:20:00+03	DME	KVX	Scheduled	CN1	\N	\N
2764	PG0196	2017-09-05 12:10:00+03	2017-09-05 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2765	PG0196	2017-08-09 12:10:00+03	2017-08-09 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-09 12:13:00+03	2017-08-09 13:42:00+03
2766	PG0196	2017-08-06 12:10:00+03	2017-08-06 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-06 12:15:00+03	2017-08-06 13:45:00+03
2767	PG0196	2017-07-18 12:10:00+03	2017-07-18 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-18 12:14:00+03	2017-07-18 13:44:00+03
2768	PG0196	2017-08-27 12:10:00+03	2017-08-27 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2769	PG0196	2017-07-25 12:10:00+03	2017-07-25 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-25 12:11:00+03	2017-07-25 13:41:00+03
2770	PG0196	2017-07-31 12:10:00+03	2017-07-31 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-31 12:12:00+03	2017-07-31 13:41:00+03
2771	PG0196	2017-07-20 12:10:00+03	2017-07-20 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-20 12:15:00+03	2017-07-20 13:46:00+03
2772	PG0196	2017-08-13 12:10:00+03	2017-08-13 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-13 12:14:00+03	2017-08-13 13:44:00+03
2773	PG0196	2017-09-04 12:10:00+03	2017-09-04 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2774	PG0196	2017-08-15 12:10:00+03	2017-08-15 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-15 12:14:00+03	2017-08-15 13:44:00+03
2775	PG0196	2017-09-10 12:10:00+03	2017-09-10 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2776	PG0196	2017-09-11 12:10:00+03	2017-09-11 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2777	PG0196	2017-07-28 12:10:00+03	2017-07-28 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-28 12:12:00+03	2017-07-28 13:41:00+03
2778	PG0196	2017-08-31 12:10:00+03	2017-08-31 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2779	PG0196	2017-09-02 12:10:00+03	2017-09-02 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2780	PG0196	2017-09-01 12:10:00+03	2017-09-01 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2781	PG0196	2017-08-26 12:10:00+03	2017-08-26 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2782	PG0196	2017-08-20 12:10:00+03	2017-08-20 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2783	PG0196	2017-08-16 12:10:00+03	2017-08-16 13:40:00+03	DME	KGD	On Time	SU9	\N	\N
2784	PG0196	2017-08-10 12:10:00+03	2017-08-10 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-10 12:13:00+03	2017-08-10 13:44:00+03
2785	PG0196	2017-07-23 12:10:00+03	2017-07-23 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-23 12:14:00+03	2017-07-23 13:45:00+03
2786	PG0196	2017-08-05 12:10:00+03	2017-08-05 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-05 12:13:00+03	2017-08-05 13:44:00+03
2787	PG0196	2017-08-21 12:10:00+03	2017-08-21 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2788	PG0196	2017-08-23 12:10:00+03	2017-08-23 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2789	PG0196	2017-08-22 12:10:00+03	2017-08-22 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2790	PG0196	2017-09-13 12:10:00+03	2017-09-13 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2791	PG0196	2017-08-19 12:10:00+03	2017-08-19 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2792	PG0196	2017-08-01 12:10:00+03	2017-08-01 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-01 12:15:00+03	2017-08-01 13:44:00+03
2793	PG0196	2017-07-29 12:10:00+03	2017-07-29 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-29 15:53:00+03	2017-07-29 17:23:00+03
2794	PG0196	2017-09-08 12:10:00+03	2017-09-08 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2795	PG0196	2017-08-25 12:10:00+03	2017-08-25 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2796	PG0196	2017-07-16 12:10:00+03	2017-07-16 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-16 12:12:00+03	2017-07-16 13:42:00+03
2797	PG0196	2017-07-21 12:10:00+03	2017-07-21 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-21 12:12:00+03	2017-07-21 13:41:00+03
2798	PG0196	2017-09-09 12:10:00+03	2017-09-09 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2799	PG0196	2017-08-17 12:10:00+03	2017-08-17 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2800	PG0196	2017-07-27 12:10:00+03	2017-07-27 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-27 12:14:00+03	2017-07-27 13:44:00+03
2801	PG0196	2017-08-07 12:10:00+03	2017-08-07 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-07 12:13:00+03	2017-08-07 13:44:00+03
2802	PG0196	2017-08-04 12:10:00+03	2017-08-04 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-04 12:13:00+03	2017-08-04 13:44:00+03
2803	PG0196	2017-07-17 12:10:00+03	2017-07-17 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-17 12:13:00+03	2017-07-17 13:43:00+03
2804	PG0196	2017-08-11 12:10:00+03	2017-08-11 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-11 12:14:00+03	2017-08-11 13:43:00+03
2805	PG0196	2017-08-18 12:10:00+03	2017-08-18 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2806	PG0196	2017-08-08 12:10:00+03	2017-08-08 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-08 12:13:00+03	2017-08-08 13:43:00+03
2807	PG0196	2017-07-30 12:10:00+03	2017-07-30 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-30 12:15:00+03	2017-07-30 13:45:00+03
2808	PG0196	2017-07-24 12:10:00+03	2017-07-24 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-24 12:10:00+03	2017-07-24 13:39:00+03
2809	PG0196	2017-09-14 12:10:00+03	2017-09-14 13:40:00+03	DME	KGD	Cancelled	SU9	\N	\N
2810	PG0196	2017-08-14 12:10:00+03	2017-08-14 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-14 12:12:00+03	2017-08-14 13:41:00+03
2811	PG0196	2017-09-06 12:10:00+03	2017-09-06 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2812	PG0196	2017-08-28 12:10:00+03	2017-08-28 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2813	PG0196	2017-09-12 12:10:00+03	2017-09-12 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2814	PG0196	2017-07-26 12:10:00+03	2017-07-26 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-26 12:15:00+03	2017-07-26 13:46:00+03
2815	PG0196	2017-08-02 12:10:00+03	2017-08-02 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-02 12:12:00+03	2017-08-02 13:42:00+03
2816	PG0196	2017-08-03 12:10:00+03	2017-08-03 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-03 12:11:00+03	2017-08-03 13:41:00+03
2817	PG0196	2017-08-12 12:10:00+03	2017-08-12 13:40:00+03	DME	KGD	Arrived	SU9	2017-08-12 12:13:00+03	2017-08-12 13:43:00+03
2818	PG0196	2017-07-22 12:10:00+03	2017-07-22 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-22 16:06:00+03	2017-07-22 17:37:00+03
2819	PG0196	2017-09-03 12:10:00+03	2017-09-03 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2820	PG0196	2017-08-29 12:10:00+03	2017-08-29 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2821	PG0196	2017-07-19 12:10:00+03	2017-07-19 13:40:00+03	DME	KGD	Arrived	SU9	2017-07-19 12:14:00+03	2017-07-19 13:44:00+03
2822	PG0196	2017-08-30 12:10:00+03	2017-08-30 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2823	PG0196	2017-09-07 12:10:00+03	2017-09-07 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2824	PG0196	2017-08-24 12:10:00+03	2017-08-24 13:40:00+03	DME	KGD	Scheduled	SU9	\N	\N
2825	PG0454	2017-08-20 10:05:00+03	2017-08-20 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2826	PG0454	2017-09-03 10:05:00+03	2017-09-03 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2827	PG0454	2017-09-05 10:05:00+03	2017-09-05 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2828	PG0454	2017-08-25 10:05:00+03	2017-08-25 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2829	PG0454	2017-08-04 10:05:00+03	2017-08-04 10:40:00+03	DME	URS	Arrived	SU9	2017-08-04 10:07:00+03	2017-08-04 10:43:00+03
2830	PG0454	2017-08-19 10:05:00+03	2017-08-19 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2831	PG0454	2017-07-29 10:05:00+03	2017-07-29 10:40:00+03	DME	URS	Arrived	SU9	2017-07-29 10:08:00+03	2017-07-29 10:43:00+03
2832	PG0454	2017-07-28 10:05:00+03	2017-07-28 10:40:00+03	DME	URS	Arrived	SU9	2017-07-28 10:08:00+03	2017-07-28 10:43:00+03
2833	PG0454	2017-07-31 10:05:00+03	2017-07-31 10:40:00+03	DME	URS	Arrived	SU9	2017-07-31 10:08:00+03	2017-07-31 10:42:00+03
2834	PG0454	2017-07-22 10:05:00+03	2017-07-22 10:40:00+03	DME	URS	Arrived	SU9	2017-07-22 10:09:00+03	2017-07-22 10:44:00+03
2835	PG0454	2017-07-21 10:05:00+03	2017-07-21 10:40:00+03	DME	URS	Arrived	SU9	2017-07-21 12:59:00+03	2017-07-21 13:34:00+03
2836	PG0454	2017-08-17 10:05:00+03	2017-08-17 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2837	PG0454	2017-07-16 10:05:00+03	2017-07-16 10:40:00+03	DME	URS	Arrived	SU9	2017-07-16 10:09:00+03	2017-07-16 10:44:00+03
2838	PG0454	2017-07-19 10:05:00+03	2017-07-19 10:40:00+03	DME	URS	Arrived	SU9	2017-07-19 10:06:00+03	2017-07-19 10:41:00+03
2839	PG0454	2017-08-08 10:05:00+03	2017-08-08 10:40:00+03	DME	URS	Arrived	SU9	2017-08-08 10:07:00+03	2017-08-08 10:41:00+03
2840	PG0454	2017-08-10 10:05:00+03	2017-08-10 10:40:00+03	DME	URS	Arrived	SU9	2017-08-10 10:10:00+03	2017-08-10 10:45:00+03
2841	PG0454	2017-09-14 10:05:00+03	2017-09-14 10:40:00+03	DME	URS	Cancelled	SU9	\N	\N
2842	PG0454	2017-08-28 10:05:00+03	2017-08-28 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2843	PG0454	2017-08-23 10:05:00+03	2017-08-23 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2844	PG0454	2017-07-20 10:05:00+03	2017-07-20 10:40:00+03	DME	URS	Arrived	SU9	2017-07-20 10:06:00+03	2017-07-20 10:42:00+03
2845	PG0454	2017-08-11 10:05:00+03	2017-08-11 10:40:00+03	DME	URS	Arrived	SU9	2017-08-11 10:10:00+03	2017-08-11 10:44:00+03
2846	PG0454	2017-07-23 10:05:00+03	2017-07-23 10:40:00+03	DME	URS	Arrived	SU9	2017-07-23 10:10:00+03	2017-07-23 10:45:00+03
2847	PG0454	2017-09-01 10:05:00+03	2017-09-01 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2848	PG0454	2017-08-15 10:05:00+03	2017-08-15 10:40:00+03	DME	URS	Arrived	SU9	2017-08-15 10:10:00+03	2017-08-15 10:45:00+03
2849	PG0454	2017-09-04 10:05:00+03	2017-09-04 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2850	PG0454	2017-07-27 10:05:00+03	2017-07-27 10:40:00+03	DME	URS	Arrived	SU9	2017-07-27 10:10:00+03	2017-07-27 10:45:00+03
2851	PG0454	2017-08-07 10:05:00+03	2017-08-07 10:40:00+03	DME	URS	Arrived	SU9	2017-08-07 10:09:00+03	2017-08-07 10:44:00+03
2852	PG0454	2017-08-02 10:05:00+03	2017-08-02 10:40:00+03	DME	URS	Arrived	SU9	2017-08-02 14:23:00+03	2017-08-02 14:58:00+03
2853	PG0454	2017-08-06 10:05:00+03	2017-08-06 10:40:00+03	DME	URS	Arrived	SU9	2017-08-06 10:10:00+03	2017-08-06 10:45:00+03
2854	PG0454	2017-08-24 10:05:00+03	2017-08-24 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2855	PG0454	2017-09-08 10:05:00+03	2017-09-08 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2856	PG0454	2017-08-12 10:05:00+03	2017-08-12 10:40:00+03	DME	URS	Arrived	SU9	2017-08-12 10:10:00+03	2017-08-12 10:45:00+03
2857	PG0454	2017-08-13 10:05:00+03	2017-08-13 10:40:00+03	DME	URS	Arrived	SU9	2017-08-13 10:09:00+03	2017-08-13 10:45:00+03
2858	PG0454	2017-09-11 10:05:00+03	2017-09-11 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2859	PG0454	2017-08-22 10:05:00+03	2017-08-22 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2860	PG0454	2017-08-27 10:05:00+03	2017-08-27 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2861	PG0454	2017-09-07 10:05:00+03	2017-09-07 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2862	PG0454	2017-07-18 10:05:00+03	2017-07-18 10:40:00+03	DME	URS	Arrived	SU9	2017-07-18 10:05:00+03	2017-07-18 10:40:00+03
2863	PG0454	2017-09-12 10:05:00+03	2017-09-12 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2864	PG0454	2017-09-06 10:05:00+03	2017-09-06 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2865	PG0454	2017-08-16 10:05:00+03	2017-08-16 10:40:00+03	DME	URS	On Time	SU9	\N	\N
2866	PG0454	2017-08-09 10:05:00+03	2017-08-09 10:40:00+03	DME	URS	Arrived	SU9	2017-08-09 10:09:00+03	2017-08-09 10:45:00+03
2867	PG0454	2017-07-25 10:05:00+03	2017-07-25 10:40:00+03	DME	URS	Arrived	SU9	2017-07-25 10:09:00+03	2017-07-25 10:44:00+03
2868	PG0454	2017-09-02 10:05:00+03	2017-09-02 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2869	PG0454	2017-09-10 10:05:00+03	2017-09-10 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2870	PG0454	2017-08-14 10:05:00+03	2017-08-14 10:40:00+03	DME	URS	Arrived	SU9	2017-08-14 10:09:00+03	2017-08-14 10:44:00+03
2871	PG0454	2017-07-26 10:05:00+03	2017-07-26 10:40:00+03	DME	URS	Arrived	SU9	2017-07-26 13:22:00+03	2017-07-26 13:57:00+03
2872	PG0454	2017-07-17 10:05:00+03	2017-07-17 10:40:00+03	DME	URS	Arrived	SU9	2017-07-17 10:07:00+03	2017-07-17 10:42:00+03
2873	PG0454	2017-08-18 10:05:00+03	2017-08-18 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2874	PG0454	2017-08-21 10:05:00+03	2017-08-21 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2875	PG0454	2017-08-31 10:05:00+03	2017-08-31 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2876	PG0454	2017-07-30 10:05:00+03	2017-07-30 10:40:00+03	DME	URS	Arrived	SU9	2017-07-30 10:06:00+03	2017-07-30 10:41:00+03
2877	PG0454	2017-08-26 10:05:00+03	2017-08-26 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2878	PG0454	2017-08-03 10:05:00+03	2017-08-03 10:40:00+03	DME	URS	Arrived	SU9	2017-08-03 10:07:00+03	2017-08-03 10:42:00+03
2879	PG0454	2017-08-29 10:05:00+03	2017-08-29 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2880	PG0454	2017-09-09 10:05:00+03	2017-09-09 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2881	PG0454	2017-08-05 10:05:00+03	2017-08-05 10:40:00+03	DME	URS	Arrived	SU9	2017-08-05 10:06:00+03	2017-08-05 10:41:00+03
2882	PG0454	2017-08-30 10:05:00+03	2017-08-30 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2883	PG0454	2017-07-24 10:05:00+03	2017-07-24 10:40:00+03	DME	URS	Arrived	SU9	2017-07-24 10:09:00+03	2017-07-24 10:44:00+03
2884	PG0454	2017-08-01 10:05:00+03	2017-08-01 10:40:00+03	DME	URS	Arrived	SU9	2017-08-01 10:08:00+03	2017-08-01 10:43:00+03
2885	PG0454	2017-09-13 10:05:00+03	2017-09-13 10:40:00+03	DME	URS	Scheduled	SU9	\N	\N
2886	PG0383	2017-08-10 14:50:00+03	2017-08-10 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-10 14:54:00+03	2017-08-10 15:24:00+03
2887	PG0382	2017-09-06 15:20:00+03	2017-09-06 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2888	PG0384	2017-08-08 12:10:00+03	2017-08-08 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-08 12:12:00+03	2017-08-08 12:42:00+03
2889	PG0382	2017-08-19 15:20:00+03	2017-08-19 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2890	PG0382	2017-08-20 15:20:00+03	2017-08-20 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2891	PG0383	2017-08-20 14:50:00+03	2017-08-20 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2892	PG0384	2017-08-20 12:10:00+03	2017-08-20 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2893	PG0382	2017-08-26 15:20:00+03	2017-08-26 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2894	PG0383	2017-08-26 14:50:00+03	2017-08-26 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2895	PG0382	2017-07-27 15:20:00+03	2017-07-27 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-27 15:24:00+03	2017-07-27 15:54:00+03
2896	PG0383	2017-07-27 14:50:00+03	2017-07-27 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-27 14:52:00+03	2017-07-27 15:22:00+03
2897	PG0384	2017-07-27 12:10:00+03	2017-07-27 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-27 12:14:00+03	2017-07-27 12:44:00+03
2898	PG0382	2017-08-15 15:20:00+03	2017-08-15 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-15 15:22:00+03	2017-08-15 15:52:00+03
2899	PG0384	2017-08-26 12:10:00+03	2017-08-26 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2900	PG0382	2017-09-13 15:20:00+03	2017-09-13 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2901	PG0382	2017-07-17 15:20:00+03	2017-07-17 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-17 15:25:00+03	2017-07-17 15:55:00+03
2902	PG0382	2017-09-12 15:20:00+03	2017-09-12 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2903	PG0383	2017-08-15 14:50:00+03	2017-08-15 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-15 14:57:00+03	2017-08-15 15:27:00+03
2904	PG0383	2017-09-13 14:50:00+03	2017-09-13 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2905	PG0383	2017-07-17 14:50:00+03	2017-07-17 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-17 18:09:00+03	2017-07-17 18:39:00+03
2906	PG0383	2017-09-12 14:50:00+03	2017-09-12 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2907	PG0382	2017-08-27 15:20:00+03	2017-08-27 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2908	PG0384	2017-09-12 12:10:00+03	2017-09-12 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2909	PG0384	2017-08-15 12:10:00+03	2017-08-15 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-15 12:11:00+03	2017-08-15 12:42:00+03
2910	PG0382	2017-09-08 15:20:00+03	2017-09-08 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2911	PG0384	2017-07-17 12:10:00+03	2017-07-17 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-17 12:12:00+03	2017-07-17 12:41:00+03
2912	PG0384	2017-08-23 12:10:00+03	2017-08-23 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2913	PG0382	2017-08-29 15:20:00+03	2017-08-29 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2914	PG0383	2017-08-29 14:50:00+03	2017-08-29 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2915	PG0384	2017-08-24 12:10:00+03	2017-08-24 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2916	PG0383	2017-08-24 14:50:00+03	2017-08-24 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2917	PG0384	2017-08-29 12:10:00+03	2017-08-29 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2918	PG0384	2017-07-19 12:10:00+03	2017-07-19 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-19 12:11:00+03	2017-07-19 12:40:00+03
2919	PG0383	2017-07-19 14:50:00+03	2017-07-19 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-19 14:53:00+03	2017-07-19 15:24:00+03
2920	PG0382	2017-07-19 15:20:00+03	2017-07-19 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-19 15:23:00+03	2017-07-19 15:53:00+03
2921	PG0382	2017-08-24 15:20:00+03	2017-08-24 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2922	PG0384	2017-09-10 12:10:00+03	2017-09-10 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2923	PG0383	2017-09-10 14:50:00+03	2017-09-10 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2924	PG0384	2017-07-26 12:10:00+03	2017-07-26 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-26 12:15:00+03	2017-07-26 12:45:00+03
2925	PG0383	2017-08-23 14:50:00+03	2017-08-23 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2926	PG0384	2017-07-16 12:10:00+03	2017-07-16 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-16 12:13:00+03	2017-07-16 12:43:00+03
2927	PG0382	2017-09-10 15:20:00+03	2017-09-10 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2928	PG0383	2017-08-27 14:50:00+03	2017-08-27 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2929	PG0384	2017-08-27 12:10:00+03	2017-08-27 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2930	PG0384	2017-09-07 12:10:00+03	2017-09-07 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2931	PG0382	2017-08-18 15:20:00+03	2017-08-18 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2932	PG0383	2017-08-18 14:50:00+03	2017-08-18 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2933	PG0384	2017-08-18 12:10:00+03	2017-08-18 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2934	PG0384	2017-08-10 12:10:00+03	2017-08-10 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-10 12:14:00+03	2017-08-10 12:45:00+03
2935	PG0382	2017-08-10 15:20:00+03	2017-08-10 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-10 15:25:00+03	2017-08-10 15:55:00+03
2936	PG0383	2017-07-16 14:50:00+03	2017-07-16 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-16 14:53:00+03	2017-07-16 15:23:00+03
2937	PG0383	2017-09-07 14:50:00+03	2017-09-07 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2938	PG0383	2017-07-26 14:50:00+03	2017-07-26 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-26 14:53:00+03	2017-07-26 15:24:00+03
2939	PG0382	2017-09-07 15:20:00+03	2017-09-07 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2940	PG0384	2017-08-21 12:10:00+03	2017-08-21 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2941	PG0383	2017-08-21 14:50:00+03	2017-08-21 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2942	PG0382	2017-07-16 15:20:00+03	2017-07-16 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-16 15:22:00+03	2017-07-16 15:52:00+03
2943	PG0382	2017-07-29 15:20:00+03	2017-07-29 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-29 15:20:00+03	2017-07-29 15:50:00+03
2944	PG0384	2017-09-01 12:10:00+03	2017-09-01 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2945	PG0384	2017-09-13 12:10:00+03	2017-09-13 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2946	PG0383	2017-09-01 14:50:00+03	2017-09-01 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2947	PG0382	2017-08-21 15:20:00+03	2017-08-21 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2948	PG0384	2017-08-13 12:10:00+03	2017-08-13 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-13 12:13:00+03	2017-08-13 12:43:00+03
2949	PG0383	2017-08-19 14:50:00+03	2017-08-19 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2950	PG0382	2017-09-01 15:20:00+03	2017-09-01 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2951	PG0383	2017-07-29 14:50:00+03	2017-07-29 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-29 14:52:00+03	2017-07-29 15:22:00+03
2952	PG0384	2017-07-29 12:10:00+03	2017-07-29 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-29 12:15:00+03	2017-07-29 12:45:00+03
2953	PG0383	2017-08-25 14:50:00+03	2017-08-25 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2954	PG0382	2017-08-23 15:20:00+03	2017-08-23 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2955	PG0382	2017-07-21 15:20:00+03	2017-07-21 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-21 15:24:00+03	2017-07-21 15:54:00+03
2956	PG0383	2017-07-21 14:50:00+03	2017-07-21 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-21 14:53:00+03	2017-07-21 15:23:00+03
2957	PG0384	2017-07-21 12:10:00+03	2017-07-21 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-21 12:12:00+03	2017-07-21 12:42:00+03
2958	PG0382	2017-08-11 15:20:00+03	2017-08-11 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-11 15:24:00+03	2017-08-11 15:54:00+03
2959	PG0383	2017-08-11 14:50:00+03	2017-08-11 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-11 14:52:00+03	2017-08-11 15:22:00+03
2960	PG0384	2017-08-11 12:10:00+03	2017-08-11 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-11 12:14:00+03	2017-08-11 12:44:00+03
2961	PG0384	2017-07-25 12:10:00+03	2017-07-25 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-25 12:12:00+03	2017-07-25 12:43:00+03
2962	PG0383	2017-07-25 14:50:00+03	2017-07-25 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-25 14:54:00+03	2017-07-25 15:24:00+03
2963	PG0382	2017-07-25 15:20:00+03	2017-07-25 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-25 15:24:00+03	2017-07-25 15:54:00+03
2964	PG0384	2017-09-04 12:10:00+03	2017-09-04 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2965	PG0383	2017-09-04 14:50:00+03	2017-09-04 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2966	PG0382	2017-09-04 15:20:00+03	2017-09-04 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2967	PG0382	2017-08-28 15:20:00+03	2017-08-28 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2968	PG0384	2017-07-18 12:10:00+03	2017-07-18 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-18 12:14:00+03	2017-07-18 12:44:00+03
2969	PG0384	2017-09-03 12:10:00+03	2017-09-03 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2970	PG0384	2017-09-14 12:10:00+03	2017-09-14 12:40:00+03	DME	BZK	Cancelled	SU9	\N	\N
2971	PG0384	2017-07-20 12:10:00+03	2017-07-20 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-20 12:11:00+03	2017-07-20 12:42:00+03
2972	PG0383	2017-07-20 14:50:00+03	2017-07-20 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-20 14:56:00+03	2017-07-20 15:26:00+03
2973	PG0382	2017-07-20 15:20:00+03	2017-07-20 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-20 15:22:00+03	2017-07-20 15:52:00+03
2974	PG0383	2017-07-18 14:50:00+03	2017-07-18 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-18 14:55:00+03	2017-07-18 15:25:00+03
2975	PG0382	2017-08-05 15:20:00+03	2017-08-05 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-05 15:25:00+03	2017-08-05 15:55:00+03
2976	PG0383	2017-08-05 14:50:00+03	2017-08-05 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-05 14:58:00+03	2017-08-05 15:27:00+03
2977	PG0384	2017-08-05 12:10:00+03	2017-08-05 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-05 12:12:00+03	2017-08-05 12:42:00+03
2978	PG0383	2017-09-03 14:50:00+03	2017-09-03 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2979	PG0382	2017-09-03 15:20:00+03	2017-09-03 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2980	PG0382	2017-07-18 15:20:00+03	2017-07-18 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-18 15:21:00+03	2017-07-18 15:51:00+03
2981	PG0382	2017-08-22 15:20:00+03	2017-08-22 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2982	PG0383	2017-08-22 14:50:00+03	2017-08-22 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2983	PG0382	2017-08-07 15:20:00+03	2017-08-07 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-07 15:22:00+03	2017-08-07 15:52:00+03
2984	PG0383	2017-08-07 14:50:00+03	2017-08-07 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-07 14:59:00+03	2017-08-07 15:29:00+03
2985	PG0384	2017-08-22 12:10:00+03	2017-08-22 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2986	PG0383	2017-09-14 14:50:00+03	2017-09-14 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2987	PG0384	2017-08-07 12:10:00+03	2017-08-07 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-07 12:11:00+03	2017-08-07 12:41:00+03
2988	PG0382	2017-09-14 15:20:00+03	2017-09-14 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2989	PG0384	2017-07-22 12:10:00+03	2017-07-22 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-22 16:14:00+03	2017-07-22 16:44:00+03
2990	PG0383	2017-07-22 14:50:00+03	2017-07-22 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-22 14:52:00+03	2017-07-22 15:22:00+03
2991	PG0383	2017-08-28 14:50:00+03	2017-08-28 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2992	PG0382	2017-07-22 15:20:00+03	2017-07-22 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-22 15:25:00+03	2017-07-22 15:55:00+03
2993	PG0384	2017-08-28 12:10:00+03	2017-08-28 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
2994	PG0383	2017-09-08 14:50:00+03	2017-09-08 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
2995	PG0384	2017-08-12 12:10:00+03	2017-08-12 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-12 12:11:00+03	2017-08-12 12:40:00+03
2996	PG0384	2017-07-31 12:10:00+03	2017-07-31 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-31 12:12:00+03	2017-07-31 12:41:00+03
2997	PG0383	2017-07-31 14:50:00+03	2017-07-31 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-31 14:51:00+03	2017-07-31 15:21:00+03
2998	PG0382	2017-09-09 15:20:00+03	2017-09-09 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
2999	PG0382	2017-07-31 15:20:00+03	2017-07-31 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-31 15:24:00+03	2017-07-31 15:54:00+03
3000	PG0384	2017-08-19 12:10:00+03	2017-08-19 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3001	PG0384	2017-08-06 12:10:00+03	2017-08-06 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-06 12:10:00+03	2017-08-06 12:40:00+03
3002	PG0382	2017-07-23 15:20:00+03	2017-07-23 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-23 15:25:00+03	2017-07-23 15:55:00+03
3003	PG0383	2017-07-23 14:50:00+03	2017-07-23 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-23 14:53:00+03	2017-07-23 15:23:00+03
3004	PG0384	2017-07-23 12:10:00+03	2017-07-23 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-23 12:15:00+03	2017-07-23 12:45:00+03
3005	PG0383	2017-08-06 14:50:00+03	2017-08-06 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-06 14:53:00+03	2017-08-06 15:23:00+03
3006	PG0382	2017-08-06 15:20:00+03	2017-08-06 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-06 15:25:00+03	2017-08-06 15:54:00+03
3007	PG0382	2017-08-17 15:20:00+03	2017-08-17 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3008	PG0383	2017-08-17 14:50:00+03	2017-08-17 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3009	PG0384	2017-08-17 12:10:00+03	2017-08-17 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3010	PG0384	2017-08-03 12:10:00+03	2017-08-03 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-03 12:14:00+03	2017-08-03 12:44:00+03
3011	PG0383	2017-08-03 14:50:00+03	2017-08-03 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-03 14:50:00+03	2017-08-03 15:20:00+03
3012	PG0382	2017-08-03 15:20:00+03	2017-08-03 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-03 15:23:00+03	2017-08-03 15:53:00+03
3013	PG0383	2017-08-13 14:50:00+03	2017-08-13 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-13 14:54:00+03	2017-08-13 15:24:00+03
3014	PG0382	2017-08-30 15:20:00+03	2017-08-30 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3015	PG0382	2017-08-25 15:20:00+03	2017-08-25 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3016	PG0383	2017-09-09 14:50:00+03	2017-09-09 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3017	PG0382	2017-09-05 15:20:00+03	2017-09-05 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3018	PG0383	2017-09-05 14:50:00+03	2017-09-05 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3019	PG0384	2017-08-25 12:10:00+03	2017-08-25 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3020	PG0384	2017-09-05 12:10:00+03	2017-09-05 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3021	PG0384	2017-07-24 12:10:00+03	2017-07-24 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-24 12:14:00+03	2017-07-24 12:44:00+03
3022	PG0383	2017-07-24 14:50:00+03	2017-07-24 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-24 14:53:00+03	2017-07-24 15:23:00+03
3023	PG0383	2017-08-30 14:50:00+03	2017-08-30 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3024	PG0384	2017-08-30 12:10:00+03	2017-08-30 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3025	PG0384	2017-08-16 12:10:00+03	2017-08-16 12:40:00+03	DME	BZK	On Time	SU9	\N	\N
3026	PG0383	2017-08-16 14:50:00+03	2017-08-16 15:20:00+03	DME	BZK	On Time	SU9	\N	\N
3027	PG0382	2017-08-16 15:20:00+03	2017-08-16 15:50:00+03	DME	BZK	Delayed	SU9	\N	\N
3028	PG0382	2017-07-28 15:20:00+03	2017-07-28 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-28 15:22:00+03	2017-07-28 15:53:00+03
3029	PG0383	2017-07-28 14:50:00+03	2017-07-28 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-28 14:52:00+03	2017-07-28 15:23:00+03
3030	PG0382	2017-07-26 15:20:00+03	2017-07-26 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-26 15:25:00+03	2017-07-26 15:55:00+03
3031	PG0384	2017-07-28 12:10:00+03	2017-07-28 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-28 12:13:00+03	2017-07-28 12:43:00+03
3032	PG0384	2017-08-09 12:10:00+03	2017-08-09 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-09 12:17:00+03	2017-08-09 12:47:00+03
3033	PG0382	2017-07-24 15:20:00+03	2017-07-24 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-24 15:23:00+03	2017-07-24 15:53:00+03
3034	PG0382	2017-08-02 15:20:00+03	2017-08-02 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-02 15:21:00+03	2017-08-02 15:51:00+03
3035	PG0383	2017-08-09 14:50:00+03	2017-08-09 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-09 14:52:00+03	2017-08-09 15:22:00+03
3036	PG0383	2017-08-02 14:50:00+03	2017-08-02 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-02 14:53:00+03	2017-08-02 15:23:00+03
3037	PG0384	2017-08-02 12:10:00+03	2017-08-02 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-02 12:13:00+03	2017-08-02 12:43:00+03
3038	PG0382	2017-08-09 15:20:00+03	2017-08-09 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-09 15:24:00+03	2017-08-09 15:54:00+03
3039	PG0383	2017-08-12 14:50:00+03	2017-08-12 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-12 14:54:00+03	2017-08-12 15:24:00+03
3040	PG0382	2017-08-31 15:20:00+03	2017-08-31 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3041	PG0382	2017-08-13 15:20:00+03	2017-08-13 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-13 15:20:00+03	2017-08-13 15:50:00+03
3042	PG0383	2017-08-31 14:50:00+03	2017-08-31 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3043	PG0384	2017-09-08 12:10:00+03	2017-09-08 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3044	PG0384	2017-09-09 12:10:00+03	2017-09-09 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3045	PG0382	2017-09-02 15:20:00+03	2017-09-02 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3046	PG0384	2017-08-31 12:10:00+03	2017-08-31 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3047	PG0383	2017-09-02 14:50:00+03	2017-09-02 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3048	PG0384	2017-09-02 12:10:00+03	2017-09-02 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3049	PG0382	2017-08-01 15:20:00+03	2017-08-01 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-01 15:26:00+03	2017-08-01 15:56:00+03
3050	PG0382	2017-08-08 15:20:00+03	2017-08-08 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-08 15:24:00+03	2017-08-08 15:54:00+03
3051	PG0383	2017-08-01 14:50:00+03	2017-08-01 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-01 14:55:00+03	2017-08-01 15:25:00+03
3052	PG0384	2017-08-04 12:10:00+03	2017-08-04 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-04 12:15:00+03	2017-08-04 12:45:00+03
3053	PG0383	2017-08-04 14:50:00+03	2017-08-04 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-04 14:54:00+03	2017-08-04 15:24:00+03
3054	PG0382	2017-08-04 15:20:00+03	2017-08-04 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-04 15:21:00+03	2017-08-04 15:51:00+03
3055	PG0384	2017-09-11 12:10:00+03	2017-09-11 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3056	PG0384	2017-08-01 12:10:00+03	2017-08-01 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-01 12:13:00+03	2017-08-01 12:43:00+03
3057	PG0382	2017-08-14 15:20:00+03	2017-08-14 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-14 15:22:00+03	2017-08-14 15:52:00+03
3058	PG0384	2017-07-30 12:10:00+03	2017-07-30 12:40:00+03	DME	BZK	Arrived	SU9	2017-07-30 12:15:00+03	2017-07-30 12:45:00+03
3059	PG0383	2017-07-30 14:50:00+03	2017-07-30 15:20:00+03	DME	BZK	Arrived	SU9	2017-07-30 14:55:00+03	2017-07-30 15:26:00+03
3060	PG0383	2017-08-14 14:50:00+03	2017-08-14 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-14 14:54:00+03	2017-08-14 15:24:00+03
3061	PG0384	2017-09-06 12:10:00+03	2017-09-06 12:40:00+03	DME	BZK	Scheduled	SU9	\N	\N
3062	PG0384	2017-08-14 12:10:00+03	2017-08-14 12:40:00+03	DME	BZK	Arrived	SU9	2017-08-14 12:13:00+03	2017-08-14 12:43:00+03
3063	PG0382	2017-07-30 15:20:00+03	2017-07-30 15:50:00+03	DME	BZK	Arrived	SU9	2017-07-30 15:22:00+03	2017-07-30 15:52:00+03
3064	PG0383	2017-09-11 14:50:00+03	2017-09-11 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3065	PG0383	2017-09-06 14:50:00+03	2017-09-06 15:20:00+03	DME	BZK	Scheduled	SU9	\N	\N
3066	PG0382	2017-09-11 15:20:00+03	2017-09-11 15:50:00+03	DME	BZK	Scheduled	SU9	\N	\N
3067	PG0382	2017-08-12 15:20:00+03	2017-08-12 15:50:00+03	DME	BZK	Arrived	SU9	2017-08-12 15:21:00+03	2017-08-12 15:51:00+03
3068	PG0383	2017-08-08 14:50:00+03	2017-08-08 15:20:00+03	DME	BZK	Arrived	SU9	2017-08-08 14:51:00+03	2017-08-08 15:21:00+03
3069	PG0118	2017-09-04 19:55:00+03	2017-09-04 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3070	PG0118	2017-08-08 19:55:00+03	2017-08-08 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-08 19:58:00+03	2017-08-08 20:43:00+03
3071	PG0118	2017-09-01 19:55:00+03	2017-09-01 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3072	PG0118	2017-07-30 19:55:00+03	2017-07-30 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-30 19:57:00+03	2017-07-30 20:42:00+03
3073	PG0118	2017-08-17 19:55:00+03	2017-08-17 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3074	PG0118	2017-08-25 19:55:00+03	2017-08-25 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3075	PG0118	2017-07-18 19:55:00+03	2017-07-18 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-18 19:57:00+03	2017-07-18 20:42:00+03
3076	PG0118	2017-07-31 19:55:00+03	2017-07-31 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-31 19:59:00+03	2017-07-31 20:44:00+03
3077	PG0118	2017-09-13 19:55:00+03	2017-09-13 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3078	PG0118	2017-07-29 19:55:00+03	2017-07-29 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-29 19:56:00+03	2017-07-29 20:41:00+03
3079	PG0118	2017-07-23 19:55:00+03	2017-07-23 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-23 19:59:00+03	2017-07-23 20:44:00+03
3080	PG0118	2017-07-22 19:55:00+03	2017-07-22 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-22 19:56:00+03	2017-07-22 20:41:00+03
3081	PG0118	2017-08-31 19:55:00+03	2017-08-31 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3082	PG0118	2017-08-04 19:55:00+03	2017-08-04 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-04 23:28:00+03	2017-08-05 00:13:00+03
3083	PG0118	2017-09-08 19:55:00+03	2017-09-08 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3084	PG0118	2017-09-12 19:55:00+03	2017-09-12 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3085	PG0118	2017-07-27 19:55:00+03	2017-07-27 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-27 20:00:00+03	2017-07-27 20:44:00+03
3086	PG0118	2017-07-17 19:55:00+03	2017-07-17 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-17 19:55:00+03	2017-07-17 20:40:00+03
3087	PG0118	2017-08-01 19:55:00+03	2017-08-01 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-01 23:22:00+03	2017-08-02 00:06:00+03
3088	PG0118	2017-07-24 19:55:00+03	2017-07-24 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-24 19:58:00+03	2017-07-24 20:43:00+03
3089	PG0118	2017-08-29 19:55:00+03	2017-08-29 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3090	PG0118	2017-08-05 19:55:00+03	2017-08-05 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-05 20:00:00+03	2017-08-05 20:45:00+03
3091	PG0118	2017-07-20 19:55:00+03	2017-07-20 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-20 19:59:00+03	2017-07-20 20:44:00+03
3092	PG0118	2017-09-03 19:55:00+03	2017-09-03 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3093	PG0118	2017-09-10 19:55:00+03	2017-09-10 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3094	PG0118	2017-07-26 19:55:00+03	2017-07-26 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-26 19:59:00+03	2017-07-26 20:44:00+03
3095	PG0118	2017-08-24 19:55:00+03	2017-08-24 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3096	PG0118	2017-09-11 19:55:00+03	2017-09-11 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3097	PG0118	2017-08-27 19:55:00+03	2017-08-27 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3098	PG0118	2017-08-14 19:55:00+03	2017-08-14 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-14 20:00:00+03	2017-08-14 20:45:00+03
3099	PG0118	2017-08-26 19:55:00+03	2017-08-26 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3100	PG0118	2017-08-30 19:55:00+03	2017-08-30 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3101	PG0118	2017-09-07 19:55:00+03	2017-09-07 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3102	PG0118	2017-08-16 19:55:00+03	2017-08-16 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3103	PG0118	2017-09-02 19:55:00+03	2017-09-02 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3104	PG0118	2017-09-09 19:55:00+03	2017-09-09 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3105	PG0118	2017-08-13 19:55:00+03	2017-08-13 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-13 19:59:00+03	2017-08-13 20:44:00+03
3106	PG0118	2017-09-14 19:55:00+03	2017-09-14 20:40:00+03	DME	EGO	Cancelled	SU9	\N	\N
3107	PG0118	2017-08-07 19:55:00+03	2017-08-07 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-07 23:26:00+03	2017-08-08 00:11:00+03
3108	PG0118	2017-07-16 19:55:00+03	2017-07-16 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-16 19:58:00+03	2017-07-16 20:43:00+03
3109	PG0118	2017-08-10 19:55:00+03	2017-08-10 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-10 19:57:00+03	2017-08-10 20:42:00+03
3110	PG0118	2017-08-28 19:55:00+03	2017-08-28 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3111	PG0118	2017-08-02 19:55:00+03	2017-08-02 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-02 23:14:00+03	2017-08-02 23:59:00+03
3112	PG0118	2017-08-11 19:55:00+03	2017-08-11 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-11 19:58:00+03	2017-08-11 20:44:00+03
3113	PG0118	2017-08-19 19:55:00+03	2017-08-19 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3114	PG0118	2017-09-06 19:55:00+03	2017-09-06 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3115	PG0118	2017-07-25 19:55:00+03	2017-07-25 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-25 19:59:00+03	2017-07-25 20:44:00+03
3116	PG0118	2017-08-20 19:55:00+03	2017-08-20 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3117	PG0118	2017-08-09 19:55:00+03	2017-08-09 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-09 19:56:00+03	2017-08-09 20:40:00+03
3118	PG0118	2017-09-05 19:55:00+03	2017-09-05 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3119	PG0118	2017-08-06 19:55:00+03	2017-08-06 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-06 19:58:00+03	2017-08-06 20:44:00+03
3120	PG0118	2017-08-18 19:55:00+03	2017-08-18 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3121	PG0118	2017-08-12 19:55:00+03	2017-08-12 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-12 19:57:00+03	2017-08-12 20:42:00+03
3122	PG0118	2017-08-15 19:55:00+03	2017-08-15 20:40:00+03	DME	EGO	On Time	SU9	\N	\N
3123	PG0118	2017-08-22 19:55:00+03	2017-08-22 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3124	PG0118	2017-08-03 19:55:00+03	2017-08-03 20:40:00+03	DME	EGO	Arrived	SU9	2017-08-03 19:57:00+03	2017-08-03 20:43:00+03
3125	PG0118	2017-07-21 19:55:00+03	2017-07-21 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-21 22:50:00+03	2017-07-21 23:35:00+03
3126	PG0118	2017-07-28 19:55:00+03	2017-07-28 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-28 22:42:00+03	2017-07-28 23:27:00+03
3127	PG0118	2017-08-21 19:55:00+03	2017-08-21 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3128	PG0118	2017-08-23 19:55:00+03	2017-08-23 20:40:00+03	DME	EGO	Scheduled	SU9	\N	\N
3129	PG0118	2017-07-19 19:55:00+03	2017-07-19 20:40:00+03	DME	EGO	Arrived	SU9	2017-07-19 19:57:00+03	2017-07-19 20:42:00+03
3130	PG0337	2017-08-11 12:45:00+03	2017-08-11 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-11 12:48:00+03	2017-08-11 14:15:00+03
3131	PG0337	2017-08-04 12:45:00+03	2017-08-04 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-04 12:49:00+03	2017-08-04 14:15:00+03
3132	PG0337	2017-08-15 12:45:00+03	2017-08-15 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-15 12:49:00+03	2017-08-15 14:14:00+03
3133	PG0337	2017-07-29 12:45:00+03	2017-07-29 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-29 12:47:00+03	2017-07-29 14:10:00+03
3134	PG0337	2017-07-27 12:45:00+03	2017-07-27 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-27 12:47:00+03	2017-07-27 14:12:00+03
3135	PG0337	2017-09-12 12:45:00+03	2017-09-12 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3136	PG0337	2017-08-10 12:45:00+03	2017-08-10 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-10 12:47:00+03	2017-08-10 14:12:00+03
3137	PG0337	2017-07-19 12:45:00+03	2017-07-19 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-19 12:50:00+03	2017-07-19 14:13:00+03
3138	PG0337	2017-08-18 12:45:00+03	2017-08-18 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3139	PG0337	2017-08-25 12:45:00+03	2017-08-25 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3140	PG0337	2017-08-16 12:45:00+03	2017-08-16 14:10:00+03	DME	ARH	On Time	CR2	\N	\N
3141	PG0337	2017-09-04 12:45:00+03	2017-09-04 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3142	PG0337	2017-08-28 12:45:00+03	2017-08-28 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3143	PG0337	2017-08-06 12:45:00+03	2017-08-06 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-06 12:51:00+03	2017-08-06 14:17:00+03
3144	PG0337	2017-07-22 12:45:00+03	2017-07-22 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-22 12:49:00+03	2017-07-22 14:14:00+03
3145	PG0337	2017-08-08 12:45:00+03	2017-08-08 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-08 12:46:00+03	2017-08-08 14:11:00+03
3146	PG0337	2017-07-31 12:45:00+03	2017-07-31 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-31 12:48:00+03	2017-07-31 14:13:00+03
3147	PG0337	2017-08-21 12:45:00+03	2017-08-21 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3148	PG0337	2017-07-30 12:45:00+03	2017-07-30 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-30 12:47:00+03	2017-07-30 14:12:00+03
3149	PG0337	2017-08-09 12:45:00+03	2017-08-09 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-09 12:49:00+03	2017-08-09 14:15:00+03
3150	PG0337	2017-09-09 12:45:00+03	2017-09-09 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3151	PG0337	2017-09-03 12:45:00+03	2017-09-03 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3152	PG0337	2017-09-08 12:45:00+03	2017-09-08 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3153	PG0337	2017-07-21 12:45:00+03	2017-07-21 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-21 12:47:00+03	2017-07-21 14:11:00+03
3154	PG0337	2017-08-22 12:45:00+03	2017-08-22 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3155	PG0337	2017-09-07 12:45:00+03	2017-09-07 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3156	PG0337	2017-09-06 12:45:00+03	2017-09-06 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3157	PG0337	2017-08-24 12:45:00+03	2017-08-24 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3158	PG0337	2017-08-23 12:45:00+03	2017-08-23 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3159	PG0337	2017-08-31 12:45:00+03	2017-08-31 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3160	PG0337	2017-08-30 12:45:00+03	2017-08-30 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3161	PG0337	2017-09-01 12:45:00+03	2017-09-01 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3162	PG0337	2017-08-02 12:45:00+03	2017-08-02 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-02 12:48:00+03	2017-08-02 14:12:00+03
3163	PG0337	2017-09-10 12:45:00+03	2017-09-10 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3164	PG0337	2017-08-19 12:45:00+03	2017-08-19 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3165	PG0337	2017-07-17 12:45:00+03	2017-07-17 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-17 12:48:00+03	2017-07-17 14:13:00+03
3166	PG0337	2017-08-29 12:45:00+03	2017-08-29 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3167	PG0337	2017-08-13 12:45:00+03	2017-08-13 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-13 12:49:00+03	2017-08-13 14:14:00+03
3168	PG0337	2017-09-14 12:45:00+03	2017-09-14 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3169	PG0337	2017-08-27 12:45:00+03	2017-08-27 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3170	PG0337	2017-09-05 12:45:00+03	2017-09-05 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3171	PG0337	2017-09-02 12:45:00+03	2017-09-02 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3172	PG0337	2017-09-11 12:45:00+03	2017-09-11 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3173	PG0337	2017-08-26 12:45:00+03	2017-08-26 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3174	PG0337	2017-08-12 12:45:00+03	2017-08-12 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-12 12:48:00+03	2017-08-12 14:13:00+03
3175	PG0337	2017-08-14 12:45:00+03	2017-08-14 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-14 12:47:00+03	2017-08-14 14:11:00+03
3176	PG0337	2017-08-01 12:45:00+03	2017-08-01 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-01 12:48:00+03	2017-08-01 14:13:00+03
3177	PG0337	2017-07-25 12:45:00+03	2017-07-25 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-25 12:48:00+03	2017-07-25 14:12:00+03
3178	PG0337	2017-07-20 12:45:00+03	2017-07-20 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-20 12:47:00+03	2017-07-20 14:12:00+03
3179	PG0337	2017-08-17 12:45:00+03	2017-08-17 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3180	PG0337	2017-07-16 12:45:00+03	2017-07-16 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-16 12:50:00+03	2017-07-16 14:14:00+03
3181	PG0337	2017-09-13 12:45:00+03	2017-09-13 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3182	PG0337	2017-07-26 12:45:00+03	2017-07-26 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-26 12:50:00+03	2017-07-26 14:15:00+03
3183	PG0337	2017-07-23 12:45:00+03	2017-07-23 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-23 12:50:00+03	2017-07-23 14:15:00+03
3184	PG0337	2017-08-03 12:45:00+03	2017-08-03 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-03 16:10:00+03	2017-08-03 17:34:00+03
3185	PG0337	2017-08-20 12:45:00+03	2017-08-20 14:10:00+03	DME	ARH	Scheduled	CR2	\N	\N
3186	PG0337	2017-07-24 12:45:00+03	2017-07-24 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-24 12:50:00+03	2017-07-24 14:16:00+03
3187	PG0337	2017-08-05 12:45:00+03	2017-08-05 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-05 12:47:00+03	2017-08-05 14:12:00+03
3188	PG0337	2017-08-07 12:45:00+03	2017-08-07 14:10:00+03	DME	ARH	Arrived	CR2	2017-08-07 12:49:00+03	2017-08-07 14:14:00+03
3189	PG0337	2017-07-28 12:45:00+03	2017-07-28 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-28 12:47:00+03	2017-07-28 14:11:00+03
3190	PG0337	2017-07-18 12:45:00+03	2017-07-18 14:10:00+03	DME	ARH	Arrived	CR2	2017-07-18 12:47:00+03	2017-07-18 14:11:00+03
3191	PG0370	2017-08-03 11:50:00+03	2017-08-03 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-03 11:54:00+03	2017-08-03 14:18:00+03
3192	PG0370	2017-09-12 11:50:00+03	2017-09-12 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3193	PG0370	2017-07-20 11:50:00+03	2017-07-20 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-20 11:53:00+03	2017-07-20 14:17:00+03
3194	PG0370	2017-07-16 11:50:00+03	2017-07-16 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-16 11:52:00+03	2017-07-16 14:16:00+03
3195	PG0370	2017-07-25 11:50:00+03	2017-07-25 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-25 11:51:00+03	2017-07-25 14:17:00+03
3196	PG0370	2017-08-13 11:50:00+03	2017-08-13 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-13 11:50:00+03	2017-08-13 14:16:00+03
3197	PG0370	2017-09-07 11:50:00+03	2017-09-07 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3198	PG0370	2017-07-23 11:50:00+03	2017-07-23 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-23 11:53:00+03	2017-07-23 14:18:00+03
3199	PG0370	2017-08-08 11:50:00+03	2017-08-08 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-08 11:52:00+03	2017-08-08 14:16:00+03
3200	PG0370	2017-09-10 11:50:00+03	2017-09-10 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3201	PG0370	2017-08-17 11:50:00+03	2017-08-17 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3202	PG0370	2017-08-22 11:50:00+03	2017-08-22 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3203	PG0370	2017-08-24 11:50:00+03	2017-08-24 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3204	PG0370	2017-09-03 11:50:00+03	2017-09-03 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3205	PG0370	2017-08-27 11:50:00+03	2017-08-27 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3206	PG0370	2017-08-20 11:50:00+03	2017-08-20 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3207	PG0370	2017-09-14 11:50:00+03	2017-09-14 14:15:00+03	DME	KRO	Cancelled	CR2	\N	\N
3208	PG0370	2017-07-27 11:50:00+03	2017-07-27 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-27 11:55:00+03	2017-07-27 14:18:00+03
3209	PG0370	2017-08-15 11:50:00+03	2017-08-15 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-15 11:52:00+03	2017-08-15 14:15:00+03
3210	PG0370	2017-08-10 11:50:00+03	2017-08-10 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-10 11:52:00+03	2017-08-10 14:18:00+03
3211	PG0370	2017-08-29 11:50:00+03	2017-08-29 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3212	PG0370	2017-09-05 11:50:00+03	2017-09-05 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3213	PG0370	2017-07-18 11:50:00+03	2017-07-18 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-18 11:53:00+03	2017-07-18 14:22:00+03
3214	PG0370	2017-08-31 11:50:00+03	2017-08-31 14:15:00+03	DME	KRO	Scheduled	CR2	\N	\N
3215	PG0370	2017-08-01 11:50:00+03	2017-08-01 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-01 11:50:00+03	2017-08-01 14:14:00+03
3216	PG0370	2017-08-06 11:50:00+03	2017-08-06 14:15:00+03	DME	KRO	Arrived	CR2	2017-08-06 11:52:00+03	2017-08-06 14:15:00+03
3217	PG0370	2017-07-30 11:50:00+03	2017-07-30 14:15:00+03	DME	KRO	Arrived	CR2	2017-07-30 11:50:00+03	2017-07-30 14:14:00+03
3218	PG0229	2017-09-04 11:50:00+03	2017-09-04 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3219	PG0227	2017-09-01 09:45:00+03	2017-09-01 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3220	PG0228	2017-09-01 11:25:00+03	2017-09-01 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3221	PG0229	2017-09-01 11:50:00+03	2017-09-01 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3222	PG0229	2017-09-14 11:50:00+03	2017-09-14 12:40:00+03	VKO	LED	Cancelled	321	\N	\N
3223	PG0229	2017-08-11 11:50:00+03	2017-08-11 12:40:00+03	VKO	LED	Arrived	321	2017-08-11 11:51:00+03	2017-08-11 12:41:00+03
3224	PG0228	2017-08-11 11:25:00+03	2017-08-11 12:15:00+03	VKO	LED	Arrived	321	2017-08-11 11:28:00+03	2017-08-11 12:19:00+03
3225	PG0227	2017-08-11 09:45:00+03	2017-08-11 10:35:00+03	VKO	LED	Arrived	321	2017-08-11 09:48:00+03	2017-08-11 10:38:00+03
3226	PG0227	2017-08-14 09:45:00+03	2017-08-14 10:35:00+03	VKO	LED	Arrived	321	2017-08-14 09:50:00+03	2017-08-14 10:39:00+03
3227	PG0228	2017-08-14 11:25:00+03	2017-08-14 12:15:00+03	VKO	LED	Arrived	321	2017-08-14 11:27:00+03	2017-08-14 12:17:00+03
3228	PG0229	2017-08-14 11:50:00+03	2017-08-14 12:40:00+03	VKO	LED	Arrived	321	2017-08-14 11:53:00+03	2017-08-14 12:43:00+03
3229	PG0227	2017-07-17 09:45:00+03	2017-07-17 10:35:00+03	VKO	LED	Arrived	321	2017-07-17 09:48:00+03	2017-07-17 10:39:00+03
3230	PG0228	2017-07-17 11:25:00+03	2017-07-17 12:15:00+03	VKO	LED	Arrived	321	2017-07-17 11:27:00+03	2017-07-17 12:16:00+03
3231	PG0229	2017-07-17 11:50:00+03	2017-07-17 12:40:00+03	VKO	LED	Arrived	321	2017-07-17 11:50:00+03	2017-07-17 12:40:00+03
3232	PG0227	2017-08-12 09:45:00+03	2017-08-12 10:35:00+03	VKO	LED	Arrived	321	2017-08-12 09:48:00+03	2017-08-12 10:38:00+03
3233	PG0228	2017-08-12 11:25:00+03	2017-08-12 12:15:00+03	VKO	LED	Arrived	321	2017-08-12 11:28:00+03	2017-08-12 12:17:00+03
3234	PG0229	2017-08-12 11:50:00+03	2017-08-12 12:40:00+03	VKO	LED	Arrived	321	2017-08-12 11:52:00+03	2017-08-12 12:42:00+03
3235	PG0229	2017-08-10 11:50:00+03	2017-08-10 12:40:00+03	VKO	LED	Arrived	321	2017-08-10 11:52:00+03	2017-08-10 12:42:00+03
3236	PG0228	2017-08-10 11:25:00+03	2017-08-10 12:15:00+03	VKO	LED	Arrived	321	2017-08-10 11:26:00+03	2017-08-10 12:16:00+03
3237	PG0227	2017-08-10 09:45:00+03	2017-08-10 10:35:00+03	VKO	LED	Arrived	321	2017-08-10 09:48:00+03	2017-08-10 10:38:00+03
3238	PG0227	2017-09-02 09:45:00+03	2017-09-02 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3239	PG0228	2017-09-02 11:25:00+03	2017-09-02 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3240	PG0229	2017-09-02 11:50:00+03	2017-09-02 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3241	PG0228	2017-09-14 11:25:00+03	2017-09-14 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3242	PG0227	2017-09-14 09:45:00+03	2017-09-14 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3243	PG0229	2017-08-24 11:50:00+03	2017-08-24 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3244	PG0228	2017-08-24 11:25:00+03	2017-08-24 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3245	PG0227	2017-08-24 09:45:00+03	2017-08-24 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3246	PG0227	2017-07-18 09:45:00+03	2017-07-18 10:35:00+03	VKO	LED	Arrived	321	2017-07-18 09:46:00+03	2017-07-18 10:36:00+03
3247	PG0228	2017-07-18 11:25:00+03	2017-07-18 12:15:00+03	VKO	LED	Arrived	321	2017-07-18 11:30:00+03	2017-07-18 12:19:00+03
3248	PG0229	2017-07-18 11:50:00+03	2017-07-18 12:40:00+03	VKO	LED	Arrived	321	2017-07-18 11:53:00+03	2017-07-18 12:42:00+03
3249	PG0229	2017-08-09 11:50:00+03	2017-08-09 12:40:00+03	VKO	LED	Arrived	321	2017-08-09 11:50:00+03	2017-08-09 12:39:00+03
3250	PG0228	2017-08-09 11:25:00+03	2017-08-09 12:15:00+03	VKO	LED	Arrived	321	2017-08-09 11:26:00+03	2017-08-09 12:16:00+03
3251	PG0227	2017-08-09 09:45:00+03	2017-08-09 10:35:00+03	VKO	LED	Arrived	321	2017-08-09 09:49:00+03	2017-08-09 10:38:00+03
3252	PG0227	2017-08-15 09:45:00+03	2017-08-15 10:35:00+03	VKO	LED	Arrived	321	2017-08-15 09:47:00+03	2017-08-15 10:36:00+03
3253	PG0228	2017-08-15 11:25:00+03	2017-08-15 12:15:00+03	VKO	LED	Arrived	321	2017-08-15 14:21:00+03	2017-08-15 15:11:00+03
3254	PG0229	2017-08-15 11:50:00+03	2017-08-15 12:40:00+03	VKO	LED	Arrived	321	2017-08-15 15:27:00+03	2017-08-15 16:17:00+03
3255	PG0229	2017-08-08 11:50:00+03	2017-08-08 12:40:00+03	VKO	LED	Arrived	321	2017-08-08 11:54:00+03	2017-08-08 12:45:00+03
3256	PG0228	2017-08-08 11:25:00+03	2017-08-08 12:15:00+03	VKO	LED	Arrived	321	2017-08-08 11:28:00+03	2017-08-08 12:18:00+03
3257	PG0227	2017-08-08 09:45:00+03	2017-08-08 10:35:00+03	VKO	LED	Arrived	321	2017-08-08 09:50:00+03	2017-08-08 10:40:00+03
3258	PG0229	2017-08-30 11:50:00+03	2017-08-30 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3259	PG0228	2017-08-30 11:25:00+03	2017-08-30 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3260	PG0227	2017-08-30 09:45:00+03	2017-08-30 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3261	PG0227	2017-09-03 09:45:00+03	2017-09-03 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3262	PG0228	2017-09-03 11:25:00+03	2017-09-03 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3263	PG0229	2017-09-03 11:50:00+03	2017-09-03 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3264	PG0227	2017-07-19 09:45:00+03	2017-07-19 10:35:00+03	VKO	LED	Arrived	321	2017-07-19 09:45:00+03	2017-07-19 10:35:00+03
3265	PG0228	2017-07-19 11:25:00+03	2017-07-19 12:15:00+03	VKO	LED	Arrived	321	2017-07-19 11:29:00+03	2017-07-19 12:20:00+03
3266	PG0229	2017-07-19 11:50:00+03	2017-07-19 12:40:00+03	VKO	LED	Arrived	321	2017-07-19 11:52:00+03	2017-07-19 12:43:00+03
3267	PG0229	2017-08-07 11:50:00+03	2017-08-07 12:40:00+03	VKO	LED	Arrived	321	2017-08-07 11:52:00+03	2017-08-07 12:41:00+03
3268	PG0228	2017-08-07 11:25:00+03	2017-08-07 12:15:00+03	VKO	LED	Arrived	321	2017-08-07 11:28:00+03	2017-08-07 12:17:00+03
3269	PG0227	2017-08-07 09:45:00+03	2017-08-07 10:35:00+03	VKO	LED	Arrived	321	2017-08-07 09:48:00+03	2017-08-07 10:39:00+03
3270	PG0229	2017-09-13 11:50:00+03	2017-09-13 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3271	PG0228	2017-09-13 11:25:00+03	2017-09-13 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3272	PG0227	2017-09-13 09:45:00+03	2017-09-13 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3273	PG0227	2017-08-16 09:45:00+03	2017-08-16 10:35:00+03	VKO	LED	On Time	321	\N	\N
3274	PG0228	2017-08-16 11:25:00+03	2017-08-16 12:15:00+03	VKO	LED	On Time	321	\N	\N
3275	PG0229	2017-08-16 11:50:00+03	2017-08-16 12:40:00+03	VKO	LED	On Time	321	\N	\N
3276	PG0229	2017-08-06 11:50:00+03	2017-08-06 12:40:00+03	VKO	LED	Arrived	321	2017-08-06 11:54:00+03	2017-08-06 12:43:00+03
3277	PG0228	2017-08-06 11:25:00+03	2017-08-06 12:15:00+03	VKO	LED	Arrived	321	2017-08-06 11:29:00+03	2017-08-06 12:19:00+03
3278	PG0227	2017-08-06 09:45:00+03	2017-08-06 10:35:00+03	VKO	LED	Arrived	321	2017-08-06 09:52:00+03	2017-08-06 10:42:00+03
3279	PG0227	2017-08-26 09:45:00+03	2017-08-26 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3280	PG0228	2017-08-26 11:25:00+03	2017-08-26 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3281	PG0229	2017-08-26 11:50:00+03	2017-08-26 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3282	PG0227	2017-07-20 09:45:00+03	2017-07-20 10:35:00+03	VKO	LED	Arrived	321	2017-07-20 09:47:00+03	2017-07-20 10:37:00+03
3283	PG0228	2017-07-20 11:25:00+03	2017-07-20 12:15:00+03	VKO	LED	Arrived	321	2017-07-20 11:27:00+03	2017-07-20 12:18:00+03
3284	PG0229	2017-07-20 11:50:00+03	2017-07-20 12:40:00+03	VKO	LED	Arrived	321	2017-07-20 11:51:00+03	2017-07-20 12:41:00+03
3285	PG0229	2017-08-25 11:50:00+03	2017-08-25 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3286	PG0227	2017-09-04 09:45:00+03	2017-09-04 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3287	PG0228	2017-09-04 11:25:00+03	2017-09-04 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3288	PG0229	2017-08-23 11:50:00+03	2017-08-23 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3289	PG0228	2017-08-23 11:25:00+03	2017-08-23 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3290	PG0227	2017-08-23 09:45:00+03	2017-08-23 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3291	PG0229	2017-08-05 11:50:00+03	2017-08-05 12:40:00+03	VKO	LED	Arrived	321	2017-08-05 11:51:00+03	2017-08-05 12:41:00+03
3292	PG0228	2017-08-05 11:25:00+03	2017-08-05 12:15:00+03	VKO	LED	Arrived	321	2017-08-05 11:27:00+03	2017-08-05 12:17:00+03
3293	PG0227	2017-08-05 09:45:00+03	2017-08-05 10:35:00+03	VKO	LED	Arrived	321	2017-08-05 09:48:00+03	2017-08-05 10:38:00+03
3294	PG0228	2017-08-25 11:25:00+03	2017-08-25 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3295	PG0229	2017-08-04 11:50:00+03	2017-08-04 12:40:00+03	VKO	LED	Arrived	321	2017-08-04 11:54:00+03	2017-08-04 12:43:00+03
3296	PG0228	2017-08-04 11:25:00+03	2017-08-04 12:15:00+03	VKO	LED	Arrived	321	2017-08-04 11:26:00+03	2017-08-04 12:16:00+03
3297	PG0227	2017-08-04 09:45:00+03	2017-08-04 10:35:00+03	VKO	LED	Arrived	321	2017-08-04 09:50:00+03	2017-08-04 10:40:00+03
3298	PG0227	2017-08-25 09:45:00+03	2017-08-25 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3299	PG0227	2017-07-21 09:45:00+03	2017-07-21 10:35:00+03	VKO	LED	Arrived	321	2017-07-21 09:47:00+03	2017-07-21 10:36:00+03
3300	PG0228	2017-07-21 11:25:00+03	2017-07-21 12:15:00+03	VKO	LED	Arrived	321	2017-07-21 11:31:00+03	2017-07-21 12:21:00+03
3301	PG0229	2017-07-21 11:50:00+03	2017-07-21 12:40:00+03	VKO	LED	Arrived	321	2017-07-21 11:56:00+03	2017-07-21 12:47:00+03
3302	PG0227	2017-08-17 09:45:00+03	2017-08-17 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3303	PG0228	2017-08-17 11:25:00+03	2017-08-17 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3304	PG0229	2017-08-17 11:50:00+03	2017-08-17 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3305	PG0229	2017-09-12 11:50:00+03	2017-09-12 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3306	PG0228	2017-09-12 11:25:00+03	2017-09-12 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3307	PG0227	2017-09-12 09:45:00+03	2017-09-12 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3308	PG0227	2017-09-05 09:45:00+03	2017-09-05 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3309	PG0228	2017-09-05 11:25:00+03	2017-09-05 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3310	PG0229	2017-09-05 11:50:00+03	2017-09-05 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3311	PG0229	2017-08-29 11:50:00+03	2017-08-29 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3312	PG0228	2017-08-29 11:25:00+03	2017-08-29 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3313	PG0227	2017-08-29 09:45:00+03	2017-08-29 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3314	PG0229	2017-07-16 11:50:00+03	2017-07-16 12:40:00+03	VKO	LED	Arrived	321	2017-07-16 11:55:00+03	2017-07-16 12:45:00+03
3315	PG0228	2017-07-16 11:25:00+03	2017-07-16 12:15:00+03	VKO	LED	Arrived	321	2017-07-16 11:26:00+03	2017-07-16 12:16:00+03
3316	PG0227	2017-07-16 09:45:00+03	2017-07-16 10:35:00+03	VKO	LED	Arrived	321	2017-07-16 09:50:00+03	2017-07-16 10:40:00+03
3317	PG0229	2017-08-03 11:50:00+03	2017-08-03 12:40:00+03	VKO	LED	Arrived	321	2017-08-03 11:55:00+03	2017-08-03 12:46:00+03
3318	PG0228	2017-08-03 11:25:00+03	2017-08-03 12:15:00+03	VKO	LED	Arrived	321	2017-08-03 11:27:00+03	2017-08-03 12:17:00+03
3319	PG0227	2017-08-03 09:45:00+03	2017-08-03 10:35:00+03	VKO	LED	Arrived	321	2017-08-03 12:42:00+03	2017-08-03 13:31:00+03
3320	PG0227	2017-07-22 09:45:00+03	2017-07-22 10:35:00+03	VKO	LED	Arrived	321	2017-07-22 09:46:00+03	2017-07-22 10:36:00+03
3321	PG0228	2017-07-22 11:25:00+03	2017-07-22 12:15:00+03	VKO	LED	Arrived	321	2017-07-22 11:32:00+03	2017-07-22 12:23:00+03
3322	PG0229	2017-07-22 11:50:00+03	2017-07-22 12:40:00+03	VKO	LED	Arrived	321	2017-07-22 11:51:00+03	2017-07-22 12:41:00+03
3323	PG0229	2017-08-02 11:50:00+03	2017-08-02 12:40:00+03	VKO	LED	Arrived	321	2017-08-02 11:52:00+03	2017-08-02 12:42:00+03
3324	PG0228	2017-08-02 11:25:00+03	2017-08-02 12:15:00+03	VKO	LED	Arrived	321	2017-08-02 11:29:00+03	2017-08-02 12:19:00+03
3325	PG0227	2017-08-02 09:45:00+03	2017-08-02 10:35:00+03	VKO	LED	Arrived	321	2017-08-02 09:50:00+03	2017-08-02 10:41:00+03
3326	PG0227	2017-09-06 09:45:00+03	2017-09-06 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3327	PG0228	2017-09-06 11:25:00+03	2017-09-06 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3328	PG0229	2017-09-06 11:50:00+03	2017-09-06 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3329	PG0227	2017-08-18 09:45:00+03	2017-08-18 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3330	PG0228	2017-08-18 11:25:00+03	2017-08-18 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3331	PG0229	2017-08-18 11:50:00+03	2017-08-18 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3332	PG0229	2017-08-01 11:50:00+03	2017-08-01 12:40:00+03	VKO	LED	Arrived	321	2017-08-01 11:55:00+03	2017-08-01 12:45:00+03
3333	PG0228	2017-08-01 11:25:00+03	2017-08-01 12:15:00+03	VKO	LED	Arrived	321	2017-08-01 11:29:00+03	2017-08-01 12:19:00+03
3334	PG0227	2017-08-01 09:45:00+03	2017-08-01 10:35:00+03	VKO	LED	Arrived	321	2017-08-01 09:48:00+03	2017-08-01 10:39:00+03
3335	PG0229	2017-08-22 11:50:00+03	2017-08-22 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3336	PG0228	2017-08-22 11:25:00+03	2017-08-22 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3337	PG0227	2017-08-22 09:45:00+03	2017-08-22 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3338	PG0227	2017-08-31 09:45:00+03	2017-08-31 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3339	PG0228	2017-08-31 11:25:00+03	2017-08-31 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3340	PG0229	2017-08-31 11:50:00+03	2017-08-31 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3341	PG0227	2017-07-23 09:45:00+03	2017-07-23 10:35:00+03	VKO	LED	Arrived	321	2017-07-23 09:47:00+03	2017-07-23 10:36:00+03
3342	PG0228	2017-07-23 11:25:00+03	2017-07-23 12:15:00+03	VKO	LED	Arrived	321	2017-07-23 14:42:00+03	2017-07-23 15:32:00+03
3343	PG0229	2017-07-23 11:50:00+03	2017-07-23 12:40:00+03	VKO	LED	Arrived	321	2017-07-23 11:55:00+03	2017-07-23 12:46:00+03
3344	PG0229	2017-09-11 11:50:00+03	2017-09-11 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3345	PG0228	2017-09-11 11:25:00+03	2017-09-11 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3346	PG0227	2017-09-11 09:45:00+03	2017-09-11 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3347	PG0229	2017-07-31 11:50:00+03	2017-07-31 12:40:00+03	VKO	LED	Arrived	321	2017-07-31 11:54:00+03	2017-07-31 12:43:00+03
3348	PG0228	2017-07-31 11:25:00+03	2017-07-31 12:15:00+03	VKO	LED	Arrived	321	2017-07-31 11:26:00+03	2017-07-31 12:16:00+03
3349	PG0227	2017-07-31 09:45:00+03	2017-07-31 10:35:00+03	VKO	LED	Arrived	321	2017-07-31 09:47:00+03	2017-07-31 10:37:00+03
3350	PG0227	2017-09-07 09:45:00+03	2017-09-07 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3351	PG0228	2017-09-07 11:25:00+03	2017-09-07 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3352	PG0229	2017-09-07 11:50:00+03	2017-09-07 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3353	PG0227	2017-08-19 09:45:00+03	2017-08-19 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3354	PG0228	2017-08-19 11:25:00+03	2017-08-19 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3355	PG0229	2017-08-19 11:50:00+03	2017-08-19 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3356	PG0229	2017-07-30 11:50:00+03	2017-07-30 12:40:00+03	VKO	LED	Arrived	321	2017-07-30 11:50:00+03	2017-07-30 12:39:00+03
3357	PG0228	2017-07-30 11:25:00+03	2017-07-30 12:15:00+03	VKO	LED	Arrived	321	2017-07-30 11:28:00+03	2017-07-30 12:18:00+03
3358	PG0227	2017-07-30 09:45:00+03	2017-07-30 10:35:00+03	VKO	LED	Arrived	321	2017-07-30 09:52:00+03	2017-07-30 10:42:00+03
3359	PG0227	2017-07-24 09:45:00+03	2017-07-24 10:35:00+03	VKO	LED	Arrived	321	2017-07-24 09:49:00+03	2017-07-24 10:39:00+03
3360	PG0228	2017-07-24 11:25:00+03	2017-07-24 12:15:00+03	VKO	LED	Arrived	321	2017-07-24 11:27:00+03	2017-07-24 12:17:00+03
3361	PG0229	2017-07-24 11:50:00+03	2017-07-24 12:40:00+03	VKO	LED	Arrived	321	2017-07-24 11:51:00+03	2017-07-24 12:40:00+03
3362	PG0229	2017-08-28 11:50:00+03	2017-08-28 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3363	PG0228	2017-08-28 11:25:00+03	2017-08-28 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3364	PG0227	2017-08-28 09:45:00+03	2017-08-28 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3365	PG0229	2017-07-29 11:50:00+03	2017-07-29 12:40:00+03	VKO	LED	Arrived	321	2017-07-29 15:18:00+03	2017-07-29 16:08:00+03
3366	PG0228	2017-07-29 11:25:00+03	2017-07-29 12:15:00+03	VKO	LED	Arrived	321	2017-07-29 11:28:00+03	2017-07-29 12:18:00+03
3367	PG0227	2017-07-29 09:45:00+03	2017-07-29 10:35:00+03	VKO	LED	Arrived	321	2017-07-29 09:48:00+03	2017-07-29 10:37:00+03
3368	PG0227	2017-08-27 09:45:00+03	2017-08-27 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3369	PG0227	2017-09-08 09:45:00+03	2017-09-08 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3370	PG0228	2017-09-08 11:25:00+03	2017-09-08 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3371	PG0229	2017-09-08 11:50:00+03	2017-09-08 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3372	PG0228	2017-08-27 11:25:00+03	2017-08-27 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3373	PG0229	2017-08-27 11:50:00+03	2017-08-27 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3374	PG0229	2017-09-10 11:50:00+03	2017-09-10 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3375	PG0228	2017-09-10 11:25:00+03	2017-09-10 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3376	PG0227	2017-09-10 09:45:00+03	2017-09-10 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3377	PG0227	2017-07-25 09:45:00+03	2017-07-25 10:35:00+03	VKO	LED	Arrived	321	2017-07-25 09:46:00+03	2017-07-25 10:36:00+03
3378	PG0228	2017-07-25 11:25:00+03	2017-07-25 12:15:00+03	VKO	LED	Arrived	321	2017-07-25 11:28:00+03	2017-07-25 12:19:00+03
3379	PG0229	2017-07-25 11:50:00+03	2017-07-25 12:40:00+03	VKO	LED	Arrived	321	2017-07-25 11:51:00+03	2017-07-25 12:41:00+03
3380	PG0229	2017-07-28 11:50:00+03	2017-07-28 12:40:00+03	VKO	LED	Arrived	321	2017-07-28 11:52:00+03	2017-07-28 12:42:00+03
3381	PG0228	2017-07-28 11:25:00+03	2017-07-28 12:15:00+03	VKO	LED	Arrived	321	2017-07-28 11:28:00+03	2017-07-28 12:19:00+03
3382	PG0227	2017-07-28 09:45:00+03	2017-07-28 10:35:00+03	VKO	LED	Arrived	321	2017-07-28 09:47:00+03	2017-07-28 10:37:00+03
3383	PG0229	2017-08-21 11:50:00+03	2017-08-21 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3384	PG0228	2017-08-21 11:25:00+03	2017-08-21 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3385	PG0227	2017-08-21 09:45:00+03	2017-08-21 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3386	PG0229	2017-08-13 11:50:00+03	2017-08-13 12:40:00+03	VKO	LED	Arrived	321	2017-08-13 11:56:00+03	2017-08-13 12:46:00+03
3387	PG0227	2017-08-20 09:45:00+03	2017-08-20 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3388	PG0228	2017-08-20 11:25:00+03	2017-08-20 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3389	PG0229	2017-08-20 11:50:00+03	2017-08-20 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3390	PG0228	2017-08-13 11:25:00+03	2017-08-13 12:15:00+03	VKO	LED	Arrived	321	2017-08-13 13:52:00+03	2017-08-13 14:42:00+03
3391	PG0227	2017-08-13 09:45:00+03	2017-08-13 10:35:00+03	VKO	LED	Arrived	321	2017-08-13 09:46:00+03	2017-08-13 10:36:00+03
3392	PG0229	2017-07-27 11:50:00+03	2017-07-27 12:40:00+03	VKO	LED	Arrived	321	2017-07-27 11:53:00+03	2017-07-27 12:43:00+03
3393	PG0228	2017-07-27 11:25:00+03	2017-07-27 12:15:00+03	VKO	LED	Arrived	321	2017-07-27 11:28:00+03	2017-07-27 12:18:00+03
3394	PG0227	2017-07-27 09:45:00+03	2017-07-27 10:35:00+03	VKO	LED	Arrived	321	2017-07-27 09:47:00+03	2017-07-27 10:38:00+03
3395	PG0227	2017-09-09 09:45:00+03	2017-09-09 10:35:00+03	VKO	LED	Scheduled	321	\N	\N
3396	PG0228	2017-09-09 11:25:00+03	2017-09-09 12:15:00+03	VKO	LED	Scheduled	321	\N	\N
3397	PG0229	2017-09-09 11:50:00+03	2017-09-09 12:40:00+03	VKO	LED	Scheduled	321	\N	\N
3398	PG0227	2017-07-26 09:45:00+03	2017-07-26 10:35:00+03	VKO	LED	Arrived	321	2017-07-26 09:47:00+03	2017-07-26 10:37:00+03
3399	PG0228	2017-07-26 11:25:00+03	2017-07-26 12:15:00+03	VKO	LED	Arrived	321	2017-07-26 11:26:00+03	2017-07-26 12:16:00+03
3400	PG0229	2017-07-26 11:50:00+03	2017-07-26 12:40:00+03	VKO	LED	Arrived	321	2017-07-26 11:52:00+03	2017-07-26 12:42:00+03
3401	PG0671	2017-09-02 13:05:00+03	2017-09-02 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3402	PG0671	2017-08-21 13:05:00+03	2017-08-21 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3403	PG0671	2017-07-22 13:05:00+03	2017-07-22 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-22 13:10:00+03	2017-07-22 16:24:00+03
3404	PG0671	2017-08-18 13:05:00+03	2017-08-18 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3405	PG0671	2017-08-11 13:05:00+03	2017-08-11 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-11 13:07:00+03	2017-08-11 16:22:00+03
3406	PG0671	2017-08-13 13:05:00+03	2017-08-13 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-13 13:08:00+03	2017-08-13 16:23:00+03
3407	PG0671	2017-09-12 13:05:00+03	2017-09-12 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3408	PG0671	2017-07-23 13:05:00+03	2017-07-23 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-23 13:08:00+03	2017-07-23 16:22:00+03
3409	PG0671	2017-09-08 13:05:00+03	2017-09-08 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3410	PG0671	2017-08-07 13:05:00+03	2017-08-07 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-07 13:12:00+03	2017-08-07 16:27:00+03
3411	PG0671	2017-09-07 13:05:00+03	2017-09-07 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3412	PG0671	2017-08-30 13:05:00+03	2017-08-30 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3413	PG0671	2017-08-26 13:05:00+03	2017-08-26 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3414	PG0671	2017-07-24 13:05:00+03	2017-07-24 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-24 13:08:00+03	2017-07-24 16:23:00+03
3415	PG0671	2017-07-16 13:05:00+03	2017-07-16 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-16 13:08:00+03	2017-07-16 16:23:00+03
3416	PG0671	2017-09-04 13:05:00+03	2017-09-04 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3417	PG0671	2017-07-18 13:05:00+03	2017-07-18 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-18 13:07:00+03	2017-07-18 16:23:00+03
3418	PG0671	2017-08-02 13:05:00+03	2017-08-02 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-02 13:07:00+03	2017-08-02 16:20:00+03
3419	PG0671	2017-08-22 13:05:00+03	2017-08-22 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3420	PG0671	2017-07-20 13:05:00+03	2017-07-20 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-20 13:07:00+03	2017-07-20 16:23:00+03
3421	PG0671	2017-07-28 13:05:00+03	2017-07-28 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-28 13:08:00+03	2017-07-28 16:21:00+03
3422	PG0671	2017-08-27 13:05:00+03	2017-08-27 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3423	PG0671	2017-07-21 13:05:00+03	2017-07-21 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-21 13:06:00+03	2017-07-21 16:20:00+03
3424	PG0671	2017-09-06 13:05:00+03	2017-09-06 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3425	PG0671	2017-08-25 13:05:00+03	2017-08-25 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3426	PG0671	2017-08-16 13:05:00+03	2017-08-16 16:20:00+03	VKO	OMS	On Time	CR2	\N	\N
3427	PG0671	2017-08-01 13:05:00+03	2017-08-01 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-01 13:08:00+03	2017-08-01 16:25:00+03
3428	PG0671	2017-08-19 13:05:00+03	2017-08-19 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3429	PG0671	2017-08-10 13:05:00+03	2017-08-10 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-10 13:08:00+03	2017-08-10 16:21:00+03
3430	PG0671	2017-08-06 13:05:00+03	2017-08-06 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-06 13:07:00+03	2017-08-06 16:25:00+03
3431	PG0671	2017-08-20 13:05:00+03	2017-08-20 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3432	PG0671	2017-08-14 13:05:00+03	2017-08-14 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-14 13:05:00+03	2017-08-14 16:21:00+03
3433	PG0671	2017-09-14 13:05:00+03	2017-09-14 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3434	PG0671	2017-08-04 13:05:00+03	2017-08-04 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-04 13:09:00+03	2017-08-04 16:23:00+03
3435	PG0671	2017-09-10 13:05:00+03	2017-09-10 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3436	PG0671	2017-07-25 13:05:00+03	2017-07-25 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-25 13:06:00+03	2017-07-25 16:17:00+03
3437	PG0671	2017-07-19 13:05:00+03	2017-07-19 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-19 13:08:00+03	2017-07-19 16:21:00+03
3438	PG0671	2017-08-09 13:05:00+03	2017-08-09 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-09 13:07:00+03	2017-08-09 16:22:00+03
3439	PG0671	2017-09-09 13:05:00+03	2017-09-09 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3440	PG0671	2017-08-31 13:05:00+03	2017-08-31 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3441	PG0671	2017-07-26 13:05:00+03	2017-07-26 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-26 13:07:00+03	2017-07-26 16:23:00+03
3442	PG0671	2017-09-05 13:05:00+03	2017-09-05 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3443	PG0671	2017-08-24 13:05:00+03	2017-08-24 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3444	PG0671	2017-07-30 13:05:00+03	2017-07-30 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-30 13:06:00+03	2017-07-30 16:21:00+03
3445	PG0671	2017-08-08 13:05:00+03	2017-08-08 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-08 13:11:00+03	2017-08-08 16:26:00+03
3446	PG0671	2017-09-11 13:05:00+03	2017-09-11 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3447	PG0671	2017-07-17 13:05:00+03	2017-07-17 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-17 13:07:00+03	2017-07-17 16:20:00+03
3448	PG0671	2017-08-28 13:05:00+03	2017-08-28 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3449	PG0671	2017-08-03 13:05:00+03	2017-08-03 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-03 13:07:00+03	2017-08-03 16:22:00+03
3450	PG0671	2017-09-03 13:05:00+03	2017-09-03 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3451	PG0671	2017-08-15 13:05:00+03	2017-08-15 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-15 13:07:00+03	2017-08-15 16:20:00+03
3452	PG0671	2017-07-27 13:05:00+03	2017-07-27 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-27 13:07:00+03	2017-07-27 16:19:00+03
3453	PG0671	2017-08-12 13:05:00+03	2017-08-12 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-12 13:07:00+03	2017-08-12 16:19:00+03
3454	PG0671	2017-08-23 13:05:00+03	2017-08-23 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3455	PG0671	2017-08-29 13:05:00+03	2017-08-29 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3456	PG0671	2017-08-17 13:05:00+03	2017-08-17 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3457	PG0671	2017-07-29 13:05:00+03	2017-07-29 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-29 13:10:00+03	2017-07-29 16:24:00+03
3458	PG0671	2017-07-31 13:05:00+03	2017-07-31 16:20:00+03	VKO	OMS	Arrived	CR2	2017-07-31 13:08:00+03	2017-07-31 16:22:00+03
3459	PG0671	2017-09-13 13:05:00+03	2017-09-13 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3460	PG0671	2017-08-05 13:05:00+03	2017-08-05 16:20:00+03	VKO	OMS	Arrived	CR2	2017-08-05 13:05:00+03	2017-08-05 16:21:00+03
3461	PG0671	2017-09-01 13:05:00+03	2017-09-01 16:20:00+03	VKO	OMS	Scheduled	CR2	\N	\N
3462	PG0412	2017-08-22 11:00:00+03	2017-08-22 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3463	PG0412	2017-08-09 11:00:00+03	2017-08-09 12:25:00+03	VKO	PEE	Arrived	773	2017-08-09 11:02:00+03	2017-08-09 12:27:00+03
3464	PG0412	2017-08-26 11:00:00+03	2017-08-26 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3465	PG0412	2017-09-03 11:00:00+03	2017-09-03 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3466	PG0412	2017-08-02 11:00:00+03	2017-08-02 12:25:00+03	VKO	PEE	Arrived	773	2017-08-02 11:01:00+03	2017-08-02 12:25:00+03
3467	PG0412	2017-08-24 11:00:00+03	2017-08-24 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3468	PG0412	2017-08-15 11:00:00+03	2017-08-15 12:25:00+03	VKO	PEE	Arrived	773	2017-08-15 11:02:00+03	2017-08-15 12:26:00+03
3469	PG0412	2017-08-18 11:00:00+03	2017-08-18 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3470	PG0412	2017-08-31 11:00:00+03	2017-08-31 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3471	PG0412	2017-08-28 11:00:00+03	2017-08-28 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3472	PG0412	2017-08-29 11:00:00+03	2017-08-29 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3473	PG0412	2017-07-19 11:00:00+03	2017-07-19 12:25:00+03	VKO	PEE	Arrived	773	2017-07-19 11:08:00+03	2017-07-19 12:32:00+03
3474	PG0412	2017-08-10 11:00:00+03	2017-08-10 12:25:00+03	VKO	PEE	Arrived	773	2017-08-10 11:01:00+03	2017-08-10 12:26:00+03
3475	PG0412	2017-07-17 11:00:00+03	2017-07-17 12:25:00+03	VKO	PEE	Arrived	773	2017-07-17 11:07:00+03	2017-07-17 12:34:00+03
3476	PG0412	2017-08-04 11:00:00+03	2017-08-04 12:25:00+03	VKO	PEE	Arrived	773	2017-08-04 11:05:00+03	2017-08-04 12:30:00+03
3477	PG0412	2017-07-27 11:00:00+03	2017-07-27 12:25:00+03	VKO	PEE	Arrived	773	2017-07-27 14:52:00+03	2017-07-27 16:18:00+03
3478	PG0412	2017-09-06 11:00:00+03	2017-09-06 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3479	PG0412	2017-08-03 11:00:00+03	2017-08-03 12:25:00+03	VKO	PEE	Arrived	773	2017-08-03 11:03:00+03	2017-08-03 12:27:00+03
3480	PG0412	2017-07-31 11:00:00+03	2017-07-31 12:25:00+03	VKO	PEE	Arrived	773	2017-07-31 11:05:00+03	2017-07-31 12:30:00+03
3481	PG0412	2017-08-16 11:00:00+03	2017-08-16 12:25:00+03	VKO	PEE	On Time	773	\N	\N
3482	PG0412	2017-09-11 11:00:00+03	2017-09-11 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3483	PG0412	2017-09-08 11:00:00+03	2017-09-08 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3484	PG0412	2017-09-02 11:00:00+03	2017-09-02 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3485	PG0412	2017-07-25 11:00:00+03	2017-07-25 12:25:00+03	VKO	PEE	Arrived	773	2017-07-25 11:02:00+03	2017-07-25 12:27:00+03
3486	PG0412	2017-08-05 11:00:00+03	2017-08-05 12:25:00+03	VKO	PEE	Arrived	773	2017-08-05 11:04:00+03	2017-08-05 12:30:00+03
3487	PG0412	2017-08-11 11:00:00+03	2017-08-11 12:25:00+03	VKO	PEE	Arrived	773	2017-08-11 11:00:00+03	2017-08-11 12:23:00+03
3488	PG0412	2017-08-19 11:00:00+03	2017-08-19 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3489	PG0412	2017-09-12 11:00:00+03	2017-09-12 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3490	PG0412	2017-07-16 11:00:00+03	2017-07-16 12:25:00+03	VKO	PEE	Arrived	773	2017-07-16 11:02:00+03	2017-07-16 12:27:00+03
3491	PG0412	2017-07-23 11:00:00+03	2017-07-23 12:25:00+03	VKO	PEE	Arrived	773	2017-07-23 11:03:00+03	2017-07-23 12:27:00+03
3492	PG0412	2017-08-12 11:00:00+03	2017-08-12 12:25:00+03	VKO	PEE	Arrived	773	2017-08-12 11:01:00+03	2017-08-12 12:25:00+03
3493	PG0412	2017-09-07 11:00:00+03	2017-09-07 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3494	PG0412	2017-09-14 11:00:00+03	2017-09-14 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3495	PG0412	2017-07-20 11:00:00+03	2017-07-20 12:25:00+03	VKO	PEE	Arrived	773	2017-07-20 11:01:00+03	2017-07-20 12:25:00+03
3496	PG0412	2017-07-30 11:00:00+03	2017-07-30 12:25:00+03	VKO	PEE	Arrived	773	2017-07-30 11:05:00+03	2017-07-30 12:30:00+03
3497	PG0412	2017-08-14 11:00:00+03	2017-08-14 12:25:00+03	VKO	PEE	Arrived	773	2017-08-14 11:01:00+03	2017-08-14 12:26:00+03
3498	PG0412	2017-08-27 11:00:00+03	2017-08-27 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3499	PG0412	2017-07-24 11:00:00+03	2017-07-24 12:25:00+03	VKO	PEE	Arrived	773	2017-07-24 11:02:00+03	2017-07-24 12:29:00+03
3500	PG0412	2017-08-13 11:00:00+03	2017-08-13 12:25:00+03	VKO	PEE	Arrived	773	2017-08-13 11:01:00+03	2017-08-13 12:26:00+03
3501	PG0412	2017-09-10 11:00:00+03	2017-09-10 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3502	PG0412	2017-08-01 11:00:00+03	2017-08-01 12:25:00+03	VKO	PEE	Arrived	773	2017-08-01 11:02:00+03	2017-08-01 12:29:00+03
3503	PG0412	2017-08-30 11:00:00+03	2017-08-30 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3504	PG0412	2017-08-06 11:00:00+03	2017-08-06 12:25:00+03	VKO	PEE	Arrived	773	2017-08-06 13:15:00+03	2017-08-06 14:39:00+03
3505	PG0412	2017-08-25 11:00:00+03	2017-08-25 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3506	PG0412	2017-07-29 11:00:00+03	2017-07-29 12:25:00+03	VKO	PEE	Arrived	773	2017-07-29 11:05:00+03	2017-07-29 12:30:00+03
3507	PG0412	2017-09-13 11:00:00+03	2017-09-13 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3508	PG0412	2017-07-26 11:00:00+03	2017-07-26 12:25:00+03	VKO	PEE	Arrived	773	2017-07-26 11:01:00+03	2017-07-26 12:27:00+03
3509	PG0412	2017-09-01 11:00:00+03	2017-09-01 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3510	PG0412	2017-08-07 11:00:00+03	2017-08-07 12:25:00+03	VKO	PEE	Arrived	773	2017-08-07 11:02:00+03	2017-08-07 12:27:00+03
3511	PG0412	2017-07-22 11:00:00+03	2017-07-22 12:25:00+03	VKO	PEE	Arrived	773	2017-07-22 11:02:00+03	2017-07-22 12:28:00+03
3512	PG0412	2017-07-18 11:00:00+03	2017-07-18 12:25:00+03	VKO	PEE	Arrived	773	2017-07-18 11:05:00+03	2017-07-18 12:29:00+03
3513	PG0412	2017-09-04 11:00:00+03	2017-09-04 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3514	PG0412	2017-08-21 11:00:00+03	2017-08-21 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3515	PG0412	2017-09-09 11:00:00+03	2017-09-09 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3516	PG0412	2017-08-20 11:00:00+03	2017-08-20 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3517	PG0412	2017-08-08 11:00:00+03	2017-08-08 12:25:00+03	VKO	PEE	Arrived	773	2017-08-08 11:02:00+03	2017-08-08 12:28:00+03
3518	PG0412	2017-07-21 11:00:00+03	2017-07-21 12:25:00+03	VKO	PEE	Arrived	773	2017-07-21 11:03:00+03	2017-07-21 12:29:00+03
3519	PG0412	2017-09-05 11:00:00+03	2017-09-05 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3520	PG0412	2017-08-23 11:00:00+03	2017-08-23 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3521	PG0412	2017-08-17 11:00:00+03	2017-08-17 12:25:00+03	VKO	PEE	Scheduled	773	\N	\N
3522	PG0412	2017-07-28 11:00:00+03	2017-07-28 12:25:00+03	VKO	PEE	Arrived	773	2017-07-28 11:08:00+03	2017-07-28 12:35:00+03
3523	PG0396	2017-07-18 16:20:00+03	2017-07-18 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-18 16:21:00+03	2017-07-18 17:30:00+03
3524	PG0396	2017-07-21 16:20:00+03	2017-07-21 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-21 16:23:00+03	2017-07-21 17:33:00+03
3525	PG0396	2017-08-18 16:20:00+03	2017-08-18 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3526	PG0396	2017-08-26 16:20:00+03	2017-08-26 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3527	PG0396	2017-08-08 16:20:00+03	2017-08-08 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-08 16:23:00+03	2017-08-08 17:32:00+03
3528	PG0396	2017-08-15 16:20:00+03	2017-08-15 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-15 16:24:00+03	2017-08-15 17:34:00+03
3529	PG0396	2017-07-30 16:20:00+03	2017-07-30 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-30 16:24:00+03	2017-07-30 17:35:00+03
3530	PG0396	2017-09-07 16:20:00+03	2017-09-07 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3531	PG0396	2017-08-02 16:20:00+03	2017-08-02 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-02 16:29:00+03	2017-08-02 17:40:00+03
3532	PG0396	2017-08-04 16:20:00+03	2017-08-04 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-04 19:42:00+03	2017-08-04 20:52:00+03
3533	PG0396	2017-07-16 16:20:00+03	2017-07-16 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-16 16:23:00+03	2017-07-16 17:33:00+03
3534	PG0396	2017-08-25 16:20:00+03	2017-08-25 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3535	PG0396	2017-08-07 16:20:00+03	2017-08-07 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-07 16:23:00+03	2017-08-07 17:33:00+03
3536	PG0396	2017-09-10 16:20:00+03	2017-09-10 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3537	PG0396	2017-09-14 16:20:00+03	2017-09-14 17:30:00+03	VKO	VOG	Cancelled	SU9	\N	\N
3538	PG0396	2017-08-01 16:20:00+03	2017-08-01 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-01 16:21:00+03	2017-08-01 17:30:00+03
3539	PG0396	2017-09-01 16:20:00+03	2017-09-01 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3540	PG0396	2017-07-19 16:20:00+03	2017-07-19 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-19 16:21:00+03	2017-07-19 17:31:00+03
3541	PG0396	2017-08-24 16:20:00+03	2017-08-24 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3542	PG0396	2017-08-14 16:20:00+03	2017-08-14 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-14 16:22:00+03	2017-08-14 17:33:00+03
3543	PG0396	2017-09-11 16:20:00+03	2017-09-11 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3544	PG0396	2017-08-12 16:20:00+03	2017-08-12 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-12 19:10:00+03	2017-08-12 20:19:00+03
3545	PG0396	2017-08-03 16:20:00+03	2017-08-03 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-03 16:24:00+03	2017-08-03 17:34:00+03
3546	PG0396	2017-07-22 16:20:00+03	2017-07-22 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-22 16:21:00+03	2017-07-22 17:30:00+03
3547	PG0396	2017-08-19 16:20:00+03	2017-08-19 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3548	PG0396	2017-07-29 16:20:00+03	2017-07-29 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-29 16:21:00+03	2017-07-29 17:30:00+03
3549	PG0396	2017-08-06 16:20:00+03	2017-08-06 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-06 16:22:00+03	2017-08-06 17:32:00+03
3550	PG0396	2017-09-05 16:20:00+03	2017-09-05 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3551	PG0396	2017-09-12 16:20:00+03	2017-09-12 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3552	PG0396	2017-09-06 16:20:00+03	2017-09-06 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3553	PG0396	2017-07-17 16:20:00+03	2017-07-17 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-17 16:22:00+03	2017-07-17 17:31:00+03
3554	PG0396	2017-07-27 16:20:00+03	2017-07-27 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-27 16:25:00+03	2017-07-27 17:35:00+03
3555	PG0396	2017-08-29 16:20:00+03	2017-08-29 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3556	PG0396	2017-08-21 16:20:00+03	2017-08-21 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3557	PG0396	2017-07-25 16:20:00+03	2017-07-25 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-25 16:23:00+03	2017-07-25 17:33:00+03
3558	PG0396	2017-09-13 16:20:00+03	2017-09-13 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3559	PG0396	2017-07-20 16:20:00+03	2017-07-20 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-20 16:24:00+03	2017-07-20 17:34:00+03
3560	PG0396	2017-08-27 16:20:00+03	2017-08-27 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3561	PG0396	2017-09-08 16:20:00+03	2017-09-08 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3562	PG0396	2017-08-20 16:20:00+03	2017-08-20 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3563	PG0396	2017-08-05 16:20:00+03	2017-08-05 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-05 16:22:00+03	2017-08-05 17:31:00+03
3564	PG0396	2017-08-30 16:20:00+03	2017-08-30 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3565	PG0396	2017-09-04 16:20:00+03	2017-09-04 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3566	PG0396	2017-09-02 16:20:00+03	2017-09-02 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3567	PG0396	2017-08-13 16:20:00+03	2017-08-13 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-13 16:25:00+03	2017-08-13 17:36:00+03
3568	PG0396	2017-08-28 16:20:00+03	2017-08-28 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3569	PG0396	2017-09-09 16:20:00+03	2017-09-09 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3570	PG0396	2017-08-10 16:20:00+03	2017-08-10 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-10 16:21:00+03	2017-08-10 17:31:00+03
3571	PG0396	2017-08-09 16:20:00+03	2017-08-09 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-09 16:22:00+03	2017-08-09 17:32:00+03
3572	PG0396	2017-08-17 16:20:00+03	2017-08-17 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3573	PG0396	2017-07-24 16:20:00+03	2017-07-24 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-24 16:22:00+03	2017-07-24 17:31:00+03
3574	PG0396	2017-09-03 16:20:00+03	2017-09-03 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3575	PG0396	2017-07-28 16:20:00+03	2017-07-28 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-28 18:50:00+03	2017-07-28 20:01:00+03
3576	PG0396	2017-08-16 16:20:00+03	2017-08-16 17:30:00+03	VKO	VOG	On Time	SU9	\N	\N
3577	PG0396	2017-08-23 16:20:00+03	2017-08-23 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3578	PG0396	2017-08-11 16:20:00+03	2017-08-11 17:30:00+03	VKO	VOG	Arrived	SU9	2017-08-11 16:23:00+03	2017-08-11 17:33:00+03
3579	PG0396	2017-07-23 16:20:00+03	2017-07-23 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-23 16:24:00+03	2017-07-23 17:34:00+03
3580	PG0396	2017-08-22 16:20:00+03	2017-08-22 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3581	PG0396	2017-07-31 16:20:00+03	2017-07-31 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-31 16:24:00+03	2017-07-31 17:35:00+03
3582	PG0396	2017-07-26 16:20:00+03	2017-07-26 17:30:00+03	VKO	VOG	Arrived	SU9	2017-07-26 16:25:00+03	2017-07-26 17:36:00+03
3583	PG0396	2017-08-31 16:20:00+03	2017-08-31 17:30:00+03	VKO	VOG	Scheduled	SU9	\N	\N
3584	PG0414	2017-09-09 09:05:00+03	2017-09-09 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3585	PG0414	2017-09-11 09:05:00+03	2017-09-11 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3586	PG0414	2017-09-08 09:05:00+03	2017-09-08 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3587	PG0414	2017-08-01 09:05:00+03	2017-08-01 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-01 12:28:00+03	2017-08-01 14:36:00+03
3588	PG0414	2017-07-26 09:05:00+03	2017-07-26 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-26 09:05:00+03	2017-07-26 11:11:00+03
3589	PG0414	2017-07-18 09:05:00+03	2017-07-18 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-18 09:08:00+03	2017-07-18 11:12:00+03
3590	PG0414	2017-09-07 09:05:00+03	2017-09-07 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3591	PG0414	2017-09-02 09:05:00+03	2017-09-02 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3592	PG0414	2017-08-04 09:05:00+03	2017-08-04 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-04 09:08:00+03	2017-08-04 11:11:00+03
3593	PG0414	2017-07-31 09:05:00+03	2017-07-31 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-31 09:06:00+03	2017-07-31 11:12:00+03
3594	PG0414	2017-09-13 09:05:00+03	2017-09-13 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3595	PG0414	2017-08-03 09:05:00+03	2017-08-03 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-03 09:09:00+03	2017-08-03 11:14:00+03
3596	PG0414	2017-09-06 09:05:00+03	2017-09-06 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3597	PG0414	2017-08-05 09:05:00+03	2017-08-05 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-05 09:09:00+03	2017-08-05 11:13:00+03
3598	PG0414	2017-08-11 09:05:00+03	2017-08-11 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-11 09:07:00+03	2017-08-11 11:10:00+03
3599	PG0414	2017-07-25 09:05:00+03	2017-07-25 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-25 09:09:00+03	2017-07-25 11:15:00+03
3600	PG0414	2017-07-28 09:05:00+03	2017-07-28 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-28 09:07:00+03	2017-07-28 11:10:00+03
3601	PG0414	2017-08-25 09:05:00+03	2017-08-25 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3602	PG0414	2017-08-13 09:05:00+03	2017-08-13 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-13 09:13:00+03	2017-08-13 11:16:00+03
3603	PG0414	2017-08-27 09:05:00+03	2017-08-27 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3604	PG0414	2017-07-20 09:05:00+03	2017-07-20 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-20 09:07:00+03	2017-07-20 11:09:00+03
3605	PG0414	2017-07-24 09:05:00+03	2017-07-24 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-24 12:01:00+03	2017-07-24 14:04:00+03
3606	PG0414	2017-09-05 09:05:00+03	2017-09-05 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3607	PG0414	2017-08-06 09:05:00+03	2017-08-06 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-06 09:08:00+03	2017-08-06 11:13:00+03
3608	PG0414	2017-08-30 09:05:00+03	2017-08-30 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3609	PG0414	2017-08-12 09:05:00+03	2017-08-12 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-12 09:07:00+03	2017-08-12 11:12:00+03
3610	PG0414	2017-08-29 09:05:00+03	2017-08-29 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3611	PG0414	2017-07-29 09:05:00+03	2017-07-29 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-29 09:06:00+03	2017-07-29 11:13:00+03
3612	PG0414	2017-08-20 09:05:00+03	2017-08-20 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3613	PG0414	2017-07-30 09:05:00+03	2017-07-30 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-30 09:08:00+03	2017-07-30 11:12:00+03
3614	PG0414	2017-07-22 09:05:00+03	2017-07-22 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-22 09:07:00+03	2017-07-22 11:09:00+03
3615	PG0414	2017-09-01 09:05:00+03	2017-09-01 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3616	PG0414	2017-09-04 09:05:00+03	2017-09-04 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3617	PG0414	2017-08-23 09:05:00+03	2017-08-23 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3618	PG0414	2017-08-17 09:05:00+03	2017-08-17 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3619	PG0414	2017-08-26 09:05:00+03	2017-08-26 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3620	PG0414	2017-08-07 09:05:00+03	2017-08-07 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-07 09:07:00+03	2017-08-07 11:13:00+03
3621	PG0414	2017-07-21 09:05:00+03	2017-07-21 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-21 09:06:00+03	2017-07-21 11:13:00+03
3622	PG0414	2017-08-02 09:05:00+03	2017-08-02 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-02 09:05:00+03	2017-08-02 11:10:00+03
3623	PG0414	2017-08-15 09:05:00+03	2017-08-15 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-15 09:09:00+03	2017-08-15 11:16:00+03
3624	PG0414	2017-09-03 09:05:00+03	2017-09-03 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3625	PG0414	2017-07-16 09:05:00+03	2017-07-16 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-16 09:09:00+03	2017-07-16 11:14:00+03
3626	PG0414	2017-08-28 09:05:00+03	2017-08-28 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3627	PG0414	2017-08-09 09:05:00+03	2017-08-09 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-09 09:07:00+03	2017-08-09 11:13:00+03
3628	PG0414	2017-08-24 09:05:00+03	2017-08-24 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3629	PG0414	2017-08-21 09:05:00+03	2017-08-21 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3630	PG0414	2017-09-10 09:05:00+03	2017-09-10 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3631	PG0414	2017-08-31 09:05:00+03	2017-08-31 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3632	PG0414	2017-08-14 09:05:00+03	2017-08-14 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-14 09:09:00+03	2017-08-14 11:12:00+03
3633	PG0414	2017-09-14 09:05:00+03	2017-09-14 11:10:00+03	VKO	MMK	Cancelled	CR2	\N	\N
3634	PG0414	2017-09-12 09:05:00+03	2017-09-12 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3635	PG0414	2017-08-22 09:05:00+03	2017-08-22 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3636	PG0414	2017-07-19 09:05:00+03	2017-07-19 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-19 09:10:00+03	2017-07-19 11:14:00+03
3637	PG0414	2017-07-27 09:05:00+03	2017-07-27 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-27 09:09:00+03	2017-07-27 11:14:00+03
3638	PG0414	2017-07-17 09:05:00+03	2017-07-17 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-17 09:08:00+03	2017-07-17 11:11:00+03
3639	PG0414	2017-08-10 09:05:00+03	2017-08-10 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-10 09:07:00+03	2017-08-10 11:11:00+03
3640	PG0414	2017-08-18 09:05:00+03	2017-08-18 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3641	PG0414	2017-08-16 09:05:00+03	2017-08-16 11:10:00+03	VKO	MMK	On Time	CR2	\N	\N
3642	PG0414	2017-08-08 09:05:00+03	2017-08-08 11:10:00+03	VKO	MMK	Arrived	CR2	2017-08-08 09:06:00+03	2017-08-08 11:11:00+03
3643	PG0414	2017-07-23 09:05:00+03	2017-07-23 11:10:00+03	VKO	MMK	Arrived	CR2	2017-07-23 09:09:00+03	2017-07-23 11:14:00+03
3644	PG0414	2017-08-19 09:05:00+03	2017-08-19 11:10:00+03	VKO	MMK	Scheduled	CR2	\N	\N
3645	PG0050	2017-09-03 14:20:00+03	2017-09-03 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3646	PG0050	2017-09-04 14:20:00+03	2017-09-04 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3647	PG0050	2017-07-29 14:20:00+03	2017-07-29 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-29 14:23:00+03	2017-07-29 15:22:00+03
3648	PG0050	2017-07-26 14:20:00+03	2017-07-26 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-26 14:21:00+03	2017-07-26 15:20:00+03
3649	PG0050	2017-09-12 14:20:00+03	2017-09-12 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3650	PG0050	2017-08-07 14:20:00+03	2017-08-07 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-07 14:22:00+03	2017-08-07 15:22:00+03
3651	PG0050	2017-08-05 14:20:00+03	2017-08-05 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-05 14:22:00+03	2017-08-05 15:21:00+03
3652	PG0050	2017-08-21 14:20:00+03	2017-08-21 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3653	PG0050	2017-08-24 14:20:00+03	2017-08-24 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3654	PG0050	2017-09-14 14:20:00+03	2017-09-14 15:20:00+03	VKO	PES	Cancelled	CR2	\N	\N
3655	PG0050	2017-08-28 14:20:00+03	2017-08-28 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3656	PG0050	2017-09-06 14:20:00+03	2017-09-06 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3657	PG0050	2017-08-29 14:20:00+03	2017-08-29 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3658	PG0050	2017-09-11 14:20:00+03	2017-09-11 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3659	PG0050	2017-09-08 14:20:00+03	2017-09-08 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3660	PG0050	2017-07-16 14:20:00+03	2017-07-16 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-16 14:21:00+03	2017-07-16 15:21:00+03
3661	PG0050	2017-08-25 14:20:00+03	2017-08-25 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3662	PG0050	2017-08-06 14:20:00+03	2017-08-06 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-06 14:25:00+03	2017-08-06 15:24:00+03
3663	PG0050	2017-09-10 14:20:00+03	2017-09-10 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3664	PG0050	2017-07-19 14:20:00+03	2017-07-19 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-19 14:23:00+03	2017-07-19 15:24:00+03
3665	PG0050	2017-07-27 14:20:00+03	2017-07-27 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-27 17:31:00+03	2017-07-27 18:32:00+03
3666	PG0050	2017-09-05 14:20:00+03	2017-09-05 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3667	PG0050	2017-07-17 14:20:00+03	2017-07-17 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-17 14:22:00+03	2017-07-17 15:22:00+03
3668	PG0050	2017-07-28 14:20:00+03	2017-07-28 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-28 14:22:00+03	2017-07-28 15:22:00+03
3669	PG0050	2017-09-09 14:20:00+03	2017-09-09 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3670	PG0050	2017-08-18 14:20:00+03	2017-08-18 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3671	PG0050	2017-08-15 14:20:00+03	2017-08-15 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-15 14:23:00+03	2017-08-15 15:23:00+03
3672	PG0050	2017-08-10 14:20:00+03	2017-08-10 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-10 14:26:00+03	2017-08-10 15:25:00+03
3673	PG0050	2017-07-22 14:20:00+03	2017-07-22 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-22 14:20:00+03	2017-07-22 15:19:00+03
3674	PG0050	2017-07-25 14:20:00+03	2017-07-25 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-25 14:21:00+03	2017-07-25 15:22:00+03
3675	PG0050	2017-09-07 14:20:00+03	2017-09-07 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3676	PG0050	2017-08-09 14:20:00+03	2017-08-09 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-09 14:26:00+03	2017-08-09 15:26:00+03
3677	PG0050	2017-08-08 14:20:00+03	2017-08-08 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-08 14:22:00+03	2017-08-08 15:22:00+03
3678	PG0050	2017-08-31 14:20:00+03	2017-08-31 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3679	PG0050	2017-07-21 14:20:00+03	2017-07-21 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-21 14:23:00+03	2017-07-21 15:23:00+03
3680	PG0050	2017-07-30 14:20:00+03	2017-07-30 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-30 14:23:00+03	2017-07-30 15:22:00+03
3681	PG0050	2017-08-20 14:20:00+03	2017-08-20 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3682	PG0050	2017-08-01 14:20:00+03	2017-08-01 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-01 14:22:00+03	2017-08-01 15:21:00+03
3683	PG0050	2017-08-13 14:20:00+03	2017-08-13 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-13 14:23:00+03	2017-08-13 15:22:00+03
3684	PG0050	2017-09-01 14:20:00+03	2017-09-01 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3685	PG0050	2017-08-17 14:20:00+03	2017-08-17 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3686	PG0050	2017-07-18 14:20:00+03	2017-07-18 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-18 14:21:00+03	2017-07-18 15:21:00+03
3687	PG0050	2017-08-16 14:20:00+03	2017-08-16 15:20:00+03	VKO	PES	On Time	CR2	\N	\N
3688	PG0050	2017-08-04 14:20:00+03	2017-08-04 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-04 14:24:00+03	2017-08-04 15:24:00+03
3689	PG0050	2017-08-23 14:20:00+03	2017-08-23 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3690	PG0050	2017-08-12 14:20:00+03	2017-08-12 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-12 14:25:00+03	2017-08-12 15:25:00+03
3691	PG0050	2017-09-02 14:20:00+03	2017-09-02 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3692	PG0050	2017-08-14 14:20:00+03	2017-08-14 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-14 14:20:00+03	2017-08-14 15:19:00+03
3693	PG0050	2017-08-22 14:20:00+03	2017-08-22 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3694	PG0050	2017-08-11 14:20:00+03	2017-08-11 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-11 14:20:00+03	2017-08-11 15:20:00+03
3695	PG0050	2017-08-26 14:20:00+03	2017-08-26 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3696	PG0050	2017-08-02 14:20:00+03	2017-08-02 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-02 14:23:00+03	2017-08-02 15:22:00+03
3697	PG0050	2017-08-03 14:20:00+03	2017-08-03 15:20:00+03	VKO	PES	Arrived	CR2	2017-08-03 14:23:00+03	2017-08-03 15:23:00+03
3698	PG0050	2017-07-20 14:20:00+03	2017-07-20 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-20 14:23:00+03	2017-07-20 15:23:00+03
3699	PG0050	2017-08-30 14:20:00+03	2017-08-30 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3700	PG0050	2017-09-13 14:20:00+03	2017-09-13 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3701	PG0050	2017-08-19 14:20:00+03	2017-08-19 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3702	PG0050	2017-07-24 14:20:00+03	2017-07-24 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-24 14:21:00+03	2017-07-24 15:22:00+03
3703	PG0050	2017-08-27 14:20:00+03	2017-08-27 15:20:00+03	VKO	PES	Scheduled	CR2	\N	\N
3704	PG0050	2017-07-23 14:20:00+03	2017-07-23 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-23 14:29:00+03	2017-07-23 15:29:00+03
3705	PG0050	2017-07-31 14:20:00+03	2017-07-31 15:20:00+03	VKO	PES	Arrived	CR2	2017-07-31 14:25:00+03	2017-07-31 15:24:00+03
3706	PG0007	2017-07-16 12:40:00+03	2017-07-16 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-16 12:46:00+03	2017-07-16 14:58:00+03
3707	PG0007	2017-08-01 12:40:00+03	2017-08-01 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-01 12:41:00+03	2017-08-01 14:53:00+03
3708	PG0008	2017-08-01 11:45:00+03	2017-08-01 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-01 11:49:00+03	2017-08-01 14:00:00+03
3709	PG0008	2017-08-12 11:45:00+03	2017-08-12 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-12 15:08:00+03	2017-08-12 17:17:00+03
3710	PG0008	2017-08-15 11:45:00+03	2017-08-15 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-15 11:49:00+03	2017-08-15 13:55:00+03
3711	PG0007	2017-08-28 12:40:00+03	2017-08-28 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3712	PG0008	2017-09-06 11:45:00+03	2017-09-06 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3713	PG0007	2017-08-15 12:40:00+03	2017-08-15 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-15 12:42:00+03	2017-08-15 14:52:00+03
3714	PG0008	2017-08-28 11:45:00+03	2017-08-28 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3715	PG0008	2017-07-30 11:45:00+03	2017-07-30 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-30 11:48:00+03	2017-07-30 13:59:00+03
3716	PG0007	2017-07-30 12:40:00+03	2017-07-30 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-30 12:43:00+03	2017-07-30 14:53:00+03
3717	PG0008	2017-08-07 11:45:00+03	2017-08-07 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-07 11:48:00+03	2017-08-07 13:59:00+03
3718	PG0007	2017-08-07 12:40:00+03	2017-08-07 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-07 12:46:00+03	2017-08-07 14:55:00+03
3719	PG0008	2017-09-12 11:45:00+03	2017-09-12 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3720	PG0008	2017-08-03 11:45:00+03	2017-08-03 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-03 11:50:00+03	2017-08-03 14:00:00+03
3721	PG0007	2017-09-12 12:40:00+03	2017-09-12 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3722	PG0007	2017-08-03 12:40:00+03	2017-08-03 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-03 12:44:00+03	2017-08-03 14:54:00+03
3723	PG0008	2017-07-24 11:45:00+03	2017-07-24 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-24 11:48:00+03	2017-07-24 14:00:00+03
3724	PG0007	2017-08-18 12:40:00+03	2017-08-18 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3725	PG0007	2017-07-24 12:40:00+03	2017-07-24 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-24 12:40:00+03	2017-07-24 14:51:00+03
3726	PG0008	2017-08-18 11:45:00+03	2017-08-18 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3727	PG0008	2017-07-16 11:45:00+03	2017-07-16 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-16 11:47:00+03	2017-07-16 13:57:00+03
3728	PG0007	2017-07-17 12:40:00+03	2017-07-17 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-17 16:02:00+03	2017-07-17 18:10:00+03
3729	PG0008	2017-07-17 11:45:00+03	2017-07-17 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-17 11:49:00+03	2017-07-17 13:58:00+03
3730	PG0007	2017-08-08 12:40:00+03	2017-08-08 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-08 16:31:00+03	2017-08-08 18:41:00+03
3731	PG0007	2017-09-08 12:40:00+03	2017-09-08 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3732	PG0008	2017-08-08 11:45:00+03	2017-08-08 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-08 11:46:00+03	2017-08-08 13:56:00+03
3733	PG0007	2017-07-27 12:40:00+03	2017-07-27 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-27 12:41:00+03	2017-07-27 14:49:00+03
3734	PG0008	2017-07-27 11:45:00+03	2017-07-27 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-27 11:47:00+03	2017-07-27 13:57:00+03
3735	PG0007	2017-07-22 12:40:00+03	2017-07-22 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-22 12:45:00+03	2017-07-22 14:55:00+03
3736	PG0008	2017-09-08 11:45:00+03	2017-09-08 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3737	PG0007	2017-09-11 12:40:00+03	2017-09-11 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3738	PG0008	2017-09-11 11:45:00+03	2017-09-11 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3739	PG0008	2017-08-30 11:45:00+03	2017-08-30 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3740	PG0007	2017-08-30 12:40:00+03	2017-08-30 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3741	PG0007	2017-08-21 12:40:00+03	2017-08-21 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3742	PG0008	2017-07-19 11:45:00+03	2017-07-19 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-19 11:48:00+03	2017-07-19 13:58:00+03
3743	PG0008	2017-08-21 11:45:00+03	2017-08-21 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3744	PG0007	2017-07-19 12:40:00+03	2017-07-19 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-19 12:44:00+03	2017-07-19 14:55:00+03
3745	PG0007	2017-09-04 12:40:00+03	2017-09-04 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3746	PG0007	2017-07-31 12:40:00+03	2017-07-31 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-31 12:44:00+03	2017-07-31 14:55:00+03
3747	PG0008	2017-07-31 11:45:00+03	2017-07-31 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-31 11:48:00+03	2017-07-31 13:57:00+03
3748	PG0008	2017-09-04 11:45:00+03	2017-09-04 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3749	PG0007	2017-08-22 12:40:00+03	2017-08-22 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3750	PG0008	2017-08-31 11:45:00+03	2017-08-31 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3751	PG0008	2017-08-22 11:45:00+03	2017-08-22 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3752	PG0007	2017-07-20 12:40:00+03	2017-07-20 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-20 12:44:00+03	2017-07-20 14:54:00+03
3753	PG0008	2017-07-20 11:45:00+03	2017-07-20 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-20 11:46:00+03	2017-07-20 13:54:00+03
3754	PG0007	2017-08-31 12:40:00+03	2017-08-31 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3755	PG0008	2017-08-29 11:45:00+03	2017-08-29 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3756	PG0008	2017-07-26 11:45:00+03	2017-07-26 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-26 11:48:00+03	2017-07-26 13:57:00+03
3757	PG0007	2017-07-26 12:40:00+03	2017-07-26 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-26 12:44:00+03	2017-07-26 14:51:00+03
3758	PG0007	2017-08-29 12:40:00+03	2017-08-29 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3759	PG0007	2017-08-04 12:40:00+03	2017-08-04 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-04 12:41:00+03	2017-08-04 14:51:00+03
3760	PG0008	2017-08-04 11:45:00+03	2017-08-04 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-04 11:47:00+03	2017-08-04 13:56:00+03
3761	PG0007	2017-08-24 12:40:00+03	2017-08-24 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3762	PG0008	2017-08-24 11:45:00+03	2017-08-24 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3763	PG0008	2017-08-02 11:45:00+03	2017-08-02 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-02 11:47:00+03	2017-08-02 13:56:00+03
3764	PG0007	2017-08-02 12:40:00+03	2017-08-02 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-02 12:45:00+03	2017-08-02 14:54:00+03
3765	PG0008	2017-08-11 11:45:00+03	2017-08-11 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-11 11:48:00+03	2017-08-11 13:59:00+03
3766	PG0007	2017-08-11 12:40:00+03	2017-08-11 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-11 12:44:00+03	2017-08-11 14:54:00+03
3767	PG0008	2017-09-13 11:45:00+03	2017-09-13 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3768	PG0007	2017-09-10 12:40:00+03	2017-09-10 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3769	PG0008	2017-09-10 11:45:00+03	2017-09-10 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3770	PG0007	2017-09-13 12:40:00+03	2017-09-13 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3771	PG0007	2017-09-06 12:40:00+03	2017-09-06 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3772	PG0008	2017-08-19 11:45:00+03	2017-08-19 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3773	PG0007	2017-08-19 12:40:00+03	2017-08-19 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3774	PG0007	2017-08-23 12:40:00+03	2017-08-23 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3775	PG0008	2017-08-23 11:45:00+03	2017-08-23 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3776	PG0008	2017-09-03 11:45:00+03	2017-09-03 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3777	PG0007	2017-09-03 12:40:00+03	2017-09-03 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3778	PG0008	2017-08-26 11:45:00+03	2017-08-26 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3779	PG0008	2017-08-14 11:45:00+03	2017-08-14 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-14 11:46:00+03	2017-08-14 13:57:00+03
3780	PG0008	2017-08-27 11:45:00+03	2017-08-27 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3781	PG0007	2017-08-14 12:40:00+03	2017-08-14 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-14 12:42:00+03	2017-08-14 14:53:00+03
3782	PG0008	2017-08-06 11:45:00+03	2017-08-06 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-06 14:57:00+03	2017-08-06 17:06:00+03
3783	PG0007	2017-08-26 12:40:00+03	2017-08-26 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3784	PG0007	2017-08-06 12:40:00+03	2017-08-06 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-06 16:13:00+03	2017-08-06 18:25:00+03
3785	PG0008	2017-07-22 11:45:00+03	2017-07-22 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-22 11:46:00+03	2017-07-22 13:55:00+03
3786	PG0007	2017-09-02 12:40:00+03	2017-09-02 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3787	PG0008	2017-09-02 11:45:00+03	2017-09-02 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3788	PG0007	2017-08-27 12:40:00+03	2017-08-27 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3789	PG0008	2017-09-09 11:45:00+03	2017-09-09 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3790	PG0007	2017-09-09 12:40:00+03	2017-09-09 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3791	PG0007	2017-08-16 12:40:00+03	2017-08-16 14:50:00+03	VKO	JOK	On Time	CN1	\N	\N
3792	PG0007	2017-08-13 12:40:00+03	2017-08-13 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-13 12:45:00+03	2017-08-13 14:55:00+03
3793	PG0008	2017-08-13 11:45:00+03	2017-08-13 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-13 11:51:00+03	2017-08-13 14:02:00+03
3794	PG0007	2017-08-12 12:40:00+03	2017-08-12 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-12 12:41:00+03	2017-08-12 14:53:00+03
3795	PG0008	2017-08-25 11:45:00+03	2017-08-25 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3796	PG0007	2017-07-25 12:40:00+03	2017-07-25 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-25 12:42:00+03	2017-07-25 14:53:00+03
3797	PG0008	2017-07-25 11:45:00+03	2017-07-25 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-25 11:49:00+03	2017-07-25 14:01:00+03
3798	PG0007	2017-08-25 12:40:00+03	2017-08-25 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3799	PG0007	2017-08-09 12:40:00+03	2017-08-09 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-09 12:41:00+03	2017-08-09 14:52:00+03
3800	PG0008	2017-08-09 11:45:00+03	2017-08-09 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-09 11:47:00+03	2017-08-09 13:56:00+03
3801	PG0008	2017-07-29 11:45:00+03	2017-07-29 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-29 11:49:00+03	2017-07-29 14:01:00+03
3802	PG0008	2017-09-05 11:45:00+03	2017-09-05 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3803	PG0007	2017-09-05 12:40:00+03	2017-09-05 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3804	PG0008	2017-08-16 11:45:00+03	2017-08-16 13:55:00+03	VKO	JOK	On Time	CN1	\N	\N
3805	PG0007	2017-07-29 12:40:00+03	2017-07-29 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-29 12:43:00+03	2017-07-29 14:51:00+03
3806	PG0007	2017-07-28 12:40:00+03	2017-07-28 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-28 12:41:00+03	2017-07-28 14:51:00+03
3807	PG0008	2017-07-28 11:45:00+03	2017-07-28 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-28 11:48:00+03	2017-07-28 13:56:00+03
3808	PG0008	2017-07-21 11:45:00+03	2017-07-21 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-21 11:49:00+03	2017-07-21 13:58:00+03
3809	PG0007	2017-07-21 12:40:00+03	2017-07-21 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-21 15:53:00+03	2017-07-21 18:02:00+03
3810	PG0007	2017-09-14 12:40:00+03	2017-09-14 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3811	PG0008	2017-09-07 11:45:00+03	2017-09-07 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3812	PG0007	2017-07-23 12:40:00+03	2017-07-23 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-23 12:43:00+03	2017-07-23 14:53:00+03
3813	PG0008	2017-07-23 11:45:00+03	2017-07-23 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-23 11:48:00+03	2017-07-23 13:58:00+03
3814	PG0007	2017-09-07 12:40:00+03	2017-09-07 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3815	PG0007	2017-08-20 12:40:00+03	2017-08-20 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3816	PG0008	2017-08-10 11:45:00+03	2017-08-10 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-10 11:48:00+03	2017-08-10 13:57:00+03
3817	PG0007	2017-08-10 12:40:00+03	2017-08-10 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-10 12:43:00+03	2017-08-10 14:56:00+03
3818	PG0008	2017-08-20 11:45:00+03	2017-08-20 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3819	PG0007	2017-09-01 12:40:00+03	2017-09-01 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3820	PG0008	2017-08-17 11:45:00+03	2017-08-17 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3821	PG0008	2017-09-01 11:45:00+03	2017-09-01 13:55:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3822	PG0007	2017-08-17 12:40:00+03	2017-08-17 14:50:00+03	VKO	JOK	Scheduled	CN1	\N	\N
3823	PG0007	2017-08-05 12:40:00+03	2017-08-05 14:50:00+03	VKO	JOK	Arrived	CN1	2017-08-05 12:44:00+03	2017-08-05 14:53:00+03
3824	PG0008	2017-09-14 11:45:00+03	2017-09-14 13:55:00+03	VKO	JOK	Cancelled	CN1	\N	\N
3825	PG0008	2017-08-05 11:45:00+03	2017-08-05 13:55:00+03	VKO	JOK	Arrived	CN1	2017-08-05 11:48:00+03	2017-08-05 13:59:00+03
3826	PG0007	2017-07-18 12:40:00+03	2017-07-18 14:50:00+03	VKO	JOK	Arrived	CN1	2017-07-18 12:40:00+03	2017-07-18 14:48:00+03
3827	PG0008	2017-07-18 11:45:00+03	2017-07-18 13:55:00+03	VKO	JOK	Arrived	CN1	2017-07-18 11:47:00+03	2017-07-18 13:58:00+03
3828	PG0025	2017-07-30 13:30:00+03	2017-07-30 15:40:00+03	VKO	OSW	Arrived	CR2	2017-07-30 13:33:00+03	2017-07-30 15:44:00+03
3829	PG0025	2017-07-16 13:30:00+03	2017-07-16 15:40:00+03	VKO	OSW	Arrived	CR2	2017-07-16 13:36:00+03	2017-07-16 15:47:00+03
3830	PG0025	2017-08-06 13:30:00+03	2017-08-06 15:40:00+03	VKO	OSW	Arrived	CR2	2017-08-06 16:44:00+03	2017-08-06 18:51:00+03
3831	PG0025	2017-08-20 13:30:00+03	2017-08-20 15:40:00+03	VKO	OSW	Scheduled	CR2	\N	\N
3832	PG0025	2017-08-13 13:30:00+03	2017-08-13 15:40:00+03	VKO	OSW	Arrived	CR2	2017-08-13 13:31:00+03	2017-08-13 15:40:00+03
3833	PG0025	2017-09-03 13:30:00+03	2017-09-03 15:40:00+03	VKO	OSW	Scheduled	CR2	\N	\N
3834	PG0025	2017-09-10 13:30:00+03	2017-09-10 15:40:00+03	VKO	OSW	Cancelled	CR2	\N	\N
3835	PG0025	2017-08-27 13:30:00+03	2017-08-27 15:40:00+03	VKO	OSW	Scheduled	CR2	\N	\N
3836	PG0025	2017-07-23 13:30:00+03	2017-07-23 15:40:00+03	VKO	OSW	Arrived	CR2	2017-07-23 13:36:00+03	2017-07-23 15:44:00+03
3837	PG0269	2017-07-18 09:25:00+03	2017-07-18 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-18 09:28:00+03	2017-07-18 12:42:00+03
3838	PG0269	2017-08-03 09:25:00+03	2017-08-03 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-03 09:29:00+03	2017-08-03 12:38:00+03
3839	PG0269	2017-08-15 09:25:00+03	2017-08-15 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-15 09:31:00+03	2017-08-15 12:45:00+03
3840	PG0269	2017-07-29 09:25:00+03	2017-07-29 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-29 09:29:00+03	2017-07-29 12:48:00+03
3841	PG0269	2017-09-12 09:25:00+03	2017-09-12 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3842	PG0269	2017-08-08 09:25:00+03	2017-08-08 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-08 09:30:00+03	2017-08-08 12:46:00+03
3843	PG0269	2017-07-27 09:25:00+03	2017-07-27 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-27 09:28:00+03	2017-07-27 12:41:00+03
3844	PG0269	2017-07-20 09:25:00+03	2017-07-20 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-20 09:28:00+03	2017-07-20 12:41:00+03
3845	PG0269	2017-08-12 09:25:00+03	2017-08-12 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-12 09:26:00+03	2017-08-12 12:41:00+03
3846	PG0269	2017-08-01 09:25:00+03	2017-08-01 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-01 09:28:00+03	2017-08-01 12:44:00+03
3847	PG0269	2017-08-19 09:25:00+03	2017-08-19 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3848	PG0269	2017-09-09 09:25:00+03	2017-09-09 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3849	PG0269	2017-07-22 09:25:00+03	2017-07-22 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-22 09:26:00+03	2017-07-22 12:40:00+03
3850	PG0269	2017-08-22 09:25:00+03	2017-08-22 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3851	PG0269	2017-08-26 09:25:00+03	2017-08-26 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3852	PG0269	2017-08-10 09:25:00+03	2017-08-10 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-10 09:26:00+03	2017-08-10 12:41:00+03
3853	PG0269	2017-08-17 09:25:00+03	2017-08-17 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3854	PG0269	2017-08-29 09:25:00+03	2017-08-29 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3855	PG0269	2017-08-24 09:25:00+03	2017-08-24 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3856	PG0269	2017-08-31 09:25:00+03	2017-08-31 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3857	PG0269	2017-09-05 09:25:00+03	2017-09-05 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3858	PG0269	2017-09-02 09:25:00+03	2017-09-02 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3859	PG0269	2017-08-05 09:25:00+03	2017-08-05 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-08-05 09:30:00+03	2017-08-05 12:48:00+03
3860	PG0269	2017-07-25 09:25:00+03	2017-07-25 12:40:00+03	VKO	NOJ	Arrived	CR2	2017-07-25 09:29:00+03	2017-07-25 12:46:00+03
3861	PG0269	2017-09-07 09:25:00+03	2017-09-07 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3862	PG0269	2017-09-14 09:25:00+03	2017-09-14 12:40:00+03	VKO	NOJ	Scheduled	CR2	\N	\N
3863	PG0450	2017-08-22 18:35:00+03	2017-08-23 02:50:00+03	VKO	DYR	Scheduled	319	\N	\N
3864	PG0450	2017-09-05 18:35:00+03	2017-09-06 02:50:00+03	VKO	DYR	Scheduled	319	\N	\N
3865	PG0450	2017-08-15 18:35:00+03	2017-08-16 02:50:00+03	VKO	DYR	On Time	319	\N	\N
3866	PG0450	2017-09-12 18:35:00+03	2017-09-13 02:50:00+03	VKO	DYR	Scheduled	319	\N	\N
3867	PG0450	2017-08-08 18:35:00+03	2017-08-09 02:50:00+03	VKO	DYR	Arrived	319	2017-08-08 18:38:00+03	2017-08-09 02:53:00+03
3868	PG0450	2017-08-29 18:35:00+03	2017-08-30 02:50:00+03	VKO	DYR	Scheduled	319	\N	\N
3869	PG0450	2017-07-18 18:35:00+03	2017-07-19 02:50:00+03	VKO	DYR	Arrived	319	2017-07-18 22:09:00+03	2017-07-19 06:31:00+03
3870	PG0450	2017-08-01 18:35:00+03	2017-08-02 02:50:00+03	VKO	DYR	Arrived	319	2017-08-01 22:07:00+03	2017-08-02 06:15:00+03
3871	PG0450	2017-07-25 18:35:00+03	2017-07-26 02:50:00+03	VKO	DYR	Arrived	319	2017-07-25 18:41:00+03	2017-07-26 02:50:00+03
3872	PG0126	2017-07-31 10:55:00+03	2017-07-31 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-31 10:58:00+03	2017-07-31 13:49:00+03
3873	PG0126	2017-08-30 10:55:00+03	2017-08-30 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3874	PG0126	2017-09-12 10:55:00+03	2017-09-12 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3875	PG0126	2017-07-22 10:55:00+03	2017-07-22 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-22 10:58:00+03	2017-07-22 13:50:00+03
3876	PG0126	2017-09-06 10:55:00+03	2017-09-06 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3877	PG0126	2017-07-26 10:55:00+03	2017-07-26 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-26 10:59:00+03	2017-07-26 13:48:00+03
3878	PG0126	2017-08-29 10:55:00+03	2017-08-29 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3879	PG0126	2017-07-17 10:55:00+03	2017-07-17 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-17 10:56:00+03	2017-07-17 13:49:00+03
3880	PG0126	2017-07-27 10:55:00+03	2017-07-27 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-27 10:56:00+03	2017-07-27 13:47:00+03
3881	PG0126	2017-08-18 10:55:00+03	2017-08-18 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3882	PG0126	2017-08-02 10:55:00+03	2017-08-02 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-02 10:58:00+03	2017-08-02 13:49:00+03
3883	PG0126	2017-08-11 10:55:00+03	2017-08-11 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-11 10:57:00+03	2017-08-11 13:46:00+03
3884	PG0126	2017-09-01 10:55:00+03	2017-09-01 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3885	PG0126	2017-08-04 10:55:00+03	2017-08-04 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-04 10:58:00+03	2017-08-04 13:47:00+03
3886	PG0126	2017-08-21 10:55:00+03	2017-08-21 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3887	PG0126	2017-09-09 10:55:00+03	2017-09-09 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3888	PG0126	2017-09-05 10:55:00+03	2017-09-05 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3889	PG0126	2017-08-25 10:55:00+03	2017-08-25 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3890	PG0126	2017-09-10 10:55:00+03	2017-09-10 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3891	PG0126	2017-07-21 10:55:00+03	2017-07-21 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-21 10:57:00+03	2017-07-21 13:47:00+03
3892	PG0126	2017-08-17 10:55:00+03	2017-08-17 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3893	PG0126	2017-08-23 10:55:00+03	2017-08-23 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3894	PG0126	2017-09-02 10:55:00+03	2017-09-02 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3895	PG0126	2017-08-10 10:55:00+03	2017-08-10 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-10 10:56:00+03	2017-08-10 13:45:00+03
3896	PG0126	2017-07-28 10:55:00+03	2017-07-28 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-28 10:57:00+03	2017-07-28 13:47:00+03
3897	PG0126	2017-08-01 10:55:00+03	2017-08-01 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-01 10:58:00+03	2017-08-01 13:48:00+03
3898	PG0126	2017-07-23 10:55:00+03	2017-07-23 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-23 10:58:00+03	2017-07-23 13:46:00+03
3899	PG0126	2017-08-20 10:55:00+03	2017-08-20 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3900	PG0126	2017-08-05 10:55:00+03	2017-08-05 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-05 10:59:00+03	2017-08-05 13:49:00+03
3901	PG0126	2017-07-18 10:55:00+03	2017-07-18 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-18 11:00:00+03	2017-07-18 13:51:00+03
3902	PG0126	2017-09-14 10:55:00+03	2017-09-14 13:45:00+03	VKO	SLY	Cancelled	CR2	\N	\N
3903	PG0126	2017-08-31 10:55:00+03	2017-08-31 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3904	PG0126	2017-08-15 10:55:00+03	2017-08-15 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-15 10:58:00+03	2017-08-15 13:49:00+03
3905	PG0126	2017-07-25 10:55:00+03	2017-07-25 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-25 10:56:00+03	2017-07-25 13:48:00+03
3906	PG0126	2017-08-03 10:55:00+03	2017-08-03 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-03 10:57:00+03	2017-08-03 13:44:00+03
3907	PG0126	2017-08-09 10:55:00+03	2017-08-09 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-09 10:57:00+03	2017-08-09 13:48:00+03
3908	PG0126	2017-08-28 10:55:00+03	2017-08-28 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3909	PG0126	2017-08-24 10:55:00+03	2017-08-24 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3910	PG0126	2017-08-12 10:55:00+03	2017-08-12 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-12 10:56:00+03	2017-08-12 13:45:00+03
3911	PG0126	2017-07-29 10:55:00+03	2017-07-29 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-29 10:56:00+03	2017-07-29 13:43:00+03
3912	PG0126	2017-09-07 10:55:00+03	2017-09-07 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3913	PG0126	2017-08-22 10:55:00+03	2017-08-22 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3914	PG0126	2017-08-14 10:55:00+03	2017-08-14 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-14 10:58:00+03	2017-08-14 13:49:00+03
3915	PG0126	2017-08-06 10:55:00+03	2017-08-06 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-06 10:56:00+03	2017-08-06 13:42:00+03
3916	PG0126	2017-09-11 10:55:00+03	2017-09-11 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3917	PG0126	2017-09-04 10:55:00+03	2017-09-04 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3918	PG0126	2017-07-20 10:55:00+03	2017-07-20 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-20 11:02:00+03	2017-07-20 13:49:00+03
3919	PG0126	2017-09-08 10:55:00+03	2017-09-08 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3920	PG0126	2017-09-03 10:55:00+03	2017-09-03 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3921	PG0126	2017-08-13 10:55:00+03	2017-08-13 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-13 10:58:00+03	2017-08-13 13:46:00+03
3922	PG0126	2017-09-13 10:55:00+03	2017-09-13 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3923	PG0126	2017-08-19 10:55:00+03	2017-08-19 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3924	PG0126	2017-08-08 10:55:00+03	2017-08-08 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-08 10:57:00+03	2017-08-08 13:47:00+03
3925	PG0126	2017-07-16 10:55:00+03	2017-07-16 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-16 10:57:00+03	2017-07-16 13:49:00+03
3926	PG0126	2017-07-19 10:55:00+03	2017-07-19 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-19 10:59:00+03	2017-07-19 13:47:00+03
3927	PG0126	2017-08-27 10:55:00+03	2017-08-27 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3928	PG0126	2017-08-26 10:55:00+03	2017-08-26 13:45:00+03	VKO	SLY	Scheduled	CR2	\N	\N
3929	PG0126	2017-08-16 10:55:00+03	2017-08-16 13:45:00+03	VKO	SLY	On Time	CR2	\N	\N
3930	PG0126	2017-08-07 10:55:00+03	2017-08-07 13:45:00+03	VKO	SLY	Arrived	CR2	2017-08-07 10:58:00+03	2017-08-07 13:48:00+03
3931	PG0126	2017-07-24 10:55:00+03	2017-07-24 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-24 10:56:00+03	2017-07-24 13:45:00+03
3932	PG0126	2017-07-30 10:55:00+03	2017-07-30 13:45:00+03	VKO	SLY	Arrived	CR2	2017-07-30 11:00:00+03	2017-07-30 13:48:00+03
3933	PG0052	2017-09-04 14:50:00+03	2017-09-04 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3934	PG0052	2017-08-01 14:50:00+03	2017-08-01 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-01 14:52:00+03	2017-08-01 17:36:00+03
3935	PG0052	2017-08-17 14:50:00+03	2017-08-17 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3936	PG0052	2017-08-26 14:50:00+03	2017-08-26 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3937	PG0052	2017-08-05 14:50:00+03	2017-08-05 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-05 14:52:00+03	2017-08-05 17:34:00+03
3938	PG0052	2017-09-06 14:50:00+03	2017-09-06 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3939	PG0052	2017-08-10 14:50:00+03	2017-08-10 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-10 14:58:00+03	2017-08-10 17:45:00+03
3940	PG0052	2017-08-20 14:50:00+03	2017-08-20 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3941	PG0052	2017-07-27 14:50:00+03	2017-07-27 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-27 14:52:00+03	2017-07-27 17:36:00+03
3942	PG0052	2017-07-30 14:50:00+03	2017-07-30 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-30 14:53:00+03	2017-07-30 17:34:00+03
3943	PG0052	2017-08-19 14:50:00+03	2017-08-19 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3944	PG0052	2017-09-03 14:50:00+03	2017-09-03 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3945	PG0052	2017-09-14 14:50:00+03	2017-09-14 17:35:00+03	VKO	HMA	Cancelled	CR2	\N	\N
3946	PG0052	2017-08-18 14:50:00+03	2017-08-18 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3947	PG0052	2017-07-22 14:50:00+03	2017-07-22 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-22 18:12:00+03	2017-07-22 20:58:00+03
3948	PG0052	2017-07-18 14:50:00+03	2017-07-18 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-18 14:51:00+03	2017-07-18 17:37:00+03
3949	PG0052	2017-08-15 14:50:00+03	2017-08-15 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-15 14:53:00+03	2017-08-15 17:39:00+03
3950	PG0052	2017-07-20 14:50:00+03	2017-07-20 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-20 14:54:00+03	2017-07-20 17:39:00+03
3951	PG0052	2017-08-31 14:50:00+03	2017-08-31 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3952	PG0052	2017-08-11 14:50:00+03	2017-08-11 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-11 14:52:00+03	2017-08-11 17:37:00+03
3953	PG0052	2017-09-10 14:50:00+03	2017-09-10 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3954	PG0052	2017-07-28 14:50:00+03	2017-07-28 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-28 14:54:00+03	2017-07-28 17:40:00+03
3955	PG0052	2017-08-29 14:50:00+03	2017-08-29 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3956	PG0052	2017-08-22 14:50:00+03	2017-08-22 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3957	PG0052	2017-07-17 14:50:00+03	2017-07-17 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-17 14:54:00+03	2017-07-17 17:38:00+03
3958	PG0052	2017-09-01 14:50:00+03	2017-09-01 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3959	PG0052	2017-08-08 14:50:00+03	2017-08-08 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-08 14:53:00+03	2017-08-08 17:39:00+03
3960	PG0052	2017-08-13 14:50:00+03	2017-08-13 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-13 14:52:00+03	2017-08-13 17:41:00+03
3961	PG0052	2017-07-21 14:50:00+03	2017-07-21 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-21 14:53:00+03	2017-07-21 17:39:00+03
3962	PG0052	2017-08-14 14:50:00+03	2017-08-14 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-14 14:50:00+03	2017-08-14 17:34:00+03
3963	PG0052	2017-07-25 14:50:00+03	2017-07-25 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-25 14:53:00+03	2017-07-25 17:38:00+03
3964	PG0052	2017-09-09 14:50:00+03	2017-09-09 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3965	PG0052	2017-08-06 14:50:00+03	2017-08-06 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-06 14:54:00+03	2017-08-06 17:39:00+03
3966	PG0052	2017-09-07 14:50:00+03	2017-09-07 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3967	PG0052	2017-08-04 14:50:00+03	2017-08-04 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-04 14:53:00+03	2017-08-04 17:38:00+03
3968	PG0052	2017-09-12 14:50:00+03	2017-09-12 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3969	PG0052	2017-07-26 14:50:00+03	2017-07-26 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-26 14:53:00+03	2017-07-26 17:38:00+03
3970	PG0052	2017-08-16 14:50:00+03	2017-08-16 17:35:00+03	VKO	HMA	Delayed	CR2	\N	\N
3971	PG0052	2017-08-09 14:50:00+03	2017-08-09 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-09 14:54:00+03	2017-08-09 17:39:00+03
3972	PG0052	2017-08-03 14:50:00+03	2017-08-03 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-03 14:54:00+03	2017-08-03 17:37:00+03
3973	PG0052	2017-08-24 14:50:00+03	2017-08-24 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3974	PG0052	2017-09-11 14:50:00+03	2017-09-11 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3975	PG0052	2017-07-24 14:50:00+03	2017-07-24 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-24 14:51:00+03	2017-07-24 17:34:00+03
3976	PG0052	2017-09-02 14:50:00+03	2017-09-02 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3977	PG0052	2017-09-08 14:50:00+03	2017-09-08 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3978	PG0052	2017-08-07 14:50:00+03	2017-08-07 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-07 14:54:00+03	2017-08-07 17:38:00+03
3980	PG0052	2017-07-19 14:50:00+03	2017-07-19 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-19 14:50:00+03	2017-07-19 17:35:00+03
3981	PG0052	2017-08-23 14:50:00+03	2017-08-23 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3982	PG0052	2017-07-23 14:50:00+03	2017-07-23 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-23 14:51:00+03	2017-07-23 17:34:00+03
3983	PG0052	2017-08-27 14:50:00+03	2017-08-27 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3984	PG0052	2017-08-12 14:50:00+03	2017-08-12 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-12 14:53:00+03	2017-08-12 17:38:00+03
3985	PG0052	2017-08-28 14:50:00+03	2017-08-28 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3986	PG0052	2017-07-31 14:50:00+03	2017-07-31 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-31 14:55:00+03	2017-07-31 17:40:00+03
3987	PG0052	2017-08-30 14:50:00+03	2017-08-30 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3988	PG0052	2017-09-13 14:50:00+03	2017-09-13 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3989	PG0052	2017-07-29 14:50:00+03	2017-07-29 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-29 18:24:00+03	2017-07-29 21:09:00+03
3990	PG0052	2017-08-02 14:50:00+03	2017-08-02 17:35:00+03	VKO	HMA	Arrived	CR2	2017-08-02 14:52:00+03	2017-08-02 17:34:00+03
3991	PG0052	2017-09-05 14:50:00+03	2017-09-05 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3992	PG0052	2017-08-21 14:50:00+03	2017-08-21 17:35:00+03	VKO	HMA	Scheduled	CR2	\N	\N
3993	PG0052	2017-07-16 14:50:00+03	2017-07-16 17:35:00+03	VKO	HMA	Arrived	CR2	2017-07-16 14:52:00+03	2017-07-16 17:36:00+03
3994	PG0099	2017-08-07 13:45:00+03	2017-08-07 16:15:00+03	VKO	NYA	Arrived	CR2	2017-08-07 13:47:00+03	2017-08-07 16:19:00+03
3995	PG0099	2017-08-14 13:45:00+03	2017-08-14 16:15:00+03	VKO	NYA	Arrived	CR2	2017-08-14 13:46:00+03	2017-08-14 16:14:00+03
3996	PG0099	2017-08-28 13:45:00+03	2017-08-28 16:15:00+03	VKO	NYA	Scheduled	CR2	\N	\N
3997	PG0099	2017-07-24 13:45:00+03	2017-07-24 16:15:00+03	VKO	NYA	Arrived	CR2	2017-07-24 13:48:00+03	2017-07-24 16:19:00+03
3998	PG0099	2017-09-04 13:45:00+03	2017-09-04 16:15:00+03	VKO	NYA	Scheduled	CR2	\N	\N
3999	PG0099	2017-08-21 13:45:00+03	2017-08-21 16:15:00+03	VKO	NYA	Scheduled	CR2	\N	\N
4000	PG0099	2017-07-31 13:45:00+03	2017-07-31 16:15:00+03	VKO	NYA	Arrived	CR2	2017-07-31 13:48:00+03	2017-07-31 16:17:00+03
4001	PG0099	2017-07-17 13:45:00+03	2017-07-17 16:15:00+03	VKO	NYA	Arrived	CR2	2017-07-17 13:47:00+03	2017-07-17 16:16:00+03
4002	PG0099	2017-09-11 13:45:00+03	2017-09-11 16:15:00+03	VKO	NYA	Cancelled	CR2	\N	\N
4003	PG0442	2017-08-20 15:45:00+03	2017-08-20 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4004	PG0442	2017-08-23 15:45:00+03	2017-08-23 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4005	PG0442	2017-09-03 15:45:00+03	2017-09-03 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4006	PG0442	2017-08-13 15:45:00+03	2017-08-13 18:45:00+03	VKO	NFG	Arrived	CR2	2017-08-13 15:50:00+03	2017-08-13 18:48:00+03
4007	PG0442	2017-08-30 15:45:00+03	2017-08-30 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4008	PG0442	2017-07-23 15:45:00+03	2017-07-23 18:45:00+03	VKO	NFG	Arrived	CR2	2017-07-23 15:46:00+03	2017-07-23 18:47:00+03
4009	PG0442	2017-08-09 15:45:00+03	2017-08-09 18:45:00+03	VKO	NFG	Arrived	CR2	2017-08-09 15:46:00+03	2017-08-09 18:47:00+03
4010	PG0442	2017-07-19 15:45:00+03	2017-07-19 18:45:00+03	VKO	NFG	Arrived	CR2	2017-07-19 15:47:00+03	2017-07-19 18:46:00+03
4011	PG0442	2017-08-16 15:45:00+03	2017-08-16 18:45:00+03	VKO	NFG	On Time	CR2	\N	\N
4012	PG0442	2017-08-02 15:45:00+03	2017-08-02 18:45:00+03	VKO	NFG	Arrived	CR2	2017-08-02 15:47:00+03	2017-08-02 18:49:00+03
4013	PG0442	2017-07-26 15:45:00+03	2017-07-26 18:45:00+03	VKO	NFG	Arrived	CR2	2017-07-26 15:47:00+03	2017-07-26 18:46:00+03
4014	PG0442	2017-09-13 15:45:00+03	2017-09-13 18:45:00+03	VKO	NFG	Cancelled	CR2	\N	\N
4015	PG0442	2017-09-10 15:45:00+03	2017-09-10 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4016	PG0442	2017-07-16 15:45:00+03	2017-07-16 18:45:00+03	VKO	NFG	Arrived	CR2	2017-07-16 15:51:00+03	2017-07-16 18:52:00+03
4017	PG0442	2017-08-27 15:45:00+03	2017-08-27 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4018	PG0442	2017-09-06 15:45:00+03	2017-09-06 18:45:00+03	VKO	NFG	Scheduled	CR2	\N	\N
4019	PG0442	2017-07-30 15:45:00+03	2017-07-30 18:45:00+03	VKO	NFG	Arrived	CR2	2017-07-30 15:47:00+03	2017-07-30 18:47:00+03
4020	PG0442	2017-08-06 15:45:00+03	2017-08-06 18:45:00+03	VKO	NFG	Arrived	CR2	2017-08-06 15:47:00+03	2017-08-06 18:46:00+03
4021	PG0049	2017-07-16 13:05:00+03	2017-07-16 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-16 13:09:00+03	2017-07-16 14:53:00+03
4022	PG0049	2017-09-01 13:05:00+03	2017-09-01 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4023	PG0049	2017-09-08 13:05:00+03	2017-09-08 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4024	PG0049	2017-07-23 13:05:00+03	2017-07-23 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-23 13:08:00+03	2017-07-23 14:52:00+03
4025	PG0049	2017-08-01 13:05:00+03	2017-08-01 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-01 13:08:00+03	2017-08-01 14:54:00+03
4026	PG0049	2017-07-18 13:05:00+03	2017-07-18 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-18 13:09:00+03	2017-07-18 14:54:00+03
4027	PG0049	2017-08-15 13:05:00+03	2017-08-15 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-15 13:06:00+03	2017-08-15 14:48:00+03
4028	PG0049	2017-08-27 13:05:00+03	2017-08-27 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4029	PG0049	2017-08-22 13:05:00+03	2017-08-22 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4030	PG0049	2017-08-11 13:05:00+03	2017-08-11 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-11 13:07:00+03	2017-08-11 14:52:00+03
4031	PG0049	2017-07-28 13:05:00+03	2017-07-28 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-28 13:07:00+03	2017-07-28 14:53:00+03
4032	PG0049	2017-08-04 13:05:00+03	2017-08-04 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-04 13:11:00+03	2017-08-04 14:56:00+03
4033	PG0049	2017-07-30 13:05:00+03	2017-07-30 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-30 15:54:00+03	2017-07-30 17:39:00+03
4034	PG0049	2017-08-29 13:05:00+03	2017-08-29 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4035	PG0049	2017-08-20 13:05:00+03	2017-08-20 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4036	PG0049	2017-08-08 13:05:00+03	2017-08-08 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-08 13:08:00+03	2017-08-08 14:54:00+03
4037	PG0049	2017-08-25 13:05:00+03	2017-08-25 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4038	PG0049	2017-07-25 13:05:00+03	2017-07-25 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-25 13:07:00+03	2017-07-25 14:53:00+03
4039	PG0049	2017-07-21 13:05:00+03	2017-07-21 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-07-21 13:07:00+03	2017-07-21 14:51:00+03
4040	PG0049	2017-08-18 13:05:00+03	2017-08-18 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4041	PG0049	2017-08-13 13:05:00+03	2017-08-13 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-13 13:09:00+03	2017-08-13 14:55:00+03
4042	PG0049	2017-09-05 13:05:00+03	2017-09-05 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4043	PG0049	2017-09-03 13:05:00+03	2017-09-03 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4044	PG0049	2017-09-10 13:05:00+03	2017-09-10 14:50:00+03	VKO	GDZ	Scheduled	CR2	\N	\N
4045	PG0049	2017-08-06 13:05:00+03	2017-08-06 14:50:00+03	VKO	GDZ	Arrived	CR2	2017-08-06 13:12:00+03	2017-08-06 14:58:00+03
4046	PG0049	2017-09-12 13:05:00+03	2017-09-12 14:50:00+03	VKO	GDZ	Cancelled	CR2	\N	\N
4047	PG0138	2017-08-23 10:15:00+03	2017-08-23 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4048	PG0138	2017-08-15 10:15:00+03	2017-08-15 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-15 10:17:00+03	2017-08-15 11:22:00+03
4049	PG0138	2017-07-30 10:15:00+03	2017-07-30 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-30 10:16:00+03	2017-07-30 11:22:00+03
4050	PG0138	2017-09-02 10:15:00+03	2017-09-02 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4051	PG0138	2017-08-24 10:15:00+03	2017-08-24 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4052	PG0138	2017-08-14 10:15:00+03	2017-08-14 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-14 10:18:00+03	2017-08-14 11:24:00+03
4053	PG0138	2017-09-01 10:15:00+03	2017-09-01 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4054	PG0138	2017-09-06 10:15:00+03	2017-09-06 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4055	PG0138	2017-08-01 10:15:00+03	2017-08-01 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-01 13:27:00+03	2017-08-01 14:32:00+03
4056	PG0138	2017-09-08 10:15:00+03	2017-09-08 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4057	PG0138	2017-07-20 10:15:00+03	2017-07-20 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-20 10:19:00+03	2017-07-20 11:24:00+03
4058	PG0138	2017-08-05 10:15:00+03	2017-08-05 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-05 10:21:00+03	2017-08-05 11:26:00+03
4059	PG0138	2017-08-29 10:15:00+03	2017-08-29 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4060	PG0138	2017-07-23 10:15:00+03	2017-07-23 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-23 10:19:00+03	2017-07-23 11:24:00+03
4061	PG0138	2017-07-31 10:15:00+03	2017-07-31 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-31 10:19:00+03	2017-07-31 11:23:00+03
4062	PG0138	2017-08-22 10:15:00+03	2017-08-22 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4063	PG0138	2017-07-19 10:15:00+03	2017-07-19 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-19 10:20:00+03	2017-07-19 11:26:00+03
4064	PG0138	2017-07-25 10:15:00+03	2017-07-25 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-25 10:16:00+03	2017-07-25 11:20:00+03
4065	PG0138	2017-08-03 10:15:00+03	2017-08-03 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-03 10:19:00+03	2017-08-03 11:24:00+03
4066	PG0138	2017-08-18 10:15:00+03	2017-08-18 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4067	PG0138	2017-08-17 10:15:00+03	2017-08-17 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4068	PG0138	2017-08-27 10:15:00+03	2017-08-27 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4069	PG0138	2017-09-13 10:15:00+03	2017-09-13 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4070	PG0138	2017-09-03 10:15:00+03	2017-09-03 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4071	PG0138	2017-07-28 10:15:00+03	2017-07-28 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-28 10:19:00+03	2017-07-28 11:24:00+03
4072	PG0138	2017-07-24 10:15:00+03	2017-07-24 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-24 10:18:00+03	2017-07-24 11:23:00+03
4073	PG0138	2017-08-28 10:15:00+03	2017-08-28 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4074	PG0138	2017-08-11 10:15:00+03	2017-08-11 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-11 10:16:00+03	2017-08-11 11:21:00+03
4075	PG0138	2017-08-06 10:15:00+03	2017-08-06 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-06 10:20:00+03	2017-08-06 11:24:00+03
4076	PG0138	2017-08-25 10:15:00+03	2017-08-25 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4077	PG0138	2017-08-04 10:15:00+03	2017-08-04 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-04 10:18:00+03	2017-08-04 11:23:00+03
4078	PG0138	2017-07-21 10:15:00+03	2017-07-21 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-21 10:17:00+03	2017-07-21 11:22:00+03
4079	PG0138	2017-07-18 10:15:00+03	2017-07-18 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-18 10:17:00+03	2017-07-18 11:22:00+03
4080	PG0138	2017-09-09 10:15:00+03	2017-09-09 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4081	PG0138	2017-09-04 10:15:00+03	2017-09-04 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4082	PG0138	2017-08-30 10:15:00+03	2017-08-30 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4083	PG0138	2017-07-26 10:15:00+03	2017-07-26 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-26 10:19:00+03	2017-07-26 11:23:00+03
4084	PG0138	2017-09-14 10:15:00+03	2017-09-14 11:20:00+03	VKO	RTW	Cancelled	CR2	\N	\N
4085	PG0138	2017-08-08 10:15:00+03	2017-08-08 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-08 12:33:00+03	2017-08-08 13:37:00+03
4086	PG0138	2017-07-17 10:15:00+03	2017-07-17 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-17 10:16:00+03	2017-07-17 11:20:00+03
4087	PG0138	2017-08-26 10:15:00+03	2017-08-26 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4088	PG0138	2017-07-27 10:15:00+03	2017-07-27 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-27 10:17:00+03	2017-07-27 11:22:00+03
4089	PG0138	2017-08-12 10:15:00+03	2017-08-12 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-12 13:32:00+03	2017-08-12 14:36:00+03
4090	PG0138	2017-09-05 10:15:00+03	2017-09-05 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4091	PG0138	2017-09-12 10:15:00+03	2017-09-12 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4092	PG0138	2017-07-22 10:15:00+03	2017-07-22 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-22 10:18:00+03	2017-07-22 11:23:00+03
4093	PG0138	2017-08-16 10:15:00+03	2017-08-16 11:20:00+03	VKO	RTW	On Time	CR2	\N	\N
4094	PG0138	2017-08-07 10:15:00+03	2017-08-07 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-07 10:19:00+03	2017-08-07 11:24:00+03
4095	PG0138	2017-08-20 10:15:00+03	2017-08-20 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4096	PG0138	2017-08-02 10:15:00+03	2017-08-02 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-02 10:16:00+03	2017-08-02 11:21:00+03
4097	PG0138	2017-09-11 10:15:00+03	2017-09-11 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4098	PG0138	2017-07-29 10:15:00+03	2017-07-29 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-29 10:19:00+03	2017-07-29 11:25:00+03
4099	PG0138	2017-08-31 10:15:00+03	2017-08-31 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4100	PG0138	2017-09-10 10:15:00+03	2017-09-10 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4101	PG0138	2017-08-19 10:15:00+03	2017-08-19 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4102	PG0138	2017-09-07 10:15:00+03	2017-09-07 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4103	PG0138	2017-07-16 10:15:00+03	2017-07-16 11:20:00+03	VKO	RTW	Arrived	CR2	2017-07-16 10:17:00+03	2017-07-16 11:22:00+03
4104	PG0138	2017-08-09 10:15:00+03	2017-08-09 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-09 10:18:00+03	2017-08-09 11:22:00+03
4105	PG0138	2017-08-10 10:15:00+03	2017-08-10 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-10 10:18:00+03	2017-08-10 11:23:00+03
4106	PG0138	2017-08-21 10:15:00+03	2017-08-21 11:20:00+03	VKO	RTW	Scheduled	CR2	\N	\N
4107	PG0138	2017-08-13 10:15:00+03	2017-08-13 11:20:00+03	VKO	RTW	Arrived	CR2	2017-08-13 10:19:00+03	2017-08-13 11:23:00+03
4108	PG0539	2017-07-17 09:50:00+03	2017-07-17 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-17 09:54:00+03	2017-07-17 13:50:00+03
4109	PG0539	2017-09-09 09:50:00+03	2017-09-09 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4110	PG0539	2017-08-03 09:50:00+03	2017-08-03 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-03 09:53:00+03	2017-08-03 13:46:00+03
4111	PG0539	2017-09-11 09:50:00+03	2017-09-11 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4112	PG0539	2017-08-12 09:50:00+03	2017-08-12 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-12 09:56:00+03	2017-08-12 13:52:00+03
4113	PG0539	2017-08-28 09:50:00+03	2017-08-28 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4114	PG0539	2017-07-31 09:50:00+03	2017-07-31 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-31 09:51:00+03	2017-07-31 13:46:00+03
4115	PG0539	2017-07-20 09:50:00+03	2017-07-20 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-20 09:54:00+03	2017-07-20 13:48:00+03
4116	PG0539	2017-09-04 09:50:00+03	2017-09-04 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4117	PG0539	2017-08-14 09:50:00+03	2017-08-14 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-14 09:55:00+03	2017-08-14 13:50:00+03
4118	PG0539	2017-08-07 09:50:00+03	2017-08-07 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-07 09:52:00+03	2017-08-07 13:46:00+03
4119	PG0539	2017-08-05 09:50:00+03	2017-08-05 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-05 09:52:00+03	2017-08-05 13:45:00+03
4120	PG0539	2017-09-02 09:50:00+03	2017-09-02 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4121	PG0539	2017-08-26 09:50:00+03	2017-08-26 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4122	PG0539	2017-07-27 09:50:00+03	2017-07-27 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-27 09:57:00+03	2017-07-27 13:51:00+03
4123	PG0539	2017-09-14 09:50:00+03	2017-09-14 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4124	PG0539	2017-08-21 09:50:00+03	2017-08-21 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4125	PG0539	2017-07-22 09:50:00+03	2017-07-22 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-22 09:51:00+03	2017-07-22 13:47:00+03
4126	PG0539	2017-08-17 09:50:00+03	2017-08-17 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4127	PG0539	2017-08-10 09:50:00+03	2017-08-10 13:45:00+03	VKO	BAX	Arrived	SU9	2017-08-10 09:53:00+03	2017-08-10 13:46:00+03
4128	PG0539	2017-09-07 09:50:00+03	2017-09-07 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4129	PG0539	2017-08-19 09:50:00+03	2017-08-19 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4130	PG0539	2017-07-24 09:50:00+03	2017-07-24 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-24 09:54:00+03	2017-07-24 13:47:00+03
4131	PG0539	2017-07-29 09:50:00+03	2017-07-29 13:45:00+03	VKO	BAX	Arrived	SU9	2017-07-29 09:50:00+03	2017-07-29 13:50:00+03
4132	PG0539	2017-08-31 09:50:00+03	2017-08-31 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4133	PG0539	2017-08-24 09:50:00+03	2017-08-24 13:45:00+03	VKO	BAX	Scheduled	SU9	\N	\N
4134	PG0106	2017-07-22 18:55:00+03	2017-07-22 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-22 19:00:00+03	2017-07-22 19:56:00+03
4135	PG0106	2017-07-16 18:55:00+03	2017-07-16 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-16 18:56:00+03	2017-07-16 19:50:00+03
4136	PG0106	2017-08-25 18:55:00+03	2017-08-25 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4137	PG0106	2017-09-12 18:55:00+03	2017-09-12 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4138	PG0106	2017-08-13 18:55:00+03	2017-08-13 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-13 18:57:00+03	2017-08-13 19:51:00+03
4139	PG0106	2017-09-05 18:55:00+03	2017-09-05 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4140	PG0106	2017-08-24 18:55:00+03	2017-08-24 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4141	PG0106	2017-09-06 18:55:00+03	2017-09-06 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4142	PG0106	2017-08-16 18:55:00+03	2017-08-16 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4143	PG0106	2017-09-01 18:55:00+03	2017-09-01 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4144	PG0106	2017-07-29 18:55:00+03	2017-07-29 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-29 18:57:00+03	2017-07-29 19:52:00+03
4145	PG0106	2017-09-10 18:55:00+03	2017-09-10 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4146	PG0106	2017-08-06 18:55:00+03	2017-08-06 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-06 18:58:00+03	2017-08-06 19:52:00+03
4147	PG0106	2017-08-14 18:55:00+03	2017-08-14 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-14 19:01:00+03	2017-08-14 19:55:00+03
4148	PG0106	2017-07-30 18:55:00+03	2017-07-30 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-30 18:59:00+03	2017-07-30 19:54:00+03
4149	PG0106	2017-08-03 18:55:00+03	2017-08-03 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-03 19:00:00+03	2017-08-03 19:56:00+03
4150	PG0106	2017-09-07 18:55:00+03	2017-09-07 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4151	PG0106	2017-08-12 18:55:00+03	2017-08-12 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-12 18:59:00+03	2017-08-12 19:54:00+03
4152	PG0106	2017-08-31 18:55:00+03	2017-08-31 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4153	PG0106	2017-08-18 18:55:00+03	2017-08-18 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4154	PG0106	2017-07-21 18:55:00+03	2017-07-21 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-21 18:57:00+03	2017-07-21 19:52:00+03
4155	PG0106	2017-08-08 18:55:00+03	2017-08-08 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-08 18:58:00+03	2017-08-08 19:54:00+03
4156	PG0106	2017-08-23 18:55:00+03	2017-08-23 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4157	PG0106	2017-08-04 18:55:00+03	2017-08-04 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-04 18:59:00+03	2017-08-04 19:54:00+03
4158	PG0106	2017-08-17 18:55:00+03	2017-08-17 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4159	PG0106	2017-07-19 18:55:00+03	2017-07-19 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-19 18:57:00+03	2017-07-19 19:52:00+03
4160	PG0106	2017-08-01 18:55:00+03	2017-08-01 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-01 19:01:00+03	2017-08-01 19:56:00+03
4161	PG0106	2017-07-20 18:55:00+03	2017-07-20 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-20 18:57:00+03	2017-07-20 19:51:00+03
4162	PG0106	2017-08-21 18:55:00+03	2017-08-21 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4163	PG0106	2017-09-04 18:55:00+03	2017-09-04 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4164	PG0106	2017-07-31 18:55:00+03	2017-07-31 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-31 18:58:00+03	2017-07-31 19:54:00+03
4165	PG0106	2017-08-26 18:55:00+03	2017-08-26 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4166	PG0106	2017-08-09 18:55:00+03	2017-08-09 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-09 18:59:00+03	2017-08-09 19:54:00+03
4167	PG0106	2017-09-02 18:55:00+03	2017-09-02 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4168	PG0106	2017-07-24 18:55:00+03	2017-07-24 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-24 18:57:00+03	2017-07-24 19:52:00+03
4169	PG0106	2017-09-11 18:55:00+03	2017-09-11 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4170	PG0106	2017-08-28 18:55:00+03	2017-08-28 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4171	PG0106	2017-08-07 18:55:00+03	2017-08-07 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-07 19:03:00+03	2017-08-07 19:58:00+03
4172	PG0106	2017-07-18 18:55:00+03	2017-07-18 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-18 18:56:00+03	2017-07-18 19:51:00+03
4173	PG0106	2017-08-05 18:55:00+03	2017-08-05 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-05 19:03:00+03	2017-08-05 19:59:00+03
4174	PG0106	2017-08-10 18:55:00+03	2017-08-10 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-10 18:59:00+03	2017-08-10 19:53:00+03
4175	PG0106	2017-07-25 18:55:00+03	2017-07-25 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-25 18:59:00+03	2017-07-25 19:54:00+03
4176	PG0106	2017-09-14 18:55:00+03	2017-09-14 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4177	PG0106	2017-08-11 18:55:00+03	2017-08-11 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-11 18:57:00+03	2017-08-11 19:53:00+03
4178	PG0106	2017-08-30 18:55:00+03	2017-08-30 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4179	PG0106	2017-07-23 18:55:00+03	2017-07-23 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-23 18:59:00+03	2017-07-23 19:53:00+03
4180	PG0106	2017-07-28 18:55:00+03	2017-07-28 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-28 18:58:00+03	2017-07-28 19:52:00+03
4181	PG0106	2017-08-20 18:55:00+03	2017-08-20 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4182	PG0106	2017-08-15 18:55:00+03	2017-08-15 19:50:00+03	VKO	ULV	On Time	SU9	\N	\N
4183	PG0106	2017-09-13 18:55:00+03	2017-09-13 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4184	PG0106	2017-07-27 18:55:00+03	2017-07-27 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-27 19:01:00+03	2017-07-27 19:57:00+03
4185	PG0106	2017-08-29 18:55:00+03	2017-08-29 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4186	PG0106	2017-08-02 18:55:00+03	2017-08-02 19:50:00+03	VKO	ULV	Arrived	SU9	2017-08-02 18:59:00+03	2017-08-02 19:53:00+03
4187	PG0106	2017-08-27 18:55:00+03	2017-08-27 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4188	PG0106	2017-07-17 18:55:00+03	2017-07-17 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-17 18:57:00+03	2017-07-17 19:52:00+03
4189	PG0106	2017-08-19 18:55:00+03	2017-08-19 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4190	PG0106	2017-09-03 18:55:00+03	2017-09-03 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4191	PG0106	2017-07-26 18:55:00+03	2017-07-26 19:50:00+03	VKO	ULV	Arrived	SU9	2017-07-26 18:59:00+03	2017-07-26 19:54:00+03
4192	PG0106	2017-09-08 18:55:00+03	2017-09-08 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4193	PG0106	2017-08-22 18:55:00+03	2017-08-22 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4194	PG0106	2017-09-09 18:55:00+03	2017-09-09 19:50:00+03	VKO	ULV	Scheduled	SU9	\N	\N
4195	PG0200	2017-08-22 19:20:00+03	2017-08-23 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4196	PG0200	2017-07-29 19:20:00+03	2017-07-30 03:45:00+03	VKO	VVO	Arrived	763	2017-07-29 19:23:00+03	2017-07-30 03:45:00+03
4197	PG0200	2017-09-10 19:20:00+03	2017-09-11 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4198	PG0200	2017-08-06 19:20:00+03	2017-08-07 03:45:00+03	VKO	VVO	Arrived	763	2017-08-06 19:23:00+03	2017-08-07 03:42:00+03
4199	PG0200	2017-07-16 19:20:00+03	2017-07-17 03:45:00+03	VKO	VVO	Arrived	763	2017-07-16 19:25:00+03	2017-07-17 04:02:00+03
4200	PG0200	2017-08-13 19:20:00+03	2017-08-14 03:45:00+03	VKO	VVO	Arrived	763	2017-08-13 19:21:00+03	2017-08-14 03:45:00+03
4201	PG0200	2017-07-21 19:20:00+03	2017-07-22 03:45:00+03	VKO	VVO	Arrived	763	2017-07-21 19:25:00+03	2017-07-22 03:49:00+03
4202	PG0200	2017-09-08 19:20:00+03	2017-09-09 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4203	PG0200	2017-08-24 19:20:00+03	2017-08-25 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4204	PG0200	2017-07-20 19:20:00+03	2017-07-21 03:45:00+03	VKO	VVO	Arrived	763	2017-07-20 19:22:00+03	2017-07-21 03:35:00+03
4205	PG0200	2017-07-18 19:20:00+03	2017-07-19 03:45:00+03	VKO	VVO	Arrived	763	2017-07-18 19:24:00+03	2017-07-19 03:55:00+03
4206	PG0200	2017-07-30 19:20:00+03	2017-07-31 03:45:00+03	VKO	VVO	Arrived	763	2017-07-30 19:22:00+03	2017-07-31 03:57:00+03
4207	PG0200	2017-09-04 19:20:00+03	2017-09-05 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4208	PG0200	2017-08-20 19:20:00+03	2017-08-21 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4209	PG0200	2017-08-19 19:20:00+03	2017-08-20 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4210	PG0200	2017-08-25 19:20:00+03	2017-08-26 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4211	PG0200	2017-08-12 19:20:00+03	2017-08-13 03:45:00+03	VKO	VVO	Arrived	763	2017-08-12 19:21:00+03	2017-08-13 03:37:00+03
4212	PG0200	2017-08-11 19:20:00+03	2017-08-12 03:45:00+03	VKO	VVO	Arrived	763	2017-08-11 19:27:00+03	2017-08-12 03:58:00+03
4213	PG0200	2017-07-31 19:20:00+03	2017-08-01 03:45:00+03	VKO	VVO	Arrived	763	2017-07-31 19:26:00+03	2017-08-01 03:49:00+03
4214	PG0200	2017-09-06 19:20:00+03	2017-09-07 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4215	PG0200	2017-07-28 19:20:00+03	2017-07-29 03:45:00+03	VKO	VVO	Arrived	763	2017-07-28 19:26:00+03	2017-07-29 03:49:00+03
4216	PG0200	2017-07-27 19:20:00+03	2017-07-28 03:45:00+03	VKO	VVO	Arrived	763	2017-07-27 19:21:00+03	2017-07-28 03:36:00+03
4217	PG0200	2017-08-16 19:20:00+03	2017-08-17 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4218	PG0200	2017-08-08 19:20:00+03	2017-08-09 03:45:00+03	VKO	VVO	Arrived	763	2017-08-08 19:22:00+03	2017-08-09 03:48:00+03
4219	PG0200	2017-07-22 19:20:00+03	2017-07-23 03:45:00+03	VKO	VVO	Arrived	763	2017-07-22 19:21:00+03	2017-07-23 03:43:00+03
4220	PG0200	2017-09-12 19:20:00+03	2017-09-13 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4221	PG0200	2017-07-26 19:20:00+03	2017-07-27 03:45:00+03	VKO	VVO	Arrived	763	2017-07-26 19:21:00+03	2017-07-27 03:37:00+03
4222	PG0200	2017-08-01 19:20:00+03	2017-08-02 03:45:00+03	VKO	VVO	Arrived	763	2017-08-01 19:24:00+03	2017-08-02 03:54:00+03
4223	PG0200	2017-09-14 19:20:00+03	2017-09-15 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4224	PG0200	2017-09-07 19:20:00+03	2017-09-08 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4225	PG0200	2017-09-03 19:20:00+03	2017-09-04 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4226	PG0200	2017-08-14 19:20:00+03	2017-08-15 03:45:00+03	VKO	VVO	Arrived	763	2017-08-14 19:22:00+03	2017-08-15 03:45:00+03
4227	PG0200	2017-08-02 19:20:00+03	2017-08-03 03:45:00+03	VKO	VVO	Arrived	763	2017-08-02 19:23:00+03	2017-08-03 03:47:00+03
4228	PG0200	2017-08-30 19:20:00+03	2017-08-31 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4229	PG0200	2017-08-04 19:20:00+03	2017-08-05 03:45:00+03	VKO	VVO	Arrived	763	2017-08-04 19:20:00+03	2017-08-05 03:49:00+03
4230	PG0200	2017-08-09 19:20:00+03	2017-08-10 03:45:00+03	VKO	VVO	Arrived	763	2017-08-09 19:22:00+03	2017-08-10 03:44:00+03
4231	PG0200	2017-08-18 19:20:00+03	2017-08-19 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4232	PG0200	2017-08-27 19:20:00+03	2017-08-28 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4233	PG0200	2017-07-25 19:20:00+03	2017-07-26 03:45:00+03	VKO	VVO	Arrived	763	2017-07-25 19:22:00+03	2017-07-26 03:49:00+03
4234	PG0200	2017-07-24 19:20:00+03	2017-07-25 03:45:00+03	VKO	VVO	Arrived	763	2017-07-24 19:21:00+03	2017-07-25 03:52:00+03
4235	PG0200	2017-09-05 19:20:00+03	2017-09-06 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4236	PG0200	2017-08-05 19:20:00+03	2017-08-06 03:45:00+03	VKO	VVO	Arrived	763	2017-08-05 19:20:00+03	2017-08-06 03:50:00+03
4237	PG0200	2017-09-02 19:20:00+03	2017-09-03 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4238	PG0200	2017-07-23 19:20:00+03	2017-07-24 03:45:00+03	VKO	VVO	Arrived	763	2017-07-23 19:21:00+03	2017-07-24 03:50:00+03
4239	PG0200	2017-09-13 19:20:00+03	2017-09-14 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4240	PG0200	2017-09-11 19:20:00+03	2017-09-12 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4241	PG0200	2017-07-19 19:20:00+03	2017-07-20 03:45:00+03	VKO	VVO	Arrived	763	2017-07-19 22:44:00+03	2017-07-20 07:16:00+03
4242	PG0200	2017-08-17 19:20:00+03	2017-08-18 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4243	PG0200	2017-09-09 19:20:00+03	2017-09-10 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4244	PG0200	2017-08-31 19:20:00+03	2017-09-01 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4245	PG0200	2017-08-07 19:20:00+03	2017-08-08 03:45:00+03	VKO	VVO	Arrived	763	2017-08-07 19:20:00+03	2017-08-08 03:49:00+03
4246	PG0200	2017-08-28 19:20:00+03	2017-08-29 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4247	PG0200	2017-08-10 19:20:00+03	2017-08-11 03:45:00+03	VKO	VVO	Arrived	763	2017-08-10 19:26:00+03	2017-08-11 03:53:00+03
4248	PG0200	2017-09-01 19:20:00+03	2017-09-02 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4249	PG0200	2017-08-23 19:20:00+03	2017-08-24 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4250	PG0200	2017-08-29 19:20:00+03	2017-08-30 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4251	PG0200	2017-08-21 19:20:00+03	2017-08-22 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4252	PG0200	2017-08-03 19:20:00+03	2017-08-04 03:45:00+03	VKO	VVO	Arrived	763	2017-08-03 19:23:00+03	2017-08-04 03:43:00+03
4253	PG0200	2017-08-15 19:20:00+03	2017-08-16 03:45:00+03	VKO	VVO	On Time	763	\N	\N
4254	PG0200	2017-08-26 19:20:00+03	2017-08-27 03:45:00+03	VKO	VVO	Scheduled	763	\N	\N
4255	PG0200	2017-07-17 19:20:00+03	2017-07-18 03:45:00+03	VKO	VVO	Arrived	763	2017-07-17 19:28:00+03	2017-07-18 03:48:00+03
4256	PG0553	2017-08-22 13:45:00+03	2017-08-22 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4257	PG0553	2017-09-04 13:45:00+03	2017-09-04 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4258	PG0553	2017-08-28 13:45:00+03	2017-08-28 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4259	PG0553	2017-09-08 13:45:00+03	2017-09-08 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4260	PG0553	2017-07-16 13:45:00+03	2017-07-16 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-16 13:46:00+03	2017-07-16 15:26:00+03
4261	PG0553	2017-07-26 13:45:00+03	2017-07-26 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-26 13:49:00+03	2017-07-26 15:29:00+03
4262	PG0553	2017-07-31 13:45:00+03	2017-07-31 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-31 13:50:00+03	2017-07-31 15:29:00+03
4263	PG0553	2017-08-20 13:45:00+03	2017-08-20 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4264	PG0553	2017-08-16 13:45:00+03	2017-08-16 15:25:00+03	VKO	REN	On Time	SU9	\N	\N
4265	PG0553	2017-08-11 13:45:00+03	2017-08-11 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-11 13:48:00+03	2017-08-11 15:30:00+03
4266	PG0553	2017-08-18 13:45:00+03	2017-08-18 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4267	PG0553	2017-07-28 13:45:00+03	2017-07-28 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-28 13:49:00+03	2017-07-28 15:30:00+03
4268	PG0553	2017-08-04 13:45:00+03	2017-08-04 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-04 13:47:00+03	2017-08-04 15:26:00+03
4269	PG0553	2017-09-12 13:45:00+03	2017-09-12 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4270	PG0553	2017-09-07 13:45:00+03	2017-09-07 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4271	PG0553	2017-08-14 13:45:00+03	2017-08-14 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-14 13:47:00+03	2017-08-14 15:28:00+03
4272	PG0553	2017-08-30 13:45:00+03	2017-08-30 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4273	PG0553	2017-07-17 13:45:00+03	2017-07-17 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-17 13:46:00+03	2017-07-17 15:29:00+03
4274	PG0553	2017-08-29 13:45:00+03	2017-08-29 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4275	PG0553	2017-08-12 13:45:00+03	2017-08-12 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-12 13:47:00+03	2017-08-12 15:25:00+03
4276	PG0553	2017-08-05 13:45:00+03	2017-08-05 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-05 13:46:00+03	2017-08-05 15:26:00+03
4277	PG0553	2017-09-02 13:45:00+03	2017-09-02 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4278	PG0553	2017-07-27 13:45:00+03	2017-07-27 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-27 13:48:00+03	2017-07-27 15:28:00+03
4279	PG0553	2017-08-08 13:45:00+03	2017-08-08 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-08 13:56:00+03	2017-08-08 15:37:00+03
4280	PG0553	2017-09-14 13:45:00+03	2017-09-14 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4281	PG0553	2017-08-25 13:45:00+03	2017-08-25 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4282	PG0553	2017-07-25 13:45:00+03	2017-07-25 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-25 13:46:00+03	2017-07-25 15:27:00+03
4283	PG0553	2017-08-31 13:45:00+03	2017-08-31 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4284	PG0553	2017-08-01 13:45:00+03	2017-08-01 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-01 13:51:00+03	2017-08-01 15:31:00+03
4285	PG0553	2017-07-18 13:45:00+03	2017-07-18 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-18 13:49:00+03	2017-07-18 15:30:00+03
4286	PG0553	2017-09-13 13:45:00+03	2017-09-13 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4287	PG0553	2017-07-22 13:45:00+03	2017-07-22 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-22 13:48:00+03	2017-07-22 15:30:00+03
4288	PG0553	2017-08-19 13:45:00+03	2017-08-19 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4289	PG0553	2017-08-10 13:45:00+03	2017-08-10 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-10 13:49:00+03	2017-08-10 15:28:00+03
4290	PG0553	2017-07-24 13:45:00+03	2017-07-24 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-24 13:46:00+03	2017-07-24 15:27:00+03
4291	PG0553	2017-09-01 13:45:00+03	2017-09-01 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4292	PG0553	2017-08-13 13:45:00+03	2017-08-13 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-13 13:48:00+03	2017-08-13 15:27:00+03
4293	PG0553	2017-07-23 13:45:00+03	2017-07-23 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-23 13:50:00+03	2017-07-23 15:30:00+03
4294	PG0553	2017-08-03 13:45:00+03	2017-08-03 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-03 13:48:00+03	2017-08-03 15:29:00+03
4295	PG0553	2017-08-27 13:45:00+03	2017-08-27 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4296	PG0553	2017-09-11 13:45:00+03	2017-09-11 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4297	PG0553	2017-08-26 13:45:00+03	2017-08-26 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4298	PG0553	2017-07-30 13:45:00+03	2017-07-30 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-30 13:48:00+03	2017-07-30 15:27:00+03
4299	PG0553	2017-08-06 13:45:00+03	2017-08-06 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-06 13:47:00+03	2017-08-06 15:26:00+03
4300	PG0553	2017-07-19 13:45:00+03	2017-07-19 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-19 13:48:00+03	2017-07-19 15:29:00+03
4301	PG0553	2017-07-29 13:45:00+03	2017-07-29 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-29 13:47:00+03	2017-07-29 15:28:00+03
4302	PG0553	2017-08-24 13:45:00+03	2017-08-24 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4303	PG0553	2017-07-21 13:45:00+03	2017-07-21 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-21 17:39:00+03	2017-07-21 19:18:00+03
4304	PG0553	2017-09-05 13:45:00+03	2017-09-05 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4305	PG0553	2017-08-23 13:45:00+03	2017-08-23 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4306	PG0553	2017-09-03 13:45:00+03	2017-09-03 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4307	PG0553	2017-08-17 13:45:00+03	2017-08-17 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4308	PG0553	2017-08-02 13:45:00+03	2017-08-02 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-02 13:51:00+03	2017-08-02 15:31:00+03
4309	PG0553	2017-08-15 13:45:00+03	2017-08-15 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-15 13:47:00+03	2017-08-15 15:28:00+03
4310	PG0553	2017-08-07 13:45:00+03	2017-08-07 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-07 13:45:00+03	2017-08-07 15:25:00+03
4311	PG0553	2017-09-10 13:45:00+03	2017-09-10 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4312	PG0553	2017-08-21 13:45:00+03	2017-08-21 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4313	PG0553	2017-07-20 13:45:00+03	2017-07-20 15:25:00+03	VKO	REN	Arrived	SU9	2017-07-20 13:47:00+03	2017-07-20 15:28:00+03
4314	PG0553	2017-09-09 13:45:00+03	2017-09-09 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4315	PG0553	2017-09-06 13:45:00+03	2017-09-06 15:25:00+03	VKO	REN	Scheduled	SU9	\N	\N
4316	PG0553	2017-08-09 13:45:00+03	2017-08-09 15:25:00+03	VKO	REN	Arrived	SU9	2017-08-09 13:47:00+03	2017-08-09 15:25:00+03
4317	PG0347	2017-08-24 12:45:00+03	2017-08-24 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4318	PG0347	2017-09-10 12:45:00+03	2017-09-10 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4319	PG0347	2017-08-06 12:45:00+03	2017-08-06 16:45:00+03	VKO	KEJ	Arrived	319	2017-08-06 12:45:00+03	2017-08-06 16:44:00+03
4320	PG0347	2017-08-31 12:45:00+03	2017-08-31 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4321	PG0347	2017-07-27 12:45:00+03	2017-07-27 16:45:00+03	VKO	KEJ	Arrived	319	2017-07-27 12:49:00+03	2017-07-27 16:48:00+03
4322	PG0347	2017-07-16 12:45:00+03	2017-07-16 16:45:00+03	VKO	KEJ	Arrived	319	2017-07-16 12:49:00+03	2017-07-16 16:46:00+03
4323	PG0347	2017-08-10 12:45:00+03	2017-08-10 16:45:00+03	VKO	KEJ	Arrived	319	2017-08-10 12:52:00+03	2017-08-10 16:51:00+03
4324	PG0347	2017-08-03 12:45:00+03	2017-08-03 16:45:00+03	VKO	KEJ	Arrived	319	2017-08-03 12:46:00+03	2017-08-03 16:45:00+03
4325	PG0347	2017-08-20 12:45:00+03	2017-08-20 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4326	PG0347	2017-08-13 12:45:00+03	2017-08-13 16:45:00+03	VKO	KEJ	Arrived	319	2017-08-13 12:45:00+03	2017-08-13 16:46:00+03
4327	PG0347	2017-07-30 12:45:00+03	2017-07-30 16:45:00+03	VKO	KEJ	Arrived	319	2017-07-30 12:46:00+03	2017-07-30 16:45:00+03
4328	PG0347	2017-07-20 12:45:00+03	2017-07-20 16:45:00+03	VKO	KEJ	Arrived	319	2017-07-20 12:48:00+03	2017-07-20 16:51:00+03
4329	PG0347	2017-09-03 12:45:00+03	2017-09-03 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4330	PG0347	2017-09-07 12:45:00+03	2017-09-07 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4331	PG0347	2017-07-23 12:45:00+03	2017-07-23 16:45:00+03	VKO	KEJ	Arrived	319	2017-07-23 12:48:00+03	2017-07-23 16:45:00+03
4332	PG0347	2017-09-14 12:45:00+03	2017-09-14 16:45:00+03	VKO	KEJ	Cancelled	319	\N	\N
4333	PG0347	2017-08-27 12:45:00+03	2017-08-27 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4334	PG0347	2017-08-17 12:45:00+03	2017-08-17 16:45:00+03	VKO	KEJ	Scheduled	319	\N	\N
4335	PG0176	2017-08-05 14:50:00+03	2017-08-05 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-05 14:55:00+03	2017-08-05 15:50:00+03
4336	PG0176	2017-07-31 14:50:00+03	2017-07-31 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-31 14:52:00+03	2017-07-31 15:46:00+03
4337	PG0176	2017-09-08 14:50:00+03	2017-09-08 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4338	PG0176	2017-09-13 14:50:00+03	2017-09-13 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4339	PG0176	2017-09-12 14:50:00+03	2017-09-12 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4340	PG0176	2017-09-09 14:50:00+03	2017-09-09 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4341	PG0176	2017-08-31 14:50:00+03	2017-08-31 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4342	PG0176	2017-08-18 14:50:00+03	2017-08-18 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4343	PG0176	2017-08-22 14:50:00+03	2017-08-22 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4344	PG0176	2017-09-03 14:50:00+03	2017-09-03 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4345	PG0176	2017-08-16 14:50:00+03	2017-08-16 15:45:00+03	VKO	CSY	On Time	CR2	\N	\N
4346	PG0176	2017-07-26 14:50:00+03	2017-07-26 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-26 14:52:00+03	2017-07-26 15:47:00+03
4347	PG0176	2017-09-05 14:50:00+03	2017-09-05 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4348	PG0176	2017-08-28 14:50:00+03	2017-08-28 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4349	PG0176	2017-08-06 14:50:00+03	2017-08-06 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-06 14:55:00+03	2017-08-06 15:50:00+03
4350	PG0176	2017-08-14 14:50:00+03	2017-08-14 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-14 14:53:00+03	2017-08-14 15:48:00+03
4351	PG0176	2017-08-19 14:50:00+03	2017-08-19 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4352	PG0176	2017-08-01 14:50:00+03	2017-08-01 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-01 14:52:00+03	2017-08-01 15:48:00+03
4353	PG0176	2017-09-07 14:50:00+03	2017-09-07 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4354	PG0176	2017-08-03 14:50:00+03	2017-08-03 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-03 14:53:00+03	2017-08-03 15:48:00+03
4355	PG0176	2017-07-20 14:50:00+03	2017-07-20 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-20 14:53:00+03	2017-07-20 15:50:00+03
4356	PG0176	2017-08-30 14:50:00+03	2017-08-30 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4357	PG0176	2017-08-04 14:50:00+03	2017-08-04 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-04 14:50:00+03	2017-08-04 15:45:00+03
4358	PG0176	2017-09-04 14:50:00+03	2017-09-04 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4359	PG0176	2017-07-25 14:50:00+03	2017-07-25 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-25 14:52:00+03	2017-07-25 15:47:00+03
4360	PG0176	2017-07-29 14:50:00+03	2017-07-29 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-29 14:53:00+03	2017-07-29 15:47:00+03
4361	PG0176	2017-07-23 14:50:00+03	2017-07-23 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-23 14:55:00+03	2017-07-23 15:50:00+03
4362	PG0176	2017-08-29 14:50:00+03	2017-08-29 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4363	PG0176	2017-08-26 14:50:00+03	2017-08-26 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4364	PG0176	2017-07-19 14:50:00+03	2017-07-19 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-19 14:54:00+03	2017-07-19 15:50:00+03
4365	PG0176	2017-08-21 14:50:00+03	2017-08-21 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4366	PG0176	2017-08-17 14:50:00+03	2017-08-17 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4367	PG0176	2017-07-21 14:50:00+03	2017-07-21 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-21 14:53:00+03	2017-07-21 15:48:00+03
4368	PG0176	2017-07-28 14:50:00+03	2017-07-28 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-28 14:53:00+03	2017-07-28 15:47:00+03
4369	PG0176	2017-09-01 14:50:00+03	2017-09-01 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4370	PG0176	2017-09-11 14:50:00+03	2017-09-11 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4371	PG0176	2017-08-23 14:50:00+03	2017-08-23 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4372	PG0176	2017-07-18 14:50:00+03	2017-07-18 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-18 14:52:00+03	2017-07-18 15:46:00+03
4373	PG0176	2017-08-27 14:50:00+03	2017-08-27 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4374	PG0176	2017-07-22 14:50:00+03	2017-07-22 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-22 14:51:00+03	2017-07-22 15:47:00+03
4375	PG0176	2017-08-10 14:50:00+03	2017-08-10 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-10 14:54:00+03	2017-08-10 15:49:00+03
4376	PG0176	2017-08-15 14:50:00+03	2017-08-15 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-15 14:55:00+03	2017-08-15 15:50:00+03
4377	PG0176	2017-07-24 14:50:00+03	2017-07-24 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-24 14:55:00+03	2017-07-24 15:50:00+03
4378	PG0176	2017-08-09 14:50:00+03	2017-08-09 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-09 14:54:00+03	2017-08-09 15:49:00+03
4379	PG0176	2017-08-24 14:50:00+03	2017-08-24 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4380	PG0176	2017-08-07 14:50:00+03	2017-08-07 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-07 14:52:00+03	2017-08-07 15:47:00+03
4381	PG0176	2017-08-25 14:50:00+03	2017-08-25 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4382	PG0176	2017-08-13 14:50:00+03	2017-08-13 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-13 17:57:00+03	2017-08-13 18:51:00+03
4383	PG0176	2017-08-20 14:50:00+03	2017-08-20 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4384	PG0176	2017-07-16 14:50:00+03	2017-07-16 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-16 14:55:00+03	2017-07-16 15:49:00+03
4385	PG0176	2017-09-02 14:50:00+03	2017-09-02 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4386	PG0176	2017-08-02 14:50:00+03	2017-08-02 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-02 14:53:00+03	2017-08-02 15:47:00+03
4387	PG0176	2017-07-17 14:50:00+03	2017-07-17 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-17 14:55:00+03	2017-07-17 15:50:00+03
4388	PG0176	2017-09-14 14:50:00+03	2017-09-14 15:45:00+03	VKO	CSY	Cancelled	CR2	\N	\N
4389	PG0176	2017-08-12 14:50:00+03	2017-08-12 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-12 14:52:00+03	2017-08-12 15:46:00+03
4390	PG0176	2017-07-30 14:50:00+03	2017-07-30 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-30 17:56:00+03	2017-07-30 18:51:00+03
4391	PG0176	2017-08-11 14:50:00+03	2017-08-11 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-11 14:51:00+03	2017-08-11 15:46:00+03
4392	PG0176	2017-08-08 14:50:00+03	2017-08-08 15:45:00+03	VKO	CSY	Arrived	CR2	2017-08-08 14:55:00+03	2017-08-08 15:51:00+03
4393	PG0176	2017-09-10 14:50:00+03	2017-09-10 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4394	PG0176	2017-07-27 14:50:00+03	2017-07-27 15:45:00+03	VKO	CSY	Arrived	CR2	2017-07-27 14:52:00+03	2017-07-27 15:47:00+03
4395	PG0176	2017-09-06 14:50:00+03	2017-09-06 15:45:00+03	VKO	CSY	Scheduled	CR2	\N	\N
4396	PG0064	2017-09-07 09:35:00+03	2017-09-07 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4397	PG0064	2017-08-21 09:35:00+03	2017-08-21 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4398	PG0064	2017-08-14 09:35:00+03	2017-08-14 15:25:00+03	VKO	UUD	Arrived	319	2017-08-14 09:37:00+03	2017-08-14 15:32:00+03
4399	PG0064	2017-09-09 09:35:00+03	2017-09-09 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4400	PG0064	2017-08-12 09:35:00+03	2017-08-12 15:25:00+03	VKO	UUD	Arrived	319	2017-08-12 09:38:00+03	2017-08-12 15:30:00+03
4401	PG0064	2017-09-04 09:35:00+03	2017-09-04 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4402	PG0064	2017-08-05 09:35:00+03	2017-08-05 15:25:00+03	VKO	UUD	Arrived	319	2017-08-05 09:39:00+03	2017-08-05 15:26:00+03
4403	PG0064	2017-09-14 09:35:00+03	2017-09-14 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4404	PG0064	2017-08-19 09:35:00+03	2017-08-19 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4405	PG0064	2017-07-17 09:35:00+03	2017-07-17 15:25:00+03	VKO	UUD	Arrived	319	2017-07-17 09:40:00+03	2017-07-17 15:24:00+03
4406	PG0064	2017-08-31 09:35:00+03	2017-08-31 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4407	PG0064	2017-08-10 09:35:00+03	2017-08-10 15:25:00+03	VKO	UUD	Arrived	319	2017-08-10 09:41:00+03	2017-08-10 15:28:00+03
4408	PG0064	2017-08-28 09:35:00+03	2017-08-28 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4409	PG0064	2017-08-03 09:35:00+03	2017-08-03 15:25:00+03	VKO	UUD	Arrived	319	2017-08-03 09:40:00+03	2017-08-03 15:29:00+03
4410	PG0064	2017-09-11 09:35:00+03	2017-09-11 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4411	PG0064	2017-08-07 09:35:00+03	2017-08-07 15:25:00+03	VKO	UUD	Arrived	319	2017-08-07 09:37:00+03	2017-08-07 15:27:00+03
4412	PG0064	2017-07-22 09:35:00+03	2017-07-22 15:25:00+03	VKO	UUD	Arrived	319	2017-07-22 09:36:00+03	2017-07-22 15:20:00+03
4413	PG0064	2017-07-27 09:35:00+03	2017-07-27 15:25:00+03	VKO	UUD	Arrived	319	2017-07-27 09:36:00+03	2017-07-27 15:28:00+03
4414	PG0064	2017-08-17 09:35:00+03	2017-08-17 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4415	PG0064	2017-07-29 09:35:00+03	2017-07-29 15:25:00+03	VKO	UUD	Arrived	319	2017-07-29 09:38:00+03	2017-07-29 15:23:00+03
4416	PG0064	2017-07-20 09:35:00+03	2017-07-20 15:25:00+03	VKO	UUD	Arrived	319	2017-07-20 09:41:00+03	2017-07-20 15:29:00+03
4417	PG0064	2017-08-24 09:35:00+03	2017-08-24 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4418	PG0064	2017-09-02 09:35:00+03	2017-09-02 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4419	PG0064	2017-08-26 09:35:00+03	2017-08-26 15:25:00+03	VKO	UUD	Scheduled	319	\N	\N
4420	PG0064	2017-07-24 09:35:00+03	2017-07-24 15:25:00+03	VKO	UUD	Arrived	319	2017-07-24 09:35:00+03	2017-07-24 15:20:00+03
4421	PG0064	2017-07-31 09:35:00+03	2017-07-31 15:25:00+03	VKO	UUD	Arrived	319	2017-07-31 09:40:00+03	2017-07-31 15:36:00+03
4422	PG0448	2017-09-03 18:30:00+03	2017-09-03 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4423	PG0448	2017-07-20 18:30:00+03	2017-07-20 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-20 18:33:00+03	2017-07-20 20:17:00+03
4424	PG0448	2017-09-05 18:30:00+03	2017-09-05 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4425	PG0448	2017-08-22 18:30:00+03	2017-08-22 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4426	PG0448	2017-08-03 18:30:00+03	2017-08-03 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-03 18:31:00+03	2017-08-03 20:16:00+03
4427	PG0448	2017-09-07 18:30:00+03	2017-09-07 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4428	PG0448	2017-08-06 18:30:00+03	2017-08-06 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-06 18:33:00+03	2017-08-06 20:19:00+03
4429	PG0448	2017-09-12 18:30:00+03	2017-09-12 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4430	PG0448	2017-08-29 18:30:00+03	2017-08-29 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4431	PG0448	2017-08-27 18:30:00+03	2017-08-27 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4432	PG0448	2017-07-16 18:30:00+03	2017-07-16 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-16 18:32:00+03	2017-07-16 20:16:00+03
4433	PG0448	2017-07-23 18:30:00+03	2017-07-23 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-23 18:34:00+03	2017-07-23 20:19:00+03
4434	PG0448	2017-08-31 18:30:00+03	2017-08-31 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4435	PG0448	2017-08-10 18:30:00+03	2017-08-10 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-10 18:35:00+03	2017-08-10 20:21:00+03
4436	PG0448	2017-07-27 18:30:00+03	2017-07-27 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-27 18:32:00+03	2017-07-27 20:19:00+03
4437	PG0448	2017-08-08 18:30:00+03	2017-08-08 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-08 18:34:00+03	2017-08-08 20:18:00+03
4438	PG0448	2017-08-15 18:30:00+03	2017-08-15 20:15:00+03	VKO	STW	On Time	CR2	\N	\N
4439	PG0448	2017-07-30 18:30:00+03	2017-07-30 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-30 18:32:00+03	2017-07-30 20:18:00+03
4440	PG0448	2017-07-25 18:30:00+03	2017-07-25 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-25 18:33:00+03	2017-07-25 20:19:00+03
4441	PG0448	2017-08-13 18:30:00+03	2017-08-13 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-13 18:33:00+03	2017-08-13 20:17:00+03
4442	PG0448	2017-08-20 18:30:00+03	2017-08-20 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4443	PG0448	2017-08-01 18:30:00+03	2017-08-01 20:15:00+03	VKO	STW	Arrived	CR2	2017-08-01 18:33:00+03	2017-08-01 20:17:00+03
4444	PG0448	2017-09-14 18:30:00+03	2017-09-14 20:15:00+03	VKO	STW	Cancelled	CR2	\N	\N
4445	PG0448	2017-08-24 18:30:00+03	2017-08-24 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4446	PG0448	2017-07-18 18:30:00+03	2017-07-18 20:15:00+03	VKO	STW	Arrived	CR2	2017-07-18 18:33:00+03	2017-07-18 20:18:00+03
4447	PG0448	2017-09-10 18:30:00+03	2017-09-10 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4448	PG0448	2017-08-17 18:30:00+03	2017-08-17 20:15:00+03	VKO	STW	Scheduled	CR2	\N	\N
4449	PG0515	2017-08-18 14:00:00+03	2017-08-18 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4450	PG0515	2017-08-11 14:00:00+03	2017-08-11 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-11 14:02:00+03	2017-08-11 16:01:00+03
4451	PG0515	2017-08-31 14:00:00+03	2017-08-31 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4452	PG0515	2017-07-21 14:00:00+03	2017-07-21 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-21 14:02:00+03	2017-07-21 16:00:00+03
4453	PG0515	2017-09-14 14:00:00+03	2017-09-14 16:00:00+03	VKO	MQF	Cancelled	CR2	\N	\N
4454	PG0515	2017-08-03 14:00:00+03	2017-08-03 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-03 14:01:00+03	2017-08-03 16:01:00+03
4455	PG0515	2017-09-11 14:00:00+03	2017-09-11 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4456	PG0515	2017-07-22 14:00:00+03	2017-07-22 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-22 14:01:00+03	2017-07-22 16:01:00+03
4457	PG0515	2017-08-01 14:00:00+03	2017-08-01 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-01 14:05:00+03	2017-08-01 16:05:00+03
4458	PG0515	2017-08-04 14:00:00+03	2017-08-04 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-04 14:06:00+03	2017-08-04 16:07:00+03
4459	PG0515	2017-08-13 14:00:00+03	2017-08-13 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-13 14:03:00+03	2017-08-13 16:01:00+03
4460	PG0515	2017-09-06 14:00:00+03	2017-09-06 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4461	PG0515	2017-09-04 14:00:00+03	2017-09-04 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4462	PG0515	2017-07-20 14:00:00+03	2017-07-20 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-20 14:04:00+03	2017-07-20 16:05:00+03
4463	PG0515	2017-09-12 14:00:00+03	2017-09-12 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4464	PG0515	2017-08-12 14:00:00+03	2017-08-12 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-12 14:02:00+03	2017-08-12 16:04:00+03
4465	PG0515	2017-08-29 14:00:00+03	2017-08-29 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4466	PG0515	2017-07-31 14:00:00+03	2017-07-31 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-31 14:04:00+03	2017-07-31 16:03:00+03
4467	PG0515	2017-08-28 14:00:00+03	2017-08-28 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4468	PG0515	2017-08-16 14:00:00+03	2017-08-16 16:00:00+03	VKO	MQF	On Time	CR2	\N	\N
4469	PG0515	2017-08-05 14:00:00+03	2017-08-05 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-05 14:02:00+03	2017-08-05 16:03:00+03
4470	PG0515	2017-07-23 14:00:00+03	2017-07-23 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-23 14:02:00+03	2017-07-23 16:02:00+03
4471	PG0515	2017-08-06 14:00:00+03	2017-08-06 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-06 14:03:00+03	2017-08-06 16:02:00+03
4472	PG0515	2017-07-30 14:00:00+03	2017-07-30 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-30 14:05:00+03	2017-07-30 16:05:00+03
4473	PG0515	2017-07-19 14:00:00+03	2017-07-19 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-19 14:02:00+03	2017-07-19 16:02:00+03
4474	PG0515	2017-09-03 14:00:00+03	2017-09-03 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4475	PG0515	2017-08-23 14:00:00+03	2017-08-23 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4476	PG0515	2017-09-07 14:00:00+03	2017-09-07 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4477	PG0515	2017-07-26 14:00:00+03	2017-07-26 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-26 14:02:00+03	2017-07-26 16:01:00+03
4478	PG0515	2017-08-21 14:00:00+03	2017-08-21 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4479	PG0515	2017-08-07 14:00:00+03	2017-08-07 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-07 14:04:00+03	2017-08-07 16:04:00+03
4480	PG0515	2017-08-15 14:00:00+03	2017-08-15 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-15 14:04:00+03	2017-08-15 16:05:00+03
4481	PG0515	2017-09-10 14:00:00+03	2017-09-10 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4482	PG0515	2017-07-29 14:00:00+03	2017-07-29 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-29 14:01:00+03	2017-07-29 16:02:00+03
4483	PG0515	2017-07-24 14:00:00+03	2017-07-24 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-24 14:02:00+03	2017-07-24 16:04:00+03
4484	PG0515	2017-08-19 14:00:00+03	2017-08-19 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4485	PG0515	2017-09-13 14:00:00+03	2017-09-13 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4486	PG0515	2017-07-18 14:00:00+03	2017-07-18 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-18 14:01:00+03	2017-07-18 15:59:00+03
4487	PG0515	2017-08-08 14:00:00+03	2017-08-08 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-08 14:02:00+03	2017-08-08 16:00:00+03
4488	PG0515	2017-09-02 14:00:00+03	2017-09-02 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4489	PG0515	2017-07-28 14:00:00+03	2017-07-28 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-28 17:21:00+03	2017-07-28 19:21:00+03
4490	PG0515	2017-07-16 14:00:00+03	2017-07-16 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-16 14:05:00+03	2017-07-16 16:06:00+03
4491	PG0515	2017-09-08 14:00:00+03	2017-09-08 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4492	PG0515	2017-08-09 14:00:00+03	2017-08-09 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-09 16:58:00+03	2017-08-09 18:59:00+03
4493	PG0515	2017-08-30 14:00:00+03	2017-08-30 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4494	PG0515	2017-07-17 14:00:00+03	2017-07-17 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-17 14:01:00+03	2017-07-17 16:00:00+03
4495	PG0515	2017-08-14 14:00:00+03	2017-08-14 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-14 14:06:00+03	2017-08-14 16:06:00+03
4496	PG0515	2017-07-25 14:00:00+03	2017-07-25 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-25 14:04:00+03	2017-07-25 16:04:00+03
4497	PG0515	2017-07-27 14:00:00+03	2017-07-27 16:00:00+03	VKO	MQF	Arrived	CR2	2017-07-27 14:02:00+03	2017-07-27 16:01:00+03
4498	PG0515	2017-08-10 14:00:00+03	2017-08-10 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-10 14:02:00+03	2017-08-10 16:02:00+03
4499	PG0515	2017-08-25 14:00:00+03	2017-08-25 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4500	PG0515	2017-09-01 14:00:00+03	2017-09-01 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4501	PG0515	2017-09-09 14:00:00+03	2017-09-09 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4502	PG0515	2017-08-24 14:00:00+03	2017-08-24 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4503	PG0515	2017-08-27 14:00:00+03	2017-08-27 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4504	PG0515	2017-08-20 14:00:00+03	2017-08-20 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4505	PG0515	2017-08-26 14:00:00+03	2017-08-26 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4506	PG0515	2017-08-17 14:00:00+03	2017-08-17 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4507	PG0515	2017-09-05 14:00:00+03	2017-09-05 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4508	PG0515	2017-08-22 14:00:00+03	2017-08-22 16:00:00+03	VKO	MQF	Scheduled	CR2	\N	\N
4509	PG0515	2017-08-02 14:00:00+03	2017-08-02 16:00:00+03	VKO	MQF	Arrived	CR2	2017-08-02 14:02:00+03	2017-08-02 16:01:00+03
4510	PG0233	2017-07-23 12:15:00+03	2017-07-23 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-23 12:18:00+03	2017-07-23 12:43:00+03
4511	PG0235	2017-07-31 19:50:00+03	2017-07-31 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-31 19:51:00+03	2017-07-31 20:16:00+03
4512	PG0235	2017-08-28 19:50:00+03	2017-08-28 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4513	PG0234	2017-07-31 15:15:00+03	2017-07-31 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-31 15:18:00+03	2017-07-31 15:43:00+03
4514	PG0234	2017-08-02 15:15:00+03	2017-08-02 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-02 19:02:00+03	2017-08-02 19:27:00+03
4515	PG0233	2017-07-19 12:15:00+03	2017-07-19 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-19 12:18:00+03	2017-07-19 12:43:00+03
4516	PG0233	2017-08-10 12:15:00+03	2017-08-10 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-10 12:21:00+03	2017-08-10 12:45:00+03
4517	PG0233	2017-07-30 12:15:00+03	2017-07-30 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-30 12:17:00+03	2017-07-30 12:42:00+03
4518	PG0234	2017-07-30 15:15:00+03	2017-07-30 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-30 18:10:00+03	2017-07-30 18:35:00+03
4519	PG0235	2017-08-12 19:50:00+03	2017-08-12 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-12 19:51:00+03	2017-08-12 20:16:00+03
4520	PG0234	2017-08-12 15:15:00+03	2017-08-12 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-12 15:19:00+03	2017-08-12 15:44:00+03
4521	PG0234	2017-08-04 15:15:00+03	2017-08-04 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-04 15:18:00+03	2017-08-04 15:43:00+03
4522	PG0233	2017-07-16 12:15:00+03	2017-07-16 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-16 12:18:00+03	2017-07-16 12:43:00+03
4523	PG0234	2017-09-13 15:15:00+03	2017-09-13 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4524	PG0233	2017-09-13 12:15:00+03	2017-09-13 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4525	PG0233	2017-08-03 12:15:00+03	2017-08-03 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-03 12:17:00+03	2017-08-03 12:42:00+03
4526	PG0234	2017-08-03 15:15:00+03	2017-08-03 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-03 15:15:00+03	2017-08-03 15:40:00+03
4527	PG0233	2017-08-16 12:15:00+03	2017-08-16 12:40:00+03	VKO	BZK	On Time	SU9	\N	\N
4528	PG0235	2017-09-07 19:50:00+03	2017-09-07 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4529	PG0234	2017-09-07 15:15:00+03	2017-09-07 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4530	PG0235	2017-08-03 19:50:00+03	2017-08-03 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-03 19:51:00+03	2017-08-03 20:16:00+03
4531	PG0233	2017-08-20 12:15:00+03	2017-08-20 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4532	PG0233	2017-08-19 12:15:00+03	2017-08-19 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4533	PG0234	2017-08-13 15:15:00+03	2017-08-13 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-13 15:18:00+03	2017-08-13 15:43:00+03
4534	PG0233	2017-09-07 12:15:00+03	2017-09-07 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4535	PG0234	2017-08-16 15:15:00+03	2017-08-16 15:40:00+03	VKO	BZK	On Time	SU9	\N	\N
4536	PG0233	2017-08-12 12:15:00+03	2017-08-12 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-12 12:18:00+03	2017-08-12 12:43:00+03
4537	PG0233	2017-08-31 12:15:00+03	2017-08-31 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4538	PG0233	2017-09-03 12:15:00+03	2017-09-03 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4539	PG0234	2017-09-03 15:15:00+03	2017-09-03 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4540	PG0235	2017-08-07 19:50:00+03	2017-08-07 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-07 19:53:00+03	2017-08-07 20:18:00+03
4541	PG0235	2017-07-26 19:50:00+03	2017-07-26 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-26 19:55:00+03	2017-07-26 20:20:00+03
4542	PG0235	2017-08-16 19:50:00+03	2017-08-16 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4543	PG0235	2017-09-14 19:50:00+03	2017-09-14 20:15:00+03	VKO	BZK	Cancelled	SU9	\N	\N
4544	PG0235	2017-08-02 19:50:00+03	2017-08-02 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-02 19:53:00+03	2017-08-02 20:18:00+03
4545	PG0235	2017-08-31 19:50:00+03	2017-08-31 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4546	PG0234	2017-08-19 15:15:00+03	2017-08-19 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4547	PG0235	2017-09-06 19:50:00+03	2017-09-06 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4548	PG0235	2017-08-11 19:50:00+03	2017-08-11 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-11 19:52:00+03	2017-08-11 20:17:00+03
4549	PG0235	2017-08-19 19:50:00+03	2017-08-19 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4550	PG0233	2017-08-25 12:15:00+03	2017-08-25 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4551	PG0233	2017-08-30 12:15:00+03	2017-08-30 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4552	PG0235	2017-07-20 19:50:00+03	2017-07-20 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-20 19:52:00+03	2017-07-20 20:17:00+03
4553	PG0234	2017-08-30 15:15:00+03	2017-08-30 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4554	PG0235	2017-08-30 19:50:00+03	2017-08-30 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4555	PG0234	2017-08-11 15:15:00+03	2017-08-11 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-11 15:19:00+03	2017-08-11 15:44:00+03
4556	PG0235	2017-09-03 19:50:00+03	2017-09-03 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4557	PG0233	2017-08-11 12:15:00+03	2017-08-11 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-11 12:19:00+03	2017-08-11 12:44:00+03
4558	PG0234	2017-07-20 15:15:00+03	2017-07-20 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-20 15:20:00+03	2017-07-20 15:45:00+03
4559	PG0235	2017-09-05 19:50:00+03	2017-09-05 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4560	PG0234	2017-09-05 15:15:00+03	2017-09-05 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4561	PG0233	2017-08-14 12:15:00+03	2017-08-14 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-14 12:21:00+03	2017-08-14 12:46:00+03
4562	PG0233	2017-08-08 12:15:00+03	2017-08-08 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-08 12:19:00+03	2017-08-08 12:44:00+03
4563	PG0234	2017-08-08 15:15:00+03	2017-08-08 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-08 15:20:00+03	2017-08-08 15:45:00+03
4564	PG0234	2017-08-14 15:15:00+03	2017-08-14 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-14 15:22:00+03	2017-08-14 15:47:00+03
4565	PG0233	2017-07-20 12:15:00+03	2017-07-20 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-20 12:20:00+03	2017-07-20 12:45:00+03
4566	PG0235	2017-08-08 19:50:00+03	2017-08-08 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-08 19:52:00+03	2017-08-08 20:17:00+03
4567	PG0235	2017-08-14 19:50:00+03	2017-08-14 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-14 19:54:00+03	2017-08-14 20:19:00+03
4568	PG0235	2017-07-24 19:50:00+03	2017-07-24 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-24 19:52:00+03	2017-07-24 20:17:00+03
4569	PG0234	2017-08-31 15:15:00+03	2017-08-31 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4570	PG0235	2017-08-06 19:50:00+03	2017-08-06 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-06 19:54:00+03	2017-08-06 20:19:00+03
4571	PG0234	2017-09-06 15:15:00+03	2017-09-06 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4572	PG0234	2017-08-06 15:15:00+03	2017-08-06 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-06 18:07:00+03	2017-08-06 18:32:00+03
4573	PG0233	2017-09-05 12:15:00+03	2017-09-05 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4574	PG0235	2017-07-22 19:50:00+03	2017-07-22 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-22 19:54:00+03	2017-07-22 20:19:00+03
4575	PG0233	2017-08-06 12:15:00+03	2017-08-06 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-06 12:19:00+03	2017-08-06 12:44:00+03
4576	PG0233	2017-07-17 12:15:00+03	2017-07-17 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-17 15:24:00+03	2017-07-17 15:49:00+03
4577	PG0233	2017-08-26 12:15:00+03	2017-08-26 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4578	PG0234	2017-08-26 15:15:00+03	2017-08-26 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4579	PG0234	2017-07-17 15:15:00+03	2017-07-17 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-17 15:17:00+03	2017-07-17 15:42:00+03
4580	PG0233	2017-07-31 12:15:00+03	2017-07-31 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-31 12:17:00+03	2017-07-31 12:42:00+03
4581	PG0235	2017-07-17 19:50:00+03	2017-07-17 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-17 19:51:00+03	2017-07-17 20:16:00+03
4582	PG0233	2017-07-27 12:15:00+03	2017-07-27 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-27 12:17:00+03	2017-07-27 12:42:00+03
4583	PG0234	2017-08-28 15:15:00+03	2017-08-28 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4584	PG0233	2017-09-06 12:15:00+03	2017-09-06 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4585	PG0235	2017-08-26 19:50:00+03	2017-08-26 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4586	PG0234	2017-07-27 15:15:00+03	2017-07-27 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-27 17:30:00+03	2017-07-27 17:55:00+03
4587	PG0235	2017-09-01 19:50:00+03	2017-09-01 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4588	PG0235	2017-07-27 19:50:00+03	2017-07-27 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-27 19:55:00+03	2017-07-27 20:20:00+03
4589	PG0233	2017-08-17 12:15:00+03	2017-08-17 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4590	PG0233	2017-09-12 12:15:00+03	2017-09-12 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4591	PG0234	2017-09-12 15:15:00+03	2017-09-12 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4592	PG0235	2017-09-12 19:50:00+03	2017-09-12 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4593	PG0233	2017-08-28 12:15:00+03	2017-08-28 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4594	PG0235	2017-08-17 19:50:00+03	2017-08-17 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4595	PG0234	2017-08-17 15:15:00+03	2017-08-17 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4596	PG0233	2017-08-04 12:15:00+03	2017-08-04 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-04 12:18:00+03	2017-08-04 12:43:00+03
4597	PG0235	2017-07-29 19:50:00+03	2017-07-29 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-29 19:52:00+03	2017-07-29 20:17:00+03
4598	PG0234	2017-07-29 15:15:00+03	2017-07-29 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-29 15:18:00+03	2017-07-29 15:43:00+03
4599	PG0233	2017-07-29 12:15:00+03	2017-07-29 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-29 12:18:00+03	2017-07-29 12:43:00+03
4600	PG0235	2017-07-18 19:50:00+03	2017-07-18 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-18 19:53:00+03	2017-07-18 20:18:00+03
4601	PG0234	2017-07-18 15:15:00+03	2017-07-18 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-18 15:18:00+03	2017-07-18 15:43:00+03
4602	PG0233	2017-07-24 12:15:00+03	2017-07-24 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-24 12:18:00+03	2017-07-24 12:43:00+03
4603	PG0233	2017-07-18 12:15:00+03	2017-07-18 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-18 12:19:00+03	2017-07-18 12:44:00+03
4604	PG0234	2017-08-20 15:15:00+03	2017-08-20 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4605	PG0233	2017-08-09 12:15:00+03	2017-08-09 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-09 12:17:00+03	2017-08-09 12:42:00+03
4606	PG0234	2017-08-09 15:15:00+03	2017-08-09 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-09 15:18:00+03	2017-08-09 15:43:00+03
4607	PG0235	2017-08-09 19:50:00+03	2017-08-09 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-09 19:55:00+03	2017-08-09 20:20:00+03
4608	PG0235	2017-08-18 19:50:00+03	2017-08-18 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4609	PG0235	2017-08-27 19:50:00+03	2017-08-27 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4610	PG0234	2017-08-18 15:15:00+03	2017-08-18 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4611	PG0233	2017-08-02 12:15:00+03	2017-08-02 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-02 12:15:00+03	2017-08-02 12:40:00+03
4612	PG0233	2017-09-01 12:15:00+03	2017-09-01 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4613	PG0233	2017-07-26 12:15:00+03	2017-07-26 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-26 12:15:00+03	2017-07-26 12:40:00+03
4614	PG0235	2017-08-01 19:50:00+03	2017-08-01 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-01 19:54:00+03	2017-08-01 20:19:00+03
4615	PG0235	2017-07-23 19:50:00+03	2017-07-23 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-23 19:54:00+03	2017-07-23 20:19:00+03
4616	PG0234	2017-07-23 15:15:00+03	2017-07-23 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-23 15:17:00+03	2017-07-23 15:42:00+03
4617	PG0234	2017-08-01 15:15:00+03	2017-08-01 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-01 15:15:00+03	2017-08-01 15:40:00+03
4618	PG0233	2017-08-01 12:15:00+03	2017-08-01 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-01 12:17:00+03	2017-08-01 12:43:00+03
4619	PG0234	2017-07-24 15:15:00+03	2017-07-24 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-24 15:19:00+03	2017-07-24 15:44:00+03
4620	PG0235	2017-08-20 19:50:00+03	2017-08-20 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4621	PG0233	2017-08-13 12:15:00+03	2017-08-13 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-13 12:19:00+03	2017-08-13 12:44:00+03
4622	PG0234	2017-08-27 15:15:00+03	2017-08-27 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4623	PG0233	2017-08-18 12:15:00+03	2017-08-18 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4624	PG0234	2017-09-01 15:15:00+03	2017-09-01 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4625	PG0233	2017-07-22 12:15:00+03	2017-07-22 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-22 12:16:00+03	2017-07-22 12:40:00+03
4626	PG0233	2017-08-27 12:15:00+03	2017-08-27 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4627	PG0235	2017-08-22 19:50:00+03	2017-08-22 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4628	PG0234	2017-08-22 15:15:00+03	2017-08-22 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4629	PG0235	2017-09-10 19:50:00+03	2017-09-10 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4630	PG0233	2017-08-22 12:15:00+03	2017-08-22 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4631	PG0233	2017-09-11 12:15:00+03	2017-09-11 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4632	PG0234	2017-09-10 15:15:00+03	2017-09-10 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4633	PG0234	2017-09-11 15:15:00+03	2017-09-11 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4634	PG0233	2017-08-23 12:15:00+03	2017-08-23 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4635	PG0235	2017-08-25 19:50:00+03	2017-08-25 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4636	PG0233	2017-09-10 12:15:00+03	2017-09-10 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4637	PG0233	2017-08-29 12:15:00+03	2017-08-29 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4638	PG0235	2017-09-04 19:50:00+03	2017-09-04 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4639	PG0235	2017-09-11 19:50:00+03	2017-09-11 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4640	PG0233	2017-08-15 12:15:00+03	2017-08-15 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-15 15:06:00+03	2017-08-15 15:31:00+03
4641	PG0234	2017-07-26 15:15:00+03	2017-07-26 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-26 15:18:00+03	2017-07-26 15:43:00+03
4642	PG0234	2017-08-15 15:15:00+03	2017-08-15 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-15 15:17:00+03	2017-08-15 15:41:00+03
4643	PG0234	2017-07-22 15:15:00+03	2017-07-22 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-22 15:19:00+03	2017-07-22 15:44:00+03
4644	PG0235	2017-09-09 19:50:00+03	2017-09-09 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4645	PG0234	2017-08-07 15:15:00+03	2017-08-07 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-07 15:15:00+03	2017-08-07 15:40:00+03
4646	PG0235	2017-08-15 19:50:00+03	2017-08-15 20:15:00+03	VKO	BZK	On Time	SU9	\N	\N
4647	PG0234	2017-09-04 15:15:00+03	2017-09-04 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4648	PG0234	2017-09-09 15:15:00+03	2017-09-09 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4649	PG0234	2017-08-23 15:15:00+03	2017-08-23 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4650	PG0235	2017-07-19 19:50:00+03	2017-07-19 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-19 19:54:00+03	2017-07-19 20:19:00+03
4651	PG0235	2017-09-08 19:50:00+03	2017-09-08 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4652	PG0235	2017-08-05 19:50:00+03	2017-08-05 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-05 19:52:00+03	2017-08-05 20:17:00+03
4653	PG0234	2017-08-05 15:15:00+03	2017-08-05 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-05 15:16:00+03	2017-08-05 15:41:00+03
4654	PG0233	2017-08-05 12:15:00+03	2017-08-05 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-05 12:17:00+03	2017-08-05 12:42:00+03
4655	PG0234	2017-09-08 15:15:00+03	2017-09-08 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4656	PG0233	2017-09-02 12:15:00+03	2017-09-02 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4657	PG0233	2017-09-08 12:15:00+03	2017-09-08 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4658	PG0234	2017-07-19 15:15:00+03	2017-07-19 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-19 15:16:00+03	2017-07-19 15:41:00+03
4659	PG0235	2017-08-23 19:50:00+03	2017-08-23 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4660	PG0235	2017-08-04 19:50:00+03	2017-08-04 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-04 19:52:00+03	2017-08-04 20:17:00+03
4661	PG0233	2017-07-21 12:15:00+03	2017-07-21 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-21 12:17:00+03	2017-07-21 12:42:00+03
4662	PG0234	2017-09-02 15:15:00+03	2017-09-02 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4663	PG0235	2017-09-02 19:50:00+03	2017-09-02 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4664	PG0234	2017-08-29 15:15:00+03	2017-08-29 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4665	PG0235	2017-08-10 19:50:00+03	2017-08-10 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-10 19:52:00+03	2017-08-10 20:17:00+03
4666	PG0234	2017-08-25 15:15:00+03	2017-08-25 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4667	PG0234	2017-09-14 15:15:00+03	2017-09-14 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4668	PG0233	2017-07-28 12:15:00+03	2017-07-28 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-28 12:19:00+03	2017-07-28 12:44:00+03
4669	PG0235	2017-08-29 19:50:00+03	2017-08-29 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4670	PG0234	2017-07-28 15:15:00+03	2017-07-28 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-28 15:17:00+03	2017-07-28 15:42:00+03
4671	PG0235	2017-07-30 19:50:00+03	2017-07-30 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-30 19:54:00+03	2017-07-30 20:19:00+03
4672	PG0235	2017-08-13 19:50:00+03	2017-08-13 20:15:00+03	VKO	BZK	Arrived	SU9	2017-08-13 19:54:00+03	2017-08-13 20:19:00+03
4673	PG0233	2017-07-25 12:15:00+03	2017-07-25 12:40:00+03	VKO	BZK	Arrived	SU9	2017-07-25 12:18:00+03	2017-07-25 12:43:00+03
4674	PG0234	2017-07-25 15:15:00+03	2017-07-25 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-25 15:17:00+03	2017-07-25 15:42:00+03
4675	PG0235	2017-07-25 19:50:00+03	2017-07-25 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-25 19:53:00+03	2017-07-25 20:18:00+03
4676	PG0235	2017-07-28 19:50:00+03	2017-07-28 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-28 19:52:00+03	2017-07-28 20:16:00+03
4677	PG0233	2017-08-21 12:15:00+03	2017-08-21 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4678	PG0235	2017-09-13 19:50:00+03	2017-09-13 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4679	PG0233	2017-08-07 12:15:00+03	2017-08-07 12:40:00+03	VKO	BZK	Arrived	SU9	2017-08-07 12:18:00+03	2017-08-07 12:43:00+03
4680	PG0233	2017-09-04 12:15:00+03	2017-09-04 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4681	PG0233	2017-09-14 12:15:00+03	2017-09-14 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4682	PG0234	2017-08-10 15:15:00+03	2017-08-10 15:40:00+03	VKO	BZK	Arrived	SU9	2017-08-10 15:18:00+03	2017-08-10 15:43:00+03
4683	PG0234	2017-08-21 15:15:00+03	2017-08-21 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4684	PG0235	2017-08-21 19:50:00+03	2017-08-21 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4685	PG0234	2017-07-21 15:15:00+03	2017-07-21 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-21 15:18:00+03	2017-07-21 15:43:00+03
4686	PG0235	2017-07-16 19:50:00+03	2017-07-16 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-16 19:56:00+03	2017-07-16 20:21:00+03
4687	PG0235	2017-08-24 19:50:00+03	2017-08-24 20:15:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4688	PG0234	2017-08-24 15:15:00+03	2017-08-24 15:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4689	PG0233	2017-08-24 12:15:00+03	2017-08-24 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4690	PG0234	2017-07-16 15:15:00+03	2017-07-16 15:40:00+03	VKO	BZK	Arrived	SU9	2017-07-16 15:19:00+03	2017-07-16 15:44:00+03
4691	PG0233	2017-09-09 12:15:00+03	2017-09-09 12:40:00+03	VKO	BZK	Scheduled	SU9	\N	\N
4692	PG0235	2017-07-21 19:50:00+03	2017-07-21 20:15:00+03	VKO	BZK	Arrived	SU9	2017-07-21 19:54:00+03	2017-07-21 20:19:00+03
4693	PG0561	2017-07-17 12:30:00+03	2017-07-17 14:15:00+03	VKO	AER	Arrived	763	2017-07-17 12:35:00+03	2017-07-17 14:18:00+03
4694	PG0561	2017-09-14 12:30:00+03	2017-09-14 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4695	PG0561	2017-07-16 12:30:00+03	2017-07-16 14:15:00+03	VKO	AER	Arrived	763	2017-07-16 12:32:00+03	2017-07-16 14:18:00+03
4696	PG0561	2017-08-10 12:30:00+03	2017-08-10 14:15:00+03	VKO	AER	Arrived	763	2017-08-10 12:35:00+03	2017-08-10 14:20:00+03
4697	PG0561	2017-08-25 12:30:00+03	2017-08-25 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4698	PG0561	2017-08-30 12:30:00+03	2017-08-30 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4699	PG0561	2017-08-20 12:30:00+03	2017-08-20 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4700	PG0561	2017-08-19 12:30:00+03	2017-08-19 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4701	PG0561	2017-08-15 12:30:00+03	2017-08-15 14:15:00+03	VKO	AER	Arrived	763	2017-08-15 12:32:00+03	2017-08-15 14:17:00+03
4702	PG0561	2017-08-28 12:30:00+03	2017-08-28 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4703	PG0561	2017-07-20 12:30:00+03	2017-07-20 14:15:00+03	VKO	AER	Arrived	763	2017-07-20 12:32:00+03	2017-07-20 14:16:00+03
4704	PG0561	2017-09-13 12:30:00+03	2017-09-13 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4705	PG0561	2017-07-18 12:30:00+03	2017-07-18 14:15:00+03	VKO	AER	Arrived	763	2017-07-18 15:18:00+03	2017-07-18 17:05:00+03
4706	PG0561	2017-08-04 12:30:00+03	2017-08-04 14:15:00+03	VKO	AER	Arrived	763	2017-08-04 12:33:00+03	2017-08-04 14:19:00+03
4707	PG0561	2017-09-11 12:30:00+03	2017-09-11 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4708	PG0561	2017-08-21 12:30:00+03	2017-08-21 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4709	PG0561	2017-07-28 12:30:00+03	2017-07-28 14:15:00+03	VKO	AER	Arrived	763	2017-07-28 12:34:00+03	2017-07-28 14:20:00+03
4710	PG0561	2017-07-24 12:30:00+03	2017-07-24 14:15:00+03	VKO	AER	Arrived	763	2017-07-24 12:32:00+03	2017-07-24 14:17:00+03
4711	PG0561	2017-09-03 12:30:00+03	2017-09-03 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4712	PG0561	2017-08-07 12:30:00+03	2017-08-07 14:15:00+03	VKO	AER	Arrived	763	2017-08-07 12:34:00+03	2017-08-07 14:18:00+03
4713	PG0561	2017-08-05 12:30:00+03	2017-08-05 14:15:00+03	VKO	AER	Arrived	763	2017-08-05 12:33:00+03	2017-08-05 14:18:00+03
4714	PG0561	2017-07-26 12:30:00+03	2017-07-26 14:15:00+03	VKO	AER	Arrived	763	2017-07-26 12:33:00+03	2017-07-26 14:20:00+03
4715	PG0561	2017-08-09 12:30:00+03	2017-08-09 14:15:00+03	VKO	AER	Arrived	763	2017-08-09 12:33:00+03	2017-08-09 14:19:00+03
4716	PG0561	2017-08-24 12:30:00+03	2017-08-24 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4717	PG0561	2017-07-23 12:30:00+03	2017-07-23 14:15:00+03	VKO	AER	Arrived	763	2017-07-23 12:33:00+03	2017-07-23 14:20:00+03
4718	PG0561	2017-07-19 12:30:00+03	2017-07-19 14:15:00+03	VKO	AER	Arrived	763	2017-07-19 12:32:00+03	2017-07-19 14:15:00+03
4719	PG0561	2017-08-29 12:30:00+03	2017-08-29 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4720	PG0561	2017-07-22 12:30:00+03	2017-07-22 14:15:00+03	VKO	AER	Arrived	763	2017-07-22 12:34:00+03	2017-07-22 14:18:00+03
4721	PG0561	2017-08-06 12:30:00+03	2017-08-06 14:15:00+03	VKO	AER	Arrived	763	2017-08-06 12:34:00+03	2017-08-06 14:19:00+03
4722	PG0561	2017-08-22 12:30:00+03	2017-08-22 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4723	PG0561	2017-08-01 12:30:00+03	2017-08-01 14:15:00+03	VKO	AER	Arrived	763	2017-08-01 12:34:00+03	2017-08-01 14:20:00+03
4724	PG0561	2017-07-27 12:30:00+03	2017-07-27 14:15:00+03	VKO	AER	Arrived	763	2017-07-27 12:32:00+03	2017-07-27 14:17:00+03
4725	PG0561	2017-08-03 12:30:00+03	2017-08-03 14:15:00+03	VKO	AER	Arrived	763	2017-08-03 12:33:00+03	2017-08-03 14:17:00+03
4726	PG0561	2017-09-02 12:30:00+03	2017-09-02 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4727	PG0561	2017-07-30 12:30:00+03	2017-07-30 14:15:00+03	VKO	AER	Arrived	763	2017-07-30 12:35:00+03	2017-07-30 14:20:00+03
4728	PG0561	2017-08-18 12:30:00+03	2017-08-18 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4729	PG0561	2017-08-02 12:30:00+03	2017-08-02 14:15:00+03	VKO	AER	Arrived	763	2017-08-02 12:32:00+03	2017-08-02 14:18:00+03
4730	PG0561	2017-08-11 12:30:00+03	2017-08-11 14:15:00+03	VKO	AER	Arrived	763	2017-08-11 12:33:00+03	2017-08-11 14:17:00+03
4731	PG0561	2017-08-26 12:30:00+03	2017-08-26 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4732	PG0561	2017-08-13 12:30:00+03	2017-08-13 14:15:00+03	VKO	AER	Arrived	763	2017-08-13 12:33:00+03	2017-08-13 14:16:00+03
4733	PG0561	2017-09-06 12:30:00+03	2017-09-06 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4734	PG0561	2017-08-16 12:30:00+03	2017-08-16 14:15:00+03	VKO	AER	On Time	763	\N	\N
4735	PG0561	2017-08-31 12:30:00+03	2017-08-31 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4736	PG0561	2017-08-14 12:30:00+03	2017-08-14 14:15:00+03	VKO	AER	Arrived	763	2017-08-14 12:36:00+03	2017-08-14 14:20:00+03
4737	PG0561	2017-07-21 12:30:00+03	2017-07-21 14:15:00+03	VKO	AER	Arrived	763	2017-07-21 12:32:00+03	2017-07-21 14:17:00+03
4738	PG0561	2017-09-12 12:30:00+03	2017-09-12 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4740	PG0561	2017-08-17 12:30:00+03	2017-08-17 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4741	PG0561	2017-08-08 12:30:00+03	2017-08-08 14:15:00+03	VKO	AER	Arrived	763	2017-08-08 12:33:00+03	2017-08-08 14:19:00+03
4742	PG0561	2017-07-31 12:30:00+03	2017-07-31 14:15:00+03	VKO	AER	Arrived	763	2017-07-31 12:32:00+03	2017-07-31 14:18:00+03
4743	PG0561	2017-08-23 12:30:00+03	2017-08-23 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4744	PG0561	2017-09-09 12:30:00+03	2017-09-09 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4745	PG0561	2017-08-27 12:30:00+03	2017-08-27 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4746	PG0561	2017-07-25 12:30:00+03	2017-07-25 14:15:00+03	VKO	AER	Arrived	763	2017-07-25 12:32:00+03	2017-07-25 14:15:00+03
4747	PG0561	2017-09-08 12:30:00+03	2017-09-08 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4748	PG0561	2017-09-10 12:30:00+03	2017-09-10 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4749	PG0561	2017-08-12 12:30:00+03	2017-08-12 14:15:00+03	VKO	AER	Arrived	763	2017-08-12 12:34:00+03	2017-08-12 14:20:00+03
4750	PG0561	2017-09-01 12:30:00+03	2017-09-01 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4751	PG0561	2017-07-29 12:30:00+03	2017-07-29 14:15:00+03	VKO	AER	Arrived	763	2017-07-29 12:33:00+03	2017-07-29 14:17:00+03
4752	PG0561	2017-09-07 12:30:00+03	2017-09-07 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4753	PG0561	2017-09-04 12:30:00+03	2017-09-04 14:15:00+03	VKO	AER	Scheduled	763	\N	\N
4754	PG0669	2017-09-02 16:15:00+03	2017-09-02 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4755	PG0669	2017-08-25 16:15:00+03	2017-08-25 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4756	PG0669	2017-08-19 16:15:00+03	2017-08-19 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4757	PG0669	2017-09-08 16:15:00+03	2017-09-08 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4758	PG0669	2017-07-27 16:15:00+03	2017-07-27 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-27 16:18:00+03	2017-07-27 18:47:00+03
4759	PG0669	2017-07-22 16:15:00+03	2017-07-22 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-22 16:22:00+03	2017-07-22 18:52:00+03
4760	PG0669	2017-08-27 16:15:00+03	2017-08-27 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4761	PG0669	2017-09-14 16:15:00+03	2017-09-14 18:45:00+03	VKO	KRO	Cancelled	CR2	\N	\N
4762	PG0669	2017-07-20 16:15:00+03	2017-07-20 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-20 16:17:00+03	2017-07-20 18:46:00+03
4763	PG0669	2017-09-04 16:15:00+03	2017-09-04 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4764	PG0669	2017-08-12 16:15:00+03	2017-08-12 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-12 16:20:00+03	2017-08-12 18:50:00+03
4765	PG0669	2017-09-06 16:15:00+03	2017-09-06 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4766	PG0669	2017-07-17 16:15:00+03	2017-07-17 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-17 16:20:00+03	2017-07-17 18:53:00+03
4767	PG0669	2017-08-09 16:15:00+03	2017-08-09 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-09 16:19:00+03	2017-08-09 18:48:00+03
4768	PG0669	2017-08-04 16:15:00+03	2017-08-04 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-04 16:18:00+03	2017-08-04 18:48:00+03
4769	PG0669	2017-08-16 16:15:00+03	2017-08-16 18:45:00+03	VKO	KRO	On Time	CR2	\N	\N
4770	PG0669	2017-07-31 16:15:00+03	2017-07-31 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-31 16:17:00+03	2017-07-31 18:47:00+03
4771	PG0669	2017-08-14 16:15:00+03	2017-08-14 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-14 19:17:00+03	2017-08-14 21:47:00+03
4772	PG0669	2017-07-23 16:15:00+03	2017-07-23 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-23 16:17:00+03	2017-07-23 18:50:00+03
4773	PG0669	2017-08-24 16:15:00+03	2017-08-24 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4774	PG0669	2017-08-21 16:15:00+03	2017-08-21 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4775	PG0669	2017-08-26 16:15:00+03	2017-08-26 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4776	PG0669	2017-08-23 16:15:00+03	2017-08-23 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4777	PG0669	2017-09-03 16:15:00+03	2017-09-03 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4778	PG0669	2017-07-30 16:15:00+03	2017-07-30 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-30 19:22:00+03	2017-07-30 21:51:00+03
4779	PG0669	2017-09-05 16:15:00+03	2017-09-05 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4780	PG0669	2017-08-17 16:15:00+03	2017-08-17 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4781	PG0669	2017-07-19 16:15:00+03	2017-07-19 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-19 20:23:00+03	2017-07-19 22:55:00+03
4782	PG0669	2017-07-18 16:15:00+03	2017-07-18 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-18 16:16:00+03	2017-07-18 18:46:00+03
4783	PG0669	2017-08-29 16:15:00+03	2017-08-29 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4784	PG0669	2017-07-21 16:15:00+03	2017-07-21 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-21 16:19:00+03	2017-07-21 18:49:00+03
4785	PG0669	2017-08-22 16:15:00+03	2017-08-22 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4786	PG0669	2017-09-09 16:15:00+03	2017-09-09 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4787	PG0669	2017-08-03 16:15:00+03	2017-08-03 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-03 16:19:00+03	2017-08-03 18:50:00+03
4788	PG0669	2017-07-25 16:15:00+03	2017-07-25 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-25 16:19:00+03	2017-07-25 18:48:00+03
4789	PG0669	2017-09-12 16:15:00+03	2017-09-12 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4790	PG0669	2017-07-29 16:15:00+03	2017-07-29 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-29 16:19:00+03	2017-07-29 18:50:00+03
4791	PG0669	2017-08-10 16:15:00+03	2017-08-10 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-10 16:19:00+03	2017-08-10 18:48:00+03
4792	PG0669	2017-08-01 16:15:00+03	2017-08-01 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-01 16:18:00+03	2017-08-01 18:48:00+03
4793	PG0669	2017-08-13 16:15:00+03	2017-08-13 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-13 16:20:00+03	2017-08-13 18:51:00+03
4794	PG0669	2017-08-30 16:15:00+03	2017-08-30 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4795	PG0669	2017-08-02 16:15:00+03	2017-08-02 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-02 16:16:00+03	2017-08-02 18:45:00+03
4796	PG0669	2017-08-18 16:15:00+03	2017-08-18 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4797	PG0669	2017-08-06 16:15:00+03	2017-08-06 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-06 16:19:00+03	2017-08-06 18:51:00+03
4798	PG0669	2017-08-11 16:15:00+03	2017-08-11 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-11 16:19:00+03	2017-08-11 18:47:00+03
4799	PG0669	2017-08-20 16:15:00+03	2017-08-20 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4800	PG0669	2017-08-05 16:15:00+03	2017-08-05 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-05 16:17:00+03	2017-08-05 18:44:00+03
4801	PG0669	2017-09-10 16:15:00+03	2017-09-10 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4802	PG0669	2017-07-26 16:15:00+03	2017-07-26 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-26 16:23:00+03	2017-07-26 18:53:00+03
4803	PG0669	2017-07-24 16:15:00+03	2017-07-24 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-24 16:20:00+03	2017-07-24 18:48:00+03
4804	PG0669	2017-08-31 16:15:00+03	2017-08-31 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4805	PG0669	2017-08-08 16:15:00+03	2017-08-08 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-08 16:16:00+03	2017-08-08 18:47:00+03
4806	PG0669	2017-09-01 16:15:00+03	2017-09-01 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4807	PG0669	2017-08-15 16:15:00+03	2017-08-15 18:45:00+03	VKO	KRO	Departed	CR2	2017-08-15 16:17:00+03	\N
4808	PG0669	2017-08-07 16:15:00+03	2017-08-07 18:45:00+03	VKO	KRO	Arrived	CR2	2017-08-07 16:18:00+03	2017-08-07 18:48:00+03
4809	PG0669	2017-07-16 16:15:00+03	2017-07-16 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-16 16:17:00+03	2017-07-16 18:50:00+03
4810	PG0669	2017-09-07 16:15:00+03	2017-09-07 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4811	PG0669	2017-09-13 16:15:00+03	2017-09-13 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4812	PG0669	2017-09-11 16:15:00+03	2017-09-11 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4813	PG0669	2017-08-28 16:15:00+03	2017-08-28 18:45:00+03	VKO	KRO	Scheduled	CR2	\N	\N
4814	PG0669	2017-07-28 16:15:00+03	2017-07-28 18:45:00+03	VKO	KRO	Arrived	CR2	2017-07-28 16:18:00+03	2017-07-28 18:47:00+03
4815	PG0146	2017-08-03 12:30:00+03	2017-08-03 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-03 12:33:00+03	2017-08-03 14:33:00+03
4816	PG0146	2017-08-11 12:30:00+03	2017-08-11 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-11 12:31:00+03	2017-08-11 14:32:00+03
4817	PG0146	2017-07-24 12:30:00+03	2017-07-24 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-24 15:59:00+03	2017-07-24 17:59:00+03
4818	PG0146	2017-09-08 12:30:00+03	2017-09-08 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4819	PG0146	2017-08-02 12:30:00+03	2017-08-02 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-02 12:32:00+03	2017-08-02 14:31:00+03
4820	PG0146	2017-07-27 12:30:00+03	2017-07-27 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-27 12:33:00+03	2017-07-27 14:35:00+03
4821	PG0146	2017-07-17 12:30:00+03	2017-07-17 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-17 12:33:00+03	2017-07-17 14:31:00+03
4822	PG0146	2017-07-16 12:30:00+03	2017-07-16 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-16 15:28:00+03	2017-07-16 17:28:00+03
4823	PG0146	2017-07-29 12:30:00+03	2017-07-29 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-29 12:33:00+03	2017-07-29 14:34:00+03
4824	PG0146	2017-08-08 12:30:00+03	2017-08-08 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-08 12:31:00+03	2017-08-08 14:31:00+03
4825	PG0146	2017-08-25 12:30:00+03	2017-08-25 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4826	PG0146	2017-09-09 12:30:00+03	2017-09-09 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4827	PG0146	2017-08-12 12:30:00+03	2017-08-12 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-12 12:36:00+03	2017-08-12 14:36:00+03
4828	PG0146	2017-08-24 12:30:00+03	2017-08-24 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4829	PG0146	2017-07-22 12:30:00+03	2017-07-22 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-22 12:34:00+03	2017-07-22 14:36:00+03
4830	PG0146	2017-08-04 12:30:00+03	2017-08-04 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-04 12:35:00+03	2017-08-04 14:35:00+03
4831	PG0146	2017-08-18 12:30:00+03	2017-08-18 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4832	PG0146	2017-08-26 12:30:00+03	2017-08-26 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4833	PG0146	2017-09-01 12:30:00+03	2017-09-01 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4834	PG0146	2017-08-30 12:30:00+03	2017-08-30 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4835	PG0146	2017-09-05 12:30:00+03	2017-09-05 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4836	PG0146	2017-09-13 12:30:00+03	2017-09-13 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4837	PG0146	2017-09-14 12:30:00+03	2017-09-14 14:30:00+03	VKO	OGZ	Cancelled	SU9	\N	\N
4838	PG0146	2017-09-03 12:30:00+03	2017-09-03 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4839	PG0146	2017-09-06 12:30:00+03	2017-09-06 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4840	PG0146	2017-07-23 12:30:00+03	2017-07-23 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-23 12:33:00+03	2017-07-23 14:34:00+03
4841	PG0146	2017-08-05 12:30:00+03	2017-08-05 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-05 12:32:00+03	2017-08-05 14:35:00+03
4842	PG0146	2017-08-01 12:30:00+03	2017-08-01 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-01 12:35:00+03	2017-08-01 14:35:00+03
4843	PG0146	2017-07-18 12:30:00+03	2017-07-18 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-18 12:32:00+03	2017-07-18 14:32:00+03
4844	PG0146	2017-08-20 12:30:00+03	2017-08-20 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4845	PG0146	2017-08-19 12:30:00+03	2017-08-19 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4846	PG0146	2017-08-21 12:30:00+03	2017-08-21 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4847	PG0146	2017-07-28 12:30:00+03	2017-07-28 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-28 12:34:00+03	2017-07-28 14:33:00+03
4848	PG0146	2017-07-26 12:30:00+03	2017-07-26 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-26 12:31:00+03	2017-07-26 14:30:00+03
4849	PG0146	2017-07-19 12:30:00+03	2017-07-19 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-19 12:32:00+03	2017-07-19 14:30:00+03
4850	PG0146	2017-08-28 12:30:00+03	2017-08-28 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4851	PG0146	2017-07-21 12:30:00+03	2017-07-21 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-21 12:35:00+03	2017-07-21 14:36:00+03
4852	PG0146	2017-08-17 12:30:00+03	2017-08-17 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4853	PG0146	2017-08-16 12:30:00+03	2017-08-16 14:30:00+03	VKO	OGZ	On Time	SU9	\N	\N
4854	PG0146	2017-07-30 12:30:00+03	2017-07-30 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-30 12:34:00+03	2017-07-30 14:34:00+03
4855	PG0146	2017-08-07 12:30:00+03	2017-08-07 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-07 12:33:00+03	2017-08-07 14:31:00+03
4856	PG0146	2017-08-14 12:30:00+03	2017-08-14 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-14 12:34:00+03	2017-08-14 14:34:00+03
4857	PG0146	2017-09-02 12:30:00+03	2017-09-02 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4858	PG0146	2017-07-25 12:30:00+03	2017-07-25 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-25 12:34:00+03	2017-07-25 14:32:00+03
4859	PG0146	2017-08-23 12:30:00+03	2017-08-23 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4860	PG0146	2017-08-10 12:30:00+03	2017-08-10 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-10 16:00:00+03	2017-08-10 18:01:00+03
4861	PG0146	2017-09-10 12:30:00+03	2017-09-10 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4862	PG0146	2017-08-22 12:30:00+03	2017-08-22 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4863	PG0146	2017-08-29 12:30:00+03	2017-08-29 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4864	PG0146	2017-08-27 12:30:00+03	2017-08-27 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4865	PG0146	2017-09-04 12:30:00+03	2017-09-04 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4866	PG0146	2017-08-13 12:30:00+03	2017-08-13 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-13 12:34:00+03	2017-08-13 14:33:00+03
4867	PG0146	2017-08-09 12:30:00+03	2017-08-09 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-09 12:30:00+03	2017-08-09 14:31:00+03
4868	PG0146	2017-08-06 12:30:00+03	2017-08-06 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-06 12:33:00+03	2017-08-06 14:30:00+03
4869	PG0146	2017-09-12 12:30:00+03	2017-09-12 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4870	PG0146	2017-07-31 12:30:00+03	2017-07-31 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-31 12:37:00+03	2017-07-31 14:37:00+03
4871	PG0146	2017-07-20 12:30:00+03	2017-07-20 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-07-20 12:32:00+03	2017-07-20 14:31:00+03
4872	PG0146	2017-09-11 12:30:00+03	2017-09-11 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4873	PG0146	2017-08-31 12:30:00+03	2017-08-31 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4874	PG0146	2017-09-07 12:30:00+03	2017-09-07 14:30:00+03	VKO	OGZ	Scheduled	SU9	\N	\N
4875	PG0146	2017-08-15 12:30:00+03	2017-08-15 14:30:00+03	VKO	OGZ	Arrived	SU9	2017-08-15 12:34:00+03	2017-08-15 14:32:00+03
4876	PG0358	2017-08-28 12:05:00+03	2017-08-28 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4877	PG0358	2017-08-12 12:05:00+03	2017-08-12 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-12 12:06:00+03	2017-08-12 12:50:00+03
4878	PG0358	2017-08-14 12:05:00+03	2017-08-14 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-14 12:07:00+03	2017-08-14 12:53:00+03
4879	PG0358	2017-08-04 12:05:00+03	2017-08-04 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-04 12:09:00+03	2017-08-04 12:53:00+03
4880	PG0358	2017-08-11 12:05:00+03	2017-08-11 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-11 12:09:00+03	2017-08-11 12:54:00+03
4881	PG0358	2017-08-22 12:05:00+03	2017-08-22 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4882	PG0358	2017-07-22 12:05:00+03	2017-07-22 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-22 12:06:00+03	2017-07-22 12:51:00+03
4883	PG0358	2017-08-20 12:05:00+03	2017-08-20 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4884	PG0358	2017-09-12 12:05:00+03	2017-09-12 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4885	PG0358	2017-08-17 12:05:00+03	2017-08-17 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4886	PG0358	2017-07-29 12:05:00+03	2017-07-29 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-29 12:07:00+03	2017-07-29 12:52:00+03
4887	PG0358	2017-08-01 12:05:00+03	2017-08-01 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-01 12:07:00+03	2017-08-01 12:51:00+03
4888	PG0358	2017-08-06 12:05:00+03	2017-08-06 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-06 12:08:00+03	2017-08-06 12:54:00+03
4889	PG0358	2017-08-05 12:05:00+03	2017-08-05 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-05 12:05:00+03	2017-08-05 12:50:00+03
4890	PG0358	2017-08-02 12:05:00+03	2017-08-02 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-02 12:08:00+03	2017-08-02 12:53:00+03
4891	PG0358	2017-07-25 12:05:00+03	2017-07-25 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-25 12:07:00+03	2017-07-25 12:52:00+03
4892	PG0358	2017-08-10 12:05:00+03	2017-08-10 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-10 12:09:00+03	2017-08-10 12:54:00+03
4893	PG0358	2017-08-03 12:05:00+03	2017-08-03 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-03 12:08:00+03	2017-08-03 12:54:00+03
4894	PG0358	2017-09-04 12:05:00+03	2017-09-04 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4895	PG0358	2017-09-07 12:05:00+03	2017-09-07 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4896	PG0358	2017-08-31 12:05:00+03	2017-08-31 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4897	PG0358	2017-08-15 12:05:00+03	2017-08-15 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-15 12:08:00+03	2017-08-15 12:53:00+03
4898	PG0358	2017-08-19 12:05:00+03	2017-08-19 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4899	PG0358	2017-09-09 12:05:00+03	2017-09-09 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4900	PG0358	2017-07-27 12:05:00+03	2017-07-27 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-27 12:11:00+03	2017-07-27 12:55:00+03
4901	PG0358	2017-09-13 12:05:00+03	2017-09-13 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4902	PG0358	2017-07-31 12:05:00+03	2017-07-31 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-31 12:06:00+03	2017-07-31 12:51:00+03
4903	PG0358	2017-07-30 12:05:00+03	2017-07-30 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-30 12:07:00+03	2017-07-30 12:52:00+03
4904	PG0358	2017-08-30 12:05:00+03	2017-08-30 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4905	PG0358	2017-07-23 12:05:00+03	2017-07-23 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-23 12:09:00+03	2017-07-23 12:54:00+03
4906	PG0358	2017-07-19 12:05:00+03	2017-07-19 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-19 12:06:00+03	2017-07-19 12:51:00+03
4907	PG0358	2017-08-24 12:05:00+03	2017-08-24 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4908	PG0358	2017-09-05 12:05:00+03	2017-09-05 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4909	PG0358	2017-09-14 12:05:00+03	2017-09-14 12:50:00+03	VKO	SKX	Cancelled	CR2	\N	\N
4910	PG0358	2017-09-03 12:05:00+03	2017-09-03 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4911	PG0358	2017-09-06 12:05:00+03	2017-09-06 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4912	PG0358	2017-07-21 12:05:00+03	2017-07-21 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-21 12:07:00+03	2017-07-21 12:52:00+03
4913	PG0358	2017-08-29 12:05:00+03	2017-08-29 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4914	PG0358	2017-07-20 12:05:00+03	2017-07-20 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-20 12:10:00+03	2017-07-20 12:55:00+03
4915	PG0358	2017-08-16 12:05:00+03	2017-08-16 12:50:00+03	VKO	SKX	On Time	CR2	\N	\N
4916	PG0358	2017-09-10 12:05:00+03	2017-09-10 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4917	PG0358	2017-08-27 12:05:00+03	2017-08-27 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4918	PG0358	2017-07-17 12:05:00+03	2017-07-17 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-17 12:09:00+03	2017-07-17 12:54:00+03
4919	PG0358	2017-08-08 12:05:00+03	2017-08-08 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-08 12:06:00+03	2017-08-08 12:51:00+03
4920	PG0358	2017-07-16 12:05:00+03	2017-07-16 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-16 12:08:00+03	2017-07-16 12:53:00+03
4921	PG0358	2017-09-08 12:05:00+03	2017-09-08 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4922	PG0358	2017-08-21 12:05:00+03	2017-08-21 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4923	PG0358	2017-07-26 12:05:00+03	2017-07-26 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-26 12:07:00+03	2017-07-26 12:51:00+03
4924	PG0358	2017-08-23 12:05:00+03	2017-08-23 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4925	PG0358	2017-08-18 12:05:00+03	2017-08-18 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4926	PG0358	2017-09-01 12:05:00+03	2017-09-01 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4927	PG0358	2017-07-28 12:05:00+03	2017-07-28 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-28 12:08:00+03	2017-07-28 12:53:00+03
4928	PG0358	2017-08-25 12:05:00+03	2017-08-25 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4929	PG0358	2017-08-07 12:05:00+03	2017-08-07 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-07 12:11:00+03	2017-08-07 12:56:00+03
4930	PG0358	2017-08-26 12:05:00+03	2017-08-26 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4931	PG0358	2017-07-24 12:05:00+03	2017-07-24 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-24 12:09:00+03	2017-07-24 12:54:00+03
4932	PG0358	2017-08-13 12:05:00+03	2017-08-13 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-13 12:09:00+03	2017-08-13 12:54:00+03
4933	PG0358	2017-09-11 12:05:00+03	2017-09-11 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4934	PG0358	2017-07-18 12:05:00+03	2017-07-18 12:50:00+03	VKO	SKX	Arrived	CR2	2017-07-18 12:09:00+03	2017-07-18 12:55:00+03
4935	PG0358	2017-09-02 12:05:00+03	2017-09-02 12:50:00+03	VKO	SKX	Scheduled	CR2	\N	\N
4936	PG0358	2017-08-09 12:05:00+03	2017-08-09 12:50:00+03	VKO	SKX	Arrived	CR2	2017-08-09 12:07:00+03	2017-08-09 12:53:00+03
4937	PG0469	2017-09-09 12:35:00+03	2017-09-09 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4938	PG0471	2017-09-07 18:40:00+03	2017-09-07 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4939	PG0468	2017-09-03 13:15:00+03	2017-09-03 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4940	PG0470	2017-09-07 10:20:00+03	2017-09-07 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4941	PG0469	2017-09-07 12:35:00+03	2017-09-07 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4942	PG0468	2017-09-07 13:15:00+03	2017-09-07 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4943	PG0469	2017-09-03 12:35:00+03	2017-09-03 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4944	PG0470	2017-09-03 10:20:00+03	2017-09-03 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4945	PG0471	2017-09-03 18:40:00+03	2017-09-03 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4946	PG0472	2017-09-03 18:30:00+03	2017-09-03 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
4947	PG0468	2017-08-07 13:15:00+03	2017-08-07 14:05:00+03	SVO	LED	Arrived	321	2017-08-07 13:16:00+03	2017-08-07 14:06:00+03
4948	PG0472	2017-08-17 18:30:00+03	2017-08-17 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
4949	PG0470	2017-09-09 10:20:00+03	2017-09-09 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4950	PG0469	2017-08-07 12:35:00+03	2017-08-07 13:25:00+03	SVO	LED	Arrived	321	2017-08-07 12:39:00+03	2017-08-07 13:28:00+03
4951	PG0470	2017-08-07 10:20:00+03	2017-08-07 11:10:00+03	SVO	LED	Arrived	321	2017-08-07 10:23:00+03	2017-08-07 11:12:00+03
4952	PG0471	2017-08-07 18:40:00+03	2017-08-07 19:30:00+03	SVO	LED	Arrived	321	2017-08-07 18:43:00+03	2017-08-07 19:34:00+03
4953	PG0472	2017-08-07 18:30:00+03	2017-08-07 19:20:00+03	SVO	LED	Arrived	321	2017-08-07 18:33:00+03	2017-08-07 19:23:00+03
4954	PG0471	2017-08-17 18:40:00+03	2017-08-17 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4955	PG0468	2017-07-19 13:15:00+03	2017-07-19 14:05:00+03	SVO	LED	Arrived	321	2017-07-19 13:19:00+03	2017-07-19 14:09:00+03
4956	PG0469	2017-07-19 12:35:00+03	2017-07-19 13:25:00+03	SVO	LED	Arrived	321	2017-07-19 12:40:00+03	2017-07-19 13:31:00+03
4957	PG0470	2017-07-19 10:20:00+03	2017-07-19 11:10:00+03	SVO	LED	Arrived	321	2017-07-19 10:23:00+03	2017-07-19 11:13:00+03
4958	PG0471	2017-07-19 18:40:00+03	2017-07-19 19:30:00+03	SVO	LED	Arrived	321	2017-07-19 18:47:00+03	2017-07-19 19:37:00+03
4959	PG0472	2017-07-19 18:30:00+03	2017-07-19 19:20:00+03	SVO	LED	Arrived	321	2017-07-19 18:32:00+03	2017-07-19 19:23:00+03
4960	PG0468	2017-07-30 13:15:00+03	2017-07-30 14:05:00+03	SVO	LED	Arrived	321	2017-07-30 13:16:00+03	2017-07-30 14:06:00+03
4961	PG0469	2017-07-30 12:35:00+03	2017-07-30 13:25:00+03	SVO	LED	Arrived	321	2017-07-30 12:38:00+03	2017-07-30 13:28:00+03
4962	PG0470	2017-07-30 10:20:00+03	2017-07-30 11:10:00+03	SVO	LED	Arrived	321	2017-07-30 10:23:00+03	2017-07-30 11:12:00+03
4963	PG0471	2017-07-30 18:40:00+03	2017-07-30 19:30:00+03	SVO	LED	Arrived	321	2017-07-30 18:43:00+03	2017-07-30 19:33:00+03
4964	PG0472	2017-07-30 18:30:00+03	2017-07-30 19:20:00+03	SVO	LED	Arrived	321	2017-07-30 18:33:00+03	2017-07-30 19:23:00+03
4965	PG0472	2017-08-23 18:30:00+03	2017-08-23 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
4966	PG0471	2017-08-23 18:40:00+03	2017-08-23 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4967	PG0470	2017-08-23 10:20:00+03	2017-08-23 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4968	PG0469	2017-08-23 12:35:00+03	2017-08-23 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4969	PG0468	2017-08-23 13:15:00+03	2017-08-23 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4970	PG0472	2017-08-21 18:30:00+03	2017-08-21 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
4971	PG0471	2017-08-21 18:40:00+03	2017-08-21 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4972	PG0470	2017-08-21 10:20:00+03	2017-08-21 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4973	PG0469	2017-08-21 12:35:00+03	2017-08-21 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4974	PG0468	2017-08-21 13:15:00+03	2017-08-21 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4975	PG0472	2017-08-15 18:30:00+03	2017-08-15 19:20:00+03	SVO	LED	On Time	321	\N	\N
4976	PG0471	2017-08-15 18:40:00+03	2017-08-15 19:30:00+03	SVO	LED	On Time	321	\N	\N
4977	PG0470	2017-08-15 10:20:00+03	2017-08-15 11:10:00+03	SVO	LED	Arrived	321	2017-08-15 10:22:00+03	2017-08-15 11:12:00+03
4978	PG0469	2017-08-15 12:35:00+03	2017-08-15 13:25:00+03	SVO	LED	Arrived	321	2017-08-15 12:39:00+03	2017-08-15 13:28:00+03
4979	PG0468	2017-08-15 13:15:00+03	2017-08-15 14:05:00+03	SVO	LED	Arrived	321	2017-08-15 13:17:00+03	2017-08-15 14:07:00+03
4980	PG0472	2017-08-06 18:30:00+03	2017-08-06 19:20:00+03	SVO	LED	Arrived	321	2017-08-06 18:32:00+03	2017-08-06 19:22:00+03
4981	PG0471	2017-08-06 18:40:00+03	2017-08-06 19:30:00+03	SVO	LED	Arrived	321	2017-08-06 18:43:00+03	2017-08-06 19:32:00+03
4982	PG0470	2017-08-06 10:20:00+03	2017-08-06 11:10:00+03	SVO	LED	Arrived	321	2017-08-06 10:23:00+03	2017-08-06 11:13:00+03
4983	PG0469	2017-08-06 12:35:00+03	2017-08-06 13:25:00+03	SVO	LED	Arrived	321	2017-08-06 12:38:00+03	2017-08-06 13:27:00+03
4984	PG0468	2017-08-06 13:15:00+03	2017-08-06 14:05:00+03	SVO	LED	Arrived	321	2017-08-06 13:22:00+03	2017-08-06 14:11:00+03
4985	PG0468	2017-09-13 13:15:00+03	2017-09-13 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4986	PG0468	2017-09-09 13:15:00+03	2017-09-09 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4987	PG0472	2017-07-29 18:30:00+03	2017-07-29 19:20:00+03	SVO	LED	Arrived	321	2017-07-29 18:33:00+03	2017-07-29 19:22:00+03
4988	PG0471	2017-07-29 18:40:00+03	2017-07-29 19:30:00+03	SVO	LED	Arrived	321	2017-07-29 18:45:00+03	2017-07-29 19:34:00+03
4989	PG0470	2017-07-29 10:20:00+03	2017-07-29 11:10:00+03	SVO	LED	Arrived	321	2017-07-29 10:20:00+03	2017-07-29 11:10:00+03
4990	PG0469	2017-07-29 12:35:00+03	2017-07-29 13:25:00+03	SVO	LED	Arrived	321	2017-07-29 12:35:00+03	2017-07-29 13:25:00+03
4991	PG0468	2017-07-29 13:15:00+03	2017-07-29 14:05:00+03	SVO	LED	Arrived	321	2017-07-29 13:19:00+03	2017-07-29 14:10:00+03
4992	PG0469	2017-09-13 12:35:00+03	2017-09-13 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4993	PG0470	2017-09-13 10:20:00+03	2017-09-13 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4994	PG0468	2017-08-19 13:15:00+03	2017-08-19 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
4995	PG0469	2017-08-19 12:35:00+03	2017-08-19 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
4996	PG0470	2017-08-19 10:20:00+03	2017-08-19 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
4997	PG0471	2017-08-19 18:40:00+03	2017-08-19 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
4998	PG0472	2017-08-19 18:30:00+03	2017-08-19 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
4999	PG0471	2017-09-13 18:40:00+03	2017-09-13 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5000	PG0472	2017-09-10 18:30:00+03	2017-09-10 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5001	PG0471	2017-09-10 18:40:00+03	2017-09-10 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5002	PG0468	2017-07-24 13:15:00+03	2017-07-24 14:05:00+03	SVO	LED	Arrived	321	2017-07-24 13:16:00+03	2017-07-24 14:07:00+03
5003	PG0469	2017-07-24 12:35:00+03	2017-07-24 13:25:00+03	SVO	LED	Arrived	321	2017-07-24 12:36:00+03	2017-07-24 13:26:00+03
5004	PG0470	2017-07-24 10:20:00+03	2017-07-24 11:10:00+03	SVO	LED	Arrived	321	2017-07-24 10:22:00+03	2017-07-24 11:12:00+03
5005	PG0471	2017-07-24 18:40:00+03	2017-07-24 19:30:00+03	SVO	LED	Arrived	321	2017-07-24 21:45:00+03	2017-07-24 22:35:00+03
5006	PG0472	2017-07-24 18:30:00+03	2017-07-24 19:20:00+03	SVO	LED	Arrived	321	2017-07-24 18:32:00+03	2017-07-24 19:22:00+03
5007	PG0472	2017-09-13 18:30:00+03	2017-09-13 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5008	PG0470	2017-09-10 10:20:00+03	2017-09-10 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5009	PG0469	2017-09-10 12:35:00+03	2017-09-10 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5010	PG0468	2017-09-10 13:15:00+03	2017-09-10 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5011	PG0470	2017-08-17 10:20:00+03	2017-08-17 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5012	PG0472	2017-09-05 18:30:00+03	2017-09-05 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5013	PG0471	2017-09-09 18:40:00+03	2017-09-09 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5014	PG0472	2017-07-23 18:30:00+03	2017-07-23 19:20:00+03	SVO	LED	Arrived	321	2017-07-23 18:32:00+03	2017-07-23 19:23:00+03
5015	PG0471	2017-07-23 18:40:00+03	2017-07-23 19:30:00+03	SVO	LED	Arrived	321	2017-07-23 18:43:00+03	2017-07-23 19:32:00+03
5016	PG0470	2017-07-23 10:20:00+03	2017-07-23 11:10:00+03	SVO	LED	Arrived	321	2017-07-23 10:23:00+03	2017-07-23 11:14:00+03
5017	PG0469	2017-07-23 12:35:00+03	2017-07-23 13:25:00+03	SVO	LED	Arrived	321	2017-07-23 12:38:00+03	2017-07-23 13:27:00+03
5018	PG0468	2017-07-23 13:15:00+03	2017-07-23 14:05:00+03	SVO	LED	Arrived	321	2017-07-23 13:18:00+03	2017-07-23 14:08:00+03
5019	PG0468	2017-08-12 13:15:00+03	2017-08-12 14:05:00+03	SVO	LED	Arrived	321	2017-08-12 13:18:00+03	2017-08-12 14:07:00+03
5020	PG0469	2017-08-12 12:35:00+03	2017-08-12 13:25:00+03	SVO	LED	Arrived	321	2017-08-12 12:36:00+03	2017-08-12 13:26:00+03
5021	PG0470	2017-08-12 10:20:00+03	2017-08-12 11:10:00+03	SVO	LED	Arrived	321	2017-08-12 10:21:00+03	2017-08-12 11:11:00+03
5022	PG0471	2017-08-12 18:40:00+03	2017-08-12 19:30:00+03	SVO	LED	Arrived	321	2017-08-12 18:44:00+03	2017-08-12 19:34:00+03
5023	PG0468	2017-08-28 13:15:00+03	2017-08-28 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5024	PG0469	2017-08-28 12:35:00+03	2017-08-28 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5025	PG0468	2017-08-08 13:15:00+03	2017-08-08 14:05:00+03	SVO	LED	Arrived	321	2017-08-08 13:15:00+03	2017-08-08 14:04:00+03
5026	PG0469	2017-08-08 12:35:00+03	2017-08-08 13:25:00+03	SVO	LED	Arrived	321	2017-08-08 12:37:00+03	2017-08-08 13:27:00+03
5027	PG0470	2017-08-08 10:20:00+03	2017-08-08 11:10:00+03	SVO	LED	Arrived	321	2017-08-08 10:23:00+03	2017-08-08 11:13:00+03
5028	PG0471	2017-08-08 18:40:00+03	2017-08-08 19:30:00+03	SVO	LED	Arrived	321	2017-08-08 18:42:00+03	2017-08-08 19:33:00+03
5029	PG0472	2017-08-08 18:30:00+03	2017-08-08 19:20:00+03	SVO	LED	Arrived	321	2017-08-08 18:34:00+03	2017-08-08 19:25:00+03
5030	PG0469	2017-08-17 12:35:00+03	2017-08-17 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5031	PG0472	2017-08-12 18:30:00+03	2017-08-12 19:20:00+03	SVO	LED	Arrived	321	2017-08-12 18:32:00+03	2017-08-12 19:22:00+03
5032	PG0470	2017-08-28 10:20:00+03	2017-08-28 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5033	PG0472	2017-07-18 18:30:00+03	2017-07-18 19:20:00+03	SVO	LED	Arrived	321	2017-07-18 18:33:00+03	2017-07-18 19:22:00+03
5034	PG0471	2017-07-18 18:40:00+03	2017-07-18 19:30:00+03	SVO	LED	Arrived	321	2017-07-18 18:42:00+03	2017-07-18 19:32:00+03
5035	PG0470	2017-07-18 10:20:00+03	2017-07-18 11:10:00+03	SVO	LED	Arrived	321	2017-07-18 10:22:00+03	2017-07-18 11:13:00+03
5036	PG0469	2017-07-18 12:35:00+03	2017-07-18 13:25:00+03	SVO	LED	Arrived	321	2017-07-18 12:39:00+03	2017-07-18 13:28:00+03
5037	PG0468	2017-07-18 13:15:00+03	2017-07-18 14:05:00+03	SVO	LED	Arrived	321	2017-07-18 13:19:00+03	2017-07-18 14:09:00+03
5038	PG0471	2017-08-28 18:40:00+03	2017-08-28 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5039	PG0472	2017-08-28 18:30:00+03	2017-08-28 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5040	PG0468	2017-08-16 13:15:00+03	2017-08-16 14:05:00+03	SVO	LED	On Time	321	\N	\N
5041	PG0469	2017-08-16 12:35:00+03	2017-08-16 13:25:00+03	SVO	LED	On Time	321	\N	\N
5042	PG0470	2017-08-16 10:20:00+03	2017-08-16 11:10:00+03	SVO	LED	Delayed	321	\N	\N
5043	PG0471	2017-08-16 18:40:00+03	2017-08-16 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5044	PG0472	2017-08-16 18:30:00+03	2017-08-16 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5045	PG0472	2017-09-09 18:30:00+03	2017-09-09 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5046	PG0472	2017-08-05 18:30:00+03	2017-08-05 19:20:00+03	SVO	LED	Arrived	321	2017-08-05 18:30:00+03	2017-08-05 19:20:00+03
5047	PG0471	2017-08-05 18:40:00+03	2017-08-05 19:30:00+03	SVO	LED	Arrived	321	2017-08-05 18:41:00+03	2017-08-05 19:31:00+03
5048	PG0470	2017-08-05 10:20:00+03	2017-08-05 11:10:00+03	SVO	LED	Arrived	321	2017-08-05 10:24:00+03	2017-08-05 11:14:00+03
5049	PG0469	2017-08-05 12:35:00+03	2017-08-05 13:25:00+03	SVO	LED	Arrived	321	2017-08-05 15:38:00+03	2017-08-05 16:27:00+03
5050	PG0468	2017-08-05 13:15:00+03	2017-08-05 14:05:00+03	SVO	LED	Arrived	321	2017-08-05 13:18:00+03	2017-08-05 14:08:00+03
5051	PG0468	2017-07-31 13:15:00+03	2017-07-31 14:05:00+03	SVO	LED	Arrived	321	2017-07-31 13:16:00+03	2017-07-31 14:06:00+03
5052	PG0469	2017-07-31 12:35:00+03	2017-07-31 13:25:00+03	SVO	LED	Arrived	321	2017-07-31 15:58:00+03	2017-07-31 16:48:00+03
5053	PG0470	2017-07-31 10:20:00+03	2017-07-31 11:10:00+03	SVO	LED	Arrived	321	2017-07-31 10:26:00+03	2017-07-31 11:16:00+03
5054	PG0472	2017-09-02 18:30:00+03	2017-09-02 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5055	PG0471	2017-09-02 18:40:00+03	2017-09-02 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5056	PG0470	2017-09-02 10:20:00+03	2017-09-02 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5057	PG0471	2017-07-31 18:40:00+03	2017-07-31 19:30:00+03	SVO	LED	Arrived	321	2017-07-31 18:45:00+03	2017-07-31 19:36:00+03
5058	PG0469	2017-09-02 12:35:00+03	2017-09-02 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5059	PG0468	2017-09-02 13:15:00+03	2017-09-02 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5060	PG0472	2017-07-31 18:30:00+03	2017-07-31 19:20:00+03	SVO	LED	Arrived	321	2017-07-31 18:31:00+03	2017-07-31 19:21:00+03
5061	PG0468	2017-08-17 13:15:00+03	2017-08-17 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5062	PG0472	2017-07-28 18:30:00+03	2017-07-28 19:20:00+03	SVO	LED	Arrived	321	2017-07-28 18:33:00+03	2017-07-28 19:23:00+03
5063	PG0471	2017-07-28 18:40:00+03	2017-07-28 19:30:00+03	SVO	LED	Arrived	321	2017-07-28 18:45:00+03	2017-07-28 19:36:00+03
5064	PG0470	2017-07-28 10:20:00+03	2017-07-28 11:10:00+03	SVO	LED	Arrived	321	2017-07-28 10:25:00+03	2017-07-28 11:15:00+03
5065	PG0469	2017-07-28 12:35:00+03	2017-07-28 13:25:00+03	SVO	LED	Arrived	321	2017-07-28 12:37:00+03	2017-07-28 13:27:00+03
5066	PG0468	2017-07-28 13:15:00+03	2017-07-28 14:05:00+03	SVO	LED	Arrived	321	2017-07-28 13:18:00+03	2017-07-28 14:08:00+03
5067	PG0468	2017-09-08 13:15:00+03	2017-09-08 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5068	PG0469	2017-09-08 12:35:00+03	2017-09-08 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5069	PG0470	2017-09-08 10:20:00+03	2017-09-08 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5070	PG0471	2017-09-08 18:40:00+03	2017-09-08 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5071	PG0472	2017-09-08 18:30:00+03	2017-09-08 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5072	PG0468	2017-07-20 13:15:00+03	2017-07-20 14:05:00+03	SVO	LED	Arrived	321	2017-07-20 13:16:00+03	2017-07-20 14:06:00+03
5073	PG0469	2017-07-20 12:35:00+03	2017-07-20 13:25:00+03	SVO	LED	Arrived	321	2017-07-20 16:02:00+03	2017-07-20 16:52:00+03
5074	PG0470	2017-07-20 10:20:00+03	2017-07-20 11:10:00+03	SVO	LED	Arrived	321	2017-07-20 10:23:00+03	2017-07-20 11:13:00+03
5075	PG0471	2017-07-20 18:40:00+03	2017-07-20 19:30:00+03	SVO	LED	Arrived	321	2017-07-20 18:41:00+03	2017-07-20 19:32:00+03
5076	PG0472	2017-07-20 18:30:00+03	2017-07-20 19:20:00+03	SVO	LED	Arrived	321	2017-07-20 18:34:00+03	2017-07-20 19:24:00+03
5077	PG0468	2017-09-04 13:15:00+03	2017-09-04 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5078	PG0469	2017-09-04 12:35:00+03	2017-09-04 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5079	PG0470	2017-09-04 10:20:00+03	2017-09-04 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5080	PG0471	2017-09-04 18:40:00+03	2017-09-04 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5081	PG0472	2017-09-04 18:30:00+03	2017-09-04 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5082	PG0472	2017-08-18 18:30:00+03	2017-08-18 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5083	PG0471	2017-08-18 18:40:00+03	2017-08-18 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5084	PG0470	2017-08-18 10:20:00+03	2017-08-18 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5085	PG0469	2017-08-18 12:35:00+03	2017-08-18 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5086	PG0468	2017-08-09 13:15:00+03	2017-08-09 14:05:00+03	SVO	LED	Arrived	321	2017-08-09 13:15:00+03	2017-08-09 14:05:00+03
5087	PG0469	2017-08-09 12:35:00+03	2017-08-09 13:25:00+03	SVO	LED	Arrived	321	2017-08-09 12:37:00+03	2017-08-09 13:27:00+03
5088	PG0470	2017-08-09 10:20:00+03	2017-08-09 11:10:00+03	SVO	LED	Arrived	321	2017-08-09 10:22:00+03	2017-08-09 11:13:00+03
5089	PG0471	2017-08-09 18:40:00+03	2017-08-09 19:30:00+03	SVO	LED	Arrived	321	2017-08-09 18:42:00+03	2017-08-09 19:32:00+03
5090	PG0472	2017-08-09 18:30:00+03	2017-08-09 19:20:00+03	SVO	LED	Arrived	321	2017-08-09 21:57:00+03	2017-08-09 22:47:00+03
5091	PG0468	2017-08-18 13:15:00+03	2017-08-18 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5092	PG0472	2017-08-29 18:30:00+03	2017-08-29 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5093	PG0468	2017-08-30 13:15:00+03	2017-08-30 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5094	PG0471	2017-08-29 18:40:00+03	2017-08-29 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5095	PG0469	2017-08-30 12:35:00+03	2017-08-30 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5096	PG0470	2017-08-30 10:20:00+03	2017-08-30 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5097	PG0471	2017-08-30 18:40:00+03	2017-08-30 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5098	PG0470	2017-08-29 10:20:00+03	2017-08-29 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5099	PG0469	2017-08-29 12:35:00+03	2017-08-29 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5100	PG0472	2017-08-30 18:30:00+03	2017-08-30 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5101	PG0468	2017-08-29 13:15:00+03	2017-08-29 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5102	PG0472	2017-09-12 18:30:00+03	2017-09-12 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5103	PG0471	2017-09-12 18:40:00+03	2017-09-12 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5104	PG0470	2017-09-12 10:20:00+03	2017-09-12 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5105	PG0469	2017-09-12 12:35:00+03	2017-09-12 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5106	PG0468	2017-09-12 13:15:00+03	2017-09-12 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5107	PG0468	2017-09-14 13:15:00+03	2017-09-14 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5108	PG0472	2017-09-06 18:30:00+03	2017-09-06 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5109	PG0469	2017-09-14 12:35:00+03	2017-09-14 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5110	PG0471	2017-09-06 18:40:00+03	2017-09-06 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5111	PG0470	2017-09-06 10:20:00+03	2017-09-06 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5112	PG0469	2017-09-06 12:35:00+03	2017-09-06 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5113	PG0468	2017-09-06 13:15:00+03	2017-09-06 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5114	PG0470	2017-09-14 10:20:00+03	2017-09-14 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5115	PG0471	2017-09-14 18:40:00+03	2017-09-14 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5116	PG0472	2017-09-14 18:30:00+03	2017-09-14 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5117	PG0472	2017-08-04 18:30:00+03	2017-08-04 19:20:00+03	SVO	LED	Arrived	321	2017-08-04 18:36:00+03	2017-08-04 19:25:00+03
5118	PG0471	2017-08-04 18:40:00+03	2017-08-04 19:30:00+03	SVO	LED	Arrived	321	2017-08-04 18:45:00+03	2017-08-04 19:35:00+03
5119	PG0470	2017-08-04 10:20:00+03	2017-08-04 11:10:00+03	SVO	LED	Arrived	321	2017-08-04 10:21:00+03	2017-08-04 11:12:00+03
5120	PG0469	2017-08-04 12:35:00+03	2017-08-04 13:25:00+03	SVO	LED	Arrived	321	2017-08-04 12:38:00+03	2017-08-04 13:27:00+03
5121	PG0468	2017-08-04 13:15:00+03	2017-08-04 14:05:00+03	SVO	LED	Arrived	321	2017-08-04 13:18:00+03	2017-08-04 14:08:00+03
5122	PG0468	2017-08-13 13:15:00+03	2017-08-13 14:05:00+03	SVO	LED	Arrived	321	2017-08-13 13:16:00+03	2017-08-13 14:06:00+03
5123	PG0469	2017-08-13 12:35:00+03	2017-08-13 13:25:00+03	SVO	LED	Arrived	321	2017-08-13 12:37:00+03	2017-08-13 13:26:00+03
5124	PG0468	2017-09-05 13:15:00+03	2017-09-05 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5125	PG0468	2017-08-31 13:15:00+03	2017-08-31 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5126	PG0470	2017-08-13 10:20:00+03	2017-08-13 11:10:00+03	SVO	LED	Arrived	321	2017-08-13 10:21:00+03	2017-08-13 11:11:00+03
5127	PG0471	2017-08-13 18:40:00+03	2017-08-13 19:30:00+03	SVO	LED	Arrived	321	2017-08-13 18:40:00+03	2017-08-13 19:29:00+03
5128	PG0468	2017-07-25 13:15:00+03	2017-07-25 14:05:00+03	SVO	LED	Arrived	321	2017-07-25 13:19:00+03	2017-07-25 14:09:00+03
5129	PG0469	2017-07-25 12:35:00+03	2017-07-25 13:25:00+03	SVO	LED	Arrived	321	2017-07-25 12:38:00+03	2017-07-25 13:29:00+03
5130	PG0470	2017-07-25 10:20:00+03	2017-07-25 11:10:00+03	SVO	LED	Arrived	321	2017-07-25 10:23:00+03	2017-07-25 11:13:00+03
5131	PG0471	2017-07-25 18:40:00+03	2017-07-25 19:30:00+03	SVO	LED	Arrived	321	2017-07-25 18:43:00+03	2017-07-25 19:33:00+03
5132	PG0472	2017-07-25 18:30:00+03	2017-07-25 19:20:00+03	SVO	LED	Arrived	321	2017-07-25 21:43:00+03	2017-07-25 22:32:00+03
5133	PG0472	2017-08-14 18:30:00+03	2017-08-14 19:20:00+03	SVO	LED	Arrived	321	2017-08-14 18:34:00+03	2017-08-14 19:24:00+03
5134	PG0471	2017-08-14 18:40:00+03	2017-08-14 19:30:00+03	SVO	LED	Arrived	321	2017-08-14 18:45:00+03	2017-08-14 19:35:00+03
5135	PG0470	2017-08-14 10:20:00+03	2017-08-14 11:10:00+03	SVO	LED	Arrived	321	2017-08-14 10:22:00+03	2017-08-14 11:12:00+03
5136	PG0469	2017-08-14 12:35:00+03	2017-08-14 13:25:00+03	SVO	LED	Arrived	321	2017-08-14 12:36:00+03	2017-08-14 13:27:00+03
5137	PG0472	2017-07-17 18:30:00+03	2017-07-17 19:20:00+03	SVO	LED	Arrived	321	2017-07-17 18:33:00+03	2017-07-17 19:23:00+03
5138	PG0471	2017-07-17 18:40:00+03	2017-07-17 19:30:00+03	SVO	LED	Arrived	321	2017-07-17 18:44:00+03	2017-07-17 19:34:00+03
5139	PG0472	2017-07-26 18:30:00+03	2017-07-26 19:20:00+03	SVO	LED	Arrived	321	2017-07-26 18:33:00+03	2017-07-26 19:23:00+03
5140	PG0468	2017-08-01 13:15:00+03	2017-08-01 14:05:00+03	SVO	LED	Arrived	321	2017-08-01 13:16:00+03	2017-08-01 14:06:00+03
5141	PG0470	2017-07-17 10:20:00+03	2017-07-17 11:10:00+03	SVO	LED	Arrived	321	2017-07-17 10:25:00+03	2017-07-17 11:14:00+03
5142	PG0469	2017-07-17 12:35:00+03	2017-07-17 13:25:00+03	SVO	LED	Arrived	321	2017-07-17 12:36:00+03	2017-07-17 13:26:00+03
5143	PG0469	2017-08-01 12:35:00+03	2017-08-01 13:25:00+03	SVO	LED	Arrived	321	2017-08-01 12:41:00+03	2017-08-01 13:31:00+03
5144	PG0468	2017-07-17 13:15:00+03	2017-07-17 14:05:00+03	SVO	LED	Arrived	321	2017-07-17 13:18:00+03	2017-07-17 14:08:00+03
5145	PG0472	2017-08-02 18:30:00+03	2017-08-02 19:20:00+03	SVO	LED	Arrived	321	2017-08-02 18:32:00+03	2017-08-02 19:21:00+03
5146	PG0470	2017-08-01 10:20:00+03	2017-08-01 11:10:00+03	SVO	LED	Arrived	321	2017-08-01 10:23:00+03	2017-08-01 11:12:00+03
5147	PG0471	2017-08-01 18:40:00+03	2017-08-01 19:30:00+03	SVO	LED	Arrived	321	2017-08-01 18:43:00+03	2017-08-01 19:33:00+03
5148	PG0468	2017-08-14 13:15:00+03	2017-08-14 14:05:00+03	SVO	LED	Arrived	321	2017-08-14 13:17:00+03	2017-08-14 14:07:00+03
5149	PG0472	2017-08-01 18:30:00+03	2017-08-01 19:20:00+03	SVO	LED	Arrived	321	2017-08-01 18:34:00+03	2017-08-01 19:24:00+03
5150	PG0472	2017-07-27 18:30:00+03	2017-07-27 19:20:00+03	SVO	LED	Arrived	321	2017-07-27 18:33:00+03	2017-07-27 19:23:00+03
5151	PG0471	2017-07-27 18:40:00+03	2017-07-27 19:30:00+03	SVO	LED	Arrived	321	2017-07-27 18:42:00+03	2017-07-27 19:33:00+03
5152	PG0470	2017-07-27 10:20:00+03	2017-07-27 11:10:00+03	SVO	LED	Arrived	321	2017-07-27 10:23:00+03	2017-07-27 11:13:00+03
5153	PG0469	2017-07-27 12:35:00+03	2017-07-27 13:25:00+03	SVO	LED	Arrived	321	2017-07-27 12:35:00+03	2017-07-27 13:25:00+03
5154	PG0468	2017-07-27 13:15:00+03	2017-07-27 14:05:00+03	SVO	LED	Arrived	321	2017-07-27 13:19:00+03	2017-07-27 14:09:00+03
5155	PG0468	2017-08-27 13:15:00+03	2017-08-27 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5156	PG0468	2017-09-11 13:15:00+03	2017-09-11 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5157	PG0469	2017-09-11 12:35:00+03	2017-09-11 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5158	PG0468	2017-08-10 13:15:00+03	2017-08-10 14:05:00+03	SVO	LED	Arrived	321	2017-08-10 13:18:00+03	2017-08-10 14:07:00+03
5159	PG0469	2017-08-10 12:35:00+03	2017-08-10 13:25:00+03	SVO	LED	Arrived	321	2017-08-10 12:35:00+03	2017-08-10 13:26:00+03
5160	PG0470	2017-08-10 10:20:00+03	2017-08-10 11:10:00+03	SVO	LED	Arrived	321	2017-08-10 10:23:00+03	2017-08-10 11:14:00+03
5161	PG0471	2017-08-10 18:40:00+03	2017-08-10 19:30:00+03	SVO	LED	Arrived	321	2017-08-10 18:45:00+03	2017-08-10 19:35:00+03
5162	PG0472	2017-08-10 18:30:00+03	2017-08-10 19:20:00+03	SVO	LED	Arrived	321	2017-08-10 18:31:00+03	2017-08-10 19:21:00+03
5163	PG0470	2017-09-11 10:20:00+03	2017-09-11 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5164	PG0471	2017-09-11 18:40:00+03	2017-09-11 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5165	PG0471	2017-08-02 18:40:00+03	2017-08-02 19:30:00+03	SVO	LED	Arrived	321	2017-08-02 18:40:00+03	2017-08-02 19:30:00+03
5166	PG0472	2017-09-11 18:30:00+03	2017-09-11 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5167	PG0468	2017-07-26 13:15:00+03	2017-07-26 14:05:00+03	SVO	LED	Arrived	321	2017-07-26 13:18:00+03	2017-07-26 14:08:00+03
5168	PG0469	2017-08-31 12:35:00+03	2017-08-31 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5169	PG0469	2017-09-05 12:35:00+03	2017-09-05 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5170	PG0470	2017-08-02 10:20:00+03	2017-08-02 11:10:00+03	SVO	LED	Arrived	321	2017-08-02 10:23:00+03	2017-08-02 11:13:00+03
5171	PG0470	2017-08-31 10:20:00+03	2017-08-31 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5172	PG0469	2017-08-27 12:35:00+03	2017-08-27 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5173	PG0472	2017-09-01 18:30:00+03	2017-09-01 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5174	PG0471	2017-09-01 18:40:00+03	2017-09-01 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5175	PG0472	2017-07-22 18:30:00+03	2017-07-22 19:20:00+03	SVO	LED	Arrived	321	2017-07-22 18:30:00+03	2017-07-22 19:20:00+03
5176	PG0471	2017-07-22 18:40:00+03	2017-07-22 19:30:00+03	SVO	LED	Arrived	321	2017-07-22 18:41:00+03	2017-07-22 19:31:00+03
5177	PG0470	2017-07-22 10:20:00+03	2017-07-22 11:10:00+03	SVO	LED	Arrived	321	2017-07-22 10:20:00+03	2017-07-22 11:10:00+03
5178	PG0470	2017-08-27 10:20:00+03	2017-08-27 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5179	PG0470	2017-09-01 10:20:00+03	2017-09-01 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5180	PG0469	2017-07-22 12:35:00+03	2017-07-22 13:25:00+03	SVO	LED	Arrived	321	2017-07-22 12:38:00+03	2017-07-22 13:28:00+03
5181	PG0469	2017-09-01 12:35:00+03	2017-09-01 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5182	PG0468	2017-07-22 13:15:00+03	2017-07-22 14:05:00+03	SVO	LED	Arrived	321	2017-07-22 13:18:00+03	2017-07-22 14:08:00+03
5183	PG0468	2017-09-01 13:15:00+03	2017-09-01 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5184	PG0471	2017-07-26 18:40:00+03	2017-07-26 19:30:00+03	SVO	LED	Arrived	321	2017-07-26 18:42:00+03	2017-07-26 19:32:00+03
5185	PG0468	2017-08-24 13:15:00+03	2017-08-24 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5186	PG0469	2017-08-24 12:35:00+03	2017-08-24 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5187	PG0470	2017-08-24 10:20:00+03	2017-08-24 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5188	PG0471	2017-08-24 18:40:00+03	2017-08-24 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5189	PG0472	2017-08-24 18:30:00+03	2017-08-24 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5190	PG0470	2017-07-26 10:20:00+03	2017-07-26 11:10:00+03	SVO	LED	Arrived	321	2017-07-26 10:21:00+03	2017-07-26 11:11:00+03
5191	PG0471	2017-08-31 18:40:00+03	2017-08-31 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5192	PG0472	2017-08-31 18:30:00+03	2017-08-31 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5193	PG0472	2017-08-13 18:30:00+03	2017-08-13 19:20:00+03	SVO	LED	Arrived	321	2017-08-13 18:32:00+03	2017-08-13 19:23:00+03
5194	PG0468	2017-07-21 13:15:00+03	2017-07-21 14:05:00+03	SVO	LED	Arrived	321	2017-07-21 13:17:00+03	2017-07-21 14:07:00+03
5195	PG0469	2017-08-02 12:35:00+03	2017-08-02 13:25:00+03	SVO	LED	Arrived	321	2017-08-02 12:38:00+03	2017-08-02 13:28:00+03
5196	PG0469	2017-07-21 12:35:00+03	2017-07-21 13:25:00+03	SVO	LED	Arrived	321	2017-07-21 15:21:00+03	2017-07-21 16:11:00+03
5197	PG0470	2017-07-21 10:20:00+03	2017-07-21 11:10:00+03	SVO	LED	Arrived	321	2017-07-21 10:22:00+03	2017-07-21 11:12:00+03
5198	PG0468	2017-07-16 13:15:00+03	2017-07-16 14:05:00+03	SVO	LED	Arrived	321	2017-07-16 13:17:00+03	2017-07-16 14:07:00+03
5199	PG0471	2017-08-27 18:40:00+03	2017-08-27 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5200	PG0469	2017-07-16 12:35:00+03	2017-07-16 13:25:00+03	SVO	LED	Arrived	321	2017-07-16 12:40:00+03	2017-07-16 13:30:00+03
5201	PG0471	2017-07-21 18:40:00+03	2017-07-21 19:30:00+03	SVO	LED	Arrived	321	2017-07-21 18:43:00+03	2017-07-21 19:34:00+03
5202	PG0472	2017-07-21 18:30:00+03	2017-07-21 19:20:00+03	SVO	LED	Arrived	321	2017-07-21 18:33:00+03	2017-07-21 19:23:00+03
5203	PG0472	2017-08-03 18:30:00+03	2017-08-03 19:20:00+03	SVO	LED	Arrived	321	2017-08-03 21:44:00+03	2017-08-03 22:34:00+03
5204	PG0470	2017-07-16 10:20:00+03	2017-07-16 11:10:00+03	SVO	LED	Arrived	321	2017-07-16 13:53:00+03	2017-07-16 14:43:00+03
5205	PG0471	2017-08-03 18:40:00+03	2017-08-03 19:30:00+03	SVO	LED	Arrived	321	2017-08-03 18:41:00+03	2017-08-03 19:31:00+03
5206	PG0468	2017-08-02 13:15:00+03	2017-08-02 14:05:00+03	SVO	LED	Arrived	321	2017-08-02 13:19:00+03	2017-08-02 14:10:00+03
5207	PG0472	2017-08-25 18:30:00+03	2017-08-25 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5208	PG0470	2017-08-03 10:20:00+03	2017-08-03 11:10:00+03	SVO	LED	Arrived	321	2017-08-03 10:22:00+03	2017-08-03 11:12:00+03
5209	PG0469	2017-08-03 12:35:00+03	2017-08-03 13:25:00+03	SVO	LED	Arrived	321	2017-08-03 12:37:00+03	2017-08-03 13:27:00+03
5210	PG0471	2017-08-25 18:40:00+03	2017-08-25 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5211	PG0468	2017-08-03 13:15:00+03	2017-08-03 14:05:00+03	SVO	LED	Arrived	321	2017-08-03 13:20:00+03	2017-08-03 14:10:00+03
5212	PG0471	2017-07-16 18:40:00+03	2017-07-16 19:30:00+03	SVO	LED	Arrived	321	2017-07-16 18:41:00+03	2017-07-16 19:31:00+03
5213	PG0470	2017-08-25 10:20:00+03	2017-08-25 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5214	PG0468	2017-08-20 13:15:00+03	2017-08-20 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5215	PG0469	2017-08-20 12:35:00+03	2017-08-20 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5216	PG0469	2017-08-25 12:35:00+03	2017-08-25 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5217	PG0470	2017-08-20 10:20:00+03	2017-08-20 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5218	PG0471	2017-08-20 18:40:00+03	2017-08-20 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5219	PG0472	2017-08-20 18:30:00+03	2017-08-20 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5220	PG0472	2017-07-16 18:30:00+03	2017-07-16 19:20:00+03	SVO	LED	Arrived	321	2017-07-16 18:31:00+03	2017-07-16 19:20:00+03
5221	PG0468	2017-08-25 13:15:00+03	2017-08-25 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5222	PG0470	2017-09-05 10:20:00+03	2017-09-05 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5223	PG0468	2017-08-11 13:15:00+03	2017-08-11 14:05:00+03	SVO	LED	Arrived	321	2017-08-11 13:19:00+03	2017-08-11 14:10:00+03
5224	PG0469	2017-08-11 12:35:00+03	2017-08-11 13:25:00+03	SVO	LED	Arrived	321	2017-08-11 15:14:00+03	2017-08-11 16:04:00+03
5225	PG0470	2017-08-11 10:20:00+03	2017-08-11 11:10:00+03	SVO	LED	Arrived	321	2017-08-11 10:22:00+03	2017-08-11 11:12:00+03
5226	PG0471	2017-09-05 18:40:00+03	2017-09-05 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5227	PG0471	2017-08-11 18:40:00+03	2017-08-11 19:30:00+03	SVO	LED	Arrived	321	2017-08-11 18:43:00+03	2017-08-11 19:34:00+03
5228	PG0472	2017-08-27 18:30:00+03	2017-08-27 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5229	PG0472	2017-08-11 18:30:00+03	2017-08-11 19:20:00+03	SVO	LED	Arrived	321	2017-08-11 18:34:00+03	2017-08-11 19:25:00+03
5230	PG0468	2017-08-26 13:15:00+03	2017-08-26 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5231	PG0469	2017-08-26 12:35:00+03	2017-08-26 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5232	PG0470	2017-08-26 10:20:00+03	2017-08-26 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5233	PG0471	2017-08-26 18:40:00+03	2017-08-26 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5234	PG0472	2017-08-26 18:30:00+03	2017-08-26 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5235	PG0469	2017-07-26 12:35:00+03	2017-07-26 13:25:00+03	SVO	LED	Arrived	321	2017-07-26 12:38:00+03	2017-07-26 13:27:00+03
5236	PG0472	2017-08-22 18:30:00+03	2017-08-22 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5237	PG0471	2017-08-22 18:40:00+03	2017-08-22 19:30:00+03	SVO	LED	Scheduled	321	\N	\N
5238	PG0470	2017-08-22 10:20:00+03	2017-08-22 11:10:00+03	SVO	LED	Scheduled	321	\N	\N
5239	PG0469	2017-08-22 12:35:00+03	2017-08-22 13:25:00+03	SVO	LED	Scheduled	321	\N	\N
5240	PG0468	2017-08-22 13:15:00+03	2017-08-22 14:05:00+03	SVO	LED	Scheduled	321	\N	\N
5241	PG0472	2017-09-07 18:30:00+03	2017-09-07 19:20:00+03	SVO	LED	Scheduled	321	\N	\N
5242	PG0277	2017-07-27 11:45:00+03	2017-07-27 15:10:00+03	SVO	OVB	Arrived	773	2017-07-27 11:47:00+03	2017-07-27 15:07:00+03
5243	PG0277	2017-09-08 11:45:00+03	2017-09-08 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5244	PG0277	2017-08-05 11:45:00+03	2017-08-05 15:10:00+03	SVO	OVB	Arrived	773	2017-08-05 14:46:00+03	2017-08-05 18:12:00+03
5245	PG0277	2017-09-13 11:45:00+03	2017-09-13 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5246	PG0277	2017-09-03 11:45:00+03	2017-09-03 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5247	PG0277	2017-07-23 11:45:00+03	2017-07-23 15:10:00+03	SVO	OVB	Arrived	773	2017-07-23 11:47:00+03	2017-07-23 15:14:00+03
5248	PG0277	2017-08-24 11:45:00+03	2017-08-24 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5249	PG0277	2017-07-25 11:45:00+03	2017-07-25 15:10:00+03	SVO	OVB	Arrived	773	2017-07-25 11:47:00+03	2017-07-25 15:10:00+03
5250	PG0277	2017-08-01 11:45:00+03	2017-08-01 15:10:00+03	SVO	OVB	Arrived	773	2017-08-01 11:45:00+03	2017-08-01 15:08:00+03
5251	PG0277	2017-09-02 11:45:00+03	2017-09-02 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5252	PG0277	2017-07-28 11:45:00+03	2017-07-28 15:10:00+03	SVO	OVB	Arrived	773	2017-07-28 11:48:00+03	2017-07-28 15:11:00+03
5253	PG0277	2017-09-11 11:45:00+03	2017-09-11 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5254	PG0277	2017-07-16 11:45:00+03	2017-07-16 15:10:00+03	SVO	OVB	Arrived	773	2017-07-16 11:51:00+03	2017-07-16 15:15:00+03
5255	PG0277	2017-08-19 11:45:00+03	2017-08-19 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5256	PG0277	2017-08-30 11:45:00+03	2017-08-30 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5257	PG0277	2017-09-10 11:45:00+03	2017-09-10 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5258	PG0277	2017-09-09 11:45:00+03	2017-09-09 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5259	PG0277	2017-08-26 11:45:00+03	2017-08-26 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5260	PG0277	2017-07-21 11:45:00+03	2017-07-21 15:10:00+03	SVO	OVB	Arrived	773	2017-07-21 11:47:00+03	2017-07-21 15:12:00+03
5261	PG0277	2017-09-14 11:45:00+03	2017-09-14 15:10:00+03	SVO	OVB	Cancelled	773	\N	\N
5262	PG0277	2017-08-11 11:45:00+03	2017-08-11 15:10:00+03	SVO	OVB	Arrived	773	2017-08-11 11:46:00+03	2017-08-11 15:13:00+03
5263	PG0277	2017-09-05 11:45:00+03	2017-09-05 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5264	PG0277	2017-09-07 11:45:00+03	2017-09-07 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5265	PG0277	2017-07-24 11:45:00+03	2017-07-24 15:10:00+03	SVO	OVB	Arrived	773	2017-07-24 11:48:00+03	2017-07-24 15:11:00+03
5266	PG0277	2017-08-20 11:45:00+03	2017-08-20 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5267	PG0277	2017-08-12 11:45:00+03	2017-08-12 15:10:00+03	SVO	OVB	Arrived	773	2017-08-12 11:50:00+03	2017-08-12 15:16:00+03
5268	PG0277	2017-08-02 11:45:00+03	2017-08-02 15:10:00+03	SVO	OVB	Arrived	773	2017-08-02 11:50:00+03	2017-08-02 15:13:00+03
5269	PG0277	2017-09-04 11:45:00+03	2017-09-04 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5270	PG0277	2017-07-30 11:45:00+03	2017-07-30 15:10:00+03	SVO	OVB	Arrived	773	2017-07-30 11:53:00+03	2017-07-30 15:18:00+03
5271	PG0277	2017-07-26 11:45:00+03	2017-07-26 15:10:00+03	SVO	OVB	Arrived	773	2017-07-26 11:49:00+03	2017-07-26 15:15:00+03
5272	PG0277	2017-08-14 11:45:00+03	2017-08-14 15:10:00+03	SVO	OVB	Arrived	773	2017-08-14 11:47:00+03	2017-08-14 15:11:00+03
5273	PG0277	2017-08-13 11:45:00+03	2017-08-13 15:10:00+03	SVO	OVB	Arrived	773	2017-08-13 11:49:00+03	2017-08-13 15:14:00+03
5274	PG0277	2017-07-20 11:45:00+03	2017-07-20 15:10:00+03	SVO	OVB	Arrived	773	2017-07-20 11:47:00+03	2017-07-20 15:07:00+03
5275	PG0277	2017-08-07 11:45:00+03	2017-08-07 15:10:00+03	SVO	OVB	Arrived	773	2017-08-07 11:48:00+03	2017-08-07 15:13:00+03
5276	PG0277	2017-08-16 11:45:00+03	2017-08-16 15:10:00+03	SVO	OVB	On Time	773	\N	\N
5277	PG0277	2017-09-01 11:45:00+03	2017-09-01 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5278	PG0277	2017-07-17 11:45:00+03	2017-07-17 15:10:00+03	SVO	OVB	Arrived	773	2017-07-17 11:48:00+03	2017-07-17 15:12:00+03
5279	PG0277	2017-08-03 11:45:00+03	2017-08-03 15:10:00+03	SVO	OVB	Arrived	773	2017-08-03 11:48:00+03	2017-08-03 15:14:00+03
5280	PG0277	2017-08-23 11:45:00+03	2017-08-23 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5281	PG0277	2017-08-25 11:45:00+03	2017-08-25 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5282	PG0277	2017-08-18 11:45:00+03	2017-08-18 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5283	PG0277	2017-07-31 11:45:00+03	2017-07-31 15:10:00+03	SVO	OVB	Arrived	773	2017-07-31 11:47:00+03	2017-07-31 15:15:00+03
5284	PG0277	2017-08-10 11:45:00+03	2017-08-10 15:10:00+03	SVO	OVB	Arrived	773	2017-08-10 11:45:00+03	2017-08-10 15:14:00+03
5285	PG0277	2017-08-22 11:45:00+03	2017-08-22 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5286	PG0277	2017-07-19 11:45:00+03	2017-07-19 15:10:00+03	SVO	OVB	Arrived	773	2017-07-19 11:48:00+03	2017-07-19 15:12:00+03
5287	PG0277	2017-09-06 11:45:00+03	2017-09-06 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5288	PG0277	2017-08-06 11:45:00+03	2017-08-06 15:10:00+03	SVO	OVB	Arrived	773	2017-08-06 11:49:00+03	2017-08-06 15:16:00+03
5289	PG0277	2017-08-31 11:45:00+03	2017-08-31 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5290	PG0277	2017-08-09 11:45:00+03	2017-08-09 15:10:00+03	SVO	OVB	Arrived	773	2017-08-09 11:45:00+03	2017-08-09 15:11:00+03
5291	PG0277	2017-08-21 11:45:00+03	2017-08-21 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5292	PG0277	2017-09-12 11:45:00+03	2017-09-12 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5293	PG0277	2017-08-04 11:45:00+03	2017-08-04 15:10:00+03	SVO	OVB	Arrived	773	2017-08-04 11:50:00+03	2017-08-04 15:17:00+03
5294	PG0277	2017-08-29 11:45:00+03	2017-08-29 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5295	PG0277	2017-08-28 11:45:00+03	2017-08-28 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5296	PG0277	2017-08-17 11:45:00+03	2017-08-17 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5297	PG0277	2017-07-22 11:45:00+03	2017-07-22 15:10:00+03	SVO	OVB	Arrived	773	2017-07-22 11:48:00+03	2017-07-22 15:14:00+03
5298	PG0277	2017-08-27 11:45:00+03	2017-08-27 15:10:00+03	SVO	OVB	Scheduled	773	\N	\N
5299	PG0277	2017-08-08 11:45:00+03	2017-08-08 15:10:00+03	SVO	OVB	Arrived	773	2017-08-08 11:49:00+03	2017-08-08 15:13:00+03
5300	PG0277	2017-08-15 11:45:00+03	2017-08-15 15:10:00+03	SVO	OVB	Arrived	773	2017-08-15 11:46:00+03	2017-08-15 15:15:00+03
5301	PG0277	2017-07-29 11:45:00+03	2017-07-29 15:10:00+03	SVO	OVB	Arrived	773	2017-07-29 11:47:00+03	2017-07-29 15:15:00+03
5302	PG0277	2017-07-18 11:45:00+03	2017-07-18 15:10:00+03	SVO	OVB	Arrived	773	2017-07-18 11:47:00+03	2017-07-18 15:14:00+03
5303	PG0225	2017-08-12 12:50:00+03	2017-08-12 14:35:00+03	SVO	SVX	Arrived	773	2017-08-12 12:53:00+03	2017-08-12 14:38:00+03
5304	PG0225	2017-07-17 12:50:00+03	2017-07-17 14:35:00+03	SVO	SVX	Arrived	773	2017-07-17 12:54:00+03	2017-07-17 14:39:00+03
5305	PG0225	2017-07-18 12:50:00+03	2017-07-18 14:35:00+03	SVO	SVX	Arrived	773	2017-07-18 12:50:00+03	2017-07-18 14:35:00+03
5306	PG0225	2017-08-27 12:50:00+03	2017-08-27 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5307	PG0225	2017-08-07 12:50:00+03	2017-08-07 14:35:00+03	SVO	SVX	Arrived	773	2017-08-07 12:57:00+03	2017-08-07 14:42:00+03
5308	PG0225	2017-08-02 12:50:00+03	2017-08-02 14:35:00+03	SVO	SVX	Arrived	773	2017-08-02 12:53:00+03	2017-08-02 14:38:00+03
5309	PG0225	2017-07-20 12:50:00+03	2017-07-20 14:35:00+03	SVO	SVX	Arrived	773	2017-07-20 12:56:00+03	2017-07-20 14:39:00+03
5310	PG0225	2017-07-27 12:50:00+03	2017-07-27 14:35:00+03	SVO	SVX	Arrived	773	2017-07-27 12:52:00+03	2017-07-27 14:37:00+03
5311	PG0225	2017-08-17 12:50:00+03	2017-08-17 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5312	PG0225	2017-07-29 12:50:00+03	2017-07-29 14:35:00+03	SVO	SVX	Arrived	773	2017-07-29 12:53:00+03	2017-07-29 14:38:00+03
5313	PG0225	2017-09-06 12:50:00+03	2017-09-06 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5314	PG0225	2017-07-31 12:50:00+03	2017-07-31 14:35:00+03	SVO	SVX	Arrived	773	2017-07-31 12:57:00+03	2017-07-31 14:42:00+03
5315	PG0225	2017-09-03 12:50:00+03	2017-09-03 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5316	PG0225	2017-07-23 12:50:00+03	2017-07-23 14:35:00+03	SVO	SVX	Arrived	773	2017-07-23 12:53:00+03	2017-07-23 14:38:00+03
5317	PG0225	2017-08-01 12:50:00+03	2017-08-01 14:35:00+03	SVO	SVX	Arrived	773	2017-08-01 12:53:00+03	2017-08-01 14:37:00+03
5318	PG0225	2017-08-31 12:50:00+03	2017-08-31 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5319	PG0225	2017-07-26 12:50:00+03	2017-07-26 14:35:00+03	SVO	SVX	Arrived	773	2017-07-26 12:53:00+03	2017-07-26 14:38:00+03
5320	PG0225	2017-08-22 12:50:00+03	2017-08-22 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5321	PG0225	2017-08-10 12:50:00+03	2017-08-10 14:35:00+03	SVO	SVX	Arrived	773	2017-08-10 12:50:00+03	2017-08-10 14:35:00+03
5322	PG0225	2017-08-19 12:50:00+03	2017-08-19 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5323	PG0225	2017-09-02 12:50:00+03	2017-09-02 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5324	PG0225	2017-08-23 12:50:00+03	2017-08-23 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5325	PG0225	2017-08-21 12:50:00+03	2017-08-21 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5326	PG0225	2017-09-10 12:50:00+03	2017-09-10 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5327	PG0225	2017-08-29 12:50:00+03	2017-08-29 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5328	PG0225	2017-08-05 12:50:00+03	2017-08-05 14:35:00+03	SVO	SVX	Arrived	773	2017-08-05 12:58:00+03	2017-08-05 14:44:00+03
5329	PG0225	2017-08-25 12:50:00+03	2017-08-25 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5330	PG0225	2017-08-24 12:50:00+03	2017-08-24 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5331	PG0225	2017-07-25 12:50:00+03	2017-07-25 14:35:00+03	SVO	SVX	Arrived	773	2017-07-25 12:54:00+03	2017-07-25 14:40:00+03
5332	PG0225	2017-08-09 12:50:00+03	2017-08-09 14:35:00+03	SVO	SVX	Arrived	773	2017-08-09 12:51:00+03	2017-08-09 14:35:00+03
5333	PG0225	2017-07-28 12:50:00+03	2017-07-28 14:35:00+03	SVO	SVX	Arrived	773	2017-07-28 12:53:00+03	2017-07-28 14:38:00+03
5334	PG0225	2017-09-13 12:50:00+03	2017-09-13 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5335	PG0225	2017-09-11 12:50:00+03	2017-09-11 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5336	PG0225	2017-08-04 12:50:00+03	2017-08-04 14:35:00+03	SVO	SVX	Arrived	773	2017-08-04 12:54:00+03	2017-08-04 14:39:00+03
5337	PG0225	2017-07-22 12:50:00+03	2017-07-22 14:35:00+03	SVO	SVX	Arrived	773	2017-07-22 12:52:00+03	2017-07-22 14:37:00+03
5338	PG0225	2017-09-14 12:50:00+03	2017-09-14 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5339	PG0225	2017-08-28 12:50:00+03	2017-08-28 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5340	PG0225	2017-09-01 12:50:00+03	2017-09-01 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5341	PG0225	2017-08-03 12:50:00+03	2017-08-03 14:35:00+03	SVO	SVX	Arrived	773	2017-08-03 12:55:00+03	2017-08-03 14:39:00+03
5342	PG0225	2017-08-20 12:50:00+03	2017-08-20 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5343	PG0225	2017-08-30 12:50:00+03	2017-08-30 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5344	PG0225	2017-08-15 12:50:00+03	2017-08-15 14:35:00+03	SVO	SVX	Arrived	773	2017-08-15 12:50:00+03	2017-08-15 14:35:00+03
5345	PG0225	2017-07-21 12:50:00+03	2017-07-21 14:35:00+03	SVO	SVX	Arrived	773	2017-07-21 12:54:00+03	2017-07-21 14:41:00+03
5346	PG0225	2017-08-16 12:50:00+03	2017-08-16 14:35:00+03	SVO	SVX	On Time	773	\N	\N
5347	PG0225	2017-08-18 12:50:00+03	2017-08-18 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5348	PG0225	2017-08-13 12:50:00+03	2017-08-13 14:35:00+03	SVO	SVX	Arrived	773	2017-08-13 12:51:00+03	2017-08-13 14:37:00+03
5349	PG0225	2017-09-07 12:50:00+03	2017-09-07 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5350	PG0225	2017-09-09 12:50:00+03	2017-09-09 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5351	PG0225	2017-08-11 12:50:00+03	2017-08-11 14:35:00+03	SVO	SVX	Arrived	773	2017-08-11 12:54:00+03	2017-08-11 14:40:00+03
5352	PG0225	2017-07-19 12:50:00+03	2017-07-19 14:35:00+03	SVO	SVX	Arrived	773	2017-07-19 12:55:00+03	2017-07-19 14:40:00+03
5353	PG0225	2017-08-14 12:50:00+03	2017-08-14 14:35:00+03	SVO	SVX	Arrived	773	2017-08-14 12:54:00+03	2017-08-14 14:38:00+03
5354	PG0225	2017-07-16 12:50:00+03	2017-07-16 14:35:00+03	SVO	SVX	Arrived	773	2017-07-16 12:51:00+03	2017-07-16 14:36:00+03
5355	PG0225	2017-08-08 12:50:00+03	2017-08-08 14:35:00+03	SVO	SVX	Arrived	773	2017-08-08 12:53:00+03	2017-08-08 14:39:00+03
5356	PG0225	2017-07-30 12:50:00+03	2017-07-30 14:35:00+03	SVO	SVX	Arrived	773	2017-07-30 12:52:00+03	2017-07-30 14:39:00+03
5357	PG0225	2017-09-04 12:50:00+03	2017-09-04 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5358	PG0225	2017-09-05 12:50:00+03	2017-09-05 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5359	PG0225	2017-07-24 12:50:00+03	2017-07-24 14:35:00+03	SVO	SVX	Arrived	773	2017-07-24 12:51:00+03	2017-07-24 14:38:00+03
5360	PG0225	2017-08-06 12:50:00+03	2017-08-06 14:35:00+03	SVO	SVX	Arrived	773	2017-08-06 16:41:00+03	2017-08-06 18:26:00+03
5361	PG0225	2017-09-08 12:50:00+03	2017-09-08 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5362	PG0225	2017-08-26 12:50:00+03	2017-08-26 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5363	PG0225	2017-09-12 12:50:00+03	2017-09-12 14:35:00+03	SVO	SVX	Scheduled	773	\N	\N
5364	PG0503	2017-08-03 13:55:00+03	2017-08-03 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-03 17:13:00+03	2017-08-03 20:13:00+03
5365	PG0503	2017-08-15 13:55:00+03	2017-08-15 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-15 13:58:00+03	2017-08-15 16:58:00+03
5366	PG0503	2017-08-23 13:55:00+03	2017-08-23 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5367	PG0503	2017-07-17 13:55:00+03	2017-07-17 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-17 13:59:00+03	2017-07-17 16:59:00+03
5368	PG0503	2017-08-14 13:55:00+03	2017-08-14 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-14 13:57:00+03	2017-08-14 16:54:00+03
5369	PG0503	2017-08-12 13:55:00+03	2017-08-12 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-12 13:57:00+03	2017-08-12 16:57:00+03
5370	PG0503	2017-08-16 13:55:00+03	2017-08-16 16:55:00+03	SVO	OMS	On Time	SU9	\N	\N
5371	PG0503	2017-07-25 13:55:00+03	2017-07-25 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-25 14:00:00+03	2017-07-25 16:59:00+03
5372	PG0503	2017-08-31 13:55:00+03	2017-08-31 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5373	PG0503	2017-08-20 13:55:00+03	2017-08-20 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5374	PG0503	2017-09-02 13:55:00+03	2017-09-02 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5375	PG0503	2017-07-26 13:55:00+03	2017-07-26 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-26 13:55:00+03	2017-07-26 16:53:00+03
5376	PG0503	2017-07-27 13:55:00+03	2017-07-27 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-27 14:00:00+03	2017-07-27 17:04:00+03
5377	PG0503	2017-08-28 13:55:00+03	2017-08-28 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5378	PG0503	2017-08-01 13:55:00+03	2017-08-01 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-01 13:56:00+03	2017-08-01 17:00:00+03
5379	PG0503	2017-09-07 13:55:00+03	2017-09-07 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5380	PG0503	2017-08-05 13:55:00+03	2017-08-05 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-05 14:01:00+03	2017-08-05 17:02:00+03
5381	PG0503	2017-07-16 13:55:00+03	2017-07-16 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-16 14:00:00+03	2017-07-16 17:00:00+03
5382	PG0503	2017-08-11 13:55:00+03	2017-08-11 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-11 13:57:00+03	2017-08-11 16:58:00+03
5383	PG0503	2017-08-10 13:55:00+03	2017-08-10 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-10 14:00:00+03	2017-08-10 16:59:00+03
5384	PG0503	2017-07-19 13:55:00+03	2017-07-19 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-19 14:01:00+03	2017-07-19 17:01:00+03
5385	PG0503	2017-08-08 13:55:00+03	2017-08-08 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-08 14:00:00+03	2017-08-08 16:58:00+03
5386	PG0503	2017-08-13 13:55:00+03	2017-08-13 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-13 13:59:00+03	2017-08-13 16:58:00+03
5387	PG0503	2017-07-18 13:55:00+03	2017-07-18 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-18 13:59:00+03	2017-07-18 17:00:00+03
5388	PG0503	2017-07-22 13:55:00+03	2017-07-22 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-22 13:57:00+03	2017-07-22 16:55:00+03
5389	PG0503	2017-09-01 13:55:00+03	2017-09-01 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5390	PG0503	2017-09-11 13:55:00+03	2017-09-11 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5391	PG0503	2017-08-25 13:55:00+03	2017-08-25 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5392	PG0503	2017-08-21 13:55:00+03	2017-08-21 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5393	PG0503	2017-07-23 13:55:00+03	2017-07-23 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-23 13:57:00+03	2017-07-23 16:59:00+03
5394	PG0503	2017-08-22 13:55:00+03	2017-08-22 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5395	PG0503	2017-08-17 13:55:00+03	2017-08-17 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5396	PG0503	2017-08-07 13:55:00+03	2017-08-07 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-07 13:57:00+03	2017-08-07 16:59:00+03
5397	PG0503	2017-09-13 13:55:00+03	2017-09-13 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5398	PG0503	2017-07-24 13:55:00+03	2017-07-24 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-24 13:57:00+03	2017-07-24 16:56:00+03
5399	PG0503	2017-08-19 13:55:00+03	2017-08-19 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5400	PG0503	2017-09-05 13:55:00+03	2017-09-05 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5401	PG0503	2017-09-14 13:55:00+03	2017-09-14 16:55:00+03	SVO	OMS	Cancelled	SU9	\N	\N
5402	PG0503	2017-09-09 13:55:00+03	2017-09-09 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5403	PG0503	2017-09-03 13:55:00+03	2017-09-03 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5404	PG0503	2017-08-26 13:55:00+03	2017-08-26 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5405	PG0503	2017-07-29 13:55:00+03	2017-07-29 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-29 14:02:00+03	2017-07-29 17:02:00+03
5406	PG0503	2017-08-24 13:55:00+03	2017-08-24 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5407	PG0503	2017-08-06 13:55:00+03	2017-08-06 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-06 13:59:00+03	2017-08-06 16:58:00+03
5408	PG0503	2017-09-10 13:55:00+03	2017-09-10 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5409	PG0503	2017-08-09 13:55:00+03	2017-08-09 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-09 13:59:00+03	2017-08-09 16:59:00+03
5410	PG0503	2017-09-04 13:55:00+03	2017-09-04 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5411	PG0503	2017-08-02 13:55:00+03	2017-08-02 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-02 13:56:00+03	2017-08-02 16:52:00+03
5412	PG0503	2017-09-08 13:55:00+03	2017-09-08 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5413	PG0503	2017-07-20 13:55:00+03	2017-07-20 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-20 13:57:00+03	2017-07-20 16:54:00+03
5414	PG0503	2017-09-12 13:55:00+03	2017-09-12 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5415	PG0503	2017-09-06 13:55:00+03	2017-09-06 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5416	PG0503	2017-08-18 13:55:00+03	2017-08-18 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5417	PG0503	2017-08-29 13:55:00+03	2017-08-29 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5418	PG0503	2017-08-30 13:55:00+03	2017-08-30 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5419	PG0503	2017-08-27 13:55:00+03	2017-08-27 16:55:00+03	SVO	OMS	Scheduled	SU9	\N	\N
5420	PG0503	2017-08-04 13:55:00+03	2017-08-04 16:55:00+03	SVO	OMS	Arrived	SU9	2017-08-04 14:01:00+03	2017-08-04 17:00:00+03
5421	PG0503	2017-07-28 13:55:00+03	2017-07-28 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-28 13:58:00+03	2017-07-28 16:59:00+03
5422	PG0503	2017-07-21 13:55:00+03	2017-07-21 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-21 13:57:00+03	2017-07-21 16:55:00+03
5423	PG0503	2017-07-30 13:55:00+03	2017-07-30 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-30 13:55:00+03	2017-07-30 16:54:00+03
5424	PG0503	2017-07-31 13:55:00+03	2017-07-31 16:55:00+03	SVO	OMS	Arrived	SU9	2017-07-31 13:58:00+03	2017-07-31 16:57:00+03
5425	PG0317	2017-07-21 16:45:00+03	2017-07-21 18:05:00+03	SVO	ROV	Arrived	733	2017-07-21 16:49:00+03	2017-07-21 18:07:00+03
5426	PG0317	2017-08-04 16:45:00+03	2017-08-04 18:05:00+03	SVO	ROV	Arrived	733	2017-08-04 16:50:00+03	2017-08-04 18:12:00+03
5427	PG0317	2017-07-31 16:45:00+03	2017-07-31 18:05:00+03	SVO	ROV	Arrived	733	2017-07-31 16:47:00+03	2017-07-31 18:06:00+03
5428	PG0317	2017-07-30 16:45:00+03	2017-07-30 18:05:00+03	SVO	ROV	Arrived	733	2017-07-30 16:48:00+03	2017-07-30 18:08:00+03
5429	PG0317	2017-09-11 16:45:00+03	2017-09-11 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5430	PG0317	2017-08-05 16:45:00+03	2017-08-05 18:05:00+03	SVO	ROV	Arrived	733	2017-08-05 16:49:00+03	2017-08-05 18:08:00+03
5431	PG0317	2017-07-18 16:45:00+03	2017-07-18 18:05:00+03	SVO	ROV	Arrived	733	2017-07-18 16:48:00+03	2017-07-18 18:07:00+03
5432	PG0317	2017-08-07 16:45:00+03	2017-08-07 18:05:00+03	SVO	ROV	Arrived	733	2017-08-07 16:48:00+03	2017-08-07 18:09:00+03
5433	PG0317	2017-08-29 16:45:00+03	2017-08-29 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5434	PG0317	2017-08-13 16:45:00+03	2017-08-13 18:05:00+03	SVO	ROV	Arrived	733	2017-08-13 19:51:00+03	2017-08-13 21:11:00+03
5435	PG0317	2017-07-19 16:45:00+03	2017-07-19 18:05:00+03	SVO	ROV	Arrived	733	2017-07-19 16:47:00+03	2017-07-19 18:07:00+03
5436	PG0317	2017-07-22 16:45:00+03	2017-07-22 18:05:00+03	SVO	ROV	Arrived	733	2017-07-22 16:47:00+03	2017-07-22 18:07:00+03
5437	PG0317	2017-09-09 16:45:00+03	2017-09-09 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5438	PG0317	2017-08-25 16:45:00+03	2017-08-25 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5439	PG0317	2017-08-03 16:45:00+03	2017-08-03 18:05:00+03	SVO	ROV	Arrived	733	2017-08-03 16:46:00+03	2017-08-03 18:05:00+03
5440	PG0317	2017-09-14 16:45:00+03	2017-09-14 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5441	PG0317	2017-08-16 16:45:00+03	2017-08-16 18:05:00+03	SVO	ROV	On Time	733	\N	\N
5442	PG0317	2017-09-07 16:45:00+03	2017-09-07 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5443	PG0317	2017-08-27 16:45:00+03	2017-08-27 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5444	PG0317	2017-09-02 16:45:00+03	2017-09-02 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5445	PG0317	2017-09-10 16:45:00+03	2017-09-10 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5446	PG0317	2017-08-24 16:45:00+03	2017-08-24 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5447	PG0317	2017-08-20 16:45:00+03	2017-08-20 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5448	PG0317	2017-08-11 16:45:00+03	2017-08-11 18:05:00+03	SVO	ROV	Arrived	733	2017-08-11 16:48:00+03	2017-08-11 18:08:00+03
5449	PG0317	2017-08-10 16:45:00+03	2017-08-10 18:05:00+03	SVO	ROV	Arrived	733	2017-08-10 16:49:00+03	2017-08-10 18:09:00+03
5450	PG0317	2017-09-04 16:45:00+03	2017-09-04 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5451	PG0317	2017-08-28 16:45:00+03	2017-08-28 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5452	PG0317	2017-07-29 16:45:00+03	2017-07-29 18:05:00+03	SVO	ROV	Arrived	733	2017-07-29 16:48:00+03	2017-07-29 18:07:00+03
5453	PG0317	2017-08-09 16:45:00+03	2017-08-09 18:05:00+03	SVO	ROV	Arrived	733	2017-08-09 16:49:00+03	2017-08-09 18:09:00+03
5454	PG0317	2017-09-13 16:45:00+03	2017-09-13 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5455	PG0317	2017-08-21 16:45:00+03	2017-08-21 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5456	PG0317	2017-07-17 16:45:00+03	2017-07-17 18:05:00+03	SVO	ROV	Arrived	733	2017-07-17 16:46:00+03	2017-07-17 18:05:00+03
5457	PG0317	2017-08-26 16:45:00+03	2017-08-26 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5458	PG0317	2017-08-08 16:45:00+03	2017-08-08 18:05:00+03	SVO	ROV	Arrived	733	2017-08-08 16:49:00+03	2017-08-08 18:08:00+03
5459	PG0317	2017-08-15 16:45:00+03	2017-08-15 18:05:00+03	SVO	ROV	Departed	733	2017-08-15 16:52:00+03	\N
5460	PG0317	2017-08-23 16:45:00+03	2017-08-23 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5461	PG0317	2017-08-02 16:45:00+03	2017-08-02 18:05:00+03	SVO	ROV	Arrived	733	2017-08-02 16:51:00+03	2017-08-02 18:12:00+03
5462	PG0317	2017-07-20 16:45:00+03	2017-07-20 18:05:00+03	SVO	ROV	Arrived	733	2017-07-20 16:50:00+03	2017-07-20 18:10:00+03
5463	PG0317	2017-08-17 16:45:00+03	2017-08-17 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5464	PG0317	2017-07-24 16:45:00+03	2017-07-24 18:05:00+03	SVO	ROV	Arrived	733	2017-07-24 16:46:00+03	2017-07-24 18:06:00+03
5465	PG0317	2017-07-25 16:45:00+03	2017-07-25 18:05:00+03	SVO	ROV	Arrived	733	2017-07-25 16:49:00+03	2017-07-25 18:09:00+03
5466	PG0317	2017-08-18 16:45:00+03	2017-08-18 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5467	PG0317	2017-09-05 16:45:00+03	2017-09-05 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5468	PG0317	2017-08-14 16:45:00+03	2017-08-14 18:05:00+03	SVO	ROV	Arrived	733	2017-08-14 16:49:00+03	2017-08-14 18:10:00+03
5469	PG0317	2017-07-27 16:45:00+03	2017-07-27 18:05:00+03	SVO	ROV	Arrived	733	2017-07-27 20:12:00+03	2017-07-27 21:31:00+03
5470	PG0317	2017-08-01 16:45:00+03	2017-08-01 18:05:00+03	SVO	ROV	Arrived	733	2017-08-01 16:48:00+03	2017-08-01 18:08:00+03
5471	PG0317	2017-09-01 16:45:00+03	2017-09-01 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5472	PG0317	2017-08-12 16:45:00+03	2017-08-12 18:05:00+03	SVO	ROV	Arrived	733	2017-08-12 16:48:00+03	2017-08-12 18:08:00+03
5473	PG0317	2017-09-12 16:45:00+03	2017-09-12 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5474	PG0317	2017-07-16 16:45:00+03	2017-07-16 18:05:00+03	SVO	ROV	Arrived	733	2017-07-16 16:47:00+03	2017-07-16 18:07:00+03
5475	PG0317	2017-08-30 16:45:00+03	2017-08-30 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5476	PG0317	2017-09-06 16:45:00+03	2017-09-06 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5477	PG0317	2017-08-06 16:45:00+03	2017-08-06 18:05:00+03	SVO	ROV	Arrived	733	2017-08-06 16:49:00+03	2017-08-06 18:10:00+03
5478	PG0317	2017-08-22 16:45:00+03	2017-08-22 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5479	PG0317	2017-07-26 16:45:00+03	2017-07-26 18:05:00+03	SVO	ROV	Arrived	733	2017-07-26 16:47:00+03	2017-07-26 18:08:00+03
5480	PG0317	2017-09-08 16:45:00+03	2017-09-08 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5481	PG0317	2017-08-31 16:45:00+03	2017-08-31 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5482	PG0317	2017-07-28 16:45:00+03	2017-07-28 18:05:00+03	SVO	ROV	Arrived	733	2017-07-28 16:47:00+03	2017-07-28 18:07:00+03
5483	PG0317	2017-07-23 16:45:00+03	2017-07-23 18:05:00+03	SVO	ROV	Arrived	733	2017-07-23 16:46:00+03	2017-07-23 18:04:00+03
5484	PG0317	2017-09-03 16:45:00+03	2017-09-03 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5485	PG0317	2017-08-19 16:45:00+03	2017-08-19 18:05:00+03	SVO	ROV	Scheduled	733	\N	\N
5486	PG0529	2017-08-07 09:50:00+03	2017-08-07 11:20:00+03	SVO	UFA	Arrived	763	2017-08-07 09:52:00+03	2017-08-07 11:21:00+03
5487	PG0529	2017-09-09 09:50:00+03	2017-09-09 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5488	PG0529	2017-08-13 09:50:00+03	2017-08-13 11:20:00+03	SVO	UFA	Arrived	763	2017-08-13 09:50:00+03	2017-08-13 11:19:00+03
5489	PG0529	2017-09-11 09:50:00+03	2017-09-11 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5490	PG0529	2017-08-30 09:50:00+03	2017-08-30 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5491	PG0529	2017-09-05 09:50:00+03	2017-09-05 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5492	PG0529	2017-07-30 09:50:00+03	2017-07-30 11:20:00+03	SVO	UFA	Arrived	763	2017-07-30 09:53:00+03	2017-07-30 11:24:00+03
5493	PG0529	2017-07-16 09:50:00+03	2017-07-16 11:20:00+03	SVO	UFA	Arrived	763	2017-07-16 09:53:00+03	2017-07-16 11:21:00+03
5494	PG0529	2017-08-12 09:50:00+03	2017-08-12 11:20:00+03	SVO	UFA	Arrived	763	2017-08-12 09:58:00+03	2017-08-12 11:28:00+03
5495	PG0529	2017-08-24 09:50:00+03	2017-08-24 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5496	PG0529	2017-07-21 09:50:00+03	2017-07-21 11:20:00+03	SVO	UFA	Arrived	763	2017-07-21 09:52:00+03	2017-07-21 11:21:00+03
5497	PG0529	2017-07-25 09:50:00+03	2017-07-25 11:20:00+03	SVO	UFA	Arrived	763	2017-07-25 09:56:00+03	2017-07-25 11:26:00+03
5498	PG0529	2017-08-18 09:50:00+03	2017-08-18 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5499	PG0529	2017-07-28 09:50:00+03	2017-07-28 11:20:00+03	SVO	UFA	Arrived	763	2017-07-28 09:54:00+03	2017-07-28 11:25:00+03
5500	PG0529	2017-07-17 09:50:00+03	2017-07-17 11:20:00+03	SVO	UFA	Arrived	763	2017-07-17 09:53:00+03	2017-07-17 11:23:00+03
5501	PG0529	2017-07-27 09:50:00+03	2017-07-27 11:20:00+03	SVO	UFA	Arrived	763	2017-07-27 09:54:00+03	2017-07-27 11:24:00+03
5503	PG0529	2017-08-15 09:50:00+03	2017-08-15 11:20:00+03	SVO	UFA	Arrived	763	2017-08-15 09:52:00+03	2017-08-15 11:23:00+03
5504	PG0529	2017-08-02 09:50:00+03	2017-08-02 11:20:00+03	SVO	UFA	Arrived	763	2017-08-02 09:50:00+03	2017-08-02 11:20:00+03
5505	PG0529	2017-07-19 09:50:00+03	2017-07-19 11:20:00+03	SVO	UFA	Arrived	763	2017-07-19 09:53:00+03	2017-07-19 11:24:00+03
5506	PG0529	2017-09-03 09:50:00+03	2017-09-03 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5507	PG0529	2017-07-18 09:50:00+03	2017-07-18 11:20:00+03	SVO	UFA	Arrived	763	2017-07-18 09:53:00+03	2017-07-18 11:23:00+03
5508	PG0529	2017-08-26 09:50:00+03	2017-08-26 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5509	PG0529	2017-08-08 09:50:00+03	2017-08-08 11:20:00+03	SVO	UFA	Arrived	763	2017-08-08 09:51:00+03	2017-08-08 11:20:00+03
5510	PG0529	2017-08-23 09:50:00+03	2017-08-23 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5511	PG0529	2017-09-01 09:50:00+03	2017-09-01 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5512	PG0529	2017-08-16 09:50:00+03	2017-08-16 11:20:00+03	SVO	UFA	On Time	763	\N	\N
5513	PG0529	2017-09-13 09:50:00+03	2017-09-13 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5514	PG0529	2017-07-31 09:50:00+03	2017-07-31 11:20:00+03	SVO	UFA	Arrived	763	2017-07-31 09:54:00+03	2017-07-31 11:24:00+03
5515	PG0529	2017-07-26 09:50:00+03	2017-07-26 11:20:00+03	SVO	UFA	Arrived	763	2017-07-26 13:42:00+03	2017-07-26 15:11:00+03
5516	PG0529	2017-08-11 09:50:00+03	2017-08-11 11:20:00+03	SVO	UFA	Arrived	763	2017-08-11 09:53:00+03	2017-08-11 11:23:00+03
5517	PG0529	2017-07-22 09:50:00+03	2017-07-22 11:20:00+03	SVO	UFA	Arrived	763	2017-07-22 09:53:00+03	2017-07-22 11:23:00+03
5518	PG0529	2017-08-17 09:50:00+03	2017-08-17 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5519	PG0529	2017-09-07 09:50:00+03	2017-09-07 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5520	PG0529	2017-08-03 09:50:00+03	2017-08-03 11:20:00+03	SVO	UFA	Arrived	763	2017-08-03 09:56:00+03	2017-08-03 11:25:00+03
5521	PG0529	2017-08-05 09:50:00+03	2017-08-05 11:20:00+03	SVO	UFA	Arrived	763	2017-08-05 09:54:00+03	2017-08-05 11:23:00+03
5522	PG0529	2017-08-28 09:50:00+03	2017-08-28 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5523	PG0529	2017-08-01 09:50:00+03	2017-08-01 11:20:00+03	SVO	UFA	Arrived	763	2017-08-01 09:54:00+03	2017-08-01 11:23:00+03
5524	PG0529	2017-08-14 09:50:00+03	2017-08-14 11:20:00+03	SVO	UFA	Arrived	763	2017-08-14 09:53:00+03	2017-08-14 11:22:00+03
5525	PG0529	2017-09-02 09:50:00+03	2017-09-02 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5526	PG0529	2017-08-06 09:50:00+03	2017-08-06 11:20:00+03	SVO	UFA	Arrived	763	2017-08-06 09:53:00+03	2017-08-06 11:24:00+03
5527	PG0529	2017-07-29 09:50:00+03	2017-07-29 11:20:00+03	SVO	UFA	Arrived	763	2017-07-29 09:53:00+03	2017-07-29 11:25:00+03
5528	PG0529	2017-08-10 09:50:00+03	2017-08-10 11:20:00+03	SVO	UFA	Arrived	763	2017-08-10 09:52:00+03	2017-08-10 11:23:00+03
5529	PG0529	2017-08-19 09:50:00+03	2017-08-19 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5530	PG0529	2017-08-31 09:50:00+03	2017-08-31 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5531	PG0529	2017-07-20 09:50:00+03	2017-07-20 11:20:00+03	SVO	UFA	Arrived	763	2017-07-20 09:53:00+03	2017-07-20 11:23:00+03
5532	PG0529	2017-09-14 09:50:00+03	2017-09-14 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5533	PG0529	2017-09-08 09:50:00+03	2017-09-08 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5534	PG0529	2017-08-20 09:50:00+03	2017-08-20 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5535	PG0529	2017-08-27 09:50:00+03	2017-08-27 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5536	PG0529	2017-09-06 09:50:00+03	2017-09-06 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5537	PG0529	2017-08-29 09:50:00+03	2017-08-29 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5538	PG0529	2017-09-04 09:50:00+03	2017-09-04 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5539	PG0529	2017-08-21 09:50:00+03	2017-08-21 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5540	PG0529	2017-08-25 09:50:00+03	2017-08-25 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5541	PG0529	2017-09-10 09:50:00+03	2017-09-10 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5542	PG0529	2017-07-24 09:50:00+03	2017-07-24 11:20:00+03	SVO	UFA	Arrived	763	2017-07-24 09:54:00+03	2017-07-24 11:24:00+03
5543	PG0529	2017-08-22 09:50:00+03	2017-08-22 11:20:00+03	SVO	UFA	Scheduled	763	\N	\N
5544	PG0529	2017-08-09 09:50:00+03	2017-08-09 11:20:00+03	SVO	UFA	Arrived	763	2017-08-09 09:51:00+03	2017-08-09 11:20:00+03
5545	PG0529	2017-07-23 09:50:00+03	2017-07-23 11:20:00+03	SVO	UFA	Arrived	763	2017-07-23 09:54:00+03	2017-07-23 11:24:00+03
5546	PG0529	2017-08-04 09:50:00+03	2017-08-04 11:20:00+03	SVO	UFA	Arrived	763	2017-08-04 09:52:00+03	2017-08-04 11:22:00+03
5547	PG0547	2017-08-21 10:25:00+03	2017-08-21 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5548	PG0547	2017-07-24 10:25:00+03	2017-07-24 14:50:00+03	SVO	KJA	Arrived	319	2017-07-24 10:26:00+03	2017-07-24 14:53:00+03
5549	PG0547	2017-08-07 10:25:00+03	2017-08-07 14:50:00+03	SVO	KJA	Arrived	319	2017-08-07 10:29:00+03	2017-08-07 14:55:00+03
5550	PG0547	2017-08-31 10:25:00+03	2017-08-31 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5551	PG0547	2017-08-10 10:25:00+03	2017-08-10 14:50:00+03	SVO	KJA	Arrived	319	2017-08-10 10:28:00+03	2017-08-10 14:52:00+03
5552	PG0547	2017-07-29 10:25:00+03	2017-07-29 14:50:00+03	SVO	KJA	Arrived	319	2017-07-29 10:26:00+03	2017-07-29 14:48:00+03
5553	PG0547	2017-09-10 10:25:00+03	2017-09-10 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5554	PG0547	2017-08-08 10:25:00+03	2017-08-08 14:50:00+03	SVO	KJA	Arrived	319	2017-08-08 10:28:00+03	2017-08-08 14:52:00+03
5555	PG0547	2017-07-23 10:25:00+03	2017-07-23 14:50:00+03	SVO	KJA	Arrived	319	2017-07-23 10:26:00+03	2017-07-23 14:49:00+03
5556	PG0547	2017-07-19 10:25:00+03	2017-07-19 14:50:00+03	SVO	KJA	Arrived	319	2017-07-19 10:29:00+03	2017-07-19 14:52:00+03
5557	PG0547	2017-09-12 10:25:00+03	2017-09-12 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5558	PG0547	2017-08-03 10:25:00+03	2017-08-03 14:50:00+03	SVO	KJA	Arrived	319	2017-08-03 10:29:00+03	2017-08-03 14:54:00+03
5559	PG0547	2017-07-22 10:25:00+03	2017-07-22 14:50:00+03	SVO	KJA	Arrived	319	2017-07-22 10:25:00+03	2017-07-22 14:55:00+03
5560	PG0547	2017-09-03 10:25:00+03	2017-09-03 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5561	PG0547	2017-09-09 10:25:00+03	2017-09-09 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5562	PG0547	2017-09-02 10:25:00+03	2017-09-02 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5563	PG0547	2017-08-02 10:25:00+03	2017-08-02 14:50:00+03	SVO	KJA	Arrived	319	2017-08-02 10:27:00+03	2017-08-02 14:54:00+03
5564	PG0547	2017-08-01 10:25:00+03	2017-08-01 14:50:00+03	SVO	KJA	Arrived	319	2017-08-01 10:26:00+03	2017-08-01 14:51:00+03
5565	PG0547	2017-08-05 10:25:00+03	2017-08-05 14:50:00+03	SVO	KJA	Arrived	319	2017-08-05 10:30:00+03	2017-08-05 14:54:00+03
5566	PG0547	2017-09-11 10:25:00+03	2017-09-11 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5567	PG0547	2017-08-20 10:25:00+03	2017-08-20 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5568	PG0547	2017-07-17 10:25:00+03	2017-07-17 14:50:00+03	SVO	KJA	Arrived	319	2017-07-17 10:27:00+03	2017-07-17 14:53:00+03
5569	PG0547	2017-08-25 10:25:00+03	2017-08-25 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5570	PG0547	2017-08-06 10:25:00+03	2017-08-06 14:50:00+03	SVO	KJA	Arrived	319	2017-08-06 10:33:00+03	2017-08-06 14:56:00+03
5571	PG0547	2017-09-06 10:25:00+03	2017-09-06 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5572	PG0547	2017-08-22 10:25:00+03	2017-08-22 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5573	PG0547	2017-07-20 10:25:00+03	2017-07-20 14:50:00+03	SVO	KJA	Arrived	319	2017-07-20 10:30:00+03	2017-07-20 14:52:00+03
5574	PG0547	2017-07-30 10:25:00+03	2017-07-30 14:50:00+03	SVO	KJA	Arrived	319	2017-07-30 10:28:00+03	2017-07-30 14:56:00+03
5575	PG0547	2017-07-28 10:25:00+03	2017-07-28 14:50:00+03	SVO	KJA	Arrived	319	2017-07-28 10:25:00+03	2017-07-28 14:50:00+03
5576	PG0547	2017-07-25 10:25:00+03	2017-07-25 14:50:00+03	SVO	KJA	Arrived	319	2017-07-25 10:27:00+03	2017-07-25 14:55:00+03
5577	PG0547	2017-08-16 10:25:00+03	2017-08-16 14:50:00+03	SVO	KJA	Delayed	319	\N	\N
5578	PG0547	2017-08-27 10:25:00+03	2017-08-27 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5579	PG0547	2017-09-08 10:25:00+03	2017-09-08 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5580	PG0547	2017-08-29 10:25:00+03	2017-08-29 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5581	PG0547	2017-08-09 10:25:00+03	2017-08-09 14:50:00+03	SVO	KJA	Arrived	319	2017-08-09 10:29:00+03	2017-08-09 14:51:00+03
5582	PG0547	2017-09-04 10:25:00+03	2017-09-04 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5583	PG0547	2017-07-21 10:25:00+03	2017-07-21 14:50:00+03	SVO	KJA	Arrived	319	2017-07-21 10:26:00+03	2017-07-21 14:53:00+03
5584	PG0547	2017-08-12 10:25:00+03	2017-08-12 14:50:00+03	SVO	KJA	Arrived	319	2017-08-12 10:31:00+03	2017-08-12 14:55:00+03
5585	PG0547	2017-08-24 10:25:00+03	2017-08-24 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5586	PG0547	2017-09-14 10:25:00+03	2017-09-14 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5587	PG0547	2017-08-23 10:25:00+03	2017-08-23 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5588	PG0547	2017-07-16 10:25:00+03	2017-07-16 14:50:00+03	SVO	KJA	Arrived	319	2017-07-16 10:30:00+03	2017-07-16 14:58:00+03
5589	PG0547	2017-08-28 10:25:00+03	2017-08-28 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5590	PG0547	2017-07-27 10:25:00+03	2017-07-27 14:50:00+03	SVO	KJA	Arrived	319	2017-07-27 10:30:00+03	2017-07-27 14:54:00+03
5591	PG0547	2017-07-26 10:25:00+03	2017-07-26 14:50:00+03	SVO	KJA	Arrived	319	2017-07-26 10:28:00+03	2017-07-26 14:53:00+03
5592	PG0547	2017-08-13 10:25:00+03	2017-08-13 14:50:00+03	SVO	KJA	Arrived	319	2017-08-13 10:30:00+03	2017-08-13 14:56:00+03
5593	PG0547	2017-08-04 10:25:00+03	2017-08-04 14:50:00+03	SVO	KJA	Arrived	319	2017-08-04 10:28:00+03	2017-08-04 14:51:00+03
5594	PG0547	2017-09-07 10:25:00+03	2017-09-07 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5595	PG0547	2017-07-31 10:25:00+03	2017-07-31 14:50:00+03	SVO	KJA	Arrived	319	2017-07-31 10:30:00+03	2017-07-31 14:54:00+03
5596	PG0547	2017-07-18 10:25:00+03	2017-07-18 14:50:00+03	SVO	KJA	Arrived	319	2017-07-18 10:26:00+03	2017-07-18 14:49:00+03
5597	PG0547	2017-08-11 10:25:00+03	2017-08-11 14:50:00+03	SVO	KJA	Arrived	319	2017-08-11 10:25:00+03	2017-08-11 14:45:00+03
5598	PG0547	2017-09-13 10:25:00+03	2017-09-13 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5599	PG0547	2017-08-14 10:25:00+03	2017-08-14 14:50:00+03	SVO	KJA	Arrived	319	2017-08-14 10:29:00+03	2017-08-14 14:50:00+03
5600	PG0547	2017-09-05 10:25:00+03	2017-09-05 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5601	PG0547	2017-09-01 10:25:00+03	2017-09-01 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5602	PG0547	2017-08-19 10:25:00+03	2017-08-19 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5603	PG0547	2017-08-30 10:25:00+03	2017-08-30 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5604	PG0547	2017-08-18 10:25:00+03	2017-08-18 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5605	PG0547	2017-08-15 10:25:00+03	2017-08-15 14:50:00+03	SVO	KJA	Arrived	319	2017-08-15 10:26:00+03	2017-08-15 14:53:00+03
5606	PG0547	2017-08-17 10:25:00+03	2017-08-17 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5607	PG0547	2017-08-26 10:25:00+03	2017-08-26 14:50:00+03	SVO	KJA	Scheduled	319	\N	\N
5608	PG0174	2017-08-31 16:25:00+03	2017-08-31 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5609	PG0174	2017-08-16 16:25:00+03	2017-08-16 17:40:00+03	SVO	VOG	Delayed	SU9	\N	\N
5610	PG0174	2017-08-09 16:25:00+03	2017-08-09 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-09 16:26:00+03	2017-08-09 17:42:00+03
5611	PG0174	2017-09-12 16:25:00+03	2017-09-12 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5612	PG0174	2017-07-24 16:25:00+03	2017-07-24 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-24 16:28:00+03	2017-07-24 17:44:00+03
5613	PG0174	2017-08-25 16:25:00+03	2017-08-25 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5614	PG0174	2017-08-26 16:25:00+03	2017-08-26 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5615	PG0174	2017-07-16 16:25:00+03	2017-07-16 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-16 16:27:00+03	2017-07-16 17:40:00+03
5616	PG0174	2017-08-19 16:25:00+03	2017-08-19 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5617	PG0174	2017-07-23 16:25:00+03	2017-07-23 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-23 16:29:00+03	2017-07-23 17:44:00+03
5618	PG0174	2017-09-11 16:25:00+03	2017-09-11 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5619	PG0174	2017-08-05 16:25:00+03	2017-08-05 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-05 20:03:00+03	2017-08-05 21:18:00+03
5620	PG0174	2017-07-26 16:25:00+03	2017-07-26 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-26 16:27:00+03	2017-07-26 17:42:00+03
5621	PG0174	2017-07-22 16:25:00+03	2017-07-22 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-22 16:25:00+03	2017-07-22 17:40:00+03
5622	PG0174	2017-09-03 16:25:00+03	2017-09-03 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5623	PG0174	2017-09-13 16:25:00+03	2017-09-13 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5624	PG0174	2017-08-02 16:25:00+03	2017-08-02 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-02 16:27:00+03	2017-08-02 17:41:00+03
5625	PG0174	2017-08-22 16:25:00+03	2017-08-22 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5626	PG0174	2017-08-24 16:25:00+03	2017-08-24 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5627	PG0174	2017-08-12 16:25:00+03	2017-08-12 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-12 16:31:00+03	2017-08-12 17:46:00+03
5628	PG0174	2017-08-04 16:25:00+03	2017-08-04 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-04 16:28:00+03	2017-08-04 17:44:00+03
5629	PG0174	2017-08-27 16:25:00+03	2017-08-27 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5630	PG0174	2017-08-30 16:25:00+03	2017-08-30 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5631	PG0174	2017-08-08 16:25:00+03	2017-08-08 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-08 16:27:00+03	2017-08-08 17:41:00+03
5632	PG0174	2017-08-29 16:25:00+03	2017-08-29 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5633	PG0174	2017-09-01 16:25:00+03	2017-09-01 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5634	PG0174	2017-07-19 16:25:00+03	2017-07-19 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-19 16:27:00+03	2017-07-19 17:43:00+03
5635	PG0174	2017-09-08 16:25:00+03	2017-09-08 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5636	PG0174	2017-07-17 16:25:00+03	2017-07-17 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-17 16:28:00+03	2017-07-17 17:43:00+03
5637	PG0174	2017-08-06 16:25:00+03	2017-08-06 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-06 16:28:00+03	2017-08-06 17:43:00+03
5638	PG0174	2017-09-04 16:25:00+03	2017-09-04 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5639	PG0174	2017-09-06 16:25:00+03	2017-09-06 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5640	PG0174	2017-07-27 16:25:00+03	2017-07-27 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-27 16:29:00+03	2017-07-27 17:44:00+03
5641	PG0174	2017-09-07 16:25:00+03	2017-09-07 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5642	PG0174	2017-08-07 16:25:00+03	2017-08-07 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-07 16:30:00+03	2017-08-07 17:44:00+03
5643	PG0174	2017-07-30 16:25:00+03	2017-07-30 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-30 16:27:00+03	2017-07-30 17:41:00+03
5644	PG0174	2017-08-28 16:25:00+03	2017-08-28 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5645	PG0174	2017-09-05 16:25:00+03	2017-09-05 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5646	PG0174	2017-09-09 16:25:00+03	2017-09-09 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5647	PG0174	2017-07-20 16:25:00+03	2017-07-20 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-20 16:30:00+03	2017-07-20 17:45:00+03
5648	PG0174	2017-08-03 16:25:00+03	2017-08-03 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-03 19:06:00+03	2017-08-03 20:22:00+03
5649	PG0174	2017-08-11 16:25:00+03	2017-08-11 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-11 16:30:00+03	2017-08-11 17:45:00+03
5650	PG0174	2017-08-18 16:25:00+03	2017-08-18 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5651	PG0174	2017-07-29 16:25:00+03	2017-07-29 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-29 16:26:00+03	2017-07-29 17:41:00+03
5652	PG0174	2017-07-21 16:25:00+03	2017-07-21 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-21 16:27:00+03	2017-07-21 17:43:00+03
5653	PG0174	2017-08-20 16:25:00+03	2017-08-20 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5654	PG0174	2017-08-17 16:25:00+03	2017-08-17 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5655	PG0174	2017-07-25 16:25:00+03	2017-07-25 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-25 16:27:00+03	2017-07-25 17:42:00+03
5656	PG0174	2017-09-10 16:25:00+03	2017-09-10 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5657	PG0174	2017-08-14 16:25:00+03	2017-08-14 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-14 16:26:00+03	2017-08-14 17:42:00+03
5658	PG0174	2017-09-14 16:25:00+03	2017-09-14 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5659	PG0174	2017-09-02 16:25:00+03	2017-09-02 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5660	PG0174	2017-07-18 16:25:00+03	2017-07-18 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-18 16:28:00+03	2017-07-18 17:43:00+03
5661	PG0174	2017-08-23 16:25:00+03	2017-08-23 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5662	PG0174	2017-08-13 16:25:00+03	2017-08-13 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-13 16:30:00+03	2017-08-13 17:46:00+03
5663	PG0174	2017-08-10 16:25:00+03	2017-08-10 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-10 16:27:00+03	2017-08-10 17:42:00+03
5664	PG0174	2017-08-01 16:25:00+03	2017-08-01 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-01 16:30:00+03	2017-08-01 17:46:00+03
5665	PG0174	2017-07-31 16:25:00+03	2017-07-31 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-31 16:31:00+03	2017-07-31 17:47:00+03
5666	PG0174	2017-08-15 16:25:00+03	2017-08-15 17:40:00+03	SVO	VOG	Arrived	SU9	2017-08-15 16:31:00+03	2017-08-15 17:46:00+03
5667	PG0174	2017-07-28 16:25:00+03	2017-07-28 17:40:00+03	SVO	VOG	Arrived	SU9	2017-07-28 16:28:00+03	2017-07-28 17:43:00+03
5668	PG0174	2017-08-21 16:25:00+03	2017-08-21 17:40:00+03	SVO	VOG	Scheduled	SU9	\N	\N
5669	PG0152	2017-07-30 17:45:00+03	2017-07-30 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-30 17:49:00+03	2017-07-30 19:43:00+03
5670	PG0152	2017-08-25 17:45:00+03	2017-08-25 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5671	PG0152	2017-07-16 17:45:00+03	2017-07-16 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-16 17:50:00+03	2017-07-16 19:44:00+03
5672	PG0152	2017-09-14 17:45:00+03	2017-09-14 19:40:00+03	SVO	MMK	Cancelled	SU9	\N	\N
5673	PG0152	2017-07-17 17:45:00+03	2017-07-17 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-17 17:46:00+03	2017-07-17 19:40:00+03
5674	PG0152	2017-07-18 17:45:00+03	2017-07-18 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-18 17:48:00+03	2017-07-18 19:42:00+03
5675	PG0152	2017-08-24 17:45:00+03	2017-08-24 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5676	PG0152	2017-07-19 17:45:00+03	2017-07-19 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-19 17:47:00+03	2017-07-19 19:42:00+03
5677	PG0152	2017-08-26 17:45:00+03	2017-08-26 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5678	PG0152	2017-09-13 17:45:00+03	2017-09-13 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5679	PG0152	2017-07-20 17:45:00+03	2017-07-20 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-20 17:49:00+03	2017-07-20 19:44:00+03
5680	PG0152	2017-08-23 17:45:00+03	2017-08-23 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5681	PG0152	2017-07-21 17:45:00+03	2017-07-21 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-21 17:48:00+03	2017-07-21 19:44:00+03
5682	PG0152	2017-09-12 17:45:00+03	2017-09-12 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5683	PG0152	2017-07-22 17:45:00+03	2017-07-22 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-22 17:50:00+03	2017-07-22 19:47:00+03
5684	PG0152	2017-07-23 17:45:00+03	2017-07-23 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-23 17:50:00+03	2017-07-23 19:45:00+03
5685	PG0152	2017-08-22 17:45:00+03	2017-08-22 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5686	PG0152	2017-09-11 17:45:00+03	2017-09-11 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5687	PG0152	2017-08-27 17:45:00+03	2017-08-27 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5688	PG0152	2017-07-24 17:45:00+03	2017-07-24 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-24 17:46:00+03	2017-07-24 19:40:00+03
5689	PG0152	2017-07-25 17:45:00+03	2017-07-25 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-25 21:01:00+03	2017-07-25 22:54:00+03
5690	PG0152	2017-09-10 17:45:00+03	2017-09-10 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5691	PG0152	2017-08-21 17:45:00+03	2017-08-21 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5692	PG0152	2017-07-26 17:45:00+03	2017-07-26 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-26 17:49:00+03	2017-07-26 19:44:00+03
5693	PG0152	2017-07-27 17:45:00+03	2017-07-27 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-27 17:46:00+03	2017-07-27 19:39:00+03
5694	PG0152	2017-09-09 17:45:00+03	2017-09-09 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5695	PG0152	2017-07-28 17:45:00+03	2017-07-28 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-28 17:46:00+03	2017-07-28 19:43:00+03
5696	PG0152	2017-08-20 17:45:00+03	2017-08-20 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5697	PG0152	2017-08-28 17:45:00+03	2017-08-28 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5698	PG0152	2017-07-29 17:45:00+03	2017-07-29 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-29 20:46:00+03	2017-07-29 22:43:00+03
5699	PG0152	2017-09-08 17:45:00+03	2017-09-08 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5700	PG0152	2017-08-19 17:45:00+03	2017-08-19 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5701	PG0152	2017-07-31 17:45:00+03	2017-07-31 19:40:00+03	SVO	MMK	Arrived	SU9	2017-07-31 17:51:00+03	2017-07-31 19:46:00+03
5702	PG0152	2017-09-07 17:45:00+03	2017-09-07 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5703	PG0152	2017-08-01 17:45:00+03	2017-08-01 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-01 17:52:00+03	2017-08-01 19:48:00+03
5704	PG0152	2017-08-18 17:45:00+03	2017-08-18 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5705	PG0152	2017-08-02 17:45:00+03	2017-08-02 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-02 17:46:00+03	2017-08-02 19:41:00+03
5706	PG0152	2017-09-06 17:45:00+03	2017-09-06 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5707	PG0152	2017-08-29 17:45:00+03	2017-08-29 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5708	PG0152	2017-08-03 17:45:00+03	2017-08-03 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-03 17:51:00+03	2017-08-03 19:47:00+03
5709	PG0152	2017-09-05 17:45:00+03	2017-09-05 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5710	PG0152	2017-08-04 17:45:00+03	2017-08-04 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-04 17:47:00+03	2017-08-04 19:40:00+03
5711	PG0152	2017-08-17 17:45:00+03	2017-08-17 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5712	PG0152	2017-08-05 17:45:00+03	2017-08-05 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-05 17:47:00+03	2017-08-05 19:40:00+03
5713	PG0152	2017-09-04 17:45:00+03	2017-09-04 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5714	PG0152	2017-08-06 17:45:00+03	2017-08-06 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-06 17:47:00+03	2017-08-06 19:43:00+03
5715	PG0152	2017-08-16 17:45:00+03	2017-08-16 19:40:00+03	SVO	MMK	On Time	SU9	\N	\N
5716	PG0152	2017-08-07 17:45:00+03	2017-08-07 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-07 17:50:00+03	2017-08-07 19:45:00+03
5717	PG0152	2017-08-30 17:45:00+03	2017-08-30 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5718	PG0152	2017-09-03 17:45:00+03	2017-09-03 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5719	PG0152	2017-08-08 17:45:00+03	2017-08-08 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-08 17:48:00+03	2017-08-08 19:44:00+03
5720	PG0152	2017-08-09 17:45:00+03	2017-08-09 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-09 17:46:00+03	2017-08-09 19:38:00+03
5721	PG0152	2017-08-15 17:45:00+03	2017-08-15 19:40:00+03	SVO	MMK	Departed	SU9	2017-08-15 17:48:00+03	\N
5722	PG0152	2017-09-02 17:45:00+03	2017-09-02 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5723	PG0152	2017-08-10 17:45:00+03	2017-08-10 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-10 17:45:00+03	2017-08-10 19:38:00+03
5724	PG0152	2017-08-11 17:45:00+03	2017-08-11 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-11 17:50:00+03	2017-08-11 19:45:00+03
5725	PG0152	2017-08-14 17:45:00+03	2017-08-14 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-14 17:49:00+03	2017-08-14 19:43:00+03
5726	PG0152	2017-09-01 17:45:00+03	2017-09-01 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5727	PG0152	2017-08-12 17:45:00+03	2017-08-12 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-12 17:49:00+03	2017-08-12 19:45:00+03
5728	PG0152	2017-08-31 17:45:00+03	2017-08-31 19:40:00+03	SVO	MMK	Scheduled	SU9	\N	\N
5729	PG0152	2017-08-13 17:45:00+03	2017-08-13 19:40:00+03	SVO	MMK	Arrived	SU9	2017-08-13 17:50:00+03	2017-08-13 19:47:00+03
5730	PG0456	2017-08-10 16:15:00+03	2017-08-10 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-10 16:18:00+03	2017-08-10 18:32:00+03
5731	PG0457	2017-08-13 11:10:00+03	2017-08-13 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-13 11:14:00+03	2017-08-13 13:31:00+03
5732	PG0457	2017-07-20 11:10:00+03	2017-07-20 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-20 11:14:00+03	2017-07-20 13:29:00+03
5733	PG0456	2017-09-13 16:15:00+03	2017-09-13 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5734	PG0456	2017-09-03 16:15:00+03	2017-09-03 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5735	PG0457	2017-09-05 11:10:00+03	2017-09-05 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5736	PG0456	2017-07-22 16:15:00+03	2017-07-22 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-22 16:17:00+03	2017-07-22 18:33:00+03
5737	PG0456	2017-07-24 16:15:00+03	2017-07-24 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-24 16:19:00+03	2017-07-24 18:35:00+03
5738	PG0457	2017-09-01 11:10:00+03	2017-09-01 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5739	PG0457	2017-08-17 11:10:00+03	2017-08-17 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5740	PG0456	2017-07-21 16:15:00+03	2017-07-21 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-21 16:19:00+03	2017-07-21 18:35:00+03
5741	PG0457	2017-07-25 11:10:00+03	2017-07-25 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-25 11:14:00+03	2017-07-25 13:30:00+03
5742	PG0456	2017-08-17 16:15:00+03	2017-08-17 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5743	PG0457	2017-09-10 11:10:00+03	2017-09-10 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5744	PG0456	2017-07-28 16:15:00+03	2017-07-28 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-28 16:15:00+03	2017-07-28 18:30:00+03
5745	PG0456	2017-08-15 16:15:00+03	2017-08-15 18:30:00+03	SVO	PES	Departed	CN1	2017-08-15 16:20:00+03	\N
5746	PG0457	2017-08-23 11:10:00+03	2017-08-23 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5747	PG0457	2017-08-31 11:10:00+03	2017-08-31 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5748	PG0456	2017-07-25 16:15:00+03	2017-07-25 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-25 16:19:00+03	2017-07-25 18:34:00+03
5749	PG0457	2017-08-09 11:10:00+03	2017-08-09 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-09 11:14:00+03	2017-08-09 13:28:00+03
5750	PG0457	2017-07-19 11:10:00+03	2017-07-19 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-19 11:15:00+03	2017-07-19 13:30:00+03
5751	PG0456	2017-09-01 16:15:00+03	2017-09-01 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5752	PG0457	2017-08-03 11:10:00+03	2017-08-03 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-03 11:15:00+03	2017-08-03 13:31:00+03
5753	PG0456	2017-08-23 16:15:00+03	2017-08-23 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5754	PG0457	2017-07-31 11:10:00+03	2017-07-31 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-31 13:42:00+03	2017-07-31 15:57:00+03
5755	PG0456	2017-07-31 16:15:00+03	2017-07-31 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-31 16:19:00+03	2017-07-31 18:35:00+03
5756	PG0456	2017-08-05 16:15:00+03	2017-08-05 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-05 16:19:00+03	2017-08-05 18:34:00+03
5757	PG0457	2017-09-13 11:10:00+03	2017-09-13 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5758	PG0457	2017-09-06 11:10:00+03	2017-09-06 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5759	PG0456	2017-07-20 16:15:00+03	2017-07-20 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-20 16:17:00+03	2017-07-20 18:31:00+03
5760	PG0456	2017-09-06 16:15:00+03	2017-09-06 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5761	PG0456	2017-07-30 16:15:00+03	2017-07-30 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-30 16:18:00+03	2017-07-30 18:34:00+03
5762	PG0457	2017-07-18 11:10:00+03	2017-07-18 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-18 11:16:00+03	2017-07-18 13:29:00+03
5763	PG0456	2017-08-31 16:15:00+03	2017-08-31 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5764	PG0456	2017-08-24 16:15:00+03	2017-08-24 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5765	PG0456	2017-08-26 16:15:00+03	2017-08-26 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5766	PG0457	2017-07-24 11:10:00+03	2017-07-24 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-24 11:11:00+03	2017-07-24 13:24:00+03
5767	PG0457	2017-07-30 11:10:00+03	2017-07-30 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-30 11:17:00+03	2017-07-30 13:32:00+03
5768	PG0456	2017-08-27 16:15:00+03	2017-08-27 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5769	PG0457	2017-09-12 11:10:00+03	2017-09-12 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5770	PG0457	2017-08-30 11:10:00+03	2017-08-30 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5771	PG0457	2017-08-15 11:10:00+03	2017-08-15 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-15 11:15:00+03	2017-08-15 13:29:00+03
5772	PG0457	2017-09-14 11:10:00+03	2017-09-14 13:25:00+03	SVO	PES	Cancelled	CN1	\N	\N
5773	PG0457	2017-08-28 11:10:00+03	2017-08-28 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5774	PG0456	2017-07-18 16:15:00+03	2017-07-18 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-18 16:17:00+03	2017-07-18 18:35:00+03
5775	PG0456	2017-09-12 16:15:00+03	2017-09-12 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5776	PG0457	2017-08-24 11:10:00+03	2017-08-24 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5777	PG0456	2017-08-13 16:15:00+03	2017-08-13 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-13 16:17:00+03	2017-08-13 18:33:00+03
5778	PG0457	2017-09-04 11:10:00+03	2017-09-04 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5779	PG0457	2017-08-22 11:10:00+03	2017-08-22 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5780	PG0457	2017-07-26 11:10:00+03	2017-07-26 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-26 11:12:00+03	2017-07-26 13:26:00+03
5781	PG0456	2017-08-22 16:15:00+03	2017-08-22 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5782	PG0457	2017-08-27 11:10:00+03	2017-08-27 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5783	PG0457	2017-08-12 11:10:00+03	2017-08-12 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-12 11:16:00+03	2017-08-12 13:30:00+03
5784	PG0456	2017-08-12 16:15:00+03	2017-08-12 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-12 16:15:00+03	2017-08-12 18:29:00+03
5785	PG0457	2017-09-07 11:10:00+03	2017-09-07 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5786	PG0456	2017-09-02 16:15:00+03	2017-09-02 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5787	PG0457	2017-08-26 11:10:00+03	2017-08-26 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5788	PG0456	2017-07-26 16:15:00+03	2017-07-26 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-26 16:17:00+03	2017-07-26 18:32:00+03
5789	PG0456	2017-08-19 16:15:00+03	2017-08-19 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5790	PG0456	2017-07-19 16:15:00+03	2017-07-19 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-19 16:19:00+03	2017-07-19 18:34:00+03
5791	PG0456	2017-08-29 16:15:00+03	2017-08-29 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5792	PG0457	2017-07-28 11:10:00+03	2017-07-28 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-28 11:10:00+03	2017-07-28 13:24:00+03
5793	PG0457	2017-08-19 11:10:00+03	2017-08-19 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5794	PG0457	2017-08-05 11:10:00+03	2017-08-05 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-05 11:12:00+03	2017-08-05 13:26:00+03
5795	PG0456	2017-07-23 16:15:00+03	2017-07-23 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-23 16:16:00+03	2017-07-23 18:30:00+03
5796	PG0456	2017-09-07 16:15:00+03	2017-09-07 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5797	PG0457	2017-09-03 11:10:00+03	2017-09-03 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5798	PG0457	2017-07-21 11:10:00+03	2017-07-21 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-21 11:11:00+03	2017-07-21 13:24:00+03
5799	PG0456	2017-08-01 16:15:00+03	2017-08-01 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-01 16:16:00+03	2017-08-01 18:30:00+03
5800	PG0457	2017-08-01 11:10:00+03	2017-08-01 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-01 11:12:00+03	2017-08-01 13:27:00+03
5801	PG0456	2017-09-09 16:15:00+03	2017-09-09 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5802	PG0456	2017-08-04 16:15:00+03	2017-08-04 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-04 16:19:00+03	2017-08-04 18:33:00+03
5803	PG0456	2017-09-14 16:15:00+03	2017-09-14 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5804	PG0456	2017-08-09 16:15:00+03	2017-08-09 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-09 16:18:00+03	2017-08-09 18:34:00+03
5805	PG0457	2017-08-21 11:10:00+03	2017-08-21 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5806	PG0456	2017-08-06 16:15:00+03	2017-08-06 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-06 16:15:00+03	2017-08-06 18:33:00+03
5807	PG0457	2017-09-08 11:10:00+03	2017-09-08 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5808	PG0457	2017-08-04 11:10:00+03	2017-08-04 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-04 11:12:00+03	2017-08-04 13:25:00+03
5809	PG0456	2017-09-10 16:15:00+03	2017-09-10 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5810	PG0457	2017-08-06 11:10:00+03	2017-08-06 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-06 11:12:00+03	2017-08-06 13:26:00+03
5811	PG0457	2017-09-09 11:10:00+03	2017-09-09 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5812	PG0456	2017-07-16 16:15:00+03	2017-07-16 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-16 16:18:00+03	2017-07-16 18:33:00+03
5813	PG0456	2017-08-28 16:15:00+03	2017-08-28 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5814	PG0457	2017-07-16 11:10:00+03	2017-07-16 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-16 11:15:00+03	2017-07-16 13:28:00+03
5815	PG0456	2017-08-20 16:15:00+03	2017-08-20 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5816	PG0456	2017-09-11 16:15:00+03	2017-09-11 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5817	PG0457	2017-08-10 11:10:00+03	2017-08-10 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-10 11:13:00+03	2017-08-10 13:26:00+03
5818	PG0457	2017-09-11 11:10:00+03	2017-09-11 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5819	PG0456	2017-08-03 16:15:00+03	2017-08-03 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-03 16:18:00+03	2017-08-03 18:31:00+03
5820	PG0457	2017-08-20 11:10:00+03	2017-08-20 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5821	PG0457	2017-07-29 11:10:00+03	2017-07-29 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-29 11:15:00+03	2017-07-29 13:30:00+03
5822	PG0456	2017-08-21 16:15:00+03	2017-08-21 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5823	PG0457	2017-08-29 11:10:00+03	2017-08-29 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5824	PG0456	2017-07-29 16:15:00+03	2017-07-29 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-29 16:19:00+03	2017-07-29 18:35:00+03
5825	PG0456	2017-08-14 16:15:00+03	2017-08-14 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-14 16:17:00+03	2017-08-14 18:36:00+03
5826	PG0457	2017-08-11 11:10:00+03	2017-08-11 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-11 11:13:00+03	2017-08-11 13:28:00+03
5827	PG0457	2017-08-02 11:10:00+03	2017-08-02 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-02 11:13:00+03	2017-08-02 13:28:00+03
5828	PG0456	2017-07-17 16:15:00+03	2017-07-17 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-17 16:20:00+03	2017-07-17 18:35:00+03
5829	PG0457	2017-08-14 11:10:00+03	2017-08-14 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-14 11:11:00+03	2017-08-14 13:28:00+03
5830	PG0457	2017-07-17 11:10:00+03	2017-07-17 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-17 11:15:00+03	2017-07-17 13:31:00+03
5831	PG0457	2017-08-08 11:10:00+03	2017-08-08 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-08 11:15:00+03	2017-08-08 13:30:00+03
5832	PG0456	2017-08-30 16:15:00+03	2017-08-30 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5833	PG0457	2017-07-23 11:10:00+03	2017-07-23 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-23 11:16:00+03	2017-07-23 13:31:00+03
5834	PG0456	2017-08-11 16:15:00+03	2017-08-11 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-11 16:18:00+03	2017-08-11 18:33:00+03
5835	PG0456	2017-08-18 16:15:00+03	2017-08-18 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5836	PG0457	2017-08-25 11:10:00+03	2017-08-25 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5837	PG0457	2017-07-22 11:10:00+03	2017-07-22 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-22 11:13:00+03	2017-07-22 13:28:00+03
5838	PG0456	2017-08-07 16:15:00+03	2017-08-07 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-07 16:18:00+03	2017-08-07 18:32:00+03
5839	PG0456	2017-08-08 16:15:00+03	2017-08-08 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-08 16:18:00+03	2017-08-08 18:33:00+03
5840	PG0456	2017-08-25 16:15:00+03	2017-08-25 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5841	PG0456	2017-08-16 16:15:00+03	2017-08-16 18:30:00+03	SVO	PES	On Time	CN1	\N	\N
5842	PG0456	2017-09-05 16:15:00+03	2017-09-05 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5843	PG0456	2017-09-08 16:15:00+03	2017-09-08 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5844	PG0456	2017-09-04 16:15:00+03	2017-09-04 18:30:00+03	SVO	PES	Scheduled	CN1	\N	\N
5845	PG0457	2017-08-18 11:10:00+03	2017-08-18 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5846	PG0457	2017-09-02 11:10:00+03	2017-09-02 13:25:00+03	SVO	PES	Scheduled	CN1	\N	\N
5847	PG0457	2017-08-16 11:10:00+03	2017-08-16 13:25:00+03	SVO	PES	On Time	CN1	\N	\N
5848	PG0457	2017-08-07 11:10:00+03	2017-08-07 13:25:00+03	SVO	PES	Arrived	CN1	2017-08-07 11:16:00+03	2017-08-07 13:31:00+03
5849	PG0456	2017-07-27 16:15:00+03	2017-07-27 18:30:00+03	SVO	PES	Arrived	CN1	2017-07-27 16:19:00+03	2017-07-27 18:35:00+03
5850	PG0457	2017-07-27 11:10:00+03	2017-07-27 13:25:00+03	SVO	PES	Arrived	CN1	2017-07-27 14:08:00+03	2017-07-27 16:20:00+03
5851	PG0456	2017-08-02 16:15:00+03	2017-08-02 18:30:00+03	SVO	PES	Arrived	CN1	2017-08-02 16:19:00+03	2017-08-02 18:34:00+03
5852	PG0496	2017-08-20 12:45:00+03	2017-08-20 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5853	PG0496	2017-09-06 12:45:00+03	2017-09-06 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5854	PG0496	2017-08-04 12:45:00+03	2017-08-04 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-04 12:46:00+03	2017-08-04 14:57:00+03
5855	PG0496	2017-08-07 12:45:00+03	2017-08-07 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-07 12:47:00+03	2017-08-07 14:57:00+03
5856	PG0496	2017-08-28 12:45:00+03	2017-08-28 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5857	PG0496	2017-07-19 12:45:00+03	2017-07-19 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-19 16:04:00+03	2017-07-19 18:15:00+03
5858	PG0496	2017-09-02 12:45:00+03	2017-09-02 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5859	PG0496	2017-07-26 12:45:00+03	2017-07-26 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-26 12:47:00+03	2017-07-26 14:58:00+03
5860	PG0496	2017-09-07 12:45:00+03	2017-09-07 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5861	PG0496	2017-08-16 12:45:00+03	2017-08-16 14:55:00+03	SVO	JOK	On Time	CN1	\N	\N
5862	PG0496	2017-09-04 12:45:00+03	2017-09-04 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5863	PG0496	2017-09-09 12:45:00+03	2017-09-09 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5864	PG0496	2017-07-30 12:45:00+03	2017-07-30 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-30 15:56:00+03	2017-07-30 18:07:00+03
5865	PG0496	2017-08-10 12:45:00+03	2017-08-10 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-10 12:49:00+03	2017-08-10 14:58:00+03
5866	PG0496	2017-07-16 12:45:00+03	2017-07-16 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-16 12:48:00+03	2017-07-16 14:59:00+03
5867	PG0496	2017-08-21 12:45:00+03	2017-08-21 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5868	PG0496	2017-07-31 12:45:00+03	2017-07-31 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-31 12:52:00+03	2017-07-31 15:02:00+03
5869	PG0496	2017-09-10 12:45:00+03	2017-09-10 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5870	PG0496	2017-08-12 12:45:00+03	2017-08-12 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-12 12:49:00+03	2017-08-12 15:01:00+03
5871	PG0496	2017-08-02 12:45:00+03	2017-08-02 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-02 12:47:00+03	2017-08-02 14:59:00+03
5872	PG0496	2017-09-03 12:45:00+03	2017-09-03 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5873	PG0496	2017-08-18 12:45:00+03	2017-08-18 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5874	PG0496	2017-09-08 12:45:00+03	2017-09-08 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5875	PG0496	2017-08-03 12:45:00+03	2017-08-03 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-03 12:50:00+03	2017-08-03 15:02:00+03
5876	PG0496	2017-09-13 12:45:00+03	2017-09-13 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5877	PG0496	2017-09-01 12:45:00+03	2017-09-01 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5878	PG0496	2017-08-13 12:45:00+03	2017-08-13 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-13 12:48:00+03	2017-08-13 14:59:00+03
5879	PG0496	2017-08-01 12:45:00+03	2017-08-01 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-01 12:49:00+03	2017-08-01 15:00:00+03
5880	PG0496	2017-07-25 12:45:00+03	2017-07-25 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-25 12:46:00+03	2017-07-25 14:56:00+03
5881	PG0496	2017-09-12 12:45:00+03	2017-09-12 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5882	PG0496	2017-09-14 12:45:00+03	2017-09-14 14:55:00+03	SVO	JOK	Cancelled	CN1	\N	\N
5883	PG0496	2017-07-21 12:45:00+03	2017-07-21 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-21 12:49:00+03	2017-07-21 14:59:00+03
5884	PG0496	2017-08-15 12:45:00+03	2017-08-15 14:55:00+03	SVO	JOK	Departed	CN1	2017-08-15 15:53:00+03	\N
5885	PG0496	2017-07-17 12:45:00+03	2017-07-17 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-17 12:51:00+03	2017-07-17 15:04:00+03
5886	PG0496	2017-08-06 12:45:00+03	2017-08-06 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-06 12:47:00+03	2017-08-06 14:56:00+03
5887	PG0496	2017-08-14 12:45:00+03	2017-08-14 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-14 12:49:00+03	2017-08-14 15:02:00+03
5888	PG0496	2017-08-24 12:45:00+03	2017-08-24 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5889	PG0496	2017-08-23 12:45:00+03	2017-08-23 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5890	PG0496	2017-08-05 12:45:00+03	2017-08-05 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-05 12:52:00+03	2017-08-05 15:01:00+03
5891	PG0496	2017-09-05 12:45:00+03	2017-09-05 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5892	PG0496	2017-08-19 12:45:00+03	2017-08-19 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5893	PG0496	2017-08-08 12:45:00+03	2017-08-08 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-08 12:48:00+03	2017-08-08 14:59:00+03
5894	PG0496	2017-07-28 12:45:00+03	2017-07-28 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-28 12:47:00+03	2017-07-28 14:54:00+03
5895	PG0496	2017-07-24 12:45:00+03	2017-07-24 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-24 12:49:00+03	2017-07-24 15:00:00+03
5896	PG0496	2017-07-29 12:45:00+03	2017-07-29 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-29 12:45:00+03	2017-07-29 14:56:00+03
5897	PG0496	2017-08-22 12:45:00+03	2017-08-22 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5898	PG0496	2017-08-25 12:45:00+03	2017-08-25 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5899	PG0496	2017-08-26 12:45:00+03	2017-08-26 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5900	PG0496	2017-08-29 12:45:00+03	2017-08-29 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5901	PG0496	2017-08-27 12:45:00+03	2017-08-27 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5902	PG0496	2017-08-11 12:45:00+03	2017-08-11 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-11 12:49:00+03	2017-08-11 15:00:00+03
5903	PG0496	2017-07-22 12:45:00+03	2017-07-22 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-22 12:49:00+03	2017-07-22 14:59:00+03
5904	PG0496	2017-08-17 12:45:00+03	2017-08-17 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5905	PG0496	2017-07-27 12:45:00+03	2017-07-27 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-27 12:48:00+03	2017-07-27 14:56:00+03
5906	PG0496	2017-07-20 12:45:00+03	2017-07-20 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-20 12:53:00+03	2017-07-20 15:04:00+03
5907	PG0496	2017-09-11 12:45:00+03	2017-09-11 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5908	PG0496	2017-07-23 12:45:00+03	2017-07-23 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-23 12:48:00+03	2017-07-23 14:59:00+03
5909	PG0496	2017-08-31 12:45:00+03	2017-08-31 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5910	PG0496	2017-08-30 12:45:00+03	2017-08-30 14:55:00+03	SVO	JOK	Scheduled	CN1	\N	\N
5911	PG0496	2017-08-09 12:45:00+03	2017-08-09 14:55:00+03	SVO	JOK	Arrived	CN1	2017-08-09 12:49:00+03	2017-08-09 14:59:00+03
5912	PG0496	2017-07-18 12:45:00+03	2017-07-18 14:55:00+03	SVO	JOK	Arrived	CN1	2017-07-18 12:48:00+03	2017-07-18 14:57:00+03
5913	PG0281	2017-08-30 10:20:00+03	2017-08-30 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5914	PG0281	2017-08-20 10:20:00+03	2017-08-20 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5915	PG0281	2017-07-31 10:20:00+03	2017-07-31 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-31 10:22:00+03	2017-07-31 12:16:00+03
5916	PG0281	2017-08-23 10:20:00+03	2017-08-23 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5917	PG0281	2017-08-04 10:20:00+03	2017-08-04 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-04 10:22:00+03	2017-08-04 12:17:00+03
5918	PG0281	2017-08-15 10:20:00+03	2017-08-15 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-15 10:22:00+03	2017-08-15 12:16:00+03
5919	PG0281	2017-09-01 10:20:00+03	2017-09-01 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5920	PG0281	2017-08-19 10:20:00+03	2017-08-19 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5921	PG0281	2017-09-14 10:20:00+03	2017-09-14 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5922	PG0281	2017-08-05 10:20:00+03	2017-08-05 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-05 10:23:00+03	2017-08-05 12:17:00+03
5923	PG0281	2017-08-26 10:20:00+03	2017-08-26 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5924	PG0281	2017-08-27 10:20:00+03	2017-08-27 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5925	PG0281	2017-09-07 10:20:00+03	2017-09-07 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5926	PG0281	2017-08-14 10:20:00+03	2017-08-14 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-14 10:23:00+03	2017-08-14 12:18:00+03
5927	PG0281	2017-07-20 10:20:00+03	2017-07-20 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-20 13:37:00+03	2017-07-20 15:33:00+03
5928	PG0281	2017-07-19 10:20:00+03	2017-07-19 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-19 10:23:00+03	2017-07-19 12:19:00+03
5929	PG0281	2017-07-17 10:20:00+03	2017-07-17 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-17 10:22:00+03	2017-07-17 12:17:00+03
5930	PG0281	2017-07-27 10:20:00+03	2017-07-27 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-27 10:22:00+03	2017-07-27 12:17:00+03
5931	PG0281	2017-07-18 10:20:00+03	2017-07-18 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-18 10:23:00+03	2017-07-18 12:17:00+03
5932	PG0281	2017-08-17 10:20:00+03	2017-08-17 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5933	PG0281	2017-08-09 10:20:00+03	2017-08-09 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-09 10:21:00+03	2017-08-09 12:16:00+03
5934	PG0281	2017-08-10 10:20:00+03	2017-08-10 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-10 10:28:00+03	2017-08-10 12:25:00+03
5935	PG0281	2017-08-29 10:20:00+03	2017-08-29 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5936	PG0281	2017-09-11 10:20:00+03	2017-09-11 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5937	PG0281	2017-08-31 10:20:00+03	2017-08-31 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5938	PG0281	2017-09-04 10:20:00+03	2017-09-04 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5939	PG0281	2017-09-10 10:20:00+03	2017-09-10 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5940	PG0281	2017-08-16 10:20:00+03	2017-08-16 12:15:00+03	SVO	PKV	On Time	CN1	\N	\N
5941	PG0281	2017-08-01 10:20:00+03	2017-08-01 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-01 10:26:00+03	2017-08-01 12:22:00+03
5942	PG0281	2017-09-05 10:20:00+03	2017-09-05 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5943	PG0281	2017-08-28 10:20:00+03	2017-08-28 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5944	PG0281	2017-08-24 10:20:00+03	2017-08-24 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5945	PG0281	2017-07-16 10:20:00+03	2017-07-16 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-16 10:23:00+03	2017-07-16 12:19:00+03
5946	PG0281	2017-07-30 10:20:00+03	2017-07-30 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-30 13:43:00+03	2017-07-30 15:37:00+03
5947	PG0281	2017-08-22 10:20:00+03	2017-08-22 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5948	PG0281	2017-09-13 10:20:00+03	2017-09-13 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5949	PG0281	2017-09-02 10:20:00+03	2017-09-02 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5950	PG0281	2017-08-18 10:20:00+03	2017-08-18 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5951	PG0281	2017-07-21 10:20:00+03	2017-07-21 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-21 10:22:00+03	2017-07-21 12:18:00+03
5952	PG0281	2017-08-12 10:20:00+03	2017-08-12 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-12 10:23:00+03	2017-08-12 12:19:00+03
5953	PG0281	2017-08-08 10:20:00+03	2017-08-08 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-08 10:23:00+03	2017-08-08 12:18:00+03
5954	PG0281	2017-07-23 10:20:00+03	2017-07-23 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-23 10:25:00+03	2017-07-23 12:21:00+03
5955	PG0281	2017-07-22 10:20:00+03	2017-07-22 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-22 10:21:00+03	2017-07-22 12:16:00+03
5956	PG0281	2017-08-21 10:20:00+03	2017-08-21 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5957	PG0281	2017-08-03 10:20:00+03	2017-08-03 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-03 10:22:00+03	2017-08-03 12:18:00+03
5958	PG0281	2017-08-11 10:20:00+03	2017-08-11 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-11 10:24:00+03	2017-08-11 12:20:00+03
5959	PG0281	2017-09-12 10:20:00+03	2017-09-12 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5960	PG0281	2017-09-03 10:20:00+03	2017-09-03 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5961	PG0281	2017-07-28 10:20:00+03	2017-07-28 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-28 10:24:00+03	2017-07-28 12:16:00+03
5962	PG0281	2017-07-29 10:20:00+03	2017-07-29 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-29 10:22:00+03	2017-07-29 12:15:00+03
5963	PG0281	2017-08-13 10:20:00+03	2017-08-13 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-13 10:23:00+03	2017-08-13 12:20:00+03
5964	PG0281	2017-07-26 10:20:00+03	2017-07-26 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-26 10:23:00+03	2017-07-26 12:19:00+03
5965	PG0281	2017-09-09 10:20:00+03	2017-09-09 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5966	PG0281	2017-09-06 10:20:00+03	2017-09-06 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5967	PG0281	2017-07-24 10:20:00+03	2017-07-24 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-24 10:22:00+03	2017-07-24 12:17:00+03
5968	PG0281	2017-08-07 10:20:00+03	2017-08-07 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-07 10:22:00+03	2017-08-07 12:17:00+03
5969	PG0281	2017-08-02 10:20:00+03	2017-08-02 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-02 10:24:00+03	2017-08-02 12:19:00+03
5970	PG0281	2017-07-25 10:20:00+03	2017-07-25 12:15:00+03	SVO	PKV	Arrived	CN1	2017-07-25 10:26:00+03	2017-07-25 12:23:00+03
5971	PG0281	2017-08-06 10:20:00+03	2017-08-06 12:15:00+03	SVO	PKV	Arrived	CN1	2017-08-06 10:22:00+03	2017-08-06 12:17:00+03
5972	PG0281	2017-09-08 10:20:00+03	2017-09-08 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5973	PG0281	2017-08-25 10:20:00+03	2017-08-25 12:15:00+03	SVO	PKV	Scheduled	CN1	\N	\N
5974	PG0703	2017-08-31 17:15:00+03	2017-09-01 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5975	PG0703	2017-08-06 17:15:00+03	2017-08-07 02:00:00+03	SVO	UUS	Arrived	319	2017-08-06 17:20:00+03	2017-08-07 02:07:00+03
5976	PG0703	2017-08-08 17:15:00+03	2017-08-09 02:00:00+03	SVO	UUS	Arrived	319	2017-08-08 17:17:00+03	2017-08-09 01:50:00+03
5977	PG0703	2017-08-07 17:15:00+03	2017-08-08 02:00:00+03	SVO	UUS	Arrived	319	2017-08-07 17:17:00+03	2017-08-08 02:03:00+03
5978	PG0703	2017-07-26 17:15:00+03	2017-07-27 02:00:00+03	SVO	UUS	Arrived	319	2017-07-26 17:18:00+03	2017-07-27 02:02:00+03
5979	PG0703	2017-07-30 17:15:00+03	2017-07-31 02:00:00+03	SVO	UUS	Arrived	319	2017-07-30 17:18:00+03	2017-07-31 02:10:00+03
5980	PG0703	2017-08-09 17:15:00+03	2017-08-10 02:00:00+03	SVO	UUS	Arrived	319	2017-08-09 17:19:00+03	2017-08-10 02:05:00+03
5981	PG0703	2017-08-26 17:15:00+03	2017-08-27 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5982	PG0703	2017-08-23 17:15:00+03	2017-08-24 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5983	PG0703	2017-08-13 17:15:00+03	2017-08-14 02:00:00+03	SVO	UUS	Arrived	319	2017-08-13 17:16:00+03	2017-08-14 01:56:00+03
5984	PG0703	2017-07-17 17:15:00+03	2017-07-18 02:00:00+03	SVO	UUS	Arrived	319	2017-07-17 17:19:00+03	2017-07-18 01:59:00+03
5985	PG0703	2017-08-10 17:15:00+03	2017-08-11 02:00:00+03	SVO	UUS	Arrived	319	2017-08-10 17:15:00+03	2017-08-11 01:57:00+03
5986	PG0703	2017-09-08 17:15:00+03	2017-09-09 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5987	PG0703	2017-09-14 17:15:00+03	2017-09-15 02:00:00+03	SVO	UUS	Cancelled	319	\N	\N
5988	PG0703	2017-07-19 17:15:00+03	2017-07-20 02:00:00+03	SVO	UUS	Arrived	319	2017-07-19 17:17:00+03	2017-07-20 02:12:00+03
5989	PG0703	2017-09-02 17:15:00+03	2017-09-03 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5990	PG0703	2017-08-16 17:15:00+03	2017-08-17 02:00:00+03	SVO	UUS	On Time	319	\N	\N
5991	PG0703	2017-08-04 17:15:00+03	2017-08-05 02:00:00+03	SVO	UUS	Arrived	319	2017-08-04 17:17:00+03	2017-08-05 01:55:00+03
5992	PG0703	2017-09-03 17:15:00+03	2017-09-04 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5993	PG0703	2017-07-18 17:15:00+03	2017-07-19 02:00:00+03	SVO	UUS	Arrived	319	2017-07-18 17:19:00+03	2017-07-19 02:02:00+03
5994	PG0703	2017-08-21 17:15:00+03	2017-08-22 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5995	PG0703	2017-07-16 17:15:00+03	2017-07-17 02:00:00+03	SVO	UUS	Arrived	319	2017-07-16 17:19:00+03	2017-07-17 01:57:00+03
5996	PG0703	2017-08-05 17:15:00+03	2017-08-06 02:00:00+03	SVO	UUS	Arrived	319	2017-08-05 17:18:00+03	2017-08-06 02:05:00+03
5997	PG0703	2017-08-18 17:15:00+03	2017-08-19 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5998	PG0703	2017-09-13 17:15:00+03	2017-09-14 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
5999	PG0703	2017-08-12 17:15:00+03	2017-08-13 02:00:00+03	SVO	UUS	Arrived	319	2017-08-12 17:17:00+03	2017-08-13 02:03:00+03
6000	PG0703	2017-09-06 17:15:00+03	2017-09-07 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6001	PG0703	2017-09-05 17:15:00+03	2017-09-06 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6002	PG0703	2017-08-19 17:15:00+03	2017-08-20 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6003	PG0703	2017-07-31 17:15:00+03	2017-08-01 02:00:00+03	SVO	UUS	Arrived	319	2017-07-31 17:19:00+03	2017-08-01 02:07:00+03
6004	PG0703	2017-07-22 17:15:00+03	2017-07-23 02:00:00+03	SVO	UUS	Arrived	319	2017-07-22 17:16:00+03	2017-07-23 02:06:00+03
6005	PG0703	2017-07-21 17:15:00+03	2017-07-22 02:00:00+03	SVO	UUS	Arrived	319	2017-07-21 17:18:00+03	2017-07-22 02:02:00+03
6006	PG0703	2017-07-29 17:15:00+03	2017-07-30 02:00:00+03	SVO	UUS	Arrived	319	2017-07-29 17:16:00+03	2017-07-30 01:59:00+03
6007	PG0703	2017-08-25 17:15:00+03	2017-08-26 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6008	PG0703	2017-08-20 17:15:00+03	2017-08-21 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6009	PG0703	2017-09-10 17:15:00+03	2017-09-11 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6010	PG0703	2017-08-15 17:15:00+03	2017-08-16 02:00:00+03	SVO	UUS	Departed	319	2017-08-15 17:19:00+03	\N
6011	PG0703	2017-08-11 17:15:00+03	2017-08-12 02:00:00+03	SVO	UUS	Arrived	319	2017-08-11 17:20:00+03	2017-08-12 02:19:00+03
6012	PG0703	2017-07-24 17:15:00+03	2017-07-25 02:00:00+03	SVO	UUS	Arrived	319	2017-07-24 17:21:00+03	2017-07-25 02:03:00+03
6013	PG0703	2017-08-01 17:15:00+03	2017-08-02 02:00:00+03	SVO	UUS	Arrived	319	2017-08-01 17:23:00+03	2017-08-02 02:09:00+03
6014	PG0703	2017-08-28 17:15:00+03	2017-08-29 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6015	PG0703	2017-07-28 17:15:00+03	2017-07-29 02:00:00+03	SVO	UUS	Arrived	319	2017-07-28 17:17:00+03	2017-07-29 01:59:00+03
6016	PG0703	2017-08-03 17:15:00+03	2017-08-04 02:00:00+03	SVO	UUS	Arrived	319	2017-08-03 17:18:00+03	2017-08-04 02:01:00+03
6017	PG0703	2017-08-30 17:15:00+03	2017-08-31 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6018	PG0703	2017-07-25 17:15:00+03	2017-07-26 02:00:00+03	SVO	UUS	Arrived	319	2017-07-25 17:19:00+03	2017-07-26 01:55:00+03
6019	PG0703	2017-07-23 17:15:00+03	2017-07-24 02:00:00+03	SVO	UUS	Arrived	319	2017-07-23 17:17:00+03	2017-07-24 02:07:00+03
6020	PG0703	2017-09-01 17:15:00+03	2017-09-02 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6021	PG0703	2017-07-27 17:15:00+03	2017-07-28 02:00:00+03	SVO	UUS	Arrived	319	2017-07-27 17:19:00+03	2017-07-28 02:15:00+03
6022	PG0703	2017-08-17 17:15:00+03	2017-08-18 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6023	PG0703	2017-08-14 17:15:00+03	2017-08-15 02:00:00+03	SVO	UUS	Arrived	319	2017-08-14 17:19:00+03	2017-08-15 02:00:00+03
6024	PG0703	2017-08-22 17:15:00+03	2017-08-23 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6025	PG0703	2017-09-04 17:15:00+03	2017-09-05 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6026	PG0703	2017-09-09 17:15:00+03	2017-09-10 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6027	PG0703	2017-08-29 17:15:00+03	2017-08-30 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6028	PG0703	2017-08-02 17:15:00+03	2017-08-03 02:00:00+03	SVO	UUS	Arrived	319	2017-08-02 17:19:00+03	2017-08-03 02:05:00+03
6029	PG0703	2017-09-11 17:15:00+03	2017-09-12 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6030	PG0703	2017-07-20 17:15:00+03	2017-07-21 02:00:00+03	SVO	UUS	Arrived	319	2017-07-20 17:18:00+03	2017-07-21 02:04:00+03
6031	PG0703	2017-09-07 17:15:00+03	2017-09-08 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6032	PG0703	2017-09-12 17:15:00+03	2017-09-13 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6033	PG0703	2017-08-27 17:15:00+03	2017-08-28 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6034	PG0703	2017-08-24 17:15:00+03	2017-08-25 02:00:00+03	SVO	UUS	Scheduled	319	\N	\N
6035	PG0291	2017-09-01 11:35:00+03	2017-09-01 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6036	PG0291	2017-07-17 11:35:00+03	2017-07-17 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-17 11:40:00+03	2017-07-17 14:43:00+03
6037	PG0291	2017-09-10 11:35:00+03	2017-09-10 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6038	PG0291	2017-08-19 11:35:00+03	2017-08-19 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6039	PG0291	2017-08-28 11:35:00+03	2017-08-28 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6040	PG0291	2017-07-19 11:35:00+03	2017-07-19 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-19 11:36:00+03	2017-07-19 14:44:00+03
6041	PG0291	2017-08-31 11:35:00+03	2017-08-31 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6042	PG0291	2017-08-29 11:35:00+03	2017-08-29 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6043	PG0291	2017-08-25 11:35:00+03	2017-08-25 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6044	PG0291	2017-08-10 11:35:00+03	2017-08-10 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-10 11:39:00+03	2017-08-10 14:44:00+03
6045	PG0291	2017-09-04 11:35:00+03	2017-09-04 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6046	PG0291	2017-08-09 11:35:00+03	2017-08-09 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-09 11:36:00+03	2017-08-09 14:41:00+03
6047	PG0291	2017-08-01 11:35:00+03	2017-08-01 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-01 11:37:00+03	2017-08-01 14:42:00+03
6048	PG0291	2017-07-20 11:35:00+03	2017-07-20 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-20 11:38:00+03	2017-07-20 14:44:00+03
6049	PG0291	2017-09-05 11:35:00+03	2017-09-05 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6050	PG0291	2017-07-16 11:35:00+03	2017-07-16 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-16 11:38:00+03	2017-07-16 14:44:00+03
6051	PG0291	2017-08-18 11:35:00+03	2017-08-18 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6052	PG0291	2017-09-13 11:35:00+03	2017-09-13 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6053	PG0291	2017-07-29 11:35:00+03	2017-07-29 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-29 15:27:00+03	2017-07-29 18:36:00+03
6054	PG0291	2017-08-22 11:35:00+03	2017-08-22 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6055	PG0291	2017-07-23 11:35:00+03	2017-07-23 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-23 11:38:00+03	2017-07-23 14:43:00+03
6056	PG0291	2017-08-12 11:35:00+03	2017-08-12 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-12 14:59:00+03	2017-08-12 18:04:00+03
6057	PG0291	2017-08-08 11:35:00+03	2017-08-08 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-08 11:38:00+03	2017-08-08 14:44:00+03
6058	PG0291	2017-07-28 11:35:00+03	2017-07-28 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-28 11:36:00+03	2017-07-28 14:37:00+03
6059	PG0291	2017-09-09 11:35:00+03	2017-09-09 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6060	PG0291	2017-09-06 11:35:00+03	2017-09-06 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6061	PG0291	2017-08-06 11:35:00+03	2017-08-06 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-06 11:39:00+03	2017-08-06 14:43:00+03
6062	PG0291	2017-07-26 11:35:00+03	2017-07-26 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-26 11:35:00+03	2017-07-26 14:39:00+03
6063	PG0291	2017-08-30 11:35:00+03	2017-08-30 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6064	PG0291	2017-08-27 11:35:00+03	2017-08-27 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6065	PG0291	2017-07-30 11:35:00+03	2017-07-30 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-30 11:37:00+03	2017-07-30 14:43:00+03
6066	PG0291	2017-08-07 11:35:00+03	2017-08-07 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-07 14:56:00+03	2017-08-07 18:03:00+03
6067	PG0291	2017-08-16 11:35:00+03	2017-08-16 14:40:00+03	SVO	NUX	On Time	SU9	\N	\N
6068	PG0291	2017-07-25 11:35:00+03	2017-07-25 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-25 11:43:00+03	2017-07-25 14:46:00+03
6069	PG0291	2017-08-04 11:35:00+03	2017-08-04 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-04 11:40:00+03	2017-08-04 14:45:00+03
6070	PG0291	2017-08-24 11:35:00+03	2017-08-24 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6071	PG0291	2017-07-24 11:35:00+03	2017-07-24 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-24 11:41:00+03	2017-07-24 14:44:00+03
6072	PG0291	2017-08-15 11:35:00+03	2017-08-15 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-15 11:38:00+03	2017-08-15 14:45:00+03
6073	PG0291	2017-09-14 11:35:00+03	2017-09-14 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6074	PG0291	2017-08-26 11:35:00+03	2017-08-26 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6075	PG0291	2017-07-31 11:35:00+03	2017-07-31 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-31 11:38:00+03	2017-07-31 14:43:00+03
6076	PG0291	2017-09-11 11:35:00+03	2017-09-11 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6077	PG0291	2017-08-05 11:35:00+03	2017-08-05 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-05 11:36:00+03	2017-08-05 14:41:00+03
6078	PG0291	2017-08-03 11:35:00+03	2017-08-03 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-03 11:37:00+03	2017-08-03 14:43:00+03
6079	PG0291	2017-09-07 11:35:00+03	2017-09-07 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6080	PG0291	2017-08-21 11:35:00+03	2017-08-21 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6081	PG0291	2017-09-02 11:35:00+03	2017-09-02 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6082	PG0291	2017-09-12 11:35:00+03	2017-09-12 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6083	PG0291	2017-08-02 11:35:00+03	2017-08-02 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-02 11:38:00+03	2017-08-02 14:43:00+03
6084	PG0291	2017-08-17 11:35:00+03	2017-08-17 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6085	PG0291	2017-07-22 11:35:00+03	2017-07-22 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-22 11:38:00+03	2017-07-22 14:45:00+03
6086	PG0291	2017-08-11 11:35:00+03	2017-08-11 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-11 11:39:00+03	2017-08-11 14:44:00+03
6087	PG0291	2017-08-13 11:35:00+03	2017-08-13 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-13 11:38:00+03	2017-08-13 14:43:00+03
6088	PG0291	2017-08-20 11:35:00+03	2017-08-20 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6089	PG0291	2017-09-08 11:35:00+03	2017-09-08 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6090	PG0291	2017-09-03 11:35:00+03	2017-09-03 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6091	PG0291	2017-07-21 11:35:00+03	2017-07-21 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-21 11:39:00+03	2017-07-21 14:43:00+03
6092	PG0291	2017-07-27 11:35:00+03	2017-07-27 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-27 11:36:00+03	2017-07-27 14:43:00+03
6093	PG0291	2017-07-18 11:35:00+03	2017-07-18 14:40:00+03	SVO	NUX	Arrived	SU9	2017-07-18 11:36:00+03	2017-07-18 14:45:00+03
6094	PG0291	2017-08-14 11:35:00+03	2017-08-14 14:40:00+03	SVO	NUX	Arrived	SU9	2017-08-14 11:44:00+03	2017-08-14 14:49:00+03
6095	PG0291	2017-08-23 11:35:00+03	2017-08-23 14:40:00+03	SVO	NUX	Scheduled	SU9	\N	\N
6096	PG0661	2017-08-19 13:05:00+03	2017-08-19 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6097	PG0661	2017-08-15 13:05:00+03	2017-08-15 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-08-15 13:08:00+03	2017-08-15 16:17:00+03
6098	PG0661	2017-07-22 13:05:00+03	2017-07-22 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-07-22 13:07:00+03	2017-07-22 16:16:00+03
6099	PG0661	2017-07-18 13:05:00+03	2017-07-18 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-07-18 13:06:00+03	2017-07-18 16:17:00+03
6100	PG0661	2017-08-29 13:05:00+03	2017-08-29 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6101	PG0661	2017-07-25 13:05:00+03	2017-07-25 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-07-25 13:09:00+03	2017-07-25 16:23:00+03
6102	PG0661	2017-07-29 13:05:00+03	2017-07-29 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-07-29 13:07:00+03	2017-07-29 16:15:00+03
6103	PG0661	2017-08-22 13:05:00+03	2017-08-22 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6104	PG0661	2017-08-05 13:05:00+03	2017-08-05 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-08-05 13:08:00+03	2017-08-05 16:19:00+03
6105	PG0661	2017-08-01 13:05:00+03	2017-08-01 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-08-01 13:10:00+03	2017-08-01 16:20:00+03
6106	PG0661	2017-09-02 13:05:00+03	2017-09-02 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6107	PG0661	2017-08-08 13:05:00+03	2017-08-08 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-08-08 13:07:00+03	2017-08-08 16:19:00+03
6108	PG0661	2017-09-09 13:05:00+03	2017-09-09 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6109	PG0661	2017-09-05 13:05:00+03	2017-09-05 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6110	PG0661	2017-08-12 13:05:00+03	2017-08-12 16:15:00+03	SVO	NOJ	Arrived	CR2	2017-08-12 13:08:00+03	2017-08-12 16:19:00+03
6111	PG0661	2017-09-12 13:05:00+03	2017-09-12 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6112	PG0661	2017-08-26 13:05:00+03	2017-08-26 16:15:00+03	SVO	NOJ	Scheduled	CR2	\N	\N
6113	PG0299	2017-09-06 13:00:00+03	2017-09-06 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6114	PG0299	2017-08-27 13:00:00+03	2017-08-27 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6115	PG0299	2017-07-25 13:00:00+03	2017-07-25 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-25 13:05:00+03	2017-07-25 16:52:00+03
6116	PG0299	2017-08-30 13:00:00+03	2017-08-30 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6117	PG0299	2017-08-04 13:00:00+03	2017-08-04 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-04 13:05:00+03	2017-08-04 16:56:00+03
6118	PG0299	2017-08-03 13:00:00+03	2017-08-03 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-03 13:01:00+03	2017-08-03 16:48:00+03
6119	PG0299	2017-07-24 13:00:00+03	2017-07-24 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-24 13:03:00+03	2017-07-24 16:55:00+03
6120	PG0299	2017-08-15 13:00:00+03	2017-08-15 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-15 13:02:00+03	2017-08-15 16:48:00+03
6121	PG0299	2017-08-17 13:00:00+03	2017-08-17 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6122	PG0299	2017-08-13 13:00:00+03	2017-08-13 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-13 13:03:00+03	2017-08-13 16:56:00+03
6123	PG0299	2017-09-01 13:00:00+03	2017-09-01 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6124	PG0299	2017-07-30 13:00:00+03	2017-07-30 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-30 13:02:00+03	2017-07-30 16:51:00+03
6125	PG0299	2017-08-16 13:00:00+03	2017-08-16 16:50:00+03	SVO	ESL	On Time	CN1	\N	\N
6126	PG0299	2017-08-20 13:00:00+03	2017-08-20 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6127	PG0299	2017-07-22 13:00:00+03	2017-07-22 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-22 13:03:00+03	2017-07-22 16:54:00+03
6128	PG0299	2017-09-05 13:00:00+03	2017-09-05 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6129	PG0299	2017-09-04 13:00:00+03	2017-09-04 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6130	PG0299	2017-08-02 13:00:00+03	2017-08-02 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-02 13:04:00+03	2017-08-02 16:54:00+03
6131	PG0299	2017-09-09 13:00:00+03	2017-09-09 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6132	PG0299	2017-08-14 13:00:00+03	2017-08-14 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-14 16:42:00+03	2017-08-14 20:35:00+03
6133	PG0299	2017-07-19 13:00:00+03	2017-07-19 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-19 13:02:00+03	2017-07-19 16:49:00+03
6134	PG0299	2017-08-11 13:00:00+03	2017-08-11 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-11 13:04:00+03	2017-08-11 16:57:00+03
6135	PG0299	2017-07-20 13:00:00+03	2017-07-20 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-20 13:03:00+03	2017-07-20 16:50:00+03
6136	PG0299	2017-08-26 13:00:00+03	2017-08-26 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6137	PG0299	2017-08-08 13:00:00+03	2017-08-08 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-08 13:03:00+03	2017-08-08 16:53:00+03
6138	PG0299	2017-07-17 13:00:00+03	2017-07-17 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-17 13:06:00+03	2017-07-17 16:56:00+03
6139	PG0299	2017-08-06 13:00:00+03	2017-08-06 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-06 13:04:00+03	2017-08-06 16:52:00+03
6140	PG0299	2017-08-22 13:00:00+03	2017-08-22 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6141	PG0299	2017-09-02 13:00:00+03	2017-09-02 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6142	PG0299	2017-07-28 13:00:00+03	2017-07-28 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-28 13:07:00+03	2017-07-28 16:58:00+03
6143	PG0299	2017-09-11 13:00:00+03	2017-09-11 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6144	PG0299	2017-08-07 13:00:00+03	2017-08-07 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-07 13:05:00+03	2017-08-07 16:54:00+03
6145	PG0299	2017-07-29 13:00:00+03	2017-07-29 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-29 13:02:00+03	2017-07-29 16:53:00+03
6146	PG0299	2017-08-12 13:00:00+03	2017-08-12 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-12 13:03:00+03	2017-08-12 16:53:00+03
6147	PG0299	2017-09-14 13:00:00+03	2017-09-14 16:50:00+03	SVO	ESL	Cancelled	CN1	\N	\N
6148	PG0299	2017-07-16 13:00:00+03	2017-07-16 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-16 13:02:00+03	2017-07-16 16:51:00+03
6149	PG0299	2017-08-18 13:00:00+03	2017-08-18 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6150	PG0299	2017-09-03 13:00:00+03	2017-09-03 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6151	PG0299	2017-08-25 13:00:00+03	2017-08-25 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6152	PG0299	2017-08-01 13:00:00+03	2017-08-01 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-01 13:00:00+03	2017-08-01 16:50:00+03
6153	PG0299	2017-08-23 13:00:00+03	2017-08-23 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6154	PG0299	2017-09-13 13:00:00+03	2017-09-13 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6155	PG0299	2017-08-31 13:00:00+03	2017-08-31 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6156	PG0299	2017-07-26 13:00:00+03	2017-07-26 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-26 13:04:00+03	2017-07-26 16:50:00+03
6157	PG0299	2017-08-28 13:00:00+03	2017-08-28 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6158	PG0299	2017-08-24 13:00:00+03	2017-08-24 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6159	PG0299	2017-08-09 13:00:00+03	2017-08-09 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-09 13:07:00+03	2017-08-09 16:57:00+03
6160	PG0299	2017-08-10 13:00:00+03	2017-08-10 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-10 13:06:00+03	2017-08-10 16:56:00+03
6161	PG0299	2017-07-18 13:00:00+03	2017-07-18 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-18 13:05:00+03	2017-07-18 16:52:00+03
6162	PG0299	2017-08-29 13:00:00+03	2017-08-29 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6163	PG0299	2017-08-21 13:00:00+03	2017-08-21 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6164	PG0299	2017-07-31 13:00:00+03	2017-07-31 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-31 13:02:00+03	2017-07-31 16:50:00+03
6165	PG0299	2017-08-19 13:00:00+03	2017-08-19 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6166	PG0299	2017-07-23 13:00:00+03	2017-07-23 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-23 13:01:00+03	2017-07-23 16:48:00+03
6167	PG0299	2017-09-10 13:00:00+03	2017-09-10 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6168	PG0299	2017-07-21 13:00:00+03	2017-07-21 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-21 13:04:00+03	2017-07-21 16:51:00+03
6169	PG0299	2017-07-27 13:00:00+03	2017-07-27 16:50:00+03	SVO	ESL	Arrived	CN1	2017-07-27 13:01:00+03	2017-07-27 16:56:00+03
6170	PG0299	2017-09-12 13:00:00+03	2017-09-12 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6171	PG0299	2017-09-08 13:00:00+03	2017-09-08 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6172	PG0299	2017-08-05 13:00:00+03	2017-08-05 16:50:00+03	SVO	ESL	Arrived	CN1	2017-08-05 13:04:00+03	2017-08-05 16:56:00+03
6173	PG0299	2017-09-07 13:00:00+03	2017-09-07 16:50:00+03	SVO	ESL	Scheduled	CN1	\N	\N
6174	PG0120	2017-08-05 09:00:00+03	2017-08-05 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-05 09:03:00+03	2017-08-05 14:42:00+03
6175	PG0120	2017-07-31 09:00:00+03	2017-07-31 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-31 09:06:00+03	2017-07-31 14:54:00+03
6176	PG0120	2017-09-14 09:00:00+03	2017-09-14 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6177	PG0120	2017-08-10 09:00:00+03	2017-08-10 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-10 09:02:00+03	2017-08-10 14:52:00+03
6178	PG0120	2017-08-29 09:00:00+03	2017-08-29 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6179	PG0120	2017-08-27 09:00:00+03	2017-08-27 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6180	PG0120	2017-08-04 09:00:00+03	2017-08-04 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-04 09:01:00+03	2017-08-04 14:44:00+03
6181	PG0120	2017-08-19 09:00:00+03	2017-08-19 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6182	PG0120	2017-09-11 09:00:00+03	2017-09-11 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6183	PG0120	2017-08-26 09:00:00+03	2017-08-26 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6184	PG0120	2017-08-08 09:00:00+03	2017-08-08 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-08 09:06:00+03	2017-08-08 14:53:00+03
6185	PG0120	2017-08-06 09:00:00+03	2017-08-06 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-06 09:02:00+03	2017-08-06 14:55:00+03
6186	PG0120	2017-08-25 09:00:00+03	2017-08-25 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6187	PG0120	2017-07-25 09:00:00+03	2017-07-25 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-25 09:03:00+03	2017-07-25 14:51:00+03
6188	PG0120	2017-08-30 09:00:00+03	2017-08-30 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6189	PG0120	2017-08-18 09:00:00+03	2017-08-18 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6190	PG0120	2017-08-03 09:00:00+03	2017-08-03 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-03 09:05:00+03	2017-08-03 14:50:00+03
6191	PG0120	2017-08-24 09:00:00+03	2017-08-24 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6192	PG0120	2017-08-13 09:00:00+03	2017-08-13 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-13 09:05:00+03	2017-08-13 14:55:00+03
6193	PG0120	2017-09-10 09:00:00+03	2017-09-10 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6194	PG0120	2017-08-02 09:00:00+03	2017-08-02 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-02 09:02:00+03	2017-08-02 14:44:00+03
6195	PG0120	2017-08-11 09:00:00+03	2017-08-11 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-11 09:03:00+03	2017-08-11 14:48:00+03
6196	PG0120	2017-07-19 09:00:00+03	2017-07-19 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-19 09:03:00+03	2017-07-19 14:53:00+03
6197	PG0120	2017-09-07 09:00:00+03	2017-09-07 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6198	PG0120	2017-09-13 09:00:00+03	2017-09-13 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6199	PG0120	2017-08-07 09:00:00+03	2017-08-07 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-07 09:04:00+03	2017-08-07 14:51:00+03
6200	PG0120	2017-07-24 09:00:00+03	2017-07-24 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-24 09:04:00+03	2017-07-24 14:47:00+03
6201	PG0120	2017-07-17 09:00:00+03	2017-07-17 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-17 09:03:00+03	2017-07-17 14:50:00+03
6202	PG0120	2017-09-09 09:00:00+03	2017-09-09 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6203	PG0120	2017-08-14 09:00:00+03	2017-08-14 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-14 09:02:00+03	2017-08-14 14:49:00+03
6204	PG0120	2017-09-02 09:00:00+03	2017-09-02 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6205	PG0120	2017-07-20 09:00:00+03	2017-07-20 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-20 09:01:00+03	2017-07-20 14:50:00+03
6206	PG0120	2017-08-15 09:00:00+03	2017-08-15 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-15 09:06:00+03	2017-08-15 14:58:00+03
6207	PG0120	2017-08-12 09:00:00+03	2017-08-12 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-12 09:00:00+03	2017-08-12 14:44:00+03
6208	PG0120	2017-09-12 09:00:00+03	2017-09-12 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6209	PG0120	2017-07-23 09:00:00+03	2017-07-23 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-23 09:05:00+03	2017-07-23 14:56:00+03
6210	PG0120	2017-07-28 09:00:00+03	2017-07-28 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-28 09:02:00+03	2017-07-28 14:44:00+03
6211	PG0120	2017-07-29 09:00:00+03	2017-07-29 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-29 09:03:00+03	2017-07-29 14:57:00+03
6212	PG0120	2017-09-01 09:00:00+03	2017-09-01 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6213	PG0120	2017-08-01 09:00:00+03	2017-08-01 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-01 09:01:00+03	2017-08-01 14:43:00+03
6214	PG0120	2017-07-26 09:00:00+03	2017-07-26 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-26 09:06:00+03	2017-07-26 14:48:00+03
6215	PG0120	2017-08-21 09:00:00+03	2017-08-21 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6216	PG0120	2017-08-23 09:00:00+03	2017-08-23 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6217	PG0120	2017-09-06 09:00:00+03	2017-09-06 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6218	PG0120	2017-09-08 09:00:00+03	2017-09-08 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6219	PG0120	2017-08-22 09:00:00+03	2017-08-22 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6220	PG0120	2017-07-22 09:00:00+03	2017-07-22 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-22 09:03:00+03	2017-07-22 14:48:00+03
6221	PG0120	2017-08-17 09:00:00+03	2017-08-17 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6222	PG0120	2017-09-04 09:00:00+03	2017-09-04 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6223	PG0120	2017-07-16 09:00:00+03	2017-07-16 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-16 09:03:00+03	2017-07-16 14:47:00+03
6224	PG0120	2017-09-03 09:00:00+03	2017-09-03 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6225	PG0120	2017-08-31 09:00:00+03	2017-08-31 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6226	PG0120	2017-09-05 09:00:00+03	2017-09-05 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6227	PG0120	2017-08-09 09:00:00+03	2017-08-09 14:45:00+03	SVO	MJZ	Arrived	733	2017-08-09 09:01:00+03	2017-08-09 14:43:00+03
6228	PG0120	2017-07-30 09:00:00+03	2017-07-30 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-30 09:04:00+03	2017-07-30 14:50:00+03
6229	PG0120	2017-08-16 09:00:00+03	2017-08-16 14:45:00+03	SVO	MJZ	On Time	733	\N	\N
6230	PG0120	2017-07-27 09:00:00+03	2017-07-27 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-27 09:02:00+03	2017-07-27 14:48:00+03
6231	PG0120	2017-08-20 09:00:00+03	2017-08-20 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6232	PG0120	2017-07-18 09:00:00+03	2017-07-18 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-18 09:04:00+03	2017-07-18 14:48:00+03
6233	PG0120	2017-07-21 09:00:00+03	2017-07-21 14:45:00+03	SVO	MJZ	Arrived	733	2017-07-21 09:03:00+03	2017-07-21 14:46:00+03
6234	PG0120	2017-08-28 09:00:00+03	2017-08-28 14:45:00+03	SVO	MJZ	Scheduled	733	\N	\N
6235	PG0179	2017-08-03 16:20:00+03	2017-08-03 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-03 16:23:00+03	2017-08-03 16:53:00+03
6236	PG0178	2017-09-12 14:45:00+03	2017-09-12 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6237	PG0179	2017-09-12 16:20:00+03	2017-09-12 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6238	PG0178	2017-07-25 14:45:00+03	2017-07-25 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-25 14:46:00+03	2017-07-25 15:16:00+03
6239	PG0178	2017-08-25 14:45:00+03	2017-08-25 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6240	PG0179	2017-07-24 16:20:00+03	2017-07-24 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-24 16:23:00+03	2017-07-24 16:53:00+03
6241	PG0178	2017-07-24 14:45:00+03	2017-07-24 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-24 14:45:00+03	2017-07-24 15:15:00+03
6242	PG0179	2017-07-25 16:20:00+03	2017-07-25 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-25 16:23:00+03	2017-07-25 16:53:00+03
6243	PG0178	2017-08-06 14:45:00+03	2017-08-06 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-06 14:46:00+03	2017-08-06 15:16:00+03
6244	PG0178	2017-07-19 14:45:00+03	2017-07-19 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-19 14:48:00+03	2017-07-19 15:18:00+03
6245	PG0179	2017-07-19 16:20:00+03	2017-07-19 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-19 16:23:00+03	2017-07-19 16:53:00+03
6246	PG0178	2017-07-31 14:45:00+03	2017-07-31 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-31 14:48:00+03	2017-07-31 15:18:00+03
6247	PG0179	2017-07-31 16:20:00+03	2017-07-31 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-31 16:22:00+03	2017-07-31 16:52:00+03
6248	PG0179	2017-08-13 16:20:00+03	2017-08-13 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-13 16:24:00+03	2017-08-13 16:54:00+03
6249	PG0178	2017-09-07 14:45:00+03	2017-09-07 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6250	PG0179	2017-08-30 16:20:00+03	2017-08-30 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6251	PG0178	2017-08-30 14:45:00+03	2017-08-30 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6252	PG0179	2017-09-07 16:20:00+03	2017-09-07 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6253	PG0178	2017-07-16 14:45:00+03	2017-07-16 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-16 14:51:00+03	2017-07-16 15:21:00+03
6254	PG0179	2017-07-16 16:20:00+03	2017-07-16 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-16 16:22:00+03	2017-07-16 16:52:00+03
6255	PG0179	2017-08-06 16:20:00+03	2017-08-06 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-06 16:24:00+03	2017-08-06 16:54:00+03
6256	PG0179	2017-08-23 16:20:00+03	2017-08-23 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6257	PG0178	2017-08-23 14:45:00+03	2017-08-23 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6258	PG0178	2017-08-08 14:45:00+03	2017-08-08 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-08 14:49:00+03	2017-08-08 15:19:00+03
6259	PG0179	2017-08-08 16:20:00+03	2017-08-08 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-08 16:26:00+03	2017-08-08 16:55:00+03
6260	PG0178	2017-07-20 14:45:00+03	2017-07-20 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-20 14:48:00+03	2017-07-20 15:18:00+03
6261	PG0179	2017-07-20 16:20:00+03	2017-07-20 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-20 16:22:00+03	2017-07-20 16:53:00+03
6262	PG0179	2017-09-08 16:20:00+03	2017-09-08 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6263	PG0179	2017-08-31 16:20:00+03	2017-08-31 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6264	PG0178	2017-08-31 14:45:00+03	2017-08-31 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6265	PG0178	2017-08-28 14:45:00+03	2017-08-28 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6266	PG0178	2017-08-13 14:45:00+03	2017-08-13 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-13 14:49:00+03	2017-08-13 15:18:00+03
6267	PG0178	2017-08-01 14:45:00+03	2017-08-01 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-01 14:49:00+03	2017-08-01 15:19:00+03
6268	PG0179	2017-08-12 16:20:00+03	2017-08-12 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-12 16:24:00+03	2017-08-12 16:54:00+03
6269	PG0178	2017-08-12 14:45:00+03	2017-08-12 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-12 14:45:00+03	2017-08-12 15:15:00+03
6270	PG0179	2017-08-22 16:20:00+03	2017-08-22 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6271	PG0179	2017-08-28 16:20:00+03	2017-08-28 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6272	PG0179	2017-07-26 16:20:00+03	2017-07-26 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-26 19:48:00+03	2017-07-26 20:18:00+03
6273	PG0178	2017-07-26 14:45:00+03	2017-07-26 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-26 17:00:00+03	2017-07-26 17:30:00+03
6274	PG0178	2017-08-22 14:45:00+03	2017-08-22 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6275	PG0178	2017-09-04 14:45:00+03	2017-09-04 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6276	PG0179	2017-08-18 16:20:00+03	2017-08-18 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6277	PG0178	2017-08-18 14:45:00+03	2017-08-18 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6278	PG0178	2017-09-01 14:45:00+03	2017-09-01 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6279	PG0179	2017-09-01 16:20:00+03	2017-09-01 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6280	PG0178	2017-09-13 14:45:00+03	2017-09-13 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6281	PG0178	2017-07-21 14:45:00+03	2017-07-21 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-21 14:47:00+03	2017-07-21 15:17:00+03
6282	PG0178	2017-09-03 14:45:00+03	2017-09-03 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6283	PG0179	2017-09-04 16:20:00+03	2017-09-04 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6284	PG0179	2017-09-06 16:20:00+03	2017-09-06 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6285	PG0179	2017-07-21 16:20:00+03	2017-07-21 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-21 16:24:00+03	2017-07-21 16:55:00+03
6286	PG0179	2017-07-29 16:20:00+03	2017-07-29 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-29 16:25:00+03	2017-07-29 16:56:00+03
6287	PG0178	2017-09-06 14:45:00+03	2017-09-06 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6288	PG0179	2017-09-03 16:20:00+03	2017-09-03 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6289	PG0178	2017-08-17 14:45:00+03	2017-08-17 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6290	PG0179	2017-09-13 16:20:00+03	2017-09-13 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6291	PG0178	2017-08-02 14:45:00+03	2017-08-02 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-02 14:46:00+03	2017-08-02 15:16:00+03
6292	PG0179	2017-08-02 16:20:00+03	2017-08-02 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-02 16:23:00+03	2017-08-02 16:54:00+03
6293	PG0179	2017-08-17 16:20:00+03	2017-08-17 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6294	PG0179	2017-08-16 16:20:00+03	2017-08-16 16:50:00+03	SVO	GOJ	On Time	SU9	\N	\N
6295	PG0178	2017-08-16 14:45:00+03	2017-08-16 15:15:00+03	SVO	GOJ	On Time	SU9	\N	\N
6296	PG0179	2017-08-07 16:20:00+03	2017-08-07 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-07 16:27:00+03	2017-08-07 16:57:00+03
6297	PG0178	2017-07-29 14:45:00+03	2017-07-29 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-29 14:49:00+03	2017-07-29 15:19:00+03
6298	PG0179	2017-07-28 16:20:00+03	2017-07-28 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-28 16:22:00+03	2017-07-28 16:52:00+03
6299	PG0178	2017-07-28 14:45:00+03	2017-07-28 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-28 14:49:00+03	2017-07-28 15:19:00+03
6300	PG0178	2017-07-27 14:45:00+03	2017-07-27 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-27 14:51:00+03	2017-07-27 15:21:00+03
6301	PG0179	2017-07-27 16:20:00+03	2017-07-27 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-27 16:23:00+03	2017-07-27 16:53:00+03
6302	PG0179	2017-08-26 16:20:00+03	2017-08-26 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6303	PG0178	2017-08-14 14:45:00+03	2017-08-14 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-14 17:40:00+03	2017-08-14 18:10:00+03
6304	PG0179	2017-08-14 16:20:00+03	2017-08-14 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-14 16:22:00+03	2017-08-14 16:52:00+03
6305	PG0178	2017-08-26 14:45:00+03	2017-08-26 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6306	PG0178	2017-08-07 14:45:00+03	2017-08-07 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-07 14:48:00+03	2017-08-07 15:19:00+03
6307	PG0179	2017-08-27 16:20:00+03	2017-08-27 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6308	PG0178	2017-08-27 14:45:00+03	2017-08-27 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6309	PG0179	2017-08-04 16:20:00+03	2017-08-04 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-04 16:23:00+03	2017-08-04 16:53:00+03
6310	PG0178	2017-08-04 14:45:00+03	2017-08-04 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-04 17:41:00+03	2017-08-04 18:11:00+03
6311	PG0179	2017-08-15 16:20:00+03	2017-08-15 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-15 16:25:00+03	2017-08-15 16:56:00+03
6312	PG0178	2017-08-15 14:45:00+03	2017-08-15 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-15 14:48:00+03	2017-08-15 15:18:00+03
6313	PG0179	2017-09-10 16:20:00+03	2017-09-10 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6314	PG0178	2017-07-17 14:45:00+03	2017-07-17 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-17 14:52:00+03	2017-07-17 15:22:00+03
6315	PG0179	2017-07-17 16:20:00+03	2017-07-17 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-17 16:22:00+03	2017-07-17 16:52:00+03
6316	PG0179	2017-08-11 16:20:00+03	2017-08-11 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-11 16:22:00+03	2017-08-11 16:52:00+03
6317	PG0178	2017-08-19 14:45:00+03	2017-08-19 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6318	PG0178	2017-08-11 14:45:00+03	2017-08-11 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-11 14:48:00+03	2017-08-11 15:18:00+03
6319	PG0179	2017-08-19 16:20:00+03	2017-08-19 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6320	PG0178	2017-07-23 14:45:00+03	2017-07-23 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-23 14:46:00+03	2017-07-23 15:16:00+03
6321	PG0178	2017-08-05 14:45:00+03	2017-08-05 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-05 14:48:00+03	2017-08-05 15:18:00+03
6322	PG0178	2017-09-10 14:45:00+03	2017-09-10 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6323	PG0179	2017-09-09 16:20:00+03	2017-09-09 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6324	PG0178	2017-09-09 14:45:00+03	2017-09-09 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6325	PG0178	2017-08-20 14:45:00+03	2017-08-20 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6326	PG0179	2017-08-20 16:20:00+03	2017-08-20 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6327	PG0178	2017-08-09 14:45:00+03	2017-08-09 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-09 14:46:00+03	2017-08-09 15:16:00+03
6328	PG0179	2017-08-09 16:20:00+03	2017-08-09 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-09 16:23:00+03	2017-08-09 16:53:00+03
6329	PG0179	2017-07-22 16:20:00+03	2017-07-22 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-22 16:23:00+03	2017-07-22 16:53:00+03
6330	PG0178	2017-07-22 14:45:00+03	2017-07-22 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-22 14:47:00+03	2017-07-22 15:17:00+03
6331	PG0179	2017-08-05 16:20:00+03	2017-08-05 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-05 16:22:00+03	2017-08-05 16:52:00+03
6332	PG0178	2017-08-24 14:45:00+03	2017-08-24 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6333	PG0179	2017-08-24 16:20:00+03	2017-08-24 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6334	PG0178	2017-09-11 14:45:00+03	2017-09-11 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6335	PG0178	2017-08-29 14:45:00+03	2017-08-29 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6336	PG0179	2017-08-29 16:20:00+03	2017-08-29 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6337	PG0178	2017-09-05 14:45:00+03	2017-09-05 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6338	PG0179	2017-09-05 16:20:00+03	2017-09-05 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6339	PG0179	2017-07-23 16:20:00+03	2017-07-23 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-23 16:23:00+03	2017-07-23 16:53:00+03
6340	PG0179	2017-09-11 16:20:00+03	2017-09-11 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6341	PG0179	2017-08-01 16:20:00+03	2017-08-01 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-01 16:20:00+03	2017-08-01 16:50:00+03
6342	PG0178	2017-07-30 14:45:00+03	2017-07-30 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-30 14:47:00+03	2017-07-30 15:17:00+03
6343	PG0178	2017-08-03 14:45:00+03	2017-08-03 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-03 14:46:00+03	2017-08-03 15:16:00+03
6344	PG0179	2017-07-30 16:20:00+03	2017-07-30 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-30 16:23:00+03	2017-07-30 16:53:00+03
6345	PG0179	2017-08-25 16:20:00+03	2017-08-25 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6346	PG0179	2017-08-10 16:20:00+03	2017-08-10 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-08-10 16:25:00+03	2017-08-10 16:55:00+03
6347	PG0178	2017-08-10 14:45:00+03	2017-08-10 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-08-10 14:46:00+03	2017-08-10 15:16:00+03
6348	PG0179	2017-07-18 16:20:00+03	2017-07-18 16:50:00+03	SVO	GOJ	Arrived	SU9	2017-07-18 16:25:00+03	2017-07-18 16:55:00+03
6349	PG0178	2017-07-18 14:45:00+03	2017-07-18 15:15:00+03	SVO	GOJ	Arrived	SU9	2017-07-18 14:45:00+03	2017-07-18 15:15:00+03
6350	PG0178	2017-09-14 14:45:00+03	2017-09-14 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6351	PG0178	2017-09-08 14:45:00+03	2017-09-08 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6352	PG0179	2017-09-14 16:20:00+03	2017-09-14 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6353	PG0178	2017-08-21 14:45:00+03	2017-08-21 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6354	PG0179	2017-08-21 16:20:00+03	2017-08-21 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6355	PG0178	2017-09-02 14:45:00+03	2017-09-02 15:15:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6356	PG0179	2017-09-02 16:20:00+03	2017-09-02 16:50:00+03	SVO	GOJ	Scheduled	SU9	\N	\N
6357	PG0251	2017-07-29 18:05:00+03	2017-07-29 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-29 18:05:00+03	2017-07-29 19:45:00+03
6358	PG0251	2017-08-17 18:05:00+03	2017-08-17 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6359	PG0251	2017-08-09 18:05:00+03	2017-08-09 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-09 18:11:00+03	2017-08-09 19:52:00+03
6360	PG0251	2017-08-03 18:05:00+03	2017-08-03 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-03 18:07:00+03	2017-08-03 19:46:00+03
6361	PG0251	2017-09-12 18:05:00+03	2017-09-12 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6362	PG0251	2017-09-08 18:05:00+03	2017-09-08 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6363	PG0251	2017-07-18 18:05:00+03	2017-07-18 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-18 18:08:00+03	2017-07-18 19:49:00+03
6364	PG0251	2017-07-17 18:05:00+03	2017-07-17 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-17 18:07:00+03	2017-07-17 19:47:00+03
6365	PG0251	2017-07-20 18:05:00+03	2017-07-20 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-20 18:10:00+03	2017-07-20 19:49:00+03
6366	PG0251	2017-08-19 18:05:00+03	2017-08-19 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6367	PG0251	2017-08-06 18:05:00+03	2017-08-06 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-06 18:10:00+03	2017-08-06 19:50:00+03
6368	PG0251	2017-08-14 18:05:00+03	2017-08-14 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-14 18:08:00+03	2017-08-14 19:50:00+03
6369	PG0251	2017-08-29 18:05:00+03	2017-08-29 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6370	PG0251	2017-09-11 18:05:00+03	2017-09-11 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6371	PG0251	2017-07-27 18:05:00+03	2017-07-27 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-27 18:07:00+03	2017-07-27 19:47:00+03
6372	PG0251	2017-07-22 18:05:00+03	2017-07-22 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-22 18:08:00+03	2017-07-22 19:48:00+03
6373	PG0251	2017-09-02 18:05:00+03	2017-09-02 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6374	PG0251	2017-09-14 18:05:00+03	2017-09-14 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6375	PG0251	2017-07-26 18:05:00+03	2017-07-26 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-26 18:08:00+03	2017-07-26 19:49:00+03
6376	PG0251	2017-08-25 18:05:00+03	2017-08-25 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6377	PG0251	2017-08-16 18:05:00+03	2017-08-16 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6378	PG0251	2017-07-23 18:05:00+03	2017-07-23 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-23 18:07:00+03	2017-07-23 19:45:00+03
6379	PG0251	2017-08-10 18:05:00+03	2017-08-10 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-10 18:09:00+03	2017-08-10 19:49:00+03
6380	PG0251	2017-09-04 18:05:00+03	2017-09-04 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6381	PG0251	2017-07-19 18:05:00+03	2017-07-19 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-19 21:33:00+03	2017-07-19 23:13:00+03
6382	PG0251	2017-08-23 18:05:00+03	2017-08-23 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6383	PG0251	2017-08-05 18:05:00+03	2017-08-05 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-05 18:09:00+03	2017-08-05 19:50:00+03
6384	PG0251	2017-07-21 18:05:00+03	2017-07-21 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-21 18:10:00+03	2017-07-21 19:50:00+03
6385	PG0251	2017-08-11 18:05:00+03	2017-08-11 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-11 18:10:00+03	2017-08-11 19:51:00+03
6386	PG0251	2017-07-24 18:05:00+03	2017-07-24 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-24 18:09:00+03	2017-07-24 19:48:00+03
6387	PG0251	2017-09-13 18:05:00+03	2017-09-13 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6388	PG0251	2017-08-04 18:05:00+03	2017-08-04 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-04 18:08:00+03	2017-08-04 19:48:00+03
6389	PG0251	2017-09-05 18:05:00+03	2017-09-05 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6390	PG0251	2017-08-02 18:05:00+03	2017-08-02 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-02 18:09:00+03	2017-08-02 19:50:00+03
6391	PG0251	2017-09-01 18:05:00+03	2017-09-01 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6392	PG0251	2017-08-28 18:05:00+03	2017-08-28 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6393	PG0251	2017-08-15 18:05:00+03	2017-08-15 19:45:00+03	SVO	AAQ	On Time	733	\N	\N
6394	PG0251	2017-09-09 18:05:00+03	2017-09-09 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6395	PG0251	2017-08-31 18:05:00+03	2017-08-31 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6396	PG0251	2017-09-07 18:05:00+03	2017-09-07 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6397	PG0251	2017-09-10 18:05:00+03	2017-09-10 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6398	PG0251	2017-07-28 18:05:00+03	2017-07-28 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-28 18:11:00+03	2017-07-28 19:51:00+03
6399	PG0251	2017-07-31 18:05:00+03	2017-07-31 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-31 18:09:00+03	2017-07-31 19:49:00+03
6400	PG0251	2017-09-06 18:05:00+03	2017-09-06 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6401	PG0251	2017-08-24 18:05:00+03	2017-08-24 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6402	PG0251	2017-08-26 18:05:00+03	2017-08-26 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6403	PG0251	2017-07-25 18:05:00+03	2017-07-25 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-25 18:09:00+03	2017-07-25 19:49:00+03
6404	PG0251	2017-08-30 18:05:00+03	2017-08-30 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6405	PG0251	2017-08-27 18:05:00+03	2017-08-27 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6406	PG0251	2017-08-12 18:05:00+03	2017-08-12 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-12 18:07:00+03	2017-08-12 19:47:00+03
6407	PG0251	2017-08-18 18:05:00+03	2017-08-18 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6408	PG0251	2017-08-08 18:05:00+03	2017-08-08 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-08 21:36:00+03	2017-08-08 23:16:00+03
6409	PG0251	2017-08-13 18:05:00+03	2017-08-13 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-13 18:11:00+03	2017-08-13 19:51:00+03
6410	PG0251	2017-08-07 18:05:00+03	2017-08-07 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-07 18:07:00+03	2017-08-07 19:46:00+03
6411	PG0251	2017-07-16 18:05:00+03	2017-07-16 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-16 18:10:00+03	2017-07-16 19:51:00+03
6412	PG0251	2017-08-21 18:05:00+03	2017-08-21 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6413	PG0251	2017-08-01 18:05:00+03	2017-08-01 19:45:00+03	SVO	AAQ	Arrived	733	2017-08-01 18:08:00+03	2017-08-01 19:48:00+03
6414	PG0251	2017-08-20 18:05:00+03	2017-08-20 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6415	PG0251	2017-09-03 18:05:00+03	2017-09-03 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6416	PG0251	2017-08-22 18:05:00+03	2017-08-22 19:45:00+03	SVO	AAQ	Scheduled	733	\N	\N
6417	PG0251	2017-07-30 18:05:00+03	2017-07-30 19:45:00+03	SVO	AAQ	Arrived	733	2017-07-30 18:06:00+03	2017-07-30 19:47:00+03
6418	PG0093	2017-08-29 09:40:00+03	2017-08-29 11:50:00+03	SVO	USK	Scheduled	CR2	\N	\N
6419	PG0093	2017-09-12 09:40:00+03	2017-09-12 11:50:00+03	SVO	USK	Cancelled	CR2	\N	\N
6420	PG0093	2017-08-22 09:40:00+03	2017-08-22 11:50:00+03	SVO	USK	Scheduled	CR2	\N	\N
6421	PG0093	2017-08-15 09:40:00+03	2017-08-15 11:50:00+03	SVO	USK	Arrived	CR2	2017-08-15 09:41:00+03	2017-08-15 11:52:00+03
6422	PG0093	2017-08-01 09:40:00+03	2017-08-01 11:50:00+03	SVO	USK	Arrived	CR2	2017-08-01 09:42:00+03	2017-08-01 11:53:00+03
6423	PG0093	2017-07-18 09:40:00+03	2017-07-18 11:50:00+03	SVO	USK	Arrived	CR2	2017-07-18 09:41:00+03	2017-07-18 11:52:00+03
6424	PG0093	2017-07-25 09:40:00+03	2017-07-25 11:50:00+03	SVO	USK	Arrived	CR2	2017-07-25 09:44:00+03	2017-07-25 11:56:00+03
6425	PG0093	2017-09-05 09:40:00+03	2017-09-05 11:50:00+03	SVO	USK	Scheduled	CR2	\N	\N
6426	PG0093	2017-08-08 09:40:00+03	2017-08-08 11:50:00+03	SVO	USK	Arrived	CR2	2017-08-08 09:42:00+03	2017-08-08 11:52:00+03
6427	PG0679	2017-08-22 11:30:00+03	2017-08-22 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6428	PG0679	2017-09-14 11:30:00+03	2017-09-14 13:40:00+03	SVO	NNM	Cancelled	CR2	\N	\N
6429	PG0679	2017-08-07 11:30:00+03	2017-08-07 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-07 11:33:00+03	2017-08-07 13:44:00+03
6430	PG0679	2017-08-19 11:30:00+03	2017-08-19 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6431	PG0679	2017-08-12 11:30:00+03	2017-08-12 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-12 11:33:00+03	2017-08-12 13:43:00+03
6432	PG0679	2017-09-12 11:30:00+03	2017-09-12 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6433	PG0679	2017-07-22 11:30:00+03	2017-07-22 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-22 11:36:00+03	2017-07-22 13:46:00+03
6434	PG0679	2017-08-31 11:30:00+03	2017-08-31 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6435	PG0679	2017-09-03 11:30:00+03	2017-09-03 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6436	PG0679	2017-08-24 11:30:00+03	2017-08-24 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6437	PG0679	2017-08-28 11:30:00+03	2017-08-28 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6438	PG0679	2017-07-26 11:30:00+03	2017-07-26 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-26 11:36:00+03	2017-07-26 13:48:00+03
6439	PG0679	2017-08-20 11:30:00+03	2017-08-20 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6440	PG0679	2017-08-13 11:30:00+03	2017-08-13 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-13 11:36:00+03	2017-08-13 13:48:00+03
6441	PG0679	2017-07-30 11:30:00+03	2017-07-30 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-30 11:34:00+03	2017-07-30 13:45:00+03
6442	PG0679	2017-08-01 11:30:00+03	2017-08-01 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-01 11:35:00+03	2017-08-01 13:45:00+03
6443	PG0679	2017-08-11 11:30:00+03	2017-08-11 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-11 11:32:00+03	2017-08-11 13:44:00+03
6444	PG0679	2017-08-21 11:30:00+03	2017-08-21 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6445	PG0679	2017-08-05 11:30:00+03	2017-08-05 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-05 11:35:00+03	2017-08-05 13:46:00+03
6446	PG0679	2017-07-16 11:30:00+03	2017-07-16 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-16 11:33:00+03	2017-07-16 13:44:00+03
6447	PG0679	2017-08-18 11:30:00+03	2017-08-18 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6448	PG0679	2017-08-17 11:30:00+03	2017-08-17 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6449	PG0679	2017-07-23 11:30:00+03	2017-07-23 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-23 11:38:00+03	2017-07-23 13:46:00+03
6450	PG0679	2017-09-09 11:30:00+03	2017-09-09 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6451	PG0679	2017-09-10 11:30:00+03	2017-09-10 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6452	PG0679	2017-07-25 11:30:00+03	2017-07-25 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-25 11:32:00+03	2017-07-25 13:42:00+03
6453	PG0679	2017-08-30 11:30:00+03	2017-08-30 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6454	PG0679	2017-09-05 11:30:00+03	2017-09-05 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6455	PG0679	2017-08-10 11:30:00+03	2017-08-10 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-10 11:34:00+03	2017-08-10 13:43:00+03
6456	PG0679	2017-07-24 11:30:00+03	2017-07-24 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-24 11:31:00+03	2017-07-24 13:42:00+03
6457	PG0679	2017-08-06 11:30:00+03	2017-08-06 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-06 11:34:00+03	2017-08-06 13:46:00+03
6458	PG0679	2017-08-26 11:30:00+03	2017-08-26 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6459	PG0679	2017-09-11 11:30:00+03	2017-09-11 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6460	PG0679	2017-08-02 11:30:00+03	2017-08-02 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-02 11:34:00+03	2017-08-02 13:44:00+03
6461	PG0679	2017-09-01 11:30:00+03	2017-09-01 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6462	PG0679	2017-07-19 11:30:00+03	2017-07-19 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-19 11:33:00+03	2017-07-19 13:44:00+03
6463	PG0679	2017-07-21 11:30:00+03	2017-07-21 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-21 11:33:00+03	2017-07-21 13:43:00+03
6464	PG0679	2017-08-09 11:30:00+03	2017-08-09 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-09 11:32:00+03	2017-08-09 13:42:00+03
6465	PG0679	2017-07-17 11:30:00+03	2017-07-17 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-17 11:31:00+03	2017-07-17 13:43:00+03
6466	PG0679	2017-08-14 11:30:00+03	2017-08-14 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-14 11:31:00+03	2017-08-14 13:42:00+03
6467	PG0679	2017-09-06 11:30:00+03	2017-09-06 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6468	PG0679	2017-08-29 11:30:00+03	2017-08-29 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6469	PG0679	2017-09-08 11:30:00+03	2017-09-08 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6470	PG0679	2017-07-31 11:30:00+03	2017-07-31 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-31 11:35:00+03	2017-07-31 13:44:00+03
6471	PG0679	2017-07-27 11:30:00+03	2017-07-27 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-27 11:32:00+03	2017-07-27 13:41:00+03
6472	PG0679	2017-08-03 11:30:00+03	2017-08-03 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-03 11:32:00+03	2017-08-03 13:44:00+03
6473	PG0679	2017-08-27 11:30:00+03	2017-08-27 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6474	PG0679	2017-09-13 11:30:00+03	2017-09-13 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6475	PG0679	2017-08-25 11:30:00+03	2017-08-25 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6476	PG0679	2017-08-08 11:30:00+03	2017-08-08 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-08 11:33:00+03	2017-08-08 13:45:00+03
6477	PG0679	2017-07-28 11:30:00+03	2017-07-28 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-28 11:36:00+03	2017-07-28 13:48:00+03
6478	PG0679	2017-09-02 11:30:00+03	2017-09-02 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6479	PG0679	2017-07-29 11:30:00+03	2017-07-29 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-29 11:33:00+03	2017-07-29 13:42:00+03
6480	PG0679	2017-08-15 11:30:00+03	2017-08-15 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-15 11:31:00+03	2017-08-15 13:41:00+03
6481	PG0679	2017-09-04 11:30:00+03	2017-09-04 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6482	PG0679	2017-07-20 11:30:00+03	2017-07-20 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-20 11:33:00+03	2017-07-20 13:43:00+03
6483	PG0679	2017-07-18 11:30:00+03	2017-07-18 13:40:00+03	SVO	NNM	Arrived	CR2	2017-07-18 11:35:00+03	2017-07-18 13:43:00+03
6484	PG0679	2017-08-04 11:30:00+03	2017-08-04 13:40:00+03	SVO	NNM	Arrived	CR2	2017-08-04 11:35:00+03	2017-08-04 13:48:00+03
6485	PG0679	2017-08-23 11:30:00+03	2017-08-23 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6486	PG0679	2017-08-16 11:30:00+03	2017-08-16 13:40:00+03	SVO	NNM	On Time	CR2	\N	\N
6487	PG0679	2017-09-07 11:30:00+03	2017-09-07 13:40:00+03	SVO	NNM	Scheduled	CR2	\N	\N
6488	PG0255	2017-08-26 16:50:00+03	2017-08-27 01:00:00+03	SVO	DYR	Scheduled	319	\N	\N
6489	PG0255	2017-08-19 16:50:00+03	2017-08-20 01:00:00+03	SVO	DYR	Scheduled	319	\N	\N
6490	PG0255	2017-09-09 16:50:00+03	2017-09-10 01:00:00+03	SVO	DYR	Scheduled	319	\N	\N
6491	PG0255	2017-09-02 16:50:00+03	2017-09-03 01:00:00+03	SVO	DYR	Scheduled	319	\N	\N
6492	PG0255	2017-07-22 16:50:00+03	2017-07-23 01:00:00+03	SVO	DYR	Arrived	319	2017-07-22 16:53:00+03	2017-07-23 01:12:00+03
6493	PG0255	2017-08-12 16:50:00+03	2017-08-13 01:00:00+03	SVO	DYR	Arrived	319	2017-08-12 16:53:00+03	2017-08-13 01:04:00+03
6494	PG0255	2017-08-05 16:50:00+03	2017-08-06 01:00:00+03	SVO	DYR	Arrived	319	2017-08-05 16:51:00+03	2017-08-06 00:59:00+03
6495	PG0255	2017-07-29 16:50:00+03	2017-07-30 01:00:00+03	SVO	DYR	Arrived	319	2017-07-29 16:55:00+03	2017-07-30 00:59:00+03
6496	PG0643	2017-07-16 13:45:00+03	2017-07-16 16:15:00+03	SVO	NYA	Arrived	CR2	2017-07-16 13:46:00+03	2017-07-16 16:15:00+03
6497	PG0643	2017-07-30 13:45:00+03	2017-07-30 16:15:00+03	SVO	NYA	Arrived	CR2	2017-07-30 13:48:00+03	2017-07-30 16:20:00+03
6498	PG0643	2017-08-27 13:45:00+03	2017-08-27 16:15:00+03	SVO	NYA	Scheduled	CR2	\N	\N
6499	PG0643	2017-09-10 13:45:00+03	2017-09-10 16:15:00+03	SVO	NYA	Cancelled	CR2	\N	\N
6500	PG0643	2017-08-13 13:45:00+03	2017-08-13 16:15:00+03	SVO	NYA	Arrived	CR2	2017-08-13 13:48:00+03	2017-08-13 16:17:00+03
6501	PG0643	2017-08-06 13:45:00+03	2017-08-06 16:15:00+03	SVO	NYA	Arrived	CR2	2017-08-06 13:48:00+03	2017-08-06 16:22:00+03
6502	PG0643	2017-09-03 13:45:00+03	2017-09-03 16:15:00+03	SVO	NYA	Scheduled	CR2	\N	\N
6503	PG0643	2017-08-20 13:45:00+03	2017-08-20 16:15:00+03	SVO	NYA	Scheduled	CR2	\N	\N
6504	PG0643	2017-07-23 13:45:00+03	2017-07-23 16:15:00+03	SVO	NYA	Arrived	CR2	2017-07-23 13:49:00+03	2017-07-23 16:19:00+03
6505	PG0089	2017-09-07 16:40:00+03	2017-09-07 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6506	PG0089	2017-08-28 16:40:00+03	2017-08-28 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6507	PG0089	2017-08-19 16:40:00+03	2017-08-19 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6508	PG0089	2017-08-12 16:40:00+03	2017-08-12 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-12 19:32:00+03	2017-08-12 21:40:00+03
6509	PG0089	2017-07-21 16:40:00+03	2017-07-21 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-21 16:41:00+03	2017-07-21 18:51:00+03
6510	PG0089	2017-09-10 16:40:00+03	2017-09-10 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6511	PG0089	2017-07-31 16:40:00+03	2017-07-31 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-31 16:42:00+03	2017-07-31 18:51:00+03
6512	PG0089	2017-08-24 16:40:00+03	2017-08-24 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6513	PG0089	2017-08-18 16:40:00+03	2017-08-18 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6514	PG0089	2017-07-26 16:40:00+03	2017-07-26 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-26 16:40:00+03	2017-07-26 18:50:00+03
6515	PG0089	2017-07-22 16:40:00+03	2017-07-22 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-22 16:43:00+03	2017-07-22 18:52:00+03
6516	PG0089	2017-08-27 16:40:00+03	2017-08-27 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6517	PG0089	2017-09-05 16:40:00+03	2017-09-05 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6518	PG0089	2017-07-27 16:40:00+03	2017-07-27 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-27 16:43:00+03	2017-07-27 18:52:00+03
6519	PG0089	2017-08-30 16:40:00+03	2017-08-30 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6520	PG0089	2017-07-19 16:40:00+03	2017-07-19 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-19 16:40:00+03	2017-07-19 18:51:00+03
6521	PG0089	2017-08-14 16:40:00+03	2017-08-14 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-14 16:44:00+03	2017-08-14 18:53:00+03
6522	PG0089	2017-09-02 16:40:00+03	2017-09-02 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6523	PG0089	2017-08-16 16:40:00+03	2017-08-16 18:50:00+03	SVO	OVS	On Time	SU9	\N	\N
6524	PG0089	2017-08-15 16:40:00+03	2017-08-15 18:50:00+03	SVO	OVS	Departed	SU9	2017-08-15 16:44:00+03	\N
6525	PG0089	2017-08-04 16:40:00+03	2017-08-04 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-04 16:44:00+03	2017-08-04 18:56:00+03
6526	PG0089	2017-07-23 16:40:00+03	2017-07-23 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-23 16:43:00+03	2017-07-23 18:51:00+03
6527	PG0089	2017-08-08 16:40:00+03	2017-08-08 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-08 16:42:00+03	2017-08-08 18:53:00+03
6528	PG0089	2017-07-18 16:40:00+03	2017-07-18 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-18 16:42:00+03	2017-07-18 18:51:00+03
6529	PG0089	2017-09-12 16:40:00+03	2017-09-12 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6530	PG0089	2017-08-22 16:40:00+03	2017-08-22 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6531	PG0089	2017-09-09 16:40:00+03	2017-09-09 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6532	PG0089	2017-07-28 16:40:00+03	2017-07-28 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-28 16:43:00+03	2017-07-28 18:55:00+03
6533	PG0089	2017-09-14 16:40:00+03	2017-09-14 18:50:00+03	SVO	OVS	Cancelled	SU9	\N	\N
6534	PG0089	2017-08-26 16:40:00+03	2017-08-26 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6535	PG0089	2017-08-06 16:40:00+03	2017-08-06 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-06 16:42:00+03	2017-08-06 18:53:00+03
6536	PG0089	2017-09-03 16:40:00+03	2017-09-03 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6537	PG0089	2017-08-13 16:40:00+03	2017-08-13 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-13 16:46:00+03	2017-08-13 18:56:00+03
6538	PG0089	2017-07-29 16:40:00+03	2017-07-29 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-29 16:44:00+03	2017-07-29 18:51:00+03
6539	PG0089	2017-08-05 16:40:00+03	2017-08-05 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-05 16:43:00+03	2017-08-05 18:53:00+03
6540	PG0089	2017-08-11 16:40:00+03	2017-08-11 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-11 16:42:00+03	2017-08-11 18:53:00+03
6541	PG0089	2017-07-24 16:40:00+03	2017-07-24 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-24 16:45:00+03	2017-07-24 18:55:00+03
6542	PG0089	2017-08-31 16:40:00+03	2017-08-31 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6543	PG0089	2017-09-11 16:40:00+03	2017-09-11 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6544	PG0089	2017-09-04 16:40:00+03	2017-09-04 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6545	PG0089	2017-09-13 16:40:00+03	2017-09-13 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6546	PG0089	2017-08-17 16:40:00+03	2017-08-17 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6547	PG0089	2017-07-16 16:40:00+03	2017-07-16 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-16 16:42:00+03	2017-07-16 18:54:00+03
6548	PG0089	2017-08-03 16:40:00+03	2017-08-03 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-03 16:47:00+03	2017-08-03 18:57:00+03
6549	PG0089	2017-09-08 16:40:00+03	2017-09-08 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6550	PG0089	2017-07-25 16:40:00+03	2017-07-25 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-25 16:40:00+03	2017-07-25 18:51:00+03
6551	PG0089	2017-08-20 16:40:00+03	2017-08-20 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6552	PG0089	2017-08-02 16:40:00+03	2017-08-02 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-02 16:44:00+03	2017-08-02 18:53:00+03
6553	PG0089	2017-08-09 16:40:00+03	2017-08-09 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-09 16:42:00+03	2017-08-09 18:54:00+03
6554	PG0089	2017-08-21 16:40:00+03	2017-08-21 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6555	PG0089	2017-08-29 16:40:00+03	2017-08-29 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6556	PG0089	2017-08-07 16:40:00+03	2017-08-07 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-07 16:42:00+03	2017-08-07 18:52:00+03
6557	PG0089	2017-07-30 16:40:00+03	2017-07-30 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-30 16:44:00+03	2017-07-30 18:52:00+03
6558	PG0089	2017-08-10 16:40:00+03	2017-08-10 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-10 19:53:00+03	2017-08-10 22:04:00+03
6559	PG0089	2017-09-06 16:40:00+03	2017-09-06 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6560	PG0089	2017-08-01 16:40:00+03	2017-08-01 18:50:00+03	SVO	OVS	Arrived	SU9	2017-08-01 16:45:00+03	2017-08-01 18:54:00+03
6561	PG0089	2017-09-01 16:40:00+03	2017-09-01 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6562	PG0089	2017-08-23 16:40:00+03	2017-08-23 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6563	PG0089	2017-07-20 16:40:00+03	2017-07-20 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-20 16:42:00+03	2017-07-20 18:53:00+03
6564	PG0089	2017-08-25 16:40:00+03	2017-08-25 18:50:00+03	SVO	OVS	Scheduled	SU9	\N	\N
6565	PG0089	2017-07-17 16:40:00+03	2017-07-17 18:50:00+03	SVO	OVS	Arrived	SU9	2017-07-17 16:42:00+03	2017-07-17 18:56:00+03
6566	PG0041	2017-07-25 09:50:00+03	2017-07-25 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-25 09:52:00+03	2017-07-25 12:51:00+03
6567	PG0041	2017-08-19 09:50:00+03	2017-08-19 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6568	PG0041	2017-08-12 09:50:00+03	2017-08-12 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-12 09:52:00+03	2017-08-12 12:52:00+03
6569	PG0041	2017-08-31 09:50:00+03	2017-08-31 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6570	PG0041	2017-08-29 09:50:00+03	2017-08-29 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6571	PG0041	2017-07-18 09:50:00+03	2017-07-18 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-18 09:53:00+03	2017-07-18 12:57:00+03
6572	PG0041	2017-09-12 09:50:00+03	2017-09-12 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6573	PG0041	2017-08-01 09:50:00+03	2017-08-01 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-01 12:33:00+03	2017-08-01 15:31:00+03
6574	PG0041	2017-08-15 09:50:00+03	2017-08-15 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-15 09:52:00+03	2017-08-15 12:53:00+03
6575	PG0041	2017-08-24 09:50:00+03	2017-08-24 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6576	PG0041	2017-09-07 09:50:00+03	2017-09-07 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6577	PG0041	2017-08-10 09:50:00+03	2017-08-10 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-10 09:53:00+03	2017-08-10 12:53:00+03
6578	PG0041	2017-09-05 09:50:00+03	2017-09-05 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6579	PG0041	2017-08-05 09:50:00+03	2017-08-05 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-05 09:55:00+03	2017-08-05 12:53:00+03
6580	PG0041	2017-07-20 09:50:00+03	2017-07-20 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-20 09:50:00+03	2017-07-20 12:51:00+03
6581	PG0041	2017-07-27 09:50:00+03	2017-07-27 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-27 09:51:00+03	2017-07-27 12:51:00+03
6582	PG0041	2017-08-26 09:50:00+03	2017-08-26 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6583	PG0041	2017-07-22 09:50:00+03	2017-07-22 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-22 09:55:00+03	2017-07-22 12:58:00+03
6584	PG0041	2017-08-17 09:50:00+03	2017-08-17 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6585	PG0041	2017-09-02 09:50:00+03	2017-09-02 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6586	PG0041	2017-08-22 09:50:00+03	2017-08-22 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6587	PG0041	2017-07-29 09:50:00+03	2017-07-29 12:50:00+03	SVO	NFG	Arrived	CR2	2017-07-29 09:51:00+03	2017-07-29 12:51:00+03
6588	PG0041	2017-09-09 09:50:00+03	2017-09-09 12:50:00+03	SVO	NFG	Scheduled	CR2	\N	\N
6589	PG0041	2017-08-03 09:50:00+03	2017-08-03 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-03 09:54:00+03	2017-08-03 12:56:00+03
6590	PG0041	2017-08-08 09:50:00+03	2017-08-08 12:50:00+03	SVO	NFG	Arrived	CR2	2017-08-08 09:53:00+03	2017-08-08 12:54:00+03
6591	PG0041	2017-09-14 09:50:00+03	2017-09-14 12:50:00+03	SVO	NFG	Cancelled	CR2	\N	\N
6592	PG0015	2017-09-13 12:40:00+03	2017-09-13 15:20:00+03	SVO	VKT	Cancelled	CR2	\N	\N
6593	PG0015	2017-08-12 12:40:00+03	2017-08-12 15:20:00+03	SVO	VKT	Arrived	CR2	2017-08-12 12:45:00+03	2017-08-12 15:21:00+03
6594	PG0015	2017-07-19 12:40:00+03	2017-07-19 15:20:00+03	SVO	VKT	Arrived	CR2	2017-07-19 12:44:00+03	2017-07-19 15:22:00+03
6595	PG0015	2017-09-02 12:40:00+03	2017-09-02 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6596	PG0015	2017-07-22 12:40:00+03	2017-07-22 15:20:00+03	SVO	VKT	Arrived	CR2	2017-07-22 12:47:00+03	2017-07-22 15:26:00+03
6597	PG0015	2017-08-30 12:40:00+03	2017-08-30 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6598	PG0015	2017-08-23 12:40:00+03	2017-08-23 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6599	PG0015	2017-09-06 12:40:00+03	2017-09-06 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6600	PG0015	2017-07-26 12:40:00+03	2017-07-26 15:20:00+03	SVO	VKT	Arrived	CR2	2017-07-26 12:40:00+03	2017-07-26 15:21:00+03
6601	PG0015	2017-08-05 12:40:00+03	2017-08-05 15:20:00+03	SVO	VKT	Arrived	CR2	2017-08-05 12:44:00+03	2017-08-05 15:26:00+03
6602	PG0015	2017-08-09 12:40:00+03	2017-08-09 15:20:00+03	SVO	VKT	Arrived	CR2	2017-08-09 12:42:00+03	2017-08-09 15:25:00+03
6603	PG0015	2017-08-02 12:40:00+03	2017-08-02 15:20:00+03	SVO	VKT	Arrived	CR2	2017-08-02 12:42:00+03	2017-08-02 15:23:00+03
6604	PG0015	2017-07-29 12:40:00+03	2017-07-29 15:20:00+03	SVO	VKT	Arrived	CR2	2017-07-29 12:44:00+03	2017-07-29 15:26:00+03
6605	PG0015	2017-08-26 12:40:00+03	2017-08-26 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6606	PG0015	2017-08-19 12:40:00+03	2017-08-19 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6607	PG0015	2017-09-09 12:40:00+03	2017-09-09 15:20:00+03	SVO	VKT	Scheduled	CR2	\N	\N
6608	PG0015	2017-08-16 12:40:00+03	2017-08-16 15:20:00+03	SVO	VKT	On Time	CR2	\N	\N
6609	PG0647	2017-07-31 10:30:00+03	2017-07-31 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-31 10:32:00+03	2017-07-31 11:57:00+03
6610	PG0647	2017-08-18 10:30:00+03	2017-08-18 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6611	PG0647	2017-08-22 10:30:00+03	2017-08-22 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6612	PG0647	2017-08-07 10:30:00+03	2017-08-07 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-07 10:33:00+03	2017-08-07 11:57:00+03
6613	PG0647	2017-08-15 10:30:00+03	2017-08-15 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-15 13:38:00+03	2017-08-15 15:04:00+03
6614	PG0647	2017-09-08 10:30:00+03	2017-09-08 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6615	PG0647	2017-07-27 10:30:00+03	2017-07-27 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-27 10:31:00+03	2017-07-27 11:56:00+03
6616	PG0647	2017-09-06 10:30:00+03	2017-09-06 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6617	PG0647	2017-07-21 10:30:00+03	2017-07-21 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-21 10:34:00+03	2017-07-21 11:58:00+03
6618	PG0647	2017-08-26 10:30:00+03	2017-08-26 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6619	PG0647	2017-08-03 10:30:00+03	2017-08-03 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-03 10:33:00+03	2017-08-03 11:59:00+03
6620	PG0647	2017-08-12 10:30:00+03	2017-08-12 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-12 10:33:00+03	2017-08-12 11:57:00+03
6621	PG0647	2017-08-14 10:30:00+03	2017-08-14 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-14 10:32:00+03	2017-08-14 11:57:00+03
6622	PG0647	2017-08-29 10:30:00+03	2017-08-29 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6623	PG0647	2017-08-09 10:30:00+03	2017-08-09 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-09 10:34:00+03	2017-08-09 11:58:00+03
6624	PG0647	2017-08-16 10:30:00+03	2017-08-16 11:55:00+03	SVO	UUA	Delayed	CR2	\N	\N
6625	PG0647	2017-08-20 10:30:00+03	2017-08-20 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6626	PG0647	2017-07-19 10:30:00+03	2017-07-19 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-19 10:32:00+03	2017-07-19 11:56:00+03
6627	PG0647	2017-09-10 10:30:00+03	2017-09-10 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6628	PG0647	2017-07-28 10:30:00+03	2017-07-28 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-28 10:32:00+03	2017-07-28 11:57:00+03
6629	PG0647	2017-07-22 10:30:00+03	2017-07-22 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-22 10:35:00+03	2017-07-22 12:02:00+03
6630	PG0647	2017-09-01 10:30:00+03	2017-09-01 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6631	PG0647	2017-08-02 10:30:00+03	2017-08-02 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-02 10:34:00+03	2017-08-02 11:57:00+03
6632	PG0647	2017-08-28 10:30:00+03	2017-08-28 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6633	PG0647	2017-08-04 10:30:00+03	2017-08-04 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-04 10:31:00+03	2017-08-04 11:56:00+03
6634	PG0647	2017-09-07 10:30:00+03	2017-09-07 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6635	PG0647	2017-07-20 10:30:00+03	2017-07-20 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-20 10:33:00+03	2017-07-20 11:58:00+03
6636	PG0647	2017-09-14 10:30:00+03	2017-09-14 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6637	PG0647	2017-08-25 10:30:00+03	2017-08-25 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6638	PG0647	2017-09-05 10:30:00+03	2017-09-05 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6639	PG0647	2017-08-27 10:30:00+03	2017-08-27 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6640	PG0647	2017-08-30 10:30:00+03	2017-08-30 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6641	PG0647	2017-07-18 10:30:00+03	2017-07-18 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-18 10:35:00+03	2017-07-18 12:01:00+03
6642	PG0647	2017-08-10 10:30:00+03	2017-08-10 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-10 10:33:00+03	2017-08-10 11:58:00+03
6643	PG0647	2017-08-31 10:30:00+03	2017-08-31 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6644	PG0647	2017-07-25 10:30:00+03	2017-07-25 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-25 10:33:00+03	2017-07-25 11:59:00+03
6645	PG0647	2017-09-04 10:30:00+03	2017-09-04 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6646	PG0647	2017-07-29 10:30:00+03	2017-07-29 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-29 10:32:00+03	2017-07-29 11:59:00+03
6647	PG0647	2017-08-23 10:30:00+03	2017-08-23 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6648	PG0647	2017-08-05 10:30:00+03	2017-08-05 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-05 10:32:00+03	2017-08-05 11:57:00+03
6649	PG0647	2017-09-11 10:30:00+03	2017-09-11 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6650	PG0647	2017-07-16 10:30:00+03	2017-07-16 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-16 10:35:00+03	2017-07-16 11:59:00+03
6651	PG0647	2017-07-17 10:30:00+03	2017-07-17 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-17 10:33:00+03	2017-07-17 11:58:00+03
6652	PG0647	2017-08-06 10:30:00+03	2017-08-06 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-06 10:33:00+03	2017-08-06 11:56:00+03
6653	PG0647	2017-08-17 10:30:00+03	2017-08-17 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6654	PG0647	2017-08-21 10:30:00+03	2017-08-21 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6655	PG0647	2017-07-26 10:30:00+03	2017-07-26 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-26 10:33:00+03	2017-07-26 11:57:00+03
6656	PG0647	2017-08-13 10:30:00+03	2017-08-13 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-13 10:32:00+03	2017-08-13 11:57:00+03
6657	PG0647	2017-08-19 10:30:00+03	2017-08-19 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6658	PG0647	2017-09-12 10:30:00+03	2017-09-12 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6659	PG0647	2017-09-13 10:30:00+03	2017-09-13 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6660	PG0647	2017-09-03 10:30:00+03	2017-09-03 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6661	PG0647	2017-08-24 10:30:00+03	2017-08-24 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6662	PG0647	2017-09-09 10:30:00+03	2017-09-09 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6663	PG0647	2017-08-11 10:30:00+03	2017-08-11 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-11 10:34:00+03	2017-08-11 12:00:00+03
6664	PG0647	2017-08-01 10:30:00+03	2017-08-01 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-01 10:33:00+03	2017-08-01 11:58:00+03
6665	PG0647	2017-08-08 10:30:00+03	2017-08-08 11:55:00+03	SVO	UUA	Arrived	CR2	2017-08-08 10:31:00+03	2017-08-08 11:56:00+03
6666	PG0647	2017-07-23 10:30:00+03	2017-07-23 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-23 10:32:00+03	2017-07-23 11:57:00+03
6667	PG0647	2017-07-24 10:30:00+03	2017-07-24 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-24 10:31:00+03	2017-07-24 11:57:00+03
6668	PG0647	2017-07-30 10:30:00+03	2017-07-30 11:55:00+03	SVO	UUA	Arrived	CR2	2017-07-30 10:33:00+03	2017-07-30 11:58:00+03
6669	PG0647	2017-09-02 10:30:00+03	2017-09-02 11:55:00+03	SVO	UUA	Scheduled	CR2	\N	\N
6670	PG0261	2017-08-01 12:55:00+03	2017-08-01 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-01 12:58:00+03	2017-08-01 14:49:00+03
6671	PG0261	2017-08-20 12:55:00+03	2017-08-20 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6672	PG0261	2017-09-05 12:55:00+03	2017-09-05 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6673	PG0261	2017-08-29 12:55:00+03	2017-08-29 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6674	PG0261	2017-08-03 12:55:00+03	2017-08-03 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-03 12:56:00+03	2017-08-03 14:47:00+03
6675	PG0261	2017-07-23 12:55:00+03	2017-07-23 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-23 13:00:00+03	2017-07-23 14:52:00+03
6676	PG0261	2017-08-10 12:55:00+03	2017-08-10 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-10 12:58:00+03	2017-08-10 14:48:00+03
6677	PG0261	2017-08-17 12:55:00+03	2017-08-17 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6678	PG0261	2017-07-18 12:55:00+03	2017-07-18 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-18 12:56:00+03	2017-07-18 14:46:00+03
6679	PG0261	2017-07-20 12:55:00+03	2017-07-20 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-20 12:58:00+03	2017-07-20 14:49:00+03
6680	PG0261	2017-08-13 12:55:00+03	2017-08-13 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-13 12:59:00+03	2017-08-13 14:49:00+03
6681	PG0261	2017-07-27 12:55:00+03	2017-07-27 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-27 12:59:00+03	2017-07-27 14:49:00+03
6682	PG0261	2017-09-12 12:55:00+03	2017-09-12 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6683	PG0261	2017-08-06 12:55:00+03	2017-08-06 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-06 12:58:00+03	2017-08-06 14:49:00+03
6684	PG0261	2017-09-10 12:55:00+03	2017-09-10 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6685	PG0261	2017-08-15 12:55:00+03	2017-08-15 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-15 12:55:00+03	2017-08-15 14:47:00+03
6686	PG0261	2017-09-07 12:55:00+03	2017-09-07 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6687	PG0261	2017-07-25 12:55:00+03	2017-07-25 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-25 12:58:00+03	2017-07-25 14:48:00+03
6688	PG0261	2017-09-14 12:55:00+03	2017-09-14 14:45:00+03	SVO	GDZ	Cancelled	CR2	\N	\N
6689	PG0261	2017-08-08 12:55:00+03	2017-08-08 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-08-08 12:59:00+03	2017-08-08 14:50:00+03
6690	PG0261	2017-08-31 12:55:00+03	2017-08-31 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6691	PG0261	2017-07-16 12:55:00+03	2017-07-16 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-16 12:58:00+03	2017-07-16 14:49:00+03
6692	PG0261	2017-08-22 12:55:00+03	2017-08-22 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6693	PG0261	2017-09-03 12:55:00+03	2017-09-03 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6694	PG0261	2017-08-27 12:55:00+03	2017-08-27 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6695	PG0261	2017-08-24 12:55:00+03	2017-08-24 14:45:00+03	SVO	GDZ	Scheduled	CR2	\N	\N
6696	PG0261	2017-07-30 12:55:00+03	2017-07-30 14:45:00+03	SVO	GDZ	Arrived	CR2	2017-07-30 16:10:00+03	2017-07-30 18:01:00+03
6697	PG0432	2017-07-19 12:15:00+03	2017-07-19 16:35:00+03	SVO	RGK	Arrived	733	2017-07-19 12:17:00+03	2017-07-19 16:39:00+03
6698	PG0432	2017-08-02 12:15:00+03	2017-08-02 16:35:00+03	SVO	RGK	Arrived	733	2017-08-02 15:51:00+03	2017-08-02 20:10:00+03
6699	PG0432	2017-09-13 12:15:00+03	2017-09-13 16:35:00+03	SVO	RGK	Scheduled	733	\N	\N
6700	PG0432	2017-07-26 12:15:00+03	2017-07-26 16:35:00+03	SVO	RGK	Arrived	733	2017-07-26 12:18:00+03	2017-07-26 16:40:00+03
6701	PG0432	2017-09-06 12:15:00+03	2017-09-06 16:35:00+03	SVO	RGK	Scheduled	733	\N	\N
6702	PG0432	2017-08-09 12:15:00+03	2017-08-09 16:35:00+03	SVO	RGK	Arrived	733	2017-08-09 12:19:00+03	2017-08-09 16:45:00+03
6703	PG0432	2017-08-23 12:15:00+03	2017-08-23 16:35:00+03	SVO	RGK	Scheduled	733	\N	\N
6704	PG0432	2017-08-16 12:15:00+03	2017-08-16 16:35:00+03	SVO	RGK	On Time	733	\N	\N
6705	PG0432	2017-08-30 12:15:00+03	2017-08-30 16:35:00+03	SVO	RGK	Scheduled	733	\N	\N
6706	PG0301	2017-09-12 13:40:00+03	2017-09-12 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6707	PG0301	2017-07-23 13:40:00+03	2017-07-23 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-23 13:42:00+03	2017-07-23 15:58:00+03
6708	PG0301	2017-09-04 13:40:00+03	2017-09-04 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6709	PG0301	2017-09-07 13:40:00+03	2017-09-07 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6710	PG0301	2017-09-01 13:40:00+03	2017-09-01 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6711	PG0301	2017-07-22 13:40:00+03	2017-07-22 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-22 13:47:00+03	2017-07-22 16:02:00+03
6712	PG0301	2017-08-02 13:40:00+03	2017-08-02 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-02 13:44:00+03	2017-08-02 15:59:00+03
6713	PG0301	2017-08-11 13:40:00+03	2017-08-11 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-11 13:42:00+03	2017-08-11 15:57:00+03
6714	PG0301	2017-08-23 13:40:00+03	2017-08-23 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6715	PG0301	2017-09-06 13:40:00+03	2017-09-06 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6716	PG0301	2017-08-22 13:40:00+03	2017-08-22 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6717	PG0301	2017-08-08 13:40:00+03	2017-08-08 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-08 13:41:00+03	2017-08-08 15:57:00+03
6718	PG0301	2017-09-09 13:40:00+03	2017-09-09 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6719	PG0301	2017-07-29 13:40:00+03	2017-07-29 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-29 13:42:00+03	2017-07-29 15:56:00+03
6720	PG0301	2017-07-28 13:40:00+03	2017-07-28 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-28 13:44:00+03	2017-07-28 15:58:00+03
6721	PG0301	2017-08-16 13:40:00+03	2017-08-16 15:55:00+03	SVO	TJM	On Time	SU9	\N	\N
6722	PG0301	2017-08-06 13:40:00+03	2017-08-06 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-06 13:44:00+03	2017-08-06 15:59:00+03
6723	PG0301	2017-07-18 13:40:00+03	2017-07-18 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-18 13:43:00+03	2017-07-18 16:00:00+03
6724	PG0301	2017-08-19 13:40:00+03	2017-08-19 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6725	PG0301	2017-08-12 13:40:00+03	2017-08-12 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-12 13:41:00+03	2017-08-12 15:55:00+03
6726	PG0301	2017-08-29 13:40:00+03	2017-08-29 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6727	PG0301	2017-07-27 13:40:00+03	2017-07-27 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-27 13:42:00+03	2017-07-27 15:57:00+03
6728	PG0301	2017-07-31 13:40:00+03	2017-07-31 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-31 13:43:00+03	2017-07-31 15:58:00+03
6729	PG0301	2017-08-14 13:40:00+03	2017-08-14 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-14 13:42:00+03	2017-08-14 15:59:00+03
6730	PG0301	2017-08-13 13:40:00+03	2017-08-13 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-13 13:44:00+03	2017-08-13 15:59:00+03
6731	PG0301	2017-07-17 13:40:00+03	2017-07-17 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-17 13:44:00+03	2017-07-17 15:57:00+03
6732	PG0301	2017-07-21 13:40:00+03	2017-07-21 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-21 13:41:00+03	2017-07-21 15:54:00+03
6733	PG0301	2017-07-16 13:40:00+03	2017-07-16 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-16 13:40:00+03	2017-07-16 15:57:00+03
6734	PG0301	2017-09-11 13:40:00+03	2017-09-11 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6735	PG0301	2017-07-26 13:40:00+03	2017-07-26 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-26 13:42:00+03	2017-07-26 15:56:00+03
6736	PG0301	2017-08-25 13:40:00+03	2017-08-25 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6737	PG0301	2017-08-18 13:40:00+03	2017-08-18 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6738	PG0301	2017-08-10 13:40:00+03	2017-08-10 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-10 13:44:00+03	2017-08-10 16:01:00+03
6739	PG0301	2017-08-01 13:40:00+03	2017-08-01 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-01 13:44:00+03	2017-08-01 15:59:00+03
6740	PG0301	2017-09-14 13:40:00+03	2017-09-14 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6741	PG0301	2017-08-09 13:40:00+03	2017-08-09 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-09 13:46:00+03	2017-08-09 16:01:00+03
6742	PG0301	2017-08-28 13:40:00+03	2017-08-28 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6743	PG0301	2017-08-26 13:40:00+03	2017-08-26 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6744	PG0301	2017-08-31 13:40:00+03	2017-08-31 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6745	PG0301	2017-08-20 13:40:00+03	2017-08-20 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6746	PG0301	2017-08-24 13:40:00+03	2017-08-24 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6747	PG0301	2017-07-20 13:40:00+03	2017-07-20 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-20 13:44:00+03	2017-07-20 15:59:00+03
6748	PG0301	2017-09-13 13:40:00+03	2017-09-13 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6749	PG0301	2017-09-03 13:40:00+03	2017-09-03 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6750	PG0301	2017-07-19 13:40:00+03	2017-07-19 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-19 13:42:00+03	2017-07-19 15:53:00+03
6751	PG0301	2017-08-05 13:40:00+03	2017-08-05 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-05 13:42:00+03	2017-08-05 15:55:00+03
6752	PG0301	2017-08-21 13:40:00+03	2017-08-21 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6753	PG0301	2017-08-27 13:40:00+03	2017-08-27 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6754	PG0301	2017-08-07 13:40:00+03	2017-08-07 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-07 13:44:00+03	2017-08-07 15:59:00+03
6755	PG0301	2017-08-17 13:40:00+03	2017-08-17 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6756	PG0301	2017-09-05 13:40:00+03	2017-09-05 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6757	PG0301	2017-08-03 13:40:00+03	2017-08-03 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-03 13:46:00+03	2017-08-03 16:02:00+03
6758	PG0301	2017-07-30 13:40:00+03	2017-07-30 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-30 13:44:00+03	2017-07-30 15:59:00+03
6759	PG0301	2017-09-10 13:40:00+03	2017-09-10 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6760	PG0301	2017-09-02 13:40:00+03	2017-09-02 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6761	PG0301	2017-08-30 13:40:00+03	2017-08-30 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6762	PG0301	2017-09-08 13:40:00+03	2017-09-08 15:55:00+03	SVO	TJM	Scheduled	SU9	\N	\N
6763	PG0301	2017-07-25 13:40:00+03	2017-07-25 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-25 13:42:00+03	2017-07-25 15:55:00+03
6764	PG0301	2017-08-04 13:40:00+03	2017-08-04 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-04 13:41:00+03	2017-08-04 15:57:00+03
6765	PG0301	2017-07-24 13:40:00+03	2017-07-24 15:55:00+03	SVO	TJM	Arrived	SU9	2017-07-24 13:42:00+03	2017-07-24 15:57:00+03
6766	PG0301	2017-08-15 13:40:00+03	2017-08-15 15:55:00+03	SVO	TJM	Arrived	SU9	2017-08-15 13:42:00+03	2017-08-15 15:57:00+03
6767	PG0043	2017-08-17 14:40:00+03	2017-08-17 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6768	PG0043	2017-09-13 14:40:00+03	2017-09-13 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6769	PG0043	2017-07-23 14:40:00+03	2017-07-23 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-23 14:41:00+03	2017-07-23 16:05:00+03
6770	PG0043	2017-07-22 14:40:00+03	2017-07-22 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-22 14:42:00+03	2017-07-22 16:08:00+03
6771	PG0043	2017-08-09 14:40:00+03	2017-08-09 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-09 14:41:00+03	2017-08-09 16:06:00+03
6772	PG0043	2017-09-06 14:40:00+03	2017-09-06 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6773	PG0043	2017-07-20 14:40:00+03	2017-07-20 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-20 14:42:00+03	2017-07-20 16:08:00+03
6774	PG0043	2017-07-21 14:40:00+03	2017-07-21 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-21 14:45:00+03	2017-07-21 16:11:00+03
6775	PG0043	2017-09-01 14:40:00+03	2017-09-01 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6776	PG0043	2017-08-23 14:40:00+03	2017-08-23 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6777	PG0043	2017-08-10 14:40:00+03	2017-08-10 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-10 14:44:00+03	2017-08-10 16:09:00+03
6778	PG0043	2017-09-04 14:40:00+03	2017-09-04 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6779	PG0043	2017-08-29 14:40:00+03	2017-08-29 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6780	PG0043	2017-08-05 14:40:00+03	2017-08-05 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-05 14:45:00+03	2017-08-05 16:10:00+03
6781	PG0043	2017-07-18 14:40:00+03	2017-07-18 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-18 14:40:00+03	2017-07-18 16:04:00+03
6782	PG0043	2017-09-07 14:40:00+03	2017-09-07 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6783	PG0043	2017-08-15 14:40:00+03	2017-08-15 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-15 14:43:00+03	2017-08-15 16:07:00+03
6784	PG0043	2017-08-11 14:40:00+03	2017-08-11 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-11 14:42:00+03	2017-08-11 16:06:00+03
6785	PG0043	2017-07-19 14:40:00+03	2017-07-19 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-19 14:40:00+03	2017-07-19 16:05:00+03
6786	PG0043	2017-07-16 14:40:00+03	2017-07-16 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-16 14:42:00+03	2017-07-16 16:08:00+03
6787	PG0043	2017-08-26 14:40:00+03	2017-08-26 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6788	PG0043	2017-08-22 14:40:00+03	2017-08-22 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6789	PG0043	2017-09-10 14:40:00+03	2017-09-10 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6790	PG0043	2017-07-24 14:40:00+03	2017-07-24 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-24 14:42:00+03	2017-07-24 16:06:00+03
6791	PG0043	2017-08-25 14:40:00+03	2017-08-25 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6792	PG0043	2017-08-04 14:40:00+03	2017-08-04 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-04 14:41:00+03	2017-08-04 16:04:00+03
6793	PG0043	2017-08-07 14:40:00+03	2017-08-07 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-07 18:02:00+03	2017-08-07 19:27:00+03
6794	PG0043	2017-08-19 14:40:00+03	2017-08-19 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6795	PG0043	2017-08-03 14:40:00+03	2017-08-03 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-03 14:45:00+03	2017-08-03 16:10:00+03
6796	PG0043	2017-08-27 14:40:00+03	2017-08-27 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6797	PG0043	2017-07-29 14:40:00+03	2017-07-29 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-29 14:43:00+03	2017-07-29 16:08:00+03
6798	PG0043	2017-08-02 14:40:00+03	2017-08-02 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-02 14:43:00+03	2017-08-02 16:07:00+03
6799	PG0043	2017-09-14 14:40:00+03	2017-09-14 16:05:00+03	SVO	IJK	Cancelled	CR2	\N	\N
6800	PG0043	2017-09-12 14:40:00+03	2017-09-12 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6801	PG0043	2017-08-28 14:40:00+03	2017-08-28 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6802	PG0043	2017-09-08 14:40:00+03	2017-09-08 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6803	PG0043	2017-09-05 14:40:00+03	2017-09-05 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6804	PG0043	2017-08-18 14:40:00+03	2017-08-18 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6805	PG0043	2017-07-30 14:40:00+03	2017-07-30 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-30 14:42:00+03	2017-07-30 16:07:00+03
6806	PG0043	2017-08-14 14:40:00+03	2017-08-14 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-14 14:45:00+03	2017-08-14 16:10:00+03
6807	PG0043	2017-08-21 14:40:00+03	2017-08-21 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6808	PG0043	2017-08-31 14:40:00+03	2017-08-31 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6809	PG0043	2017-07-26 14:40:00+03	2017-07-26 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-26 14:42:00+03	2017-07-26 16:08:00+03
6810	PG0043	2017-08-08 14:40:00+03	2017-08-08 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-08 14:43:00+03	2017-08-08 16:08:00+03
6811	PG0043	2017-09-09 14:40:00+03	2017-09-09 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6812	PG0043	2017-09-11 14:40:00+03	2017-09-11 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6813	PG0043	2017-08-06 14:40:00+03	2017-08-06 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-06 14:42:00+03	2017-08-06 16:07:00+03
6814	PG0043	2017-07-17 14:40:00+03	2017-07-17 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-17 14:43:00+03	2017-07-17 16:07:00+03
6815	PG0043	2017-07-27 14:40:00+03	2017-07-27 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-27 14:45:00+03	2017-07-27 16:11:00+03
6816	PG0043	2017-08-12 14:40:00+03	2017-08-12 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-12 14:42:00+03	2017-08-12 16:07:00+03
6817	PG0043	2017-08-13 14:40:00+03	2017-08-13 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-13 14:42:00+03	2017-08-13 16:08:00+03
6818	PG0043	2017-07-28 14:40:00+03	2017-07-28 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-28 14:45:00+03	2017-07-28 16:11:00+03
6819	PG0043	2017-08-16 14:40:00+03	2017-08-16 16:05:00+03	SVO	IJK	On Time	CR2	\N	\N
6820	PG0043	2017-09-03 14:40:00+03	2017-09-03 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6821	PG0043	2017-08-24 14:40:00+03	2017-08-24 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6822	PG0043	2017-08-30 14:40:00+03	2017-08-30 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6823	PG0043	2017-07-25 14:40:00+03	2017-07-25 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-25 14:41:00+03	2017-07-25 16:06:00+03
6824	PG0043	2017-09-02 14:40:00+03	2017-09-02 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6825	PG0043	2017-08-20 14:40:00+03	2017-08-20 16:05:00+03	SVO	IJK	Scheduled	CR2	\N	\N
6826	PG0043	2017-08-01 14:40:00+03	2017-08-01 16:05:00+03	SVO	IJK	Arrived	CR2	2017-08-01 14:41:00+03	2017-08-01 16:06:00+03
6827	PG0043	2017-07-31 14:40:00+03	2017-07-31 16:05:00+03	SVO	IJK	Arrived	CR2	2017-07-31 14:47:00+03	2017-07-31 16:12:00+03
6828	PG0452	2017-07-23 12:35:00+03	2017-07-23 16:30:00+03	SVO	BAX	Arrived	SU9	2017-07-23 12:39:00+03	2017-07-23 16:33:00+03
6829	PG0452	2017-08-16 12:35:00+03	2017-08-16 16:30:00+03	SVO	BAX	On Time	SU9	\N	\N
6830	PG0452	2017-07-30 12:35:00+03	2017-07-30 16:30:00+03	SVO	BAX	Arrived	SU9	2017-07-30 12:36:00+03	2017-07-30 16:31:00+03
6831	PG0452	2017-07-26 12:35:00+03	2017-07-26 16:30:00+03	SVO	BAX	Arrived	SU9	2017-07-26 12:37:00+03	2017-07-26 16:35:00+03
6832	PG0452	2017-08-02 12:35:00+03	2017-08-02 16:30:00+03	SVO	BAX	Arrived	SU9	2017-08-02 12:39:00+03	2017-08-02 16:32:00+03
6833	PG0452	2017-08-13 12:35:00+03	2017-08-13 16:30:00+03	SVO	BAX	Arrived	SU9	2017-08-13 12:37:00+03	2017-08-13 16:27:00+03
6834	PG0452	2017-08-20 12:35:00+03	2017-08-20 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6835	PG0452	2017-09-03 12:35:00+03	2017-09-03 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6836	PG0452	2017-08-27 12:35:00+03	2017-08-27 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6837	PG0452	2017-07-19 12:35:00+03	2017-07-19 16:30:00+03	SVO	BAX	Arrived	SU9	2017-07-19 12:36:00+03	2017-07-19 16:30:00+03
6838	PG0452	2017-08-09 12:35:00+03	2017-08-09 16:30:00+03	SVO	BAX	Arrived	SU9	2017-08-09 12:37:00+03	2017-08-09 16:35:00+03
6839	PG0452	2017-09-06 12:35:00+03	2017-09-06 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6840	PG0452	2017-07-16 12:35:00+03	2017-07-16 16:30:00+03	SVO	BAX	Arrived	SU9	2017-07-16 12:35:00+03	2017-07-16 16:33:00+03
6841	PG0452	2017-09-13 12:35:00+03	2017-09-13 16:30:00+03	SVO	BAX	Cancelled	SU9	\N	\N
6842	PG0452	2017-09-10 12:35:00+03	2017-09-10 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6843	PG0452	2017-08-06 12:35:00+03	2017-08-06 16:30:00+03	SVO	BAX	Arrived	SU9	2017-08-06 12:40:00+03	2017-08-06 16:36:00+03
6844	PG0452	2017-08-23 12:35:00+03	2017-08-23 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6845	PG0452	2017-08-30 12:35:00+03	2017-08-30 16:30:00+03	SVO	BAX	Scheduled	SU9	\N	\N
6846	PG0461	2017-09-12 12:25:00+03	2017-09-12 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6847	PG0460	2017-08-28 14:30:00+03	2017-08-28 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6848	PG0460	2017-07-23 14:30:00+03	2017-07-23 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-23 17:25:00+03	2017-07-23 18:20:00+03
6849	PG0461	2017-07-23 12:25:00+03	2017-07-23 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-23 12:29:00+03	2017-07-23 13:24:00+03
6850	PG0461	2017-07-31 12:25:00+03	2017-07-31 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-31 12:27:00+03	2017-07-31 13:22:00+03
6851	PG0460	2017-07-31 14:30:00+03	2017-07-31 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-31 14:34:00+03	2017-07-31 15:29:00+03
6852	PG0460	2017-08-13 14:30:00+03	2017-08-13 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-13 14:36:00+03	2017-08-13 15:31:00+03
6853	PG0461	2017-08-13 12:25:00+03	2017-08-13 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-13 12:30:00+03	2017-08-13 13:25:00+03
6854	PG0460	2017-08-31 14:30:00+03	2017-08-31 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6855	PG0461	2017-08-31 12:25:00+03	2017-08-31 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6856	PG0461	2017-09-06 12:25:00+03	2017-09-06 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6857	PG0460	2017-09-06 14:30:00+03	2017-09-06 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6858	PG0461	2017-08-12 12:25:00+03	2017-08-12 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-12 12:29:00+03	2017-08-12 13:24:00+03
6859	PG0460	2017-08-12 14:30:00+03	2017-08-12 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-12 14:36:00+03	2017-08-12 15:31:00+03
6860	PG0460	2017-08-01 14:30:00+03	2017-08-01 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-01 14:34:00+03	2017-08-01 15:29:00+03
6861	PG0461	2017-08-01 12:25:00+03	2017-08-01 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-01 12:29:00+03	2017-08-01 13:23:00+03
6862	PG0460	2017-07-16 14:30:00+03	2017-07-16 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-16 14:34:00+03	2017-07-16 15:30:00+03
6863	PG0461	2017-07-16 12:25:00+03	2017-07-16 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-16 12:28:00+03	2017-07-16 13:24:00+03
6864	PG0460	2017-09-11 14:30:00+03	2017-09-11 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6865	PG0461	2017-09-11 12:25:00+03	2017-09-11 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6866	PG0461	2017-08-20 12:25:00+03	2017-08-20 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6867	PG0460	2017-08-20 14:30:00+03	2017-08-20 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6868	PG0461	2017-07-22 12:25:00+03	2017-07-22 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-22 12:26:00+03	2017-07-22 13:21:00+03
6869	PG0460	2017-07-22 14:30:00+03	2017-07-22 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-22 14:31:00+03	2017-07-22 15:26:00+03
6870	PG0461	2017-08-28 12:25:00+03	2017-08-28 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6871	PG0461	2017-08-11 12:25:00+03	2017-08-11 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-11 12:29:00+03	2017-08-11 13:24:00+03
6872	PG0460	2017-08-11 14:30:00+03	2017-08-11 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-11 14:34:00+03	2017-08-11 15:29:00+03
6873	PG0460	2017-08-25 14:30:00+03	2017-08-25 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6874	PG0461	2017-08-25 12:25:00+03	2017-08-25 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6875	PG0460	2017-08-22 14:30:00+03	2017-08-22 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6876	PG0461	2017-08-22 12:25:00+03	2017-08-22 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6877	PG0460	2017-09-01 14:30:00+03	2017-09-01 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6878	PG0461	2017-09-01 12:25:00+03	2017-09-01 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6879	PG0460	2017-08-02 14:30:00+03	2017-08-02 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-02 14:32:00+03	2017-08-02 15:28:00+03
6880	PG0461	2017-08-02 12:25:00+03	2017-08-02 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-02 12:27:00+03	2017-08-02 13:22:00+03
6881	PG0461	2017-08-24 12:25:00+03	2017-08-24 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6882	PG0460	2017-08-24 14:30:00+03	2017-08-24 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6883	PG0461	2017-07-30 12:25:00+03	2017-07-30 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-30 12:32:00+03	2017-07-30 13:27:00+03
6884	PG0460	2017-07-30 14:30:00+03	2017-07-30 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-30 14:33:00+03	2017-07-30 15:28:00+03
6885	PG0461	2017-08-10 12:25:00+03	2017-08-10 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-10 12:29:00+03	2017-08-10 13:24:00+03
6886	PG0460	2017-08-10 14:30:00+03	2017-08-10 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-10 14:30:00+03	2017-08-10 15:25:00+03
6887	PG0460	2017-08-14 14:30:00+03	2017-08-14 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-14 14:32:00+03	2017-08-14 15:27:00+03
6888	PG0461	2017-08-14 12:25:00+03	2017-08-14 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-14 12:26:00+03	2017-08-14 13:21:00+03
6889	PG0460	2017-07-17 14:30:00+03	2017-07-17 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-17 14:33:00+03	2017-07-17 15:29:00+03
6890	PG0461	2017-07-17 12:25:00+03	2017-07-17 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-17 12:27:00+03	2017-07-17 13:21:00+03
6891	PG0460	2017-07-27 14:30:00+03	2017-07-27 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-27 14:32:00+03	2017-07-27 15:27:00+03
6892	PG0461	2017-07-27 12:25:00+03	2017-07-27 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-27 12:25:00+03	2017-07-27 13:21:00+03
6893	PG0461	2017-08-17 12:25:00+03	2017-08-17 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6894	PG0460	2017-08-17 14:30:00+03	2017-08-17 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6895	PG0461	2017-09-05 12:25:00+03	2017-09-05 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6896	PG0460	2017-09-05 14:30:00+03	2017-09-05 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6897	PG0461	2017-08-27 12:25:00+03	2017-08-27 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6898	PG0461	2017-09-14 12:25:00+03	2017-09-14 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6899	PG0460	2017-09-14 14:30:00+03	2017-09-14 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6900	PG0460	2017-09-07 14:30:00+03	2017-09-07 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6901	PG0461	2017-09-07 12:25:00+03	2017-09-07 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6902	PG0461	2017-08-26 12:25:00+03	2017-08-26 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6903	PG0460	2017-08-26 14:30:00+03	2017-08-26 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6904	PG0461	2017-08-30 12:25:00+03	2017-08-30 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6905	PG0460	2017-08-30 14:30:00+03	2017-08-30 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6906	PG0460	2017-08-27 14:30:00+03	2017-08-27 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6907	PG0460	2017-08-03 14:30:00+03	2017-08-03 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-03 14:35:00+03	2017-08-03 15:31:00+03
6908	PG0461	2017-08-03 12:25:00+03	2017-08-03 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-03 12:30:00+03	2017-08-03 13:26:00+03
6909	PG0461	2017-07-21 12:25:00+03	2017-07-21 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-21 12:29:00+03	2017-07-21 13:24:00+03
6910	PG0461	2017-07-25 12:25:00+03	2017-07-25 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-25 12:27:00+03	2017-07-25 13:23:00+03
6911	PG0460	2017-07-25 14:30:00+03	2017-07-25 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-25 14:33:00+03	2017-07-25 15:28:00+03
6912	PG0460	2017-07-21 14:30:00+03	2017-07-21 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-21 14:32:00+03	2017-07-21 15:26:00+03
6913	PG0461	2017-08-09 12:25:00+03	2017-08-09 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-09 12:30:00+03	2017-08-09 13:24:00+03
6914	PG0460	2017-08-09 14:30:00+03	2017-08-09 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-09 14:34:00+03	2017-08-09 15:29:00+03
6915	PG0460	2017-09-02 14:30:00+03	2017-09-02 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6916	PG0461	2017-09-02 12:25:00+03	2017-09-02 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6917	PG0461	2017-08-18 12:25:00+03	2017-08-18 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6918	PG0460	2017-07-18 14:30:00+03	2017-07-18 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-18 14:32:00+03	2017-07-18 15:28:00+03
6919	PG0461	2017-07-18 12:25:00+03	2017-07-18 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-18 12:26:00+03	2017-07-18 13:20:00+03
6920	PG0461	2017-08-08 12:25:00+03	2017-08-08 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-08 12:26:00+03	2017-08-08 13:21:00+03
6921	PG0460	2017-08-08 14:30:00+03	2017-08-08 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-08 14:38:00+03	2017-08-08 15:33:00+03
6922	PG0460	2017-08-04 14:30:00+03	2017-08-04 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-04 14:32:00+03	2017-08-04 15:27:00+03
6923	PG0461	2017-08-04 12:25:00+03	2017-08-04 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-04 12:28:00+03	2017-08-04 13:22:00+03
6924	PG0460	2017-09-12 14:30:00+03	2017-09-12 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6925	PG0461	2017-09-09 12:25:00+03	2017-09-09 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6926	PG0461	2017-09-13 12:25:00+03	2017-09-13 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6927	PG0460	2017-09-13 14:30:00+03	2017-09-13 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6928	PG0460	2017-08-15 14:30:00+03	2017-08-15 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-15 14:33:00+03	2017-08-15 15:28:00+03
6929	PG0461	2017-08-15 12:25:00+03	2017-08-15 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-15 12:25:00+03	2017-08-15 13:20:00+03
6930	PG0461	2017-09-08 12:25:00+03	2017-09-08 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6931	PG0460	2017-09-08 14:30:00+03	2017-09-08 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6932	PG0460	2017-07-28 14:30:00+03	2017-07-28 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-28 14:34:00+03	2017-07-28 15:29:00+03
6933	PG0461	2017-07-28 12:25:00+03	2017-07-28 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-28 12:31:00+03	2017-07-28 13:25:00+03
6934	PG0460	2017-08-29 14:30:00+03	2017-08-29 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6935	PG0461	2017-08-29 12:25:00+03	2017-08-29 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6936	PG0460	2017-09-09 14:30:00+03	2017-09-09 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6937	PG0460	2017-08-18 14:30:00+03	2017-08-18 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6939	PG0460	2017-09-04 14:30:00+03	2017-09-04 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6940	PG0461	2017-07-20 12:25:00+03	2017-07-20 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-20 12:29:00+03	2017-07-20 13:25:00+03
6941	PG0460	2017-07-20 14:30:00+03	2017-07-20 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-20 14:32:00+03	2017-07-20 15:26:00+03
6942	PG0460	2017-08-19 14:30:00+03	2017-08-19 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6943	PG0461	2017-08-19 12:25:00+03	2017-08-19 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6944	PG0461	2017-08-07 12:25:00+03	2017-08-07 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-07 12:27:00+03	2017-08-07 13:22:00+03
6945	PG0460	2017-08-07 14:30:00+03	2017-08-07 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-07 14:30:00+03	2017-08-07 15:25:00+03
6946	PG0461	2017-08-21 12:25:00+03	2017-08-21 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6947	PG0461	2017-07-26 12:25:00+03	2017-07-26 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-26 12:29:00+03	2017-07-26 13:25:00+03
6948	PG0461	2017-07-29 12:25:00+03	2017-07-29 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-29 12:28:00+03	2017-07-29 13:23:00+03
6949	PG0460	2017-07-29 14:30:00+03	2017-07-29 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-29 14:32:00+03	2017-07-29 15:28:00+03
6950	PG0460	2017-08-21 14:30:00+03	2017-08-21 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6951	PG0460	2017-07-24 14:30:00+03	2017-07-24 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-24 14:32:00+03	2017-07-24 15:28:00+03
6952	PG0461	2017-07-24 12:25:00+03	2017-07-24 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-24 12:31:00+03	2017-07-24 13:26:00+03
6953	PG0460	2017-07-26 14:30:00+03	2017-07-26 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-26 14:34:00+03	2017-07-26 15:29:00+03
6954	PG0460	2017-08-05 14:30:00+03	2017-08-05 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-05 14:35:00+03	2017-08-05 15:29:00+03
6955	PG0461	2017-08-05 12:25:00+03	2017-08-05 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-05 12:29:00+03	2017-08-05 13:24:00+03
6956	PG0460	2017-09-03 14:30:00+03	2017-09-03 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6957	PG0461	2017-09-03 12:25:00+03	2017-09-03 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6958	PG0461	2017-09-10 12:25:00+03	2017-09-10 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6959	PG0461	2017-08-16 12:25:00+03	2017-08-16 13:20:00+03	SVO	ULV	On Time	SU9	\N	\N
6960	PG0460	2017-09-10 14:30:00+03	2017-09-10 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6961	PG0460	2017-08-16 14:30:00+03	2017-08-16 15:25:00+03	SVO	ULV	Delayed	SU9	\N	\N
6962	PG0460	2017-07-19 14:30:00+03	2017-07-19 15:25:00+03	SVO	ULV	Arrived	SU9	2017-07-19 17:55:00+03	2017-07-19 18:50:00+03
6963	PG0461	2017-07-19 12:25:00+03	2017-07-19 13:20:00+03	SVO	ULV	Arrived	SU9	2017-07-19 12:29:00+03	2017-07-19 13:24:00+03
6964	PG0461	2017-08-23 12:25:00+03	2017-08-23 13:20:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6965	PG0460	2017-08-23 14:30:00+03	2017-08-23 15:25:00+03	SVO	ULV	Scheduled	SU9	\N	\N
6966	PG0461	2017-08-06 12:25:00+03	2017-08-06 13:20:00+03	SVO	ULV	Arrived	SU9	2017-08-06 12:28:00+03	2017-08-06 13:23:00+03
6967	PG0460	2017-08-06 14:30:00+03	2017-08-06 15:25:00+03	SVO	ULV	Arrived	SU9	2017-08-06 14:35:00+03	2017-08-06 15:30:00+03
6968	PG0283	2017-07-22 13:25:00+03	2017-07-22 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-22 13:27:00+03	2017-07-22 14:31:00+03
6969	PG0283	2017-09-04 13:25:00+03	2017-09-04 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6970	PG0283	2017-08-17 13:25:00+03	2017-08-17 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6971	PG0283	2017-09-08 13:25:00+03	2017-09-08 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6972	PG0283	2017-08-31 13:25:00+03	2017-08-31 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6973	PG0283	2017-09-13 13:25:00+03	2017-09-13 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6974	PG0283	2017-08-13 13:25:00+03	2017-08-13 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-13 13:26:00+03	2017-08-13 14:31:00+03
6975	PG0283	2017-07-29 13:25:00+03	2017-07-29 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-29 13:30:00+03	2017-07-29 14:35:00+03
6976	PG0283	2017-09-02 13:25:00+03	2017-09-02 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6977	PG0283	2017-09-05 13:25:00+03	2017-09-05 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6978	PG0283	2017-07-16 13:25:00+03	2017-07-16 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-16 13:29:00+03	2017-07-16 14:34:00+03
6979	PG0283	2017-09-10 13:25:00+03	2017-09-10 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6980	PG0283	2017-07-27 13:25:00+03	2017-07-27 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-27 13:29:00+03	2017-07-27 14:35:00+03
6981	PG0283	2017-08-14 13:25:00+03	2017-08-14 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-14 13:31:00+03	2017-08-14 14:36:00+03
6982	PG0283	2017-08-25 13:25:00+03	2017-08-25 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6983	PG0283	2017-07-17 13:25:00+03	2017-07-17 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-17 13:31:00+03	2017-07-17 14:37:00+03
6984	PG0283	2017-08-08 13:25:00+03	2017-08-08 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-08 13:27:00+03	2017-08-08 14:32:00+03
6985	PG0283	2017-08-18 13:25:00+03	2017-08-18 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6986	PG0283	2017-07-23 13:25:00+03	2017-07-23 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-23 13:29:00+03	2017-07-23 14:34:00+03
6987	PG0283	2017-07-30 13:25:00+03	2017-07-30 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-30 13:27:00+03	2017-07-30 14:32:00+03
6988	PG0283	2017-08-24 13:25:00+03	2017-08-24 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6989	PG0283	2017-08-23 13:25:00+03	2017-08-23 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6990	PG0283	2017-08-20 13:25:00+03	2017-08-20 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6991	PG0283	2017-07-20 13:25:00+03	2017-07-20 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-20 13:29:00+03	2017-07-20 14:34:00+03
6992	PG0283	2017-08-03 13:25:00+03	2017-08-03 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-03 13:28:00+03	2017-08-03 14:33:00+03
6993	PG0283	2017-08-10 13:25:00+03	2017-08-10 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-10 13:27:00+03	2017-08-10 14:32:00+03
6994	PG0283	2017-09-11 13:25:00+03	2017-09-11 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6995	PG0283	2017-08-12 13:25:00+03	2017-08-12 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-12 13:26:00+03	2017-08-12 14:32:00+03
6996	PG0283	2017-07-28 13:25:00+03	2017-07-28 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-28 13:30:00+03	2017-07-28 14:34:00+03
6997	PG0283	2017-08-05 13:25:00+03	2017-08-05 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-05 13:29:00+03	2017-08-05 14:34:00+03
6998	PG0283	2017-08-30 13:25:00+03	2017-08-30 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
6999	PG0283	2017-09-14 13:25:00+03	2017-09-14 14:30:00+03	SVO	ULY	Cancelled	CR2	\N	\N
7000	PG0283	2017-08-21 13:25:00+03	2017-08-21 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7001	PG0283	2017-07-25 13:25:00+03	2017-07-25 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-25 16:53:00+03	2017-07-25 17:58:00+03
7002	PG0283	2017-08-04 13:25:00+03	2017-08-04 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-04 13:26:00+03	2017-08-04 14:31:00+03
7003	PG0283	2017-08-15 13:25:00+03	2017-08-15 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-15 13:30:00+03	2017-08-15 14:34:00+03
7004	PG0283	2017-08-16 13:25:00+03	2017-08-16 14:30:00+03	SVO	ULY	On Time	CR2	\N	\N
7005	PG0283	2017-09-03 13:25:00+03	2017-09-03 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7006	PG0283	2017-09-09 13:25:00+03	2017-09-09 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7007	PG0283	2017-09-06 13:25:00+03	2017-09-06 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7008	PG0283	2017-08-27 13:25:00+03	2017-08-27 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7009	PG0283	2017-08-06 13:25:00+03	2017-08-06 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-06 13:29:00+03	2017-08-06 14:35:00+03
7010	PG0283	2017-07-24 13:25:00+03	2017-07-24 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-24 13:30:00+03	2017-07-24 14:36:00+03
7011	PG0283	2017-09-07 13:25:00+03	2017-09-07 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7012	PG0283	2017-08-26 13:25:00+03	2017-08-26 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7013	PG0283	2017-09-12 13:25:00+03	2017-09-12 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7014	PG0283	2017-07-19 13:25:00+03	2017-07-19 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-19 15:58:00+03	2017-07-19 17:03:00+03
7015	PG0283	2017-08-07 13:25:00+03	2017-08-07 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-07 16:14:00+03	2017-08-07 17:19:00+03
7016	PG0283	2017-07-21 13:25:00+03	2017-07-21 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-21 13:28:00+03	2017-07-21 14:33:00+03
7017	PG0283	2017-07-31 13:25:00+03	2017-07-31 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-31 13:30:00+03	2017-07-31 14:36:00+03
7018	PG0283	2017-08-28 13:25:00+03	2017-08-28 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7019	PG0283	2017-09-01 13:25:00+03	2017-09-01 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7020	PG0283	2017-07-18 13:25:00+03	2017-07-18 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-18 13:25:00+03	2017-07-18 14:30:00+03
7021	PG0283	2017-08-02 13:25:00+03	2017-08-02 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-02 13:29:00+03	2017-08-02 14:35:00+03
7022	PG0283	2017-08-01 13:25:00+03	2017-08-01 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-01 13:31:00+03	2017-08-01 14:36:00+03
7023	PG0283	2017-08-19 13:25:00+03	2017-08-19 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7024	PG0283	2017-08-22 13:25:00+03	2017-08-22 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7025	PG0283	2017-08-09 13:25:00+03	2017-08-09 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-09 13:29:00+03	2017-08-09 14:35:00+03
7026	PG0283	2017-08-11 13:25:00+03	2017-08-11 14:30:00+03	SVO	ULY	Arrived	CR2	2017-08-11 13:27:00+03	2017-08-11 14:32:00+03
7027	PG0283	2017-08-29 13:25:00+03	2017-08-29 14:30:00+03	SVO	ULY	Scheduled	CR2	\N	\N
7028	PG0283	2017-07-26 13:25:00+03	2017-07-26 14:30:00+03	SVO	ULY	Arrived	CR2	2017-07-26 13:25:00+03	2017-07-26 14:31:00+03
7029	PG0677	2017-07-22 09:40:00+03	2017-07-22 11:55:00+03	SVO	MCX	Arrived	733	2017-07-22 12:58:00+03	2017-07-22 15:13:00+03
7030	PG0677	2017-09-07 09:40:00+03	2017-09-07 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7031	PG0677	2017-07-19 09:40:00+03	2017-07-19 11:55:00+03	SVO	MCX	Arrived	733	2017-07-19 09:41:00+03	2017-07-19 11:54:00+03
7032	PG0677	2017-08-16 09:40:00+03	2017-08-16 11:55:00+03	SVO	MCX	On Time	733	\N	\N
7033	PG0677	2017-08-23 09:40:00+03	2017-08-23 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7034	PG0677	2017-07-31 09:40:00+03	2017-07-31 11:55:00+03	SVO	MCX	Arrived	733	2017-07-31 09:43:00+03	2017-07-31 11:58:00+03
7035	PG0677	2017-08-04 09:40:00+03	2017-08-04 11:55:00+03	SVO	MCX	Arrived	733	2017-08-04 13:25:00+03	2017-08-04 15:40:00+03
7036	PG0677	2017-07-18 09:40:00+03	2017-07-18 11:55:00+03	SVO	MCX	Arrived	733	2017-07-18 09:41:00+03	2017-07-18 11:55:00+03
7037	PG0677	2017-08-15 09:40:00+03	2017-08-15 11:55:00+03	SVO	MCX	Arrived	733	2017-08-15 09:44:00+03	2017-08-15 12:00:00+03
7038	PG0677	2017-07-20 09:40:00+03	2017-07-20 11:55:00+03	SVO	MCX	Arrived	733	2017-07-20 09:41:00+03	2017-07-20 11:55:00+03
7039	PG0677	2017-09-04 09:40:00+03	2017-09-04 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7040	PG0677	2017-07-29 09:40:00+03	2017-07-29 11:55:00+03	SVO	MCX	Arrived	733	2017-07-29 09:43:00+03	2017-07-29 11:55:00+03
7041	PG0677	2017-09-02 09:40:00+03	2017-09-02 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7042	PG0677	2017-07-28 09:40:00+03	2017-07-28 11:55:00+03	SVO	MCX	Arrived	733	2017-07-28 09:42:00+03	2017-07-28 11:58:00+03
7043	PG0677	2017-08-12 09:40:00+03	2017-08-12 11:55:00+03	SVO	MCX	Arrived	733	2017-08-12 09:46:00+03	2017-08-12 12:00:00+03
7044	PG0677	2017-08-08 09:40:00+03	2017-08-08 11:55:00+03	SVO	MCX	Arrived	733	2017-08-08 09:41:00+03	2017-08-08 11:56:00+03
7045	PG0677	2017-08-25 09:40:00+03	2017-08-25 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7046	PG0677	2017-09-13 09:40:00+03	2017-09-13 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7047	PG0677	2017-08-27 09:40:00+03	2017-08-27 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7048	PG0677	2017-08-22 09:40:00+03	2017-08-22 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7049	PG0677	2017-08-03 09:40:00+03	2017-08-03 11:55:00+03	SVO	MCX	Arrived	733	2017-08-03 09:41:00+03	2017-08-03 11:54:00+03
7050	PG0677	2017-07-27 09:40:00+03	2017-07-27 11:55:00+03	SVO	MCX	Arrived	733	2017-07-27 12:56:00+03	2017-07-27 15:11:00+03
7051	PG0677	2017-09-08 09:40:00+03	2017-09-08 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7052	PG0677	2017-09-14 09:40:00+03	2017-09-14 11:55:00+03	SVO	MCX	Cancelled	733	\N	\N
7053	PG0677	2017-08-14 09:40:00+03	2017-08-14 11:55:00+03	SVO	MCX	Arrived	733	2017-08-14 09:44:00+03	2017-08-14 12:02:00+03
7054	PG0677	2017-07-17 09:40:00+03	2017-07-17 11:55:00+03	SVO	MCX	Arrived	733	2017-07-17 09:40:00+03	2017-07-17 11:55:00+03
7055	PG0677	2017-08-09 09:40:00+03	2017-08-09 11:55:00+03	SVO	MCX	Arrived	733	2017-08-09 09:43:00+03	2017-08-09 11:56:00+03
7056	PG0677	2017-08-26 09:40:00+03	2017-08-26 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7057	PG0677	2017-07-21 09:40:00+03	2017-07-21 11:55:00+03	SVO	MCX	Arrived	733	2017-07-21 09:42:00+03	2017-07-21 11:57:00+03
7058	PG0677	2017-09-01 09:40:00+03	2017-09-01 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7059	PG0677	2017-08-02 09:40:00+03	2017-08-02 11:55:00+03	SVO	MCX	Arrived	733	2017-08-02 09:42:00+03	2017-08-02 11:58:00+03
7060	PG0677	2017-09-11 09:40:00+03	2017-09-11 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7061	PG0677	2017-08-10 09:40:00+03	2017-08-10 11:55:00+03	SVO	MCX	Arrived	733	2017-08-10 09:42:00+03	2017-08-10 11:58:00+03
7062	PG0677	2017-08-06 09:40:00+03	2017-08-06 11:55:00+03	SVO	MCX	Arrived	733	2017-08-06 09:42:00+03	2017-08-06 12:00:00+03
7063	PG0677	2017-09-05 09:40:00+03	2017-09-05 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7064	PG0677	2017-07-24 09:40:00+03	2017-07-24 11:55:00+03	SVO	MCX	Arrived	733	2017-07-24 09:44:00+03	2017-07-24 11:58:00+03
7065	PG0677	2017-08-30 09:40:00+03	2017-08-30 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7066	PG0677	2017-07-25 09:40:00+03	2017-07-25 11:55:00+03	SVO	MCX	Arrived	733	2017-07-25 09:44:00+03	2017-07-25 11:56:00+03
7067	PG0677	2017-09-10 09:40:00+03	2017-09-10 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7068	PG0677	2017-09-09 09:40:00+03	2017-09-09 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7069	PG0677	2017-08-17 09:40:00+03	2017-08-17 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7070	PG0677	2017-07-23 09:40:00+03	2017-07-23 11:55:00+03	SVO	MCX	Arrived	733	2017-07-23 09:47:00+03	2017-07-23 12:01:00+03
7071	PG0677	2017-08-05 09:40:00+03	2017-08-05 11:55:00+03	SVO	MCX	Arrived	733	2017-08-05 09:44:00+03	2017-08-05 12:02:00+03
7072	PG0677	2017-07-16 09:40:00+03	2017-07-16 11:55:00+03	SVO	MCX	Arrived	733	2017-07-16 09:45:00+03	2017-07-16 11:58:00+03
7073	PG0677	2017-08-21 09:40:00+03	2017-08-21 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7074	PG0677	2017-08-18 09:40:00+03	2017-08-18 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7075	PG0677	2017-09-06 09:40:00+03	2017-09-06 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7076	PG0677	2017-08-11 09:40:00+03	2017-08-11 11:55:00+03	SVO	MCX	Arrived	733	2017-08-11 09:42:00+03	2017-08-11 11:58:00+03
7077	PG0677	2017-08-01 09:40:00+03	2017-08-01 11:55:00+03	SVO	MCX	Arrived	733	2017-08-01 09:42:00+03	2017-08-01 11:56:00+03
7078	PG0677	2017-07-30 09:40:00+03	2017-07-30 11:55:00+03	SVO	MCX	Arrived	733	2017-07-30 09:46:00+03	2017-07-30 12:02:00+03
7079	PG0677	2017-08-13 09:40:00+03	2017-08-13 11:55:00+03	SVO	MCX	Arrived	733	2017-08-13 09:44:00+03	2017-08-13 11:58:00+03
7080	PG0677	2017-07-26 09:40:00+03	2017-07-26 11:55:00+03	SVO	MCX	Arrived	733	2017-07-26 12:52:00+03	2017-07-26 15:05:00+03
7081	PG0677	2017-08-28 09:40:00+03	2017-08-28 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7082	PG0677	2017-08-29 09:40:00+03	2017-08-29 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7083	PG0677	2017-08-24 09:40:00+03	2017-08-24 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7084	PG0677	2017-08-20 09:40:00+03	2017-08-20 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7085	PG0677	2017-09-03 09:40:00+03	2017-09-03 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7086	PG0677	2017-09-12 09:40:00+03	2017-09-12 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7087	PG0677	2017-08-31 09:40:00+03	2017-08-31 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7088	PG0677	2017-08-19 09:40:00+03	2017-08-19 11:55:00+03	SVO	MCX	Scheduled	733	\N	\N
7089	PG0677	2017-08-07 09:40:00+03	2017-08-07 11:55:00+03	SVO	MCX	Arrived	733	2017-08-07 09:42:00+03	2017-08-07 11:57:00+03
7090	PG0591	2017-09-13 09:00:00+03	2017-09-13 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7091	PG0591	2017-07-27 09:00:00+03	2017-07-27 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-27 09:05:00+03	2017-07-27 12:57:00+03
7092	PG0591	2017-07-20 09:00:00+03	2017-07-20 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-20 09:03:00+03	2017-07-20 12:59:00+03
7093	PG0591	2017-07-25 09:00:00+03	2017-07-25 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-25 09:02:00+03	2017-07-25 12:56:00+03
7094	PG0591	2017-09-05 09:00:00+03	2017-09-05 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7095	PG0591	2017-08-02 09:00:00+03	2017-08-02 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-02 09:03:00+03	2017-08-02 12:55:00+03
7096	PG0591	2017-09-01 09:00:00+03	2017-09-01 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7097	PG0591	2017-08-27 09:00:00+03	2017-08-27 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7098	PG0591	2017-07-21 09:00:00+03	2017-07-21 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-21 09:04:00+03	2017-07-21 12:59:00+03
7099	PG0591	2017-08-10 09:00:00+03	2017-08-10 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-10 09:02:00+03	2017-08-10 12:54:00+03
7100	PG0591	2017-08-19 09:00:00+03	2017-08-19 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7101	PG0591	2017-08-17 09:00:00+03	2017-08-17 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7102	PG0591	2017-08-25 09:00:00+03	2017-08-25 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7103	PG0591	2017-09-10 09:00:00+03	2017-09-10 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7104	PG0591	2017-07-22 09:00:00+03	2017-07-22 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-22 09:00:00+03	2017-07-22 12:53:00+03
7105	PG0591	2017-08-16 09:00:00+03	2017-08-16 12:55:00+03	SVO	TOF	On Time	SU9	\N	\N
7106	PG0591	2017-09-07 09:00:00+03	2017-09-07 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7107	PG0591	2017-07-18 09:00:00+03	2017-07-18 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-18 09:03:00+03	2017-07-18 13:00:00+03
7108	PG0591	2017-07-29 09:00:00+03	2017-07-29 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-29 09:02:00+03	2017-07-29 12:56:00+03
7109	PG0591	2017-08-09 09:00:00+03	2017-08-09 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-09 09:05:00+03	2017-08-09 12:57:00+03
7110	PG0591	2017-07-31 09:00:00+03	2017-07-31 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-31 09:01:00+03	2017-07-31 12:56:00+03
7111	PG0591	2017-08-04 09:00:00+03	2017-08-04 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-04 09:04:00+03	2017-08-04 13:03:00+03
7112	PG0591	2017-08-13 09:00:00+03	2017-08-13 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-13 09:02:00+03	2017-08-13 12:55:00+03
7113	PG0591	2017-08-03 09:00:00+03	2017-08-03 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-03 09:04:00+03	2017-08-03 13:00:00+03
7114	PG0591	2017-09-12 09:00:00+03	2017-09-12 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7115	PG0591	2017-07-26 09:00:00+03	2017-07-26 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-26 09:02:00+03	2017-07-26 12:53:00+03
7116	PG0591	2017-09-11 09:00:00+03	2017-09-11 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7117	PG0591	2017-09-03 09:00:00+03	2017-09-03 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7118	PG0591	2017-08-06 09:00:00+03	2017-08-06 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-06 09:03:00+03	2017-08-06 12:56:00+03
7119	PG0591	2017-09-08 09:00:00+03	2017-09-08 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7120	PG0591	2017-07-30 09:00:00+03	2017-07-30 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-30 09:03:00+03	2017-07-30 12:58:00+03
7121	PG0591	2017-09-04 09:00:00+03	2017-09-04 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7122	PG0591	2017-08-11 09:00:00+03	2017-08-11 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-11 09:00:00+03	2017-08-11 13:00:00+03
7123	PG0591	2017-08-18 09:00:00+03	2017-08-18 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7124	PG0591	2017-07-24 09:00:00+03	2017-07-24 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-24 09:02:00+03	2017-07-24 13:00:00+03
7125	PG0591	2017-08-24 09:00:00+03	2017-08-24 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7126	PG0591	2017-07-28 09:00:00+03	2017-07-28 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-28 09:02:00+03	2017-07-28 12:57:00+03
7127	PG0591	2017-08-15 09:00:00+03	2017-08-15 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-15 09:07:00+03	2017-08-15 12:57:00+03
7128	PG0591	2017-08-20 09:00:00+03	2017-08-20 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7129	PG0591	2017-09-09 09:00:00+03	2017-09-09 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7130	PG0591	2017-07-16 09:00:00+03	2017-07-16 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-16 09:05:00+03	2017-07-16 13:00:00+03
7131	PG0591	2017-07-19 09:00:00+03	2017-07-19 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-19 09:03:00+03	2017-07-19 12:59:00+03
7132	PG0591	2017-08-12 09:00:00+03	2017-08-12 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-12 09:01:00+03	2017-08-12 12:57:00+03
7133	PG0591	2017-08-31 09:00:00+03	2017-08-31 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7134	PG0591	2017-08-26 09:00:00+03	2017-08-26 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7135	PG0591	2017-08-08 09:00:00+03	2017-08-08 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-08 09:04:00+03	2017-08-08 12:57:00+03
7136	PG0591	2017-08-01 09:00:00+03	2017-08-01 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-01 12:24:00+03	2017-08-01 16:18:00+03
7137	PG0591	2017-09-02 09:00:00+03	2017-09-02 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7138	PG0591	2017-09-06 09:00:00+03	2017-09-06 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7139	PG0591	2017-07-23 09:00:00+03	2017-07-23 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-23 09:03:00+03	2017-07-23 12:56:00+03
7140	PG0591	2017-08-29 09:00:00+03	2017-08-29 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7141	PG0591	2017-09-14 09:00:00+03	2017-09-14 12:55:00+03	SVO	TOF	Cancelled	SU9	\N	\N
7142	PG0591	2017-08-28 09:00:00+03	2017-08-28 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7143	PG0591	2017-08-07 09:00:00+03	2017-08-07 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-07 09:00:00+03	2017-08-07 12:57:00+03
7144	PG0591	2017-07-17 09:00:00+03	2017-07-17 12:55:00+03	SVO	TOF	Arrived	SU9	2017-07-17 09:01:00+03	2017-07-17 12:59:00+03
7145	PG0591	2017-08-05 09:00:00+03	2017-08-05 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-05 09:01:00+03	2017-08-05 12:57:00+03
7146	PG0591	2017-08-23 09:00:00+03	2017-08-23 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7147	PG0591	2017-08-22 09:00:00+03	2017-08-22 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7148	PG0591	2017-08-14 09:00:00+03	2017-08-14 12:55:00+03	SVO	TOF	Arrived	SU9	2017-08-14 09:05:00+03	2017-08-14 13:01:00+03
7149	PG0591	2017-08-21 09:00:00+03	2017-08-21 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7150	PG0591	2017-08-30 09:00:00+03	2017-08-30 12:55:00+03	SVO	TOF	Scheduled	SU9	\N	\N
7151	PG0663	2017-09-08 12:30:00+03	2017-09-08 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7152	PG0663	2017-07-28 12:30:00+03	2017-07-28 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-07-28 12:34:00+03	2017-07-28 16:31:00+03
7153	PG0663	2017-08-08 12:30:00+03	2017-08-08 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-08-08 12:32:00+03	2017-08-08 16:30:00+03
7154	PG0663	2017-08-04 12:30:00+03	2017-08-04 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-08-04 12:32:00+03	2017-08-04 16:32:00+03
7155	PG0663	2017-07-21 12:30:00+03	2017-07-21 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-07-21 12:33:00+03	2017-07-21 16:35:00+03
7156	PG0663	2017-08-01 12:30:00+03	2017-08-01 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-08-01 12:33:00+03	2017-08-01 16:30:00+03
7157	PG0663	2017-08-22 12:30:00+03	2017-08-22 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7158	PG0663	2017-08-18 12:30:00+03	2017-08-18 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7159	PG0663	2017-09-12 12:30:00+03	2017-09-12 16:30:00+03	SVO	KEJ	Cancelled	SU9	\N	\N
7160	PG0663	2017-07-18 12:30:00+03	2017-07-18 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-07-18 12:36:00+03	2017-07-18 16:35:00+03
7161	PG0663	2017-09-05 12:30:00+03	2017-09-05 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7162	PG0663	2017-08-11 12:30:00+03	2017-08-11 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-08-11 12:33:00+03	2017-08-11 16:34:00+03
7163	PG0663	2017-09-01 12:30:00+03	2017-09-01 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7164	PG0663	2017-08-15 12:30:00+03	2017-08-15 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-08-15 12:33:00+03	2017-08-15 16:31:00+03
7165	PG0663	2017-07-25 12:30:00+03	2017-07-25 16:30:00+03	SVO	KEJ	Arrived	SU9	2017-07-25 12:32:00+03	2017-07-25 16:38:00+03
7166	PG0663	2017-08-25 12:30:00+03	2017-08-25 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7167	PG0663	2017-08-29 12:30:00+03	2017-08-29 16:30:00+03	SVO	KEJ	Scheduled	SU9	\N	\N
7168	PG0128	2017-08-20 11:00:00+03	2017-08-20 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7169	PG0128	2017-09-07 11:00:00+03	2017-09-07 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7170	PG0128	2017-08-22 11:00:00+03	2017-08-22 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7171	PG0128	2017-08-25 11:00:00+03	2017-08-25 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7172	PG0128	2017-08-31 11:00:00+03	2017-08-31 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7173	PG0128	2017-08-12 11:00:00+03	2017-08-12 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-12 11:03:00+03	2017-08-12 12:53:00+03
7174	PG0128	2017-09-01 11:00:00+03	2017-09-01 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7175	PG0128	2017-09-14 11:00:00+03	2017-09-14 12:50:00+03	SVO	ASF	Cancelled	CR2	\N	\N
7176	PG0128	2017-07-26 11:00:00+03	2017-07-26 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-26 13:48:00+03	2017-07-26 15:37:00+03
7177	PG0128	2017-08-14 11:00:00+03	2017-08-14 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-14 11:03:00+03	2017-08-14 12:54:00+03
7178	PG0128	2017-07-27 11:00:00+03	2017-07-27 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-27 11:01:00+03	2017-07-27 12:51:00+03
7179	PG0128	2017-07-17 11:00:00+03	2017-07-17 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-17 11:00:00+03	2017-07-17 12:49:00+03
7180	PG0128	2017-08-11 11:00:00+03	2017-08-11 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-11 11:01:00+03	2017-08-11 12:50:00+03
7181	PG0128	2017-08-21 11:00:00+03	2017-08-21 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7182	PG0128	2017-09-09 11:00:00+03	2017-09-09 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7183	PG0128	2017-09-02 11:00:00+03	2017-09-02 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7184	PG0128	2017-08-10 11:00:00+03	2017-08-10 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-10 11:03:00+03	2017-08-10 12:53:00+03
7185	PG0128	2017-09-10 11:00:00+03	2017-09-10 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7186	PG0128	2017-07-18 11:00:00+03	2017-07-18 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-18 11:07:00+03	2017-07-18 12:55:00+03
7187	PG0128	2017-08-15 11:00:00+03	2017-08-15 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-15 11:00:00+03	2017-08-15 12:50:00+03
7188	PG0128	2017-07-28 11:00:00+03	2017-07-28 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-28 11:03:00+03	2017-07-28 12:54:00+03
7189	PG0128	2017-08-09 11:00:00+03	2017-08-09 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-09 11:03:00+03	2017-08-09 12:53:00+03
7190	PG0128	2017-08-24 11:00:00+03	2017-08-24 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7191	PG0128	2017-09-03 11:00:00+03	2017-09-03 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7192	PG0128	2017-08-08 11:00:00+03	2017-08-08 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-08 11:02:00+03	2017-08-08 12:52:00+03
7193	PG0128	2017-07-19 11:00:00+03	2017-07-19 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-19 11:02:00+03	2017-07-19 12:52:00+03
7194	PG0128	2017-07-25 11:00:00+03	2017-07-25 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-25 11:04:00+03	2017-07-25 12:53:00+03
7195	PG0128	2017-08-26 11:00:00+03	2017-08-26 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7196	PG0128	2017-08-30 11:00:00+03	2017-08-30 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7197	PG0128	2017-08-07 11:00:00+03	2017-08-07 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-07 11:05:00+03	2017-08-07 12:56:00+03
7198	PG0128	2017-08-28 11:00:00+03	2017-08-28 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7199	PG0128	2017-08-16 11:00:00+03	2017-08-16 12:50:00+03	SVO	ASF	On Time	CR2	\N	\N
7200	PG0128	2017-07-29 11:00:00+03	2017-07-29 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-29 11:02:00+03	2017-07-29 12:52:00+03
7201	PG0128	2017-09-13 11:00:00+03	2017-09-13 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7202	PG0128	2017-07-20 11:00:00+03	2017-07-20 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-20 11:03:00+03	2017-07-20 12:53:00+03
7203	PG0128	2017-09-04 11:00:00+03	2017-09-04 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7204	PG0128	2017-08-06 11:00:00+03	2017-08-06 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-06 11:04:00+03	2017-08-06 12:55:00+03
7205	PG0128	2017-09-08 11:00:00+03	2017-09-08 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7206	PG0128	2017-08-05 11:00:00+03	2017-08-05 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-05 11:02:00+03	2017-08-05 12:52:00+03
7207	PG0128	2017-08-23 11:00:00+03	2017-08-23 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7208	PG0128	2017-08-17 11:00:00+03	2017-08-17 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7209	PG0128	2017-07-21 11:00:00+03	2017-07-21 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-21 11:06:00+03	2017-07-21 12:57:00+03
7210	PG0128	2017-09-05 11:00:00+03	2017-09-05 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7211	PG0128	2017-08-04 11:00:00+03	2017-08-04 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-04 11:02:00+03	2017-08-04 12:52:00+03
7212	PG0128	2017-07-30 11:00:00+03	2017-07-30 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-30 11:02:00+03	2017-07-30 12:51:00+03
7213	PG0128	2017-09-12 11:00:00+03	2017-09-12 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7214	PG0128	2017-07-24 11:00:00+03	2017-07-24 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-24 11:02:00+03	2017-07-24 12:52:00+03
7215	PG0128	2017-08-03 11:00:00+03	2017-08-03 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-03 11:02:00+03	2017-08-03 12:52:00+03
7216	PG0128	2017-07-22 11:00:00+03	2017-07-22 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-22 11:01:00+03	2017-07-22 12:51:00+03
7217	PG0128	2017-08-27 11:00:00+03	2017-08-27 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7218	PG0128	2017-08-13 11:00:00+03	2017-08-13 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-13 11:04:00+03	2017-08-13 12:54:00+03
7219	PG0128	2017-08-29 11:00:00+03	2017-08-29 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7220	PG0128	2017-09-06 11:00:00+03	2017-09-06 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7221	PG0128	2017-08-18 11:00:00+03	2017-08-18 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7222	PG0128	2017-08-19 11:00:00+03	2017-08-19 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7223	PG0128	2017-08-02 11:00:00+03	2017-08-02 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-02 14:27:00+03	2017-08-02 16:15:00+03
7224	PG0128	2017-07-31 11:00:00+03	2017-07-31 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-31 11:01:00+03	2017-07-31 12:50:00+03
7225	PG0128	2017-09-11 11:00:00+03	2017-09-11 12:50:00+03	SVO	ASF	Scheduled	CR2	\N	\N
7226	PG0128	2017-07-16 11:00:00+03	2017-07-16 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-16 11:01:00+03	2017-07-16 12:50:00+03
7227	PG0128	2017-08-01 11:00:00+03	2017-08-01 12:50:00+03	SVO	ASF	Arrived	CR2	2017-08-01 11:02:00+03	2017-08-01 12:54:00+03
7228	PG0128	2017-07-23 11:00:00+03	2017-07-23 12:50:00+03	SVO	ASF	Arrived	CR2	2017-07-23 11:04:00+03	2017-07-23 12:54:00+03
7229	PG0513	2017-09-06 18:40:00+03	2017-09-06 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7230	PG0513	2017-08-14 18:40:00+03	2017-08-14 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-14 18:42:00+03	2017-08-14 20:38:00+03
7231	PG0513	2017-07-24 18:40:00+03	2017-07-24 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-24 18:44:00+03	2017-07-24 20:39:00+03
7232	PG0513	2017-07-19 18:40:00+03	2017-07-19 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-19 18:44:00+03	2017-07-19 20:39:00+03
7233	PG0513	2017-07-23 18:40:00+03	2017-07-23 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-23 18:42:00+03	2017-07-23 20:36:00+03
7234	PG0513	2017-07-31 18:40:00+03	2017-07-31 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-31 18:46:00+03	2017-07-31 20:40:00+03
7235	PG0513	2017-07-26 18:40:00+03	2017-07-26 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-26 18:41:00+03	2017-07-26 20:36:00+03
7236	PG0513	2017-07-21 18:40:00+03	2017-07-21 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-21 18:42:00+03	2017-07-21 20:38:00+03
7237	PG0513	2017-08-11 18:40:00+03	2017-08-11 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-11 18:43:00+03	2017-08-11 20:38:00+03
7238	PG0513	2017-09-12 18:40:00+03	2017-09-12 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7239	PG0513	2017-09-07 18:40:00+03	2017-09-07 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7240	PG0513	2017-08-10 18:40:00+03	2017-08-10 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-10 18:44:00+03	2017-08-10 20:40:00+03
7241	PG0513	2017-08-03 18:40:00+03	2017-08-03 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-03 18:42:00+03	2017-08-03 20:37:00+03
7242	PG0513	2017-07-27 18:40:00+03	2017-07-27 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-27 18:43:00+03	2017-07-27 20:40:00+03
7243	PG0513	2017-08-27 18:40:00+03	2017-08-27 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7244	PG0513	2017-07-29 18:40:00+03	2017-07-29 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-29 18:45:00+03	2017-07-29 20:41:00+03
7245	PG0513	2017-08-08 18:40:00+03	2017-08-08 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-08 18:47:00+03	2017-08-08 20:43:00+03
7246	PG0513	2017-07-18 18:40:00+03	2017-07-18 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-18 18:42:00+03	2017-07-18 20:37:00+03
7247	PG0513	2017-08-23 18:40:00+03	2017-08-23 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7248	PG0513	2017-07-28 18:40:00+03	2017-07-28 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-28 18:45:00+03	2017-07-28 20:39:00+03
7249	PG0513	2017-08-16 18:40:00+03	2017-08-16 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7250	PG0513	2017-08-22 18:40:00+03	2017-08-22 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7251	PG0513	2017-09-11 18:40:00+03	2017-09-11 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7252	PG0513	2017-08-18 18:40:00+03	2017-08-18 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7253	PG0513	2017-08-09 18:40:00+03	2017-08-09 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-09 18:42:00+03	2017-08-09 20:39:00+03
7254	PG0513	2017-09-02 18:40:00+03	2017-09-02 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7255	PG0513	2017-08-04 18:40:00+03	2017-08-04 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-04 18:45:00+03	2017-08-04 20:39:00+03
7256	PG0513	2017-08-21 18:40:00+03	2017-08-21 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7257	PG0513	2017-07-30 18:40:00+03	2017-07-30 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-30 18:43:00+03	2017-07-30 20:39:00+03
7258	PG0513	2017-08-07 18:40:00+03	2017-08-07 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-07 18:44:00+03	2017-08-07 20:39:00+03
7259	PG0513	2017-09-05 18:40:00+03	2017-09-05 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7260	PG0513	2017-08-13 18:40:00+03	2017-08-13 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-13 18:41:00+03	2017-08-13 20:37:00+03
7261	PG0513	2017-09-10 18:40:00+03	2017-09-10 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7262	PG0513	2017-09-08 18:40:00+03	2017-09-08 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7263	PG0513	2017-08-15 18:40:00+03	2017-08-15 20:35:00+03	SVO	PEZ	On Time	CN1	\N	\N
7264	PG0513	2017-09-14 18:40:00+03	2017-09-14 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7265	PG0513	2017-09-01 18:40:00+03	2017-09-01 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7266	PG0513	2017-08-02 18:40:00+03	2017-08-02 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-02 18:43:00+03	2017-08-02 20:40:00+03
7267	PG0513	2017-07-16 18:40:00+03	2017-07-16 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-16 21:30:00+03	2017-07-16 23:25:00+03
7268	PG0513	2017-08-25 18:40:00+03	2017-08-25 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7269	PG0513	2017-08-20 18:40:00+03	2017-08-20 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7270	PG0513	2017-08-26 18:40:00+03	2017-08-26 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7271	PG0513	2017-09-04 18:40:00+03	2017-09-04 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7272	PG0513	2017-07-22 18:40:00+03	2017-07-22 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-22 18:45:00+03	2017-07-22 20:40:00+03
7273	PG0513	2017-08-30 18:40:00+03	2017-08-30 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7274	PG0513	2017-08-01 18:40:00+03	2017-08-01 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-01 18:46:00+03	2017-08-01 20:42:00+03
7275	PG0513	2017-08-29 18:40:00+03	2017-08-29 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7276	PG0513	2017-09-03 18:40:00+03	2017-09-03 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7277	PG0513	2017-09-09 18:40:00+03	2017-09-09 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7278	PG0513	2017-07-20 18:40:00+03	2017-07-20 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-20 18:41:00+03	2017-07-20 20:34:00+03
7279	PG0513	2017-09-13 18:40:00+03	2017-09-13 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7280	PG0513	2017-07-25 18:40:00+03	2017-07-25 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-25 18:44:00+03	2017-07-25 20:39:00+03
7281	PG0513	2017-08-24 18:40:00+03	2017-08-24 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7282	PG0513	2017-08-06 18:40:00+03	2017-08-06 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-06 18:45:00+03	2017-08-06 20:40:00+03
7283	PG0513	2017-08-17 18:40:00+03	2017-08-17 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7284	PG0513	2017-08-31 18:40:00+03	2017-08-31 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7285	PG0513	2017-07-17 18:40:00+03	2017-07-17 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-07-17 18:46:00+03	2017-07-17 20:41:00+03
7286	PG0513	2017-08-19 18:40:00+03	2017-08-19 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7287	PG0513	2017-08-05 18:40:00+03	2017-08-05 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-05 18:43:00+03	2017-08-05 20:37:00+03
7288	PG0513	2017-08-12 18:40:00+03	2017-08-12 20:35:00+03	SVO	PEZ	Arrived	CN1	2017-08-12 18:43:00+03	2017-08-12 20:39:00+03
7289	PG0513	2017-08-28 18:40:00+03	2017-08-28 20:35:00+03	SVO	PEZ	Scheduled	CN1	\N	\N
7290	PG0637	2017-08-28 14:05:00+03	2017-08-28 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7291	PG0637	2017-07-31 14:05:00+03	2017-07-31 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-31 14:07:00+03	2017-07-31 15:07:00+03
7292	PG0637	2017-08-04 14:05:00+03	2017-08-04 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-04 14:07:00+03	2017-08-04 15:07:00+03
7293	PG0637	2017-08-06 14:05:00+03	2017-08-06 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-06 14:08:00+03	2017-08-06 15:08:00+03
7294	PG0637	2017-08-11 14:05:00+03	2017-08-11 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-11 14:11:00+03	2017-08-11 15:11:00+03
7295	PG0637	2017-07-17 14:05:00+03	2017-07-17 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-17 14:09:00+03	2017-07-17 15:10:00+03
7296	PG0637	2017-08-07 14:05:00+03	2017-08-07 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-07 14:10:00+03	2017-08-07 15:09:00+03
7297	PG0637	2017-07-27 14:05:00+03	2017-07-27 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-27 17:28:00+03	2017-07-27 18:28:00+03
7298	PG0637	2017-08-23 14:05:00+03	2017-08-23 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7299	PG0637	2017-08-14 14:05:00+03	2017-08-14 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-14 14:08:00+03	2017-08-14 15:08:00+03
7300	PG0637	2017-09-01 14:05:00+03	2017-09-01 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7301	PG0637	2017-08-24 14:05:00+03	2017-08-24 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7302	PG0637	2017-08-09 14:05:00+03	2017-08-09 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-09 14:06:00+03	2017-08-09 15:06:00+03
7303	PG0637	2017-09-07 14:05:00+03	2017-09-07 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7304	PG0637	2017-09-09 14:05:00+03	2017-09-09 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7305	PG0637	2017-08-01 14:05:00+03	2017-08-01 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-01 14:07:00+03	2017-08-01 15:07:00+03
7306	PG0637	2017-08-18 14:05:00+03	2017-08-18 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7307	PG0637	2017-08-29 14:05:00+03	2017-08-29 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7308	PG0637	2017-07-20 14:05:00+03	2017-07-20 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-20 14:11:00+03	2017-07-20 15:11:00+03
7309	PG0637	2017-07-18 14:05:00+03	2017-07-18 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-18 14:08:00+03	2017-07-18 15:08:00+03
7310	PG0637	2017-08-05 14:05:00+03	2017-08-05 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-05 14:06:00+03	2017-08-05 15:06:00+03
7311	PG0637	2017-07-29 14:05:00+03	2017-07-29 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-29 14:08:00+03	2017-07-29 15:08:00+03
7312	PG0637	2017-08-02 14:05:00+03	2017-08-02 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-02 14:07:00+03	2017-08-02 15:06:00+03
7313	PG0637	2017-09-02 14:05:00+03	2017-09-02 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7314	PG0637	2017-09-05 14:05:00+03	2017-09-05 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7315	PG0637	2017-08-19 14:05:00+03	2017-08-19 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7316	PG0637	2017-07-19 14:05:00+03	2017-07-19 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-19 14:07:00+03	2017-07-19 15:07:00+03
7317	PG0637	2017-08-08 14:05:00+03	2017-08-08 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-08 14:07:00+03	2017-08-08 15:07:00+03
7318	PG0637	2017-08-22 14:05:00+03	2017-08-22 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7319	PG0637	2017-09-11 14:05:00+03	2017-09-11 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7320	PG0637	2017-08-25 14:05:00+03	2017-08-25 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7321	PG0637	2017-09-14 14:05:00+03	2017-09-14 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7322	PG0637	2017-09-13 14:05:00+03	2017-09-13 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7323	PG0637	2017-07-21 14:05:00+03	2017-07-21 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-21 14:07:00+03	2017-07-21 15:07:00+03
7324	PG0637	2017-08-17 14:05:00+03	2017-08-17 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7325	PG0637	2017-08-21 14:05:00+03	2017-08-21 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7326	PG0637	2017-07-24 14:05:00+03	2017-07-24 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-24 14:07:00+03	2017-07-24 15:08:00+03
7327	PG0637	2017-08-03 14:05:00+03	2017-08-03 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-03 14:09:00+03	2017-08-03 15:08:00+03
7328	PG0637	2017-09-12 14:05:00+03	2017-09-12 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7329	PG0637	2017-08-26 14:05:00+03	2017-08-26 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7330	PG0637	2017-08-30 14:05:00+03	2017-08-30 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7331	PG0637	2017-07-30 14:05:00+03	2017-07-30 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-30 17:01:00+03	2017-07-30 18:01:00+03
7332	PG0637	2017-08-12 14:05:00+03	2017-08-12 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-12 14:09:00+03	2017-08-12 15:08:00+03
7333	PG0637	2017-07-28 14:05:00+03	2017-07-28 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-28 17:32:00+03	2017-07-28 18:32:00+03
7334	PG0637	2017-08-27 14:05:00+03	2017-08-27 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7335	PG0637	2017-08-15 14:05:00+03	2017-08-15 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-15 14:07:00+03	2017-08-15 15:08:00+03
7336	PG0637	2017-09-03 14:05:00+03	2017-09-03 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7337	PG0637	2017-08-10 14:05:00+03	2017-08-10 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-10 14:09:00+03	2017-08-10 15:08:00+03
7338	PG0637	2017-08-16 14:05:00+03	2017-08-16 15:05:00+03	SVO	KVX	On Time	SU9	\N	\N
7339	PG0637	2017-07-25 14:05:00+03	2017-07-25 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-25 14:07:00+03	2017-07-25 15:07:00+03
7340	PG0637	2017-09-08 14:05:00+03	2017-09-08 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7341	PG0637	2017-09-06 14:05:00+03	2017-09-06 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7342	PG0637	2017-07-23 14:05:00+03	2017-07-23 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-23 14:06:00+03	2017-07-23 15:06:00+03
7343	PG0637	2017-09-10 14:05:00+03	2017-09-10 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7344	PG0637	2017-08-31 14:05:00+03	2017-08-31 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7345	PG0637	2017-09-04 14:05:00+03	2017-09-04 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7346	PG0637	2017-07-22 14:05:00+03	2017-07-22 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-22 14:08:00+03	2017-07-22 15:08:00+03
7347	PG0637	2017-08-20 14:05:00+03	2017-08-20 15:05:00+03	SVO	KVX	Scheduled	SU9	\N	\N
7348	PG0637	2017-07-26 14:05:00+03	2017-07-26 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-26 14:07:00+03	2017-07-26 15:07:00+03
7349	PG0637	2017-08-13 14:05:00+03	2017-08-13 15:05:00+03	SVO	KVX	Arrived	SU9	2017-08-13 14:07:00+03	2017-08-13 15:07:00+03
7350	PG0637	2017-07-16 14:05:00+03	2017-07-16 15:05:00+03	SVO	KVX	Arrived	SU9	2017-07-16 17:29:00+03	2017-07-16 18:29:00+03
7351	PG0241	2017-08-11 09:40:00+03	2017-08-11 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-11 09:43:00+03	2017-08-11 10:34:00+03
7352	PG0241	2017-07-24 09:40:00+03	2017-07-24 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-24 09:42:00+03	2017-07-24 10:32:00+03
7353	PG0241	2017-09-04 09:40:00+03	2017-09-04 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7354	PG0241	2017-07-19 09:40:00+03	2017-07-19 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-19 09:42:00+03	2017-07-19 10:32:00+03
7355	PG0241	2017-09-05 09:40:00+03	2017-09-05 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7356	PG0241	2017-08-21 09:40:00+03	2017-08-21 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7357	PG0241	2017-07-25 09:40:00+03	2017-07-25 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-25 09:42:00+03	2017-07-25 10:32:00+03
7358	PG0241	2017-08-14 09:40:00+03	2017-08-14 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-14 09:43:00+03	2017-08-14 10:33:00+03
7359	PG0241	2017-08-23 09:40:00+03	2017-08-23 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7360	PG0241	2017-08-19 09:40:00+03	2017-08-19 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7361	PG0241	2017-09-02 09:40:00+03	2017-09-02 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7362	PG0241	2017-07-28 09:40:00+03	2017-07-28 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-28 09:42:00+03	2017-07-28 10:31:00+03
7363	PG0241	2017-08-08 09:40:00+03	2017-08-08 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-08 09:43:00+03	2017-08-08 10:32:00+03
7364	PG0241	2017-07-16 09:40:00+03	2017-07-16 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-16 09:43:00+03	2017-07-16 10:33:00+03
7365	PG0241	2017-09-03 09:40:00+03	2017-09-03 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7366	PG0241	2017-08-09 09:40:00+03	2017-08-09 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-09 09:42:00+03	2017-08-09 10:33:00+03
7367	PG0241	2017-08-18 09:40:00+03	2017-08-18 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7368	PG0241	2017-08-12 09:40:00+03	2017-08-12 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-12 09:40:00+03	2017-08-12 10:30:00+03
7369	PG0241	2017-08-27 09:40:00+03	2017-08-27 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7370	PG0241	2017-08-24 09:40:00+03	2017-08-24 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7371	PG0241	2017-07-17 09:40:00+03	2017-07-17 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-17 09:41:00+03	2017-07-17 10:31:00+03
7372	PG0241	2017-07-30 09:40:00+03	2017-07-30 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-30 09:41:00+03	2017-07-30 10:31:00+03
7373	PG0241	2017-09-14 09:40:00+03	2017-09-14 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7374	PG0241	2017-09-08 09:40:00+03	2017-09-08 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7375	PG0241	2017-08-29 09:40:00+03	2017-08-29 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7376	PG0241	2017-09-06 09:40:00+03	2017-09-06 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7377	PG0241	2017-07-18 09:40:00+03	2017-07-18 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-18 09:42:00+03	2017-07-18 10:32:00+03
7378	PG0241	2017-09-11 09:40:00+03	2017-09-11 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7379	PG0241	2017-08-06 09:40:00+03	2017-08-06 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-06 09:41:00+03	2017-08-06 10:30:00+03
7380	PG0241	2017-09-07 09:40:00+03	2017-09-07 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7381	PG0241	2017-08-20 09:40:00+03	2017-08-20 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7382	PG0241	2017-07-22 09:40:00+03	2017-07-22 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-22 09:42:00+03	2017-07-22 10:32:00+03
7383	PG0241	2017-08-01 09:40:00+03	2017-08-01 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-01 09:41:00+03	2017-08-01 10:31:00+03
7384	PG0241	2017-09-13 09:40:00+03	2017-09-13 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7385	PG0241	2017-07-27 09:40:00+03	2017-07-27 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-27 09:43:00+03	2017-07-27 10:32:00+03
7386	PG0241	2017-08-04 09:40:00+03	2017-08-04 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-04 09:41:00+03	2017-08-04 10:32:00+03
7387	PG0241	2017-08-30 09:40:00+03	2017-08-30 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7388	PG0241	2017-07-20 09:40:00+03	2017-07-20 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-20 09:43:00+03	2017-07-20 10:33:00+03
7389	PG0241	2017-08-22 09:40:00+03	2017-08-22 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7390	PG0241	2017-08-13 09:40:00+03	2017-08-13 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-13 09:44:00+03	2017-08-13 10:34:00+03
7391	PG0241	2017-09-12 09:40:00+03	2017-09-12 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7392	PG0241	2017-08-10 09:40:00+03	2017-08-10 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-10 09:40:00+03	2017-08-10 10:29:00+03
7393	PG0241	2017-08-26 09:40:00+03	2017-08-26 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7394	PG0241	2017-08-17 09:40:00+03	2017-08-17 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7395	PG0241	2017-07-29 09:40:00+03	2017-07-29 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-29 09:42:00+03	2017-07-29 10:32:00+03
7396	PG0241	2017-08-05 09:40:00+03	2017-08-05 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-05 09:45:00+03	2017-08-05 10:35:00+03
7397	PG0241	2017-08-15 09:40:00+03	2017-08-15 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-15 09:42:00+03	2017-08-15 10:32:00+03
7398	PG0241	2017-07-23 09:40:00+03	2017-07-23 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-23 12:35:00+03	2017-07-23 13:25:00+03
7399	PG0241	2017-08-25 09:40:00+03	2017-08-25 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7400	PG0241	2017-07-21 09:40:00+03	2017-07-21 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-21 09:43:00+03	2017-07-21 10:32:00+03
7401	PG0241	2017-07-31 09:40:00+03	2017-07-31 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-31 09:45:00+03	2017-07-31 10:35:00+03
7402	PG0241	2017-08-02 09:40:00+03	2017-08-02 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-02 09:42:00+03	2017-08-02 10:32:00+03
7403	PG0241	2017-08-31 09:40:00+03	2017-08-31 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7404	PG0241	2017-08-03 09:40:00+03	2017-08-03 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-03 09:41:00+03	2017-08-03 10:31:00+03
7405	PG0241	2017-07-26 09:40:00+03	2017-07-26 10:30:00+03	SVO	CSY	Arrived	SU9	2017-07-26 09:46:00+03	2017-07-26 10:36:00+03
7406	PG0241	2017-09-01 09:40:00+03	2017-09-01 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7407	PG0241	2017-09-09 09:40:00+03	2017-09-09 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7408	PG0241	2017-09-10 09:40:00+03	2017-09-10 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7409	PG0241	2017-08-07 09:40:00+03	2017-08-07 10:30:00+03	SVO	CSY	Arrived	SU9	2017-08-07 09:42:00+03	2017-08-07 10:32:00+03
7410	PG0241	2017-08-28 09:40:00+03	2017-08-28 10:30:00+03	SVO	CSY	Scheduled	SU9	\N	\N
7411	PG0241	2017-08-16 09:40:00+03	2017-08-16 10:30:00+03	SVO	CSY	On Time	SU9	\N	\N
7412	PG0505	2017-09-10 11:40:00+03	2017-09-10 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7413	PG0505	2017-09-13 11:40:00+03	2017-09-13 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7414	PG0505	2017-08-22 11:40:00+03	2017-08-22 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7415	PG0505	2017-08-17 11:40:00+03	2017-08-17 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7416	PG0505	2017-09-08 11:40:00+03	2017-09-08 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7417	PG0505	2017-09-03 11:40:00+03	2017-09-03 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7418	PG0505	2017-08-04 11:40:00+03	2017-08-04 13:10:00+03	SVO	KGD	Arrived	733	2017-08-04 11:42:00+03	2017-08-04 13:12:00+03
7419	PG0505	2017-08-11 11:40:00+03	2017-08-11 13:10:00+03	SVO	KGD	Arrived	733	2017-08-11 11:44:00+03	2017-08-11 13:14:00+03
7420	PG0505	2017-07-26 11:40:00+03	2017-07-26 13:10:00+03	SVO	KGD	Arrived	733	2017-07-26 11:43:00+03	2017-07-26 13:14:00+03
7421	PG0505	2017-08-24 11:40:00+03	2017-08-24 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7422	PG0505	2017-07-18 11:40:00+03	2017-07-18 13:10:00+03	SVO	KGD	Arrived	733	2017-07-18 11:43:00+03	2017-07-18 13:13:00+03
7423	PG0505	2017-08-05 11:40:00+03	2017-08-05 13:10:00+03	SVO	KGD	Arrived	733	2017-08-05 11:44:00+03	2017-08-05 13:15:00+03
7424	PG0505	2017-08-21 11:40:00+03	2017-08-21 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7425	PG0505	2017-08-10 11:40:00+03	2017-08-10 13:10:00+03	SVO	KGD	Arrived	733	2017-08-10 11:46:00+03	2017-08-10 13:15:00+03
7426	PG0505	2017-08-30 11:40:00+03	2017-08-30 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7427	PG0505	2017-08-08 11:40:00+03	2017-08-08 13:10:00+03	SVO	KGD	Arrived	733	2017-08-08 11:43:00+03	2017-08-08 13:13:00+03
7428	PG0505	2017-07-31 11:40:00+03	2017-07-31 13:10:00+03	SVO	KGD	Arrived	733	2017-07-31 11:45:00+03	2017-07-31 13:15:00+03
7429	PG0505	2017-08-23 11:40:00+03	2017-08-23 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7430	PG0505	2017-07-30 11:40:00+03	2017-07-30 13:10:00+03	SVO	KGD	Arrived	733	2017-07-30 15:07:00+03	2017-07-30 16:35:00+03
7431	PG0505	2017-07-17 11:40:00+03	2017-07-17 13:10:00+03	SVO	KGD	Arrived	733	2017-07-17 11:43:00+03	2017-07-17 13:13:00+03
7432	PG0505	2017-08-31 11:40:00+03	2017-08-31 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7433	PG0505	2017-09-02 11:40:00+03	2017-09-02 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7434	PG0505	2017-08-18 11:40:00+03	2017-08-18 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7435	PG0505	2017-08-09 11:40:00+03	2017-08-09 13:10:00+03	SVO	KGD	Arrived	733	2017-08-09 11:43:00+03	2017-08-09 13:15:00+03
7436	PG0505	2017-07-23 11:40:00+03	2017-07-23 13:10:00+03	SVO	KGD	Arrived	733	2017-07-23 11:42:00+03	2017-07-23 13:12:00+03
7437	PG0505	2017-08-14 11:40:00+03	2017-08-14 13:10:00+03	SVO	KGD	Arrived	733	2017-08-14 14:32:00+03	2017-08-14 16:02:00+03
7438	PG0505	2017-08-06 11:40:00+03	2017-08-06 13:10:00+03	SVO	KGD	Arrived	733	2017-08-06 11:43:00+03	2017-08-06 13:13:00+03
7439	PG0505	2017-08-02 11:40:00+03	2017-08-02 13:10:00+03	SVO	KGD	Arrived	733	2017-08-02 11:40:00+03	2017-08-02 13:08:00+03
7440	PG0505	2017-08-13 11:40:00+03	2017-08-13 13:10:00+03	SVO	KGD	Arrived	733	2017-08-13 11:42:00+03	2017-08-13 13:13:00+03
7441	PG0505	2017-08-25 11:40:00+03	2017-08-25 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7442	PG0505	2017-09-01 11:40:00+03	2017-09-01 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7443	PG0505	2017-08-16 11:40:00+03	2017-08-16 13:10:00+03	SVO	KGD	On Time	733	\N	\N
7444	PG0505	2017-08-27 11:40:00+03	2017-08-27 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7445	PG0505	2017-08-12 11:40:00+03	2017-08-12 13:10:00+03	SVO	KGD	Arrived	733	2017-08-12 11:44:00+03	2017-08-12 13:14:00+03
7446	PG0505	2017-08-03 11:40:00+03	2017-08-03 13:10:00+03	SVO	KGD	Arrived	733	2017-08-03 11:43:00+03	2017-08-03 13:13:00+03
7447	PG0505	2017-08-07 11:40:00+03	2017-08-07 13:10:00+03	SVO	KGD	Arrived	733	2017-08-07 11:41:00+03	2017-08-07 13:12:00+03
7448	PG0505	2017-08-20 11:40:00+03	2017-08-20 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7449	PG0505	2017-08-01 11:40:00+03	2017-08-01 13:10:00+03	SVO	KGD	Arrived	733	2017-08-01 15:20:00+03	2017-08-01 16:51:00+03
7450	PG0505	2017-07-29 11:40:00+03	2017-07-29 13:10:00+03	SVO	KGD	Arrived	733	2017-07-29 11:45:00+03	2017-07-29 13:15:00+03
7451	PG0505	2017-07-21 11:40:00+03	2017-07-21 13:10:00+03	SVO	KGD	Arrived	733	2017-07-21 11:41:00+03	2017-07-21 13:10:00+03
7452	PG0505	2017-08-26 11:40:00+03	2017-08-26 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7453	PG0505	2017-09-09 11:40:00+03	2017-09-09 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7454	PG0505	2017-08-19 11:40:00+03	2017-08-19 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7455	PG0505	2017-08-29 11:40:00+03	2017-08-29 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7456	PG0505	2017-07-16 11:40:00+03	2017-07-16 13:10:00+03	SVO	KGD	Arrived	733	2017-07-16 11:42:00+03	2017-07-16 13:13:00+03
7457	PG0505	2017-09-05 11:40:00+03	2017-09-05 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7458	PG0505	2017-07-24 11:40:00+03	2017-07-24 13:10:00+03	SVO	KGD	Arrived	733	2017-07-24 11:42:00+03	2017-07-24 13:12:00+03
7459	PG0505	2017-09-12 11:40:00+03	2017-09-12 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7460	PG0505	2017-07-28 11:40:00+03	2017-07-28 13:10:00+03	SVO	KGD	Arrived	733	2017-07-28 11:42:00+03	2017-07-28 13:12:00+03
7461	PG0505	2017-07-20 11:40:00+03	2017-07-20 13:10:00+03	SVO	KGD	Arrived	733	2017-07-20 11:44:00+03	2017-07-20 13:15:00+03
7462	PG0505	2017-08-15 11:40:00+03	2017-08-15 13:10:00+03	SVO	KGD	Arrived	733	2017-08-15 11:41:00+03	2017-08-15 13:11:00+03
7463	PG0505	2017-09-04 11:40:00+03	2017-09-04 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7464	PG0505	2017-07-22 11:40:00+03	2017-07-22 13:10:00+03	SVO	KGD	Arrived	733	2017-07-22 11:41:00+03	2017-07-22 13:10:00+03
7465	PG0505	2017-07-19 11:40:00+03	2017-07-19 13:10:00+03	SVO	KGD	Arrived	733	2017-07-19 11:42:00+03	2017-07-19 13:13:00+03
7466	PG0505	2017-09-14 11:40:00+03	2017-09-14 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7467	PG0505	2017-09-11 11:40:00+03	2017-09-11 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7468	PG0505	2017-07-25 11:40:00+03	2017-07-25 13:10:00+03	SVO	KGD	Arrived	733	2017-07-25 11:42:00+03	2017-07-25 13:12:00+03
7469	PG0505	2017-07-27 11:40:00+03	2017-07-27 13:10:00+03	SVO	KGD	Arrived	733	2017-07-27 15:07:00+03	2017-07-27 16:37:00+03
7470	PG0505	2017-09-06 11:40:00+03	2017-09-06 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7471	PG0505	2017-09-07 11:40:00+03	2017-09-07 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7472	PG0505	2017-08-28 11:40:00+03	2017-08-28 13:10:00+03	SVO	KGD	Scheduled	733	\N	\N
7473	PG0066	2017-09-04 12:15:00+03	2017-09-04 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7474	PG0066	2017-09-03 12:15:00+03	2017-09-03 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7475	PG0066	2017-07-31 12:15:00+03	2017-07-31 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-31 12:19:00+03	2017-07-31 14:05:00+03
7476	PG0066	2017-08-25 12:15:00+03	2017-08-25 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7477	PG0066	2017-07-16 12:15:00+03	2017-07-16 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-16 12:16:00+03	2017-07-16 14:01:00+03
7478	PG0066	2017-07-19 12:15:00+03	2017-07-19 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-19 12:18:00+03	2017-07-19 14:03:00+03
7479	PG0066	2017-08-07 12:15:00+03	2017-08-07 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-07 12:20:00+03	2017-08-07 14:05:00+03
7480	PG0066	2017-08-22 12:15:00+03	2017-08-22 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7481	PG0066	2017-08-04 12:15:00+03	2017-08-04 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-04 12:20:00+03	2017-08-04 14:05:00+03
7482	PG0066	2017-07-28 12:15:00+03	2017-07-28 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-28 12:21:00+03	2017-07-28 14:06:00+03
7483	PG0066	2017-08-11 12:15:00+03	2017-08-11 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-11 12:17:00+03	2017-08-11 14:01:00+03
7484	PG0066	2017-08-10 12:15:00+03	2017-08-10 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-10 12:16:00+03	2017-08-10 14:01:00+03
7485	PG0066	2017-07-25 12:15:00+03	2017-07-25 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-25 12:17:00+03	2017-07-25 14:02:00+03
7486	PG0066	2017-09-08 12:15:00+03	2017-09-08 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7487	PG0066	2017-08-09 12:15:00+03	2017-08-09 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-09 12:20:00+03	2017-08-09 14:04:00+03
7488	PG0066	2017-08-05 12:15:00+03	2017-08-05 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-05 12:15:00+03	2017-08-05 14:00:00+03
7489	PG0066	2017-08-08 12:15:00+03	2017-08-08 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-08 12:22:00+03	2017-08-08 14:08:00+03
7490	PG0066	2017-08-01 12:15:00+03	2017-08-01 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-01 12:16:00+03	2017-08-01 14:02:00+03
7491	PG0066	2017-07-30 12:15:00+03	2017-07-30 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-30 12:16:00+03	2017-07-30 14:02:00+03
7492	PG0066	2017-09-12 12:15:00+03	2017-09-12 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7493	PG0066	2017-08-17 12:15:00+03	2017-08-17 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7494	PG0066	2017-08-14 12:15:00+03	2017-08-14 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-14 12:17:00+03	2017-08-14 14:03:00+03
7495	PG0066	2017-09-10 12:15:00+03	2017-09-10 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7496	PG0066	2017-09-06 12:15:00+03	2017-09-06 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7497	PG0066	2017-09-05 12:15:00+03	2017-09-05 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7498	PG0066	2017-08-29 12:15:00+03	2017-08-29 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7499	PG0066	2017-08-30 12:15:00+03	2017-08-30 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7500	PG0066	2017-08-26 12:15:00+03	2017-08-26 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7501	PG0066	2017-07-22 12:15:00+03	2017-07-22 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-22 12:15:00+03	2017-07-22 13:59:00+03
7502	PG0066	2017-08-21 12:15:00+03	2017-08-21 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7503	PG0066	2017-08-23 12:15:00+03	2017-08-23 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7504	PG0066	2017-07-29 12:15:00+03	2017-07-29 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-29 12:20:00+03	2017-07-29 14:04:00+03
7505	PG0066	2017-07-27 12:15:00+03	2017-07-27 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-27 12:17:00+03	2017-07-27 14:02:00+03
7506	PG0066	2017-09-09 12:15:00+03	2017-09-09 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7507	PG0066	2017-07-17 12:15:00+03	2017-07-17 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-17 12:19:00+03	2017-07-17 14:05:00+03
7508	PG0066	2017-08-20 12:15:00+03	2017-08-20 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7509	PG0066	2017-08-06 12:15:00+03	2017-08-06 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-06 12:18:00+03	2017-08-06 14:02:00+03
7510	PG0066	2017-09-02 12:15:00+03	2017-09-02 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7511	PG0066	2017-08-18 12:15:00+03	2017-08-18 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7512	PG0066	2017-09-07 12:15:00+03	2017-09-07 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7513	PG0066	2017-08-16 12:15:00+03	2017-08-16 14:00:00+03	SVO	STW	On Time	CR2	\N	\N
7514	PG0066	2017-07-23 12:15:00+03	2017-07-23 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-23 12:18:00+03	2017-07-23 14:04:00+03
7515	PG0066	2017-08-31 12:15:00+03	2017-08-31 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7516	PG0066	2017-08-15 12:15:00+03	2017-08-15 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-15 12:19:00+03	2017-08-15 14:04:00+03
7517	PG0066	2017-08-24 12:15:00+03	2017-08-24 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7518	PG0066	2017-07-24 12:15:00+03	2017-07-24 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-24 12:20:00+03	2017-07-24 14:03:00+03
7519	PG0066	2017-08-02 12:15:00+03	2017-08-02 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-02 12:19:00+03	2017-08-02 14:06:00+03
7520	PG0066	2017-07-26 12:15:00+03	2017-07-26 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-26 12:19:00+03	2017-07-26 14:02:00+03
7521	PG0066	2017-07-21 12:15:00+03	2017-07-21 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-21 12:19:00+03	2017-07-21 14:04:00+03
7522	PG0066	2017-09-14 12:15:00+03	2017-09-14 14:00:00+03	SVO	STW	Cancelled	CR2	\N	\N
7523	PG0066	2017-07-20 12:15:00+03	2017-07-20 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-20 12:21:00+03	2017-07-20 14:04:00+03
7524	PG0066	2017-08-27 12:15:00+03	2017-08-27 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7525	PG0066	2017-08-12 12:15:00+03	2017-08-12 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-12 12:21:00+03	2017-08-12 14:05:00+03
7526	PG0066	2017-08-03 12:15:00+03	2017-08-03 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-03 12:16:00+03	2017-08-03 14:01:00+03
7527	PG0066	2017-09-01 12:15:00+03	2017-09-01 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7528	PG0066	2017-09-11 12:15:00+03	2017-09-11 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7529	PG0066	2017-08-28 12:15:00+03	2017-08-28 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7530	PG0066	2017-07-18 12:15:00+03	2017-07-18 14:00:00+03	SVO	STW	Arrived	CR2	2017-07-18 12:18:00+03	2017-07-18 14:02:00+03
7531	PG0066	2017-08-19 12:15:00+03	2017-08-19 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7532	PG0066	2017-09-13 12:15:00+03	2017-09-13 14:00:00+03	SVO	STW	Scheduled	CR2	\N	\N
7533	PG0066	2017-08-13 12:15:00+03	2017-08-13 14:00:00+03	SVO	STW	Arrived	CR2	2017-08-13 12:17:00+03	2017-08-13 14:03:00+03
7534	PG0159	2017-07-24 10:40:00+03	2017-07-24 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-24 10:40:00+03	2017-07-24 11:10:00+03
7535	PG0158	2017-08-10 19:30:00+03	2017-08-10 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-10 19:31:00+03	2017-08-10 20:01:00+03
7536	PG0158	2017-07-24 19:30:00+03	2017-07-24 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-24 19:34:00+03	2017-07-24 20:04:00+03
7537	PG0159	2017-08-27 10:40:00+03	2017-08-27 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7538	PG0158	2017-08-27 19:30:00+03	2017-08-27 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7539	PG0160	2017-07-29 11:25:00+03	2017-07-29 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-29 11:26:00+03	2017-07-29 11:56:00+03
7540	PG0160	2017-09-12 11:25:00+03	2017-09-12 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7541	PG0159	2017-09-12 10:40:00+03	2017-09-12 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7542	PG0158	2017-09-12 19:30:00+03	2017-09-12 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7543	PG0160	2017-09-02 11:25:00+03	2017-09-02 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7544	PG0159	2017-09-02 10:40:00+03	2017-09-02 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7545	PG0158	2017-09-02 19:30:00+03	2017-09-02 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7546	PG0159	2017-07-29 10:40:00+03	2017-07-29 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-29 10:42:00+03	2017-07-29 11:12:00+03
7547	PG0158	2017-09-04 19:30:00+03	2017-09-04 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7548	PG0159	2017-09-04 10:40:00+03	2017-09-04 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7549	PG0158	2017-07-29 19:30:00+03	2017-07-29 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-29 19:31:00+03	2017-07-29 20:01:00+03
7550	PG0160	2017-09-04 11:25:00+03	2017-09-04 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7551	PG0160	2017-09-08 11:25:00+03	2017-09-08 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7552	PG0159	2017-09-08 10:40:00+03	2017-09-08 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7553	PG0158	2017-09-08 19:30:00+03	2017-09-08 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7554	PG0159	2017-08-28 10:40:00+03	2017-08-28 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7555	PG0158	2017-09-13 19:30:00+03	2017-09-13 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7556	PG0160	2017-08-22 11:25:00+03	2017-08-22 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7557	PG0159	2017-08-22 10:40:00+03	2017-08-22 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7558	PG0159	2017-09-13 10:40:00+03	2017-09-13 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7559	PG0160	2017-09-13 11:25:00+03	2017-09-13 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7560	PG0158	2017-08-28 19:30:00+03	2017-08-28 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7561	PG0158	2017-08-22 19:30:00+03	2017-08-22 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7562	PG0160	2017-08-16 11:25:00+03	2017-08-16 11:55:00+03	SVO	BZK	On Time	SU9	\N	\N
7563	PG0159	2017-08-16 10:40:00+03	2017-08-16 11:10:00+03	SVO	BZK	On Time	SU9	\N	\N
7564	PG0158	2017-08-16 19:30:00+03	2017-08-16 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7565	PG0158	2017-09-07 19:30:00+03	2017-09-07 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7566	PG0159	2017-09-07 10:40:00+03	2017-09-07 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7567	PG0160	2017-09-07 11:25:00+03	2017-09-07 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7568	PG0158	2017-08-01 19:30:00+03	2017-08-01 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-01 19:30:00+03	2017-08-01 20:00:00+03
7569	PG0159	2017-08-01 10:40:00+03	2017-08-01 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-01 10:40:00+03	2017-08-01 11:10:00+03
7570	PG0160	2017-08-01 11:25:00+03	2017-08-01 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-01 11:27:00+03	2017-08-01 11:56:00+03
7571	PG0158	2017-07-16 19:30:00+03	2017-07-16 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-16 19:33:00+03	2017-07-16 20:03:00+03
7572	PG0159	2017-07-16 10:40:00+03	2017-07-16 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-16 10:46:00+03	2017-07-16 11:15:00+03
7573	PG0160	2017-07-16 11:25:00+03	2017-07-16 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-16 11:30:00+03	2017-07-16 12:01:00+03
7574	PG0158	2017-08-07 19:30:00+03	2017-08-07 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-07 19:31:00+03	2017-08-07 20:01:00+03
7575	PG0159	2017-08-07 10:40:00+03	2017-08-07 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-07 10:41:00+03	2017-08-07 11:11:00+03
7576	PG0160	2017-08-07 11:25:00+03	2017-08-07 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-07 11:31:00+03	2017-08-07 12:01:00+03
7577	PG0160	2017-07-31 11:25:00+03	2017-07-31 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-31 11:29:00+03	2017-07-31 12:00:00+03
7578	PG0159	2017-07-31 10:40:00+03	2017-07-31 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-31 10:41:00+03	2017-07-31 11:11:00+03
7579	PG0160	2017-08-13 11:25:00+03	2017-08-13 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-13 11:29:00+03	2017-08-13 12:00:00+03
7580	PG0159	2017-08-13 10:40:00+03	2017-08-13 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-13 10:41:00+03	2017-08-13 11:12:00+03
7581	PG0158	2017-07-31 19:30:00+03	2017-07-31 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-31 19:32:00+03	2017-07-31 20:02:00+03
7582	PG0158	2017-08-13 19:30:00+03	2017-08-13 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-13 19:32:00+03	2017-08-13 20:02:00+03
7583	PG0160	2017-08-26 11:25:00+03	2017-08-26 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7584	PG0159	2017-08-26 10:40:00+03	2017-08-26 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7585	PG0158	2017-08-26 19:30:00+03	2017-08-26 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7586	PG0159	2017-07-23 10:40:00+03	2017-07-23 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-23 10:42:00+03	2017-07-23 11:12:00+03
7587	PG0158	2017-08-30 19:30:00+03	2017-08-30 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7588	PG0159	2017-08-30 10:40:00+03	2017-08-30 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7589	PG0160	2017-08-30 11:25:00+03	2017-08-30 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7590	PG0160	2017-08-25 11:25:00+03	2017-08-25 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7591	PG0160	2017-08-31 11:25:00+03	2017-08-31 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7592	PG0159	2017-08-31 10:40:00+03	2017-08-31 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7593	PG0158	2017-08-31 19:30:00+03	2017-08-31 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7594	PG0160	2017-08-06 11:25:00+03	2017-08-06 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-06 11:27:00+03	2017-08-06 11:57:00+03
7595	PG0159	2017-08-06 10:40:00+03	2017-08-06 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-06 10:41:00+03	2017-08-06 11:11:00+03
7596	PG0158	2017-08-06 19:30:00+03	2017-08-06 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-06 19:33:00+03	2017-08-06 20:02:00+03
7597	PG0160	2017-07-19 11:25:00+03	2017-07-19 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-19 11:28:00+03	2017-07-19 11:58:00+03
7598	PG0159	2017-07-19 10:40:00+03	2017-07-19 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-19 10:44:00+03	2017-07-19 11:14:00+03
7599	PG0158	2017-07-19 19:30:00+03	2017-07-19 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-19 19:35:00+03	2017-07-19 20:05:00+03
7600	PG0160	2017-08-12 11:25:00+03	2017-08-12 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-12 11:32:00+03	2017-08-12 12:02:00+03
7601	PG0159	2017-08-12 10:40:00+03	2017-08-12 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-12 10:44:00+03	2017-08-12 11:14:00+03
7602	PG0158	2017-08-12 19:30:00+03	2017-08-12 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-12 19:37:00+03	2017-08-12 20:07:00+03
7603	PG0160	2017-09-14 11:25:00+03	2017-09-14 11:55:00+03	SVO	BZK	Cancelled	SU9	\N	\N
7604	PG0159	2017-08-25 10:40:00+03	2017-08-25 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7605	PG0158	2017-08-25 19:30:00+03	2017-08-25 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7606	PG0160	2017-08-05 11:25:00+03	2017-08-05 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-05 11:29:00+03	2017-08-05 11:59:00+03
7607	PG0159	2017-08-05 10:40:00+03	2017-08-05 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-05 10:43:00+03	2017-08-05 11:13:00+03
7608	PG0158	2017-08-05 19:30:00+03	2017-08-05 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-05 19:32:00+03	2017-08-05 20:01:00+03
7609	PG0160	2017-07-26 11:25:00+03	2017-07-26 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-26 11:29:00+03	2017-07-26 11:59:00+03
7610	PG0159	2017-07-26 10:40:00+03	2017-07-26 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-26 10:45:00+03	2017-07-26 11:15:00+03
7611	PG0158	2017-07-25 19:30:00+03	2017-07-25 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-25 19:32:00+03	2017-07-25 20:02:00+03
7612	PG0159	2017-07-25 10:40:00+03	2017-07-25 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-25 10:44:00+03	2017-07-25 11:14:00+03
7613	PG0158	2017-07-26 19:30:00+03	2017-07-26 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-26 19:33:00+03	2017-07-26 20:03:00+03
7614	PG0160	2017-09-03 11:25:00+03	2017-09-03 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7615	PG0160	2017-07-25 11:25:00+03	2017-07-25 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-25 11:30:00+03	2017-07-25 12:00:00+03
7616	PG0159	2017-09-03 10:40:00+03	2017-09-03 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7617	PG0158	2017-09-03 19:30:00+03	2017-09-03 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7618	PG0158	2017-09-01 19:30:00+03	2017-09-01 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7619	PG0159	2017-09-01 10:40:00+03	2017-09-01 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7620	PG0160	2017-09-01 11:25:00+03	2017-09-01 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7621	PG0160	2017-08-18 11:25:00+03	2017-08-18 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7622	PG0159	2017-08-18 10:40:00+03	2017-08-18 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7623	PG0158	2017-08-18 19:30:00+03	2017-08-18 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7624	PG0158	2017-08-08 19:30:00+03	2017-08-08 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-08 19:33:00+03	2017-08-08 20:03:00+03
7625	PG0159	2017-08-08 10:40:00+03	2017-08-08 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-08 10:43:00+03	2017-08-08 11:13:00+03
7626	PG0160	2017-08-08 11:25:00+03	2017-08-08 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-08 11:25:00+03	2017-08-08 11:55:00+03
7627	PG0160	2017-08-23 11:25:00+03	2017-08-23 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7628	PG0159	2017-08-23 10:40:00+03	2017-08-23 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7629	PG0158	2017-08-23 19:30:00+03	2017-08-23 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7630	PG0160	2017-09-11 11:25:00+03	2017-09-11 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7631	PG0158	2017-08-02 19:30:00+03	2017-08-02 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-02 19:33:00+03	2017-08-02 20:03:00+03
7632	PG0159	2017-08-02 10:40:00+03	2017-08-02 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-02 10:42:00+03	2017-08-02 11:12:00+03
7633	PG0158	2017-07-20 19:30:00+03	2017-07-20 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-20 19:31:00+03	2017-07-20 20:01:00+03
7634	PG0160	2017-08-02 11:25:00+03	2017-08-02 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-02 11:28:00+03	2017-08-02 11:58:00+03
7635	PG0160	2017-09-06 11:25:00+03	2017-09-06 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7636	PG0159	2017-09-06 10:40:00+03	2017-09-06 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7637	PG0158	2017-08-14 19:30:00+03	2017-08-14 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-14 19:32:00+03	2017-08-14 20:02:00+03
7638	PG0158	2017-09-06 19:30:00+03	2017-09-06 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7639	PG0159	2017-08-14 10:40:00+03	2017-08-14 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-14 10:42:00+03	2017-08-14 11:12:00+03
7640	PG0159	2017-07-20 10:40:00+03	2017-07-20 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-20 10:44:00+03	2017-07-20 11:14:00+03
7641	PG0160	2017-08-14 11:25:00+03	2017-08-14 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-14 11:25:00+03	2017-08-14 11:55:00+03
7642	PG0158	2017-07-27 19:30:00+03	2017-07-27 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-27 19:31:00+03	2017-07-27 20:01:00+03
7643	PG0159	2017-07-27 10:40:00+03	2017-07-27 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-27 10:43:00+03	2017-07-27 11:13:00+03
7644	PG0160	2017-07-27 11:25:00+03	2017-07-27 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-27 11:26:00+03	2017-07-27 11:55:00+03
7645	PG0159	2017-09-11 10:40:00+03	2017-09-11 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7646	PG0158	2017-07-21 19:30:00+03	2017-07-21 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-21 19:33:00+03	2017-07-21 20:02:00+03
7647	PG0159	2017-07-21 10:40:00+03	2017-07-21 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-21 10:43:00+03	2017-07-21 11:13:00+03
7648	PG0158	2017-08-17 19:30:00+03	2017-08-17 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7649	PG0159	2017-08-17 10:40:00+03	2017-08-17 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7650	PG0160	2017-07-21 11:25:00+03	2017-07-21 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-21 11:27:00+03	2017-07-21 11:57:00+03
7651	PG0160	2017-08-17 11:25:00+03	2017-08-17 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7652	PG0160	2017-07-23 11:25:00+03	2017-07-23 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-23 11:30:00+03	2017-07-23 12:00:00+03
7653	PG0158	2017-07-23 19:30:00+03	2017-07-23 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-23 19:32:00+03	2017-07-23 20:03:00+03
7654	PG0158	2017-08-19 19:30:00+03	2017-08-19 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7655	PG0159	2017-08-19 10:40:00+03	2017-08-19 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7656	PG0160	2017-08-19 11:25:00+03	2017-08-19 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7657	PG0160	2017-07-20 11:25:00+03	2017-07-20 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-20 11:30:00+03	2017-07-20 12:00:00+03
7658	PG0160	2017-08-28 11:25:00+03	2017-08-28 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7659	PG0158	2017-07-17 19:30:00+03	2017-07-17 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-17 19:33:00+03	2017-07-17 20:03:00+03
7660	PG0159	2017-07-17 10:40:00+03	2017-07-17 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-17 10:41:00+03	2017-07-17 11:11:00+03
7661	PG0160	2017-07-17 11:25:00+03	2017-07-17 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-17 11:27:00+03	2017-07-17 11:57:00+03
7662	PG0158	2017-08-20 19:30:00+03	2017-08-20 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7663	PG0159	2017-08-20 10:40:00+03	2017-08-20 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7664	PG0160	2017-08-11 11:25:00+03	2017-08-11 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-11 15:07:00+03	2017-08-11 15:37:00+03
7665	PG0160	2017-07-28 11:25:00+03	2017-07-28 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-28 11:26:00+03	2017-07-28 11:56:00+03
7666	PG0159	2017-07-28 10:40:00+03	2017-07-28 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-28 10:47:00+03	2017-07-28 11:17:00+03
7667	PG0160	2017-08-04 11:25:00+03	2017-08-04 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-04 11:26:00+03	2017-08-04 11:56:00+03
7668	PG0159	2017-08-04 10:40:00+03	2017-08-04 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-04 10:43:00+03	2017-08-04 11:13:00+03
7669	PG0158	2017-08-04 19:30:00+03	2017-08-04 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-04 19:34:00+03	2017-08-04 20:04:00+03
7670	PG0158	2017-07-28 19:30:00+03	2017-07-28 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-28 19:31:00+03	2017-07-28 20:01:00+03
7671	PG0160	2017-08-20 11:25:00+03	2017-08-20 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7672	PG0159	2017-08-11 10:40:00+03	2017-08-11 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-11 10:42:00+03	2017-08-11 11:12:00+03
7673	PG0158	2017-08-11 19:30:00+03	2017-08-11 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-11 19:34:00+03	2017-08-11 20:04:00+03
7674	PG0158	2017-08-24 19:30:00+03	2017-08-24 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7675	PG0159	2017-08-24 10:40:00+03	2017-08-24 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7676	PG0160	2017-08-24 11:25:00+03	2017-08-24 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7677	PG0160	2017-08-15 11:25:00+03	2017-08-15 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-15 11:27:00+03	2017-08-15 11:58:00+03
7678	PG0158	2017-09-05 19:30:00+03	2017-09-05 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7679	PG0159	2017-08-15 10:40:00+03	2017-08-15 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-15 10:45:00+03	2017-08-15 11:15:00+03
7680	PG0158	2017-08-15 19:30:00+03	2017-08-15 20:00:00+03	SVO	BZK	Delayed	SU9	\N	\N
7681	PG0158	2017-08-09 19:30:00+03	2017-08-09 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-09 19:32:00+03	2017-08-09 20:02:00+03
7682	PG0159	2017-09-05 10:40:00+03	2017-09-05 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7683	PG0159	2017-08-09 10:40:00+03	2017-08-09 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-09 10:42:00+03	2017-08-09 11:12:00+03
7684	PG0160	2017-09-05 11:25:00+03	2017-09-05 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7685	PG0160	2017-08-09 11:25:00+03	2017-08-09 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-09 11:27:00+03	2017-08-09 11:57:00+03
7686	PG0160	2017-09-10 11:25:00+03	2017-09-10 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7687	PG0159	2017-09-10 10:40:00+03	2017-09-10 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7688	PG0158	2017-09-11 19:30:00+03	2017-09-11 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7689	PG0160	2017-09-09 11:25:00+03	2017-09-09 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7690	PG0159	2017-09-09 10:40:00+03	2017-09-09 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7691	PG0158	2017-09-09 19:30:00+03	2017-09-09 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7692	PG0158	2017-09-10 19:30:00+03	2017-09-10 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7693	PG0160	2017-07-22 11:25:00+03	2017-07-22 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-22 11:28:00+03	2017-07-22 11:58:00+03
7694	PG0158	2017-07-30 19:30:00+03	2017-07-30 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-30 19:35:00+03	2017-07-30 20:05:00+03
7695	PG0159	2017-07-30 10:40:00+03	2017-07-30 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-30 10:43:00+03	2017-07-30 11:13:00+03
7696	PG0160	2017-07-30 11:25:00+03	2017-07-30 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-30 11:28:00+03	2017-07-30 11:58:00+03
7697	PG0159	2017-07-22 10:40:00+03	2017-07-22 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-22 10:42:00+03	2017-07-22 11:12:00+03
7698	PG0158	2017-09-14 19:30:00+03	2017-09-14 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7699	PG0158	2017-07-22 19:30:00+03	2017-07-22 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-22 19:32:00+03	2017-07-22 20:02:00+03
7700	PG0158	2017-08-29 19:30:00+03	2017-08-29 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7701	PG0159	2017-08-29 10:40:00+03	2017-08-29 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7702	PG0160	2017-08-29 11:25:00+03	2017-08-29 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7703	PG0159	2017-09-14 10:40:00+03	2017-09-14 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7704	PG0160	2017-07-18 11:25:00+03	2017-07-18 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-18 11:28:00+03	2017-07-18 11:58:00+03
7705	PG0159	2017-07-18 10:40:00+03	2017-07-18 11:10:00+03	SVO	BZK	Arrived	SU9	2017-07-18 10:43:00+03	2017-07-18 11:13:00+03
7706	PG0158	2017-07-18 19:30:00+03	2017-07-18 20:00:00+03	SVO	BZK	Arrived	SU9	2017-07-18 19:31:00+03	2017-07-18 20:02:00+03
7707	PG0158	2017-08-21 19:30:00+03	2017-08-21 20:00:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7708	PG0159	2017-08-21 10:40:00+03	2017-08-21 11:10:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7709	PG0158	2017-08-03 19:30:00+03	2017-08-03 20:00:00+03	SVO	BZK	Arrived	SU9	2017-08-03 19:36:00+03	2017-08-03 20:06:00+03
7710	PG0159	2017-08-03 10:40:00+03	2017-08-03 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-03 14:42:00+03	2017-08-03 15:13:00+03
7711	PG0160	2017-08-03 11:25:00+03	2017-08-03 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-03 11:28:00+03	2017-08-03 11:58:00+03
7712	PG0160	2017-08-27 11:25:00+03	2017-08-27 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7713	PG0160	2017-08-21 11:25:00+03	2017-08-21 11:55:00+03	SVO	BZK	Scheduled	SU9	\N	\N
7714	PG0160	2017-08-10 11:25:00+03	2017-08-10 11:55:00+03	SVO	BZK	Arrived	SU9	2017-08-10 11:28:00+03	2017-08-10 11:58:00+03
7715	PG0160	2017-07-24 11:25:00+03	2017-07-24 11:55:00+03	SVO	BZK	Arrived	SU9	2017-07-24 11:29:00+03	2017-07-24 11:59:00+03
7716	PG0159	2017-08-10 10:40:00+03	2017-08-10 11:10:00+03	SVO	BZK	Arrived	SU9	2017-08-10 10:41:00+03	2017-08-10 11:11:00+03
7717	PG0224	2017-07-17 17:05:00+03	2017-07-17 18:50:00+03	SVO	AER	Arrived	773	2017-07-17 17:08:00+03	2017-07-17 18:52:00+03
7718	PG0224	2017-08-26 17:05:00+03	2017-08-26 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7719	PG0224	2017-07-20 17:05:00+03	2017-07-20 18:50:00+03	SVO	AER	Arrived	773	2017-07-20 17:06:00+03	2017-07-20 18:51:00+03
7720	PG0224	2017-07-27 17:05:00+03	2017-07-27 18:50:00+03	SVO	AER	Arrived	773	2017-07-27 17:08:00+03	2017-07-27 18:53:00+03
7721	PG0224	2017-08-14 17:05:00+03	2017-08-14 18:50:00+03	SVO	AER	Arrived	773	2017-08-14 17:07:00+03	2017-08-14 18:51:00+03
7722	PG0224	2017-08-17 17:05:00+03	2017-08-17 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7723	PG0224	2017-07-18 17:05:00+03	2017-07-18 18:50:00+03	SVO	AER	Arrived	773	2017-07-18 17:07:00+03	2017-07-18 18:53:00+03
7724	PG0224	2017-09-08 17:05:00+03	2017-09-08 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7725	PG0224	2017-08-21 17:05:00+03	2017-08-21 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7726	PG0224	2017-07-22 17:05:00+03	2017-07-22 18:50:00+03	SVO	AER	Arrived	773	2017-07-22 17:06:00+03	2017-07-22 18:51:00+03
7727	PG0224	2017-07-21 17:05:00+03	2017-07-21 18:50:00+03	SVO	AER	Arrived	773	2017-07-21 17:06:00+03	2017-07-21 18:50:00+03
7728	PG0224	2017-08-22 17:05:00+03	2017-08-22 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7729	PG0224	2017-09-13 17:05:00+03	2017-09-13 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7730	PG0224	2017-08-29 17:05:00+03	2017-08-29 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7731	PG0224	2017-09-02 17:05:00+03	2017-09-02 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7732	PG0224	2017-07-23 17:05:00+03	2017-07-23 18:50:00+03	SVO	AER	Arrived	773	2017-07-23 17:09:00+03	2017-07-23 18:51:00+03
7733	PG0224	2017-09-04 17:05:00+03	2017-09-04 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7734	PG0224	2017-08-04 17:05:00+03	2017-08-04 18:50:00+03	SVO	AER	Arrived	773	2017-08-04 17:09:00+03	2017-08-04 18:56:00+03
7735	PG0224	2017-08-15 17:05:00+03	2017-08-15 18:50:00+03	SVO	AER	Departed	773	2017-08-15 17:07:00+03	\N
7736	PG0224	2017-07-31 17:05:00+03	2017-07-31 18:50:00+03	SVO	AER	Arrived	773	2017-07-31 17:09:00+03	2017-07-31 18:54:00+03
7737	PG0224	2017-07-28 17:05:00+03	2017-07-28 18:50:00+03	SVO	AER	Arrived	773	2017-07-28 17:08:00+03	2017-07-28 18:54:00+03
7738	PG0224	2017-08-11 17:05:00+03	2017-08-11 18:50:00+03	SVO	AER	Arrived	773	2017-08-11 17:07:00+03	2017-08-11 18:52:00+03
7739	PG0224	2017-08-06 17:05:00+03	2017-08-06 18:50:00+03	SVO	AER	Arrived	773	2017-08-06 17:08:00+03	2017-08-06 18:55:00+03
7740	PG0224	2017-09-12 17:05:00+03	2017-09-12 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7741	PG0224	2017-08-02 17:05:00+03	2017-08-02 18:50:00+03	SVO	AER	Arrived	773	2017-08-02 17:08:00+03	2017-08-02 18:53:00+03
7742	PG0224	2017-08-25 17:05:00+03	2017-08-25 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7743	PG0224	2017-09-09 17:05:00+03	2017-09-09 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7744	PG0224	2017-07-25 17:05:00+03	2017-07-25 18:50:00+03	SVO	AER	Arrived	773	2017-07-25 17:10:00+03	2017-07-25 18:55:00+03
7745	PG0224	2017-09-05 17:05:00+03	2017-09-05 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7746	PG0224	2017-09-01 17:05:00+03	2017-09-01 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7747	PG0224	2017-08-28 17:05:00+03	2017-08-28 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7748	PG0224	2017-08-10 17:05:00+03	2017-08-10 18:50:00+03	SVO	AER	Arrived	773	2017-08-10 17:08:00+03	2017-08-10 18:53:00+03
7749	PG0224	2017-08-08 17:05:00+03	2017-08-08 18:50:00+03	SVO	AER	Arrived	773	2017-08-08 17:05:00+03	2017-08-08 18:50:00+03
7750	PG0224	2017-09-10 17:05:00+03	2017-09-10 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7751	PG0224	2017-08-30 17:05:00+03	2017-08-30 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7752	PG0224	2017-09-06 17:05:00+03	2017-09-06 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7753	PG0224	2017-08-13 17:05:00+03	2017-08-13 18:50:00+03	SVO	AER	Arrived	773	2017-08-13 17:13:00+03	2017-08-13 18:57:00+03
7754	PG0224	2017-08-27 17:05:00+03	2017-08-27 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7755	PG0224	2017-08-05 17:05:00+03	2017-08-05 18:50:00+03	SVO	AER	Arrived	773	2017-08-05 17:07:00+03	2017-08-05 18:52:00+03
7756	PG0224	2017-09-07 17:05:00+03	2017-09-07 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7757	PG0224	2017-08-24 17:05:00+03	2017-08-24 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7758	PG0224	2017-09-14 17:05:00+03	2017-09-14 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7759	PG0224	2017-08-18 17:05:00+03	2017-08-18 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7760	PG0224	2017-09-03 17:05:00+03	2017-09-03 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7761	PG0224	2017-08-20 17:05:00+03	2017-08-20 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7762	PG0224	2017-08-12 17:05:00+03	2017-08-12 18:50:00+03	SVO	AER	Arrived	773	2017-08-12 17:08:00+03	2017-08-12 18:54:00+03
7763	PG0224	2017-07-19 17:05:00+03	2017-07-19 18:50:00+03	SVO	AER	Arrived	773	2017-07-19 17:05:00+03	2017-07-19 18:51:00+03
7764	PG0224	2017-08-23 17:05:00+03	2017-08-23 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7765	PG0224	2017-08-16 17:05:00+03	2017-08-16 18:50:00+03	SVO	AER	On Time	773	\N	\N
7766	PG0224	2017-07-26 17:05:00+03	2017-07-26 18:50:00+03	SVO	AER	Arrived	773	2017-07-26 17:10:00+03	2017-07-26 18:55:00+03
7767	PG0224	2017-08-31 17:05:00+03	2017-08-31 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7768	PG0224	2017-07-16 17:05:00+03	2017-07-16 18:50:00+03	SVO	AER	Arrived	773	2017-07-16 17:09:00+03	2017-07-16 18:53:00+03
7769	PG0224	2017-07-30 17:05:00+03	2017-07-30 18:50:00+03	SVO	AER	Arrived	773	2017-07-30 17:08:00+03	2017-07-30 18:54:00+03
7770	PG0224	2017-08-07 17:05:00+03	2017-08-07 18:50:00+03	SVO	AER	Arrived	773	2017-08-07 17:09:00+03	2017-08-07 18:54:00+03
7771	PG0224	2017-07-29 17:05:00+03	2017-07-29 18:50:00+03	SVO	AER	Arrived	773	2017-07-29 17:08:00+03	2017-07-29 18:51:00+03
7772	PG0224	2017-08-03 17:05:00+03	2017-08-03 18:50:00+03	SVO	AER	Arrived	773	2017-08-03 20:40:00+03	2017-08-03 22:25:00+03
7773	PG0224	2017-08-01 17:05:00+03	2017-08-01 18:50:00+03	SVO	AER	Arrived	773	2017-08-01 17:06:00+03	2017-08-01 18:51:00+03
7774	PG0224	2017-09-11 17:05:00+03	2017-09-11 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7775	PG0224	2017-07-24 17:05:00+03	2017-07-24 18:50:00+03	SVO	AER	Arrived	773	2017-07-24 17:06:00+03	2017-07-24 18:51:00+03
7776	PG0224	2017-08-09 17:05:00+03	2017-08-09 18:50:00+03	SVO	AER	Arrived	773	2017-08-09 17:08:00+03	2017-08-09 18:52:00+03
7777	PG0224	2017-08-19 17:05:00+03	2017-08-19 18:50:00+03	SVO	AER	Scheduled	773	\N	\N
7778	PG0667	2017-08-03 15:00:00+03	2017-08-03 17:30:00+03	SVO	KRO	Arrived	CR2	2017-08-03 15:02:00+03	2017-08-03 17:35:00+03
7779	PG0667	2017-07-30 15:00:00+03	2017-07-30 17:30:00+03	SVO	KRO	Arrived	CR2	2017-07-30 18:23:00+03	2017-07-30 20:53:00+03
7780	PG0667	2017-07-23 15:00:00+03	2017-07-23 17:30:00+03	SVO	KRO	Arrived	CR2	2017-07-23 15:02:00+03	2017-07-23 17:28:00+03
7781	PG0667	2017-08-31 15:00:00+03	2017-08-31 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7782	PG0667	2017-09-14 15:00:00+03	2017-09-14 17:30:00+03	SVO	KRO	Cancelled	CR2	\N	\N
7783	PG0667	2017-08-13 15:00:00+03	2017-08-13 17:30:00+03	SVO	KRO	Arrived	CR2	2017-08-13 15:07:00+03	2017-08-13 17:35:00+03
7785	PG0667	2017-07-20 15:00:00+03	2017-07-20 17:30:00+03	SVO	KRO	Arrived	CR2	2017-07-20 15:04:00+03	2017-07-20 17:33:00+03
7786	PG0667	2017-07-16 15:00:00+03	2017-07-16 17:30:00+03	SVO	KRO	Arrived	CR2	2017-07-16 15:01:00+03	2017-07-16 17:32:00+03
7787	PG0667	2017-08-27 15:00:00+03	2017-08-27 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7788	PG0667	2017-08-10 15:00:00+03	2017-08-10 17:30:00+03	SVO	KRO	Arrived	CR2	2017-08-10 15:06:00+03	2017-08-10 17:37:00+03
7789	PG0667	2017-09-03 15:00:00+03	2017-09-03 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7790	PG0667	2017-08-24 15:00:00+03	2017-08-24 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7791	PG0667	2017-08-20 15:00:00+03	2017-08-20 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7792	PG0667	2017-08-17 15:00:00+03	2017-08-17 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7793	PG0667	2017-07-27 15:00:00+03	2017-07-27 17:30:00+03	SVO	KRO	Arrived	CR2	2017-07-27 15:06:00+03	2017-07-27 17:37:00+03
7794	PG0667	2017-09-07 15:00:00+03	2017-09-07 17:30:00+03	SVO	KRO	Scheduled	CR2	\N	\N
7795	PG0667	2017-08-06 15:00:00+03	2017-08-06 17:30:00+03	SVO	KRO	Arrived	CR2	2017-08-06 15:03:00+03	2017-08-06 17:32:00+03
7796	PG0549	2017-08-19 11:55:00+03	2017-08-19 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7797	PG0549	2017-09-06 11:55:00+03	2017-09-06 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7798	PG0549	2017-07-24 11:55:00+03	2017-07-24 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-24 11:59:00+03	2017-07-24 14:07:00+03
7799	PG0549	2017-08-06 11:55:00+03	2017-08-06 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-06 11:58:00+03	2017-08-06 14:07:00+03
7800	PG0549	2017-07-19 11:55:00+03	2017-07-19 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-19 11:56:00+03	2017-07-19 14:06:00+03
7801	PG0549	2017-09-03 11:55:00+03	2017-09-03 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7802	PG0549	2017-08-05 11:55:00+03	2017-08-05 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-05 12:01:00+03	2017-08-05 14:12:00+03
7803	PG0549	2017-08-29 11:55:00+03	2017-08-29 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7804	PG0549	2017-08-23 11:55:00+03	2017-08-23 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7805	PG0549	2017-09-12 11:55:00+03	2017-09-12 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7806	PG0549	2017-08-16 11:55:00+03	2017-08-16 14:05:00+03	SVO	OGZ	On Time	CR2	\N	\N
7807	PG0549	2017-08-07 11:55:00+03	2017-08-07 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-07 11:56:00+03	2017-08-07 14:04:00+03
7808	PG0549	2017-08-15 11:55:00+03	2017-08-15 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-15 12:02:00+03	2017-08-15 14:11:00+03
7809	PG0549	2017-07-28 11:55:00+03	2017-07-28 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-28 11:58:00+03	2017-07-28 14:07:00+03
7810	PG0549	2017-07-29 11:55:00+03	2017-07-29 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-29 11:59:00+03	2017-07-29 14:08:00+03
7811	PG0549	2017-07-20 11:55:00+03	2017-07-20 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-20 12:00:00+03	2017-07-20 14:07:00+03
7812	PG0549	2017-09-04 11:55:00+03	2017-09-04 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7813	PG0549	2017-08-04 11:55:00+03	2017-08-04 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-04 11:57:00+03	2017-08-04 14:08:00+03
7814	PG0549	2017-09-13 11:55:00+03	2017-09-13 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7815	PG0549	2017-07-18 11:55:00+03	2017-07-18 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-18 11:57:00+03	2017-07-18 14:09:00+03
7816	PG0549	2017-09-08 11:55:00+03	2017-09-08 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7817	PG0549	2017-08-08 11:55:00+03	2017-08-08 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-08 11:59:00+03	2017-08-08 14:11:00+03
7818	PG0549	2017-09-10 11:55:00+03	2017-09-10 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7819	PG0549	2017-09-02 11:55:00+03	2017-09-02 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7820	PG0549	2017-09-07 11:55:00+03	2017-09-07 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7821	PG0549	2017-08-21 11:55:00+03	2017-08-21 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7822	PG0549	2017-08-03 11:55:00+03	2017-08-03 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-03 11:59:00+03	2017-08-03 14:09:00+03
7823	PG0549	2017-08-09 11:55:00+03	2017-08-09 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-09 12:00:00+03	2017-08-09 14:12:00+03
7824	PG0549	2017-07-27 11:55:00+03	2017-07-27 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-27 11:57:00+03	2017-07-27 14:05:00+03
7825	PG0549	2017-07-21 11:55:00+03	2017-07-21 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-21 11:56:00+03	2017-07-21 14:09:00+03
7826	PG0549	2017-08-14 11:55:00+03	2017-08-14 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-14 11:58:00+03	2017-08-14 14:10:00+03
7827	PG0549	2017-08-30 11:55:00+03	2017-08-30 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7828	PG0549	2017-07-17 11:55:00+03	2017-07-17 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-17 12:00:00+03	2017-07-17 14:09:00+03
7829	PG0549	2017-07-25 11:55:00+03	2017-07-25 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-25 12:01:00+03	2017-07-25 14:11:00+03
7830	PG0549	2017-08-22 11:55:00+03	2017-08-22 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7831	PG0549	2017-08-25 11:55:00+03	2017-08-25 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7832	PG0549	2017-09-05 11:55:00+03	2017-09-05 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7833	PG0549	2017-08-17 11:55:00+03	2017-08-17 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7834	PG0549	2017-08-10 11:55:00+03	2017-08-10 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-10 11:58:00+03	2017-08-10 14:07:00+03
7835	PG0549	2017-09-01 11:55:00+03	2017-09-01 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7836	PG0549	2017-08-02 11:55:00+03	2017-08-02 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-02 11:58:00+03	2017-08-02 14:11:00+03
7837	PG0549	2017-07-30 11:55:00+03	2017-07-30 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-30 11:55:00+03	2017-07-30 14:05:00+03
7838	PG0549	2017-08-24 11:55:00+03	2017-08-24 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7839	PG0549	2017-08-26 11:55:00+03	2017-08-26 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7840	PG0549	2017-09-11 11:55:00+03	2017-09-11 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7841	PG0549	2017-08-11 11:55:00+03	2017-08-11 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-11 11:58:00+03	2017-08-11 14:06:00+03
7842	PG0549	2017-08-27 11:55:00+03	2017-08-27 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7843	PG0549	2017-07-16 11:55:00+03	2017-07-16 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-16 12:02:00+03	2017-07-16 14:13:00+03
7844	PG0549	2017-07-22 11:55:00+03	2017-07-22 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-22 11:57:00+03	2017-07-22 14:06:00+03
7845	PG0549	2017-08-01 11:55:00+03	2017-08-01 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-01 11:59:00+03	2017-08-01 14:09:00+03
7846	PG0549	2017-07-23 11:55:00+03	2017-07-23 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-23 15:10:00+03	2017-07-23 17:20:00+03
7847	PG0549	2017-08-13 11:55:00+03	2017-08-13 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-13 12:00:00+03	2017-08-13 14:10:00+03
7848	PG0549	2017-08-12 11:55:00+03	2017-08-12 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-08-12 11:59:00+03	2017-08-12 14:11:00+03
7849	PG0549	2017-08-31 11:55:00+03	2017-08-31 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7850	PG0549	2017-08-20 11:55:00+03	2017-08-20 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7851	PG0549	2017-07-26 11:55:00+03	2017-07-26 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-26 12:01:00+03	2017-07-26 14:10:00+03
7852	PG0549	2017-09-14 11:55:00+03	2017-09-14 14:05:00+03	SVO	OGZ	Cancelled	CR2	\N	\N
7853	PG0549	2017-09-09 11:55:00+03	2017-09-09 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7854	PG0549	2017-08-28 11:55:00+03	2017-08-28 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7855	PG0549	2017-08-18 11:55:00+03	2017-08-18 14:05:00+03	SVO	OGZ	Scheduled	CR2	\N	\N
7856	PG0549	2017-07-31 11:55:00+03	2017-07-31 14:05:00+03	SVO	OGZ	Arrived	CR2	2017-07-31 12:00:00+03	2017-07-31 14:12:00+03
7857	PG0062	2017-08-28 14:40:00+03	2017-08-28 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7858	PG0062	2017-08-13 14:40:00+03	2017-08-13 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-13 14:41:00+03	2017-08-13 15:25:00+03
7859	PG0062	2017-07-29 14:40:00+03	2017-07-29 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-29 14:43:00+03	2017-07-29 15:28:00+03
7860	PG0062	2017-08-30 14:40:00+03	2017-08-30 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7861	PG0062	2017-08-05 14:40:00+03	2017-08-05 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-05 14:44:00+03	2017-08-05 15:30:00+03
7862	PG0062	2017-07-16 14:40:00+03	2017-07-16 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-16 14:41:00+03	2017-07-16 15:25:00+03
7863	PG0062	2017-07-22 14:40:00+03	2017-07-22 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-22 14:44:00+03	2017-07-22 15:29:00+03
7864	PG0062	2017-09-07 14:40:00+03	2017-09-07 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7865	PG0062	2017-08-16 14:40:00+03	2017-08-16 15:25:00+03	SVO	SKX	On Time	CR2	\N	\N
7866	PG0062	2017-08-07 14:40:00+03	2017-08-07 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-07 14:41:00+03	2017-08-07 15:26:00+03
7867	PG0062	2017-07-23 14:40:00+03	2017-07-23 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-23 14:47:00+03	2017-07-23 15:32:00+03
7868	PG0062	2017-09-13 14:40:00+03	2017-09-13 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7869	PG0062	2017-08-15 14:40:00+03	2017-08-15 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-15 14:44:00+03	2017-08-15 15:29:00+03
7870	PG0062	2017-07-25 14:40:00+03	2017-07-25 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-25 14:46:00+03	2017-07-25 15:31:00+03
7871	PG0062	2017-07-19 14:40:00+03	2017-07-19 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-19 14:43:00+03	2017-07-19 15:28:00+03
7872	PG0062	2017-09-08 14:40:00+03	2017-09-08 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7873	PG0062	2017-08-22 14:40:00+03	2017-08-22 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7874	PG0062	2017-08-25 14:40:00+03	2017-08-25 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7875	PG0062	2017-09-12 14:40:00+03	2017-09-12 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7876	PG0062	2017-08-14 14:40:00+03	2017-08-14 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-14 14:43:00+03	2017-08-14 15:28:00+03
7877	PG0062	2017-09-11 14:40:00+03	2017-09-11 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7878	PG0062	2017-08-27 14:40:00+03	2017-08-27 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7879	PG0062	2017-08-12 14:40:00+03	2017-08-12 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-12 14:43:00+03	2017-08-12 15:28:00+03
7880	PG0062	2017-07-27 14:40:00+03	2017-07-27 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-27 14:42:00+03	2017-07-27 15:27:00+03
7881	PG0062	2017-08-03 14:40:00+03	2017-08-03 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-03 14:41:00+03	2017-08-03 15:26:00+03
7882	PG0062	2017-08-01 14:40:00+03	2017-08-01 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-01 14:42:00+03	2017-08-01 15:27:00+03
7883	PG0062	2017-09-02 14:40:00+03	2017-09-02 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7884	PG0062	2017-07-24 14:40:00+03	2017-07-24 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-24 14:44:00+03	2017-07-24 15:29:00+03
7885	PG0062	2017-08-08 14:40:00+03	2017-08-08 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-08 14:41:00+03	2017-08-08 15:26:00+03
7886	PG0062	2017-09-09 14:40:00+03	2017-09-09 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7887	PG0062	2017-07-31 14:40:00+03	2017-07-31 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-31 14:44:00+03	2017-07-31 15:29:00+03
7888	PG0062	2017-09-10 14:40:00+03	2017-09-10 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7889	PG0062	2017-09-04 14:40:00+03	2017-09-04 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7890	PG0062	2017-08-26 14:40:00+03	2017-08-26 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7891	PG0062	2017-08-02 14:40:00+03	2017-08-02 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-02 14:44:00+03	2017-08-02 15:29:00+03
7892	PG0062	2017-08-31 14:40:00+03	2017-08-31 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7893	PG0062	2017-08-19 14:40:00+03	2017-08-19 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7894	PG0062	2017-07-18 14:40:00+03	2017-07-18 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-18 14:44:00+03	2017-07-18 15:28:00+03
7895	PG0062	2017-09-14 14:40:00+03	2017-09-14 15:25:00+03	SVO	SKX	Cancelled	CR2	\N	\N
7896	PG0062	2017-08-20 14:40:00+03	2017-08-20 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7897	PG0062	2017-08-17 14:40:00+03	2017-08-17 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7898	PG0062	2017-09-03 14:40:00+03	2017-09-03 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7899	PG0062	2017-07-21 14:40:00+03	2017-07-21 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-21 14:45:00+03	2017-07-21 15:30:00+03
7900	PG0062	2017-08-24 14:40:00+03	2017-08-24 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7901	PG0062	2017-08-04 14:40:00+03	2017-08-04 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-04 14:41:00+03	2017-08-04 15:25:00+03
7902	PG0062	2017-08-18 14:40:00+03	2017-08-18 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7903	PG0062	2017-07-28 14:40:00+03	2017-07-28 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-28 14:43:00+03	2017-07-28 15:28:00+03
7904	PG0062	2017-07-20 14:40:00+03	2017-07-20 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-20 14:43:00+03	2017-07-20 15:28:00+03
7905	PG0062	2017-07-26 14:40:00+03	2017-07-26 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-26 14:45:00+03	2017-07-26 15:31:00+03
7906	PG0062	2017-08-11 14:40:00+03	2017-08-11 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-11 14:43:00+03	2017-08-11 15:28:00+03
7907	PG0062	2017-08-21 14:40:00+03	2017-08-21 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7908	PG0062	2017-07-17 14:40:00+03	2017-07-17 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-17 14:43:00+03	2017-07-17 15:28:00+03
7909	PG0062	2017-08-23 14:40:00+03	2017-08-23 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7910	PG0062	2017-08-29 14:40:00+03	2017-08-29 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7911	PG0062	2017-09-05 14:40:00+03	2017-09-05 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7912	PG0062	2017-08-10 14:40:00+03	2017-08-10 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-10 14:43:00+03	2017-08-10 15:28:00+03
7913	PG0062	2017-08-06 14:40:00+03	2017-08-06 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-06 14:46:00+03	2017-08-06 15:31:00+03
7914	PG0062	2017-09-06 14:40:00+03	2017-09-06 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7915	PG0062	2017-08-09 14:40:00+03	2017-08-09 15:25:00+03	SVO	SKX	Arrived	CR2	2017-08-09 14:41:00+03	2017-08-09 15:26:00+03
7916	PG0062	2017-07-30 14:40:00+03	2017-07-30 15:25:00+03	SVO	SKX	Arrived	CR2	2017-07-30 14:43:00+03	2017-07-30 15:28:00+03
7917	PG0062	2017-09-01 14:40:00+03	2017-09-01 15:25:00+03	SVO	SKX	Scheduled	CR2	\N	\N
7918	PG0408	2017-08-07 11:55:00+03	2017-08-07 12:50:00+03	LED	DME	Arrived	321	2017-08-07 11:57:00+03	2017-08-07 12:53:00+03
7919	PG0406	2017-08-06 19:00:00+03	2017-08-06 19:55:00+03	LED	DME	Arrived	321	2017-08-06 19:04:00+03	2017-08-06 19:58:00+03
7920	PG0406	2017-08-21 19:00:00+03	2017-08-21 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7921	PG0406	2017-07-23 19:00:00+03	2017-07-23 19:55:00+03	LED	DME	Arrived	321	2017-07-23 19:05:00+03	2017-07-23 19:59:00+03
7922	PG0409	2017-09-07 14:55:00+03	2017-09-07 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7923	PG0408	2017-09-07 11:55:00+03	2017-09-07 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7924	PG0407	2017-09-07 12:10:00+03	2017-09-07 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7925	PG0409	2017-08-09 14:55:00+03	2017-08-09 15:50:00+03	LED	DME	Arrived	321	2017-08-09 14:57:00+03	2017-08-09 15:52:00+03
7926	PG0408	2017-08-09 11:55:00+03	2017-08-09 12:50:00+03	LED	DME	Arrived	321	2017-08-09 11:59:00+03	2017-08-09 12:54:00+03
7927	PG0407	2017-08-09 12:10:00+03	2017-08-09 13:05:00+03	LED	DME	Arrived	321	2017-08-09 12:17:00+03	2017-08-09 13:12:00+03
7928	PG0406	2017-09-07 19:00:00+03	2017-09-07 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7929	PG0409	2017-07-27 14:55:00+03	2017-07-27 15:50:00+03	LED	DME	Arrived	321	2017-07-27 14:55:00+03	2017-07-27 15:50:00+03
7930	PG0408	2017-07-27 11:55:00+03	2017-07-27 12:50:00+03	LED	DME	Arrived	321	2017-07-27 11:57:00+03	2017-07-27 12:53:00+03
7931	PG0406	2017-08-09 19:00:00+03	2017-08-09 19:55:00+03	LED	DME	Arrived	321	2017-08-09 19:05:00+03	2017-08-09 20:00:00+03
7932	PG0407	2017-07-27 12:10:00+03	2017-07-27 13:05:00+03	LED	DME	Arrived	321	2017-07-27 12:13:00+03	2017-07-27 13:07:00+03
7933	PG0406	2017-07-30 19:00:00+03	2017-07-30 19:55:00+03	LED	DME	Arrived	321	2017-07-30 19:04:00+03	2017-07-30 19:59:00+03
7934	PG0407	2017-07-30 12:10:00+03	2017-07-30 13:05:00+03	LED	DME	Arrived	321	2017-07-30 12:15:00+03	2017-07-30 13:10:00+03
7935	PG0408	2017-07-30 11:55:00+03	2017-07-30 12:50:00+03	LED	DME	Arrived	321	2017-07-30 11:59:00+03	2017-07-30 12:54:00+03
7936	PG0409	2017-07-30 14:55:00+03	2017-07-30 15:50:00+03	LED	DME	Arrived	321	2017-07-30 14:57:00+03	2017-07-30 15:53:00+03
7937	PG0406	2017-07-27 19:00:00+03	2017-07-27 19:55:00+03	LED	DME	Arrived	321	2017-07-27 19:02:00+03	2017-07-27 19:57:00+03
7938	PG0409	2017-07-21 14:55:00+03	2017-07-21 15:50:00+03	LED	DME	Arrived	321	2017-07-21 15:01:00+03	2017-07-21 15:56:00+03
7939	PG0406	2017-08-10 19:00:00+03	2017-08-10 19:55:00+03	LED	DME	Arrived	321	2017-08-10 19:03:00+03	2017-08-10 19:58:00+03
7940	PG0407	2017-08-10 12:10:00+03	2017-08-10 13:05:00+03	LED	DME	Arrived	321	2017-08-10 12:15:00+03	2017-08-10 13:10:00+03
7941	PG0408	2017-08-10 11:55:00+03	2017-08-10 12:50:00+03	LED	DME	Arrived	321	2017-08-10 11:57:00+03	2017-08-10 12:52:00+03
7942	PG0408	2017-07-21 11:55:00+03	2017-07-21 12:50:00+03	LED	DME	Arrived	321	2017-07-21 11:56:00+03	2017-07-21 12:51:00+03
7943	PG0409	2017-08-10 14:55:00+03	2017-08-10 15:50:00+03	LED	DME	Arrived	321	2017-08-10 15:00:00+03	2017-08-10 15:56:00+03
7944	PG0407	2017-07-21 12:10:00+03	2017-07-21 13:05:00+03	LED	DME	Arrived	321	2017-07-21 12:11:00+03	2017-07-21 13:06:00+03
7945	PG0409	2017-07-17 14:55:00+03	2017-07-17 15:50:00+03	LED	DME	Arrived	321	2017-07-17 14:57:00+03	2017-07-17 15:52:00+03
7946	PG0406	2017-07-21 19:00:00+03	2017-07-21 19:55:00+03	LED	DME	Arrived	321	2017-07-21 19:03:00+03	2017-07-21 19:58:00+03
7947	PG0408	2017-07-17 11:55:00+03	2017-07-17 12:50:00+03	LED	DME	Arrived	321	2017-07-17 11:57:00+03	2017-07-17 12:52:00+03
7948	PG0407	2017-07-17 12:10:00+03	2017-07-17 13:05:00+03	LED	DME	Arrived	321	2017-07-17 12:11:00+03	2017-07-17 13:05:00+03
7949	PG0406	2017-07-17 19:00:00+03	2017-07-17 19:55:00+03	LED	DME	Arrived	321	2017-07-17 19:02:00+03	2017-07-17 19:57:00+03
7950	PG0409	2017-08-30 14:55:00+03	2017-08-30 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7951	PG0408	2017-08-30 11:55:00+03	2017-08-30 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7952	PG0409	2017-08-14 14:55:00+03	2017-08-14 15:50:00+03	LED	DME	Arrived	321	2017-08-14 15:01:00+03	2017-08-14 15:56:00+03
7953	PG0408	2017-08-14 11:55:00+03	2017-08-14 12:50:00+03	LED	DME	Arrived	321	2017-08-14 11:56:00+03	2017-08-14 12:51:00+03
7954	PG0407	2017-07-23 12:10:00+03	2017-07-23 13:05:00+03	LED	DME	Arrived	321	2017-07-23 12:14:00+03	2017-07-23 13:09:00+03
7955	PG0407	2017-08-14 12:10:00+03	2017-08-14 13:05:00+03	LED	DME	Arrived	321	2017-08-14 15:17:00+03	2017-08-14 16:11:00+03
7956	PG0407	2017-08-30 12:10:00+03	2017-08-30 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7957	PG0406	2017-08-30 19:00:00+03	2017-08-30 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7958	PG0409	2017-07-25 14:55:00+03	2017-07-25 15:50:00+03	LED	DME	Arrived	321	2017-07-25 18:33:00+03	2017-07-25 19:29:00+03
7959	PG0406	2017-08-14 19:00:00+03	2017-08-14 19:55:00+03	LED	DME	Arrived	321	2017-08-14 19:02:00+03	2017-08-14 19:57:00+03
7960	PG0408	2017-07-25 11:55:00+03	2017-07-25 12:50:00+03	LED	DME	Arrived	321	2017-07-25 11:56:00+03	2017-07-25 12:51:00+03
7961	PG0407	2017-07-25 12:10:00+03	2017-07-25 13:05:00+03	LED	DME	Arrived	321	2017-07-25 12:15:00+03	2017-07-25 13:10:00+03
7962	PG0406	2017-07-25 19:00:00+03	2017-07-25 19:55:00+03	LED	DME	Arrived	321	2017-07-25 19:03:00+03	2017-07-25 19:57:00+03
7963	PG0406	2017-09-02 19:00:00+03	2017-09-02 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7964	PG0406	2017-08-24 19:00:00+03	2017-08-24 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7965	PG0407	2017-08-24 12:10:00+03	2017-08-24 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7966	PG0406	2017-09-10 19:00:00+03	2017-09-10 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7967	PG0408	2017-08-24 11:55:00+03	2017-08-24 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7968	PG0408	2017-07-23 11:55:00+03	2017-07-23 12:50:00+03	LED	DME	Arrived	321	2017-07-23 11:57:00+03	2017-07-23 12:52:00+03
7969	PG0407	2017-09-02 12:10:00+03	2017-09-02 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7970	PG0408	2017-09-02 11:55:00+03	2017-09-02 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7971	PG0409	2017-08-26 14:55:00+03	2017-08-26 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7972	PG0409	2017-08-24 14:55:00+03	2017-08-24 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7973	PG0409	2017-09-02 14:55:00+03	2017-09-02 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7974	PG0408	2017-08-26 11:55:00+03	2017-08-26 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7975	PG0407	2017-07-26 12:10:00+03	2017-07-26 13:05:00+03	LED	DME	Arrived	321	2017-07-26 12:15:00+03	2017-07-26 13:09:00+03
7976	PG0407	2017-08-26 12:10:00+03	2017-08-26 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7977	PG0406	2017-08-26 19:00:00+03	2017-08-26 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7978	PG0407	2017-08-20 12:10:00+03	2017-08-20 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7979	PG0408	2017-08-20 11:55:00+03	2017-08-20 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7980	PG0409	2017-09-01 14:55:00+03	2017-09-01 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7981	PG0406	2017-07-18 19:00:00+03	2017-07-18 19:55:00+03	LED	DME	Arrived	321	2017-07-18 19:05:00+03	2017-07-18 20:00:00+03
7982	PG0408	2017-09-01 11:55:00+03	2017-09-01 12:50:00+03	LED	DME	Scheduled	321	\N	\N
7983	PG0407	2017-07-18 12:10:00+03	2017-07-18 13:05:00+03	LED	DME	Arrived	321	2017-07-18 12:12:00+03	2017-07-18 13:07:00+03
7984	PG0409	2017-08-02 14:55:00+03	2017-08-02 15:50:00+03	LED	DME	Arrived	321	2017-08-02 14:56:00+03	2017-08-02 15:50:00+03
7985	PG0408	2017-08-02 11:55:00+03	2017-08-02 12:50:00+03	LED	DME	Arrived	321	2017-08-02 11:57:00+03	2017-08-02 12:52:00+03
7986	PG0407	2017-08-02 12:10:00+03	2017-08-02 13:05:00+03	LED	DME	Arrived	321	2017-08-02 12:13:00+03	2017-08-02 13:09:00+03
7987	PG0406	2017-08-02 19:00:00+03	2017-08-02 19:55:00+03	LED	DME	Arrived	321	2017-08-02 19:02:00+03	2017-08-02 19:57:00+03
7988	PG0408	2017-07-18 11:55:00+03	2017-07-18 12:50:00+03	LED	DME	Arrived	321	2017-07-18 15:16:00+03	2017-07-18 16:10:00+03
7989	PG0409	2017-07-18 14:55:00+03	2017-07-18 15:50:00+03	LED	DME	Arrived	321	2017-07-18 14:56:00+03	2017-07-18 15:51:00+03
7990	PG0407	2017-09-01 12:10:00+03	2017-09-01 13:05:00+03	LED	DME	Scheduled	321	\N	\N
7991	PG0406	2017-09-01 19:00:00+03	2017-09-01 19:55:00+03	LED	DME	Scheduled	321	\N	\N
7992	PG0409	2017-08-20 14:55:00+03	2017-08-20 15:50:00+03	LED	DME	Scheduled	321	\N	\N
7993	PG0409	2017-08-08 14:55:00+03	2017-08-08 15:50:00+03	LED	DME	Arrived	321	2017-08-08 14:58:00+03	2017-08-08 15:53:00+03
7994	PG0406	2017-08-11 19:00:00+03	2017-08-11 19:55:00+03	LED	DME	Arrived	321	2017-08-11 19:03:00+03	2017-08-11 19:58:00+03
7995	PG0407	2017-08-11 12:10:00+03	2017-08-11 13:05:00+03	LED	DME	Arrived	321	2017-08-11 12:16:00+03	2017-08-11 13:11:00+03
7996	PG0408	2017-08-11 11:55:00+03	2017-08-11 12:50:00+03	LED	DME	Arrived	321	2017-08-11 11:59:00+03	2017-08-11 12:54:00+03
7997	PG0409	2017-08-11 14:55:00+03	2017-08-11 15:50:00+03	LED	DME	Arrived	321	2017-08-11 14:57:00+03	2017-08-11 15:52:00+03
7998	PG0408	2017-08-08 11:55:00+03	2017-08-08 12:50:00+03	LED	DME	Arrived	321	2017-08-08 11:57:00+03	2017-08-08 12:52:00+03
7999	PG0407	2017-08-08 12:10:00+03	2017-08-08 13:05:00+03	LED	DME	Arrived	321	2017-08-08 12:14:00+03	2017-08-08 13:09:00+03
8000	PG0406	2017-08-04 19:00:00+03	2017-08-04 19:55:00+03	LED	DME	Arrived	321	2017-08-04 19:05:00+03	2017-08-04 20:00:00+03
8001	PG0409	2017-08-22 14:55:00+03	2017-08-22 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8002	PG0408	2017-08-22 11:55:00+03	2017-08-22 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8003	PG0407	2017-08-04 12:10:00+03	2017-08-04 13:05:00+03	LED	DME	Arrived	321	2017-08-04 12:17:00+03	2017-08-04 13:12:00+03
8004	PG0407	2017-08-22 12:10:00+03	2017-08-22 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8005	PG0406	2017-08-22 19:00:00+03	2017-08-22 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8006	PG0408	2017-08-04 11:55:00+03	2017-08-04 12:50:00+03	LED	DME	Arrived	321	2017-08-04 11:56:00+03	2017-08-04 12:51:00+03
8007	PG0409	2017-08-04 14:55:00+03	2017-08-04 15:50:00+03	LED	DME	Arrived	321	2017-08-04 14:58:00+03	2017-08-04 15:54:00+03
8008	PG0406	2017-08-08 19:00:00+03	2017-08-08 19:55:00+03	LED	DME	Arrived	321	2017-08-08 22:27:00+03	2017-08-08 23:22:00+03
8009	PG0406	2017-08-15 19:00:00+03	2017-08-15 19:55:00+03	LED	DME	On Time	321	\N	\N
8010	PG0407	2017-08-15 12:10:00+03	2017-08-15 13:05:00+03	LED	DME	Arrived	321	2017-08-15 12:17:00+03	2017-08-15 13:12:00+03
8011	PG0408	2017-08-15 11:55:00+03	2017-08-15 12:50:00+03	LED	DME	Arrived	321	2017-08-15 11:55:00+03	2017-08-15 12:50:00+03
8012	PG0409	2017-08-15 14:55:00+03	2017-08-15 15:50:00+03	LED	DME	Arrived	321	2017-08-15 14:58:00+03	2017-08-15 15:53:00+03
8013	PG0406	2017-09-12 19:00:00+03	2017-09-12 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8014	PG0407	2017-09-12 12:10:00+03	2017-09-12 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8015	PG0406	2017-07-22 19:00:00+03	2017-07-22 19:55:00+03	LED	DME	Arrived	321	2017-07-22 19:03:00+03	2017-07-22 19:58:00+03
8016	PG0407	2017-07-22 12:10:00+03	2017-07-22 13:05:00+03	LED	DME	Arrived	321	2017-07-22 12:13:00+03	2017-07-22 13:09:00+03
8017	PG0408	2017-09-12 11:55:00+03	2017-09-12 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8018	PG0408	2017-07-22 11:55:00+03	2017-07-22 12:50:00+03	LED	DME	Arrived	321	2017-07-22 11:58:00+03	2017-07-22 12:52:00+03
8019	PG0409	2017-07-22 14:55:00+03	2017-07-22 15:50:00+03	LED	DME	Arrived	321	2017-07-22 15:01:00+03	2017-07-22 15:56:00+03
8020	PG0409	2017-09-12 14:55:00+03	2017-09-12 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8021	PG0409	2017-07-23 14:55:00+03	2017-07-23 15:50:00+03	LED	DME	Arrived	321	2017-07-23 14:59:00+03	2017-07-23 15:55:00+03
8022	PG0406	2017-08-27 19:00:00+03	2017-08-27 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8023	PG0406	2017-08-29 19:00:00+03	2017-08-29 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8024	PG0407	2017-08-29 12:10:00+03	2017-08-29 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8025	PG0408	2017-08-29 11:55:00+03	2017-08-29 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8026	PG0407	2017-08-27 12:10:00+03	2017-08-27 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8027	PG0409	2017-08-29 14:55:00+03	2017-08-29 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8028	PG0408	2017-08-27 11:55:00+03	2017-08-27 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8029	PG0406	2017-07-28 19:00:00+03	2017-07-28 19:55:00+03	LED	DME	Arrived	321	2017-07-28 19:07:00+03	2017-07-28 20:02:00+03
8030	PG0407	2017-07-28 12:10:00+03	2017-07-28 13:05:00+03	LED	DME	Arrived	321	2017-07-28 12:12:00+03	2017-07-28 13:06:00+03
8031	PG0408	2017-07-28 11:55:00+03	2017-07-28 12:50:00+03	LED	DME	Arrived	321	2017-07-28 11:59:00+03	2017-07-28 12:54:00+03
8032	PG0409	2017-08-27 14:55:00+03	2017-08-27 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8033	PG0409	2017-07-28 14:55:00+03	2017-07-28 15:50:00+03	LED	DME	Arrived	321	2017-07-28 14:58:00+03	2017-07-28 15:53:00+03
8034	PG0407	2017-08-31 12:10:00+03	2017-08-31 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8035	PG0406	2017-08-19 19:00:00+03	2017-08-19 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8036	PG0407	2017-08-19 12:10:00+03	2017-08-19 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8037	PG0408	2017-08-19 11:55:00+03	2017-08-19 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8038	PG0409	2017-08-19 14:55:00+03	2017-08-19 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8039	PG0409	2017-08-25 14:55:00+03	2017-08-25 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8040	PG0409	2017-07-26 14:55:00+03	2017-07-26 15:50:00+03	LED	DME	Arrived	321	2017-07-26 14:56:00+03	2017-07-26 15:51:00+03
8041	PG0408	2017-07-26 11:55:00+03	2017-07-26 12:50:00+03	LED	DME	Arrived	321	2017-07-26 11:59:00+03	2017-07-26 12:54:00+03
8042	PG0408	2017-08-25 11:55:00+03	2017-08-25 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8043	PG0409	2017-08-13 14:55:00+03	2017-08-13 15:50:00+03	LED	DME	Arrived	321	2017-08-13 14:59:00+03	2017-08-13 15:54:00+03
8044	PG0407	2017-08-25 12:10:00+03	2017-08-25 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8045	PG0409	2017-09-13 14:55:00+03	2017-09-13 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8046	PG0406	2017-08-25 19:00:00+03	2017-08-25 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8047	PG0408	2017-09-13 11:55:00+03	2017-09-13 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8048	PG0409	2017-09-08 14:55:00+03	2017-09-08 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8049	PG0407	2017-08-21 12:10:00+03	2017-08-21 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8050	PG0406	2017-08-23 19:00:00+03	2017-08-23 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8051	PG0407	2017-09-13 12:10:00+03	2017-09-13 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8052	PG0406	2017-09-13 19:00:00+03	2017-09-13 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8053	PG0406	2017-07-24 19:00:00+03	2017-07-24 19:55:00+03	LED	DME	Arrived	321	2017-07-24 19:03:00+03	2017-07-24 19:58:00+03
8054	PG0407	2017-07-24 12:10:00+03	2017-07-24 13:05:00+03	LED	DME	Arrived	321	2017-07-24 12:11:00+03	2017-07-24 13:06:00+03
8055	PG0408	2017-07-24 11:55:00+03	2017-07-24 12:50:00+03	LED	DME	Arrived	321	2017-07-24 11:56:00+03	2017-07-24 12:51:00+03
8056	PG0409	2017-07-24 14:55:00+03	2017-07-24 15:50:00+03	LED	DME	Arrived	321	2017-07-24 18:17:00+03	2017-07-24 19:13:00+03
8057	PG0408	2017-08-21 11:55:00+03	2017-08-21 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8058	PG0408	2017-09-08 11:55:00+03	2017-09-08 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8059	PG0407	2017-09-08 12:10:00+03	2017-09-08 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8060	PG0406	2017-09-08 19:00:00+03	2017-09-08 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8061	PG0406	2017-08-28 19:00:00+03	2017-08-28 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8062	PG0407	2017-08-28 12:10:00+03	2017-08-28 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8063	PG0409	2017-09-04 14:55:00+03	2017-09-04 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8064	PG0408	2017-09-04 11:55:00+03	2017-09-04 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8065	PG0407	2017-09-04 12:10:00+03	2017-09-04 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8066	PG0406	2017-09-04 19:00:00+03	2017-09-04 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8067	PG0408	2017-08-28 11:55:00+03	2017-08-28 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8068	PG0409	2017-07-20 14:55:00+03	2017-07-20 15:50:00+03	LED	DME	Arrived	321	2017-07-20 14:57:00+03	2017-07-20 15:53:00+03
8069	PG0408	2017-07-20 11:55:00+03	2017-07-20 12:50:00+03	LED	DME	Arrived	321	2017-07-20 11:57:00+03	2017-07-20 12:52:00+03
8070	PG0407	2017-07-20 12:10:00+03	2017-07-20 13:05:00+03	LED	DME	Arrived	321	2017-07-20 12:13:00+03	2017-07-20 13:08:00+03
8071	PG0406	2017-07-20 19:00:00+03	2017-07-20 19:55:00+03	LED	DME	Arrived	321	2017-07-20 19:02:00+03	2017-07-20 19:58:00+03
8072	PG0406	2017-08-31 19:00:00+03	2017-08-31 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8073	PG0408	2017-08-13 11:55:00+03	2017-08-13 12:50:00+03	LED	DME	Arrived	321	2017-08-13 11:57:00+03	2017-08-13 12:52:00+03
8074	PG0409	2017-09-11 14:55:00+03	2017-09-11 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8075	PG0409	2017-08-28 14:55:00+03	2017-08-28 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8076	PG0409	2017-07-16 14:55:00+03	2017-07-16 15:50:00+03	LED	DME	Arrived	321	2017-07-16 14:58:00+03	2017-07-16 15:53:00+03
8077	PG0408	2017-09-11 11:55:00+03	2017-09-11 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8078	PG0408	2017-07-16 11:55:00+03	2017-07-16 12:50:00+03	LED	DME	Arrived	321	2017-07-16 12:02:00+03	2017-07-16 12:57:00+03
8079	PG0407	2017-09-11 12:10:00+03	2017-09-11 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8080	PG0406	2017-09-11 19:00:00+03	2017-09-11 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8081	PG0409	2017-08-01 14:55:00+03	2017-08-01 15:50:00+03	LED	DME	Arrived	321	2017-08-01 14:57:00+03	2017-08-01 15:52:00+03
8082	PG0408	2017-08-01 11:55:00+03	2017-08-01 12:50:00+03	LED	DME	Arrived	321	2017-08-01 11:57:00+03	2017-08-01 12:52:00+03
8083	PG0407	2017-08-01 12:10:00+03	2017-08-01 13:05:00+03	LED	DME	Arrived	321	2017-08-01 12:12:00+03	2017-08-01 13:06:00+03
8084	PG0406	2017-08-01 19:00:00+03	2017-08-01 19:55:00+03	LED	DME	Arrived	321	2017-08-01 19:06:00+03	2017-08-01 20:02:00+03
8085	PG0407	2017-07-16 12:10:00+03	2017-07-16 13:05:00+03	LED	DME	Arrived	321	2017-07-16 12:14:00+03	2017-07-16 13:08:00+03
8086	PG0406	2017-07-16 19:00:00+03	2017-07-16 19:55:00+03	LED	DME	Arrived	321	2017-07-16 19:03:00+03	2017-07-16 19:58:00+03
8087	PG0406	2017-08-12 19:00:00+03	2017-08-12 19:55:00+03	LED	DME	Arrived	321	2017-08-12 19:02:00+03	2017-08-12 19:56:00+03
8088	PG0407	2017-08-12 12:10:00+03	2017-08-12 13:05:00+03	LED	DME	Arrived	321	2017-08-12 12:15:00+03	2017-08-12 13:11:00+03
8089	PG0408	2017-08-12 11:55:00+03	2017-08-12 12:50:00+03	LED	DME	Arrived	321	2017-08-12 11:58:00+03	2017-08-12 12:53:00+03
8090	PG0409	2017-08-12 14:55:00+03	2017-08-12 15:50:00+03	LED	DME	Arrived	321	2017-08-12 14:57:00+03	2017-08-12 15:52:00+03
8091	PG0406	2017-09-06 19:00:00+03	2017-09-06 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8092	PG0407	2017-09-06 12:10:00+03	2017-09-06 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8093	PG0408	2017-09-06 11:55:00+03	2017-09-06 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8094	PG0406	2017-08-05 19:00:00+03	2017-08-05 19:55:00+03	LED	DME	Arrived	321	2017-08-05 19:03:00+03	2017-08-05 19:58:00+03
8095	PG0409	2017-09-06 14:55:00+03	2017-09-06 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8096	PG0407	2017-08-05 12:10:00+03	2017-08-05 13:05:00+03	LED	DME	Arrived	321	2017-08-05 12:13:00+03	2017-08-05 13:08:00+03
8097	PG0408	2017-08-05 11:55:00+03	2017-08-05 12:50:00+03	LED	DME	Arrived	321	2017-08-05 12:02:00+03	2017-08-05 12:57:00+03
8098	PG0409	2017-08-05 14:55:00+03	2017-08-05 15:50:00+03	LED	DME	Arrived	321	2017-08-05 18:44:00+03	2017-08-05 19:39:00+03
8099	PG0409	2017-08-07 14:55:00+03	2017-08-07 15:50:00+03	LED	DME	Arrived	321	2017-08-07 14:56:00+03	2017-08-07 15:51:00+03
8100	PG0407	2017-08-07 12:10:00+03	2017-08-07 13:05:00+03	LED	DME	Arrived	321	2017-08-07 12:13:00+03	2017-08-07 13:08:00+03
8101	PG0406	2017-08-07 19:00:00+03	2017-08-07 19:55:00+03	LED	DME	Arrived	321	2017-08-07 19:05:00+03	2017-08-07 20:00:00+03
8102	PG0407	2017-08-23 12:10:00+03	2017-08-23 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8103	PG0409	2017-08-21 14:55:00+03	2017-08-21 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8104	PG0406	2017-09-03 19:00:00+03	2017-09-03 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8105	PG0407	2017-09-03 12:10:00+03	2017-09-03 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8106	PG0408	2017-09-03 11:55:00+03	2017-09-03 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8107	PG0409	2017-09-03 14:55:00+03	2017-09-03 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8108	PG0407	2017-08-13 12:10:00+03	2017-08-13 13:05:00+03	LED	DME	Arrived	321	2017-08-13 12:12:00+03	2017-08-13 13:07:00+03
8109	PG0406	2017-08-13 19:00:00+03	2017-08-13 19:55:00+03	LED	DME	Arrived	321	2017-08-13 19:03:00+03	2017-08-13 19:59:00+03
8110	PG0409	2017-08-23 14:55:00+03	2017-08-23 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8111	PG0409	2017-09-10 14:55:00+03	2017-09-10 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8112	PG0406	2017-09-09 19:00:00+03	2017-09-09 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8113	PG0407	2017-09-09 12:10:00+03	2017-09-09 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8114	PG0409	2017-07-29 14:55:00+03	2017-07-29 15:50:00+03	LED	DME	Arrived	321	2017-07-29 14:59:00+03	2017-07-29 15:55:00+03
8115	PG0408	2017-07-29 11:55:00+03	2017-07-29 12:50:00+03	LED	DME	Arrived	321	2017-07-29 11:57:00+03	2017-07-29 12:53:00+03
8116	PG0408	2017-09-09 11:55:00+03	2017-09-09 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8117	PG0409	2017-09-09 14:55:00+03	2017-09-09 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8118	PG0407	2017-07-29 12:10:00+03	2017-07-29 13:05:00+03	LED	DME	Arrived	321	2017-07-29 12:15:00+03	2017-07-29 13:10:00+03
8119	PG0406	2017-07-29 19:00:00+03	2017-07-29 19:55:00+03	LED	DME	Arrived	321	2017-07-29 19:01:00+03	2017-07-29 19:55:00+03
8120	PG0406	2017-07-19 19:00:00+03	2017-07-19 19:55:00+03	LED	DME	Arrived	321	2017-07-19 19:05:00+03	2017-07-19 20:01:00+03
8121	PG0407	2017-07-19 12:10:00+03	2017-07-19 13:05:00+03	LED	DME	Arrived	321	2017-07-19 12:13:00+03	2017-07-19 13:08:00+03
8122	PG0408	2017-07-19 11:55:00+03	2017-07-19 12:50:00+03	LED	DME	Arrived	321	2017-07-19 11:58:00+03	2017-07-19 12:52:00+03
8123	PG0409	2017-07-19 14:55:00+03	2017-07-19 15:50:00+03	LED	DME	Arrived	321	2017-07-19 15:00:00+03	2017-07-19 15:55:00+03
8124	PG0408	2017-09-10 11:55:00+03	2017-09-10 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8125	PG0409	2017-08-31 14:55:00+03	2017-08-31 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8126	PG0406	2017-07-31 19:00:00+03	2017-07-31 19:55:00+03	LED	DME	Arrived	321	2017-07-31 19:05:00+03	2017-07-31 20:00:00+03
8127	PG0407	2017-07-31 12:10:00+03	2017-07-31 13:05:00+03	LED	DME	Arrived	321	2017-07-31 12:12:00+03	2017-07-31 13:07:00+03
8128	PG0408	2017-07-31 11:55:00+03	2017-07-31 12:50:00+03	LED	DME	Arrived	321	2017-07-31 11:57:00+03	2017-07-31 12:52:00+03
8129	PG0409	2017-07-31 14:55:00+03	2017-07-31 15:50:00+03	LED	DME	Arrived	321	2017-07-31 14:58:00+03	2017-07-31 15:53:00+03
8130	PG0409	2017-08-16 14:55:00+03	2017-08-16 15:50:00+03	LED	DME	On Time	321	\N	\N
8131	PG0406	2017-08-18 19:00:00+03	2017-08-18 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8132	PG0408	2017-08-16 11:55:00+03	2017-08-16 12:50:00+03	LED	DME	On Time	321	\N	\N
8133	PG0407	2017-08-16 12:10:00+03	2017-08-16 13:05:00+03	LED	DME	On Time	321	\N	\N
8134	PG0407	2017-08-18 12:10:00+03	2017-08-18 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8135	PG0408	2017-08-18 11:55:00+03	2017-08-18 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8136	PG0409	2017-08-18 14:55:00+03	2017-08-18 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8137	PG0406	2017-08-16 19:00:00+03	2017-08-16 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8138	PG0407	2017-09-10 12:10:00+03	2017-09-10 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8139	PG0408	2017-08-23 11:55:00+03	2017-08-23 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8140	PG0409	2017-08-06 14:55:00+03	2017-08-06 15:50:00+03	LED	DME	Arrived	321	2017-08-06 14:57:00+03	2017-08-06 15:53:00+03
8141	PG0408	2017-08-06 11:55:00+03	2017-08-06 12:50:00+03	LED	DME	Arrived	321	2017-08-06 11:59:00+03	2017-08-06 12:55:00+03
8142	PG0407	2017-08-06 12:10:00+03	2017-08-06 13:05:00+03	LED	DME	Arrived	321	2017-08-06 12:14:00+03	2017-08-06 13:09:00+03
8143	PG0409	2017-08-17 14:55:00+03	2017-08-17 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8144	PG0408	2017-08-17 11:55:00+03	2017-08-17 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8145	PG0406	2017-09-14 19:00:00+03	2017-09-14 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8146	PG0406	2017-09-05 19:00:00+03	2017-09-05 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8147	PG0407	2017-09-05 12:10:00+03	2017-09-05 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8148	PG0407	2017-09-14 12:10:00+03	2017-09-14 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8149	PG0408	2017-09-05 11:55:00+03	2017-09-05 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8150	PG0409	2017-09-05 14:55:00+03	2017-09-05 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8151	PG0408	2017-09-14 11:55:00+03	2017-09-14 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8152	PG0407	2017-08-17 12:10:00+03	2017-08-17 13:05:00+03	LED	DME	Scheduled	321	\N	\N
8153	PG0406	2017-08-17 19:00:00+03	2017-08-17 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8154	PG0409	2017-09-14 14:55:00+03	2017-09-14 15:50:00+03	LED	DME	Scheduled	321	\N	\N
8155	PG0406	2017-07-26 19:00:00+03	2017-07-26 19:55:00+03	LED	DME	Arrived	321	2017-07-26 19:04:00+03	2017-07-26 19:59:00+03
8156	PG0408	2017-08-31 11:55:00+03	2017-08-31 12:50:00+03	LED	DME	Scheduled	321	\N	\N
8157	PG0406	2017-08-03 19:00:00+03	2017-08-03 19:55:00+03	LED	DME	Arrived	321	2017-08-03 19:07:00+03	2017-08-03 20:03:00+03
8158	PG0407	2017-08-03 12:10:00+03	2017-08-03 13:05:00+03	LED	DME	Arrived	321	2017-08-03 15:08:00+03	2017-08-03 16:03:00+03
8159	PG0408	2017-08-03 11:55:00+03	2017-08-03 12:50:00+03	LED	DME	Arrived	321	2017-08-03 11:59:00+03	2017-08-03 12:54:00+03
8160	PG0409	2017-08-03 14:55:00+03	2017-08-03 15:50:00+03	LED	DME	Arrived	321	2017-08-03 14:57:00+03	2017-08-03 15:52:00+03
8161	PG0406	2017-08-20 19:00:00+03	2017-08-20 19:55:00+03	LED	DME	Scheduled	321	\N	\N
8162	PG0232	2017-07-21 11:25:00+03	2017-07-21 12:15:00+03	LED	VKO	Arrived	321	2017-07-21 11:31:00+03	2017-07-21 12:21:00+03
8163	PG0231	2017-07-21 17:20:00+03	2017-07-21 18:10:00+03	LED	VKO	Arrived	321	2017-07-21 17:24:00+03	2017-07-21 18:13:00+03
8164	PG0231	2017-08-07 17:20:00+03	2017-08-07 18:10:00+03	LED	VKO	Arrived	321	2017-08-07 17:24:00+03	2017-08-07 18:14:00+03
8165	PG0230	2017-09-14 10:20:00+03	2017-09-14 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8166	PG0230	2017-07-21 10:20:00+03	2017-07-21 11:10:00+03	LED	VKO	Arrived	321	2017-07-21 10:23:00+03	2017-07-21 11:13:00+03
8167	PG0230	2017-08-13 10:20:00+03	2017-08-13 11:10:00+03	LED	VKO	Arrived	321	2017-08-13 10:25:00+03	2017-08-13 11:14:00+03
8168	PG0232	2017-08-14 11:25:00+03	2017-08-14 12:15:00+03	LED	VKO	Arrived	321	2017-08-14 11:27:00+03	2017-08-14 12:17:00+03
8169	PG0231	2017-08-14 17:20:00+03	2017-08-14 18:10:00+03	LED	VKO	Arrived	321	2017-08-14 17:23:00+03	2017-08-14 18:13:00+03
8170	PG0230	2017-07-22 10:20:00+03	2017-07-22 11:10:00+03	LED	VKO	Arrived	321	2017-07-22 10:22:00+03	2017-07-22 11:12:00+03
8171	PG0230	2017-08-07 10:20:00+03	2017-08-07 11:10:00+03	LED	VKO	Arrived	321	2017-08-07 10:23:00+03	2017-08-07 11:12:00+03
8172	PG0230	2017-08-14 10:20:00+03	2017-08-14 11:10:00+03	LED	VKO	Arrived	321	2017-08-14 10:21:00+03	2017-08-14 11:10:00+03
8173	PG0230	2017-08-04 10:20:00+03	2017-08-04 11:10:00+03	LED	VKO	Arrived	321	2017-08-04 10:24:00+03	2017-08-04 11:14:00+03
8174	PG0231	2017-07-22 17:20:00+03	2017-07-22 18:10:00+03	LED	VKO	Arrived	321	2017-07-22 17:26:00+03	2017-07-22 18:15:00+03
8175	PG0231	2017-08-04 17:20:00+03	2017-08-04 18:10:00+03	LED	VKO	Arrived	321	2017-08-04 20:14:00+03	2017-08-04 21:04:00+03
8176	PG0232	2017-07-22 11:25:00+03	2017-07-22 12:15:00+03	LED	VKO	Arrived	321	2017-07-22 11:29:00+03	2017-07-22 12:19:00+03
8177	PG0230	2017-09-03 10:20:00+03	2017-09-03 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8178	PG0231	2017-09-03 17:20:00+03	2017-09-03 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8179	PG0230	2017-08-12 10:20:00+03	2017-08-12 11:10:00+03	LED	VKO	Arrived	321	2017-08-12 10:24:00+03	2017-08-12 11:14:00+03
8180	PG0232	2017-08-04 11:25:00+03	2017-08-04 12:15:00+03	LED	VKO	Arrived	321	2017-08-04 11:29:00+03	2017-08-04 12:19:00+03
8181	PG0231	2017-08-12 17:20:00+03	2017-08-12 18:10:00+03	LED	VKO	Arrived	321	2017-08-12 17:26:00+03	2017-08-12 18:16:00+03
8182	PG0232	2017-08-12 11:25:00+03	2017-08-12 12:15:00+03	LED	VKO	Arrived	321	2017-08-12 11:28:00+03	2017-08-12 12:18:00+03
8183	PG0231	2017-07-20 17:20:00+03	2017-07-20 18:10:00+03	LED	VKO	Arrived	321	2017-07-20 20:59:00+03	2017-07-20 21:49:00+03
8184	PG0230	2017-07-20 10:20:00+03	2017-07-20 11:10:00+03	LED	VKO	Arrived	321	2017-07-20 10:23:00+03	2017-07-20 11:13:00+03
8185	PG0232	2017-09-03 11:25:00+03	2017-09-03 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8186	PG0232	2017-07-27 11:25:00+03	2017-07-27 12:15:00+03	LED	VKO	Arrived	321	2017-07-27 11:28:00+03	2017-07-27 12:17:00+03
8187	PG0231	2017-07-27 17:20:00+03	2017-07-27 18:10:00+03	LED	VKO	Arrived	321	2017-07-27 17:28:00+03	2017-07-27 18:18:00+03
8188	PG0230	2017-07-27 10:20:00+03	2017-07-27 11:10:00+03	LED	VKO	Arrived	321	2017-07-27 10:24:00+03	2017-07-27 11:14:00+03
8189	PG0231	2017-08-19 17:20:00+03	2017-08-19 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8190	PG0231	2017-08-25 17:20:00+03	2017-08-25 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8191	PG0232	2017-09-02 11:25:00+03	2017-09-02 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8192	PG0230	2017-08-15 10:20:00+03	2017-08-15 11:10:00+03	LED	VKO	Arrived	321	2017-08-15 10:20:00+03	2017-08-15 11:09:00+03
8193	PG0231	2017-08-15 17:20:00+03	2017-08-15 18:10:00+03	LED	VKO	Departed	321	2017-08-15 17:25:00+03	\N
8194	PG0232	2017-08-15 11:25:00+03	2017-08-15 12:15:00+03	LED	VKO	Arrived	321	2017-08-15 11:28:00+03	2017-08-15 12:18:00+03
8195	PG0230	2017-08-21 10:20:00+03	2017-08-21 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8196	PG0231	2017-08-21 17:20:00+03	2017-08-21 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8197	PG0232	2017-08-21 11:25:00+03	2017-08-21 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8198	PG0230	2017-08-11 10:20:00+03	2017-08-11 11:10:00+03	LED	VKO	Arrived	321	2017-08-11 10:24:00+03	2017-08-11 11:14:00+03
8199	PG0231	2017-08-11 17:20:00+03	2017-08-11 18:10:00+03	LED	VKO	Arrived	321	2017-08-11 17:23:00+03	2017-08-11 18:12:00+03
8200	PG0232	2017-08-11 11:25:00+03	2017-08-11 12:15:00+03	LED	VKO	Arrived	321	2017-08-11 11:32:00+03	2017-08-11 12:22:00+03
8201	PG0230	2017-07-31 10:20:00+03	2017-07-31 11:10:00+03	LED	VKO	Arrived	321	2017-07-31 10:21:00+03	2017-07-31 11:11:00+03
8202	PG0230	2017-07-28 10:20:00+03	2017-07-28 11:10:00+03	LED	VKO	Arrived	321	2017-07-28 10:28:00+03	2017-07-28 11:17:00+03
8203	PG0230	2017-08-03 10:20:00+03	2017-08-03 11:10:00+03	LED	VKO	Arrived	321	2017-08-03 10:21:00+03	2017-08-03 11:10:00+03
8204	PG0231	2017-08-06 17:20:00+03	2017-08-06 18:10:00+03	LED	VKO	Arrived	321	2017-08-06 17:23:00+03	2017-08-06 18:13:00+03
8205	PG0230	2017-07-17 10:20:00+03	2017-07-17 11:10:00+03	LED	VKO	Arrived	321	2017-07-17 10:23:00+03	2017-07-17 11:13:00+03
8206	PG0231	2017-07-28 17:20:00+03	2017-07-28 18:10:00+03	LED	VKO	Arrived	321	2017-07-28 17:22:00+03	2017-07-28 18:12:00+03
8207	PG0232	2017-08-19 11:25:00+03	2017-08-19 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8208	PG0232	2017-07-28 11:25:00+03	2017-07-28 12:15:00+03	LED	VKO	Arrived	321	2017-07-28 11:26:00+03	2017-07-28 12:15:00+03
8209	PG0231	2017-07-17 17:20:00+03	2017-07-17 18:10:00+03	LED	VKO	Arrived	321	2017-07-17 21:14:00+03	2017-07-17 22:04:00+03
8210	PG0230	2017-07-23 10:20:00+03	2017-07-23 11:10:00+03	LED	VKO	Arrived	321	2017-07-23 10:23:00+03	2017-07-23 11:13:00+03
8211	PG0232	2017-07-17 11:25:00+03	2017-07-17 12:15:00+03	LED	VKO	Arrived	321	2017-07-17 11:31:00+03	2017-07-17 12:21:00+03
8212	PG0232	2017-08-28 11:25:00+03	2017-08-28 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8213	PG0232	2017-08-01 11:25:00+03	2017-08-01 12:15:00+03	LED	VKO	Arrived	321	2017-08-01 11:27:00+03	2017-08-01 12:18:00+03
8214	PG0232	2017-07-24 11:25:00+03	2017-07-24 12:15:00+03	LED	VKO	Arrived	321	2017-07-24 11:31:00+03	2017-07-24 12:21:00+03
8215	PG0230	2017-08-25 10:20:00+03	2017-08-25 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8216	PG0231	2017-08-01 17:20:00+03	2017-08-01 18:10:00+03	LED	VKO	Arrived	321	2017-08-01 17:23:00+03	2017-08-01 18:12:00+03
8217	PG0231	2017-09-11 17:20:00+03	2017-09-11 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8218	PG0230	2017-08-01 10:20:00+03	2017-08-01 11:10:00+03	LED	VKO	Arrived	321	2017-08-01 10:21:00+03	2017-08-01 11:11:00+03
8219	PG0231	2017-07-24 17:20:00+03	2017-07-24 18:10:00+03	LED	VKO	Arrived	321	2017-07-24 17:22:00+03	2017-07-24 18:13:00+03
8220	PG0230	2017-08-06 10:20:00+03	2017-08-06 11:10:00+03	LED	VKO	Arrived	321	2017-08-06 10:23:00+03	2017-08-06 11:13:00+03
8221	PG0230	2017-07-24 10:20:00+03	2017-07-24 11:10:00+03	LED	VKO	Arrived	321	2017-07-24 10:24:00+03	2017-07-24 11:14:00+03
8222	PG0231	2017-08-28 17:20:00+03	2017-08-28 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8223	PG0231	2017-07-23 17:20:00+03	2017-07-23 18:10:00+03	LED	VKO	Arrived	321	2017-07-23 21:05:00+03	2017-07-23 21:56:00+03
8224	PG0232	2017-08-22 11:25:00+03	2017-08-22 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8225	PG0231	2017-07-31 17:20:00+03	2017-07-31 18:10:00+03	LED	VKO	Arrived	321	2017-07-31 17:26:00+03	2017-07-31 18:17:00+03
8226	PG0230	2017-07-19 10:20:00+03	2017-07-19 11:10:00+03	LED	VKO	Arrived	321	2017-07-19 10:20:00+03	2017-07-19 11:10:00+03
8227	PG0231	2017-09-02 17:20:00+03	2017-09-02 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8228	PG0231	2017-08-22 17:20:00+03	2017-08-22 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8229	PG0231	2017-08-24 17:20:00+03	2017-08-24 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8230	PG0231	2017-08-26 17:20:00+03	2017-08-26 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8231	PG0230	2017-08-09 10:20:00+03	2017-08-09 11:10:00+03	LED	VKO	Arrived	321	2017-08-09 10:22:00+03	2017-08-09 11:12:00+03
8232	PG0230	2017-08-22 10:20:00+03	2017-08-22 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8233	PG0230	2017-08-19 10:20:00+03	2017-08-19 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8234	PG0232	2017-08-02 11:25:00+03	2017-08-02 12:15:00+03	LED	VKO	Arrived	321	2017-08-02 11:27:00+03	2017-08-02 12:17:00+03
8235	PG0231	2017-08-02 17:20:00+03	2017-08-02 18:10:00+03	LED	VKO	Arrived	321	2017-08-02 17:26:00+03	2017-08-02 18:16:00+03
8236	PG0230	2017-08-02 10:20:00+03	2017-08-02 11:10:00+03	LED	VKO	Arrived	321	2017-08-02 10:21:00+03	2017-08-02 11:11:00+03
8237	PG0232	2017-08-03 11:25:00+03	2017-08-03 12:15:00+03	LED	VKO	Arrived	321	2017-08-03 11:27:00+03	2017-08-03 12:17:00+03
8238	PG0232	2017-08-24 11:25:00+03	2017-08-24 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8239	PG0230	2017-07-29 10:20:00+03	2017-07-29 11:10:00+03	LED	VKO	Arrived	321	2017-07-29 10:27:00+03	2017-07-29 11:18:00+03
8240	PG0231	2017-08-29 17:20:00+03	2017-08-29 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8241	PG0231	2017-08-09 17:20:00+03	2017-08-09 18:10:00+03	LED	VKO	Arrived	321	2017-08-09 17:20:00+03	2017-08-09 18:10:00+03
8242	PG0232	2017-08-09 11:25:00+03	2017-08-09 12:15:00+03	LED	VKO	Arrived	321	2017-08-09 11:27:00+03	2017-08-09 12:17:00+03
8243	PG0230	2017-08-28 10:20:00+03	2017-08-28 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8244	PG0232	2017-07-25 11:25:00+03	2017-07-25 12:15:00+03	LED	VKO	Arrived	321	2017-07-25 11:27:00+03	2017-07-25 12:17:00+03
8245	PG0231	2017-07-25 17:20:00+03	2017-07-25 18:10:00+03	LED	VKO	Arrived	321	2017-07-25 17:23:00+03	2017-07-25 18:13:00+03
8246	PG0230	2017-08-17 10:20:00+03	2017-08-17 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8247	PG0232	2017-07-23 11:25:00+03	2017-07-23 12:15:00+03	LED	VKO	Arrived	321	2017-07-23 11:26:00+03	2017-07-23 12:16:00+03
8248	PG0230	2017-07-25 10:20:00+03	2017-07-25 11:10:00+03	LED	VKO	Arrived	321	2017-07-25 10:23:00+03	2017-07-25 11:13:00+03
8249	PG0232	2017-08-13 11:25:00+03	2017-08-13 12:15:00+03	LED	VKO	Arrived	321	2017-08-13 11:27:00+03	2017-08-13 12:17:00+03
8250	PG0231	2017-08-10 17:20:00+03	2017-08-10 18:10:00+03	LED	VKO	Arrived	321	2017-08-10 17:25:00+03	2017-08-10 18:15:00+03
8251	PG0231	2017-07-19 17:20:00+03	2017-07-19 18:10:00+03	LED	VKO	Arrived	321	2017-07-19 17:24:00+03	2017-07-19 18:15:00+03
8252	PG0230	2017-08-31 10:20:00+03	2017-08-31 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8253	PG0231	2017-08-17 17:20:00+03	2017-08-17 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8254	PG0230	2017-08-16 10:20:00+03	2017-08-16 11:10:00+03	LED	VKO	On Time	321	\N	\N
8255	PG0231	2017-07-30 17:20:00+03	2017-07-30 18:10:00+03	LED	VKO	Arrived	321	2017-07-30 17:20:00+03	2017-07-30 18:10:00+03
8256	PG0231	2017-08-31 17:20:00+03	2017-08-31 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8257	PG0232	2017-09-13 11:25:00+03	2017-09-13 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8258	PG0231	2017-07-29 17:20:00+03	2017-07-29 18:10:00+03	LED	VKO	Arrived	321	2017-07-29 17:21:00+03	2017-07-29 18:11:00+03
8259	PG0230	2017-08-23 10:20:00+03	2017-08-23 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8260	PG0232	2017-09-01 11:25:00+03	2017-09-01 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8261	PG0231	2017-08-23 17:20:00+03	2017-08-23 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8262	PG0232	2017-08-23 11:25:00+03	2017-08-23 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8263	PG0230	2017-08-10 10:20:00+03	2017-08-10 11:10:00+03	LED	VKO	Arrived	321	2017-08-10 10:23:00+03	2017-08-10 11:14:00+03
8264	PG0232	2017-08-08 11:25:00+03	2017-08-08 12:15:00+03	LED	VKO	Arrived	321	2017-08-08 11:28:00+03	2017-08-08 12:18:00+03
8265	PG0231	2017-09-01 17:20:00+03	2017-09-01 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8266	PG0232	2017-08-31 11:25:00+03	2017-08-31 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8267	PG0230	2017-09-01 10:20:00+03	2017-09-01 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8268	PG0231	2017-09-13 17:20:00+03	2017-09-13 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8269	PG0232	2017-07-18 11:25:00+03	2017-07-18 12:15:00+03	LED	VKO	Arrived	321	2017-07-18 11:28:00+03	2017-07-18 12:18:00+03
8270	PG0230	2017-09-13 10:20:00+03	2017-09-13 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8271	PG0230	2017-09-09 10:20:00+03	2017-09-09 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8272	PG0231	2017-09-09 17:20:00+03	2017-09-09 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8273	PG0232	2017-08-17 11:25:00+03	2017-08-17 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8274	PG0232	2017-09-09 11:25:00+03	2017-09-09 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8275	PG0231	2017-08-08 17:20:00+03	2017-08-08 18:10:00+03	LED	VKO	Arrived	321	2017-08-08 17:22:00+03	2017-08-08 18:12:00+03
8276	PG0232	2017-07-29 11:25:00+03	2017-07-29 12:15:00+03	LED	VKO	Arrived	321	2017-07-29 11:28:00+03	2017-07-29 12:18:00+03
8277	PG0230	2017-08-20 10:20:00+03	2017-08-20 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8278	PG0232	2017-07-30 11:25:00+03	2017-07-30 12:15:00+03	LED	VKO	Arrived	321	2017-07-30 11:27:00+03	2017-07-30 12:17:00+03
8279	PG0231	2017-09-14 17:20:00+03	2017-09-14 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8280	PG0232	2017-08-16 11:25:00+03	2017-08-16 12:15:00+03	LED	VKO	On Time	321	\N	\N
8281	PG0231	2017-07-18 17:20:00+03	2017-07-18 18:10:00+03	LED	VKO	Arrived	321	2017-07-18 17:22:00+03	2017-07-18 18:12:00+03
8282	PG0230	2017-08-08 10:20:00+03	2017-08-08 11:10:00+03	LED	VKO	Arrived	321	2017-08-08 10:21:00+03	2017-08-08 11:11:00+03
8283	PG0232	2017-08-30 11:25:00+03	2017-08-30 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8284	PG0231	2017-08-30 17:20:00+03	2017-08-30 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8285	PG0230	2017-08-30 10:20:00+03	2017-08-30 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8286	PG0232	2017-08-27 11:25:00+03	2017-08-27 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8287	PG0230	2017-07-18 10:20:00+03	2017-07-18 11:10:00+03	LED	VKO	Arrived	321	2017-07-18 10:24:00+03	2017-07-18 11:14:00+03
8288	PG0232	2017-08-06 11:25:00+03	2017-08-06 12:15:00+03	LED	VKO	Arrived	321	2017-08-06 11:30:00+03	2017-08-06 12:21:00+03
8289	PG0230	2017-09-10 10:20:00+03	2017-09-10 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8290	PG0231	2017-08-20 17:20:00+03	2017-08-20 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8291	PG0231	2017-08-27 17:20:00+03	2017-08-27 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8292	PG0232	2017-09-14 11:25:00+03	2017-09-14 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8293	PG0230	2017-08-29 10:20:00+03	2017-08-29 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8294	PG0232	2017-09-12 11:25:00+03	2017-09-12 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8295	PG0232	2017-07-19 11:25:00+03	2017-07-19 12:15:00+03	LED	VKO	Arrived	321	2017-07-19 11:29:00+03	2017-07-19 12:19:00+03
8296	PG0231	2017-09-10 17:20:00+03	2017-09-10 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8297	PG0232	2017-09-10 11:25:00+03	2017-09-10 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8298	PG0230	2017-09-02 10:20:00+03	2017-09-02 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8299	PG0231	2017-09-12 17:20:00+03	2017-09-12 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8300	PG0230	2017-09-12 10:20:00+03	2017-09-12 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8301	PG0232	2017-07-31 11:25:00+03	2017-07-31 12:15:00+03	LED	VKO	Arrived	321	2017-07-31 11:30:00+03	2017-07-31 12:20:00+03
8302	PG0232	2017-08-26 11:25:00+03	2017-08-26 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8303	PG0230	2017-08-26 10:20:00+03	2017-08-26 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8304	PG0231	2017-08-16 17:20:00+03	2017-08-16 18:10:00+03	LED	VKO	On Time	321	\N	\N
8305	PG0231	2017-08-03 17:20:00+03	2017-08-03 18:10:00+03	LED	VKO	Arrived	321	2017-08-03 17:21:00+03	2017-08-03 18:11:00+03
8306	PG0230	2017-09-11 10:20:00+03	2017-09-11 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8307	PG0230	2017-09-06 10:20:00+03	2017-09-06 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8308	PG0230	2017-08-27 10:20:00+03	2017-08-27 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8309	PG0232	2017-09-11 11:25:00+03	2017-09-11 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8310	PG0231	2017-09-06 17:20:00+03	2017-09-06 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8311	PG0232	2017-09-04 11:25:00+03	2017-09-04 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8312	PG0232	2017-09-06 11:25:00+03	2017-09-06 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8313	PG0231	2017-09-04 17:20:00+03	2017-09-04 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8314	PG0232	2017-08-29 11:25:00+03	2017-08-29 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8315	PG0232	2017-09-07 11:25:00+03	2017-09-07 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8316	PG0232	2017-08-25 11:25:00+03	2017-08-25 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8317	PG0231	2017-09-07 17:20:00+03	2017-09-07 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8318	PG0230	2017-09-04 10:20:00+03	2017-09-04 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8319	PG0230	2017-09-07 10:20:00+03	2017-09-07 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8320	PG0232	2017-07-16 11:25:00+03	2017-07-16 12:15:00+03	LED	VKO	Arrived	321	2017-07-16 11:27:00+03	2017-07-16 12:15:00+03
8321	PG0232	2017-08-10 11:25:00+03	2017-08-10 12:15:00+03	LED	VKO	Arrived	321	2017-08-10 11:27:00+03	2017-08-10 12:17:00+03
8322	PG0231	2017-07-16 17:20:00+03	2017-07-16 18:10:00+03	LED	VKO	Arrived	321	2017-07-16 17:23:00+03	2017-07-16 18:14:00+03
8323	PG0230	2017-07-16 10:20:00+03	2017-07-16 11:10:00+03	LED	VKO	Arrived	321	2017-07-16 10:20:00+03	2017-07-16 11:10:00+03
8324	PG0230	2017-09-05 10:20:00+03	2017-09-05 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8325	PG0231	2017-08-13 17:20:00+03	2017-08-13 18:10:00+03	LED	VKO	Arrived	321	2017-08-13 17:21:00+03	2017-08-13 18:10:00+03
8326	PG0230	2017-08-05 10:20:00+03	2017-08-05 11:10:00+03	LED	VKO	Arrived	321	2017-08-05 10:25:00+03	2017-08-05 11:16:00+03
8327	PG0232	2017-09-08 11:25:00+03	2017-09-08 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8328	PG0231	2017-08-05 17:20:00+03	2017-08-05 18:10:00+03	LED	VKO	Arrived	321	2017-08-05 17:22:00+03	2017-08-05 18:12:00+03
8329	PG0231	2017-09-08 17:20:00+03	2017-09-08 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8330	PG0232	2017-08-05 11:25:00+03	2017-08-05 12:15:00+03	LED	VKO	Arrived	321	2017-08-05 11:26:00+03	2017-08-05 12:16:00+03
8331	PG0231	2017-09-05 17:20:00+03	2017-09-05 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8332	PG0232	2017-08-20 11:25:00+03	2017-08-20 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8333	PG0230	2017-09-08 10:20:00+03	2017-09-08 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8334	PG0230	2017-07-26 10:20:00+03	2017-07-26 11:10:00+03	LED	VKO	Arrived	321	2017-07-26 13:28:00+03	2017-07-26 14:17:00+03
8335	PG0230	2017-07-30 10:20:00+03	2017-07-30 11:10:00+03	LED	VKO	Arrived	321	2017-07-30 10:24:00+03	2017-07-30 11:14:00+03
8336	PG0232	2017-09-05 11:25:00+03	2017-09-05 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8337	PG0232	2017-08-07 11:25:00+03	2017-08-07 12:15:00+03	LED	VKO	Arrived	321	2017-08-07 11:28:00+03	2017-08-07 12:19:00+03
8338	PG0232	2017-07-20 11:25:00+03	2017-07-20 12:15:00+03	LED	VKO	Arrived	321	2017-07-20 11:28:00+03	2017-07-20 12:18:00+03
8339	PG0230	2017-08-24 10:20:00+03	2017-08-24 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8340	PG0231	2017-07-26 17:20:00+03	2017-07-26 18:10:00+03	LED	VKO	Arrived	321	2017-07-26 17:21:00+03	2017-07-26 18:11:00+03
8341	PG0232	2017-07-26 11:25:00+03	2017-07-26 12:15:00+03	LED	VKO	Arrived	321	2017-07-26 11:29:00+03	2017-07-26 12:19:00+03
8342	PG0230	2017-08-18 10:20:00+03	2017-08-18 11:10:00+03	LED	VKO	Scheduled	321	\N	\N
8343	PG0231	2017-08-18 17:20:00+03	2017-08-18 18:10:00+03	LED	VKO	Scheduled	321	\N	\N
8344	PG0232	2017-08-18 11:25:00+03	2017-08-18 12:15:00+03	LED	VKO	Scheduled	321	\N	\N
8345	PG0477	2017-09-09 18:20:00+03	2017-09-09 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8346	PG0474	2017-08-27 15:40:00+03	2017-08-27 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8347	PG0476	2017-09-09 09:45:00+03	2017-09-09 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8348	PG0475	2017-09-09 13:15:00+03	2017-09-09 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8349	PG0474	2017-09-09 15:40:00+03	2017-09-09 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8350	PG0475	2017-08-27 13:15:00+03	2017-08-27 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8351	PG0473	2017-09-09 10:00:00+03	2017-09-09 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8352	PG0476	2017-08-27 09:45:00+03	2017-08-27 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8353	PG0477	2017-08-27 18:20:00+03	2017-08-27 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8354	PG0473	2017-07-26 10:00:00+03	2017-07-26 10:50:00+03	LED	SVO	Arrived	321	2017-07-26 10:04:00+03	2017-07-26 10:54:00+03
8355	PG0474	2017-07-26 15:40:00+03	2017-07-26 16:30:00+03	LED	SVO	Arrived	321	2017-07-26 15:42:00+03	2017-07-26 16:33:00+03
8356	PG0475	2017-07-26 13:15:00+03	2017-07-26 14:05:00+03	LED	SVO	Arrived	321	2017-07-26 13:18:00+03	2017-07-26 14:08:00+03
8357	PG0476	2017-07-26 09:45:00+03	2017-07-26 10:35:00+03	LED	SVO	Arrived	321	2017-07-26 09:48:00+03	2017-07-26 10:38:00+03
8358	PG0477	2017-07-26 18:20:00+03	2017-07-26 19:10:00+03	LED	SVO	Arrived	321	2017-07-26 18:22:00+03	2017-07-26 19:12:00+03
8359	PG0477	2017-08-20 18:20:00+03	2017-08-20 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8360	PG0476	2017-08-20 09:45:00+03	2017-08-20 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8361	PG0475	2017-08-20 13:15:00+03	2017-08-20 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8362	PG0474	2017-08-20 15:40:00+03	2017-08-20 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8363	PG0473	2017-08-20 10:00:00+03	2017-08-20 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8364	PG0473	2017-07-27 10:00:00+03	2017-07-27 10:50:00+03	LED	SVO	Arrived	321	2017-07-27 10:06:00+03	2017-07-27 10:55:00+03
8365	PG0474	2017-07-27 15:40:00+03	2017-07-27 16:30:00+03	LED	SVO	Arrived	321	2017-07-27 15:46:00+03	2017-07-27 16:37:00+03
8366	PG0475	2017-07-27 13:15:00+03	2017-07-27 14:05:00+03	LED	SVO	Arrived	321	2017-07-27 13:17:00+03	2017-07-27 14:07:00+03
8367	PG0476	2017-07-27 09:45:00+03	2017-07-27 10:35:00+03	LED	SVO	Arrived	321	2017-07-27 09:50:00+03	2017-07-27 10:39:00+03
8368	PG0477	2017-07-27 18:20:00+03	2017-07-27 19:10:00+03	LED	SVO	Arrived	321	2017-07-27 18:25:00+03	2017-07-27 19:15:00+03
8369	PG0477	2017-07-25 18:20:00+03	2017-07-25 19:10:00+03	LED	SVO	Arrived	321	2017-07-25 18:21:00+03	2017-07-25 19:11:00+03
8370	PG0476	2017-07-25 09:45:00+03	2017-07-25 10:35:00+03	LED	SVO	Arrived	321	2017-07-25 09:47:00+03	2017-07-25 10:38:00+03
8371	PG0475	2017-07-25 13:15:00+03	2017-07-25 14:05:00+03	LED	SVO	Arrived	321	2017-07-25 13:19:00+03	2017-07-25 14:09:00+03
8372	PG0474	2017-07-25 15:40:00+03	2017-07-25 16:30:00+03	LED	SVO	Arrived	321	2017-07-25 15:44:00+03	2017-07-25 16:35:00+03
8373	PG0473	2017-07-25 10:00:00+03	2017-07-25 10:50:00+03	LED	SVO	Arrived	321	2017-07-25 10:05:00+03	2017-07-25 10:54:00+03
8374	PG0477	2017-09-08 18:20:00+03	2017-09-08 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8375	PG0476	2017-09-08 09:45:00+03	2017-09-08 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8376	PG0475	2017-09-08 13:15:00+03	2017-09-08 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8377	PG0474	2017-09-08 15:40:00+03	2017-09-08 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8378	PG0473	2017-09-08 10:00:00+03	2017-09-08 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8379	PG0473	2017-07-28 10:00:00+03	2017-07-28 10:50:00+03	LED	SVO	Arrived	321	2017-07-28 10:02:00+03	2017-07-28 10:53:00+03
8380	PG0474	2017-07-28 15:40:00+03	2017-07-28 16:30:00+03	LED	SVO	Arrived	321	2017-07-28 15:43:00+03	2017-07-28 16:33:00+03
8381	PG0475	2017-07-28 13:15:00+03	2017-07-28 14:05:00+03	LED	SVO	Arrived	321	2017-07-28 13:17:00+03	2017-07-28 14:07:00+03
8382	PG0476	2017-07-28 09:45:00+03	2017-07-28 10:35:00+03	LED	SVO	Arrived	321	2017-07-28 09:48:00+03	2017-07-28 10:38:00+03
8383	PG0477	2017-07-28 18:20:00+03	2017-07-28 19:10:00+03	LED	SVO	Arrived	321	2017-07-28 18:23:00+03	2017-07-28 19:14:00+03
8384	PG0477	2017-07-24 18:20:00+03	2017-07-24 19:10:00+03	LED	SVO	Arrived	321	2017-07-24 18:25:00+03	2017-07-24 19:15:00+03
8385	PG0476	2017-07-24 09:45:00+03	2017-07-24 10:35:00+03	LED	SVO	Arrived	321	2017-07-24 09:50:00+03	2017-07-24 10:39:00+03
8386	PG0475	2017-07-24 13:15:00+03	2017-07-24 14:05:00+03	LED	SVO	Arrived	321	2017-07-24 13:16:00+03	2017-07-24 14:06:00+03
8387	PG0474	2017-07-24 15:40:00+03	2017-07-24 16:30:00+03	LED	SVO	Arrived	321	2017-07-24 15:42:00+03	2017-07-24 16:32:00+03
8388	PG0473	2017-07-24 10:00:00+03	2017-07-24 10:50:00+03	LED	SVO	Arrived	321	2017-07-24 10:05:00+03	2017-07-24 10:55:00+03
8389	PG0473	2017-09-10 10:00:00+03	2017-09-10 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8390	PG0477	2017-08-19 18:20:00+03	2017-08-19 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8391	PG0474	2017-09-10 15:40:00+03	2017-09-10 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8392	PG0476	2017-08-19 09:45:00+03	2017-08-19 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8393	PG0475	2017-09-10 13:15:00+03	2017-09-10 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8394	PG0475	2017-08-19 13:15:00+03	2017-08-19 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8395	PG0474	2017-08-19 15:40:00+03	2017-08-19 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8396	PG0473	2017-08-19 10:00:00+03	2017-08-19 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8397	PG0476	2017-09-10 09:45:00+03	2017-09-10 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8398	PG0477	2017-09-10 18:20:00+03	2017-09-10 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8399	PG0473	2017-07-29 10:00:00+03	2017-07-29 10:50:00+03	LED	SVO	Arrived	321	2017-07-29 10:01:00+03	2017-07-29 10:51:00+03
8400	PG0474	2017-07-29 15:40:00+03	2017-07-29 16:30:00+03	LED	SVO	Arrived	321	2017-07-29 15:44:00+03	2017-07-29 16:34:00+03
8401	PG0475	2017-07-29 13:15:00+03	2017-07-29 14:05:00+03	LED	SVO	Arrived	321	2017-07-29 13:15:00+03	2017-07-29 14:05:00+03
8402	PG0476	2017-07-29 09:45:00+03	2017-07-29 10:35:00+03	LED	SVO	Arrived	321	2017-07-29 09:50:00+03	2017-07-29 10:40:00+03
8403	PG0477	2017-07-29 18:20:00+03	2017-07-29 19:10:00+03	LED	SVO	Arrived	321	2017-07-29 18:24:00+03	2017-07-29 19:13:00+03
8404	PG0473	2017-08-21 10:00:00+03	2017-08-21 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8405	PG0474	2017-08-21 15:40:00+03	2017-08-21 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8406	PG0475	2017-08-21 13:15:00+03	2017-08-21 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8407	PG0476	2017-08-21 09:45:00+03	2017-08-21 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8408	PG0477	2017-08-21 18:20:00+03	2017-08-21 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8409	PG0477	2017-09-07 18:20:00+03	2017-09-07 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8410	PG0476	2017-09-07 09:45:00+03	2017-09-07 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8411	PG0475	2017-09-07 13:15:00+03	2017-09-07 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8412	PG0474	2017-09-07 15:40:00+03	2017-09-07 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8413	PG0473	2017-09-07 10:00:00+03	2017-09-07 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8414	PG0473	2017-07-30 10:00:00+03	2017-07-30 10:50:00+03	LED	SVO	Arrived	321	2017-07-30 10:02:00+03	2017-07-30 10:53:00+03
8415	PG0474	2017-07-30 15:40:00+03	2017-07-30 16:30:00+03	LED	SVO	Arrived	321	2017-07-30 15:41:00+03	2017-07-30 16:30:00+03
8416	PG0475	2017-07-30 13:15:00+03	2017-07-30 14:05:00+03	LED	SVO	Arrived	321	2017-07-30 13:19:00+03	2017-07-30 14:08:00+03
8417	PG0476	2017-07-30 09:45:00+03	2017-07-30 10:35:00+03	LED	SVO	Arrived	321	2017-07-30 09:50:00+03	2017-07-30 10:40:00+03
8418	PG0477	2017-07-30 18:20:00+03	2017-07-30 19:10:00+03	LED	SVO	Arrived	321	2017-07-30 18:24:00+03	2017-07-30 19:15:00+03
8419	PG0477	2017-07-23 18:20:00+03	2017-07-23 19:10:00+03	LED	SVO	Arrived	321	2017-07-23 18:23:00+03	2017-07-23 19:13:00+03
8420	PG0476	2017-07-23 09:45:00+03	2017-07-23 10:35:00+03	LED	SVO	Arrived	321	2017-07-23 09:51:00+03	2017-07-23 10:40:00+03
8421	PG0475	2017-07-23 13:15:00+03	2017-07-23 14:05:00+03	LED	SVO	Arrived	321	2017-07-23 13:18:00+03	2017-07-23 14:09:00+03
8422	PG0474	2017-07-23 15:40:00+03	2017-07-23 16:30:00+03	LED	SVO	Arrived	321	2017-07-23 15:44:00+03	2017-07-23 16:34:00+03
8423	PG0473	2017-07-23 10:00:00+03	2017-07-23 10:50:00+03	LED	SVO	Arrived	321	2017-07-23 13:43:00+03	2017-07-23 14:33:00+03
8424	PG0473	2017-08-28 10:00:00+03	2017-08-28 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8425	PG0474	2017-08-28 15:40:00+03	2017-08-28 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8426	PG0475	2017-08-28 13:15:00+03	2017-08-28 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8427	PG0476	2017-08-28 09:45:00+03	2017-08-28 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8428	PG0477	2017-08-28 18:20:00+03	2017-08-28 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8429	PG0473	2017-07-31 10:00:00+03	2017-07-31 10:50:00+03	LED	SVO	Arrived	321	2017-07-31 10:05:00+03	2017-07-31 10:55:00+03
8430	PG0474	2017-07-31 15:40:00+03	2017-07-31 16:30:00+03	LED	SVO	Arrived	321	2017-07-31 15:42:00+03	2017-07-31 16:32:00+03
8431	PG0475	2017-07-31 13:15:00+03	2017-07-31 14:05:00+03	LED	SVO	Arrived	321	2017-07-31 13:18:00+03	2017-07-31 14:08:00+03
8432	PG0476	2017-07-31 09:45:00+03	2017-07-31 10:35:00+03	LED	SVO	Arrived	321	2017-07-31 09:47:00+03	2017-07-31 10:37:00+03
8433	PG0477	2017-07-31 18:20:00+03	2017-07-31 19:10:00+03	LED	SVO	Arrived	321	2017-07-31 18:21:00+03	2017-07-31 19:10:00+03
8434	PG0477	2017-08-18 18:20:00+03	2017-08-18 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8435	PG0476	2017-08-18 09:45:00+03	2017-08-18 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8436	PG0475	2017-08-18 13:15:00+03	2017-08-18 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8437	PG0474	2017-08-18 15:40:00+03	2017-08-18 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8438	PG0473	2017-08-18 10:00:00+03	2017-08-18 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8439	PG0477	2017-09-06 18:20:00+03	2017-09-06 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8440	PG0476	2017-09-06 09:45:00+03	2017-09-06 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8441	PG0475	2017-09-06 13:15:00+03	2017-09-06 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8442	PG0474	2017-09-06 15:40:00+03	2017-09-06 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8443	PG0473	2017-09-06 10:00:00+03	2017-09-06 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8444	PG0473	2017-08-01 10:00:00+03	2017-08-01 10:50:00+03	LED	SVO	Arrived	321	2017-08-01 10:03:00+03	2017-08-01 10:53:00+03
8445	PG0474	2017-08-01 15:40:00+03	2017-08-01 16:30:00+03	LED	SVO	Arrived	321	2017-08-01 15:43:00+03	2017-08-01 16:33:00+03
8446	PG0475	2017-08-01 13:15:00+03	2017-08-01 14:05:00+03	LED	SVO	Arrived	321	2017-08-01 13:18:00+03	2017-08-01 14:09:00+03
8447	PG0476	2017-08-01 09:45:00+03	2017-08-01 10:35:00+03	LED	SVO	Arrived	321	2017-08-01 09:49:00+03	2017-08-01 10:39:00+03
8448	PG0477	2017-08-01 18:20:00+03	2017-08-01 19:10:00+03	LED	SVO	Arrived	321	2017-08-01 18:21:00+03	2017-08-01 19:11:00+03
8449	PG0473	2017-09-11 10:00:00+03	2017-09-11 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8450	PG0474	2017-09-11 15:40:00+03	2017-09-11 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8451	PG0475	2017-09-11 13:15:00+03	2017-09-11 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8452	PG0476	2017-09-11 09:45:00+03	2017-09-11 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8453	PG0477	2017-09-11 18:20:00+03	2017-09-11 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8454	PG0477	2017-07-22 18:20:00+03	2017-07-22 19:10:00+03	LED	SVO	Arrived	321	2017-07-22 18:25:00+03	2017-07-22 19:15:00+03
8455	PG0476	2017-07-22 09:45:00+03	2017-07-22 10:35:00+03	LED	SVO	Arrived	321	2017-07-22 09:47:00+03	2017-07-22 10:37:00+03
8456	PG0475	2017-07-22 13:15:00+03	2017-07-22 14:05:00+03	LED	SVO	Arrived	321	2017-07-22 13:17:00+03	2017-07-22 14:07:00+03
8457	PG0474	2017-07-22 15:40:00+03	2017-07-22 16:30:00+03	LED	SVO	Arrived	321	2017-07-22 15:41:00+03	2017-07-22 16:31:00+03
8458	PG0473	2017-07-22 10:00:00+03	2017-07-22 10:50:00+03	LED	SVO	Arrived	321	2017-07-22 10:03:00+03	2017-07-22 10:54:00+03
8459	PG0473	2017-08-02 10:00:00+03	2017-08-02 10:50:00+03	LED	SVO	Arrived	321	2017-08-02 10:08:00+03	2017-08-02 10:58:00+03
8460	PG0474	2017-08-02 15:40:00+03	2017-08-02 16:30:00+03	LED	SVO	Arrived	321	2017-08-02 15:43:00+03	2017-08-02 16:33:00+03
8461	PG0475	2017-08-02 13:15:00+03	2017-08-02 14:05:00+03	LED	SVO	Arrived	321	2017-08-02 13:19:00+03	2017-08-02 14:09:00+03
8462	PG0476	2017-08-02 09:45:00+03	2017-08-02 10:35:00+03	LED	SVO	Arrived	321	2017-08-02 13:17:00+03	2017-08-02 14:07:00+03
8463	PG0477	2017-08-02 18:20:00+03	2017-08-02 19:10:00+03	LED	SVO	Arrived	321	2017-08-02 18:22:00+03	2017-08-02 19:12:00+03
8464	PG0473	2017-08-22 10:00:00+03	2017-08-22 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8465	PG0474	2017-08-22 15:40:00+03	2017-08-22 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8466	PG0475	2017-08-22 13:15:00+03	2017-08-22 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8467	PG0476	2017-08-22 09:45:00+03	2017-08-22 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8468	PG0477	2017-08-22 18:20:00+03	2017-08-22 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8469	PG0477	2017-08-17 18:20:00+03	2017-08-17 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8470	PG0476	2017-08-17 09:45:00+03	2017-08-17 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8471	PG0475	2017-08-17 13:15:00+03	2017-08-17 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8472	PG0474	2017-08-17 15:40:00+03	2017-08-17 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8473	PG0473	2017-08-17 10:00:00+03	2017-08-17 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8474	PG0477	2017-09-05 18:20:00+03	2017-09-05 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8475	PG0476	2017-09-05 09:45:00+03	2017-09-05 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8476	PG0475	2017-09-05 13:15:00+03	2017-09-05 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8477	PG0474	2017-09-05 15:40:00+03	2017-09-05 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8478	PG0473	2017-09-05 10:00:00+03	2017-09-05 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8479	PG0477	2017-08-26 18:20:00+03	2017-08-26 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8480	PG0476	2017-08-26 09:45:00+03	2017-08-26 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8481	PG0475	2017-08-26 13:15:00+03	2017-08-26 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8482	PG0474	2017-08-26 15:40:00+03	2017-08-26 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8483	PG0473	2017-08-26 10:00:00+03	2017-08-26 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8484	PG0473	2017-08-03 10:00:00+03	2017-08-03 10:50:00+03	LED	SVO	Arrived	321	2017-08-03 10:05:00+03	2017-08-03 10:55:00+03
8485	PG0474	2017-08-03 15:40:00+03	2017-08-03 16:30:00+03	LED	SVO	Arrived	321	2017-08-03 15:43:00+03	2017-08-03 16:33:00+03
8486	PG0475	2017-08-03 13:15:00+03	2017-08-03 14:05:00+03	LED	SVO	Arrived	321	2017-08-03 13:18:00+03	2017-08-03 14:07:00+03
8487	PG0476	2017-08-03 09:45:00+03	2017-08-03 10:35:00+03	LED	SVO	Arrived	321	2017-08-03 09:49:00+03	2017-08-03 10:40:00+03
8488	PG0477	2017-08-03 18:20:00+03	2017-08-03 19:10:00+03	LED	SVO	Arrived	321	2017-08-03 18:23:00+03	2017-08-03 19:13:00+03
8489	PG0477	2017-07-21 18:20:00+03	2017-07-21 19:10:00+03	LED	SVO	Arrived	321	2017-07-21 18:22:00+03	2017-07-21 19:13:00+03
8490	PG0476	2017-07-21 09:45:00+03	2017-07-21 10:35:00+03	LED	SVO	Arrived	321	2017-07-21 09:47:00+03	2017-07-21 10:37:00+03
8491	PG0475	2017-07-21 13:15:00+03	2017-07-21 14:05:00+03	LED	SVO	Arrived	321	2017-07-21 13:17:00+03	2017-07-21 14:08:00+03
8492	PG0474	2017-07-21 15:40:00+03	2017-07-21 16:30:00+03	LED	SVO	Arrived	321	2017-07-21 15:43:00+03	2017-07-21 16:34:00+03
8493	PG0473	2017-07-21 10:00:00+03	2017-07-21 10:50:00+03	LED	SVO	Arrived	321	2017-07-21 10:07:00+03	2017-07-21 10:58:00+03
8494	PG0473	2017-08-04 10:00:00+03	2017-08-04 10:50:00+03	LED	SVO	Arrived	321	2017-08-04 10:01:00+03	2017-08-04 10:52:00+03
8495	PG0474	2017-08-04 15:40:00+03	2017-08-04 16:30:00+03	LED	SVO	Arrived	321	2017-08-04 15:42:00+03	2017-08-04 16:32:00+03
8496	PG0475	2017-08-04 13:15:00+03	2017-08-04 14:05:00+03	LED	SVO	Arrived	321	2017-08-04 13:17:00+03	2017-08-04 14:06:00+03
8497	PG0476	2017-08-04 09:45:00+03	2017-08-04 10:35:00+03	LED	SVO	Arrived	321	2017-08-04 09:48:00+03	2017-08-04 10:38:00+03
8498	PG0477	2017-08-04 18:20:00+03	2017-08-04 19:10:00+03	LED	SVO	Arrived	321	2017-08-04 18:23:00+03	2017-08-04 19:13:00+03
8499	PG0473	2017-09-12 10:00:00+03	2017-09-12 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8500	PG0474	2017-09-12 15:40:00+03	2017-09-12 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8501	PG0475	2017-09-12 13:15:00+03	2017-09-12 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8502	PG0476	2017-09-12 09:45:00+03	2017-09-12 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8503	PG0477	2017-09-12 18:20:00+03	2017-09-12 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8504	PG0473	2017-08-29 10:00:00+03	2017-08-29 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8505	PG0474	2017-08-29 15:40:00+03	2017-08-29 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8506	PG0475	2017-08-29 13:15:00+03	2017-08-29 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8507	PG0476	2017-08-29 09:45:00+03	2017-08-29 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8508	PG0477	2017-08-29 18:20:00+03	2017-08-29 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8509	PG0477	2017-09-04 18:20:00+03	2017-09-04 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8510	PG0476	2017-09-04 09:45:00+03	2017-09-04 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8511	PG0475	2017-09-04 13:15:00+03	2017-09-04 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8512	PG0474	2017-09-04 15:40:00+03	2017-09-04 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8513	PG0473	2017-09-04 10:00:00+03	2017-09-04 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8514	PG0477	2017-07-20 18:20:00+03	2017-07-20 19:10:00+03	LED	SVO	Arrived	321	2017-07-20 18:21:00+03	2017-07-20 19:10:00+03
8515	PG0476	2017-07-20 09:45:00+03	2017-07-20 10:35:00+03	LED	SVO	Arrived	321	2017-07-20 09:50:00+03	2017-07-20 10:40:00+03
8516	PG0475	2017-07-20 13:15:00+03	2017-07-20 14:05:00+03	LED	SVO	Arrived	321	2017-07-20 13:18:00+03	2017-07-20 14:08:00+03
8517	PG0474	2017-07-20 15:40:00+03	2017-07-20 16:30:00+03	LED	SVO	Arrived	321	2017-07-20 15:44:00+03	2017-07-20 16:34:00+03
8518	PG0473	2017-07-20 10:00:00+03	2017-07-20 10:50:00+03	LED	SVO	Arrived	321	2017-07-20 10:03:00+03	2017-07-20 10:53:00+03
8519	PG0473	2017-08-05 10:00:00+03	2017-08-05 10:50:00+03	LED	SVO	Arrived	321	2017-08-05 10:05:00+03	2017-08-05 10:55:00+03
8520	PG0474	2017-08-05 15:40:00+03	2017-08-05 16:30:00+03	LED	SVO	Arrived	321	2017-08-05 15:42:00+03	2017-08-05 16:33:00+03
8521	PG0475	2017-08-05 13:15:00+03	2017-08-05 14:05:00+03	LED	SVO	Arrived	321	2017-08-05 13:17:00+03	2017-08-05 14:07:00+03
8522	PG0476	2017-08-05 09:45:00+03	2017-08-05 10:35:00+03	LED	SVO	Arrived	321	2017-08-05 09:45:00+03	2017-08-05 10:35:00+03
8523	PG0477	2017-08-05 18:20:00+03	2017-08-05 19:10:00+03	LED	SVO	Arrived	321	2017-08-05 18:24:00+03	2017-08-05 19:15:00+03
8524	PG0477	2017-08-16 18:20:00+03	2017-08-16 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8525	PG0476	2017-08-16 09:45:00+03	2017-08-16 10:35:00+03	LED	SVO	On Time	321	\N	\N
8526	PG0475	2017-08-16 13:15:00+03	2017-08-16 14:05:00+03	LED	SVO	On Time	321	\N	\N
8527	PG0474	2017-08-16 15:40:00+03	2017-08-16 16:30:00+03	LED	SVO	On Time	321	\N	\N
8528	PG0473	2017-08-16 10:00:00+03	2017-08-16 10:50:00+03	LED	SVO	On Time	321	\N	\N
8529	PG0473	2017-08-06 10:00:00+03	2017-08-06 10:50:00+03	LED	SVO	Arrived	321	2017-08-06 10:07:00+03	2017-08-06 10:58:00+03
8530	PG0474	2017-08-06 15:40:00+03	2017-08-06 16:30:00+03	LED	SVO	Arrived	321	2017-08-06 15:44:00+03	2017-08-06 16:35:00+03
8531	PG0475	2017-08-06 13:15:00+03	2017-08-06 14:05:00+03	LED	SVO	Arrived	321	2017-08-06 13:17:00+03	2017-08-06 14:07:00+03
8532	PG0476	2017-08-06 09:45:00+03	2017-08-06 10:35:00+03	LED	SVO	Arrived	321	2017-08-06 09:49:00+03	2017-08-06 10:39:00+03
8533	PG0477	2017-08-06 18:20:00+03	2017-08-06 19:10:00+03	LED	SVO	Arrived	321	2017-08-06 18:23:00+03	2017-08-06 19:13:00+03
8534	PG0473	2017-08-23 10:00:00+03	2017-08-23 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8535	PG0474	2017-08-23 15:40:00+03	2017-08-23 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8536	PG0475	2017-08-23 13:15:00+03	2017-08-23 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8537	PG0476	2017-08-23 09:45:00+03	2017-08-23 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8538	PG0477	2017-08-23 18:20:00+03	2017-08-23 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8539	PG0477	2017-07-19 18:20:00+03	2017-07-19 19:10:00+03	LED	SVO	Arrived	321	2017-07-19 18:22:00+03	2017-07-19 19:12:00+03
8540	PG0476	2017-07-19 09:45:00+03	2017-07-19 10:35:00+03	LED	SVO	Arrived	321	2017-07-19 09:49:00+03	2017-07-19 10:39:00+03
8541	PG0475	2017-07-19 13:15:00+03	2017-07-19 14:05:00+03	LED	SVO	Arrived	321	2017-07-19 13:21:00+03	2017-07-19 14:12:00+03
8542	PG0474	2017-07-19 15:40:00+03	2017-07-19 16:30:00+03	LED	SVO	Arrived	321	2017-07-19 15:44:00+03	2017-07-19 16:34:00+03
8543	PG0473	2017-07-19 10:00:00+03	2017-07-19 10:50:00+03	LED	SVO	Arrived	321	2017-07-19 13:32:00+03	2017-07-19 14:23:00+03
8544	PG0477	2017-09-03 18:20:00+03	2017-09-03 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8545	PG0476	2017-09-03 09:45:00+03	2017-09-03 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8546	PG0475	2017-09-03 13:15:00+03	2017-09-03 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8547	PG0474	2017-09-03 15:40:00+03	2017-09-03 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8548	PG0473	2017-09-03 10:00:00+03	2017-09-03 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8549	PG0473	2017-08-07 10:00:00+03	2017-08-07 10:50:00+03	LED	SVO	Arrived	321	2017-08-07 10:01:00+03	2017-08-07 10:51:00+03
8550	PG0474	2017-08-07 15:40:00+03	2017-08-07 16:30:00+03	LED	SVO	Arrived	321	2017-08-07 15:42:00+03	2017-08-07 16:32:00+03
8551	PG0475	2017-08-07 13:15:00+03	2017-08-07 14:05:00+03	LED	SVO	Arrived	321	2017-08-07 13:17:00+03	2017-08-07 14:07:00+03
8552	PG0476	2017-08-07 09:45:00+03	2017-08-07 10:35:00+03	LED	SVO	Arrived	321	2017-08-07 09:48:00+03	2017-08-07 10:38:00+03
8553	PG0477	2017-08-07 18:20:00+03	2017-08-07 19:10:00+03	LED	SVO	Arrived	321	2017-08-07 18:24:00+03	2017-08-07 19:15:00+03
8554	PG0477	2017-08-15 18:20:00+03	2017-08-15 19:10:00+03	LED	SVO	On Time	321	\N	\N
8555	PG0476	2017-08-15 09:45:00+03	2017-08-15 10:35:00+03	LED	SVO	Arrived	321	2017-08-15 09:46:00+03	2017-08-15 10:36:00+03
8556	PG0475	2017-08-15 13:15:00+03	2017-08-15 14:05:00+03	LED	SVO	Arrived	321	2017-08-15 13:15:00+03	2017-08-15 14:05:00+03
8557	PG0474	2017-08-15 15:40:00+03	2017-08-15 16:30:00+03	LED	SVO	Arrived	321	2017-08-15 15:43:00+03	2017-08-15 16:33:00+03
8558	PG0473	2017-08-15 10:00:00+03	2017-08-15 10:50:00+03	LED	SVO	Arrived	321	2017-08-15 10:04:00+03	2017-08-15 10:54:00+03
8559	PG0473	2017-09-13 10:00:00+03	2017-09-13 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8560	PG0474	2017-09-13 15:40:00+03	2017-09-13 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8561	PG0475	2017-09-13 13:15:00+03	2017-09-13 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8562	PG0476	2017-09-13 09:45:00+03	2017-09-13 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8563	PG0477	2017-09-13 18:20:00+03	2017-09-13 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8564	PG0473	2017-08-08 10:00:00+03	2017-08-08 10:50:00+03	LED	SVO	Arrived	321	2017-08-08 10:01:00+03	2017-08-08 10:51:00+03
8565	PG0474	2017-08-08 15:40:00+03	2017-08-08 16:30:00+03	LED	SVO	Arrived	321	2017-08-08 15:43:00+03	2017-08-08 16:33:00+03
8566	PG0475	2017-08-08 13:15:00+03	2017-08-08 14:05:00+03	LED	SVO	Arrived	321	2017-08-08 13:16:00+03	2017-08-08 14:06:00+03
8567	PG0476	2017-08-08 09:45:00+03	2017-08-08 10:35:00+03	LED	SVO	Arrived	321	2017-08-08 09:49:00+03	2017-08-08 10:39:00+03
8568	PG0477	2017-08-08 18:20:00+03	2017-08-08 19:10:00+03	LED	SVO	Arrived	321	2017-08-08 18:24:00+03	2017-08-08 19:14:00+03
8569	PG0477	2017-07-18 18:20:00+03	2017-07-18 19:10:00+03	LED	SVO	Arrived	321	2017-07-18 18:22:00+03	2017-07-18 19:12:00+03
8570	PG0476	2017-07-18 09:45:00+03	2017-07-18 10:35:00+03	LED	SVO	Arrived	321	2017-07-18 09:48:00+03	2017-07-18 10:37:00+03
8571	PG0475	2017-07-18 13:15:00+03	2017-07-18 14:05:00+03	LED	SVO	Arrived	321	2017-07-18 13:15:00+03	2017-07-18 14:05:00+03
8572	PG0474	2017-07-18 15:40:00+03	2017-07-18 16:30:00+03	LED	SVO	Arrived	321	2017-07-18 15:45:00+03	2017-07-18 16:35:00+03
8573	PG0473	2017-07-18 10:00:00+03	2017-07-18 10:50:00+03	LED	SVO	Arrived	321	2017-07-18 10:01:00+03	2017-07-18 10:51:00+03
8574	PG0477	2017-09-02 18:20:00+03	2017-09-02 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8575	PG0476	2017-09-02 09:45:00+03	2017-09-02 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8576	PG0475	2017-09-02 13:15:00+03	2017-09-02 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8577	PG0474	2017-09-02 15:40:00+03	2017-09-02 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8578	PG0473	2017-09-02 10:00:00+03	2017-09-02 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8579	PG0473	2017-08-09 10:00:00+03	2017-08-09 10:50:00+03	LED	SVO	Arrived	321	2017-08-09 10:01:00+03	2017-08-09 10:50:00+03
8580	PG0474	2017-08-09 15:40:00+03	2017-08-09 16:30:00+03	LED	SVO	Arrived	321	2017-08-09 15:43:00+03	2017-08-09 16:32:00+03
8581	PG0475	2017-08-09 13:15:00+03	2017-08-09 14:05:00+03	LED	SVO	Arrived	321	2017-08-09 13:19:00+03	2017-08-09 14:09:00+03
8582	PG0476	2017-08-09 09:45:00+03	2017-08-09 10:35:00+03	LED	SVO	Arrived	321	2017-08-09 12:16:00+03	2017-08-09 13:06:00+03
8583	PG0477	2017-08-09 18:20:00+03	2017-08-09 19:10:00+03	LED	SVO	Arrived	321	2017-08-09 18:24:00+03	2017-08-09 19:14:00+03
8584	PG0473	2017-08-30 10:00:00+03	2017-08-30 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8585	PG0474	2017-08-30 15:40:00+03	2017-08-30 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8586	PG0475	2017-08-30 13:15:00+03	2017-08-30 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8587	PG0476	2017-08-30 09:45:00+03	2017-08-30 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8588	PG0477	2017-08-30 18:20:00+03	2017-08-30 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8589	PG0473	2017-09-14 10:00:00+03	2017-09-14 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8590	PG0474	2017-09-14 15:40:00+03	2017-09-14 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8591	PG0475	2017-09-14 13:15:00+03	2017-09-14 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8592	PG0476	2017-09-14 09:45:00+03	2017-09-14 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8593	PG0477	2017-09-14 18:20:00+03	2017-09-14 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8594	PG0477	2017-08-14 18:20:00+03	2017-08-14 19:10:00+03	LED	SVO	Arrived	321	2017-08-14 18:22:00+03	2017-08-14 19:12:00+03
8595	PG0476	2017-08-14 09:45:00+03	2017-08-14 10:35:00+03	LED	SVO	Arrived	321	2017-08-14 09:48:00+03	2017-08-14 10:38:00+03
8596	PG0475	2017-08-14 13:15:00+03	2017-08-14 14:05:00+03	LED	SVO	Arrived	321	2017-08-14 13:17:00+03	2017-08-14 14:08:00+03
8597	PG0474	2017-08-14 15:40:00+03	2017-08-14 16:30:00+03	LED	SVO	Arrived	321	2017-08-14 15:42:00+03	2017-08-14 16:32:00+03
8598	PG0473	2017-08-14 10:00:00+03	2017-08-14 10:50:00+03	LED	SVO	Arrived	321	2017-08-14 10:04:00+03	2017-08-14 10:54:00+03
8599	PG0477	2017-07-17 18:20:00+03	2017-07-17 19:10:00+03	LED	SVO	Arrived	321	2017-07-17 18:24:00+03	2017-07-17 19:14:00+03
8600	PG0476	2017-07-17 09:45:00+03	2017-07-17 10:35:00+03	LED	SVO	Arrived	321	2017-07-17 09:48:00+03	2017-07-17 10:38:00+03
8601	PG0475	2017-07-17 13:15:00+03	2017-07-17 14:05:00+03	LED	SVO	Arrived	321	2017-07-17 13:20:00+03	2017-07-17 14:11:00+03
8602	PG0474	2017-07-17 15:40:00+03	2017-07-17 16:30:00+03	LED	SVO	Arrived	321	2017-07-17 15:42:00+03	2017-07-17 16:32:00+03
8603	PG0473	2017-07-17 10:00:00+03	2017-07-17 10:50:00+03	LED	SVO	Arrived	321	2017-07-17 10:03:00+03	2017-07-17 10:54:00+03
8604	PG0473	2017-08-10 10:00:00+03	2017-08-10 10:50:00+03	LED	SVO	Arrived	321	2017-08-10 10:03:00+03	2017-08-10 10:54:00+03
8605	PG0474	2017-08-10 15:40:00+03	2017-08-10 16:30:00+03	LED	SVO	Arrived	321	2017-08-10 15:44:00+03	2017-08-10 16:33:00+03
8606	PG0475	2017-08-10 13:15:00+03	2017-08-10 14:05:00+03	LED	SVO	Arrived	321	2017-08-10 13:18:00+03	2017-08-10 14:08:00+03
8607	PG0476	2017-08-10 09:45:00+03	2017-08-10 10:35:00+03	LED	SVO	Arrived	321	2017-08-10 09:51:00+03	2017-08-10 10:41:00+03
8608	PG0477	2017-08-10 18:20:00+03	2017-08-10 19:10:00+03	LED	SVO	Arrived	321	2017-08-10 18:23:00+03	2017-08-10 19:14:00+03
8609	PG0477	2017-09-01 18:20:00+03	2017-09-01 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8610	PG0476	2017-09-01 09:45:00+03	2017-09-01 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8611	PG0475	2017-09-01 13:15:00+03	2017-09-01 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8612	PG0474	2017-09-01 15:40:00+03	2017-09-01 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8613	PG0473	2017-09-01 10:00:00+03	2017-09-01 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8614	PG0473	2017-08-24 10:00:00+03	2017-08-24 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8615	PG0474	2017-08-24 15:40:00+03	2017-08-24 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8616	PG0475	2017-08-24 13:15:00+03	2017-08-24 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8617	PG0476	2017-08-24 09:45:00+03	2017-08-24 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8618	PG0477	2017-08-24 18:20:00+03	2017-08-24 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8619	PG0477	2017-08-25 18:20:00+03	2017-08-25 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8620	PG0476	2017-08-25 09:45:00+03	2017-08-25 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8621	PG0475	2017-08-25 13:15:00+03	2017-08-25 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8622	PG0474	2017-08-25 15:40:00+03	2017-08-25 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8623	PG0473	2017-08-25 10:00:00+03	2017-08-25 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8624	PG0473	2017-08-11 10:00:00+03	2017-08-11 10:50:00+03	LED	SVO	Arrived	321	2017-08-11 10:00:00+03	2017-08-11 10:50:00+03
8625	PG0474	2017-08-11 15:40:00+03	2017-08-11 16:30:00+03	LED	SVO	Arrived	321	2017-08-11 15:42:00+03	2017-08-11 16:32:00+03
8626	PG0475	2017-08-11 13:15:00+03	2017-08-11 14:05:00+03	LED	SVO	Arrived	321	2017-08-11 13:19:00+03	2017-08-11 14:08:00+03
8627	PG0476	2017-08-11 09:45:00+03	2017-08-11 10:35:00+03	LED	SVO	Arrived	321	2017-08-11 09:48:00+03	2017-08-11 10:38:00+03
8628	PG0477	2017-08-11 18:20:00+03	2017-08-11 19:10:00+03	LED	SVO	Arrived	321	2017-08-11 18:23:00+03	2017-08-11 19:14:00+03
8629	PG0477	2017-07-16 18:20:00+03	2017-07-16 19:10:00+03	LED	SVO	Arrived	321	2017-07-16 18:24:00+03	2017-07-16 19:14:00+03
8630	PG0476	2017-07-16 09:45:00+03	2017-07-16 10:35:00+03	LED	SVO	Arrived	321	2017-07-16 09:48:00+03	2017-07-16 10:38:00+03
8631	PG0475	2017-07-16 13:15:00+03	2017-07-16 14:05:00+03	LED	SVO	Arrived	321	2017-07-16 13:18:00+03	2017-07-16 14:08:00+03
8632	PG0474	2017-07-16 15:40:00+03	2017-07-16 16:30:00+03	LED	SVO	Arrived	321	2017-07-16 15:42:00+03	2017-07-16 16:32:00+03
8633	PG0473	2017-07-16 10:00:00+03	2017-07-16 10:50:00+03	LED	SVO	Arrived	321	2017-07-16 10:07:00+03	2017-07-16 10:58:00+03
8634	PG0473	2017-08-12 10:00:00+03	2017-08-12 10:50:00+03	LED	SVO	Arrived	321	2017-08-12 10:06:00+03	2017-08-12 10:56:00+03
8635	PG0474	2017-08-12 15:40:00+03	2017-08-12 16:30:00+03	LED	SVO	Arrived	321	2017-08-12 15:43:00+03	2017-08-12 16:33:00+03
8636	PG0475	2017-08-12 13:15:00+03	2017-08-12 14:05:00+03	LED	SVO	Arrived	321	2017-08-12 13:18:00+03	2017-08-12 14:08:00+03
8637	PG0476	2017-08-12 09:45:00+03	2017-08-12 10:35:00+03	LED	SVO	Arrived	321	2017-08-12 09:52:00+03	2017-08-12 10:42:00+03
8638	PG0477	2017-08-12 18:20:00+03	2017-08-12 19:10:00+03	LED	SVO	Arrived	321	2017-08-12 18:20:00+03	2017-08-12 19:10:00+03
8639	PG0477	2017-08-13 18:20:00+03	2017-08-13 19:10:00+03	LED	SVO	Arrived	321	2017-08-13 18:25:00+03	2017-08-13 19:15:00+03
8640	PG0476	2017-08-13 09:45:00+03	2017-08-13 10:35:00+03	LED	SVO	Arrived	321	2017-08-13 09:49:00+03	2017-08-13 10:40:00+03
8641	PG0477	2017-08-31 18:20:00+03	2017-08-31 19:10:00+03	LED	SVO	Scheduled	321	\N	\N
8642	PG0476	2017-08-31 09:45:00+03	2017-08-31 10:35:00+03	LED	SVO	Scheduled	321	\N	\N
8643	PG0475	2017-08-31 13:15:00+03	2017-08-31 14:05:00+03	LED	SVO	Scheduled	321	\N	\N
8644	PG0474	2017-08-31 15:40:00+03	2017-08-31 16:30:00+03	LED	SVO	Scheduled	321	\N	\N
8645	PG0473	2017-08-31 10:00:00+03	2017-08-31 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8646	PG0475	2017-08-13 13:15:00+03	2017-08-13 14:05:00+03	LED	SVO	Arrived	321	2017-08-13 13:18:00+03	2017-08-13 14:08:00+03
8647	PG0474	2017-08-13 15:40:00+03	2017-08-13 16:30:00+03	LED	SVO	Arrived	321	2017-08-13 15:43:00+03	2017-08-13 16:33:00+03
8648	PG0473	2017-08-13 10:00:00+03	2017-08-13 10:50:00+03	LED	SVO	Arrived	321	2017-08-13 10:05:00+03	2017-08-13 10:55:00+03
8649	PG0473	2017-08-27 10:00:00+03	2017-08-27 10:50:00+03	LED	SVO	Scheduled	321	\N	\N
8650	PG0507	2017-07-26 17:45:00+03	2017-07-26 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-26 17:46:00+03	2017-07-26 19:27:00+03
8651	PG0507	2017-08-17 17:45:00+03	2017-08-17 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8652	PG0507	2017-08-20 17:45:00+03	2017-08-20 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8653	PG0507	2017-08-01 17:45:00+03	2017-08-01 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-01 17:47:00+03	2017-08-01 19:27:00+03
8654	PG0507	2017-08-06 17:45:00+03	2017-08-06 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-06 17:52:00+03	2017-08-06 19:32:00+03
8655	PG0507	2017-07-27 17:45:00+03	2017-07-27 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-27 17:50:00+03	2017-07-27 19:30:00+03
8656	PG0507	2017-09-13 17:45:00+03	2017-09-13 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8657	PG0507	2017-08-26 17:45:00+03	2017-08-26 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8658	PG0507	2017-09-08 17:45:00+03	2017-09-08 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8659	PG0507	2017-08-22 17:45:00+03	2017-08-22 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8660	PG0507	2017-07-29 17:45:00+03	2017-07-29 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-29 17:51:00+03	2017-07-29 19:31:00+03
8661	PG0507	2017-09-05 17:45:00+03	2017-09-05 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8662	PG0507	2017-08-30 17:45:00+03	2017-08-30 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8663	PG0507	2017-07-25 17:45:00+03	2017-07-25 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-25 17:47:00+03	2017-07-25 19:27:00+03
8664	PG0507	2017-08-28 17:45:00+03	2017-08-28 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8665	PG0507	2017-08-09 17:45:00+03	2017-08-09 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-09 17:48:00+03	2017-08-09 19:27:00+03
8666	PG0507	2017-08-29 17:45:00+03	2017-08-29 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8667	PG0507	2017-07-24 17:45:00+03	2017-07-24 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-24 17:47:00+03	2017-07-24 19:28:00+03
8668	PG0507	2017-07-21 17:45:00+03	2017-07-21 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-21 17:50:00+03	2017-07-21 19:31:00+03
8669	PG0507	2017-08-03 17:45:00+03	2017-08-03 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-03 17:51:00+03	2017-08-03 19:30:00+03
8670	PG0507	2017-09-09 17:45:00+03	2017-09-09 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8671	PG0507	2017-09-12 17:45:00+03	2017-09-12 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8672	PG0507	2017-07-18 17:45:00+03	2017-07-18 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-18 17:45:00+03	2017-07-18 19:25:00+03
8673	PG0507	2017-09-02 17:45:00+03	2017-09-02 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8674	PG0507	2017-09-07 17:45:00+03	2017-09-07 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8675	PG0507	2017-08-08 17:45:00+03	2017-08-08 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-08 17:50:00+03	2017-08-08 19:31:00+03
8676	PG0507	2017-07-16 17:45:00+03	2017-07-16 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-16 17:48:00+03	2017-07-16 19:28:00+03
8677	PG0507	2017-07-19 17:45:00+03	2017-07-19 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-19 17:47:00+03	2017-07-19 19:27:00+03
8678	PG0507	2017-09-06 17:45:00+03	2017-09-06 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8679	PG0507	2017-09-10 17:45:00+03	2017-09-10 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8680	PG0507	2017-07-20 17:45:00+03	2017-07-20 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-20 20:49:00+03	2017-07-20 22:28:00+03
8681	PG0507	2017-09-03 17:45:00+03	2017-09-03 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8682	PG0507	2017-08-12 17:45:00+03	2017-08-12 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-12 21:27:00+03	2017-08-12 23:05:00+03
8683	PG0507	2017-08-27 17:45:00+03	2017-08-27 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8684	PG0507	2017-09-01 17:45:00+03	2017-09-01 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8685	PG0507	2017-08-23 17:45:00+03	2017-08-23 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8686	PG0507	2017-09-04 17:45:00+03	2017-09-04 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8687	PG0507	2017-08-13 17:45:00+03	2017-08-13 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-13 17:47:00+03	2017-08-13 19:26:00+03
8688	PG0507	2017-07-22 17:45:00+03	2017-07-22 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-22 17:47:00+03	2017-07-22 19:27:00+03
8689	PG0507	2017-08-25 17:45:00+03	2017-08-25 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8690	PG0507	2017-07-30 17:45:00+03	2017-07-30 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-30 17:49:00+03	2017-07-30 19:29:00+03
8691	PG0507	2017-08-10 17:45:00+03	2017-08-10 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-10 17:46:00+03	2017-08-10 19:25:00+03
8692	PG0507	2017-08-02 17:45:00+03	2017-08-02 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-02 17:49:00+03	2017-08-02 19:29:00+03
8693	PG0507	2017-08-11 17:45:00+03	2017-08-11 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-11 17:49:00+03	2017-08-11 19:30:00+03
8694	PG0507	2017-08-18 17:45:00+03	2017-08-18 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8695	PG0507	2017-08-14 17:45:00+03	2017-08-14 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-14 17:49:00+03	2017-08-14 19:28:00+03
8696	PG0507	2017-08-07 17:45:00+03	2017-08-07 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-07 17:49:00+03	2017-08-07 19:28:00+03
8697	PG0507	2017-07-17 17:45:00+03	2017-07-17 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-17 17:50:00+03	2017-07-17 19:29:00+03
8698	PG0507	2017-08-04 17:45:00+03	2017-08-04 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-04 17:46:00+03	2017-08-04 19:27:00+03
8699	PG0507	2017-08-31 17:45:00+03	2017-08-31 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8700	PG0507	2017-08-05 17:45:00+03	2017-08-05 19:25:00+03	LED	KZN	Arrived	SU9	2017-08-05 17:51:00+03	2017-08-05 19:31:00+03
8701	PG0507	2017-08-19 17:45:00+03	2017-08-19 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8702	PG0507	2017-09-11 17:45:00+03	2017-09-11 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8703	PG0507	2017-07-28 17:45:00+03	2017-07-28 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-28 17:49:00+03	2017-07-28 19:31:00+03
8704	PG0507	2017-08-24 17:45:00+03	2017-08-24 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8705	PG0507	2017-08-15 17:45:00+03	2017-08-15 19:25:00+03	LED	KZN	Departed	SU9	2017-08-15 17:47:00+03	\N
8706	PG0507	2017-09-14 17:45:00+03	2017-09-14 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8707	PG0507	2017-07-31 17:45:00+03	2017-07-31 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-31 17:46:00+03	2017-07-31 19:26:00+03
8708	PG0507	2017-08-16 17:45:00+03	2017-08-16 19:25:00+03	LED	KZN	On Time	SU9	\N	\N
8709	PG0507	2017-07-23 17:45:00+03	2017-07-23 19:25:00+03	LED	KZN	Arrived	SU9	2017-07-23 17:48:00+03	2017-07-23 19:28:00+03
8710	PG0507	2017-08-21 17:45:00+03	2017-08-21 19:25:00+03	LED	KZN	Scheduled	SU9	\N	\N
8711	PG0132	2017-09-09 12:25:00+03	2017-09-09 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8712	PG0132	2017-07-31 12:25:00+03	2017-07-31 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-31 12:27:00+03	2017-07-31 13:56:00+03
8713	PG0132	2017-09-13 12:25:00+03	2017-09-13 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8714	PG0132	2017-08-13 12:25:00+03	2017-08-13 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-13 12:26:00+03	2017-08-13 13:58:00+03
8715	PG0132	2017-07-29 12:25:00+03	2017-07-29 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-29 12:29:00+03	2017-07-29 14:00:00+03
8716	PG0132	2017-08-16 12:25:00+03	2017-08-16 13:55:00+03	LED	VOZ	On Time	CR2	\N	\N
8717	PG0132	2017-08-28 12:25:00+03	2017-08-28 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8718	PG0132	2017-08-07 12:25:00+03	2017-08-07 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-07 12:26:00+03	2017-08-07 13:56:00+03
8719	PG0132	2017-07-16 12:25:00+03	2017-07-16 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-16 12:25:00+03	2017-07-16 13:54:00+03
8720	PG0132	2017-08-05 12:25:00+03	2017-08-05 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-05 12:26:00+03	2017-08-05 13:56:00+03
8721	PG0132	2017-08-30 12:25:00+03	2017-08-30 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8722	PG0132	2017-08-26 12:25:00+03	2017-08-26 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8723	PG0132	2017-08-23 12:25:00+03	2017-08-23 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8724	PG0132	2017-07-19 12:25:00+03	2017-07-19 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-19 12:28:00+03	2017-07-19 13:59:00+03
8725	PG0132	2017-08-22 12:25:00+03	2017-08-22 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8726	PG0132	2017-07-25 12:25:00+03	2017-07-25 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-25 12:26:00+03	2017-07-25 13:56:00+03
8727	PG0132	2017-08-17 12:25:00+03	2017-08-17 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8728	PG0132	2017-07-21 12:25:00+03	2017-07-21 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-21 12:31:00+03	2017-07-21 14:01:00+03
8729	PG0132	2017-09-08 12:25:00+03	2017-09-08 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8730	PG0132	2017-08-08 12:25:00+03	2017-08-08 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-08 12:27:00+03	2017-08-08 13:57:00+03
8731	PG0132	2017-09-03 12:25:00+03	2017-09-03 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8732	PG0132	2017-09-05 12:25:00+03	2017-09-05 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8733	PG0132	2017-08-04 12:25:00+03	2017-08-04 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-04 12:26:00+03	2017-08-04 13:57:00+03
8734	PG0132	2017-07-30 12:25:00+03	2017-07-30 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-30 12:29:00+03	2017-07-30 13:59:00+03
8735	PG0132	2017-08-06 12:25:00+03	2017-08-06 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-06 12:26:00+03	2017-08-06 13:55:00+03
8736	PG0132	2017-08-20 12:25:00+03	2017-08-20 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8737	PG0132	2017-08-24 12:25:00+03	2017-08-24 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8738	PG0132	2017-08-09 12:25:00+03	2017-08-09 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-09 12:28:00+03	2017-08-09 13:57:00+03
8739	PG0132	2017-07-28 12:25:00+03	2017-07-28 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-28 12:28:00+03	2017-07-28 13:58:00+03
8740	PG0132	2017-08-15 12:25:00+03	2017-08-15 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-15 12:27:00+03	2017-08-15 13:57:00+03
8741	PG0132	2017-09-14 12:25:00+03	2017-09-14 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8742	PG0132	2017-09-12 12:25:00+03	2017-09-12 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8743	PG0132	2017-09-04 12:25:00+03	2017-09-04 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8744	PG0132	2017-07-20 12:25:00+03	2017-07-20 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-20 12:29:00+03	2017-07-20 13:58:00+03
8745	PG0132	2017-07-24 12:25:00+03	2017-07-24 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-24 12:30:00+03	2017-07-24 14:01:00+03
8746	PG0132	2017-07-18 12:25:00+03	2017-07-18 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-18 12:27:00+03	2017-07-18 13:56:00+03
8747	PG0132	2017-09-10 12:25:00+03	2017-09-10 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8748	PG0132	2017-07-23 12:25:00+03	2017-07-23 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-23 15:12:00+03	2017-07-23 16:41:00+03
8749	PG0132	2017-08-03 12:25:00+03	2017-08-03 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-03 15:54:00+03	2017-08-03 17:25:00+03
8750	PG0132	2017-08-25 12:25:00+03	2017-08-25 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8751	PG0132	2017-09-02 12:25:00+03	2017-09-02 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8752	PG0132	2017-08-10 12:25:00+03	2017-08-10 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-10 12:27:00+03	2017-08-10 13:58:00+03
8753	PG0132	2017-09-11 12:25:00+03	2017-09-11 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8754	PG0132	2017-07-22 12:25:00+03	2017-07-22 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-22 12:29:00+03	2017-07-22 13:58:00+03
8755	PG0132	2017-08-01 12:25:00+03	2017-08-01 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-01 12:30:00+03	2017-08-01 14:00:00+03
8756	PG0132	2017-08-27 12:25:00+03	2017-08-27 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8757	PG0132	2017-08-29 12:25:00+03	2017-08-29 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8758	PG0132	2017-08-21 12:25:00+03	2017-08-21 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8759	PG0132	2017-08-11 12:25:00+03	2017-08-11 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-11 12:29:00+03	2017-08-11 14:00:00+03
8760	PG0132	2017-09-06 12:25:00+03	2017-09-06 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8761	PG0132	2017-08-19 12:25:00+03	2017-08-19 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8762	PG0132	2017-07-17 12:25:00+03	2017-07-17 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-17 12:28:00+03	2017-07-17 13:59:00+03
8763	PG0132	2017-08-02 12:25:00+03	2017-08-02 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-02 15:50:00+03	2017-08-02 17:20:00+03
8764	PG0132	2017-08-18 12:25:00+03	2017-08-18 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8765	PG0132	2017-08-14 12:25:00+03	2017-08-14 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-14 15:52:00+03	2017-08-14 17:22:00+03
8766	PG0132	2017-07-27 12:25:00+03	2017-07-27 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-27 12:29:00+03	2017-07-27 13:57:00+03
8767	PG0132	2017-07-26 12:25:00+03	2017-07-26 13:55:00+03	LED	VOZ	Arrived	CR2	2017-07-26 12:30:00+03	2017-07-26 14:01:00+03
8768	PG0132	2017-09-07 12:25:00+03	2017-09-07 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8769	PG0132	2017-09-01 12:25:00+03	2017-09-01 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8770	PG0132	2017-08-12 12:25:00+03	2017-08-12 13:55:00+03	LED	VOZ	Arrived	CR2	2017-08-12 12:30:00+03	2017-08-12 14:00:00+03
8771	PG0132	2017-08-31 12:25:00+03	2017-08-31 13:55:00+03	LED	VOZ	Scheduled	CR2	\N	\N
8772	PG0243	2017-08-08 20:55:00+03	2017-08-09 03:20:00+03	LED	YKS	Arrived	319	2017-08-08 20:57:00+03	2017-08-09 03:25:00+03
8773	PG0243	2017-08-04 20:55:00+03	2017-08-05 03:20:00+03	LED	YKS	Arrived	319	2017-08-04 20:59:00+03	2017-08-05 03:20:00+03
8774	PG0243	2017-08-28 20:55:00+03	2017-08-29 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8775	PG0243	2017-08-23 20:55:00+03	2017-08-24 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8776	PG0243	2017-08-06 20:55:00+03	2017-08-07 03:20:00+03	LED	YKS	Arrived	319	2017-08-06 20:55:00+03	2017-08-07 03:18:00+03
8777	PG0243	2017-09-04 20:55:00+03	2017-09-05 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8778	PG0243	2017-09-07 20:55:00+03	2017-09-08 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8779	PG0243	2017-07-20 20:55:00+03	2017-07-21 03:20:00+03	LED	YKS	Arrived	319	2017-07-20 21:00:00+03	2017-07-21 03:23:00+03
8780	PG0243	2017-09-10 20:55:00+03	2017-09-11 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8781	PG0243	2017-09-01 20:55:00+03	2017-09-02 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8782	PG0243	2017-08-10 20:55:00+03	2017-08-11 03:20:00+03	LED	YKS	Arrived	319	2017-08-10 20:59:00+03	2017-08-11 03:20:00+03
8783	PG0243	2017-09-03 20:55:00+03	2017-09-04 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8784	PG0243	2017-07-23 20:55:00+03	2017-07-24 03:20:00+03	LED	YKS	Arrived	319	2017-07-23 20:57:00+03	2017-07-24 03:30:00+03
8785	PG0243	2017-09-11 20:55:00+03	2017-09-12 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8786	PG0243	2017-07-19 20:55:00+03	2017-07-20 03:20:00+03	LED	YKS	Arrived	319	2017-07-19 20:57:00+03	2017-07-20 03:19:00+03
8787	PG0243	2017-08-07 20:55:00+03	2017-08-08 03:20:00+03	LED	YKS	Arrived	319	2017-08-07 20:55:00+03	2017-08-08 03:21:00+03
8788	PG0243	2017-08-12 20:55:00+03	2017-08-13 03:20:00+03	LED	YKS	Arrived	319	2017-08-12 20:57:00+03	2017-08-13 03:20:00+03
8789	PG0243	2017-09-14 20:55:00+03	2017-09-15 03:20:00+03	LED	YKS	Cancelled	319	\N	\N
8790	PG0243	2017-08-31 20:55:00+03	2017-09-01 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8791	PG0243	2017-07-29 20:55:00+03	2017-07-30 03:20:00+03	LED	YKS	Arrived	319	2017-07-29 21:00:00+03	2017-07-30 03:29:00+03
8792	PG0243	2017-08-27 20:55:00+03	2017-08-28 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8793	PG0243	2017-07-22 20:55:00+03	2017-07-23 03:20:00+03	LED	YKS	Arrived	319	2017-07-22 20:58:00+03	2017-07-23 03:25:00+03
8794	PG0243	2017-07-31 20:55:00+03	2017-08-01 03:20:00+03	LED	YKS	Arrived	319	2017-07-31 20:55:00+03	2017-08-01 03:23:00+03
8795	PG0243	2017-09-13 20:55:00+03	2017-09-14 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8796	PG0243	2017-07-17 20:55:00+03	2017-07-18 03:20:00+03	LED	YKS	Arrived	319	2017-07-17 20:56:00+03	2017-07-18 03:22:00+03
8797	PG0243	2017-08-14 20:55:00+03	2017-08-15 03:20:00+03	LED	YKS	Arrived	319	2017-08-14 20:59:00+03	2017-08-15 03:23:00+03
8798	PG0243	2017-08-15 20:55:00+03	2017-08-16 03:20:00+03	LED	YKS	On Time	319	\N	\N
8799	PG0243	2017-08-17 20:55:00+03	2017-08-18 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8800	PG0243	2017-09-05 20:55:00+03	2017-09-06 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8801	PG0243	2017-09-06 20:55:00+03	2017-09-07 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8802	PG0243	2017-09-12 20:55:00+03	2017-09-13 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8803	PG0243	2017-08-29 20:55:00+03	2017-08-30 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8804	PG0243	2017-08-26 20:55:00+03	2017-08-27 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8805	PG0243	2017-09-08 20:55:00+03	2017-09-09 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8806	PG0243	2017-08-01 20:55:00+03	2017-08-02 03:20:00+03	LED	YKS	Arrived	319	2017-08-01 20:59:00+03	2017-08-02 03:29:00+03
8807	PG0243	2017-07-30 20:55:00+03	2017-07-31 03:20:00+03	LED	YKS	Arrived	319	2017-07-30 20:57:00+03	2017-07-31 03:25:00+03
8808	PG0243	2017-08-19 20:55:00+03	2017-08-20 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8809	PG0243	2017-07-28 20:55:00+03	2017-07-29 03:20:00+03	LED	YKS	Arrived	319	2017-07-29 00:03:00+03	2017-07-29 06:35:00+03
8810	PG0243	2017-07-18 20:55:00+03	2017-07-19 03:20:00+03	LED	YKS	Arrived	319	2017-07-18 20:57:00+03	2017-07-19 03:13:00+03
8811	PG0243	2017-08-02 20:55:00+03	2017-08-03 03:20:00+03	LED	YKS	Arrived	319	2017-08-02 20:58:00+03	2017-08-03 03:25:00+03
8812	PG0243	2017-08-09 20:55:00+03	2017-08-10 03:20:00+03	LED	YKS	Arrived	319	2017-08-09 20:57:00+03	2017-08-10 03:21:00+03
8813	PG0243	2017-07-27 20:55:00+03	2017-07-28 03:20:00+03	LED	YKS	Arrived	319	2017-07-27 20:56:00+03	2017-07-28 03:18:00+03
8814	PG0243	2017-08-05 20:55:00+03	2017-08-06 03:20:00+03	LED	YKS	Arrived	319	2017-08-05 20:58:00+03	2017-08-06 03:22:00+03
8815	PG0243	2017-08-11 20:55:00+03	2017-08-12 03:20:00+03	LED	YKS	Arrived	319	2017-08-11 21:01:00+03	2017-08-12 03:28:00+03
8816	PG0243	2017-08-25 20:55:00+03	2017-08-26 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8817	PG0243	2017-07-16 20:55:00+03	2017-07-17 03:20:00+03	LED	YKS	Arrived	319	2017-07-16 20:59:00+03	2017-07-17 03:25:00+03
8818	PG0243	2017-09-09 20:55:00+03	2017-09-10 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8819	PG0243	2017-08-16 20:55:00+03	2017-08-17 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8820	PG0243	2017-08-03 20:55:00+03	2017-08-04 03:20:00+03	LED	YKS	Arrived	319	2017-08-03 21:00:00+03	2017-08-04 03:27:00+03
8821	PG0243	2017-07-24 20:55:00+03	2017-07-25 03:20:00+03	LED	YKS	Arrived	319	2017-07-24 20:58:00+03	2017-07-25 03:23:00+03
8822	PG0243	2017-07-26 20:55:00+03	2017-07-27 03:20:00+03	LED	YKS	Arrived	319	2017-07-26 20:58:00+03	2017-07-27 03:25:00+03
8823	PG0243	2017-08-24 20:55:00+03	2017-08-25 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8824	PG0243	2017-09-02 20:55:00+03	2017-09-03 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8825	PG0243	2017-08-20 20:55:00+03	2017-08-21 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8826	PG0243	2017-08-22 20:55:00+03	2017-08-23 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8827	PG0243	2017-08-18 20:55:00+03	2017-08-19 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8828	PG0243	2017-08-13 20:55:00+03	2017-08-14 03:20:00+03	LED	YKS	Arrived	319	2017-08-13 20:57:00+03	2017-08-14 03:27:00+03
8829	PG0243	2017-07-21 20:55:00+03	2017-07-22 03:20:00+03	LED	YKS	Arrived	319	2017-07-21 20:56:00+03	2017-07-22 03:23:00+03
8830	PG0243	2017-08-21 20:55:00+03	2017-08-22 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8831	PG0243	2017-07-25 20:55:00+03	2017-07-26 03:20:00+03	LED	YKS	Arrived	319	2017-07-25 20:59:00+03	2017-07-26 03:21:00+03
8832	PG0243	2017-08-30 20:55:00+03	2017-08-31 03:20:00+03	LED	YKS	Scheduled	319	\N	\N
8833	PG0438	2017-07-25 09:45:00+03	2017-07-25 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-25 09:46:00+03	2017-07-25 13:10:00+03
8834	PG0439	2017-08-21 12:55:00+03	2017-08-21 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8835	PG0438	2017-08-21 09:45:00+03	2017-08-21 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8836	PG0438	2017-07-23 09:45:00+03	2017-07-23 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-23 09:47:00+03	2017-07-23 13:11:00+03
8837	PG0439	2017-07-23 12:55:00+03	2017-07-23 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-23 13:00:00+03	2017-07-23 16:24:00+03
8838	PG0439	2017-08-18 12:55:00+03	2017-08-18 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8839	PG0438	2017-08-18 09:45:00+03	2017-08-18 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8840	PG0439	2017-07-31 12:55:00+03	2017-07-31 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-31 12:56:00+03	2017-07-31 16:20:00+03
8841	PG0438	2017-07-31 09:45:00+03	2017-07-31 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-31 09:48:00+03	2017-07-31 13:10:00+03
8842	PG0439	2017-08-28 12:55:00+03	2017-08-28 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8843	PG0438	2017-08-28 09:45:00+03	2017-08-28 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8844	PG0439	2017-09-14 12:55:00+03	2017-09-14 16:20:00+03	LED	TBW	Cancelled	CN1	\N	\N
8845	PG0439	2017-08-12 12:55:00+03	2017-08-12 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-12 12:57:00+03	2017-08-12 16:25:00+03
8846	PG0438	2017-08-12 09:45:00+03	2017-08-12 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-12 09:46:00+03	2017-08-12 13:14:00+03
8847	PG0439	2017-09-06 12:55:00+03	2017-09-06 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8848	PG0438	2017-09-06 09:45:00+03	2017-09-06 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8849	PG0438	2017-07-16 09:45:00+03	2017-07-16 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-16 09:48:00+03	2017-07-16 13:17:00+03
8850	PG0439	2017-07-16 12:55:00+03	2017-07-16 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-16 12:57:00+03	2017-07-16 16:19:00+03
8851	PG0438	2017-08-01 09:45:00+03	2017-08-01 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-01 09:49:00+03	2017-08-01 13:16:00+03
8852	PG0439	2017-08-01 12:55:00+03	2017-08-01 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-01 12:59:00+03	2017-08-01 16:24:00+03
8853	PG0438	2017-09-11 09:45:00+03	2017-09-11 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8854	PG0439	2017-09-11 12:55:00+03	2017-09-11 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8855	PG0439	2017-08-20 12:55:00+03	2017-08-20 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8856	PG0438	2017-08-20 09:45:00+03	2017-08-20 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8857	PG0438	2017-08-25 09:45:00+03	2017-08-25 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8858	PG0439	2017-08-25 12:55:00+03	2017-08-25 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8859	PG0439	2017-08-11 12:55:00+03	2017-08-11 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-11 13:00:00+03	2017-08-11 16:25:00+03
8860	PG0438	2017-08-11 09:45:00+03	2017-08-11 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-11 09:47:00+03	2017-08-11 13:12:00+03
8861	PG0439	2017-07-22 12:55:00+03	2017-07-22 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-22 12:58:00+03	2017-07-22 16:26:00+03
8862	PG0438	2017-07-22 09:45:00+03	2017-07-22 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-22 09:50:00+03	2017-07-22 13:09:00+03
8863	PG0438	2017-09-01 09:45:00+03	2017-09-01 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8864	PG0439	2017-09-01 12:55:00+03	2017-09-01 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8865	PG0438	2017-08-22 09:45:00+03	2017-08-22 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8866	PG0439	2017-08-24 12:55:00+03	2017-08-24 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8867	PG0438	2017-08-24 09:45:00+03	2017-08-24 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8868	PG0439	2017-08-22 12:55:00+03	2017-08-22 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8869	PG0438	2017-08-02 09:45:00+03	2017-08-02 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-02 09:47:00+03	2017-08-02 13:09:00+03
8870	PG0439	2017-08-02 12:55:00+03	2017-08-02 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-02 12:57:00+03	2017-08-02 16:21:00+03
8871	PG0439	2017-08-10 12:55:00+03	2017-08-10 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-10 12:58:00+03	2017-08-10 16:22:00+03
8872	PG0438	2017-08-10 09:45:00+03	2017-08-10 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-10 09:49:00+03	2017-08-10 13:14:00+03
8873	PG0438	2017-08-14 09:45:00+03	2017-08-14 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-14 09:47:00+03	2017-08-14 13:13:00+03
8874	PG0439	2017-08-14 12:55:00+03	2017-08-14 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-14 12:57:00+03	2017-08-14 16:23:00+03
8875	PG0438	2017-07-17 09:45:00+03	2017-07-17 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-17 09:49:00+03	2017-07-17 13:15:00+03
8876	PG0439	2017-07-17 12:55:00+03	2017-07-17 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-17 13:00:00+03	2017-07-17 16:23:00+03
8877	PG0438	2017-08-27 09:45:00+03	2017-08-27 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8878	PG0438	2017-07-27 09:45:00+03	2017-07-27 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-27 09:47:00+03	2017-07-27 13:12:00+03
8879	PG0439	2017-07-27 12:55:00+03	2017-07-27 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-27 16:11:00+03	2017-07-27 19:39:00+03
8880	PG0439	2017-07-30 12:55:00+03	2017-07-30 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-30 12:59:00+03	2017-07-30 16:22:00+03
8881	PG0438	2017-07-30 09:45:00+03	2017-07-30 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-30 09:48:00+03	2017-07-30 13:12:00+03
8882	PG0438	2017-09-14 09:45:00+03	2017-09-14 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8883	PG0439	2017-08-31 12:55:00+03	2017-08-31 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8884	PG0438	2017-09-07 09:45:00+03	2017-09-07 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8885	PG0439	2017-09-07 12:55:00+03	2017-09-07 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8886	PG0439	2017-08-30 12:55:00+03	2017-08-30 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8887	PG0439	2017-08-09 12:55:00+03	2017-08-09 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-09 13:01:00+03	2017-08-09 16:28:00+03
8888	PG0438	2017-08-09 09:45:00+03	2017-08-09 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-09 09:46:00+03	2017-08-09 13:10:00+03
8889	PG0439	2017-08-17 12:55:00+03	2017-08-17 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8890	PG0438	2017-08-17 09:45:00+03	2017-08-17 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8891	PG0439	2017-09-05 12:55:00+03	2017-09-05 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8892	PG0438	2017-09-05 09:45:00+03	2017-09-05 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8893	PG0438	2017-08-30 09:45:00+03	2017-08-30 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8894	PG0439	2017-07-25 12:55:00+03	2017-07-25 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-25 12:56:00+03	2017-07-25 16:18:00+03
8895	PG0438	2017-09-02 09:45:00+03	2017-09-02 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8896	PG0439	2017-09-02 12:55:00+03	2017-09-02 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8897	PG0438	2017-08-03 09:45:00+03	2017-08-03 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-03 09:47:00+03	2017-08-03 13:10:00+03
8898	PG0439	2017-08-03 12:55:00+03	2017-08-03 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-03 12:58:00+03	2017-08-03 16:22:00+03
8899	PG0439	2017-08-26 12:55:00+03	2017-08-26 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8900	PG0439	2017-08-27 12:55:00+03	2017-08-27 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8901	PG0438	2017-08-31 09:45:00+03	2017-08-31 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8902	PG0438	2017-08-26 09:45:00+03	2017-08-26 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8903	PG0439	2017-07-21 12:55:00+03	2017-07-21 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-21 12:57:00+03	2017-07-21 16:21:00+03
8904	PG0438	2017-07-21 09:45:00+03	2017-07-21 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-21 09:48:00+03	2017-07-21 13:15:00+03
8905	PG0438	2017-07-18 09:45:00+03	2017-07-18 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-18 09:48:00+03	2017-07-18 13:13:00+03
8906	PG0439	2017-07-18 12:55:00+03	2017-07-18 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-18 12:58:00+03	2017-07-18 16:23:00+03
8907	PG0438	2017-07-26 09:45:00+03	2017-07-26 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-26 09:50:00+03	2017-07-26 13:17:00+03
8908	PG0439	2017-07-26 12:55:00+03	2017-07-26 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-26 12:58:00+03	2017-07-26 16:23:00+03
8909	PG0439	2017-08-08 12:55:00+03	2017-08-08 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-08 12:57:00+03	2017-08-08 16:22:00+03
8910	PG0438	2017-08-08 09:45:00+03	2017-08-08 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-08 09:47:00+03	2017-08-08 13:10:00+03
8911	PG0438	2017-08-15 09:45:00+03	2017-08-15 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-15 09:50:00+03	2017-08-15 13:14:00+03
8912	PG0439	2017-08-15 12:55:00+03	2017-08-15 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-15 13:03:00+03	2017-08-15 16:30:00+03
8913	PG0438	2017-07-28 09:45:00+03	2017-07-28 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-28 09:47:00+03	2017-07-28 13:10:00+03
8914	PG0439	2017-07-28 12:55:00+03	2017-07-28 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-28 12:57:00+03	2017-07-28 16:20:00+03
8915	PG0439	2017-09-08 12:55:00+03	2017-09-08 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8916	PG0438	2017-09-08 09:45:00+03	2017-09-08 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8917	PG0439	2017-09-13 12:55:00+03	2017-09-13 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8918	PG0438	2017-09-13 09:45:00+03	2017-09-13 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8919	PG0438	2017-08-04 09:45:00+03	2017-08-04 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-04 09:48:00+03	2017-08-04 13:13:00+03
8920	PG0439	2017-08-04 12:55:00+03	2017-08-04 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-04 12:58:00+03	2017-08-04 16:25:00+03
8921	PG0439	2017-08-13 12:55:00+03	2017-08-13 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-13 12:58:00+03	2017-08-13 16:27:00+03
8922	PG0439	2017-08-07 12:55:00+03	2017-08-07 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-07 12:58:00+03	2017-08-07 16:22:00+03
8923	PG0438	2017-09-12 09:45:00+03	2017-09-12 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8924	PG0438	2017-08-07 09:45:00+03	2017-08-07 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-07 09:48:00+03	2017-08-07 13:13:00+03
8925	PG0439	2017-09-12 12:55:00+03	2017-09-12 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8926	PG0438	2017-08-29 09:45:00+03	2017-08-29 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8927	PG0439	2017-08-29 12:55:00+03	2017-08-29 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8928	PG0438	2017-08-13 09:45:00+03	2017-08-13 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-13 09:46:00+03	2017-08-13 13:12:00+03
8929	PG0438	2017-09-03 09:45:00+03	2017-09-03 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8930	PG0439	2017-09-03 12:55:00+03	2017-09-03 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8931	PG0438	2017-07-19 09:45:00+03	2017-07-19 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-19 09:47:00+03	2017-07-19 13:14:00+03
8932	PG0439	2017-07-19 12:55:00+03	2017-07-19 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-19 13:01:00+03	2017-07-19 16:24:00+03
8933	PG0439	2017-09-09 12:55:00+03	2017-09-09 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8934	PG0438	2017-09-09 09:45:00+03	2017-09-09 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8935	PG0438	2017-08-19 09:45:00+03	2017-08-19 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8936	PG0439	2017-09-04 12:55:00+03	2017-09-04 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8937	PG0439	2017-08-19 12:55:00+03	2017-08-19 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8938	PG0438	2017-09-04 09:45:00+03	2017-09-04 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8939	PG0439	2017-07-20 12:55:00+03	2017-07-20 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-20 12:59:00+03	2017-07-20 16:26:00+03
8940	PG0438	2017-07-20 09:45:00+03	2017-07-20 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-20 09:46:00+03	2017-07-20 13:09:00+03
8941	PG0438	2017-07-24 09:45:00+03	2017-07-24 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-24 09:47:00+03	2017-07-24 13:13:00+03
8942	PG0439	2017-08-23 12:55:00+03	2017-08-23 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8943	PG0439	2017-07-24 12:55:00+03	2017-07-24 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-24 13:00:00+03	2017-07-24 16:25:00+03
8944	PG0438	2017-08-23 09:45:00+03	2017-08-23 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8945	PG0439	2017-08-06 12:55:00+03	2017-08-06 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-06 13:00:00+03	2017-08-06 16:29:00+03
8946	PG0438	2017-08-06 09:45:00+03	2017-08-06 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-06 09:45:00+03	2017-08-06 13:10:00+03
8947	PG0438	2017-08-05 09:45:00+03	2017-08-05 13:10:00+03	LED	TBW	Arrived	CN1	2017-08-05 09:48:00+03	2017-08-05 13:10:00+03
8948	PG0439	2017-08-05 12:55:00+03	2017-08-05 16:20:00+03	LED	TBW	Arrived	CN1	2017-08-05 12:57:00+03	2017-08-05 16:20:00+03
8949	PG0439	2017-07-29 12:55:00+03	2017-07-29 16:20:00+03	LED	TBW	Arrived	CN1	2017-07-29 12:56:00+03	2017-07-29 16:20:00+03
8950	PG0438	2017-07-29 09:45:00+03	2017-07-29 13:10:00+03	LED	TBW	Arrived	CN1	2017-07-29 09:49:00+03	2017-07-29 13:15:00+03
8951	PG0438	2017-09-10 09:45:00+03	2017-09-10 13:10:00+03	LED	TBW	Scheduled	CN1	\N	\N
8952	PG0439	2017-08-16 12:55:00+03	2017-08-16 16:20:00+03	LED	TBW	On Time	CN1	\N	\N
8953	PG0438	2017-08-16 09:45:00+03	2017-08-16 13:10:00+03	LED	TBW	On Time	CN1	\N	\N
8954	PG0439	2017-09-10 12:55:00+03	2017-09-10 16:20:00+03	LED	TBW	Scheduled	CN1	\N	\N
8955	PG0156	2017-08-28 14:55:00+03	2017-08-28 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8956	PG0156	2017-09-01 14:55:00+03	2017-09-01 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8957	PG0156	2017-07-22 14:55:00+03	2017-07-22 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-22 14:58:00+03	2017-07-22 18:31:00+03
8958	PG0156	2017-07-26 14:55:00+03	2017-07-26 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-26 15:00:00+03	2017-07-26 18:36:00+03
8959	PG0156	2017-08-23 14:55:00+03	2017-08-23 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8960	PG0156	2017-08-15 14:55:00+03	2017-08-15 18:30:00+03	LED	NJC	Departed	CR2	2017-08-15 14:59:00+03	\N
8961	PG0156	2017-08-09 14:55:00+03	2017-08-09 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-09 14:57:00+03	2017-08-09 18:29:00+03
8962	PG0156	2017-09-12 14:55:00+03	2017-09-12 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8963	PG0156	2017-07-21 14:55:00+03	2017-07-21 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-21 14:56:00+03	2017-07-21 18:33:00+03
8964	PG0156	2017-09-13 14:55:00+03	2017-09-13 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8965	PG0156	2017-07-24 14:55:00+03	2017-07-24 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-24 14:57:00+03	2017-07-24 18:33:00+03
8966	PG0156	2017-08-11 14:55:00+03	2017-08-11 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-11 14:56:00+03	2017-08-11 18:31:00+03
8967	PG0156	2017-09-10 14:55:00+03	2017-09-10 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8968	PG0156	2017-08-24 14:55:00+03	2017-08-24 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8969	PG0156	2017-08-13 14:55:00+03	2017-08-13 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-13 14:59:00+03	2017-08-13 18:34:00+03
8970	PG0156	2017-08-01 14:55:00+03	2017-08-01 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-01 18:29:00+03	2017-08-01 22:04:00+03
8971	PG0156	2017-08-16 14:55:00+03	2017-08-16 18:30:00+03	LED	NJC	On Time	CR2	\N	\N
8972	PG0156	2017-09-04 14:55:00+03	2017-09-04 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8973	PG0156	2017-08-05 14:55:00+03	2017-08-05 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-05 14:56:00+03	2017-08-05 18:30:00+03
8974	PG0156	2017-08-31 14:55:00+03	2017-08-31 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8975	PG0156	2017-09-07 14:55:00+03	2017-09-07 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8976	PG0156	2017-07-20 14:55:00+03	2017-07-20 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-20 14:57:00+03	2017-07-20 18:34:00+03
8977	PG0156	2017-07-28 14:55:00+03	2017-07-28 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-28 14:56:00+03	2017-07-28 18:30:00+03
8978	PG0156	2017-07-17 14:55:00+03	2017-07-17 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-17 14:58:00+03	2017-07-17 18:33:00+03
8979	PG0156	2017-09-03 14:55:00+03	2017-09-03 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8980	PG0156	2017-07-29 14:55:00+03	2017-07-29 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-29 14:57:00+03	2017-07-29 18:33:00+03
8981	PG0156	2017-09-06 14:55:00+03	2017-09-06 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8982	PG0156	2017-08-20 14:55:00+03	2017-08-20 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8983	PG0156	2017-08-03 14:55:00+03	2017-08-03 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-03 14:55:00+03	2017-08-03 18:27:00+03
8984	PG0156	2017-08-27 14:55:00+03	2017-08-27 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8985	PG0156	2017-08-08 14:55:00+03	2017-08-08 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-08 14:58:00+03	2017-08-08 18:33:00+03
8986	PG0156	2017-08-07 14:55:00+03	2017-08-07 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-07 14:57:00+03	2017-08-07 18:34:00+03
8987	PG0156	2017-08-02 14:55:00+03	2017-08-02 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-02 14:58:00+03	2017-08-02 18:34:00+03
8988	PG0156	2017-08-06 14:55:00+03	2017-08-06 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-06 14:57:00+03	2017-08-06 18:34:00+03
8989	PG0156	2017-09-11 14:55:00+03	2017-09-11 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8990	PG0156	2017-08-04 14:55:00+03	2017-08-04 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-04 14:57:00+03	2017-08-04 18:28:00+03
8991	PG0156	2017-08-17 14:55:00+03	2017-08-17 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8992	PG0156	2017-08-10 14:55:00+03	2017-08-10 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-10 14:58:00+03	2017-08-10 18:32:00+03
8993	PG0156	2017-08-19 14:55:00+03	2017-08-19 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8994	PG0156	2017-07-18 14:55:00+03	2017-07-18 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-18 14:57:00+03	2017-07-18 18:37:00+03
8995	PG0156	2017-08-12 14:55:00+03	2017-08-12 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-12 14:58:00+03	2017-08-12 18:36:00+03
8996	PG0156	2017-09-02 14:55:00+03	2017-09-02 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8997	PG0156	2017-07-19 14:55:00+03	2017-07-19 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-19 15:01:00+03	2017-07-19 18:34:00+03
8998	PG0156	2017-08-22 14:55:00+03	2017-08-22 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
8999	PG0156	2017-09-05 14:55:00+03	2017-09-05 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9000	PG0156	2017-08-18 14:55:00+03	2017-08-18 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9001	PG0156	2017-07-16 14:55:00+03	2017-07-16 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-16 14:56:00+03	2017-07-16 18:31:00+03
9002	PG0156	2017-08-25 14:55:00+03	2017-08-25 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9003	PG0156	2017-07-25 14:55:00+03	2017-07-25 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-25 18:09:00+03	2017-07-25 21:43:00+03
9004	PG0156	2017-07-27 14:55:00+03	2017-07-27 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-27 14:57:00+03	2017-07-27 18:31:00+03
9005	PG0156	2017-08-21 14:55:00+03	2017-08-21 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9006	PG0156	2017-08-14 14:55:00+03	2017-08-14 18:30:00+03	LED	NJC	Arrived	CR2	2017-08-14 14:59:00+03	2017-08-14 18:34:00+03
9007	PG0156	2017-09-09 14:55:00+03	2017-09-09 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9008	PG0156	2017-09-08 14:55:00+03	2017-09-08 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9009	PG0156	2017-09-14 14:55:00+03	2017-09-14 18:30:00+03	LED	NJC	Cancelled	CR2	\N	\N
9010	PG0156	2017-08-26 14:55:00+03	2017-08-26 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9011	PG0156	2017-08-29 14:55:00+03	2017-08-29 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9012	PG0156	2017-07-30 14:55:00+03	2017-07-30 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-30 14:56:00+03	2017-07-30 18:30:00+03
9013	PG0156	2017-07-31 14:55:00+03	2017-07-31 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-31 14:58:00+03	2017-07-31 18:33:00+03
9014	PG0156	2017-07-23 14:55:00+03	2017-07-23 18:30:00+03	LED	NJC	Arrived	CR2	2017-07-23 14:56:00+03	2017-07-23 18:32:00+03
9015	PG0156	2017-08-30 14:55:00+03	2017-08-30 18:30:00+03	LED	NJC	Scheduled	CR2	\N	\N
9016	PG0114	2017-09-06 14:20:00+03	2017-09-06 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9017	PG0114	2017-08-05 14:20:00+03	2017-08-05 17:40:00+03	LED	NOJ	Arrived	CR2	2017-08-05 14:25:00+03	2017-08-05 17:45:00+03
9018	PG0114	2017-09-02 14:20:00+03	2017-09-02 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9019	PG0114	2017-07-26 14:20:00+03	2017-07-26 17:40:00+03	LED	NOJ	Arrived	CR2	2017-07-26 14:25:00+03	2017-07-26 17:44:00+03
9020	PG0114	2017-07-29 14:20:00+03	2017-07-29 17:40:00+03	LED	NOJ	Arrived	CR2	2017-07-29 14:24:00+03	2017-07-29 17:42:00+03
9021	PG0114	2017-07-22 14:20:00+03	2017-07-22 17:40:00+03	LED	NOJ	Arrived	CR2	2017-07-22 14:21:00+03	2017-07-22 17:41:00+03
9022	PG0114	2017-08-23 14:20:00+03	2017-08-23 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9023	PG0114	2017-09-09 14:20:00+03	2017-09-09 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9024	PG0114	2017-07-19 14:20:00+03	2017-07-19 17:40:00+03	LED	NOJ	Arrived	CR2	2017-07-19 17:16:00+03	2017-07-19 20:41:00+03
9025	PG0114	2017-08-30 14:20:00+03	2017-08-30 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9026	PG0114	2017-08-26 14:20:00+03	2017-08-26 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9027	PG0114	2017-08-12 14:20:00+03	2017-08-12 17:40:00+03	LED	NOJ	Arrived	CR2	2017-08-12 14:22:00+03	2017-08-12 17:43:00+03
9028	PG0114	2017-08-16 14:20:00+03	2017-08-16 17:40:00+03	LED	NOJ	On Time	CR2	\N	\N
9029	PG0114	2017-08-09 14:20:00+03	2017-08-09 17:40:00+03	LED	NOJ	Arrived	CR2	2017-08-09 14:21:00+03	2017-08-09 17:42:00+03
9030	PG0114	2017-09-13 14:20:00+03	2017-09-13 17:40:00+03	LED	NOJ	Cancelled	CR2	\N	\N
9031	PG0114	2017-08-19 14:20:00+03	2017-08-19 17:40:00+03	LED	NOJ	Scheduled	CR2	\N	\N
9032	PG0114	2017-08-02 14:20:00+03	2017-08-02 17:40:00+03	LED	NOJ	Arrived	CR2	2017-08-02 14:23:00+03	2017-08-02 17:42:00+03
9033	PG0523	2017-08-30 15:10:00+03	2017-08-30 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9034	PG0523	2017-08-05 15:10:00+03	2017-08-05 17:40:00+03	LED	ESL	Arrived	CR2	2017-08-05 15:11:00+03	2017-08-05 17:43:00+03
9035	PG0523	2017-08-16 15:10:00+03	2017-08-16 17:40:00+03	LED	ESL	On Time	CR2	\N	\N
9036	PG0523	2017-08-02 15:10:00+03	2017-08-02 17:40:00+03	LED	ESL	Arrived	CR2	2017-08-02 15:13:00+03	2017-08-02 17:43:00+03
9037	PG0523	2017-07-22 15:10:00+03	2017-07-22 17:40:00+03	LED	ESL	Arrived	CR2	2017-07-22 15:12:00+03	2017-07-22 17:43:00+03
9038	PG0523	2017-08-19 15:10:00+03	2017-08-19 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9039	PG0523	2017-08-12 15:10:00+03	2017-08-12 17:40:00+03	LED	ESL	Arrived	CR2	2017-08-12 15:13:00+03	2017-08-12 17:42:00+03
9040	PG0523	2017-08-26 15:10:00+03	2017-08-26 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9041	PG0523	2017-09-06 15:10:00+03	2017-09-06 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9042	PG0523	2017-07-29 15:10:00+03	2017-07-29 17:40:00+03	LED	ESL	Arrived	CR2	2017-07-29 15:11:00+03	2017-07-29 17:42:00+03
9043	PG0523	2017-08-23 15:10:00+03	2017-08-23 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9044	PG0523	2017-09-02 15:10:00+03	2017-09-02 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9045	PG0523	2017-09-09 15:10:00+03	2017-09-09 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9046	PG0523	2017-07-26 15:10:00+03	2017-07-26 17:40:00+03	LED	ESL	Arrived	CR2	2017-07-26 15:13:00+03	2017-07-26 17:42:00+03
9047	PG0523	2017-09-13 15:10:00+03	2017-09-13 17:40:00+03	LED	ESL	Scheduled	CR2	\N	\N
9048	PG0523	2017-07-19 15:10:00+03	2017-07-19 17:40:00+03	LED	ESL	Arrived	CR2	2017-07-19 15:12:00+03	2017-07-19 17:42:00+03
9049	PG0523	2017-08-09 15:10:00+03	2017-08-09 17:40:00+03	LED	ESL	Arrived	CR2	2017-08-09 15:15:00+03	2017-08-09 17:48:00+03
9050	PG0245	2017-08-13 20:50:00+03	2017-08-14 03:30:00+03	LED	CNN	Arrived	319	2017-08-13 20:53:00+03	2017-08-14 03:39:00+03
9051	PG0245	2017-09-03 20:50:00+03	2017-09-04 03:30:00+03	LED	CNN	Scheduled	319	\N	\N
9052	PG0245	2017-09-10 20:50:00+03	2017-09-11 03:30:00+03	LED	CNN	Cancelled	319	\N	\N
9053	PG0245	2017-07-23 20:50:00+03	2017-07-24 03:30:00+03	LED	CNN	Arrived	319	2017-07-23 20:55:00+03	2017-07-24 03:36:00+03
9054	PG0245	2017-08-20 20:50:00+03	2017-08-21 03:30:00+03	LED	CNN	Scheduled	319	\N	\N
9055	PG0245	2017-07-16 20:50:00+03	2017-07-17 03:30:00+03	LED	CNN	Arrived	319	2017-07-16 20:52:00+03	2017-07-17 03:32:00+03
9056	PG0245	2017-08-06 20:50:00+03	2017-08-07 03:30:00+03	LED	CNN	Arrived	319	2017-08-06 20:53:00+03	2017-08-07 03:37:00+03
9057	PG0245	2017-07-30 20:50:00+03	2017-07-31 03:30:00+03	LED	CNN	Arrived	319	2017-07-30 23:53:00+03	2017-07-31 06:31:00+03
9058	PG0245	2017-08-27 20:50:00+03	2017-08-28 03:30:00+03	LED	CNN	Scheduled	319	\N	\N
9059	PG0571	2017-08-19 14:50:00+03	2017-08-19 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9060	PG0571	2017-08-27 14:50:00+03	2017-08-27 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9061	PG0571	2017-07-28 14:50:00+03	2017-07-28 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-28 14:54:00+03	2017-07-28 16:04:00+03
9062	PG0571	2017-08-04 14:50:00+03	2017-08-04 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-04 14:56:00+03	2017-08-04 16:07:00+03
9063	PG0571	2017-07-30 14:50:00+03	2017-07-30 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-30 14:53:00+03	2017-07-30 16:03:00+03
9064	PG0571	2017-09-12 14:50:00+03	2017-09-12 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9065	PG0571	2017-09-08 14:50:00+03	2017-09-08 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9066	PG0571	2017-07-22 14:50:00+03	2017-07-22 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-22 14:54:00+03	2017-07-22 16:05:00+03
9067	PG0571	2017-09-04 14:50:00+03	2017-09-04 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9068	PG0571	2017-08-01 14:50:00+03	2017-08-01 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-01 14:53:00+03	2017-08-01 16:04:00+03
9069	PG0571	2017-07-26 14:50:00+03	2017-07-26 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-26 14:52:00+03	2017-07-26 16:02:00+03
9070	PG0571	2017-08-03 14:50:00+03	2017-08-03 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-03 14:57:00+03	2017-08-03 16:07:00+03
9071	PG0571	2017-08-07 14:50:00+03	2017-08-07 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-07 14:53:00+03	2017-08-07 16:04:00+03
9072	PG0571	2017-09-07 14:50:00+03	2017-09-07 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9073	PG0571	2017-08-18 14:50:00+03	2017-08-18 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9074	PG0571	2017-09-14 14:50:00+03	2017-09-14 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9075	PG0571	2017-08-02 14:50:00+03	2017-08-02 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-02 14:55:00+03	2017-08-02 16:04:00+03
9076	PG0571	2017-08-09 14:50:00+03	2017-08-09 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-09 14:51:00+03	2017-08-09 16:00:00+03
9077	PG0571	2017-07-27 14:50:00+03	2017-07-27 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-27 14:52:00+03	2017-07-27 16:03:00+03
9078	PG0571	2017-08-10 14:50:00+03	2017-08-10 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-10 14:52:00+03	2017-08-10 16:01:00+03
9079	PG0571	2017-07-20 14:50:00+03	2017-07-20 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-20 14:56:00+03	2017-07-20 16:06:00+03
9080	PG0571	2017-09-02 14:50:00+03	2017-09-02 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9081	PG0571	2017-08-26 14:50:00+03	2017-08-26 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9082	PG0571	2017-08-22 14:50:00+03	2017-08-22 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9083	PG0571	2017-09-05 14:50:00+03	2017-09-05 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9084	PG0571	2017-08-24 14:50:00+03	2017-08-24 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9085	PG0571	2017-07-18 14:50:00+03	2017-07-18 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-18 14:55:00+03	2017-07-18 16:04:00+03
9086	PG0571	2017-08-28 14:50:00+03	2017-08-28 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9087	PG0571	2017-07-24 14:50:00+03	2017-07-24 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-24 14:52:00+03	2017-07-24 16:02:00+03
9088	PG0571	2017-07-17 14:50:00+03	2017-07-17 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-17 14:52:00+03	2017-07-17 16:03:00+03
9089	PG0571	2017-08-05 14:50:00+03	2017-08-05 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-05 14:55:00+03	2017-08-05 16:05:00+03
9090	PG0571	2017-08-08 14:50:00+03	2017-08-08 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-08 14:50:00+03	2017-08-08 16:00:00+03
9091	PG0571	2017-09-06 14:50:00+03	2017-09-06 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9092	PG0571	2017-09-13 14:50:00+03	2017-09-13 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9093	PG0571	2017-08-25 14:50:00+03	2017-08-25 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9094	PG0571	2017-08-31 14:50:00+03	2017-08-31 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9095	PG0571	2017-08-16 14:50:00+03	2017-08-16 16:00:00+03	LED	GOJ	On Time	SU9	\N	\N
9096	PG0571	2017-09-09 14:50:00+03	2017-09-09 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9097	PG0571	2017-07-29 14:50:00+03	2017-07-29 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-29 14:53:00+03	2017-07-29 16:04:00+03
9098	PG0571	2017-08-30 14:50:00+03	2017-08-30 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9099	PG0571	2017-08-14 14:50:00+03	2017-08-14 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-14 14:52:00+03	2017-08-14 16:01:00+03
9100	PG0571	2017-07-31 14:50:00+03	2017-07-31 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-31 14:52:00+03	2017-07-31 16:02:00+03
9101	PG0571	2017-08-29 14:50:00+03	2017-08-29 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9102	PG0571	2017-08-17 14:50:00+03	2017-08-17 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9103	PG0571	2017-07-21 14:50:00+03	2017-07-21 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-21 14:55:00+03	2017-07-21 16:06:00+03
9104	PG0571	2017-07-25 14:50:00+03	2017-07-25 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-25 14:51:00+03	2017-07-25 16:00:00+03
9105	PG0571	2017-08-23 14:50:00+03	2017-08-23 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9106	PG0571	2017-07-23 14:50:00+03	2017-07-23 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-23 14:53:00+03	2017-07-23 16:02:00+03
9107	PG0571	2017-09-01 14:50:00+03	2017-09-01 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9108	PG0571	2017-09-11 14:50:00+03	2017-09-11 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9109	PG0571	2017-08-20 14:50:00+03	2017-08-20 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9110	PG0571	2017-08-12 14:50:00+03	2017-08-12 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-12 14:56:00+03	2017-08-12 16:06:00+03
9111	PG0571	2017-08-15 14:50:00+03	2017-08-15 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-15 14:51:00+03	2017-08-15 16:02:00+03
9112	PG0571	2017-08-21 14:50:00+03	2017-08-21 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9113	PG0571	2017-09-03 14:50:00+03	2017-09-03 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9114	PG0571	2017-08-06 14:50:00+03	2017-08-06 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-06 14:55:00+03	2017-08-06 16:06:00+03
9115	PG0571	2017-07-19 14:50:00+03	2017-07-19 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-19 18:29:00+03	2017-07-19 19:39:00+03
9116	PG0571	2017-07-16 14:50:00+03	2017-07-16 16:00:00+03	LED	GOJ	Arrived	SU9	2017-07-16 14:55:00+03	2017-07-16 16:04:00+03
9117	PG0571	2017-08-11 14:50:00+03	2017-08-11 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-11 14:54:00+03	2017-08-11 16:05:00+03
9118	PG0571	2017-08-13 14:50:00+03	2017-08-13 16:00:00+03	LED	GOJ	Arrived	SU9	2017-08-13 14:52:00+03	2017-08-13 16:02:00+03
9119	PG0571	2017-09-10 14:50:00+03	2017-09-10 16:00:00+03	LED	GOJ	Scheduled	SU9	\N	\N
9120	PG0339	2017-08-14 09:10:00+03	2017-08-14 14:35:00+03	LED	PYJ	Arrived	733	2017-08-14 09:14:00+03	2017-08-14 14:34:00+03
9121	PG0339	2017-09-11 09:10:00+03	2017-09-11 14:35:00+03	LED	PYJ	Cancelled	733	\N	\N
9122	PG0339	2017-08-28 09:10:00+03	2017-08-28 14:35:00+03	LED	PYJ	Scheduled	733	\N	\N
9123	PG0339	2017-07-31 09:10:00+03	2017-07-31 14:35:00+03	LED	PYJ	Arrived	733	2017-07-31 09:11:00+03	2017-07-31 14:44:00+03
9124	PG0339	2017-07-17 09:10:00+03	2017-07-17 14:35:00+03	LED	PYJ	Arrived	733	2017-07-17 09:11:00+03	2017-07-17 14:31:00+03
9125	PG0339	2017-09-04 09:10:00+03	2017-09-04 14:35:00+03	LED	PYJ	Scheduled	733	\N	\N
9126	PG0339	2017-07-24 09:10:00+03	2017-07-24 14:35:00+03	LED	PYJ	Arrived	733	2017-07-24 09:11:00+03	2017-07-24 14:40:00+03
9127	PG0339	2017-08-07 09:10:00+03	2017-08-07 14:35:00+03	LED	PYJ	Arrived	733	2017-08-07 09:13:00+03	2017-08-07 14:43:00+03
9128	PG0339	2017-08-21 09:10:00+03	2017-08-21 14:35:00+03	LED	PYJ	Scheduled	733	\N	\N
9129	PG0685	2017-08-27 15:15:00+03	2017-08-27 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9130	PG0685	2017-08-10 15:15:00+03	2017-08-10 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-10 15:18:00+03	2017-08-10 17:54:00+03
9131	PG0685	2017-07-23 15:15:00+03	2017-07-23 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-23 15:18:00+03	2017-07-23 17:57:00+03
9132	PG0685	2017-09-10 15:15:00+03	2017-09-10 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9133	PG0685	2017-08-18 15:15:00+03	2017-08-18 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9134	PG0685	2017-08-24 15:15:00+03	2017-08-24 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9135	PG0685	2017-07-22 15:15:00+03	2017-07-22 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-22 15:19:00+03	2017-07-22 17:50:00+03
9136	PG0685	2017-08-15 15:15:00+03	2017-08-15 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-15 15:18:00+03	2017-08-15 17:53:00+03
9137	PG0685	2017-09-07 15:15:00+03	2017-09-07 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9138	PG0685	2017-07-26 15:15:00+03	2017-07-26 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-26 15:18:00+03	2017-07-26 17:55:00+03
9139	PG0685	2017-08-02 15:15:00+03	2017-08-02 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-02 15:17:00+03	2017-08-02 17:51:00+03
9140	PG0685	2017-07-29 15:15:00+03	2017-07-29 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-29 15:19:00+03	2017-07-29 17:59:00+03
9141	PG0685	2017-08-13 15:15:00+03	2017-08-13 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-13 15:20:00+03	2017-08-13 17:54:00+03
9142	PG0685	2017-07-21 15:15:00+03	2017-07-21 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-21 15:17:00+03	2017-07-21 17:54:00+03
9143	PG0685	2017-08-22 15:15:00+03	2017-08-22 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9144	PG0685	2017-08-14 15:15:00+03	2017-08-14 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-14 15:20:00+03	2017-08-14 17:57:00+03
9145	PG0685	2017-08-20 15:15:00+03	2017-08-20 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9146	PG0685	2017-09-12 15:15:00+03	2017-09-12 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9147	PG0685	2017-09-02 15:15:00+03	2017-09-02 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9148	PG0685	2017-09-08 15:15:00+03	2017-09-08 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9149	PG0685	2017-09-11 15:15:00+03	2017-09-11 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9150	PG0685	2017-08-28 15:15:00+03	2017-08-28 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9151	PG0685	2017-08-11 15:15:00+03	2017-08-11 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-11 15:18:00+03	2017-08-11 17:55:00+03
9152	PG0685	2017-07-31 15:15:00+03	2017-07-31 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-31 15:18:00+03	2017-07-31 17:53:00+03
9153	PG0685	2017-07-28 15:15:00+03	2017-07-28 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-28 15:19:00+03	2017-07-28 17:57:00+03
9154	PG0685	2017-07-30 15:15:00+03	2017-07-30 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-30 15:17:00+03	2017-07-30 17:54:00+03
9155	PG0685	2017-08-16 15:15:00+03	2017-08-16 17:50:00+03	LED	OVS	On Time	CR2	\N	\N
9156	PG0685	2017-08-07 15:15:00+03	2017-08-07 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-07 15:16:00+03	2017-08-07 17:52:00+03
9157	PG0685	2017-09-14 15:15:00+03	2017-09-14 17:50:00+03	LED	OVS	Cancelled	CR2	\N	\N
9158	PG0685	2017-08-01 15:15:00+03	2017-08-01 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-01 15:17:00+03	2017-08-01 17:52:00+03
9159	PG0685	2017-08-26 15:15:00+03	2017-08-26 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9160	PG0685	2017-07-16 15:15:00+03	2017-07-16 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-16 15:20:00+03	2017-07-16 17:54:00+03
9161	PG0685	2017-08-03 15:15:00+03	2017-08-03 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-03 15:19:00+03	2017-08-03 17:54:00+03
9162	PG0685	2017-07-24 15:15:00+03	2017-07-24 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-24 15:17:00+03	2017-07-24 17:49:00+03
9163	PG0685	2017-08-09 15:15:00+03	2017-08-09 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-09 15:20:00+03	2017-08-09 17:52:00+03
9164	PG0685	2017-08-05 15:15:00+03	2017-08-05 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-05 15:16:00+03	2017-08-05 17:51:00+03
9165	PG0685	2017-08-21 15:15:00+03	2017-08-21 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9166	PG0685	2017-08-29 15:15:00+03	2017-08-29 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9167	PG0685	2017-07-19 15:15:00+03	2017-07-19 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-19 15:17:00+03	2017-07-19 17:50:00+03
9168	PG0685	2017-07-27 15:15:00+03	2017-07-27 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-27 15:18:00+03	2017-07-27 17:51:00+03
9169	PG0685	2017-09-04 15:15:00+03	2017-09-04 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9170	PG0685	2017-08-06 15:15:00+03	2017-08-06 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-06 15:18:00+03	2017-08-06 17:55:00+03
9171	PG0685	2017-09-01 15:15:00+03	2017-09-01 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9172	PG0685	2017-08-04 15:15:00+03	2017-08-04 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-04 15:15:00+03	2017-08-04 17:48:00+03
9173	PG0685	2017-08-19 15:15:00+03	2017-08-19 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9174	PG0685	2017-07-20 15:15:00+03	2017-07-20 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-20 15:16:00+03	2017-07-20 17:52:00+03
9175	PG0685	2017-07-17 15:15:00+03	2017-07-17 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-17 15:18:00+03	2017-07-17 17:53:00+03
9176	PG0685	2017-08-25 15:15:00+03	2017-08-25 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9177	PG0685	2017-08-08 15:15:00+03	2017-08-08 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-08 15:20:00+03	2017-08-08 17:57:00+03
9178	PG0685	2017-09-03 15:15:00+03	2017-09-03 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9179	PG0685	2017-07-25 15:15:00+03	2017-07-25 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-25 15:18:00+03	2017-07-25 17:55:00+03
9180	PG0685	2017-07-18 15:15:00+03	2017-07-18 17:50:00+03	LED	OVS	Arrived	CR2	2017-07-18 15:22:00+03	2017-07-18 17:58:00+03
9181	PG0685	2017-09-13 15:15:00+03	2017-09-13 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9182	PG0685	2017-09-05 15:15:00+03	2017-09-05 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9183	PG0685	2017-09-09 15:15:00+03	2017-09-09 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9184	PG0685	2017-08-23 15:15:00+03	2017-08-23 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9185	PG0685	2017-09-06 15:15:00+03	2017-09-06 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9186	PG0685	2017-08-31 15:15:00+03	2017-08-31 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9187	PG0685	2017-08-30 15:15:00+03	2017-08-30 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9188	PG0685	2017-08-17 15:15:00+03	2017-08-17 17:50:00+03	LED	OVS	Scheduled	CR2	\N	\N
9189	PG0685	2017-08-12 15:15:00+03	2017-08-12 17:50:00+03	LED	OVS	Arrived	CR2	2017-08-12 15:18:00+03	2017-08-12 17:54:00+03
9190	PG0271	2017-07-30 16:50:00+03	2017-07-30 19:25:00+03	LED	VKT	Arrived	CR2	2017-07-30 16:53:00+03	2017-07-30 19:31:00+03
9191	PG0271	2017-07-23 16:50:00+03	2017-07-23 19:25:00+03	LED	VKT	Arrived	CR2	2017-07-23 16:54:00+03	2017-07-23 19:27:00+03
9192	PG0271	2017-07-19 16:50:00+03	2017-07-19 19:25:00+03	LED	VKT	Arrived	CR2	2017-07-19 16:54:00+03	2017-07-19 19:29:00+03
9193	PG0271	2017-08-30 16:50:00+03	2017-08-30 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9194	PG0271	2017-09-10 16:50:00+03	2017-09-10 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9195	PG0271	2017-08-23 16:50:00+03	2017-08-23 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9196	PG0271	2017-09-06 16:50:00+03	2017-09-06 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9197	PG0271	2017-08-20 16:50:00+03	2017-08-20 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9198	PG0271	2017-07-16 16:50:00+03	2017-07-16 19:25:00+03	LED	VKT	Arrived	CR2	2017-07-16 16:50:00+03	2017-07-16 19:25:00+03
9199	PG0271	2017-09-03 16:50:00+03	2017-09-03 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9200	PG0271	2017-08-13 16:50:00+03	2017-08-13 19:25:00+03	LED	VKT	Arrived	CR2	2017-08-13 16:54:00+03	2017-08-13 19:29:00+03
9201	PG0271	2017-08-27 16:50:00+03	2017-08-27 19:25:00+03	LED	VKT	Scheduled	CR2	\N	\N
9202	PG0271	2017-09-13 16:50:00+03	2017-09-13 19:25:00+03	LED	VKT	Cancelled	CR2	\N	\N
9203	PG0271	2017-07-26 16:50:00+03	2017-07-26 19:25:00+03	LED	VKT	Arrived	CR2	2017-07-26 20:08:00+03	2017-07-26 22:43:00+03
9204	PG0271	2017-08-09 16:50:00+03	2017-08-09 19:25:00+03	LED	VKT	Arrived	CR2	2017-08-09 16:51:00+03	2017-08-09 19:23:00+03
9205	PG0271	2017-08-16 16:50:00+03	2017-08-16 19:25:00+03	LED	VKT	On Time	CR2	\N	\N
9206	PG0271	2017-08-02 16:50:00+03	2017-08-02 19:25:00+03	LED	VKT	Arrived	CR2	2017-08-02 16:51:00+03	2017-08-02 19:24:00+03
9207	PG0271	2017-08-06 16:50:00+03	2017-08-06 19:25:00+03	LED	VKT	Arrived	CR2	2017-08-06 16:50:00+03	2017-08-06 19:26:00+03
9208	PG0188	2017-08-24 11:15:00+03	2017-08-24 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9209	PG0188	2017-07-25 11:15:00+03	2017-07-25 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-25 11:18:00+03	2017-07-25 14:13:00+03
9210	PG0188	2017-07-28 11:15:00+03	2017-07-28 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-28 11:20:00+03	2017-07-28 14:14:00+03
9211	PG0188	2017-08-19 11:15:00+03	2017-08-19 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9212	PG0188	2017-08-25 11:15:00+03	2017-08-25 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9213	PG0188	2017-09-01 11:15:00+03	2017-09-01 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9214	PG0188	2017-08-02 11:15:00+03	2017-08-02 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-02 14:09:00+03	2017-08-02 17:04:00+03
9215	PG0188	2017-08-07 11:15:00+03	2017-08-07 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-07 11:20:00+03	2017-08-07 14:15:00+03
9216	PG0188	2017-08-30 11:15:00+03	2017-08-30 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9217	PG0188	2017-07-19 11:15:00+03	2017-07-19 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-19 11:16:00+03	2017-07-19 14:10:00+03
9218	PG0188	2017-07-23 11:15:00+03	2017-07-23 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-23 11:17:00+03	2017-07-23 14:16:00+03
9219	PG0188	2017-09-07 11:15:00+03	2017-09-07 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9220	PG0188	2017-08-18 11:15:00+03	2017-08-18 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9221	PG0188	2017-08-28 11:15:00+03	2017-08-28 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9222	PG0188	2017-09-03 11:15:00+03	2017-09-03 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9223	PG0188	2017-09-08 11:15:00+03	2017-09-08 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9224	PG0188	2017-09-11 11:15:00+03	2017-09-11 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9225	PG0188	2017-08-22 11:15:00+03	2017-08-22 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9226	PG0188	2017-07-29 11:15:00+03	2017-07-29 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-29 11:19:00+03	2017-07-29 14:13:00+03
9227	PG0188	2017-08-05 11:15:00+03	2017-08-05 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-05 11:16:00+03	2017-08-05 14:11:00+03
9228	PG0188	2017-08-31 11:15:00+03	2017-08-31 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9229	PG0188	2017-08-27 11:15:00+03	2017-08-27 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9230	PG0188	2017-08-03 11:15:00+03	2017-08-03 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-03 11:22:00+03	2017-08-03 14:18:00+03
9231	PG0188	2017-08-10 11:15:00+03	2017-08-10 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-10 11:19:00+03	2017-08-10 14:18:00+03
9232	PG0188	2017-09-04 11:15:00+03	2017-09-04 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9233	PG0188	2017-07-18 11:15:00+03	2017-07-18 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-18 11:18:00+03	2017-07-18 14:11:00+03
9234	PG0188	2017-08-20 11:15:00+03	2017-08-20 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9235	PG0188	2017-08-09 11:15:00+03	2017-08-09 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-09 11:17:00+03	2017-08-09 14:13:00+03
9236	PG0188	2017-08-13 11:15:00+03	2017-08-13 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-13 11:18:00+03	2017-08-13 14:12:00+03
9237	PG0188	2017-07-21 11:15:00+03	2017-07-21 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-21 11:18:00+03	2017-07-21 14:13:00+03
9238	PG0188	2017-08-26 11:15:00+03	2017-08-26 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9239	PG0188	2017-08-01 11:15:00+03	2017-08-01 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-01 11:18:00+03	2017-08-01 14:14:00+03
9240	PG0188	2017-08-17 11:15:00+03	2017-08-17 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9241	PG0188	2017-08-29 11:15:00+03	2017-08-29 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9242	PG0188	2017-07-27 11:15:00+03	2017-07-27 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-27 11:19:00+03	2017-07-27 14:14:00+03
9243	PG0188	2017-08-23 11:15:00+03	2017-08-23 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9244	PG0188	2017-09-12 11:15:00+03	2017-09-12 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9245	PG0188	2017-09-06 11:15:00+03	2017-09-06 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9246	PG0188	2017-07-17 11:15:00+03	2017-07-17 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-17 11:18:00+03	2017-07-17 14:13:00+03
9247	PG0188	2017-08-16 11:15:00+03	2017-08-16 14:10:00+03	LED	TJM	On Time	CR2	\N	\N
9248	PG0188	2017-08-21 11:15:00+03	2017-08-21 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9249	PG0188	2017-09-13 11:15:00+03	2017-09-13 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9250	PG0188	2017-08-14 11:15:00+03	2017-08-14 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-14 11:20:00+03	2017-08-14 14:16:00+03
9251	PG0188	2017-08-08 11:15:00+03	2017-08-08 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-08 11:17:00+03	2017-08-08 14:11:00+03
9252	PG0188	2017-08-15 11:15:00+03	2017-08-15 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-15 11:19:00+03	2017-08-15 14:13:00+03
9253	PG0188	2017-07-30 11:15:00+03	2017-07-30 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-30 13:47:00+03	2017-07-30 16:41:00+03
9254	PG0188	2017-09-14 11:15:00+03	2017-09-14 14:10:00+03	LED	TJM	Cancelled	CR2	\N	\N
9255	PG0188	2017-07-26 11:15:00+03	2017-07-26 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-26 11:17:00+03	2017-07-26 14:15:00+03
9256	PG0188	2017-09-09 11:15:00+03	2017-09-09 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9257	PG0188	2017-09-10 11:15:00+03	2017-09-10 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9258	PG0188	2017-07-31 11:15:00+03	2017-07-31 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-31 11:20:00+03	2017-07-31 14:18:00+03
9259	PG0188	2017-09-05 11:15:00+03	2017-09-05 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9260	PG0188	2017-08-11 11:15:00+03	2017-08-11 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-11 11:18:00+03	2017-08-11 14:12:00+03
9261	PG0188	2017-08-12 11:15:00+03	2017-08-12 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-12 11:17:00+03	2017-08-12 14:13:00+03
9262	PG0188	2017-07-16 11:15:00+03	2017-07-16 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-16 13:42:00+03	2017-07-16 16:37:00+03
9263	PG0188	2017-09-02 11:15:00+03	2017-09-02 14:10:00+03	LED	TJM	Scheduled	CR2	\N	\N
9264	PG0188	2017-08-06 11:15:00+03	2017-08-06 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-06 11:18:00+03	2017-08-06 14:16:00+03
9265	PG0188	2017-07-20 11:15:00+03	2017-07-20 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-20 11:17:00+03	2017-07-20 14:11:00+03
9266	PG0188	2017-08-04 11:15:00+03	2017-08-04 14:10:00+03	LED	TJM	Arrived	CR2	2017-08-04 11:18:00+03	2017-08-04 14:13:00+03
9267	PG0188	2017-07-22 11:15:00+03	2017-07-22 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-22 11:17:00+03	2017-07-22 14:12:00+03
9268	PG0188	2017-07-24 11:15:00+03	2017-07-24 14:10:00+03	LED	TJM	Arrived	CR2	2017-07-24 11:16:00+03	2017-07-24 14:10:00+03
9269	PG0198	2017-08-11 09:10:00+03	2017-08-11 15:00:00+03	LED	IKT	Arrived	321	2017-08-11 09:14:00+03	2017-08-11 15:08:00+03
9270	PG0198	2017-08-22 09:10:00+03	2017-08-22 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9271	PG0198	2017-08-23 09:10:00+03	2017-08-23 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9272	PG0198	2017-07-20 09:10:00+03	2017-07-20 15:00:00+03	LED	IKT	Arrived	321	2017-07-20 09:13:00+03	2017-07-20 14:59:00+03
9273	PG0198	2017-08-16 09:10:00+03	2017-08-16 15:00:00+03	LED	IKT	Delayed	321	\N	\N
9274	PG0198	2017-08-13 09:10:00+03	2017-08-13 15:00:00+03	LED	IKT	Arrived	321	2017-08-13 09:13:00+03	2017-08-13 15:03:00+03
9275	PG0198	2017-09-12 09:10:00+03	2017-09-12 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9276	PG0198	2017-07-18 09:10:00+03	2017-07-18 15:00:00+03	LED	IKT	Arrived	321	2017-07-18 09:12:00+03	2017-07-18 15:06:00+03
9277	PG0198	2017-09-06 09:10:00+03	2017-09-06 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9278	PG0198	2017-08-04 09:10:00+03	2017-08-04 15:00:00+03	LED	IKT	Arrived	321	2017-08-04 09:12:00+03	2017-08-04 15:04:00+03
9279	PG0198	2017-08-29 09:10:00+03	2017-08-29 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9280	PG0198	2017-07-29 09:10:00+03	2017-07-29 15:00:00+03	LED	IKT	Arrived	321	2017-07-29 09:15:00+03	2017-07-29 15:07:00+03
9281	PG0198	2017-07-25 09:10:00+03	2017-07-25 15:00:00+03	LED	IKT	Arrived	321	2017-07-25 09:11:00+03	2017-07-25 15:07:00+03
9282	PG0198	2017-09-04 09:10:00+03	2017-09-04 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9283	PG0198	2017-09-03 09:10:00+03	2017-09-03 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9284	PG0198	2017-07-21 09:10:00+03	2017-07-21 15:00:00+03	LED	IKT	Arrived	321	2017-07-21 09:14:00+03	2017-07-21 15:06:00+03
9285	PG0198	2017-08-12 09:10:00+03	2017-08-12 15:00:00+03	LED	IKT	Arrived	321	2017-08-12 09:12:00+03	2017-08-12 15:01:00+03
9286	PG0198	2017-08-26 09:10:00+03	2017-08-26 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9287	PG0198	2017-09-08 09:10:00+03	2017-09-08 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9288	PG0198	2017-09-10 09:10:00+03	2017-09-10 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9289	PG0198	2017-08-05 09:10:00+03	2017-08-05 15:00:00+03	LED	IKT	Arrived	321	2017-08-05 09:11:00+03	2017-08-05 15:07:00+03
9290	PG0198	2017-07-19 09:10:00+03	2017-07-19 15:00:00+03	LED	IKT	Arrived	321	2017-07-19 09:13:00+03	2017-07-19 15:08:00+03
9291	PG0198	2017-09-09 09:10:00+03	2017-09-09 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9292	PG0198	2017-08-25 09:10:00+03	2017-08-25 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9293	PG0198	2017-09-05 09:10:00+03	2017-09-05 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9294	PG0198	2017-09-14 09:10:00+03	2017-09-14 15:00:00+03	LED	IKT	Cancelled	321	\N	\N
9295	PG0198	2017-07-30 09:10:00+03	2017-07-30 15:00:00+03	LED	IKT	Arrived	321	2017-07-30 09:15:00+03	2017-07-30 15:05:00+03
9296	PG0198	2017-08-28 09:10:00+03	2017-08-28 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9297	PG0198	2017-08-15 09:10:00+03	2017-08-15 15:00:00+03	LED	IKT	Arrived	321	2017-08-15 09:14:00+03	2017-08-15 15:06:00+03
9298	PG0198	2017-08-10 09:10:00+03	2017-08-10 15:00:00+03	LED	IKT	Arrived	321	2017-08-10 09:12:00+03	2017-08-10 15:05:00+03
9299	PG0198	2017-08-08 09:10:00+03	2017-08-08 15:00:00+03	LED	IKT	Arrived	321	2017-08-08 09:15:00+03	2017-08-08 15:02:00+03
9300	PG0198	2017-08-17 09:10:00+03	2017-08-17 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9301	PG0198	2017-08-19 09:10:00+03	2017-08-19 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9302	PG0198	2017-08-24 09:10:00+03	2017-08-24 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9303	PG0198	2017-08-03 09:10:00+03	2017-08-03 15:00:00+03	LED	IKT	Arrived	321	2017-08-03 09:13:00+03	2017-08-03 15:04:00+03
9304	PG0198	2017-09-11 09:10:00+03	2017-09-11 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9305	PG0198	2017-08-31 09:10:00+03	2017-08-31 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9306	PG0198	2017-08-02 09:10:00+03	2017-08-02 15:00:00+03	LED	IKT	Arrived	321	2017-08-02 09:12:00+03	2017-08-02 15:02:00+03
9307	PG0198	2017-07-16 09:10:00+03	2017-07-16 15:00:00+03	LED	IKT	Arrived	321	2017-07-16 09:16:00+03	2017-07-16 15:05:00+03
9308	PG0198	2017-07-23 09:10:00+03	2017-07-23 15:00:00+03	LED	IKT	Arrived	321	2017-07-23 12:19:00+03	2017-07-23 18:08:00+03
9309	PG0198	2017-08-14 09:10:00+03	2017-08-14 15:00:00+03	LED	IKT	Arrived	321	2017-08-14 09:15:00+03	2017-08-14 15:11:00+03
9310	PG0198	2017-07-31 09:10:00+03	2017-07-31 15:00:00+03	LED	IKT	Arrived	321	2017-07-31 09:14:00+03	2017-07-31 15:09:00+03
9311	PG0198	2017-07-24 09:10:00+03	2017-07-24 15:00:00+03	LED	IKT	Arrived	321	2017-07-24 09:12:00+03	2017-07-24 15:08:00+03
9312	PG0198	2017-08-18 09:10:00+03	2017-08-18 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9313	PG0198	2017-08-06 09:10:00+03	2017-08-06 15:00:00+03	LED	IKT	Arrived	321	2017-08-06 09:12:00+03	2017-08-06 15:03:00+03
9314	PG0198	2017-09-02 09:10:00+03	2017-09-02 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9315	PG0198	2017-09-13 09:10:00+03	2017-09-13 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9316	PG0198	2017-07-28 09:10:00+03	2017-07-28 15:00:00+03	LED	IKT	Arrived	321	2017-07-28 09:13:00+03	2017-07-28 15:02:00+03
9317	PG0198	2017-09-01 09:10:00+03	2017-09-01 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9318	PG0198	2017-08-01 09:10:00+03	2017-08-01 15:00:00+03	LED	IKT	Arrived	321	2017-08-01 09:16:00+03	2017-08-01 15:04:00+03
9319	PG0198	2017-07-17 09:10:00+03	2017-07-17 15:00:00+03	LED	IKT	Arrived	321	2017-07-17 12:47:00+03	2017-07-17 18:40:00+03
9320	PG0198	2017-09-07 09:10:00+03	2017-09-07 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9321	PG0198	2017-08-30 09:10:00+03	2017-08-30 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9322	PG0198	2017-08-27 09:10:00+03	2017-08-27 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9323	PG0198	2017-08-20 09:10:00+03	2017-08-20 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9324	PG0198	2017-07-26 09:10:00+03	2017-07-26 15:00:00+03	LED	IKT	Arrived	321	2017-07-26 09:14:00+03	2017-07-26 15:00:00+03
9325	PG0198	2017-08-07 09:10:00+03	2017-08-07 15:00:00+03	LED	IKT	Arrived	321	2017-08-07 09:16:00+03	2017-08-07 15:05:00+03
9326	PG0198	2017-07-27 09:10:00+03	2017-07-27 15:00:00+03	LED	IKT	Arrived	321	2017-07-27 09:14:00+03	2017-07-27 15:02:00+03
9327	PG0198	2017-08-21 09:10:00+03	2017-08-21 15:00:00+03	LED	IKT	Scheduled	321	\N	\N
9328	PG0198	2017-07-22 09:10:00+03	2017-07-22 15:00:00+03	LED	IKT	Arrived	321	2017-07-22 09:12:00+03	2017-07-22 15:08:00+03
9329	PG0198	2017-08-09 09:10:00+03	2017-08-09 15:00:00+03	LED	IKT	Arrived	321	2017-08-09 09:11:00+03	2017-08-09 15:04:00+03
9330	PG0356	2017-08-23 19:10:00+03	2017-08-24 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9331	PG0356	2017-08-24 19:10:00+03	2017-08-25 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9332	PG0356	2017-07-21 19:10:00+03	2017-07-22 03:15:00+03	LED	KHV	Arrived	763	2017-07-21 19:12:00+03	2017-07-22 03:26:00+03
9333	PG0356	2017-07-31 19:10:00+03	2017-08-01 03:15:00+03	LED	KHV	Arrived	763	2017-07-31 19:14:00+03	2017-08-01 03:23:00+03
9334	PG0356	2017-08-10 19:10:00+03	2017-08-11 03:15:00+03	LED	KHV	Arrived	763	2017-08-10 19:13:00+03	2017-08-11 03:20:00+03
9335	PG0356	2017-09-08 19:10:00+03	2017-09-09 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9336	PG0356	2017-07-16 19:10:00+03	2017-07-17 03:15:00+03	LED	KHV	Arrived	763	2017-07-16 19:14:00+03	2017-07-17 03:20:00+03
9337	PG0356	2017-08-16 19:10:00+03	2017-08-17 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9338	PG0356	2017-08-06 19:10:00+03	2017-08-07 03:15:00+03	LED	KHV	Arrived	763	2017-08-06 19:13:00+03	2017-08-07 03:11:00+03
9339	PG0356	2017-08-31 19:10:00+03	2017-09-01 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9340	PG0356	2017-08-08 19:10:00+03	2017-08-09 03:15:00+03	LED	KHV	Arrived	763	2017-08-08 19:10:00+03	2017-08-09 03:21:00+03
9341	PG0356	2017-08-01 19:10:00+03	2017-08-02 03:15:00+03	LED	KHV	Arrived	763	2017-08-01 19:14:00+03	2017-08-02 03:18:00+03
9342	PG0356	2017-08-19 19:10:00+03	2017-08-20 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9343	PG0356	2017-08-22 19:10:00+03	2017-08-23 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9344	PG0356	2017-08-07 19:10:00+03	2017-08-08 03:15:00+03	LED	KHV	Arrived	763	2017-08-07 19:14:00+03	2017-08-08 03:25:00+03
9345	PG0356	2017-09-14 19:10:00+03	2017-09-15 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9346	PG0356	2017-08-18 19:10:00+03	2017-08-19 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9347	PG0356	2017-08-15 19:10:00+03	2017-08-16 03:15:00+03	LED	KHV	On Time	763	\N	\N
9348	PG0356	2017-08-11 19:10:00+03	2017-08-12 03:15:00+03	LED	KHV	Arrived	763	2017-08-11 22:06:00+03	2017-08-12 06:00:00+03
9349	PG0356	2017-08-21 19:10:00+03	2017-08-22 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9350	PG0356	2017-09-01 19:10:00+03	2017-09-02 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9351	PG0356	2017-08-27 19:10:00+03	2017-08-28 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9352	PG0356	2017-07-26 19:10:00+03	2017-07-27 03:15:00+03	LED	KHV	Arrived	763	2017-07-26 19:14:00+03	2017-07-27 03:22:00+03
9353	PG0356	2017-09-07 19:10:00+03	2017-09-08 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9354	PG0356	2017-08-02 19:10:00+03	2017-08-03 03:15:00+03	LED	KHV	Arrived	763	2017-08-02 19:13:00+03	2017-08-03 03:16:00+03
9355	PG0356	2017-08-26 19:10:00+03	2017-08-27 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9356	PG0356	2017-07-20 19:10:00+03	2017-07-21 03:15:00+03	LED	KHV	Arrived	763	2017-07-20 19:12:00+03	2017-07-21 03:15:00+03
9357	PG0356	2017-09-06 19:10:00+03	2017-09-07 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9358	PG0356	2017-09-02 19:10:00+03	2017-09-03 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9359	PG0356	2017-07-18 19:10:00+03	2017-07-19 03:15:00+03	LED	KHV	Arrived	763	2017-07-18 19:13:00+03	2017-07-19 03:25:00+03
9360	PG0356	2017-08-04 19:10:00+03	2017-08-05 03:15:00+03	LED	KHV	Arrived	763	2017-08-04 19:13:00+03	2017-08-05 03:17:00+03
9361	PG0356	2017-08-13 19:10:00+03	2017-08-14 03:15:00+03	LED	KHV	Arrived	763	2017-08-13 19:14:00+03	2017-08-14 03:18:00+03
9362	PG0356	2017-08-09 19:10:00+03	2017-08-10 03:15:00+03	LED	KHV	Arrived	763	2017-08-09 19:15:00+03	2017-08-10 03:15:00+03
9363	PG0356	2017-08-28 19:10:00+03	2017-08-29 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9364	PG0356	2017-07-22 19:10:00+03	2017-07-23 03:15:00+03	LED	KHV	Arrived	763	2017-07-22 19:10:00+03	2017-07-23 03:19:00+03
9365	PG0356	2017-08-30 19:10:00+03	2017-08-31 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9366	PG0356	2017-09-05 19:10:00+03	2017-09-06 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9367	PG0356	2017-08-25 19:10:00+03	2017-08-26 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9368	PG0356	2017-09-11 19:10:00+03	2017-09-12 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9369	PG0356	2017-09-04 19:10:00+03	2017-09-05 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9370	PG0356	2017-09-03 19:10:00+03	2017-09-04 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9371	PG0356	2017-09-09 19:10:00+03	2017-09-10 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9372	PG0356	2017-08-20 19:10:00+03	2017-08-21 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9373	PG0356	2017-08-14 19:10:00+03	2017-08-15 03:15:00+03	LED	KHV	Arrived	763	2017-08-14 19:12:00+03	2017-08-15 03:10:00+03
9374	PG0356	2017-07-19 19:10:00+03	2017-07-20 03:15:00+03	LED	KHV	Arrived	763	2017-07-19 19:11:00+03	2017-07-20 03:15:00+03
9375	PG0356	2017-08-17 19:10:00+03	2017-08-18 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9376	PG0356	2017-09-13 19:10:00+03	2017-09-14 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9377	PG0356	2017-08-05 19:10:00+03	2017-08-06 03:15:00+03	LED	KHV	Arrived	763	2017-08-05 19:13:00+03	2017-08-06 03:13:00+03
9378	PG0356	2017-07-25 19:10:00+03	2017-07-26 03:15:00+03	LED	KHV	Arrived	763	2017-07-25 19:12:00+03	2017-07-26 03:09:00+03
9379	PG0356	2017-07-17 19:10:00+03	2017-07-18 03:15:00+03	LED	KHV	Arrived	763	2017-07-17 19:12:00+03	2017-07-18 03:15:00+03
9380	PG0356	2017-07-27 19:10:00+03	2017-07-28 03:15:00+03	LED	KHV	Arrived	763	2017-07-27 19:16:00+03	2017-07-28 03:16:00+03
9381	PG0356	2017-07-23 19:10:00+03	2017-07-24 03:15:00+03	LED	KHV	Arrived	763	2017-07-23 22:37:00+03	2017-07-24 06:39:00+03
9382	PG0356	2017-08-03 19:10:00+03	2017-08-04 03:15:00+03	LED	KHV	Arrived	763	2017-08-03 19:14:00+03	2017-08-04 03:14:00+03
9383	PG0356	2017-09-10 19:10:00+03	2017-09-11 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9384	PG0356	2017-09-12 19:10:00+03	2017-09-13 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9385	PG0356	2017-07-24 19:10:00+03	2017-07-25 03:15:00+03	LED	KHV	Arrived	763	2017-07-24 19:13:00+03	2017-07-25 03:15:00+03
9386	PG0356	2017-07-29 19:10:00+03	2017-07-30 03:15:00+03	LED	KHV	Arrived	763	2017-07-29 19:11:00+03	2017-07-30 03:05:00+03
9387	PG0356	2017-08-29 19:10:00+03	2017-08-30 03:15:00+03	LED	KHV	Scheduled	763	\N	\N
9388	PG0356	2017-07-30 19:10:00+03	2017-07-31 03:15:00+03	LED	KHV	Arrived	763	2017-07-30 19:12:00+03	2017-07-31 03:20:00+03
9389	PG0356	2017-07-28 19:10:00+03	2017-07-29 03:15:00+03	LED	KHV	Arrived	763	2017-07-28 19:13:00+03	2017-07-29 03:19:00+03
9390	PG0356	2017-08-12 19:10:00+03	2017-08-13 03:15:00+03	LED	KHV	Arrived	763	2017-08-12 19:17:00+03	2017-08-13 03:17:00+03
9391	PG0436	2017-07-22 10:55:00+03	2017-07-22 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-22 11:00:00+03	2017-07-22 13:00:00+03
9392	PG0436	2017-08-13 10:55:00+03	2017-08-13 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-13 10:56:00+03	2017-08-13 12:58:00+03
9393	PG0436	2017-07-30 10:55:00+03	2017-07-30 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-30 10:56:00+03	2017-07-30 12:57:00+03
9394	PG0436	2017-07-28 10:55:00+03	2017-07-28 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-28 10:59:00+03	2017-07-28 12:59:00+03
9395	PG0436	2017-08-10 10:55:00+03	2017-08-10 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-10 11:01:00+03	2017-08-10 13:01:00+03
9396	PG0436	2017-09-05 10:55:00+03	2017-09-05 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9397	PG0436	2017-09-10 10:55:00+03	2017-09-10 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9398	PG0436	2017-08-29 10:55:00+03	2017-08-29 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9399	PG0436	2017-08-11 10:55:00+03	2017-08-11 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-11 10:56:00+03	2017-08-11 12:57:00+03
9400	PG0436	2017-08-06 10:55:00+03	2017-08-06 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-06 10:59:00+03	2017-08-06 12:58:00+03
9401	PG0436	2017-07-16 10:55:00+03	2017-07-16 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-16 10:59:00+03	2017-07-16 12:59:00+03
9402	PG0436	2017-07-26 10:55:00+03	2017-07-26 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-26 10:56:00+03	2017-07-26 12:54:00+03
9403	PG0436	2017-07-29 10:55:00+03	2017-07-29 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-29 10:59:00+03	2017-07-29 12:58:00+03
9404	PG0436	2017-09-02 10:55:00+03	2017-09-02 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9405	PG0436	2017-08-07 10:55:00+03	2017-08-07 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-07 10:57:00+03	2017-08-07 12:59:00+03
9406	PG0436	2017-08-20 10:55:00+03	2017-08-20 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9407	PG0436	2017-08-24 10:55:00+03	2017-08-24 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9408	PG0436	2017-07-23 10:55:00+03	2017-07-23 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-23 10:57:00+03	2017-07-23 12:58:00+03
9409	PG0436	2017-08-25 10:55:00+03	2017-08-25 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9410	PG0436	2017-08-08 10:55:00+03	2017-08-08 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-08 10:56:00+03	2017-08-08 12:56:00+03
9411	PG0436	2017-09-13 10:55:00+03	2017-09-13 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9412	PG0436	2017-08-16 10:55:00+03	2017-08-16 12:55:00+03	LED	IAR	On Time	CN1	\N	\N
9413	PG0436	2017-08-04 10:55:00+03	2017-08-04 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-04 10:56:00+03	2017-08-04 12:56:00+03
9414	PG0436	2017-08-28 10:55:00+03	2017-08-28 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9415	PG0436	2017-09-08 10:55:00+03	2017-09-08 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9416	PG0436	2017-07-20 10:55:00+03	2017-07-20 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-20 10:56:00+03	2017-07-20 12:57:00+03
9417	PG0436	2017-07-27 10:55:00+03	2017-07-27 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-27 11:02:00+03	2017-07-27 13:01:00+03
9418	PG0436	2017-08-27 10:55:00+03	2017-08-27 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9419	PG0436	2017-08-18 10:55:00+03	2017-08-18 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9420	PG0436	2017-08-15 10:55:00+03	2017-08-15 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-15 10:57:00+03	2017-08-15 12:55:00+03
9421	PG0436	2017-08-31 10:55:00+03	2017-08-31 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9422	PG0436	2017-07-19 10:55:00+03	2017-07-19 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-19 13:33:00+03	2017-07-19 15:32:00+03
9423	PG0436	2017-09-03 10:55:00+03	2017-09-03 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9424	PG0436	2017-07-25 10:55:00+03	2017-07-25 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-25 10:57:00+03	2017-07-25 12:54:00+03
9425	PG0436	2017-09-06 10:55:00+03	2017-09-06 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9426	PG0436	2017-08-01 10:55:00+03	2017-08-01 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-01 10:57:00+03	2017-08-01 12:57:00+03
9427	PG0436	2017-07-17 10:55:00+03	2017-07-17 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-17 10:56:00+03	2017-07-17 12:54:00+03
9428	PG0436	2017-07-31 10:55:00+03	2017-07-31 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-31 10:56:00+03	2017-07-31 12:56:00+03
9429	PG0436	2017-09-12 10:55:00+03	2017-09-12 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9430	PG0436	2017-08-23 10:55:00+03	2017-08-23 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9431	PG0436	2017-09-07 10:55:00+03	2017-09-07 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9432	PG0436	2017-09-11 10:55:00+03	2017-09-11 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9433	PG0436	2017-08-03 10:55:00+03	2017-08-03 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-03 14:06:00+03	2017-08-03 16:06:00+03
9434	PG0436	2017-07-21 10:55:00+03	2017-07-21 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-21 11:00:00+03	2017-07-21 13:01:00+03
9435	PG0436	2017-07-18 10:55:00+03	2017-07-18 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-18 10:59:00+03	2017-07-18 13:00:00+03
9436	PG0436	2017-08-12 10:55:00+03	2017-08-12 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-12 11:00:00+03	2017-08-12 12:57:00+03
9437	PG0436	2017-08-17 10:55:00+03	2017-08-17 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9438	PG0436	2017-09-04 10:55:00+03	2017-09-04 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9439	PG0436	2017-08-21 10:55:00+03	2017-08-21 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9440	PG0436	2017-08-05 10:55:00+03	2017-08-05 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-05 10:58:00+03	2017-08-05 13:00:00+03
9441	PG0436	2017-09-14 10:55:00+03	2017-09-14 12:55:00+03	LED	IAR	Cancelled	CN1	\N	\N
9442	PG0436	2017-07-24 10:55:00+03	2017-07-24 12:55:00+03	LED	IAR	Arrived	CN1	2017-07-24 10:57:00+03	2017-07-24 12:57:00+03
9443	PG0436	2017-08-19 10:55:00+03	2017-08-19 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9444	PG0436	2017-08-22 10:55:00+03	2017-08-22 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9445	PG0436	2017-08-09 10:55:00+03	2017-08-09 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-09 10:58:00+03	2017-08-09 12:58:00+03
9446	PG0436	2017-08-02 10:55:00+03	2017-08-02 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-02 10:58:00+03	2017-08-02 12:58:00+03
9447	PG0436	2017-09-09 10:55:00+03	2017-09-09 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9448	PG0436	2017-08-26 10:55:00+03	2017-08-26 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9449	PG0436	2017-08-14 10:55:00+03	2017-08-14 12:55:00+03	LED	IAR	Arrived	CN1	2017-08-14 10:57:00+03	2017-08-14 12:59:00+03
9450	PG0436	2017-09-01 10:55:00+03	2017-09-01 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9451	PG0436	2017-08-30 10:55:00+03	2017-08-30 12:55:00+03	LED	IAR	Scheduled	CN1	\N	\N
9452	PG0360	2017-07-24 09:00:00+03	2017-07-24 11:35:00+03	LED	REN	Arrived	CR2	2017-07-24 09:05:00+03	2017-07-24 11:39:00+03
9453	PG0360	2017-08-23 09:00:00+03	2017-08-23 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9454	PG0360	2017-08-22 09:00:00+03	2017-08-22 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9455	PG0360	2017-08-19 09:00:00+03	2017-08-19 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9456	PG0360	2017-07-27 09:00:00+03	2017-07-27 11:35:00+03	LED	REN	Arrived	CR2	2017-07-27 09:04:00+03	2017-07-27 11:38:00+03
9457	PG0360	2017-08-02 09:00:00+03	2017-08-02 11:35:00+03	LED	REN	Arrived	CR2	2017-08-02 09:04:00+03	2017-08-02 11:40:00+03
9458	PG0360	2017-08-18 09:00:00+03	2017-08-18 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9459	PG0360	2017-08-11 09:00:00+03	2017-08-11 11:35:00+03	LED	REN	Arrived	CR2	2017-08-11 09:07:00+03	2017-08-11 11:45:00+03
9460	PG0360	2017-08-30 09:00:00+03	2017-08-30 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9461	PG0360	2017-09-11 09:00:00+03	2017-09-11 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9462	PG0360	2017-09-10 09:00:00+03	2017-09-10 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9463	PG0360	2017-09-14 09:00:00+03	2017-09-14 11:35:00+03	LED	REN	Cancelled	CR2	\N	\N
9464	PG0360	2017-09-04 09:00:00+03	2017-09-04 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9465	PG0360	2017-09-09 09:00:00+03	2017-09-09 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9466	PG0360	2017-08-08 09:00:00+03	2017-08-08 11:35:00+03	LED	REN	Arrived	CR2	2017-08-08 09:05:00+03	2017-08-08 11:39:00+03
9467	PG0360	2017-07-16 09:00:00+03	2017-07-16 11:35:00+03	LED	REN	Arrived	CR2	2017-07-16 09:09:00+03	2017-07-16 11:45:00+03
9468	PG0360	2017-09-03 09:00:00+03	2017-09-03 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9469	PG0360	2017-07-23 09:00:00+03	2017-07-23 11:35:00+03	LED	REN	Arrived	CR2	2017-07-23 09:01:00+03	2017-07-23 11:37:00+03
9470	PG0360	2017-07-31 09:00:00+03	2017-07-31 11:35:00+03	LED	REN	Arrived	CR2	2017-07-31 09:03:00+03	2017-07-31 11:39:00+03
9471	PG0360	2017-08-06 09:00:00+03	2017-08-06 11:35:00+03	LED	REN	Arrived	CR2	2017-08-06 09:02:00+03	2017-08-06 11:37:00+03
9472	PG0360	2017-07-29 09:00:00+03	2017-07-29 11:35:00+03	LED	REN	Arrived	CR2	2017-07-29 09:02:00+03	2017-07-29 11:37:00+03
9473	PG0360	2017-07-19 09:00:00+03	2017-07-19 11:35:00+03	LED	REN	Arrived	CR2	2017-07-19 09:04:00+03	2017-07-19 11:38:00+03
9474	PG0360	2017-09-07 09:00:00+03	2017-09-07 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9475	PG0360	2017-07-21 09:00:00+03	2017-07-21 11:35:00+03	LED	REN	Arrived	CR2	2017-07-21 09:01:00+03	2017-07-21 11:39:00+03
9476	PG0360	2017-08-14 09:00:00+03	2017-08-14 11:35:00+03	LED	REN	Arrived	CR2	2017-08-14 09:03:00+03	2017-08-14 11:37:00+03
9477	PG0360	2017-08-10 09:00:00+03	2017-08-10 11:35:00+03	LED	REN	Arrived	CR2	2017-08-10 09:06:00+03	2017-08-10 11:40:00+03
9479	PG0360	2017-09-13 09:00:00+03	2017-09-13 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9480	PG0360	2017-07-28 09:00:00+03	2017-07-28 11:35:00+03	LED	REN	Arrived	CR2	2017-07-28 09:04:00+03	2017-07-28 11:40:00+03
9481	PG0360	2017-08-24 09:00:00+03	2017-08-24 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9482	PG0360	2017-07-26 09:00:00+03	2017-07-26 11:35:00+03	LED	REN	Arrived	CR2	2017-07-26 09:02:00+03	2017-07-26 11:37:00+03
9483	PG0360	2017-08-12 09:00:00+03	2017-08-12 11:35:00+03	LED	REN	Arrived	CR2	2017-08-12 09:01:00+03	2017-08-12 11:36:00+03
9484	PG0360	2017-08-13 09:00:00+03	2017-08-13 11:35:00+03	LED	REN	Arrived	CR2	2017-08-13 09:03:00+03	2017-08-13 11:37:00+03
9485	PG0360	2017-08-16 09:00:00+03	2017-08-16 11:35:00+03	LED	REN	On Time	CR2	\N	\N
9486	PG0360	2017-08-05 09:00:00+03	2017-08-05 11:35:00+03	LED	REN	Arrived	CR2	2017-08-05 09:02:00+03	2017-08-05 11:38:00+03
9487	PG0360	2017-09-12 09:00:00+03	2017-09-12 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9488	PG0360	2017-08-20 09:00:00+03	2017-08-20 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9489	PG0360	2017-08-31 09:00:00+03	2017-08-31 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9490	PG0360	2017-08-01 09:00:00+03	2017-08-01 11:35:00+03	LED	REN	Arrived	CR2	2017-08-01 09:03:00+03	2017-08-01 11:39:00+03
9491	PG0360	2017-08-21 09:00:00+03	2017-08-21 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9492	PG0360	2017-07-17 09:00:00+03	2017-07-17 11:35:00+03	LED	REN	Arrived	CR2	2017-07-17 12:14:00+03	2017-07-17 14:48:00+03
9493	PG0360	2017-07-30 09:00:00+03	2017-07-30 11:35:00+03	LED	REN	Arrived	CR2	2017-07-30 09:03:00+03	2017-07-30 11:39:00+03
9494	PG0360	2017-08-03 09:00:00+03	2017-08-03 11:35:00+03	LED	REN	Arrived	CR2	2017-08-03 09:04:00+03	2017-08-03 11:39:00+03
9495	PG0360	2017-08-17 09:00:00+03	2017-08-17 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9496	PG0360	2017-07-25 09:00:00+03	2017-07-25 11:35:00+03	LED	REN	Arrived	CR2	2017-07-25 09:02:00+03	2017-07-25 11:36:00+03
9497	PG0360	2017-09-08 09:00:00+03	2017-09-08 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9498	PG0360	2017-07-20 09:00:00+03	2017-07-20 11:35:00+03	LED	REN	Arrived	CR2	2017-07-20 09:02:00+03	2017-07-20 11:38:00+03
9499	PG0360	2017-08-26 09:00:00+03	2017-08-26 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9500	PG0360	2017-08-25 09:00:00+03	2017-08-25 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9501	PG0360	2017-08-07 09:00:00+03	2017-08-07 11:35:00+03	LED	REN	Arrived	CR2	2017-08-07 09:01:00+03	2017-08-07 11:37:00+03
9502	PG0360	2017-08-29 09:00:00+03	2017-08-29 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9503	PG0360	2017-07-18 09:00:00+03	2017-07-18 11:35:00+03	LED	REN	Arrived	CR2	2017-07-18 09:02:00+03	2017-07-18 11:39:00+03
9504	PG0360	2017-08-04 09:00:00+03	2017-08-04 11:35:00+03	LED	REN	Arrived	CR2	2017-08-04 09:01:00+03	2017-08-04 11:36:00+03
9505	PG0360	2017-09-06 09:00:00+03	2017-09-06 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9506	PG0360	2017-09-05 09:00:00+03	2017-09-05 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9507	PG0360	2017-08-27 09:00:00+03	2017-08-27 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9508	PG0360	2017-08-09 09:00:00+03	2017-08-09 11:35:00+03	LED	REN	Arrived	CR2	2017-08-09 09:05:00+03	2017-08-09 11:38:00+03
9509	PG0360	2017-09-02 09:00:00+03	2017-09-02 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9510	PG0360	2017-09-01 09:00:00+03	2017-09-01 11:35:00+03	LED	REN	Scheduled	CR2	\N	\N
9511	PG0360	2017-07-22 09:00:00+03	2017-07-22 11:35:00+03	LED	REN	Arrived	CR2	2017-07-22 09:03:00+03	2017-07-22 11:38:00+03
9512	PG0360	2017-08-15 09:00:00+03	2017-08-15 11:35:00+03	LED	REN	Arrived	CR2	2017-08-15 09:06:00+03	2017-08-15 11:42:00+03
9513	PG0285	2017-08-20 10:50:00+03	2017-08-20 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9514	PG0285	2017-08-24 10:50:00+03	2017-08-24 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9515	PG0285	2017-08-13 10:50:00+03	2017-08-13 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-13 10:52:00+03	2017-08-13 12:21:00+03
9516	PG0285	2017-09-12 10:50:00+03	2017-09-12 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9517	PG0285	2017-09-14 10:50:00+03	2017-09-14 12:20:00+03	LED	KVX	Cancelled	SU9	\N	\N
9518	PG0285	2017-08-08 10:50:00+03	2017-08-08 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-08 10:50:00+03	2017-08-08 12:21:00+03
9519	PG0285	2017-08-01 10:50:00+03	2017-08-01 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-01 10:51:00+03	2017-08-01 12:21:00+03
9520	PG0285	2017-08-23 10:50:00+03	2017-08-23 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9521	PG0285	2017-08-12 10:50:00+03	2017-08-12 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-12 10:53:00+03	2017-08-12 12:22:00+03
9522	PG0285	2017-07-23 10:50:00+03	2017-07-23 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-23 14:28:00+03	2017-07-23 15:56:00+03
9523	PG0285	2017-07-28 10:50:00+03	2017-07-28 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-28 10:50:00+03	2017-07-28 12:21:00+03
9524	PG0285	2017-09-09 10:50:00+03	2017-09-09 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9525	PG0285	2017-08-30 10:50:00+03	2017-08-30 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9526	PG0285	2017-07-21 10:50:00+03	2017-07-21 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-21 10:52:00+03	2017-07-21 12:22:00+03
9527	PG0285	2017-08-28 10:50:00+03	2017-08-28 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9528	PG0285	2017-07-16 10:50:00+03	2017-07-16 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-16 10:53:00+03	2017-07-16 12:22:00+03
9529	PG0285	2017-09-06 10:50:00+03	2017-09-06 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9530	PG0285	2017-08-19 10:50:00+03	2017-08-19 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9531	PG0285	2017-07-25 10:50:00+03	2017-07-25 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-25 10:57:00+03	2017-07-25 12:27:00+03
9532	PG0285	2017-09-04 10:50:00+03	2017-09-04 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9533	PG0285	2017-08-06 10:50:00+03	2017-08-06 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-06 10:54:00+03	2017-08-06 12:24:00+03
9534	PG0285	2017-08-25 10:50:00+03	2017-08-25 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9535	PG0285	2017-08-16 10:50:00+03	2017-08-16 12:20:00+03	LED	KVX	On Time	SU9	\N	\N
9536	PG0285	2017-08-27 10:50:00+03	2017-08-27 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9537	PG0285	2017-08-29 10:50:00+03	2017-08-29 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9538	PG0285	2017-07-24 10:50:00+03	2017-07-24 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-24 10:51:00+03	2017-07-24 12:20:00+03
9539	PG0285	2017-09-01 10:50:00+03	2017-09-01 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9540	PG0285	2017-08-21 10:50:00+03	2017-08-21 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9541	PG0285	2017-08-15 10:50:00+03	2017-08-15 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-15 10:51:00+03	2017-08-15 12:20:00+03
9542	PG0285	2017-08-18 10:50:00+03	2017-08-18 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9543	PG0285	2017-08-17 10:50:00+03	2017-08-17 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9544	PG0285	2017-08-26 10:50:00+03	2017-08-26 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9545	PG0285	2017-07-31 10:50:00+03	2017-07-31 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-31 10:55:00+03	2017-07-31 12:26:00+03
9546	PG0285	2017-09-07 10:50:00+03	2017-09-07 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9547	PG0285	2017-08-11 10:50:00+03	2017-08-11 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-11 10:51:00+03	2017-08-11 12:22:00+03
9548	PG0285	2017-09-03 10:50:00+03	2017-09-03 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9549	PG0285	2017-09-05 10:50:00+03	2017-09-05 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9550	PG0285	2017-08-02 10:50:00+03	2017-08-02 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-02 10:55:00+03	2017-08-02 12:24:00+03
9551	PG0285	2017-07-27 10:50:00+03	2017-07-27 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-27 10:54:00+03	2017-07-27 12:23:00+03
9552	PG0285	2017-07-29 10:50:00+03	2017-07-29 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-29 10:53:00+03	2017-07-29 12:24:00+03
9553	PG0285	2017-07-18 10:50:00+03	2017-07-18 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-18 10:53:00+03	2017-07-18 12:23:00+03
9554	PG0285	2017-07-26 10:50:00+03	2017-07-26 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-26 10:51:00+03	2017-07-26 12:20:00+03
9555	PG0285	2017-08-14 10:50:00+03	2017-08-14 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-14 10:55:00+03	2017-08-14 12:25:00+03
9556	PG0285	2017-07-22 10:50:00+03	2017-07-22 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-22 10:56:00+03	2017-07-22 12:26:00+03
9557	PG0285	2017-07-17 10:50:00+03	2017-07-17 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-17 10:51:00+03	2017-07-17 12:22:00+03
9558	PG0285	2017-08-05 10:50:00+03	2017-08-05 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-05 10:55:00+03	2017-08-05 12:25:00+03
9559	PG0285	2017-07-30 10:50:00+03	2017-07-30 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-30 10:56:00+03	2017-07-30 12:25:00+03
9560	PG0285	2017-07-20 10:50:00+03	2017-07-20 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-20 10:50:00+03	2017-07-20 12:20:00+03
9561	PG0285	2017-08-09 10:50:00+03	2017-08-09 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-09 10:54:00+03	2017-08-09 12:23:00+03
9562	PG0285	2017-08-22 10:50:00+03	2017-08-22 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9563	PG0285	2017-07-19 10:50:00+03	2017-07-19 12:20:00+03	LED	KVX	Arrived	SU9	2017-07-19 10:52:00+03	2017-07-19 12:23:00+03
9564	PG0285	2017-08-04 10:50:00+03	2017-08-04 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-04 13:43:00+03	2017-08-04 15:12:00+03
9565	PG0285	2017-08-03 10:50:00+03	2017-08-03 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-03 10:54:00+03	2017-08-03 12:25:00+03
9566	PG0285	2017-08-31 10:50:00+03	2017-08-31 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9567	PG0285	2017-09-10 10:50:00+03	2017-09-10 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9568	PG0285	2017-08-10 10:50:00+03	2017-08-10 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-10 10:59:00+03	2017-08-10 12:30:00+03
9569	PG0285	2017-08-07 10:50:00+03	2017-08-07 12:20:00+03	LED	KVX	Arrived	SU9	2017-08-07 10:55:00+03	2017-08-07 12:25:00+03
9570	PG0285	2017-09-02 10:50:00+03	2017-09-02 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9571	PG0285	2017-09-11 10:50:00+03	2017-09-11 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9572	PG0285	2017-09-13 10:50:00+03	2017-09-13 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9573	PG0285	2017-09-08 10:50:00+03	2017-09-08 12:20:00+03	LED	KVX	Scheduled	SU9	\N	\N
9574	PG0488	2017-07-28 13:30:00+03	2017-07-28 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-28 13:37:00+03	2017-07-28 15:01:00+03
9575	PG0488	2017-09-14 13:30:00+03	2017-09-14 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9576	PG0488	2017-07-21 13:30:00+03	2017-07-21 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-21 13:34:00+03	2017-07-21 15:00:00+03
9577	PG0488	2017-08-09 13:30:00+03	2017-08-09 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-09 13:32:00+03	2017-08-09 14:56:00+03
9578	PG0488	2017-08-26 13:30:00+03	2017-08-26 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9579	PG0488	2017-08-18 13:30:00+03	2017-08-18 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9580	PG0488	2017-07-30 13:30:00+03	2017-07-30 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-30 13:37:00+03	2017-07-30 15:02:00+03
9581	PG0488	2017-07-26 13:30:00+03	2017-07-26 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-26 13:34:00+03	2017-07-26 14:58:00+03
9582	PG0488	2017-08-14 13:30:00+03	2017-08-14 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-14 13:32:00+03	2017-08-14 14:57:00+03
9583	PG0488	2017-08-03 13:30:00+03	2017-08-03 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-03 13:33:00+03	2017-08-03 14:57:00+03
9584	PG0488	2017-08-27 13:30:00+03	2017-08-27 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9585	PG0488	2017-09-05 13:30:00+03	2017-09-05 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9586	PG0488	2017-07-17 13:30:00+03	2017-07-17 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-17 13:33:00+03	2017-07-17 14:57:00+03
9587	PG0488	2017-07-19 13:30:00+03	2017-07-19 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-19 13:33:00+03	2017-07-19 15:01:00+03
9588	PG0488	2017-09-08 13:30:00+03	2017-09-08 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9589	PG0488	2017-07-24 13:30:00+03	2017-07-24 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-24 13:37:00+03	2017-07-24 15:02:00+03
9590	PG0488	2017-08-16 13:30:00+03	2017-08-16 14:55:00+03	LED	CSY	Delayed	SU9	\N	\N
9591	PG0488	2017-08-05 13:30:00+03	2017-08-05 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-05 13:31:00+03	2017-08-05 14:55:00+03
9592	PG0488	2017-08-08 13:30:00+03	2017-08-08 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-08 13:34:00+03	2017-08-08 14:59:00+03
9593	PG0488	2017-08-19 13:30:00+03	2017-08-19 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9594	PG0488	2017-08-13 13:30:00+03	2017-08-13 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-13 13:35:00+03	2017-08-13 15:01:00+03
9595	PG0488	2017-09-07 13:30:00+03	2017-09-07 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9596	PG0488	2017-07-18 13:30:00+03	2017-07-18 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-18 13:32:00+03	2017-07-18 14:58:00+03
9597	PG0488	2017-09-11 13:30:00+03	2017-09-11 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9598	PG0488	2017-08-10 13:30:00+03	2017-08-10 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-10 13:31:00+03	2017-08-10 14:56:00+03
9599	PG0488	2017-09-12 13:30:00+03	2017-09-12 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9600	PG0488	2017-08-21 13:30:00+03	2017-08-21 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9601	PG0488	2017-07-22 13:30:00+03	2017-07-22 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-22 13:35:00+03	2017-07-22 15:00:00+03
9602	PG0488	2017-07-29 13:30:00+03	2017-07-29 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-29 13:38:00+03	2017-07-29 15:02:00+03
9603	PG0488	2017-08-04 13:30:00+03	2017-08-04 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-04 13:35:00+03	2017-08-04 15:01:00+03
9604	PG0488	2017-08-11 13:30:00+03	2017-08-11 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-11 16:23:00+03	2017-08-11 17:48:00+03
9605	PG0488	2017-08-02 13:30:00+03	2017-08-02 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-02 13:32:00+03	2017-08-02 14:57:00+03
9606	PG0488	2017-09-13 13:30:00+03	2017-09-13 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9607	PG0488	2017-09-06 13:30:00+03	2017-09-06 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9608	PG0488	2017-08-17 13:30:00+03	2017-08-17 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9609	PG0488	2017-07-25 13:30:00+03	2017-07-25 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-25 13:33:00+03	2017-07-25 14:57:00+03
9610	PG0488	2017-08-22 13:30:00+03	2017-08-22 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9611	PG0488	2017-09-02 13:30:00+03	2017-09-02 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9612	PG0488	2017-08-30 13:30:00+03	2017-08-30 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9613	PG0488	2017-07-31 13:30:00+03	2017-07-31 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-31 13:34:00+03	2017-07-31 14:58:00+03
9614	PG0488	2017-07-16 13:30:00+03	2017-07-16 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-16 13:31:00+03	2017-07-16 14:55:00+03
9615	PG0488	2017-08-01 13:30:00+03	2017-08-01 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-01 13:30:00+03	2017-08-01 14:54:00+03
9616	PG0488	2017-07-27 13:30:00+03	2017-07-27 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-27 13:31:00+03	2017-07-27 14:56:00+03
9617	PG0488	2017-08-12 13:30:00+03	2017-08-12 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-12 13:35:00+03	2017-08-12 15:00:00+03
9618	PG0488	2017-09-03 13:30:00+03	2017-09-03 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9619	PG0488	2017-09-04 13:30:00+03	2017-09-04 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9620	PG0488	2017-09-01 13:30:00+03	2017-09-01 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9621	PG0488	2017-08-07 13:30:00+03	2017-08-07 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-07 13:35:00+03	2017-08-07 15:01:00+03
9622	PG0488	2017-08-29 13:30:00+03	2017-08-29 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9623	PG0488	2017-08-25 13:30:00+03	2017-08-25 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9624	PG0488	2017-08-20 13:30:00+03	2017-08-20 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9625	PG0488	2017-08-28 13:30:00+03	2017-08-28 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9626	PG0488	2017-07-23 13:30:00+03	2017-07-23 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-23 16:34:00+03	2017-07-23 17:58:00+03
9627	PG0488	2017-09-09 13:30:00+03	2017-09-09 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9628	PG0488	2017-08-23 13:30:00+03	2017-08-23 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9629	PG0488	2017-07-20 13:30:00+03	2017-07-20 14:55:00+03	LED	CSY	Arrived	SU9	2017-07-20 13:34:00+03	2017-07-20 14:58:00+03
9630	PG0488	2017-08-15 13:30:00+03	2017-08-15 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-15 13:33:00+03	2017-08-15 14:59:00+03
9631	PG0488	2017-09-10 13:30:00+03	2017-09-10 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9632	PG0488	2017-08-24 13:30:00+03	2017-08-24 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9633	PG0488	2017-08-06 13:30:00+03	2017-08-06 14:55:00+03	LED	CSY	Arrived	SU9	2017-08-06 13:32:00+03	2017-08-06 14:56:00+03
9634	PG0488	2017-08-31 13:30:00+03	2017-08-31 14:55:00+03	LED	CSY	Scheduled	SU9	\N	\N
9635	PG0410	2017-08-28 13:15:00+03	2017-08-28 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9636	PG0410	2017-08-24 13:15:00+03	2017-08-24 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9637	PG0410	2017-07-24 13:15:00+03	2017-07-24 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-24 13:19:00+03	2017-07-24 15:34:00+03
9638	PG0410	2017-07-26 13:15:00+03	2017-07-26 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-26 13:18:00+03	2017-07-26 15:33:00+03
9639	PG0410	2017-08-07 13:15:00+03	2017-08-07 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-07 13:17:00+03	2017-08-07 15:32:00+03
9640	PG0410	2017-07-20 13:15:00+03	2017-07-20 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-20 13:17:00+03	2017-07-20 15:32:00+03
9641	PG0410	2017-07-25 13:15:00+03	2017-07-25 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-25 13:17:00+03	2017-07-25 15:32:00+03
9642	PG0410	2017-09-12 13:15:00+03	2017-09-12 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9643	PG0410	2017-08-13 13:15:00+03	2017-08-13 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-13 13:19:00+03	2017-08-13 15:38:00+03
9644	PG0410	2017-07-31 13:15:00+03	2017-07-31 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-31 13:19:00+03	2017-07-31 15:35:00+03
9645	PG0410	2017-08-30 13:15:00+03	2017-08-30 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9646	PG0410	2017-08-14 13:15:00+03	2017-08-14 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-14 13:19:00+03	2017-08-14 15:34:00+03
9647	PG0410	2017-08-22 13:15:00+03	2017-08-22 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9648	PG0410	2017-08-21 13:15:00+03	2017-08-21 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9649	PG0410	2017-08-31 13:15:00+03	2017-08-31 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9650	PG0410	2017-09-01 13:15:00+03	2017-09-01 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9651	PG0410	2017-07-17 13:15:00+03	2017-07-17 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-17 13:17:00+03	2017-07-17 15:31:00+03
9652	PG0410	2017-08-17 13:15:00+03	2017-08-17 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9653	PG0410	2017-08-10 13:15:00+03	2017-08-10 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-10 13:20:00+03	2017-08-10 15:37:00+03
9654	PG0410	2017-07-23 13:15:00+03	2017-07-23 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-23 13:21:00+03	2017-07-23 15:36:00+03
9655	PG0410	2017-08-05 13:15:00+03	2017-08-05 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-05 13:17:00+03	2017-08-05 15:29:00+03
9656	PG0410	2017-07-18 13:15:00+03	2017-07-18 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-18 13:18:00+03	2017-07-18 15:35:00+03
9657	PG0410	2017-08-06 13:15:00+03	2017-08-06 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-06 13:20:00+03	2017-08-06 15:35:00+03
9658	PG0410	2017-07-22 13:15:00+03	2017-07-22 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-22 13:18:00+03	2017-07-22 15:33:00+03
9659	PG0410	2017-07-21 13:15:00+03	2017-07-21 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-21 13:18:00+03	2017-07-21 15:34:00+03
9660	PG0410	2017-09-05 13:15:00+03	2017-09-05 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9661	PG0410	2017-07-27 13:15:00+03	2017-07-27 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-27 13:18:00+03	2017-07-27 15:35:00+03
9662	PG0410	2017-08-11 13:15:00+03	2017-08-11 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-11 13:17:00+03	2017-08-11 15:34:00+03
9663	PG0410	2017-08-20 13:15:00+03	2017-08-20 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9664	PG0410	2017-08-09 13:15:00+03	2017-08-09 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-09 13:20:00+03	2017-08-09 15:34:00+03
9665	PG0410	2017-08-26 13:15:00+03	2017-08-26 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9666	PG0410	2017-08-23 13:15:00+03	2017-08-23 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9667	PG0410	2017-07-28 13:15:00+03	2017-07-28 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-28 13:17:00+03	2017-07-28 15:30:00+03
9668	PG0410	2017-07-29 13:15:00+03	2017-07-29 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-29 13:18:00+03	2017-07-29 15:32:00+03
9669	PG0410	2017-09-10 13:15:00+03	2017-09-10 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9670	PG0410	2017-09-08 13:15:00+03	2017-09-08 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9671	PG0410	2017-07-16 13:15:00+03	2017-07-16 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-16 13:16:00+03	2017-07-16 15:30:00+03
9672	PG0410	2017-08-16 13:15:00+03	2017-08-16 15:30:00+03	LED	KLF	Delayed	CN1	\N	\N
9673	PG0410	2017-09-13 13:15:00+03	2017-09-13 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9674	PG0410	2017-08-25 13:15:00+03	2017-08-25 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9675	PG0410	2017-09-03 13:15:00+03	2017-09-03 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9676	PG0410	2017-08-27 13:15:00+03	2017-08-27 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9677	PG0410	2017-08-08 13:15:00+03	2017-08-08 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-08 13:17:00+03	2017-08-08 15:32:00+03
9678	PG0410	2017-08-04 13:15:00+03	2017-08-04 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-04 13:19:00+03	2017-08-04 15:33:00+03
9679	PG0410	2017-07-30 13:15:00+03	2017-07-30 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-30 13:21:00+03	2017-07-30 15:38:00+03
9680	PG0410	2017-09-06 13:15:00+03	2017-09-06 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9681	PG0410	2017-09-14 13:15:00+03	2017-09-14 15:30:00+03	LED	KLF	Cancelled	CN1	\N	\N
9682	PG0410	2017-09-11 13:15:00+03	2017-09-11 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9683	PG0410	2017-08-12 13:15:00+03	2017-08-12 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-12 13:17:00+03	2017-08-12 15:31:00+03
9684	PG0410	2017-07-19 13:15:00+03	2017-07-19 15:30:00+03	LED	KLF	Arrived	CN1	2017-07-19 13:19:00+03	2017-07-19 15:30:00+03
9685	PG0410	2017-08-01 13:15:00+03	2017-08-01 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-01 13:19:00+03	2017-08-01 15:32:00+03
9686	PG0410	2017-08-18 13:15:00+03	2017-08-18 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9687	PG0410	2017-08-15 13:15:00+03	2017-08-15 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-15 13:19:00+03	2017-08-15 15:36:00+03
9688	PG0410	2017-09-07 13:15:00+03	2017-09-07 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9689	PG0410	2017-09-09 13:15:00+03	2017-09-09 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9690	PG0410	2017-08-02 13:15:00+03	2017-08-02 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-02 13:18:00+03	2017-08-02 15:32:00+03
9691	PG0410	2017-08-03 13:15:00+03	2017-08-03 15:30:00+03	LED	KLF	Arrived	CN1	2017-08-03 13:22:00+03	2017-08-03 15:36:00+03
9692	PG0410	2017-08-19 13:15:00+03	2017-08-19 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9693	PG0410	2017-09-02 13:15:00+03	2017-09-02 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9694	PG0410	2017-08-29 13:15:00+03	2017-08-29 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9695	PG0410	2017-09-04 13:15:00+03	2017-09-04 15:30:00+03	LED	KLF	Scheduled	CN1	\N	\N
9696	PG0078	2017-09-07 18:25:00+03	2017-09-07 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9697	PG0077	2017-07-17 17:45:00+03	2017-07-17 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-17 17:48:00+03	2017-07-17 19:12:00+03
9698	PG0077	2017-08-20 17:45:00+03	2017-08-20 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9699	PG0078	2017-07-17 18:25:00+03	2017-07-17 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-17 18:32:00+03	2017-07-17 19:57:00+03
9700	PG0077	2017-08-17 17:45:00+03	2017-08-17 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9701	PG0078	2017-07-27 18:25:00+03	2017-07-27 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-27 18:29:00+03	2017-07-27 19:54:00+03
9702	PG0078	2017-07-25 18:25:00+03	2017-07-25 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-25 18:25:00+03	2017-07-25 19:49:00+03
9703	PG0077	2017-08-06 17:45:00+03	2017-08-06 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-06 17:48:00+03	2017-08-06 19:13:00+03
9704	PG0077	2017-07-27 17:45:00+03	2017-07-27 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-27 17:49:00+03	2017-07-27 19:13:00+03
9705	PG0078	2017-08-16 18:25:00+03	2017-08-16 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9706	PG0077	2017-08-03 17:45:00+03	2017-08-03 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-03 17:46:00+03	2017-08-03 19:12:00+03
9707	PG0077	2017-08-31 17:45:00+03	2017-08-31 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9708	PG0077	2017-07-28 17:45:00+03	2017-07-28 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-28 17:48:00+03	2017-07-28 19:14:00+03
9709	PG0078	2017-07-24 18:25:00+03	2017-07-24 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-24 18:26:00+03	2017-07-24 19:51:00+03
9710	PG0077	2017-07-25 17:45:00+03	2017-07-25 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-25 17:47:00+03	2017-07-25 19:11:00+03
9711	PG0078	2017-08-06 18:25:00+03	2017-08-06 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-06 22:33:00+03	2017-08-06 23:58:00+03
9712	PG0078	2017-08-14 18:25:00+03	2017-08-14 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-14 18:26:00+03	2017-08-14 19:52:00+03
9713	PG0077	2017-08-14 17:45:00+03	2017-08-14 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-14 17:50:00+03	2017-08-14 19:15:00+03
9714	PG0078	2017-07-18 18:25:00+03	2017-07-18 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-18 18:27:00+03	2017-07-18 19:52:00+03
9715	PG0077	2017-08-16 17:45:00+03	2017-08-16 19:10:00+03	LED	CEE	On Time	CN1	\N	\N
9716	PG0077	2017-08-30 17:45:00+03	2017-08-30 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9717	PG0078	2017-08-30 18:25:00+03	2017-08-30 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9718	PG0077	2017-07-18 17:45:00+03	2017-07-18 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-18 17:51:00+03	2017-07-18 19:16:00+03
9719	PG0078	2017-08-31 18:25:00+03	2017-08-31 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9720	PG0078	2017-08-11 18:25:00+03	2017-08-11 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-11 18:27:00+03	2017-08-11 19:51:00+03
9721	PG0077	2017-09-02 17:45:00+03	2017-09-02 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9722	PG0077	2017-07-24 17:45:00+03	2017-07-24 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-24 17:48:00+03	2017-07-24 19:13:00+03
9723	PG0077	2017-08-28 17:45:00+03	2017-08-28 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9724	PG0078	2017-08-10 18:25:00+03	2017-08-10 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-10 18:26:00+03	2017-08-10 19:51:00+03
9725	PG0077	2017-08-01 17:45:00+03	2017-08-01 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-01 17:47:00+03	2017-08-01 19:12:00+03
9726	PG0077	2017-08-04 17:45:00+03	2017-08-04 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-04 17:45:00+03	2017-08-04 19:10:00+03
9727	PG0078	2017-08-04 18:25:00+03	2017-08-04 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-04 18:27:00+03	2017-08-04 19:53:00+03
9728	PG0077	2017-08-11 17:45:00+03	2017-08-11 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-11 17:46:00+03	2017-08-11 19:11:00+03
9729	PG0078	2017-09-02 18:25:00+03	2017-09-02 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9730	PG0077	2017-08-21 17:45:00+03	2017-08-21 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9731	PG0078	2017-08-19 18:25:00+03	2017-08-19 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9732	PG0078	2017-09-09 18:25:00+03	2017-09-09 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9733	PG0078	2017-08-21 18:25:00+03	2017-08-21 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9734	PG0077	2017-07-21 17:45:00+03	2017-07-21 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-21 17:46:00+03	2017-07-21 19:11:00+03
9735	PG0078	2017-07-21 18:25:00+03	2017-07-21 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-21 18:27:00+03	2017-07-21 19:52:00+03
9736	PG0078	2017-07-19 18:25:00+03	2017-07-19 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-19 18:27:00+03	2017-07-19 19:52:00+03
9737	PG0077	2017-08-19 17:45:00+03	2017-08-19 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9738	PG0077	2017-07-19 17:45:00+03	2017-07-19 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-19 17:50:00+03	2017-07-19 19:14:00+03
9739	PG0078	2017-08-03 18:25:00+03	2017-08-03 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-03 18:27:00+03	2017-08-03 19:52:00+03
9740	PG0078	2017-08-18 18:25:00+03	2017-08-18 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9741	PG0077	2017-08-12 17:45:00+03	2017-08-12 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-12 17:51:00+03	2017-08-12 19:13:00+03
9742	PG0078	2017-08-12 18:25:00+03	2017-08-12 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-12 18:28:00+03	2017-08-12 19:54:00+03
9743	PG0078	2017-09-05 18:25:00+03	2017-09-05 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9744	PG0077	2017-08-07 17:45:00+03	2017-08-07 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-07 17:48:00+03	2017-08-07 19:13:00+03
9745	PG0078	2017-08-24 18:25:00+03	2017-08-24 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9746	PG0078	2017-08-07 18:25:00+03	2017-08-07 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-07 18:32:00+03	2017-08-07 19:56:00+03
9747	PG0077	2017-08-29 17:45:00+03	2017-08-29 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9748	PG0078	2017-08-25 18:25:00+03	2017-08-25 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9749	PG0077	2017-08-24 17:45:00+03	2017-08-24 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9750	PG0078	2017-08-01 18:25:00+03	2017-08-01 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-01 18:30:00+03	2017-08-01 19:53:00+03
9751	PG0077	2017-08-25 17:45:00+03	2017-08-25 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9752	PG0077	2017-08-18 17:45:00+03	2017-08-18 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9753	PG0078	2017-09-12 18:25:00+03	2017-09-12 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9754	PG0077	2017-09-09 17:45:00+03	2017-09-09 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9755	PG0077	2017-08-08 17:45:00+03	2017-08-08 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-08 17:50:00+03	2017-08-08 19:16:00+03
9756	PG0077	2017-09-10 17:45:00+03	2017-09-10 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9757	PG0077	2017-07-31 17:45:00+03	2017-07-31 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-31 17:46:00+03	2017-07-31 19:11:00+03
9758	PG0078	2017-08-08 18:25:00+03	2017-08-08 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-08 18:30:00+03	2017-08-08 19:55:00+03
9759	PG0077	2017-09-12 17:45:00+03	2017-09-12 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9760	PG0078	2017-09-10 18:25:00+03	2017-09-10 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9761	PG0077	2017-08-15 17:45:00+03	2017-08-15 19:10:00+03	LED	CEE	Departed	CN1	2017-08-15 17:48:00+03	\N
9762	PG0078	2017-08-22 18:25:00+03	2017-08-22 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9763	PG0078	2017-08-13 18:25:00+03	2017-08-13 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-13 18:26:00+03	2017-08-13 19:52:00+03
9764	PG0078	2017-08-23 18:25:00+03	2017-08-23 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9765	PG0078	2017-09-06 18:25:00+03	2017-09-06 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9766	PG0077	2017-08-13 17:45:00+03	2017-08-13 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-13 17:51:00+03	2017-08-13 19:18:00+03
9767	PG0078	2017-08-15 18:25:00+03	2017-08-15 19:50:00+03	LED	CEE	On Time	CN1	\N	\N
9768	PG0077	2017-08-09 17:45:00+03	2017-08-09 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-09 21:32:00+03	2017-08-09 22:57:00+03
9769	PG0078	2017-09-01 18:25:00+03	2017-09-01 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9770	PG0077	2017-09-01 17:45:00+03	2017-09-01 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9771	PG0078	2017-07-30 18:25:00+03	2017-07-30 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-30 18:26:00+03	2017-07-30 19:51:00+03
9772	PG0077	2017-07-30 17:45:00+03	2017-07-30 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-30 17:47:00+03	2017-07-30 19:11:00+03
9773	PG0077	2017-08-23 17:45:00+03	2017-08-23 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9774	PG0078	2017-07-28 18:25:00+03	2017-07-28 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-28 18:30:00+03	2017-07-28 19:54:00+03
9775	PG0078	2017-08-09 18:25:00+03	2017-08-09 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-09 18:27:00+03	2017-08-09 19:52:00+03
9776	PG0077	2017-09-11 17:45:00+03	2017-09-11 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9777	PG0078	2017-07-16 18:25:00+03	2017-07-16 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-16 18:27:00+03	2017-07-16 19:52:00+03
9778	PG0077	2017-07-20 17:45:00+03	2017-07-20 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-20 17:50:00+03	2017-07-20 19:16:00+03
9779	PG0077	2017-08-22 17:45:00+03	2017-08-22 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9780	PG0078	2017-09-11 18:25:00+03	2017-09-11 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9781	PG0077	2017-09-05 17:45:00+03	2017-09-05 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9782	PG0078	2017-08-26 18:25:00+03	2017-08-26 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9783	PG0077	2017-07-16 17:45:00+03	2017-07-16 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-16 17:45:00+03	2017-07-16 19:10:00+03
9784	PG0077	2017-09-06 17:45:00+03	2017-09-06 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9785	PG0077	2017-08-26 17:45:00+03	2017-08-26 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9786	PG0078	2017-08-29 18:25:00+03	2017-08-29 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9787	PG0078	2017-07-31 18:25:00+03	2017-07-31 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-31 18:28:00+03	2017-07-31 19:53:00+03
9788	PG0078	2017-09-13 18:25:00+03	2017-09-13 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9789	PG0077	2017-09-13 17:45:00+03	2017-09-13 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9790	PG0077	2017-07-26 17:45:00+03	2017-07-26 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-26 17:49:00+03	2017-07-26 19:15:00+03
9791	PG0078	2017-07-26 18:25:00+03	2017-07-26 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-26 21:47:00+03	2017-07-26 23:13:00+03
9792	PG0078	2017-07-23 18:25:00+03	2017-07-23 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-23 18:29:00+03	2017-07-23 19:55:00+03
9793	PG0077	2017-09-14 17:45:00+03	2017-09-14 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9794	PG0077	2017-07-23 17:45:00+03	2017-07-23 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-23 17:47:00+03	2017-07-23 19:11:00+03
9795	PG0077	2017-08-02 17:45:00+03	2017-08-02 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-02 17:48:00+03	2017-08-02 19:13:00+03
9796	PG0078	2017-07-20 18:25:00+03	2017-07-20 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-20 18:27:00+03	2017-07-20 19:53:00+03
9797	PG0078	2017-08-02 18:25:00+03	2017-08-02 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-02 18:25:00+03	2017-08-02 19:49:00+03
9798	PG0078	2017-09-08 18:25:00+03	2017-09-08 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9799	PG0077	2017-09-08 17:45:00+03	2017-09-08 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9800	PG0077	2017-07-29 17:45:00+03	2017-07-29 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-29 17:49:00+03	2017-07-29 19:13:00+03
9801	PG0078	2017-07-29 18:25:00+03	2017-07-29 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-29 18:28:00+03	2017-07-29 19:52:00+03
9802	PG0078	2017-08-17 18:25:00+03	2017-08-17 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9803	PG0078	2017-08-20 18:25:00+03	2017-08-20 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9804	PG0077	2017-09-03 17:45:00+03	2017-09-03 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9805	PG0078	2017-09-03 18:25:00+03	2017-09-03 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9806	PG0078	2017-08-28 18:25:00+03	2017-08-28 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9807	PG0077	2017-08-05 17:45:00+03	2017-08-05 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-05 17:47:00+03	2017-08-05 19:13:00+03
9808	PG0078	2017-07-22 18:25:00+03	2017-07-22 19:50:00+03	LED	CEE	Arrived	CN1	2017-07-22 18:28:00+03	2017-07-22 19:54:00+03
9809	PG0078	2017-08-27 18:25:00+03	2017-08-27 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9810	PG0077	2017-09-04 17:45:00+03	2017-09-04 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9811	PG0078	2017-09-04 18:25:00+03	2017-09-04 19:50:00+03	LED	CEE	Scheduled	CN1	\N	\N
9812	PG0078	2017-09-14 18:25:00+03	2017-09-14 19:50:00+03	LED	CEE	Cancelled	CN1	\N	\N
9813	PG0077	2017-07-22 17:45:00+03	2017-07-22 19:10:00+03	LED	CEE	Arrived	CN1	2017-07-22 17:51:00+03	2017-07-22 19:15:00+03
9814	PG0077	2017-08-10 17:45:00+03	2017-08-10 19:10:00+03	LED	CEE	Arrived	CN1	2017-08-10 17:47:00+03	2017-08-10 19:12:00+03
9815	PG0077	2017-08-27 17:45:00+03	2017-08-27 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9816	PG0077	2017-09-07 17:45:00+03	2017-09-07 19:10:00+03	LED	CEE	Scheduled	CN1	\N	\N
9817	PG0078	2017-08-05 18:25:00+03	2017-08-05 19:50:00+03	LED	CEE	Arrived	CN1	2017-08-05 18:27:00+03	2017-08-05 19:53:00+03
9818	PG0223	2017-08-10 11:50:00+03	2017-08-10 15:15:00+03	OVB	DME	Arrived	773	2017-08-10 11:52:00+03	2017-08-10 15:17:00+03
9819	PG0223	2017-08-12 11:50:00+03	2017-08-12 15:15:00+03	OVB	DME	Arrived	773	2017-08-12 11:52:00+03	2017-08-12 15:17:00+03
9820	PG0223	2017-07-29 11:50:00+03	2017-07-29 15:15:00+03	OVB	DME	Arrived	773	2017-07-29 11:52:00+03	2017-07-29 15:16:00+03
9821	PG0223	2017-08-01 11:50:00+03	2017-08-01 15:15:00+03	OVB	DME	Arrived	773	2017-08-01 11:51:00+03	2017-08-01 15:14:00+03
9822	PG0223	2017-08-18 11:50:00+03	2017-08-18 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9823	PG0223	2017-09-07 11:50:00+03	2017-09-07 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9824	PG0223	2017-08-22 11:50:00+03	2017-08-22 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9825	PG0223	2017-07-26 11:50:00+03	2017-07-26 15:15:00+03	OVB	DME	Arrived	773	2017-07-26 11:51:00+03	2017-07-26 15:17:00+03
9826	PG0223	2017-09-01 11:50:00+03	2017-09-01 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9827	PG0223	2017-09-06 11:50:00+03	2017-09-06 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9828	PG0223	2017-08-31 11:50:00+03	2017-08-31 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9829	PG0223	2017-07-16 11:50:00+03	2017-07-16 15:15:00+03	OVB	DME	Arrived	773	2017-07-16 11:51:00+03	2017-07-16 15:17:00+03
9830	PG0223	2017-09-09 11:50:00+03	2017-09-09 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9831	PG0223	2017-08-06 11:50:00+03	2017-08-06 15:15:00+03	OVB	DME	Arrived	773	2017-08-06 11:52:00+03	2017-08-06 15:16:00+03
9832	PG0223	2017-08-25 11:50:00+03	2017-08-25 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9833	PG0223	2017-08-26 11:50:00+03	2017-08-26 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9834	PG0223	2017-07-20 11:50:00+03	2017-07-20 15:15:00+03	OVB	DME	Arrived	773	2017-07-20 11:54:00+03	2017-07-20 15:19:00+03
9835	PG0223	2017-08-14 11:50:00+03	2017-08-14 15:15:00+03	OVB	DME	Arrived	773	2017-08-14 11:51:00+03	2017-08-14 15:17:00+03
9836	PG0223	2017-07-27 11:50:00+03	2017-07-27 15:15:00+03	OVB	DME	Arrived	773	2017-07-27 11:53:00+03	2017-07-27 15:16:00+03
9837	PG0223	2017-08-11 11:50:00+03	2017-08-11 15:15:00+03	OVB	DME	Arrived	773	2017-08-11 11:54:00+03	2017-08-11 15:22:00+03
9838	PG0223	2017-08-02 11:50:00+03	2017-08-02 15:15:00+03	OVB	DME	Arrived	773	2017-08-02 11:53:00+03	2017-08-02 15:19:00+03
9839	PG0223	2017-08-16 11:50:00+03	2017-08-16 15:15:00+03	OVB	DME	On Time	773	\N	\N
9840	PG0223	2017-08-27 11:50:00+03	2017-08-27 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9841	PG0223	2017-07-17 11:50:00+03	2017-07-17 15:15:00+03	OVB	DME	Arrived	773	2017-07-17 11:56:00+03	2017-07-17 15:20:00+03
9842	PG0223	2017-08-23 11:50:00+03	2017-08-23 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9843	PG0223	2017-09-08 11:50:00+03	2017-09-08 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9844	PG0223	2017-08-13 11:50:00+03	2017-08-13 15:15:00+03	OVB	DME	Arrived	773	2017-08-13 11:56:00+03	2017-08-13 15:23:00+03
9845	PG0223	2017-07-22 11:50:00+03	2017-07-22 15:15:00+03	OVB	DME	Arrived	773	2017-07-22 14:51:00+03	2017-07-22 18:14:00+03
9846	PG0223	2017-07-23 11:50:00+03	2017-07-23 15:15:00+03	OVB	DME	Arrived	773	2017-07-23 11:53:00+03	2017-07-23 15:18:00+03
9847	PG0223	2017-08-05 11:50:00+03	2017-08-05 15:15:00+03	OVB	DME	Arrived	773	2017-08-05 11:52:00+03	2017-08-05 15:18:00+03
9848	PG0223	2017-09-13 11:50:00+03	2017-09-13 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9849	PG0223	2017-08-07 11:50:00+03	2017-08-07 15:15:00+03	OVB	DME	Arrived	773	2017-08-07 11:51:00+03	2017-08-07 15:19:00+03
9850	PG0223	2017-09-02 11:50:00+03	2017-09-02 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9851	PG0223	2017-08-20 11:50:00+03	2017-08-20 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9852	PG0223	2017-09-14 11:50:00+03	2017-09-14 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9853	PG0223	2017-08-03 11:50:00+03	2017-08-03 15:15:00+03	OVB	DME	Arrived	773	2017-08-03 11:56:00+03	2017-08-03 15:22:00+03
9854	PG0223	2017-08-19 11:50:00+03	2017-08-19 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9855	PG0223	2017-08-24 11:50:00+03	2017-08-24 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9856	PG0223	2017-09-04 11:50:00+03	2017-09-04 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9857	PG0223	2017-08-29 11:50:00+03	2017-08-29 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9858	PG0223	2017-07-18 11:50:00+03	2017-07-18 15:15:00+03	OVB	DME	Arrived	773	2017-07-18 11:50:00+03	2017-07-18 15:14:00+03
9859	PG0223	2017-08-28 11:50:00+03	2017-08-28 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9860	PG0223	2017-08-09 11:50:00+03	2017-08-09 15:15:00+03	OVB	DME	Arrived	773	2017-08-09 11:50:00+03	2017-08-09 15:13:00+03
9861	PG0223	2017-07-19 11:50:00+03	2017-07-19 15:15:00+03	OVB	DME	Arrived	773	2017-07-19 11:50:00+03	2017-07-19 15:17:00+03
9862	PG0223	2017-07-30 11:50:00+03	2017-07-30 15:15:00+03	OVB	DME	Arrived	773	2017-07-30 11:54:00+03	2017-07-30 15:15:00+03
9863	PG0223	2017-08-21 11:50:00+03	2017-08-21 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9864	PG0223	2017-08-15 11:50:00+03	2017-08-15 15:15:00+03	OVB	DME	Arrived	773	2017-08-15 11:54:00+03	2017-08-15 15:23:00+03
9865	PG0223	2017-09-05 11:50:00+03	2017-09-05 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9866	PG0223	2017-09-12 11:50:00+03	2017-09-12 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9867	PG0223	2017-09-03 11:50:00+03	2017-09-03 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9868	PG0223	2017-09-11 11:50:00+03	2017-09-11 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9869	PG0223	2017-07-28 11:50:00+03	2017-07-28 15:15:00+03	OVB	DME	Arrived	773	2017-07-28 11:54:00+03	2017-07-28 15:20:00+03
9870	PG0223	2017-07-24 11:50:00+03	2017-07-24 15:15:00+03	OVB	DME	Arrived	773	2017-07-24 11:52:00+03	2017-07-24 15:18:00+03
9871	PG0223	2017-08-17 11:50:00+03	2017-08-17 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9872	PG0223	2017-07-31 11:50:00+03	2017-07-31 15:15:00+03	OVB	DME	Arrived	773	2017-07-31 11:53:00+03	2017-07-31 15:24:00+03
9873	PG0223	2017-07-21 11:50:00+03	2017-07-21 15:15:00+03	OVB	DME	Arrived	773	2017-07-21 11:53:00+03	2017-07-21 15:16:00+03
9874	PG0223	2017-08-30 11:50:00+03	2017-08-30 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9875	PG0223	2017-07-25 11:50:00+03	2017-07-25 15:15:00+03	OVB	DME	Arrived	773	2017-07-25 11:52:00+03	2017-07-25 15:18:00+03
9876	PG0223	2017-09-10 11:50:00+03	2017-09-10 15:15:00+03	OVB	DME	Scheduled	773	\N	\N
9877	PG0223	2017-08-04 11:50:00+03	2017-08-04 15:15:00+03	OVB	DME	Arrived	773	2017-08-04 11:56:00+03	2017-08-04 15:18:00+03
9878	PG0223	2017-08-08 11:50:00+03	2017-08-08 15:15:00+03	OVB	DME	Arrived	773	2017-08-08 11:53:00+03	2017-08-08 15:16:00+03
9879	PG0278	2017-07-18 14:20:00+03	2017-07-18 17:45:00+03	OVB	SVO	Arrived	773	2017-07-18 14:22:00+03	2017-07-18 17:48:00+03
9880	PG0278	2017-07-22 14:20:00+03	2017-07-22 17:45:00+03	OVB	SVO	Arrived	773	2017-07-22 14:24:00+03	2017-07-22 17:50:00+03
9881	PG0278	2017-09-09 14:20:00+03	2017-09-09 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9882	PG0278	2017-08-09 14:20:00+03	2017-08-09 17:45:00+03	OVB	SVO	Arrived	773	2017-08-09 14:27:00+03	2017-08-09 17:52:00+03
9883	PG0278	2017-07-17 14:20:00+03	2017-07-17 17:45:00+03	OVB	SVO	Arrived	773	2017-07-17 14:25:00+03	2017-07-17 17:48:00+03
9884	PG0278	2017-09-06 14:20:00+03	2017-09-06 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9885	PG0278	2017-08-21 14:20:00+03	2017-08-21 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9886	PG0278	2017-09-14 14:20:00+03	2017-09-14 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9887	PG0278	2017-09-11 14:20:00+03	2017-09-11 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9888	PG0278	2017-08-04 14:20:00+03	2017-08-04 17:45:00+03	OVB	SVO	Arrived	773	2017-08-04 14:21:00+03	2017-08-04 17:46:00+03
9889	PG0278	2017-07-30 14:20:00+03	2017-07-30 17:45:00+03	OVB	SVO	Arrived	773	2017-07-30 14:24:00+03	2017-07-30 17:45:00+03
9890	PG0278	2017-08-05 14:20:00+03	2017-08-05 17:45:00+03	OVB	SVO	Arrived	773	2017-08-05 14:25:00+03	2017-08-05 17:50:00+03
9891	PG0278	2017-07-16 14:20:00+03	2017-07-16 17:45:00+03	OVB	SVO	Arrived	773	2017-07-16 18:36:00+03	2017-07-16 21:59:00+03
9892	PG0278	2017-08-22 14:20:00+03	2017-08-22 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9893	PG0278	2017-07-25 14:20:00+03	2017-07-25 17:45:00+03	OVB	SVO	Arrived	773	2017-07-25 14:21:00+03	2017-07-25 17:47:00+03
9894	PG0278	2017-08-17 14:20:00+03	2017-08-17 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9895	PG0278	2017-08-26 14:20:00+03	2017-08-26 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9896	PG0278	2017-08-23 14:20:00+03	2017-08-23 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9897	PG0278	2017-09-07 14:20:00+03	2017-09-07 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9898	PG0278	2017-08-29 14:20:00+03	2017-08-29 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9899	PG0278	2017-08-24 14:20:00+03	2017-08-24 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9900	PG0278	2017-09-13 14:20:00+03	2017-09-13 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9901	PG0278	2017-08-11 14:20:00+03	2017-08-11 17:45:00+03	OVB	SVO	Arrived	773	2017-08-11 14:23:00+03	2017-08-11 17:47:00+03
9902	PG0278	2017-09-01 14:20:00+03	2017-09-01 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9903	PG0278	2017-08-12 14:20:00+03	2017-08-12 17:45:00+03	OVB	SVO	Arrived	773	2017-08-12 14:20:00+03	2017-08-12 17:45:00+03
9904	PG0278	2017-09-02 14:20:00+03	2017-09-02 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9905	PG0278	2017-08-25 14:20:00+03	2017-08-25 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9906	PG0278	2017-07-23 14:20:00+03	2017-07-23 17:45:00+03	OVB	SVO	Arrived	773	2017-07-23 14:25:00+03	2017-07-23 17:47:00+03
9907	PG0278	2017-08-07 14:20:00+03	2017-08-07 17:45:00+03	OVB	SVO	Arrived	773	2017-08-07 14:21:00+03	2017-08-07 17:48:00+03
9908	PG0278	2017-08-08 14:20:00+03	2017-08-08 17:45:00+03	OVB	SVO	Arrived	773	2017-08-08 14:22:00+03	2017-08-08 17:49:00+03
9909	PG0278	2017-08-10 14:20:00+03	2017-08-10 17:45:00+03	OVB	SVO	Arrived	773	2017-08-10 14:24:00+03	2017-08-10 17:47:00+03
9910	PG0278	2017-09-03 14:20:00+03	2017-09-03 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9911	PG0278	2017-08-18 14:20:00+03	2017-08-18 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9912	PG0278	2017-09-04 14:20:00+03	2017-09-04 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9913	PG0278	2017-08-31 14:20:00+03	2017-08-31 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9914	PG0278	2017-07-24 14:20:00+03	2017-07-24 17:45:00+03	OVB	SVO	Arrived	773	2017-07-24 14:23:00+03	2017-07-24 17:48:00+03
9915	PG0278	2017-08-13 14:20:00+03	2017-08-13 17:45:00+03	OVB	SVO	Arrived	773	2017-08-13 17:43:00+03	2017-08-13 21:08:00+03
9916	PG0278	2017-08-27 14:20:00+03	2017-08-27 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9917	PG0278	2017-08-01 14:20:00+03	2017-08-01 17:45:00+03	OVB	SVO	Arrived	773	2017-08-01 14:23:00+03	2017-08-01 17:50:00+03
9918	PG0278	2017-09-10 14:20:00+03	2017-09-10 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9919	PG0278	2017-08-28 14:20:00+03	2017-08-28 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9920	PG0278	2017-08-16 14:20:00+03	2017-08-16 17:45:00+03	OVB	SVO	On Time	773	\N	\N
9921	PG0278	2017-09-12 14:20:00+03	2017-09-12 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9922	PG0278	2017-08-03 14:20:00+03	2017-08-03 17:45:00+03	OVB	SVO	Arrived	773	2017-08-03 14:24:00+03	2017-08-03 17:48:00+03
9923	PG0278	2017-09-05 14:20:00+03	2017-09-05 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9924	PG0278	2017-08-20 14:20:00+03	2017-08-20 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9925	PG0278	2017-07-29 14:20:00+03	2017-07-29 17:45:00+03	OVB	SVO	Arrived	773	2017-07-29 17:51:00+03	2017-07-29 21:17:00+03
9926	PG0278	2017-08-06 14:20:00+03	2017-08-06 17:45:00+03	OVB	SVO	Arrived	773	2017-08-06 14:21:00+03	2017-08-06 17:48:00+03
9927	PG0278	2017-08-02 14:20:00+03	2017-08-02 17:45:00+03	OVB	SVO	Arrived	773	2017-08-02 14:22:00+03	2017-08-02 17:48:00+03
9928	PG0278	2017-08-30 14:20:00+03	2017-08-30 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9929	PG0278	2017-07-19 14:20:00+03	2017-07-19 17:45:00+03	OVB	SVO	Arrived	773	2017-07-19 14:21:00+03	2017-07-19 17:43:00+03
9930	PG0278	2017-09-08 14:20:00+03	2017-09-08 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9931	PG0278	2017-07-27 14:20:00+03	2017-07-27 17:45:00+03	OVB	SVO	Arrived	773	2017-07-27 14:23:00+03	2017-07-27 17:47:00+03
9932	PG0278	2017-07-31 14:20:00+03	2017-07-31 17:45:00+03	OVB	SVO	Arrived	773	2017-07-31 14:21:00+03	2017-07-31 17:45:00+03
9933	PG0278	2017-08-14 14:20:00+03	2017-08-14 17:45:00+03	OVB	SVO	Arrived	773	2017-08-14 17:40:00+03	2017-08-14 21:05:00+03
9934	PG0278	2017-07-26 14:20:00+03	2017-07-26 17:45:00+03	OVB	SVO	Arrived	773	2017-07-26 14:23:00+03	2017-07-26 17:46:00+03
9935	PG0278	2017-07-21 14:20:00+03	2017-07-21 17:45:00+03	OVB	SVO	Arrived	773	2017-07-21 14:23:00+03	2017-07-21 17:50:00+03
9936	PG0278	2017-07-20 14:20:00+03	2017-07-20 17:45:00+03	OVB	SVO	Arrived	773	2017-07-20 14:23:00+03	2017-07-20 17:44:00+03
9937	PG0278	2017-08-19 14:20:00+03	2017-08-19 17:45:00+03	OVB	SVO	Scheduled	773	\N	\N
9938	PG0278	2017-07-28 14:20:00+03	2017-07-28 17:45:00+03	OVB	SVO	Arrived	773	2017-07-28 14:25:00+03	2017-07-28 17:47:00+03
9939	PG0278	2017-08-15 14:20:00+03	2017-08-15 17:45:00+03	OVB	SVO	Arrived	773	2017-08-15 14:21:00+03	2017-08-15 17:43:00+03
9940	PG0204	2017-07-19 12:20:00+03	2017-07-19 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-19 12:24:00+03	2017-07-19 14:28:00+03
9941	PG0204	2017-08-29 12:20:00+03	2017-08-29 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9942	PG0205	2017-09-07 13:30:00+03	2017-09-07 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9943	PG0205	2017-09-11 13:30:00+03	2017-09-11 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9944	PG0204	2017-09-08 12:20:00+03	2017-09-08 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9945	PG0205	2017-08-15 13:30:00+03	2017-08-15 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-15 13:34:00+03	2017-08-15 15:40:00+03
9946	PG0204	2017-09-11 12:20:00+03	2017-09-11 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9947	PG0205	2017-08-27 13:30:00+03	2017-08-27 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9948	PG0204	2017-09-01 12:20:00+03	2017-09-01 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9949	PG0204	2017-07-23 12:20:00+03	2017-07-23 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-23 12:23:00+03	2017-07-23 14:27:00+03
9950	PG0205	2017-07-25 13:30:00+03	2017-07-25 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-25 13:31:00+03	2017-07-25 15:35:00+03
9951	PG0205	2017-07-19 13:30:00+03	2017-07-19 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-19 13:34:00+03	2017-07-19 15:42:00+03
9952	PG0204	2017-08-24 12:20:00+03	2017-08-24 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9953	PG0205	2017-08-08 13:30:00+03	2017-08-08 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-08 13:33:00+03	2017-08-08 15:39:00+03
9954	PG0205	2017-08-21 13:30:00+03	2017-08-21 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9955	PG0205	2017-07-26 13:30:00+03	2017-07-26 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-26 16:36:00+03	2017-07-26 18:42:00+03
9956	PG0204	2017-08-23 12:20:00+03	2017-08-23 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9957	PG0205	2017-07-22 13:30:00+03	2017-07-22 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-22 13:30:00+03	2017-07-22 15:35:00+03
9958	PG0205	2017-08-31 13:30:00+03	2017-08-31 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9959	PG0204	2017-08-14 12:20:00+03	2017-08-14 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-14 12:25:00+03	2017-08-14 14:29:00+03
9960	PG0204	2017-09-02 12:20:00+03	2017-09-02 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9961	PG0204	2017-09-09 12:20:00+03	2017-09-09 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9962	PG0204	2017-08-15 12:20:00+03	2017-08-15 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-15 12:22:00+03	2017-08-15 14:28:00+03
9963	PG0205	2017-08-20 13:30:00+03	2017-08-20 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9964	PG0204	2017-08-02 12:20:00+03	2017-08-02 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-02 12:22:00+03	2017-08-02 14:27:00+03
9965	PG0204	2017-08-20 12:20:00+03	2017-08-20 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9966	PG0204	2017-09-10 12:20:00+03	2017-09-10 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9967	PG0204	2017-08-28 12:20:00+03	2017-08-28 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9968	PG0205	2017-08-29 13:30:00+03	2017-08-29 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9969	PG0204	2017-08-05 12:20:00+03	2017-08-05 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-05 12:24:00+03	2017-08-05 14:30:00+03
9970	PG0205	2017-08-05 13:30:00+03	2017-08-05 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-05 13:31:00+03	2017-08-05 15:37:00+03
9971	PG0205	2017-08-02 13:30:00+03	2017-08-02 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-02 13:33:00+03	2017-08-02 15:36:00+03
9972	PG0205	2017-08-07 13:30:00+03	2017-08-07 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-07 13:34:00+03	2017-08-07 15:39:00+03
9973	PG0204	2017-07-26 12:20:00+03	2017-07-26 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-26 12:23:00+03	2017-07-26 14:28:00+03
9974	PG0205	2017-09-13 13:30:00+03	2017-09-13 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9975	PG0204	2017-08-26 12:20:00+03	2017-08-26 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9976	PG0205	2017-08-12 13:30:00+03	2017-08-12 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-12 13:31:00+03	2017-08-12 15:36:00+03
9977	PG0204	2017-08-12 12:20:00+03	2017-08-12 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-12 12:21:00+03	2017-08-12 14:26:00+03
9978	PG0205	2017-09-08 13:30:00+03	2017-09-08 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9979	PG0204	2017-07-24 12:20:00+03	2017-07-24 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-24 12:22:00+03	2017-07-24 14:24:00+03
9980	PG0205	2017-08-11 13:30:00+03	2017-08-11 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-11 13:32:00+03	2017-08-11 15:35:00+03
9981	PG0204	2017-08-11 12:20:00+03	2017-08-11 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-11 12:22:00+03	2017-08-11 14:29:00+03
9982	PG0204	2017-09-05 12:20:00+03	2017-09-05 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9983	PG0205	2017-08-18 13:30:00+03	2017-08-18 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9984	PG0204	2017-07-25 12:20:00+03	2017-07-25 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-25 12:22:00+03	2017-07-25 14:28:00+03
9985	PG0204	2017-08-27 12:20:00+03	2017-08-27 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9986	PG0204	2017-08-07 12:20:00+03	2017-08-07 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-07 12:22:00+03	2017-08-07 14:30:00+03
9987	PG0205	2017-07-24 13:30:00+03	2017-07-24 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-24 13:35:00+03	2017-07-24 15:41:00+03
9988	PG0205	2017-07-31 13:30:00+03	2017-07-31 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-31 13:32:00+03	2017-07-31 15:38:00+03
9989	PG0204	2017-08-25 12:20:00+03	2017-08-25 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9990	PG0204	2017-09-13 12:20:00+03	2017-09-13 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9991	PG0205	2017-07-23 13:30:00+03	2017-07-23 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-23 16:37:00+03	2017-07-23 18:42:00+03
9992	PG0205	2017-09-10 13:30:00+03	2017-09-10 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9993	PG0205	2017-08-23 13:30:00+03	2017-08-23 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9994	PG0204	2017-09-14 12:20:00+03	2017-09-14 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9995	PG0204	2017-08-22 12:20:00+03	2017-08-22 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9996	PG0205	2017-09-02 13:30:00+03	2017-09-02 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
9997	PG0204	2017-07-27 12:20:00+03	2017-07-27 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-27 12:21:00+03	2017-07-27 14:25:00+03
9998	PG0204	2017-07-20 12:20:00+03	2017-07-20 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-20 12:23:00+03	2017-07-20 14:29:00+03
9999	PG0205	2017-09-14 13:30:00+03	2017-09-14 15:35:00+03	OVB	KJA	Cancelled	CN1	\N	\N
10000	PG0205	2017-08-26 13:30:00+03	2017-08-26 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10001	PG0205	2017-09-09 13:30:00+03	2017-09-09 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10002	PG0204	2017-08-06 12:20:00+03	2017-08-06 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-06 12:21:00+03	2017-08-06 14:26:00+03
10003	PG0205	2017-09-04 13:30:00+03	2017-09-04 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10004	PG0204	2017-08-01 12:20:00+03	2017-08-01 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-01 12:21:00+03	2017-08-01 14:29:00+03
10005	PG0204	2017-07-16 12:20:00+03	2017-07-16 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-16 12:24:00+03	2017-07-16 14:28:00+03
10006	PG0204	2017-08-19 12:20:00+03	2017-08-19 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10007	PG0204	2017-08-08 12:20:00+03	2017-08-08 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-08 12:24:00+03	2017-08-08 14:30:00+03
10008	PG0205	2017-08-01 13:30:00+03	2017-08-01 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-01 13:34:00+03	2017-08-01 15:39:00+03
10009	PG0204	2017-07-18 12:20:00+03	2017-07-18 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-18 12:25:00+03	2017-07-18 14:31:00+03
10010	PG0204	2017-08-17 12:20:00+03	2017-08-17 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10011	PG0204	2017-07-21 12:20:00+03	2017-07-21 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-21 12:26:00+03	2017-07-21 14:31:00+03
10012	PG0205	2017-07-18 13:30:00+03	2017-07-18 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-18 13:33:00+03	2017-07-18 15:36:00+03
10013	PG0204	2017-08-09 12:20:00+03	2017-08-09 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-09 12:24:00+03	2017-08-09 14:28:00+03
10014	PG0205	2017-08-09 13:30:00+03	2017-08-09 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-09 13:34:00+03	2017-08-09 15:37:00+03
10015	PG0205	2017-08-19 13:30:00+03	2017-08-19 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10016	PG0204	2017-08-18 12:20:00+03	2017-08-18 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10017	PG0205	2017-09-03 13:30:00+03	2017-09-03 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10018	PG0204	2017-09-03 12:20:00+03	2017-09-03 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10019	PG0204	2017-07-29 12:20:00+03	2017-07-29 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-29 12:24:00+03	2017-07-29 14:31:00+03
10020	PG0205	2017-08-22 13:30:00+03	2017-08-22 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10021	PG0205	2017-08-04 13:30:00+03	2017-08-04 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-04 13:32:00+03	2017-08-04 15:37:00+03
10022	PG0205	2017-07-29 13:30:00+03	2017-07-29 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-29 13:34:00+03	2017-07-29 15:38:00+03
10023	PG0204	2017-08-31 12:20:00+03	2017-08-31 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10024	PG0204	2017-09-04 12:20:00+03	2017-09-04 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10025	PG0205	2017-08-25 13:30:00+03	2017-08-25 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10026	PG0205	2017-08-30 13:30:00+03	2017-08-30 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10027	PG0205	2017-08-24 13:30:00+03	2017-08-24 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10028	PG0205	2017-07-27 13:30:00+03	2017-07-27 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-27 13:32:00+03	2017-07-27 15:35:00+03
10029	PG0205	2017-09-12 13:30:00+03	2017-09-12 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10030	PG0204	2017-07-28 12:20:00+03	2017-07-28 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-28 12:21:00+03	2017-07-28 14:24:00+03
10031	PG0205	2017-08-13 13:30:00+03	2017-08-13 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-13 13:32:00+03	2017-08-13 15:36:00+03
10032	PG0205	2017-09-05 13:30:00+03	2017-09-05 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10033	PG0204	2017-09-12 12:20:00+03	2017-09-12 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10034	PG0205	2017-07-28 13:30:00+03	2017-07-28 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-28 13:33:00+03	2017-07-28 15:38:00+03
10035	PG0205	2017-07-21 13:30:00+03	2017-07-21 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-21 13:34:00+03	2017-07-21 15:38:00+03
10036	PG0204	2017-08-30 12:20:00+03	2017-08-30 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10037	PG0204	2017-07-17 12:20:00+03	2017-07-17 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-17 12:23:00+03	2017-07-17 14:29:00+03
10038	PG0205	2017-08-28 13:30:00+03	2017-08-28 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10039	PG0204	2017-08-16 12:20:00+03	2017-08-16 14:25:00+03	OVB	KJA	On Time	CN1	\N	\N
10040	PG0204	2017-07-30 12:20:00+03	2017-07-30 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-30 15:00:00+03	2017-07-30 17:04:00+03
10041	PG0205	2017-09-06 13:30:00+03	2017-09-06 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10042	PG0205	2017-08-06 13:30:00+03	2017-08-06 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-06 13:33:00+03	2017-08-06 15:39:00+03
10043	PG0204	2017-07-31 12:20:00+03	2017-07-31 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-31 12:22:00+03	2017-07-31 14:29:00+03
10044	PG0205	2017-09-01 13:30:00+03	2017-09-01 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10045	PG0204	2017-08-10 12:20:00+03	2017-08-10 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-10 12:20:00+03	2017-08-10 14:28:00+03
10046	PG0205	2017-08-17 13:30:00+03	2017-08-17 15:35:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10047	PG0205	2017-07-17 13:30:00+03	2017-07-17 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-17 13:34:00+03	2017-07-17 15:39:00+03
10048	PG0204	2017-08-04 12:20:00+03	2017-08-04 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-04 12:22:00+03	2017-08-04 14:27:00+03
10049	PG0205	2017-08-10 13:30:00+03	2017-08-10 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-10 13:34:00+03	2017-08-10 15:38:00+03
10050	PG0204	2017-08-21 12:20:00+03	2017-08-21 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10051	PG0204	2017-07-22 12:20:00+03	2017-07-22 14:25:00+03	OVB	KJA	Arrived	CN1	2017-07-22 12:25:00+03	2017-07-22 14:29:00+03
10052	PG0204	2017-09-07 12:20:00+03	2017-09-07 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10053	PG0205	2017-07-30 13:30:00+03	2017-07-30 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-30 16:29:00+03	2017-07-30 18:32:00+03
10054	PG0205	2017-08-14 13:30:00+03	2017-08-14 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-14 13:32:00+03	2017-08-14 15:37:00+03
10055	PG0205	2017-07-16 13:30:00+03	2017-07-16 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-16 13:34:00+03	2017-07-16 15:39:00+03
10056	PG0204	2017-08-03 12:20:00+03	2017-08-03 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-03 12:21:00+03	2017-08-03 14:27:00+03
10057	PG0205	2017-08-03 13:30:00+03	2017-08-03 15:35:00+03	OVB	KJA	Arrived	CN1	2017-08-03 13:36:00+03	2017-08-03 15:42:00+03
10058	PG0204	2017-08-13 12:20:00+03	2017-08-13 14:25:00+03	OVB	KJA	Arrived	CN1	2017-08-13 12:22:00+03	2017-08-13 14:27:00+03
10059	PG0205	2017-08-16 13:30:00+03	2017-08-16 15:35:00+03	OVB	KJA	On Time	CN1	\N	\N
10060	PG0204	2017-09-06 12:20:00+03	2017-09-06 14:25:00+03	OVB	KJA	Scheduled	CN1	\N	\N
10061	PG0205	2017-07-20 13:30:00+03	2017-07-20 15:35:00+03	OVB	KJA	Arrived	CN1	2017-07-20 13:33:00+03	2017-07-20 15:37:00+03
10062	PG0186	2017-08-19 13:50:00+03	2017-08-19 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10063	PG0186	2017-08-10 13:50:00+03	2017-08-10 16:00:00+03	OVB	PEE	Arrived	319	2017-08-10 13:53:00+03	2017-08-10 16:04:00+03
10064	PG0186	2017-08-03 13:50:00+03	2017-08-03 16:00:00+03	OVB	PEE	Arrived	319	2017-08-03 13:54:00+03	2017-08-03 16:02:00+03
10065	PG0186	2017-08-31 13:50:00+03	2017-08-31 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10066	PG0186	2017-07-27 13:50:00+03	2017-07-27 16:00:00+03	OVB	PEE	Arrived	319	2017-07-27 13:50:00+03	2017-07-27 15:59:00+03
10067	PG0186	2017-08-27 13:50:00+03	2017-08-27 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10068	PG0186	2017-08-08 13:50:00+03	2017-08-08 16:00:00+03	OVB	PEE	Arrived	319	2017-08-08 13:51:00+03	2017-08-08 16:00:00+03
10069	PG0186	2017-07-25 13:50:00+03	2017-07-25 16:00:00+03	OVB	PEE	Arrived	319	2017-07-25 13:53:00+03	2017-07-25 16:03:00+03
10070	PG0186	2017-07-30 13:50:00+03	2017-07-30 16:00:00+03	OVB	PEE	Arrived	319	2017-07-30 13:54:00+03	2017-07-30 16:05:00+03
10071	PG0186	2017-09-06 13:50:00+03	2017-09-06 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10072	PG0186	2017-09-02 13:50:00+03	2017-09-02 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10073	PG0186	2017-08-14 13:50:00+03	2017-08-14 16:00:00+03	OVB	PEE	Arrived	319	2017-08-14 13:53:00+03	2017-08-14 16:02:00+03
10074	PG0186	2017-07-21 13:50:00+03	2017-07-21 16:00:00+03	OVB	PEE	Arrived	319	2017-07-21 13:55:00+03	2017-07-21 16:06:00+03
10075	PG0186	2017-08-05 13:50:00+03	2017-08-05 16:00:00+03	OVB	PEE	Arrived	319	2017-08-05 13:50:00+03	2017-08-05 16:00:00+03
10076	PG0186	2017-09-07 13:50:00+03	2017-09-07 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10077	PG0186	2017-08-04 13:50:00+03	2017-08-04 16:00:00+03	OVB	PEE	Arrived	319	2017-08-04 13:53:00+03	2017-08-04 16:04:00+03
10078	PG0186	2017-07-26 13:50:00+03	2017-07-26 16:00:00+03	OVB	PEE	Arrived	319	2017-07-26 13:54:00+03	2017-07-26 16:05:00+03
10079	PG0186	2017-08-23 13:50:00+03	2017-08-23 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10080	PG0186	2017-08-06 13:50:00+03	2017-08-06 16:00:00+03	OVB	PEE	Arrived	319	2017-08-06 13:54:00+03	2017-08-06 16:03:00+03
10081	PG0186	2017-08-12 13:50:00+03	2017-08-12 16:00:00+03	OVB	PEE	Arrived	319	2017-08-12 13:52:00+03	2017-08-12 16:02:00+03
10082	PG0186	2017-07-22 13:50:00+03	2017-07-22 16:00:00+03	OVB	PEE	Arrived	319	2017-07-22 13:51:00+03	2017-07-22 16:02:00+03
10083	PG0186	2017-08-25 13:50:00+03	2017-08-25 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10084	PG0186	2017-09-14 13:50:00+03	2017-09-14 16:00:00+03	OVB	PEE	Cancelled	319	\N	\N
10085	PG0186	2017-07-18 13:50:00+03	2017-07-18 16:00:00+03	OVB	PEE	Arrived	319	2017-07-18 13:52:00+03	2017-07-18 16:05:00+03
10086	PG0186	2017-09-13 13:50:00+03	2017-09-13 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10087	PG0186	2017-08-01 13:50:00+03	2017-08-01 16:00:00+03	OVB	PEE	Arrived	319	2017-08-01 13:53:00+03	2017-08-01 16:03:00+03
10088	PG0186	2017-07-28 13:50:00+03	2017-07-28 16:00:00+03	OVB	PEE	Arrived	319	2017-07-28 13:54:00+03	2017-07-28 16:06:00+03
10089	PG0186	2017-08-20 13:50:00+03	2017-08-20 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10090	PG0186	2017-09-08 13:50:00+03	2017-09-08 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10091	PG0186	2017-09-03 13:50:00+03	2017-09-03 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10092	PG0186	2017-08-17 13:50:00+03	2017-08-17 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10093	PG0186	2017-08-24 13:50:00+03	2017-08-24 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10094	PG0186	2017-08-16 13:50:00+03	2017-08-16 16:00:00+03	OVB	PEE	On Time	319	\N	\N
10095	PG0186	2017-07-16 13:50:00+03	2017-07-16 16:00:00+03	OVB	PEE	Arrived	319	2017-07-16 13:52:00+03	2017-07-16 16:01:00+03
10096	PG0186	2017-08-09 13:50:00+03	2017-08-09 16:00:00+03	OVB	PEE	Arrived	319	2017-08-09 13:54:00+03	2017-08-09 16:03:00+03
10097	PG0186	2017-08-26 13:50:00+03	2017-08-26 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10098	PG0186	2017-09-01 13:50:00+03	2017-09-01 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10099	PG0186	2017-07-23 13:50:00+03	2017-07-23 16:00:00+03	OVB	PEE	Arrived	319	2017-07-23 13:53:00+03	2017-07-23 16:02:00+03
10100	PG0186	2017-08-28 13:50:00+03	2017-08-28 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10101	PG0186	2017-09-04 13:50:00+03	2017-09-04 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10102	PG0186	2017-08-29 13:50:00+03	2017-08-29 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10103	PG0186	2017-08-07 13:50:00+03	2017-08-07 16:00:00+03	OVB	PEE	Arrived	319	2017-08-07 13:53:00+03	2017-08-07 16:04:00+03
10104	PG0186	2017-09-12 13:50:00+03	2017-09-12 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10105	PG0186	2017-09-11 13:50:00+03	2017-09-11 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10106	PG0186	2017-08-13 13:50:00+03	2017-08-13 16:00:00+03	OVB	PEE	Arrived	319	2017-08-13 13:52:00+03	2017-08-13 16:02:00+03
10107	PG0186	2017-09-05 13:50:00+03	2017-09-05 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10108	PG0186	2017-09-09 13:50:00+03	2017-09-09 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10109	PG0186	2017-08-30 13:50:00+03	2017-08-30 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10110	PG0186	2017-08-15 13:50:00+03	2017-08-15 16:00:00+03	OVB	PEE	Arrived	319	2017-08-15 13:53:00+03	2017-08-15 16:07:00+03
10111	PG0186	2017-07-17 13:50:00+03	2017-07-17 16:00:00+03	OVB	PEE	Arrived	319	2017-07-17 13:52:00+03	2017-07-17 16:02:00+03
10112	PG0186	2017-07-20 13:50:00+03	2017-07-20 16:00:00+03	OVB	PEE	Arrived	319	2017-07-20 13:53:00+03	2017-07-20 16:07:00+03
10113	PG0186	2017-08-11 13:50:00+03	2017-08-11 16:00:00+03	OVB	PEE	Arrived	319	2017-08-11 13:54:00+03	2017-08-11 16:04:00+03
10114	PG0186	2017-07-24 13:50:00+03	2017-07-24 16:00:00+03	OVB	PEE	Arrived	319	2017-07-24 13:51:00+03	2017-07-24 16:00:00+03
10115	PG0186	2017-08-18 13:50:00+03	2017-08-18 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10116	PG0186	2017-08-02 13:50:00+03	2017-08-02 16:00:00+03	OVB	PEE	Arrived	319	2017-08-02 13:53:00+03	2017-08-02 16:02:00+03
10117	PG0186	2017-07-31 13:50:00+03	2017-07-31 16:00:00+03	OVB	PEE	Arrived	319	2017-07-31 13:51:00+03	2017-07-31 16:03:00+03
10118	PG0186	2017-09-10 13:50:00+03	2017-09-10 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10119	PG0186	2017-07-29 13:50:00+03	2017-07-29 16:00:00+03	OVB	PEE	Arrived	319	2017-07-29 13:51:00+03	2017-07-29 16:02:00+03
10120	PG0186	2017-08-22 13:50:00+03	2017-08-22 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10121	PG0186	2017-08-21 13:50:00+03	2017-08-21 16:00:00+03	OVB	PEE	Scheduled	319	\N	\N
10122	PG0186	2017-07-19 13:50:00+03	2017-07-19 16:00:00+03	OVB	PEE	Arrived	319	2017-07-19 13:53:00+03	2017-07-19 16:03:00+03
10123	PG0583	2017-08-27 06:35:00+03	2017-08-27 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10124	PG0583	2017-09-12 06:35:00+03	2017-09-12 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10125	PG0583	2017-07-19 06:35:00+03	2017-07-19 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-19 10:08:00+03	2017-07-19 12:04:00+03
10126	PG0584	2017-09-13 07:45:00+03	2017-09-13 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10127	PG0584	2017-09-01 07:45:00+03	2017-09-01 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10128	PG0584	2017-07-19 07:45:00+03	2017-07-19 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-19 07:46:00+03	2017-07-19 09:40:00+03
10129	PG0584	2017-08-21 07:45:00+03	2017-08-21 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10130	PG0584	2017-09-10 07:45:00+03	2017-09-10 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10131	PG0584	2017-08-23 07:45:00+03	2017-08-23 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10132	PG0583	2017-08-23 06:35:00+03	2017-08-23 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10133	PG0583	2017-09-03 06:35:00+03	2017-09-03 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10134	PG0583	2017-07-23 06:35:00+03	2017-07-23 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-23 06:37:00+03	2017-07-23 08:32:00+03
10135	PG0583	2017-08-05 06:35:00+03	2017-08-05 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-05 06:37:00+03	2017-08-05 08:33:00+03
10136	PG0584	2017-08-15 07:45:00+03	2017-08-15 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-15 07:48:00+03	2017-08-15 09:42:00+03
10137	PG0584	2017-07-29 07:45:00+03	2017-07-29 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-29 07:48:00+03	2017-07-29 09:44:00+03
10138	PG0584	2017-09-05 07:45:00+03	2017-09-05 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10139	PG0583	2017-07-22 06:35:00+03	2017-07-22 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-22 06:36:00+03	2017-07-22 08:31:00+03
10140	PG0583	2017-08-31 06:35:00+03	2017-08-31 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10141	PG0583	2017-09-05 06:35:00+03	2017-09-05 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10142	PG0584	2017-08-19 07:45:00+03	2017-08-19 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10143	PG0583	2017-07-21 06:35:00+03	2017-07-21 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-21 06:38:00+03	2017-07-21 08:32:00+03
10144	PG0584	2017-08-20 07:45:00+03	2017-08-20 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10145	PG0584	2017-07-21 07:45:00+03	2017-07-21 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-21 07:46:00+03	2017-07-21 09:39:00+03
10146	PG0584	2017-08-05 07:45:00+03	2017-08-05 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-05 07:45:00+03	2017-08-05 09:40:00+03
10147	PG0583	2017-08-15 06:35:00+03	2017-08-15 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-15 06:35:00+03	2017-08-15 08:28:00+03
10148	PG0583	2017-08-08 06:35:00+03	2017-08-08 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-08 06:38:00+03	2017-08-08 08:33:00+03
10149	PG0583	2017-07-17 06:35:00+03	2017-07-17 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-17 06:37:00+03	2017-07-17 08:34:00+03
10150	PG0584	2017-09-14 07:45:00+03	2017-09-14 09:40:00+03	OVB	ABA	Cancelled	CN1	\N	\N
10151	PG0583	2017-08-25 06:35:00+03	2017-08-25 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10152	PG0584	2017-07-22 07:45:00+03	2017-07-22 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-22 07:49:00+03	2017-07-22 09:43:00+03
10153	PG0584	2017-08-04 07:45:00+03	2017-08-04 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-04 07:50:00+03	2017-08-04 09:45:00+03
10154	PG0583	2017-08-04 06:35:00+03	2017-08-04 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-04 06:39:00+03	2017-08-04 08:34:00+03
10155	PG0583	2017-08-21 06:35:00+03	2017-08-21 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10156	PG0584	2017-08-31 07:45:00+03	2017-08-31 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10157	PG0583	2017-08-14 06:35:00+03	2017-08-14 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-14 06:39:00+03	2017-08-14 08:33:00+03
10158	PG0584	2017-08-07 07:45:00+03	2017-08-07 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-07 07:50:00+03	2017-08-07 09:44:00+03
10159	PG0584	2017-09-06 07:45:00+03	2017-09-06 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10160	PG0584	2017-08-12 07:45:00+03	2017-08-12 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-12 07:47:00+03	2017-08-12 09:41:00+03
10161	PG0583	2017-08-09 06:35:00+03	2017-08-09 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-09 06:37:00+03	2017-08-09 08:32:00+03
10162	PG0584	2017-07-31 07:45:00+03	2017-07-31 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-31 10:46:00+03	2017-07-31 12:41:00+03
10163	PG0583	2017-08-07 06:35:00+03	2017-08-07 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-07 06:35:00+03	2017-08-07 08:30:00+03
10164	PG0583	2017-07-18 06:35:00+03	2017-07-18 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-18 06:40:00+03	2017-07-18 08:36:00+03
10165	PG0583	2017-09-14 06:35:00+03	2017-09-14 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10166	PG0584	2017-08-09 07:45:00+03	2017-08-09 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-09 07:48:00+03	2017-08-09 09:42:00+03
10167	PG0583	2017-08-18 06:35:00+03	2017-08-18 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10168	PG0584	2017-07-25 07:45:00+03	2017-07-25 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-25 07:50:00+03	2017-07-25 09:45:00+03
10169	PG0584	2017-07-18 07:45:00+03	2017-07-18 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-18 07:47:00+03	2017-07-18 09:41:00+03
10170	PG0583	2017-07-25 06:35:00+03	2017-07-25 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-25 06:40:00+03	2017-07-25 08:34:00+03
10171	PG0584	2017-08-08 07:45:00+03	2017-08-08 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-08 07:45:00+03	2017-08-08 09:40:00+03
10172	PG0583	2017-07-29 06:35:00+03	2017-07-29 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-29 06:40:00+03	2017-07-29 08:35:00+03
10173	PG0584	2017-08-26 07:45:00+03	2017-08-26 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10174	PG0584	2017-09-04 07:45:00+03	2017-09-04 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10175	PG0583	2017-09-07 06:35:00+03	2017-09-07 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10176	PG0583	2017-09-04 06:35:00+03	2017-09-04 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10177	PG0583	2017-07-24 06:35:00+03	2017-07-24 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-24 09:55:00+03	2017-07-24 11:49:00+03
10178	PG0584	2017-09-12 07:45:00+03	2017-09-12 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10179	PG0584	2017-08-11 07:45:00+03	2017-08-11 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-11 11:06:00+03	2017-08-11 13:02:00+03
10180	PG0583	2017-08-11 06:35:00+03	2017-08-11 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-11 06:38:00+03	2017-08-11 08:34:00+03
10181	PG0583	2017-07-31 06:35:00+03	2017-07-31 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-31 06:40:00+03	2017-07-31 08:36:00+03
10182	PG0584	2017-09-08 07:45:00+03	2017-09-08 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10183	PG0583	2017-08-20 06:35:00+03	2017-08-20 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10184	PG0583	2017-08-03 06:35:00+03	2017-08-03 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-03 06:37:00+03	2017-08-03 08:30:00+03
10185	PG0584	2017-09-11 07:45:00+03	2017-09-11 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10186	PG0583	2017-09-11 06:35:00+03	2017-09-11 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10187	PG0584	2017-08-17 07:45:00+03	2017-08-17 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10188	PG0584	2017-08-24 07:45:00+03	2017-08-24 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10189	PG0583	2017-09-08 06:35:00+03	2017-09-08 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10190	PG0583	2017-07-30 06:35:00+03	2017-07-30 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-30 09:15:00+03	2017-07-30 11:11:00+03
10191	PG0583	2017-08-24 06:35:00+03	2017-08-24 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10192	PG0584	2017-07-30 07:45:00+03	2017-07-30 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-30 07:48:00+03	2017-07-30 09:46:00+03
10193	PG0583	2017-08-13 06:35:00+03	2017-08-13 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-13 06:38:00+03	2017-08-13 08:31:00+03
10194	PG0583	2017-08-29 06:35:00+03	2017-08-29 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10195	PG0584	2017-08-30 07:45:00+03	2017-08-30 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10196	PG0584	2017-08-03 07:45:00+03	2017-08-03 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-03 07:47:00+03	2017-08-03 09:42:00+03
10197	PG0583	2017-09-10 06:35:00+03	2017-09-10 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10198	PG0583	2017-08-26 06:35:00+03	2017-08-26 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10199	PG0583	2017-08-17 06:35:00+03	2017-08-17 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10200	PG0583	2017-08-30 06:35:00+03	2017-08-30 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10201	PG0583	2017-08-12 06:35:00+03	2017-08-12 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-12 06:37:00+03	2017-08-12 08:31:00+03
10202	PG0583	2017-08-02 06:35:00+03	2017-08-02 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-02 06:39:00+03	2017-08-02 08:32:00+03
10203	PG0584	2017-08-18 07:45:00+03	2017-08-18 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10204	PG0584	2017-08-02 07:45:00+03	2017-08-02 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-02 07:48:00+03	2017-08-02 09:42:00+03
10205	PG0584	2017-08-22 07:45:00+03	2017-08-22 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10206	PG0583	2017-08-22 06:35:00+03	2017-08-22 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10207	PG0584	2017-07-27 07:45:00+03	2017-07-27 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-27 10:41:00+03	2017-07-27 12:35:00+03
10208	PG0584	2017-09-02 07:45:00+03	2017-09-02 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10209	PG0583	2017-07-27 06:35:00+03	2017-07-27 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-27 09:23:00+03	2017-07-27 11:19:00+03
10210	PG0584	2017-08-25 07:45:00+03	2017-08-25 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10211	PG0583	2017-07-26 06:35:00+03	2017-07-26 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-26 06:40:00+03	2017-07-26 08:35:00+03
10212	PG0583	2017-08-01 06:35:00+03	2017-08-01 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-01 06:38:00+03	2017-08-01 08:33:00+03
10213	PG0583	2017-08-06 06:35:00+03	2017-08-06 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-06 06:37:00+03	2017-08-06 08:32:00+03
10214	PG0583	2017-08-19 06:35:00+03	2017-08-19 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10215	PG0584	2017-07-20 07:45:00+03	2017-07-20 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-20 07:48:00+03	2017-07-20 09:43:00+03
10216	PG0583	2017-08-16 06:35:00+03	2017-08-16 08:30:00+03	OVB	ABA	On Time	CN1	\N	\N
10217	PG0584	2017-08-06 07:45:00+03	2017-08-06 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-06 07:49:00+03	2017-08-06 09:43:00+03
10218	PG0584	2017-07-28 07:45:00+03	2017-07-28 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-28 07:47:00+03	2017-07-28 09:42:00+03
10219	PG0584	2017-09-07 07:45:00+03	2017-09-07 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10220	PG0584	2017-08-01 07:45:00+03	2017-08-01 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-01 07:52:00+03	2017-08-01 09:47:00+03
10221	PG0584	2017-07-16 07:45:00+03	2017-07-16 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-16 07:50:00+03	2017-07-16 09:43:00+03
10222	PG0583	2017-07-28 06:35:00+03	2017-07-28 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-28 06:38:00+03	2017-07-28 08:34:00+03
10223	PG0584	2017-07-24 07:45:00+03	2017-07-24 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-24 07:45:00+03	2017-07-24 09:41:00+03
10224	PG0583	2017-07-20 06:35:00+03	2017-07-20 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-20 06:37:00+03	2017-07-20 08:31:00+03
10225	PG0583	2017-09-13 06:35:00+03	2017-09-13 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10226	PG0584	2017-08-29 07:45:00+03	2017-08-29 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10227	PG0583	2017-09-02 06:35:00+03	2017-09-02 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10228	PG0584	2017-08-16 07:45:00+03	2017-08-16 09:40:00+03	OVB	ABA	On Time	CN1	\N	\N
10229	PG0584	2017-08-10 07:45:00+03	2017-08-10 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-10 07:52:00+03	2017-08-10 09:46:00+03
10230	PG0584	2017-08-14 07:45:00+03	2017-08-14 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-14 07:53:00+03	2017-08-14 09:48:00+03
10231	PG0583	2017-08-10 06:35:00+03	2017-08-10 08:30:00+03	OVB	ABA	Arrived	CN1	2017-08-10 06:41:00+03	2017-08-10 08:35:00+03
10232	PG0583	2017-07-16 06:35:00+03	2017-07-16 08:30:00+03	OVB	ABA	Arrived	CN1	2017-07-16 06:39:00+03	2017-07-16 08:31:00+03
10233	PG0584	2017-09-03 07:45:00+03	2017-09-03 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10234	PG0584	2017-08-13 07:45:00+03	2017-08-13 09:40:00+03	OVB	ABA	Arrived	CN1	2017-08-13 07:46:00+03	2017-08-13 09:42:00+03
10235	PG0584	2017-07-17 07:45:00+03	2017-07-17 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-17 07:47:00+03	2017-07-17 09:42:00+03
10236	PG0584	2017-09-09 07:45:00+03	2017-09-09 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10237	PG0584	2017-08-28 07:45:00+03	2017-08-28 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10238	PG0583	2017-09-06 06:35:00+03	2017-09-06 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10239	PG0583	2017-09-09 06:35:00+03	2017-09-09 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10240	PG0583	2017-09-01 06:35:00+03	2017-09-01 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10241	PG0584	2017-08-27 07:45:00+03	2017-08-27 09:40:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10242	PG0584	2017-07-26 07:45:00+03	2017-07-26 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-26 07:52:00+03	2017-07-26 09:47:00+03
10243	PG0583	2017-08-28 06:35:00+03	2017-08-28 08:30:00+03	OVB	ABA	Scheduled	CN1	\N	\N
10244	PG0584	2017-07-23 07:45:00+03	2017-07-23 09:40:00+03	OVB	ABA	Arrived	CN1	2017-07-23 07:47:00+03	2017-07-23 09:42:00+03
10245	PG0390	2017-08-06 07:10:00+03	2017-08-06 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-06 07:11:00+03	2017-08-06 10:01:00+03
10246	PG0390	2017-07-23 07:10:00+03	2017-07-23 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-23 07:15:00+03	2017-07-23 10:01:00+03
10247	PG0390	2017-08-16 07:10:00+03	2017-08-16 10:00:00+03	OVB	MJZ	On Time	CR2	\N	\N
10248	PG0390	2017-09-07 07:10:00+03	2017-09-07 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10249	PG0390	2017-09-06 07:10:00+03	2017-09-06 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10250	PG0390	2017-07-31 07:10:00+03	2017-07-31 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-31 07:11:00+03	2017-07-31 10:00:00+03
10251	PG0390	2017-07-28 07:10:00+03	2017-07-28 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-28 07:14:00+03	2017-07-28 10:07:00+03
10252	PG0390	2017-09-11 07:10:00+03	2017-09-11 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10253	PG0390	2017-09-03 07:10:00+03	2017-09-03 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10254	PG0390	2017-08-09 07:10:00+03	2017-08-09 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-09 07:13:00+03	2017-08-09 10:02:00+03
10255	PG0390	2017-08-10 07:10:00+03	2017-08-10 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-10 07:15:00+03	2017-08-10 10:03:00+03
10256	PG0390	2017-07-24 07:10:00+03	2017-07-24 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-24 07:15:00+03	2017-07-24 10:08:00+03
10257	PG0390	2017-07-27 07:10:00+03	2017-07-27 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-27 07:10:00+03	2017-07-27 09:59:00+03
10258	PG0390	2017-07-17 07:10:00+03	2017-07-17 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-17 07:18:00+03	2017-07-17 10:06:00+03
10259	PG0390	2017-09-02 07:10:00+03	2017-09-02 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10260	PG0390	2017-08-07 07:10:00+03	2017-08-07 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-07 07:12:00+03	2017-08-07 10:02:00+03
10261	PG0390	2017-09-05 07:10:00+03	2017-09-05 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10262	PG0390	2017-08-24 07:10:00+03	2017-08-24 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10263	PG0390	2017-08-14 07:10:00+03	2017-08-14 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-14 07:14:00+03	2017-08-14 10:05:00+03
10264	PG0390	2017-08-17 07:10:00+03	2017-08-17 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10265	PG0390	2017-07-25 07:10:00+03	2017-07-25 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-25 07:13:00+03	2017-07-25 10:05:00+03
10266	PG0390	2017-08-03 07:10:00+03	2017-08-03 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-03 07:13:00+03	2017-08-03 10:03:00+03
10267	PG0390	2017-08-12 07:10:00+03	2017-08-12 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-12 07:11:00+03	2017-08-12 10:01:00+03
10268	PG0390	2017-08-02 07:10:00+03	2017-08-02 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-02 07:17:00+03	2017-08-02 10:07:00+03
10269	PG0390	2017-08-18 07:10:00+03	2017-08-18 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10270	PG0390	2017-08-30 07:10:00+03	2017-08-30 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10271	PG0390	2017-08-19 07:10:00+03	2017-08-19 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10272	PG0390	2017-09-08 07:10:00+03	2017-09-08 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10273	PG0390	2017-09-10 07:10:00+03	2017-09-10 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10274	PG0390	2017-09-04 07:10:00+03	2017-09-04 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10275	PG0390	2017-08-20 07:10:00+03	2017-08-20 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10276	PG0390	2017-07-20 07:10:00+03	2017-07-20 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-20 07:14:00+03	2017-07-20 10:04:00+03
10277	PG0390	2017-08-21 07:10:00+03	2017-08-21 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10278	PG0390	2017-08-05 07:10:00+03	2017-08-05 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-05 07:12:00+03	2017-08-05 10:01:00+03
10279	PG0390	2017-08-22 07:10:00+03	2017-08-22 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10280	PG0390	2017-07-18 07:10:00+03	2017-07-18 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-18 07:13:00+03	2017-07-18 10:04:00+03
10281	PG0390	2017-09-01 07:10:00+03	2017-09-01 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10282	PG0390	2017-07-22 07:10:00+03	2017-07-22 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-22 07:12:00+03	2017-07-22 10:03:00+03
10283	PG0390	2017-09-13 07:10:00+03	2017-09-13 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10284	PG0390	2017-08-29 07:10:00+03	2017-08-29 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10285	PG0390	2017-09-12 07:10:00+03	2017-09-12 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10286	PG0390	2017-08-11 07:10:00+03	2017-08-11 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-11 07:14:00+03	2017-08-11 10:02:00+03
10287	PG0390	2017-07-21 07:10:00+03	2017-07-21 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-21 07:13:00+03	2017-07-21 10:01:00+03
10288	PG0390	2017-08-27 07:10:00+03	2017-08-27 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10289	PG0390	2017-08-31 07:10:00+03	2017-08-31 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10290	PG0390	2017-08-13 07:10:00+03	2017-08-13 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-13 07:10:00+03	2017-08-13 09:58:00+03
10291	PG0390	2017-08-28 07:10:00+03	2017-08-28 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10292	PG0390	2017-08-23 07:10:00+03	2017-08-23 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10293	PG0390	2017-08-26 07:10:00+03	2017-08-26 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10294	PG0390	2017-07-29 07:10:00+03	2017-07-29 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-29 07:14:00+03	2017-07-29 10:05:00+03
10295	PG0390	2017-08-01 07:10:00+03	2017-08-01 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-01 07:13:00+03	2017-08-01 10:05:00+03
10296	PG0390	2017-08-25 07:10:00+03	2017-08-25 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10297	PG0390	2017-08-08 07:10:00+03	2017-08-08 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-08 07:12:00+03	2017-08-08 10:01:00+03
10298	PG0390	2017-09-09 07:10:00+03	2017-09-09 10:00:00+03	OVB	MJZ	Scheduled	CR2	\N	\N
10299	PG0390	2017-08-04 07:10:00+03	2017-08-04 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-04 07:14:00+03	2017-08-04 10:03:00+03
10300	PG0390	2017-07-26 07:10:00+03	2017-07-26 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-26 07:13:00+03	2017-07-26 10:02:00+03
10301	PG0390	2017-09-14 07:10:00+03	2017-09-14 10:00:00+03	OVB	MJZ	Cancelled	CR2	\N	\N
10302	PG0390	2017-08-15 07:10:00+03	2017-08-15 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-08-15 07:12:00+03	2017-08-15 10:03:00+03
10303	PG0390	2017-07-16 07:10:00+03	2017-07-16 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-16 07:14:00+03	2017-07-16 10:05:00+03
10304	PG0390	2017-07-30 07:10:00+03	2017-07-30 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-30 07:12:00+03	2017-07-30 10:03:00+03
10305	PG0390	2017-07-19 07:10:00+03	2017-07-19 10:00:00+03	OVB	MJZ	Arrived	CR2	2017-07-19 07:13:00+03	2017-07-19 10:02:00+03
10306	PG0083	2017-08-07 06:15:00+03	2017-08-07 09:05:00+03	OVB	PYJ	Arrived	CR2	2017-08-07 06:16:00+03	2017-08-07 09:07:00+03
10307	PG0083	2017-08-28 06:15:00+03	2017-08-28 09:05:00+03	OVB	PYJ	Scheduled	CR2	\N	\N
10308	PG0083	2017-09-11 06:15:00+03	2017-09-11 09:05:00+03	OVB	PYJ	Cancelled	CR2	\N	\N
10309	PG0083	2017-08-14 06:15:00+03	2017-08-14 09:05:00+03	OVB	PYJ	Arrived	CR2	2017-08-14 06:17:00+03	2017-08-14 09:09:00+03
10310	PG0083	2017-07-24 06:15:00+03	2017-07-24 09:05:00+03	OVB	PYJ	Arrived	CR2	2017-07-24 06:17:00+03	2017-07-24 09:09:00+03
10311	PG0083	2017-09-04 06:15:00+03	2017-09-04 09:05:00+03	OVB	PYJ	Scheduled	CR2	\N	\N
10312	PG0083	2017-07-17 06:15:00+03	2017-07-17 09:05:00+03	OVB	PYJ	Arrived	CR2	2017-07-17 06:18:00+03	2017-07-17 09:07:00+03
10313	PG0083	2017-08-21 06:15:00+03	2017-08-21 09:05:00+03	OVB	PYJ	Scheduled	CR2	\N	\N
10314	PG0083	2017-07-31 06:15:00+03	2017-07-31 09:05:00+03	OVB	PYJ	Arrived	CR2	2017-07-31 06:21:00+03	2017-07-31 09:07:00+03
10315	PG0376	2017-07-16 10:05:00+03	2017-07-16 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-16 10:08:00+03	2017-07-16 12:18:00+03
10316	PG0376	2017-08-02 10:05:00+03	2017-08-02 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-02 10:10:00+03	2017-08-02 12:20:00+03
10317	PG0376	2017-09-12 10:05:00+03	2017-09-12 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10318	PG0376	2017-09-05 10:05:00+03	2017-09-05 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10319	PG0376	2017-07-29 10:05:00+03	2017-07-29 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-29 10:10:00+03	2017-07-29 12:20:00+03
10320	PG0376	2017-08-15 10:05:00+03	2017-08-15 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-15 10:05:00+03	2017-08-15 12:15:00+03
10321	PG0376	2017-08-04 10:05:00+03	2017-08-04 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-04 10:10:00+03	2017-08-04 12:19:00+03
10322	PG0376	2017-07-26 10:05:00+03	2017-07-26 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-26 10:07:00+03	2017-07-26 12:16:00+03
10323	PG0376	2017-08-20 10:05:00+03	2017-08-20 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10324	PG0376	2017-08-01 10:05:00+03	2017-08-01 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-01 10:07:00+03	2017-08-01 12:17:00+03
10325	PG0376	2017-08-21 10:05:00+03	2017-08-21 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10326	PG0376	2017-08-12 10:05:00+03	2017-08-12 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-12 10:07:00+03	2017-08-12 12:17:00+03
10327	PG0376	2017-09-07 10:05:00+03	2017-09-07 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10328	PG0376	2017-08-30 10:05:00+03	2017-08-30 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10329	PG0376	2017-09-04 10:05:00+03	2017-09-04 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10330	PG0376	2017-08-26 10:05:00+03	2017-08-26 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10331	PG0376	2017-09-06 10:05:00+03	2017-09-06 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10332	PG0376	2017-08-25 10:05:00+03	2017-08-25 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10333	PG0376	2017-07-22 10:05:00+03	2017-07-22 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-22 10:09:00+03	2017-07-22 12:19:00+03
10334	PG0376	2017-08-18 10:05:00+03	2017-08-18 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10335	PG0376	2017-08-13 10:05:00+03	2017-08-13 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-13 10:10:00+03	2017-08-13 12:18:00+03
10336	PG0376	2017-08-23 10:05:00+03	2017-08-23 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10337	PG0376	2017-08-08 10:05:00+03	2017-08-08 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-08 10:08:00+03	2017-08-08 12:18:00+03
10338	PG0376	2017-09-14 10:05:00+03	2017-09-14 12:15:00+03	OVB	SLY	Cancelled	CR2	\N	\N
10339	PG0376	2017-07-28 10:05:00+03	2017-07-28 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-28 10:10:00+03	2017-07-28 12:20:00+03
10340	PG0376	2017-07-20 10:05:00+03	2017-07-20 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-20 10:07:00+03	2017-07-20 12:17:00+03
10341	PG0376	2017-07-17 10:05:00+03	2017-07-17 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-17 10:05:00+03	2017-07-17 12:16:00+03
10342	PG0376	2017-07-19 10:05:00+03	2017-07-19 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-19 10:08:00+03	2017-07-19 12:18:00+03
10343	PG0376	2017-07-27 10:05:00+03	2017-07-27 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-27 10:07:00+03	2017-07-27 12:17:00+03
10344	PG0376	2017-07-24 10:05:00+03	2017-07-24 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-24 10:06:00+03	2017-07-24 12:15:00+03
10345	PG0376	2017-07-30 10:05:00+03	2017-07-30 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-30 10:06:00+03	2017-07-30 12:18:00+03
10346	PG0376	2017-08-29 10:05:00+03	2017-08-29 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10347	PG0376	2017-08-16 10:05:00+03	2017-08-16 12:15:00+03	OVB	SLY	On Time	CR2	\N	\N
10348	PG0376	2017-09-11 10:05:00+03	2017-09-11 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10349	PG0376	2017-07-18 10:05:00+03	2017-07-18 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-18 10:08:00+03	2017-07-18 12:18:00+03
10350	PG0376	2017-08-17 10:05:00+03	2017-08-17 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10351	PG0376	2017-07-31 10:05:00+03	2017-07-31 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-31 10:09:00+03	2017-07-31 12:19:00+03
10352	PG0376	2017-08-07 10:05:00+03	2017-08-07 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-07 10:11:00+03	2017-08-07 12:19:00+03
10353	PG0376	2017-08-11 10:05:00+03	2017-08-11 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-11 10:08:00+03	2017-08-11 12:18:00+03
10354	PG0376	2017-08-06 10:05:00+03	2017-08-06 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-06 10:06:00+03	2017-08-06 12:19:00+03
10355	PG0376	2017-09-09 10:05:00+03	2017-09-09 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10356	PG0376	2017-09-10 10:05:00+03	2017-09-10 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10357	PG0376	2017-09-13 10:05:00+03	2017-09-13 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10358	PG0376	2017-08-14 10:05:00+03	2017-08-14 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-14 10:10:00+03	2017-08-14 12:20:00+03
10359	PG0376	2017-07-21 10:05:00+03	2017-07-21 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-21 10:07:00+03	2017-07-21 12:19:00+03
10360	PG0376	2017-08-28 10:05:00+03	2017-08-28 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10361	PG0376	2017-09-08 10:05:00+03	2017-09-08 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10362	PG0376	2017-09-01 10:05:00+03	2017-09-01 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10363	PG0376	2017-09-02 10:05:00+03	2017-09-02 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10364	PG0376	2017-08-22 10:05:00+03	2017-08-22 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10365	PG0376	2017-08-24 10:05:00+03	2017-08-24 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10366	PG0376	2017-09-03 10:05:00+03	2017-09-03 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10367	PG0376	2017-08-27 10:05:00+03	2017-08-27 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10368	PG0376	2017-08-09 10:05:00+03	2017-08-09 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-09 13:01:00+03	2017-08-09 15:12:00+03
10369	PG0376	2017-08-31 10:05:00+03	2017-08-31 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10370	PG0376	2017-08-19 10:05:00+03	2017-08-19 12:15:00+03	OVB	SLY	Scheduled	CR2	\N	\N
10371	PG0376	2017-08-03 10:05:00+03	2017-08-03 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-03 10:06:00+03	2017-08-03 12:13:00+03
10372	PG0376	2017-08-10 10:05:00+03	2017-08-10 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-10 10:07:00+03	2017-08-10 12:20:00+03
10373	PG0376	2017-07-25 10:05:00+03	2017-07-25 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-25 10:07:00+03	2017-07-25 12:18:00+03
10374	PG0376	2017-07-23 10:05:00+03	2017-07-23 12:15:00+03	OVB	SLY	Arrived	CR2	2017-07-23 10:08:00+03	2017-07-23 12:18:00+03
10375	PG0376	2017-08-05 10:05:00+03	2017-08-05 12:15:00+03	OVB	SLY	Arrived	CR2	2017-08-05 10:07:00+03	2017-08-05 12:15:00+03
10376	PG0574	2017-07-29 11:45:00+03	2017-07-29 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-29 11:50:00+03	2017-07-29 15:15:00+03
10377	PG0574	2017-09-03 11:45:00+03	2017-09-03 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10378	PG0574	2017-09-09 11:45:00+03	2017-09-09 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10379	PG0573	2017-08-12 07:35:00+03	2017-08-12 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-12 07:38:00+03	2017-08-12 11:03:00+03
10380	PG0573	2017-09-03 07:35:00+03	2017-09-03 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10381	PG0573	2017-07-18 07:35:00+03	2017-07-18 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-18 07:44:00+03	2017-07-18 11:09:00+03
10382	PG0573	2017-09-09 07:35:00+03	2017-09-09 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10383	PG0574	2017-07-18 11:45:00+03	2017-07-18 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-18 11:48:00+03	2017-07-18 15:14:00+03
10384	PG0574	2017-09-14 11:45:00+03	2017-09-14 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10385	PG0573	2017-09-14 07:35:00+03	2017-09-14 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10386	PG0574	2017-07-25 11:45:00+03	2017-07-25 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-25 11:49:00+03	2017-07-25 15:14:00+03
10387	PG0574	2017-09-06 11:45:00+03	2017-09-06 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10388	PG0573	2017-07-25 07:35:00+03	2017-07-25 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-25 07:42:00+03	2017-07-25 11:07:00+03
10389	PG0574	2017-09-04 11:45:00+03	2017-09-04 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10390	PG0573	2017-09-04 07:35:00+03	2017-09-04 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10391	PG0574	2017-07-24 11:45:00+03	2017-07-24 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-24 11:51:00+03	2017-07-24 15:17:00+03
10392	PG0574	2017-08-30 11:45:00+03	2017-08-30 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10393	PG0574	2017-08-17 11:45:00+03	2017-08-17 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10394	PG0573	2017-08-02 07:35:00+03	2017-08-02 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-02 07:36:00+03	2017-08-02 11:04:00+03
10395	PG0574	2017-08-02 11:45:00+03	2017-08-02 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-02 11:45:00+03	2017-08-02 15:11:00+03
10396	PG0573	2017-08-17 07:35:00+03	2017-08-17 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10397	PG0574	2017-08-29 11:45:00+03	2017-08-29 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10398	PG0574	2017-08-12 11:45:00+03	2017-08-12 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-12 11:51:00+03	2017-08-12 15:16:00+03
10399	PG0574	2017-07-31 11:45:00+03	2017-07-31 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-31 11:45:00+03	2017-07-31 15:14:00+03
10400	PG0574	2017-08-18 11:45:00+03	2017-08-18 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10401	PG0573	2017-07-27 07:35:00+03	2017-07-27 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-27 07:38:00+03	2017-07-27 11:06:00+03
10402	PG0573	2017-08-30 07:35:00+03	2017-08-30 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10403	PG0573	2017-08-05 07:35:00+03	2017-08-05 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-05 07:37:00+03	2017-08-05 11:03:00+03
10404	PG0574	2017-08-05 11:45:00+03	2017-08-05 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-05 11:47:00+03	2017-08-05 15:12:00+03
10405	PG0574	2017-08-14 11:45:00+03	2017-08-14 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-14 11:48:00+03	2017-08-14 15:11:00+03
10406	PG0573	2017-07-31 07:35:00+03	2017-07-31 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-31 07:39:00+03	2017-07-31 11:03:00+03
10407	PG0574	2017-08-22 11:45:00+03	2017-08-22 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10408	PG0574	2017-07-20 11:45:00+03	2017-07-20 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-20 11:47:00+03	2017-07-20 15:09:00+03
10409	PG0573	2017-08-22 07:35:00+03	2017-08-22 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10410	PG0574	2017-09-05 11:45:00+03	2017-09-05 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10411	PG0573	2017-09-05 07:35:00+03	2017-09-05 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10412	PG0573	2017-08-25 07:35:00+03	2017-08-25 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10413	PG0573	2017-08-14 07:35:00+03	2017-08-14 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-14 07:40:00+03	2017-08-14 11:07:00+03
10414	PG0574	2017-08-25 11:45:00+03	2017-08-25 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10415	PG0573	2017-07-17 07:35:00+03	2017-07-17 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-17 07:38:00+03	2017-07-17 11:03:00+03
10416	PG0574	2017-08-08 11:45:00+03	2017-08-08 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-08 11:49:00+03	2017-08-08 15:15:00+03
10417	PG0573	2017-08-08 07:35:00+03	2017-08-08 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-08 07:38:00+03	2017-08-08 11:02:00+03
10418	PG0573	2017-08-13 07:35:00+03	2017-08-13 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-13 07:41:00+03	2017-08-13 11:05:00+03
10419	PG0573	2017-08-21 07:35:00+03	2017-08-21 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10420	PG0573	2017-08-26 07:35:00+03	2017-08-26 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10421	PG0574	2017-07-27 11:45:00+03	2017-07-27 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-27 11:50:00+03	2017-07-27 15:14:00+03
10422	PG0574	2017-09-02 11:45:00+03	2017-09-02 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10423	PG0573	2017-09-02 07:35:00+03	2017-09-02 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10424	PG0573	2017-09-07 07:35:00+03	2017-09-07 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10425	PG0573	2017-08-20 07:35:00+03	2017-08-20 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10426	PG0574	2017-07-17 11:45:00+03	2017-07-17 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-17 11:47:00+03	2017-07-17 15:10:00+03
10427	PG0573	2017-07-20 07:35:00+03	2017-07-20 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-20 07:38:00+03	2017-07-20 11:02:00+03
10428	PG0574	2017-08-07 11:45:00+03	2017-08-07 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-07 11:51:00+03	2017-08-07 15:16:00+03
10429	PG0573	2017-08-07 07:35:00+03	2017-08-07 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-07 07:38:00+03	2017-08-07 11:00:00+03
10430	PG0574	2017-09-12 11:45:00+03	2017-09-12 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10431	PG0574	2017-08-03 11:45:00+03	2017-08-03 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-03 11:48:00+03	2017-08-03 15:14:00+03
10432	PG0573	2017-08-03 07:35:00+03	2017-08-03 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-03 07:38:00+03	2017-08-03 11:03:00+03
10433	PG0573	2017-09-12 07:35:00+03	2017-09-12 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10434	PG0574	2017-09-10 11:45:00+03	2017-09-10 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10435	PG0573	2017-08-24 07:35:00+03	2017-08-24 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10436	PG0574	2017-08-24 11:45:00+03	2017-08-24 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10437	PG0573	2017-09-08 07:35:00+03	2017-09-08 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10438	PG0574	2017-09-08 11:45:00+03	2017-09-08 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10439	PG0573	2017-09-11 07:35:00+03	2017-09-11 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10440	PG0574	2017-09-11 11:45:00+03	2017-09-11 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10441	PG0574	2017-09-13 11:45:00+03	2017-09-13 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10442	PG0573	2017-08-11 07:35:00+03	2017-08-11 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-11 07:39:00+03	2017-08-11 11:01:00+03
10443	PG0574	2017-08-11 11:45:00+03	2017-08-11 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-11 11:49:00+03	2017-08-11 15:16:00+03
10444	PG0574	2017-08-13 11:45:00+03	2017-08-13 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-13 11:46:00+03	2017-08-13 15:09:00+03
10445	PG0574	2017-07-30 11:45:00+03	2017-07-30 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-30 11:49:00+03	2017-07-30 15:12:00+03
10446	PG0573	2017-08-15 07:35:00+03	2017-08-15 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-15 10:42:00+03	2017-08-15 14:06:00+03
10447	PG0573	2017-07-30 07:35:00+03	2017-07-30 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-30 07:36:00+03	2017-07-30 11:00:00+03
10448	PG0573	2017-09-13 07:35:00+03	2017-09-13 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10449	PG0574	2017-08-15 11:45:00+03	2017-08-15 15:10:00+03	OVB	HMA	Departed	CN1	2017-08-15 15:00:00+03	\N
10450	PG0574	2017-08-21 11:45:00+03	2017-08-21 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10451	PG0573	2017-07-24 07:35:00+03	2017-07-24 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-24 07:36:00+03	2017-07-24 11:01:00+03
10452	PG0573	2017-08-04 07:35:00+03	2017-08-04 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-04 07:38:00+03	2017-08-04 11:03:00+03
10453	PG0573	2017-09-10 07:35:00+03	2017-09-10 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10454	PG0573	2017-07-29 07:35:00+03	2017-07-29 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-29 07:39:00+03	2017-07-29 11:02:00+03
10455	PG0574	2017-08-04 11:45:00+03	2017-08-04 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-04 11:47:00+03	2017-08-04 15:12:00+03
10456	PG0573	2017-08-19 07:35:00+03	2017-08-19 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10457	PG0574	2017-08-19 11:45:00+03	2017-08-19 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10458	PG0573	2017-08-27 07:35:00+03	2017-08-27 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10459	PG0574	2017-08-27 11:45:00+03	2017-08-27 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10460	PG0574	2017-07-19 11:45:00+03	2017-07-19 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-19 11:50:00+03	2017-07-19 15:16:00+03
10461	PG0573	2017-07-19 07:35:00+03	2017-07-19 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-19 07:36:00+03	2017-07-19 10:59:00+03
10462	PG0573	2017-08-09 07:35:00+03	2017-08-09 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-09 11:02:00+03	2017-08-09 14:25:00+03
10463	PG0573	2017-07-28 07:35:00+03	2017-07-28 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-28 07:39:00+03	2017-07-28 11:05:00+03
10464	PG0573	2017-08-29 07:35:00+03	2017-08-29 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10465	PG0573	2017-07-26 07:35:00+03	2017-07-26 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-26 07:37:00+03	2017-07-26 11:04:00+03
10466	PG0574	2017-07-26 11:45:00+03	2017-07-26 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-26 11:46:00+03	2017-07-26 15:11:00+03
10467	PG0574	2017-08-28 11:45:00+03	2017-08-28 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10468	PG0573	2017-08-16 07:35:00+03	2017-08-16 11:00:00+03	OVB	HMA	On Time	CN1	\N	\N
10469	PG0574	2017-07-28 11:45:00+03	2017-07-28 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-28 11:46:00+03	2017-07-28 15:10:00+03
10470	PG0574	2017-08-16 11:45:00+03	2017-08-16 15:10:00+03	OVB	HMA	On Time	CN1	\N	\N
10471	PG0573	2017-08-06 07:35:00+03	2017-08-06 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-06 07:37:00+03	2017-08-06 11:00:00+03
10472	PG0574	2017-08-26 11:45:00+03	2017-08-26 15:10:00+03	OVB	HMA	Cancelled	CN1	\N	\N
10473	PG0574	2017-08-06 11:45:00+03	2017-08-06 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-06 11:47:00+03	2017-08-06 15:08:00+03
10474	PG0574	2017-09-07 11:45:00+03	2017-09-07 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10475	PG0574	2017-08-01 11:45:00+03	2017-08-01 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-01 11:50:00+03	2017-08-01 15:18:00+03
10476	PG0573	2017-08-01 07:35:00+03	2017-08-01 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-01 07:39:00+03	2017-08-01 11:04:00+03
10477	PG0574	2017-07-16 11:45:00+03	2017-07-16 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-16 11:50:00+03	2017-07-16 15:11:00+03
10478	PG0573	2017-07-16 07:35:00+03	2017-07-16 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-16 07:37:00+03	2017-07-16 11:00:00+03
10479	PG0573	2017-08-18 07:35:00+03	2017-08-18 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10480	PG0573	2017-08-31 07:35:00+03	2017-08-31 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10481	PG0573	2017-09-01 07:35:00+03	2017-09-01 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10482	PG0574	2017-09-01 11:45:00+03	2017-09-01 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10483	PG0574	2017-08-31 11:45:00+03	2017-08-31 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10484	PG0574	2017-08-10 11:45:00+03	2017-08-10 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-10 11:52:00+03	2017-08-10 15:19:00+03
10485	PG0574	2017-08-09 11:45:00+03	2017-08-09 15:10:00+03	OVB	HMA	Arrived	CN1	2017-08-09 11:49:00+03	2017-08-09 15:15:00+03
10486	PG0573	2017-08-10 07:35:00+03	2017-08-10 11:00:00+03	OVB	HMA	Arrived	CN1	2017-08-10 07:38:00+03	2017-08-10 11:04:00+03
10487	PG0573	2017-09-06 07:35:00+03	2017-09-06 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10488	PG0574	2017-08-23 11:45:00+03	2017-08-23 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10489	PG0573	2017-07-22 07:35:00+03	2017-07-22 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-22 10:31:00+03	2017-07-22 13:52:00+03
10490	PG0574	2017-07-22 11:45:00+03	2017-07-22 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-22 11:48:00+03	2017-07-22 15:18:00+03
10491	PG0574	2017-07-23 11:45:00+03	2017-07-23 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-23 11:48:00+03	2017-07-23 15:10:00+03
10492	PG0573	2017-07-23 07:35:00+03	2017-07-23 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-23 07:40:00+03	2017-07-23 11:07:00+03
10493	PG0573	2017-07-21 07:35:00+03	2017-07-21 11:00:00+03	OVB	HMA	Arrived	CN1	2017-07-21 07:39:00+03	2017-07-21 11:02:00+03
10494	PG0574	2017-07-21 11:45:00+03	2017-07-21 15:10:00+03	OVB	HMA	Arrived	CN1	2017-07-21 11:47:00+03	2017-07-21 15:11:00+03
10495	PG0573	2017-08-28 07:35:00+03	2017-08-28 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10496	PG0573	2017-08-23 07:35:00+03	2017-08-23 11:00:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10497	PG0574	2017-08-20 11:45:00+03	2017-08-20 15:10:00+03	OVB	HMA	Scheduled	CN1	\N	\N
10498	PG0323	2017-09-14 15:10:00+03	2017-09-14 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10499	PG0323	2017-08-12 15:10:00+03	2017-08-12 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-12 15:16:00+03	2017-08-12 16:36:00+03
10500	PG0323	2017-09-09 15:10:00+03	2017-09-09 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10501	PG0323	2017-09-06 15:10:00+03	2017-09-06 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10502	PG0323	2017-08-22 15:10:00+03	2017-08-22 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10503	PG0323	2017-07-26 15:10:00+03	2017-07-26 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-26 15:12:00+03	2017-07-26 16:33:00+03
10504	PG0323	2017-09-01 15:10:00+03	2017-09-01 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10505	PG0323	2017-08-11 15:10:00+03	2017-08-11 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-11 15:11:00+03	2017-08-11 16:32:00+03
10506	PG0323	2017-07-22 15:10:00+03	2017-07-22 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-22 15:11:00+03	2017-07-22 16:31:00+03
10507	PG0323	2017-08-02 15:10:00+03	2017-08-02 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-02 15:14:00+03	2017-08-02 16:35:00+03
10508	PG0323	2017-07-27 15:10:00+03	2017-07-27 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-27 15:13:00+03	2017-07-27 16:33:00+03
10509	PG0323	2017-08-14 15:10:00+03	2017-08-14 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-14 15:15:00+03	2017-08-14 16:36:00+03
10510	PG0323	2017-09-07 15:10:00+03	2017-09-07 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10511	PG0323	2017-07-17 15:10:00+03	2017-07-17 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-17 15:12:00+03	2017-07-17 16:34:00+03
10512	PG0323	2017-08-10 15:10:00+03	2017-08-10 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-10 15:12:00+03	2017-08-10 16:31:00+03
10513	PG0323	2017-08-20 15:10:00+03	2017-08-20 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10514	PG0323	2017-08-27 15:10:00+03	2017-08-27 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10515	PG0323	2017-08-24 15:10:00+03	2017-08-24 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10516	PG0323	2017-07-23 15:10:00+03	2017-07-23 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-23 18:14:00+03	2017-07-23 19:35:00+03
10517	PG0323	2017-08-28 15:10:00+03	2017-08-28 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10518	PG0323	2017-08-13 15:10:00+03	2017-08-13 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-13 15:14:00+03	2017-08-13 16:34:00+03
10519	PG0323	2017-08-16 15:10:00+03	2017-08-16 16:30:00+03	OVB	RGK	On Time	CN1	\N	\N
10520	PG0323	2017-07-30 15:10:00+03	2017-07-30 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-30 15:12:00+03	2017-07-30 16:31:00+03
10521	PG0323	2017-09-02 15:10:00+03	2017-09-02 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10522	PG0323	2017-08-03 15:10:00+03	2017-08-03 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-03 15:15:00+03	2017-08-03 16:36:00+03
10523	PG0323	2017-08-09 15:10:00+03	2017-08-09 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-09 15:15:00+03	2017-08-09 16:37:00+03
10524	PG0323	2017-09-05 15:10:00+03	2017-09-05 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10525	PG0323	2017-07-18 15:10:00+03	2017-07-18 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-18 15:13:00+03	2017-07-18 16:33:00+03
10526	PG0323	2017-08-17 15:10:00+03	2017-08-17 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10527	PG0323	2017-07-25 15:10:00+03	2017-07-25 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-25 15:13:00+03	2017-07-25 16:33:00+03
10528	PG0323	2017-08-30 15:10:00+03	2017-08-30 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10529	PG0323	2017-07-21 15:10:00+03	2017-07-21 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-21 15:12:00+03	2017-07-21 16:32:00+03
10530	PG0323	2017-08-23 15:10:00+03	2017-08-23 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10531	PG0323	2017-08-15 15:10:00+03	2017-08-15 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-15 15:11:00+03	2017-08-15 16:32:00+03
10532	PG0323	2017-08-08 15:10:00+03	2017-08-08 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-08 15:11:00+03	2017-08-08 16:30:00+03
10533	PG0323	2017-07-28 15:10:00+03	2017-07-28 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-28 15:14:00+03	2017-07-28 16:35:00+03
10534	PG0323	2017-07-31 15:10:00+03	2017-07-31 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-31 15:14:00+03	2017-07-31 16:35:00+03
10535	PG0323	2017-08-19 15:10:00+03	2017-08-19 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10536	PG0323	2017-08-29 15:10:00+03	2017-08-29 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10537	PG0323	2017-08-04 15:10:00+03	2017-08-04 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-04 15:11:00+03	2017-08-04 16:31:00+03
10538	PG0323	2017-09-12 15:10:00+03	2017-09-12 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10539	PG0323	2017-08-26 15:10:00+03	2017-08-26 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10540	PG0323	2017-07-24 15:10:00+03	2017-07-24 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-24 15:13:00+03	2017-07-24 16:33:00+03
10541	PG0323	2017-09-03 15:10:00+03	2017-09-03 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10542	PG0323	2017-09-13 15:10:00+03	2017-09-13 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10543	PG0323	2017-08-07 15:10:00+03	2017-08-07 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-07 15:15:00+03	2017-08-07 16:34:00+03
10544	PG0323	2017-07-19 15:10:00+03	2017-07-19 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-19 15:15:00+03	2017-07-19 16:34:00+03
10545	PG0323	2017-09-08 15:10:00+03	2017-09-08 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10546	PG0323	2017-08-21 15:10:00+03	2017-08-21 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10547	PG0323	2017-08-31 15:10:00+03	2017-08-31 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10548	PG0323	2017-09-10 15:10:00+03	2017-09-10 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10549	PG0323	2017-07-29 15:10:00+03	2017-07-29 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-29 15:13:00+03	2017-07-29 16:32:00+03
10550	PG0323	2017-08-05 15:10:00+03	2017-08-05 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-05 15:16:00+03	2017-08-05 16:36:00+03
10551	PG0323	2017-09-04 15:10:00+03	2017-09-04 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10552	PG0323	2017-07-20 15:10:00+03	2017-07-20 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-20 15:12:00+03	2017-07-20 16:32:00+03
10553	PG0323	2017-08-06 15:10:00+03	2017-08-06 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-06 15:14:00+03	2017-08-06 16:34:00+03
10554	PG0323	2017-09-11 15:10:00+03	2017-09-11 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10555	PG0323	2017-07-16 15:10:00+03	2017-07-16 16:30:00+03	OVB	RGK	Arrived	CN1	2017-07-16 15:15:00+03	2017-07-16 16:35:00+03
10556	PG0323	2017-08-18 15:10:00+03	2017-08-18 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10557	PG0323	2017-08-01 15:10:00+03	2017-08-01 16:30:00+03	OVB	RGK	Arrived	CN1	2017-08-01 15:10:00+03	2017-08-01 16:29:00+03
10558	PG0323	2017-08-25 15:10:00+03	2017-08-25 16:30:00+03	OVB	RGK	Scheduled	CN1	\N	\N
10559	PG0295	2017-09-04 16:20:00+03	2017-09-04 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10560	PG0296	2017-07-23 13:15:00+03	2017-07-23 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-23 13:16:00+03	2017-07-23 13:41:00+03
10561	PG0295	2017-08-16 16:20:00+03	2017-08-16 16:45:00+03	OVB	NOZ	On Time	SU9	\N	\N
10562	PG0296	2017-09-03 13:15:00+03	2017-09-03 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10563	PG0295	2017-09-03 16:20:00+03	2017-09-03 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10564	PG0296	2017-08-08 13:15:00+03	2017-08-08 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-08 13:15:00+03	2017-08-08 13:40:00+03
10565	PG0295	2017-07-18 16:20:00+03	2017-07-18 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-18 16:24:00+03	2017-07-18 16:49:00+03
10566	PG0296	2017-09-05 13:15:00+03	2017-09-05 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10567	PG0296	2017-08-05 13:15:00+03	2017-08-05 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-05 13:17:00+03	2017-08-05 13:42:00+03
10568	PG0295	2017-09-05 16:20:00+03	2017-09-05 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10569	PG0296	2017-07-28 13:15:00+03	2017-07-28 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-28 13:16:00+03	2017-07-28 13:41:00+03
10570	PG0295	2017-08-05 16:20:00+03	2017-08-05 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-05 16:21:00+03	2017-08-05 16:46:00+03
10571	PG0296	2017-07-18 13:15:00+03	2017-07-18 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-18 13:18:00+03	2017-07-18 13:43:00+03
10572	PG0296	2017-08-16 13:15:00+03	2017-08-16 13:40:00+03	OVB	NOZ	On Time	SU9	\N	\N
10573	PG0296	2017-09-06 13:15:00+03	2017-09-06 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10574	PG0296	2017-07-26 13:15:00+03	2017-07-26 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-26 13:17:00+03	2017-07-26 13:42:00+03
10575	PG0296	2017-09-12 13:15:00+03	2017-09-12 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10576	PG0296	2017-08-27 13:15:00+03	2017-08-27 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10577	PG0295	2017-07-28 16:20:00+03	2017-07-28 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-28 16:20:00+03	2017-07-28 16:45:00+03
10578	PG0295	2017-08-17 16:20:00+03	2017-08-17 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10579	PG0295	2017-09-06 16:20:00+03	2017-09-06 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10580	PG0296	2017-08-17 13:15:00+03	2017-08-17 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10581	PG0295	2017-08-12 16:20:00+03	2017-08-12 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-12 16:23:00+03	2017-08-12 16:48:00+03
10582	PG0295	2017-09-12 16:20:00+03	2017-09-12 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10583	PG0295	2017-08-25 16:20:00+03	2017-08-25 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10584	PG0296	2017-08-25 13:15:00+03	2017-08-25 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10585	PG0295	2017-08-24 16:20:00+03	2017-08-24 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10586	PG0295	2017-08-01 16:20:00+03	2017-08-01 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-01 16:21:00+03	2017-08-01 16:46:00+03
10587	PG0295	2017-09-08 16:20:00+03	2017-09-08 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10588	PG0296	2017-08-01 13:15:00+03	2017-08-01 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-01 13:17:00+03	2017-08-01 13:42:00+03
10589	PG0295	2017-07-17 16:20:00+03	2017-07-17 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-17 16:22:00+03	2017-07-17 16:47:00+03
10590	PG0295	2017-07-31 16:20:00+03	2017-07-31 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-31 16:22:00+03	2017-07-31 16:47:00+03
10591	PG0295	2017-09-10 16:20:00+03	2017-09-10 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10592	PG0296	2017-07-22 13:15:00+03	2017-07-22 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-22 13:17:00+03	2017-07-22 13:42:00+03
10593	PG0296	2017-08-02 13:15:00+03	2017-08-02 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-02 13:17:00+03	2017-08-02 13:42:00+03
10594	PG0295	2017-08-02 16:20:00+03	2017-08-02 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-02 16:22:00+03	2017-08-02 16:47:00+03
10595	PG0296	2017-08-13 13:15:00+03	2017-08-13 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-13 13:16:00+03	2017-08-13 13:41:00+03
10596	PG0295	2017-08-19 16:20:00+03	2017-08-19 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10597	PG0296	2017-08-19 13:15:00+03	2017-08-19 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10598	PG0295	2017-09-11 16:20:00+03	2017-09-11 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10599	PG0296	2017-07-17 13:15:00+03	2017-07-17 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-17 13:20:00+03	2017-07-17 13:45:00+03
10600	PG0296	2017-08-23 13:15:00+03	2017-08-23 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10601	PG0295	2017-08-20 16:20:00+03	2017-08-20 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10602	PG0295	2017-09-14 16:20:00+03	2017-09-14 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10603	PG0296	2017-08-31 13:15:00+03	2017-08-31 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10604	PG0296	2017-09-08 13:15:00+03	2017-09-08 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10605	PG0296	2017-09-07 13:15:00+03	2017-09-07 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10606	PG0295	2017-08-10 16:20:00+03	2017-08-10 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-10 16:23:00+03	2017-08-10 16:48:00+03
10607	PG0296	2017-08-10 13:15:00+03	2017-08-10 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-10 13:17:00+03	2017-08-10 13:42:00+03
10608	PG0295	2017-07-21 16:20:00+03	2017-07-21 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-21 16:24:00+03	2017-07-21 16:49:00+03
10609	PG0296	2017-07-21 13:15:00+03	2017-07-21 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-21 13:19:00+03	2017-07-21 13:44:00+03
10610	PG0295	2017-08-27 16:20:00+03	2017-08-27 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10611	PG0295	2017-09-07 16:20:00+03	2017-09-07 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10612	PG0295	2017-08-23 16:20:00+03	2017-08-23 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10613	PG0295	2017-09-13 16:20:00+03	2017-09-13 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10614	PG0295	2017-08-11 16:20:00+03	2017-08-11 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-11 16:23:00+03	2017-08-11 16:48:00+03
10615	PG0296	2017-08-11 13:15:00+03	2017-08-11 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-11 13:18:00+03	2017-08-11 13:43:00+03
10616	PG0296	2017-07-27 13:15:00+03	2017-07-27 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-27 13:15:00+03	2017-07-27 13:40:00+03
10617	PG0295	2017-08-31 16:20:00+03	2017-08-31 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10618	PG0296	2017-09-13 13:15:00+03	2017-09-13 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10619	PG0296	2017-08-20 13:15:00+03	2017-08-20 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10620	PG0295	2017-08-18 16:20:00+03	2017-08-18 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10621	PG0295	2017-08-28 16:20:00+03	2017-08-28 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10622	PG0295	2017-09-02 16:20:00+03	2017-09-02 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10623	PG0295	2017-08-30 16:20:00+03	2017-08-30 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10624	PG0296	2017-09-02 13:15:00+03	2017-09-02 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10625	PG0295	2017-08-13 16:20:00+03	2017-08-13 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-13 16:22:00+03	2017-08-13 16:47:00+03
10626	PG0296	2017-08-30 13:15:00+03	2017-08-30 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10627	PG0296	2017-09-11 13:15:00+03	2017-09-11 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10628	PG0295	2017-08-07 16:20:00+03	2017-08-07 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-07 16:24:00+03	2017-08-07 16:49:00+03
10629	PG0295	2017-08-14 16:20:00+03	2017-08-14 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-14 16:23:00+03	2017-08-14 16:48:00+03
10630	PG0296	2017-08-07 13:15:00+03	2017-08-07 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-07 13:16:00+03	2017-08-07 13:41:00+03
10631	PG0296	2017-08-24 13:15:00+03	2017-08-24 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10632	PG0295	2017-08-22 16:20:00+03	2017-08-22 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10633	PG0296	2017-08-18 13:15:00+03	2017-08-18 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10634	PG0295	2017-07-23 16:20:00+03	2017-07-23 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-23 16:26:00+03	2017-07-23 16:51:00+03
10635	PG0296	2017-08-04 13:15:00+03	2017-08-04 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-04 13:21:00+03	2017-08-04 13:46:00+03
10636	PG0295	2017-07-29 16:20:00+03	2017-07-29 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-29 16:26:00+03	2017-07-29 16:51:00+03
10637	PG0296	2017-07-20 13:15:00+03	2017-07-20 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-20 13:16:00+03	2017-07-20 13:41:00+03
10638	PG0296	2017-08-29 13:15:00+03	2017-08-29 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10639	PG0295	2017-08-29 16:20:00+03	2017-08-29 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10640	PG0296	2017-07-19 13:15:00+03	2017-07-19 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-19 13:18:00+03	2017-07-19 13:43:00+03
10641	PG0296	2017-08-28 13:15:00+03	2017-08-28 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10642	PG0295	2017-07-20 16:20:00+03	2017-07-20 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-20 16:23:00+03	2017-07-20 16:48:00+03
10643	PG0295	2017-07-25 16:20:00+03	2017-07-25 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-25 16:23:00+03	2017-07-25 16:48:00+03
10644	PG0296	2017-08-22 13:15:00+03	2017-08-22 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10645	PG0296	2017-08-14 13:15:00+03	2017-08-14 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-14 13:17:00+03	2017-08-14 13:42:00+03
10646	PG0296	2017-08-26 13:15:00+03	2017-08-26 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10647	PG0295	2017-07-19 16:20:00+03	2017-07-19 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-19 16:23:00+03	2017-07-19 16:48:00+03
10648	PG0296	2017-09-09 13:15:00+03	2017-09-09 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10649	PG0295	2017-08-04 16:20:00+03	2017-08-04 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-04 16:23:00+03	2017-08-04 16:48:00+03
10650	PG0296	2017-09-14 13:15:00+03	2017-09-14 13:40:00+03	OVB	NOZ	Cancelled	SU9	\N	\N
10651	PG0295	2017-09-09 16:20:00+03	2017-09-09 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10652	PG0296	2017-08-15 13:15:00+03	2017-08-15 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-15 13:16:00+03	2017-08-15 13:41:00+03
10653	PG0296	2017-07-16 13:15:00+03	2017-07-16 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-16 13:18:00+03	2017-07-16 13:43:00+03
10654	PG0296	2017-07-29 13:15:00+03	2017-07-29 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-29 13:18:00+03	2017-07-29 13:43:00+03
10655	PG0296	2017-07-25 13:15:00+03	2017-07-25 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-25 13:17:00+03	2017-07-25 13:42:00+03
10656	PG0295	2017-08-03 16:20:00+03	2017-08-03 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-03 16:21:00+03	2017-08-03 16:46:00+03
10657	PG0295	2017-08-15 16:20:00+03	2017-08-15 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-15 16:22:00+03	2017-08-15 16:47:00+03
10658	PG0296	2017-09-01 13:15:00+03	2017-09-01 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10659	PG0296	2017-08-03 13:15:00+03	2017-08-03 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-03 13:17:00+03	2017-08-03 13:42:00+03
10660	PG0295	2017-09-01 16:20:00+03	2017-09-01 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10661	PG0295	2017-07-24 16:20:00+03	2017-07-24 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-24 16:24:00+03	2017-07-24 16:48:00+03
10662	PG0296	2017-07-30 13:15:00+03	2017-07-30 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-30 13:22:00+03	2017-07-30 13:47:00+03
10663	PG0295	2017-07-16 16:20:00+03	2017-07-16 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-16 16:23:00+03	2017-07-16 16:48:00+03
10664	PG0295	2017-07-26 16:20:00+03	2017-07-26 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-26 16:24:00+03	2017-07-26 16:49:00+03
10665	PG0296	2017-07-31 13:15:00+03	2017-07-31 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-31 13:18:00+03	2017-07-31 13:43:00+03
10666	PG0295	2017-07-30 16:20:00+03	2017-07-30 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-30 16:22:00+03	2017-07-30 16:47:00+03
10667	PG0296	2017-08-09 13:15:00+03	2017-08-09 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-09 13:16:00+03	2017-08-09 13:41:00+03
10668	PG0295	2017-08-09 16:20:00+03	2017-08-09 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-09 16:23:00+03	2017-08-09 16:48:00+03
10669	PG0295	2017-07-27 16:20:00+03	2017-07-27 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-27 16:24:00+03	2017-07-27 16:49:00+03
10670	PG0295	2017-08-26 16:20:00+03	2017-08-26 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10671	PG0296	2017-09-04 13:15:00+03	2017-09-04 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10672	PG0296	2017-08-06 13:15:00+03	2017-08-06 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-06 13:17:00+03	2017-08-06 13:42:00+03
10673	PG0295	2017-08-21 16:20:00+03	2017-08-21 16:45:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10674	PG0296	2017-08-21 13:15:00+03	2017-08-21 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10675	PG0296	2017-09-10 13:15:00+03	2017-09-10 13:40:00+03	OVB	NOZ	Scheduled	SU9	\N	\N
10676	PG0296	2017-08-12 13:15:00+03	2017-08-12 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-08-12 13:18:00+03	2017-08-12 13:43:00+03
10677	PG0295	2017-07-22 16:20:00+03	2017-07-22 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-07-22 16:22:00+03	2017-07-22 16:47:00+03
10678	PG0296	2017-07-24 13:15:00+03	2017-07-24 13:40:00+03	OVB	NOZ	Arrived	SU9	2017-07-24 13:19:00+03	2017-07-24 13:44:00+03
10679	PG0295	2017-08-06 16:20:00+03	2017-08-06 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-06 16:24:00+03	2017-08-06 16:49:00+03
10680	PG0295	2017-08-08 16:20:00+03	2017-08-08 16:45:00+03	OVB	NOZ	Arrived	SU9	2017-08-08 16:23:00+03	2017-08-08 16:48:00+03
10681	PG0311	2017-08-02 13:35:00+03	2017-08-02 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-02 13:38:00+03	2017-08-02 16:24:00+03
10682	PG0311	2017-09-07 13:35:00+03	2017-09-07 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10683	PG0311	2017-08-05 13:35:00+03	2017-08-05 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-05 13:38:00+03	2017-08-05 16:22:00+03
10684	PG0311	2017-07-27 13:35:00+03	2017-07-27 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-27 13:36:00+03	2017-07-27 16:21:00+03
10685	PG0311	2017-08-14 13:35:00+03	2017-08-14 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-14 13:38:00+03	2017-08-14 16:22:00+03
10686	PG0311	2017-08-24 13:35:00+03	2017-08-24 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10687	PG0311	2017-09-10 13:35:00+03	2017-09-10 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10688	PG0311	2017-08-20 13:35:00+03	2017-08-20 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10689	PG0311	2017-07-17 13:35:00+03	2017-07-17 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-17 13:37:00+03	2017-07-17 16:22:00+03
10690	PG0311	2017-08-10 13:35:00+03	2017-08-10 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-10 13:38:00+03	2017-08-10 16:21:00+03
10691	PG0311	2017-08-13 13:35:00+03	2017-08-13 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-13 13:40:00+03	2017-08-13 16:24:00+03
10692	PG0311	2017-08-31 13:35:00+03	2017-08-31 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10693	PG0311	2017-08-23 13:35:00+03	2017-08-23 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10694	PG0311	2017-08-15 13:35:00+03	2017-08-15 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-15 13:36:00+03	2017-08-15 16:21:00+03
10695	PG0311	2017-09-09 13:35:00+03	2017-09-09 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10696	PG0311	2017-07-21 13:35:00+03	2017-07-21 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-21 13:40:00+03	2017-07-21 16:24:00+03
10697	PG0311	2017-08-25 13:35:00+03	2017-08-25 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10698	PG0311	2017-07-24 13:35:00+03	2017-07-24 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-24 13:35:00+03	2017-07-24 16:17:00+03
10699	PG0311	2017-07-16 13:35:00+03	2017-07-16 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-16 13:37:00+03	2017-07-16 16:21:00+03
10700	PG0311	2017-07-28 13:35:00+03	2017-07-28 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-28 13:36:00+03	2017-07-28 16:22:00+03
10701	PG0311	2017-08-30 13:35:00+03	2017-08-30 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10702	PG0311	2017-09-06 13:35:00+03	2017-09-06 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10703	PG0311	2017-07-31 13:35:00+03	2017-07-31 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-31 13:37:00+03	2017-07-31 16:24:00+03
10704	PG0311	2017-07-25 13:35:00+03	2017-07-25 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-25 13:37:00+03	2017-07-25 16:21:00+03
10705	PG0311	2017-09-11 13:35:00+03	2017-09-11 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10706	PG0311	2017-09-12 13:35:00+03	2017-09-12 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10707	PG0311	2017-08-22 13:35:00+03	2017-08-22 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10708	PG0311	2017-08-16 13:35:00+03	2017-08-16 16:20:00+03	OVB	KVX	On Time	SU9	\N	\N
10709	PG0311	2017-08-17 13:35:00+03	2017-08-17 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10710	PG0311	2017-07-18 13:35:00+03	2017-07-18 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-18 13:40:00+03	2017-07-18 16:24:00+03
10711	PG0311	2017-08-04 13:35:00+03	2017-08-04 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-04 13:35:00+03	2017-08-04 16:20:00+03
10712	PG0311	2017-08-08 13:35:00+03	2017-08-08 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-08 13:38:00+03	2017-08-08 16:21:00+03
10713	PG0311	2017-07-20 13:35:00+03	2017-07-20 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-20 13:37:00+03	2017-07-20 16:22:00+03
10714	PG0311	2017-09-05 13:35:00+03	2017-09-05 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10715	PG0311	2017-08-01 13:35:00+03	2017-08-01 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-01 13:39:00+03	2017-08-01 16:23:00+03
10716	PG0311	2017-08-28 13:35:00+03	2017-08-28 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10717	PG0311	2017-09-03 13:35:00+03	2017-09-03 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10718	PG0311	2017-08-26 13:35:00+03	2017-08-26 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10719	PG0311	2017-08-19 13:35:00+03	2017-08-19 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10720	PG0311	2017-08-06 13:35:00+03	2017-08-06 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-06 13:36:00+03	2017-08-06 16:19:00+03
10721	PG0311	2017-08-18 13:35:00+03	2017-08-18 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10722	PG0311	2017-08-09 13:35:00+03	2017-08-09 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-09 13:37:00+03	2017-08-09 16:21:00+03
10723	PG0311	2017-08-03 13:35:00+03	2017-08-03 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-03 13:37:00+03	2017-08-03 16:20:00+03
10724	PG0311	2017-09-04 13:35:00+03	2017-09-04 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10725	PG0311	2017-07-30 13:35:00+03	2017-07-30 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-30 13:36:00+03	2017-07-30 16:21:00+03
10726	PG0311	2017-09-01 13:35:00+03	2017-09-01 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10727	PG0311	2017-09-02 13:35:00+03	2017-09-02 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10728	PG0311	2017-07-29 13:35:00+03	2017-07-29 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-29 13:40:00+03	2017-07-29 16:27:00+03
10729	PG0311	2017-09-13 13:35:00+03	2017-09-13 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10730	PG0311	2017-08-12 13:35:00+03	2017-08-12 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-12 13:36:00+03	2017-08-12 16:19:00+03
10731	PG0311	2017-08-21 13:35:00+03	2017-08-21 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10732	PG0311	2017-08-07 13:35:00+03	2017-08-07 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-07 13:39:00+03	2017-08-07 16:25:00+03
10733	PG0311	2017-08-29 13:35:00+03	2017-08-29 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10734	PG0311	2017-08-11 13:35:00+03	2017-08-11 16:20:00+03	OVB	KVX	Arrived	SU9	2017-08-11 13:36:00+03	2017-08-11 16:24:00+03
10735	PG0311	2017-07-19 13:35:00+03	2017-07-19 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-19 13:37:00+03	2017-07-19 16:23:00+03
10736	PG0311	2017-07-26 13:35:00+03	2017-07-26 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-26 13:42:00+03	2017-07-26 16:26:00+03
10737	PG0311	2017-09-14 13:35:00+03	2017-09-14 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10738	PG0311	2017-09-08 13:35:00+03	2017-09-08 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10739	PG0311	2017-07-22 13:35:00+03	2017-07-22 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-22 13:40:00+03	2017-07-22 16:26:00+03
10740	PG0311	2017-08-27 13:35:00+03	2017-08-27 16:20:00+03	OVB	KVX	Scheduled	SU9	\N	\N
10741	PG0311	2017-07-23 13:35:00+03	2017-07-23 16:20:00+03	OVB	KVX	Arrived	SU9	2017-07-23 13:39:00+03	2017-07-23 16:25:00+03
10742	PG0655	2017-09-12 15:20:00+03	2017-09-12 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10743	PG0655	2017-08-20 15:20:00+03	2017-08-20 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10744	PG0655	2017-07-18 15:20:00+03	2017-07-18 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-18 15:22:00+03	2017-07-18 17:38:00+03
10745	PG0655	2017-07-16 15:20:00+03	2017-07-16 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-16 15:21:00+03	2017-07-16 17:34:00+03
10746	PG0655	2017-09-10 15:20:00+03	2017-09-10 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10747	PG0655	2017-09-02 15:20:00+03	2017-09-02 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10748	PG0655	2017-09-07 15:20:00+03	2017-09-07 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10749	PG0655	2017-09-09 15:20:00+03	2017-09-09 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10750	PG0655	2017-07-28 15:20:00+03	2017-07-28 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-28 15:24:00+03	2017-07-28 17:38:00+03
10751	PG0655	2017-09-08 15:20:00+03	2017-09-08 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10752	PG0655	2017-08-05 15:20:00+03	2017-08-05 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-05 15:23:00+03	2017-08-05 17:36:00+03
10753	PG0655	2017-07-26 15:20:00+03	2017-07-26 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-26 15:21:00+03	2017-07-26 17:36:00+03
10754	PG0655	2017-08-31 15:20:00+03	2017-08-31 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10755	PG0655	2017-07-24 15:20:00+03	2017-07-24 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-24 15:21:00+03	2017-07-24 17:37:00+03
10756	PG0655	2017-08-27 15:20:00+03	2017-08-27 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10757	PG0655	2017-08-13 15:20:00+03	2017-08-13 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-13 15:23:00+03	2017-08-13 17:36:00+03
10758	PG0655	2017-08-16 15:20:00+03	2017-08-16 17:35:00+03	OVB	MQF	On Time	CR2	\N	\N
10759	PG0655	2017-08-25 15:20:00+03	2017-08-25 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10760	PG0655	2017-07-29 15:20:00+03	2017-07-29 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-29 15:24:00+03	2017-07-29 17:40:00+03
10761	PG0655	2017-09-01 15:20:00+03	2017-09-01 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10762	PG0655	2017-08-12 15:20:00+03	2017-08-12 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-12 15:22:00+03	2017-08-12 17:36:00+03
10763	PG0655	2017-08-28 15:20:00+03	2017-08-28 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10764	PG0655	2017-07-25 15:20:00+03	2017-07-25 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-25 15:24:00+03	2017-07-25 17:41:00+03
10765	PG0655	2017-07-21 15:20:00+03	2017-07-21 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-21 15:23:00+03	2017-07-21 17:36:00+03
10766	PG0655	2017-08-19 15:20:00+03	2017-08-19 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10767	PG0655	2017-09-11 15:20:00+03	2017-09-11 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10768	PG0655	2017-08-06 15:20:00+03	2017-08-06 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-06 18:50:00+03	2017-08-06 21:06:00+03
10769	PG0655	2017-09-05 15:20:00+03	2017-09-05 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10770	PG0655	2017-08-15 15:20:00+03	2017-08-15 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-15 15:21:00+03	2017-08-15 17:36:00+03
10771	PG0655	2017-07-20 15:20:00+03	2017-07-20 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-20 15:21:00+03	2017-07-20 17:37:00+03
10772	PG0655	2017-07-27 15:20:00+03	2017-07-27 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-27 15:27:00+03	2017-07-27 17:41:00+03
10773	PG0655	2017-08-08 15:20:00+03	2017-08-08 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-08 15:21:00+03	2017-08-08 17:35:00+03
10774	PG0655	2017-07-19 15:20:00+03	2017-07-19 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-19 15:26:00+03	2017-07-19 17:42:00+03
10775	PG0655	2017-08-29 15:20:00+03	2017-08-29 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10776	PG0655	2017-08-03 15:20:00+03	2017-08-03 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-03 15:21:00+03	2017-08-03 17:34:00+03
10777	PG0655	2017-08-24 15:20:00+03	2017-08-24 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10778	PG0655	2017-08-11 15:20:00+03	2017-08-11 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-11 15:21:00+03	2017-08-11 17:36:00+03
10779	PG0655	2017-09-14 15:20:00+03	2017-09-14 17:35:00+03	OVB	MQF	Cancelled	CR2	\N	\N
10780	PG0655	2017-08-22 15:20:00+03	2017-08-22 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10781	PG0655	2017-08-01 15:20:00+03	2017-08-01 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-01 18:00:00+03	2017-08-01 20:13:00+03
10782	PG0655	2017-09-04 15:20:00+03	2017-09-04 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10783	PG0655	2017-09-13 15:20:00+03	2017-09-13 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10784	PG0655	2017-08-21 15:20:00+03	2017-08-21 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10785	PG0655	2017-08-04 15:20:00+03	2017-08-04 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-04 15:24:00+03	2017-08-04 17:40:00+03
10786	PG0655	2017-09-06 15:20:00+03	2017-09-06 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10787	PG0655	2017-08-30 15:20:00+03	2017-08-30 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10788	PG0655	2017-08-02 15:20:00+03	2017-08-02 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-02 15:21:00+03	2017-08-02 17:36:00+03
10789	PG0655	2017-08-26 15:20:00+03	2017-08-26 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10790	PG0655	2017-08-09 15:20:00+03	2017-08-09 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-09 15:22:00+03	2017-08-09 17:37:00+03
10791	PG0655	2017-07-31 15:20:00+03	2017-07-31 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-31 15:21:00+03	2017-07-31 17:35:00+03
10792	PG0655	2017-09-03 15:20:00+03	2017-09-03 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10793	PG0655	2017-07-17 15:20:00+03	2017-07-17 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-17 15:22:00+03	2017-07-17 17:39:00+03
10794	PG0655	2017-08-10 15:20:00+03	2017-08-10 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-10 15:22:00+03	2017-08-10 17:36:00+03
10795	PG0655	2017-08-17 15:20:00+03	2017-08-17 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10796	PG0655	2017-07-22 15:20:00+03	2017-07-22 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-22 15:23:00+03	2017-07-22 17:35:00+03
10797	PG0655	2017-08-23 15:20:00+03	2017-08-23 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10798	PG0655	2017-08-14 15:20:00+03	2017-08-14 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-14 15:22:00+03	2017-08-14 17:37:00+03
10799	PG0655	2017-07-30 15:20:00+03	2017-07-30 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-30 15:24:00+03	2017-07-30 17:38:00+03
10800	PG0655	2017-08-07 15:20:00+03	2017-08-07 17:35:00+03	OVB	MQF	Arrived	CR2	2017-08-07 15:26:00+03	2017-08-07 17:40:00+03
10801	PG0655	2017-08-18 15:20:00+03	2017-08-18 17:35:00+03	OVB	MQF	Scheduled	CR2	\N	\N
10802	PG0655	2017-07-23 15:20:00+03	2017-07-23 17:35:00+03	OVB	MQF	Arrived	CR2	2017-07-23 15:21:00+03	2017-07-23 17:35:00+03
10803	PG0287	2017-09-04 08:15:00+03	2017-09-04 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10804	PG0287	2017-08-31 08:15:00+03	2017-08-31 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10805	PG0287	2017-07-18 08:15:00+03	2017-07-18 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-18 08:19:00+03	2017-07-18 09:34:00+03
10806	PG0287	2017-07-16 08:15:00+03	2017-07-16 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-16 08:15:00+03	2017-07-16 09:29:00+03
10807	PG0287	2017-07-29 08:15:00+03	2017-07-29 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-29 08:20:00+03	2017-07-29 09:35:00+03
10808	PG0287	2017-09-12 08:15:00+03	2017-09-12 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10809	PG0287	2017-08-24 08:15:00+03	2017-08-24 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10810	PG0287	2017-08-17 08:15:00+03	2017-08-17 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10811	PG0287	2017-07-24 08:15:00+03	2017-07-24 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-24 08:16:00+03	2017-07-24 09:32:00+03
10812	PG0287	2017-08-06 08:15:00+03	2017-08-06 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-06 08:21:00+03	2017-08-06 09:36:00+03
10813	PG0287	2017-07-30 08:15:00+03	2017-07-30 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-30 08:18:00+03	2017-07-30 09:33:00+03
10814	PG0287	2017-08-08 08:15:00+03	2017-08-08 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-08 08:20:00+03	2017-08-08 09:35:00+03
10815	PG0287	2017-08-09 08:15:00+03	2017-08-09 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-09 08:18:00+03	2017-08-09 09:33:00+03
10816	PG0287	2017-08-19 08:15:00+03	2017-08-19 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10817	PG0287	2017-07-27 08:15:00+03	2017-07-27 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-27 12:08:00+03	2017-07-27 13:23:00+03
10818	PG0287	2017-07-28 08:15:00+03	2017-07-28 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-28 08:19:00+03	2017-07-28 09:34:00+03
10819	PG0287	2017-08-16 08:15:00+03	2017-08-16 09:30:00+03	OVB	SGC	On Time	CR2	\N	\N
10820	PG0287	2017-07-31 08:15:00+03	2017-07-31 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-31 08:23:00+03	2017-07-31 09:39:00+03
10821	PG0287	2017-08-21 08:15:00+03	2017-08-21 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10822	PG0287	2017-08-04 08:15:00+03	2017-08-04 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-04 08:19:00+03	2017-08-04 09:35:00+03
10823	PG0287	2017-07-17 08:15:00+03	2017-07-17 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-17 08:18:00+03	2017-07-17 09:33:00+03
10824	PG0287	2017-09-09 08:15:00+03	2017-09-09 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10825	PG0287	2017-09-01 08:15:00+03	2017-09-01 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10826	PG0287	2017-08-15 08:15:00+03	2017-08-15 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-15 08:18:00+03	2017-08-15 09:34:00+03
10827	PG0287	2017-08-29 08:15:00+03	2017-08-29 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10828	PG0287	2017-07-19 08:15:00+03	2017-07-19 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-19 08:19:00+03	2017-07-19 09:34:00+03
10829	PG0287	2017-07-20 08:15:00+03	2017-07-20 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-20 08:19:00+03	2017-07-20 09:33:00+03
10830	PG0287	2017-08-03 08:15:00+03	2017-08-03 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-03 08:16:00+03	2017-08-03 09:32:00+03
10831	PG0287	2017-08-20 08:15:00+03	2017-08-20 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10832	PG0287	2017-08-28 08:15:00+03	2017-08-28 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10833	PG0287	2017-07-25 08:15:00+03	2017-07-25 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-25 08:17:00+03	2017-07-25 09:31:00+03
10834	PG0287	2017-08-14 08:15:00+03	2017-08-14 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-14 08:19:00+03	2017-08-14 09:35:00+03
10835	PG0287	2017-08-01 08:15:00+03	2017-08-01 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-01 08:20:00+03	2017-08-01 09:35:00+03
10836	PG0287	2017-07-23 08:15:00+03	2017-07-23 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-23 08:19:00+03	2017-07-23 09:33:00+03
10837	PG0287	2017-07-22 08:15:00+03	2017-07-22 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-22 08:19:00+03	2017-07-22 09:34:00+03
10838	PG0287	2017-08-13 08:15:00+03	2017-08-13 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-13 08:19:00+03	2017-08-13 09:32:00+03
10839	PG0287	2017-08-07 08:15:00+03	2017-08-07 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-07 08:17:00+03	2017-08-07 09:32:00+03
10840	PG0287	2017-09-10 08:15:00+03	2017-09-10 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10841	PG0287	2017-07-26 08:15:00+03	2017-07-26 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-26 08:19:00+03	2017-07-26 09:34:00+03
10842	PG0287	2017-09-14 08:15:00+03	2017-09-14 09:30:00+03	OVB	SGC	Cancelled	CR2	\N	\N
10843	PG0287	2017-08-18 08:15:00+03	2017-08-18 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10844	PG0287	2017-08-11 08:15:00+03	2017-08-11 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-11 08:19:00+03	2017-08-11 09:33:00+03
10845	PG0287	2017-09-02 08:15:00+03	2017-09-02 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10846	PG0287	2017-09-07 08:15:00+03	2017-09-07 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10847	PG0287	2017-08-30 08:15:00+03	2017-08-30 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10848	PG0287	2017-08-27 08:15:00+03	2017-08-27 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10849	PG0287	2017-08-22 08:15:00+03	2017-08-22 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10850	PG0287	2017-08-10 08:15:00+03	2017-08-10 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-10 08:18:00+03	2017-08-10 09:34:00+03
10851	PG0287	2017-07-21 08:15:00+03	2017-07-21 09:30:00+03	OVB	SGC	Arrived	CR2	2017-07-21 08:17:00+03	2017-07-21 09:32:00+03
10852	PG0287	2017-08-23 08:15:00+03	2017-08-23 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10853	PG0287	2017-09-13 08:15:00+03	2017-09-13 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10854	PG0287	2017-08-26 08:15:00+03	2017-08-26 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10855	PG0287	2017-09-11 08:15:00+03	2017-09-11 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10856	PG0287	2017-09-08 08:15:00+03	2017-09-08 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10857	PG0287	2017-08-05 08:15:00+03	2017-08-05 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-05 08:21:00+03	2017-08-05 09:36:00+03
10858	PG0287	2017-08-02 08:15:00+03	2017-08-02 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-02 08:22:00+03	2017-08-02 09:37:00+03
10859	PG0287	2017-09-06 08:15:00+03	2017-09-06 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10860	PG0287	2017-08-25 08:15:00+03	2017-08-25 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10861	PG0287	2017-08-12 08:15:00+03	2017-08-12 09:30:00+03	OVB	SGC	Arrived	CR2	2017-08-12 08:22:00+03	2017-08-12 09:36:00+03
10862	PG0287	2017-09-05 08:15:00+03	2017-09-05 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10863	PG0287	2017-09-03 08:15:00+03	2017-09-03 09:30:00+03	OVB	SGC	Scheduled	CR2	\N	\N
10864	PG0047	2017-09-04 12:55:00+03	2017-09-04 16:50:00+03	OVB	KLF	Scheduled	SU9	\N	\N
10865	PG0047	2017-07-24 12:55:00+03	2017-07-24 16:50:00+03	OVB	KLF	Arrived	SU9	2017-07-24 13:00:00+03	2017-07-24 16:52:00+03
10866	PG0047	2017-07-17 12:55:00+03	2017-07-17 16:50:00+03	OVB	KLF	Arrived	SU9	2017-07-17 12:57:00+03	2017-07-17 16:47:00+03
10867	PG0047	2017-07-31 12:55:00+03	2017-07-31 16:50:00+03	OVB	KLF	Arrived	SU9	2017-07-31 16:31:00+03	2017-07-31 20:23:00+03
10868	PG0047	2017-08-28 12:55:00+03	2017-08-28 16:50:00+03	OVB	KLF	Scheduled	SU9	\N	\N
10869	PG0047	2017-08-21 12:55:00+03	2017-08-21 16:50:00+03	OVB	KLF	Scheduled	SU9	\N	\N
10870	PG0047	2017-08-07 12:55:00+03	2017-08-07 16:50:00+03	OVB	KLF	Arrived	SU9	2017-08-07 13:00:00+03	2017-08-07 16:54:00+03
10871	PG0047	2017-09-11 12:55:00+03	2017-09-11 16:50:00+03	OVB	KLF	Scheduled	SU9	\N	\N
10872	PG0047	2017-08-14 12:55:00+03	2017-08-14 16:50:00+03	OVB	KLF	Arrived	SU9	2017-08-14 12:59:00+03	2017-08-14 16:53:00+03
10873	PG0226	2017-08-14 08:10:00+03	2017-08-14 09:55:00+03	SVX	SVO	Arrived	773	2017-08-14 08:15:00+03	2017-08-14 10:00:00+03
10874	PG0226	2017-08-02 08:10:00+03	2017-08-02 09:55:00+03	SVX	SVO	Arrived	773	2017-08-02 08:12:00+03	2017-08-02 09:57:00+03
10875	PG0226	2017-07-29 08:10:00+03	2017-07-29 09:55:00+03	SVX	SVO	Arrived	773	2017-07-29 08:15:00+03	2017-07-29 09:59:00+03
10876	PG0226	2017-08-25 08:10:00+03	2017-08-25 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10877	PG0226	2017-09-02 08:10:00+03	2017-09-02 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10878	PG0226	2017-08-19 08:10:00+03	2017-08-19 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10879	PG0226	2017-08-28 08:10:00+03	2017-08-28 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10880	PG0226	2017-09-08 08:10:00+03	2017-09-08 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10881	PG0226	2017-07-25 08:10:00+03	2017-07-25 09:55:00+03	SVX	SVO	Arrived	773	2017-07-25 08:13:00+03	2017-07-25 09:58:00+03
10882	PG0226	2017-08-06 08:10:00+03	2017-08-06 09:55:00+03	SVX	SVO	Arrived	773	2017-08-06 08:14:00+03	2017-08-06 10:01:00+03
10883	PG0226	2017-09-10 08:10:00+03	2017-09-10 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10884	PG0226	2017-08-07 08:10:00+03	2017-08-07 09:55:00+03	SVX	SVO	Arrived	773	2017-08-07 12:13:00+03	2017-08-07 13:57:00+03
10885	PG0226	2017-07-26 08:10:00+03	2017-07-26 09:55:00+03	SVX	SVO	Arrived	773	2017-07-26 08:15:00+03	2017-07-26 10:01:00+03
10886	PG0226	2017-08-04 08:10:00+03	2017-08-04 09:55:00+03	SVX	SVO	Arrived	773	2017-08-04 08:13:00+03	2017-08-04 09:59:00+03
10887	PG0226	2017-09-05 08:10:00+03	2017-09-05 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10888	PG0226	2017-08-23 08:10:00+03	2017-08-23 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10889	PG0226	2017-09-09 08:10:00+03	2017-09-09 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10890	PG0226	2017-09-11 08:10:00+03	2017-09-11 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10891	PG0226	2017-09-12 08:10:00+03	2017-09-12 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10892	PG0226	2017-07-21 08:10:00+03	2017-07-21 09:55:00+03	SVX	SVO	Arrived	773	2017-07-21 08:14:00+03	2017-07-21 10:00:00+03
10893	PG0226	2017-09-07 08:10:00+03	2017-09-07 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10894	PG0226	2017-08-27 08:10:00+03	2017-08-27 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10895	PG0226	2017-07-16 08:10:00+03	2017-07-16 09:55:00+03	SVX	SVO	Arrived	773	2017-07-16 08:13:00+03	2017-07-16 09:58:00+03
10896	PG0226	2017-08-10 08:10:00+03	2017-08-10 09:55:00+03	SVX	SVO	Arrived	773	2017-08-10 08:13:00+03	2017-08-10 09:56:00+03
10897	PG0226	2017-09-03 08:10:00+03	2017-09-03 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10898	PG0226	2017-08-22 08:10:00+03	2017-08-22 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10899	PG0226	2017-08-18 08:10:00+03	2017-08-18 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10900	PG0226	2017-09-06 08:10:00+03	2017-09-06 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10901	PG0226	2017-07-20 08:10:00+03	2017-07-20 09:55:00+03	SVX	SVO	Arrived	773	2017-07-20 08:13:00+03	2017-07-20 09:58:00+03
10902	PG0226	2017-08-31 08:10:00+03	2017-08-31 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10903	PG0226	2017-08-03 08:10:00+03	2017-08-03 09:55:00+03	SVX	SVO	Arrived	773	2017-08-03 08:14:00+03	2017-08-03 09:58:00+03
10904	PG0226	2017-08-30 08:10:00+03	2017-08-30 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10905	PG0226	2017-08-12 08:10:00+03	2017-08-12 09:55:00+03	SVX	SVO	Arrived	773	2017-08-12 08:15:00+03	2017-08-12 10:00:00+03
10906	PG0226	2017-08-05 08:10:00+03	2017-08-05 09:55:00+03	SVX	SVO	Arrived	773	2017-08-05 08:12:00+03	2017-08-05 09:56:00+03
10907	PG0226	2017-08-26 08:10:00+03	2017-08-26 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10908	PG0226	2017-08-21 08:10:00+03	2017-08-21 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10909	PG0226	2017-09-13 08:10:00+03	2017-09-13 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10910	PG0226	2017-07-18 08:10:00+03	2017-07-18 09:55:00+03	SVX	SVO	Arrived	773	2017-07-18 08:10:00+03	2017-07-18 09:54:00+03
10911	PG0226	2017-07-23 08:10:00+03	2017-07-23 09:55:00+03	SVX	SVO	Arrived	773	2017-07-23 08:11:00+03	2017-07-23 09:57:00+03
10912	PG0226	2017-08-13 08:10:00+03	2017-08-13 09:55:00+03	SVX	SVO	Arrived	773	2017-08-13 08:14:00+03	2017-08-13 09:58:00+03
10913	PG0226	2017-08-24 08:10:00+03	2017-08-24 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10914	PG0226	2017-08-08 08:10:00+03	2017-08-08 09:55:00+03	SVX	SVO	Arrived	773	2017-08-08 08:12:00+03	2017-08-08 09:58:00+03
10915	PG0226	2017-08-09 08:10:00+03	2017-08-09 09:55:00+03	SVX	SVO	Arrived	773	2017-08-09 08:13:00+03	2017-08-09 09:57:00+03
10916	PG0226	2017-07-31 08:10:00+03	2017-07-31 09:55:00+03	SVX	SVO	Arrived	773	2017-07-31 08:12:00+03	2017-07-31 09:59:00+03
10917	PG0226	2017-09-01 08:10:00+03	2017-09-01 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10918	PG0226	2017-08-29 08:10:00+03	2017-08-29 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10919	PG0226	2017-09-04 08:10:00+03	2017-09-04 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10920	PG0226	2017-07-19 08:10:00+03	2017-07-19 09:55:00+03	SVX	SVO	Arrived	773	2017-07-19 08:16:00+03	2017-07-19 10:01:00+03
10921	PG0226	2017-09-14 08:10:00+03	2017-09-14 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10922	PG0226	2017-08-15 08:10:00+03	2017-08-15 09:55:00+03	SVX	SVO	Arrived	773	2017-08-15 08:15:00+03	2017-08-15 10:01:00+03
10923	PG0226	2017-08-20 08:10:00+03	2017-08-20 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10924	PG0226	2017-07-28 08:10:00+03	2017-07-28 09:55:00+03	SVX	SVO	Arrived	773	2017-07-28 08:13:00+03	2017-07-28 09:59:00+03
10925	PG0226	2017-08-17 08:10:00+03	2017-08-17 09:55:00+03	SVX	SVO	Scheduled	773	\N	\N
10926	PG0226	2017-07-22 08:10:00+03	2017-07-22 09:55:00+03	SVX	SVO	Arrived	773	2017-07-22 08:12:00+03	2017-07-22 09:54:00+03
10927	PG0226	2017-08-16 08:10:00+03	2017-08-16 09:55:00+03	SVX	SVO	On Time	773	\N	\N
10928	PG0226	2017-07-17 08:10:00+03	2017-07-17 09:55:00+03	SVX	SVO	Arrived	773	2017-07-17 08:13:00+03	2017-07-17 09:59:00+03
10929	PG0226	2017-07-30 08:10:00+03	2017-07-30 09:55:00+03	SVX	SVO	Arrived	773	2017-07-30 08:12:00+03	2017-07-30 09:56:00+03
10930	PG0226	2017-07-24 08:10:00+03	2017-07-24 09:55:00+03	SVX	SVO	Arrived	773	2017-07-24 08:12:00+03	2017-07-24 09:57:00+03
10931	PG0226	2017-08-01 08:10:00+03	2017-08-01 09:55:00+03	SVX	SVO	Arrived	773	2017-08-01 08:15:00+03	2017-08-01 10:02:00+03
10932	PG0226	2017-08-11 08:10:00+03	2017-08-11 09:55:00+03	SVX	SVO	Arrived	773	2017-08-11 08:14:00+03	2017-08-11 09:59:00+03
10933	PG0226	2017-07-27 08:10:00+03	2017-07-27 09:55:00+03	SVX	SVO	Arrived	773	2017-07-27 08:12:00+03	2017-07-27 09:57:00+03
10934	PG0588	2017-08-01 08:50:00+03	2017-08-01 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-01 08:54:00+03	2017-08-01 09:20:00+03
10935	PG0588	2017-07-18 08:50:00+03	2017-07-18 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-18 08:53:00+03	2017-07-18 09:18:00+03
10936	PG0587	2017-07-18 15:40:00+03	2017-07-18 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-18 15:44:00+03	2017-07-18 16:08:00+03
10937	PG0587	2017-09-07 15:40:00+03	2017-09-07 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10938	PG0588	2017-09-07 08:50:00+03	2017-09-07 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10939	PG0587	2017-09-13 15:40:00+03	2017-09-13 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10940	PG0588	2017-09-13 08:50:00+03	2017-09-13 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10941	PG0587	2017-08-08 15:40:00+03	2017-08-08 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-08 15:43:00+03	2017-08-08 16:08:00+03
10942	PG0588	2017-08-08 08:50:00+03	2017-08-08 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-08 08:55:00+03	2017-08-08 09:20:00+03
10943	PG0588	2017-09-02 08:50:00+03	2017-09-02 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10944	PG0587	2017-09-02 15:40:00+03	2017-09-02 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10945	PG0587	2017-08-18 15:40:00+03	2017-08-18 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10946	PG0588	2017-08-07 08:50:00+03	2017-08-07 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-07 08:51:00+03	2017-08-07 09:16:00+03
10947	PG0587	2017-08-07 15:40:00+03	2017-08-07 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-07 15:48:00+03	2017-08-07 16:12:00+03
10948	PG0588	2017-08-18 08:50:00+03	2017-08-18 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10949	PG0588	2017-08-03 08:50:00+03	2017-08-03 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-03 08:54:00+03	2017-08-03 09:19:00+03
10950	PG0587	2017-08-03 15:40:00+03	2017-08-03 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-03 15:43:00+03	2017-08-03 16:08:00+03
10951	PG0588	2017-08-23 08:50:00+03	2017-08-23 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10952	PG0587	2017-08-28 15:40:00+03	2017-08-28 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10953	PG0587	2017-09-10 15:40:00+03	2017-09-10 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10954	PG0588	2017-08-28 08:50:00+03	2017-08-28 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10955	PG0588	2017-09-10 08:50:00+03	2017-09-10 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10956	PG0587	2017-08-04 15:40:00+03	2017-08-04 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-04 15:41:00+03	2017-08-04 16:06:00+03
10957	PG0588	2017-08-04 08:50:00+03	2017-08-04 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-04 08:52:00+03	2017-08-04 09:17:00+03
10958	PG0587	2017-09-08 15:40:00+03	2017-09-08 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10959	PG0588	2017-09-08 08:50:00+03	2017-09-08 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10960	PG0587	2017-08-15 15:40:00+03	2017-08-15 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-15 15:43:00+03	2017-08-15 16:08:00+03
10961	PG0587	2017-08-29 15:40:00+03	2017-08-29 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10962	PG0588	2017-08-15 08:50:00+03	2017-08-15 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-15 08:51:00+03	2017-08-15 09:16:00+03
10963	PG0587	2017-07-28 15:40:00+03	2017-07-28 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-28 15:44:00+03	2017-07-28 16:09:00+03
10964	PG0588	2017-07-28 08:50:00+03	2017-07-28 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-28 08:52:00+03	2017-07-28 09:17:00+03
10965	PG0587	2017-08-23 15:40:00+03	2017-08-23 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10966	PG0587	2017-07-21 15:40:00+03	2017-07-21 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-21 15:43:00+03	2017-07-21 16:08:00+03
10967	PG0588	2017-07-21 08:50:00+03	2017-07-21 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-21 08:52:00+03	2017-07-21 09:17:00+03
10968	PG0588	2017-09-04 08:50:00+03	2017-09-04 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10969	PG0587	2017-09-04 15:40:00+03	2017-09-04 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10970	PG0588	2017-08-22 08:50:00+03	2017-08-22 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10971	PG0588	2017-08-05 08:50:00+03	2017-08-05 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-05 08:53:00+03	2017-08-05 09:18:00+03
10972	PG0587	2017-08-05 15:40:00+03	2017-08-05 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-05 18:50:00+03	2017-08-05 19:15:00+03
10973	PG0587	2017-08-22 15:40:00+03	2017-08-22 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10974	PG0588	2017-07-31 08:50:00+03	2017-07-31 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-31 08:54:00+03	2017-07-31 09:19:00+03
10975	PG0588	2017-07-20 08:50:00+03	2017-07-20 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-20 08:54:00+03	2017-07-20 09:19:00+03
10976	PG0587	2017-07-20 15:40:00+03	2017-07-20 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-20 15:43:00+03	2017-07-20 16:08:00+03
10977	PG0588	2017-07-29 08:50:00+03	2017-07-29 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-29 08:52:00+03	2017-07-29 09:17:00+03
10978	PG0587	2017-07-29 15:40:00+03	2017-07-29 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-29 15:45:00+03	2017-07-29 16:10:00+03
10979	PG0587	2017-08-13 15:40:00+03	2017-08-13 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-13 15:46:00+03	2017-08-13 16:11:00+03
10980	PG0588	2017-07-27 08:50:00+03	2017-07-27 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-27 08:52:00+03	2017-07-27 09:17:00+03
10981	PG0587	2017-07-27 15:40:00+03	2017-07-27 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-27 15:41:00+03	2017-07-27 16:06:00+03
10982	PG0587	2017-08-09 15:40:00+03	2017-08-09 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-09 15:40:00+03	2017-08-09 16:05:00+03
10983	PG0588	2017-08-09 08:50:00+03	2017-08-09 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-09 08:56:00+03	2017-08-09 09:21:00+03
10984	PG0587	2017-08-21 15:40:00+03	2017-08-21 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10985	PG0588	2017-08-21 08:50:00+03	2017-08-21 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10986	PG0588	2017-08-25 08:50:00+03	2017-08-25 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10987	PG0587	2017-08-25 15:40:00+03	2017-08-25 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10988	PG0588	2017-08-14 08:50:00+03	2017-08-14 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-14 08:53:00+03	2017-08-14 09:18:00+03
10989	PG0587	2017-09-06 15:40:00+03	2017-09-06 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10990	PG0587	2017-08-14 15:40:00+03	2017-08-14 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-14 18:24:00+03	2017-08-14 18:49:00+03
10991	PG0588	2017-07-17 08:50:00+03	2017-07-17 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-17 08:55:00+03	2017-07-17 09:20:00+03
10992	PG0587	2017-07-17 15:40:00+03	2017-07-17 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-17 15:44:00+03	2017-07-17 16:09:00+03
10993	PG0587	2017-09-05 15:40:00+03	2017-09-05 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10994	PG0588	2017-09-05 08:50:00+03	2017-09-05 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10995	PG0588	2017-08-02 08:50:00+03	2017-08-02 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-02 08:55:00+03	2017-08-02 09:20:00+03
10996	PG0587	2017-08-02 15:40:00+03	2017-08-02 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-02 15:44:00+03	2017-08-02 16:09:00+03
10997	PG0587	2017-08-17 15:40:00+03	2017-08-17 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10998	PG0587	2017-08-30 15:40:00+03	2017-08-30 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
10999	PG0588	2017-08-30 08:50:00+03	2017-08-30 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11000	PG0588	2017-08-17 08:50:00+03	2017-08-17 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11001	PG0587	2017-07-25 15:40:00+03	2017-07-25 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-25 15:41:00+03	2017-07-25 16:06:00+03
11002	PG0588	2017-07-25 08:50:00+03	2017-07-25 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-25 08:53:00+03	2017-07-25 09:18:00+03
11003	PG0587	2017-08-20 15:40:00+03	2017-08-20 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11004	PG0587	2017-09-14 15:40:00+03	2017-09-14 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11005	PG0588	2017-08-19 08:50:00+03	2017-08-19 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11006	PG0587	2017-08-19 15:40:00+03	2017-08-19 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11007	PG0588	2017-09-14 08:50:00+03	2017-09-14 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11008	PG0588	2017-09-01 08:50:00+03	2017-09-01 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11009	PG0587	2017-09-01 15:40:00+03	2017-09-01 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11010	PG0588	2017-08-29 08:50:00+03	2017-08-29 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11011	PG0587	2017-09-03 15:40:00+03	2017-09-03 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11012	PG0588	2017-08-20 08:50:00+03	2017-08-20 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11013	PG0587	2017-08-10 15:40:00+03	2017-08-10 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-10 15:44:00+03	2017-08-10 16:09:00+03
11014	PG0588	2017-09-03 08:50:00+03	2017-09-03 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11015	PG0588	2017-08-10 08:50:00+03	2017-08-10 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-10 08:52:00+03	2017-08-10 09:17:00+03
11016	PG0588	2017-08-16 08:50:00+03	2017-08-16 09:15:00+03	SVX	PEE	On Time	SU9	\N	\N
11017	PG0587	2017-08-16 15:40:00+03	2017-08-16 16:05:00+03	SVX	PEE	On Time	SU9	\N	\N
11018	PG0588	2017-08-06 08:50:00+03	2017-08-06 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-06 12:29:00+03	2017-08-06 12:54:00+03
11019	PG0587	2017-08-06 15:40:00+03	2017-08-06 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-06 15:43:00+03	2017-08-06 16:09:00+03
11020	PG0588	2017-07-26 08:50:00+03	2017-07-26 09:15:00+03	SVX	PEE	Cancelled	SU9	2017-07-26 08:53:00+03	2017-07-26 09:18:00+03
11021	PG0588	2017-08-27 08:50:00+03	2017-08-27 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11022	PG0587	2017-08-27 15:40:00+03	2017-08-27 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11023	PG0588	2017-09-06 08:50:00+03	2017-09-06 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11024	PG0587	2017-07-19 15:40:00+03	2017-07-19 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-19 19:08:00+03	2017-07-19 19:33:00+03
11025	PG0588	2017-07-19 08:50:00+03	2017-07-19 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-19 08:53:00+03	2017-07-19 09:19:00+03
11026	PG0588	2017-09-11 08:50:00+03	2017-09-11 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11027	PG0587	2017-09-11 15:40:00+03	2017-09-11 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11028	PG0587	2017-07-30 15:40:00+03	2017-07-30 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-30 15:42:00+03	2017-07-30 16:07:00+03
11029	PG0588	2017-07-30 08:50:00+03	2017-07-30 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-30 08:55:00+03	2017-07-30 09:20:00+03
11030	PG0587	2017-09-12 15:40:00+03	2017-09-12 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11031	PG0588	2017-09-12 08:50:00+03	2017-09-12 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11032	PG0588	2017-08-13 08:50:00+03	2017-08-13 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-13 08:54:00+03	2017-08-13 09:19:00+03
11033	PG0587	2017-08-26 15:40:00+03	2017-08-26 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11034	PG0588	2017-08-26 08:50:00+03	2017-08-26 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11035	PG0587	2017-08-24 15:40:00+03	2017-08-24 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11036	PG0588	2017-08-24 08:50:00+03	2017-08-24 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11037	PG0587	2017-08-11 15:40:00+03	2017-08-11 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-11 15:41:00+03	2017-08-11 16:06:00+03
11038	PG0588	2017-08-11 08:50:00+03	2017-08-11 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-11 08:53:00+03	2017-08-11 09:18:00+03
11039	PG0588	2017-07-24 08:50:00+03	2017-07-24 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-24 08:52:00+03	2017-07-24 09:18:00+03
11040	PG0587	2017-07-24 15:40:00+03	2017-07-24 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-24 15:42:00+03	2017-07-24 16:08:00+03
11041	PG0587	2017-07-31 15:40:00+03	2017-07-31 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-31 15:43:00+03	2017-07-31 16:09:00+03
11042	PG0588	2017-07-16 08:50:00+03	2017-07-16 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-16 08:51:00+03	2017-07-16 09:17:00+03
11043	PG0588	2017-09-09 08:50:00+03	2017-09-09 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11044	PG0587	2017-07-16 15:40:00+03	2017-07-16 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-16 15:44:00+03	2017-07-16 16:09:00+03
11045	PG0587	2017-09-09 15:40:00+03	2017-09-09 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11046	PG0587	2017-08-01 15:40:00+03	2017-08-01 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-01 15:45:00+03	2017-08-01 16:10:00+03
11047	PG0588	2017-07-23 08:50:00+03	2017-07-23 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-23 08:53:00+03	2017-07-23 09:18:00+03
11048	PG0588	2017-08-12 08:50:00+03	2017-08-12 09:15:00+03	SVX	PEE	Arrived	SU9	2017-08-12 08:51:00+03	2017-08-12 09:16:00+03
11049	PG0587	2017-07-23 15:40:00+03	2017-07-23 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-23 15:43:00+03	2017-07-23 16:08:00+03
11050	PG0587	2017-07-26 15:40:00+03	2017-07-26 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-26 15:40:00+03	2017-07-26 16:05:00+03
11051	PG0587	2017-08-12 15:40:00+03	2017-08-12 16:05:00+03	SVX	PEE	Arrived	SU9	2017-08-12 15:44:00+03	2017-08-12 16:09:00+03
11052	PG0587	2017-08-31 15:40:00+03	2017-08-31 16:05:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11053	PG0588	2017-08-31 08:50:00+03	2017-08-31 09:15:00+03	SVX	PEE	Scheduled	SU9	\N	\N
11054	PG0587	2017-07-22 15:40:00+03	2017-07-22 16:05:00+03	SVX	PEE	Arrived	SU9	2017-07-22 18:23:00+03	2017-07-22 18:48:00+03
11055	PG0588	2017-07-22 08:50:00+03	2017-07-22 09:15:00+03	SVX	PEE	Arrived	SU9	2017-07-22 08:56:00+03	2017-07-22 09:21:00+03
11056	PG0140	2017-07-22 07:10:00+03	2017-07-22 13:25:00+03	SVX	KXK	Arrived	763	2017-07-22 07:11:00+03	2017-07-22 13:29:00+03
11057	PG0140	2017-09-06 07:10:00+03	2017-09-06 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11058	PG0140	2017-08-23 07:10:00+03	2017-08-23 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11059	PG0140	2017-08-19 07:10:00+03	2017-08-19 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11060	PG0140	2017-08-12 07:10:00+03	2017-08-12 13:25:00+03	SVX	KXK	Arrived	763	2017-08-12 07:11:00+03	2017-08-12 13:18:00+03
11061	PG0140	2017-07-19 07:10:00+03	2017-07-19 13:25:00+03	SVX	KXK	Arrived	763	2017-07-19 07:12:00+03	2017-07-19 13:32:00+03
11062	PG0140	2017-07-26 07:10:00+03	2017-07-26 13:25:00+03	SVX	KXK	Arrived	763	2017-07-26 07:13:00+03	2017-07-26 13:25:00+03
11063	PG0140	2017-07-29 07:10:00+03	2017-07-29 13:25:00+03	SVX	KXK	Arrived	763	2017-07-29 07:12:00+03	2017-07-29 13:28:00+03
11064	PG0140	2017-08-26 07:10:00+03	2017-08-26 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11065	PG0140	2017-08-09 07:10:00+03	2017-08-09 13:25:00+03	SVX	KXK	Arrived	763	2017-08-09 07:15:00+03	2017-08-09 13:34:00+03
11066	PG0140	2017-09-02 07:10:00+03	2017-09-02 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11067	PG0140	2017-09-09 07:10:00+03	2017-09-09 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11068	PG0140	2017-08-30 07:10:00+03	2017-08-30 13:25:00+03	SVX	KXK	Scheduled	763	\N	\N
11069	PG0140	2017-08-05 07:10:00+03	2017-08-05 13:25:00+03	SVX	KXK	Arrived	763	2017-08-05 07:13:00+03	2017-08-05 13:30:00+03
11070	PG0140	2017-08-16 07:10:00+03	2017-08-16 13:25:00+03	SVX	KXK	On Time	763	\N	\N
11071	PG0140	2017-09-13 07:10:00+03	2017-09-13 13:25:00+03	SVX	KXK	Cancelled	763	\N	\N
11072	PG0140	2017-08-02 07:10:00+03	2017-08-02 13:25:00+03	SVX	KXK	Arrived	763	2017-08-02 07:12:00+03	2017-08-02 13:30:00+03
11073	PG0569	2017-08-07 15:05:00+03	2017-08-07 16:10:00+03	SVX	SCW	Arrived	733	2017-08-07 15:06:00+03	2017-08-07 16:12:00+03
11074	PG0569	2017-08-04 15:05:00+03	2017-08-04 16:10:00+03	SVX	SCW	Arrived	733	2017-08-04 15:09:00+03	2017-08-04 16:13:00+03
11075	PG0569	2017-08-21 15:05:00+03	2017-08-21 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11076	PG0569	2017-09-05 15:05:00+03	2017-09-05 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11077	PG0569	2017-07-28 15:05:00+03	2017-07-28 16:10:00+03	SVX	SCW	Arrived	733	2017-07-28 15:06:00+03	2017-07-28 16:11:00+03
11078	PG0569	2017-09-07 15:05:00+03	2017-09-07 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11079	PG0569	2017-07-18 15:05:00+03	2017-07-18 16:10:00+03	SVX	SCW	Arrived	733	2017-07-18 15:08:00+03	2017-07-18 16:12:00+03
11080	PG0569	2017-09-06 15:05:00+03	2017-09-06 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11081	PG0569	2017-07-17 15:05:00+03	2017-07-17 16:10:00+03	SVX	SCW	Arrived	733	2017-07-17 15:07:00+03	2017-07-17 16:12:00+03
11082	PG0569	2017-09-01 15:05:00+03	2017-09-01 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11083	PG0569	2017-07-21 15:05:00+03	2017-07-21 16:10:00+03	SVX	SCW	Arrived	733	2017-07-21 15:08:00+03	2017-07-21 16:13:00+03
11084	PG0569	2017-08-11 15:05:00+03	2017-08-11 16:10:00+03	SVX	SCW	Arrived	733	2017-08-11 15:08:00+03	2017-08-11 16:12:00+03
11086	PG0569	2017-08-23 15:05:00+03	2017-08-23 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11087	PG0569	2017-09-10 15:05:00+03	2017-09-10 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11088	PG0569	2017-09-03 15:05:00+03	2017-09-03 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11089	PG0569	2017-08-14 15:05:00+03	2017-08-14 16:10:00+03	SVX	SCW	Arrived	733	2017-08-14 15:07:00+03	2017-08-14 16:12:00+03
11090	PG0569	2017-08-02 15:05:00+03	2017-08-02 16:10:00+03	SVX	SCW	Arrived	733	2017-08-02 15:08:00+03	2017-08-02 16:12:00+03
11091	PG0569	2017-07-25 15:05:00+03	2017-07-25 16:10:00+03	SVX	SCW	Arrived	733	2017-07-25 15:09:00+03	2017-07-25 16:15:00+03
11092	PG0569	2017-09-14 15:05:00+03	2017-09-14 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11093	PG0569	2017-08-05 15:05:00+03	2017-08-05 16:10:00+03	SVX	SCW	Arrived	733	2017-08-05 15:09:00+03	2017-08-05 16:15:00+03
11094	PG0569	2017-08-20 15:05:00+03	2017-08-20 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11095	PG0569	2017-07-24 15:05:00+03	2017-07-24 16:10:00+03	SVX	SCW	Arrived	733	2017-07-24 15:09:00+03	2017-07-24 16:14:00+03
11096	PG0569	2017-07-23 15:05:00+03	2017-07-23 16:10:00+03	SVX	SCW	Arrived	733	2017-07-23 15:08:00+03	2017-07-23 16:12:00+03
11097	PG0569	2017-09-13 15:05:00+03	2017-09-13 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11098	PG0569	2017-07-29 15:05:00+03	2017-07-29 16:10:00+03	SVX	SCW	Arrived	733	2017-07-29 15:07:00+03	2017-07-29 16:13:00+03
11099	PG0569	2017-08-28 15:05:00+03	2017-08-28 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11100	PG0569	2017-08-27 15:05:00+03	2017-08-27 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11101	PG0569	2017-08-25 15:05:00+03	2017-08-25 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11102	PG0569	2017-08-08 15:05:00+03	2017-08-08 16:10:00+03	SVX	SCW	Arrived	733	2017-08-08 15:05:00+03	2017-08-08 16:08:00+03
11103	PG0569	2017-07-30 15:05:00+03	2017-07-30 16:10:00+03	SVX	SCW	Arrived	733	2017-07-30 15:05:00+03	2017-07-30 16:10:00+03
11104	PG0569	2017-07-26 15:05:00+03	2017-07-26 16:10:00+03	SVX	SCW	Arrived	733	2017-07-26 15:09:00+03	2017-07-26 16:14:00+03
11105	PG0569	2017-08-12 15:05:00+03	2017-08-12 16:10:00+03	SVX	SCW	Arrived	733	2017-08-12 15:08:00+03	2017-08-12 16:13:00+03
11106	PG0569	2017-08-06 15:05:00+03	2017-08-06 16:10:00+03	SVX	SCW	Arrived	733	2017-08-06 15:07:00+03	2017-08-06 16:11:00+03
11107	PG0569	2017-09-09 15:05:00+03	2017-09-09 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11108	PG0569	2017-07-22 15:05:00+03	2017-07-22 16:10:00+03	SVX	SCW	Arrived	733	2017-07-22 15:09:00+03	2017-07-22 16:14:00+03
11109	PG0569	2017-08-19 15:05:00+03	2017-08-19 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11110	PG0569	2017-08-13 15:05:00+03	2017-08-13 16:10:00+03	SVX	SCW	Arrived	733	2017-08-13 18:21:00+03	2017-08-13 19:26:00+03
11111	PG0569	2017-07-27 15:05:00+03	2017-07-27 16:10:00+03	SVX	SCW	Arrived	733	2017-07-27 15:08:00+03	2017-07-27 16:13:00+03
11112	PG0569	2017-07-16 15:05:00+03	2017-07-16 16:10:00+03	SVX	SCW	Arrived	733	2017-07-16 17:57:00+03	2017-07-16 19:01:00+03
11113	PG0569	2017-09-11 15:05:00+03	2017-09-11 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11114	PG0569	2017-09-02 15:05:00+03	2017-09-02 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11115	PG0569	2017-07-19 15:05:00+03	2017-07-19 16:10:00+03	SVX	SCW	Arrived	733	2017-07-19 15:07:00+03	2017-07-19 16:13:00+03
11116	PG0569	2017-09-12 15:05:00+03	2017-09-12 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11117	PG0569	2017-07-20 15:05:00+03	2017-07-20 16:10:00+03	SVX	SCW	Arrived	733	2017-07-20 15:07:00+03	2017-07-20 16:12:00+03
11118	PG0569	2017-08-22 15:05:00+03	2017-08-22 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11119	PG0569	2017-08-09 15:05:00+03	2017-08-09 16:10:00+03	SVX	SCW	Arrived	733	2017-08-09 15:10:00+03	2017-08-09 16:15:00+03
11120	PG0569	2017-08-29 15:05:00+03	2017-08-29 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11121	PG0569	2017-07-31 15:05:00+03	2017-07-31 16:10:00+03	SVX	SCW	Arrived	733	2017-07-31 15:06:00+03	2017-07-31 16:11:00+03
11122	PG0569	2017-08-10 15:05:00+03	2017-08-10 16:10:00+03	SVX	SCW	Arrived	733	2017-08-10 15:05:00+03	2017-08-10 16:10:00+03
11123	PG0569	2017-08-30 15:05:00+03	2017-08-30 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11124	PG0569	2017-08-16 15:05:00+03	2017-08-16 16:10:00+03	SVX	SCW	On Time	733	\N	\N
11125	PG0569	2017-08-01 15:05:00+03	2017-08-01 16:10:00+03	SVX	SCW	Arrived	733	2017-08-01 15:06:00+03	2017-08-01 16:11:00+03
11126	PG0569	2017-08-31 15:05:00+03	2017-08-31 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11127	PG0569	2017-08-03 15:05:00+03	2017-08-03 16:10:00+03	SVX	SCW	Arrived	733	2017-08-03 15:08:00+03	2017-08-03 16:13:00+03
11128	PG0569	2017-08-26 15:05:00+03	2017-08-26 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11129	PG0569	2017-09-08 15:05:00+03	2017-09-08 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11130	PG0569	2017-08-15 15:05:00+03	2017-08-15 16:10:00+03	SVX	SCW	Arrived	733	2017-08-15 15:09:00+03	2017-08-15 16:15:00+03
11131	PG0569	2017-09-04 15:05:00+03	2017-09-04 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11132	PG0569	2017-08-18 15:05:00+03	2017-08-18 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11133	PG0569	2017-08-17 15:05:00+03	2017-08-17 16:10:00+03	SVX	SCW	Scheduled	733	\N	\N
11134	PG0434	2017-07-23 07:15:00+03	2017-07-23 10:25:00+03	SVX	KYZ	Arrived	CR2	2017-07-23 07:19:00+03	2017-07-23 10:30:00+03
11135	PG0434	2017-07-30 07:15:00+03	2017-07-30 10:25:00+03	SVX	KYZ	Arrived	CR2	2017-07-30 07:16:00+03	2017-07-30 10:25:00+03
11136	PG0434	2017-08-20 07:15:00+03	2017-08-20 10:25:00+03	SVX	KYZ	Scheduled	CR2	\N	\N
11137	PG0434	2017-09-10 07:15:00+03	2017-09-10 10:25:00+03	SVX	KYZ	Cancelled	CR2	\N	\N
11138	PG0434	2017-08-06 07:15:00+03	2017-08-06 10:25:00+03	SVX	KYZ	Arrived	CR2	2017-08-06 07:22:00+03	2017-08-06 10:34:00+03
11139	PG0434	2017-07-16 07:15:00+03	2017-07-16 10:25:00+03	SVX	KYZ	Arrived	CR2	2017-07-16 07:19:00+03	2017-07-16 10:28:00+03
11140	PG0434	2017-08-13 07:15:00+03	2017-08-13 10:25:00+03	SVX	KYZ	Arrived	CR2	2017-08-13 07:17:00+03	2017-08-13 10:26:00+03
11141	PG0434	2017-09-03 07:15:00+03	2017-09-03 10:25:00+03	SVX	KYZ	Scheduled	CR2	\N	\N
11142	PG0434	2017-08-27 07:15:00+03	2017-08-27 10:25:00+03	SVX	KYZ	Scheduled	CR2	\N	\N
11143	PG0343	2017-08-05 07:20:00+03	2017-08-05 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-08-05 07:22:00+03	2017-08-05 11:23:00+03
11144	PG0343	2017-08-30 07:20:00+03	2017-08-30 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11145	PG0343	2017-07-22 07:20:00+03	2017-07-22 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-07-22 07:23:00+03	2017-07-22 11:23:00+03
11146	PG0343	2017-08-19 07:20:00+03	2017-08-19 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11147	PG0343	2017-09-06 07:20:00+03	2017-09-06 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11148	PG0343	2017-08-12 07:20:00+03	2017-08-12 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-08-12 07:21:00+03	2017-08-12 11:22:00+03
11149	PG0343	2017-07-26 07:20:00+03	2017-07-26 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-07-26 07:25:00+03	2017-07-26 11:28:00+03
11150	PG0343	2017-09-09 07:20:00+03	2017-09-09 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11151	PG0343	2017-09-13 07:20:00+03	2017-09-13 11:20:00+03	SVX	MJZ	Cancelled	SU9	\N	\N
11152	PG0343	2017-08-16 07:20:00+03	2017-08-16 11:20:00+03	SVX	MJZ	On Time	SU9	\N	\N
11153	PG0343	2017-08-23 07:20:00+03	2017-08-23 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11154	PG0343	2017-08-09 07:20:00+03	2017-08-09 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-08-09 07:20:00+03	2017-08-09 11:22:00+03
11155	PG0343	2017-07-29 07:20:00+03	2017-07-29 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-07-29 07:22:00+03	2017-07-29 11:23:00+03
11156	PG0343	2017-08-02 07:20:00+03	2017-08-02 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-08-02 07:25:00+03	2017-08-02 11:25:00+03
11157	PG0343	2017-08-26 07:20:00+03	2017-08-26 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11158	PG0343	2017-09-02 07:20:00+03	2017-09-02 11:20:00+03	SVX	MJZ	Scheduled	SU9	\N	\N
11159	PG0343	2017-07-19 07:20:00+03	2017-07-19 11:20:00+03	SVX	MJZ	Arrived	SU9	2017-07-19 07:22:00+03	2017-07-19 11:25:00+03
11160	PG0597	2017-09-14 11:50:00+03	2017-09-14 15:20:00+03	SVX	UIK	Cancelled	CR2	\N	\N
11161	PG0597	2017-08-28 11:50:00+03	2017-08-28 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11162	PG0597	2017-07-31 11:50:00+03	2017-07-31 15:20:00+03	SVX	UIK	Arrived	CR2	2017-07-31 11:59:00+03	2017-07-31 15:27:00+03
11163	PG0597	2017-07-20 11:50:00+03	2017-07-20 15:20:00+03	SVX	UIK	Arrived	CR2	2017-07-20 11:54:00+03	2017-07-20 15:27:00+03
11164	PG0597	2017-08-17 11:50:00+03	2017-08-17 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11165	PG0597	2017-07-17 11:50:00+03	2017-07-17 15:20:00+03	SVX	UIK	Arrived	CR2	2017-07-17 11:51:00+03	2017-07-17 15:24:00+03
11166	PG0597	2017-07-27 11:50:00+03	2017-07-27 15:20:00+03	SVX	UIK	Arrived	CR2	2017-07-27 11:54:00+03	2017-07-27 15:21:00+03
11167	PG0597	2017-08-03 11:50:00+03	2017-08-03 15:20:00+03	SVX	UIK	Arrived	CR2	2017-08-03 11:54:00+03	2017-08-03 15:22:00+03
11168	PG0597	2017-08-14 11:50:00+03	2017-08-14 15:20:00+03	SVX	UIK	Arrived	CR2	2017-08-14 11:52:00+03	2017-08-14 15:26:00+03
11169	PG0597	2017-08-21 11:50:00+03	2017-08-21 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11170	PG0597	2017-09-04 11:50:00+03	2017-09-04 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11171	PG0597	2017-07-24 11:50:00+03	2017-07-24 15:20:00+03	SVX	UIK	Arrived	CR2	2017-07-24 11:55:00+03	2017-07-24 15:24:00+03
11172	PG0597	2017-09-11 11:50:00+03	2017-09-11 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11173	PG0597	2017-08-24 11:50:00+03	2017-08-24 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11174	PG0597	2017-08-10 11:50:00+03	2017-08-10 15:20:00+03	SVX	UIK	Arrived	CR2	2017-08-10 11:51:00+03	2017-08-10 15:20:00+03
11175	PG0597	2017-08-31 11:50:00+03	2017-08-31 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11176	PG0597	2017-08-07 11:50:00+03	2017-08-07 15:20:00+03	SVX	UIK	Arrived	CR2	2017-08-07 11:54:00+03	2017-08-07 15:25:00+03
11177	PG0597	2017-09-07 11:50:00+03	2017-09-07 15:20:00+03	SVX	UIK	Scheduled	CR2	\N	\N
11178	PG0378	2017-08-25 11:40:00+03	2017-08-25 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11179	PG0378	2017-07-24 11:40:00+03	2017-07-24 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-24 11:42:00+03	2017-07-24 14:15:00+03
11180	PG0378	2017-08-02 11:40:00+03	2017-08-02 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-02 11:46:00+03	2017-08-02 14:21:00+03
11181	PG0378	2017-08-20 11:40:00+03	2017-08-20 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11182	PG0378	2017-07-29 11:40:00+03	2017-07-29 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-29 11:42:00+03	2017-07-29 14:19:00+03
11183	PG0378	2017-08-16 11:40:00+03	2017-08-16 14:15:00+03	SVX	NSK	On Time	SU9	\N	\N
11184	PG0378	2017-09-10 11:40:00+03	2017-09-10 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11185	PG0378	2017-09-14 11:40:00+03	2017-09-14 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11186	PG0378	2017-07-19 11:40:00+03	2017-07-19 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-19 11:41:00+03	2017-07-19 14:16:00+03
11187	PG0378	2017-09-04 11:40:00+03	2017-09-04 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11188	PG0378	2017-08-05 11:40:00+03	2017-08-05 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-05 11:42:00+03	2017-08-05 14:19:00+03
11189	PG0378	2017-07-20 11:40:00+03	2017-07-20 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-20 11:43:00+03	2017-07-20 14:16:00+03
11190	PG0378	2017-08-12 11:40:00+03	2017-08-12 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-12 11:42:00+03	2017-08-12 14:16:00+03
11191	PG0378	2017-07-30 11:40:00+03	2017-07-30 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-30 11:46:00+03	2017-07-30 14:20:00+03
11192	PG0378	2017-07-22 11:40:00+03	2017-07-22 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-22 11:44:00+03	2017-07-22 14:20:00+03
11193	PG0378	2017-08-27 11:40:00+03	2017-08-27 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11194	PG0378	2017-08-31 11:40:00+03	2017-08-31 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11195	PG0378	2017-08-22 11:40:00+03	2017-08-22 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11196	PG0378	2017-09-01 11:40:00+03	2017-09-01 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11197	PG0378	2017-09-11 11:40:00+03	2017-09-11 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11198	PG0378	2017-08-11 11:40:00+03	2017-08-11 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-11 11:40:00+03	2017-08-11 14:16:00+03
11199	PG0378	2017-08-06 11:40:00+03	2017-08-06 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-06 11:44:00+03	2017-08-06 14:20:00+03
11200	PG0378	2017-08-28 11:40:00+03	2017-08-28 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11201	PG0378	2017-08-09 11:40:00+03	2017-08-09 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-09 11:45:00+03	2017-08-09 14:18:00+03
11202	PG0378	2017-09-03 11:40:00+03	2017-09-03 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11203	PG0378	2017-09-02 11:40:00+03	2017-09-02 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11204	PG0378	2017-09-08 11:40:00+03	2017-09-08 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11205	PG0378	2017-08-07 11:40:00+03	2017-08-07 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-07 11:43:00+03	2017-08-07 14:19:00+03
11206	PG0378	2017-08-01 11:40:00+03	2017-08-01 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-01 11:45:00+03	2017-08-01 14:18:00+03
11207	PG0378	2017-07-16 11:40:00+03	2017-07-16 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-16 11:43:00+03	2017-07-16 14:20:00+03
11208	PG0378	2017-08-08 11:40:00+03	2017-08-08 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-08 11:43:00+03	2017-08-08 14:16:00+03
11209	PG0378	2017-09-05 11:40:00+03	2017-09-05 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11210	PG0378	2017-08-03 11:40:00+03	2017-08-03 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-03 11:42:00+03	2017-08-03 14:17:00+03
11211	PG0378	2017-08-17 11:40:00+03	2017-08-17 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11212	PG0378	2017-07-25 11:40:00+03	2017-07-25 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-25 11:44:00+03	2017-07-25 14:17:00+03
11213	PG0378	2017-08-30 11:40:00+03	2017-08-30 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11214	PG0378	2017-07-18 11:40:00+03	2017-07-18 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-18 11:46:00+03	2017-07-18 14:20:00+03
11215	PG0378	2017-08-04 11:40:00+03	2017-08-04 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-04 11:46:00+03	2017-08-04 14:22:00+03
11216	PG0378	2017-09-13 11:40:00+03	2017-09-13 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11217	PG0378	2017-07-28 11:40:00+03	2017-07-28 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-28 11:43:00+03	2017-07-28 14:17:00+03
11218	PG0378	2017-08-15 11:40:00+03	2017-08-15 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-15 11:41:00+03	2017-08-15 14:16:00+03
11219	PG0378	2017-08-26 11:40:00+03	2017-08-26 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11220	PG0378	2017-08-13 11:40:00+03	2017-08-13 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-13 11:41:00+03	2017-08-13 14:17:00+03
11221	PG0378	2017-07-21 11:40:00+03	2017-07-21 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-21 11:42:00+03	2017-07-21 14:14:00+03
11222	PG0378	2017-08-29 11:40:00+03	2017-08-29 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11223	PG0378	2017-07-26 11:40:00+03	2017-07-26 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-26 11:42:00+03	2017-07-26 14:16:00+03
11224	PG0378	2017-07-23 11:40:00+03	2017-07-23 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-23 11:45:00+03	2017-07-23 14:22:00+03
11225	PG0378	2017-09-09 11:40:00+03	2017-09-09 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11226	PG0378	2017-09-12 11:40:00+03	2017-09-12 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11227	PG0378	2017-08-21 11:40:00+03	2017-08-21 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11228	PG0378	2017-08-19 11:40:00+03	2017-08-19 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11229	PG0378	2017-08-10 11:40:00+03	2017-08-10 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-10 11:47:00+03	2017-08-10 14:25:00+03
11230	PG0378	2017-08-23 11:40:00+03	2017-08-23 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11231	PG0378	2017-08-24 11:40:00+03	2017-08-24 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11232	PG0378	2017-07-17 11:40:00+03	2017-07-17 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-17 11:43:00+03	2017-07-17 14:17:00+03
11233	PG0378	2017-07-27 11:40:00+03	2017-07-27 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-27 11:40:00+03	2017-07-27 14:11:00+03
11234	PG0378	2017-07-31 11:40:00+03	2017-07-31 14:15:00+03	SVX	NSK	Arrived	SU9	2017-07-31 11:42:00+03	2017-07-31 14:16:00+03
11235	PG0378	2017-08-14 11:40:00+03	2017-08-14 14:15:00+03	SVX	NSK	Arrived	SU9	2017-08-14 11:44:00+03	2017-08-14 14:19:00+03
11236	PG0378	2017-09-06 11:40:00+03	2017-09-06 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11237	PG0378	2017-08-18 11:40:00+03	2017-08-18 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11238	PG0378	2017-09-07 11:40:00+03	2017-09-07 14:15:00+03	SVX	NSK	Scheduled	SU9	\N	\N
11239	PG0102	2017-08-26 14:40:00+03	2017-08-26 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11240	PG0102	2017-09-05 14:40:00+03	2017-09-05 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11241	PG0102	2017-07-27 14:40:00+03	2017-07-27 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-27 14:43:00+03	2017-07-27 17:53:00+03
11242	PG0103	2017-08-09 13:25:00+03	2017-08-09 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-09 16:47:00+03	2017-08-09 19:55:00+03
11243	PG0102	2017-08-14 14:40:00+03	2017-08-14 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-14 14:44:00+03	2017-08-14 17:53:00+03
11244	PG0102	2017-09-04 14:40:00+03	2017-09-04 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11245	PG0103	2017-09-14 13:25:00+03	2017-09-14 16:35:00+03	SVX	KGP	Cancelled	CN1	\N	\N
11246	PG0102	2017-08-09 14:40:00+03	2017-08-09 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-09 14:43:00+03	2017-08-09 17:51:00+03
11247	PG0103	2017-07-20 13:25:00+03	2017-07-20 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-20 13:31:00+03	2017-07-20 16:45:00+03
11248	PG0102	2017-07-17 14:40:00+03	2017-07-17 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-17 14:45:00+03	2017-07-17 17:53:00+03
11249	PG0103	2017-07-17 13:25:00+03	2017-07-17 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-17 13:30:00+03	2017-07-17 16:41:00+03
11250	PG0102	2017-07-25 14:40:00+03	2017-07-25 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-25 14:43:00+03	2017-07-25 17:53:00+03
11251	PG0103	2017-08-25 13:25:00+03	2017-08-25 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11252	PG0102	2017-08-25 14:40:00+03	2017-08-25 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11253	PG0102	2017-08-23 14:40:00+03	2017-08-23 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11254	PG0102	2017-08-04 14:40:00+03	2017-08-04 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-04 14:44:00+03	2017-08-04 17:54:00+03
11255	PG0103	2017-07-18 13:25:00+03	2017-07-18 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-18 17:33:00+03	2017-07-18 20:41:00+03
11256	PG0103	2017-08-22 13:25:00+03	2017-08-22 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11257	PG0103	2017-09-05 13:25:00+03	2017-09-05 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11258	PG0103	2017-07-19 13:25:00+03	2017-07-19 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-19 13:28:00+03	2017-07-19 16:37:00+03
11259	PG0102	2017-07-18 14:40:00+03	2017-07-18 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-18 14:41:00+03	2017-07-18 17:53:00+03
11260	PG0103	2017-09-03 13:25:00+03	2017-09-03 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11261	PG0102	2017-08-07 14:40:00+03	2017-08-07 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-07 14:43:00+03	2017-08-07 17:52:00+03
11262	PG0102	2017-08-31 14:40:00+03	2017-08-31 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11263	PG0103	2017-09-12 13:25:00+03	2017-09-12 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11264	PG0103	2017-08-18 13:25:00+03	2017-08-18 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11265	PG0103	2017-08-31 13:25:00+03	2017-08-31 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11266	PG0103	2017-07-25 13:25:00+03	2017-07-25 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-25 13:29:00+03	2017-07-25 16:37:00+03
11267	PG0102	2017-09-12 14:40:00+03	2017-09-12 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11268	PG0102	2017-08-18 14:40:00+03	2017-08-18 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11269	PG0102	2017-08-28 14:40:00+03	2017-08-28 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11270	PG0102	2017-09-08 14:40:00+03	2017-09-08 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11271	PG0103	2017-08-28 13:25:00+03	2017-08-28 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11272	PG0103	2017-07-30 13:25:00+03	2017-07-30 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-30 13:27:00+03	2017-07-30 16:39:00+03
11273	PG0103	2017-07-24 13:25:00+03	2017-07-24 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-24 13:28:00+03	2017-07-24 16:39:00+03
11274	PG0102	2017-08-30 14:40:00+03	2017-08-30 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11275	PG0102	2017-07-24 14:40:00+03	2017-07-24 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-24 14:42:00+03	2017-07-24 17:55:00+03
11276	PG0102	2017-07-19 14:40:00+03	2017-07-19 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-19 14:42:00+03	2017-07-19 17:51:00+03
11277	PG0102	2017-08-12 14:40:00+03	2017-08-12 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-12 18:22:00+03	2017-08-12 21:36:00+03
11278	PG0103	2017-08-12 13:25:00+03	2017-08-12 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-12 13:31:00+03	2017-08-12 16:42:00+03
11279	PG0102	2017-08-27 14:40:00+03	2017-08-27 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11280	PG0103	2017-08-27 13:25:00+03	2017-08-27 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11281	PG0103	2017-09-04 13:25:00+03	2017-09-04 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11282	PG0103	2017-07-31 13:25:00+03	2017-07-31 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-31 13:30:00+03	2017-07-31 16:42:00+03
11283	PG0102	2017-08-05 14:40:00+03	2017-08-05 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-05 14:42:00+03	2017-08-05 17:53:00+03
11284	PG0103	2017-08-05 13:25:00+03	2017-08-05 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-05 13:32:00+03	2017-08-05 16:43:00+03
11285	PG0102	2017-08-08 14:40:00+03	2017-08-08 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-08 14:42:00+03	2017-08-08 17:57:00+03
11286	PG0102	2017-08-29 14:40:00+03	2017-08-29 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11287	PG0102	2017-08-13 14:40:00+03	2017-08-13 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-13 17:50:00+03	2017-08-13 21:00:00+03
11288	PG0103	2017-09-08 13:25:00+03	2017-09-08 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11289	PG0103	2017-08-13 13:25:00+03	2017-08-13 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-13 13:29:00+03	2017-08-13 16:41:00+03
11290	PG0103	2017-09-01 13:25:00+03	2017-09-01 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11291	PG0102	2017-09-01 14:40:00+03	2017-09-01 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11292	PG0103	2017-09-10 13:25:00+03	2017-09-10 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11293	PG0103	2017-08-03 13:25:00+03	2017-08-03 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-03 13:27:00+03	2017-08-03 16:35:00+03
11294	PG0103	2017-08-08 13:25:00+03	2017-08-08 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-08 13:27:00+03	2017-08-08 16:35:00+03
11295	PG0102	2017-08-03 14:40:00+03	2017-08-03 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-03 14:45:00+03	2017-08-03 17:56:00+03
11296	PG0102	2017-08-22 14:40:00+03	2017-08-22 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11297	PG0102	2017-08-16 14:40:00+03	2017-08-16 17:50:00+03	SVX	KGP	Delayed	CN1	\N	\N
11298	PG0103	2017-08-11 13:25:00+03	2017-08-11 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-11 13:26:00+03	2017-08-11 16:36:00+03
11299	PG0103	2017-08-06 13:25:00+03	2017-08-06 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-06 13:27:00+03	2017-08-06 16:36:00+03
11300	PG0102	2017-08-11 14:40:00+03	2017-08-11 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-11 14:41:00+03	2017-08-11 17:48:00+03
11301	PG0102	2017-09-09 14:40:00+03	2017-09-09 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11302	PG0102	2017-07-31 14:40:00+03	2017-07-31 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-31 14:44:00+03	2017-07-31 17:58:00+03
11303	PG0102	2017-09-03 14:40:00+03	2017-09-03 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11304	PG0102	2017-09-10 14:40:00+03	2017-09-10 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11305	PG0103	2017-08-24 13:25:00+03	2017-08-24 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11306	PG0102	2017-08-21 14:40:00+03	2017-08-21 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11307	PG0103	2017-08-21 13:25:00+03	2017-08-21 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11308	PG0102	2017-08-24 14:40:00+03	2017-08-24 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11309	PG0102	2017-08-10 14:40:00+03	2017-08-10 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-10 14:45:00+03	2017-08-10 17:55:00+03
11310	PG0103	2017-09-09 13:25:00+03	2017-09-09 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11311	PG0103	2017-09-02 13:25:00+03	2017-09-02 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11312	PG0103	2017-07-23 13:25:00+03	2017-07-23 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-23 13:29:00+03	2017-07-23 16:42:00+03
11313	PG0102	2017-08-06 14:40:00+03	2017-08-06 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-06 14:45:00+03	2017-08-06 17:52:00+03
11314	PG0103	2017-08-10 13:25:00+03	2017-08-10 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-10 13:26:00+03	2017-08-10 16:36:00+03
11315	PG0103	2017-09-06 13:25:00+03	2017-09-06 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11316	PG0102	2017-09-06 14:40:00+03	2017-09-06 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11317	PG0102	2017-07-16 14:40:00+03	2017-07-16 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-16 14:42:00+03	2017-07-16 17:51:00+03
11318	PG0103	2017-09-11 13:25:00+03	2017-09-11 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11319	PG0102	2017-07-29 14:40:00+03	2017-07-29 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-29 18:30:00+03	2017-07-29 21:42:00+03
11320	PG0103	2017-07-29 13:25:00+03	2017-07-29 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-29 13:26:00+03	2017-07-29 16:39:00+03
11321	PG0103	2017-08-16 13:25:00+03	2017-08-16 16:35:00+03	SVX	KGP	On Time	CN1	\N	\N
11322	PG0102	2017-09-02 14:40:00+03	2017-09-02 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11323	PG0102	2017-09-11 14:40:00+03	2017-09-11 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11324	PG0102	2017-07-22 14:40:00+03	2017-07-22 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-22 14:44:00+03	2017-07-22 17:57:00+03
11325	PG0102	2017-08-17 14:40:00+03	2017-08-17 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11326	PG0103	2017-07-22 13:25:00+03	2017-07-22 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-22 13:27:00+03	2017-07-22 16:35:00+03
11327	PG0103	2017-08-17 13:25:00+03	2017-08-17 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11328	PG0103	2017-08-04 13:25:00+03	2017-08-04 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-04 13:26:00+03	2017-08-04 16:32:00+03
11329	PG0103	2017-08-29 13:25:00+03	2017-08-29 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11330	PG0102	2017-08-19 14:40:00+03	2017-08-19 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11331	PG0103	2017-08-19 13:25:00+03	2017-08-19 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11332	PG0103	2017-07-16 13:25:00+03	2017-07-16 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-16 13:26:00+03	2017-07-16 16:33:00+03
11333	PG0102	2017-08-15 14:40:00+03	2017-08-15 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-15 14:43:00+03	2017-08-15 17:53:00+03
11334	PG0102	2017-07-26 14:40:00+03	2017-07-26 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-26 14:42:00+03	2017-07-26 17:52:00+03
11335	PG0103	2017-07-26 13:25:00+03	2017-07-26 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-26 13:28:00+03	2017-07-26 16:34:00+03
11336	PG0103	2017-08-20 13:25:00+03	2017-08-20 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11337	PG0103	2017-08-26 13:25:00+03	2017-08-26 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11338	PG0102	2017-07-23 14:40:00+03	2017-07-23 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-23 14:42:00+03	2017-07-23 17:52:00+03
11339	PG0103	2017-09-07 13:25:00+03	2017-09-07 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11340	PG0103	2017-08-15 13:25:00+03	2017-08-15 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-15 13:29:00+03	2017-08-15 16:38:00+03
11341	PG0103	2017-07-21 13:25:00+03	2017-07-21 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-21 13:29:00+03	2017-07-21 16:34:00+03
11342	PG0102	2017-07-21 14:40:00+03	2017-07-21 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-21 14:43:00+03	2017-07-21 17:55:00+03
11343	PG0102	2017-08-20 14:40:00+03	2017-08-20 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11344	PG0102	2017-07-20 14:40:00+03	2017-07-20 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-20 14:42:00+03	2017-07-20 17:53:00+03
11345	PG0103	2017-08-30 13:25:00+03	2017-08-30 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11346	PG0102	2017-07-30 14:40:00+03	2017-07-30 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-30 14:43:00+03	2017-07-30 17:51:00+03
11347	PG0102	2017-09-13 14:40:00+03	2017-09-13 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11348	PG0103	2017-08-07 13:25:00+03	2017-08-07 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-07 13:26:00+03	2017-08-07 16:33:00+03
11349	PG0102	2017-09-14 14:40:00+03	2017-09-14 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11350	PG0102	2017-07-28 14:40:00+03	2017-07-28 17:50:00+03	SVX	KGP	Arrived	CN1	2017-07-28 14:44:00+03	2017-07-28 17:56:00+03
11351	PG0103	2017-07-28 13:25:00+03	2017-07-28 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-28 13:29:00+03	2017-07-28 16:41:00+03
11352	PG0102	2017-08-01 14:40:00+03	2017-08-01 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-01 14:44:00+03	2017-08-01 17:50:00+03
11353	PG0103	2017-08-01 13:25:00+03	2017-08-01 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-01 13:26:00+03	2017-08-01 16:35:00+03
11354	PG0103	2017-08-23 13:25:00+03	2017-08-23 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11355	PG0102	2017-08-02 14:40:00+03	2017-08-02 17:50:00+03	SVX	KGP	Arrived	CN1	2017-08-02 14:43:00+03	2017-08-02 17:55:00+03
11356	PG0102	2017-09-07 14:40:00+03	2017-09-07 17:50:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11357	PG0103	2017-08-02 13:25:00+03	2017-08-02 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-02 13:31:00+03	2017-08-02 16:44:00+03
11358	PG0103	2017-07-27 13:25:00+03	2017-07-27 16:35:00+03	SVX	KGP	Arrived	CN1	2017-07-27 13:28:00+03	2017-07-27 16:41:00+03
11359	PG0103	2017-09-13 13:25:00+03	2017-09-13 16:35:00+03	SVX	KGP	Scheduled	CN1	\N	\N
11360	PG0103	2017-08-14 13:25:00+03	2017-08-14 16:35:00+03	SVX	KGP	Arrived	CN1	2017-08-14 13:26:00+03	2017-08-14 16:36:00+03
11361	PG0599	2017-09-06 15:55:00+03	2017-09-06 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11362	PG0599	2017-08-28 15:55:00+03	2017-08-28 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11363	PG0599	2017-07-22 15:55:00+03	2017-07-22 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-22 15:57:00+03	2017-07-22 16:52:00+03
11364	PG0599	2017-07-23 15:55:00+03	2017-07-23 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-23 15:57:00+03	2017-07-23 16:52:00+03
11365	PG0599	2017-08-01 15:55:00+03	2017-08-01 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-01 16:05:00+03	2017-08-01 16:59:00+03
11366	PG0599	2017-08-26 15:55:00+03	2017-08-26 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11367	PG0599	2017-07-30 15:55:00+03	2017-07-30 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-30 15:57:00+03	2017-07-30 16:51:00+03
11368	PG0599	2017-09-11 15:55:00+03	2017-09-11 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11369	PG0599	2017-08-17 15:55:00+03	2017-08-17 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11370	PG0599	2017-08-02 15:55:00+03	2017-08-02 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-02 15:59:00+03	2017-08-02 16:55:00+03
11371	PG0599	2017-09-05 15:55:00+03	2017-09-05 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11372	PG0599	2017-08-21 15:55:00+03	2017-08-21 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11373	PG0599	2017-08-22 15:55:00+03	2017-08-22 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11374	PG0599	2017-07-21 15:55:00+03	2017-07-21 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-21 15:58:00+03	2017-07-21 16:53:00+03
11375	PG0599	2017-09-10 15:55:00+03	2017-09-10 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11376	PG0599	2017-08-03 15:55:00+03	2017-08-03 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-03 15:56:00+03	2017-08-03 16:52:00+03
11377	PG0599	2017-09-07 15:55:00+03	2017-09-07 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11378	PG0599	2017-08-04 15:55:00+03	2017-08-04 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-04 15:57:00+03	2017-08-04 16:52:00+03
11379	PG0599	2017-09-04 15:55:00+03	2017-09-04 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11380	PG0599	2017-07-29 15:55:00+03	2017-07-29 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-29 15:59:00+03	2017-07-29 16:56:00+03
11381	PG0599	2017-07-20 15:55:00+03	2017-07-20 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-20 15:57:00+03	2017-07-20 16:52:00+03
11382	PG0599	2017-08-16 15:55:00+03	2017-08-16 16:50:00+03	SVX	HMA	On Time	SU9	\N	\N
11383	PG0599	2017-09-12 15:55:00+03	2017-09-12 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11384	PG0599	2017-08-05 15:55:00+03	2017-08-05 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-05 15:57:00+03	2017-08-05 16:52:00+03
11385	PG0599	2017-08-29 15:55:00+03	2017-08-29 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11386	PG0599	2017-07-24 15:55:00+03	2017-07-24 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-24 15:58:00+03	2017-07-24 16:53:00+03
11387	PG0599	2017-07-19 15:55:00+03	2017-07-19 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-19 15:57:00+03	2017-07-19 16:51:00+03
11388	PG0599	2017-09-03 15:55:00+03	2017-09-03 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11389	PG0599	2017-08-06 15:55:00+03	2017-08-06 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-06 15:58:00+03	2017-08-06 16:54:00+03
11390	PG0599	2017-08-19 15:55:00+03	2017-08-19 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11391	PG0599	2017-07-28 15:55:00+03	2017-07-28 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-28 15:59:00+03	2017-07-28 16:54:00+03
11392	PG0599	2017-08-15 15:55:00+03	2017-08-15 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-15 15:56:00+03	2017-08-15 16:50:00+03
11393	PG0599	2017-08-20 15:55:00+03	2017-08-20 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11394	PG0599	2017-08-07 15:55:00+03	2017-08-07 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-07 15:58:00+03	2017-08-07 16:53:00+03
11395	PG0599	2017-08-23 15:55:00+03	2017-08-23 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11396	PG0599	2017-07-18 15:55:00+03	2017-07-18 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-18 15:55:00+03	2017-07-18 16:50:00+03
11397	PG0599	2017-09-13 15:55:00+03	2017-09-13 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11398	PG0599	2017-09-02 15:55:00+03	2017-09-02 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11399	PG0599	2017-08-08 15:55:00+03	2017-08-08 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-08 15:59:00+03	2017-08-08 16:55:00+03
11400	PG0599	2017-09-08 15:55:00+03	2017-09-08 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11401	PG0599	2017-07-27 15:55:00+03	2017-07-27 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-27 16:01:00+03	2017-07-27 16:56:00+03
11402	PG0599	2017-08-09 15:55:00+03	2017-08-09 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-09 15:56:00+03	2017-08-09 16:50:00+03
11403	PG0599	2017-08-25 15:55:00+03	2017-08-25 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11404	PG0599	2017-08-14 15:55:00+03	2017-08-14 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-14 16:00:00+03	2017-08-14 16:55:00+03
11405	PG0599	2017-07-17 15:55:00+03	2017-07-17 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-17 15:58:00+03	2017-07-17 16:53:00+03
11406	PG0599	2017-08-30 15:55:00+03	2017-08-30 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11407	PG0599	2017-08-27 15:55:00+03	2017-08-27 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11408	PG0599	2017-07-25 15:55:00+03	2017-07-25 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-25 15:56:00+03	2017-07-25 16:51:00+03
11409	PG0599	2017-09-14 15:55:00+03	2017-09-14 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11410	PG0599	2017-09-01 15:55:00+03	2017-09-01 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11411	PG0599	2017-08-10 15:55:00+03	2017-08-10 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-10 15:59:00+03	2017-08-10 16:54:00+03
11412	PG0599	2017-08-11 15:55:00+03	2017-08-11 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-11 15:58:00+03	2017-08-11 16:53:00+03
11413	PG0599	2017-08-24 15:55:00+03	2017-08-24 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11414	PG0599	2017-09-09 15:55:00+03	2017-09-09 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11415	PG0599	2017-07-16 15:55:00+03	2017-07-16 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-16 15:57:00+03	2017-07-16 16:52:00+03
11416	PG0599	2017-08-13 15:55:00+03	2017-08-13 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-13 15:55:00+03	2017-08-13 16:51:00+03
11417	PG0599	2017-07-26 15:55:00+03	2017-07-26 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-26 15:59:00+03	2017-07-26 16:53:00+03
11418	PG0599	2017-08-31 15:55:00+03	2017-08-31 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11419	PG0599	2017-08-12 15:55:00+03	2017-08-12 16:50:00+03	SVX	HMA	Arrived	SU9	2017-08-12 16:01:00+03	2017-08-12 16:56:00+03
11420	PG0599	2017-08-18 15:55:00+03	2017-08-18 16:50:00+03	SVX	HMA	Scheduled	SU9	\N	\N
11421	PG0599	2017-07-31 15:55:00+03	2017-07-31 16:50:00+03	SVX	HMA	Arrived	SU9	2017-07-31 15:57:00+03	2017-07-31 16:52:00+03
11422	PG0166	2017-08-14 14:35:00+03	2017-08-14 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-14 14:39:00+03	2017-08-14 15:14:00+03
11423	PG0166	2017-07-27 14:35:00+03	2017-07-27 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-27 14:37:00+03	2017-07-27 15:12:00+03
11424	PG0166	2017-07-18 14:35:00+03	2017-07-18 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-18 14:39:00+03	2017-07-18 15:14:00+03
11425	PG0166	2017-08-18 14:35:00+03	2017-08-18 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11426	PG0166	2017-08-12 14:35:00+03	2017-08-12 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-12 18:51:00+03	2017-08-12 19:26:00+03
11427	PG0166	2017-08-03 14:35:00+03	2017-08-03 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-03 14:39:00+03	2017-08-03 15:14:00+03
11428	PG0166	2017-09-14 14:35:00+03	2017-09-14 15:10:00+03	SVX	MQF	Cancelled	CR2	\N	\N
11429	PG0166	2017-07-16 14:35:00+03	2017-07-16 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-16 14:40:00+03	2017-07-16 15:15:00+03
11430	PG0166	2017-09-02 14:35:00+03	2017-09-02 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11431	PG0166	2017-08-25 14:35:00+03	2017-08-25 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11432	PG0166	2017-07-17 14:35:00+03	2017-07-17 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-17 14:39:00+03	2017-07-17 15:14:00+03
11433	PG0166	2017-08-07 14:35:00+03	2017-08-07 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-07 14:39:00+03	2017-08-07 15:14:00+03
11434	PG0166	2017-08-01 14:35:00+03	2017-08-01 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-01 14:42:00+03	2017-08-01 15:17:00+03
11435	PG0166	2017-08-11 14:35:00+03	2017-08-11 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-11 18:05:00+03	2017-08-11 18:40:00+03
11436	PG0166	2017-08-30 14:35:00+03	2017-08-30 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11437	PG0166	2017-08-02 14:35:00+03	2017-08-02 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-02 14:38:00+03	2017-08-02 15:13:00+03
11438	PG0166	2017-09-08 14:35:00+03	2017-09-08 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11439	PG0166	2017-09-13 14:35:00+03	2017-09-13 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11440	PG0166	2017-08-23 14:35:00+03	2017-08-23 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11441	PG0166	2017-09-07 14:35:00+03	2017-09-07 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11442	PG0166	2017-09-09 14:35:00+03	2017-09-09 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11443	PG0166	2017-07-31 14:35:00+03	2017-07-31 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-31 14:36:00+03	2017-07-31 15:11:00+03
11444	PG0166	2017-07-19 14:35:00+03	2017-07-19 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-19 14:39:00+03	2017-07-19 15:14:00+03
11445	PG0166	2017-09-03 14:35:00+03	2017-09-03 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11446	PG0166	2017-08-28 14:35:00+03	2017-08-28 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11447	PG0166	2017-08-13 14:35:00+03	2017-08-13 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-13 14:40:00+03	2017-08-13 15:15:00+03
11448	PG0166	2017-07-25 14:35:00+03	2017-07-25 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-25 14:36:00+03	2017-07-25 15:10:00+03
11449	PG0166	2017-08-19 14:35:00+03	2017-08-19 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11450	PG0166	2017-08-06 14:35:00+03	2017-08-06 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-06 14:38:00+03	2017-08-06 15:13:00+03
11451	PG0166	2017-08-17 14:35:00+03	2017-08-17 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11452	PG0166	2017-07-21 14:35:00+03	2017-07-21 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-21 14:38:00+03	2017-07-21 15:13:00+03
11453	PG0166	2017-08-08 14:35:00+03	2017-08-08 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-08 14:37:00+03	2017-08-08 15:12:00+03
11454	PG0166	2017-08-22 14:35:00+03	2017-08-22 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11455	PG0166	2017-07-23 14:35:00+03	2017-07-23 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-23 14:37:00+03	2017-07-23 15:13:00+03
11456	PG0166	2017-08-04 14:35:00+03	2017-08-04 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-04 14:37:00+03	2017-08-04 15:12:00+03
11457	PG0166	2017-08-16 14:35:00+03	2017-08-16 15:10:00+03	SVX	MQF	On Time	CR2	\N	\N
11458	PG0166	2017-07-20 14:35:00+03	2017-07-20 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-20 14:36:00+03	2017-07-20 15:11:00+03
11459	PG0166	2017-09-05 14:35:00+03	2017-09-05 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11460	PG0166	2017-09-04 14:35:00+03	2017-09-04 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11461	PG0166	2017-09-06 14:35:00+03	2017-09-06 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11462	PG0166	2017-09-11 14:35:00+03	2017-09-11 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11463	PG0166	2017-07-30 14:35:00+03	2017-07-30 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-30 14:37:00+03	2017-07-30 15:12:00+03
11464	PG0166	2017-07-22 14:35:00+03	2017-07-22 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-22 14:36:00+03	2017-07-22 15:10:00+03
11465	PG0166	2017-08-05 14:35:00+03	2017-08-05 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-05 14:40:00+03	2017-08-05 15:15:00+03
11466	PG0166	2017-08-26 14:35:00+03	2017-08-26 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11467	PG0166	2017-07-29 14:35:00+03	2017-07-29 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-29 14:36:00+03	2017-07-29 15:11:00+03
11468	PG0166	2017-09-01 14:35:00+03	2017-09-01 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11469	PG0166	2017-07-28 14:35:00+03	2017-07-28 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-28 14:40:00+03	2017-07-28 15:15:00+03
11470	PG0166	2017-08-27 14:35:00+03	2017-08-27 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11471	PG0166	2017-08-20 14:35:00+03	2017-08-20 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11472	PG0166	2017-08-15 14:35:00+03	2017-08-15 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-15 14:37:00+03	2017-08-15 15:12:00+03
11473	PG0166	2017-08-24 14:35:00+03	2017-08-24 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11474	PG0166	2017-07-26 14:35:00+03	2017-07-26 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-26 14:38:00+03	2017-07-26 15:14:00+03
11475	PG0166	2017-08-29 14:35:00+03	2017-08-29 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11476	PG0166	2017-09-10 14:35:00+03	2017-09-10 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11477	PG0166	2017-08-10 14:35:00+03	2017-08-10 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-10 14:38:00+03	2017-08-10 15:13:00+03
11478	PG0166	2017-08-09 14:35:00+03	2017-08-09 15:10:00+03	SVX	MQF	Arrived	CR2	2017-08-09 14:37:00+03	2017-08-09 15:12:00+03
11479	PG0166	2017-08-21 14:35:00+03	2017-08-21 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11480	PG0166	2017-08-31 14:35:00+03	2017-08-31 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11481	PG0166	2017-07-24 14:35:00+03	2017-07-24 15:10:00+03	SVX	MQF	Arrived	CR2	2017-07-24 14:38:00+03	2017-07-24 15:14:00+03
11482	PG0166	2017-09-12 14:35:00+03	2017-09-12 15:10:00+03	SVX	MQF	Scheduled	CR2	\N	\N
11483	PG0362	2017-08-14 17:15:00+03	2017-08-14 19:00:00+03	SVX	IWA	Arrived	CR2	2017-08-14 17:20:00+03	2017-08-14 19:05:00+03
11484	PG0362	2017-07-20 17:15:00+03	2017-07-20 19:00:00+03	SVX	IWA	Arrived	CR2	2017-07-20 17:15:00+03	2017-07-20 19:00:00+03
11485	PG0362	2017-08-28 17:15:00+03	2017-08-28 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11486	PG0362	2017-07-27 17:15:00+03	2017-07-27 19:00:00+03	SVX	IWA	Arrived	CR2	2017-07-27 17:18:00+03	2017-07-27 19:03:00+03
11487	PG0362	2017-07-17 17:15:00+03	2017-07-17 19:00:00+03	SVX	IWA	Arrived	CR2	2017-07-17 17:16:00+03	2017-07-17 18:59:00+03
11488	PG0362	2017-08-31 17:15:00+03	2017-08-31 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11489	PG0362	2017-08-10 17:15:00+03	2017-08-10 19:00:00+03	SVX	IWA	Arrived	CR2	2017-08-10 17:18:00+03	2017-08-10 19:03:00+03
11490	PG0362	2017-08-24 17:15:00+03	2017-08-24 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11491	PG0362	2017-09-07 17:15:00+03	2017-09-07 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11492	PG0362	2017-08-03 17:15:00+03	2017-08-03 19:00:00+03	SVX	IWA	Arrived	CR2	2017-08-03 17:17:00+03	2017-08-03 19:02:00+03
11493	PG0362	2017-08-17 17:15:00+03	2017-08-17 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11494	PG0362	2017-09-11 17:15:00+03	2017-09-11 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11495	PG0362	2017-09-14 17:15:00+03	2017-09-14 19:00:00+03	SVX	IWA	Cancelled	CR2	\N	\N
11496	PG0362	2017-08-07 17:15:00+03	2017-08-07 19:00:00+03	SVX	IWA	Arrived	CR2	2017-08-07 17:17:00+03	2017-08-07 19:02:00+03
11497	PG0362	2017-07-31 17:15:00+03	2017-07-31 19:00:00+03	SVX	IWA	Arrived	CR2	2017-07-31 17:18:00+03	2017-07-31 19:03:00+03
11498	PG0362	2017-07-24 17:15:00+03	2017-07-24 19:00:00+03	SVX	IWA	Arrived	CR2	2017-07-24 17:17:00+03	2017-07-24 19:03:00+03
11499	PG0362	2017-08-21 17:15:00+03	2017-08-21 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11500	PG0362	2017-09-04 17:15:00+03	2017-09-04 19:00:00+03	SVX	IWA	Scheduled	CR2	\N	\N
11501	PG0303	2017-08-06 11:30:00+03	2017-08-06 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-06 11:32:00+03	2017-08-06 12:41:00+03
11502	PG0303	2017-07-26 11:30:00+03	2017-07-26 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-26 11:30:00+03	2017-07-26 12:40:00+03
11503	PG0303	2017-08-05 11:30:00+03	2017-08-05 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-05 14:53:00+03	2017-08-05 16:04:00+03
11504	PG0303	2017-09-02 11:30:00+03	2017-09-02 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11505	PG0303	2017-07-25 11:30:00+03	2017-07-25 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-25 11:33:00+03	2017-07-25 12:42:00+03
11506	PG0303	2017-09-03 11:30:00+03	2017-09-03 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11507	PG0303	2017-09-08 11:30:00+03	2017-09-08 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11508	PG0303	2017-07-23 11:30:00+03	2017-07-23 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-23 11:36:00+03	2017-07-23 12:46:00+03
11509	PG0303	2017-08-15 11:30:00+03	2017-08-15 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-15 11:31:00+03	2017-08-15 12:40:00+03
11510	PG0303	2017-07-21 11:30:00+03	2017-07-21 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-21 14:45:00+03	2017-07-21 15:55:00+03
11511	PG0303	2017-08-27 11:30:00+03	2017-08-27 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11512	PG0303	2017-09-11 11:30:00+03	2017-09-11 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11513	PG0303	2017-08-26 11:30:00+03	2017-08-26 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11514	PG0303	2017-07-27 11:30:00+03	2017-07-27 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-27 11:31:00+03	2017-07-27 12:40:00+03
11515	PG0303	2017-08-19 11:30:00+03	2017-08-19 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11516	PG0303	2017-08-29 11:30:00+03	2017-08-29 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11517	PG0303	2017-08-21 11:30:00+03	2017-08-21 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11518	PG0303	2017-09-01 11:30:00+03	2017-09-01 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11519	PG0303	2017-07-20 11:30:00+03	2017-07-20 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-20 11:34:00+03	2017-07-20 12:43:00+03
11520	PG0303	2017-08-13 11:30:00+03	2017-08-13 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-13 11:32:00+03	2017-08-13 12:43:00+03
11521	PG0303	2017-07-16 11:30:00+03	2017-07-16 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-16 11:33:00+03	2017-07-16 12:43:00+03
11522	PG0303	2017-08-08 11:30:00+03	2017-08-08 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-08 11:30:00+03	2017-08-08 12:39:00+03
11523	PG0303	2017-07-28 11:30:00+03	2017-07-28 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-28 11:33:00+03	2017-07-28 12:43:00+03
11524	PG0303	2017-07-31 11:30:00+03	2017-07-31 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-31 11:36:00+03	2017-07-31 12:47:00+03
11525	PG0303	2017-09-06 11:30:00+03	2017-09-06 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11526	PG0303	2017-08-24 11:30:00+03	2017-08-24 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11527	PG0303	2017-08-16 11:30:00+03	2017-08-16 12:40:00+03	SVX	SGC	On Time	SU9	\N	\N
11528	PG0303	2017-08-14 11:30:00+03	2017-08-14 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-14 11:33:00+03	2017-08-14 12:43:00+03
11529	PG0303	2017-09-05 11:30:00+03	2017-09-05 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11530	PG0303	2017-09-10 11:30:00+03	2017-09-10 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11531	PG0303	2017-07-24 11:30:00+03	2017-07-24 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-24 14:48:00+03	2017-07-24 15:58:00+03
11532	PG0303	2017-08-25 11:30:00+03	2017-08-25 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11533	PG0303	2017-07-17 11:30:00+03	2017-07-17 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-17 15:14:00+03	2017-07-17 16:25:00+03
11534	PG0303	2017-08-04 11:30:00+03	2017-08-04 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-04 11:30:00+03	2017-08-04 12:40:00+03
11535	PG0303	2017-09-12 11:30:00+03	2017-09-12 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11536	PG0303	2017-07-30 11:30:00+03	2017-07-30 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-30 11:34:00+03	2017-07-30 12:44:00+03
11537	PG0303	2017-09-13 11:30:00+03	2017-09-13 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11538	PG0303	2017-07-18 11:30:00+03	2017-07-18 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-18 11:32:00+03	2017-07-18 12:41:00+03
11539	PG0303	2017-08-12 11:30:00+03	2017-08-12 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-12 11:35:00+03	2017-08-12 12:45:00+03
11540	PG0303	2017-09-14 11:30:00+03	2017-09-14 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11541	PG0303	2017-08-20 11:30:00+03	2017-08-20 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11542	PG0303	2017-08-07 11:30:00+03	2017-08-07 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-07 11:31:00+03	2017-08-07 12:40:00+03
11543	PG0303	2017-07-19 11:30:00+03	2017-07-19 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-19 11:32:00+03	2017-07-19 12:41:00+03
11544	PG0303	2017-08-03 11:30:00+03	2017-08-03 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-03 11:31:00+03	2017-08-03 12:40:00+03
11545	PG0303	2017-08-23 11:30:00+03	2017-08-23 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11546	PG0303	2017-09-07 11:30:00+03	2017-09-07 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11547	PG0303	2017-08-10 11:30:00+03	2017-08-10 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-10 11:33:00+03	2017-08-10 12:44:00+03
11548	PG0303	2017-08-17 11:30:00+03	2017-08-17 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11549	PG0303	2017-09-09 11:30:00+03	2017-09-09 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11550	PG0303	2017-08-22 11:30:00+03	2017-08-22 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11551	PG0303	2017-07-22 11:30:00+03	2017-07-22 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-22 14:47:00+03	2017-07-22 15:57:00+03
11552	PG0303	2017-08-18 11:30:00+03	2017-08-18 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11553	PG0303	2017-08-02 11:30:00+03	2017-08-02 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-02 11:34:00+03	2017-08-02 12:44:00+03
11554	PG0303	2017-09-04 11:30:00+03	2017-09-04 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11555	PG0303	2017-08-31 11:30:00+03	2017-08-31 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11556	PG0303	2017-08-09 11:30:00+03	2017-08-09 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-09 11:34:00+03	2017-08-09 12:44:00+03
11557	PG0303	2017-07-29 11:30:00+03	2017-07-29 12:40:00+03	SVX	SGC	Arrived	SU9	2017-07-29 11:33:00+03	2017-07-29 12:44:00+03
11558	PG0303	2017-08-28 11:30:00+03	2017-08-28 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11559	PG0303	2017-08-11 11:30:00+03	2017-08-11 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-11 11:36:00+03	2017-08-11 12:45:00+03
11560	PG0303	2017-08-01 11:30:00+03	2017-08-01 12:40:00+03	SVX	SGC	Arrived	SU9	2017-08-01 11:34:00+03	2017-08-01 12:43:00+03
11561	PG0303	2017-08-30 11:30:00+03	2017-08-30 12:40:00+03	SVX	SGC	Scheduled	SU9	\N	\N
11562	PG0203	2017-08-14 17:45:00+03	2017-08-14 18:40:00+03	KZN	DME	Arrived	321	2017-08-14 17:47:00+03	2017-08-14 18:42:00+03
11563	PG0203	2017-08-03 17:45:00+03	2017-08-03 18:40:00+03	KZN	DME	Arrived	321	2017-08-03 17:49:00+03	2017-08-03 18:44:00+03
11564	PG0203	2017-09-14 17:45:00+03	2017-09-14 18:40:00+03	KZN	DME	Cancelled	321	\N	\N
11565	PG0203	2017-08-12 17:45:00+03	2017-08-12 18:40:00+03	KZN	DME	Arrived	321	2017-08-12 17:50:00+03	2017-08-12 18:44:00+03
11566	PG0203	2017-09-06 17:45:00+03	2017-09-06 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11567	PG0203	2017-08-21 17:45:00+03	2017-08-21 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11568	PG0203	2017-08-24 17:45:00+03	2017-08-24 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11569	PG0203	2017-08-20 17:45:00+03	2017-08-20 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11570	PG0203	2017-07-18 17:45:00+03	2017-07-18 18:40:00+03	KZN	DME	Arrived	321	2017-07-18 17:48:00+03	2017-07-18 18:43:00+03
11571	PG0203	2017-08-19 17:45:00+03	2017-08-19 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11572	PG0203	2017-08-09 17:45:00+03	2017-08-09 18:40:00+03	KZN	DME	Arrived	321	2017-08-09 17:48:00+03	2017-08-09 18:43:00+03
11573	PG0203	2017-08-16 17:45:00+03	2017-08-16 18:40:00+03	KZN	DME	On Time	321	\N	\N
11574	PG0203	2017-09-07 17:45:00+03	2017-09-07 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11575	PG0203	2017-08-13 17:45:00+03	2017-08-13 18:40:00+03	KZN	DME	Arrived	321	2017-08-13 17:50:00+03	2017-08-13 18:45:00+03
11576	PG0203	2017-08-10 17:45:00+03	2017-08-10 18:40:00+03	KZN	DME	Arrived	321	2017-08-10 17:45:00+03	2017-08-10 18:41:00+03
11577	PG0203	2017-08-06 17:45:00+03	2017-08-06 18:40:00+03	KZN	DME	Arrived	321	2017-08-06 21:17:00+03	2017-08-06 22:12:00+03
11578	PG0203	2017-08-15 17:45:00+03	2017-08-15 18:40:00+03	KZN	DME	Departed	321	2017-08-15 17:50:00+03	\N
11579	PG0203	2017-09-12 17:45:00+03	2017-09-12 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11580	PG0203	2017-07-30 17:45:00+03	2017-07-30 18:40:00+03	KZN	DME	Arrived	321	2017-07-30 17:47:00+03	2017-07-30 18:42:00+03
11581	PG0203	2017-07-23 17:45:00+03	2017-07-23 18:40:00+03	KZN	DME	Arrived	321	2017-07-23 17:49:00+03	2017-07-23 18:44:00+03
11582	PG0203	2017-07-28 17:45:00+03	2017-07-28 18:40:00+03	KZN	DME	Arrived	321	2017-07-28 17:47:00+03	2017-07-28 18:42:00+03
11583	PG0203	2017-07-26 17:45:00+03	2017-07-26 18:40:00+03	KZN	DME	Arrived	321	2017-07-26 17:48:00+03	2017-07-26 18:43:00+03
11584	PG0203	2017-09-05 17:45:00+03	2017-09-05 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11585	PG0203	2017-07-27 17:45:00+03	2017-07-27 18:40:00+03	KZN	DME	Arrived	321	2017-07-27 17:46:00+03	2017-07-27 18:41:00+03
11586	PG0203	2017-07-24 17:45:00+03	2017-07-24 18:40:00+03	KZN	DME	Arrived	321	2017-07-24 17:46:00+03	2017-07-24 18:41:00+03
11587	PG0203	2017-09-10 17:45:00+03	2017-09-10 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11588	PG0203	2017-08-18 17:45:00+03	2017-08-18 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11589	PG0203	2017-08-31 17:45:00+03	2017-08-31 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11590	PG0203	2017-09-01 17:45:00+03	2017-09-01 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11591	PG0203	2017-08-17 17:45:00+03	2017-08-17 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11592	PG0203	2017-07-22 17:45:00+03	2017-07-22 18:40:00+03	KZN	DME	Arrived	321	2017-07-22 17:48:00+03	2017-07-22 18:44:00+03
11593	PG0203	2017-08-04 17:45:00+03	2017-08-04 18:40:00+03	KZN	DME	Arrived	321	2017-08-04 17:48:00+03	2017-08-04 18:43:00+03
11594	PG0203	2017-07-21 17:45:00+03	2017-07-21 18:40:00+03	KZN	DME	Arrived	321	2017-07-21 17:47:00+03	2017-07-21 18:43:00+03
11595	PG0203	2017-08-25 17:45:00+03	2017-08-25 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11596	PG0203	2017-08-08 17:45:00+03	2017-08-08 18:40:00+03	KZN	DME	Arrived	321	2017-08-08 17:46:00+03	2017-08-08 18:41:00+03
11597	PG0203	2017-07-25 17:45:00+03	2017-07-25 18:40:00+03	KZN	DME	Arrived	321	2017-07-25 17:49:00+03	2017-07-25 18:44:00+03
11598	PG0203	2017-07-20 17:45:00+03	2017-07-20 18:40:00+03	KZN	DME	Arrived	321	2017-07-20 17:48:00+03	2017-07-20 18:43:00+03
11599	PG0203	2017-09-03 17:45:00+03	2017-09-03 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11600	PG0203	2017-08-01 17:45:00+03	2017-08-01 18:40:00+03	KZN	DME	Arrived	321	2017-08-01 17:48:00+03	2017-08-01 18:43:00+03
11601	PG0203	2017-07-29 17:45:00+03	2017-07-29 18:40:00+03	KZN	DME	Arrived	321	2017-07-29 17:46:00+03	2017-07-29 18:41:00+03
11602	PG0203	2017-08-30 17:45:00+03	2017-08-30 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11603	PG0203	2017-07-19 17:45:00+03	2017-07-19 18:40:00+03	KZN	DME	Arrived	321	2017-07-19 20:50:00+03	2017-07-19 21:45:00+03
11604	PG0203	2017-09-08 17:45:00+03	2017-09-08 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11605	PG0203	2017-07-17 17:45:00+03	2017-07-17 18:40:00+03	KZN	DME	Arrived	321	2017-07-17 17:48:00+03	2017-07-17 18:43:00+03
11606	PG0203	2017-07-16 17:45:00+03	2017-07-16 18:40:00+03	KZN	DME	Arrived	321	2017-07-16 17:46:00+03	2017-07-16 18:42:00+03
11607	PG0203	2017-08-07 17:45:00+03	2017-08-07 18:40:00+03	KZN	DME	Arrived	321	2017-08-07 17:47:00+03	2017-08-07 18:42:00+03
11608	PG0203	2017-09-04 17:45:00+03	2017-09-04 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11609	PG0203	2017-08-27 17:45:00+03	2017-08-27 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11610	PG0203	2017-08-11 17:45:00+03	2017-08-11 18:40:00+03	KZN	DME	Arrived	321	2017-08-11 17:48:00+03	2017-08-11 18:43:00+03
11611	PG0203	2017-09-11 17:45:00+03	2017-09-11 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11612	PG0203	2017-08-02 17:45:00+03	2017-08-02 18:40:00+03	KZN	DME	Arrived	321	2017-08-02 17:45:00+03	2017-08-02 18:39:00+03
11613	PG0203	2017-09-09 17:45:00+03	2017-09-09 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11614	PG0203	2017-08-22 17:45:00+03	2017-08-22 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11615	PG0203	2017-08-23 17:45:00+03	2017-08-23 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11616	PG0203	2017-07-31 17:45:00+03	2017-07-31 18:40:00+03	KZN	DME	Arrived	321	2017-07-31 17:46:00+03	2017-07-31 18:42:00+03
11617	PG0203	2017-08-28 17:45:00+03	2017-08-28 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11618	PG0203	2017-08-05 17:45:00+03	2017-08-05 18:40:00+03	KZN	DME	Arrived	321	2017-08-05 17:45:00+03	2017-08-05 18:40:00+03
11619	PG0203	2017-09-13 17:45:00+03	2017-09-13 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11620	PG0203	2017-08-26 17:45:00+03	2017-08-26 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11621	PG0203	2017-09-02 17:45:00+03	2017-09-02 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11622	PG0203	2017-08-29 17:45:00+03	2017-08-29 18:40:00+03	KZN	DME	Scheduled	321	\N	\N
11623	PG0508	2017-08-02 09:45:00+03	2017-08-02 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-02 09:50:00+03	2017-08-02 11:29:00+03
11624	PG0508	2017-08-08 09:45:00+03	2017-08-08 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-08 09:47:00+03	2017-08-08 11:25:00+03
11625	PG0508	2017-07-23 09:45:00+03	2017-07-23 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-23 09:47:00+03	2017-07-23 11:28:00+03
11626	PG0508	2017-08-06 09:45:00+03	2017-08-06 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-06 09:48:00+03	2017-08-06 11:28:00+03
11627	PG0508	2017-09-14 09:45:00+03	2017-09-14 11:25:00+03	KZN	LED	Cancelled	SU9	\N	\N
11628	PG0508	2017-09-07 09:45:00+03	2017-09-07 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11629	PG0508	2017-07-31 09:45:00+03	2017-07-31 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-31 09:49:00+03	2017-07-31 11:28:00+03
11630	PG0508	2017-08-14 09:45:00+03	2017-08-14 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-14 09:46:00+03	2017-08-14 11:27:00+03
11631	PG0508	2017-08-18 09:45:00+03	2017-08-18 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11632	PG0508	2017-08-31 09:45:00+03	2017-08-31 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11633	PG0508	2017-08-28 09:45:00+03	2017-08-28 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11634	PG0508	2017-08-09 09:45:00+03	2017-08-09 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-09 09:48:00+03	2017-08-09 11:28:00+03
11635	PG0508	2017-09-02 09:45:00+03	2017-09-02 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11636	PG0508	2017-08-11 09:45:00+03	2017-08-11 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-11 09:46:00+03	2017-08-11 11:26:00+03
11637	PG0508	2017-08-03 09:45:00+03	2017-08-03 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-03 09:47:00+03	2017-08-03 11:26:00+03
11638	PG0508	2017-07-17 09:45:00+03	2017-07-17 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-17 09:46:00+03	2017-07-17 11:26:00+03
11639	PG0508	2017-07-26 09:45:00+03	2017-07-26 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-26 09:47:00+03	2017-07-26 11:27:00+03
11640	PG0508	2017-07-21 09:45:00+03	2017-07-21 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-21 09:49:00+03	2017-07-21 11:29:00+03
11641	PG0508	2017-09-06 09:45:00+03	2017-09-06 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11642	PG0508	2017-07-19 09:45:00+03	2017-07-19 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-19 09:47:00+03	2017-07-19 11:27:00+03
11643	PG0508	2017-08-20 09:45:00+03	2017-08-20 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11644	PG0508	2017-08-23 09:45:00+03	2017-08-23 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11645	PG0508	2017-09-04 09:45:00+03	2017-09-04 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11646	PG0508	2017-07-16 09:45:00+03	2017-07-16 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-16 09:48:00+03	2017-07-16 11:28:00+03
11647	PG0508	2017-09-12 09:45:00+03	2017-09-12 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11648	PG0508	2017-08-17 09:45:00+03	2017-08-17 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11649	PG0508	2017-08-01 09:45:00+03	2017-08-01 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-01 09:48:00+03	2017-08-01 11:28:00+03
11650	PG0508	2017-07-29 09:45:00+03	2017-07-29 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-29 09:47:00+03	2017-07-29 11:26:00+03
11651	PG0508	2017-08-26 09:45:00+03	2017-08-26 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11652	PG0508	2017-08-29 09:45:00+03	2017-08-29 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11653	PG0508	2017-09-09 09:45:00+03	2017-09-09 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11654	PG0508	2017-07-27 09:45:00+03	2017-07-27 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-27 09:46:00+03	2017-07-27 11:26:00+03
11655	PG0508	2017-08-16 09:45:00+03	2017-08-16 11:25:00+03	KZN	LED	On Time	SU9	\N	\N
11656	PG0508	2017-08-22 09:45:00+03	2017-08-22 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11657	PG0508	2017-08-19 09:45:00+03	2017-08-19 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11658	PG0508	2017-09-10 09:45:00+03	2017-09-10 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11659	PG0508	2017-08-21 09:45:00+03	2017-08-21 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11660	PG0508	2017-07-22 09:45:00+03	2017-07-22 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-22 09:46:00+03	2017-07-22 11:28:00+03
11661	PG0508	2017-07-30 09:45:00+03	2017-07-30 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-30 09:47:00+03	2017-07-30 11:27:00+03
11662	PG0508	2017-08-12 09:45:00+03	2017-08-12 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-12 09:51:00+03	2017-08-12 11:32:00+03
11663	PG0508	2017-08-25 09:45:00+03	2017-08-25 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11664	PG0508	2017-08-24 09:45:00+03	2017-08-24 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11665	PG0508	2017-07-24 09:45:00+03	2017-07-24 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-24 09:47:00+03	2017-07-24 11:26:00+03
11666	PG0508	2017-09-01 09:45:00+03	2017-09-01 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11667	PG0508	2017-08-05 09:45:00+03	2017-08-05 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-05 09:48:00+03	2017-08-05 11:28:00+03
11668	PG0508	2017-09-13 09:45:00+03	2017-09-13 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11669	PG0508	2017-08-30 09:45:00+03	2017-08-30 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11670	PG0508	2017-07-20 09:45:00+03	2017-07-20 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-20 09:47:00+03	2017-07-20 11:25:00+03
11671	PG0508	2017-08-15 09:45:00+03	2017-08-15 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-15 09:49:00+03	2017-08-15 11:29:00+03
11672	PG0508	2017-08-13 09:45:00+03	2017-08-13 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-13 09:46:00+03	2017-08-13 11:24:00+03
11673	PG0508	2017-09-11 09:45:00+03	2017-09-11 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11674	PG0508	2017-07-28 09:45:00+03	2017-07-28 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-28 09:47:00+03	2017-07-28 11:27:00+03
11675	PG0508	2017-09-08 09:45:00+03	2017-09-08 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11676	PG0508	2017-09-03 09:45:00+03	2017-09-03 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11677	PG0508	2017-08-04 09:45:00+03	2017-08-04 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-04 09:49:00+03	2017-08-04 11:27:00+03
11678	PG0508	2017-09-05 09:45:00+03	2017-09-05 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11679	PG0508	2017-08-10 09:45:00+03	2017-08-10 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-10 09:46:00+03	2017-08-10 11:25:00+03
11680	PG0508	2017-08-27 09:45:00+03	2017-08-27 11:25:00+03	KZN	LED	Scheduled	SU9	\N	\N
11681	PG0508	2017-07-25 09:45:00+03	2017-07-25 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-25 09:50:00+03	2017-07-25 11:30:00+03
11682	PG0508	2017-08-07 09:45:00+03	2017-08-07 11:25:00+03	KZN	LED	Arrived	SU9	2017-08-07 09:52:00+03	2017-08-07 11:33:00+03
11683	PG0508	2017-07-18 09:45:00+03	2017-07-18 11:25:00+03	KZN	LED	Arrived	SU9	2017-07-18 09:46:00+03	2017-07-18 11:26:00+03
11684	PG0610	2017-08-22 12:45:00+03	2017-08-22 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11685	PG0609	2017-07-30 11:15:00+03	2017-07-30 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-30 11:20:00+03	2017-07-30 15:00:00+03
11686	PG0610	2017-07-30 12:45:00+03	2017-07-30 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-30 12:48:00+03	2017-07-30 16:29:00+03
11687	PG0610	2017-09-12 12:45:00+03	2017-09-12 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11688	PG0609	2017-09-12 11:15:00+03	2017-09-12 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11689	PG0610	2017-07-31 12:45:00+03	2017-07-31 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-31 12:45:00+03	2017-07-31 16:25:00+03
11690	PG0610	2017-09-14 12:45:00+03	2017-09-14 16:25:00+03	KZN	ROV	Cancelled	CN1	\N	\N
11691	PG0610	2017-08-20 12:45:00+03	2017-08-20 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11692	PG0609	2017-07-24 11:15:00+03	2017-07-24 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-24 11:21:00+03	2017-07-24 15:00:00+03
11693	PG0610	2017-07-24 12:45:00+03	2017-07-24 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-24 12:46:00+03	2017-07-24 16:26:00+03
11694	PG0609	2017-07-31 11:15:00+03	2017-07-31 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-31 11:17:00+03	2017-07-31 14:55:00+03
11695	PG0610	2017-07-19 12:45:00+03	2017-07-19 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-19 12:52:00+03	2017-07-19 16:29:00+03
11696	PG0609	2017-07-19 11:15:00+03	2017-07-19 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-19 11:17:00+03	2017-07-19 14:56:00+03
11697	PG0610	2017-09-03 12:45:00+03	2017-09-03 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11698	PG0609	2017-09-03 11:15:00+03	2017-09-03 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11699	PG0609	2017-08-06 11:15:00+03	2017-08-06 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-06 11:22:00+03	2017-08-06 15:04:00+03
11700	PG0610	2017-08-06 12:45:00+03	2017-08-06 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-06 12:46:00+03	2017-08-06 16:24:00+03
11701	PG0609	2017-08-19 11:15:00+03	2017-08-19 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11702	PG0610	2017-08-19 12:45:00+03	2017-08-19 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11703	PG0609	2017-08-16 11:15:00+03	2017-08-16 14:55:00+03	KZN	ROV	On Time	CN1	\N	\N
11704	PG0610	2017-08-16 12:45:00+03	2017-08-16 16:25:00+03	KZN	ROV	On Time	CN1	\N	\N
11705	PG0609	2017-08-18 11:15:00+03	2017-08-18 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11706	PG0610	2017-08-18 12:45:00+03	2017-08-18 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11707	PG0609	2017-08-29 11:15:00+03	2017-08-29 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11708	PG0610	2017-07-28 12:45:00+03	2017-07-28 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-28 12:47:00+03	2017-07-28 16:24:00+03
11709	PG0609	2017-07-28 11:15:00+03	2017-07-28 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-28 11:17:00+03	2017-07-28 14:57:00+03
11710	PG0610	2017-08-29 12:45:00+03	2017-08-29 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11711	PG0609	2017-07-29 11:15:00+03	2017-07-29 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-29 11:18:00+03	2017-07-29 15:01:00+03
11712	PG0609	2017-07-20 11:15:00+03	2017-07-20 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-20 11:18:00+03	2017-07-20 14:56:00+03
11713	PG0610	2017-07-20 12:45:00+03	2017-07-20 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-20 12:51:00+03	2017-07-20 16:27:00+03
11714	PG0610	2017-07-29 12:45:00+03	2017-07-29 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-29 12:47:00+03	2017-07-29 16:28:00+03
11715	PG0609	2017-08-28 11:15:00+03	2017-08-28 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11716	PG0610	2017-08-15 12:45:00+03	2017-08-15 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-15 12:47:00+03	2017-08-15 16:27:00+03
11717	PG0609	2017-08-15 11:15:00+03	2017-08-15 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-15 11:15:00+03	2017-08-15 14:56:00+03
11718	PG0609	2017-09-04 11:15:00+03	2017-09-04 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11719	PG0610	2017-09-04 12:45:00+03	2017-09-04 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11720	PG0610	2017-08-04 12:45:00+03	2017-08-04 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-04 12:45:00+03	2017-08-04 16:26:00+03
11721	PG0609	2017-08-04 11:15:00+03	2017-08-04 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-04 11:16:00+03	2017-08-04 15:02:00+03
11722	PG0610	2017-08-12 12:45:00+03	2017-08-12 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-12 12:47:00+03	2017-08-12 16:25:00+03
11723	PG0609	2017-08-12 11:15:00+03	2017-08-12 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-12 11:16:00+03	2017-08-12 14:57:00+03
11724	PG0609	2017-08-07 11:15:00+03	2017-08-07 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-07 11:19:00+03	2017-08-07 14:55:00+03
11725	PG0610	2017-08-07 12:45:00+03	2017-08-07 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-07 12:46:00+03	2017-08-07 16:25:00+03
11726	PG0610	2017-08-28 12:45:00+03	2017-08-28 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11727	PG0610	2017-09-07 12:45:00+03	2017-09-07 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11728	PG0609	2017-08-23 11:15:00+03	2017-08-23 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11729	PG0610	2017-08-23 12:45:00+03	2017-08-23 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11730	PG0609	2017-09-07 11:15:00+03	2017-09-07 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11731	PG0610	2017-07-18 12:45:00+03	2017-07-18 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-18 12:48:00+03	2017-07-18 16:30:00+03
11732	PG0609	2017-07-18 11:15:00+03	2017-07-18 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-18 11:17:00+03	2017-07-18 14:56:00+03
11733	PG0609	2017-08-31 11:15:00+03	2017-08-31 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11734	PG0610	2017-08-31 12:45:00+03	2017-08-31 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11735	PG0610	2017-09-02 12:45:00+03	2017-09-02 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11736	PG0609	2017-09-02 11:15:00+03	2017-09-02 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11737	PG0609	2017-07-26 11:15:00+03	2017-07-26 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-26 11:15:00+03	2017-07-26 14:54:00+03
11738	PG0609	2017-08-08 11:15:00+03	2017-08-08 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-08 11:18:00+03	2017-08-08 15:00:00+03
11739	PG0610	2017-08-08 12:45:00+03	2017-08-08 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-08 12:49:00+03	2017-08-08 16:34:00+03
11740	PG0609	2017-09-13 11:15:00+03	2017-09-13 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11741	PG0610	2017-09-13 12:45:00+03	2017-09-13 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11742	PG0610	2017-08-03 12:45:00+03	2017-08-03 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-03 12:49:00+03	2017-08-03 16:28:00+03
11743	PG0609	2017-08-03 11:15:00+03	2017-08-03 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-03 11:16:00+03	2017-08-03 14:54:00+03
11744	PG0610	2017-07-26 12:45:00+03	2017-07-26 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-26 12:48:00+03	2017-07-26 16:25:00+03
11745	PG0609	2017-09-06 11:15:00+03	2017-09-06 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11746	PG0609	2017-08-13 11:15:00+03	2017-08-13 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-13 11:18:00+03	2017-08-13 15:00:00+03
11747	PG0610	2017-08-13 12:45:00+03	2017-08-13 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-13 12:48:00+03	2017-08-13 16:31:00+03
11748	PG0609	2017-09-08 11:15:00+03	2017-09-08 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11749	PG0610	2017-09-08 12:45:00+03	2017-09-08 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11750	PG0609	2017-09-10 11:15:00+03	2017-09-10 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11751	PG0609	2017-08-22 11:15:00+03	2017-08-22 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11752	PG0610	2017-09-10 12:45:00+03	2017-09-10 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11753	PG0610	2017-07-22 12:45:00+03	2017-07-22 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-22 12:47:00+03	2017-07-22 16:29:00+03
11754	PG0609	2017-07-21 11:15:00+03	2017-07-21 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-21 11:17:00+03	2017-07-21 14:59:00+03
11755	PG0609	2017-07-22 11:15:00+03	2017-07-22 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-22 11:19:00+03	2017-07-22 14:59:00+03
11756	PG0610	2017-07-21 12:45:00+03	2017-07-21 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-21 12:50:00+03	2017-07-21 16:28:00+03
11757	PG0609	2017-08-20 11:15:00+03	2017-08-20 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11758	PG0610	2017-07-27 12:45:00+03	2017-07-27 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-27 12:48:00+03	2017-07-27 16:28:00+03
11759	PG0609	2017-07-27 11:15:00+03	2017-07-27 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-27 11:18:00+03	2017-07-27 14:52:00+03
11760	PG0610	2017-08-25 12:45:00+03	2017-08-25 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11761	PG0610	2017-08-26 12:45:00+03	2017-08-26 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11762	PG0609	2017-08-25 11:15:00+03	2017-08-25 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11763	PG0609	2017-08-09 11:15:00+03	2017-08-09 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-09 11:19:00+03	2017-08-09 15:01:00+03
11764	PG0610	2017-08-09 12:45:00+03	2017-08-09 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-09 16:19:00+03	2017-08-09 19:58:00+03
11765	PG0609	2017-08-26 11:15:00+03	2017-08-26 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11766	PG0610	2017-08-14 12:45:00+03	2017-08-14 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-14 16:07:00+03	2017-08-14 19:49:00+03
11767	PG0609	2017-08-14 11:15:00+03	2017-08-14 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-14 11:17:00+03	2017-08-14 14:58:00+03
11768	PG0610	2017-07-17 12:45:00+03	2017-07-17 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-17 12:50:00+03	2017-07-17 16:31:00+03
11769	PG0609	2017-07-17 11:15:00+03	2017-07-17 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-17 11:15:00+03	2017-07-17 14:54:00+03
11770	PG0609	2017-08-21 11:15:00+03	2017-08-21 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11771	PG0610	2017-08-21 12:45:00+03	2017-08-21 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11772	PG0609	2017-09-05 11:15:00+03	2017-09-05 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11773	PG0610	2017-09-05 12:45:00+03	2017-09-05 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11774	PG0610	2017-08-02 12:45:00+03	2017-08-02 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-02 12:48:00+03	2017-08-02 16:29:00+03
11775	PG0609	2017-08-02 11:15:00+03	2017-08-02 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-02 11:19:00+03	2017-08-02 14:59:00+03
11776	PG0610	2017-08-27 12:45:00+03	2017-08-27 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11777	PG0610	2017-08-05 12:45:00+03	2017-08-05 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-05 12:47:00+03	2017-08-05 16:27:00+03
11778	PG0609	2017-08-27 11:15:00+03	2017-08-27 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11779	PG0610	2017-09-06 12:45:00+03	2017-09-06 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11780	PG0610	2017-08-24 12:45:00+03	2017-08-24 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11781	PG0609	2017-08-01 11:15:00+03	2017-08-01 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-01 11:19:00+03	2017-08-01 15:01:00+03
11782	PG0610	2017-08-01 12:45:00+03	2017-08-01 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-01 12:50:00+03	2017-08-01 16:29:00+03
11783	PG0609	2017-07-16 11:15:00+03	2017-07-16 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-16 11:17:00+03	2017-07-16 14:58:00+03
11784	PG0610	2017-07-16 12:45:00+03	2017-07-16 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-16 12:46:00+03	2017-07-16 16:25:00+03
11785	PG0609	2017-08-24 11:15:00+03	2017-08-24 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11786	PG0609	2017-08-30 11:15:00+03	2017-08-30 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11787	PG0609	2017-07-25 11:15:00+03	2017-07-25 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-25 11:19:00+03	2017-07-25 14:55:00+03
11788	PG0610	2017-07-25 12:45:00+03	2017-07-25 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-25 12:49:00+03	2017-07-25 16:28:00+03
11789	PG0609	2017-09-14 11:15:00+03	2017-09-14 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11790	PG0609	2017-08-05 11:15:00+03	2017-08-05 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-05 14:24:00+03	2017-08-05 18:03:00+03
11791	PG0610	2017-08-30 12:45:00+03	2017-08-30 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11792	PG0609	2017-08-17 11:15:00+03	2017-08-17 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11793	PG0610	2017-08-17 12:45:00+03	2017-08-17 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11794	PG0610	2017-09-01 12:45:00+03	2017-09-01 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11795	PG0609	2017-09-01 11:15:00+03	2017-09-01 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11796	PG0609	2017-09-09 11:15:00+03	2017-09-09 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11797	PG0610	2017-08-11 12:45:00+03	2017-08-11 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-11 15:59:00+03	2017-08-11 19:41:00+03
11798	PG0609	2017-08-11 11:15:00+03	2017-08-11 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-11 11:18:00+03	2017-08-11 14:56:00+03
11799	PG0609	2017-08-10 11:15:00+03	2017-08-10 14:55:00+03	KZN	ROV	Arrived	CN1	2017-08-10 11:16:00+03	2017-08-10 14:56:00+03
11800	PG0610	2017-08-10 12:45:00+03	2017-08-10 16:25:00+03	KZN	ROV	Arrived	CN1	2017-08-10 12:50:00+03	2017-08-10 16:33:00+03
11801	PG0609	2017-07-23 11:15:00+03	2017-07-23 14:55:00+03	KZN	ROV	Arrived	CN1	2017-07-23 11:17:00+03	2017-07-23 14:57:00+03
11802	PG0610	2017-09-09 12:45:00+03	2017-09-09 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11803	PG0610	2017-07-23 12:45:00+03	2017-07-23 16:25:00+03	KZN	ROV	Arrived	CN1	2017-07-23 12:49:00+03	2017-07-23 16:31:00+03
11804	PG0610	2017-09-11 12:45:00+03	2017-09-11 16:25:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11805	PG0609	2017-09-11 11:15:00+03	2017-09-11 14:55:00+03	KZN	ROV	Scheduled	CN1	\N	\N
11806	PG0579	2017-09-06 15:45:00+03	2017-09-06 17:35:00+03	KZN	PKV	Scheduled	CR2	\N	\N
11807	PG0579	2017-08-16 15:45:00+03	2017-08-16 17:35:00+03	KZN	PKV	On Time	CR2	\N	\N
11808	PG0579	2017-07-26 15:45:00+03	2017-07-26 17:35:00+03	KZN	PKV	Arrived	CR2	2017-07-26 15:46:00+03	2017-07-26 17:34:00+03
11809	PG0579	2017-07-19 15:45:00+03	2017-07-19 17:35:00+03	KZN	PKV	Arrived	CR2	2017-07-19 15:51:00+03	2017-07-19 17:40:00+03
11810	PG0579	2017-08-23 15:45:00+03	2017-08-23 17:35:00+03	KZN	PKV	Scheduled	CR2	\N	\N
11811	PG0579	2017-08-02 15:45:00+03	2017-08-02 17:35:00+03	KZN	PKV	Arrived	CR2	2017-08-02 15:48:00+03	2017-08-02 17:37:00+03
11812	PG0579	2017-08-09 15:45:00+03	2017-08-09 17:35:00+03	KZN	PKV	Arrived	CR2	2017-08-09 15:50:00+03	2017-08-09 17:41:00+03
11813	PG0579	2017-09-13 15:45:00+03	2017-09-13 17:35:00+03	KZN	PKV	Cancelled	CR2	\N	\N
11814	PG0579	2017-08-30 15:45:00+03	2017-08-30 17:35:00+03	KZN	PKV	Scheduled	CR2	\N	\N
11815	PG0446	2017-07-22 11:25:00+03	2017-07-22 13:20:00+03	KZN	MRV	Arrived	CR2	2017-07-22 11:25:00+03	2017-07-22 13:20:00+03
11816	PG0446	2017-07-25 11:25:00+03	2017-07-25 13:20:00+03	KZN	MRV	Arrived	CR2	2017-07-25 11:28:00+03	2017-07-25 13:22:00+03
11817	PG0446	2017-09-02 11:25:00+03	2017-09-02 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11818	PG0446	2017-09-12 11:25:00+03	2017-09-12 13:20:00+03	KZN	MRV	Cancelled	CR2	\N	\N
11819	PG0446	2017-08-26 11:25:00+03	2017-08-26 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11820	PG0446	2017-09-05 11:25:00+03	2017-09-05 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11821	PG0446	2017-08-19 11:25:00+03	2017-08-19 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11822	PG0446	2017-08-01 11:25:00+03	2017-08-01 13:20:00+03	KZN	MRV	Arrived	CR2	2017-08-01 11:28:00+03	2017-08-01 13:25:00+03
11823	PG0446	2017-08-08 11:25:00+03	2017-08-08 13:20:00+03	KZN	MRV	Arrived	CR2	2017-08-08 11:29:00+03	2017-08-08 13:23:00+03
11824	PG0446	2017-08-15 11:25:00+03	2017-08-15 13:20:00+03	KZN	MRV	Arrived	CR2	2017-08-15 11:28:00+03	2017-08-15 13:21:00+03
11825	PG0446	2017-08-05 11:25:00+03	2017-08-05 13:20:00+03	KZN	MRV	Arrived	CR2	2017-08-05 11:27:00+03	2017-08-05 13:22:00+03
11826	PG0446	2017-08-12 11:25:00+03	2017-08-12 13:20:00+03	KZN	MRV	Arrived	CR2	2017-08-12 11:28:00+03	2017-08-12 13:25:00+03
11827	PG0446	2017-07-18 11:25:00+03	2017-07-18 13:20:00+03	KZN	MRV	Arrived	CR2	2017-07-18 11:28:00+03	2017-07-18 13:23:00+03
11828	PG0446	2017-07-29 11:25:00+03	2017-07-29 13:20:00+03	KZN	MRV	Arrived	CR2	2017-07-29 11:29:00+03	2017-07-29 13:23:00+03
11829	PG0446	2017-08-29 11:25:00+03	2017-08-29 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11830	PG0446	2017-08-22 11:25:00+03	2017-08-22 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11831	PG0446	2017-09-09 11:25:00+03	2017-09-09 13:20:00+03	KZN	MRV	Scheduled	CR2	\N	\N
11832	PG0498	2017-09-11 10:15:00+03	2017-09-11 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11833	PG0498	2017-09-02 10:15:00+03	2017-09-02 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11834	PG0498	2017-09-07 10:15:00+03	2017-09-07 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11835	PG0498	2017-08-25 10:15:00+03	2017-08-25 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11836	PG0498	2017-07-22 10:15:00+03	2017-07-22 14:55:00+03	KZN	IKT	Arrived	319	2017-07-22 10:21:00+03	2017-07-22 14:56:00+03
11837	PG0498	2017-08-03 10:15:00+03	2017-08-03 14:55:00+03	KZN	IKT	Arrived	319	2017-08-03 10:19:00+03	2017-08-03 14:56:00+03
11838	PG0498	2017-07-21 10:15:00+03	2017-07-21 14:55:00+03	KZN	IKT	Arrived	319	2017-07-21 10:16:00+03	2017-07-21 14:55:00+03
11839	PG0498	2017-08-16 10:15:00+03	2017-08-16 14:55:00+03	KZN	IKT	Delayed	319	\N	\N
11840	PG0498	2017-08-18 10:15:00+03	2017-08-18 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11841	PG0498	2017-09-10 10:15:00+03	2017-09-10 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11842	PG0498	2017-09-01 10:15:00+03	2017-09-01 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11843	PG0498	2017-07-24 10:15:00+03	2017-07-24 14:55:00+03	KZN	IKT	Arrived	319	2017-07-24 10:18:00+03	2017-07-24 14:57:00+03
11844	PG0498	2017-08-14 10:15:00+03	2017-08-14 14:55:00+03	KZN	IKT	Arrived	319	2017-08-14 10:18:00+03	2017-08-14 14:58:00+03
11845	PG0498	2017-07-17 10:15:00+03	2017-07-17 14:55:00+03	KZN	IKT	Arrived	319	2017-07-17 10:17:00+03	2017-07-17 14:56:00+03
11846	PG0498	2017-07-19 10:15:00+03	2017-07-19 14:55:00+03	KZN	IKT	Arrived	319	2017-07-19 10:17:00+03	2017-07-19 14:56:00+03
11848	PG0498	2017-08-02 10:15:00+03	2017-08-02 14:55:00+03	KZN	IKT	Arrived	319	2017-08-02 10:18:00+03	2017-08-02 14:59:00+03
11849	PG0498	2017-08-24 10:15:00+03	2017-08-24 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11850	PG0498	2017-07-20 10:15:00+03	2017-07-20 14:55:00+03	KZN	IKT	Arrived	319	2017-07-20 10:21:00+03	2017-07-20 14:59:00+03
11851	PG0498	2017-07-28 10:15:00+03	2017-07-28 14:55:00+03	KZN	IKT	Arrived	319	2017-07-28 10:19:00+03	2017-07-28 15:03:00+03
11852	PG0498	2017-08-27 10:15:00+03	2017-08-27 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11853	PG0498	2017-08-12 10:15:00+03	2017-08-12 14:55:00+03	KZN	IKT	Arrived	319	2017-08-12 10:18:00+03	2017-08-12 15:01:00+03
11854	PG0498	2017-08-13 10:15:00+03	2017-08-13 14:55:00+03	KZN	IKT	Arrived	319	2017-08-13 10:17:00+03	2017-08-13 14:54:00+03
11855	PG0498	2017-07-23 10:15:00+03	2017-07-23 14:55:00+03	KZN	IKT	Arrived	319	2017-07-23 10:20:00+03	2017-07-23 14:56:00+03
11856	PG0498	2017-09-13 10:15:00+03	2017-09-13 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11857	PG0498	2017-09-08 10:15:00+03	2017-09-08 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11858	PG0498	2017-09-14 10:15:00+03	2017-09-14 14:55:00+03	KZN	IKT	Cancelled	319	\N	\N
11859	PG0498	2017-08-19 10:15:00+03	2017-08-19 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11860	PG0498	2017-08-07 10:15:00+03	2017-08-07 14:55:00+03	KZN	IKT	Arrived	319	2017-08-07 10:17:00+03	2017-08-07 14:58:00+03
11861	PG0498	2017-08-21 10:15:00+03	2017-08-21 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11862	PG0498	2017-08-31 10:15:00+03	2017-08-31 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11863	PG0498	2017-09-06 10:15:00+03	2017-09-06 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11864	PG0498	2017-07-29 10:15:00+03	2017-07-29 14:55:00+03	KZN	IKT	Arrived	319	2017-07-29 10:19:00+03	2017-07-29 14:54:00+03
11865	PG0498	2017-07-31 10:15:00+03	2017-07-31 14:55:00+03	KZN	IKT	Arrived	319	2017-07-31 10:20:00+03	2017-07-31 15:00:00+03
11866	PG0498	2017-07-18 10:15:00+03	2017-07-18 14:55:00+03	KZN	IKT	Arrived	319	2017-07-18 10:17:00+03	2017-07-18 14:52:00+03
11867	PG0498	2017-08-08 10:15:00+03	2017-08-08 14:55:00+03	KZN	IKT	Arrived	319	2017-08-08 10:21:00+03	2017-08-08 14:57:00+03
11868	PG0498	2017-09-09 10:15:00+03	2017-09-09 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11869	PG0498	2017-08-15 10:15:00+03	2017-08-15 14:55:00+03	KZN	IKT	Arrived	319	2017-08-15 10:17:00+03	2017-08-15 14:55:00+03
11870	PG0498	2017-08-29 10:15:00+03	2017-08-29 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11871	PG0498	2017-08-04 10:15:00+03	2017-08-04 14:55:00+03	KZN	IKT	Arrived	319	2017-08-04 13:22:00+03	2017-08-04 18:01:00+03
11872	PG0498	2017-09-04 10:15:00+03	2017-09-04 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11873	PG0498	2017-08-20 10:15:00+03	2017-08-20 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11874	PG0498	2017-08-01 10:15:00+03	2017-08-01 14:55:00+03	KZN	IKT	Arrived	319	2017-08-01 10:18:00+03	2017-08-01 14:58:00+03
11875	PG0498	2017-08-23 10:15:00+03	2017-08-23 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11876	PG0498	2017-08-26 10:15:00+03	2017-08-26 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11877	PG0498	2017-07-30 10:15:00+03	2017-07-30 14:55:00+03	KZN	IKT	Arrived	319	2017-07-30 10:16:00+03	2017-07-30 14:53:00+03
11878	PG0498	2017-09-05 10:15:00+03	2017-09-05 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11879	PG0498	2017-07-25 10:15:00+03	2017-07-25 14:55:00+03	KZN	IKT	Arrived	319	2017-07-25 10:19:00+03	2017-07-25 14:59:00+03
11880	PG0498	2017-08-30 10:15:00+03	2017-08-30 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11881	PG0498	2017-09-03 10:15:00+03	2017-09-03 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11882	PG0498	2017-08-05 10:15:00+03	2017-08-05 14:55:00+03	KZN	IKT	Arrived	319	2017-08-05 10:17:00+03	2017-08-05 14:56:00+03
11883	PG0498	2017-08-17 10:15:00+03	2017-08-17 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11884	PG0498	2017-08-22 10:15:00+03	2017-08-22 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11885	PG0498	2017-07-27 10:15:00+03	2017-07-27 14:55:00+03	KZN	IKT	Arrived	319	2017-07-27 10:18:00+03	2017-07-27 14:54:00+03
11886	PG0498	2017-08-10 10:15:00+03	2017-08-10 14:55:00+03	KZN	IKT	Arrived	319	2017-08-10 10:19:00+03	2017-08-10 14:56:00+03
11887	PG0498	2017-08-06 10:15:00+03	2017-08-06 14:55:00+03	KZN	IKT	Arrived	319	2017-08-06 10:17:00+03	2017-08-06 14:56:00+03
11888	PG0498	2017-08-11 10:15:00+03	2017-08-11 14:55:00+03	KZN	IKT	Arrived	319	2017-08-11 10:20:00+03	2017-08-11 15:00:00+03
11889	PG0498	2017-07-26 10:15:00+03	2017-07-26 14:55:00+03	KZN	IKT	Arrived	319	2017-07-26 10:20:00+03	2017-07-26 15:00:00+03
11890	PG0498	2017-08-28 10:15:00+03	2017-08-28 14:55:00+03	KZN	IKT	Scheduled	319	\N	\N
11891	PG0498	2017-08-09 10:15:00+03	2017-08-09 14:55:00+03	KZN	IKT	Arrived	319	2017-08-09 10:18:00+03	2017-08-09 14:52:00+03
11892	PG0498	2017-07-16 10:15:00+03	2017-07-16 14:55:00+03	KZN	IKT	Arrived	319	2017-07-16 10:20:00+03	2017-07-16 14:58:00+03
11893	PG0525	2017-08-20 18:45:00+03	2017-08-20 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11894	PG0525	2017-09-07 18:45:00+03	2017-09-07 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11895	PG0525	2017-09-14 18:45:00+03	2017-09-14 20:45:00+03	KZN	MCX	Cancelled	CR2	\N	\N
11896	PG0525	2017-09-03 18:45:00+03	2017-09-03 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11897	PG0525	2017-08-03 18:45:00+03	2017-08-03 20:45:00+03	KZN	MCX	Arrived	CR2	2017-08-03 18:47:00+03	2017-08-03 20:48:00+03
11898	PG0525	2017-08-13 18:45:00+03	2017-08-13 20:45:00+03	KZN	MCX	Arrived	CR2	2017-08-13 18:46:00+03	2017-08-13 20:47:00+03
11899	PG0525	2017-08-27 18:45:00+03	2017-08-27 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11900	PG0525	2017-07-20 18:45:00+03	2017-07-20 20:45:00+03	KZN	MCX	Arrived	CR2	2017-07-20 22:37:00+03	2017-07-21 00:36:00+03
11901	PG0525	2017-08-06 18:45:00+03	2017-08-06 20:45:00+03	KZN	MCX	Arrived	CR2	2017-08-06 18:46:00+03	2017-08-06 20:43:00+03
11902	PG0525	2017-07-16 18:45:00+03	2017-07-16 20:45:00+03	KZN	MCX	Arrived	CR2	2017-07-16 18:46:00+03	2017-07-16 20:47:00+03
11903	PG0525	2017-07-30 18:45:00+03	2017-07-30 20:45:00+03	KZN	MCX	Arrived	CR2	2017-07-30 18:51:00+03	2017-07-30 20:49:00+03
11904	PG0525	2017-08-24 18:45:00+03	2017-08-24 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11905	PG0525	2017-08-17 18:45:00+03	2017-08-17 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11906	PG0525	2017-09-10 18:45:00+03	2017-09-10 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11907	PG0525	2017-07-23 18:45:00+03	2017-07-23 20:45:00+03	KZN	MCX	Arrived	CR2	2017-07-23 18:50:00+03	2017-07-23 20:50:00+03
11908	PG0525	2017-08-31 18:45:00+03	2017-08-31 20:45:00+03	KZN	MCX	Scheduled	CR2	\N	\N
11909	PG0525	2017-08-10 18:45:00+03	2017-08-10 20:45:00+03	KZN	MCX	Arrived	CR2	2017-08-10 18:45:00+03	2017-08-10 20:43:00+03
11910	PG0525	2017-07-27 18:45:00+03	2017-07-27 20:45:00+03	KZN	MCX	Arrived	CR2	2017-07-27 18:51:00+03	2017-07-27 20:51:00+03
11911	PG0039	2017-09-07 17:25:00+03	2017-09-07 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11912	PG0039	2017-07-21 17:25:00+03	2017-07-21 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-21 20:40:00+03	2017-07-21 21:05:00+03
11913	PG0039	2017-08-17 17:25:00+03	2017-08-17 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11914	PG0039	2017-08-18 17:25:00+03	2017-08-18 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11915	PG0039	2017-07-16 17:25:00+03	2017-07-16 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-16 17:30:00+03	2017-07-16 17:55:00+03
11916	PG0039	2017-08-01 17:25:00+03	2017-08-01 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-01 17:29:00+03	2017-08-01 17:54:00+03
11917	PG0039	2017-09-14 17:25:00+03	2017-09-14 17:50:00+03	KZN	KVX	Cancelled	SU9	\N	\N
11918	PG0039	2017-08-11 17:25:00+03	2017-08-11 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-11 17:27:00+03	2017-08-11 17:52:00+03
11919	PG0039	2017-08-30 17:25:00+03	2017-08-30 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11920	PG0039	2017-09-06 17:25:00+03	2017-09-06 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11921	PG0039	2017-09-10 17:25:00+03	2017-09-10 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11922	PG0039	2017-09-08 17:25:00+03	2017-09-08 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11923	PG0039	2017-08-29 17:25:00+03	2017-08-29 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11924	PG0039	2017-09-02 17:25:00+03	2017-09-02 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11925	PG0039	2017-08-13 17:25:00+03	2017-08-13 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-13 17:27:00+03	2017-08-13 17:52:00+03
11926	PG0039	2017-08-12 17:25:00+03	2017-08-12 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-12 17:26:00+03	2017-08-12 17:51:00+03
11927	PG0039	2017-07-27 17:25:00+03	2017-07-27 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-27 17:28:00+03	2017-07-27 17:53:00+03
11928	PG0039	2017-07-24 17:25:00+03	2017-07-24 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-24 17:30:00+03	2017-07-24 17:55:00+03
11929	PG0039	2017-08-21 17:25:00+03	2017-08-21 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11930	PG0039	2017-08-07 17:25:00+03	2017-08-07 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-07 17:27:00+03	2017-08-07 17:52:00+03
11931	PG0039	2017-08-14 17:25:00+03	2017-08-14 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-14 17:30:00+03	2017-08-14 17:55:00+03
11932	PG0039	2017-09-11 17:25:00+03	2017-09-11 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11933	PG0039	2017-08-31 17:25:00+03	2017-08-31 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11934	PG0039	2017-08-03 17:25:00+03	2017-08-03 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-03 17:29:00+03	2017-08-03 17:54:00+03
11935	PG0039	2017-09-12 17:25:00+03	2017-09-12 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11936	PG0039	2017-09-04 17:25:00+03	2017-09-04 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11937	PG0039	2017-07-29 17:25:00+03	2017-07-29 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-29 17:26:00+03	2017-07-29 17:51:00+03
11938	PG0039	2017-08-16 17:25:00+03	2017-08-16 17:50:00+03	KZN	KVX	Delayed	SU9	\N	\N
11939	PG0039	2017-08-10 17:25:00+03	2017-08-10 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-10 17:29:00+03	2017-08-10 17:54:00+03
11940	PG0039	2017-07-22 17:25:00+03	2017-07-22 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-22 17:29:00+03	2017-07-22 17:54:00+03
11941	PG0039	2017-09-09 17:25:00+03	2017-09-09 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11942	PG0039	2017-07-17 17:25:00+03	2017-07-17 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-17 17:27:00+03	2017-07-17 17:52:00+03
11943	PG0039	2017-07-31 17:25:00+03	2017-07-31 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-31 17:29:00+03	2017-07-31 17:55:00+03
11944	PG0039	2017-07-18 17:25:00+03	2017-07-18 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-18 17:35:00+03	2017-07-18 18:00:00+03
11945	PG0039	2017-07-25 17:25:00+03	2017-07-25 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-25 17:30:00+03	2017-07-25 17:55:00+03
11946	PG0039	2017-07-26 17:25:00+03	2017-07-26 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-26 17:28:00+03	2017-07-26 17:53:00+03
11947	PG0039	2017-08-15 17:25:00+03	2017-08-15 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-15 17:28:00+03	2017-08-15 17:53:00+03
11948	PG0039	2017-08-06 17:25:00+03	2017-08-06 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-06 17:25:00+03	2017-08-06 17:50:00+03
11949	PG0039	2017-08-02 17:25:00+03	2017-08-02 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-02 17:25:00+03	2017-08-02 17:50:00+03
11950	PG0039	2017-08-22 17:25:00+03	2017-08-22 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11951	PG0039	2017-07-28 17:25:00+03	2017-07-28 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-28 17:31:00+03	2017-07-28 17:56:00+03
11952	PG0039	2017-09-01 17:25:00+03	2017-09-01 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11953	PG0039	2017-08-05 17:25:00+03	2017-08-05 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-05 17:27:00+03	2017-08-05 17:52:00+03
11954	PG0039	2017-08-09 17:25:00+03	2017-08-09 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-09 17:30:00+03	2017-08-09 17:55:00+03
11955	PG0039	2017-08-19 17:25:00+03	2017-08-19 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11956	PG0039	2017-08-25 17:25:00+03	2017-08-25 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11957	PG0039	2017-08-27 17:25:00+03	2017-08-27 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11958	PG0039	2017-09-13 17:25:00+03	2017-09-13 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11959	PG0039	2017-08-04 17:25:00+03	2017-08-04 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-04 17:25:00+03	2017-08-04 17:50:00+03
11960	PG0039	2017-09-03 17:25:00+03	2017-09-03 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11961	PG0039	2017-08-24 17:25:00+03	2017-08-24 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11962	PG0039	2017-08-26 17:25:00+03	2017-08-26 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11963	PG0039	2017-08-28 17:25:00+03	2017-08-28 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11964	PG0039	2017-07-20 17:25:00+03	2017-07-20 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-20 17:29:00+03	2017-07-20 17:54:00+03
11965	PG0039	2017-07-30 17:25:00+03	2017-07-30 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-30 17:26:00+03	2017-07-30 17:51:00+03
11966	PG0039	2017-08-23 17:25:00+03	2017-08-23 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11967	PG0039	2017-07-23 17:25:00+03	2017-07-23 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-23 17:28:00+03	2017-07-23 17:53:00+03
11968	PG0039	2017-07-19 17:25:00+03	2017-07-19 17:50:00+03	KZN	KVX	Arrived	SU9	2017-07-19 17:25:00+03	2017-07-19 17:50:00+03
11969	PG0039	2017-08-20 17:25:00+03	2017-08-20 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11970	PG0039	2017-09-05 17:25:00+03	2017-09-05 17:50:00+03	KZN	KVX	Scheduled	SU9	\N	\N
11971	PG0039	2017-08-08 17:25:00+03	2017-08-08 17:50:00+03	KZN	KVX	Arrived	SU9	2017-08-08 17:29:00+03	2017-08-08 17:54:00+03
11972	PG0621	2017-08-27 16:05:00+03	2017-08-27 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11973	PG0621	2017-07-28 16:05:00+03	2017-07-28 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-28 16:07:00+03	2017-07-28 17:01:00+03
11974	PG0621	2017-09-11 16:05:00+03	2017-09-11 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11975	PG0621	2017-08-01 16:05:00+03	2017-08-01 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-01 16:06:00+03	2017-08-01 17:01:00+03
11976	PG0621	2017-08-18 16:05:00+03	2017-08-18 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11977	PG0621	2017-09-03 16:05:00+03	2017-09-03 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11978	PG0621	2017-08-10 16:05:00+03	2017-08-10 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-10 16:10:00+03	2017-08-10 17:05:00+03
11979	PG0621	2017-07-19 16:05:00+03	2017-07-19 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-19 16:06:00+03	2017-07-19 17:02:00+03
11980	PG0621	2017-09-01 16:05:00+03	2017-09-01 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11981	PG0621	2017-09-14 16:05:00+03	2017-09-14 17:00:00+03	KZN	MQF	Cancelled	CR2	\N	\N
11982	PG0621	2017-07-21 16:05:00+03	2017-07-21 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-21 16:09:00+03	2017-07-21 17:05:00+03
11983	PG0621	2017-07-31 16:05:00+03	2017-07-31 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-31 16:08:00+03	2017-07-31 17:04:00+03
11984	PG0621	2017-08-19 16:05:00+03	2017-08-19 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11985	PG0621	2017-08-28 16:05:00+03	2017-08-28 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11986	PG0621	2017-08-29 16:05:00+03	2017-08-29 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11987	PG0621	2017-08-08 16:05:00+03	2017-08-08 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-08 16:06:00+03	2017-08-08 17:01:00+03
11988	PG0621	2017-09-10 16:05:00+03	2017-09-10 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11989	PG0621	2017-07-18 16:05:00+03	2017-07-18 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-18 16:06:00+03	2017-07-18 17:01:00+03
11990	PG0621	2017-07-20 16:05:00+03	2017-07-20 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-20 16:12:00+03	2017-07-20 17:06:00+03
11991	PG0621	2017-08-25 16:05:00+03	2017-08-25 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11992	PG0621	2017-08-12 16:05:00+03	2017-08-12 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-12 16:10:00+03	2017-08-12 17:05:00+03
11993	PG0621	2017-08-03 16:05:00+03	2017-08-03 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-03 16:07:00+03	2017-08-03 17:02:00+03
11994	PG0621	2017-08-06 16:05:00+03	2017-08-06 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-06 16:08:00+03	2017-08-06 17:03:00+03
11995	PG0621	2017-07-27 16:05:00+03	2017-07-27 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-27 16:08:00+03	2017-07-27 17:03:00+03
11996	PG0621	2017-09-04 16:05:00+03	2017-09-04 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11997	PG0621	2017-07-24 16:05:00+03	2017-07-24 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-24 16:09:00+03	2017-07-24 17:03:00+03
11998	PG0621	2017-09-12 16:05:00+03	2017-09-12 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
11999	PG0621	2017-09-07 16:05:00+03	2017-09-07 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12000	PG0621	2017-09-05 16:05:00+03	2017-09-05 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12001	PG0621	2017-08-31 16:05:00+03	2017-08-31 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12002	PG0621	2017-07-16 16:05:00+03	2017-07-16 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-16 16:11:00+03	2017-07-16 17:07:00+03
12003	PG0621	2017-08-04 16:05:00+03	2017-08-04 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-04 16:09:00+03	2017-08-04 17:04:00+03
12004	PG0621	2017-08-24 16:05:00+03	2017-08-24 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12005	PG0621	2017-09-02 16:05:00+03	2017-09-02 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12006	PG0621	2017-08-21 16:05:00+03	2017-08-21 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12007	PG0621	2017-07-22 16:05:00+03	2017-07-22 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-22 18:55:00+03	2017-07-22 19:50:00+03
12008	PG0621	2017-07-25 16:05:00+03	2017-07-25 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-25 16:09:00+03	2017-07-25 17:04:00+03
12009	PG0621	2017-08-13 16:05:00+03	2017-08-13 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-13 16:09:00+03	2017-08-13 17:04:00+03
12010	PG0621	2017-08-22 16:05:00+03	2017-08-22 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12011	PG0621	2017-07-29 16:05:00+03	2017-07-29 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-29 16:06:00+03	2017-07-29 17:00:00+03
12013	PG0621	2017-08-02 16:05:00+03	2017-08-02 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-02 16:06:00+03	2017-08-02 17:00:00+03
12014	PG0621	2017-08-14 16:05:00+03	2017-08-14 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-14 16:07:00+03	2017-08-14 17:02:00+03
12015	PG0621	2017-07-23 16:05:00+03	2017-07-23 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-23 16:07:00+03	2017-07-23 17:02:00+03
12016	PG0621	2017-09-09 16:05:00+03	2017-09-09 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12017	PG0621	2017-08-05 16:05:00+03	2017-08-05 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-05 16:14:00+03	2017-08-05 17:09:00+03
12018	PG0621	2017-09-08 16:05:00+03	2017-09-08 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12019	PG0621	2017-08-30 16:05:00+03	2017-08-30 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12020	PG0621	2017-09-06 16:05:00+03	2017-09-06 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12021	PG0621	2017-08-17 16:05:00+03	2017-08-17 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12022	PG0621	2017-08-20 16:05:00+03	2017-08-20 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12023	PG0621	2017-08-07 16:05:00+03	2017-08-07 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-07 16:06:00+03	2017-08-07 17:01:00+03
12024	PG0621	2017-07-30 16:05:00+03	2017-07-30 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-30 19:33:00+03	2017-07-30 20:28:00+03
12025	PG0621	2017-08-16 16:05:00+03	2017-08-16 17:00:00+03	KZN	MQF	On Time	CR2	\N	\N
12026	PG0621	2017-08-11 16:05:00+03	2017-08-11 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-11 16:08:00+03	2017-08-11 17:04:00+03
12027	PG0621	2017-08-23 16:05:00+03	2017-08-23 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12028	PG0621	2017-07-26 16:05:00+03	2017-07-26 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-26 16:11:00+03	2017-07-26 17:05:00+03
12029	PG0621	2017-08-15 16:05:00+03	2017-08-15 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-15 16:09:00+03	2017-08-15 17:04:00+03
12030	PG0621	2017-07-17 16:05:00+03	2017-07-17 17:00:00+03	KZN	MQF	Arrived	CR2	2017-07-17 16:10:00+03	2017-07-17 17:06:00+03
12031	PG0621	2017-09-13 16:05:00+03	2017-09-13 17:00:00+03	KZN	MQF	Scheduled	CR2	\N	\N
12032	PG0621	2017-08-09 16:05:00+03	2017-08-09 17:00:00+03	KZN	MQF	Arrived	CR2	2017-08-09 16:09:00+03	2017-08-09 17:04:00+03
12033	PG0274	2017-08-07 15:50:00+03	2017-08-07 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-07 15:53:00+03	2017-08-07 17:56:00+03
12034	PG0274	2017-08-02 15:50:00+03	2017-08-02 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-02 15:53:00+03	2017-08-02 17:52:00+03
12035	PG0274	2017-08-01 15:50:00+03	2017-08-01 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-01 15:55:00+03	2017-08-01 17:54:00+03
12036	PG0274	2017-09-07 15:50:00+03	2017-09-07 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12037	PG0274	2017-08-22 15:50:00+03	2017-08-22 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12038	PG0274	2017-08-19 15:50:00+03	2017-08-19 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12039	PG0274	2017-08-29 15:50:00+03	2017-08-29 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12040	PG0274	2017-08-21 15:50:00+03	2017-08-21 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12041	PG0274	2017-08-14 15:50:00+03	2017-08-14 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-14 15:53:00+03	2017-08-14 17:53:00+03
12042	PG0274	2017-08-25 15:50:00+03	2017-08-25 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12043	PG0274	2017-08-17 15:50:00+03	2017-08-17 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12044	PG0274	2017-08-31 15:50:00+03	2017-08-31 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12045	PG0274	2017-09-06 15:50:00+03	2017-09-06 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12046	PG0274	2017-08-15 15:50:00+03	2017-08-15 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-15 15:56:00+03	2017-08-15 17:55:00+03
12047	PG0274	2017-09-04 15:50:00+03	2017-09-04 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12048	PG0274	2017-08-20 15:50:00+03	2017-08-20 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12049	PG0274	2017-09-10 15:50:00+03	2017-09-10 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12050	PG0274	2017-09-01 15:50:00+03	2017-09-01 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12051	PG0274	2017-09-11 15:50:00+03	2017-09-11 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12052	PG0274	2017-09-08 15:50:00+03	2017-09-08 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12053	PG0274	2017-08-24 15:50:00+03	2017-08-24 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12054	PG0274	2017-08-06 15:50:00+03	2017-08-06 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-06 15:52:00+03	2017-08-06 17:52:00+03
12055	PG0274	2017-08-13 15:50:00+03	2017-08-13 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-13 15:52:00+03	2017-08-13 17:53:00+03
12056	PG0274	2017-08-23 15:50:00+03	2017-08-23 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12057	PG0274	2017-08-27 15:50:00+03	2017-08-27 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12058	PG0274	2017-09-03 15:50:00+03	2017-09-03 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12059	PG0274	2017-09-02 15:50:00+03	2017-09-02 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12060	PG0274	2017-07-31 15:50:00+03	2017-07-31 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-31 15:55:00+03	2017-07-31 17:55:00+03
12061	PG0274	2017-07-23 15:50:00+03	2017-07-23 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-23 15:54:00+03	2017-07-23 17:55:00+03
12062	PG0274	2017-07-24 15:50:00+03	2017-07-24 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-24 15:55:00+03	2017-07-24 17:54:00+03
12063	PG0274	2017-07-20 15:50:00+03	2017-07-20 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-20 15:52:00+03	2017-07-20 17:52:00+03
12064	PG0274	2017-07-17 15:50:00+03	2017-07-17 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-17 15:53:00+03	2017-07-17 17:52:00+03
12065	PG0274	2017-08-16 15:50:00+03	2017-08-16 17:50:00+03	CEK	DME	On Time	SU9	\N	\N
12066	PG0274	2017-08-03 15:50:00+03	2017-08-03 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-03 15:55:00+03	2017-08-03 17:55:00+03
12067	PG0274	2017-09-09 15:50:00+03	2017-09-09 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12068	PG0274	2017-08-08 15:50:00+03	2017-08-08 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-08 15:52:00+03	2017-08-08 17:52:00+03
12069	PG0274	2017-08-28 15:50:00+03	2017-08-28 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12070	PG0274	2017-08-30 15:50:00+03	2017-08-30 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12071	PG0274	2017-09-14 15:50:00+03	2017-09-14 17:50:00+03	CEK	DME	Cancelled	SU9	\N	\N
12072	PG0274	2017-07-22 15:50:00+03	2017-07-22 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-22 15:56:00+03	2017-07-22 17:56:00+03
12073	PG0274	2017-09-13 15:50:00+03	2017-09-13 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12074	PG0274	2017-07-19 15:50:00+03	2017-07-19 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-19 15:53:00+03	2017-07-19 17:51:00+03
12075	PG0274	2017-08-18 15:50:00+03	2017-08-18 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12076	PG0274	2017-07-16 15:50:00+03	2017-07-16 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-16 15:54:00+03	2017-07-16 17:54:00+03
12077	PG0274	2017-08-09 15:50:00+03	2017-08-09 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-09 15:54:00+03	2017-08-09 17:53:00+03
12078	PG0274	2017-09-12 15:50:00+03	2017-09-12 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12079	PG0274	2017-07-21 15:50:00+03	2017-07-21 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-21 15:50:00+03	2017-07-21 17:52:00+03
12080	PG0274	2017-07-30 15:50:00+03	2017-07-30 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-30 15:53:00+03	2017-07-30 17:54:00+03
12081	PG0274	2017-08-04 15:50:00+03	2017-08-04 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-04 15:53:00+03	2017-08-04 17:55:00+03
12082	PG0274	2017-07-28 15:50:00+03	2017-07-28 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-28 15:51:00+03	2017-07-28 17:51:00+03
12083	PG0274	2017-07-25 15:50:00+03	2017-07-25 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-25 15:51:00+03	2017-07-25 17:50:00+03
12084	PG0274	2017-08-12 15:50:00+03	2017-08-12 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-12 15:52:00+03	2017-08-12 17:53:00+03
12085	PG0274	2017-07-18 15:50:00+03	2017-07-18 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-18 15:58:00+03	2017-07-18 17:58:00+03
12086	PG0274	2017-08-10 15:50:00+03	2017-08-10 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-10 15:52:00+03	2017-08-10 17:53:00+03
12087	PG0274	2017-07-26 15:50:00+03	2017-07-26 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-26 15:52:00+03	2017-07-26 17:56:00+03
12088	PG0274	2017-08-11 15:50:00+03	2017-08-11 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-11 15:53:00+03	2017-08-11 17:50:00+03
12089	PG0274	2017-07-29 15:50:00+03	2017-07-29 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-29 15:54:00+03	2017-07-29 17:54:00+03
12090	PG0274	2017-08-26 15:50:00+03	2017-08-26 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12091	PG0274	2017-07-27 15:50:00+03	2017-07-27 17:50:00+03	CEK	DME	Arrived	SU9	2017-07-27 15:51:00+03	2017-07-27 17:52:00+03
12092	PG0274	2017-09-05 15:50:00+03	2017-09-05 17:50:00+03	CEK	DME	Scheduled	SU9	\N	\N
12093	PG0274	2017-08-05 15:50:00+03	2017-08-05 17:50:00+03	CEK	DME	Arrived	SU9	2017-08-05 15:54:00+03	2017-08-05 17:55:00+03
12094	PG0675	2017-09-01 11:40:00+03	2017-09-01 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12095	PG0675	2017-08-12 11:40:00+03	2017-08-12 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-12 11:41:00+03	2017-08-12 12:21:00+03
12096	PG0675	2017-07-16 11:40:00+03	2017-07-16 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-16 11:46:00+03	2017-07-16 12:26:00+03
12097	PG0675	2017-07-17 11:40:00+03	2017-07-17 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-17 11:42:00+03	2017-07-17 12:22:00+03
12098	PG0675	2017-07-22 11:40:00+03	2017-07-22 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-22 11:43:00+03	2017-07-22 12:22:00+03
12099	PG0675	2017-09-02 11:40:00+03	2017-09-02 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12100	PG0675	2017-08-09 11:40:00+03	2017-08-09 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-09 14:58:00+03	2017-08-09 15:38:00+03
12101	PG0675	2017-08-08 11:40:00+03	2017-08-08 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-08 14:46:00+03	2017-08-08 15:26:00+03
12102	PG0675	2017-08-16 11:40:00+03	2017-08-16 12:20:00+03	CEK	PEE	On Time	CR2	\N	\N
12103	PG0675	2017-08-30 11:40:00+03	2017-08-30 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12104	PG0675	2017-08-07 11:40:00+03	2017-08-07 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-07 11:46:00+03	2017-08-07 12:26:00+03
12105	PG0675	2017-08-15 11:40:00+03	2017-08-15 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-15 11:43:00+03	2017-08-15 12:22:00+03
12106	PG0675	2017-08-02 11:40:00+03	2017-08-02 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-02 11:44:00+03	2017-08-02 12:24:00+03
12107	PG0675	2017-07-24 11:40:00+03	2017-07-24 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-24 11:41:00+03	2017-07-24 12:21:00+03
12108	PG0675	2017-09-14 11:40:00+03	2017-09-14 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12109	PG0675	2017-08-17 11:40:00+03	2017-08-17 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12110	PG0675	2017-09-11 11:40:00+03	2017-09-11 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12111	PG0675	2017-08-27 11:40:00+03	2017-08-27 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12112	PG0675	2017-09-10 11:40:00+03	2017-09-10 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12113	PG0675	2017-07-23 11:40:00+03	2017-07-23 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-23 11:43:00+03	2017-07-23 12:23:00+03
12114	PG0675	2017-08-05 11:40:00+03	2017-08-05 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-05 11:42:00+03	2017-08-05 12:22:00+03
12115	PG0675	2017-07-19 11:40:00+03	2017-07-19 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-19 11:41:00+03	2017-07-19 12:22:00+03
12116	PG0675	2017-07-25 11:40:00+03	2017-07-25 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-25 11:40:00+03	2017-07-25 12:19:00+03
12117	PG0675	2017-09-09 11:40:00+03	2017-09-09 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12118	PG0675	2017-08-06 11:40:00+03	2017-08-06 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-06 11:45:00+03	2017-08-06 12:25:00+03
12119	PG0675	2017-08-04 11:40:00+03	2017-08-04 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-04 11:42:00+03	2017-08-04 12:23:00+03
12120	PG0675	2017-09-04 11:40:00+03	2017-09-04 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12121	PG0675	2017-08-18 11:40:00+03	2017-08-18 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12122	PG0675	2017-08-29 11:40:00+03	2017-08-29 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12123	PG0675	2017-08-23 11:40:00+03	2017-08-23 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12124	PG0675	2017-08-28 11:40:00+03	2017-08-28 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12125	PG0675	2017-07-21 11:40:00+03	2017-07-21 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-21 11:46:00+03	2017-07-21 12:26:00+03
12126	PG0675	2017-08-25 11:40:00+03	2017-08-25 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12127	PG0675	2017-08-03 11:40:00+03	2017-08-03 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-03 11:44:00+03	2017-08-03 12:24:00+03
12128	PG0675	2017-08-31 11:40:00+03	2017-08-31 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12129	PG0675	2017-09-08 11:40:00+03	2017-09-08 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12130	PG0675	2017-08-21 11:40:00+03	2017-08-21 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12131	PG0675	2017-07-26 11:40:00+03	2017-07-26 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-26 11:46:00+03	2017-07-26 12:26:00+03
12132	PG0675	2017-07-31 11:40:00+03	2017-07-31 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-31 11:42:00+03	2017-07-31 12:21:00+03
12133	PG0675	2017-08-13 11:40:00+03	2017-08-13 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-13 11:42:00+03	2017-08-13 12:21:00+03
12134	PG0675	2017-08-10 11:40:00+03	2017-08-10 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-10 11:43:00+03	2017-08-10 12:23:00+03
12135	PG0675	2017-08-11 11:40:00+03	2017-08-11 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-11 11:44:00+03	2017-08-11 12:24:00+03
12136	PG0675	2017-07-20 11:40:00+03	2017-07-20 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-20 11:43:00+03	2017-07-20 12:23:00+03
12137	PG0675	2017-07-30 11:40:00+03	2017-07-30 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-30 11:42:00+03	2017-07-30 12:22:00+03
12138	PG0675	2017-07-27 11:40:00+03	2017-07-27 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-27 11:44:00+03	2017-07-27 12:24:00+03
12139	PG0675	2017-08-01 11:40:00+03	2017-08-01 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-01 11:42:00+03	2017-08-01 12:22:00+03
12140	PG0675	2017-09-06 11:40:00+03	2017-09-06 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12141	PG0675	2017-08-22 11:40:00+03	2017-08-22 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12142	PG0675	2017-08-19 11:40:00+03	2017-08-19 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12143	PG0675	2017-07-18 11:40:00+03	2017-07-18 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-18 11:46:00+03	2017-07-18 12:25:00+03
12144	PG0675	2017-09-13 11:40:00+03	2017-09-13 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12145	PG0675	2017-08-14 11:40:00+03	2017-08-14 12:20:00+03	CEK	PEE	Arrived	CR2	2017-08-14 11:43:00+03	2017-08-14 12:23:00+03
12146	PG0675	2017-07-29 11:40:00+03	2017-07-29 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-29 11:45:00+03	2017-07-29 12:25:00+03
12147	PG0675	2017-09-05 11:40:00+03	2017-09-05 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12148	PG0675	2017-09-03 11:40:00+03	2017-09-03 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12149	PG0675	2017-08-20 11:40:00+03	2017-08-20 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12150	PG0675	2017-08-24 11:40:00+03	2017-08-24 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12151	PG0675	2017-07-28 11:40:00+03	2017-07-28 12:20:00+03	CEK	PEE	Arrived	CR2	2017-07-28 11:43:00+03	2017-07-28 12:23:00+03
12152	PG0675	2017-09-07 11:40:00+03	2017-09-07 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12153	PG0675	2017-09-12 11:40:00+03	2017-09-12 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12154	PG0675	2017-08-26 11:40:00+03	2017-08-26 12:20:00+03	CEK	PEE	Scheduled	CR2	\N	\N
12155	PG0184	2017-07-22 18:50:00+03	2017-07-22 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-22 18:54:00+03	2017-07-22 20:44:00+03
12156	PG0184	2017-08-14 18:50:00+03	2017-08-14 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-14 18:53:00+03	2017-08-14 20:43:00+03
12157	PG0184	2017-08-05 18:50:00+03	2017-08-05 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-05 18:56:00+03	2017-08-05 20:47:00+03
12158	PG0184	2017-08-29 18:50:00+03	2017-08-29 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12159	PG0184	2017-07-25 18:50:00+03	2017-07-25 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-25 18:51:00+03	2017-07-25 20:41:00+03
12160	PG0184	2017-08-06 18:50:00+03	2017-08-06 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-06 18:53:00+03	2017-08-06 20:43:00+03
12161	PG0184	2017-09-02 18:50:00+03	2017-09-02 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12162	PG0184	2017-08-19 18:50:00+03	2017-08-19 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12163	PG0184	2017-08-21 18:50:00+03	2017-08-21 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12164	PG0184	2017-07-27 18:50:00+03	2017-07-27 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-27 18:53:00+03	2017-07-27 20:43:00+03
12165	PG0184	2017-08-03 18:50:00+03	2017-08-03 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-03 18:52:00+03	2017-08-03 20:43:00+03
12166	PG0184	2017-09-14 18:50:00+03	2017-09-14 20:40:00+03	CEK	VOG	Cancelled	SU9	\N	\N
12167	PG0184	2017-07-20 18:50:00+03	2017-07-20 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-20 18:54:00+03	2017-07-20 20:46:00+03
12168	PG0184	2017-07-19 18:50:00+03	2017-07-19 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-19 18:52:00+03	2017-07-19 20:42:00+03
12169	PG0184	2017-08-12 18:50:00+03	2017-08-12 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-12 18:54:00+03	2017-08-12 20:45:00+03
12170	PG0184	2017-09-11 18:50:00+03	2017-09-11 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12171	PG0184	2017-08-07 18:50:00+03	2017-08-07 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-07 18:52:00+03	2017-08-07 20:41:00+03
12172	PG0184	2017-07-26 18:50:00+03	2017-07-26 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-26 18:53:00+03	2017-07-26 20:44:00+03
12173	PG0184	2017-08-18 18:50:00+03	2017-08-18 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12174	PG0184	2017-07-18 18:50:00+03	2017-07-18 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-18 21:36:00+03	2017-07-18 23:25:00+03
12175	PG0184	2017-09-04 18:50:00+03	2017-09-04 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12176	PG0184	2017-08-22 18:50:00+03	2017-08-22 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12177	PG0184	2017-08-20 18:50:00+03	2017-08-20 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12178	PG0184	2017-09-08 18:50:00+03	2017-09-08 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12179	PG0184	2017-08-24 18:50:00+03	2017-08-24 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12180	PG0184	2017-09-13 18:50:00+03	2017-09-13 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12181	PG0184	2017-08-09 18:50:00+03	2017-08-09 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-09 18:51:00+03	2017-08-09 20:40:00+03
12182	PG0184	2017-09-12 18:50:00+03	2017-09-12 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12183	PG0184	2017-08-23 18:50:00+03	2017-08-23 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12184	PG0184	2017-07-24 18:50:00+03	2017-07-24 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-24 18:53:00+03	2017-07-24 20:42:00+03
12185	PG0184	2017-08-15 18:50:00+03	2017-08-15 20:40:00+03	CEK	VOG	On Time	SU9	\N	\N
12186	PG0184	2017-08-31 18:50:00+03	2017-08-31 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12187	PG0184	2017-09-10 18:50:00+03	2017-09-10 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12188	PG0184	2017-07-28 18:50:00+03	2017-07-28 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-28 18:53:00+03	2017-07-28 20:43:00+03
12189	PG0184	2017-07-30 18:50:00+03	2017-07-30 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-30 21:59:00+03	2017-07-30 23:49:00+03
12190	PG0184	2017-08-26 18:50:00+03	2017-08-26 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12191	PG0184	2017-08-25 18:50:00+03	2017-08-25 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12192	PG0184	2017-08-13 18:50:00+03	2017-08-13 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-13 18:56:00+03	2017-08-13 20:47:00+03
12193	PG0184	2017-07-23 18:50:00+03	2017-07-23 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-23 18:53:00+03	2017-07-23 20:44:00+03
12194	PG0184	2017-07-31 18:50:00+03	2017-07-31 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-31 18:52:00+03	2017-07-31 20:42:00+03
12195	PG0184	2017-09-05 18:50:00+03	2017-09-05 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12196	PG0184	2017-08-30 18:50:00+03	2017-08-30 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12197	PG0184	2017-07-17 18:50:00+03	2017-07-17 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-17 18:56:00+03	2017-07-17 20:47:00+03
12198	PG0184	2017-09-09 18:50:00+03	2017-09-09 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12199	PG0184	2017-08-16 18:50:00+03	2017-08-16 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12200	PG0184	2017-09-07 18:50:00+03	2017-09-07 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12201	PG0184	2017-08-04 18:50:00+03	2017-08-04 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-04 18:53:00+03	2017-08-04 20:43:00+03
12202	PG0184	2017-08-28 18:50:00+03	2017-08-28 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12203	PG0184	2017-09-03 18:50:00+03	2017-09-03 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12204	PG0184	2017-08-27 18:50:00+03	2017-08-27 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12205	PG0184	2017-08-11 18:50:00+03	2017-08-11 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-11 18:54:00+03	2017-08-11 20:43:00+03
12206	PG0184	2017-07-21 18:50:00+03	2017-07-21 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-21 21:50:00+03	2017-07-21 23:39:00+03
12207	PG0184	2017-08-17 18:50:00+03	2017-08-17 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12208	PG0184	2017-08-10 18:50:00+03	2017-08-10 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-10 18:52:00+03	2017-08-10 20:42:00+03
12209	PG0184	2017-09-01 18:50:00+03	2017-09-01 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12210	PG0184	2017-09-06 18:50:00+03	2017-09-06 20:40:00+03	CEK	VOG	Scheduled	SU9	\N	\N
12211	PG0184	2017-07-16 18:50:00+03	2017-07-16 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-16 18:58:00+03	2017-07-16 20:49:00+03
12212	PG0184	2017-08-08 18:50:00+03	2017-08-08 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-08 18:56:00+03	2017-08-08 20:46:00+03
12213	PG0184	2017-08-02 18:50:00+03	2017-08-02 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-02 18:54:00+03	2017-08-02 20:44:00+03
12214	PG0184	2017-07-29 18:50:00+03	2017-07-29 20:40:00+03	CEK	VOG	Arrived	SU9	2017-07-29 18:50:00+03	2017-07-29 20:39:00+03
12215	PG0184	2017-08-01 18:50:00+03	2017-08-01 20:40:00+03	CEK	VOG	Arrived	SU9	2017-08-01 18:57:00+03	2017-08-01 20:47:00+03
12216	PG0097	2017-08-08 09:30:00+03	2017-08-08 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-08 09:32:00+03	2017-08-08 13:15:00+03
12217	PG0097	2017-08-23 09:30:00+03	2017-08-23 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12218	PG0097	2017-08-31 09:30:00+03	2017-08-31 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12219	PG0097	2017-08-14 09:30:00+03	2017-08-14 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-14 09:34:00+03	2017-08-14 13:16:00+03
12220	PG0097	2017-08-19 09:30:00+03	2017-08-19 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12221	PG0097	2017-07-27 09:30:00+03	2017-07-27 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-27 12:36:00+03	2017-07-27 16:20:00+03
12222	PG0097	2017-08-10 09:30:00+03	2017-08-10 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-10 09:35:00+03	2017-08-10 13:15:00+03
12223	PG0097	2017-07-24 09:30:00+03	2017-07-24 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-24 09:34:00+03	2017-07-24 13:14:00+03
12224	PG0097	2017-09-05 09:30:00+03	2017-09-05 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12225	PG0097	2017-08-03 09:30:00+03	2017-08-03 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-03 09:36:00+03	2017-08-03 13:16:00+03
12226	PG0097	2017-09-07 09:30:00+03	2017-09-07 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12227	PG0097	2017-08-07 09:30:00+03	2017-08-07 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-07 09:33:00+03	2017-08-07 13:15:00+03
12228	PG0097	2017-09-11 09:30:00+03	2017-09-11 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12229	PG0097	2017-08-30 09:30:00+03	2017-08-30 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12230	PG0097	2017-08-02 09:30:00+03	2017-08-02 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-02 09:33:00+03	2017-08-02 13:14:00+03
12231	PG0097	2017-09-10 09:30:00+03	2017-09-10 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12232	PG0097	2017-08-22 09:30:00+03	2017-08-22 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12233	PG0097	2017-07-28 09:30:00+03	2017-07-28 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-28 09:31:00+03	2017-07-28 13:09:00+03
12234	PG0097	2017-07-22 09:30:00+03	2017-07-22 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-22 09:32:00+03	2017-07-22 13:16:00+03
12235	PG0097	2017-07-29 09:30:00+03	2017-07-29 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-29 09:33:00+03	2017-07-29 13:16:00+03
12236	PG0097	2017-08-25 09:30:00+03	2017-08-25 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12237	PG0097	2017-08-15 09:30:00+03	2017-08-15 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-15 09:33:00+03	2017-08-15 13:10:00+03
12238	PG0097	2017-08-11 09:30:00+03	2017-08-11 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-11 09:33:00+03	2017-08-11 13:15:00+03
12239	PG0097	2017-08-16 09:30:00+03	2017-08-16 13:10:00+03	CEK	SWT	On Time	CN1	\N	\N
12240	PG0097	2017-07-16 09:30:00+03	2017-07-16 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-16 09:33:00+03	2017-07-16 13:13:00+03
12241	PG0097	2017-08-21 09:30:00+03	2017-08-21 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12242	PG0097	2017-09-13 09:30:00+03	2017-09-13 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12243	PG0097	2017-07-17 09:30:00+03	2017-07-17 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-17 09:36:00+03	2017-07-17 13:14:00+03
12244	PG0097	2017-07-31 09:30:00+03	2017-07-31 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-31 09:35:00+03	2017-07-31 13:14:00+03
12245	PG0097	2017-08-28 09:30:00+03	2017-08-28 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12246	PG0097	2017-07-20 09:30:00+03	2017-07-20 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-20 09:32:00+03	2017-07-20 13:16:00+03
12247	PG0097	2017-08-17 09:30:00+03	2017-08-17 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12248	PG0097	2017-08-01 09:30:00+03	2017-08-01 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-01 09:33:00+03	2017-08-01 13:13:00+03
12249	PG0097	2017-09-06 09:30:00+03	2017-09-06 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12250	PG0097	2017-07-26 09:30:00+03	2017-07-26 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-26 09:35:00+03	2017-07-26 13:17:00+03
12251	PG0097	2017-08-09 09:30:00+03	2017-08-09 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-09 09:34:00+03	2017-08-09 13:13:00+03
12252	PG0097	2017-09-08 09:30:00+03	2017-09-08 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12253	PG0097	2017-08-24 09:30:00+03	2017-08-24 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12254	PG0097	2017-08-12 09:30:00+03	2017-08-12 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-12 09:32:00+03	2017-08-12 13:13:00+03
12255	PG0097	2017-07-19 09:30:00+03	2017-07-19 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-19 12:54:00+03	2017-07-19 16:38:00+03
12256	PG0097	2017-08-20 09:30:00+03	2017-08-20 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12257	PG0097	2017-07-23 09:30:00+03	2017-07-23 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-23 09:34:00+03	2017-07-23 13:12:00+03
12258	PG0097	2017-08-27 09:30:00+03	2017-08-27 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12259	PG0097	2017-09-14 09:30:00+03	2017-09-14 13:10:00+03	CEK	SWT	Cancelled	CN1	\N	\N
12260	PG0097	2017-07-21 09:30:00+03	2017-07-21 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-21 09:33:00+03	2017-07-21 13:14:00+03
12261	PG0097	2017-08-26 09:30:00+03	2017-08-26 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12262	PG0097	2017-08-04 09:30:00+03	2017-08-04 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-04 09:32:00+03	2017-08-04 13:11:00+03
12263	PG0097	2017-08-13 09:30:00+03	2017-08-13 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-13 09:31:00+03	2017-08-13 13:09:00+03
12264	PG0097	2017-09-09 09:30:00+03	2017-09-09 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12265	PG0097	2017-07-18 09:30:00+03	2017-07-18 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-18 09:33:00+03	2017-07-18 13:11:00+03
12266	PG0097	2017-07-25 09:30:00+03	2017-07-25 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-25 09:35:00+03	2017-07-25 13:13:00+03
12267	PG0097	2017-09-03 09:30:00+03	2017-09-03 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12268	PG0097	2017-09-12 09:30:00+03	2017-09-12 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12269	PG0097	2017-08-29 09:30:00+03	2017-08-29 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12270	PG0097	2017-08-05 09:30:00+03	2017-08-05 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-05 09:32:00+03	2017-08-05 13:12:00+03
12271	PG0097	2017-07-30 09:30:00+03	2017-07-30 13:10:00+03	CEK	SWT	Arrived	CN1	2017-07-30 09:31:00+03	2017-07-30 13:15:00+03
12272	PG0097	2017-08-18 09:30:00+03	2017-08-18 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12273	PG0097	2017-09-01 09:30:00+03	2017-09-01 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12274	PG0097	2017-09-02 09:30:00+03	2017-09-02 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12275	PG0097	2017-09-04 09:30:00+03	2017-09-04 13:10:00+03	CEK	SWT	Scheduled	CN1	\N	\N
12276	PG0097	2017-08-06 09:30:00+03	2017-08-06 13:10:00+03	CEK	SWT	Arrived	CN1	2017-08-06 09:32:00+03	2017-08-06 13:16:00+03
12277	PG0545	2017-08-08 07:55:00+03	2017-08-08 11:40:00+03	CEK	IKT	Arrived	SU9	2017-08-08 08:02:00+03	2017-08-08 11:44:00+03
12278	PG0545	2017-08-12 07:55:00+03	2017-08-12 11:40:00+03	CEK	IKT	Arrived	SU9	2017-08-12 10:53:00+03	2017-08-12 14:40:00+03
12279	PG0545	2017-08-26 07:55:00+03	2017-08-26 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12280	PG0545	2017-09-09 07:55:00+03	2017-09-09 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12281	PG0545	2017-08-29 07:55:00+03	2017-08-29 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12282	PG0545	2017-08-05 07:55:00+03	2017-08-05 11:40:00+03	CEK	IKT	Arrived	SU9	2017-08-05 08:00:00+03	2017-08-05 11:43:00+03
12283	PG0545	2017-07-25 07:55:00+03	2017-07-25 11:40:00+03	CEK	IKT	Arrived	SU9	2017-07-25 07:59:00+03	2017-07-25 11:48:00+03
12284	PG0545	2017-07-29 07:55:00+03	2017-07-29 11:40:00+03	CEK	IKT	Arrived	SU9	2017-07-29 08:02:00+03	2017-07-29 11:46:00+03
12285	PG0545	2017-07-18 07:55:00+03	2017-07-18 11:40:00+03	CEK	IKT	Arrived	SU9	2017-07-18 07:59:00+03	2017-07-18 11:46:00+03
12286	PG0545	2017-08-15 07:55:00+03	2017-08-15 11:40:00+03	CEK	IKT	Arrived	SU9	2017-08-15 07:59:00+03	2017-08-15 11:46:00+03
12287	PG0545	2017-09-02 07:55:00+03	2017-09-02 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12288	PG0545	2017-09-05 07:55:00+03	2017-09-05 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12289	PG0545	2017-08-22 07:55:00+03	2017-08-22 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12290	PG0545	2017-08-01 07:55:00+03	2017-08-01 11:40:00+03	CEK	IKT	Arrived	SU9	2017-08-01 07:56:00+03	2017-08-01 11:41:00+03
12291	PG0545	2017-08-19 07:55:00+03	2017-08-19 11:40:00+03	CEK	IKT	Scheduled	SU9	\N	\N
12292	PG0545	2017-09-12 07:55:00+03	2017-09-12 11:40:00+03	CEK	IKT	Cancelled	SU9	\N	\N
12293	PG0545	2017-07-22 07:55:00+03	2017-07-22 11:40:00+03	CEK	IKT	Arrived	SU9	2017-07-22 07:57:00+03	2017-07-22 11:45:00+03
12294	PG0259	2017-09-11 12:30:00+03	2017-09-11 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12295	PG0259	2017-09-04 12:30:00+03	2017-09-04 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12296	PG0259	2017-08-02 12:30:00+03	2017-08-02 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-02 12:31:00+03	2017-08-02 15:05:00+03
12297	PG0259	2017-07-17 12:30:00+03	2017-07-17 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-17 12:34:00+03	2017-07-17 15:05:00+03
12298	PG0259	2017-08-12 12:30:00+03	2017-08-12 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-12 15:08:00+03	2017-08-12 17:37:00+03
12299	PG0259	2017-07-31 12:30:00+03	2017-07-31 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-31 12:31:00+03	2017-07-31 15:01:00+03
12300	PG0259	2017-08-09 12:30:00+03	2017-08-09 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-09 12:32:00+03	2017-08-09 15:02:00+03
12301	PG0259	2017-08-30 12:30:00+03	2017-08-30 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12302	PG0259	2017-07-24 12:30:00+03	2017-07-24 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-24 12:33:00+03	2017-07-24 15:03:00+03
12303	PG0259	2017-07-22 12:30:00+03	2017-07-22 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-22 12:31:00+03	2017-07-22 15:01:00+03
12304	PG0259	2017-07-19 12:30:00+03	2017-07-19 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-19 12:36:00+03	2017-07-19 15:07:00+03
12305	PG0259	2017-07-29 12:30:00+03	2017-07-29 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-29 12:34:00+03	2017-07-29 15:05:00+03
12306	PG0259	2017-09-02 12:30:00+03	2017-09-02 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12307	PG0259	2017-08-28 12:30:00+03	2017-08-28 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12308	PG0259	2017-09-09 12:30:00+03	2017-09-09 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12309	PG0259	2017-08-23 12:30:00+03	2017-08-23 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12310	PG0259	2017-07-26 12:30:00+03	2017-07-26 15:00:00+03	CEK	STW	Arrived	CR2	2017-07-26 12:32:00+03	2017-07-26 15:04:00+03
12311	PG0259	2017-09-06 12:30:00+03	2017-09-06 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12312	PG0259	2017-08-05 12:30:00+03	2017-08-05 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-05 12:33:00+03	2017-08-05 15:04:00+03
12313	PG0259	2017-08-21 12:30:00+03	2017-08-21 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12314	PG0259	2017-08-16 12:30:00+03	2017-08-16 15:00:00+03	CEK	STW	On Time	CR2	\N	\N
12315	PG0259	2017-09-13 12:30:00+03	2017-09-13 15:00:00+03	CEK	STW	Cancelled	CR2	\N	\N
12316	PG0259	2017-08-19 12:30:00+03	2017-08-19 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12317	PG0259	2017-08-14 12:30:00+03	2017-08-14 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-14 12:30:00+03	2017-08-14 15:00:00+03
12318	PG0259	2017-08-26 12:30:00+03	2017-08-26 15:00:00+03	CEK	STW	Scheduled	CR2	\N	\N
12319	PG0259	2017-08-07 12:30:00+03	2017-08-07 15:00:00+03	CEK	STW	Arrived	CR2	2017-08-07 12:31:00+03	2017-08-07 15:02:00+03
12320	PG0190	2017-08-16 07:35:00+03	2017-08-16 10:45:00+03	CEK	SGC	On Time	CN1	\N	\N
12321	PG0190	2017-08-22 07:35:00+03	2017-08-22 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12322	PG0191	2017-08-22 11:40:00+03	2017-08-22 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12323	PG0190	2017-09-13 07:35:00+03	2017-09-13 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12324	PG0191	2017-09-13 11:40:00+03	2017-09-13 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12325	PG0191	2017-08-05 11:40:00+03	2017-08-05 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-05 11:41:00+03	2017-08-05 14:48:00+03
12326	PG0190	2017-08-05 07:35:00+03	2017-08-05 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-05 07:36:00+03	2017-08-05 10:51:00+03
12327	PG0190	2017-09-11 07:35:00+03	2017-09-11 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12328	PG0191	2017-07-31 11:40:00+03	2017-07-31 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-31 11:46:00+03	2017-07-31 14:53:00+03
12329	PG0190	2017-07-31 07:35:00+03	2017-07-31 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-31 07:41:00+03	2017-07-31 10:48:00+03
12330	PG0191	2017-09-11 11:40:00+03	2017-09-11 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12331	PG0191	2017-08-23 11:40:00+03	2017-08-23 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12332	PG0190	2017-08-07 07:35:00+03	2017-08-07 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-07 10:25:00+03	2017-08-07 13:36:00+03
12333	PG0191	2017-08-07 11:40:00+03	2017-08-07 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-07 11:42:00+03	2017-08-07 14:49:00+03
12334	PG0190	2017-08-23 07:35:00+03	2017-08-23 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12335	PG0191	2017-08-27 11:40:00+03	2017-08-27 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12336	PG0191	2017-08-25 11:40:00+03	2017-08-25 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12337	PG0190	2017-07-29 07:35:00+03	2017-07-29 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-29 07:42:00+03	2017-07-29 10:51:00+03
12338	PG0191	2017-07-29 11:40:00+03	2017-07-29 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-29 11:43:00+03	2017-07-29 14:52:00+03
12339	PG0190	2017-09-09 07:35:00+03	2017-09-09 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12340	PG0191	2017-09-09 11:40:00+03	2017-09-09 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12341	PG0190	2017-08-27 07:35:00+03	2017-08-27 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12342	PG0190	2017-08-30 07:35:00+03	2017-08-30 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12343	PG0191	2017-08-30 11:40:00+03	2017-08-30 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12344	PG0191	2017-07-19 11:40:00+03	2017-07-19 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-19 11:43:00+03	2017-07-19 14:52:00+03
12345	PG0190	2017-07-19 07:35:00+03	2017-07-19 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-19 07:37:00+03	2017-07-19 10:46:00+03
12346	PG0191	2017-07-23 11:40:00+03	2017-07-23 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-23 11:42:00+03	2017-07-23 14:56:00+03
12347	PG0190	2017-08-01 07:35:00+03	2017-08-01 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-01 07:38:00+03	2017-08-01 10:46:00+03
12348	PG0191	2017-08-01 11:40:00+03	2017-08-01 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-01 11:42:00+03	2017-08-01 14:48:00+03
12349	PG0190	2017-08-11 07:35:00+03	2017-08-11 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-11 07:37:00+03	2017-08-11 10:45:00+03
12350	PG0191	2017-08-11 11:40:00+03	2017-08-11 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-11 11:42:00+03	2017-08-11 14:54:00+03
12351	PG0190	2017-07-23 07:35:00+03	2017-07-23 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-23 07:39:00+03	2017-07-23 10:47:00+03
12352	PG0191	2017-09-03 11:40:00+03	2017-09-03 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12353	PG0190	2017-09-03 07:35:00+03	2017-09-03 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12354	PG0191	2017-09-08 11:40:00+03	2017-09-08 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12355	PG0190	2017-08-25 07:35:00+03	2017-08-25 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12356	PG0190	2017-07-25 07:35:00+03	2017-07-25 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-25 07:37:00+03	2017-07-25 10:47:00+03
12357	PG0191	2017-07-25 11:40:00+03	2017-07-25 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-25 11:42:00+03	2017-07-25 14:52:00+03
12358	PG0191	2017-07-16 11:40:00+03	2017-07-16 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-16 11:44:00+03	2017-07-16 14:53:00+03
12359	PG0190	2017-07-16 07:35:00+03	2017-07-16 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-16 07:40:00+03	2017-07-16 10:50:00+03
12360	PG0190	2017-08-08 07:35:00+03	2017-08-08 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-08 07:37:00+03	2017-08-08 10:46:00+03
12361	PG0191	2017-08-08 11:40:00+03	2017-08-08 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-08 11:42:00+03	2017-08-08 14:52:00+03
12362	PG0190	2017-08-17 07:35:00+03	2017-08-17 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12363	PG0190	2017-07-21 07:35:00+03	2017-07-21 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-21 07:36:00+03	2017-07-21 10:47:00+03
12364	PG0191	2017-07-21 11:40:00+03	2017-07-21 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-21 15:15:00+03	2017-07-21 18:26:00+03
12365	PG0191	2017-07-20 11:40:00+03	2017-07-20 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-20 11:43:00+03	2017-07-20 14:52:00+03
12366	PG0191	2017-08-17 11:40:00+03	2017-08-17 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12367	PG0191	2017-08-04 11:40:00+03	2017-08-04 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-04 11:42:00+03	2017-08-04 14:53:00+03
12368	PG0190	2017-08-04 07:35:00+03	2017-08-04 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-04 07:38:00+03	2017-08-04 10:50:00+03
12369	PG0190	2017-09-08 07:35:00+03	2017-09-08 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12370	PG0190	2017-09-05 07:35:00+03	2017-09-05 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12371	PG0191	2017-09-05 11:40:00+03	2017-09-05 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12372	PG0191	2017-08-28 11:40:00+03	2017-08-28 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12373	PG0191	2017-09-10 11:40:00+03	2017-09-10 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12374	PG0190	2017-09-07 07:35:00+03	2017-09-07 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12375	PG0190	2017-09-10 07:35:00+03	2017-09-10 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12376	PG0191	2017-08-31 11:40:00+03	2017-08-31 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12377	PG0190	2017-08-31 07:35:00+03	2017-08-31 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12378	PG0190	2017-07-30 07:35:00+03	2017-07-30 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-30 07:39:00+03	2017-07-30 10:49:00+03
12379	PG0191	2017-07-30 11:40:00+03	2017-07-30 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-30 11:43:00+03	2017-07-30 14:53:00+03
12380	PG0191	2017-07-28 11:40:00+03	2017-07-28 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-28 11:41:00+03	2017-07-28 14:51:00+03
12381	PG0190	2017-07-28 07:35:00+03	2017-07-28 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-28 07:39:00+03	2017-07-28 10:48:00+03
12382	PG0191	2017-07-24 11:40:00+03	2017-07-24 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-24 11:42:00+03	2017-07-24 14:52:00+03
12383	PG0191	2017-09-07 11:40:00+03	2017-09-07 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12384	PG0190	2017-07-24 07:35:00+03	2017-07-24 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-24 07:40:00+03	2017-07-24 10:50:00+03
12385	PG0191	2017-09-12 11:40:00+03	2017-09-12 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12386	PG0191	2017-08-15 11:40:00+03	2017-08-15 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-15 11:43:00+03	2017-08-15 14:56:00+03
12387	PG0190	2017-08-15 07:35:00+03	2017-08-15 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-15 07:39:00+03	2017-08-15 10:50:00+03
12388	PG0190	2017-09-12 07:35:00+03	2017-09-12 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12389	PG0190	2017-08-13 07:35:00+03	2017-08-13 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-13 07:37:00+03	2017-08-13 10:47:00+03
12390	PG0190	2017-08-28 07:35:00+03	2017-08-28 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12391	PG0190	2017-08-09 07:35:00+03	2017-08-09 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-09 07:37:00+03	2017-08-09 10:43:00+03
12392	PG0191	2017-08-06 11:40:00+03	2017-08-06 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-06 15:01:00+03	2017-08-06 18:09:00+03
12393	PG0190	2017-08-06 07:35:00+03	2017-08-06 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-06 07:41:00+03	2017-08-06 10:50:00+03
12394	PG0190	2017-08-24 07:35:00+03	2017-08-24 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12395	PG0191	2017-08-24 11:40:00+03	2017-08-24 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12396	PG0191	2017-07-26 11:40:00+03	2017-07-26 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-26 11:43:00+03	2017-07-26 14:53:00+03
12397	PG0190	2017-08-20 07:35:00+03	2017-08-20 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12398	PG0191	2017-08-20 11:40:00+03	2017-08-20 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12399	PG0190	2017-07-26 07:35:00+03	2017-07-26 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-26 07:37:00+03	2017-07-26 10:48:00+03
12400	PG0190	2017-09-04 07:35:00+03	2017-09-04 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12401	PG0191	2017-07-18 11:40:00+03	2017-07-18 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-18 11:42:00+03	2017-07-18 14:51:00+03
12402	PG0190	2017-07-18 07:35:00+03	2017-07-18 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-18 07:39:00+03	2017-07-18 10:47:00+03
12403	PG0190	2017-09-14 07:35:00+03	2017-09-14 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12404	PG0191	2017-09-14 11:40:00+03	2017-09-14 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12405	PG0190	2017-07-20 07:35:00+03	2017-07-20 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-20 07:37:00+03	2017-07-20 10:47:00+03
12406	PG0191	2017-08-12 11:40:00+03	2017-08-12 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-12 11:43:00+03	2017-08-12 14:51:00+03
12407	PG0190	2017-08-12 07:35:00+03	2017-08-12 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-12 07:40:00+03	2017-08-12 10:53:00+03
12408	PG0191	2017-08-13 11:40:00+03	2017-08-13 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-13 11:42:00+03	2017-08-13 14:55:00+03
12409	PG0191	2017-08-21 11:40:00+03	2017-08-21 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12410	PG0190	2017-08-21 07:35:00+03	2017-08-21 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12411	PG0191	2017-08-03 11:40:00+03	2017-08-03 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-03 11:42:00+03	2017-08-03 14:54:00+03
12412	PG0190	2017-08-03 07:35:00+03	2017-08-03 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-03 07:36:00+03	2017-08-03 10:44:00+03
12413	PG0191	2017-08-02 11:40:00+03	2017-08-02 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-02 11:43:00+03	2017-08-02 14:53:00+03
12414	PG0191	2017-08-29 11:40:00+03	2017-08-29 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12415	PG0190	2017-08-02 07:35:00+03	2017-08-02 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-02 07:37:00+03	2017-08-02 10:49:00+03
12416	PG0191	2017-09-02 11:40:00+03	2017-09-02 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12417	PG0190	2017-09-02 07:35:00+03	2017-09-02 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12418	PG0191	2017-09-06 11:40:00+03	2017-09-06 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12419	PG0190	2017-07-27 07:35:00+03	2017-07-27 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-27 07:36:00+03	2017-07-27 10:42:00+03
12420	PG0190	2017-09-06 07:35:00+03	2017-09-06 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12421	PG0190	2017-08-29 07:35:00+03	2017-08-29 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12422	PG0191	2017-07-27 11:40:00+03	2017-07-27 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-27 11:42:00+03	2017-07-27 14:53:00+03
12423	PG0190	2017-08-10 07:35:00+03	2017-08-10 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-10 07:38:00+03	2017-08-10 10:48:00+03
12424	PG0191	2017-08-10 11:40:00+03	2017-08-10 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-10 11:44:00+03	2017-08-10 14:51:00+03
12425	PG0191	2017-08-19 11:40:00+03	2017-08-19 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12426	PG0190	2017-08-19 07:35:00+03	2017-08-19 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12427	PG0190	2017-08-14 07:35:00+03	2017-08-14 10:45:00+03	CEK	SGC	Arrived	CN1	2017-08-14 07:37:00+03	2017-08-14 10:50:00+03
12428	PG0191	2017-08-14 11:40:00+03	2017-08-14 14:50:00+03	CEK	SGC	Arrived	CN1	2017-08-14 11:44:00+03	2017-08-14 14:51:00+03
12429	PG0190	2017-07-22 07:35:00+03	2017-07-22 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-22 07:38:00+03	2017-07-22 10:49:00+03
12430	PG0191	2017-07-22 11:40:00+03	2017-07-22 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-22 11:42:00+03	2017-07-22 14:53:00+03
12431	PG0190	2017-09-01 07:35:00+03	2017-09-01 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12432	PG0191	2017-09-01 11:40:00+03	2017-09-01 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12433	PG0191	2017-09-04 11:40:00+03	2017-09-04 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12434	PG0191	2017-08-09 11:40:00+03	2017-08-09 14:50:00+03	CEK	SGC	Cancelled	CN1	2017-08-09 11:42:00+03	2017-08-09 14:53:00+03
12435	PG0191	2017-08-18 11:40:00+03	2017-08-18 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12436	PG0190	2017-08-18 07:35:00+03	2017-08-18 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12437	PG0191	2017-07-17 11:40:00+03	2017-07-17 14:50:00+03	CEK	SGC	Arrived	CN1	2017-07-17 11:43:00+03	2017-07-17 14:54:00+03
12438	PG0190	2017-07-17 07:35:00+03	2017-07-17 10:45:00+03	CEK	SGC	Arrived	CN1	2017-07-17 07:37:00+03	2017-07-17 10:44:00+03
12439	PG0191	2017-08-26 11:40:00+03	2017-08-26 14:50:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12440	PG0190	2017-08-26 07:35:00+03	2017-08-26 10:45:00+03	CEK	SGC	Scheduled	CN1	\N	\N
12441	PG0191	2017-08-16 11:40:00+03	2017-08-16 14:50:00+03	CEK	SGC	On Time	CN1	\N	\N
12442	PG0672	2017-08-19 10:10:00+03	2017-08-19 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12443	PG0672	2017-08-20 10:10:00+03	2017-08-20 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12444	PG0672	2017-08-01 10:10:00+03	2017-08-01 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-01 10:14:00+03	2017-08-01 13:28:00+03
12445	PG0672	2017-07-16 10:10:00+03	2017-07-16 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-16 10:12:00+03	2017-07-16 13:26:00+03
12446	PG0672	2017-07-19 10:10:00+03	2017-07-19 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-19 10:11:00+03	2017-07-19 13:29:00+03
12447	PG0672	2017-07-31 10:10:00+03	2017-07-31 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-31 10:14:00+03	2017-07-31 13:29:00+03
12448	PG0672	2017-09-10 10:10:00+03	2017-09-10 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12449	PG0672	2017-09-07 10:10:00+03	2017-09-07 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12450	PG0672	2017-07-27 10:10:00+03	2017-07-27 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-27 10:11:00+03	2017-07-27 13:25:00+03
12451	PG0672	2017-08-31 10:10:00+03	2017-08-31 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12452	PG0672	2017-08-29 10:10:00+03	2017-08-29 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12453	PG0672	2017-07-26 10:10:00+03	2017-07-26 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-26 10:12:00+03	2017-07-26 13:28:00+03
12454	PG0672	2017-09-02 10:10:00+03	2017-09-02 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12455	PG0672	2017-08-26 10:10:00+03	2017-08-26 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12456	PG0672	2017-09-14 10:10:00+03	2017-09-14 13:25:00+03	OMS	VKO	Cancelled	CR2	\N	\N
12457	PG0672	2017-09-08 10:10:00+03	2017-09-08 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12458	PG0672	2017-08-25 10:10:00+03	2017-08-25 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12459	PG0672	2017-08-09 10:10:00+03	2017-08-09 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-09 13:26:00+03	2017-08-09 16:44:00+03
12460	PG0672	2017-07-20 10:10:00+03	2017-07-20 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-20 10:13:00+03	2017-07-20 13:27:00+03
12461	PG0672	2017-08-18 10:10:00+03	2017-08-18 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12462	PG0672	2017-09-06 10:10:00+03	2017-09-06 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12463	PG0672	2017-09-09 10:10:00+03	2017-09-09 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12464	PG0672	2017-07-17 10:10:00+03	2017-07-17 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-17 10:15:00+03	2017-07-17 13:31:00+03
12465	PG0672	2017-08-22 10:10:00+03	2017-08-22 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12466	PG0672	2017-08-15 10:10:00+03	2017-08-15 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-15 10:19:00+03	2017-08-15 13:32:00+03
12467	PG0672	2017-08-14 10:10:00+03	2017-08-14 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-14 10:14:00+03	2017-08-14 13:28:00+03
12468	PG0672	2017-09-04 10:10:00+03	2017-09-04 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12469	PG0672	2017-09-05 10:10:00+03	2017-09-05 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12470	PG0672	2017-08-11 10:10:00+03	2017-08-11 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-11 10:11:00+03	2017-08-11 13:26:00+03
12471	PG0672	2017-09-13 10:10:00+03	2017-09-13 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12472	PG0672	2017-09-11 10:10:00+03	2017-09-11 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12473	PG0672	2017-07-24 10:10:00+03	2017-07-24 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-24 10:15:00+03	2017-07-24 13:28:00+03
12474	PG0672	2017-08-08 10:10:00+03	2017-08-08 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-08 10:12:00+03	2017-08-08 13:30:00+03
12475	PG0672	2017-08-13 10:10:00+03	2017-08-13 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-13 10:12:00+03	2017-08-13 13:30:00+03
12476	PG0672	2017-09-01 10:10:00+03	2017-09-01 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12477	PG0672	2017-08-12 10:10:00+03	2017-08-12 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-12 10:12:00+03	2017-08-12 13:26:00+03
12478	PG0672	2017-08-30 10:10:00+03	2017-08-30 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12479	PG0672	2017-08-24 10:10:00+03	2017-08-24 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12480	PG0672	2017-08-05 10:10:00+03	2017-08-05 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-05 10:14:00+03	2017-08-05 13:29:00+03
12481	PG0672	2017-08-02 10:10:00+03	2017-08-02 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-02 10:14:00+03	2017-08-02 13:28:00+03
12482	PG0672	2017-07-30 10:10:00+03	2017-07-30 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-30 10:15:00+03	2017-07-30 13:29:00+03
12483	PG0672	2017-07-29 10:10:00+03	2017-07-29 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-29 10:13:00+03	2017-07-29 13:29:00+03
12484	PG0672	2017-08-06 10:10:00+03	2017-08-06 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-06 10:12:00+03	2017-08-06 13:28:00+03
12485	PG0672	2017-08-10 10:10:00+03	2017-08-10 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-10 10:13:00+03	2017-08-10 13:30:00+03
12486	PG0672	2017-07-28 10:10:00+03	2017-07-28 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-28 13:00:00+03	2017-07-28 16:16:00+03
12487	PG0672	2017-08-28 10:10:00+03	2017-08-28 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12488	PG0672	2017-09-03 10:10:00+03	2017-09-03 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12489	PG0672	2017-07-25 10:10:00+03	2017-07-25 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-25 10:17:00+03	2017-07-25 13:33:00+03
12490	PG0672	2017-08-03 10:10:00+03	2017-08-03 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-03 10:15:00+03	2017-08-03 13:29:00+03
12491	PG0672	2017-08-27 10:10:00+03	2017-08-27 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12492	PG0672	2017-07-21 10:10:00+03	2017-07-21 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-21 10:11:00+03	2017-07-21 13:30:00+03
12493	PG0672	2017-08-16 10:10:00+03	2017-08-16 13:25:00+03	OMS	VKO	On Time	CR2	\N	\N
12494	PG0672	2017-07-23 10:10:00+03	2017-07-23 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-23 10:16:00+03	2017-07-23 13:30:00+03
12495	PG0672	2017-08-07 10:10:00+03	2017-08-07 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-07 10:14:00+03	2017-08-07 13:25:00+03
12496	PG0672	2017-08-04 10:10:00+03	2017-08-04 13:25:00+03	OMS	VKO	Arrived	CR2	2017-08-04 10:17:00+03	2017-08-04 13:33:00+03
12497	PG0672	2017-09-12 10:10:00+03	2017-09-12 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12498	PG0672	2017-07-22 10:10:00+03	2017-07-22 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-22 10:13:00+03	2017-07-22 13:26:00+03
12499	PG0672	2017-08-21 10:10:00+03	2017-08-21 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12500	PG0672	2017-07-18 10:10:00+03	2017-07-18 13:25:00+03	OMS	VKO	Arrived	CR2	2017-07-18 10:12:00+03	2017-07-18 13:28:00+03
12501	PG0672	2017-08-17 10:10:00+03	2017-08-17 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12502	PG0672	2017-08-23 10:10:00+03	2017-08-23 13:25:00+03	OMS	VKO	Scheduled	CR2	\N	\N
12503	PG0504	2017-08-14 15:20:00+03	2017-08-14 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-14 15:26:00+03	2017-08-14 18:23:00+03
12504	PG0504	2017-07-22 15:20:00+03	2017-07-22 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-22 15:22:00+03	2017-07-22 18:24:00+03
12505	PG0504	2017-09-01 15:20:00+03	2017-09-01 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12506	PG0504	2017-09-03 15:20:00+03	2017-09-03 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12507	PG0504	2017-07-27 15:20:00+03	2017-07-27 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-27 15:23:00+03	2017-07-27 18:23:00+03
12508	PG0504	2017-09-08 15:20:00+03	2017-09-08 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12509	PG0504	2017-08-22 15:20:00+03	2017-08-22 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12510	PG0504	2017-07-19 15:20:00+03	2017-07-19 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-19 15:22:00+03	2017-07-19 18:23:00+03
12511	PG0504	2017-09-13 15:20:00+03	2017-09-13 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12512	PG0504	2017-08-17 15:20:00+03	2017-08-17 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12513	PG0504	2017-09-10 15:20:00+03	2017-09-10 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12514	PG0504	2017-09-07 15:20:00+03	2017-09-07 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12515	PG0504	2017-08-15 15:20:00+03	2017-08-15 18:20:00+03	OMS	SVO	Departed	SU9	2017-08-15 15:21:00+03	\N
12516	PG0504	2017-09-09 15:20:00+03	2017-09-09 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12517	PG0504	2017-09-06 15:20:00+03	2017-09-06 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12518	PG0504	2017-08-18 15:20:00+03	2017-08-18 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12519	PG0504	2017-08-04 15:20:00+03	2017-08-04 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-04 15:22:00+03	2017-08-04 18:23:00+03
12520	PG0504	2017-08-23 15:20:00+03	2017-08-23 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12521	PG0504	2017-09-12 15:20:00+03	2017-09-12 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12522	PG0504	2017-08-05 15:20:00+03	2017-08-05 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-05 15:23:00+03	2017-08-05 18:23:00+03
12523	PG0504	2017-07-20 15:20:00+03	2017-07-20 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-20 15:21:00+03	2017-07-20 18:23:00+03
12524	PG0504	2017-08-10 15:20:00+03	2017-08-10 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-10 15:22:00+03	2017-08-10 18:22:00+03
12525	PG0504	2017-09-02 15:20:00+03	2017-09-02 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12526	PG0504	2017-08-08 15:20:00+03	2017-08-08 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-08 15:22:00+03	2017-08-08 18:20:00+03
12527	PG0504	2017-08-07 15:20:00+03	2017-08-07 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-07 15:23:00+03	2017-08-07 18:22:00+03
12528	PG0504	2017-07-23 15:20:00+03	2017-07-23 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-23 15:24:00+03	2017-07-23 18:22:00+03
12529	PG0504	2017-08-02 15:20:00+03	2017-08-02 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-02 15:24:00+03	2017-08-02 18:26:00+03
12530	PG0504	2017-08-16 15:20:00+03	2017-08-16 18:20:00+03	OMS	SVO	On Time	SU9	\N	\N
12531	PG0504	2017-08-27 15:20:00+03	2017-08-27 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12532	PG0504	2017-08-13 15:20:00+03	2017-08-13 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-13 15:26:00+03	2017-08-13 18:26:00+03
12533	PG0504	2017-07-18 15:20:00+03	2017-07-18 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-18 15:24:00+03	2017-07-18 18:24:00+03
12534	PG0504	2017-07-17 15:20:00+03	2017-07-17 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-17 15:21:00+03	2017-07-17 18:20:00+03
12535	PG0504	2017-08-03 15:20:00+03	2017-08-03 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-03 15:23:00+03	2017-08-03 18:24:00+03
12536	PG0504	2017-07-28 15:20:00+03	2017-07-28 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-28 15:22:00+03	2017-07-28 18:21:00+03
12537	PG0504	2017-08-19 15:20:00+03	2017-08-19 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12538	PG0504	2017-09-14 15:20:00+03	2017-09-14 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12539	PG0504	2017-08-01 15:20:00+03	2017-08-01 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-01 15:23:00+03	2017-08-01 18:23:00+03
12540	PG0504	2017-07-26 15:20:00+03	2017-07-26 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-26 15:23:00+03	2017-07-26 18:25:00+03
12541	PG0504	2017-08-21 15:20:00+03	2017-08-21 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12542	PG0504	2017-07-25 15:20:00+03	2017-07-25 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-25 15:20:00+03	2017-07-25 18:21:00+03
12543	PG0504	2017-07-30 15:20:00+03	2017-07-30 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-30 15:27:00+03	2017-07-30 18:26:00+03
12544	PG0504	2017-08-09 15:20:00+03	2017-08-09 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-09 15:25:00+03	2017-08-09 18:25:00+03
12545	PG0504	2017-08-26 15:20:00+03	2017-08-26 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12546	PG0504	2017-08-31 15:20:00+03	2017-08-31 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12547	PG0504	2017-07-31 15:20:00+03	2017-07-31 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-31 15:21:00+03	2017-07-31 18:24:00+03
12548	PG0504	2017-07-21 15:20:00+03	2017-07-21 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-21 15:21:00+03	2017-07-21 18:20:00+03
12549	PG0504	2017-07-29 15:20:00+03	2017-07-29 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-29 15:23:00+03	2017-07-29 18:24:00+03
12550	PG0504	2017-09-05 15:20:00+03	2017-09-05 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12551	PG0504	2017-08-30 15:20:00+03	2017-08-30 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12552	PG0504	2017-08-24 15:20:00+03	2017-08-24 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12553	PG0504	2017-08-12 15:20:00+03	2017-08-12 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-12 15:24:00+03	2017-08-12 18:24:00+03
12554	PG0504	2017-07-16 15:20:00+03	2017-07-16 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-16 15:25:00+03	2017-07-16 18:24:00+03
12555	PG0504	2017-07-24 15:20:00+03	2017-07-24 18:20:00+03	OMS	SVO	Arrived	SU9	2017-07-24 15:23:00+03	2017-07-24 18:22:00+03
12556	PG0504	2017-08-06 15:20:00+03	2017-08-06 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-06 15:25:00+03	2017-08-06 18:24:00+03
12557	PG0504	2017-08-29 15:20:00+03	2017-08-29 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12558	PG0504	2017-09-11 15:20:00+03	2017-09-11 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12559	PG0504	2017-09-04 15:20:00+03	2017-09-04 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12560	PG0504	2017-08-11 15:20:00+03	2017-08-11 18:20:00+03	OMS	SVO	Arrived	SU9	2017-08-11 15:24:00+03	2017-08-11 18:27:00+03
12561	PG0504	2017-08-28 15:20:00+03	2017-08-28 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12562	PG0504	2017-08-25 15:20:00+03	2017-08-25 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12563	PG0504	2017-08-20 15:20:00+03	2017-08-20 18:20:00+03	OMS	SVO	Scheduled	SU9	\N	\N
12564	PG0172	2017-08-18 09:50:00+03	2017-08-18 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12565	PG0172	2017-08-25 09:50:00+03	2017-08-25 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12566	PG0172	2017-07-28 09:50:00+03	2017-07-28 11:45:00+03	OMS	NBC	Arrived	CR2	2017-07-28 09:52:00+03	2017-07-28 11:47:00+03
12567	PG0172	2017-08-28 09:50:00+03	2017-08-28 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12568	PG0172	2017-09-01 09:50:00+03	2017-09-01 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12569	PG0172	2017-09-08 09:50:00+03	2017-09-08 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12570	PG0172	2017-08-21 09:50:00+03	2017-08-21 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12571	PG0172	2017-07-24 09:50:00+03	2017-07-24 11:45:00+03	OMS	NBC	Arrived	CR2	2017-07-24 09:53:00+03	2017-07-24 11:51:00+03
12572	PG0172	2017-08-14 09:50:00+03	2017-08-14 11:45:00+03	OMS	NBC	Arrived	CR2	2017-08-14 09:55:00+03	2017-08-14 11:50:00+03
12573	PG0172	2017-09-04 09:50:00+03	2017-09-04 11:45:00+03	OMS	NBC	Scheduled	CR2	\N	\N
12574	PG0172	2017-08-11 09:50:00+03	2017-08-11 11:45:00+03	OMS	NBC	Arrived	CR2	2017-08-11 12:59:00+03	2017-08-11 14:53:00+03
12575	PG0172	2017-07-31 09:50:00+03	2017-07-31 11:45:00+03	OMS	NBC	Arrived	CR2	2017-07-31 09:54:00+03	2017-07-31 11:49:00+03
12576	PG0172	2017-08-07 09:50:00+03	2017-08-07 11:45:00+03	OMS	NBC	Arrived	CR2	2017-08-07 09:53:00+03	2017-08-07 11:46:00+03
12577	PG0172	2017-08-04 09:50:00+03	2017-08-04 11:45:00+03	OMS	NBC	Arrived	CR2	2017-08-04 09:57:00+03	2017-08-04 11:51:00+03
12578	PG0172	2017-07-21 09:50:00+03	2017-07-21 11:45:00+03	OMS	NBC	Arrived	CR2	2017-07-21 09:53:00+03	2017-07-21 11:49:00+03
12579	PG0172	2017-07-17 09:50:00+03	2017-07-17 11:45:00+03	OMS	NBC	Arrived	CR2	2017-07-17 09:51:00+03	2017-07-17 11:48:00+03
12580	PG0172	2017-09-11 09:50:00+03	2017-09-11 11:45:00+03	OMS	NBC	Cancelled	CR2	\N	\N
12581	PG0478	2017-09-01 15:55:00+03	2017-09-01 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12582	PG0478	2017-08-16 15:55:00+03	2017-08-16 18:00:00+03	OMS	VKT	On Time	CR2	\N	\N
12583	PG0478	2017-08-13 15:55:00+03	2017-08-13 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-13 15:59:00+03	2017-08-13 18:04:00+03
12584	PG0478	2017-07-22 15:55:00+03	2017-07-22 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-22 15:57:00+03	2017-07-22 18:01:00+03
12585	PG0478	2017-08-23 15:55:00+03	2017-08-23 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12586	PG0478	2017-08-22 15:55:00+03	2017-08-22 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12587	PG0478	2017-08-11 15:55:00+03	2017-08-11 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-11 15:58:00+03	2017-08-11 18:02:00+03
12588	PG0478	2017-07-26 15:55:00+03	2017-07-26 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-26 15:57:00+03	2017-07-26 18:01:00+03
12589	PG0478	2017-07-20 15:55:00+03	2017-07-20 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-20 16:00:00+03	2017-07-20 18:04:00+03
12590	PG0478	2017-09-08 15:55:00+03	2017-09-08 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12591	PG0478	2017-08-09 15:55:00+03	2017-08-09 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-09 15:58:00+03	2017-08-09 18:02:00+03
12592	PG0478	2017-09-10 15:55:00+03	2017-09-10 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12593	PG0478	2017-08-28 15:55:00+03	2017-08-28 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12594	PG0478	2017-08-18 15:55:00+03	2017-08-18 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12595	PG0478	2017-08-06 15:55:00+03	2017-08-06 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-06 15:59:00+03	2017-08-06 18:04:00+03
12596	PG0478	2017-08-20 15:55:00+03	2017-08-20 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12597	PG0478	2017-09-13 15:55:00+03	2017-09-13 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12598	PG0478	2017-09-14 15:55:00+03	2017-09-14 18:00:00+03	OMS	VKT	Cancelled	CR2	\N	\N
12599	PG0478	2017-07-23 15:55:00+03	2017-07-23 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-23 16:00:00+03	2017-07-23 18:06:00+03
12600	PG0478	2017-07-29 15:55:00+03	2017-07-29 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-29 15:59:00+03	2017-07-29 18:03:00+03
12601	PG0478	2017-08-15 15:55:00+03	2017-08-15 18:00:00+03	OMS	VKT	Departed	CR2	2017-08-15 16:00:00+03	\N
12602	PG0478	2017-09-04 15:55:00+03	2017-09-04 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12603	PG0478	2017-08-08 15:55:00+03	2017-08-08 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-08 15:56:00+03	2017-08-08 18:02:00+03
12604	PG0478	2017-08-27 15:55:00+03	2017-08-27 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12605	PG0478	2017-08-21 15:55:00+03	2017-08-21 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12606	PG0478	2017-07-21 15:55:00+03	2017-07-21 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-21 15:56:00+03	2017-07-21 18:00:00+03
12607	PG0478	2017-09-07 15:55:00+03	2017-09-07 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12608	PG0478	2017-09-02 15:55:00+03	2017-09-02 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12609	PG0478	2017-07-28 15:55:00+03	2017-07-28 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-28 15:57:00+03	2017-07-28 18:02:00+03
12610	PG0478	2017-08-14 15:55:00+03	2017-08-14 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-14 16:02:00+03	2017-08-14 18:09:00+03
12611	PG0478	2017-08-31 15:55:00+03	2017-08-31 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12612	PG0478	2017-08-29 15:55:00+03	2017-08-29 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12613	PG0478	2017-08-24 15:55:00+03	2017-08-24 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12614	PG0478	2017-08-04 15:55:00+03	2017-08-04 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-04 15:57:00+03	2017-08-04 18:03:00+03
12615	PG0478	2017-07-16 15:55:00+03	2017-07-16 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-16 16:01:00+03	2017-07-16 18:05:00+03
12616	PG0478	2017-08-30 15:55:00+03	2017-08-30 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12617	PG0478	2017-09-12 15:55:00+03	2017-09-12 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12618	PG0478	2017-08-02 15:55:00+03	2017-08-02 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-02 16:00:00+03	2017-08-02 18:05:00+03
12619	PG0478	2017-08-07 15:55:00+03	2017-08-07 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-07 15:59:00+03	2017-08-07 18:03:00+03
12620	PG0478	2017-07-30 15:55:00+03	2017-07-30 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-30 15:55:00+03	2017-07-30 18:00:00+03
12621	PG0478	2017-07-31 15:55:00+03	2017-07-31 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-31 15:56:00+03	2017-07-31 18:00:00+03
12622	PG0478	2017-08-10 15:55:00+03	2017-08-10 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-10 15:57:00+03	2017-08-10 18:02:00+03
12623	PG0478	2017-09-05 15:55:00+03	2017-09-05 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12624	PG0478	2017-09-11 15:55:00+03	2017-09-11 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12625	PG0478	2017-07-17 15:55:00+03	2017-07-17 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-17 15:58:00+03	2017-07-17 18:02:00+03
12626	PG0478	2017-08-25 15:55:00+03	2017-08-25 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12627	PG0478	2017-09-06 15:55:00+03	2017-09-06 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12628	PG0478	2017-08-03 15:55:00+03	2017-08-03 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-03 15:57:00+03	2017-08-03 18:03:00+03
12629	PG0478	2017-07-27 15:55:00+03	2017-07-27 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-27 15:58:00+03	2017-07-27 18:03:00+03
12630	PG0478	2017-07-25 15:55:00+03	2017-07-25 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-25 15:59:00+03	2017-07-25 18:04:00+03
12631	PG0478	2017-09-09 15:55:00+03	2017-09-09 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12632	PG0478	2017-08-17 15:55:00+03	2017-08-17 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12633	PG0478	2017-07-24 15:55:00+03	2017-07-24 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-24 15:58:00+03	2017-07-24 18:03:00+03
12634	PG0478	2017-09-03 15:55:00+03	2017-09-03 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12635	PG0478	2017-08-12 15:55:00+03	2017-08-12 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-12 15:56:00+03	2017-08-12 18:01:00+03
12636	PG0478	2017-08-26 15:55:00+03	2017-08-26 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12637	PG0478	2017-07-18 15:55:00+03	2017-07-18 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-18 15:56:00+03	2017-07-18 18:00:00+03
12638	PG0478	2017-08-19 15:55:00+03	2017-08-19 18:00:00+03	OMS	VKT	Scheduled	CR2	\N	\N
12639	PG0478	2017-08-05 15:55:00+03	2017-08-05 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-05 15:57:00+03	2017-08-05 18:00:00+03
12640	PG0478	2017-07-19 15:55:00+03	2017-07-19 18:00:00+03	OMS	VKT	Arrived	CR2	2017-07-19 15:59:00+03	2017-07-19 18:02:00+03
12641	PG0478	2017-08-01 15:55:00+03	2017-08-01 18:00:00+03	OMS	VKT	Arrived	CR2	2017-08-01 15:56:00+03	2017-08-01 18:00:00+03
12642	PG0217	2017-07-31 10:40:00+03	2017-07-31 11:45:00+03	KUF	DME	Arrived	763	2017-07-31 10:42:00+03	2017-07-31 11:45:00+03
12643	PG0217	2017-08-05 10:40:00+03	2017-08-05 11:45:00+03	KUF	DME	Arrived	763	2017-08-05 10:44:00+03	2017-08-05 11:48:00+03
12644	PG0217	2017-08-14 10:40:00+03	2017-08-14 11:45:00+03	KUF	DME	Arrived	763	2017-08-14 10:42:00+03	2017-08-14 11:47:00+03
12645	PG0217	2017-07-23 10:40:00+03	2017-07-23 11:45:00+03	KUF	DME	Arrived	763	2017-07-23 10:41:00+03	2017-07-23 11:46:00+03
12646	PG0217	2017-08-03 10:40:00+03	2017-08-03 11:45:00+03	KUF	DME	Arrived	763	2017-08-03 10:42:00+03	2017-08-03 11:46:00+03
12647	PG0217	2017-09-14 10:40:00+03	2017-09-14 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12648	PG0217	2017-08-20 10:40:00+03	2017-08-20 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12649	PG0217	2017-07-26 10:40:00+03	2017-07-26 11:45:00+03	KUF	DME	Arrived	763	2017-07-26 10:42:00+03	2017-07-26 11:48:00+03
12650	PG0217	2017-08-30 10:40:00+03	2017-08-30 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12651	PG0217	2017-08-31 10:40:00+03	2017-08-31 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12652	PG0217	2017-08-02 10:40:00+03	2017-08-02 11:45:00+03	KUF	DME	Arrived	763	2017-08-02 10:41:00+03	2017-08-02 11:46:00+03
12653	PG0217	2017-09-07 10:40:00+03	2017-09-07 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12654	PG0217	2017-09-04 10:40:00+03	2017-09-04 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12655	PG0217	2017-08-24 10:40:00+03	2017-08-24 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12656	PG0217	2017-08-22 10:40:00+03	2017-08-22 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12657	PG0217	2017-08-01 10:40:00+03	2017-08-01 11:45:00+03	KUF	DME	Arrived	763	2017-08-01 10:44:00+03	2017-08-01 11:49:00+03
12658	PG0217	2017-07-17 10:40:00+03	2017-07-17 11:45:00+03	KUF	DME	Arrived	763	2017-07-17 10:41:00+03	2017-07-17 11:46:00+03
12659	PG0217	2017-08-12 10:40:00+03	2017-08-12 11:45:00+03	KUF	DME	Arrived	763	2017-08-12 10:43:00+03	2017-08-12 11:48:00+03
12660	PG0217	2017-09-09 10:40:00+03	2017-09-09 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12661	PG0217	2017-09-11 10:40:00+03	2017-09-11 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12662	PG0217	2017-09-03 10:40:00+03	2017-09-03 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12663	PG0217	2017-08-08 10:40:00+03	2017-08-08 11:45:00+03	KUF	DME	Arrived	763	2017-08-08 10:45:00+03	2017-08-08 11:50:00+03
12664	PG0217	2017-08-29 10:40:00+03	2017-08-29 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12665	PG0217	2017-07-25 10:40:00+03	2017-07-25 11:45:00+03	KUF	DME	Arrived	763	2017-07-25 10:45:00+03	2017-07-25 11:49:00+03
12666	PG0217	2017-07-20 10:40:00+03	2017-07-20 11:45:00+03	KUF	DME	Arrived	763	2017-07-20 10:43:00+03	2017-07-20 11:47:00+03
12667	PG0217	2017-09-13 10:40:00+03	2017-09-13 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12668	PG0217	2017-08-04 10:40:00+03	2017-08-04 11:45:00+03	KUF	DME	Arrived	763	2017-08-04 10:42:00+03	2017-08-04 11:46:00+03
12669	PG0217	2017-09-06 10:40:00+03	2017-09-06 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12670	PG0217	2017-08-19 10:40:00+03	2017-08-19 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12671	PG0217	2017-07-18 10:40:00+03	2017-07-18 11:45:00+03	KUF	DME	Arrived	763	2017-07-18 10:45:00+03	2017-07-18 11:51:00+03
12672	PG0217	2017-09-08 10:40:00+03	2017-09-08 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12673	PG0217	2017-08-07 10:40:00+03	2017-08-07 11:45:00+03	KUF	DME	Arrived	763	2017-08-07 10:40:00+03	2017-08-07 11:44:00+03
12674	PG0217	2017-07-21 10:40:00+03	2017-07-21 11:45:00+03	KUF	DME	Arrived	763	2017-07-21 10:43:00+03	2017-07-21 11:47:00+03
12675	PG0217	2017-09-10 10:40:00+03	2017-09-10 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12676	PG0217	2017-08-11 10:40:00+03	2017-08-11 11:45:00+03	KUF	DME	Arrived	763	2017-08-11 10:41:00+03	2017-08-11 11:46:00+03
12677	PG0217	2017-07-19 10:40:00+03	2017-07-19 11:45:00+03	KUF	DME	Arrived	763	2017-07-19 10:43:00+03	2017-07-19 11:48:00+03
12678	PG0217	2017-08-09 10:40:00+03	2017-08-09 11:45:00+03	KUF	DME	Arrived	763	2017-08-09 10:42:00+03	2017-08-09 11:47:00+03
12679	PG0217	2017-07-16 10:40:00+03	2017-07-16 11:45:00+03	KUF	DME	Arrived	763	2017-07-16 10:44:00+03	2017-07-16 11:49:00+03
12680	PG0217	2017-07-29 10:40:00+03	2017-07-29 11:45:00+03	KUF	DME	Arrived	763	2017-07-29 10:46:00+03	2017-07-29 11:51:00+03
12681	PG0217	2017-08-23 10:40:00+03	2017-08-23 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12682	PG0217	2017-09-01 10:40:00+03	2017-09-01 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12683	PG0217	2017-08-27 10:40:00+03	2017-08-27 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12684	PG0217	2017-08-10 10:40:00+03	2017-08-10 11:45:00+03	KUF	DME	Arrived	763	2017-08-10 10:42:00+03	2017-08-10 11:48:00+03
12685	PG0217	2017-08-17 10:40:00+03	2017-08-17 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12686	PG0217	2017-08-18 10:40:00+03	2017-08-18 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12687	PG0217	2017-08-26 10:40:00+03	2017-08-26 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12688	PG0217	2017-07-27 10:40:00+03	2017-07-27 11:45:00+03	KUF	DME	Arrived	763	2017-07-27 10:43:00+03	2017-07-27 11:48:00+03
12689	PG0217	2017-08-21 10:40:00+03	2017-08-21 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12690	PG0217	2017-07-24 10:40:00+03	2017-07-24 11:45:00+03	KUF	DME	Arrived	763	2017-07-24 10:42:00+03	2017-07-24 11:47:00+03
12691	PG0217	2017-07-22 10:40:00+03	2017-07-22 11:45:00+03	KUF	DME	Arrived	763	2017-07-22 10:44:00+03	2017-07-22 11:51:00+03
12692	PG0217	2017-07-30 10:40:00+03	2017-07-30 11:45:00+03	KUF	DME	Arrived	763	2017-07-30 10:43:00+03	2017-07-30 11:49:00+03
12693	PG0217	2017-07-28 10:40:00+03	2017-07-28 11:45:00+03	KUF	DME	Arrived	763	2017-07-28 10:45:00+03	2017-07-28 11:50:00+03
12694	PG0217	2017-09-02 10:40:00+03	2017-09-02 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12695	PG0217	2017-08-28 10:40:00+03	2017-08-28 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12696	PG0217	2017-08-15 10:40:00+03	2017-08-15 11:45:00+03	KUF	DME	Arrived	763	2017-08-15 10:40:00+03	2017-08-15 11:45:00+03
12697	PG0217	2017-08-13 10:40:00+03	2017-08-13 11:45:00+03	KUF	DME	Arrived	763	2017-08-13 10:45:00+03	2017-08-13 11:49:00+03
12698	PG0217	2017-08-16 10:40:00+03	2017-08-16 11:45:00+03	KUF	DME	On Time	763	\N	\N
12699	PG0217	2017-08-06 10:40:00+03	2017-08-06 11:45:00+03	KUF	DME	Arrived	763	2017-08-06 10:45:00+03	2017-08-06 11:50:00+03
12700	PG0217	2017-09-05 10:40:00+03	2017-09-05 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12701	PG0217	2017-09-12 10:40:00+03	2017-09-12 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12702	PG0217	2017-08-25 10:40:00+03	2017-08-25 11:45:00+03	KUF	DME	Scheduled	763	\N	\N
12703	PG0130	2017-07-19 08:40:00+03	2017-07-19 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-19 08:41:00+03	2017-07-19 11:44:00+03
12704	PG0130	2017-08-27 08:40:00+03	2017-08-27 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12705	PG0130	2017-09-09 08:40:00+03	2017-09-09 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12706	PG0130	2017-07-16 08:40:00+03	2017-07-16 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-16 08:45:00+03	2017-07-16 11:49:00+03
12707	PG0130	2017-07-26 08:40:00+03	2017-07-26 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-26 08:46:00+03	2017-07-26 11:49:00+03
12708	PG0130	2017-08-19 08:40:00+03	2017-08-19 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12709	PG0130	2017-08-15 08:40:00+03	2017-08-15 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-15 12:15:00+03	2017-08-15 15:22:00+03
12710	PG0130	2017-07-24 08:40:00+03	2017-07-24 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-24 08:43:00+03	2017-07-24 11:49:00+03
12711	PG0130	2017-08-31 08:40:00+03	2017-08-31 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12712	PG0130	2017-08-04 08:40:00+03	2017-08-04 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-04 08:41:00+03	2017-08-04 11:48:00+03
12713	PG0130	2017-08-30 08:40:00+03	2017-08-30 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12714	PG0130	2017-07-18 08:40:00+03	2017-07-18 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-18 08:42:00+03	2017-07-18 11:46:00+03
12715	PG0130	2017-08-05 08:40:00+03	2017-08-05 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-05 08:41:00+03	2017-08-05 11:43:00+03
12716	PG0130	2017-08-20 08:40:00+03	2017-08-20 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12717	PG0130	2017-07-30 08:40:00+03	2017-07-30 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-30 08:41:00+03	2017-07-30 11:43:00+03
12718	PG0130	2017-08-11 08:40:00+03	2017-08-11 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-11 08:43:00+03	2017-08-11 11:48:00+03
12719	PG0130	2017-08-08 08:40:00+03	2017-08-08 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-08 08:43:00+03	2017-08-08 11:48:00+03
12720	PG0130	2017-08-13 08:40:00+03	2017-08-13 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-13 08:44:00+03	2017-08-13 11:51:00+03
12721	PG0130	2017-07-25 08:40:00+03	2017-07-25 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-25 08:43:00+03	2017-07-25 11:49:00+03
12722	PG0130	2017-07-17 08:40:00+03	2017-07-17 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-17 08:43:00+03	2017-07-17 11:49:00+03
12723	PG0130	2017-08-12 08:40:00+03	2017-08-12 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-12 08:41:00+03	2017-08-12 11:44:00+03
12724	PG0130	2017-09-10 08:40:00+03	2017-09-10 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12725	PG0130	2017-08-10 08:40:00+03	2017-08-10 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-10 08:45:00+03	2017-08-10 11:52:00+03
12726	PG0130	2017-09-02 08:40:00+03	2017-09-02 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12727	PG0130	2017-08-07 08:40:00+03	2017-08-07 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-07 08:43:00+03	2017-08-07 11:45:00+03
12728	PG0130	2017-08-25 08:40:00+03	2017-08-25 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12729	PG0130	2017-08-17 08:40:00+03	2017-08-17 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12730	PG0130	2017-08-01 08:40:00+03	2017-08-01 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-01 08:45:00+03	2017-08-01 11:51:00+03
12731	PG0130	2017-09-05 08:40:00+03	2017-09-05 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12732	PG0130	2017-07-29 08:40:00+03	2017-07-29 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-29 08:45:00+03	2017-07-29 11:53:00+03
12733	PG0130	2017-08-21 08:40:00+03	2017-08-21 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12734	PG0130	2017-08-02 08:40:00+03	2017-08-02 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-02 11:53:00+03	2017-08-02 14:55:00+03
12735	PG0130	2017-08-18 08:40:00+03	2017-08-18 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12736	PG0130	2017-09-04 08:40:00+03	2017-09-04 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12737	PG0130	2017-09-12 08:40:00+03	2017-09-12 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12738	PG0130	2017-07-27 08:40:00+03	2017-07-27 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-27 08:41:00+03	2017-07-27 11:45:00+03
12739	PG0130	2017-07-21 08:40:00+03	2017-07-21 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-21 08:40:00+03	2017-07-21 11:46:00+03
12740	PG0130	2017-08-16 08:40:00+03	2017-08-16 11:45:00+03	KUF	URS	Delayed	CN1	\N	\N
12741	PG0130	2017-08-22 08:40:00+03	2017-08-22 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12742	PG0130	2017-08-06 08:40:00+03	2017-08-06 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-06 08:44:00+03	2017-08-06 11:47:00+03
12743	PG0130	2017-09-01 08:40:00+03	2017-09-01 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12744	PG0130	2017-09-11 08:40:00+03	2017-09-11 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12745	PG0130	2017-07-23 08:40:00+03	2017-07-23 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-23 08:40:00+03	2017-07-23 11:43:00+03
12746	PG0130	2017-08-23 08:40:00+03	2017-08-23 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12747	PG0130	2017-08-24 08:40:00+03	2017-08-24 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12748	PG0130	2017-08-28 08:40:00+03	2017-08-28 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12749	PG0130	2017-09-06 08:40:00+03	2017-09-06 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12750	PG0130	2017-09-14 08:40:00+03	2017-09-14 11:45:00+03	KUF	URS	Cancelled	CN1	\N	\N
12751	PG0130	2017-07-31 08:40:00+03	2017-07-31 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-31 08:40:00+03	2017-07-31 11:47:00+03
12752	PG0130	2017-08-29 08:40:00+03	2017-08-29 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12753	PG0130	2017-09-08 08:40:00+03	2017-09-08 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12754	PG0130	2017-08-14 08:40:00+03	2017-08-14 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-14 08:45:00+03	2017-08-14 11:52:00+03
12755	PG0130	2017-08-09 08:40:00+03	2017-08-09 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-09 08:46:00+03	2017-08-09 11:53:00+03
12756	PG0130	2017-08-03 08:40:00+03	2017-08-03 11:45:00+03	KUF	URS	Arrived	CN1	2017-08-03 08:43:00+03	2017-08-03 11:47:00+03
12757	PG0130	2017-09-13 08:40:00+03	2017-09-13 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12758	PG0130	2017-08-26 08:40:00+03	2017-08-26 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12759	PG0130	2017-07-28 08:40:00+03	2017-07-28 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-28 08:43:00+03	2017-07-28 11:47:00+03
12760	PG0130	2017-09-07 08:40:00+03	2017-09-07 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12761	PG0130	2017-07-22 08:40:00+03	2017-07-22 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-22 08:43:00+03	2017-07-22 11:47:00+03
12762	PG0130	2017-07-20 08:40:00+03	2017-07-20 11:45:00+03	KUF	URS	Arrived	CN1	2017-07-20 08:40:00+03	2017-07-20 11:46:00+03
12763	PG0130	2017-09-03 08:40:00+03	2017-09-03 11:45:00+03	KUF	URS	Scheduled	CN1	\N	\N
12764	PG0521	2017-08-28 09:50:00+03	2017-08-28 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12765	PG0521	2017-08-30 09:50:00+03	2017-08-30 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12766	PG0521	2017-09-11 09:50:00+03	2017-09-11 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12767	PG0521	2017-09-13 09:50:00+03	2017-09-13 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12768	PG0521	2017-07-29 09:50:00+03	2017-07-29 11:40:00+03	KUF	AER	Arrived	733	2017-07-29 09:52:00+03	2017-07-29 11:43:00+03
12769	PG0521	2017-07-27 09:50:00+03	2017-07-27 11:40:00+03	KUF	AER	Arrived	733	2017-07-27 09:52:00+03	2017-07-27 11:43:00+03
12770	PG0521	2017-08-05 09:50:00+03	2017-08-05 11:40:00+03	KUF	AER	Arrived	733	2017-08-05 09:54:00+03	2017-08-05 11:44:00+03
12771	PG0521	2017-07-26 09:50:00+03	2017-07-26 11:40:00+03	KUF	AER	Arrived	733	2017-07-26 09:54:00+03	2017-07-26 11:46:00+03
12772	PG0521	2017-08-19 09:50:00+03	2017-08-19 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12773	PG0521	2017-08-16 09:50:00+03	2017-08-16 11:40:00+03	KUF	AER	Delayed	733	\N	\N
12774	PG0521	2017-07-21 09:50:00+03	2017-07-21 11:40:00+03	KUF	AER	Arrived	733	2017-07-21 09:53:00+03	2017-07-21 11:42:00+03
12775	PG0521	2017-08-21 09:50:00+03	2017-08-21 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12776	PG0521	2017-09-01 09:50:00+03	2017-09-01 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12777	PG0521	2017-09-04 09:50:00+03	2017-09-04 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12778	PG0521	2017-07-30 09:50:00+03	2017-07-30 11:40:00+03	KUF	AER	Arrived	733	2017-07-30 09:53:00+03	2017-07-30 11:44:00+03
12779	PG0521	2017-08-06 09:50:00+03	2017-08-06 11:40:00+03	KUF	AER	Arrived	733	2017-08-06 09:54:00+03	2017-08-06 11:45:00+03
12780	PG0521	2017-09-08 09:50:00+03	2017-09-08 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12781	PG0521	2017-09-12 09:50:00+03	2017-09-12 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12782	PG0521	2017-08-14 09:50:00+03	2017-08-14 11:40:00+03	KUF	AER	Arrived	733	2017-08-14 12:26:00+03	2017-08-14 14:16:00+03
12783	PG0521	2017-07-28 09:50:00+03	2017-07-28 11:40:00+03	KUF	AER	Arrived	733	2017-07-28 09:53:00+03	2017-07-28 11:41:00+03
12784	PG0521	2017-08-20 09:50:00+03	2017-08-20 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12785	PG0521	2017-08-12 09:50:00+03	2017-08-12 11:40:00+03	KUF	AER	Arrived	733	2017-08-12 09:52:00+03	2017-08-12 11:41:00+03
12786	PG0521	2017-07-18 09:50:00+03	2017-07-18 11:40:00+03	KUF	AER	Arrived	733	2017-07-18 09:51:00+03	2017-07-18 11:40:00+03
12787	PG0521	2017-09-06 09:50:00+03	2017-09-06 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12788	PG0521	2017-08-18 09:50:00+03	2017-08-18 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12789	PG0521	2017-08-29 09:50:00+03	2017-08-29 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12790	PG0521	2017-07-20 09:50:00+03	2017-07-20 11:40:00+03	KUF	AER	Arrived	733	2017-07-20 13:01:00+03	2017-07-20 14:53:00+03
12791	PG0521	2017-07-17 09:50:00+03	2017-07-17 11:40:00+03	KUF	AER	Arrived	733	2017-07-17 09:54:00+03	2017-07-17 11:45:00+03
12792	PG0521	2017-08-22 09:50:00+03	2017-08-22 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12793	PG0521	2017-08-15 09:50:00+03	2017-08-15 11:40:00+03	KUF	AER	Arrived	733	2017-08-15 09:51:00+03	2017-08-15 11:42:00+03
12794	PG0521	2017-08-09 09:50:00+03	2017-08-09 11:40:00+03	KUF	AER	Arrived	733	2017-08-09 09:53:00+03	2017-08-09 11:42:00+03
12795	PG0521	2017-08-07 09:50:00+03	2017-08-07 11:40:00+03	KUF	AER	Arrived	733	2017-08-07 09:52:00+03	2017-08-07 11:43:00+03
12796	PG0521	2017-08-24 09:50:00+03	2017-08-24 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12797	PG0521	2017-07-16 09:50:00+03	2017-07-16 11:40:00+03	KUF	AER	Arrived	733	2017-07-16 09:52:00+03	2017-07-16 11:41:00+03
12798	PG0521	2017-07-19 09:50:00+03	2017-07-19 11:40:00+03	KUF	AER	Arrived	733	2017-07-19 09:52:00+03	2017-07-19 11:42:00+03
12799	PG0521	2017-09-07 09:50:00+03	2017-09-07 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12800	PG0521	2017-08-13 09:50:00+03	2017-08-13 11:40:00+03	KUF	AER	Arrived	733	2017-08-13 09:53:00+03	2017-08-13 11:44:00+03
12801	PG0521	2017-09-10 09:50:00+03	2017-09-10 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12802	PG0521	2017-08-10 09:50:00+03	2017-08-10 11:40:00+03	KUF	AER	Arrived	733	2017-08-10 09:53:00+03	2017-08-10 11:43:00+03
12803	PG0521	2017-08-25 09:50:00+03	2017-08-25 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12804	PG0521	2017-09-09 09:50:00+03	2017-09-09 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12805	PG0521	2017-07-22 09:50:00+03	2017-07-22 11:40:00+03	KUF	AER	Arrived	733	2017-07-22 09:51:00+03	2017-07-22 11:41:00+03
12806	PG0521	2017-08-03 09:50:00+03	2017-08-03 11:40:00+03	KUF	AER	Arrived	733	2017-08-03 09:56:00+03	2017-08-03 11:46:00+03
12807	PG0521	2017-09-03 09:50:00+03	2017-09-03 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12808	PG0521	2017-08-27 09:50:00+03	2017-08-27 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12809	PG0521	2017-07-24 09:50:00+03	2017-07-24 11:40:00+03	KUF	AER	Arrived	733	2017-07-24 13:23:00+03	2017-07-24 15:13:00+03
12810	PG0521	2017-08-04 09:50:00+03	2017-08-04 11:40:00+03	KUF	AER	Arrived	733	2017-08-04 09:50:00+03	2017-08-04 11:40:00+03
12811	PG0521	2017-08-08 09:50:00+03	2017-08-08 11:40:00+03	KUF	AER	Arrived	733	2017-08-08 09:54:00+03	2017-08-08 11:43:00+03
12812	PG0521	2017-07-23 09:50:00+03	2017-07-23 11:40:00+03	KUF	AER	Arrived	733	2017-07-23 09:51:00+03	2017-07-23 11:43:00+03
12813	PG0521	2017-07-31 09:50:00+03	2017-07-31 11:40:00+03	KUF	AER	Arrived	733	2017-07-31 09:57:00+03	2017-07-31 11:46:00+03
12814	PG0521	2017-08-01 09:50:00+03	2017-08-01 11:40:00+03	KUF	AER	Arrived	733	2017-08-01 09:55:00+03	2017-08-01 11:45:00+03
12815	PG0521	2017-08-31 09:50:00+03	2017-08-31 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12816	PG0521	2017-08-26 09:50:00+03	2017-08-26 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12817	PG0521	2017-09-14 09:50:00+03	2017-09-14 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12818	PG0521	2017-09-05 09:50:00+03	2017-09-05 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12819	PG0521	2017-09-02 09:50:00+03	2017-09-02 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12820	PG0521	2017-07-25 09:50:00+03	2017-07-25 11:40:00+03	KUF	AER	Arrived	733	2017-07-25 09:51:00+03	2017-07-25 11:41:00+03
12821	PG0521	2017-08-11 09:50:00+03	2017-08-11 11:40:00+03	KUF	AER	Arrived	733	2017-08-11 12:48:00+03	2017-08-11 14:40:00+03
12822	PG0521	2017-08-17 09:50:00+03	2017-08-17 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12823	PG0521	2017-08-23 09:50:00+03	2017-08-23 11:40:00+03	KUF	AER	Scheduled	733	\N	\N
12824	PG0521	2017-08-02 09:50:00+03	2017-08-02 11:40:00+03	KUF	AER	Arrived	733	2017-08-02 09:53:00+03	2017-08-02 11:42:00+03
12825	PG0215	2017-08-22 18:15:00+03	2017-08-22 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12826	PG0215	2017-08-02 18:15:00+03	2017-08-02 19:30:00+03	ROV	DME	Arrived	321	2017-08-02 18:19:00+03	2017-08-02 19:34:00+03
12827	PG0214	2017-08-28 14:20:00+03	2017-08-28 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12828	PG0215	2017-08-12 18:15:00+03	2017-08-12 19:30:00+03	ROV	DME	Arrived	321	2017-08-12 18:20:00+03	2017-08-12 19:35:00+03
12829	PG0214	2017-07-25 14:20:00+03	2017-07-25 15:35:00+03	ROV	DME	Arrived	321	2017-07-25 14:25:00+03	2017-07-25 15:40:00+03
12830	PG0214	2017-09-13 14:20:00+03	2017-09-13 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12831	PG0214	2017-09-03 14:20:00+03	2017-09-03 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12832	PG0214	2017-08-13 14:20:00+03	2017-08-13 15:35:00+03	ROV	DME	Arrived	321	2017-08-13 14:25:00+03	2017-08-13 15:40:00+03
12833	PG0215	2017-08-25 18:15:00+03	2017-08-25 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12834	PG0214	2017-08-09 14:20:00+03	2017-08-09 15:35:00+03	ROV	DME	Arrived	321	2017-08-09 14:24:00+03	2017-08-09 15:38:00+03
12835	PG0214	2017-09-07 14:20:00+03	2017-09-07 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12836	PG0214	2017-08-20 14:20:00+03	2017-08-20 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12837	PG0214	2017-08-29 14:20:00+03	2017-08-29 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12838	PG0215	2017-07-18 18:15:00+03	2017-07-18 19:30:00+03	ROV	DME	Arrived	321	2017-07-18 18:18:00+03	2017-07-18 19:33:00+03
12839	PG0214	2017-09-06 14:20:00+03	2017-09-06 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12840	PG0214	2017-07-16 14:20:00+03	2017-07-16 15:35:00+03	ROV	DME	Arrived	321	2017-07-16 14:25:00+03	2017-07-16 15:40:00+03
12841	PG0214	2017-08-19 14:20:00+03	2017-08-19 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12842	PG0215	2017-08-09 18:15:00+03	2017-08-09 19:30:00+03	ROV	DME	Arrived	321	2017-08-09 18:20:00+03	2017-08-09 19:34:00+03
12843	PG0215	2017-09-12 18:15:00+03	2017-09-12 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12844	PG0215	2017-08-11 18:15:00+03	2017-08-11 19:30:00+03	ROV	DME	Arrived	321	2017-08-11 18:16:00+03	2017-08-11 19:30:00+03
12845	PG0214	2017-08-01 14:20:00+03	2017-08-01 15:35:00+03	ROV	DME	Arrived	321	2017-08-01 14:23:00+03	2017-08-01 15:39:00+03
12846	PG0214	2017-08-15 14:20:00+03	2017-08-15 15:35:00+03	ROV	DME	Arrived	321	2017-08-15 14:22:00+03	2017-08-15 15:36:00+03
12847	PG0215	2017-07-29 18:15:00+03	2017-07-29 19:30:00+03	ROV	DME	Arrived	321	2017-07-29 18:19:00+03	2017-07-29 19:34:00+03
12848	PG0215	2017-08-29 18:15:00+03	2017-08-29 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12849	PG0215	2017-08-04 18:15:00+03	2017-08-04 19:30:00+03	ROV	DME	Arrived	321	2017-08-04 18:17:00+03	2017-08-04 19:33:00+03
12850	PG0214	2017-08-22 14:20:00+03	2017-08-22 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12851	PG0215	2017-08-28 18:15:00+03	2017-08-28 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12852	PG0214	2017-07-23 14:20:00+03	2017-07-23 15:35:00+03	ROV	DME	Arrived	321	2017-07-23 14:23:00+03	2017-07-23 15:38:00+03
12853	PG0215	2017-09-06 18:15:00+03	2017-09-06 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12854	PG0214	2017-08-04 14:20:00+03	2017-08-04 15:35:00+03	ROV	DME	Arrived	321	2017-08-04 14:22:00+03	2017-08-04 15:37:00+03
12855	PG0215	2017-08-15 18:15:00+03	2017-08-15 19:30:00+03	ROV	DME	On Time	321	\N	\N
12856	PG0215	2017-08-20 18:15:00+03	2017-08-20 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12857	PG0214	2017-09-09 14:20:00+03	2017-09-09 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12858	PG0214	2017-08-14 14:20:00+03	2017-08-14 15:35:00+03	ROV	DME	Arrived	321	2017-08-14 14:24:00+03	2017-08-14 15:39:00+03
12859	PG0214	2017-08-23 14:20:00+03	2017-08-23 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12860	PG0215	2017-09-13 18:15:00+03	2017-09-13 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12861	PG0215	2017-08-30 18:15:00+03	2017-08-30 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12862	PG0214	2017-09-14 14:20:00+03	2017-09-14 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12863	PG0214	2017-08-11 14:20:00+03	2017-08-11 15:35:00+03	ROV	DME	Arrived	321	2017-08-11 14:25:00+03	2017-08-11 15:40:00+03
12864	PG0214	2017-08-26 14:20:00+03	2017-08-26 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12865	PG0214	2017-09-11 14:20:00+03	2017-09-11 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12866	PG0215	2017-08-08 18:15:00+03	2017-08-08 19:30:00+03	ROV	DME	Arrived	321	2017-08-08 18:19:00+03	2017-08-08 19:36:00+03
12867	PG0215	2017-07-28 18:15:00+03	2017-07-28 19:30:00+03	ROV	DME	Arrived	321	2017-07-28 18:17:00+03	2017-07-28 19:31:00+03
12868	PG0215	2017-09-14 18:15:00+03	2017-09-14 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12869	PG0214	2017-08-08 14:20:00+03	2017-08-08 15:35:00+03	ROV	DME	Arrived	321	2017-08-08 14:22:00+03	2017-08-08 15:37:00+03
12870	PG0214	2017-08-02 14:20:00+03	2017-08-02 15:35:00+03	ROV	DME	Arrived	321	2017-08-02 14:25:00+03	2017-08-02 15:41:00+03
12871	PG0215	2017-09-04 18:15:00+03	2017-09-04 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12872	PG0214	2017-07-28 14:20:00+03	2017-07-28 15:35:00+03	ROV	DME	Arrived	321	2017-07-28 14:22:00+03	2017-07-28 15:37:00+03
12873	PG0215	2017-09-09 18:15:00+03	2017-09-09 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12874	PG0215	2017-07-30 18:15:00+03	2017-07-30 19:30:00+03	ROV	DME	Arrived	321	2017-07-30 22:07:00+03	2017-07-30 23:23:00+03
12875	PG0215	2017-09-08 18:15:00+03	2017-09-08 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12876	PG0214	2017-07-29 14:20:00+03	2017-07-29 15:35:00+03	ROV	DME	Arrived	321	2017-07-29 14:24:00+03	2017-07-29 15:40:00+03
12877	PG0214	2017-07-19 14:20:00+03	2017-07-19 15:35:00+03	ROV	DME	Arrived	321	2017-07-19 14:22:00+03	2017-07-19 15:37:00+03
12878	PG0214	2017-08-30 14:20:00+03	2017-08-30 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12879	PG0214	2017-09-02 14:20:00+03	2017-09-02 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12880	PG0215	2017-08-31 18:15:00+03	2017-08-31 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12881	PG0214	2017-07-27 14:20:00+03	2017-07-27 15:35:00+03	ROV	DME	Arrived	321	2017-07-27 14:25:00+03	2017-07-27 15:41:00+03
12882	PG0215	2017-08-18 18:15:00+03	2017-08-18 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12883	PG0214	2017-08-18 14:20:00+03	2017-08-18 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12884	PG0214	2017-08-05 14:20:00+03	2017-08-05 15:35:00+03	ROV	DME	Arrived	321	2017-08-05 14:24:00+03	2017-08-05 15:37:00+03
12885	PG0214	2017-07-30 14:20:00+03	2017-07-30 15:35:00+03	ROV	DME	Arrived	321	2017-07-30 14:25:00+03	2017-07-30 15:40:00+03
12886	PG0214	2017-08-16 14:20:00+03	2017-08-16 15:35:00+03	ROV	DME	On Time	321	\N	\N
12887	PG0215	2017-07-26 18:15:00+03	2017-07-26 19:30:00+03	ROV	DME	Arrived	321	2017-07-26 18:17:00+03	2017-07-26 19:31:00+03
12888	PG0215	2017-08-13 18:15:00+03	2017-08-13 19:30:00+03	ROV	DME	Arrived	321	2017-08-13 18:20:00+03	2017-08-13 19:35:00+03
12889	PG0214	2017-08-07 14:20:00+03	2017-08-07 15:35:00+03	ROV	DME	Arrived	321	2017-08-07 14:21:00+03	2017-08-07 15:36:00+03
12890	PG0214	2017-09-04 14:20:00+03	2017-09-04 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12891	PG0214	2017-08-06 14:20:00+03	2017-08-06 15:35:00+03	ROV	DME	Arrived	321	2017-08-06 14:23:00+03	2017-08-06 15:37:00+03
12892	PG0215	2017-07-19 18:15:00+03	2017-07-19 19:30:00+03	ROV	DME	Arrived	321	2017-07-19 18:17:00+03	2017-07-19 19:33:00+03
12893	PG0215	2017-09-02 18:15:00+03	2017-09-02 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12894	PG0215	2017-07-23 18:15:00+03	2017-07-23 19:30:00+03	ROV	DME	Arrived	321	2017-07-23 18:16:00+03	2017-07-23 19:32:00+03
12895	PG0215	2017-07-31 18:15:00+03	2017-07-31 19:30:00+03	ROV	DME	Arrived	321	2017-07-31 18:16:00+03	2017-07-31 19:30:00+03
12896	PG0215	2017-08-03 18:15:00+03	2017-08-03 19:30:00+03	ROV	DME	Arrived	321	2017-08-03 18:18:00+03	2017-08-03 19:34:00+03
12897	PG0214	2017-08-03 14:20:00+03	2017-08-03 15:35:00+03	ROV	DME	Arrived	321	2017-08-03 14:26:00+03	2017-08-03 15:42:00+03
12898	PG0214	2017-07-21 14:20:00+03	2017-07-21 15:35:00+03	ROV	DME	Arrived	321	2017-07-21 14:22:00+03	2017-07-21 15:38:00+03
12899	PG0215	2017-07-21 18:15:00+03	2017-07-21 19:30:00+03	ROV	DME	Arrived	321	2017-07-21 18:21:00+03	2017-07-21 19:36:00+03
12900	PG0215	2017-07-27 18:15:00+03	2017-07-27 19:30:00+03	ROV	DME	Arrived	321	2017-07-27 18:16:00+03	2017-07-27 19:31:00+03
12901	PG0214	2017-07-26 14:20:00+03	2017-07-26 15:35:00+03	ROV	DME	Arrived	321	2017-07-26 14:20:00+03	2017-07-26 15:36:00+03
12902	PG0214	2017-08-27 14:20:00+03	2017-08-27 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12903	PG0215	2017-08-23 18:15:00+03	2017-08-23 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12904	PG0214	2017-09-12 14:20:00+03	2017-09-12 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12905	PG0214	2017-07-18 14:20:00+03	2017-07-18 15:35:00+03	ROV	DME	Arrived	321	2017-07-18 14:26:00+03	2017-07-18 15:42:00+03
12906	PG0215	2017-08-26 18:15:00+03	2017-08-26 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12907	PG0214	2017-07-17 14:20:00+03	2017-07-17 15:35:00+03	ROV	DME	Arrived	321	2017-07-17 14:26:00+03	2017-07-17 15:41:00+03
12908	PG0215	2017-08-17 18:15:00+03	2017-08-17 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12909	PG0214	2017-09-08 14:20:00+03	2017-09-08 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12910	PG0214	2017-08-17 14:20:00+03	2017-08-17 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12911	PG0215	2017-08-16 18:15:00+03	2017-08-16 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12912	PG0214	2017-08-25 14:20:00+03	2017-08-25 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12913	PG0214	2017-08-31 14:20:00+03	2017-08-31 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12914	PG0215	2017-08-14 18:15:00+03	2017-08-14 19:30:00+03	ROV	DME	Arrived	321	2017-08-14 18:16:00+03	2017-08-14 19:30:00+03
12915	PG0215	2017-08-19 18:15:00+03	2017-08-19 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12916	PG0215	2017-09-10 18:15:00+03	2017-09-10 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12917	PG0214	2017-09-10 14:20:00+03	2017-09-10 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12918	PG0215	2017-09-07 18:15:00+03	2017-09-07 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12919	PG0215	2017-09-05 18:15:00+03	2017-09-05 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12920	PG0215	2017-08-10 18:15:00+03	2017-08-10 19:30:00+03	ROV	DME	Arrived	321	2017-08-10 18:22:00+03	2017-08-10 19:38:00+03
12921	PG0215	2017-07-16 18:15:00+03	2017-07-16 19:30:00+03	ROV	DME	Arrived	321	2017-07-16 18:18:00+03	2017-07-16 19:34:00+03
12922	PG0215	2017-07-17 18:15:00+03	2017-07-17 19:30:00+03	ROV	DME	Arrived	321	2017-07-17 18:20:00+03	2017-07-17 19:35:00+03
12923	PG0215	2017-08-01 18:15:00+03	2017-08-01 19:30:00+03	ROV	DME	Arrived	321	2017-08-01 18:16:00+03	2017-08-01 19:31:00+03
12924	PG0214	2017-08-10 14:20:00+03	2017-08-10 15:35:00+03	ROV	DME	Arrived	321	2017-08-10 14:21:00+03	2017-08-10 15:35:00+03
12925	PG0215	2017-08-27 18:15:00+03	2017-08-27 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12926	PG0215	2017-07-25 18:15:00+03	2017-07-25 19:30:00+03	ROV	DME	Arrived	321	2017-07-25 18:17:00+03	2017-07-25 19:33:00+03
12927	PG0215	2017-08-21 18:15:00+03	2017-08-21 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12928	PG0215	2017-07-20 18:15:00+03	2017-07-20 19:30:00+03	ROV	DME	Arrived	321	2017-07-20 18:17:00+03	2017-07-20 19:32:00+03
12929	PG0214	2017-08-21 14:20:00+03	2017-08-21 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12930	PG0215	2017-08-24 18:15:00+03	2017-08-24 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12931	PG0215	2017-09-01 18:15:00+03	2017-09-01 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12932	PG0215	2017-08-05 18:15:00+03	2017-08-05 19:30:00+03	ROV	DME	Arrived	321	2017-08-05 18:17:00+03	2017-08-05 19:31:00+03
12933	PG0214	2017-09-01 14:20:00+03	2017-09-01 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12934	PG0215	2017-08-07 18:15:00+03	2017-08-07 19:30:00+03	ROV	DME	Arrived	321	2017-08-07 18:17:00+03	2017-08-07 19:33:00+03
12935	PG0215	2017-09-03 18:15:00+03	2017-09-03 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12936	PG0215	2017-08-06 18:15:00+03	2017-08-06 19:30:00+03	ROV	DME	Arrived	321	2017-08-06 18:18:00+03	2017-08-06 19:33:00+03
12937	PG0215	2017-09-11 18:15:00+03	2017-09-11 19:30:00+03	ROV	DME	Scheduled	321	\N	\N
12938	PG0214	2017-07-20 14:20:00+03	2017-07-20 15:35:00+03	ROV	DME	Arrived	321	2017-07-20 14:20:00+03	2017-07-20 15:36:00+03
12939	PG0215	2017-07-24 18:15:00+03	2017-07-24 19:30:00+03	ROV	DME	Arrived	321	2017-07-24 21:36:00+03	2017-07-24 22:51:00+03
12940	PG0214	2017-07-31 14:20:00+03	2017-07-31 15:35:00+03	ROV	DME	Arrived	321	2017-07-31 14:26:00+03	2017-07-31 15:41:00+03
12941	PG0214	2017-07-24 14:20:00+03	2017-07-24 15:35:00+03	ROV	DME	Arrived	321	2017-07-24 14:25:00+03	2017-07-24 15:41:00+03
12942	PG0215	2017-07-22 18:15:00+03	2017-07-22 19:30:00+03	ROV	DME	Arrived	321	2017-07-22 18:20:00+03	2017-07-22 19:35:00+03
12943	PG0214	2017-07-22 14:20:00+03	2017-07-22 15:35:00+03	ROV	DME	Arrived	321	2017-07-22 17:01:00+03	2017-07-22 18:17:00+03
12944	PG0214	2017-09-05 14:20:00+03	2017-09-05 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12945	PG0214	2017-08-24 14:20:00+03	2017-08-24 15:35:00+03	ROV	DME	Scheduled	321	\N	\N
12946	PG0214	2017-08-12 14:20:00+03	2017-08-12 15:35:00+03	ROV	DME	Arrived	321	2017-08-12 17:52:00+03	2017-08-12 19:07:00+03
12947	PG0318	2017-08-20 15:00:00+03	2017-08-20 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12948	PG0318	2017-09-06 15:00:00+03	2017-09-06 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12949	PG0318	2017-07-20 15:00:00+03	2017-07-20 16:20:00+03	ROV	SVO	Arrived	733	2017-07-20 18:15:00+03	2017-07-20 19:35:00+03
12950	PG0318	2017-07-24 15:00:00+03	2017-07-24 16:20:00+03	ROV	SVO	Arrived	733	2017-07-24 17:47:00+03	2017-07-24 19:07:00+03
12951	PG0318	2017-08-26 15:00:00+03	2017-08-26 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12952	PG0318	2017-09-12 15:00:00+03	2017-09-12 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12953	PG0318	2017-08-05 15:00:00+03	2017-08-05 16:20:00+03	ROV	SVO	Arrived	733	2017-08-05 15:04:00+03	2017-08-05 16:24:00+03
12954	PG0318	2017-08-11 15:00:00+03	2017-08-11 16:20:00+03	ROV	SVO	Arrived	733	2017-08-11 15:02:00+03	2017-08-11 16:23:00+03
12955	PG0318	2017-08-04 15:00:00+03	2017-08-04 16:20:00+03	ROV	SVO	Arrived	733	2017-08-04 15:01:00+03	2017-08-04 16:21:00+03
12956	PG0318	2017-09-03 15:00:00+03	2017-09-03 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12957	PG0318	2017-09-11 15:00:00+03	2017-09-11 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12958	PG0318	2017-08-02 15:00:00+03	2017-08-02 16:20:00+03	ROV	SVO	Arrived	733	2017-08-02 15:02:00+03	2017-08-02 16:21:00+03
12959	PG0318	2017-08-29 15:00:00+03	2017-08-29 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12960	PG0318	2017-08-31 15:00:00+03	2017-08-31 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12961	PG0318	2017-09-07 15:00:00+03	2017-09-07 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12962	PG0318	2017-07-27 15:00:00+03	2017-07-27 16:20:00+03	ROV	SVO	Arrived	733	2017-07-27 15:02:00+03	2017-07-27 16:21:00+03
12963	PG0318	2017-07-28 15:00:00+03	2017-07-28 16:20:00+03	ROV	SVO	Arrived	733	2017-07-28 15:05:00+03	2017-07-28 16:24:00+03
12964	PG0318	2017-08-19 15:00:00+03	2017-08-19 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12965	PG0318	2017-08-08 15:00:00+03	2017-08-08 16:20:00+03	ROV	SVO	Arrived	733	2017-08-08 15:02:00+03	2017-08-08 16:21:00+03
12966	PG0318	2017-08-14 15:00:00+03	2017-08-14 16:20:00+03	ROV	SVO	Arrived	733	2017-08-14 15:03:00+03	2017-08-14 16:24:00+03
12967	PG0318	2017-08-15 15:00:00+03	2017-08-15 16:20:00+03	ROV	SVO	Arrived	733	2017-08-15 15:03:00+03	2017-08-15 16:22:00+03
12968	PG0318	2017-07-29 15:00:00+03	2017-07-29 16:20:00+03	ROV	SVO	Arrived	733	2017-07-29 15:07:00+03	2017-07-29 16:26:00+03
12969	PG0318	2017-07-17 15:00:00+03	2017-07-17 16:20:00+03	ROV	SVO	Arrived	733	2017-07-17 15:04:00+03	2017-07-17 16:24:00+03
12970	PG0318	2017-08-06 15:00:00+03	2017-08-06 16:20:00+03	ROV	SVO	Arrived	733	2017-08-06 15:02:00+03	2017-08-06 16:23:00+03
12971	PG0318	2017-09-13 15:00:00+03	2017-09-13 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12972	PG0318	2017-07-21 15:00:00+03	2017-07-21 16:20:00+03	ROV	SVO	Arrived	733	2017-07-21 15:01:00+03	2017-07-21 16:21:00+03
12973	PG0318	2017-07-16 15:00:00+03	2017-07-16 16:20:00+03	ROV	SVO	Arrived	733	2017-07-16 15:01:00+03	2017-07-16 16:20:00+03
12974	PG0318	2017-08-18 15:00:00+03	2017-08-18 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12975	PG0318	2017-08-07 15:00:00+03	2017-08-07 16:20:00+03	ROV	SVO	Arrived	733	2017-08-07 15:05:00+03	2017-08-07 16:25:00+03
12976	PG0318	2017-08-30 15:00:00+03	2017-08-30 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12977	PG0318	2017-08-01 15:00:00+03	2017-08-01 16:20:00+03	ROV	SVO	Arrived	733	2017-08-01 15:09:00+03	2017-08-01 16:28:00+03
12978	PG0318	2017-08-25 15:00:00+03	2017-08-25 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12979	PG0318	2017-08-22 15:00:00+03	2017-08-22 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12980	PG0318	2017-07-25 15:00:00+03	2017-07-25 16:20:00+03	ROV	SVO	Arrived	733	2017-07-25 15:03:00+03	2017-07-25 16:23:00+03
12981	PG0318	2017-09-14 15:00:00+03	2017-09-14 16:20:00+03	ROV	SVO	Cancelled	733	\N	\N
12982	PG0318	2017-08-10 15:00:00+03	2017-08-10 16:20:00+03	ROV	SVO	Arrived	733	2017-08-10 15:05:00+03	2017-08-10 16:26:00+03
12983	PG0318	2017-08-16 15:00:00+03	2017-08-16 16:20:00+03	ROV	SVO	On Time	733	\N	\N
12984	PG0318	2017-08-13 15:00:00+03	2017-08-13 16:20:00+03	ROV	SVO	Arrived	733	2017-08-13 15:03:00+03	2017-08-13 16:23:00+03
12985	PG0318	2017-07-19 15:00:00+03	2017-07-19 16:20:00+03	ROV	SVO	Arrived	733	2017-07-19 15:01:00+03	2017-07-19 16:19:00+03
12986	PG0318	2017-08-17 15:00:00+03	2017-08-17 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12987	PG0318	2017-08-21 15:00:00+03	2017-08-21 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12988	PG0318	2017-07-26 15:00:00+03	2017-07-26 16:20:00+03	ROV	SVO	Arrived	733	2017-07-26 15:03:00+03	2017-07-26 16:23:00+03
12989	PG0318	2017-07-22 15:00:00+03	2017-07-22 16:20:00+03	ROV	SVO	Arrived	733	2017-07-22 15:04:00+03	2017-07-22 16:24:00+03
12990	PG0318	2017-08-12 15:00:00+03	2017-08-12 16:20:00+03	ROV	SVO	Arrived	733	2017-08-12 15:03:00+03	2017-08-12 16:22:00+03
12991	PG0318	2017-07-18 15:00:00+03	2017-07-18 16:20:00+03	ROV	SVO	Arrived	733	2017-07-18 15:04:00+03	2017-07-18 16:26:00+03
12992	PG0318	2017-08-24 15:00:00+03	2017-08-24 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12993	PG0318	2017-09-08 15:00:00+03	2017-09-08 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12994	PG0318	2017-09-01 15:00:00+03	2017-09-01 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12995	PG0318	2017-09-04 15:00:00+03	2017-09-04 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12996	PG0318	2017-09-05 15:00:00+03	2017-09-05 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12997	PG0318	2017-08-28 15:00:00+03	2017-08-28 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12998	PG0318	2017-09-09 15:00:00+03	2017-09-09 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
12999	PG0318	2017-09-10 15:00:00+03	2017-09-10 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
13000	PG0318	2017-08-23 15:00:00+03	2017-08-23 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
13001	PG0318	2017-08-09 15:00:00+03	2017-08-09 16:20:00+03	ROV	SVO	Arrived	733	2017-08-09 15:02:00+03	2017-08-09 16:21:00+03
13002	PG0318	2017-08-03 15:00:00+03	2017-08-03 16:20:00+03	ROV	SVO	Arrived	733	2017-08-03 15:02:00+03	2017-08-03 16:23:00+03
13003	PG0318	2017-07-23 15:00:00+03	2017-07-23 16:20:00+03	ROV	SVO	Arrived	733	2017-07-23 15:03:00+03	2017-07-23 16:22:00+03
13004	PG0318	2017-08-27 15:00:00+03	2017-08-27 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
13005	PG0318	2017-07-30 15:00:00+03	2017-07-30 16:20:00+03	ROV	SVO	Arrived	733	2017-07-30 15:05:00+03	2017-07-30 16:25:00+03
13006	PG0318	2017-09-02 15:00:00+03	2017-09-02 16:20:00+03	ROV	SVO	Scheduled	733	\N	\N
13007	PG0318	2017-07-31 15:00:00+03	2017-07-31 16:20:00+03	ROV	SVO	Arrived	733	2017-07-31 15:02:00+03	2017-07-31 16:24:00+03
13008	PG0612	2017-08-06 16:25:00+03	2017-08-06 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-06 16:31:00+03	2017-08-06 20:10:00+03
13009	PG0612	2017-08-11 16:25:00+03	2017-08-11 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-11 16:26:00+03	2017-08-11 20:05:00+03
13010	PG0612	2017-08-03 16:25:00+03	2017-08-03 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-03 16:28:00+03	2017-08-03 20:07:00+03
13011	PG0612	2017-09-14 16:25:00+03	2017-09-14 20:05:00+03	ROV	KZN	Cancelled	CN1	\N	\N
13012	PG0611	2017-08-21 16:10:00+03	2017-08-21 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13013	PG0611	2017-08-31 16:10:00+03	2017-08-31 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13014	PG0611	2017-09-08 16:10:00+03	2017-09-08 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13015	PG0611	2017-08-03 16:10:00+03	2017-08-03 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-03 16:17:00+03	2017-08-03 19:59:00+03
13016	PG0611	2017-07-29 16:10:00+03	2017-07-29 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-29 16:12:00+03	2017-07-29 19:50:00+03
13017	PG0612	2017-09-11 16:25:00+03	2017-09-11 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13018	PG0611	2017-08-23 16:10:00+03	2017-08-23 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13019	PG0611	2017-08-11 16:10:00+03	2017-08-11 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-11 16:14:00+03	2017-08-11 19:55:00+03
13020	PG0611	2017-08-15 16:10:00+03	2017-08-15 19:50:00+03	ROV	KZN	Delayed	CN1	\N	\N
13021	PG0612	2017-09-06 16:25:00+03	2017-09-06 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13022	PG0611	2017-07-20 16:10:00+03	2017-07-20 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-20 16:14:00+03	2017-07-20 19:58:00+03
13023	PG0612	2017-07-30 16:25:00+03	2017-07-30 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-30 16:27:00+03	2017-07-30 20:05:00+03
13024	PG0612	2017-08-15 16:25:00+03	2017-08-15 20:05:00+03	ROV	KZN	Departed	CN1	2017-08-15 16:27:00+03	\N
13025	PG0611	2017-09-14 16:10:00+03	2017-09-14 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13026	PG0612	2017-08-10 16:25:00+03	2017-08-10 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-10 16:28:00+03	2017-08-10 20:10:00+03
13027	PG0611	2017-08-10 16:10:00+03	2017-08-10 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-10 16:14:00+03	2017-08-10 19:53:00+03
13028	PG0611	2017-07-26 16:10:00+03	2017-07-26 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-26 16:15:00+03	2017-07-26 19:58:00+03
13029	PG0611	2017-09-02 16:10:00+03	2017-09-02 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13030	PG0611	2017-07-16 16:10:00+03	2017-07-16 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-16 16:19:00+03	2017-07-16 20:02:00+03
13031	PG0611	2017-08-01 16:10:00+03	2017-08-01 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-01 16:13:00+03	2017-08-01 19:53:00+03
13032	PG0612	2017-09-02 16:25:00+03	2017-09-02 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13033	PG0611	2017-08-09 16:10:00+03	2017-08-09 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-09 16:10:00+03	2017-08-09 19:54:00+03
13034	PG0612	2017-08-01 16:25:00+03	2017-08-01 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-01 16:30:00+03	2017-08-01 20:09:00+03
13035	PG0612	2017-09-12 16:25:00+03	2017-09-12 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13036	PG0611	2017-09-13 16:10:00+03	2017-09-13 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13037	PG0612	2017-09-13 16:25:00+03	2017-09-13 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13038	PG0611	2017-08-20 16:10:00+03	2017-08-20 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13039	PG0611	2017-07-31 16:10:00+03	2017-07-31 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-31 16:12:00+03	2017-07-31 19:54:00+03
13040	PG0612	2017-08-07 16:25:00+03	2017-08-07 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-07 16:27:00+03	2017-08-07 20:06:00+03
13041	PG0611	2017-08-07 16:10:00+03	2017-08-07 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-07 16:11:00+03	2017-08-07 19:53:00+03
13042	PG0612	2017-09-07 16:25:00+03	2017-09-07 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13043	PG0612	2017-08-12 16:25:00+03	2017-08-12 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-12 16:27:00+03	2017-08-12 20:11:00+03
13044	PG0611	2017-08-05 16:10:00+03	2017-08-05 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-05 16:13:00+03	2017-08-05 19:53:00+03
13045	PG0612	2017-07-16 16:25:00+03	2017-07-16 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-16 16:29:00+03	2017-07-16 20:11:00+03
13046	PG0611	2017-08-04 16:10:00+03	2017-08-04 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-04 16:17:00+03	2017-08-04 19:56:00+03
13047	PG0612	2017-08-04 16:25:00+03	2017-08-04 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-04 16:26:00+03	2017-08-04 20:07:00+03
13048	PG0611	2017-08-12 16:10:00+03	2017-08-12 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-12 16:16:00+03	2017-08-12 19:54:00+03
13049	PG0612	2017-09-01 16:25:00+03	2017-09-01 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13050	PG0611	2017-09-12 16:10:00+03	2017-09-12 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13051	PG0611	2017-08-26 16:10:00+03	2017-08-26 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13052	PG0612	2017-09-05 16:25:00+03	2017-09-05 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13053	PG0611	2017-09-05 16:10:00+03	2017-09-05 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13054	PG0612	2017-07-27 16:25:00+03	2017-07-27 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-27 16:28:00+03	2017-07-27 20:08:00+03
13055	PG0612	2017-07-26 16:25:00+03	2017-07-26 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-26 16:29:00+03	2017-07-26 20:09:00+03
13056	PG0612	2017-07-25 16:25:00+03	2017-07-25 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-25 16:27:00+03	2017-07-25 20:07:00+03
13057	PG0611	2017-09-03 16:10:00+03	2017-09-03 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13058	PG0612	2017-07-24 16:25:00+03	2017-07-24 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-24 16:26:00+03	2017-07-24 20:03:00+03
13059	PG0611	2017-07-19 16:10:00+03	2017-07-19 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-19 19:36:00+03	2017-07-19 23:14:00+03
13060	PG0611	2017-09-01 16:10:00+03	2017-09-01 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13061	PG0611	2017-07-24 16:10:00+03	2017-07-24 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-24 16:10:00+03	2017-07-24 19:51:00+03
13062	PG0612	2017-07-28 16:25:00+03	2017-07-28 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-28 16:30:00+03	2017-07-28 20:09:00+03
13063	PG0611	2017-08-02 16:10:00+03	2017-08-02 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-02 16:12:00+03	2017-08-02 19:51:00+03
13064	PG0611	2017-07-27 16:10:00+03	2017-07-27 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-27 16:17:00+03	2017-07-27 19:56:00+03
13065	PG0611	2017-08-16 16:10:00+03	2017-08-16 19:50:00+03	ROV	KZN	On Time	CN1	\N	\N
13066	PG0612	2017-08-29 16:25:00+03	2017-08-29 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13067	PG0612	2017-08-25 16:25:00+03	2017-08-25 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13068	PG0612	2017-07-31 16:25:00+03	2017-07-31 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-31 16:29:00+03	2017-07-31 20:13:00+03
13069	PG0612	2017-08-02 16:25:00+03	2017-08-02 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-02 16:25:00+03	2017-08-02 20:07:00+03
13070	PG0612	2017-09-09 16:25:00+03	2017-09-09 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13071	PG0611	2017-09-07 16:10:00+03	2017-09-07 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13072	PG0612	2017-08-24 16:25:00+03	2017-08-24 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13073	PG0612	2017-09-04 16:25:00+03	2017-09-04 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13074	PG0612	2017-08-23 16:25:00+03	2017-08-23 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13075	PG0611	2017-08-27 16:10:00+03	2017-08-27 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13076	PG0611	2017-09-04 16:10:00+03	2017-09-04 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13077	PG0612	2017-09-10 16:25:00+03	2017-09-10 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13078	PG0611	2017-08-18 16:10:00+03	2017-08-18 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13079	PG0611	2017-07-30 16:10:00+03	2017-07-30 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-30 16:11:00+03	2017-07-30 19:52:00+03
13080	PG0611	2017-07-25 16:10:00+03	2017-07-25 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-25 16:12:00+03	2017-07-25 19:53:00+03
13081	PG0611	2017-07-28 16:10:00+03	2017-07-28 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-28 16:15:00+03	2017-07-28 19:57:00+03
13082	PG0612	2017-08-14 16:25:00+03	2017-08-14 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-14 16:27:00+03	2017-08-14 20:07:00+03
13083	PG0611	2017-08-14 16:10:00+03	2017-08-14 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-14 16:15:00+03	2017-08-14 19:54:00+03
13084	PG0612	2017-08-26 16:25:00+03	2017-08-26 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13085	PG0612	2017-07-21 16:25:00+03	2017-07-21 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-21 16:27:00+03	2017-07-21 20:08:00+03
13086	PG0611	2017-08-29 16:10:00+03	2017-08-29 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13087	PG0611	2017-08-28 16:10:00+03	2017-08-28 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13088	PG0611	2017-08-25 16:10:00+03	2017-08-25 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13089	PG0612	2017-08-19 16:25:00+03	2017-08-19 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13090	PG0611	2017-09-10 16:10:00+03	2017-09-10 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13091	PG0611	2017-07-21 16:10:00+03	2017-07-21 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-21 16:13:00+03	2017-07-21 19:54:00+03
13092	PG0612	2017-08-05 16:25:00+03	2017-08-05 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-05 16:27:00+03	2017-08-05 20:09:00+03
13093	PG0611	2017-08-19 16:10:00+03	2017-08-19 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13094	PG0612	2017-08-28 16:25:00+03	2017-08-28 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13095	PG0611	2017-08-30 16:10:00+03	2017-08-30 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13096	PG0611	2017-07-22 16:10:00+03	2017-07-22 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-22 16:12:00+03	2017-07-22 19:50:00+03
13097	PG0612	2017-08-30 16:25:00+03	2017-08-30 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13098	PG0612	2017-07-22 16:25:00+03	2017-07-22 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-22 16:26:00+03	2017-07-22 20:03:00+03
13099	PG0612	2017-08-27 16:25:00+03	2017-08-27 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13100	PG0612	2017-08-16 16:25:00+03	2017-08-16 20:05:00+03	ROV	KZN	On Time	CN1	\N	\N
13101	PG0612	2017-07-17 16:25:00+03	2017-07-17 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-17 16:27:00+03	2017-07-17 20:04:00+03
13102	PG0611	2017-08-17 16:10:00+03	2017-08-17 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13103	PG0611	2017-08-13 16:10:00+03	2017-08-13 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-13 16:14:00+03	2017-08-13 19:54:00+03
13104	PG0611	2017-07-17 16:10:00+03	2017-07-17 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-17 16:11:00+03	2017-07-17 19:51:00+03
13105	PG0612	2017-09-03 16:25:00+03	2017-09-03 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13106	PG0612	2017-08-17 16:25:00+03	2017-08-17 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13107	PG0612	2017-08-20 16:25:00+03	2017-08-20 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13108	PG0612	2017-07-23 16:25:00+03	2017-07-23 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-23 16:28:00+03	2017-07-23 20:11:00+03
13109	PG0612	2017-07-29 16:25:00+03	2017-07-29 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-29 16:29:00+03	2017-07-29 20:12:00+03
13110	PG0612	2017-08-09 16:25:00+03	2017-08-09 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-09 16:31:00+03	2017-08-09 20:11:00+03
13111	PG0612	2017-08-13 16:25:00+03	2017-08-13 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-13 16:29:00+03	2017-08-13 20:06:00+03
13112	PG0611	2017-07-23 16:10:00+03	2017-07-23 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-23 16:14:00+03	2017-07-23 19:55:00+03
13114	PG0611	2017-08-24 16:10:00+03	2017-08-24 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13115	PG0612	2017-09-08 16:25:00+03	2017-09-08 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13116	PG0611	2017-08-06 16:10:00+03	2017-08-06 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-06 16:12:00+03	2017-08-06 19:47:00+03
13117	PG0611	2017-08-08 16:10:00+03	2017-08-08 19:50:00+03	ROV	KZN	Arrived	CN1	2017-08-08 16:12:00+03	2017-08-08 19:54:00+03
13118	PG0612	2017-07-20 16:25:00+03	2017-07-20 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-20 16:26:00+03	2017-07-20 20:06:00+03
13119	PG0611	2017-09-09 16:10:00+03	2017-09-09 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13120	PG0611	2017-09-11 16:10:00+03	2017-09-11 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13121	PG0612	2017-07-18 16:25:00+03	2017-07-18 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-18 16:28:00+03	2017-07-18 20:07:00+03
13122	PG0611	2017-07-18 16:10:00+03	2017-07-18 19:50:00+03	ROV	KZN	Arrived	CN1	2017-07-18 16:11:00+03	2017-07-18 19:51:00+03
13123	PG0612	2017-07-19 16:25:00+03	2017-07-19 20:05:00+03	ROV	KZN	Arrived	CN1	2017-07-19 16:27:00+03	2017-07-19 20:07:00+03
13124	PG0611	2017-08-22 16:10:00+03	2017-08-22 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13125	PG0612	2017-08-08 16:25:00+03	2017-08-08 20:05:00+03	ROV	KZN	Arrived	CN1	2017-08-08 16:26:00+03	2017-08-08 20:10:00+03
13126	PG0612	2017-08-21 16:25:00+03	2017-08-21 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13127	PG0611	2017-09-06 16:10:00+03	2017-09-06 19:50:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13128	PG0612	2017-08-31 16:25:00+03	2017-08-31 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13129	PG0612	2017-08-22 16:25:00+03	2017-08-22 20:05:00+03	ROV	KZN	Scheduled	CN1	\N	\N
13130	PG0307	2017-08-28 16:00:00+03	2017-08-28 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13131	PG0307	2017-07-25 16:00:00+03	2017-07-25 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-25 16:01:00+03	2017-07-25 16:31:00+03
13132	PG0307	2017-08-01 16:00:00+03	2017-08-01 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-01 16:01:00+03	2017-08-01 16:31:00+03
13133	PG0307	2017-09-04 16:00:00+03	2017-09-04 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13134	PG0307	2017-08-07 16:00:00+03	2017-08-07 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-07 16:03:00+03	2017-08-07 16:33:00+03
13135	PG0307	2017-08-13 16:00:00+03	2017-08-13 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-13 16:05:00+03	2017-08-13 16:35:00+03
13136	PG0307	2017-08-31 16:00:00+03	2017-08-31 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13137	PG0307	2017-07-19 16:00:00+03	2017-07-19 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-19 16:05:00+03	2017-07-19 16:35:00+03
13138	PG0307	2017-08-17 16:00:00+03	2017-08-17 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13139	PG0307	2017-08-10 16:00:00+03	2017-08-10 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-10 16:02:00+03	2017-08-10 16:32:00+03
13140	PG0307	2017-08-30 16:00:00+03	2017-08-30 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13141	PG0307	2017-09-13 16:00:00+03	2017-09-13 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13142	PG0307	2017-08-12 16:00:00+03	2017-08-12 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-12 16:04:00+03	2017-08-12 16:34:00+03
13143	PG0307	2017-08-20 16:00:00+03	2017-08-20 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13144	PG0307	2017-07-18 16:00:00+03	2017-07-18 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-18 16:07:00+03	2017-07-18 16:37:00+03
13145	PG0307	2017-07-21 16:00:00+03	2017-07-21 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-21 16:05:00+03	2017-07-21 16:35:00+03
13146	PG0307	2017-08-23 16:00:00+03	2017-08-23 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13147	PG0307	2017-08-15 16:00:00+03	2017-08-15 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-15 16:03:00+03	2017-08-15 16:33:00+03
13148	PG0307	2017-07-16 16:00:00+03	2017-07-16 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-16 16:05:00+03	2017-07-16 16:36:00+03
13149	PG0307	2017-07-17 16:00:00+03	2017-07-17 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-17 16:03:00+03	2017-07-17 16:33:00+03
13150	PG0307	2017-09-05 16:00:00+03	2017-09-05 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13151	PG0307	2017-08-24 16:00:00+03	2017-08-24 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13152	PG0307	2017-08-19 16:00:00+03	2017-08-19 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13153	PG0307	2017-08-08 16:00:00+03	2017-08-08 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-08 16:04:00+03	2017-08-08 16:34:00+03
13154	PG0307	2017-08-25 16:00:00+03	2017-08-25 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13155	PG0307	2017-08-06 16:00:00+03	2017-08-06 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-06 16:08:00+03	2017-08-06 16:38:00+03
13156	PG0307	2017-08-22 16:00:00+03	2017-08-22 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13157	PG0307	2017-08-29 16:00:00+03	2017-08-29 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13158	PG0307	2017-09-08 16:00:00+03	2017-09-08 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13159	PG0307	2017-07-28 16:00:00+03	2017-07-28 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-28 16:02:00+03	2017-07-28 16:32:00+03
13160	PG0307	2017-08-16 16:00:00+03	2017-08-16 16:30:00+03	ROV	VOG	On Time	SU9	\N	\N
13161	PG0307	2017-08-14 16:00:00+03	2017-08-14 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-14 16:02:00+03	2017-08-14 16:32:00+03
13162	PG0307	2017-08-21 16:00:00+03	2017-08-21 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13163	PG0307	2017-07-23 16:00:00+03	2017-07-23 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-23 16:03:00+03	2017-07-23 16:33:00+03
13164	PG0307	2017-09-10 16:00:00+03	2017-09-10 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13165	PG0307	2017-07-27 16:00:00+03	2017-07-27 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-27 16:02:00+03	2017-07-27 16:32:00+03
13166	PG0307	2017-08-09 16:00:00+03	2017-08-09 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-09 16:04:00+03	2017-08-09 16:34:00+03
13167	PG0307	2017-09-09 16:00:00+03	2017-09-09 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13168	PG0307	2017-08-03 16:00:00+03	2017-08-03 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-03 16:02:00+03	2017-08-03 16:32:00+03
13169	PG0307	2017-08-26 16:00:00+03	2017-08-26 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13170	PG0307	2017-07-30 16:00:00+03	2017-07-30 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-30 19:13:00+03	2017-07-30 19:43:00+03
13171	PG0307	2017-09-07 16:00:00+03	2017-09-07 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13172	PG0307	2017-08-02 16:00:00+03	2017-08-02 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-02 16:03:00+03	2017-08-02 16:33:00+03
13173	PG0307	2017-07-20 16:00:00+03	2017-07-20 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-20 16:02:00+03	2017-07-20 16:32:00+03
13174	PG0307	2017-08-04 16:00:00+03	2017-08-04 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-04 16:02:00+03	2017-08-04 16:32:00+03
13175	PG0307	2017-07-22 16:00:00+03	2017-07-22 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-22 16:02:00+03	2017-07-22 16:33:00+03
13176	PG0307	2017-09-12 16:00:00+03	2017-09-12 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13177	PG0307	2017-07-26 16:00:00+03	2017-07-26 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-26 16:01:00+03	2017-07-26 16:31:00+03
13178	PG0307	2017-07-31 16:00:00+03	2017-07-31 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-31 16:03:00+03	2017-07-31 16:33:00+03
13179	PG0307	2017-09-03 16:00:00+03	2017-09-03 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13180	PG0307	2017-09-02 16:00:00+03	2017-09-02 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13181	PG0307	2017-08-05 16:00:00+03	2017-08-05 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-05 16:04:00+03	2017-08-05 16:34:00+03
13182	PG0307	2017-09-11 16:00:00+03	2017-09-11 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13183	PG0307	2017-07-29 16:00:00+03	2017-07-29 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-29 16:05:00+03	2017-07-29 16:35:00+03
13184	PG0307	2017-09-01 16:00:00+03	2017-09-01 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13185	PG0307	2017-09-06 16:00:00+03	2017-09-06 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13186	PG0307	2017-07-24 16:00:00+03	2017-07-24 16:30:00+03	ROV	VOG	Arrived	SU9	2017-07-24 16:04:00+03	2017-07-24 16:34:00+03
13187	PG0307	2017-08-27 16:00:00+03	2017-08-27 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13188	PG0307	2017-08-11 16:00:00+03	2017-08-11 16:30:00+03	ROV	VOG	Arrived	SU9	2017-08-11 16:01:00+03	2017-08-11 16:32:00+03
13189	PG0307	2017-09-14 16:00:00+03	2017-09-14 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13190	PG0307	2017-08-18 16:00:00+03	2017-08-18 16:30:00+03	ROV	VOG	Scheduled	SU9	\N	\N
13191	PG0557	2017-07-22 16:10:00+03	2017-07-22 18:30:00+03	ROV	PES	Arrived	CR2	2017-07-22 16:11:00+03	2017-07-22 18:30:00+03
13192	PG0557	2017-09-02 16:10:00+03	2017-09-02 18:30:00+03	ROV	PES	Scheduled	CR2	\N	\N
13193	PG0557	2017-08-05 16:10:00+03	2017-08-05 18:30:00+03	ROV	PES	Arrived	CR2	2017-08-05 16:14:00+03	2017-08-05 18:33:00+03
13194	PG0557	2017-07-29 16:10:00+03	2017-07-29 18:30:00+03	ROV	PES	Arrived	CR2	2017-07-29 16:11:00+03	2017-07-29 18:31:00+03
13195	PG0557	2017-08-19 16:10:00+03	2017-08-19 18:30:00+03	ROV	PES	Scheduled	CR2	\N	\N
13196	PG0557	2017-08-12 16:10:00+03	2017-08-12 18:30:00+03	ROV	PES	Arrived	CR2	2017-08-12 16:13:00+03	2017-08-12 18:31:00+03
13197	PG0557	2017-08-26 16:10:00+03	2017-08-26 18:30:00+03	ROV	PES	Scheduled	CR2	\N	\N
13198	PG0557	2017-09-09 16:10:00+03	2017-09-09 18:30:00+03	ROV	PES	Scheduled	CR2	\N	\N
13199	PG0122	2017-08-21 16:30:00+03	2017-08-21 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13200	PG0122	2017-09-11 16:30:00+03	2017-09-11 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13201	PG0122	2017-07-24 16:30:00+03	2017-07-24 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-24 16:34:00+03	2017-07-24 18:19:00+03
13202	PG0122	2017-08-12 16:30:00+03	2017-08-12 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-12 16:33:00+03	2017-08-12 18:18:00+03
13203	PG0122	2017-09-14 16:30:00+03	2017-09-14 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13204	PG0122	2017-08-14 16:30:00+03	2017-08-14 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-14 16:32:00+03	2017-08-14 18:16:00+03
13205	PG0122	2017-08-28 16:30:00+03	2017-08-28 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13206	PG0122	2017-08-10 16:30:00+03	2017-08-10 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-10 16:32:00+03	2017-08-10 18:17:00+03
13207	PG0122	2017-08-05 16:30:00+03	2017-08-05 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-05 16:32:00+03	2017-08-05 18:17:00+03
13208	PG0122	2017-09-02 16:30:00+03	2017-09-02 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13209	PG0122	2017-09-04 16:30:00+03	2017-09-04 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13210	PG0122	2017-07-29 16:30:00+03	2017-07-29 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-29 16:33:00+03	2017-07-29 18:18:00+03
13211	PG0122	2017-08-24 16:30:00+03	2017-08-24 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13212	PG0122	2017-09-09 16:30:00+03	2017-09-09 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13213	PG0122	2017-07-17 16:30:00+03	2017-07-17 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-17 16:35:00+03	2017-07-17 18:20:00+03
13214	PG0122	2017-07-22 16:30:00+03	2017-07-22 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-22 16:32:00+03	2017-07-22 18:19:00+03
13215	PG0122	2017-07-20 16:30:00+03	2017-07-20 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-20 19:41:00+03	2017-07-20 21:26:00+03
13216	PG0122	2017-08-07 16:30:00+03	2017-08-07 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-07 16:34:00+03	2017-08-07 18:19:00+03
13217	PG0122	2017-08-19 16:30:00+03	2017-08-19 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13218	PG0122	2017-09-07 16:30:00+03	2017-09-07 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13219	PG0122	2017-08-31 16:30:00+03	2017-08-31 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13220	PG0122	2017-08-03 16:30:00+03	2017-08-03 18:15:00+03	ROV	NBC	Arrived	CR2	2017-08-03 16:33:00+03	2017-08-03 18:18:00+03
13221	PG0122	2017-07-31 16:30:00+03	2017-07-31 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-31 16:33:00+03	2017-07-31 18:16:00+03
13222	PG0122	2017-08-17 16:30:00+03	2017-08-17 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13223	PG0122	2017-08-26 16:30:00+03	2017-08-26 18:15:00+03	ROV	NBC	Scheduled	CR2	\N	\N
13224	PG0122	2017-07-27 16:30:00+03	2017-07-27 18:15:00+03	ROV	NBC	Arrived	CR2	2017-07-27 16:34:00+03	2017-07-27 18:20:00+03
13225	PG0635	2017-08-19 09:55:00+03	2017-08-19 13:15:00+03	ROV	NYA	Scheduled	CR2	\N	\N
13226	PG0635	2017-09-09 09:55:00+03	2017-09-09 13:15:00+03	ROV	NYA	Cancelled	CR2	\N	\N
13227	PG0635	2017-08-26 09:55:00+03	2017-08-26 13:15:00+03	ROV	NYA	Scheduled	CR2	\N	\N
13228	PG0635	2017-07-22 09:55:00+03	2017-07-22 13:15:00+03	ROV	NYA	Arrived	CR2	2017-07-22 09:58:00+03	2017-07-22 13:19:00+03
13229	PG0635	2017-08-12 09:55:00+03	2017-08-12 13:15:00+03	ROV	NYA	Arrived	CR2	2017-08-12 09:56:00+03	2017-08-12 13:16:00+03
13230	PG0635	2017-07-29 09:55:00+03	2017-07-29 13:15:00+03	ROV	NYA	Arrived	CR2	2017-07-29 10:02:00+03	2017-07-29 13:22:00+03
13231	PG0635	2017-08-05 09:55:00+03	2017-08-05 13:15:00+03	ROV	NYA	Arrived	CR2	2017-08-05 09:58:00+03	2017-08-05 13:17:00+03
13232	PG0635	2017-09-02 09:55:00+03	2017-09-02 13:15:00+03	ROV	NYA	Scheduled	CR2	\N	\N
13233	PG0527	2017-09-10 14:25:00+03	2017-09-10 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13234	PG0527	2017-08-31 14:25:00+03	2017-08-31 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13235	PG0527	2017-07-30 14:25:00+03	2017-07-30 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-07-30 14:32:00+03	2017-07-30 15:38:00+03
13236	PG0527	2017-07-23 14:25:00+03	2017-07-23 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-07-23 14:27:00+03	2017-07-23 15:30:00+03
13237	PG0527	2017-08-17 14:25:00+03	2017-08-17 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13238	PG0527	2017-09-03 14:25:00+03	2017-09-03 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13239	PG0527	2017-07-20 14:25:00+03	2017-07-20 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-07-20 14:27:00+03	2017-07-20 15:32:00+03
13240	PG0527	2017-07-27 14:25:00+03	2017-07-27 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-07-27 14:26:00+03	2017-07-27 15:31:00+03
13241	PG0527	2017-07-16 14:25:00+03	2017-07-16 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-07-16 14:27:00+03	2017-07-16 15:32:00+03
13242	PG0527	2017-08-10 14:25:00+03	2017-08-10 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-08-10 14:28:00+03	2017-08-10 15:32:00+03
13243	PG0527	2017-08-24 14:25:00+03	2017-08-24 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13244	PG0527	2017-08-13 14:25:00+03	2017-08-13 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-08-13 14:27:00+03	2017-08-13 15:31:00+03
13245	PG0527	2017-08-03 14:25:00+03	2017-08-03 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-08-03 14:27:00+03	2017-08-03 15:32:00+03
13246	PG0527	2017-09-07 14:25:00+03	2017-09-07 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13247	PG0527	2017-09-14 14:25:00+03	2017-09-14 15:30:00+03	ROV	GDZ	Cancelled	CN1	\N	\N
13248	PG0527	2017-08-20 14:25:00+03	2017-08-20 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13249	PG0527	2017-08-06 14:25:00+03	2017-08-06 15:30:00+03	ROV	GDZ	Arrived	CN1	2017-08-06 14:31:00+03	2017-08-06 15:36:00+03
13250	PG0527	2017-08-27 14:25:00+03	2017-08-27 15:30:00+03	ROV	GDZ	Scheduled	CN1	\N	\N
13251	PG0693	2017-09-02 10:00:00+03	2017-09-02 14:15:00+03	ROV	TOF	Scheduled	319	\N	\N
13252	PG0693	2017-08-12 10:00:00+03	2017-08-12 14:15:00+03	ROV	TOF	Arrived	319	2017-08-12 10:02:00+03	2017-08-12 14:13:00+03
13253	PG0693	2017-07-22 10:00:00+03	2017-07-22 14:15:00+03	ROV	TOF	Arrived	319	2017-07-22 10:02:00+03	2017-07-22 14:16:00+03
13254	PG0693	2017-07-29 10:00:00+03	2017-07-29 14:15:00+03	ROV	TOF	Arrived	319	2017-07-29 10:01:00+03	2017-07-29 14:19:00+03
13255	PG0693	2017-09-09 10:00:00+03	2017-09-09 14:15:00+03	ROV	TOF	Cancelled	319	\N	\N
13256	PG0693	2017-08-05 10:00:00+03	2017-08-05 14:15:00+03	ROV	TOF	Arrived	319	2017-08-05 10:02:00+03	2017-08-05 14:21:00+03
13257	PG0693	2017-08-19 10:00:00+03	2017-08-19 14:15:00+03	ROV	TOF	Scheduled	319	\N	\N
13258	PG0693	2017-08-26 10:00:00+03	2017-08-26 14:15:00+03	ROV	TOF	Scheduled	319	\N	\N
13259	PG0485	2017-08-04 11:15:00+03	2017-08-04 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-04 11:17:00+03	2017-08-04 11:51:00+03
13260	PG0485	2017-07-27 11:15:00+03	2017-07-27 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-27 11:17:00+03	2017-07-27 11:52:00+03
13261	PG0485	2017-09-09 11:15:00+03	2017-09-09 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13262	PG0484	2017-09-07 11:40:00+03	2017-09-07 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13263	PG0484	2017-07-26 11:40:00+03	2017-07-26 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-26 11:43:00+03	2017-07-26 12:18:00+03
13264	PG0484	2017-09-05 11:40:00+03	2017-09-05 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13265	PG0484	2017-07-29 11:40:00+03	2017-07-29 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-29 11:43:00+03	2017-07-29 12:18:00+03
13266	PG0485	2017-08-27 11:15:00+03	2017-08-27 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13267	PG0484	2017-08-06 11:40:00+03	2017-08-06 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-06 11:46:00+03	2017-08-06 12:21:00+03
13268	PG0485	2017-08-21 11:15:00+03	2017-08-21 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13269	PG0484	2017-08-21 11:40:00+03	2017-08-21 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13270	PG0485	2017-08-16 11:15:00+03	2017-08-16 11:50:00+03	ROV	AER	On Time	SU9	\N	\N
13271	PG0485	2017-08-06 11:15:00+03	2017-08-06 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-06 11:20:00+03	2017-08-06 11:55:00+03
13272	PG0484	2017-08-03 11:40:00+03	2017-08-03 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-03 11:43:00+03	2017-08-03 12:18:00+03
13273	PG0485	2017-07-19 11:15:00+03	2017-07-19 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-19 11:18:00+03	2017-07-19 11:52:00+03
13274	PG0485	2017-08-03 11:15:00+03	2017-08-03 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-03 11:18:00+03	2017-08-03 11:53:00+03
13275	PG0484	2017-09-06 11:40:00+03	2017-09-06 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13276	PG0485	2017-08-23 11:15:00+03	2017-08-23 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13277	PG0485	2017-07-30 11:15:00+03	2017-07-30 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-30 11:17:00+03	2017-07-30 11:51:00+03
13278	PG0485	2017-08-28 11:15:00+03	2017-08-28 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13279	PG0484	2017-07-20 11:40:00+03	2017-07-20 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-20 11:41:00+03	2017-07-20 12:16:00+03
13280	PG0485	2017-08-02 11:15:00+03	2017-08-02 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-02 11:17:00+03	2017-08-02 11:52:00+03
13281	PG0485	2017-07-20 11:15:00+03	2017-07-20 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-20 11:18:00+03	2017-07-20 11:54:00+03
13282	PG0485	2017-08-25 11:15:00+03	2017-08-25 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13283	PG0485	2017-07-21 11:15:00+03	2017-07-21 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-21 11:17:00+03	2017-07-21 11:52:00+03
13284	PG0484	2017-09-04 11:40:00+03	2017-09-04 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13285	PG0485	2017-07-29 11:15:00+03	2017-07-29 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-29 11:20:00+03	2017-07-29 11:55:00+03
13286	PG0484	2017-09-11 11:40:00+03	2017-09-11 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13287	PG0485	2017-09-01 11:15:00+03	2017-09-01 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13288	PG0484	2017-09-01 11:40:00+03	2017-09-01 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13289	PG0484	2017-08-12 11:40:00+03	2017-08-12 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-12 11:43:00+03	2017-08-12 12:18:00+03
13290	PG0485	2017-08-12 11:15:00+03	2017-08-12 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-12 11:17:00+03	2017-08-12 11:52:00+03
13291	PG0484	2017-07-31 11:40:00+03	2017-07-31 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-31 11:42:00+03	2017-07-31 12:18:00+03
13292	PG0485	2017-09-13 11:15:00+03	2017-09-13 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13293	PG0485	2017-08-26 11:15:00+03	2017-08-26 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13294	PG0484	2017-09-13 11:40:00+03	2017-09-13 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13295	PG0485	2017-09-04 11:15:00+03	2017-09-04 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13296	PG0484	2017-09-12 11:40:00+03	2017-09-12 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13297	PG0485	2017-08-11 11:15:00+03	2017-08-11 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-11 11:17:00+03	2017-08-11 11:52:00+03
13298	PG0485	2017-07-31 11:15:00+03	2017-07-31 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-31 11:18:00+03	2017-07-31 11:53:00+03
13299	PG0484	2017-07-21 11:40:00+03	2017-07-21 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-21 11:46:00+03	2017-07-21 12:21:00+03
13300	PG0485	2017-08-17 11:15:00+03	2017-08-17 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13301	PG0484	2017-08-26 11:40:00+03	2017-08-26 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13302	PG0484	2017-08-17 11:40:00+03	2017-08-17 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13303	PG0484	2017-07-24 11:40:00+03	2017-07-24 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-24 11:40:00+03	2017-07-24 12:15:00+03
13304	PG0484	2017-09-02 11:40:00+03	2017-09-02 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13305	PG0485	2017-07-17 11:15:00+03	2017-07-17 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-17 11:20:00+03	2017-07-17 11:55:00+03
13306	PG0484	2017-08-18 11:40:00+03	2017-08-18 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13307	PG0485	2017-09-02 11:15:00+03	2017-09-02 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13308	PG0484	2017-08-08 11:40:00+03	2017-08-08 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-08 11:44:00+03	2017-08-08 12:19:00+03
13309	PG0484	2017-08-13 11:40:00+03	2017-08-13 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-13 11:46:00+03	2017-08-13 12:21:00+03
13310	PG0484	2017-08-04 11:40:00+03	2017-08-04 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-04 11:44:00+03	2017-08-04 12:19:00+03
13311	PG0485	2017-08-08 11:15:00+03	2017-08-08 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-08 11:17:00+03	2017-08-08 11:52:00+03
13312	PG0485	2017-08-13 11:15:00+03	2017-08-13 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-13 11:17:00+03	2017-08-13 11:52:00+03
13313	PG0485	2017-08-31 11:15:00+03	2017-08-31 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13314	PG0485	2017-08-29 11:15:00+03	2017-08-29 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13315	PG0484	2017-07-30 11:40:00+03	2017-07-30 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-30 11:43:00+03	2017-07-30 12:18:00+03
13316	PG0485	2017-09-08 11:15:00+03	2017-09-08 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13317	PG0484	2017-08-20 11:40:00+03	2017-08-20 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13318	PG0485	2017-09-05 11:15:00+03	2017-09-05 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13319	PG0484	2017-08-29 11:40:00+03	2017-08-29 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13320	PG0485	2017-07-22 11:15:00+03	2017-07-22 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-22 11:17:00+03	2017-07-22 11:52:00+03
13321	PG0484	2017-08-23 11:40:00+03	2017-08-23 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13322	PG0484	2017-09-08 11:40:00+03	2017-09-08 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13323	PG0484	2017-07-17 11:40:00+03	2017-07-17 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-17 11:41:00+03	2017-07-17 12:15:00+03
13324	PG0484	2017-08-19 11:40:00+03	2017-08-19 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13325	PG0485	2017-07-24 11:15:00+03	2017-07-24 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-24 11:16:00+03	2017-07-24 11:51:00+03
13326	PG0485	2017-08-24 11:15:00+03	2017-08-24 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13327	PG0485	2017-08-18 11:15:00+03	2017-08-18 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13328	PG0484	2017-08-24 11:40:00+03	2017-08-24 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13329	PG0485	2017-08-19 11:15:00+03	2017-08-19 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13330	PG0485	2017-08-20 11:15:00+03	2017-08-20 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13331	PG0485	2017-07-18 11:15:00+03	2017-07-18 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-18 11:16:00+03	2017-07-18 11:51:00+03
13332	PG0484	2017-07-18 11:40:00+03	2017-07-18 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-18 11:42:00+03	2017-07-18 12:17:00+03
13333	PG0484	2017-08-31 11:40:00+03	2017-08-31 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13334	PG0484	2017-07-22 11:40:00+03	2017-07-22 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-22 11:46:00+03	2017-07-22 12:20:00+03
13335	PG0485	2017-08-05 11:15:00+03	2017-08-05 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-05 11:21:00+03	2017-08-05 11:56:00+03
13336	PG0485	2017-08-14 11:15:00+03	2017-08-14 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-14 11:17:00+03	2017-08-14 11:52:00+03
13337	PG0484	2017-07-16 11:40:00+03	2017-07-16 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-16 11:45:00+03	2017-07-16 12:21:00+03
13338	PG0485	2017-09-12 11:15:00+03	2017-09-12 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13339	PG0485	2017-09-03 11:15:00+03	2017-09-03 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13340	PG0484	2017-09-03 11:40:00+03	2017-09-03 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13341	PG0485	2017-07-16 11:15:00+03	2017-07-16 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-16 11:16:00+03	2017-07-16 11:51:00+03
13342	PG0484	2017-08-28 11:40:00+03	2017-08-28 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13343	PG0484	2017-08-16 11:40:00+03	2017-08-16 12:15:00+03	ROV	AER	On Time	SU9	\N	\N
13344	PG0484	2017-08-14 11:40:00+03	2017-08-14 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-14 11:42:00+03	2017-08-14 12:17:00+03
13345	PG0484	2017-08-05 11:40:00+03	2017-08-05 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-05 11:41:00+03	2017-08-05 12:16:00+03
13346	PG0484	2017-08-02 11:40:00+03	2017-08-02 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-02 11:42:00+03	2017-08-02 12:17:00+03
13347	PG0485	2017-09-11 11:15:00+03	2017-09-11 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13348	PG0484	2017-08-15 11:40:00+03	2017-08-15 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-15 11:44:00+03	2017-08-15 12:18:00+03
13349	PG0484	2017-08-25 11:40:00+03	2017-08-25 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13350	PG0485	2017-08-15 11:15:00+03	2017-08-15 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-15 11:18:00+03	2017-08-15 11:53:00+03
13351	PG0484	2017-07-28 11:40:00+03	2017-07-28 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-28 11:42:00+03	2017-07-28 12:18:00+03
13352	PG0485	2017-07-28 11:15:00+03	2017-07-28 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-28 11:22:00+03	2017-07-28 11:57:00+03
13353	PG0485	2017-07-23 11:15:00+03	2017-07-23 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-23 11:20:00+03	2017-07-23 11:55:00+03
13354	PG0484	2017-08-07 11:40:00+03	2017-08-07 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-07 11:42:00+03	2017-08-07 12:17:00+03
13355	PG0485	2017-08-07 11:15:00+03	2017-08-07 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-07 11:18:00+03	2017-08-07 11:52:00+03
13356	PG0485	2017-09-06 11:15:00+03	2017-09-06 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13357	PG0484	2017-08-09 11:40:00+03	2017-08-09 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-09 11:45:00+03	2017-08-09 12:20:00+03
13358	PG0485	2017-08-09 11:15:00+03	2017-08-09 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-09 11:18:00+03	2017-08-09 11:53:00+03
13359	PG0485	2017-08-30 11:15:00+03	2017-08-30 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13360	PG0484	2017-08-01 11:40:00+03	2017-08-01 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-01 11:43:00+03	2017-08-01 12:19:00+03
13361	PG0484	2017-09-09 11:40:00+03	2017-09-09 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13362	PG0484	2017-08-11 11:40:00+03	2017-08-11 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-11 11:45:00+03	2017-08-11 12:20:00+03
13363	PG0485	2017-09-14 11:15:00+03	2017-09-14 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13364	PG0484	2017-09-14 11:40:00+03	2017-09-14 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13365	PG0485	2017-07-25 11:15:00+03	2017-07-25 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-25 11:17:00+03	2017-07-25 11:52:00+03
13366	PG0484	2017-09-10 11:40:00+03	2017-09-10 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13367	PG0484	2017-08-30 11:40:00+03	2017-08-30 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13368	PG0484	2017-08-27 11:40:00+03	2017-08-27 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13369	PG0485	2017-09-07 11:15:00+03	2017-09-07 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13370	PG0484	2017-07-19 11:40:00+03	2017-07-19 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-19 11:43:00+03	2017-07-19 12:18:00+03
13371	PG0485	2017-09-10 11:15:00+03	2017-09-10 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13372	PG0484	2017-08-22 11:40:00+03	2017-08-22 12:15:00+03	ROV	AER	Scheduled	SU9	\N	\N
13373	PG0484	2017-07-23 11:40:00+03	2017-07-23 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-23 11:43:00+03	2017-07-23 12:18:00+03
13374	PG0484	2017-07-25 11:40:00+03	2017-07-25 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-25 11:40:00+03	2017-07-25 12:15:00+03
13375	PG0484	2017-07-27 11:40:00+03	2017-07-27 12:15:00+03	ROV	AER	Arrived	SU9	2017-07-27 11:43:00+03	2017-07-27 12:17:00+03
13376	PG0485	2017-08-01 11:15:00+03	2017-08-01 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-01 11:20:00+03	2017-08-01 11:55:00+03
13377	PG0485	2017-08-10 11:15:00+03	2017-08-10 11:50:00+03	ROV	AER	Arrived	SU9	2017-08-10 11:15:00+03	2017-08-10 11:50:00+03
13378	PG0485	2017-08-22 11:15:00+03	2017-08-22 11:50:00+03	ROV	AER	Scheduled	SU9	\N	\N
13379	PG0485	2017-07-26 11:15:00+03	2017-07-26 11:50:00+03	ROV	AER	Arrived	SU9	2017-07-26 11:21:00+03	2017-07-26 11:56:00+03
13380	PG0484	2017-08-10 11:40:00+03	2017-08-10 12:15:00+03	ROV	AER	Arrived	SU9	2017-08-10 11:43:00+03	2017-08-10 12:18:00+03
13381	PG0559	2017-09-03 10:55:00+03	2017-09-03 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13382	PG0559	2017-08-23 10:55:00+03	2017-08-23 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13383	PG0559	2017-07-25 10:55:00+03	2017-07-25 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-25 10:59:00+03	2017-07-25 12:24:00+03
13384	PG0559	2017-08-11 10:55:00+03	2017-08-11 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-11 10:56:00+03	2017-08-11 12:19:00+03
13385	PG0559	2017-09-07 10:55:00+03	2017-09-07 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13386	PG0559	2017-08-16 10:55:00+03	2017-08-16 12:20:00+03	ROV	EGO	On Time	CN1	\N	\N
13387	PG0559	2017-08-03 10:55:00+03	2017-08-03 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-03 10:55:00+03	2017-08-03 12:19:00+03
13388	PG0559	2017-08-17 10:55:00+03	2017-08-17 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13389	PG0559	2017-08-28 10:55:00+03	2017-08-28 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13390	PG0559	2017-09-10 10:55:00+03	2017-09-10 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13391	PG0559	2017-08-02 10:55:00+03	2017-08-02 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-02 10:59:00+03	2017-08-02 12:24:00+03
13392	PG0559	2017-08-08 10:55:00+03	2017-08-08 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-08 10:58:00+03	2017-08-08 12:23:00+03
13393	PG0559	2017-07-23 10:55:00+03	2017-07-23 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-23 10:56:00+03	2017-07-23 12:21:00+03
13394	PG0559	2017-07-30 10:55:00+03	2017-07-30 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-30 10:57:00+03	2017-07-30 12:21:00+03
13395	PG0559	2017-08-13 10:55:00+03	2017-08-13 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-13 10:57:00+03	2017-08-13 12:20:00+03
13396	PG0559	2017-08-19 10:55:00+03	2017-08-19 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13397	PG0559	2017-08-24 10:55:00+03	2017-08-24 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13398	PG0559	2017-08-06 10:55:00+03	2017-08-06 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-06 10:57:00+03	2017-08-06 12:22:00+03
13399	PG0559	2017-09-05 10:55:00+03	2017-09-05 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13400	PG0559	2017-07-26 10:55:00+03	2017-07-26 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-26 10:58:00+03	2017-07-26 12:22:00+03
13401	PG0559	2017-07-19 10:55:00+03	2017-07-19 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-19 10:58:00+03	2017-07-19 12:24:00+03
13402	PG0559	2017-08-05 10:55:00+03	2017-08-05 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-05 10:58:00+03	2017-08-05 12:23:00+03
13403	PG0559	2017-09-14 10:55:00+03	2017-09-14 12:20:00+03	ROV	EGO	Cancelled	CN1	\N	\N
13404	PG0559	2017-08-12 10:55:00+03	2017-08-12 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-12 10:56:00+03	2017-08-12 12:21:00+03
13405	PG0559	2017-08-27 10:55:00+03	2017-08-27 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13406	PG0559	2017-07-27 10:55:00+03	2017-07-27 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-27 10:57:00+03	2017-07-27 12:23:00+03
13407	PG0559	2017-07-24 10:55:00+03	2017-07-24 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-24 10:56:00+03	2017-07-24 12:22:00+03
13408	PG0559	2017-08-21 10:55:00+03	2017-08-21 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13409	PG0559	2017-08-18 10:55:00+03	2017-08-18 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13410	PG0559	2017-08-01 10:55:00+03	2017-08-01 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-01 10:57:00+03	2017-08-01 12:21:00+03
13411	PG0559	2017-09-11 10:55:00+03	2017-09-11 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13412	PG0559	2017-08-30 10:55:00+03	2017-08-30 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13413	PG0559	2017-08-26 10:55:00+03	2017-08-26 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13414	PG0559	2017-09-04 10:55:00+03	2017-09-04 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13415	PG0559	2017-08-09 10:55:00+03	2017-08-09 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-09 10:59:00+03	2017-08-09 12:25:00+03
13416	PG0559	2017-07-17 10:55:00+03	2017-07-17 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-17 10:58:00+03	2017-07-17 12:24:00+03
13417	PG0559	2017-07-29 10:55:00+03	2017-07-29 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-29 10:57:00+03	2017-07-29 12:20:00+03
13418	PG0559	2017-08-20 10:55:00+03	2017-08-20 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13419	PG0559	2017-08-29 10:55:00+03	2017-08-29 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13420	PG0559	2017-07-31 10:55:00+03	2017-07-31 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-31 11:01:00+03	2017-07-31 12:26:00+03
13421	PG0559	2017-08-31 10:55:00+03	2017-08-31 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13422	PG0559	2017-08-04 10:55:00+03	2017-08-04 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-04 10:59:00+03	2017-08-04 12:23:00+03
13423	PG0559	2017-09-12 10:55:00+03	2017-09-12 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13424	PG0559	2017-08-22 10:55:00+03	2017-08-22 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13425	PG0559	2017-09-06 10:55:00+03	2017-09-06 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13426	PG0559	2017-09-01 10:55:00+03	2017-09-01 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13427	PG0559	2017-07-20 10:55:00+03	2017-07-20 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-20 10:56:00+03	2017-07-20 12:20:00+03
13428	PG0559	2017-08-10 10:55:00+03	2017-08-10 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-10 10:59:00+03	2017-08-10 12:23:00+03
13429	PG0559	2017-09-13 10:55:00+03	2017-09-13 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13430	PG0559	2017-08-15 10:55:00+03	2017-08-15 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-15 11:01:00+03	2017-08-15 12:25:00+03
13431	PG0559	2017-07-18 10:55:00+03	2017-07-18 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-18 11:00:00+03	2017-07-18 12:25:00+03
13432	PG0559	2017-08-07 10:55:00+03	2017-08-07 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-07 11:00:00+03	2017-08-07 12:24:00+03
13433	PG0559	2017-07-16 10:55:00+03	2017-07-16 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-16 10:55:00+03	2017-07-16 12:20:00+03
13434	PG0559	2017-09-09 10:55:00+03	2017-09-09 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13435	PG0559	2017-07-28 10:55:00+03	2017-07-28 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-28 10:59:00+03	2017-07-28 12:24:00+03
13436	PG0559	2017-08-25 10:55:00+03	2017-08-25 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13437	PG0559	2017-07-21 10:55:00+03	2017-07-21 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-21 10:58:00+03	2017-07-21 12:23:00+03
13438	PG0559	2017-08-14 10:55:00+03	2017-08-14 12:20:00+03	ROV	EGO	Arrived	CN1	2017-08-14 10:59:00+03	2017-08-14 12:24:00+03
13439	PG0559	2017-07-22 10:55:00+03	2017-07-22 12:20:00+03	ROV	EGO	Arrived	CN1	2017-07-22 13:51:00+03	2017-07-22 15:17:00+03
13440	PG0559	2017-09-08 10:55:00+03	2017-09-08 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13441	PG0559	2017-09-02 10:55:00+03	2017-09-02 12:20:00+03	ROV	EGO	Scheduled	CN1	\N	\N
13442	PG0530	2017-08-24 10:30:00+03	2017-08-24 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13443	PG0530	2017-08-12 10:30:00+03	2017-08-12 12:00:00+03	UFA	SVO	Arrived	763	2017-08-12 10:35:00+03	2017-08-12 12:06:00+03
13444	PG0530	2017-08-13 10:30:00+03	2017-08-13 12:00:00+03	UFA	SVO	Arrived	763	2017-08-13 10:36:00+03	2017-08-13 12:06:00+03
13445	PG0530	2017-08-29 10:30:00+03	2017-08-29 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13446	PG0530	2017-08-16 10:30:00+03	2017-08-16 12:00:00+03	UFA	SVO	On Time	763	\N	\N
13447	PG0530	2017-09-13 10:30:00+03	2017-09-13 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13448	PG0530	2017-08-05 10:30:00+03	2017-08-05 12:00:00+03	UFA	SVO	Arrived	763	2017-08-05 10:33:00+03	2017-08-05 12:03:00+03
13449	PG0530	2017-08-21 10:30:00+03	2017-08-21 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13450	PG0530	2017-07-24 10:30:00+03	2017-07-24 12:00:00+03	UFA	SVO	Arrived	763	2017-07-24 10:32:00+03	2017-07-24 12:02:00+03
13451	PG0530	2017-07-18 10:30:00+03	2017-07-18 12:00:00+03	UFA	SVO	Arrived	763	2017-07-18 10:32:00+03	2017-07-18 12:02:00+03
13452	PG0530	2017-09-08 10:30:00+03	2017-09-08 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13453	PG0530	2017-09-07 10:30:00+03	2017-09-07 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13454	PG0530	2017-08-08 10:30:00+03	2017-08-08 12:00:00+03	UFA	SVO	Arrived	763	2017-08-08 10:31:00+03	2017-08-08 12:02:00+03
13455	PG0530	2017-08-28 10:30:00+03	2017-08-28 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13456	PG0530	2017-09-02 10:30:00+03	2017-09-02 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13457	PG0530	2017-08-20 10:30:00+03	2017-08-20 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13458	PG0530	2017-08-03 10:30:00+03	2017-08-03 12:00:00+03	UFA	SVO	Arrived	763	2017-08-03 10:34:00+03	2017-08-03 12:05:00+03
13459	PG0530	2017-08-23 10:30:00+03	2017-08-23 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13460	PG0530	2017-08-19 10:30:00+03	2017-08-19 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13461	PG0530	2017-07-23 10:30:00+03	2017-07-23 12:00:00+03	UFA	SVO	Arrived	763	2017-07-23 10:35:00+03	2017-07-23 12:03:00+03
13462	PG0530	2017-09-04 10:30:00+03	2017-09-04 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13463	PG0530	2017-07-21 10:30:00+03	2017-07-21 12:00:00+03	UFA	SVO	Arrived	763	2017-07-21 10:33:00+03	2017-07-21 12:03:00+03
13464	PG0530	2017-07-31 10:30:00+03	2017-07-31 12:00:00+03	UFA	SVO	Arrived	763	2017-07-31 10:32:00+03	2017-07-31 12:03:00+03
13465	PG0530	2017-07-20 10:30:00+03	2017-07-20 12:00:00+03	UFA	SVO	Arrived	763	2017-07-20 10:32:00+03	2017-07-20 12:01:00+03
13466	PG0530	2017-08-09 10:30:00+03	2017-08-09 12:00:00+03	UFA	SVO	Arrived	763	2017-08-09 10:37:00+03	2017-08-09 12:07:00+03
13467	PG0530	2017-09-09 10:30:00+03	2017-09-09 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13468	PG0530	2017-08-01 10:30:00+03	2017-08-01 12:00:00+03	UFA	SVO	Arrived	763	2017-08-01 10:32:00+03	2017-08-01 12:01:00+03
13469	PG0530	2017-08-22 10:30:00+03	2017-08-22 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13470	PG0530	2017-07-16 10:30:00+03	2017-07-16 12:00:00+03	UFA	SVO	Arrived	763	2017-07-16 10:32:00+03	2017-07-16 12:02:00+03
13471	PG0530	2017-07-27 10:30:00+03	2017-07-27 12:00:00+03	UFA	SVO	Arrived	763	2017-07-27 10:33:00+03	2017-07-27 12:02:00+03
13472	PG0530	2017-07-25 10:30:00+03	2017-07-25 12:00:00+03	UFA	SVO	Arrived	763	2017-07-25 10:34:00+03	2017-07-25 12:03:00+03
13473	PG0530	2017-08-30 10:30:00+03	2017-08-30 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13474	PG0530	2017-09-05 10:30:00+03	2017-09-05 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13475	PG0530	2017-08-17 10:30:00+03	2017-08-17 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13476	PG0530	2017-08-14 10:30:00+03	2017-08-14 12:00:00+03	UFA	SVO	Arrived	763	2017-08-14 10:36:00+03	2017-08-14 12:06:00+03
13477	PG0530	2017-07-17 10:30:00+03	2017-07-17 12:00:00+03	UFA	SVO	Arrived	763	2017-07-17 10:33:00+03	2017-07-17 12:03:00+03
13478	PG0530	2017-09-06 10:30:00+03	2017-09-06 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13479	PG0530	2017-08-27 10:30:00+03	2017-08-27 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13480	PG0530	2017-09-14 10:30:00+03	2017-09-14 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13481	PG0530	2017-09-03 10:30:00+03	2017-09-03 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13482	PG0530	2017-07-22 10:30:00+03	2017-07-22 12:00:00+03	UFA	SVO	Arrived	763	2017-07-22 10:35:00+03	2017-07-22 12:06:00+03
13483	PG0530	2017-08-02 10:30:00+03	2017-08-02 12:00:00+03	UFA	SVO	Arrived	763	2017-08-02 10:35:00+03	2017-08-02 12:07:00+03
13484	PG0530	2017-08-25 10:30:00+03	2017-08-25 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13485	PG0530	2017-07-26 10:30:00+03	2017-07-26 12:00:00+03	UFA	SVO	Arrived	763	2017-07-26 10:35:00+03	2017-07-26 12:04:00+03
13486	PG0530	2017-07-19 10:30:00+03	2017-07-19 12:00:00+03	UFA	SVO	Arrived	763	2017-07-19 10:32:00+03	2017-07-19 12:02:00+03
13487	PG0530	2017-08-10 10:30:00+03	2017-08-10 12:00:00+03	UFA	SVO	Arrived	763	2017-08-10 10:33:00+03	2017-08-10 12:03:00+03
13488	PG0530	2017-07-29 10:30:00+03	2017-07-29 12:00:00+03	UFA	SVO	Arrived	763	2017-07-29 10:32:00+03	2017-07-29 12:01:00+03
13489	PG0530	2017-08-26 10:30:00+03	2017-08-26 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13490	PG0530	2017-09-01 10:30:00+03	2017-09-01 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13491	PG0530	2017-07-30 10:30:00+03	2017-07-30 12:00:00+03	UFA	SVO	Arrived	763	2017-07-30 10:37:00+03	2017-07-30 12:08:00+03
13492	PG0530	2017-08-11 10:30:00+03	2017-08-11 12:00:00+03	UFA	SVO	Arrived	763	2017-08-11 10:34:00+03	2017-08-11 12:03:00+03
13493	PG0530	2017-09-11 10:30:00+03	2017-09-11 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13494	PG0530	2017-08-06 10:30:00+03	2017-08-06 12:00:00+03	UFA	SVO	Arrived	763	2017-08-06 10:31:00+03	2017-08-06 12:02:00+03
13495	PG0530	2017-09-12 10:30:00+03	2017-09-12 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13496	PG0530	2017-08-18 10:30:00+03	2017-08-18 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13497	PG0530	2017-08-07 10:30:00+03	2017-08-07 12:00:00+03	UFA	SVO	Arrived	763	2017-08-07 10:32:00+03	2017-08-07 12:02:00+03
13498	PG0530	2017-08-31 10:30:00+03	2017-08-31 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13499	PG0530	2017-09-10 10:30:00+03	2017-09-10 12:00:00+03	UFA	SVO	Scheduled	763	\N	\N
13500	PG0530	2017-08-04 10:30:00+03	2017-08-04 12:00:00+03	UFA	SVO	Arrived	763	2017-08-04 10:30:00+03	2017-08-04 11:59:00+03
13501	PG0530	2017-08-15 10:30:00+03	2017-08-15 12:00:00+03	UFA	SVO	Arrived	763	2017-08-15 10:35:00+03	2017-08-15 12:06:00+03
13502	PG0530	2017-07-28 10:30:00+03	2017-07-28 12:00:00+03	UFA	SVO	Arrived	763	2017-07-28 10:33:00+03	2017-07-28 12:03:00+03
13503	PG0305	2017-07-20 08:10:00+03	2017-07-20 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-20 08:15:00+03	2017-07-20 09:53:00+03
13504	PG0305	2017-08-24 08:10:00+03	2017-08-24 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13505	PG0305	2017-07-19 08:10:00+03	2017-07-19 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-19 08:12:00+03	2017-07-19 09:52:00+03
13506	PG0305	2017-08-08 08:10:00+03	2017-08-08 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-08 08:13:00+03	2017-08-08 09:54:00+03
13507	PG0305	2017-08-31 08:10:00+03	2017-08-31 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13508	PG0305	2017-09-13 08:10:00+03	2017-09-13 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13509	PG0305	2017-08-01 08:10:00+03	2017-08-01 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-01 08:11:00+03	2017-08-01 09:50:00+03
13510	PG0305	2017-08-10 08:10:00+03	2017-08-10 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-10 08:16:00+03	2017-08-10 09:56:00+03
13511	PG0305	2017-09-10 08:10:00+03	2017-09-10 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13512	PG0305	2017-08-22 08:10:00+03	2017-08-22 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13513	PG0305	2017-08-19 08:10:00+03	2017-08-19 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13514	PG0305	2017-08-23 08:10:00+03	2017-08-23 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13515	PG0305	2017-09-14 08:10:00+03	2017-09-14 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13516	PG0305	2017-09-02 08:10:00+03	2017-09-02 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13517	PG0305	2017-09-01 08:10:00+03	2017-09-01 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13518	PG0305	2017-08-29 08:10:00+03	2017-08-29 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13519	PG0305	2017-09-08 08:10:00+03	2017-09-08 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13520	PG0305	2017-08-30 08:10:00+03	2017-08-30 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13521	PG0305	2017-07-27 08:10:00+03	2017-07-27 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-27 08:12:00+03	2017-07-27 09:52:00+03
13522	PG0305	2017-08-11 08:10:00+03	2017-08-11 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-11 08:12:00+03	2017-08-11 09:51:00+03
13523	PG0305	2017-07-23 08:10:00+03	2017-07-23 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-23 08:13:00+03	2017-07-23 09:53:00+03
13524	PG0305	2017-08-09 08:10:00+03	2017-08-09 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-09 08:13:00+03	2017-08-09 09:54:00+03
13525	PG0305	2017-08-27 08:10:00+03	2017-08-27 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13526	PG0305	2017-08-02 08:10:00+03	2017-08-02 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-02 08:12:00+03	2017-08-02 09:52:00+03
13527	PG0305	2017-08-18 08:10:00+03	2017-08-18 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13528	PG0305	2017-09-09 08:10:00+03	2017-09-09 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13529	PG0305	2017-08-04 08:10:00+03	2017-08-04 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-04 08:18:00+03	2017-08-04 09:58:00+03
13530	PG0305	2017-09-04 08:10:00+03	2017-09-04 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13531	PG0305	2017-07-30 08:10:00+03	2017-07-30 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-30 08:13:00+03	2017-07-30 09:55:00+03
13532	PG0305	2017-08-05 08:10:00+03	2017-08-05 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-05 08:15:00+03	2017-08-05 09:56:00+03
13533	PG0305	2017-07-17 08:10:00+03	2017-07-17 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-17 08:13:00+03	2017-07-17 09:52:00+03
13534	PG0305	2017-08-07 08:10:00+03	2017-08-07 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-07 08:13:00+03	2017-08-07 09:52:00+03
13535	PG0305	2017-07-31 08:10:00+03	2017-07-31 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-31 08:13:00+03	2017-07-31 09:54:00+03
13536	PG0305	2017-08-28 08:10:00+03	2017-08-28 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13537	PG0305	2017-07-16 08:10:00+03	2017-07-16 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-16 08:13:00+03	2017-07-16 09:53:00+03
13538	PG0305	2017-08-14 08:10:00+03	2017-08-14 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-14 08:15:00+03	2017-08-14 09:55:00+03
13539	PG0305	2017-08-06 08:10:00+03	2017-08-06 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-06 08:12:00+03	2017-08-06 09:53:00+03
13540	PG0305	2017-07-28 08:10:00+03	2017-07-28 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-28 10:56:00+03	2017-07-28 12:37:00+03
13541	PG0305	2017-07-21 08:10:00+03	2017-07-21 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-21 08:15:00+03	2017-07-21 09:56:00+03
13542	PG0305	2017-07-25 08:10:00+03	2017-07-25 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-25 08:12:00+03	2017-07-25 09:51:00+03
13543	PG0305	2017-08-15 08:10:00+03	2017-08-15 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-15 08:12:00+03	2017-08-15 09:53:00+03
13544	PG0305	2017-08-16 08:10:00+03	2017-08-16 09:50:00+03	UFA	ESL	On Time	SU9	\N	\N
13545	PG0305	2017-08-12 08:10:00+03	2017-08-12 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-12 08:12:00+03	2017-08-12 09:53:00+03
13546	PG0305	2017-07-22 08:10:00+03	2017-07-22 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-22 08:11:00+03	2017-07-22 09:51:00+03
13547	PG0305	2017-09-07 08:10:00+03	2017-09-07 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13548	PG0305	2017-08-26 08:10:00+03	2017-08-26 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13549	PG0305	2017-08-03 08:10:00+03	2017-08-03 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-03 08:12:00+03	2017-08-03 09:54:00+03
13550	PG0305	2017-09-12 08:10:00+03	2017-09-12 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13551	PG0305	2017-08-20 08:10:00+03	2017-08-20 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13552	PG0305	2017-08-25 08:10:00+03	2017-08-25 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13553	PG0305	2017-09-03 08:10:00+03	2017-09-03 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13554	PG0305	2017-08-21 08:10:00+03	2017-08-21 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13555	PG0305	2017-09-06 08:10:00+03	2017-09-06 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13556	PG0305	2017-07-26 08:10:00+03	2017-07-26 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-26 08:14:00+03	2017-07-26 09:56:00+03
13557	PG0305	2017-08-13 08:10:00+03	2017-08-13 09:50:00+03	UFA	ESL	Arrived	SU9	2017-08-13 08:15:00+03	2017-08-13 09:56:00+03
13558	PG0305	2017-07-18 08:10:00+03	2017-07-18 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-18 08:12:00+03	2017-07-18 09:54:00+03
13559	PG0305	2017-08-17 08:10:00+03	2017-08-17 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13560	PG0305	2017-09-11 08:10:00+03	2017-09-11 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13561	PG0305	2017-09-05 08:10:00+03	2017-09-05 09:50:00+03	UFA	ESL	Scheduled	SU9	\N	\N
13562	PG0305	2017-07-24 08:10:00+03	2017-07-24 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-24 08:14:00+03	2017-07-24 09:54:00+03
13563	PG0305	2017-07-29 08:10:00+03	2017-07-29 09:50:00+03	UFA	ESL	Arrived	SU9	2017-07-29 08:14:00+03	2017-07-29 09:54:00+03
13564	PG0563	2017-08-19 13:55:00+03	2017-08-19 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13565	PG0564	2017-09-08 09:30:00+03	2017-09-08 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13566	PG0563	2017-09-08 13:55:00+03	2017-09-08 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13567	PG0564	2017-07-27 09:30:00+03	2017-07-27 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-27 09:32:00+03	2017-07-27 12:46:00+03
13568	PG0563	2017-09-01 13:55:00+03	2017-09-01 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13569	PG0563	2017-07-27 13:55:00+03	2017-07-27 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-27 14:00:00+03	2017-07-27 17:15:00+03
13570	PG0563	2017-08-31 13:55:00+03	2017-08-31 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13571	PG0563	2017-09-12 13:55:00+03	2017-09-12 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13572	PG0564	2017-09-09 09:30:00+03	2017-09-09 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13573	PG0563	2017-07-31 13:55:00+03	2017-07-31 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-31 13:56:00+03	2017-07-31 17:06:00+03
13574	PG0564	2017-09-12 09:30:00+03	2017-09-12 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13575	PG0564	2017-07-30 09:30:00+03	2017-07-30 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-30 09:34:00+03	2017-07-30 12:48:00+03
13576	PG0563	2017-07-30 13:55:00+03	2017-07-30 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-30 13:58:00+03	2017-07-30 17:13:00+03
13577	PG0564	2017-07-23 09:30:00+03	2017-07-23 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-23 09:34:00+03	2017-07-23 12:51:00+03
13578	PG0564	2017-08-08 09:30:00+03	2017-08-08 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-08 09:32:00+03	2017-08-08 12:46:00+03
13579	PG0563	2017-08-08 13:55:00+03	2017-08-08 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-08 13:57:00+03	2017-08-08 17:11:00+03
13580	PG0563	2017-09-11 13:55:00+03	2017-09-11 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13581	PG0563	2017-07-24 13:55:00+03	2017-07-24 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-24 13:56:00+03	2017-07-24 17:08:00+03
13582	PG0564	2017-07-19 09:30:00+03	2017-07-19 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-19 09:32:00+03	2017-07-19 12:47:00+03
13583	PG0563	2017-08-11 13:55:00+03	2017-08-11 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-11 13:58:00+03	2017-08-11 17:15:00+03
13584	PG0564	2017-08-21 09:30:00+03	2017-08-21 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13585	PG0563	2017-08-12 13:55:00+03	2017-08-12 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-12 14:00:00+03	2017-08-12 17:15:00+03
13586	PG0563	2017-08-28 13:55:00+03	2017-08-28 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13587	PG0564	2017-08-11 09:30:00+03	2017-08-11 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-11 09:31:00+03	2017-08-11 12:47:00+03
13588	PG0563	2017-08-26 13:55:00+03	2017-08-26 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13589	PG0564	2017-08-04 09:30:00+03	2017-08-04 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-04 09:31:00+03	2017-08-04 12:43:00+03
13590	PG0563	2017-08-04 13:55:00+03	2017-08-04 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-04 13:56:00+03	2017-08-04 17:11:00+03
13591	PG0563	2017-09-03 13:55:00+03	2017-09-03 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13592	PG0564	2017-09-14 09:30:00+03	2017-09-14 12:45:00+03	UFA	UCT	Cancelled	CN1	\N	\N
13593	PG0564	2017-08-13 09:30:00+03	2017-08-13 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-13 09:34:00+03	2017-08-13 12:52:00+03
13594	PG0564	2017-09-03 09:30:00+03	2017-09-03 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13595	PG0563	2017-08-13 13:55:00+03	2017-08-13 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-13 13:59:00+03	2017-08-13 17:15:00+03
13596	PG0563	2017-07-29 13:55:00+03	2017-07-29 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-29 13:58:00+03	2017-07-29 17:14:00+03
13597	PG0564	2017-08-12 09:30:00+03	2017-08-12 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-12 09:32:00+03	2017-08-12 12:47:00+03
13598	PG0564	2017-08-31 09:30:00+03	2017-08-31 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13599	PG0563	2017-08-16 13:55:00+03	2017-08-16 17:10:00+03	UFA	UCT	On Time	CN1	\N	\N
13600	PG0563	2017-08-21 13:55:00+03	2017-08-21 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13601	PG0563	2017-07-23 13:55:00+03	2017-07-23 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-23 13:57:00+03	2017-07-23 17:11:00+03
13602	PG0563	2017-07-19 13:55:00+03	2017-07-19 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-19 14:00:00+03	2017-07-19 17:11:00+03
13603	PG0563	2017-09-09 13:55:00+03	2017-09-09 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13604	PG0564	2017-07-26 09:30:00+03	2017-07-26 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-26 09:33:00+03	2017-07-26 12:46:00+03
13605	PG0564	2017-07-22 09:30:00+03	2017-07-22 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-22 09:33:00+03	2017-07-22 12:48:00+03
13606	PG0564	2017-09-07 09:30:00+03	2017-09-07 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13607	PG0564	2017-07-28 09:30:00+03	2017-07-28 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-28 09:33:00+03	2017-07-28 12:47:00+03
13608	PG0563	2017-07-28 13:55:00+03	2017-07-28 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-28 13:57:00+03	2017-07-28 17:11:00+03
13609	PG0564	2017-08-27 09:30:00+03	2017-08-27 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13610	PG0564	2017-09-11 09:30:00+03	2017-09-11 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13611	PG0564	2017-08-07 09:30:00+03	2017-08-07 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-07 09:34:00+03	2017-08-07 12:51:00+03
13612	PG0563	2017-07-22 13:55:00+03	2017-07-22 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-22 14:00:00+03	2017-07-22 17:14:00+03
13613	PG0564	2017-07-21 09:30:00+03	2017-07-21 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-21 09:34:00+03	2017-07-21 12:49:00+03
13614	PG0563	2017-07-21 13:55:00+03	2017-07-21 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-21 13:56:00+03	2017-07-21 17:12:00+03
13615	PG0564	2017-08-14 09:30:00+03	2017-08-14 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-14 09:33:00+03	2017-08-14 12:48:00+03
13616	PG0563	2017-08-07 13:55:00+03	2017-08-07 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-07 13:57:00+03	2017-08-07 17:09:00+03
13617	PG0563	2017-08-14 13:55:00+03	2017-08-14 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-14 13:57:00+03	2017-08-14 17:13:00+03
13618	PG0563	2017-07-18 13:55:00+03	2017-07-18 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-18 13:55:00+03	2017-07-18 17:12:00+03
13619	PG0563	2017-07-16 13:55:00+03	2017-07-16 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-16 13:58:00+03	2017-07-16 17:15:00+03
13620	PG0564	2017-07-16 09:30:00+03	2017-07-16 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-16 09:32:00+03	2017-07-16 12:47:00+03
13621	PG0564	2017-08-16 09:30:00+03	2017-08-16 12:45:00+03	UFA	UCT	On Time	CN1	\N	\N
13622	PG0564	2017-08-19 09:30:00+03	2017-08-19 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13623	PG0564	2017-07-18 09:30:00+03	2017-07-18 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-18 09:31:00+03	2017-07-18 12:48:00+03
13624	PG0563	2017-07-26 13:55:00+03	2017-07-26 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-26 13:55:00+03	2017-07-26 17:10:00+03
13625	PG0564	2017-08-28 09:30:00+03	2017-08-28 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13626	PG0563	2017-08-23 13:55:00+03	2017-08-23 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13627	PG0564	2017-07-17 09:30:00+03	2017-07-17 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-17 09:32:00+03	2017-07-17 12:49:00+03
13628	PG0563	2017-07-17 13:55:00+03	2017-07-17 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-17 13:59:00+03	2017-07-17 17:14:00+03
13629	PG0563	2017-09-05 13:55:00+03	2017-09-05 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13630	PG0564	2017-09-05 09:30:00+03	2017-09-05 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13631	PG0563	2017-07-20 13:55:00+03	2017-07-20 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-20 13:58:00+03	2017-07-20 17:16:00+03
13632	PG0563	2017-08-01 13:55:00+03	2017-08-01 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-01 13:57:00+03	2017-08-01 17:13:00+03
13633	PG0564	2017-08-01 09:30:00+03	2017-08-01 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-01 09:34:00+03	2017-08-01 12:46:00+03
13634	PG0564	2017-07-20 09:30:00+03	2017-07-20 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-20 09:34:00+03	2017-07-20 12:47:00+03
13635	PG0564	2017-09-13 09:30:00+03	2017-09-13 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13636	PG0564	2017-08-26 09:30:00+03	2017-08-26 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13637	PG0563	2017-08-09 13:55:00+03	2017-08-09 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-09 13:59:00+03	2017-08-09 17:09:00+03
13638	PG0564	2017-09-06 09:30:00+03	2017-09-06 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13639	PG0564	2017-07-24 09:30:00+03	2017-07-24 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-24 09:32:00+03	2017-07-24 12:48:00+03
13640	PG0563	2017-08-15 13:55:00+03	2017-08-15 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-15 13:58:00+03	2017-08-15 17:11:00+03
13641	PG0564	2017-08-15 09:30:00+03	2017-08-15 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-15 09:34:00+03	2017-08-15 12:47:00+03
13642	PG0564	2017-08-09 09:30:00+03	2017-08-09 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-09 09:34:00+03	2017-08-09 12:50:00+03
13643	PG0563	2017-09-07 13:55:00+03	2017-09-07 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13644	PG0563	2017-08-22 13:55:00+03	2017-08-22 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13645	PG0564	2017-08-10 09:30:00+03	2017-08-10 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-10 13:44:00+03	2017-08-10 17:01:00+03
13646	PG0563	2017-08-10 13:55:00+03	2017-08-10 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-10 13:58:00+03	2017-08-10 17:10:00+03
13647	PG0564	2017-08-29 09:30:00+03	2017-08-29 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13648	PG0563	2017-08-30 13:55:00+03	2017-08-30 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13649	PG0564	2017-08-30 09:30:00+03	2017-08-30 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13650	PG0564	2017-08-25 09:30:00+03	2017-08-25 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13651	PG0564	2017-09-02 09:30:00+03	2017-09-02 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13652	PG0564	2017-08-20 09:30:00+03	2017-08-20 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13653	PG0563	2017-08-25 13:55:00+03	2017-08-25 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13654	PG0564	2017-07-29 09:30:00+03	2017-07-29 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-29 09:32:00+03	2017-07-29 12:48:00+03
13655	PG0563	2017-08-20 13:55:00+03	2017-08-20 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13656	PG0564	2017-09-10 09:30:00+03	2017-09-10 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13657	PG0563	2017-08-18 13:55:00+03	2017-08-18 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13658	PG0563	2017-07-25 13:55:00+03	2017-07-25 17:10:00+03	UFA	UCT	Arrived	CN1	2017-07-25 13:57:00+03	2017-07-25 17:10:00+03
13659	PG0563	2017-08-17 13:55:00+03	2017-08-17 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13660	PG0564	2017-08-17 09:30:00+03	2017-08-17 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13661	PG0564	2017-07-25 09:30:00+03	2017-07-25 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-25 09:32:00+03	2017-07-25 12:48:00+03
13662	PG0563	2017-09-10 13:55:00+03	2017-09-10 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13663	PG0563	2017-09-06 13:55:00+03	2017-09-06 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13664	PG0563	2017-08-03 13:55:00+03	2017-08-03 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-03 13:59:00+03	2017-08-03 17:14:00+03
13665	PG0564	2017-08-03 09:30:00+03	2017-08-03 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-03 09:34:00+03	2017-08-03 12:49:00+03
13666	PG0563	2017-08-29 13:55:00+03	2017-08-29 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13667	PG0564	2017-08-23 09:30:00+03	2017-08-23 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13668	PG0564	2017-08-05 09:30:00+03	2017-08-05 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-05 12:44:00+03	2017-08-05 15:57:00+03
13669	PG0563	2017-08-05 13:55:00+03	2017-08-05 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-05 13:58:00+03	2017-08-05 17:14:00+03
13670	PG0563	2017-08-06 13:55:00+03	2017-08-06 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-06 13:56:00+03	2017-08-06 17:11:00+03
13671	PG0563	2017-08-24 13:55:00+03	2017-08-24 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13672	PG0564	2017-08-02 09:30:00+03	2017-08-02 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-02 09:36:00+03	2017-08-02 12:51:00+03
13673	PG0563	2017-08-02 13:55:00+03	2017-08-02 17:10:00+03	UFA	UCT	Arrived	CN1	2017-08-02 13:56:00+03	2017-08-02 17:09:00+03
13674	PG0563	2017-09-13 13:55:00+03	2017-09-13 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13675	PG0563	2017-08-27 13:55:00+03	2017-08-27 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13676	PG0563	2017-09-14 13:55:00+03	2017-09-14 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13677	PG0564	2017-08-06 09:30:00+03	2017-08-06 12:45:00+03	UFA	UCT	Arrived	CN1	2017-08-06 09:35:00+03	2017-08-06 12:50:00+03
13678	PG0564	2017-08-18 09:30:00+03	2017-08-18 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13679	PG0564	2017-07-31 09:30:00+03	2017-07-31 12:45:00+03	UFA	UCT	Arrived	CN1	2017-07-31 09:36:00+03	2017-07-31 12:51:00+03
13680	PG0563	2017-09-04 13:55:00+03	2017-09-04 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13681	PG0564	2017-09-04 09:30:00+03	2017-09-04 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13682	PG0564	2017-08-22 09:30:00+03	2017-08-22 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13683	PG0564	2017-09-01 09:30:00+03	2017-09-01 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13684	PG0564	2017-08-24 09:30:00+03	2017-08-24 12:45:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13685	PG0563	2017-09-02 13:55:00+03	2017-09-02 17:10:00+03	UFA	UCT	Scheduled	CN1	\N	\N
13686	PG0567	2017-08-12 10:55:00+03	2017-08-12 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-12 10:58:00+03	2017-08-12 12:13:00+03
13687	PG0567	2017-08-04 10:55:00+03	2017-08-04 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-04 11:00:00+03	2017-08-04 12:15:00+03
13688	PG0567	2017-08-24 10:55:00+03	2017-08-24 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13689	PG0567	2017-07-26 10:55:00+03	2017-07-26 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-26 10:57:00+03	2017-07-26 12:11:00+03
13690	PG0567	2017-08-28 10:55:00+03	2017-08-28 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13691	PG0567	2017-09-01 10:55:00+03	2017-09-01 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13692	PG0567	2017-07-29 10:55:00+03	2017-07-29 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-29 10:59:00+03	2017-07-29 12:15:00+03
13693	PG0567	2017-08-30 10:55:00+03	2017-08-30 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13694	PG0567	2017-08-10 10:55:00+03	2017-08-10 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-10 10:58:00+03	2017-08-10 12:12:00+03
13695	PG0567	2017-09-02 10:55:00+03	2017-09-02 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13696	PG0567	2017-07-31 10:55:00+03	2017-07-31 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-31 13:51:00+03	2017-07-31 15:06:00+03
13697	PG0567	2017-08-25 10:55:00+03	2017-08-25 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13698	PG0567	2017-08-15 10:55:00+03	2017-08-15 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-15 11:01:00+03	2017-08-15 12:16:00+03
13699	PG0567	2017-09-09 10:55:00+03	2017-09-09 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13700	PG0567	2017-08-02 10:55:00+03	2017-08-02 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-02 10:56:00+03	2017-08-02 12:11:00+03
13701	PG0567	2017-08-06 10:55:00+03	2017-08-06 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-06 10:56:00+03	2017-08-06 12:12:00+03
13702	PG0567	2017-08-31 10:55:00+03	2017-08-31 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13703	PG0567	2017-09-03 10:55:00+03	2017-09-03 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13704	PG0567	2017-08-29 10:55:00+03	2017-08-29 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13705	PG0567	2017-08-05 10:55:00+03	2017-08-05 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-05 11:00:00+03	2017-08-05 12:15:00+03
13706	PG0567	2017-09-12 10:55:00+03	2017-09-12 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13707	PG0567	2017-07-28 10:55:00+03	2017-07-28 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-28 10:58:00+03	2017-07-28 12:14:00+03
13708	PG0567	2017-08-08 10:55:00+03	2017-08-08 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-08 10:59:00+03	2017-08-08 12:14:00+03
13709	PG0567	2017-08-17 10:55:00+03	2017-08-17 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13710	PG0567	2017-09-08 10:55:00+03	2017-09-08 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13711	PG0567	2017-07-27 10:55:00+03	2017-07-27 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-27 10:57:00+03	2017-07-27 12:14:00+03
13712	PG0567	2017-08-21 10:55:00+03	2017-08-21 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13713	PG0567	2017-08-27 10:55:00+03	2017-08-27 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13714	PG0567	2017-07-30 10:55:00+03	2017-07-30 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-30 10:58:00+03	2017-07-30 12:13:00+03
13715	PG0567	2017-08-14 10:55:00+03	2017-08-14 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-14 10:56:00+03	2017-08-14 12:11:00+03
13716	PG0567	2017-07-18 10:55:00+03	2017-07-18 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-18 10:56:00+03	2017-07-18 12:12:00+03
13717	PG0567	2017-07-24 10:55:00+03	2017-07-24 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-24 10:56:00+03	2017-07-24 12:11:00+03
13718	PG0567	2017-08-16 10:55:00+03	2017-08-16 12:10:00+03	UFA	OVS	On Time	CR2	\N	\N
13719	PG0567	2017-07-19 10:55:00+03	2017-07-19 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-19 10:55:00+03	2017-07-19 12:08:00+03
13720	PG0567	2017-08-20 10:55:00+03	2017-08-20 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13721	PG0567	2017-09-05 10:55:00+03	2017-09-05 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13722	PG0567	2017-08-23 10:55:00+03	2017-08-23 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13723	PG0567	2017-08-01 10:55:00+03	2017-08-01 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-01 10:58:00+03	2017-08-01 12:13:00+03
13724	PG0567	2017-09-13 10:55:00+03	2017-09-13 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13725	PG0567	2017-08-19 10:55:00+03	2017-08-19 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13726	PG0567	2017-09-06 10:55:00+03	2017-09-06 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13727	PG0567	2017-09-10 10:55:00+03	2017-09-10 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13728	PG0567	2017-08-07 10:55:00+03	2017-08-07 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-07 11:00:00+03	2017-08-07 12:13:00+03
13729	PG0567	2017-08-09 10:55:00+03	2017-08-09 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-09 13:45:00+03	2017-08-09 15:00:00+03
13730	PG0567	2017-09-04 10:55:00+03	2017-09-04 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13731	PG0567	2017-07-21 10:55:00+03	2017-07-21 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-21 10:56:00+03	2017-07-21 12:10:00+03
13732	PG0567	2017-07-23 10:55:00+03	2017-07-23 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-23 10:57:00+03	2017-07-23 12:11:00+03
13733	PG0567	2017-08-18 10:55:00+03	2017-08-18 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13734	PG0567	2017-07-25 10:55:00+03	2017-07-25 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-25 10:57:00+03	2017-07-25 12:12:00+03
13735	PG0567	2017-09-14 10:55:00+03	2017-09-14 12:10:00+03	UFA	OVS	Cancelled	CR2	\N	\N
13736	PG0567	2017-07-22 10:55:00+03	2017-07-22 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-22 10:58:00+03	2017-07-22 12:12:00+03
13737	PG0567	2017-09-07 10:55:00+03	2017-09-07 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13738	PG0567	2017-08-03 10:55:00+03	2017-08-03 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-03 11:03:00+03	2017-08-03 12:18:00+03
13739	PG0567	2017-08-13 10:55:00+03	2017-08-13 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-13 11:00:00+03	2017-08-13 12:13:00+03
13740	PG0567	2017-08-11 10:55:00+03	2017-08-11 12:10:00+03	UFA	OVS	Arrived	CR2	2017-08-11 10:56:00+03	2017-08-11 12:12:00+03
13741	PG0567	2017-08-22 10:55:00+03	2017-08-22 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13742	PG0567	2017-07-16 10:55:00+03	2017-07-16 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-16 10:58:00+03	2017-07-16 12:14:00+03
13743	PG0567	2017-07-17 10:55:00+03	2017-07-17 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-17 10:55:00+03	2017-07-17 12:10:00+03
13744	PG0567	2017-08-26 10:55:00+03	2017-08-26 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13745	PG0567	2017-09-11 10:55:00+03	2017-09-11 12:10:00+03	UFA	OVS	Scheduled	CR2	\N	\N
13746	PG0567	2017-07-20 10:55:00+03	2017-07-20 12:10:00+03	UFA	OVS	Arrived	CR2	2017-07-20 11:01:00+03	2017-07-20 12:16:00+03
13747	PG0148	2017-08-15 08:15:00+03	2017-08-15 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-15 08:18:00+03	2017-08-15 08:43:00+03
13748	PG0148	2017-08-04 08:15:00+03	2017-08-04 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-04 08:17:00+03	2017-08-04 08:42:00+03
13749	PG0148	2017-08-18 08:15:00+03	2017-08-18 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13750	PG0148	2017-08-30 08:15:00+03	2017-08-30 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13751	PG0148	2017-08-17 08:15:00+03	2017-08-17 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13752	PG0148	2017-07-19 08:15:00+03	2017-07-19 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-19 08:15:00+03	2017-07-19 08:40:00+03
13753	PG0148	2017-08-01 08:15:00+03	2017-08-01 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-01 08:20:00+03	2017-08-01 08:45:00+03
13754	PG0148	2017-09-05 08:15:00+03	2017-09-05 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13755	PG0148	2017-09-08 08:15:00+03	2017-09-08 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13756	PG0148	2017-07-18 08:15:00+03	2017-07-18 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-18 08:15:00+03	2017-07-18 08:40:00+03
13757	PG0148	2017-08-11 08:15:00+03	2017-08-11 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-11 08:17:00+03	2017-08-11 08:42:00+03
13758	PG0148	2017-08-27 08:15:00+03	2017-08-27 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13759	PG0148	2017-08-23 08:15:00+03	2017-08-23 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13760	PG0148	2017-08-20 08:15:00+03	2017-08-20 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13761	PG0148	2017-08-25 08:15:00+03	2017-08-25 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13762	PG0148	2017-09-11 08:15:00+03	2017-09-11 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13763	PG0148	2017-07-22 08:15:00+03	2017-07-22 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-22 08:19:00+03	2017-07-22 08:44:00+03
13764	PG0148	2017-08-28 08:15:00+03	2017-08-28 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13765	PG0148	2017-08-09 08:15:00+03	2017-08-09 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-09 08:20:00+03	2017-08-09 08:45:00+03
13766	PG0148	2017-08-06 08:15:00+03	2017-08-06 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-06 08:21:00+03	2017-08-06 08:46:00+03
13767	PG0148	2017-09-06 08:15:00+03	2017-09-06 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13768	PG0148	2017-07-26 08:15:00+03	2017-07-26 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-26 08:19:00+03	2017-07-26 08:44:00+03
13769	PG0148	2017-08-02 08:15:00+03	2017-08-02 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-02 08:19:00+03	2017-08-02 08:44:00+03
13770	PG0148	2017-08-14 08:15:00+03	2017-08-14 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-14 08:21:00+03	2017-08-14 08:46:00+03
13771	PG0148	2017-08-29 08:15:00+03	2017-08-29 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13772	PG0148	2017-07-20 08:15:00+03	2017-07-20 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-20 08:20:00+03	2017-07-20 08:45:00+03
13773	PG0148	2017-07-29 08:15:00+03	2017-07-29 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-29 08:18:00+03	2017-07-29 08:43:00+03
13774	PG0148	2017-07-21 08:15:00+03	2017-07-21 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-21 08:18:00+03	2017-07-21 08:43:00+03
13775	PG0148	2017-07-28 08:15:00+03	2017-07-28 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-28 08:16:00+03	2017-07-28 08:41:00+03
13776	PG0148	2017-07-31 08:15:00+03	2017-07-31 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-31 08:17:00+03	2017-07-31 08:42:00+03
13777	PG0148	2017-07-16 08:15:00+03	2017-07-16 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-16 08:19:00+03	2017-07-16 08:44:00+03
13778	PG0148	2017-07-17 08:15:00+03	2017-07-17 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-17 11:57:00+03	2017-07-17 12:21:00+03
13779	PG0148	2017-09-07 08:15:00+03	2017-09-07 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13780	PG0148	2017-08-24 08:15:00+03	2017-08-24 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13781	PG0148	2017-08-31 08:15:00+03	2017-08-31 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13782	PG0148	2017-09-12 08:15:00+03	2017-09-12 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13783	PG0148	2017-08-26 08:15:00+03	2017-08-26 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13784	PG0148	2017-09-02 08:15:00+03	2017-09-02 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13785	PG0148	2017-08-19 08:15:00+03	2017-08-19 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13786	PG0148	2017-07-30 08:15:00+03	2017-07-30 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-30 10:51:00+03	2017-07-30 11:16:00+03
13787	PG0148	2017-09-10 08:15:00+03	2017-09-10 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13788	PG0148	2017-08-12 08:15:00+03	2017-08-12 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-12 08:19:00+03	2017-08-12 08:44:00+03
13789	PG0148	2017-09-09 08:15:00+03	2017-09-09 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13790	PG0148	2017-07-27 08:15:00+03	2017-07-27 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-27 08:22:00+03	2017-07-27 08:47:00+03
13791	PG0148	2017-09-14 08:15:00+03	2017-09-14 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13792	PG0148	2017-08-16 08:15:00+03	2017-08-16 08:40:00+03	UFA	REN	On Time	CR2	\N	\N
13793	PG0148	2017-07-25 08:15:00+03	2017-07-25 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-25 08:17:00+03	2017-07-25 08:42:00+03
13794	PG0148	2017-08-21 08:15:00+03	2017-08-21 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13795	PG0148	2017-08-22 08:15:00+03	2017-08-22 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13796	PG0148	2017-07-24 08:15:00+03	2017-07-24 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-24 08:16:00+03	2017-07-24 08:41:00+03
13797	PG0148	2017-08-05 08:15:00+03	2017-08-05 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-05 08:17:00+03	2017-08-05 08:42:00+03
13798	PG0148	2017-08-08 08:15:00+03	2017-08-08 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-08 08:16:00+03	2017-08-08 08:41:00+03
13799	PG0148	2017-09-03 08:15:00+03	2017-09-03 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13800	PG0148	2017-07-23 08:15:00+03	2017-07-23 08:40:00+03	UFA	REN	Arrived	CR2	2017-07-23 12:01:00+03	2017-07-23 12:26:00+03
13801	PG0148	2017-09-04 08:15:00+03	2017-09-04 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13802	PG0148	2017-08-07 08:15:00+03	2017-08-07 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-07 08:17:00+03	2017-08-07 08:42:00+03
13803	PG0148	2017-09-13 08:15:00+03	2017-09-13 08:40:00+03	UFA	REN	Cancelled	CR2	\N	\N
13804	PG0148	2017-08-03 08:15:00+03	2017-08-03 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-03 08:18:00+03	2017-08-03 08:43:00+03
13805	PG0148	2017-09-01 08:15:00+03	2017-09-01 08:40:00+03	UFA	REN	Scheduled	CR2	\N	\N
13806	PG0148	2017-08-13 08:15:00+03	2017-08-13 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-13 08:16:00+03	2017-08-13 08:41:00+03
13807	PG0148	2017-08-10 08:15:00+03	2017-08-10 08:40:00+03	UFA	REN	Arrived	CR2	2017-08-10 08:20:00+03	2017-08-10 08:45:00+03
13808	PG0218	2017-09-03 10:10:00+03	2017-09-03 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13809	PG0218	2017-08-16 10:10:00+03	2017-08-16 15:05:00+03	UFA	HTA	On Time	319	\N	\N
13810	PG0218	2017-08-20 10:10:00+03	2017-08-20 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13811	PG0218	2017-08-02 10:10:00+03	2017-08-02 15:05:00+03	UFA	HTA	Arrived	319	2017-08-02 10:12:00+03	2017-08-02 15:11:00+03
13812	PG0218	2017-07-16 10:10:00+03	2017-07-16 15:05:00+03	UFA	HTA	Arrived	319	2017-07-16 10:16:00+03	2017-07-16 15:07:00+03
13813	PG0218	2017-08-09 10:10:00+03	2017-08-09 15:05:00+03	UFA	HTA	Arrived	319	2017-08-09 10:16:00+03	2017-08-09 15:16:00+03
13814	PG0218	2017-07-30 10:10:00+03	2017-07-30 15:05:00+03	UFA	HTA	Arrived	319	2017-07-30 10:13:00+03	2017-07-30 15:12:00+03
13815	PG0218	2017-08-13 10:10:00+03	2017-08-13 15:05:00+03	UFA	HTA	Arrived	319	2017-08-13 10:13:00+03	2017-08-13 15:00:00+03
13816	PG0218	2017-08-06 10:10:00+03	2017-08-06 15:05:00+03	UFA	HTA	Arrived	319	2017-08-06 10:15:00+03	2017-08-06 15:12:00+03
13817	PG0218	2017-09-13 10:10:00+03	2017-09-13 15:05:00+03	UFA	HTA	Cancelled	319	\N	\N
13818	PG0218	2017-07-26 10:10:00+03	2017-07-26 15:05:00+03	UFA	HTA	Arrived	319	2017-07-26 10:12:00+03	2017-07-26 15:05:00+03
13819	PG0218	2017-07-23 10:10:00+03	2017-07-23 15:05:00+03	UFA	HTA	Arrived	319	2017-07-23 10:13:00+03	2017-07-23 15:11:00+03
13820	PG0218	2017-08-27 10:10:00+03	2017-08-27 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13821	PG0218	2017-09-06 10:10:00+03	2017-09-06 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13822	PG0218	2017-09-10 10:10:00+03	2017-09-10 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13823	PG0218	2017-08-23 10:10:00+03	2017-08-23 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13824	PG0218	2017-07-19 10:10:00+03	2017-07-19 15:05:00+03	UFA	HTA	Arrived	319	2017-07-19 10:12:00+03	2017-07-19 15:00:00+03
13825	PG0218	2017-08-30 10:10:00+03	2017-08-30 15:05:00+03	UFA	HTA	Scheduled	319	\N	\N
13826	PG0548	2017-08-19 08:40:00+03	2017-08-19 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13827	PG0548	2017-08-27 08:40:00+03	2017-08-27 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13828	PG0548	2017-09-14 08:40:00+03	2017-09-14 13:05:00+03	KJA	SVO	Cancelled	319	\N	\N
13829	PG0548	2017-08-17 08:40:00+03	2017-08-17 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13830	PG0548	2017-09-05 08:40:00+03	2017-09-05 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13831	PG0548	2017-07-28 08:40:00+03	2017-07-28 13:05:00+03	KJA	SVO	Arrived	319	2017-07-28 08:40:00+03	2017-07-28 13:10:00+03
13832	PG0548	2017-08-13 08:40:00+03	2017-08-13 13:05:00+03	KJA	SVO	Arrived	319	2017-08-13 08:43:00+03	2017-08-13 13:07:00+03
13833	PG0548	2017-09-09 08:40:00+03	2017-09-09 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13834	PG0548	2017-08-28 08:40:00+03	2017-08-28 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13835	PG0548	2017-08-05 08:40:00+03	2017-08-05 13:05:00+03	KJA	SVO	Arrived	319	2017-08-05 08:42:00+03	2017-08-05 13:08:00+03
13836	PG0548	2017-07-18 08:40:00+03	2017-07-18 13:05:00+03	KJA	SVO	Arrived	319	2017-07-18 08:42:00+03	2017-07-18 13:09:00+03
13837	PG0548	2017-08-24 08:40:00+03	2017-08-24 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13838	PG0548	2017-09-13 08:40:00+03	2017-09-13 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13839	PG0548	2017-08-20 08:40:00+03	2017-08-20 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13840	PG0548	2017-08-07 08:40:00+03	2017-08-07 13:05:00+03	KJA	SVO	Arrived	319	2017-08-07 08:46:00+03	2017-08-07 13:12:00+03
13841	PG0548	2017-08-16 08:40:00+03	2017-08-16 13:05:00+03	KJA	SVO	On Time	319	\N	\N
13842	PG0548	2017-08-15 08:40:00+03	2017-08-15 13:05:00+03	KJA	SVO	Arrived	319	2017-08-15 08:47:00+03	2017-08-15 13:12:00+03
13843	PG0548	2017-08-11 08:40:00+03	2017-08-11 13:05:00+03	KJA	SVO	Arrived	319	2017-08-11 08:43:00+03	2017-08-11 13:10:00+03
13844	PG0548	2017-08-23 08:40:00+03	2017-08-23 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13845	PG0548	2017-08-01 08:40:00+03	2017-08-01 13:05:00+03	KJA	SVO	Arrived	319	2017-08-01 08:46:00+03	2017-08-01 13:09:00+03
13846	PG0548	2017-08-31 08:40:00+03	2017-08-31 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13847	PG0548	2017-07-29 08:40:00+03	2017-07-29 13:05:00+03	KJA	SVO	Arrived	319	2017-07-29 08:42:00+03	2017-07-29 13:04:00+03
13848	PG0548	2017-09-03 08:40:00+03	2017-09-03 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13849	PG0548	2017-09-11 08:40:00+03	2017-09-11 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13850	PG0548	2017-08-30 08:40:00+03	2017-08-30 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13851	PG0548	2017-07-21 08:40:00+03	2017-07-21 13:05:00+03	KJA	SVO	Arrived	319	2017-07-21 08:42:00+03	2017-07-21 13:06:00+03
13852	PG0548	2017-09-04 08:40:00+03	2017-09-04 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13853	PG0548	2017-07-26 08:40:00+03	2017-07-26 13:05:00+03	KJA	SVO	Arrived	319	2017-07-26 08:43:00+03	2017-07-26 13:05:00+03
13854	PG0548	2017-07-25 08:40:00+03	2017-07-25 13:05:00+03	KJA	SVO	Arrived	319	2017-07-25 08:45:00+03	2017-07-25 13:10:00+03
13855	PG0548	2017-07-31 08:40:00+03	2017-07-31 13:05:00+03	KJA	SVO	Arrived	319	2017-07-31 08:45:00+03	2017-07-31 13:09:00+03
13856	PG0548	2017-08-14 08:40:00+03	2017-08-14 13:05:00+03	KJA	SVO	Arrived	319	2017-08-14 08:42:00+03	2017-08-14 13:04:00+03
13857	PG0548	2017-07-27 08:40:00+03	2017-07-27 13:05:00+03	KJA	SVO	Arrived	319	2017-07-27 08:44:00+03	2017-07-27 13:11:00+03
13858	PG0548	2017-09-02 08:40:00+03	2017-09-02 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13859	PG0548	2017-08-06 08:40:00+03	2017-08-06 13:05:00+03	KJA	SVO	Arrived	319	2017-08-06 08:41:00+03	2017-08-06 13:02:00+03
13860	PG0548	2017-08-18 08:40:00+03	2017-08-18 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13861	PG0548	2017-09-06 08:40:00+03	2017-09-06 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13862	PG0548	2017-08-04 08:40:00+03	2017-08-04 13:05:00+03	KJA	SVO	Arrived	319	2017-08-04 08:42:00+03	2017-08-04 13:10:00+03
13863	PG0548	2017-07-22 08:40:00+03	2017-07-22 13:05:00+03	KJA	SVO	Arrived	319	2017-07-22 08:43:00+03	2017-07-22 13:10:00+03
13864	PG0548	2017-09-07 08:40:00+03	2017-09-07 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13865	PG0548	2017-08-22 08:40:00+03	2017-08-22 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13866	PG0548	2017-08-26 08:40:00+03	2017-08-26 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13867	PG0548	2017-07-24 08:40:00+03	2017-07-24 13:05:00+03	KJA	SVO	Arrived	319	2017-07-24 08:45:00+03	2017-07-24 13:11:00+03
13868	PG0548	2017-09-10 08:40:00+03	2017-09-10 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13869	PG0548	2017-08-09 08:40:00+03	2017-08-09 13:05:00+03	KJA	SVO	Arrived	319	2017-08-09 08:42:00+03	2017-08-09 13:04:00+03
13870	PG0548	2017-08-25 08:40:00+03	2017-08-25 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13871	PG0548	2017-08-12 08:40:00+03	2017-08-12 13:05:00+03	KJA	SVO	Arrived	319	2017-08-12 08:44:00+03	2017-08-12 13:13:00+03
13872	PG0548	2017-09-08 08:40:00+03	2017-09-08 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13873	PG0548	2017-09-12 08:40:00+03	2017-09-12 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13874	PG0548	2017-07-19 08:40:00+03	2017-07-19 13:05:00+03	KJA	SVO	Arrived	319	2017-07-19 08:42:00+03	2017-07-19 13:10:00+03
13875	PG0548	2017-07-30 08:40:00+03	2017-07-30 13:05:00+03	KJA	SVO	Arrived	319	2017-07-30 08:43:00+03	2017-07-30 13:08:00+03
13876	PG0548	2017-08-10 08:40:00+03	2017-08-10 13:05:00+03	KJA	SVO	Arrived	319	2017-08-10 08:44:00+03	2017-08-10 13:11:00+03
13877	PG0548	2017-07-20 08:40:00+03	2017-07-20 13:05:00+03	KJA	SVO	Arrived	319	2017-07-20 08:42:00+03	2017-07-20 13:09:00+03
13878	PG0548	2017-08-08 08:40:00+03	2017-08-08 13:05:00+03	KJA	SVO	Arrived	319	2017-08-08 08:41:00+03	2017-08-08 13:06:00+03
13879	PG0548	2017-08-03 08:40:00+03	2017-08-03 13:05:00+03	KJA	SVO	Arrived	319	2017-08-03 08:42:00+03	2017-08-03 13:07:00+03
13880	PG0548	2017-08-29 08:40:00+03	2017-08-29 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13881	PG0548	2017-09-01 08:40:00+03	2017-09-01 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13882	PG0548	2017-07-23 08:40:00+03	2017-07-23 13:05:00+03	KJA	SVO	Arrived	319	2017-07-23 08:42:00+03	2017-07-23 13:09:00+03
13883	PG0548	2017-08-02 08:40:00+03	2017-08-02 13:05:00+03	KJA	SVO	Arrived	319	2017-08-02 08:44:00+03	2017-08-02 13:05:00+03
13884	PG0548	2017-07-16 08:40:00+03	2017-07-16 13:05:00+03	KJA	SVO	Arrived	319	2017-07-16 08:44:00+03	2017-07-16 13:09:00+03
13885	PG0548	2017-07-17 08:40:00+03	2017-07-17 13:05:00+03	KJA	SVO	Arrived	319	2017-07-17 08:42:00+03	2017-07-17 13:01:00+03
13886	PG0548	2017-08-21 08:40:00+03	2017-08-21 13:05:00+03	KJA	SVO	Scheduled	319	\N	\N
13887	PG0206	2017-07-26 10:20:00+03	2017-07-26 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-26 10:22:00+03	2017-07-26 12:27:00+03
13888	PG0206	2017-08-31 10:20:00+03	2017-08-31 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13889	PG0207	2017-07-29 07:35:00+03	2017-07-29 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-29 07:40:00+03	2017-07-29 09:44:00+03
13890	PG0207	2017-09-10 07:35:00+03	2017-09-10 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13891	PG0207	2017-07-26 07:35:00+03	2017-07-26 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-26 07:39:00+03	2017-07-26 09:44:00+03
13892	PG0206	2017-08-08 10:20:00+03	2017-08-08 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-08 10:20:00+03	2017-08-08 12:26:00+03
13893	PG0206	2017-08-23 10:20:00+03	2017-08-23 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13894	PG0206	2017-07-27 10:20:00+03	2017-07-27 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-27 10:24:00+03	2017-07-27 12:28:00+03
13895	PG0207	2017-08-08 07:35:00+03	2017-08-08 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-08 07:39:00+03	2017-08-08 09:44:00+03
13896	PG0206	2017-07-20 10:20:00+03	2017-07-20 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-20 10:24:00+03	2017-07-20 12:27:00+03
13897	PG0207	2017-08-23 07:35:00+03	2017-08-23 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13898	PG0206	2017-09-09 10:20:00+03	2017-09-09 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13899	PG0207	2017-08-24 07:35:00+03	2017-08-24 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13900	PG0207	2017-08-17 07:35:00+03	2017-08-17 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13901	PG0206	2017-08-17 10:20:00+03	2017-08-17 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13902	PG0207	2017-09-03 07:35:00+03	2017-09-03 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13903	PG0206	2017-08-24 10:20:00+03	2017-08-24 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13904	PG0206	2017-09-04 10:20:00+03	2017-09-04 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13905	PG0206	2017-08-27 10:20:00+03	2017-08-27 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13906	PG0207	2017-08-16 07:35:00+03	2017-08-16 09:40:00+03	KJA	OVB	On Time	CN1	\N	\N
13907	PG0207	2017-08-27 07:35:00+03	2017-08-27 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13908	PG0207	2017-09-06 07:35:00+03	2017-09-06 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13909	PG0206	2017-08-04 10:20:00+03	2017-08-04 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-04 10:26:00+03	2017-08-04 12:30:00+03
13910	PG0207	2017-08-04 07:35:00+03	2017-08-04 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-04 07:36:00+03	2017-08-04 09:42:00+03
13911	PG0207	2017-07-21 07:35:00+03	2017-07-21 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-21 07:40:00+03	2017-07-21 09:43:00+03
13912	PG0206	2017-07-21 10:20:00+03	2017-07-21 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-21 10:23:00+03	2017-07-21 12:28:00+03
13913	PG0206	2017-07-29 10:20:00+03	2017-07-29 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-29 10:23:00+03	2017-07-29 12:28:00+03
13914	PG0207	2017-08-20 07:35:00+03	2017-08-20 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13915	PG0206	2017-08-20 10:20:00+03	2017-08-20 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13916	PG0207	2017-09-11 07:35:00+03	2017-09-11 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13917	PG0206	2017-08-14 10:20:00+03	2017-08-14 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-14 10:24:00+03	2017-08-14 12:29:00+03
13918	PG0207	2017-08-19 07:35:00+03	2017-08-19 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13919	PG0207	2017-08-26 07:35:00+03	2017-08-26 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13920	PG0206	2017-08-28 10:20:00+03	2017-08-28 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13921	PG0206	2017-08-07 10:20:00+03	2017-08-07 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-07 10:28:00+03	2017-08-07 12:33:00+03
13922	PG0207	2017-08-07 07:35:00+03	2017-08-07 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-07 07:40:00+03	2017-08-07 09:41:00+03
13923	PG0206	2017-08-19 10:20:00+03	2017-08-19 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13924	PG0207	2017-08-03 07:35:00+03	2017-08-03 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-03 10:54:00+03	2017-08-03 12:58:00+03
13925	PG0206	2017-08-21 10:20:00+03	2017-08-21 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13926	PG0206	2017-08-02 10:20:00+03	2017-08-02 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-02 10:20:00+03	2017-08-02 12:23:00+03
13927	PG0206	2017-08-16 10:20:00+03	2017-08-16 12:25:00+03	KJA	OVB	On Time	CN1	\N	\N
13928	PG0206	2017-08-01 10:20:00+03	2017-08-01 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-01 10:23:00+03	2017-08-01 12:29:00+03
13929	PG0207	2017-08-30 07:35:00+03	2017-08-30 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13930	PG0207	2017-08-21 07:35:00+03	2017-08-21 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13931	PG0206	2017-07-18 10:20:00+03	2017-07-18 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-18 10:22:00+03	2017-07-18 12:28:00+03
13932	PG0207	2017-07-18 07:35:00+03	2017-07-18 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-18 07:36:00+03	2017-07-18 09:40:00+03
13933	PG0207	2017-09-07 07:35:00+03	2017-09-07 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13934	PG0206	2017-09-07 10:20:00+03	2017-09-07 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13935	PG0207	2017-09-02 07:35:00+03	2017-09-02 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13936	PG0207	2017-08-09 07:35:00+03	2017-08-09 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-09 07:40:00+03	2017-08-09 09:45:00+03
13937	PG0206	2017-08-09 10:20:00+03	2017-08-09 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-09 10:22:00+03	2017-08-09 12:27:00+03
13938	PG0206	2017-09-02 10:20:00+03	2017-09-02 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13939	PG0206	2017-08-13 10:20:00+03	2017-08-13 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-13 10:23:00+03	2017-08-13 12:28:00+03
13940	PG0207	2017-09-04 07:35:00+03	2017-09-04 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13941	PG0207	2017-08-13 07:35:00+03	2017-08-13 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-13 07:37:00+03	2017-08-13 09:43:00+03
13942	PG0206	2017-08-25 10:20:00+03	2017-08-25 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13943	PG0206	2017-08-10 10:20:00+03	2017-08-10 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-10 10:23:00+03	2017-08-10 12:28:00+03
13944	PG0207	2017-08-10 07:35:00+03	2017-08-10 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-10 07:39:00+03	2017-08-10 09:44:00+03
13945	PG0206	2017-09-11 10:20:00+03	2017-09-11 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13946	PG0206	2017-07-19 10:20:00+03	2017-07-19 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-19 10:21:00+03	2017-07-19 12:25:00+03
13947	PG0206	2017-07-31 10:20:00+03	2017-07-31 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-31 10:24:00+03	2017-07-31 12:29:00+03
13948	PG0207	2017-07-19 07:35:00+03	2017-07-19 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-19 07:38:00+03	2017-07-19 09:42:00+03
13949	PG0206	2017-08-22 10:20:00+03	2017-08-22 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13950	PG0207	2017-09-09 07:35:00+03	2017-09-09 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13951	PG0207	2017-07-31 07:35:00+03	2017-07-31 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-31 07:39:00+03	2017-07-31 09:45:00+03
13952	PG0206	2017-08-06 10:20:00+03	2017-08-06 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-06 10:21:00+03	2017-08-06 12:24:00+03
13953	PG0207	2017-09-13 07:35:00+03	2017-09-13 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13954	PG0206	2017-08-30 10:20:00+03	2017-08-30 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13955	PG0207	2017-09-08 07:35:00+03	2017-09-08 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13956	PG0206	2017-08-05 10:20:00+03	2017-08-05 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-05 10:24:00+03	2017-08-05 12:30:00+03
13957	PG0206	2017-09-06 10:20:00+03	2017-09-06 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13958	PG0207	2017-08-05 07:35:00+03	2017-08-05 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-05 07:36:00+03	2017-08-05 09:41:00+03
13959	PG0206	2017-09-13 10:20:00+03	2017-09-13 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13960	PG0207	2017-08-06 07:35:00+03	2017-08-06 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-06 07:36:00+03	2017-08-06 09:43:00+03
13961	PG0206	2017-08-15 10:20:00+03	2017-08-15 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-15 10:21:00+03	2017-08-15 12:26:00+03
13962	PG0207	2017-08-15 07:35:00+03	2017-08-15 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-15 07:38:00+03	2017-08-15 09:43:00+03
13963	PG0206	2017-07-16 10:20:00+03	2017-07-16 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-16 10:20:00+03	2017-07-16 12:26:00+03
13964	PG0207	2017-07-30 07:35:00+03	2017-07-30 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-30 07:39:00+03	2017-07-30 09:44:00+03
13965	PG0206	2017-07-30 10:20:00+03	2017-07-30 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-30 10:25:00+03	2017-07-30 12:29:00+03
13966	PG0207	2017-07-20 07:35:00+03	2017-07-20 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-20 07:37:00+03	2017-07-20 09:43:00+03
13967	PG0206	2017-09-12 10:20:00+03	2017-09-12 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13968	PG0207	2017-07-16 07:35:00+03	2017-07-16 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-16 07:37:00+03	2017-07-16 09:42:00+03
13969	PG0206	2017-09-08 10:20:00+03	2017-09-08 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13970	PG0207	2017-08-02 07:35:00+03	2017-08-02 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-02 07:36:00+03	2017-08-02 09:41:00+03
13971	PG0206	2017-07-17 10:20:00+03	2017-07-17 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-17 10:23:00+03	2017-07-17 12:29:00+03
13972	PG0207	2017-07-17 07:35:00+03	2017-07-17 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-17 07:40:00+03	2017-07-17 09:45:00+03
13973	PG0207	2017-09-12 07:35:00+03	2017-09-12 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13974	PG0206	2017-08-29 10:20:00+03	2017-08-29 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13975	PG0207	2017-08-28 07:35:00+03	2017-08-28 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13976	PG0207	2017-08-29 07:35:00+03	2017-08-29 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13977	PG0207	2017-08-11 07:35:00+03	2017-08-11 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-11 07:37:00+03	2017-08-11 09:43:00+03
13978	PG0206	2017-08-26 10:20:00+03	2017-08-26 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13979	PG0206	2017-08-11 10:20:00+03	2017-08-11 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-11 10:22:00+03	2017-08-11 12:28:00+03
13980	PG0207	2017-08-18 07:35:00+03	2017-08-18 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13981	PG0206	2017-08-18 10:20:00+03	2017-08-18 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13982	PG0207	2017-09-05 07:35:00+03	2017-09-05 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13983	PG0206	2017-09-05 10:20:00+03	2017-09-05 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13984	PG0207	2017-09-14 07:35:00+03	2017-09-14 09:40:00+03	KJA	OVB	Cancelled	CN1	\N	\N
13985	PG0207	2017-08-01 07:35:00+03	2017-08-01 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-01 07:38:00+03	2017-08-01 09:45:00+03
13986	PG0206	2017-08-12 10:20:00+03	2017-08-12 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-12 10:23:00+03	2017-08-12 12:29:00+03
13987	PG0207	2017-08-12 07:35:00+03	2017-08-12 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-12 07:39:00+03	2017-08-12 09:43:00+03
13988	PG0206	2017-07-28 10:20:00+03	2017-07-28 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-28 10:22:00+03	2017-07-28 12:27:00+03
13989	PG0207	2017-07-28 07:35:00+03	2017-07-28 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-28 07:42:00+03	2017-07-28 09:45:00+03
13990	PG0207	2017-08-14 07:35:00+03	2017-08-14 09:40:00+03	KJA	OVB	Arrived	CN1	2017-08-14 07:36:00+03	2017-08-14 09:42:00+03
13991	PG0206	2017-09-03 10:20:00+03	2017-09-03 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13992	PG0207	2017-07-27 07:35:00+03	2017-07-27 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-27 11:14:00+03	2017-07-27 13:18:00+03
13993	PG0206	2017-07-24 10:20:00+03	2017-07-24 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-24 10:25:00+03	2017-07-24 12:31:00+03
13994	PG0207	2017-08-22 07:35:00+03	2017-08-22 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13995	PG0207	2017-07-23 07:35:00+03	2017-07-23 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-23 07:37:00+03	2017-07-23 09:41:00+03
13996	PG0206	2017-09-01 10:20:00+03	2017-09-01 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13997	PG0207	2017-07-24 07:35:00+03	2017-07-24 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-24 07:37:00+03	2017-07-24 09:41:00+03
13998	PG0207	2017-09-01 07:35:00+03	2017-09-01 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
13999	PG0206	2017-07-25 10:20:00+03	2017-07-25 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-25 13:21:00+03	2017-07-25 15:25:00+03
14000	PG0207	2017-08-25 07:35:00+03	2017-08-25 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
14001	PG0206	2017-09-14 10:20:00+03	2017-09-14 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
14002	PG0207	2017-07-25 07:35:00+03	2017-07-25 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-25 07:36:00+03	2017-07-25 09:41:00+03
14003	PG0206	2017-08-03 10:20:00+03	2017-08-03 12:25:00+03	KJA	OVB	Arrived	CN1	2017-08-03 10:22:00+03	2017-08-03 12:26:00+03
14004	PG0207	2017-08-31 07:35:00+03	2017-08-31 09:40:00+03	KJA	OVB	Scheduled	CN1	\N	\N
14005	PG0206	2017-07-23 10:20:00+03	2017-07-23 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-23 10:22:00+03	2017-07-23 12:27:00+03
14006	PG0206	2017-07-22 10:20:00+03	2017-07-22 12:25:00+03	KJA	OVB	Arrived	CN1	2017-07-22 10:24:00+03	2017-07-22 12:28:00+03
14007	PG0207	2017-07-22 07:35:00+03	2017-07-22 09:40:00+03	KJA	OVB	Arrived	CN1	2017-07-22 07:40:00+03	2017-07-22 09:47:00+03
14008	PG0206	2017-09-10 10:20:00+03	2017-09-10 12:25:00+03	KJA	OVB	Scheduled	CN1	\N	\N
14009	PG0623	2017-09-06 10:00:00+03	2017-09-06 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14010	PG0623	2017-08-02 10:00:00+03	2017-08-02 12:00:00+03	KJA	NUX	Arrived	CR2	2017-08-02 10:03:00+03	2017-08-02 12:04:00+03
14011	PG0623	2017-09-03 10:00:00+03	2017-09-03 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14012	PG0623	2017-08-23 10:00:00+03	2017-08-23 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14013	PG0623	2017-07-26 10:00:00+03	2017-07-26 12:00:00+03	KJA	NUX	Arrived	CR2	2017-07-26 10:01:00+03	2017-07-26 12:01:00+03
14014	PG0623	2017-09-10 10:00:00+03	2017-09-10 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14015	PG0623	2017-09-13 10:00:00+03	2017-09-13 12:00:00+03	KJA	NUX	Cancelled	CR2	\N	\N
14016	PG0623	2017-08-06 10:00:00+03	2017-08-06 12:00:00+03	KJA	NUX	Arrived	CR2	2017-08-06 10:04:00+03	2017-08-06 12:06:00+03
14017	PG0623	2017-08-13 10:00:00+03	2017-08-13 12:00:00+03	KJA	NUX	Arrived	CR2	2017-08-13 10:05:00+03	2017-08-13 12:05:00+03
14018	PG0623	2017-07-19 10:00:00+03	2017-07-19 12:00:00+03	KJA	NUX	Arrived	CR2	2017-07-19 10:04:00+03	2017-07-19 12:03:00+03
14019	PG0623	2017-07-30 10:00:00+03	2017-07-30 12:00:00+03	KJA	NUX	Arrived	CR2	2017-07-30 10:03:00+03	2017-07-30 12:04:00+03
14020	PG0623	2017-08-27 10:00:00+03	2017-08-27 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14021	PG0623	2017-08-09 10:00:00+03	2017-08-09 12:00:00+03	KJA	NUX	Arrived	CR2	2017-08-09 10:03:00+03	2017-08-09 12:03:00+03
14022	PG0623	2017-07-16 10:00:00+03	2017-07-16 12:00:00+03	KJA	NUX	Arrived	CR2	2017-07-16 10:01:00+03	2017-07-16 12:02:00+03
14023	PG0623	2017-08-16 10:00:00+03	2017-08-16 12:00:00+03	KJA	NUX	On Time	CR2	\N	\N
14024	PG0623	2017-07-23 10:00:00+03	2017-07-23 12:00:00+03	KJA	NUX	Arrived	CR2	2017-07-23 10:03:00+03	2017-07-23 12:03:00+03
14025	PG0623	2017-08-30 10:00:00+03	2017-08-30 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14026	PG0623	2017-08-20 10:00:00+03	2017-08-20 12:00:00+03	KJA	NUX	Scheduled	CR2	\N	\N
14027	PG0625	2017-09-10 13:10:00+03	2017-09-10 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14028	PG0626	2017-07-27 11:35:00+03	2017-07-27 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-27 14:41:00+03	2017-07-27 16:45:00+03
14029	PG0626	2017-08-19 11:35:00+03	2017-08-19 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14030	PG0625	2017-08-09 13:10:00+03	2017-08-09 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-09 13:13:00+03	2017-08-09 15:18:00+03
14031	PG0626	2017-08-09 11:35:00+03	2017-08-09 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-09 11:35:00+03	2017-08-09 13:40:00+03
14032	PG0626	2017-07-21 11:35:00+03	2017-07-21 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-21 11:38:00+03	2017-07-21 13:41:00+03
14033	PG0626	2017-08-14 11:35:00+03	2017-08-14 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-14 11:37:00+03	2017-08-14 13:40:00+03
14034	PG0625	2017-08-14 13:10:00+03	2017-08-14 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-14 13:14:00+03	2017-08-14 15:18:00+03
14035	PG0625	2017-07-21 13:10:00+03	2017-07-21 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-21 13:11:00+03	2017-07-21 15:17:00+03
14036	PG0626	2017-07-17 11:35:00+03	2017-07-17 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-17 11:38:00+03	2017-07-17 13:43:00+03
14037	PG0625	2017-07-17 13:10:00+03	2017-07-17 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-17 13:18:00+03	2017-07-17 15:23:00+03
14038	PG0626	2017-09-08 11:35:00+03	2017-09-08 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14039	PG0625	2017-09-08 13:10:00+03	2017-09-08 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14040	PG0625	2017-08-16 13:10:00+03	2017-08-16 15:15:00+03	KJA	UIK	On Time	CN1	\N	\N
14041	PG0625	2017-09-06 13:10:00+03	2017-09-06 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14042	PG0626	2017-08-27 11:35:00+03	2017-08-27 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14043	PG0626	2017-08-16 11:35:00+03	2017-08-16 13:40:00+03	KJA	UIK	On Time	CN1	\N	\N
14044	PG0626	2017-08-24 11:35:00+03	2017-08-24 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14045	PG0625	2017-08-24 13:10:00+03	2017-08-24 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14046	PG0625	2017-08-27 13:10:00+03	2017-08-27 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14047	PG0625	2017-08-18 13:10:00+03	2017-08-18 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14048	PG0625	2017-08-22 13:10:00+03	2017-08-22 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14049	PG0626	2017-08-22 11:35:00+03	2017-08-22 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14050	PG0626	2017-08-18 11:35:00+03	2017-08-18 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14051	PG0625	2017-07-22 13:10:00+03	2017-07-22 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-22 13:13:00+03	2017-07-22 15:20:00+03
14052	PG0626	2017-07-22 11:35:00+03	2017-07-22 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-22 11:38:00+03	2017-07-22 13:44:00+03
14053	PG0626	2017-08-13 11:35:00+03	2017-08-13 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-13 11:37:00+03	2017-08-13 13:42:00+03
14054	PG0625	2017-08-13 13:10:00+03	2017-08-13 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-13 13:13:00+03	2017-08-13 15:18:00+03
14055	PG0625	2017-09-12 13:10:00+03	2017-09-12 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14056	PG0625	2017-08-26 13:10:00+03	2017-08-26 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14057	PG0626	2017-08-26 11:35:00+03	2017-08-26 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14058	PG0626	2017-07-26 11:35:00+03	2017-07-26 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-26 11:40:00+03	2017-07-26 13:45:00+03
14059	PG0625	2017-07-26 13:10:00+03	2017-07-26 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-26 13:12:00+03	2017-07-26 15:18:00+03
14060	PG0625	2017-08-05 13:10:00+03	2017-08-05 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-05 13:14:00+03	2017-08-05 15:18:00+03
14061	PG0626	2017-08-02 11:35:00+03	2017-08-02 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-02 11:38:00+03	2017-08-02 13:42:00+03
14062	PG0625	2017-08-02 13:10:00+03	2017-08-02 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-02 13:11:00+03	2017-08-02 15:17:00+03
14063	PG0626	2017-07-24 11:35:00+03	2017-07-24 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-24 11:39:00+03	2017-07-24 13:44:00+03
14064	PG0626	2017-08-05 11:35:00+03	2017-08-05 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-05 11:38:00+03	2017-08-05 13:44:00+03
14065	PG0625	2017-09-05 13:10:00+03	2017-09-05 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14066	PG0626	2017-09-05 11:35:00+03	2017-09-05 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14067	PG0625	2017-08-21 13:10:00+03	2017-08-21 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14068	PG0626	2017-09-13 11:35:00+03	2017-09-13 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14069	PG0625	2017-09-13 13:10:00+03	2017-09-13 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14070	PG0625	2017-08-07 13:10:00+03	2017-08-07 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-07 13:13:00+03	2017-08-07 15:18:00+03
14071	PG0626	2017-07-28 11:35:00+03	2017-07-28 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-28 11:38:00+03	2017-07-28 13:41:00+03
14072	PG0625	2017-07-28 13:10:00+03	2017-07-28 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-28 16:42:00+03	2017-07-28 18:45:00+03
14073	PG0626	2017-08-07 11:35:00+03	2017-08-07 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-07 11:38:00+03	2017-08-07 13:42:00+03
14074	PG0626	2017-09-09 11:35:00+03	2017-09-09 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14075	PG0626	2017-08-08 11:35:00+03	2017-08-08 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-08 11:36:00+03	2017-08-08 13:42:00+03
14076	PG0625	2017-08-08 13:10:00+03	2017-08-08 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-08 13:11:00+03	2017-08-08 15:15:00+03
14077	PG0625	2017-08-01 13:10:00+03	2017-08-01 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-01 13:14:00+03	2017-08-01 15:20:00+03
14078	PG0625	2017-08-03 13:10:00+03	2017-08-03 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-03 13:15:00+03	2017-08-03 15:18:00+03
14079	PG0626	2017-08-03 11:35:00+03	2017-08-03 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-03 11:39:00+03	2017-08-03 13:43:00+03
14080	PG0626	2017-09-03 11:35:00+03	2017-09-03 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14081	PG0626	2017-08-01 11:35:00+03	2017-08-01 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-01 11:42:00+03	2017-08-01 13:48:00+03
14082	PG0626	2017-08-21 11:35:00+03	2017-08-21 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14083	PG0626	2017-07-31 11:35:00+03	2017-07-31 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-31 15:02:00+03	2017-07-31 17:07:00+03
14084	PG0626	2017-08-20 11:35:00+03	2017-08-20 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14085	PG0625	2017-09-14 13:10:00+03	2017-09-14 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14086	PG0625	2017-09-02 13:10:00+03	2017-09-02 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14087	PG0626	2017-09-01 11:35:00+03	2017-09-01 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14088	PG0626	2017-09-02 11:35:00+03	2017-09-02 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14089	PG0625	2017-09-01 13:10:00+03	2017-09-01 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14090	PG0626	2017-09-14 11:35:00+03	2017-09-14 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14091	PG0626	2017-08-29 11:35:00+03	2017-08-29 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14092	PG0626	2017-07-30 11:35:00+03	2017-07-30 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-30 11:37:00+03	2017-07-30 13:41:00+03
14093	PG0625	2017-07-16 13:10:00+03	2017-07-16 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-16 13:12:00+03	2017-07-16 15:17:00+03
14094	PG0626	2017-08-31 11:35:00+03	2017-08-31 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14095	PG0625	2017-08-31 13:10:00+03	2017-08-31 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14096	PG0625	2017-07-30 13:10:00+03	2017-07-30 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-30 17:13:00+03	2017-07-30 19:18:00+03
14097	PG0625	2017-09-09 13:10:00+03	2017-09-09 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14098	PG0625	2017-07-25 13:10:00+03	2017-07-25 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-25 13:10:00+03	2017-07-25 15:15:00+03
14099	PG0626	2017-07-16 11:35:00+03	2017-07-16 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-16 11:37:00+03	2017-07-16 13:42:00+03
14100	PG0625	2017-08-30 13:10:00+03	2017-08-30 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14101	PG0626	2017-08-30 11:35:00+03	2017-08-30 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14102	PG0626	2017-07-25 11:35:00+03	2017-07-25 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-25 14:04:00+03	2017-07-25 16:09:00+03
14103	PG0626	2017-08-11 11:35:00+03	2017-08-11 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-11 11:38:00+03	2017-08-11 13:44:00+03
14104	PG0625	2017-08-11 13:10:00+03	2017-08-11 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-11 13:12:00+03	2017-08-11 15:16:00+03
14105	PG0626	2017-08-15 11:35:00+03	2017-08-15 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-15 11:38:00+03	2017-08-15 13:43:00+03
14106	PG0625	2017-08-15 13:10:00+03	2017-08-15 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-15 13:13:00+03	2017-08-15 15:18:00+03
14107	PG0625	2017-08-17 13:10:00+03	2017-08-17 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14108	PG0626	2017-08-17 11:35:00+03	2017-08-17 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14109	PG0626	2017-07-19 11:35:00+03	2017-07-19 13:40:00+03	KJA	UIK	Cancelled	CN1	2017-07-19 11:39:00+03	2017-07-19 13:43:00+03
14110	PG0626	2017-08-28 11:35:00+03	2017-08-28 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14111	PG0626	2017-09-12 11:35:00+03	2017-09-12 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14112	PG0625	2017-08-10 13:10:00+03	2017-08-10 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-10 13:15:00+03	2017-08-10 15:20:00+03
14113	PG0626	2017-08-10 11:35:00+03	2017-08-10 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-10 11:37:00+03	2017-08-10 13:41:00+03
14114	PG0626	2017-08-06 11:35:00+03	2017-08-06 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-06 11:42:00+03	2017-08-06 13:47:00+03
14115	PG0625	2017-08-06 13:10:00+03	2017-08-06 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-06 13:17:00+03	2017-08-06 15:23:00+03
14116	PG0626	2017-09-11 11:35:00+03	2017-09-11 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14117	PG0625	2017-09-11 13:10:00+03	2017-09-11 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14118	PG0625	2017-08-28 13:10:00+03	2017-08-28 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14119	PG0625	2017-07-31 13:10:00+03	2017-07-31 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-31 13:11:00+03	2017-07-31 15:15:00+03
14120	PG0625	2017-07-19 13:10:00+03	2017-07-19 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-19 13:13:00+03	2017-07-19 15:17:00+03
14121	PG0625	2017-08-20 13:10:00+03	2017-08-20 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14122	PG0625	2017-07-18 13:10:00+03	2017-07-18 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-18 13:13:00+03	2017-07-18 15:17:00+03
14123	PG0626	2017-07-18 11:35:00+03	2017-07-18 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-18 11:36:00+03	2017-07-18 13:39:00+03
14124	PG0625	2017-08-29 13:10:00+03	2017-08-29 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14125	PG0625	2017-07-20 13:10:00+03	2017-07-20 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-20 13:14:00+03	2017-07-20 15:16:00+03
14126	PG0626	2017-07-20 11:35:00+03	2017-07-20 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-20 11:38:00+03	2017-07-20 13:40:00+03
14127	PG0626	2017-08-04 11:35:00+03	2017-08-04 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-04 11:40:00+03	2017-08-04 13:44:00+03
14128	PG0625	2017-08-04 13:10:00+03	2017-08-04 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-04 13:14:00+03	2017-08-04 15:19:00+03
14129	PG0625	2017-09-04 13:10:00+03	2017-09-04 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14130	PG0626	2017-09-04 11:35:00+03	2017-09-04 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14131	PG0625	2017-07-24 13:10:00+03	2017-07-24 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-24 13:15:00+03	2017-07-24 15:21:00+03
14132	PG0626	2017-08-12 11:35:00+03	2017-08-12 13:40:00+03	KJA	UIK	Arrived	CN1	2017-08-12 11:39:00+03	2017-08-12 13:43:00+03
14133	PG0626	2017-08-23 11:35:00+03	2017-08-23 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14134	PG0625	2017-07-29 13:10:00+03	2017-07-29 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-29 13:15:00+03	2017-07-29 15:21:00+03
14135	PG0625	2017-08-23 13:10:00+03	2017-08-23 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14136	PG0626	2017-09-07 11:35:00+03	2017-09-07 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14137	PG0625	2017-09-07 13:10:00+03	2017-09-07 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14138	PG0626	2017-07-29 11:35:00+03	2017-07-29 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-29 11:38:00+03	2017-07-29 13:42:00+03
14139	PG0625	2017-08-12 13:10:00+03	2017-08-12 15:15:00+03	KJA	UIK	Arrived	CN1	2017-08-12 13:15:00+03	2017-08-12 15:21:00+03
14140	PG0626	2017-09-06 11:35:00+03	2017-09-06 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14141	PG0626	2017-09-10 11:35:00+03	2017-09-10 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14142	PG0625	2017-08-19 13:10:00+03	2017-08-19 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14143	PG0625	2017-09-03 13:10:00+03	2017-09-03 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14144	PG0626	2017-07-23 11:35:00+03	2017-07-23 13:40:00+03	KJA	UIK	Arrived	CN1	2017-07-23 11:36:00+03	2017-07-23 13:41:00+03
14145	PG0625	2017-08-25 13:10:00+03	2017-08-25 15:15:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14146	PG0626	2017-08-25 11:35:00+03	2017-08-25 13:40:00+03	KJA	UIK	Scheduled	CN1	\N	\N
14147	PG0625	2017-07-27 13:10:00+03	2017-07-27 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-27 13:16:00+03	2017-07-27 15:24:00+03
14148	PG0625	2017-07-23 13:10:00+03	2017-07-23 15:15:00+03	KJA	UIK	Arrived	CN1	2017-07-23 13:13:00+03	2017-07-23 15:20:00+03
14149	PG0689	2017-08-08 07:25:00+03	2017-08-08 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-08 07:29:00+03	2017-08-08 09:49:00+03
14150	PG0689	2017-08-15 07:25:00+03	2017-08-15 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-15 07:27:00+03	2017-08-15 09:47:00+03
14151	PG0689	2017-09-09 07:25:00+03	2017-09-09 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14152	PG0689	2017-07-18 07:25:00+03	2017-07-18 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-18 10:35:00+03	2017-07-18 12:54:00+03
14153	PG0689	2017-08-02 07:25:00+03	2017-08-02 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-02 07:29:00+03	2017-08-02 09:49:00+03
14154	PG0689	2017-08-22 07:25:00+03	2017-08-22 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14155	PG0689	2017-08-05 07:25:00+03	2017-08-05 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-05 07:28:00+03	2017-08-05 09:46:00+03
14156	PG0689	2017-07-28 07:25:00+03	2017-07-28 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-28 07:28:00+03	2017-07-28 09:50:00+03
14157	PG0689	2017-08-24 07:25:00+03	2017-08-24 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14158	PG0689	2017-07-16 07:25:00+03	2017-07-16 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-16 10:48:00+03	2017-07-16 13:08:00+03
14159	PG0689	2017-08-04 07:25:00+03	2017-08-04 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-04 07:30:00+03	2017-08-04 09:49:00+03
14160	PG0689	2017-07-29 07:25:00+03	2017-07-29 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-29 07:28:00+03	2017-07-29 09:48:00+03
14161	PG0689	2017-09-12 07:25:00+03	2017-09-12 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14162	PG0689	2017-08-31 07:25:00+03	2017-08-31 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14163	PG0689	2017-08-27 07:25:00+03	2017-08-27 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14164	PG0689	2017-08-20 07:25:00+03	2017-08-20 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14165	PG0689	2017-09-13 07:25:00+03	2017-09-13 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14166	PG0689	2017-07-24 07:25:00+03	2017-07-24 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-24 07:28:00+03	2017-07-24 09:47:00+03
14167	PG0689	2017-08-26 07:25:00+03	2017-08-26 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14168	PG0689	2017-09-04 07:25:00+03	2017-09-04 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14169	PG0689	2017-09-08 07:25:00+03	2017-09-08 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14170	PG0689	2017-08-12 07:25:00+03	2017-08-12 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-12 07:30:00+03	2017-08-12 09:49:00+03
14171	PG0689	2017-08-28 07:25:00+03	2017-08-28 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14172	PG0689	2017-08-03 07:25:00+03	2017-08-03 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-03 09:45:00+03	2017-08-03 12:04:00+03
14173	PG0689	2017-09-07 07:25:00+03	2017-09-07 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14174	PG0689	2017-08-01 07:25:00+03	2017-08-01 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-01 09:58:00+03	2017-08-01 12:17:00+03
14175	PG0689	2017-08-13 07:25:00+03	2017-08-13 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-13 07:25:00+03	2017-08-13 09:45:00+03
14176	PG0689	2017-08-19 07:25:00+03	2017-08-19 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14177	PG0689	2017-09-11 07:25:00+03	2017-09-11 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14178	PG0689	2017-09-05 07:25:00+03	2017-09-05 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14179	PG0689	2017-08-07 07:25:00+03	2017-08-07 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-07 07:31:00+03	2017-08-07 09:50:00+03
14180	PG0689	2017-09-10 07:25:00+03	2017-09-10 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14181	PG0689	2017-07-20 07:25:00+03	2017-07-20 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-20 07:28:00+03	2017-07-20 09:46:00+03
14182	PG0689	2017-08-09 07:25:00+03	2017-08-09 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-09 07:29:00+03	2017-08-09 09:48:00+03
14183	PG0689	2017-07-21 07:25:00+03	2017-07-21 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-21 07:28:00+03	2017-07-21 09:49:00+03
14184	PG0689	2017-09-03 07:25:00+03	2017-09-03 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14185	PG0689	2017-07-22 07:25:00+03	2017-07-22 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-22 07:26:00+03	2017-07-22 09:46:00+03
14186	PG0689	2017-08-18 07:25:00+03	2017-08-18 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14187	PG0689	2017-07-26 07:25:00+03	2017-07-26 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-26 07:30:00+03	2017-07-26 09:49:00+03
14188	PG0689	2017-07-31 07:25:00+03	2017-07-31 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-31 07:31:00+03	2017-07-31 09:50:00+03
14189	PG0689	2017-09-14 07:25:00+03	2017-09-14 09:45:00+03	KJA	OVS	Cancelled	SU9	\N	\N
14190	PG0689	2017-08-25 07:25:00+03	2017-08-25 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14191	PG0689	2017-07-27 07:25:00+03	2017-07-27 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-27 07:27:00+03	2017-07-27 09:51:00+03
14192	PG0689	2017-08-11 07:25:00+03	2017-08-11 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-11 07:28:00+03	2017-08-11 09:49:00+03
14193	PG0689	2017-07-17 07:25:00+03	2017-07-17 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-17 07:28:00+03	2017-07-17 09:47:00+03
14194	PG0689	2017-07-25 07:25:00+03	2017-07-25 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-25 07:29:00+03	2017-07-25 09:47:00+03
14195	PG0689	2017-08-17 07:25:00+03	2017-08-17 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14196	PG0689	2017-07-19 07:25:00+03	2017-07-19 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-19 07:29:00+03	2017-07-19 09:49:00+03
14197	PG0689	2017-08-16 07:25:00+03	2017-08-16 09:45:00+03	KJA	OVS	On Time	SU9	\N	\N
14198	PG0689	2017-09-01 07:25:00+03	2017-09-01 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14199	PG0689	2017-08-14 07:25:00+03	2017-08-14 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-14 07:30:00+03	2017-08-14 09:49:00+03
14200	PG0689	2017-08-30 07:25:00+03	2017-08-30 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14201	PG0689	2017-08-10 07:25:00+03	2017-08-10 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-10 10:25:00+03	2017-08-10 12:44:00+03
14202	PG0689	2017-08-21 07:25:00+03	2017-08-21 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14203	PG0689	2017-08-23 07:25:00+03	2017-08-23 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14204	PG0689	2017-08-06 07:25:00+03	2017-08-06 09:45:00+03	KJA	OVS	Arrived	SU9	2017-08-06 07:27:00+03	2017-08-06 09:49:00+03
14205	PG0689	2017-09-02 07:25:00+03	2017-09-02 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14206	PG0689	2017-08-29 07:25:00+03	2017-08-29 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14207	PG0689	2017-07-30 07:25:00+03	2017-07-30 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-30 07:26:00+03	2017-07-30 09:44:00+03
14208	PG0689	2017-07-23 07:25:00+03	2017-07-23 09:45:00+03	KJA	OVS	Arrived	SU9	2017-07-23 07:28:00+03	2017-07-23 09:50:00+03
14209	PG0689	2017-09-06 07:25:00+03	2017-09-06 09:45:00+03	KJA	OVS	Scheduled	SU9	\N	\N
14210	PG0021	2017-09-06 08:25:00+03	2017-09-06 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14211	PG0021	2017-09-07 08:25:00+03	2017-09-07 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14212	PG0021	2017-08-19 08:25:00+03	2017-08-19 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14213	PG0021	2017-08-13 08:25:00+03	2017-08-13 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-13 08:27:00+03	2017-08-13 11:07:00+03
14214	PG0021	2017-08-04 08:25:00+03	2017-08-04 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-04 08:28:00+03	2017-08-04 11:07:00+03
14215	PG0021	2017-08-06 08:25:00+03	2017-08-06 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-06 08:29:00+03	2017-08-06 11:10:00+03
14216	PG0021	2017-08-27 08:25:00+03	2017-08-27 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14217	PG0021	2017-08-18 08:25:00+03	2017-08-18 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14218	PG0021	2017-09-04 08:25:00+03	2017-09-04 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14219	PG0021	2017-07-30 08:25:00+03	2017-07-30 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-30 08:29:00+03	2017-07-30 11:08:00+03
14220	PG0021	2017-07-23 08:25:00+03	2017-07-23 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-23 08:31:00+03	2017-07-23 11:13:00+03
14221	PG0021	2017-08-05 08:25:00+03	2017-08-05 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-05 08:27:00+03	2017-08-05 11:06:00+03
14222	PG0021	2017-07-26 08:25:00+03	2017-07-26 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-26 08:28:00+03	2017-07-26 11:08:00+03
14223	PG0021	2017-08-17 08:25:00+03	2017-08-17 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14224	PG0021	2017-08-30 08:25:00+03	2017-08-30 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14225	PG0021	2017-07-19 08:25:00+03	2017-07-19 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-19 08:25:00+03	2017-07-19 11:04:00+03
14226	PG0021	2017-09-11 08:25:00+03	2017-09-11 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14227	PG0021	2017-07-21 08:25:00+03	2017-07-21 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-21 11:35:00+03	2017-07-21 14:15:00+03
14228	PG0021	2017-08-25 08:25:00+03	2017-08-25 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14229	PG0021	2017-07-24 08:25:00+03	2017-07-24 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-24 08:30:00+03	2017-07-24 11:12:00+03
14230	PG0021	2017-09-02 08:25:00+03	2017-09-02 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14231	PG0021	2017-08-29 08:25:00+03	2017-08-29 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14232	PG0021	2017-08-12 08:25:00+03	2017-08-12 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-12 08:28:00+03	2017-08-12 11:08:00+03
14233	PG0021	2017-08-09 08:25:00+03	2017-08-09 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-09 08:29:00+03	2017-08-09 11:06:00+03
14234	PG0021	2017-08-21 08:25:00+03	2017-08-21 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14235	PG0021	2017-08-07 08:25:00+03	2017-08-07 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-07 11:13:00+03	2017-08-07 13:54:00+03
14236	PG0021	2017-07-22 08:25:00+03	2017-07-22 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-22 08:29:00+03	2017-07-22 11:09:00+03
14237	PG0021	2017-09-13 08:25:00+03	2017-09-13 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14238	PG0021	2017-07-16 08:25:00+03	2017-07-16 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-16 08:28:00+03	2017-07-16 11:09:00+03
14239	PG0021	2017-09-01 08:25:00+03	2017-09-01 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14240	PG0021	2017-08-20 08:25:00+03	2017-08-20 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14241	PG0021	2017-07-20 08:25:00+03	2017-07-20 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-20 08:28:00+03	2017-07-20 11:09:00+03
14242	PG0021	2017-08-14 08:25:00+03	2017-08-14 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-14 08:29:00+03	2017-08-14 11:11:00+03
14243	PG0021	2017-08-03 08:25:00+03	2017-08-03 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-03 08:28:00+03	2017-08-03 11:08:00+03
14244	PG0021	2017-08-31 08:25:00+03	2017-08-31 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14245	PG0021	2017-09-12 08:25:00+03	2017-09-12 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14246	PG0021	2017-07-27 08:25:00+03	2017-07-27 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-27 08:28:00+03	2017-07-27 11:07:00+03
14247	PG0021	2017-08-02 08:25:00+03	2017-08-02 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-02 08:27:00+03	2017-08-02 11:08:00+03
14248	PG0021	2017-07-28 08:25:00+03	2017-07-28 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-28 08:26:00+03	2017-07-28 11:05:00+03
14249	PG0021	2017-09-09 08:25:00+03	2017-09-09 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14250	PG0021	2017-08-01 08:25:00+03	2017-08-01 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-01 08:26:00+03	2017-08-01 11:07:00+03
14251	PG0021	2017-07-25 08:25:00+03	2017-07-25 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-25 08:27:00+03	2017-07-25 11:07:00+03
14252	PG0021	2017-07-17 08:25:00+03	2017-07-17 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-17 11:12:00+03	2017-07-17 13:53:00+03
14253	PG0021	2017-08-10 08:25:00+03	2017-08-10 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-10 08:29:00+03	2017-08-10 11:10:00+03
14254	PG0021	2017-08-22 08:25:00+03	2017-08-22 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14255	PG0021	2017-07-29 08:25:00+03	2017-07-29 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-29 08:27:00+03	2017-07-29 11:08:00+03
14256	PG0021	2017-08-08 08:25:00+03	2017-08-08 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-08 08:28:00+03	2017-08-08 11:10:00+03
14257	PG0021	2017-08-16 08:25:00+03	2017-08-16 11:05:00+03	KJA	UKX	On Time	CN1	\N	\N
14258	PG0021	2017-09-05 08:25:00+03	2017-09-05 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14259	PG0021	2017-09-14 08:25:00+03	2017-09-14 11:05:00+03	KJA	UKX	Cancelled	CN1	\N	\N
14260	PG0021	2017-08-15 08:25:00+03	2017-08-15 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-15 08:27:00+03	2017-08-15 11:05:00+03
14261	PG0021	2017-07-31 08:25:00+03	2017-07-31 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-31 08:25:00+03	2017-07-31 11:03:00+03
14262	PG0021	2017-07-18 08:25:00+03	2017-07-18 11:05:00+03	KJA	UKX	Arrived	CN1	2017-07-18 08:28:00+03	2017-07-18 11:07:00+03
14263	PG0021	2017-08-23 08:25:00+03	2017-08-23 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14264	PG0021	2017-09-08 08:25:00+03	2017-09-08 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14265	PG0021	2017-08-24 08:25:00+03	2017-08-24 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14266	PG0021	2017-09-10 08:25:00+03	2017-09-10 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14267	PG0021	2017-08-28 08:25:00+03	2017-08-28 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14268	PG0021	2017-08-11 08:25:00+03	2017-08-11 11:05:00+03	KJA	UKX	Arrived	CN1	2017-08-11 08:27:00+03	2017-08-11 11:08:00+03
14269	PG0021	2017-08-26 08:25:00+03	2017-08-26 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14270	PG0021	2017-09-03 08:25:00+03	2017-09-03 11:05:00+03	KJA	UKX	Scheduled	CN1	\N	\N
14271	PG0653	2017-08-08 11:25:00+03	2017-08-08 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-08 11:25:00+03	2017-08-08 13:34:00+03
14272	PG0653	2017-08-04 11:25:00+03	2017-08-04 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-04 11:29:00+03	2017-08-04 13:40:00+03
14273	PG0653	2017-07-25 11:25:00+03	2017-07-25 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-25 11:27:00+03	2017-07-25 13:37:00+03
14274	PG0653	2017-09-06 11:25:00+03	2017-09-06 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14275	PG0653	2017-07-26 11:25:00+03	2017-07-26 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-26 11:27:00+03	2017-07-26 13:35:00+03
14276	PG0653	2017-08-21 11:25:00+03	2017-08-21 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14277	PG0653	2017-08-17 11:25:00+03	2017-08-17 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14278	PG0653	2017-08-18 11:25:00+03	2017-08-18 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14279	PG0653	2017-08-26 11:25:00+03	2017-08-26 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14280	PG0653	2017-08-13 11:25:00+03	2017-08-13 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-13 11:31:00+03	2017-08-13 13:40:00+03
14281	PG0653	2017-07-29 11:25:00+03	2017-07-29 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-29 11:30:00+03	2017-07-29 13:39:00+03
14282	PG0653	2017-08-24 11:25:00+03	2017-08-24 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14283	PG0653	2017-09-01 11:25:00+03	2017-09-01 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14284	PG0653	2017-09-04 11:25:00+03	2017-09-04 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14285	PG0653	2017-07-23 11:25:00+03	2017-07-23 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-23 11:27:00+03	2017-07-23 13:38:00+03
14286	PG0653	2017-07-17 11:25:00+03	2017-07-17 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-17 11:29:00+03	2017-07-17 13:38:00+03
14287	PG0653	2017-08-03 11:25:00+03	2017-08-03 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-03 11:28:00+03	2017-08-03 13:38:00+03
14288	PG0653	2017-08-12 11:25:00+03	2017-08-12 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-12 11:31:00+03	2017-08-12 13:40:00+03
14289	PG0653	2017-09-08 11:25:00+03	2017-09-08 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14290	PG0653	2017-08-15 11:25:00+03	2017-08-15 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-15 11:29:00+03	2017-08-15 13:36:00+03
14291	PG0653	2017-08-07 11:25:00+03	2017-08-07 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-07 11:34:00+03	2017-08-07 13:47:00+03
14292	PG0653	2017-08-11 11:25:00+03	2017-08-11 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-11 11:28:00+03	2017-08-11 13:37:00+03
14293	PG0653	2017-07-18 11:25:00+03	2017-07-18 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-18 11:29:00+03	2017-07-18 13:37:00+03
14294	PG0653	2017-07-31 11:25:00+03	2017-07-31 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-31 11:31:00+03	2017-07-31 13:42:00+03
14295	PG0653	2017-09-07 11:25:00+03	2017-09-07 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14296	PG0653	2017-07-21 11:25:00+03	2017-07-21 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-21 11:29:00+03	2017-07-21 13:39:00+03
14297	PG0653	2017-08-06 11:25:00+03	2017-08-06 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-06 11:30:00+03	2017-08-06 13:40:00+03
14298	PG0653	2017-09-09 11:25:00+03	2017-09-09 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14299	PG0653	2017-07-30 11:25:00+03	2017-07-30 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-30 11:29:00+03	2017-07-30 13:38:00+03
14300	PG0653	2017-08-16 11:25:00+03	2017-08-16 13:35:00+03	KJA	BAX	On Time	CN1	\N	\N
14301	PG0653	2017-08-29 11:25:00+03	2017-08-29 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14302	PG0653	2017-07-22 11:25:00+03	2017-07-22 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-22 11:26:00+03	2017-07-22 13:35:00+03
14303	PG0653	2017-08-28 11:25:00+03	2017-08-28 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14304	PG0653	2017-09-12 11:25:00+03	2017-09-12 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14305	PG0653	2017-07-16 11:25:00+03	2017-07-16 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-16 11:30:00+03	2017-07-16 13:42:00+03
14306	PG0653	2017-09-02 11:25:00+03	2017-09-02 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14307	PG0653	2017-08-02 11:25:00+03	2017-08-02 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-02 11:29:00+03	2017-08-02 13:40:00+03
14308	PG0653	2017-09-14 11:25:00+03	2017-09-14 13:35:00+03	KJA	BAX	Cancelled	CN1	\N	\N
14309	PG0653	2017-08-23 11:25:00+03	2017-08-23 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14310	PG0653	2017-08-27 11:25:00+03	2017-08-27 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14311	PG0653	2017-07-28 11:25:00+03	2017-07-28 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-28 11:29:00+03	2017-07-28 13:39:00+03
14312	PG0653	2017-08-25 11:25:00+03	2017-08-25 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14313	PG0653	2017-07-19 11:25:00+03	2017-07-19 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-19 11:27:00+03	2017-07-19 13:38:00+03
14314	PG0653	2017-08-22 11:25:00+03	2017-08-22 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14315	PG0653	2017-09-03 11:25:00+03	2017-09-03 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14316	PG0653	2017-09-13 11:25:00+03	2017-09-13 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14317	PG0653	2017-08-19 11:25:00+03	2017-08-19 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14318	PG0653	2017-08-14 11:25:00+03	2017-08-14 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-14 11:28:00+03	2017-08-14 13:36:00+03
14319	PG0653	2017-07-24 11:25:00+03	2017-07-24 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-24 11:28:00+03	2017-07-24 13:37:00+03
14320	PG0653	2017-09-05 11:25:00+03	2017-09-05 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14321	PG0653	2017-08-20 11:25:00+03	2017-08-20 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14322	PG0653	2017-08-10 11:25:00+03	2017-08-10 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-10 11:32:00+03	2017-08-10 13:39:00+03
14323	PG0653	2017-08-05 11:25:00+03	2017-08-05 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-05 11:26:00+03	2017-08-05 13:38:00+03
14324	PG0653	2017-09-10 11:25:00+03	2017-09-10 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14325	PG0653	2017-09-11 11:25:00+03	2017-09-11 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14326	PG0653	2017-07-27 11:25:00+03	2017-07-27 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-27 11:25:00+03	2017-07-27 13:35:00+03
14327	PG0653	2017-08-31 11:25:00+03	2017-08-31 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14328	PG0653	2017-08-30 11:25:00+03	2017-08-30 13:35:00+03	KJA	BAX	Scheduled	CN1	\N	\N
14329	PG0653	2017-08-01 11:25:00+03	2017-08-01 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-01 11:28:00+03	2017-08-01 13:35:00+03
14330	PG0653	2017-07-20 11:25:00+03	2017-07-20 13:35:00+03	KJA	BAX	Arrived	CN1	2017-07-20 11:29:00+03	2017-07-20 13:39:00+03
14331	PG0653	2017-08-09 11:25:00+03	2017-08-09 13:35:00+03	KJA	BAX	Arrived	CN1	2017-08-09 11:29:00+03	2017-08-09 13:39:00+03
14332	PG0351	2017-08-12 09:15:00+03	2017-08-12 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-12 09:17:00+03	2017-08-12 10:44:00+03
14333	PG0351	2017-07-29 09:15:00+03	2017-07-29 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-29 09:18:00+03	2017-07-29 10:44:00+03
14334	PG0352	2017-07-29 07:50:00+03	2017-07-29 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-29 07:54:00+03	2017-07-29 09:19:00+03
14335	PG0352	2017-08-16 07:50:00+03	2017-08-16 09:15:00+03	KJA	NOZ	On Time	CN1	\N	\N
14336	PG0351	2017-08-16 09:15:00+03	2017-08-16 10:40:00+03	KJA	NOZ	On Time	CN1	\N	\N
14337	PG0351	2017-08-23 09:15:00+03	2017-08-23 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14338	PG0352	2017-08-23 07:50:00+03	2017-08-23 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14339	PG0351	2017-08-06 09:15:00+03	2017-08-06 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-06 09:19:00+03	2017-08-06 10:44:00+03
14340	PG0352	2017-08-06 07:50:00+03	2017-08-06 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-06 07:51:00+03	2017-08-06 09:16:00+03
14341	PG0351	2017-07-20 09:15:00+03	2017-07-20 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-20 09:19:00+03	2017-07-20 10:45:00+03
14342	PG0352	2017-07-20 07:50:00+03	2017-07-20 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-20 07:53:00+03	2017-07-20 09:20:00+03
14343	PG0351	2017-09-04 09:15:00+03	2017-09-04 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14344	PG0352	2017-09-04 07:50:00+03	2017-09-04 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14345	PG0352	2017-08-05 07:50:00+03	2017-08-05 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-05 07:52:00+03	2017-08-05 09:16:00+03
14346	PG0351	2017-08-05 09:15:00+03	2017-08-05 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-05 09:17:00+03	2017-08-05 10:43:00+03
14347	PG0352	2017-09-10 07:50:00+03	2017-09-10 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14348	PG0351	2017-09-10 09:15:00+03	2017-09-10 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14349	PG0352	2017-08-21 07:50:00+03	2017-08-21 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14350	PG0351	2017-08-21 09:15:00+03	2017-08-21 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14351	PG0351	2017-08-31 09:15:00+03	2017-08-31 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14352	PG0352	2017-07-19 07:50:00+03	2017-07-19 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-19 07:53:00+03	2017-07-19 09:19:00+03
14353	PG0351	2017-07-19 09:15:00+03	2017-07-19 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-19 09:18:00+03	2017-07-19 10:44:00+03
14354	PG0351	2017-09-08 09:15:00+03	2017-09-08 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14355	PG0352	2017-09-08 07:50:00+03	2017-09-08 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14356	PG0352	2017-07-24 07:50:00+03	2017-07-24 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-24 07:55:00+03	2017-07-24 09:19:00+03
14357	PG0351	2017-08-07 09:15:00+03	2017-08-07 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-07 09:17:00+03	2017-08-07 10:42:00+03
14358	PG0352	2017-08-07 07:50:00+03	2017-08-07 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-07 11:22:00+03	2017-08-07 12:47:00+03
14359	PG0351	2017-07-24 09:15:00+03	2017-07-24 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-24 09:18:00+03	2017-07-24 10:41:00+03
14360	PG0352	2017-09-03 07:50:00+03	2017-09-03 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14361	PG0351	2017-09-03 09:15:00+03	2017-09-03 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14362	PG0351	2017-09-13 09:15:00+03	2017-09-13 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14363	PG0352	2017-09-13 07:50:00+03	2017-09-13 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14364	PG0352	2017-09-12 07:50:00+03	2017-09-12 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14365	PG0351	2017-09-12 09:15:00+03	2017-09-12 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14366	PG0351	2017-08-26 09:15:00+03	2017-08-26 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14367	PG0352	2017-08-26 07:50:00+03	2017-08-26 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14368	PG0352	2017-08-29 07:50:00+03	2017-08-29 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14369	PG0351	2017-08-29 09:15:00+03	2017-08-29 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14370	PG0352	2017-08-04 07:50:00+03	2017-08-04 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-04 07:54:00+03	2017-08-04 09:19:00+03
14371	PG0351	2017-08-04 09:15:00+03	2017-08-04 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-04 09:18:00+03	2017-08-04 10:43:00+03
14372	PG0352	2017-08-19 07:50:00+03	2017-08-19 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14373	PG0351	2017-08-19 09:15:00+03	2017-08-19 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14374	PG0352	2017-07-28 07:50:00+03	2017-07-28 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-28 07:56:00+03	2017-07-28 09:20:00+03
14375	PG0351	2017-07-28 09:15:00+03	2017-07-28 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-28 09:16:00+03	2017-07-28 10:41:00+03
14376	PG0351	2017-08-08 09:15:00+03	2017-08-08 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-08 09:18:00+03	2017-08-08 10:43:00+03
14377	PG0352	2017-08-08 07:50:00+03	2017-08-08 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-08 07:52:00+03	2017-08-08 09:16:00+03
14378	PG0352	2017-08-15 07:50:00+03	2017-08-15 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-15 07:55:00+03	2017-08-15 09:21:00+03
14379	PG0351	2017-08-15 09:15:00+03	2017-08-15 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-15 09:19:00+03	2017-08-15 10:43:00+03
14380	PG0351	2017-07-21 09:15:00+03	2017-07-21 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-21 09:18:00+03	2017-07-21 10:42:00+03
14381	PG0352	2017-07-21 07:50:00+03	2017-07-21 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-21 07:51:00+03	2017-07-21 09:16:00+03
14382	PG0351	2017-08-30 09:15:00+03	2017-08-30 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14383	PG0352	2017-07-18 07:50:00+03	2017-07-18 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-18 07:53:00+03	2017-07-18 09:18:00+03
14384	PG0352	2017-08-30 07:50:00+03	2017-08-30 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14385	PG0351	2017-07-18 09:15:00+03	2017-07-18 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-18 12:54:00+03	2017-07-18 14:19:00+03
14386	PG0351	2017-08-17 09:15:00+03	2017-08-17 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14387	PG0352	2017-08-17 07:50:00+03	2017-08-17 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14388	PG0351	2017-07-25 09:15:00+03	2017-07-25 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-25 09:17:00+03	2017-07-25 10:41:00+03
14389	PG0352	2017-07-25 07:50:00+03	2017-07-25 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-25 07:52:00+03	2017-07-25 09:19:00+03
14390	PG0351	2017-09-05 09:15:00+03	2017-09-05 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14391	PG0352	2017-09-05 07:50:00+03	2017-09-05 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14392	PG0352	2017-08-03 07:50:00+03	2017-08-03 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-03 07:52:00+03	2017-08-03 09:17:00+03
14393	PG0351	2017-08-03 09:15:00+03	2017-08-03 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-03 09:17:00+03	2017-08-03 10:42:00+03
14394	PG0351	2017-08-09 09:15:00+03	2017-08-09 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-09 09:18:00+03	2017-08-09 10:42:00+03
14395	PG0352	2017-08-09 07:50:00+03	2017-08-09 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-09 07:50:00+03	2017-08-09 09:14:00+03
14396	PG0352	2017-09-02 07:50:00+03	2017-09-02 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14397	PG0351	2017-09-02 09:15:00+03	2017-09-02 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14398	PG0351	2017-07-30 09:15:00+03	2017-07-30 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-30 09:18:00+03	2017-07-30 10:44:00+03
14399	PG0352	2017-07-30 07:50:00+03	2017-07-30 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-30 07:53:00+03	2017-07-30 09:19:00+03
14400	PG0352	2017-08-31 07:50:00+03	2017-08-31 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14401	PG0351	2017-09-14 09:15:00+03	2017-09-14 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14402	PG0351	2017-08-24 09:15:00+03	2017-08-24 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14403	PG0352	2017-08-24 07:50:00+03	2017-08-24 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14404	PG0351	2017-08-13 09:15:00+03	2017-08-13 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-13 09:19:00+03	2017-08-13 10:43:00+03
14405	PG0351	2017-08-10 09:15:00+03	2017-08-10 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-10 09:18:00+03	2017-08-10 10:43:00+03
14406	PG0352	2017-08-10 07:50:00+03	2017-08-10 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-10 07:53:00+03	2017-08-10 09:19:00+03
14407	PG0352	2017-08-13 07:50:00+03	2017-08-13 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-13 07:51:00+03	2017-08-13 09:16:00+03
14408	PG0351	2017-08-20 09:15:00+03	2017-08-20 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14409	PG0352	2017-08-20 07:50:00+03	2017-08-20 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14410	PG0352	2017-07-17 07:50:00+03	2017-07-17 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-17 07:54:00+03	2017-07-17 09:18:00+03
14411	PG0351	2017-07-17 09:15:00+03	2017-07-17 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-17 09:16:00+03	2017-07-17 10:42:00+03
14412	PG0352	2017-09-07 07:50:00+03	2017-09-07 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14413	PG0351	2017-09-07 09:15:00+03	2017-09-07 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14414	PG0351	2017-08-27 09:15:00+03	2017-08-27 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14415	PG0352	2017-08-14 07:50:00+03	2017-08-14 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-14 08:00:00+03	2017-08-14 09:26:00+03
14416	PG0351	2017-08-14 09:15:00+03	2017-08-14 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-14 09:17:00+03	2017-08-14 10:43:00+03
14417	PG0352	2017-07-27 07:50:00+03	2017-07-27 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-27 07:53:00+03	2017-07-27 09:18:00+03
14418	PG0351	2017-07-27 09:15:00+03	2017-07-27 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-27 09:16:00+03	2017-07-27 10:42:00+03
14419	PG0351	2017-08-28 09:15:00+03	2017-08-28 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14420	PG0352	2017-08-27 07:50:00+03	2017-08-27 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14421	PG0352	2017-08-28 07:50:00+03	2017-08-28 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14422	PG0352	2017-08-02 07:50:00+03	2017-08-02 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-02 07:53:00+03	2017-08-02 09:17:00+03
14423	PG0351	2017-08-02 09:15:00+03	2017-08-02 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-02 09:19:00+03	2017-08-02 10:44:00+03
14424	PG0351	2017-07-22 09:15:00+03	2017-07-22 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-22 09:21:00+03	2017-07-22 10:45:00+03
14425	PG0352	2017-07-22 07:50:00+03	2017-07-22 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-22 07:53:00+03	2017-07-22 09:17:00+03
14426	PG0351	2017-07-26 09:15:00+03	2017-07-26 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-26 09:18:00+03	2017-07-26 10:44:00+03
14427	PG0352	2017-07-26 07:50:00+03	2017-07-26 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-26 07:57:00+03	2017-07-26 09:24:00+03
14428	PG0351	2017-08-11 09:15:00+03	2017-08-11 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-11 09:18:00+03	2017-08-11 10:43:00+03
14429	PG0352	2017-08-11 07:50:00+03	2017-08-11 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-11 07:54:00+03	2017-08-11 09:18:00+03
14430	PG0352	2017-09-01 07:50:00+03	2017-09-01 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14431	PG0351	2017-09-01 09:15:00+03	2017-09-01 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14432	PG0352	2017-08-22 07:50:00+03	2017-08-22 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14433	PG0351	2017-08-22 09:15:00+03	2017-08-22 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14434	PG0351	2017-09-06 09:15:00+03	2017-09-06 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14435	PG0352	2017-09-06 07:50:00+03	2017-09-06 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14436	PG0352	2017-08-25 07:50:00+03	2017-08-25 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14437	PG0351	2017-08-25 09:15:00+03	2017-08-25 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14438	PG0351	2017-09-09 09:15:00+03	2017-09-09 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14439	PG0352	2017-08-01 07:50:00+03	2017-08-01 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-01 07:54:00+03	2017-08-01 09:18:00+03
14440	PG0351	2017-08-01 09:15:00+03	2017-08-01 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-08-01 09:21:00+03	2017-08-01 10:46:00+03
14441	PG0352	2017-09-09 07:50:00+03	2017-09-09 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14442	PG0352	2017-08-12 07:50:00+03	2017-08-12 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-08-12 07:53:00+03	2017-08-12 09:16:00+03
14443	PG0352	2017-09-14 07:50:00+03	2017-09-14 09:15:00+03	KJA	NOZ	Cancelled	CN1	\N	\N
14444	PG0352	2017-07-16 07:50:00+03	2017-07-16 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-16 07:58:00+03	2017-07-16 09:21:00+03
14445	PG0351	2017-07-16 09:15:00+03	2017-07-16 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-16 09:19:00+03	2017-07-16 10:44:00+03
14446	PG0352	2017-09-11 07:50:00+03	2017-09-11 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14447	PG0351	2017-08-18 09:15:00+03	2017-08-18 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14448	PG0352	2017-08-18 07:50:00+03	2017-08-18 09:15:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14449	PG0351	2017-09-11 09:15:00+03	2017-09-11 10:40:00+03	KJA	NOZ	Scheduled	CN1	\N	\N
14450	PG0352	2017-07-23 07:50:00+03	2017-07-23 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-23 07:55:00+03	2017-07-23 09:21:00+03
14451	PG0351	2017-07-23 09:15:00+03	2017-07-23 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-23 09:17:00+03	2017-07-23 10:42:00+03
14452	PG0352	2017-07-31 07:50:00+03	2017-07-31 09:15:00+03	KJA	NOZ	Arrived	CN1	2017-07-31 07:55:00+03	2017-07-31 09:19:00+03
14453	PG0351	2017-07-31 09:15:00+03	2017-07-31 10:40:00+03	KJA	NOZ	Arrived	CN1	2017-07-31 09:18:00+03	2017-07-31 10:45:00+03
14454	PG0501	2017-09-03 12:25:00+03	2017-09-03 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14455	PG0501	2017-07-27 12:25:00+03	2017-07-27 17:35:00+03	KJA	AER	Arrived	319	2017-07-27 12:25:00+03	2017-07-27 17:36:00+03
14456	PG0501	2017-08-27 12:25:00+03	2017-08-27 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14457	PG0501	2017-08-03 12:25:00+03	2017-08-03 17:35:00+03	KJA	AER	Arrived	319	2017-08-03 12:29:00+03	2017-08-03 17:36:00+03
14458	PG0501	2017-09-14 12:25:00+03	2017-09-14 17:35:00+03	KJA	AER	Cancelled	319	\N	\N
14459	PG0501	2017-07-20 12:25:00+03	2017-07-20 17:35:00+03	KJA	AER	Arrived	319	2017-07-20 12:29:00+03	2017-07-20 17:41:00+03
14460	PG0501	2017-07-30 12:25:00+03	2017-07-30 17:35:00+03	KJA	AER	Arrived	319	2017-07-30 12:27:00+03	2017-07-30 17:39:00+03
14461	PG0501	2017-08-31 12:25:00+03	2017-08-31 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14462	PG0501	2017-08-17 12:25:00+03	2017-08-17 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14463	PG0501	2017-08-06 12:25:00+03	2017-08-06 17:35:00+03	KJA	AER	Arrived	319	2017-08-06 12:27:00+03	2017-08-06 17:43:00+03
14464	PG0501	2017-08-13 12:25:00+03	2017-08-13 17:35:00+03	KJA	AER	Arrived	319	2017-08-13 12:27:00+03	2017-08-13 17:35:00+03
14465	PG0501	2017-08-10 12:25:00+03	2017-08-10 17:35:00+03	KJA	AER	Arrived	319	2017-08-10 12:28:00+03	2017-08-10 17:37:00+03
14466	PG0501	2017-07-23 12:25:00+03	2017-07-23 17:35:00+03	KJA	AER	Arrived	319	2017-07-23 12:29:00+03	2017-07-23 17:32:00+03
14467	PG0501	2017-07-16 12:25:00+03	2017-07-16 17:35:00+03	KJA	AER	Arrived	319	2017-07-16 12:32:00+03	2017-07-16 17:47:00+03
14468	PG0501	2017-08-20 12:25:00+03	2017-08-20 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14469	PG0501	2017-08-24 12:25:00+03	2017-08-24 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14470	PG0501	2017-09-07 12:25:00+03	2017-09-07 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14471	PG0501	2017-09-10 12:25:00+03	2017-09-10 17:35:00+03	KJA	AER	Scheduled	319	\N	\N
14472	PG0673	2017-09-04 09:10:00+03	2017-09-04 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14473	PG0673	2017-08-13 09:10:00+03	2017-08-13 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-13 09:13:00+03	2017-08-13 11:38:00+03
14474	PG0673	2017-08-25 09:10:00+03	2017-08-25 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14475	PG0673	2017-08-07 09:10:00+03	2017-08-07 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-07 09:14:00+03	2017-08-07 11:38:00+03
14476	PG0673	2017-08-24 09:10:00+03	2017-08-24 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14477	PG0673	2017-09-14 09:10:00+03	2017-09-14 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14478	PG0673	2017-07-29 09:10:00+03	2017-07-29 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-29 09:13:00+03	2017-07-29 11:37:00+03
14479	PG0673	2017-09-13 09:10:00+03	2017-09-13 11:35:00+03	KJA	KRO	Cancelled	CR2	\N	\N
14480	PG0673	2017-08-28 09:10:00+03	2017-08-28 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14481	PG0673	2017-08-05 09:10:00+03	2017-08-05 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-05 09:12:00+03	2017-08-05 11:36:00+03
14482	PG0673	2017-08-03 09:10:00+03	2017-08-03 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-03 09:14:00+03	2017-08-03 11:42:00+03
14483	PG0673	2017-08-09 09:10:00+03	2017-08-09 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-09 09:11:00+03	2017-08-09 11:35:00+03
14484	PG0673	2017-08-23 09:10:00+03	2017-08-23 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14485	PG0673	2017-08-29 09:10:00+03	2017-08-29 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14486	PG0673	2017-07-22 09:10:00+03	2017-07-22 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-22 09:13:00+03	2017-07-22 11:39:00+03
14487	PG0673	2017-08-08 09:10:00+03	2017-08-08 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-08 09:14:00+03	2017-08-08 11:39:00+03
14488	PG0673	2017-07-18 09:10:00+03	2017-07-18 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-18 09:10:00+03	2017-07-18 11:36:00+03
14489	PG0673	2017-07-27 09:10:00+03	2017-07-27 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-27 09:13:00+03	2017-07-27 11:38:00+03
14490	PG0673	2017-08-14 09:10:00+03	2017-08-14 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-14 09:10:00+03	2017-08-14 11:33:00+03
14491	PG0673	2017-07-31 09:10:00+03	2017-07-31 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-31 09:14:00+03	2017-07-31 11:41:00+03
14492	PG0673	2017-08-20 09:10:00+03	2017-08-20 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14493	PG0673	2017-08-06 09:10:00+03	2017-08-06 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-06 12:38:00+03	2017-08-06 15:01:00+03
14494	PG0673	2017-09-02 09:10:00+03	2017-09-02 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14495	PG0673	2017-08-27 09:10:00+03	2017-08-27 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14496	PG0673	2017-07-24 09:10:00+03	2017-07-24 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-24 09:16:00+03	2017-07-24 11:42:00+03
14497	PG0673	2017-08-31 09:10:00+03	2017-08-31 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14498	PG0673	2017-09-01 09:10:00+03	2017-09-01 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14499	PG0673	2017-07-16 09:10:00+03	2017-07-16 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-16 09:12:00+03	2017-07-16 11:37:00+03
14500	PG0673	2017-09-10 09:10:00+03	2017-09-10 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14501	PG0673	2017-08-17 09:10:00+03	2017-08-17 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14502	PG0673	2017-09-05 09:10:00+03	2017-09-05 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14503	PG0673	2017-09-12 09:10:00+03	2017-09-12 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14504	PG0673	2017-07-28 09:10:00+03	2017-07-28 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-28 09:12:00+03	2017-07-28 11:38:00+03
14505	PG0673	2017-09-09 09:10:00+03	2017-09-09 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14506	PG0673	2017-09-08 09:10:00+03	2017-09-08 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14507	PG0673	2017-08-15 09:10:00+03	2017-08-15 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-15 09:12:00+03	2017-08-15 11:38:00+03
14508	PG0673	2017-07-19 09:10:00+03	2017-07-19 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-19 09:13:00+03	2017-07-19 11:36:00+03
14509	PG0673	2017-08-01 09:10:00+03	2017-08-01 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-01 09:12:00+03	2017-08-01 11:38:00+03
14510	PG0673	2017-08-30 09:10:00+03	2017-08-30 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14511	PG0673	2017-07-26 09:10:00+03	2017-07-26 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-26 09:13:00+03	2017-07-26 11:37:00+03
14512	PG0673	2017-08-21 09:10:00+03	2017-08-21 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14513	PG0673	2017-08-12 09:10:00+03	2017-08-12 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-12 09:12:00+03	2017-08-12 11:35:00+03
14514	PG0673	2017-09-06 09:10:00+03	2017-09-06 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14515	PG0673	2017-08-16 09:10:00+03	2017-08-16 11:35:00+03	KJA	KRO	On Time	CR2	\N	\N
14516	PG0673	2017-09-11 09:10:00+03	2017-09-11 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14517	PG0673	2017-08-10 09:10:00+03	2017-08-10 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-10 09:14:00+03	2017-08-10 11:38:00+03
14518	PG0673	2017-08-02 09:10:00+03	2017-08-02 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-02 09:11:00+03	2017-08-02 11:36:00+03
14519	PG0673	2017-09-07 09:10:00+03	2017-09-07 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14520	PG0673	2017-08-18 09:10:00+03	2017-08-18 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14521	PG0673	2017-07-30 09:10:00+03	2017-07-30 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-30 09:14:00+03	2017-07-30 11:38:00+03
14522	PG0673	2017-08-11 09:10:00+03	2017-08-11 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-11 09:10:00+03	2017-08-11 11:36:00+03
14523	PG0673	2017-07-25 09:10:00+03	2017-07-25 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-25 09:11:00+03	2017-07-25 11:35:00+03
14524	PG0673	2017-08-04 09:10:00+03	2017-08-04 11:35:00+03	KJA	KRO	Arrived	CR2	2017-08-04 09:13:00+03	2017-08-04 11:37:00+03
14525	PG0673	2017-07-17 09:10:00+03	2017-07-17 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-17 09:14:00+03	2017-07-17 11:38:00+03
14526	PG0673	2017-08-19 09:10:00+03	2017-08-19 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14527	PG0673	2017-07-21 09:10:00+03	2017-07-21 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-21 09:12:00+03	2017-07-21 11:38:00+03
14528	PG0673	2017-08-22 09:10:00+03	2017-08-22 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14529	PG0673	2017-09-03 09:10:00+03	2017-09-03 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14530	PG0673	2017-07-23 09:10:00+03	2017-07-23 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-23 09:11:00+03	2017-07-23 11:39:00+03
14531	PG0673	2017-08-26 09:10:00+03	2017-08-26 11:35:00+03	KJA	KRO	Scheduled	CR2	\N	\N
14532	PG0673	2017-07-20 09:10:00+03	2017-07-20 11:35:00+03	KJA	KRO	Arrived	CR2	2017-07-20 09:12:00+03	2017-07-20 11:38:00+03
14533	PG0413	2017-08-29 18:55:00+03	2017-08-29 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14534	PG0413	2017-07-17 18:55:00+03	2017-07-17 20:20:00+03	PEE	VKO	Arrived	773	2017-07-17 18:55:00+03	2017-07-17 20:20:00+03
14535	PG0413	2017-08-12 18:55:00+03	2017-08-12 20:20:00+03	PEE	VKO	Arrived	773	2017-08-12 18:57:00+03	2017-08-12 20:21:00+03
14536	PG0413	2017-08-30 18:55:00+03	2017-08-30 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14537	PG0413	2017-08-10 18:55:00+03	2017-08-10 20:20:00+03	PEE	VKO	Arrived	773	2017-08-10 18:58:00+03	2017-08-10 20:25:00+03
14538	PG0413	2017-08-26 18:55:00+03	2017-08-26 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14539	PG0413	2017-09-05 18:55:00+03	2017-09-05 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14540	PG0413	2017-07-21 18:55:00+03	2017-07-21 20:20:00+03	PEE	VKO	Arrived	773	2017-07-21 18:58:00+03	2017-07-21 20:23:00+03
14541	PG0413	2017-08-13 18:55:00+03	2017-08-13 20:20:00+03	PEE	VKO	Arrived	773	2017-08-13 18:57:00+03	2017-08-13 20:24:00+03
14542	PG0413	2017-09-01 18:55:00+03	2017-09-01 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14543	PG0413	2017-07-18 18:55:00+03	2017-07-18 20:20:00+03	PEE	VKO	Arrived	773	2017-07-18 19:01:00+03	2017-07-18 20:26:00+03
14544	PG0413	2017-09-06 18:55:00+03	2017-09-06 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14545	PG0413	2017-08-28 18:55:00+03	2017-08-28 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14546	PG0413	2017-07-27 18:55:00+03	2017-07-27 20:20:00+03	PEE	VKO	Arrived	773	2017-07-27 19:00:00+03	2017-07-27 20:25:00+03
14547	PG0413	2017-08-06 18:55:00+03	2017-08-06 20:20:00+03	PEE	VKO	Arrived	773	2017-08-06 18:58:00+03	2017-08-06 20:22:00+03
14548	PG0413	2017-07-26 18:55:00+03	2017-07-26 20:20:00+03	PEE	VKO	Arrived	773	2017-07-26 19:00:00+03	2017-07-26 20:24:00+03
14549	PG0413	2017-08-21 18:55:00+03	2017-08-21 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14550	PG0413	2017-08-05 18:55:00+03	2017-08-05 20:20:00+03	PEE	VKO	Arrived	773	2017-08-05 18:58:00+03	2017-08-05 20:24:00+03
14551	PG0413	2017-07-16 18:55:00+03	2017-07-16 20:20:00+03	PEE	VKO	Arrived	773	2017-07-16 18:58:00+03	2017-07-16 20:24:00+03
14552	PG0413	2017-08-09 18:55:00+03	2017-08-09 20:20:00+03	PEE	VKO	Arrived	773	2017-08-09 18:58:00+03	2017-08-09 20:23:00+03
14553	PG0413	2017-07-23 18:55:00+03	2017-07-23 20:20:00+03	PEE	VKO	Arrived	773	2017-07-23 18:58:00+03	2017-07-23 20:23:00+03
14554	PG0413	2017-08-18 18:55:00+03	2017-08-18 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14555	PG0413	2017-08-31 18:55:00+03	2017-08-31 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14556	PG0413	2017-08-03 18:55:00+03	2017-08-03 20:20:00+03	PEE	VKO	Arrived	773	2017-08-03 18:56:00+03	2017-08-03 20:19:00+03
14557	PG0413	2017-07-20 18:55:00+03	2017-07-20 20:20:00+03	PEE	VKO	Arrived	773	2017-07-20 18:57:00+03	2017-07-20 20:23:00+03
14558	PG0413	2017-08-27 18:55:00+03	2017-08-27 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14559	PG0413	2017-08-01 18:55:00+03	2017-08-01 20:20:00+03	PEE	VKO	Arrived	773	2017-08-01 18:59:00+03	2017-08-01 20:23:00+03
14560	PG0413	2017-09-02 18:55:00+03	2017-09-02 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14561	PG0413	2017-07-31 18:55:00+03	2017-07-31 20:20:00+03	PEE	VKO	Arrived	773	2017-07-31 19:02:00+03	2017-07-31 20:26:00+03
14562	PG0413	2017-08-19 18:55:00+03	2017-08-19 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14563	PG0413	2017-07-19 18:55:00+03	2017-07-19 20:20:00+03	PEE	VKO	Arrived	773	2017-07-19 19:00:00+03	2017-07-19 20:25:00+03
14564	PG0413	2017-09-09 18:55:00+03	2017-09-09 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14565	PG0413	2017-09-14 18:55:00+03	2017-09-14 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14566	PG0413	2017-08-11 18:55:00+03	2017-08-11 20:20:00+03	PEE	VKO	Arrived	773	2017-08-11 18:55:00+03	2017-08-11 20:20:00+03
14567	PG0413	2017-08-20 18:55:00+03	2017-08-20 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14568	PG0413	2017-09-03 18:55:00+03	2017-09-03 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14569	PG0413	2017-08-16 18:55:00+03	2017-08-16 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14570	PG0413	2017-08-02 18:55:00+03	2017-08-02 20:20:00+03	PEE	VKO	Arrived	773	2017-08-02 18:59:00+03	2017-08-02 20:25:00+03
14571	PG0413	2017-08-07 18:55:00+03	2017-08-07 20:20:00+03	PEE	VKO	Arrived	773	2017-08-07 18:58:00+03	2017-08-07 20:23:00+03
14572	PG0413	2017-09-12 18:55:00+03	2017-09-12 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14573	PG0413	2017-08-24 18:55:00+03	2017-08-24 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14574	PG0413	2017-08-22 18:55:00+03	2017-08-22 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14575	PG0413	2017-09-04 18:55:00+03	2017-09-04 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14576	PG0413	2017-07-22 18:55:00+03	2017-07-22 20:20:00+03	PEE	VKO	Arrived	773	2017-07-22 18:58:00+03	2017-07-22 20:22:00+03
14577	PG0413	2017-08-17 18:55:00+03	2017-08-17 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14578	PG0413	2017-08-25 18:55:00+03	2017-08-25 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14579	PG0413	2017-09-10 18:55:00+03	2017-09-10 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14580	PG0413	2017-09-08 18:55:00+03	2017-09-08 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14581	PG0413	2017-07-30 18:55:00+03	2017-07-30 20:20:00+03	PEE	VKO	Arrived	773	2017-07-30 18:59:00+03	2017-07-30 20:25:00+03
14582	PG0413	2017-09-13 18:55:00+03	2017-09-13 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14583	PG0413	2017-08-04 18:55:00+03	2017-08-04 20:20:00+03	PEE	VKO	Arrived	773	2017-08-04 18:59:00+03	2017-08-04 20:24:00+03
14584	PG0413	2017-07-28 18:55:00+03	2017-07-28 20:20:00+03	PEE	VKO	Arrived	773	2017-07-28 18:58:00+03	2017-07-28 20:25:00+03
14585	PG0413	2017-07-25 18:55:00+03	2017-07-25 20:20:00+03	PEE	VKO	Arrived	773	2017-07-25 18:58:00+03	2017-07-25 20:24:00+03
14586	PG0413	2017-07-24 18:55:00+03	2017-07-24 20:20:00+03	PEE	VKO	Arrived	773	2017-07-24 21:58:00+03	2017-07-24 23:22:00+03
14587	PG0413	2017-08-14 18:55:00+03	2017-08-14 20:20:00+03	PEE	VKO	Arrived	773	2017-08-14 19:00:00+03	2017-08-14 20:25:00+03
14588	PG0413	2017-09-11 18:55:00+03	2017-09-11 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14589	PG0413	2017-08-15 18:55:00+03	2017-08-15 20:20:00+03	PEE	VKO	On Time	773	\N	\N
14590	PG0413	2017-08-08 18:55:00+03	2017-08-08 20:20:00+03	PEE	VKO	Arrived	773	2017-08-08 18:57:00+03	2017-08-08 20:22:00+03
14591	PG0413	2017-07-29 18:55:00+03	2017-07-29 20:20:00+03	PEE	VKO	Arrived	773	2017-07-29 19:01:00+03	2017-07-29 20:27:00+03
14592	PG0413	2017-09-07 18:55:00+03	2017-09-07 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14593	PG0413	2017-08-23 18:55:00+03	2017-08-23 20:20:00+03	PEE	VKO	Scheduled	773	\N	\N
14594	PG0187	2017-08-31 15:05:00+03	2017-08-31 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14595	PG0187	2017-08-10 15:05:00+03	2017-08-10 17:15:00+03	PEE	OVB	Arrived	319	2017-08-10 15:11:00+03	2017-08-10 17:19:00+03
14596	PG0187	2017-07-18 15:05:00+03	2017-07-18 17:15:00+03	PEE	OVB	Arrived	319	2017-07-18 15:06:00+03	2017-07-18 17:18:00+03
14597	PG0187	2017-07-26 15:05:00+03	2017-07-26 17:15:00+03	PEE	OVB	Arrived	319	2017-07-26 15:07:00+03	2017-07-26 17:19:00+03
14598	PG0187	2017-09-09 15:05:00+03	2017-09-09 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14599	PG0187	2017-09-14 15:05:00+03	2017-09-14 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14600	PG0187	2017-08-16 15:05:00+03	2017-08-16 17:15:00+03	PEE	OVB	On Time	319	\N	\N
14601	PG0187	2017-08-14 15:05:00+03	2017-08-14 17:15:00+03	PEE	OVB	Arrived	319	2017-08-14 15:08:00+03	2017-08-14 17:18:00+03
14602	PG0187	2017-07-16 15:05:00+03	2017-07-16 17:15:00+03	PEE	OVB	Arrived	319	2017-07-16 15:07:00+03	2017-07-16 17:18:00+03
14603	PG0187	2017-08-12 15:05:00+03	2017-08-12 17:15:00+03	PEE	OVB	Arrived	319	2017-08-12 15:07:00+03	2017-08-12 17:18:00+03
14604	PG0187	2017-08-21 15:05:00+03	2017-08-21 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14605	PG0187	2017-08-29 15:05:00+03	2017-08-29 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14606	PG0187	2017-08-18 15:05:00+03	2017-08-18 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14607	PG0187	2017-08-03 15:05:00+03	2017-08-03 17:15:00+03	PEE	OVB	Arrived	319	2017-08-03 15:09:00+03	2017-08-03 17:19:00+03
14608	PG0187	2017-09-02 15:05:00+03	2017-09-02 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14609	PG0187	2017-09-06 15:05:00+03	2017-09-06 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14610	PG0187	2017-09-13 15:05:00+03	2017-09-13 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14611	PG0187	2017-09-11 15:05:00+03	2017-09-11 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14612	PG0187	2017-07-20 15:05:00+03	2017-07-20 17:15:00+03	PEE	OVB	Arrived	319	2017-07-20 15:06:00+03	2017-07-20 17:15:00+03
14613	PG0187	2017-08-05 15:05:00+03	2017-08-05 17:15:00+03	PEE	OVB	Arrived	319	2017-08-05 15:08:00+03	2017-08-05 17:18:00+03
14614	PG0187	2017-08-07 15:05:00+03	2017-08-07 17:15:00+03	PEE	OVB	Arrived	319	2017-08-07 15:08:00+03	2017-08-07 17:18:00+03
14615	PG0187	2017-08-23 15:05:00+03	2017-08-23 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14616	PG0187	2017-07-27 15:05:00+03	2017-07-27 17:15:00+03	PEE	OVB	Arrived	319	2017-07-27 15:11:00+03	2017-07-27 17:23:00+03
14617	PG0187	2017-08-02 15:05:00+03	2017-08-02 17:15:00+03	PEE	OVB	Arrived	319	2017-08-02 18:57:00+03	2017-08-02 21:08:00+03
14618	PG0187	2017-07-31 15:05:00+03	2017-07-31 17:15:00+03	PEE	OVB	Arrived	319	2017-07-31 15:05:00+03	2017-07-31 17:14:00+03
14619	PG0187	2017-08-28 15:05:00+03	2017-08-28 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14620	PG0187	2017-08-27 15:05:00+03	2017-08-27 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14621	PG0187	2017-08-06 15:05:00+03	2017-08-06 17:15:00+03	PEE	OVB	Arrived	319	2017-08-06 15:09:00+03	2017-08-06 17:21:00+03
14622	PG0187	2017-09-04 15:05:00+03	2017-09-04 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14623	PG0187	2017-08-30 15:05:00+03	2017-08-30 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14624	PG0187	2017-07-19 15:05:00+03	2017-07-19 17:15:00+03	PEE	OVB	Arrived	319	2017-07-19 15:08:00+03	2017-07-19 17:17:00+03
14625	PG0187	2017-08-01 15:05:00+03	2017-08-01 17:15:00+03	PEE	OVB	Arrived	319	2017-08-01 15:09:00+03	2017-08-01 17:18:00+03
14626	PG0187	2017-09-08 15:05:00+03	2017-09-08 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14627	PG0187	2017-09-03 15:05:00+03	2017-09-03 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14628	PG0187	2017-07-25 15:05:00+03	2017-07-25 17:15:00+03	PEE	OVB	Arrived	319	2017-07-25 15:07:00+03	2017-07-25 17:18:00+03
14629	PG0187	2017-08-08 15:05:00+03	2017-08-08 17:15:00+03	PEE	OVB	Arrived	319	2017-08-08 15:07:00+03	2017-08-08 17:17:00+03
14630	PG0187	2017-08-17 15:05:00+03	2017-08-17 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14631	PG0187	2017-07-21 15:05:00+03	2017-07-21 17:15:00+03	PEE	OVB	Arrived	319	2017-07-21 15:09:00+03	2017-07-21 17:19:00+03
14632	PG0187	2017-08-04 15:05:00+03	2017-08-04 17:15:00+03	PEE	OVB	Arrived	319	2017-08-04 15:06:00+03	2017-08-04 17:18:00+03
14633	PG0187	2017-09-01 15:05:00+03	2017-09-01 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14634	PG0187	2017-07-29 15:05:00+03	2017-07-29 17:15:00+03	PEE	OVB	Arrived	319	2017-07-29 15:06:00+03	2017-07-29 17:17:00+03
14635	PG0187	2017-08-19 15:05:00+03	2017-08-19 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14636	PG0187	2017-08-25 15:05:00+03	2017-08-25 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14637	PG0187	2017-09-05 15:05:00+03	2017-09-05 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14638	PG0187	2017-09-07 15:05:00+03	2017-09-07 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14639	PG0187	2017-07-22 15:05:00+03	2017-07-22 17:15:00+03	PEE	OVB	Arrived	319	2017-07-22 15:12:00+03	2017-07-22 17:24:00+03
14640	PG0187	2017-07-23 15:05:00+03	2017-07-23 17:15:00+03	PEE	OVB	Arrived	319	2017-07-23 15:07:00+03	2017-07-23 17:19:00+03
14641	PG0187	2017-07-30 15:05:00+03	2017-07-30 17:15:00+03	PEE	OVB	Arrived	319	2017-07-30 15:07:00+03	2017-07-30 17:19:00+03
14642	PG0187	2017-07-28 15:05:00+03	2017-07-28 17:15:00+03	PEE	OVB	Arrived	319	2017-07-28 15:08:00+03	2017-07-28 17:18:00+03
14643	PG0187	2017-09-10 15:05:00+03	2017-09-10 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14644	PG0187	2017-08-11 15:05:00+03	2017-08-11 17:15:00+03	PEE	OVB	Arrived	319	2017-08-11 15:06:00+03	2017-08-11 17:17:00+03
14645	PG0187	2017-07-24 15:05:00+03	2017-07-24 17:15:00+03	PEE	OVB	Arrived	319	2017-07-24 15:07:00+03	2017-07-24 17:16:00+03
14646	PG0187	2017-08-15 15:05:00+03	2017-08-15 17:15:00+03	PEE	OVB	Arrived	319	2017-08-15 15:05:00+03	2017-08-15 17:15:00+03
14647	PG0187	2017-08-13 15:05:00+03	2017-08-13 17:15:00+03	PEE	OVB	Arrived	319	2017-08-13 15:07:00+03	2017-08-13 17:19:00+03
14648	PG0187	2017-09-12 15:05:00+03	2017-09-12 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14649	PG0187	2017-08-09 15:05:00+03	2017-08-09 17:15:00+03	PEE	OVB	Arrived	319	2017-08-09 15:09:00+03	2017-08-09 17:18:00+03
14650	PG0187	2017-07-17 15:05:00+03	2017-07-17 17:15:00+03	PEE	OVB	Arrived	319	2017-07-17 15:07:00+03	2017-07-17 17:16:00+03
14651	PG0187	2017-08-26 15:05:00+03	2017-08-26 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14652	PG0187	2017-08-24 15:05:00+03	2017-08-24 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14653	PG0187	2017-08-22 15:05:00+03	2017-08-22 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14654	PG0187	2017-08-20 15:05:00+03	2017-08-20 17:15:00+03	PEE	OVB	Scheduled	319	\N	\N
14655	PG0590	2017-07-20 17:50:00+03	2017-07-20 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-20 21:09:00+03	2017-07-20 21:34:00+03
14656	PG0590	2017-07-30 17:50:00+03	2017-07-30 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-30 17:51:00+03	2017-07-30 18:16:00+03
14657	PG0589	2017-07-30 15:30:00+03	2017-07-30 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-30 15:33:00+03	2017-07-30 15:58:00+03
14658	PG0589	2017-09-11 15:30:00+03	2017-09-11 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14659	PG0590	2017-09-11 17:50:00+03	2017-09-11 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14660	PG0589	2017-08-24 15:30:00+03	2017-08-24 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14661	PG0589	2017-08-26 15:30:00+03	2017-08-26 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14662	PG0590	2017-08-24 17:50:00+03	2017-08-24 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14663	PG0589	2017-08-11 15:30:00+03	2017-08-11 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-11 15:32:00+03	2017-08-11 15:57:00+03
14664	PG0590	2017-08-11 17:50:00+03	2017-08-11 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-11 17:50:00+03	2017-08-11 18:15:00+03
14665	PG0589	2017-08-27 15:30:00+03	2017-08-27 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14666	PG0590	2017-08-27 17:50:00+03	2017-08-27 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14667	PG0590	2017-08-10 17:50:00+03	2017-08-10 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-10 17:52:00+03	2017-08-10 18:17:00+03
14668	PG0589	2017-08-10 15:30:00+03	2017-08-10 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-10 15:33:00+03	2017-08-10 15:58:00+03
14669	PG0590	2017-08-26 17:50:00+03	2017-08-26 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14670	PG0589	2017-09-01 15:30:00+03	2017-09-01 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14671	PG0590	2017-09-01 17:50:00+03	2017-09-01 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14672	PG0589	2017-09-14 15:30:00+03	2017-09-14 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14673	PG0590	2017-09-06 17:50:00+03	2017-09-06 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14674	PG0590	2017-07-25 17:50:00+03	2017-07-25 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-25 17:53:00+03	2017-07-25 18:18:00+03
14675	PG0589	2017-07-25 15:30:00+03	2017-07-25 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-25 15:32:00+03	2017-07-25 15:57:00+03
14676	PG0590	2017-08-30 17:50:00+03	2017-08-30 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14677	PG0589	2017-08-30 15:30:00+03	2017-08-30 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14678	PG0590	2017-08-17 17:50:00+03	2017-08-17 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14679	PG0589	2017-08-17 15:30:00+03	2017-08-17 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14680	PG0589	2017-08-02 15:30:00+03	2017-08-02 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-02 15:35:00+03	2017-08-02 16:00:00+03
14681	PG0590	2017-08-02 17:50:00+03	2017-08-02 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-02 17:52:00+03	2017-08-02 18:17:00+03
14682	PG0590	2017-09-09 17:50:00+03	2017-09-09 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14683	PG0590	2017-07-16 17:50:00+03	2017-07-16 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-16 17:51:00+03	2017-07-16 18:16:00+03
14684	PG0589	2017-09-09 15:30:00+03	2017-09-09 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14685	PG0589	2017-07-16 15:30:00+03	2017-07-16 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-16 15:32:00+03	2017-07-16 15:57:00+03
14686	PG0590	2017-09-05 17:50:00+03	2017-09-05 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14687	PG0590	2017-08-01 17:50:00+03	2017-08-01 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-01 17:53:00+03	2017-08-01 18:18:00+03
14688	PG0589	2017-08-01 15:30:00+03	2017-08-01 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-01 15:33:00+03	2017-08-01 15:58:00+03
14689	PG0589	2017-09-05 15:30:00+03	2017-09-05 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14690	PG0590	2017-07-23 17:50:00+03	2017-07-23 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-23 17:53:00+03	2017-07-23 18:18:00+03
14691	PG0589	2017-07-23 15:30:00+03	2017-07-23 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-23 15:31:00+03	2017-07-23 15:56:00+03
14692	PG0589	2017-07-17 15:30:00+03	2017-07-17 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-17 15:33:00+03	2017-07-17 15:58:00+03
14693	PG0590	2017-07-17 17:50:00+03	2017-07-17 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-17 17:55:00+03	2017-07-17 18:20:00+03
14694	PG0589	2017-08-14 15:30:00+03	2017-08-14 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-14 15:33:00+03	2017-08-14 15:58:00+03
14695	PG0590	2017-08-14 17:50:00+03	2017-08-14 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-14 17:54:00+03	2017-08-14 18:19:00+03
14696	PG0589	2017-08-25 15:30:00+03	2017-08-25 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14697	PG0590	2017-08-25 17:50:00+03	2017-08-25 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14698	PG0590	2017-08-21 17:50:00+03	2017-08-21 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14699	PG0589	2017-08-21 15:30:00+03	2017-08-21 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14700	PG0590	2017-08-09 17:50:00+03	2017-08-09 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-09 17:50:00+03	2017-08-09 18:15:00+03
14701	PG0589	2017-08-09 15:30:00+03	2017-08-09 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-09 15:33:00+03	2017-08-09 15:58:00+03
14702	PG0589	2017-07-27 15:30:00+03	2017-07-27 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-27 15:34:00+03	2017-07-27 16:00:00+03
14703	PG0590	2017-07-27 17:50:00+03	2017-07-27 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-27 17:52:00+03	2017-07-27 18:17:00+03
14704	PG0589	2017-09-06 15:30:00+03	2017-09-06 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14705	PG0589	2017-07-22 15:30:00+03	2017-07-22 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-22 15:31:00+03	2017-07-22 15:56:00+03
14706	PG0590	2017-07-22 17:50:00+03	2017-07-22 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-22 17:54:00+03	2017-07-22 18:19:00+03
14707	PG0589	2017-08-22 15:30:00+03	2017-08-22 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14708	PG0590	2017-08-22 17:50:00+03	2017-08-22 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14709	PG0590	2017-09-14 17:50:00+03	2017-09-14 18:15:00+03	PEE	SVX	Cancelled	SU9	\N	\N
14710	PG0590	2017-07-21 17:50:00+03	2017-07-21 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-21 17:53:00+03	2017-07-21 18:18:00+03
14711	PG0589	2017-07-21 15:30:00+03	2017-07-21 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-21 19:09:00+03	2017-07-21 19:34:00+03
14712	PG0590	2017-09-10 17:50:00+03	2017-09-10 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14713	PG0590	2017-09-08 17:50:00+03	2017-09-08 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14714	PG0589	2017-09-08 15:30:00+03	2017-09-08 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14715	PG0589	2017-09-10 15:30:00+03	2017-09-10 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14716	PG0589	2017-08-03 15:30:00+03	2017-08-03 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-03 15:34:00+03	2017-08-03 15:59:00+03
14717	PG0590	2017-08-03 17:50:00+03	2017-08-03 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-03 17:53:00+03	2017-08-03 18:18:00+03
14718	PG0590	2017-08-13 17:50:00+03	2017-08-13 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-13 17:52:00+03	2017-08-13 18:17:00+03
14719	PG0589	2017-08-13 15:30:00+03	2017-08-13 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-13 15:33:00+03	2017-08-13 15:58:00+03
14720	PG0589	2017-09-02 15:30:00+03	2017-09-02 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14721	PG0590	2017-09-02 17:50:00+03	2017-09-02 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14722	PG0590	2017-08-08 17:50:00+03	2017-08-08 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-08 17:51:00+03	2017-08-08 18:16:00+03
14723	PG0589	2017-08-08 15:30:00+03	2017-08-08 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-08 15:34:00+03	2017-08-08 15:59:00+03
14724	PG0590	2017-09-13 17:50:00+03	2017-09-13 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14725	PG0589	2017-09-13 15:30:00+03	2017-09-13 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14726	PG0589	2017-07-18 15:30:00+03	2017-07-18 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-18 18:42:00+03	2017-07-18 19:07:00+03
14727	PG0590	2017-07-18 17:50:00+03	2017-07-18 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-18 17:54:00+03	2017-07-18 18:19:00+03
14728	PG0590	2017-07-26 17:50:00+03	2017-07-26 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-26 17:53:00+03	2017-07-26 18:18:00+03
14729	PG0590	2017-08-31 17:50:00+03	2017-08-31 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14730	PG0589	2017-08-31 15:30:00+03	2017-08-31 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14731	PG0589	2017-07-26 15:30:00+03	2017-07-26 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-26 15:34:00+03	2017-07-26 15:59:00+03
14732	PG0589	2017-09-07 15:30:00+03	2017-09-07 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14733	PG0590	2017-09-07 17:50:00+03	2017-09-07 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14734	PG0590	2017-08-07 17:50:00+03	2017-08-07 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-07 17:54:00+03	2017-08-07 18:19:00+03
14735	PG0589	2017-08-07 15:30:00+03	2017-08-07 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-07 15:33:00+03	2017-08-07 15:58:00+03
14736	PG0589	2017-08-12 15:30:00+03	2017-08-12 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-12 15:32:00+03	2017-08-12 15:57:00+03
14737	PG0590	2017-08-12 17:50:00+03	2017-08-12 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-12 17:53:00+03	2017-08-12 18:18:00+03
14738	PG0590	2017-08-23 17:50:00+03	2017-08-23 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14739	PG0589	2017-08-23 15:30:00+03	2017-08-23 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14740	PG0589	2017-08-04 15:30:00+03	2017-08-04 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-04 15:34:00+03	2017-08-04 15:59:00+03
14741	PG0590	2017-08-04 17:50:00+03	2017-08-04 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-04 17:53:00+03	2017-08-04 18:17:00+03
14742	PG0589	2017-08-15 15:30:00+03	2017-08-15 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-15 15:37:00+03	2017-08-15 16:02:00+03
14743	PG0590	2017-08-15 17:50:00+03	2017-08-15 18:15:00+03	PEE	SVX	Departed	SU9	2017-08-15 17:56:00+03	\N
14744	PG0589	2017-07-28 15:30:00+03	2017-07-28 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-28 15:33:00+03	2017-07-28 15:58:00+03
14745	PG0590	2017-07-28 17:50:00+03	2017-07-28 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-28 17:51:00+03	2017-07-28 18:16:00+03
14746	PG0590	2017-09-04 17:50:00+03	2017-09-04 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14747	PG0589	2017-09-04 15:30:00+03	2017-09-04 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14748	PG0589	2017-07-20 15:30:00+03	2017-07-20 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-20 15:32:00+03	2017-07-20 15:57:00+03
14749	PG0590	2017-07-29 17:50:00+03	2017-07-29 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-29 17:51:00+03	2017-07-29 18:17:00+03
14750	PG0589	2017-07-29 15:30:00+03	2017-07-29 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-29 20:07:00+03	2017-07-29 20:32:00+03
14751	PG0590	2017-08-28 17:50:00+03	2017-08-28 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14752	PG0590	2017-08-18 17:50:00+03	2017-08-18 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14753	PG0589	2017-08-28 15:30:00+03	2017-08-28 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14754	PG0589	2017-08-18 15:30:00+03	2017-08-18 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14755	PG0590	2017-08-19 17:50:00+03	2017-08-19 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14756	PG0590	2017-08-20 17:50:00+03	2017-08-20 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14757	PG0589	2017-08-19 15:30:00+03	2017-08-19 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14758	PG0590	2017-08-16 17:50:00+03	2017-08-16 18:15:00+03	PEE	SVX	On Time	SU9	\N	\N
14759	PG0589	2017-09-03 15:30:00+03	2017-09-03 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14760	PG0590	2017-09-03 17:50:00+03	2017-09-03 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14761	PG0589	2017-08-16 15:30:00+03	2017-08-16 15:55:00+03	PEE	SVX	On Time	SU9	\N	\N
14762	PG0590	2017-08-06 17:50:00+03	2017-08-06 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-06 17:53:00+03	2017-08-06 18:18:00+03
14763	PG0589	2017-08-06 15:30:00+03	2017-08-06 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-06 15:32:00+03	2017-08-06 15:57:00+03
14764	PG0589	2017-07-19 15:30:00+03	2017-07-19 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-19 18:23:00+03	2017-07-19 18:48:00+03
14765	PG0590	2017-07-19 17:50:00+03	2017-07-19 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-19 17:52:00+03	2017-07-19 18:17:00+03
14766	PG0589	2017-09-12 15:30:00+03	2017-09-12 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14767	PG0590	2017-09-12 17:50:00+03	2017-09-12 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14768	PG0589	2017-08-20 15:30:00+03	2017-08-20 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14769	PG0589	2017-07-31 15:30:00+03	2017-07-31 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-31 15:32:00+03	2017-07-31 15:57:00+03
14770	PG0590	2017-07-31 17:50:00+03	2017-07-31 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-31 17:54:00+03	2017-07-31 18:19:00+03
14771	PG0590	2017-07-24 17:50:00+03	2017-07-24 18:15:00+03	PEE	SVX	Arrived	SU9	2017-07-24 17:55:00+03	2017-07-24 18:20:00+03
14772	PG0589	2017-07-24 15:30:00+03	2017-07-24 15:55:00+03	PEE	SVX	Arrived	SU9	2017-07-24 15:33:00+03	2017-07-24 15:58:00+03
14773	PG0589	2017-08-29 15:30:00+03	2017-08-29 15:55:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14774	PG0589	2017-08-05 15:30:00+03	2017-08-05 15:55:00+03	PEE	SVX	Arrived	SU9	2017-08-05 15:32:00+03	2017-08-05 15:56:00+03
14775	PG0590	2017-08-05 17:50:00+03	2017-08-05 18:15:00+03	PEE	SVX	Arrived	SU9	2017-08-05 17:53:00+03	2017-08-05 18:18:00+03
14776	PG0590	2017-08-29 17:50:00+03	2017-08-29 18:15:00+03	PEE	SVX	Scheduled	SU9	\N	\N
14777	PG0676	2017-08-21 07:05:00+03	2017-08-21 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14778	PG0676	2017-07-22 07:05:00+03	2017-07-22 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-22 07:07:00+03	2017-07-22 07:47:00+03
14779	PG0676	2017-09-05 07:05:00+03	2017-09-05 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14780	PG0676	2017-07-26 07:05:00+03	2017-07-26 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-26 07:06:00+03	2017-07-26 07:46:00+03
14781	PG0676	2017-08-03 07:05:00+03	2017-08-03 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-03 07:11:00+03	2017-08-03 07:52:00+03
14782	PG0676	2017-08-19 07:05:00+03	2017-08-19 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14783	PG0676	2017-07-27 07:05:00+03	2017-07-27 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-27 07:08:00+03	2017-07-27 07:48:00+03
14784	PG0676	2017-08-20 07:05:00+03	2017-08-20 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14785	PG0676	2017-08-28 07:05:00+03	2017-08-28 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14786	PG0676	2017-07-19 07:05:00+03	2017-07-19 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-19 07:11:00+03	2017-07-19 07:51:00+03
14787	PG0676	2017-09-01 07:05:00+03	2017-09-01 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14788	PG0676	2017-08-29 07:05:00+03	2017-08-29 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14789	PG0676	2017-09-10 07:05:00+03	2017-09-10 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14790	PG0676	2017-08-08 07:05:00+03	2017-08-08 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-08 07:08:00+03	2017-08-08 07:48:00+03
14791	PG0676	2017-08-06 07:05:00+03	2017-08-06 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-06 10:24:00+03	2017-08-06 11:04:00+03
14792	PG0676	2017-09-11 07:05:00+03	2017-09-11 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14793	PG0676	2017-07-24 07:05:00+03	2017-07-24 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-24 07:10:00+03	2017-07-24 07:50:00+03
14794	PG0676	2017-08-31 07:05:00+03	2017-08-31 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14795	PG0676	2017-08-14 07:05:00+03	2017-08-14 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-14 07:06:00+03	2017-08-14 07:45:00+03
14796	PG0676	2017-07-25 07:05:00+03	2017-07-25 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-25 07:10:00+03	2017-07-25 07:50:00+03
14797	PG0676	2017-09-03 07:05:00+03	2017-09-03 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14798	PG0676	2017-07-16 07:05:00+03	2017-07-16 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-16 07:08:00+03	2017-07-16 07:48:00+03
14799	PG0676	2017-09-09 07:05:00+03	2017-09-09 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14800	PG0676	2017-08-26 07:05:00+03	2017-08-26 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14801	PG0676	2017-09-13 07:05:00+03	2017-09-13 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14802	PG0676	2017-07-21 07:05:00+03	2017-07-21 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-21 10:17:00+03	2017-07-21 10:57:00+03
14803	PG0676	2017-08-18 07:05:00+03	2017-08-18 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14804	PG0676	2017-08-25 07:05:00+03	2017-08-25 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14805	PG0676	2017-08-13 07:05:00+03	2017-08-13 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-13 07:06:00+03	2017-08-13 07:46:00+03
14807	PG0676	2017-08-24 07:05:00+03	2017-08-24 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14808	PG0676	2017-08-16 07:05:00+03	2017-08-16 07:45:00+03	PEE	CEK	On Time	CR2	\N	\N
14809	PG0676	2017-08-02 07:05:00+03	2017-08-02 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-02 07:06:00+03	2017-08-02 07:46:00+03
14810	PG0676	2017-08-23 07:05:00+03	2017-08-23 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14811	PG0676	2017-08-04 07:05:00+03	2017-08-04 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-04 07:08:00+03	2017-08-04 07:48:00+03
14812	PG0676	2017-07-29 07:05:00+03	2017-07-29 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-29 07:10:00+03	2017-07-29 07:50:00+03
14813	PG0676	2017-08-12 07:05:00+03	2017-08-12 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-12 07:08:00+03	2017-08-12 07:48:00+03
14814	PG0676	2017-08-30 07:05:00+03	2017-08-30 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14815	PG0676	2017-08-15 07:05:00+03	2017-08-15 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-15 07:09:00+03	2017-08-15 07:49:00+03
14816	PG0676	2017-07-20 07:05:00+03	2017-07-20 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-20 07:08:00+03	2017-07-20 07:48:00+03
14817	PG0676	2017-09-04 07:05:00+03	2017-09-04 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14818	PG0676	2017-07-30 07:05:00+03	2017-07-30 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-30 07:09:00+03	2017-07-30 07:49:00+03
14819	PG0676	2017-08-01 07:05:00+03	2017-08-01 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-01 07:09:00+03	2017-08-01 07:49:00+03
14820	PG0676	2017-08-07 07:05:00+03	2017-08-07 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-07 07:08:00+03	2017-08-07 07:48:00+03
14821	PG0676	2017-09-02 07:05:00+03	2017-09-02 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14822	PG0676	2017-09-14 07:05:00+03	2017-09-14 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14823	PG0676	2017-07-17 07:05:00+03	2017-07-17 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-17 07:08:00+03	2017-07-17 07:48:00+03
14824	PG0676	2017-08-10 07:05:00+03	2017-08-10 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-10 07:07:00+03	2017-08-10 07:46:00+03
14825	PG0676	2017-07-28 07:05:00+03	2017-07-28 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-28 10:01:00+03	2017-07-28 10:41:00+03
14826	PG0676	2017-09-12 07:05:00+03	2017-09-12 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14827	PG0676	2017-08-22 07:05:00+03	2017-08-22 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14828	PG0676	2017-08-11 07:05:00+03	2017-08-11 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-11 07:08:00+03	2017-08-11 07:48:00+03
14829	PG0676	2017-08-27 07:05:00+03	2017-08-27 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14830	PG0676	2017-07-31 07:05:00+03	2017-07-31 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-31 07:08:00+03	2017-07-31 07:48:00+03
14831	PG0676	2017-09-08 07:05:00+03	2017-09-08 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14832	PG0676	2017-08-17 07:05:00+03	2017-08-17 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14833	PG0676	2017-08-05 07:05:00+03	2017-08-05 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-05 07:09:00+03	2017-08-05 07:49:00+03
14834	PG0676	2017-07-23 07:05:00+03	2017-07-23 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-23 07:09:00+03	2017-07-23 07:49:00+03
14835	PG0676	2017-09-07 07:05:00+03	2017-09-07 07:45:00+03	PEE	CEK	Scheduled	CR2	\N	\N
14836	PG0676	2017-08-09 07:05:00+03	2017-08-09 07:45:00+03	PEE	CEK	Arrived	CR2	2017-08-09 07:09:00+03	2017-08-09 07:49:00+03
14837	PG0676	2017-07-18 07:05:00+03	2017-07-18 07:45:00+03	PEE	CEK	Arrived	CR2	2017-07-18 07:06:00+03	2017-07-18 07:46:00+03
14838	PG0394	2017-09-06 08:30:00+03	2017-09-06 13:45:00+03	PEE	CNN	Scheduled	319	\N	\N
14839	PG0394	2017-09-13 08:30:00+03	2017-09-13 13:45:00+03	PEE	CNN	Scheduled	319	\N	\N
14840	PG0394	2017-07-19 08:30:00+03	2017-07-19 13:45:00+03	PEE	CNN	Arrived	319	2017-07-19 08:35:00+03	2017-07-19 13:49:00+03
14841	PG0394	2017-08-16 08:30:00+03	2017-08-16 13:45:00+03	PEE	CNN	On Time	319	\N	\N
14842	PG0394	2017-08-23 08:30:00+03	2017-08-23 13:45:00+03	PEE	CNN	Scheduled	319	\N	\N
14843	PG0394	2017-08-30 08:30:00+03	2017-08-30 13:45:00+03	PEE	CNN	Scheduled	319	\N	\N
14844	PG0394	2017-08-02 08:30:00+03	2017-08-02 13:45:00+03	PEE	CNN	Arrived	319	2017-08-02 08:33:00+03	2017-08-02 13:49:00+03
14845	PG0394	2017-07-26 08:30:00+03	2017-07-26 13:45:00+03	PEE	CNN	Arrived	319	2017-07-26 08:33:00+03	2017-07-26 13:46:00+03
14846	PG0394	2017-08-09 08:30:00+03	2017-08-09 13:45:00+03	PEE	CNN	Arrived	319	2017-08-09 08:32:00+03	2017-08-09 13:46:00+03
14847	PG0319	2017-08-05 08:25:00+03	2017-08-05 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-05 08:26:00+03	2017-08-05 10:44:00+03
14848	PG0319	2017-09-13 08:25:00+03	2017-09-13 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14849	PG0319	2017-08-31 08:25:00+03	2017-08-31 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14850	PG0319	2017-08-04 08:25:00+03	2017-08-04 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-04 08:28:00+03	2017-08-04 10:48:00+03
14851	PG0319	2017-07-29 08:25:00+03	2017-07-29 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-29 08:30:00+03	2017-07-29 10:49:00+03
14852	PG0319	2017-09-12 08:25:00+03	2017-09-12 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14853	PG0319	2017-08-11 08:25:00+03	2017-08-11 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-11 08:28:00+03	2017-08-11 10:49:00+03
14854	PG0319	2017-09-03 08:25:00+03	2017-09-03 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14855	PG0319	2017-08-16 08:25:00+03	2017-08-16 10:45:00+03	PEE	MRV	On Time	SU9	\N	\N
14856	PG0319	2017-07-17 08:25:00+03	2017-07-17 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-17 08:29:00+03	2017-07-17 10:48:00+03
14857	PG0319	2017-09-09 08:25:00+03	2017-09-09 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14858	PG0319	2017-08-24 08:25:00+03	2017-08-24 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14859	PG0319	2017-07-24 08:25:00+03	2017-07-24 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-24 08:26:00+03	2017-07-24 10:46:00+03
14860	PG0319	2017-08-26 08:25:00+03	2017-08-26 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14861	PG0319	2017-09-14 08:25:00+03	2017-09-14 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14862	PG0319	2017-07-20 08:25:00+03	2017-07-20 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-20 08:28:00+03	2017-07-20 10:46:00+03
14863	PG0319	2017-09-05 08:25:00+03	2017-09-05 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14864	PG0319	2017-07-26 08:25:00+03	2017-07-26 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-26 08:28:00+03	2017-07-26 10:48:00+03
14865	PG0319	2017-09-02 08:25:00+03	2017-09-02 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14866	PG0319	2017-07-22 08:25:00+03	2017-07-22 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-22 08:31:00+03	2017-07-22 10:50:00+03
14867	PG0319	2017-08-28 08:25:00+03	2017-08-28 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14868	PG0319	2017-07-31 08:25:00+03	2017-07-31 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-31 08:27:00+03	2017-07-31 10:47:00+03
14869	PG0319	2017-07-30 08:25:00+03	2017-07-30 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-30 08:29:00+03	2017-07-30 10:48:00+03
14870	PG0319	2017-09-11 08:25:00+03	2017-09-11 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14871	PG0319	2017-07-18 08:25:00+03	2017-07-18 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-18 08:31:00+03	2017-07-18 10:51:00+03
14872	PG0319	2017-08-27 08:25:00+03	2017-08-27 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14873	PG0319	2017-08-12 08:25:00+03	2017-08-12 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-12 08:26:00+03	2017-08-12 10:46:00+03
14874	PG0319	2017-08-17 08:25:00+03	2017-08-17 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14875	PG0319	2017-08-20 08:25:00+03	2017-08-20 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14876	PG0319	2017-08-13 08:25:00+03	2017-08-13 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-13 08:27:00+03	2017-08-13 10:49:00+03
14877	PG0319	2017-08-10 08:25:00+03	2017-08-10 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-10 08:29:00+03	2017-08-10 10:48:00+03
14878	PG0319	2017-08-23 08:25:00+03	2017-08-23 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14879	PG0319	2017-08-25 08:25:00+03	2017-08-25 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14880	PG0319	2017-08-22 08:25:00+03	2017-08-22 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14881	PG0319	2017-07-25 08:25:00+03	2017-07-25 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-25 08:27:00+03	2017-07-25 10:48:00+03
14882	PG0319	2017-08-02 08:25:00+03	2017-08-02 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-02 08:28:00+03	2017-08-02 10:46:00+03
14883	PG0319	2017-08-01 08:25:00+03	2017-08-01 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-01 08:25:00+03	2017-08-01 10:46:00+03
14884	PG0319	2017-08-06 08:25:00+03	2017-08-06 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-06 08:30:00+03	2017-08-06 10:51:00+03
14885	PG0319	2017-09-10 08:25:00+03	2017-09-10 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14886	PG0319	2017-08-30 08:25:00+03	2017-08-30 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14887	PG0319	2017-08-18 08:25:00+03	2017-08-18 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14888	PG0319	2017-07-23 08:25:00+03	2017-07-23 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-23 08:31:00+03	2017-07-23 10:54:00+03
14889	PG0319	2017-07-16 08:25:00+03	2017-07-16 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-16 08:25:00+03	2017-07-16 10:45:00+03
14890	PG0319	2017-07-21 08:25:00+03	2017-07-21 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-21 08:27:00+03	2017-07-21 10:47:00+03
14891	PG0319	2017-08-21 08:25:00+03	2017-08-21 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14892	PG0319	2017-08-15 08:25:00+03	2017-08-15 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-15 08:30:00+03	2017-08-15 10:52:00+03
14893	PG0319	2017-09-08 08:25:00+03	2017-09-08 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14894	PG0319	2017-08-08 08:25:00+03	2017-08-08 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-08 08:27:00+03	2017-08-08 10:48:00+03
14895	PG0319	2017-07-27 08:25:00+03	2017-07-27 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-27 08:29:00+03	2017-07-27 10:50:00+03
14896	PG0319	2017-08-03 08:25:00+03	2017-08-03 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-03 08:31:00+03	2017-08-03 10:50:00+03
14897	PG0319	2017-09-06 08:25:00+03	2017-09-06 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14898	PG0319	2017-08-19 08:25:00+03	2017-08-19 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14899	PG0319	2017-07-28 08:25:00+03	2017-07-28 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-28 08:25:00+03	2017-07-28 10:44:00+03
14900	PG0319	2017-09-07 08:25:00+03	2017-09-07 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14901	PG0319	2017-07-19 08:25:00+03	2017-07-19 10:45:00+03	PEE	MRV	Arrived	SU9	2017-07-19 08:26:00+03	2017-07-19 10:50:00+03
14902	PG0319	2017-08-09 08:25:00+03	2017-08-09 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-09 08:27:00+03	2017-08-09 10:47:00+03
14903	PG0319	2017-09-04 08:25:00+03	2017-09-04 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14904	PG0319	2017-09-01 08:25:00+03	2017-09-01 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14905	PG0319	2017-08-14 08:25:00+03	2017-08-14 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-14 08:28:00+03	2017-08-14 10:48:00+03
14906	PG0319	2017-08-07 08:25:00+03	2017-08-07 10:45:00+03	PEE	MRV	Arrived	SU9	2017-08-07 08:28:00+03	2017-08-07 10:49:00+03
14907	PG0319	2017-08-29 08:25:00+03	2017-08-29 10:45:00+03	PEE	MRV	Scheduled	SU9	\N	\N
14908	PG0697	2017-08-04 15:35:00+03	2017-08-04 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-04 15:38:00+03	2017-08-04 16:38:00+03
14909	PG0697	2017-09-03 15:35:00+03	2017-09-03 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14910	PG0697	2017-09-02 15:35:00+03	2017-09-02 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14911	PG0697	2017-07-27 15:35:00+03	2017-07-27 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-27 15:40:00+03	2017-07-27 16:41:00+03
14912	PG0697	2017-09-07 15:35:00+03	2017-09-07 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14913	PG0697	2017-08-07 15:35:00+03	2017-08-07 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-07 15:38:00+03	2017-08-07 16:38:00+03
14914	PG0697	2017-08-21 15:35:00+03	2017-08-21 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14915	PG0697	2017-08-17 15:35:00+03	2017-08-17 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14916	PG0697	2017-07-26 15:35:00+03	2017-07-26 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-26 15:36:00+03	2017-07-26 16:36:00+03
14917	PG0697	2017-08-05 15:35:00+03	2017-08-05 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-05 15:37:00+03	2017-08-05 16:37:00+03
14918	PG0697	2017-08-25 15:35:00+03	2017-08-25 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14919	PG0697	2017-07-29 15:35:00+03	2017-07-29 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-29 15:38:00+03	2017-07-29 16:37:00+03
14920	PG0697	2017-08-22 15:35:00+03	2017-08-22 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14921	PG0697	2017-08-26 15:35:00+03	2017-08-26 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14922	PG0697	2017-07-22 15:35:00+03	2017-07-22 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-22 15:39:00+03	2017-07-22 16:39:00+03
14923	PG0697	2017-09-05 15:35:00+03	2017-09-05 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14924	PG0697	2017-08-13 15:35:00+03	2017-08-13 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-13 15:39:00+03	2017-08-13 16:38:00+03
14925	PG0697	2017-08-11 15:35:00+03	2017-08-11 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-11 15:38:00+03	2017-08-11 16:37:00+03
14926	PG0697	2017-07-18 15:35:00+03	2017-07-18 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-18 15:36:00+03	2017-07-18 16:36:00+03
14927	PG0697	2017-07-19 15:35:00+03	2017-07-19 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-19 15:38:00+03	2017-07-19 16:37:00+03
14928	PG0697	2017-08-29 15:35:00+03	2017-08-29 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14929	PG0697	2017-08-10 15:35:00+03	2017-08-10 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-10 15:37:00+03	2017-08-10 16:38:00+03
14930	PG0697	2017-07-25 15:35:00+03	2017-07-25 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-25 15:42:00+03	2017-07-25 16:42:00+03
14931	PG0697	2017-08-24 15:35:00+03	2017-08-24 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14932	PG0697	2017-07-30 15:35:00+03	2017-07-30 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-30 15:36:00+03	2017-07-30 16:36:00+03
14933	PG0697	2017-08-18 15:35:00+03	2017-08-18 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14934	PG0697	2017-07-17 15:35:00+03	2017-07-17 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-17 15:38:00+03	2017-07-17 16:38:00+03
14935	PG0697	2017-08-09 15:35:00+03	2017-08-09 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-09 15:37:00+03	2017-08-09 16:37:00+03
14936	PG0697	2017-09-13 15:35:00+03	2017-09-13 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14937	PG0697	2017-07-21 15:35:00+03	2017-07-21 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-21 15:36:00+03	2017-07-21 16:35:00+03
14938	PG0697	2017-08-02 15:35:00+03	2017-08-02 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-02 15:37:00+03	2017-08-02 16:36:00+03
14939	PG0697	2017-08-23 15:35:00+03	2017-08-23 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14940	PG0697	2017-09-14 15:35:00+03	2017-09-14 16:35:00+03	PEE	GOJ	Cancelled	SU9	\N	\N
14941	PG0697	2017-08-14 15:35:00+03	2017-08-14 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-14 15:40:00+03	2017-08-14 16:40:00+03
14942	PG0697	2017-07-23 15:35:00+03	2017-07-23 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-23 15:40:00+03	2017-07-23 16:40:00+03
14943	PG0697	2017-09-11 15:35:00+03	2017-09-11 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14944	PG0697	2017-09-08 15:35:00+03	2017-09-08 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14945	PG0697	2017-08-31 15:35:00+03	2017-08-31 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14946	PG0697	2017-08-27 15:35:00+03	2017-08-27 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14947	PG0697	2017-08-15 15:35:00+03	2017-08-15 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-15 15:36:00+03	2017-08-15 16:36:00+03
14948	PG0697	2017-08-03 15:35:00+03	2017-08-03 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-03 15:39:00+03	2017-08-03 16:40:00+03
14949	PG0697	2017-09-06 15:35:00+03	2017-09-06 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14950	PG0697	2017-09-09 15:35:00+03	2017-09-09 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14951	PG0697	2017-07-28 15:35:00+03	2017-07-28 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-28 15:35:00+03	2017-07-28 16:36:00+03
14952	PG0697	2017-07-20 15:35:00+03	2017-07-20 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-20 15:38:00+03	2017-07-20 16:38:00+03
14953	PG0697	2017-08-06 15:35:00+03	2017-08-06 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-06 15:38:00+03	2017-08-06 16:38:00+03
14954	PG0697	2017-08-30 15:35:00+03	2017-08-30 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14955	PG0697	2017-07-24 15:35:00+03	2017-07-24 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-24 15:38:00+03	2017-07-24 16:38:00+03
14956	PG0697	2017-08-16 15:35:00+03	2017-08-16 16:35:00+03	PEE	GOJ	On Time	SU9	\N	\N
14957	PG0697	2017-08-01 15:35:00+03	2017-08-01 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-01 15:38:00+03	2017-08-01 16:38:00+03
14958	PG0697	2017-09-12 15:35:00+03	2017-09-12 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14959	PG0697	2017-08-08 15:35:00+03	2017-08-08 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-08 15:37:00+03	2017-08-08 16:37:00+03
14960	PG0697	2017-09-10 15:35:00+03	2017-09-10 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14961	PG0697	2017-08-12 15:35:00+03	2017-08-12 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-08-12 15:38:00+03	2017-08-12 16:38:00+03
14962	PG0697	2017-08-19 15:35:00+03	2017-08-19 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14963	PG0697	2017-09-04 15:35:00+03	2017-09-04 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14964	PG0697	2017-07-16 15:35:00+03	2017-07-16 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-16 18:30:00+03	2017-07-16 19:30:00+03
14965	PG0697	2017-08-20 15:35:00+03	2017-08-20 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14966	PG0697	2017-07-31 15:35:00+03	2017-07-31 16:35:00+03	PEE	GOJ	Arrived	SU9	2017-07-31 15:42:00+03	2017-07-31 16:41:00+03
14967	PG0697	2017-08-28 15:35:00+03	2017-08-28 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14968	PG0697	2017-09-01 15:35:00+03	2017-09-01 16:35:00+03	PEE	GOJ	Scheduled	SU9	\N	\N
14969	PG0683	2017-08-25 07:15:00+03	2017-08-25 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14970	PG0683	2017-08-05 07:15:00+03	2017-08-05 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-05 07:18:00+03	2017-08-05 08:08:00+03
14971	PG0683	2017-08-06 07:15:00+03	2017-08-06 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-06 07:20:00+03	2017-08-06 08:10:00+03
14972	PG0683	2017-07-29 07:15:00+03	2017-07-29 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-29 07:17:00+03	2017-07-29 08:07:00+03
14973	PG0683	2017-07-21 07:15:00+03	2017-07-21 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-21 07:16:00+03	2017-07-21 08:06:00+03
14974	PG0683	2017-09-10 07:15:00+03	2017-09-10 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14975	PG0683	2017-09-01 07:15:00+03	2017-09-01 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14976	PG0683	2017-08-29 07:15:00+03	2017-08-29 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14977	PG0683	2017-07-24 07:15:00+03	2017-07-24 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-24 07:17:00+03	2017-07-24 08:07:00+03
14978	PG0683	2017-09-12 07:15:00+03	2017-09-12 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14979	PG0683	2017-09-09 07:15:00+03	2017-09-09 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14980	PG0683	2017-08-30 07:15:00+03	2017-08-30 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14981	PG0683	2017-08-18 07:15:00+03	2017-08-18 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14982	PG0683	2017-09-06 07:15:00+03	2017-09-06 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14983	PG0683	2017-07-31 07:15:00+03	2017-07-31 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-31 07:17:00+03	2017-07-31 08:06:00+03
14984	PG0683	2017-07-27 07:15:00+03	2017-07-27 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-27 07:15:00+03	2017-07-27 08:05:00+03
14985	PG0683	2017-08-11 07:15:00+03	2017-08-11 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-11 07:18:00+03	2017-08-11 08:09:00+03
14986	PG0683	2017-08-09 07:15:00+03	2017-08-09 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-09 07:18:00+03	2017-08-09 08:09:00+03
14987	PG0683	2017-08-17 07:15:00+03	2017-08-17 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14988	PG0683	2017-08-03 07:15:00+03	2017-08-03 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-03 07:19:00+03	2017-08-03 08:09:00+03
14989	PG0683	2017-07-22 07:15:00+03	2017-07-22 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-22 07:17:00+03	2017-07-22 08:07:00+03
14990	PG0683	2017-08-01 07:15:00+03	2017-08-01 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-01 07:16:00+03	2017-08-01 08:06:00+03
14991	PG0683	2017-08-13 07:15:00+03	2017-08-13 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-13 07:16:00+03	2017-08-13 08:07:00+03
14992	PG0683	2017-09-04 07:15:00+03	2017-09-04 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14993	PG0683	2017-08-14 07:15:00+03	2017-08-14 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-14 07:21:00+03	2017-08-14 08:11:00+03
14994	PG0683	2017-07-30 07:15:00+03	2017-07-30 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-30 07:17:00+03	2017-07-30 08:06:00+03
14995	PG0683	2017-08-24 07:15:00+03	2017-08-24 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14996	PG0683	2017-07-28 07:15:00+03	2017-07-28 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-28 07:16:00+03	2017-07-28 08:06:00+03
14997	PG0683	2017-07-20 07:15:00+03	2017-07-20 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-20 07:17:00+03	2017-07-20 08:07:00+03
14998	PG0683	2017-09-02 07:15:00+03	2017-09-02 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
14999	PG0683	2017-08-15 07:15:00+03	2017-08-15 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-15 07:18:00+03	2017-08-15 08:07:00+03
15000	PG0683	2017-08-07 07:15:00+03	2017-08-07 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-07 07:17:00+03	2017-08-07 08:07:00+03
15001	PG0683	2017-08-22 07:15:00+03	2017-08-22 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15002	PG0683	2017-07-17 07:15:00+03	2017-07-17 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-17 07:16:00+03	2017-07-17 08:06:00+03
15003	PG0683	2017-08-28 07:15:00+03	2017-08-28 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15004	PG0683	2017-09-05 07:15:00+03	2017-09-05 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15005	PG0683	2017-07-23 07:15:00+03	2017-07-23 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-23 07:18:00+03	2017-07-23 08:07:00+03
15006	PG0683	2017-09-07 07:15:00+03	2017-09-07 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15007	PG0683	2017-07-18 07:15:00+03	2017-07-18 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-18 07:18:00+03	2017-07-18 08:08:00+03
15008	PG0683	2017-08-04 07:15:00+03	2017-08-04 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-04 07:16:00+03	2017-08-04 08:06:00+03
15009	PG0683	2017-08-23 07:15:00+03	2017-08-23 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15010	PG0683	2017-08-12 07:15:00+03	2017-08-12 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-12 07:19:00+03	2017-08-12 08:10:00+03
15011	PG0683	2017-08-21 07:15:00+03	2017-08-21 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15012	PG0683	2017-08-16 07:15:00+03	2017-08-16 08:05:00+03	PEE	ULV	On Time	SU9	\N	\N
15013	PG0683	2017-08-20 07:15:00+03	2017-08-20 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15014	PG0683	2017-07-26 07:15:00+03	2017-07-26 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-26 07:19:00+03	2017-07-26 08:09:00+03
15015	PG0683	2017-09-13 07:15:00+03	2017-09-13 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15016	PG0683	2017-08-27 07:15:00+03	2017-08-27 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15017	PG0683	2017-08-31 07:15:00+03	2017-08-31 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15018	PG0683	2017-09-14 07:15:00+03	2017-09-14 08:05:00+03	PEE	ULV	Cancelled	SU9	\N	\N
15019	PG0683	2017-08-02 07:15:00+03	2017-08-02 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-02 07:16:00+03	2017-08-02 08:06:00+03
15020	PG0683	2017-07-25 07:15:00+03	2017-07-25 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-25 07:19:00+03	2017-07-25 08:10:00+03
15021	PG0683	2017-08-19 07:15:00+03	2017-08-19 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15022	PG0683	2017-07-19 07:15:00+03	2017-07-19 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-19 07:19:00+03	2017-07-19 08:08:00+03
15023	PG0683	2017-09-11 07:15:00+03	2017-09-11 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15024	PG0683	2017-08-10 07:15:00+03	2017-08-10 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-10 07:18:00+03	2017-08-10 08:08:00+03
15025	PG0683	2017-07-16 07:15:00+03	2017-07-16 08:05:00+03	PEE	ULV	Arrived	SU9	2017-07-16 10:33:00+03	2017-07-16 11:23:00+03
15026	PG0683	2017-09-08 07:15:00+03	2017-09-08 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15027	PG0683	2017-08-26 07:15:00+03	2017-08-26 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15028	PG0683	2017-09-03 07:15:00+03	2017-09-03 08:05:00+03	PEE	ULV	Scheduled	SU9	\N	\N
15029	PG0683	2017-08-08 07:15:00+03	2017-08-08 08:05:00+03	PEE	ULV	Arrived	SU9	2017-08-08 07:18:00+03	2017-08-08 08:08:00+03
15030	PG0493	2017-09-11 16:50:00+03	2017-09-11 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15031	PG0493	2017-08-22 16:50:00+03	2017-08-22 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15032	PG0492	2017-08-22 11:20:00+03	2017-08-22 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15033	PG0493	2017-07-27 16:50:00+03	2017-07-27 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-27 16:55:00+03	2017-07-27 20:31:00+03
15034	PG0492	2017-07-27 11:20:00+03	2017-07-27 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-27 11:22:00+03	2017-07-27 14:56:00+03
15035	PG0492	2017-09-14 11:20:00+03	2017-09-14 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15036	PG0493	2017-07-24 16:50:00+03	2017-07-24 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-24 16:59:00+03	2017-07-24 20:38:00+03
15037	PG0492	2017-09-07 11:20:00+03	2017-09-07 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15038	PG0493	2017-09-07 16:50:00+03	2017-09-07 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15039	PG0492	2017-07-22 11:20:00+03	2017-07-22 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-22 11:24:00+03	2017-07-22 14:58:00+03
15040	PG0493	2017-07-21 16:50:00+03	2017-07-21 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-21 16:54:00+03	2017-07-21 20:30:00+03
15041	PG0493	2017-07-26 16:50:00+03	2017-07-26 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-26 16:53:00+03	2017-07-26 20:29:00+03
15042	PG0492	2017-07-21 11:20:00+03	2017-07-21 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-21 11:25:00+03	2017-07-21 14:58:00+03
15043	PG0492	2017-08-03 11:20:00+03	2017-08-03 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-03 11:24:00+03	2017-08-03 14:58:00+03
15044	PG0493	2017-08-03 16:50:00+03	2017-08-03 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-03 16:53:00+03	2017-08-03 20:25:00+03
15045	PG0493	2017-08-14 16:50:00+03	2017-08-14 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-14 16:51:00+03	2017-08-14 20:26:00+03
15046	PG0493	2017-07-17 16:50:00+03	2017-07-17 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-17 16:52:00+03	2017-07-17 20:25:00+03
15047	PG0492	2017-08-14 11:20:00+03	2017-08-14 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-14 11:25:00+03	2017-08-14 15:01:00+03
15048	PG0492	2017-09-02 11:20:00+03	2017-09-02 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15049	PG0493	2017-09-02 16:50:00+03	2017-09-02 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15050	PG0492	2017-07-17 11:20:00+03	2017-07-17 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-17 11:24:00+03	2017-07-17 15:00:00+03
15051	PG0492	2017-07-26 11:20:00+03	2017-07-26 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-26 11:20:00+03	2017-07-26 14:49:00+03
15052	PG0493	2017-08-16 16:50:00+03	2017-08-16 20:25:00+03	PEE	ARH	On Time	CN1	\N	\N
15053	PG0492	2017-08-16 11:20:00+03	2017-08-16 14:55:00+03	PEE	ARH	On Time	CN1	\N	\N
15054	PG0492	2017-08-25 11:20:00+03	2017-08-25 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15055	PG0493	2017-08-08 16:50:00+03	2017-08-08 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-08 16:50:00+03	2017-08-08 20:23:00+03
15056	PG0492	2017-08-08 11:20:00+03	2017-08-08 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-08 11:22:00+03	2017-08-08 14:55:00+03
15057	PG0492	2017-07-18 11:20:00+03	2017-07-18 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-18 11:23:00+03	2017-07-18 14:57:00+03
15058	PG0493	2017-07-18 16:50:00+03	2017-07-18 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-18 16:53:00+03	2017-07-18 20:26:00+03
15059	PG0492	2017-08-05 11:20:00+03	2017-08-05 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-05 11:21:00+03	2017-08-05 14:54:00+03
15060	PG0493	2017-08-05 16:50:00+03	2017-08-05 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-05 16:53:00+03	2017-08-05 20:32:00+03
15061	PG0493	2017-09-09 16:50:00+03	2017-09-09 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15062	PG0492	2017-09-09 11:20:00+03	2017-09-09 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15063	PG0493	2017-08-02 16:50:00+03	2017-08-02 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-02 16:51:00+03	2017-08-02 20:26:00+03
15064	PG0493	2017-09-13 16:50:00+03	2017-09-13 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15065	PG0492	2017-09-13 11:20:00+03	2017-09-13 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15066	PG0493	2017-09-08 16:50:00+03	2017-09-08 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15067	PG0492	2017-09-08 11:20:00+03	2017-09-08 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15068	PG0492	2017-08-02 11:20:00+03	2017-08-02 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-02 11:21:00+03	2017-08-02 14:57:00+03
15069	PG0492	2017-08-12 11:20:00+03	2017-08-12 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-12 11:24:00+03	2017-08-12 15:01:00+03
15070	PG0493	2017-08-12 16:50:00+03	2017-08-12 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-12 16:57:00+03	2017-08-12 20:29:00+03
15071	PG0493	2017-07-23 16:50:00+03	2017-07-23 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-23 16:54:00+03	2017-07-23 20:28:00+03
15072	PG0492	2017-07-23 11:20:00+03	2017-07-23 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-23 11:23:00+03	2017-07-23 14:56:00+03
15073	PG0492	2017-08-10 11:20:00+03	2017-08-10 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-10 11:23:00+03	2017-08-10 14:57:00+03
15074	PG0493	2017-08-10 16:50:00+03	2017-08-10 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-10 16:55:00+03	2017-08-10 20:29:00+03
15075	PG0492	2017-08-27 11:20:00+03	2017-08-27 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15076	PG0492	2017-08-15 11:20:00+03	2017-08-15 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-15 11:23:00+03	2017-08-15 14:56:00+03
15077	PG0493	2017-08-15 16:50:00+03	2017-08-15 20:25:00+03	PEE	ARH	Departed	CN1	2017-08-15 16:51:00+03	\N
15078	PG0492	2017-07-28 11:20:00+03	2017-07-28 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-28 11:23:00+03	2017-07-28 15:00:00+03
15079	PG0492	2017-08-18 11:20:00+03	2017-08-18 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15080	PG0493	2017-07-28 16:50:00+03	2017-07-28 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-28 16:55:00+03	2017-07-28 20:28:00+03
15081	PG0492	2017-08-04 11:20:00+03	2017-08-04 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-04 11:23:00+03	2017-08-04 14:59:00+03
15082	PG0493	2017-08-04 16:50:00+03	2017-08-04 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-04 16:53:00+03	2017-08-04 20:26:00+03
15083	PG0493	2017-09-14 16:50:00+03	2017-09-14 20:25:00+03	PEE	ARH	Cancelled	CN1	\N	\N
15084	PG0492	2017-09-06 11:20:00+03	2017-09-06 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15085	PG0492	2017-09-11 11:20:00+03	2017-09-11 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15086	PG0493	2017-08-21 16:50:00+03	2017-08-21 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15087	PG0493	2017-09-06 16:50:00+03	2017-09-06 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15088	PG0492	2017-07-30 11:20:00+03	2017-07-30 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-30 11:22:00+03	2017-07-30 14:56:00+03
15089	PG0493	2017-07-30 16:50:00+03	2017-07-30 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-30 16:52:00+03	2017-07-30 20:30:00+03
15090	PG0492	2017-08-21 11:20:00+03	2017-08-21 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15091	PG0493	2017-08-07 16:50:00+03	2017-08-07 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-07 16:52:00+03	2017-08-07 20:27:00+03
15092	PG0493	2017-08-13 16:50:00+03	2017-08-13 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-13 16:52:00+03	2017-08-13 20:29:00+03
15093	PG0492	2017-08-07 11:20:00+03	2017-08-07 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-07 11:22:00+03	2017-08-07 14:57:00+03
15094	PG0492	2017-08-13 11:20:00+03	2017-08-13 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-13 11:22:00+03	2017-08-13 14:57:00+03
15095	PG0492	2017-07-24 11:20:00+03	2017-07-24 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-24 11:22:00+03	2017-07-24 14:58:00+03
15096	PG0493	2017-08-31 16:50:00+03	2017-08-31 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15097	PG0492	2017-08-31 11:20:00+03	2017-08-31 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15098	PG0492	2017-08-24 11:20:00+03	2017-08-24 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15099	PG0493	2017-08-24 16:50:00+03	2017-08-24 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15100	PG0493	2017-08-28 16:50:00+03	2017-08-28 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15101	PG0493	2017-09-01 16:50:00+03	2017-09-01 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15102	PG0492	2017-09-12 11:20:00+03	2017-09-12 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15103	PG0492	2017-09-01 11:20:00+03	2017-09-01 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15104	PG0493	2017-09-04 16:50:00+03	2017-09-04 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15105	PG0492	2017-09-04 11:20:00+03	2017-09-04 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15106	PG0492	2017-09-03 11:20:00+03	2017-09-03 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15107	PG0493	2017-08-23 16:50:00+03	2017-08-23 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15108	PG0492	2017-08-28 11:20:00+03	2017-08-28 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15109	PG0493	2017-09-12 16:50:00+03	2017-09-12 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15110	PG0493	2017-09-03 16:50:00+03	2017-09-03 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15111	PG0492	2017-08-23 11:20:00+03	2017-08-23 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15112	PG0492	2017-08-29 11:20:00+03	2017-08-29 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15113	PG0493	2017-08-29 16:50:00+03	2017-08-29 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15114	PG0492	2017-07-19 11:20:00+03	2017-07-19 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-19 11:22:00+03	2017-07-19 15:00:00+03
15115	PG0493	2017-07-19 16:50:00+03	2017-07-19 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-19 16:52:00+03	2017-07-19 20:26:00+03
15116	PG0493	2017-08-25 16:50:00+03	2017-08-25 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15117	PG0492	2017-08-19 11:20:00+03	2017-08-19 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15118	PG0493	2017-08-19 16:50:00+03	2017-08-19 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15119	PG0493	2017-07-20 16:50:00+03	2017-07-20 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-20 16:56:00+03	2017-07-20 20:30:00+03
15120	PG0493	2017-08-11 16:50:00+03	2017-08-11 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-11 16:52:00+03	2017-08-11 20:27:00+03
15121	PG0492	2017-07-20 11:20:00+03	2017-07-20 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-20 11:20:00+03	2017-07-20 14:57:00+03
15122	PG0492	2017-08-11 11:20:00+03	2017-08-11 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-11 11:23:00+03	2017-08-11 15:02:00+03
15123	PG0492	2017-07-31 11:20:00+03	2017-07-31 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-31 11:25:00+03	2017-07-31 15:00:00+03
15124	PG0493	2017-07-31 16:50:00+03	2017-07-31 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-31 16:52:00+03	2017-07-31 20:28:00+03
15125	PG0493	2017-09-10 16:50:00+03	2017-09-10 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15126	PG0492	2017-09-10 11:20:00+03	2017-09-10 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15127	PG0493	2017-07-29 16:50:00+03	2017-07-29 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-29 16:50:00+03	2017-07-29 20:24:00+03
15128	PG0492	2017-07-29 11:20:00+03	2017-07-29 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-29 11:21:00+03	2017-07-29 15:01:00+03
15129	PG0493	2017-08-06 16:50:00+03	2017-08-06 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-06 16:56:00+03	2017-08-06 20:31:00+03
15130	PG0492	2017-08-06 11:20:00+03	2017-08-06 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-06 11:22:00+03	2017-08-06 14:58:00+03
15131	PG0493	2017-07-22 16:50:00+03	2017-07-22 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-22 16:52:00+03	2017-07-22 20:29:00+03
15132	PG0493	2017-08-30 16:50:00+03	2017-08-30 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15133	PG0493	2017-07-25 16:50:00+03	2017-07-25 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-25 16:51:00+03	2017-07-25 20:27:00+03
15134	PG0493	2017-09-05 16:50:00+03	2017-09-05 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15135	PG0492	2017-08-30 11:20:00+03	2017-08-30 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15136	PG0492	2017-09-05 11:20:00+03	2017-09-05 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15137	PG0492	2017-08-20 11:20:00+03	2017-08-20 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15138	PG0492	2017-07-25 11:20:00+03	2017-07-25 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-25 11:21:00+03	2017-07-25 14:56:00+03
15139	PG0493	2017-08-26 16:50:00+03	2017-08-26 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15140	PG0492	2017-08-26 11:20:00+03	2017-08-26 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15141	PG0493	2017-08-20 16:50:00+03	2017-08-20 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15142	PG0493	2017-08-18 16:50:00+03	2017-08-18 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15143	PG0493	2017-08-01 16:50:00+03	2017-08-01 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-01 16:53:00+03	2017-08-01 20:29:00+03
15144	PG0492	2017-08-01 11:20:00+03	2017-08-01 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-01 11:25:00+03	2017-08-01 15:01:00+03
15145	PG0493	2017-07-16 16:50:00+03	2017-07-16 20:25:00+03	PEE	ARH	Arrived	CN1	2017-07-16 16:54:00+03	2017-07-16 20:27:00+03
15146	PG0492	2017-07-16 11:20:00+03	2017-07-16 14:55:00+03	PEE	ARH	Arrived	CN1	2017-07-16 11:22:00+03	2017-07-16 15:01:00+03
15147	PG0493	2017-08-09 16:50:00+03	2017-08-09 20:25:00+03	PEE	ARH	Arrived	CN1	2017-08-09 16:51:00+03	2017-08-09 20:26:00+03
15148	PG0492	2017-08-09 11:20:00+03	2017-08-09 14:55:00+03	PEE	ARH	Arrived	CN1	2017-08-09 11:21:00+03	2017-08-09 14:56:00+03
15149	PG0492	2017-08-17 11:20:00+03	2017-08-17 14:55:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15150	PG0493	2017-08-27 16:50:00+03	2017-08-27 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15151	PG0493	2017-08-17 16:50:00+03	2017-08-17 20:25:00+03	PEE	ARH	Scheduled	CN1	\N	\N
15152	PG0417	2017-07-31 19:50:00+03	2017-07-31 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-31 19:56:00+03	2017-07-31 20:31:00+03
15153	PG0417	2017-08-10 19:50:00+03	2017-08-10 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-10 19:57:00+03	2017-08-10 20:32:00+03
15154	PG0417	2017-08-07 19:50:00+03	2017-08-07 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-07 19:55:00+03	2017-08-07 20:30:00+03
15155	PG0417	2017-07-26 19:50:00+03	2017-07-26 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-26 19:51:00+03	2017-07-26 20:26:00+03
15156	PG0417	2017-08-29 19:50:00+03	2017-08-29 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15157	PG0417	2017-07-23 19:50:00+03	2017-07-23 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-23 19:51:00+03	2017-07-23 20:25:00+03
15158	PG0417	2017-07-17 19:50:00+03	2017-07-17 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-17 19:52:00+03	2017-07-17 20:26:00+03
15159	PG0417	2017-09-02 19:50:00+03	2017-09-02 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15160	PG0417	2017-09-12 19:50:00+03	2017-09-12 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15161	PG0417	2017-09-09 19:50:00+03	2017-09-09 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15162	PG0417	2017-08-28 19:50:00+03	2017-08-28 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15163	PG0417	2017-08-12 19:50:00+03	2017-08-12 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-12 19:53:00+03	2017-08-12 20:28:00+03
15164	PG0417	2017-08-13 19:50:00+03	2017-08-13 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-13 19:52:00+03	2017-08-13 20:27:00+03
15165	PG0417	2017-08-17 19:50:00+03	2017-08-17 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15166	PG0417	2017-07-21 19:50:00+03	2017-07-21 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-21 19:53:00+03	2017-07-21 20:28:00+03
15167	PG0417	2017-08-24 19:50:00+03	2017-08-24 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15168	PG0417	2017-08-22 19:50:00+03	2017-08-22 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15169	PG0417	2017-07-25 19:50:00+03	2017-07-25 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-25 19:52:00+03	2017-07-25 20:27:00+03
15170	PG0417	2017-07-20 19:50:00+03	2017-07-20 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-20 19:50:00+03	2017-07-20 20:25:00+03
15171	PG0417	2017-08-18 19:50:00+03	2017-08-18 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15172	PG0417	2017-08-09 19:50:00+03	2017-08-09 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-09 19:53:00+03	2017-08-09 20:28:00+03
15173	PG0417	2017-07-18 19:50:00+03	2017-07-18 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-18 19:51:00+03	2017-07-18 20:27:00+03
15174	PG0417	2017-08-19 19:50:00+03	2017-08-19 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15175	PG0417	2017-08-15 19:50:00+03	2017-08-15 20:25:00+03	VOZ	DME	On Time	CR2	\N	\N
15176	PG0417	2017-07-22 19:50:00+03	2017-07-22 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-22 19:53:00+03	2017-07-22 20:28:00+03
15177	PG0417	2017-07-16 19:50:00+03	2017-07-16 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-16 19:53:00+03	2017-07-16 20:28:00+03
15178	PG0417	2017-09-06 19:50:00+03	2017-09-06 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15179	PG0417	2017-08-16 19:50:00+03	2017-08-16 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15180	PG0417	2017-09-13 19:50:00+03	2017-09-13 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15181	PG0417	2017-07-19 19:50:00+03	2017-07-19 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-19 19:55:00+03	2017-07-19 20:31:00+03
15182	PG0417	2017-09-08 19:50:00+03	2017-09-08 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15183	PG0417	2017-08-04 19:50:00+03	2017-08-04 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-04 19:52:00+03	2017-08-04 20:27:00+03
15184	PG0417	2017-09-05 19:50:00+03	2017-09-05 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15185	PG0417	2017-08-26 19:50:00+03	2017-08-26 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15186	PG0417	2017-09-10 19:50:00+03	2017-09-10 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15187	PG0417	2017-08-23 19:50:00+03	2017-08-23 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15188	PG0417	2017-09-11 19:50:00+03	2017-09-11 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15189	PG0417	2017-09-07 19:50:00+03	2017-09-07 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15190	PG0417	2017-08-25 19:50:00+03	2017-08-25 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15191	PG0417	2017-09-01 19:50:00+03	2017-09-01 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15192	PG0417	2017-08-30 19:50:00+03	2017-08-30 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15193	PG0417	2017-09-03 19:50:00+03	2017-09-03 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15194	PG0417	2017-07-27 19:50:00+03	2017-07-27 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-27 19:55:00+03	2017-07-27 20:30:00+03
15195	PG0417	2017-07-30 19:50:00+03	2017-07-30 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-30 19:53:00+03	2017-07-30 20:27:00+03
15196	PG0417	2017-08-14 19:50:00+03	2017-08-14 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-14 19:52:00+03	2017-08-14 20:28:00+03
15197	PG0417	2017-08-03 19:50:00+03	2017-08-03 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-03 19:51:00+03	2017-08-03 20:25:00+03
15198	PG0417	2017-07-29 19:50:00+03	2017-07-29 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-29 19:54:00+03	2017-07-29 20:29:00+03
15199	PG0417	2017-08-06 19:50:00+03	2017-08-06 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-06 19:52:00+03	2017-08-06 20:27:00+03
15200	PG0417	2017-08-11 19:50:00+03	2017-08-11 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-11 19:53:00+03	2017-08-11 20:29:00+03
15201	PG0417	2017-08-01 19:50:00+03	2017-08-01 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-01 19:58:00+03	2017-08-01 20:34:00+03
15202	PG0417	2017-08-08 19:50:00+03	2017-08-08 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-08 19:52:00+03	2017-08-08 20:27:00+03
15203	PG0417	2017-08-20 19:50:00+03	2017-08-20 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15204	PG0417	2017-08-31 19:50:00+03	2017-08-31 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15205	PG0417	2017-08-27 19:50:00+03	2017-08-27 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15206	PG0417	2017-08-05 19:50:00+03	2017-08-05 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-05 19:53:00+03	2017-08-05 20:28:00+03
15207	PG0417	2017-08-21 19:50:00+03	2017-08-21 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15208	PG0417	2017-09-14 19:50:00+03	2017-09-14 20:25:00+03	VOZ	DME	Cancelled	CR2	\N	\N
15209	PG0417	2017-07-24 19:50:00+03	2017-07-24 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-24 19:54:00+03	2017-07-24 20:29:00+03
15210	PG0417	2017-09-04 19:50:00+03	2017-09-04 20:25:00+03	VOZ	DME	Scheduled	CR2	\N	\N
15211	PG0417	2017-08-02 19:50:00+03	2017-08-02 20:25:00+03	VOZ	DME	Arrived	CR2	2017-08-02 19:51:00+03	2017-08-02 20:26:00+03
15212	PG0417	2017-07-28 19:50:00+03	2017-07-28 20:25:00+03	VOZ	DME	Arrived	CR2	2017-07-28 19:52:00+03	2017-07-28 20:27:00+03
15213	PG0133	2017-07-22 18:55:00+03	2017-07-22 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-22 18:55:00+03	2017-07-22 20:24:00+03
15214	PG0133	2017-09-09 18:55:00+03	2017-09-09 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15215	PG0133	2017-09-04 18:55:00+03	2017-09-04 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15216	PG0133	2017-08-23 18:55:00+03	2017-08-23 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15217	PG0133	2017-07-28 18:55:00+03	2017-07-28 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-28 18:58:00+03	2017-07-28 20:28:00+03
15218	PG0133	2017-07-17 18:55:00+03	2017-07-17 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-17 18:57:00+03	2017-07-17 20:27:00+03
15219	PG0133	2017-07-29 18:55:00+03	2017-07-29 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-29 22:42:00+03	2017-07-30 00:14:00+03
15220	PG0133	2017-08-09 18:55:00+03	2017-08-09 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-09 18:56:00+03	2017-08-09 20:27:00+03
15221	PG0133	2017-08-15 18:55:00+03	2017-08-15 20:25:00+03	VOZ	LED	On Time	CR2	\N	\N
15222	PG0133	2017-09-06 18:55:00+03	2017-09-06 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15223	PG0133	2017-08-20 18:55:00+03	2017-08-20 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15224	PG0133	2017-08-02 18:55:00+03	2017-08-02 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-02 18:56:00+03	2017-08-02 20:26:00+03
15225	PG0133	2017-08-19 18:55:00+03	2017-08-19 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15226	PG0133	2017-08-26 18:55:00+03	2017-08-26 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15227	PG0133	2017-09-07 18:55:00+03	2017-09-07 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15228	PG0133	2017-08-13 18:55:00+03	2017-08-13 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-13 18:57:00+03	2017-08-13 20:28:00+03
15229	PG0133	2017-08-08 18:55:00+03	2017-08-08 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-08 18:57:00+03	2017-08-08 20:27:00+03
15230	PG0133	2017-08-22 18:55:00+03	2017-08-22 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15231	PG0133	2017-08-31 18:55:00+03	2017-08-31 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15232	PG0133	2017-08-29 18:55:00+03	2017-08-29 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15233	PG0133	2017-08-05 18:55:00+03	2017-08-05 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-05 18:58:00+03	2017-08-05 20:28:00+03
15234	PG0133	2017-08-27 18:55:00+03	2017-08-27 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15235	PG0133	2017-09-10 18:55:00+03	2017-09-10 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15236	PG0133	2017-09-13 18:55:00+03	2017-09-13 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15237	PG0133	2017-08-10 18:55:00+03	2017-08-10 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-10 18:59:00+03	2017-08-10 20:31:00+03
15238	PG0133	2017-07-31 18:55:00+03	2017-07-31 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-31 18:57:00+03	2017-07-31 20:27:00+03
15239	PG0133	2017-08-01 18:55:00+03	2017-08-01 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-01 18:59:00+03	2017-08-01 20:30:00+03
15240	PG0133	2017-09-02 18:55:00+03	2017-09-02 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15241	PG0133	2017-08-25 18:55:00+03	2017-08-25 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15242	PG0133	2017-08-07 18:55:00+03	2017-08-07 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-07 18:57:00+03	2017-08-07 20:28:00+03
15243	PG0133	2017-09-08 18:55:00+03	2017-09-08 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15244	PG0133	2017-07-21 18:55:00+03	2017-07-21 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-21 18:59:00+03	2017-07-21 20:29:00+03
15245	PG0133	2017-08-21 18:55:00+03	2017-08-21 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15246	PG0133	2017-09-11 18:55:00+03	2017-09-11 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15247	PG0133	2017-09-05 18:55:00+03	2017-09-05 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15248	PG0133	2017-08-28 18:55:00+03	2017-08-28 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15249	PG0133	2017-08-30 18:55:00+03	2017-08-30 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15250	PG0133	2017-08-17 18:55:00+03	2017-08-17 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15251	PG0133	2017-07-26 18:55:00+03	2017-07-26 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-26 18:58:00+03	2017-07-26 20:26:00+03
15252	PG0133	2017-09-03 18:55:00+03	2017-09-03 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15253	PG0133	2017-08-18 18:55:00+03	2017-08-18 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15254	PG0133	2017-07-23 18:55:00+03	2017-07-23 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-23 19:00:00+03	2017-07-23 20:29:00+03
15255	PG0133	2017-08-04 18:55:00+03	2017-08-04 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-04 18:58:00+03	2017-08-04 20:28:00+03
15256	PG0133	2017-08-03 18:55:00+03	2017-08-03 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-03 18:57:00+03	2017-08-03 20:25:00+03
15257	PG0133	2017-09-12 18:55:00+03	2017-09-12 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15258	PG0133	2017-07-27 18:55:00+03	2017-07-27 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-27 18:58:00+03	2017-07-27 20:29:00+03
15259	PG0133	2017-07-20 18:55:00+03	2017-07-20 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-20 18:57:00+03	2017-07-20 20:26:00+03
15260	PG0133	2017-08-12 18:55:00+03	2017-08-12 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-12 18:55:00+03	2017-08-12 20:25:00+03
15261	PG0133	2017-08-16 18:55:00+03	2017-08-16 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15262	PG0133	2017-08-06 18:55:00+03	2017-08-06 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-06 18:58:00+03	2017-08-06 20:26:00+03
15263	PG0133	2017-07-30 18:55:00+03	2017-07-30 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-30 18:59:00+03	2017-07-30 20:28:00+03
15264	PG0133	2017-07-16 18:55:00+03	2017-07-16 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-16 18:56:00+03	2017-07-16 20:26:00+03
15265	PG0133	2017-07-18 18:55:00+03	2017-07-18 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-18 18:59:00+03	2017-07-18 20:28:00+03
15266	PG0133	2017-07-25 18:55:00+03	2017-07-25 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-25 18:59:00+03	2017-07-25 20:27:00+03
15267	PG0133	2017-09-14 18:55:00+03	2017-09-14 20:25:00+03	VOZ	LED	Cancelled	CR2	\N	\N
15268	PG0133	2017-07-24 18:55:00+03	2017-07-24 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-24 18:57:00+03	2017-07-24 20:26:00+03
15269	PG0133	2017-08-11 18:55:00+03	2017-08-11 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-11 19:00:00+03	2017-08-11 20:30:00+03
15270	PG0133	2017-07-19 18:55:00+03	2017-07-19 20:25:00+03	VOZ	LED	Arrived	CR2	2017-07-19 18:57:00+03	2017-07-19 20:28:00+03
15271	PG0133	2017-08-24 18:55:00+03	2017-08-24 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15272	PG0133	2017-09-01 18:55:00+03	2017-09-01 20:25:00+03	VOZ	LED	Scheduled	CR2	\N	\N
15273	PG0133	2017-08-14 18:55:00+03	2017-08-14 20:25:00+03	VOZ	LED	Arrived	CR2	2017-08-14 22:18:00+03	2017-08-14 23:49:00+03
15274	PG0397	2017-08-01 19:10:00+03	2017-08-01 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-01 19:10:00+03	2017-08-01 20:21:00+03
15275	PG0397	2017-07-29 19:10:00+03	2017-07-29 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-29 19:10:00+03	2017-07-29 20:20:00+03
15276	PG0397	2017-07-17 19:10:00+03	2017-07-17 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-17 19:11:00+03	2017-07-17 20:21:00+03
15277	PG0397	2017-08-15 19:10:00+03	2017-08-15 20:20:00+03	VOG	VKO	On Time	SU9	\N	\N
15278	PG0397	2017-08-26 19:10:00+03	2017-08-26 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15279	PG0397	2017-08-08 19:10:00+03	2017-08-08 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-08 19:11:00+03	2017-08-08 20:21:00+03
15280	PG0397	2017-07-25 19:10:00+03	2017-07-25 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-25 19:11:00+03	2017-07-25 20:21:00+03
15281	PG0397	2017-08-18 19:10:00+03	2017-08-18 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15282	PG0397	2017-08-16 19:10:00+03	2017-08-16 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15283	PG0397	2017-07-19 19:10:00+03	2017-07-19 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-19 19:13:00+03	2017-07-19 20:23:00+03
15284	PG0397	2017-07-31 19:10:00+03	2017-07-31 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-31 19:12:00+03	2017-07-31 20:21:00+03
15285	PG0397	2017-08-17 19:10:00+03	2017-08-17 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15286	PG0397	2017-07-30 19:10:00+03	2017-07-30 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-30 19:14:00+03	2017-07-30 20:24:00+03
15287	PG0397	2017-09-02 19:10:00+03	2017-09-02 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15288	PG0397	2017-09-14 19:10:00+03	2017-09-14 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15289	PG0397	2017-07-23 19:10:00+03	2017-07-23 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-23 19:12:00+03	2017-07-23 20:23:00+03
15290	PG0397	2017-07-27 19:10:00+03	2017-07-27 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-27 19:13:00+03	2017-07-27 20:23:00+03
15291	PG0397	2017-09-05 19:10:00+03	2017-09-05 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15292	PG0397	2017-08-25 19:10:00+03	2017-08-25 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15293	PG0397	2017-07-21 19:10:00+03	2017-07-21 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-21 19:15:00+03	2017-07-21 20:25:00+03
15294	PG0397	2017-08-12 19:10:00+03	2017-08-12 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-12 19:11:00+03	2017-08-12 20:20:00+03
15295	PG0397	2017-08-10 19:10:00+03	2017-08-10 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-10 19:11:00+03	2017-08-10 20:22:00+03
15296	PG0397	2017-07-22 19:10:00+03	2017-07-22 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-22 22:43:00+03	2017-07-22 23:53:00+03
15297	PG0397	2017-07-24 19:10:00+03	2017-07-24 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-24 19:11:00+03	2017-07-24 20:21:00+03
15298	PG0397	2017-07-18 19:10:00+03	2017-07-18 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-18 19:10:00+03	2017-07-18 20:20:00+03
15299	PG0397	2017-08-20 19:10:00+03	2017-08-20 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15300	PG0397	2017-08-27 19:10:00+03	2017-08-27 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15301	PG0397	2017-09-07 19:10:00+03	2017-09-07 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15302	PG0397	2017-07-16 19:10:00+03	2017-07-16 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-16 19:12:00+03	2017-07-16 20:22:00+03
15303	PG0397	2017-09-04 19:10:00+03	2017-09-04 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15304	PG0397	2017-07-26 19:10:00+03	2017-07-26 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-26 19:12:00+03	2017-07-26 20:22:00+03
15305	PG0397	2017-07-20 19:10:00+03	2017-07-20 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-20 19:11:00+03	2017-07-20 20:20:00+03
15306	PG0397	2017-09-11 19:10:00+03	2017-09-11 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15307	PG0397	2017-08-05 19:10:00+03	2017-08-05 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-05 19:11:00+03	2017-08-05 20:21:00+03
15308	PG0397	2017-08-21 19:10:00+03	2017-08-21 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15309	PG0397	2017-09-06 19:10:00+03	2017-09-06 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15310	PG0397	2017-08-22 19:10:00+03	2017-08-22 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15311	PG0397	2017-09-10 19:10:00+03	2017-09-10 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15312	PG0397	2017-08-06 19:10:00+03	2017-08-06 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-06 22:02:00+03	2017-08-06 23:11:00+03
15313	PG0397	2017-08-09 19:10:00+03	2017-08-09 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-09 19:13:00+03	2017-08-09 20:23:00+03
15314	PG0397	2017-09-01 19:10:00+03	2017-09-01 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15315	PG0397	2017-08-11 19:10:00+03	2017-08-11 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-11 19:17:00+03	2017-08-11 20:26:00+03
15316	PG0397	2017-08-28 19:10:00+03	2017-08-28 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15317	PG0397	2017-09-12 19:10:00+03	2017-09-12 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15318	PG0397	2017-09-13 19:10:00+03	2017-09-13 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15319	PG0397	2017-09-08 19:10:00+03	2017-09-08 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15320	PG0397	2017-08-14 19:10:00+03	2017-08-14 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-14 19:12:00+03	2017-08-14 20:22:00+03
15321	PG0397	2017-08-24 19:10:00+03	2017-08-24 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15322	PG0397	2017-08-29 19:10:00+03	2017-08-29 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15323	PG0397	2017-08-03 19:10:00+03	2017-08-03 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-03 19:12:00+03	2017-08-03 20:21:00+03
15324	PG0397	2017-08-31 19:10:00+03	2017-08-31 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15325	PG0397	2017-08-19 19:10:00+03	2017-08-19 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15326	PG0397	2017-08-30 19:10:00+03	2017-08-30 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15327	PG0397	2017-08-23 19:10:00+03	2017-08-23 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15328	PG0397	2017-08-04 19:10:00+03	2017-08-04 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-04 19:13:00+03	2017-08-04 20:23:00+03
15329	PG0397	2017-09-09 19:10:00+03	2017-09-09 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15330	PG0397	2017-08-07 19:10:00+03	2017-08-07 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-07 19:12:00+03	2017-08-07 20:23:00+03
15331	PG0397	2017-07-28 19:10:00+03	2017-07-28 20:20:00+03	VOG	VKO	Arrived	SU9	2017-07-28 22:28:00+03	2017-07-28 23:38:00+03
15332	PG0397	2017-08-02 19:10:00+03	2017-08-02 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-02 19:13:00+03	2017-08-02 20:22:00+03
15333	PG0397	2017-08-13 19:10:00+03	2017-08-13 20:20:00+03	VOG	VKO	Arrived	SU9	2017-08-13 19:11:00+03	2017-08-13 20:21:00+03
15334	PG0397	2017-09-03 19:10:00+03	2017-09-03 20:20:00+03	VOG	VKO	Scheduled	SU9	\N	\N
15335	PG0175	2017-09-13 16:30:00+03	2017-09-13 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15336	PG0175	2017-08-12 16:30:00+03	2017-08-12 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-12 16:31:00+03	2017-08-12 17:45:00+03
15337	PG0175	2017-09-04 16:30:00+03	2017-09-04 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15338	PG0175	2017-08-15 16:30:00+03	2017-08-15 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-15 16:37:00+03	2017-08-15 17:51:00+03
15339	PG0175	2017-08-18 16:30:00+03	2017-08-18 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15340	PG0175	2017-08-16 16:30:00+03	2017-08-16 17:45:00+03	VOG	SVO	On Time	SU9	\N	\N
15341	PG0175	2017-08-29 16:30:00+03	2017-08-29 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15342	PG0175	2017-09-08 16:30:00+03	2017-09-08 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15343	PG0175	2017-08-14 16:30:00+03	2017-08-14 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-14 16:32:00+03	2017-08-14 17:46:00+03
15344	PG0175	2017-08-03 16:30:00+03	2017-08-03 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-03 16:32:00+03	2017-08-03 17:46:00+03
15345	PG0175	2017-07-16 16:30:00+03	2017-07-16 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-16 16:31:00+03	2017-07-16 17:47:00+03
15346	PG0175	2017-07-27 16:30:00+03	2017-07-27 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-27 19:34:00+03	2017-07-27 20:50:00+03
15347	PG0175	2017-08-21 16:30:00+03	2017-08-21 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15348	PG0175	2017-08-07 16:30:00+03	2017-08-07 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-07 16:31:00+03	2017-08-07 17:46:00+03
15349	PG0175	2017-07-17 16:30:00+03	2017-07-17 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-17 16:36:00+03	2017-07-17 17:51:00+03
15350	PG0175	2017-07-28 16:30:00+03	2017-07-28 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-28 19:57:00+03	2017-07-28 21:13:00+03
15351	PG0175	2017-07-22 16:30:00+03	2017-07-22 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-22 16:34:00+03	2017-07-22 17:49:00+03
15352	PG0175	2017-08-26 16:30:00+03	2017-08-26 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15353	PG0175	2017-09-03 16:30:00+03	2017-09-03 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15354	PG0175	2017-08-28 16:30:00+03	2017-08-28 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15355	PG0175	2017-08-19 16:30:00+03	2017-08-19 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15356	PG0175	2017-08-06 16:30:00+03	2017-08-06 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-06 16:31:00+03	2017-08-06 17:45:00+03
15357	PG0175	2017-09-01 16:30:00+03	2017-09-01 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15358	PG0175	2017-07-18 16:30:00+03	2017-07-18 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-18 16:34:00+03	2017-07-18 17:49:00+03
15359	PG0175	2017-09-05 16:30:00+03	2017-09-05 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15360	PG0175	2017-07-21 16:30:00+03	2017-07-21 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-21 16:35:00+03	2017-07-21 17:49:00+03
15361	PG0175	2017-09-09 16:30:00+03	2017-09-09 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15362	PG0175	2017-09-14 16:30:00+03	2017-09-14 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15363	PG0175	2017-08-17 16:30:00+03	2017-08-17 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15364	PG0175	2017-08-27 16:30:00+03	2017-08-27 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15365	PG0175	2017-08-02 16:30:00+03	2017-08-02 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-02 16:35:00+03	2017-08-02 17:51:00+03
15366	PG0175	2017-08-13 16:30:00+03	2017-08-13 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-13 16:35:00+03	2017-08-13 17:50:00+03
15367	PG0175	2017-07-31 16:30:00+03	2017-07-31 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-31 16:33:00+03	2017-07-31 17:48:00+03
15368	PG0175	2017-07-20 16:30:00+03	2017-07-20 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-20 16:32:00+03	2017-07-20 17:47:00+03
15369	PG0175	2017-09-07 16:30:00+03	2017-09-07 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15370	PG0175	2017-08-25 16:30:00+03	2017-08-25 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15371	PG0175	2017-08-24 16:30:00+03	2017-08-24 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15372	PG0175	2017-08-30 16:30:00+03	2017-08-30 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15373	PG0175	2017-09-06 16:30:00+03	2017-09-06 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15374	PG0175	2017-07-29 16:30:00+03	2017-07-29 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-29 16:33:00+03	2017-07-29 17:49:00+03
15375	PG0175	2017-09-11 16:30:00+03	2017-09-11 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15376	PG0175	2017-08-10 16:30:00+03	2017-08-10 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-10 16:31:00+03	2017-08-10 17:47:00+03
15377	PG0175	2017-07-24 16:30:00+03	2017-07-24 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-24 16:32:00+03	2017-07-24 17:47:00+03
15378	PG0175	2017-08-09 16:30:00+03	2017-08-09 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-09 16:34:00+03	2017-08-09 17:48:00+03
15379	PG0175	2017-08-08 16:30:00+03	2017-08-08 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-08 16:36:00+03	2017-08-08 17:50:00+03
15380	PG0175	2017-08-20 16:30:00+03	2017-08-20 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15381	PG0175	2017-09-10 16:30:00+03	2017-09-10 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15382	PG0175	2017-08-04 16:30:00+03	2017-08-04 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-04 16:33:00+03	2017-08-04 17:50:00+03
15383	PG0175	2017-09-02 16:30:00+03	2017-09-02 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15384	PG0175	2017-08-11 16:30:00+03	2017-08-11 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-11 16:33:00+03	2017-08-11 17:48:00+03
15385	PG0175	2017-07-30 16:30:00+03	2017-07-30 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-30 16:34:00+03	2017-07-30 17:49:00+03
15386	PG0175	2017-09-12 16:30:00+03	2017-09-12 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15387	PG0175	2017-08-01 16:30:00+03	2017-08-01 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-01 16:31:00+03	2017-08-01 17:46:00+03
15388	PG0175	2017-08-05 16:30:00+03	2017-08-05 17:45:00+03	VOG	SVO	Arrived	SU9	2017-08-05 19:32:00+03	2017-08-05 20:47:00+03
15389	PG0175	2017-07-23 16:30:00+03	2017-07-23 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-23 16:32:00+03	2017-07-23 17:46:00+03
15390	PG0175	2017-07-25 16:30:00+03	2017-07-25 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-25 16:31:00+03	2017-07-25 17:45:00+03
15391	PG0175	2017-07-26 16:30:00+03	2017-07-26 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-26 19:34:00+03	2017-07-26 20:49:00+03
15392	PG0175	2017-07-19 16:30:00+03	2017-07-19 17:45:00+03	VOG	SVO	Arrived	SU9	2017-07-19 16:33:00+03	2017-07-19 17:49:00+03
15393	PG0175	2017-08-23 16:30:00+03	2017-08-23 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15394	PG0175	2017-08-22 16:30:00+03	2017-08-22 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15395	PG0175	2017-08-31 16:30:00+03	2017-08-31 17:45:00+03	VOG	SVO	Scheduled	SU9	\N	\N
15396	PG0185	2017-08-20 13:35:00+03	2017-08-20 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15397	PG0185	2017-07-16 13:35:00+03	2017-07-16 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-16 13:38:00+03	2017-07-16 15:28:00+03
15398	PG0185	2017-07-17 13:35:00+03	2017-07-17 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-17 13:41:00+03	2017-07-17 15:31:00+03
15399	PG0185	2017-09-14 13:35:00+03	2017-09-14 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15400	PG0185	2017-07-18 13:35:00+03	2017-07-18 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-18 13:40:00+03	2017-07-18 15:30:00+03
15401	PG0185	2017-07-19 13:35:00+03	2017-07-19 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-19 13:38:00+03	2017-07-19 15:28:00+03
15402	PG0185	2017-09-13 13:35:00+03	2017-09-13 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15403	PG0185	2017-07-20 13:35:00+03	2017-07-20 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-20 13:39:00+03	2017-07-20 15:31:00+03
15404	PG0185	2017-07-21 13:35:00+03	2017-07-21 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-21 13:41:00+03	2017-07-21 15:32:00+03
15405	PG0185	2017-09-12 13:35:00+03	2017-09-12 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15406	PG0185	2017-07-22 13:35:00+03	2017-07-22 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-22 13:37:00+03	2017-07-22 15:27:00+03
15407	PG0185	2017-07-23 13:35:00+03	2017-07-23 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-23 13:43:00+03	2017-07-23 15:33:00+03
15408	PG0185	2017-09-11 13:35:00+03	2017-09-11 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15409	PG0185	2017-07-24 13:35:00+03	2017-07-24 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-24 13:42:00+03	2017-07-24 15:32:00+03
15410	PG0185	2017-07-25 13:35:00+03	2017-07-25 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-25 13:36:00+03	2017-07-25 15:27:00+03
15411	PG0185	2017-09-10 13:35:00+03	2017-09-10 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15412	PG0185	2017-07-26 13:35:00+03	2017-07-26 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-26 13:38:00+03	2017-07-26 15:29:00+03
15413	PG0185	2017-07-27 13:35:00+03	2017-07-27 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-27 13:39:00+03	2017-07-27 15:28:00+03
15414	PG0185	2017-09-09 13:35:00+03	2017-09-09 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15415	PG0185	2017-07-28 13:35:00+03	2017-07-28 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-28 13:37:00+03	2017-07-28 15:27:00+03
15416	PG0185	2017-07-29 13:35:00+03	2017-07-29 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-29 13:40:00+03	2017-07-29 15:30:00+03
15417	PG0185	2017-09-08 13:35:00+03	2017-09-08 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15418	PG0185	2017-07-30 13:35:00+03	2017-07-30 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-30 13:37:00+03	2017-07-30 15:27:00+03
15419	PG0185	2017-09-07 13:35:00+03	2017-09-07 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15420	PG0185	2017-07-31 13:35:00+03	2017-07-31 15:25:00+03	VOG	CEK	Arrived	SU9	2017-07-31 13:37:00+03	2017-07-31 15:27:00+03
15421	PG0185	2017-08-01 13:35:00+03	2017-08-01 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-01 13:39:00+03	2017-08-01 15:30:00+03
15422	PG0185	2017-09-06 13:35:00+03	2017-09-06 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15423	PG0185	2017-08-02 13:35:00+03	2017-08-02 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-02 13:38:00+03	2017-08-02 15:29:00+03
15424	PG0185	2017-08-03 13:35:00+03	2017-08-03 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-03 17:08:00+03	2017-08-03 18:58:00+03
15425	PG0185	2017-09-05 13:35:00+03	2017-09-05 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15426	PG0185	2017-08-04 13:35:00+03	2017-08-04 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-04 17:12:00+03	2017-08-04 19:03:00+03
15427	PG0185	2017-08-05 13:35:00+03	2017-08-05 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-05 13:38:00+03	2017-08-05 15:28:00+03
15428	PG0185	2017-09-04 13:35:00+03	2017-09-04 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15429	PG0185	2017-08-06 13:35:00+03	2017-08-06 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-06 13:38:00+03	2017-08-06 15:28:00+03
15430	PG0185	2017-08-07 13:35:00+03	2017-08-07 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-07 13:40:00+03	2017-08-07 15:30:00+03
15431	PG0185	2017-09-03 13:35:00+03	2017-09-03 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15432	PG0185	2017-08-08 13:35:00+03	2017-08-08 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-08 13:37:00+03	2017-08-08 15:29:00+03
15433	PG0185	2017-08-09 13:35:00+03	2017-08-09 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-09 13:40:00+03	2017-08-09 15:31:00+03
15434	PG0185	2017-09-02 13:35:00+03	2017-09-02 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15435	PG0185	2017-08-10 13:35:00+03	2017-08-10 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-10 13:37:00+03	2017-08-10 15:28:00+03
15436	PG0185	2017-08-11 13:35:00+03	2017-08-11 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-11 13:36:00+03	2017-08-11 15:25:00+03
15437	PG0185	2017-09-01 13:35:00+03	2017-09-01 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15438	PG0185	2017-08-12 13:35:00+03	2017-08-12 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-12 13:42:00+03	2017-08-12 15:32:00+03
15439	PG0185	2017-08-13 13:35:00+03	2017-08-13 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-13 13:40:00+03	2017-08-13 15:30:00+03
15440	PG0185	2017-08-31 13:35:00+03	2017-08-31 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15441	PG0185	2017-08-14 13:35:00+03	2017-08-14 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-14 13:39:00+03	2017-08-14 15:30:00+03
15442	PG0185	2017-08-15 13:35:00+03	2017-08-15 15:25:00+03	VOG	CEK	Arrived	SU9	2017-08-15 13:36:00+03	2017-08-15 15:26:00+03
15443	PG0185	2017-08-30 13:35:00+03	2017-08-30 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15444	PG0185	2017-08-16 13:35:00+03	2017-08-16 15:25:00+03	VOG	CEK	On Time	SU9	\N	\N
15445	PG0185	2017-08-17 13:35:00+03	2017-08-17 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15446	PG0185	2017-08-29 13:35:00+03	2017-08-29 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15447	PG0185	2017-08-18 13:35:00+03	2017-08-18 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15448	PG0185	2017-08-19 13:35:00+03	2017-08-19 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15449	PG0185	2017-08-28 13:35:00+03	2017-08-28 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15450	PG0185	2017-08-21 13:35:00+03	2017-08-21 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15451	PG0185	2017-08-27 13:35:00+03	2017-08-27 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15452	PG0185	2017-08-22 13:35:00+03	2017-08-22 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15453	PG0185	2017-08-23 13:35:00+03	2017-08-23 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15454	PG0185	2017-08-26 13:35:00+03	2017-08-26 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15455	PG0185	2017-08-24 13:35:00+03	2017-08-24 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15456	PG0185	2017-08-25 13:35:00+03	2017-08-25 15:25:00+03	VOG	CEK	Scheduled	SU9	\N	\N
15457	PG0308	2017-08-17 15:35:00+03	2017-08-17 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15458	PG0308	2017-07-21 15:35:00+03	2017-07-21 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-21 15:38:00+03	2017-07-21 16:08:00+03
15459	PG0308	2017-09-05 15:35:00+03	2017-09-05 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15460	PG0308	2017-09-12 15:35:00+03	2017-09-12 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15461	PG0308	2017-08-03 15:35:00+03	2017-08-03 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-03 15:37:00+03	2017-08-03 16:07:00+03
15462	PG0308	2017-07-27 15:35:00+03	2017-07-27 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-27 15:38:00+03	2017-07-27 16:08:00+03
15463	PG0308	2017-09-06 15:35:00+03	2017-09-06 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15464	PG0308	2017-08-10 15:35:00+03	2017-08-10 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-10 15:39:00+03	2017-08-10 16:09:00+03
15465	PG0308	2017-08-21 15:35:00+03	2017-08-21 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15466	PG0308	2017-08-26 15:35:00+03	2017-08-26 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15467	PG0308	2017-08-02 15:35:00+03	2017-08-02 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-02 15:39:00+03	2017-08-02 16:09:00+03
15468	PG0308	2017-07-20 15:35:00+03	2017-07-20 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-20 15:38:00+03	2017-07-20 16:08:00+03
15469	PG0308	2017-07-16 15:35:00+03	2017-07-16 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-16 15:38:00+03	2017-07-16 16:08:00+03
15470	PG0308	2017-08-23 15:35:00+03	2017-08-23 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15471	PG0308	2017-09-03 15:35:00+03	2017-09-03 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15472	PG0308	2017-08-11 15:35:00+03	2017-08-11 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-11 15:37:00+03	2017-08-11 16:07:00+03
15473	PG0308	2017-07-28 15:35:00+03	2017-07-28 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-28 15:36:00+03	2017-07-28 16:06:00+03
15474	PG0308	2017-07-24 15:35:00+03	2017-07-24 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-24 15:40:00+03	2017-07-24 16:10:00+03
15475	PG0308	2017-08-07 15:35:00+03	2017-08-07 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-07 15:38:00+03	2017-08-07 16:08:00+03
15476	PG0308	2017-09-08 15:35:00+03	2017-09-08 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15477	PG0308	2017-08-27 15:35:00+03	2017-08-27 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15478	PG0308	2017-07-17 15:35:00+03	2017-07-17 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-17 15:37:00+03	2017-07-17 16:07:00+03
15479	PG0308	2017-09-09 15:35:00+03	2017-09-09 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15480	PG0308	2017-08-25 15:35:00+03	2017-08-25 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15481	PG0308	2017-08-24 15:35:00+03	2017-08-24 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15482	PG0308	2017-07-29 15:35:00+03	2017-07-29 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-29 15:36:00+03	2017-07-29 16:05:00+03
15483	PG0308	2017-08-20 15:35:00+03	2017-08-20 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15484	PG0308	2017-09-14 15:35:00+03	2017-09-14 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15485	PG0308	2017-08-30 15:35:00+03	2017-08-30 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15486	PG0308	2017-07-23 15:35:00+03	2017-07-23 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-23 15:36:00+03	2017-07-23 16:07:00+03
15487	PG0308	2017-09-01 15:35:00+03	2017-09-01 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15488	PG0308	2017-08-19 15:35:00+03	2017-08-19 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15489	PG0308	2017-08-06 15:35:00+03	2017-08-06 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-06 15:38:00+03	2017-08-06 16:08:00+03
15490	PG0308	2017-08-16 15:35:00+03	2017-08-16 16:05:00+03	VOG	ROV	On Time	SU9	\N	\N
15491	PG0308	2017-08-13 15:35:00+03	2017-08-13 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-13 15:37:00+03	2017-08-13 16:07:00+03
15492	PG0308	2017-08-31 15:35:00+03	2017-08-31 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15493	PG0308	2017-08-28 15:35:00+03	2017-08-28 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15494	PG0308	2017-09-11 15:35:00+03	2017-09-11 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15495	PG0308	2017-07-30 15:35:00+03	2017-07-30 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-30 15:44:00+03	2017-07-30 16:14:00+03
15496	PG0308	2017-08-14 15:35:00+03	2017-08-14 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-14 15:36:00+03	2017-08-14 16:05:00+03
15497	PG0308	2017-09-07 15:35:00+03	2017-09-07 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15498	PG0308	2017-09-04 15:35:00+03	2017-09-04 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15499	PG0308	2017-07-25 15:35:00+03	2017-07-25 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-25 15:36:00+03	2017-07-25 16:06:00+03
15500	PG0308	2017-07-18 15:35:00+03	2017-07-18 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-18 15:41:00+03	2017-07-18 16:11:00+03
15501	PG0308	2017-08-22 15:35:00+03	2017-08-22 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15502	PG0308	2017-09-02 15:35:00+03	2017-09-02 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15503	PG0308	2017-08-05 15:35:00+03	2017-08-05 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-05 15:38:00+03	2017-08-05 16:08:00+03
15504	PG0308	2017-09-10 15:35:00+03	2017-09-10 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15505	PG0308	2017-08-15 15:35:00+03	2017-08-15 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-15 15:37:00+03	2017-08-15 16:08:00+03
15506	PG0308	2017-07-22 15:35:00+03	2017-07-22 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-22 15:42:00+03	2017-07-22 16:12:00+03
15507	PG0308	2017-08-08 15:35:00+03	2017-08-08 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-08 15:36:00+03	2017-08-08 16:07:00+03
15508	PG0308	2017-08-04 15:35:00+03	2017-08-04 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-04 15:35:00+03	2017-08-04 16:05:00+03
15509	PG0308	2017-08-09 15:35:00+03	2017-08-09 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-09 15:37:00+03	2017-08-09 16:06:00+03
15510	PG0308	2017-08-29 15:35:00+03	2017-08-29 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15511	PG0308	2017-07-31 15:35:00+03	2017-07-31 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-31 15:40:00+03	2017-07-31 16:10:00+03
15512	PG0308	2017-07-26 15:35:00+03	2017-07-26 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-26 15:39:00+03	2017-07-26 16:09:00+03
15513	PG0308	2017-08-12 15:35:00+03	2017-08-12 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-12 15:42:00+03	2017-08-12 16:12:00+03
15514	PG0308	2017-09-13 15:35:00+03	2017-09-13 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15515	PG0308	2017-07-19 15:35:00+03	2017-07-19 16:05:00+03	VOG	ROV	Arrived	SU9	2017-07-19 15:42:00+03	2017-07-19 16:12:00+03
15516	PG0308	2017-08-01 15:35:00+03	2017-08-01 16:05:00+03	VOG	ROV	Arrived	SU9	2017-08-01 15:36:00+03	2017-08-01 16:06:00+03
15517	PG0308	2017-08-18 15:35:00+03	2017-08-18 16:05:00+03	VOG	ROV	Scheduled	SU9	\N	\N
15518	PG0695	2017-07-24 09:05:00+03	2017-07-24 12:55:00+03	VOG	TOF	Arrived	SU9	2017-07-24 09:08:00+03	2017-07-24 13:00:00+03
15519	PG0695	2017-08-07 09:05:00+03	2017-08-07 12:55:00+03	VOG	TOF	Arrived	SU9	2017-08-07 09:10:00+03	2017-08-07 13:03:00+03
15520	PG0695	2017-08-21 09:05:00+03	2017-08-21 12:55:00+03	VOG	TOF	Scheduled	SU9	\N	\N
15521	PG0695	2017-09-04 09:05:00+03	2017-09-04 12:55:00+03	VOG	TOF	Scheduled	SU9	\N	\N
15522	PG0695	2017-08-28 09:05:00+03	2017-08-28 12:55:00+03	VOG	TOF	Scheduled	SU9	\N	\N
15523	PG0695	2017-07-17 09:05:00+03	2017-07-17 12:55:00+03	VOG	TOF	Arrived	SU9	2017-07-17 09:08:00+03	2017-07-17 12:56:00+03
15524	PG0695	2017-08-14 09:05:00+03	2017-08-14 12:55:00+03	VOG	TOF	Arrived	SU9	2017-08-14 09:08:00+03	2017-08-14 12:57:00+03
15525	PG0695	2017-09-11 09:05:00+03	2017-09-11 12:55:00+03	VOG	TOF	Cancelled	SU9	\N	\N
15526	PG0695	2017-07-31 09:05:00+03	2017-07-31 12:55:00+03	VOG	TOF	Arrived	SU9	2017-07-31 09:11:00+03	2017-07-31 12:59:00+03
15527	PG0665	2017-08-04 13:40:00+03	2017-08-04 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-04 13:46:00+03	2017-08-04 16:29:00+03
15528	PG0665	2017-08-20 13:40:00+03	2017-08-20 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15529	PG0665	2017-08-31 13:40:00+03	2017-08-31 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15530	PG0665	2017-08-28 13:40:00+03	2017-08-28 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15531	PG0665	2017-08-26 13:40:00+03	2017-08-26 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15532	PG0665	2017-08-13 13:40:00+03	2017-08-13 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-13 13:45:00+03	2017-08-13 16:28:00+03
15533	PG0665	2017-07-24 13:40:00+03	2017-07-24 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-24 16:51:00+03	2017-07-24 19:38:00+03
15534	PG0665	2017-09-04 13:40:00+03	2017-09-04 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15535	PG0665	2017-07-19 13:40:00+03	2017-07-19 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-19 13:43:00+03	2017-07-19 16:25:00+03
15536	PG0665	2017-07-27 13:40:00+03	2017-07-27 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-27 13:45:00+03	2017-07-27 16:30:00+03
15537	PG0665	2017-09-06 13:40:00+03	2017-09-06 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15538	PG0665	2017-08-01 13:40:00+03	2017-08-01 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-01 13:45:00+03	2017-08-01 16:29:00+03
15539	PG0665	2017-08-02 13:40:00+03	2017-08-02 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-02 13:49:00+03	2017-08-02 16:36:00+03
15540	PG0665	2017-09-01 13:40:00+03	2017-09-01 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15541	PG0665	2017-07-20 13:40:00+03	2017-07-20 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-20 13:42:00+03	2017-07-20 16:26:00+03
15542	PG0665	2017-09-05 13:40:00+03	2017-09-05 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15543	PG0665	2017-07-18 13:40:00+03	2017-07-18 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-18 13:42:00+03	2017-07-18 16:26:00+03
15544	PG0665	2017-08-17 13:40:00+03	2017-08-17 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15545	PG0665	2017-09-14 13:40:00+03	2017-09-14 16:25:00+03	VOG	CSY	Cancelled	CN1	\N	\N
15546	PG0665	2017-08-22 13:40:00+03	2017-08-22 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15547	PG0665	2017-07-22 13:40:00+03	2017-07-22 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-22 13:42:00+03	2017-07-22 16:24:00+03
15548	PG0665	2017-08-27 13:40:00+03	2017-08-27 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15549	PG0665	2017-08-05 13:40:00+03	2017-08-05 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-05 13:41:00+03	2017-08-05 16:25:00+03
15550	PG0665	2017-09-12 13:40:00+03	2017-09-12 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15551	PG0665	2017-08-07 13:40:00+03	2017-08-07 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-07 13:42:00+03	2017-08-07 16:29:00+03
15552	PG0665	2017-09-08 13:40:00+03	2017-09-08 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15553	PG0665	2017-07-16 13:40:00+03	2017-07-16 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-16 13:45:00+03	2017-07-16 16:30:00+03
15554	PG0665	2017-07-31 13:40:00+03	2017-07-31 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-31 13:43:00+03	2017-07-31 16:26:00+03
15555	PG0665	2017-09-11 13:40:00+03	2017-09-11 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15556	PG0665	2017-08-23 13:40:00+03	2017-08-23 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15557	PG0665	2017-08-25 13:40:00+03	2017-08-25 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15558	PG0665	2017-08-19 13:40:00+03	2017-08-19 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15559	PG0665	2017-07-26 13:40:00+03	2017-07-26 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-26 13:41:00+03	2017-07-26 16:26:00+03
15560	PG0665	2017-08-15 13:40:00+03	2017-08-15 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-15 13:42:00+03	2017-08-15 16:27:00+03
15561	PG0665	2017-09-02 13:40:00+03	2017-09-02 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15562	PG0665	2017-09-10 13:40:00+03	2017-09-10 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15563	PG0665	2017-08-24 13:40:00+03	2017-08-24 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15564	PG0665	2017-07-23 13:40:00+03	2017-07-23 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-23 13:41:00+03	2017-07-23 16:29:00+03
15565	PG0665	2017-08-21 13:40:00+03	2017-08-21 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15566	PG0665	2017-07-28 13:40:00+03	2017-07-28 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-28 13:42:00+03	2017-07-28 16:27:00+03
15567	PG0665	2017-08-08 13:40:00+03	2017-08-08 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-08 13:44:00+03	2017-08-08 16:30:00+03
15568	PG0665	2017-07-21 13:40:00+03	2017-07-21 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-21 13:42:00+03	2017-07-21 16:25:00+03
15569	PG0665	2017-09-09 13:40:00+03	2017-09-09 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15570	PG0665	2017-08-18 13:40:00+03	2017-08-18 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15571	PG0665	2017-08-14 13:40:00+03	2017-08-14 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-14 13:46:00+03	2017-08-14 16:31:00+03
15572	PG0665	2017-08-09 13:40:00+03	2017-08-09 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-09 13:41:00+03	2017-08-09 16:27:00+03
15573	PG0665	2017-08-06 13:40:00+03	2017-08-06 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-06 13:44:00+03	2017-08-06 16:29:00+03
15574	PG0665	2017-09-13 13:40:00+03	2017-09-13 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15575	PG0665	2017-08-03 13:40:00+03	2017-08-03 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-03 13:41:00+03	2017-08-03 16:26:00+03
15576	PG0665	2017-08-12 13:40:00+03	2017-08-12 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-12 13:42:00+03	2017-08-12 16:26:00+03
15577	PG0665	2017-08-11 13:40:00+03	2017-08-11 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-11 13:43:00+03	2017-08-11 16:26:00+03
15578	PG0665	2017-09-07 13:40:00+03	2017-09-07 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15579	PG0665	2017-07-17 13:40:00+03	2017-07-17 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-17 13:42:00+03	2017-07-17 16:30:00+03
15580	PG0665	2017-09-03 13:40:00+03	2017-09-03 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15581	PG0665	2017-08-10 13:40:00+03	2017-08-10 16:25:00+03	VOG	CSY	Arrived	CN1	2017-08-10 13:44:00+03	2017-08-10 16:30:00+03
15582	PG0665	2017-07-25 13:40:00+03	2017-07-25 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-25 13:41:00+03	2017-07-25 16:29:00+03
15583	PG0665	2017-07-29 13:40:00+03	2017-07-29 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-29 13:45:00+03	2017-07-29 16:33:00+03
15584	PG0665	2017-07-30 13:40:00+03	2017-07-30 16:25:00+03	VOG	CSY	Arrived	CN1	2017-07-30 13:45:00+03	2017-07-30 16:29:00+03
15585	PG0665	2017-08-30 13:40:00+03	2017-08-30 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15586	PG0665	2017-08-16 13:40:00+03	2017-08-16 16:25:00+03	VOG	CSY	On Time	CN1	\N	\N
15587	PG0665	2017-08-29 13:40:00+03	2017-08-29 16:25:00+03	VOG	CSY	Scheduled	CN1	\N	\N
15588	PG0415	2017-09-01 14:05:00+03	2017-09-01 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15589	PG0415	2017-07-25 14:05:00+03	2017-07-25 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-25 14:07:00+03	2017-07-25 16:11:00+03
15590	PG0415	2017-09-09 14:05:00+03	2017-09-09 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15591	PG0415	2017-07-26 14:05:00+03	2017-07-26 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-26 14:09:00+03	2017-07-26 16:13:00+03
15592	PG0415	2017-08-27 14:05:00+03	2017-08-27 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15593	PG0415	2017-08-25 14:05:00+03	2017-08-25 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15594	PG0415	2017-08-07 14:05:00+03	2017-08-07 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-07 14:09:00+03	2017-08-07 16:14:00+03
15595	PG0415	2017-09-03 14:05:00+03	2017-09-03 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15596	PG0415	2017-08-13 14:05:00+03	2017-08-13 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-13 14:06:00+03	2017-08-13 16:12:00+03
15597	PG0415	2017-08-24 14:05:00+03	2017-08-24 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15598	PG0415	2017-08-09 14:05:00+03	2017-08-09 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-09 14:10:00+03	2017-08-09 16:12:00+03
15599	PG0415	2017-07-17 14:05:00+03	2017-07-17 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-17 14:07:00+03	2017-07-17 16:14:00+03
15600	PG0415	2017-08-31 14:05:00+03	2017-08-31 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15601	PG0415	2017-08-06 14:05:00+03	2017-08-06 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-06 14:08:00+03	2017-08-06 16:13:00+03
15602	PG0415	2017-08-16 14:05:00+03	2017-08-16 16:10:00+03	MMK	VKO	On Time	CR2	\N	\N
15603	PG0415	2017-08-05 14:05:00+03	2017-08-05 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-05 14:09:00+03	2017-08-05 16:17:00+03
15604	PG0415	2017-07-18 14:05:00+03	2017-07-18 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-18 14:12:00+03	2017-07-18 16:17:00+03
15605	PG0415	2017-09-04 14:05:00+03	2017-09-04 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15606	PG0415	2017-08-08 14:05:00+03	2017-08-08 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-08 14:07:00+03	2017-08-08 16:11:00+03
15607	PG0415	2017-08-29 14:05:00+03	2017-08-29 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15608	PG0415	2017-08-04 14:05:00+03	2017-08-04 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-04 14:07:00+03	2017-08-04 16:13:00+03
15609	PG0415	2017-09-13 14:05:00+03	2017-09-13 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15610	PG0415	2017-07-19 14:05:00+03	2017-07-19 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-19 14:06:00+03	2017-07-19 16:12:00+03
15611	PG0415	2017-08-03 14:05:00+03	2017-08-03 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-03 14:08:00+03	2017-08-03 16:11:00+03
15612	PG0415	2017-08-17 14:05:00+03	2017-08-17 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15613	PG0415	2017-09-05 14:05:00+03	2017-09-05 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15614	PG0415	2017-08-23 14:05:00+03	2017-08-23 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15615	PG0415	2017-08-02 14:05:00+03	2017-08-02 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-02 14:10:00+03	2017-08-02 16:14:00+03
15616	PG0415	2017-07-20 14:05:00+03	2017-07-20 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-20 14:07:00+03	2017-07-20 16:12:00+03
15617	PG0415	2017-08-10 14:05:00+03	2017-08-10 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-10 14:08:00+03	2017-08-10 16:14:00+03
15618	PG0415	2017-08-12 14:05:00+03	2017-08-12 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-12 17:00:00+03	2017-08-12 19:05:00+03
15619	PG0415	2017-09-12 14:05:00+03	2017-09-12 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15620	PG0415	2017-08-14 14:05:00+03	2017-08-14 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-14 14:09:00+03	2017-08-14 16:14:00+03
15621	PG0415	2017-08-01 14:05:00+03	2017-08-01 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-01 14:07:00+03	2017-08-01 16:11:00+03
15622	PG0415	2017-09-06 14:05:00+03	2017-09-06 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15623	PG0415	2017-07-21 14:05:00+03	2017-07-21 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-21 17:30:00+03	2017-07-21 19:36:00+03
15624	PG0415	2017-08-26 14:05:00+03	2017-08-26 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15625	PG0415	2017-09-02 14:05:00+03	2017-09-02 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15626	PG0415	2017-08-18 14:05:00+03	2017-08-18 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15627	PG0415	2017-07-31 14:05:00+03	2017-07-31 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-31 14:08:00+03	2017-07-31 16:13:00+03
15628	PG0415	2017-08-28 14:05:00+03	2017-08-28 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15629	PG0415	2017-08-22 14:05:00+03	2017-08-22 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15630	PG0415	2017-07-22 14:05:00+03	2017-07-22 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-22 14:07:00+03	2017-07-22 16:14:00+03
15631	PG0415	2017-09-11 14:05:00+03	2017-09-11 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15632	PG0415	2017-07-30 14:05:00+03	2017-07-30 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-30 14:10:00+03	2017-07-30 16:17:00+03
15633	PG0415	2017-09-07 14:05:00+03	2017-09-07 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15634	PG0415	2017-08-30 14:05:00+03	2017-08-30 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15635	PG0415	2017-08-15 14:05:00+03	2017-08-15 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-15 14:07:00+03	2017-08-15 16:13:00+03
15636	PG0415	2017-07-23 14:05:00+03	2017-07-23 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-23 14:09:00+03	2017-07-23 16:12:00+03
15637	PG0415	2017-08-19 14:05:00+03	2017-08-19 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15638	PG0415	2017-07-29 14:05:00+03	2017-07-29 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-29 14:09:00+03	2017-07-29 16:13:00+03
15639	PG0415	2017-07-16 14:05:00+03	2017-07-16 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-16 14:11:00+03	2017-07-16 16:18:00+03
15640	PG0415	2017-09-14 14:05:00+03	2017-09-14 16:10:00+03	MMK	VKO	Cancelled	CR2	\N	\N
15641	PG0415	2017-09-08 14:05:00+03	2017-09-08 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15642	PG0415	2017-07-28 14:05:00+03	2017-07-28 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-28 14:09:00+03	2017-07-28 16:15:00+03
15643	PG0415	2017-07-24 14:05:00+03	2017-07-24 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-24 14:06:00+03	2017-07-24 16:10:00+03
15644	PG0415	2017-08-21 14:05:00+03	2017-08-21 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15645	PG0415	2017-09-10 14:05:00+03	2017-09-10 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15646	PG0415	2017-08-11 14:05:00+03	2017-08-11 16:10:00+03	MMK	VKO	Arrived	CR2	2017-08-11 14:06:00+03	2017-08-11 16:10:00+03
15647	PG0415	2017-07-27 14:05:00+03	2017-07-27 16:10:00+03	MMK	VKO	Arrived	CR2	2017-07-27 14:07:00+03	2017-07-27 16:13:00+03
15648	PG0415	2017-08-20 14:05:00+03	2017-08-20 16:10:00+03	MMK	VKO	Scheduled	CR2	\N	\N
15649	PG0153	2017-07-23 10:05:00+03	2017-07-23 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-23 10:06:00+03	2017-07-23 12:03:00+03
15650	PG0153	2017-07-28 10:05:00+03	2017-07-28 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-28 10:07:00+03	2017-07-28 12:01:00+03
15651	PG0153	2017-07-31 10:05:00+03	2017-07-31 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-31 10:07:00+03	2017-07-31 12:01:00+03
15652	PG0153	2017-07-26 10:05:00+03	2017-07-26 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-26 10:08:00+03	2017-07-26 12:03:00+03
15653	PG0153	2017-08-22 10:05:00+03	2017-08-22 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15654	PG0153	2017-08-09 10:05:00+03	2017-08-09 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-09 10:08:00+03	2017-08-09 12:04:00+03
15655	PG0153	2017-08-21 10:05:00+03	2017-08-21 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15656	PG0153	2017-08-10 10:05:00+03	2017-08-10 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-10 10:10:00+03	2017-08-10 12:04:00+03
15657	PG0153	2017-08-14 10:05:00+03	2017-08-14 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-14 10:08:00+03	2017-08-14 12:03:00+03
15658	PG0153	2017-08-12 10:05:00+03	2017-08-12 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-12 10:07:00+03	2017-08-12 12:02:00+03
15659	PG0153	2017-09-11 10:05:00+03	2017-09-11 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15660	PG0153	2017-08-05 10:05:00+03	2017-08-05 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-05 10:11:00+03	2017-08-05 12:07:00+03
15661	PG0153	2017-08-02 10:05:00+03	2017-08-02 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-02 10:06:00+03	2017-08-02 12:00:00+03
15662	PG0153	2017-09-09 10:05:00+03	2017-09-09 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15663	PG0153	2017-09-10 10:05:00+03	2017-09-10 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15664	PG0153	2017-09-08 10:05:00+03	2017-09-08 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15665	PG0153	2017-08-29 10:05:00+03	2017-08-29 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15666	PG0153	2017-08-03 10:05:00+03	2017-08-03 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-03 10:07:00+03	2017-08-03 12:02:00+03
15667	PG0153	2017-07-29 10:05:00+03	2017-07-29 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-29 10:08:00+03	2017-07-29 12:04:00+03
15668	PG0153	2017-08-01 10:05:00+03	2017-08-01 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-01 10:06:00+03	2017-08-01 12:05:00+03
15669	PG0153	2017-08-16 10:05:00+03	2017-08-16 12:00:00+03	MMK	SVO	On Time	SU9	\N	\N
15670	PG0153	2017-08-28 10:05:00+03	2017-08-28 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15671	PG0153	2017-08-23 10:05:00+03	2017-08-23 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15672	PG0153	2017-07-21 10:05:00+03	2017-07-21 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-21 10:12:00+03	2017-07-21 12:09:00+03
15673	PG0153	2017-08-20 10:05:00+03	2017-08-20 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15674	PG0153	2017-08-24 10:05:00+03	2017-08-24 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15675	PG0153	2017-08-15 10:05:00+03	2017-08-15 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-15 10:06:00+03	2017-08-15 12:01:00+03
15676	PG0153	2017-08-18 10:05:00+03	2017-08-18 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15677	PG0153	2017-08-11 10:05:00+03	2017-08-11 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-11 10:07:00+03	2017-08-11 12:00:00+03
15678	PG0153	2017-08-07 10:05:00+03	2017-08-07 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-07 10:07:00+03	2017-08-07 12:04:00+03
15679	PG0153	2017-07-19 10:05:00+03	2017-07-19 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-19 10:07:00+03	2017-07-19 12:01:00+03
15680	PG0153	2017-08-19 10:05:00+03	2017-08-19 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15681	PG0153	2017-08-08 10:05:00+03	2017-08-08 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-08 10:07:00+03	2017-08-08 12:04:00+03
15682	PG0153	2017-09-03 10:05:00+03	2017-09-03 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15683	PG0153	2017-07-17 10:05:00+03	2017-07-17 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-17 10:08:00+03	2017-07-17 12:04:00+03
15684	PG0153	2017-08-26 10:05:00+03	2017-08-26 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15685	PG0153	2017-08-30 10:05:00+03	2017-08-30 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15686	PG0153	2017-09-13 10:05:00+03	2017-09-13 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15687	PG0153	2017-08-31 10:05:00+03	2017-08-31 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15688	PG0153	2017-08-27 10:05:00+03	2017-08-27 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15689	PG0153	2017-07-24 10:05:00+03	2017-07-24 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-24 10:06:00+03	2017-07-24 12:01:00+03
15690	PG0153	2017-08-13 10:05:00+03	2017-08-13 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-13 10:07:00+03	2017-08-13 12:03:00+03
15691	PG0153	2017-09-05 10:05:00+03	2017-09-05 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15692	PG0153	2017-09-06 10:05:00+03	2017-09-06 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15693	PG0153	2017-07-25 10:05:00+03	2017-07-25 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-25 10:09:00+03	2017-07-25 12:04:00+03
15694	PG0153	2017-09-14 10:05:00+03	2017-09-14 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15695	PG0153	2017-07-16 10:05:00+03	2017-07-16 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-16 10:08:00+03	2017-07-16 12:02:00+03
15696	PG0153	2017-08-04 10:05:00+03	2017-08-04 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-04 10:08:00+03	2017-08-04 12:04:00+03
15697	PG0153	2017-07-20 10:05:00+03	2017-07-20 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-20 10:07:00+03	2017-07-20 12:01:00+03
15698	PG0153	2017-08-25 10:05:00+03	2017-08-25 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15699	PG0153	2017-09-12 10:05:00+03	2017-09-12 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15700	PG0153	2017-09-01 10:05:00+03	2017-09-01 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15701	PG0153	2017-07-18 10:05:00+03	2017-07-18 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-18 10:08:00+03	2017-07-18 12:02:00+03
15702	PG0153	2017-07-27 10:05:00+03	2017-07-27 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-27 10:07:00+03	2017-07-27 12:02:00+03
15703	PG0153	2017-09-02 10:05:00+03	2017-09-02 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15704	PG0153	2017-07-22 10:05:00+03	2017-07-22 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-22 10:10:00+03	2017-07-22 12:04:00+03
15705	PG0153	2017-09-07 10:05:00+03	2017-09-07 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15706	PG0153	2017-09-04 10:05:00+03	2017-09-04 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15707	PG0153	2017-08-06 10:05:00+03	2017-08-06 12:00:00+03	MMK	SVO	Arrived	SU9	2017-08-06 10:08:00+03	2017-08-06 12:02:00+03
15708	PG0153	2017-07-30 10:05:00+03	2017-07-30 12:00:00+03	MMK	SVO	Arrived	SU9	2017-07-30 10:07:00+03	2017-07-30 12:02:00+03
15709	PG0153	2017-08-17 10:05:00+03	2017-08-17 12:00:00+03	MMK	SVO	Scheduled	SU9	\N	\N
15710	PG0244	2017-08-25 03:20:00+03	2017-08-25 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15711	PG0244	2017-08-08 03:20:00+03	2017-08-08 09:45:00+03	YKS	LED	Arrived	319	2017-08-08 03:22:00+03	2017-08-08 09:47:00+03
15712	PG0244	2017-09-12 03:20:00+03	2017-09-12 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15713	PG0244	2017-09-03 03:20:00+03	2017-09-03 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15714	PG0244	2017-08-29 03:20:00+03	2017-08-29 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15715	PG0244	2017-09-13 03:20:00+03	2017-09-13 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15716	PG0244	2017-09-05 03:20:00+03	2017-09-05 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15717	PG0244	2017-08-27 03:20:00+03	2017-08-27 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15718	PG0244	2017-08-01 03:20:00+03	2017-08-01 09:45:00+03	YKS	LED	Arrived	319	2017-08-01 03:22:00+03	2017-08-01 09:35:00+03
15719	PG0244	2017-07-26 03:20:00+03	2017-07-26 09:45:00+03	YKS	LED	Arrived	319	2017-07-26 03:21:00+03	2017-07-26 09:47:00+03
15720	PG0244	2017-08-10 03:20:00+03	2017-08-10 09:45:00+03	YKS	LED	Arrived	319	2017-08-10 03:23:00+03	2017-08-10 09:43:00+03
15721	PG0244	2017-08-09 03:20:00+03	2017-08-09 09:45:00+03	YKS	LED	Arrived	319	2017-08-09 03:21:00+03	2017-08-09 09:47:00+03
15722	PG0244	2017-07-19 03:20:00+03	2017-07-19 09:45:00+03	YKS	LED	Arrived	319	2017-07-19 03:22:00+03	2017-07-19 09:51:00+03
15723	PG0244	2017-08-17 03:20:00+03	2017-08-17 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15724	PG0244	2017-07-31 03:20:00+03	2017-07-31 09:45:00+03	YKS	LED	Arrived	319	2017-07-31 03:22:00+03	2017-07-31 09:49:00+03
15725	PG0244	2017-08-04 03:20:00+03	2017-08-04 09:45:00+03	YKS	LED	Arrived	319	2017-08-04 03:23:00+03	2017-08-04 09:42:00+03
15726	PG0244	2017-07-22 03:20:00+03	2017-07-22 09:45:00+03	YKS	LED	Arrived	319	2017-07-22 07:04:00+03	2017-07-22 13:29:00+03
15727	PG0244	2017-08-20 03:20:00+03	2017-08-20 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15728	PG0244	2017-08-05 03:20:00+03	2017-08-05 09:45:00+03	YKS	LED	Arrived	319	2017-08-05 03:22:00+03	2017-08-05 09:48:00+03
15729	PG0244	2017-09-07 03:20:00+03	2017-09-07 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15730	PG0244	2017-09-04 03:20:00+03	2017-09-04 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15731	PG0244	2017-09-01 03:20:00+03	2017-09-01 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15732	PG0244	2017-08-12 03:20:00+03	2017-08-12 09:45:00+03	YKS	LED	Arrived	319	2017-08-12 03:22:00+03	2017-08-12 09:51:00+03
15733	PG0244	2017-07-18 03:20:00+03	2017-07-18 09:45:00+03	YKS	LED	Arrived	319	2017-07-18 03:22:00+03	2017-07-18 09:46:00+03
15734	PG0244	2017-07-25 03:20:00+03	2017-07-25 09:45:00+03	YKS	LED	Arrived	319	2017-07-25 03:20:00+03	2017-07-25 09:47:00+03
15735	PG0244	2017-09-10 03:20:00+03	2017-09-10 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15736	PG0244	2017-08-22 03:20:00+03	2017-08-22 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15737	PG0244	2017-07-30 03:20:00+03	2017-07-30 09:45:00+03	YKS	LED	Arrived	319	2017-07-30 03:23:00+03	2017-07-30 09:50:00+03
15738	PG0244	2017-08-19 03:20:00+03	2017-08-19 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15739	PG0244	2017-08-06 03:20:00+03	2017-08-06 09:45:00+03	YKS	LED	Arrived	319	2017-08-06 03:23:00+03	2017-08-06 09:55:00+03
15740	PG0244	2017-09-11 03:20:00+03	2017-09-11 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15741	PG0244	2017-07-23 03:20:00+03	2017-07-23 09:45:00+03	YKS	LED	Arrived	319	2017-07-23 03:25:00+03	2017-07-23 09:47:00+03
15742	PG0244	2017-08-16 03:20:00+03	2017-08-16 09:45:00+03	YKS	LED	On Time	319	\N	\N
15743	PG0244	2017-08-24 03:20:00+03	2017-08-24 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15744	PG0244	2017-08-28 03:20:00+03	2017-08-28 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15745	PG0244	2017-09-14 03:20:00+03	2017-09-14 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15746	PG0244	2017-07-29 03:20:00+03	2017-07-29 09:45:00+03	YKS	LED	Arrived	319	2017-07-29 06:50:00+03	2017-07-29 13:10:00+03
15747	PG0244	2017-08-14 03:20:00+03	2017-08-14 09:45:00+03	YKS	LED	Arrived	319	2017-08-14 03:21:00+03	2017-08-14 09:47:00+03
15748	PG0244	2017-09-09 03:20:00+03	2017-09-09 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15749	PG0244	2017-08-31 03:20:00+03	2017-08-31 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15750	PG0244	2017-07-16 03:20:00+03	2017-07-16 09:45:00+03	YKS	LED	Arrived	319	2017-07-16 03:21:00+03	2017-07-16 09:45:00+03
15751	PG0244	2017-09-08 03:20:00+03	2017-09-08 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15752	PG0244	2017-09-02 03:20:00+03	2017-09-02 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15753	PG0244	2017-07-17 03:20:00+03	2017-07-17 09:45:00+03	YKS	LED	Arrived	319	2017-07-17 03:24:00+03	2017-07-17 09:47:00+03
15754	PG0244	2017-08-07 03:20:00+03	2017-08-07 09:45:00+03	YKS	LED	Arrived	319	2017-08-07 03:22:00+03	2017-08-07 09:49:00+03
15755	PG0244	2017-08-21 03:20:00+03	2017-08-21 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15756	PG0244	2017-08-11 03:20:00+03	2017-08-11 09:45:00+03	YKS	LED	Arrived	319	2017-08-11 03:21:00+03	2017-08-11 09:46:00+03
15757	PG0244	2017-07-24 03:20:00+03	2017-07-24 09:45:00+03	YKS	LED	Arrived	319	2017-07-24 03:26:00+03	2017-07-24 09:51:00+03
15758	PG0244	2017-07-27 03:20:00+03	2017-07-27 09:45:00+03	YKS	LED	Arrived	319	2017-07-27 03:22:00+03	2017-07-27 09:49:00+03
15759	PG0244	2017-07-20 03:20:00+03	2017-07-20 09:45:00+03	YKS	LED	Arrived	319	2017-07-20 03:22:00+03	2017-07-20 09:50:00+03
15760	PG0244	2017-08-26 03:20:00+03	2017-08-26 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15761	PG0244	2017-08-23 03:20:00+03	2017-08-23 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15762	PG0244	2017-08-13 03:20:00+03	2017-08-13 09:45:00+03	YKS	LED	Arrived	319	2017-08-13 03:25:00+03	2017-08-13 10:00:00+03
15763	PG0244	2017-08-15 03:20:00+03	2017-08-15 09:45:00+03	YKS	LED	Arrived	319	2017-08-15 03:23:00+03	2017-08-15 09:45:00+03
15764	PG0244	2017-08-02 03:20:00+03	2017-08-02 09:45:00+03	YKS	LED	Arrived	319	2017-08-02 03:24:00+03	2017-08-02 09:49:00+03
15765	PG0244	2017-07-28 03:20:00+03	2017-07-28 09:45:00+03	YKS	LED	Arrived	319	2017-07-28 03:24:00+03	2017-07-28 09:44:00+03
15766	PG0244	2017-08-30 03:20:00+03	2017-08-30 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15767	PG0244	2017-09-06 03:20:00+03	2017-09-06 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15768	PG0244	2017-08-03 03:20:00+03	2017-08-03 09:45:00+03	YKS	LED	Arrived	319	2017-08-03 03:23:00+03	2017-08-03 09:45:00+03
15769	PG0244	2017-08-18 03:20:00+03	2017-08-18 09:45:00+03	YKS	LED	Scheduled	319	\N	\N
15770	PG0244	2017-07-21 03:20:00+03	2017-07-21 09:45:00+03	YKS	LED	Arrived	319	2017-07-21 03:21:00+03	2017-07-21 09:46:00+03
15771	PG0581	2017-08-23 08:05:00+03	2017-08-23 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15772	PG0581	2017-09-03 08:05:00+03	2017-09-03 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15773	PG0581	2017-07-16 08:05:00+03	2017-07-16 10:45:00+03	YKS	UUS	Arrived	CR2	2017-07-16 08:07:00+03	2017-07-16 10:49:00+03
15774	PG0581	2017-08-06 08:05:00+03	2017-08-06 10:45:00+03	YKS	UUS	Arrived	CR2	2017-08-06 08:06:00+03	2017-08-06 10:48:00+03
15775	PG0581	2017-08-02 08:05:00+03	2017-08-02 10:45:00+03	YKS	UUS	Arrived	CR2	2017-08-02 08:12:00+03	2017-08-02 10:52:00+03
15776	PG0581	2017-07-30 08:05:00+03	2017-07-30 10:45:00+03	YKS	UUS	Arrived	CR2	2017-07-30 11:04:00+03	2017-07-30 13:45:00+03
15777	PG0581	2017-08-16 08:05:00+03	2017-08-16 10:45:00+03	YKS	UUS	On Time	CR2	\N	\N
15778	PG0581	2017-08-13 08:05:00+03	2017-08-13 10:45:00+03	YKS	UUS	Arrived	CR2	2017-08-13 08:08:00+03	2017-08-13 10:48:00+03
15779	PG0581	2017-07-26 08:05:00+03	2017-07-26 10:45:00+03	YKS	UUS	Arrived	CR2	2017-07-26 08:08:00+03	2017-07-26 10:48:00+03
15780	PG0581	2017-07-19 08:05:00+03	2017-07-19 10:45:00+03	YKS	UUS	Arrived	CR2	2017-07-19 08:10:00+03	2017-07-19 10:50:00+03
15781	PG0581	2017-09-06 08:05:00+03	2017-09-06 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15782	PG0581	2017-08-30 08:05:00+03	2017-08-30 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15783	PG0581	2017-08-20 08:05:00+03	2017-08-20 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15784	PG0581	2017-08-27 08:05:00+03	2017-08-27 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15785	PG0581	2017-09-13 08:05:00+03	2017-09-13 10:45:00+03	YKS	UUS	Cancelled	CR2	\N	\N
15786	PG0581	2017-09-10 08:05:00+03	2017-09-10 10:45:00+03	YKS	UUS	Scheduled	CR2	\N	\N
15787	PG0581	2017-08-09 08:05:00+03	2017-08-09 10:45:00+03	YKS	UUS	Arrived	CR2	2017-08-09 08:09:00+03	2017-08-09 10:50:00+03
15788	PG0581	2017-07-23 08:05:00+03	2017-07-23 10:45:00+03	YKS	UUS	Arrived	CR2	2017-07-23 08:08:00+03	2017-07-23 10:48:00+03
15789	PG0699	2017-07-30 11:20:00+03	2017-07-30 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-30 11:23:00+03	2017-07-30 12:33:00+03
15790	PG0699	2017-08-24 11:20:00+03	2017-08-24 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15791	PG0699	2017-07-16 11:20:00+03	2017-07-16 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-16 11:23:00+03	2017-07-16 12:34:00+03
15792	PG0699	2017-09-14 11:20:00+03	2017-09-14 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15793	PG0699	2017-07-17 11:20:00+03	2017-07-17 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-17 11:22:00+03	2017-07-17 12:32:00+03
15794	PG0699	2017-09-13 11:20:00+03	2017-09-13 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15795	PG0699	2017-08-12 11:20:00+03	2017-08-12 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-12 11:23:00+03	2017-08-12 12:34:00+03
15796	PG0699	2017-08-25 11:20:00+03	2017-08-25 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15797	PG0699	2017-08-23 11:20:00+03	2017-08-23 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15798	PG0699	2017-07-18 11:20:00+03	2017-07-18 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-18 11:21:00+03	2017-07-18 12:29:00+03
15799	PG0699	2017-07-19 11:20:00+03	2017-07-19 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-19 11:22:00+03	2017-07-19 12:33:00+03
15800	PG0699	2017-09-12 11:20:00+03	2017-09-12 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15801	PG0699	2017-07-20 11:20:00+03	2017-07-20 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-20 11:23:00+03	2017-07-20 12:33:00+03
15802	PG0699	2017-08-22 11:20:00+03	2017-08-22 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15803	PG0699	2017-08-31 11:20:00+03	2017-08-31 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15804	PG0699	2017-07-21 11:20:00+03	2017-07-21 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-21 11:24:00+03	2017-07-21 12:34:00+03
15805	PG0699	2017-09-11 11:20:00+03	2017-09-11 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15806	PG0699	2017-07-22 11:20:00+03	2017-07-22 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-22 11:21:00+03	2017-07-22 12:31:00+03
15807	PG0699	2017-08-26 11:20:00+03	2017-08-26 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15808	PG0699	2017-08-21 11:20:00+03	2017-08-21 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15809	PG0699	2017-08-13 11:20:00+03	2017-08-13 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-13 11:23:00+03	2017-08-13 12:32:00+03
15810	PG0699	2017-09-10 11:20:00+03	2017-09-10 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15811	PG0699	2017-07-23 11:20:00+03	2017-07-23 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-23 11:22:00+03	2017-07-23 12:32:00+03
15812	PG0699	2017-07-24 11:20:00+03	2017-07-24 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-24 11:24:00+03	2017-07-24 12:35:00+03
15813	PG0699	2017-08-11 11:20:00+03	2017-08-11 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-11 11:22:00+03	2017-08-11 12:31:00+03
15814	PG0699	2017-09-09 11:20:00+03	2017-09-09 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15815	PG0699	2017-07-25 11:20:00+03	2017-07-25 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-25 11:23:00+03	2017-07-25 12:33:00+03
15816	PG0699	2017-08-20 11:20:00+03	2017-08-20 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15817	PG0699	2017-07-26 11:20:00+03	2017-07-26 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-26 11:24:00+03	2017-07-26 12:34:00+03
15818	PG0699	2017-09-08 11:20:00+03	2017-09-08 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15819	PG0699	2017-07-27 11:20:00+03	2017-07-27 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-27 11:22:00+03	2017-07-27 12:32:00+03
15820	PG0699	2017-08-27 11:20:00+03	2017-08-27 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15821	PG0699	2017-08-19 11:20:00+03	2017-08-19 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15822	PG0699	2017-07-28 11:20:00+03	2017-07-28 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-28 11:22:00+03	2017-07-28 12:32:00+03
15823	PG0699	2017-08-30 11:20:00+03	2017-08-30 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15824	PG0699	2017-09-07 11:20:00+03	2017-09-07 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15825	PG0699	2017-07-29 11:20:00+03	2017-07-29 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-29 11:22:00+03	2017-07-29 12:32:00+03
15826	PG0699	2017-08-10 11:20:00+03	2017-08-10 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-10 11:20:00+03	2017-08-10 12:31:00+03
15827	PG0699	2017-08-08 11:20:00+03	2017-08-08 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-08 11:23:00+03	2017-08-08 12:34:00+03
15828	PG0699	2017-08-18 11:20:00+03	2017-08-18 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15829	PG0699	2017-09-06 11:20:00+03	2017-09-06 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15830	PG0699	2017-07-31 11:20:00+03	2017-07-31 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-07-31 11:25:00+03	2017-07-31 12:34:00+03
15831	PG0699	2017-08-28 11:20:00+03	2017-08-28 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15832	PG0699	2017-08-01 11:20:00+03	2017-08-01 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-01 11:23:00+03	2017-08-01 12:32:00+03
15833	PG0699	2017-09-01 11:20:00+03	2017-09-01 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15834	PG0699	2017-08-17 11:20:00+03	2017-08-17 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15835	PG0699	2017-09-05 11:20:00+03	2017-09-05 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15836	PG0699	2017-08-02 11:20:00+03	2017-08-02 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-02 11:24:00+03	2017-08-02 12:35:00+03
15837	PG0699	2017-08-03 11:20:00+03	2017-08-03 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-03 11:23:00+03	2017-08-03 12:34:00+03
15838	PG0699	2017-09-04 11:20:00+03	2017-09-04 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15839	PG0699	2017-08-16 11:20:00+03	2017-08-16 12:30:00+03	YKS	MJZ	Delayed	CR2	\N	\N
15840	PG0699	2017-08-04 11:20:00+03	2017-08-04 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-04 11:22:00+03	2017-08-04 12:32:00+03
15841	PG0699	2017-08-05 11:20:00+03	2017-08-05 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-05 11:24:00+03	2017-08-05 12:34:00+03
15842	PG0699	2017-08-29 11:20:00+03	2017-08-29 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15843	PG0699	2017-09-03 11:20:00+03	2017-09-03 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15844	PG0699	2017-08-09 11:20:00+03	2017-08-09 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-09 11:22:00+03	2017-08-09 12:31:00+03
15845	PG0699	2017-08-06 11:20:00+03	2017-08-06 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-06 11:23:00+03	2017-08-06 12:32:00+03
15846	PG0699	2017-08-15 11:20:00+03	2017-08-15 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-15 11:21:00+03	2017-08-15 12:31:00+03
15847	PG0699	2017-08-07 11:20:00+03	2017-08-07 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-07 11:23:00+03	2017-08-07 12:33:00+03
15848	PG0699	2017-08-14 11:20:00+03	2017-08-14 12:30:00+03	YKS	MJZ	Arrived	CR2	2017-08-14 11:21:00+03	2017-08-14 12:31:00+03
15849	PG0699	2017-09-02 11:20:00+03	2017-09-02 12:30:00+03	YKS	MJZ	Scheduled	CR2	\N	\N
15850	PG0170	2017-08-19 11:00:00+03	2017-08-19 14:50:00+03	YKS	BAX	Scheduled	SU9	\N	\N
15851	PG0170	2017-09-02 11:00:00+03	2017-09-02 14:50:00+03	YKS	BAX	Scheduled	SU9	\N	\N
15852	PG0170	2017-08-05 11:00:00+03	2017-08-05 14:50:00+03	YKS	BAX	Arrived	SU9	2017-08-05 11:02:00+03	2017-08-05 14:53:00+03
15853	PG0170	2017-07-22 11:00:00+03	2017-07-22 14:50:00+03	YKS	BAX	Arrived	SU9	2017-07-22 11:07:00+03	2017-07-22 14:57:00+03
15854	PG0170	2017-08-12 11:00:00+03	2017-08-12 14:50:00+03	YKS	BAX	Arrived	SU9	2017-08-12 11:00:00+03	2017-08-12 14:51:00+03
15855	PG0170	2017-09-09 11:00:00+03	2017-09-09 14:50:00+03	YKS	BAX	Cancelled	SU9	\N	\N
15856	PG0170	2017-07-29 11:00:00+03	2017-07-29 14:50:00+03	YKS	BAX	Arrived	SU9	2017-07-29 11:02:00+03	2017-07-29 14:50:00+03
15857	PG0170	2017-08-26 11:00:00+03	2017-08-26 14:50:00+03	YKS	BAX	Scheduled	SU9	\N	\N
15858	PG0531	2017-07-30 09:15:00+03	2017-07-30 11:45:00+03	YKS	UUD	Arrived	CR2	2017-07-30 09:21:00+03	2017-07-30 11:51:00+03
15859	PG0531	2017-09-10 09:15:00+03	2017-09-10 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15860	PG0531	2017-07-26 09:15:00+03	2017-07-26 11:45:00+03	YKS	UUD	Arrived	CR2	2017-07-26 09:17:00+03	2017-07-26 11:45:00+03
15861	PG0531	2017-08-20 09:15:00+03	2017-08-20 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15862	PG0531	2017-08-16 09:15:00+03	2017-08-16 11:45:00+03	YKS	UUD	On Time	CR2	\N	\N
15863	PG0531	2017-08-09 09:15:00+03	2017-08-09 11:45:00+03	YKS	UUD	Arrived	CR2	2017-08-09 09:15:00+03	2017-08-09 11:43:00+03
15864	PG0531	2017-09-06 09:15:00+03	2017-09-06 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15865	PG0531	2017-09-13 09:15:00+03	2017-09-13 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15866	PG0531	2017-08-23 09:15:00+03	2017-08-23 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15867	PG0531	2017-09-03 09:15:00+03	2017-09-03 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15868	PG0531	2017-08-06 09:15:00+03	2017-08-06 11:45:00+03	YKS	UUD	Arrived	CR2	2017-08-06 12:15:00+03	2017-08-06 14:46:00+03
15869	PG0531	2017-08-27 09:15:00+03	2017-08-27 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15870	PG0531	2017-07-23 09:15:00+03	2017-07-23 11:45:00+03	YKS	UUD	Arrived	CR2	2017-07-23 09:18:00+03	2017-07-23 11:48:00+03
15871	PG0531	2017-08-30 09:15:00+03	2017-08-30 11:45:00+03	YKS	UUD	Scheduled	CR2	\N	\N
15872	PG0531	2017-07-16 09:15:00+03	2017-07-16 11:45:00+03	YKS	UUD	Arrived	CR2	2017-07-16 09:17:00+03	2017-07-16 11:48:00+03
15873	PG0531	2017-08-02 09:15:00+03	2017-08-02 11:45:00+03	YKS	UUD	Arrived	CR2	2017-08-02 12:09:00+03	2017-08-02 14:38:00+03
15874	PG0531	2017-07-19 09:15:00+03	2017-07-19 11:45:00+03	YKS	UUD	Arrived	CR2	2017-07-19 09:19:00+03	2017-07-19 11:48:00+03
15875	PG0531	2017-08-13 09:15:00+03	2017-08-13 11:45:00+03	YKS	UUD	Arrived	CR2	2017-08-13 09:17:00+03	2017-08-13 11:48:00+03
15876	PG0056	2017-08-14 16:30:00+03	2017-08-14 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-14 16:34:00+03	2017-08-14 17:49:00+03
15877	PG0057	2017-08-07 18:10:00+03	2017-08-07 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-07 18:11:00+03	2017-08-07 19:26:00+03
15878	PG0057	2017-09-06 18:10:00+03	2017-09-06 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15879	PG0056	2017-08-07 16:30:00+03	2017-08-07 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-07 16:32:00+03	2017-08-07 17:47:00+03
15880	PG0057	2017-08-20 18:10:00+03	2017-08-20 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15881	PG0056	2017-08-20 16:30:00+03	2017-08-20 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15882	PG0057	2017-08-29 18:10:00+03	2017-08-29 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15883	PG0056	2017-08-29 16:30:00+03	2017-08-29 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15884	PG0056	2017-08-18 16:30:00+03	2017-08-18 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15885	PG0057	2017-08-18 18:10:00+03	2017-08-18 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15886	PG0056	2017-07-21 16:30:00+03	2017-07-21 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-21 16:32:00+03	2017-07-21 17:47:00+03
15887	PG0056	2017-08-16 16:30:00+03	2017-08-16 17:45:00+03	TBW	DME	On Time	CN1	\N	\N
15888	PG0057	2017-08-16 18:10:00+03	2017-08-16 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15889	PG0057	2017-08-02 18:10:00+03	2017-08-02 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-02 18:13:00+03	2017-08-02 19:29:00+03
15890	PG0056	2017-08-25 16:30:00+03	2017-08-25 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15891	PG0056	2017-08-23 16:30:00+03	2017-08-23 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15892	PG0057	2017-08-23 18:10:00+03	2017-08-23 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15893	PG0057	2017-08-25 18:10:00+03	2017-08-25 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15894	PG0056	2017-08-02 16:30:00+03	2017-08-02 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-02 16:33:00+03	2017-08-02 17:48:00+03
15895	PG0057	2017-07-21 18:10:00+03	2017-07-21 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-21 21:13:00+03	2017-07-21 22:27:00+03
15896	PG0057	2017-08-30 18:10:00+03	2017-08-30 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15897	PG0057	2017-07-27 18:10:00+03	2017-07-27 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-27 21:14:00+03	2017-07-27 22:28:00+03
15898	PG0056	2017-08-30 16:30:00+03	2017-08-30 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15899	PG0056	2017-09-10 16:30:00+03	2017-09-10 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15900	PG0056	2017-07-16 16:30:00+03	2017-07-16 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-16 16:34:00+03	2017-07-16 17:48:00+03
15901	PG0056	2017-08-28 16:30:00+03	2017-08-28 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15902	PG0057	2017-07-24 18:10:00+03	2017-07-24 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-24 18:13:00+03	2017-07-24 19:29:00+03
15903	PG0057	2017-08-28 18:10:00+03	2017-08-28 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15904	PG0056	2017-07-24 16:30:00+03	2017-07-24 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-24 16:33:00+03	2017-07-24 17:47:00+03
15905	PG0056	2017-08-15 16:30:00+03	2017-08-15 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-15 16:31:00+03	2017-08-15 17:46:00+03
15906	PG0056	2017-09-04 16:30:00+03	2017-09-04 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15907	PG0057	2017-08-13 18:10:00+03	2017-08-13 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-13 18:14:00+03	2017-08-13 19:28:00+03
15908	PG0057	2017-08-31 18:10:00+03	2017-08-31 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15909	PG0057	2017-07-25 18:10:00+03	2017-07-25 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-25 18:14:00+03	2017-07-25 19:29:00+03
15910	PG0057	2017-09-04 18:10:00+03	2017-09-04 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15911	PG0057	2017-08-21 18:10:00+03	2017-08-21 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15912	PG0056	2017-08-13 16:30:00+03	2017-08-13 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-13 16:37:00+03	2017-08-13 17:52:00+03
15913	PG0056	2017-07-18 16:30:00+03	2017-07-18 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-18 16:30:00+03	2017-07-18 17:45:00+03
15914	PG0056	2017-07-29 16:30:00+03	2017-07-29 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-29 16:34:00+03	2017-07-29 17:49:00+03
15915	PG0057	2017-07-29 18:10:00+03	2017-07-29 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-29 18:14:00+03	2017-07-29 19:28:00+03
15916	PG0056	2017-09-11 16:30:00+03	2017-09-11 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15917	PG0057	2017-09-11 18:10:00+03	2017-09-11 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15918	PG0057	2017-08-27 18:10:00+03	2017-08-27 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15919	PG0056	2017-08-27 16:30:00+03	2017-08-27 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15920	PG0057	2017-08-06 18:10:00+03	2017-08-06 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-06 18:14:00+03	2017-08-06 19:30:00+03
15921	PG0056	2017-08-06 16:30:00+03	2017-08-06 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-06 16:33:00+03	2017-08-06 17:48:00+03
15922	PG0057	2017-07-18 18:10:00+03	2017-07-18 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-18 18:14:00+03	2017-07-18 19:30:00+03
15923	PG0056	2017-08-10 16:30:00+03	2017-08-10 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-10 16:31:00+03	2017-08-10 17:46:00+03
15924	PG0056	2017-09-14 16:30:00+03	2017-09-14 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15925	PG0056	2017-08-22 16:30:00+03	2017-08-22 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15926	PG0057	2017-07-16 18:10:00+03	2017-07-16 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-16 18:11:00+03	2017-07-16 19:26:00+03
15927	PG0056	2017-08-21 16:30:00+03	2017-08-21 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15928	PG0057	2017-09-08 18:10:00+03	2017-09-08 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15929	PG0056	2017-09-08 16:30:00+03	2017-09-08 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15930	PG0057	2017-08-10 18:10:00+03	2017-08-10 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-10 18:14:00+03	2017-08-10 19:30:00+03
15931	PG0057	2017-09-03 18:10:00+03	2017-09-03 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15932	PG0056	2017-08-12 16:30:00+03	2017-08-12 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-12 16:31:00+03	2017-08-12 17:45:00+03
15933	PG0057	2017-09-09 18:10:00+03	2017-09-09 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15934	PG0057	2017-08-22 18:10:00+03	2017-08-22 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15935	PG0056	2017-09-09 16:30:00+03	2017-09-09 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15936	PG0057	2017-08-12 18:10:00+03	2017-08-12 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-12 18:11:00+03	2017-08-12 19:25:00+03
15937	PG0057	2017-08-08 18:10:00+03	2017-08-08 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-08 18:13:00+03	2017-08-08 19:27:00+03
15938	PG0056	2017-09-03 16:30:00+03	2017-09-03 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15939	PG0057	2017-08-24 18:10:00+03	2017-08-24 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15940	PG0056	2017-08-24 16:30:00+03	2017-08-24 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15941	PG0056	2017-07-30 16:30:00+03	2017-07-30 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-30 16:32:00+03	2017-07-30 17:47:00+03
15942	PG0057	2017-07-30 18:10:00+03	2017-07-30 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-30 18:15:00+03	2017-07-30 19:30:00+03
15943	PG0057	2017-08-11 18:10:00+03	2017-08-11 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-11 21:08:00+03	2017-08-11 22:22:00+03
15944	PG0056	2017-08-11 16:30:00+03	2017-08-11 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-11 16:36:00+03	2017-08-11 17:52:00+03
15945	PG0057	2017-08-05 18:10:00+03	2017-08-05 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-05 18:12:00+03	2017-08-05 19:27:00+03
15946	PG0056	2017-08-05 16:30:00+03	2017-08-05 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-05 16:32:00+03	2017-08-05 17:46:00+03
15947	PG0057	2017-07-23 18:10:00+03	2017-07-23 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-23 18:16:00+03	2017-07-23 19:32:00+03
15948	PG0056	2017-07-23 16:30:00+03	2017-07-23 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-23 16:35:00+03	2017-07-23 17:50:00+03
15949	PG0057	2017-08-15 18:10:00+03	2017-08-15 19:25:00+03	TBW	DME	On Time	CN1	\N	\N
15950	PG0057	2017-09-01 18:10:00+03	2017-09-01 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15951	PG0056	2017-08-17 16:30:00+03	2017-08-17 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15952	PG0057	2017-07-26 18:10:00+03	2017-07-26 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-26 18:10:00+03	2017-07-26 19:24:00+03
15953	PG0056	2017-07-26 16:30:00+03	2017-07-26 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-26 16:36:00+03	2017-07-26 17:51:00+03
15954	PG0057	2017-08-17 18:10:00+03	2017-08-17 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15955	PG0056	2017-09-01 16:30:00+03	2017-09-01 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15956	PG0056	2017-08-08 16:30:00+03	2017-08-08 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-08 16:32:00+03	2017-08-08 17:46:00+03
15957	PG0056	2017-08-09 16:30:00+03	2017-08-09 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-09 16:34:00+03	2017-08-09 17:48:00+03
15958	PG0056	2017-08-26 16:30:00+03	2017-08-26 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15959	PG0057	2017-08-26 18:10:00+03	2017-08-26 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15960	PG0056	2017-09-05 16:30:00+03	2017-09-05 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15961	PG0056	2017-07-25 16:30:00+03	2017-07-25 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-25 16:34:00+03	2017-07-25 17:49:00+03
15962	PG0057	2017-09-05 18:10:00+03	2017-09-05 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15963	PG0056	2017-07-19 16:30:00+03	2017-07-19 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-19 16:33:00+03	2017-07-19 17:48:00+03
15964	PG0057	2017-09-10 18:10:00+03	2017-09-10 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15965	PG0057	2017-09-14 18:10:00+03	2017-09-14 19:25:00+03	TBW	DME	Cancelled	CN1	\N	\N
15966	PG0057	2017-08-04 18:10:00+03	2017-08-04 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-04 18:13:00+03	2017-08-04 19:28:00+03
15967	PG0056	2017-08-04 16:30:00+03	2017-08-04 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-04 16:32:00+03	2017-08-04 17:46:00+03
15968	PG0057	2017-07-19 18:10:00+03	2017-07-19 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-19 18:12:00+03	2017-07-19 19:27:00+03
15969	PG0056	2017-07-31 16:30:00+03	2017-07-31 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-31 16:33:00+03	2017-07-31 17:49:00+03
15970	PG0057	2017-07-31 18:10:00+03	2017-07-31 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-31 18:10:00+03	2017-07-31 19:25:00+03
15971	PG0057	2017-08-19 18:10:00+03	2017-08-19 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15972	PG0056	2017-08-19 16:30:00+03	2017-08-19 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15973	PG0056	2017-07-17 16:30:00+03	2017-07-17 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-17 16:34:00+03	2017-07-17 17:49:00+03
15974	PG0056	2017-07-28 16:30:00+03	2017-07-28 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-28 16:30:00+03	2017-07-28 17:45:00+03
15975	PG0057	2017-09-02 18:10:00+03	2017-09-02 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15976	PG0057	2017-07-17 18:10:00+03	2017-07-17 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-17 18:12:00+03	2017-07-17 19:27:00+03
15977	PG0056	2017-09-02 16:30:00+03	2017-09-02 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15978	PG0057	2017-07-22 18:10:00+03	2017-07-22 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-22 18:11:00+03	2017-07-22 19:26:00+03
15979	PG0056	2017-07-22 16:30:00+03	2017-07-22 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-22 16:32:00+03	2017-07-22 17:48:00+03
15980	PG0057	2017-09-13 18:10:00+03	2017-09-13 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15981	PG0057	2017-09-07 18:10:00+03	2017-09-07 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15982	PG0056	2017-09-13 16:30:00+03	2017-09-13 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15983	PG0056	2017-09-07 16:30:00+03	2017-09-07 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15984	PG0057	2017-08-03 18:10:00+03	2017-08-03 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-03 18:12:00+03	2017-08-03 19:28:00+03
15985	PG0056	2017-08-03 16:30:00+03	2017-08-03 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-03 16:34:00+03	2017-08-03 17:50:00+03
15986	PG0057	2017-07-28 18:10:00+03	2017-07-28 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-28 21:51:00+03	2017-07-28 23:07:00+03
15987	PG0056	2017-08-31 16:30:00+03	2017-08-31 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15988	PG0057	2017-08-09 18:10:00+03	2017-08-09 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-09 18:13:00+03	2017-08-09 19:28:00+03
15989	PG0056	2017-07-20 16:30:00+03	2017-07-20 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-20 16:30:00+03	2017-07-20 17:46:00+03
15990	PG0056	2017-09-12 16:30:00+03	2017-09-12 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15991	PG0057	2017-09-12 18:10:00+03	2017-09-12 19:25:00+03	TBW	DME	Scheduled	CN1	\N	\N
15992	PG0056	2017-07-27 16:30:00+03	2017-07-27 17:45:00+03	TBW	DME	Arrived	CN1	2017-07-27 16:32:00+03	2017-07-27 17:47:00+03
15993	PG0057	2017-07-20 18:10:00+03	2017-07-20 19:25:00+03	TBW	DME	Arrived	CN1	2017-07-20 18:13:00+03	2017-07-20 19:28:00+03
15994	PG0056	2017-09-06 16:30:00+03	2017-09-06 17:45:00+03	TBW	DME	Scheduled	CN1	\N	\N
15995	PG0056	2017-08-01 16:30:00+03	2017-08-01 17:45:00+03	TBW	DME	Arrived	CN1	2017-08-01 16:35:00+03	2017-08-01 17:49:00+03
15996	PG0057	2017-08-01 18:10:00+03	2017-08-01 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-01 18:13:00+03	2017-08-01 19:29:00+03
15997	PG0057	2017-08-14 18:10:00+03	2017-08-14 19:25:00+03	TBW	DME	Arrived	CN1	2017-08-14 18:14:00+03	2017-08-14 19:29:00+03
15998	PG0441	2017-07-28 13:30:00+03	2017-07-28 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-28 13:35:00+03	2017-07-28 16:59:00+03
15999	PG0441	2017-08-20 13:30:00+03	2017-08-20 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16000	PG0440	2017-08-20 13:10:00+03	2017-08-20 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16001	PG0441	2017-09-14 13:30:00+03	2017-09-14 16:55:00+03	TBW	LED	Cancelled	CN1	\N	\N
16002	PG0441	2017-08-11 13:30:00+03	2017-08-11 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-11 13:32:00+03	2017-08-11 16:58:00+03
16003	PG0440	2017-08-11 13:10:00+03	2017-08-11 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-11 13:12:00+03	2017-08-11 16:37:00+03
16004	PG0440	2017-07-27 13:10:00+03	2017-07-27 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-27 13:14:00+03	2017-07-27 16:40:00+03
16005	PG0441	2017-07-27 13:30:00+03	2017-07-27 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-27 13:32:00+03	2017-07-27 16:59:00+03
16006	PG0440	2017-09-10 13:10:00+03	2017-09-10 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16007	PG0441	2017-09-10 13:30:00+03	2017-09-10 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16008	PG0441	2017-08-15 13:30:00+03	2017-08-15 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-15 13:32:00+03	2017-08-15 16:57:00+03
16009	PG0440	2017-08-21 13:10:00+03	2017-08-21 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16010	PG0440	2017-08-15 13:10:00+03	2017-08-15 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-15 13:12:00+03	2017-08-15 16:35:00+03
16011	PG0441	2017-08-21 13:30:00+03	2017-08-21 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16012	PG0441	2017-07-24 13:30:00+03	2017-07-24 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-24 16:53:00+03	2017-07-24 20:21:00+03
16013	PG0440	2017-07-24 13:10:00+03	2017-07-24 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-24 13:16:00+03	2017-07-24 16:43:00+03
16014	PG0440	2017-07-28 13:10:00+03	2017-07-28 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-28 13:13:00+03	2017-07-28 16:39:00+03
16015	PG0441	2017-09-08 13:30:00+03	2017-09-08 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16016	PG0440	2017-09-08 13:10:00+03	2017-09-08 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16017	PG0440	2017-09-01 13:10:00+03	2017-09-01 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16018	PG0440	2017-09-02 13:10:00+03	2017-09-02 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16019	PG0441	2017-09-01 13:30:00+03	2017-09-01 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16020	PG0440	2017-07-29 13:10:00+03	2017-07-29 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-29 13:19:00+03	2017-07-29 16:47:00+03
16021	PG0441	2017-07-29 13:30:00+03	2017-07-29 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-29 16:31:00+03	2017-07-29 20:01:00+03
16022	PG0441	2017-08-19 13:30:00+03	2017-08-19 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16023	PG0440	2017-08-19 13:10:00+03	2017-08-19 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16024	PG0441	2017-09-02 13:30:00+03	2017-09-02 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16025	PG0441	2017-07-23 13:30:00+03	2017-07-23 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-23 13:34:00+03	2017-07-23 16:58:00+03
16026	PG0440	2017-07-23 13:10:00+03	2017-07-23 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-23 13:12:00+03	2017-07-23 16:37:00+03
16027	PG0441	2017-09-07 13:30:00+03	2017-09-07 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16028	PG0440	2017-09-07 13:10:00+03	2017-09-07 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16029	PG0440	2017-07-30 13:10:00+03	2017-07-30 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-30 13:16:00+03	2017-07-30 16:44:00+03
16030	PG0441	2017-07-30 13:30:00+03	2017-07-30 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-30 13:31:00+03	2017-07-30 16:51:00+03
16031	PG0440	2017-09-11 13:10:00+03	2017-09-11 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16032	PG0441	2017-09-11 13:30:00+03	2017-09-11 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16033	PG0441	2017-07-22 13:30:00+03	2017-07-22 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-22 13:31:00+03	2017-07-22 16:55:00+03
16034	PG0440	2017-07-22 13:10:00+03	2017-07-22 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-22 13:11:00+03	2017-07-22 16:33:00+03
16035	PG0440	2017-08-22 13:10:00+03	2017-08-22 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16036	PG0441	2017-08-22 13:30:00+03	2017-08-22 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16037	PG0440	2017-08-28 13:10:00+03	2017-08-28 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16038	PG0441	2017-08-28 13:30:00+03	2017-08-28 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16039	PG0440	2017-07-31 13:10:00+03	2017-07-31 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-31 13:14:00+03	2017-07-31 16:38:00+03
16040	PG0441	2017-07-31 13:30:00+03	2017-07-31 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-31 13:31:00+03	2017-07-31 16:52:00+03
16041	PG0441	2017-08-30 13:30:00+03	2017-08-30 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16042	PG0441	2017-08-18 13:30:00+03	2017-08-18 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16043	PG0440	2017-08-18 13:10:00+03	2017-08-18 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16044	PG0441	2017-08-26 13:30:00+03	2017-08-26 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16045	PG0440	2017-08-26 13:10:00+03	2017-08-26 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16046	PG0441	2017-07-21 13:30:00+03	2017-07-21 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-21 13:34:00+03	2017-07-21 17:01:00+03
16047	PG0441	2017-09-06 13:30:00+03	2017-09-06 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16048	PG0440	2017-09-06 13:10:00+03	2017-09-06 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16049	PG0440	2017-07-21 13:10:00+03	2017-07-21 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-21 13:11:00+03	2017-07-21 16:36:00+03
16050	PG0440	2017-08-01 13:10:00+03	2017-08-01 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-01 13:14:00+03	2017-08-01 16:40:00+03
16051	PG0441	2017-08-01 13:30:00+03	2017-08-01 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-01 13:32:00+03	2017-08-01 17:00:00+03
16052	PG0440	2017-08-30 13:10:00+03	2017-08-30 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16053	PG0441	2017-08-10 13:30:00+03	2017-08-10 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-10 13:33:00+03	2017-08-10 16:58:00+03
16054	PG0440	2017-08-10 13:10:00+03	2017-08-10 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-10 13:15:00+03	2017-08-10 16:40:00+03
16055	PG0440	2017-09-12 13:10:00+03	2017-09-12 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16056	PG0441	2017-09-12 13:30:00+03	2017-09-12 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16057	PG0441	2017-07-20 13:30:00+03	2017-07-20 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-20 16:58:00+03	2017-07-20 20:26:00+03
16058	PG0440	2017-08-14 13:10:00+03	2017-08-14 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-14 13:11:00+03	2017-08-14 16:40:00+03
16059	PG0441	2017-08-14 13:30:00+03	2017-08-14 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-14 13:32:00+03	2017-08-14 16:57:00+03
16060	PG0440	2017-07-20 13:10:00+03	2017-07-20 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-20 13:12:00+03	2017-07-20 16:38:00+03
16061	PG0440	2017-08-12 13:10:00+03	2017-08-12 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-12 13:16:00+03	2017-08-12 16:42:00+03
16062	PG0441	2017-08-09 13:30:00+03	2017-08-09 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-09 13:31:00+03	2017-08-09 16:57:00+03
16063	PG0441	2017-08-12 13:30:00+03	2017-08-12 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-12 13:31:00+03	2017-08-12 16:58:00+03
16064	PG0440	2017-08-02 13:10:00+03	2017-08-02 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-02 13:13:00+03	2017-08-02 16:38:00+03
16065	PG0441	2017-08-02 13:30:00+03	2017-08-02 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-02 13:33:00+03	2017-08-02 16:55:00+03
16066	PG0440	2017-08-09 13:10:00+03	2017-08-09 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-09 13:12:00+03	2017-08-09 16:33:00+03
16067	PG0441	2017-09-05 13:30:00+03	2017-09-05 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16068	PG0441	2017-08-17 13:30:00+03	2017-08-17 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16069	PG0440	2017-08-17 13:10:00+03	2017-08-17 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16070	PG0440	2017-09-05 13:10:00+03	2017-09-05 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16071	PG0440	2017-08-23 13:10:00+03	2017-08-23 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16072	PG0441	2017-08-23 13:30:00+03	2017-08-23 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16073	PG0440	2017-08-03 13:10:00+03	2017-08-03 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-03 13:14:00+03	2017-08-03 16:41:00+03
16074	PG0441	2017-08-03 13:30:00+03	2017-08-03 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-03 13:33:00+03	2017-08-03 16:55:00+03
16075	PG0441	2017-07-19 13:30:00+03	2017-07-19 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-19 13:33:00+03	2017-07-19 17:01:00+03
16076	PG0440	2017-07-19 13:10:00+03	2017-07-19 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-19 13:16:00+03	2017-07-19 16:41:00+03
16077	PG0440	2017-09-13 13:10:00+03	2017-09-13 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16078	PG0441	2017-09-13 13:30:00+03	2017-09-13 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16079	PG0440	2017-08-04 13:10:00+03	2017-08-04 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-04 13:10:00+03	2017-08-04 16:36:00+03
16080	PG0441	2017-08-04 13:30:00+03	2017-08-04 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-04 13:34:00+03	2017-08-04 17:00:00+03
16081	PG0440	2017-08-08 13:10:00+03	2017-08-08 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-08 13:11:00+03	2017-08-08 16:37:00+03
16082	PG0440	2017-08-29 13:10:00+03	2017-08-29 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16083	PG0441	2017-08-29 13:30:00+03	2017-08-29 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16084	PG0441	2017-09-04 13:30:00+03	2017-09-04 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16085	PG0440	2017-09-04 13:10:00+03	2017-09-04 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16086	PG0441	2017-07-18 13:30:00+03	2017-07-18 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-18 13:33:00+03	2017-07-18 16:59:00+03
16087	PG0440	2017-07-18 13:10:00+03	2017-07-18 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-18 13:16:00+03	2017-07-18 16:42:00+03
16088	PG0440	2017-08-05 13:10:00+03	2017-08-05 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-05 13:14:00+03	2017-08-05 16:41:00+03
16089	PG0441	2017-08-05 13:30:00+03	2017-08-05 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-05 13:34:00+03	2017-08-05 17:02:00+03
16090	PG0441	2017-08-16 13:30:00+03	2017-08-16 16:55:00+03	TBW	LED	On Time	CN1	\N	\N
16091	PG0440	2017-08-16 13:10:00+03	2017-08-16 16:35:00+03	TBW	LED	Delayed	CN1	\N	\N
16092	PG0441	2017-08-08 13:30:00+03	2017-08-08 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-08 13:33:00+03	2017-08-08 16:57:00+03
16093	PG0441	2017-08-31 13:30:00+03	2017-08-31 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16094	PG0440	2017-08-31 13:10:00+03	2017-08-31 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16095	PG0440	2017-08-06 13:10:00+03	2017-08-06 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-06 13:14:00+03	2017-08-06 16:40:00+03
16096	PG0441	2017-08-06 13:30:00+03	2017-08-06 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-06 13:32:00+03	2017-08-06 16:55:00+03
16097	PG0441	2017-08-13 13:30:00+03	2017-08-13 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-13 13:33:00+03	2017-08-13 16:58:00+03
16098	PG0440	2017-08-13 13:10:00+03	2017-08-13 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-13 13:14:00+03	2017-08-13 16:40:00+03
16099	PG0440	2017-09-14 13:10:00+03	2017-09-14 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16100	PG0441	2017-07-17 13:30:00+03	2017-07-17 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-17 13:33:00+03	2017-07-17 16:54:00+03
16101	PG0440	2017-07-17 13:10:00+03	2017-07-17 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-17 13:11:00+03	2017-07-17 16:33:00+03
16102	PG0440	2017-08-24 13:10:00+03	2017-08-24 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16103	PG0441	2017-08-24 13:30:00+03	2017-08-24 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16104	PG0441	2017-09-03 13:30:00+03	2017-09-03 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16105	PG0440	2017-09-03 13:10:00+03	2017-09-03 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16106	PG0441	2017-08-25 13:30:00+03	2017-08-25 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16107	PG0440	2017-08-07 13:10:00+03	2017-08-07 16:35:00+03	TBW	LED	Arrived	CN1	2017-08-07 13:13:00+03	2017-08-07 16:38:00+03
16108	PG0441	2017-08-07 13:30:00+03	2017-08-07 16:55:00+03	TBW	LED	Arrived	CN1	2017-08-07 13:37:00+03	2017-08-07 17:04:00+03
16109	PG0440	2017-08-25 13:10:00+03	2017-08-25 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16110	PG0441	2017-07-16 13:30:00+03	2017-07-16 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-16 13:36:00+03	2017-07-16 17:02:00+03
16111	PG0440	2017-08-27 13:10:00+03	2017-08-27 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16112	PG0441	2017-08-27 13:30:00+03	2017-08-27 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16113	PG0440	2017-07-26 13:10:00+03	2017-07-26 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-26 13:13:00+03	2017-07-26 16:37:00+03
16114	PG0441	2017-07-26 13:30:00+03	2017-07-26 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-26 13:30:00+03	2017-07-26 16:50:00+03
16115	PG0441	2017-09-09 13:30:00+03	2017-09-09 16:55:00+03	TBW	LED	Scheduled	CN1	\N	\N
16116	PG0440	2017-09-09 13:10:00+03	2017-09-09 16:35:00+03	TBW	LED	Scheduled	CN1	\N	\N
16117	PG0441	2017-07-25 13:30:00+03	2017-07-25 16:55:00+03	TBW	LED	Arrived	CN1	2017-07-25 13:35:00+03	2017-07-25 16:58:00+03
16118	PG0440	2017-07-16 13:10:00+03	2017-07-16 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-16 13:13:00+03	2017-07-16 16:40:00+03
16119	PG0440	2017-07-25 13:10:00+03	2017-07-25 16:35:00+03	TBW	LED	Arrived	CN1	2017-07-25 13:12:00+03	2017-07-25 16:32:00+03
16120	PG0046	2017-09-14 18:50:00+03	2017-09-14 20:55:00+03	GRV	DME	Cancelled	CR2	\N	\N
16121	PG0046	2017-07-21 18:50:00+03	2017-07-21 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-21 18:54:00+03	2017-07-21 20:58:00+03
16122	PG0046	2017-08-23 18:50:00+03	2017-08-23 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16123	PG0046	2017-09-03 18:50:00+03	2017-09-03 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16124	PG0046	2017-09-01 18:50:00+03	2017-09-01 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16125	PG0046	2017-08-02 18:50:00+03	2017-08-02 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-02 18:53:00+03	2017-08-02 20:56:00+03
16126	PG0046	2017-07-26 18:50:00+03	2017-07-26 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-26 18:55:00+03	2017-07-26 21:00:00+03
16127	PG0046	2017-08-22 18:50:00+03	2017-08-22 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16128	PG0046	2017-08-14 18:50:00+03	2017-08-14 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-14 18:52:00+03	2017-08-14 20:57:00+03
16129	PG0046	2017-08-29 18:50:00+03	2017-08-29 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16130	PG0046	2017-07-19 18:50:00+03	2017-07-19 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-19 18:53:00+03	2017-07-19 21:00:00+03
16131	PG0046	2017-07-25 18:50:00+03	2017-07-25 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-25 18:55:00+03	2017-07-25 21:00:00+03
16132	PG0046	2017-09-08 18:50:00+03	2017-09-08 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16133	PG0046	2017-07-17 18:50:00+03	2017-07-17 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-17 18:55:00+03	2017-07-17 21:01:00+03
16134	PG0046	2017-09-09 18:50:00+03	2017-09-09 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16135	PG0046	2017-08-21 18:50:00+03	2017-08-21 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16136	PG0046	2017-08-16 18:50:00+03	2017-08-16 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16137	PG0046	2017-08-10 18:50:00+03	2017-08-10 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-10 18:50:00+03	2017-08-10 20:54:00+03
16138	PG0046	2017-08-20 18:50:00+03	2017-08-20 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16139	PG0046	2017-08-06 18:50:00+03	2017-08-06 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-06 18:54:00+03	2017-08-06 20:59:00+03
16140	PG0046	2017-08-07 18:50:00+03	2017-08-07 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-07 18:51:00+03	2017-08-07 20:56:00+03
16141	PG0046	2017-08-27 18:50:00+03	2017-08-27 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16142	PG0046	2017-08-28 18:50:00+03	2017-08-28 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16143	PG0046	2017-08-09 18:50:00+03	2017-08-09 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-09 18:52:00+03	2017-08-09 20:57:00+03
16144	PG0046	2017-08-12 18:50:00+03	2017-08-12 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-12 18:54:00+03	2017-08-12 21:01:00+03
16145	PG0046	2017-07-22 18:50:00+03	2017-07-22 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-22 18:52:00+03	2017-07-22 20:59:00+03
16146	PG0046	2017-08-13 18:50:00+03	2017-08-13 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-13 18:52:00+03	2017-08-13 20:55:00+03
16147	PG0046	2017-08-31 18:50:00+03	2017-08-31 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16148	PG0046	2017-07-29 18:50:00+03	2017-07-29 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-29 18:53:00+03	2017-07-29 20:58:00+03
16149	PG0046	2017-08-30 18:50:00+03	2017-08-30 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16150	PG0046	2017-09-11 18:50:00+03	2017-09-11 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16151	PG0046	2017-07-24 18:50:00+03	2017-07-24 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-24 18:52:00+03	2017-07-24 20:57:00+03
16152	PG0046	2017-09-10 18:50:00+03	2017-09-10 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16153	PG0046	2017-07-20 18:50:00+03	2017-07-20 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-20 18:53:00+03	2017-07-20 20:58:00+03
16154	PG0046	2017-09-04 18:50:00+03	2017-09-04 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16155	PG0046	2017-07-18 18:50:00+03	2017-07-18 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-18 18:51:00+03	2017-07-18 20:54:00+03
16156	PG0046	2017-09-05 18:50:00+03	2017-09-05 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16157	PG0046	2017-07-16 18:50:00+03	2017-07-16 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-16 18:55:00+03	2017-07-16 21:00:00+03
16158	PG0046	2017-09-13 18:50:00+03	2017-09-13 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16159	PG0046	2017-08-04 18:50:00+03	2017-08-04 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-04 18:51:00+03	2017-08-04 20:56:00+03
16160	PG0046	2017-09-12 18:50:00+03	2017-09-12 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16161	PG0046	2017-08-15 18:50:00+03	2017-08-15 20:55:00+03	GRV	DME	On Time	CR2	\N	\N
16162	PG0046	2017-09-07 18:50:00+03	2017-09-07 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16163	PG0046	2017-07-31 18:50:00+03	2017-07-31 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-31 18:54:00+03	2017-07-31 20:58:00+03
16164	PG0046	2017-07-28 18:50:00+03	2017-07-28 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-28 18:51:00+03	2017-07-28 20:57:00+03
16165	PG0046	2017-08-26 18:50:00+03	2017-08-26 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16166	PG0046	2017-08-01 18:50:00+03	2017-08-01 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-01 18:54:00+03	2017-08-01 20:57:00+03
16167	PG0046	2017-08-17 18:50:00+03	2017-08-17 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16168	PG0046	2017-07-23 18:50:00+03	2017-07-23 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-23 18:53:00+03	2017-07-23 21:00:00+03
16169	PG0046	2017-09-06 18:50:00+03	2017-09-06 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16170	PG0046	2017-08-24 18:50:00+03	2017-08-24 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16171	PG0046	2017-08-08 18:50:00+03	2017-08-08 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-08 18:52:00+03	2017-08-08 20:57:00+03
16172	PG0046	2017-09-02 18:50:00+03	2017-09-02 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16173	PG0046	2017-08-05 18:50:00+03	2017-08-05 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-05 18:53:00+03	2017-08-05 20:58:00+03
16174	PG0046	2017-07-27 18:50:00+03	2017-07-27 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-27 18:53:00+03	2017-07-27 20:56:00+03
16175	PG0046	2017-08-18 18:50:00+03	2017-08-18 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16176	PG0046	2017-08-11 18:50:00+03	2017-08-11 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-11 18:52:00+03	2017-08-11 20:59:00+03
16177	PG0046	2017-07-30 18:50:00+03	2017-07-30 20:55:00+03	GRV	DME	Arrived	CR2	2017-07-30 18:53:00+03	2017-07-30 20:57:00+03
16178	PG0046	2017-08-19 18:50:00+03	2017-08-19 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16179	PG0046	2017-08-03 18:50:00+03	2017-08-03 20:55:00+03	GRV	DME	Arrived	CR2	2017-08-03 18:57:00+03	2017-08-03 21:02:00+03
16180	PG0046	2017-08-25 18:50:00+03	2017-08-25 20:55:00+03	GRV	DME	Scheduled	CR2	\N	\N
16181	PG0701	2017-08-01 10:30:00+03	2017-08-01 15:20:00+03	GRV	ABA	Arrived	733	2017-08-01 10:35:00+03	2017-08-01 15:30:00+03
16182	PG0701	2017-07-25 10:30:00+03	2017-07-25 15:20:00+03	GRV	ABA	Arrived	733	2017-07-25 10:34:00+03	2017-07-25 15:21:00+03
16183	PG0701	2017-08-08 10:30:00+03	2017-08-08 15:20:00+03	GRV	ABA	Arrived	733	2017-08-08 10:34:00+03	2017-08-08 15:27:00+03
16184	PG0701	2017-08-15 10:30:00+03	2017-08-15 15:20:00+03	GRV	ABA	Arrived	733	2017-08-15 10:33:00+03	2017-08-15 15:26:00+03
16185	PG0701	2017-08-22 10:30:00+03	2017-08-22 15:20:00+03	GRV	ABA	Scheduled	733	\N	\N
16186	PG0701	2017-09-12 10:30:00+03	2017-09-12 15:20:00+03	GRV	ABA	Cancelled	733	\N	\N
16187	PG0701	2017-08-29 10:30:00+03	2017-08-29 15:20:00+03	GRV	ABA	Scheduled	733	\N	\N
16188	PG0701	2017-09-05 10:30:00+03	2017-09-05 15:20:00+03	GRV	ABA	Scheduled	733	\N	\N
16189	PG0701	2017-07-18 10:30:00+03	2017-07-18 15:20:00+03	GRV	ABA	Arrived	733	2017-07-18 10:36:00+03	2017-07-18 15:24:00+03
16190	PG0342	2017-08-25 19:25:00+03	2017-08-25 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16191	PG0342	2017-08-14 19:25:00+03	2017-08-14 20:30:00+03	PES	DME	Arrived	CR2	2017-08-14 19:27:00+03	2017-08-14 20:32:00+03
16192	PG0342	2017-09-05 19:25:00+03	2017-09-05 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16193	PG0342	2017-08-27 19:25:00+03	2017-08-27 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16194	PG0342	2017-08-21 19:25:00+03	2017-08-21 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16195	PG0342	2017-08-17 19:25:00+03	2017-08-17 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16196	PG0342	2017-07-19 19:25:00+03	2017-07-19 20:30:00+03	PES	DME	Arrived	CR2	2017-07-19 19:26:00+03	2017-07-19 20:30:00+03
16197	PG0342	2017-07-22 19:25:00+03	2017-07-22 20:30:00+03	PES	DME	Arrived	CR2	2017-07-22 19:25:00+03	2017-07-22 20:31:00+03
16198	PG0342	2017-09-13 19:25:00+03	2017-09-13 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16199	PG0342	2017-07-16 19:25:00+03	2017-07-16 20:30:00+03	PES	DME	Arrived	CR2	2017-07-16 19:29:00+03	2017-07-16 20:35:00+03
16200	PG0342	2017-08-22 19:25:00+03	2017-08-22 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16201	PG0342	2017-09-10 19:25:00+03	2017-09-10 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16202	PG0342	2017-08-04 19:25:00+03	2017-08-04 20:30:00+03	PES	DME	Arrived	CR2	2017-08-04 19:29:00+03	2017-08-04 20:33:00+03
16203	PG0342	2017-08-29 19:25:00+03	2017-08-29 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16204	PG0342	2017-08-28 19:25:00+03	2017-08-28 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16205	PG0342	2017-08-30 19:25:00+03	2017-08-30 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16206	PG0342	2017-09-07 19:25:00+03	2017-09-07 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16207	PG0342	2017-09-11 19:25:00+03	2017-09-11 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16208	PG0342	2017-07-30 19:25:00+03	2017-07-30 20:30:00+03	PES	DME	Arrived	CR2	2017-07-30 19:29:00+03	2017-07-30 20:32:00+03
16209	PG0342	2017-08-03 19:25:00+03	2017-08-03 20:30:00+03	PES	DME	Arrived	CR2	2017-08-03 19:31:00+03	2017-08-03 20:35:00+03
16210	PG0342	2017-08-19 19:25:00+03	2017-08-19 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16211	PG0342	2017-07-23 19:25:00+03	2017-07-23 20:30:00+03	PES	DME	Arrived	CR2	2017-07-23 19:28:00+03	2017-07-23 20:33:00+03
16212	PG0342	2017-07-18 19:25:00+03	2017-07-18 20:30:00+03	PES	DME	Arrived	CR2	2017-07-18 19:29:00+03	2017-07-18 20:34:00+03
16213	PG0342	2017-08-05 19:25:00+03	2017-08-05 20:30:00+03	PES	DME	Arrived	CR2	2017-08-05 19:27:00+03	2017-08-05 20:32:00+03
16214	PG0342	2017-08-31 19:25:00+03	2017-08-31 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16215	PG0342	2017-09-04 19:25:00+03	2017-09-04 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16216	PG0342	2017-08-13 19:25:00+03	2017-08-13 20:30:00+03	PES	DME	Arrived	CR2	2017-08-13 19:28:00+03	2017-08-13 20:32:00+03
16217	PG0342	2017-07-29 19:25:00+03	2017-07-29 20:30:00+03	PES	DME	Arrived	CR2	2017-07-29 19:26:00+03	2017-07-29 20:31:00+03
16218	PG0342	2017-08-16 19:25:00+03	2017-08-16 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16219	PG0342	2017-08-06 19:25:00+03	2017-08-06 20:30:00+03	PES	DME	Arrived	CR2	2017-08-06 19:28:00+03	2017-08-06 20:34:00+03
16220	PG0342	2017-09-08 19:25:00+03	2017-09-08 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16221	PG0342	2017-09-02 19:25:00+03	2017-09-02 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16222	PG0342	2017-09-09 19:25:00+03	2017-09-09 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16223	PG0342	2017-08-09 19:25:00+03	2017-08-09 20:30:00+03	PES	DME	Arrived	CR2	2017-08-09 19:31:00+03	2017-08-09 20:36:00+03
16224	PG0342	2017-07-26 19:25:00+03	2017-07-26 20:30:00+03	PES	DME	Arrived	CR2	2017-07-26 19:27:00+03	2017-07-26 20:32:00+03
16225	PG0342	2017-08-24 19:25:00+03	2017-08-24 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16226	PG0342	2017-07-28 19:25:00+03	2017-07-28 20:30:00+03	PES	DME	Arrived	CR2	2017-07-28 19:30:00+03	2017-07-28 20:35:00+03
16227	PG0342	2017-07-24 19:25:00+03	2017-07-24 20:30:00+03	PES	DME	Arrived	CR2	2017-07-24 19:28:00+03	2017-07-24 20:33:00+03
16228	PG0342	2017-08-26 19:25:00+03	2017-08-26 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16229	PG0342	2017-09-12 19:25:00+03	2017-09-12 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16230	PG0342	2017-09-06 19:25:00+03	2017-09-06 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16231	PG0342	2017-07-17 19:25:00+03	2017-07-17 20:30:00+03	PES	DME	Arrived	CR2	2017-07-17 23:06:00+03	2017-07-18 00:11:00+03
16232	PG0342	2017-08-01 19:25:00+03	2017-08-01 20:30:00+03	PES	DME	Arrived	CR2	2017-08-01 19:28:00+03	2017-08-01 20:33:00+03
16233	PG0342	2017-07-25 19:25:00+03	2017-07-25 20:30:00+03	PES	DME	Arrived	CR2	2017-07-25 19:30:00+03	2017-07-25 20:35:00+03
16234	PG0342	2017-08-08 19:25:00+03	2017-08-08 20:30:00+03	PES	DME	Arrived	CR2	2017-08-08 19:27:00+03	2017-08-08 20:32:00+03
16235	PG0342	2017-08-12 19:25:00+03	2017-08-12 20:30:00+03	PES	DME	Arrived	CR2	2017-08-12 19:29:00+03	2017-08-12 20:33:00+03
16236	PG0342	2017-07-21 19:25:00+03	2017-07-21 20:30:00+03	PES	DME	Arrived	CR2	2017-07-21 19:26:00+03	2017-07-21 20:31:00+03
16237	PG0342	2017-07-20 19:25:00+03	2017-07-20 20:30:00+03	PES	DME	Arrived	CR2	2017-07-20 19:28:00+03	2017-07-20 20:32:00+03
16238	PG0342	2017-08-02 19:25:00+03	2017-08-02 20:30:00+03	PES	DME	Arrived	CR2	2017-08-02 19:28:00+03	2017-08-02 20:33:00+03
16239	PG0342	2017-08-18 19:25:00+03	2017-08-18 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16240	PG0342	2017-08-23 19:25:00+03	2017-08-23 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16241	PG0342	2017-08-11 19:25:00+03	2017-08-11 20:30:00+03	PES	DME	Arrived	CR2	2017-08-11 19:27:00+03	2017-08-11 20:32:00+03
16242	PG0342	2017-08-10 19:25:00+03	2017-08-10 20:30:00+03	PES	DME	Arrived	CR2	2017-08-10 19:29:00+03	2017-08-10 20:34:00+03
16243	PG0342	2017-09-01 19:25:00+03	2017-09-01 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16244	PG0342	2017-08-15 19:25:00+03	2017-08-15 20:30:00+03	PES	DME	On Time	CR2	\N	\N
16245	PG0342	2017-08-07 19:25:00+03	2017-08-07 20:30:00+03	PES	DME	Arrived	CR2	2017-08-07 19:32:00+03	2017-08-07 20:37:00+03
16246	PG0342	2017-08-20 19:25:00+03	2017-08-20 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16247	PG0342	2017-09-03 19:25:00+03	2017-09-03 20:30:00+03	PES	DME	Scheduled	CR2	\N	\N
16248	PG0342	2017-07-31 19:25:00+03	2017-07-31 20:30:00+03	PES	DME	Arrived	CR2	2017-07-31 19:27:00+03	2017-07-31 20:31:00+03
16249	PG0342	2017-09-14 19:25:00+03	2017-09-14 20:30:00+03	PES	DME	Cancelled	CR2	\N	\N
16250	PG0342	2017-07-27 19:25:00+03	2017-07-27 20:30:00+03	PES	DME	Arrived	CR2	2017-07-27 19:26:00+03	2017-07-27 20:31:00+03
16251	PG0051	2017-08-23 11:50:00+03	2017-08-23 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16252	PG0051	2017-09-01 11:50:00+03	2017-09-01 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16253	PG0051	2017-08-16 11:50:00+03	2017-08-16 12:50:00+03	PES	VKO	On Time	CR2	\N	\N
16254	PG0051	2017-07-20 11:50:00+03	2017-07-20 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-20 11:52:00+03	2017-07-20 12:52:00+03
16255	PG0051	2017-07-26 11:50:00+03	2017-07-26 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-26 11:50:00+03	2017-07-26 12:48:00+03
16256	PG0051	2017-07-21 11:50:00+03	2017-07-21 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-21 11:53:00+03	2017-07-21 12:54:00+03
16257	PG0051	2017-09-09 11:50:00+03	2017-09-09 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16258	PG0051	2017-07-27 11:50:00+03	2017-07-27 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-27 11:53:00+03	2017-07-27 12:53:00+03
16259	PG0051	2017-09-14 11:50:00+03	2017-09-14 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16260	PG0051	2017-08-21 11:50:00+03	2017-08-21 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16261	PG0051	2017-08-25 11:50:00+03	2017-08-25 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16262	PG0051	2017-09-05 11:50:00+03	2017-09-05 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16263	PG0051	2017-07-30 11:50:00+03	2017-07-30 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-30 11:56:00+03	2017-07-30 12:56:00+03
16264	PG0051	2017-08-18 11:50:00+03	2017-08-18 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16265	PG0051	2017-08-11 11:50:00+03	2017-08-11 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-11 11:54:00+03	2017-08-11 12:53:00+03
16266	PG0051	2017-09-13 11:50:00+03	2017-09-13 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16267	PG0051	2017-08-24 11:50:00+03	2017-08-24 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16268	PG0051	2017-08-29 11:50:00+03	2017-08-29 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16269	PG0051	2017-07-28 11:50:00+03	2017-07-28 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-28 11:52:00+03	2017-07-28 12:51:00+03
16270	PG0051	2017-07-19 11:50:00+03	2017-07-19 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-19 11:54:00+03	2017-07-19 12:55:00+03
16271	PG0051	2017-08-03 11:50:00+03	2017-08-03 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-03 11:52:00+03	2017-08-03 12:52:00+03
16272	PG0051	2017-07-16 11:50:00+03	2017-07-16 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-16 11:56:00+03	2017-07-16 12:56:00+03
16273	PG0051	2017-08-04 11:50:00+03	2017-08-04 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-04 11:55:00+03	2017-08-04 12:54:00+03
16274	PG0051	2017-08-05 11:50:00+03	2017-08-05 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-05 11:54:00+03	2017-08-05 12:55:00+03
16275	PG0051	2017-09-10 11:50:00+03	2017-09-10 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16276	PG0051	2017-09-07 11:50:00+03	2017-09-07 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16277	PG0051	2017-07-31 11:50:00+03	2017-07-31 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-31 11:55:00+03	2017-07-31 12:54:00+03
16278	PG0051	2017-08-01 11:50:00+03	2017-08-01 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-01 11:55:00+03	2017-08-01 12:55:00+03
16279	PG0051	2017-09-06 11:50:00+03	2017-09-06 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16280	PG0051	2017-08-08 11:50:00+03	2017-08-08 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-08 14:26:00+03	2017-08-08 15:26:00+03
16281	PG0051	2017-08-15 11:50:00+03	2017-08-15 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-15 11:55:00+03	2017-08-15 12:56:00+03
16282	PG0051	2017-07-18 11:50:00+03	2017-07-18 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-18 11:53:00+03	2017-07-18 12:53:00+03
16283	PG0051	2017-07-23 11:50:00+03	2017-07-23 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-23 11:52:00+03	2017-07-23 12:53:00+03
16284	PG0051	2017-07-25 11:50:00+03	2017-07-25 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-25 11:53:00+03	2017-07-25 12:54:00+03
16285	PG0051	2017-08-17 11:50:00+03	2017-08-17 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16286	PG0051	2017-09-04 11:50:00+03	2017-09-04 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16287	PG0051	2017-08-19 11:50:00+03	2017-08-19 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16288	PG0051	2017-09-02 11:50:00+03	2017-09-02 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16289	PG0051	2017-08-09 11:50:00+03	2017-08-09 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-09 11:51:00+03	2017-08-09 12:51:00+03
16290	PG0051	2017-07-24 11:50:00+03	2017-07-24 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-24 11:52:00+03	2017-07-24 12:52:00+03
16291	PG0051	2017-07-22 11:50:00+03	2017-07-22 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-22 11:53:00+03	2017-07-22 12:53:00+03
16292	PG0051	2017-09-11 11:50:00+03	2017-09-11 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16293	PG0051	2017-08-13 11:50:00+03	2017-08-13 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-13 11:51:00+03	2017-08-13 12:51:00+03
16294	PG0051	2017-08-30 11:50:00+03	2017-08-30 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16295	PG0051	2017-08-28 11:50:00+03	2017-08-28 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16296	PG0051	2017-08-14 11:50:00+03	2017-08-14 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-14 11:54:00+03	2017-08-14 12:54:00+03
16297	PG0051	2017-07-29 11:50:00+03	2017-07-29 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-29 11:54:00+03	2017-07-29 12:54:00+03
16298	PG0051	2017-08-31 11:50:00+03	2017-08-31 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16299	PG0051	2017-08-27 11:50:00+03	2017-08-27 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16300	PG0051	2017-08-06 11:50:00+03	2017-08-06 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-06 11:51:00+03	2017-08-06 12:51:00+03
16301	PG0051	2017-08-07 11:50:00+03	2017-08-07 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-07 11:50:00+03	2017-08-07 12:50:00+03
16302	PG0051	2017-08-12 11:50:00+03	2017-08-12 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-12 11:52:00+03	2017-08-12 12:52:00+03
16303	PG0051	2017-08-20 11:50:00+03	2017-08-20 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16304	PG0051	2017-08-26 11:50:00+03	2017-08-26 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16305	PG0051	2017-07-17 11:50:00+03	2017-07-17 12:50:00+03	PES	VKO	Arrived	CR2	2017-07-17 11:52:00+03	2017-07-17 12:51:00+03
16306	PG0051	2017-08-10 11:50:00+03	2017-08-10 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-10 11:53:00+03	2017-08-10 12:52:00+03
16307	PG0051	2017-08-22 11:50:00+03	2017-08-22 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16308	PG0051	2017-08-02 11:50:00+03	2017-08-02 12:50:00+03	PES	VKO	Arrived	CR2	2017-08-02 11:54:00+03	2017-08-02 12:53:00+03
16309	PG0051	2017-09-08 11:50:00+03	2017-09-08 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16310	PG0051	2017-09-12 11:50:00+03	2017-09-12 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16311	PG0051	2017-09-03 11:50:00+03	2017-09-03 12:50:00+03	PES	VKO	Scheduled	CR2	\N	\N
16312	PG0459	2017-08-02 14:35:00+03	2017-08-02 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-02 14:38:00+03	2017-08-02 16:54:00+03
16313	PG0458	2017-08-13 14:00:00+03	2017-08-13 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-13 14:02:00+03	2017-08-13 16:16:00+03
16314	PG0459	2017-08-13 14:35:00+03	2017-08-13 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-13 14:40:00+03	2017-08-13 16:56:00+03
16315	PG0458	2017-08-31 14:00:00+03	2017-08-31 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16316	PG0459	2017-08-31 14:35:00+03	2017-08-31 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16317	PG0459	2017-08-12 14:35:00+03	2017-08-12 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-12 14:39:00+03	2017-08-12 16:52:00+03
16318	PG0458	2017-08-12 14:00:00+03	2017-08-12 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-12 14:02:00+03	2017-08-12 16:17:00+03
16319	PG0459	2017-08-11 14:35:00+03	2017-08-11 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-11 14:38:00+03	2017-08-11 16:54:00+03
16320	PG0458	2017-08-11 14:00:00+03	2017-08-11 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-11 14:04:00+03	2017-08-11 16:20:00+03
16321	PG0458	2017-09-01 14:00:00+03	2017-09-01 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16322	PG0459	2017-09-01 14:35:00+03	2017-09-01 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16323	PG0459	2017-08-10 14:35:00+03	2017-08-10 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-10 17:56:00+03	2017-08-10 20:10:00+03
16324	PG0458	2017-08-10 14:00:00+03	2017-08-10 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-10 14:08:00+03	2017-08-10 16:25:00+03
16325	PG0458	2017-08-14 14:00:00+03	2017-08-14 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-14 14:02:00+03	2017-08-14 16:17:00+03
16326	PG0459	2017-08-14 14:35:00+03	2017-08-14 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-14 14:39:00+03	2017-08-14 16:54:00+03
16327	PG0459	2017-08-30 14:35:00+03	2017-08-30 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16328	PG0458	2017-08-30 14:00:00+03	2017-08-30 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16329	PG0459	2017-08-09 14:35:00+03	2017-08-09 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-09 14:37:00+03	2017-08-09 16:54:00+03
16330	PG0458	2017-08-09 14:00:00+03	2017-08-09 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-09 14:08:00+03	2017-08-09 16:25:00+03
16331	PG0458	2017-09-02 14:00:00+03	2017-09-02 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16332	PG0459	2017-09-02 14:35:00+03	2017-09-02 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16333	PG0459	2017-08-08 14:35:00+03	2017-08-08 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-08 14:38:00+03	2017-08-08 16:56:00+03
16334	PG0458	2017-08-08 14:00:00+03	2017-08-08 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-08 14:02:00+03	2017-08-08 16:17:00+03
16335	PG0458	2017-08-15 14:00:00+03	2017-08-15 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-15 14:05:00+03	2017-08-15 16:20:00+03
16336	PG0459	2017-08-15 14:35:00+03	2017-08-15 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-15 14:36:00+03	2017-08-15 16:50:00+03
16337	PG0459	2017-08-07 14:35:00+03	2017-08-07 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-07 14:36:00+03	2017-08-07 16:51:00+03
16338	PG0458	2017-08-07 14:00:00+03	2017-08-07 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-07 14:07:00+03	2017-08-07 16:24:00+03
16339	PG0458	2017-09-03 14:00:00+03	2017-09-03 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16340	PG0459	2017-09-03 14:35:00+03	2017-09-03 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16341	PG0459	2017-08-06 14:35:00+03	2017-08-06 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-06 14:40:00+03	2017-08-06 16:55:00+03
16342	PG0458	2017-08-06 14:00:00+03	2017-08-06 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-06 14:03:00+03	2017-08-06 16:19:00+03
16343	PG0458	2017-08-16 14:00:00+03	2017-08-16 16:15:00+03	PES	SVO	On Time	CN1	\N	\N
16344	PG0459	2017-08-16 14:35:00+03	2017-08-16 16:50:00+03	PES	SVO	On Time	CN1	\N	\N
16345	PG0459	2017-08-05 14:35:00+03	2017-08-05 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-05 14:37:00+03	2017-08-05 16:53:00+03
16346	PG0458	2017-08-05 14:00:00+03	2017-08-05 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-05 14:04:00+03	2017-08-05 16:18:00+03
16347	PG0458	2017-09-04 14:00:00+03	2017-09-04 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16348	PG0459	2017-09-04 14:35:00+03	2017-09-04 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16349	PG0459	2017-08-29 14:35:00+03	2017-08-29 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16350	PG0458	2017-08-29 14:00:00+03	2017-08-29 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16351	PG0459	2017-08-04 14:35:00+03	2017-08-04 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-04 14:37:00+03	2017-08-04 16:53:00+03
16352	PG0458	2017-08-04 14:00:00+03	2017-08-04 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-04 14:03:00+03	2017-08-04 16:20:00+03
16353	PG0459	2017-08-03 14:35:00+03	2017-08-03 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-03 14:40:00+03	2017-08-03 16:53:00+03
16354	PG0458	2017-08-03 14:00:00+03	2017-08-03 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-03 14:02:00+03	2017-08-03 16:20:00+03
16355	PG0458	2017-09-05 14:00:00+03	2017-09-05 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16356	PG0459	2017-09-05 14:35:00+03	2017-09-05 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16357	PG0458	2017-08-17 14:00:00+03	2017-08-17 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16358	PG0459	2017-08-17 14:35:00+03	2017-08-17 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16359	PG0458	2017-08-02 14:00:00+03	2017-08-02 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-02 14:04:00+03	2017-08-02 16:19:00+03
16360	PG0459	2017-08-01 14:35:00+03	2017-08-01 16:50:00+03	PES	SVO	Arrived	CN1	2017-08-01 14:40:00+03	2017-08-01 16:57:00+03
16361	PG0458	2017-08-01 14:00:00+03	2017-08-01 16:15:00+03	PES	SVO	Arrived	CN1	2017-08-01 14:02:00+03	2017-08-01 16:18:00+03
16362	PG0458	2017-09-06 14:00:00+03	2017-09-06 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16363	PG0459	2017-09-06 14:35:00+03	2017-09-06 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16364	PG0458	2017-08-18 14:00:00+03	2017-08-18 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16365	PG0459	2017-08-18 14:35:00+03	2017-08-18 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16366	PG0459	2017-07-31 14:35:00+03	2017-07-31 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-31 14:38:00+03	2017-07-31 16:52:00+03
16367	PG0458	2017-07-31 14:00:00+03	2017-07-31 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-31 17:34:00+03	2017-07-31 19:51:00+03
16368	PG0459	2017-08-28 14:35:00+03	2017-08-28 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16369	PG0458	2017-08-28 14:00:00+03	2017-08-28 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16370	PG0459	2017-07-30 14:35:00+03	2017-07-30 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-30 14:39:00+03	2017-07-30 16:52:00+03
16371	PG0458	2017-07-30 14:00:00+03	2017-07-30 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-30 14:06:00+03	2017-07-30 16:22:00+03
16372	PG0458	2017-09-07 14:00:00+03	2017-09-07 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16373	PG0459	2017-09-07 14:35:00+03	2017-09-07 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16374	PG0458	2017-08-19 14:00:00+03	2017-08-19 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16375	PG0459	2017-08-19 14:35:00+03	2017-08-19 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16376	PG0459	2017-07-29 14:35:00+03	2017-07-29 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-29 14:35:00+03	2017-07-29 16:49:00+03
16377	PG0458	2017-07-29 14:00:00+03	2017-07-29 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-29 14:02:00+03	2017-07-29 16:17:00+03
16378	PG0459	2017-07-28 14:35:00+03	2017-07-28 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-28 14:39:00+03	2017-07-28 16:52:00+03
16379	PG0458	2017-07-28 14:00:00+03	2017-07-28 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-28 14:02:00+03	2017-07-28 16:15:00+03
16380	PG0458	2017-09-08 14:00:00+03	2017-09-08 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16381	PG0459	2017-09-08 14:35:00+03	2017-09-08 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16382	PG0459	2017-07-27 14:35:00+03	2017-07-27 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-27 14:38:00+03	2017-07-27 16:53:00+03
16383	PG0458	2017-07-27 14:00:00+03	2017-07-27 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-27 14:03:00+03	2017-07-27 16:18:00+03
16384	PG0458	2017-08-20 14:00:00+03	2017-08-20 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16385	PG0459	2017-08-20 14:35:00+03	2017-08-20 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16386	PG0459	2017-07-26 14:35:00+03	2017-07-26 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-26 14:37:00+03	2017-07-26 16:53:00+03
16387	PG0458	2017-07-26 14:00:00+03	2017-07-26 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-26 14:01:00+03	2017-07-26 16:16:00+03
16388	PG0458	2017-09-09 14:00:00+03	2017-09-09 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16389	PG0459	2017-09-09 14:35:00+03	2017-09-09 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16390	PG0459	2017-08-27 14:35:00+03	2017-08-27 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16391	PG0458	2017-08-27 14:00:00+03	2017-08-27 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16392	PG0459	2017-07-25 14:35:00+03	2017-07-25 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-25 18:13:00+03	2017-07-25 20:28:00+03
16393	PG0458	2017-07-25 14:00:00+03	2017-07-25 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-25 14:02:00+03	2017-07-25 16:16:00+03
16394	PG0458	2017-09-10 14:00:00+03	2017-09-10 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16395	PG0459	2017-09-10 14:35:00+03	2017-09-10 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16396	PG0459	2017-07-24 14:35:00+03	2017-07-24 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-24 14:37:00+03	2017-07-24 16:50:00+03
16397	PG0458	2017-08-21 14:00:00+03	2017-08-21 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16398	PG0459	2017-08-21 14:35:00+03	2017-08-21 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16399	PG0458	2017-07-24 14:00:00+03	2017-07-24 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-24 14:03:00+03	2017-07-24 16:19:00+03
16400	PG0459	2017-07-23 14:35:00+03	2017-07-23 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-23 14:42:00+03	2017-07-23 16:58:00+03
16401	PG0458	2017-07-23 14:00:00+03	2017-07-23 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-23 14:04:00+03	2017-07-23 16:18:00+03
16402	PG0458	2017-09-11 14:00:00+03	2017-09-11 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16403	PG0459	2017-09-11 14:35:00+03	2017-09-11 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16404	PG0459	2017-07-22 14:35:00+03	2017-07-22 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-22 14:40:00+03	2017-07-22 16:54:00+03
16405	PG0458	2017-07-22 14:00:00+03	2017-07-22 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-22 14:02:00+03	2017-07-22 16:16:00+03
16406	PG0458	2017-08-22 14:00:00+03	2017-08-22 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16407	PG0459	2017-08-22 14:35:00+03	2017-08-22 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16408	PG0459	2017-08-26 14:35:00+03	2017-08-26 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16409	PG0458	2017-08-26 14:00:00+03	2017-08-26 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16410	PG0459	2017-07-21 14:35:00+03	2017-07-21 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-21 14:38:00+03	2017-07-21 16:53:00+03
16411	PG0458	2017-07-21 14:00:00+03	2017-07-21 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-21 14:05:00+03	2017-07-21 16:20:00+03
16412	PG0458	2017-09-12 14:00:00+03	2017-09-12 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16413	PG0459	2017-09-12 14:35:00+03	2017-09-12 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16414	PG0459	2017-07-20 14:35:00+03	2017-07-20 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-20 14:35:00+03	2017-07-20 16:50:00+03
16415	PG0458	2017-07-20 14:00:00+03	2017-07-20 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-20 14:06:00+03	2017-07-20 16:20:00+03
16416	PG0458	2017-08-23 14:00:00+03	2017-08-23 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16417	PG0459	2017-08-23 14:35:00+03	2017-08-23 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16418	PG0459	2017-07-19 14:35:00+03	2017-07-19 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-19 14:35:00+03	2017-07-19 16:50:00+03
16419	PG0458	2017-07-19 14:00:00+03	2017-07-19 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-19 14:02:00+03	2017-07-19 16:15:00+03
16420	PG0458	2017-09-13 14:00:00+03	2017-09-13 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16421	PG0459	2017-09-13 14:35:00+03	2017-09-13 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16422	PG0459	2017-07-18 14:35:00+03	2017-07-18 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-18 14:40:00+03	2017-07-18 16:55:00+03
16423	PG0458	2017-07-18 14:00:00+03	2017-07-18 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-18 14:04:00+03	2017-07-18 16:20:00+03
16424	PG0458	2017-09-14 14:00:00+03	2017-09-14 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16425	PG0459	2017-07-17 14:35:00+03	2017-07-17 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-17 14:37:00+03	2017-07-17 16:52:00+03
16426	PG0458	2017-07-17 14:00:00+03	2017-07-17 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-17 14:01:00+03	2017-07-17 16:19:00+03
16427	PG0458	2017-08-24 14:00:00+03	2017-08-24 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16428	PG0459	2017-08-24 14:35:00+03	2017-08-24 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16429	PG0459	2017-08-25 14:35:00+03	2017-08-25 16:50:00+03	PES	SVO	Scheduled	CN1	\N	\N
16430	PG0458	2017-08-25 14:00:00+03	2017-08-25 16:15:00+03	PES	SVO	Scheduled	CN1	\N	\N
16431	PG0459	2017-07-16 14:35:00+03	2017-07-16 16:50:00+03	PES	SVO	Arrived	CN1	2017-07-16 14:38:00+03	2017-07-16 16:51:00+03
16432	PG0458	2017-07-16 14:00:00+03	2017-07-16 16:15:00+03	PES	SVO	Arrived	CN1	2017-07-16 14:06:00+03	2017-07-16 16:20:00+03
16433	PG0459	2017-09-14 14:35:00+03	2017-09-14 16:50:00+03	PES	SVO	Cancelled	CN1	\N	\N
16434	PG0558	2017-09-11 09:45:00+03	2017-09-11 12:05:00+03	PES	ROV	Cancelled	CR2	\N	\N
16435	PG0558	2017-08-07 09:45:00+03	2017-08-07 12:05:00+03	PES	ROV	Arrived	CR2	2017-08-07 09:52:00+03	2017-08-07 12:14:00+03
16436	PG0558	2017-09-04 09:45:00+03	2017-09-04 12:05:00+03	PES	ROV	Scheduled	CR2	\N	\N
16437	PG0558	2017-07-17 09:45:00+03	2017-07-17 12:05:00+03	PES	ROV	Arrived	CR2	2017-07-17 09:47:00+03	2017-07-17 12:08:00+03
16438	PG0558	2017-07-31 09:45:00+03	2017-07-31 12:05:00+03	PES	ROV	Arrived	CR2	2017-07-31 09:47:00+03	2017-07-31 12:08:00+03
16439	PG0558	2017-08-21 09:45:00+03	2017-08-21 12:05:00+03	PES	ROV	Scheduled	CR2	\N	\N
16440	PG0558	2017-07-24 09:45:00+03	2017-07-24 12:05:00+03	PES	ROV	Arrived	CR2	2017-07-24 09:51:00+03	2017-07-24 12:10:00+03
16441	PG0558	2017-08-28 09:45:00+03	2017-08-28 12:05:00+03	PES	ROV	Scheduled	CR2	\N	\N
16442	PG0558	2017-08-14 09:45:00+03	2017-08-14 12:05:00+03	PES	ROV	Arrived	CR2	2017-08-14 13:41:00+03	2017-08-14 15:59:00+03
16443	PG0631	2017-08-17 11:25:00+03	2017-08-17 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16444	PG0631	2017-08-30 11:25:00+03	2017-08-30 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16445	PG0631	2017-08-22 11:25:00+03	2017-08-22 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16446	PG0631	2017-07-19 11:25:00+03	2017-07-19 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-19 11:28:00+03	2017-07-19 14:01:00+03
16447	PG0631	2017-08-04 11:25:00+03	2017-08-04 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-04 15:25:00+03	2017-08-04 17:57:00+03
16448	PG0631	2017-09-05 11:25:00+03	2017-09-05 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16449	PG0631	2017-08-20 11:25:00+03	2017-08-20 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16450	PG0631	2017-07-16 11:25:00+03	2017-07-16 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-16 14:30:00+03	2017-07-16 17:06:00+03
16451	PG0631	2017-08-21 11:25:00+03	2017-08-21 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16452	PG0631	2017-09-12 11:25:00+03	2017-09-12 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16453	PG0631	2017-07-26 11:25:00+03	2017-07-26 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-26 11:29:00+03	2017-07-26 14:04:00+03
16454	PG0631	2017-08-19 11:25:00+03	2017-08-19 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16455	PG0631	2017-08-15 11:25:00+03	2017-08-15 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-15 15:18:00+03	2017-08-15 17:53:00+03
16456	PG0631	2017-07-20 11:25:00+03	2017-07-20 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-20 11:26:00+03	2017-07-20 14:02:00+03
16457	PG0631	2017-07-21 11:25:00+03	2017-07-21 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-21 11:29:00+03	2017-07-21 14:04:00+03
16458	PG0631	2017-08-12 11:25:00+03	2017-08-12 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-12 11:28:00+03	2017-08-12 14:01:00+03
16459	PG0631	2017-08-03 11:25:00+03	2017-08-03 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-03 11:27:00+03	2017-08-03 14:04:00+03
16460	PG0631	2017-08-26 11:25:00+03	2017-08-26 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16461	PG0631	2017-07-24 11:25:00+03	2017-07-24 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-24 11:27:00+03	2017-07-24 14:03:00+03
16462	PG0631	2017-09-01 11:25:00+03	2017-09-01 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16463	PG0631	2017-07-18 11:25:00+03	2017-07-18 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-18 11:26:00+03	2017-07-18 14:00:00+03
16464	PG0631	2017-08-31 11:25:00+03	2017-08-31 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16465	PG0631	2017-08-27 11:25:00+03	2017-08-27 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16466	PG0631	2017-07-17 11:25:00+03	2017-07-17 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-17 11:28:00+03	2017-07-17 14:04:00+03
16467	PG0631	2017-08-07 11:25:00+03	2017-08-07 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-07 11:26:00+03	2017-08-07 14:02:00+03
16468	PG0631	2017-07-22 11:25:00+03	2017-07-22 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-22 11:27:00+03	2017-07-22 14:03:00+03
16469	PG0631	2017-09-06 11:25:00+03	2017-09-06 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16470	PG0631	2017-08-05 11:25:00+03	2017-08-05 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-05 11:25:00+03	2017-08-05 13:58:00+03
16471	PG0631	2017-09-09 11:25:00+03	2017-09-09 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16472	PG0631	2017-08-08 11:25:00+03	2017-08-08 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-08 11:29:00+03	2017-08-08 14:02:00+03
16473	PG0631	2017-09-03 11:25:00+03	2017-09-03 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16474	PG0631	2017-08-29 11:25:00+03	2017-08-29 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16475	PG0631	2017-08-13 11:25:00+03	2017-08-13 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-13 11:29:00+03	2017-08-13 14:05:00+03
16476	PG0631	2017-07-27 11:25:00+03	2017-07-27 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-27 11:29:00+03	2017-07-27 14:02:00+03
16477	PG0631	2017-09-10 11:25:00+03	2017-09-10 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16478	PG0631	2017-09-11 11:25:00+03	2017-09-11 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16479	PG0631	2017-08-16 11:25:00+03	2017-08-16 14:00:00+03	PES	TJM	On Time	CR2	\N	\N
16480	PG0631	2017-09-04 11:25:00+03	2017-09-04 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16481	PG0631	2017-09-02 11:25:00+03	2017-09-02 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16482	PG0631	2017-08-10 11:25:00+03	2017-08-10 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-10 11:26:00+03	2017-08-10 14:04:00+03
16483	PG0631	2017-08-09 11:25:00+03	2017-08-09 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-09 11:28:00+03	2017-08-09 14:04:00+03
16484	PG0631	2017-09-07 11:25:00+03	2017-09-07 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16485	PG0631	2017-08-25 11:25:00+03	2017-08-25 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16486	PG0631	2017-07-31 11:25:00+03	2017-07-31 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-31 11:30:00+03	2017-07-31 14:03:00+03
16487	PG0631	2017-08-28 11:25:00+03	2017-08-28 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16488	PG0631	2017-09-08 11:25:00+03	2017-09-08 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16489	PG0631	2017-08-18 11:25:00+03	2017-08-18 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16490	PG0631	2017-07-28 11:25:00+03	2017-07-28 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-28 11:30:00+03	2017-07-28 14:05:00+03
16491	PG0631	2017-08-24 11:25:00+03	2017-08-24 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16492	PG0631	2017-07-30 11:25:00+03	2017-07-30 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-30 15:00:00+03	2017-07-30 17:36:00+03
16493	PG0631	2017-07-29 11:25:00+03	2017-07-29 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-29 11:29:00+03	2017-07-29 14:05:00+03
16494	PG0631	2017-09-14 11:25:00+03	2017-09-14 14:00:00+03	PES	TJM	Cancelled	CR2	\N	\N
16495	PG0631	2017-07-23 11:25:00+03	2017-07-23 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-23 11:27:00+03	2017-07-23 14:02:00+03
16496	PG0631	2017-09-13 11:25:00+03	2017-09-13 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16497	PG0631	2017-08-14 11:25:00+03	2017-08-14 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-14 11:30:00+03	2017-08-14 14:06:00+03
16498	PG0631	2017-08-23 11:25:00+03	2017-08-23 14:00:00+03	PES	TJM	Scheduled	CR2	\N	\N
16499	PG0631	2017-08-01 11:25:00+03	2017-08-01 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-01 11:28:00+03	2017-08-01 14:06:00+03
16500	PG0631	2017-08-11 11:25:00+03	2017-08-11 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-11 14:16:00+03	2017-08-11 16:50:00+03
16501	PG0631	2017-08-06 11:25:00+03	2017-08-06 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-06 11:26:00+03	2017-08-06 13:59:00+03
16502	PG0631	2017-07-25 11:25:00+03	2017-07-25 14:00:00+03	PES	TJM	Arrived	CR2	2017-07-25 11:32:00+03	2017-07-25 14:08:00+03
16503	PG0631	2017-08-02 11:25:00+03	2017-08-02 14:00:00+03	PES	TJM	Arrived	CR2	2017-08-02 11:29:00+03	2017-08-02 14:03:00+03
16504	PG0430	2017-08-20 15:55:00+03	2017-08-20 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16505	PG0430	2017-09-03 15:55:00+03	2017-09-03 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16506	PG0430	2017-08-17 15:55:00+03	2017-08-17 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16507	PG0430	2017-07-20 15:55:00+03	2017-07-20 19:25:00+03	PES	LPK	Arrived	CN1	2017-07-20 15:57:00+03	2017-07-20 19:28:00+03
16508	PG0430	2017-08-24 15:55:00+03	2017-08-24 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16509	PG0430	2017-08-06 15:55:00+03	2017-08-06 19:25:00+03	PES	LPK	Arrived	CN1	2017-08-06 15:58:00+03	2017-08-06 19:26:00+03
16510	PG0430	2017-08-10 15:55:00+03	2017-08-10 19:25:00+03	PES	LPK	Arrived	CN1	2017-08-10 16:00:00+03	2017-08-10 19:29:00+03
16511	PG0430	2017-07-30 15:55:00+03	2017-07-30 19:25:00+03	PES	LPK	Arrived	CN1	2017-07-30 16:00:00+03	2017-07-30 19:28:00+03
16512	PG0430	2017-08-31 15:55:00+03	2017-08-31 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16513	PG0430	2017-07-16 15:55:00+03	2017-07-16 19:25:00+03	PES	LPK	Arrived	CN1	2017-07-16 15:59:00+03	2017-07-16 19:31:00+03
16514	PG0430	2017-08-27 15:55:00+03	2017-08-27 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16515	PG0430	2017-08-13 15:55:00+03	2017-08-13 19:25:00+03	PES	LPK	Arrived	CN1	2017-08-13 15:57:00+03	2017-08-13 19:25:00+03
16516	PG0430	2017-09-14 15:55:00+03	2017-09-14 19:25:00+03	PES	LPK	Cancelled	CN1	\N	\N
16517	PG0430	2017-07-23 15:55:00+03	2017-07-23 19:25:00+03	PES	LPK	Arrived	CN1	2017-07-23 15:56:00+03	2017-07-23 19:25:00+03
16518	PG0430	2017-07-27 15:55:00+03	2017-07-27 19:25:00+03	PES	LPK	Arrived	CN1	2017-07-27 15:57:00+03	2017-07-27 19:27:00+03
16519	PG0430	2017-09-10 15:55:00+03	2017-09-10 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16520	PG0430	2017-09-07 15:55:00+03	2017-09-07 19:25:00+03	PES	LPK	Scheduled	CN1	\N	\N
16521	PG0430	2017-08-03 15:55:00+03	2017-08-03 19:25:00+03	PES	LPK	Arrived	CN1	2017-08-03 15:59:00+03	2017-08-03 19:28:00+03
16522	PG0293	2017-08-31 17:30:00+03	2017-08-31 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16523	PG0293	2017-09-05 17:30:00+03	2017-09-05 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16524	PG0293	2017-08-15 17:30:00+03	2017-08-15 20:10:00+03	PES	KLF	Departed	CN1	2017-08-15 17:32:00+03	\N
16525	PG0293	2017-09-14 17:30:00+03	2017-09-14 20:10:00+03	PES	KLF	Cancelled	CN1	\N	\N
16526	PG0293	2017-08-01 17:30:00+03	2017-08-01 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-01 17:35:00+03	2017-08-01 20:15:00+03
16527	PG0293	2017-08-05 17:30:00+03	2017-08-05 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-05 17:32:00+03	2017-08-05 20:16:00+03
16528	PG0293	2017-09-09 17:30:00+03	2017-09-09 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16529	PG0293	2017-08-10 17:30:00+03	2017-08-10 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-10 17:35:00+03	2017-08-10 20:18:00+03
16530	PG0293	2017-08-29 17:30:00+03	2017-08-29 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16531	PG0293	2017-09-07 17:30:00+03	2017-09-07 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16532	PG0293	2017-07-22 17:30:00+03	2017-07-22 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-22 17:32:00+03	2017-07-22 20:12:00+03
16533	PG0293	2017-08-26 17:30:00+03	2017-08-26 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16534	PG0293	2017-08-24 17:30:00+03	2017-08-24 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16535	PG0293	2017-08-17 17:30:00+03	2017-08-17 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16536	PG0293	2017-07-25 17:30:00+03	2017-07-25 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-25 17:33:00+03	2017-07-25 20:12:00+03
16537	PG0293	2017-08-22 17:30:00+03	2017-08-22 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16538	PG0293	2017-08-19 17:30:00+03	2017-08-19 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16539	PG0293	2017-09-12 17:30:00+03	2017-09-12 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16540	PG0293	2017-07-29 17:30:00+03	2017-07-29 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-29 17:32:00+03	2017-07-29 20:12:00+03
16541	PG0293	2017-08-08 17:30:00+03	2017-08-08 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-08 17:35:00+03	2017-08-08 20:14:00+03
16542	PG0293	2017-09-02 17:30:00+03	2017-09-02 20:10:00+03	PES	KLF	Scheduled	CN1	\N	\N
16543	PG0293	2017-08-03 17:30:00+03	2017-08-03 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-03 17:32:00+03	2017-08-03 20:12:00+03
16544	PG0293	2017-07-18 17:30:00+03	2017-07-18 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-18 17:35:00+03	2017-07-18 20:14:00+03
16545	PG0293	2017-07-27 17:30:00+03	2017-07-27 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-27 17:37:00+03	2017-07-27 20:15:00+03
16546	PG0293	2017-07-20 17:30:00+03	2017-07-20 20:10:00+03	PES	KLF	Arrived	CN1	2017-07-20 17:32:00+03	2017-07-20 20:14:00+03
16547	PG0293	2017-08-12 17:30:00+03	2017-08-12 20:10:00+03	PES	KLF	Arrived	CN1	2017-08-12 17:35:00+03	2017-08-12 20:14:00+03
16548	PG0369	2017-09-04 07:30:00+03	2017-09-04 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16549	PG0369	2017-07-19 07:30:00+03	2017-07-19 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-19 07:35:00+03	2017-07-19 10:52:00+03
16550	PG0369	2017-09-03 07:30:00+03	2017-09-03 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16551	PG0369	2017-08-07 07:30:00+03	2017-08-07 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-07 07:34:00+03	2017-08-07 10:48:00+03
16552	PG0369	2017-08-19 07:30:00+03	2017-08-19 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16553	PG0369	2017-07-23 07:30:00+03	2017-07-23 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-23 07:35:00+03	2017-07-23 10:49:00+03
16554	PG0369	2017-07-30 07:30:00+03	2017-07-30 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-30 07:32:00+03	2017-07-30 10:49:00+03
16555	PG0369	2017-09-14 07:30:00+03	2017-09-14 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16556	PG0369	2017-07-22 07:30:00+03	2017-07-22 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-22 07:34:00+03	2017-07-22 10:49:00+03
16557	PG0369	2017-08-16 07:30:00+03	2017-08-16 10:45:00+03	NJC	DME	On Time	CR2	\N	\N
16558	PG0369	2017-08-18 07:30:00+03	2017-08-18 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16559	PG0369	2017-09-09 07:30:00+03	2017-09-09 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16560	PG0369	2017-07-20 07:30:00+03	2017-07-20 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-20 07:31:00+03	2017-07-20 10:46:00+03
16561	PG0369	2017-09-06 07:30:00+03	2017-09-06 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16562	PG0369	2017-08-24 07:30:00+03	2017-08-24 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16563	PG0369	2017-08-02 07:30:00+03	2017-08-02 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-02 07:31:00+03	2017-08-02 10:47:00+03
16564	PG0369	2017-08-14 07:30:00+03	2017-08-14 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-14 07:34:00+03	2017-08-14 10:50:00+03
16565	PG0369	2017-08-28 07:30:00+03	2017-08-28 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16566	PG0369	2017-07-17 07:30:00+03	2017-07-17 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-17 07:33:00+03	2017-07-17 10:45:00+03
16567	PG0369	2017-09-10 07:30:00+03	2017-09-10 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16568	PG0369	2017-08-22 07:30:00+03	2017-08-22 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16569	PG0369	2017-08-20 07:30:00+03	2017-08-20 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16570	PG0369	2017-08-06 07:30:00+03	2017-08-06 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-06 07:31:00+03	2017-08-06 10:46:00+03
16571	PG0369	2017-08-08 07:30:00+03	2017-08-08 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-08 07:31:00+03	2017-08-08 10:47:00+03
16572	PG0369	2017-08-10 07:30:00+03	2017-08-10 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-10 07:37:00+03	2017-08-10 10:54:00+03
16573	PG0369	2017-08-15 07:30:00+03	2017-08-15 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-15 07:32:00+03	2017-08-15 10:48:00+03
16574	PG0369	2017-07-24 07:30:00+03	2017-07-24 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-24 07:32:00+03	2017-07-24 10:47:00+03
16575	PG0369	2017-09-13 07:30:00+03	2017-09-13 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16576	PG0369	2017-07-18 07:30:00+03	2017-07-18 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-18 07:32:00+03	2017-07-18 10:48:00+03
16577	PG0369	2017-07-21 07:30:00+03	2017-07-21 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-21 07:32:00+03	2017-07-21 10:45:00+03
16578	PG0369	2017-09-11 07:30:00+03	2017-09-11 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16579	PG0369	2017-07-26 07:30:00+03	2017-07-26 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-26 07:31:00+03	2017-07-26 10:46:00+03
16580	PG0369	2017-07-27 07:30:00+03	2017-07-27 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-27 07:32:00+03	2017-07-27 10:47:00+03
16581	PG0369	2017-09-08 07:30:00+03	2017-09-08 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16582	PG0369	2017-07-29 07:30:00+03	2017-07-29 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-29 07:31:00+03	2017-07-29 10:48:00+03
16583	PG0369	2017-08-09 07:30:00+03	2017-08-09 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-09 07:35:00+03	2017-08-09 10:49:00+03
16584	PG0369	2017-07-28 07:30:00+03	2017-07-28 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-28 07:32:00+03	2017-07-28 10:47:00+03
16585	PG0369	2017-09-05 07:30:00+03	2017-09-05 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16586	PG0369	2017-08-03 07:30:00+03	2017-08-03 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-03 07:30:00+03	2017-08-03 10:44:00+03
16587	PG0369	2017-09-02 07:30:00+03	2017-09-02 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16588	PG0369	2017-08-31 07:30:00+03	2017-08-31 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16589	PG0369	2017-08-17 07:30:00+03	2017-08-17 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16590	PG0369	2017-07-16 07:30:00+03	2017-07-16 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-16 07:34:00+03	2017-07-16 10:47:00+03
16591	PG0369	2017-09-01 07:30:00+03	2017-09-01 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16592	PG0369	2017-08-29 07:30:00+03	2017-08-29 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16593	PG0369	2017-08-21 07:30:00+03	2017-08-21 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16594	PG0369	2017-09-12 07:30:00+03	2017-09-12 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16595	PG0369	2017-07-25 07:30:00+03	2017-07-25 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-25 07:31:00+03	2017-07-25 10:47:00+03
16596	PG0369	2017-08-27 07:30:00+03	2017-08-27 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16597	PG0369	2017-08-01 07:30:00+03	2017-08-01 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-01 07:33:00+03	2017-08-01 10:49:00+03
16598	PG0369	2017-08-04 07:30:00+03	2017-08-04 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-04 07:34:00+03	2017-08-04 10:51:00+03
16599	PG0369	2017-08-12 07:30:00+03	2017-08-12 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-12 07:34:00+03	2017-08-12 10:51:00+03
16600	PG0369	2017-08-25 07:30:00+03	2017-08-25 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16601	PG0369	2017-08-11 07:30:00+03	2017-08-11 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-11 07:31:00+03	2017-08-11 10:50:00+03
16602	PG0369	2017-08-13 07:30:00+03	2017-08-13 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-13 07:32:00+03	2017-08-13 10:49:00+03
16603	PG0369	2017-07-31 07:30:00+03	2017-07-31 10:45:00+03	NJC	DME	Arrived	CR2	2017-07-31 07:34:00+03	2017-07-31 10:49:00+03
16604	PG0369	2017-08-30 07:30:00+03	2017-08-30 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16605	PG0369	2017-09-07 07:30:00+03	2017-09-07 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16606	PG0369	2017-08-05 07:30:00+03	2017-08-05 10:45:00+03	NJC	DME	Arrived	CR2	2017-08-05 07:35:00+03	2017-08-05 10:55:00+03
16607	PG0369	2017-08-23 07:30:00+03	2017-08-23 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16608	PG0369	2017-08-26 07:30:00+03	2017-08-26 10:45:00+03	NJC	DME	Scheduled	CR2	\N	\N
16609	PG0157	2017-08-28 14:50:00+03	2017-08-28 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16610	PG0157	2017-09-01 14:50:00+03	2017-09-01 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16611	PG0157	2017-08-26 14:50:00+03	2017-08-26 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16612	PG0157	2017-08-03 14:50:00+03	2017-08-03 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-03 14:53:00+03	2017-08-03 18:29:00+03
16613	PG0157	2017-09-03 14:50:00+03	2017-09-03 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16614	PG0157	2017-09-09 14:50:00+03	2017-09-09 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16615	PG0157	2017-08-25 14:50:00+03	2017-08-25 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16616	PG0157	2017-09-06 14:50:00+03	2017-09-06 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16617	PG0157	2017-09-13 14:50:00+03	2017-09-13 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16618	PG0157	2017-08-09 14:50:00+03	2017-08-09 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-09 14:52:00+03	2017-08-09 18:26:00+03
16619	PG0157	2017-09-02 14:50:00+03	2017-09-02 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16620	PG0157	2017-07-16 14:50:00+03	2017-07-16 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-16 14:53:00+03	2017-07-16 18:27:00+03
16621	PG0157	2017-09-04 14:50:00+03	2017-09-04 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16622	PG0157	2017-08-15 14:50:00+03	2017-08-15 18:25:00+03	NJC	LED	Departed	CR2	2017-08-15 14:52:00+03	\N
16623	PG0157	2017-08-19 14:50:00+03	2017-08-19 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16624	PG0157	2017-07-31 14:50:00+03	2017-07-31 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-31 14:54:00+03	2017-07-31 18:27:00+03
16625	PG0157	2017-07-20 14:50:00+03	2017-07-20 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-20 14:56:00+03	2017-07-20 18:31:00+03
16626	PG0157	2017-09-05 14:50:00+03	2017-09-05 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16627	PG0157	2017-07-21 14:50:00+03	2017-07-21 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-21 14:52:00+03	2017-07-21 18:26:00+03
16628	PG0157	2017-07-26 14:50:00+03	2017-07-26 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-26 14:55:00+03	2017-07-26 18:28:00+03
16629	PG0157	2017-08-24 14:50:00+03	2017-08-24 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16630	PG0157	2017-08-13 14:50:00+03	2017-08-13 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-13 14:54:00+03	2017-08-13 18:25:00+03
16631	PG0157	2017-07-27 14:50:00+03	2017-07-27 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-27 14:53:00+03	2017-07-27 18:26:00+03
16632	PG0157	2017-08-04 14:50:00+03	2017-08-04 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-04 14:54:00+03	2017-08-04 18:29:00+03
16633	PG0157	2017-08-05 14:50:00+03	2017-08-05 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-05 14:52:00+03	2017-08-05 18:28:00+03
16634	PG0157	2017-08-02 14:50:00+03	2017-08-02 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-02 14:51:00+03	2017-08-02 18:27:00+03
16635	PG0157	2017-08-18 14:50:00+03	2017-08-18 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16636	PG0157	2017-08-17 14:50:00+03	2017-08-17 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16637	PG0157	2017-08-12 14:50:00+03	2017-08-12 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-12 14:52:00+03	2017-08-12 18:27:00+03
16638	PG0157	2017-08-31 14:50:00+03	2017-08-31 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16639	PG0157	2017-07-24 14:50:00+03	2017-07-24 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-24 14:51:00+03	2017-07-24 18:27:00+03
16640	PG0157	2017-08-08 14:50:00+03	2017-08-08 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-08 14:54:00+03	2017-08-08 18:34:00+03
16641	PG0157	2017-07-18 14:50:00+03	2017-07-18 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-18 14:53:00+03	2017-07-18 18:26:00+03
16642	PG0157	2017-08-30 14:50:00+03	2017-08-30 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16643	PG0157	2017-07-17 14:50:00+03	2017-07-17 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-17 14:51:00+03	2017-07-17 18:29:00+03
16644	PG0157	2017-08-07 14:50:00+03	2017-08-07 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-07 17:49:00+03	2017-08-07 21:25:00+03
16645	PG0157	2017-08-27 14:50:00+03	2017-08-27 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16646	PG0157	2017-08-01 14:50:00+03	2017-08-01 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-01 14:55:00+03	2017-08-01 18:28:00+03
16647	PG0157	2017-07-23 14:50:00+03	2017-07-23 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-23 14:50:00+03	2017-07-23 18:28:00+03
16648	PG0157	2017-07-28 14:50:00+03	2017-07-28 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-28 14:51:00+03	2017-07-28 18:28:00+03
16649	PG0157	2017-08-21 14:50:00+03	2017-08-21 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16650	PG0157	2017-08-20 14:50:00+03	2017-08-20 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16651	PG0157	2017-09-07 14:50:00+03	2017-09-07 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16652	PG0157	2017-08-29 14:50:00+03	2017-08-29 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16653	PG0157	2017-07-22 14:50:00+03	2017-07-22 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-22 14:51:00+03	2017-07-22 18:26:00+03
16654	PG0157	2017-09-14 14:50:00+03	2017-09-14 18:25:00+03	NJC	LED	Cancelled	CR2	\N	\N
16655	PG0157	2017-07-25 14:50:00+03	2017-07-25 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-25 14:52:00+03	2017-07-25 18:30:00+03
16656	PG0157	2017-08-14 14:50:00+03	2017-08-14 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-14 14:52:00+03	2017-08-14 18:26:00+03
16657	PG0157	2017-08-06 14:50:00+03	2017-08-06 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-06 14:54:00+03	2017-08-06 18:30:00+03
16658	PG0157	2017-08-10 14:50:00+03	2017-08-10 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-10 14:54:00+03	2017-08-10 18:30:00+03
16659	PG0157	2017-09-12 14:50:00+03	2017-09-12 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16660	PG0157	2017-07-30 14:50:00+03	2017-07-30 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-30 14:53:00+03	2017-07-30 18:29:00+03
16661	PG0157	2017-08-23 14:50:00+03	2017-08-23 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16662	PG0157	2017-08-22 14:50:00+03	2017-08-22 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16663	PG0157	2017-09-11 14:50:00+03	2017-09-11 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16664	PG0157	2017-08-16 14:50:00+03	2017-08-16 18:25:00+03	NJC	LED	On Time	CR2	\N	\N
16665	PG0157	2017-09-08 14:50:00+03	2017-09-08 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16666	PG0157	2017-09-10 14:50:00+03	2017-09-10 18:25:00+03	NJC	LED	Scheduled	CR2	\N	\N
16667	PG0157	2017-08-11 14:50:00+03	2017-08-11 18:25:00+03	NJC	LED	Arrived	CR2	2017-08-11 14:51:00+03	2017-08-11 18:27:00+03
16668	PG0157	2017-07-29 14:50:00+03	2017-07-29 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-29 14:50:00+03	2017-07-29 18:22:00+03
16669	PG0157	2017-07-19 14:50:00+03	2017-07-19 18:25:00+03	NJC	LED	Arrived	CR2	2017-07-19 14:53:00+03	2017-07-19 18:29:00+03
16670	PG0641	2017-08-31 11:15:00+03	2017-08-31 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16671	PG0641	2017-08-26 11:15:00+03	2017-08-26 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16672	PG0641	2017-08-17 11:15:00+03	2017-08-17 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16673	PG0641	2017-07-28 11:15:00+03	2017-07-28 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-28 11:21:00+03	2017-07-28 12:21:00+03
16674	PG0641	2017-07-17 11:15:00+03	2017-07-17 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-17 11:17:00+03	2017-07-17 12:17:00+03
16675	PG0641	2017-09-14 11:15:00+03	2017-09-14 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16676	PG0641	2017-07-22 11:15:00+03	2017-07-22 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-22 11:20:00+03	2017-07-22 12:21:00+03
16677	PG0641	2017-09-07 11:15:00+03	2017-09-07 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16678	PG0641	2017-08-20 11:15:00+03	2017-08-20 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16679	PG0641	2017-07-31 11:15:00+03	2017-07-31 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-31 11:19:00+03	2017-07-31 12:19:00+03
16680	PG0641	2017-08-22 11:15:00+03	2017-08-22 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16681	PG0641	2017-07-21 11:15:00+03	2017-07-21 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-21 11:20:00+03	2017-07-21 12:20:00+03
16682	PG0641	2017-08-14 11:15:00+03	2017-08-14 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-14 11:19:00+03	2017-08-14 12:19:00+03
16683	PG0641	2017-08-05 11:15:00+03	2017-08-05 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-05 11:16:00+03	2017-08-05 12:16:00+03
16684	PG0641	2017-09-02 11:15:00+03	2017-09-02 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16685	PG0641	2017-07-23 11:15:00+03	2017-07-23 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-23 11:17:00+03	2017-07-23 12:17:00+03
16686	PG0641	2017-08-12 11:15:00+03	2017-08-12 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-12 11:20:00+03	2017-08-12 12:20:00+03
16687	PG0641	2017-08-06 11:15:00+03	2017-08-06 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-06 11:19:00+03	2017-08-06 12:20:00+03
16688	PG0641	2017-09-11 11:15:00+03	2017-09-11 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16689	PG0641	2017-08-09 11:15:00+03	2017-08-09 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-09 11:18:00+03	2017-08-09 12:18:00+03
16690	PG0641	2017-07-25 11:15:00+03	2017-07-25 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-25 11:17:00+03	2017-07-25 12:17:00+03
16691	PG0641	2017-08-24 11:15:00+03	2017-08-24 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16692	PG0641	2017-08-01 11:15:00+03	2017-08-01 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-01 11:19:00+03	2017-08-01 12:18:00+03
16693	PG0641	2017-08-23 11:15:00+03	2017-08-23 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16694	PG0641	2017-08-08 11:15:00+03	2017-08-08 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-08 11:19:00+03	2017-08-08 12:19:00+03
16695	PG0641	2017-08-19 11:15:00+03	2017-08-19 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16696	PG0641	2017-08-29 11:15:00+03	2017-08-29 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16697	PG0641	2017-08-11 11:15:00+03	2017-08-11 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-11 11:15:00+03	2017-08-11 12:16:00+03
16698	PG0641	2017-09-10 11:15:00+03	2017-09-10 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16699	PG0641	2017-08-30 11:15:00+03	2017-08-30 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16700	PG0641	2017-08-16 11:15:00+03	2017-08-16 12:15:00+03	NJC	OVS	On Time	CR2	\N	\N
16701	PG0641	2017-07-26 11:15:00+03	2017-07-26 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-26 11:16:00+03	2017-07-26 12:16:00+03
16702	PG0641	2017-08-07 11:15:00+03	2017-08-07 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-07 11:21:00+03	2017-08-07 12:21:00+03
16703	PG0641	2017-08-25 11:15:00+03	2017-08-25 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16704	PG0641	2017-07-24 11:15:00+03	2017-07-24 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-24 11:18:00+03	2017-07-24 12:18:00+03
16705	PG0641	2017-08-13 11:15:00+03	2017-08-13 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-13 11:18:00+03	2017-08-13 12:18:00+03
16706	PG0641	2017-08-10 11:15:00+03	2017-08-10 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-10 11:16:00+03	2017-08-10 12:16:00+03
16707	PG0641	2017-09-05 11:15:00+03	2017-09-05 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16708	PG0641	2017-07-29 11:15:00+03	2017-07-29 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-29 11:18:00+03	2017-07-29 12:18:00+03
16709	PG0641	2017-09-08 11:15:00+03	2017-09-08 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16710	PG0641	2017-08-02 11:15:00+03	2017-08-02 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-02 11:18:00+03	2017-08-02 12:18:00+03
16711	PG0641	2017-08-18 11:15:00+03	2017-08-18 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16712	PG0641	2017-08-15 11:15:00+03	2017-08-15 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-15 11:20:00+03	2017-08-15 12:20:00+03
16713	PG0641	2017-07-18 11:15:00+03	2017-07-18 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-18 11:22:00+03	2017-07-18 12:22:00+03
16714	PG0641	2017-08-03 11:15:00+03	2017-08-03 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-03 14:59:00+03	2017-08-03 15:59:00+03
16715	PG0641	2017-08-27 11:15:00+03	2017-08-27 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16716	PG0641	2017-07-16 11:15:00+03	2017-07-16 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-16 11:16:00+03	2017-07-16 12:16:00+03
16717	PG0641	2017-07-30 11:15:00+03	2017-07-30 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-30 14:22:00+03	2017-07-30 15:23:00+03
16718	PG0641	2017-09-06 11:15:00+03	2017-09-06 12:15:00+03	NJC	OVS	Cancelled	CR2	\N	\N
16719	PG0641	2017-07-20 11:15:00+03	2017-07-20 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-20 11:19:00+03	2017-07-20 12:19:00+03
16720	PG0641	2017-09-13 11:15:00+03	2017-09-13 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16721	PG0641	2017-07-19 11:15:00+03	2017-07-19 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-19 11:19:00+03	2017-07-19 12:19:00+03
16722	PG0641	2017-08-04 11:15:00+03	2017-08-04 12:15:00+03	NJC	OVS	Arrived	CR2	2017-08-04 11:17:00+03	2017-08-04 12:17:00+03
16723	PG0641	2017-09-04 11:15:00+03	2017-09-04 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16724	PG0641	2017-08-21 11:15:00+03	2017-08-21 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16725	PG0641	2017-09-03 11:15:00+03	2017-09-03 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16726	PG0641	2017-09-12 11:15:00+03	2017-09-12 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16727	PG0641	2017-09-09 11:15:00+03	2017-09-09 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16728	PG0641	2017-08-28 11:15:00+03	2017-08-28 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16729	PG0641	2017-07-27 11:15:00+03	2017-07-27 12:15:00+03	NJC	OVS	Arrived	CR2	2017-07-27 11:18:00+03	2017-07-27 12:18:00+03
16730	PG0641	2017-09-01 11:15:00+03	2017-09-01 12:15:00+03	NJC	OVS	Scheduled	CR2	\N	\N
16731	PG0017	2017-08-16 16:05:00+03	2017-08-16 18:35:00+03	NJC	ULY	On Time	CR2	\N	\N
16732	PG0017	2017-09-06 16:05:00+03	2017-09-06 18:35:00+03	NJC	ULY	Scheduled	CR2	\N	\N
16733	PG0017	2017-08-02 16:05:00+03	2017-08-02 18:35:00+03	NJC	ULY	Arrived	CR2	2017-08-02 16:09:00+03	2017-08-02 18:40:00+03
16734	PG0017	2017-07-26 16:05:00+03	2017-07-26 18:35:00+03	NJC	ULY	Arrived	CR2	2017-07-26 16:07:00+03	2017-07-26 18:37:00+03
16735	PG0017	2017-08-30 16:05:00+03	2017-08-30 18:35:00+03	NJC	ULY	Scheduled	CR2	\N	\N
16736	PG0017	2017-09-13 16:05:00+03	2017-09-13 18:35:00+03	NJC	ULY	Cancelled	CR2	\N	\N
16737	PG0017	2017-07-19 16:05:00+03	2017-07-19 18:35:00+03	NJC	ULY	Arrived	CR2	2017-07-19 16:09:00+03	2017-07-19 18:41:00+03
16738	PG0017	2017-08-23 16:05:00+03	2017-08-23 18:35:00+03	NJC	ULY	Scheduled	CR2	\N	\N
16739	PG0017	2017-08-09 16:05:00+03	2017-08-09 18:35:00+03	NJC	ULY	Arrived	CR2	2017-08-09 16:10:00+03	2017-08-09 18:40:00+03
16740	PG0336	2017-07-22 16:25:00+03	2017-07-22 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-22 16:28:00+03	2017-07-22 18:33:00+03
16741	PG0336	2017-08-18 16:25:00+03	2017-08-18 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16742	PG0336	2017-07-25 16:25:00+03	2017-07-25 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-25 16:31:00+03	2017-07-25 18:35:00+03
16743	PG0336	2017-08-05 16:25:00+03	2017-08-05 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-05 16:28:00+03	2017-08-05 18:31:00+03
16744	PG0336	2017-07-20 16:25:00+03	2017-07-20 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-20 16:26:00+03	2017-07-20 18:31:00+03
16745	PG0336	2017-09-14 16:25:00+03	2017-09-14 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16746	PG0336	2017-07-29 16:25:00+03	2017-07-29 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-29 16:25:00+03	2017-07-29 18:29:00+03
16747	PG0336	2017-09-04 16:25:00+03	2017-09-04 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16748	PG0336	2017-08-21 16:25:00+03	2017-08-21 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16749	PG0336	2017-08-10 16:25:00+03	2017-08-10 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-10 16:25:00+03	2017-08-10 18:28:00+03
16750	PG0336	2017-09-11 16:25:00+03	2017-09-11 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16751	PG0336	2017-07-16 16:25:00+03	2017-07-16 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-16 16:27:00+03	2017-07-16 18:32:00+03
16752	PG0336	2017-07-19 16:25:00+03	2017-07-19 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-19 16:27:00+03	2017-07-19 18:31:00+03
16753	PG0336	2017-08-02 16:25:00+03	2017-08-02 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-02 20:09:00+03	2017-08-02 22:15:00+03
16754	PG0336	2017-08-15 16:25:00+03	2017-08-15 18:30:00+03	JOK	DME	Departed	CN1	2017-08-15 16:29:00+03	\N
16755	PG0336	2017-09-13 16:25:00+03	2017-09-13 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16756	PG0336	2017-08-08 16:25:00+03	2017-08-08 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-08 19:56:00+03	2017-08-08 22:00:00+03
16757	PG0336	2017-08-11 16:25:00+03	2017-08-11 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-11 16:28:00+03	2017-08-11 18:32:00+03
16758	PG0336	2017-08-12 16:25:00+03	2017-08-12 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-12 16:25:00+03	2017-08-12 18:31:00+03
16759	PG0336	2017-07-21 16:25:00+03	2017-07-21 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-21 16:30:00+03	2017-07-21 18:33:00+03
16760	PG0336	2017-08-03 16:25:00+03	2017-08-03 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-03 19:46:00+03	2017-08-03 21:48:00+03
16761	PG0336	2017-08-27 16:25:00+03	2017-08-27 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16762	PG0336	2017-08-30 16:25:00+03	2017-08-30 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16763	PG0336	2017-07-24 16:25:00+03	2017-07-24 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-24 16:27:00+03	2017-07-24 18:33:00+03
16764	PG0336	2017-08-09 16:25:00+03	2017-08-09 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-09 16:29:00+03	2017-08-09 18:35:00+03
16765	PG0336	2017-09-08 16:25:00+03	2017-09-08 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16766	PG0336	2017-09-05 16:25:00+03	2017-09-05 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16767	PG0336	2017-08-25 16:25:00+03	2017-08-25 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16768	PG0336	2017-08-17 16:25:00+03	2017-08-17 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16769	PG0336	2017-09-01 16:25:00+03	2017-09-01 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16770	PG0336	2017-08-14 16:25:00+03	2017-08-14 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-14 16:29:00+03	2017-08-14 18:35:00+03
16771	PG0336	2017-08-19 16:25:00+03	2017-08-19 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16772	PG0336	2017-08-31 16:25:00+03	2017-08-31 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16773	PG0336	2017-08-22 16:25:00+03	2017-08-22 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16774	PG0336	2017-08-13 16:25:00+03	2017-08-13 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-13 16:27:00+03	2017-08-13 18:31:00+03
16775	PG0336	2017-09-03 16:25:00+03	2017-09-03 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16776	PG0336	2017-08-07 16:25:00+03	2017-08-07 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-07 16:28:00+03	2017-08-07 18:32:00+03
16777	PG0336	2017-07-23 16:25:00+03	2017-07-23 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-23 16:30:00+03	2017-07-23 18:35:00+03
16778	PG0336	2017-09-12 16:25:00+03	2017-09-12 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16779	PG0336	2017-07-31 16:25:00+03	2017-07-31 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-31 16:26:00+03	2017-07-31 18:31:00+03
16780	PG0336	2017-08-28 16:25:00+03	2017-08-28 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16781	PG0336	2017-08-29 16:25:00+03	2017-08-29 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16782	PG0336	2017-08-04 16:25:00+03	2017-08-04 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-04 16:27:00+03	2017-08-04 18:32:00+03
16783	PG0336	2017-09-10 16:25:00+03	2017-09-10 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16784	PG0336	2017-08-23 16:25:00+03	2017-08-23 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16785	PG0336	2017-08-26 16:25:00+03	2017-08-26 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16786	PG0336	2017-07-28 16:25:00+03	2017-07-28 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-28 19:40:00+03	2017-07-28 21:43:00+03
16787	PG0336	2017-09-07 16:25:00+03	2017-09-07 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16788	PG0336	2017-08-20 16:25:00+03	2017-08-20 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16789	PG0336	2017-07-26 16:25:00+03	2017-07-26 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-26 16:28:00+03	2017-07-26 18:32:00+03
16790	PG0336	2017-07-18 16:25:00+03	2017-07-18 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-18 16:28:00+03	2017-07-18 18:33:00+03
16791	PG0336	2017-07-27 16:25:00+03	2017-07-27 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-27 16:30:00+03	2017-07-27 18:34:00+03
16792	PG0336	2017-09-02 16:25:00+03	2017-09-02 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16793	PG0336	2017-07-17 16:25:00+03	2017-07-17 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-17 16:26:00+03	2017-07-17 18:31:00+03
16794	PG0336	2017-08-06 16:25:00+03	2017-08-06 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-06 16:25:00+03	2017-08-06 18:29:00+03
16795	PG0336	2017-09-06 16:25:00+03	2017-09-06 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16796	PG0336	2017-08-16 16:25:00+03	2017-08-16 18:30:00+03	JOK	DME	On Time	CN1	\N	\N
16797	PG0336	2017-07-30 16:25:00+03	2017-07-30 18:30:00+03	JOK	DME	Arrived	CN1	2017-07-30 16:28:00+03	2017-07-30 18:34:00+03
16798	PG0336	2017-08-24 16:25:00+03	2017-08-24 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16799	PG0336	2017-08-01 16:25:00+03	2017-08-01 18:30:00+03	JOK	DME	Arrived	CN1	2017-08-01 16:29:00+03	2017-08-01 18:34:00+03
16800	PG0336	2017-09-09 16:25:00+03	2017-09-09 18:30:00+03	JOK	DME	Scheduled	CN1	\N	\N
16801	PG0009	2017-07-26 12:10:00+03	2017-07-26 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-26 12:14:00+03	2017-07-26 14:23:00+03
16802	PG0010	2017-08-26 12:25:00+03	2017-08-26 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16803	PG0009	2017-08-23 12:10:00+03	2017-08-23 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16804	PG0010	2017-07-26 12:25:00+03	2017-07-26 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-26 12:30:00+03	2017-07-26 14:42:00+03
16805	PG0009	2017-08-26 12:10:00+03	2017-08-26 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16806	PG0009	2017-08-19 12:10:00+03	2017-08-19 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16807	PG0010	2017-07-20 12:25:00+03	2017-07-20 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-20 12:30:00+03	2017-07-20 14:40:00+03
16808	PG0009	2017-08-04 12:10:00+03	2017-08-04 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-04 12:13:00+03	2017-08-04 14:26:00+03
16809	PG0009	2017-07-16 12:10:00+03	2017-07-16 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-16 12:13:00+03	2017-07-16 14:21:00+03
16810	PG0010	2017-09-13 12:25:00+03	2017-09-13 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16811	PG0010	2017-08-21 12:25:00+03	2017-08-21 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16812	PG0009	2017-07-29 12:10:00+03	2017-07-29 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-29 12:15:00+03	2017-07-29 14:27:00+03
16813	PG0009	2017-07-28 12:10:00+03	2017-07-28 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-28 12:11:00+03	2017-07-28 14:21:00+03
16814	PG0010	2017-07-28 12:25:00+03	2017-07-28 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-28 12:28:00+03	2017-07-28 14:39:00+03
16815	PG0010	2017-08-24 12:25:00+03	2017-08-24 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16816	PG0009	2017-08-24 12:10:00+03	2017-08-24 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16817	PG0009	2017-09-06 12:10:00+03	2017-09-06 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16818	PG0009	2017-08-08 12:10:00+03	2017-08-08 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-08 12:12:00+03	2017-08-08 14:22:00+03
16819	PG0010	2017-08-08 12:25:00+03	2017-08-08 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-08 12:30:00+03	2017-08-08 14:40:00+03
16820	PG0010	2017-08-19 12:25:00+03	2017-08-19 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16821	PG0010	2017-09-12 12:25:00+03	2017-09-12 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16822	PG0010	2017-08-07 12:25:00+03	2017-08-07 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-07 12:28:00+03	2017-08-07 14:36:00+03
16823	PG0010	2017-09-02 12:25:00+03	2017-09-02 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16824	PG0009	2017-08-07 12:10:00+03	2017-08-07 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-07 12:16:00+03	2017-08-07 14:26:00+03
16825	PG0009	2017-08-11 12:10:00+03	2017-08-11 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-11 12:16:00+03	2017-08-11 14:27:00+03
16826	PG0009	2017-09-10 12:10:00+03	2017-09-10 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16827	PG0010	2017-07-29 12:25:00+03	2017-07-29 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-29 12:26:00+03	2017-07-29 14:37:00+03
16828	PG0009	2017-08-09 12:10:00+03	2017-08-09 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-09 12:13:00+03	2017-08-09 14:24:00+03
16829	PG0010	2017-09-10 12:25:00+03	2017-09-10 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16830	PG0009	2017-08-21 12:10:00+03	2017-08-21 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16831	PG0009	2017-08-20 12:10:00+03	2017-08-20 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16832	PG0010	2017-07-21 12:25:00+03	2017-07-21 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-21 12:28:00+03	2017-07-21 14:39:00+03
16833	PG0009	2017-08-29 12:10:00+03	2017-08-29 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16834	PG0010	2017-08-02 12:25:00+03	2017-08-02 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-02 12:28:00+03	2017-08-02 14:40:00+03
16835	PG0009	2017-07-21 12:10:00+03	2017-07-21 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-21 12:14:00+03	2017-07-21 14:24:00+03
16836	PG0009	2017-07-30 12:10:00+03	2017-07-30 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-30 12:14:00+03	2017-07-30 14:25:00+03
16838	PG0009	2017-09-05 12:10:00+03	2017-09-05 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16839	PG0010	2017-08-14 12:25:00+03	2017-08-14 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-14 12:27:00+03	2017-08-14 14:37:00+03
16840	PG0010	2017-07-30 12:25:00+03	2017-07-30 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-30 12:28:00+03	2017-07-30 14:39:00+03
16841	PG0009	2017-08-14 12:10:00+03	2017-08-14 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-14 12:16:00+03	2017-08-14 14:26:00+03
16842	PG0009	2017-08-06 12:10:00+03	2017-08-06 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-06 12:10:00+03	2017-08-06 14:21:00+03
16843	PG0009	2017-08-27 12:10:00+03	2017-08-27 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16844	PG0010	2017-09-06 12:25:00+03	2017-09-06 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16845	PG0010	2017-07-24 12:25:00+03	2017-07-24 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-24 12:26:00+03	2017-07-24 14:36:00+03
16846	PG0010	2017-08-20 12:25:00+03	2017-08-20 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16847	PG0009	2017-08-25 12:10:00+03	2017-08-25 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16848	PG0010	2017-08-25 12:25:00+03	2017-08-25 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16849	PG0009	2017-07-24 12:10:00+03	2017-07-24 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-24 12:12:00+03	2017-07-24 14:23:00+03
16850	PG0010	2017-09-07 12:25:00+03	2017-09-07 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16851	PG0009	2017-09-07 12:10:00+03	2017-09-07 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16852	PG0010	2017-08-27 12:25:00+03	2017-08-27 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16853	PG0010	2017-08-11 12:25:00+03	2017-08-11 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-11 12:29:00+03	2017-08-11 14:43:00+03
16854	PG0009	2017-07-19 12:10:00+03	2017-07-19 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-19 12:13:00+03	2017-07-19 14:24:00+03
16855	PG0009	2017-09-12 12:10:00+03	2017-09-12 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16856	PG0009	2017-08-02 12:10:00+03	2017-08-02 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-02 12:15:00+03	2017-08-02 14:26:00+03
16857	PG0009	2017-09-13 12:10:00+03	2017-09-13 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16858	PG0010	2017-08-06 12:25:00+03	2017-08-06 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-06 12:28:00+03	2017-08-06 14:39:00+03
16859	PG0010	2017-09-14 12:25:00+03	2017-09-14 14:35:00+03	JOK	VKO	Cancelled	CN1	\N	\N
16860	PG0009	2017-07-20 12:10:00+03	2017-07-20 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-20 12:13:00+03	2017-07-20 14:23:00+03
16861	PG0010	2017-08-31 12:25:00+03	2017-08-31 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16862	PG0009	2017-08-31 12:10:00+03	2017-08-31 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16863	PG0010	2017-08-09 12:25:00+03	2017-08-09 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-09 12:25:00+03	2017-08-09 14:35:00+03
16864	PG0009	2017-08-16 12:10:00+03	2017-08-16 14:20:00+03	JOK	VKO	On Time	CN1	\N	\N
16865	PG0009	2017-07-27 12:10:00+03	2017-07-27 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-27 12:13:00+03	2017-07-27 14:23:00+03
16866	PG0010	2017-08-16 12:25:00+03	2017-08-16 14:35:00+03	JOK	VKO	On Time	CN1	\N	\N
16867	PG0010	2017-07-31 12:25:00+03	2017-07-31 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-31 12:27:00+03	2017-07-31 14:37:00+03
16868	PG0009	2017-07-31 12:10:00+03	2017-07-31 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-31 12:13:00+03	2017-07-31 14:24:00+03
16869	PG0010	2017-09-09 12:25:00+03	2017-09-09 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16870	PG0010	2017-08-30 12:25:00+03	2017-08-30 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16871	PG0009	2017-08-30 12:10:00+03	2017-08-30 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16872	PG0010	2017-07-27 12:25:00+03	2017-07-27 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-27 12:27:00+03	2017-07-27 14:36:00+03
16873	PG0009	2017-08-15 12:10:00+03	2017-08-15 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-15 12:13:00+03	2017-08-15 14:24:00+03
16874	PG0009	2017-09-09 12:10:00+03	2017-09-09 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16875	PG0009	2017-09-08 12:10:00+03	2017-09-08 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16876	PG0010	2017-07-19 12:25:00+03	2017-07-19 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-19 12:29:00+03	2017-07-19 14:39:00+03
16877	PG0010	2017-09-08 12:25:00+03	2017-09-08 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16878	PG0010	2017-08-15 12:25:00+03	2017-08-15 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-15 12:29:00+03	2017-08-15 14:38:00+03
16879	PG0010	2017-07-18 12:25:00+03	2017-07-18 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-18 12:27:00+03	2017-07-18 14:37:00+03
16880	PG0010	2017-09-01 12:25:00+03	2017-09-01 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16881	PG0009	2017-09-01 12:10:00+03	2017-09-01 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16882	PG0010	2017-08-04 12:25:00+03	2017-08-04 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-04 12:27:00+03	2017-08-04 14:36:00+03
16883	PG0009	2017-08-12 12:10:00+03	2017-08-12 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-12 12:14:00+03	2017-08-12 14:23:00+03
16884	PG0010	2017-08-18 12:25:00+03	2017-08-18 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16885	PG0009	2017-08-22 12:10:00+03	2017-08-22 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16886	PG0009	2017-07-25 12:10:00+03	2017-07-25 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-25 12:15:00+03	2017-07-25 14:24:00+03
16887	PG0010	2017-08-22 12:25:00+03	2017-08-22 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16888	PG0010	2017-07-22 12:25:00+03	2017-07-22 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-22 12:27:00+03	2017-07-22 14:37:00+03
16889	PG0009	2017-08-18 12:10:00+03	2017-08-18 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16890	PG0009	2017-08-03 12:10:00+03	2017-08-03 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-03 12:13:00+03	2017-08-03 14:24:00+03
16891	PG0010	2017-08-17 12:25:00+03	2017-08-17 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16892	PG0009	2017-08-17 12:10:00+03	2017-08-17 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16893	PG0009	2017-09-04 12:10:00+03	2017-09-04 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16894	PG0010	2017-09-04 12:25:00+03	2017-09-04 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16895	PG0010	2017-08-29 12:25:00+03	2017-08-29 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16896	PG0009	2017-09-02 12:10:00+03	2017-09-02 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16897	PG0009	2017-08-13 12:10:00+03	2017-08-13 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-13 12:13:00+03	2017-08-13 14:23:00+03
16898	PG0010	2017-09-03 12:25:00+03	2017-09-03 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16899	PG0009	2017-07-18 12:10:00+03	2017-07-18 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-18 12:12:00+03	2017-07-18 14:21:00+03
16900	PG0009	2017-09-03 12:10:00+03	2017-09-03 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16901	PG0009	2017-08-10 12:10:00+03	2017-08-10 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-10 12:13:00+03	2017-08-10 14:24:00+03
16902	PG0009	2017-08-05 12:10:00+03	2017-08-05 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-05 12:15:00+03	2017-08-05 14:25:00+03
16903	PG0010	2017-08-10 12:25:00+03	2017-08-10 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-10 12:30:00+03	2017-08-10 14:41:00+03
16904	PG0010	2017-08-13 12:25:00+03	2017-08-13 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-13 15:33:00+03	2017-08-13 17:45:00+03
16905	PG0009	2017-08-28 12:10:00+03	2017-08-28 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16906	PG0010	2017-07-23 12:25:00+03	2017-07-23 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-23 12:27:00+03	2017-07-23 14:38:00+03
16907	PG0010	2017-07-25 12:25:00+03	2017-07-25 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-25 12:30:00+03	2017-07-25 14:38:00+03
16908	PG0010	2017-08-05 12:25:00+03	2017-08-05 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-05 12:28:00+03	2017-08-05 14:38:00+03
16909	PG0009	2017-09-14 12:10:00+03	2017-09-14 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16910	PG0010	2017-08-03 12:25:00+03	2017-08-03 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-03 12:27:00+03	2017-08-03 14:37:00+03
16911	PG0010	2017-08-28 12:25:00+03	2017-08-28 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16912	PG0009	2017-07-23 12:10:00+03	2017-07-23 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-23 12:12:00+03	2017-07-23 14:21:00+03
16913	PG0009	2017-07-17 12:10:00+03	2017-07-17 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-17 12:11:00+03	2017-07-17 14:22:00+03
16914	PG0009	2017-09-11 12:10:00+03	2017-09-11 14:20:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16915	PG0009	2017-08-01 12:10:00+03	2017-08-01 14:20:00+03	JOK	VKO	Arrived	CN1	2017-08-01 12:13:00+03	2017-08-01 14:25:00+03
16916	PG0010	2017-07-17 12:25:00+03	2017-07-17 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-17 12:28:00+03	2017-07-17 14:37:00+03
16917	PG0010	2017-08-01 12:25:00+03	2017-08-01 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-01 15:17:00+03	2017-08-01 17:27:00+03
16918	PG0009	2017-07-22 12:10:00+03	2017-07-22 14:20:00+03	JOK	VKO	Arrived	CN1	2017-07-22 12:17:00+03	2017-07-22 14:26:00+03
16919	PG0010	2017-08-12 12:25:00+03	2017-08-12 14:35:00+03	JOK	VKO	Arrived	CN1	2017-08-12 12:31:00+03	2017-08-12 14:41:00+03
16920	PG0010	2017-09-11 12:25:00+03	2017-09-11 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16921	PG0010	2017-07-16 12:25:00+03	2017-07-16 14:35:00+03	JOK	VKO	Arrived	CN1	2017-07-16 12:26:00+03	2017-07-16 14:35:00+03
16922	PG0010	2017-08-23 12:25:00+03	2017-08-23 14:35:00+03	JOK	VKO	Scheduled	CN1	\N	\N
16923	PG0497	2017-08-19 15:20:00+03	2017-08-19 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16924	PG0497	2017-09-02 15:20:00+03	2017-09-02 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16925	PG0497	2017-07-28 15:20:00+03	2017-07-28 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-28 15:22:00+03	2017-07-28 17:32:00+03
16926	PG0497	2017-09-08 15:20:00+03	2017-09-08 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16927	PG0497	2017-08-03 15:20:00+03	2017-08-03 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-03 15:22:00+03	2017-08-03 17:33:00+03
16928	PG0497	2017-08-02 15:20:00+03	2017-08-02 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-02 15:22:00+03	2017-08-02 17:32:00+03
16929	PG0497	2017-09-07 15:20:00+03	2017-09-07 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16930	PG0497	2017-09-03 15:20:00+03	2017-09-03 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16931	PG0497	2017-07-19 15:20:00+03	2017-07-19 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-19 15:21:00+03	2017-07-19 17:30:00+03
16932	PG0497	2017-07-27 15:20:00+03	2017-07-27 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-27 15:26:00+03	2017-07-27 17:37:00+03
16933	PG0497	2017-08-11 15:20:00+03	2017-08-11 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-11 15:24:00+03	2017-08-11 17:34:00+03
16934	PG0497	2017-08-04 15:20:00+03	2017-08-04 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-04 15:22:00+03	2017-08-04 17:30:00+03
16935	PG0497	2017-07-22 15:20:00+03	2017-07-22 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-22 15:23:00+03	2017-07-22 17:34:00+03
16936	PG0497	2017-09-05 15:20:00+03	2017-09-05 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16937	PG0497	2017-09-14 15:20:00+03	2017-09-14 17:30:00+03	JOK	SVO	Cancelled	CN1	\N	\N
16938	PG0497	2017-08-26 15:20:00+03	2017-08-26 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16939	PG0497	2017-07-20 15:20:00+03	2017-07-20 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-20 15:24:00+03	2017-07-20 17:31:00+03
16940	PG0497	2017-08-14 15:20:00+03	2017-08-14 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-14 15:24:00+03	2017-08-14 17:35:00+03
16941	PG0497	2017-08-23 15:20:00+03	2017-08-23 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16942	PG0497	2017-08-21 15:20:00+03	2017-08-21 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16943	PG0497	2017-07-16 15:20:00+03	2017-07-16 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-16 15:27:00+03	2017-07-16 17:38:00+03
16944	PG0497	2017-08-10 15:20:00+03	2017-08-10 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-10 15:23:00+03	2017-08-10 17:33:00+03
16945	PG0497	2017-08-30 15:20:00+03	2017-08-30 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16946	PG0497	2017-07-31 15:20:00+03	2017-07-31 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-31 15:24:00+03	2017-07-31 17:35:00+03
16947	PG0497	2017-08-20 15:20:00+03	2017-08-20 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16948	PG0497	2017-07-17 15:20:00+03	2017-07-17 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-17 15:21:00+03	2017-07-17 17:31:00+03
16949	PG0497	2017-09-09 15:20:00+03	2017-09-09 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16950	PG0497	2017-08-29 15:20:00+03	2017-08-29 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16951	PG0497	2017-08-05 15:20:00+03	2017-08-05 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-05 15:21:00+03	2017-08-05 17:31:00+03
16952	PG0497	2017-08-15 15:20:00+03	2017-08-15 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-15 15:24:00+03	2017-08-15 17:33:00+03
16953	PG0497	2017-08-22 15:20:00+03	2017-08-22 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16954	PG0497	2017-08-06 15:20:00+03	2017-08-06 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-06 15:23:00+03	2017-08-06 17:33:00+03
16955	PG0497	2017-07-21 15:20:00+03	2017-07-21 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-21 15:23:00+03	2017-07-21 17:32:00+03
16956	PG0497	2017-07-25 15:20:00+03	2017-07-25 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-25 15:22:00+03	2017-07-25 17:31:00+03
16957	PG0497	2017-08-16 15:20:00+03	2017-08-16 17:30:00+03	JOK	SVO	On Time	CN1	\N	\N
16958	PG0497	2017-09-13 15:20:00+03	2017-09-13 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16959	PG0497	2017-08-13 15:20:00+03	2017-08-13 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-13 15:23:00+03	2017-08-13 17:33:00+03
16960	PG0497	2017-09-11 15:20:00+03	2017-09-11 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16961	PG0497	2017-09-06 15:20:00+03	2017-09-06 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16962	PG0497	2017-09-10 15:20:00+03	2017-09-10 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16963	PG0497	2017-07-29 15:20:00+03	2017-07-29 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-29 15:26:00+03	2017-07-29 17:38:00+03
16964	PG0497	2017-08-25 15:20:00+03	2017-08-25 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16965	PG0497	2017-08-08 15:20:00+03	2017-08-08 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-08 15:20:00+03	2017-08-08 17:30:00+03
16966	PG0497	2017-08-01 15:20:00+03	2017-08-01 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-01 15:24:00+03	2017-08-01 17:35:00+03
16967	PG0497	2017-08-18 15:20:00+03	2017-08-18 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16968	PG0497	2017-08-17 15:20:00+03	2017-08-17 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16969	PG0497	2017-08-28 15:20:00+03	2017-08-28 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16970	PG0497	2017-08-31 15:20:00+03	2017-08-31 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16971	PG0497	2017-07-23 15:20:00+03	2017-07-23 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-23 15:22:00+03	2017-07-23 17:31:00+03
16972	PG0497	2017-08-07 15:20:00+03	2017-08-07 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-07 15:24:00+03	2017-08-07 17:32:00+03
16973	PG0497	2017-07-26 15:20:00+03	2017-07-26 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-26 15:24:00+03	2017-07-26 17:34:00+03
16974	PG0497	2017-09-04 15:20:00+03	2017-09-04 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16975	PG0497	2017-07-30 15:20:00+03	2017-07-30 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-30 15:23:00+03	2017-07-30 17:33:00+03
16976	PG0497	2017-08-12 15:20:00+03	2017-08-12 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-12 15:24:00+03	2017-08-12 17:35:00+03
16977	PG0497	2017-07-24 15:20:00+03	2017-07-24 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-24 15:22:00+03	2017-07-24 17:34:00+03
16978	PG0497	2017-08-09 15:20:00+03	2017-08-09 17:30:00+03	JOK	SVO	Arrived	CN1	2017-08-09 15:24:00+03	2017-08-09 17:33:00+03
16979	PG0497	2017-09-12 15:20:00+03	2017-09-12 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16980	PG0497	2017-08-27 15:20:00+03	2017-08-27 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16981	PG0497	2017-07-18 15:20:00+03	2017-07-18 17:30:00+03	JOK	SVO	Arrived	CN1	2017-07-18 15:23:00+03	2017-07-18 17:34:00+03
16982	PG0497	2017-09-01 15:20:00+03	2017-09-01 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16983	PG0497	2017-08-24 15:20:00+03	2017-08-24 17:30:00+03	JOK	SVO	Scheduled	CN1	\N	\N
16984	PG0392	2017-08-05 17:20:00+03	2017-08-05 19:20:00+03	JOK	KRR	Arrived	CR2	2017-08-05 17:24:00+03	2017-08-05 19:23:00+03
16985	PG0392	2017-09-09 17:20:00+03	2017-09-09 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16986	PG0392	2017-07-26 17:20:00+03	2017-07-26 19:20:00+03	JOK	KRR	Arrived	CR2	2017-07-26 17:23:00+03	2017-07-26 19:21:00+03
16987	PG0392	2017-08-30 17:20:00+03	2017-08-30 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16988	PG0392	2017-08-23 17:20:00+03	2017-08-23 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16989	PG0392	2017-08-12 17:20:00+03	2017-08-12 19:20:00+03	JOK	KRR	Arrived	CR2	2017-08-12 17:21:00+03	2017-08-12 19:21:00+03
16990	PG0392	2017-08-19 17:20:00+03	2017-08-19 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16991	PG0392	2017-09-13 17:20:00+03	2017-09-13 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16992	PG0392	2017-08-02 17:20:00+03	2017-08-02 19:20:00+03	JOK	KRR	Arrived	CR2	2017-08-02 17:23:00+03	2017-08-02 19:21:00+03
16993	PG0392	2017-08-26 17:20:00+03	2017-08-26 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16994	PG0392	2017-07-19 17:20:00+03	2017-07-19 19:20:00+03	JOK	KRR	Arrived	CR2	2017-07-19 17:22:00+03	2017-07-19 19:23:00+03
16995	PG0392	2017-08-16 17:20:00+03	2017-08-16 19:20:00+03	JOK	KRR	On Time	CR2	\N	\N
16996	PG0392	2017-07-29 17:20:00+03	2017-07-29 19:20:00+03	JOK	KRR	Arrived	CR2	2017-07-29 17:21:00+03	2017-07-29 19:20:00+03
16997	PG0392	2017-09-06 17:20:00+03	2017-09-06 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16998	PG0392	2017-09-02 17:20:00+03	2017-09-02 19:20:00+03	JOK	KRR	Scheduled	CR2	\N	\N
16999	PG0392	2017-08-09 17:20:00+03	2017-08-09 19:20:00+03	JOK	KRR	Arrived	CR2	2017-08-09 17:25:00+03	2017-08-09 19:25:00+03
17000	PG0392	2017-07-22 17:20:00+03	2017-07-22 19:20:00+03	JOK	KRR	Arrived	CR2	2017-07-22 17:24:00+03	2017-07-22 19:24:00+03
17001	PG0141	2017-08-13 07:00:00+03	2017-08-13 13:15:00+03	KXK	SVX	Arrived	763	2017-08-13 07:03:00+03	2017-08-13 13:20:00+03
17002	PG0141	2017-08-16 07:00:00+03	2017-08-16 13:15:00+03	KXK	SVX	Delayed	763	\N	\N
17003	PG0141	2017-07-16 07:00:00+03	2017-07-16 13:15:00+03	KXK	SVX	Arrived	763	2017-07-16 07:05:00+03	2017-07-16 13:24:00+03
17004	PG0141	2017-07-23 07:00:00+03	2017-07-23 13:15:00+03	KXK	SVX	Arrived	763	2017-07-23 07:03:00+03	2017-07-23 13:13:00+03
17005	PG0141	2017-07-26 07:00:00+03	2017-07-26 13:15:00+03	KXK	SVX	Arrived	763	2017-07-26 07:03:00+03	2017-07-26 13:08:00+03
17006	PG0141	2017-09-13 07:00:00+03	2017-09-13 13:15:00+03	KXK	SVX	Cancelled	763	\N	\N
17007	PG0141	2017-08-23 07:00:00+03	2017-08-23 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17008	PG0141	2017-08-27 07:00:00+03	2017-08-27 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17009	PG0141	2017-08-06 07:00:00+03	2017-08-06 13:15:00+03	KXK	SVX	Arrived	763	2017-08-06 07:03:00+03	2017-08-06 13:15:00+03
17010	PG0141	2017-09-03 07:00:00+03	2017-09-03 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17011	PG0141	2017-07-19 07:00:00+03	2017-07-19 13:15:00+03	KXK	SVX	Arrived	763	2017-07-19 07:07:00+03	2017-07-19 13:28:00+03
17012	PG0141	2017-08-20 07:00:00+03	2017-08-20 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17013	PG0141	2017-08-02 07:00:00+03	2017-08-02 13:15:00+03	KXK	SVX	Arrived	763	2017-08-02 07:04:00+03	2017-08-02 13:17:00+03
17014	PG0141	2017-08-09 07:00:00+03	2017-08-09 13:15:00+03	KXK	SVX	Arrived	763	2017-08-09 07:03:00+03	2017-08-09 13:18:00+03
17015	PG0141	2017-09-10 07:00:00+03	2017-09-10 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17016	PG0141	2017-07-30 07:00:00+03	2017-07-30 13:15:00+03	KXK	SVX	Arrived	763	2017-07-30 07:03:00+03	2017-07-30 13:14:00+03
17017	PG0141	2017-09-06 07:00:00+03	2017-09-06 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17018	PG0141	2017-08-30 07:00:00+03	2017-08-30 13:15:00+03	KXK	SVX	Scheduled	763	\N	\N
17019	PG0518	2017-07-23 15:30:00+03	2017-07-23 16:50:00+03	SCW	DME	Arrived	763	2017-07-23 15:31:00+03	2017-07-23 16:51:00+03
17020	PG0518	2017-08-22 15:30:00+03	2017-08-22 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17021	PG0518	2017-09-06 15:30:00+03	2017-09-06 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17022	PG0518	2017-07-27 15:30:00+03	2017-07-27 16:50:00+03	SCW	DME	Arrived	763	2017-07-27 15:35:00+03	2017-07-27 16:55:00+03
17023	PG0518	2017-08-07 15:30:00+03	2017-08-07 16:50:00+03	SCW	DME	Arrived	763	2017-08-07 15:33:00+03	2017-08-07 16:53:00+03
17024	PG0518	2017-07-16 15:30:00+03	2017-07-16 16:50:00+03	SCW	DME	Arrived	763	2017-07-16 15:33:00+03	2017-07-16 16:52:00+03
17025	PG0518	2017-09-02 15:30:00+03	2017-09-02 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17026	PG0518	2017-08-15 15:30:00+03	2017-08-15 16:50:00+03	SCW	DME	Arrived	763	2017-08-15 15:33:00+03	2017-08-15 16:53:00+03
17027	PG0518	2017-08-09 15:30:00+03	2017-08-09 16:50:00+03	SCW	DME	Arrived	763	2017-08-09 15:32:00+03	2017-08-09 16:53:00+03
17028	PG0518	2017-08-17 15:30:00+03	2017-08-17 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17029	PG0518	2017-08-21 15:30:00+03	2017-08-21 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17030	PG0518	2017-08-02 15:30:00+03	2017-08-02 16:50:00+03	SCW	DME	Arrived	763	2017-08-02 15:35:00+03	2017-08-02 16:56:00+03
17031	PG0518	2017-07-18 15:30:00+03	2017-07-18 16:50:00+03	SCW	DME	Arrived	763	2017-07-18 15:32:00+03	2017-07-18 16:53:00+03
17032	PG0518	2017-09-03 15:30:00+03	2017-09-03 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17033	PG0518	2017-08-24 15:30:00+03	2017-08-24 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17034	PG0518	2017-07-21 15:30:00+03	2017-07-21 16:50:00+03	SCW	DME	Arrived	763	2017-07-21 15:31:00+03	2017-07-21 16:51:00+03
17035	PG0518	2017-08-23 15:30:00+03	2017-08-23 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17036	PG0518	2017-09-07 15:30:00+03	2017-09-07 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17037	PG0518	2017-08-13 15:30:00+03	2017-08-13 16:50:00+03	SCW	DME	Arrived	763	2017-08-13 15:32:00+03	2017-08-13 16:52:00+03
17038	PG0518	2017-07-24 15:30:00+03	2017-07-24 16:50:00+03	SCW	DME	Arrived	763	2017-07-24 19:26:00+03	2017-07-24 20:45:00+03
17039	PG0518	2017-08-03 15:30:00+03	2017-08-03 16:50:00+03	SCW	DME	Arrived	763	2017-08-03 15:33:00+03	2017-08-03 16:54:00+03
17040	PG0518	2017-07-19 15:30:00+03	2017-07-19 16:50:00+03	SCW	DME	Arrived	763	2017-07-19 15:32:00+03	2017-07-19 16:51:00+03
17041	PG0518	2017-08-28 15:30:00+03	2017-08-28 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17042	PG0518	2017-09-11 15:30:00+03	2017-09-11 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17043	PG0518	2017-08-04 15:30:00+03	2017-08-04 16:50:00+03	SCW	DME	Arrived	763	2017-08-04 15:36:00+03	2017-08-04 16:55:00+03
17044	PG0518	2017-07-31 15:30:00+03	2017-07-31 16:50:00+03	SCW	DME	Arrived	763	2017-07-31 15:34:00+03	2017-07-31 16:54:00+03
17045	PG0518	2017-09-12 15:30:00+03	2017-09-12 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17046	PG0518	2017-09-09 15:30:00+03	2017-09-09 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17047	PG0518	2017-07-22 15:30:00+03	2017-07-22 16:50:00+03	SCW	DME	Arrived	763	2017-07-22 15:34:00+03	2017-07-22 16:53:00+03
17048	PG0518	2017-08-06 15:30:00+03	2017-08-06 16:50:00+03	SCW	DME	Arrived	763	2017-08-06 15:33:00+03	2017-08-06 16:53:00+03
17049	PG0518	2017-09-01 15:30:00+03	2017-09-01 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17050	PG0518	2017-07-29 15:30:00+03	2017-07-29 16:50:00+03	SCW	DME	Arrived	763	2017-07-29 15:32:00+03	2017-07-29 16:52:00+03
17051	PG0518	2017-09-10 15:30:00+03	2017-09-10 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17052	PG0518	2017-08-26 15:30:00+03	2017-08-26 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17053	PG0518	2017-07-25 15:30:00+03	2017-07-25 16:50:00+03	SCW	DME	Arrived	763	2017-07-25 15:36:00+03	2017-07-25 16:56:00+03
17054	PG0518	2017-08-18 15:30:00+03	2017-08-18 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17055	PG0518	2017-08-01 15:30:00+03	2017-08-01 16:50:00+03	SCW	DME	Arrived	763	2017-08-01 15:31:00+03	2017-08-01 16:51:00+03
17056	PG0518	2017-08-12 15:30:00+03	2017-08-12 16:50:00+03	SCW	DME	Arrived	763	2017-08-12 15:33:00+03	2017-08-12 16:52:00+03
17057	PG0518	2017-08-25 15:30:00+03	2017-08-25 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17058	PG0518	2017-09-05 15:30:00+03	2017-09-05 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17059	PG0518	2017-07-26 15:30:00+03	2017-07-26 16:50:00+03	SCW	DME	Arrived	763	2017-07-26 15:31:00+03	2017-07-26 16:51:00+03
17060	PG0518	2017-08-10 15:30:00+03	2017-08-10 16:50:00+03	SCW	DME	Arrived	763	2017-08-10 15:34:00+03	2017-08-10 16:55:00+03
17061	PG0518	2017-09-08 15:30:00+03	2017-09-08 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17062	PG0518	2017-07-30 15:30:00+03	2017-07-30 16:50:00+03	SCW	DME	Arrived	763	2017-07-30 18:35:00+03	2017-07-30 19:55:00+03
17063	PG0518	2017-08-30 15:30:00+03	2017-08-30 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17064	PG0518	2017-09-04 15:30:00+03	2017-09-04 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17065	PG0518	2017-08-16 15:30:00+03	2017-08-16 16:50:00+03	SCW	DME	On Time	763	\N	\N
17066	PG0518	2017-08-05 15:30:00+03	2017-08-05 16:50:00+03	SCW	DME	Arrived	763	2017-08-05 15:30:00+03	2017-08-05 16:50:00+03
17067	PG0518	2017-07-20 15:30:00+03	2017-07-20 16:50:00+03	SCW	DME	Arrived	763	2017-07-20 15:36:00+03	2017-07-20 16:57:00+03
17068	PG0518	2017-09-14 15:30:00+03	2017-09-14 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17069	PG0518	2017-07-28 15:30:00+03	2017-07-28 16:50:00+03	SCW	DME	Arrived	763	2017-07-28 15:31:00+03	2017-07-28 16:52:00+03
17070	PG0518	2017-08-11 15:30:00+03	2017-08-11 16:50:00+03	SCW	DME	Arrived	763	2017-08-11 15:32:00+03	2017-08-11 16:52:00+03
17071	PG0518	2017-07-17 15:30:00+03	2017-07-17 16:50:00+03	SCW	DME	Arrived	763	2017-07-17 15:35:00+03	2017-07-17 16:55:00+03
17072	PG0518	2017-08-19 15:30:00+03	2017-08-19 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17073	PG0518	2017-08-27 15:30:00+03	2017-08-27 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17074	PG0518	2017-08-29 15:30:00+03	2017-08-29 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17075	PG0518	2017-08-08 15:30:00+03	2017-08-08 16:50:00+03	SCW	DME	Arrived	763	2017-08-08 15:33:00+03	2017-08-08 16:53:00+03
17076	PG0518	2017-09-13 15:30:00+03	2017-09-13 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17077	PG0518	2017-08-20 15:30:00+03	2017-08-20 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17078	PG0518	2017-08-31 15:30:00+03	2017-08-31 16:50:00+03	SCW	DME	Scheduled	763	\N	\N
17079	PG0518	2017-08-14 15:30:00+03	2017-08-14 16:50:00+03	SCW	DME	Arrived	763	2017-08-14 15:35:00+03	2017-08-14 16:54:00+03
17080	PG0570	2017-09-08 14:05:00+03	2017-09-08 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17081	PG0570	2017-07-26 14:05:00+03	2017-07-26 15:10:00+03	SCW	SVX	Arrived	733	2017-07-26 14:09:00+03	2017-07-26 15:13:00+03
17082	PG0570	2017-08-28 14:05:00+03	2017-08-28 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17083	PG0570	2017-08-22 14:05:00+03	2017-08-22 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17084	PG0570	2017-07-24 14:05:00+03	2017-07-24 15:10:00+03	SCW	SVX	Arrived	733	2017-07-24 14:08:00+03	2017-07-24 15:13:00+03
17085	PG0570	2017-08-19 14:05:00+03	2017-08-19 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17086	PG0570	2017-09-02 14:05:00+03	2017-09-02 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17087	PG0570	2017-08-01 14:05:00+03	2017-08-01 15:10:00+03	SCW	SVX	Arrived	733	2017-08-01 14:09:00+03	2017-08-01 15:13:00+03
17088	PG0570	2017-08-27 14:05:00+03	2017-08-27 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17089	PG0570	2017-07-21 14:05:00+03	2017-07-21 15:10:00+03	SCW	SVX	Arrived	733	2017-07-21 14:07:00+03	2017-07-21 15:11:00+03
17090	PG0570	2017-07-25 14:05:00+03	2017-07-25 15:10:00+03	SCW	SVX	Arrived	733	2017-07-25 14:08:00+03	2017-07-25 15:13:00+03
17091	PG0570	2017-08-21 14:05:00+03	2017-08-21 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17092	PG0570	2017-09-12 14:05:00+03	2017-09-12 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17093	PG0570	2017-08-25 14:05:00+03	2017-08-25 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17094	PG0570	2017-08-29 14:05:00+03	2017-08-29 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17095	PG0570	2017-08-04 14:05:00+03	2017-08-04 15:10:00+03	SCW	SVX	Arrived	733	2017-08-04 17:08:00+03	2017-08-04 18:13:00+03
17096	PG0570	2017-08-15 14:05:00+03	2017-08-15 15:10:00+03	SCW	SVX	Arrived	733	2017-08-15 14:09:00+03	2017-08-15 15:15:00+03
17097	PG0570	2017-07-27 14:05:00+03	2017-07-27 15:10:00+03	SCW	SVX	Arrived	733	2017-07-27 14:09:00+03	2017-07-27 15:14:00+03
17098	PG0570	2017-09-05 14:05:00+03	2017-09-05 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17099	PG0570	2017-08-07 14:05:00+03	2017-08-07 15:10:00+03	SCW	SVX	Arrived	733	2017-08-07 14:10:00+03	2017-08-07 15:14:00+03
17100	PG0570	2017-08-13 14:05:00+03	2017-08-13 15:10:00+03	SCW	SVX	Arrived	733	2017-08-13 14:08:00+03	2017-08-13 15:13:00+03
17101	PG0570	2017-07-29 14:05:00+03	2017-07-29 15:10:00+03	SCW	SVX	Arrived	733	2017-07-29 14:07:00+03	2017-07-29 15:13:00+03
17102	PG0570	2017-08-06 14:05:00+03	2017-08-06 15:10:00+03	SCW	SVX	Arrived	733	2017-08-06 14:06:00+03	2017-08-06 15:11:00+03
17103	PG0570	2017-08-26 14:05:00+03	2017-08-26 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17104	PG0570	2017-08-18 14:05:00+03	2017-08-18 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17105	PG0570	2017-09-03 14:05:00+03	2017-09-03 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17106	PG0570	2017-07-23 14:05:00+03	2017-07-23 15:10:00+03	SCW	SVX	Arrived	733	2017-07-23 14:08:00+03	2017-07-23 15:14:00+03
17107	PG0570	2017-07-18 14:05:00+03	2017-07-18 15:10:00+03	SCW	SVX	Arrived	733	2017-07-18 14:08:00+03	2017-07-18 15:12:00+03
17108	PG0570	2017-08-11 14:05:00+03	2017-08-11 15:10:00+03	SCW	SVX	Arrived	733	2017-08-11 14:11:00+03	2017-08-11 15:15:00+03
17109	PG0570	2017-08-08 14:05:00+03	2017-08-08 15:10:00+03	SCW	SVX	Arrived	733	2017-08-08 14:08:00+03	2017-08-08 15:13:00+03
17110	PG0570	2017-08-02 14:05:00+03	2017-08-02 15:10:00+03	SCW	SVX	Arrived	733	2017-08-02 14:11:00+03	2017-08-02 15:15:00+03
17111	PG0570	2017-07-19 14:05:00+03	2017-07-19 15:10:00+03	SCW	SVX	Arrived	733	2017-07-19 14:09:00+03	2017-07-19 15:15:00+03
17112	PG0570	2017-07-16 14:05:00+03	2017-07-16 15:10:00+03	SCW	SVX	Arrived	733	2017-07-16 14:06:00+03	2017-07-16 15:09:00+03
17113	PG0570	2017-08-09 14:05:00+03	2017-08-09 15:10:00+03	SCW	SVX	Arrived	733	2017-08-09 14:09:00+03	2017-08-09 15:15:00+03
17114	PG0570	2017-09-13 14:05:00+03	2017-09-13 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17115	PG0570	2017-08-05 14:05:00+03	2017-08-05 15:10:00+03	SCW	SVX	Arrived	733	2017-08-05 14:09:00+03	2017-08-05 15:14:00+03
17116	PG0570	2017-08-24 14:05:00+03	2017-08-24 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17117	PG0570	2017-09-01 14:05:00+03	2017-09-01 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17118	PG0570	2017-08-17 14:05:00+03	2017-08-17 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17119	PG0570	2017-09-07 14:05:00+03	2017-09-07 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17120	PG0570	2017-08-12 14:05:00+03	2017-08-12 15:10:00+03	SCW	SVX	Arrived	733	2017-08-12 14:09:00+03	2017-08-12 15:14:00+03
17121	PG0570	2017-09-09 14:05:00+03	2017-09-09 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17122	PG0570	2017-07-30 14:05:00+03	2017-07-30 15:10:00+03	SCW	SVX	Arrived	733	2017-07-30 14:09:00+03	2017-07-30 15:14:00+03
17123	PG0570	2017-08-16 14:05:00+03	2017-08-16 15:10:00+03	SCW	SVX	On Time	733	\N	\N
17124	PG0570	2017-08-20 14:05:00+03	2017-08-20 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17125	PG0570	2017-07-20 14:05:00+03	2017-07-20 15:10:00+03	SCW	SVX	Arrived	733	2017-07-20 14:08:00+03	2017-07-20 15:14:00+03
17126	PG0570	2017-09-06 14:05:00+03	2017-09-06 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17127	PG0570	2017-09-11 14:05:00+03	2017-09-11 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17128	PG0570	2017-07-17 14:05:00+03	2017-07-17 15:10:00+03	SCW	SVX	Arrived	733	2017-07-17 14:09:00+03	2017-07-17 15:15:00+03
17129	PG0570	2017-08-10 14:05:00+03	2017-08-10 15:10:00+03	SCW	SVX	Arrived	733	2017-08-10 14:06:00+03	2017-08-10 15:11:00+03
17130	PG0570	2017-09-04 14:05:00+03	2017-09-04 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17131	PG0570	2017-08-03 14:05:00+03	2017-08-03 15:10:00+03	SCW	SVX	Arrived	733	2017-08-03 14:08:00+03	2017-08-03 15:12:00+03
17132	PG0570	2017-08-31 14:05:00+03	2017-08-31 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17133	PG0570	2017-08-14 14:05:00+03	2017-08-14 15:10:00+03	SCW	SVX	Arrived	733	2017-08-14 14:07:00+03	2017-08-14 15:12:00+03
17134	PG0570	2017-08-30 14:05:00+03	2017-08-30 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17135	PG0570	2017-09-14 14:05:00+03	2017-09-14 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17136	PG0570	2017-07-22 14:05:00+03	2017-07-22 15:10:00+03	SCW	SVX	Arrived	733	2017-07-22 14:09:00+03	2017-07-22 15:14:00+03
17137	PG0570	2017-07-31 14:05:00+03	2017-07-31 15:10:00+03	SCW	SVX	Arrived	733	2017-07-31 14:08:00+03	2017-07-31 15:13:00+03
17138	PG0570	2017-09-10 14:05:00+03	2017-09-10 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17139	PG0570	2017-08-23 14:05:00+03	2017-08-23 15:10:00+03	SCW	SVX	Scheduled	733	\N	\N
17140	PG0570	2017-07-28 14:05:00+03	2017-07-28 15:10:00+03	SCW	SVX	Arrived	733	2017-07-28 14:06:00+03	2017-07-28 15:11:00+03
17141	PG0059	2017-08-23 12:25:00+03	2017-08-23 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17142	PG0059	2017-08-28 12:25:00+03	2017-08-28 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17143	PG0058	2017-08-28 13:20:00+03	2017-08-28 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17144	PG0058	2017-08-12 13:20:00+03	2017-08-12 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-12 13:25:00+03	2017-08-12 15:43:00+03
17145	PG0059	2017-08-12 12:25:00+03	2017-08-12 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-12 12:28:00+03	2017-08-12 14:48:00+03
17146	PG0058	2017-08-14 13:20:00+03	2017-08-14 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-14 13:25:00+03	2017-08-14 15:46:00+03
17147	PG0059	2017-07-25 12:25:00+03	2017-07-25 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-25 12:26:00+03	2017-07-25 14:45:00+03
17148	PG0058	2017-07-25 13:20:00+03	2017-07-25 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-25 13:24:00+03	2017-07-25 15:44:00+03
17149	PG0059	2017-08-14 12:25:00+03	2017-08-14 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-14 12:29:00+03	2017-08-14 14:49:00+03
17150	PG0058	2017-09-03 13:20:00+03	2017-09-03 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17151	PG0059	2017-09-03 12:25:00+03	2017-09-03 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17152	PG0059	2017-09-12 12:25:00+03	2017-09-12 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17153	PG0058	2017-09-12 13:20:00+03	2017-09-12 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17154	PG0059	2017-09-10 12:25:00+03	2017-09-10 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17155	PG0058	2017-09-10 13:20:00+03	2017-09-10 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17156	PG0058	2017-07-16 13:20:00+03	2017-07-16 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-16 13:22:00+03	2017-07-16 15:43:00+03
17157	PG0059	2017-07-30 12:25:00+03	2017-07-30 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-30 15:26:00+03	2017-07-30 17:48:00+03
17158	PG0058	2017-07-30 13:20:00+03	2017-07-30 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-30 13:24:00+03	2017-07-30 15:44:00+03
17159	PG0058	2017-08-11 13:20:00+03	2017-08-11 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-11 16:14:00+03	2017-08-11 18:33:00+03
17160	PG0059	2017-08-11 12:25:00+03	2017-08-11 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-11 12:29:00+03	2017-08-11 14:47:00+03
17161	PG0059	2017-08-08 12:25:00+03	2017-08-08 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-08 12:28:00+03	2017-08-08 14:48:00+03
17162	PG0058	2017-08-08 13:20:00+03	2017-08-08 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-08 13:23:00+03	2017-08-08 15:43:00+03
17163	PG0059	2017-08-19 12:25:00+03	2017-08-19 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17164	PG0058	2017-08-19 13:20:00+03	2017-08-19 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17165	PG0058	2017-07-31 13:20:00+03	2017-07-31 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-31 13:24:00+03	2017-07-31 15:46:00+03
17166	PG0059	2017-07-31 12:25:00+03	2017-07-31 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-31 12:26:00+03	2017-07-31 14:45:00+03
17167	PG0059	2017-08-21 12:25:00+03	2017-08-21 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17168	PG0058	2017-08-21 13:20:00+03	2017-08-21 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17169	PG0058	2017-07-26 13:20:00+03	2017-07-26 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-26 13:24:00+03	2017-07-26 15:45:00+03
17170	PG0059	2017-07-26 12:25:00+03	2017-07-26 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-26 12:27:00+03	2017-07-26 14:49:00+03
17171	PG0058	2017-07-22 13:20:00+03	2017-07-22 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-22 13:25:00+03	2017-07-22 15:46:00+03
17172	PG0058	2017-08-23 13:20:00+03	2017-08-23 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17174	PG0059	2017-08-31 12:25:00+03	2017-08-31 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17175	PG0059	2017-07-22 12:25:00+03	2017-07-22 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-22 12:26:00+03	2017-07-22 14:46:00+03
17176	PG0058	2017-08-25 13:20:00+03	2017-08-25 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17177	PG0059	2017-07-21 12:25:00+03	2017-07-21 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-21 12:30:00+03	2017-07-21 14:51:00+03
17178	PG0058	2017-07-21 13:20:00+03	2017-07-21 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-21 13:23:00+03	2017-07-21 15:43:00+03
17179	PG0058	2017-08-15 13:20:00+03	2017-08-15 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-15 13:27:00+03	2017-08-15 15:49:00+03
17180	PG0059	2017-09-07 12:25:00+03	2017-09-07 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17181	PG0059	2017-08-07 12:25:00+03	2017-08-07 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-07 12:26:00+03	2017-08-07 14:46:00+03
17182	PG0058	2017-09-07 13:20:00+03	2017-09-07 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17183	PG0058	2017-08-07 13:20:00+03	2017-08-07 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-07 13:22:00+03	2017-08-07 15:42:00+03
17184	PG0058	2017-08-16 13:20:00+03	2017-08-16 15:40:00+03	SCW	NBC	On Time	CN1	\N	\N
17185	PG0059	2017-08-16 12:25:00+03	2017-08-16 14:45:00+03	SCW	NBC	On Time	CN1	\N	\N
17186	PG0059	2017-08-15 12:25:00+03	2017-08-15 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-15 12:26:00+03	2017-08-15 14:47:00+03
17187	PG0058	2017-07-17 13:20:00+03	2017-07-17 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-17 13:25:00+03	2017-07-17 15:46:00+03
17188	PG0059	2017-08-30 12:25:00+03	2017-08-30 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17189	PG0059	2017-07-17 12:25:00+03	2017-07-17 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-17 12:27:00+03	2017-07-17 14:48:00+03
17190	PG0058	2017-08-30 13:20:00+03	2017-08-30 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17191	PG0059	2017-07-24 12:25:00+03	2017-07-24 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-24 12:28:00+03	2017-07-24 14:49:00+03
17192	PG0058	2017-07-24 13:20:00+03	2017-07-24 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-24 13:23:00+03	2017-07-24 15:44:00+03
17193	PG0059	2017-08-25 12:25:00+03	2017-08-25 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17194	PG0058	2017-08-31 13:20:00+03	2017-08-31 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17195	PG0058	2017-08-09 13:20:00+03	2017-08-09 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-09 13:20:00+03	2017-08-09 15:42:00+03
17196	PG0058	2017-09-04 13:20:00+03	2017-09-04 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17197	PG0059	2017-09-04 12:25:00+03	2017-09-04 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17198	PG0058	2017-09-08 13:20:00+03	2017-09-08 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17199	PG0059	2017-09-08 12:25:00+03	2017-09-08 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17200	PG0058	2017-09-11 13:20:00+03	2017-09-11 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17201	PG0059	2017-09-11 12:25:00+03	2017-09-11 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17202	PG0059	2017-08-06 12:25:00+03	2017-08-06 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-06 12:28:00+03	2017-08-06 14:48:00+03
17203	PG0058	2017-08-06 13:20:00+03	2017-08-06 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-06 13:21:00+03	2017-08-06 15:39:00+03
17204	PG0058	2017-08-01 13:20:00+03	2017-08-01 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-01 13:23:00+03	2017-08-01 15:43:00+03
17205	PG0059	2017-08-01 12:25:00+03	2017-08-01 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-01 12:27:00+03	2017-08-01 14:48:00+03
17206	PG0059	2017-08-09 12:25:00+03	2017-08-09 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-09 12:29:00+03	2017-08-09 14:46:00+03
17207	PG0058	2017-08-10 13:20:00+03	2017-08-10 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-10 13:21:00+03	2017-08-10 15:43:00+03
17208	PG0059	2017-08-10 12:25:00+03	2017-08-10 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-10 12:26:00+03	2017-08-10 14:46:00+03
17209	PG0059	2017-08-27 12:25:00+03	2017-08-27 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17210	PG0058	2017-08-27 13:20:00+03	2017-08-27 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17211	PG0058	2017-07-27 13:20:00+03	2017-07-27 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-27 13:24:00+03	2017-07-27 15:43:00+03
17212	PG0059	2017-07-27 12:25:00+03	2017-07-27 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-27 12:29:00+03	2017-07-27 14:52:00+03
17213	PG0059	2017-08-13 12:25:00+03	2017-08-13 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-13 12:31:00+03	2017-08-13 14:50:00+03
17214	PG0058	2017-08-13 13:20:00+03	2017-08-13 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-13 13:23:00+03	2017-08-13 15:43:00+03
17215	PG0058	2017-07-18 13:20:00+03	2017-07-18 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-18 13:22:00+03	2017-07-18 15:42:00+03
17216	PG0059	2017-07-18 12:25:00+03	2017-07-18 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-18 12:27:00+03	2017-07-18 14:47:00+03
17217	PG0058	2017-08-22 13:20:00+03	2017-08-22 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17218	PG0059	2017-08-22 12:25:00+03	2017-08-22 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17219	PG0058	2017-09-14 13:20:00+03	2017-09-14 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17220	PG0059	2017-08-05 12:25:00+03	2017-08-05 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-05 12:28:00+03	2017-08-05 14:48:00+03
17221	PG0058	2017-08-05 13:20:00+03	2017-08-05 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-05 13:22:00+03	2017-08-05 15:43:00+03
17222	PG0059	2017-07-29 12:25:00+03	2017-07-29 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-29 12:27:00+03	2017-07-29 14:46:00+03
17223	PG0058	2017-07-29 13:20:00+03	2017-07-29 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-29 13:23:00+03	2017-07-29 15:41:00+03
17224	PG0058	2017-08-17 13:20:00+03	2017-08-17 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17225	PG0059	2017-08-17 12:25:00+03	2017-08-17 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17226	PG0058	2017-09-05 13:20:00+03	2017-09-05 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17227	PG0059	2017-09-09 12:25:00+03	2017-09-09 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17228	PG0059	2017-09-05 12:25:00+03	2017-09-05 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17229	PG0059	2017-08-24 12:25:00+03	2017-08-24 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17230	PG0058	2017-08-24 13:20:00+03	2017-08-24 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17231	PG0058	2017-09-09 13:20:00+03	2017-09-09 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17232	PG0058	2017-08-02 13:20:00+03	2017-08-02 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-02 13:27:00+03	2017-08-02 15:43:00+03
17233	PG0059	2017-08-02 12:25:00+03	2017-08-02 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-02 12:28:00+03	2017-08-02 14:48:00+03
17234	PG0059	2017-07-20 12:25:00+03	2017-07-20 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-20 14:37:00+03	2017-07-20 17:01:00+03
17235	PG0058	2017-07-20 13:20:00+03	2017-07-20 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-20 13:26:00+03	2017-07-20 15:46:00+03
17236	PG0059	2017-08-04 12:25:00+03	2017-08-04 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-04 12:31:00+03	2017-08-04 14:49:00+03
17237	PG0058	2017-08-04 13:20:00+03	2017-08-04 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-04 13:23:00+03	2017-08-04 15:42:00+03
17238	PG0058	2017-08-26 13:20:00+03	2017-08-26 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17239	PG0059	2017-08-26 12:25:00+03	2017-08-26 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17240	PG0058	2017-09-13 13:20:00+03	2017-09-13 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17241	PG0059	2017-09-13 12:25:00+03	2017-09-13 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17242	PG0058	2017-07-19 13:20:00+03	2017-07-19 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-19 13:24:00+03	2017-07-19 15:42:00+03
17243	PG0059	2017-07-19 12:25:00+03	2017-07-19 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-19 12:27:00+03	2017-07-19 14:48:00+03
17244	PG0058	2017-07-28 13:20:00+03	2017-07-28 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-28 13:27:00+03	2017-07-28 15:47:00+03
17245	PG0059	2017-07-28 12:25:00+03	2017-07-28 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-28 12:28:00+03	2017-07-28 14:46:00+03
17246	PG0059	2017-08-18 12:25:00+03	2017-08-18 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17247	PG0058	2017-08-18 13:20:00+03	2017-08-18 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17248	PG0059	2017-09-02 12:25:00+03	2017-09-02 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17249	PG0058	2017-09-02 13:20:00+03	2017-09-02 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17250	PG0058	2017-08-29 13:20:00+03	2017-08-29 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17251	PG0059	2017-08-29 12:25:00+03	2017-08-29 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17252	PG0059	2017-07-23 12:25:00+03	2017-07-23 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-23 12:28:00+03	2017-07-23 14:50:00+03
17253	PG0058	2017-07-23 13:20:00+03	2017-07-23 15:40:00+03	SCW	NBC	Arrived	CN1	2017-07-23 13:21:00+03	2017-07-23 15:40:00+03
17254	PG0059	2017-09-01 12:25:00+03	2017-09-01 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17255	PG0059	2017-08-03 12:25:00+03	2017-08-03 14:45:00+03	SCW	NBC	Arrived	CN1	2017-08-03 12:29:00+03	2017-08-03 14:53:00+03
17256	PG0058	2017-08-03 13:20:00+03	2017-08-03 15:40:00+03	SCW	NBC	Arrived	CN1	2017-08-03 13:20:00+03	2017-08-03 15:39:00+03
17257	PG0059	2017-07-16 12:25:00+03	2017-07-16 14:45:00+03	SCW	NBC	Arrived	CN1	2017-07-16 12:28:00+03	2017-07-16 14:48:00+03
17258	PG0059	2017-09-06 12:25:00+03	2017-09-06 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17259	PG0058	2017-09-01 13:20:00+03	2017-09-01 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17260	PG0058	2017-09-06 13:20:00+03	2017-09-06 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17261	PG0059	2017-08-20 12:25:00+03	2017-08-20 14:45:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17262	PG0058	2017-08-20 13:20:00+03	2017-08-20 15:40:00+03	SCW	NBC	Scheduled	CN1	\N	\N
17263	PG0705	2017-07-16 20:45:00+03	2017-07-17 03:10:00+03	SCW	GDX	Arrived	763	2017-07-16 20:46:00+03	2017-07-17 03:05:00+03
17264	PG0705	2017-08-13 20:45:00+03	2017-08-14 03:10:00+03	SCW	GDX	Arrived	763	2017-08-13 20:48:00+03	2017-08-14 03:06:00+03
17265	PG0705	2017-08-06 20:45:00+03	2017-08-07 03:10:00+03	SCW	GDX	Arrived	763	2017-08-06 20:49:00+03	2017-08-07 03:17:00+03
17266	PG0705	2017-07-30 20:45:00+03	2017-07-31 03:10:00+03	SCW	GDX	Arrived	763	2017-07-30 20:48:00+03	2017-07-31 03:10:00+03
17267	PG0705	2017-08-20 20:45:00+03	2017-08-21 03:10:00+03	SCW	GDX	Scheduled	763	\N	\N
17268	PG0705	2017-09-10 20:45:00+03	2017-09-11 03:10:00+03	SCW	GDX	Cancelled	763	\N	\N
17269	PG0705	2017-07-23 20:45:00+03	2017-07-24 03:10:00+03	SCW	GDX	Arrived	763	2017-07-23 20:47:00+03	2017-07-24 03:11:00+03
17270	PG0705	2017-08-27 20:45:00+03	2017-08-28 03:10:00+03	SCW	GDX	Scheduled	763	\N	\N
17271	PG0705	2017-09-03 20:45:00+03	2017-09-04 03:10:00+03	SCW	GDX	Scheduled	763	\N	\N
17272	PG0137	2017-08-24 13:25:00+03	2017-08-24 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17273	PG0137	2017-08-25 13:25:00+03	2017-08-25 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17274	PG0137	2017-08-28 13:25:00+03	2017-08-28 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17275	PG0137	2017-08-11 13:25:00+03	2017-08-11 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-11 13:27:00+03	2017-08-11 15:28:00+03
17276	PG0137	2017-08-26 13:25:00+03	2017-08-26 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17277	PG0137	2017-08-21 13:25:00+03	2017-08-21 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17278	PG0137	2017-07-22 13:25:00+03	2017-07-22 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-22 13:27:00+03	2017-07-22 15:27:00+03
17279	PG0137	2017-09-14 13:25:00+03	2017-09-14 15:25:00+03	NAL	DME	Cancelled	CR2	\N	\N
17280	PG0137	2017-08-22 13:25:00+03	2017-08-22 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17281	PG0137	2017-07-31 13:25:00+03	2017-07-31 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-31 13:25:00+03	2017-07-31 15:23:00+03
17282	PG0137	2017-07-26 13:25:00+03	2017-07-26 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-26 13:27:00+03	2017-07-26 15:28:00+03
17283	PG0137	2017-09-04 13:25:00+03	2017-09-04 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17284	PG0137	2017-09-13 13:25:00+03	2017-09-13 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17285	PG0137	2017-07-24 13:25:00+03	2017-07-24 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-24 13:28:00+03	2017-07-24 15:28:00+03
17286	PG0137	2017-07-28 13:25:00+03	2017-07-28 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-28 13:26:00+03	2017-07-28 15:25:00+03
17287	PG0137	2017-08-07 13:25:00+03	2017-08-07 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-07 13:28:00+03	2017-08-07 15:30:00+03
17288	PG0137	2017-08-15 13:25:00+03	2017-08-15 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-15 13:28:00+03	2017-08-15 15:27:00+03
17289	PG0137	2017-08-03 13:25:00+03	2017-08-03 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-03 13:27:00+03	2017-08-03 15:26:00+03
17290	PG0137	2017-07-27 13:25:00+03	2017-07-27 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-27 13:25:00+03	2017-07-27 15:28:00+03
17291	PG0137	2017-09-01 13:25:00+03	2017-09-01 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17292	PG0137	2017-08-01 13:25:00+03	2017-08-01 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-01 13:28:00+03	2017-08-01 15:28:00+03
17293	PG0137	2017-08-05 13:25:00+03	2017-08-05 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-05 17:22:00+03	2017-08-05 19:22:00+03
17294	PG0137	2017-08-29 13:25:00+03	2017-08-29 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17295	PG0137	2017-07-21 13:25:00+03	2017-07-21 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-21 13:28:00+03	2017-07-21 15:31:00+03
17296	PG0137	2017-08-17 13:25:00+03	2017-08-17 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17297	PG0137	2017-07-29 13:25:00+03	2017-07-29 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-29 13:27:00+03	2017-07-29 15:28:00+03
17298	PG0137	2017-08-13 13:25:00+03	2017-08-13 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-13 13:28:00+03	2017-08-13 15:28:00+03
17299	PG0137	2017-07-25 13:25:00+03	2017-07-25 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-25 13:29:00+03	2017-07-25 15:28:00+03
17300	PG0137	2017-07-20 13:25:00+03	2017-07-20 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-20 13:27:00+03	2017-07-20 15:29:00+03
17301	PG0137	2017-07-16 13:25:00+03	2017-07-16 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-16 13:29:00+03	2017-07-16 15:31:00+03
17302	PG0137	2017-08-18 13:25:00+03	2017-08-18 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17303	PG0137	2017-08-02 13:25:00+03	2017-08-02 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-02 13:27:00+03	2017-08-02 15:26:00+03
17304	PG0137	2017-08-14 13:25:00+03	2017-08-14 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-14 16:29:00+03	2017-08-14 18:29:00+03
17305	PG0137	2017-08-27 13:25:00+03	2017-08-27 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17306	PG0137	2017-08-06 13:25:00+03	2017-08-06 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-06 13:30:00+03	2017-08-06 15:30:00+03
17307	PG0137	2017-08-08 13:25:00+03	2017-08-08 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-08 13:29:00+03	2017-08-08 15:28:00+03
17308	PG0137	2017-07-30 13:25:00+03	2017-07-30 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-30 13:29:00+03	2017-07-30 15:30:00+03
17309	PG0137	2017-08-16 13:25:00+03	2017-08-16 15:25:00+03	NAL	DME	Delayed	CR2	\N	\N
17310	PG0137	2017-07-17 13:25:00+03	2017-07-17 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-17 13:27:00+03	2017-07-17 15:26:00+03
17311	PG0137	2017-09-06 13:25:00+03	2017-09-06 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17312	PG0137	2017-07-19 13:25:00+03	2017-07-19 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-19 13:27:00+03	2017-07-19 15:26:00+03
17313	PG0137	2017-08-23 13:25:00+03	2017-08-23 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17314	PG0137	2017-08-20 13:25:00+03	2017-08-20 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17315	PG0137	2017-09-08 13:25:00+03	2017-09-08 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17316	PG0137	2017-08-09 13:25:00+03	2017-08-09 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-09 13:28:00+03	2017-08-09 15:28:00+03
17317	PG0137	2017-07-18 13:25:00+03	2017-07-18 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-18 13:29:00+03	2017-07-18 15:30:00+03
17318	PG0137	2017-08-31 13:25:00+03	2017-08-31 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17319	PG0137	2017-09-10 13:25:00+03	2017-09-10 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17320	PG0137	2017-09-03 13:25:00+03	2017-09-03 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17321	PG0137	2017-08-10 13:25:00+03	2017-08-10 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-10 13:30:00+03	2017-08-10 15:30:00+03
17322	PG0137	2017-09-07 13:25:00+03	2017-09-07 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17323	PG0137	2017-08-30 13:25:00+03	2017-08-30 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17324	PG0137	2017-08-04 13:25:00+03	2017-08-04 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-04 13:29:00+03	2017-08-04 15:29:00+03
17325	PG0137	2017-09-02 13:25:00+03	2017-09-02 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17326	PG0137	2017-09-09 13:25:00+03	2017-09-09 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17327	PG0137	2017-09-05 13:25:00+03	2017-09-05 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17328	PG0137	2017-08-12 13:25:00+03	2017-08-12 15:25:00+03	NAL	DME	Arrived	CR2	2017-08-12 13:27:00+03	2017-08-12 15:25:00+03
17329	PG0137	2017-09-11 13:25:00+03	2017-09-11 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17330	PG0137	2017-07-23 13:25:00+03	2017-07-23 15:25:00+03	NAL	DME	Arrived	CR2	2017-07-23 13:26:00+03	2017-07-23 15:26:00+03
17331	PG0137	2017-08-19 13:25:00+03	2017-08-19 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17332	PG0137	2017-09-12 13:25:00+03	2017-09-12 15:25:00+03	NAL	DME	Scheduled	CR2	\N	\N
17333	PG0511	2017-09-10 12:50:00+03	2017-09-10 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17334	PG0511	2017-07-19 12:50:00+03	2017-07-19 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-19 12:54:00+03	2017-07-19 14:54:00+03
17335	PG0511	2017-08-12 12:50:00+03	2017-08-12 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-12 12:58:00+03	2017-08-12 14:57:00+03
17336	PG0511	2017-09-06 12:50:00+03	2017-09-06 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17337	PG0511	2017-08-07 12:50:00+03	2017-08-07 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-07 12:54:00+03	2017-08-07 14:53:00+03
17338	PG0511	2017-07-16 12:50:00+03	2017-07-16 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-16 12:56:00+03	2017-07-16 14:58:00+03
17339	PG0511	2017-08-20 12:50:00+03	2017-08-20 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17340	PG0511	2017-08-08 12:50:00+03	2017-08-08 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-08 12:51:00+03	2017-08-08 14:53:00+03
17341	PG0511	2017-07-22 12:50:00+03	2017-07-22 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-22 12:54:00+03	2017-07-22 14:53:00+03
17342	PG0511	2017-08-05 12:50:00+03	2017-08-05 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-05 12:51:00+03	2017-08-05 14:50:00+03
17343	PG0511	2017-08-15 12:50:00+03	2017-08-15 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-15 15:42:00+03	2017-08-15 17:41:00+03
17344	PG0511	2017-08-21 12:50:00+03	2017-08-21 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17345	PG0511	2017-08-19 12:50:00+03	2017-08-19 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17346	PG0511	2017-08-14 12:50:00+03	2017-08-14 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-14 12:55:00+03	2017-08-14 14:54:00+03
17347	PG0511	2017-07-26 12:50:00+03	2017-07-26 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-26 12:53:00+03	2017-07-26 14:54:00+03
17348	PG0511	2017-08-09 12:50:00+03	2017-08-09 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-09 12:53:00+03	2017-08-09 14:53:00+03
17349	PG0511	2017-08-16 12:50:00+03	2017-08-16 14:50:00+03	NAL	GOJ	On Time	CR2	\N	\N
17350	PG0511	2017-08-03 12:50:00+03	2017-08-03 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-03 12:53:00+03	2017-08-03 14:52:00+03
17351	PG0511	2017-08-02 12:50:00+03	2017-08-02 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-02 12:54:00+03	2017-08-02 14:56:00+03
17352	PG0511	2017-08-01 12:50:00+03	2017-08-01 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-01 16:11:00+03	2017-08-01 18:10:00+03
17353	PG0511	2017-08-29 12:50:00+03	2017-08-29 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17354	PG0511	2017-08-18 12:50:00+03	2017-08-18 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17355	PG0511	2017-08-10 12:50:00+03	2017-08-10 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-10 12:54:00+03	2017-08-10 14:53:00+03
17356	PG0511	2017-08-25 12:50:00+03	2017-08-25 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17357	PG0511	2017-09-02 12:50:00+03	2017-09-02 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17358	PG0511	2017-07-29 12:50:00+03	2017-07-29 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-29 15:58:00+03	2017-07-29 17:57:00+03
17359	PG0511	2017-08-17 12:50:00+03	2017-08-17 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17360	PG0511	2017-07-28 12:50:00+03	2017-07-28 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-28 12:51:00+03	2017-07-28 14:52:00+03
17361	PG0511	2017-08-06 12:50:00+03	2017-08-06 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-06 12:54:00+03	2017-08-06 14:55:00+03
17362	PG0511	2017-08-11 12:50:00+03	2017-08-11 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-11 12:53:00+03	2017-08-11 14:54:00+03
17363	PG0511	2017-08-23 12:50:00+03	2017-08-23 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17364	PG0511	2017-09-09 12:50:00+03	2017-09-09 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17365	PG0511	2017-09-05 12:50:00+03	2017-09-05 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17366	PG0511	2017-08-26 12:50:00+03	2017-08-26 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17367	PG0511	2017-07-31 12:50:00+03	2017-07-31 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-31 12:52:00+03	2017-07-31 14:52:00+03
17368	PG0511	2017-08-13 12:50:00+03	2017-08-13 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-13 12:53:00+03	2017-08-13 14:53:00+03
17369	PG0511	2017-08-04 12:50:00+03	2017-08-04 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-08-04 12:53:00+03	2017-08-04 14:54:00+03
17370	PG0511	2017-08-24 12:50:00+03	2017-08-24 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17371	PG0511	2017-08-27 12:50:00+03	2017-08-27 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17372	PG0511	2017-07-18 12:50:00+03	2017-07-18 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-18 12:50:00+03	2017-07-18 14:52:00+03
17373	PG0511	2017-08-30 12:50:00+03	2017-08-30 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17374	PG0511	2017-08-28 12:50:00+03	2017-08-28 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17375	PG0511	2017-09-03 12:50:00+03	2017-09-03 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17376	PG0511	2017-09-07 12:50:00+03	2017-09-07 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17377	PG0511	2017-07-21 12:50:00+03	2017-07-21 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-21 12:52:00+03	2017-07-21 14:53:00+03
17378	PG0511	2017-07-20 12:50:00+03	2017-07-20 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-20 12:54:00+03	2017-07-20 14:56:00+03
17379	PG0511	2017-07-17 12:50:00+03	2017-07-17 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-17 12:53:00+03	2017-07-17 14:53:00+03
17380	PG0511	2017-09-08 12:50:00+03	2017-09-08 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17381	PG0511	2017-07-27 12:50:00+03	2017-07-27 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-27 12:52:00+03	2017-07-27 14:54:00+03
17382	PG0511	2017-09-12 12:50:00+03	2017-09-12 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17383	PG0511	2017-09-11 12:50:00+03	2017-09-11 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17384	PG0511	2017-09-04 12:50:00+03	2017-09-04 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17385	PG0511	2017-08-22 12:50:00+03	2017-08-22 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17386	PG0511	2017-09-14 12:50:00+03	2017-09-14 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17387	PG0511	2017-07-24 12:50:00+03	2017-07-24 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-24 12:51:00+03	2017-07-24 14:52:00+03
17388	PG0511	2017-08-31 12:50:00+03	2017-08-31 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17389	PG0511	2017-07-25 12:50:00+03	2017-07-25 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-25 12:56:00+03	2017-07-25 14:55:00+03
17390	PG0511	2017-09-13 12:50:00+03	2017-09-13 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17391	PG0511	2017-07-23 12:50:00+03	2017-07-23 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-23 12:51:00+03	2017-07-23 14:51:00+03
17392	PG0511	2017-09-01 12:50:00+03	2017-09-01 14:50:00+03	NAL	GOJ	Scheduled	CR2	\N	\N
17393	PG0511	2017-07-30 12:50:00+03	2017-07-30 14:50:00+03	NAL	GOJ	Arrived	CR2	2017-07-30 12:51:00+03	2017-07-30 14:53:00+03
17394	PG0418	2017-07-19 11:20:00+03	2017-07-19 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-19 11:23:00+03	2017-07-19 12:38:00+03
17395	PG0418	2017-08-04 11:20:00+03	2017-08-04 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-04 11:22:00+03	2017-08-04 12:37:00+03
17396	PG0418	2017-08-27 11:20:00+03	2017-08-27 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17397	PG0418	2017-08-07 11:20:00+03	2017-08-07 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-07 11:23:00+03	2017-08-07 12:38:00+03
17398	PG0418	2017-08-21 11:20:00+03	2017-08-21 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17399	PG0418	2017-08-06 11:20:00+03	2017-08-06 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-06 14:33:00+03	2017-08-06 15:49:00+03
17400	PG0418	2017-09-04 11:20:00+03	2017-09-04 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17401	PG0418	2017-09-12 11:20:00+03	2017-09-12 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17402	PG0418	2017-08-14 11:20:00+03	2017-08-14 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-14 11:22:00+03	2017-08-14 12:37:00+03
17403	PG0418	2017-07-31 11:20:00+03	2017-07-31 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-31 11:26:00+03	2017-07-31 12:41:00+03
17404	PG0418	2017-07-20 11:20:00+03	2017-07-20 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-20 11:22:00+03	2017-07-20 12:37:00+03
17405	PG0418	2017-08-13 11:20:00+03	2017-08-13 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-13 11:21:00+03	2017-08-13 12:36:00+03
17406	PG0418	2017-08-31 11:20:00+03	2017-08-31 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17407	PG0418	2017-09-08 11:20:00+03	2017-09-08 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17408	PG0418	2017-08-28 11:20:00+03	2017-08-28 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17409	PG0418	2017-09-13 11:20:00+03	2017-09-13 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17410	PG0418	2017-07-30 11:20:00+03	2017-07-30 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-30 11:21:00+03	2017-07-30 12:36:00+03
17411	PG0418	2017-07-26 11:20:00+03	2017-07-26 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-26 11:27:00+03	2017-07-26 12:42:00+03
17412	PG0418	2017-09-02 11:20:00+03	2017-09-02 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17413	PG0418	2017-07-24 11:20:00+03	2017-07-24 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-24 11:23:00+03	2017-07-24 12:38:00+03
17414	PG0418	2017-07-16 11:20:00+03	2017-07-16 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-16 11:25:00+03	2017-07-16 12:40:00+03
17415	PG0418	2017-08-25 11:20:00+03	2017-08-25 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17416	PG0418	2017-08-17 11:20:00+03	2017-08-17 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17417	PG0418	2017-08-19 11:20:00+03	2017-08-19 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17418	PG0418	2017-08-30 11:20:00+03	2017-08-30 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17419	PG0418	2017-08-01 11:20:00+03	2017-08-01 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-01 11:27:00+03	2017-08-01 12:43:00+03
17420	PG0418	2017-07-29 11:20:00+03	2017-07-29 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-29 11:27:00+03	2017-07-29 12:43:00+03
17421	PG0418	2017-07-23 11:20:00+03	2017-07-23 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-23 14:55:00+03	2017-07-23 16:09:00+03
17422	PG0418	2017-08-23 11:20:00+03	2017-08-23 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17423	PG0418	2017-08-09 11:20:00+03	2017-08-09 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-09 11:22:00+03	2017-08-09 12:37:00+03
17424	PG0418	2017-08-10 11:20:00+03	2017-08-10 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-10 11:21:00+03	2017-08-10 12:37:00+03
17425	PG0418	2017-08-11 11:20:00+03	2017-08-11 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-11 11:24:00+03	2017-08-11 12:39:00+03
17426	PG0418	2017-09-01 11:20:00+03	2017-09-01 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17427	PG0418	2017-07-21 11:20:00+03	2017-07-21 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-21 11:25:00+03	2017-07-21 12:41:00+03
17428	PG0418	2017-08-15 11:20:00+03	2017-08-15 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-15 11:24:00+03	2017-08-15 12:41:00+03
17429	PG0418	2017-08-26 11:20:00+03	2017-08-26 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17430	PG0418	2017-08-20 11:20:00+03	2017-08-20 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17431	PG0418	2017-08-03 11:20:00+03	2017-08-03 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-03 11:23:00+03	2017-08-03 12:38:00+03
17432	PG0418	2017-09-11 11:20:00+03	2017-09-11 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17433	PG0418	2017-08-22 11:20:00+03	2017-08-22 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17434	PG0418	2017-07-22 11:20:00+03	2017-07-22 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-22 11:22:00+03	2017-07-22 12:36:00+03
17435	PG0418	2017-09-10 11:20:00+03	2017-09-10 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17436	PG0418	2017-07-28 11:20:00+03	2017-07-28 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-28 11:23:00+03	2017-07-28 12:37:00+03
17437	PG0418	2017-08-05 11:20:00+03	2017-08-05 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-05 11:21:00+03	2017-08-05 12:36:00+03
17438	PG0418	2017-09-14 11:20:00+03	2017-09-14 12:35:00+03	NAL	KRR	Cancelled	CN1	\N	\N
17439	PG0418	2017-08-24 11:20:00+03	2017-08-24 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17440	PG0418	2017-08-18 11:20:00+03	2017-08-18 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17441	PG0418	2017-08-08 11:20:00+03	2017-08-08 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-08 11:21:00+03	2017-08-08 12:36:00+03
17442	PG0418	2017-08-16 11:20:00+03	2017-08-16 12:35:00+03	NAL	KRR	On Time	CN1	\N	\N
17443	PG0418	2017-09-05 11:20:00+03	2017-09-05 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17444	PG0418	2017-08-29 11:20:00+03	2017-08-29 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17445	PG0418	2017-08-02 11:20:00+03	2017-08-02 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-02 11:28:00+03	2017-08-02 12:44:00+03
17446	PG0418	2017-07-17 11:20:00+03	2017-07-17 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-17 11:23:00+03	2017-07-17 12:38:00+03
17447	PG0418	2017-09-07 11:20:00+03	2017-09-07 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17448	PG0418	2017-07-18 11:20:00+03	2017-07-18 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-18 11:23:00+03	2017-07-18 12:37:00+03
17449	PG0418	2017-07-27 11:20:00+03	2017-07-27 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-27 11:25:00+03	2017-07-27 12:39:00+03
17450	PG0418	2017-09-06 11:20:00+03	2017-09-06 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17451	PG0418	2017-09-09 11:20:00+03	2017-09-09 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17452	PG0418	2017-08-12 11:20:00+03	2017-08-12 12:35:00+03	NAL	KRR	Arrived	CN1	2017-08-12 11:24:00+03	2017-08-12 12:39:00+03
17453	PG0418	2017-09-03 11:20:00+03	2017-09-03 12:35:00+03	NAL	KRR	Scheduled	CN1	\N	\N
17454	PG0418	2017-07-25 11:20:00+03	2017-07-25 12:35:00+03	NAL	KRR	Arrived	CN1	2017-07-25 11:25:00+03	2017-07-25 12:40:00+03
17455	PG0135	2017-08-14 05:25:00+03	2017-08-14 10:30:00+03	BTK	DME	Arrived	319	2017-08-14 05:25:00+03	2017-08-14 10:31:00+03
17456	PG0135	2017-07-26 05:25:00+03	2017-07-26 10:30:00+03	BTK	DME	Arrived	319	2017-07-26 05:28:00+03	2017-07-26 10:35:00+03
17457	PG0135	2017-08-28 05:25:00+03	2017-08-28 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17458	PG0135	2017-09-09 05:25:00+03	2017-09-09 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17459	PG0135	2017-07-22 05:25:00+03	2017-07-22 10:30:00+03	BTK	DME	Arrived	319	2017-07-22 05:27:00+03	2017-07-22 10:30:00+03
17460	PG0135	2017-08-20 05:25:00+03	2017-08-20 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17461	PG0135	2017-09-06 05:25:00+03	2017-09-06 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17462	PG0135	2017-09-10 05:25:00+03	2017-09-10 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17463	PG0135	2017-07-19 05:25:00+03	2017-07-19 10:30:00+03	BTK	DME	Arrived	319	2017-07-19 05:28:00+03	2017-07-19 10:30:00+03
17464	PG0135	2017-08-04 05:25:00+03	2017-08-04 10:30:00+03	BTK	DME	Arrived	319	2017-08-04 05:29:00+03	2017-08-04 10:27:00+03
17465	PG0135	2017-09-12 05:25:00+03	2017-09-12 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17466	PG0135	2017-08-08 05:25:00+03	2017-08-08 10:30:00+03	BTK	DME	Arrived	319	2017-08-08 05:28:00+03	2017-08-08 10:36:00+03
17467	PG0135	2017-09-08 05:25:00+03	2017-09-08 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17468	PG0135	2017-07-29 05:25:00+03	2017-07-29 10:30:00+03	BTK	DME	Arrived	319	2017-07-29 05:27:00+03	2017-07-29 10:34:00+03
17469	PG0135	2017-08-18 05:25:00+03	2017-08-18 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17470	PG0135	2017-08-23 05:25:00+03	2017-08-23 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17471	PG0135	2017-07-17 05:25:00+03	2017-07-17 10:30:00+03	BTK	DME	Arrived	319	2017-07-17 05:30:00+03	2017-07-17 10:30:00+03
17472	PG0135	2017-08-16 05:25:00+03	2017-08-16 10:30:00+03	BTK	DME	On Time	319	\N	\N
17473	PG0135	2017-08-27 05:25:00+03	2017-08-27 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17474	PG0135	2017-07-30 05:25:00+03	2017-07-30 10:30:00+03	BTK	DME	Arrived	319	2017-07-30 05:29:00+03	2017-07-30 10:31:00+03
17475	PG0135	2017-09-03 05:25:00+03	2017-09-03 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17476	PG0135	2017-09-07 05:25:00+03	2017-09-07 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17477	PG0135	2017-08-03 05:25:00+03	2017-08-03 10:30:00+03	BTK	DME	Arrived	319	2017-08-03 05:29:00+03	2017-08-03 10:37:00+03
17478	PG0135	2017-07-21 05:25:00+03	2017-07-21 10:30:00+03	BTK	DME	Arrived	319	2017-07-21 05:29:00+03	2017-07-21 10:35:00+03
17479	PG0135	2017-07-25 05:25:00+03	2017-07-25 10:30:00+03	BTK	DME	Arrived	319	2017-07-25 05:26:00+03	2017-07-25 10:34:00+03
17480	PG0135	2017-09-14 05:25:00+03	2017-09-14 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17481	PG0135	2017-08-09 05:25:00+03	2017-08-09 10:30:00+03	BTK	DME	Arrived	319	2017-08-09 05:28:00+03	2017-08-09 10:35:00+03
17482	PG0135	2017-07-20 05:25:00+03	2017-07-20 10:30:00+03	BTK	DME	Arrived	319	2017-07-20 05:27:00+03	2017-07-20 10:31:00+03
17483	PG0135	2017-09-01 05:25:00+03	2017-09-01 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17484	PG0135	2017-08-13 05:25:00+03	2017-08-13 10:30:00+03	BTK	DME	Arrived	319	2017-08-13 05:27:00+03	2017-08-13 10:34:00+03
17485	PG0135	2017-08-06 05:25:00+03	2017-08-06 10:30:00+03	BTK	DME	Arrived	319	2017-08-06 05:30:00+03	2017-08-06 10:27:00+03
17486	PG0135	2017-08-17 05:25:00+03	2017-08-17 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17487	PG0135	2017-07-27 05:25:00+03	2017-07-27 10:30:00+03	BTK	DME	Arrived	319	2017-07-27 05:28:00+03	2017-07-27 10:33:00+03
17488	PG0135	2017-09-04 05:25:00+03	2017-09-04 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17489	PG0135	2017-08-26 05:25:00+03	2017-08-26 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17490	PG0135	2017-08-12 05:25:00+03	2017-08-12 10:30:00+03	BTK	DME	Arrived	319	2017-08-12 05:27:00+03	2017-08-12 10:39:00+03
17491	PG0135	2017-08-05 05:25:00+03	2017-08-05 10:30:00+03	BTK	DME	Arrived	319	2017-08-05 05:30:00+03	2017-08-05 10:35:00+03
17492	PG0135	2017-08-01 05:25:00+03	2017-08-01 10:30:00+03	BTK	DME	Arrived	319	2017-08-01 05:29:00+03	2017-08-01 10:34:00+03
17493	PG0135	2017-08-15 05:25:00+03	2017-08-15 10:30:00+03	BTK	DME	Arrived	319	2017-08-15 05:29:00+03	2017-08-15 10:31:00+03
17494	PG0135	2017-08-07 05:25:00+03	2017-08-07 10:30:00+03	BTK	DME	Arrived	319	2017-08-07 05:27:00+03	2017-08-07 10:33:00+03
17495	PG0135	2017-09-13 05:25:00+03	2017-09-13 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17496	PG0135	2017-07-24 05:25:00+03	2017-07-24 10:30:00+03	BTK	DME	Arrived	319	2017-07-24 05:26:00+03	2017-07-24 10:30:00+03
17497	PG0135	2017-08-02 05:25:00+03	2017-08-02 10:30:00+03	BTK	DME	Arrived	319	2017-08-02 09:16:00+03	2017-08-02 14:23:00+03
17498	PG0135	2017-07-31 05:25:00+03	2017-07-31 10:30:00+03	BTK	DME	Arrived	319	2017-07-31 05:29:00+03	2017-07-31 10:36:00+03
17499	PG0135	2017-08-22 05:25:00+03	2017-08-22 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17500	PG0135	2017-07-28 05:25:00+03	2017-07-28 10:30:00+03	BTK	DME	Arrived	319	2017-07-28 05:30:00+03	2017-07-28 10:32:00+03
17501	PG0135	2017-08-30 05:25:00+03	2017-08-30 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17502	PG0135	2017-08-11 05:25:00+03	2017-08-11 10:30:00+03	BTK	DME	Arrived	319	2017-08-11 08:23:00+03	2017-08-11 13:23:00+03
17503	PG0135	2017-09-02 05:25:00+03	2017-09-02 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17504	PG0135	2017-08-25 05:25:00+03	2017-08-25 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17505	PG0135	2017-08-10 05:25:00+03	2017-08-10 10:30:00+03	BTK	DME	Arrived	319	2017-08-10 05:29:00+03	2017-08-10 10:36:00+03
17506	PG0135	2017-08-31 05:25:00+03	2017-08-31 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17507	PG0135	2017-08-29 05:25:00+03	2017-08-29 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17508	PG0135	2017-07-18 05:25:00+03	2017-07-18 10:30:00+03	BTK	DME	Arrived	319	2017-07-18 05:27:00+03	2017-07-18 10:30:00+03
17509	PG0135	2017-07-16 05:25:00+03	2017-07-16 10:30:00+03	BTK	DME	Arrived	319	2017-07-16 05:27:00+03	2017-07-16 10:33:00+03
17510	PG0135	2017-08-21 05:25:00+03	2017-08-21 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17511	PG0135	2017-09-05 05:25:00+03	2017-09-05 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17512	PG0135	2017-07-23 05:25:00+03	2017-07-23 10:30:00+03	BTK	DME	Arrived	319	2017-07-23 05:27:00+03	2017-07-23 10:27:00+03
17513	PG0135	2017-09-11 05:25:00+03	2017-09-11 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17514	PG0135	2017-08-24 05:25:00+03	2017-08-24 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17515	PG0135	2017-08-19 05:25:00+03	2017-08-19 10:30:00+03	BTK	DME	Scheduled	319	\N	\N
17516	PG0173	2017-09-13 14:20:00+03	2017-09-13 16:15:00+03	NBC	OMS	Cancelled	CR2	\N	\N
17517	PG0173	2017-09-06 14:20:00+03	2017-09-06 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17518	PG0173	2017-09-02 14:20:00+03	2017-09-02 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17519	PG0173	2017-08-09 14:20:00+03	2017-08-09 16:15:00+03	NBC	OMS	Arrived	CR2	2017-08-09 14:23:00+03	2017-08-09 16:18:00+03
17520	PG0173	2017-08-05 14:20:00+03	2017-08-05 16:15:00+03	NBC	OMS	Arrived	CR2	2017-08-05 14:22:00+03	2017-08-05 16:15:00+03
17521	PG0173	2017-07-29 14:20:00+03	2017-07-29 16:15:00+03	NBC	OMS	Arrived	CR2	2017-07-29 14:22:00+03	2017-07-29 16:15:00+03
17522	PG0173	2017-09-09 14:20:00+03	2017-09-09 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17523	PG0173	2017-08-19 14:20:00+03	2017-08-19 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17524	PG0173	2017-08-26 14:20:00+03	2017-08-26 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17525	PG0173	2017-07-22 14:20:00+03	2017-07-22 16:15:00+03	NBC	OMS	Arrived	CR2	2017-07-22 14:24:00+03	2017-07-22 16:19:00+03
17526	PG0173	2017-07-19 14:20:00+03	2017-07-19 16:15:00+03	NBC	OMS	Arrived	CR2	2017-07-19 14:24:00+03	2017-07-19 16:18:00+03
17527	PG0173	2017-08-12 14:20:00+03	2017-08-12 16:15:00+03	NBC	OMS	Arrived	CR2	2017-08-12 14:23:00+03	2017-08-12 16:17:00+03
17528	PG0173	2017-08-16 14:20:00+03	2017-08-16 16:15:00+03	NBC	OMS	On Time	CR2	\N	\N
17529	PG0173	2017-08-23 14:20:00+03	2017-08-23 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17530	PG0173	2017-08-30 14:20:00+03	2017-08-30 16:15:00+03	NBC	OMS	Scheduled	CR2	\N	\N
17531	PG0173	2017-08-02 14:20:00+03	2017-08-02 16:15:00+03	NBC	OMS	Arrived	CR2	2017-08-02 14:21:00+03	2017-08-02 16:17:00+03
17532	PG0173	2017-07-26 14:20:00+03	2017-07-26 16:15:00+03	NBC	OMS	Arrived	CR2	2017-07-26 14:20:00+03	2017-07-26 16:15:00+03
17533	PG0123	2017-07-18 09:25:00+03	2017-07-18 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-18 09:30:00+03	2017-07-18 11:17:00+03
17534	PG0123	2017-07-16 09:25:00+03	2017-07-16 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-16 09:29:00+03	2017-07-16 11:11:00+03
17535	PG0123	2017-08-27 09:25:00+03	2017-08-27 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17536	PG0123	2017-08-13 09:25:00+03	2017-08-13 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-13 09:27:00+03	2017-08-13 11:13:00+03
17537	PG0123	2017-09-12 09:25:00+03	2017-09-12 11:10:00+03	NBC	ROV	Cancelled	CR2	\N	\N
17538	PG0123	2017-08-31 09:25:00+03	2017-08-31 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17539	PG0123	2017-07-20 09:25:00+03	2017-07-20 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-20 09:33:00+03	2017-07-20 11:20:00+03
17540	PG0123	2017-08-17 09:25:00+03	2017-08-17 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17541	PG0123	2017-09-03 09:25:00+03	2017-09-03 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17542	PG0123	2017-07-25 09:25:00+03	2017-07-25 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-25 09:27:00+03	2017-07-25 11:13:00+03
17543	PG0123	2017-09-07 09:25:00+03	2017-09-07 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17544	PG0123	2017-08-20 09:25:00+03	2017-08-20 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17545	PG0123	2017-08-06 09:25:00+03	2017-08-06 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-06 09:31:00+03	2017-08-06 11:16:00+03
17546	PG0123	2017-07-27 09:25:00+03	2017-07-27 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-27 09:28:00+03	2017-07-27 11:15:00+03
17547	PG0123	2017-09-14 09:25:00+03	2017-09-14 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17548	PG0123	2017-08-22 09:25:00+03	2017-08-22 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17549	PG0123	2017-08-01 09:25:00+03	2017-08-01 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-01 09:25:00+03	2017-08-01 11:12:00+03
17550	PG0123	2017-09-05 09:25:00+03	2017-09-05 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17551	PG0123	2017-08-10 09:25:00+03	2017-08-10 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-10 09:27:00+03	2017-08-10 11:12:00+03
17552	PG0123	2017-07-23 09:25:00+03	2017-07-23 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-23 09:27:00+03	2017-07-23 11:13:00+03
17553	PG0123	2017-08-29 09:25:00+03	2017-08-29 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17554	PG0123	2017-08-08 09:25:00+03	2017-08-08 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-08 09:29:00+03	2017-08-08 11:14:00+03
17555	PG0123	2017-08-15 09:25:00+03	2017-08-15 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-15 09:31:00+03	2017-08-15 11:18:00+03
17556	PG0123	2017-08-03 09:25:00+03	2017-08-03 11:10:00+03	NBC	ROV	Arrived	CR2	2017-08-03 09:30:00+03	2017-08-03 11:15:00+03
17557	PG0123	2017-09-10 09:25:00+03	2017-09-10 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17558	PG0123	2017-07-30 09:25:00+03	2017-07-30 11:10:00+03	NBC	ROV	Arrived	CR2	2017-07-30 09:28:00+03	2017-07-30 11:12:00+03
17559	PG0123	2017-08-24 09:25:00+03	2017-08-24 11:10:00+03	NBC	ROV	Scheduled	CR2	\N	\N
17560	PG0060	2017-08-03 17:50:00+03	2017-08-03 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-03 17:57:00+03	2017-08-03 20:17:00+03
17561	PG0061	2017-08-01 16:05:00+03	2017-08-01 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-01 16:07:00+03	2017-08-01 18:27:00+03
17562	PG0061	2017-08-27 16:05:00+03	2017-08-27 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17563	PG0060	2017-08-01 17:50:00+03	2017-08-01 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-01 17:54:00+03	2017-08-01 20:11:00+03
17564	PG0061	2017-09-11 16:05:00+03	2017-09-11 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17565	PG0060	2017-09-11 17:50:00+03	2017-09-11 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17566	PG0060	2017-08-06 17:50:00+03	2017-08-06 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-06 17:51:00+03	2017-08-06 20:12:00+03
17567	PG0061	2017-08-06 16:05:00+03	2017-08-06 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-06 16:11:00+03	2017-08-06 18:30:00+03
17568	PG0060	2017-08-22 17:50:00+03	2017-08-22 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17569	PG0061	2017-08-22 16:05:00+03	2017-08-22 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17570	PG0060	2017-09-14 17:50:00+03	2017-09-14 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17571	PG0060	2017-08-14 17:50:00+03	2017-08-14 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-14 17:51:00+03	2017-08-14 20:10:00+03
17572	PG0061	2017-09-08 16:05:00+03	2017-09-08 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17573	PG0061	2017-08-05 16:05:00+03	2017-08-05 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-05 16:11:00+03	2017-08-05 18:31:00+03
17574	PG0060	2017-08-05 17:50:00+03	2017-08-05 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-05 17:53:00+03	2017-08-05 20:12:00+03
17575	PG0061	2017-08-14 16:05:00+03	2017-08-14 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-14 16:10:00+03	2017-08-14 18:30:00+03
17576	PG0060	2017-09-08 17:50:00+03	2017-09-08 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17577	PG0061	2017-09-04 16:05:00+03	2017-09-04 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17578	PG0060	2017-09-04 17:50:00+03	2017-09-04 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17579	PG0061	2017-07-29 16:05:00+03	2017-07-29 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-29 16:06:00+03	2017-07-29 18:26:00+03
17580	PG0060	2017-07-29 17:50:00+03	2017-07-29 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-29 17:53:00+03	2017-07-29 20:15:00+03
17581	PG0060	2017-08-25 17:50:00+03	2017-08-25 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17582	PG0060	2017-08-09 17:50:00+03	2017-08-09 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-09 17:51:00+03	2017-08-09 20:11:00+03
17583	PG0060	2017-08-17 17:50:00+03	2017-08-17 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17584	PG0061	2017-08-17 16:05:00+03	2017-08-17 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17585	PG0061	2017-07-17 16:05:00+03	2017-07-17 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-17 19:08:00+03	2017-07-17 21:30:00+03
17586	PG0060	2017-07-24 17:50:00+03	2017-07-24 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-24 17:53:00+03	2017-07-24 20:13:00+03
17587	PG0060	2017-07-17 17:50:00+03	2017-07-17 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-17 17:55:00+03	2017-07-17 20:15:00+03
17588	PG0060	2017-08-30 17:50:00+03	2017-08-30 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17589	PG0061	2017-08-09 16:05:00+03	2017-08-09 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-09 16:08:00+03	2017-08-09 18:28:00+03
17590	PG0061	2017-08-30 16:05:00+03	2017-08-30 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17591	PG0061	2017-07-24 16:05:00+03	2017-07-24 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-24 16:08:00+03	2017-07-24 18:27:00+03
17592	PG0061	2017-08-16 16:05:00+03	2017-08-16 18:25:00+03	NBC	SCW	On Time	CN1	\N	\N
17593	PG0060	2017-08-16 17:50:00+03	2017-08-16 20:10:00+03	NBC	SCW	On Time	CN1	\N	\N
17594	PG0061	2017-09-09 16:05:00+03	2017-09-09 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17595	PG0060	2017-08-07 17:50:00+03	2017-08-07 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-07 17:53:00+03	2017-08-07 20:12:00+03
17596	PG0061	2017-08-07 16:05:00+03	2017-08-07 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-07 16:08:00+03	2017-08-07 18:29:00+03
17597	PG0060	2017-07-25 17:50:00+03	2017-07-25 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-25 17:52:00+03	2017-07-25 20:10:00+03
17598	PG0060	2017-09-09 17:50:00+03	2017-09-09 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17599	PG0061	2017-07-25 16:05:00+03	2017-07-25 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-25 16:12:00+03	2017-07-25 18:32:00+03
17600	PG0060	2017-09-05 17:50:00+03	2017-09-05 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17601	PG0061	2017-08-24 16:05:00+03	2017-08-24 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17602	PG0060	2017-08-24 17:50:00+03	2017-08-24 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17603	PG0061	2017-09-05 16:05:00+03	2017-09-05 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17604	PG0060	2017-09-07 17:50:00+03	2017-09-07 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17605	PG0061	2017-09-07 16:05:00+03	2017-09-07 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17606	PG0060	2017-07-21 17:50:00+03	2017-07-21 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-21 17:53:00+03	2017-07-21 20:15:00+03
17607	PG0061	2017-07-22 16:05:00+03	2017-07-22 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-22 16:08:00+03	2017-07-22 18:28:00+03
17608	PG0061	2017-07-21 16:05:00+03	2017-07-21 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-21 16:05:00+03	2017-07-21 18:22:00+03
17609	PG0060	2017-07-22 17:50:00+03	2017-07-22 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-22 17:53:00+03	2017-07-22 20:13:00+03
17610	PG0061	2017-09-14 16:05:00+03	2017-09-14 18:25:00+03	NBC	SCW	Cancelled	CN1	\N	\N
17611	PG0060	2017-08-02 17:50:00+03	2017-08-02 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-02 17:55:00+03	2017-08-02 20:14:00+03
17612	PG0061	2017-08-23 16:05:00+03	2017-08-23 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17613	PG0060	2017-08-23 17:50:00+03	2017-08-23 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17614	PG0061	2017-08-02 16:05:00+03	2017-08-02 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-02 16:11:00+03	2017-08-02 18:29:00+03
17615	PG0061	2017-07-20 16:05:00+03	2017-07-20 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-20 16:08:00+03	2017-07-20 18:26:00+03
17616	PG0060	2017-07-20 17:50:00+03	2017-07-20 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-20 17:52:00+03	2017-07-20 20:12:00+03
17617	PG0061	2017-08-04 16:05:00+03	2017-08-04 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-04 16:09:00+03	2017-08-04 18:26:00+03
17618	PG0060	2017-08-04 17:50:00+03	2017-08-04 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-04 17:53:00+03	2017-08-04 20:14:00+03
17619	PG0061	2017-08-20 16:05:00+03	2017-08-20 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17620	PG0060	2017-08-20 17:50:00+03	2017-08-20 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17621	PG0061	2017-07-26 16:05:00+03	2017-07-26 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-26 16:10:00+03	2017-07-26 18:31:00+03
17622	PG0060	2017-08-26 17:50:00+03	2017-08-26 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17623	PG0060	2017-07-26 17:50:00+03	2017-07-26 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-26 17:54:00+03	2017-07-26 20:14:00+03
17624	PG0061	2017-08-26 16:05:00+03	2017-08-26 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17625	PG0061	2017-09-02 16:05:00+03	2017-09-02 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17626	PG0060	2017-08-31 17:50:00+03	2017-08-31 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17627	PG0061	2017-08-31 16:05:00+03	2017-08-31 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17628	PG0060	2017-07-16 17:50:00+03	2017-07-16 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-16 17:53:00+03	2017-07-16 20:13:00+03
17629	PG0060	2017-08-21 17:50:00+03	2017-08-21 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17630	PG0061	2017-08-21 16:05:00+03	2017-08-21 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17631	PG0061	2017-08-28 16:05:00+03	2017-08-28 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17632	PG0060	2017-09-13 17:50:00+03	2017-09-13 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17633	PG0061	2017-09-13 16:05:00+03	2017-09-13 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17634	PG0061	2017-07-31 16:05:00+03	2017-07-31 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-31 16:08:00+03	2017-07-31 18:26:00+03
17635	PG0060	2017-07-31 17:50:00+03	2017-07-31 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-31 17:53:00+03	2017-07-31 20:14:00+03
17636	PG0061	2017-08-11 16:05:00+03	2017-08-11 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-11 16:09:00+03	2017-08-11 18:30:00+03
17637	PG0060	2017-08-11 17:50:00+03	2017-08-11 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-11 17:55:00+03	2017-08-11 20:16:00+03
17638	PG0060	2017-07-19 17:50:00+03	2017-07-19 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-19 17:54:00+03	2017-07-19 20:14:00+03
17639	PG0060	2017-08-15 17:50:00+03	2017-08-15 20:10:00+03	NBC	SCW	Departed	CN1	2017-08-15 17:54:00+03	\N
17640	PG0061	2017-07-19 16:05:00+03	2017-07-19 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-19 19:03:00+03	2017-07-19 21:23:00+03
17641	PG0060	2017-07-28 17:50:00+03	2017-07-28 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-28 17:53:00+03	2017-07-28 20:13:00+03
17642	PG0061	2017-07-28 16:05:00+03	2017-07-28 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-28 16:08:00+03	2017-07-28 18:27:00+03
17643	PG0061	2017-08-18 16:05:00+03	2017-08-18 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17644	PG0060	2017-08-19 17:50:00+03	2017-08-19 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17645	PG0060	2017-08-08 17:50:00+03	2017-08-08 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-08 17:51:00+03	2017-08-08 20:11:00+03
17646	PG0061	2017-08-08 16:05:00+03	2017-08-08 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-08 16:05:00+03	2017-08-08 18:25:00+03
17647	PG0060	2017-08-18 17:50:00+03	2017-08-18 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17648	PG0061	2017-08-19 16:05:00+03	2017-08-19 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17649	PG0060	2017-09-02 17:50:00+03	2017-09-02 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17650	PG0060	2017-08-28 17:50:00+03	2017-08-28 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17651	PG0061	2017-09-12 16:05:00+03	2017-09-12 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17652	PG0060	2017-07-30 17:50:00+03	2017-07-30 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-30 17:52:00+03	2017-07-30 20:12:00+03
17653	PG0061	2017-07-30 16:05:00+03	2017-07-30 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-30 16:06:00+03	2017-07-30 18:27:00+03
17654	PG0061	2017-09-03 16:05:00+03	2017-09-03 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17655	PG0060	2017-09-03 17:50:00+03	2017-09-03 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17656	PG0060	2017-08-12 17:50:00+03	2017-08-12 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-12 17:52:00+03	2017-08-12 20:12:00+03
17657	PG0060	2017-09-12 17:50:00+03	2017-09-12 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17658	PG0061	2017-07-23 16:05:00+03	2017-07-23 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-23 16:13:00+03	2017-07-23 18:34:00+03
17659	PG0060	2017-09-10 17:50:00+03	2017-09-10 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17660	PG0060	2017-07-23 17:50:00+03	2017-07-23 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-23 17:55:00+03	2017-07-23 20:13:00+03
17661	PG0061	2017-09-10 16:05:00+03	2017-09-10 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17662	PG0060	2017-08-29 17:50:00+03	2017-08-29 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17663	PG0061	2017-08-29 16:05:00+03	2017-08-29 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17664	PG0061	2017-09-01 16:05:00+03	2017-09-01 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17665	PG0060	2017-09-01 17:50:00+03	2017-09-01 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17666	PG0061	2017-08-12 16:05:00+03	2017-08-12 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-12 16:07:00+03	2017-08-12 18:28:00+03
17667	PG0061	2017-09-06 16:05:00+03	2017-09-06 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17668	PG0061	2017-08-03 16:05:00+03	2017-08-03 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-03 16:08:00+03	2017-08-03 18:28:00+03
17669	PG0060	2017-09-06 17:50:00+03	2017-09-06 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17670	PG0061	2017-08-13 16:05:00+03	2017-08-13 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-13 16:07:00+03	2017-08-13 18:29:00+03
17671	PG0061	2017-08-10 16:05:00+03	2017-08-10 18:25:00+03	NBC	SCW	Arrived	CN1	2017-08-10 16:08:00+03	2017-08-10 18:31:00+03
17672	PG0060	2017-08-13 17:50:00+03	2017-08-13 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-13 17:52:00+03	2017-08-13 20:11:00+03
17673	PG0060	2017-07-27 17:50:00+03	2017-07-27 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-27 17:54:00+03	2017-07-27 20:14:00+03
17674	PG0061	2017-07-27 16:05:00+03	2017-07-27 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-27 16:09:00+03	2017-07-27 18:26:00+03
17675	PG0061	2017-08-25 16:05:00+03	2017-08-25 18:25:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17676	PG0061	2017-08-15 16:05:00+03	2017-08-15 18:25:00+03	NBC	SCW	Departed	CN1	2017-08-15 16:09:00+03	\N
17677	PG0061	2017-07-16 16:05:00+03	2017-07-16 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-16 16:06:00+03	2017-07-16 18:25:00+03
17678	PG0060	2017-08-10 17:50:00+03	2017-08-10 20:10:00+03	NBC	SCW	Arrived	CN1	2017-08-10 17:55:00+03	2017-08-10 20:14:00+03
17679	PG0060	2017-08-27 17:50:00+03	2017-08-27 20:10:00+03	NBC	SCW	Scheduled	CN1	\N	\N
17680	PG0060	2017-07-18 17:50:00+03	2017-07-18 20:10:00+03	NBC	SCW	Arrived	CN1	2017-07-18 17:51:00+03	2017-07-18 20:11:00+03
17681	PG0061	2017-07-18 16:05:00+03	2017-07-18 18:25:00+03	NBC	SCW	Arrived	CN1	2017-07-18 16:09:00+03	2017-07-18 18:28:00+03
17682	PG0253	2017-08-31 18:10:00+03	2017-08-31 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17683	PG0253	2017-09-01 18:10:00+03	2017-09-01 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17684	PG0253	2017-07-31 18:10:00+03	2017-07-31 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-31 18:14:00+03	2017-07-31 18:39:00+03
17685	PG0253	2017-08-23 18:10:00+03	2017-08-23 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17686	PG0253	2017-08-21 18:10:00+03	2017-08-21 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17687	PG0253	2017-08-24 18:10:00+03	2017-08-24 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17688	PG0253	2017-07-24 18:10:00+03	2017-07-24 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-24 18:14:00+03	2017-07-24 18:38:00+03
17689	PG0253	2017-08-19 18:10:00+03	2017-08-19 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17690	PG0253	2017-09-13 18:10:00+03	2017-09-13 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17691	PG0253	2017-09-04 18:10:00+03	2017-09-04 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17692	PG0253	2017-08-10 18:10:00+03	2017-08-10 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-10 18:13:00+03	2017-08-10 18:38:00+03
17693	PG0253	2017-07-17 18:10:00+03	2017-07-17 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-17 18:13:00+03	2017-07-17 18:38:00+03
17694	PG0253	2017-07-18 18:10:00+03	2017-07-18 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-18 18:12:00+03	2017-07-18 18:37:00+03
17695	PG0253	2017-08-26 18:10:00+03	2017-08-26 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17696	PG0253	2017-09-10 18:10:00+03	2017-09-10 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17697	PG0253	2017-08-11 18:10:00+03	2017-08-11 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-11 18:15:00+03	2017-08-11 18:40:00+03
17698	PG0253	2017-07-20 18:10:00+03	2017-07-20 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-20 18:11:00+03	2017-07-20 18:36:00+03
17699	PG0253	2017-07-28 18:10:00+03	2017-07-28 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-28 18:14:00+03	2017-07-28 18:39:00+03
17700	PG0253	2017-09-08 18:10:00+03	2017-09-08 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17701	PG0253	2017-08-02 18:10:00+03	2017-08-02 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-02 18:14:00+03	2017-08-02 18:39:00+03
17702	PG0253	2017-09-05 18:10:00+03	2017-09-05 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17703	PG0253	2017-07-25 18:10:00+03	2017-07-25 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-25 18:16:00+03	2017-07-25 18:41:00+03
17704	PG0253	2017-08-08 18:10:00+03	2017-08-08 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-08 18:11:00+03	2017-08-08 18:36:00+03
17705	PG0253	2017-08-16 18:10:00+03	2017-08-16 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17706	PG0253	2017-09-07 18:10:00+03	2017-09-07 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17707	PG0253	2017-08-18 18:10:00+03	2017-08-18 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17708	PG0253	2017-08-06 18:10:00+03	2017-08-06 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-06 18:12:00+03	2017-08-06 18:37:00+03
17709	PG0253	2017-08-29 18:10:00+03	2017-08-29 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17710	PG0253	2017-08-25 18:10:00+03	2017-08-25 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17711	PG0253	2017-07-29 18:10:00+03	2017-07-29 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-29 18:14:00+03	2017-07-29 18:39:00+03
17712	PG0253	2017-08-01 18:10:00+03	2017-08-01 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-01 18:13:00+03	2017-08-01 18:38:00+03
17713	PG0253	2017-08-05 18:10:00+03	2017-08-05 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-05 18:15:00+03	2017-08-05 18:40:00+03
17714	PG0253	2017-08-14 18:10:00+03	2017-08-14 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-14 18:12:00+03	2017-08-14 18:37:00+03
17715	PG0253	2017-09-09 18:10:00+03	2017-09-09 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17716	PG0253	2017-08-28 18:10:00+03	2017-08-28 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17717	PG0253	2017-08-03 18:10:00+03	2017-08-03 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-03 18:15:00+03	2017-08-03 18:40:00+03
17718	PG0253	2017-07-30 18:10:00+03	2017-07-30 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-30 18:13:00+03	2017-07-30 18:38:00+03
17719	PG0253	2017-07-22 18:10:00+03	2017-07-22 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-22 18:11:00+03	2017-07-22 18:36:00+03
17720	PG0253	2017-07-19 18:10:00+03	2017-07-19 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-19 18:12:00+03	2017-07-19 18:37:00+03
17721	PG0253	2017-07-23 18:10:00+03	2017-07-23 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-23 18:10:00+03	2017-07-23 18:36:00+03
17722	PG0253	2017-07-27 18:10:00+03	2017-07-27 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-27 18:11:00+03	2017-07-27 18:36:00+03
17723	PG0253	2017-09-14 18:10:00+03	2017-09-14 18:35:00+03	NBC	CSY	Cancelled	CR2	\N	\N
17724	PG0253	2017-08-27 18:10:00+03	2017-08-27 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17725	PG0253	2017-09-02 18:10:00+03	2017-09-02 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17726	PG0253	2017-08-07 18:10:00+03	2017-08-07 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-07 18:11:00+03	2017-08-07 18:36:00+03
17727	PG0253	2017-08-20 18:10:00+03	2017-08-20 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17728	PG0253	2017-08-09 18:10:00+03	2017-08-09 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-09 18:13:00+03	2017-08-09 18:38:00+03
17729	PG0253	2017-09-12 18:10:00+03	2017-09-12 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17730	PG0253	2017-08-04 18:10:00+03	2017-08-04 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-04 18:13:00+03	2017-08-04 18:38:00+03
17731	PG0253	2017-08-13 18:10:00+03	2017-08-13 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-13 18:13:00+03	2017-08-13 18:38:00+03
17732	PG0253	2017-07-16 18:10:00+03	2017-07-16 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-16 18:14:00+03	2017-07-16 18:39:00+03
17733	PG0253	2017-09-03 18:10:00+03	2017-09-03 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17734	PG0253	2017-08-12 18:10:00+03	2017-08-12 18:35:00+03	NBC	CSY	Arrived	CR2	2017-08-12 18:14:00+03	2017-08-12 18:40:00+03
17735	PG0253	2017-08-22 18:10:00+03	2017-08-22 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17736	PG0253	2017-08-30 18:10:00+03	2017-08-30 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17737	PG0253	2017-09-11 18:10:00+03	2017-09-11 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17738	PG0253	2017-07-26 18:10:00+03	2017-07-26 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-26 18:11:00+03	2017-07-26 18:36:00+03
17739	PG0253	2017-08-17 18:10:00+03	2017-08-17 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17740	PG0253	2017-07-21 18:10:00+03	2017-07-21 18:35:00+03	NBC	CSY	Arrived	CR2	2017-07-21 18:12:00+03	2017-07-21 18:37:00+03
17741	PG0253	2017-09-06 18:10:00+03	2017-09-06 18:35:00+03	NBC	CSY	Scheduled	CR2	\N	\N
17742	PG0253	2017-08-15 18:10:00+03	2017-08-15 18:35:00+03	NBC	CSY	On Time	CR2	\N	\N
17743	PG0026	2017-08-27 08:05:00+03	2017-08-27 10:15:00+03	OSW	VKO	Scheduled	CR2	\N	\N
17744	PG0026	2017-09-10 08:05:00+03	2017-09-10 10:15:00+03	OSW	VKO	Cancelled	CR2	\N	\N
17745	PG0026	2017-07-30 08:05:00+03	2017-07-30 10:15:00+03	OSW	VKO	Arrived	CR2	2017-07-30 08:08:00+03	2017-07-30 10:19:00+03
17746	PG0026	2017-08-06 08:05:00+03	2017-08-06 10:15:00+03	OSW	VKO	Arrived	CR2	2017-08-06 08:08:00+03	2017-08-06 10:18:00+03
17747	PG0026	2017-07-23 08:05:00+03	2017-07-23 10:15:00+03	OSW	VKO	Arrived	CR2	2017-07-23 08:07:00+03	2017-07-23 10:18:00+03
17748	PG0026	2017-08-20 08:05:00+03	2017-08-20 10:15:00+03	OSW	VKO	Scheduled	CR2	\N	\N
17749	PG0026	2017-07-16 08:05:00+03	2017-07-16 10:15:00+03	OSW	VKO	Arrived	CR2	2017-07-16 08:07:00+03	2017-07-16 10:17:00+03
17750	PG0026	2017-09-03 08:05:00+03	2017-09-03 10:15:00+03	OSW	VKO	Scheduled	CR2	\N	\N
17751	PG0026	2017-08-13 08:05:00+03	2017-08-13 10:15:00+03	OSW	VKO	Arrived	CR2	2017-08-13 08:08:00+03	2017-08-13 10:16:00+03
17752	PG0349	2017-08-03 07:15:00+03	2017-08-03 09:05:00+03	OSW	HMA	Arrived	CR2	2017-08-03 07:18:00+03	2017-08-03 09:08:00+03
17753	PG0349	2017-08-24 07:15:00+03	2017-08-24 09:05:00+03	OSW	HMA	Scheduled	CR2	\N	\N
17754	PG0349	2017-08-10 07:15:00+03	2017-08-10 09:05:00+03	OSW	HMA	Arrived	CR2	2017-08-10 07:16:00+03	2017-08-10 09:06:00+03
17755	PG0349	2017-09-14 07:15:00+03	2017-09-14 09:05:00+03	OSW	HMA	Cancelled	CR2	\N	\N
17756	PG0349	2017-08-17 07:15:00+03	2017-08-17 09:05:00+03	OSW	HMA	Scheduled	CR2	\N	\N
17757	PG0349	2017-07-20 07:15:00+03	2017-07-20 09:05:00+03	OSW	HMA	Arrived	CR2	2017-07-20 07:18:00+03	2017-07-20 09:08:00+03
17758	PG0349	2017-09-07 07:15:00+03	2017-09-07 09:05:00+03	OSW	HMA	Scheduled	CR2	\N	\N
17759	PG0349	2017-08-31 07:15:00+03	2017-08-31 09:05:00+03	OSW	HMA	Scheduled	CR2	\N	\N
17760	PG0349	2017-07-27 07:15:00+03	2017-07-27 09:05:00+03	OSW	HMA	Arrived	CR2	2017-07-27 07:15:00+03	2017-07-27 09:05:00+03
17761	PG0372	2017-09-06 09:15:00+03	2017-09-06 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17762	PG0372	2017-08-30 09:15:00+03	2017-08-30 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17763	PG0372	2017-07-22 09:15:00+03	2017-07-22 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-22 09:17:00+03	2017-07-22 11:52:00+03
17764	PG0372	2017-08-12 09:15:00+03	2017-08-12 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-12 09:18:00+03	2017-08-12 11:54:00+03
17765	PG0372	2017-08-07 09:15:00+03	2017-08-07 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-07 09:20:00+03	2017-08-07 11:54:00+03
17766	PG0372	2017-09-04 09:15:00+03	2017-09-04 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17767	PG0372	2017-08-05 09:15:00+03	2017-08-05 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-05 09:19:00+03	2017-08-05 11:55:00+03
17768	PG0372	2017-08-21 09:15:00+03	2017-08-21 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17769	PG0372	2017-08-26 09:15:00+03	2017-08-26 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17770	PG0372	2017-07-24 09:15:00+03	2017-07-24 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-24 09:20:00+03	2017-07-24 11:56:00+03
17771	PG0372	2017-08-19 09:15:00+03	2017-08-19 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17772	PG0372	2017-08-09 09:15:00+03	2017-08-09 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-09 09:18:00+03	2017-08-09 11:51:00+03
17773	PG0372	2017-08-23 09:15:00+03	2017-08-23 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17774	PG0372	2017-07-31 09:15:00+03	2017-07-31 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-31 09:17:00+03	2017-07-31 11:50:00+03
17775	PG0372	2017-09-13 09:15:00+03	2017-09-13 11:50:00+03	OSW	ULV	Cancelled	CN1	\N	\N
17776	PG0372	2017-08-16 09:15:00+03	2017-08-16 11:50:00+03	OSW	ULV	On Time	CN1	\N	\N
17777	PG0372	2017-08-28 09:15:00+03	2017-08-28 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17778	PG0372	2017-07-26 09:15:00+03	2017-07-26 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-26 09:16:00+03	2017-07-26 11:53:00+03
17779	PG0372	2017-09-11 09:15:00+03	2017-09-11 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17780	PG0372	2017-08-02 09:15:00+03	2017-08-02 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-02 09:18:00+03	2017-08-02 11:52:00+03
17781	PG0372	2017-07-29 09:15:00+03	2017-07-29 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-29 09:16:00+03	2017-07-29 11:48:00+03
17782	PG0372	2017-08-14 09:15:00+03	2017-08-14 11:50:00+03	OSW	ULV	Arrived	CN1	2017-08-14 09:16:00+03	2017-08-14 11:51:00+03
17783	PG0372	2017-07-17 09:15:00+03	2017-07-17 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-17 09:18:00+03	2017-07-17 11:52:00+03
17784	PG0372	2017-07-19 09:15:00+03	2017-07-19 11:50:00+03	OSW	ULV	Arrived	CN1	2017-07-19 09:20:00+03	2017-07-19 11:54:00+03
17785	PG0372	2017-09-02 09:15:00+03	2017-09-02 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17786	PG0372	2017-09-09 09:15:00+03	2017-09-09 11:50:00+03	OSW	ULV	Scheduled	CN1	\N	\N
17787	PG0023	2017-08-20 11:50:00+03	2017-08-20 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17788	PG0023	2017-09-10 11:50:00+03	2017-09-10 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17789	PG0023	2017-08-13 11:50:00+03	2017-08-13 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-13 11:53:00+03	2017-08-13 14:03:00+03
17790	PG0023	2017-08-10 11:50:00+03	2017-08-10 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-10 11:55:00+03	2017-08-10 14:05:00+03
17791	PG0023	2017-08-31 11:50:00+03	2017-08-31 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17792	PG0023	2017-08-03 11:50:00+03	2017-08-03 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-03 11:52:00+03	2017-08-03 14:03:00+03
17793	PG0023	2017-08-08 11:50:00+03	2017-08-08 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-08 11:54:00+03	2017-08-08 14:06:00+03
17794	PG0023	2017-07-23 11:50:00+03	2017-07-23 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-23 11:50:00+03	2017-07-23 13:59:00+03
17795	PG0023	2017-08-17 11:50:00+03	2017-08-17 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17796	PG0023	2017-08-27 11:50:00+03	2017-08-27 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17797	PG0023	2017-07-25 11:50:00+03	2017-07-25 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-25 11:53:00+03	2017-07-25 14:01:00+03
17798	PG0023	2017-09-07 11:50:00+03	2017-09-07 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17799	PG0023	2017-09-03 11:50:00+03	2017-09-03 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17800	PG0023	2017-09-05 11:50:00+03	2017-09-05 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17801	PG0023	2017-09-12 11:50:00+03	2017-09-12 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17802	PG0023	2017-07-30 11:50:00+03	2017-07-30 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-30 11:54:00+03	2017-07-30 14:05:00+03
17803	PG0023	2017-07-20 11:50:00+03	2017-07-20 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-20 11:53:00+03	2017-07-20 14:03:00+03
17804	PG0023	2017-09-14 11:50:00+03	2017-09-14 14:00:00+03	OSW	KRO	Cancelled	CN1	\N	\N
17805	PG0023	2017-07-18 11:50:00+03	2017-07-18 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-18 11:52:00+03	2017-07-18 14:01:00+03
17806	PG0023	2017-08-24 11:50:00+03	2017-08-24 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17807	PG0023	2017-08-15 11:50:00+03	2017-08-15 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-15 11:52:00+03	2017-08-15 14:04:00+03
17808	PG0023	2017-07-16 11:50:00+03	2017-07-16 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-16 11:52:00+03	2017-07-16 14:02:00+03
17809	PG0023	2017-08-29 11:50:00+03	2017-08-29 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17810	PG0023	2017-08-22 11:50:00+03	2017-08-22 14:00:00+03	OSW	KRO	Scheduled	CN1	\N	\N
17811	PG0023	2017-08-01 11:50:00+03	2017-08-01 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-01 11:58:00+03	2017-08-01 14:08:00+03
17812	PG0023	2017-07-27 11:50:00+03	2017-07-27 14:00:00+03	OSW	KRO	Arrived	CN1	2017-07-27 11:50:00+03	2017-07-27 13:59:00+03
17813	PG0023	2017-08-06 11:50:00+03	2017-08-06 14:00:00+03	OSW	KRO	Arrived	CN1	2017-08-06 11:53:00+03	2017-08-06 14:03:00+03
17814	PG0115	2017-08-20 10:45:00+03	2017-08-20 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17815	PG0115	2017-08-25 10:45:00+03	2017-08-25 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17816	PG0115	2017-07-25 10:45:00+03	2017-07-25 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-25 10:47:00+03	2017-07-25 11:37:00+03
17817	PG0115	2017-09-10 10:45:00+03	2017-09-10 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17818	PG0115	2017-08-15 10:45:00+03	2017-08-15 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-15 10:47:00+03	2017-08-15 11:37:00+03
17819	PG0115	2017-09-03 10:45:00+03	2017-09-03 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17820	PG0115	2017-08-08 10:45:00+03	2017-08-08 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-08 10:50:00+03	2017-08-08 11:40:00+03
17821	PG0115	2017-08-21 10:45:00+03	2017-08-21 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17822	PG0115	2017-08-31 10:45:00+03	2017-08-31 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17823	PG0115	2017-08-14 10:45:00+03	2017-08-14 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-14 10:50:00+03	2017-08-14 11:40:00+03
17824	PG0115	2017-07-26 10:45:00+03	2017-07-26 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-26 14:21:00+03	2017-07-26 15:11:00+03
17825	PG0115	2017-07-24 10:45:00+03	2017-07-24 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-24 10:48:00+03	2017-07-24 11:39:00+03
17826	PG0115	2017-08-30 10:45:00+03	2017-08-30 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17827	PG0115	2017-08-07 10:45:00+03	2017-08-07 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-07 10:49:00+03	2017-08-07 11:38:00+03
17828	PG0115	2017-08-16 10:45:00+03	2017-08-16 11:35:00+03	BQS	KHV	On Time	SU9	\N	\N
17829	PG0115	2017-07-17 10:45:00+03	2017-07-17 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-17 10:48:00+03	2017-07-17 11:39:00+03
17830	PG0115	2017-08-13 10:45:00+03	2017-08-13 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-13 10:50:00+03	2017-08-13 11:40:00+03
17831	PG0115	2017-08-27 10:45:00+03	2017-08-27 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17832	PG0115	2017-09-04 10:45:00+03	2017-09-04 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17833	PG0115	2017-08-12 10:45:00+03	2017-08-12 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-12 10:51:00+03	2017-08-12 11:41:00+03
17834	PG0115	2017-08-06 10:45:00+03	2017-08-06 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-06 10:46:00+03	2017-08-06 11:35:00+03
17835	PG0115	2017-09-01 10:45:00+03	2017-09-01 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17836	PG0115	2017-07-27 10:45:00+03	2017-07-27 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-27 10:48:00+03	2017-07-27 11:39:00+03
17837	PG0115	2017-07-18 10:45:00+03	2017-07-18 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-18 10:46:00+03	2017-07-18 11:35:00+03
17838	PG0115	2017-08-10 10:45:00+03	2017-08-10 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-10 10:46:00+03	2017-08-10 11:36:00+03
17839	PG0115	2017-09-14 10:45:00+03	2017-09-14 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17840	PG0115	2017-08-05 10:45:00+03	2017-08-05 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-05 10:49:00+03	2017-08-05 11:40:00+03
17841	PG0115	2017-09-11 10:45:00+03	2017-09-11 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17842	PG0115	2017-09-09 10:45:00+03	2017-09-09 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17843	PG0115	2017-08-24 10:45:00+03	2017-08-24 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17844	PG0115	2017-08-22 10:45:00+03	2017-08-22 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17845	PG0115	2017-08-17 10:45:00+03	2017-08-17 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17846	PG0115	2017-09-02 10:45:00+03	2017-09-02 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17847	PG0115	2017-09-05 10:45:00+03	2017-09-05 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17848	PG0115	2017-08-04 10:45:00+03	2017-08-04 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-04 13:53:00+03	2017-08-04 14:43:00+03
17849	PG0115	2017-08-26 10:45:00+03	2017-08-26 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17850	PG0115	2017-07-19 10:45:00+03	2017-07-19 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-19 10:45:00+03	2017-07-19 11:35:00+03
17851	PG0115	2017-07-23 10:45:00+03	2017-07-23 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-23 10:48:00+03	2017-07-23 11:39:00+03
17852	PG0115	2017-07-28 10:45:00+03	2017-07-28 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-28 10:47:00+03	2017-07-28 11:38:00+03
17853	PG0115	2017-08-03 10:45:00+03	2017-08-03 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-03 10:47:00+03	2017-08-03 11:36:00+03
17854	PG0115	2017-09-12 10:45:00+03	2017-09-12 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17855	PG0115	2017-08-29 10:45:00+03	2017-08-29 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17856	PG0115	2017-07-16 10:45:00+03	2017-07-16 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-16 10:49:00+03	2017-07-16 11:39:00+03
17857	PG0115	2017-09-06 10:45:00+03	2017-09-06 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17858	PG0115	2017-09-13 10:45:00+03	2017-09-13 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17859	PG0115	2017-08-18 10:45:00+03	2017-08-18 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17860	PG0115	2017-08-28 10:45:00+03	2017-08-28 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17861	PG0115	2017-08-02 10:45:00+03	2017-08-02 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-02 10:47:00+03	2017-08-02 11:37:00+03
17862	PG0115	2017-08-09 10:45:00+03	2017-08-09 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-09 10:47:00+03	2017-08-09 11:37:00+03
17863	PG0115	2017-07-20 10:45:00+03	2017-07-20 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-20 10:45:00+03	2017-07-20 11:35:00+03
17864	PG0115	2017-07-29 10:45:00+03	2017-07-29 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-29 14:22:00+03	2017-07-29 15:13:00+03
17865	PG0115	2017-08-01 10:45:00+03	2017-08-01 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-01 10:46:00+03	2017-08-01 11:35:00+03
17866	PG0115	2017-09-08 10:45:00+03	2017-09-08 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17867	PG0115	2017-08-11 10:45:00+03	2017-08-11 11:35:00+03	BQS	KHV	Arrived	SU9	2017-08-11 10:52:00+03	2017-08-11 11:42:00+03
17868	PG0115	2017-07-22 10:45:00+03	2017-07-22 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-22 10:50:00+03	2017-07-22 11:40:00+03
17869	PG0115	2017-08-23 10:45:00+03	2017-08-23 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17870	PG0115	2017-07-21 10:45:00+03	2017-07-21 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-21 10:51:00+03	2017-07-21 11:41:00+03
17871	PG0115	2017-09-07 10:45:00+03	2017-09-07 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17872	PG0115	2017-07-31 10:45:00+03	2017-07-31 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-31 10:48:00+03	2017-07-31 11:38:00+03
17873	PG0115	2017-07-30 10:45:00+03	2017-07-30 11:35:00+03	BQS	KHV	Arrived	SU9	2017-07-30 10:49:00+03	2017-07-30 11:39:00+03
17874	PG0115	2017-08-19 10:45:00+03	2017-08-19 11:35:00+03	BQS	KHV	Scheduled	SU9	\N	\N
17875	PG0006	2017-08-17 17:20:00+03	2017-08-17 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17876	PG0006	2017-09-09 17:20:00+03	2017-09-09 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17877	PG0006	2017-08-03 17:20:00+03	2017-08-03 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-03 17:25:00+03	2017-08-03 19:30:00+03
17878	PG0006	2017-07-31 17:20:00+03	2017-07-31 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-31 17:22:00+03	2017-07-31 19:26:00+03
17879	PG0006	2017-08-31 17:20:00+03	2017-08-31 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17880	PG0006	2017-09-11 17:20:00+03	2017-09-11 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17881	PG0006	2017-07-22 17:20:00+03	2017-07-22 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-22 17:23:00+03	2017-07-22 19:26:00+03
17882	PG0006	2017-07-27 17:20:00+03	2017-07-27 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-27 17:22:00+03	2017-07-27 19:29:00+03
17883	PG0006	2017-09-04 17:20:00+03	2017-09-04 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17884	PG0006	2017-07-20 17:20:00+03	2017-07-20 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-20 17:24:00+03	2017-07-20 19:30:00+03
17885	PG0006	2017-09-14 17:20:00+03	2017-09-14 19:25:00+03	PKV	DME	Cancelled	CN1	\N	\N
17886	PG0006	2017-08-05 17:20:00+03	2017-08-05 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-05 17:23:00+03	2017-08-05 19:28:00+03
17887	PG0006	2017-08-07 17:20:00+03	2017-08-07 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-07 19:58:00+03	2017-08-07 22:03:00+03
17888	PG0006	2017-08-26 17:20:00+03	2017-08-26 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17889	PG0006	2017-07-17 17:20:00+03	2017-07-17 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-17 17:26:00+03	2017-07-17 19:28:00+03
17890	PG0006	2017-07-29 17:20:00+03	2017-07-29 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-29 17:22:00+03	2017-07-29 19:30:00+03
17891	PG0006	2017-09-02 17:20:00+03	2017-09-02 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17892	PG0006	2017-07-24 17:20:00+03	2017-07-24 19:25:00+03	PKV	DME	Arrived	CN1	2017-07-24 17:22:00+03	2017-07-24 19:28:00+03
17893	PG0006	2017-09-07 17:20:00+03	2017-09-07 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17894	PG0006	2017-08-10 17:20:00+03	2017-08-10 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-10 17:26:00+03	2017-08-10 19:28:00+03
17895	PG0006	2017-08-28 17:20:00+03	2017-08-28 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17896	PG0006	2017-08-12 17:20:00+03	2017-08-12 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-12 17:26:00+03	2017-08-12 19:30:00+03
17897	PG0006	2017-08-21 17:20:00+03	2017-08-21 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17898	PG0006	2017-08-24 17:20:00+03	2017-08-24 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17899	PG0006	2017-08-14 17:20:00+03	2017-08-14 19:25:00+03	PKV	DME	Arrived	CN1	2017-08-14 17:26:00+03	2017-08-14 19:30:00+03
17900	PG0006	2017-08-19 17:20:00+03	2017-08-19 19:25:00+03	PKV	DME	Scheduled	CN1	\N	\N
17901	PG0282	2017-07-24 16:55:00+03	2017-07-24 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-24 16:57:00+03	2017-07-24 18:52:00+03
17902	PG0282	2017-07-18 16:55:00+03	2017-07-18 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-18 16:57:00+03	2017-07-18 18:50:00+03
17903	PG0282	2017-08-18 16:55:00+03	2017-08-18 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17904	PG0282	2017-07-16 16:55:00+03	2017-07-16 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-16 16:58:00+03	2017-07-16 18:54:00+03
17905	PG0282	2017-09-01 16:55:00+03	2017-09-01 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17906	PG0282	2017-07-20 16:55:00+03	2017-07-20 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-20 16:59:00+03	2017-07-20 18:55:00+03
17907	PG0282	2017-07-31 16:55:00+03	2017-07-31 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-31 16:59:00+03	2017-07-31 18:55:00+03
17908	PG0282	2017-08-15 16:55:00+03	2017-08-15 18:50:00+03	PKV	SVO	Departed	CN1	2017-08-15 16:56:00+03	\N
17909	PG0282	2017-07-27 16:55:00+03	2017-07-27 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-27 17:05:00+03	2017-07-27 19:00:00+03
17910	PG0282	2017-08-10 16:55:00+03	2017-08-10 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-10 16:57:00+03	2017-08-10 18:53:00+03
17911	PG0282	2017-08-05 16:55:00+03	2017-08-05 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-05 16:57:00+03	2017-08-05 18:53:00+03
17912	PG0282	2017-08-27 16:55:00+03	2017-08-27 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17913	PG0282	2017-07-29 16:55:00+03	2017-07-29 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-29 16:57:00+03	2017-07-29 18:52:00+03
17914	PG0282	2017-09-14 16:55:00+03	2017-09-14 18:50:00+03	PKV	SVO	Cancelled	CN1	\N	\N
17915	PG0282	2017-09-11 16:55:00+03	2017-09-11 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17916	PG0282	2017-08-31 16:55:00+03	2017-08-31 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17917	PG0282	2017-08-01 16:55:00+03	2017-08-01 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-01 16:57:00+03	2017-08-01 18:51:00+03
17918	PG0282	2017-09-13 16:55:00+03	2017-09-13 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17919	PG0282	2017-08-26 16:55:00+03	2017-08-26 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17920	PG0282	2017-08-03 16:55:00+03	2017-08-03 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-03 16:58:00+03	2017-08-03 18:52:00+03
17921	PG0282	2017-08-07 16:55:00+03	2017-08-07 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-07 16:58:00+03	2017-08-07 18:54:00+03
17922	PG0282	2017-08-13 16:55:00+03	2017-08-13 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-13 16:57:00+03	2017-08-13 18:52:00+03
17923	PG0282	2017-07-22 16:55:00+03	2017-07-22 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-22 16:59:00+03	2017-07-22 18:54:00+03
17924	PG0282	2017-08-14 16:55:00+03	2017-08-14 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-14 16:57:00+03	2017-08-14 18:51:00+03
17925	PG0282	2017-08-11 16:55:00+03	2017-08-11 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-11 16:58:00+03	2017-08-11 18:53:00+03
17926	PG0282	2017-09-04 16:55:00+03	2017-09-04 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17927	PG0282	2017-07-25 16:55:00+03	2017-07-25 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-25 16:57:00+03	2017-07-25 18:52:00+03
17928	PG0282	2017-09-09 16:55:00+03	2017-09-09 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17929	PG0282	2017-08-12 16:55:00+03	2017-08-12 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-12 16:57:00+03	2017-08-12 18:54:00+03
17930	PG0282	2017-08-24 16:55:00+03	2017-08-24 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17931	PG0282	2017-08-02 16:55:00+03	2017-08-02 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-02 16:59:00+03	2017-08-02 18:52:00+03
17932	PG0282	2017-09-03 16:55:00+03	2017-09-03 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17933	PG0282	2017-09-12 16:55:00+03	2017-09-12 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17934	PG0282	2017-08-19 16:55:00+03	2017-08-19 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17935	PG0282	2017-08-17 16:55:00+03	2017-08-17 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17936	PG0282	2017-08-25 16:55:00+03	2017-08-25 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17937	PG0282	2017-07-23 16:55:00+03	2017-07-23 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-23 16:59:00+03	2017-07-23 18:55:00+03
17938	PG0282	2017-08-29 16:55:00+03	2017-08-29 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17939	PG0282	2017-07-28 16:55:00+03	2017-07-28 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-28 16:58:00+03	2017-07-28 18:53:00+03
17940	PG0282	2017-09-07 16:55:00+03	2017-09-07 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17941	PG0282	2017-08-30 16:55:00+03	2017-08-30 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17942	PG0282	2017-09-05 16:55:00+03	2017-09-05 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17943	PG0282	2017-09-10 16:55:00+03	2017-09-10 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17944	PG0282	2017-08-20 16:55:00+03	2017-08-20 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17945	PG0282	2017-08-09 16:55:00+03	2017-08-09 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-09 17:00:00+03	2017-08-09 18:54:00+03
17946	PG0282	2017-08-04 16:55:00+03	2017-08-04 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-04 16:59:00+03	2017-08-04 18:54:00+03
17947	PG0282	2017-07-30 16:55:00+03	2017-07-30 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-30 16:57:00+03	2017-07-30 18:52:00+03
17948	PG0282	2017-07-26 16:55:00+03	2017-07-26 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-26 16:59:00+03	2017-07-26 18:55:00+03
17949	PG0282	2017-07-17 16:55:00+03	2017-07-17 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-17 16:57:00+03	2017-07-17 18:51:00+03
17950	PG0282	2017-08-28 16:55:00+03	2017-08-28 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17951	PG0282	2017-08-08 16:55:00+03	2017-08-08 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-08 16:56:00+03	2017-08-08 18:51:00+03
17952	PG0282	2017-08-06 16:55:00+03	2017-08-06 18:50:00+03	PKV	SVO	Arrived	CN1	2017-08-06 16:56:00+03	2017-08-06 18:53:00+03
17953	PG0282	2017-09-08 16:55:00+03	2017-09-08 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17954	PG0282	2017-08-22 16:55:00+03	2017-08-22 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17955	PG0282	2017-07-21 16:55:00+03	2017-07-21 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-21 17:02:00+03	2017-07-21 18:57:00+03
17956	PG0282	2017-09-06 16:55:00+03	2017-09-06 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17957	PG0282	2017-07-19 16:55:00+03	2017-07-19 18:50:00+03	PKV	SVO	Arrived	CN1	2017-07-19 16:59:00+03	2017-07-19 18:53:00+03
17958	PG0282	2017-08-21 16:55:00+03	2017-08-21 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17959	PG0282	2017-08-23 16:55:00+03	2017-08-23 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17960	PG0282	2017-08-16 16:55:00+03	2017-08-16 18:50:00+03	PKV	SVO	Delayed	CN1	\N	\N
17961	PG0282	2017-09-02 16:55:00+03	2017-09-02 18:50:00+03	PKV	SVO	Scheduled	CN1	\N	\N
17962	PG0580	2017-08-13 15:05:00+03	2017-08-13 16:55:00+03	PKV	KZN	Arrived	CR2	2017-08-13 15:11:00+03	2017-08-13 17:02:00+03
17963	PG0580	2017-07-30 15:05:00+03	2017-07-30 16:55:00+03	PKV	KZN	Arrived	CR2	2017-07-30 15:08:00+03	2017-07-30 16:59:00+03
17964	PG0580	2017-07-23 15:05:00+03	2017-07-23 16:55:00+03	PKV	KZN	Arrived	CR2	2017-07-23 15:10:00+03	2017-07-23 17:00:00+03
17965	PG0580	2017-08-20 15:05:00+03	2017-08-20 16:55:00+03	PKV	KZN	Scheduled	CR2	\N	\N
17966	PG0580	2017-09-10 15:05:00+03	2017-09-10 16:55:00+03	PKV	KZN	Cancelled	CR2	\N	\N
17967	PG0580	2017-07-16 15:05:00+03	2017-07-16 16:55:00+03	PKV	KZN	Arrived	CR2	2017-07-16 15:05:00+03	2017-07-16 16:56:00+03
17968	PG0580	2017-09-03 15:05:00+03	2017-09-03 16:55:00+03	PKV	KZN	Scheduled	CR2	\N	\N
17969	PG0580	2017-08-06 15:05:00+03	2017-08-06 16:55:00+03	PKV	KZN	Arrived	CR2	2017-08-06 15:10:00+03	2017-08-06 16:58:00+03
17970	PG0580	2017-08-27 15:05:00+03	2017-08-27 16:55:00+03	PKV	KZN	Scheduled	CR2	\N	\N
17971	PG0169	2017-08-10 09:55:00+03	2017-08-10 18:45:00+03	UUS	DME	Arrived	319	2017-08-10 09:57:00+03	2017-08-10 18:52:00+03
17972	PG0169	2017-08-08 09:55:00+03	2017-08-08 18:45:00+03	UUS	DME	Arrived	319	2017-08-08 09:57:00+03	2017-08-08 18:51:00+03
17973	PG0169	2017-07-28 09:55:00+03	2017-07-28 18:45:00+03	UUS	DME	Arrived	319	2017-07-28 09:58:00+03	2017-07-28 18:50:00+03
17974	PG0169	2017-08-15 09:55:00+03	2017-08-15 18:45:00+03	UUS	DME	Departed	319	2017-08-15 10:00:00+03	\N
17975	PG0169	2017-07-18 09:55:00+03	2017-07-18 18:45:00+03	UUS	DME	Arrived	319	2017-07-18 09:58:00+03	2017-07-18 18:46:00+03
17976	PG0169	2017-08-05 09:55:00+03	2017-08-05 18:45:00+03	UUS	DME	Arrived	319	2017-08-05 09:58:00+03	2017-08-05 18:51:00+03
17977	PG0169	2017-07-23 09:55:00+03	2017-07-23 18:45:00+03	UUS	DME	Arrived	319	2017-07-23 09:57:00+03	2017-07-23 18:49:00+03
17978	PG0169	2017-08-06 09:55:00+03	2017-08-06 18:45:00+03	UUS	DME	Arrived	319	2017-08-06 09:59:00+03	2017-08-06 18:46:00+03
17979	PG0169	2017-09-04 09:55:00+03	2017-09-04 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17980	PG0169	2017-07-16 09:55:00+03	2017-07-16 18:45:00+03	UUS	DME	Arrived	319	2017-07-16 09:57:00+03	2017-07-16 18:52:00+03
17981	PG0169	2017-08-14 09:55:00+03	2017-08-14 18:45:00+03	UUS	DME	Arrived	319	2017-08-14 10:00:00+03	2017-08-14 18:55:00+03
17982	PG0169	2017-07-31 09:55:00+03	2017-07-31 18:45:00+03	UUS	DME	Arrived	319	2017-07-31 10:01:00+03	2017-07-31 18:53:00+03
17983	PG0169	2017-07-26 09:55:00+03	2017-07-26 18:45:00+03	UUS	DME	Arrived	319	2017-07-26 09:59:00+03	2017-07-26 18:52:00+03
17984	PG0169	2017-08-13 09:55:00+03	2017-08-13 18:45:00+03	UUS	DME	Arrived	319	2017-08-13 09:56:00+03	2017-08-13 18:44:00+03
17985	PG0169	2017-09-02 09:55:00+03	2017-09-02 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17986	PG0169	2017-09-09 09:55:00+03	2017-09-09 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17987	PG0169	2017-08-30 09:55:00+03	2017-08-30 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17988	PG0169	2017-09-14 09:55:00+03	2017-09-14 18:45:00+03	UUS	DME	Cancelled	319	\N	\N
17989	PG0169	2017-09-08 09:55:00+03	2017-09-08 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17990	PG0169	2017-07-20 09:55:00+03	2017-07-20 18:45:00+03	UUS	DME	Arrived	319	2017-07-20 09:57:00+03	2017-07-20 18:47:00+03
17991	PG0169	2017-07-30 09:55:00+03	2017-07-30 18:45:00+03	UUS	DME	Arrived	319	2017-07-30 10:02:00+03	2017-07-30 18:58:00+03
17992	PG0169	2017-09-05 09:55:00+03	2017-09-05 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17993	PG0169	2017-08-31 09:55:00+03	2017-08-31 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17994	PG0169	2017-08-01 09:55:00+03	2017-08-01 18:45:00+03	UUS	DME	Arrived	319	2017-08-01 09:57:00+03	2017-08-01 18:37:00+03
17995	PG0169	2017-07-19 09:55:00+03	2017-07-19 18:45:00+03	UUS	DME	Arrived	319	2017-07-19 09:57:00+03	2017-07-19 18:50:00+03
17996	PG0169	2017-08-12 09:55:00+03	2017-08-12 18:45:00+03	UUS	DME	Arrived	319	2017-08-12 09:57:00+03	2017-08-12 18:50:00+03
17997	PG0169	2017-07-22 09:55:00+03	2017-07-22 18:45:00+03	UUS	DME	Arrived	319	2017-07-22 09:55:00+03	2017-07-22 18:49:00+03
17998	PG0169	2017-08-28 09:55:00+03	2017-08-28 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
17999	PG0169	2017-08-27 09:55:00+03	2017-08-27 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18000	PG0169	2017-07-21 09:55:00+03	2017-07-21 18:45:00+03	UUS	DME	Arrived	319	2017-07-21 10:00:00+03	2017-07-21 18:45:00+03
18001	PG0169	2017-08-25 09:55:00+03	2017-08-25 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18002	PG0169	2017-08-24 09:55:00+03	2017-08-24 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18003	PG0169	2017-09-10 09:55:00+03	2017-09-10 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18004	PG0169	2017-08-26 09:55:00+03	2017-08-26 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18005	PG0169	2017-07-24 09:55:00+03	2017-07-24 18:45:00+03	UUS	DME	Arrived	319	2017-07-24 09:58:00+03	2017-07-24 18:55:00+03
18006	PG0169	2017-09-06 09:55:00+03	2017-09-06 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18007	PG0169	2017-07-27 09:55:00+03	2017-07-27 18:45:00+03	UUS	DME	Arrived	319	2017-07-27 09:56:00+03	2017-07-27 18:46:00+03
18008	PG0169	2017-08-29 09:55:00+03	2017-08-29 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18009	PG0169	2017-08-16 09:55:00+03	2017-08-16 18:45:00+03	UUS	DME	On Time	319	\N	\N
18010	PG0169	2017-08-04 09:55:00+03	2017-08-04 18:45:00+03	UUS	DME	Arrived	319	2017-08-04 09:58:00+03	2017-08-04 18:51:00+03
18011	PG0169	2017-08-07 09:55:00+03	2017-08-07 18:45:00+03	UUS	DME	Arrived	319	2017-08-07 10:00:00+03	2017-08-07 18:53:00+03
18012	PG0169	2017-08-21 09:55:00+03	2017-08-21 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18013	PG0169	2017-08-09 09:55:00+03	2017-08-09 18:45:00+03	UUS	DME	Arrived	319	2017-08-09 09:58:00+03	2017-08-09 18:48:00+03
18014	PG0169	2017-07-29 09:55:00+03	2017-07-29 18:45:00+03	UUS	DME	Arrived	319	2017-07-29 09:59:00+03	2017-07-29 18:48:00+03
18015	PG0169	2017-09-07 09:55:00+03	2017-09-07 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18016	PG0169	2017-08-22 09:55:00+03	2017-08-22 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18017	PG0169	2017-08-19 09:55:00+03	2017-08-19 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18018	PG0169	2017-09-03 09:55:00+03	2017-09-03 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18019	PG0169	2017-09-12 09:55:00+03	2017-09-12 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18020	PG0169	2017-07-25 09:55:00+03	2017-07-25 18:45:00+03	UUS	DME	Arrived	319	2017-07-25 09:55:00+03	2017-07-25 18:47:00+03
18021	PG0169	2017-08-18 09:55:00+03	2017-08-18 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18022	PG0169	2017-08-20 09:55:00+03	2017-08-20 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18023	PG0169	2017-08-17 09:55:00+03	2017-08-17 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18024	PG0169	2017-08-03 09:55:00+03	2017-08-03 18:45:00+03	UUS	DME	Arrived	319	2017-08-03 10:01:00+03	2017-08-03 18:54:00+03
18025	PG0169	2017-09-01 09:55:00+03	2017-09-01 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18026	PG0169	2017-08-02 09:55:00+03	2017-08-02 18:45:00+03	UUS	DME	Arrived	319	2017-08-02 10:00:00+03	2017-08-02 18:50:00+03
18027	PG0169	2017-08-11 09:55:00+03	2017-08-11 18:45:00+03	UUS	DME	Arrived	319	2017-08-11 09:58:00+03	2017-08-11 18:53:00+03
18028	PG0169	2017-08-23 09:55:00+03	2017-08-23 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18029	PG0169	2017-07-17 09:55:00+03	2017-07-17 18:45:00+03	UUS	DME	Arrived	319	2017-07-17 09:56:00+03	2017-07-17 18:49:00+03
18030	PG0169	2017-09-13 09:55:00+03	2017-09-13 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18031	PG0169	2017-09-11 09:55:00+03	2017-09-11 18:45:00+03	UUS	DME	Scheduled	319	\N	\N
18032	PG0704	2017-09-14 10:45:00+03	2017-09-14 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18033	PG0704	2017-09-05 10:45:00+03	2017-09-05 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18034	PG0704	2017-07-29 10:45:00+03	2017-07-29 19:30:00+03	UUS	SVO	Arrived	319	2017-07-29 10:51:00+03	2017-07-29 19:35:00+03
18035	PG0704	2017-08-02 10:45:00+03	2017-08-02 19:30:00+03	UUS	SVO	Arrived	319	2017-08-02 10:49:00+03	2017-08-02 19:34:00+03
18036	PG0704	2017-08-27 10:45:00+03	2017-08-27 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18037	PG0704	2017-09-03 10:45:00+03	2017-09-03 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18038	PG0704	2017-07-31 10:45:00+03	2017-07-31 19:30:00+03	UUS	SVO	Arrived	319	2017-07-31 10:47:00+03	2017-07-31 19:31:00+03
18039	PG0704	2017-08-09 10:45:00+03	2017-08-09 19:30:00+03	UUS	SVO	Arrived	319	2017-08-09 10:46:00+03	2017-08-09 19:31:00+03
18040	PG0704	2017-08-16 10:45:00+03	2017-08-16 19:30:00+03	UUS	SVO	On Time	319	\N	\N
18041	PG0704	2017-08-30 10:45:00+03	2017-08-30 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18042	PG0704	2017-08-17 10:45:00+03	2017-08-17 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18043	PG0704	2017-08-12 10:45:00+03	2017-08-12 19:30:00+03	UUS	SVO	Arrived	319	2017-08-12 10:49:00+03	2017-08-12 19:43:00+03
18044	PG0704	2017-07-18 10:45:00+03	2017-07-18 19:30:00+03	UUS	SVO	Arrived	319	2017-07-18 10:48:00+03	2017-07-18 19:40:00+03
18045	PG0704	2017-08-29 10:45:00+03	2017-08-29 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18046	PG0704	2017-09-08 10:45:00+03	2017-09-08 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18047	PG0704	2017-08-31 10:45:00+03	2017-08-31 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18048	PG0704	2017-07-19 10:45:00+03	2017-07-19 19:30:00+03	UUS	SVO	Arrived	319	2017-07-19 10:49:00+03	2017-07-19 19:27:00+03
18049	PG0704	2017-08-24 10:45:00+03	2017-08-24 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18050	PG0704	2017-08-03 10:45:00+03	2017-08-03 19:30:00+03	UUS	SVO	Arrived	319	2017-08-03 10:47:00+03	2017-08-03 19:29:00+03
18051	PG0704	2017-09-02 10:45:00+03	2017-09-02 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18052	PG0704	2017-08-13 10:45:00+03	2017-08-13 19:30:00+03	UUS	SVO	Arrived	319	2017-08-13 10:47:00+03	2017-08-13 19:29:00+03
18053	PG0704	2017-07-22 10:45:00+03	2017-07-22 19:30:00+03	UUS	SVO	Arrived	319	2017-07-22 10:49:00+03	2017-07-22 19:35:00+03
18054	PG0704	2017-08-04 10:45:00+03	2017-08-04 19:30:00+03	UUS	SVO	Arrived	319	2017-08-04 10:46:00+03	2017-08-04 19:40:00+03
18055	PG0704	2017-09-01 10:45:00+03	2017-09-01 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18056	PG0704	2017-08-14 10:45:00+03	2017-08-14 19:30:00+03	UUS	SVO	Arrived	319	2017-08-14 10:47:00+03	2017-08-14 19:32:00+03
18057	PG0704	2017-08-23 10:45:00+03	2017-08-23 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18058	PG0704	2017-07-24 10:45:00+03	2017-07-24 19:30:00+03	UUS	SVO	Arrived	319	2017-07-24 10:47:00+03	2017-07-24 19:26:00+03
18059	PG0704	2017-08-10 10:45:00+03	2017-08-10 19:30:00+03	UUS	SVO	Arrived	319	2017-08-10 10:45:00+03	2017-08-10 19:26:00+03
18060	PG0704	2017-08-26 10:45:00+03	2017-08-26 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18061	PG0704	2017-08-19 10:45:00+03	2017-08-19 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18062	PG0704	2017-09-13 10:45:00+03	2017-09-13 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18063	PG0704	2017-09-06 10:45:00+03	2017-09-06 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18064	PG0704	2017-08-08 10:45:00+03	2017-08-08 19:30:00+03	UUS	SVO	Arrived	319	2017-08-08 10:48:00+03	2017-08-08 19:28:00+03
18065	PG0704	2017-08-22 10:45:00+03	2017-08-22 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18066	PG0704	2017-07-30 10:45:00+03	2017-07-30 19:30:00+03	UUS	SVO	Arrived	319	2017-07-30 10:49:00+03	2017-07-30 19:28:00+03
18067	PG0704	2017-09-10 10:45:00+03	2017-09-10 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18068	PG0704	2017-07-28 10:45:00+03	2017-07-28 19:30:00+03	UUS	SVO	Arrived	319	2017-07-28 10:48:00+03	2017-07-28 19:29:00+03
18069	PG0704	2017-07-16 10:45:00+03	2017-07-16 19:30:00+03	UUS	SVO	Arrived	319	2017-07-16 10:49:00+03	2017-07-16 19:35:00+03
18070	PG0704	2017-08-28 10:45:00+03	2017-08-28 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18071	PG0704	2017-08-01 10:45:00+03	2017-08-01 19:30:00+03	UUS	SVO	Arrived	319	2017-08-01 10:46:00+03	2017-08-01 19:33:00+03
18072	PG0704	2017-09-12 10:45:00+03	2017-09-12 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18073	PG0704	2017-07-27 10:45:00+03	2017-07-27 19:30:00+03	UUS	SVO	Arrived	319	2017-07-27 10:48:00+03	2017-07-27 19:36:00+03
18074	PG0704	2017-08-25 10:45:00+03	2017-08-25 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18075	PG0704	2017-09-04 10:45:00+03	2017-09-04 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18076	PG0704	2017-09-07 10:45:00+03	2017-09-07 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18077	PG0704	2017-09-09 10:45:00+03	2017-09-09 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18078	PG0704	2017-07-25 10:45:00+03	2017-07-25 19:30:00+03	UUS	SVO	Arrived	319	2017-07-25 10:48:00+03	2017-07-25 19:36:00+03
18079	PG0704	2017-07-23 10:45:00+03	2017-07-23 19:30:00+03	UUS	SVO	Arrived	319	2017-07-23 10:49:00+03	2017-07-23 19:30:00+03
18080	PG0704	2017-07-20 10:45:00+03	2017-07-20 19:30:00+03	UUS	SVO	Arrived	319	2017-07-20 10:46:00+03	2017-07-20 19:43:00+03
18081	PG0704	2017-08-18 10:45:00+03	2017-08-18 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18082	PG0704	2017-08-07 10:45:00+03	2017-08-07 19:30:00+03	UUS	SVO	Arrived	319	2017-08-07 13:57:00+03	2017-08-07 22:44:00+03
18083	PG0704	2017-08-15 10:45:00+03	2017-08-15 19:30:00+03	UUS	SVO	Departed	319	2017-08-15 10:48:00+03	\N
18084	PG0704	2017-08-11 10:45:00+03	2017-08-11 19:30:00+03	UUS	SVO	Arrived	319	2017-08-11 10:51:00+03	2017-08-11 19:31:00+03
18085	PG0704	2017-08-21 10:45:00+03	2017-08-21 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18086	PG0704	2017-07-17 10:45:00+03	2017-07-17 19:30:00+03	UUS	SVO	Arrived	319	2017-07-17 10:48:00+03	2017-07-17 19:35:00+03
18087	PG0704	2017-09-11 10:45:00+03	2017-09-11 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18088	PG0704	2017-07-21 10:45:00+03	2017-07-21 19:30:00+03	UUS	SVO	Arrived	319	2017-07-21 14:23:00+03	2017-07-21 23:16:00+03
18089	PG0704	2017-08-06 10:45:00+03	2017-08-06 19:30:00+03	UUS	SVO	Arrived	319	2017-08-06 10:48:00+03	2017-08-06 19:28:00+03
18090	PG0704	2017-07-26 10:45:00+03	2017-07-26 19:30:00+03	UUS	SVO	Arrived	319	2017-07-26 10:50:00+03	2017-07-26 19:32:00+03
18091	PG0704	2017-08-20 10:45:00+03	2017-08-20 19:30:00+03	UUS	SVO	Scheduled	319	\N	\N
18092	PG0704	2017-08-05 10:45:00+03	2017-08-05 19:30:00+03	UUS	SVO	Arrived	319	2017-08-05 10:48:00+03	2017-08-05 19:31:00+03
18093	PG0582	2017-09-07 04:10:00+03	2017-09-07 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18094	PG0582	2017-07-30 04:10:00+03	2017-07-30 06:50:00+03	UUS	YKS	Arrived	CR2	2017-07-30 04:10:00+03	2017-07-30 06:51:00+03
18095	PG0582	2017-07-27 04:10:00+03	2017-07-27 06:50:00+03	UUS	YKS	Arrived	CR2	2017-07-27 04:13:00+03	2017-07-27 06:50:00+03
18096	PG0582	2017-09-10 04:10:00+03	2017-09-10 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18097	PG0582	2017-08-27 04:10:00+03	2017-08-27 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18098	PG0582	2017-07-23 04:10:00+03	2017-07-23 06:50:00+03	UUS	YKS	Arrived	CR2	2017-07-23 04:12:00+03	2017-07-23 06:52:00+03
18099	PG0582	2017-07-16 04:10:00+03	2017-07-16 06:50:00+03	UUS	YKS	Arrived	CR2	2017-07-16 06:48:00+03	2017-07-16 09:26:00+03
18100	PG0582	2017-08-06 04:10:00+03	2017-08-06 06:50:00+03	UUS	YKS	Arrived	CR2	2017-08-06 04:10:00+03	2017-08-06 06:51:00+03
18101	PG0582	2017-09-03 04:10:00+03	2017-09-03 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18102	PG0582	2017-08-20 04:10:00+03	2017-08-20 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18103	PG0582	2017-08-17 04:10:00+03	2017-08-17 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18104	PG0582	2017-09-14 04:10:00+03	2017-09-14 06:50:00+03	UUS	YKS	Cancelled	CR2	\N	\N
18105	PG0582	2017-08-13 04:10:00+03	2017-08-13 06:50:00+03	UUS	YKS	Arrived	CR2	2017-08-13 04:12:00+03	2017-08-13 06:54:00+03
18106	PG0582	2017-08-03 04:10:00+03	2017-08-03 06:50:00+03	UUS	YKS	Arrived	CR2	2017-08-03 04:18:00+03	2017-08-03 06:56:00+03
18107	PG0582	2017-08-24 04:10:00+03	2017-08-24 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18108	PG0582	2017-08-31 04:10:00+03	2017-08-31 06:50:00+03	UUS	YKS	Scheduled	CR2	\N	\N
18109	PG0582	2017-08-10 04:10:00+03	2017-08-10 06:50:00+03	UUS	YKS	Arrived	CR2	2017-08-10 04:11:00+03	2017-08-10 06:55:00+03
18110	PG0582	2017-07-20 04:10:00+03	2017-07-20 06:50:00+03	UUS	YKS	Arrived	CR2	2017-07-20 04:11:00+03	2017-07-20 06:51:00+03
18111	PG0399	2017-08-03 08:40:00+03	2017-08-03 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-03 08:40:00+03	2017-08-03 10:33:00+03
18112	PG0399	2017-07-25 08:40:00+03	2017-07-25 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-25 08:43:00+03	2017-07-25 10:38:00+03
18113	PG0398	2017-08-10 03:50:00+03	2017-08-10 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-10 03:51:00+03	2017-08-10 05:45:00+03
18114	PG0398	2017-08-06 03:50:00+03	2017-08-06 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-06 03:53:00+03	2017-08-06 05:48:00+03
18115	PG0399	2017-08-06 08:40:00+03	2017-08-06 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-06 08:43:00+03	2017-08-06 10:37:00+03
18116	PG0399	2017-07-26 08:40:00+03	2017-07-26 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-26 08:41:00+03	2017-07-26 10:35:00+03
18117	PG0399	2017-08-07 08:40:00+03	2017-08-07 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-07 08:46:00+03	2017-08-07 10:38:00+03
18118	PG0398	2017-07-26 03:50:00+03	2017-07-26 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-26 03:51:00+03	2017-07-26 05:46:00+03
18119	PG0398	2017-08-07 03:50:00+03	2017-08-07 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-07 03:56:00+03	2017-08-07 05:51:00+03
18120	PG0399	2017-08-25 08:40:00+03	2017-08-25 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18121	PG0398	2017-09-07 03:50:00+03	2017-09-07 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18122	PG0399	2017-09-12 08:40:00+03	2017-09-12 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18123	PG0399	2017-08-19 08:40:00+03	2017-08-19 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18124	PG0398	2017-08-19 03:50:00+03	2017-08-19 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18125	PG0398	2017-09-12 03:50:00+03	2017-09-12 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18126	PG0398	2017-09-03 03:50:00+03	2017-09-03 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18127	PG0399	2017-08-13 08:40:00+03	2017-08-13 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-13 08:41:00+03	2017-08-13 10:36:00+03
18128	PG0399	2017-08-10 08:40:00+03	2017-08-10 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-10 08:40:00+03	2017-08-10 10:33:00+03
18129	PG0399	2017-08-12 08:40:00+03	2017-08-12 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-12 08:44:00+03	2017-08-12 10:37:00+03
18130	PG0399	2017-09-03 08:40:00+03	2017-09-03 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18131	PG0398	2017-08-12 03:50:00+03	2017-08-12 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-12 03:54:00+03	2017-08-12 05:50:00+03
18132	PG0399	2017-07-31 08:40:00+03	2017-07-31 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-31 08:42:00+03	2017-07-31 10:35:00+03
18133	PG0398	2017-07-31 03:50:00+03	2017-07-31 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-31 03:58:00+03	2017-07-31 05:51:00+03
18134	PG0399	2017-09-10 08:40:00+03	2017-09-10 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18135	PG0399	2017-08-31 08:40:00+03	2017-08-31 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18136	PG0398	2017-08-31 03:50:00+03	2017-08-31 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18137	PG0399	2017-08-23 08:40:00+03	2017-08-23 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18138	PG0398	2017-08-23 03:50:00+03	2017-08-23 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18139	PG0398	2017-07-30 03:50:00+03	2017-07-30 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-30 03:52:00+03	2017-07-30 05:47:00+03
18140	PG0399	2017-08-08 08:40:00+03	2017-08-08 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-08 08:43:00+03	2017-08-08 10:39:00+03
18141	PG0398	2017-08-08 03:50:00+03	2017-08-08 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-08 03:56:00+03	2017-08-08 05:48:00+03
18142	PG0399	2017-07-30 08:40:00+03	2017-07-30 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-30 08:43:00+03	2017-07-30 10:38:00+03
18143	PG0399	2017-09-08 08:40:00+03	2017-09-08 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18144	PG0399	2017-07-24 08:40:00+03	2017-07-24 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-24 11:57:00+03	2017-07-24 13:51:00+03
18145	PG0399	2017-07-21 08:40:00+03	2017-07-21 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-21 08:47:00+03	2017-07-21 10:43:00+03
18146	PG0398	2017-07-21 03:50:00+03	2017-07-21 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-21 03:56:00+03	2017-07-21 05:50:00+03
18147	PG0398	2017-07-24 03:50:00+03	2017-07-24 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-24 03:53:00+03	2017-07-24 05:49:00+03
18148	PG0398	2017-07-23 03:50:00+03	2017-07-23 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-23 03:54:00+03	2017-07-23 05:51:00+03
18149	PG0399	2017-07-23 08:40:00+03	2017-07-23 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-23 08:41:00+03	2017-07-23 10:37:00+03
18150	PG0398	2017-08-30 03:50:00+03	2017-08-30 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18151	PG0399	2017-08-30 08:40:00+03	2017-08-30 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18152	PG0398	2017-08-11 03:50:00+03	2017-08-11 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-11 03:54:00+03	2017-08-11 05:50:00+03
18153	PG0399	2017-09-02 08:40:00+03	2017-09-02 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18154	PG0399	2017-08-11 08:40:00+03	2017-08-11 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-11 08:40:00+03	2017-08-11 10:36:00+03
18155	PG0398	2017-08-15 03:50:00+03	2017-08-15 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-15 03:52:00+03	2017-08-15 05:48:00+03
18156	PG0398	2017-09-08 03:50:00+03	2017-09-08 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18157	PG0399	2017-08-15 08:40:00+03	2017-08-15 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-15 08:43:00+03	2017-08-15 10:40:00+03
18158	PG0398	2017-08-04 03:50:00+03	2017-08-04 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-04 03:53:00+03	2017-08-04 05:49:00+03
18159	PG0399	2017-08-04 08:40:00+03	2017-08-04 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-04 11:57:00+03	2017-08-04 13:52:00+03
18160	PG0398	2017-09-02 03:50:00+03	2017-09-02 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18161	PG0398	2017-09-01 03:50:00+03	2017-09-01 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18162	PG0399	2017-07-27 08:40:00+03	2017-07-27 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-27 08:42:00+03	2017-07-27 10:37:00+03
18163	PG0398	2017-07-27 03:50:00+03	2017-07-27 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-27 03:52:00+03	2017-07-27 05:46:00+03
18164	PG0398	2017-08-29 03:50:00+03	2017-08-29 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18165	PG0398	2017-09-11 03:50:00+03	2017-09-11 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18166	PG0399	2017-08-29 08:40:00+03	2017-08-29 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18167	PG0399	2017-07-18 08:40:00+03	2017-07-18 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-18 08:42:00+03	2017-07-18 10:38:00+03
18168	PG0398	2017-08-09 03:50:00+03	2017-08-09 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-09 03:52:00+03	2017-08-09 05:50:00+03
18169	PG0398	2017-07-18 03:50:00+03	2017-07-18 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-18 03:52:00+03	2017-07-18 05:49:00+03
18170	PG0399	2017-09-11 08:40:00+03	2017-09-11 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18171	PG0398	2017-08-28 03:50:00+03	2017-08-28 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18172	PG0399	2017-08-28 08:40:00+03	2017-08-28 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18173	PG0399	2017-07-22 08:40:00+03	2017-07-22 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-22 08:41:00+03	2017-07-22 10:37:00+03
18174	PG0399	2017-09-07 08:40:00+03	2017-09-07 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18175	PG0398	2017-07-22 03:50:00+03	2017-07-22 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-22 03:54:00+03	2017-07-22 05:50:00+03
18176	PG0398	2017-08-21 03:50:00+03	2017-08-21 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18177	PG0398	2017-08-20 03:50:00+03	2017-08-20 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18178	PG0399	2017-08-20 08:40:00+03	2017-08-20 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18179	PG0399	2017-08-14 08:40:00+03	2017-08-14 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-14 08:43:00+03	2017-08-14 10:37:00+03
18180	PG0399	2017-08-01 08:40:00+03	2017-08-01 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-01 08:41:00+03	2017-08-01 10:35:00+03
18181	PG0398	2017-08-01 03:50:00+03	2017-08-01 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-01 03:56:00+03	2017-08-01 05:51:00+03
18182	PG0399	2017-09-14 08:40:00+03	2017-09-14 10:35:00+03	UUS	KHV	Cancelled	CN1	\N	\N
18183	PG0398	2017-09-06 03:50:00+03	2017-09-06 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18184	PG0399	2017-09-06 08:40:00+03	2017-09-06 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18185	PG0398	2017-07-16 03:50:00+03	2017-07-16 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-16 03:53:00+03	2017-07-16 05:48:00+03
18186	PG0398	2017-08-14 03:50:00+03	2017-08-14 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-14 03:53:00+03	2017-08-14 05:49:00+03
18187	PG0399	2017-07-16 08:40:00+03	2017-07-16 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-16 08:43:00+03	2017-07-16 10:38:00+03
18188	PG0398	2017-08-22 03:50:00+03	2017-08-22 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18189	PG0399	2017-08-22 08:40:00+03	2017-08-22 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18190	PG0399	2017-09-04 08:40:00+03	2017-09-04 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18191	PG0399	2017-08-02 08:40:00+03	2017-08-02 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-02 08:42:00+03	2017-08-02 10:36:00+03
18192	PG0398	2017-08-02 03:50:00+03	2017-08-02 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-02 03:55:00+03	2017-08-02 05:50:00+03
18193	PG0398	2017-09-04 03:50:00+03	2017-09-04 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18194	PG0399	2017-08-26 08:40:00+03	2017-08-26 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18195	PG0398	2017-08-26 03:50:00+03	2017-08-26 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18196	PG0398	2017-08-05 03:50:00+03	2017-08-05 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-05 03:52:00+03	2017-08-05 05:46:00+03
18197	PG0399	2017-08-05 08:40:00+03	2017-08-05 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-05 11:13:00+03	2017-08-05 13:08:00+03
18198	PG0399	2017-09-01 08:40:00+03	2017-09-01 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18199	PG0398	2017-07-20 03:50:00+03	2017-07-20 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-20 03:52:00+03	2017-07-20 05:47:00+03
18200	PG0399	2017-07-20 08:40:00+03	2017-07-20 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-20 08:43:00+03	2017-07-20 10:39:00+03
18201	PG0399	2017-08-21 08:40:00+03	2017-08-21 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18202	PG0398	2017-08-18 03:50:00+03	2017-08-18 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18203	PG0399	2017-08-18 08:40:00+03	2017-08-18 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18204	PG0398	2017-09-14 03:50:00+03	2017-09-14 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18205	PG0399	2017-09-05 08:40:00+03	2017-09-05 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18206	PG0398	2017-07-19 03:50:00+03	2017-07-19 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-19 03:53:00+03	2017-07-19 05:48:00+03
18207	PG0399	2017-07-19 08:40:00+03	2017-07-19 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-19 08:45:00+03	2017-07-19 10:39:00+03
18208	PG0398	2017-09-05 03:50:00+03	2017-09-05 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18209	PG0398	2017-07-28 03:50:00+03	2017-07-28 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-28 03:52:00+03	2017-07-28 05:46:00+03
18210	PG0399	2017-08-17 08:40:00+03	2017-08-17 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18211	PG0398	2017-08-17 03:50:00+03	2017-08-17 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18212	PG0398	2017-07-29 03:50:00+03	2017-07-29 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-29 03:52:00+03	2017-07-29 05:46:00+03
18213	PG0399	2017-07-29 08:40:00+03	2017-07-29 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-29 08:43:00+03	2017-07-29 10:40:00+03
18214	PG0398	2017-08-13 03:50:00+03	2017-08-13 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-13 03:51:00+03	2017-08-13 05:46:00+03
18215	PG0399	2017-08-16 08:40:00+03	2017-08-16 10:35:00+03	UUS	KHV	On Time	CN1	\N	\N
18216	PG0398	2017-08-16 03:50:00+03	2017-08-16 05:45:00+03	UUS	KHV	On Time	CN1	\N	\N
18217	PG0399	2017-08-09 08:40:00+03	2017-08-09 10:35:00+03	UUS	KHV	Arrived	CN1	2017-08-09 08:42:00+03	2017-08-09 10:35:00+03
18218	PG0398	2017-08-25 03:50:00+03	2017-08-25 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18219	PG0399	2017-07-28 08:40:00+03	2017-07-28 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-28 08:41:00+03	2017-07-28 10:37:00+03
18220	PG0398	2017-09-13 03:50:00+03	2017-09-13 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18221	PG0399	2017-07-17 08:40:00+03	2017-07-17 10:35:00+03	UUS	KHV	Arrived	CN1	2017-07-17 08:42:00+03	2017-07-17 10:38:00+03
18222	PG0399	2017-09-13 08:40:00+03	2017-09-13 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18223	PG0398	2017-07-17 03:50:00+03	2017-07-17 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-17 03:52:00+03	2017-07-17 05:49:00+03
18224	PG0398	2017-09-09 03:50:00+03	2017-09-09 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18225	PG0399	2017-09-09 08:40:00+03	2017-09-09 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18226	PG0398	2017-08-03 03:50:00+03	2017-08-03 05:45:00+03	UUS	KHV	Arrived	CN1	2017-08-03 03:53:00+03	2017-08-03 05:46:00+03
18227	PG0398	2017-08-27 03:50:00+03	2017-08-27 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18228	PG0398	2017-08-24 03:50:00+03	2017-08-24 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18229	PG0398	2017-07-25 03:50:00+03	2017-07-25 05:45:00+03	UUS	KHV	Arrived	CN1	2017-07-25 03:53:00+03	2017-07-25 05:49:00+03
18230	PG0399	2017-08-24 08:40:00+03	2017-08-24 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18231	PG0399	2017-08-27 08:40:00+03	2017-08-27 10:35:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18232	PG0398	2017-09-10 03:50:00+03	2017-09-10 05:45:00+03	UUS	KHV	Scheduled	CN1	\N	\N
18233	PG0145	2017-08-23 09:15:00+03	2017-08-23 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18234	PG0145	2017-08-05 09:15:00+03	2017-08-05 18:05:00+03	PKC	DME	Arrived	763	2017-08-05 09:21:00+03	2017-08-05 18:14:00+03
18235	PG0145	2017-07-24 09:15:00+03	2017-07-24 18:05:00+03	PKC	DME	Arrived	763	2017-07-24 09:18:00+03	2017-07-24 18:01:00+03
18236	PG0145	2017-07-29 09:15:00+03	2017-07-29 18:05:00+03	PKC	DME	Arrived	763	2017-07-29 09:17:00+03	2017-07-29 18:05:00+03
18237	PG0145	2017-08-21 09:15:00+03	2017-08-21 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18238	PG0145	2017-08-28 09:15:00+03	2017-08-28 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18239	PG0145	2017-09-09 09:15:00+03	2017-09-09 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18240	PG0145	2017-08-26 09:15:00+03	2017-08-26 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18241	PG0145	2017-09-11 09:15:00+03	2017-09-11 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18242	PG0145	2017-07-19 09:15:00+03	2017-07-19 18:05:00+03	PKC	DME	Arrived	763	2017-07-19 09:17:00+03	2017-07-19 18:03:00+03
18243	PG0145	2017-08-02 09:15:00+03	2017-08-02 18:05:00+03	PKC	DME	Arrived	763	2017-08-02 09:17:00+03	2017-08-02 18:13:00+03
18244	PG0145	2017-08-19 09:15:00+03	2017-08-19 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18245	PG0145	2017-07-26 09:15:00+03	2017-07-26 18:05:00+03	PKC	DME	Arrived	763	2017-07-26 09:17:00+03	2017-07-26 18:13:00+03
18246	PG0145	2017-08-07 09:15:00+03	2017-08-07 18:05:00+03	PKC	DME	Arrived	763	2017-08-07 09:16:00+03	2017-08-07 17:58:00+03
18247	PG0145	2017-07-31 09:15:00+03	2017-07-31 18:05:00+03	PKC	DME	Arrived	763	2017-07-31 09:21:00+03	2017-07-31 18:07:00+03
18248	PG0145	2017-09-02 09:15:00+03	2017-09-02 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18249	PG0145	2017-07-22 09:15:00+03	2017-07-22 18:05:00+03	PKC	DME	Arrived	763	2017-07-22 09:17:00+03	2017-07-22 17:54:00+03
18250	PG0145	2017-09-06 09:15:00+03	2017-09-06 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18251	PG0145	2017-09-04 09:15:00+03	2017-09-04 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18252	PG0145	2017-08-14 09:15:00+03	2017-08-14 18:05:00+03	PKC	DME	Arrived	763	2017-08-14 09:17:00+03	2017-08-14 17:57:00+03
18253	PG0145	2017-08-30 09:15:00+03	2017-08-30 18:05:00+03	PKC	DME	Scheduled	763	\N	\N
18254	PG0145	2017-08-12 09:15:00+03	2017-08-12 18:05:00+03	PKC	DME	Arrived	763	2017-08-12 09:20:00+03	2017-08-12 18:02:00+03
18255	PG0145	2017-09-13 09:15:00+03	2017-09-13 18:05:00+03	PKC	DME	Cancelled	763	\N	\N
18256	PG0145	2017-08-16 09:15:00+03	2017-08-16 18:05:00+03	PKC	DME	On Time	763	\N	\N
18257	PG0145	2017-08-09 09:15:00+03	2017-08-09 18:05:00+03	PKC	DME	Arrived	763	2017-08-09 09:20:00+03	2017-08-09 18:12:00+03
18258	PG0145	2017-07-17 09:15:00+03	2017-07-17 18:05:00+03	PKC	DME	Arrived	763	2017-07-17 09:16:00+03	2017-07-17 17:58:00+03
18259	PG0520	2017-08-02 07:35:00+03	2017-08-02 12:00:00+03	ABA	DME	Arrived	319	2017-08-02 07:41:00+03	2017-08-02 12:10:00+03
18260	PG0520	2017-09-03 07:35:00+03	2017-09-03 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18261	PG0520	2017-08-23 07:35:00+03	2017-08-23 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18262	PG0520	2017-08-13 07:35:00+03	2017-08-13 12:00:00+03	ABA	DME	Arrived	319	2017-08-13 07:39:00+03	2017-08-13 12:01:00+03
18263	PG0520	2017-07-16 07:35:00+03	2017-07-16 12:00:00+03	ABA	DME	Arrived	319	2017-07-16 07:35:00+03	2017-07-16 11:59:00+03
18264	PG0520	2017-08-06 07:35:00+03	2017-08-06 12:00:00+03	ABA	DME	Arrived	319	2017-08-06 07:36:00+03	2017-08-06 11:57:00+03
18265	PG0520	2017-09-06 07:35:00+03	2017-09-06 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18266	PG0520	2017-07-26 07:35:00+03	2017-07-26 12:00:00+03	ABA	DME	Arrived	319	2017-07-26 07:39:00+03	2017-07-26 11:59:00+03
18267	PG0520	2017-08-16 07:35:00+03	2017-08-16 12:00:00+03	ABA	DME	On Time	319	\N	\N
18268	PG0520	2017-08-20 07:35:00+03	2017-08-20 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18269	PG0520	2017-08-30 07:35:00+03	2017-08-30 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18270	PG0520	2017-07-30 07:35:00+03	2017-07-30 12:00:00+03	ABA	DME	Arrived	319	2017-07-30 07:36:00+03	2017-07-30 12:03:00+03
18271	PG0520	2017-08-27 07:35:00+03	2017-08-27 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18272	PG0520	2017-07-23 07:35:00+03	2017-07-23 12:00:00+03	ABA	DME	Arrived	319	2017-07-23 07:39:00+03	2017-07-23 12:06:00+03
18273	PG0520	2017-09-10 07:35:00+03	2017-09-10 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18274	PG0520	2017-07-19 07:35:00+03	2017-07-19 12:00:00+03	ABA	DME	Arrived	319	2017-07-19 07:37:00+03	2017-07-19 11:58:00+03
18275	PG0520	2017-09-13 07:35:00+03	2017-09-13 12:00:00+03	ABA	DME	Scheduled	319	\N	\N
18276	PG0520	2017-08-09 07:35:00+03	2017-08-09 12:00:00+03	ABA	DME	Arrived	319	2017-08-09 07:39:00+03	2017-08-09 12:03:00+03
18277	PG0585	2017-08-02 09:35:00+03	2017-08-02 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-02 09:37:00+03	2017-08-02 11:31:00+03
18278	PG0586	2017-09-05 12:15:00+03	2017-09-05 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18279	PG0585	2017-09-05 09:35:00+03	2017-09-05 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18280	PG0586	2017-07-22 12:15:00+03	2017-07-22 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-22 12:19:00+03	2017-07-22 14:12:00+03
18281	PG0585	2017-08-30 09:35:00+03	2017-08-30 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18282	PG0585	2017-07-19 09:35:00+03	2017-07-19 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-19 09:38:00+03	2017-07-19 11:34:00+03
18283	PG0586	2017-07-19 12:15:00+03	2017-07-19 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-19 12:19:00+03	2017-07-19 14:15:00+03
18284	PG0585	2017-07-22 09:35:00+03	2017-07-22 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-22 09:36:00+03	2017-07-22 11:31:00+03
18285	PG0585	2017-08-23 09:35:00+03	2017-08-23 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18286	PG0585	2017-07-28 09:35:00+03	2017-07-28 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-28 09:37:00+03	2017-07-28 11:32:00+03
18287	PG0586	2017-08-23 12:15:00+03	2017-08-23 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18288	PG0586	2017-07-28 12:15:00+03	2017-07-28 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-28 12:16:00+03	2017-07-28 14:14:00+03
18289	PG0586	2017-08-30 12:15:00+03	2017-08-30 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18290	PG0586	2017-07-21 12:15:00+03	2017-07-21 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-21 12:17:00+03	2017-07-21 14:12:00+03
18291	PG0585	2017-09-08 09:35:00+03	2017-09-08 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18292	PG0585	2017-07-21 09:35:00+03	2017-07-21 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-21 09:37:00+03	2017-07-21 11:31:00+03
18293	PG0586	2017-09-08 12:15:00+03	2017-09-08 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18294	PG0585	2017-08-12 09:35:00+03	2017-08-12 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-12 09:37:00+03	2017-08-12 11:30:00+03
18295	PG0586	2017-08-12 12:15:00+03	2017-08-12 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-12 12:19:00+03	2017-08-12 14:15:00+03
18296	PG0585	2017-08-03 09:35:00+03	2017-08-03 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-03 09:36:00+03	2017-08-03 11:31:00+03
18297	PG0586	2017-08-03 12:15:00+03	2017-08-03 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-03 12:17:00+03	2017-08-03 14:10:00+03
18298	PG0585	2017-09-02 09:35:00+03	2017-09-02 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18299	PG0586	2017-08-26 12:15:00+03	2017-08-26 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18300	PG0586	2017-07-27 12:15:00+03	2017-07-27 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-27 12:19:00+03	2017-07-27 14:15:00+03
18301	PG0585	2017-07-27 09:35:00+03	2017-07-27 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-27 09:37:00+03	2017-07-27 11:34:00+03
18302	PG0585	2017-08-31 09:35:00+03	2017-08-31 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18303	PG0586	2017-07-18 12:15:00+03	2017-07-18 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-18 12:19:00+03	2017-07-18 14:14:00+03
18304	PG0585	2017-07-18 09:35:00+03	2017-07-18 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-18 09:39:00+03	2017-07-18 11:36:00+03
18305	PG0586	2017-09-02 12:15:00+03	2017-09-02 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18306	PG0585	2017-08-26 09:35:00+03	2017-08-26 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18307	PG0586	2017-08-31 12:15:00+03	2017-08-31 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18308	PG0585	2017-09-13 09:35:00+03	2017-09-13 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18309	PG0586	2017-09-13 12:15:00+03	2017-09-13 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18310	PG0585	2017-08-04 09:35:00+03	2017-08-04 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-04 12:22:00+03	2017-08-04 14:16:00+03
18311	PG0586	2017-08-01 12:15:00+03	2017-08-01 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-01 12:22:00+03	2017-08-01 14:17:00+03
18312	PG0585	2017-08-01 09:35:00+03	2017-08-01 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-01 09:40:00+03	2017-08-01 11:35:00+03
18313	PG0586	2017-08-04 12:15:00+03	2017-08-04 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-04 12:18:00+03	2017-08-04 14:14:00+03
18314	PG0586	2017-09-04 12:15:00+03	2017-09-04 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18315	PG0585	2017-09-04 09:35:00+03	2017-09-04 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18316	PG0586	2017-08-27 12:15:00+03	2017-08-27 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18317	PG0585	2017-08-27 09:35:00+03	2017-08-27 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18318	PG0586	2017-08-19 12:15:00+03	2017-08-19 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18319	PG0585	2017-08-19 09:35:00+03	2017-08-19 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18320	PG0586	2017-08-16 12:15:00+03	2017-08-16 14:10:00+03	ABA	OVB	On Time	CN1	\N	\N
18321	PG0585	2017-08-16 09:35:00+03	2017-08-16 11:30:00+03	ABA	OVB	Delayed	CN1	\N	\N
18322	PG0585	2017-09-11 09:35:00+03	2017-09-11 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18323	PG0586	2017-09-11 12:15:00+03	2017-09-11 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18324	PG0586	2017-09-01 12:15:00+03	2017-09-01 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18325	PG0585	2017-08-14 09:35:00+03	2017-08-14 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-14 09:40:00+03	2017-08-14 11:35:00+03
18326	PG0586	2017-09-12 12:15:00+03	2017-09-12 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18327	PG0586	2017-08-14 12:15:00+03	2017-08-14 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-14 12:18:00+03	2017-08-14 14:15:00+03
18328	PG0585	2017-09-12 09:35:00+03	2017-09-12 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18329	PG0585	2017-09-01 09:35:00+03	2017-09-01 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18330	PG0585	2017-07-23 09:35:00+03	2017-07-23 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-23 09:37:00+03	2017-07-23 11:32:00+03
18331	PG0585	2017-08-05 09:35:00+03	2017-08-05 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-05 09:37:00+03	2017-08-05 11:33:00+03
18332	PG0586	2017-08-05 12:15:00+03	2017-08-05 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-05 12:19:00+03	2017-08-05 14:13:00+03
18333	PG0586	2017-08-25 12:15:00+03	2017-08-25 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18334	PG0585	2017-08-25 09:35:00+03	2017-08-25 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18335	PG0586	2017-07-23 12:15:00+03	2017-07-23 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-23 12:19:00+03	2017-07-23 14:13:00+03
18336	PG0586	2017-07-17 12:15:00+03	2017-07-17 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-17 12:18:00+03	2017-07-17 14:13:00+03
18337	PG0585	2017-07-17 09:35:00+03	2017-07-17 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-17 09:37:00+03	2017-07-17 11:32:00+03
18338	PG0585	2017-08-29 09:35:00+03	2017-08-29 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18339	PG0586	2017-08-29 12:15:00+03	2017-08-29 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18340	PG0586	2017-08-28 12:15:00+03	2017-08-28 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18341	PG0585	2017-08-28 09:35:00+03	2017-08-28 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18342	PG0586	2017-07-26 12:15:00+03	2017-07-26 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-26 15:34:00+03	2017-07-26 17:27:00+03
18343	PG0585	2017-07-26 09:35:00+03	2017-07-26 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-26 09:41:00+03	2017-07-26 11:39:00+03
18344	PG0586	2017-08-08 12:15:00+03	2017-08-08 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-08 12:20:00+03	2017-08-08 14:15:00+03
18345	PG0585	2017-09-14 09:35:00+03	2017-09-14 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18346	PG0585	2017-08-22 09:35:00+03	2017-08-22 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18347	PG0585	2017-07-20 09:35:00+03	2017-07-20 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-20 09:39:00+03	2017-07-20 11:35:00+03
18348	PG0585	2017-08-10 09:35:00+03	2017-08-10 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-10 09:37:00+03	2017-08-10 11:31:00+03
18349	PG0585	2017-09-06 09:35:00+03	2017-09-06 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18350	PG0586	2017-07-20 12:15:00+03	2017-07-20 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-20 12:17:00+03	2017-07-20 14:11:00+03
18351	PG0586	2017-09-06 12:15:00+03	2017-09-06 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18352	PG0585	2017-08-20 09:35:00+03	2017-08-20 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18353	PG0586	2017-08-20 12:15:00+03	2017-08-20 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18354	PG0586	2017-09-14 12:15:00+03	2017-09-14 14:10:00+03	ABA	OVB	Cancelled	CN1	\N	\N
18355	PG0586	2017-07-31 12:15:00+03	2017-07-31 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-31 12:16:00+03	2017-07-31 14:13:00+03
18356	PG0585	2017-07-31 09:35:00+03	2017-07-31 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-31 09:41:00+03	2017-07-31 11:37:00+03
18357	PG0585	2017-07-29 09:35:00+03	2017-07-29 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-29 09:38:00+03	2017-07-29 11:34:00+03
18358	PG0586	2017-07-29 12:15:00+03	2017-07-29 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-29 12:15:00+03	2017-07-29 14:09:00+03
18359	PG0585	2017-08-06 09:35:00+03	2017-08-06 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-06 09:40:00+03	2017-08-06 11:36:00+03
18360	PG0586	2017-08-06 12:15:00+03	2017-08-06 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-06 12:18:00+03	2017-08-06 14:12:00+03
18361	PG0586	2017-09-03 12:15:00+03	2017-09-03 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18362	PG0585	2017-09-03 09:35:00+03	2017-09-03 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18363	PG0585	2017-08-18 09:35:00+03	2017-08-18 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18364	PG0586	2017-08-18 12:15:00+03	2017-08-18 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18365	PG0585	2017-08-11 09:35:00+03	2017-08-11 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-11 09:42:00+03	2017-08-11 11:37:00+03
18366	PG0586	2017-08-10 12:15:00+03	2017-08-10 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-10 12:17:00+03	2017-08-10 14:13:00+03
18367	PG0586	2017-08-09 12:15:00+03	2017-08-09 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-09 12:17:00+03	2017-08-09 14:13:00+03
18368	PG0585	2017-08-09 09:35:00+03	2017-08-09 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-09 09:41:00+03	2017-08-09 11:38:00+03
18369	PG0585	2017-09-09 09:35:00+03	2017-09-09 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18370	PG0586	2017-09-09 12:15:00+03	2017-09-09 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18371	PG0586	2017-08-11 12:15:00+03	2017-08-11 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-11 12:15:00+03	2017-08-11 14:11:00+03
18372	PG0586	2017-08-21 12:15:00+03	2017-08-21 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18373	PG0585	2017-08-24 09:35:00+03	2017-08-24 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18374	PG0586	2017-08-24 12:15:00+03	2017-08-24 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18375	PG0586	2017-09-07 12:15:00+03	2017-09-07 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18376	PG0585	2017-08-21 09:35:00+03	2017-08-21 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18377	PG0585	2017-09-07 09:35:00+03	2017-09-07 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18378	PG0586	2017-07-16 12:15:00+03	2017-07-16 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-16 12:21:00+03	2017-07-16 14:16:00+03
18379	PG0585	2017-07-16 09:35:00+03	2017-07-16 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-16 09:36:00+03	2017-07-16 11:32:00+03
18380	PG0585	2017-08-13 09:35:00+03	2017-08-13 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-13 09:35:00+03	2017-08-13 11:32:00+03
18381	PG0586	2017-08-13 12:15:00+03	2017-08-13 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-13 12:21:00+03	2017-08-13 14:17:00+03
18382	PG0586	2017-08-15 12:15:00+03	2017-08-15 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-15 12:16:00+03	2017-08-15 14:13:00+03
18383	PG0585	2017-08-15 09:35:00+03	2017-08-15 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-15 09:36:00+03	2017-08-15 11:30:00+03
18384	PG0586	2017-07-24 12:15:00+03	2017-07-24 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-24 12:19:00+03	2017-07-24 14:14:00+03
18385	PG0586	2017-09-10 12:15:00+03	2017-09-10 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18386	PG0585	2017-09-10 09:35:00+03	2017-09-10 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18387	PG0585	2017-08-08 09:35:00+03	2017-08-08 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-08 09:40:00+03	2017-08-08 11:36:00+03
18388	PG0585	2017-08-07 09:35:00+03	2017-08-07 11:30:00+03	ABA	OVB	Arrived	CN1	2017-08-07 09:38:00+03	2017-08-07 11:33:00+03
18389	PG0586	2017-08-07 12:15:00+03	2017-08-07 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-07 12:16:00+03	2017-08-07 14:13:00+03
18390	PG0585	2017-07-24 09:35:00+03	2017-07-24 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-24 09:36:00+03	2017-07-24 11:31:00+03
18391	PG0586	2017-07-25 12:15:00+03	2017-07-25 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-25 12:20:00+03	2017-07-25 14:16:00+03
18392	PG0585	2017-07-25 09:35:00+03	2017-07-25 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-25 13:08:00+03	2017-07-25 15:03:00+03
18393	PG0586	2017-08-22 12:15:00+03	2017-08-22 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18394	PG0586	2017-07-30 12:15:00+03	2017-07-30 14:10:00+03	ABA	OVB	Arrived	CN1	2017-07-30 15:18:00+03	2017-07-30 17:13:00+03
18395	PG0585	2017-07-30 09:35:00+03	2017-07-30 11:30:00+03	ABA	OVB	Arrived	CN1	2017-07-30 09:40:00+03	2017-07-30 11:35:00+03
18396	PG0586	2017-08-17 12:15:00+03	2017-08-17 14:10:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18397	PG0585	2017-08-17 09:35:00+03	2017-08-17 11:30:00+03	ABA	OVB	Scheduled	CN1	\N	\N
18398	PG0586	2017-08-02 12:15:00+03	2017-08-02 14:10:00+03	ABA	OVB	Arrived	CN1	2017-08-02 12:16:00+03	2017-08-02 14:10:00+03
18399	PG0702	2017-09-13 10:25:00+03	2017-09-13 15:15:00+03	ABA	GRV	Cancelled	733	\N	\N
18400	PG0702	2017-07-19 10:25:00+03	2017-07-19 15:15:00+03	ABA	GRV	Arrived	733	2017-07-19 10:27:00+03	2017-07-19 15:22:00+03
18401	PG0702	2017-08-23 10:25:00+03	2017-08-23 15:15:00+03	ABA	GRV	Scheduled	733	\N	\N
18402	PG0702	2017-08-30 10:25:00+03	2017-08-30 15:15:00+03	ABA	GRV	Scheduled	733	\N	\N
18403	PG0702	2017-07-26 10:25:00+03	2017-07-26 15:15:00+03	ABA	GRV	Arrived	733	2017-07-26 10:28:00+03	2017-07-26 15:21:00+03
18404	PG0702	2017-08-02 10:25:00+03	2017-08-02 15:15:00+03	ABA	GRV	Arrived	733	2017-08-02 10:27:00+03	2017-08-02 15:16:00+03
18405	PG0702	2017-08-09 10:25:00+03	2017-08-09 15:15:00+03	ABA	GRV	Arrived	733	2017-08-09 10:28:00+03	2017-08-09 15:15:00+03
18406	PG0702	2017-09-06 10:25:00+03	2017-09-06 15:15:00+03	ABA	GRV	Scheduled	733	\N	\N
18407	PG0702	2017-08-16 10:25:00+03	2017-08-16 15:15:00+03	ABA	GRV	On Time	733	\N	\N
18408	PG0313	2017-07-25 08:15:00+03	2017-07-25 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-07-25 08:17:00+03	2017-07-25 09:17:00+03
18409	PG0313	2017-08-08 08:15:00+03	2017-08-08 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-08-08 08:19:00+03	2017-08-08 09:19:00+03
18410	PG0313	2017-08-29 08:15:00+03	2017-08-29 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18411	PG0313	2017-07-29 08:15:00+03	2017-07-29 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-07-29 12:05:00+03	2017-07-29 13:05:00+03
18412	PG0313	2017-08-15 08:15:00+03	2017-08-15 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-08-15 08:19:00+03	2017-08-15 09:19:00+03
18413	PG0313	2017-08-05 08:15:00+03	2017-08-05 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-08-05 11:32:00+03	2017-08-05 12:31:00+03
18414	PG0313	2017-09-02 08:15:00+03	2017-09-02 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18415	PG0313	2017-09-05 08:15:00+03	2017-09-05 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18416	PG0313	2017-08-12 08:15:00+03	2017-08-12 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-08-12 08:16:00+03	2017-08-12 09:16:00+03
18417	PG0313	2017-07-22 08:15:00+03	2017-07-22 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-07-22 08:17:00+03	2017-07-22 09:17:00+03
18418	PG0313	2017-08-01 08:15:00+03	2017-08-01 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-08-01 08:19:00+03	2017-08-01 09:19:00+03
18419	PG0313	2017-08-22 08:15:00+03	2017-08-22 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18420	PG0313	2017-09-12 08:15:00+03	2017-09-12 09:15:00+03	ABA	KYZ	Cancelled	CN1	\N	\N
18421	PG0313	2017-08-26 08:15:00+03	2017-08-26 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18422	PG0313	2017-09-09 08:15:00+03	2017-09-09 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18423	PG0313	2017-08-19 08:15:00+03	2017-08-19 09:15:00+03	ABA	KYZ	Scheduled	CN1	\N	\N
18424	PG0313	2017-07-18 08:15:00+03	2017-07-18 09:15:00+03	ABA	KYZ	Arrived	CN1	2017-07-18 08:19:00+03	2017-07-18 09:20:00+03
18425	PG0070	2017-08-06 12:05:00+03	2017-08-06 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-06 12:07:00+03	2017-08-06 13:42:00+03
18426	PG0070	2017-09-02 12:05:00+03	2017-09-02 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18427	PG0070	2017-07-27 12:05:00+03	2017-07-27 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-27 12:07:00+03	2017-07-27 13:41:00+03
18428	PG0070	2017-08-28 12:05:00+03	2017-08-28 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18429	PG0070	2017-07-16 12:05:00+03	2017-07-16 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-16 12:07:00+03	2017-07-16 13:44:00+03
18430	PG0070	2017-07-30 12:05:00+03	2017-07-30 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-30 12:07:00+03	2017-07-30 13:40:00+03
18431	PG0070	2017-09-11 12:05:00+03	2017-09-11 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18432	PG0070	2017-08-26 12:05:00+03	2017-08-26 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18433	PG0070	2017-07-31 12:05:00+03	2017-07-31 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-31 12:06:00+03	2017-07-31 13:42:00+03
18434	PG0070	2017-08-18 12:05:00+03	2017-08-18 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18435	PG0070	2017-08-11 12:05:00+03	2017-08-11 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-11 12:09:00+03	2017-08-11 13:44:00+03
18436	PG0070	2017-07-25 12:05:00+03	2017-07-25 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-25 12:07:00+03	2017-07-25 13:41:00+03
18437	PG0070	2017-07-19 12:05:00+03	2017-07-19 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-19 12:07:00+03	2017-07-19 13:42:00+03
18438	PG0070	2017-07-28 12:05:00+03	2017-07-28 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-28 12:09:00+03	2017-07-28 13:43:00+03
18439	PG0070	2017-09-03 12:05:00+03	2017-09-03 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18440	PG0070	2017-09-13 12:05:00+03	2017-09-13 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18441	PG0070	2017-07-26 12:05:00+03	2017-07-26 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-26 12:10:00+03	2017-07-26 13:43:00+03
18442	PG0070	2017-08-31 12:05:00+03	2017-08-31 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18443	PG0070	2017-07-18 12:05:00+03	2017-07-18 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-18 12:08:00+03	2017-07-18 13:43:00+03
18444	PG0070	2017-08-13 12:05:00+03	2017-08-13 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-13 12:12:00+03	2017-08-13 13:47:00+03
18445	PG0070	2017-08-23 12:05:00+03	2017-08-23 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18446	PG0070	2017-09-01 12:05:00+03	2017-09-01 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18447	PG0070	2017-08-24 12:05:00+03	2017-08-24 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18448	PG0070	2017-09-14 12:05:00+03	2017-09-14 13:40:00+03	ABA	TOF	Cancelled	CN1	\N	\N
18449	PG0070	2017-09-04 12:05:00+03	2017-09-04 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18450	PG0070	2017-07-21 12:05:00+03	2017-07-21 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-21 12:07:00+03	2017-07-21 13:42:00+03
18451	PG0070	2017-07-22 12:05:00+03	2017-07-22 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-22 15:10:00+03	2017-07-22 16:45:00+03
18452	PG0070	2017-08-10 12:05:00+03	2017-08-10 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-10 12:12:00+03	2017-08-10 13:47:00+03
18453	PG0070	2017-09-07 12:05:00+03	2017-09-07 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18454	PG0070	2017-08-07 12:05:00+03	2017-08-07 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-07 12:05:00+03	2017-08-07 13:42:00+03
18455	PG0070	2017-09-09 12:05:00+03	2017-09-09 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18456	PG0070	2017-07-24 12:05:00+03	2017-07-24 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-24 12:09:00+03	2017-07-24 13:46:00+03
18457	PG0070	2017-08-30 12:05:00+03	2017-08-30 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18458	PG0070	2017-08-25 12:05:00+03	2017-08-25 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18459	PG0070	2017-08-01 12:05:00+03	2017-08-01 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-01 12:06:00+03	2017-08-01 13:42:00+03
18460	PG0070	2017-08-16 12:05:00+03	2017-08-16 13:40:00+03	ABA	TOF	On Time	CN1	\N	\N
18461	PG0070	2017-07-23 12:05:00+03	2017-07-23 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-23 12:08:00+03	2017-07-23 13:44:00+03
18462	PG0070	2017-07-17 12:05:00+03	2017-07-17 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-17 12:10:00+03	2017-07-17 13:45:00+03
18463	PG0070	2017-09-05 12:05:00+03	2017-09-05 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18464	PG0070	2017-09-08 12:05:00+03	2017-09-08 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18465	PG0070	2017-08-21 12:05:00+03	2017-08-21 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18466	PG0070	2017-08-08 12:05:00+03	2017-08-08 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-08 12:08:00+03	2017-08-08 13:43:00+03
18467	PG0070	2017-08-14 12:05:00+03	2017-08-14 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-14 12:06:00+03	2017-08-14 13:42:00+03
18468	PG0070	2017-09-06 12:05:00+03	2017-09-06 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18469	PG0070	2017-08-12 12:05:00+03	2017-08-12 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-12 12:06:00+03	2017-08-12 13:42:00+03
18470	PG0070	2017-08-22 12:05:00+03	2017-08-22 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18471	PG0070	2017-08-27 12:05:00+03	2017-08-27 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18472	PG0070	2017-08-19 12:05:00+03	2017-08-19 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18473	PG0070	2017-08-29 12:05:00+03	2017-08-29 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18474	PG0070	2017-08-05 12:05:00+03	2017-08-05 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-05 12:07:00+03	2017-08-05 13:41:00+03
18475	PG0070	2017-09-10 12:05:00+03	2017-09-10 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18476	PG0070	2017-08-03 12:05:00+03	2017-08-03 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-03 12:08:00+03	2017-08-03 13:42:00+03
18477	PG0070	2017-07-29 12:05:00+03	2017-07-29 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-29 12:07:00+03	2017-07-29 13:42:00+03
18478	PG0070	2017-07-20 12:05:00+03	2017-07-20 13:40:00+03	ABA	TOF	Arrived	CN1	2017-07-20 12:08:00+03	2017-07-20 13:44:00+03
18479	PG0070	2017-08-20 12:05:00+03	2017-08-20 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18480	PG0070	2017-09-12 12:05:00+03	2017-09-12 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18481	PG0070	2017-08-15 12:05:00+03	2017-08-15 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-15 12:09:00+03	2017-08-15 13:43:00+03
18482	PG0070	2017-08-17 12:05:00+03	2017-08-17 13:40:00+03	ABA	TOF	Scheduled	CN1	\N	\N
18483	PG0070	2017-08-02 12:05:00+03	2017-08-02 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-02 12:10:00+03	2017-08-02 13:46:00+03
18484	PG0070	2017-08-04 12:05:00+03	2017-08-04 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-04 12:09:00+03	2017-08-04 13:43:00+03
18485	PG0070	2017-08-09 12:05:00+03	2017-08-09 13:40:00+03	ABA	TOF	Arrived	CN1	2017-08-09 12:06:00+03	2017-08-09 13:41:00+03
18486	PG0490	2017-09-09 11:40:00+03	2017-09-09 15:40:00+03	ABA	ARH	Cancelled	319	\N	\N
18487	PG0490	2017-08-19 11:40:00+03	2017-08-19 15:40:00+03	ABA	ARH	Scheduled	319	\N	\N
18488	PG0490	2017-08-05 11:40:00+03	2017-08-05 15:40:00+03	ABA	ARH	Arrived	319	2017-08-05 11:42:00+03	2017-08-05 15:41:00+03
18489	PG0490	2017-09-02 11:40:00+03	2017-09-02 15:40:00+03	ABA	ARH	Scheduled	319	\N	\N
18490	PG0490	2017-08-12 11:40:00+03	2017-08-12 15:40:00+03	ABA	ARH	Arrived	319	2017-08-12 11:42:00+03	2017-08-12 15:44:00+03
18491	PG0490	2017-07-22 11:40:00+03	2017-07-22 15:40:00+03	ABA	ARH	Arrived	319	2017-07-22 11:45:00+03	2017-07-22 15:45:00+03
18492	PG0490	2017-08-26 11:40:00+03	2017-08-26 15:40:00+03	ABA	ARH	Scheduled	319	\N	\N
18493	PG0490	2017-07-29 11:40:00+03	2017-07-29 15:40:00+03	ABA	ARH	Arrived	319	2017-07-29 11:41:00+03	2017-07-29 15:42:00+03
18494	PG0165	2017-08-13 10:35:00+03	2017-08-13 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-13 10:39:00+03	2017-08-13 13:50:00+03
18495	PG0165	2017-09-01 10:35:00+03	2017-09-01 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18496	PG0165	2017-08-30 10:35:00+03	2017-08-30 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18497	PG0165	2017-09-07 10:35:00+03	2017-09-07 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18498	PG0165	2017-07-22 10:35:00+03	2017-07-22 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-22 10:39:00+03	2017-07-22 13:50:00+03
18499	PG0165	2017-08-23 10:35:00+03	2017-08-23 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18500	PG0165	2017-09-02 10:35:00+03	2017-09-02 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18501	PG0165	2017-07-21 10:35:00+03	2017-07-21 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-21 10:36:00+03	2017-07-21 13:42:00+03
18502	PG0165	2017-08-06 10:35:00+03	2017-08-06 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-06 10:36:00+03	2017-08-06 13:45:00+03
18503	PG0165	2017-07-31 10:35:00+03	2017-07-31 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-31 10:38:00+03	2017-07-31 13:47:00+03
18504	PG0165	2017-07-24 10:35:00+03	2017-07-24 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-24 13:17:00+03	2017-07-24 16:28:00+03
18505	PG0165	2017-07-28 10:35:00+03	2017-07-28 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-28 10:37:00+03	2017-07-28 13:49:00+03
18506	PG0165	2017-08-03 10:35:00+03	2017-08-03 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-03 10:40:00+03	2017-08-03 13:52:00+03
18507	PG0165	2017-09-04 10:35:00+03	2017-09-04 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18508	PG0165	2017-08-27 10:35:00+03	2017-08-27 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18509	PG0165	2017-09-14 10:35:00+03	2017-09-14 13:45:00+03	NUX	DME	Cancelled	SU9	\N	\N
18510	PG0165	2017-08-31 10:35:00+03	2017-08-31 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18511	PG0165	2017-08-25 10:35:00+03	2017-08-25 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18512	PG0165	2017-09-13 10:35:00+03	2017-09-13 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18513	PG0165	2017-08-01 10:35:00+03	2017-08-01 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-01 10:38:00+03	2017-08-01 13:48:00+03
18514	PG0165	2017-07-16 10:35:00+03	2017-07-16 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-16 10:39:00+03	2017-07-16 13:51:00+03
18515	PG0165	2017-09-08 10:35:00+03	2017-09-08 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18516	PG0165	2017-08-29 10:35:00+03	2017-08-29 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18517	PG0165	2017-08-28 10:35:00+03	2017-08-28 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18518	PG0165	2017-08-09 10:35:00+03	2017-08-09 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-09 10:43:00+03	2017-08-09 13:54:00+03
18519	PG0165	2017-07-27 10:35:00+03	2017-07-27 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-27 10:38:00+03	2017-07-27 13:47:00+03
18520	PG0165	2017-07-29 10:35:00+03	2017-07-29 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-29 10:37:00+03	2017-07-29 13:46:00+03
18521	PG0165	2017-07-18 10:35:00+03	2017-07-18 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-18 10:38:00+03	2017-07-18 13:50:00+03
18522	PG0165	2017-09-03 10:35:00+03	2017-09-03 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18523	PG0165	2017-08-05 10:35:00+03	2017-08-05 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-05 10:35:00+03	2017-08-05 13:47:00+03
18524	PG0165	2017-08-15 10:35:00+03	2017-08-15 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-15 10:38:00+03	2017-08-15 13:49:00+03
18525	PG0165	2017-08-08 10:35:00+03	2017-08-08 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-08 10:36:00+03	2017-08-08 13:47:00+03
18526	PG0165	2017-08-14 10:35:00+03	2017-08-14 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-14 10:37:00+03	2017-08-14 13:46:00+03
18527	PG0165	2017-09-09 10:35:00+03	2017-09-09 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18528	PG0165	2017-08-24 10:35:00+03	2017-08-24 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18529	PG0165	2017-08-26 10:35:00+03	2017-08-26 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18530	PG0165	2017-07-20 10:35:00+03	2017-07-20 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-20 10:38:00+03	2017-07-20 13:48:00+03
18531	PG0165	2017-09-11 10:35:00+03	2017-09-11 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18532	PG0165	2017-08-10 10:35:00+03	2017-08-10 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-10 10:39:00+03	2017-08-10 13:48:00+03
18533	PG0165	2017-08-17 10:35:00+03	2017-08-17 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18534	PG0165	2017-08-19 10:35:00+03	2017-08-19 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18535	PG0165	2017-08-18 10:35:00+03	2017-08-18 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18536	PG0165	2017-08-21 10:35:00+03	2017-08-21 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18537	PG0165	2017-08-04 10:35:00+03	2017-08-04 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-04 10:37:00+03	2017-08-04 13:47:00+03
18538	PG0165	2017-08-12 10:35:00+03	2017-08-12 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-12 10:36:00+03	2017-08-12 13:42:00+03
18539	PG0165	2017-09-05 10:35:00+03	2017-09-05 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18540	PG0165	2017-08-11 10:35:00+03	2017-08-11 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-11 10:39:00+03	2017-08-11 13:50:00+03
18541	PG0165	2017-08-22 10:35:00+03	2017-08-22 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18542	PG0165	2017-09-06 10:35:00+03	2017-09-06 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18543	PG0165	2017-08-02 10:35:00+03	2017-08-02 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-02 10:39:00+03	2017-08-02 13:49:00+03
18544	PG0165	2017-07-25 10:35:00+03	2017-07-25 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-25 10:37:00+03	2017-07-25 13:48:00+03
18545	PG0165	2017-07-23 10:35:00+03	2017-07-23 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-23 10:39:00+03	2017-07-23 13:48:00+03
18546	PG0165	2017-07-30 10:35:00+03	2017-07-30 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-30 10:35:00+03	2017-07-30 13:43:00+03
18547	PG0165	2017-09-12 10:35:00+03	2017-09-12 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18548	PG0165	2017-07-19 10:35:00+03	2017-07-19 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-19 13:41:00+03	2017-07-19 16:51:00+03
18549	PG0165	2017-07-17 10:35:00+03	2017-07-17 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-17 10:38:00+03	2017-07-17 13:43:00+03
18550	PG0165	2017-08-07 10:35:00+03	2017-08-07 13:45:00+03	NUX	DME	Arrived	SU9	2017-08-07 10:35:00+03	2017-08-07 13:47:00+03
18551	PG0165	2017-07-26 10:35:00+03	2017-07-26 13:45:00+03	NUX	DME	Arrived	SU9	2017-07-26 10:39:00+03	2017-07-26 13:48:00+03
18552	PG0165	2017-09-10 10:35:00+03	2017-09-10 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18553	PG0165	2017-08-20 10:35:00+03	2017-08-20 13:45:00+03	NUX	DME	Scheduled	SU9	\N	\N
18554	PG0165	2017-08-16 10:35:00+03	2017-08-16 13:45:00+03	NUX	DME	Delayed	SU9	\N	\N
18555	PG0292	2017-08-13 10:20:00+03	2017-08-13 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-13 10:24:00+03	2017-08-13 13:28:00+03
18556	PG0292	2017-08-21 10:20:00+03	2017-08-21 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18557	PG0292	2017-09-10 10:20:00+03	2017-09-10 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18558	PG0292	2017-08-30 10:20:00+03	2017-08-30 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18559	PG0292	2017-08-08 10:20:00+03	2017-08-08 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-08 10:24:00+03	2017-08-08 13:29:00+03
18560	PG0292	2017-08-09 10:20:00+03	2017-08-09 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-09 10:21:00+03	2017-08-09 13:24:00+03
18561	PG0292	2017-09-02 10:20:00+03	2017-09-02 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18562	PG0292	2017-09-14 10:20:00+03	2017-09-14 13:25:00+03	NUX	SVO	Cancelled	SU9	\N	\N
18563	PG0292	2017-09-03 10:20:00+03	2017-09-03 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18564	PG0292	2017-08-07 10:20:00+03	2017-08-07 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-07 10:22:00+03	2017-08-07 13:29:00+03
18565	PG0292	2017-07-17 10:20:00+03	2017-07-17 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-17 10:22:00+03	2017-07-17 13:30:00+03
18566	PG0292	2017-08-06 10:20:00+03	2017-08-06 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-06 10:24:00+03	2017-08-06 13:24:00+03
18567	PG0292	2017-08-16 10:20:00+03	2017-08-16 13:25:00+03	NUX	SVO	On Time	SU9	\N	\N
18568	PG0292	2017-08-24 10:20:00+03	2017-08-24 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18569	PG0292	2017-09-04 10:20:00+03	2017-09-04 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18570	PG0292	2017-08-05 10:20:00+03	2017-08-05 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-05 10:20:00+03	2017-08-05 13:27:00+03
18571	PG0292	2017-07-16 10:20:00+03	2017-07-16 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-16 10:21:00+03	2017-07-16 13:25:00+03
18572	PG0292	2017-07-18 10:20:00+03	2017-07-18 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-18 10:23:00+03	2017-07-18 13:31:00+03
18573	PG0292	2017-08-04 10:20:00+03	2017-08-04 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-04 13:23:00+03	2017-08-04 16:27:00+03
18574	PG0292	2017-08-29 10:20:00+03	2017-08-29 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18575	PG0292	2017-08-17 10:20:00+03	2017-08-17 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18576	PG0292	2017-09-05 10:20:00+03	2017-09-05 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18577	PG0292	2017-08-03 10:20:00+03	2017-08-03 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-03 10:21:00+03	2017-08-03 13:25:00+03
18578	PG0292	2017-08-10 10:20:00+03	2017-08-10 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-10 10:26:00+03	2017-08-10 13:29:00+03
18579	PG0292	2017-07-19 10:20:00+03	2017-07-19 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-19 10:21:00+03	2017-07-19 13:26:00+03
18580	PG0292	2017-09-13 10:20:00+03	2017-09-13 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18581	PG0292	2017-08-31 10:20:00+03	2017-08-31 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18582	PG0292	2017-08-02 10:20:00+03	2017-08-02 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-02 10:25:00+03	2017-08-02 13:29:00+03
18583	PG0292	2017-08-23 10:20:00+03	2017-08-23 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18584	PG0292	2017-09-06 10:20:00+03	2017-09-06 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18585	PG0292	2017-08-18 10:20:00+03	2017-08-18 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18586	PG0292	2017-07-20 10:20:00+03	2017-07-20 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-20 10:22:00+03	2017-07-20 13:26:00+03
18587	PG0292	2017-08-01 10:20:00+03	2017-08-01 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-01 13:42:00+03	2017-08-01 16:45:00+03
18588	PG0292	2017-08-26 10:20:00+03	2017-08-26 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18589	PG0292	2017-07-31 10:20:00+03	2017-07-31 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-31 10:22:00+03	2017-07-31 13:28:00+03
18590	PG0292	2017-09-12 10:20:00+03	2017-09-12 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18591	PG0292	2017-07-21 10:20:00+03	2017-07-21 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-21 10:23:00+03	2017-07-21 13:26:00+03
18592	PG0292	2017-09-07 10:20:00+03	2017-09-07 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18593	PG0292	2017-08-25 10:20:00+03	2017-08-25 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18594	PG0292	2017-07-30 10:20:00+03	2017-07-30 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-30 10:22:00+03	2017-07-30 13:26:00+03
18595	PG0292	2017-08-14 10:20:00+03	2017-08-14 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-14 10:25:00+03	2017-08-14 13:33:00+03
18596	PG0292	2017-08-28 10:20:00+03	2017-08-28 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18597	PG0292	2017-08-19 10:20:00+03	2017-08-19 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18598	PG0292	2017-08-12 10:20:00+03	2017-08-12 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-12 10:24:00+03	2017-08-12 13:28:00+03
18599	PG0292	2017-07-22 10:20:00+03	2017-07-22 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-22 10:20:00+03	2017-07-22 13:23:00+03
18600	PG0292	2017-07-29 10:20:00+03	2017-07-29 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-29 10:21:00+03	2017-07-29 13:26:00+03
18601	PG0292	2017-09-08 10:20:00+03	2017-09-08 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18602	PG0292	2017-08-22 10:20:00+03	2017-08-22 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18603	PG0292	2017-08-11 10:20:00+03	2017-08-11 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-11 10:21:00+03	2017-08-11 13:26:00+03
18604	PG0292	2017-07-28 10:20:00+03	2017-07-28 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-28 10:22:00+03	2017-07-28 13:25:00+03
18605	PG0292	2017-09-11 10:20:00+03	2017-09-11 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18606	PG0292	2017-07-23 10:20:00+03	2017-07-23 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-23 10:23:00+03	2017-07-23 13:27:00+03
18607	PG0292	2017-08-20 10:20:00+03	2017-08-20 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18608	PG0292	2017-09-01 10:20:00+03	2017-09-01 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18609	PG0292	2017-07-27 10:20:00+03	2017-07-27 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-27 10:26:00+03	2017-07-27 13:32:00+03
18610	PG0292	2017-09-09 10:20:00+03	2017-09-09 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18611	PG0292	2017-07-26 10:20:00+03	2017-07-26 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-26 10:22:00+03	2017-07-26 13:25:00+03
18612	PG0292	2017-07-24 10:20:00+03	2017-07-24 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-24 13:26:00+03	2017-07-24 16:33:00+03
18613	PG0292	2017-08-15 10:20:00+03	2017-08-15 13:25:00+03	NUX	SVO	Arrived	SU9	2017-08-15 10:22:00+03	2017-08-15 13:28:00+03
18614	PG0292	2017-07-25 10:20:00+03	2017-07-25 13:25:00+03	NUX	SVO	Arrived	SU9	2017-07-25 10:23:00+03	2017-07-25 13:29:00+03
18615	PG0292	2017-08-27 10:20:00+03	2017-08-27 13:25:00+03	NUX	SVO	Scheduled	SU9	\N	\N
18616	PG0624	2017-09-14 11:05:00+03	2017-09-14 13:05:00+03	NUX	KJA	Cancelled	CR2	\N	\N
18617	PG0624	2017-08-28 11:05:00+03	2017-08-28 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18618	PG0624	2017-09-11 11:05:00+03	2017-09-11 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18619	PG0624	2017-08-03 11:05:00+03	2017-08-03 13:05:00+03	NUX	KJA	Arrived	CR2	2017-08-03 11:11:00+03	2017-08-03 13:11:00+03
18620	PG0624	2017-08-07 11:05:00+03	2017-08-07 13:05:00+03	NUX	KJA	Arrived	CR2	2017-08-07 11:08:00+03	2017-08-07 13:09:00+03
18621	PG0624	2017-09-04 11:05:00+03	2017-09-04 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18622	PG0624	2017-07-27 11:05:00+03	2017-07-27 13:05:00+03	NUX	KJA	Arrived	CR2	2017-07-27 11:09:00+03	2017-07-27 13:08:00+03
18623	PG0624	2017-08-14 11:05:00+03	2017-08-14 13:05:00+03	NUX	KJA	Arrived	CR2	2017-08-14 11:09:00+03	2017-08-14 13:09:00+03
18624	PG0624	2017-08-17 11:05:00+03	2017-08-17 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18625	PG0624	2017-09-07 11:05:00+03	2017-09-07 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18626	PG0624	2017-07-24 11:05:00+03	2017-07-24 13:05:00+03	NUX	KJA	Arrived	CR2	2017-07-24 11:06:00+03	2017-07-24 13:06:00+03
18627	PG0624	2017-08-10 11:05:00+03	2017-08-10 13:05:00+03	NUX	KJA	Arrived	CR2	2017-08-10 11:06:00+03	2017-08-10 13:08:00+03
18628	PG0624	2017-08-24 11:05:00+03	2017-08-24 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18629	PG0624	2017-08-31 11:05:00+03	2017-08-31 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18630	PG0624	2017-08-21 11:05:00+03	2017-08-21 13:05:00+03	NUX	KJA	Scheduled	CR2	\N	\N
18631	PG0624	2017-07-17 11:05:00+03	2017-07-17 13:05:00+03	NUX	KJA	Arrived	CR2	2017-07-17 11:08:00+03	2017-07-17 13:08:00+03
18632	PG0624	2017-07-31 11:05:00+03	2017-07-31 13:05:00+03	NUX	KJA	Arrived	CR2	2017-07-31 11:13:00+03	2017-07-31 13:12:00+03
18633	PG0624	2017-07-20 11:05:00+03	2017-07-20 13:05:00+03	NUX	KJA	Arrived	CR2	2017-07-20 11:05:00+03	2017-07-20 13:05:00+03
18634	PG0536	2017-08-19 08:25:00+03	2017-08-19 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18635	PG0535	2017-08-11 13:15:00+03	2017-08-11 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-11 13:18:00+03	2017-08-11 14:22:00+03
18636	PG0536	2017-08-01 08:25:00+03	2017-08-01 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-01 08:27:00+03	2017-08-01 09:32:00+03
18637	PG0535	2017-08-01 13:15:00+03	2017-08-01 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-01 13:22:00+03	2017-08-01 14:27:00+03
18638	PG0536	2017-08-30 08:25:00+03	2017-08-30 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18639	PG0536	2017-09-09 08:25:00+03	2017-09-09 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18640	PG0535	2017-09-09 13:15:00+03	2017-09-09 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18641	PG0535	2017-07-16 13:15:00+03	2017-07-16 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-16 13:20:00+03	2017-07-16 14:25:00+03
18642	PG0535	2017-09-14 13:15:00+03	2017-09-14 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18643	PG0535	2017-08-23 13:15:00+03	2017-08-23 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18644	PG0536	2017-09-12 08:25:00+03	2017-09-12 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18645	PG0536	2017-09-14 08:25:00+03	2017-09-14 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18646	PG0535	2017-08-20 13:15:00+03	2017-08-20 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18647	PG0535	2017-09-03 13:15:00+03	2017-09-03 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18648	PG0536	2017-08-20 08:25:00+03	2017-08-20 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18649	PG0536	2017-09-03 08:25:00+03	2017-09-03 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18650	PG0535	2017-09-02 13:15:00+03	2017-09-02 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18651	PG0535	2017-08-03 13:15:00+03	2017-08-03 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-03 13:18:00+03	2017-08-03 14:23:00+03
18652	PG0536	2017-08-03 08:25:00+03	2017-08-03 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-03 08:29:00+03	2017-08-03 09:34:00+03
18653	PG0536	2017-08-25 08:25:00+03	2017-08-25 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18654	PG0536	2017-07-26 08:25:00+03	2017-07-26 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-26 08:28:00+03	2017-07-26 09:33:00+03
18655	PG0535	2017-08-25 13:15:00+03	2017-08-25 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18656	PG0535	2017-07-18 13:15:00+03	2017-07-18 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-18 13:17:00+03	2017-07-18 14:21:00+03
18657	PG0535	2017-07-26 13:15:00+03	2017-07-26 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-26 13:19:00+03	2017-07-26 14:24:00+03
18658	PG0535	2017-08-19 13:15:00+03	2017-08-19 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18659	PG0536	2017-07-25 08:25:00+03	2017-07-25 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-25 08:29:00+03	2017-07-25 09:33:00+03
18660	PG0536	2017-08-02 08:25:00+03	2017-08-02 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-02 08:29:00+03	2017-08-02 09:34:00+03
18661	PG0535	2017-08-02 13:15:00+03	2017-08-02 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-02 16:23:00+03	2017-08-02 17:28:00+03
18662	PG0536	2017-08-29 08:25:00+03	2017-08-29 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18663	PG0535	2017-07-25 13:15:00+03	2017-07-25 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-25 13:17:00+03	2017-07-25 14:22:00+03
18664	PG0535	2017-08-12 13:15:00+03	2017-08-12 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-12 13:18:00+03	2017-08-12 14:24:00+03
18665	PG0536	2017-08-27 08:25:00+03	2017-08-27 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18666	PG0535	2017-08-27 13:15:00+03	2017-08-27 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18667	PG0535	2017-08-21 13:15:00+03	2017-08-21 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18668	PG0536	2017-08-21 08:25:00+03	2017-08-21 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18669	PG0535	2017-08-15 13:15:00+03	2017-08-15 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-15 13:17:00+03	2017-08-15 14:23:00+03
18670	PG0536	2017-08-15 08:25:00+03	2017-08-15 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-15 08:28:00+03	2017-08-15 09:34:00+03
18671	PG0536	2017-07-27 08:25:00+03	2017-07-27 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-27 08:26:00+03	2017-07-27 09:31:00+03
18672	PG0535	2017-07-19 13:15:00+03	2017-07-19 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-19 13:15:00+03	2017-07-19 14:18:00+03
18673	PG0536	2017-07-19 08:25:00+03	2017-07-19 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-19 08:28:00+03	2017-07-19 09:33:00+03
18674	PG0535	2017-08-28 13:15:00+03	2017-08-28 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18675	PG0535	2017-07-31 13:15:00+03	2017-07-31 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-31 13:19:00+03	2017-07-31 14:24:00+03
18676	PG0536	2017-07-31 08:25:00+03	2017-07-31 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-31 08:27:00+03	2017-07-31 09:32:00+03
18677	PG0536	2017-07-30 08:25:00+03	2017-07-30 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-30 08:28:00+03	2017-07-30 09:33:00+03
18678	PG0536	2017-08-28 08:25:00+03	2017-08-28 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18679	PG0536	2017-09-04 08:25:00+03	2017-09-04 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18680	PG0535	2017-07-28 13:15:00+03	2017-07-28 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-28 13:16:00+03	2017-07-28 14:21:00+03
18681	PG0536	2017-07-28 08:25:00+03	2017-07-28 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-28 08:25:00+03	2017-07-28 09:30:00+03
18682	PG0535	2017-08-05 13:15:00+03	2017-08-05 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-05 13:19:00+03	2017-08-05 14:24:00+03
18683	PG0536	2017-08-07 08:25:00+03	2017-08-07 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-07 08:30:00+03	2017-08-07 09:35:00+03
18684	PG0536	2017-08-05 08:25:00+03	2017-08-05 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-05 08:25:00+03	2017-08-05 09:30:00+03
18685	PG0535	2017-09-04 13:15:00+03	2017-09-04 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18686	PG0535	2017-07-21 13:15:00+03	2017-07-21 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-21 13:18:00+03	2017-07-21 14:24:00+03
18687	PG0536	2017-09-08 08:25:00+03	2017-09-08 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18688	PG0536	2017-07-29 08:25:00+03	2017-07-29 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-29 08:27:00+03	2017-07-29 09:33:00+03
18689	PG0535	2017-07-29 13:15:00+03	2017-07-29 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-29 13:17:00+03	2017-07-29 14:22:00+03
18690	PG0535	2017-08-07 13:15:00+03	2017-08-07 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-07 13:19:00+03	2017-08-07 14:24:00+03
18691	PG0536	2017-08-18 08:25:00+03	2017-08-18 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18692	PG0535	2017-08-18 13:15:00+03	2017-08-18 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18693	PG0535	2017-09-08 13:15:00+03	2017-09-08 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18694	PG0535	2017-08-24 13:15:00+03	2017-08-24 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18695	PG0536	2017-07-16 08:25:00+03	2017-07-16 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-16 08:29:00+03	2017-07-16 09:34:00+03
18696	PG0535	2017-08-09 13:15:00+03	2017-08-09 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-09 13:17:00+03	2017-08-09 14:23:00+03
18697	PG0536	2017-08-31 08:25:00+03	2017-08-31 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18698	PG0536	2017-08-23 08:25:00+03	2017-08-23 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18699	PG0536	2017-08-09 08:25:00+03	2017-08-09 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-09 08:27:00+03	2017-08-09 09:33:00+03
18700	PG0536	2017-09-02 08:25:00+03	2017-09-02 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18701	PG0536	2017-09-07 08:25:00+03	2017-09-07 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18702	PG0536	2017-07-17 08:25:00+03	2017-07-17 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-17 08:28:00+03	2017-07-17 09:33:00+03
18703	PG0536	2017-07-20 08:25:00+03	2017-07-20 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-20 08:27:00+03	2017-07-20 09:32:00+03
18704	PG0536	2017-07-22 08:25:00+03	2017-07-22 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-22 11:27:00+03	2017-07-22 12:31:00+03
18705	PG0535	2017-07-22 13:15:00+03	2017-07-22 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-22 13:18:00+03	2017-07-22 14:21:00+03
18706	PG0535	2017-08-04 13:15:00+03	2017-08-04 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-04 13:22:00+03	2017-08-04 14:26:00+03
18707	PG0536	2017-07-24 08:25:00+03	2017-07-24 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-24 08:28:00+03	2017-07-24 09:33:00+03
18708	PG0535	2017-08-13 13:15:00+03	2017-08-13 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-13 13:15:00+03	2017-08-13 14:20:00+03
18709	PG0536	2017-09-06 08:25:00+03	2017-09-06 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18710	PG0535	2017-08-26 13:15:00+03	2017-08-26 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18711	PG0536	2017-08-26 08:25:00+03	2017-08-26 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18712	PG0535	2017-07-24 13:15:00+03	2017-07-24 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-24 13:21:00+03	2017-07-24 14:27:00+03
18713	PG0535	2017-09-05 13:15:00+03	2017-09-05 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18714	PG0535	2017-09-06 13:15:00+03	2017-09-06 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18715	PG0535	2017-07-17 13:15:00+03	2017-07-17 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-17 13:18:00+03	2017-07-17 14:23:00+03
18716	PG0536	2017-08-13 08:25:00+03	2017-08-13 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-13 08:30:00+03	2017-08-13 09:35:00+03
18717	PG0536	2017-09-05 08:25:00+03	2017-09-05 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18718	PG0536	2017-08-24 08:25:00+03	2017-08-24 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18719	PG0535	2017-09-12 13:15:00+03	2017-09-12 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18720	PG0535	2017-08-31 13:15:00+03	2017-08-31 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18721	PG0536	2017-08-10 08:25:00+03	2017-08-10 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-10 08:27:00+03	2017-08-10 09:32:00+03
18722	PG0536	2017-08-11 08:25:00+03	2017-08-11 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-11 08:27:00+03	2017-08-11 09:32:00+03
18723	PG0536	2017-08-06 08:25:00+03	2017-08-06 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-06 08:27:00+03	2017-08-06 09:32:00+03
18724	PG0535	2017-08-06 13:15:00+03	2017-08-06 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-06 13:19:00+03	2017-08-06 14:24:00+03
18725	PG0536	2017-09-13 08:25:00+03	2017-09-13 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18726	PG0535	2017-07-20 13:15:00+03	2017-07-20 14:20:00+03	NUX	NOJ	Cancelled	CN1	2017-07-20 13:17:00+03	2017-07-20 14:21:00+03
18727	PG0535	2017-09-07 13:15:00+03	2017-09-07 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18728	PG0535	2017-08-10 13:15:00+03	2017-08-10 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-10 13:20:00+03	2017-08-10 14:26:00+03
18729	PG0535	2017-09-13 13:15:00+03	2017-09-13 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18730	PG0535	2017-09-11 13:15:00+03	2017-09-11 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18731	PG0536	2017-09-11 08:25:00+03	2017-09-11 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18732	PG0535	2017-08-08 13:15:00+03	2017-08-08 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-08 13:17:00+03	2017-08-08 14:21:00+03
18733	PG0535	2017-09-01 13:15:00+03	2017-09-01 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18734	PG0536	2017-09-01 08:25:00+03	2017-09-01 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18735	PG0536	2017-07-18 08:25:00+03	2017-07-18 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-18 08:26:00+03	2017-07-18 09:31:00+03
18736	PG0536	2017-08-14 08:25:00+03	2017-08-14 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-14 08:29:00+03	2017-08-14 09:35:00+03
18737	PG0535	2017-08-17 13:15:00+03	2017-08-17 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18738	PG0536	2017-08-17 08:25:00+03	2017-08-17 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18739	PG0536	2017-07-21 08:25:00+03	2017-07-21 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-21 08:26:00+03	2017-07-21 09:31:00+03
18740	PG0536	2017-08-22 08:25:00+03	2017-08-22 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18741	PG0535	2017-07-23 13:15:00+03	2017-07-23 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-23 13:20:00+03	2017-07-23 14:25:00+03
18742	PG0535	2017-08-30 13:15:00+03	2017-08-30 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18743	PG0535	2017-07-27 13:15:00+03	2017-07-27 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-27 13:19:00+03	2017-07-27 14:23:00+03
18744	PG0535	2017-08-14 13:15:00+03	2017-08-14 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-08-14 13:16:00+03	2017-08-14 14:20:00+03
18745	PG0535	2017-08-22 13:15:00+03	2017-08-22 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18746	PG0536	2017-07-23 08:25:00+03	2017-07-23 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-07-23 08:30:00+03	2017-07-23 09:34:00+03
18747	PG0536	2017-08-04 08:25:00+03	2017-08-04 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-04 08:31:00+03	2017-08-04 09:35:00+03
18748	PG0535	2017-07-30 13:15:00+03	2017-07-30 14:20:00+03	NUX	NOJ	Arrived	CN1	2017-07-30 13:16:00+03	2017-07-30 14:22:00+03
18749	PG0535	2017-09-10 13:15:00+03	2017-09-10 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18750	PG0536	2017-08-16 08:25:00+03	2017-08-16 09:30:00+03	NUX	NOJ	On Time	CN1	\N	\N
18751	PG0535	2017-08-16 13:15:00+03	2017-08-16 14:20:00+03	NUX	NOJ	On Time	CN1	\N	\N
18752	PG0536	2017-08-12 08:25:00+03	2017-08-12 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-12 08:30:00+03	2017-08-12 09:34:00+03
18753	PG0536	2017-09-10 08:25:00+03	2017-09-10 09:30:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18754	PG0535	2017-08-29 13:15:00+03	2017-08-29 14:20:00+03	NUX	NOJ	Scheduled	CN1	\N	\N
18755	PG0536	2017-08-08 08:25:00+03	2017-08-08 09:30:00+03	NUX	NOJ	Arrived	CN1	2017-08-08 08:28:00+03	2017-08-08 09:32:00+03
18756	PG0633	2017-08-25 13:35:00+03	2017-08-25 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18757	PG0633	2017-09-12 13:35:00+03	2017-09-12 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18758	PG0633	2017-08-21 13:35:00+03	2017-08-21 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18759	PG0633	2017-07-26 13:35:00+03	2017-07-26 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-26 13:38:00+03	2017-07-26 15:02:00+03
18760	PG0633	2017-08-20 13:35:00+03	2017-08-20 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18761	PG0633	2017-09-13 13:35:00+03	2017-09-13 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18762	PG0633	2017-07-27 13:35:00+03	2017-07-27 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-27 13:40:00+03	2017-07-27 15:05:00+03
18763	PG0633	2017-08-07 13:35:00+03	2017-08-07 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-07 13:37:00+03	2017-08-07 15:03:00+03
18764	PG0633	2017-09-07 13:35:00+03	2017-09-07 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18765	PG0633	2017-08-30 13:35:00+03	2017-08-30 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18766	PG0633	2017-07-29 13:35:00+03	2017-07-29 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-29 13:42:00+03	2017-07-29 15:07:00+03
18767	PG0633	2017-09-03 13:35:00+03	2017-09-03 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18768	PG0633	2017-08-28 13:35:00+03	2017-08-28 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18769	PG0633	2017-08-14 13:35:00+03	2017-08-14 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-14 13:36:00+03	2017-08-14 15:03:00+03
18770	PG0633	2017-07-20 13:35:00+03	2017-07-20 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-20 13:37:00+03	2017-07-20 15:04:00+03
18771	PG0633	2017-08-17 13:35:00+03	2017-08-17 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18772	PG0633	2017-07-18 13:35:00+03	2017-07-18 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-18 13:38:00+03	2017-07-18 15:03:00+03
18773	PG0633	2017-08-26 13:35:00+03	2017-08-26 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18774	PG0633	2017-08-12 13:35:00+03	2017-08-12 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-12 13:37:00+03	2017-08-12 15:01:00+03
18775	PG0633	2017-08-01 13:35:00+03	2017-08-01 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-01 13:38:00+03	2017-08-01 15:02:00+03
18776	PG0633	2017-08-09 13:35:00+03	2017-08-09 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-09 13:39:00+03	2017-08-09 15:04:00+03
18777	PG0633	2017-09-14 13:35:00+03	2017-09-14 15:00:00+03	NUX	KGP	Cancelled	CN1	\N	\N
18778	PG0633	2017-08-11 13:35:00+03	2017-08-11 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-11 13:38:00+03	2017-08-11 15:03:00+03
18779	PG0633	2017-08-31 13:35:00+03	2017-08-31 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18780	PG0633	2017-09-06 13:35:00+03	2017-09-06 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18781	PG0633	2017-07-21 13:35:00+03	2017-07-21 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-21 13:38:00+03	2017-07-21 15:03:00+03
18782	PG0633	2017-09-01 13:35:00+03	2017-09-01 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18783	PG0633	2017-07-23 13:35:00+03	2017-07-23 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-23 13:38:00+03	2017-07-23 15:03:00+03
18784	PG0633	2017-08-03 13:35:00+03	2017-08-03 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-03 13:38:00+03	2017-08-03 15:02:00+03
18785	PG0633	2017-07-31 13:35:00+03	2017-07-31 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-31 13:39:00+03	2017-07-31 15:04:00+03
18786	PG0633	2017-09-09 13:35:00+03	2017-09-09 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18787	PG0633	2017-09-02 13:35:00+03	2017-09-02 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18788	PG0633	2017-09-04 13:35:00+03	2017-09-04 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18789	PG0633	2017-08-02 13:35:00+03	2017-08-02 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-02 13:36:00+03	2017-08-02 15:00:00+03
18790	PG0633	2017-08-24 13:35:00+03	2017-08-24 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18791	PG0633	2017-08-29 13:35:00+03	2017-08-29 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18792	PG0633	2017-09-05 13:35:00+03	2017-09-05 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18793	PG0633	2017-07-16 13:35:00+03	2017-07-16 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-16 13:37:00+03	2017-07-16 15:02:00+03
18794	PG0633	2017-08-08 13:35:00+03	2017-08-08 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-08 13:38:00+03	2017-08-08 15:03:00+03
18795	PG0633	2017-08-22 13:35:00+03	2017-08-22 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18796	PG0633	2017-08-05 13:35:00+03	2017-08-05 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-05 13:40:00+03	2017-08-05 15:05:00+03
18797	PG0633	2017-07-24 13:35:00+03	2017-07-24 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-24 13:41:00+03	2017-07-24 15:06:00+03
18798	PG0633	2017-07-30 13:35:00+03	2017-07-30 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-30 13:38:00+03	2017-07-30 15:04:00+03
18799	PG0633	2017-08-16 13:35:00+03	2017-08-16 15:00:00+03	NUX	KGP	On Time	CN1	\N	\N
18800	PG0633	2017-08-15 13:35:00+03	2017-08-15 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-15 13:39:00+03	2017-08-15 15:04:00+03
18801	PG0633	2017-08-10 13:35:00+03	2017-08-10 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-10 13:37:00+03	2017-08-10 15:02:00+03
18802	PG0633	2017-08-13 13:35:00+03	2017-08-13 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-13 13:36:00+03	2017-08-13 15:01:00+03
18803	PG0633	2017-08-27 13:35:00+03	2017-08-27 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18804	PG0633	2017-09-08 13:35:00+03	2017-09-08 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18805	PG0633	2017-08-23 13:35:00+03	2017-08-23 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18806	PG0633	2017-09-11 13:35:00+03	2017-09-11 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18807	PG0633	2017-07-28 13:35:00+03	2017-07-28 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-28 13:40:00+03	2017-07-28 15:05:00+03
18808	PG0633	2017-07-25 13:35:00+03	2017-07-25 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-25 13:37:00+03	2017-07-25 15:02:00+03
18809	PG0633	2017-07-17 13:35:00+03	2017-07-17 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-17 13:38:00+03	2017-07-17 15:03:00+03
18810	PG0633	2017-07-19 13:35:00+03	2017-07-19 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-19 16:33:00+03	2017-07-19 17:57:00+03
18811	PG0633	2017-08-19 13:35:00+03	2017-08-19 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18812	PG0633	2017-07-22 13:35:00+03	2017-07-22 15:00:00+03	NUX	KGP	Arrived	CN1	2017-07-22 13:38:00+03	2017-07-22 15:03:00+03
18813	PG0633	2017-09-10 13:35:00+03	2017-09-10 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18814	PG0633	2017-08-04 13:35:00+03	2017-08-04 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-04 13:36:00+03	2017-08-04 15:01:00+03
18815	PG0633	2017-08-06 13:35:00+03	2017-08-06 15:00:00+03	NUX	KGP	Arrived	CN1	2017-08-06 13:40:00+03	2017-08-06 15:06:00+03
18816	PG0633	2017-08-18 13:35:00+03	2017-08-18 15:00:00+03	NUX	KGP	Scheduled	CN1	\N	\N
18817	PG0263	2017-08-06 16:20:00+03	2017-08-06 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-06 16:24:00+03	2017-08-06 18:35:00+03
18818	PG0264	2017-08-21 13:35:00+03	2017-08-21 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18819	PG0264	2017-08-04 13:35:00+03	2017-08-04 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-04 13:37:00+03	2017-08-04 15:48:00+03
18820	PG0264	2017-07-21 13:35:00+03	2017-07-21 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-21 13:39:00+03	2017-07-21 15:48:00+03
18821	PG0264	2017-09-05 13:35:00+03	2017-09-05 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18822	PG0264	2017-09-11 13:35:00+03	2017-09-11 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18823	PG0263	2017-09-11 16:20:00+03	2017-09-11 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18824	PG0263	2017-09-05 16:20:00+03	2017-09-05 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18825	PG0263	2017-08-29 16:20:00+03	2017-08-29 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18826	PG0264	2017-08-29 13:35:00+03	2017-08-29 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18827	PG0263	2017-07-21 16:20:00+03	2017-07-21 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-21 16:22:00+03	2017-07-21 18:33:00+03
18828	PG0263	2017-07-23 16:20:00+03	2017-07-23 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-23 16:23:00+03	2017-07-23 18:31:00+03
18829	PG0264	2017-07-23 13:35:00+03	2017-07-23 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-23 13:37:00+03	2017-07-23 15:48:00+03
18830	PG0263	2017-08-21 16:20:00+03	2017-08-21 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18831	PG0264	2017-08-17 13:35:00+03	2017-08-17 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18832	PG0263	2017-08-04 16:20:00+03	2017-08-04 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-04 16:25:00+03	2017-08-04 18:35:00+03
18833	PG0263	2017-08-17 16:20:00+03	2017-08-17 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18834	PG0264	2017-08-20 13:35:00+03	2017-08-20 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18835	PG0263	2017-08-20 16:20:00+03	2017-08-20 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18836	PG0264	2017-08-08 13:35:00+03	2017-08-08 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-08 13:40:00+03	2017-08-08 15:50:00+03
18837	PG0264	2017-08-28 13:35:00+03	2017-08-28 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18838	PG0263	2017-08-28 16:20:00+03	2017-08-28 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18839	PG0263	2017-08-15 16:20:00+03	2017-08-15 18:30:00+03	NUX	HMA	Departed	CN1	2017-08-15 16:21:00+03	\N
18840	PG0263	2017-08-08 16:20:00+03	2017-08-08 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-08 16:26:00+03	2017-08-08 18:37:00+03
18841	PG0264	2017-08-15 13:35:00+03	2017-08-15 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-15 13:36:00+03	2017-08-15 15:46:00+03
18842	PG0263	2017-09-10 16:20:00+03	2017-09-10 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18843	PG0263	2017-08-13 16:20:00+03	2017-08-13 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-13 16:24:00+03	2017-08-13 18:32:00+03
18844	PG0263	2017-07-31 16:20:00+03	2017-07-31 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-31 16:22:00+03	2017-07-31 18:30:00+03
18845	PG0264	2017-07-31 13:35:00+03	2017-07-31 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-31 13:40:00+03	2017-07-31 15:52:00+03
18846	PG0264	2017-07-24 13:35:00+03	2017-07-24 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-24 13:44:00+03	2017-07-24 15:53:00+03
18847	PG0263	2017-07-24 16:20:00+03	2017-07-24 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-24 16:21:00+03	2017-07-24 18:31:00+03
18848	PG0264	2017-09-14 13:35:00+03	2017-09-14 15:45:00+03	NUX	HMA	Cancelled	CN1	\N	\N
18849	PG0263	2017-09-03 16:20:00+03	2017-09-03 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18850	PG0264	2017-09-03 13:35:00+03	2017-09-03 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18851	PG0263	2017-08-19 16:20:00+03	2017-08-19 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18852	PG0264	2017-08-19 13:35:00+03	2017-08-19 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18853	PG0263	2017-08-27 16:20:00+03	2017-08-27 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18854	PG0264	2017-09-02 13:35:00+03	2017-09-02 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18855	PG0263	2017-09-02 16:20:00+03	2017-09-02 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18856	PG0263	2017-08-25 16:20:00+03	2017-08-25 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18857	PG0264	2017-08-14 13:35:00+03	2017-08-14 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-14 13:37:00+03	2017-08-14 15:47:00+03
18858	PG0263	2017-08-14 16:20:00+03	2017-08-14 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-14 16:25:00+03	2017-08-14 18:35:00+03
18859	PG0264	2017-08-07 13:35:00+03	2017-08-07 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-07 13:41:00+03	2017-08-07 15:52:00+03
18860	PG0263	2017-08-07 16:20:00+03	2017-08-07 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-07 16:21:00+03	2017-08-07 18:33:00+03
18861	PG0264	2017-08-27 13:35:00+03	2017-08-27 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18862	PG0263	2017-07-25 16:20:00+03	2017-07-25 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-25 16:22:00+03	2017-07-25 18:32:00+03
18863	PG0263	2017-07-22 16:20:00+03	2017-07-22 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-22 16:23:00+03	2017-07-22 18:34:00+03
18864	PG0264	2017-07-22 13:35:00+03	2017-07-22 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-22 13:35:00+03	2017-07-22 15:46:00+03
18865	PG0263	2017-08-01 16:20:00+03	2017-08-01 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-01 16:24:00+03	2017-08-01 18:33:00+03
18866	PG0264	2017-08-01 13:35:00+03	2017-08-01 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-01 13:37:00+03	2017-08-01 15:46:00+03
18867	PG0263	2017-07-26 16:20:00+03	2017-07-26 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-26 19:27:00+03	2017-07-26 21:38:00+03
18868	PG0264	2017-07-26 13:35:00+03	2017-07-26 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-26 13:37:00+03	2017-07-26 15:46:00+03
18869	PG0264	2017-07-29 13:35:00+03	2017-07-29 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-29 13:37:00+03	2017-07-29 15:46:00+03
18870	PG0263	2017-07-29 16:20:00+03	2017-07-29 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-29 16:24:00+03	2017-07-29 18:35:00+03
18871	PG0263	2017-08-23 16:20:00+03	2017-08-23 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18872	PG0264	2017-08-23 13:35:00+03	2017-08-23 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18873	PG0264	2017-09-10 13:35:00+03	2017-09-10 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18874	PG0264	2017-08-13 13:35:00+03	2017-08-13 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-13 13:36:00+03	2017-08-13 15:46:00+03
18875	PG0263	2017-07-17 16:20:00+03	2017-07-17 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-17 20:12:00+03	2017-07-17 22:24:00+03
18876	PG0264	2017-07-17 13:35:00+03	2017-07-17 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-17 13:37:00+03	2017-07-17 15:47:00+03
18877	PG0264	2017-08-18 13:35:00+03	2017-08-18 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18878	PG0263	2017-08-18 16:20:00+03	2017-08-18 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18879	PG0264	2017-08-31 13:35:00+03	2017-08-31 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18880	PG0264	2017-08-26 13:35:00+03	2017-08-26 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18881	PG0263	2017-08-31 16:20:00+03	2017-08-31 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18882	PG0264	2017-07-20 13:35:00+03	2017-07-20 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-20 13:36:00+03	2017-07-20 15:47:00+03
18883	PG0263	2017-07-20 16:20:00+03	2017-07-20 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-20 16:24:00+03	2017-07-20 18:33:00+03
18884	PG0264	2017-08-12 13:35:00+03	2017-08-12 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-12 13:37:00+03	2017-08-12 15:48:00+03
18885	PG0263	2017-08-26 16:20:00+03	2017-08-26 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18886	PG0263	2017-08-09 16:20:00+03	2017-08-09 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-09 16:20:00+03	2017-08-09 18:29:00+03
18887	PG0263	2017-08-16 16:20:00+03	2017-08-16 18:30:00+03	NUX	HMA	On Time	CN1	\N	\N
18888	PG0264	2017-08-16 13:35:00+03	2017-08-16 15:45:00+03	NUX	HMA	On Time	CN1	\N	\N
18889	PG0263	2017-09-08 16:20:00+03	2017-09-08 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18890	PG0264	2017-09-06 13:35:00+03	2017-09-06 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18891	PG0263	2017-09-06 16:20:00+03	2017-09-06 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18892	PG0264	2017-09-08 13:35:00+03	2017-09-08 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18893	PG0263	2017-08-12 16:20:00+03	2017-08-12 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-12 16:25:00+03	2017-08-12 18:34:00+03
18894	PG0264	2017-08-06 13:35:00+03	2017-08-06 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-06 16:10:00+03	2017-08-06 18:20:00+03
18895	PG0264	2017-08-25 13:35:00+03	2017-08-25 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18896	PG0264	2017-09-07 13:35:00+03	2017-09-07 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18897	PG0263	2017-08-02 16:20:00+03	2017-08-02 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-02 16:21:00+03	2017-08-02 18:31:00+03
18898	PG0264	2017-08-02 13:35:00+03	2017-08-02 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-02 17:17:00+03	2017-08-02 19:29:00+03
18899	PG0263	2017-07-30 16:20:00+03	2017-07-30 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-30 16:24:00+03	2017-07-30 18:34:00+03
18900	PG0264	2017-07-25 13:35:00+03	2017-07-25 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-25 13:36:00+03	2017-07-25 15:47:00+03
18901	PG0263	2017-09-04 16:20:00+03	2017-09-04 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18902	PG0264	2017-09-04 13:35:00+03	2017-09-04 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18903	PG0263	2017-09-07 16:20:00+03	2017-09-07 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18904	PG0264	2017-09-09 13:35:00+03	2017-09-09 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18905	PG0263	2017-09-09 16:20:00+03	2017-09-09 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18906	PG0264	2017-07-30 13:35:00+03	2017-07-30 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-30 13:39:00+03	2017-07-30 15:49:00+03
18907	PG0263	2017-07-16 16:20:00+03	2017-07-16 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-16 16:23:00+03	2017-07-16 18:31:00+03
18908	PG0264	2017-08-24 13:35:00+03	2017-08-24 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18909	PG0263	2017-08-24 16:20:00+03	2017-08-24 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18910	PG0263	2017-09-14 16:20:00+03	2017-09-14 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18911	PG0264	2017-08-09 13:35:00+03	2017-08-09 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-09 13:37:00+03	2017-08-09 15:47:00+03
18912	PG0263	2017-08-11 16:20:00+03	2017-08-11 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-11 19:42:00+03	2017-08-11 21:53:00+03
18913	PG0264	2017-08-11 13:35:00+03	2017-08-11 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-11 13:39:00+03	2017-08-11 15:47:00+03
18914	PG0263	2017-09-01 16:20:00+03	2017-09-01 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18915	PG0264	2017-09-01 13:35:00+03	2017-09-01 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18916	PG0263	2017-09-13 16:20:00+03	2017-09-13 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18917	PG0264	2017-09-13 13:35:00+03	2017-09-13 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18918	PG0264	2017-08-30 13:35:00+03	2017-08-30 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18919	PG0263	2017-08-30 16:20:00+03	2017-08-30 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18920	PG0264	2017-08-22 13:35:00+03	2017-08-22 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18921	PG0263	2017-08-22 16:20:00+03	2017-08-22 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18922	PG0263	2017-09-12 16:20:00+03	2017-09-12 18:30:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18923	PG0264	2017-08-05 13:35:00+03	2017-08-05 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-05 13:43:00+03	2017-08-05 15:54:00+03
18924	PG0263	2017-08-05 16:20:00+03	2017-08-05 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-05 16:22:00+03	2017-08-05 18:32:00+03
18925	PG0263	2017-07-18 16:20:00+03	2017-07-18 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-18 16:25:00+03	2017-07-18 18:34:00+03
18926	PG0264	2017-07-18 13:35:00+03	2017-07-18 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-18 13:35:00+03	2017-07-18 15:43:00+03
18927	PG0264	2017-09-12 13:35:00+03	2017-09-12 15:45:00+03	NUX	HMA	Scheduled	CN1	\N	\N
18928	PG0264	2017-07-28 13:35:00+03	2017-07-28 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-28 13:40:00+03	2017-07-28 15:50:00+03
18929	PG0263	2017-07-28 16:20:00+03	2017-07-28 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-28 16:23:00+03	2017-07-28 18:32:00+03
18930	PG0263	2017-07-27 16:20:00+03	2017-07-27 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-27 16:23:00+03	2017-07-27 18:31:00+03
18931	PG0264	2017-07-27 13:35:00+03	2017-07-27 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-27 13:38:00+03	2017-07-27 15:48:00+03
18932	PG0264	2017-07-19 13:35:00+03	2017-07-19 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-19 13:35:00+03	2017-07-19 15:45:00+03
18933	PG0264	2017-07-16 13:35:00+03	2017-07-16 15:45:00+03	NUX	HMA	Arrived	CN1	2017-07-16 13:38:00+03	2017-07-16 15:48:00+03
18934	PG0263	2017-07-19 16:20:00+03	2017-07-19 18:30:00+03	NUX	HMA	Arrived	CN1	2017-07-19 20:17:00+03	2017-07-19 22:28:00+03
18935	PG0263	2017-08-03 16:20:00+03	2017-08-03 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-03 16:22:00+03	2017-08-03 18:33:00+03
18936	PG0264	2017-08-03 13:35:00+03	2017-08-03 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-03 13:37:00+03	2017-08-03 15:47:00+03
18937	PG0264	2017-08-10 13:35:00+03	2017-08-10 15:45:00+03	NUX	HMA	Arrived	CN1	2017-08-10 13:38:00+03	2017-08-10 15:47:00+03
18938	PG0263	2017-08-10 16:20:00+03	2017-08-10 18:30:00+03	NUX	HMA	Arrived	CN1	2017-08-10 16:23:00+03	2017-08-10 18:33:00+03
18939	PG0275	2017-07-29 07:50:00+03	2017-07-29 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-29 07:52:00+03	2017-07-29 11:32:00+03
18940	PG0275	2017-07-19 07:50:00+03	2017-07-19 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-19 07:52:00+03	2017-07-19 11:30:00+03
18941	PG0275	2017-08-11 07:50:00+03	2017-08-11 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-11 07:54:00+03	2017-08-11 11:30:00+03
18942	PG0275	2017-07-30 07:50:00+03	2017-07-30 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-30 07:52:00+03	2017-07-30 11:33:00+03
18943	PG0275	2017-08-19 07:50:00+03	2017-08-19 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18944	PG0275	2017-09-12 07:50:00+03	2017-09-12 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18945	PG0275	2017-09-02 07:50:00+03	2017-09-02 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18946	PG0275	2017-08-12 07:50:00+03	2017-08-12 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-12 07:52:00+03	2017-08-12 11:32:00+03
18947	PG0275	2017-09-13 07:50:00+03	2017-09-13 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18948	PG0275	2017-08-28 07:50:00+03	2017-08-28 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18949	PG0275	2017-08-02 07:50:00+03	2017-08-02 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-02 07:54:00+03	2017-08-02 11:36:00+03
18950	PG0275	2017-08-22 07:50:00+03	2017-08-22 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18951	PG0275	2017-08-07 07:50:00+03	2017-08-07 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-07 07:54:00+03	2017-08-07 11:34:00+03
18952	PG0275	2017-08-31 07:50:00+03	2017-08-31 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18953	PG0275	2017-09-01 07:50:00+03	2017-09-01 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18954	PG0275	2017-07-31 07:50:00+03	2017-07-31 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-31 07:53:00+03	2017-07-31 11:34:00+03
18955	PG0275	2017-08-20 07:50:00+03	2017-08-20 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18956	PG0275	2017-08-26 07:50:00+03	2017-08-26 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18957	PG0275	2017-07-16 07:50:00+03	2017-07-16 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-16 07:53:00+03	2017-07-16 11:32:00+03
18958	PG0275	2017-08-15 07:50:00+03	2017-08-15 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-15 07:59:00+03	2017-08-15 11:42:00+03
18959	PG0275	2017-08-05 07:50:00+03	2017-08-05 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-05 07:51:00+03	2017-08-05 11:29:00+03
18960	PG0275	2017-07-18 07:50:00+03	2017-07-18 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-18 07:52:00+03	2017-07-18 11:33:00+03
18961	PG0275	2017-08-13 07:50:00+03	2017-08-13 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-13 07:54:00+03	2017-08-13 11:32:00+03
18962	PG0275	2017-09-05 07:50:00+03	2017-09-05 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18963	PG0275	2017-08-25 07:50:00+03	2017-08-25 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18964	PG0275	2017-08-03 07:50:00+03	2017-08-03 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-03 07:51:00+03	2017-08-03 11:28:00+03
18965	PG0275	2017-08-06 07:50:00+03	2017-08-06 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-06 07:53:00+03	2017-08-06 11:33:00+03
18966	PG0275	2017-08-29 07:50:00+03	2017-08-29 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18967	PG0275	2017-09-10 07:50:00+03	2017-09-10 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18968	PG0275	2017-08-04 07:50:00+03	2017-08-04 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-04 07:51:00+03	2017-08-04 11:26:00+03
18969	PG0275	2017-09-07 07:50:00+03	2017-09-07 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18970	PG0275	2017-09-04 07:50:00+03	2017-09-04 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18971	PG0275	2017-08-14 07:50:00+03	2017-08-14 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-14 07:53:00+03	2017-08-14 11:30:00+03
18972	PG0275	2017-09-08 07:50:00+03	2017-09-08 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18973	PG0275	2017-07-22 07:50:00+03	2017-07-22 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-22 07:52:00+03	2017-07-22 11:31:00+03
18974	PG0275	2017-09-09 07:50:00+03	2017-09-09 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18975	PG0275	2017-08-08 07:50:00+03	2017-08-08 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-08 07:52:00+03	2017-08-08 11:33:00+03
18976	PG0275	2017-09-03 07:50:00+03	2017-09-03 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18977	PG0275	2017-08-30 07:50:00+03	2017-08-30 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18978	PG0275	2017-08-24 07:50:00+03	2017-08-24 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18979	PG0275	2017-08-17 07:50:00+03	2017-08-17 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18980	PG0275	2017-08-16 07:50:00+03	2017-08-16 11:30:00+03	NUX	HTA	On Time	CR2	\N	\N
18981	PG0275	2017-09-06 07:50:00+03	2017-09-06 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18982	PG0275	2017-07-21 07:50:00+03	2017-07-21 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-21 07:53:00+03	2017-07-21 11:35:00+03
18983	PG0275	2017-07-26 07:50:00+03	2017-07-26 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-26 07:53:00+03	2017-07-26 11:34:00+03
18984	PG0275	2017-07-28 07:50:00+03	2017-07-28 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-28 07:51:00+03	2017-07-28 11:27:00+03
18985	PG0275	2017-07-20 07:50:00+03	2017-07-20 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-20 07:53:00+03	2017-07-20 11:35:00+03
18986	PG0275	2017-08-09 07:50:00+03	2017-08-09 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-09 07:52:00+03	2017-08-09 11:31:00+03
18987	PG0275	2017-07-23 07:50:00+03	2017-07-23 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-23 07:54:00+03	2017-07-23 11:32:00+03
18988	PG0275	2017-08-18 07:50:00+03	2017-08-18 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18989	PG0275	2017-07-17 07:50:00+03	2017-07-17 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-17 07:54:00+03	2017-07-17 11:31:00+03
18990	PG0275	2017-08-21 07:50:00+03	2017-08-21 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18991	PG0275	2017-07-27 07:50:00+03	2017-07-27 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-27 07:54:00+03	2017-07-27 11:31:00+03
18992	PG0275	2017-08-27 07:50:00+03	2017-08-27 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18993	PG0275	2017-09-14 07:50:00+03	2017-09-14 11:30:00+03	NUX	HTA	Cancelled	CR2	\N	\N
18994	PG0275	2017-08-23 07:50:00+03	2017-08-23 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18995	PG0275	2017-07-24 07:50:00+03	2017-07-24 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-24 07:53:00+03	2017-07-24 11:32:00+03
18996	PG0275	2017-09-11 07:50:00+03	2017-09-11 11:30:00+03	NUX	HTA	Scheduled	CR2	\N	\N
18997	PG0275	2017-08-10 07:50:00+03	2017-08-10 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-10 07:53:00+03	2017-08-10 11:31:00+03
18998	PG0275	2017-08-01 07:50:00+03	2017-08-01 11:30:00+03	NUX	HTA	Arrived	CR2	2017-08-01 07:51:00+03	2017-08-01 11:32:00+03
18999	PG0275	2017-07-25 07:50:00+03	2017-07-25 11:30:00+03	NUX	HTA	Arrived	CR2	2017-07-25 07:50:00+03	2017-07-25 11:28:00+03
19000	PG0435	2017-07-29 13:35:00+03	2017-07-29 16:45:00+03	KYZ	SVX	Arrived	CR2	2017-07-29 13:38:00+03	2017-07-29 16:48:00+03
19001	PG0435	2017-08-05 13:35:00+03	2017-08-05 16:45:00+03	KYZ	SVX	Arrived	CR2	2017-08-05 13:37:00+03	2017-08-05 16:51:00+03
19002	PG0435	2017-08-26 13:35:00+03	2017-08-26 16:45:00+03	KYZ	SVX	Scheduled	CR2	\N	\N
19003	PG0435	2017-08-19 13:35:00+03	2017-08-19 16:45:00+03	KYZ	SVX	Scheduled	CR2	\N	\N
19004	PG0435	2017-07-22 13:35:00+03	2017-07-22 16:45:00+03	KYZ	SVX	Arrived	CR2	2017-07-22 13:39:00+03	2017-07-22 16:51:00+03
19005	PG0435	2017-08-12 13:35:00+03	2017-08-12 16:45:00+03	KYZ	SVX	Arrived	CR2	2017-08-12 13:36:00+03	2017-08-12 16:43:00+03
19006	PG0435	2017-09-09 13:35:00+03	2017-09-09 16:45:00+03	KYZ	SVX	Scheduled	CR2	\N	\N
19007	PG0435	2017-09-02 13:35:00+03	2017-09-02 16:45:00+03	KYZ	SVX	Scheduled	CR2	\N	\N
19008	PG0314	2017-08-14 05:50:00+03	2017-08-14 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-08-14 05:51:00+03	2017-08-14 06:51:00+03
19009	PG0314	2017-08-07 05:50:00+03	2017-08-07 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-08-07 05:54:00+03	2017-08-07 06:54:00+03
19010	PG0314	2017-08-24 05:50:00+03	2017-08-24 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19011	PG0314	2017-09-07 05:50:00+03	2017-09-07 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19012	PG0314	2017-09-11 05:50:00+03	2017-09-11 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19013	PG0314	2017-09-04 05:50:00+03	2017-09-04 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19014	PG0314	2017-07-31 05:50:00+03	2017-07-31 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-07-31 05:53:00+03	2017-07-31 06:53:00+03
19015	PG0314	2017-07-27 05:50:00+03	2017-07-27 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-07-27 05:52:00+03	2017-07-27 06:51:00+03
19016	PG0314	2017-08-10 05:50:00+03	2017-08-10 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-08-10 08:26:00+03	2017-08-10 09:26:00+03
19017	PG0314	2017-09-14 05:50:00+03	2017-09-14 06:50:00+03	KYZ	ABA	Cancelled	CN1	\N	\N
19018	PG0314	2017-08-17 05:50:00+03	2017-08-17 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19019	PG0314	2017-07-24 05:50:00+03	2017-07-24 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-07-24 05:53:00+03	2017-07-24 06:54:00+03
19020	PG0314	2017-08-03 05:50:00+03	2017-08-03 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-08-03 05:56:00+03	2017-08-03 06:57:00+03
19021	PG0314	2017-07-17 05:50:00+03	2017-07-17 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-07-17 05:54:00+03	2017-07-17 06:55:00+03
19022	PG0314	2017-07-20 05:50:00+03	2017-07-20 06:50:00+03	KYZ	ABA	Arrived	CN1	2017-07-20 05:52:00+03	2017-07-20 06:52:00+03
19023	PG0314	2017-08-21 05:50:00+03	2017-08-21 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19024	PG0314	2017-08-31 05:50:00+03	2017-08-31 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19025	PG0314	2017-08-28 05:50:00+03	2017-08-28 06:50:00+03	KYZ	ABA	Scheduled	CN1	\N	\N
19026	PG0081	2017-08-29 08:40:00+03	2017-08-29 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19027	PG0081	2017-08-26 08:40:00+03	2017-08-26 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19028	PG0081	2017-09-09 08:40:00+03	2017-09-09 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19029	PG0081	2017-08-15 08:40:00+03	2017-08-15 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-08-15 08:43:00+03	2017-08-15 10:58:00+03
19030	PG0081	2017-07-22 08:40:00+03	2017-07-22 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-07-22 08:43:00+03	2017-07-22 10:57:00+03
19031	PG0081	2017-07-25 08:40:00+03	2017-07-25 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-07-25 08:45:00+03	2017-07-25 11:02:00+03
19032	PG0081	2017-09-05 08:40:00+03	2017-09-05 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19033	PG0081	2017-08-22 08:40:00+03	2017-08-22 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19034	PG0081	2017-08-08 08:40:00+03	2017-08-08 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-08-08 08:44:00+03	2017-08-08 10:58:00+03
19035	PG0081	2017-09-12 08:40:00+03	2017-09-12 10:55:00+03	KYZ	KEJ	Cancelled	CN1	\N	\N
19036	PG0081	2017-07-29 08:40:00+03	2017-07-29 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-07-29 08:43:00+03	2017-07-29 10:58:00+03
19037	PG0081	2017-08-12 08:40:00+03	2017-08-12 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-08-12 08:41:00+03	2017-08-12 10:56:00+03
19038	PG0081	2017-08-05 08:40:00+03	2017-08-05 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-08-05 08:44:00+03	2017-08-05 10:58:00+03
19039	PG0081	2017-08-01 08:40:00+03	2017-08-01 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-08-01 08:43:00+03	2017-08-01 11:01:00+03
19040	PG0081	2017-08-19 08:40:00+03	2017-08-19 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19041	PG0081	2017-09-02 08:40:00+03	2017-09-02 10:55:00+03	KYZ	KEJ	Scheduled	CN1	\N	\N
19042	PG0081	2017-07-18 08:40:00+03	2017-07-18 10:55:00+03	KYZ	KEJ	Arrived	CN1	2017-07-18 08:42:00+03	2017-07-18 10:56:00+03
19043	PG0270	2017-09-02 15:50:00+03	2017-09-02 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19044	PG0270	2017-07-22 15:50:00+03	2017-07-22 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-22 15:51:00+03	2017-07-22 19:07:00+03
19045	PG0270	2017-09-05 15:50:00+03	2017-09-05 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19046	PG0270	2017-08-08 15:50:00+03	2017-08-08 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-08 15:52:00+03	2017-08-08 19:09:00+03
19047	PG0270	2017-07-25 15:50:00+03	2017-07-25 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-25 15:54:00+03	2017-07-25 19:09:00+03
19048	PG0270	2017-08-05 15:50:00+03	2017-08-05 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-05 15:57:00+03	2017-08-05 19:12:00+03
19049	PG0270	2017-08-29 15:50:00+03	2017-08-29 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19050	PG0270	2017-08-10 15:50:00+03	2017-08-10 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-10 15:52:00+03	2017-08-10 19:07:00+03
19051	PG0270	2017-07-20 15:50:00+03	2017-07-20 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-20 15:54:00+03	2017-07-20 19:07:00+03
19052	PG0270	2017-08-17 15:50:00+03	2017-08-17 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19053	PG0270	2017-09-12 15:50:00+03	2017-09-12 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19054	PG0270	2017-09-14 15:50:00+03	2017-09-14 19:05:00+03	NOJ	VKO	Cancelled	CR2	\N	\N
19055	PG0270	2017-08-24 15:50:00+03	2017-08-24 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19056	PG0270	2017-08-26 15:50:00+03	2017-08-26 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19057	PG0270	2017-09-07 15:50:00+03	2017-09-07 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19058	PG0270	2017-07-27 15:50:00+03	2017-07-27 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-27 15:55:00+03	2017-07-27 19:08:00+03
19059	PG0270	2017-07-18 15:50:00+03	2017-07-18 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-18 15:52:00+03	2017-07-18 19:09:00+03
19060	PG0270	2017-09-09 15:50:00+03	2017-09-09 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19061	PG0270	2017-08-15 15:50:00+03	2017-08-15 19:05:00+03	NOJ	VKO	Departed	CR2	2017-08-15 15:52:00+03	\N
19062	PG0270	2017-08-12 15:50:00+03	2017-08-12 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-12 15:55:00+03	2017-08-12 19:15:00+03
19063	PG0270	2017-07-29 15:50:00+03	2017-07-29 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-07-29 15:50:00+03	2017-07-29 19:05:00+03
19064	PG0270	2017-08-03 15:50:00+03	2017-08-03 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-03 15:53:00+03	2017-08-03 19:06:00+03
19065	PG0270	2017-08-19 15:50:00+03	2017-08-19 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19066	PG0270	2017-08-31 15:50:00+03	2017-08-31 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19067	PG0270	2017-08-01 15:50:00+03	2017-08-01 19:05:00+03	NOJ	VKO	Arrived	CR2	2017-08-01 15:52:00+03	2017-08-01 19:06:00+03
19068	PG0270	2017-08-22 15:50:00+03	2017-08-22 19:05:00+03	NOJ	VKO	Scheduled	CR2	\N	\N
19069	PG0662	2017-08-24 14:40:00+03	2017-08-24 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19070	PG0662	2017-07-16 14:40:00+03	2017-07-16 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-07-16 14:45:00+03	2017-07-16 17:56:00+03
19071	PG0662	2017-09-10 14:40:00+03	2017-09-10 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19072	PG0662	2017-09-14 14:40:00+03	2017-09-14 17:50:00+03	NOJ	SVO	Cancelled	CR2	\N	\N
19073	PG0662	2017-08-17 14:40:00+03	2017-08-17 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19074	PG0662	2017-08-20 14:40:00+03	2017-08-20 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19075	PG0662	2017-08-03 14:40:00+03	2017-08-03 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-08-03 14:42:00+03	2017-08-03 17:51:00+03
19076	PG0662	2017-09-07 14:40:00+03	2017-09-07 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19077	PG0662	2017-07-20 14:40:00+03	2017-07-20 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-07-20 14:44:00+03	2017-07-20 17:54:00+03
19078	PG0662	2017-08-10 14:40:00+03	2017-08-10 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-08-10 14:41:00+03	2017-08-10 17:50:00+03
19079	PG0662	2017-08-06 14:40:00+03	2017-08-06 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-08-06 14:43:00+03	2017-08-06 17:51:00+03
19080	PG0662	2017-09-03 14:40:00+03	2017-09-03 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19081	PG0662	2017-07-27 14:40:00+03	2017-07-27 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-07-27 14:41:00+03	2017-07-27 17:49:00+03
19082	PG0662	2017-07-30 14:40:00+03	2017-07-30 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-07-30 14:42:00+03	2017-07-30 17:51:00+03
19083	PG0662	2017-07-23 14:40:00+03	2017-07-23 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-07-23 14:44:00+03	2017-07-23 17:52:00+03
19084	PG0662	2017-08-27 14:40:00+03	2017-08-27 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19085	PG0662	2017-08-13 14:40:00+03	2017-08-13 17:50:00+03	NOJ	SVO	Arrived	CR2	2017-08-13 14:43:00+03	2017-08-13 17:53:00+03
19086	PG0662	2017-08-31 14:40:00+03	2017-08-31 17:50:00+03	NOJ	SVO	Scheduled	CR2	\N	\N
19087	PG0042	2017-08-03 09:30:00+03	2017-08-03 12:50:00+03	NOJ	LED	Arrived	CR2	2017-08-03 09:32:00+03	2017-08-03 12:51:00+03
19088	PG0042	2017-08-17 09:30:00+03	2017-08-17 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19089	PG0042	2017-08-24 09:30:00+03	2017-08-24 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19090	PG0042	2017-07-20 09:30:00+03	2017-07-20 12:50:00+03	NOJ	LED	Arrived	CR2	2017-07-20 09:32:00+03	2017-07-20 12:53:00+03
19091	PG0042	2017-08-31 09:30:00+03	2017-08-31 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19092	PG0042	2017-07-16 09:30:00+03	2017-07-16 12:50:00+03	NOJ	LED	Arrived	CR2	2017-07-16 09:31:00+03	2017-07-16 12:49:00+03
19093	PG0042	2017-08-20 09:30:00+03	2017-08-20 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19094	PG0042	2017-08-06 09:30:00+03	2017-08-06 12:50:00+03	NOJ	LED	Arrived	CR2	2017-08-06 09:33:00+03	2017-08-06 12:53:00+03
19095	PG0042	2017-07-30 09:30:00+03	2017-07-30 12:50:00+03	NOJ	LED	Arrived	CR2	2017-07-30 09:34:00+03	2017-07-30 12:55:00+03
19096	PG0042	2017-09-07 09:30:00+03	2017-09-07 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19097	PG0042	2017-08-13 09:30:00+03	2017-08-13 12:50:00+03	NOJ	LED	Arrived	CR2	2017-08-13 09:33:00+03	2017-08-13 12:49:00+03
19098	PG0042	2017-09-14 09:30:00+03	2017-09-14 12:50:00+03	NOJ	LED	Cancelled	CR2	\N	\N
19099	PG0042	2017-07-27 09:30:00+03	2017-07-27 12:50:00+03	NOJ	LED	Arrived	CR2	2017-07-27 09:36:00+03	2017-07-27 12:54:00+03
19100	PG0042	2017-08-10 09:30:00+03	2017-08-10 12:50:00+03	NOJ	LED	Arrived	CR2	2017-08-10 09:34:00+03	2017-08-10 12:51:00+03
19101	PG0042	2017-07-23 09:30:00+03	2017-07-23 12:50:00+03	NOJ	LED	Arrived	CR2	2017-07-23 09:32:00+03	2017-07-23 12:53:00+03
19102	PG0042	2017-08-27 09:30:00+03	2017-08-27 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19103	PG0042	2017-09-03 09:30:00+03	2017-09-03 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19104	PG0042	2017-09-10 09:30:00+03	2017-09-10 12:50:00+03	NOJ	LED	Scheduled	CR2	\N	\N
19105	PG0537	2017-08-15 14:00:00+03	2017-08-15 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-15 14:03:00+03	2017-08-15 15:08:00+03
19106	PG0537	2017-07-30 14:00:00+03	2017-07-30 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-30 14:04:00+03	2017-07-30 15:09:00+03
19107	PG0538	2017-07-30 11:40:00+03	2017-07-30 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-30 11:45:00+03	2017-07-30 12:50:00+03
19108	PG0537	2017-07-24 14:00:00+03	2017-07-24 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-24 14:02:00+03	2017-07-24 15:08:00+03
19109	PG0537	2017-09-07 14:00:00+03	2017-09-07 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19110	PG0538	2017-09-07 11:40:00+03	2017-09-07 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19111	PG0538	2017-08-22 11:40:00+03	2017-08-22 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19112	PG0537	2017-08-22 14:00:00+03	2017-08-22 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19113	PG0537	2017-09-01 14:00:00+03	2017-09-01 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19114	PG0538	2017-09-01 11:40:00+03	2017-09-01 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19115	PG0537	2017-07-31 14:00:00+03	2017-07-31 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-31 14:03:00+03	2017-07-31 15:08:00+03
19116	PG0537	2017-08-28 14:00:00+03	2017-08-28 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19117	PG0538	2017-07-31 11:40:00+03	2017-07-31 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-31 11:42:00+03	2017-07-31 12:48:00+03
19118	PG0538	2017-07-29 11:40:00+03	2017-07-29 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-29 11:43:00+03	2017-07-29 12:49:00+03
19119	PG0538	2017-08-28 11:40:00+03	2017-08-28 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19120	PG0537	2017-07-29 14:00:00+03	2017-07-29 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-29 14:04:00+03	2017-07-29 15:09:00+03
19121	PG0538	2017-08-18 11:40:00+03	2017-08-18 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19122	PG0537	2017-08-18 14:00:00+03	2017-08-18 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19123	PG0538	2017-07-20 11:40:00+03	2017-07-20 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-20 11:41:00+03	2017-07-20 12:45:00+03
19124	PG0537	2017-07-20 14:00:00+03	2017-07-20 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-20 14:04:00+03	2017-07-20 15:09:00+03
19125	PG0538	2017-09-06 11:40:00+03	2017-09-06 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19126	PG0537	2017-09-06 14:00:00+03	2017-09-06 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19127	PG0537	2017-08-26 14:00:00+03	2017-08-26 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19128	PG0538	2017-08-26 11:40:00+03	2017-08-26 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19129	PG0537	2017-09-12 14:00:00+03	2017-09-12 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19130	PG0538	2017-09-12 11:40:00+03	2017-09-12 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19131	PG0538	2017-07-24 11:40:00+03	2017-07-24 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-24 11:44:00+03	2017-07-24 12:49:00+03
19132	PG0537	2017-08-19 14:00:00+03	2017-08-19 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19133	PG0538	2017-08-19 11:40:00+03	2017-08-19 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19134	PG0538	2017-08-10 11:40:00+03	2017-08-10 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-10 11:45:00+03	2017-08-10 12:51:00+03
19135	PG0537	2017-08-10 14:00:00+03	2017-08-10 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-10 14:05:00+03	2017-08-10 15:10:00+03
19136	PG0538	2017-09-11 11:40:00+03	2017-09-11 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19137	PG0537	2017-09-11 14:00:00+03	2017-09-11 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19138	PG0537	2017-08-01 14:00:00+03	2017-08-01 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-01 14:04:00+03	2017-08-01 15:09:00+03
19139	PG0538	2017-08-01 11:40:00+03	2017-08-01 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-01 11:44:00+03	2017-08-01 12:50:00+03
19140	PG0538	2017-08-08 11:40:00+03	2017-08-08 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-08 11:44:00+03	2017-08-08 12:49:00+03
19141	PG0538	2017-08-13 11:40:00+03	2017-08-13 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-13 11:40:00+03	2017-08-13 12:46:00+03
19142	PG0537	2017-08-13 14:00:00+03	2017-08-13 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-13 14:03:00+03	2017-08-13 15:08:00+03
19143	PG0537	2017-07-22 14:00:00+03	2017-07-22 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-22 14:03:00+03	2017-07-22 15:08:00+03
19144	PG0538	2017-07-22 11:40:00+03	2017-07-22 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-22 11:40:00+03	2017-07-22 12:45:00+03
19145	PG0538	2017-07-28 11:40:00+03	2017-07-28 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-28 11:42:00+03	2017-07-28 12:46:00+03
19146	PG0537	2017-07-28 14:00:00+03	2017-07-28 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-28 14:04:00+03	2017-07-28 15:10:00+03
19147	PG0538	2017-07-19 11:40:00+03	2017-07-19 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-19 11:43:00+03	2017-07-19 12:49:00+03
19148	PG0537	2017-07-19 14:00:00+03	2017-07-19 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-19 14:06:00+03	2017-07-19 15:10:00+03
19149	PG0538	2017-09-14 11:40:00+03	2017-09-14 12:45:00+03	NOJ	NUX	Cancelled	CN1	\N	\N
19150	PG0537	2017-08-02 14:00:00+03	2017-08-02 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-02 14:05:00+03	2017-08-02 15:11:00+03
19151	PG0538	2017-08-02 11:40:00+03	2017-08-02 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-02 11:44:00+03	2017-08-02 12:49:00+03
19152	PG0537	2017-08-08 14:00:00+03	2017-08-08 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-08 14:01:00+03	2017-08-08 15:05:00+03
19153	PG0537	2017-08-12 14:00:00+03	2017-08-12 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-12 14:03:00+03	2017-08-12 15:08:00+03
19154	PG0538	2017-08-17 11:40:00+03	2017-08-17 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19155	PG0537	2017-08-17 14:00:00+03	2017-08-17 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19156	PG0538	2017-08-12 11:40:00+03	2017-08-12 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-12 11:45:00+03	2017-08-12 12:51:00+03
19157	PG0538	2017-09-05 11:40:00+03	2017-09-05 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19158	PG0537	2017-09-05 14:00:00+03	2017-09-05 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19159	PG0537	2017-08-23 14:00:00+03	2017-08-23 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19160	PG0538	2017-08-23 11:40:00+03	2017-08-23 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19161	PG0537	2017-09-08 14:00:00+03	2017-09-08 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19162	PG0538	2017-09-08 11:40:00+03	2017-09-08 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19163	PG0537	2017-08-03 14:00:00+03	2017-08-03 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-03 14:01:00+03	2017-08-03 15:07:00+03
19164	PG0538	2017-08-03 11:40:00+03	2017-08-03 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-03 11:44:00+03	2017-08-03 12:49:00+03
19165	PG0538	2017-08-31 11:40:00+03	2017-08-31 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19166	PG0537	2017-08-31 14:00:00+03	2017-08-31 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19167	PG0537	2017-09-13 14:00:00+03	2017-09-13 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19168	PG0538	2017-09-13 11:40:00+03	2017-09-13 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19169	PG0538	2017-07-27 11:40:00+03	2017-07-27 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-27 11:49:00+03	2017-07-27 12:55:00+03
19170	PG0537	2017-07-27 14:00:00+03	2017-07-27 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-27 14:02:00+03	2017-07-27 15:06:00+03
19171	PG0537	2017-08-14 14:00:00+03	2017-08-14 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-14 14:04:00+03	2017-08-14 15:09:00+03
19172	PG0538	2017-07-18 11:40:00+03	2017-07-18 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-18 14:53:00+03	2017-07-18 15:58:00+03
19173	PG0538	2017-08-14 11:40:00+03	2017-08-14 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-14 11:43:00+03	2017-08-14 12:49:00+03
19174	PG0537	2017-07-18 14:00:00+03	2017-07-18 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-18 14:03:00+03	2017-07-18 15:08:00+03
19175	PG0537	2017-08-04 14:00:00+03	2017-08-04 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-04 14:01:00+03	2017-08-04 15:06:00+03
19176	PG0538	2017-08-30 11:40:00+03	2017-08-30 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19177	PG0538	2017-08-04 11:40:00+03	2017-08-04 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-04 11:42:00+03	2017-08-04 12:49:00+03
19178	PG0537	2017-08-30 14:00:00+03	2017-08-30 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19179	PG0538	2017-09-02 11:40:00+03	2017-09-02 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19180	PG0537	2017-09-02 14:00:00+03	2017-09-02 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19181	PG0538	2017-09-04 11:40:00+03	2017-09-04 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19182	PG0537	2017-09-04 14:00:00+03	2017-09-04 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19183	PG0537	2017-07-23 14:00:00+03	2017-07-23 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-23 14:02:00+03	2017-07-23 15:07:00+03
19184	PG0538	2017-07-23 11:40:00+03	2017-07-23 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-23 11:43:00+03	2017-07-23 12:48:00+03
19185	PG0538	2017-08-16 11:40:00+03	2017-08-16 12:45:00+03	NOJ	NUX	On Time	CN1	\N	\N
19186	PG0537	2017-08-16 14:00:00+03	2017-08-16 15:05:00+03	NOJ	NUX	On Time	CN1	\N	\N
19187	PG0538	2017-08-27 11:40:00+03	2017-08-27 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19188	PG0537	2017-08-29 14:00:00+03	2017-08-29 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19189	PG0537	2017-08-27 14:00:00+03	2017-08-27 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19190	PG0538	2017-08-29 11:40:00+03	2017-08-29 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19191	PG0537	2017-08-05 14:00:00+03	2017-08-05 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-05 14:00:00+03	2017-08-05 15:05:00+03
19192	PG0538	2017-08-05 11:40:00+03	2017-08-05 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-05 11:43:00+03	2017-08-05 12:47:00+03
19193	PG0538	2017-07-17 11:40:00+03	2017-07-17 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-17 11:44:00+03	2017-07-17 12:49:00+03
19194	PG0537	2017-07-17 14:00:00+03	2017-07-17 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-17 14:01:00+03	2017-07-17 15:06:00+03
19195	PG0537	2017-08-20 14:00:00+03	2017-08-20 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19196	PG0538	2017-08-20 11:40:00+03	2017-08-20 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19197	PG0537	2017-09-14 14:00:00+03	2017-09-14 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19198	PG0538	2017-08-25 11:40:00+03	2017-08-25 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19199	PG0537	2017-08-25 14:00:00+03	2017-08-25 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19200	PG0538	2017-07-26 11:40:00+03	2017-07-26 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-26 11:44:00+03	2017-07-26 12:49:00+03
19201	PG0537	2017-07-26 14:00:00+03	2017-07-26 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-26 14:03:00+03	2017-07-26 15:08:00+03
19202	PG0537	2017-08-11 14:00:00+03	2017-08-11 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-11 14:07:00+03	2017-08-11 15:12:00+03
19203	PG0538	2017-08-11 11:40:00+03	2017-08-11 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-11 11:44:00+03	2017-08-11 12:49:00+03
19204	PG0537	2017-08-06 14:00:00+03	2017-08-06 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-06 14:05:00+03	2017-08-06 15:11:00+03
19205	PG0538	2017-08-06 11:40:00+03	2017-08-06 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-06 11:42:00+03	2017-08-06 12:47:00+03
19206	PG0537	2017-09-09 14:00:00+03	2017-09-09 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19207	PG0538	2017-09-09 11:40:00+03	2017-09-09 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19208	PG0538	2017-09-03 11:40:00+03	2017-09-03 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19209	PG0537	2017-09-03 14:00:00+03	2017-09-03 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19210	PG0537	2017-08-24 14:00:00+03	2017-08-24 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19211	PG0538	2017-08-24 11:40:00+03	2017-08-24 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19212	PG0538	2017-08-09 11:40:00+03	2017-08-09 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-09 11:43:00+03	2017-08-09 12:47:00+03
19213	PG0537	2017-08-09 14:00:00+03	2017-08-09 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-09 14:03:00+03	2017-08-09 15:08:00+03
19214	PG0538	2017-07-16 11:40:00+03	2017-07-16 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-16 11:43:00+03	2017-07-16 12:48:00+03
19215	PG0537	2017-07-16 14:00:00+03	2017-07-16 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-16 17:56:00+03	2017-07-16 19:02:00+03
19216	PG0537	2017-08-07 14:00:00+03	2017-08-07 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-08-07 14:02:00+03	2017-08-07 15:07:00+03
19217	PG0538	2017-08-07 11:40:00+03	2017-08-07 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-07 11:43:00+03	2017-08-07 12:48:00+03
19218	PG0538	2017-08-15 11:40:00+03	2017-08-15 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-08-15 14:47:00+03	2017-08-15 15:53:00+03
19219	PG0538	2017-08-21 11:40:00+03	2017-08-21 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19220	PG0537	2017-08-21 14:00:00+03	2017-08-21 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19221	PG0538	2017-09-10 11:40:00+03	2017-09-10 12:45:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19222	PG0537	2017-09-10 14:00:00+03	2017-09-10 15:05:00+03	NOJ	NUX	Scheduled	CN1	\N	\N
19223	PG0538	2017-07-25 11:40:00+03	2017-07-25 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-25 11:42:00+03	2017-07-25 12:47:00+03
19224	PG0537	2017-07-25 14:00:00+03	2017-07-25 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-25 14:02:00+03	2017-07-25 15:06:00+03
19225	PG0538	2017-07-21 11:40:00+03	2017-07-21 12:45:00+03	NOJ	NUX	Arrived	CN1	2017-07-21 11:42:00+03	2017-07-21 12:47:00+03
19226	PG0537	2017-07-21 14:00:00+03	2017-07-21 15:05:00+03	NOJ	NUX	Arrived	CN1	2017-07-21 14:03:00+03	2017-07-21 15:08:00+03
19227	PG0510	2017-08-05 18:00:00+03	2017-08-05 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-05 18:04:00+03	2017-08-05 19:34:00+03
19228	PG0510	2017-07-28 18:00:00+03	2017-07-28 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-28 18:01:00+03	2017-07-28 19:32:00+03
19229	PG0510	2017-09-04 18:00:00+03	2017-09-04 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19230	PG0510	2017-07-19 18:00:00+03	2017-07-19 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-19 18:03:00+03	2017-07-19 19:34:00+03
19231	PG0510	2017-07-16 18:00:00+03	2017-07-16 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-16 18:01:00+03	2017-07-16 19:31:00+03
19232	PG0510	2017-08-19 18:00:00+03	2017-08-19 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19233	PG0510	2017-08-16 18:00:00+03	2017-08-16 19:30:00+03	ESL	DME	On Time	SU9	\N	\N
19234	PG0510	2017-09-08 18:00:00+03	2017-09-08 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19235	PG0510	2017-08-02 18:00:00+03	2017-08-02 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-02 18:01:00+03	2017-08-02 19:31:00+03
19236	PG0510	2017-08-04 18:00:00+03	2017-08-04 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-04 18:02:00+03	2017-08-04 19:31:00+03
19237	PG0510	2017-09-10 18:00:00+03	2017-09-10 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19238	PG0510	2017-08-23 18:00:00+03	2017-08-23 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19239	PG0510	2017-07-25 18:00:00+03	2017-07-25 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-25 18:08:00+03	2017-07-25 19:38:00+03
19240	PG0510	2017-08-29 18:00:00+03	2017-08-29 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19241	PG0510	2017-07-30 18:00:00+03	2017-07-30 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-30 20:17:00+03	2017-07-30 21:46:00+03
19242	PG0510	2017-08-24 18:00:00+03	2017-08-24 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19243	PG0510	2017-08-26 18:00:00+03	2017-08-26 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19244	PG0510	2017-08-31 18:00:00+03	2017-08-31 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19245	PG0510	2017-07-31 18:00:00+03	2017-07-31 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-31 18:01:00+03	2017-07-31 19:30:00+03
19246	PG0510	2017-09-02 18:00:00+03	2017-09-02 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19247	PG0510	2017-07-21 18:00:00+03	2017-07-21 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-21 18:02:00+03	2017-07-21 19:33:00+03
19248	PG0510	2017-09-07 18:00:00+03	2017-09-07 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19249	PG0510	2017-08-28 18:00:00+03	2017-08-28 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19250	PG0510	2017-08-15 18:00:00+03	2017-08-15 19:30:00+03	ESL	DME	On Time	SU9	\N	\N
19251	PG0510	2017-08-22 18:00:00+03	2017-08-22 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19252	PG0510	2017-08-21 18:00:00+03	2017-08-21 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19253	PG0510	2017-09-09 18:00:00+03	2017-09-09 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19254	PG0510	2017-09-03 18:00:00+03	2017-09-03 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19255	PG0510	2017-08-07 18:00:00+03	2017-08-07 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-07 18:01:00+03	2017-08-07 19:32:00+03
19256	PG0510	2017-09-12 18:00:00+03	2017-09-12 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19257	PG0510	2017-08-06 18:00:00+03	2017-08-06 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-06 18:03:00+03	2017-08-06 19:33:00+03
19258	PG0510	2017-09-06 18:00:00+03	2017-09-06 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19259	PG0510	2017-08-25 18:00:00+03	2017-08-25 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19260	PG0510	2017-07-18 18:00:00+03	2017-07-18 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-18 18:05:00+03	2017-07-18 19:36:00+03
19261	PG0510	2017-08-09 18:00:00+03	2017-08-09 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-09 18:05:00+03	2017-08-09 19:36:00+03
19262	PG0510	2017-08-01 18:00:00+03	2017-08-01 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-01 18:03:00+03	2017-08-01 19:34:00+03
19263	PG0510	2017-08-10 18:00:00+03	2017-08-10 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-10 18:05:00+03	2017-08-10 19:35:00+03
19264	PG0510	2017-07-26 18:00:00+03	2017-07-26 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-26 18:03:00+03	2017-07-26 19:32:00+03
19265	PG0510	2017-08-18 18:00:00+03	2017-08-18 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19266	PG0510	2017-07-29 18:00:00+03	2017-07-29 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-29 18:01:00+03	2017-07-29 19:29:00+03
19267	PG0510	2017-08-30 18:00:00+03	2017-08-30 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19268	PG0510	2017-08-13 18:00:00+03	2017-08-13 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-13 18:04:00+03	2017-08-13 19:32:00+03
19269	PG0510	2017-08-12 18:00:00+03	2017-08-12 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-12 18:04:00+03	2017-08-12 19:34:00+03
19270	PG0510	2017-09-11 18:00:00+03	2017-09-11 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19271	PG0510	2017-08-08 18:00:00+03	2017-08-08 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-08 18:06:00+03	2017-08-08 19:35:00+03
19272	PG0510	2017-07-27 18:00:00+03	2017-07-27 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-27 18:04:00+03	2017-07-27 19:35:00+03
19273	PG0510	2017-07-24 18:00:00+03	2017-07-24 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-24 18:05:00+03	2017-07-24 19:37:00+03
19274	PG0510	2017-09-14 18:00:00+03	2017-09-14 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19275	PG0510	2017-08-14 18:00:00+03	2017-08-14 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-14 18:03:00+03	2017-08-14 19:33:00+03
19276	PG0510	2017-09-05 18:00:00+03	2017-09-05 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19277	PG0510	2017-07-17 18:00:00+03	2017-07-17 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-17 18:01:00+03	2017-07-17 19:29:00+03
19278	PG0510	2017-07-23 18:00:00+03	2017-07-23 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-23 18:02:00+03	2017-07-23 19:33:00+03
19279	PG0510	2017-08-03 18:00:00+03	2017-08-03 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-03 18:05:00+03	2017-08-03 19:35:00+03
19280	PG0510	2017-08-27 18:00:00+03	2017-08-27 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19281	PG0510	2017-07-20 18:00:00+03	2017-07-20 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-20 18:04:00+03	2017-07-20 19:33:00+03
19282	PG0510	2017-09-01 18:00:00+03	2017-09-01 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19283	PG0510	2017-07-22 18:00:00+03	2017-07-22 19:30:00+03	ESL	DME	Arrived	SU9	2017-07-22 18:02:00+03	2017-07-22 19:32:00+03
19284	PG0510	2017-08-20 18:00:00+03	2017-08-20 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19285	PG0510	2017-08-11 18:00:00+03	2017-08-11 19:30:00+03	ESL	DME	Arrived	SU9	2017-08-11 21:11:00+03	2017-08-11 22:43:00+03
19286	PG0510	2017-09-13 18:00:00+03	2017-09-13 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19287	PG0510	2017-08-17 18:00:00+03	2017-08-17 19:30:00+03	ESL	DME	Scheduled	SU9	\N	\N
19288	PG0300	2017-07-26 11:20:00+03	2017-07-26 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-26 11:24:00+03	2017-07-26 15:16:00+03
19289	PG0300	2017-07-25 11:20:00+03	2017-07-25 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-25 11:22:00+03	2017-07-25 15:12:00+03
19290	PG0300	2017-07-18 11:20:00+03	2017-07-18 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-18 11:23:00+03	2017-07-18 15:16:00+03
19291	PG0300	2017-08-07 11:20:00+03	2017-08-07 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-07 11:24:00+03	2017-08-07 15:15:00+03
19292	PG0300	2017-07-30 11:20:00+03	2017-07-30 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-30 11:25:00+03	2017-07-30 15:18:00+03
19293	PG0300	2017-07-27 11:20:00+03	2017-07-27 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-27 11:23:00+03	2017-07-27 15:11:00+03
19294	PG0300	2017-08-26 11:20:00+03	2017-08-26 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19295	PG0300	2017-09-03 11:20:00+03	2017-09-03 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19296	PG0300	2017-08-28 11:20:00+03	2017-08-28 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19297	PG0300	2017-07-19 11:20:00+03	2017-07-19 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-19 11:23:00+03	2017-07-19 15:14:00+03
19298	PG0300	2017-09-13 11:20:00+03	2017-09-13 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19299	PG0300	2017-08-10 11:20:00+03	2017-08-10 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-10 11:21:00+03	2017-08-10 15:10:00+03
19300	PG0300	2017-07-28 11:20:00+03	2017-07-28 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-28 11:23:00+03	2017-07-28 15:13:00+03
19301	PG0300	2017-07-16 11:20:00+03	2017-07-16 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-16 14:53:00+03	2017-07-16 18:43:00+03
19302	PG0300	2017-08-05 11:20:00+03	2017-08-05 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-05 11:23:00+03	2017-08-05 15:11:00+03
19303	PG0300	2017-08-11 11:20:00+03	2017-08-11 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-11 11:22:00+03	2017-08-11 15:11:00+03
19304	PG0300	2017-08-20 11:20:00+03	2017-08-20 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19305	PG0300	2017-08-17 11:20:00+03	2017-08-17 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19306	PG0300	2017-08-15 11:20:00+03	2017-08-15 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-15 11:26:00+03	2017-08-15 15:19:00+03
19307	PG0300	2017-07-23 11:20:00+03	2017-07-23 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-23 11:24:00+03	2017-07-23 15:17:00+03
19308	PG0300	2017-08-30 11:20:00+03	2017-08-30 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19309	PG0300	2017-09-10 11:20:00+03	2017-09-10 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19310	PG0300	2017-09-04 11:20:00+03	2017-09-04 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19311	PG0300	2017-08-27 11:20:00+03	2017-08-27 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19312	PG0300	2017-08-29 11:20:00+03	2017-08-29 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19313	PG0300	2017-08-22 11:20:00+03	2017-08-22 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19314	PG0300	2017-08-02 11:20:00+03	2017-08-02 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-02 11:22:00+03	2017-08-02 15:12:00+03
19315	PG0300	2017-09-09 11:20:00+03	2017-09-09 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19316	PG0300	2017-08-24 11:20:00+03	2017-08-24 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19317	PG0300	2017-09-11 11:20:00+03	2017-09-11 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19318	PG0300	2017-08-19 11:20:00+03	2017-08-19 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19319	PG0300	2017-07-21 11:20:00+03	2017-07-21 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-21 11:23:00+03	2017-07-21 15:13:00+03
19320	PG0300	2017-09-02 11:20:00+03	2017-09-02 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19321	PG0300	2017-09-08 11:20:00+03	2017-09-08 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19322	PG0300	2017-08-31 11:20:00+03	2017-08-31 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19323	PG0300	2017-08-03 11:20:00+03	2017-08-03 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-03 11:21:00+03	2017-08-03 15:10:00+03
19324	PG0300	2017-08-08 11:20:00+03	2017-08-08 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-08 11:25:00+03	2017-08-08 15:17:00+03
19325	PG0300	2017-09-07 11:20:00+03	2017-09-07 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19326	PG0300	2017-08-09 11:20:00+03	2017-08-09 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-09 11:22:00+03	2017-08-09 15:12:00+03
19327	PG0300	2017-09-05 11:20:00+03	2017-09-05 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19328	PG0300	2017-08-16 11:20:00+03	2017-08-16 15:10:00+03	ESL	SVO	On Time	CN1	\N	\N
19329	PG0300	2017-09-12 11:20:00+03	2017-09-12 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19330	PG0300	2017-08-06 11:20:00+03	2017-08-06 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-06 11:23:00+03	2017-08-06 15:13:00+03
19331	PG0300	2017-08-23 11:20:00+03	2017-08-23 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19332	PG0300	2017-09-06 11:20:00+03	2017-09-06 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19333	PG0300	2017-07-17 11:20:00+03	2017-07-17 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-17 11:23:00+03	2017-07-17 15:12:00+03
19334	PG0300	2017-08-21 11:20:00+03	2017-08-21 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19335	PG0300	2017-07-24 11:20:00+03	2017-07-24 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-24 11:25:00+03	2017-07-24 15:14:00+03
19336	PG0300	2017-09-01 11:20:00+03	2017-09-01 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19337	PG0300	2017-08-25 11:20:00+03	2017-08-25 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19338	PG0300	2017-09-14 11:20:00+03	2017-09-14 15:10:00+03	ESL	SVO	Cancelled	CN1	\N	\N
19339	PG0300	2017-07-31 11:20:00+03	2017-07-31 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-31 11:24:00+03	2017-07-31 15:13:00+03
19340	PG0300	2017-08-13 11:20:00+03	2017-08-13 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-13 11:23:00+03	2017-08-13 15:19:00+03
19341	PG0300	2017-08-14 11:20:00+03	2017-08-14 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-14 11:22:00+03	2017-08-14 15:15:00+03
19342	PG0300	2017-08-18 11:20:00+03	2017-08-18 15:10:00+03	ESL	SVO	Scheduled	CN1	\N	\N
19343	PG0300	2017-07-20 11:20:00+03	2017-07-20 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-20 11:22:00+03	2017-07-20 15:11:00+03
19344	PG0300	2017-08-12 11:20:00+03	2017-08-12 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-12 11:24:00+03	2017-08-12 15:15:00+03
19345	PG0300	2017-08-01 11:20:00+03	2017-08-01 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-01 11:25:00+03	2017-08-01 15:12:00+03
19346	PG0300	2017-08-04 11:20:00+03	2017-08-04 15:10:00+03	ESL	SVO	Arrived	CN1	2017-08-04 11:25:00+03	2017-08-04 15:14:00+03
19347	PG0300	2017-07-22 11:20:00+03	2017-07-22 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-22 11:24:00+03	2017-07-22 15:10:00+03
19348	PG0300	2017-07-29 11:20:00+03	2017-07-29 15:10:00+03	ESL	SVO	Arrived	CN1	2017-07-29 11:25:00+03	2017-07-29 15:17:00+03
19349	PG0524	2017-08-24 10:05:00+03	2017-08-24 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19350	PG0524	2017-08-27 10:05:00+03	2017-08-27 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19351	PG0524	2017-08-10 10:05:00+03	2017-08-10 12:35:00+03	ESL	LED	Arrived	CR2	2017-08-10 10:06:00+03	2017-08-10 12:35:00+03
19352	PG0524	2017-09-14 10:05:00+03	2017-09-14 12:35:00+03	ESL	LED	Cancelled	CR2	\N	\N
19353	PG0524	2017-09-03 10:05:00+03	2017-09-03 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19354	PG0524	2017-07-20 10:05:00+03	2017-07-20 12:35:00+03	ESL	LED	Arrived	CR2	2017-07-20 10:07:00+03	2017-07-20 12:38:00+03
19355	PG0524	2017-07-23 10:05:00+03	2017-07-23 12:35:00+03	ESL	LED	Arrived	CR2	2017-07-23 10:10:00+03	2017-07-23 12:41:00+03
19356	PG0524	2017-08-17 10:05:00+03	2017-08-17 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19357	PG0524	2017-08-13 10:05:00+03	2017-08-13 12:35:00+03	ESL	LED	Arrived	CR2	2017-08-13 10:07:00+03	2017-08-13 12:37:00+03
19358	PG0524	2017-07-16 10:05:00+03	2017-07-16 12:35:00+03	ESL	LED	Arrived	CR2	2017-07-16 10:10:00+03	2017-07-16 12:39:00+03
19359	PG0524	2017-08-31 10:05:00+03	2017-08-31 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19360	PG0524	2017-09-10 10:05:00+03	2017-09-10 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19361	PG0524	2017-08-03 10:05:00+03	2017-08-03 12:35:00+03	ESL	LED	Arrived	CR2	2017-08-03 10:07:00+03	2017-08-03 12:37:00+03
19362	PG0524	2017-07-30 10:05:00+03	2017-07-30 12:35:00+03	ESL	LED	Arrived	CR2	2017-07-30 10:10:00+03	2017-07-30 12:42:00+03
19363	PG0524	2017-08-06 10:05:00+03	2017-08-06 12:35:00+03	ESL	LED	Arrived	CR2	2017-08-06 10:08:00+03	2017-08-06 12:39:00+03
19364	PG0524	2017-08-20 10:05:00+03	2017-08-20 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19365	PG0524	2017-07-27 10:05:00+03	2017-07-27 12:35:00+03	ESL	LED	Arrived	CR2	2017-07-27 10:08:00+03	2017-07-27 12:38:00+03
19366	PG0524	2017-09-07 10:05:00+03	2017-09-07 12:35:00+03	ESL	LED	Scheduled	CR2	\N	\N
19367	PG0306	2017-08-19 13:50:00+03	2017-08-19 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19368	PG0306	2017-08-20 13:50:00+03	2017-08-20 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19369	PG0306	2017-08-05 13:50:00+03	2017-08-05 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-05 13:52:00+03	2017-08-05 15:34:00+03
19370	PG0306	2017-07-27 13:50:00+03	2017-07-27 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-27 13:51:00+03	2017-07-27 15:30:00+03
19371	PG0306	2017-08-02 13:50:00+03	2017-08-02 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-02 13:52:00+03	2017-08-02 15:33:00+03
19372	PG0306	2017-08-10 13:50:00+03	2017-08-10 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-10 13:51:00+03	2017-08-10 15:31:00+03
19373	PG0306	2017-08-28 13:50:00+03	2017-08-28 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19374	PG0306	2017-08-17 13:50:00+03	2017-08-17 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19375	PG0306	2017-09-02 13:50:00+03	2017-09-02 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19376	PG0306	2017-09-08 13:50:00+03	2017-09-08 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19377	PG0306	2017-09-06 13:50:00+03	2017-09-06 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19378	PG0306	2017-07-17 13:50:00+03	2017-07-17 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-17 13:55:00+03	2017-07-17 15:33:00+03
19379	PG0306	2017-08-01 13:50:00+03	2017-08-01 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-01 13:51:00+03	2017-08-01 15:31:00+03
19380	PG0306	2017-07-24 13:50:00+03	2017-07-24 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-24 13:53:00+03	2017-07-24 15:35:00+03
19381	PG0306	2017-09-12 13:50:00+03	2017-09-12 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19382	PG0306	2017-08-18 13:50:00+03	2017-08-18 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19383	PG0306	2017-09-01 13:50:00+03	2017-09-01 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19384	PG0306	2017-07-28 13:50:00+03	2017-07-28 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-28 13:53:00+03	2017-07-28 15:34:00+03
19385	PG0306	2017-07-18 13:50:00+03	2017-07-18 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-18 13:54:00+03	2017-07-18 15:33:00+03
19386	PG0306	2017-08-14 13:50:00+03	2017-08-14 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-14 13:57:00+03	2017-08-14 15:37:00+03
19387	PG0306	2017-09-14 13:50:00+03	2017-09-14 15:30:00+03	ESL	UFA	Cancelled	SU9	\N	\N
19388	PG0306	2017-08-11 13:50:00+03	2017-08-11 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-11 13:53:00+03	2017-08-11 15:32:00+03
19389	PG0306	2017-08-15 13:50:00+03	2017-08-15 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-15 13:52:00+03	2017-08-15 15:32:00+03
19390	PG0306	2017-08-04 13:50:00+03	2017-08-04 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-04 13:56:00+03	2017-08-04 15:36:00+03
19391	PG0306	2017-07-31 13:50:00+03	2017-07-31 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-31 13:53:00+03	2017-07-31 15:34:00+03
19392	PG0306	2017-07-26 13:50:00+03	2017-07-26 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-26 17:04:00+03	2017-07-26 18:46:00+03
19393	PG0306	2017-07-19 13:50:00+03	2017-07-19 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-19 13:54:00+03	2017-07-19 15:34:00+03
19394	PG0306	2017-09-13 13:50:00+03	2017-09-13 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19395	PG0306	2017-08-09 13:50:00+03	2017-08-09 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-09 13:53:00+03	2017-08-09 15:34:00+03
19396	PG0306	2017-08-31 13:50:00+03	2017-08-31 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19397	PG0306	2017-09-09 13:50:00+03	2017-09-09 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19398	PG0306	2017-07-21 13:50:00+03	2017-07-21 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-21 13:51:00+03	2017-07-21 15:31:00+03
19399	PG0306	2017-08-24 13:50:00+03	2017-08-24 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19400	PG0306	2017-08-16 13:50:00+03	2017-08-16 15:30:00+03	ESL	UFA	On Time	SU9	\N	\N
19401	PG0306	2017-07-29 13:50:00+03	2017-07-29 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-29 13:54:00+03	2017-07-29 15:34:00+03
19402	PG0306	2017-09-10 13:50:00+03	2017-09-10 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19403	PG0306	2017-08-26 13:50:00+03	2017-08-26 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19404	PG0306	2017-09-03 13:50:00+03	2017-09-03 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19405	PG0306	2017-07-30 13:50:00+03	2017-07-30 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-30 13:51:00+03	2017-07-30 15:32:00+03
19406	PG0306	2017-09-04 13:50:00+03	2017-09-04 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19407	PG0306	2017-08-06 13:50:00+03	2017-08-06 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-06 13:51:00+03	2017-08-06 15:31:00+03
19408	PG0306	2017-07-23 13:50:00+03	2017-07-23 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-23 13:56:00+03	2017-07-23 15:36:00+03
19409	PG0306	2017-08-23 13:50:00+03	2017-08-23 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19410	PG0306	2017-08-29 13:50:00+03	2017-08-29 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19411	PG0306	2017-08-12 13:50:00+03	2017-08-12 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-12 13:50:00+03	2017-08-12 15:31:00+03
19412	PG0306	2017-08-27 13:50:00+03	2017-08-27 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19413	PG0306	2017-08-03 13:50:00+03	2017-08-03 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-03 13:53:00+03	2017-08-03 15:32:00+03
19414	PG0306	2017-09-07 13:50:00+03	2017-09-07 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19415	PG0306	2017-08-21 13:50:00+03	2017-08-21 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19416	PG0306	2017-07-22 13:50:00+03	2017-07-22 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-22 13:54:00+03	2017-07-22 15:35:00+03
19417	PG0306	2017-07-16 13:50:00+03	2017-07-16 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-16 13:52:00+03	2017-07-16 15:35:00+03
19418	PG0306	2017-07-20 13:50:00+03	2017-07-20 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-20 13:53:00+03	2017-07-20 15:34:00+03
19419	PG0306	2017-08-25 13:50:00+03	2017-08-25 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19420	PG0306	2017-08-08 13:50:00+03	2017-08-08 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-08 13:52:00+03	2017-08-08 15:31:00+03
19421	PG0306	2017-08-22 13:50:00+03	2017-08-22 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19422	PG0306	2017-08-30 13:50:00+03	2017-08-30 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19423	PG0306	2017-07-25 13:50:00+03	2017-07-25 15:30:00+03	ESL	UFA	Arrived	SU9	2017-07-25 13:51:00+03	2017-07-25 15:30:00+03
19424	PG0306	2017-08-13 13:50:00+03	2017-08-13 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-13 13:56:00+03	2017-08-13 15:35:00+03
19425	PG0306	2017-09-05 13:50:00+03	2017-09-05 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19426	PG0306	2017-09-11 13:50:00+03	2017-09-11 15:30:00+03	ESL	UFA	Scheduled	SU9	\N	\N
19427	PG0306	2017-08-07 13:50:00+03	2017-08-07 15:30:00+03	ESL	UFA	Arrived	SU9	2017-08-07 13:51:00+03	2017-08-07 15:32:00+03
19428	PG0033	2017-08-01 16:50:00+03	2017-08-01 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-08-01 16:52:00+03	2017-08-01 18:36:00+03
19429	PG0033	2017-08-22 16:50:00+03	2017-08-22 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19430	PG0033	2017-07-25 16:50:00+03	2017-07-25 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-07-25 16:53:00+03	2017-07-25 18:38:00+03
19431	PG0033	2017-07-29 16:50:00+03	2017-07-29 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-07-29 16:53:00+03	2017-07-29 18:38:00+03
19432	PG0033	2017-09-09 16:50:00+03	2017-09-09 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19433	PG0033	2017-09-05 16:50:00+03	2017-09-05 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19434	PG0033	2017-08-08 16:50:00+03	2017-08-08 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-08-08 16:50:00+03	2017-08-08 18:34:00+03
19435	PG0033	2017-08-05 16:50:00+03	2017-08-05 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-08-05 16:51:00+03	2017-08-05 18:38:00+03
19436	PG0033	2017-09-12 16:50:00+03	2017-09-12 18:35:00+03	ESL	GDZ	Cancelled	CN1	\N	\N
19437	PG0033	2017-08-29 16:50:00+03	2017-08-29 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19438	PG0033	2017-08-15 16:50:00+03	2017-08-15 18:35:00+03	ESL	GDZ	Departed	CN1	2017-08-15 16:52:00+03	\N
19439	PG0033	2017-08-12 16:50:00+03	2017-08-12 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-08-12 16:52:00+03	2017-08-12 18:36:00+03
19440	PG0033	2017-07-18 16:50:00+03	2017-07-18 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-07-18 16:56:00+03	2017-07-18 18:38:00+03
19441	PG0033	2017-08-19 16:50:00+03	2017-08-19 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19442	PG0033	2017-07-22 16:50:00+03	2017-07-22 18:35:00+03	ESL	GDZ	Arrived	CN1	2017-07-22 16:53:00+03	2017-07-22 18:39:00+03
19443	PG0033	2017-09-02 16:50:00+03	2017-09-02 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19444	PG0033	2017-08-26 16:50:00+03	2017-08-26 18:35:00+03	ESL	GDZ	Scheduled	CN1	\N	\N
19445	PG0533	2017-07-31 14:55:00+03	2017-07-31 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-31 14:58:00+03	2017-07-31 18:16:00+03
19446	PG0533	2017-07-28 14:55:00+03	2017-07-28 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-28 14:57:00+03	2017-07-28 18:18:00+03
19447	PG0533	2017-08-05 14:55:00+03	2017-08-05 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-05 15:00:00+03	2017-08-05 18:23:00+03
19448	PG0533	2017-08-04 14:55:00+03	2017-08-04 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-04 14:57:00+03	2017-08-04 18:17:00+03
19449	PG0533	2017-09-08 14:55:00+03	2017-09-08 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19450	PG0533	2017-09-09 14:55:00+03	2017-09-09 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19451	PG0533	2017-09-05 14:55:00+03	2017-09-05 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19452	PG0533	2017-08-15 14:55:00+03	2017-08-15 18:15:00+03	ESL	REN	Departed	CN1	2017-08-15 14:58:00+03	\N
19453	PG0533	2017-07-25 14:55:00+03	2017-07-25 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-25 14:56:00+03	2017-07-25 18:16:00+03
19454	PG0533	2017-09-07 14:55:00+03	2017-09-07 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19455	PG0533	2017-08-13 14:55:00+03	2017-08-13 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-13 14:59:00+03	2017-08-13 18:18:00+03
19456	PG0533	2017-07-22 14:55:00+03	2017-07-22 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-22 14:59:00+03	2017-07-22 18:21:00+03
19457	PG0533	2017-07-21 14:55:00+03	2017-07-21 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-21 14:57:00+03	2017-07-21 18:17:00+03
19458	PG0533	2017-07-17 14:55:00+03	2017-07-17 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-17 14:56:00+03	2017-07-17 18:18:00+03
19459	PG0533	2017-09-04 14:55:00+03	2017-09-04 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19460	PG0533	2017-08-20 14:55:00+03	2017-08-20 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19461	PG0533	2017-07-24 14:55:00+03	2017-07-24 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-24 14:57:00+03	2017-07-24 18:18:00+03
19462	PG0533	2017-08-11 14:55:00+03	2017-08-11 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-11 15:01:00+03	2017-08-11 18:19:00+03
19463	PG0533	2017-09-02 14:55:00+03	2017-09-02 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19464	PG0533	2017-08-19 14:55:00+03	2017-08-19 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19465	PG0533	2017-09-01 14:55:00+03	2017-09-01 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19466	PG0533	2017-08-30 14:55:00+03	2017-08-30 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19467	PG0533	2017-08-18 14:55:00+03	2017-08-18 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19468	PG0533	2017-09-12 14:55:00+03	2017-09-12 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19469	PG0533	2017-07-26 14:55:00+03	2017-07-26 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-26 15:02:00+03	2017-07-26 18:22:00+03
19470	PG0533	2017-08-25 14:55:00+03	2017-08-25 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19471	PG0533	2017-08-22 14:55:00+03	2017-08-22 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19472	PG0533	2017-09-10 14:55:00+03	2017-09-10 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19473	PG0533	2017-08-12 14:55:00+03	2017-08-12 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-12 14:58:00+03	2017-08-12 18:17:00+03
19474	PG0533	2017-09-11 14:55:00+03	2017-09-11 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19475	PG0533	2017-07-20 14:55:00+03	2017-07-20 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-20 15:02:00+03	2017-07-20 18:23:00+03
19476	PG0533	2017-08-01 14:55:00+03	2017-08-01 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-01 14:56:00+03	2017-08-01 18:14:00+03
19477	PG0533	2017-08-09 14:55:00+03	2017-08-09 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-09 14:59:00+03	2017-08-09 18:20:00+03
19478	PG0533	2017-07-16 14:55:00+03	2017-07-16 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-16 14:59:00+03	2017-07-16 18:19:00+03
19479	PG0533	2017-09-03 14:55:00+03	2017-09-03 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19480	PG0533	2017-07-30 14:55:00+03	2017-07-30 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-30 14:58:00+03	2017-07-30 18:19:00+03
19481	PG0533	2017-08-07 14:55:00+03	2017-08-07 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-07 14:56:00+03	2017-08-07 18:20:00+03
19482	PG0533	2017-08-28 14:55:00+03	2017-08-28 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19483	PG0533	2017-08-10 14:55:00+03	2017-08-10 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-10 14:58:00+03	2017-08-10 18:16:00+03
19484	PG0533	2017-07-29 14:55:00+03	2017-07-29 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-29 14:58:00+03	2017-07-29 18:17:00+03
19485	PG0533	2017-08-06 14:55:00+03	2017-08-06 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-06 14:57:00+03	2017-08-06 18:14:00+03
19486	PG0533	2017-08-24 14:55:00+03	2017-08-24 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19487	PG0533	2017-09-14 14:55:00+03	2017-09-14 18:15:00+03	ESL	REN	Cancelled	CN1	\N	\N
19488	PG0533	2017-08-26 14:55:00+03	2017-08-26 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19489	PG0533	2017-09-06 14:55:00+03	2017-09-06 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19490	PG0533	2017-07-23 14:55:00+03	2017-07-23 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-23 14:57:00+03	2017-07-23 18:18:00+03
19491	PG0533	2017-07-27 14:55:00+03	2017-07-27 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-27 14:57:00+03	2017-07-27 18:14:00+03
19492	PG0533	2017-08-08 14:55:00+03	2017-08-08 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-08 14:58:00+03	2017-08-08 18:15:00+03
19493	PG0533	2017-08-17 14:55:00+03	2017-08-17 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19494	PG0533	2017-08-21 14:55:00+03	2017-08-21 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19495	PG0533	2017-08-23 14:55:00+03	2017-08-23 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19496	PG0533	2017-08-16 14:55:00+03	2017-08-16 18:15:00+03	ESL	REN	On Time	CN1	\N	\N
19497	PG0533	2017-08-31 14:55:00+03	2017-08-31 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19498	PG0533	2017-08-29 14:55:00+03	2017-08-29 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19499	PG0533	2017-08-02 14:55:00+03	2017-08-02 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-02 14:58:00+03	2017-08-02 18:21:00+03
19500	PG0533	2017-07-18 14:55:00+03	2017-07-18 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-18 14:58:00+03	2017-07-18 18:20:00+03
19501	PG0533	2017-09-13 14:55:00+03	2017-09-13 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19502	PG0533	2017-08-27 14:55:00+03	2017-08-27 18:15:00+03	ESL	REN	Scheduled	CN1	\N	\N
19503	PG0533	2017-08-14 14:55:00+03	2017-08-14 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-14 15:00:00+03	2017-08-14 18:16:00+03
19504	PG0533	2017-08-03 14:55:00+03	2017-08-03 18:15:00+03	ESL	REN	Arrived	CN1	2017-08-03 14:56:00+03	2017-08-03 18:18:00+03
19505	PG0533	2017-07-19 14:55:00+03	2017-07-19 18:15:00+03	ESL	REN	Arrived	CN1	2017-07-19 14:56:00+03	2017-07-19 18:16:00+03
19506	PG0333	2017-08-09 15:55:00+03	2017-08-09 18:40:00+03	ESL	KGD	Arrived	CR2	2017-08-09 15:59:00+03	2017-08-09 18:42:00+03
19507	PG0333	2017-09-10 15:55:00+03	2017-09-10 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19508	PG0333	2017-08-20 15:55:00+03	2017-08-20 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19509	PG0333	2017-08-13 15:55:00+03	2017-08-13 18:40:00+03	ESL	KGD	Arrived	CR2	2017-08-13 15:57:00+03	2017-08-13 18:44:00+03
19510	PG0333	2017-08-16 15:55:00+03	2017-08-16 18:40:00+03	ESL	KGD	On Time	CR2	\N	\N
19511	PG0333	2017-07-30 15:55:00+03	2017-07-30 18:40:00+03	ESL	KGD	Arrived	CR2	2017-07-30 16:00:00+03	2017-07-30 18:45:00+03
19512	PG0333	2017-08-30 15:55:00+03	2017-08-30 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19513	PG0333	2017-07-26 15:55:00+03	2017-07-26 18:40:00+03	ESL	KGD	Arrived	CR2	2017-07-26 15:57:00+03	2017-07-26 18:42:00+03
19514	PG0333	2017-08-27 15:55:00+03	2017-08-27 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19515	PG0333	2017-07-16 15:55:00+03	2017-07-16 18:40:00+03	ESL	KGD	Arrived	CR2	2017-07-16 15:56:00+03	2017-07-16 18:40:00+03
19516	PG0333	2017-09-06 15:55:00+03	2017-09-06 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19517	PG0333	2017-09-13 15:55:00+03	2017-09-13 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19518	PG0333	2017-08-02 15:55:00+03	2017-08-02 18:40:00+03	ESL	KGD	Arrived	CR2	2017-08-02 15:57:00+03	2017-08-02 18:41:00+03
19519	PG0333	2017-09-03 15:55:00+03	2017-09-03 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19520	PG0333	2017-08-06 15:55:00+03	2017-08-06 18:40:00+03	ESL	KGD	Arrived	CR2	2017-08-06 15:56:00+03	2017-08-06 18:41:00+03
19521	PG0333	2017-07-19 15:55:00+03	2017-07-19 18:40:00+03	ESL	KGD	Arrived	CR2	2017-07-19 15:58:00+03	2017-07-19 18:46:00+03
19522	PG0333	2017-07-23 15:55:00+03	2017-07-23 18:40:00+03	ESL	KGD	Arrived	CR2	2017-07-23 16:00:00+03	2017-07-23 18:45:00+03
19523	PG0333	2017-08-23 15:55:00+03	2017-08-23 18:40:00+03	ESL	KGD	Scheduled	CR2	\N	\N
19524	PG0121	2017-09-02 09:35:00+03	2017-09-02 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19525	PG0121	2017-07-28 09:35:00+03	2017-07-28 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-28 09:36:00+03	2017-07-28 15:24:00+03
19526	PG0121	2017-09-09 09:35:00+03	2017-09-09 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19527	PG0121	2017-08-24 09:35:00+03	2017-08-24 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19528	PG0121	2017-07-16 09:35:00+03	2017-07-16 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-16 09:36:00+03	2017-07-16 15:23:00+03
19529	PG0121	2017-09-11 09:35:00+03	2017-09-11 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19530	PG0121	2017-08-03 09:35:00+03	2017-08-03 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-03 09:38:00+03	2017-08-03 15:19:00+03
19531	PG0121	2017-08-10 09:35:00+03	2017-08-10 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-10 09:38:00+03	2017-08-10 15:26:00+03
19532	PG0121	2017-08-20 09:35:00+03	2017-08-20 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19533	PG0121	2017-08-05 09:35:00+03	2017-08-05 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-05 09:39:00+03	2017-08-05 15:28:00+03
19534	PG0121	2017-07-18 09:35:00+03	2017-07-18 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-18 09:37:00+03	2017-07-18 15:10:00+03
19535	PG0121	2017-07-27 09:35:00+03	2017-07-27 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-27 12:52:00+03	2017-07-27 18:34:00+03
19536	PG0121	2017-09-10 09:35:00+03	2017-09-10 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19537	PG0121	2017-08-12 09:35:00+03	2017-08-12 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-12 12:38:00+03	2017-08-12 18:23:00+03
19538	PG0121	2017-08-29 09:35:00+03	2017-08-29 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19539	PG0121	2017-09-06 09:35:00+03	2017-09-06 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19540	PG0121	2017-09-13 09:35:00+03	2017-09-13 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19541	PG0121	2017-08-06 09:35:00+03	2017-08-06 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-06 09:37:00+03	2017-08-06 15:25:00+03
19542	PG0121	2017-08-18 09:35:00+03	2017-08-18 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19543	PG0121	2017-08-02 09:35:00+03	2017-08-02 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-02 09:39:00+03	2017-08-02 15:21:00+03
19544	PG0121	2017-09-01 09:35:00+03	2017-09-01 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19545	PG0121	2017-09-04 09:35:00+03	2017-09-04 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19546	PG0121	2017-07-20 09:35:00+03	2017-07-20 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-20 09:38:00+03	2017-07-20 15:22:00+03
19547	PG0121	2017-08-28 09:35:00+03	2017-08-28 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19548	PG0121	2017-08-31 09:35:00+03	2017-08-31 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19549	PG0121	2017-07-29 09:35:00+03	2017-07-29 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-29 09:35:00+03	2017-07-29 15:14:00+03
19550	PG0121	2017-08-27 09:35:00+03	2017-08-27 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19551	PG0121	2017-08-13 09:35:00+03	2017-08-13 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-13 09:37:00+03	2017-08-13 15:24:00+03
19552	PG0121	2017-07-17 09:35:00+03	2017-07-17 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-17 09:39:00+03	2017-07-17 15:28:00+03
19553	PG0121	2017-07-25 09:35:00+03	2017-07-25 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-25 09:37:00+03	2017-07-25 15:22:00+03
19554	PG0121	2017-08-16 09:35:00+03	2017-08-16 15:20:00+03	MJZ	SVO	On Time	733	\N	\N
19555	PG0121	2017-08-01 09:35:00+03	2017-08-01 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-01 09:40:00+03	2017-08-01 15:35:00+03
19556	PG0121	2017-09-08 09:35:00+03	2017-09-08 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19557	PG0121	2017-08-14 09:35:00+03	2017-08-14 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-14 09:38:00+03	2017-08-14 15:25:00+03
19558	PG0121	2017-08-07 09:35:00+03	2017-08-07 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-07 09:36:00+03	2017-08-07 15:17:00+03
19559	PG0121	2017-08-30 09:35:00+03	2017-08-30 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19560	PG0121	2017-08-11 09:35:00+03	2017-08-11 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-11 09:39:00+03	2017-08-11 15:26:00+03
19561	PG0121	2017-07-26 09:35:00+03	2017-07-26 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-26 09:42:00+03	2017-07-26 15:29:00+03
19562	PG0121	2017-09-14 09:35:00+03	2017-09-14 15:20:00+03	MJZ	SVO	Cancelled	733	\N	\N
19563	PG0121	2017-07-24 09:35:00+03	2017-07-24 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-24 09:37:00+03	2017-07-24 15:25:00+03
19564	PG0121	2017-08-25 09:35:00+03	2017-08-25 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19565	PG0121	2017-07-22 09:35:00+03	2017-07-22 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-22 09:39:00+03	2017-07-22 15:25:00+03
19566	PG0121	2017-08-23 09:35:00+03	2017-08-23 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19567	PG0121	2017-07-21 09:35:00+03	2017-07-21 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-21 09:37:00+03	2017-07-21 15:25:00+03
19568	PG0121	2017-09-12 09:35:00+03	2017-09-12 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19569	PG0121	2017-08-21 09:35:00+03	2017-08-21 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19570	PG0121	2017-09-07 09:35:00+03	2017-09-07 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19571	PG0121	2017-07-31 09:35:00+03	2017-07-31 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-31 09:37:00+03	2017-07-31 15:23:00+03
19572	PG0121	2017-08-08 09:35:00+03	2017-08-08 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-08 09:38:00+03	2017-08-08 15:23:00+03
19573	PG0121	2017-09-03 09:35:00+03	2017-09-03 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19574	PG0121	2017-08-09 09:35:00+03	2017-08-09 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-09 09:41:00+03	2017-08-09 15:25:00+03
19575	PG0121	2017-08-15 09:35:00+03	2017-08-15 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-15 09:36:00+03	2017-08-15 15:28:00+03
19576	PG0121	2017-08-04 09:35:00+03	2017-08-04 15:20:00+03	MJZ	SVO	Arrived	733	2017-08-04 12:28:00+03	2017-08-04 18:09:00+03
19577	PG0121	2017-09-05 09:35:00+03	2017-09-05 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19578	PG0121	2017-07-30 09:35:00+03	2017-07-30 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-30 09:35:00+03	2017-07-30 15:19:00+03
19579	PG0121	2017-08-19 09:35:00+03	2017-08-19 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19580	PG0121	2017-07-23 09:35:00+03	2017-07-23 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-23 09:38:00+03	2017-07-23 15:29:00+03
19581	PG0121	2017-07-19 09:35:00+03	2017-07-19 15:20:00+03	MJZ	SVO	Arrived	733	2017-07-19 12:47:00+03	2017-07-19 18:32:00+03
19582	PG0121	2017-08-26 09:35:00+03	2017-08-26 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19583	PG0121	2017-08-17 09:35:00+03	2017-08-17 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19584	PG0121	2017-08-22 09:35:00+03	2017-08-22 15:20:00+03	MJZ	SVO	Scheduled	733	\N	\N
19585	PG0391	2017-09-11 05:40:00+03	2017-09-11 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19586	PG0391	2017-08-02 05:40:00+03	2017-08-02 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-02 05:41:00+03	2017-08-02 08:32:00+03
19587	PG0391	2017-08-15 05:40:00+03	2017-08-15 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-15 05:41:00+03	2017-08-15 08:32:00+03
19588	PG0391	2017-09-09 05:40:00+03	2017-09-09 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19589	PG0391	2017-09-08 05:40:00+03	2017-09-08 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19590	PG0391	2017-08-19 05:40:00+03	2017-08-19 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19591	PG0391	2017-08-10 05:40:00+03	2017-08-10 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-10 05:42:00+03	2017-08-10 08:34:00+03
19592	PG0391	2017-08-23 05:40:00+03	2017-08-23 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19593	PG0391	2017-07-20 05:40:00+03	2017-07-20 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-20 09:38:00+03	2017-07-20 12:26:00+03
19594	PG0391	2017-08-28 05:40:00+03	2017-08-28 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19595	PG0391	2017-08-16 05:40:00+03	2017-08-16 08:30:00+03	MJZ	OVB	On Time	CR2	\N	\N
19596	PG0391	2017-09-03 05:40:00+03	2017-09-03 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19597	PG0391	2017-08-31 05:40:00+03	2017-08-31 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19598	PG0391	2017-07-18 05:40:00+03	2017-07-18 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-18 05:41:00+03	2017-07-18 08:30:00+03
19599	PG0391	2017-08-07 05:40:00+03	2017-08-07 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-07 05:42:00+03	2017-08-07 08:31:00+03
19600	PG0391	2017-07-31 05:40:00+03	2017-07-31 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-31 05:45:00+03	2017-07-31 08:35:00+03
19601	PG0391	2017-07-30 05:40:00+03	2017-07-30 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-30 05:42:00+03	2017-07-30 08:31:00+03
19602	PG0391	2017-08-12 05:40:00+03	2017-08-12 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-12 05:42:00+03	2017-08-12 08:33:00+03
19603	PG0391	2017-08-22 05:40:00+03	2017-08-22 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19604	PG0391	2017-07-21 05:40:00+03	2017-07-21 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-21 05:43:00+03	2017-07-21 08:36:00+03
19605	PG0391	2017-09-05 05:40:00+03	2017-09-05 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19606	PG0391	2017-08-13 05:40:00+03	2017-08-13 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-13 05:44:00+03	2017-08-13 08:32:00+03
19607	PG0391	2017-09-06 05:40:00+03	2017-09-06 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19608	PG0391	2017-08-27 05:40:00+03	2017-08-27 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19609	PG0391	2017-08-25 05:40:00+03	2017-08-25 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19610	PG0391	2017-09-13 05:40:00+03	2017-09-13 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19611	PG0391	2017-08-20 05:40:00+03	2017-08-20 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19612	PG0391	2017-08-01 05:40:00+03	2017-08-01 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-01 05:42:00+03	2017-08-01 08:34:00+03
19613	PG0391	2017-09-07 05:40:00+03	2017-09-07 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19614	PG0391	2017-09-12 05:40:00+03	2017-09-12 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19615	PG0391	2017-08-29 05:40:00+03	2017-08-29 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19616	PG0391	2017-07-22 05:40:00+03	2017-07-22 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-22 05:41:00+03	2017-07-22 08:30:00+03
19617	PG0391	2017-09-04 05:40:00+03	2017-09-04 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19618	PG0391	2017-07-26 05:40:00+03	2017-07-26 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-26 05:44:00+03	2017-07-26 08:32:00+03
19619	PG0391	2017-07-27 05:40:00+03	2017-07-27 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-27 09:39:00+03	2017-07-27 12:29:00+03
19620	PG0391	2017-08-18 05:40:00+03	2017-08-18 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19621	PG0391	2017-08-14 05:40:00+03	2017-08-14 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-14 05:43:00+03	2017-08-14 08:36:00+03
19622	PG0391	2017-08-21 05:40:00+03	2017-08-21 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19623	PG0391	2017-09-14 05:40:00+03	2017-09-14 08:30:00+03	MJZ	OVB	Cancelled	CR2	\N	\N
19624	PG0391	2017-07-28 05:40:00+03	2017-07-28 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-28 05:44:00+03	2017-07-28 08:32:00+03
19625	PG0391	2017-08-06 05:40:00+03	2017-08-06 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-06 05:44:00+03	2017-08-06 08:34:00+03
19626	PG0391	2017-07-19 05:40:00+03	2017-07-19 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-19 05:44:00+03	2017-07-19 08:36:00+03
19627	PG0391	2017-08-08 05:40:00+03	2017-08-08 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-08 05:42:00+03	2017-08-08 08:33:00+03
19628	PG0391	2017-07-24 05:40:00+03	2017-07-24 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-24 05:45:00+03	2017-07-24 08:34:00+03
19629	PG0391	2017-08-26 05:40:00+03	2017-08-26 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19630	PG0391	2017-08-17 05:40:00+03	2017-08-17 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19631	PG0391	2017-08-24 05:40:00+03	2017-08-24 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19632	PG0391	2017-07-16 05:40:00+03	2017-07-16 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-16 05:45:00+03	2017-07-16 08:35:00+03
19633	PG0391	2017-08-11 05:40:00+03	2017-08-11 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-11 05:43:00+03	2017-08-11 08:31:00+03
19634	PG0391	2017-08-30 05:40:00+03	2017-08-30 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19635	PG0391	2017-07-23 05:40:00+03	2017-07-23 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-23 05:45:00+03	2017-07-23 08:34:00+03
19636	PG0391	2017-08-09 05:40:00+03	2017-08-09 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-09 05:43:00+03	2017-08-09 08:34:00+03
19637	PG0391	2017-08-04 05:40:00+03	2017-08-04 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-04 05:42:00+03	2017-08-04 08:31:00+03
19638	PG0391	2017-09-10 05:40:00+03	2017-09-10 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19639	PG0391	2017-07-29 05:40:00+03	2017-07-29 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-29 05:42:00+03	2017-07-29 08:33:00+03
19640	PG0391	2017-09-02 05:40:00+03	2017-09-02 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19641	PG0391	2017-07-25 05:40:00+03	2017-07-25 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-25 05:42:00+03	2017-07-25 08:31:00+03
19642	PG0391	2017-09-01 05:40:00+03	2017-09-01 08:30:00+03	MJZ	OVB	Scheduled	CR2	\N	\N
19643	PG0391	2017-08-05 05:40:00+03	2017-08-05 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-05 05:42:00+03	2017-08-05 08:35:00+03
19644	PG0391	2017-08-03 05:40:00+03	2017-08-03 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-08-03 05:40:00+03	2017-08-03 08:33:00+03
19645	PG0391	2017-07-17 05:40:00+03	2017-07-17 08:30:00+03	MJZ	OVB	Arrived	CR2	2017-07-17 05:44:00+03	2017-07-17 08:34:00+03
19646	PG0344	2017-09-09 08:35:00+03	2017-09-09 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19647	PG0344	2017-07-22 08:35:00+03	2017-07-22 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-07-22 08:38:00+03	2017-07-22 12:37:00+03
19648	PG0344	2017-08-26 08:35:00+03	2017-08-26 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19649	PG0344	2017-08-30 08:35:00+03	2017-08-30 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19650	PG0344	2017-07-26 08:35:00+03	2017-07-26 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-07-26 08:38:00+03	2017-07-26 12:38:00+03
19651	PG0344	2017-09-06 08:35:00+03	2017-09-06 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19652	PG0344	2017-09-02 08:35:00+03	2017-09-02 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19653	PG0344	2017-08-09 08:35:00+03	2017-08-09 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-08-09 08:38:00+03	2017-08-09 12:38:00+03
19654	PG0344	2017-08-19 08:35:00+03	2017-08-19 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19655	PG0344	2017-08-23 08:35:00+03	2017-08-23 12:35:00+03	MJZ	SVX	Scheduled	SU9	\N	\N
19656	PG0344	2017-08-16 08:35:00+03	2017-08-16 12:35:00+03	MJZ	SVX	On Time	SU9	\N	\N
19657	PG0344	2017-08-12 08:35:00+03	2017-08-12 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-08-12 08:40:00+03	2017-08-12 12:39:00+03
19658	PG0344	2017-08-02 08:35:00+03	2017-08-02 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-08-02 08:35:00+03	2017-08-02 12:34:00+03
19659	PG0344	2017-08-05 08:35:00+03	2017-08-05 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-08-05 12:13:00+03	2017-08-05 16:07:00+03
19660	PG0344	2017-07-19 08:35:00+03	2017-07-19 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-07-19 08:37:00+03	2017-07-19 12:38:00+03
19661	PG0344	2017-09-13 08:35:00+03	2017-09-13 12:35:00+03	MJZ	SVX	Cancelled	SU9	\N	\N
19662	PG0344	2017-07-29 08:35:00+03	2017-07-29 12:35:00+03	MJZ	SVX	Arrived	SU9	2017-07-29 08:41:00+03	2017-07-29 12:42:00+03
19663	PG0700	2017-09-01 10:10:00+03	2017-09-01 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19664	PG0700	2017-08-17 10:10:00+03	2017-08-17 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19665	PG0700	2017-07-26 10:10:00+03	2017-07-26 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-26 10:13:00+03	2017-07-26 11:24:00+03
19666	PG0700	2017-08-23 10:10:00+03	2017-08-23 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19667	PG0700	2017-09-02 10:10:00+03	2017-09-02 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19668	PG0700	2017-08-13 10:10:00+03	2017-08-13 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-13 10:13:00+03	2017-08-13 11:23:00+03
19669	PG0700	2017-09-06 10:10:00+03	2017-09-06 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19670	PG0700	2017-07-30 10:10:00+03	2017-07-30 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-30 10:14:00+03	2017-07-30 11:23:00+03
19671	PG0700	2017-08-26 10:10:00+03	2017-08-26 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19672	PG0700	2017-08-19 10:10:00+03	2017-08-19 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19673	PG0700	2017-07-17 10:10:00+03	2017-07-17 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-17 10:14:00+03	2017-07-17 11:24:00+03
19674	PG0700	2017-09-04 10:10:00+03	2017-09-04 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19675	PG0700	2017-09-05 10:10:00+03	2017-09-05 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19676	PG0700	2017-08-11 10:10:00+03	2017-08-11 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-11 10:11:00+03	2017-08-11 11:21:00+03
19677	PG0700	2017-08-22 10:10:00+03	2017-08-22 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19678	PG0700	2017-07-24 10:10:00+03	2017-07-24 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-24 10:14:00+03	2017-07-24 11:24:00+03
19679	PG0700	2017-07-28 10:10:00+03	2017-07-28 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-28 10:10:00+03	2017-07-28 11:21:00+03
19680	PG0700	2017-07-18 10:10:00+03	2017-07-18 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-18 10:12:00+03	2017-07-18 11:21:00+03
19681	PG0700	2017-08-03 10:10:00+03	2017-08-03 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-03 10:12:00+03	2017-08-03 11:22:00+03
19682	PG0700	2017-09-08 10:10:00+03	2017-09-08 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19683	PG0700	2017-08-01 10:10:00+03	2017-08-01 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-01 10:10:00+03	2017-08-01 11:19:00+03
19684	PG0700	2017-08-28 10:10:00+03	2017-08-28 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19685	PG0700	2017-09-12 10:10:00+03	2017-09-12 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19686	PG0700	2017-08-29 10:10:00+03	2017-08-29 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19687	PG0700	2017-09-10 10:10:00+03	2017-09-10 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19688	PG0700	2017-08-18 10:10:00+03	2017-08-18 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19689	PG0700	2017-07-27 10:10:00+03	2017-07-27 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-27 10:13:00+03	2017-07-27 11:24:00+03
19690	PG0700	2017-07-29 10:10:00+03	2017-07-29 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-29 10:13:00+03	2017-07-29 11:21:00+03
19691	PG0700	2017-09-03 10:10:00+03	2017-09-03 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19692	PG0700	2017-08-14 10:10:00+03	2017-08-14 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-14 10:13:00+03	2017-08-14 11:23:00+03
19693	PG0700	2017-08-10 10:10:00+03	2017-08-10 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-10 10:13:00+03	2017-08-10 11:23:00+03
19694	PG0700	2017-08-06 10:10:00+03	2017-08-06 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-06 10:12:00+03	2017-08-06 11:22:00+03
19695	PG0700	2017-08-02 10:10:00+03	2017-08-02 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-02 10:14:00+03	2017-08-02 11:23:00+03
19696	PG0700	2017-07-22 10:10:00+03	2017-07-22 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-22 10:13:00+03	2017-07-22 11:23:00+03
19697	PG0700	2017-07-23 10:10:00+03	2017-07-23 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-23 13:25:00+03	2017-07-23 14:35:00+03
19698	PG0700	2017-08-04 10:10:00+03	2017-08-04 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-04 10:13:00+03	2017-08-04 11:24:00+03
19699	PG0700	2017-09-13 10:10:00+03	2017-09-13 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19700	PG0700	2017-08-16 10:10:00+03	2017-08-16 11:20:00+03	MJZ	YKS	On Time	CR2	\N	\N
19701	PG0700	2017-08-27 10:10:00+03	2017-08-27 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19702	PG0700	2017-08-12 10:10:00+03	2017-08-12 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-12 10:12:00+03	2017-08-12 11:23:00+03
19703	PG0700	2017-08-24 10:10:00+03	2017-08-24 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19704	PG0700	2017-08-07 10:10:00+03	2017-08-07 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-07 10:14:00+03	2017-08-07 11:24:00+03
19705	PG0700	2017-07-31 10:10:00+03	2017-07-31 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-31 10:13:00+03	2017-07-31 11:24:00+03
19706	PG0700	2017-09-09 10:10:00+03	2017-09-09 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19707	PG0700	2017-07-21 10:10:00+03	2017-07-21 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-21 10:12:00+03	2017-07-21 11:21:00+03
19708	PG0700	2017-08-09 10:10:00+03	2017-08-09 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-09 10:11:00+03	2017-08-09 11:22:00+03
19709	PG0700	2017-08-30 10:10:00+03	2017-08-30 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19710	PG0700	2017-08-08 10:10:00+03	2017-08-08 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-08 10:14:00+03	2017-08-08 11:24:00+03
19711	PG0700	2017-08-20 10:10:00+03	2017-08-20 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19712	PG0700	2017-07-25 10:10:00+03	2017-07-25 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-25 10:15:00+03	2017-07-25 11:25:00+03
19713	PG0700	2017-09-07 10:10:00+03	2017-09-07 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19714	PG0700	2017-08-15 10:10:00+03	2017-08-15 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-15 10:14:00+03	2017-08-15 11:25:00+03
19715	PG0700	2017-07-20 10:10:00+03	2017-07-20 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-20 10:12:00+03	2017-07-20 11:23:00+03
19716	PG0700	2017-09-11 10:10:00+03	2017-09-11 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19717	PG0700	2017-09-14 10:10:00+03	2017-09-14 11:20:00+03	MJZ	YKS	Cancelled	CR2	\N	\N
19718	PG0700	2017-08-21 10:10:00+03	2017-08-21 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19719	PG0700	2017-08-31 10:10:00+03	2017-08-31 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19720	PG0700	2017-07-16 10:10:00+03	2017-07-16 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-16 10:12:00+03	2017-07-16 11:24:00+03
19721	PG0700	2017-07-19 10:10:00+03	2017-07-19 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-07-19 10:15:00+03	2017-07-19 11:25:00+03
19722	PG0700	2017-08-25 10:10:00+03	2017-08-25 11:20:00+03	MJZ	YKS	Scheduled	CR2	\N	\N
19723	PG0700	2017-08-05 10:10:00+03	2017-08-05 11:20:00+03	MJZ	YKS	Arrived	CR2	2017-08-05 10:11:00+03	2017-08-05 11:22:00+03
19724	PG0035	2017-08-09 06:35:00+03	2017-08-09 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-09 06:40:00+03	2017-08-09 09:30:00+03
19725	PG0036	2017-08-15 07:05:00+03	2017-08-15 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-15 07:08:00+03	2017-08-15 09:58:00+03
19726	PG0035	2017-08-15 06:35:00+03	2017-08-15 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-15 06:36:00+03	2017-08-15 09:26:00+03
19727	PG0035	2017-09-03 06:35:00+03	2017-09-03 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19728	PG0036	2017-09-03 07:05:00+03	2017-09-03 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19729	PG0036	2017-07-16 07:05:00+03	2017-07-16 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-16 07:07:00+03	2017-07-16 09:57:00+03
19730	PG0036	2017-08-08 07:05:00+03	2017-08-08 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-08 07:07:00+03	2017-08-08 10:00:00+03
19731	PG0035	2017-08-08 06:35:00+03	2017-08-08 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-08 06:37:00+03	2017-08-08 09:29:00+03
19732	PG0035	2017-07-16 06:35:00+03	2017-07-16 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-16 06:37:00+03	2017-07-16 09:31:00+03
19733	PG0035	2017-08-16 06:35:00+03	2017-08-16 09:25:00+03	MJZ	CNN	On Time	CN1	\N	\N
19734	PG0036	2017-08-16 07:05:00+03	2017-08-16 09:55:00+03	MJZ	CNN	On Time	CN1	\N	\N
19735	PG0036	2017-08-07 07:05:00+03	2017-08-07 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-07 07:06:00+03	2017-08-07 09:56:00+03
19736	PG0035	2017-08-07 06:35:00+03	2017-08-07 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-07 06:37:00+03	2017-08-07 09:28:00+03
19737	PG0036	2017-08-30 07:05:00+03	2017-08-30 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19738	PG0035	2017-08-30 06:35:00+03	2017-08-30 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19739	PG0035	2017-09-04 06:35:00+03	2017-09-04 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19740	PG0036	2017-09-04 07:05:00+03	2017-09-04 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19741	PG0035	2017-08-10 06:35:00+03	2017-08-10 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-10 06:38:00+03	2017-08-10 09:32:00+03
19742	PG0036	2017-08-10 07:05:00+03	2017-08-10 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-10 07:08:00+03	2017-08-10 09:58:00+03
19743	PG0036	2017-08-06 07:05:00+03	2017-08-06 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-06 07:07:00+03	2017-08-06 09:56:00+03
19744	PG0035	2017-08-06 06:35:00+03	2017-08-06 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-06 06:35:00+03	2017-08-06 09:24:00+03
19745	PG0036	2017-08-05 07:05:00+03	2017-08-05 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-05 07:06:00+03	2017-08-05 09:59:00+03
19746	PG0035	2017-08-05 06:35:00+03	2017-08-05 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-05 06:38:00+03	2017-08-05 09:25:00+03
19747	PG0035	2017-08-17 06:35:00+03	2017-08-17 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19748	PG0036	2017-08-17 07:05:00+03	2017-08-17 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19749	PG0035	2017-09-05 06:35:00+03	2017-09-05 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19750	PG0036	2017-09-05 07:05:00+03	2017-09-05 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19751	PG0036	2017-08-04 07:05:00+03	2017-08-04 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-04 07:08:00+03	2017-08-04 09:58:00+03
19752	PG0035	2017-08-04 06:35:00+03	2017-08-04 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-04 06:39:00+03	2017-08-04 09:28:00+03
19753	PG0036	2017-08-03 07:05:00+03	2017-08-03 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-03 07:06:00+03	2017-08-03 09:55:00+03
19754	PG0035	2017-08-03 06:35:00+03	2017-08-03 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-03 06:39:00+03	2017-08-03 09:32:00+03
19755	PG0036	2017-09-02 07:05:00+03	2017-09-02 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19756	PG0035	2017-09-02 06:35:00+03	2017-09-02 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19757	PG0035	2017-09-06 06:35:00+03	2017-09-06 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19758	PG0036	2017-09-06 07:05:00+03	2017-09-06 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19759	PG0035	2017-08-18 06:35:00+03	2017-08-18 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19760	PG0036	2017-08-18 07:05:00+03	2017-08-18 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19761	PG0036	2017-08-29 07:05:00+03	2017-08-29 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19762	PG0035	2017-08-29 06:35:00+03	2017-08-29 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19763	PG0036	2017-08-02 07:05:00+03	2017-08-02 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-02 07:07:00+03	2017-08-02 09:54:00+03
19764	PG0035	2017-08-02 06:35:00+03	2017-08-02 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-02 06:37:00+03	2017-08-02 09:25:00+03
19765	PG0036	2017-08-01 07:05:00+03	2017-08-01 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-01 07:09:00+03	2017-08-01 09:56:00+03
19766	PG0035	2017-08-01 06:35:00+03	2017-08-01 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-01 06:38:00+03	2017-08-01 09:27:00+03
19767	PG0035	2017-09-07 06:35:00+03	2017-09-07 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19768	PG0036	2017-09-07 07:05:00+03	2017-09-07 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19769	PG0035	2017-08-19 06:35:00+03	2017-08-19 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19770	PG0036	2017-08-19 07:05:00+03	2017-08-19 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19771	PG0036	2017-07-31 07:05:00+03	2017-07-31 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-31 07:06:00+03	2017-07-31 09:57:00+03
19772	PG0035	2017-07-31 06:35:00+03	2017-07-31 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-31 06:37:00+03	2017-07-31 09:26:00+03
19773	PG0035	2017-08-11 06:35:00+03	2017-08-11 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-11 06:36:00+03	2017-08-11 09:28:00+03
19774	PG0036	2017-08-11 07:05:00+03	2017-08-11 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-11 07:06:00+03	2017-08-11 10:00:00+03
19775	PG0036	2017-07-30 07:05:00+03	2017-07-30 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-30 07:09:00+03	2017-07-30 10:00:00+03
19776	PG0035	2017-07-30 06:35:00+03	2017-07-30 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-30 06:38:00+03	2017-07-30 09:30:00+03
19777	PG0035	2017-09-08 06:35:00+03	2017-09-08 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19778	PG0036	2017-09-08 07:05:00+03	2017-09-08 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19779	PG0036	2017-07-29 07:05:00+03	2017-07-29 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-29 07:07:00+03	2017-07-29 09:58:00+03
19780	PG0035	2017-07-29 06:35:00+03	2017-07-29 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-29 06:39:00+03	2017-07-29 09:25:00+03
19781	PG0035	2017-08-20 06:35:00+03	2017-08-20 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19782	PG0036	2017-08-20 07:05:00+03	2017-08-20 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19783	PG0036	2017-08-28 07:05:00+03	2017-08-28 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19784	PG0035	2017-08-28 06:35:00+03	2017-08-28 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19785	PG0035	2017-08-31 06:35:00+03	2017-08-31 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19786	PG0036	2017-07-28 07:05:00+03	2017-07-28 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-28 07:12:00+03	2017-07-28 10:00:00+03
19787	PG0035	2017-07-28 06:35:00+03	2017-07-28 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-28 06:38:00+03	2017-07-28 09:30:00+03
19788	PG0036	2017-08-31 07:05:00+03	2017-08-31 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19789	PG0035	2017-09-09 06:35:00+03	2017-09-09 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19790	PG0036	2017-09-09 07:05:00+03	2017-09-09 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19791	PG0036	2017-07-27 07:05:00+03	2017-07-27 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-27 07:06:00+03	2017-07-27 09:57:00+03
19792	PG0035	2017-07-27 06:35:00+03	2017-07-27 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-27 06:36:00+03	2017-07-27 09:25:00+03
19793	PG0035	2017-08-21 06:35:00+03	2017-08-21 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19794	PG0036	2017-08-21 07:05:00+03	2017-08-21 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19795	PG0036	2017-07-26 07:05:00+03	2017-07-26 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-26 07:08:00+03	2017-07-26 10:00:00+03
19796	PG0035	2017-07-26 06:35:00+03	2017-07-26 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-26 06:38:00+03	2017-07-26 09:29:00+03
19797	PG0035	2017-09-10 06:35:00+03	2017-09-10 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19798	PG0036	2017-09-10 07:05:00+03	2017-09-10 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19799	PG0035	2017-08-12 06:35:00+03	2017-08-12 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-12 06:36:00+03	2017-08-12 09:25:00+03
19800	PG0036	2017-08-12 07:05:00+03	2017-08-12 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-12 07:09:00+03	2017-08-12 09:57:00+03
19801	PG0036	2017-07-25 07:05:00+03	2017-07-25 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-25 10:47:00+03	2017-07-25 13:36:00+03
19802	PG0035	2017-07-25 06:35:00+03	2017-07-25 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-25 06:38:00+03	2017-07-25 09:30:00+03
19803	PG0036	2017-08-14 07:05:00+03	2017-08-14 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-14 07:11:00+03	2017-08-14 10:04:00+03
19804	PG0035	2017-08-14 06:35:00+03	2017-08-14 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-14 06:43:00+03	2017-08-14 09:33:00+03
19805	PG0036	2017-07-24 07:05:00+03	2017-07-24 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-24 07:11:00+03	2017-07-24 10:00:00+03
19806	PG0035	2017-07-24 06:35:00+03	2017-07-24 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-24 06:38:00+03	2017-07-24 09:30:00+03
19808	PG0036	2017-09-11 07:05:00+03	2017-09-11 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19809	PG0035	2017-08-22 06:35:00+03	2017-08-22 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19810	PG0036	2017-08-22 07:05:00+03	2017-08-22 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19811	PG0036	2017-08-27 07:05:00+03	2017-08-27 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19812	PG0035	2017-08-27 06:35:00+03	2017-08-27 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19813	PG0036	2017-07-23 07:05:00+03	2017-07-23 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-23 07:06:00+03	2017-07-23 09:56:00+03
19814	PG0035	2017-07-23 06:35:00+03	2017-07-23 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-23 06:39:00+03	2017-07-23 09:30:00+03
19815	PG0036	2017-09-01 07:05:00+03	2017-09-01 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19816	PG0035	2017-09-12 06:35:00+03	2017-09-12 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19817	PG0036	2017-09-12 07:05:00+03	2017-09-12 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19818	PG0035	2017-09-01 06:35:00+03	2017-09-01 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19819	PG0036	2017-07-22 07:05:00+03	2017-07-22 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-22 07:07:00+03	2017-07-22 09:59:00+03
19820	PG0035	2017-07-22 06:35:00+03	2017-07-22 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-22 06:38:00+03	2017-07-22 09:29:00+03
19821	PG0035	2017-08-23 06:35:00+03	2017-08-23 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19822	PG0036	2017-08-23 07:05:00+03	2017-08-23 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19823	PG0036	2017-07-21 07:05:00+03	2017-07-21 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-21 07:10:00+03	2017-07-21 09:59:00+03
19824	PG0035	2017-07-21 06:35:00+03	2017-07-21 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-21 06:38:00+03	2017-07-21 09:27:00+03
19825	PG0035	2017-09-13 06:35:00+03	2017-09-13 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19826	PG0036	2017-09-13 07:05:00+03	2017-09-13 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19827	PG0036	2017-07-20 07:05:00+03	2017-07-20 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-20 07:06:00+03	2017-07-20 09:56:00+03
19828	PG0035	2017-07-20 06:35:00+03	2017-07-20 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-20 06:38:00+03	2017-07-20 09:31:00+03
19829	PG0036	2017-07-19 07:05:00+03	2017-07-19 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-19 07:08:00+03	2017-07-19 09:55:00+03
19830	PG0035	2017-07-19 06:35:00+03	2017-07-19 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-19 06:38:00+03	2017-07-19 09:28:00+03
19831	PG0036	2017-08-26 07:05:00+03	2017-08-26 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19832	PG0035	2017-08-26 06:35:00+03	2017-08-26 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19833	PG0035	2017-08-24 06:35:00+03	2017-08-24 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19834	PG0036	2017-08-24 07:05:00+03	2017-08-24 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19835	PG0035	2017-09-14 06:35:00+03	2017-09-14 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19836	PG0035	2017-08-13 06:35:00+03	2017-08-13 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-08-13 06:41:00+03	2017-08-13 09:30:00+03
19837	PG0036	2017-08-13 07:05:00+03	2017-08-13 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-13 07:06:00+03	2017-08-13 09:58:00+03
19838	PG0036	2017-07-18 07:05:00+03	2017-07-18 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-18 07:06:00+03	2017-07-18 09:57:00+03
19839	PG0035	2017-07-18 06:35:00+03	2017-07-18 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-18 06:38:00+03	2017-07-18 09:27:00+03
19840	PG0036	2017-07-17 07:05:00+03	2017-07-17 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-07-17 07:11:00+03	2017-07-17 09:58:00+03
19841	PG0035	2017-07-17 06:35:00+03	2017-07-17 09:25:00+03	MJZ	CNN	Arrived	CN1	2017-07-17 06:37:00+03	2017-07-17 09:24:00+03
19842	PG0036	2017-09-14 07:05:00+03	2017-09-14 09:55:00+03	MJZ	CNN	Cancelled	CN1	\N	\N
19843	PG0035	2017-08-25 06:35:00+03	2017-08-25 09:25:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19844	PG0036	2017-08-25 07:05:00+03	2017-08-25 09:55:00+03	MJZ	CNN	Scheduled	CN1	\N	\N
19845	PG0036	2017-08-09 07:05:00+03	2017-08-09 09:55:00+03	MJZ	CNN	Arrived	CN1	2017-08-09 07:07:00+03	2017-08-09 09:58:00+03
19846	PG0555	2017-07-31 09:30:00+03	2017-07-31 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-31 09:33:00+03	2017-07-31 11:23:00+03
19847	PG0555	2017-08-18 09:30:00+03	2017-08-18 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19848	PG0555	2017-08-04 09:30:00+03	2017-08-04 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-04 09:35:00+03	2017-08-04 11:26:00+03
19849	PG0555	2017-07-23 09:30:00+03	2017-07-23 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-23 09:33:00+03	2017-07-23 11:22:00+03
19850	PG0555	2017-08-03 09:30:00+03	2017-08-03 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-03 09:31:00+03	2017-08-03 11:21:00+03
19851	PG0555	2017-09-04 09:30:00+03	2017-09-04 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19852	PG0555	2017-09-13 09:30:00+03	2017-09-13 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19853	PG0555	2017-07-27 09:30:00+03	2017-07-27 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-27 09:31:00+03	2017-07-27 11:22:00+03
19854	PG0555	2017-08-12 09:30:00+03	2017-08-12 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-12 09:34:00+03	2017-08-12 11:24:00+03
19855	PG0555	2017-08-27 09:30:00+03	2017-08-27 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19856	PG0555	2017-08-14 09:30:00+03	2017-08-14 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-14 09:34:00+03	2017-08-14 11:24:00+03
19857	PG0555	2017-08-23 09:30:00+03	2017-08-23 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19858	PG0555	2017-07-18 09:30:00+03	2017-07-18 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-18 09:34:00+03	2017-07-18 11:24:00+03
19859	PG0555	2017-07-24 09:30:00+03	2017-07-24 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-24 09:34:00+03	2017-07-24 11:24:00+03
19860	PG0555	2017-08-20 09:30:00+03	2017-08-20 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19861	PG0555	2017-08-30 09:30:00+03	2017-08-30 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19862	PG0555	2017-07-26 09:30:00+03	2017-07-26 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-26 09:32:00+03	2017-07-26 11:23:00+03
19863	PG0555	2017-08-16 09:30:00+03	2017-08-16 11:20:00+03	MJZ	IKT	On Time	CR2	\N	\N
19864	PG0555	2017-08-08 09:30:00+03	2017-08-08 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-08 09:32:00+03	2017-08-08 11:21:00+03
19865	PG0555	2017-09-05 09:30:00+03	2017-09-05 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19866	PG0555	2017-08-17 09:30:00+03	2017-08-17 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19867	PG0555	2017-08-29 09:30:00+03	2017-08-29 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19868	PG0555	2017-09-02 09:30:00+03	2017-09-02 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19869	PG0555	2017-08-05 09:30:00+03	2017-08-05 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-05 09:33:00+03	2017-08-05 11:21:00+03
19870	PG0555	2017-08-02 09:30:00+03	2017-08-02 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-02 09:32:00+03	2017-08-02 11:22:00+03
19871	PG0555	2017-08-11 09:30:00+03	2017-08-11 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-11 09:33:00+03	2017-08-11 11:25:00+03
19872	PG0555	2017-07-17 09:30:00+03	2017-07-17 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-17 09:32:00+03	2017-07-17 11:21:00+03
19873	PG0555	2017-07-19 09:30:00+03	2017-07-19 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-19 09:33:00+03	2017-07-19 11:24:00+03
19874	PG0555	2017-08-25 09:30:00+03	2017-08-25 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19875	PG0555	2017-07-30 09:30:00+03	2017-07-30 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-30 09:37:00+03	2017-07-30 11:30:00+03
19876	PG0555	2017-08-19 09:30:00+03	2017-08-19 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19877	PG0555	2017-08-31 09:30:00+03	2017-08-31 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19878	PG0555	2017-08-26 09:30:00+03	2017-08-26 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19879	PG0555	2017-09-08 09:30:00+03	2017-09-08 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19880	PG0555	2017-08-06 09:30:00+03	2017-08-06 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-06 09:35:00+03	2017-08-06 11:24:00+03
19881	PG0555	2017-09-09 09:30:00+03	2017-09-09 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19882	PG0555	2017-07-21 09:30:00+03	2017-07-21 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-21 09:34:00+03	2017-07-21 11:23:00+03
19883	PG0555	2017-09-03 09:30:00+03	2017-09-03 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19884	PG0555	2017-07-29 09:30:00+03	2017-07-29 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-29 09:32:00+03	2017-07-29 11:22:00+03
19885	PG0555	2017-08-24 09:30:00+03	2017-08-24 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19886	PG0555	2017-08-21 09:30:00+03	2017-08-21 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19887	PG0555	2017-09-14 09:30:00+03	2017-09-14 11:20:00+03	MJZ	IKT	Cancelled	CR2	\N	\N
19888	PG0555	2017-08-13 09:30:00+03	2017-08-13 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-13 09:34:00+03	2017-08-13 11:24:00+03
19889	PG0555	2017-09-11 09:30:00+03	2017-09-11 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19890	PG0555	2017-08-01 09:30:00+03	2017-08-01 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-01 09:34:00+03	2017-08-01 11:24:00+03
19891	PG0555	2017-08-09 09:30:00+03	2017-08-09 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-09 09:33:00+03	2017-08-09 11:23:00+03
19892	PG0555	2017-08-22 09:30:00+03	2017-08-22 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19893	PG0555	2017-07-28 09:30:00+03	2017-07-28 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-28 09:35:00+03	2017-07-28 11:25:00+03
19894	PG0555	2017-07-25 09:30:00+03	2017-07-25 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-25 09:33:00+03	2017-07-25 11:22:00+03
19895	PG0555	2017-07-16 09:30:00+03	2017-07-16 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-16 09:36:00+03	2017-07-16 11:26:00+03
19896	PG0555	2017-08-10 09:30:00+03	2017-08-10 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-10 12:15:00+03	2017-08-10 14:06:00+03
19897	PG0555	2017-09-12 09:30:00+03	2017-09-12 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19898	PG0555	2017-08-07 09:30:00+03	2017-08-07 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-07 09:34:00+03	2017-08-07 11:23:00+03
19899	PG0555	2017-08-15 09:30:00+03	2017-08-15 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-08-15 09:33:00+03	2017-08-15 11:23:00+03
19900	PG0555	2017-09-10 09:30:00+03	2017-09-10 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19901	PG0555	2017-07-22 09:30:00+03	2017-07-22 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-22 12:33:00+03	2017-07-22 14:24:00+03
19902	PG0555	2017-09-06 09:30:00+03	2017-09-06 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19903	PG0555	2017-09-01 09:30:00+03	2017-09-01 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19904	PG0555	2017-09-07 09:30:00+03	2017-09-07 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19905	PG0555	2017-07-20 09:30:00+03	2017-07-20 11:20:00+03	MJZ	IKT	Arrived	CR2	2017-07-20 09:32:00+03	2017-07-20 11:23:00+03
19906	PG0555	2017-08-28 09:30:00+03	2017-08-28 11:20:00+03	MJZ	IKT	Scheduled	CR2	\N	\N
19907	PG0706	2017-08-22 07:30:00+03	2017-08-22 13:55:00+03	GDX	SCW	Scheduled	763	\N	\N
19908	PG0706	2017-07-18 07:30:00+03	2017-07-18 13:55:00+03	GDX	SCW	Arrived	763	2017-07-18 07:32:00+03	2017-07-18 13:57:00+03
19909	PG0706	2017-07-25 07:30:00+03	2017-07-25 13:55:00+03	GDX	SCW	Arrived	763	2017-07-25 07:34:00+03	2017-07-25 13:59:00+03
19910	PG0706	2017-08-15 07:30:00+03	2017-08-15 13:55:00+03	GDX	SCW	Arrived	763	2017-08-15 07:33:00+03	2017-08-15 13:57:00+03
19911	PG0706	2017-09-12 07:30:00+03	2017-09-12 13:55:00+03	GDX	SCW	Scheduled	763	\N	\N
19912	PG0706	2017-08-01 07:30:00+03	2017-08-01 13:55:00+03	GDX	SCW	Arrived	763	2017-08-01 07:33:00+03	2017-08-01 14:02:00+03
19913	PG0706	2017-08-29 07:30:00+03	2017-08-29 13:55:00+03	GDX	SCW	Scheduled	763	\N	\N
19914	PG0706	2017-09-05 07:30:00+03	2017-09-05 13:55:00+03	GDX	SCW	Scheduled	763	\N	\N
19915	PG0706	2017-08-08 07:30:00+03	2017-08-08 13:55:00+03	GDX	SCW	Arrived	763	2017-08-08 07:37:00+03	2017-08-08 13:55:00+03
19916	PG0108	2017-09-14 07:30:00+03	2017-09-14 16:15:00+03	GDX	MRV	Scheduled	763	\N	\N
19917	PG0108	2017-08-17 07:30:00+03	2017-08-17 16:15:00+03	GDX	MRV	Scheduled	763	\N	\N
19918	PG0108	2017-07-27 07:30:00+03	2017-07-27 16:15:00+03	GDX	MRV	Arrived	763	2017-07-27 07:31:00+03	2017-07-27 16:27:00+03
19919	PG0108	2017-07-20 07:30:00+03	2017-07-20 16:15:00+03	GDX	MRV	Arrived	763	2017-07-20 07:33:00+03	2017-07-20 16:18:00+03
19920	PG0108	2017-08-03 07:30:00+03	2017-08-03 16:15:00+03	GDX	MRV	Arrived	763	2017-08-03 07:33:00+03	2017-08-03 16:19:00+03
19921	PG0108	2017-08-24 07:30:00+03	2017-08-24 16:15:00+03	GDX	MRV	Scheduled	763	\N	\N
19922	PG0108	2017-08-31 07:30:00+03	2017-08-31 16:15:00+03	GDX	MRV	Scheduled	763	\N	\N
19923	PG0108	2017-08-10 07:30:00+03	2017-08-10 16:15:00+03	GDX	MRV	Arrived	763	2017-08-10 07:34:00+03	2017-08-10 16:18:00+03
19924	PG0108	2017-09-07 07:30:00+03	2017-09-07 16:15:00+03	GDX	MRV	Scheduled	763	\N	\N
19925	PG0267	2017-07-19 10:05:00+03	2017-07-19 14:00:00+03	GDX	IKT	Arrived	SU9	2017-07-19 10:07:00+03	2017-07-19 14:02:00+03
19926	PG0267	2017-08-02 10:05:00+03	2017-08-02 14:00:00+03	GDX	IKT	Arrived	SU9	2017-08-02 10:10:00+03	2017-08-02 14:07:00+03
19927	PG0267	2017-07-16 10:05:00+03	2017-07-16 14:00:00+03	GDX	IKT	Arrived	SU9	2017-07-16 10:09:00+03	2017-07-16 14:03:00+03
19928	PG0267	2017-07-23 10:05:00+03	2017-07-23 14:00:00+03	GDX	IKT	Arrived	SU9	2017-07-23 10:09:00+03	2017-07-23 13:59:00+03
19929	PG0267	2017-09-10 10:05:00+03	2017-09-10 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19930	PG0267	2017-08-13 10:05:00+03	2017-08-13 14:00:00+03	GDX	IKT	Arrived	SU9	2017-08-13 10:07:00+03	2017-08-13 14:04:00+03
19931	PG0267	2017-08-27 10:05:00+03	2017-08-27 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19932	PG0267	2017-08-20 10:05:00+03	2017-08-20 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19933	PG0267	2017-08-16 10:05:00+03	2017-08-16 14:00:00+03	GDX	IKT	On Time	SU9	\N	\N
19934	PG0267	2017-08-06 10:05:00+03	2017-08-06 14:00:00+03	GDX	IKT	Arrived	SU9	2017-08-06 10:07:00+03	2017-08-06 14:04:00+03
19935	PG0267	2017-08-23 10:05:00+03	2017-08-23 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19936	PG0267	2017-08-30 10:05:00+03	2017-08-30 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19937	PG0267	2017-09-13 10:05:00+03	2017-09-13 14:00:00+03	GDX	IKT	Cancelled	SU9	\N	\N
19938	PG0267	2017-07-30 10:05:00+03	2017-07-30 14:00:00+03	GDX	IKT	Arrived	SU9	2017-07-30 10:08:00+03	2017-07-30 14:06:00+03
19939	PG0267	2017-07-26 10:05:00+03	2017-07-26 14:00:00+03	GDX	IKT	Arrived	SU9	2017-07-26 10:07:00+03	2017-07-26 14:05:00+03
19940	PG0267	2017-08-09 10:05:00+03	2017-08-09 14:00:00+03	GDX	IKT	Arrived	SU9	2017-08-09 10:09:00+03	2017-08-09 14:04:00+03
19941	PG0267	2017-09-03 10:05:00+03	2017-09-03 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19942	PG0267	2017-09-06 10:05:00+03	2017-09-06 14:00:00+03	GDX	IKT	Scheduled	SU9	\N	\N
19943	PG0710	2017-08-29 04:25:00+03	2017-08-29 11:05:00+03	CNN	DME	Scheduled	319	\N	\N
19944	PG0710	2017-09-05 04:25:00+03	2017-09-05 11:05:00+03	CNN	DME	Scheduled	319	\N	\N
19945	PG0710	2017-08-15 04:25:00+03	2017-08-15 11:05:00+03	CNN	DME	Arrived	319	2017-08-15 04:27:00+03	2017-08-15 11:13:00+03
19946	PG0710	2017-08-22 04:25:00+03	2017-08-22 11:05:00+03	CNN	DME	Scheduled	319	\N	\N
19947	PG0710	2017-07-25 04:25:00+03	2017-07-25 11:05:00+03	CNN	DME	Arrived	319	2017-07-25 04:27:00+03	2017-07-25 10:59:00+03
19948	PG0710	2017-08-08 04:25:00+03	2017-08-08 11:05:00+03	CNN	DME	Arrived	319	2017-08-08 04:25:00+03	2017-08-08 11:03:00+03
19949	PG0710	2017-09-12 04:25:00+03	2017-09-12 11:05:00+03	CNN	DME	Scheduled	319	\N	\N
19950	PG0710	2017-08-01 04:25:00+03	2017-08-01 11:05:00+03	CNN	DME	Arrived	319	2017-08-01 04:27:00+03	2017-08-01 11:03:00+03
19951	PG0710	2017-07-18 04:25:00+03	2017-07-18 11:05:00+03	CNN	DME	Arrived	319	2017-07-18 04:28:00+03	2017-07-18 11:01:00+03
19952	PG0246	2017-07-17 11:40:00+03	2017-07-17 18:20:00+03	CNN	LED	Arrived	319	2017-07-17 11:41:00+03	2017-07-17 18:24:00+03
19953	PG0246	2017-09-11 11:40:00+03	2017-09-11 18:20:00+03	CNN	LED	Scheduled	319	\N	\N
19954	PG0246	2017-08-28 11:40:00+03	2017-08-28 18:20:00+03	CNN	LED	Scheduled	319	\N	\N
19955	PG0246	2017-07-24 11:40:00+03	2017-07-24 18:20:00+03	CNN	LED	Arrived	319	2017-07-24 14:40:00+03	2017-07-24 21:27:00+03
19956	PG0246	2017-08-21 11:40:00+03	2017-08-21 18:20:00+03	CNN	LED	Scheduled	319	\N	\N
19957	PG0246	2017-09-04 11:40:00+03	2017-09-04 18:20:00+03	CNN	LED	Scheduled	319	\N	\N
19958	PG0246	2017-08-14 11:40:00+03	2017-08-14 18:20:00+03	CNN	LED	Arrived	319	2017-08-14 11:41:00+03	2017-08-14 18:16:00+03
19959	PG0246	2017-08-07 11:40:00+03	2017-08-07 18:20:00+03	CNN	LED	Arrived	319	2017-08-07 11:43:00+03	2017-08-07 18:25:00+03
19960	PG0246	2017-07-31 11:40:00+03	2017-07-31 18:20:00+03	CNN	LED	Arrived	319	2017-07-31 14:55:00+03	2017-07-31 21:39:00+03
19961	PG0395	2017-08-10 04:25:00+03	2017-08-10 09:40:00+03	CNN	PEE	Arrived	319	2017-08-10 04:26:00+03	2017-08-10 09:44:00+03
19962	PG0395	2017-09-07 04:25:00+03	2017-09-07 09:40:00+03	CNN	PEE	Scheduled	319	\N	\N
19963	PG0395	2017-08-24 04:25:00+03	2017-08-24 09:40:00+03	CNN	PEE	Scheduled	319	\N	\N
19964	PG0395	2017-08-03 04:25:00+03	2017-08-03 09:40:00+03	CNN	PEE	Arrived	319	2017-08-03 04:27:00+03	2017-08-03 09:46:00+03
19965	PG0395	2017-09-14 04:25:00+03	2017-09-14 09:40:00+03	CNN	PEE	Scheduled	319	\N	\N
19966	PG0395	2017-07-27 04:25:00+03	2017-07-27 09:40:00+03	CNN	PEE	Arrived	319	2017-07-27 04:27:00+03	2017-07-27 09:40:00+03
19967	PG0395	2017-08-31 04:25:00+03	2017-08-31 09:40:00+03	CNN	PEE	Scheduled	319	\N	\N
19968	PG0395	2017-08-17 04:25:00+03	2017-08-17 09:40:00+03	CNN	PEE	Scheduled	319	\N	\N
19969	PG0395	2017-07-20 04:25:00+03	2017-07-20 09:40:00+03	CNN	PEE	Arrived	319	2017-07-20 04:29:00+03	2017-07-20 09:42:00+03
19970	PG0037	2017-09-04 03:40:00+03	2017-09-04 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19971	PG0038	2017-07-24 10:05:00+03	2017-07-24 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-24 10:06:00+03	2017-07-24 12:52:00+03
19972	PG0037	2017-07-24 03:40:00+03	2017-07-24 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-24 03:44:00+03	2017-07-24 06:35:00+03
19973	PG0037	2017-07-23 03:40:00+03	2017-07-23 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-23 03:41:00+03	2017-07-23 06:29:00+03
19974	PG0038	2017-09-04 10:05:00+03	2017-09-04 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19975	PG0038	2017-07-23 10:05:00+03	2017-07-23 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-23 10:06:00+03	2017-07-23 12:59:00+03
19976	PG0038	2017-08-11 10:05:00+03	2017-08-11 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-11 13:20:00+03	2017-08-11 16:14:00+03
19977	PG0038	2017-09-01 10:05:00+03	2017-09-01 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19978	PG0038	2017-08-18 10:05:00+03	2017-08-18 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19979	PG0037	2017-08-18 03:40:00+03	2017-08-18 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19980	PG0038	2017-07-31 10:05:00+03	2017-07-31 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-31 10:09:00+03	2017-07-31 13:00:00+03
19981	PG0038	2017-09-06 10:05:00+03	2017-09-06 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19982	PG0037	2017-08-10 03:40:00+03	2017-08-10 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-10 07:06:00+03	2017-08-10 09:56:00+03
19983	PG0038	2017-08-10 10:05:00+03	2017-08-10 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-10 10:09:00+03	2017-08-10 13:01:00+03
19984	PG0038	2017-08-06 10:05:00+03	2017-08-06 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-06 10:08:00+03	2017-08-06 12:58:00+03
19985	PG0037	2017-09-06 03:40:00+03	2017-09-06 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19986	PG0037	2017-08-06 03:40:00+03	2017-08-06 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-06 03:42:00+03	2017-08-06 06:30:00+03
19987	PG0038	2017-07-28 10:05:00+03	2017-07-28 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-28 10:08:00+03	2017-07-28 12:58:00+03
19988	PG0037	2017-08-15 03:40:00+03	2017-08-15 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-15 03:44:00+03	2017-08-15 06:33:00+03
19989	PG0037	2017-09-08 03:40:00+03	2017-09-08 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19990	PG0038	2017-08-27 10:05:00+03	2017-08-27 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19991	PG0037	2017-07-28 03:40:00+03	2017-07-28 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-28 03:45:00+03	2017-07-28 06:35:00+03
19992	PG0037	2017-08-22 03:40:00+03	2017-08-22 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19993	PG0037	2017-08-26 03:40:00+03	2017-08-26 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19994	PG0037	2017-09-02 03:40:00+03	2017-09-02 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19995	PG0038	2017-08-15 10:05:00+03	2017-08-15 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-15 10:05:00+03	2017-08-15 12:53:00+03
19996	PG0037	2017-08-24 03:40:00+03	2017-08-24 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19997	PG0038	2017-08-24 10:05:00+03	2017-08-24 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
19998	PG0037	2017-08-14 03:40:00+03	2017-08-14 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-14 03:43:00+03	2017-08-14 06:31:00+03
19999	PG0037	2017-08-03 03:40:00+03	2017-08-03 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-03 03:41:00+03	2017-08-03 06:30:00+03
20000	PG0037	2017-08-31 03:40:00+03	2017-08-31 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20001	PG0037	2017-07-25 03:40:00+03	2017-07-25 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-25 03:42:00+03	2017-07-25 06:32:00+03
20002	PG0037	2017-07-18 03:40:00+03	2017-07-18 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-18 03:43:00+03	2017-07-18 06:33:00+03
20003	PG0037	2017-09-11 03:40:00+03	2017-09-11 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20004	PG0038	2017-07-18 10:05:00+03	2017-07-18 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-18 10:08:00+03	2017-07-18 12:58:00+03
20005	PG0038	2017-09-11 10:05:00+03	2017-09-11 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20006	PG0037	2017-07-21 03:40:00+03	2017-07-21 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-21 03:47:00+03	2017-07-21 06:39:00+03
20007	PG0038	2017-08-26 10:05:00+03	2017-08-26 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20008	PG0038	2017-08-13 10:05:00+03	2017-08-13 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-13 10:12:00+03	2017-08-13 13:04:00+03
20009	PG0038	2017-08-04 10:05:00+03	2017-08-04 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-04 10:06:00+03	2017-08-04 12:54:00+03
20010	PG0038	2017-08-03 10:05:00+03	2017-08-03 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-03 10:08:00+03	2017-08-03 12:59:00+03
20011	PG0037	2017-07-31 03:40:00+03	2017-07-31 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-31 03:42:00+03	2017-07-31 06:32:00+03
20012	PG0038	2017-09-02 10:05:00+03	2017-09-02 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20013	PG0037	2017-08-13 03:40:00+03	2017-08-13 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-13 03:41:00+03	2017-08-13 06:31:00+03
20014	PG0037	2017-08-04 03:40:00+03	2017-08-04 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-04 03:42:00+03	2017-08-04 06:31:00+03
20015	PG0037	2017-09-01 03:40:00+03	2017-09-01 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20016	PG0038	2017-09-08 10:05:00+03	2017-09-08 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20017	PG0038	2017-08-31 10:05:00+03	2017-08-31 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20018	PG0038	2017-08-22 10:05:00+03	2017-08-22 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20019	PG0037	2017-09-09 03:40:00+03	2017-09-09 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20020	PG0038	2017-09-09 10:05:00+03	2017-09-09 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20021	PG0038	2017-07-25 10:05:00+03	2017-07-25 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-25 10:08:00+03	2017-07-25 12:55:00+03
20022	PG0037	2017-08-27 03:40:00+03	2017-08-27 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20023	PG0037	2017-08-25 03:40:00+03	2017-08-25 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20024	PG0038	2017-08-08 10:05:00+03	2017-08-08 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-08 10:10:00+03	2017-08-08 13:00:00+03
20025	PG0037	2017-08-08 03:40:00+03	2017-08-08 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-08 03:46:00+03	2017-08-08 06:38:00+03
20026	PG0038	2017-08-25 10:05:00+03	2017-08-25 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20027	PG0037	2017-08-01 03:40:00+03	2017-08-01 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-01 03:42:00+03	2017-08-01 06:33:00+03
20028	PG0038	2017-07-21 10:05:00+03	2017-07-21 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-21 10:10:00+03	2017-07-21 13:00:00+03
20029	PG0038	2017-08-01 10:05:00+03	2017-08-01 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-01 10:09:00+03	2017-08-01 12:59:00+03
20030	PG0037	2017-08-11 03:40:00+03	2017-08-11 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-11 03:46:00+03	2017-08-11 06:34:00+03
20031	PG0037	2017-07-29 03:40:00+03	2017-07-29 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-29 03:43:00+03	2017-07-29 06:31:00+03
20032	PG0038	2017-07-29 10:05:00+03	2017-07-29 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-29 10:08:00+03	2017-07-29 13:01:00+03
20033	PG0037	2017-08-12 03:40:00+03	2017-08-12 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-12 03:42:00+03	2017-08-12 06:33:00+03
20034	PG0038	2017-08-23 10:05:00+03	2017-08-23 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20035	PG0037	2017-08-23 03:40:00+03	2017-08-23 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20036	PG0038	2017-08-12 10:05:00+03	2017-08-12 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-12 10:09:00+03	2017-08-12 13:00:00+03
20037	PG0038	2017-08-14 10:05:00+03	2017-08-14 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-14 10:07:00+03	2017-08-14 12:58:00+03
20038	PG0038	2017-09-05 10:05:00+03	2017-09-05 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20039	PG0037	2017-07-22 03:40:00+03	2017-07-22 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-22 03:42:00+03	2017-07-22 06:33:00+03
20040	PG0038	2017-07-30 10:05:00+03	2017-07-30 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-30 10:07:00+03	2017-07-30 12:59:00+03
20041	PG0037	2017-07-26 03:40:00+03	2017-07-26 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-26 03:45:00+03	2017-07-26 06:33:00+03
20042	PG0038	2017-07-26 10:05:00+03	2017-07-26 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-26 14:06:00+03	2017-07-26 16:58:00+03
20043	PG0038	2017-09-14 10:05:00+03	2017-09-14 12:55:00+03	CNN	MJZ	Cancelled	CN1	\N	\N
20044	PG0037	2017-07-30 03:40:00+03	2017-07-30 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-30 03:44:00+03	2017-07-30 06:35:00+03
20045	PG0037	2017-09-05 03:40:00+03	2017-09-05 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20046	PG0038	2017-08-21 10:05:00+03	2017-08-21 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20047	PG0037	2017-08-21 03:40:00+03	2017-08-21 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20048	PG0037	2017-08-20 03:40:00+03	2017-08-20 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20049	PG0038	2017-08-20 10:05:00+03	2017-08-20 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20050	PG0037	2017-08-19 03:40:00+03	2017-08-19 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20051	PG0037	2017-08-16 03:40:00+03	2017-08-16 06:30:00+03	CNN	MJZ	On Time	CN1	\N	\N
20052	PG0038	2017-08-16 10:05:00+03	2017-08-16 12:55:00+03	CNN	MJZ	On Time	CN1	\N	\N
20053	PG0038	2017-07-22 10:05:00+03	2017-07-22 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-22 10:09:00+03	2017-07-22 12:58:00+03
20054	PG0037	2017-07-17 03:40:00+03	2017-07-17 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-17 03:43:00+03	2017-07-17 06:31:00+03
20055	PG0038	2017-07-17 10:05:00+03	2017-07-17 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-17 10:07:00+03	2017-07-17 12:58:00+03
20056	PG0038	2017-08-07 10:05:00+03	2017-08-07 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-07 10:08:00+03	2017-08-07 12:58:00+03
20057	PG0037	2017-08-07 03:40:00+03	2017-08-07 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-07 03:43:00+03	2017-08-07 06:33:00+03
20058	PG0038	2017-08-19 10:05:00+03	2017-08-19 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20059	PG0038	2017-08-28 10:05:00+03	2017-08-28 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20060	PG0037	2017-08-28 03:40:00+03	2017-08-28 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20061	PG0038	2017-08-30 10:05:00+03	2017-08-30 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20062	PG0037	2017-08-30 03:40:00+03	2017-08-30 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20063	PG0037	2017-09-13 03:40:00+03	2017-09-13 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20064	PG0038	2017-09-13 10:05:00+03	2017-09-13 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20065	PG0037	2017-08-02 03:40:00+03	2017-08-02 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-02 03:44:00+03	2017-08-02 06:34:00+03
20066	PG0038	2017-08-02 10:05:00+03	2017-08-02 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-02 10:07:00+03	2017-08-02 12:58:00+03
20067	PG0038	2017-07-20 10:05:00+03	2017-07-20 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-20 10:07:00+03	2017-07-20 12:58:00+03
20068	PG0037	2017-07-20 03:40:00+03	2017-07-20 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-20 03:45:00+03	2017-07-20 06:36:00+03
20069	PG0037	2017-08-29 03:40:00+03	2017-08-29 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20070	PG0038	2017-08-29 10:05:00+03	2017-08-29 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20071	PG0038	2017-09-03 10:05:00+03	2017-09-03 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20072	PG0037	2017-07-16 03:40:00+03	2017-07-16 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-16 03:41:00+03	2017-07-16 06:30:00+03
20073	PG0037	2017-09-03 03:40:00+03	2017-09-03 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20074	PG0038	2017-09-12 10:05:00+03	2017-09-12 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20075	PG0037	2017-09-12 03:40:00+03	2017-09-12 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20076	PG0038	2017-07-16 10:05:00+03	2017-07-16 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-16 10:07:00+03	2017-07-16 12:56:00+03
20077	PG0037	2017-08-17 03:40:00+03	2017-08-17 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20078	PG0038	2017-08-17 10:05:00+03	2017-08-17 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20079	PG0037	2017-08-09 03:40:00+03	2017-08-09 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-09 03:44:00+03	2017-08-09 06:35:00+03
20080	PG0038	2017-09-07 10:05:00+03	2017-09-07 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20081	PG0038	2017-08-09 10:05:00+03	2017-08-09 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-09 10:07:00+03	2017-08-09 12:57:00+03
20082	PG0037	2017-09-07 03:40:00+03	2017-09-07 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20083	PG0038	2017-09-10 10:05:00+03	2017-09-10 12:55:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20084	PG0037	2017-09-10 03:40:00+03	2017-09-10 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20085	PG0037	2017-07-27 03:40:00+03	2017-07-27 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-27 03:41:00+03	2017-07-27 06:28:00+03
20086	PG0038	2017-07-27 10:05:00+03	2017-07-27 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-27 10:07:00+03	2017-07-27 12:55:00+03
20087	PG0037	2017-07-19 03:40:00+03	2017-07-19 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-07-19 06:31:00+03	2017-07-19 09:21:00+03
20088	PG0037	2017-09-14 03:40:00+03	2017-09-14 06:30:00+03	CNN	MJZ	Scheduled	CN1	\N	\N
20089	PG0038	2017-08-05 10:05:00+03	2017-08-05 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-08-05 10:11:00+03	2017-08-05 13:00:00+03
20090	PG0037	2017-08-05 03:40:00+03	2017-08-05 06:30:00+03	CNN	MJZ	Arrived	CN1	2017-08-05 03:41:00+03	2017-08-05 06:32:00+03
20091	PG0038	2017-07-19 10:05:00+03	2017-07-19 12:55:00+03	CNN	MJZ	Arrived	CN1	2017-07-19 12:48:00+03	2017-07-19 15:37:00+03
20092	PG0426	2017-09-04 04:20:00+03	2017-09-04 11:10:00+03	CNN	ASF	Scheduled	319	\N	\N
20093	PG0426	2017-08-21 04:20:00+03	2017-08-21 11:10:00+03	CNN	ASF	Scheduled	319	\N	\N
20094	PG0426	2017-07-17 04:20:00+03	2017-07-17 11:10:00+03	CNN	ASF	Arrived	319	2017-07-17 04:24:00+03	2017-07-17 11:07:00+03
20095	PG0426	2017-08-28 04:20:00+03	2017-08-28 11:10:00+03	CNN	ASF	Scheduled	319	\N	\N
20096	PG0426	2017-08-07 04:20:00+03	2017-08-07 11:10:00+03	CNN	ASF	Arrived	319	2017-08-07 04:20:00+03	2017-08-07 11:06:00+03
20097	PG0426	2017-09-11 04:20:00+03	2017-09-11 11:10:00+03	CNN	ASF	Cancelled	319	\N	\N
20098	PG0426	2017-08-14 04:20:00+03	2017-08-14 11:10:00+03	CNN	ASF	Arrived	319	2017-08-14 04:25:00+03	2017-08-14 11:16:00+03
20099	PG0426	2017-07-31 04:20:00+03	2017-07-31 11:10:00+03	CNN	ASF	Arrived	319	2017-07-31 04:22:00+03	2017-07-31 11:23:00+03
20100	PG0426	2017-07-24 04:20:00+03	2017-07-24 11:10:00+03	CNN	ASF	Arrived	319	2017-07-24 04:22:00+03	2017-07-24 11:11:00+03
20101	PG0211	2017-08-05 11:35:00+03	2017-08-05 13:25:00+03	MRV	DME	Arrived	733	2017-08-05 11:37:00+03	2017-08-05 13:25:00+03
20102	PG0211	2017-08-28 11:35:00+03	2017-08-28 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20103	PG0211	2017-08-27 11:35:00+03	2017-08-27 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20104	PG0211	2017-08-09 11:35:00+03	2017-08-09 13:25:00+03	MRV	DME	Arrived	733	2017-08-09 11:38:00+03	2017-08-09 13:27:00+03
20105	PG0211	2017-08-08 11:35:00+03	2017-08-08 13:25:00+03	MRV	DME	Arrived	733	2017-08-08 11:39:00+03	2017-08-08 13:32:00+03
20106	PG0211	2017-08-13 11:35:00+03	2017-08-13 13:25:00+03	MRV	DME	Arrived	733	2017-08-13 11:38:00+03	2017-08-13 13:28:00+03
20107	PG0211	2017-08-30 11:35:00+03	2017-08-30 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20108	PG0211	2017-09-03 11:35:00+03	2017-09-03 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20109	PG0211	2017-08-07 11:35:00+03	2017-08-07 13:25:00+03	MRV	DME	Arrived	733	2017-08-07 11:37:00+03	2017-08-07 13:27:00+03
20110	PG0211	2017-07-25 11:35:00+03	2017-07-25 13:25:00+03	MRV	DME	Arrived	733	2017-07-25 11:36:00+03	2017-07-25 13:26:00+03
20111	PG0211	2017-07-24 11:35:00+03	2017-07-24 13:25:00+03	MRV	DME	Arrived	733	2017-07-24 11:38:00+03	2017-07-24 13:28:00+03
20112	PG0211	2017-09-01 11:35:00+03	2017-09-01 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20113	PG0211	2017-08-15 11:35:00+03	2017-08-15 13:25:00+03	MRV	DME	Arrived	733	2017-08-15 11:38:00+03	2017-08-15 13:26:00+03
20114	PG0211	2017-09-02 11:35:00+03	2017-09-02 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20115	PG0211	2017-07-17 11:35:00+03	2017-07-17 13:25:00+03	MRV	DME	Arrived	733	2017-07-17 11:39:00+03	2017-07-17 13:29:00+03
20116	PG0211	2017-07-26 11:35:00+03	2017-07-26 13:25:00+03	MRV	DME	Arrived	733	2017-07-26 11:40:00+03	2017-07-26 13:31:00+03
20117	PG0211	2017-08-16 11:35:00+03	2017-08-16 13:25:00+03	MRV	DME	On Time	733	\N	\N
20118	PG0211	2017-09-10 11:35:00+03	2017-09-10 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20119	PG0211	2017-08-06 11:35:00+03	2017-08-06 13:25:00+03	MRV	DME	Arrived	733	2017-08-06 11:39:00+03	2017-08-06 13:26:00+03
20120	PG0211	2017-09-04 11:35:00+03	2017-09-04 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20121	PG0211	2017-09-14 11:35:00+03	2017-09-14 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20122	PG0211	2017-08-24 11:35:00+03	2017-08-24 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20123	PG0211	2017-07-18 11:35:00+03	2017-07-18 13:25:00+03	MRV	DME	Arrived	733	2017-07-18 11:37:00+03	2017-07-18 13:27:00+03
20124	PG0211	2017-09-09 11:35:00+03	2017-09-09 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20125	PG0211	2017-07-27 11:35:00+03	2017-07-27 13:25:00+03	MRV	DME	Arrived	733	2017-07-27 11:36:00+03	2017-07-27 13:27:00+03
20126	PG0211	2017-08-04 11:35:00+03	2017-08-04 13:25:00+03	MRV	DME	Arrived	733	2017-08-04 11:39:00+03	2017-08-04 13:31:00+03
20127	PG0211	2017-08-17 11:35:00+03	2017-08-17 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20128	PG0211	2017-08-10 11:35:00+03	2017-08-10 13:25:00+03	MRV	DME	Arrived	733	2017-08-10 11:37:00+03	2017-08-10 13:28:00+03
20129	PG0211	2017-09-05 11:35:00+03	2017-09-05 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20130	PG0211	2017-08-29 11:35:00+03	2017-08-29 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20131	PG0211	2017-07-19 11:35:00+03	2017-07-19 13:25:00+03	MRV	DME	Arrived	733	2017-07-19 11:40:00+03	2017-07-19 13:32:00+03
20132	PG0211	2017-08-03 11:35:00+03	2017-08-03 13:25:00+03	MRV	DME	Arrived	733	2017-08-03 11:36:00+03	2017-08-03 13:25:00+03
20133	PG0211	2017-09-11 11:35:00+03	2017-09-11 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20134	PG0211	2017-08-20 11:35:00+03	2017-08-20 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20135	PG0211	2017-07-23 11:35:00+03	2017-07-23 13:25:00+03	MRV	DME	Arrived	733	2017-07-23 11:36:00+03	2017-07-23 13:27:00+03
20136	PG0211	2017-08-25 11:35:00+03	2017-08-25 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20137	PG0211	2017-09-13 11:35:00+03	2017-09-13 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20138	PG0211	2017-08-31 11:35:00+03	2017-08-31 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20139	PG0211	2017-08-22 11:35:00+03	2017-08-22 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20140	PG0211	2017-08-02 11:35:00+03	2017-08-02 13:25:00+03	MRV	DME	Arrived	733	2017-08-02 11:37:00+03	2017-08-02 13:29:00+03
20141	PG0211	2017-07-28 11:35:00+03	2017-07-28 13:25:00+03	MRV	DME	Arrived	733	2017-07-28 11:39:00+03	2017-07-28 13:28:00+03
20142	PG0211	2017-08-26 11:35:00+03	2017-08-26 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20143	PG0211	2017-08-12 11:35:00+03	2017-08-12 13:25:00+03	MRV	DME	Arrived	733	2017-08-12 11:36:00+03	2017-08-12 13:26:00+03
20144	PG0211	2017-09-06 11:35:00+03	2017-09-06 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20145	PG0211	2017-08-14 11:35:00+03	2017-08-14 13:25:00+03	MRV	DME	Arrived	733	2017-08-14 11:39:00+03	2017-08-14 13:29:00+03
20146	PG0211	2017-08-18 11:35:00+03	2017-08-18 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20147	PG0211	2017-07-20 11:35:00+03	2017-07-20 13:25:00+03	MRV	DME	Arrived	733	2017-07-20 11:37:00+03	2017-07-20 13:27:00+03
20148	PG0211	2017-08-11 11:35:00+03	2017-08-11 13:25:00+03	MRV	DME	Arrived	733	2017-08-11 11:37:00+03	2017-08-11 13:26:00+03
20149	PG0211	2017-08-01 11:35:00+03	2017-08-01 13:25:00+03	MRV	DME	Arrived	733	2017-08-01 14:48:00+03	2017-08-01 16:37:00+03
20150	PG0211	2017-08-23 11:35:00+03	2017-08-23 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20151	PG0211	2017-07-31 11:35:00+03	2017-07-31 13:25:00+03	MRV	DME	Arrived	733	2017-07-31 11:40:00+03	2017-07-31 13:30:00+03
20152	PG0211	2017-08-21 11:35:00+03	2017-08-21 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20153	PG0211	2017-07-21 11:35:00+03	2017-07-21 13:25:00+03	MRV	DME	Arrived	733	2017-07-21 11:37:00+03	2017-07-21 13:29:00+03
20154	PG0211	2017-09-08 11:35:00+03	2017-09-08 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20155	PG0211	2017-09-07 11:35:00+03	2017-09-07 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20156	PG0211	2017-07-29 11:35:00+03	2017-07-29 13:25:00+03	MRV	DME	Arrived	733	2017-07-29 11:39:00+03	2017-07-29 13:29:00+03
20157	PG0211	2017-09-12 11:35:00+03	2017-09-12 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20158	PG0211	2017-08-19 11:35:00+03	2017-08-19 13:25:00+03	MRV	DME	Scheduled	733	\N	\N
20159	PG0211	2017-07-16 11:35:00+03	2017-07-16 13:25:00+03	MRV	DME	Arrived	733	2017-07-16 11:38:00+03	2017-07-16 13:29:00+03
20160	PG0211	2017-07-30 11:35:00+03	2017-07-30 13:25:00+03	MRV	DME	Arrived	733	2017-07-30 11:42:00+03	2017-07-30 13:32:00+03
20161	PG0211	2017-07-22 11:35:00+03	2017-07-22 13:25:00+03	MRV	DME	Arrived	733	2017-07-22 11:37:00+03	2017-07-22 13:28:00+03
20162	PG0447	2017-09-06 13:20:00+03	2017-09-06 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20163	PG0447	2017-08-23 13:20:00+03	2017-08-23 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20164	PG0447	2017-08-09 13:20:00+03	2017-08-09 15:15:00+03	MRV	KZN	Arrived	CR2	2017-08-09 13:25:00+03	2017-08-09 15:20:00+03
20165	PG0447	2017-07-29 13:20:00+03	2017-07-29 15:15:00+03	MRV	KZN	Arrived	CR2	2017-07-29 13:20:00+03	2017-07-29 15:15:00+03
20166	PG0447	2017-08-19 13:20:00+03	2017-08-19 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20167	PG0447	2017-08-05 13:20:00+03	2017-08-05 15:15:00+03	MRV	KZN	Arrived	CR2	2017-08-05 13:23:00+03	2017-08-05 15:18:00+03
20168	PG0447	2017-09-13 13:20:00+03	2017-09-13 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20169	PG0447	2017-09-09 13:20:00+03	2017-09-09 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20170	PG0447	2017-08-30 13:20:00+03	2017-08-30 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20171	PG0447	2017-08-02 13:20:00+03	2017-08-02 15:15:00+03	MRV	KZN	Arrived	CR2	2017-08-02 13:24:00+03	2017-08-02 15:20:00+03
20172	PG0447	2017-08-12 13:20:00+03	2017-08-12 15:15:00+03	MRV	KZN	Arrived	CR2	2017-08-12 13:23:00+03	2017-08-12 15:21:00+03
20173	PG0447	2017-08-26 13:20:00+03	2017-08-26 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20174	PG0447	2017-07-22 13:20:00+03	2017-07-22 15:15:00+03	MRV	KZN	Arrived	CR2	2017-07-22 13:21:00+03	2017-07-22 15:16:00+03
20175	PG0447	2017-08-16 13:20:00+03	2017-08-16 15:15:00+03	MRV	KZN	On Time	CR2	\N	\N
20176	PG0447	2017-07-26 13:20:00+03	2017-07-26 15:15:00+03	MRV	KZN	Arrived	CR2	2017-07-26 13:21:00+03	2017-07-26 15:16:00+03
20177	PG0447	2017-09-02 13:20:00+03	2017-09-02 15:15:00+03	MRV	KZN	Scheduled	CR2	\N	\N
20178	PG0447	2017-07-19 13:20:00+03	2017-07-19 15:15:00+03	MRV	KZN	Arrived	CR2	2017-07-19 13:22:00+03	2017-07-19 15:17:00+03
20179	PG0320	2017-08-19 13:55:00+03	2017-08-19 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20180	PG0320	2017-08-31 13:55:00+03	2017-08-31 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20181	PG0320	2017-08-21 13:55:00+03	2017-08-21 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20182	PG0320	2017-09-02 13:55:00+03	2017-09-02 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20183	PG0320	2017-09-13 13:55:00+03	2017-09-13 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20184	PG0320	2017-07-28 13:55:00+03	2017-07-28 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-28 13:57:00+03	2017-07-28 16:17:00+03
20185	PG0320	2017-09-01 13:55:00+03	2017-09-01 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20186	PG0320	2017-07-22 13:55:00+03	2017-07-22 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-22 13:59:00+03	2017-07-22 16:17:00+03
20187	PG0320	2017-08-15 13:55:00+03	2017-08-15 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-15 13:55:00+03	2017-08-15 16:16:00+03
20188	PG0320	2017-07-19 13:55:00+03	2017-07-19 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-19 13:57:00+03	2017-07-19 16:18:00+03
20189	PG0320	2017-08-17 13:55:00+03	2017-08-17 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20190	PG0320	2017-08-08 13:55:00+03	2017-08-08 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-08 14:02:00+03	2017-08-08 16:22:00+03
20191	PG0320	2017-08-05 13:55:00+03	2017-08-05 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-05 14:01:00+03	2017-08-05 16:21:00+03
20192	PG0320	2017-08-13 13:55:00+03	2017-08-13 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-13 13:58:00+03	2017-08-13 16:17:00+03
20193	PG0320	2017-08-04 13:55:00+03	2017-08-04 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-04 13:58:00+03	2017-08-04 16:18:00+03
20194	PG0320	2017-08-29 13:55:00+03	2017-08-29 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20195	PG0320	2017-08-20 13:55:00+03	2017-08-20 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20196	PG0320	2017-09-04 13:55:00+03	2017-09-04 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20197	PG0320	2017-08-27 13:55:00+03	2017-08-27 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20198	PG0320	2017-07-21 13:55:00+03	2017-07-21 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-21 13:57:00+03	2017-07-21 16:18:00+03
20199	PG0320	2017-08-09 13:55:00+03	2017-08-09 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-09 17:03:00+03	2017-08-09 19:20:00+03
20200	PG0320	2017-08-10 13:55:00+03	2017-08-10 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-10 13:58:00+03	2017-08-10 16:19:00+03
20201	PG0320	2017-09-12 13:55:00+03	2017-09-12 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20202	PG0320	2017-09-03 13:55:00+03	2017-09-03 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20203	PG0320	2017-07-20 13:55:00+03	2017-07-20 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-20 17:22:00+03	2017-07-20 19:41:00+03
20204	PG0320	2017-08-16 13:55:00+03	2017-08-16 16:15:00+03	MRV	PEE	On Time	SU9	\N	\N
20205	PG0320	2017-07-18 13:55:00+03	2017-07-18 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-18 13:57:00+03	2017-07-18 16:19:00+03
20206	PG0320	2017-08-11 13:55:00+03	2017-08-11 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-11 14:00:00+03	2017-08-11 16:22:00+03
20207	PG0320	2017-08-06 13:55:00+03	2017-08-06 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-06 14:00:00+03	2017-08-06 16:19:00+03
20208	PG0320	2017-07-17 13:55:00+03	2017-07-17 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-17 13:56:00+03	2017-07-17 16:16:00+03
20209	PG0320	2017-08-30 13:55:00+03	2017-08-30 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20210	PG0320	2017-08-07 13:55:00+03	2017-08-07 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-07 13:57:00+03	2017-08-07 16:19:00+03
20211	PG0320	2017-08-18 13:55:00+03	2017-08-18 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20212	PG0320	2017-08-01 13:55:00+03	2017-08-01 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-01 13:56:00+03	2017-08-01 16:17:00+03
20213	PG0320	2017-09-06 13:55:00+03	2017-09-06 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20214	PG0320	2017-09-11 13:55:00+03	2017-09-11 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20215	PG0320	2017-08-28 13:55:00+03	2017-08-28 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20216	PG0320	2017-08-23 13:55:00+03	2017-08-23 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20217	PG0320	2017-09-10 13:55:00+03	2017-09-10 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20218	PG0320	2017-09-08 13:55:00+03	2017-09-08 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20219	PG0320	2017-08-02 13:55:00+03	2017-08-02 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-02 16:48:00+03	2017-08-02 19:09:00+03
20220	PG0320	2017-09-09 13:55:00+03	2017-09-09 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20221	PG0320	2017-08-22 13:55:00+03	2017-08-22 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20222	PG0320	2017-07-26 13:55:00+03	2017-07-26 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-26 13:58:00+03	2017-07-26 16:18:00+03
20223	PG0320	2017-07-23 13:55:00+03	2017-07-23 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-23 13:56:00+03	2017-07-23 16:16:00+03
20224	PG0320	2017-09-07 13:55:00+03	2017-09-07 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20225	PG0320	2017-07-30 13:55:00+03	2017-07-30 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-30 14:00:00+03	2017-07-30 16:19:00+03
20226	PG0320	2017-08-14 13:55:00+03	2017-08-14 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-14 14:00:00+03	2017-08-14 16:19:00+03
20227	PG0320	2017-07-29 13:55:00+03	2017-07-29 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-29 14:01:00+03	2017-07-29 16:19:00+03
20228	PG0320	2017-07-31 13:55:00+03	2017-07-31 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-31 14:00:00+03	2017-07-31 16:17:00+03
20229	PG0320	2017-08-12 13:55:00+03	2017-08-12 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-12 13:57:00+03	2017-08-12 16:20:00+03
20230	PG0320	2017-08-03 13:55:00+03	2017-08-03 16:15:00+03	MRV	PEE	Arrived	SU9	2017-08-03 13:58:00+03	2017-08-03 16:18:00+03
20231	PG0320	2017-08-24 13:55:00+03	2017-08-24 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20232	PG0320	2017-07-27 13:55:00+03	2017-07-27 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-27 13:57:00+03	2017-07-27 16:16:00+03
20233	PG0320	2017-09-05 13:55:00+03	2017-09-05 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20234	PG0320	2017-07-16 13:55:00+03	2017-07-16 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-16 13:58:00+03	2017-07-16 16:17:00+03
20235	PG0320	2017-07-24 13:55:00+03	2017-07-24 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-24 13:57:00+03	2017-07-24 16:15:00+03
20236	PG0320	2017-08-25 13:55:00+03	2017-08-25 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20237	PG0320	2017-08-26 13:55:00+03	2017-08-26 16:15:00+03	MRV	PEE	Scheduled	SU9	\N	\N
20238	PG0320	2017-07-25 13:55:00+03	2017-07-25 16:15:00+03	MRV	PEE	Arrived	SU9	2017-07-25 13:59:00+03	2017-07-25 16:18:00+03
20239	PG0320	2017-09-14 13:55:00+03	2017-09-14 16:15:00+03	MRV	PEE	Cancelled	SU9	\N	\N
20240	PG0109	2017-07-30 20:30:00+03	2017-07-31 05:15:00+03	MRV	GDX	Arrived	763	2017-07-30 20:34:00+03	2017-07-31 05:13:00+03
20241	PG0109	2017-08-20 20:30:00+03	2017-08-21 05:15:00+03	MRV	GDX	Scheduled	763	\N	\N
20242	PG0109	2017-08-27 20:30:00+03	2017-08-28 05:15:00+03	MRV	GDX	Scheduled	763	\N	\N
20243	PG0109	2017-07-23 20:30:00+03	2017-07-24 05:15:00+03	MRV	GDX	Arrived	763	2017-07-23 20:31:00+03	2017-07-24 05:14:00+03
20244	PG0109	2017-09-03 20:30:00+03	2017-09-04 05:15:00+03	MRV	GDX	Scheduled	763	\N	\N
20245	PG0109	2017-09-10 20:30:00+03	2017-09-11 05:15:00+03	MRV	GDX	Scheduled	763	\N	\N
20246	PG0109	2017-08-13 20:30:00+03	2017-08-14 05:15:00+03	MRV	GDX	Arrived	763	2017-08-13 20:31:00+03	2017-08-14 05:16:00+03
20247	PG0109	2017-08-06 20:30:00+03	2017-08-07 05:15:00+03	MRV	GDX	Arrived	763	2017-08-06 20:34:00+03	2017-08-07 05:23:00+03
20248	PG0109	2017-07-16 20:30:00+03	2017-07-17 05:15:00+03	MRV	GDX	Arrived	763	2017-07-16 20:32:00+03	2017-07-17 05:23:00+03
20249	PG0150	2017-08-10 13:20:00+03	2017-08-10 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-10 13:22:00+03	2017-08-10 13:52:00+03
20250	PG0150	2017-08-24 13:20:00+03	2017-08-24 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20251	PG0150	2017-07-19 13:20:00+03	2017-07-19 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-19 13:23:00+03	2017-07-19 13:53:00+03
20252	PG0150	2017-08-14 13:20:00+03	2017-08-14 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-14 16:05:00+03	2017-08-14 16:35:00+03
20253	PG0150	2017-08-05 13:20:00+03	2017-08-05 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-05 13:25:00+03	2017-08-05 13:55:00+03
20254	PG0150	2017-08-22 13:20:00+03	2017-08-22 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20255	PG0150	2017-08-03 13:20:00+03	2017-08-03 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-03 13:21:00+03	2017-08-03 13:52:00+03
20256	PG0150	2017-09-10 13:20:00+03	2017-09-10 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20257	PG0150	2017-08-26 13:20:00+03	2017-08-26 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20258	PG0150	2017-07-18 13:20:00+03	2017-07-18 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-18 13:24:00+03	2017-07-18 13:54:00+03
20259	PG0150	2017-08-09 13:20:00+03	2017-08-09 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-09 13:21:00+03	2017-08-09 13:51:00+03
20260	PG0150	2017-09-02 13:20:00+03	2017-09-02 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20261	PG0150	2017-07-25 13:20:00+03	2017-07-25 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-25 13:24:00+03	2017-07-25 13:54:00+03
20262	PG0150	2017-09-08 13:20:00+03	2017-09-08 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20263	PG0150	2017-08-29 13:20:00+03	2017-08-29 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20264	PG0150	2017-08-19 13:20:00+03	2017-08-19 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20265	PG0150	2017-07-23 13:20:00+03	2017-07-23 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-23 13:25:00+03	2017-07-23 13:55:00+03
20266	PG0150	2017-09-04 13:20:00+03	2017-09-04 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20267	PG0150	2017-09-13 13:20:00+03	2017-09-13 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20268	PG0150	2017-08-06 13:20:00+03	2017-08-06 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-06 13:27:00+03	2017-08-06 13:57:00+03
20269	PG0150	2017-07-28 13:20:00+03	2017-07-28 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-28 13:22:00+03	2017-07-28 13:51:00+03
20270	PG0150	2017-09-06 13:20:00+03	2017-09-06 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20271	PG0150	2017-08-20 13:20:00+03	2017-08-20 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20272	PG0150	2017-07-16 13:20:00+03	2017-07-16 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-16 13:23:00+03	2017-07-16 13:53:00+03
20273	PG0150	2017-08-02 13:20:00+03	2017-08-02 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-02 16:55:00+03	2017-08-02 17:25:00+03
20274	PG0150	2017-08-18 13:20:00+03	2017-08-18 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20275	PG0150	2017-08-27 13:20:00+03	2017-08-27 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20276	PG0150	2017-08-31 13:20:00+03	2017-08-31 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20277	PG0150	2017-07-26 13:20:00+03	2017-07-26 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-26 13:24:00+03	2017-07-26 13:54:00+03
20278	PG0150	2017-07-17 13:20:00+03	2017-07-17 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-17 13:21:00+03	2017-07-17 13:51:00+03
20279	PG0150	2017-08-16 13:20:00+03	2017-08-16 13:50:00+03	MRV	MCX	On Time	SU9	\N	\N
20280	PG0150	2017-07-20 13:20:00+03	2017-07-20 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-20 13:24:00+03	2017-07-20 13:54:00+03
20281	PG0150	2017-08-13 13:20:00+03	2017-08-13 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-13 13:21:00+03	2017-08-13 13:52:00+03
20282	PG0150	2017-07-24 13:20:00+03	2017-07-24 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-24 13:23:00+03	2017-07-24 13:52:00+03
20283	PG0150	2017-08-07 13:20:00+03	2017-08-07 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-07 13:25:00+03	2017-08-07 13:55:00+03
20284	PG0150	2017-09-12 13:20:00+03	2017-09-12 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20285	PG0150	2017-08-30 13:20:00+03	2017-08-30 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20286	PG0150	2017-09-14 13:20:00+03	2017-09-14 13:50:00+03	MRV	MCX	Cancelled	SU9	\N	\N
20287	PG0150	2017-07-30 13:20:00+03	2017-07-30 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-30 13:24:00+03	2017-07-30 13:53:00+03
20288	PG0150	2017-08-01 13:20:00+03	2017-08-01 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-01 13:22:00+03	2017-08-01 13:52:00+03
20289	PG0150	2017-09-03 13:20:00+03	2017-09-03 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20290	PG0150	2017-08-23 13:20:00+03	2017-08-23 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20291	PG0150	2017-09-01 13:20:00+03	2017-09-01 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20292	PG0150	2017-08-08 13:20:00+03	2017-08-08 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-08 13:20:00+03	2017-08-08 13:50:00+03
20293	PG0150	2017-07-22 13:20:00+03	2017-07-22 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-22 13:23:00+03	2017-07-22 13:53:00+03
20294	PG0150	2017-08-21 13:20:00+03	2017-08-21 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20295	PG0150	2017-09-07 13:20:00+03	2017-09-07 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20296	PG0150	2017-08-11 13:20:00+03	2017-08-11 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-11 13:25:00+03	2017-08-11 13:55:00+03
20297	PG0150	2017-08-28 13:20:00+03	2017-08-28 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20298	PG0150	2017-07-21 13:20:00+03	2017-07-21 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-21 13:21:00+03	2017-07-21 13:50:00+03
20299	PG0150	2017-07-31 13:20:00+03	2017-07-31 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-31 13:22:00+03	2017-07-31 13:52:00+03
20300	PG0150	2017-07-29 13:20:00+03	2017-07-29 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-29 13:22:00+03	2017-07-29 13:52:00+03
20301	PG0150	2017-08-25 13:20:00+03	2017-08-25 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20302	PG0150	2017-08-15 13:20:00+03	2017-08-15 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-15 13:22:00+03	2017-08-15 13:52:00+03
20303	PG0150	2017-08-04 13:20:00+03	2017-08-04 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-04 13:21:00+03	2017-08-04 13:51:00+03
20304	PG0150	2017-09-05 13:20:00+03	2017-09-05 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20305	PG0150	2017-09-09 13:20:00+03	2017-09-09 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20306	PG0150	2017-07-27 13:20:00+03	2017-07-27 13:50:00+03	MRV	MCX	Arrived	SU9	2017-07-27 16:14:00+03	2017-07-27 16:44:00+03
20307	PG0150	2017-09-11 13:20:00+03	2017-09-11 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20308	PG0150	2017-08-17 13:20:00+03	2017-08-17 13:50:00+03	MRV	MCX	Scheduled	SU9	\N	\N
20309	PG0150	2017-08-12 13:20:00+03	2017-08-12 13:50:00+03	MRV	MCX	Arrived	SU9	2017-08-12 13:25:00+03	2017-08-12 13:55:00+03
20310	PG0181	2017-08-07 19:05:00+03	2017-08-07 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-07 19:10:00+03	2017-08-07 19:39:00+03
20311	PG0181	2017-09-11 19:05:00+03	2017-09-11 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20312	PG0181	2017-07-17 19:05:00+03	2017-07-17 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-17 19:07:00+03	2017-07-17 19:36:00+03
20313	PG0180	2017-08-02 13:15:00+03	2017-08-02 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-02 16:04:00+03	2017-08-02 16:34:00+03
20314	PG0180	2017-08-25 13:15:00+03	2017-08-25 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20315	PG0180	2017-08-10 13:15:00+03	2017-08-10 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-10 13:15:00+03	2017-08-10 13:45:00+03
20316	PG0181	2017-08-02 19:05:00+03	2017-08-02 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-02 19:06:00+03	2017-08-02 19:36:00+03
20317	PG0181	2017-07-28 19:05:00+03	2017-07-28 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-28 19:06:00+03	2017-07-28 19:36:00+03
20318	PG0181	2017-08-24 19:05:00+03	2017-08-24 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20319	PG0180	2017-07-28 13:15:00+03	2017-07-28 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-28 13:18:00+03	2017-07-28 13:48:00+03
20320	PG0180	2017-08-30 13:15:00+03	2017-08-30 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20321	PG0181	2017-08-30 19:05:00+03	2017-08-30 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20322	PG0180	2017-08-13 13:15:00+03	2017-08-13 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-13 13:19:00+03	2017-08-13 13:49:00+03
20323	PG0181	2017-08-01 19:05:00+03	2017-08-01 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-01 19:10:00+03	2017-08-01 19:40:00+03
20324	PG0180	2017-08-01 13:15:00+03	2017-08-01 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-01 13:18:00+03	2017-08-01 13:47:00+03
20325	PG0180	2017-08-11 13:15:00+03	2017-08-11 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-11 13:20:00+03	2017-08-11 13:50:00+03
20326	PG0181	2017-08-25 19:05:00+03	2017-08-25 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20327	PG0181	2017-08-06 19:05:00+03	2017-08-06 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-06 19:07:00+03	2017-08-06 19:37:00+03
20328	PG0181	2017-08-13 19:05:00+03	2017-08-13 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-13 19:09:00+03	2017-08-13 19:39:00+03
20329	PG0181	2017-09-03 19:05:00+03	2017-09-03 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20330	PG0180	2017-08-06 13:15:00+03	2017-08-06 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-06 13:17:00+03	2017-08-06 13:47:00+03
20331	PG0180	2017-09-03 13:15:00+03	2017-09-03 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20332	PG0180	2017-08-27 13:15:00+03	2017-08-27 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20333	PG0181	2017-08-23 19:05:00+03	2017-08-23 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20334	PG0180	2017-08-23 13:15:00+03	2017-08-23 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20335	PG0181	2017-08-31 19:05:00+03	2017-08-31 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20336	PG0180	2017-09-12 13:15:00+03	2017-09-12 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20337	PG0181	2017-08-27 19:05:00+03	2017-08-27 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20338	PG0181	2017-08-17 19:05:00+03	2017-08-17 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20339	PG0181	2017-08-12 19:05:00+03	2017-08-12 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-12 19:08:00+03	2017-08-12 19:38:00+03
20340	PG0181	2017-08-26 19:05:00+03	2017-08-26 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20341	PG0180	2017-08-26 13:15:00+03	2017-08-26 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20342	PG0181	2017-09-01 19:05:00+03	2017-09-01 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20343	PG0180	2017-09-13 13:15:00+03	2017-09-13 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20344	PG0180	2017-08-15 13:15:00+03	2017-08-15 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-15 13:15:00+03	2017-08-15 13:45:00+03
20345	PG0180	2017-09-01 13:15:00+03	2017-09-01 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20346	PG0181	2017-09-13 19:05:00+03	2017-09-13 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20347	PG0180	2017-08-20 13:15:00+03	2017-08-20 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20348	PG0180	2017-08-17 13:15:00+03	2017-08-17 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20349	PG0180	2017-07-19 13:15:00+03	2017-07-19 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-19 13:16:00+03	2017-07-19 13:46:00+03
20350	PG0181	2017-08-20 19:05:00+03	2017-08-20 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20351	PG0180	2017-09-04 13:15:00+03	2017-09-04 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20352	PG0181	2017-09-04 19:05:00+03	2017-09-04 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20353	PG0180	2017-08-08 13:15:00+03	2017-08-08 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-08 16:30:00+03	2017-08-08 17:00:00+03
20354	PG0180	2017-09-05 13:15:00+03	2017-09-05 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20355	PG0181	2017-09-12 19:05:00+03	2017-09-12 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20356	PG0180	2017-08-28 13:15:00+03	2017-08-28 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20357	PG0181	2017-08-08 19:05:00+03	2017-08-08 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-08 19:06:00+03	2017-08-08 19:36:00+03
20358	PG0181	2017-09-05 19:05:00+03	2017-09-05 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20359	PG0180	2017-07-30 13:15:00+03	2017-07-30 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-30 13:18:00+03	2017-07-30 13:48:00+03
20360	PG0180	2017-08-24 13:15:00+03	2017-08-24 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20361	PG0180	2017-08-31 13:15:00+03	2017-08-31 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20362	PG0181	2017-07-31 19:05:00+03	2017-07-31 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-31 19:10:00+03	2017-07-31 19:40:00+03
20363	PG0180	2017-07-31 13:15:00+03	2017-07-31 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-31 13:17:00+03	2017-07-31 13:47:00+03
20364	PG0180	2017-07-23 13:15:00+03	2017-07-23 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-23 13:20:00+03	2017-07-23 13:50:00+03
20365	PG0181	2017-07-23 19:05:00+03	2017-07-23 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-23 19:08:00+03	2017-07-23 19:38:00+03
20366	PG0180	2017-07-21 13:15:00+03	2017-07-21 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-21 13:17:00+03	2017-07-21 13:47:00+03
20367	PG0181	2017-07-21 19:05:00+03	2017-07-21 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-21 19:10:00+03	2017-07-21 19:40:00+03
20368	PG0181	2017-08-14 19:05:00+03	2017-08-14 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-14 22:07:00+03	2017-08-14 22:37:00+03
20369	PG0180	2017-09-07 13:15:00+03	2017-09-07 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20370	PG0181	2017-08-22 19:05:00+03	2017-08-22 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20371	PG0181	2017-07-19 19:05:00+03	2017-07-19 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-19 19:10:00+03	2017-07-19 19:40:00+03
20372	PG0180	2017-08-22 13:15:00+03	2017-08-22 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20373	PG0180	2017-08-12 13:15:00+03	2017-08-12 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-12 13:17:00+03	2017-08-12 13:46:00+03
20374	PG0180	2017-08-21 13:15:00+03	2017-08-21 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20375	PG0181	2017-08-21 19:05:00+03	2017-08-21 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20376	PG0181	2017-09-07 19:05:00+03	2017-09-07 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20377	PG0181	2017-08-28 19:05:00+03	2017-08-28 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20378	PG0180	2017-08-29 13:15:00+03	2017-08-29 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20379	PG0181	2017-08-29 19:05:00+03	2017-08-29 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20380	PG0181	2017-09-14 19:05:00+03	2017-09-14 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20381	PG0180	2017-07-29 13:15:00+03	2017-07-29 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-29 13:16:00+03	2017-07-29 13:46:00+03
20382	PG0180	2017-09-14 13:15:00+03	2017-09-14 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20383	PG0180	2017-09-11 13:15:00+03	2017-09-11 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20384	PG0181	2017-07-29 19:05:00+03	2017-07-29 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-29 19:08:00+03	2017-07-29 19:38:00+03
20385	PG0181	2017-07-22 19:05:00+03	2017-07-22 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-22 19:09:00+03	2017-07-22 19:39:00+03
20386	PG0181	2017-08-09 19:05:00+03	2017-08-09 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-09 19:10:00+03	2017-08-09 19:40:00+03
20387	PG0181	2017-08-05 19:05:00+03	2017-08-05 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-05 19:11:00+03	2017-08-05 19:41:00+03
20388	PG0180	2017-08-09 13:15:00+03	2017-08-09 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-09 13:21:00+03	2017-08-09 13:51:00+03
20389	PG0181	2017-07-30 19:05:00+03	2017-07-30 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-30 19:07:00+03	2017-07-30 19:37:00+03
20390	PG0181	2017-08-10 19:05:00+03	2017-08-10 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-10 19:06:00+03	2017-08-10 19:36:00+03
20391	PG0181	2017-09-08 19:05:00+03	2017-09-08 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20392	PG0180	2017-07-18 13:15:00+03	2017-07-18 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-18 16:31:00+03	2017-07-18 17:02:00+03
20393	PG0180	2017-09-08 13:15:00+03	2017-09-08 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20394	PG0181	2017-07-18 19:05:00+03	2017-07-18 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-18 22:25:00+03	2017-07-18 22:55:00+03
20395	PG0180	2017-08-05 13:15:00+03	2017-08-05 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-05 13:21:00+03	2017-08-05 13:51:00+03
20396	PG0180	2017-08-03 13:15:00+03	2017-08-03 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-03 13:18:00+03	2017-08-03 13:48:00+03
20397	PG0180	2017-09-09 13:15:00+03	2017-09-09 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20398	PG0181	2017-08-16 19:05:00+03	2017-08-16 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20399	PG0180	2017-08-16 13:15:00+03	2017-08-16 13:45:00+03	GOJ	SVO	On Time	SU9	\N	\N
20400	PG0181	2017-09-09 19:05:00+03	2017-09-09 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20401	PG0180	2017-07-26 13:15:00+03	2017-07-26 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-26 13:18:00+03	2017-07-26 13:47:00+03
20402	PG0181	2017-08-15 19:05:00+03	2017-08-15 19:35:00+03	GOJ	SVO	On Time	SU9	\N	\N
20403	PG0180	2017-09-10 13:15:00+03	2017-09-10 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20404	PG0181	2017-08-19 19:05:00+03	2017-08-19 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20405	PG0181	2017-08-04 19:05:00+03	2017-08-04 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-04 19:11:00+03	2017-08-04 19:41:00+03
20406	PG0181	2017-07-27 19:05:00+03	2017-07-27 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-27 19:10:00+03	2017-07-27 19:40:00+03
20407	PG0180	2017-09-02 13:15:00+03	2017-09-02 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20408	PG0181	2017-09-02 19:05:00+03	2017-09-02 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20409	PG0180	2017-08-18 13:15:00+03	2017-08-18 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20410	PG0181	2017-08-18 19:05:00+03	2017-08-18 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20411	PG0181	2017-07-25 19:05:00+03	2017-07-25 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-25 19:08:00+03	2017-07-25 19:38:00+03
20412	PG0181	2017-09-06 19:05:00+03	2017-09-06 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20413	PG0180	2017-08-04 13:15:00+03	2017-08-04 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-04 13:18:00+03	2017-08-04 13:48:00+03
20414	PG0180	2017-09-06 13:15:00+03	2017-09-06 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20415	PG0180	2017-07-17 13:15:00+03	2017-07-17 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-17 13:17:00+03	2017-07-17 13:47:00+03
20416	PG0181	2017-08-03 19:05:00+03	2017-08-03 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-03 19:06:00+03	2017-08-03 19:36:00+03
20417	PG0181	2017-09-10 19:05:00+03	2017-09-10 19:35:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20418	PG0180	2017-07-16 13:15:00+03	2017-07-16 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-16 13:16:00+03	2017-07-16 13:46:00+03
20419	PG0180	2017-07-20 13:15:00+03	2017-07-20 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-20 13:18:00+03	2017-07-20 13:48:00+03
20420	PG0181	2017-07-16 19:05:00+03	2017-07-16 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-16 19:07:00+03	2017-07-16 19:37:00+03
20421	PG0180	2017-07-24 13:15:00+03	2017-07-24 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-24 13:18:00+03	2017-07-24 13:48:00+03
20422	PG0181	2017-07-26 19:05:00+03	2017-07-26 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-26 19:10:00+03	2017-07-26 19:40:00+03
20423	PG0181	2017-07-20 19:05:00+03	2017-07-20 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-20 19:08:00+03	2017-07-20 19:38:00+03
20424	PG0180	2017-08-19 13:15:00+03	2017-08-19 13:45:00+03	GOJ	SVO	Scheduled	SU9	\N	\N
20425	PG0180	2017-07-22 13:15:00+03	2017-07-22 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-22 13:17:00+03	2017-07-22 13:47:00+03
20426	PG0181	2017-07-24 19:05:00+03	2017-07-24 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-07-24 19:06:00+03	2017-07-24 19:36:00+03
20427	PG0180	2017-07-27 13:15:00+03	2017-07-27 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-27 13:18:00+03	2017-07-27 13:48:00+03
20428	PG0180	2017-08-14 13:15:00+03	2017-08-14 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-14 13:16:00+03	2017-08-14 13:46:00+03
20429	PG0180	2017-08-07 13:15:00+03	2017-08-07 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-08-07 13:21:00+03	2017-08-07 13:51:00+03
20430	PG0180	2017-07-25 13:15:00+03	2017-07-25 13:45:00+03	GOJ	SVO	Arrived	SU9	2017-07-25 13:19:00+03	2017-07-25 13:49:00+03
20431	PG0181	2017-08-11 19:05:00+03	2017-08-11 19:35:00+03	GOJ	SVO	Arrived	SU9	2017-08-11 19:11:00+03	2017-08-11 19:41:00+03
20432	PG0572	2017-07-24 19:10:00+03	2017-07-24 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-24 19:15:00+03	2017-07-24 20:25:00+03
20433	PG0572	2017-07-25 19:10:00+03	2017-07-25 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-25 23:09:00+03	2017-07-26 00:19:00+03
20434	PG0572	2017-09-10 19:10:00+03	2017-09-10 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20435	PG0572	2017-08-21 19:10:00+03	2017-08-21 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20436	PG0572	2017-09-09 19:10:00+03	2017-09-09 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20437	PG0572	2017-08-11 19:10:00+03	2017-08-11 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-11 19:11:00+03	2017-08-11 20:21:00+03
20438	PG0572	2017-08-20 19:10:00+03	2017-08-20 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20439	PG0572	2017-07-26 19:10:00+03	2017-07-26 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-26 19:13:00+03	2017-07-26 20:24:00+03
20440	PG0572	2017-07-23 19:10:00+03	2017-07-23 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-23 19:14:00+03	2017-07-23 20:25:00+03
20441	PG0572	2017-08-27 19:10:00+03	2017-08-27 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20442	PG0572	2017-08-08 19:10:00+03	2017-08-08 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-08 19:14:00+03	2017-08-08 20:23:00+03
20443	PG0572	2017-07-27 19:10:00+03	2017-07-27 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-27 19:10:00+03	2017-07-27 20:20:00+03
20444	PG0572	2017-09-08 19:10:00+03	2017-09-08 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20445	PG0572	2017-07-22 19:10:00+03	2017-07-22 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-22 19:13:00+03	2017-07-22 20:23:00+03
20446	PG0572	2017-07-28 19:10:00+03	2017-07-28 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-28 19:12:00+03	2017-07-28 20:22:00+03
20447	PG0572	2017-08-26 19:10:00+03	2017-08-26 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20448	PG0572	2017-08-19 19:10:00+03	2017-08-19 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20449	PG0572	2017-09-11 19:10:00+03	2017-09-11 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20450	PG0572	2017-07-29 19:10:00+03	2017-07-29 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-29 19:15:00+03	2017-07-29 20:26:00+03
20451	PG0572	2017-09-07 19:10:00+03	2017-09-07 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20452	PG0572	2017-08-22 19:10:00+03	2017-08-22 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20453	PG0572	2017-07-21 19:10:00+03	2017-07-21 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-21 19:13:00+03	2017-07-21 20:23:00+03
20454	PG0572	2017-07-30 19:10:00+03	2017-07-30 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-30 19:13:00+03	2017-07-30 20:21:00+03
20455	PG0572	2017-09-02 19:10:00+03	2017-09-02 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20456	PG0572	2017-08-18 19:10:00+03	2017-08-18 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20457	PG0572	2017-08-13 19:10:00+03	2017-08-13 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-13 19:15:00+03	2017-08-13 20:26:00+03
20458	PG0572	2017-07-31 19:10:00+03	2017-07-31 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-31 22:26:00+03	2017-07-31 23:37:00+03
20459	PG0572	2017-07-20 19:10:00+03	2017-07-20 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-20 19:16:00+03	2017-07-20 20:26:00+03
20460	PG0572	2017-09-06 19:10:00+03	2017-09-06 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20461	PG0572	2017-08-28 19:10:00+03	2017-08-28 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20462	PG0572	2017-09-01 19:10:00+03	2017-09-01 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20463	PG0572	2017-08-10 19:10:00+03	2017-08-10 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-10 19:13:00+03	2017-08-10 20:24:00+03
20464	PG0572	2017-09-12 19:10:00+03	2017-09-12 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20465	PG0572	2017-08-01 19:10:00+03	2017-08-01 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-01 19:15:00+03	2017-08-01 20:26:00+03
20466	PG0572	2017-08-31 19:10:00+03	2017-08-31 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20467	PG0572	2017-07-19 19:10:00+03	2017-07-19 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-19 19:11:00+03	2017-07-19 20:21:00+03
20468	PG0572	2017-08-02 19:10:00+03	2017-08-02 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-02 19:10:00+03	2017-08-02 20:20:00+03
20469	PG0572	2017-08-17 19:10:00+03	2017-08-17 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20470	PG0572	2017-09-05 19:10:00+03	2017-09-05 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20471	PG0572	2017-08-30 19:10:00+03	2017-08-30 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20472	PG0572	2017-08-23 19:10:00+03	2017-08-23 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20473	PG0572	2017-08-12 19:10:00+03	2017-08-12 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-12 19:16:00+03	2017-08-12 20:26:00+03
20474	PG0572	2017-08-03 19:10:00+03	2017-08-03 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-03 19:12:00+03	2017-08-03 20:22:00+03
20475	PG0572	2017-07-18 19:10:00+03	2017-07-18 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-18 19:12:00+03	2017-07-18 20:21:00+03
20476	PG0572	2017-09-13 19:10:00+03	2017-09-13 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20477	PG0572	2017-08-04 19:10:00+03	2017-08-04 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-04 19:14:00+03	2017-08-04 20:25:00+03
20478	PG0572	2017-09-04 19:10:00+03	2017-09-04 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20479	PG0572	2017-08-14 19:10:00+03	2017-08-14 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-14 19:13:00+03	2017-08-14 20:22:00+03
20480	PG0572	2017-08-16 19:10:00+03	2017-08-16 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20481	PG0572	2017-08-05 19:10:00+03	2017-08-05 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-05 19:14:00+03	2017-08-05 20:24:00+03
20482	PG0572	2017-08-29 19:10:00+03	2017-08-29 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20483	PG0572	2017-07-17 19:10:00+03	2017-07-17 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-17 19:13:00+03	2017-07-17 20:23:00+03
20484	PG0572	2017-08-25 19:10:00+03	2017-08-25 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20485	PG0572	2017-09-14 19:10:00+03	2017-09-14 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20486	PG0572	2017-08-06 19:10:00+03	2017-08-06 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-06 19:16:00+03	2017-08-06 20:26:00+03
20487	PG0572	2017-09-03 19:10:00+03	2017-09-03 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20488	PG0572	2017-08-09 19:10:00+03	2017-08-09 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-09 19:14:00+03	2017-08-09 20:24:00+03
20489	PG0572	2017-08-24 19:10:00+03	2017-08-24 20:20:00+03	GOJ	LED	Scheduled	SU9	\N	\N
20490	PG0572	2017-07-16 19:10:00+03	2017-07-16 20:20:00+03	GOJ	LED	Arrived	SU9	2017-07-16 19:11:00+03	2017-07-16 20:22:00+03
20491	PG0572	2017-08-15 19:10:00+03	2017-08-15 20:20:00+03	GOJ	LED	On Time	SU9	\N	\N
20492	PG0572	2017-08-07 19:10:00+03	2017-08-07 20:20:00+03	GOJ	LED	Arrived	SU9	2017-08-07 22:13:00+03	2017-08-07 23:22:00+03
20493	PG0698	2017-08-25 16:35:00+03	2017-08-25 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20494	PG0698	2017-08-26 16:35:00+03	2017-08-26 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20495	PG0698	2017-07-27 16:35:00+03	2017-07-27 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-27 16:36:00+03	2017-07-27 17:35:00+03
20496	PG0698	2017-08-14 16:35:00+03	2017-08-14 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-14 16:38:00+03	2017-08-14 17:39:00+03
20497	PG0698	2017-08-10 16:35:00+03	2017-08-10 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-10 16:36:00+03	2017-08-10 17:37:00+03
20498	PG0698	2017-07-20 16:35:00+03	2017-07-20 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-20 20:21:00+03	2017-07-20 21:23:00+03
20499	PG0698	2017-08-15 16:35:00+03	2017-08-15 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-15 16:38:00+03	2017-08-15 17:37:00+03
20500	PG0698	2017-08-06 16:35:00+03	2017-08-06 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-06 16:36:00+03	2017-08-06 17:37:00+03
20501	PG0698	2017-07-31 16:35:00+03	2017-07-31 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-31 16:37:00+03	2017-07-31 17:38:00+03
20502	PG0698	2017-08-17 16:35:00+03	2017-08-17 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20503	PG0698	2017-08-22 16:35:00+03	2017-08-22 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20504	PG0698	2017-08-12 16:35:00+03	2017-08-12 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-12 16:36:00+03	2017-08-12 17:37:00+03
20505	PG0698	2017-07-30 16:35:00+03	2017-07-30 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-30 16:38:00+03	2017-07-30 17:39:00+03
20506	PG0698	2017-09-13 16:35:00+03	2017-09-13 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20507	PG0698	2017-08-24 16:35:00+03	2017-08-24 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20508	PG0698	2017-08-18 16:35:00+03	2017-08-18 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20509	PG0698	2017-08-16 16:35:00+03	2017-08-16 17:35:00+03	GOJ	PEE	On Time	SU9	\N	\N
20510	PG0698	2017-07-22 16:35:00+03	2017-07-22 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-22 16:38:00+03	2017-07-22 17:38:00+03
20511	PG0698	2017-08-30 16:35:00+03	2017-08-30 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20512	PG0698	2017-08-04 16:35:00+03	2017-08-04 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-04 16:36:00+03	2017-08-04 17:36:00+03
20513	PG0698	2017-08-03 16:35:00+03	2017-08-03 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-03 16:37:00+03	2017-08-03 17:36:00+03
20514	PG0698	2017-07-23 16:35:00+03	2017-07-23 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-23 16:39:00+03	2017-07-23 17:38:00+03
20515	PG0698	2017-09-10 16:35:00+03	2017-09-10 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20516	PG0698	2017-07-19 16:35:00+03	2017-07-19 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-19 16:36:00+03	2017-07-19 17:36:00+03
20517	PG0698	2017-09-01 16:35:00+03	2017-09-01 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20518	PG0698	2017-09-05 16:35:00+03	2017-09-05 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20519	PG0698	2017-08-31 16:35:00+03	2017-08-31 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20520	PG0698	2017-08-13 16:35:00+03	2017-08-13 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-13 16:36:00+03	2017-08-13 17:35:00+03
20521	PG0698	2017-08-27 16:35:00+03	2017-08-27 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20522	PG0698	2017-08-21 16:35:00+03	2017-08-21 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20523	PG0698	2017-07-26 16:35:00+03	2017-07-26 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-26 16:37:00+03	2017-07-26 17:37:00+03
20524	PG0698	2017-08-02 16:35:00+03	2017-08-02 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-02 16:37:00+03	2017-08-02 17:38:00+03
20525	PG0698	2017-07-25 16:35:00+03	2017-07-25 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-25 16:39:00+03	2017-07-25 17:39:00+03
20526	PG0698	2017-08-08 16:35:00+03	2017-08-08 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-08 16:37:00+03	2017-08-08 17:37:00+03
20527	PG0698	2017-07-24 16:35:00+03	2017-07-24 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-24 16:38:00+03	2017-07-24 17:38:00+03
20528	PG0698	2017-09-06 16:35:00+03	2017-09-06 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20529	PG0698	2017-07-29 16:35:00+03	2017-07-29 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-29 16:39:00+03	2017-07-29 17:40:00+03
20530	PG0698	2017-07-28 16:35:00+03	2017-07-28 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-28 16:39:00+03	2017-07-28 17:40:00+03
20531	PG0698	2017-08-09 16:35:00+03	2017-08-09 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-09 16:39:00+03	2017-08-09 17:39:00+03
20532	PG0698	2017-09-02 16:35:00+03	2017-09-02 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20533	PG0698	2017-08-20 16:35:00+03	2017-08-20 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20534	PG0698	2017-07-16 16:35:00+03	2017-07-16 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-16 16:38:00+03	2017-07-16 17:38:00+03
20535	PG0698	2017-07-17 16:35:00+03	2017-07-17 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-17 16:37:00+03	2017-07-17 17:36:00+03
20536	PG0698	2017-09-12 16:35:00+03	2017-09-12 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20537	PG0698	2017-09-09 16:35:00+03	2017-09-09 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20538	PG0698	2017-08-23 16:35:00+03	2017-08-23 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20539	PG0698	2017-09-07 16:35:00+03	2017-09-07 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20540	PG0698	2017-08-19 16:35:00+03	2017-08-19 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20541	PG0698	2017-08-28 16:35:00+03	2017-08-28 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20542	PG0698	2017-09-08 16:35:00+03	2017-09-08 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20543	PG0698	2017-08-11 16:35:00+03	2017-08-11 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-11 16:40:00+03	2017-08-11 17:40:00+03
20544	PG0698	2017-09-11 16:35:00+03	2017-09-11 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20545	PG0698	2017-08-05 16:35:00+03	2017-08-05 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-05 16:38:00+03	2017-08-05 17:38:00+03
20546	PG0698	2017-09-03 16:35:00+03	2017-09-03 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20547	PG0698	2017-08-01 16:35:00+03	2017-08-01 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-01 16:36:00+03	2017-08-01 17:36:00+03
20548	PG0698	2017-09-14 16:35:00+03	2017-09-14 17:35:00+03	GOJ	PEE	Cancelled	SU9	\N	\N
20549	PG0698	2017-07-18 16:35:00+03	2017-07-18 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-18 16:35:00+03	2017-07-18 17:35:00+03
20550	PG0698	2017-08-29 16:35:00+03	2017-08-29 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20551	PG0698	2017-07-21 16:35:00+03	2017-07-21 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-07-21 16:37:00+03	2017-07-21 17:37:00+03
20552	PG0698	2017-09-04 16:35:00+03	2017-09-04 17:35:00+03	GOJ	PEE	Scheduled	SU9	\N	\N
20553	PG0698	2017-08-07 16:35:00+03	2017-08-07 17:35:00+03	GOJ	PEE	Arrived	SU9	2017-08-07 16:37:00+03	2017-08-07 17:37:00+03
20554	PG0512	2017-07-17 12:55:00+03	2017-07-17 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-17 13:01:00+03	2017-07-17 15:01:00+03
20555	PG0512	2017-08-02 12:55:00+03	2017-08-02 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-02 12:58:00+03	2017-08-02 14:59:00+03
20556	PG0512	2017-08-26 12:55:00+03	2017-08-26 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20557	PG0512	2017-09-12 12:55:00+03	2017-09-12 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20558	PG0512	2017-07-20 12:55:00+03	2017-07-20 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-20 13:00:00+03	2017-07-20 14:58:00+03
20559	PG0512	2017-08-25 12:55:00+03	2017-08-25 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20560	PG0512	2017-08-28 12:55:00+03	2017-08-28 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20561	PG0512	2017-08-13 12:55:00+03	2017-08-13 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-13 12:58:00+03	2017-08-13 14:57:00+03
20562	PG0512	2017-09-03 12:55:00+03	2017-09-03 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20563	PG0512	2017-07-22 12:55:00+03	2017-07-22 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-22 12:56:00+03	2017-07-22 14:56:00+03
20564	PG0512	2017-08-06 12:55:00+03	2017-08-06 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-06 12:56:00+03	2017-08-06 14:59:00+03
20565	PG0512	2017-07-31 12:55:00+03	2017-07-31 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-31 13:01:00+03	2017-07-31 15:00:00+03
20566	PG0512	2017-08-24 12:55:00+03	2017-08-24 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20567	PG0512	2017-09-05 12:55:00+03	2017-09-05 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20568	PG0512	2017-09-07 12:55:00+03	2017-09-07 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20569	PG0512	2017-08-18 12:55:00+03	2017-08-18 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20570	PG0512	2017-07-24 12:55:00+03	2017-07-24 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-24 12:56:00+03	2017-07-24 14:55:00+03
20571	PG0512	2017-07-29 12:55:00+03	2017-07-29 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-29 12:56:00+03	2017-07-29 14:55:00+03
20572	PG0512	2017-08-14 12:55:00+03	2017-08-14 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-14 12:58:00+03	2017-08-14 14:59:00+03
20573	PG0512	2017-07-23 12:55:00+03	2017-07-23 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-23 12:59:00+03	2017-07-23 15:00:00+03
20574	PG0512	2017-08-22 12:55:00+03	2017-08-22 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20575	PG0512	2017-07-19 12:55:00+03	2017-07-19 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-19 12:56:00+03	2017-07-19 14:54:00+03
20576	PG0512	2017-07-18 12:55:00+03	2017-07-18 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-18 15:58:00+03	2017-07-18 17:58:00+03
20577	PG0512	2017-08-08 12:55:00+03	2017-08-08 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-08 12:56:00+03	2017-08-08 14:56:00+03
20578	PG0512	2017-08-17 12:55:00+03	2017-08-17 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20579	PG0512	2017-07-30 12:55:00+03	2017-07-30 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-30 12:57:00+03	2017-07-30 14:58:00+03
20580	PG0512	2017-07-25 12:55:00+03	2017-07-25 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-25 13:01:00+03	2017-07-25 15:02:00+03
20581	PG0512	2017-08-04 12:55:00+03	2017-08-04 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-04 13:00:00+03	2017-08-04 14:58:00+03
20582	PG0512	2017-07-21 12:55:00+03	2017-07-21 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-21 12:57:00+03	2017-07-21 14:58:00+03
20583	PG0512	2017-09-10 12:55:00+03	2017-09-10 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20584	PG0512	2017-08-19 12:55:00+03	2017-08-19 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20585	PG0512	2017-08-12 12:55:00+03	2017-08-12 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-12 12:56:00+03	2017-08-12 14:58:00+03
20586	PG0512	2017-09-01 12:55:00+03	2017-09-01 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20587	PG0512	2017-09-04 12:55:00+03	2017-09-04 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20588	PG0512	2017-08-11 12:55:00+03	2017-08-11 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-11 12:59:00+03	2017-08-11 15:00:00+03
20589	PG0512	2017-08-20 12:55:00+03	2017-08-20 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20590	PG0512	2017-08-27 12:55:00+03	2017-08-27 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20591	PG0512	2017-09-08 12:55:00+03	2017-09-08 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20592	PG0512	2017-08-29 12:55:00+03	2017-08-29 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20593	PG0512	2017-08-09 12:55:00+03	2017-08-09 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-09 12:58:00+03	2017-08-09 14:59:00+03
20594	PG0512	2017-08-16 12:55:00+03	2017-08-16 14:55:00+03	GOJ	NAL	On Time	CR2	\N	\N
20595	PG0512	2017-08-15 12:55:00+03	2017-08-15 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-15 12:59:00+03	2017-08-15 15:00:00+03
20596	PG0512	2017-08-21 12:55:00+03	2017-08-21 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20597	PG0512	2017-08-31 12:55:00+03	2017-08-31 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20598	PG0512	2017-07-26 12:55:00+03	2017-07-26 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-26 12:58:00+03	2017-07-26 14:58:00+03
20599	PG0512	2017-07-16 12:55:00+03	2017-07-16 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-16 12:58:00+03	2017-07-16 14:58:00+03
20600	PG0512	2017-08-07 12:55:00+03	2017-08-07 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-07 13:00:00+03	2017-08-07 14:59:00+03
20601	PG0512	2017-08-05 12:55:00+03	2017-08-05 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-05 12:56:00+03	2017-08-05 14:54:00+03
20602	PG0512	2017-08-01 12:55:00+03	2017-08-01 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-01 12:58:00+03	2017-08-01 14:59:00+03
20603	PG0512	2017-07-28 12:55:00+03	2017-07-28 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-28 13:01:00+03	2017-07-28 15:01:00+03
20604	PG0512	2017-07-27 12:55:00+03	2017-07-27 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-07-27 12:56:00+03	2017-07-27 14:55:00+03
20605	PG0512	2017-08-10 12:55:00+03	2017-08-10 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-10 12:59:00+03	2017-08-10 15:00:00+03
20606	PG0512	2017-08-30 12:55:00+03	2017-08-30 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20607	PG0512	2017-08-23 12:55:00+03	2017-08-23 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20608	PG0512	2017-09-02 12:55:00+03	2017-09-02 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20609	PG0512	2017-09-13 12:55:00+03	2017-09-13 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20610	PG0512	2017-09-11 12:55:00+03	2017-09-11 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20611	PG0512	2017-09-14 12:55:00+03	2017-09-14 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20612	PG0512	2017-08-03 12:55:00+03	2017-08-03 14:55:00+03	GOJ	NAL	Arrived	CR2	2017-08-03 12:59:00+03	2017-08-03 15:01:00+03
20613	PG0512	2017-09-09 12:55:00+03	2017-09-09 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20614	PG0512	2017-09-06 12:55:00+03	2017-09-06 14:55:00+03	GOJ	NAL	Scheduled	CR2	\N	\N
20615	PG0247	2017-08-12 14:30:00+03	2017-08-12 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-12 14:32:00+03	2017-08-12 16:39:00+03
20616	PG0247	2017-08-07 14:30:00+03	2017-08-07 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-07 14:36:00+03	2017-08-07 16:41:00+03
20617	PG0247	2017-07-24 14:30:00+03	2017-07-24 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-24 14:33:00+03	2017-07-24 16:39:00+03
20618	PG0247	2017-07-29 14:30:00+03	2017-07-29 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-29 14:32:00+03	2017-07-29 16:37:00+03
20619	PG0247	2017-07-17 14:30:00+03	2017-07-17 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-17 14:33:00+03	2017-07-17 16:38:00+03
20620	PG0247	2017-09-02 14:30:00+03	2017-09-02 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20621	PG0247	2017-08-28 14:30:00+03	2017-08-28 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20622	PG0247	2017-09-13 14:30:00+03	2017-09-13 16:35:00+03	GOJ	AER	Cancelled	CR2	\N	\N
20623	PG0247	2017-08-16 14:30:00+03	2017-08-16 16:35:00+03	GOJ	AER	On Time	CR2	\N	\N
20624	PG0247	2017-08-09 14:30:00+03	2017-08-09 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-09 14:35:00+03	2017-08-09 16:42:00+03
20625	PG0247	2017-07-31 14:30:00+03	2017-07-31 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-31 14:31:00+03	2017-07-31 16:37:00+03
20626	PG0247	2017-09-06 14:30:00+03	2017-09-06 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20627	PG0247	2017-07-22 14:30:00+03	2017-07-22 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-22 14:33:00+03	2017-07-22 16:37:00+03
20628	PG0247	2017-08-23 14:30:00+03	2017-08-23 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20629	PG0247	2017-08-05 14:30:00+03	2017-08-05 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-05 14:30:00+03	2017-08-05 16:35:00+03
20630	PG0247	2017-08-14 14:30:00+03	2017-08-14 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-14 14:33:00+03	2017-08-14 16:39:00+03
20631	PG0247	2017-08-30 14:30:00+03	2017-08-30 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20632	PG0247	2017-09-09 14:30:00+03	2017-09-09 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20633	PG0247	2017-08-02 14:30:00+03	2017-08-02 16:35:00+03	GOJ	AER	Arrived	CR2	2017-08-02 14:34:00+03	2017-08-02 16:38:00+03
20634	PG0247	2017-08-21 14:30:00+03	2017-08-21 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20635	PG0247	2017-07-19 14:30:00+03	2017-07-19 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-19 14:31:00+03	2017-07-19 16:36:00+03
20636	PG0247	2017-08-26 14:30:00+03	2017-08-26 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20637	PG0247	2017-07-26 14:30:00+03	2017-07-26 16:35:00+03	GOJ	AER	Arrived	CR2	2017-07-26 14:32:00+03	2017-07-26 16:39:00+03
20638	PG0247	2017-09-04 14:30:00+03	2017-09-04 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20639	PG0247	2017-09-11 14:30:00+03	2017-09-11 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20640	PG0247	2017-08-19 14:30:00+03	2017-08-19 16:35:00+03	GOJ	AER	Scheduled	CR2	\N	\N
20641	PG0345	2017-07-17 09:20:00+03	2017-07-17 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-17 09:20:00+03	2017-07-17 11:00:00+03
20642	PG0345	2017-08-24 09:20:00+03	2017-08-24 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20643	PG0345	2017-08-10 09:20:00+03	2017-08-10 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-10 09:22:00+03	2017-08-10 11:02:00+03
20644	PG0345	2017-08-31 09:20:00+03	2017-08-31 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20645	PG0345	2017-09-02 09:20:00+03	2017-09-02 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20646	PG0345	2017-07-27 09:20:00+03	2017-07-27 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-27 09:22:00+03	2017-07-27 11:01:00+03
20647	PG0345	2017-09-07 09:20:00+03	2017-09-07 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20648	PG0345	2017-07-31 09:20:00+03	2017-07-31 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-31 09:21:00+03	2017-07-31 11:02:00+03
20649	PG0345	2017-08-14 09:20:00+03	2017-08-14 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-14 12:29:00+03	2017-08-14 14:09:00+03
20650	PG0345	2017-08-07 09:20:00+03	2017-08-07 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-07 09:23:00+03	2017-08-07 11:04:00+03
20651	PG0345	2017-07-20 09:20:00+03	2017-07-20 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-20 09:22:00+03	2017-07-20 11:01:00+03
20652	PG0345	2017-08-03 09:20:00+03	2017-08-03 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-03 09:26:00+03	2017-08-03 11:07:00+03
20653	PG0345	2017-08-17 09:20:00+03	2017-08-17 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20654	PG0345	2017-08-21 09:20:00+03	2017-08-21 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20655	PG0345	2017-07-24 09:20:00+03	2017-07-24 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-24 09:23:00+03	2017-07-24 11:02:00+03
20656	PG0345	2017-08-26 09:20:00+03	2017-08-26 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20657	PG0345	2017-09-09 09:20:00+03	2017-09-09 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20658	PG0345	2017-09-14 09:20:00+03	2017-09-14 11:00:00+03	GOJ	KLF	Cancelled	CN1	\N	\N
20659	PG0345	2017-08-19 09:20:00+03	2017-08-19 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20660	PG0345	2017-07-29 09:20:00+03	2017-07-29 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-29 09:23:00+03	2017-07-29 11:03:00+03
20661	PG0345	2017-09-11 09:20:00+03	2017-09-11 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20662	PG0345	2017-08-05 09:20:00+03	2017-08-05 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-05 09:25:00+03	2017-08-05 11:05:00+03
20663	PG0345	2017-09-04 09:20:00+03	2017-09-04 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20664	PG0345	2017-07-22 09:20:00+03	2017-07-22 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-07-22 09:21:00+03	2017-07-22 11:03:00+03
20665	PG0345	2017-08-28 09:20:00+03	2017-08-28 11:00:00+03	GOJ	KLF	Scheduled	CN1	\N	\N
20666	PG0345	2017-08-12 09:20:00+03	2017-08-12 11:00:00+03	GOJ	KLF	Arrived	CN1	2017-08-12 09:23:00+03	2017-08-12 11:02:00+03
20667	PG0598	2017-08-31 11:55:00+03	2017-08-31 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20668	PG0598	2017-07-31 11:55:00+03	2017-07-31 15:25:00+03	UIK	SVX	Arrived	CR2	2017-07-31 12:00:00+03	2017-07-31 15:27:00+03
20669	PG0598	2017-08-21 11:55:00+03	2017-08-21 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20670	PG0598	2017-08-17 11:55:00+03	2017-08-17 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20671	PG0598	2017-08-07 11:55:00+03	2017-08-07 15:25:00+03	UIK	SVX	Arrived	CR2	2017-08-07 12:00:00+03	2017-08-07 15:29:00+03
20672	PG0598	2017-07-27 11:55:00+03	2017-07-27 15:25:00+03	UIK	SVX	Arrived	CR2	2017-07-27 11:58:00+03	2017-07-27 15:29:00+03
20673	PG0598	2017-09-14 11:55:00+03	2017-09-14 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20674	PG0598	2017-08-24 11:55:00+03	2017-08-24 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20675	PG0598	2017-08-10 11:55:00+03	2017-08-10 15:25:00+03	UIK	SVX	Arrived	CR2	2017-08-10 11:58:00+03	2017-08-10 15:27:00+03
20676	PG0598	2017-09-11 11:55:00+03	2017-09-11 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20677	PG0598	2017-07-20 11:55:00+03	2017-07-20 15:25:00+03	UIK	SVX	Arrived	CR2	2017-07-20 15:28:00+03	2017-07-20 18:59:00+03
20678	PG0598	2017-07-24 11:55:00+03	2017-07-24 15:25:00+03	UIK	SVX	Arrived	CR2	2017-07-24 11:57:00+03	2017-07-24 15:28:00+03
20679	PG0598	2017-08-03 11:55:00+03	2017-08-03 15:25:00+03	UIK	SVX	Arrived	CR2	2017-08-03 11:58:00+03	2017-08-03 15:30:00+03
20680	PG0598	2017-08-28 11:55:00+03	2017-08-28 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20681	PG0598	2017-08-14 11:55:00+03	2017-08-14 15:25:00+03	UIK	SVX	Arrived	CR2	2017-08-14 11:57:00+03	2017-08-14 15:29:00+03
20682	PG0598	2017-09-07 11:55:00+03	2017-09-07 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20683	PG0598	2017-09-04 11:55:00+03	2017-09-04 15:25:00+03	UIK	SVX	Scheduled	CR2	\N	\N
20684	PG0598	2017-07-17 11:55:00+03	2017-07-17 15:25:00+03	UIK	SVX	Arrived	CR2	2017-07-17 11:57:00+03	2017-07-17 15:28:00+03
20685	PG0627	2017-07-26 09:00:00+03	2017-07-26 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-26 12:01:00+03	2017-07-26 14:05:00+03
20686	PG0628	2017-08-23 12:40:00+03	2017-08-23 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20687	PG0627	2017-08-23 09:00:00+03	2017-08-23 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20688	PG0627	2017-08-27 09:00:00+03	2017-08-27 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20689	PG0628	2017-08-27 12:40:00+03	2017-08-27 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20690	PG0627	2017-09-07 09:00:00+03	2017-09-07 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20691	PG0628	2017-09-07 12:40:00+03	2017-09-07 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20692	PG0628	2017-07-29 12:40:00+03	2017-07-29 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-29 12:45:00+03	2017-07-29 14:49:00+03
20693	PG0627	2017-07-29 09:00:00+03	2017-07-29 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-29 09:03:00+03	2017-07-29 11:09:00+03
20694	PG0628	2017-07-21 12:40:00+03	2017-07-21 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-21 12:41:00+03	2017-07-21 14:46:00+03
20695	PG0627	2017-07-21 09:00:00+03	2017-07-21 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-21 09:05:00+03	2017-07-21 11:09:00+03
20696	PG0628	2017-09-11 12:40:00+03	2017-09-11 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20697	PG0627	2017-09-11 09:00:00+03	2017-09-11 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20698	PG0627	2017-08-22 09:00:00+03	2017-08-22 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20699	PG0628	2017-08-22 12:40:00+03	2017-08-22 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20700	PG0627	2017-07-30 09:00:00+03	2017-07-30 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-30 09:05:00+03	2017-07-30 11:09:00+03
20701	PG0628	2017-07-30 12:40:00+03	2017-07-30 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-30 12:41:00+03	2017-07-30 14:47:00+03
20702	PG0627	2017-07-25 09:00:00+03	2017-07-25 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-25 09:02:00+03	2017-07-25 11:06:00+03
20703	PG0628	2017-07-25 12:40:00+03	2017-07-25 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-25 15:54:00+03	2017-07-25 18:01:00+03
20704	PG0628	2017-08-07 12:40:00+03	2017-08-07 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-07 12:44:00+03	2017-08-07 14:48:00+03
20705	PG0627	2017-08-07 09:00:00+03	2017-08-07 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-07 09:01:00+03	2017-08-07 11:06:00+03
20706	PG0628	2017-08-24 12:40:00+03	2017-08-24 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20707	PG0627	2017-08-24 09:00:00+03	2017-08-24 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20708	PG0627	2017-08-15 09:00:00+03	2017-08-15 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-15 09:02:00+03	2017-08-15 11:10:00+03
20709	PG0628	2017-08-10 12:40:00+03	2017-08-10 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-10 12:43:00+03	2017-08-10 14:48:00+03
20710	PG0628	2017-08-15 12:40:00+03	2017-08-15 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-15 12:46:00+03	2017-08-15 14:52:00+03
20711	PG0627	2017-08-10 09:00:00+03	2017-08-10 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-10 09:02:00+03	2017-08-10 11:06:00+03
20712	PG0627	2017-08-19 09:00:00+03	2017-08-19 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20713	PG0627	2017-07-16 09:00:00+03	2017-07-16 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-16 09:02:00+03	2017-07-16 11:06:00+03
20714	PG0628	2017-07-16 12:40:00+03	2017-07-16 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-16 12:44:00+03	2017-07-16 14:48:00+03
20715	PG0628	2017-08-13 12:40:00+03	2017-08-13 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-13 12:42:00+03	2017-08-13 14:47:00+03
20716	PG0628	2017-08-11 12:40:00+03	2017-08-11 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-11 12:41:00+03	2017-08-11 14:43:00+03
20717	PG0627	2017-08-11 09:00:00+03	2017-08-11 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-11 09:03:00+03	2017-08-11 11:07:00+03
20718	PG0628	2017-09-09 12:40:00+03	2017-09-09 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20719	PG0628	2017-08-18 12:40:00+03	2017-08-18 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20720	PG0627	2017-08-18 09:00:00+03	2017-08-18 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20721	PG0628	2017-08-19 12:40:00+03	2017-08-19 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20722	PG0627	2017-09-09 09:00:00+03	2017-09-09 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20723	PG0627	2017-08-09 09:00:00+03	2017-08-09 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-09 09:02:00+03	2017-08-09 11:08:00+03
20724	PG0628	2017-08-09 12:40:00+03	2017-08-09 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-09 12:43:00+03	2017-08-09 14:48:00+03
20725	PG0627	2017-09-10 09:00:00+03	2017-09-10 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20726	PG0628	2017-09-10 12:40:00+03	2017-09-10 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20727	PG0628	2017-08-06 12:40:00+03	2017-08-06 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-06 12:43:00+03	2017-08-06 14:48:00+03
20728	PG0627	2017-08-06 09:00:00+03	2017-08-06 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-06 09:02:00+03	2017-08-06 11:09:00+03
20729	PG0628	2017-07-20 12:40:00+03	2017-07-20 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-20 12:43:00+03	2017-07-20 14:47:00+03
20730	PG0627	2017-07-20 09:00:00+03	2017-07-20 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-20 09:01:00+03	2017-07-20 11:05:00+03
20731	PG0628	2017-09-06 12:40:00+03	2017-09-06 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20732	PG0627	2017-09-06 09:00:00+03	2017-09-06 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20733	PG0627	2017-07-31 09:00:00+03	2017-07-31 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-31 09:03:00+03	2017-07-31 11:08:00+03
20734	PG0628	2017-07-31 12:40:00+03	2017-07-31 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-31 12:42:00+03	2017-07-31 14:45:00+03
20735	PG0627	2017-09-03 09:00:00+03	2017-09-03 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20736	PG0627	2017-08-13 09:00:00+03	2017-08-13 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-13 09:03:00+03	2017-08-13 11:08:00+03
20737	PG0628	2017-09-03 12:40:00+03	2017-09-03 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20738	PG0628	2017-08-17 12:40:00+03	2017-08-17 14:45:00+03	UIK	KJA	Cancelled	CN1	\N	\N
20739	PG0628	2017-07-28 12:40:00+03	2017-07-28 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-28 12:42:00+03	2017-07-28 14:47:00+03
20740	PG0628	2017-08-14 12:40:00+03	2017-08-14 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-14 12:45:00+03	2017-08-14 14:50:00+03
20741	PG0628	2017-08-30 12:40:00+03	2017-08-30 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20742	PG0627	2017-08-14 09:00:00+03	2017-08-14 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-14 09:03:00+03	2017-08-14 11:08:00+03
20743	PG0627	2017-08-30 09:00:00+03	2017-08-30 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20744	PG0627	2017-07-28 09:00:00+03	2017-07-28 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-28 09:05:00+03	2017-07-28 11:11:00+03
20745	PG0628	2017-09-02 12:40:00+03	2017-09-02 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20746	PG0627	2017-09-02 09:00:00+03	2017-09-02 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20747	PG0628	2017-09-14 12:40:00+03	2017-09-14 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20748	PG0627	2017-09-14 09:00:00+03	2017-09-14 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20749	PG0628	2017-08-31 12:40:00+03	2017-08-31 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20750	PG0627	2017-08-21 09:00:00+03	2017-08-21 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20751	PG0628	2017-08-21 12:40:00+03	2017-08-21 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20752	PG0627	2017-08-31 09:00:00+03	2017-08-31 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20753	PG0627	2017-08-28 09:00:00+03	2017-08-28 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20754	PG0628	2017-08-29 12:40:00+03	2017-08-29 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20755	PG0628	2017-08-28 12:40:00+03	2017-08-28 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20756	PG0627	2017-08-29 09:00:00+03	2017-08-29 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20757	PG0628	2017-08-20 12:40:00+03	2017-08-20 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20758	PG0627	2017-08-20 09:00:00+03	2017-08-20 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20759	PG0627	2017-09-12 09:00:00+03	2017-09-12 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20760	PG0628	2017-09-12 12:40:00+03	2017-09-12 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20761	PG0627	2017-07-24 09:00:00+03	2017-07-24 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-24 12:17:00+03	2017-07-24 14:21:00+03
20762	PG0628	2017-08-05 12:40:00+03	2017-08-05 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-05 12:44:00+03	2017-08-05 14:50:00+03
20763	PG0627	2017-08-05 09:00:00+03	2017-08-05 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-05 09:02:00+03	2017-08-05 11:07:00+03
20764	PG0628	2017-07-24 12:40:00+03	2017-07-24 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-24 12:45:00+03	2017-07-24 14:49:00+03
20765	PG0627	2017-07-22 09:00:00+03	2017-07-22 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-22 09:01:00+03	2017-07-22 11:05:00+03
20766	PG0628	2017-07-22 12:40:00+03	2017-07-22 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-22 12:43:00+03	2017-07-22 14:46:00+03
20767	PG0627	2017-07-17 09:00:00+03	2017-07-17 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-17 09:04:00+03	2017-07-17 11:06:00+03
20768	PG0628	2017-07-17 12:40:00+03	2017-07-17 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-17 12:44:00+03	2017-07-17 14:48:00+03
20769	PG0627	2017-08-26 09:00:00+03	2017-08-26 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20770	PG0627	2017-08-01 09:00:00+03	2017-08-01 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-01 09:03:00+03	2017-08-01 11:07:00+03
20771	PG0628	2017-08-01 12:40:00+03	2017-08-01 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-01 12:40:00+03	2017-08-01 14:45:00+03
20772	PG0628	2017-08-26 12:40:00+03	2017-08-26 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20773	PG0627	2017-09-01 09:00:00+03	2017-09-01 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20774	PG0628	2017-09-01 12:40:00+03	2017-09-01 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20775	PG0627	2017-08-25 09:00:00+03	2017-08-25 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20776	PG0627	2017-08-08 09:00:00+03	2017-08-08 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-08 09:03:00+03	2017-08-08 11:08:00+03
20777	PG0628	2017-08-25 12:40:00+03	2017-08-25 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20778	PG0628	2017-07-23 12:40:00+03	2017-07-23 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-23 15:33:00+03	2017-07-23 17:37:00+03
20779	PG0627	2017-07-23 09:00:00+03	2017-07-23 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-23 09:00:00+03	2017-07-23 11:06:00+03
20780	PG0628	2017-07-26 12:40:00+03	2017-07-26 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-26 12:45:00+03	2017-07-26 14:48:00+03
20781	PG0627	2017-08-16 09:00:00+03	2017-08-16 11:05:00+03	UIK	KJA	On Time	CN1	\N	\N
20782	PG0628	2017-08-16 12:40:00+03	2017-08-16 14:45:00+03	UIK	KJA	On Time	CN1	\N	\N
20783	PG0628	2017-07-19 12:40:00+03	2017-07-19 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-19 12:43:00+03	2017-07-19 14:49:00+03
20784	PG0628	2017-08-04 12:40:00+03	2017-08-04 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-04 12:44:00+03	2017-08-04 14:48:00+03
20785	PG0627	2017-07-19 09:00:00+03	2017-07-19 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-19 09:02:00+03	2017-07-19 11:07:00+03
20786	PG0627	2017-08-04 09:00:00+03	2017-08-04 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-04 09:02:00+03	2017-08-04 11:08:00+03
20787	PG0627	2017-09-04 09:00:00+03	2017-09-04 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20788	PG0628	2017-09-04 12:40:00+03	2017-09-04 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20789	PG0628	2017-09-13 12:40:00+03	2017-09-13 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20790	PG0627	2017-09-13 09:00:00+03	2017-09-13 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20791	PG0627	2017-08-17 09:00:00+03	2017-08-17 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20792	PG0627	2017-09-08 09:00:00+03	2017-09-08 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20793	PG0628	2017-09-08 12:40:00+03	2017-09-08 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20794	PG0627	2017-07-18 09:00:00+03	2017-07-18 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-18 09:02:00+03	2017-07-18 11:08:00+03
20795	PG0628	2017-07-18 12:40:00+03	2017-07-18 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-18 12:41:00+03	2017-07-18 14:47:00+03
20796	PG0628	2017-08-12 12:40:00+03	2017-08-12 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-12 12:44:00+03	2017-08-12 14:50:00+03
20797	PG0628	2017-09-05 12:40:00+03	2017-09-05 14:45:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20798	PG0627	2017-08-12 09:00:00+03	2017-08-12 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-12 09:04:00+03	2017-08-12 11:11:00+03
20799	PG0627	2017-09-05 09:00:00+03	2017-09-05 11:05:00+03	UIK	KJA	Scheduled	CN1	\N	\N
20800	PG0627	2017-08-02 09:00:00+03	2017-08-02 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-02 09:04:00+03	2017-08-02 11:10:00+03
20801	PG0628	2017-08-02 12:40:00+03	2017-08-02 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-02 12:42:00+03	2017-08-02 14:45:00+03
20802	PG0628	2017-08-03 12:40:00+03	2017-08-03 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-03 12:45:00+03	2017-08-03 14:48:00+03
20803	PG0628	2017-08-08 12:40:00+03	2017-08-08 14:45:00+03	UIK	KJA	Arrived	CN1	2017-08-08 12:45:00+03	2017-08-08 14:47:00+03
20804	PG0627	2017-08-03 09:00:00+03	2017-08-03 11:05:00+03	UIK	KJA	Arrived	CN1	2017-08-03 09:02:00+03	2017-08-03 11:06:00+03
20805	PG0628	2017-07-27 12:40:00+03	2017-07-27 14:45:00+03	UIK	KJA	Arrived	CN1	2017-07-27 12:43:00+03	2017-07-27 14:48:00+03
20806	PG0627	2017-07-27 09:00:00+03	2017-07-27 11:05:00+03	UIK	KJA	Arrived	CN1	2017-07-27 09:05:00+03	2017-07-27 11:09:00+03
20807	PG0651	2017-07-16 07:50:00+03	2017-07-16 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-16 07:53:00+03	2017-07-16 11:21:00+03
20808	PG0651	2017-09-03 07:50:00+03	2017-09-03 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20809	PG0651	2017-09-12 07:50:00+03	2017-09-12 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20810	PG0651	2017-08-01 07:50:00+03	2017-08-01 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-01 07:53:00+03	2017-08-01 11:19:00+03
20811	PG0651	2017-08-27 07:50:00+03	2017-08-27 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20812	PG0651	2017-08-22 07:50:00+03	2017-08-22 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20813	PG0651	2017-07-18 07:50:00+03	2017-07-18 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-18 07:52:00+03	2017-07-18 11:15:00+03
20814	PG0651	2017-07-20 07:50:00+03	2017-07-20 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-20 07:52:00+03	2017-07-20 11:15:00+03
20815	PG0651	2017-09-10 07:50:00+03	2017-09-10 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20816	PG0651	2017-08-17 07:50:00+03	2017-08-17 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20817	PG0651	2017-08-08 07:50:00+03	2017-08-08 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-08 07:51:00+03	2017-08-08 11:18:00+03
20818	PG0651	2017-07-27 07:50:00+03	2017-07-27 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-27 07:51:00+03	2017-07-27 11:16:00+03
20819	PG0651	2017-08-15 07:50:00+03	2017-08-15 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-15 07:54:00+03	2017-08-15 11:19:00+03
20820	PG0651	2017-07-30 07:50:00+03	2017-07-30 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-30 07:56:00+03	2017-07-30 11:21:00+03
20821	PG0651	2017-08-24 07:50:00+03	2017-08-24 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20822	PG0651	2017-08-06 07:50:00+03	2017-08-06 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-06 07:53:00+03	2017-08-06 11:17:00+03
20823	PG0651	2017-08-03 07:50:00+03	2017-08-03 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-03 07:57:00+03	2017-08-03 11:20:00+03
20824	PG0651	2017-08-13 07:50:00+03	2017-08-13 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-13 07:54:00+03	2017-08-13 11:16:00+03
20825	PG0651	2017-09-07 07:50:00+03	2017-09-07 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20826	PG0651	2017-08-10 07:50:00+03	2017-08-10 11:15:00+03	UIK	KHV	Arrived	CR2	2017-08-10 07:52:00+03	2017-08-10 11:15:00+03
20827	PG0651	2017-09-14 07:50:00+03	2017-09-14 11:15:00+03	UIK	KHV	Cancelled	CR2	\N	\N
20828	PG0651	2017-08-29 07:50:00+03	2017-08-29 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20829	PG0651	2017-08-31 07:50:00+03	2017-08-31 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20830	PG0651	2017-08-20 07:50:00+03	2017-08-20 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20831	PG0651	2017-07-23 07:50:00+03	2017-07-23 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-23 07:52:00+03	2017-07-23 11:19:00+03
20832	PG0651	2017-09-05 07:50:00+03	2017-09-05 11:15:00+03	UIK	KHV	Scheduled	CR2	\N	\N
20833	PG0651	2017-07-25 07:50:00+03	2017-07-25 11:15:00+03	UIK	KHV	Arrived	CR2	2017-07-25 07:52:00+03	2017-07-25 11:14:00+03
20834	PG0001	2017-08-12 15:15:00+03	2017-08-12 17:35:00+03	UIK	SGC	Arrived	CR2	2017-08-12 15:17:00+03	2017-08-12 17:34:00+03
20835	PG0001	2017-07-22 15:15:00+03	2017-07-22 17:35:00+03	UIK	SGC	Arrived	CR2	2017-07-22 15:17:00+03	2017-07-22 17:35:00+03
20836	PG0001	2017-09-09 15:15:00+03	2017-09-09 17:35:00+03	UIK	SGC	Cancelled	CR2	\N	\N
20837	PG0001	2017-09-02 15:15:00+03	2017-09-02 17:35:00+03	UIK	SGC	Scheduled	CR2	\N	\N
20838	PG0001	2017-08-26 15:15:00+03	2017-08-26 17:35:00+03	UIK	SGC	Scheduled	CR2	\N	\N
20839	PG0001	2017-08-05 15:15:00+03	2017-08-05 17:35:00+03	UIK	SGC	Arrived	CR2	2017-08-05 15:18:00+03	2017-08-05 17:38:00+03
20840	PG0001	2017-08-19 15:15:00+03	2017-08-19 17:35:00+03	UIK	SGC	Scheduled	CR2	\N	\N
20841	PG0001	2017-07-29 15:15:00+03	2017-07-29 17:35:00+03	UIK	SGC	Arrived	CR2	2017-07-29 15:19:00+03	2017-07-29 17:40:00+03
20842	PG0125	2017-07-30 14:45:00+03	2017-07-30 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-30 14:47:00+03	2017-07-30 18:32:00+03
20843	PG0125	2017-08-04 14:45:00+03	2017-08-04 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-04 14:48:00+03	2017-08-04 18:41:00+03
20844	PG0125	2017-08-27 14:45:00+03	2017-08-27 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20845	PG0125	2017-07-29 14:45:00+03	2017-07-29 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-29 14:48:00+03	2017-07-29 18:39:00+03
20846	PG0125	2017-07-16 14:45:00+03	2017-07-16 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-16 14:48:00+03	2017-07-16 18:39:00+03
20847	PG0125	2017-07-21 14:45:00+03	2017-07-21 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-21 14:46:00+03	2017-07-21 18:35:00+03
20848	PG0125	2017-09-07 14:45:00+03	2017-09-07 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20849	PG0125	2017-07-31 14:45:00+03	2017-07-31 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-31 14:48:00+03	2017-07-31 18:39:00+03
20850	PG0125	2017-09-02 14:45:00+03	2017-09-02 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20851	PG0125	2017-08-13 14:45:00+03	2017-08-13 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-13 14:49:00+03	2017-08-13 18:35:00+03
20852	PG0125	2017-08-09 14:45:00+03	2017-08-09 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-09 14:47:00+03	2017-08-09 18:35:00+03
20853	PG0125	2017-07-27 14:45:00+03	2017-07-27 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-27 14:48:00+03	2017-07-27 18:38:00+03
20854	PG0125	2017-09-12 14:45:00+03	2017-09-12 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20855	PG0125	2017-08-16 14:45:00+03	2017-08-16 18:35:00+03	NSK	DME	On Time	SU9	\N	\N
20856	PG0125	2017-07-20 14:45:00+03	2017-07-20 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-20 17:39:00+03	2017-07-20 21:29:00+03
20857	PG0125	2017-09-01 14:45:00+03	2017-09-01 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20858	PG0125	2017-09-04 14:45:00+03	2017-09-04 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20859	PG0125	2017-07-23 14:45:00+03	2017-07-23 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-23 14:50:00+03	2017-07-23 18:41:00+03
20860	PG0125	2017-08-17 14:45:00+03	2017-08-17 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20861	PG0125	2017-07-17 14:45:00+03	2017-07-17 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-17 14:50:00+03	2017-07-17 18:37:00+03
20862	PG0125	2017-08-30 14:45:00+03	2017-08-30 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20863	PG0125	2017-08-21 14:45:00+03	2017-08-21 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20864	PG0125	2017-07-25 14:45:00+03	2017-07-25 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-25 14:46:00+03	2017-07-25 18:36:00+03
20865	PG0125	2017-08-15 14:45:00+03	2017-08-15 18:35:00+03	NSK	DME	Departed	SU9	2017-08-15 14:50:00+03	\N
20866	PG0125	2017-08-01 14:45:00+03	2017-08-01 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-01 14:47:00+03	2017-08-01 18:36:00+03
20867	PG0125	2017-07-18 14:45:00+03	2017-07-18 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-18 14:50:00+03	2017-07-18 18:42:00+03
20868	PG0125	2017-07-22 14:45:00+03	2017-07-22 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-22 14:47:00+03	2017-07-22 18:33:00+03
20869	PG0125	2017-08-12 14:45:00+03	2017-08-12 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-12 14:50:00+03	2017-08-12 18:39:00+03
20870	PG0125	2017-08-28 14:45:00+03	2017-08-28 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20871	PG0125	2017-09-10 14:45:00+03	2017-09-10 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20872	PG0125	2017-08-02 14:45:00+03	2017-08-02 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-02 14:51:00+03	2017-08-02 18:39:00+03
20873	PG0125	2017-08-18 14:45:00+03	2017-08-18 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20874	PG0125	2017-08-03 14:45:00+03	2017-08-03 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-03 14:49:00+03	2017-08-03 18:40:00+03
20875	PG0125	2017-08-26 14:45:00+03	2017-08-26 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20876	PG0125	2017-08-08 14:45:00+03	2017-08-08 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-08 14:46:00+03	2017-08-08 18:36:00+03
20877	PG0125	2017-08-24 14:45:00+03	2017-08-24 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20878	PG0125	2017-08-22 14:45:00+03	2017-08-22 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20879	PG0125	2017-08-07 14:45:00+03	2017-08-07 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-07 18:43:00+03	2017-08-07 22:38:00+03
20880	PG0125	2017-08-20 14:45:00+03	2017-08-20 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20881	PG0125	2017-09-08 14:45:00+03	2017-09-08 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20882	PG0125	2017-09-13 14:45:00+03	2017-09-13 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20883	PG0125	2017-08-05 14:45:00+03	2017-08-05 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-05 14:46:00+03	2017-08-05 18:37:00+03
20884	PG0125	2017-08-19 14:45:00+03	2017-08-19 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20885	PG0125	2017-08-11 14:45:00+03	2017-08-11 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-11 14:47:00+03	2017-08-11 18:36:00+03
20886	PG0125	2017-07-28 14:45:00+03	2017-07-28 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-28 14:47:00+03	2017-07-28 18:40:00+03
20887	PG0125	2017-09-06 14:45:00+03	2017-09-06 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20888	PG0125	2017-08-10 14:45:00+03	2017-08-10 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-10 14:47:00+03	2017-08-10 18:37:00+03
20889	PG0125	2017-09-09 14:45:00+03	2017-09-09 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20890	PG0125	2017-08-29 14:45:00+03	2017-08-29 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20891	PG0125	2017-08-31 14:45:00+03	2017-08-31 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20892	PG0125	2017-09-03 14:45:00+03	2017-09-03 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20893	PG0125	2017-07-24 14:45:00+03	2017-07-24 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-24 14:48:00+03	2017-07-24 18:39:00+03
20894	PG0125	2017-07-19 14:45:00+03	2017-07-19 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-19 14:52:00+03	2017-07-19 18:41:00+03
20895	PG0125	2017-08-06 14:45:00+03	2017-08-06 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-06 14:50:00+03	2017-08-06 18:42:00+03
20896	PG0125	2017-09-14 14:45:00+03	2017-09-14 18:35:00+03	NSK	DME	Cancelled	SU9	\N	\N
20897	PG0125	2017-09-05 14:45:00+03	2017-09-05 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20898	PG0125	2017-08-25 14:45:00+03	2017-08-25 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20899	PG0125	2017-08-23 14:45:00+03	2017-08-23 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20900	PG0125	2017-07-26 14:45:00+03	2017-07-26 18:35:00+03	NSK	DME	Arrived	SU9	2017-07-26 14:49:00+03	2017-07-26 18:37:00+03
20901	PG0125	2017-09-11 14:45:00+03	2017-09-11 18:35:00+03	NSK	DME	Scheduled	SU9	\N	\N
20902	PG0125	2017-08-14 14:45:00+03	2017-08-14 18:35:00+03	NSK	DME	Arrived	SU9	2017-08-14 14:51:00+03	2017-08-14 18:41:00+03
20903	PG0379	2017-09-03 06:40:00+03	2017-09-03 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20904	PG0379	2017-08-20 06:40:00+03	2017-08-20 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20905	PG0379	2017-08-16 06:40:00+03	2017-08-16 09:15:00+03	NSK	SVX	On Time	SU9	\N	\N
20906	PG0379	2017-08-01 06:40:00+03	2017-08-01 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-01 06:43:00+03	2017-08-01 09:20:00+03
20907	PG0379	2017-09-06 06:40:00+03	2017-09-06 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20908	PG0379	2017-07-26 06:40:00+03	2017-07-26 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-26 06:43:00+03	2017-07-26 09:20:00+03
20909	PG0379	2017-08-12 06:40:00+03	2017-08-12 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-12 06:44:00+03	2017-08-12 09:19:00+03
20910	PG0379	2017-08-07 06:40:00+03	2017-08-07 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-07 06:41:00+03	2017-08-07 09:15:00+03
20911	PG0379	2017-08-26 06:40:00+03	2017-08-26 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20912	PG0379	2017-08-19 06:40:00+03	2017-08-19 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20913	PG0379	2017-07-23 06:40:00+03	2017-07-23 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-23 06:43:00+03	2017-07-23 09:17:00+03
20914	PG0379	2017-08-22 06:40:00+03	2017-08-22 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20915	PG0379	2017-09-13 06:40:00+03	2017-09-13 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20916	PG0379	2017-07-22 06:40:00+03	2017-07-22 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-22 06:42:00+03	2017-07-22 09:14:00+03
20917	PG0379	2017-08-11 06:40:00+03	2017-08-11 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-11 06:42:00+03	2017-08-11 09:16:00+03
20918	PG0379	2017-08-13 06:40:00+03	2017-08-13 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-13 06:41:00+03	2017-08-13 09:17:00+03
20919	PG0379	2017-09-11 06:40:00+03	2017-09-11 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20920	PG0379	2017-08-25 06:40:00+03	2017-08-25 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20921	PG0379	2017-07-19 06:40:00+03	2017-07-19 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-19 06:44:00+03	2017-07-19 09:21:00+03
20922	PG0379	2017-07-28 06:40:00+03	2017-07-28 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-28 06:40:00+03	2017-07-28 09:15:00+03
20923	PG0379	2017-09-01 06:40:00+03	2017-09-01 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20924	PG0379	2017-08-05 06:40:00+03	2017-08-05 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-05 06:47:00+03	2017-08-05 09:23:00+03
20925	PG0379	2017-09-04 06:40:00+03	2017-09-04 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20926	PG0379	2017-09-05 06:40:00+03	2017-09-05 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20927	PG0379	2017-07-27 06:40:00+03	2017-07-27 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-27 06:43:00+03	2017-07-27 09:15:00+03
20928	PG0379	2017-08-23 06:40:00+03	2017-08-23 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20929	PG0379	2017-08-31 06:40:00+03	2017-08-31 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20930	PG0379	2017-09-09 06:40:00+03	2017-09-09 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20931	PG0379	2017-07-16 06:40:00+03	2017-07-16 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-16 06:42:00+03	2017-07-16 09:17:00+03
20932	PG0379	2017-07-21 06:40:00+03	2017-07-21 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-21 06:42:00+03	2017-07-21 09:18:00+03
20933	PG0379	2017-08-28 06:40:00+03	2017-08-28 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20934	PG0379	2017-09-14 06:40:00+03	2017-09-14 09:15:00+03	NSK	SVX	Cancelled	SU9	\N	\N
20935	PG0379	2017-08-10 06:40:00+03	2017-08-10 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-10 06:45:00+03	2017-08-10 09:18:00+03
20936	PG0379	2017-09-02 06:40:00+03	2017-09-02 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20937	PG0379	2017-08-15 06:40:00+03	2017-08-15 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-15 06:45:00+03	2017-08-15 09:19:00+03
20938	PG0379	2017-08-03 06:40:00+03	2017-08-03 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-03 06:44:00+03	2017-08-03 09:20:00+03
20939	PG0379	2017-07-18 06:40:00+03	2017-07-18 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-18 06:42:00+03	2017-07-18 09:19:00+03
20940	PG0379	2017-08-17 06:40:00+03	2017-08-17 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20941	PG0379	2017-08-02 06:40:00+03	2017-08-02 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-02 06:44:00+03	2017-08-02 09:19:00+03
20942	PG0379	2017-07-24 06:40:00+03	2017-07-24 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-24 06:43:00+03	2017-07-24 09:19:00+03
20943	PG0379	2017-07-29 06:40:00+03	2017-07-29 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-29 06:45:00+03	2017-07-29 09:21:00+03
20944	PG0379	2017-08-29 06:40:00+03	2017-08-29 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20945	PG0379	2017-08-30 06:40:00+03	2017-08-30 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20946	PG0379	2017-09-07 06:40:00+03	2017-09-07 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20947	PG0379	2017-08-04 06:40:00+03	2017-08-04 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-04 06:42:00+03	2017-08-04 09:15:00+03
20948	PG0379	2017-09-10 06:40:00+03	2017-09-10 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20949	PG0379	2017-09-12 06:40:00+03	2017-09-12 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20950	PG0379	2017-08-06 06:40:00+03	2017-08-06 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-06 06:44:00+03	2017-08-06 09:19:00+03
20951	PG0379	2017-07-25 06:40:00+03	2017-07-25 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-25 06:44:00+03	2017-07-25 09:18:00+03
20952	PG0379	2017-08-14 06:40:00+03	2017-08-14 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-14 06:42:00+03	2017-08-14 09:18:00+03
20953	PG0379	2017-07-31 06:40:00+03	2017-07-31 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-31 06:42:00+03	2017-07-31 09:17:00+03
20954	PG0379	2017-08-09 06:40:00+03	2017-08-09 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-09 06:43:00+03	2017-08-09 09:17:00+03
20955	PG0379	2017-08-08 06:40:00+03	2017-08-08 09:15:00+03	NSK	SVX	Arrived	SU9	2017-08-08 06:45:00+03	2017-08-08 09:18:00+03
20956	PG0379	2017-08-27 06:40:00+03	2017-08-27 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20957	PG0379	2017-07-30 06:40:00+03	2017-07-30 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-30 06:43:00+03	2017-07-30 09:19:00+03
20958	PG0379	2017-08-21 06:40:00+03	2017-08-21 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20959	PG0379	2017-09-08 06:40:00+03	2017-09-08 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20960	PG0379	2017-08-18 06:40:00+03	2017-08-18 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20961	PG0379	2017-07-17 06:40:00+03	2017-07-17 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-17 06:44:00+03	2017-07-17 09:20:00+03
20962	PG0379	2017-07-20 06:40:00+03	2017-07-20 09:15:00+03	NSK	SVX	Arrived	SU9	2017-07-20 06:41:00+03	2017-07-20 09:16:00+03
20963	PG0379	2017-08-24 06:40:00+03	2017-08-24 09:15:00+03	NSK	SVX	Scheduled	SU9	\N	\N
20964	PG0329	2017-09-01 13:15:00+03	2017-09-01 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20965	PG0329	2017-07-17 13:15:00+03	2017-07-17 15:45:00+03	NSK	NYM	Arrived	CN1	2017-07-17 13:19:00+03	2017-07-17 15:50:00+03
20966	PG0329	2017-08-14 13:15:00+03	2017-08-14 15:45:00+03	NSK	NYM	Arrived	CN1	2017-08-14 13:17:00+03	2017-08-14 15:44:00+03
20967	PG0329	2017-07-24 13:15:00+03	2017-07-24 15:45:00+03	NSK	NYM	Arrived	CN1	2017-07-24 13:18:00+03	2017-07-24 15:46:00+03
20968	PG0329	2017-08-28 13:15:00+03	2017-08-28 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20969	PG0329	2017-08-07 13:15:00+03	2017-08-07 15:45:00+03	NSK	NYM	Arrived	CN1	2017-08-07 13:19:00+03	2017-08-07 15:47:00+03
20970	PG0329	2017-07-31 13:15:00+03	2017-07-31 15:45:00+03	NSK	NYM	Arrived	CN1	2017-07-31 13:15:00+03	2017-07-31 15:45:00+03
20971	PG0329	2017-08-25 13:15:00+03	2017-08-25 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20972	PG0329	2017-09-04 13:15:00+03	2017-09-04 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20973	PG0329	2017-08-04 13:15:00+03	2017-08-04 15:45:00+03	NSK	NYM	Arrived	CN1	2017-08-04 13:18:00+03	2017-08-04 15:48:00+03
20974	PG0329	2017-08-11 13:15:00+03	2017-08-11 15:45:00+03	NSK	NYM	Arrived	CN1	2017-08-11 13:19:00+03	2017-08-11 15:48:00+03
20975	PG0329	2017-07-21 13:15:00+03	2017-07-21 15:45:00+03	NSK	NYM	Arrived	CN1	2017-07-21 13:18:00+03	2017-07-21 15:50:00+03
20976	PG0329	2017-08-21 13:15:00+03	2017-08-21 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20977	PG0329	2017-07-28 13:15:00+03	2017-07-28 15:45:00+03	NSK	NYM	Arrived	CN1	2017-07-28 13:18:00+03	2017-07-28 15:46:00+03
20978	PG0329	2017-08-18 13:15:00+03	2017-08-18 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20979	PG0329	2017-09-08 13:15:00+03	2017-09-08 15:45:00+03	NSK	NYM	Scheduled	CN1	\N	\N
20980	PG0329	2017-09-11 13:15:00+03	2017-09-11 15:45:00+03	NSK	NYM	Cancelled	CN1	\N	\N
20981	PG0252	2017-07-21 13:05:00+03	2017-07-21 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-21 13:08:00+03	2017-07-21 14:47:00+03
20982	PG0252	2017-07-17 13:05:00+03	2017-07-17 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-17 13:07:00+03	2017-07-17 14:47:00+03
20983	PG0252	2017-09-03 13:05:00+03	2017-09-03 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20984	PG0252	2017-09-02 13:05:00+03	2017-09-02 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20985	PG0252	2017-08-29 13:05:00+03	2017-08-29 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20986	PG0252	2017-07-25 13:05:00+03	2017-07-25 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-25 16:21:00+03	2017-07-25 18:02:00+03
20987	PG0252	2017-09-14 13:05:00+03	2017-09-14 14:45:00+03	AAQ	SVO	Cancelled	733	\N	\N
20988	PG0252	2017-09-06 13:05:00+03	2017-09-06 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20989	PG0252	2017-08-19 13:05:00+03	2017-08-19 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20990	PG0252	2017-08-20 13:05:00+03	2017-08-20 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20991	PG0252	2017-08-13 13:05:00+03	2017-08-13 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-13 13:09:00+03	2017-08-13 14:49:00+03
20992	PG0252	2017-09-13 13:05:00+03	2017-09-13 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20993	PG0252	2017-07-16 13:05:00+03	2017-07-16 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-16 13:08:00+03	2017-07-16 14:47:00+03
20994	PG0252	2017-08-04 13:05:00+03	2017-08-04 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-04 13:07:00+03	2017-08-04 14:49:00+03
20995	PG0252	2017-07-27 13:05:00+03	2017-07-27 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-27 13:07:00+03	2017-07-27 14:45:00+03
20996	PG0252	2017-08-06 13:05:00+03	2017-08-06 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-06 13:06:00+03	2017-08-06 14:45:00+03
20997	PG0252	2017-08-11 13:05:00+03	2017-08-11 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-11 13:11:00+03	2017-08-11 14:51:00+03
20998	PG0252	2017-08-26 13:05:00+03	2017-08-26 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
20999	PG0252	2017-07-22 13:05:00+03	2017-07-22 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-22 13:10:00+03	2017-07-22 14:50:00+03
21000	PG0252	2017-07-31 13:05:00+03	2017-07-31 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-31 13:08:00+03	2017-07-31 14:48:00+03
21001	PG0252	2017-09-04 13:05:00+03	2017-09-04 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21002	PG0252	2017-07-20 13:05:00+03	2017-07-20 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-20 13:07:00+03	2017-07-20 14:46:00+03
21003	PG0252	2017-08-16 13:05:00+03	2017-08-16 14:45:00+03	AAQ	SVO	On Time	733	\N	\N
21004	PG0252	2017-09-11 13:05:00+03	2017-09-11 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21005	PG0252	2017-08-23 13:05:00+03	2017-08-23 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21006	PG0252	2017-07-24 13:05:00+03	2017-07-24 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-24 15:48:00+03	2017-07-24 17:30:00+03
21007	PG0252	2017-08-07 13:05:00+03	2017-08-07 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-07 13:08:00+03	2017-08-07 14:46:00+03
21008	PG0252	2017-08-17 13:05:00+03	2017-08-17 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21009	PG0252	2017-09-01 13:05:00+03	2017-09-01 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21010	PG0252	2017-09-09 13:05:00+03	2017-09-09 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21011	PG0252	2017-08-25 13:05:00+03	2017-08-25 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21012	PG0252	2017-08-02 13:05:00+03	2017-08-02 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-02 13:11:00+03	2017-08-02 14:50:00+03
21013	PG0252	2017-08-14 13:05:00+03	2017-08-14 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-14 13:09:00+03	2017-08-14 14:49:00+03
21014	PG0252	2017-07-19 13:05:00+03	2017-07-19 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-19 13:05:00+03	2017-07-19 14:45:00+03
21015	PG0252	2017-08-31 13:05:00+03	2017-08-31 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21016	PG0252	2017-08-05 13:05:00+03	2017-08-05 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-05 13:06:00+03	2017-08-05 14:44:00+03
21017	PG0252	2017-08-28 13:05:00+03	2017-08-28 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21018	PG0252	2017-08-18 13:05:00+03	2017-08-18 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21019	PG0252	2017-08-03 13:05:00+03	2017-08-03 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-03 13:08:00+03	2017-08-03 14:49:00+03
21020	PG0252	2017-09-12 13:05:00+03	2017-09-12 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21021	PG0252	2017-08-22 13:05:00+03	2017-08-22 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21022	PG0252	2017-08-01 13:05:00+03	2017-08-01 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-01 13:08:00+03	2017-08-01 14:48:00+03
21023	PG0252	2017-08-21 13:05:00+03	2017-08-21 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21024	PG0252	2017-09-07 13:05:00+03	2017-09-07 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21025	PG0252	2017-08-09 13:05:00+03	2017-08-09 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-09 13:13:00+03	2017-08-09 14:54:00+03
21026	PG0252	2017-08-24 13:05:00+03	2017-08-24 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21027	PG0252	2017-07-29 13:05:00+03	2017-07-29 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-29 13:09:00+03	2017-07-29 14:48:00+03
21028	PG0252	2017-07-30 13:05:00+03	2017-07-30 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-30 13:09:00+03	2017-07-30 14:50:00+03
21029	PG0252	2017-07-26 13:05:00+03	2017-07-26 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-26 13:09:00+03	2017-07-26 14:50:00+03
21030	PG0252	2017-08-27 13:05:00+03	2017-08-27 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21031	PG0252	2017-08-08 13:05:00+03	2017-08-08 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-08 13:08:00+03	2017-08-08 14:48:00+03
21032	PG0252	2017-08-30 13:05:00+03	2017-08-30 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21033	PG0252	2017-08-12 13:05:00+03	2017-08-12 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-12 13:09:00+03	2017-08-12 14:48:00+03
21034	PG0252	2017-09-08 13:05:00+03	2017-09-08 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21035	PG0252	2017-09-05 13:05:00+03	2017-09-05 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21036	PG0252	2017-09-10 13:05:00+03	2017-09-10 14:45:00+03	AAQ	SVO	Scheduled	733	\N	\N
21037	PG0252	2017-08-10 13:05:00+03	2017-08-10 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-10 13:09:00+03	2017-08-10 14:48:00+03
21038	PG0252	2017-08-15 13:05:00+03	2017-08-15 14:45:00+03	AAQ	SVO	Arrived	733	2017-08-15 13:12:00+03	2017-08-15 14:51:00+03
21039	PG0252	2017-07-23 13:05:00+03	2017-07-23 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-23 13:07:00+03	2017-07-23 14:48:00+03
21040	PG0252	2017-07-28 13:05:00+03	2017-07-28 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-28 13:11:00+03	2017-07-28 14:51:00+03
21041	PG0252	2017-07-18 13:05:00+03	2017-07-18 14:45:00+03	AAQ	SVO	Arrived	733	2017-07-18 13:09:00+03	2017-07-18 14:48:00+03
21042	PG0194	2017-08-08 09:10:00+03	2017-08-08 14:15:00+03	AAQ	NOZ	Arrived	733	2017-08-08 12:23:00+03	2017-08-08 17:27:00+03
21043	PG0194	2017-09-12 09:10:00+03	2017-09-12 14:15:00+03	AAQ	NOZ	Scheduled	733	\N	\N
21044	PG0194	2017-08-15 09:10:00+03	2017-08-15 14:15:00+03	AAQ	NOZ	Arrived	733	2017-08-15 09:14:00+03	2017-08-15 14:13:00+03
21045	PG0194	2017-08-22 09:10:00+03	2017-08-22 14:15:00+03	AAQ	NOZ	Scheduled	733	\N	\N
21046	PG0194	2017-07-25 09:10:00+03	2017-07-25 14:15:00+03	AAQ	NOZ	Arrived	733	2017-07-25 09:14:00+03	2017-07-25 14:18:00+03
21047	PG0194	2017-09-05 09:10:00+03	2017-09-05 14:15:00+03	AAQ	NOZ	Scheduled	733	\N	\N
21048	PG0194	2017-08-01 09:10:00+03	2017-08-01 14:15:00+03	AAQ	NOZ	Arrived	733	2017-08-01 09:11:00+03	2017-08-01 14:14:00+03
21049	PG0194	2017-07-18 09:10:00+03	2017-07-18 14:15:00+03	AAQ	NOZ	Arrived	733	2017-07-18 09:14:00+03	2017-07-18 14:24:00+03
21050	PG0194	2017-08-29 09:10:00+03	2017-08-29 14:15:00+03	AAQ	NOZ	Scheduled	733	\N	\N
21051	PG0480	2017-09-02 12:25:00+03	2017-09-02 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21052	PG0480	2017-07-29 12:25:00+03	2017-07-29 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-29 12:27:00+03	2017-07-29 13:16:00+03
21053	PG0480	2017-08-26 12:25:00+03	2017-08-26 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21054	PG0480	2017-09-01 12:25:00+03	2017-09-01 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21055	PG0480	2017-09-07 12:25:00+03	2017-09-07 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21056	PG0480	2017-08-19 12:25:00+03	2017-08-19 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21057	PG0480	2017-07-30 12:25:00+03	2017-07-30 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-30 12:30:00+03	2017-07-30 13:20:00+03
21058	PG0480	2017-07-21 12:25:00+03	2017-07-21 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-21 12:26:00+03	2017-07-21 13:16:00+03
21059	PG0480	2017-08-28 12:25:00+03	2017-08-28 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21060	PG0480	2017-07-31 12:25:00+03	2017-07-31 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-31 12:27:00+03	2017-07-31 13:16:00+03
21061	PG0480	2017-07-22 12:25:00+03	2017-07-22 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-22 12:28:00+03	2017-07-22 13:18:00+03
21062	PG0480	2017-09-11 12:25:00+03	2017-09-11 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21063	PG0480	2017-08-18 12:25:00+03	2017-08-18 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21064	PG0480	2017-09-12 12:25:00+03	2017-09-12 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21065	PG0480	2017-07-20 12:25:00+03	2017-07-20 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-20 12:27:00+03	2017-07-20 13:17:00+03
21066	PG0480	2017-09-06 12:25:00+03	2017-09-06 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21067	PG0480	2017-08-01 12:25:00+03	2017-08-01 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-01 12:29:00+03	2017-08-01 13:20:00+03
21068	PG0480	2017-07-28 12:25:00+03	2017-07-28 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-28 12:30:00+03	2017-07-28 13:20:00+03
21069	PG0480	2017-08-12 12:25:00+03	2017-08-12 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-12 12:30:00+03	2017-08-12 13:19:00+03
21070	PG0480	2017-09-08 12:25:00+03	2017-09-08 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21071	PG0480	2017-08-10 12:25:00+03	2017-08-10 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-10 12:27:00+03	2017-08-10 13:17:00+03
21072	PG0480	2017-08-23 12:25:00+03	2017-08-23 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21073	PG0480	2017-07-19 12:25:00+03	2017-07-19 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-19 12:26:00+03	2017-07-19 13:16:00+03
21074	PG0480	2017-08-02 12:25:00+03	2017-08-02 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-02 12:30:00+03	2017-08-02 13:20:00+03
21075	PG0480	2017-08-14 12:25:00+03	2017-08-14 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-14 12:28:00+03	2017-08-14 13:19:00+03
21076	PG0480	2017-08-17 12:25:00+03	2017-08-17 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21077	PG0480	2017-09-05 12:25:00+03	2017-09-05 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21078	PG0480	2017-07-27 12:25:00+03	2017-07-27 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-27 12:28:00+03	2017-07-27 13:18:00+03
21079	PG0480	2017-08-03 12:25:00+03	2017-08-03 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-03 12:26:00+03	2017-08-03 13:16:00+03
21080	PG0480	2017-09-13 12:25:00+03	2017-09-13 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21081	PG0480	2017-07-23 12:25:00+03	2017-07-23 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-23 12:28:00+03	2017-07-23 13:18:00+03
21082	PG0480	2017-08-11 12:25:00+03	2017-08-11 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-11 12:30:00+03	2017-08-11 13:20:00+03
21083	PG0480	2017-08-04 12:25:00+03	2017-08-04 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-04 12:29:00+03	2017-08-04 13:19:00+03
21084	PG0480	2017-07-18 12:25:00+03	2017-07-18 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-18 12:26:00+03	2017-07-18 13:16:00+03
21085	PG0480	2017-08-13 12:25:00+03	2017-08-13 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-13 12:26:00+03	2017-08-13 13:16:00+03
21086	PG0480	2017-08-31 12:25:00+03	2017-08-31 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21087	PG0480	2017-08-20 12:25:00+03	2017-08-20 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21088	PG0480	2017-08-29 12:25:00+03	2017-08-29 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21089	PG0480	2017-09-04 12:25:00+03	2017-09-04 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21090	PG0480	2017-07-26 12:25:00+03	2017-07-26 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-26 12:26:00+03	2017-07-26 13:16:00+03
21091	PG0480	2017-08-05 12:25:00+03	2017-08-05 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-05 12:28:00+03	2017-08-05 13:18:00+03
21092	PG0480	2017-08-16 12:25:00+03	2017-08-16 13:15:00+03	AAQ	EGO	On Time	SU9	\N	\N
21093	PG0480	2017-08-27 12:25:00+03	2017-08-27 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21094	PG0480	2017-09-09 12:25:00+03	2017-09-09 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21095	PG0480	2017-09-14 12:25:00+03	2017-09-14 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21096	PG0480	2017-07-17 12:25:00+03	2017-07-17 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-17 12:29:00+03	2017-07-17 13:19:00+03
21097	PG0480	2017-08-06 12:25:00+03	2017-08-06 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-06 12:26:00+03	2017-08-06 13:17:00+03
21098	PG0480	2017-08-24 12:25:00+03	2017-08-24 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21099	PG0480	2017-08-25 12:25:00+03	2017-08-25 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21100	PG0480	2017-08-30 12:25:00+03	2017-08-30 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21101	PG0480	2017-09-03 12:25:00+03	2017-09-03 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21102	PG0480	2017-08-07 12:25:00+03	2017-08-07 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-07 12:29:00+03	2017-08-07 13:18:00+03
21103	PG0480	2017-07-16 12:25:00+03	2017-07-16 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-16 12:35:00+03	2017-07-16 13:25:00+03
21104	PG0480	2017-08-15 12:25:00+03	2017-08-15 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-15 12:30:00+03	2017-08-15 13:19:00+03
21105	PG0480	2017-08-21 12:25:00+03	2017-08-21 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21106	PG0480	2017-08-09 12:25:00+03	2017-08-09 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-09 12:31:00+03	2017-08-09 13:20:00+03
21107	PG0480	2017-09-10 12:25:00+03	2017-09-10 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21108	PG0480	2017-07-24 12:25:00+03	2017-07-24 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-24 12:27:00+03	2017-07-24 13:17:00+03
21109	PG0480	2017-07-25 12:25:00+03	2017-07-25 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-07-25 12:26:00+03	2017-07-25 13:16:00+03
21110	PG0480	2017-08-08 12:25:00+03	2017-08-08 13:15:00+03	AAQ	EGO	Arrived	SU9	2017-08-08 12:29:00+03	2017-08-08 13:18:00+03
21111	PG0480	2017-08-22 12:25:00+03	2017-08-22 13:15:00+03	AAQ	EGO	Scheduled	SU9	\N	\N
21112	PG0565	2017-08-11 10:25:00+03	2017-08-11 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-11 13:06:00+03	2017-08-11 16:24:00+03
21113	PG0565	2017-07-24 10:25:00+03	2017-07-24 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-24 10:28:00+03	2017-07-24 13:42:00+03
21114	PG0565	2017-08-31 10:25:00+03	2017-08-31 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21115	PG0566	2017-08-31 10:25:00+03	2017-08-31 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21116	PG0566	2017-09-14 10:25:00+03	2017-09-14 13:40:00+03	UCT	UFA	Cancelled	CN1	\N	\N
21117	PG0565	2017-07-25 10:25:00+03	2017-07-25 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-25 10:28:00+03	2017-07-25 13:47:00+03
21118	PG0566	2017-07-27 10:25:00+03	2017-07-27 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-27 10:26:00+03	2017-07-27 13:41:00+03
21119	PG0566	2017-08-30 10:25:00+03	2017-08-30 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21120	PG0565	2017-09-05 10:25:00+03	2017-09-05 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21121	PG0566	2017-09-05 10:25:00+03	2017-09-05 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21122	PG0565	2017-07-30 10:25:00+03	2017-07-30 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-30 10:31:00+03	2017-07-30 13:44:00+03
21123	PG0566	2017-07-25 10:25:00+03	2017-07-25 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-25 10:31:00+03	2017-07-25 13:48:00+03
21124	PG0566	2017-07-30 10:25:00+03	2017-07-30 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-30 10:27:00+03	2017-07-30 13:42:00+03
21125	PG0566	2017-08-12 10:25:00+03	2017-08-12 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-12 10:25:00+03	2017-08-12 13:40:00+03
21126	PG0565	2017-08-17 10:25:00+03	2017-08-17 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21127	PG0566	2017-08-17 10:25:00+03	2017-08-17 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21128	PG0565	2017-08-03 10:25:00+03	2017-08-03 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-03 10:28:00+03	2017-08-03 13:42:00+03
21129	PG0565	2017-08-12 10:25:00+03	2017-08-12 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-12 10:27:00+03	2017-08-12 13:39:00+03
21130	PG0566	2017-08-07 10:25:00+03	2017-08-07 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-07 10:28:00+03	2017-08-07 13:49:00+03
21131	PG0565	2017-08-07 10:25:00+03	2017-08-07 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-07 10:27:00+03	2017-08-07 13:43:00+03
21132	PG0566	2017-08-02 10:25:00+03	2017-08-02 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-02 10:26:00+03	2017-08-02 13:40:00+03
21133	PG0565	2017-08-02 10:25:00+03	2017-08-02 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-02 10:28:00+03	2017-08-02 13:39:00+03
21134	PG0566	2017-08-08 10:25:00+03	2017-08-08 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-08 10:31:00+03	2017-08-08 13:46:00+03
21135	PG0566	2017-09-11 10:25:00+03	2017-09-11 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21136	PG0565	2017-09-11 10:25:00+03	2017-09-11 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21137	PG0566	2017-09-02 10:25:00+03	2017-09-02 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21138	PG0565	2017-09-02 10:25:00+03	2017-09-02 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21139	PG0565	2017-08-19 10:25:00+03	2017-08-19 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21140	PG0565	2017-08-15 10:25:00+03	2017-08-15 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-15 10:26:00+03	2017-08-15 13:42:00+03
21141	PG0565	2017-07-27 10:25:00+03	2017-07-27 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-27 10:26:00+03	2017-07-27 13:42:00+03
21142	PG0566	2017-08-15 10:25:00+03	2017-08-15 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-15 13:52:00+03	2017-08-15 17:05:00+03
21143	PG0566	2017-08-19 10:25:00+03	2017-08-19 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21144	PG0565	2017-09-10 10:25:00+03	2017-09-10 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21145	PG0565	2017-08-26 10:25:00+03	2017-08-26 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21146	PG0566	2017-08-26 10:25:00+03	2017-08-26 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21147	PG0566	2017-08-27 10:25:00+03	2017-08-27 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21148	PG0565	2017-07-16 10:25:00+03	2017-07-16 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-16 10:27:00+03	2017-07-16 13:45:00+03
21149	PG0566	2017-07-16 10:25:00+03	2017-07-16 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-16 10:27:00+03	2017-07-16 13:43:00+03
21150	PG0566	2017-07-18 10:25:00+03	2017-07-18 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-18 10:29:00+03	2017-07-18 13:43:00+03
21151	PG0565	2017-07-18 10:25:00+03	2017-07-18 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-18 10:30:00+03	2017-07-18 13:44:00+03
21152	PG0565	2017-08-27 10:25:00+03	2017-08-27 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21153	PG0566	2017-09-10 10:25:00+03	2017-09-10 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21154	PG0565	2017-08-09 10:25:00+03	2017-08-09 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-09 10:27:00+03	2017-08-09 13:39:00+03
21155	PG0566	2017-08-09 10:25:00+03	2017-08-09 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-09 13:07:00+03	2017-08-09 16:21:00+03
21156	PG0565	2017-09-07 10:25:00+03	2017-09-07 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21157	PG0565	2017-09-13 10:25:00+03	2017-09-13 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21158	PG0566	2017-09-13 10:25:00+03	2017-09-13 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21159	PG0565	2017-09-01 10:25:00+03	2017-09-01 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21160	PG0565	2017-07-19 10:25:00+03	2017-07-19 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-19 10:26:00+03	2017-07-19 13:42:00+03
21161	PG0566	2017-08-03 10:25:00+03	2017-08-03 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-03 10:28:00+03	2017-08-03 13:44:00+03
21162	PG0566	2017-08-24 10:25:00+03	2017-08-24 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21163	PG0565	2017-08-24 10:25:00+03	2017-08-24 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21164	PG0566	2017-07-19 10:25:00+03	2017-07-19 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-19 10:29:00+03	2017-07-19 13:42:00+03
21165	PG0565	2017-08-21 10:25:00+03	2017-08-21 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21166	PG0566	2017-08-21 10:25:00+03	2017-08-21 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21167	PG0565	2017-08-08 10:25:00+03	2017-08-08 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-08 10:29:00+03	2017-08-08 13:46:00+03
21168	PG0566	2017-09-01 10:25:00+03	2017-09-01 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21169	PG0566	2017-09-07 10:25:00+03	2017-09-07 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21170	PG0565	2017-08-30 10:25:00+03	2017-08-30 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21171	PG0566	2017-08-18 10:25:00+03	2017-08-18 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21172	PG0565	2017-08-18 10:25:00+03	2017-08-18 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21173	PG0565	2017-08-04 10:25:00+03	2017-08-04 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-04 10:27:00+03	2017-08-04 13:45:00+03
21174	PG0566	2017-08-04 10:25:00+03	2017-08-04 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-04 10:25:00+03	2017-08-04 13:36:00+03
21175	PG0565	2017-07-23 10:25:00+03	2017-07-23 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-23 10:29:00+03	2017-07-23 13:44:00+03
21176	PG0566	2017-07-23 10:25:00+03	2017-07-23 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-23 10:30:00+03	2017-07-23 13:45:00+03
21177	PG0565	2017-09-03 10:25:00+03	2017-09-03 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21178	PG0566	2017-09-03 10:25:00+03	2017-09-03 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21179	PG0565	2017-07-31 10:25:00+03	2017-07-31 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-31 10:30:00+03	2017-07-31 13:48:00+03
21180	PG0566	2017-07-31 10:25:00+03	2017-07-31 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-31 10:27:00+03	2017-07-31 13:44:00+03
21181	PG0566	2017-07-29 10:25:00+03	2017-07-29 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-29 10:32:00+03	2017-07-29 13:49:00+03
21182	PG0566	2017-07-24 10:25:00+03	2017-07-24 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-24 10:27:00+03	2017-07-24 13:39:00+03
21183	PG0566	2017-08-06 10:25:00+03	2017-08-06 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-06 10:28:00+03	2017-08-06 13:48:00+03
21184	PG0566	2017-09-09 10:25:00+03	2017-09-09 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21185	PG0565	2017-09-09 10:25:00+03	2017-09-09 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21186	PG0565	2017-08-06 10:25:00+03	2017-08-06 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-06 10:27:00+03	2017-08-06 13:39:00+03
21187	PG0566	2017-08-13 10:25:00+03	2017-08-13 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-13 10:29:00+03	2017-08-13 13:44:00+03
21188	PG0566	2017-09-06 10:25:00+03	2017-09-06 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21189	PG0565	2017-08-14 10:25:00+03	2017-08-14 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-14 10:31:00+03	2017-08-14 13:44:00+03
21190	PG0566	2017-09-04 10:25:00+03	2017-09-04 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21191	PG0565	2017-09-04 10:25:00+03	2017-09-04 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21192	PG0566	2017-07-20 10:25:00+03	2017-07-20 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-20 10:27:00+03	2017-07-20 13:44:00+03
21193	PG0565	2017-07-20 10:25:00+03	2017-07-20 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-20 10:28:00+03	2017-07-20 13:44:00+03
21194	PG0565	2017-08-23 10:25:00+03	2017-08-23 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21195	PG0565	2017-09-06 10:25:00+03	2017-09-06 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21196	PG0566	2017-08-14 10:25:00+03	2017-08-14 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-14 10:27:00+03	2017-08-14 13:42:00+03
21197	PG0565	2017-08-28 10:25:00+03	2017-08-28 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21198	PG0566	2017-08-28 10:25:00+03	2017-08-28 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21199	PG0566	2017-08-10 10:25:00+03	2017-08-10 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-10 10:31:00+03	2017-08-10 13:42:00+03
21200	PG0565	2017-08-13 10:25:00+03	2017-08-13 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-13 10:27:00+03	2017-08-13 13:40:00+03
21201	PG0566	2017-08-23 10:25:00+03	2017-08-23 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21202	PG0566	2017-09-08 10:25:00+03	2017-09-08 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21203	PG0565	2017-09-08 10:25:00+03	2017-09-08 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21204	PG0565	2017-08-10 10:25:00+03	2017-08-10 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-10 10:29:00+03	2017-08-10 13:45:00+03
21205	PG0565	2017-09-12 10:25:00+03	2017-09-12 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21206	PG0566	2017-08-11 10:25:00+03	2017-08-11 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-11 13:40:00+03	2017-08-11 16:57:00+03
21207	PG0566	2017-09-12 10:25:00+03	2017-09-12 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21208	PG0565	2017-07-22 10:25:00+03	2017-07-22 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-22 10:25:00+03	2017-07-22 13:39:00+03
21209	PG0565	2017-09-14 10:25:00+03	2017-09-14 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21210	PG0566	2017-07-22 10:25:00+03	2017-07-22 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-22 10:27:00+03	2017-07-22 13:41:00+03
21211	PG0566	2017-07-21 10:25:00+03	2017-07-21 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-21 10:26:00+03	2017-07-21 13:40:00+03
21212	PG0566	2017-07-28 10:25:00+03	2017-07-28 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-28 10:27:00+03	2017-07-28 13:43:00+03
21213	PG0566	2017-07-26 10:25:00+03	2017-07-26 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-26 10:27:00+03	2017-07-26 13:45:00+03
21214	PG0565	2017-07-28 10:25:00+03	2017-07-28 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-28 13:37:00+03	2017-07-28 16:51:00+03
21215	PG0565	2017-08-25 10:25:00+03	2017-08-25 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21216	PG0566	2017-08-25 10:25:00+03	2017-08-25 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21217	PG0565	2017-07-26 10:25:00+03	2017-07-26 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-26 10:27:00+03	2017-07-26 13:39:00+03
21218	PG0565	2017-08-22 10:25:00+03	2017-08-22 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21219	PG0565	2017-07-17 10:25:00+03	2017-07-17 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-17 10:26:00+03	2017-07-17 13:39:00+03
21220	PG0566	2017-07-17 10:25:00+03	2017-07-17 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-17 10:28:00+03	2017-07-17 13:44:00+03
21221	PG0565	2017-08-01 10:25:00+03	2017-08-01 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-01 13:55:00+03	2017-08-01 17:10:00+03
21222	PG0566	2017-08-16 10:25:00+03	2017-08-16 13:40:00+03	UCT	UFA	On Time	CN1	\N	\N
21223	PG0565	2017-08-16 10:25:00+03	2017-08-16 13:40:00+03	UCT	UFA	On Time	CN1	\N	\N
21224	PG0566	2017-08-01 10:25:00+03	2017-08-01 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-01 10:30:00+03	2017-08-01 13:45:00+03
21225	PG0566	2017-08-22 10:25:00+03	2017-08-22 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21226	PG0566	2017-08-29 10:25:00+03	2017-08-29 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21227	PG0565	2017-08-29 10:25:00+03	2017-08-29 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21228	PG0566	2017-08-05 10:25:00+03	2017-08-05 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-05 10:27:00+03	2017-08-05 13:39:00+03
21229	PG0565	2017-08-20 10:25:00+03	2017-08-20 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21230	PG0565	2017-08-05 10:25:00+03	2017-08-05 13:40:00+03	UCT	UFA	Arrived	CN1	2017-08-05 10:29:00+03	2017-08-05 13:43:00+03
21231	PG0565	2017-07-29 10:25:00+03	2017-07-29 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-29 10:29:00+03	2017-07-29 13:47:00+03
21232	PG0566	2017-08-20 10:25:00+03	2017-08-20 13:40:00+03	UCT	UFA	Scheduled	CN1	\N	\N
21233	PG0565	2017-07-21 10:25:00+03	2017-07-21 13:40:00+03	UCT	UFA	Arrived	CN1	2017-07-21 10:26:00+03	2017-07-21 13:40:00+03
21234	PG0110	2017-08-06 12:00:00+03	2017-08-06 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-06 12:04:00+03	2017-08-06 13:22:00+03
21235	PG0110	2017-08-02 12:00:00+03	2017-08-02 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-02 12:02:00+03	2017-08-02 13:21:00+03
21236	PG0110	2017-07-22 12:00:00+03	2017-07-22 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-22 12:04:00+03	2017-07-22 13:25:00+03
21237	PG0110	2017-09-10 12:00:00+03	2017-09-10 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21238	PG0110	2017-08-20 12:00:00+03	2017-08-20 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21239	PG0110	2017-08-28 12:00:00+03	2017-08-28 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21240	PG0110	2017-07-17 12:00:00+03	2017-07-17 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-17 12:03:00+03	2017-07-17 13:23:00+03
21241	PG0110	2017-08-30 12:00:00+03	2017-08-30 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21242	PG0110	2017-08-10 12:00:00+03	2017-08-10 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-10 12:01:00+03	2017-08-10 13:21:00+03
21243	PG0110	2017-08-23 12:00:00+03	2017-08-23 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21244	PG0110	2017-08-27 12:00:00+03	2017-08-27 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21245	PG0110	2017-08-22 12:00:00+03	2017-08-22 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21246	PG0110	2017-09-06 12:00:00+03	2017-09-06 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21247	PG0110	2017-09-02 12:00:00+03	2017-09-02 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21248	PG0110	2017-07-27 12:00:00+03	2017-07-27 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-27 12:04:00+03	2017-07-27 13:25:00+03
21249	PG0110	2017-07-28 12:00:00+03	2017-07-28 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-28 14:42:00+03	2017-07-28 16:03:00+03
21250	PG0110	2017-08-17 12:00:00+03	2017-08-17 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21251	PG0110	2017-08-05 12:00:00+03	2017-08-05 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-05 12:04:00+03	2017-08-05 13:24:00+03
21252	PG0110	2017-08-14 12:00:00+03	2017-08-14 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-14 12:04:00+03	2017-08-14 13:25:00+03
21253	PG0110	2017-08-12 12:00:00+03	2017-08-12 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-12 12:07:00+03	2017-08-12 13:28:00+03
21254	PG0110	2017-09-01 12:00:00+03	2017-09-01 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21255	PG0110	2017-08-07 12:00:00+03	2017-08-07 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-07 12:06:00+03	2017-08-07 13:26:00+03
21256	PG0110	2017-07-20 12:00:00+03	2017-07-20 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-20 12:04:00+03	2017-07-20 13:24:00+03
21257	PG0110	2017-09-12 12:00:00+03	2017-09-12 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21258	PG0110	2017-09-08 12:00:00+03	2017-09-08 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21259	PG0110	2017-07-21 12:00:00+03	2017-07-21 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-21 12:01:00+03	2017-07-21 13:22:00+03
21260	PG0110	2017-08-26 12:00:00+03	2017-08-26 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21261	PG0110	2017-08-29 12:00:00+03	2017-08-29 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21262	PG0110	2017-09-14 12:00:00+03	2017-09-14 13:20:00+03	UCT	TJM	Cancelled	CR2	\N	\N
21263	PG0110	2017-08-13 12:00:00+03	2017-08-13 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-13 12:06:00+03	2017-08-13 13:25:00+03
21264	PG0110	2017-07-19 12:00:00+03	2017-07-19 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-19 12:04:00+03	2017-07-19 13:25:00+03
21265	PG0110	2017-08-15 12:00:00+03	2017-08-15 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-15 12:03:00+03	2017-08-15 13:22:00+03
21266	PG0110	2017-08-11 12:00:00+03	2017-08-11 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-11 12:02:00+03	2017-08-11 13:23:00+03
21267	PG0110	2017-09-13 12:00:00+03	2017-09-13 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21268	PG0110	2017-09-07 12:00:00+03	2017-09-07 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21269	PG0110	2017-07-26 12:00:00+03	2017-07-26 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-26 12:02:00+03	2017-07-26 13:20:00+03
21270	PG0110	2017-09-03 12:00:00+03	2017-09-03 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21271	PG0110	2017-07-25 12:00:00+03	2017-07-25 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-25 12:07:00+03	2017-07-25 13:27:00+03
21272	PG0110	2017-08-01 12:00:00+03	2017-08-01 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-01 12:05:00+03	2017-08-01 13:25:00+03
21273	PG0110	2017-08-24 12:00:00+03	2017-08-24 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21274	PG0110	2017-07-16 12:00:00+03	2017-07-16 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-16 12:03:00+03	2017-07-16 13:22:00+03
21275	PG0110	2017-08-03 12:00:00+03	2017-08-03 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-03 12:03:00+03	2017-08-03 13:21:00+03
21276	PG0110	2017-08-18 12:00:00+03	2017-08-18 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21277	PG0110	2017-09-09 12:00:00+03	2017-09-09 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21278	PG0110	2017-09-04 12:00:00+03	2017-09-04 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21279	PG0110	2017-07-23 12:00:00+03	2017-07-23 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-23 12:04:00+03	2017-07-23 13:24:00+03
21280	PG0110	2017-07-30 12:00:00+03	2017-07-30 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-30 12:05:00+03	2017-07-30 13:25:00+03
21281	PG0110	2017-08-25 12:00:00+03	2017-08-25 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21282	PG0110	2017-08-31 12:00:00+03	2017-08-31 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21283	PG0110	2017-08-19 12:00:00+03	2017-08-19 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21284	PG0110	2017-07-29 12:00:00+03	2017-07-29 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-29 12:04:00+03	2017-07-29 13:24:00+03
21285	PG0110	2017-08-04 12:00:00+03	2017-08-04 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-04 12:02:00+03	2017-08-04 13:21:00+03
21286	PG0110	2017-09-11 12:00:00+03	2017-09-11 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21287	PG0110	2017-08-16 12:00:00+03	2017-08-16 13:20:00+03	UCT	TJM	On Time	CR2	\N	\N
21288	PG0110	2017-09-05 12:00:00+03	2017-09-05 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21289	PG0110	2017-07-24 12:00:00+03	2017-07-24 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-24 12:03:00+03	2017-07-24 13:22:00+03
21290	PG0110	2017-08-08 12:00:00+03	2017-08-08 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-08 12:04:00+03	2017-08-08 13:25:00+03
21291	PG0110	2017-08-21 12:00:00+03	2017-08-21 13:20:00+03	UCT	TJM	Scheduled	CR2	\N	\N
21292	PG0110	2017-07-18 12:00:00+03	2017-07-18 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-18 15:05:00+03	2017-07-18 16:24:00+03
21293	PG0110	2017-08-09 12:00:00+03	2017-08-09 13:20:00+03	UCT	TJM	Arrived	CR2	2017-08-09 12:01:00+03	2017-08-09 13:22:00+03
21294	PG0110	2017-07-31 12:00:00+03	2017-07-31 13:20:00+03	UCT	TJM	Arrived	CR2	2017-07-31 12:04:00+03	2017-07-31 13:25:00+03
21295	PG0630	2017-08-14 11:35:00+03	2017-08-14 13:50:00+03	USK	DME	Arrived	CR2	2017-08-14 11:35:00+03	2017-08-14 13:50:00+03
21296	PG0630	2017-08-21 11:35:00+03	2017-08-21 13:50:00+03	USK	DME	Scheduled	CR2	\N	\N
21297	PG0630	2017-07-24 11:35:00+03	2017-07-24 13:50:00+03	USK	DME	Arrived	CR2	2017-07-24 11:36:00+03	2017-07-24 13:53:00+03
21298	PG0630	2017-07-17 11:35:00+03	2017-07-17 13:50:00+03	USK	DME	Arrived	CR2	2017-07-17 11:39:00+03	2017-07-17 13:56:00+03
21299	PG0630	2017-07-31 11:35:00+03	2017-07-31 13:50:00+03	USK	DME	Arrived	CR2	2017-07-31 11:40:00+03	2017-07-31 13:55:00+03
21300	PG0630	2017-08-28 11:35:00+03	2017-08-28 13:50:00+03	USK	DME	Scheduled	CR2	\N	\N
21301	PG0630	2017-08-07 11:35:00+03	2017-08-07 13:50:00+03	USK	DME	Arrived	CR2	2017-08-07 11:36:00+03	2017-08-07 13:52:00+03
21302	PG0630	2017-09-04 11:35:00+03	2017-09-04 13:50:00+03	USK	DME	Scheduled	CR2	\N	\N
21303	PG0630	2017-09-11 11:35:00+03	2017-09-11 13:50:00+03	USK	DME	Cancelled	CR2	\N	\N
21304	PG0094	2017-08-21 09:45:00+03	2017-08-21 11:55:00+03	USK	SVO	Scheduled	CR2	\N	\N
21305	PG0094	2017-08-07 09:45:00+03	2017-08-07 11:55:00+03	USK	SVO	Arrived	CR2	2017-08-07 09:46:00+03	2017-08-07 11:54:00+03
21306	PG0094	2017-08-28 09:45:00+03	2017-08-28 11:55:00+03	USK	SVO	Scheduled	CR2	\N	\N
21307	PG0094	2017-07-24 09:45:00+03	2017-07-24 11:55:00+03	USK	SVO	Arrived	CR2	2017-07-24 09:46:00+03	2017-07-24 11:58:00+03
21308	PG0094	2017-09-11 09:45:00+03	2017-09-11 11:55:00+03	USK	SVO	Cancelled	CR2	\N	\N
21309	PG0094	2017-08-14 09:45:00+03	2017-08-14 11:55:00+03	USK	SVO	Arrived	CR2	2017-08-14 09:53:00+03	2017-08-14 12:04:00+03
21310	PG0094	2017-09-04 09:45:00+03	2017-09-04 11:55:00+03	USK	SVO	Scheduled	CR2	\N	\N
21311	PG0094	2017-07-31 09:45:00+03	2017-07-31 11:55:00+03	USK	SVO	Arrived	CR2	2017-07-31 09:45:00+03	2017-07-31 11:56:00+03
21312	PG0094	2017-07-17 09:45:00+03	2017-07-17 11:55:00+03	USK	SVO	Arrived	CR2	2017-07-17 09:46:00+03	2017-07-17 11:55:00+03
21313	PG0113	2017-07-25 18:30:00+03	2017-07-25 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-25 18:34:00+03	2017-07-25 20:45:00+03
21314	PG0113	2017-08-20 18:30:00+03	2017-08-20 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21315	PG0113	2017-08-25 18:30:00+03	2017-08-25 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21316	PG0113	2017-09-10 18:30:00+03	2017-09-10 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21317	PG0113	2017-08-01 18:30:00+03	2017-08-01 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-01 18:33:00+03	2017-08-01 20:44:00+03
21318	PG0113	2017-07-28 18:30:00+03	2017-07-28 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-28 18:32:00+03	2017-07-28 20:41:00+03
21319	PG0113	2017-07-30 18:30:00+03	2017-07-30 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-30 18:32:00+03	2017-07-30 20:40:00+03
21320	PG0113	2017-07-21 18:30:00+03	2017-07-21 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-21 18:32:00+03	2017-07-21 20:42:00+03
21321	PG0113	2017-08-29 18:30:00+03	2017-08-29 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21322	PG0113	2017-09-08 18:30:00+03	2017-09-08 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21323	PG0113	2017-08-15 18:30:00+03	2017-08-15 20:40:00+03	NNM	DME	On Time	CR2	\N	\N
21324	PG0113	2017-08-11 18:30:00+03	2017-08-11 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-11 18:31:00+03	2017-08-11 20:41:00+03
21325	PG0113	2017-08-18 18:30:00+03	2017-08-18 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21326	PG0113	2017-08-13 18:30:00+03	2017-08-13 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-13 18:31:00+03	2017-08-13 20:42:00+03
21327	PG0113	2017-08-22 18:30:00+03	2017-08-22 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21328	PG0113	2017-09-01 18:30:00+03	2017-09-01 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21329	PG0113	2017-07-23 18:30:00+03	2017-07-23 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-23 18:32:00+03	2017-07-23 20:41:00+03
21330	PG0113	2017-09-03 18:30:00+03	2017-09-03 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21331	PG0113	2017-09-05 18:30:00+03	2017-09-05 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21332	PG0113	2017-07-16 18:30:00+03	2017-07-16 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-16 18:31:00+03	2017-07-16 20:40:00+03
21333	PG0113	2017-08-06 18:30:00+03	2017-08-06 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-06 18:31:00+03	2017-08-06 20:39:00+03
21334	PG0113	2017-08-27 18:30:00+03	2017-08-27 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21335	PG0113	2017-08-04 18:30:00+03	2017-08-04 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-04 18:34:00+03	2017-08-04 20:45:00+03
21336	PG0113	2017-07-18 18:30:00+03	2017-07-18 20:40:00+03	NNM	DME	Arrived	CR2	2017-07-18 18:32:00+03	2017-07-18 20:41:00+03
21337	PG0113	2017-08-08 18:30:00+03	2017-08-08 20:40:00+03	NNM	DME	Arrived	CR2	2017-08-08 18:32:00+03	2017-08-08 20:41:00+03
21338	PG0113	2017-09-12 18:30:00+03	2017-09-12 20:40:00+03	NNM	DME	Scheduled	CR2	\N	\N
21339	PG0680	2017-07-19 15:20:00+03	2017-07-19 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-19 15:22:00+03	2017-07-19 17:32:00+03
21340	PG0680	2017-09-08 15:20:00+03	2017-09-08 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21341	PG0680	2017-08-03 15:20:00+03	2017-08-03 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-03 15:23:00+03	2017-08-03 17:32:00+03
21342	PG0680	2017-07-27 15:20:00+03	2017-07-27 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-27 15:24:00+03	2017-07-27 17:34:00+03
21343	PG0680	2017-08-23 15:20:00+03	2017-08-23 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21344	PG0680	2017-08-13 15:20:00+03	2017-08-13 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-13 15:24:00+03	2017-08-13 17:34:00+03
21345	PG0680	2017-08-02 15:20:00+03	2017-08-02 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-02 15:21:00+03	2017-08-02 17:30:00+03
21346	PG0680	2017-07-18 15:20:00+03	2017-07-18 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-18 15:20:00+03	2017-07-18 17:30:00+03
21347	PG0680	2017-08-26 15:20:00+03	2017-08-26 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21348	PG0680	2017-09-14 15:20:00+03	2017-09-14 17:30:00+03	NNM	SVO	Cancelled	CR2	\N	\N
21349	PG0680	2017-07-24 15:20:00+03	2017-07-24 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-24 15:22:00+03	2017-07-24 17:32:00+03
21350	PG0680	2017-09-05 15:20:00+03	2017-09-05 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21351	PG0680	2017-08-27 15:20:00+03	2017-08-27 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21352	PG0680	2017-09-04 15:20:00+03	2017-09-04 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21353	PG0680	2017-08-17 15:20:00+03	2017-08-17 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21354	PG0680	2017-08-25 15:20:00+03	2017-08-25 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21355	PG0680	2017-08-12 15:20:00+03	2017-08-12 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-12 15:21:00+03	2017-08-12 17:30:00+03
21356	PG0680	2017-09-13 15:20:00+03	2017-09-13 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21357	PG0680	2017-08-04 15:20:00+03	2017-08-04 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-04 15:24:00+03	2017-08-04 17:34:00+03
21358	PG0680	2017-08-16 15:20:00+03	2017-08-16 17:30:00+03	NNM	SVO	On Time	CR2	\N	\N
21359	PG0680	2017-08-08 15:20:00+03	2017-08-08 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-08 15:22:00+03	2017-08-08 17:30:00+03
21360	PG0680	2017-09-01 15:20:00+03	2017-09-01 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21361	PG0680	2017-07-26 15:20:00+03	2017-07-26 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-26 15:21:00+03	2017-07-26 17:32:00+03
21362	PG0680	2017-07-21 15:20:00+03	2017-07-21 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-21 15:24:00+03	2017-07-21 17:31:00+03
21363	PG0680	2017-08-21 15:20:00+03	2017-08-21 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21364	PG0680	2017-07-22 15:20:00+03	2017-07-22 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-22 15:25:00+03	2017-07-22 17:33:00+03
21365	PG0680	2017-08-01 15:20:00+03	2017-08-01 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-01 15:25:00+03	2017-08-01 17:37:00+03
21366	PG0680	2017-09-12 15:20:00+03	2017-09-12 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21367	PG0680	2017-07-29 15:20:00+03	2017-07-29 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-29 15:20:00+03	2017-07-29 17:29:00+03
21368	PG0680	2017-07-17 15:20:00+03	2017-07-17 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-17 15:22:00+03	2017-07-17 17:31:00+03
21369	PG0680	2017-08-05 15:20:00+03	2017-08-05 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-05 15:25:00+03	2017-08-05 17:36:00+03
21370	PG0680	2017-08-28 15:20:00+03	2017-08-28 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21371	PG0680	2017-07-23 15:20:00+03	2017-07-23 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-23 15:24:00+03	2017-07-23 17:34:00+03
21372	PG0680	2017-09-10 15:20:00+03	2017-09-10 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21373	PG0680	2017-08-19 15:20:00+03	2017-08-19 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21374	PG0680	2017-08-29 15:20:00+03	2017-08-29 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21375	PG0680	2017-09-03 15:20:00+03	2017-09-03 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21376	PG0680	2017-07-31 15:20:00+03	2017-07-31 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-31 15:25:00+03	2017-07-31 17:38:00+03
21377	PG0680	2017-08-20 15:20:00+03	2017-08-20 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21378	PG0680	2017-09-06 15:20:00+03	2017-09-06 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21379	PG0680	2017-07-20 15:20:00+03	2017-07-20 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-20 15:22:00+03	2017-07-20 17:32:00+03
21380	PG0680	2017-08-06 15:20:00+03	2017-08-06 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-06 15:22:00+03	2017-08-06 17:32:00+03
21381	PG0680	2017-08-09 15:20:00+03	2017-08-09 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-09 15:25:00+03	2017-08-09 17:34:00+03
21382	PG0680	2017-07-28 15:20:00+03	2017-07-28 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-28 15:23:00+03	2017-07-28 17:33:00+03
21383	PG0680	2017-07-16 15:20:00+03	2017-07-16 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-16 15:22:00+03	2017-07-16 17:31:00+03
21384	PG0680	2017-08-15 15:20:00+03	2017-08-15 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-15 15:22:00+03	2017-08-15 17:32:00+03
21385	PG0680	2017-08-14 15:20:00+03	2017-08-14 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-14 15:24:00+03	2017-08-14 17:35:00+03
21386	PG0680	2017-08-18 15:20:00+03	2017-08-18 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21387	PG0680	2017-09-11 15:20:00+03	2017-09-11 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21388	PG0680	2017-09-09 15:20:00+03	2017-09-09 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21389	PG0680	2017-07-25 15:20:00+03	2017-07-25 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-25 15:20:00+03	2017-07-25 17:30:00+03
21390	PG0680	2017-08-30 15:20:00+03	2017-08-30 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21391	PG0680	2017-08-24 15:20:00+03	2017-08-24 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21392	PG0680	2017-08-07 15:20:00+03	2017-08-07 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-07 15:24:00+03	2017-08-07 17:35:00+03
21393	PG0680	2017-07-30 15:20:00+03	2017-07-30 17:30:00+03	NNM	SVO	Arrived	CR2	2017-07-30 15:23:00+03	2017-07-30 17:34:00+03
21394	PG0680	2017-08-22 15:20:00+03	2017-08-22 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21395	PG0680	2017-08-31 15:20:00+03	2017-08-31 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21396	PG0680	2017-08-11 15:20:00+03	2017-08-11 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-11 15:22:00+03	2017-08-11 17:33:00+03
21397	PG0680	2017-08-10 15:20:00+03	2017-08-10 17:30:00+03	NNM	SVO	Arrived	CR2	2017-08-10 15:24:00+03	2017-08-10 17:36:00+03
21398	PG0680	2017-09-02 15:20:00+03	2017-09-02 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21399	PG0680	2017-09-07 15:20:00+03	2017-09-07 17:30:00+03	NNM	SVO	Scheduled	CR2	\N	\N
21400	PG0279	2017-07-26 16:20:00+03	2017-07-26 18:10:00+03	NNM	TJM	Arrived	CR2	2017-07-26 16:23:00+03	2017-07-26 18:14:00+03
21401	PG0279	2017-08-09 16:20:00+03	2017-08-09 18:10:00+03	NNM	TJM	Arrived	CR2	2017-08-09 16:23:00+03	2017-08-09 18:12:00+03
21402	PG0279	2017-07-19 16:20:00+03	2017-07-19 18:10:00+03	NNM	TJM	Arrived	CR2	2017-07-19 16:23:00+03	2017-07-19 18:12:00+03
21403	PG0279	2017-08-30 16:20:00+03	2017-08-30 18:10:00+03	NNM	TJM	Scheduled	CR2	\N	\N
21404	PG0279	2017-08-16 16:20:00+03	2017-08-16 18:10:00+03	NNM	TJM	On Time	CR2	\N	\N
21405	PG0279	2017-09-06 16:20:00+03	2017-09-06 18:10:00+03	NNM	TJM	Scheduled	CR2	\N	\N
21406	PG0279	2017-08-23 16:20:00+03	2017-08-23 18:10:00+03	NNM	TJM	Scheduled	CR2	\N	\N
21407	PG0279	2017-08-02 16:20:00+03	2017-08-02 18:10:00+03	NNM	TJM	Arrived	CR2	2017-08-02 16:23:00+03	2017-08-02 18:14:00+03
21408	PG0279	2017-09-13 16:20:00+03	2017-09-13 18:10:00+03	NNM	TJM	Cancelled	CR2	\N	\N
21409	PG0257	2017-08-28 14:15:00+03	2017-08-28 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21410	PG0257	2017-08-02 14:15:00+03	2017-08-02 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-02 14:18:00+03	2017-08-02 15:12:00+03
21411	PG0257	2017-07-17 14:15:00+03	2017-07-17 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-17 14:17:00+03	2017-07-17 15:13:00+03
21412	PG0257	2017-07-26 14:15:00+03	2017-07-26 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-26 14:15:00+03	2017-07-26 15:09:00+03
21413	PG0257	2017-08-19 14:15:00+03	2017-08-19 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21414	PG0257	2017-08-09 14:15:00+03	2017-08-09 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-09 14:17:00+03	2017-08-09 15:12:00+03
21415	PG0257	2017-08-18 14:15:00+03	2017-08-18 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21416	PG0257	2017-08-16 14:15:00+03	2017-08-16 15:10:00+03	NNM	ARH	On Time	CR2	\N	\N
21417	PG0257	2017-08-30 14:15:00+03	2017-08-30 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21418	PG0257	2017-08-31 14:15:00+03	2017-08-31 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21419	PG0257	2017-08-27 14:15:00+03	2017-08-27 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21420	PG0257	2017-09-09 14:15:00+03	2017-09-09 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21421	PG0257	2017-08-17 14:15:00+03	2017-08-17 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21422	PG0257	2017-07-20 14:15:00+03	2017-07-20 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-20 14:18:00+03	2017-07-20 15:13:00+03
21423	PG0257	2017-08-25 14:15:00+03	2017-08-25 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21424	PG0257	2017-08-08 14:15:00+03	2017-08-08 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-08 17:28:00+03	2017-08-08 18:24:00+03
21425	PG0257	2017-09-04 14:15:00+03	2017-09-04 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21426	PG0257	2017-08-05 14:15:00+03	2017-08-05 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-05 14:17:00+03	2017-08-05 15:11:00+03
21427	PG0257	2017-08-13 14:15:00+03	2017-08-13 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-13 14:15:00+03	2017-08-13 15:10:00+03
21428	PG0257	2017-08-26 14:15:00+03	2017-08-26 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21429	PG0257	2017-07-22 14:15:00+03	2017-07-22 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-22 14:18:00+03	2017-07-22 15:13:00+03
21430	PG0257	2017-09-07 14:15:00+03	2017-09-07 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21431	PG0257	2017-09-06 14:15:00+03	2017-09-06 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21432	PG0257	2017-09-13 14:15:00+03	2017-09-13 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21433	PG0257	2017-08-03 14:15:00+03	2017-08-03 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-03 14:16:00+03	2017-08-03 15:11:00+03
21434	PG0257	2017-07-29 14:15:00+03	2017-07-29 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-29 14:16:00+03	2017-07-29 15:12:00+03
21435	PG0257	2017-08-23 14:15:00+03	2017-08-23 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21436	PG0257	2017-09-12 14:15:00+03	2017-09-12 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21437	PG0257	2017-07-21 14:15:00+03	2017-07-21 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-21 14:20:00+03	2017-07-21 15:15:00+03
21438	PG0257	2017-08-22 14:15:00+03	2017-08-22 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21439	PG0257	2017-09-14 14:15:00+03	2017-09-14 15:10:00+03	NNM	ARH	Cancelled	CR2	\N	\N
21440	PG0257	2017-09-03 14:15:00+03	2017-09-03 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21441	PG0257	2017-09-11 14:15:00+03	2017-09-11 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21442	PG0257	2017-07-24 14:15:00+03	2017-07-24 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-24 14:20:00+03	2017-07-24 15:15:00+03
21443	PG0257	2017-07-16 14:15:00+03	2017-07-16 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-16 14:19:00+03	2017-07-16 15:13:00+03
21444	PG0257	2017-07-27 14:15:00+03	2017-07-27 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-27 14:20:00+03	2017-07-27 15:15:00+03
21445	PG0257	2017-09-02 14:15:00+03	2017-09-02 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21446	PG0257	2017-08-11 14:15:00+03	2017-08-11 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-11 14:20:00+03	2017-08-11 15:15:00+03
21447	PG0257	2017-08-04 14:15:00+03	2017-08-04 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-04 14:15:00+03	2017-08-04 15:10:00+03
21448	PG0257	2017-08-01 14:15:00+03	2017-08-01 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-01 14:19:00+03	2017-08-01 15:15:00+03
21449	PG0257	2017-08-21 14:15:00+03	2017-08-21 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21450	PG0257	2017-09-08 14:15:00+03	2017-09-08 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21451	PG0257	2017-07-31 14:15:00+03	2017-07-31 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-31 14:18:00+03	2017-07-31 15:12:00+03
21452	PG0257	2017-08-10 14:15:00+03	2017-08-10 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-10 14:19:00+03	2017-08-10 15:14:00+03
21453	PG0257	2017-08-07 14:15:00+03	2017-08-07 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-07 14:19:00+03	2017-08-07 15:14:00+03
21454	PG0257	2017-08-20 14:15:00+03	2017-08-20 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21455	PG0257	2017-07-28 14:15:00+03	2017-07-28 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-28 14:16:00+03	2017-07-28 15:11:00+03
21456	PG0257	2017-08-24 14:15:00+03	2017-08-24 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21457	PG0257	2017-07-30 14:15:00+03	2017-07-30 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-30 14:17:00+03	2017-07-30 15:11:00+03
21458	PG0257	2017-07-19 14:15:00+03	2017-07-19 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-19 14:18:00+03	2017-07-19 15:14:00+03
21459	PG0257	2017-07-23 14:15:00+03	2017-07-23 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-23 14:18:00+03	2017-07-23 15:12:00+03
21460	PG0257	2017-08-06 14:15:00+03	2017-08-06 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-06 14:19:00+03	2017-08-06 15:14:00+03
21461	PG0257	2017-07-25 14:15:00+03	2017-07-25 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-25 14:17:00+03	2017-07-25 15:13:00+03
21462	PG0257	2017-08-12 14:15:00+03	2017-08-12 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-12 14:21:00+03	2017-08-12 15:15:00+03
21463	PG0257	2017-08-15 14:15:00+03	2017-08-15 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-15 14:17:00+03	2017-08-15 15:12:00+03
21464	PG0257	2017-08-14 14:15:00+03	2017-08-14 15:10:00+03	NNM	ARH	Arrived	CR2	2017-08-14 14:17:00+03	2017-08-14 15:12:00+03
21465	PG0257	2017-08-29 14:15:00+03	2017-08-29 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21466	PG0257	2017-09-05 14:15:00+03	2017-09-05 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21467	PG0257	2017-09-01 14:15:00+03	2017-09-01 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21468	PG0257	2017-09-10 14:15:00+03	2017-09-10 15:10:00+03	NNM	ARH	Scheduled	CR2	\N	\N
21469	PG0257	2017-07-18 14:15:00+03	2017-07-18 15:10:00+03	NNM	ARH	Arrived	CR2	2017-07-18 14:17:00+03	2017-07-18 15:11:00+03
21470	PG0105	2017-09-13 13:15:00+03	2017-09-13 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21471	PG0104	2017-08-10 14:00:00+03	2017-08-10 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-10 14:02:00+03	2017-08-10 17:10:00+03
21472	PG0104	2017-07-18 14:00:00+03	2017-07-18 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-18 14:03:00+03	2017-07-18 17:14:00+03
21473	PG0105	2017-07-18 13:15:00+03	2017-07-18 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-18 13:19:00+03	2017-07-18 16:28:00+03
21474	PG0104	2017-08-13 14:00:00+03	2017-08-13 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-13 14:04:00+03	2017-08-13 17:11:00+03
21475	PG0105	2017-08-10 13:15:00+03	2017-08-10 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-10 13:17:00+03	2017-08-10 16:28:00+03
21476	PG0104	2017-08-06 14:00:00+03	2017-08-06 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-06 14:09:00+03	2017-08-06 17:19:00+03
21477	PG0105	2017-08-06 13:15:00+03	2017-08-06 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-06 13:18:00+03	2017-08-06 16:28:00+03
21478	PG0105	2017-08-13 13:15:00+03	2017-08-13 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-13 13:15:00+03	2017-08-13 16:24:00+03
21479	PG0104	2017-08-02 14:00:00+03	2017-08-02 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-02 14:03:00+03	2017-08-02 17:10:00+03
21480	PG0105	2017-08-02 13:15:00+03	2017-08-02 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-02 13:20:00+03	2017-08-02 16:30:00+03
21481	PG0104	2017-08-20 14:00:00+03	2017-08-20 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21482	PG0105	2017-08-20 13:15:00+03	2017-08-20 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21483	PG0104	2017-08-25 14:00:00+03	2017-08-25 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21484	PG0105	2017-09-04 13:15:00+03	2017-09-04 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21485	PG0104	2017-09-04 14:00:00+03	2017-09-04 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21486	PG0104	2017-08-11 14:00:00+03	2017-08-11 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-11 14:02:00+03	2017-08-11 17:07:00+03
21487	PG0105	2017-08-18 13:15:00+03	2017-08-18 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21488	PG0104	2017-09-14 14:00:00+03	2017-09-14 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21489	PG0104	2017-08-18 14:00:00+03	2017-08-18 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21490	PG0105	2017-08-12 13:15:00+03	2017-08-12 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-12 13:17:00+03	2017-08-12 16:26:00+03
21491	PG0105	2017-08-01 13:15:00+03	2017-08-01 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-01 13:21:00+03	2017-08-01 16:33:00+03
21492	PG0104	2017-08-12 14:00:00+03	2017-08-12 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-12 14:02:00+03	2017-08-12 17:12:00+03
21493	PG0104	2017-08-01 14:00:00+03	2017-08-01 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-01 14:02:00+03	2017-08-01 17:11:00+03
21494	PG0105	2017-08-25 13:15:00+03	2017-08-25 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21495	PG0105	2017-08-05 13:15:00+03	2017-08-05 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-05 13:19:00+03	2017-08-05 16:31:00+03
21496	PG0104	2017-08-05 14:00:00+03	2017-08-05 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-05 14:05:00+03	2017-08-05 17:17:00+03
21497	PG0104	2017-09-13 14:00:00+03	2017-09-13 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21498	PG0104	2017-07-23 14:00:00+03	2017-07-23 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-23 14:03:00+03	2017-07-23 17:11:00+03
21499	PG0105	2017-09-06 13:15:00+03	2017-09-06 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21500	PG0104	2017-09-06 14:00:00+03	2017-09-06 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21501	PG0105	2017-07-25 13:15:00+03	2017-07-25 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-25 13:21:00+03	2017-07-25 16:32:00+03
21502	PG0105	2017-07-23 13:15:00+03	2017-07-23 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-23 13:20:00+03	2017-07-23 16:30:00+03
21503	PG0104	2017-08-28 14:00:00+03	2017-08-28 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21504	PG0104	2017-07-24 14:00:00+03	2017-07-24 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-24 14:03:00+03	2017-07-24 17:10:00+03
21505	PG0105	2017-08-28 13:15:00+03	2017-08-28 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21506	PG0105	2017-07-24 13:15:00+03	2017-07-24 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-24 13:17:00+03	2017-07-24 16:27:00+03
21507	PG0104	2017-09-12 14:00:00+03	2017-09-12 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21508	PG0105	2017-07-17 13:15:00+03	2017-07-17 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-17 13:16:00+03	2017-07-17 16:27:00+03
21509	PG0104	2017-07-17 14:00:00+03	2017-07-17 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-17 14:00:00+03	2017-07-17 17:12:00+03
21510	PG0104	2017-09-09 14:00:00+03	2017-09-09 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21511	PG0105	2017-09-12 13:15:00+03	2017-09-12 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21512	PG0104	2017-07-27 14:00:00+03	2017-07-27 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-27 14:04:00+03	2017-07-27 17:14:00+03
21513	PG0105	2017-08-16 13:15:00+03	2017-08-16 16:25:00+03	KGP	SVX	On Time	CN1	\N	\N
21514	PG0104	2017-08-16 14:00:00+03	2017-08-16 17:10:00+03	KGP	SVX	On Time	CN1	\N	\N
21515	PG0104	2017-08-09 14:00:00+03	2017-08-09 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-09 14:03:00+03	2017-08-09 17:12:00+03
21516	PG0104	2017-08-29 14:00:00+03	2017-08-29 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21517	PG0105	2017-08-29 13:15:00+03	2017-08-29 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21518	PG0105	2017-07-26 13:15:00+03	2017-07-26 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-26 13:17:00+03	2017-07-26 16:26:00+03
21519	PG0104	2017-07-26 14:00:00+03	2017-07-26 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-26 14:03:00+03	2017-07-26 17:13:00+03
21520	PG0105	2017-08-24 13:15:00+03	2017-08-24 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21521	PG0104	2017-08-24 14:00:00+03	2017-08-24 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21522	PG0104	2017-08-07 14:00:00+03	2017-08-07 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-07 14:00:00+03	2017-08-07 17:10:00+03
21523	PG0105	2017-08-07 13:15:00+03	2017-08-07 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-07 13:17:00+03	2017-08-07 16:31:00+03
21524	PG0104	2017-08-17 14:00:00+03	2017-08-17 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21525	PG0105	2017-08-17 13:15:00+03	2017-08-17 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21526	PG0104	2017-08-30 14:00:00+03	2017-08-30 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21527	PG0104	2017-09-11 14:00:00+03	2017-09-11 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21528	PG0105	2017-08-30 13:15:00+03	2017-08-30 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21529	PG0105	2017-07-27 13:15:00+03	2017-07-27 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-27 13:22:00+03	2017-07-27 16:33:00+03
21530	PG0105	2017-07-28 13:15:00+03	2017-07-28 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-28 16:27:00+03	2017-07-28 19:35:00+03
21531	PG0105	2017-08-23 13:15:00+03	2017-08-23 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21532	PG0104	2017-08-23 14:00:00+03	2017-08-23 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21533	PG0104	2017-09-07 14:00:00+03	2017-09-07 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21534	PG0104	2017-07-28 14:00:00+03	2017-07-28 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-28 14:05:00+03	2017-07-28 17:15:00+03
21535	PG0105	2017-09-07 13:15:00+03	2017-09-07 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21536	PG0105	2017-08-14 13:15:00+03	2017-08-14 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-14 13:18:00+03	2017-08-14 16:26:00+03
21537	PG0104	2017-07-21 14:00:00+03	2017-07-21 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-21 14:05:00+03	2017-07-21 17:15:00+03
21538	PG0105	2017-07-21 13:15:00+03	2017-07-21 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-21 13:17:00+03	2017-07-21 16:29:00+03
21539	PG0105	2017-09-14 13:15:00+03	2017-09-14 16:25:00+03	KGP	SVX	Cancelled	CN1	\N	\N
21540	PG0105	2017-09-11 13:15:00+03	2017-09-11 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21541	PG0104	2017-08-14 14:00:00+03	2017-08-14 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-14 14:04:00+03	2017-08-14 17:11:00+03
21542	PG0104	2017-09-05 14:00:00+03	2017-09-05 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21543	PG0105	2017-09-05 13:15:00+03	2017-09-05 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21544	PG0105	2017-09-01 13:15:00+03	2017-09-01 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21545	PG0104	2017-07-29 14:00:00+03	2017-07-29 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-29 14:06:00+03	2017-07-29 17:13:00+03
21546	PG0105	2017-08-09 13:15:00+03	2017-08-09 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-09 13:18:00+03	2017-08-09 16:30:00+03
21547	PG0105	2017-07-29 13:15:00+03	2017-07-29 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-29 16:07:00+03	2017-07-29 19:16:00+03
21548	PG0105	2017-07-16 13:15:00+03	2017-07-16 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-16 13:17:00+03	2017-07-16 16:28:00+03
21549	PG0104	2017-08-26 14:00:00+03	2017-08-26 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21550	PG0105	2017-09-02 13:15:00+03	2017-09-02 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21551	PG0105	2017-07-19 13:15:00+03	2017-07-19 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-19 13:19:00+03	2017-07-19 16:29:00+03
21552	PG0104	2017-09-02 14:00:00+03	2017-09-02 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21553	PG0105	2017-07-31 13:15:00+03	2017-07-31 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-31 17:09:00+03	2017-07-31 20:18:00+03
21554	PG0104	2017-07-31 14:00:00+03	2017-07-31 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-31 14:03:00+03	2017-07-31 17:13:00+03
21555	PG0104	2017-07-19 14:00:00+03	2017-07-19 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-19 14:04:00+03	2017-07-19 17:14:00+03
21556	PG0104	2017-08-21 14:00:00+03	2017-08-21 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21557	PG0105	2017-08-21 13:15:00+03	2017-08-21 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21558	PG0105	2017-07-30 13:15:00+03	2017-07-30 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-30 13:18:00+03	2017-07-30 16:27:00+03
21559	PG0104	2017-08-08 14:00:00+03	2017-08-08 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-08 14:04:00+03	2017-08-08 17:15:00+03
21560	PG0105	2017-08-08 13:15:00+03	2017-08-08 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-08 13:20:00+03	2017-08-08 16:32:00+03
21561	PG0105	2017-08-04 13:15:00+03	2017-08-04 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-04 13:21:00+03	2017-08-04 16:28:00+03
21562	PG0104	2017-08-19 14:00:00+03	2017-08-19 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21563	PG0105	2017-08-19 13:15:00+03	2017-08-19 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21564	PG0104	2017-08-04 14:00:00+03	2017-08-04 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-04 14:03:00+03	2017-08-04 17:16:00+03
21565	PG0104	2017-08-31 14:00:00+03	2017-08-31 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21566	PG0104	2017-07-30 14:00:00+03	2017-07-30 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-30 14:02:00+03	2017-07-30 17:11:00+03
21567	PG0105	2017-09-03 13:15:00+03	2017-09-03 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21568	PG0104	2017-09-03 14:00:00+03	2017-09-03 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21569	PG0104	2017-08-15 14:00:00+03	2017-08-15 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-15 14:05:00+03	2017-08-15 17:16:00+03
21570	PG0105	2017-08-15 13:15:00+03	2017-08-15 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-15 13:23:00+03	2017-08-15 16:31:00+03
21571	PG0104	2017-08-22 14:00:00+03	2017-08-22 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21572	PG0105	2017-08-22 13:15:00+03	2017-08-22 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21573	PG0104	2017-09-10 14:00:00+03	2017-09-10 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21574	PG0105	2017-09-10 13:15:00+03	2017-09-10 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21575	PG0104	2017-09-01 14:00:00+03	2017-09-01 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21576	PG0104	2017-07-16 14:00:00+03	2017-07-16 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-16 14:04:00+03	2017-07-16 17:16:00+03
21577	PG0105	2017-09-08 13:15:00+03	2017-09-08 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21578	PG0104	2017-09-08 14:00:00+03	2017-09-08 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21579	PG0105	2017-09-09 13:15:00+03	2017-09-09 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21580	PG0104	2017-08-03 14:00:00+03	2017-08-03 17:10:00+03	KGP	SVX	Arrived	CN1	2017-08-03 14:05:00+03	2017-08-03 17:17:00+03
21581	PG0105	2017-08-26 13:15:00+03	2017-08-26 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21582	PG0105	2017-08-11 13:15:00+03	2017-08-11 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-11 13:17:00+03	2017-08-11 16:24:00+03
21583	PG0105	2017-08-03 13:15:00+03	2017-08-03 16:25:00+03	KGP	SVX	Arrived	CN1	2017-08-03 13:18:00+03	2017-08-03 16:26:00+03
21584	PG0105	2017-07-22 13:15:00+03	2017-07-22 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-22 13:17:00+03	2017-07-22 16:28:00+03
21585	PG0105	2017-07-20 13:15:00+03	2017-07-20 16:25:00+03	KGP	SVX	Arrived	CN1	2017-07-20 13:17:00+03	2017-07-20 16:26:00+03
21586	PG0104	2017-07-22 14:00:00+03	2017-07-22 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-22 14:04:00+03	2017-07-22 17:17:00+03
21587	PG0105	2017-08-31 13:15:00+03	2017-08-31 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21588	PG0104	2017-07-20 14:00:00+03	2017-07-20 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-20 14:04:00+03	2017-07-20 17:13:00+03
21589	PG0104	2017-08-27 14:00:00+03	2017-08-27 17:10:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21590	PG0105	2017-08-27 13:15:00+03	2017-08-27 16:25:00+03	KGP	SVX	Scheduled	CN1	\N	\N
21591	PG0104	2017-07-25 14:00:00+03	2017-07-25 17:10:00+03	KGP	SVX	Arrived	CN1	2017-07-25 14:04:00+03	2017-07-25 17:14:00+03
21592	PG0634	2017-08-25 15:25:00+03	2017-08-25 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21593	PG0634	2017-08-24 15:25:00+03	2017-08-24 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21594	PG0634	2017-08-23 15:25:00+03	2017-08-23 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21595	PG0634	2017-08-05 15:25:00+03	2017-08-05 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-05 15:25:00+03	2017-08-05 16:51:00+03
21596	PG0634	2017-08-15 15:25:00+03	2017-08-15 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-15 15:30:00+03	2017-08-15 16:55:00+03
21597	PG0634	2017-08-13 15:25:00+03	2017-08-13 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-13 15:27:00+03	2017-08-13 16:52:00+03
21598	PG0634	2017-07-25 15:25:00+03	2017-07-25 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-25 15:26:00+03	2017-07-25 16:50:00+03
21599	PG0634	2017-09-13 15:25:00+03	2017-09-13 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21600	PG0634	2017-07-18 15:25:00+03	2017-07-18 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-18 15:29:00+03	2017-07-18 16:54:00+03
21601	PG0634	2017-07-22 15:25:00+03	2017-07-22 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-22 15:27:00+03	2017-07-22 16:53:00+03
21602	PG0634	2017-08-31 15:25:00+03	2017-08-31 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21603	PG0634	2017-08-26 15:25:00+03	2017-08-26 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21604	PG0634	2017-08-07 15:25:00+03	2017-08-07 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-07 15:29:00+03	2017-08-07 16:53:00+03
21605	PG0634	2017-07-17 15:25:00+03	2017-07-17 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-17 15:29:00+03	2017-07-17 16:55:00+03
21606	PG0634	2017-08-06 15:25:00+03	2017-08-06 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-06 15:26:00+03	2017-08-06 16:49:00+03
21607	PG0634	2017-07-23 15:25:00+03	2017-07-23 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-23 15:27:00+03	2017-07-23 16:52:00+03
21608	PG0634	2017-07-26 15:25:00+03	2017-07-26 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-26 15:28:00+03	2017-07-26 16:52:00+03
21609	PG0634	2017-09-05 15:25:00+03	2017-09-05 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21610	PG0634	2017-08-09 15:25:00+03	2017-08-09 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-09 15:27:00+03	2017-08-09 16:54:00+03
21611	PG0634	2017-08-10 15:25:00+03	2017-08-10 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-10 15:28:00+03	2017-08-10 16:53:00+03
21612	PG0634	2017-08-29 15:25:00+03	2017-08-29 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21613	PG0634	2017-09-11 15:25:00+03	2017-09-11 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21614	PG0634	2017-09-02 15:25:00+03	2017-09-02 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21615	PG0634	2017-08-01 15:25:00+03	2017-08-01 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-01 15:31:00+03	2017-08-01 16:57:00+03
21616	PG0634	2017-07-21 15:25:00+03	2017-07-21 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-21 15:29:00+03	2017-07-21 16:53:00+03
21617	PG0634	2017-08-17 15:25:00+03	2017-08-17 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21618	PG0634	2017-08-11 15:25:00+03	2017-08-11 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-11 15:29:00+03	2017-08-11 16:54:00+03
21619	PG0634	2017-08-21 15:25:00+03	2017-08-21 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21620	PG0634	2017-09-08 15:25:00+03	2017-09-08 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21621	PG0634	2017-08-20 15:25:00+03	2017-08-20 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21622	PG0634	2017-09-10 15:25:00+03	2017-09-10 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21623	PG0634	2017-08-18 15:25:00+03	2017-08-18 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21624	PG0634	2017-09-09 15:25:00+03	2017-09-09 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21625	PG0634	2017-08-08 15:25:00+03	2017-08-08 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-08 15:31:00+03	2017-08-08 16:57:00+03
21626	PG0634	2017-08-04 15:25:00+03	2017-08-04 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-04 15:28:00+03	2017-08-04 16:52:00+03
21627	PG0634	2017-07-19 15:25:00+03	2017-07-19 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-19 15:28:00+03	2017-07-19 16:52:00+03
21628	PG0634	2017-07-20 15:25:00+03	2017-07-20 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-20 15:26:00+03	2017-07-20 16:51:00+03
21629	PG0634	2017-09-14 15:25:00+03	2017-09-14 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21630	PG0634	2017-09-06 15:25:00+03	2017-09-06 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21631	PG0634	2017-08-28 15:25:00+03	2017-08-28 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21632	PG0634	2017-07-31 15:25:00+03	2017-07-31 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-31 15:27:00+03	2017-07-31 16:52:00+03
21633	PG0634	2017-08-19 15:25:00+03	2017-08-19 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21634	PG0634	2017-08-30 15:25:00+03	2017-08-30 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21635	PG0634	2017-07-28 15:25:00+03	2017-07-28 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-28 15:29:00+03	2017-07-28 16:55:00+03
21636	PG0634	2017-09-03 15:25:00+03	2017-09-03 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21637	PG0634	2017-09-01 15:25:00+03	2017-09-01 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21638	PG0634	2017-09-07 15:25:00+03	2017-09-07 16:50:00+03	KGP	NUX	Cancelled	CN1	\N	\N
21639	PG0634	2017-08-27 15:25:00+03	2017-08-27 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21640	PG0634	2017-09-12 15:25:00+03	2017-09-12 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21641	PG0634	2017-08-14 15:25:00+03	2017-08-14 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-14 15:28:00+03	2017-08-14 16:52:00+03
21642	PG0634	2017-07-16 15:25:00+03	2017-07-16 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-16 15:27:00+03	2017-07-16 16:52:00+03
21643	PG0634	2017-08-16 15:25:00+03	2017-08-16 16:50:00+03	KGP	NUX	On Time	CN1	\N	\N
21644	PG0634	2017-08-03 15:25:00+03	2017-08-03 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-03 15:30:00+03	2017-08-03 16:55:00+03
21645	PG0634	2017-07-29 15:25:00+03	2017-07-29 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-29 15:29:00+03	2017-07-29 16:55:00+03
21646	PG0634	2017-07-30 15:25:00+03	2017-07-30 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-30 15:28:00+03	2017-07-30 16:52:00+03
21647	PG0634	2017-07-24 15:25:00+03	2017-07-24 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-24 15:28:00+03	2017-07-24 16:53:00+03
21648	PG0634	2017-09-04 15:25:00+03	2017-09-04 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21649	PG0634	2017-08-02 15:25:00+03	2017-08-02 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-02 15:29:00+03	2017-08-02 16:54:00+03
21650	PG0634	2017-08-12 15:25:00+03	2017-08-12 16:50:00+03	KGP	NUX	Arrived	CN1	2017-08-12 15:27:00+03	2017-08-12 16:53:00+03
21651	PG0634	2017-07-27 15:25:00+03	2017-07-27 16:50:00+03	KGP	NUX	Arrived	CN1	2017-07-27 18:08:00+03	2017-07-27 19:35:00+03
21652	PG0634	2017-08-22 15:25:00+03	2017-08-22 16:50:00+03	KGP	NUX	Scheduled	CN1	\N	\N
21653	PG0325	2017-08-14 15:15:00+03	2017-08-14 19:30:00+03	KGP	AER	Arrived	733	2017-08-14 15:18:00+03	2017-08-14 19:33:00+03
21654	PG0325	2017-07-17 15:15:00+03	2017-07-17 19:30:00+03	KGP	AER	Arrived	733	2017-07-17 15:18:00+03	2017-07-17 19:35:00+03
21655	PG0325	2017-07-31 15:15:00+03	2017-07-31 19:30:00+03	KGP	AER	Arrived	733	2017-07-31 15:17:00+03	2017-07-31 19:34:00+03
21656	PG0325	2017-08-07 15:15:00+03	2017-08-07 19:30:00+03	KGP	AER	Arrived	733	2017-08-07 15:18:00+03	2017-08-07 19:30:00+03
21657	PG0325	2017-09-11 15:15:00+03	2017-09-11 19:30:00+03	KGP	AER	Scheduled	733	\N	\N
21658	PG0325	2017-07-24 15:15:00+03	2017-07-24 19:30:00+03	KGP	AER	Arrived	733	2017-07-24 15:20:00+03	2017-07-24 19:35:00+03
21659	PG0325	2017-08-28 15:15:00+03	2017-08-28 19:30:00+03	KGP	AER	Scheduled	733	\N	\N
21660	PG0325	2017-08-21 15:15:00+03	2017-08-21 19:30:00+03	KGP	AER	Scheduled	733	\N	\N
21661	PG0325	2017-09-04 15:15:00+03	2017-09-04 19:30:00+03	KGP	AER	Scheduled	733	\N	\N
21662	PG0096	2017-07-27 16:35:00+03	2017-07-27 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-27 16:39:00+03	2017-07-27 18:53:00+03
21663	PG0096	2017-07-26 16:35:00+03	2017-07-26 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-26 16:39:00+03	2017-07-26 18:57:00+03
21664	PG0096	2017-08-26 16:35:00+03	2017-08-26 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21665	PG0096	2017-08-30 16:35:00+03	2017-08-30 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21666	PG0096	2017-08-17 16:35:00+03	2017-08-17 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21667	PG0096	2017-08-07 16:35:00+03	2017-08-07 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-07 16:40:00+03	2017-08-07 18:54:00+03
21668	PG0096	2017-08-24 16:35:00+03	2017-08-24 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21669	PG0096	2017-09-11 16:35:00+03	2017-09-11 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21670	PG0096	2017-09-07 16:35:00+03	2017-09-07 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21671	PG0096	2017-08-23 16:35:00+03	2017-08-23 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21672	PG0096	2017-09-04 16:35:00+03	2017-09-04 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21673	PG0096	2017-07-21 16:35:00+03	2017-07-21 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-21 16:39:00+03	2017-07-21 18:55:00+03
21674	PG0096	2017-08-20 16:35:00+03	2017-08-20 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21675	PG0096	2017-09-14 16:35:00+03	2017-09-14 18:50:00+03	URJ	DME	Cancelled	SU9	\N	\N
21676	PG0096	2017-07-30 16:35:00+03	2017-07-30 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-30 16:37:00+03	2017-07-30 18:50:00+03
21677	PG0096	2017-09-05 16:35:00+03	2017-09-05 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21678	PG0096	2017-07-28 16:35:00+03	2017-07-28 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-28 16:36:00+03	2017-07-28 18:51:00+03
21679	PG0096	2017-08-27 16:35:00+03	2017-08-27 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21680	PG0096	2017-07-29 16:35:00+03	2017-07-29 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-29 19:55:00+03	2017-07-29 22:11:00+03
21681	PG0096	2017-07-20 16:35:00+03	2017-07-20 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-20 16:38:00+03	2017-07-20 18:54:00+03
21682	PG0096	2017-08-21 16:35:00+03	2017-08-21 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21683	PG0096	2017-09-08 16:35:00+03	2017-09-08 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21684	PG0096	2017-08-03 16:35:00+03	2017-08-03 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-03 20:53:00+03	2017-08-03 23:08:00+03
21685	PG0096	2017-08-13 16:35:00+03	2017-08-13 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-13 16:40:00+03	2017-08-13 18:54:00+03
21686	PG0096	2017-07-31 16:35:00+03	2017-07-31 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-31 16:37:00+03	2017-07-31 18:54:00+03
21687	PG0096	2017-08-09 16:35:00+03	2017-08-09 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-09 16:40:00+03	2017-08-09 18:56:00+03
21688	PG0096	2017-07-22 16:35:00+03	2017-07-22 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-22 16:39:00+03	2017-07-22 18:53:00+03
21689	PG0096	2017-07-19 16:35:00+03	2017-07-19 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-19 16:35:00+03	2017-07-19 18:51:00+03
21690	PG0096	2017-08-19 16:35:00+03	2017-08-19 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21691	PG0096	2017-08-08 16:35:00+03	2017-08-08 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-08 16:39:00+03	2017-08-08 18:55:00+03
21692	PG0096	2017-09-09 16:35:00+03	2017-09-09 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21693	PG0096	2017-09-02 16:35:00+03	2017-09-02 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21694	PG0096	2017-08-11 16:35:00+03	2017-08-11 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-11 16:37:00+03	2017-08-11 18:52:00+03
21695	PG0096	2017-08-10 16:35:00+03	2017-08-10 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-10 16:36:00+03	2017-08-10 18:49:00+03
21696	PG0096	2017-08-14 16:35:00+03	2017-08-14 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-14 16:42:00+03	2017-08-14 18:55:00+03
21697	PG0096	2017-08-02 16:35:00+03	2017-08-02 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-02 16:40:00+03	2017-08-02 18:57:00+03
21698	PG0096	2017-08-04 16:35:00+03	2017-08-04 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-04 16:38:00+03	2017-08-04 18:53:00+03
21699	PG0096	2017-08-01 16:35:00+03	2017-08-01 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-01 16:37:00+03	2017-08-01 18:50:00+03
21700	PG0096	2017-09-12 16:35:00+03	2017-09-12 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21701	PG0096	2017-08-28 16:35:00+03	2017-08-28 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21702	PG0096	2017-08-22 16:35:00+03	2017-08-22 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21703	PG0096	2017-08-05 16:35:00+03	2017-08-05 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-05 16:36:00+03	2017-08-05 18:52:00+03
21704	PG0096	2017-07-23 16:35:00+03	2017-07-23 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-23 16:35:00+03	2017-07-23 18:50:00+03
21705	PG0096	2017-07-25 16:35:00+03	2017-07-25 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-25 16:36:00+03	2017-07-25 18:50:00+03
21706	PG0096	2017-09-13 16:35:00+03	2017-09-13 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21707	PG0096	2017-07-16 16:35:00+03	2017-07-16 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-16 16:40:00+03	2017-07-16 18:54:00+03
21708	PG0096	2017-08-31 16:35:00+03	2017-08-31 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21709	PG0096	2017-07-24 16:35:00+03	2017-07-24 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-24 16:39:00+03	2017-07-24 18:55:00+03
21710	PG0096	2017-09-10 16:35:00+03	2017-09-10 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21711	PG0096	2017-08-15 16:35:00+03	2017-08-15 18:50:00+03	URJ	DME	Departed	SU9	2017-08-15 16:40:00+03	\N
21712	PG0096	2017-09-06 16:35:00+03	2017-09-06 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21713	PG0096	2017-09-03 16:35:00+03	2017-09-03 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21714	PG0096	2017-07-17 16:35:00+03	2017-07-17 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-17 16:37:00+03	2017-07-17 18:52:00+03
21715	PG0096	2017-08-12 16:35:00+03	2017-08-12 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-12 19:37:00+03	2017-08-12 21:52:00+03
21716	PG0096	2017-09-01 16:35:00+03	2017-09-01 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21717	PG0096	2017-08-06 16:35:00+03	2017-08-06 18:50:00+03	URJ	DME	Arrived	SU9	2017-08-06 16:37:00+03	2017-08-06 18:50:00+03
21718	PG0096	2017-07-18 16:35:00+03	2017-07-18 18:50:00+03	URJ	DME	Arrived	SU9	2017-07-18 16:38:00+03	2017-07-18 18:53:00+03
21719	PG0096	2017-08-16 16:35:00+03	2017-08-16 18:50:00+03	URJ	DME	On Time	SU9	\N	\N
21720	PG0096	2017-08-18 16:35:00+03	2017-08-18 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21721	PG0096	2017-08-29 16:35:00+03	2017-08-29 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21722	PG0096	2017-08-25 16:35:00+03	2017-08-25 18:50:00+03	URJ	DME	Scheduled	SU9	\N	\N
21723	PG0355	2017-07-28 11:55:00+03	2017-07-28 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-28 11:59:00+03	2017-07-28 12:24:00+03
21724	PG0355	2017-08-10 11:55:00+03	2017-08-10 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-10 11:59:00+03	2017-08-10 12:24:00+03
21725	PG0355	2017-08-17 11:55:00+03	2017-08-17 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21726	PG0355	2017-07-25 11:55:00+03	2017-07-25 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-25 11:59:00+03	2017-07-25 12:24:00+03
21727	PG0355	2017-08-14 11:55:00+03	2017-08-14 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-14 11:58:00+03	2017-08-14 12:23:00+03
21728	PG0355	2017-09-11 11:55:00+03	2017-09-11 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21729	PG0355	2017-07-21 11:55:00+03	2017-07-21 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-21 11:57:00+03	2017-07-21 12:22:00+03
21730	PG0355	2017-07-30 11:55:00+03	2017-07-30 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-30 11:57:00+03	2017-07-30 12:22:00+03
21731	PG0355	2017-09-14 11:55:00+03	2017-09-14 12:20:00+03	URJ	TJM	Cancelled	SU9	\N	\N
21732	PG0355	2017-07-16 11:55:00+03	2017-07-16 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-16 11:58:00+03	2017-07-16 12:23:00+03
21733	PG0355	2017-08-22 11:55:00+03	2017-08-22 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21734	PG0355	2017-09-02 11:55:00+03	2017-09-02 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21735	PG0355	2017-08-09 11:55:00+03	2017-08-09 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-09 11:59:00+03	2017-08-09 12:24:00+03
21736	PG0355	2017-07-24 11:55:00+03	2017-07-24 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-24 11:55:00+03	2017-07-24 12:20:00+03
21737	PG0355	2017-08-20 11:55:00+03	2017-08-20 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21738	PG0355	2017-08-02 11:55:00+03	2017-08-02 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-02 11:58:00+03	2017-08-02 12:23:00+03
21739	PG0355	2017-08-26 11:55:00+03	2017-08-26 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21740	PG0355	2017-08-05 11:55:00+03	2017-08-05 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-05 11:56:00+03	2017-08-05 12:21:00+03
21741	PG0355	2017-07-29 11:55:00+03	2017-07-29 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-29 11:58:00+03	2017-07-29 12:23:00+03
21742	PG0355	2017-09-10 11:55:00+03	2017-09-10 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21743	PG0355	2017-07-26 11:55:00+03	2017-07-26 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-26 11:57:00+03	2017-07-26 12:22:00+03
21744	PG0355	2017-09-12 11:55:00+03	2017-09-12 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21745	PG0355	2017-08-13 11:55:00+03	2017-08-13 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-13 12:01:00+03	2017-08-13 12:26:00+03
21746	PG0355	2017-07-23 11:55:00+03	2017-07-23 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-23 11:56:00+03	2017-07-23 12:22:00+03
21747	PG0355	2017-08-04 11:55:00+03	2017-08-04 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-04 11:58:00+03	2017-08-04 12:23:00+03
21748	PG0355	2017-08-21 11:55:00+03	2017-08-21 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21749	PG0355	2017-07-17 11:55:00+03	2017-07-17 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-17 11:59:00+03	2017-07-17 12:24:00+03
21750	PG0355	2017-08-06 11:55:00+03	2017-08-06 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-06 12:00:00+03	2017-08-06 12:25:00+03
21751	PG0355	2017-08-08 11:55:00+03	2017-08-08 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-08 11:57:00+03	2017-08-08 12:22:00+03
21752	PG0355	2017-07-31 11:55:00+03	2017-07-31 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-31 11:56:00+03	2017-07-31 12:21:00+03
21753	PG0355	2017-08-30 11:55:00+03	2017-08-30 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21754	PG0355	2017-08-03 11:55:00+03	2017-08-03 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-03 11:57:00+03	2017-08-03 12:22:00+03
21755	PG0355	2017-08-29 11:55:00+03	2017-08-29 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21756	PG0355	2017-09-13 11:55:00+03	2017-09-13 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21757	PG0355	2017-07-18 11:55:00+03	2017-07-18 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-18 11:57:00+03	2017-07-18 12:22:00+03
21758	PG0355	2017-07-19 11:55:00+03	2017-07-19 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-19 12:00:00+03	2017-07-19 12:25:00+03
21759	PG0355	2017-08-01 11:55:00+03	2017-08-01 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-01 11:57:00+03	2017-08-01 12:22:00+03
21760	PG0355	2017-09-05 11:55:00+03	2017-09-05 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21761	PG0355	2017-09-08 11:55:00+03	2017-09-08 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21762	PG0355	2017-08-15 11:55:00+03	2017-08-15 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-15 12:00:00+03	2017-08-15 12:25:00+03
21763	PG0355	2017-09-06 11:55:00+03	2017-09-06 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21764	PG0355	2017-08-18 11:55:00+03	2017-08-18 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21765	PG0355	2017-08-11 11:55:00+03	2017-08-11 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-11 11:56:00+03	2017-08-11 12:21:00+03
21766	PG0355	2017-08-31 11:55:00+03	2017-08-31 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21767	PG0355	2017-08-16 11:55:00+03	2017-08-16 12:20:00+03	URJ	TJM	On Time	SU9	\N	\N
21768	PG0355	2017-09-01 11:55:00+03	2017-09-01 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21769	PG0355	2017-09-03 11:55:00+03	2017-09-03 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21770	PG0355	2017-09-07 11:55:00+03	2017-09-07 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21771	PG0355	2017-08-19 11:55:00+03	2017-08-19 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21772	PG0355	2017-07-27 11:55:00+03	2017-07-27 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-27 11:57:00+03	2017-07-27 12:22:00+03
21773	PG0355	2017-08-25 11:55:00+03	2017-08-25 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21774	PG0355	2017-07-22 11:55:00+03	2017-07-22 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-22 11:58:00+03	2017-07-22 12:23:00+03
21775	PG0355	2017-08-23 11:55:00+03	2017-08-23 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21776	PG0355	2017-08-12 11:55:00+03	2017-08-12 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-12 12:00:00+03	2017-08-12 12:25:00+03
21777	PG0355	2017-08-07 11:55:00+03	2017-08-07 12:20:00+03	URJ	TJM	Arrived	SU9	2017-08-07 12:01:00+03	2017-08-07 12:26:00+03
21778	PG0355	2017-07-20 11:55:00+03	2017-07-20 12:20:00+03	URJ	TJM	Arrived	SU9	2017-07-20 11:56:00+03	2017-07-20 12:21:00+03
21779	PG0355	2017-08-27 11:55:00+03	2017-08-27 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21780	PG0355	2017-08-24 11:55:00+03	2017-08-24 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21781	PG0355	2017-09-09 11:55:00+03	2017-09-09 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21782	PG0355	2017-09-04 11:55:00+03	2017-09-04 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21783	PG0355	2017-08-28 11:55:00+03	2017-08-28 12:20:00+03	URJ	TJM	Scheduled	SU9	\N	\N
21784	PG0340	2017-07-25 11:05:00+03	2017-07-25 16:30:00+03	PYJ	LED	Arrived	733	2017-07-25 11:08:00+03	2017-07-25 16:30:00+03
21785	PG0340	2017-07-18 11:05:00+03	2017-07-18 16:30:00+03	PYJ	LED	Arrived	733	2017-07-18 11:07:00+03	2017-07-18 16:31:00+03
21786	PG0340	2017-08-22 11:05:00+03	2017-08-22 16:30:00+03	PYJ	LED	Scheduled	733	\N	\N
21787	PG0340	2017-08-29 11:05:00+03	2017-08-29 16:30:00+03	PYJ	LED	Scheduled	733	\N	\N
21788	PG0340	2017-08-15 11:05:00+03	2017-08-15 16:30:00+03	PYJ	LED	Arrived	733	2017-08-15 11:10:00+03	2017-08-15 16:35:00+03
21789	PG0340	2017-09-05 11:05:00+03	2017-09-05 16:30:00+03	PYJ	LED	Scheduled	733	\N	\N
21790	PG0340	2017-08-01 11:05:00+03	2017-08-01 16:30:00+03	PYJ	LED	Arrived	733	2017-08-01 11:09:00+03	2017-08-01 16:35:00+03
21791	PG0340	2017-09-12 11:05:00+03	2017-09-12 16:30:00+03	PYJ	LED	Cancelled	733	\N	\N
21792	PG0340	2017-08-08 11:05:00+03	2017-08-08 16:30:00+03	PYJ	LED	Arrived	733	2017-08-08 11:08:00+03	2017-08-08 16:33:00+03
21793	PG0084	2017-07-17 09:05:00+03	2017-07-17 11:55:00+03	PYJ	OVB	Arrived	CR2	2017-07-17 09:09:00+03	2017-07-17 12:02:00+03
21794	PG0084	2017-08-14 09:05:00+03	2017-08-14 11:55:00+03	PYJ	OVB	Arrived	CR2	2017-08-14 09:09:00+03	2017-08-14 11:59:00+03
21795	PG0084	2017-07-31 09:05:00+03	2017-07-31 11:55:00+03	PYJ	OVB	Arrived	CR2	2017-07-31 09:08:00+03	2017-07-31 11:59:00+03
21796	PG0084	2017-09-04 09:05:00+03	2017-09-04 11:55:00+03	PYJ	OVB	Scheduled	CR2	\N	\N
21797	PG0084	2017-09-11 09:05:00+03	2017-09-11 11:55:00+03	PYJ	OVB	Cancelled	CR2	\N	\N
21798	PG0084	2017-08-07 09:05:00+03	2017-08-07 11:55:00+03	PYJ	OVB	Arrived	CR2	2017-08-07 09:06:00+03	2017-08-07 11:58:00+03
21799	PG0084	2017-08-21 09:05:00+03	2017-08-21 11:55:00+03	PYJ	OVB	Scheduled	CR2	\N	\N
21800	PG0084	2017-07-24 09:05:00+03	2017-07-24 11:55:00+03	PYJ	OVB	Arrived	CR2	2017-07-24 09:07:00+03	2017-07-24 11:57:00+03
21801	PG0084	2017-08-28 09:05:00+03	2017-08-28 11:55:00+03	PYJ	OVB	Scheduled	CR2	\N	\N
21802	PG0551	2017-07-16 09:10:00+03	2017-07-16 11:50:00+03	PYJ	KEJ	Arrived	CR2	2017-07-16 09:14:00+03	2017-07-16 11:53:00+03
21803	PG0551	2017-08-20 09:10:00+03	2017-08-20 11:50:00+03	PYJ	KEJ	Scheduled	CR2	\N	\N
21804	PG0551	2017-08-27 09:10:00+03	2017-08-27 11:50:00+03	PYJ	KEJ	Scheduled	CR2	\N	\N
21805	PG0551	2017-08-13 09:10:00+03	2017-08-13 11:50:00+03	PYJ	KEJ	Arrived	CR2	2017-08-13 09:11:00+03	2017-08-13 11:49:00+03
21806	PG0551	2017-07-23 09:10:00+03	2017-07-23 11:50:00+03	PYJ	KEJ	Arrived	CR2	2017-07-23 09:11:00+03	2017-07-23 11:50:00+03
21807	PG0551	2017-09-03 09:10:00+03	2017-09-03 11:50:00+03	PYJ	KEJ	Scheduled	CR2	\N	\N
21808	PG0551	2017-07-30 09:10:00+03	2017-07-30 11:50:00+03	PYJ	KEJ	Arrived	CR2	2017-07-30 12:14:00+03	2017-07-30 14:53:00+03
21809	PG0551	2017-08-06 09:10:00+03	2017-08-06 11:50:00+03	PYJ	KEJ	Arrived	CR2	2017-08-06 09:13:00+03	2017-08-06 11:53:00+03
21810	PG0551	2017-09-10 09:10:00+03	2017-09-10 11:50:00+03	PYJ	KEJ	Cancelled	CR2	\N	\N
21811	PG0316	2017-08-01 06:00:00+03	2017-08-01 14:15:00+03	DYR	DME	Arrived	319	2017-08-01 06:03:00+03	2017-08-01 14:19:00+03
21812	PG0316	2017-09-12 06:00:00+03	2017-09-12 14:15:00+03	DYR	DME	Cancelled	319	\N	\N
21813	PG0316	2017-08-15 06:00:00+03	2017-08-15 14:15:00+03	DYR	DME	Arrived	319	2017-08-15 06:01:00+03	2017-08-15 14:15:00+03
21814	PG0316	2017-08-08 06:00:00+03	2017-08-08 14:15:00+03	DYR	DME	Arrived	319	2017-08-08 06:02:00+03	2017-08-08 14:18:00+03
21815	PG0316	2017-08-22 06:00:00+03	2017-08-22 14:15:00+03	DYR	DME	Scheduled	319	\N	\N
21816	PG0316	2017-07-25 06:00:00+03	2017-07-25 14:15:00+03	DYR	DME	Arrived	319	2017-07-25 06:04:00+03	2017-07-25 14:16:00+03
21817	PG0316	2017-07-18 06:00:00+03	2017-07-18 14:15:00+03	DYR	DME	Arrived	319	2017-07-18 06:04:00+03	2017-07-18 14:23:00+03
21818	PG0316	2017-09-05 06:00:00+03	2017-09-05 14:15:00+03	DYR	DME	Scheduled	319	\N	\N
21819	PG0316	2017-08-29 06:00:00+03	2017-08-29 14:15:00+03	DYR	DME	Scheduled	319	\N	\N
21820	PG0451	2017-07-30 01:50:00+03	2017-07-30 10:05:00+03	DYR	VKO	Arrived	319	2017-07-30 05:00:00+03	2017-07-30 13:21:00+03
21821	PG0451	2017-07-23 01:50:00+03	2017-07-23 10:05:00+03	DYR	VKO	Arrived	319	2017-07-23 01:54:00+03	2017-07-23 10:05:00+03
21822	PG0451	2017-08-20 01:50:00+03	2017-08-20 10:05:00+03	DYR	VKO	Scheduled	319	\N	\N
21823	PG0451	2017-08-06 01:50:00+03	2017-08-06 10:05:00+03	DYR	VKO	Arrived	319	2017-08-06 01:51:00+03	2017-08-06 10:15:00+03
21824	PG0451	2017-09-03 01:50:00+03	2017-09-03 10:05:00+03	DYR	VKO	Scheduled	319	\N	\N
21825	PG0451	2017-08-13 01:50:00+03	2017-08-13 10:05:00+03	DYR	VKO	Arrived	319	2017-08-13 01:54:00+03	2017-08-13 10:03:00+03
21826	PG0451	2017-09-10 01:50:00+03	2017-09-10 10:05:00+03	DYR	VKO	Scheduled	319	\N	\N
21827	PG0451	2017-07-16 01:50:00+03	2017-07-16 10:05:00+03	DYR	VKO	Arrived	319	2017-07-16 01:54:00+03	2017-07-16 10:17:00+03
21828	PG0451	2017-08-27 01:50:00+03	2017-08-27 10:05:00+03	DYR	VKO	Scheduled	319	\N	\N
21829	PG0256	2017-09-07 03:45:00+03	2017-09-07 11:55:00+03	DYR	SVO	Scheduled	319	\N	\N
21830	PG0256	2017-07-20 03:45:00+03	2017-07-20 11:55:00+03	DYR	SVO	Arrived	319	2017-07-20 03:49:00+03	2017-07-20 11:59:00+03
21831	PG0256	2017-08-24 03:45:00+03	2017-08-24 11:55:00+03	DYR	SVO	Scheduled	319	\N	\N
21832	PG0256	2017-07-27 03:45:00+03	2017-07-27 11:55:00+03	DYR	SVO	Arrived	319	2017-07-27 03:49:00+03	2017-07-27 11:59:00+03
21833	PG0256	2017-08-17 03:45:00+03	2017-08-17 11:55:00+03	DYR	SVO	Scheduled	319	\N	\N
21834	PG0256	2017-08-10 03:45:00+03	2017-08-10 11:55:00+03	DYR	SVO	Arrived	319	2017-08-10 03:49:00+03	2017-08-10 12:07:00+03
21835	PG0256	2017-09-14 03:45:00+03	2017-09-14 11:55:00+03	DYR	SVO	Cancelled	319	\N	\N
21836	PG0256	2017-08-31 03:45:00+03	2017-08-31 11:55:00+03	DYR	SVO	Scheduled	319	\N	\N
21837	PG0256	2017-08-03 03:45:00+03	2017-08-03 11:55:00+03	DYR	SVO	Arrived	319	2017-08-03 03:49:00+03	2017-08-03 11:57:00+03
21838	PG0087	2017-08-30 02:00:00+03	2017-08-30 06:05:00+03	DYR	KHV	Scheduled	319	\N	\N
21839	PG0087	2017-07-19 02:00:00+03	2017-07-19 06:05:00+03	DYR	KHV	Arrived	319	2017-07-19 02:04:00+03	2017-07-19 06:12:00+03
21840	PG0087	2017-08-16 02:00:00+03	2017-08-16 06:05:00+03	DYR	KHV	On Time	319	\N	\N
21841	PG0087	2017-07-26 02:00:00+03	2017-07-26 06:05:00+03	DYR	KHV	Arrived	319	2017-07-26 02:04:00+03	2017-07-26 06:08:00+03
21842	PG0087	2017-08-23 02:00:00+03	2017-08-23 06:05:00+03	DYR	KHV	Scheduled	319	\N	\N
21843	PG0087	2017-08-02 02:00:00+03	2017-08-02 06:05:00+03	DYR	KHV	Arrived	319	2017-08-02 02:04:00+03	2017-08-02 06:13:00+03
21844	PG0087	2017-09-06 02:00:00+03	2017-09-06 06:05:00+03	DYR	KHV	Scheduled	319	\N	\N
21845	PG0087	2017-09-13 02:00:00+03	2017-09-13 06:05:00+03	DYR	KHV	Cancelled	319	\N	\N
21846	PG0087	2017-08-09 02:00:00+03	2017-08-09 06:05:00+03	DYR	KHV	Arrived	319	2017-08-09 02:03:00+03	2017-08-09 06:13:00+03
21847	PG0127	2017-08-23 11:45:00+03	2017-08-23 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21848	PG0127	2017-07-16 11:45:00+03	2017-07-16 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-16 11:48:00+03	2017-07-16 14:39:00+03
21849	PG0127	2017-07-17 11:45:00+03	2017-07-17 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-17 11:49:00+03	2017-07-17 14:37:00+03
21850	PG0127	2017-07-18 11:45:00+03	2017-07-18 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-18 11:50:00+03	2017-07-18 14:40:00+03
21851	PG0127	2017-07-19 11:45:00+03	2017-07-19 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-19 11:48:00+03	2017-07-19 14:38:00+03
21852	PG0127	2017-07-20 11:45:00+03	2017-07-20 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-20 11:49:00+03	2017-07-20 14:42:00+03
21853	PG0127	2017-07-21 11:45:00+03	2017-07-21 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-21 11:47:00+03	2017-07-21 14:37:00+03
21854	PG0127	2017-07-22 11:45:00+03	2017-07-22 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-22 11:49:00+03	2017-07-22 14:41:00+03
21855	PG0127	2017-07-23 11:45:00+03	2017-07-23 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-23 11:50:00+03	2017-07-23 14:41:00+03
21856	PG0127	2017-07-24 11:45:00+03	2017-07-24 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-24 11:47:00+03	2017-07-24 14:34:00+03
21857	PG0127	2017-07-25 11:45:00+03	2017-07-25 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-25 11:48:00+03	2017-07-25 14:39:00+03
21858	PG0127	2017-07-26 11:45:00+03	2017-07-26 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-26 11:47:00+03	2017-07-26 14:38:00+03
21859	PG0127	2017-07-27 11:45:00+03	2017-07-27 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-27 11:48:00+03	2017-07-27 14:38:00+03
21860	PG0127	2017-07-28 11:45:00+03	2017-07-28 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-28 11:49:00+03	2017-07-28 14:42:00+03
21861	PG0127	2017-07-29 11:45:00+03	2017-07-29 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-29 11:49:00+03	2017-07-29 14:37:00+03
21862	PG0127	2017-07-30 11:45:00+03	2017-07-30 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-30 11:47:00+03	2017-07-30 14:35:00+03
21863	PG0127	2017-07-31 11:45:00+03	2017-07-31 14:35:00+03	SLY	VKO	Arrived	CR2	2017-07-31 11:48:00+03	2017-07-31 14:38:00+03
21864	PG0127	2017-08-01 11:45:00+03	2017-08-01 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-01 11:49:00+03	2017-08-01 14:37:00+03
21865	PG0127	2017-08-02 11:45:00+03	2017-08-02 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-02 11:48:00+03	2017-08-02 14:36:00+03
21866	PG0127	2017-08-03 11:45:00+03	2017-08-03 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-03 11:49:00+03	2017-08-03 14:42:00+03
21867	PG0127	2017-08-04 11:45:00+03	2017-08-04 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-04 11:47:00+03	2017-08-04 14:34:00+03
21868	PG0127	2017-08-05 11:45:00+03	2017-08-05 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-05 11:46:00+03	2017-08-05 14:37:00+03
21869	PG0127	2017-08-06 11:45:00+03	2017-08-06 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-06 11:50:00+03	2017-08-06 14:40:00+03
21870	PG0127	2017-08-07 11:45:00+03	2017-08-07 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-07 11:49:00+03	2017-08-07 14:38:00+03
21871	PG0127	2017-08-08 11:45:00+03	2017-08-08 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-08 11:51:00+03	2017-08-08 14:41:00+03
21872	PG0127	2017-08-09 11:45:00+03	2017-08-09 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-09 11:47:00+03	2017-08-09 14:37:00+03
21873	PG0127	2017-08-10 11:45:00+03	2017-08-10 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-10 11:48:00+03	2017-08-10 14:37:00+03
21874	PG0127	2017-08-11 11:45:00+03	2017-08-11 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-11 11:47:00+03	2017-08-11 14:37:00+03
21875	PG0127	2017-08-12 11:45:00+03	2017-08-12 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-12 11:50:00+03	2017-08-12 14:44:00+03
21876	PG0127	2017-08-13 11:45:00+03	2017-08-13 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-13 11:49:00+03	2017-08-13 14:37:00+03
21877	PG0127	2017-08-14 11:45:00+03	2017-08-14 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-14 11:48:00+03	2017-08-14 14:40:00+03
21878	PG0127	2017-08-15 11:45:00+03	2017-08-15 14:35:00+03	SLY	VKO	Arrived	CR2	2017-08-15 11:48:00+03	2017-08-15 14:37:00+03
21879	PG0127	2017-08-16 11:45:00+03	2017-08-16 14:35:00+03	SLY	VKO	On Time	CR2	\N	\N
21880	PG0127	2017-08-17 11:45:00+03	2017-08-17 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21881	PG0127	2017-08-18 11:45:00+03	2017-08-18 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21882	PG0127	2017-08-19 11:45:00+03	2017-08-19 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21883	PG0127	2017-08-20 11:45:00+03	2017-08-20 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21884	PG0127	2017-08-21 11:45:00+03	2017-08-21 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21885	PG0127	2017-08-22 11:45:00+03	2017-08-22 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21886	PG0127	2017-08-24 11:45:00+03	2017-08-24 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21887	PG0127	2017-08-25 11:45:00+03	2017-08-25 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21888	PG0127	2017-08-26 11:45:00+03	2017-08-26 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21889	PG0127	2017-08-27 11:45:00+03	2017-08-27 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21890	PG0127	2017-08-28 11:45:00+03	2017-08-28 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21891	PG0127	2017-08-29 11:45:00+03	2017-08-29 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21892	PG0127	2017-08-30 11:45:00+03	2017-08-30 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21893	PG0127	2017-08-31 11:45:00+03	2017-08-31 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21894	PG0127	2017-09-01 11:45:00+03	2017-09-01 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21895	PG0127	2017-09-02 11:45:00+03	2017-09-02 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21896	PG0127	2017-09-03 11:45:00+03	2017-09-03 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21897	PG0127	2017-09-04 11:45:00+03	2017-09-04 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21898	PG0127	2017-09-05 11:45:00+03	2017-09-05 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21899	PG0127	2017-09-06 11:45:00+03	2017-09-06 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21900	PG0127	2017-09-07 11:45:00+03	2017-09-07 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21901	PG0127	2017-09-08 11:45:00+03	2017-09-08 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21902	PG0127	2017-09-09 11:45:00+03	2017-09-09 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21903	PG0127	2017-09-10 11:45:00+03	2017-09-10 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21904	PG0127	2017-09-11 11:45:00+03	2017-09-11 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21905	PG0127	2017-09-12 11:45:00+03	2017-09-12 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21906	PG0127	2017-09-13 11:45:00+03	2017-09-13 14:35:00+03	SLY	VKO	Scheduled	CR2	\N	\N
21907	PG0127	2017-09-14 11:45:00+03	2017-09-14 14:35:00+03	SLY	VKO	Cancelled	CR2	\N	\N
21908	PG0377	2017-09-04 08:50:00+03	2017-09-04 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21909	PG0377	2017-09-08 08:50:00+03	2017-09-08 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21910	PG0377	2017-07-23 08:50:00+03	2017-07-23 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-23 08:54:00+03	2017-07-23 11:04:00+03
21911	PG0377	2017-09-01 08:50:00+03	2017-09-01 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21912	PG0377	2017-09-13 08:50:00+03	2017-09-13 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21913	PG0377	2017-07-22 08:50:00+03	2017-07-22 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-22 08:54:00+03	2017-07-22 11:04:00+03
21914	PG0377	2017-08-02 08:50:00+03	2017-08-02 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-02 08:52:00+03	2017-08-02 11:02:00+03
21915	PG0377	2017-07-29 08:50:00+03	2017-07-29 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-29 08:52:00+03	2017-07-29 11:02:00+03
21916	PG0377	2017-08-12 08:50:00+03	2017-08-12 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-12 08:52:00+03	2017-08-12 11:03:00+03
21917	PG0377	2017-08-23 08:50:00+03	2017-08-23 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21918	PG0377	2017-09-05 08:50:00+03	2017-09-05 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21919	PG0377	2017-08-09 08:50:00+03	2017-08-09 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-09 08:55:00+03	2017-08-09 11:06:00+03
21920	PG0377	2017-08-27 08:50:00+03	2017-08-27 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21921	PG0377	2017-09-02 08:50:00+03	2017-09-02 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21922	PG0377	2017-08-28 08:50:00+03	2017-08-28 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21923	PG0377	2017-09-12 08:50:00+03	2017-09-12 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21924	PG0377	2017-07-27 08:50:00+03	2017-07-27 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-27 08:53:00+03	2017-07-27 11:01:00+03
21925	PG0377	2017-07-21 08:50:00+03	2017-07-21 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-21 08:54:00+03	2017-07-21 11:03:00+03
21926	PG0377	2017-07-16 08:50:00+03	2017-07-16 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-16 08:53:00+03	2017-07-16 11:04:00+03
21927	PG0377	2017-08-19 08:50:00+03	2017-08-19 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21928	PG0377	2017-08-16 08:50:00+03	2017-08-16 11:00:00+03	SLY	OVB	On Time	CR2	\N	\N
21929	PG0377	2017-07-17 08:50:00+03	2017-07-17 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-17 08:52:00+03	2017-07-17 11:03:00+03
21930	PG0377	2017-09-09 08:50:00+03	2017-09-09 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21931	PG0377	2017-08-31 08:50:00+03	2017-08-31 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21932	PG0377	2017-08-03 08:50:00+03	2017-08-03 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-03 12:51:00+03	2017-08-03 15:02:00+03
21933	PG0377	2017-09-06 08:50:00+03	2017-09-06 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21934	PG0377	2017-08-21 08:50:00+03	2017-08-21 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21935	PG0377	2017-08-11 08:50:00+03	2017-08-11 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-11 08:51:00+03	2017-08-11 11:01:00+03
21936	PG0377	2017-08-07 08:50:00+03	2017-08-07 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-07 08:54:00+03	2017-08-07 11:04:00+03
21937	PG0377	2017-09-03 08:50:00+03	2017-09-03 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21938	PG0377	2017-09-14 08:50:00+03	2017-09-14 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21939	PG0377	2017-07-30 08:50:00+03	2017-07-30 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-30 08:52:00+03	2017-07-30 11:02:00+03
21940	PG0377	2017-08-10 08:50:00+03	2017-08-10 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-10 08:50:00+03	2017-08-10 11:01:00+03
21941	PG0377	2017-08-05 08:50:00+03	2017-08-05 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-05 08:55:00+03	2017-08-05 11:05:00+03
21942	PG0377	2017-08-04 08:50:00+03	2017-08-04 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-04 08:55:00+03	2017-08-04 11:05:00+03
21943	PG0377	2017-08-17 08:50:00+03	2017-08-17 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21944	PG0377	2017-07-28 08:50:00+03	2017-07-28 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-28 08:57:00+03	2017-07-28 11:06:00+03
21945	PG0377	2017-08-25 08:50:00+03	2017-08-25 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21946	PG0377	2017-08-29 08:50:00+03	2017-08-29 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21947	PG0377	2017-07-18 08:50:00+03	2017-07-18 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-18 08:52:00+03	2017-07-18 11:01:00+03
21948	PG0377	2017-09-07 08:50:00+03	2017-09-07 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21949	PG0377	2017-07-19 08:50:00+03	2017-07-19 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-19 08:52:00+03	2017-07-19 11:03:00+03
21950	PG0377	2017-08-22 08:50:00+03	2017-08-22 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21951	PG0377	2017-08-26 08:50:00+03	2017-08-26 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21952	PG0377	2017-08-15 08:50:00+03	2017-08-15 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-15 08:52:00+03	2017-08-15 11:02:00+03
21953	PG0377	2017-08-13 08:50:00+03	2017-08-13 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-13 08:54:00+03	2017-08-13 11:05:00+03
21954	PG0377	2017-08-20 08:50:00+03	2017-08-20 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21955	PG0377	2017-09-10 08:50:00+03	2017-09-10 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21956	PG0377	2017-07-20 08:50:00+03	2017-07-20 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-20 08:52:00+03	2017-07-20 11:02:00+03
21957	PG0377	2017-08-08 08:50:00+03	2017-08-08 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-08 08:52:00+03	2017-08-08 11:01:00+03
21958	PG0377	2017-08-24 08:50:00+03	2017-08-24 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21959	PG0377	2017-08-01 08:50:00+03	2017-08-01 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-01 08:55:00+03	2017-08-01 11:05:00+03
21960	PG0377	2017-08-30 08:50:00+03	2017-08-30 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21961	PG0377	2017-08-18 08:50:00+03	2017-08-18 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21962	PG0377	2017-08-06 08:50:00+03	2017-08-06 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-06 08:54:00+03	2017-08-06 11:04:00+03
21963	PG0377	2017-07-25 08:50:00+03	2017-07-25 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-25 08:53:00+03	2017-07-25 11:02:00+03
21964	PG0377	2017-07-31 08:50:00+03	2017-07-31 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-31 08:53:00+03	2017-07-31 11:05:00+03
21965	PG0377	2017-07-26 08:50:00+03	2017-07-26 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-26 08:52:00+03	2017-07-26 11:03:00+03
21966	PG0377	2017-08-14 08:50:00+03	2017-08-14 11:00:00+03	SLY	OVB	Arrived	CR2	2017-08-14 08:53:00+03	2017-08-14 11:03:00+03
21967	PG0377	2017-09-11 08:50:00+03	2017-09-11 11:00:00+03	SLY	OVB	Scheduled	CR2	\N	\N
21968	PG0377	2017-07-24 08:50:00+03	2017-07-24 11:00:00+03	SLY	OVB	Arrived	CR2	2017-07-24 08:54:00+03	2017-07-24 11:02:00+03
21969	PG0240	2017-07-16 07:15:00+03	2017-07-16 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-16 07:20:00+03	2017-07-16 09:53:00+03
21970	PG0240	2017-07-22 07:15:00+03	2017-07-22 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-22 07:22:00+03	2017-07-22 09:56:00+03
21971	PG0240	2017-08-15 07:15:00+03	2017-08-15 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-15 07:18:00+03	2017-08-15 09:54:00+03
21972	PG0240	2017-08-14 07:15:00+03	2017-08-14 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-14 07:19:00+03	2017-08-14 09:53:00+03
21973	PG0240	2017-08-17 07:15:00+03	2017-08-17 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21974	PG0240	2017-08-08 07:15:00+03	2017-08-08 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-08 07:16:00+03	2017-08-08 09:51:00+03
21975	PG0240	2017-08-27 07:15:00+03	2017-08-27 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21976	PG0240	2017-09-06 07:15:00+03	2017-09-06 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21977	PG0240	2017-08-10 07:15:00+03	2017-08-10 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-10 07:17:00+03	2017-08-10 09:51:00+03
21978	PG0240	2017-08-04 07:15:00+03	2017-08-04 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-04 07:19:00+03	2017-08-04 09:55:00+03
21979	PG0240	2017-08-03 07:15:00+03	2017-08-03 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-03 07:18:00+03	2017-08-03 09:54:00+03
21980	PG0240	2017-07-26 07:15:00+03	2017-07-26 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-26 09:56:00+03	2017-07-26 12:31:00+03
21981	PG0240	2017-08-12 07:15:00+03	2017-08-12 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-12 07:15:00+03	2017-08-12 09:49:00+03
21982	PG0240	2017-09-07 07:15:00+03	2017-09-07 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21983	PG0240	2017-09-10 07:15:00+03	2017-09-10 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21984	PG0240	2017-08-16 07:15:00+03	2017-08-16 09:50:00+03	HMA	DME	On Time	SU9	\N	\N
21985	PG0240	2017-07-25 07:15:00+03	2017-07-25 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-25 07:17:00+03	2017-07-25 09:52:00+03
21986	PG0240	2017-07-27 07:15:00+03	2017-07-27 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-27 07:17:00+03	2017-07-27 09:55:00+03
21987	PG0240	2017-09-04 07:15:00+03	2017-09-04 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21988	PG0240	2017-07-29 07:15:00+03	2017-07-29 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-29 07:17:00+03	2017-07-29 09:53:00+03
21989	PG0240	2017-08-31 07:15:00+03	2017-08-31 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21990	PG0240	2017-08-22 07:15:00+03	2017-08-22 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21991	PG0240	2017-07-30 07:15:00+03	2017-07-30 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-30 07:16:00+03	2017-07-30 09:52:00+03
21992	PG0240	2017-08-23 07:15:00+03	2017-08-23 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21993	PG0240	2017-07-19 07:15:00+03	2017-07-19 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-19 07:19:00+03	2017-07-19 09:58:00+03
21994	PG0240	2017-08-24 07:15:00+03	2017-08-24 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21995	PG0240	2017-07-23 07:15:00+03	2017-07-23 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-23 07:19:00+03	2017-07-23 09:54:00+03
21996	PG0240	2017-09-05 07:15:00+03	2017-09-05 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21997	PG0240	2017-08-20 07:15:00+03	2017-08-20 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
21998	PG0240	2017-07-28 07:15:00+03	2017-07-28 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-28 07:21:00+03	2017-07-28 09:58:00+03
21999	PG0240	2017-09-08 07:15:00+03	2017-09-08 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22000	PG0240	2017-08-07 07:15:00+03	2017-08-07 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-07 07:19:00+03	2017-08-07 09:54:00+03
22001	PG0240	2017-08-01 07:15:00+03	2017-08-01 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-01 07:22:00+03	2017-08-01 10:00:00+03
22002	PG0240	2017-08-26 07:15:00+03	2017-08-26 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22003	PG0240	2017-07-31 07:15:00+03	2017-07-31 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-31 07:18:00+03	2017-07-31 09:50:00+03
22004	PG0240	2017-09-01 07:15:00+03	2017-09-01 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22005	PG0240	2017-09-11 07:15:00+03	2017-09-11 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22006	PG0240	2017-08-05 07:15:00+03	2017-08-05 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-05 07:18:00+03	2017-08-05 09:52:00+03
22007	PG0240	2017-08-18 07:15:00+03	2017-08-18 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22008	PG0240	2017-07-20 07:15:00+03	2017-07-20 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-20 07:18:00+03	2017-07-20 09:53:00+03
22009	PG0240	2017-09-02 07:15:00+03	2017-09-02 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22010	PG0240	2017-09-09 07:15:00+03	2017-09-09 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22011	PG0240	2017-07-18 07:15:00+03	2017-07-18 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-18 07:18:00+03	2017-07-18 09:57:00+03
22012	PG0240	2017-08-28 07:15:00+03	2017-08-28 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22013	PG0240	2017-08-25 07:15:00+03	2017-08-25 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22014	PG0240	2017-07-17 07:15:00+03	2017-07-17 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-17 07:20:00+03	2017-07-17 09:56:00+03
22015	PG0240	2017-09-12 07:15:00+03	2017-09-12 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22016	PG0240	2017-08-21 07:15:00+03	2017-08-21 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22017	PG0240	2017-08-09 07:15:00+03	2017-08-09 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-09 07:15:00+03	2017-08-09 09:51:00+03
22018	PG0240	2017-08-30 07:15:00+03	2017-08-30 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22019	PG0240	2017-09-03 07:15:00+03	2017-09-03 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22020	PG0240	2017-08-19 07:15:00+03	2017-08-19 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22021	PG0240	2017-07-24 07:15:00+03	2017-07-24 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-24 07:19:00+03	2017-07-24 09:53:00+03
22022	PG0240	2017-08-02 07:15:00+03	2017-08-02 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-02 07:16:00+03	2017-08-02 09:51:00+03
22023	PG0240	2017-08-13 07:15:00+03	2017-08-13 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-13 07:20:00+03	2017-08-13 09:55:00+03
22024	PG0240	2017-09-14 07:15:00+03	2017-09-14 09:50:00+03	HMA	DME	Cancelled	SU9	\N	\N
22025	PG0240	2017-07-21 07:15:00+03	2017-07-21 09:50:00+03	HMA	DME	Arrived	SU9	2017-07-21 07:16:00+03	2017-07-21 09:52:00+03
22026	PG0240	2017-08-06 07:15:00+03	2017-08-06 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-06 07:18:00+03	2017-08-06 09:56:00+03
22027	PG0240	2017-09-13 07:15:00+03	2017-09-13 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22028	PG0240	2017-08-11 07:15:00+03	2017-08-11 09:50:00+03	HMA	DME	Arrived	SU9	2017-08-11 07:17:00+03	2017-08-11 09:55:00+03
22029	PG0240	2017-08-29 07:15:00+03	2017-08-29 09:50:00+03	HMA	DME	Scheduled	SU9	\N	\N
22030	PG0053	2017-08-16 08:20:00+03	2017-08-16 11:05:00+03	HMA	VKO	On Time	CR2	\N	\N
22031	PG0053	2017-08-18 08:20:00+03	2017-08-18 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22032	PG0053	2017-08-11 08:20:00+03	2017-08-11 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-11 08:23:00+03	2017-08-11 11:09:00+03
22033	PG0053	2017-07-23 08:20:00+03	2017-07-23 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-23 08:24:00+03	2017-07-23 11:10:00+03
22034	PG0053	2017-08-29 08:20:00+03	2017-08-29 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22035	PG0053	2017-09-10 08:20:00+03	2017-09-10 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22036	PG0053	2017-08-19 08:20:00+03	2017-08-19 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22037	PG0053	2017-08-15 08:20:00+03	2017-08-15 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-15 08:22:00+03	2017-08-15 11:07:00+03
22038	PG0053	2017-08-09 08:20:00+03	2017-08-09 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-09 08:24:00+03	2017-08-09 11:09:00+03
22039	PG0053	2017-07-26 08:20:00+03	2017-07-26 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-26 08:24:00+03	2017-07-26 11:07:00+03
22040	PG0053	2017-08-25 08:20:00+03	2017-08-25 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22041	PG0053	2017-07-19 08:20:00+03	2017-07-19 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-19 08:22:00+03	2017-07-19 11:02:00+03
22042	PG0053	2017-09-11 08:20:00+03	2017-09-11 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22043	PG0053	2017-07-18 08:20:00+03	2017-07-18 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-18 08:25:00+03	2017-07-18 11:12:00+03
22044	PG0053	2017-08-14 08:20:00+03	2017-08-14 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-14 08:20:00+03	2017-08-14 11:04:00+03
22045	PG0053	2017-07-25 08:20:00+03	2017-07-25 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-25 08:22:00+03	2017-07-25 11:10:00+03
22046	PG0053	2017-08-20 08:20:00+03	2017-08-20 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22047	PG0053	2017-08-17 08:20:00+03	2017-08-17 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22048	PG0053	2017-09-12 08:20:00+03	2017-09-12 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22049	PG0053	2017-08-01 08:20:00+03	2017-08-01 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-01 08:22:00+03	2017-08-01 11:06:00+03
22050	PG0053	2017-09-01 08:20:00+03	2017-09-01 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22051	PG0053	2017-08-04 08:20:00+03	2017-08-04 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-04 11:52:00+03	2017-08-04 14:38:00+03
22052	PG0053	2017-07-20 08:20:00+03	2017-07-20 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-20 08:21:00+03	2017-07-20 11:08:00+03
22053	PG0053	2017-07-27 08:20:00+03	2017-07-27 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-27 08:22:00+03	2017-07-27 11:05:00+03
22054	PG0053	2017-07-28 08:20:00+03	2017-07-28 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-28 08:22:00+03	2017-07-28 11:06:00+03
22055	PG0053	2017-09-03 08:20:00+03	2017-09-03 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22056	PG0053	2017-08-31 08:20:00+03	2017-08-31 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22057	PG0053	2017-08-12 08:20:00+03	2017-08-12 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-12 08:23:00+03	2017-08-12 11:10:00+03
22058	PG0053	2017-09-14 08:20:00+03	2017-09-14 11:05:00+03	HMA	VKO	Cancelled	CR2	\N	\N
22059	PG0053	2017-09-05 08:20:00+03	2017-09-05 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22060	PG0053	2017-08-06 08:20:00+03	2017-08-06 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-06 08:25:00+03	2017-08-06 11:12:00+03
22061	PG0053	2017-08-30 08:20:00+03	2017-08-30 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22062	PG0053	2017-07-22 08:20:00+03	2017-07-22 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-22 08:22:00+03	2017-07-22 11:08:00+03
22063	PG0053	2017-07-21 08:20:00+03	2017-07-21 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-21 08:22:00+03	2017-07-21 11:07:00+03
22064	PG0053	2017-09-13 08:20:00+03	2017-09-13 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22065	PG0053	2017-08-08 08:20:00+03	2017-08-08 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-08 08:23:00+03	2017-08-08 11:09:00+03
22066	PG0053	2017-08-13 08:20:00+03	2017-08-13 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-13 08:21:00+03	2017-08-13 11:06:00+03
22067	PG0053	2017-07-30 08:20:00+03	2017-07-30 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-30 08:21:00+03	2017-07-30 11:05:00+03
22068	PG0053	2017-08-26 08:20:00+03	2017-08-26 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22069	PG0053	2017-08-10 08:20:00+03	2017-08-10 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-10 08:21:00+03	2017-08-10 11:06:00+03
22070	PG0053	2017-09-08 08:20:00+03	2017-09-08 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22071	PG0053	2017-08-23 08:20:00+03	2017-08-23 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22072	PG0053	2017-09-07 08:20:00+03	2017-09-07 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22073	PG0053	2017-08-22 08:20:00+03	2017-08-22 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22074	PG0053	2017-09-09 08:20:00+03	2017-09-09 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22075	PG0053	2017-07-31 08:20:00+03	2017-07-31 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-31 08:22:00+03	2017-07-31 11:08:00+03
22076	PG0053	2017-09-04 08:20:00+03	2017-09-04 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22077	PG0053	2017-08-02 08:20:00+03	2017-08-02 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-02 08:26:00+03	2017-08-02 11:10:00+03
22078	PG0053	2017-08-03 08:20:00+03	2017-08-03 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-03 08:20:00+03	2017-08-03 11:05:00+03
22079	PG0053	2017-09-06 08:20:00+03	2017-09-06 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22080	PG0053	2017-07-16 08:20:00+03	2017-07-16 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-16 08:23:00+03	2017-07-16 11:09:00+03
22081	PG0053	2017-08-24 08:20:00+03	2017-08-24 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22082	PG0053	2017-07-17 08:20:00+03	2017-07-17 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-17 08:24:00+03	2017-07-17 11:08:00+03
22083	PG0053	2017-08-21 08:20:00+03	2017-08-21 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22084	PG0053	2017-08-28 08:20:00+03	2017-08-28 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22085	PG0053	2017-07-29 08:20:00+03	2017-07-29 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-29 08:21:00+03	2017-07-29 11:06:00+03
22086	PG0053	2017-08-07 08:20:00+03	2017-08-07 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-07 08:21:00+03	2017-08-07 11:05:00+03
22087	PG0053	2017-08-05 08:20:00+03	2017-08-05 11:05:00+03	HMA	VKO	Arrived	CR2	2017-08-05 08:25:00+03	2017-08-05 11:09:00+03
22088	PG0053	2017-08-27 08:20:00+03	2017-08-27 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22089	PG0053	2017-07-24 08:20:00+03	2017-07-24 11:05:00+03	HMA	VKO	Arrived	CR2	2017-07-24 08:24:00+03	2017-07-24 11:11:00+03
22090	PG0053	2017-09-02 08:20:00+03	2017-09-02 11:05:00+03	HMA	VKO	Scheduled	CR2	\N	\N
22091	PG0575	2017-08-12 08:25:00+03	2017-08-12 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-12 08:29:00+03	2017-08-12 11:51:00+03
22092	PG0575	2017-07-21 08:25:00+03	2017-07-21 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-21 08:30:00+03	2017-07-21 11:58:00+03
22093	PG0575	2017-07-23 08:25:00+03	2017-07-23 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-23 08:26:00+03	2017-07-23 11:51:00+03
22094	PG0576	2017-07-23 09:35:00+03	2017-07-23 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-23 09:38:00+03	2017-07-23 13:05:00+03
22095	PG0575	2017-08-09 08:25:00+03	2017-08-09 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-09 08:29:00+03	2017-08-09 11:52:00+03
22096	PG0576	2017-08-09 09:35:00+03	2017-08-09 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-09 12:18:00+03	2017-08-09 15:42:00+03
22097	PG0576	2017-09-14 09:35:00+03	2017-09-14 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22098	PG0575	2017-09-14 08:25:00+03	2017-09-14 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22099	PG0576	2017-07-28 09:35:00+03	2017-07-28 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-28 09:37:00+03	2017-07-28 13:02:00+03
22100	PG0576	2017-08-23 09:35:00+03	2017-08-23 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22101	PG0575	2017-08-23 08:25:00+03	2017-08-23 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22102	PG0575	2017-08-21 08:25:00+03	2017-08-21 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22103	PG0576	2017-08-21 09:35:00+03	2017-08-21 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22104	PG0575	2017-07-27 08:25:00+03	2017-07-27 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-27 08:30:00+03	2017-07-27 11:55:00+03
22105	PG0576	2017-07-27 09:35:00+03	2017-07-27 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-27 09:38:00+03	2017-07-27 13:02:00+03
22106	PG0575	2017-07-28 08:25:00+03	2017-07-28 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-28 08:28:00+03	2017-07-28 11:54:00+03
22107	PG0575	2017-08-19 08:25:00+03	2017-08-19 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22108	PG0576	2017-08-19 09:35:00+03	2017-08-19 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22109	PG0576	2017-08-14 09:35:00+03	2017-08-14 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-14 09:36:00+03	2017-08-14 12:59:00+03
22110	PG0575	2017-08-14 08:25:00+03	2017-08-14 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-14 08:30:00+03	2017-08-14 11:57:00+03
22111	PG0576	2017-07-19 09:35:00+03	2017-07-19 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-19 09:42:00+03	2017-07-19 13:06:00+03
22112	PG0575	2017-07-19 08:25:00+03	2017-07-19 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-19 08:29:00+03	2017-07-19 11:59:00+03
22113	PG0576	2017-09-03 09:35:00+03	2017-09-03 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22114	PG0575	2017-09-03 08:25:00+03	2017-09-03 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22115	PG0575	2017-07-17 08:25:00+03	2017-07-17 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-17 08:31:00+03	2017-07-17 11:56:00+03
22116	PG0576	2017-07-17 09:35:00+03	2017-07-17 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-17 09:39:00+03	2017-07-17 13:01:00+03
22117	PG0575	2017-08-30 08:25:00+03	2017-08-30 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22118	PG0576	2017-08-30 09:35:00+03	2017-08-30 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22119	PG0575	2017-08-01 08:25:00+03	2017-08-01 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-01 08:26:00+03	2017-08-01 11:51:00+03
22120	PG0576	2017-09-08 09:35:00+03	2017-09-08 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22121	PG0575	2017-09-08 08:25:00+03	2017-09-08 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22122	PG0576	2017-07-29 09:35:00+03	2017-07-29 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-29 09:39:00+03	2017-07-29 13:01:00+03
22123	PG0576	2017-08-01 09:35:00+03	2017-08-01 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-01 09:37:00+03	2017-08-01 13:04:00+03
22124	PG0575	2017-07-29 08:25:00+03	2017-07-29 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-29 11:28:00+03	2017-07-29 14:55:00+03
22125	PG0576	2017-07-18 09:35:00+03	2017-07-18 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-18 09:38:00+03	2017-07-18 13:04:00+03
22126	PG0575	2017-07-18 08:25:00+03	2017-07-18 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-18 08:28:00+03	2017-07-18 11:54:00+03
22127	PG0576	2017-08-24 09:35:00+03	2017-08-24 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22128	PG0575	2017-08-24 08:25:00+03	2017-08-24 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22129	PG0575	2017-07-31 08:25:00+03	2017-07-31 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-31 08:29:00+03	2017-07-31 11:55:00+03
22130	PG0575	2017-07-22 08:25:00+03	2017-07-22 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-22 08:27:00+03	2017-07-22 11:48:00+03
22131	PG0576	2017-07-31 09:35:00+03	2017-07-31 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-31 09:37:00+03	2017-07-31 13:06:00+03
22132	PG0575	2017-09-04 08:25:00+03	2017-09-04 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22133	PG0576	2017-09-04 09:35:00+03	2017-09-04 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22134	PG0575	2017-09-13 08:25:00+03	2017-09-13 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22135	PG0576	2017-09-10 09:35:00+03	2017-09-10 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22136	PG0576	2017-09-13 09:35:00+03	2017-09-13 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22137	PG0575	2017-09-10 08:25:00+03	2017-09-10 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22138	PG0576	2017-08-27 09:35:00+03	2017-08-27 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22139	PG0575	2017-08-07 08:25:00+03	2017-08-07 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-07 08:26:00+03	2017-08-07 11:54:00+03
22140	PG0576	2017-08-07 09:35:00+03	2017-08-07 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-07 09:36:00+03	2017-08-07 13:01:00+03
22141	PG0575	2017-08-27 08:25:00+03	2017-08-27 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22142	PG0575	2017-08-22 08:25:00+03	2017-08-22 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22143	PG0576	2017-08-22 09:35:00+03	2017-08-22 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22144	PG0576	2017-08-04 09:35:00+03	2017-08-04 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-04 09:37:00+03	2017-08-04 13:03:00+03
22145	PG0575	2017-08-04 08:25:00+03	2017-08-04 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-04 08:28:00+03	2017-08-04 11:55:00+03
22146	PG0576	2017-08-06 09:35:00+03	2017-08-06 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-06 09:40:00+03	2017-08-06 13:03:00+03
22147	PG0575	2017-08-06 08:25:00+03	2017-08-06 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-06 08:27:00+03	2017-08-06 11:51:00+03
22148	PG0576	2017-08-17 09:35:00+03	2017-08-17 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22149	PG0575	2017-08-17 08:25:00+03	2017-08-17 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22150	PG0575	2017-07-24 08:25:00+03	2017-07-24 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-24 08:27:00+03	2017-07-24 11:50:00+03
22151	PG0576	2017-07-24 09:35:00+03	2017-07-24 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-24 09:37:00+03	2017-07-24 13:03:00+03
22152	PG0575	2017-07-30 08:25:00+03	2017-07-30 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-30 08:31:00+03	2017-07-30 11:59:00+03
22153	PG0575	2017-07-16 08:25:00+03	2017-07-16 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-16 08:28:00+03	2017-07-16 11:52:00+03
22154	PG0575	2017-09-11 08:25:00+03	2017-09-11 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22155	PG0576	2017-07-16 09:35:00+03	2017-07-16 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-16 09:37:00+03	2017-07-16 13:03:00+03
22156	PG0576	2017-07-30 09:35:00+03	2017-07-30 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-30 09:40:00+03	2017-07-30 13:03:00+03
22157	PG0575	2017-09-07 08:25:00+03	2017-09-07 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22158	PG0576	2017-08-12 09:35:00+03	2017-08-12 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-12 09:36:00+03	2017-08-12 13:04:00+03
22159	PG0576	2017-09-06 09:35:00+03	2017-09-06 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22160	PG0575	2017-09-06 08:25:00+03	2017-09-06 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22161	PG0575	2017-08-20 08:25:00+03	2017-08-20 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22162	PG0575	2017-08-11 08:25:00+03	2017-08-11 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-11 08:26:00+03	2017-08-11 11:48:00+03
22163	PG0576	2017-08-20 09:35:00+03	2017-08-20 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22164	PG0575	2017-08-25 08:25:00+03	2017-08-25 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22165	PG0576	2017-08-25 09:35:00+03	2017-08-25 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22166	PG0576	2017-09-07 09:35:00+03	2017-09-07 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22167	PG0576	2017-08-16 09:35:00+03	2017-08-16 13:00:00+03	HMA	OVB	On Time	CN1	\N	\N
22168	PG0575	2017-08-16 08:25:00+03	2017-08-16 11:50:00+03	HMA	OVB	On Time	CN1	\N	\N
22169	PG0576	2017-07-20 09:35:00+03	2017-07-20 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-20 09:41:00+03	2017-07-20 13:08:00+03
22170	PG0576	2017-08-03 09:35:00+03	2017-08-03 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-03 13:02:00+03	2017-08-03 16:29:00+03
22171	PG0575	2017-07-25 08:25:00+03	2017-07-25 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-25 08:26:00+03	2017-07-25 11:53:00+03
22172	PG0575	2017-08-03 08:25:00+03	2017-08-03 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-03 08:27:00+03	2017-08-03 11:53:00+03
22173	PG0575	2017-07-20 08:25:00+03	2017-07-20 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-20 08:27:00+03	2017-07-20 11:51:00+03
22174	PG0576	2017-08-11 09:35:00+03	2017-08-11 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-11 09:43:00+03	2017-08-11 13:08:00+03
22175	PG0576	2017-08-05 09:35:00+03	2017-08-05 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-05 09:37:00+03	2017-08-05 13:06:00+03
22176	PG0576	2017-09-11 09:35:00+03	2017-09-11 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22177	PG0575	2017-08-29 08:25:00+03	2017-08-29 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22178	PG0576	2017-08-29 09:35:00+03	2017-08-29 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22179	PG0575	2017-08-08 08:25:00+03	2017-08-08 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-08 08:28:00+03	2017-08-08 11:52:00+03
22180	PG0576	2017-08-08 09:35:00+03	2017-08-08 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-08 09:38:00+03	2017-08-08 13:04:00+03
22181	PG0575	2017-08-13 08:25:00+03	2017-08-13 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-13 08:28:00+03	2017-08-13 11:54:00+03
22182	PG0576	2017-09-02 09:35:00+03	2017-09-02 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22183	PG0575	2017-09-02 08:25:00+03	2017-09-02 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22184	PG0576	2017-08-13 09:35:00+03	2017-08-13 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-13 09:41:00+03	2017-08-13 13:04:00+03
22185	PG0575	2017-08-05 08:25:00+03	2017-08-05 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-05 08:29:00+03	2017-08-05 11:56:00+03
22186	PG0576	2017-08-10 09:35:00+03	2017-08-10 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-10 09:38:00+03	2017-08-10 13:04:00+03
22187	PG0576	2017-09-09 09:35:00+03	2017-09-09 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22188	PG0575	2017-08-31 08:25:00+03	2017-08-31 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22189	PG0575	2017-09-09 08:25:00+03	2017-09-09 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22190	PG0576	2017-08-18 09:35:00+03	2017-08-18 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22191	PG0575	2017-09-12 08:25:00+03	2017-09-12 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22192	PG0576	2017-09-12 09:35:00+03	2017-09-12 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22193	PG0575	2017-08-26 08:25:00+03	2017-08-26 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22194	PG0575	2017-09-01 08:25:00+03	2017-09-01 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22195	PG0576	2017-07-22 09:35:00+03	2017-07-22 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-22 13:01:00+03	2017-07-22 16:26:00+03
22196	PG0575	2017-08-18 08:25:00+03	2017-08-18 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22197	PG0576	2017-09-01 09:35:00+03	2017-09-01 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22198	PG0576	2017-08-26 09:35:00+03	2017-08-26 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22199	PG0575	2017-08-10 08:25:00+03	2017-08-10 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-10 08:29:00+03	2017-08-10 11:51:00+03
22200	PG0576	2017-08-15 09:35:00+03	2017-08-15 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-15 09:39:00+03	2017-08-15 13:06:00+03
22201	PG0575	2017-08-28 08:25:00+03	2017-08-28 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22202	PG0576	2017-08-28 09:35:00+03	2017-08-28 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22203	PG0575	2017-08-15 08:25:00+03	2017-08-15 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-15 08:27:00+03	2017-08-15 11:52:00+03
22204	PG0575	2017-07-26 08:25:00+03	2017-07-26 11:50:00+03	HMA	OVB	Arrived	CN1	2017-07-26 08:25:00+03	2017-07-26 11:50:00+03
22205	PG0576	2017-07-26 09:35:00+03	2017-07-26 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-26 09:40:00+03	2017-07-26 13:06:00+03
22206	PG0575	2017-09-05 08:25:00+03	2017-09-05 11:50:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22207	PG0576	2017-09-05 09:35:00+03	2017-09-05 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22208	PG0576	2017-07-25 09:35:00+03	2017-07-25 13:00:00+03	HMA	OVB	Cancelled	CN1	2017-07-25 09:37:00+03	2017-07-25 13:02:00+03
22209	PG0576	2017-08-02 09:35:00+03	2017-08-02 13:00:00+03	HMA	OVB	Arrived	CN1	2017-08-02 09:36:00+03	2017-08-02 13:04:00+03
22210	PG0575	2017-08-02 08:25:00+03	2017-08-02 11:50:00+03	HMA	OVB	Arrived	CN1	2017-08-02 08:28:00+03	2017-08-02 11:53:00+03
22211	PG0576	2017-08-31 09:35:00+03	2017-08-31 13:00:00+03	HMA	OVB	Scheduled	CN1	\N	\N
22212	PG0576	2017-07-21 09:35:00+03	2017-07-21 13:00:00+03	HMA	OVB	Arrived	CN1	2017-07-21 09:37:00+03	2017-07-21 13:02:00+03
22213	PG0600	2017-09-13 12:50:00+03	2017-09-13 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22214	PG0600	2017-08-14 12:50:00+03	2017-08-14 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-14 12:52:00+03	2017-08-14 13:47:00+03
22215	PG0600	2017-07-16 12:50:00+03	2017-07-16 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-16 15:49:00+03	2017-07-16 16:43:00+03
22216	PG0600	2017-09-05 12:50:00+03	2017-09-05 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22217	PG0600	2017-09-12 12:50:00+03	2017-09-12 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22218	PG0600	2017-09-03 12:50:00+03	2017-09-03 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22219	PG0600	2017-09-08 12:50:00+03	2017-09-08 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22220	PG0600	2017-08-25 12:50:00+03	2017-08-25 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22221	PG0600	2017-08-30 12:50:00+03	2017-08-30 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22222	PG0600	2017-07-19 12:50:00+03	2017-07-19 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-19 12:55:00+03	2017-07-19 13:50:00+03
22223	PG0600	2017-07-30 12:50:00+03	2017-07-30 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-30 12:52:00+03	2017-07-30 13:47:00+03
22224	PG0600	2017-08-18 12:50:00+03	2017-08-18 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22225	PG0600	2017-07-23 12:50:00+03	2017-07-23 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-23 12:53:00+03	2017-07-23 13:48:00+03
22226	PG0600	2017-08-20 12:50:00+03	2017-08-20 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22227	PG0600	2017-09-06 12:50:00+03	2017-09-06 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22228	PG0600	2017-08-22 12:50:00+03	2017-08-22 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22229	PG0600	2017-07-24 12:50:00+03	2017-07-24 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-24 12:53:00+03	2017-07-24 13:49:00+03
22230	PG0600	2017-07-18 12:50:00+03	2017-07-18 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-18 12:53:00+03	2017-07-18 13:48:00+03
22231	PG0600	2017-08-17 12:50:00+03	2017-08-17 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22232	PG0600	2017-08-04 12:50:00+03	2017-08-04 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-04 12:55:00+03	2017-08-04 13:50:00+03
22233	PG0600	2017-08-21 12:50:00+03	2017-08-21 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22234	PG0600	2017-08-07 12:50:00+03	2017-08-07 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-07 12:52:00+03	2017-08-07 13:47:00+03
22235	PG0600	2017-09-04 12:50:00+03	2017-09-04 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22236	PG0600	2017-07-31 12:50:00+03	2017-07-31 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-31 12:51:00+03	2017-07-31 13:45:00+03
22237	PG0600	2017-08-02 12:50:00+03	2017-08-02 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-02 12:52:00+03	2017-08-02 13:48:00+03
22238	PG0600	2017-08-28 12:50:00+03	2017-08-28 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22239	PG0600	2017-07-27 12:50:00+03	2017-07-27 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-27 12:52:00+03	2017-07-27 13:47:00+03
22240	PG0600	2017-09-10 12:50:00+03	2017-09-10 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22241	PG0600	2017-08-27 12:50:00+03	2017-08-27 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22242	PG0600	2017-07-22 12:50:00+03	2017-07-22 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-22 12:55:00+03	2017-07-22 13:51:00+03
22243	PG0600	2017-08-06 12:50:00+03	2017-08-06 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-06 12:53:00+03	2017-08-06 13:48:00+03
22244	PG0600	2017-08-26 12:50:00+03	2017-08-26 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22245	PG0600	2017-08-15 12:50:00+03	2017-08-15 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-15 12:53:00+03	2017-08-15 13:48:00+03
22246	PG0600	2017-08-24 12:50:00+03	2017-08-24 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22247	PG0600	2017-07-29 12:50:00+03	2017-07-29 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-29 12:51:00+03	2017-07-29 13:45:00+03
22248	PG0600	2017-07-28 12:50:00+03	2017-07-28 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-28 12:53:00+03	2017-07-28 13:48:00+03
22249	PG0600	2017-08-19 12:50:00+03	2017-08-19 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22250	PG0600	2017-07-21 12:50:00+03	2017-07-21 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-21 12:52:00+03	2017-07-21 13:47:00+03
22251	PG0600	2017-08-12 12:50:00+03	2017-08-12 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-12 12:53:00+03	2017-08-12 13:48:00+03
22252	PG0600	2017-08-31 12:50:00+03	2017-08-31 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22253	PG0600	2017-08-23 12:50:00+03	2017-08-23 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22254	PG0600	2017-08-09 12:50:00+03	2017-08-09 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-09 12:52:00+03	2017-08-09 13:47:00+03
22255	PG0600	2017-08-08 12:50:00+03	2017-08-08 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-08 12:53:00+03	2017-08-08 13:48:00+03
22256	PG0600	2017-09-02 12:50:00+03	2017-09-02 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22257	PG0600	2017-09-01 12:50:00+03	2017-09-01 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22258	PG0600	2017-08-01 12:50:00+03	2017-08-01 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-01 12:52:00+03	2017-08-01 13:47:00+03
22259	PG0600	2017-09-14 12:50:00+03	2017-09-14 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22260	PG0600	2017-08-29 12:50:00+03	2017-08-29 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22261	PG0600	2017-09-11 12:50:00+03	2017-09-11 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22262	PG0600	2017-08-05 12:50:00+03	2017-08-05 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-05 12:53:00+03	2017-08-05 13:48:00+03
22263	PG0600	2017-07-17 12:50:00+03	2017-07-17 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-17 12:53:00+03	2017-07-17 13:48:00+03
22264	PG0600	2017-07-25 12:50:00+03	2017-07-25 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-25 15:40:00+03	2017-07-25 16:35:00+03
22265	PG0600	2017-08-03 12:50:00+03	2017-08-03 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-03 12:51:00+03	2017-08-03 13:46:00+03
22266	PG0600	2017-07-26 12:50:00+03	2017-07-26 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-26 12:51:00+03	2017-07-26 13:46:00+03
22267	PG0600	2017-08-16 12:50:00+03	2017-08-16 13:45:00+03	HMA	SVX	On Time	SU9	\N	\N
22268	PG0600	2017-08-11 12:50:00+03	2017-08-11 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-11 12:54:00+03	2017-08-11 13:49:00+03
22269	PG0600	2017-07-20 12:50:00+03	2017-07-20 13:45:00+03	HMA	SVX	Arrived	SU9	2017-07-20 12:56:00+03	2017-07-20 13:51:00+03
22270	PG0600	2017-08-10 12:50:00+03	2017-08-10 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-10 12:52:00+03	2017-08-10 13:47:00+03
22271	PG0600	2017-09-07 12:50:00+03	2017-09-07 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22272	PG0600	2017-08-13 12:50:00+03	2017-08-13 13:45:00+03	HMA	SVX	Arrived	SU9	2017-08-13 12:52:00+03	2017-08-13 13:47:00+03
22273	PG0600	2017-09-09 12:50:00+03	2017-09-09 13:45:00+03	HMA	SVX	Scheduled	SU9	\N	\N
22274	PG0350	2017-07-26 07:40:00+03	2017-07-26 09:30:00+03	HMA	OSW	Arrived	CR2	2017-07-26 07:44:00+03	2017-07-26 09:34:00+03
22275	PG0350	2017-08-23 07:40:00+03	2017-08-23 09:30:00+03	HMA	OSW	Scheduled	CR2	\N	\N
22276	PG0350	2017-08-16 07:40:00+03	2017-08-16 09:30:00+03	HMA	OSW	On Time	CR2	\N	\N
22277	PG0350	2017-09-06 07:40:00+03	2017-09-06 09:30:00+03	HMA	OSW	Scheduled	CR2	\N	\N
22278	PG0350	2017-08-09 07:40:00+03	2017-08-09 09:30:00+03	HMA	OSW	Arrived	CR2	2017-08-09 11:16:00+03	2017-08-09 13:07:00+03
22279	PG0350	2017-09-13 07:40:00+03	2017-09-13 09:30:00+03	HMA	OSW	Cancelled	CR2	\N	\N
22280	PG0350	2017-08-02 07:40:00+03	2017-08-02 09:30:00+03	HMA	OSW	Arrived	CR2	2017-08-02 07:40:00+03	2017-08-02 09:31:00+03
22281	PG0350	2017-08-30 07:40:00+03	2017-08-30 09:30:00+03	HMA	OSW	Scheduled	CR2	\N	\N
22282	PG0350	2017-07-19 07:40:00+03	2017-07-19 09:30:00+03	HMA	OSW	Arrived	CR2	2017-07-19 07:44:00+03	2017-07-19 09:35:00+03
22283	PG0265	2017-09-14 14:35:00+03	2017-09-14 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22284	PG0265	2017-07-23 14:35:00+03	2017-07-23 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-23 14:36:00+03	2017-07-23 16:47:00+03
22285	PG0265	2017-07-30 14:35:00+03	2017-07-30 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-30 14:41:00+03	2017-07-30 16:49:00+03
22286	PG0266	2017-07-30 15:40:00+03	2017-07-30 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-30 15:42:00+03	2017-07-30 17:52:00+03
22287	PG0266	2017-07-31 15:40:00+03	2017-07-31 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-31 15:46:00+03	2017-07-31 17:57:00+03
22288	PG0265	2017-07-31 14:35:00+03	2017-07-31 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-31 14:39:00+03	2017-07-31 16:48:00+03
22289	PG0266	2017-08-12 15:40:00+03	2017-08-12 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-12 15:41:00+03	2017-08-12 17:51:00+03
22290	PG0265	2017-08-12 14:35:00+03	2017-08-12 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-12 14:35:00+03	2017-08-12 16:44:00+03
22291	PG0265	2017-09-07 14:35:00+03	2017-09-07 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22292	PG0266	2017-09-07 15:40:00+03	2017-09-07 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22293	PG0266	2017-07-23 15:40:00+03	2017-07-23 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-23 15:44:00+03	2017-07-23 17:54:00+03
22294	PG0266	2017-08-19 15:40:00+03	2017-08-19 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22295	PG0265	2017-08-19 14:35:00+03	2017-08-19 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22296	PG0265	2017-09-04 14:35:00+03	2017-09-04 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22297	PG0266	2017-09-04 15:40:00+03	2017-09-04 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22298	PG0265	2017-07-16 14:35:00+03	2017-07-16 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-16 14:38:00+03	2017-07-16 16:48:00+03
22299	PG0266	2017-07-16 15:40:00+03	2017-07-16 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-16 15:43:00+03	2017-07-16 17:53:00+03
22300	PG0265	2017-08-07 14:35:00+03	2017-08-07 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-07 14:41:00+03	2017-08-07 16:49:00+03
22301	PG0266	2017-08-07 15:40:00+03	2017-08-07 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-07 15:41:00+03	2017-08-07 17:49:00+03
22302	PG0266	2017-08-05 15:40:00+03	2017-08-05 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-05 15:45:00+03	2017-08-05 17:54:00+03
22303	PG0265	2017-08-05 14:35:00+03	2017-08-05 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-05 14:37:00+03	2017-08-05 16:48:00+03
22304	PG0266	2017-08-18 15:40:00+03	2017-08-18 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22305	PG0265	2017-08-18 14:35:00+03	2017-08-18 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22306	PG0265	2017-08-20 14:35:00+03	2017-08-20 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22307	PG0266	2017-08-06 15:40:00+03	2017-08-06 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-06 18:36:00+03	2017-08-06 20:46:00+03
22308	PG0266	2017-08-20 15:40:00+03	2017-08-20 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22309	PG0266	2017-08-28 15:40:00+03	2017-08-28 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22310	PG0266	2017-09-03 15:40:00+03	2017-09-03 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22311	PG0265	2017-09-03 14:35:00+03	2017-09-03 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22312	PG0265	2017-09-12 14:35:00+03	2017-09-12 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22313	PG0266	2017-09-14 15:40:00+03	2017-09-14 17:50:00+03	HMA	NUX	Cancelled	CN1	\N	\N
22314	PG0266	2017-09-12 15:40:00+03	2017-09-12 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22315	PG0266	2017-07-21 15:40:00+03	2017-07-21 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-21 15:41:00+03	2017-07-21 17:50:00+03
22316	PG0265	2017-07-24 14:35:00+03	2017-07-24 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-24 14:36:00+03	2017-07-24 16:46:00+03
22317	PG0265	2017-07-21 14:35:00+03	2017-07-21 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-21 14:36:00+03	2017-07-21 16:46:00+03
22318	PG0266	2017-07-24 15:40:00+03	2017-07-24 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-24 15:41:00+03	2017-07-24 17:51:00+03
22319	PG0265	2017-08-29 14:35:00+03	2017-08-29 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22320	PG0266	2017-08-25 15:40:00+03	2017-08-25 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22321	PG0266	2017-08-29 15:40:00+03	2017-08-29 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22322	PG0266	2017-08-17 15:40:00+03	2017-08-17 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22323	PG0265	2017-08-17 14:35:00+03	2017-08-17 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22324	PG0266	2017-08-04 15:40:00+03	2017-08-04 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-04 15:43:00+03	2017-08-04 17:54:00+03
22325	PG0265	2017-08-04 14:35:00+03	2017-08-04 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-04 14:37:00+03	2017-08-04 16:46:00+03
22326	PG0265	2017-08-08 14:35:00+03	2017-08-08 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-08 17:42:00+03	2017-08-08 19:51:00+03
22327	PG0266	2017-09-10 15:40:00+03	2017-09-10 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22328	PG0266	2017-08-08 15:40:00+03	2017-08-08 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-08 15:44:00+03	2017-08-08 17:54:00+03
22329	PG0265	2017-09-10 14:35:00+03	2017-09-10 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22330	PG0266	2017-08-24 15:40:00+03	2017-08-24 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22331	PG0265	2017-08-24 14:35:00+03	2017-08-24 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22332	PG0265	2017-07-25 14:35:00+03	2017-07-25 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-25 14:38:00+03	2017-07-25 16:49:00+03
22333	PG0266	2017-07-25 15:40:00+03	2017-07-25 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-25 15:41:00+03	2017-07-25 17:51:00+03
22334	PG0265	2017-09-05 14:35:00+03	2017-09-05 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22335	PG0266	2017-09-05 15:40:00+03	2017-09-05 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22336	PG0266	2017-07-22 15:40:00+03	2017-07-22 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-22 15:48:00+03	2017-07-22 17:59:00+03
22337	PG0266	2017-08-16 15:40:00+03	2017-08-16 17:50:00+03	HMA	NUX	On Time	CN1	\N	\N
22338	PG0265	2017-08-28 14:35:00+03	2017-08-28 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22339	PG0265	2017-08-16 14:35:00+03	2017-08-16 16:45:00+03	HMA	NUX	On Time	CN1	\N	\N
22340	PG0266	2017-08-03 15:40:00+03	2017-08-03 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-03 15:41:00+03	2017-08-03 17:52:00+03
22341	PG0265	2017-08-03 14:35:00+03	2017-08-03 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-03 14:37:00+03	2017-08-03 16:47:00+03
22342	PG0265	2017-07-26 14:35:00+03	2017-07-26 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-26 18:22:00+03	2017-07-26 20:34:00+03
22343	PG0266	2017-07-26 15:40:00+03	2017-07-26 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-26 15:43:00+03	2017-07-26 17:55:00+03
22344	PG0265	2017-08-25 14:35:00+03	2017-08-25 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22345	PG0266	2017-07-20 15:40:00+03	2017-07-20 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-20 15:42:00+03	2017-07-20 17:52:00+03
22346	PG0265	2017-07-22 14:35:00+03	2017-07-22 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-22 14:37:00+03	2017-07-22 16:46:00+03
22347	PG0265	2017-07-20 14:35:00+03	2017-07-20 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-20 14:39:00+03	2017-07-20 16:49:00+03
22348	PG0265	2017-08-21 14:35:00+03	2017-08-21 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22349	PG0265	2017-08-09 14:35:00+03	2017-08-09 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-09 14:42:00+03	2017-08-09 16:52:00+03
22350	PG0266	2017-08-09 15:40:00+03	2017-08-09 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-09 15:40:00+03	2017-08-09 17:48:00+03
22351	PG0266	2017-08-21 15:40:00+03	2017-08-21 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22352	PG0265	2017-07-17 14:35:00+03	2017-07-17 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-17 14:39:00+03	2017-07-17 16:48:00+03
22353	PG0266	2017-08-27 15:40:00+03	2017-08-27 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22354	PG0265	2017-08-27 14:35:00+03	2017-08-27 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22355	PG0266	2017-07-17 15:40:00+03	2017-07-17 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-17 15:43:00+03	2017-07-17 17:53:00+03
22356	PG0265	2017-08-30 14:35:00+03	2017-08-30 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22357	PG0266	2017-08-30 15:40:00+03	2017-08-30 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22358	PG0266	2017-09-09 15:40:00+03	2017-09-09 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22359	PG0265	2017-09-09 14:35:00+03	2017-09-09 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22360	PG0266	2017-08-15 15:40:00+03	2017-08-15 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-15 15:47:00+03	2017-08-15 17:57:00+03
22361	PG0265	2017-08-15 14:35:00+03	2017-08-15 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-15 14:37:00+03	2017-08-15 16:48:00+03
22362	PG0265	2017-07-27 14:35:00+03	2017-07-27 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-27 14:37:00+03	2017-07-27 16:48:00+03
22363	PG0266	2017-07-27 15:40:00+03	2017-07-27 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-27 15:41:00+03	2017-07-27 17:50:00+03
22364	PG0266	2017-09-02 15:40:00+03	2017-09-02 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22365	PG0265	2017-09-02 14:35:00+03	2017-09-02 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22366	PG0266	2017-08-02 15:40:00+03	2017-08-02 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-02 15:44:00+03	2017-08-02 17:54:00+03
22367	PG0265	2017-08-02 14:35:00+03	2017-08-02 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-02 14:40:00+03	2017-08-02 16:51:00+03
22368	PG0265	2017-09-06 14:35:00+03	2017-09-06 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22369	PG0266	2017-09-06 15:40:00+03	2017-09-06 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22370	PG0265	2017-08-10 14:35:00+03	2017-08-10 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-10 17:39:00+03	2017-08-10 19:48:00+03
22371	PG0266	2017-08-10 15:40:00+03	2017-08-10 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-10 15:41:00+03	2017-08-10 17:51:00+03
22372	PG0265	2017-07-28 14:35:00+03	2017-07-28 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-28 14:39:00+03	2017-07-28 16:50:00+03
22373	PG0266	2017-07-28 15:40:00+03	2017-07-28 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-28 15:45:00+03	2017-07-28 17:55:00+03
22374	PG0266	2017-08-14 15:40:00+03	2017-08-14 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-14 15:40:00+03	2017-08-14 17:51:00+03
22375	PG0265	2017-08-14 14:35:00+03	2017-08-14 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-14 14:39:00+03	2017-08-14 16:48:00+03
22376	PG0265	2017-09-13 14:35:00+03	2017-09-13 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22377	PG0266	2017-09-13 15:40:00+03	2017-09-13 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22378	PG0266	2017-09-11 15:40:00+03	2017-09-11 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22379	PG0266	2017-09-08 15:40:00+03	2017-09-08 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22380	PG0266	2017-08-01 15:40:00+03	2017-08-01 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-01 15:44:00+03	2017-08-01 17:54:00+03
22381	PG0265	2017-09-08 14:35:00+03	2017-09-08 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22382	PG0265	2017-08-01 14:35:00+03	2017-08-01 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-01 14:39:00+03	2017-08-01 16:50:00+03
22383	PG0265	2017-08-26 14:35:00+03	2017-08-26 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22384	PG0266	2017-08-26 15:40:00+03	2017-08-26 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22385	PG0265	2017-09-11 14:35:00+03	2017-09-11 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22386	PG0266	2017-08-23 15:40:00+03	2017-08-23 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22387	PG0265	2017-08-23 14:35:00+03	2017-08-23 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22388	PG0266	2017-07-19 15:40:00+03	2017-07-19 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-19 15:41:00+03	2017-07-19 17:52:00+03
22389	PG0265	2017-07-19 14:35:00+03	2017-07-19 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-19 14:38:00+03	2017-07-19 16:47:00+03
22390	PG0265	2017-07-29 14:35:00+03	2017-07-29 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-29 14:38:00+03	2017-07-29 16:48:00+03
22391	PG0266	2017-07-29 15:40:00+03	2017-07-29 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-29 15:42:00+03	2017-07-29 17:51:00+03
22392	PG0265	2017-08-06 14:35:00+03	2017-08-06 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-06 14:36:00+03	2017-08-06 16:47:00+03
22393	PG0265	2017-08-22 14:35:00+03	2017-08-22 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22394	PG0265	2017-08-31 14:35:00+03	2017-08-31 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22395	PG0266	2017-08-22 15:40:00+03	2017-08-22 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22396	PG0266	2017-08-31 15:40:00+03	2017-08-31 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22397	PG0266	2017-08-13 15:40:00+03	2017-08-13 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-13 15:42:00+03	2017-08-13 17:50:00+03
22398	PG0265	2017-08-13 14:35:00+03	2017-08-13 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-13 14:41:00+03	2017-08-13 16:51:00+03
22399	PG0265	2017-08-11 14:35:00+03	2017-08-11 16:45:00+03	HMA	NUX	Arrived	CN1	2017-08-11 14:36:00+03	2017-08-11 16:46:00+03
22400	PG0266	2017-08-11 15:40:00+03	2017-08-11 17:50:00+03	HMA	NUX	Arrived	CN1	2017-08-11 15:45:00+03	2017-08-11 17:55:00+03
22401	PG0265	2017-07-18 14:35:00+03	2017-07-18 16:45:00+03	HMA	NUX	Arrived	CN1	2017-07-18 14:37:00+03	2017-07-18 16:47:00+03
22402	PG0266	2017-07-18 15:40:00+03	2017-07-18 17:50:00+03	HMA	NUX	Arrived	CN1	2017-07-18 15:44:00+03	2017-07-18 17:54:00+03
22403	PG0266	2017-09-01 15:40:00+03	2017-09-01 17:50:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22404	PG0265	2017-09-01 14:35:00+03	2017-09-01 16:45:00+03	HMA	NUX	Scheduled	CN1	\N	\N
22405	PG0691	2017-07-22 14:50:00+03	2017-07-22 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-22 14:54:00+03	2017-07-22 18:40:00+03
22406	PG0691	2017-08-26 14:50:00+03	2017-08-26 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22407	PG0691	2017-09-06 14:50:00+03	2017-09-06 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22408	PG0691	2017-07-30 14:50:00+03	2017-07-30 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-30 14:52:00+03	2017-07-30 18:39:00+03
22409	PG0691	2017-08-20 14:50:00+03	2017-08-20 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22410	PG0691	2017-08-31 14:50:00+03	2017-08-31 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22411	PG0691	2017-08-27 14:50:00+03	2017-08-27 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22412	PG0691	2017-07-16 14:50:00+03	2017-07-16 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-16 14:51:00+03	2017-07-16 18:37:00+03
22413	PG0691	2017-08-10 14:50:00+03	2017-08-10 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-10 14:54:00+03	2017-08-10 18:39:00+03
22414	PG0691	2017-08-16 14:50:00+03	2017-08-16 18:35:00+03	HMA	KVX	Delayed	CN1	\N	\N
22415	PG0691	2017-08-06 14:50:00+03	2017-08-06 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-06 14:57:00+03	2017-08-06 18:45:00+03
22416	PG0691	2017-08-12 14:50:00+03	2017-08-12 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-12 14:51:00+03	2017-08-12 18:35:00+03
22417	PG0691	2017-09-02 14:50:00+03	2017-09-02 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22418	PG0691	2017-08-24 14:50:00+03	2017-08-24 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22419	PG0691	2017-08-03 14:50:00+03	2017-08-03 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-03 14:53:00+03	2017-08-03 18:38:00+03
22420	PG0691	2017-07-18 14:50:00+03	2017-07-18 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-18 14:52:00+03	2017-07-18 18:39:00+03
22421	PG0691	2017-09-13 14:50:00+03	2017-09-13 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22422	PG0691	2017-09-14 14:50:00+03	2017-09-14 18:35:00+03	HMA	KVX	Cancelled	CN1	\N	\N
22423	PG0691	2017-07-24 14:50:00+03	2017-07-24 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-24 14:51:00+03	2017-07-24 18:36:00+03
22424	PG0691	2017-07-20 14:50:00+03	2017-07-20 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-20 14:51:00+03	2017-07-20 18:38:00+03
22425	PG0691	2017-07-31 14:50:00+03	2017-07-31 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-31 17:53:00+03	2017-07-31 21:38:00+03
22426	PG0691	2017-07-29 14:50:00+03	2017-07-29 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-29 14:52:00+03	2017-07-29 18:38:00+03
22427	PG0691	2017-08-22 14:50:00+03	2017-08-22 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22428	PG0691	2017-09-04 14:50:00+03	2017-09-04 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22429	PG0691	2017-08-19 14:50:00+03	2017-08-19 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22430	PG0691	2017-08-07 14:50:00+03	2017-08-07 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-07 14:53:00+03	2017-08-07 18:42:00+03
22431	PG0691	2017-08-11 14:50:00+03	2017-08-11 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-11 14:54:00+03	2017-08-11 18:43:00+03
22432	PG0691	2017-08-17 14:50:00+03	2017-08-17 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22433	PG0691	2017-09-11 14:50:00+03	2017-09-11 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22434	PG0691	2017-08-04 14:50:00+03	2017-08-04 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-04 14:51:00+03	2017-08-04 18:36:00+03
22435	PG0691	2017-08-30 14:50:00+03	2017-08-30 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22436	PG0691	2017-08-21 14:50:00+03	2017-08-21 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22437	PG0691	2017-07-23 14:50:00+03	2017-07-23 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-23 14:58:00+03	2017-07-23 18:44:00+03
22438	PG0691	2017-08-01 14:50:00+03	2017-08-01 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-01 14:54:00+03	2017-08-01 18:41:00+03
22439	PG0691	2017-07-27 14:50:00+03	2017-07-27 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-27 14:53:00+03	2017-07-27 18:39:00+03
22440	PG0691	2017-08-18 14:50:00+03	2017-08-18 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22441	PG0691	2017-07-21 14:50:00+03	2017-07-21 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-21 17:46:00+03	2017-07-21 21:31:00+03
22442	PG0691	2017-09-08 14:50:00+03	2017-09-08 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22443	PG0691	2017-08-09 14:50:00+03	2017-08-09 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-09 14:54:00+03	2017-08-09 18:37:00+03
22444	PG0691	2017-09-01 14:50:00+03	2017-09-01 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22445	PG0691	2017-08-14 14:50:00+03	2017-08-14 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-14 14:54:00+03	2017-08-14 18:40:00+03
22446	PG0691	2017-09-10 14:50:00+03	2017-09-10 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22447	PG0691	2017-07-19 14:50:00+03	2017-07-19 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-19 14:51:00+03	2017-07-19 18:40:00+03
22448	PG0691	2017-09-05 14:50:00+03	2017-09-05 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22449	PG0691	2017-07-26 14:50:00+03	2017-07-26 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-26 14:55:00+03	2017-07-26 18:40:00+03
22450	PG0691	2017-08-13 14:50:00+03	2017-08-13 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-13 14:54:00+03	2017-08-13 18:39:00+03
22451	PG0691	2017-09-12 14:50:00+03	2017-09-12 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22452	PG0691	2017-09-07 14:50:00+03	2017-09-07 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22453	PG0691	2017-08-23 14:50:00+03	2017-08-23 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22454	PG0691	2017-07-28 14:50:00+03	2017-07-28 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-28 14:54:00+03	2017-07-28 18:37:00+03
22455	PG0691	2017-08-02 14:50:00+03	2017-08-02 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-02 14:51:00+03	2017-08-02 18:36:00+03
22456	PG0691	2017-08-15 14:50:00+03	2017-08-15 18:35:00+03	HMA	KVX	Departed	CN1	2017-08-15 14:54:00+03	\N
22457	PG0691	2017-08-25 14:50:00+03	2017-08-25 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22458	PG0691	2017-08-08 14:50:00+03	2017-08-08 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-08 14:53:00+03	2017-08-08 18:37:00+03
22459	PG0691	2017-07-17 14:50:00+03	2017-07-17 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-17 14:54:00+03	2017-07-17 18:40:00+03
22460	PG0691	2017-08-28 14:50:00+03	2017-08-28 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22461	PG0691	2017-09-03 14:50:00+03	2017-09-03 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22462	PG0691	2017-08-29 14:50:00+03	2017-08-29 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22463	PG0691	2017-08-05 14:50:00+03	2017-08-05 18:35:00+03	HMA	KVX	Arrived	CN1	2017-08-05 14:52:00+03	2017-08-05 18:35:00+03
22464	PG0691	2017-07-25 14:50:00+03	2017-07-25 18:35:00+03	HMA	KVX	Arrived	CN1	2017-07-25 14:54:00+03	2017-07-25 18:38:00+03
22465	PG0691	2017-09-09 14:50:00+03	2017-09-09 18:35:00+03	HMA	KVX	Scheduled	CN1	\N	\N
22466	PG0687	2017-08-20 09:20:00+03	2017-08-20 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22467	PG0687	2017-07-26 09:20:00+03	2017-07-26 11:30:00+03	HMA	ARH	Arrived	CR2	2017-07-26 09:23:00+03	2017-07-26 11:34:00+03
22468	PG0687	2017-07-19 09:20:00+03	2017-07-19 11:30:00+03	HMA	ARH	Arrived	CR2	2017-07-19 09:24:00+03	2017-07-19 11:32:00+03
22469	PG0687	2017-09-10 09:20:00+03	2017-09-10 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22470	PG0687	2017-08-13 09:20:00+03	2017-08-13 11:30:00+03	HMA	ARH	Arrived	CR2	2017-08-13 09:28:00+03	2017-08-13 11:38:00+03
22471	PG0687	2017-08-16 09:20:00+03	2017-08-16 11:30:00+03	HMA	ARH	On Time	CR2	\N	\N
22472	PG0687	2017-08-23 09:20:00+03	2017-08-23 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22473	PG0687	2017-07-16 09:20:00+03	2017-07-16 11:30:00+03	HMA	ARH	Arrived	CR2	2017-07-16 09:23:00+03	2017-07-16 11:33:00+03
22474	PG0687	2017-09-06 09:20:00+03	2017-09-06 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22475	PG0687	2017-09-03 09:20:00+03	2017-09-03 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22476	PG0687	2017-08-06 09:20:00+03	2017-08-06 11:30:00+03	HMA	ARH	Arrived	CR2	2017-08-06 09:22:00+03	2017-08-06 11:32:00+03
22477	PG0687	2017-08-09 09:20:00+03	2017-08-09 11:30:00+03	HMA	ARH	Arrived	CR2	2017-08-09 09:23:00+03	2017-08-09 11:33:00+03
22478	PG0687	2017-08-30 09:20:00+03	2017-08-30 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22479	PG0687	2017-09-13 09:20:00+03	2017-09-13 11:30:00+03	HMA	ARH	Cancelled	CR2	\N	\N
22480	PG0687	2017-08-02 09:20:00+03	2017-08-02 11:30:00+03	HMA	ARH	Arrived	CR2	2017-08-02 09:26:00+03	2017-08-02 11:37:00+03
22481	PG0687	2017-07-23 09:20:00+03	2017-07-23 11:30:00+03	HMA	ARH	Arrived	CR2	2017-07-23 09:24:00+03	2017-07-23 11:34:00+03
22482	PG0687	2017-07-30 09:20:00+03	2017-07-30 11:30:00+03	HMA	ARH	Arrived	CR2	2017-07-30 09:24:00+03	2017-07-30 11:34:00+03
22483	PG0687	2017-08-27 09:20:00+03	2017-08-27 11:30:00+03	HMA	ARH	Scheduled	CR2	\N	\N
22484	PG0100	2017-09-12 12:45:00+03	2017-09-12 15:15:00+03	NYA	VKO	Scheduled	CR2	\N	\N
22485	PG0100	2017-07-18 12:45:00+03	2017-07-18 15:15:00+03	NYA	VKO	Arrived	CR2	2017-07-18 12:48:00+03	2017-07-18 15:17:00+03
22486	PG0100	2017-07-25 12:45:00+03	2017-07-25 15:15:00+03	NYA	VKO	Arrived	CR2	2017-07-25 12:46:00+03	2017-07-25 15:15:00+03
22487	PG0100	2017-08-15 12:45:00+03	2017-08-15 15:15:00+03	NYA	VKO	Arrived	CR2	2017-08-15 12:47:00+03	2017-08-15 15:20:00+03
22488	PG0100	2017-09-05 12:45:00+03	2017-09-05 15:15:00+03	NYA	VKO	Scheduled	CR2	\N	\N
22489	PG0100	2017-08-08 12:45:00+03	2017-08-08 15:15:00+03	NYA	VKO	Arrived	CR2	2017-08-08 12:51:00+03	2017-08-08 15:18:00+03
22490	PG0100	2017-08-01 12:45:00+03	2017-08-01 15:15:00+03	NYA	VKO	Arrived	CR2	2017-08-01 12:48:00+03	2017-08-01 15:18:00+03
22491	PG0100	2017-08-29 12:45:00+03	2017-08-29 15:15:00+03	NYA	VKO	Scheduled	CR2	\N	\N
22492	PG0100	2017-08-22 12:45:00+03	2017-08-22 15:15:00+03	NYA	VKO	Scheduled	CR2	\N	\N
22493	PG0644	2017-08-06 07:40:00+03	2017-08-06 10:10:00+03	NYA	SVO	Arrived	CR2	2017-08-06 07:44:00+03	2017-08-06 10:13:00+03
22494	PG0644	2017-08-27 07:40:00+03	2017-08-27 10:10:00+03	NYA	SVO	Scheduled	CR2	\N	\N
22495	PG0644	2017-09-03 07:40:00+03	2017-09-03 10:10:00+03	NYA	SVO	Scheduled	CR2	\N	\N
22496	PG0644	2017-09-10 07:40:00+03	2017-09-10 10:10:00+03	NYA	SVO	Cancelled	CR2	\N	\N
22497	PG0644	2017-08-20 07:40:00+03	2017-08-20 10:10:00+03	NYA	SVO	Scheduled	CR2	\N	\N
22498	PG0644	2017-07-30 07:40:00+03	2017-07-30 10:10:00+03	NYA	SVO	Arrived	CR2	2017-07-30 07:41:00+03	2017-07-30 10:11:00+03
22499	PG0644	2017-08-13 07:40:00+03	2017-08-13 10:10:00+03	NYA	SVO	Arrived	CR2	2017-08-13 07:41:00+03	2017-08-13 10:11:00+03
22500	PG0644	2017-07-16 07:40:00+03	2017-07-16 10:10:00+03	NYA	SVO	Arrived	CR2	2017-07-16 07:43:00+03	2017-07-16 10:15:00+03
22501	PG0644	2017-07-23 07:40:00+03	2017-07-23 10:10:00+03	NYA	SVO	Arrived	CR2	2017-07-23 07:40:00+03	2017-07-23 10:06:00+03
22502	PG0636	2017-08-21 13:10:00+03	2017-08-21 16:30:00+03	NYA	ROV	Scheduled	CR2	\N	\N
22503	PG0636	2017-09-04 13:10:00+03	2017-09-04 16:30:00+03	NYA	ROV	Scheduled	CR2	\N	\N
22504	PG0636	2017-07-24 13:10:00+03	2017-07-24 16:30:00+03	NYA	ROV	Arrived	CR2	2017-07-24 13:11:00+03	2017-07-24 16:27:00+03
22505	PG0636	2017-07-31 13:10:00+03	2017-07-31 16:30:00+03	NYA	ROV	Arrived	CR2	2017-07-31 13:13:00+03	2017-07-31 16:32:00+03
22506	PG0636	2017-08-14 13:10:00+03	2017-08-14 16:30:00+03	NYA	ROV	Arrived	CR2	2017-08-14 13:12:00+03	2017-08-14 16:31:00+03
22507	PG0636	2017-07-17 13:10:00+03	2017-07-17 16:30:00+03	NYA	ROV	Arrived	CR2	2017-07-17 13:12:00+03	2017-07-17 16:32:00+03
22508	PG0636	2017-08-28 13:10:00+03	2017-08-28 16:30:00+03	NYA	ROV	Scheduled	CR2	\N	\N
22509	PG0636	2017-08-07 13:10:00+03	2017-08-07 16:30:00+03	NYA	ROV	Arrived	CR2	2017-08-07 13:12:00+03	2017-08-07 16:31:00+03
22510	PG0636	2017-09-11 13:10:00+03	2017-09-11 16:30:00+03	NYA	ROV	Scheduled	CR2	\N	\N
22511	PG0544	2017-07-22 09:55:00+03	2017-07-22 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-22 09:59:00+03	2017-07-22 12:09:00+03
22512	PG0543	2017-07-22 07:45:00+03	2017-07-22 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-22 07:47:00+03	2017-07-22 09:57:00+03
22513	PG0543	2017-09-11 07:45:00+03	2017-09-11 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22514	PG0544	2017-09-11 09:55:00+03	2017-09-11 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22515	PG0543	2017-08-19 07:45:00+03	2017-08-19 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22516	PG0544	2017-08-19 09:55:00+03	2017-08-19 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22517	PG0544	2017-09-03 09:55:00+03	2017-09-03 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22518	PG0543	2017-09-03 07:45:00+03	2017-09-03 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22519	PG0544	2017-08-05 09:55:00+03	2017-08-05 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-05 09:59:00+03	2017-08-05 12:10:00+03
22520	PG0543	2017-08-05 07:45:00+03	2017-08-05 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-05 07:47:00+03	2017-08-05 09:55:00+03
22521	PG0543	2017-09-04 07:45:00+03	2017-09-04 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22522	PG0544	2017-09-04 09:55:00+03	2017-09-04 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22523	PG0544	2017-08-24 09:55:00+03	2017-08-24 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22524	PG0543	2017-08-24 07:45:00+03	2017-08-24 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22525	PG0543	2017-08-07 07:45:00+03	2017-08-07 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-07 07:47:00+03	2017-08-07 09:56:00+03
22526	PG0544	2017-08-07 09:55:00+03	2017-08-07 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-07 10:01:00+03	2017-08-07 12:12:00+03
22527	PG0543	2017-07-16 07:45:00+03	2017-07-16 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-16 07:49:00+03	2017-07-16 09:59:00+03
22528	PG0544	2017-07-16 09:55:00+03	2017-07-16 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-16 09:57:00+03	2017-07-16 12:07:00+03
22529	PG0544	2017-08-04 09:55:00+03	2017-08-04 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-04 09:57:00+03	2017-08-04 12:08:00+03
22530	PG0543	2017-08-04 07:45:00+03	2017-08-04 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-04 07:51:00+03	2017-08-04 10:03:00+03
22531	PG0543	2017-08-25 07:45:00+03	2017-08-25 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22532	PG0544	2017-08-25 09:55:00+03	2017-08-25 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22533	PG0544	2017-08-03 09:55:00+03	2017-08-03 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-03 10:00:00+03	2017-08-03 12:09:00+03
22534	PG0543	2017-08-03 07:45:00+03	2017-08-03 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-03 07:46:00+03	2017-08-03 09:56:00+03
22535	PG0543	2017-08-08 07:45:00+03	2017-08-08 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-08 07:49:00+03	2017-08-08 10:01:00+03
22536	PG0544	2017-08-08 09:55:00+03	2017-08-08 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-08 09:57:00+03	2017-08-08 12:05:00+03
22537	PG0544	2017-09-02 09:55:00+03	2017-09-02 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22538	PG0543	2017-09-02 07:45:00+03	2017-09-02 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22539	PG0543	2017-09-05 07:45:00+03	2017-09-05 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22540	PG0544	2017-09-05 09:55:00+03	2017-09-05 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22541	PG0544	2017-08-02 09:55:00+03	2017-08-02 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-02 09:57:00+03	2017-08-02 12:08:00+03
22542	PG0543	2017-08-02 07:45:00+03	2017-08-02 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-02 10:41:00+03	2017-08-02 12:50:00+03
22543	PG0543	2017-08-09 07:45:00+03	2017-08-09 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-09 07:49:00+03	2017-08-09 10:01:00+03
22544	PG0544	2017-08-09 09:55:00+03	2017-08-09 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-09 10:01:00+03	2017-08-09 12:13:00+03
22545	PG0544	2017-09-14 09:55:00+03	2017-09-14 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22546	PG0543	2017-09-14 07:45:00+03	2017-09-14 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22547	PG0544	2017-08-23 09:55:00+03	2017-08-23 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22548	PG0543	2017-08-23 07:45:00+03	2017-08-23 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22549	PG0543	2017-07-17 07:45:00+03	2017-07-17 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-17 07:50:00+03	2017-07-17 09:59:00+03
22550	PG0544	2017-07-17 09:55:00+03	2017-07-17 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-17 09:59:00+03	2017-07-17 12:09:00+03
22551	PG0544	2017-08-01 09:55:00+03	2017-08-01 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-01 09:56:00+03	2017-08-01 12:06:00+03
22552	PG0543	2017-08-01 07:45:00+03	2017-08-01 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-01 07:47:00+03	2017-08-01 09:57:00+03
22553	PG0543	2017-08-10 07:45:00+03	2017-08-10 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-10 07:46:00+03	2017-08-10 09:54:00+03
22554	PG0544	2017-08-10 09:55:00+03	2017-08-10 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-10 09:58:00+03	2017-08-10 12:06:00+03
22555	PG0544	2017-09-01 09:55:00+03	2017-09-01 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22556	PG0543	2017-09-01 07:45:00+03	2017-09-01 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22557	PG0543	2017-09-06 07:45:00+03	2017-09-06 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22558	PG0544	2017-09-06 09:55:00+03	2017-09-06 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22559	PG0544	2017-07-31 09:55:00+03	2017-07-31 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-31 09:57:00+03	2017-07-31 12:07:00+03
22560	PG0543	2017-07-31 07:45:00+03	2017-07-31 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-31 07:46:00+03	2017-07-31 09:56:00+03
22561	PG0543	2017-08-11 07:45:00+03	2017-08-11 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-11 07:49:00+03	2017-08-11 09:56:00+03
22562	PG0544	2017-08-11 09:55:00+03	2017-08-11 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-11 09:55:00+03	2017-08-11 12:06:00+03
22563	PG0544	2017-07-30 09:55:00+03	2017-07-30 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-30 10:03:00+03	2017-07-30 12:10:00+03
22564	PG0543	2017-07-30 07:45:00+03	2017-07-30 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-30 07:48:00+03	2017-07-30 09:59:00+03
22565	PG0543	2017-07-18 07:45:00+03	2017-07-18 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-18 07:49:00+03	2017-07-18 09:59:00+03
22566	PG0544	2017-07-18 09:55:00+03	2017-07-18 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-18 09:57:00+03	2017-07-18 12:07:00+03
22567	PG0544	2017-08-22 09:55:00+03	2017-08-22 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22568	PG0543	2017-08-22 07:45:00+03	2017-08-22 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22569	PG0544	2017-09-13 09:55:00+03	2017-09-13 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22570	PG0543	2017-09-13 07:45:00+03	2017-09-13 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22571	PG0543	2017-08-12 07:45:00+03	2017-08-12 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-12 07:47:00+03	2017-08-12 09:59:00+03
22572	PG0544	2017-08-12 09:55:00+03	2017-08-12 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-12 09:58:00+03	2017-08-12 12:12:00+03
22573	PG0544	2017-08-31 09:55:00+03	2017-08-31 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22574	PG0543	2017-08-31 07:45:00+03	2017-08-31 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22575	PG0543	2017-09-07 07:45:00+03	2017-09-07 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22576	PG0544	2017-09-07 09:55:00+03	2017-09-07 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22577	PG0543	2017-08-26 07:45:00+03	2017-08-26 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22578	PG0544	2017-08-26 09:55:00+03	2017-08-26 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22579	PG0544	2017-07-29 09:55:00+03	2017-07-29 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-29 13:21:00+03	2017-07-29 15:32:00+03
22580	PG0543	2017-07-29 07:45:00+03	2017-07-29 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-29 07:51:00+03	2017-07-29 10:02:00+03
22581	PG0543	2017-08-13 07:45:00+03	2017-08-13 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-13 07:47:00+03	2017-08-13 09:57:00+03
22582	PG0544	2017-08-13 09:55:00+03	2017-08-13 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-13 09:58:00+03	2017-08-13 12:07:00+03
22583	PG0544	2017-07-28 09:55:00+03	2017-07-28 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-28 09:59:00+03	2017-07-28 12:09:00+03
22584	PG0543	2017-07-28 07:45:00+03	2017-07-28 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-28 07:51:00+03	2017-07-28 10:02:00+03
22585	PG0543	2017-08-06 07:45:00+03	2017-08-06 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-06 07:48:00+03	2017-08-06 09:57:00+03
22586	PG0544	2017-08-06 09:55:00+03	2017-08-06 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-06 09:58:00+03	2017-08-06 12:08:00+03
22587	PG0543	2017-09-08 07:45:00+03	2017-09-08 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22588	PG0544	2017-09-08 09:55:00+03	2017-09-08 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22589	PG0543	2017-07-19 07:45:00+03	2017-07-19 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-19 07:48:00+03	2017-07-19 09:58:00+03
22590	PG0544	2017-07-19 09:55:00+03	2017-07-19 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-19 09:58:00+03	2017-07-19 12:07:00+03
22591	PG0543	2017-08-14 07:45:00+03	2017-08-14 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-14 07:50:00+03	2017-08-14 10:02:00+03
22592	PG0544	2017-08-14 09:55:00+03	2017-08-14 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-14 09:59:00+03	2017-08-14 12:10:00+03
22593	PG0544	2017-08-30 09:55:00+03	2017-08-30 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22594	PG0543	2017-08-30 07:45:00+03	2017-08-30 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22595	PG0544	2017-07-27 09:55:00+03	2017-07-27 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-27 09:59:00+03	2017-07-27 12:10:00+03
22596	PG0543	2017-07-27 07:45:00+03	2017-07-27 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-27 07:48:00+03	2017-07-27 10:00:00+03
22597	PG0544	2017-08-21 09:55:00+03	2017-08-21 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22598	PG0543	2017-08-21 07:45:00+03	2017-08-21 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22599	PG0543	2017-08-15 07:45:00+03	2017-08-15 09:55:00+03	OVS	DME	Arrived	SU9	2017-08-15 07:51:00+03	2017-08-15 09:59:00+03
22600	PG0544	2017-08-15 09:55:00+03	2017-08-15 12:05:00+03	OVS	DME	Arrived	SU9	2017-08-15 10:00:00+03	2017-08-15 12:10:00+03
22601	PG0544	2017-07-26 09:55:00+03	2017-07-26 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-26 09:58:00+03	2017-07-26 12:13:00+03
22602	PG0543	2017-07-26 07:45:00+03	2017-07-26 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-26 07:48:00+03	2017-07-26 10:00:00+03
22603	PG0543	2017-09-09 07:45:00+03	2017-09-09 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22604	PG0544	2017-09-09 09:55:00+03	2017-09-09 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22605	PG0544	2017-09-12 09:55:00+03	2017-09-12 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22606	PG0543	2017-09-12 07:45:00+03	2017-09-12 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22607	PG0543	2017-07-20 07:45:00+03	2017-07-20 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-20 07:49:00+03	2017-07-20 10:00:00+03
22608	PG0544	2017-08-29 09:55:00+03	2017-08-29 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22609	PG0544	2017-07-20 09:55:00+03	2017-07-20 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-20 09:59:00+03	2017-07-20 12:11:00+03
22610	PG0543	2017-08-29 07:45:00+03	2017-08-29 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22611	PG0544	2017-07-25 09:55:00+03	2017-07-25 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-25 09:58:00+03	2017-07-25 12:08:00+03
22612	PG0543	2017-08-16 07:45:00+03	2017-08-16 09:55:00+03	OVS	DME	On Time	SU9	\N	\N
22613	PG0544	2017-08-16 09:55:00+03	2017-08-16 12:05:00+03	OVS	DME	On Time	SU9	\N	\N
22614	PG0543	2017-07-25 07:45:00+03	2017-07-25 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-25 07:51:00+03	2017-07-25 10:00:00+03
22615	PG0544	2017-08-20 09:55:00+03	2017-08-20 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22616	PG0543	2017-08-20 07:45:00+03	2017-08-20 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22617	PG0544	2017-07-24 09:55:00+03	2017-07-24 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-24 09:57:00+03	2017-07-24 12:07:00+03
22618	PG0543	2017-07-24 07:45:00+03	2017-07-24 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-24 07:47:00+03	2017-07-24 09:56:00+03
22619	PG0543	2017-08-17 07:45:00+03	2017-08-17 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22620	PG0543	2017-08-27 07:45:00+03	2017-08-27 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22621	PG0544	2017-08-27 09:55:00+03	2017-08-27 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22622	PG0544	2017-08-17 09:55:00+03	2017-08-17 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22623	PG0543	2017-09-10 07:45:00+03	2017-09-10 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22624	PG0544	2017-09-10 09:55:00+03	2017-09-10 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22625	PG0543	2017-07-21 07:45:00+03	2017-07-21 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-21 07:52:00+03	2017-07-21 10:04:00+03
22626	PG0544	2017-07-21 09:55:00+03	2017-07-21 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-21 09:58:00+03	2017-07-21 12:07:00+03
22627	PG0544	2017-07-23 09:55:00+03	2017-07-23 12:05:00+03	OVS	DME	Arrived	SU9	2017-07-23 09:59:00+03	2017-07-23 12:09:00+03
22628	PG0543	2017-07-23 07:45:00+03	2017-07-23 09:55:00+03	OVS	DME	Arrived	SU9	2017-07-23 07:50:00+03	2017-07-23 10:01:00+03
22629	PG0544	2017-08-28 09:55:00+03	2017-08-28 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22630	PG0543	2017-08-28 07:45:00+03	2017-08-28 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22631	PG0543	2017-08-18 07:45:00+03	2017-08-18 09:55:00+03	OVS	DME	Scheduled	SU9	\N	\N
22632	PG0544	2017-08-18 09:55:00+03	2017-08-18 12:05:00+03	OVS	DME	Scheduled	SU9	\N	\N
22633	PG0090	2017-07-18 13:40:00+03	2017-07-18 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-18 13:42:00+03	2017-07-18 15:52:00+03
22634	PG0090	2017-08-04 13:40:00+03	2017-08-04 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-04 13:41:00+03	2017-08-04 15:50:00+03
22635	PG0090	2017-07-16 13:40:00+03	2017-07-16 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-16 13:43:00+03	2017-07-16 15:51:00+03
22636	PG0090	2017-08-17 13:40:00+03	2017-08-17 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22637	PG0090	2017-08-06 13:40:00+03	2017-08-06 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-06 13:44:00+03	2017-08-06 15:53:00+03
22638	PG0090	2017-07-24 13:40:00+03	2017-07-24 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-24 13:44:00+03	2017-07-24 15:53:00+03
22639	PG0090	2017-09-10 13:40:00+03	2017-09-10 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22640	PG0090	2017-08-26 13:40:00+03	2017-08-26 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22641	PG0090	2017-08-22 13:40:00+03	2017-08-22 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22642	PG0090	2017-08-29 13:40:00+03	2017-08-29 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22643	PG0090	2017-09-12 13:40:00+03	2017-09-12 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22644	PG0090	2017-08-31 13:40:00+03	2017-08-31 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22645	PG0090	2017-08-14 13:40:00+03	2017-08-14 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-14 17:14:00+03	2017-08-14 19:24:00+03
22646	PG0090	2017-09-13 13:40:00+03	2017-09-13 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22647	PG0090	2017-07-27 13:40:00+03	2017-07-27 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-27 13:41:00+03	2017-07-27 15:52:00+03
22648	PG0090	2017-08-03 13:40:00+03	2017-08-03 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-03 13:41:00+03	2017-08-03 15:50:00+03
22649	PG0090	2017-08-23 13:40:00+03	2017-08-23 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22650	PG0090	2017-07-26 13:40:00+03	2017-07-26 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-26 13:44:00+03	2017-07-26 15:52:00+03
22651	PG0090	2017-08-16 13:40:00+03	2017-08-16 15:50:00+03	OVS	SVO	On Time	SU9	\N	\N
22652	PG0090	2017-08-28 13:40:00+03	2017-08-28 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22653	PG0090	2017-09-09 13:40:00+03	2017-09-09 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22654	PG0090	2017-09-04 13:40:00+03	2017-09-04 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22655	PG0090	2017-09-06 13:40:00+03	2017-09-06 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22656	PG0090	2017-07-31 13:40:00+03	2017-07-31 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-31 13:44:00+03	2017-07-31 15:54:00+03
22657	PG0090	2017-08-21 13:40:00+03	2017-08-21 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22658	PG0090	2017-08-13 13:40:00+03	2017-08-13 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-13 17:06:00+03	2017-08-13 19:18:00+03
22659	PG0090	2017-07-22 13:40:00+03	2017-07-22 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-22 13:41:00+03	2017-07-22 15:52:00+03
22660	PG0090	2017-08-09 13:40:00+03	2017-08-09 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-09 13:43:00+03	2017-08-09 15:52:00+03
22661	PG0090	2017-08-20 13:40:00+03	2017-08-20 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22662	PG0090	2017-09-01 13:40:00+03	2017-09-01 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22663	PG0090	2017-07-17 13:40:00+03	2017-07-17 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-17 13:41:00+03	2017-07-17 15:50:00+03
22664	PG0090	2017-08-12 13:40:00+03	2017-08-12 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-12 13:44:00+03	2017-08-12 15:55:00+03
22665	PG0090	2017-08-05 13:40:00+03	2017-08-05 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-05 13:44:00+03	2017-08-05 15:53:00+03
22666	PG0090	2017-07-19 13:40:00+03	2017-07-19 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-19 13:41:00+03	2017-07-19 15:49:00+03
22667	PG0090	2017-07-21 13:40:00+03	2017-07-21 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-21 13:41:00+03	2017-07-21 15:52:00+03
22668	PG0090	2017-08-18 13:40:00+03	2017-08-18 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22669	PG0090	2017-09-08 13:40:00+03	2017-09-08 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22670	PG0090	2017-08-08 13:40:00+03	2017-08-08 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-08 13:41:00+03	2017-08-08 15:50:00+03
22671	PG0090	2017-09-07 13:40:00+03	2017-09-07 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22672	PG0090	2017-08-10 13:40:00+03	2017-08-10 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-10 13:45:00+03	2017-08-10 15:53:00+03
22673	PG0090	2017-08-02 13:40:00+03	2017-08-02 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-02 13:41:00+03	2017-08-02 15:50:00+03
22674	PG0090	2017-08-11 13:40:00+03	2017-08-11 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-11 13:43:00+03	2017-08-11 15:52:00+03
22675	PG0090	2017-08-19 13:40:00+03	2017-08-19 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22676	PG0090	2017-08-25 13:40:00+03	2017-08-25 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22677	PG0090	2017-09-05 13:40:00+03	2017-09-05 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22678	PG0090	2017-07-30 13:40:00+03	2017-07-30 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-30 13:41:00+03	2017-07-30 15:51:00+03
22679	PG0090	2017-08-01 13:40:00+03	2017-08-01 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-01 13:40:00+03	2017-08-01 15:52:00+03
22680	PG0090	2017-09-14 13:40:00+03	2017-09-14 15:50:00+03	OVS	SVO	Cancelled	SU9	\N	\N
22681	PG0090	2017-07-23 13:40:00+03	2017-07-23 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-23 17:12:00+03	2017-07-23 19:22:00+03
22682	PG0090	2017-08-30 13:40:00+03	2017-08-30 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22683	PG0090	2017-08-27 13:40:00+03	2017-08-27 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22684	PG0090	2017-08-07 13:40:00+03	2017-08-07 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-07 13:44:00+03	2017-08-07 15:54:00+03
22685	PG0090	2017-07-29 13:40:00+03	2017-07-29 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-29 13:40:00+03	2017-07-29 15:52:00+03
22686	PG0090	2017-09-11 13:40:00+03	2017-09-11 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22687	PG0090	2017-07-20 13:40:00+03	2017-07-20 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-20 13:41:00+03	2017-07-20 15:49:00+03
22688	PG0090	2017-09-03 13:40:00+03	2017-09-03 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22689	PG0090	2017-07-28 13:40:00+03	2017-07-28 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-28 13:41:00+03	2017-07-28 15:50:00+03
22690	PG0090	2017-07-25 13:40:00+03	2017-07-25 15:50:00+03	OVS	SVO	Arrived	SU9	2017-07-25 13:41:00+03	2017-07-25 15:52:00+03
22691	PG0090	2017-09-02 13:40:00+03	2017-09-02 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22692	PG0090	2017-08-24 13:40:00+03	2017-08-24 15:50:00+03	OVS	SVO	Scheduled	SU9	\N	\N
22693	PG0090	2017-08-15 13:40:00+03	2017-08-15 15:50:00+03	OVS	SVO	Arrived	SU9	2017-08-15 13:42:00+03	2017-08-15 15:53:00+03
22694	PG0686	2017-08-01 17:00:00+03	2017-08-01 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-01 17:03:00+03	2017-08-01 19:38:00+03
22695	PG0686	2017-07-28 17:00:00+03	2017-07-28 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-28 20:03:00+03	2017-07-28 22:42:00+03
22696	PG0686	2017-08-19 17:00:00+03	2017-08-19 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22697	PG0686	2017-08-05 17:00:00+03	2017-08-05 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-05 19:48:00+03	2017-08-05 22:23:00+03
22698	PG0686	2017-08-28 17:00:00+03	2017-08-28 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22699	PG0686	2017-07-23 17:00:00+03	2017-07-23 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-23 17:07:00+03	2017-07-23 19:43:00+03
22700	PG0686	2017-08-20 17:00:00+03	2017-08-20 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22701	PG0686	2017-09-11 17:00:00+03	2017-09-11 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22702	PG0686	2017-08-18 17:00:00+03	2017-08-18 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22703	PG0686	2017-08-26 17:00:00+03	2017-08-26 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22704	PG0686	2017-08-21 17:00:00+03	2017-08-21 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22705	PG0686	2017-08-30 17:00:00+03	2017-08-30 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22706	PG0686	2017-09-03 17:00:00+03	2017-09-03 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22707	PG0686	2017-08-13 17:00:00+03	2017-08-13 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-13 17:01:00+03	2017-08-13 19:36:00+03
22708	PG0686	2017-09-04 17:00:00+03	2017-09-04 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22709	PG0686	2017-07-24 17:00:00+03	2017-07-24 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-24 17:03:00+03	2017-07-24 19:36:00+03
22710	PG0686	2017-07-21 17:00:00+03	2017-07-21 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-21 17:01:00+03	2017-07-21 19:36:00+03
22711	PG0686	2017-09-14 17:00:00+03	2017-09-14 19:35:00+03	OVS	LED	Cancelled	CR2	\N	\N
22712	PG0686	2017-09-08 17:00:00+03	2017-09-08 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22713	PG0686	2017-08-03 17:00:00+03	2017-08-03 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-03 17:01:00+03	2017-08-03 19:36:00+03
22714	PG0686	2017-07-25 17:00:00+03	2017-07-25 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-25 17:06:00+03	2017-07-25 19:43:00+03
22715	PG0686	2017-08-16 17:00:00+03	2017-08-16 19:35:00+03	OVS	LED	On Time	CR2	\N	\N
22716	PG0686	2017-08-04 17:00:00+03	2017-08-04 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-04 17:02:00+03	2017-08-04 19:35:00+03
22717	PG0686	2017-09-01 17:00:00+03	2017-09-01 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22718	PG0686	2017-09-02 17:00:00+03	2017-09-02 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22719	PG0686	2017-08-24 17:00:00+03	2017-08-24 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22720	PG0686	2017-08-25 17:00:00+03	2017-08-25 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22721	PG0686	2017-07-16 17:00:00+03	2017-07-16 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-16 17:05:00+03	2017-07-16 19:40:00+03
22722	PG0686	2017-09-10 17:00:00+03	2017-09-10 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22723	PG0686	2017-07-31 17:00:00+03	2017-07-31 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-31 17:02:00+03	2017-07-31 19:39:00+03
22724	PG0686	2017-07-29 17:00:00+03	2017-07-29 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-29 17:03:00+03	2017-07-29 19:37:00+03
22725	PG0686	2017-08-02 17:00:00+03	2017-08-02 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-02 17:02:00+03	2017-08-02 19:38:00+03
22726	PG0686	2017-08-23 17:00:00+03	2017-08-23 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22727	PG0686	2017-09-13 17:00:00+03	2017-09-13 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22728	PG0686	2017-08-15 17:00:00+03	2017-08-15 19:35:00+03	OVS	LED	Delayed	CR2	\N	\N
22729	PG0686	2017-09-09 17:00:00+03	2017-09-09 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22730	PG0686	2017-08-08 17:00:00+03	2017-08-08 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-08 17:03:00+03	2017-08-08 19:37:00+03
22731	PG0686	2017-07-19 17:00:00+03	2017-07-19 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-19 17:03:00+03	2017-07-19 19:38:00+03
22732	PG0686	2017-08-06 17:00:00+03	2017-08-06 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-06 17:01:00+03	2017-08-06 19:36:00+03
22733	PG0686	2017-08-29 17:00:00+03	2017-08-29 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22734	PG0686	2017-08-17 17:00:00+03	2017-08-17 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22735	PG0686	2017-08-22 17:00:00+03	2017-08-22 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22736	PG0686	2017-07-30 17:00:00+03	2017-07-30 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-30 17:03:00+03	2017-07-30 19:38:00+03
22737	PG0686	2017-08-10 17:00:00+03	2017-08-10 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-10 17:05:00+03	2017-08-10 19:38:00+03
22738	PG0686	2017-07-27 17:00:00+03	2017-07-27 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-27 17:00:00+03	2017-07-27 19:34:00+03
22739	PG0686	2017-07-22 17:00:00+03	2017-07-22 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-22 17:01:00+03	2017-07-22 19:36:00+03
22740	PG0686	2017-09-07 17:00:00+03	2017-09-07 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22741	PG0686	2017-08-14 17:00:00+03	2017-08-14 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-14 17:02:00+03	2017-08-14 19:36:00+03
22742	PG0686	2017-08-07 17:00:00+03	2017-08-07 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-07 17:05:00+03	2017-08-07 19:38:00+03
22743	PG0686	2017-07-20 17:00:00+03	2017-07-20 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-20 17:02:00+03	2017-07-20 19:36:00+03
22744	PG0686	2017-08-12 17:00:00+03	2017-08-12 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-12 17:01:00+03	2017-08-12 19:35:00+03
22745	PG0686	2017-07-17 17:00:00+03	2017-07-17 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-17 17:02:00+03	2017-07-17 19:40:00+03
22746	PG0686	2017-09-12 17:00:00+03	2017-09-12 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22747	PG0686	2017-08-27 17:00:00+03	2017-08-27 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22748	PG0686	2017-08-31 17:00:00+03	2017-08-31 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22749	PG0686	2017-09-06 17:00:00+03	2017-09-06 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22750	PG0686	2017-07-18 17:00:00+03	2017-07-18 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-18 20:40:00+03	2017-07-18 23:13:00+03
22751	PG0686	2017-08-11 17:00:00+03	2017-08-11 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-11 17:01:00+03	2017-08-11 19:38:00+03
22752	PG0686	2017-08-09 17:00:00+03	2017-08-09 19:35:00+03	OVS	LED	Arrived	CR2	2017-08-09 17:02:00+03	2017-08-09 19:36:00+03
22753	PG0686	2017-09-05 17:00:00+03	2017-09-05 19:35:00+03	OVS	LED	Scheduled	CR2	\N	\N
22754	PG0686	2017-07-26 17:00:00+03	2017-07-26 19:35:00+03	OVS	LED	Arrived	CR2	2017-07-26 17:05:00+03	2017-07-26 19:41:00+03
22755	PG0568	2017-09-11 16:15:00+03	2017-09-11 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22756	PG0568	2017-08-12 16:15:00+03	2017-08-12 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-12 16:18:00+03	2017-08-12 17:34:00+03
22757	PG0568	2017-08-02 16:15:00+03	2017-08-02 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-02 16:18:00+03	2017-08-02 17:33:00+03
22758	PG0568	2017-07-30 16:15:00+03	2017-07-30 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-30 16:20:00+03	2017-07-30 17:34:00+03
22759	PG0568	2017-09-05 16:15:00+03	2017-09-05 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22760	PG0568	2017-08-15 16:15:00+03	2017-08-15 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-15 16:17:00+03	2017-08-15 17:30:00+03
22761	PG0568	2017-07-26 16:15:00+03	2017-07-26 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-26 16:19:00+03	2017-07-26 17:34:00+03
22762	PG0568	2017-09-10 16:15:00+03	2017-09-10 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22763	PG0568	2017-08-27 16:15:00+03	2017-08-27 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22764	PG0568	2017-08-04 16:15:00+03	2017-08-04 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-04 16:22:00+03	2017-08-04 17:37:00+03
22765	PG0568	2017-07-23 16:15:00+03	2017-07-23 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-23 16:21:00+03	2017-07-23 17:38:00+03
22766	PG0568	2017-08-17 16:15:00+03	2017-08-17 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22767	PG0568	2017-07-29 16:15:00+03	2017-07-29 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-29 16:18:00+03	2017-07-29 17:33:00+03
22768	PG0568	2017-08-28 16:15:00+03	2017-08-28 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22769	PG0568	2017-07-31 16:15:00+03	2017-07-31 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-31 16:18:00+03	2017-07-31 17:34:00+03
22770	PG0568	2017-08-11 16:15:00+03	2017-08-11 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-11 16:16:00+03	2017-08-11 17:31:00+03
22771	PG0568	2017-09-03 16:15:00+03	2017-09-03 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22772	PG0568	2017-07-24 16:15:00+03	2017-07-24 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-24 16:18:00+03	2017-07-24 17:35:00+03
22773	PG0568	2017-07-16 16:15:00+03	2017-07-16 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-16 16:19:00+03	2017-07-16 17:34:00+03
22774	PG0568	2017-09-06 16:15:00+03	2017-09-06 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22775	PG0568	2017-08-20 16:15:00+03	2017-08-20 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22776	PG0568	2017-08-25 16:15:00+03	2017-08-25 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22777	PG0568	2017-09-14 16:15:00+03	2017-09-14 17:30:00+03	OVS	UFA	Cancelled	CR2	\N	\N
22778	PG0568	2017-08-13 16:15:00+03	2017-08-13 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-13 20:35:00+03	2017-08-13 21:49:00+03
22779	PG0568	2017-07-18 16:15:00+03	2017-07-18 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-18 16:16:00+03	2017-07-18 17:31:00+03
22780	PG0568	2017-09-01 16:15:00+03	2017-09-01 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22781	PG0568	2017-07-22 16:15:00+03	2017-07-22 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-22 16:17:00+03	2017-07-22 17:32:00+03
22782	PG0568	2017-09-07 16:15:00+03	2017-09-07 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22783	PG0568	2017-08-31 16:15:00+03	2017-08-31 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22784	PG0568	2017-08-10 16:15:00+03	2017-08-10 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-10 16:19:00+03	2017-08-10 17:33:00+03
22785	PG0568	2017-08-06 16:15:00+03	2017-08-06 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-06 16:20:00+03	2017-08-06 17:36:00+03
22786	PG0568	2017-07-28 16:15:00+03	2017-07-28 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-28 16:16:00+03	2017-07-28 17:29:00+03
22787	PG0568	2017-08-24 16:15:00+03	2017-08-24 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22788	PG0568	2017-08-05 16:15:00+03	2017-08-05 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-05 16:17:00+03	2017-08-05 17:33:00+03
22789	PG0568	2017-08-01 16:15:00+03	2017-08-01 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-01 16:21:00+03	2017-08-01 17:37:00+03
22790	PG0568	2017-08-16 16:15:00+03	2017-08-16 17:30:00+03	OVS	UFA	On Time	CR2	\N	\N
22791	PG0568	2017-07-25 16:15:00+03	2017-07-25 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-25 16:21:00+03	2017-07-25 17:37:00+03
22792	PG0568	2017-08-18 16:15:00+03	2017-08-18 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22793	PG0568	2017-08-03 16:15:00+03	2017-08-03 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-03 16:19:00+03	2017-08-03 17:33:00+03
22794	PG0568	2017-09-08 16:15:00+03	2017-09-08 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22795	PG0568	2017-09-13 16:15:00+03	2017-09-13 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22796	PG0568	2017-07-20 16:15:00+03	2017-07-20 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-20 16:16:00+03	2017-07-20 17:31:00+03
22797	PG0568	2017-09-04 16:15:00+03	2017-09-04 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22798	PG0568	2017-08-29 16:15:00+03	2017-08-29 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22799	PG0568	2017-08-30 16:15:00+03	2017-08-30 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22800	PG0568	2017-08-19 16:15:00+03	2017-08-19 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22801	PG0568	2017-07-19 16:15:00+03	2017-07-19 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-19 16:16:00+03	2017-07-19 17:32:00+03
22802	PG0568	2017-07-17 16:15:00+03	2017-07-17 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-17 16:17:00+03	2017-07-17 17:34:00+03
22803	PG0568	2017-08-08 16:15:00+03	2017-08-08 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-08 19:52:00+03	2017-08-08 21:07:00+03
22804	PG0568	2017-08-14 16:15:00+03	2017-08-14 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-14 16:20:00+03	2017-08-14 17:35:00+03
22805	PG0568	2017-09-02 16:15:00+03	2017-09-02 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22806	PG0568	2017-07-27 16:15:00+03	2017-07-27 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-27 16:19:00+03	2017-07-27 17:34:00+03
22807	PG0568	2017-08-21 16:15:00+03	2017-08-21 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22808	PG0568	2017-08-23 16:15:00+03	2017-08-23 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22809	PG0568	2017-08-22 16:15:00+03	2017-08-22 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22810	PG0568	2017-08-26 16:15:00+03	2017-08-26 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22811	PG0568	2017-09-12 16:15:00+03	2017-09-12 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22812	PG0568	2017-08-09 16:15:00+03	2017-08-09 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-09 16:19:00+03	2017-08-09 17:35:00+03
22813	PG0568	2017-09-09 16:15:00+03	2017-09-09 17:30:00+03	OVS	UFA	Scheduled	CR2	\N	\N
22814	PG0568	2017-08-07 16:15:00+03	2017-08-07 17:30:00+03	OVS	UFA	Arrived	CR2	2017-08-07 16:18:00+03	2017-08-07 17:33:00+03
22815	PG0568	2017-07-21 16:15:00+03	2017-07-21 17:30:00+03	OVS	UFA	Arrived	CR2	2017-07-21 16:23:00+03	2017-07-21 17:37:00+03
22816	PG0690	2017-08-29 11:25:00+03	2017-08-29 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22817	PG0690	2017-08-15 11:25:00+03	2017-08-15 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-15 11:29:00+03	2017-08-15 13:51:00+03
22818	PG0690	2017-07-21 11:25:00+03	2017-07-21 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-21 14:45:00+03	2017-07-21 17:03:00+03
22819	PG0690	2017-07-22 11:25:00+03	2017-07-22 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-22 11:26:00+03	2017-07-22 13:44:00+03
22820	PG0690	2017-07-28 11:25:00+03	2017-07-28 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-28 11:27:00+03	2017-07-28 13:46:00+03
22821	PG0690	2017-09-10 11:25:00+03	2017-09-10 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22822	PG0690	2017-08-20 11:25:00+03	2017-08-20 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22823	PG0690	2017-08-21 11:25:00+03	2017-08-21 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22824	PG0690	2017-07-17 11:25:00+03	2017-07-17 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-17 14:33:00+03	2017-07-17 16:55:00+03
22825	PG0690	2017-08-04 11:25:00+03	2017-08-04 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-04 11:25:00+03	2017-08-04 13:43:00+03
22826	PG0690	2017-08-01 11:25:00+03	2017-08-01 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-01 11:26:00+03	2017-08-01 13:47:00+03
22827	PG0690	2017-08-06 11:25:00+03	2017-08-06 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-06 11:27:00+03	2017-08-06 13:47:00+03
22828	PG0690	2017-07-20 11:25:00+03	2017-07-20 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-20 14:57:00+03	2017-07-20 17:16:00+03
22829	PG0690	2017-08-22 11:25:00+03	2017-08-22 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22830	PG0690	2017-07-27 11:25:00+03	2017-07-27 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-27 14:33:00+03	2017-07-27 16:54:00+03
22831	PG0690	2017-08-24 11:25:00+03	2017-08-24 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22832	PG0690	2017-08-10 11:25:00+03	2017-08-10 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-10 11:29:00+03	2017-08-10 13:50:00+03
22833	PG0690	2017-09-12 11:25:00+03	2017-09-12 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22834	PG0690	2017-07-29 11:25:00+03	2017-07-29 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-29 11:25:00+03	2017-07-29 13:49:00+03
22835	PG0690	2017-07-24 11:25:00+03	2017-07-24 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-24 14:44:00+03	2017-07-24 17:04:00+03
22836	PG0690	2017-09-14 11:25:00+03	2017-09-14 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22837	PG0690	2017-09-13 11:25:00+03	2017-09-13 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22838	PG0690	2017-08-31 11:25:00+03	2017-08-31 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22839	PG0690	2017-09-05 11:25:00+03	2017-09-05 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22840	PG0690	2017-07-31 11:25:00+03	2017-07-31 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-31 11:30:00+03	2017-07-31 13:50:00+03
22841	PG0690	2017-09-09 11:25:00+03	2017-09-09 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22842	PG0690	2017-09-08 11:25:00+03	2017-09-08 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22843	PG0690	2017-08-17 11:25:00+03	2017-08-17 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22844	PG0690	2017-09-04 11:25:00+03	2017-09-04 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22845	PG0690	2017-07-25 11:25:00+03	2017-07-25 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-25 11:31:00+03	2017-07-25 13:50:00+03
22846	PG0690	2017-07-30 11:25:00+03	2017-07-30 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-30 11:28:00+03	2017-07-30 13:46:00+03
22847	PG0690	2017-08-09 11:25:00+03	2017-08-09 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-09 11:28:00+03	2017-08-09 13:48:00+03
22848	PG0690	2017-08-05 11:25:00+03	2017-08-05 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-05 11:28:00+03	2017-08-05 13:48:00+03
22849	PG0690	2017-09-07 11:25:00+03	2017-09-07 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22850	PG0690	2017-09-06 11:25:00+03	2017-09-06 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22851	PG0690	2017-08-07 11:25:00+03	2017-08-07 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-07 11:27:00+03	2017-08-07 13:47:00+03
22852	PG0690	2017-08-02 11:25:00+03	2017-08-02 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-02 11:29:00+03	2017-08-02 13:49:00+03
22853	PG0690	2017-07-18 11:25:00+03	2017-07-18 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-18 11:28:00+03	2017-07-18 13:46:00+03
22854	PG0690	2017-07-26 11:25:00+03	2017-07-26 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-26 11:29:00+03	2017-07-26 13:50:00+03
22855	PG0690	2017-08-14 11:25:00+03	2017-08-14 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-14 11:30:00+03	2017-08-14 13:51:00+03
22856	PG0690	2017-07-19 11:25:00+03	2017-07-19 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-19 11:29:00+03	2017-07-19 13:49:00+03
22857	PG0690	2017-08-08 11:25:00+03	2017-08-08 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-08 11:26:00+03	2017-08-08 13:48:00+03
22858	PG0690	2017-08-16 11:25:00+03	2017-08-16 13:45:00+03	OVS	KJA	On Time	SU9	\N	\N
22859	PG0690	2017-09-02 11:25:00+03	2017-09-02 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22860	PG0690	2017-08-12 11:25:00+03	2017-08-12 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-12 11:27:00+03	2017-08-12 13:46:00+03
22861	PG0690	2017-09-01 11:25:00+03	2017-09-01 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22862	PG0690	2017-09-03 11:25:00+03	2017-09-03 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22863	PG0690	2017-08-27 11:25:00+03	2017-08-27 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22864	PG0690	2017-08-23 11:25:00+03	2017-08-23 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22865	PG0690	2017-07-16 11:25:00+03	2017-07-16 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-16 11:28:00+03	2017-07-16 13:49:00+03
22866	PG0690	2017-08-11 11:25:00+03	2017-08-11 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-11 11:27:00+03	2017-08-11 13:48:00+03
22867	PG0690	2017-08-28 11:25:00+03	2017-08-28 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22868	PG0690	2017-08-25 11:25:00+03	2017-08-25 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22869	PG0690	2017-08-13 11:25:00+03	2017-08-13 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-13 11:26:00+03	2017-08-13 13:47:00+03
22870	PG0690	2017-08-03 11:25:00+03	2017-08-03 13:45:00+03	OVS	KJA	Arrived	SU9	2017-08-03 11:30:00+03	2017-08-03 13:51:00+03
22871	PG0690	2017-08-30 11:25:00+03	2017-08-30 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22872	PG0690	2017-08-19 11:25:00+03	2017-08-19 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22873	PG0690	2017-07-23 11:25:00+03	2017-07-23 13:45:00+03	OVS	KJA	Arrived	SU9	2017-07-23 11:27:00+03	2017-07-23 13:48:00+03
22874	PG0690	2017-08-26 11:25:00+03	2017-08-26 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22875	PG0690	2017-08-18 11:25:00+03	2017-08-18 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22876	PG0690	2017-09-11 11:25:00+03	2017-09-11 13:45:00+03	OVS	KJA	Scheduled	SU9	\N	\N
22877	PG0642	2017-08-03 14:45:00+03	2017-08-03 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-03 18:01:00+03	2017-08-03 19:01:00+03
22878	PG0642	2017-07-19 14:45:00+03	2017-07-19 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-19 14:48:00+03	2017-07-19 15:48:00+03
22879	PG0642	2017-08-31 14:45:00+03	2017-08-31 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22880	PG0642	2017-08-13 14:45:00+03	2017-08-13 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-13 14:48:00+03	2017-08-13 15:49:00+03
22881	PG0642	2017-09-10 14:45:00+03	2017-09-10 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22882	PG0642	2017-09-12 14:45:00+03	2017-09-12 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22883	PG0642	2017-09-02 14:45:00+03	2017-09-02 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22884	PG0642	2017-08-15 14:45:00+03	2017-08-15 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-15 14:49:00+03	2017-08-15 15:49:00+03
22885	PG0642	2017-08-12 14:45:00+03	2017-08-12 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-12 14:48:00+03	2017-08-12 15:49:00+03
22886	PG0642	2017-08-17 14:45:00+03	2017-08-17 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22887	PG0642	2017-08-30 14:45:00+03	2017-08-30 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22888	PG0642	2017-09-05 14:45:00+03	2017-09-05 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22889	PG0642	2017-08-02 14:45:00+03	2017-08-02 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-02 14:49:00+03	2017-08-02 15:49:00+03
22890	PG0642	2017-09-01 14:45:00+03	2017-09-01 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22891	PG0642	2017-07-26 14:45:00+03	2017-07-26 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-26 14:47:00+03	2017-07-26 15:47:00+03
22892	PG0642	2017-08-01 14:45:00+03	2017-08-01 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-01 14:49:00+03	2017-08-01 15:49:00+03
22893	PG0642	2017-08-08 14:45:00+03	2017-08-08 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-08 14:50:00+03	2017-08-08 15:50:00+03
22894	PG0642	2017-07-16 14:45:00+03	2017-07-16 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-16 14:47:00+03	2017-07-16 15:46:00+03
22895	PG0642	2017-08-16 14:45:00+03	2017-08-16 15:45:00+03	OVS	NJC	On Time	CR2	\N	\N
22896	PG0642	2017-08-06 14:45:00+03	2017-08-06 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-06 14:49:00+03	2017-08-06 15:48:00+03
22897	PG0642	2017-07-21 14:45:00+03	2017-07-21 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-21 14:46:00+03	2017-07-21 15:45:00+03
22898	PG0642	2017-08-20 14:45:00+03	2017-08-20 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22899	PG0642	2017-08-10 14:45:00+03	2017-08-10 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-10 14:49:00+03	2017-08-10 15:48:00+03
22900	PG0642	2017-08-25 14:45:00+03	2017-08-25 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22901	PG0642	2017-08-29 14:45:00+03	2017-08-29 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22902	PG0642	2017-08-14 14:45:00+03	2017-08-14 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-14 14:51:00+03	2017-08-14 15:51:00+03
22903	PG0642	2017-09-09 14:45:00+03	2017-09-09 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22904	PG0642	2017-09-11 14:45:00+03	2017-09-11 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22905	PG0642	2017-09-08 14:45:00+03	2017-09-08 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22906	PG0642	2017-07-18 14:45:00+03	2017-07-18 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-18 14:50:00+03	2017-07-18 15:50:00+03
22907	PG0642	2017-07-17 14:45:00+03	2017-07-17 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-17 14:47:00+03	2017-07-17 15:46:00+03
22908	PG0642	2017-09-14 14:45:00+03	2017-09-14 15:45:00+03	OVS	NJC	Cancelled	CR2	\N	\N
22909	PG0642	2017-09-07 14:45:00+03	2017-09-07 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22910	PG0642	2017-07-25 14:45:00+03	2017-07-25 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-25 14:49:00+03	2017-07-25 15:49:00+03
22911	PG0642	2017-08-26 14:45:00+03	2017-08-26 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22912	PG0642	2017-09-13 14:45:00+03	2017-09-13 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22913	PG0642	2017-08-19 14:45:00+03	2017-08-19 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22914	PG0642	2017-07-22 14:45:00+03	2017-07-22 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-22 14:47:00+03	2017-07-22 15:47:00+03
22915	PG0642	2017-07-27 14:45:00+03	2017-07-27 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-27 14:50:00+03	2017-07-27 15:50:00+03
22916	PG0642	2017-08-05 14:45:00+03	2017-08-05 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-05 14:46:00+03	2017-08-05 15:46:00+03
22917	PG0642	2017-07-24 14:45:00+03	2017-07-24 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-24 14:48:00+03	2017-07-24 15:48:00+03
22918	PG0642	2017-08-21 14:45:00+03	2017-08-21 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22919	PG0642	2017-08-22 14:45:00+03	2017-08-22 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22920	PG0642	2017-08-28 14:45:00+03	2017-08-28 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22921	PG0642	2017-07-23 14:45:00+03	2017-07-23 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-23 14:48:00+03	2017-07-23 15:48:00+03
22922	PG0642	2017-09-03 14:45:00+03	2017-09-03 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22923	PG0642	2017-07-29 14:45:00+03	2017-07-29 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-29 14:45:00+03	2017-07-29 15:45:00+03
22924	PG0642	2017-08-09 14:45:00+03	2017-08-09 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-09 14:48:00+03	2017-08-09 15:48:00+03
22925	PG0642	2017-08-07 14:45:00+03	2017-08-07 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-07 14:47:00+03	2017-08-07 15:47:00+03
22926	PG0642	2017-08-27 14:45:00+03	2017-08-27 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22927	PG0642	2017-08-24 14:45:00+03	2017-08-24 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22928	PG0642	2017-09-04 14:45:00+03	2017-09-04 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22929	PG0642	2017-08-18 14:45:00+03	2017-08-18 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22930	PG0642	2017-07-20 14:45:00+03	2017-07-20 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-20 14:48:00+03	2017-07-20 15:48:00+03
22931	PG0642	2017-08-04 14:45:00+03	2017-08-04 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-04 14:48:00+03	2017-08-04 15:48:00+03
22932	PG0642	2017-07-28 14:45:00+03	2017-07-28 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-28 14:47:00+03	2017-07-28 15:48:00+03
22933	PG0642	2017-07-31 14:45:00+03	2017-07-31 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-31 14:45:00+03	2017-07-31 15:45:00+03
22934	PG0642	2017-07-30 14:45:00+03	2017-07-30 15:45:00+03	OVS	NJC	Arrived	CR2	2017-07-30 14:47:00+03	2017-07-30 15:47:00+03
22935	PG0642	2017-08-11 14:45:00+03	2017-08-11 15:45:00+03	OVS	NJC	Arrived	CR2	2017-08-11 14:48:00+03	2017-08-11 15:48:00+03
22936	PG0642	2017-08-23 14:45:00+03	2017-08-23 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22937	PG0642	2017-09-06 14:45:00+03	2017-09-06 15:45:00+03	OVS	NJC	Scheduled	CR2	\N	\N
22938	PG0444	2017-07-18 12:30:00+03	2017-07-18 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-18 12:34:00+03	2017-07-18 14:05:00+03
22939	PG0444	2017-08-05 12:30:00+03	2017-08-05 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-05 12:33:00+03	2017-08-05 14:04:00+03
22940	PG0444	2017-08-07 12:30:00+03	2017-08-07 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-07 12:33:00+03	2017-08-07 14:02:00+03
22941	PG0444	2017-08-25 12:30:00+03	2017-08-25 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22942	PG0444	2017-07-21 12:30:00+03	2017-07-21 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-21 12:33:00+03	2017-07-21 14:04:00+03
22943	PG0444	2017-09-04 12:30:00+03	2017-09-04 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22944	PG0444	2017-09-03 12:30:00+03	2017-09-03 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22945	PG0444	2017-09-13 12:30:00+03	2017-09-13 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22946	PG0444	2017-07-29 12:30:00+03	2017-07-29 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-29 12:35:00+03	2017-07-29 14:04:00+03
22947	PG0444	2017-09-01 12:30:00+03	2017-09-01 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22948	PG0444	2017-08-13 12:30:00+03	2017-08-13 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-13 12:30:00+03	2017-08-13 14:00:00+03
22949	PG0444	2017-08-22 12:30:00+03	2017-08-22 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22950	PG0444	2017-09-07 12:30:00+03	2017-09-07 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22951	PG0444	2017-09-06 12:30:00+03	2017-09-06 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22952	PG0444	2017-08-10 12:30:00+03	2017-08-10 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-10 12:31:00+03	2017-08-10 14:01:00+03
22953	PG0444	2017-08-01 12:30:00+03	2017-08-01 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-01 12:32:00+03	2017-08-01 14:02:00+03
22954	PG0444	2017-08-12 12:30:00+03	2017-08-12 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-12 12:33:00+03	2017-08-12 14:04:00+03
22955	PG0444	2017-09-08 12:30:00+03	2017-09-08 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22956	PG0444	2017-07-28 12:30:00+03	2017-07-28 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-28 12:33:00+03	2017-07-28 14:04:00+03
22957	PG0444	2017-08-28 12:30:00+03	2017-08-28 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22958	PG0444	2017-07-19 12:30:00+03	2017-07-19 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-19 12:32:00+03	2017-07-19 14:00:00+03
22959	PG0444	2017-09-14 12:30:00+03	2017-09-14 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22960	PG0444	2017-08-23 12:30:00+03	2017-08-23 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22961	PG0444	2017-08-14 12:30:00+03	2017-08-14 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-14 12:32:00+03	2017-08-14 14:01:00+03
22962	PG0444	2017-07-30 12:30:00+03	2017-07-30 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-30 12:34:00+03	2017-07-30 14:03:00+03
22963	PG0444	2017-07-17 12:30:00+03	2017-07-17 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-17 12:33:00+03	2017-07-17 14:02:00+03
22964	PG0444	2017-07-27 12:30:00+03	2017-07-27 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-27 12:34:00+03	2017-07-27 14:04:00+03
22965	PG0444	2017-08-30 12:30:00+03	2017-08-30 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22966	PG0444	2017-08-02 12:30:00+03	2017-08-02 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-02 12:33:00+03	2017-08-02 14:03:00+03
22967	PG0444	2017-07-31 12:30:00+03	2017-07-31 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-31 12:32:00+03	2017-07-31 14:02:00+03
22968	PG0444	2017-08-21 12:30:00+03	2017-08-21 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22969	PG0444	2017-08-09 12:30:00+03	2017-08-09 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-09 12:33:00+03	2017-08-09 14:05:00+03
22970	PG0444	2017-08-15 12:30:00+03	2017-08-15 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-15 12:34:00+03	2017-08-15 14:05:00+03
22971	PG0444	2017-09-09 12:30:00+03	2017-09-09 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22972	PG0444	2017-07-26 12:30:00+03	2017-07-26 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-26 12:31:00+03	2017-07-26 14:01:00+03
22973	PG0444	2017-08-06 12:30:00+03	2017-08-06 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-06 12:31:00+03	2017-08-06 14:02:00+03
22974	PG0444	2017-09-02 12:30:00+03	2017-09-02 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22975	PG0444	2017-09-05 12:30:00+03	2017-09-05 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22976	PG0444	2017-07-20 12:30:00+03	2017-07-20 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-20 12:34:00+03	2017-07-20 14:05:00+03
22977	PG0444	2017-08-03 12:30:00+03	2017-08-03 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-03 12:32:00+03	2017-08-03 14:03:00+03
22978	PG0444	2017-08-16 12:30:00+03	2017-08-16 14:00:00+03	OVS	TJM	On Time	CN1	\N	\N
22979	PG0444	2017-08-26 12:30:00+03	2017-08-26 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22980	PG0444	2017-08-19 12:30:00+03	2017-08-19 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22981	PG0444	2017-07-25 12:30:00+03	2017-07-25 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-25 12:32:00+03	2017-07-25 14:03:00+03
22982	PG0444	2017-08-08 12:30:00+03	2017-08-08 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-08 12:32:00+03	2017-08-08 14:04:00+03
22983	PG0444	2017-08-27 12:30:00+03	2017-08-27 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22984	PG0444	2017-08-29 12:30:00+03	2017-08-29 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22985	PG0444	2017-09-12 12:30:00+03	2017-09-12 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22986	PG0444	2017-08-11 12:30:00+03	2017-08-11 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-11 12:35:00+03	2017-08-11 14:06:00+03
22987	PG0444	2017-08-31 12:30:00+03	2017-08-31 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22988	PG0444	2017-08-04 12:30:00+03	2017-08-04 14:00:00+03	OVS	TJM	Arrived	CN1	2017-08-04 12:33:00+03	2017-08-04 14:03:00+03
22989	PG0444	2017-09-10 12:30:00+03	2017-09-10 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22990	PG0444	2017-08-17 12:30:00+03	2017-08-17 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22991	PG0444	2017-07-23 12:30:00+03	2017-07-23 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-23 12:34:00+03	2017-07-23 14:02:00+03
22992	PG0444	2017-07-24 12:30:00+03	2017-07-24 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-24 16:26:00+03	2017-07-24 17:57:00+03
22993	PG0444	2017-07-22 12:30:00+03	2017-07-22 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-22 12:35:00+03	2017-07-22 14:05:00+03
22994	PG0444	2017-09-11 12:30:00+03	2017-09-11 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22995	PG0444	2017-08-20 12:30:00+03	2017-08-20 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22996	PG0444	2017-08-18 12:30:00+03	2017-08-18 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22997	PG0444	2017-08-24 12:30:00+03	2017-08-24 14:00:00+03	OVS	TJM	Scheduled	CN1	\N	\N
22998	PG0444	2017-07-16 12:30:00+03	2017-07-16 14:00:00+03	OVS	TJM	Arrived	CN1	2017-07-16 12:32:00+03	2017-07-16 14:01:00+03
22999	PG0707	2017-08-26 16:45:00+03	2017-08-26 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23000	PG0707	2017-08-04 16:45:00+03	2017-08-04 17:30:00+03	OVS	SGC	Arrived	733	2017-08-04 16:45:00+03	2017-08-04 17:30:00+03
23001	PG0707	2017-09-01 16:45:00+03	2017-09-01 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23002	PG0707	2017-09-02 16:45:00+03	2017-09-02 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23003	PG0707	2017-08-18 16:45:00+03	2017-08-18 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23004	PG0707	2017-08-16 16:45:00+03	2017-08-16 17:30:00+03	OVS	SGC	On Time	733	\N	\N
23005	PG0707	2017-09-12 16:45:00+03	2017-09-12 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23006	PG0707	2017-08-02 16:45:00+03	2017-08-02 17:30:00+03	OVS	SGC	Arrived	733	2017-08-02 16:46:00+03	2017-08-02 17:31:00+03
23007	PG0707	2017-07-18 16:45:00+03	2017-07-18 17:30:00+03	OVS	SGC	Arrived	733	2017-07-18 16:46:00+03	2017-07-18 17:32:00+03
23008	PG0707	2017-08-17 16:45:00+03	2017-08-17 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23009	PG0707	2017-08-23 16:45:00+03	2017-08-23 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23010	PG0707	2017-07-29 16:45:00+03	2017-07-29 17:30:00+03	OVS	SGC	Arrived	733	2017-07-29 16:46:00+03	2017-07-29 17:31:00+03
23011	PG0707	2017-07-26 16:45:00+03	2017-07-26 17:30:00+03	OVS	SGC	Arrived	733	2017-07-26 16:48:00+03	2017-07-26 17:33:00+03
23012	PG0707	2017-08-31 16:45:00+03	2017-08-31 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23013	PG0707	2017-07-22 16:45:00+03	2017-07-22 17:30:00+03	OVS	SGC	Arrived	733	2017-07-22 16:50:00+03	2017-07-22 17:35:00+03
23014	PG0707	2017-08-25 16:45:00+03	2017-08-25 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23015	PG0707	2017-09-05 16:45:00+03	2017-09-05 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23016	PG0707	2017-09-03 16:45:00+03	2017-09-03 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23017	PG0707	2017-08-08 16:45:00+03	2017-08-08 17:30:00+03	OVS	SGC	Arrived	733	2017-08-08 16:48:00+03	2017-08-08 17:33:00+03
23018	PG0707	2017-08-29 16:45:00+03	2017-08-29 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23019	PG0707	2017-07-23 16:45:00+03	2017-07-23 17:30:00+03	OVS	SGC	Arrived	733	2017-07-23 16:47:00+03	2017-07-23 17:32:00+03
23020	PG0707	2017-09-07 16:45:00+03	2017-09-07 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23021	PG0707	2017-08-14 16:45:00+03	2017-08-14 17:30:00+03	OVS	SGC	Arrived	733	2017-08-14 16:49:00+03	2017-08-14 17:35:00+03
23022	PG0707	2017-07-19 16:45:00+03	2017-07-19 17:30:00+03	OVS	SGC	Arrived	733	2017-07-19 16:47:00+03	2017-07-19 17:32:00+03
23023	PG0707	2017-08-28 16:45:00+03	2017-08-28 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23024	PG0707	2017-09-11 16:45:00+03	2017-09-11 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23025	PG0707	2017-08-05 16:45:00+03	2017-08-05 17:30:00+03	OVS	SGC	Arrived	733	2017-08-05 16:48:00+03	2017-08-05 17:33:00+03
23026	PG0707	2017-08-07 16:45:00+03	2017-08-07 17:30:00+03	OVS	SGC	Arrived	733	2017-08-07 16:48:00+03	2017-08-07 17:33:00+03
23027	PG0707	2017-08-22 16:45:00+03	2017-08-22 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23028	PG0707	2017-09-04 16:45:00+03	2017-09-04 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23029	PG0707	2017-07-25 16:45:00+03	2017-07-25 17:30:00+03	OVS	SGC	Arrived	733	2017-07-25 16:46:00+03	2017-07-25 17:31:00+03
23030	PG0707	2017-08-24 16:45:00+03	2017-08-24 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23031	PG0707	2017-07-31 16:45:00+03	2017-07-31 17:30:00+03	OVS	SGC	Arrived	733	2017-07-31 16:46:00+03	2017-07-31 17:31:00+03
23032	PG0707	2017-08-09 16:45:00+03	2017-08-09 17:30:00+03	OVS	SGC	Arrived	733	2017-08-09 16:48:00+03	2017-08-09 17:34:00+03
23033	PG0707	2017-09-08 16:45:00+03	2017-09-08 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23034	PG0707	2017-08-11 16:45:00+03	2017-08-11 17:30:00+03	OVS	SGC	Arrived	733	2017-08-11 16:47:00+03	2017-08-11 17:32:00+03
23035	PG0707	2017-09-14 16:45:00+03	2017-09-14 17:30:00+03	OVS	SGC	Cancelled	733	\N	\N
23036	PG0707	2017-09-09 16:45:00+03	2017-09-09 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23037	PG0707	2017-07-21 16:45:00+03	2017-07-21 17:30:00+03	OVS	SGC	Arrived	733	2017-07-21 16:47:00+03	2017-07-21 17:32:00+03
23038	PG0707	2017-07-20 16:45:00+03	2017-07-20 17:30:00+03	OVS	SGC	Arrived	733	2017-07-20 16:46:00+03	2017-07-20 17:31:00+03
23039	PG0707	2017-08-19 16:45:00+03	2017-08-19 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23040	PG0707	2017-08-10 16:45:00+03	2017-08-10 17:30:00+03	OVS	SGC	Arrived	733	2017-08-10 16:47:00+03	2017-08-10 17:32:00+03
23041	PG0707	2017-07-24 16:45:00+03	2017-07-24 17:30:00+03	OVS	SGC	Arrived	733	2017-07-24 16:48:00+03	2017-07-24 17:33:00+03
23042	PG0707	2017-08-01 16:45:00+03	2017-08-01 17:30:00+03	OVS	SGC	Arrived	733	2017-08-01 16:47:00+03	2017-08-01 17:32:00+03
23043	PG0707	2017-08-20 16:45:00+03	2017-08-20 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23044	PG0707	2017-07-27 16:45:00+03	2017-07-27 17:30:00+03	OVS	SGC	Arrived	733	2017-07-27 16:47:00+03	2017-07-27 17:32:00+03
23045	PG0707	2017-08-21 16:45:00+03	2017-08-21 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23046	PG0707	2017-07-30 16:45:00+03	2017-07-30 17:30:00+03	OVS	SGC	Arrived	733	2017-07-30 16:48:00+03	2017-07-30 17:33:00+03
23047	PG0707	2017-07-17 16:45:00+03	2017-07-17 17:30:00+03	OVS	SGC	Arrived	733	2017-07-17 16:47:00+03	2017-07-17 17:32:00+03
23048	PG0707	2017-09-13 16:45:00+03	2017-09-13 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23049	PG0707	2017-07-28 16:45:00+03	2017-07-28 17:30:00+03	OVS	SGC	Arrived	733	2017-07-28 16:50:00+03	2017-07-28 17:34:00+03
23050	PG0707	2017-08-12 16:45:00+03	2017-08-12 17:30:00+03	OVS	SGC	Arrived	733	2017-08-12 16:50:00+03	2017-08-12 17:35:00+03
23051	PG0707	2017-08-30 16:45:00+03	2017-08-30 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23052	PG0707	2017-07-16 16:45:00+03	2017-07-16 17:30:00+03	OVS	SGC	Arrived	733	2017-07-16 16:49:00+03	2017-07-16 17:33:00+03
23053	PG0707	2017-08-06 16:45:00+03	2017-08-06 17:30:00+03	OVS	SGC	Arrived	733	2017-08-06 16:49:00+03	2017-08-06 17:34:00+03
23054	PG0707	2017-09-06 16:45:00+03	2017-09-06 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23055	PG0707	2017-09-10 16:45:00+03	2017-09-10 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23056	PG0707	2017-08-03 16:45:00+03	2017-08-03 17:30:00+03	OVS	SGC	Arrived	733	2017-08-03 16:48:00+03	2017-08-03 17:33:00+03
23057	PG0707	2017-08-15 16:45:00+03	2017-08-15 17:30:00+03	OVS	SGC	Arrived	733	2017-08-15 16:48:00+03	2017-08-15 17:34:00+03
23058	PG0707	2017-08-27 16:45:00+03	2017-08-27 17:30:00+03	OVS	SGC	Scheduled	733	\N	\N
23059	PG0707	2017-08-13 16:45:00+03	2017-08-13 17:30:00+03	OVS	SGC	Arrived	733	2017-08-13 16:49:00+03	2017-08-13 17:34:00+03
23060	PG0640	2017-08-25 15:00:00+03	2017-08-25 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23061	PG0640	2017-09-03 15:00:00+03	2017-09-03 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23062	PG0640	2017-07-17 15:00:00+03	2017-07-17 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-17 15:05:00+03	2017-07-17 18:07:00+03
23063	PG0640	2017-07-20 15:00:00+03	2017-07-20 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-20 15:04:00+03	2017-07-20 18:12:00+03
23064	PG0640	2017-09-01 15:00:00+03	2017-09-01 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23065	PG0640	2017-08-20 15:00:00+03	2017-08-20 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23066	PG0640	2017-08-31 15:00:00+03	2017-08-31 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23067	PG0640	2017-07-27 15:00:00+03	2017-07-27 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-27 15:08:00+03	2017-07-27 18:16:00+03
23068	PG0640	2017-09-02 15:00:00+03	2017-09-02 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23069	PG0640	2017-07-24 15:00:00+03	2017-07-24 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-24 15:04:00+03	2017-07-24 18:11:00+03
23070	PG0640	2017-08-05 15:00:00+03	2017-08-05 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-05 15:05:00+03	2017-08-05 18:13:00+03
23071	PG0640	2017-08-15 15:00:00+03	2017-08-15 18:05:00+03	NYM	DME	Departed	CR2	2017-08-15 15:01:00+03	\N
23072	PG0640	2017-09-05 15:00:00+03	2017-09-05 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23073	PG0640	2017-07-16 15:00:00+03	2017-07-16 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-16 15:04:00+03	2017-07-16 18:08:00+03
23074	PG0640	2017-08-02 15:00:00+03	2017-08-02 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-02 15:07:00+03	2017-08-02 18:14:00+03
23075	PG0640	2017-07-22 15:00:00+03	2017-07-22 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-22 15:02:00+03	2017-07-22 18:04:00+03
23076	PG0640	2017-08-27 15:00:00+03	2017-08-27 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23077	PG0640	2017-08-11 15:00:00+03	2017-08-11 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-11 15:03:00+03	2017-08-11 18:13:00+03
23078	PG0640	2017-08-18 15:00:00+03	2017-08-18 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23079	PG0640	2017-07-26 15:00:00+03	2017-07-26 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-26 15:02:00+03	2017-07-26 18:09:00+03
23080	PG0640	2017-08-23 15:00:00+03	2017-08-23 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23081	PG0640	2017-08-22 15:00:00+03	2017-08-22 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23082	PG0640	2017-09-12 15:00:00+03	2017-09-12 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23083	PG0640	2017-08-21 15:00:00+03	2017-08-21 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23084	PG0640	2017-08-07 15:00:00+03	2017-08-07 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-07 15:03:00+03	2017-08-07 18:05:00+03
23085	PG0640	2017-08-03 15:00:00+03	2017-08-03 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-03 15:06:00+03	2017-08-03 18:12:00+03
23086	PG0640	2017-08-16 15:00:00+03	2017-08-16 18:05:00+03	NYM	DME	On Time	CR2	\N	\N
23087	PG0640	2017-07-21 15:00:00+03	2017-07-21 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-21 15:06:00+03	2017-07-21 18:09:00+03
23088	PG0640	2017-07-23 15:00:00+03	2017-07-23 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-23 15:05:00+03	2017-07-23 18:10:00+03
23089	PG0640	2017-08-28 15:00:00+03	2017-08-28 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23090	PG0640	2017-08-24 15:00:00+03	2017-08-24 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23091	PG0640	2017-09-04 15:00:00+03	2017-09-04 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23092	PG0640	2017-09-14 15:00:00+03	2017-09-14 18:05:00+03	NYM	DME	Cancelled	CR2	\N	\N
23093	PG0640	2017-08-26 15:00:00+03	2017-08-26 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23094	PG0640	2017-07-18 15:00:00+03	2017-07-18 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-18 15:06:00+03	2017-07-18 18:12:00+03
23095	PG0640	2017-08-12 15:00:00+03	2017-08-12 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-12 15:02:00+03	2017-08-12 18:09:00+03
23096	PG0640	2017-07-25 15:00:00+03	2017-07-25 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-25 15:06:00+03	2017-07-25 18:11:00+03
23097	PG0640	2017-09-13 15:00:00+03	2017-09-13 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23098	PG0640	2017-08-17 15:00:00+03	2017-08-17 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23099	PG0640	2017-08-06 15:00:00+03	2017-08-06 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-06 15:02:00+03	2017-08-06 18:06:00+03
23100	PG0640	2017-08-09 15:00:00+03	2017-08-09 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-09 15:01:00+03	2017-08-09 18:09:00+03
23101	PG0640	2017-09-07 15:00:00+03	2017-09-07 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23102	PG0640	2017-09-08 15:00:00+03	2017-09-08 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23103	PG0640	2017-07-29 15:00:00+03	2017-07-29 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-29 15:01:00+03	2017-07-29 18:06:00+03
23104	PG0640	2017-07-30 15:00:00+03	2017-07-30 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-30 15:01:00+03	2017-07-30 18:05:00+03
23105	PG0640	2017-09-10 15:00:00+03	2017-09-10 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23106	PG0640	2017-08-13 15:00:00+03	2017-08-13 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-13 18:22:00+03	2017-08-13 21:29:00+03
23107	PG0640	2017-08-04 15:00:00+03	2017-08-04 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-04 15:04:00+03	2017-08-04 18:07:00+03
23108	PG0640	2017-07-28 15:00:00+03	2017-07-28 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-28 15:05:00+03	2017-07-28 18:10:00+03
23109	PG0640	2017-09-09 15:00:00+03	2017-09-09 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23110	PG0640	2017-09-11 15:00:00+03	2017-09-11 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23111	PG0640	2017-08-19 15:00:00+03	2017-08-19 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23112	PG0640	2017-09-06 15:00:00+03	2017-09-06 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23113	PG0640	2017-08-14 15:00:00+03	2017-08-14 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-14 15:04:00+03	2017-08-14 18:08:00+03
23114	PG0640	2017-07-31 15:00:00+03	2017-07-31 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-31 15:03:00+03	2017-07-31 18:08:00+03
23115	PG0640	2017-08-01 15:00:00+03	2017-08-01 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-01 15:05:00+03	2017-08-01 18:09:00+03
23116	PG0640	2017-08-29 15:00:00+03	2017-08-29 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23117	PG0640	2017-08-30 15:00:00+03	2017-08-30 18:05:00+03	NYM	DME	Scheduled	CR2	\N	\N
23118	PG0640	2017-08-08 15:00:00+03	2017-08-08 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-08 17:58:00+03	2017-08-08 21:08:00+03
23119	PG0640	2017-07-19 15:00:00+03	2017-07-19 18:05:00+03	NYM	DME	Arrived	CR2	2017-07-19 15:04:00+03	2017-07-19 18:06:00+03
23120	PG0640	2017-08-10 15:00:00+03	2017-08-10 18:05:00+03	NYM	DME	Arrived	CR2	2017-08-10 19:02:00+03	2017-08-10 22:07:00+03
23121	PG0330	2017-09-07 09:35:00+03	2017-09-07 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23122	PG0330	2017-07-17 09:35:00+03	2017-07-17 12:05:00+03	NYM	NSK	Arrived	CN1	2017-07-17 09:37:00+03	2017-07-17 12:08:00+03
23123	PG0330	2017-07-20 09:35:00+03	2017-07-20 12:05:00+03	NYM	NSK	Arrived	CN1	2017-07-20 09:36:00+03	2017-07-20 12:04:00+03
23124	PG0330	2017-07-27 09:35:00+03	2017-07-27 12:05:00+03	NYM	NSK	Arrived	CN1	2017-07-27 09:39:00+03	2017-07-27 12:08:00+03
23125	PG0330	2017-09-11 09:35:00+03	2017-09-11 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23126	PG0330	2017-08-03 09:35:00+03	2017-08-03 12:05:00+03	NYM	NSK	Arrived	CN1	2017-08-03 09:39:00+03	2017-08-03 12:11:00+03
23127	PG0330	2017-08-14 09:35:00+03	2017-08-14 12:05:00+03	NYM	NSK	Arrived	CN1	2017-08-14 09:37:00+03	2017-08-14 12:08:00+03
23128	PG0330	2017-08-10 09:35:00+03	2017-08-10 12:05:00+03	NYM	NSK	Arrived	CN1	2017-08-10 09:41:00+03	2017-08-10 12:11:00+03
23129	PG0330	2017-08-07 09:35:00+03	2017-08-07 12:05:00+03	NYM	NSK	Arrived	CN1	2017-08-07 09:42:00+03	2017-08-07 12:13:00+03
23130	PG0330	2017-08-24 09:35:00+03	2017-08-24 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23131	PG0330	2017-07-31 09:35:00+03	2017-07-31 12:05:00+03	NYM	NSK	Arrived	CN1	2017-07-31 09:44:00+03	2017-07-31 12:14:00+03
23132	PG0330	2017-08-31 09:35:00+03	2017-08-31 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23133	PG0330	2017-08-17 09:35:00+03	2017-08-17 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23134	PG0330	2017-08-28 09:35:00+03	2017-08-28 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23135	PG0330	2017-09-14 09:35:00+03	2017-09-14 12:05:00+03	NYM	NSK	Cancelled	CN1	\N	\N
23136	PG0330	2017-07-24 09:35:00+03	2017-07-24 12:05:00+03	NYM	NSK	Arrived	CN1	2017-07-24 09:36:00+03	2017-07-24 12:06:00+03
23137	PG0330	2017-09-04 09:35:00+03	2017-09-04 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23138	PG0330	2017-08-21 09:35:00+03	2017-08-21 12:05:00+03	NYM	NSK	Scheduled	CN1	\N	\N
23139	PG0027	2017-09-02 12:30:00+03	2017-09-02 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23140	PG0027	2017-07-29 12:30:00+03	2017-07-29 15:45:00+03	NYM	IKT	Arrived	CR2	2017-07-29 12:33:00+03	2017-07-29 15:47:00+03
23141	PG0027	2017-08-02 12:30:00+03	2017-08-02 15:45:00+03	NYM	IKT	Arrived	CR2	2017-08-02 12:33:00+03	2017-08-02 15:48:00+03
23142	PG0027	2017-08-19 12:30:00+03	2017-08-19 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23143	PG0027	2017-08-05 12:30:00+03	2017-08-05 15:45:00+03	NYM	IKT	Arrived	CR2	2017-08-05 12:32:00+03	2017-08-05 15:48:00+03
23144	PG0027	2017-07-26 12:30:00+03	2017-07-26 15:45:00+03	NYM	IKT	Arrived	CR2	2017-07-26 15:36:00+03	2017-07-26 18:48:00+03
23145	PG0027	2017-08-26 12:30:00+03	2017-08-26 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23146	PG0027	2017-09-13 12:30:00+03	2017-09-13 15:45:00+03	NYM	IKT	Cancelled	CR2	\N	\N
23147	PG0027	2017-08-12 12:30:00+03	2017-08-12 15:45:00+03	NYM	IKT	Arrived	CR2	2017-08-12 12:31:00+03	2017-08-12 15:45:00+03
23148	PG0027	2017-08-16 12:30:00+03	2017-08-16 15:45:00+03	NYM	IKT	On Time	CR2	\N	\N
23149	PG0027	2017-09-06 12:30:00+03	2017-09-06 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23150	PG0027	2017-09-09 12:30:00+03	2017-09-09 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23151	PG0027	2017-07-19 12:30:00+03	2017-07-19 15:45:00+03	NYM	IKT	Arrived	CR2	2017-07-19 12:34:00+03	2017-07-19 15:50:00+03
23152	PG0027	2017-08-23 12:30:00+03	2017-08-23 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23153	PG0027	2017-08-30 12:30:00+03	2017-08-30 15:45:00+03	NYM	IKT	Scheduled	CR2	\N	\N
23154	PG0027	2017-08-09 12:30:00+03	2017-08-09 15:45:00+03	NYM	IKT	Arrived	CR2	2017-08-09 12:34:00+03	2017-08-09 15:47:00+03
23155	PG0027	2017-07-22 12:30:00+03	2017-07-22 15:45:00+03	NYM	IKT	Arrived	CR2	2017-07-22 12:32:00+03	2017-07-22 15:47:00+03
23156	PG0681	2017-07-16 14:30:00+03	2017-07-16 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-07-16 14:30:00+03	2017-07-16 16:40:00+03
23157	PG0681	2017-08-13 14:30:00+03	2017-08-13 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-08-13 14:32:00+03	2017-08-13 16:43:00+03
23158	PG0681	2017-08-23 14:30:00+03	2017-08-23 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23159	PG0681	2017-08-20 14:30:00+03	2017-08-20 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23160	PG0681	2017-08-16 14:30:00+03	2017-08-16 16:40:00+03	NYM	NOZ	On Time	CR2	\N	\N
23161	PG0681	2017-07-26 14:30:00+03	2017-07-26 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-07-26 14:33:00+03	2017-07-26 16:45:00+03
23162	PG0681	2017-07-23 14:30:00+03	2017-07-23 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-07-23 14:32:00+03	2017-07-23 16:43:00+03
23163	PG0681	2017-09-03 14:30:00+03	2017-09-03 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23164	PG0681	2017-08-02 14:30:00+03	2017-08-02 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-08-02 14:31:00+03	2017-08-02 16:41:00+03
23165	PG0681	2017-07-30 14:30:00+03	2017-07-30 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-07-30 14:37:00+03	2017-07-30 16:46:00+03
23166	PG0681	2017-08-09 14:30:00+03	2017-08-09 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-08-09 14:33:00+03	2017-08-09 16:42:00+03
23167	PG0681	2017-09-13 14:30:00+03	2017-09-13 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23168	PG0681	2017-08-27 14:30:00+03	2017-08-27 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23169	PG0681	2017-08-06 14:30:00+03	2017-08-06 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-08-06 14:33:00+03	2017-08-06 16:42:00+03
23170	PG0681	2017-08-30 14:30:00+03	2017-08-30 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23171	PG0681	2017-07-19 14:30:00+03	2017-07-19 16:40:00+03	NYM	NOZ	Arrived	CR2	2017-07-19 14:33:00+03	2017-07-19 16:44:00+03
23172	PG0681	2017-09-06 14:30:00+03	2017-09-06 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23173	PG0681	2017-09-10 14:30:00+03	2017-09-10 16:40:00+03	NYM	NOZ	Scheduled	CR2	\N	\N
23174	PG0309	2017-07-29 08:40:00+03	2017-07-29 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-29 08:44:00+03	2017-07-29 12:14:00+03
23175	PG0309	2017-09-06 08:40:00+03	2017-09-06 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23176	PG0309	2017-08-14 08:40:00+03	2017-08-14 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-14 08:42:00+03	2017-08-14 12:11:00+03
23177	PG0309	2017-07-26 08:40:00+03	2017-07-26 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-26 08:41:00+03	2017-07-26 12:12:00+03
23178	PG0309	2017-07-22 08:40:00+03	2017-07-22 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-22 08:45:00+03	2017-07-22 12:15:00+03
23179	PG0309	2017-07-24 08:40:00+03	2017-07-24 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-24 08:47:00+03	2017-07-24 12:19:00+03
23180	PG0309	2017-08-12 08:40:00+03	2017-08-12 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-12 08:42:00+03	2017-08-12 12:14:00+03
23181	PG0309	2017-08-21 08:40:00+03	2017-08-21 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23182	PG0309	2017-08-02 08:40:00+03	2017-08-02 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-02 08:42:00+03	2017-08-02 12:09:00+03
23183	PG0309	2017-08-19 08:40:00+03	2017-08-19 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23184	PG0309	2017-09-04 08:40:00+03	2017-09-04 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23185	PG0309	2017-08-26 08:40:00+03	2017-08-26 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23186	PG0309	2017-08-05 08:40:00+03	2017-08-05 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-05 08:44:00+03	2017-08-05 12:13:00+03
23187	PG0309	2017-08-09 08:40:00+03	2017-08-09 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-09 08:45:00+03	2017-08-09 12:12:00+03
23188	PG0309	2017-07-31 08:40:00+03	2017-07-31 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-31 08:46:00+03	2017-07-31 12:18:00+03
23189	PG0309	2017-08-07 08:40:00+03	2017-08-07 12:10:00+03	NYM	UUD	Arrived	CR2	2017-08-07 08:40:00+03	2017-08-07 12:14:00+03
23190	PG0309	2017-08-16 08:40:00+03	2017-08-16 12:10:00+03	NYM	UUD	On Time	CR2	\N	\N
23191	PG0309	2017-08-30 08:40:00+03	2017-08-30 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23192	PG0309	2017-07-19 08:40:00+03	2017-07-19 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-19 08:41:00+03	2017-07-19 12:08:00+03
23193	PG0309	2017-09-11 08:40:00+03	2017-09-11 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23194	PG0309	2017-07-17 08:40:00+03	2017-07-17 12:10:00+03	NYM	UUD	Arrived	CR2	2017-07-17 08:43:00+03	2017-07-17 12:15:00+03
23195	PG0309	2017-09-09 08:40:00+03	2017-09-09 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23196	PG0309	2017-09-02 08:40:00+03	2017-09-02 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23197	PG0309	2017-08-23 08:40:00+03	2017-08-23 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23198	PG0309	2017-08-28 08:40:00+03	2017-08-28 12:10:00+03	NYM	UUD	Scheduled	CR2	\N	\N
23199	PG0309	2017-09-13 08:40:00+03	2017-09-13 12:10:00+03	NYM	UUD	Cancelled	CR2	\N	\N
23200	PG0443	2017-07-26 15:00:00+03	2017-07-26 18:00:00+03	NFG	VKO	Arrived	CR2	2017-07-26 15:05:00+03	2017-07-26 18:07:00+03
23201	PG0443	2017-07-19 15:00:00+03	2017-07-19 18:00:00+03	NFG	VKO	Arrived	CR2	2017-07-19 15:01:00+03	2017-07-19 18:00:00+03
23202	PG0443	2017-08-06 15:00:00+03	2017-08-06 18:00:00+03	NFG	VKO	Arrived	CR2	2017-08-06 15:04:00+03	2017-08-06 18:03:00+03
23203	PG0443	2017-08-23 15:00:00+03	2017-08-23 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23204	PG0443	2017-09-13 15:00:00+03	2017-09-13 18:00:00+03	NFG	VKO	Cancelled	CR2	\N	\N
23205	PG0443	2017-08-13 15:00:00+03	2017-08-13 18:00:00+03	NFG	VKO	Arrived	CR2	2017-08-13 15:04:00+03	2017-08-13 18:04:00+03
23206	PG0443	2017-07-30 15:00:00+03	2017-07-30 18:00:00+03	NFG	VKO	Arrived	CR2	2017-07-30 15:01:00+03	2017-07-30 18:03:00+03
23207	PG0443	2017-08-16 15:00:00+03	2017-08-16 18:00:00+03	NFG	VKO	On Time	CR2	\N	\N
23208	PG0443	2017-07-16 15:00:00+03	2017-07-16 18:00:00+03	NFG	VKO	Arrived	CR2	2017-07-16 15:02:00+03	2017-07-16 18:00:00+03
23209	PG0443	2017-07-23 15:00:00+03	2017-07-23 18:00:00+03	NFG	VKO	Arrived	CR2	2017-07-23 15:03:00+03	2017-07-23 18:03:00+03
23210	PG0443	2017-09-10 15:00:00+03	2017-09-10 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23211	PG0443	2017-08-30 15:00:00+03	2017-08-30 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23212	PG0443	2017-08-09 15:00:00+03	2017-08-09 18:00:00+03	NFG	VKO	Arrived	CR2	2017-08-09 15:03:00+03	2017-08-09 18:04:00+03
23213	PG0443	2017-08-20 15:00:00+03	2017-08-20 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23214	PG0443	2017-08-02 15:00:00+03	2017-08-02 18:00:00+03	NFG	VKO	Arrived	CR2	2017-08-02 15:03:00+03	2017-08-02 18:05:00+03
23215	PG0443	2017-09-03 15:00:00+03	2017-09-03 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23216	PG0443	2017-09-06 15:00:00+03	2017-09-06 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23217	PG0443	2017-08-27 15:00:00+03	2017-08-27 18:00:00+03	NFG	VKO	Scheduled	CR2	\N	\N
23218	PG0101	2017-08-24 16:30:00+03	2017-08-24 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23219	PG0101	2017-09-09 16:30:00+03	2017-09-09 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23220	PG0101	2017-09-12 16:30:00+03	2017-09-12 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23221	PG0101	2017-08-19 16:30:00+03	2017-08-19 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23222	PG0101	2017-08-15 16:30:00+03	2017-08-15 19:30:00+03	NFG	SVO	Departed	CR2	2017-08-15 16:32:00+03	\N
23223	PG0101	2017-08-08 16:30:00+03	2017-08-08 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-08 16:34:00+03	2017-08-08 19:38:00+03
23224	PG0101	2017-08-26 16:30:00+03	2017-08-26 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23225	PG0101	2017-07-27 16:30:00+03	2017-07-27 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-27 16:34:00+03	2017-07-27 19:30:00+03
23226	PG0101	2017-08-29 16:30:00+03	2017-08-29 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23227	PG0101	2017-07-18 16:30:00+03	2017-07-18 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-18 16:35:00+03	2017-07-18 19:34:00+03
23228	PG0101	2017-07-20 16:30:00+03	2017-07-20 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-20 16:35:00+03	2017-07-20 19:35:00+03
23229	PG0101	2017-09-05 16:30:00+03	2017-09-05 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23230	PG0101	2017-08-03 16:30:00+03	2017-08-03 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-03 16:34:00+03	2017-08-03 19:33:00+03
23231	PG0101	2017-08-10 16:30:00+03	2017-08-10 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-10 16:35:00+03	2017-08-10 19:33:00+03
23232	PG0101	2017-09-14 16:30:00+03	2017-09-14 19:30:00+03	NFG	SVO	Cancelled	CR2	\N	\N
23233	PG0101	2017-07-29 16:30:00+03	2017-07-29 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-29 16:32:00+03	2017-07-29 19:34:00+03
23234	PG0101	2017-08-01 16:30:00+03	2017-08-01 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-01 16:35:00+03	2017-08-01 19:33:00+03
23235	PG0101	2017-08-31 16:30:00+03	2017-08-31 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23236	PG0101	2017-08-22 16:30:00+03	2017-08-22 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23237	PG0101	2017-08-12 16:30:00+03	2017-08-12 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-12 16:34:00+03	2017-08-12 19:32:00+03
23238	PG0101	2017-09-02 16:30:00+03	2017-09-02 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23239	PG0101	2017-07-25 16:30:00+03	2017-07-25 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-25 16:32:00+03	2017-07-25 19:32:00+03
23240	PG0101	2017-08-17 16:30:00+03	2017-08-17 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23241	PG0101	2017-08-05 16:30:00+03	2017-08-05 19:30:00+03	NFG	SVO	Arrived	CR2	2017-08-05 16:36:00+03	2017-08-05 19:37:00+03
23242	PG0101	2017-07-22 16:30:00+03	2017-07-22 19:30:00+03	NFG	SVO	Arrived	CR2	2017-07-22 16:33:00+03	2017-07-22 19:33:00+03
23243	PG0101	2017-09-07 16:30:00+03	2017-09-07 19:30:00+03	NFG	SVO	Scheduled	CR2	\N	\N
23244	PG0290	2017-09-12 15:15:00+03	2017-09-12 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23245	PG0290	2017-09-01 15:15:00+03	2017-09-01 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23246	PG0290	2017-07-18 15:15:00+03	2017-07-18 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-18 15:17:00+03	2017-07-18 18:00:00+03
23247	PG0290	2017-08-11 15:15:00+03	2017-08-11 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-11 15:16:00+03	2017-08-11 18:01:00+03
23248	PG0290	2017-08-13 15:15:00+03	2017-08-13 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-13 15:17:00+03	2017-08-13 18:03:00+03
23249	PG0290	2017-08-31 15:15:00+03	2017-08-31 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23250	PG0290	2017-08-22 15:15:00+03	2017-08-22 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23251	PG0290	2017-08-26 15:15:00+03	2017-08-26 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23252	PG0290	2017-07-29 15:15:00+03	2017-07-29 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-29 15:21:00+03	2017-07-29 18:05:00+03
23253	PG0290	2017-09-11 15:15:00+03	2017-09-11 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23254	PG0290	2017-08-23 15:15:00+03	2017-08-23 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23255	PG0290	2017-09-08 15:15:00+03	2017-09-08 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23256	PG0290	2017-07-19 15:15:00+03	2017-07-19 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-19 15:15:00+03	2017-07-19 18:03:00+03
23257	PG0290	2017-09-13 15:15:00+03	2017-09-13 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23258	PG0290	2017-08-01 15:15:00+03	2017-08-01 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-01 15:18:00+03	2017-08-01 18:03:00+03
23259	PG0290	2017-09-06 15:15:00+03	2017-09-06 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23260	PG0290	2017-07-28 15:15:00+03	2017-07-28 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-28 15:20:00+03	2017-07-28 18:04:00+03
23261	PG0290	2017-08-10 15:15:00+03	2017-08-10 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-10 15:16:00+03	2017-08-10 17:59:00+03
23262	PG0290	2017-08-14 15:15:00+03	2017-08-14 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-14 15:16:00+03	2017-08-14 18:01:00+03
23263	PG0290	2017-08-02 15:15:00+03	2017-08-02 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-02 15:17:00+03	2017-08-02 18:02:00+03
23264	PG0290	2017-07-22 15:15:00+03	2017-07-22 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-22 18:08:00+03	2017-07-22 20:54:00+03
23265	PG0290	2017-08-06 15:15:00+03	2017-08-06 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-06 15:16:00+03	2017-08-06 18:01:00+03
23266	PG0290	2017-07-27 15:15:00+03	2017-07-27 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-27 15:18:00+03	2017-07-27 18:03:00+03
23267	PG0290	2017-09-02 15:15:00+03	2017-09-02 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23268	PG0290	2017-08-15 15:15:00+03	2017-08-15 18:00:00+03	VKT	DME	Delayed	CR2	\N	\N
23269	PG0290	2017-08-30 15:15:00+03	2017-08-30 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23270	PG0290	2017-09-09 15:15:00+03	2017-09-09 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23271	PG0290	2017-07-17 15:15:00+03	2017-07-17 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-17 15:15:00+03	2017-07-17 17:59:00+03
23272	PG0290	2017-08-21 15:15:00+03	2017-08-21 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23273	PG0290	2017-08-09 15:15:00+03	2017-08-09 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-09 15:17:00+03	2017-08-09 17:59:00+03
23274	PG0290	2017-08-27 15:15:00+03	2017-08-27 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23275	PG0290	2017-07-20 15:15:00+03	2017-07-20 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-20 15:20:00+03	2017-07-20 18:04:00+03
23276	PG0290	2017-07-26 15:15:00+03	2017-07-26 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-26 15:16:00+03	2017-07-26 18:00:00+03
23277	PG0290	2017-08-03 15:15:00+03	2017-08-03 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-03 15:20:00+03	2017-08-03 18:01:00+03
23278	PG0290	2017-08-16 15:15:00+03	2017-08-16 18:00:00+03	VKT	DME	On Time	CR2	\N	\N
23279	PG0290	2017-09-05 15:15:00+03	2017-09-05 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23280	PG0290	2017-07-25 15:15:00+03	2017-07-25 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-25 15:20:00+03	2017-07-25 18:04:00+03
23281	PG0290	2017-08-25 15:15:00+03	2017-08-25 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23282	PG0290	2017-08-08 15:15:00+03	2017-08-08 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-08 15:16:00+03	2017-08-08 17:59:00+03
23283	PG0290	2017-08-24 15:15:00+03	2017-08-24 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23284	PG0290	2017-09-10 15:15:00+03	2017-09-10 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23285	PG0290	2017-08-29 15:15:00+03	2017-08-29 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23286	PG0290	2017-08-04 15:15:00+03	2017-08-04 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-04 15:17:00+03	2017-08-04 18:05:00+03
23287	PG0290	2017-08-17 15:15:00+03	2017-08-17 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23288	PG0290	2017-07-24 15:15:00+03	2017-07-24 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-24 15:16:00+03	2017-07-24 18:03:00+03
23289	PG0290	2017-07-21 15:15:00+03	2017-07-21 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-21 15:19:00+03	2017-07-21 18:06:00+03
23290	PG0290	2017-09-14 15:15:00+03	2017-09-14 18:00:00+03	VKT	DME	Cancelled	CR2	\N	\N
23291	PG0290	2017-09-03 15:15:00+03	2017-09-03 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23292	PG0290	2017-08-20 15:15:00+03	2017-08-20 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23293	PG0290	2017-08-07 15:15:00+03	2017-08-07 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-07 15:16:00+03	2017-08-07 17:58:00+03
23294	PG0290	2017-08-05 15:15:00+03	2017-08-05 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-05 15:19:00+03	2017-08-05 18:05:00+03
23295	PG0290	2017-08-18 15:15:00+03	2017-08-18 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23296	PG0290	2017-07-16 15:15:00+03	2017-07-16 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-16 15:20:00+03	2017-07-16 18:05:00+03
23297	PG0290	2017-08-28 15:15:00+03	2017-08-28 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23298	PG0290	2017-09-04 15:15:00+03	2017-09-04 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23299	PG0290	2017-08-19 15:15:00+03	2017-08-19 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23300	PG0290	2017-09-07 15:15:00+03	2017-09-07 18:00:00+03	VKT	DME	Scheduled	CR2	\N	\N
23301	PG0290	2017-08-12 15:15:00+03	2017-08-12 18:00:00+03	VKT	DME	Arrived	CR2	2017-08-12 15:18:00+03	2017-08-12 18:02:00+03
23302	PG0290	2017-07-23 15:15:00+03	2017-07-23 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-23 15:16:00+03	2017-07-23 18:01:00+03
23303	PG0290	2017-07-31 15:15:00+03	2017-07-31 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-31 15:19:00+03	2017-07-31 18:05:00+03
23304	PG0290	2017-07-30 15:15:00+03	2017-07-30 18:00:00+03	VKT	DME	Arrived	CR2	2017-07-30 15:16:00+03	2017-07-30 18:02:00+03
23305	PG0016	2017-08-27 14:30:00+03	2017-08-27 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23306	PG0016	2017-08-20 14:30:00+03	2017-08-20 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23307	PG0016	2017-07-16 14:30:00+03	2017-07-16 17:10:00+03	VKT	SVO	Arrived	CR2	2017-07-16 14:32:00+03	2017-07-16 17:13:00+03
23308	PG0016	2017-08-06 14:30:00+03	2017-08-06 17:10:00+03	VKT	SVO	Arrived	CR2	2017-08-06 14:31:00+03	2017-08-06 17:12:00+03
23309	PG0016	2017-07-30 14:30:00+03	2017-07-30 17:10:00+03	VKT	SVO	Arrived	CR2	2017-07-30 14:35:00+03	2017-07-30 17:12:00+03
23310	PG0016	2017-09-03 14:30:00+03	2017-09-03 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23311	PG0016	2017-09-07 14:30:00+03	2017-09-07 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23312	PG0016	2017-08-17 14:30:00+03	2017-08-17 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23313	PG0016	2017-08-13 14:30:00+03	2017-08-13 17:10:00+03	VKT	SVO	Arrived	CR2	2017-08-13 14:32:00+03	2017-08-13 17:12:00+03
23314	PG0016	2017-07-20 14:30:00+03	2017-07-20 17:10:00+03	VKT	SVO	Arrived	CR2	2017-07-20 14:33:00+03	2017-07-20 17:13:00+03
23315	PG0016	2017-08-24 14:30:00+03	2017-08-24 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23316	PG0016	2017-09-14 14:30:00+03	2017-09-14 17:10:00+03	VKT	SVO	Cancelled	CR2	\N	\N
23317	PG0016	2017-09-10 14:30:00+03	2017-09-10 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23318	PG0016	2017-08-10 14:30:00+03	2017-08-10 17:10:00+03	VKT	SVO	Arrived	CR2	2017-08-10 14:31:00+03	2017-08-10 17:10:00+03
23319	PG0016	2017-07-23 14:30:00+03	2017-07-23 17:10:00+03	VKT	SVO	Arrived	CR2	2017-07-23 17:13:00+03	2017-07-23 19:55:00+03
23320	PG0016	2017-08-31 14:30:00+03	2017-08-31 17:10:00+03	VKT	SVO	Scheduled	CR2	\N	\N
23321	PG0016	2017-07-27 14:30:00+03	2017-07-27 17:10:00+03	VKT	SVO	Arrived	CR2	2017-07-27 14:30:00+03	2017-07-27 17:11:00+03
23322	PG0016	2017-08-03 14:30:00+03	2017-08-03 17:10:00+03	VKT	SVO	Arrived	CR2	2017-08-03 14:32:00+03	2017-08-03 17:11:00+03
23323	PG0272	2017-08-06 10:10:00+03	2017-08-06 12:45:00+03	VKT	LED	Arrived	CR2	2017-08-06 10:12:00+03	2017-08-06 12:49:00+03
23324	PG0272	2017-08-09 10:10:00+03	2017-08-09 12:45:00+03	VKT	LED	Arrived	CR2	2017-08-09 10:16:00+03	2017-08-09 12:51:00+03
23325	PG0272	2017-08-27 10:10:00+03	2017-08-27 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23326	PG0272	2017-09-06 10:10:00+03	2017-09-06 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23327	PG0272	2017-07-30 10:10:00+03	2017-07-30 12:45:00+03	VKT	LED	Arrived	CR2	2017-07-30 10:13:00+03	2017-07-30 12:49:00+03
23328	PG0272	2017-07-23 10:10:00+03	2017-07-23 12:45:00+03	VKT	LED	Arrived	CR2	2017-07-23 10:12:00+03	2017-07-23 12:48:00+03
23329	PG0272	2017-09-13 10:10:00+03	2017-09-13 12:45:00+03	VKT	LED	Cancelled	CR2	\N	\N
23330	PG0272	2017-08-23 10:10:00+03	2017-08-23 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23331	PG0272	2017-08-30 10:10:00+03	2017-08-30 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23332	PG0272	2017-07-19 10:10:00+03	2017-07-19 12:45:00+03	VKT	LED	Arrived	CR2	2017-07-19 10:15:00+03	2017-07-19 12:49:00+03
23333	PG0272	2017-08-16 10:10:00+03	2017-08-16 12:45:00+03	VKT	LED	On Time	CR2	\N	\N
23334	PG0272	2017-08-13 10:10:00+03	2017-08-13 12:45:00+03	VKT	LED	Arrived	CR2	2017-08-13 10:15:00+03	2017-08-13 12:49:00+03
23335	PG0272	2017-07-26 10:10:00+03	2017-07-26 12:45:00+03	VKT	LED	Arrived	CR2	2017-07-26 10:11:00+03	2017-07-26 12:46:00+03
23336	PG0272	2017-09-10 10:10:00+03	2017-09-10 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23337	PG0272	2017-07-16 10:10:00+03	2017-07-16 12:45:00+03	VKT	LED	Arrived	CR2	2017-07-16 10:12:00+03	2017-07-16 12:47:00+03
23338	PG0272	2017-08-20 10:10:00+03	2017-08-20 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23339	PG0272	2017-08-02 10:10:00+03	2017-08-02 12:45:00+03	VKT	LED	Arrived	CR2	2017-08-02 10:17:00+03	2017-08-02 12:52:00+03
23340	PG0272	2017-09-03 10:10:00+03	2017-09-03 12:45:00+03	VKT	LED	Scheduled	CR2	\N	\N
23341	PG0479	2017-08-30 09:00:00+03	2017-08-30 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23342	PG0479	2017-08-26 09:00:00+03	2017-08-26 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23343	PG0479	2017-07-27 09:00:00+03	2017-07-27 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-27 09:03:00+03	2017-07-27 11:08:00+03
23344	PG0479	2017-07-18 09:00:00+03	2017-07-18 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-18 09:03:00+03	2017-07-18 11:09:00+03
23345	PG0479	2017-07-17 09:00:00+03	2017-07-17 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-17 09:03:00+03	2017-07-17 11:07:00+03
23346	PG0479	2017-08-14 09:00:00+03	2017-08-14 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-14 09:08:00+03	2017-08-14 11:12:00+03
23347	PG0479	2017-08-23 09:00:00+03	2017-08-23 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23348	PG0479	2017-07-19 09:00:00+03	2017-07-19 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-19 09:00:00+03	2017-07-19 11:04:00+03
23349	PG0479	2017-09-08 09:00:00+03	2017-09-08 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23350	PG0479	2017-07-28 09:00:00+03	2017-07-28 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-28 09:00:00+03	2017-07-28 11:05:00+03
23351	PG0479	2017-08-01 09:00:00+03	2017-08-01 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-01 09:02:00+03	2017-08-01 11:08:00+03
23352	PG0479	2017-08-10 09:00:00+03	2017-08-10 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-10 09:02:00+03	2017-08-10 11:06:00+03
23353	PG0479	2017-09-06 09:00:00+03	2017-09-06 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23354	PG0479	2017-08-13 09:00:00+03	2017-08-13 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-13 12:47:00+03	2017-08-13 14:54:00+03
23355	PG0479	2017-09-01 09:00:00+03	2017-09-01 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23356	PG0479	2017-08-12 09:00:00+03	2017-08-12 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-12 09:03:00+03	2017-08-12 11:07:00+03
23357	PG0479	2017-08-28 09:00:00+03	2017-08-28 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23358	PG0479	2017-07-29 09:00:00+03	2017-07-29 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-29 12:40:00+03	2017-07-29 14:44:00+03
23359	PG0479	2017-09-07 09:00:00+03	2017-09-07 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23360	PG0479	2017-08-31 09:00:00+03	2017-08-31 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23361	PG0479	2017-09-03 09:00:00+03	2017-09-03 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23362	PG0479	2017-07-22 09:00:00+03	2017-07-22 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-22 09:01:00+03	2017-07-22 11:06:00+03
23363	PG0479	2017-07-21 09:00:00+03	2017-07-21 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-21 09:05:00+03	2017-07-21 11:10:00+03
23364	PG0479	2017-09-04 09:00:00+03	2017-09-04 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23365	PG0479	2017-08-07 09:00:00+03	2017-08-07 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-07 09:04:00+03	2017-08-07 11:10:00+03
23366	PG0479	2017-09-11 09:00:00+03	2017-09-11 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23367	PG0479	2017-08-25 09:00:00+03	2017-08-25 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23368	PG0479	2017-08-24 09:00:00+03	2017-08-24 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23369	PG0479	2017-07-23 09:00:00+03	2017-07-23 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-23 09:04:00+03	2017-07-23 11:09:00+03
23370	PG0479	2017-07-16 09:00:00+03	2017-07-16 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-16 09:03:00+03	2017-07-16 11:07:00+03
23371	PG0479	2017-09-10 09:00:00+03	2017-09-10 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23372	PG0479	2017-08-05 09:00:00+03	2017-08-05 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-05 09:03:00+03	2017-08-05 11:08:00+03
23373	PG0479	2017-08-17 09:00:00+03	2017-08-17 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23374	PG0479	2017-08-18 09:00:00+03	2017-08-18 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23375	PG0479	2017-07-24 09:00:00+03	2017-07-24 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-24 09:01:00+03	2017-07-24 11:05:00+03
23376	PG0479	2017-08-20 09:00:00+03	2017-08-20 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23377	PG0479	2017-08-04 09:00:00+03	2017-08-04 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-04 09:04:00+03	2017-08-04 11:08:00+03
23378	PG0479	2017-07-31 09:00:00+03	2017-07-31 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-31 09:09:00+03	2017-07-31 11:15:00+03
23379	PG0479	2017-08-27 09:00:00+03	2017-08-27 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23380	PG0479	2017-08-11 09:00:00+03	2017-08-11 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-11 09:02:00+03	2017-08-11 11:07:00+03
23381	PG0479	2017-09-14 09:00:00+03	2017-09-14 11:05:00+03	VKT	OMS	Cancelled	CR2	\N	\N
23382	PG0479	2017-08-29 09:00:00+03	2017-08-29 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23383	PG0479	2017-07-25 09:00:00+03	2017-07-25 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-25 09:04:00+03	2017-07-25 11:07:00+03
23384	PG0479	2017-08-08 09:00:00+03	2017-08-08 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-08 09:03:00+03	2017-08-08 11:09:00+03
23385	PG0479	2017-09-12 09:00:00+03	2017-09-12 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23386	PG0479	2017-08-19 09:00:00+03	2017-08-19 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23387	PG0479	2017-08-16 09:00:00+03	2017-08-16 11:05:00+03	VKT	OMS	On Time	CR2	\N	\N
23388	PG0479	2017-08-03 09:00:00+03	2017-08-03 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-03 09:02:00+03	2017-08-03 11:08:00+03
23389	PG0479	2017-07-20 09:00:00+03	2017-07-20 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-20 09:02:00+03	2017-07-20 11:05:00+03
23390	PG0479	2017-09-05 09:00:00+03	2017-09-05 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23391	PG0479	2017-09-02 09:00:00+03	2017-09-02 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23392	PG0479	2017-08-22 09:00:00+03	2017-08-22 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23393	PG0479	2017-09-09 09:00:00+03	2017-09-09 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23394	PG0479	2017-08-06 09:00:00+03	2017-08-06 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-06 09:02:00+03	2017-08-06 11:07:00+03
23395	PG0479	2017-07-26 09:00:00+03	2017-07-26 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-26 09:03:00+03	2017-07-26 11:08:00+03
23396	PG0479	2017-09-13 09:00:00+03	2017-09-13 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23397	PG0479	2017-08-15 09:00:00+03	2017-08-15 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-15 09:03:00+03	2017-08-15 11:07:00+03
23398	PG0479	2017-07-30 09:00:00+03	2017-07-30 11:05:00+03	VKT	OMS	Arrived	CR2	2017-07-30 09:05:00+03	2017-07-30 11:10:00+03
23399	PG0479	2017-08-09 09:00:00+03	2017-08-09 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-09 09:01:00+03	2017-08-09 11:05:00+03
23400	PG0479	2017-08-02 09:00:00+03	2017-08-02 11:05:00+03	VKT	OMS	Arrived	CR2	2017-08-02 09:02:00+03	2017-08-02 11:06:00+03
23401	PG0479	2017-08-21 09:00:00+03	2017-08-21 11:05:00+03	VKT	OMS	Scheduled	CR2	\N	\N
23402	PG0422	2017-08-13 11:20:00+03	2017-08-13 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-13 11:25:00+03	2017-08-13 14:03:00+03
23403	PG0423	2017-08-06 16:15:00+03	2017-08-06 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-06 16:17:00+03	2017-08-06 18:58:00+03
23404	PG0422	2017-08-06 11:20:00+03	2017-08-06 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-06 11:22:00+03	2017-08-06 14:03:00+03
23405	PG0422	2017-08-25 11:20:00+03	2017-08-25 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23406	PG0423	2017-08-25 16:15:00+03	2017-08-25 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23407	PG0422	2017-07-16 11:20:00+03	2017-07-16 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-16 11:22:00+03	2017-07-16 14:01:00+03
23408	PG0423	2017-07-16 16:15:00+03	2017-07-16 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-16 16:17:00+03	2017-07-16 18:54:00+03
23409	PG0423	2017-08-24 16:15:00+03	2017-08-24 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23410	PG0422	2017-08-24 11:20:00+03	2017-08-24 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23411	PG0422	2017-08-04 11:20:00+03	2017-08-04 14:00:00+03	VKT	SGC	Cancelled	CN1	2017-08-04 11:22:00+03	2017-08-04 14:02:00+03
23412	PG0422	2017-07-17 11:20:00+03	2017-07-17 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-17 11:23:00+03	2017-07-17 14:03:00+03
23413	PG0423	2017-07-17 16:15:00+03	2017-07-17 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-17 19:21:00+03	2017-07-17 22:01:00+03
23414	PG0423	2017-09-14 16:15:00+03	2017-09-14 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23415	PG0422	2017-09-14 11:20:00+03	2017-09-14 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23416	PG0423	2017-08-23 16:15:00+03	2017-08-23 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23417	PG0422	2017-08-23 11:20:00+03	2017-08-23 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23418	PG0422	2017-08-26 11:20:00+03	2017-08-26 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23419	PG0423	2017-08-26 16:15:00+03	2017-08-26 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23420	PG0422	2017-07-18 11:20:00+03	2017-07-18 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-18 11:24:00+03	2017-07-18 14:04:00+03
23421	PG0423	2017-07-18 16:15:00+03	2017-07-18 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-18 16:18:00+03	2017-07-18 18:56:00+03
23422	PG0423	2017-08-22 16:15:00+03	2017-08-22 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23423	PG0422	2017-08-22 11:20:00+03	2017-08-22 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23424	PG0423	2017-09-13 16:15:00+03	2017-09-13 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23425	PG0422	2017-09-13 11:20:00+03	2017-09-13 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23426	PG0422	2017-07-19 11:20:00+03	2017-07-19 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-19 11:22:00+03	2017-07-19 14:00:00+03
23427	PG0423	2017-07-19 16:15:00+03	2017-07-19 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-19 16:18:00+03	2017-07-19 18:59:00+03
23428	PG0423	2017-08-21 16:15:00+03	2017-08-21 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23429	PG0422	2017-08-21 11:20:00+03	2017-08-21 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23430	PG0422	2017-07-20 11:20:00+03	2017-07-20 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-20 11:23:00+03	2017-07-20 14:05:00+03
23431	PG0423	2017-07-20 16:15:00+03	2017-07-20 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-20 16:15:00+03	2017-07-20 18:53:00+03
23432	PG0422	2017-08-27 11:20:00+03	2017-08-27 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23433	PG0423	2017-08-27 16:15:00+03	2017-08-27 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23434	PG0423	2017-09-12 16:15:00+03	2017-09-12 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23435	PG0422	2017-09-12 11:20:00+03	2017-09-12 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23436	PG0423	2017-08-20 16:15:00+03	2017-08-20 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23437	PG0422	2017-08-20 11:20:00+03	2017-08-20 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23438	PG0422	2017-07-21 11:20:00+03	2017-07-21 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-21 11:24:00+03	2017-07-21 14:03:00+03
23439	PG0423	2017-07-21 16:15:00+03	2017-07-21 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-21 16:21:00+03	2017-07-21 19:01:00+03
23440	PG0423	2017-08-19 16:15:00+03	2017-08-19 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23441	PG0422	2017-08-19 11:20:00+03	2017-08-19 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23442	PG0422	2017-07-22 11:20:00+03	2017-07-22 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-22 11:26:00+03	2017-07-22 14:07:00+03
23443	PG0423	2017-07-22 16:15:00+03	2017-07-22 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-22 16:17:00+03	2017-07-22 18:57:00+03
23444	PG0423	2017-09-11 16:15:00+03	2017-09-11 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23445	PG0422	2017-09-11 11:20:00+03	2017-09-11 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23446	PG0422	2017-08-28 11:20:00+03	2017-08-28 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23447	PG0423	2017-08-28 16:15:00+03	2017-08-28 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23448	PG0422	2017-07-23 11:20:00+03	2017-07-23 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-23 11:21:00+03	2017-07-23 14:01:00+03
23449	PG0423	2017-07-23 16:15:00+03	2017-07-23 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-23 16:16:00+03	2017-07-23 18:54:00+03
23450	PG0423	2017-08-18 16:15:00+03	2017-08-18 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23451	PG0422	2017-08-18 11:20:00+03	2017-08-18 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23452	PG0422	2017-07-24 11:20:00+03	2017-07-24 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-24 11:25:00+03	2017-07-24 14:05:00+03
23453	PG0423	2017-07-24 16:15:00+03	2017-07-24 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-24 16:18:00+03	2017-07-24 19:01:00+03
23454	PG0423	2017-08-17 16:15:00+03	2017-08-17 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23455	PG0422	2017-08-17 11:20:00+03	2017-08-17 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23456	PG0423	2017-09-10 16:15:00+03	2017-09-10 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23457	PG0422	2017-09-10 11:20:00+03	2017-09-10 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23458	PG0422	2017-08-29 11:20:00+03	2017-08-29 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23459	PG0423	2017-08-29 16:15:00+03	2017-08-29 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23460	PG0422	2017-07-25 11:20:00+03	2017-07-25 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-25 11:24:00+03	2017-07-25 14:05:00+03
23461	PG0423	2017-07-25 16:15:00+03	2017-07-25 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-25 16:17:00+03	2017-07-25 18:58:00+03
23462	PG0423	2017-08-16 16:15:00+03	2017-08-16 18:55:00+03	VKT	SGC	On Time	CN1	\N	\N
23463	PG0422	2017-08-16 11:20:00+03	2017-08-16 14:00:00+03	VKT	SGC	On Time	CN1	\N	\N
23464	PG0422	2017-07-26 11:20:00+03	2017-07-26 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-26 11:25:00+03	2017-07-26 14:09:00+03
23465	PG0423	2017-07-26 16:15:00+03	2017-07-26 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-26 16:17:00+03	2017-07-26 18:58:00+03
23466	PG0423	2017-09-09 16:15:00+03	2017-09-09 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23467	PG0422	2017-09-09 11:20:00+03	2017-09-09 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23468	PG0423	2017-08-15 16:15:00+03	2017-08-15 18:55:00+03	VKT	SGC	Departed	CN1	2017-08-15 16:16:00+03	\N
23469	PG0422	2017-08-15 11:20:00+03	2017-08-15 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-15 11:22:00+03	2017-08-15 14:03:00+03
23470	PG0422	2017-08-30 11:20:00+03	2017-08-30 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23471	PG0423	2017-08-30 16:15:00+03	2017-08-30 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23472	PG0422	2017-07-27 11:20:00+03	2017-07-27 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-27 14:19:00+03	2017-07-27 16:58:00+03
23473	PG0423	2017-07-27 16:15:00+03	2017-07-27 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-27 16:18:00+03	2017-07-27 18:59:00+03
23474	PG0423	2017-08-14 16:15:00+03	2017-08-14 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-14 16:15:00+03	2017-08-14 18:56:00+03
23475	PG0422	2017-08-14 11:20:00+03	2017-08-14 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-14 11:21:00+03	2017-08-14 13:58:00+03
23476	PG0422	2017-07-28 11:20:00+03	2017-07-28 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-28 11:22:00+03	2017-07-28 14:00:00+03
23477	PG0423	2017-07-28 16:15:00+03	2017-07-28 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-28 16:19:00+03	2017-07-28 18:59:00+03
23478	PG0423	2017-09-08 16:15:00+03	2017-09-08 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23479	PG0422	2017-09-08 11:20:00+03	2017-09-08 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23480	PG0423	2017-08-13 16:15:00+03	2017-08-13 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-13 16:17:00+03	2017-08-13 18:59:00+03
23481	PG0422	2017-07-29 11:20:00+03	2017-07-29 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-29 11:21:00+03	2017-07-29 14:01:00+03
23482	PG0423	2017-07-29 16:15:00+03	2017-07-29 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-29 18:53:00+03	2017-07-29 21:33:00+03
23483	PG0422	2017-08-31 11:20:00+03	2017-08-31 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23484	PG0423	2017-08-31 16:15:00+03	2017-08-31 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23485	PG0423	2017-09-07 16:15:00+03	2017-09-07 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23486	PG0422	2017-09-07 11:20:00+03	2017-09-07 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23487	PG0423	2017-08-12 16:15:00+03	2017-08-12 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-12 16:22:00+03	2017-08-12 19:02:00+03
23488	PG0422	2017-08-12 11:20:00+03	2017-08-12 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-12 11:21:00+03	2017-08-12 14:00:00+03
23489	PG0422	2017-07-30 11:20:00+03	2017-07-30 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-30 11:24:00+03	2017-07-30 14:04:00+03
23490	PG0423	2017-07-30 16:15:00+03	2017-07-30 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-30 16:18:00+03	2017-07-30 18:57:00+03
23491	PG0422	2017-07-31 11:20:00+03	2017-07-31 14:00:00+03	VKT	SGC	Arrived	CN1	2017-07-31 11:23:00+03	2017-07-31 14:04:00+03
23492	PG0423	2017-07-31 16:15:00+03	2017-07-31 18:55:00+03	VKT	SGC	Arrived	CN1	2017-07-31 16:17:00+03	2017-07-31 18:56:00+03
23493	PG0423	2017-08-11 16:15:00+03	2017-08-11 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-11 16:15:00+03	2017-08-11 18:53:00+03
23494	PG0422	2017-08-11 11:20:00+03	2017-08-11 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-11 11:23:00+03	2017-08-11 14:03:00+03
23495	PG0422	2017-09-01 11:20:00+03	2017-09-01 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23496	PG0423	2017-09-01 16:15:00+03	2017-09-01 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23497	PG0423	2017-09-06 16:15:00+03	2017-09-06 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23498	PG0422	2017-09-06 11:20:00+03	2017-09-06 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23499	PG0422	2017-08-01 11:20:00+03	2017-08-01 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-01 11:23:00+03	2017-08-01 14:04:00+03
23500	PG0423	2017-08-01 16:15:00+03	2017-08-01 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-01 16:16:00+03	2017-08-01 18:55:00+03
23501	PG0423	2017-08-10 16:15:00+03	2017-08-10 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-10 16:20:00+03	2017-08-10 19:00:00+03
23502	PG0422	2017-08-10 11:20:00+03	2017-08-10 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-10 11:27:00+03	2017-08-10 14:08:00+03
23503	PG0422	2017-08-02 11:20:00+03	2017-08-02 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-02 14:16:00+03	2017-08-02 16:54:00+03
23504	PG0423	2017-08-02 16:15:00+03	2017-08-02 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-02 16:18:00+03	2017-08-02 18:58:00+03
23505	PG0423	2017-08-09 16:15:00+03	2017-08-09 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-09 16:19:00+03	2017-08-09 18:58:00+03
23506	PG0422	2017-08-09 11:20:00+03	2017-08-09 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-09 11:23:00+03	2017-08-09 14:04:00+03
23507	PG0422	2017-09-02 11:20:00+03	2017-09-02 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23508	PG0423	2017-09-02 16:15:00+03	2017-09-02 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23509	PG0423	2017-09-05 16:15:00+03	2017-09-05 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23510	PG0422	2017-09-05 11:20:00+03	2017-09-05 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23511	PG0422	2017-08-03 11:20:00+03	2017-08-03 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-03 11:29:00+03	2017-08-03 14:11:00+03
23512	PG0423	2017-08-03 16:15:00+03	2017-08-03 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-03 16:19:00+03	2017-08-03 19:01:00+03
23513	PG0423	2017-08-08 16:15:00+03	2017-08-08 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-08 16:19:00+03	2017-08-08 18:57:00+03
23514	PG0422	2017-08-08 11:20:00+03	2017-08-08 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-08 11:24:00+03	2017-08-08 14:04:00+03
23515	PG0423	2017-08-04 16:15:00+03	2017-08-04 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-04 16:17:00+03	2017-08-04 18:56:00+03
23516	PG0423	2017-08-07 16:15:00+03	2017-08-07 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-07 16:19:00+03	2017-08-07 18:58:00+03
23517	PG0422	2017-08-07 11:20:00+03	2017-08-07 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-07 11:24:00+03	2017-08-07 14:06:00+03
23518	PG0422	2017-09-03 11:20:00+03	2017-09-03 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23519	PG0423	2017-09-03 16:15:00+03	2017-09-03 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23520	PG0423	2017-09-04 16:15:00+03	2017-09-04 18:55:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23521	PG0422	2017-09-04 11:20:00+03	2017-09-04 14:00:00+03	VKT	SGC	Scheduled	CN1	\N	\N
23522	PG0422	2017-08-05 11:20:00+03	2017-08-05 14:00:00+03	VKT	SGC	Arrived	CN1	2017-08-05 11:23:00+03	2017-08-05 14:03:00+03
23523	PG0423	2017-08-05 16:15:00+03	2017-08-05 18:55:00+03	VKT	SGC	Arrived	CN1	2017-08-05 16:18:00+03	2017-08-05 18:56:00+03
23524	PG0020	2017-08-07 10:10:00+03	2017-08-07 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-07 10:11:00+03	2017-08-07 11:31:00+03
23525	PG0020	2017-08-29 10:10:00+03	2017-08-29 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23526	PG0020	2017-09-07 10:10:00+03	2017-09-07 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23527	PG0020	2017-08-04 10:10:00+03	2017-08-04 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-04 10:12:00+03	2017-08-04 11:33:00+03
23528	PG0020	2017-09-12 10:10:00+03	2017-09-12 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23529	PG0020	2017-08-18 10:10:00+03	2017-08-18 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23530	PG0020	2017-09-08 10:10:00+03	2017-09-08 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23531	PG0020	2017-07-29 10:10:00+03	2017-07-29 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-29 10:17:00+03	2017-07-29 11:37:00+03
23532	PG0020	2017-09-09 10:10:00+03	2017-09-09 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23533	PG0020	2017-08-08 10:10:00+03	2017-08-08 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-08 10:13:00+03	2017-08-08 11:33:00+03
23534	PG0020	2017-07-23 10:10:00+03	2017-07-23 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-23 10:17:00+03	2017-07-23 11:35:00+03
23535	PG0020	2017-07-17 10:10:00+03	2017-07-17 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-17 10:10:00+03	2017-07-17 11:30:00+03
23536	PG0020	2017-08-06 10:10:00+03	2017-08-06 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-06 10:13:00+03	2017-08-06 11:33:00+03
23537	PG0020	2017-08-31 10:10:00+03	2017-08-31 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23538	PG0020	2017-07-22 10:10:00+03	2017-07-22 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-22 10:14:00+03	2017-07-22 11:34:00+03
23539	PG0020	2017-08-24 10:10:00+03	2017-08-24 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23540	PG0020	2017-08-05 10:10:00+03	2017-08-05 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-05 10:11:00+03	2017-08-05 11:30:00+03
23541	PG0020	2017-08-13 10:10:00+03	2017-08-13 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-13 10:15:00+03	2017-08-13 11:36:00+03
23542	PG0020	2017-07-16 10:10:00+03	2017-07-16 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-16 10:12:00+03	2017-07-16 11:32:00+03
23543	PG0020	2017-09-14 10:10:00+03	2017-09-14 11:30:00+03	UUA	DME	Cancelled	CR2	\N	\N
23544	PG0020	2017-08-28 10:10:00+03	2017-08-28 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23545	PG0020	2017-09-03 10:10:00+03	2017-09-03 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23546	PG0020	2017-08-09 10:10:00+03	2017-08-09 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-09 10:13:00+03	2017-08-09 11:33:00+03
23547	PG0020	2017-08-20 10:10:00+03	2017-08-20 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23548	PG0020	2017-08-23 10:10:00+03	2017-08-23 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23549	PG0020	2017-08-27 10:10:00+03	2017-08-27 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23550	PG0020	2017-07-27 10:10:00+03	2017-07-27 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-27 10:12:00+03	2017-07-27 11:33:00+03
23551	PG0020	2017-08-21 10:10:00+03	2017-08-21 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23552	PG0020	2017-07-19 10:10:00+03	2017-07-19 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-19 10:12:00+03	2017-07-19 11:32:00+03
23553	PG0020	2017-08-25 10:10:00+03	2017-08-25 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23554	PG0020	2017-09-06 10:10:00+03	2017-09-06 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23555	PG0020	2017-09-04 10:10:00+03	2017-09-04 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23556	PG0020	2017-08-02 10:10:00+03	2017-08-02 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-02 10:13:00+03	2017-08-02 11:32:00+03
23557	PG0020	2017-08-11 10:10:00+03	2017-08-11 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-11 10:12:00+03	2017-08-11 11:33:00+03
23558	PG0020	2017-07-28 10:10:00+03	2017-07-28 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-28 10:14:00+03	2017-07-28 11:34:00+03
23559	PG0020	2017-08-12 10:10:00+03	2017-08-12 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-12 10:11:00+03	2017-08-12 11:31:00+03
23560	PG0020	2017-09-10 10:10:00+03	2017-09-10 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23561	PG0020	2017-07-25 10:10:00+03	2017-07-25 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-25 10:12:00+03	2017-07-25 11:32:00+03
23562	PG0020	2017-09-11 10:10:00+03	2017-09-11 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23563	PG0020	2017-08-14 10:10:00+03	2017-08-14 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-14 10:14:00+03	2017-08-14 11:32:00+03
23564	PG0020	2017-08-10 10:10:00+03	2017-08-10 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-10 10:15:00+03	2017-08-10 11:33:00+03
23565	PG0020	2017-08-16 10:10:00+03	2017-08-16 11:30:00+03	UUA	DME	On Time	CR2	\N	\N
23566	PG0020	2017-08-17 10:10:00+03	2017-08-17 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23567	PG0020	2017-08-01 10:10:00+03	2017-08-01 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-01 10:12:00+03	2017-08-01 11:33:00+03
23568	PG0020	2017-07-31 10:10:00+03	2017-07-31 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-31 10:12:00+03	2017-07-31 11:32:00+03
23569	PG0020	2017-07-26 10:10:00+03	2017-07-26 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-26 10:13:00+03	2017-07-26 11:32:00+03
23570	PG0020	2017-07-30 10:10:00+03	2017-07-30 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-30 10:11:00+03	2017-07-30 11:31:00+03
23571	PG0020	2017-08-15 10:10:00+03	2017-08-15 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-15 10:12:00+03	2017-08-15 11:31:00+03
23572	PG0020	2017-07-20 10:10:00+03	2017-07-20 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-20 10:10:00+03	2017-07-20 11:30:00+03
23573	PG0020	2017-08-30 10:10:00+03	2017-08-30 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23574	PG0020	2017-09-01 10:10:00+03	2017-09-01 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23575	PG0020	2017-09-13 10:10:00+03	2017-09-13 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23576	PG0020	2017-08-26 10:10:00+03	2017-08-26 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23577	PG0020	2017-07-21 10:10:00+03	2017-07-21 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-21 10:13:00+03	2017-07-21 11:33:00+03
23578	PG0020	2017-07-24 10:10:00+03	2017-07-24 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-24 10:14:00+03	2017-07-24 11:32:00+03
23579	PG0020	2017-07-18 10:10:00+03	2017-07-18 11:30:00+03	UUA	DME	Arrived	CR2	2017-07-18 10:12:00+03	2017-07-18 11:32:00+03
23580	PG0020	2017-08-19 10:10:00+03	2017-08-19 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23581	PG0020	2017-08-03 10:10:00+03	2017-08-03 11:30:00+03	UUA	DME	Arrived	CR2	2017-08-03 10:12:00+03	2017-08-03 11:32:00+03
23582	PG0020	2017-08-22 10:10:00+03	2017-08-22 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23583	PG0020	2017-09-05 10:10:00+03	2017-09-05 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23584	PG0020	2017-09-02 10:10:00+03	2017-09-02 11:30:00+03	UUA	DME	Scheduled	CR2	\N	\N
23585	PG0648	2017-07-31 11:35:00+03	2017-07-31 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-31 11:36:00+03	2017-07-31 13:02:00+03
23586	PG0648	2017-08-29 11:35:00+03	2017-08-29 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23587	PG0648	2017-08-08 11:35:00+03	2017-08-08 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-08 11:39:00+03	2017-08-08 13:04:00+03
23588	PG0648	2017-08-24 11:35:00+03	2017-08-24 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23589	PG0648	2017-09-07 11:35:00+03	2017-09-07 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23590	PG0648	2017-09-06 11:35:00+03	2017-09-06 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23591	PG0648	2017-08-09 11:35:00+03	2017-08-09 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-09 11:41:00+03	2017-08-09 13:06:00+03
23592	PG0648	2017-07-21 11:35:00+03	2017-07-21 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-21 11:36:00+03	2017-07-21 13:01:00+03
23593	PG0648	2017-09-09 11:35:00+03	2017-09-09 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23594	PG0648	2017-09-14 11:35:00+03	2017-09-14 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23595	PG0648	2017-09-12 11:35:00+03	2017-09-12 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23596	PG0648	2017-08-21 11:35:00+03	2017-08-21 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23597	PG0648	2017-07-27 11:35:00+03	2017-07-27 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-27 11:35:00+03	2017-07-27 12:59:00+03
23598	PG0648	2017-08-16 11:35:00+03	2017-08-16 13:00:00+03	UUA	SVO	On Time	CR2	\N	\N
23599	PG0648	2017-07-20 11:35:00+03	2017-07-20 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-20 11:39:00+03	2017-07-20 13:05:00+03
23600	PG0648	2017-09-08 11:35:00+03	2017-09-08 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23601	PG0648	2017-08-03 11:35:00+03	2017-08-03 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-03 11:39:00+03	2017-08-03 13:05:00+03
23602	PG0648	2017-07-16 11:35:00+03	2017-07-16 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-16 11:36:00+03	2017-07-16 13:01:00+03
23603	PG0648	2017-08-02 11:35:00+03	2017-08-02 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-02 11:38:00+03	2017-08-02 13:03:00+03
23604	PG0648	2017-08-01 11:35:00+03	2017-08-01 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-01 11:38:00+03	2017-08-01 13:03:00+03
23605	PG0648	2017-08-15 11:35:00+03	2017-08-15 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-15 11:37:00+03	2017-08-15 13:02:00+03
23606	PG0648	2017-09-02 11:35:00+03	2017-09-02 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23607	PG0648	2017-08-30 11:35:00+03	2017-08-30 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23608	PG0648	2017-07-24 11:35:00+03	2017-07-24 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-24 11:38:00+03	2017-07-24 13:05:00+03
23610	PG0648	2017-09-03 11:35:00+03	2017-09-03 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23611	PG0648	2017-09-13 11:35:00+03	2017-09-13 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23612	PG0648	2017-07-22 11:35:00+03	2017-07-22 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-22 11:41:00+03	2017-07-22 13:06:00+03
23613	PG0648	2017-07-17 11:35:00+03	2017-07-17 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-17 15:05:00+03	2017-07-17 16:29:00+03
23614	PG0648	2017-09-04 11:35:00+03	2017-09-04 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23615	PG0648	2017-08-11 11:35:00+03	2017-08-11 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-11 11:40:00+03	2017-08-11 13:04:00+03
23616	PG0648	2017-08-07 11:35:00+03	2017-08-07 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-07 14:58:00+03	2017-08-07 16:23:00+03
23617	PG0648	2017-09-11 11:35:00+03	2017-09-11 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23618	PG0648	2017-08-22 11:35:00+03	2017-08-22 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23619	PG0648	2017-09-01 11:35:00+03	2017-09-01 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23620	PG0648	2017-08-14 11:35:00+03	2017-08-14 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-14 11:36:00+03	2017-08-14 13:01:00+03
23621	PG0648	2017-08-25 11:35:00+03	2017-08-25 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23622	PG0648	2017-07-25 11:35:00+03	2017-07-25 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-25 11:37:00+03	2017-07-25 13:00:00+03
23623	PG0648	2017-08-04 11:35:00+03	2017-08-04 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-04 11:37:00+03	2017-08-04 13:01:00+03
23624	PG0648	2017-07-18 11:35:00+03	2017-07-18 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-18 11:38:00+03	2017-07-18 13:04:00+03
23625	PG0648	2017-07-19 11:35:00+03	2017-07-19 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-19 11:36:00+03	2017-07-19 13:00:00+03
23626	PG0648	2017-08-05 11:35:00+03	2017-08-05 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-05 11:35:00+03	2017-08-05 13:01:00+03
23627	PG0648	2017-08-20 11:35:00+03	2017-08-20 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23628	PG0648	2017-08-17 11:35:00+03	2017-08-17 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23629	PG0648	2017-07-26 11:35:00+03	2017-07-26 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-26 11:39:00+03	2017-07-26 13:05:00+03
23630	PG0648	2017-07-28 11:35:00+03	2017-07-28 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-28 11:39:00+03	2017-07-28 13:03:00+03
23631	PG0648	2017-08-13 11:35:00+03	2017-08-13 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-13 11:38:00+03	2017-08-13 13:04:00+03
23632	PG0648	2017-09-10 11:35:00+03	2017-09-10 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23633	PG0648	2017-08-10 11:35:00+03	2017-08-10 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-10 11:36:00+03	2017-08-10 13:01:00+03
23634	PG0648	2017-08-19 11:35:00+03	2017-08-19 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23635	PG0648	2017-08-26 11:35:00+03	2017-08-26 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23636	PG0648	2017-08-06 11:35:00+03	2017-08-06 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-06 11:37:00+03	2017-08-06 13:03:00+03
23637	PG0648	2017-07-30 11:35:00+03	2017-07-30 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-30 11:39:00+03	2017-07-30 13:03:00+03
23638	PG0648	2017-08-12 11:35:00+03	2017-08-12 13:00:00+03	UUA	SVO	Arrived	CR2	2017-08-12 11:39:00+03	2017-08-12 13:05:00+03
23639	PG0648	2017-07-23 11:35:00+03	2017-07-23 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-23 11:37:00+03	2017-07-23 13:02:00+03
23640	PG0648	2017-08-28 11:35:00+03	2017-08-28 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23641	PG0648	2017-08-27 11:35:00+03	2017-08-27 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23642	PG0648	2017-08-23 11:35:00+03	2017-08-23 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23643	PG0648	2017-08-18 11:35:00+03	2017-08-18 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23644	PG0648	2017-09-05 11:35:00+03	2017-09-05 13:00:00+03	UUA	SVO	Scheduled	CR2	\N	\N
23645	PG0648	2017-07-29 11:35:00+03	2017-07-29 13:00:00+03	UUA	SVO	Arrived	CR2	2017-07-29 11:36:00+03	2017-07-29 13:01:00+03
23646	PG0388	2017-08-25 10:55:00+03	2017-08-25 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23647	PG0388	2017-07-18 10:55:00+03	2017-07-18 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-18 10:59:00+03	2017-07-18 11:30:00+03
23648	PG0388	2017-07-20 10:55:00+03	2017-07-20 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-20 10:59:00+03	2017-07-20 11:29:00+03
23649	PG0388	2017-09-02 10:55:00+03	2017-09-02 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23650	PG0388	2017-07-28 10:55:00+03	2017-07-28 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-28 11:00:00+03	2017-07-28 11:30:00+03
23651	PG0388	2017-08-17 10:55:00+03	2017-08-17 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23652	PG0388	2017-09-07 10:55:00+03	2017-09-07 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23653	PG0388	2017-08-24 10:55:00+03	2017-08-24 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23654	PG0388	2017-08-31 10:55:00+03	2017-08-31 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23655	PG0388	2017-07-23 10:55:00+03	2017-07-23 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-23 10:57:00+03	2017-07-23 11:28:00+03
23656	PG0388	2017-08-27 10:55:00+03	2017-08-27 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23657	PG0388	2017-08-12 10:55:00+03	2017-08-12 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-12 10:59:00+03	2017-08-12 11:29:00+03
23658	PG0388	2017-08-23 10:55:00+03	2017-08-23 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23659	PG0388	2017-09-10 10:55:00+03	2017-09-10 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23660	PG0388	2017-08-02 10:55:00+03	2017-08-02 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-02 10:59:00+03	2017-08-02 11:29:00+03
23661	PG0388	2017-07-30 10:55:00+03	2017-07-30 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-30 10:56:00+03	2017-07-30 11:26:00+03
23662	PG0388	2017-07-31 10:55:00+03	2017-07-31 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-31 10:59:00+03	2017-07-31 11:30:00+03
23663	PG0388	2017-08-05 10:55:00+03	2017-08-05 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-05 10:58:00+03	2017-08-05 11:28:00+03
23664	PG0388	2017-09-12 10:55:00+03	2017-09-12 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23665	PG0388	2017-08-07 10:55:00+03	2017-08-07 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-07 10:57:00+03	2017-08-07 11:27:00+03
23666	PG0388	2017-08-04 10:55:00+03	2017-08-04 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-04 11:00:00+03	2017-08-04 11:30:00+03
23667	PG0388	2017-07-21 10:55:00+03	2017-07-21 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-21 11:02:00+03	2017-07-21 11:32:00+03
23668	PG0388	2017-08-16 10:55:00+03	2017-08-16 11:25:00+03	UUA	REN	On Time	CR2	\N	\N
23669	PG0388	2017-09-03 10:55:00+03	2017-09-03 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23670	PG0388	2017-08-09 10:55:00+03	2017-08-09 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-09 10:56:00+03	2017-08-09 11:26:00+03
23671	PG0388	2017-07-29 10:55:00+03	2017-07-29 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-29 10:57:00+03	2017-07-29 11:27:00+03
23672	PG0388	2017-07-27 10:55:00+03	2017-07-27 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-27 10:59:00+03	2017-07-27 11:29:00+03
23673	PG0388	2017-09-05 10:55:00+03	2017-09-05 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23674	PG0388	2017-08-15 10:55:00+03	2017-08-15 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-15 11:00:00+03	2017-08-15 11:31:00+03
23675	PG0388	2017-08-08 10:55:00+03	2017-08-08 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-08 10:59:00+03	2017-08-08 11:30:00+03
23676	PG0388	2017-08-21 10:55:00+03	2017-08-21 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23677	PG0388	2017-08-14 10:55:00+03	2017-08-14 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-14 10:58:00+03	2017-08-14 11:28:00+03
23678	PG0388	2017-07-26 10:55:00+03	2017-07-26 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-26 10:56:00+03	2017-07-26 11:26:00+03
23679	PG0388	2017-09-14 10:55:00+03	2017-09-14 11:25:00+03	UUA	REN	Cancelled	CR2	\N	\N
23680	PG0388	2017-09-01 10:55:00+03	2017-09-01 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23681	PG0388	2017-08-03 10:55:00+03	2017-08-03 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-03 10:59:00+03	2017-08-03 11:28:00+03
23682	PG0388	2017-08-22 10:55:00+03	2017-08-22 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23683	PG0388	2017-09-04 10:55:00+03	2017-09-04 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23684	PG0388	2017-08-18 10:55:00+03	2017-08-18 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23685	PG0388	2017-08-19 10:55:00+03	2017-08-19 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23686	PG0388	2017-07-22 10:55:00+03	2017-07-22 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-22 10:58:00+03	2017-07-22 11:28:00+03
23687	PG0388	2017-09-06 10:55:00+03	2017-09-06 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23688	PG0388	2017-08-28 10:55:00+03	2017-08-28 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23689	PG0388	2017-07-19 10:55:00+03	2017-07-19 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-19 11:00:00+03	2017-07-19 11:30:00+03
23690	PG0388	2017-08-01 10:55:00+03	2017-08-01 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-01 10:55:00+03	2017-08-01 11:25:00+03
23691	PG0388	2017-08-20 10:55:00+03	2017-08-20 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23692	PG0388	2017-08-13 10:55:00+03	2017-08-13 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-13 10:58:00+03	2017-08-13 11:28:00+03
23693	PG0388	2017-07-16 10:55:00+03	2017-07-16 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-16 10:58:00+03	2017-07-16 11:28:00+03
23694	PG0388	2017-08-06 10:55:00+03	2017-08-06 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-06 10:58:00+03	2017-08-06 11:28:00+03
23696	PG0388	2017-09-08 10:55:00+03	2017-09-08 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23697	PG0388	2017-07-24 10:55:00+03	2017-07-24 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-24 10:59:00+03	2017-07-24 11:29:00+03
23698	PG0388	2017-09-09 10:55:00+03	2017-09-09 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23699	PG0388	2017-07-25 10:55:00+03	2017-07-25 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-25 11:01:00+03	2017-07-25 11:31:00+03
23700	PG0388	2017-08-10 10:55:00+03	2017-08-10 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-10 10:55:00+03	2017-08-10 11:25:00+03
23701	PG0388	2017-07-17 10:55:00+03	2017-07-17 11:25:00+03	UUA	REN	Arrived	CR2	2017-07-17 10:59:00+03	2017-07-17 11:30:00+03
23702	PG0388	2017-09-13 10:55:00+03	2017-09-13 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23703	PG0388	2017-09-11 10:55:00+03	2017-09-11 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23704	PG0388	2017-08-29 10:55:00+03	2017-08-29 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23705	PG0388	2017-08-11 10:55:00+03	2017-08-11 11:25:00+03	UUA	REN	Arrived	CR2	2017-08-11 10:56:00+03	2017-08-11 11:26:00+03
23706	PG0388	2017-08-30 10:55:00+03	2017-08-30 11:25:00+03	UUA	REN	Scheduled	CR2	\N	\N
23707	PG0022	2017-08-08 10:30:00+03	2017-08-08 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-08 10:33:00+03	2017-08-08 13:14:00+03
23708	PG0022	2017-08-06 10:30:00+03	2017-08-06 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-06 10:32:00+03	2017-08-06 13:15:00+03
23709	PG0022	2017-08-24 10:30:00+03	2017-08-24 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23710	PG0022	2017-08-26 10:30:00+03	2017-08-26 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23711	PG0022	2017-08-16 10:30:00+03	2017-08-16 13:10:00+03	UKX	KJA	On Time	CN1	\N	\N
23712	PG0022	2017-08-30 10:30:00+03	2017-08-30 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23713	PG0022	2017-08-03 10:30:00+03	2017-08-03 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-03 10:34:00+03	2017-08-03 13:17:00+03
23714	PG0022	2017-09-12 10:30:00+03	2017-09-12 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23715	PG0022	2017-08-23 10:30:00+03	2017-08-23 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23716	PG0022	2017-08-25 10:30:00+03	2017-08-25 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23717	PG0022	2017-07-22 10:30:00+03	2017-07-22 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-22 10:33:00+03	2017-07-22 13:12:00+03
23718	PG0022	2017-08-09 10:30:00+03	2017-08-09 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-09 10:32:00+03	2017-08-09 13:11:00+03
23719	PG0022	2017-08-20 10:30:00+03	2017-08-20 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23720	PG0022	2017-07-23 10:30:00+03	2017-07-23 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-23 10:36:00+03	2017-07-23 13:17:00+03
23721	PG0022	2017-08-19 10:30:00+03	2017-08-19 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23722	PG0022	2017-07-30 10:30:00+03	2017-07-30 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-30 10:34:00+03	2017-07-30 13:16:00+03
23723	PG0022	2017-08-28 10:30:00+03	2017-08-28 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23724	PG0022	2017-09-07 10:30:00+03	2017-09-07 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23725	PG0022	2017-08-13 10:30:00+03	2017-08-13 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-13 10:31:00+03	2017-08-13 13:12:00+03
23726	PG0022	2017-08-07 10:30:00+03	2017-08-07 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-07 10:34:00+03	2017-08-07 13:14:00+03
23727	PG0022	2017-07-19 10:30:00+03	2017-07-19 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-19 10:32:00+03	2017-07-19 13:13:00+03
23728	PG0022	2017-09-08 10:30:00+03	2017-09-08 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23729	PG0022	2017-07-27 10:30:00+03	2017-07-27 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-27 10:33:00+03	2017-07-27 13:11:00+03
23730	PG0022	2017-09-01 10:30:00+03	2017-09-01 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23731	PG0022	2017-07-26 10:30:00+03	2017-07-26 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-26 10:32:00+03	2017-07-26 13:11:00+03
23732	PG0022	2017-08-01 10:30:00+03	2017-08-01 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-01 10:31:00+03	2017-08-01 13:10:00+03
23733	PG0022	2017-08-11 10:30:00+03	2017-08-11 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-11 10:33:00+03	2017-08-11 13:14:00+03
23734	PG0022	2017-09-11 10:30:00+03	2017-09-11 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23735	PG0022	2017-07-16 10:30:00+03	2017-07-16 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-16 10:32:00+03	2017-07-16 13:12:00+03
23736	PG0022	2017-09-13 10:30:00+03	2017-09-13 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23737	PG0022	2017-07-18 10:30:00+03	2017-07-18 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-18 10:34:00+03	2017-07-18 13:17:00+03
23738	PG0022	2017-07-24 10:30:00+03	2017-07-24 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-24 10:33:00+03	2017-07-24 13:13:00+03
23739	PG0022	2017-08-29 10:30:00+03	2017-08-29 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23740	PG0022	2017-07-17 10:30:00+03	2017-07-17 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-17 10:35:00+03	2017-07-17 13:17:00+03
23741	PG0022	2017-08-18 10:30:00+03	2017-08-18 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23742	PG0022	2017-07-29 10:30:00+03	2017-07-29 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-29 10:34:00+03	2017-07-29 13:12:00+03
23743	PG0022	2017-08-05 10:30:00+03	2017-08-05 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-05 10:35:00+03	2017-08-05 13:11:00+03
23744	PG0022	2017-07-31 10:30:00+03	2017-07-31 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-31 10:33:00+03	2017-07-31 13:11:00+03
23745	PG0022	2017-08-12 10:30:00+03	2017-08-12 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-12 10:32:00+03	2017-08-12 13:16:00+03
23746	PG0022	2017-08-14 10:30:00+03	2017-08-14 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-14 10:35:00+03	2017-08-14 13:16:00+03
23747	PG0022	2017-09-10 10:30:00+03	2017-09-10 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23748	PG0022	2017-08-21 10:30:00+03	2017-08-21 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23749	PG0022	2017-08-27 10:30:00+03	2017-08-27 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23750	PG0022	2017-09-06 10:30:00+03	2017-09-06 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23751	PG0022	2017-09-04 10:30:00+03	2017-09-04 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23752	PG0022	2017-08-31 10:30:00+03	2017-08-31 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23753	PG0022	2017-09-02 10:30:00+03	2017-09-02 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23754	PG0022	2017-08-22 10:30:00+03	2017-08-22 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23755	PG0022	2017-09-05 10:30:00+03	2017-09-05 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23756	PG0022	2017-07-21 10:30:00+03	2017-07-21 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-21 10:33:00+03	2017-07-21 13:09:00+03
23757	PG0022	2017-07-25 10:30:00+03	2017-07-25 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-25 10:35:00+03	2017-07-25 13:13:00+03
23758	PG0022	2017-07-28 10:30:00+03	2017-07-28 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-28 10:32:00+03	2017-07-28 13:13:00+03
23759	PG0022	2017-07-20 10:30:00+03	2017-07-20 13:10:00+03	UKX	KJA	Arrived	CN1	2017-07-20 10:34:00+03	2017-07-20 13:14:00+03
23760	PG0022	2017-08-02 10:30:00+03	2017-08-02 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-02 10:32:00+03	2017-08-02 13:11:00+03
23761	PG0022	2017-08-15 10:30:00+03	2017-08-15 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-15 10:33:00+03	2017-08-15 13:11:00+03
23762	PG0022	2017-08-04 10:30:00+03	2017-08-04 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-04 10:31:00+03	2017-08-04 13:13:00+03
23763	PG0022	2017-08-17 10:30:00+03	2017-08-17 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23764	PG0022	2017-09-03 10:30:00+03	2017-09-03 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23765	PG0022	2017-09-09 10:30:00+03	2017-09-09 13:10:00+03	UKX	KJA	Scheduled	CN1	\N	\N
23766	PG0022	2017-09-14 10:30:00+03	2017-09-14 13:10:00+03	UKX	KJA	Cancelled	CN1	\N	\N
23767	PG0022	2017-08-10 10:30:00+03	2017-08-10 13:10:00+03	UKX	KJA	Arrived	CN1	2017-08-10 10:35:00+03	2017-08-10 13:17:00+03
23768	PG0098	2017-09-01 06:50:00+03	2017-09-01 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23769	PG0098	2017-08-15 06:50:00+03	2017-08-15 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-15 06:56:00+03	2017-08-15 10:33:00+03
23770	PG0098	2017-08-27 06:50:00+03	2017-08-27 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23771	PG0098	2017-08-06 06:50:00+03	2017-08-06 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-06 06:52:00+03	2017-08-06 10:30:00+03
23772	PG0098	2017-07-20 06:50:00+03	2017-07-20 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-20 06:52:00+03	2017-07-20 10:27:00+03
23773	PG0098	2017-07-21 06:50:00+03	2017-07-21 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-21 06:53:00+03	2017-07-21 10:35:00+03
23774	PG0098	2017-08-25 06:50:00+03	2017-08-25 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23775	PG0098	2017-09-10 06:50:00+03	2017-09-10 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23776	PG0098	2017-07-25 06:50:00+03	2017-07-25 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-25 06:55:00+03	2017-07-25 10:37:00+03
23777	PG0098	2017-07-30 06:50:00+03	2017-07-30 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-30 06:52:00+03	2017-07-30 10:38:00+03
23778	PG0098	2017-07-17 06:50:00+03	2017-07-17 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-17 06:51:00+03	2017-07-17 10:32:00+03
23779	PG0098	2017-07-24 06:50:00+03	2017-07-24 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-24 06:54:00+03	2017-07-24 10:36:00+03
23781	PG0098	2017-07-19 06:50:00+03	2017-07-19 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-19 06:52:00+03	2017-07-19 10:29:00+03
23782	PG0098	2017-09-12 06:50:00+03	2017-09-12 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23783	PG0098	2017-09-06 06:50:00+03	2017-09-06 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23784	PG0098	2017-08-22 06:50:00+03	2017-08-22 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23785	PG0098	2017-07-23 06:50:00+03	2017-07-23 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-23 06:52:00+03	2017-07-23 10:35:00+03
23786	PG0098	2017-08-24 06:50:00+03	2017-08-24 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23787	PG0098	2017-09-03 06:50:00+03	2017-09-03 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23788	PG0098	2017-08-12 06:50:00+03	2017-08-12 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-12 06:53:00+03	2017-08-12 10:30:00+03
23789	PG0098	2017-09-05 06:50:00+03	2017-09-05 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23790	PG0098	2017-08-30 06:50:00+03	2017-08-30 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23791	PG0098	2017-09-09 06:50:00+03	2017-09-09 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23792	PG0098	2017-09-07 06:50:00+03	2017-09-07 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23793	PG0098	2017-08-19 06:50:00+03	2017-08-19 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23794	PG0098	2017-07-27 06:50:00+03	2017-07-27 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-27 06:53:00+03	2017-07-27 10:34:00+03
23795	PG0098	2017-08-29 06:50:00+03	2017-08-29 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23796	PG0098	2017-09-08 06:50:00+03	2017-09-08 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23797	PG0098	2017-08-13 06:50:00+03	2017-08-13 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-13 06:54:00+03	2017-08-13 10:33:00+03
23798	PG0098	2017-09-11 06:50:00+03	2017-09-11 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23799	PG0098	2017-07-26 06:50:00+03	2017-07-26 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-26 06:51:00+03	2017-07-26 10:30:00+03
23800	PG0098	2017-07-16 06:50:00+03	2017-07-16 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-16 06:54:00+03	2017-07-16 10:34:00+03
23801	PG0098	2017-09-13 06:50:00+03	2017-09-13 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23802	PG0098	2017-08-11 06:50:00+03	2017-08-11 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-11 06:52:00+03	2017-08-11 10:32:00+03
23803	PG0098	2017-08-20 06:50:00+03	2017-08-20 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23804	PG0098	2017-08-23 06:50:00+03	2017-08-23 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23805	PG0098	2017-08-14 06:50:00+03	2017-08-14 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-14 07:00:00+03	2017-08-14 10:41:00+03
23806	PG0098	2017-08-01 06:50:00+03	2017-08-01 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-01 06:51:00+03	2017-08-01 10:33:00+03
23807	PG0098	2017-08-16 06:50:00+03	2017-08-16 10:30:00+03	SWT	CEK	On Time	CN1	\N	\N
23808	PG0098	2017-08-28 06:50:00+03	2017-08-28 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23809	PG0098	2017-08-08 06:50:00+03	2017-08-08 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-08 06:53:00+03	2017-08-08 10:33:00+03
23810	PG0098	2017-08-04 06:50:00+03	2017-08-04 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-04 06:51:00+03	2017-08-04 10:29:00+03
23811	PG0098	2017-08-21 06:50:00+03	2017-08-21 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23812	PG0098	2017-08-03 06:50:00+03	2017-08-03 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-03 06:51:00+03	2017-08-03 10:30:00+03
23813	PG0098	2017-08-18 06:50:00+03	2017-08-18 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23814	PG0098	2017-08-10 06:50:00+03	2017-08-10 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-10 10:38:00+03	2017-08-10 14:18:00+03
23815	PG0098	2017-07-18 06:50:00+03	2017-07-18 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-18 06:54:00+03	2017-07-18 10:33:00+03
23816	PG0098	2017-08-05 06:50:00+03	2017-08-05 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-05 06:53:00+03	2017-08-05 10:34:00+03
23817	PG0098	2017-07-28 06:50:00+03	2017-07-28 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-28 06:54:00+03	2017-07-28 10:33:00+03
23818	PG0098	2017-09-04 06:50:00+03	2017-09-04 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23819	PG0098	2017-08-02 06:50:00+03	2017-08-02 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-02 10:08:00+03	2017-08-02 13:47:00+03
23820	PG0098	2017-08-17 06:50:00+03	2017-08-17 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23821	PG0098	2017-07-29 06:50:00+03	2017-07-29 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-29 06:55:00+03	2017-07-29 10:35:00+03
23822	PG0098	2017-07-31 06:50:00+03	2017-07-31 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-31 06:56:00+03	2017-07-31 10:36:00+03
23823	PG0098	2017-08-07 06:50:00+03	2017-08-07 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-07 06:53:00+03	2017-08-07 10:35:00+03
23824	PG0098	2017-07-22 06:50:00+03	2017-07-22 10:30:00+03	SWT	CEK	Arrived	CN1	2017-07-22 06:53:00+03	2017-07-22 10:33:00+03
23825	PG0098	2017-08-31 06:50:00+03	2017-08-31 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23826	PG0098	2017-08-09 06:50:00+03	2017-08-09 10:30:00+03	SWT	CEK	Arrived	CN1	2017-08-09 06:51:00+03	2017-08-09 10:30:00+03
23827	PG0098	2017-08-26 06:50:00+03	2017-08-26 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23828	PG0098	2017-09-14 06:50:00+03	2017-09-14 10:30:00+03	SWT	CEK	Scheduled	CN1	\N	\N
23829	PG0250	2017-08-31 13:10:00+03	2017-08-31 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23830	PG0250	2017-08-22 13:10:00+03	2017-08-22 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23831	PG0250	2017-09-07 13:10:00+03	2017-09-07 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23832	PG0250	2017-07-20 13:10:00+03	2017-07-20 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-20 13:17:00+03	2017-07-20 15:02:00+03
23833	PG0250	2017-08-26 13:10:00+03	2017-08-26 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23834	PG0250	2017-08-24 13:10:00+03	2017-08-24 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23835	PG0250	2017-09-14 13:10:00+03	2017-09-14 14:55:00+03	GDZ	DME	Cancelled	CR2	\N	\N
23836	PG0250	2017-08-29 13:10:00+03	2017-08-29 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23837	PG0250	2017-08-03 13:10:00+03	2017-08-03 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-03 16:04:00+03	2017-08-03 17:50:00+03
23838	PG0250	2017-07-18 13:10:00+03	2017-07-18 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-18 13:11:00+03	2017-07-18 14:56:00+03
23839	PG0250	2017-08-12 13:10:00+03	2017-08-12 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-12 13:14:00+03	2017-08-12 14:59:00+03
23840	PG0250	2017-09-12 13:10:00+03	2017-09-12 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23841	PG0250	2017-07-25 13:10:00+03	2017-07-25 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-25 13:15:00+03	2017-07-25 15:01:00+03
23842	PG0250	2017-08-15 13:10:00+03	2017-08-15 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-15 13:12:00+03	2017-08-15 14:56:00+03
23843	PG0250	2017-09-09 13:10:00+03	2017-09-09 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23844	PG0250	2017-08-01 13:10:00+03	2017-08-01 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-01 13:14:00+03	2017-08-01 14:59:00+03
23845	PG0250	2017-09-02 13:10:00+03	2017-09-02 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23846	PG0250	2017-07-27 13:10:00+03	2017-07-27 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-27 13:15:00+03	2017-07-27 15:01:00+03
23847	PG0250	2017-08-19 13:10:00+03	2017-08-19 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23848	PG0250	2017-08-17 13:10:00+03	2017-08-17 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23849	PG0250	2017-08-08 13:10:00+03	2017-08-08 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-08 13:13:00+03	2017-08-08 14:55:00+03
23850	PG0250	2017-08-10 13:10:00+03	2017-08-10 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-10 13:13:00+03	2017-08-10 14:58:00+03
23851	PG0250	2017-07-29 13:10:00+03	2017-07-29 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-29 13:16:00+03	2017-07-29 15:03:00+03
23852	PG0250	2017-07-22 13:10:00+03	2017-07-22 14:55:00+03	GDZ	DME	Arrived	CR2	2017-07-22 16:05:00+03	2017-07-22 17:51:00+03
23853	PG0250	2017-08-05 13:10:00+03	2017-08-05 14:55:00+03	GDZ	DME	Arrived	CR2	2017-08-05 13:14:00+03	2017-08-05 14:57:00+03
23854	PG0250	2017-09-05 13:10:00+03	2017-09-05 14:55:00+03	GDZ	DME	Scheduled	CR2	\N	\N
23855	PG0012	2017-08-26 10:55:00+03	2017-08-26 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23856	PG0012	2017-07-18 10:55:00+03	2017-07-18 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-18 10:59:00+03	2017-07-18 12:43:00+03
23857	PG0012	2017-08-31 10:55:00+03	2017-08-31 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23858	PG0012	2017-08-08 10:55:00+03	2017-08-08 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-08 13:47:00+03	2017-08-08 15:32:00+03
23859	PG0012	2017-07-27 10:55:00+03	2017-07-27 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-27 10:57:00+03	2017-07-27 12:43:00+03
23860	PG0012	2017-08-15 10:55:00+03	2017-08-15 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-15 10:56:00+03	2017-08-15 12:42:00+03
23861	PG0012	2017-08-10 10:55:00+03	2017-08-10 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-10 10:58:00+03	2017-08-10 12:43:00+03
23862	PG0012	2017-08-01 10:55:00+03	2017-08-01 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-01 10:59:00+03	2017-08-01 12:44:00+03
23863	PG0012	2017-07-20 10:55:00+03	2017-07-20 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-20 10:58:00+03	2017-07-20 12:43:00+03
23864	PG0012	2017-09-07 10:55:00+03	2017-09-07 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23865	PG0012	2017-09-12 10:55:00+03	2017-09-12 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23866	PG0012	2017-08-24 10:55:00+03	2017-08-24 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23867	PG0012	2017-07-25 10:55:00+03	2017-07-25 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-25 10:56:00+03	2017-07-25 12:40:00+03
23868	PG0012	2017-08-17 10:55:00+03	2017-08-17 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23869	PG0012	2017-08-19 10:55:00+03	2017-08-19 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23870	PG0012	2017-08-03 10:55:00+03	2017-08-03 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-03 11:00:00+03	2017-08-03 12:46:00+03
23871	PG0012	2017-08-29 10:55:00+03	2017-08-29 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23872	PG0012	2017-09-09 10:55:00+03	2017-09-09 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23873	PG0012	2017-08-22 10:55:00+03	2017-08-22 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23874	PG0012	2017-08-12 10:55:00+03	2017-08-12 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-12 10:59:00+03	2017-08-12 12:44:00+03
23875	PG0012	2017-09-05 10:55:00+03	2017-09-05 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23876	PG0012	2017-09-14 10:55:00+03	2017-09-14 12:40:00+03	GDZ	VKO	Cancelled	CR2	\N	\N
23877	PG0012	2017-07-22 10:55:00+03	2017-07-22 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-22 10:58:00+03	2017-07-22 12:42:00+03
23878	PG0012	2017-08-05 10:55:00+03	2017-08-05 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-08-05 10:58:00+03	2017-08-05 12:44:00+03
23879	PG0012	2017-07-29 10:55:00+03	2017-07-29 12:40:00+03	GDZ	VKO	Arrived	CR2	2017-07-29 10:57:00+03	2017-07-29 12:41:00+03
23880	PG0012	2017-09-02 10:55:00+03	2017-09-02 12:40:00+03	GDZ	VKO	Scheduled	CR2	\N	\N
23881	PG0262	2017-08-01 11:20:00+03	2017-08-01 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-01 11:25:00+03	2017-08-01 13:15:00+03
23882	PG0262	2017-08-26 11:20:00+03	2017-08-26 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23883	PG0262	2017-08-15 11:20:00+03	2017-08-15 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-15 11:25:00+03	2017-08-15 13:17:00+03
23884	PG0262	2017-08-17 11:20:00+03	2017-08-17 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23885	PG0262	2017-07-27 11:20:00+03	2017-07-27 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-27 11:23:00+03	2017-07-27 13:15:00+03
23886	PG0262	2017-09-12 11:20:00+03	2017-09-12 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23887	PG0262	2017-09-07 11:20:00+03	2017-09-07 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23888	PG0262	2017-07-20 11:20:00+03	2017-07-20 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-20 11:22:00+03	2017-07-20 13:12:00+03
23889	PG0262	2017-08-05 11:20:00+03	2017-08-05 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-05 11:22:00+03	2017-08-05 13:13:00+03
23890	PG0262	2017-07-29 11:20:00+03	2017-07-29 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-29 11:21:00+03	2017-07-29 13:09:00+03
23891	PG0262	2017-08-19 11:20:00+03	2017-08-19 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23892	PG0262	2017-08-22 11:20:00+03	2017-08-22 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23893	PG0262	2017-08-03 11:20:00+03	2017-08-03 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-03 11:24:00+03	2017-08-03 13:14:00+03
23894	PG0262	2017-07-22 11:20:00+03	2017-07-22 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-22 11:22:00+03	2017-07-22 13:12:00+03
23895	PG0262	2017-09-02 11:20:00+03	2017-09-02 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23896	PG0262	2017-08-10 11:20:00+03	2017-08-10 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-10 11:22:00+03	2017-08-10 13:12:00+03
23897	PG0262	2017-07-18 11:20:00+03	2017-07-18 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-18 11:22:00+03	2017-07-18 13:09:00+03
23898	PG0262	2017-08-08 11:20:00+03	2017-08-08 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-08 11:29:00+03	2017-08-08 13:19:00+03
23899	PG0262	2017-09-05 11:20:00+03	2017-09-05 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23900	PG0262	2017-08-31 11:20:00+03	2017-08-31 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23901	PG0262	2017-07-25 11:20:00+03	2017-07-25 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-07-25 11:23:00+03	2017-07-25 13:13:00+03
23902	PG0262	2017-09-09 11:20:00+03	2017-09-09 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23903	PG0262	2017-08-29 11:20:00+03	2017-08-29 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23904	PG0262	2017-09-14 11:20:00+03	2017-09-14 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23905	PG0262	2017-08-12 11:20:00+03	2017-08-12 13:10:00+03	GDZ	SVO	Arrived	CR2	2017-08-12 11:24:00+03	2017-08-12 13:14:00+03
23906	PG0262	2017-08-24 11:20:00+03	2017-08-24 13:10:00+03	GDZ	SVO	Scheduled	CR2	\N	\N
23907	PG0528	2017-08-30 15:50:00+03	2017-08-30 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23908	PG0528	2017-08-23 15:50:00+03	2017-08-23 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23909	PG0528	2017-07-19 15:50:00+03	2017-07-19 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-07-19 15:53:00+03	2017-07-19 16:58:00+03
23910	PG0528	2017-07-26 15:50:00+03	2017-07-26 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-07-26 18:54:00+03	2017-07-26 19:59:00+03
23911	PG0528	2017-09-09 15:50:00+03	2017-09-09 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23912	PG0528	2017-09-02 15:50:00+03	2017-09-02 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23913	PG0528	2017-09-13 15:50:00+03	2017-09-13 16:55:00+03	GDZ	ROV	Cancelled	CN1	\N	\N
23914	PG0528	2017-08-12 15:50:00+03	2017-08-12 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-08-12 15:51:00+03	2017-08-12 16:56:00+03
23915	PG0528	2017-08-19 15:50:00+03	2017-08-19 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23916	PG0528	2017-08-26 15:50:00+03	2017-08-26 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23917	PG0528	2017-08-05 15:50:00+03	2017-08-05 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-08-05 15:53:00+03	2017-08-05 16:59:00+03
23918	PG0528	2017-08-02 15:50:00+03	2017-08-02 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-08-02 15:52:00+03	2017-08-02 16:56:00+03
23919	PG0528	2017-08-09 15:50:00+03	2017-08-09 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-08-09 15:55:00+03	2017-08-09 16:59:00+03
23920	PG0528	2017-07-22 15:50:00+03	2017-07-22 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-07-22 15:54:00+03	2017-07-22 16:58:00+03
23921	PG0528	2017-09-06 15:50:00+03	2017-09-06 16:55:00+03	GDZ	ROV	Scheduled	CN1	\N	\N
23922	PG0528	2017-08-16 15:50:00+03	2017-08-16 16:55:00+03	GDZ	ROV	On Time	CN1	\N	\N
23923	PG0528	2017-07-29 15:50:00+03	2017-07-29 16:55:00+03	GDZ	ROV	Arrived	CN1	2017-07-29 15:52:00+03	2017-07-29 16:56:00+03
23924	PG0034	2017-08-09 11:25:00+03	2017-08-09 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-08-09 11:26:00+03	2017-08-09 13:11:00+03
23925	PG0034	2017-07-19 11:25:00+03	2017-07-19 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-07-19 11:28:00+03	2017-07-19 13:14:00+03
23926	PG0034	2017-08-13 11:25:00+03	2017-08-13 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-08-13 11:27:00+03	2017-08-13 13:10:00+03
23927	PG0034	2017-07-26 11:25:00+03	2017-07-26 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-07-26 11:26:00+03	2017-07-26 13:10:00+03
23928	PG0034	2017-08-30 11:25:00+03	2017-08-30 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23929	PG0034	2017-08-02 11:25:00+03	2017-08-02 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-08-02 11:32:00+03	2017-08-02 13:17:00+03
23930	PG0034	2017-08-16 11:25:00+03	2017-08-16 13:10:00+03	GDZ	ESL	On Time	CN1	\N	\N
23931	PG0034	2017-09-03 11:25:00+03	2017-09-03 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23932	PG0034	2017-09-13 11:25:00+03	2017-09-13 13:10:00+03	GDZ	ESL	Cancelled	CN1	\N	\N
23933	PG0034	2017-07-30 11:25:00+03	2017-07-30 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-07-30 11:27:00+03	2017-07-30 13:12:00+03
23934	PG0034	2017-08-20 11:25:00+03	2017-08-20 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23935	PG0034	2017-07-16 11:25:00+03	2017-07-16 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-07-16 11:30:00+03	2017-07-16 13:16:00+03
23936	PG0034	2017-07-23 11:25:00+03	2017-07-23 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-07-23 11:31:00+03	2017-07-23 13:16:00+03
23937	PG0034	2017-08-23 11:25:00+03	2017-08-23 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23938	PG0034	2017-08-27 11:25:00+03	2017-08-27 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23939	PG0034	2017-09-06 11:25:00+03	2017-09-06 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23940	PG0034	2017-08-06 11:25:00+03	2017-08-06 13:10:00+03	GDZ	ESL	Arrived	CN1	2017-08-06 11:27:00+03	2017-08-06 13:12:00+03
23941	PG0034	2017-09-10 11:25:00+03	2017-09-10 13:10:00+03	GDZ	ESL	Scheduled	CN1	\N	\N
23942	PG0076	2017-07-18 09:15:00+03	2017-07-18 11:50:00+03	EYK	DME	Arrived	CR2	2017-07-18 09:19:00+03	2017-07-18 11:51:00+03
23943	PG0076	2017-08-08 09:15:00+03	2017-08-08 11:50:00+03	EYK	DME	Arrived	CR2	2017-08-08 09:17:00+03	2017-08-08 11:51:00+03
23944	PG0076	2017-08-01 09:15:00+03	2017-08-01 11:50:00+03	EYK	DME	Arrived	CR2	2017-08-01 09:18:00+03	2017-08-01 11:52:00+03
23946	PG0076	2017-08-15 09:15:00+03	2017-08-15 11:50:00+03	EYK	DME	Arrived	CR2	2017-08-15 09:17:00+03	2017-08-15 11:56:00+03
23947	PG0076	2017-09-12 09:15:00+03	2017-09-12 11:50:00+03	EYK	DME	Cancelled	CR2	\N	\N
23948	PG0076	2017-08-29 09:15:00+03	2017-08-29 11:50:00+03	EYK	DME	Scheduled	CR2	\N	\N
23949	PG0076	2017-08-22 09:15:00+03	2017-08-22 11:50:00+03	EYK	DME	Scheduled	CR2	\N	\N
23950	PG0076	2017-07-25 09:15:00+03	2017-07-25 11:50:00+03	EYK	DME	Arrived	CR2	2017-07-25 09:18:00+03	2017-07-25 11:54:00+03
23951	PG0577	2017-08-31 09:50:00+03	2017-08-31 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23952	PG0577	2017-08-08 09:50:00+03	2017-08-08 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-08 09:53:00+03	2017-08-08 12:12:00+03
23953	PG0577	2017-09-07 09:50:00+03	2017-09-07 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23954	PG0577	2017-07-27 09:50:00+03	2017-07-27 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-27 09:52:00+03	2017-07-27 12:10:00+03
23955	PG0577	2017-09-12 09:50:00+03	2017-09-12 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23956	PG0577	2017-08-05 09:50:00+03	2017-08-05 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-05 09:52:00+03	2017-08-05 12:11:00+03
23957	PG0577	2017-09-02 09:50:00+03	2017-09-02 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23958	PG0577	2017-08-19 09:50:00+03	2017-08-19 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23959	PG0577	2017-08-15 09:50:00+03	2017-08-15 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-15 09:53:00+03	2017-08-15 12:10:00+03
23960	PG0577	2017-09-05 09:50:00+03	2017-09-05 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23961	PG0577	2017-07-29 09:50:00+03	2017-07-29 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-29 09:54:00+03	2017-07-29 12:14:00+03
23962	PG0577	2017-08-22 09:50:00+03	2017-08-22 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23963	PG0577	2017-08-26 09:50:00+03	2017-08-26 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23964	PG0577	2017-07-22 09:50:00+03	2017-07-22 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-22 09:53:00+03	2017-07-22 12:13:00+03
23965	PG0577	2017-08-29 09:50:00+03	2017-08-29 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23966	PG0577	2017-07-18 09:50:00+03	2017-07-18 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-18 09:54:00+03	2017-07-18 12:14:00+03
23967	PG0577	2017-08-12 09:50:00+03	2017-08-12 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-12 09:51:00+03	2017-08-12 12:11:00+03
23968	PG0577	2017-07-25 09:50:00+03	2017-07-25 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-25 09:52:00+03	2017-07-25 12:10:00+03
23969	PG0577	2017-08-10 09:50:00+03	2017-08-10 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-10 09:54:00+03	2017-08-10 12:14:00+03
23970	PG0577	2017-07-20 09:50:00+03	2017-07-20 12:10:00+03	EYK	TJM	Arrived	CN1	2017-07-20 09:54:00+03	2017-07-20 12:13:00+03
23971	PG0577	2017-08-24 09:50:00+03	2017-08-24 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23972	PG0577	2017-08-01 09:50:00+03	2017-08-01 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-01 09:54:00+03	2017-08-01 12:15:00+03
23973	PG0577	2017-08-03 09:50:00+03	2017-08-03 12:10:00+03	EYK	TJM	Arrived	CN1	2017-08-03 09:52:00+03	2017-08-03 12:10:00+03
23974	PG0577	2017-09-14 09:50:00+03	2017-09-14 12:10:00+03	EYK	TJM	Cancelled	CN1	\N	\N
23975	PG0577	2017-09-09 09:50:00+03	2017-09-09 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23976	PG0577	2017-08-17 09:50:00+03	2017-08-17 12:10:00+03	EYK	TJM	Scheduled	CN1	\N	\N
23977	PG0366	2017-08-17 10:30:00+03	2017-08-17 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23978	PG0366	2017-09-04 10:30:00+03	2017-09-04 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23979	PG0366	2017-08-03 10:30:00+03	2017-08-03 13:30:00+03	EYK	KRO	Arrived	CN1	2017-08-03 10:32:00+03	2017-08-03 13:35:00+03
23980	PG0366	2017-09-07 10:30:00+03	2017-09-07 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23981	PG0366	2017-09-14 10:30:00+03	2017-09-14 13:30:00+03	EYK	KRO	Cancelled	CN1	\N	\N
23982	PG0366	2017-08-07 10:30:00+03	2017-08-07 13:30:00+03	EYK	KRO	Arrived	CN1	2017-08-07 10:33:00+03	2017-08-07 13:31:00+03
23983	PG0366	2017-07-31 10:30:00+03	2017-07-31 13:30:00+03	EYK	KRO	Arrived	CN1	2017-07-31 10:32:00+03	2017-07-31 13:34:00+03
23984	PG0366	2017-07-17 10:30:00+03	2017-07-17 13:30:00+03	EYK	KRO	Arrived	CN1	2017-07-17 10:32:00+03	2017-07-17 13:30:00+03
23985	PG0366	2017-07-24 10:30:00+03	2017-07-24 13:30:00+03	EYK	KRO	Arrived	CN1	2017-07-24 10:32:00+03	2017-07-24 13:35:00+03
23986	PG0366	2017-09-11 10:30:00+03	2017-09-11 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23987	PG0366	2017-08-28 10:30:00+03	2017-08-28 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23988	PG0366	2017-08-10 10:30:00+03	2017-08-10 13:30:00+03	EYK	KRO	Arrived	CN1	2017-08-10 10:33:00+03	2017-08-10 13:34:00+03
23989	PG0366	2017-07-20 10:30:00+03	2017-07-20 13:30:00+03	EYK	KRO	Arrived	CN1	2017-07-20 10:32:00+03	2017-07-20 13:35:00+03
23990	PG0366	2017-08-24 10:30:00+03	2017-08-24 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23991	PG0366	2017-07-27 10:30:00+03	2017-07-27 13:30:00+03	EYK	KRO	Arrived	CN1	2017-07-27 10:33:00+03	2017-07-27 13:33:00+03
23992	PG0366	2017-08-14 10:30:00+03	2017-08-14 13:30:00+03	EYK	KRO	Arrived	CN1	2017-08-14 10:32:00+03	2017-08-14 13:31:00+03
23993	PG0366	2017-08-31 10:30:00+03	2017-08-31 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23994	PG0366	2017-08-21 10:30:00+03	2017-08-21 13:30:00+03	EYK	KRO	Scheduled	CN1	\N	\N
23995	PG0433	2017-07-17 06:30:00+03	2017-07-17 10:50:00+03	RGK	SVO	Arrived	733	2017-07-17 06:32:00+03	2017-07-17 10:48:00+03
23996	PG0433	2017-09-11 06:30:00+03	2017-09-11 10:50:00+03	RGK	SVO	Scheduled	733	\N	\N
23997	PG0433	2017-08-07 06:30:00+03	2017-08-07 10:50:00+03	RGK	SVO	Arrived	733	2017-08-07 06:35:00+03	2017-08-07 10:57:00+03
23998	PG0433	2017-09-04 06:30:00+03	2017-09-04 10:50:00+03	RGK	SVO	Scheduled	733	\N	\N
23999	PG0433	2017-08-14 06:30:00+03	2017-08-14 10:50:00+03	RGK	SVO	Arrived	733	2017-08-14 06:33:00+03	2017-08-14 10:49:00+03
24000	PG0433	2017-07-24 06:30:00+03	2017-07-24 10:50:00+03	RGK	SVO	Arrived	733	2017-07-24 06:31:00+03	2017-07-24 10:50:00+03
24001	PG0433	2017-08-28 06:30:00+03	2017-08-28 10:50:00+03	RGK	SVO	Scheduled	733	\N	\N
24002	PG0433	2017-08-21 06:30:00+03	2017-08-21 10:50:00+03	RGK	SVO	Scheduled	733	\N	\N
24003	PG0433	2017-07-31 06:30:00+03	2017-07-31 10:50:00+03	RGK	SVO	Arrived	733	2017-07-31 06:32:00+03	2017-07-31 10:52:00+03
24004	PG0324	2017-07-23 06:50:00+03	2017-07-23 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-23 06:52:00+03	2017-07-23 08:10:00+03
24005	PG0324	2017-08-05 06:50:00+03	2017-08-05 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-05 06:54:00+03	2017-08-05 08:13:00+03
24006	PG0324	2017-08-11 06:50:00+03	2017-08-11 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-11 06:51:00+03	2017-08-11 08:12:00+03
24007	PG0324	2017-07-20 06:50:00+03	2017-07-20 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-20 06:51:00+03	2017-07-20 08:10:00+03
24008	PG0324	2017-08-09 06:50:00+03	2017-08-09 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-09 06:52:00+03	2017-08-09 08:11:00+03
24009	PG0324	2017-08-22 06:50:00+03	2017-08-22 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24010	PG0324	2017-08-27 06:50:00+03	2017-08-27 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24011	PG0324	2017-07-25 06:50:00+03	2017-07-25 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-25 06:54:00+03	2017-07-25 08:15:00+03
24012	PG0324	2017-08-14 06:50:00+03	2017-08-14 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-14 06:53:00+03	2017-08-14 08:14:00+03
24013	PG0324	2017-08-24 06:50:00+03	2017-08-24 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24014	PG0324	2017-08-25 06:50:00+03	2017-08-25 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24015	PG0324	2017-08-31 06:50:00+03	2017-08-31 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24016	PG0324	2017-08-07 06:50:00+03	2017-08-07 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-07 06:52:00+03	2017-08-07 08:11:00+03
24017	PG0324	2017-08-29 06:50:00+03	2017-08-29 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24018	PG0324	2017-07-24 06:50:00+03	2017-07-24 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-24 06:53:00+03	2017-07-24 08:13:00+03
24019	PG0324	2017-08-13 06:50:00+03	2017-08-13 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-13 06:53:00+03	2017-08-13 08:13:00+03
24020	PG0324	2017-07-28 06:50:00+03	2017-07-28 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-28 06:52:00+03	2017-07-28 08:12:00+03
24021	PG0324	2017-07-29 06:50:00+03	2017-07-29 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-29 06:52:00+03	2017-07-29 08:12:00+03
24022	PG0324	2017-07-18 06:50:00+03	2017-07-18 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-18 09:38:00+03	2017-07-18 10:57:00+03
24023	PG0324	2017-07-30 06:50:00+03	2017-07-30 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-30 06:52:00+03	2017-07-30 08:11:00+03
24024	PG0324	2017-09-13 06:50:00+03	2017-09-13 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24025	PG0324	2017-09-03 06:50:00+03	2017-09-03 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24026	PG0324	2017-08-17 06:50:00+03	2017-08-17 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24027	PG0324	2017-08-28 06:50:00+03	2017-08-28 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24028	PG0324	2017-08-16 06:50:00+03	2017-08-16 08:10:00+03	RGK	OVB	On Time	CN1	\N	\N
24029	PG0324	2017-08-03 06:50:00+03	2017-08-03 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-03 06:51:00+03	2017-08-03 08:11:00+03
24030	PG0324	2017-08-12 06:50:00+03	2017-08-12 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-12 06:51:00+03	2017-08-12 08:11:00+03
24031	PG0324	2017-08-30 06:50:00+03	2017-08-30 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24032	PG0324	2017-08-23 06:50:00+03	2017-08-23 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24033	PG0324	2017-08-02 06:50:00+03	2017-08-02 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-02 06:50:00+03	2017-08-02 08:11:00+03
24034	PG0324	2017-07-22 06:50:00+03	2017-07-22 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-22 06:50:00+03	2017-07-22 08:09:00+03
24035	PG0324	2017-08-10 06:50:00+03	2017-08-10 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-10 06:56:00+03	2017-08-10 08:16:00+03
24036	PG0324	2017-08-20 06:50:00+03	2017-08-20 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24037	PG0324	2017-09-09 06:50:00+03	2017-09-09 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24038	PG0324	2017-09-05 06:50:00+03	2017-09-05 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24039	PG0324	2017-08-15 06:50:00+03	2017-08-15 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-15 06:53:00+03	2017-08-15 08:13:00+03
24040	PG0324	2017-09-10 06:50:00+03	2017-09-10 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24041	PG0324	2017-08-04 06:50:00+03	2017-08-04 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-04 06:51:00+03	2017-08-04 08:11:00+03
24042	PG0324	2017-08-26 06:50:00+03	2017-08-26 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24043	PG0324	2017-07-27 06:50:00+03	2017-07-27 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-27 06:51:00+03	2017-07-27 08:11:00+03
24044	PG0324	2017-08-21 06:50:00+03	2017-08-21 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24045	PG0324	2017-09-07 06:50:00+03	2017-09-07 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24046	PG0324	2017-09-08 06:50:00+03	2017-09-08 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24047	PG0324	2017-09-14 06:50:00+03	2017-09-14 08:10:00+03	RGK	OVB	Cancelled	CN1	\N	\N
24048	PG0324	2017-09-02 06:50:00+03	2017-09-02 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24049	PG0324	2017-07-16 06:50:00+03	2017-07-16 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-16 06:53:00+03	2017-07-16 08:14:00+03
24050	PG0324	2017-09-11 06:50:00+03	2017-09-11 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24051	PG0324	2017-07-26 06:50:00+03	2017-07-26 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-26 06:52:00+03	2017-07-26 08:12:00+03
24052	PG0324	2017-09-01 06:50:00+03	2017-09-01 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24053	PG0324	2017-09-04 06:50:00+03	2017-09-04 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24054	PG0324	2017-08-06 06:50:00+03	2017-08-06 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-06 06:50:00+03	2017-08-06 08:10:00+03
24055	PG0324	2017-09-12 06:50:00+03	2017-09-12 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24056	PG0324	2017-07-17 06:50:00+03	2017-07-17 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-17 06:51:00+03	2017-07-17 08:10:00+03
24057	PG0324	2017-07-19 06:50:00+03	2017-07-19 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-19 10:38:00+03	2017-07-19 11:59:00+03
24058	PG0324	2017-08-08 06:50:00+03	2017-08-08 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-08 06:55:00+03	2017-08-08 08:15:00+03
24059	PG0324	2017-08-01 06:50:00+03	2017-08-01 08:10:00+03	RGK	OVB	Arrived	CN1	2017-08-01 06:53:00+03	2017-08-01 08:12:00+03
24060	PG0324	2017-07-31 06:50:00+03	2017-07-31 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-31 06:56:00+03	2017-07-31 08:17:00+03
24061	PG0324	2017-07-21 06:50:00+03	2017-07-21 08:10:00+03	RGK	OVB	Arrived	CN1	2017-07-21 06:52:00+03	2017-07-21 08:12:00+03
24062	PG0324	2017-09-06 06:50:00+03	2017-09-06 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24063	PG0324	2017-08-18 06:50:00+03	2017-08-18 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24064	PG0324	2017-08-19 06:50:00+03	2017-08-19 08:10:00+03	RGK	OVB	Scheduled	CN1	\N	\N
24065	PG0331	2017-08-27 08:55:00+03	2017-08-27 13:45:00+03	RGK	KRR	Scheduled	733	\N	\N
24066	PG0331	2017-09-10 08:55:00+03	2017-09-10 13:45:00+03	RGK	KRR	Scheduled	733	\N	\N
24067	PG0331	2017-08-20 08:55:00+03	2017-08-20 13:45:00+03	RGK	KRR	Scheduled	733	\N	\N
24068	PG0331	2017-08-13 08:55:00+03	2017-08-13 13:45:00+03	RGK	KRR	Arrived	733	2017-08-13 08:57:00+03	2017-08-13 13:50:00+03
24069	PG0331	2017-09-03 08:55:00+03	2017-09-03 13:45:00+03	RGK	KRR	Scheduled	733	\N	\N
24070	PG0331	2017-07-30 08:55:00+03	2017-07-30 13:45:00+03	RGK	KRR	Arrived	733	2017-07-30 08:55:00+03	2017-07-30 13:46:00+03
24071	PG0331	2017-07-16 08:55:00+03	2017-07-16 13:45:00+03	RGK	KRR	Arrived	733	2017-07-16 08:57:00+03	2017-07-16 13:47:00+03
24072	PG0331	2017-08-06 08:55:00+03	2017-08-06 13:45:00+03	RGK	KRR	Arrived	733	2017-08-06 08:58:00+03	2017-08-06 13:54:00+03
24073	PG0331	2017-07-23 08:55:00+03	2017-07-23 13:45:00+03	RGK	KRR	Arrived	733	2017-07-23 08:59:00+03	2017-07-23 13:48:00+03
24074	PG0091	2017-08-22 06:45:00+03	2017-08-22 11:15:00+03	RGK	STW	Scheduled	733	\N	\N
24075	PG0091	2017-09-05 06:45:00+03	2017-09-05 11:15:00+03	RGK	STW	Scheduled	733	\N	\N
24076	PG0091	2017-07-18 06:45:00+03	2017-07-18 11:15:00+03	RGK	STW	Arrived	733	2017-07-18 06:48:00+03	2017-07-18 11:16:00+03
24077	PG0091	2017-08-08 06:45:00+03	2017-08-08 11:15:00+03	RGK	STW	Arrived	733	2017-08-08 06:49:00+03	2017-08-08 11:20:00+03
24078	PG0091	2017-08-29 06:45:00+03	2017-08-29 11:15:00+03	RGK	STW	Scheduled	733	\N	\N
24079	PG0091	2017-08-01 06:45:00+03	2017-08-01 11:15:00+03	RGK	STW	Arrived	733	2017-08-01 06:46:00+03	2017-08-01 11:18:00+03
24080	PG0091	2017-07-25 06:45:00+03	2017-07-25 11:15:00+03	RGK	STW	Arrived	733	2017-07-25 06:51:00+03	2017-07-25 11:22:00+03
24081	PG0091	2017-09-12 06:45:00+03	2017-09-12 11:15:00+03	RGK	STW	Cancelled	733	\N	\N
24082	PG0091	2017-08-15 06:45:00+03	2017-08-15 11:15:00+03	RGK	STW	Arrived	733	2017-08-15 06:46:00+03	2017-08-15 11:13:00+03
24083	PG0221	2017-09-12 17:55:00+03	2017-09-12 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24084	PG0221	2017-09-01 17:55:00+03	2017-09-01 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24085	PG0221	2017-07-22 17:55:00+03	2017-07-22 19:25:00+03	KRR	DME	Arrived	763	2017-07-22 17:58:00+03	2017-07-22 19:28:00+03
24086	PG0221	2017-07-30 17:55:00+03	2017-07-30 19:25:00+03	KRR	DME	Arrived	763	2017-07-30 18:00:00+03	2017-07-30 19:30:00+03
24087	PG0221	2017-07-21 17:55:00+03	2017-07-21 19:25:00+03	KRR	DME	Arrived	763	2017-07-21 17:57:00+03	2017-07-21 19:29:00+03
24088	PG0221	2017-07-27 17:55:00+03	2017-07-27 19:25:00+03	KRR	DME	Arrived	763	2017-07-27 17:58:00+03	2017-07-27 19:27:00+03
24089	PG0221	2017-09-03 17:55:00+03	2017-09-03 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24090	PG0221	2017-08-26 17:55:00+03	2017-08-26 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24091	PG0221	2017-07-24 17:55:00+03	2017-07-24 19:25:00+03	KRR	DME	Arrived	763	2017-07-24 17:59:00+03	2017-07-24 19:28:00+03
24092	PG0221	2017-09-04 17:55:00+03	2017-09-04 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24093	PG0221	2017-08-02 17:55:00+03	2017-08-02 19:25:00+03	KRR	DME	Arrived	763	2017-08-02 17:57:00+03	2017-08-02 19:27:00+03
24094	PG0221	2017-08-25 17:55:00+03	2017-08-25 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24095	PG0221	2017-08-14 17:55:00+03	2017-08-14 19:25:00+03	KRR	DME	Arrived	763	2017-08-14 17:57:00+03	2017-08-14 19:27:00+03
24096	PG0221	2017-07-31 17:55:00+03	2017-07-31 19:25:00+03	KRR	DME	Arrived	763	2017-07-31 17:56:00+03	2017-07-31 19:26:00+03
24097	PG0221	2017-08-29 17:55:00+03	2017-08-29 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24098	PG0221	2017-08-12 17:55:00+03	2017-08-12 19:25:00+03	KRR	DME	Arrived	763	2017-08-12 17:57:00+03	2017-08-12 19:30:00+03
24099	PG0221	2017-08-15 17:55:00+03	2017-08-15 19:25:00+03	KRR	DME	On Time	763	\N	\N
24100	PG0221	2017-08-11 17:55:00+03	2017-08-11 19:25:00+03	KRR	DME	Arrived	763	2017-08-11 17:58:00+03	2017-08-11 19:28:00+03
24101	PG0221	2017-09-09 17:55:00+03	2017-09-09 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24102	PG0221	2017-08-30 17:55:00+03	2017-08-30 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24103	PG0221	2017-08-01 17:55:00+03	2017-08-01 19:25:00+03	KRR	DME	Arrived	763	2017-08-01 17:57:00+03	2017-08-01 19:24:00+03
24104	PG0221	2017-09-05 17:55:00+03	2017-09-05 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24105	PG0221	2017-08-22 17:55:00+03	2017-08-22 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24106	PG0221	2017-09-13 17:55:00+03	2017-09-13 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24107	PG0221	2017-09-02 17:55:00+03	2017-09-02 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24108	PG0221	2017-08-21 17:55:00+03	2017-08-21 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24109	PG0221	2017-07-28 17:55:00+03	2017-07-28 19:25:00+03	KRR	DME	Arrived	763	2017-07-28 17:56:00+03	2017-07-28 19:25:00+03
24110	PG0221	2017-08-09 17:55:00+03	2017-08-09 19:25:00+03	KRR	DME	Arrived	763	2017-08-09 17:57:00+03	2017-08-09 19:26:00+03
24111	PG0221	2017-09-08 17:55:00+03	2017-09-08 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24112	PG0221	2017-08-28 17:55:00+03	2017-08-28 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24113	PG0221	2017-08-06 17:55:00+03	2017-08-06 19:25:00+03	KRR	DME	Arrived	763	2017-08-06 17:59:00+03	2017-08-06 19:31:00+03
24114	PG0221	2017-08-31 17:55:00+03	2017-08-31 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24115	PG0221	2017-08-17 17:55:00+03	2017-08-17 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24116	PG0221	2017-08-23 17:55:00+03	2017-08-23 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24117	PG0221	2017-07-19 17:55:00+03	2017-07-19 19:25:00+03	KRR	DME	Arrived	763	2017-07-19 17:57:00+03	2017-07-19 19:28:00+03
24118	PG0221	2017-07-16 17:55:00+03	2017-07-16 19:25:00+03	KRR	DME	Arrived	763	2017-07-16 18:01:00+03	2017-07-16 19:29:00+03
24119	PG0221	2017-08-05 17:55:00+03	2017-08-05 19:25:00+03	KRR	DME	Arrived	763	2017-08-05 18:01:00+03	2017-08-05 19:31:00+03
24120	PG0221	2017-08-18 17:55:00+03	2017-08-18 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24121	PG0221	2017-08-10 17:55:00+03	2017-08-10 19:25:00+03	KRR	DME	Arrived	763	2017-08-10 17:57:00+03	2017-08-10 19:25:00+03
24122	PG0221	2017-07-29 17:55:00+03	2017-07-29 19:25:00+03	KRR	DME	Arrived	763	2017-07-29 18:00:00+03	2017-07-29 19:31:00+03
24123	PG0221	2017-08-08 17:55:00+03	2017-08-08 19:25:00+03	KRR	DME	Arrived	763	2017-08-08 17:59:00+03	2017-08-08 19:31:00+03
24124	PG0221	2017-09-14 17:55:00+03	2017-09-14 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24125	PG0221	2017-09-06 17:55:00+03	2017-09-06 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24126	PG0221	2017-08-04 17:55:00+03	2017-08-04 19:25:00+03	KRR	DME	Arrived	763	2017-08-04 17:57:00+03	2017-08-04 19:25:00+03
24127	PG0221	2017-08-19 17:55:00+03	2017-08-19 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24128	PG0221	2017-08-24 17:55:00+03	2017-08-24 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24129	PG0221	2017-07-17 17:55:00+03	2017-07-17 19:25:00+03	KRR	DME	Arrived	763	2017-07-17 17:56:00+03	2017-07-17 19:26:00+03
24130	PG0221	2017-08-03 17:55:00+03	2017-08-03 19:25:00+03	KRR	DME	Arrived	763	2017-08-03 17:55:00+03	2017-08-03 19:25:00+03
24131	PG0221	2017-07-26 17:55:00+03	2017-07-26 19:25:00+03	KRR	DME	Arrived	763	2017-07-26 17:58:00+03	2017-07-26 19:29:00+03
24132	PG0221	2017-07-25 17:55:00+03	2017-07-25 19:25:00+03	KRR	DME	Arrived	763	2017-07-25 17:57:00+03	2017-07-25 19:28:00+03
24133	PG0221	2017-09-10 17:55:00+03	2017-09-10 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24134	PG0221	2017-08-27 17:55:00+03	2017-08-27 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24135	PG0221	2017-07-18 17:55:00+03	2017-07-18 19:25:00+03	KRR	DME	Arrived	763	2017-07-18 17:56:00+03	2017-07-18 19:25:00+03
24136	PG0221	2017-08-20 17:55:00+03	2017-08-20 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24137	PG0221	2017-08-07 17:55:00+03	2017-08-07 19:25:00+03	KRR	DME	Arrived	763	2017-08-07 21:03:00+03	2017-08-07 22:33:00+03
24138	PG0221	2017-09-07 17:55:00+03	2017-09-07 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24139	PG0221	2017-09-11 17:55:00+03	2017-09-11 19:25:00+03	KRR	DME	Scheduled	763	\N	\N
24140	PG0221	2017-08-13 17:55:00+03	2017-08-13 19:25:00+03	KRR	DME	Arrived	763	2017-08-13 17:58:00+03	2017-08-13 19:29:00+03
24141	PG0221	2017-08-16 17:55:00+03	2017-08-16 19:25:00+03	KRR	DME	On Time	763	\N	\N
24142	PG0221	2017-07-20 17:55:00+03	2017-07-20 19:25:00+03	KRR	DME	Arrived	763	2017-07-20 18:02:00+03	2017-07-20 19:31:00+03
24143	PG0221	2017-07-23 17:55:00+03	2017-07-23 19:25:00+03	KRR	DME	Arrived	763	2017-07-23 17:58:00+03	2017-07-23 19:27:00+03
24144	PG0393	2017-07-16 09:30:00+03	2017-07-16 11:30:00+03	KRR	JOK	Arrived	CR2	2017-07-16 09:31:00+03	2017-07-16 11:30:00+03
24145	PG0393	2017-09-06 09:30:00+03	2017-09-06 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24146	PG0393	2017-08-23 09:30:00+03	2017-08-23 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24147	PG0393	2017-08-16 09:30:00+03	2017-08-16 11:30:00+03	KRR	JOK	On Time	CR2	\N	\N
24148	PG0393	2017-09-03 09:30:00+03	2017-09-03 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24149	PG0393	2017-08-20 09:30:00+03	2017-08-20 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24150	PG0393	2017-08-02 09:30:00+03	2017-08-02 11:30:00+03	KRR	JOK	Arrived	CR2	2017-08-02 09:35:00+03	2017-08-02 11:35:00+03
24151	PG0393	2017-08-06 09:30:00+03	2017-08-06 11:30:00+03	KRR	JOK	Arrived	CR2	2017-08-06 09:34:00+03	2017-08-06 11:35:00+03
24152	PG0393	2017-08-30 09:30:00+03	2017-08-30 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24153	PG0393	2017-07-26 09:30:00+03	2017-07-26 11:30:00+03	KRR	JOK	Arrived	CR2	2017-07-26 09:34:00+03	2017-07-26 11:32:00+03
24154	PG0393	2017-07-23 09:30:00+03	2017-07-23 11:30:00+03	KRR	JOK	Arrived	CR2	2017-07-23 09:31:00+03	2017-07-23 11:30:00+03
24155	PG0393	2017-07-30 09:30:00+03	2017-07-30 11:30:00+03	KRR	JOK	Arrived	CR2	2017-07-30 09:33:00+03	2017-07-30 11:32:00+03
24156	PG0393	2017-07-19 09:30:00+03	2017-07-19 11:30:00+03	KRR	JOK	Arrived	CR2	2017-07-19 09:33:00+03	2017-07-19 11:35:00+03
24157	PG0393	2017-08-13 09:30:00+03	2017-08-13 11:30:00+03	KRR	JOK	Arrived	CR2	2017-08-13 09:35:00+03	2017-08-13 11:33:00+03
24158	PG0393	2017-09-13 09:30:00+03	2017-09-13 11:30:00+03	KRR	JOK	Cancelled	CR2	\N	\N
24159	PG0393	2017-09-10 09:30:00+03	2017-09-10 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24160	PG0393	2017-08-09 09:30:00+03	2017-08-09 11:30:00+03	KRR	JOK	Arrived	CR2	2017-08-09 09:32:00+03	2017-08-09 11:31:00+03
24161	PG0393	2017-08-27 09:30:00+03	2017-08-27 11:30:00+03	KRR	JOK	Scheduled	CR2	\N	\N
24162	PG0419	2017-09-12 10:10:00+03	2017-09-12 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24163	PG0419	2017-09-09 10:10:00+03	2017-09-09 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24164	PG0419	2017-09-03 10:10:00+03	2017-09-03 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24165	PG0419	2017-08-27 10:10:00+03	2017-08-27 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24166	PG0419	2017-07-27 10:10:00+03	2017-07-27 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-27 10:19:00+03	2017-07-27 11:34:00+03
24167	PG0419	2017-09-11 10:10:00+03	2017-09-11 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24168	PG0419	2017-08-18 10:10:00+03	2017-08-18 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24169	PG0419	2017-07-19 10:10:00+03	2017-07-19 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-19 10:11:00+03	2017-07-19 11:27:00+03
24170	PG0419	2017-08-06 10:10:00+03	2017-08-06 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-06 10:16:00+03	2017-08-06 11:31:00+03
24171	PG0419	2017-08-08 10:10:00+03	2017-08-08 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-08 10:13:00+03	2017-08-08 11:27:00+03
24172	PG0419	2017-09-04 10:10:00+03	2017-09-04 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24173	PG0419	2017-08-11 10:10:00+03	2017-08-11 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-11 10:15:00+03	2017-08-11 11:31:00+03
24174	PG0419	2017-08-17 10:10:00+03	2017-08-17 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24175	PG0419	2017-07-18 10:10:00+03	2017-07-18 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-18 10:11:00+03	2017-07-18 11:27:00+03
24176	PG0419	2017-08-01 10:10:00+03	2017-08-01 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-01 10:14:00+03	2017-08-01 11:29:00+03
24177	PG0419	2017-09-01 10:10:00+03	2017-09-01 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24178	PG0419	2017-07-22 10:10:00+03	2017-07-22 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-22 10:10:00+03	2017-07-22 11:27:00+03
24179	PG0419	2017-08-24 10:10:00+03	2017-08-24 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24180	PG0419	2017-08-02 10:10:00+03	2017-08-02 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-02 10:14:00+03	2017-08-02 11:29:00+03
24181	PG0419	2017-07-24 10:10:00+03	2017-07-24 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-24 10:13:00+03	2017-07-24 11:29:00+03
24182	PG0419	2017-09-14 10:10:00+03	2017-09-14 11:25:00+03	KRR	NAL	Cancelled	CN1	\N	\N
24183	PG0419	2017-07-28 10:10:00+03	2017-07-28 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-28 10:18:00+03	2017-07-28 11:33:00+03
24184	PG0419	2017-09-06 10:10:00+03	2017-09-06 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24185	PG0419	2017-07-21 10:10:00+03	2017-07-21 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-21 10:16:00+03	2017-07-21 11:32:00+03
24186	PG0419	2017-08-31 10:10:00+03	2017-08-31 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24187	PG0419	2017-08-22 10:10:00+03	2017-08-22 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24188	PG0419	2017-09-02 10:10:00+03	2017-09-02 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24189	PG0419	2017-07-31 10:10:00+03	2017-07-31 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-31 10:11:00+03	2017-07-31 11:25:00+03
24190	PG0419	2017-09-13 10:10:00+03	2017-09-13 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24191	PG0419	2017-08-04 10:10:00+03	2017-08-04 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-04 10:16:00+03	2017-08-04 11:32:00+03
24192	PG0419	2017-08-20 10:10:00+03	2017-08-20 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24193	PG0419	2017-07-26 10:10:00+03	2017-07-26 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-26 10:13:00+03	2017-07-26 11:29:00+03
24194	PG0419	2017-08-09 10:10:00+03	2017-08-09 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-09 10:11:00+03	2017-08-09 11:26:00+03
24195	PG0419	2017-08-14 10:10:00+03	2017-08-14 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-14 10:14:00+03	2017-08-14 11:30:00+03
24196	PG0419	2017-07-29 10:10:00+03	2017-07-29 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-29 10:14:00+03	2017-07-29 11:29:00+03
24197	PG0419	2017-07-17 10:10:00+03	2017-07-17 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-17 10:11:00+03	2017-07-17 11:27:00+03
24198	PG0419	2017-08-25 10:10:00+03	2017-08-25 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24199	PG0419	2017-07-23 10:10:00+03	2017-07-23 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-23 10:15:00+03	2017-07-23 11:29:00+03
24200	PG0419	2017-08-23 10:10:00+03	2017-08-23 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24201	PG0419	2017-08-07 10:10:00+03	2017-08-07 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-07 10:14:00+03	2017-08-07 11:28:00+03
24202	PG0419	2017-09-05 10:10:00+03	2017-09-05 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24203	PG0419	2017-08-03 10:10:00+03	2017-08-03 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-03 10:11:00+03	2017-08-03 11:24:00+03
24204	PG0419	2017-07-16 10:10:00+03	2017-07-16 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-16 10:14:00+03	2017-07-16 11:30:00+03
24205	PG0419	2017-08-19 10:10:00+03	2017-08-19 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24206	PG0419	2017-08-28 10:10:00+03	2017-08-28 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24207	PG0419	2017-09-08 10:10:00+03	2017-09-08 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24208	PG0419	2017-08-30 10:10:00+03	2017-08-30 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24209	PG0419	2017-08-26 10:10:00+03	2017-08-26 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24210	PG0419	2017-08-13 10:10:00+03	2017-08-13 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-13 10:11:00+03	2017-08-13 11:27:00+03
24211	PG0419	2017-08-10 10:10:00+03	2017-08-10 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-10 10:13:00+03	2017-08-10 11:26:00+03
24212	PG0419	2017-07-20 10:10:00+03	2017-07-20 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-20 10:11:00+03	2017-07-20 11:26:00+03
24213	PG0419	2017-09-07 10:10:00+03	2017-09-07 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24214	PG0419	2017-08-21 10:10:00+03	2017-08-21 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24215	PG0419	2017-08-05 10:10:00+03	2017-08-05 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-05 10:13:00+03	2017-08-05 11:29:00+03
24216	PG0419	2017-08-29 10:10:00+03	2017-08-29 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24217	PG0419	2017-08-16 10:10:00+03	2017-08-16 11:25:00+03	KRR	NAL	On Time	CN1	\N	\N
24218	PG0419	2017-08-15 10:10:00+03	2017-08-15 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-15 10:12:00+03	2017-08-15 11:27:00+03
24219	PG0419	2017-07-30 10:10:00+03	2017-07-30 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-30 10:13:00+03	2017-07-30 11:28:00+03
24220	PG0419	2017-09-10 10:10:00+03	2017-09-10 11:25:00+03	KRR	NAL	Scheduled	CN1	\N	\N
24221	PG0419	2017-07-25 10:10:00+03	2017-07-25 11:25:00+03	KRR	NAL	Arrived	CN1	2017-07-25 10:12:00+03	2017-07-25 11:27:00+03
24222	PG0419	2017-08-12 10:10:00+03	2017-08-12 11:25:00+03	KRR	NAL	Arrived	CN1	2017-08-12 10:14:00+03	2017-08-12 11:29:00+03
24223	PG0332	2017-08-30 10:00:00+03	2017-08-30 14:50:00+03	KRR	RGK	Scheduled	733	\N	\N
24224	PG0332	2017-07-26 10:00:00+03	2017-07-26 14:50:00+03	KRR	RGK	Arrived	733	2017-07-26 10:02:00+03	2017-07-26 14:49:00+03
24225	PG0332	2017-07-19 10:00:00+03	2017-07-19 14:50:00+03	KRR	RGK	Arrived	733	2017-07-19 10:03:00+03	2017-07-19 14:55:00+03
24226	PG0332	2017-08-23 10:00:00+03	2017-08-23 14:50:00+03	KRR	RGK	Scheduled	733	\N	\N
24227	PG0332	2017-09-06 10:00:00+03	2017-09-06 14:50:00+03	KRR	RGK	Scheduled	733	\N	\N
24228	PG0332	2017-08-02 10:00:00+03	2017-08-02 14:50:00+03	KRR	RGK	Arrived	733	2017-08-02 10:02:00+03	2017-08-02 14:52:00+03
24229	PG0332	2017-09-13 10:00:00+03	2017-09-13 14:50:00+03	KRR	RGK	Cancelled	733	\N	\N
24230	PG0332	2017-08-16 10:00:00+03	2017-08-16 14:50:00+03	KRR	RGK	On Time	733	\N	\N
24231	PG0332	2017-08-09 10:00:00+03	2017-08-09 14:50:00+03	KRR	RGK	Arrived	733	2017-08-09 10:02:00+03	2017-08-09 14:55:00+03
24232	PG0364	2017-08-21 11:45:00+03	2017-08-21 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24233	PG0364	2017-08-08 11:45:00+03	2017-08-08 13:20:00+03	KRR	ULV	Arrived	763	2017-08-08 11:46:00+03	2017-08-08 13:22:00+03
24234	PG0364	2017-08-29 11:45:00+03	2017-08-29 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24235	PG0364	2017-08-04 11:45:00+03	2017-08-04 13:20:00+03	KRR	ULV	Arrived	763	2017-08-04 11:49:00+03	2017-08-04 13:25:00+03
24236	PG0364	2017-08-14 11:45:00+03	2017-08-14 13:20:00+03	KRR	ULV	Arrived	763	2017-08-14 11:49:00+03	2017-08-14 13:24:00+03
24237	PG0364	2017-08-02 11:45:00+03	2017-08-02 13:20:00+03	KRR	ULV	Arrived	763	2017-08-02 11:48:00+03	2017-08-02 13:23:00+03
24238	PG0364	2017-09-10 11:45:00+03	2017-09-10 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24239	PG0364	2017-08-24 11:45:00+03	2017-08-24 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24240	PG0364	2017-09-12 11:45:00+03	2017-09-12 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24241	PG0364	2017-08-06 11:45:00+03	2017-08-06 13:20:00+03	KRR	ULV	Arrived	763	2017-08-06 11:47:00+03	2017-08-06 13:20:00+03
24242	PG0364	2017-07-28 11:45:00+03	2017-07-28 13:20:00+03	KRR	ULV	Arrived	763	2017-07-28 11:46:00+03	2017-07-28 13:21:00+03
24243	PG0364	2017-07-27 11:45:00+03	2017-07-27 13:20:00+03	KRR	ULV	Arrived	763	2017-07-27 11:46:00+03	2017-07-27 13:21:00+03
24244	PG0364	2017-08-17 11:45:00+03	2017-08-17 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24245	PG0364	2017-08-10 11:45:00+03	2017-08-10 13:20:00+03	KRR	ULV	Arrived	763	2017-08-10 11:49:00+03	2017-08-10 13:23:00+03
24246	PG0364	2017-08-12 11:45:00+03	2017-08-12 13:20:00+03	KRR	ULV	Arrived	763	2017-08-12 11:46:00+03	2017-08-12 13:20:00+03
24247	PG0364	2017-08-23 11:45:00+03	2017-08-23 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24248	PG0364	2017-09-06 11:45:00+03	2017-09-06 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24249	PG0364	2017-07-24 11:45:00+03	2017-07-24 13:20:00+03	KRR	ULV	Arrived	763	2017-07-24 15:09:00+03	2017-07-24 16:44:00+03
24250	PG0364	2017-09-14 11:45:00+03	2017-09-14 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24251	PG0364	2017-08-01 11:45:00+03	2017-08-01 13:20:00+03	KRR	ULV	Arrived	763	2017-08-01 11:48:00+03	2017-08-01 13:24:00+03
24252	PG0364	2017-08-30 11:45:00+03	2017-08-30 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24253	PG0364	2017-07-19 11:45:00+03	2017-07-19 13:20:00+03	KRR	ULV	Arrived	763	2017-07-19 16:12:00+03	2017-07-19 17:49:00+03
24254	PG0364	2017-09-08 11:45:00+03	2017-09-08 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24255	PG0364	2017-08-20 11:45:00+03	2017-08-20 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24256	PG0364	2017-07-16 11:45:00+03	2017-07-16 13:20:00+03	KRR	ULV	Arrived	763	2017-07-16 11:47:00+03	2017-07-16 13:22:00+03
24257	PG0364	2017-07-21 11:45:00+03	2017-07-21 13:20:00+03	KRR	ULV	Arrived	763	2017-07-21 11:52:00+03	2017-07-21 13:27:00+03
24258	PG0364	2017-08-19 11:45:00+03	2017-08-19 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24259	PG0364	2017-07-17 11:45:00+03	2017-07-17 13:20:00+03	KRR	ULV	Arrived	763	2017-07-17 11:46:00+03	2017-07-17 13:21:00+03
24260	PG0364	2017-09-03 11:45:00+03	2017-09-03 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24261	PG0364	2017-08-07 11:45:00+03	2017-08-07 13:20:00+03	KRR	ULV	Arrived	763	2017-08-07 15:13:00+03	2017-08-07 16:49:00+03
24262	PG0364	2017-09-13 11:45:00+03	2017-09-13 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24263	PG0364	2017-07-29 11:45:00+03	2017-07-29 13:20:00+03	KRR	ULV	Arrived	763	2017-07-29 11:49:00+03	2017-07-29 13:24:00+03
24264	PG0364	2017-08-16 11:45:00+03	2017-08-16 13:20:00+03	KRR	ULV	On Time	763	\N	\N
24265	PG0364	2017-09-05 11:45:00+03	2017-09-05 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24266	PG0364	2017-08-13 11:45:00+03	2017-08-13 13:20:00+03	KRR	ULV	Arrived	763	2017-08-13 11:45:00+03	2017-08-13 13:21:00+03
24267	PG0364	2017-08-18 11:45:00+03	2017-08-18 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24268	PG0364	2017-08-05 11:45:00+03	2017-08-05 13:20:00+03	KRR	ULV	Arrived	763	2017-08-05 11:48:00+03	2017-08-05 13:22:00+03
24269	PG0364	2017-09-07 11:45:00+03	2017-09-07 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24270	PG0364	2017-09-04 11:45:00+03	2017-09-04 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24271	PG0364	2017-07-20 11:45:00+03	2017-07-20 13:20:00+03	KRR	ULV	Arrived	763	2017-07-20 11:46:00+03	2017-07-20 13:20:00+03
24272	PG0364	2017-08-31 11:45:00+03	2017-08-31 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24273	PG0364	2017-08-03 11:45:00+03	2017-08-03 13:20:00+03	KRR	ULV	Arrived	763	2017-08-03 11:46:00+03	2017-08-03 13:20:00+03
24274	PG0364	2017-07-23 11:45:00+03	2017-07-23 13:20:00+03	KRR	ULV	Arrived	763	2017-07-23 11:48:00+03	2017-07-23 13:22:00+03
24275	PG0364	2017-09-01 11:45:00+03	2017-09-01 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24276	PG0364	2017-08-27 11:45:00+03	2017-08-27 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24277	PG0364	2017-08-15 11:45:00+03	2017-08-15 13:20:00+03	KRR	ULV	Arrived	763	2017-08-15 11:48:00+03	2017-08-15 13:22:00+03
24278	PG0364	2017-08-11 11:45:00+03	2017-08-11 13:20:00+03	KRR	ULV	Arrived	763	2017-08-11 11:46:00+03	2017-08-11 13:20:00+03
24279	PG0364	2017-08-25 11:45:00+03	2017-08-25 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24280	PG0364	2017-08-22 11:45:00+03	2017-08-22 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24281	PG0364	2017-08-26 11:45:00+03	2017-08-26 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24282	PG0364	2017-07-31 11:45:00+03	2017-07-31 13:20:00+03	KRR	ULV	Arrived	763	2017-07-31 11:48:00+03	2017-07-31 13:24:00+03
24283	PG0364	2017-07-18 11:45:00+03	2017-07-18 13:20:00+03	KRR	ULV	Arrived	763	2017-07-18 11:47:00+03	2017-07-18 13:24:00+03
24284	PG0364	2017-09-11 11:45:00+03	2017-09-11 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24285	PG0364	2017-08-28 11:45:00+03	2017-08-28 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24286	PG0364	2017-08-09 11:45:00+03	2017-08-09 13:20:00+03	KRR	ULV	Arrived	763	2017-08-09 11:49:00+03	2017-08-09 13:24:00+03
24287	PG0364	2017-09-02 11:45:00+03	2017-09-02 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24288	PG0364	2017-07-30 11:45:00+03	2017-07-30 13:20:00+03	KRR	ULV	Arrived	763	2017-07-30 11:47:00+03	2017-07-30 13:23:00+03
24289	PG0364	2017-09-09 11:45:00+03	2017-09-09 13:20:00+03	KRR	ULV	Scheduled	763	\N	\N
24290	PG0364	2017-07-26 11:45:00+03	2017-07-26 13:20:00+03	KRR	ULV	Arrived	763	2017-07-26 11:48:00+03	2017-07-26 13:23:00+03
24291	PG0364	2017-07-22 11:45:00+03	2017-07-22 13:20:00+03	KRR	ULV	Arrived	763	2017-07-22 11:50:00+03	2017-07-22 13:25:00+03
24292	PG0364	2017-07-25 11:45:00+03	2017-07-25 13:20:00+03	KRR	ULV	Arrived	763	2017-07-25 11:48:00+03	2017-07-25 13:24:00+03
24293	PG0073	2017-07-29 11:50:00+03	2017-07-29 16:45:00+03	KRR	NOZ	Arrived	733	2017-07-29 11:54:00+03	2017-07-29 16:52:00+03
24294	PG0073	2017-09-02 11:50:00+03	2017-09-02 16:45:00+03	KRR	NOZ	Scheduled	733	\N	\N
24295	PG0073	2017-08-19 11:50:00+03	2017-08-19 16:45:00+03	KRR	NOZ	Scheduled	733	\N	\N
24296	PG0073	2017-07-22 11:50:00+03	2017-07-22 16:45:00+03	KRR	NOZ	Arrived	733	2017-07-22 11:52:00+03	2017-07-22 16:51:00+03
24297	PG0073	2017-08-12 11:50:00+03	2017-08-12 16:45:00+03	KRR	NOZ	Arrived	733	2017-08-12 11:56:00+03	2017-08-12 16:47:00+03
24298	PG0073	2017-08-05 11:50:00+03	2017-08-05 16:45:00+03	KRR	NOZ	Arrived	733	2017-08-05 11:55:00+03	2017-08-05 16:52:00+03
24299	PG0073	2017-08-26 11:50:00+03	2017-08-26 16:45:00+03	KRR	NOZ	Scheduled	733	\N	\N
24300	PG0073	2017-09-09 11:50:00+03	2017-09-09 16:45:00+03	KRR	NOZ	Cancelled	733	\N	\N
24301	PG0380	2017-08-27 11:30:00+03	2017-08-27 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24302	PG0380	2017-09-13 11:30:00+03	2017-09-13 13:55:00+03	KRR	KGD	Cancelled	CR2	\N	\N
24303	PG0380	2017-07-19 11:30:00+03	2017-07-19 13:55:00+03	KRR	KGD	Arrived	CR2	2017-07-19 14:41:00+03	2017-07-19 17:07:00+03
24304	PG0380	2017-09-03 11:30:00+03	2017-09-03 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24305	PG0380	2017-08-23 11:30:00+03	2017-08-23 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24306	PG0380	2017-07-16 11:30:00+03	2017-07-16 13:55:00+03	KRR	KGD	Arrived	CR2	2017-07-16 11:34:00+03	2017-07-16 14:01:00+03
24307	PG0380	2017-07-26 11:30:00+03	2017-07-26 13:55:00+03	KRR	KGD	Arrived	CR2	2017-07-26 11:33:00+03	2017-07-26 13:59:00+03
24308	PG0380	2017-07-23 11:30:00+03	2017-07-23 13:55:00+03	KRR	KGD	Arrived	CR2	2017-07-23 11:30:00+03	2017-07-23 13:56:00+03
24309	PG0380	2017-08-02 11:30:00+03	2017-08-02 13:55:00+03	KRR	KGD	Arrived	CR2	2017-08-02 11:32:00+03	2017-08-02 13:55:00+03
24310	PG0380	2017-09-06 11:30:00+03	2017-09-06 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24311	PG0380	2017-09-10 11:30:00+03	2017-09-10 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24312	PG0380	2017-08-06 11:30:00+03	2017-08-06 13:55:00+03	KRR	KGD	Arrived	CR2	2017-08-06 11:32:00+03	2017-08-06 13:57:00+03
24313	PG0380	2017-07-30 11:30:00+03	2017-07-30 13:55:00+03	KRR	KGD	Arrived	CR2	2017-07-30 11:35:00+03	2017-07-30 14:02:00+03
24314	PG0380	2017-08-30 11:30:00+03	2017-08-30 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24315	PG0380	2017-08-20 11:30:00+03	2017-08-20 13:55:00+03	KRR	KGD	Scheduled	CR2	\N	\N
24316	PG0380	2017-08-09 11:30:00+03	2017-08-09 13:55:00+03	KRR	KGD	Arrived	CR2	2017-08-09 14:39:00+03	2017-08-09 17:04:00+03
24317	PG0380	2017-08-16 11:30:00+03	2017-08-16 13:55:00+03	KRR	KGD	Delayed	CR2	\N	\N
24318	PG0380	2017-08-13 11:30:00+03	2017-08-13 13:55:00+03	KRR	KGD	Arrived	CR2	2017-08-13 11:32:00+03	2017-08-13 13:55:00+03
24319	PG0646	2017-07-23 16:55:00+03	2017-07-23 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-23 16:57:00+03	2017-07-23 17:58:00+03
24320	PG0646	2017-08-27 16:55:00+03	2017-08-27 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24321	PG0646	2017-08-28 16:55:00+03	2017-08-28 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24322	PG0646	2017-08-23 16:55:00+03	2017-08-23 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24323	PG0646	2017-07-24 16:55:00+03	2017-07-24 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-24 16:58:00+03	2017-07-24 17:59:00+03
24324	PG0646	2017-08-14 16:55:00+03	2017-08-14 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-14 16:57:00+03	2017-08-14 17:57:00+03
24325	PG0646	2017-08-02 16:55:00+03	2017-08-02 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-02 17:01:00+03	2017-08-02 17:59:00+03
24326	PG0646	2017-07-25 16:55:00+03	2017-07-25 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-25 16:58:00+03	2017-07-25 17:58:00+03
24327	PG0646	2017-07-29 16:55:00+03	2017-07-29 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-29 16:59:00+03	2017-07-29 17:59:00+03
24328	PG0646	2017-08-18 16:55:00+03	2017-08-18 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24329	PG0646	2017-09-13 16:55:00+03	2017-09-13 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24330	PG0646	2017-08-25 16:55:00+03	2017-08-25 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24331	PG0646	2017-09-12 16:55:00+03	2017-09-12 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24332	PG0646	2017-07-17 16:55:00+03	2017-07-17 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-17 16:57:00+03	2017-07-17 17:57:00+03
24333	PG0646	2017-09-05 16:55:00+03	2017-09-05 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24334	PG0646	2017-08-22 16:55:00+03	2017-08-22 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24335	PG0646	2017-08-07 16:55:00+03	2017-08-07 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-07 16:58:00+03	2017-08-07 17:58:00+03
24336	PG0646	2017-09-11 16:55:00+03	2017-09-11 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24337	PG0646	2017-08-03 16:55:00+03	2017-08-03 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-03 16:59:00+03	2017-08-03 17:59:00+03
24338	PG0646	2017-08-17 16:55:00+03	2017-08-17 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24339	PG0646	2017-07-31 16:55:00+03	2017-07-31 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-31 16:57:00+03	2017-07-31 17:57:00+03
24340	PG0646	2017-09-01 16:55:00+03	2017-09-01 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24341	PG0646	2017-07-28 16:55:00+03	2017-07-28 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-28 16:59:00+03	2017-07-28 17:59:00+03
24342	PG0646	2017-08-29 16:55:00+03	2017-08-29 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24343	PG0646	2017-08-16 16:55:00+03	2017-08-16 17:55:00+03	RTW	DME	On Time	CR2	\N	\N
24344	PG0646	2017-08-13 16:55:00+03	2017-08-13 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-13 16:59:00+03	2017-08-13 17:59:00+03
24345	PG0646	2017-08-08 16:55:00+03	2017-08-08 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-08 16:58:00+03	2017-08-08 17:59:00+03
24346	PG0646	2017-08-11 16:55:00+03	2017-08-11 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-11 16:59:00+03	2017-08-11 17:58:00+03
24347	PG0646	2017-07-22 16:55:00+03	2017-07-22 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-22 17:00:00+03	2017-07-22 18:00:00+03
24348	PG0646	2017-08-24 16:55:00+03	2017-08-24 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24349	PG0646	2017-09-06 16:55:00+03	2017-09-06 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24350	PG0646	2017-07-21 16:55:00+03	2017-07-21 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-21 17:00:00+03	2017-07-21 18:00:00+03
24351	PG0646	2017-08-12 16:55:00+03	2017-08-12 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-12 16:59:00+03	2017-08-12 18:00:00+03
24352	PG0646	2017-07-30 16:55:00+03	2017-07-30 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-30 16:59:00+03	2017-07-30 17:59:00+03
24353	PG0646	2017-08-06 16:55:00+03	2017-08-06 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-06 16:57:00+03	2017-08-06 17:57:00+03
24354	PG0646	2017-09-07 16:55:00+03	2017-09-07 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24355	PG0646	2017-07-19 16:55:00+03	2017-07-19 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-19 16:59:00+03	2017-07-19 17:59:00+03
24356	PG0646	2017-08-20 16:55:00+03	2017-08-20 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24357	PG0646	2017-08-04 16:55:00+03	2017-08-04 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-04 16:58:00+03	2017-08-04 17:57:00+03
24358	PG0646	2017-08-10 16:55:00+03	2017-08-10 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-10 16:57:00+03	2017-08-10 17:57:00+03
24359	PG0646	2017-08-31 16:55:00+03	2017-08-31 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24360	PG0646	2017-09-10 16:55:00+03	2017-09-10 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24361	PG0646	2017-09-14 16:55:00+03	2017-09-14 17:55:00+03	RTW	DME	Cancelled	CR2	\N	\N
24362	PG0646	2017-09-04 16:55:00+03	2017-09-04 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24363	PG0646	2017-08-21 16:55:00+03	2017-08-21 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24364	PG0646	2017-07-27 16:55:00+03	2017-07-27 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-27 16:57:00+03	2017-07-27 17:57:00+03
24365	PG0646	2017-07-20 16:55:00+03	2017-07-20 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-20 16:58:00+03	2017-07-20 17:57:00+03
24366	PG0646	2017-08-15 16:55:00+03	2017-08-15 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-15 16:58:00+03	2017-08-15 17:58:00+03
24367	PG0646	2017-08-05 16:55:00+03	2017-08-05 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-05 17:02:00+03	2017-08-05 18:03:00+03
24368	PG0646	2017-08-26 16:55:00+03	2017-08-26 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24369	PG0646	2017-09-09 16:55:00+03	2017-09-09 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24370	PG0646	2017-08-09 16:55:00+03	2017-08-09 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-09 16:58:00+03	2017-08-09 17:58:00+03
24371	PG0646	2017-09-08 16:55:00+03	2017-09-08 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24372	PG0646	2017-07-16 16:55:00+03	2017-07-16 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-16 16:55:00+03	2017-07-16 17:55:00+03
24373	PG0646	2017-07-18 16:55:00+03	2017-07-18 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-18 16:58:00+03	2017-07-18 17:58:00+03
24374	PG0646	2017-09-03 16:55:00+03	2017-09-03 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24375	PG0646	2017-07-26 16:55:00+03	2017-07-26 17:55:00+03	RTW	DME	Arrived	CR2	2017-07-26 16:57:00+03	2017-07-26 17:57:00+03
24376	PG0646	2017-08-01 16:55:00+03	2017-08-01 17:55:00+03	RTW	DME	Arrived	CR2	2017-08-01 17:01:00+03	2017-08-01 18:01:00+03
24377	PG0646	2017-09-02 16:55:00+03	2017-09-02 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24378	PG0646	2017-08-19 16:55:00+03	2017-08-19 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24379	PG0646	2017-08-30 16:55:00+03	2017-08-30 17:55:00+03	RTW	DME	Scheduled	CR2	\N	\N
24380	PG0139	2017-08-26 11:05:00+03	2017-08-26 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24381	PG0139	2017-08-14 11:05:00+03	2017-08-14 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-14 11:07:00+03	2017-08-14 12:12:00+03
24382	PG0139	2017-08-29 11:05:00+03	2017-08-29 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24383	PG0139	2017-08-22 11:05:00+03	2017-08-22 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24384	PG0139	2017-07-16 11:05:00+03	2017-07-16 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-16 11:08:00+03	2017-07-16 12:13:00+03
24385	PG0139	2017-07-30 11:05:00+03	2017-07-30 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-30 11:07:00+03	2017-07-30 12:12:00+03
24386	PG0139	2017-08-31 11:05:00+03	2017-08-31 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24387	PG0139	2017-08-21 11:05:00+03	2017-08-21 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24388	PG0139	2017-07-27 11:05:00+03	2017-07-27 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-27 11:09:00+03	2017-07-27 12:14:00+03
24389	PG0139	2017-07-24 11:05:00+03	2017-07-24 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-24 11:10:00+03	2017-07-24 12:15:00+03
24390	PG0139	2017-08-25 11:05:00+03	2017-08-25 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24391	PG0139	2017-07-22 11:05:00+03	2017-07-22 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-22 11:09:00+03	2017-07-22 12:14:00+03
24392	PG0139	2017-08-01 11:05:00+03	2017-08-01 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-01 11:05:00+03	2017-08-01 12:11:00+03
24393	PG0139	2017-07-29 11:05:00+03	2017-07-29 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-29 11:08:00+03	2017-07-29 12:12:00+03
24394	PG0139	2017-08-18 11:05:00+03	2017-08-18 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24395	PG0139	2017-08-05 11:05:00+03	2017-08-05 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-05 11:08:00+03	2017-08-05 12:13:00+03
24396	PG0139	2017-08-12 11:05:00+03	2017-08-12 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-12 11:06:00+03	2017-08-12 12:11:00+03
24397	PG0139	2017-09-08 11:05:00+03	2017-09-08 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24398	PG0139	2017-07-26 11:05:00+03	2017-07-26 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-26 11:09:00+03	2017-07-26 12:14:00+03
24399	PG0139	2017-08-19 11:05:00+03	2017-08-19 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24400	PG0139	2017-08-11 11:05:00+03	2017-08-11 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-11 11:11:00+03	2017-08-11 12:17:00+03
24401	PG0139	2017-07-18 11:05:00+03	2017-07-18 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-18 11:06:00+03	2017-07-18 12:11:00+03
24402	PG0139	2017-07-19 11:05:00+03	2017-07-19 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-19 11:09:00+03	2017-07-19 12:15:00+03
24403	PG0139	2017-08-28 11:05:00+03	2017-08-28 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24404	PG0139	2017-09-12 11:05:00+03	2017-09-12 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24405	PG0139	2017-08-07 11:05:00+03	2017-08-07 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-07 11:06:00+03	2017-08-07 12:10:00+03
24406	PG0139	2017-09-11 11:05:00+03	2017-09-11 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24407	PG0139	2017-08-23 11:05:00+03	2017-08-23 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24408	PG0139	2017-09-07 11:05:00+03	2017-09-07 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24409	PG0139	2017-08-09 11:05:00+03	2017-08-09 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-09 11:07:00+03	2017-08-09 12:13:00+03
24410	PG0139	2017-08-13 11:05:00+03	2017-08-13 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-13 11:10:00+03	2017-08-13 12:14:00+03
24411	PG0139	2017-08-20 11:05:00+03	2017-08-20 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24412	PG0139	2017-09-06 11:05:00+03	2017-09-06 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24413	PG0139	2017-08-27 11:05:00+03	2017-08-27 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24414	PG0139	2017-07-21 11:05:00+03	2017-07-21 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-21 11:09:00+03	2017-07-21 12:14:00+03
24415	PG0139	2017-08-03 11:05:00+03	2017-08-03 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-03 11:08:00+03	2017-08-03 12:14:00+03
24416	PG0139	2017-09-13 11:05:00+03	2017-09-13 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24417	PG0139	2017-09-10 11:05:00+03	2017-09-10 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24418	PG0139	2017-08-02 11:05:00+03	2017-08-02 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-02 11:07:00+03	2017-08-02 12:12:00+03
24419	PG0139	2017-09-02 11:05:00+03	2017-09-02 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24420	PG0139	2017-08-16 11:05:00+03	2017-08-16 12:10:00+03	RTW	VKO	On Time	CR2	\N	\N
24421	PG0139	2017-08-04 11:05:00+03	2017-08-04 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-04 11:06:00+03	2017-08-04 12:11:00+03
24422	PG0139	2017-07-25 11:05:00+03	2017-07-25 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-25 11:07:00+03	2017-07-25 12:12:00+03
24423	PG0139	2017-09-05 11:05:00+03	2017-09-05 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24424	PG0139	2017-08-10 11:05:00+03	2017-08-10 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-10 11:07:00+03	2017-08-10 12:12:00+03
24425	PG0139	2017-08-17 11:05:00+03	2017-08-17 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24426	PG0139	2017-07-20 11:05:00+03	2017-07-20 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-20 11:05:00+03	2017-07-20 12:11:00+03
24427	PG0139	2017-07-28 11:05:00+03	2017-07-28 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-28 11:12:00+03	2017-07-28 12:18:00+03
24428	PG0139	2017-07-31 11:05:00+03	2017-07-31 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-31 11:09:00+03	2017-07-31 12:15:00+03
24429	PG0139	2017-09-04 11:05:00+03	2017-09-04 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24430	PG0139	2017-08-08 11:05:00+03	2017-08-08 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-08 11:06:00+03	2017-08-08 12:10:00+03
24431	PG0139	2017-09-03 11:05:00+03	2017-09-03 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24432	PG0139	2017-08-24 11:05:00+03	2017-08-24 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24433	PG0139	2017-08-06 11:05:00+03	2017-08-06 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-06 11:08:00+03	2017-08-06 12:12:00+03
24434	PG0139	2017-09-09 11:05:00+03	2017-09-09 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24435	PG0139	2017-08-30 11:05:00+03	2017-08-30 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24436	PG0139	2017-09-14 11:05:00+03	2017-09-14 12:10:00+03	RTW	VKO	Cancelled	CR2	\N	\N
24437	PG0139	2017-07-23 11:05:00+03	2017-07-23 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-23 11:07:00+03	2017-07-23 12:12:00+03
24438	PG0139	2017-08-15 11:05:00+03	2017-08-15 12:10:00+03	RTW	VKO	Arrived	CR2	2017-08-15 11:11:00+03	2017-08-15 12:16:00+03
24439	PG0139	2017-09-01 11:05:00+03	2017-09-01 12:10:00+03	RTW	VKO	Scheduled	CR2	\N	\N
24440	PG0139	2017-07-17 11:05:00+03	2017-07-17 12:10:00+03	RTW	VKO	Arrived	CR2	2017-07-17 11:07:00+03	2017-07-17 12:12:00+03
24441	PG0465	2017-09-12 13:10:00+03	2017-09-12 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24442	PG0465	2017-08-26 13:10:00+03	2017-08-26 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24443	PG0464	2017-08-26 13:35:00+03	2017-08-26 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24444	PG0465	2017-08-19 13:10:00+03	2017-08-19 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24445	PG0464	2017-08-28 13:35:00+03	2017-08-28 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24446	PG0465	2017-08-28 13:10:00+03	2017-08-28 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24447	PG0465	2017-09-14 13:10:00+03	2017-09-14 14:25:00+03	RTW	ULY	Cancelled	CN1	\N	\N
24448	PG0465	2017-08-05 13:10:00+03	2017-08-05 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-05 13:13:00+03	2017-08-05 14:28:00+03
24449	PG0464	2017-08-05 13:35:00+03	2017-08-05 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-05 16:51:00+03	2017-08-05 18:06:00+03
24450	PG0465	2017-08-18 13:10:00+03	2017-08-18 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24451	PG0464	2017-08-18 13:35:00+03	2017-08-18 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24452	PG0464	2017-07-23 13:35:00+03	2017-07-23 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-23 16:59:00+03	2017-07-23 18:15:00+03
24453	PG0465	2017-07-23 13:10:00+03	2017-07-23 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-23 13:11:00+03	2017-07-23 14:26:00+03
24454	PG0465	2017-09-03 13:10:00+03	2017-09-03 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24455	PG0464	2017-09-03 13:35:00+03	2017-09-03 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24456	PG0464	2017-07-22 13:35:00+03	2017-07-22 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-22 13:38:00+03	2017-07-22 14:53:00+03
24457	PG0465	2017-07-22 13:10:00+03	2017-07-22 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-22 13:15:00+03	2017-07-22 14:32:00+03
24458	PG0465	2017-07-21 13:10:00+03	2017-07-21 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-21 13:11:00+03	2017-07-21 14:25:00+03
24459	PG0464	2017-07-21 13:35:00+03	2017-07-21 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-21 13:37:00+03	2017-07-21 14:53:00+03
24460	PG0464	2017-09-04 13:35:00+03	2017-09-04 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24461	PG0465	2017-09-04 13:10:00+03	2017-09-04 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24462	PG0464	2017-08-07 13:35:00+03	2017-08-07 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-07 13:36:00+03	2017-08-07 14:51:00+03
24463	PG0465	2017-08-07 13:10:00+03	2017-08-07 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-07 13:12:00+03	2017-08-07 14:27:00+03
24464	PG0464	2017-08-25 13:35:00+03	2017-08-25 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24465	PG0465	2017-08-25 13:10:00+03	2017-08-25 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24466	PG0464	2017-07-16 13:35:00+03	2017-07-16 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-16 13:40:00+03	2017-07-16 14:55:00+03
24467	PG0465	2017-07-16 13:10:00+03	2017-07-16 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-16 13:14:00+03	2017-07-16 14:30:00+03
24468	PG0465	2017-08-24 13:10:00+03	2017-08-24 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24469	PG0464	2017-08-24 13:35:00+03	2017-08-24 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24470	PG0464	2017-07-24 13:35:00+03	2017-07-24 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-24 13:37:00+03	2017-07-24 14:51:00+03
24471	PG0465	2017-07-24 13:10:00+03	2017-07-24 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-24 13:13:00+03	2017-07-24 14:28:00+03
24472	PG0465	2017-08-17 13:10:00+03	2017-08-17 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24473	PG0464	2017-08-17 13:35:00+03	2017-08-17 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24474	PG0465	2017-09-10 13:10:00+03	2017-09-10 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24475	PG0464	2017-09-10 13:35:00+03	2017-09-10 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24476	PG0464	2017-08-20 13:35:00+03	2017-08-20 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24477	PG0465	2017-08-20 13:10:00+03	2017-08-20 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24478	PG0465	2017-08-04 13:10:00+03	2017-08-04 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-04 13:12:00+03	2017-08-04 14:27:00+03
24479	PG0464	2017-08-04 13:35:00+03	2017-08-04 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-04 13:36:00+03	2017-08-04 14:50:00+03
24480	PG0465	2017-08-27 13:10:00+03	2017-08-27 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24481	PG0464	2017-08-27 13:35:00+03	2017-08-27 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24482	PG0464	2017-08-29 13:35:00+03	2017-08-29 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24483	PG0465	2017-08-29 13:10:00+03	2017-08-29 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24484	PG0464	2017-08-08 13:35:00+03	2017-08-08 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-08 13:38:00+03	2017-08-08 14:54:00+03
24485	PG0465	2017-08-08 13:10:00+03	2017-08-08 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-08 13:16:00+03	2017-08-08 14:30:00+03
24486	PG0464	2017-07-25 13:35:00+03	2017-07-25 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-25 13:39:00+03	2017-07-25 14:54:00+03
24487	PG0465	2017-07-25 13:10:00+03	2017-07-25 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-25 13:17:00+03	2017-07-25 14:32:00+03
24488	PG0464	2017-09-12 13:35:00+03	2017-09-12 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24489	PG0465	2017-08-16 13:10:00+03	2017-08-16 14:25:00+03	RTW	ULY	On Time	CN1	\N	\N
24490	PG0464	2017-08-16 13:35:00+03	2017-08-16 14:50:00+03	RTW	ULY	On Time	CN1	\N	\N
24491	PG0465	2017-08-03 13:10:00+03	2017-08-03 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-03 13:16:00+03	2017-08-03 14:32:00+03
24492	PG0464	2017-08-03 13:35:00+03	2017-08-03 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-03 13:41:00+03	2017-08-03 14:56:00+03
24493	PG0465	2017-07-20 13:10:00+03	2017-07-20 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-20 13:16:00+03	2017-07-20 14:30:00+03
24494	PG0464	2017-07-20 13:35:00+03	2017-07-20 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-20 13:42:00+03	2017-07-20 14:57:00+03
24495	PG0464	2017-09-05 13:35:00+03	2017-09-05 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24496	PG0465	2017-09-05 13:10:00+03	2017-09-05 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24497	PG0465	2017-09-02 13:10:00+03	2017-09-02 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24498	PG0464	2017-09-02 13:35:00+03	2017-09-02 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24499	PG0465	2017-09-09 13:10:00+03	2017-09-09 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24500	PG0464	2017-09-09 13:35:00+03	2017-09-09 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24501	PG0464	2017-07-26 13:35:00+03	2017-07-26 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-26 13:43:00+03	2017-07-26 14:57:00+03
24502	PG0465	2017-07-26 13:10:00+03	2017-07-26 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-26 13:13:00+03	2017-07-26 14:28:00+03
24503	PG0465	2017-08-15 13:10:00+03	2017-08-15 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-15 16:03:00+03	2017-08-15 17:18:00+03
24504	PG0464	2017-08-15 13:35:00+03	2017-08-15 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-15 16:42:00+03	2017-08-15 17:56:00+03
24505	PG0464	2017-08-09 13:35:00+03	2017-08-09 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-09 13:38:00+03	2017-08-09 14:53:00+03
24506	PG0465	2017-08-09 13:10:00+03	2017-08-09 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-09 13:14:00+03	2017-08-09 14:28:00+03
24507	PG0465	2017-08-02 13:10:00+03	2017-08-02 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-02 16:16:00+03	2017-08-02 17:30:00+03
24508	PG0464	2017-08-02 13:35:00+03	2017-08-02 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-02 13:41:00+03	2017-08-02 14:55:00+03
24509	PG0464	2017-08-21 13:35:00+03	2017-08-21 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24510	PG0465	2017-08-21 13:10:00+03	2017-08-21 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24511	PG0464	2017-08-30 13:35:00+03	2017-08-30 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24512	PG0465	2017-08-30 13:10:00+03	2017-08-30 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24513	PG0464	2017-07-27 13:35:00+03	2017-07-27 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-27 13:38:00+03	2017-07-27 14:53:00+03
24514	PG0465	2017-07-27 13:10:00+03	2017-07-27 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-27 13:14:00+03	2017-07-27 14:31:00+03
24515	PG0464	2017-07-17 13:35:00+03	2017-07-17 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-17 13:38:00+03	2017-07-17 14:54:00+03
24516	PG0465	2017-07-17 13:10:00+03	2017-07-17 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-17 13:16:00+03	2017-07-17 14:33:00+03
24517	PG0465	2017-08-14 13:10:00+03	2017-08-14 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-14 13:13:00+03	2017-08-14 14:28:00+03
24518	PG0464	2017-08-14 13:35:00+03	2017-08-14 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-14 13:39:00+03	2017-08-14 14:56:00+03
24519	PG0465	2017-08-23 13:10:00+03	2017-08-23 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24520	PG0464	2017-08-23 13:35:00+03	2017-08-23 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24521	PG0464	2017-09-14 13:35:00+03	2017-09-14 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24522	PG0465	2017-07-19 13:10:00+03	2017-07-19 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-19 13:12:00+03	2017-07-19 14:26:00+03
24523	PG0464	2017-07-19 13:35:00+03	2017-07-19 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-19 13:39:00+03	2017-07-19 14:55:00+03
24524	PG0465	2017-08-01 13:10:00+03	2017-08-01 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-01 13:13:00+03	2017-08-01 14:28:00+03
24525	PG0465	2017-09-08 13:10:00+03	2017-09-08 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24526	PG0464	2017-09-08 13:35:00+03	2017-09-08 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24527	PG0464	2017-08-01 13:35:00+03	2017-08-01 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-01 13:36:00+03	2017-08-01 14:52:00+03
24528	PG0464	2017-07-28 13:35:00+03	2017-07-28 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-28 13:39:00+03	2017-07-28 14:53:00+03
24529	PG0465	2017-07-28 13:10:00+03	2017-07-28 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-28 13:13:00+03	2017-07-28 14:28:00+03
24530	PG0464	2017-08-10 13:35:00+03	2017-08-10 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-10 13:41:00+03	2017-08-10 14:56:00+03
24531	PG0465	2017-08-10 13:10:00+03	2017-08-10 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-10 13:12:00+03	2017-08-10 14:28:00+03
24532	PG0464	2017-08-06 13:35:00+03	2017-08-06 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-06 13:38:00+03	2017-08-06 14:53:00+03
24533	PG0465	2017-08-06 13:10:00+03	2017-08-06 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-06 13:12:00+03	2017-08-06 14:27:00+03
24534	PG0464	2017-09-06 13:35:00+03	2017-09-06 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24535	PG0465	2017-09-06 13:10:00+03	2017-09-06 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24536	PG0465	2017-08-13 13:10:00+03	2017-08-13 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-13 13:15:00+03	2017-08-13 14:30:00+03
24537	PG0464	2017-08-13 13:35:00+03	2017-08-13 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-13 13:37:00+03	2017-08-13 14:53:00+03
24538	PG0465	2017-09-01 13:10:00+03	2017-09-01 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24539	PG0464	2017-09-01 13:35:00+03	2017-09-01 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24540	PG0464	2017-07-29 13:35:00+03	2017-07-29 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-29 13:39:00+03	2017-07-29 14:54:00+03
24541	PG0465	2017-07-29 13:10:00+03	2017-07-29 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-29 13:13:00+03	2017-07-29 14:29:00+03
24542	PG0465	2017-09-11 13:10:00+03	2017-09-11 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24543	PG0464	2017-09-11 13:35:00+03	2017-09-11 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24544	PG0464	2017-08-31 13:35:00+03	2017-08-31 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24545	PG0465	2017-08-31 13:10:00+03	2017-08-31 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24546	PG0464	2017-09-13 13:35:00+03	2017-09-13 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24547	PG0465	2017-09-13 13:10:00+03	2017-09-13 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24548	PG0465	2017-07-31 13:10:00+03	2017-07-31 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-31 13:12:00+03	2017-07-31 14:28:00+03
24549	PG0464	2017-08-11 13:35:00+03	2017-08-11 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-11 13:35:00+03	2017-08-11 14:50:00+03
24550	PG0465	2017-08-11 13:10:00+03	2017-08-11 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-11 13:13:00+03	2017-08-11 14:27:00+03
24551	PG0464	2017-07-31 13:35:00+03	2017-07-31 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-31 13:38:00+03	2017-07-31 14:53:00+03
24552	PG0464	2017-08-22 13:35:00+03	2017-08-22 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24553	PG0465	2017-08-22 13:10:00+03	2017-08-22 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24554	PG0465	2017-09-07 13:10:00+03	2017-09-07 14:25:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24555	PG0464	2017-09-07 13:35:00+03	2017-09-07 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24556	PG0465	2017-08-12 13:10:00+03	2017-08-12 14:25:00+03	RTW	ULY	Arrived	CN1	2017-08-12 13:13:00+03	2017-08-12 14:28:00+03
24557	PG0464	2017-08-19 13:35:00+03	2017-08-19 14:50:00+03	RTW	ULY	Scheduled	CN1	\N	\N
24558	PG0464	2017-08-12 13:35:00+03	2017-08-12 14:50:00+03	RTW	ULY	Arrived	CN1	2017-08-12 13:39:00+03	2017-08-12 14:53:00+03
24559	PG0464	2017-07-30 13:35:00+03	2017-07-30 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-30 13:39:00+03	2017-07-30 14:53:00+03
24560	PG0465	2017-07-30 13:10:00+03	2017-07-30 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-30 13:12:00+03	2017-07-30 14:28:00+03
24561	PG0465	2017-07-18 13:10:00+03	2017-07-18 14:25:00+03	RTW	ULY	Arrived	CN1	2017-07-18 13:13:00+03	2017-07-18 14:27:00+03
24562	PG0464	2017-07-18 13:35:00+03	2017-07-18 14:50:00+03	RTW	ULY	Arrived	CN1	2017-07-18 13:35:00+03	2017-07-18 14:50:00+03
24563	PG0302	2017-08-27 10:55:00+03	2017-08-27 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24564	PG0302	2017-07-26 10:55:00+03	2017-07-26 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-26 10:56:00+03	2017-07-26 13:11:00+03
24565	PG0302	2017-08-05 10:55:00+03	2017-08-05 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-05 10:56:00+03	2017-08-05 13:12:00+03
24566	PG0302	2017-07-21 10:55:00+03	2017-07-21 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-21 10:59:00+03	2017-07-21 13:15:00+03
24567	PG0302	2017-08-09 10:55:00+03	2017-08-09 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-09 10:57:00+03	2017-08-09 13:10:00+03
24568	PG0302	2017-07-30 10:55:00+03	2017-07-30 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-30 10:59:00+03	2017-07-30 13:14:00+03
24569	PG0302	2017-07-27 10:55:00+03	2017-07-27 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-27 10:58:00+03	2017-07-27 13:15:00+03
24570	PG0302	2017-09-10 10:55:00+03	2017-09-10 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24571	PG0302	2017-07-28 10:55:00+03	2017-07-28 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-28 10:58:00+03	2017-07-28 13:14:00+03
24572	PG0302	2017-07-17 10:55:00+03	2017-07-17 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-17 10:59:00+03	2017-07-17 13:14:00+03
24573	PG0302	2017-07-31 10:55:00+03	2017-07-31 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-31 10:56:00+03	2017-07-31 13:08:00+03
24574	PG0302	2017-07-16 10:55:00+03	2017-07-16 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-16 10:58:00+03	2017-07-16 13:13:00+03
24575	PG0302	2017-08-11 10:55:00+03	2017-08-11 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-11 10:58:00+03	2017-08-11 13:12:00+03
24576	PG0302	2017-08-08 10:55:00+03	2017-08-08 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-08 11:00:00+03	2017-08-08 13:14:00+03
24577	PG0302	2017-08-31 10:55:00+03	2017-08-31 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24578	PG0302	2017-08-26 10:55:00+03	2017-08-26 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24579	PG0302	2017-09-08 10:55:00+03	2017-09-08 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24580	PG0302	2017-08-13 10:55:00+03	2017-08-13 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-13 10:56:00+03	2017-08-13 13:12:00+03
24581	PG0302	2017-08-19 10:55:00+03	2017-08-19 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24582	PG0302	2017-08-28 10:55:00+03	2017-08-28 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24583	PG0302	2017-07-23 10:55:00+03	2017-07-23 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-23 11:01:00+03	2017-07-23 13:13:00+03
24584	PG0302	2017-08-25 10:55:00+03	2017-08-25 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24585	PG0302	2017-08-23 10:55:00+03	2017-08-23 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24586	PG0302	2017-08-06 10:55:00+03	2017-08-06 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-06 10:58:00+03	2017-08-06 13:13:00+03
24587	PG0302	2017-09-11 10:55:00+03	2017-09-11 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24588	PG0302	2017-09-09 10:55:00+03	2017-09-09 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24589	PG0302	2017-07-25 10:55:00+03	2017-07-25 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-25 10:57:00+03	2017-07-25 13:13:00+03
24590	PG0302	2017-08-03 10:55:00+03	2017-08-03 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-03 11:00:00+03	2017-08-03 13:14:00+03
24591	PG0302	2017-08-01 10:55:00+03	2017-08-01 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-01 10:59:00+03	2017-08-01 13:13:00+03
24592	PG0302	2017-09-13 10:55:00+03	2017-09-13 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24593	PG0302	2017-08-16 10:55:00+03	2017-08-16 13:10:00+03	TJM	SVO	On Time	SU9	\N	\N
24594	PG0302	2017-08-04 10:55:00+03	2017-08-04 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-04 10:59:00+03	2017-08-04 13:15:00+03
24595	PG0302	2017-07-20 10:55:00+03	2017-07-20 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-20 10:57:00+03	2017-07-20 13:10:00+03
24596	PG0302	2017-08-20 10:55:00+03	2017-08-20 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24597	PG0302	2017-09-03 10:55:00+03	2017-09-03 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24598	PG0302	2017-09-02 10:55:00+03	2017-09-02 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24599	PG0302	2017-08-12 10:55:00+03	2017-08-12 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-12 10:59:00+03	2017-08-12 13:17:00+03
24600	PG0302	2017-08-02 10:55:00+03	2017-08-02 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-02 11:00:00+03	2017-08-02 13:13:00+03
24601	PG0302	2017-08-29 10:55:00+03	2017-08-29 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24602	PG0302	2017-08-07 10:55:00+03	2017-08-07 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-07 10:58:00+03	2017-08-07 13:12:00+03
24603	PG0302	2017-08-24 10:55:00+03	2017-08-24 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24604	PG0302	2017-07-24 10:55:00+03	2017-07-24 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-24 14:07:00+03	2017-07-24 16:22:00+03
24605	PG0302	2017-08-15 10:55:00+03	2017-08-15 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-15 10:58:00+03	2017-08-15 13:13:00+03
24606	PG0302	2017-08-21 10:55:00+03	2017-08-21 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24607	PG0302	2017-09-14 10:55:00+03	2017-09-14 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24608	PG0302	2017-08-30 10:55:00+03	2017-08-30 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24609	PG0302	2017-07-19 10:55:00+03	2017-07-19 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-19 10:58:00+03	2017-07-19 13:12:00+03
24610	PG0302	2017-07-29 10:55:00+03	2017-07-29 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-29 14:18:00+03	2017-07-29 16:34:00+03
24611	PG0302	2017-09-12 10:55:00+03	2017-09-12 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24612	PG0302	2017-09-01 10:55:00+03	2017-09-01 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24613	PG0302	2017-08-22 10:55:00+03	2017-08-22 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24614	PG0302	2017-09-07 10:55:00+03	2017-09-07 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24615	PG0302	2017-07-22 10:55:00+03	2017-07-22 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-22 10:57:00+03	2017-07-22 13:12:00+03
24616	PG0302	2017-08-10 10:55:00+03	2017-08-10 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-10 10:58:00+03	2017-08-10 13:14:00+03
24617	PG0302	2017-09-04 10:55:00+03	2017-09-04 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24618	PG0302	2017-07-18 10:55:00+03	2017-07-18 13:10:00+03	TJM	SVO	Arrived	SU9	2017-07-18 11:02:00+03	2017-07-18 13:17:00+03
24619	PG0302	2017-08-14 10:55:00+03	2017-08-14 13:10:00+03	TJM	SVO	Arrived	SU9	2017-08-14 10:56:00+03	2017-08-14 13:11:00+03
24620	PG0302	2017-09-05 10:55:00+03	2017-09-05 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24621	PG0302	2017-08-18 10:55:00+03	2017-08-18 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24622	PG0302	2017-08-17 10:55:00+03	2017-08-17 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24623	PG0302	2017-09-06 10:55:00+03	2017-09-06 13:10:00+03	TJM	SVO	Scheduled	SU9	\N	\N
24624	PG0189	2017-07-25 14:05:00+03	2017-07-25 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-25 14:12:00+03	2017-07-25 17:07:00+03
24625	PG0189	2017-07-17 14:05:00+03	2017-07-17 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-17 14:13:00+03	2017-07-17 17:04:00+03
24626	PG0189	2017-08-31 14:05:00+03	2017-08-31 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24627	PG0189	2017-08-15 14:05:00+03	2017-08-15 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-15 14:08:00+03	2017-08-15 17:03:00+03
24628	PG0189	2017-08-02 14:05:00+03	2017-08-02 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-02 14:10:00+03	2017-08-02 17:05:00+03
24629	PG0189	2017-08-29 14:05:00+03	2017-08-29 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24630	PG0189	2017-07-30 14:05:00+03	2017-07-30 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-30 14:09:00+03	2017-07-30 17:05:00+03
24631	PG0189	2017-09-09 14:05:00+03	2017-09-09 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24632	PG0189	2017-08-21 14:05:00+03	2017-08-21 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24633	PG0189	2017-08-13 14:05:00+03	2017-08-13 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-13 14:08:00+03	2017-08-13 17:01:00+03
24634	PG0189	2017-08-23 14:05:00+03	2017-08-23 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24635	PG0189	2017-08-14 14:05:00+03	2017-08-14 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-14 14:07:00+03	2017-08-14 17:00:00+03
24636	PG0189	2017-07-26 14:05:00+03	2017-07-26 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-26 14:07:00+03	2017-07-26 16:58:00+03
24637	PG0189	2017-07-23 14:05:00+03	2017-07-23 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-23 14:07:00+03	2017-07-23 17:03:00+03
24638	PG0189	2017-09-07 14:05:00+03	2017-09-07 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24639	PG0189	2017-08-03 14:05:00+03	2017-08-03 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-03 14:07:00+03	2017-08-03 17:00:00+03
24640	PG0189	2017-07-19 14:05:00+03	2017-07-19 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-19 14:08:00+03	2017-07-19 17:04:00+03
24641	PG0189	2017-09-08 14:05:00+03	2017-09-08 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24642	PG0189	2017-08-01 14:05:00+03	2017-08-01 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-01 14:07:00+03	2017-08-01 17:04:00+03
24643	PG0189	2017-08-24 14:05:00+03	2017-08-24 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24644	PG0189	2017-09-05 14:05:00+03	2017-09-05 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24645	PG0189	2017-08-27 14:05:00+03	2017-08-27 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24646	PG0189	2017-08-16 14:05:00+03	2017-08-16 17:00:00+03	TJM	LED	On Time	CR2	\N	\N
24647	PG0189	2017-07-24 14:05:00+03	2017-07-24 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-24 17:22:00+03	2017-07-24 20:14:00+03
24648	PG0189	2017-08-11 14:05:00+03	2017-08-11 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-11 14:07:00+03	2017-08-11 17:04:00+03
24649	PG0189	2017-08-30 14:05:00+03	2017-08-30 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24650	PG0189	2017-07-27 14:05:00+03	2017-07-27 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-27 14:09:00+03	2017-07-27 17:03:00+03
24651	PG0189	2017-07-22 14:05:00+03	2017-07-22 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-22 18:03:00+03	2017-07-22 20:57:00+03
24652	PG0189	2017-09-02 14:05:00+03	2017-09-02 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24653	PG0189	2017-08-09 14:05:00+03	2017-08-09 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-09 14:07:00+03	2017-08-09 17:05:00+03
24654	PG0189	2017-09-12 14:05:00+03	2017-09-12 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24655	PG0189	2017-07-31 14:05:00+03	2017-07-31 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-31 14:08:00+03	2017-07-31 17:02:00+03
24656	PG0189	2017-09-04 14:05:00+03	2017-09-04 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24657	PG0189	2017-09-03 14:05:00+03	2017-09-03 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24658	PG0189	2017-08-07 14:05:00+03	2017-08-07 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-07 16:54:00+03	2017-08-07 19:50:00+03
24659	PG0189	2017-08-22 14:05:00+03	2017-08-22 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24660	PG0189	2017-08-10 14:05:00+03	2017-08-10 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-10 14:06:00+03	2017-08-10 17:01:00+03
24661	PG0189	2017-07-18 14:05:00+03	2017-07-18 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-18 14:09:00+03	2017-07-18 17:01:00+03
24662	PG0189	2017-08-12 14:05:00+03	2017-08-12 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-12 14:08:00+03	2017-08-12 17:01:00+03
24663	PG0189	2017-09-06 14:05:00+03	2017-09-06 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24664	PG0189	2017-08-19 14:05:00+03	2017-08-19 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24665	PG0189	2017-07-20 14:05:00+03	2017-07-20 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-20 14:07:00+03	2017-07-20 17:00:00+03
24666	PG0189	2017-07-29 14:05:00+03	2017-07-29 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-29 14:06:00+03	2017-07-29 17:00:00+03
24667	PG0189	2017-08-28 14:05:00+03	2017-08-28 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24668	PG0189	2017-09-10 14:05:00+03	2017-09-10 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24669	PG0189	2017-07-28 14:05:00+03	2017-07-28 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-28 14:07:00+03	2017-07-28 17:01:00+03
24670	PG0189	2017-08-08 14:05:00+03	2017-08-08 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-08 14:09:00+03	2017-08-08 17:04:00+03
24671	PG0189	2017-08-17 14:05:00+03	2017-08-17 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24672	PG0189	2017-08-06 14:05:00+03	2017-08-06 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-06 14:10:00+03	2017-08-06 16:59:00+03
24673	PG0189	2017-08-25 14:05:00+03	2017-08-25 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24674	PG0189	2017-07-21 14:05:00+03	2017-07-21 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-21 14:06:00+03	2017-07-21 17:02:00+03
24675	PG0189	2017-08-20 14:05:00+03	2017-08-20 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24676	PG0189	2017-07-16 14:05:00+03	2017-07-16 17:00:00+03	TJM	LED	Arrived	CR2	2017-07-16 14:08:00+03	2017-07-16 17:03:00+03
24677	PG0189	2017-09-13 14:05:00+03	2017-09-13 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24678	PG0189	2017-09-14 14:05:00+03	2017-09-14 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24679	PG0189	2017-08-04 14:05:00+03	2017-08-04 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-04 14:08:00+03	2017-08-04 17:03:00+03
24680	PG0189	2017-08-05 14:05:00+03	2017-08-05 17:00:00+03	TJM	LED	Arrived	CR2	2017-08-05 14:08:00+03	2017-08-05 17:05:00+03
24681	PG0189	2017-09-01 14:05:00+03	2017-09-01 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24682	PG0189	2017-09-11 14:05:00+03	2017-09-11 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24683	PG0189	2017-08-18 14:05:00+03	2017-08-18 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24684	PG0189	2017-08-26 14:05:00+03	2017-08-26 17:00:00+03	TJM	LED	Scheduled	CR2	\N	\N
24685	PG0632	2017-07-20 15:00:00+03	2017-07-20 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-20 15:02:00+03	2017-07-20 17:38:00+03
24686	PG0632	2017-07-19 15:00:00+03	2017-07-19 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-19 15:03:00+03	2017-07-19 17:38:00+03
24687	PG0632	2017-09-05 15:00:00+03	2017-09-05 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24688	PG0632	2017-07-27 15:00:00+03	2017-07-27 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-27 15:02:00+03	2017-07-27 17:38:00+03
24689	PG0632	2017-08-21 15:00:00+03	2017-08-21 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24690	PG0632	2017-08-18 15:00:00+03	2017-08-18 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24691	PG0632	2017-09-07 15:00:00+03	2017-09-07 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24692	PG0632	2017-07-29 15:00:00+03	2017-07-29 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-29 15:03:00+03	2017-07-29 17:38:00+03
24693	PG0632	2017-07-28 15:00:00+03	2017-07-28 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-28 15:01:00+03	2017-07-28 17:36:00+03
24694	PG0632	2017-08-17 15:00:00+03	2017-08-17 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24695	PG0632	2017-09-09 15:00:00+03	2017-09-09 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24696	PG0632	2017-08-15 15:00:00+03	2017-08-15 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-15 15:02:00+03	2017-08-15 17:33:00+03
24697	PG0632	2017-08-27 15:00:00+03	2017-08-27 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24698	PG0632	2017-09-10 15:00:00+03	2017-09-10 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24699	PG0632	2017-09-12 15:00:00+03	2017-09-12 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24700	PG0632	2017-09-01 15:00:00+03	2017-09-01 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24701	PG0632	2017-08-08 15:00:00+03	2017-08-08 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-08 15:02:00+03	2017-08-08 17:36:00+03
24702	PG0632	2017-08-29 15:00:00+03	2017-08-29 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24703	PG0632	2017-07-30 15:00:00+03	2017-07-30 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-30 15:03:00+03	2017-07-30 17:37:00+03
24704	PG0632	2017-08-04 15:00:00+03	2017-08-04 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-04 15:01:00+03	2017-08-04 17:35:00+03
24706	PG0632	2017-08-23 15:00:00+03	2017-08-23 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24707	PG0632	2017-09-04 15:00:00+03	2017-09-04 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24708	PG0632	2017-08-31 15:00:00+03	2017-08-31 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24709	PG0632	2017-09-13 15:00:00+03	2017-09-13 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24710	PG0632	2017-07-22 15:00:00+03	2017-07-22 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-22 15:02:00+03	2017-07-22 17:37:00+03
24711	PG0632	2017-09-14 15:00:00+03	2017-09-14 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24712	PG0632	2017-07-23 15:00:00+03	2017-07-23 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-23 15:03:00+03	2017-07-23 17:37:00+03
24713	PG0632	2017-08-28 15:00:00+03	2017-08-28 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24714	PG0632	2017-08-07 15:00:00+03	2017-08-07 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-07 15:04:00+03	2017-08-07 17:38:00+03
24715	PG0632	2017-08-22 15:00:00+03	2017-08-22 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24716	PG0632	2017-09-11 15:00:00+03	2017-09-11 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24717	PG0632	2017-07-25 15:00:00+03	2017-07-25 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-25 15:05:00+03	2017-07-25 17:39:00+03
24718	PG0632	2017-08-11 15:00:00+03	2017-08-11 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-11 15:03:00+03	2017-08-11 17:36:00+03
24719	PG0632	2017-09-02 15:00:00+03	2017-09-02 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24720	PG0632	2017-07-18 15:00:00+03	2017-07-18 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-18 15:02:00+03	2017-07-18 17:38:00+03
24721	PG0632	2017-08-24 15:00:00+03	2017-08-24 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24722	PG0632	2017-08-05 15:00:00+03	2017-08-05 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-05 15:02:00+03	2017-08-05 17:39:00+03
24723	PG0632	2017-08-09 15:00:00+03	2017-08-09 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-09 18:53:00+03	2017-08-09 21:28:00+03
24724	PG0632	2017-08-06 15:00:00+03	2017-08-06 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-06 15:02:00+03	2017-08-06 17:38:00+03
24725	PG0632	2017-08-25 15:00:00+03	2017-08-25 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24726	PG0632	2017-09-03 15:00:00+03	2017-09-03 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24727	PG0632	2017-07-24 15:00:00+03	2017-07-24 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-24 15:03:00+03	2017-07-24 17:39:00+03
24728	PG0632	2017-08-10 15:00:00+03	2017-08-10 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-10 15:04:00+03	2017-08-10 17:40:00+03
24729	PG0632	2017-08-03 15:00:00+03	2017-08-03 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-03 15:04:00+03	2017-08-03 17:37:00+03
24730	PG0632	2017-08-02 15:00:00+03	2017-08-02 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-02 15:03:00+03	2017-08-02 17:37:00+03
24731	PG0632	2017-07-17 15:00:00+03	2017-07-17 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-17 15:01:00+03	2017-07-17 17:35:00+03
24732	PG0632	2017-07-26 15:00:00+03	2017-07-26 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-26 15:01:00+03	2017-07-26 17:37:00+03
24733	PG0632	2017-08-16 15:00:00+03	2017-08-16 17:35:00+03	TJM	PES	On Time	CR2	\N	\N
24734	PG0632	2017-08-01 15:00:00+03	2017-08-01 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-01 15:03:00+03	2017-08-01 17:35:00+03
24735	PG0632	2017-07-31 15:00:00+03	2017-07-31 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-31 15:04:00+03	2017-07-31 17:40:00+03
24736	PG0632	2017-08-30 15:00:00+03	2017-08-30 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24737	PG0632	2017-09-06 15:00:00+03	2017-09-06 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24738	PG0632	2017-08-12 15:00:00+03	2017-08-12 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-12 15:04:00+03	2017-08-12 17:40:00+03
24739	PG0632	2017-08-13 15:00:00+03	2017-08-13 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-13 15:04:00+03	2017-08-13 17:42:00+03
24740	PG0632	2017-07-16 15:00:00+03	2017-07-16 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-16 15:02:00+03	2017-07-16 17:36:00+03
24741	PG0632	2017-09-08 15:00:00+03	2017-09-08 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24742	PG0632	2017-08-14 15:00:00+03	2017-08-14 17:35:00+03	TJM	PES	Arrived	CR2	2017-08-14 15:02:00+03	2017-08-14 17:38:00+03
24743	PG0632	2017-07-21 15:00:00+03	2017-07-21 17:35:00+03	TJM	PES	Arrived	CR2	2017-07-21 15:05:00+03	2017-07-21 17:39:00+03
24744	PG0632	2017-08-19 15:00:00+03	2017-08-19 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24745	PG0632	2017-08-20 15:00:00+03	2017-08-20 17:35:00+03	TJM	PES	Scheduled	CR2	\N	\N
24746	PG0111	2017-09-01 16:20:00+03	2017-09-01 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24747	PG0111	2017-08-04 16:20:00+03	2017-08-04 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-04 16:25:00+03	2017-08-04 17:45:00+03
24748	PG0111	2017-09-09 16:20:00+03	2017-09-09 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24749	PG0111	2017-08-16 16:20:00+03	2017-08-16 17:40:00+03	TJM	UCT	On Time	CR2	\N	\N
24750	PG0111	2017-09-05 16:20:00+03	2017-09-05 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24751	PG0111	2017-08-27 16:20:00+03	2017-08-27 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24752	PG0111	2017-09-12 16:20:00+03	2017-09-12 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24753	PG0111	2017-07-30 16:20:00+03	2017-07-30 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-30 16:24:00+03	2017-07-30 17:43:00+03
24754	PG0111	2017-08-26 16:20:00+03	2017-08-26 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24755	PG0111	2017-08-25 16:20:00+03	2017-08-25 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24756	PG0111	2017-08-03 16:20:00+03	2017-08-03 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-03 16:25:00+03	2017-08-03 17:44:00+03
24757	PG0111	2017-07-27 16:20:00+03	2017-07-27 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-27 16:21:00+03	2017-07-27 17:41:00+03
24758	PG0111	2017-08-08 16:20:00+03	2017-08-08 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-08 16:21:00+03	2017-08-08 17:42:00+03
24759	PG0111	2017-08-17 16:20:00+03	2017-08-17 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24760	PG0111	2017-08-22 16:20:00+03	2017-08-22 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24761	PG0111	2017-07-25 16:20:00+03	2017-07-25 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-25 16:24:00+03	2017-07-25 17:45:00+03
24762	PG0111	2017-07-18 16:20:00+03	2017-07-18 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-18 16:25:00+03	2017-07-18 17:45:00+03
24763	PG0111	2017-07-23 16:20:00+03	2017-07-23 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-23 16:23:00+03	2017-07-23 17:43:00+03
24764	PG0111	2017-08-09 16:20:00+03	2017-08-09 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-09 16:20:00+03	2017-08-09 17:39:00+03
24765	PG0111	2017-09-14 16:20:00+03	2017-09-14 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24766	PG0111	2017-07-16 16:20:00+03	2017-07-16 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-16 16:21:00+03	2017-07-16 17:41:00+03
24767	PG0111	2017-07-19 16:20:00+03	2017-07-19 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-19 16:22:00+03	2017-07-19 17:41:00+03
24768	PG0111	2017-08-14 16:20:00+03	2017-08-14 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-14 16:23:00+03	2017-08-14 17:43:00+03
24769	PG0111	2017-08-05 16:20:00+03	2017-08-05 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-05 16:21:00+03	2017-08-05 17:41:00+03
24770	PG0111	2017-09-02 16:20:00+03	2017-09-02 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24771	PG0111	2017-08-06 16:20:00+03	2017-08-06 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-06 16:23:00+03	2017-08-06 17:42:00+03
24772	PG0111	2017-08-07 16:20:00+03	2017-08-07 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-07 16:24:00+03	2017-08-07 17:44:00+03
24773	PG0111	2017-08-31 16:20:00+03	2017-08-31 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24774	PG0111	2017-07-20 16:20:00+03	2017-07-20 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-20 16:23:00+03	2017-07-20 17:43:00+03
24775	PG0111	2017-07-29 16:20:00+03	2017-07-29 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-29 16:25:00+03	2017-07-29 17:44:00+03
24776	PG0111	2017-08-18 16:20:00+03	2017-08-18 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24777	PG0111	2017-08-30 16:20:00+03	2017-08-30 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24778	PG0111	2017-09-06 16:20:00+03	2017-09-06 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24779	PG0111	2017-08-23 16:20:00+03	2017-08-23 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24780	PG0111	2017-08-20 16:20:00+03	2017-08-20 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24781	PG0111	2017-08-21 16:20:00+03	2017-08-21 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24782	PG0111	2017-07-17 16:20:00+03	2017-07-17 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-17 16:23:00+03	2017-07-17 17:41:00+03
24783	PG0111	2017-08-02 16:20:00+03	2017-08-02 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-02 16:21:00+03	2017-08-02 17:41:00+03
24784	PG0111	2017-07-28 16:20:00+03	2017-07-28 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-28 16:20:00+03	2017-07-28 17:41:00+03
24785	PG0111	2017-08-29 16:20:00+03	2017-08-29 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24786	PG0111	2017-07-26 16:20:00+03	2017-07-26 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-26 16:23:00+03	2017-07-26 17:43:00+03
24787	PG0111	2017-08-24 16:20:00+03	2017-08-24 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24788	PG0111	2017-09-13 16:20:00+03	2017-09-13 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24789	PG0111	2017-08-01 16:20:00+03	2017-08-01 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-01 16:23:00+03	2017-08-01 17:42:00+03
24790	PG0111	2017-07-24 16:20:00+03	2017-07-24 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-24 16:22:00+03	2017-07-24 17:42:00+03
24791	PG0111	2017-08-13 16:20:00+03	2017-08-13 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-13 16:21:00+03	2017-08-13 17:42:00+03
24792	PG0111	2017-09-03 16:20:00+03	2017-09-03 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24793	PG0111	2017-08-15 16:20:00+03	2017-08-15 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-15 16:24:00+03	2017-08-15 17:43:00+03
24794	PG0111	2017-09-11 16:20:00+03	2017-09-11 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24795	PG0111	2017-08-19 16:20:00+03	2017-08-19 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24796	PG0111	2017-08-12 16:20:00+03	2017-08-12 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-12 16:23:00+03	2017-08-12 17:43:00+03
24797	PG0111	2017-09-07 16:20:00+03	2017-09-07 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24798	PG0111	2017-09-04 16:20:00+03	2017-09-04 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24799	PG0111	2017-08-11 16:20:00+03	2017-08-11 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-11 16:24:00+03	2017-08-11 17:44:00+03
24800	PG0111	2017-07-21 16:20:00+03	2017-07-21 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-21 16:25:00+03	2017-07-21 17:45:00+03
24801	PG0111	2017-08-28 16:20:00+03	2017-08-28 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24802	PG0111	2017-09-10 16:20:00+03	2017-09-10 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24803	PG0111	2017-08-10 16:20:00+03	2017-08-10 17:40:00+03	TJM	UCT	Arrived	CR2	2017-08-10 16:23:00+03	2017-08-10 17:43:00+03
24804	PG0111	2017-07-31 16:20:00+03	2017-07-31 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-31 16:22:00+03	2017-07-31 17:43:00+03
24805	PG0111	2017-09-08 16:20:00+03	2017-09-08 17:40:00+03	TJM	UCT	Scheduled	CR2	\N	\N
24806	PG0111	2017-07-22 16:20:00+03	2017-07-22 17:40:00+03	TJM	UCT	Arrived	CR2	2017-07-22 16:23:00+03	2017-07-22 17:43:00+03
24807	PG0280	2017-08-07 07:45:00+03	2017-08-07 09:35:00+03	TJM	NNM	Arrived	CR2	2017-08-07 07:48:00+03	2017-08-07 09:37:00+03
24808	PG0280	2017-07-17 07:45:00+03	2017-07-17 09:35:00+03	TJM	NNM	Arrived	CR2	2017-07-17 07:45:00+03	2017-07-17 09:34:00+03
24809	PG0280	2017-07-31 07:45:00+03	2017-07-31 09:35:00+03	TJM	NNM	Arrived	CR2	2017-07-31 07:49:00+03	2017-07-31 09:40:00+03
24810	PG0280	2017-08-14 07:45:00+03	2017-08-14 09:35:00+03	TJM	NNM	Arrived	CR2	2017-08-14 07:47:00+03	2017-08-14 09:39:00+03
24811	PG0280	2017-09-11 07:45:00+03	2017-09-11 09:35:00+03	TJM	NNM	Cancelled	CR2	\N	\N
24812	PG0280	2017-07-24 07:45:00+03	2017-07-24 09:35:00+03	TJM	NNM	Arrived	CR2	2017-07-24 07:48:00+03	2017-07-24 09:38:00+03
24813	PG0280	2017-09-04 07:45:00+03	2017-09-04 09:35:00+03	TJM	NNM	Scheduled	CR2	\N	\N
24814	PG0280	2017-08-21 07:45:00+03	2017-08-21 09:35:00+03	TJM	NNM	Scheduled	CR2	\N	\N
24815	PG0280	2017-08-28 07:45:00+03	2017-08-28 09:35:00+03	TJM	NNM	Scheduled	CR2	\N	\N
24816	PG0014	2017-07-18 07:30:00+03	2017-07-18 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-18 07:34:00+03	2017-07-18 07:59:00+03
24817	PG0014	2017-08-24 07:30:00+03	2017-08-24 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24818	PG0014	2017-09-12 07:30:00+03	2017-09-12 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24819	PG0014	2017-08-30 07:30:00+03	2017-08-30 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24820	PG0014	2017-08-09 07:30:00+03	2017-08-09 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-09 07:35:00+03	2017-08-09 08:00:00+03
24821	PG0014	2017-08-16 07:30:00+03	2017-08-16 07:55:00+03	TJM	URJ	On Time	SU9	\N	\N
24822	PG0014	2017-08-26 07:30:00+03	2017-08-26 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24823	PG0014	2017-08-12 07:30:00+03	2017-08-12 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-12 07:31:00+03	2017-08-12 07:56:00+03
24824	PG0014	2017-09-04 07:30:00+03	2017-09-04 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24825	PG0014	2017-07-27 07:30:00+03	2017-07-27 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-27 07:33:00+03	2017-07-27 07:58:00+03
24826	PG0014	2017-09-13 07:30:00+03	2017-09-13 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24827	PG0014	2017-07-26 07:30:00+03	2017-07-26 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-26 07:30:00+03	2017-07-26 07:55:00+03
24828	PG0014	2017-08-03 07:30:00+03	2017-08-03 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-03 07:34:00+03	2017-08-03 07:59:00+03
24829	PG0014	2017-09-10 07:30:00+03	2017-09-10 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24830	PG0014	2017-08-23 07:30:00+03	2017-08-23 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24831	PG0014	2017-09-06 07:30:00+03	2017-09-06 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24832	PG0014	2017-08-21 07:30:00+03	2017-08-21 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24833	PG0014	2017-07-17 07:30:00+03	2017-07-17 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-17 07:34:00+03	2017-07-17 07:59:00+03
24834	PG0014	2017-08-20 07:30:00+03	2017-08-20 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24835	PG0014	2017-07-23 07:30:00+03	2017-07-23 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-23 07:33:00+03	2017-07-23 07:57:00+03
24836	PG0014	2017-07-16 07:30:00+03	2017-07-16 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-16 07:34:00+03	2017-07-16 07:59:00+03
24837	PG0014	2017-07-22 07:30:00+03	2017-07-22 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-22 07:31:00+03	2017-07-22 07:56:00+03
24838	PG0014	2017-08-25 07:30:00+03	2017-08-25 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24839	PG0014	2017-08-06 07:30:00+03	2017-08-06 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-06 07:37:00+03	2017-08-06 08:02:00+03
24840	PG0014	2017-08-15 07:30:00+03	2017-08-15 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-15 07:34:00+03	2017-08-15 07:59:00+03
24841	PG0014	2017-07-20 07:30:00+03	2017-07-20 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-20 07:31:00+03	2017-07-20 07:56:00+03
24842	PG0014	2017-08-19 07:30:00+03	2017-08-19 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24843	PG0014	2017-08-10 07:30:00+03	2017-08-10 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-10 07:32:00+03	2017-08-10 07:57:00+03
24844	PG0014	2017-07-30 07:30:00+03	2017-07-30 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-30 07:36:00+03	2017-07-30 08:02:00+03
24845	PG0014	2017-09-01 07:30:00+03	2017-09-01 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24846	PG0014	2017-09-14 07:30:00+03	2017-09-14 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24847	PG0014	2017-09-07 07:30:00+03	2017-09-07 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24848	PG0014	2017-09-03 07:30:00+03	2017-09-03 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24849	PG0014	2017-09-09 07:30:00+03	2017-09-09 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24850	PG0014	2017-08-04 07:30:00+03	2017-08-04 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-04 07:35:00+03	2017-08-04 08:00:00+03
24851	PG0014	2017-08-17 07:30:00+03	2017-08-17 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24852	PG0014	2017-08-13 07:30:00+03	2017-08-13 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-13 07:31:00+03	2017-08-13 07:56:00+03
24853	PG0014	2017-08-28 07:30:00+03	2017-08-28 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24854	PG0014	2017-07-19 07:30:00+03	2017-07-19 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-19 07:33:00+03	2017-07-19 07:58:00+03
24855	PG0014	2017-08-07 07:30:00+03	2017-08-07 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-07 07:34:00+03	2017-08-07 07:59:00+03
24856	PG0014	2017-08-02 07:30:00+03	2017-08-02 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-02 07:34:00+03	2017-08-02 07:59:00+03
24857	PG0014	2017-07-28 07:30:00+03	2017-07-28 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-28 07:32:00+03	2017-07-28 07:57:00+03
24858	PG0014	2017-07-25 07:30:00+03	2017-07-25 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-25 07:33:00+03	2017-07-25 07:58:00+03
24859	PG0014	2017-07-31 07:30:00+03	2017-07-31 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-31 10:37:00+03	2017-07-31 11:02:00+03
24860	PG0014	2017-09-08 07:30:00+03	2017-09-08 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24861	PG0014	2017-07-21 07:30:00+03	2017-07-21 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-21 07:31:00+03	2017-07-21 07:56:00+03
24862	PG0014	2017-08-22 07:30:00+03	2017-08-22 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24863	PG0014	2017-09-05 07:30:00+03	2017-09-05 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24864	PG0014	2017-09-02 07:30:00+03	2017-09-02 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24865	PG0014	2017-08-08 07:30:00+03	2017-08-08 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-08 07:34:00+03	2017-08-08 07:59:00+03
24866	PG0014	2017-08-31 07:30:00+03	2017-08-31 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24867	PG0014	2017-08-01 07:30:00+03	2017-08-01 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-01 07:37:00+03	2017-08-01 08:02:00+03
24868	PG0014	2017-08-27 07:30:00+03	2017-08-27 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24869	PG0014	2017-08-11 07:30:00+03	2017-08-11 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-11 07:31:00+03	2017-08-11 07:56:00+03
24870	PG0014	2017-09-11 07:30:00+03	2017-09-11 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24871	PG0014	2017-08-14 07:30:00+03	2017-08-14 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-14 07:33:00+03	2017-08-14 07:58:00+03
24872	PG0014	2017-07-24 07:30:00+03	2017-07-24 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-24 11:04:00+03	2017-07-24 11:29:00+03
24873	PG0014	2017-08-05 07:30:00+03	2017-08-05 07:55:00+03	TJM	URJ	Arrived	SU9	2017-08-05 07:34:00+03	2017-08-05 07:59:00+03
24874	PG0014	2017-08-29 07:30:00+03	2017-08-29 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24875	PG0014	2017-07-29 07:30:00+03	2017-07-29 07:55:00+03	TJM	URJ	Arrived	SU9	2017-07-29 07:34:00+03	2017-07-29 07:59:00+03
24876	PG0014	2017-08-18 07:30:00+03	2017-08-18 07:55:00+03	TJM	URJ	Scheduled	SU9	\N	\N
24877	PG0445	2017-09-05 17:15:00+03	2017-09-05 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24878	PG0445	2017-08-30 17:15:00+03	2017-08-30 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24879	PG0445	2017-09-10 17:15:00+03	2017-09-10 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24880	PG0445	2017-09-01 17:15:00+03	2017-09-01 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24881	PG0445	2017-07-29 17:15:00+03	2017-07-29 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-29 17:15:00+03	2017-07-29 18:46:00+03
24882	PG0445	2017-07-25 17:15:00+03	2017-07-25 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-25 17:21:00+03	2017-07-25 18:50:00+03
24883	PG0445	2017-07-19 17:15:00+03	2017-07-19 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-19 17:18:00+03	2017-07-19 18:49:00+03
24884	PG0445	2017-08-15 17:15:00+03	2017-08-15 18:45:00+03	TJM	OVS	Departed	CN1	2017-08-15 17:18:00+03	\N
24885	PG0445	2017-07-22 17:15:00+03	2017-07-22 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-22 17:16:00+03	2017-07-22 18:44:00+03
24886	PG0445	2017-08-29 17:15:00+03	2017-08-29 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24887	PG0445	2017-08-14 17:15:00+03	2017-08-14 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-14 17:17:00+03	2017-08-14 18:47:00+03
24888	PG0445	2017-08-26 17:15:00+03	2017-08-26 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24889	PG0445	2017-09-06 17:15:00+03	2017-09-06 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24890	PG0445	2017-09-09 17:15:00+03	2017-09-09 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24891	PG0445	2017-08-19 17:15:00+03	2017-08-19 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24892	PG0445	2017-09-13 17:15:00+03	2017-09-13 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24893	PG0445	2017-08-06 17:15:00+03	2017-08-06 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-06 17:16:00+03	2017-08-06 18:46:00+03
24894	PG0445	2017-07-30 17:15:00+03	2017-07-30 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-30 17:18:00+03	2017-07-30 18:48:00+03
24895	PG0445	2017-07-31 17:15:00+03	2017-07-31 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-31 17:15:00+03	2017-07-31 18:45:00+03
24896	PG0445	2017-08-13 17:15:00+03	2017-08-13 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-13 17:18:00+03	2017-08-13 18:48:00+03
24897	PG0445	2017-07-21 17:15:00+03	2017-07-21 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-21 17:21:00+03	2017-07-21 18:53:00+03
24898	PG0445	2017-08-09 17:15:00+03	2017-08-09 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-09 17:18:00+03	2017-08-09 18:48:00+03
24899	PG0445	2017-08-31 17:15:00+03	2017-08-31 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24900	PG0445	2017-08-28 17:15:00+03	2017-08-28 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24901	PG0445	2017-08-11 17:15:00+03	2017-08-11 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-11 17:16:00+03	2017-08-11 18:46:00+03
24902	PG0445	2017-07-26 17:15:00+03	2017-07-26 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-26 17:16:00+03	2017-07-26 18:47:00+03
24903	PG0445	2017-08-25 17:15:00+03	2017-08-25 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24904	PG0445	2017-09-11 17:15:00+03	2017-09-11 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24905	PG0445	2017-07-16 17:15:00+03	2017-07-16 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-16 17:17:00+03	2017-07-16 18:48:00+03
24906	PG0445	2017-08-07 17:15:00+03	2017-08-07 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-07 17:18:00+03	2017-08-07 18:47:00+03
24907	PG0445	2017-07-17 17:15:00+03	2017-07-17 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-17 17:21:00+03	2017-07-17 18:51:00+03
24908	PG0445	2017-09-04 17:15:00+03	2017-09-04 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24909	PG0445	2017-08-05 17:15:00+03	2017-08-05 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-05 17:16:00+03	2017-08-05 18:47:00+03
24910	PG0445	2017-07-20 17:15:00+03	2017-07-20 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-20 17:17:00+03	2017-07-20 18:47:00+03
24911	PG0445	2017-08-21 17:15:00+03	2017-08-21 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24912	PG0445	2017-07-23 17:15:00+03	2017-07-23 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-23 17:21:00+03	2017-07-23 18:51:00+03
24913	PG0445	2017-09-12 17:15:00+03	2017-09-12 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24914	PG0445	2017-09-02 17:15:00+03	2017-09-02 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24915	PG0445	2017-08-12 17:15:00+03	2017-08-12 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-12 17:18:00+03	2017-08-12 18:50:00+03
24916	PG0445	2017-08-03 17:15:00+03	2017-08-03 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-03 17:17:00+03	2017-08-03 18:47:00+03
24917	PG0445	2017-08-20 17:15:00+03	2017-08-20 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24918	PG0445	2017-08-10 17:15:00+03	2017-08-10 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-10 17:18:00+03	2017-08-10 18:49:00+03
24919	PG0445	2017-09-07 17:15:00+03	2017-09-07 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24920	PG0445	2017-08-23 17:15:00+03	2017-08-23 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24921	PG0445	2017-08-27 17:15:00+03	2017-08-27 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24922	PG0445	2017-08-02 17:15:00+03	2017-08-02 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-02 17:16:00+03	2017-08-02 18:45:00+03
24923	PG0445	2017-08-22 17:15:00+03	2017-08-22 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24924	PG0445	2017-08-01 17:15:00+03	2017-08-01 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-01 17:20:00+03	2017-08-01 18:50:00+03
24925	PG0445	2017-07-27 17:15:00+03	2017-07-27 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-27 17:19:00+03	2017-07-27 18:50:00+03
24926	PG0445	2017-09-14 17:15:00+03	2017-09-14 18:45:00+03	TJM	OVS	Cancelled	CN1	\N	\N
24927	PG0445	2017-07-24 17:15:00+03	2017-07-24 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-24 17:17:00+03	2017-07-24 18:49:00+03
24928	PG0445	2017-08-08 17:15:00+03	2017-08-08 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-08 17:17:00+03	2017-08-08 18:47:00+03
24929	PG0445	2017-09-08 17:15:00+03	2017-09-08 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24930	PG0445	2017-08-24 17:15:00+03	2017-08-24 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24931	PG0445	2017-07-28 17:15:00+03	2017-07-28 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-28 17:17:00+03	2017-07-28 18:47:00+03
24932	PG0445	2017-08-16 17:15:00+03	2017-08-16 18:45:00+03	TJM	OVS	On Time	CN1	\N	\N
24933	PG0445	2017-07-18 17:15:00+03	2017-07-18 18:45:00+03	TJM	OVS	Arrived	CN1	2017-07-18 17:17:00+03	2017-07-18 18:48:00+03
24934	PG0445	2017-08-17 17:15:00+03	2017-08-17 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24935	PG0445	2017-08-04 17:15:00+03	2017-08-04 18:45:00+03	TJM	OVS	Arrived	CN1	2017-08-04 17:19:00+03	2017-08-04 18:51:00+03
24936	PG0445	2017-08-18 17:15:00+03	2017-08-18 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24937	PG0445	2017-09-03 17:15:00+03	2017-09-03 18:45:00+03	TJM	OVS	Scheduled	CN1	\N	\N
24938	PG0578	2017-07-29 12:50:00+03	2017-07-29 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-29 12:52:00+03	2017-07-29 15:11:00+03
24939	PG0578	2017-07-27 12:50:00+03	2017-07-27 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-27 12:52:00+03	2017-07-27 15:10:00+03
24940	PG0578	2017-08-21 12:50:00+03	2017-08-21 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24941	PG0578	2017-08-05 12:50:00+03	2017-08-05 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-05 12:52:00+03	2017-08-05 15:11:00+03
24942	PG0578	2017-09-07 12:50:00+03	2017-09-07 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24943	PG0578	2017-09-09 12:50:00+03	2017-09-09 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24944	PG0578	2017-09-14 12:50:00+03	2017-09-14 15:10:00+03	TJM	EYK	Cancelled	CN1	\N	\N
24945	PG0578	2017-07-22 12:50:00+03	2017-07-22 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-22 12:53:00+03	2017-07-22 15:12:00+03
24946	PG0578	2017-08-28 12:50:00+03	2017-08-28 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24947	PG0578	2017-08-03 12:50:00+03	2017-08-03 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-03 12:53:00+03	2017-08-03 15:12:00+03
24948	PG0578	2017-08-12 12:50:00+03	2017-08-12 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-12 12:55:00+03	2017-08-12 15:19:00+03
24949	PG0578	2017-07-24 12:50:00+03	2017-07-24 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-24 12:54:00+03	2017-07-24 15:15:00+03
24950	PG0578	2017-08-19 12:50:00+03	2017-08-19 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24951	PG0578	2017-07-20 12:50:00+03	2017-07-20 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-20 12:55:00+03	2017-07-20 15:15:00+03
24952	PG0578	2017-08-31 12:50:00+03	2017-08-31 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24953	PG0578	2017-08-24 12:50:00+03	2017-08-24 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24954	PG0578	2017-09-02 12:50:00+03	2017-09-02 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24955	PG0578	2017-08-07 12:50:00+03	2017-08-07 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-07 12:53:00+03	2017-08-07 15:12:00+03
24956	PG0578	2017-08-17 12:50:00+03	2017-08-17 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24957	PG0578	2017-09-11 12:50:00+03	2017-09-11 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24958	PG0578	2017-09-04 12:50:00+03	2017-09-04 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24959	PG0578	2017-08-10 12:50:00+03	2017-08-10 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-10 12:51:00+03	2017-08-10 15:13:00+03
24960	PG0578	2017-08-26 12:50:00+03	2017-08-26 15:10:00+03	TJM	EYK	Scheduled	CN1	\N	\N
24961	PG0578	2017-07-31 12:50:00+03	2017-07-31 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-31 12:55:00+03	2017-07-31 15:16:00+03
24962	PG0578	2017-07-17 12:50:00+03	2017-07-17 15:10:00+03	TJM	EYK	Arrived	CN1	2017-07-17 12:53:00+03	2017-07-17 15:14:00+03
24963	PG0578	2017-08-14 12:50:00+03	2017-08-14 15:10:00+03	TJM	EYK	Arrived	CN1	2017-08-14 12:57:00+03	2017-08-14 15:19:00+03
24964	PG0154	2017-09-11 12:40:00+03	2017-09-11 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24965	PG0154	2017-07-19 12:40:00+03	2017-07-19 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-19 12:43:00+03	2017-07-19 14:59:00+03
24966	PG0154	2017-08-26 12:40:00+03	2017-08-26 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24967	PG0154	2017-09-13 12:40:00+03	2017-09-13 14:55:00+03	TJM	ARH	Cancelled	CR2	\N	\N
24968	PG0154	2017-09-04 12:40:00+03	2017-09-04 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24969	PG0154	2017-08-09 12:40:00+03	2017-08-09 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-09 12:42:00+03	2017-08-09 14:56:00+03
24970	PG0154	2017-09-02 12:40:00+03	2017-09-02 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24971	PG0154	2017-07-24 12:40:00+03	2017-07-24 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-24 12:41:00+03	2017-07-24 14:55:00+03
24972	PG0154	2017-08-14 12:40:00+03	2017-08-14 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-14 12:42:00+03	2017-08-14 14:57:00+03
24973	PG0154	2017-08-07 12:40:00+03	2017-08-07 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-07 12:50:00+03	2017-08-07 15:05:00+03
24974	PG0154	2017-07-17 12:40:00+03	2017-07-17 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-17 12:44:00+03	2017-07-17 14:58:00+03
24975	PG0154	2017-07-22 12:40:00+03	2017-07-22 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-22 12:43:00+03	2017-07-22 14:57:00+03
24976	PG0154	2017-08-12 12:40:00+03	2017-08-12 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-12 12:43:00+03	2017-08-12 15:00:00+03
24977	PG0154	2017-08-23 12:40:00+03	2017-08-23 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24978	PG0154	2017-08-19 12:40:00+03	2017-08-19 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24979	PG0154	2017-07-29 12:40:00+03	2017-07-29 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-29 12:42:00+03	2017-07-29 14:56:00+03
24980	PG0154	2017-07-31 12:40:00+03	2017-07-31 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-31 15:20:00+03	2017-07-31 17:35:00+03
24981	PG0154	2017-08-16 12:40:00+03	2017-08-16 14:55:00+03	TJM	ARH	On Time	CR2	\N	\N
24982	PG0154	2017-08-05 12:40:00+03	2017-08-05 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-05 12:46:00+03	2017-08-05 15:01:00+03
24983	PG0154	2017-08-28 12:40:00+03	2017-08-28 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24984	PG0154	2017-09-09 12:40:00+03	2017-09-09 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24985	PG0154	2017-09-06 12:40:00+03	2017-09-06 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24986	PG0154	2017-07-26 12:40:00+03	2017-07-26 14:55:00+03	TJM	ARH	Arrived	CR2	2017-07-26 12:43:00+03	2017-07-26 14:58:00+03
24987	PG0154	2017-08-21 12:40:00+03	2017-08-21 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24988	PG0154	2017-08-30 12:40:00+03	2017-08-30 14:55:00+03	TJM	ARH	Scheduled	CR2	\N	\N
24989	PG0154	2017-08-02 12:40:00+03	2017-08-02 14:55:00+03	TJM	ARH	Arrived	CR2	2017-08-02 12:41:00+03	2017-08-02 14:56:00+03
24990	PG0044	2017-07-20 08:20:00+03	2017-07-20 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-20 11:53:00+03	2017-07-20 13:18:00+03
24991	PG0044	2017-09-13 08:20:00+03	2017-09-13 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
24992	PG0044	2017-08-23 08:20:00+03	2017-08-23 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
24993	PG0044	2017-07-21 08:20:00+03	2017-07-21 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-21 08:23:00+03	2017-07-21 09:48:00+03
24994	PG0044	2017-07-29 08:20:00+03	2017-07-29 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-29 08:21:00+03	2017-07-29 09:45:00+03
24995	PG0044	2017-09-06 08:20:00+03	2017-09-06 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
24996	PG0044	2017-09-01 08:20:00+03	2017-09-01 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
24997	PG0044	2017-07-31 08:20:00+03	2017-07-31 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-31 08:22:00+03	2017-07-31 09:46:00+03
24998	PG0044	2017-08-12 08:20:00+03	2017-08-12 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-12 08:22:00+03	2017-08-12 09:47:00+03
24999	PG0044	2017-09-10 08:20:00+03	2017-09-10 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25000	PG0044	2017-08-07 08:20:00+03	2017-08-07 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-07 08:23:00+03	2017-08-07 09:47:00+03
25001	PG0044	2017-08-31 08:20:00+03	2017-08-31 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25002	PG0044	2017-08-30 08:20:00+03	2017-08-30 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25003	PG0044	2017-07-23 08:20:00+03	2017-07-23 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-23 08:21:00+03	2017-07-23 09:48:00+03
25004	PG0044	2017-09-02 08:20:00+03	2017-09-02 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25005	PG0044	2017-09-08 08:20:00+03	2017-09-08 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25006	PG0044	2017-08-11 08:20:00+03	2017-08-11 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-11 08:20:00+03	2017-08-11 09:45:00+03
25007	PG0044	2017-09-11 08:20:00+03	2017-09-11 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25008	PG0044	2017-08-21 08:20:00+03	2017-08-21 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25009	PG0044	2017-09-05 08:20:00+03	2017-09-05 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25010	PG0044	2017-08-09 08:20:00+03	2017-08-09 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-09 08:26:00+03	2017-08-09 09:50:00+03
25011	PG0044	2017-08-18 08:20:00+03	2017-08-18 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25012	PG0044	2017-08-01 08:20:00+03	2017-08-01 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-01 08:23:00+03	2017-08-01 09:48:00+03
25013	PG0044	2017-09-04 08:20:00+03	2017-09-04 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25014	PG0044	2017-08-10 08:20:00+03	2017-08-10 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-10 08:22:00+03	2017-08-10 09:47:00+03
25015	PG0044	2017-07-30 08:20:00+03	2017-07-30 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-30 08:22:00+03	2017-07-30 09:47:00+03
25016	PG0044	2017-07-17 08:20:00+03	2017-07-17 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-17 08:24:00+03	2017-07-17 09:49:00+03
25017	PG0044	2017-07-27 08:20:00+03	2017-07-27 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-27 08:21:00+03	2017-07-27 09:46:00+03
25018	PG0044	2017-08-14 08:20:00+03	2017-08-14 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-14 08:22:00+03	2017-08-14 09:48:00+03
25019	PG0044	2017-08-04 08:20:00+03	2017-08-04 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-04 08:24:00+03	2017-08-04 09:49:00+03
25020	PG0044	2017-08-05 08:20:00+03	2017-08-05 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-05 08:24:00+03	2017-08-05 09:48:00+03
25021	PG0044	2017-08-20 08:20:00+03	2017-08-20 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25022	PG0044	2017-08-03 08:20:00+03	2017-08-03 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-03 08:23:00+03	2017-08-03 09:47:00+03
25023	PG0044	2017-08-28 08:20:00+03	2017-08-28 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25024	PG0044	2017-08-25 08:20:00+03	2017-08-25 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25025	PG0044	2017-09-07 08:20:00+03	2017-09-07 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25026	PG0044	2017-07-26 08:20:00+03	2017-07-26 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-26 08:24:00+03	2017-07-26 09:50:00+03
25027	PG0044	2017-07-19 08:20:00+03	2017-07-19 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-19 08:22:00+03	2017-07-19 09:47:00+03
25028	PG0044	2017-08-24 08:20:00+03	2017-08-24 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25029	PG0044	2017-07-16 08:20:00+03	2017-07-16 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-16 08:24:00+03	2017-07-16 09:49:00+03
25030	PG0044	2017-09-14 08:20:00+03	2017-09-14 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25031	PG0044	2017-08-26 08:20:00+03	2017-08-26 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25032	PG0044	2017-08-16 08:20:00+03	2017-08-16 09:45:00+03	IJK	SVO	On Time	CR2	\N	\N
25033	PG0044	2017-07-28 08:20:00+03	2017-07-28 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-28 08:23:00+03	2017-07-28 09:48:00+03
25034	PG0044	2017-07-25 08:20:00+03	2017-07-25 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-25 08:22:00+03	2017-07-25 09:46:00+03
25035	PG0044	2017-07-24 08:20:00+03	2017-07-24 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-24 08:25:00+03	2017-07-24 09:49:00+03
25036	PG0044	2017-07-18 08:20:00+03	2017-07-18 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-18 08:20:00+03	2017-07-18 09:45:00+03
25037	PG0044	2017-09-09 08:20:00+03	2017-09-09 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25038	PG0044	2017-08-29 08:20:00+03	2017-08-29 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25039	PG0044	2017-08-06 08:20:00+03	2017-08-06 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-06 08:21:00+03	2017-08-06 09:46:00+03
25040	PG0044	2017-08-13 08:20:00+03	2017-08-13 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-13 08:24:00+03	2017-08-13 09:49:00+03
25041	PG0044	2017-09-03 08:20:00+03	2017-09-03 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25042	PG0044	2017-08-22 08:20:00+03	2017-08-22 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25043	PG0044	2017-08-02 08:20:00+03	2017-08-02 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-02 08:23:00+03	2017-08-02 09:47:00+03
25044	PG0044	2017-08-27 08:20:00+03	2017-08-27 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25045	PG0044	2017-08-15 08:20:00+03	2017-08-15 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-15 08:23:00+03	2017-08-15 09:48:00+03
25046	PG0044	2017-07-22 08:20:00+03	2017-07-22 09:45:00+03	IJK	SVO	Arrived	CR2	2017-07-22 08:20:00+03	2017-07-22 09:45:00+03
25047	PG0044	2017-09-12 08:20:00+03	2017-09-12 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25048	PG0044	2017-08-17 08:20:00+03	2017-08-17 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25049	PG0044	2017-08-19 08:20:00+03	2017-08-19 09:45:00+03	IJK	SVO	Scheduled	CR2	\N	\N
25050	PG0044	2017-08-08 08:20:00+03	2017-08-08 09:45:00+03	IJK	SVO	Arrived	CR2	2017-08-08 08:26:00+03	2017-08-08 09:51:00+03
25051	PG0117	2017-08-17 09:05:00+03	2017-08-17 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25052	PG0117	2017-07-29 09:05:00+03	2017-07-29 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-29 09:07:00+03	2017-07-29 12:59:00+03
25053	PG0117	2017-08-10 09:05:00+03	2017-08-10 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-10 09:07:00+03	2017-08-10 13:01:00+03
25054	PG0117	2017-08-19 09:05:00+03	2017-08-19 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25055	PG0117	2017-08-14 09:05:00+03	2017-08-14 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-14 09:07:00+03	2017-08-14 12:58:00+03
25056	PG0117	2017-09-14 09:05:00+03	2017-09-14 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25057	PG0117	2017-08-07 09:05:00+03	2017-08-07 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-07 09:05:00+03	2017-08-07 12:59:00+03
25058	PG0117	2017-08-03 09:05:00+03	2017-08-03 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-03 09:07:00+03	2017-08-03 13:07:00+03
25059	PG0117	2017-07-27 09:05:00+03	2017-07-27 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-27 09:05:00+03	2017-07-27 13:00:00+03
25060	PG0117	2017-09-04 09:05:00+03	2017-09-04 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25061	PG0117	2017-08-24 09:05:00+03	2017-08-24 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25062	PG0117	2017-09-11 09:05:00+03	2017-09-11 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25063	PG0117	2017-09-09 09:05:00+03	2017-09-09 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25064	PG0117	2017-07-22 09:05:00+03	2017-07-22 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-22 09:08:00+03	2017-07-22 13:06:00+03
25065	PG0117	2017-07-31 09:05:00+03	2017-07-31 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-31 09:06:00+03	2017-07-31 12:59:00+03
25066	PG0117	2017-08-28 09:05:00+03	2017-08-28 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25067	PG0117	2017-08-21 09:05:00+03	2017-08-21 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25068	PG0117	2017-07-24 09:05:00+03	2017-07-24 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-24 09:08:00+03	2017-07-24 13:03:00+03
25069	PG0117	2017-09-07 09:05:00+03	2017-09-07 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25070	PG0117	2017-08-05 09:05:00+03	2017-08-05 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-05 09:06:00+03	2017-08-05 13:00:00+03
25071	PG0117	2017-09-02 09:05:00+03	2017-09-02 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25072	PG0117	2017-08-31 09:05:00+03	2017-08-31 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25073	PG0117	2017-07-17 09:05:00+03	2017-07-17 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-17 09:05:00+03	2017-07-17 13:04:00+03
25074	PG0117	2017-08-12 09:05:00+03	2017-08-12 13:00:00+03	BAX	DME	Arrived	SU9	2017-08-12 09:07:00+03	2017-08-12 13:00:00+03
25075	PG0117	2017-07-20 09:05:00+03	2017-07-20 13:00:00+03	BAX	DME	Arrived	SU9	2017-07-20 09:07:00+03	2017-07-20 13:01:00+03
25076	PG0117	2017-08-26 09:05:00+03	2017-08-26 13:00:00+03	BAX	DME	Scheduled	SU9	\N	\N
25077	PG0540	2017-09-10 13:05:00+03	2017-09-10 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25078	PG0540	2017-08-25 13:05:00+03	2017-08-25 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25079	PG0540	2017-08-29 13:05:00+03	2017-08-29 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25080	PG0540	2017-09-08 13:05:00+03	2017-09-08 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25081	PG0540	2017-08-22 13:05:00+03	2017-08-22 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25082	PG0540	2017-07-25 13:05:00+03	2017-07-25 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-25 13:07:00+03	2017-07-25 16:56:00+03
25083	PG0540	2017-07-21 13:05:00+03	2017-07-21 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-21 13:08:00+03	2017-07-21 17:01:00+03
25084	PG0540	2017-08-01 13:05:00+03	2017-08-01 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-01 13:07:00+03	2017-08-01 17:02:00+03
25085	PG0540	2017-09-01 13:05:00+03	2017-09-01 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25086	PG0540	2017-09-05 13:05:00+03	2017-09-05 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25087	PG0540	2017-07-30 13:05:00+03	2017-07-30 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-30 13:08:00+03	2017-07-30 17:01:00+03
25088	PG0540	2017-09-12 13:05:00+03	2017-09-12 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25089	PG0540	2017-07-23 13:05:00+03	2017-07-23 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-23 13:10:00+03	2017-07-23 17:07:00+03
25090	PG0540	2017-08-11 13:05:00+03	2017-08-11 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-11 13:06:00+03	2017-08-11 16:57:00+03
25091	PG0540	2017-08-15 13:05:00+03	2017-08-15 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-15 13:10:00+03	2017-08-15 17:02:00+03
25092	PG0540	2017-07-18 13:05:00+03	2017-07-18 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-18 13:09:00+03	2017-07-18 17:08:00+03
25093	PG0540	2017-08-06 13:05:00+03	2017-08-06 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-06 13:07:00+03	2017-08-06 17:04:00+03
25094	PG0540	2017-08-13 13:05:00+03	2017-08-13 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-13 13:12:00+03	2017-08-13 17:04:00+03
25095	PG0540	2017-08-18 13:05:00+03	2017-08-18 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25096	PG0540	2017-07-16 13:05:00+03	2017-07-16 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-16 13:07:00+03	2017-07-16 17:05:00+03
25097	PG0540	2017-08-20 13:05:00+03	2017-08-20 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25098	PG0540	2017-08-08 13:05:00+03	2017-08-08 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-08 13:07:00+03	2017-08-08 16:58:00+03
25099	PG0540	2017-07-28 13:05:00+03	2017-07-28 17:00:00+03	BAX	VKO	Arrived	SU9	2017-07-28 13:09:00+03	2017-07-28 17:03:00+03
25100	PG0540	2017-08-27 13:05:00+03	2017-08-27 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25101	PG0540	2017-09-03 13:05:00+03	2017-09-03 17:00:00+03	BAX	VKO	Scheduled	SU9	\N	\N
25102	PG0540	2017-08-04 13:05:00+03	2017-08-04 17:00:00+03	BAX	VKO	Arrived	SU9	2017-08-04 13:06:00+03	2017-08-04 17:05:00+03
25103	PG0453	2017-08-02 15:25:00+03	2017-08-02 19:20:00+03	BAX	SVO	Arrived	SU9	2017-08-02 15:31:00+03	2017-08-02 19:26:00+03
25104	PG0453	2017-08-09 15:25:00+03	2017-08-09 19:20:00+03	BAX	SVO	Arrived	SU9	2017-08-09 15:30:00+03	2017-08-09 19:21:00+03
25105	PG0453	2017-08-16 15:25:00+03	2017-08-16 19:20:00+03	BAX	SVO	On Time	SU9	\N	\N
25106	PG0453	2017-08-30 15:25:00+03	2017-08-30 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25107	PG0453	2017-08-23 15:25:00+03	2017-08-23 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25108	PG0453	2017-07-19 15:25:00+03	2017-07-19 19:20:00+03	BAX	SVO	Arrived	SU9	2017-07-19 15:30:00+03	2017-07-19 19:28:00+03
25109	PG0453	2017-08-26 15:25:00+03	2017-08-26 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25110	PG0453	2017-09-06 15:25:00+03	2017-09-06 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25111	PG0453	2017-07-29 15:25:00+03	2017-07-29 19:20:00+03	BAX	SVO	Arrived	SU9	2017-07-29 15:29:00+03	2017-07-29 19:26:00+03
25112	PG0453	2017-09-13 15:25:00+03	2017-09-13 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25113	PG0453	2017-08-05 15:25:00+03	2017-08-05 19:20:00+03	BAX	SVO	Arrived	SU9	2017-08-05 15:28:00+03	2017-08-05 19:25:00+03
25114	PG0453	2017-08-19 15:25:00+03	2017-08-19 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25115	PG0453	2017-07-22 15:25:00+03	2017-07-22 19:20:00+03	BAX	SVO	Arrived	SU9	2017-07-22 15:32:00+03	2017-07-22 19:26:00+03
25116	PG0453	2017-08-12 15:25:00+03	2017-08-12 19:20:00+03	BAX	SVO	Arrived	SU9	2017-08-12 15:28:00+03	2017-08-12 19:26:00+03
25117	PG0453	2017-09-02 15:25:00+03	2017-09-02 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25118	PG0453	2017-07-26 15:25:00+03	2017-07-26 19:20:00+03	BAX	SVO	Arrived	SU9	2017-07-26 15:28:00+03	2017-07-26 19:25:00+03
25119	PG0453	2017-09-09 15:25:00+03	2017-09-09 19:20:00+03	BAX	SVO	Scheduled	SU9	\N	\N
25120	PG0654	2017-08-27 05:00:00+03	2017-08-27 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25121	PG0654	2017-08-26 05:00:00+03	2017-08-26 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25122	PG0654	2017-09-10 05:00:00+03	2017-09-10 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25123	PG0654	2017-09-12 05:00:00+03	2017-09-12 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25124	PG0654	2017-07-26 05:00:00+03	2017-07-26 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-26 05:02:00+03	2017-07-26 07:10:00+03
25125	PG0654	2017-08-10 05:00:00+03	2017-08-10 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-10 05:04:00+03	2017-08-10 07:15:00+03
25126	PG0654	2017-09-05 05:00:00+03	2017-09-05 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25127	PG0654	2017-08-23 05:00:00+03	2017-08-23 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25128	PG0654	2017-08-08 05:00:00+03	2017-08-08 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-08 05:04:00+03	2017-08-08 07:12:00+03
25129	PG0654	2017-08-29 05:00:00+03	2017-08-29 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25130	PG0654	2017-09-09 05:00:00+03	2017-09-09 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25131	PG0654	2017-08-15 05:00:00+03	2017-08-15 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-15 05:04:00+03	2017-08-15 07:15:00+03
25132	PG0654	2017-08-02 05:00:00+03	2017-08-02 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-02 05:03:00+03	2017-08-02 07:13:00+03
25133	PG0654	2017-07-28 05:00:00+03	2017-07-28 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-28 05:00:00+03	2017-07-28 07:11:00+03
25134	PG0654	2017-07-25 05:00:00+03	2017-07-25 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-25 05:04:00+03	2017-07-25 07:13:00+03
25135	PG0654	2017-09-11 05:00:00+03	2017-09-11 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25136	PG0654	2017-08-13 05:00:00+03	2017-08-13 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-13 05:02:00+03	2017-08-13 07:14:00+03
25137	PG0654	2017-09-13 05:00:00+03	2017-09-13 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25138	PG0654	2017-08-17 05:00:00+03	2017-08-17 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25139	PG0654	2017-08-11 05:00:00+03	2017-08-11 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-11 05:01:00+03	2017-08-11 07:14:00+03
25140	PG0654	2017-08-25 05:00:00+03	2017-08-25 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25141	PG0654	2017-07-22 05:00:00+03	2017-07-22 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-22 07:42:00+03	2017-07-22 09:52:00+03
25142	PG0654	2017-08-05 05:00:00+03	2017-08-05 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-05 05:04:00+03	2017-08-05 07:15:00+03
25143	PG0654	2017-08-22 05:00:00+03	2017-08-22 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25144	PG0654	2017-09-02 05:00:00+03	2017-09-02 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25145	PG0654	2017-07-18 05:00:00+03	2017-07-18 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-18 08:29:00+03	2017-07-18 10:41:00+03
25146	PG0654	2017-08-09 05:00:00+03	2017-08-09 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-09 05:03:00+03	2017-08-09 07:13:00+03
25147	PG0654	2017-08-20 05:00:00+03	2017-08-20 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25148	PG0654	2017-08-03 05:00:00+03	2017-08-03 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-03 05:02:00+03	2017-08-03 07:12:00+03
25149	PG0654	2017-08-16 05:00:00+03	2017-08-16 07:10:00+03	BAX	KJA	On Time	CN1	\N	\N
25150	PG0654	2017-08-14 05:00:00+03	2017-08-14 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-14 05:04:00+03	2017-08-14 07:14:00+03
25151	PG0654	2017-08-12 05:00:00+03	2017-08-12 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-12 05:00:00+03	2017-08-12 07:09:00+03
25152	PG0654	2017-08-06 05:00:00+03	2017-08-06 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-06 05:05:00+03	2017-08-06 07:13:00+03
25153	PG0654	2017-07-19 05:00:00+03	2017-07-19 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-19 05:05:00+03	2017-07-19 07:16:00+03
25154	PG0654	2017-07-30 05:00:00+03	2017-07-30 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-30 05:01:00+03	2017-07-30 07:11:00+03
25155	PG0654	2017-08-19 05:00:00+03	2017-08-19 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25156	PG0654	2017-08-18 05:00:00+03	2017-08-18 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25157	PG0654	2017-07-29 05:00:00+03	2017-07-29 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-29 05:03:00+03	2017-07-29 07:12:00+03
25158	PG0654	2017-07-27 05:00:00+03	2017-07-27 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-27 05:03:00+03	2017-07-27 07:12:00+03
25159	PG0654	2017-08-04 05:00:00+03	2017-08-04 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-04 05:05:00+03	2017-08-04 07:18:00+03
25160	PG0654	2017-08-24 05:00:00+03	2017-08-24 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25161	PG0654	2017-07-23 05:00:00+03	2017-07-23 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-23 05:00:00+03	2017-07-23 07:10:00+03
25162	PG0654	2017-07-21 05:00:00+03	2017-07-21 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-21 05:03:00+03	2017-07-21 07:13:00+03
25163	PG0654	2017-09-07 05:00:00+03	2017-09-07 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25164	PG0654	2017-09-08 05:00:00+03	2017-09-08 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25165	PG0654	2017-08-21 05:00:00+03	2017-08-21 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25166	PG0654	2017-07-16 05:00:00+03	2017-07-16 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-16 05:02:00+03	2017-07-16 07:13:00+03
25167	PG0654	2017-07-20 05:00:00+03	2017-07-20 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-20 05:02:00+03	2017-07-20 07:14:00+03
25168	PG0654	2017-08-28 05:00:00+03	2017-08-28 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25169	PG0654	2017-09-06 05:00:00+03	2017-09-06 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25170	PG0654	2017-08-01 05:00:00+03	2017-08-01 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-01 05:02:00+03	2017-08-01 07:13:00+03
25171	PG0654	2017-08-30 05:00:00+03	2017-08-30 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25172	PG0654	2017-09-14 05:00:00+03	2017-09-14 07:10:00+03	BAX	KJA	Cancelled	CN1	\N	\N
25173	PG0654	2017-09-03 05:00:00+03	2017-09-03 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25174	PG0654	2017-07-24 05:00:00+03	2017-07-24 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-24 05:04:00+03	2017-07-24 07:17:00+03
25175	PG0654	2017-07-31 05:00:00+03	2017-07-31 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-31 05:01:00+03	2017-07-31 07:13:00+03
25176	PG0654	2017-08-31 05:00:00+03	2017-08-31 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25177	PG0654	2017-08-07 05:00:00+03	2017-08-07 07:10:00+03	BAX	KJA	Arrived	CN1	2017-08-07 05:00:00+03	2017-08-07 07:11:00+03
25178	PG0654	2017-09-04 05:00:00+03	2017-09-04 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25179	PG0654	2017-07-17 05:00:00+03	2017-07-17 07:10:00+03	BAX	KJA	Arrived	CN1	2017-07-17 05:01:00+03	2017-07-17 07:10:00+03
25180	PG0654	2017-09-01 05:00:00+03	2017-09-01 07:10:00+03	BAX	KJA	Scheduled	CN1	\N	\N
25181	PG0171	2017-08-27 05:35:00+03	2017-08-27 09:25:00+03	BAX	YKS	Scheduled	SU9	\N	\N
25182	PG0171	2017-09-03 05:35:00+03	2017-09-03 09:25:00+03	BAX	YKS	Scheduled	SU9	\N	\N
25183	PG0171	2017-08-20 05:35:00+03	2017-08-20 09:25:00+03	BAX	YKS	Scheduled	SU9	\N	\N
25184	PG0171	2017-08-13 05:35:00+03	2017-08-13 09:25:00+03	BAX	YKS	Arrived	SU9	2017-08-13 05:35:00+03	2017-08-13 09:25:00+03
25185	PG0171	2017-07-23 05:35:00+03	2017-07-23 09:25:00+03	BAX	YKS	Arrived	SU9	2017-07-23 05:40:00+03	2017-07-23 09:32:00+03
25186	PG0171	2017-09-10 05:35:00+03	2017-09-10 09:25:00+03	BAX	YKS	Scheduled	SU9	\N	\N
25187	PG0171	2017-07-16 05:35:00+03	2017-07-16 09:25:00+03	BAX	YKS	Arrived	SU9	2017-07-16 05:36:00+03	2017-07-16 09:25:00+03
25188	PG0171	2017-08-06 05:35:00+03	2017-08-06 09:25:00+03	BAX	YKS	Arrived	SU9	2017-08-06 05:39:00+03	2017-08-06 09:29:00+03
25189	PG0171	2017-07-30 05:35:00+03	2017-07-30 09:25:00+03	BAX	YKS	Arrived	SU9	2017-07-30 05:39:00+03	2017-07-30 09:28:00+03
25190	PG0595	2017-07-22 08:35:00+03	2017-07-22 12:20:00+03	BAX	ASF	Arrived	CR2	2017-07-22 08:40:00+03	2017-07-22 12:24:00+03
25191	PG0595	2017-08-09 08:35:00+03	2017-08-09 12:20:00+03	BAX	ASF	Arrived	CR2	2017-08-09 08:37:00+03	2017-08-09 12:21:00+03
25192	PG0595	2017-07-19 08:35:00+03	2017-07-19 12:20:00+03	BAX	ASF	Arrived	CR2	2017-07-19 08:41:00+03	2017-07-19 12:26:00+03
25193	PG0595	2017-08-16 08:35:00+03	2017-08-16 12:20:00+03	BAX	ASF	Delayed	CR2	\N	\N
25194	PG0595	2017-08-23 08:35:00+03	2017-08-23 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25195	PG0595	2017-07-29 08:35:00+03	2017-07-29 12:20:00+03	BAX	ASF	Arrived	CR2	2017-07-29 08:37:00+03	2017-07-29 12:21:00+03
25196	PG0595	2017-08-05 08:35:00+03	2017-08-05 12:20:00+03	BAX	ASF	Arrived	CR2	2017-08-05 08:40:00+03	2017-08-05 12:25:00+03
25197	PG0595	2017-08-26 08:35:00+03	2017-08-26 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25198	PG0595	2017-09-09 08:35:00+03	2017-09-09 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25199	PG0595	2017-07-26 08:35:00+03	2017-07-26 12:20:00+03	BAX	ASF	Arrived	CR2	2017-07-26 12:20:00+03	2017-07-26 16:09:00+03
25200	PG0595	2017-08-12 08:35:00+03	2017-08-12 12:20:00+03	BAX	ASF	Arrived	CR2	2017-08-12 08:39:00+03	2017-08-12 12:22:00+03
25201	PG0595	2017-08-02 08:35:00+03	2017-08-02 12:20:00+03	BAX	ASF	Arrived	CR2	2017-08-02 08:38:00+03	2017-08-02 12:24:00+03
25202	PG0595	2017-09-02 08:35:00+03	2017-09-02 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25203	PG0595	2017-09-13 08:35:00+03	2017-09-13 12:20:00+03	BAX	ASF	Cancelled	CR2	\N	\N
25204	PG0595	2017-09-06 08:35:00+03	2017-09-06 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25205	PG0595	2017-08-19 08:35:00+03	2017-08-19 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25206	PG0595	2017-08-30 08:35:00+03	2017-08-30 12:20:00+03	BAX	ASF	Scheduled	CR2	\N	\N
25207	PG0199	2017-07-20 04:35:00+03	2017-07-20 10:25:00+03	IKT	LED	Arrived	321	2017-07-20 04:40:00+03	2017-07-20 10:26:00+03
25208	PG0199	2017-08-03 04:35:00+03	2017-08-03 10:25:00+03	IKT	LED	Arrived	321	2017-08-03 04:39:00+03	2017-08-03 10:29:00+03
25209	PG0199	2017-08-16 04:35:00+03	2017-08-16 10:25:00+03	IKT	LED	On Time	321	\N	\N
25210	PG0199	2017-08-19 04:35:00+03	2017-08-19 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25211	PG0199	2017-09-14 04:35:00+03	2017-09-14 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25212	PG0199	2017-07-31 04:35:00+03	2017-07-31 10:25:00+03	IKT	LED	Arrived	321	2017-07-31 04:37:00+03	2017-07-31 10:26:00+03
25213	PG0199	2017-07-24 04:35:00+03	2017-07-24 10:25:00+03	IKT	LED	Arrived	321	2017-07-24 04:40:00+03	2017-07-24 10:25:00+03
25214	PG0199	2017-08-15 04:35:00+03	2017-08-15 10:25:00+03	IKT	LED	Arrived	321	2017-08-15 04:38:00+03	2017-08-15 10:34:00+03
25215	PG0199	2017-09-04 04:35:00+03	2017-09-04 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25216	PG0199	2017-08-21 04:35:00+03	2017-08-21 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25217	PG0199	2017-07-27 04:35:00+03	2017-07-27 10:25:00+03	IKT	LED	Arrived	321	2017-07-27 04:37:00+03	2017-07-27 10:31:00+03
25218	PG0199	2017-08-23 04:35:00+03	2017-08-23 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25219	PG0199	2017-07-17 04:35:00+03	2017-07-17 10:25:00+03	IKT	LED	Arrived	321	2017-07-17 04:38:00+03	2017-07-17 10:27:00+03
25220	PG0199	2017-07-22 04:35:00+03	2017-07-22 10:25:00+03	IKT	LED	Arrived	321	2017-07-22 04:42:00+03	2017-07-22 10:33:00+03
25221	PG0199	2017-08-29 04:35:00+03	2017-08-29 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25222	PG0199	2017-08-12 04:35:00+03	2017-08-12 10:25:00+03	IKT	LED	Arrived	321	2017-08-12 04:36:00+03	2017-08-12 10:24:00+03
25223	PG0199	2017-07-19 04:35:00+03	2017-07-19 10:25:00+03	IKT	LED	Arrived	321	2017-07-19 04:41:00+03	2017-07-19 10:36:00+03
25224	PG0199	2017-09-01 04:35:00+03	2017-09-01 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25225	PG0199	2017-09-09 04:35:00+03	2017-09-09 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25226	PG0199	2017-08-11 04:35:00+03	2017-08-11 10:25:00+03	IKT	LED	Arrived	321	2017-08-11 04:37:00+03	2017-08-11 10:29:00+03
25227	PG0199	2017-08-26 04:35:00+03	2017-08-26 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25228	PG0199	2017-08-27 04:35:00+03	2017-08-27 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25229	PG0199	2017-07-28 04:35:00+03	2017-07-28 10:25:00+03	IKT	LED	Arrived	321	2017-07-28 04:39:00+03	2017-07-28 10:26:00+03
25230	PG0199	2017-08-31 04:35:00+03	2017-08-31 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25231	PG0199	2017-08-24 04:35:00+03	2017-08-24 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25232	PG0199	2017-08-20 04:35:00+03	2017-08-20 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25233	PG0199	2017-09-07 04:35:00+03	2017-09-07 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25234	PG0199	2017-07-30 04:35:00+03	2017-07-30 10:25:00+03	IKT	LED	Arrived	321	2017-07-30 04:36:00+03	2017-07-30 10:22:00+03
25235	PG0199	2017-08-17 04:35:00+03	2017-08-17 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25236	PG0199	2017-09-02 04:35:00+03	2017-09-02 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25237	PG0199	2017-07-18 04:35:00+03	2017-07-18 10:25:00+03	IKT	LED	Arrived	321	2017-07-18 04:37:00+03	2017-07-18 10:24:00+03
25238	PG0199	2017-08-14 04:35:00+03	2017-08-14 10:25:00+03	IKT	LED	Arrived	321	2017-08-14 04:37:00+03	2017-08-14 10:32:00+03
25239	PG0199	2017-09-08 04:35:00+03	2017-09-08 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25240	PG0199	2017-09-13 04:35:00+03	2017-09-13 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25241	PG0199	2017-08-13 04:35:00+03	2017-08-13 10:25:00+03	IKT	LED	Arrived	321	2017-08-13 04:37:00+03	2017-08-13 10:29:00+03
25242	PG0199	2017-07-29 04:35:00+03	2017-07-29 10:25:00+03	IKT	LED	Arrived	321	2017-07-29 04:36:00+03	2017-07-29 10:34:00+03
25243	PG0199	2017-08-28 04:35:00+03	2017-08-28 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25244	PG0199	2017-08-10 04:35:00+03	2017-08-10 10:25:00+03	IKT	LED	Arrived	321	2017-08-10 04:39:00+03	2017-08-10 10:29:00+03
25245	PG0199	2017-08-06 04:35:00+03	2017-08-06 10:25:00+03	IKT	LED	Arrived	321	2017-08-06 04:39:00+03	2017-08-06 10:30:00+03
25246	PG0199	2017-08-05 04:35:00+03	2017-08-05 10:25:00+03	IKT	LED	Arrived	321	2017-08-05 04:38:00+03	2017-08-05 10:30:00+03
25247	PG0199	2017-08-30 04:35:00+03	2017-08-30 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25248	PG0199	2017-08-08 04:35:00+03	2017-08-08 10:25:00+03	IKT	LED	Arrived	321	2017-08-08 04:37:00+03	2017-08-08 10:30:00+03
25249	PG0199	2017-09-03 04:35:00+03	2017-09-03 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25250	PG0199	2017-08-01 04:35:00+03	2017-08-01 10:25:00+03	IKT	LED	Arrived	321	2017-08-01 04:36:00+03	2017-08-01 10:21:00+03
25251	PG0199	2017-07-26 04:35:00+03	2017-07-26 10:25:00+03	IKT	LED	Arrived	321	2017-07-26 04:40:00+03	2017-07-26 10:35:00+03
25252	PG0199	2017-09-05 04:35:00+03	2017-09-05 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25253	PG0199	2017-08-18 04:35:00+03	2017-08-18 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25254	PG0199	2017-08-25 04:35:00+03	2017-08-25 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25255	PG0199	2017-09-11 04:35:00+03	2017-09-11 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25256	PG0199	2017-08-02 04:35:00+03	2017-08-02 10:25:00+03	IKT	LED	Arrived	321	2017-08-02 04:36:00+03	2017-08-02 10:29:00+03
25257	PG0199	2017-09-10 04:35:00+03	2017-09-10 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25258	PG0199	2017-09-12 04:35:00+03	2017-09-12 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25259	PG0199	2017-08-04 04:35:00+03	2017-08-04 10:25:00+03	IKT	LED	Arrived	321	2017-08-04 04:38:00+03	2017-08-04 10:29:00+03
25260	PG0199	2017-07-16 04:35:00+03	2017-07-16 10:25:00+03	IKT	LED	Arrived	321	2017-07-16 04:39:00+03	2017-07-16 10:29:00+03
25261	PG0199	2017-08-09 04:35:00+03	2017-08-09 10:25:00+03	IKT	LED	Arrived	321	2017-08-09 04:38:00+03	2017-08-09 10:31:00+03
25262	PG0199	2017-08-22 04:35:00+03	2017-08-22 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25263	PG0199	2017-07-23 04:35:00+03	2017-07-23 10:25:00+03	IKT	LED	Arrived	321	2017-07-23 04:41:00+03	2017-07-23 10:32:00+03
25264	PG0199	2017-07-25 04:35:00+03	2017-07-25 10:25:00+03	IKT	LED	Arrived	321	2017-07-25 04:36:00+03	2017-07-25 10:29:00+03
25265	PG0199	2017-07-21 04:35:00+03	2017-07-21 10:25:00+03	IKT	LED	Arrived	321	2017-07-21 04:40:00+03	2017-07-21 10:35:00+03
25266	PG0199	2017-09-06 04:35:00+03	2017-09-06 10:25:00+03	IKT	LED	Scheduled	321	\N	\N
25267	PG0199	2017-08-07 04:35:00+03	2017-08-07 10:25:00+03	IKT	LED	Arrived	321	2017-08-07 08:01:00+03	2017-08-07 13:55:00+03
25268	PG0499	2017-08-17 13:10:00+03	2017-08-17 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25269	PG0499	2017-07-28 13:10:00+03	2017-07-28 17:50:00+03	IKT	KZN	Arrived	319	2017-07-28 13:10:00+03	2017-07-28 17:54:00+03
25270	PG0499	2017-07-16 13:10:00+03	2017-07-16 17:50:00+03	IKT	KZN	Arrived	319	2017-07-16 13:11:00+03	2017-07-16 17:55:00+03
25271	PG0499	2017-07-24 13:10:00+03	2017-07-24 17:50:00+03	IKT	KZN	Arrived	319	2017-07-24 16:24:00+03	2017-07-24 21:04:00+03
25272	PG0499	2017-07-23 13:10:00+03	2017-07-23 17:50:00+03	IKT	KZN	Arrived	319	2017-07-23 13:14:00+03	2017-07-23 17:55:00+03
25273	PG0499	2017-08-04 13:10:00+03	2017-08-04 17:50:00+03	IKT	KZN	Arrived	319	2017-08-04 13:12:00+03	2017-08-04 17:55:00+03
25274	PG0499	2017-08-01 13:10:00+03	2017-08-01 17:50:00+03	IKT	KZN	Arrived	319	2017-08-01 13:18:00+03	2017-08-01 17:57:00+03
25275	PG0499	2017-09-08 13:10:00+03	2017-09-08 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25276	PG0499	2017-08-15 13:10:00+03	2017-08-15 17:50:00+03	IKT	KZN	Arrived	319	2017-08-15 13:13:00+03	2017-08-15 17:53:00+03
25277	PG0499	2017-09-11 13:10:00+03	2017-09-11 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25278	PG0499	2017-08-20 13:10:00+03	2017-08-20 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25279	PG0499	2017-07-29 13:10:00+03	2017-07-29 17:50:00+03	IKT	KZN	Arrived	319	2017-07-29 16:57:00+03	2017-07-29 21:33:00+03
25280	PG0499	2017-08-27 13:10:00+03	2017-08-27 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25281	PG0499	2017-07-19 13:10:00+03	2017-07-19 17:50:00+03	IKT	KZN	Arrived	319	2017-07-19 13:11:00+03	2017-07-19 17:48:00+03
25282	PG0499	2017-08-18 13:10:00+03	2017-08-18 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25283	PG0499	2017-09-03 13:10:00+03	2017-09-03 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25284	PG0499	2017-08-06 13:10:00+03	2017-08-06 17:50:00+03	IKT	KZN	Arrived	319	2017-08-06 13:13:00+03	2017-08-06 17:49:00+03
25285	PG0499	2017-07-22 13:10:00+03	2017-07-22 17:50:00+03	IKT	KZN	Arrived	319	2017-07-22 13:15:00+03	2017-07-22 17:55:00+03
25286	PG0499	2017-08-05 13:10:00+03	2017-08-05 17:50:00+03	IKT	KZN	Arrived	319	2017-08-05 13:15:00+03	2017-08-05 18:01:00+03
25287	PG0499	2017-08-28 13:10:00+03	2017-08-28 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25288	PG0499	2017-08-23 13:10:00+03	2017-08-23 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25289	PG0499	2017-08-14 13:10:00+03	2017-08-14 17:50:00+03	IKT	KZN	Arrived	319	2017-08-14 13:13:00+03	2017-08-14 17:59:00+03
25290	PG0499	2017-09-14 13:10:00+03	2017-09-14 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25291	PG0499	2017-07-17 13:10:00+03	2017-07-17 17:50:00+03	IKT	KZN	Arrived	319	2017-07-17 13:11:00+03	2017-07-17 17:52:00+03
25292	PG0499	2017-08-24 13:10:00+03	2017-08-24 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25293	PG0499	2017-07-31 13:10:00+03	2017-07-31 17:50:00+03	IKT	KZN	Arrived	319	2017-07-31 13:10:00+03	2017-07-31 17:49:00+03
25294	PG0499	2017-08-30 13:10:00+03	2017-08-30 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25295	PG0499	2017-07-30 13:10:00+03	2017-07-30 17:50:00+03	IKT	KZN	Arrived	319	2017-07-30 13:14:00+03	2017-07-30 17:56:00+03
25296	PG0499	2017-07-27 13:10:00+03	2017-07-27 17:50:00+03	IKT	KZN	Arrived	319	2017-07-27 13:13:00+03	2017-07-27 17:57:00+03
25297	PG0499	2017-08-31 13:10:00+03	2017-08-31 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25298	PG0499	2017-08-11 13:10:00+03	2017-08-11 17:50:00+03	IKT	KZN	Arrived	319	2017-08-11 13:12:00+03	2017-08-11 17:54:00+03
25299	PG0499	2017-08-10 13:10:00+03	2017-08-10 17:50:00+03	IKT	KZN	Arrived	319	2017-08-10 13:12:00+03	2017-08-10 17:47:00+03
25300	PG0499	2017-08-21 13:10:00+03	2017-08-21 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25301	PG0499	2017-09-01 13:10:00+03	2017-09-01 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25302	PG0499	2017-09-13 13:10:00+03	2017-09-13 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25303	PG0499	2017-08-29 13:10:00+03	2017-08-29 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25304	PG0499	2017-09-07 13:10:00+03	2017-09-07 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25305	PG0499	2017-07-25 13:10:00+03	2017-07-25 17:50:00+03	IKT	KZN	Arrived	319	2017-07-25 13:10:00+03	2017-07-25 17:51:00+03
25306	PG0499	2017-08-07 13:10:00+03	2017-08-07 17:50:00+03	IKT	KZN	Arrived	319	2017-08-07 13:13:00+03	2017-08-07 17:48:00+03
25307	PG0499	2017-08-08 13:10:00+03	2017-08-08 17:50:00+03	IKT	KZN	Arrived	319	2017-08-08 13:12:00+03	2017-08-08 17:51:00+03
25308	PG0499	2017-08-16 13:10:00+03	2017-08-16 17:50:00+03	IKT	KZN	On Time	319	\N	\N
25309	PG0499	2017-08-12 13:10:00+03	2017-08-12 17:50:00+03	IKT	KZN	Arrived	319	2017-08-12 13:14:00+03	2017-08-12 17:54:00+03
25310	PG0499	2017-08-03 13:10:00+03	2017-08-03 17:50:00+03	IKT	KZN	Arrived	319	2017-08-03 13:14:00+03	2017-08-03 17:54:00+03
25311	PG0499	2017-09-04 13:10:00+03	2017-09-04 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25312	PG0499	2017-07-20 13:10:00+03	2017-07-20 17:50:00+03	IKT	KZN	Arrived	319	2017-07-20 15:59:00+03	2017-07-20 20:40:00+03
25313	PG0499	2017-08-22 13:10:00+03	2017-08-22 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25314	PG0499	2017-09-12 13:10:00+03	2017-09-12 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25315	PG0499	2017-08-26 13:10:00+03	2017-08-26 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25316	PG0499	2017-08-09 13:10:00+03	2017-08-09 17:50:00+03	IKT	KZN	Arrived	319	2017-08-09 13:15:00+03	2017-08-09 17:53:00+03
25317	PG0499	2017-08-19 13:10:00+03	2017-08-19 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25318	PG0499	2017-08-02 13:10:00+03	2017-08-02 17:50:00+03	IKT	KZN	Arrived	319	2017-08-02 13:13:00+03	2017-08-02 17:54:00+03
25319	PG0499	2017-08-13 13:10:00+03	2017-08-13 17:50:00+03	IKT	KZN	Arrived	319	2017-08-13 13:15:00+03	2017-08-13 17:56:00+03
25320	PG0499	2017-09-05 13:10:00+03	2017-09-05 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25321	PG0499	2017-09-06 13:10:00+03	2017-09-06 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25322	PG0499	2017-09-09 13:10:00+03	2017-09-09 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25323	PG0499	2017-07-26 13:10:00+03	2017-07-26 17:50:00+03	IKT	KZN	Arrived	319	2017-07-26 13:14:00+03	2017-07-26 17:54:00+03
25324	PG0499	2017-09-02 13:10:00+03	2017-09-02 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25325	PG0499	2017-09-10 13:10:00+03	2017-09-10 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25326	PG0499	2017-07-21 13:10:00+03	2017-07-21 17:50:00+03	IKT	KZN	Arrived	319	2017-07-21 13:13:00+03	2017-07-21 17:52:00+03
25327	PG0499	2017-08-25 13:10:00+03	2017-08-25 17:50:00+03	IKT	KZN	Scheduled	319	\N	\N
25328	PG0499	2017-07-18 13:10:00+03	2017-07-18 17:50:00+03	IKT	KZN	Arrived	319	2017-07-18 15:39:00+03	2017-07-18 20:22:00+03
25329	PG0546	2017-08-09 11:45:00+03	2017-08-09 15:30:00+03	IKT	CEK	Arrived	SU9	2017-08-09 11:46:00+03	2017-08-09 15:31:00+03
25330	PG0546	2017-08-02 11:45:00+03	2017-08-02 15:30:00+03	IKT	CEK	Arrived	SU9	2017-08-02 11:49:00+03	2017-08-02 15:34:00+03
25331	PG0546	2017-07-23 11:45:00+03	2017-07-23 15:30:00+03	IKT	CEK	Arrived	SU9	2017-07-23 11:50:00+03	2017-07-23 15:34:00+03
25332	PG0546	2017-08-23 11:45:00+03	2017-08-23 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25333	PG0546	2017-07-16 11:45:00+03	2017-07-16 15:30:00+03	IKT	CEK	Arrived	SU9	2017-07-16 11:54:00+03	2017-07-16 15:44:00+03
25334	PG0546	2017-07-19 11:45:00+03	2017-07-19 15:30:00+03	IKT	CEK	Arrived	SU9	2017-07-19 11:50:00+03	2017-07-19 15:36:00+03
25335	PG0546	2017-08-06 11:45:00+03	2017-08-06 15:30:00+03	IKT	CEK	Arrived	SU9	2017-08-06 11:48:00+03	2017-08-06 15:34:00+03
25336	PG0546	2017-07-26 11:45:00+03	2017-07-26 15:30:00+03	IKT	CEK	Arrived	SU9	2017-07-26 11:51:00+03	2017-07-26 15:36:00+03
25337	PG0546	2017-08-13 11:45:00+03	2017-08-13 15:30:00+03	IKT	CEK	Arrived	SU9	2017-08-13 11:48:00+03	2017-08-13 15:34:00+03
25338	PG0546	2017-09-13 11:45:00+03	2017-09-13 15:30:00+03	IKT	CEK	Cancelled	SU9	\N	\N
25339	PG0546	2017-09-06 11:45:00+03	2017-09-06 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25340	PG0546	2017-09-03 11:45:00+03	2017-09-03 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25341	PG0546	2017-08-16 11:45:00+03	2017-08-16 15:30:00+03	IKT	CEK	On Time	SU9	\N	\N
25342	PG0546	2017-08-30 11:45:00+03	2017-08-30 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25343	PG0546	2017-08-27 11:45:00+03	2017-08-27 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25344	PG0546	2017-08-20 11:45:00+03	2017-08-20 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25345	PG0546	2017-09-10 11:45:00+03	2017-09-10 15:30:00+03	IKT	CEK	Scheduled	SU9	\N	\N
25346	PG0546	2017-07-30 11:45:00+03	2017-07-30 15:30:00+03	IKT	CEK	Arrived	SU9	2017-07-30 11:49:00+03	2017-07-30 15:36:00+03
25347	PG0556	2017-08-28 09:05:00+03	2017-08-28 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25348	PG0556	2017-09-03 09:05:00+03	2017-09-03 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25349	PG0556	2017-08-24 09:05:00+03	2017-08-24 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25350	PG0556	2017-09-10 09:05:00+03	2017-09-10 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25351	PG0556	2017-09-11 09:05:00+03	2017-09-11 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25352	PG0556	2017-09-01 09:05:00+03	2017-09-01 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25353	PG0556	2017-08-05 09:05:00+03	2017-08-05 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-05 09:09:00+03	2017-08-05 10:59:00+03
25354	PG0556	2017-08-30 09:05:00+03	2017-08-30 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25355	PG0556	2017-08-09 09:05:00+03	2017-08-09 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-09 09:07:00+03	2017-08-09 10:56:00+03
25356	PG0556	2017-09-09 09:05:00+03	2017-09-09 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25357	PG0556	2017-08-07 09:05:00+03	2017-08-07 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-07 09:06:00+03	2017-08-07 10:55:00+03
25358	PG0556	2017-07-16 09:05:00+03	2017-07-16 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-16 09:09:00+03	2017-07-16 11:00:00+03
25359	PG0556	2017-08-23 09:05:00+03	2017-08-23 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25360	PG0556	2017-08-06 09:05:00+03	2017-08-06 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-06 09:11:00+03	2017-08-06 11:00:00+03
25361	PG0556	2017-09-06 09:05:00+03	2017-09-06 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25362	PG0556	2017-07-18 09:05:00+03	2017-07-18 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-18 09:09:00+03	2017-07-18 11:00:00+03
25363	PG0556	2017-08-04 09:05:00+03	2017-08-04 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-04 09:09:00+03	2017-08-04 10:59:00+03
25364	PG0556	2017-08-26 09:05:00+03	2017-08-26 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25365	PG0556	2017-08-15 09:05:00+03	2017-08-15 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-15 09:08:00+03	2017-08-15 10:57:00+03
25366	PG0556	2017-09-07 09:05:00+03	2017-09-07 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25367	PG0556	2017-08-18 09:05:00+03	2017-08-18 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25368	PG0556	2017-09-02 09:05:00+03	2017-09-02 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25369	PG0556	2017-07-30 09:05:00+03	2017-07-30 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-30 09:08:00+03	2017-07-30 10:57:00+03
25370	PG0556	2017-08-02 09:05:00+03	2017-08-02 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-02 09:05:00+03	2017-08-02 10:54:00+03
25371	PG0556	2017-07-31 09:05:00+03	2017-07-31 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-31 09:10:00+03	2017-07-31 10:59:00+03
25372	PG0556	2017-08-27 09:05:00+03	2017-08-27 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25373	PG0556	2017-07-19 09:05:00+03	2017-07-19 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-19 09:09:00+03	2017-07-19 10:59:00+03
25374	PG0556	2017-07-17 09:05:00+03	2017-07-17 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-17 09:09:00+03	2017-07-17 11:00:00+03
25375	PG0556	2017-08-25 09:05:00+03	2017-08-25 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25376	PG0556	2017-07-28 09:05:00+03	2017-07-28 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-28 09:10:00+03	2017-07-28 11:00:00+03
25377	PG0556	2017-08-14 09:05:00+03	2017-08-14 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-14 09:08:00+03	2017-08-14 10:59:00+03
25378	PG0556	2017-08-11 09:05:00+03	2017-08-11 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-11 09:06:00+03	2017-08-11 10:56:00+03
25379	PG0556	2017-08-20 09:05:00+03	2017-08-20 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25380	PG0556	2017-07-26 09:05:00+03	2017-07-26 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-26 09:08:00+03	2017-07-26 10:59:00+03
25381	PG0556	2017-07-29 09:05:00+03	2017-07-29 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-29 09:08:00+03	2017-07-29 10:57:00+03
25383	PG0556	2017-08-22 09:05:00+03	2017-08-22 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25384	PG0556	2017-09-12 09:05:00+03	2017-09-12 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25385	PG0556	2017-08-16 09:05:00+03	2017-08-16 10:55:00+03	IKT	MJZ	On Time	CR2	\N	\N
25386	PG0556	2017-08-12 09:05:00+03	2017-08-12 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-12 12:47:00+03	2017-08-12 14:38:00+03
25387	PG0556	2017-07-22 09:05:00+03	2017-07-22 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-22 09:07:00+03	2017-07-22 10:58:00+03
25388	PG0556	2017-08-03 09:05:00+03	2017-08-03 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-03 09:08:00+03	2017-08-03 10:58:00+03
25389	PG0556	2017-07-25 09:05:00+03	2017-07-25 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-25 09:07:00+03	2017-07-25 10:56:00+03
25390	PG0556	2017-07-23 09:05:00+03	2017-07-23 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-23 09:07:00+03	2017-07-23 10:57:00+03
25391	PG0556	2017-09-08 09:05:00+03	2017-09-08 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25392	PG0556	2017-07-20 09:05:00+03	2017-07-20 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-20 09:07:00+03	2017-07-20 10:59:00+03
25393	PG0556	2017-08-17 09:05:00+03	2017-08-17 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25394	PG0556	2017-08-29 09:05:00+03	2017-08-29 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25395	PG0556	2017-07-27 09:05:00+03	2017-07-27 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-27 09:11:00+03	2017-07-27 11:00:00+03
25396	PG0556	2017-08-10 09:05:00+03	2017-08-10 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-10 09:07:00+03	2017-08-10 10:57:00+03
25397	PG0556	2017-09-04 09:05:00+03	2017-09-04 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25398	PG0556	2017-08-19 09:05:00+03	2017-08-19 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25399	PG0556	2017-08-13 09:05:00+03	2017-08-13 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-13 09:08:00+03	2017-08-13 10:58:00+03
25400	PG0556	2017-07-21 09:05:00+03	2017-07-21 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-21 09:05:00+03	2017-07-21 10:55:00+03
25401	PG0556	2017-09-13 09:05:00+03	2017-09-13 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25402	PG0556	2017-08-01 09:05:00+03	2017-08-01 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-01 09:08:00+03	2017-08-01 10:59:00+03
25403	PG0556	2017-09-05 09:05:00+03	2017-09-05 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25404	PG0556	2017-08-21 09:05:00+03	2017-08-21 10:55:00+03	IKT	MJZ	Scheduled	CR2	\N	\N
25405	PG0556	2017-07-24 09:05:00+03	2017-07-24 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-07-24 09:10:00+03	2017-07-24 10:59:00+03
25406	PG0556	2017-08-08 09:05:00+03	2017-08-08 10:55:00+03	IKT	MJZ	Arrived	CR2	2017-08-08 09:08:00+03	2017-08-08 10:59:00+03
25407	PG0556	2017-09-14 09:05:00+03	2017-09-14 10:55:00+03	IKT	MJZ	Cancelled	CR2	\N	\N
25408	PG0268	2017-07-29 08:55:00+03	2017-07-29 12:50:00+03	IKT	GDX	Arrived	SU9	2017-07-29 08:57:00+03	2017-07-29 12:49:00+03
25409	PG0268	2017-07-26 08:55:00+03	2017-07-26 12:50:00+03	IKT	GDX	Arrived	SU9	2017-07-26 08:58:00+03	2017-07-26 12:56:00+03
25410	PG0268	2017-08-23 08:55:00+03	2017-08-23 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25411	PG0268	2017-08-05 08:55:00+03	2017-08-05 12:50:00+03	IKT	GDX	Arrived	SU9	2017-08-05 08:56:00+03	2017-08-05 12:48:00+03
25412	PG0268	2017-08-30 08:55:00+03	2017-08-30 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25413	PG0268	2017-08-02 08:55:00+03	2017-08-02 12:50:00+03	IKT	GDX	Arrived	SU9	2017-08-02 08:57:00+03	2017-08-02 12:49:00+03
25414	PG0268	2017-08-19 08:55:00+03	2017-08-19 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25415	PG0268	2017-08-26 08:55:00+03	2017-08-26 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25416	PG0268	2017-07-22 08:55:00+03	2017-07-22 12:50:00+03	IKT	GDX	Arrived	SU9	2017-07-22 08:58:00+03	2017-07-22 12:52:00+03
25417	PG0268	2017-09-06 08:55:00+03	2017-09-06 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25418	PG0268	2017-09-13 08:55:00+03	2017-09-13 12:50:00+03	IKT	GDX	Cancelled	SU9	\N	\N
25419	PG0268	2017-08-09 08:55:00+03	2017-08-09 12:50:00+03	IKT	GDX	Arrived	SU9	2017-08-09 08:57:00+03	2017-08-09 12:49:00+03
25420	PG0268	2017-07-19 08:55:00+03	2017-07-19 12:50:00+03	IKT	GDX	Arrived	SU9	2017-07-19 08:58:00+03	2017-07-19 12:56:00+03
25421	PG0268	2017-09-02 08:55:00+03	2017-09-02 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25422	PG0268	2017-08-12 08:55:00+03	2017-08-12 12:50:00+03	IKT	GDX	Arrived	SU9	2017-08-12 09:00:00+03	2017-08-12 12:56:00+03
25423	PG0268	2017-08-16 08:55:00+03	2017-08-16 12:50:00+03	IKT	GDX	On Time	SU9	\N	\N
25424	PG0268	2017-09-09 08:55:00+03	2017-09-09 12:50:00+03	IKT	GDX	Scheduled	SU9	\N	\N
25425	PG0028	2017-08-17 11:45:00+03	2017-08-17 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25426	PG0028	2017-07-20 11:45:00+03	2017-07-20 15:00:00+03	IKT	NYM	Arrived	CR2	2017-07-20 11:49:00+03	2017-07-20 15:03:00+03
25427	PG0028	2017-07-27 11:45:00+03	2017-07-27 15:00:00+03	IKT	NYM	Arrived	CR2	2017-07-27 11:49:00+03	2017-07-27 15:02:00+03
25428	PG0028	2017-09-07 11:45:00+03	2017-09-07 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25429	PG0028	2017-08-07 11:45:00+03	2017-08-07 15:00:00+03	IKT	NYM	Arrived	CR2	2017-08-07 14:27:00+03	2017-08-07 17:43:00+03
25430	PG0028	2017-08-31 11:45:00+03	2017-08-31 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25431	PG0028	2017-08-24 11:45:00+03	2017-08-24 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25432	PG0028	2017-07-17 11:45:00+03	2017-07-17 15:00:00+03	IKT	NYM	Arrived	CR2	2017-07-17 11:50:00+03	2017-07-17 15:05:00+03
25433	PG0028	2017-09-14 11:45:00+03	2017-09-14 15:00:00+03	IKT	NYM	Cancelled	CR2	\N	\N
25434	PG0028	2017-08-21 11:45:00+03	2017-08-21 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25435	PG0028	2017-08-03 11:45:00+03	2017-08-03 15:00:00+03	IKT	NYM	Arrived	CR2	2017-08-03 11:49:00+03	2017-08-03 15:03:00+03
25436	PG0028	2017-08-28 11:45:00+03	2017-08-28 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25437	PG0028	2017-07-31 11:45:00+03	2017-07-31 15:00:00+03	IKT	NYM	Arrived	CR2	2017-07-31 11:47:00+03	2017-07-31 15:02:00+03
25438	PG0028	2017-07-24 11:45:00+03	2017-07-24 15:00:00+03	IKT	NYM	Arrived	CR2	2017-07-24 11:46:00+03	2017-07-24 15:04:00+03
25439	PG0028	2017-09-04 11:45:00+03	2017-09-04 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25440	PG0028	2017-08-10 11:45:00+03	2017-08-10 15:00:00+03	IKT	NYM	Arrived	CR2	2017-08-10 11:48:00+03	2017-08-10 15:03:00+03
25441	PG0028	2017-09-11 11:45:00+03	2017-09-11 15:00:00+03	IKT	NYM	Scheduled	CR2	\N	\N
25442	PG0028	2017-08-14 11:45:00+03	2017-08-14 15:00:00+03	IKT	NYM	Arrived	CR2	2017-08-14 11:46:00+03	2017-08-14 14:57:00+03
25443	PG0659	2017-09-11 06:30:00+03	2017-09-11 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25444	PG0659	2017-08-06 06:30:00+03	2017-08-06 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-06 06:32:00+03	2017-08-06 09:47:00+03
25445	PG0659	2017-07-26 06:30:00+03	2017-07-26 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-26 06:35:00+03	2017-07-26 09:52:00+03
25446	PG0659	2017-07-19 06:30:00+03	2017-07-19 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-19 06:31:00+03	2017-07-19 09:46:00+03
25447	PG0659	2017-08-21 06:30:00+03	2017-08-21 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25448	PG0659	2017-08-03 06:30:00+03	2017-08-03 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-03 06:32:00+03	2017-08-03 09:47:00+03
25449	PG0659	2017-08-12 06:30:00+03	2017-08-12 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-12 06:32:00+03	2017-08-12 09:50:00+03
25450	PG0659	2017-07-20 06:30:00+03	2017-07-20 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-20 06:36:00+03	2017-07-20 09:52:00+03
25451	PG0659	2017-08-16 06:30:00+03	2017-08-16 09:45:00+03	IKT	VVO	On Time	CR2	\N	\N
25452	PG0659	2017-09-01 06:30:00+03	2017-09-01 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25453	PG0659	2017-08-14 06:30:00+03	2017-08-14 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-14 06:33:00+03	2017-08-14 09:44:00+03
25454	PG0659	2017-08-01 06:30:00+03	2017-08-01 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-01 06:35:00+03	2017-08-01 09:50:00+03
25455	PG0659	2017-09-04 06:30:00+03	2017-09-04 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25456	PG0659	2017-07-18 06:30:00+03	2017-07-18 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-18 10:00:00+03	2017-07-18 13:16:00+03
25457	PG0659	2017-08-31 06:30:00+03	2017-08-31 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25458	PG0659	2017-08-09 06:30:00+03	2017-08-09 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-09 06:34:00+03	2017-08-09 09:46:00+03
25459	PG0659	2017-08-19 06:30:00+03	2017-08-19 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25460	PG0659	2017-08-07 06:30:00+03	2017-08-07 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-07 06:35:00+03	2017-08-07 09:49:00+03
25461	PG0659	2017-08-20 06:30:00+03	2017-08-20 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25462	PG0659	2017-09-02 06:30:00+03	2017-09-02 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25463	PG0659	2017-08-23 06:30:00+03	2017-08-23 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25464	PG0659	2017-07-24 06:30:00+03	2017-07-24 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-24 06:33:00+03	2017-07-24 09:48:00+03
25465	PG0659	2017-09-13 06:30:00+03	2017-09-13 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25466	PG0659	2017-07-17 06:30:00+03	2017-07-17 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-17 06:34:00+03	2017-07-17 09:51:00+03
25467	PG0659	2017-07-30 06:30:00+03	2017-07-30 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-30 06:32:00+03	2017-07-30 09:48:00+03
25468	PG0659	2017-07-22 06:30:00+03	2017-07-22 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-22 06:34:00+03	2017-07-22 09:47:00+03
25469	PG0659	2017-09-14 06:30:00+03	2017-09-14 09:45:00+03	IKT	VVO	Cancelled	CR2	\N	\N
25470	PG0659	2017-08-30 06:30:00+03	2017-08-30 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25471	PG0659	2017-08-13 06:30:00+03	2017-08-13 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-13 06:30:00+03	2017-08-13 09:44:00+03
25472	PG0659	2017-08-27 06:30:00+03	2017-08-27 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25473	PG0659	2017-08-17 06:30:00+03	2017-08-17 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25474	PG0659	2017-08-11 06:30:00+03	2017-08-11 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-11 06:33:00+03	2017-08-11 09:46:00+03
25475	PG0659	2017-09-03 06:30:00+03	2017-09-03 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25476	PG0659	2017-09-12 06:30:00+03	2017-09-12 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25477	PG0659	2017-07-31 06:30:00+03	2017-07-31 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-31 06:31:00+03	2017-07-31 09:45:00+03
25478	PG0659	2017-07-25 06:30:00+03	2017-07-25 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-25 06:31:00+03	2017-07-25 09:44:00+03
25479	PG0659	2017-08-25 06:30:00+03	2017-08-25 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25480	PG0659	2017-08-15 06:30:00+03	2017-08-15 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-15 06:32:00+03	2017-08-15 09:49:00+03
25481	PG0659	2017-09-09 06:30:00+03	2017-09-09 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25482	PG0659	2017-09-10 06:30:00+03	2017-09-10 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25483	PG0659	2017-07-28 06:30:00+03	2017-07-28 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-28 06:33:00+03	2017-07-28 09:47:00+03
25484	PG0659	2017-08-29 06:30:00+03	2017-08-29 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25485	PG0659	2017-08-08 06:30:00+03	2017-08-08 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-08 06:32:00+03	2017-08-08 09:49:00+03
25486	PG0659	2017-08-05 06:30:00+03	2017-08-05 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-05 06:31:00+03	2017-08-05 09:45:00+03
25487	PG0659	2017-09-08 06:30:00+03	2017-09-08 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25488	PG0659	2017-08-26 06:30:00+03	2017-08-26 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25489	PG0659	2017-08-02 06:30:00+03	2017-08-02 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-02 06:34:00+03	2017-08-02 09:47:00+03
25490	PG0659	2017-07-27 06:30:00+03	2017-07-27 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-27 06:32:00+03	2017-07-27 09:45:00+03
25491	PG0659	2017-07-21 06:30:00+03	2017-07-21 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-21 06:33:00+03	2017-07-21 09:47:00+03
25492	PG0659	2017-07-23 06:30:00+03	2017-07-23 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-23 06:33:00+03	2017-07-23 09:45:00+03
25493	PG0659	2017-08-24 06:30:00+03	2017-08-24 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25494	PG0659	2017-09-05 06:30:00+03	2017-09-05 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25495	PG0659	2017-09-07 06:30:00+03	2017-09-07 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25496	PG0659	2017-07-16 06:30:00+03	2017-07-16 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-16 06:31:00+03	2017-07-16 09:46:00+03
25497	PG0659	2017-08-28 06:30:00+03	2017-08-28 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25498	PG0659	2017-08-04 06:30:00+03	2017-08-04 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-04 06:33:00+03	2017-08-04 09:46:00+03
25499	PG0659	2017-08-10 06:30:00+03	2017-08-10 09:45:00+03	IKT	VVO	Arrived	CR2	2017-08-10 06:31:00+03	2017-08-10 09:45:00+03
25500	PG0659	2017-08-18 06:30:00+03	2017-08-18 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25501	PG0659	2017-09-06 06:30:00+03	2017-09-06 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25502	PG0659	2017-07-29 06:30:00+03	2017-07-29 09:45:00+03	IKT	VVO	Arrived	CR2	2017-07-29 06:33:00+03	2017-07-29 09:51:00+03
25503	PG0659	2017-08-22 06:30:00+03	2017-08-22 09:45:00+03	IKT	VVO	Scheduled	CR2	\N	\N
25504	PG0374	2017-07-29 12:55:00+03	2017-07-29 17:55:00+03	IKT	ARH	Arrived	319	2017-07-29 12:59:00+03	2017-07-29 18:05:00+03
25505	PG0374	2017-08-19 12:55:00+03	2017-08-19 17:55:00+03	IKT	ARH	Scheduled	319	\N	\N
25506	PG0374	2017-09-09 12:55:00+03	2017-09-09 17:55:00+03	IKT	ARH	Scheduled	319	\N	\N
25507	PG0374	2017-08-12 12:55:00+03	2017-08-12 17:55:00+03	IKT	ARH	Arrived	319	2017-08-12 16:14:00+03	2017-08-12 21:17:00+03
25508	PG0374	2017-08-05 12:55:00+03	2017-08-05 17:55:00+03	IKT	ARH	Arrived	319	2017-08-05 12:57:00+03	2017-08-05 17:55:00+03
25509	PG0374	2017-09-02 12:55:00+03	2017-09-02 17:55:00+03	IKT	ARH	Scheduled	319	\N	\N
25510	PG0374	2017-08-26 12:55:00+03	2017-08-26 17:55:00+03	IKT	ARH	Scheduled	319	\N	\N
25511	PG0374	2017-07-22 12:55:00+03	2017-07-22 17:55:00+03	IKT	ARH	Arrived	319	2017-07-22 12:59:00+03	2017-07-22 17:59:00+03
25512	PG0603	2017-07-31 09:35:00+03	2017-07-31 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-31 09:38:00+03	2017-07-31 12:35:00+03
25513	PG0603	2017-07-22 09:35:00+03	2017-07-22 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-22 09:41:00+03	2017-07-22 12:41:00+03
25514	PG0603	2017-09-03 09:35:00+03	2017-09-03 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25515	PG0603	2017-08-18 09:35:00+03	2017-08-18 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25516	PG0603	2017-07-21 09:35:00+03	2017-07-21 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-21 09:38:00+03	2017-07-21 12:39:00+03
25517	PG0603	2017-08-28 09:35:00+03	2017-08-28 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25518	PG0603	2017-07-23 09:35:00+03	2017-07-23 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-23 09:38:00+03	2017-07-23 12:38:00+03
25519	PG0603	2017-08-27 09:35:00+03	2017-08-27 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25520	PG0603	2017-09-10 09:35:00+03	2017-09-10 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25521	PG0603	2017-08-17 09:35:00+03	2017-08-17 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25522	PG0603	2017-07-24 09:35:00+03	2017-07-24 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-24 09:35:00+03	2017-07-24 12:31:00+03
25523	PG0603	2017-08-20 09:35:00+03	2017-08-20 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25524	PG0603	2017-07-20 09:35:00+03	2017-07-20 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-20 09:39:00+03	2017-07-20 12:41:00+03
25525	PG0603	2017-08-16 09:35:00+03	2017-08-16 12:35:00+03	IKT	SGC	On Time	CR2	\N	\N
25526	PG0603	2017-07-25 09:35:00+03	2017-07-25 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-25 09:41:00+03	2017-07-25 12:40:00+03
25527	PG0603	2017-08-29 09:35:00+03	2017-08-29 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25528	PG0603	2017-09-09 09:35:00+03	2017-09-09 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25529	PG0603	2017-09-12 09:35:00+03	2017-09-12 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25530	PG0603	2017-08-15 09:35:00+03	2017-08-15 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-15 09:39:00+03	2017-08-15 12:38:00+03
25531	PG0603	2017-07-26 09:35:00+03	2017-07-26 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-26 09:38:00+03	2017-07-26 12:37:00+03
25532	PG0603	2017-08-14 09:35:00+03	2017-08-14 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-14 09:37:00+03	2017-08-14 12:35:00+03
25533	PG0603	2017-07-27 09:35:00+03	2017-07-27 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-27 09:41:00+03	2017-07-27 12:36:00+03
25534	PG0603	2017-08-21 09:35:00+03	2017-08-21 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25535	PG0603	2017-07-19 09:35:00+03	2017-07-19 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-19 09:38:00+03	2017-07-19 12:38:00+03
25536	PG0603	2017-08-30 09:35:00+03	2017-08-30 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25537	PG0603	2017-09-08 09:35:00+03	2017-09-08 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25538	PG0603	2017-07-28 09:35:00+03	2017-07-28 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-28 09:36:00+03	2017-07-28 12:35:00+03
25539	PG0603	2017-08-13 09:35:00+03	2017-08-13 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-13 09:37:00+03	2017-08-13 12:36:00+03
25540	PG0603	2017-08-26 09:35:00+03	2017-08-26 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25541	PG0603	2017-07-29 09:35:00+03	2017-07-29 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-29 09:38:00+03	2017-07-29 12:41:00+03
25542	PG0603	2017-09-07 09:35:00+03	2017-09-07 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25543	PG0603	2017-08-12 09:35:00+03	2017-08-12 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-12 12:42:00+03	2017-08-12 15:41:00+03
25544	PG0603	2017-07-18 09:35:00+03	2017-07-18 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-18 09:39:00+03	2017-07-18 12:39:00+03
25545	PG0603	2017-08-31 09:35:00+03	2017-08-31 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25546	PG0603	2017-08-22 09:35:00+03	2017-08-22 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25547	PG0603	2017-09-13 09:35:00+03	2017-09-13 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25548	PG0603	2017-07-30 09:35:00+03	2017-07-30 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-30 09:40:00+03	2017-07-30 12:40:00+03
25549	PG0603	2017-08-11 09:35:00+03	2017-08-11 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-11 09:40:00+03	2017-08-11 12:37:00+03
25550	PG0603	2017-09-06 09:35:00+03	2017-09-06 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25551	PG0603	2017-08-10 09:35:00+03	2017-08-10 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-10 09:37:00+03	2017-08-10 12:38:00+03
25552	PG0603	2017-09-01 09:35:00+03	2017-09-01 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25553	PG0603	2017-08-01 09:35:00+03	2017-08-01 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-01 09:41:00+03	2017-08-01 12:42:00+03
25554	PG0603	2017-07-17 09:35:00+03	2017-07-17 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-17 09:38:00+03	2017-07-17 12:39:00+03
25555	PG0603	2017-08-09 09:35:00+03	2017-08-09 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-09 09:40:00+03	2017-08-09 12:38:00+03
25556	PG0603	2017-08-23 09:35:00+03	2017-08-23 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25557	PG0603	2017-09-14 09:35:00+03	2017-09-14 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25558	PG0603	2017-08-02 09:35:00+03	2017-08-02 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-02 09:38:00+03	2017-08-02 12:41:00+03
25559	PG0603	2017-09-05 09:35:00+03	2017-09-05 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25560	PG0603	2017-08-08 09:35:00+03	2017-08-08 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-08 09:41:00+03	2017-08-08 12:40:00+03
25561	PG0603	2017-09-02 09:35:00+03	2017-09-02 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25562	PG0603	2017-08-03 09:35:00+03	2017-08-03 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-03 09:37:00+03	2017-08-03 12:38:00+03
25563	PG0603	2017-08-25 09:35:00+03	2017-08-25 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25564	PG0603	2017-07-16 09:35:00+03	2017-07-16 12:35:00+03	IKT	SGC	Arrived	CR2	2017-07-16 09:38:00+03	2017-07-16 12:38:00+03
25565	PG0603	2017-08-04 09:35:00+03	2017-08-04 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-04 09:37:00+03	2017-08-04 12:37:00+03
25566	PG0603	2017-08-07 09:35:00+03	2017-08-07 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-07 09:37:00+03	2017-08-07 12:40:00+03
25567	PG0603	2017-09-04 09:35:00+03	2017-09-04 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25568	PG0603	2017-08-24 09:35:00+03	2017-08-24 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25569	PG0603	2017-08-05 09:35:00+03	2017-08-05 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-05 09:38:00+03	2017-08-05 12:41:00+03
25570	PG0603	2017-08-06 09:35:00+03	2017-08-06 12:35:00+03	IKT	SGC	Arrived	CR2	2017-08-06 09:37:00+03	2017-08-06 12:38:00+03
25571	PG0603	2017-08-19 09:35:00+03	2017-08-19 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25572	PG0603	2017-09-11 09:35:00+03	2017-09-11 12:35:00+03	IKT	SGC	Scheduled	CR2	\N	\N
25573	PG0606	2017-08-11 15:55:00+03	2017-08-11 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-11 15:57:00+03	2017-08-11 16:53:00+03
25574	PG0606	2017-08-26 15:55:00+03	2017-08-26 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25575	PG0606	2017-08-06 15:55:00+03	2017-08-06 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-06 15:58:00+03	2017-08-06 16:53:00+03
25576	PG0606	2017-07-31 15:55:00+03	2017-07-31 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-31 15:57:00+03	2017-07-31 16:52:00+03
25577	PG0606	2017-07-29 15:55:00+03	2017-07-29 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-29 16:00:00+03	2017-07-29 16:55:00+03
25578	PG0606	2017-09-11 15:55:00+03	2017-09-11 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25579	PG0606	2017-09-07 15:55:00+03	2017-09-07 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25580	PG0606	2017-08-19 15:55:00+03	2017-08-19 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25581	PG0606	2017-07-22 15:55:00+03	2017-07-22 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-22 15:58:00+03	2017-07-22 16:53:00+03
25582	PG0606	2017-07-25 15:55:00+03	2017-07-25 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-25 15:56:00+03	2017-07-25 16:51:00+03
25583	PG0606	2017-09-02 15:55:00+03	2017-09-02 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25584	PG0606	2017-08-29 15:55:00+03	2017-08-29 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25585	PG0606	2017-08-08 15:55:00+03	2017-08-08 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-08 18:57:00+03	2017-08-08 19:52:00+03
25586	PG0606	2017-08-07 15:55:00+03	2017-08-07 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-07 15:59:00+03	2017-08-07 16:54:00+03
25587	PG0606	2017-09-09 15:55:00+03	2017-09-09 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25588	PG0606	2017-08-04 15:55:00+03	2017-08-04 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-04 15:58:00+03	2017-08-04 16:52:00+03
25589	PG0606	2017-09-04 15:55:00+03	2017-09-04 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25590	PG0606	2017-08-17 15:55:00+03	2017-08-17 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25591	PG0606	2017-07-16 15:55:00+03	2017-07-16 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-16 15:56:00+03	2017-07-16 16:51:00+03
25592	PG0606	2017-09-12 15:55:00+03	2017-09-12 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25593	PG0606	2017-08-15 15:55:00+03	2017-08-15 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-15 15:59:00+03	2017-08-15 16:54:00+03
25594	PG0606	2017-09-10 15:55:00+03	2017-09-10 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25595	PG0606	2017-07-26 15:55:00+03	2017-07-26 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-26 15:58:00+03	2017-07-26 16:53:00+03
25596	PG0606	2017-09-05 15:55:00+03	2017-09-05 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25597	PG0606	2017-08-02 15:55:00+03	2017-08-02 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-02 15:56:00+03	2017-08-02 16:51:00+03
25598	PG0606	2017-08-20 15:55:00+03	2017-08-20 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25599	PG0606	2017-09-13 15:55:00+03	2017-09-13 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25600	PG0606	2017-08-27 15:55:00+03	2017-08-27 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25601	PG0606	2017-07-30 15:55:00+03	2017-07-30 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-30 15:55:00+03	2017-07-30 16:49:00+03
25602	PG0606	2017-08-31 15:55:00+03	2017-08-31 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25603	PG0606	2017-08-23 15:55:00+03	2017-08-23 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25604	PG0606	2017-08-09 15:55:00+03	2017-08-09 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-09 15:57:00+03	2017-08-09 16:53:00+03
25605	PG0606	2017-08-14 15:55:00+03	2017-08-14 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-14 16:00:00+03	2017-08-14 16:55:00+03
25606	PG0606	2017-08-24 15:55:00+03	2017-08-24 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25607	PG0606	2017-08-21 15:55:00+03	2017-08-21 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25608	PG0606	2017-07-27 15:55:00+03	2017-07-27 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-27 15:59:00+03	2017-07-27 16:54:00+03
25609	PG0606	2017-07-23 15:55:00+03	2017-07-23 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-23 15:58:00+03	2017-07-23 16:53:00+03
25610	PG0606	2017-07-19 15:55:00+03	2017-07-19 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-19 15:57:00+03	2017-07-19 16:52:00+03
25611	PG0606	2017-07-24 15:55:00+03	2017-07-24 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-24 15:57:00+03	2017-07-24 16:52:00+03
25612	PG0606	2017-07-20 15:55:00+03	2017-07-20 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-20 15:58:00+03	2017-07-20 16:53:00+03
25613	PG0606	2017-08-28 15:55:00+03	2017-08-28 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25614	PG0606	2017-08-25 15:55:00+03	2017-08-25 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25615	PG0606	2017-07-18 15:55:00+03	2017-07-18 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-18 15:55:00+03	2017-07-18 16:50:00+03
25616	PG0606	2017-08-30 15:55:00+03	2017-08-30 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25617	PG0606	2017-09-08 15:55:00+03	2017-09-08 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25618	PG0606	2017-08-01 15:55:00+03	2017-08-01 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-01 15:58:00+03	2017-08-01 16:54:00+03
25619	PG0606	2017-07-17 15:55:00+03	2017-07-17 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-17 16:00:00+03	2017-07-17 16:55:00+03
25620	PG0606	2017-09-03 15:55:00+03	2017-09-03 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25621	PG0606	2017-09-06 15:55:00+03	2017-09-06 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25622	PG0606	2017-08-16 15:55:00+03	2017-08-16 16:50:00+03	ULV	DME	On Time	SU9	\N	\N
25623	PG0606	2017-08-03 15:55:00+03	2017-08-03 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-03 16:00:00+03	2017-08-03 16:55:00+03
25624	PG0606	2017-07-21 15:55:00+03	2017-07-21 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-21 15:57:00+03	2017-07-21 16:51:00+03
25625	PG0606	2017-09-01 15:55:00+03	2017-09-01 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25626	PG0606	2017-07-28 15:55:00+03	2017-07-28 16:50:00+03	ULV	DME	Arrived	SU9	2017-07-28 15:59:00+03	2017-07-28 16:53:00+03
25627	PG0606	2017-08-22 15:55:00+03	2017-08-22 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25628	PG0606	2017-08-18 15:55:00+03	2017-08-18 16:50:00+03	ULV	DME	Scheduled	SU9	\N	\N
25629	PG0606	2017-08-10 15:55:00+03	2017-08-10 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-10 15:55:00+03	2017-08-10 16:50:00+03
25630	PG0606	2017-08-12 15:55:00+03	2017-08-12 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-12 15:56:00+03	2017-08-12 16:51:00+03
25631	PG0606	2017-08-13 15:55:00+03	2017-08-13 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-13 15:56:00+03	2017-08-13 16:51:00+03
25632	PG0606	2017-08-05 15:55:00+03	2017-08-05 16:50:00+03	ULV	DME	Arrived	SU9	2017-08-05 15:57:00+03	2017-08-05 16:51:00+03
25633	PG0606	2017-09-14 15:55:00+03	2017-09-14 16:50:00+03	ULV	DME	Cancelled	SU9	\N	\N
25634	PG0107	2017-07-23 19:55:00+03	2017-07-23 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-23 19:58:00+03	2017-07-23 20:53:00+03
25635	PG0107	2017-07-19 19:55:00+03	2017-07-19 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-19 20:00:00+03	2017-07-19 20:55:00+03
25636	PG0107	2017-09-07 19:55:00+03	2017-09-07 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25637	PG0107	2017-08-15 19:55:00+03	2017-08-15 20:50:00+03	ULV	VKO	On Time	SU9	\N	\N
25638	PG0107	2017-09-09 19:55:00+03	2017-09-09 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25639	PG0107	2017-08-19 19:55:00+03	2017-08-19 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25640	PG0107	2017-09-06 19:55:00+03	2017-09-06 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25641	PG0107	2017-08-13 19:55:00+03	2017-08-13 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-13 19:58:00+03	2017-08-13 20:52:00+03
25642	PG0107	2017-07-31 19:55:00+03	2017-07-31 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-31 19:59:00+03	2017-07-31 20:54:00+03
25643	PG0107	2017-09-10 19:55:00+03	2017-09-10 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25644	PG0107	2017-09-05 19:55:00+03	2017-09-05 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25645	PG0107	2017-09-13 19:55:00+03	2017-09-13 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25646	PG0107	2017-08-23 19:55:00+03	2017-08-23 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25647	PG0107	2017-07-21 19:55:00+03	2017-07-21 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-21 19:59:00+03	2017-07-21 20:54:00+03
25648	PG0107	2017-07-30 19:55:00+03	2017-07-30 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-30 19:57:00+03	2017-07-30 20:52:00+03
25649	PG0107	2017-08-06 19:55:00+03	2017-08-06 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-06 20:00:00+03	2017-08-06 20:56:00+03
25650	PG0107	2017-08-22 19:55:00+03	2017-08-22 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25651	PG0107	2017-07-25 19:55:00+03	2017-07-25 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-25 19:55:00+03	2017-07-25 20:49:00+03
25652	PG0107	2017-08-07 19:55:00+03	2017-08-07 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-07 19:56:00+03	2017-08-07 20:51:00+03
25653	PG0107	2017-08-10 19:55:00+03	2017-08-10 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-10 20:03:00+03	2017-08-10 20:58:00+03
25654	PG0107	2017-07-16 19:55:00+03	2017-07-16 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-16 19:59:00+03	2017-07-16 20:55:00+03
25655	PG0107	2017-09-14 19:55:00+03	2017-09-14 20:50:00+03	ULV	VKO	Cancelled	SU9	\N	\N
25656	PG0107	2017-08-21 19:55:00+03	2017-08-21 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25657	PG0107	2017-07-17 19:55:00+03	2017-07-17 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-17 19:58:00+03	2017-07-17 20:53:00+03
25658	PG0107	2017-07-26 19:55:00+03	2017-07-26 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-26 19:57:00+03	2017-07-26 20:52:00+03
25659	PG0107	2017-08-24 19:55:00+03	2017-08-24 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25660	PG0107	2017-08-31 19:55:00+03	2017-08-31 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25661	PG0107	2017-08-02 19:55:00+03	2017-08-02 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-02 19:57:00+03	2017-08-02 20:53:00+03
25662	PG0107	2017-09-03 19:55:00+03	2017-09-03 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25663	PG0107	2017-08-27 19:55:00+03	2017-08-27 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25664	PG0107	2017-07-29 19:55:00+03	2017-07-29 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-29 19:58:00+03	2017-07-29 20:53:00+03
25665	PG0107	2017-08-16 19:55:00+03	2017-08-16 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25666	PG0107	2017-08-09 19:55:00+03	2017-08-09 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-09 19:55:00+03	2017-08-09 20:50:00+03
25667	PG0107	2017-07-22 19:55:00+03	2017-07-22 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-22 19:59:00+03	2017-07-22 20:53:00+03
25668	PG0107	2017-08-03 19:55:00+03	2017-08-03 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-03 23:14:00+03	2017-08-04 00:09:00+03
25669	PG0107	2017-08-30 19:55:00+03	2017-08-30 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25670	PG0107	2017-08-12 19:55:00+03	2017-08-12 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-12 19:57:00+03	2017-08-12 20:52:00+03
25671	PG0107	2017-09-02 19:55:00+03	2017-09-02 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25672	PG0107	2017-09-01 19:55:00+03	2017-09-01 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25673	PG0107	2017-08-20 19:55:00+03	2017-08-20 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25674	PG0107	2017-08-29 19:55:00+03	2017-08-29 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25675	PG0107	2017-09-11 19:55:00+03	2017-09-11 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25676	PG0107	2017-08-01 19:55:00+03	2017-08-01 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-01 19:57:00+03	2017-08-01 20:52:00+03
25677	PG0107	2017-07-18 19:55:00+03	2017-07-18 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-18 19:58:00+03	2017-07-18 20:53:00+03
25678	PG0107	2017-07-28 19:55:00+03	2017-07-28 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-28 19:58:00+03	2017-07-28 20:53:00+03
25679	PG0107	2017-08-28 19:55:00+03	2017-08-28 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25680	PG0107	2017-09-12 19:55:00+03	2017-09-12 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25681	PG0107	2017-08-08 19:55:00+03	2017-08-08 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-08 19:58:00+03	2017-08-08 20:53:00+03
25682	PG0107	2017-08-25 19:55:00+03	2017-08-25 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25683	PG0107	2017-07-24 19:55:00+03	2017-07-24 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-24 19:59:00+03	2017-07-24 20:55:00+03
25684	PG0107	2017-08-04 19:55:00+03	2017-08-04 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-04 19:56:00+03	2017-08-04 20:52:00+03
25685	PG0107	2017-08-17 19:55:00+03	2017-08-17 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25686	PG0107	2017-09-04 19:55:00+03	2017-09-04 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25687	PG0107	2017-08-11 19:55:00+03	2017-08-11 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-11 20:01:00+03	2017-08-11 20:56:00+03
25688	PG0107	2017-09-08 19:55:00+03	2017-09-08 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25689	PG0107	2017-08-14 19:55:00+03	2017-08-14 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-14 20:00:00+03	2017-08-14 20:55:00+03
25690	PG0107	2017-08-18 19:55:00+03	2017-08-18 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25691	PG0107	2017-08-05 19:55:00+03	2017-08-05 20:50:00+03	ULV	VKO	Arrived	SU9	2017-08-05 19:58:00+03	2017-08-05 20:52:00+03
25692	PG0107	2017-07-20 19:55:00+03	2017-07-20 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-20 19:58:00+03	2017-07-20 20:53:00+03
25693	PG0107	2017-07-27 19:55:00+03	2017-07-27 20:50:00+03	ULV	VKO	Arrived	SU9	2017-07-27 19:59:00+03	2017-07-27 20:54:00+03
25694	PG0107	2017-08-26 19:55:00+03	2017-08-26 20:50:00+03	ULV	VKO	Scheduled	SU9	\N	\N
25695	PG0462	2017-08-10 12:45:00+03	2017-08-10 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-10 12:48:00+03	2017-08-10 13:42:00+03
25696	PG0462	2017-08-26 12:45:00+03	2017-08-26 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25697	PG0462	2017-07-18 12:45:00+03	2017-07-18 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-18 12:47:00+03	2017-07-18 13:42:00+03
25698	PG0462	2017-08-12 12:45:00+03	2017-08-12 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-12 12:47:00+03	2017-08-12 13:42:00+03
25699	PG0463	2017-08-12 13:15:00+03	2017-08-12 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-12 13:20:00+03	2017-08-12 14:15:00+03
25700	PG0462	2017-09-07 12:45:00+03	2017-09-07 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25701	PG0463	2017-09-07 13:15:00+03	2017-09-07 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25702	PG0463	2017-09-11 13:15:00+03	2017-09-11 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25703	PG0462	2017-09-11 12:45:00+03	2017-09-11 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25704	PG0462	2017-08-19 12:45:00+03	2017-08-19 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25705	PG0463	2017-08-19 13:15:00+03	2017-08-19 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25706	PG0463	2017-08-22 13:15:00+03	2017-08-22 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25707	PG0462	2017-08-22 12:45:00+03	2017-08-22 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25708	PG0462	2017-07-31 12:45:00+03	2017-07-31 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-31 12:51:00+03	2017-07-31 13:45:00+03
25709	PG0463	2017-07-31 13:15:00+03	2017-07-31 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-31 13:21:00+03	2017-07-31 14:16:00+03
25710	PG0463	2017-07-18 13:15:00+03	2017-07-18 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-18 13:18:00+03	2017-07-18 14:13:00+03
25711	PG0463	2017-08-11 13:15:00+03	2017-08-11 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-11 13:18:00+03	2017-08-11 14:13:00+03
25712	PG0462	2017-08-11 12:45:00+03	2017-08-11 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-11 12:48:00+03	2017-08-11 13:42:00+03
25713	PG0463	2017-08-31 13:15:00+03	2017-08-31 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25714	PG0462	2017-08-31 12:45:00+03	2017-08-31 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25715	PG0463	2017-09-13 13:15:00+03	2017-09-13 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25716	PG0462	2017-09-13 12:45:00+03	2017-09-13 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25717	PG0463	2017-07-29 13:15:00+03	2017-07-29 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-29 13:19:00+03	2017-07-29 14:14:00+03
25718	PG0462	2017-07-29 12:45:00+03	2017-07-29 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-29 12:47:00+03	2017-07-29 13:42:00+03
25719	PG0462	2017-08-28 12:45:00+03	2017-08-28 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25720	PG0463	2017-08-28 13:15:00+03	2017-08-28 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25721	PG0462	2017-09-01 12:45:00+03	2017-09-01 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25722	PG0463	2017-09-01 13:15:00+03	2017-09-01 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25723	PG0462	2017-08-13 12:45:00+03	2017-08-13 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-13 12:47:00+03	2017-08-13 13:42:00+03
25724	PG0463	2017-08-13 13:15:00+03	2017-08-13 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-13 13:18:00+03	2017-08-13 14:13:00+03
25725	PG0463	2017-09-06 13:15:00+03	2017-09-06 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25726	PG0462	2017-09-06 12:45:00+03	2017-09-06 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25727	PG0463	2017-08-05 13:15:00+03	2017-08-05 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-05 13:17:00+03	2017-08-05 14:12:00+03
25728	PG0462	2017-08-05 12:45:00+03	2017-08-05 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-05 12:51:00+03	2017-08-05 13:46:00+03
25729	PG0463	2017-08-10 13:15:00+03	2017-08-10 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-10 13:17:00+03	2017-08-10 14:12:00+03
25730	PG0462	2017-07-23 12:45:00+03	2017-07-23 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-23 12:47:00+03	2017-07-23 13:42:00+03
25731	PG0463	2017-08-06 13:15:00+03	2017-08-06 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-06 13:18:00+03	2017-08-06 14:14:00+03
25732	PG0463	2017-07-28 13:15:00+03	2017-07-28 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-28 13:17:00+03	2017-07-28 14:12:00+03
25733	PG0462	2017-08-06 12:45:00+03	2017-08-06 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-06 12:50:00+03	2017-08-06 13:45:00+03
25734	PG0462	2017-08-01 12:45:00+03	2017-08-01 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-01 12:48:00+03	2017-08-01 13:43:00+03
25735	PG0463	2017-08-01 13:15:00+03	2017-08-01 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-01 13:17:00+03	2017-08-01 14:13:00+03
25736	PG0462	2017-07-28 12:45:00+03	2017-07-28 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-28 12:47:00+03	2017-07-28 13:42:00+03
25737	PG0463	2017-08-18 13:15:00+03	2017-08-18 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25738	PG0462	2017-09-08 12:45:00+03	2017-09-08 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25739	PG0463	2017-09-08 13:15:00+03	2017-09-08 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25740	PG0462	2017-08-18 12:45:00+03	2017-08-18 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25741	PG0463	2017-07-23 13:15:00+03	2017-07-23 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-23 13:18:00+03	2017-07-23 14:13:00+03
25742	PG0462	2017-07-19 12:45:00+03	2017-07-19 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-19 12:48:00+03	2017-07-19 13:42:00+03
25743	PG0463	2017-07-19 13:15:00+03	2017-07-19 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-19 13:19:00+03	2017-07-19 14:15:00+03
25744	PG0463	2017-09-03 13:15:00+03	2017-09-03 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25745	PG0462	2017-09-03 12:45:00+03	2017-09-03 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25746	PG0462	2017-09-14 12:45:00+03	2017-09-14 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25747	PG0462	2017-08-23 12:45:00+03	2017-08-23 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25748	PG0463	2017-08-23 13:15:00+03	2017-08-23 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25749	PG0463	2017-09-14 13:15:00+03	2017-09-14 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25750	PG0462	2017-08-14 12:45:00+03	2017-08-14 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-14 12:47:00+03	2017-08-14 13:43:00+03
25751	PG0463	2017-08-14 13:15:00+03	2017-08-14 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-14 13:21:00+03	2017-08-14 14:16:00+03
25752	PG0463	2017-07-30 13:15:00+03	2017-07-30 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-30 13:16:00+03	2017-07-30 14:12:00+03
25753	PG0462	2017-07-30 12:45:00+03	2017-07-30 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-30 12:47:00+03	2017-07-30 13:42:00+03
25754	PG0462	2017-07-22 12:45:00+03	2017-07-22 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-22 12:48:00+03	2017-07-22 13:43:00+03
25755	PG0463	2017-07-21 13:15:00+03	2017-07-21 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-21 13:18:00+03	2017-07-21 14:13:00+03
25756	PG0463	2017-07-27 13:15:00+03	2017-07-27 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-27 13:16:00+03	2017-07-27 14:11:00+03
25757	PG0463	2017-07-17 13:15:00+03	2017-07-17 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-17 13:18:00+03	2017-07-17 14:13:00+03
25758	PG0462	2017-07-17 12:45:00+03	2017-07-17 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-17 12:48:00+03	2017-07-17 13:42:00+03
25759	PG0463	2017-08-30 13:15:00+03	2017-08-30 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25760	PG0462	2017-09-04 12:45:00+03	2017-09-04 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25761	PG0462	2017-08-30 12:45:00+03	2017-08-30 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25762	PG0463	2017-09-04 13:15:00+03	2017-09-04 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25763	PG0462	2017-07-27 12:45:00+03	2017-07-27 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-27 12:47:00+03	2017-07-27 13:42:00+03
25764	PG0462	2017-07-21 12:45:00+03	2017-07-21 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-21 12:52:00+03	2017-07-21 13:47:00+03
25765	PG0462	2017-08-02 12:45:00+03	2017-08-02 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-02 15:51:00+03	2017-08-02 16:45:00+03
25766	PG0463	2017-08-02 13:15:00+03	2017-08-02 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-02 13:20:00+03	2017-08-02 14:15:00+03
25767	PG0463	2017-08-21 13:15:00+03	2017-08-21 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25768	PG0462	2017-08-21 12:45:00+03	2017-08-21 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25769	PG0463	2017-08-09 13:15:00+03	2017-08-09 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-09 13:17:00+03	2017-08-09 14:12:00+03
25770	PG0462	2017-08-09 12:45:00+03	2017-08-09 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-09 16:03:00+03	2017-08-09 16:57:00+03
25771	PG0462	2017-08-07 12:45:00+03	2017-08-07 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-07 12:50:00+03	2017-08-07 13:46:00+03
25772	PG0463	2017-08-07 13:15:00+03	2017-08-07 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-07 13:15:00+03	2017-08-07 14:10:00+03
25773	PG0462	2017-08-15 12:45:00+03	2017-08-15 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-15 12:51:00+03	2017-08-15 13:46:00+03
25774	PG0463	2017-08-15 13:15:00+03	2017-08-15 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-15 13:18:00+03	2017-08-15 14:13:00+03
25775	PG0462	2017-08-25 12:45:00+03	2017-08-25 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25776	PG0463	2017-08-25 13:15:00+03	2017-08-25 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25777	PG0463	2017-07-26 13:15:00+03	2017-07-26 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-26 13:19:00+03	2017-07-26 14:14:00+03
25778	PG0462	2017-07-26 12:45:00+03	2017-07-26 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-26 12:48:00+03	2017-07-26 13:42:00+03
25779	PG0462	2017-09-09 12:45:00+03	2017-09-09 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25780	PG0463	2017-09-09 13:15:00+03	2017-09-09 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25781	PG0462	2017-09-02 12:45:00+03	2017-09-02 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25782	PG0463	2017-09-02 13:15:00+03	2017-09-02 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25783	PG0463	2017-07-22 13:15:00+03	2017-07-22 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-22 13:18:00+03	2017-07-22 14:13:00+03
25784	PG0462	2017-07-16 12:45:00+03	2017-07-16 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-16 12:50:00+03	2017-07-16 13:46:00+03
25785	PG0463	2017-07-16 13:15:00+03	2017-07-16 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-16 17:04:00+03	2017-07-16 17:58:00+03
25786	PG0463	2017-09-05 13:15:00+03	2017-09-05 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25787	PG0462	2017-09-05 12:45:00+03	2017-09-05 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25788	PG0463	2017-08-24 13:15:00+03	2017-08-24 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25789	PG0462	2017-08-24 12:45:00+03	2017-08-24 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25790	PG0462	2017-07-24 12:45:00+03	2017-07-24 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-24 12:45:00+03	2017-07-24 13:39:00+03
25791	PG0463	2017-07-24 13:15:00+03	2017-07-24 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-24 13:17:00+03	2017-07-24 14:13:00+03
25792	PG0463	2017-08-26 13:15:00+03	2017-08-26 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25793	PG0462	2017-08-20 12:45:00+03	2017-08-20 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25794	PG0462	2017-07-20 12:45:00+03	2017-07-20 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-20 12:47:00+03	2017-07-20 13:41:00+03
25795	PG0463	2017-07-20 13:15:00+03	2017-07-20 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-20 13:15:00+03	2017-07-20 14:10:00+03
25796	PG0463	2017-08-17 13:15:00+03	2017-08-17 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25797	PG0462	2017-08-17 12:45:00+03	2017-08-17 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25798	PG0462	2017-08-03 12:45:00+03	2017-08-03 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-03 12:49:00+03	2017-08-03 13:44:00+03
25799	PG0463	2017-08-03 13:15:00+03	2017-08-03 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-03 16:12:00+03	2017-08-03 17:07:00+03
25800	PG0463	2017-08-20 13:15:00+03	2017-08-20 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25801	PG0462	2017-08-16 12:45:00+03	2017-08-16 13:40:00+03	ULV	SVO	On Time	SU9	\N	\N
25802	PG0463	2017-08-16 13:15:00+03	2017-08-16 14:10:00+03	ULV	SVO	Delayed	SU9	\N	\N
25803	PG0463	2017-09-10 13:15:00+03	2017-09-10 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25804	PG0462	2017-09-10 12:45:00+03	2017-09-10 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25805	PG0463	2017-09-12 13:15:00+03	2017-09-12 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25806	PG0462	2017-09-12 12:45:00+03	2017-09-12 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25807	PG0463	2017-07-25 13:15:00+03	2017-07-25 14:10:00+03	ULV	SVO	Arrived	SU9	2017-07-25 13:16:00+03	2017-07-25 14:12:00+03
25808	PG0462	2017-07-25 12:45:00+03	2017-07-25 13:40:00+03	ULV	SVO	Arrived	SU9	2017-07-25 12:47:00+03	2017-07-25 13:42:00+03
25809	PG0463	2017-08-08 13:15:00+03	2017-08-08 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-08 16:35:00+03	2017-08-08 17:30:00+03
25810	PG0462	2017-08-08 12:45:00+03	2017-08-08 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-08 12:48:00+03	2017-08-08 13:44:00+03
25811	PG0463	2017-08-29 13:15:00+03	2017-08-29 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25812	PG0462	2017-08-29 12:45:00+03	2017-08-29 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25813	PG0463	2017-08-04 13:15:00+03	2017-08-04 14:10:00+03	ULV	SVO	Arrived	SU9	2017-08-04 13:18:00+03	2017-08-04 14:13:00+03
25814	PG0462	2017-08-04 12:45:00+03	2017-08-04 13:40:00+03	ULV	SVO	Arrived	SU9	2017-08-04 16:12:00+03	2017-08-04 17:07:00+03
25815	PG0462	2017-08-27 12:45:00+03	2017-08-27 13:40:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25816	PG0463	2017-08-27 13:15:00+03	2017-08-27 14:10:00+03	ULV	SVO	Scheduled	SU9	\N	\N
25817	PG0684	2017-08-09 14:15:00+03	2017-08-09 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-09 14:16:00+03	2017-08-09 15:05:00+03
25818	PG0684	2017-08-18 14:15:00+03	2017-08-18 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25819	PG0684	2017-08-16 14:15:00+03	2017-08-16 15:05:00+03	ULV	PEE	On Time	SU9	\N	\N
25820	PG0684	2017-09-14 14:15:00+03	2017-09-14 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25821	PG0684	2017-07-19 14:15:00+03	2017-07-19 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-19 17:23:00+03	2017-07-19 18:13:00+03
25822	PG0684	2017-07-18 14:15:00+03	2017-07-18 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-18 14:16:00+03	2017-07-18 15:06:00+03
25823	PG0684	2017-09-10 14:15:00+03	2017-09-10 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25824	PG0684	2017-07-20 14:15:00+03	2017-07-20 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-20 14:17:00+03	2017-07-20 15:07:00+03
25825	PG0684	2017-08-13 14:15:00+03	2017-08-13 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-13 14:16:00+03	2017-08-13 15:07:00+03
25826	PG0684	2017-09-12 14:15:00+03	2017-09-12 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25827	PG0684	2017-08-27 14:15:00+03	2017-08-27 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25828	PG0684	2017-09-05 14:15:00+03	2017-09-05 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25829	PG0684	2017-08-17 14:15:00+03	2017-08-17 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25830	PG0684	2017-08-05 14:15:00+03	2017-08-05 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-05 14:16:00+03	2017-08-05 15:06:00+03
25831	PG0684	2017-08-08 14:15:00+03	2017-08-08 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-08 14:17:00+03	2017-08-08 15:07:00+03
25832	PG0684	2017-08-25 14:15:00+03	2017-08-25 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25833	PG0684	2017-08-14 14:15:00+03	2017-08-14 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-14 14:19:00+03	2017-08-14 15:09:00+03
25834	PG0684	2017-09-03 14:15:00+03	2017-09-03 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25835	PG0684	2017-08-26 14:15:00+03	2017-08-26 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25836	PG0684	2017-07-21 14:15:00+03	2017-07-21 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-21 14:20:00+03	2017-07-21 15:10:00+03
25837	PG0684	2017-08-23 14:15:00+03	2017-08-23 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25838	PG0684	2017-07-31 14:15:00+03	2017-07-31 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-31 14:21:00+03	2017-07-31 15:10:00+03
25839	PG0684	2017-07-28 14:15:00+03	2017-07-28 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-28 14:19:00+03	2017-07-28 15:09:00+03
25840	PG0684	2017-07-30 14:15:00+03	2017-07-30 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-30 14:15:00+03	2017-07-30 15:04:00+03
25841	PG0684	2017-07-22 14:15:00+03	2017-07-22 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-22 14:17:00+03	2017-07-22 15:08:00+03
25842	PG0684	2017-08-29 14:15:00+03	2017-08-29 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25843	PG0684	2017-07-16 14:15:00+03	2017-07-16 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-16 14:17:00+03	2017-07-16 15:07:00+03
25844	PG0684	2017-08-20 14:15:00+03	2017-08-20 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25845	PG0684	2017-08-12 14:15:00+03	2017-08-12 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-12 14:17:00+03	2017-08-12 15:06:00+03
25846	PG0684	2017-08-11 14:15:00+03	2017-08-11 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-11 14:17:00+03	2017-08-11 15:07:00+03
25847	PG0684	2017-09-06 14:15:00+03	2017-09-06 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25848	PG0684	2017-08-21 14:15:00+03	2017-08-21 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25849	PG0684	2017-08-19 14:15:00+03	2017-08-19 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25850	PG0684	2017-08-31 14:15:00+03	2017-08-31 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25851	PG0684	2017-09-11 14:15:00+03	2017-09-11 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25852	PG0684	2017-08-01 14:15:00+03	2017-08-01 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-01 14:18:00+03	2017-08-01 15:08:00+03
25853	PG0684	2017-07-26 14:15:00+03	2017-07-26 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-26 14:20:00+03	2017-07-26 15:10:00+03
25854	PG0684	2017-09-04 14:15:00+03	2017-09-04 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25855	PG0684	2017-08-28 14:15:00+03	2017-08-28 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25856	PG0684	2017-09-08 14:15:00+03	2017-09-08 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25857	PG0684	2017-09-01 14:15:00+03	2017-09-01 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25858	PG0684	2017-08-22 14:15:00+03	2017-08-22 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25859	PG0684	2017-07-17 14:15:00+03	2017-07-17 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-17 17:24:00+03	2017-07-17 18:15:00+03
25860	PG0684	2017-08-03 14:15:00+03	2017-08-03 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-03 14:16:00+03	2017-08-03 15:06:00+03
25861	PG0684	2017-08-30 14:15:00+03	2017-08-30 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25862	PG0684	2017-09-02 14:15:00+03	2017-09-02 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25863	PG0684	2017-07-27 14:15:00+03	2017-07-27 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-27 14:16:00+03	2017-07-27 15:06:00+03
25864	PG0684	2017-08-02 14:15:00+03	2017-08-02 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-02 14:19:00+03	2017-08-02 15:09:00+03
25865	PG0684	2017-08-10 14:15:00+03	2017-08-10 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-10 14:18:00+03	2017-08-10 15:09:00+03
25866	PG0684	2017-08-24 14:15:00+03	2017-08-24 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25867	PG0684	2017-07-29 14:15:00+03	2017-07-29 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-29 14:18:00+03	2017-07-29 15:08:00+03
25868	PG0684	2017-08-04 14:15:00+03	2017-08-04 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-04 14:18:00+03	2017-08-04 15:09:00+03
25869	PG0684	2017-08-07 14:15:00+03	2017-08-07 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-07 14:16:00+03	2017-08-07 15:06:00+03
25870	PG0684	2017-07-25 14:15:00+03	2017-07-25 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-25 14:16:00+03	2017-07-25 15:06:00+03
25871	PG0684	2017-09-09 14:15:00+03	2017-09-09 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25872	PG0684	2017-08-15 14:15:00+03	2017-08-15 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-15 14:18:00+03	2017-08-15 15:07:00+03
25873	PG0684	2017-07-24 14:15:00+03	2017-07-24 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-24 14:16:00+03	2017-07-24 15:06:00+03
25874	PG0684	2017-09-13 14:15:00+03	2017-09-13 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25875	PG0684	2017-09-07 14:15:00+03	2017-09-07 15:05:00+03	ULV	PEE	Scheduled	SU9	\N	\N
25876	PG0684	2017-07-23 14:15:00+03	2017-07-23 15:05:00+03	ULV	PEE	Arrived	SU9	2017-07-23 14:16:00+03	2017-07-23 15:06:00+03
25877	PG0684	2017-08-06 14:15:00+03	2017-08-06 15:05:00+03	ULV	PEE	Arrived	SU9	2017-08-06 14:17:00+03	2017-08-06 15:06:00+03
25878	PG0373	2017-07-27 10:50:00+03	2017-07-27 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-27 10:53:00+03	2017-07-27 13:28:00+03
25879	PG0373	2017-07-25 10:50:00+03	2017-07-25 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-25 10:53:00+03	2017-07-25 13:29:00+03
25880	PG0373	2017-09-07 10:50:00+03	2017-09-07 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25881	PG0373	2017-07-29 10:50:00+03	2017-07-29 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-29 10:51:00+03	2017-07-29 13:24:00+03
25882	PG0373	2017-07-20 10:50:00+03	2017-07-20 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-20 10:53:00+03	2017-07-20 13:30:00+03
25883	PG0373	2017-08-01 10:50:00+03	2017-08-01 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-01 10:52:00+03	2017-08-01 13:26:00+03
25884	PG0373	2017-08-19 10:50:00+03	2017-08-19 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25885	PG0373	2017-08-08 10:50:00+03	2017-08-08 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-08 10:54:00+03	2017-08-08 13:28:00+03
25886	PG0373	2017-08-31 10:50:00+03	2017-08-31 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25887	PG0373	2017-08-10 10:50:00+03	2017-08-10 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-10 10:54:00+03	2017-08-10 13:29:00+03
25888	PG0373	2017-07-22 10:50:00+03	2017-07-22 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-22 10:52:00+03	2017-07-22 13:27:00+03
25889	PG0373	2017-07-18 10:50:00+03	2017-07-18 13:25:00+03	ULV	OSW	Arrived	CN1	2017-07-18 10:51:00+03	2017-07-18 13:25:00+03
25890	PG0373	2017-08-17 10:50:00+03	2017-08-17 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25891	PG0373	2017-08-24 10:50:00+03	2017-08-24 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25892	PG0373	2017-08-15 10:50:00+03	2017-08-15 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-15 10:52:00+03	2017-08-15 13:28:00+03
25893	PG0373	2017-08-12 10:50:00+03	2017-08-12 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-12 10:55:00+03	2017-08-12 13:27:00+03
25894	PG0373	2017-08-26 10:50:00+03	2017-08-26 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25895	PG0373	2017-08-29 10:50:00+03	2017-08-29 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25896	PG0373	2017-08-03 10:50:00+03	2017-08-03 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-03 10:55:00+03	2017-08-03 13:29:00+03
25897	PG0373	2017-09-14 10:50:00+03	2017-09-14 13:25:00+03	ULV	OSW	Cancelled	CN1	\N	\N
25898	PG0373	2017-09-05 10:50:00+03	2017-09-05 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25899	PG0373	2017-08-22 10:50:00+03	2017-08-22 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25900	PG0373	2017-08-05 10:50:00+03	2017-08-05 13:25:00+03	ULV	OSW	Arrived	CN1	2017-08-05 10:51:00+03	2017-08-05 13:24:00+03
25901	PG0373	2017-09-12 10:50:00+03	2017-09-12 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25902	PG0373	2017-09-02 10:50:00+03	2017-09-02 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25903	PG0373	2017-09-09 10:50:00+03	2017-09-09 13:25:00+03	ULV	OSW	Scheduled	CN1	\N	\N
25904	PG0365	2017-09-06 15:05:00+03	2017-09-06 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25905	PG0365	2017-08-24 15:05:00+03	2017-08-24 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25906	PG0365	2017-08-17 15:05:00+03	2017-08-17 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25907	PG0365	2017-08-14 15:05:00+03	2017-08-14 16:40:00+03	ULV	KRR	Arrived	763	2017-08-14 15:05:00+03	2017-08-14 16:39:00+03
25908	PG0365	2017-08-05 15:05:00+03	2017-08-05 16:40:00+03	ULV	KRR	Arrived	763	2017-08-05 15:06:00+03	2017-08-05 16:41:00+03
25909	PG0365	2017-09-07 15:05:00+03	2017-09-07 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25910	PG0365	2017-07-18 15:05:00+03	2017-07-18 16:40:00+03	ULV	KRR	Arrived	763	2017-07-18 15:05:00+03	2017-07-18 16:41:00+03
25911	PG0365	2017-09-12 15:05:00+03	2017-09-12 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25912	PG0365	2017-08-31 15:05:00+03	2017-08-31 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25913	PG0365	2017-08-18 15:05:00+03	2017-08-18 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25914	PG0365	2017-08-25 15:05:00+03	2017-08-25 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25915	PG0365	2017-09-10 15:05:00+03	2017-09-10 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25916	PG0365	2017-08-16 15:05:00+03	2017-08-16 16:40:00+03	ULV	KRR	On Time	763	\N	\N
25917	PG0365	2017-09-05 15:05:00+03	2017-09-05 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25918	PG0365	2017-08-03 15:05:00+03	2017-08-03 16:40:00+03	ULV	KRR	Arrived	763	2017-08-03 15:08:00+03	2017-08-03 16:44:00+03
25919	PG0365	2017-08-27 15:05:00+03	2017-08-27 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25920	PG0365	2017-08-06 15:05:00+03	2017-08-06 16:40:00+03	ULV	KRR	Arrived	763	2017-08-06 15:08:00+03	2017-08-06 16:44:00+03
25921	PG0365	2017-08-08 15:05:00+03	2017-08-08 16:40:00+03	ULV	KRR	Arrived	763	2017-08-08 15:06:00+03	2017-08-08 16:39:00+03
25922	PG0365	2017-07-31 15:05:00+03	2017-07-31 16:40:00+03	ULV	KRR	Arrived	763	2017-07-31 15:11:00+03	2017-07-31 16:47:00+03
25923	PG0365	2017-08-19 15:05:00+03	2017-08-19 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25924	PG0365	2017-08-26 15:05:00+03	2017-08-26 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25925	PG0365	2017-07-22 15:05:00+03	2017-07-22 16:40:00+03	ULV	KRR	Arrived	763	2017-07-22 15:09:00+03	2017-07-22 16:42:00+03
25926	PG0365	2017-07-24 15:05:00+03	2017-07-24 16:40:00+03	ULV	KRR	Arrived	763	2017-07-24 15:09:00+03	2017-07-24 16:43:00+03
25927	PG0365	2017-07-20 15:05:00+03	2017-07-20 16:40:00+03	ULV	KRR	Arrived	763	2017-07-20 15:06:00+03	2017-07-20 16:41:00+03
25928	PG0365	2017-08-29 15:05:00+03	2017-08-29 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25929	PG0365	2017-07-23 15:05:00+03	2017-07-23 16:40:00+03	ULV	KRR	Arrived	763	2017-07-23 15:12:00+03	2017-07-23 16:47:00+03
25930	PG0365	2017-07-26 15:05:00+03	2017-07-26 16:40:00+03	ULV	KRR	Arrived	763	2017-07-26 15:09:00+03	2017-07-26 16:45:00+03
25931	PG0365	2017-08-04 15:05:00+03	2017-08-04 16:40:00+03	ULV	KRR	Arrived	763	2017-08-04 15:10:00+03	2017-08-04 16:44:00+03
25932	PG0365	2017-09-08 15:05:00+03	2017-09-08 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25933	PG0365	2017-08-01 15:05:00+03	2017-08-01 16:40:00+03	ULV	KRR	Arrived	763	2017-08-01 15:06:00+03	2017-08-01 16:41:00+03
25934	PG0365	2017-07-19 15:05:00+03	2017-07-19 16:40:00+03	ULV	KRR	Arrived	763	2017-07-19 15:06:00+03	2017-07-19 16:40:00+03
25935	PG0365	2017-08-13 15:05:00+03	2017-08-13 16:40:00+03	ULV	KRR	Arrived	763	2017-08-13 15:07:00+03	2017-08-13 16:42:00+03
25936	PG0365	2017-08-20 15:05:00+03	2017-08-20 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25937	PG0365	2017-09-09 15:05:00+03	2017-09-09 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25938	PG0365	2017-09-02 15:05:00+03	2017-09-02 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25939	PG0365	2017-09-01 15:05:00+03	2017-09-01 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25940	PG0365	2017-09-14 15:05:00+03	2017-09-14 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25941	PG0365	2017-08-09 15:05:00+03	2017-08-09 16:40:00+03	ULV	KRR	Arrived	763	2017-08-09 15:10:00+03	2017-08-09 16:46:00+03
25942	PG0365	2017-07-16 15:05:00+03	2017-07-16 16:40:00+03	ULV	KRR	Arrived	763	2017-07-16 15:10:00+03	2017-07-16 16:45:00+03
25943	PG0365	2017-07-29 15:05:00+03	2017-07-29 16:40:00+03	ULV	KRR	Arrived	763	2017-07-29 15:06:00+03	2017-07-29 16:40:00+03
25944	PG0365	2017-07-30 15:05:00+03	2017-07-30 16:40:00+03	ULV	KRR	Arrived	763	2017-07-30 15:09:00+03	2017-07-30 16:45:00+03
25945	PG0365	2017-09-11 15:05:00+03	2017-09-11 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25946	PG0365	2017-08-15 15:05:00+03	2017-08-15 16:40:00+03	ULV	KRR	Arrived	763	2017-08-15 15:09:00+03	2017-08-15 16:45:00+03
25947	PG0365	2017-08-21 15:05:00+03	2017-08-21 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25948	PG0365	2017-07-21 15:05:00+03	2017-07-21 16:40:00+03	ULV	KRR	Arrived	763	2017-07-21 15:06:00+03	2017-07-21 16:42:00+03
25949	PG0365	2017-08-12 15:05:00+03	2017-08-12 16:40:00+03	ULV	KRR	Arrived	763	2017-08-12 15:06:00+03	2017-08-12 16:41:00+03
25950	PG0365	2017-08-28 15:05:00+03	2017-08-28 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25951	PG0365	2017-08-23 15:05:00+03	2017-08-23 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25952	PG0365	2017-08-11 15:05:00+03	2017-08-11 16:40:00+03	ULV	KRR	Arrived	763	2017-08-11 15:09:00+03	2017-08-11 16:45:00+03
25953	PG0365	2017-08-10 15:05:00+03	2017-08-10 16:40:00+03	ULV	KRR	Arrived	763	2017-08-10 15:09:00+03	2017-08-10 16:44:00+03
25954	PG0365	2017-07-28 15:05:00+03	2017-07-28 16:40:00+03	ULV	KRR	Arrived	763	2017-07-28 18:54:00+03	2017-07-28 20:29:00+03
25955	PG0365	2017-08-22 15:05:00+03	2017-08-22 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25956	PG0365	2017-07-25 15:05:00+03	2017-07-25 16:40:00+03	ULV	KRR	Arrived	763	2017-07-25 15:07:00+03	2017-07-25 16:43:00+03
25957	PG0365	2017-07-17 15:05:00+03	2017-07-17 16:40:00+03	ULV	KRR	Arrived	763	2017-07-17 15:06:00+03	2017-07-17 16:40:00+03
25958	PG0365	2017-08-30 15:05:00+03	2017-08-30 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25959	PG0365	2017-09-03 15:05:00+03	2017-09-03 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25960	PG0365	2017-08-07 15:05:00+03	2017-08-07 16:40:00+03	ULV	KRR	Arrived	763	2017-08-07 15:07:00+03	2017-08-07 16:42:00+03
25961	PG0365	2017-09-04 15:05:00+03	2017-09-04 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25962	PG0365	2017-07-27 15:05:00+03	2017-07-27 16:40:00+03	ULV	KRR	Arrived	763	2017-07-27 15:06:00+03	2017-07-27 16:41:00+03
25963	PG0365	2017-09-13 15:05:00+03	2017-09-13 16:40:00+03	ULV	KRR	Scheduled	763	\N	\N
25964	PG0365	2017-08-02 15:05:00+03	2017-08-02 16:40:00+03	ULV	KRR	Arrived	763	2017-08-02 15:06:00+03	2017-08-02 16:43:00+03
25965	PG0284	2017-08-23 19:00:00+03	2017-08-23 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25966	PG0284	2017-07-27 19:00:00+03	2017-07-27 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-27 19:02:00+03	2017-07-27 20:07:00+03
25967	PG0284	2017-08-24 19:00:00+03	2017-08-24 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25968	PG0284	2017-08-12 19:00:00+03	2017-08-12 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-12 19:05:00+03	2017-08-12 20:10:00+03
25969	PG0284	2017-09-10 19:00:00+03	2017-09-10 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25970	PG0284	2017-08-19 19:00:00+03	2017-08-19 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25971	PG0284	2017-07-18 19:00:00+03	2017-07-18 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-18 22:43:00+03	2017-07-18 23:49:00+03
25972	PG0284	2017-08-17 19:00:00+03	2017-08-17 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25973	PG0284	2017-09-02 19:00:00+03	2017-09-02 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25974	PG0284	2017-08-03 19:00:00+03	2017-08-03 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-03 19:05:00+03	2017-08-03 20:10:00+03
25975	PG0284	2017-08-30 19:00:00+03	2017-08-30 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25976	PG0284	2017-08-29 19:00:00+03	2017-08-29 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25977	PG0284	2017-08-16 19:00:00+03	2017-08-16 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25978	PG0284	2017-07-19 19:00:00+03	2017-07-19 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-19 19:02:00+03	2017-07-19 20:08:00+03
25979	PG0284	2017-09-08 19:00:00+03	2017-09-08 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25980	PG0284	2017-08-18 19:00:00+03	2017-08-18 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25981	PG0284	2017-08-15 19:00:00+03	2017-08-15 20:05:00+03	ULY	SVO	On Time	CR2	\N	\N
25982	PG0284	2017-07-17 19:00:00+03	2017-07-17 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-17 19:04:00+03	2017-07-17 20:10:00+03
25983	PG0284	2017-08-25 19:00:00+03	2017-08-25 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25984	PG0284	2017-09-11 19:00:00+03	2017-09-11 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25985	PG0284	2017-08-02 19:00:00+03	2017-08-02 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-02 19:04:00+03	2017-08-02 20:09:00+03
25986	PG0284	2017-07-25 19:00:00+03	2017-07-25 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-25 19:04:00+03	2017-07-25 20:09:00+03
25987	PG0284	2017-07-22 19:00:00+03	2017-07-22 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-22 19:04:00+03	2017-07-22 20:09:00+03
25988	PG0284	2017-09-05 19:00:00+03	2017-09-05 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25989	PG0284	2017-07-30 19:00:00+03	2017-07-30 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-30 19:01:00+03	2017-07-30 20:06:00+03
25990	PG0284	2017-08-31 19:00:00+03	2017-08-31 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25991	PG0284	2017-08-26 19:00:00+03	2017-08-26 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25992	PG0284	2017-09-06 19:00:00+03	2017-09-06 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25993	PG0284	2017-07-29 19:00:00+03	2017-07-29 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-29 22:39:00+03	2017-07-29 23:44:00+03
25994	PG0284	2017-08-14 19:00:00+03	2017-08-14 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-14 19:07:00+03	2017-08-14 20:12:00+03
25995	PG0284	2017-08-08 19:00:00+03	2017-08-08 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-08 19:00:00+03	2017-08-08 20:05:00+03
25996	PG0284	2017-08-20 19:00:00+03	2017-08-20 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25997	PG0284	2017-07-31 19:00:00+03	2017-07-31 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-31 19:02:00+03	2017-07-31 20:07:00+03
25998	PG0284	2017-09-07 19:00:00+03	2017-09-07 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
25999	PG0284	2017-08-06 19:00:00+03	2017-08-06 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-06 19:03:00+03	2017-08-06 20:07:00+03
26000	PG0284	2017-08-28 19:00:00+03	2017-08-28 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26001	PG0284	2017-08-10 19:00:00+03	2017-08-10 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-10 19:05:00+03	2017-08-10 20:09:00+03
26002	PG0284	2017-08-05 19:00:00+03	2017-08-05 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-05 19:02:00+03	2017-08-05 20:07:00+03
26003	PG0284	2017-07-16 19:00:00+03	2017-07-16 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-16 19:02:00+03	2017-07-16 20:07:00+03
26004	PG0284	2017-08-11 19:00:00+03	2017-08-11 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-11 19:04:00+03	2017-08-11 20:09:00+03
26005	PG0284	2017-09-12 19:00:00+03	2017-09-12 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26006	PG0284	2017-08-22 19:00:00+03	2017-08-22 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26007	PG0284	2017-09-14 19:00:00+03	2017-09-14 20:05:00+03	ULY	SVO	Cancelled	CR2	\N	\N
26008	PG0284	2017-08-13 19:00:00+03	2017-08-13 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-13 19:03:00+03	2017-08-13 20:08:00+03
26009	PG0284	2017-09-13 19:00:00+03	2017-09-13 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26010	PG0284	2017-07-24 19:00:00+03	2017-07-24 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-24 19:01:00+03	2017-07-24 20:06:00+03
26011	PG0284	2017-09-09 19:00:00+03	2017-09-09 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26012	PG0284	2017-09-01 19:00:00+03	2017-09-01 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26013	PG0284	2017-07-20 19:00:00+03	2017-07-20 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-20 19:02:00+03	2017-07-20 20:08:00+03
26014	PG0284	2017-07-26 19:00:00+03	2017-07-26 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-26 19:03:00+03	2017-07-26 20:08:00+03
26015	PG0284	2017-07-28 19:00:00+03	2017-07-28 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-28 19:04:00+03	2017-07-28 20:09:00+03
26016	PG0284	2017-08-01 19:00:00+03	2017-08-01 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-01 19:01:00+03	2017-08-01 20:06:00+03
26017	PG0284	2017-07-21 19:00:00+03	2017-07-21 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-21 22:45:00+03	2017-07-21 23:49:00+03
26018	PG0284	2017-08-04 19:00:00+03	2017-08-04 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-04 19:01:00+03	2017-08-04 20:06:00+03
26019	PG0284	2017-08-27 19:00:00+03	2017-08-27 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26020	PG0284	2017-08-07 19:00:00+03	2017-08-07 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-07 19:02:00+03	2017-08-07 20:07:00+03
26021	PG0284	2017-09-03 19:00:00+03	2017-09-03 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26022	PG0284	2017-08-21 19:00:00+03	2017-08-21 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26023	PG0284	2017-08-09 19:00:00+03	2017-08-09 20:05:00+03	ULY	SVO	Arrived	CR2	2017-08-09 19:03:00+03	2017-08-09 20:08:00+03
26024	PG0284	2017-09-04 19:00:00+03	2017-09-04 20:05:00+03	ULY	SVO	Scheduled	CR2	\N	\N
26025	PG0284	2017-07-23 19:00:00+03	2017-07-23 20:05:00+03	ULY	SVO	Arrived	CR2	2017-07-23 19:04:00+03	2017-07-23 20:10:00+03
26026	PG0018	2017-08-15 11:25:00+03	2017-08-15 13:55:00+03	ULY	NJC	Arrived	CR2	2017-08-15 11:29:00+03	2017-08-15 13:57:00+03
26027	PG0018	2017-07-18 11:25:00+03	2017-07-18 13:55:00+03	ULY	NJC	Arrived	CR2	2017-07-18 11:28:00+03	2017-07-18 13:58:00+03
26028	PG0018	2017-08-01 11:25:00+03	2017-08-01 13:55:00+03	ULY	NJC	Arrived	CR2	2017-08-01 11:31:00+03	2017-08-01 13:59:00+03
26029	PG0018	2017-07-25 11:25:00+03	2017-07-25 13:55:00+03	ULY	NJC	Arrived	CR2	2017-07-25 11:27:00+03	2017-07-25 14:00:00+03
26030	PG0018	2017-09-05 11:25:00+03	2017-09-05 13:55:00+03	ULY	NJC	Scheduled	CR2	\N	\N
26031	PG0018	2017-08-22 11:25:00+03	2017-08-22 13:55:00+03	ULY	NJC	Scheduled	CR2	\N	\N
26032	PG0018	2017-09-12 11:25:00+03	2017-09-12 13:55:00+03	ULY	NJC	Cancelled	CR2	\N	\N
26033	PG0018	2017-08-29 11:25:00+03	2017-08-29 13:55:00+03	ULY	NJC	Scheduled	CR2	\N	\N
26034	PG0018	2017-08-08 11:25:00+03	2017-08-08 13:55:00+03	ULY	NJC	Arrived	CR2	2017-08-08 11:30:00+03	2017-08-08 14:01:00+03
26035	PG0467	2017-07-31 15:45:00+03	2017-07-31 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-31 15:47:00+03	2017-07-31 17:02:00+03
26036	PG0467	2017-09-12 15:45:00+03	2017-09-12 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26037	PG0466	2017-09-12 10:45:00+03	2017-09-12 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26038	PG0466	2017-09-01 10:45:00+03	2017-09-01 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26039	PG0467	2017-09-01 15:45:00+03	2017-09-01 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26040	PG0466	2017-08-28 10:45:00+03	2017-08-28 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26041	PG0467	2017-08-28 15:45:00+03	2017-08-28 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26042	PG0466	2017-08-13 10:45:00+03	2017-08-13 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-13 10:47:00+03	2017-08-13 12:02:00+03
26043	PG0467	2017-08-13 15:45:00+03	2017-08-13 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-13 15:48:00+03	2017-08-13 17:03:00+03
26044	PG0467	2017-09-06 15:45:00+03	2017-09-06 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26045	PG0466	2017-09-06 10:45:00+03	2017-09-06 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26046	PG0467	2017-09-11 15:45:00+03	2017-09-11 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26047	PG0467	2017-07-30 15:45:00+03	2017-07-30 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-30 15:51:00+03	2017-07-30 17:05:00+03
26048	PG0467	2017-09-14 15:45:00+03	2017-09-14 17:00:00+03	ULY	RTW	Cancelled	CN1	\N	\N
26049	PG0466	2017-07-30 10:45:00+03	2017-07-30 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-30 10:49:00+03	2017-07-30 12:04:00+03
26050	PG0467	2017-08-05 15:45:00+03	2017-08-05 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-05 15:48:00+03	2017-08-05 17:03:00+03
26051	PG0466	2017-08-05 10:45:00+03	2017-08-05 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-05 10:46:00+03	2017-08-05 11:59:00+03
26052	PG0467	2017-08-19 15:45:00+03	2017-08-19 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26053	PG0466	2017-08-19 10:45:00+03	2017-08-19 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26054	PG0467	2017-08-10 15:45:00+03	2017-08-10 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-10 15:46:00+03	2017-08-10 17:01:00+03
26055	PG0466	2017-08-10 10:45:00+03	2017-08-10 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-10 10:51:00+03	2017-08-10 12:05:00+03
26056	PG0467	2017-07-28 15:45:00+03	2017-07-28 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-28 15:47:00+03	2017-07-28 17:02:00+03
26058	PG0467	2017-08-18 15:45:00+03	2017-08-18 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26059	PG0466	2017-07-28 10:45:00+03	2017-07-28 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-28 14:06:00+03	2017-07-28 15:21:00+03
26060	PG0466	2017-08-18 10:45:00+03	2017-08-18 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26061	PG0467	2017-07-25 15:45:00+03	2017-07-25 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-25 15:49:00+03	2017-07-25 17:03:00+03
26062	PG0466	2017-07-25 10:45:00+03	2017-07-25 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-25 10:48:00+03	2017-07-25 12:03:00+03
26063	PG0466	2017-08-20 10:45:00+03	2017-08-20 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26064	PG0466	2017-09-08 10:45:00+03	2017-09-08 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26065	PG0467	2017-09-08 15:45:00+03	2017-09-08 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26066	PG0466	2017-08-01 10:45:00+03	2017-08-01 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-01 10:50:00+03	2017-08-01 12:06:00+03
26067	PG0467	2017-08-01 15:45:00+03	2017-08-01 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-01 15:47:00+03	2017-08-01 17:02:00+03
26068	PG0467	2017-08-20 15:45:00+03	2017-08-20 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26069	PG0467	2017-08-08 15:45:00+03	2017-08-08 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-08 15:48:00+03	2017-08-08 17:04:00+03
26070	PG0466	2017-08-08 10:45:00+03	2017-08-08 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-08 10:48:00+03	2017-08-08 12:03:00+03
26071	PG0466	2017-07-23 10:45:00+03	2017-07-23 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-23 10:49:00+03	2017-07-23 12:03:00+03
26072	PG0467	2017-09-03 15:45:00+03	2017-09-03 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26073	PG0466	2017-09-03 10:45:00+03	2017-09-03 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26074	PG0467	2017-07-23 15:45:00+03	2017-07-23 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-23 15:45:00+03	2017-07-23 17:00:00+03
26075	PG0466	2017-08-22 10:45:00+03	2017-08-22 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26076	PG0466	2017-07-19 10:45:00+03	2017-07-19 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-19 10:49:00+03	2017-07-19 12:05:00+03
26077	PG0467	2017-07-19 15:45:00+03	2017-07-19 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-19 15:46:00+03	2017-07-19 17:03:00+03
26078	PG0467	2017-08-22 15:45:00+03	2017-08-22 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26079	PG0466	2017-08-23 10:45:00+03	2017-08-23 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26080	PG0467	2017-08-23 15:45:00+03	2017-08-23 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26081	PG0466	2017-09-14 10:45:00+03	2017-09-14 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26082	PG0467	2017-09-07 15:45:00+03	2017-09-07 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26083	PG0466	2017-09-07 10:45:00+03	2017-09-07 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26084	PG0467	2017-08-04 15:45:00+03	2017-08-04 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-04 19:23:00+03	2017-08-04 20:38:00+03
26085	PG0466	2017-08-14 10:45:00+03	2017-08-14 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-14 10:50:00+03	2017-08-14 12:05:00+03
26086	PG0467	2017-08-14 15:45:00+03	2017-08-14 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-14 15:50:00+03	2017-08-14 17:04:00+03
26087	PG0467	2017-07-21 15:45:00+03	2017-07-21 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-21 19:08:00+03	2017-07-21 20:24:00+03
26088	PG0467	2017-07-17 15:45:00+03	2017-07-17 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-17 15:49:00+03	2017-07-17 17:04:00+03
26089	PG0467	2017-08-12 15:45:00+03	2017-08-12 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-12 15:46:00+03	2017-08-12 17:02:00+03
26090	PG0466	2017-07-21 10:45:00+03	2017-07-21 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-21 10:47:00+03	2017-07-21 12:02:00+03
26091	PG0466	2017-07-17 10:45:00+03	2017-07-17 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-17 10:50:00+03	2017-07-17 12:04:00+03
26092	PG0467	2017-07-27 15:45:00+03	2017-07-27 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-27 15:48:00+03	2017-07-27 17:03:00+03
26093	PG0466	2017-07-27 10:45:00+03	2017-07-27 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-27 10:46:00+03	2017-07-27 12:00:00+03
26094	PG0466	2017-08-12 10:45:00+03	2017-08-12 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-12 10:47:00+03	2017-08-12 12:01:00+03
26095	PG0466	2017-07-18 10:45:00+03	2017-07-18 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-18 10:50:00+03	2017-07-18 12:05:00+03
26096	PG0466	2017-08-04 10:45:00+03	2017-08-04 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-04 10:50:00+03	2017-08-04 12:07:00+03
26097	PG0467	2017-08-29 15:45:00+03	2017-08-29 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26098	PG0466	2017-08-29 10:45:00+03	2017-08-29 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26099	PG0467	2017-08-30 15:45:00+03	2017-08-30 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26100	PG0466	2017-08-30 10:45:00+03	2017-08-30 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26101	PG0467	2017-07-18 15:45:00+03	2017-07-18 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-18 15:46:00+03	2017-07-18 17:02:00+03
26102	PG0466	2017-09-04 10:45:00+03	2017-09-04 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26103	PG0467	2017-09-04 15:45:00+03	2017-09-04 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26104	PG0466	2017-09-11 10:45:00+03	2017-09-11 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26105	PG0467	2017-08-21 15:45:00+03	2017-08-21 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26106	PG0466	2017-08-21 10:45:00+03	2017-08-21 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26107	PG0466	2017-08-02 10:45:00+03	2017-08-02 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-02 14:09:00+03	2017-08-02 15:24:00+03
26108	PG0467	2017-08-02 15:45:00+03	2017-08-02 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-02 15:51:00+03	2017-08-02 17:05:00+03
26109	PG0467	2017-08-09 15:45:00+03	2017-08-09 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-09 15:49:00+03	2017-08-09 17:05:00+03
26110	PG0466	2017-08-09 10:45:00+03	2017-08-09 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-09 13:17:00+03	2017-08-09 14:33:00+03
26111	PG0466	2017-08-07 10:45:00+03	2017-08-07 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-07 14:43:00+03	2017-08-07 15:57:00+03
26112	PG0467	2017-08-07 15:45:00+03	2017-08-07 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-07 15:50:00+03	2017-08-07 17:05:00+03
26113	PG0466	2017-08-15 10:45:00+03	2017-08-15 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-15 10:50:00+03	2017-08-15 12:05:00+03
26114	PG0467	2017-08-15 15:45:00+03	2017-08-15 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-15 15:45:00+03	2017-08-15 17:01:00+03
26115	PG0466	2017-08-25 10:45:00+03	2017-08-25 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26116	PG0467	2017-07-26 15:45:00+03	2017-07-26 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-26 15:48:00+03	2017-07-26 17:04:00+03
26117	PG0466	2017-07-26 10:45:00+03	2017-07-26 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-26 10:45:00+03	2017-07-26 12:01:00+03
26118	PG0467	2017-08-25 15:45:00+03	2017-08-25 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26119	PG0466	2017-09-09 10:45:00+03	2017-09-09 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26120	PG0467	2017-09-09 15:45:00+03	2017-09-09 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26121	PG0466	2017-09-02 10:45:00+03	2017-09-02 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26122	PG0467	2017-09-02 15:45:00+03	2017-09-02 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26123	PG0467	2017-09-05 15:45:00+03	2017-09-05 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26124	PG0466	2017-09-05 10:45:00+03	2017-09-05 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26125	PG0467	2017-07-22 15:45:00+03	2017-07-22 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-22 15:47:00+03	2017-07-22 17:02:00+03
26126	PG0467	2017-08-24 15:45:00+03	2017-08-24 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26127	PG0466	2017-07-22 10:45:00+03	2017-07-22 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-22 10:46:00+03	2017-07-22 12:03:00+03
26128	PG0466	2017-08-24 10:45:00+03	2017-08-24 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26129	PG0466	2017-08-26 10:45:00+03	2017-08-26 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26130	PG0466	2017-07-16 10:45:00+03	2017-07-16 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-16 10:51:00+03	2017-07-16 12:06:00+03
26131	PG0466	2017-07-24 10:45:00+03	2017-07-24 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-24 10:50:00+03	2017-07-24 12:06:00+03
26132	PG0467	2017-08-17 15:45:00+03	2017-08-17 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26133	PG0467	2017-07-24 15:45:00+03	2017-07-24 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-24 15:50:00+03	2017-07-24 17:05:00+03
26134	PG0467	2017-07-16 15:45:00+03	2017-07-16 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-16 15:48:00+03	2017-07-16 17:02:00+03
26135	PG0466	2017-08-17 10:45:00+03	2017-08-17 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26136	PG0467	2017-09-10 15:45:00+03	2017-09-10 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26137	PG0466	2017-07-20 10:45:00+03	2017-07-20 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-20 10:48:00+03	2017-07-20 12:03:00+03
26138	PG0467	2017-07-20 15:45:00+03	2017-07-20 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-20 15:47:00+03	2017-07-20 17:02:00+03
26139	PG0466	2017-09-10 10:45:00+03	2017-09-10 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26140	PG0466	2017-08-27 10:45:00+03	2017-08-27 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26141	PG0466	2017-08-03 10:45:00+03	2017-08-03 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-03 10:47:00+03	2017-08-03 12:02:00+03
26142	PG0467	2017-08-03 15:45:00+03	2017-08-03 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-03 15:47:00+03	2017-08-03 17:02:00+03
26143	PG0467	2017-08-27 15:45:00+03	2017-08-27 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26144	PG0466	2017-07-31 10:45:00+03	2017-07-31 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-31 10:45:00+03	2017-07-31 12:00:00+03
26145	PG0467	2017-09-13 15:45:00+03	2017-09-13 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26146	PG0466	2017-09-13 10:45:00+03	2017-09-13 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26147	PG0466	2017-08-11 10:45:00+03	2017-08-11 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-11 10:48:00+03	2017-08-11 12:03:00+03
26148	PG0466	2017-08-06 10:45:00+03	2017-08-06 12:00:00+03	ULY	RTW	Arrived	CN1	2017-08-06 10:47:00+03	2017-08-06 12:02:00+03
26149	PG0467	2017-08-31 15:45:00+03	2017-08-31 17:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26150	PG0466	2017-08-31 10:45:00+03	2017-08-31 12:00:00+03	ULY	RTW	Scheduled	CN1	\N	\N
26151	PG0466	2017-08-16 10:45:00+03	2017-08-16 12:00:00+03	ULY	RTW	On Time	CN1	\N	\N
26152	PG0467	2017-08-16 15:45:00+03	2017-08-16 17:00:00+03	ULY	RTW	On Time	CN1	\N	\N
26153	PG0467	2017-08-11 15:45:00+03	2017-08-11 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-11 15:48:00+03	2017-08-11 17:03:00+03
26154	PG0467	2017-07-29 15:45:00+03	2017-07-29 17:00:00+03	ULY	RTW	Arrived	CN1	2017-07-29 15:46:00+03	2017-07-29 17:03:00+03
26155	PG0466	2017-07-29 10:45:00+03	2017-07-29 12:00:00+03	ULY	RTW	Arrived	CN1	2017-07-29 14:26:00+03	2017-07-29 15:41:00+03
26156	PG0467	2017-08-06 15:45:00+03	2017-08-06 17:00:00+03	ULY	RTW	Arrived	CN1	2017-08-06 15:47:00+03	2017-08-06 17:02:00+03
26157	PG0209	2017-08-05 12:55:00+03	2017-08-05 20:55:00+03	KHV	DME	Arrived	763	2017-08-05 12:57:00+03	2017-08-05 20:56:00+03
26158	PG0209	2017-08-08 12:55:00+03	2017-08-08 20:55:00+03	KHV	DME	Arrived	763	2017-08-08 12:57:00+03	2017-08-08 20:55:00+03
26159	PG0209	2017-08-29 12:55:00+03	2017-08-29 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26160	PG0209	2017-08-24 12:55:00+03	2017-08-24 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26161	PG0209	2017-09-11 12:55:00+03	2017-09-11 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26162	PG0209	2017-08-03 12:55:00+03	2017-08-03 20:55:00+03	KHV	DME	Arrived	763	2017-08-03 12:57:00+03	2017-08-03 20:55:00+03
26163	PG0209	2017-07-26 12:55:00+03	2017-07-26 20:55:00+03	KHV	DME	Arrived	763	2017-07-26 12:58:00+03	2017-07-26 20:53:00+03
26164	PG0209	2017-08-30 12:55:00+03	2017-08-30 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26165	PG0209	2017-08-16 12:55:00+03	2017-08-16 20:55:00+03	KHV	DME	On Time	763	\N	\N
26166	PG0209	2017-09-13 12:55:00+03	2017-09-13 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26167	PG0209	2017-08-25 12:55:00+03	2017-08-25 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26168	PG0209	2017-08-15 12:55:00+03	2017-08-15 20:55:00+03	KHV	DME	Departed	763	2017-08-15 12:58:00+03	\N
26169	PG0209	2017-09-14 12:55:00+03	2017-09-14 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26170	PG0209	2017-08-18 12:55:00+03	2017-08-18 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26171	PG0209	2017-09-02 12:55:00+03	2017-09-02 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26172	PG0209	2017-07-31 12:55:00+03	2017-07-31 20:55:00+03	KHV	DME	Arrived	763	2017-07-31 15:53:00+03	2017-07-31 23:54:00+03
26173	PG0209	2017-08-07 12:55:00+03	2017-08-07 20:55:00+03	KHV	DME	Arrived	763	2017-08-07 12:59:00+03	2017-08-07 21:08:00+03
26174	PG0209	2017-07-17 12:55:00+03	2017-07-17 20:55:00+03	KHV	DME	Arrived	763	2017-07-17 12:58:00+03	2017-07-17 20:53:00+03
26175	PG0209	2017-09-08 12:55:00+03	2017-09-08 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26176	PG0209	2017-08-27 12:55:00+03	2017-08-27 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26177	PG0209	2017-08-20 12:55:00+03	2017-08-20 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26178	PG0209	2017-08-06 12:55:00+03	2017-08-06 20:55:00+03	KHV	DME	Arrived	763	2017-08-06 12:58:00+03	2017-08-06 21:02:00+03
26179	PG0209	2017-07-27 12:55:00+03	2017-07-27 20:55:00+03	KHV	DME	Arrived	763	2017-07-27 12:58:00+03	2017-07-27 20:48:00+03
26180	PG0209	2017-08-28 12:55:00+03	2017-08-28 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26181	PG0209	2017-07-28 12:55:00+03	2017-07-28 20:55:00+03	KHV	DME	Arrived	763	2017-07-28 13:01:00+03	2017-07-28 21:04:00+03
26182	PG0209	2017-09-03 12:55:00+03	2017-09-03 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26183	PG0209	2017-07-22 12:55:00+03	2017-07-22 20:55:00+03	KHV	DME	Arrived	763	2017-07-22 12:59:00+03	2017-07-22 20:55:00+03
26184	PG0209	2017-08-10 12:55:00+03	2017-08-10 20:55:00+03	KHV	DME	Arrived	763	2017-08-10 12:59:00+03	2017-08-10 20:51:00+03
26185	PG0209	2017-07-16 12:55:00+03	2017-07-16 20:55:00+03	KHV	DME	Arrived	763	2017-07-16 13:00:00+03	2017-07-16 20:55:00+03
26186	PG0209	2017-09-06 12:55:00+03	2017-09-06 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26187	PG0209	2017-08-21 12:55:00+03	2017-08-21 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26188	PG0209	2017-07-25 12:55:00+03	2017-07-25 20:55:00+03	KHV	DME	Arrived	763	2017-07-25 13:01:00+03	2017-07-25 21:00:00+03
26189	PG0209	2017-08-14 12:55:00+03	2017-08-14 20:55:00+03	KHV	DME	Arrived	763	2017-08-14 12:57:00+03	2017-08-14 20:55:00+03
26190	PG0209	2017-08-22 12:55:00+03	2017-08-22 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26191	PG0209	2017-08-31 12:55:00+03	2017-08-31 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26192	PG0209	2017-07-24 12:55:00+03	2017-07-24 20:55:00+03	KHV	DME	Arrived	763	2017-07-24 12:57:00+03	2017-07-24 20:54:00+03
26193	PG0209	2017-08-17 12:55:00+03	2017-08-17 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26194	PG0209	2017-08-13 12:55:00+03	2017-08-13 20:55:00+03	KHV	DME	Arrived	763	2017-08-13 13:01:00+03	2017-08-13 21:04:00+03
26195	PG0209	2017-07-18 12:55:00+03	2017-07-18 20:55:00+03	KHV	DME	Arrived	763	2017-07-18 13:00:00+03	2017-07-18 20:51:00+03
26196	PG0209	2017-09-12 12:55:00+03	2017-09-12 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26197	PG0209	2017-07-20 12:55:00+03	2017-07-20 20:55:00+03	KHV	DME	Arrived	763	2017-07-20 12:58:00+03	2017-07-20 20:56:00+03
26198	PG0209	2017-07-29 12:55:00+03	2017-07-29 20:55:00+03	KHV	DME	Arrived	763	2017-07-29 12:57:00+03	2017-07-29 21:00:00+03
26199	PG0209	2017-08-26 12:55:00+03	2017-08-26 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26200	PG0209	2017-07-30 12:55:00+03	2017-07-30 20:55:00+03	KHV	DME	Arrived	763	2017-07-30 12:58:00+03	2017-07-30 20:58:00+03
26201	PG0209	2017-08-09 12:55:00+03	2017-08-09 20:55:00+03	KHV	DME	Arrived	763	2017-08-09 13:00:00+03	2017-08-09 21:10:00+03
26202	PG0209	2017-08-11 12:55:00+03	2017-08-11 20:55:00+03	KHV	DME	Arrived	763	2017-08-11 12:58:00+03	2017-08-11 21:04:00+03
26203	PG0209	2017-07-21 12:55:00+03	2017-07-21 20:55:00+03	KHV	DME	Arrived	763	2017-07-21 12:58:00+03	2017-07-21 20:53:00+03
26204	PG0209	2017-08-01 12:55:00+03	2017-08-01 20:55:00+03	KHV	DME	Arrived	763	2017-08-01 12:57:00+03	2017-08-01 20:55:00+03
26205	PG0209	2017-09-01 12:55:00+03	2017-09-01 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26206	PG0209	2017-07-19 12:55:00+03	2017-07-19 20:55:00+03	KHV	DME	Arrived	763	2017-07-19 12:57:00+03	2017-07-19 20:54:00+03
26207	PG0209	2017-07-23 12:55:00+03	2017-07-23 20:55:00+03	KHV	DME	Arrived	763	2017-07-23 12:57:00+03	2017-07-23 20:56:00+03
26208	PG0209	2017-08-04 12:55:00+03	2017-08-04 20:55:00+03	KHV	DME	Arrived	763	2017-08-04 12:55:00+03	2017-08-04 20:59:00+03
26209	PG0209	2017-08-02 12:55:00+03	2017-08-02 20:55:00+03	KHV	DME	Arrived	763	2017-08-02 12:58:00+03	2017-08-02 20:57:00+03
26210	PG0209	2017-08-19 12:55:00+03	2017-08-19 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26211	PG0209	2017-09-07 12:55:00+03	2017-09-07 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26212	PG0209	2017-08-23 12:55:00+03	2017-08-23 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26213	PG0209	2017-09-04 12:55:00+03	2017-09-04 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26214	PG0209	2017-09-09 12:55:00+03	2017-09-09 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26215	PG0209	2017-09-10 12:55:00+03	2017-09-10 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26216	PG0209	2017-08-12 12:55:00+03	2017-08-12 20:55:00+03	KHV	DME	Arrived	763	2017-08-12 12:58:00+03	2017-08-12 21:01:00+03
26217	PG0209	2017-09-05 12:55:00+03	2017-09-05 20:55:00+03	KHV	DME	Scheduled	763	\N	\N
26218	PG0357	2017-07-18 05:05:00+03	2017-07-18 13:10:00+03	KHV	LED	Arrived	763	2017-07-18 05:09:00+03	2017-07-18 13:05:00+03
26219	PG0357	2017-08-30 05:05:00+03	2017-08-30 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26220	PG0357	2017-08-08 05:05:00+03	2017-08-08 13:10:00+03	KHV	LED	Arrived	763	2017-08-08 05:09:00+03	2017-08-08 13:12:00+03
26221	PG0357	2017-09-13 05:05:00+03	2017-09-13 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26222	PG0357	2017-08-18 05:05:00+03	2017-08-18 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26223	PG0357	2017-09-05 05:05:00+03	2017-09-05 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26224	PG0357	2017-08-16 05:05:00+03	2017-08-16 13:10:00+03	KHV	LED	On Time	763	\N	\N
26225	PG0357	2017-09-04 05:05:00+03	2017-09-04 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26226	PG0357	2017-08-01 05:05:00+03	2017-08-01 13:10:00+03	KHV	LED	Arrived	763	2017-08-01 05:08:00+03	2017-08-01 13:10:00+03
26227	PG0357	2017-08-03 05:05:00+03	2017-08-03 13:10:00+03	KHV	LED	Arrived	763	2017-08-03 07:58:00+03	2017-08-03 16:05:00+03
26228	PG0357	2017-07-28 05:05:00+03	2017-07-28 13:10:00+03	KHV	LED	Arrived	763	2017-07-28 05:09:00+03	2017-07-28 13:08:00+03
26229	PG0357	2017-07-19 05:05:00+03	2017-07-19 13:10:00+03	KHV	LED	Arrived	763	2017-07-19 05:07:00+03	2017-07-19 13:18:00+03
26230	PG0357	2017-09-12 05:05:00+03	2017-09-12 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26231	PG0357	2017-08-31 05:05:00+03	2017-08-31 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26232	PG0357	2017-09-03 05:05:00+03	2017-09-03 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26233	PG0357	2017-07-26 05:05:00+03	2017-07-26 13:10:00+03	KHV	LED	Arrived	763	2017-07-26 05:08:00+03	2017-07-26 13:08:00+03
26234	PG0357	2017-07-31 05:05:00+03	2017-07-31 13:10:00+03	KHV	LED	Arrived	763	2017-07-31 05:08:00+03	2017-07-31 13:13:00+03
26235	PG0357	2017-09-08 05:05:00+03	2017-09-08 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26236	PG0357	2017-08-27 05:05:00+03	2017-08-27 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26237	PG0357	2017-08-24 05:05:00+03	2017-08-24 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26238	PG0357	2017-07-23 05:05:00+03	2017-07-23 13:10:00+03	KHV	LED	Arrived	763	2017-07-23 05:06:00+03	2017-07-23 13:11:00+03
26239	PG0357	2017-08-17 05:05:00+03	2017-08-17 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26240	PG0357	2017-08-07 05:05:00+03	2017-08-07 13:10:00+03	KHV	LED	Arrived	763	2017-08-07 05:09:00+03	2017-08-07 13:10:00+03
26241	PG0357	2017-07-20 05:05:00+03	2017-07-20 13:10:00+03	KHV	LED	Arrived	763	2017-07-20 05:09:00+03	2017-07-20 13:20:00+03
26242	PG0357	2017-07-24 05:05:00+03	2017-07-24 13:10:00+03	KHV	LED	Arrived	763	2017-07-24 05:09:00+03	2017-07-24 13:13:00+03
26243	PG0357	2017-08-05 05:05:00+03	2017-08-05 13:10:00+03	KHV	LED	Arrived	763	2017-08-05 05:08:00+03	2017-08-05 13:11:00+03
26244	PG0357	2017-08-10 05:05:00+03	2017-08-10 13:10:00+03	KHV	LED	Arrived	763	2017-08-10 05:06:00+03	2017-08-10 13:15:00+03
26245	PG0357	2017-07-17 05:05:00+03	2017-07-17 13:10:00+03	KHV	LED	Arrived	763	2017-07-17 05:06:00+03	2017-07-17 13:12:00+03
26246	PG0357	2017-08-02 05:05:00+03	2017-08-02 13:10:00+03	KHV	LED	Arrived	763	2017-08-02 05:07:00+03	2017-08-02 13:07:00+03
26247	PG0357	2017-09-11 05:05:00+03	2017-09-11 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26248	PG0357	2017-08-28 05:05:00+03	2017-08-28 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26249	PG0357	2017-07-30 05:05:00+03	2017-07-30 13:10:00+03	KHV	LED	Arrived	763	2017-07-30 05:11:00+03	2017-07-30 13:23:00+03
26250	PG0357	2017-08-14 05:05:00+03	2017-08-14 13:10:00+03	KHV	LED	Arrived	763	2017-08-14 05:09:00+03	2017-08-14 13:12:00+03
26251	PG0357	2017-08-15 05:05:00+03	2017-08-15 13:10:00+03	KHV	LED	Arrived	763	2017-08-15 05:10:00+03	2017-08-15 13:14:00+03
26252	PG0357	2017-08-12 05:05:00+03	2017-08-12 13:10:00+03	KHV	LED	Arrived	763	2017-08-12 05:11:00+03	2017-08-12 13:17:00+03
26253	PG0357	2017-09-10 05:05:00+03	2017-09-10 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26254	PG0357	2017-09-06 05:05:00+03	2017-09-06 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26255	PG0357	2017-08-22 05:05:00+03	2017-08-22 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26256	PG0357	2017-07-21 05:05:00+03	2017-07-21 13:10:00+03	KHV	LED	Arrived	763	2017-07-21 05:08:00+03	2017-07-21 13:12:00+03
26257	PG0357	2017-08-19 05:05:00+03	2017-08-19 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26258	PG0357	2017-07-25 05:05:00+03	2017-07-25 13:10:00+03	KHV	LED	Arrived	763	2017-07-25 05:08:00+03	2017-07-25 13:13:00+03
26259	PG0357	2017-07-27 05:05:00+03	2017-07-27 13:10:00+03	KHV	LED	Arrived	763	2017-07-27 05:07:00+03	2017-07-27 13:13:00+03
26260	PG0357	2017-08-21 05:05:00+03	2017-08-21 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26261	PG0357	2017-08-06 05:05:00+03	2017-08-06 13:10:00+03	KHV	LED	Arrived	763	2017-08-06 07:58:00+03	2017-08-06 16:02:00+03
26262	PG0357	2017-08-23 05:05:00+03	2017-08-23 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26263	PG0357	2017-08-20 05:05:00+03	2017-08-20 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26264	PG0357	2017-09-02 05:05:00+03	2017-09-02 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26265	PG0357	2017-08-11 05:05:00+03	2017-08-11 13:10:00+03	KHV	LED	Arrived	763	2017-08-11 05:09:00+03	2017-08-11 13:16:00+03
26266	PG0357	2017-09-01 05:05:00+03	2017-09-01 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26267	PG0357	2017-08-09 05:05:00+03	2017-08-09 13:10:00+03	KHV	LED	Arrived	763	2017-08-09 05:06:00+03	2017-08-09 13:06:00+03
26268	PG0357	2017-08-13 05:05:00+03	2017-08-13 13:10:00+03	KHV	LED	Arrived	763	2017-08-13 05:10:00+03	2017-08-13 13:20:00+03
26269	PG0357	2017-09-09 05:05:00+03	2017-09-09 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26270	PG0357	2017-08-04 05:05:00+03	2017-08-04 13:10:00+03	KHV	LED	Arrived	763	2017-08-04 05:06:00+03	2017-08-04 13:03:00+03
26271	PG0357	2017-08-29 05:05:00+03	2017-08-29 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26272	PG0357	2017-08-26 05:05:00+03	2017-08-26 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26273	PG0357	2017-09-14 05:05:00+03	2017-09-14 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26274	PG0357	2017-07-29 05:05:00+03	2017-07-29 13:10:00+03	KHV	LED	Arrived	763	2017-07-29 05:07:00+03	2017-07-29 13:14:00+03
26275	PG0357	2017-08-25 05:05:00+03	2017-08-25 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26276	PG0357	2017-09-07 05:05:00+03	2017-09-07 13:10:00+03	KHV	LED	Scheduled	763	\N	\N
26277	PG0357	2017-07-16 05:05:00+03	2017-07-16 13:10:00+03	KHV	LED	Arrived	763	2017-07-16 05:07:00+03	2017-07-16 13:08:00+03
26278	PG0357	2017-07-22 05:05:00+03	2017-07-22 13:10:00+03	KHV	LED	Arrived	763	2017-07-22 05:08:00+03	2017-07-22 13:09:00+03
26279	PG0116	2017-09-12 06:15:00+03	2017-09-12 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26280	PG0116	2017-07-26 06:15:00+03	2017-07-26 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-26 06:15:00+03	2017-07-26 07:04:00+03
26281	PG0116	2017-07-22 06:15:00+03	2017-07-22 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-22 06:16:00+03	2017-07-22 07:06:00+03
26282	PG0116	2017-08-26 06:15:00+03	2017-08-26 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26283	PG0116	2017-07-28 06:15:00+03	2017-07-28 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-28 06:22:00+03	2017-07-28 07:13:00+03
26284	PG0116	2017-08-06 06:15:00+03	2017-08-06 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-06 10:21:00+03	2017-08-06 11:12:00+03
26285	PG0116	2017-07-21 06:15:00+03	2017-07-21 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-21 06:16:00+03	2017-07-21 07:05:00+03
26286	PG0116	2017-07-30 06:15:00+03	2017-07-30 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-30 06:19:00+03	2017-07-30 07:09:00+03
26287	PG0116	2017-09-01 06:15:00+03	2017-09-01 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26288	PG0116	2017-08-24 06:15:00+03	2017-08-24 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26289	PG0116	2017-09-04 06:15:00+03	2017-09-04 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26290	PG0116	2017-09-08 06:15:00+03	2017-09-08 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26291	PG0116	2017-08-16 06:15:00+03	2017-08-16 07:05:00+03	KHV	BQS	On Time	SU9	\N	\N
26292	PG0116	2017-07-17 06:15:00+03	2017-07-17 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-17 06:16:00+03	2017-07-17 07:07:00+03
26293	PG0116	2017-07-31 06:15:00+03	2017-07-31 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-31 06:17:00+03	2017-07-31 07:07:00+03
26294	PG0116	2017-08-10 06:15:00+03	2017-08-10 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-10 06:18:00+03	2017-08-10 07:08:00+03
26295	PG0116	2017-08-22 06:15:00+03	2017-08-22 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26296	PG0116	2017-08-20 06:15:00+03	2017-08-20 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26297	PG0116	2017-08-01 06:15:00+03	2017-08-01 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-01 06:24:00+03	2017-08-01 07:13:00+03
26298	PG0116	2017-08-21 06:15:00+03	2017-08-21 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26299	PG0116	2017-08-09 06:15:00+03	2017-08-09 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-09 06:20:00+03	2017-08-09 07:10:00+03
26300	PG0116	2017-08-03 06:15:00+03	2017-08-03 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-03 06:19:00+03	2017-08-03 07:08:00+03
26301	PG0116	2017-09-10 06:15:00+03	2017-09-10 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26302	PG0116	2017-08-12 06:15:00+03	2017-08-12 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-12 06:16:00+03	2017-08-12 07:06:00+03
26303	PG0116	2017-07-29 06:15:00+03	2017-07-29 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-29 06:17:00+03	2017-07-29 07:07:00+03
26304	PG0116	2017-08-29 06:15:00+03	2017-08-29 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26305	PG0116	2017-08-02 06:15:00+03	2017-08-02 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-02 06:19:00+03	2017-08-02 07:09:00+03
26306	PG0116	2017-08-08 06:15:00+03	2017-08-08 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-08 06:15:00+03	2017-08-08 07:05:00+03
26307	PG0116	2017-07-23 06:15:00+03	2017-07-23 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-23 06:16:00+03	2017-07-23 07:06:00+03
26308	PG0116	2017-08-13 06:15:00+03	2017-08-13 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-13 06:17:00+03	2017-08-13 07:07:00+03
26309	PG0116	2017-09-14 06:15:00+03	2017-09-14 07:05:00+03	KHV	BQS	Cancelled	SU9	\N	\N
26310	PG0116	2017-08-27 06:15:00+03	2017-08-27 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26311	PG0116	2017-09-03 06:15:00+03	2017-09-03 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26312	PG0116	2017-09-05 06:15:00+03	2017-09-05 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26313	PG0116	2017-09-02 06:15:00+03	2017-09-02 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26314	PG0116	2017-08-23 06:15:00+03	2017-08-23 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26315	PG0116	2017-08-15 06:15:00+03	2017-08-15 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-15 06:16:00+03	2017-08-15 07:06:00+03
26316	PG0116	2017-07-25 06:15:00+03	2017-07-25 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-25 06:19:00+03	2017-07-25 07:09:00+03
26317	PG0116	2017-07-20 06:15:00+03	2017-07-20 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-20 06:15:00+03	2017-07-20 07:06:00+03
26318	PG0116	2017-08-18 06:15:00+03	2017-08-18 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26319	PG0116	2017-08-17 06:15:00+03	2017-08-17 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26320	PG0116	2017-08-19 06:15:00+03	2017-08-19 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26321	PG0116	2017-09-06 06:15:00+03	2017-09-06 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26322	PG0116	2017-08-04 06:15:00+03	2017-08-04 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-04 06:20:00+03	2017-08-04 07:10:00+03
26323	PG0116	2017-08-25 06:15:00+03	2017-08-25 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26324	PG0116	2017-08-05 06:15:00+03	2017-08-05 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-05 06:19:00+03	2017-08-05 07:09:00+03
26325	PG0116	2017-09-13 06:15:00+03	2017-09-13 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26326	PG0116	2017-07-27 06:15:00+03	2017-07-27 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-27 06:19:00+03	2017-07-27 07:08:00+03
26327	PG0116	2017-08-31 06:15:00+03	2017-08-31 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26328	PG0116	2017-08-30 06:15:00+03	2017-08-30 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26329	PG0116	2017-07-19 06:15:00+03	2017-07-19 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-19 06:17:00+03	2017-07-19 07:07:00+03
26330	PG0116	2017-09-09 06:15:00+03	2017-09-09 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26331	PG0116	2017-08-28 06:15:00+03	2017-08-28 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26332	PG0116	2017-09-07 06:15:00+03	2017-09-07 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26333	PG0116	2017-08-14 06:15:00+03	2017-08-14 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-14 06:15:00+03	2017-08-14 07:04:00+03
26334	PG0116	2017-08-11 06:15:00+03	2017-08-11 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-11 09:26:00+03	2017-08-11 10:16:00+03
26335	PG0116	2017-08-07 06:15:00+03	2017-08-07 07:05:00+03	KHV	BQS	Arrived	SU9	2017-08-07 09:44:00+03	2017-08-07 10:33:00+03
26336	PG0116	2017-07-24 06:15:00+03	2017-07-24 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-24 06:15:00+03	2017-07-24 07:05:00+03
26337	PG0116	2017-07-18 06:15:00+03	2017-07-18 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-18 10:02:00+03	2017-07-18 10:52:00+03
26338	PG0116	2017-09-11 06:15:00+03	2017-09-11 07:05:00+03	KHV	BQS	Scheduled	SU9	\N	\N
26339	PG0116	2017-07-16 06:15:00+03	2017-07-16 07:05:00+03	KHV	BQS	Arrived	SU9	2017-07-16 06:17:00+03	2017-07-16 07:06:00+03
26340	PG0400	2017-09-10 12:00:00+03	2017-09-10 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26341	PG0400	2017-08-26 12:00:00+03	2017-08-26 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26342	PG0400	2017-07-31 12:00:00+03	2017-07-31 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-31 12:04:00+03	2017-07-31 14:00:00+03
26343	PG0401	2017-07-27 07:40:00+03	2017-07-27 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-27 07:43:00+03	2017-07-27 09:37:00+03
26344	PG0400	2017-07-27 12:00:00+03	2017-07-27 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-27 12:03:00+03	2017-07-27 13:57:00+03
26345	PG0401	2017-07-17 07:40:00+03	2017-07-17 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-17 07:45:00+03	2017-07-17 09:42:00+03
26346	PG0401	2017-08-30 07:40:00+03	2017-08-30 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26347	PG0400	2017-08-30 12:00:00+03	2017-08-30 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26348	PG0400	2017-08-02 12:00:00+03	2017-08-02 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-02 12:04:00+03	2017-08-02 13:59:00+03
26349	PG0400	2017-08-19 12:00:00+03	2017-08-19 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26350	PG0401	2017-08-02 07:40:00+03	2017-08-02 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-02 07:42:00+03	2017-08-02 09:38:00+03
26351	PG0400	2017-07-17 12:00:00+03	2017-07-17 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-17 12:06:00+03	2017-07-17 14:01:00+03
26352	PG0401	2017-08-23 07:40:00+03	2017-08-23 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26353	PG0401	2017-07-21 07:40:00+03	2017-07-21 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-21 07:43:00+03	2017-07-21 09:38:00+03
26354	PG0400	2017-07-21 12:00:00+03	2017-07-21 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-21 12:05:00+03	2017-07-21 13:59:00+03
26355	PG0400	2017-08-23 12:00:00+03	2017-08-23 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26356	PG0401	2017-07-22 07:40:00+03	2017-07-22 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-22 07:42:00+03	2017-07-22 09:37:00+03
26357	PG0400	2017-09-07 12:00:00+03	2017-09-07 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26358	PG0400	2017-08-05 12:00:00+03	2017-08-05 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-05 12:03:00+03	2017-08-05 13:59:00+03
26359	PG0401	2017-08-31 07:40:00+03	2017-08-31 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26360	PG0401	2017-08-05 07:40:00+03	2017-08-05 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-05 07:43:00+03	2017-08-05 09:38:00+03
26361	PG0400	2017-08-07 12:00:00+03	2017-08-07 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-07 12:01:00+03	2017-08-07 13:54:00+03
26362	PG0400	2017-07-28 12:00:00+03	2017-07-28 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-28 12:03:00+03	2017-07-28 13:57:00+03
26363	PG0401	2017-08-07 07:40:00+03	2017-08-07 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-07 07:40:00+03	2017-08-07 09:35:00+03
26364	PG0400	2017-09-14 12:00:00+03	2017-09-14 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26365	PG0400	2017-08-31 12:00:00+03	2017-08-31 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26366	PG0401	2017-08-21 07:40:00+03	2017-08-21 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26367	PG0401	2017-08-26 07:40:00+03	2017-08-26 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26368	PG0401	2017-08-08 07:40:00+03	2017-08-08 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-08 07:43:00+03	2017-08-08 09:37:00+03
26369	PG0400	2017-08-08 12:00:00+03	2017-08-08 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-08 12:02:00+03	2017-08-08 13:57:00+03
26370	PG0401	2017-07-28 07:40:00+03	2017-07-28 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-28 07:42:00+03	2017-07-28 09:38:00+03
26371	PG0400	2017-08-21 12:00:00+03	2017-08-21 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26372	PG0400	2017-08-10 12:00:00+03	2017-08-10 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-10 12:06:00+03	2017-08-10 14:02:00+03
26373	PG0401	2017-08-06 07:40:00+03	2017-08-06 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-06 07:42:00+03	2017-08-06 09:40:00+03
26374	PG0401	2017-08-10 07:40:00+03	2017-08-10 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-10 07:45:00+03	2017-08-10 09:42:00+03
26375	PG0401	2017-08-09 07:40:00+03	2017-08-09 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-09 07:43:00+03	2017-08-09 09:38:00+03
26376	PG0400	2017-08-09 12:00:00+03	2017-08-09 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-09 12:03:00+03	2017-08-09 13:56:00+03
26377	PG0401	2017-08-25 07:40:00+03	2017-08-25 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26378	PG0400	2017-08-15 12:00:00+03	2017-08-15 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-15 12:02:00+03	2017-08-15 13:58:00+03
26379	PG0401	2017-08-15 07:40:00+03	2017-08-15 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-15 07:44:00+03	2017-08-15 09:39:00+03
26380	PG0400	2017-08-25 12:00:00+03	2017-08-25 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26381	PG0400	2017-07-30 12:00:00+03	2017-07-30 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-30 12:03:00+03	2017-07-30 13:56:00+03
26382	PG0401	2017-08-12 07:40:00+03	2017-08-12 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-12 07:44:00+03	2017-08-12 09:37:00+03
26383	PG0400	2017-08-12 12:00:00+03	2017-08-12 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-12 12:00:00+03	2017-08-12 13:52:00+03
26384	PG0401	2017-07-30 07:40:00+03	2017-07-30 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-30 07:44:00+03	2017-07-30 09:38:00+03
26385	PG0401	2017-07-19 07:40:00+03	2017-07-19 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-19 07:45:00+03	2017-07-19 09:38:00+03
26386	PG0400	2017-08-17 12:00:00+03	2017-08-17 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26387	PG0401	2017-09-08 07:40:00+03	2017-09-08 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26388	PG0400	2017-09-08 12:00:00+03	2017-09-08 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26389	PG0400	2017-09-09 12:00:00+03	2017-09-09 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26390	PG0400	2017-09-02 12:00:00+03	2017-09-02 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26391	PG0401	2017-09-02 07:40:00+03	2017-09-02 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26392	PG0401	2017-09-09 07:40:00+03	2017-09-09 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26393	PG0400	2017-07-19 12:00:00+03	2017-07-19 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-19 12:02:00+03	2017-07-19 13:58:00+03
26394	PG0401	2017-08-01 07:40:00+03	2017-08-01 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-01 07:43:00+03	2017-08-01 09:37:00+03
26395	PG0400	2017-08-01 12:00:00+03	2017-08-01 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-01 12:03:00+03	2017-08-01 13:58:00+03
26396	PG0401	2017-07-31 07:40:00+03	2017-07-31 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-31 07:44:00+03	2017-07-31 09:39:00+03
26397	PG0401	2017-07-23 07:40:00+03	2017-07-23 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-23 07:44:00+03	2017-07-23 09:38:00+03
26398	PG0400	2017-09-06 12:00:00+03	2017-09-06 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26399	PG0400	2017-08-20 12:00:00+03	2017-08-20 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26400	PG0401	2017-08-20 07:40:00+03	2017-08-20 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26401	PG0401	2017-09-06 07:40:00+03	2017-09-06 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26402	PG0400	2017-07-23 12:00:00+03	2017-07-23 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-23 12:00:00+03	2017-07-23 13:55:00+03
26403	PG0400	2017-07-16 12:00:00+03	2017-07-16 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-16 12:02:00+03	2017-07-16 13:56:00+03
26404	PG0401	2017-07-16 07:40:00+03	2017-07-16 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-16 07:43:00+03	2017-07-16 09:37:00+03
26405	PG0401	2017-07-26 07:40:00+03	2017-07-26 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-26 07:44:00+03	2017-07-26 09:38:00+03
26406	PG0400	2017-07-26 12:00:00+03	2017-07-26 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-26 12:01:00+03	2017-07-26 13:55:00+03
26407	PG0400	2017-09-13 12:00:00+03	2017-09-13 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26408	PG0400	2017-07-29 12:00:00+03	2017-07-29 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-29 12:00:00+03	2017-07-29 13:55:00+03
26409	PG0400	2017-09-01 12:00:00+03	2017-09-01 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26410	PG0401	2017-09-01 07:40:00+03	2017-09-01 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26411	PG0400	2017-07-20 12:00:00+03	2017-07-20 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-20 12:00:00+03	2017-07-20 13:55:00+03
26412	PG0401	2017-07-20 07:40:00+03	2017-07-20 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-20 07:43:00+03	2017-07-20 09:37:00+03
26413	PG0400	2017-09-12 12:00:00+03	2017-09-12 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26414	PG0400	2017-08-28 12:00:00+03	2017-08-28 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26415	PG0400	2017-07-24 12:00:00+03	2017-07-24 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-24 12:01:00+03	2017-07-24 13:56:00+03
26416	PG0401	2017-07-24 07:40:00+03	2017-07-24 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-24 07:44:00+03	2017-07-24 09:39:00+03
26417	PG0401	2017-09-12 07:40:00+03	2017-09-12 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26418	PG0401	2017-09-05 07:40:00+03	2017-09-05 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26419	PG0400	2017-09-05 12:00:00+03	2017-09-05 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26420	PG0400	2017-07-18 12:00:00+03	2017-07-18 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-18 12:06:00+03	2017-07-18 14:01:00+03
26421	PG0401	2017-09-10 07:40:00+03	2017-09-10 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26422	PG0401	2017-09-07 07:40:00+03	2017-09-07 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26423	PG0400	2017-07-22 12:00:00+03	2017-07-22 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-22 12:00:00+03	2017-07-22 13:55:00+03
26424	PG0400	2017-08-03 12:00:00+03	2017-08-03 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-03 12:01:00+03	2017-08-03 13:57:00+03
26425	PG0401	2017-08-03 07:40:00+03	2017-08-03 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-03 07:42:00+03	2017-08-03 09:34:00+03
26426	PG0401	2017-07-29 07:40:00+03	2017-07-29 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-29 07:42:00+03	2017-07-29 09:36:00+03
26427	PG0400	2017-08-16 12:00:00+03	2017-08-16 13:55:00+03	KHV	UUS	On Time	CN1	\N	\N
26428	PG0401	2017-08-16 07:40:00+03	2017-08-16 09:35:00+03	KHV	UUS	On Time	CN1	\N	\N
26429	PG0401	2017-08-29 07:40:00+03	2017-08-29 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26430	PG0401	2017-08-24 07:40:00+03	2017-08-24 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26431	PG0400	2017-08-27 12:00:00+03	2017-08-27 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26432	PG0401	2017-08-27 07:40:00+03	2017-08-27 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26433	PG0400	2017-08-29 12:00:00+03	2017-08-29 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26434	PG0401	2017-08-04 07:40:00+03	2017-08-04 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-04 11:05:00+03	2017-08-04 13:01:00+03
26435	PG0400	2017-08-24 12:00:00+03	2017-08-24 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26436	PG0401	2017-08-17 07:40:00+03	2017-08-17 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26437	PG0401	2017-08-28 07:40:00+03	2017-08-28 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26438	PG0401	2017-08-22 07:40:00+03	2017-08-22 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26439	PG0401	2017-09-11 07:40:00+03	2017-09-11 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26440	PG0400	2017-09-11 12:00:00+03	2017-09-11 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26441	PG0401	2017-08-11 07:40:00+03	2017-08-11 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-11 07:41:00+03	2017-08-11 09:37:00+03
26442	PG0400	2017-08-11 12:00:00+03	2017-08-11 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-11 12:01:00+03	2017-08-11 13:54:00+03
26443	PG0400	2017-08-04 12:00:00+03	2017-08-04 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-04 12:02:00+03	2017-08-04 13:55:00+03
26444	PG0401	2017-09-13 07:40:00+03	2017-09-13 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26445	PG0400	2017-09-04 12:00:00+03	2017-09-04 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26446	PG0401	2017-07-25 07:40:00+03	2017-07-25 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-25 07:46:00+03	2017-07-25 09:42:00+03
26447	PG0401	2017-09-04 07:40:00+03	2017-09-04 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26448	PG0401	2017-08-13 07:40:00+03	2017-08-13 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-13 07:42:00+03	2017-08-13 09:37:00+03
26449	PG0400	2017-07-25 12:00:00+03	2017-07-25 13:55:00+03	KHV	UUS	Arrived	CN1	2017-07-25 12:05:00+03	2017-07-25 14:00:00+03
26450	PG0401	2017-09-14 07:40:00+03	2017-09-14 09:35:00+03	KHV	UUS	Cancelled	CN1	\N	\N
26451	PG0401	2017-08-14 07:40:00+03	2017-08-14 09:35:00+03	KHV	UUS	Arrived	CN1	2017-08-14 07:42:00+03	2017-08-14 09:38:00+03
26452	PG0400	2017-08-06 12:00:00+03	2017-08-06 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-06 12:02:00+03	2017-08-06 13:58:00+03
26453	PG0400	2017-08-14 12:00:00+03	2017-08-14 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-14 12:05:00+03	2017-08-14 13:59:00+03
26454	PG0400	2017-08-18 12:00:00+03	2017-08-18 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26455	PG0400	2017-08-13 12:00:00+03	2017-08-13 13:55:00+03	KHV	UUS	Arrived	CN1	2017-08-13 12:04:00+03	2017-08-13 13:59:00+03
26456	PG0400	2017-08-22 12:00:00+03	2017-08-22 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26457	PG0401	2017-09-03 07:40:00+03	2017-09-03 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26458	PG0400	2017-09-03 12:00:00+03	2017-09-03 13:55:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26459	PG0401	2017-08-18 07:40:00+03	2017-08-18 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26460	PG0401	2017-07-18 07:40:00+03	2017-07-18 09:35:00+03	KHV	UUS	Arrived	CN1	2017-07-18 07:42:00+03	2017-07-18 09:39:00+03
26461	PG0401	2017-08-19 07:40:00+03	2017-08-19 09:35:00+03	KHV	UUS	Scheduled	CN1	\N	\N
26462	PG0652	2017-07-27 05:45:00+03	2017-07-27 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-27 05:47:00+03	2017-07-27 09:13:00+03
26463	PG0652	2017-08-29 05:45:00+03	2017-08-29 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26464	PG0652	2017-08-26 05:45:00+03	2017-08-26 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26465	PG0652	2017-09-09 05:45:00+03	2017-09-09 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26466	PG0652	2017-07-22 05:45:00+03	2017-07-22 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-22 05:47:00+03	2017-07-22 09:11:00+03
26467	PG0652	2017-09-05 05:45:00+03	2017-09-05 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26468	PG0652	2017-09-14 05:45:00+03	2017-09-14 09:10:00+03	KHV	UIK	Cancelled	CR2	\N	\N
26469	PG0652	2017-07-29 05:45:00+03	2017-07-29 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-29 05:48:00+03	2017-07-29 09:15:00+03
26470	PG0652	2017-07-25 05:45:00+03	2017-07-25 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-25 05:48:00+03	2017-07-25 09:11:00+03
26471	PG0652	2017-08-19 05:45:00+03	2017-08-19 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26472	PG0652	2017-07-20 05:45:00+03	2017-07-20 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-20 05:46:00+03	2017-07-20 09:14:00+03
26473	PG0652	2017-08-10 05:45:00+03	2017-08-10 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-10 05:51:00+03	2017-08-10 09:17:00+03
26474	PG0652	2017-08-01 05:45:00+03	2017-08-01 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-01 05:47:00+03	2017-08-01 09:14:00+03
26475	PG0652	2017-08-03 05:45:00+03	2017-08-03 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-03 05:47:00+03	2017-08-03 09:15:00+03
26476	PG0652	2017-09-02 05:45:00+03	2017-09-02 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26477	PG0652	2017-08-17 05:45:00+03	2017-08-17 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26478	PG0652	2017-09-07 05:45:00+03	2017-09-07 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26479	PG0652	2017-07-18 05:45:00+03	2017-07-18 09:10:00+03	KHV	UIK	Arrived	CR2	2017-07-18 05:50:00+03	2017-07-18 09:18:00+03
26480	PG0652	2017-08-22 05:45:00+03	2017-08-22 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26481	PG0652	2017-08-24 05:45:00+03	2017-08-24 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26482	PG0652	2017-08-12 05:45:00+03	2017-08-12 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-12 05:48:00+03	2017-08-12 09:12:00+03
26483	PG0652	2017-08-05 05:45:00+03	2017-08-05 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-05 05:45:00+03	2017-08-05 09:09:00+03
26484	PG0652	2017-09-12 05:45:00+03	2017-09-12 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26485	PG0652	2017-08-31 05:45:00+03	2017-08-31 09:10:00+03	KHV	UIK	Scheduled	CR2	\N	\N
26486	PG0652	2017-08-08 05:45:00+03	2017-08-08 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-08 05:46:00+03	2017-08-08 09:12:00+03
26487	PG0652	2017-08-15 05:45:00+03	2017-08-15 09:10:00+03	KHV	UIK	Arrived	CR2	2017-08-15 05:49:00+03	2017-08-15 09:11:00+03
26488	PG0088	2017-08-26 03:20:00+03	2017-08-26 07:25:00+03	KHV	DYR	Scheduled	319	\N	\N
26489	PG0088	2017-09-09 03:20:00+03	2017-09-09 07:25:00+03	KHV	DYR	Scheduled	319	\N	\N
26490	PG0088	2017-09-02 03:20:00+03	2017-09-02 07:25:00+03	KHV	DYR	Scheduled	319	\N	\N
26491	PG0088	2017-08-05 03:20:00+03	2017-08-05 07:25:00+03	KHV	DYR	Arrived	319	2017-08-05 03:25:00+03	2017-08-05 07:30:00+03
26492	PG0088	2017-07-29 03:20:00+03	2017-07-29 07:25:00+03	KHV	DYR	Arrived	319	2017-07-29 03:23:00+03	2017-07-29 07:30:00+03
26493	PG0088	2017-08-19 03:20:00+03	2017-08-19 07:25:00+03	KHV	DYR	Scheduled	319	\N	\N
26494	PG0088	2017-08-12 03:20:00+03	2017-08-12 07:25:00+03	KHV	DYR	Arrived	319	2017-08-12 03:26:00+03	2017-08-12 07:28:00+03
26495	PG0088	2017-07-22 03:20:00+03	2017-07-22 07:25:00+03	KHV	DYR	Arrived	319	2017-07-22 03:22:00+03	2017-07-22 07:31:00+03
26496	PG0327	2017-07-28 11:25:00+03	2017-07-28 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-28 11:27:00+03	2017-07-28 12:16:00+03
26497	PG0327	2017-07-27 11:25:00+03	2017-07-27 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-27 11:26:00+03	2017-07-27 12:15:00+03
26498	PG0327	2017-09-10 11:25:00+03	2017-09-10 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26499	PG0327	2017-08-17 11:25:00+03	2017-08-17 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26500	PG0327	2017-07-22 11:25:00+03	2017-07-22 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-22 11:28:00+03	2017-07-22 12:18:00+03
26501	PG0327	2017-09-04 11:25:00+03	2017-09-04 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26502	PG0327	2017-08-18 11:25:00+03	2017-08-18 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26503	PG0327	2017-08-11 11:25:00+03	2017-08-11 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-11 11:27:00+03	2017-08-11 12:17:00+03
26504	PG0327	2017-08-10 11:25:00+03	2017-08-10 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-10 11:27:00+03	2017-08-10 12:17:00+03
26505	PG0327	2017-09-05 11:25:00+03	2017-09-05 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26506	PG0327	2017-08-24 11:25:00+03	2017-08-24 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26507	PG0327	2017-08-06 11:25:00+03	2017-08-06 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-06 11:27:00+03	2017-08-06 12:17:00+03
26508	PG0327	2017-08-04 11:25:00+03	2017-08-04 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-04 11:29:00+03	2017-08-04 12:19:00+03
26509	PG0327	2017-08-13 11:25:00+03	2017-08-13 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-13 11:30:00+03	2017-08-13 12:20:00+03
26510	PG0327	2017-07-16 11:25:00+03	2017-07-16 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-16 11:26:00+03	2017-07-16 12:16:00+03
26511	PG0327	2017-08-02 11:25:00+03	2017-08-02 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-02 11:28:00+03	2017-08-02 12:18:00+03
26512	PG0327	2017-08-25 11:25:00+03	2017-08-25 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26513	PG0327	2017-08-09 11:25:00+03	2017-08-09 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-09 11:28:00+03	2017-08-09 12:18:00+03
26514	PG0327	2017-09-12 11:25:00+03	2017-09-12 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26515	PG0327	2017-08-31 11:25:00+03	2017-08-31 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26516	PG0327	2017-08-21 11:25:00+03	2017-08-21 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26517	PG0327	2017-08-22 11:25:00+03	2017-08-22 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26518	PG0327	2017-07-25 11:25:00+03	2017-07-25 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-25 11:25:00+03	2017-07-25 12:15:00+03
26519	PG0327	2017-09-11 11:25:00+03	2017-09-11 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26520	PG0327	2017-08-19 11:25:00+03	2017-08-19 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26521	PG0327	2017-09-09 11:25:00+03	2017-09-09 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26522	PG0327	2017-07-31 11:25:00+03	2017-07-31 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-31 11:29:00+03	2017-07-31 12:20:00+03
26523	PG0327	2017-07-21 11:25:00+03	2017-07-21 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-21 14:33:00+03	2017-07-21 15:23:00+03
26524	PG0327	2017-09-02 11:25:00+03	2017-09-02 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26525	PG0327	2017-08-14 11:25:00+03	2017-08-14 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-14 11:28:00+03	2017-08-14 12:19:00+03
26526	PG0327	2017-07-18 11:25:00+03	2017-07-18 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-18 11:27:00+03	2017-07-18 12:17:00+03
26527	PG0327	2017-09-03 11:25:00+03	2017-09-03 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26528	PG0327	2017-07-17 11:25:00+03	2017-07-17 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-17 11:26:00+03	2017-07-17 12:16:00+03
26529	PG0327	2017-09-01 11:25:00+03	2017-09-01 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26530	PG0327	2017-08-26 11:25:00+03	2017-08-26 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26531	PG0327	2017-07-29 11:25:00+03	2017-07-29 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-29 11:28:00+03	2017-07-29 12:18:00+03
26532	PG0327	2017-08-15 11:25:00+03	2017-08-15 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-15 11:28:00+03	2017-08-15 12:18:00+03
26533	PG0327	2017-09-06 11:25:00+03	2017-09-06 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26534	PG0327	2017-08-30 11:25:00+03	2017-08-30 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26535	PG0327	2017-08-05 11:25:00+03	2017-08-05 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-05 14:23:00+03	2017-08-05 15:13:00+03
26536	PG0327	2017-08-20 11:25:00+03	2017-08-20 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26537	PG0327	2017-08-07 11:25:00+03	2017-08-07 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-07 11:32:00+03	2017-08-07 12:22:00+03
26538	PG0327	2017-07-24 11:25:00+03	2017-07-24 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-24 11:27:00+03	2017-07-24 12:17:00+03
26539	PG0327	2017-08-27 11:25:00+03	2017-08-27 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26540	PG0327	2017-07-19 11:25:00+03	2017-07-19 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-19 11:25:00+03	2017-07-19 12:15:00+03
26541	PG0327	2017-09-08 11:25:00+03	2017-09-08 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26542	PG0327	2017-07-23 11:25:00+03	2017-07-23 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-23 11:27:00+03	2017-07-23 12:17:00+03
26543	PG0327	2017-09-14 11:25:00+03	2017-09-14 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26544	PG0327	2017-07-30 11:25:00+03	2017-07-30 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-30 11:30:00+03	2017-07-30 12:20:00+03
26545	PG0327	2017-07-20 11:25:00+03	2017-07-20 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-20 11:27:00+03	2017-07-20 12:16:00+03
26546	PG0327	2017-08-29 11:25:00+03	2017-08-29 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26547	PG0327	2017-08-12 11:25:00+03	2017-08-12 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-12 11:31:00+03	2017-08-12 12:21:00+03
26548	PG0327	2017-09-07 11:25:00+03	2017-09-07 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26549	PG0327	2017-07-26 11:25:00+03	2017-07-26 12:15:00+03	KHV	VVO	Arrived	SU9	2017-07-26 11:29:00+03	2017-07-26 12:19:00+03
26550	PG0327	2017-08-03 11:25:00+03	2017-08-03 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-03 11:27:00+03	2017-08-03 12:17:00+03
26551	PG0327	2017-08-23 11:25:00+03	2017-08-23 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26552	PG0327	2017-09-13 11:25:00+03	2017-09-13 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26553	PG0327	2017-08-08 11:25:00+03	2017-08-08 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-08 11:25:00+03	2017-08-08 12:15:00+03
26554	PG0327	2017-08-28 11:25:00+03	2017-08-28 12:15:00+03	KHV	VVO	Scheduled	SU9	\N	\N
26555	PG0327	2017-08-16 11:25:00+03	2017-08-16 12:15:00+03	KHV	VVO	On Time	SU9	\N	\N
26556	PG0327	2017-08-01 11:25:00+03	2017-08-01 12:15:00+03	KHV	VVO	Arrived	SU9	2017-08-01 11:26:00+03	2017-08-01 12:16:00+03
26557	PG0201	2017-07-28 12:10:00+03	2017-07-28 20:35:00+03	VVO	VKO	Arrived	763	2017-07-28 12:12:00+03	2017-07-28 20:32:00+03
26558	PG0201	2017-08-22 12:10:00+03	2017-08-22 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26559	PG0201	2017-08-11 12:10:00+03	2017-08-11 20:35:00+03	VVO	VKO	Arrived	763	2017-08-11 12:16:00+03	2017-08-11 20:40:00+03
26560	PG0201	2017-09-06 12:10:00+03	2017-09-06 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26561	PG0201	2017-08-13 12:10:00+03	2017-08-13 20:35:00+03	VVO	VKO	Arrived	763	2017-08-13 12:15:00+03	2017-08-13 20:48:00+03
26562	PG0201	2017-08-07 12:10:00+03	2017-08-07 20:35:00+03	VVO	VKO	Arrived	763	2017-08-07 12:15:00+03	2017-08-07 20:34:00+03
26563	PG0201	2017-08-06 12:10:00+03	2017-08-06 20:35:00+03	VVO	VKO	Arrived	763	2017-08-06 12:10:00+03	2017-08-06 20:43:00+03
26564	PG0201	2017-07-18 12:10:00+03	2017-07-18 20:35:00+03	VVO	VKO	Arrived	763	2017-07-18 12:12:00+03	2017-07-18 20:37:00+03
26565	PG0201	2017-08-15 12:10:00+03	2017-08-15 20:35:00+03	VVO	VKO	Departed	763	2017-08-15 12:10:00+03	\N
26566	PG0201	2017-09-10 12:10:00+03	2017-09-10 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26567	PG0201	2017-08-10 12:10:00+03	2017-08-10 20:35:00+03	VVO	VKO	Arrived	763	2017-08-10 12:15:00+03	2017-08-10 20:45:00+03
26568	PG0201	2017-08-16 12:10:00+03	2017-08-16 20:35:00+03	VVO	VKO	On Time	763	\N	\N
26569	PG0201	2017-07-17 12:10:00+03	2017-07-17 20:35:00+03	VVO	VKO	Arrived	763	2017-07-17 12:15:00+03	2017-07-17 20:33:00+03
26570	PG0201	2017-07-26 12:10:00+03	2017-07-26 20:35:00+03	VVO	VKO	Arrived	763	2017-07-26 12:15:00+03	2017-07-26 20:47:00+03
26571	PG0201	2017-08-29 12:10:00+03	2017-08-29 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26572	PG0201	2017-08-03 12:10:00+03	2017-08-03 20:35:00+03	VVO	VKO	Arrived	763	2017-08-03 12:12:00+03	2017-08-03 20:39:00+03
26573	PG0201	2017-07-30 12:10:00+03	2017-07-30 20:35:00+03	VVO	VKO	Arrived	763	2017-07-30 12:11:00+03	2017-07-30 20:41:00+03
26574	PG0201	2017-08-21 12:10:00+03	2017-08-21 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26575	PG0201	2017-08-08 12:10:00+03	2017-08-08 20:35:00+03	VVO	VKO	Arrived	763	2017-08-08 12:14:00+03	2017-08-08 20:37:00+03
26576	PG0201	2017-08-25 12:10:00+03	2017-08-25 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26577	PG0201	2017-08-31 12:10:00+03	2017-08-31 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26578	PG0201	2017-09-08 12:10:00+03	2017-09-08 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26579	PG0201	2017-07-29 12:10:00+03	2017-07-29 20:35:00+03	VVO	VKO	Arrived	763	2017-07-29 12:13:00+03	2017-07-29 20:44:00+03
26580	PG0201	2017-08-28 12:10:00+03	2017-08-28 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26581	PG0201	2017-08-09 12:10:00+03	2017-08-09 20:35:00+03	VVO	VKO	Arrived	763	2017-08-09 12:11:00+03	2017-08-09 20:38:00+03
26582	PG0201	2017-08-05 12:10:00+03	2017-08-05 20:35:00+03	VVO	VKO	Arrived	763	2017-08-05 12:13:00+03	2017-08-05 20:37:00+03
26583	PG0201	2017-09-07 12:10:00+03	2017-09-07 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26584	PG0201	2017-08-19 12:10:00+03	2017-08-19 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26585	PG0201	2017-07-23 12:10:00+03	2017-07-23 20:35:00+03	VVO	VKO	Arrived	763	2017-07-23 12:11:00+03	2017-07-23 20:41:00+03
26586	PG0201	2017-09-11 12:10:00+03	2017-09-11 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26587	PG0201	2017-09-12 12:10:00+03	2017-09-12 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26588	PG0201	2017-07-16 12:10:00+03	2017-07-16 20:35:00+03	VVO	VKO	Arrived	763	2017-07-16 12:15:00+03	2017-07-16 20:32:00+03
26589	PG0201	2017-08-18 12:10:00+03	2017-08-18 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26590	PG0201	2017-08-24 12:10:00+03	2017-08-24 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26591	PG0201	2017-08-02 12:10:00+03	2017-08-02 20:35:00+03	VVO	VKO	Arrived	763	2017-08-02 12:15:00+03	2017-08-02 20:33:00+03
26592	PG0201	2017-08-12 12:10:00+03	2017-08-12 20:35:00+03	VVO	VKO	Arrived	763	2017-08-12 12:18:00+03	2017-08-12 20:39:00+03
26593	PG0201	2017-07-27 12:10:00+03	2017-07-27 20:35:00+03	VVO	VKO	Arrived	763	2017-07-27 12:12:00+03	2017-07-27 20:40:00+03
26594	PG0201	2017-09-04 12:10:00+03	2017-09-04 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26595	PG0201	2017-07-24 12:10:00+03	2017-07-24 20:35:00+03	VVO	VKO	Arrived	763	2017-07-24 12:11:00+03	2017-07-24 20:32:00+03
26596	PG0201	2017-09-02 12:10:00+03	2017-09-02 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26597	PG0201	2017-07-20 12:10:00+03	2017-07-20 20:35:00+03	VVO	VKO	Arrived	763	2017-07-20 12:12:00+03	2017-07-20 20:32:00+03
26598	PG0201	2017-07-19 12:10:00+03	2017-07-19 20:35:00+03	VVO	VKO	Arrived	763	2017-07-19 12:14:00+03	2017-07-19 20:48:00+03
26599	PG0201	2017-09-03 12:10:00+03	2017-09-03 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26600	PG0201	2017-08-26 12:10:00+03	2017-08-26 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26601	PG0201	2017-08-27 12:10:00+03	2017-08-27 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26602	PG0201	2017-09-13 12:10:00+03	2017-09-13 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26603	PG0201	2017-09-05 12:10:00+03	2017-09-05 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26604	PG0201	2017-09-14 12:10:00+03	2017-09-14 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26605	PG0201	2017-07-31 12:10:00+03	2017-07-31 20:35:00+03	VVO	VKO	Arrived	763	2017-07-31 12:14:00+03	2017-07-31 20:47:00+03
26606	PG0201	2017-08-17 12:10:00+03	2017-08-17 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26607	PG0201	2017-07-25 12:10:00+03	2017-07-25 20:35:00+03	VVO	VKO	Arrived	763	2017-07-25 12:11:00+03	2017-07-25 20:37:00+03
26608	PG0201	2017-08-30 12:10:00+03	2017-08-30 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26609	PG0201	2017-08-20 12:10:00+03	2017-08-20 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26610	PG0201	2017-08-04 12:10:00+03	2017-08-04 20:35:00+03	VVO	VKO	Arrived	763	2017-08-04 12:14:00+03	2017-08-04 20:35:00+03
26611	PG0201	2017-09-09 12:10:00+03	2017-09-09 20:35:00+03	VVO	VKO	Cancelled	763	\N	\N
26612	PG0201	2017-08-14 12:10:00+03	2017-08-14 20:35:00+03	VVO	VKO	Arrived	763	2017-08-14 12:16:00+03	2017-08-14 20:44:00+03
26613	PG0201	2017-07-21 12:10:00+03	2017-07-21 20:35:00+03	VVO	VKO	Arrived	763	2017-07-21 12:14:00+03	2017-07-21 20:40:00+03
26614	PG0201	2017-08-01 12:10:00+03	2017-08-01 20:35:00+03	VVO	VKO	Arrived	763	2017-08-01 12:12:00+03	2017-08-01 20:41:00+03
26615	PG0201	2017-08-23 12:10:00+03	2017-08-23 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26616	PG0201	2017-07-22 12:10:00+03	2017-07-22 20:35:00+03	VVO	VKO	Arrived	763	2017-07-22 12:12:00+03	2017-07-22 20:29:00+03
26617	PG0201	2017-09-01 12:10:00+03	2017-09-01 20:35:00+03	VVO	VKO	Scheduled	763	\N	\N
26618	PG0660	2017-09-02 03:55:00+03	2017-09-02 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26619	PG0660	2017-08-22 03:55:00+03	2017-08-22 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26620	PG0660	2017-08-31 03:55:00+03	2017-08-31 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26621	PG0660	2017-08-11 03:55:00+03	2017-08-11 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-11 03:59:00+03	2017-08-11 07:12:00+03
26622	PG0660	2017-09-13 03:55:00+03	2017-09-13 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26623	PG0660	2017-07-18 03:55:00+03	2017-07-18 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-18 03:57:00+03	2017-07-18 07:15:00+03
26624	PG0660	2017-08-12 03:55:00+03	2017-08-12 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-12 03:56:00+03	2017-08-12 07:09:00+03
26625	PG0660	2017-07-29 03:55:00+03	2017-07-29 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-29 04:00:00+03	2017-07-29 07:20:00+03
26626	PG0660	2017-09-07 03:55:00+03	2017-09-07 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26627	PG0660	2017-09-06 03:55:00+03	2017-09-06 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26628	PG0660	2017-09-03 03:55:00+03	2017-09-03 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26629	PG0660	2017-07-31 03:55:00+03	2017-07-31 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-31 03:58:00+03	2017-07-31 07:18:00+03
26630	PG0660	2017-08-10 03:55:00+03	2017-08-10 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-10 03:59:00+03	2017-08-10 07:15:00+03
26631	PG0660	2017-08-26 03:55:00+03	2017-08-26 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26632	PG0660	2017-07-28 03:55:00+03	2017-07-28 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-28 03:55:00+03	2017-07-28 07:10:00+03
26633	PG0660	2017-08-13 03:55:00+03	2017-08-13 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-13 03:56:00+03	2017-08-13 07:13:00+03
26634	PG0660	2017-07-17 03:55:00+03	2017-07-17 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-17 03:57:00+03	2017-07-17 07:11:00+03
26635	PG0660	2017-09-01 03:55:00+03	2017-09-01 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26636	PG0660	2017-08-30 03:55:00+03	2017-08-30 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26637	PG0660	2017-08-01 03:55:00+03	2017-08-01 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-01 04:00:00+03	2017-08-01 07:15:00+03
26638	PG0660	2017-08-21 03:55:00+03	2017-08-21 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26639	PG0660	2017-09-08 03:55:00+03	2017-09-08 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26640	PG0660	2017-07-27 03:55:00+03	2017-07-27 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-27 03:58:00+03	2017-07-27 07:12:00+03
26641	PG0660	2017-07-19 03:55:00+03	2017-07-19 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-19 03:57:00+03	2017-07-19 07:09:00+03
26642	PG0660	2017-08-14 03:55:00+03	2017-08-14 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-14 03:59:00+03	2017-08-14 07:10:00+03
26643	PG0660	2017-08-09 03:55:00+03	2017-08-09 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-09 03:57:00+03	2017-08-09 07:10:00+03
26644	PG0660	2017-09-05 03:55:00+03	2017-09-05 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26645	PG0660	2017-07-26 03:55:00+03	2017-07-26 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-26 03:59:00+03	2017-07-26 07:14:00+03
26646	PG0660	2017-08-23 03:55:00+03	2017-08-23 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26647	PG0660	2017-08-02 03:55:00+03	2017-08-02 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-02 03:57:00+03	2017-08-02 07:12:00+03
26648	PG0660	2017-09-12 03:55:00+03	2017-09-12 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26649	PG0660	2017-08-15 03:55:00+03	2017-08-15 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-15 03:56:00+03	2017-08-15 07:11:00+03
26650	PG0660	2017-08-08 03:55:00+03	2017-08-08 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-08 03:58:00+03	2017-08-08 07:14:00+03
26651	PG0660	2017-08-29 03:55:00+03	2017-08-29 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26652	PG0660	2017-09-09 03:55:00+03	2017-09-09 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26653	PG0660	2017-08-25 03:55:00+03	2017-08-25 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26654	PG0660	2017-07-25 03:55:00+03	2017-07-25 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-25 03:56:00+03	2017-07-25 07:09:00+03
26655	PG0660	2017-08-20 03:55:00+03	2017-08-20 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26656	PG0660	2017-08-16 03:55:00+03	2017-08-16 07:10:00+03	VVO	IKT	On Time	CR2	\N	\N
26657	PG0660	2017-08-03 03:55:00+03	2017-08-03 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-03 04:01:00+03	2017-08-03 07:17:00+03
26658	PG0660	2017-07-16 03:55:00+03	2017-07-16 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-16 03:56:00+03	2017-07-16 07:08:00+03
26659	PG0660	2017-07-20 03:55:00+03	2017-07-20 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-20 04:00:00+03	2017-07-20 07:13:00+03
26660	PG0660	2017-07-24 03:55:00+03	2017-07-24 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-24 03:57:00+03	2017-07-24 07:15:00+03
26661	PG0660	2017-09-04 03:55:00+03	2017-09-04 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26662	PG0660	2017-08-07 03:55:00+03	2017-08-07 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-07 03:59:00+03	2017-08-07 07:11:00+03
26663	PG0660	2017-08-04 03:55:00+03	2017-08-04 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-04 03:57:00+03	2017-08-04 07:15:00+03
26664	PG0660	2017-08-17 03:55:00+03	2017-08-17 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26665	PG0660	2017-09-14 03:55:00+03	2017-09-14 07:10:00+03	VVO	IKT	Cancelled	CR2	\N	\N
26666	PG0660	2017-09-10 03:55:00+03	2017-09-10 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26667	PG0660	2017-07-23 03:55:00+03	2017-07-23 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-23 03:58:00+03	2017-07-23 07:16:00+03
26668	PG0660	2017-08-28 03:55:00+03	2017-08-28 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26669	PG0660	2017-08-27 03:55:00+03	2017-08-27 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26670	PG0660	2017-07-21 03:55:00+03	2017-07-21 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-21 03:57:00+03	2017-07-21 07:12:00+03
26671	PG0660	2017-08-24 03:55:00+03	2017-08-24 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26672	PG0660	2017-08-18 03:55:00+03	2017-08-18 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26673	PG0660	2017-08-06 03:55:00+03	2017-08-06 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-06 04:00:00+03	2017-08-06 07:14:00+03
26674	PG0660	2017-07-22 03:55:00+03	2017-07-22 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-22 03:58:00+03	2017-07-22 07:14:00+03
26675	PG0660	2017-09-11 03:55:00+03	2017-09-11 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26676	PG0660	2017-08-05 03:55:00+03	2017-08-05 07:10:00+03	VVO	IKT	Arrived	CR2	2017-08-05 03:57:00+03	2017-08-05 07:12:00+03
26677	PG0660	2017-08-19 03:55:00+03	2017-08-19 07:10:00+03	VVO	IKT	Scheduled	CR2	\N	\N
26678	PG0660	2017-07-30 03:55:00+03	2017-07-30 07:10:00+03	VVO	IKT	Arrived	CR2	2017-07-30 03:59:00+03	2017-07-30 07:13:00+03
26679	PG0328	2017-08-04 02:45:00+03	2017-08-04 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-04 06:01:00+03	2017-08-04 06:50:00+03
26680	PG0328	2017-07-16 02:45:00+03	2017-07-16 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-16 06:16:00+03	2017-07-16 07:06:00+03
26681	PG0328	2017-07-18 02:45:00+03	2017-07-18 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-18 02:47:00+03	2017-07-18 03:38:00+03
26682	PG0328	2017-09-03 02:45:00+03	2017-09-03 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26683	PG0328	2017-08-29 02:45:00+03	2017-08-29 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26684	PG0328	2017-08-16 02:45:00+03	2017-08-16 03:35:00+03	VVO	KHV	On Time	SU9	\N	\N
26685	PG0328	2017-08-22 02:45:00+03	2017-08-22 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26686	PG0328	2017-09-09 02:45:00+03	2017-09-09 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26687	PG0328	2017-08-11 02:45:00+03	2017-08-11 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-11 02:49:00+03	2017-08-11 03:39:00+03
26688	PG0328	2017-08-03 02:45:00+03	2017-08-03 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-03 02:45:00+03	2017-08-03 03:34:00+03
26689	PG0328	2017-08-02 02:45:00+03	2017-08-02 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-02 02:48:00+03	2017-08-02 03:38:00+03
26690	PG0328	2017-08-28 02:45:00+03	2017-08-28 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26691	PG0328	2017-09-12 02:45:00+03	2017-09-12 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26692	PG0328	2017-08-14 02:45:00+03	2017-08-14 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-14 02:48:00+03	2017-08-14 03:38:00+03
26693	PG0328	2017-09-01 02:45:00+03	2017-09-01 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26694	PG0328	2017-07-25 02:45:00+03	2017-07-25 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-25 02:47:00+03	2017-07-25 03:37:00+03
26695	PG0328	2017-08-08 02:45:00+03	2017-08-08 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-08 02:50:00+03	2017-08-08 03:40:00+03
26696	PG0328	2017-07-19 02:45:00+03	2017-07-19 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-19 06:07:00+03	2017-07-19 06:57:00+03
26697	PG0328	2017-07-17 02:45:00+03	2017-07-17 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-17 02:47:00+03	2017-07-17 03:37:00+03
26698	PG0328	2017-08-21 02:45:00+03	2017-08-21 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26699	PG0328	2017-08-15 02:45:00+03	2017-08-15 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-15 02:45:00+03	2017-08-15 03:35:00+03
26700	PG0328	2017-09-13 02:45:00+03	2017-09-13 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26701	PG0328	2017-08-07 02:45:00+03	2017-08-07 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-07 02:51:00+03	2017-08-07 03:41:00+03
26702	PG0328	2017-08-18 02:45:00+03	2017-08-18 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26703	PG0328	2017-09-08 02:45:00+03	2017-09-08 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26704	PG0328	2017-08-27 02:45:00+03	2017-08-27 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26705	PG0328	2017-07-24 02:45:00+03	2017-07-24 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-24 02:48:00+03	2017-07-24 03:38:00+03
26706	PG0328	2017-08-01 02:45:00+03	2017-08-01 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-01 02:48:00+03	2017-08-01 03:38:00+03
26707	PG0328	2017-09-07 02:45:00+03	2017-09-07 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26708	PG0328	2017-08-26 02:45:00+03	2017-08-26 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26709	PG0328	2017-08-20 02:45:00+03	2017-08-20 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26710	PG0328	2017-07-20 02:45:00+03	2017-07-20 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-20 02:47:00+03	2017-07-20 03:36:00+03
26711	PG0328	2017-09-11 02:45:00+03	2017-09-11 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26712	PG0328	2017-07-27 02:45:00+03	2017-07-27 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-27 02:50:00+03	2017-07-27 03:40:00+03
26713	PG0328	2017-08-09 02:45:00+03	2017-08-09 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-09 02:49:00+03	2017-08-09 03:40:00+03
26714	PG0328	2017-08-24 02:45:00+03	2017-08-24 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26715	PG0328	2017-09-14 02:45:00+03	2017-09-14 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26716	PG0328	2017-08-23 02:45:00+03	2017-08-23 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26717	PG0328	2017-07-30 02:45:00+03	2017-07-30 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-30 02:47:00+03	2017-07-30 03:36:00+03
26718	PG0328	2017-09-04 02:45:00+03	2017-09-04 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26719	PG0328	2017-07-26 02:45:00+03	2017-07-26 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-26 02:51:00+03	2017-07-26 03:42:00+03
26720	PG0328	2017-09-06 02:45:00+03	2017-09-06 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26721	PG0328	2017-08-05 02:45:00+03	2017-08-05 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-05 02:50:00+03	2017-08-05 03:40:00+03
26722	PG0328	2017-07-31 02:45:00+03	2017-07-31 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-31 02:47:00+03	2017-07-31 03:37:00+03
26723	PG0328	2017-09-10 02:45:00+03	2017-09-10 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26724	PG0328	2017-08-31 02:45:00+03	2017-08-31 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26725	PG0328	2017-07-28 02:45:00+03	2017-07-28 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-28 02:46:00+03	2017-07-28 03:36:00+03
26726	PG0328	2017-09-02 02:45:00+03	2017-09-02 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26727	PG0328	2017-08-06 02:45:00+03	2017-08-06 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-06 02:47:00+03	2017-08-06 03:37:00+03
26728	PG0328	2017-09-05 02:45:00+03	2017-09-05 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26729	PG0328	2017-07-29 02:45:00+03	2017-07-29 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-29 02:49:00+03	2017-07-29 03:39:00+03
26730	PG0328	2017-08-13 02:45:00+03	2017-08-13 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-13 02:48:00+03	2017-08-13 03:37:00+03
26731	PG0328	2017-08-12 02:45:00+03	2017-08-12 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-12 02:49:00+03	2017-08-12 03:39:00+03
26732	PG0328	2017-07-23 02:45:00+03	2017-07-23 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-23 02:48:00+03	2017-07-23 03:38:00+03
26733	PG0328	2017-08-17 02:45:00+03	2017-08-17 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26734	PG0328	2017-08-25 02:45:00+03	2017-08-25 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26735	PG0328	2017-08-19 02:45:00+03	2017-08-19 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26736	PG0328	2017-07-21 02:45:00+03	2017-07-21 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-21 02:49:00+03	2017-07-21 03:39:00+03
26737	PG0328	2017-07-22 02:45:00+03	2017-07-22 03:35:00+03	VVO	KHV	Arrived	SU9	2017-07-22 02:48:00+03	2017-07-22 03:38:00+03
26738	PG0328	2017-08-10 02:45:00+03	2017-08-10 03:35:00+03	VVO	KHV	Arrived	SU9	2017-08-10 02:47:00+03	2017-08-10 03:37:00+03
26739	PG0328	2017-08-30 02:45:00+03	2017-08-30 03:35:00+03	VVO	KHV	Scheduled	SU9	\N	\N
26740	PG0437	2017-08-22 18:25:00+03	2017-08-22 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26741	PG0437	2017-07-28 18:25:00+03	2017-07-28 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-28 18:26:00+03	2017-07-28 20:23:00+03
26742	PG0437	2017-08-07 18:25:00+03	2017-08-07 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-07 18:27:00+03	2017-08-07 20:26:00+03
26743	PG0437	2017-08-09 18:25:00+03	2017-08-09 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-09 18:31:00+03	2017-08-09 20:32:00+03
26744	PG0437	2017-08-12 18:25:00+03	2017-08-12 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-12 18:27:00+03	2017-08-12 20:26:00+03
26745	PG0437	2017-08-21 18:25:00+03	2017-08-21 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26746	PG0437	2017-08-27 18:25:00+03	2017-08-27 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26747	PG0437	2017-08-04 18:25:00+03	2017-08-04 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-04 18:31:00+03	2017-08-04 20:29:00+03
26748	PG0437	2017-07-17 18:25:00+03	2017-07-17 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-17 18:26:00+03	2017-07-17 20:28:00+03
26749	PG0437	2017-07-27 18:25:00+03	2017-07-27 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-27 18:28:00+03	2017-07-27 20:29:00+03
26750	PG0437	2017-08-02 18:25:00+03	2017-08-02 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-02 18:25:00+03	2017-08-02 20:24:00+03
26751	PG0437	2017-08-30 18:25:00+03	2017-08-30 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26752	PG0437	2017-08-25 18:25:00+03	2017-08-25 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26753	PG0437	2017-08-29 18:25:00+03	2017-08-29 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26754	PG0437	2017-07-21 18:25:00+03	2017-07-21 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-21 18:32:00+03	2017-07-21 20:32:00+03
26755	PG0437	2017-09-11 18:25:00+03	2017-09-11 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26756	PG0437	2017-07-19 18:25:00+03	2017-07-19 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-19 21:33:00+03	2017-07-19 23:33:00+03
26757	PG0437	2017-08-13 18:25:00+03	2017-08-13 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-13 18:29:00+03	2017-08-13 20:30:00+03
26758	PG0437	2017-08-08 18:25:00+03	2017-08-08 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-08 18:29:00+03	2017-08-08 20:28:00+03
26759	PG0437	2017-08-18 18:25:00+03	2017-08-18 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26760	PG0437	2017-07-29 18:25:00+03	2017-07-29 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-29 18:29:00+03	2017-07-29 20:31:00+03
26761	PG0437	2017-08-28 18:25:00+03	2017-08-28 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26762	PG0437	2017-08-24 18:25:00+03	2017-08-24 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26763	PG0437	2017-09-13 18:25:00+03	2017-09-13 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26764	PG0437	2017-07-20 18:25:00+03	2017-07-20 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-20 18:27:00+03	2017-07-20 20:28:00+03
26765	PG0437	2017-08-10 18:25:00+03	2017-08-10 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-10 18:25:00+03	2017-08-10 20:23:00+03
26766	PG0437	2017-07-24 18:25:00+03	2017-07-24 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-24 18:29:00+03	2017-07-24 20:29:00+03
26767	PG0437	2017-08-01 18:25:00+03	2017-08-01 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-01 18:28:00+03	2017-08-01 20:27:00+03
26768	PG0437	2017-07-22 18:25:00+03	2017-07-22 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-22 18:27:00+03	2017-07-22 20:27:00+03
26769	PG0437	2017-07-18 18:25:00+03	2017-07-18 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-18 18:30:00+03	2017-07-18 20:31:00+03
26770	PG0437	2017-08-06 18:25:00+03	2017-08-06 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-06 18:30:00+03	2017-08-06 20:31:00+03
26771	PG0437	2017-09-07 18:25:00+03	2017-09-07 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26772	PG0437	2017-08-20 18:25:00+03	2017-08-20 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26773	PG0437	2017-08-23 18:25:00+03	2017-08-23 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26774	PG0437	2017-09-05 18:25:00+03	2017-09-05 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26775	PG0437	2017-08-03 18:25:00+03	2017-08-03 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-03 18:27:00+03	2017-08-03 20:27:00+03
26776	PG0437	2017-08-11 18:25:00+03	2017-08-11 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-11 18:27:00+03	2017-08-11 20:25:00+03
26777	PG0437	2017-08-19 18:25:00+03	2017-08-19 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26778	PG0437	2017-09-08 18:25:00+03	2017-09-08 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26779	PG0437	2017-09-14 18:25:00+03	2017-09-14 20:25:00+03	IAR	LED	Cancelled	CN1	\N	\N
26780	PG0437	2017-07-16 18:25:00+03	2017-07-16 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-16 18:28:00+03	2017-07-16 20:28:00+03
26781	PG0437	2017-09-12 18:25:00+03	2017-09-12 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26782	PG0437	2017-08-14 18:25:00+03	2017-08-14 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-14 18:28:00+03	2017-08-14 20:29:00+03
26783	PG0437	2017-09-06 18:25:00+03	2017-09-06 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26784	PG0437	2017-09-10 18:25:00+03	2017-09-10 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26785	PG0437	2017-09-01 18:25:00+03	2017-09-01 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26786	PG0437	2017-09-03 18:25:00+03	2017-09-03 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26787	PG0437	2017-09-02 18:25:00+03	2017-09-02 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26788	PG0437	2017-07-23 18:25:00+03	2017-07-23 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-23 18:28:00+03	2017-07-23 20:26:00+03
26789	PG0437	2017-07-26 18:25:00+03	2017-07-26 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-26 18:26:00+03	2017-07-26 20:25:00+03
26790	PG0437	2017-09-09 18:25:00+03	2017-09-09 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26791	PG0437	2017-08-26 18:25:00+03	2017-08-26 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26792	PG0437	2017-08-05 18:25:00+03	2017-08-05 20:25:00+03	IAR	LED	Arrived	CN1	2017-08-05 18:28:00+03	2017-08-05 20:29:00+03
26793	PG0437	2017-08-16 18:25:00+03	2017-08-16 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26794	PG0437	2017-08-17 18:25:00+03	2017-08-17 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26795	PG0437	2017-09-04 18:25:00+03	2017-09-04 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26796	PG0437	2017-07-25 18:25:00+03	2017-07-25 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-25 18:27:00+03	2017-07-25 20:26:00+03
26797	PG0437	2017-08-15 18:25:00+03	2017-08-15 20:25:00+03	IAR	LED	On Time	CN1	\N	\N
26798	PG0437	2017-07-31 18:25:00+03	2017-07-31 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-31 18:27:00+03	2017-07-31 20:28:00+03
26799	PG0437	2017-07-30 18:25:00+03	2017-07-30 20:25:00+03	IAR	LED	Arrived	CN1	2017-07-30 18:28:00+03	2017-07-30 20:30:00+03
26800	PG0437	2017-08-31 18:25:00+03	2017-08-31 20:25:00+03	IAR	LED	Scheduled	CN1	\N	\N
26801	PG0011	2017-09-03 11:05:00+03	2017-09-03 14:55:00+03	IAR	TOF	Scheduled	CR2	\N	\N
26802	PG0011	2017-07-16 11:05:00+03	2017-07-16 14:55:00+03	IAR	TOF	Arrived	CR2	2017-07-16 13:26:00+03	2017-07-16 17:15:00+03
26803	PG0011	2017-08-06 11:05:00+03	2017-08-06 14:55:00+03	IAR	TOF	Arrived	CR2	2017-08-06 11:08:00+03	2017-08-06 14:59:00+03
26804	PG0011	2017-08-27 11:05:00+03	2017-08-27 14:55:00+03	IAR	TOF	Scheduled	CR2	\N	\N
26805	PG0011	2017-08-13 11:05:00+03	2017-08-13 14:55:00+03	IAR	TOF	Arrived	CR2	2017-08-13 11:09:00+03	2017-08-13 14:59:00+03
26806	PG0011	2017-09-10 11:05:00+03	2017-09-10 14:55:00+03	IAR	TOF	Cancelled	CR2	\N	\N
26807	PG0011	2017-07-23 11:05:00+03	2017-07-23 14:55:00+03	IAR	TOF	Arrived	CR2	2017-07-23 11:07:00+03	2017-07-23 14:51:00+03
26808	PG0011	2017-08-20 11:05:00+03	2017-08-20 14:55:00+03	IAR	TOF	Scheduled	CR2	\N	\N
26809	PG0011	2017-07-30 11:05:00+03	2017-07-30 14:55:00+03	IAR	TOF	Arrived	CR2	2017-07-30 11:09:00+03	2017-07-30 15:00:00+03
26810	PG0420	2017-08-23 10:35:00+03	2017-08-23 12:50:00+03	IAR	AER	Scheduled	CR2	\N	\N
26811	PG0420	2017-08-02 10:35:00+03	2017-08-02 12:50:00+03	IAR	AER	Arrived	CR2	2017-08-02 10:37:00+03	2017-08-02 12:53:00+03
26812	PG0420	2017-07-26 10:35:00+03	2017-07-26 12:50:00+03	IAR	AER	Arrived	CR2	2017-07-26 10:39:00+03	2017-07-26 12:54:00+03
26813	PG0420	2017-08-30 10:35:00+03	2017-08-30 12:50:00+03	IAR	AER	Scheduled	CR2	\N	\N
26814	PG0420	2017-08-16 10:35:00+03	2017-08-16 12:50:00+03	IAR	AER	On Time	CR2	\N	\N
26815	PG0420	2017-09-06 10:35:00+03	2017-09-06 12:50:00+03	IAR	AER	Scheduled	CR2	\N	\N
26816	PG0420	2017-09-13 10:35:00+03	2017-09-13 12:50:00+03	IAR	AER	Cancelled	CR2	\N	\N
26817	PG0420	2017-08-09 10:35:00+03	2017-08-09 12:50:00+03	IAR	AER	Arrived	CR2	2017-08-09 10:36:00+03	2017-08-09 12:51:00+03
26818	PG0420	2017-07-19 10:35:00+03	2017-07-19 12:50:00+03	IAR	AER	Arrived	CR2	2017-07-19 13:21:00+03	2017-07-19 15:35:00+03
26819	PG0658	2017-09-13 12:10:00+03	2017-09-13 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26820	PG0658	2017-07-17 12:10:00+03	2017-07-17 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-17 12:12:00+03	2017-07-17 14:29:00+03
26821	PG0658	2017-08-03 12:10:00+03	2017-08-03 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-03 12:15:00+03	2017-08-03 14:30:00+03
26822	PG0658	2017-08-13 12:10:00+03	2017-08-13 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-13 12:14:00+03	2017-08-13 14:30:00+03
26823	PG0658	2017-09-04 12:10:00+03	2017-09-04 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26824	PG0658	2017-07-22 12:10:00+03	2017-07-22 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-22 12:14:00+03	2017-07-22 14:29:00+03
26825	PG0658	2017-07-28 12:10:00+03	2017-07-28 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-28 12:12:00+03	2017-07-28 14:29:00+03
26826	PG0658	2017-08-24 12:10:00+03	2017-08-24 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26827	PG0658	2017-07-21 12:10:00+03	2017-07-21 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-21 12:11:00+03	2017-07-21 14:28:00+03
26828	PG0658	2017-08-26 12:10:00+03	2017-08-26 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26829	PG0658	2017-08-16 12:10:00+03	2017-08-16 14:25:00+03	MCX	DME	Delayed	CR2	\N	\N
26830	PG0658	2017-08-10 12:10:00+03	2017-08-10 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-10 12:15:00+03	2017-08-10 14:30:00+03
26831	PG0658	2017-08-18 12:10:00+03	2017-08-18 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26832	PG0658	2017-08-22 12:10:00+03	2017-08-22 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26833	PG0658	2017-08-07 12:10:00+03	2017-08-07 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-07 12:13:00+03	2017-08-07 14:28:00+03
26834	PG0658	2017-08-06 12:10:00+03	2017-08-06 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-06 12:12:00+03	2017-08-06 14:29:00+03
26835	PG0658	2017-09-07 12:10:00+03	2017-09-07 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26836	PG0658	2017-09-09 12:10:00+03	2017-09-09 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26837	PG0658	2017-08-29 12:10:00+03	2017-08-29 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26838	PG0658	2017-08-08 12:10:00+03	2017-08-08 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-08 12:13:00+03	2017-08-08 14:28:00+03
26839	PG0658	2017-09-06 12:10:00+03	2017-09-06 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26840	PG0658	2017-08-05 12:10:00+03	2017-08-05 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-05 12:16:00+03	2017-08-05 14:35:00+03
26841	PG0658	2017-07-31 12:10:00+03	2017-07-31 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-31 12:11:00+03	2017-07-31 14:25:00+03
26842	PG0658	2017-08-11 12:10:00+03	2017-08-11 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-11 12:12:00+03	2017-08-11 14:27:00+03
26843	PG0658	2017-08-20 12:10:00+03	2017-08-20 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26844	PG0658	2017-09-14 12:10:00+03	2017-09-14 14:25:00+03	MCX	DME	Cancelled	CR2	\N	\N
26845	PG0658	2017-08-04 12:10:00+03	2017-08-04 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-04 12:14:00+03	2017-08-04 14:30:00+03
26846	PG0658	2017-08-15 12:10:00+03	2017-08-15 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-15 12:12:00+03	2017-08-15 14:28:00+03
26847	PG0658	2017-07-24 12:10:00+03	2017-07-24 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-24 12:12:00+03	2017-07-24 14:26:00+03
26848	PG0658	2017-08-19 12:10:00+03	2017-08-19 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26849	PG0658	2017-09-12 12:10:00+03	2017-09-12 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26850	PG0658	2017-08-02 12:10:00+03	2017-08-02 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-02 12:13:00+03	2017-08-02 14:28:00+03
26851	PG0658	2017-08-17 12:10:00+03	2017-08-17 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26852	PG0658	2017-09-02 12:10:00+03	2017-09-02 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26853	PG0658	2017-08-23 12:10:00+03	2017-08-23 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26854	PG0658	2017-07-18 12:10:00+03	2017-07-18 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-18 12:14:00+03	2017-07-18 14:28:00+03
26855	PG0658	2017-07-26 12:10:00+03	2017-07-26 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-26 12:13:00+03	2017-07-26 14:28:00+03
26856	PG0658	2017-07-20 12:10:00+03	2017-07-20 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-20 12:13:00+03	2017-07-20 14:28:00+03
26857	PG0658	2017-09-05 12:10:00+03	2017-09-05 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26858	PG0658	2017-09-10 12:10:00+03	2017-09-10 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26859	PG0658	2017-08-09 12:10:00+03	2017-08-09 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-09 12:12:00+03	2017-08-09 14:26:00+03
26860	PG0658	2017-08-14 12:10:00+03	2017-08-14 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-14 12:13:00+03	2017-08-14 14:28:00+03
26861	PG0658	2017-07-30 12:10:00+03	2017-07-30 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-30 12:16:00+03	2017-07-30 14:30:00+03
26862	PG0658	2017-07-23 12:10:00+03	2017-07-23 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-23 12:12:00+03	2017-07-23 14:25:00+03
26863	PG0658	2017-08-31 12:10:00+03	2017-08-31 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26864	PG0658	2017-08-28 12:10:00+03	2017-08-28 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26865	PG0658	2017-07-19 12:10:00+03	2017-07-19 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-19 12:14:00+03	2017-07-19 14:29:00+03
26866	PG0658	2017-08-27 12:10:00+03	2017-08-27 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26867	PG0658	2017-09-11 12:10:00+03	2017-09-11 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26868	PG0658	2017-08-12 12:10:00+03	2017-08-12 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-12 12:11:00+03	2017-08-12 14:27:00+03
26869	PG0658	2017-07-27 12:10:00+03	2017-07-27 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-27 12:12:00+03	2017-07-27 14:25:00+03
26870	PG0658	2017-09-08 12:10:00+03	2017-09-08 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26871	PG0658	2017-08-21 12:10:00+03	2017-08-21 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26872	PG0658	2017-08-01 12:10:00+03	2017-08-01 14:25:00+03	MCX	DME	Arrived	CR2	2017-08-01 12:13:00+03	2017-08-01 14:31:00+03
26873	PG0658	2017-07-29 12:10:00+03	2017-07-29 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-29 12:15:00+03	2017-07-29 14:28:00+03
26874	PG0658	2017-09-03 12:10:00+03	2017-09-03 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26875	PG0658	2017-07-25 12:10:00+03	2017-07-25 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-25 12:13:00+03	2017-07-25 14:28:00+03
26876	PG0658	2017-08-30 12:10:00+03	2017-08-30 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26877	PG0658	2017-08-25 12:10:00+03	2017-08-25 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26878	PG0658	2017-09-01 12:10:00+03	2017-09-01 14:25:00+03	MCX	DME	Scheduled	CR2	\N	\N
26879	PG0658	2017-07-16 12:10:00+03	2017-07-16 14:25:00+03	MCX	DME	Arrived	CR2	2017-07-16 15:12:00+03	2017-07-16 17:27:00+03
26880	PG0678	2017-07-18 14:30:00+03	2017-07-18 16:45:00+03	MCX	SVO	Arrived	733	2017-07-18 14:34:00+03	2017-07-18 16:49:00+03
26881	PG0678	2017-07-24 14:30:00+03	2017-07-24 16:45:00+03	MCX	SVO	Arrived	733	2017-07-24 14:31:00+03	2017-07-24 16:44:00+03
26882	PG0678	2017-08-18 14:30:00+03	2017-08-18 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26883	PG0678	2017-08-02 14:30:00+03	2017-08-02 16:45:00+03	MCX	SVO	Arrived	733	2017-08-02 14:31:00+03	2017-08-02 16:46:00+03
26884	PG0678	2017-09-10 14:30:00+03	2017-09-10 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26885	PG0678	2017-07-16 14:30:00+03	2017-07-16 16:45:00+03	MCX	SVO	Arrived	733	2017-07-16 14:33:00+03	2017-07-16 16:48:00+03
26886	PG0678	2017-08-24 14:30:00+03	2017-08-24 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26887	PG0678	2017-08-09 14:30:00+03	2017-08-09 16:45:00+03	MCX	SVO	Arrived	733	2017-08-09 14:35:00+03	2017-08-09 16:51:00+03
26888	PG0678	2017-09-05 14:30:00+03	2017-09-05 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26889	PG0678	2017-07-19 14:30:00+03	2017-07-19 16:45:00+03	MCX	SVO	Arrived	733	2017-07-19 14:32:00+03	2017-07-19 16:49:00+03
26890	PG0678	2017-08-15 14:30:00+03	2017-08-15 16:45:00+03	MCX	SVO	Arrived	733	2017-08-15 14:32:00+03	2017-08-15 16:47:00+03
26891	PG0678	2017-09-04 14:30:00+03	2017-09-04 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26892	PG0678	2017-08-14 14:30:00+03	2017-08-14 16:45:00+03	MCX	SVO	Arrived	733	2017-08-14 14:32:00+03	2017-08-14 16:49:00+03
26893	PG0678	2017-08-10 14:30:00+03	2017-08-10 16:45:00+03	MCX	SVO	Arrived	733	2017-08-10 14:35:00+03	2017-08-10 16:50:00+03
26894	PG0678	2017-08-28 14:30:00+03	2017-08-28 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26895	PG0678	2017-07-23 14:30:00+03	2017-07-23 16:45:00+03	MCX	SVO	Arrived	733	2017-07-23 14:34:00+03	2017-07-23 16:49:00+03
26896	PG0678	2017-09-03 14:30:00+03	2017-09-03 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26897	PG0678	2017-08-27 14:30:00+03	2017-08-27 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26898	PG0678	2017-08-16 14:30:00+03	2017-08-16 16:45:00+03	MCX	SVO	On Time	733	\N	\N
26899	PG0678	2017-09-01 14:30:00+03	2017-09-01 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26900	PG0678	2017-09-08 14:30:00+03	2017-09-08 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26901	PG0678	2017-08-13 14:30:00+03	2017-08-13 16:45:00+03	MCX	SVO	Arrived	733	2017-08-13 14:31:00+03	2017-08-13 16:48:00+03
26902	PG0678	2017-08-31 14:30:00+03	2017-08-31 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26903	PG0678	2017-07-28 14:30:00+03	2017-07-28 16:45:00+03	MCX	SVO	Arrived	733	2017-07-28 14:34:00+03	2017-07-28 16:49:00+03
26904	PG0678	2017-08-26 14:30:00+03	2017-08-26 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26905	PG0678	2017-07-27 14:30:00+03	2017-07-27 16:45:00+03	MCX	SVO	Arrived	733	2017-07-27 14:35:00+03	2017-07-27 16:52:00+03
26906	PG0678	2017-08-04 14:30:00+03	2017-08-04 16:45:00+03	MCX	SVO	Arrived	733	2017-08-04 14:33:00+03	2017-08-04 16:47:00+03
26907	PG0678	2017-08-03 14:30:00+03	2017-08-03 16:45:00+03	MCX	SVO	Arrived	733	2017-08-03 14:35:00+03	2017-08-03 16:50:00+03
26908	PG0678	2017-08-06 14:30:00+03	2017-08-06 16:45:00+03	MCX	SVO	Arrived	733	2017-08-06 14:33:00+03	2017-08-06 16:46:00+03
26909	PG0678	2017-08-07 14:30:00+03	2017-08-07 16:45:00+03	MCX	SVO	Arrived	733	2017-08-07 14:31:00+03	2017-08-07 16:45:00+03
26910	PG0678	2017-07-26 14:30:00+03	2017-07-26 16:45:00+03	MCX	SVO	Arrived	733	2017-07-26 14:35:00+03	2017-07-26 16:49:00+03
26911	PG0678	2017-08-20 14:30:00+03	2017-08-20 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26912	PG0678	2017-07-29 14:30:00+03	2017-07-29 16:45:00+03	MCX	SVO	Arrived	733	2017-07-29 14:31:00+03	2017-07-29 16:45:00+03
26913	PG0678	2017-09-14 14:30:00+03	2017-09-14 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26914	PG0678	2017-09-12 14:30:00+03	2017-09-12 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26915	PG0678	2017-08-12 14:30:00+03	2017-08-12 16:45:00+03	MCX	SVO	Arrived	733	2017-08-12 14:33:00+03	2017-08-12 16:47:00+03
26916	PG0678	2017-08-17 14:30:00+03	2017-08-17 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26917	PG0678	2017-08-21 14:30:00+03	2017-08-21 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26918	PG0678	2017-08-23 14:30:00+03	2017-08-23 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26919	PG0678	2017-09-02 14:30:00+03	2017-09-02 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26920	PG0678	2017-08-01 14:30:00+03	2017-08-01 16:45:00+03	MCX	SVO	Arrived	733	2017-08-01 14:33:00+03	2017-08-01 16:51:00+03
26921	PG0678	2017-07-25 14:30:00+03	2017-07-25 16:45:00+03	MCX	SVO	Arrived	733	2017-07-25 14:34:00+03	2017-07-25 16:50:00+03
26922	PG0678	2017-08-05 14:30:00+03	2017-08-05 16:45:00+03	MCX	SVO	Arrived	733	2017-08-05 14:32:00+03	2017-08-05 16:49:00+03
26923	PG0678	2017-09-07 14:30:00+03	2017-09-07 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26924	PG0678	2017-08-11 14:30:00+03	2017-08-11 16:45:00+03	MCX	SVO	Arrived	733	2017-08-11 14:33:00+03	2017-08-11 16:47:00+03
26925	PG0678	2017-07-20 14:30:00+03	2017-07-20 16:45:00+03	MCX	SVO	Arrived	733	2017-07-20 14:30:00+03	2017-07-20 16:46:00+03
26926	PG0678	2017-07-17 14:30:00+03	2017-07-17 16:45:00+03	MCX	SVO	Arrived	733	2017-07-17 14:31:00+03	2017-07-17 16:48:00+03
26927	PG0678	2017-07-22 14:30:00+03	2017-07-22 16:45:00+03	MCX	SVO	Arrived	733	2017-07-22 14:33:00+03	2017-07-22 16:48:00+03
26928	PG0678	2017-09-13 14:30:00+03	2017-09-13 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26929	PG0678	2017-09-06 14:30:00+03	2017-09-06 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26930	PG0678	2017-08-29 14:30:00+03	2017-08-29 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26931	PG0678	2017-08-08 14:30:00+03	2017-08-08 16:45:00+03	MCX	SVO	Arrived	733	2017-08-08 14:34:00+03	2017-08-08 16:50:00+03
26932	PG0678	2017-08-25 14:30:00+03	2017-08-25 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26933	PG0678	2017-08-30 14:30:00+03	2017-08-30 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26934	PG0678	2017-07-31 14:30:00+03	2017-07-31 16:45:00+03	MCX	SVO	Arrived	733	2017-07-31 14:33:00+03	2017-07-31 16:50:00+03
26935	PG0678	2017-09-09 14:30:00+03	2017-09-09 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26936	PG0678	2017-07-21 14:30:00+03	2017-07-21 16:45:00+03	MCX	SVO	Arrived	733	2017-07-21 14:32:00+03	2017-07-21 16:49:00+03
26937	PG0678	2017-08-22 14:30:00+03	2017-08-22 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26938	PG0678	2017-08-19 14:30:00+03	2017-08-19 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26939	PG0678	2017-07-30 14:30:00+03	2017-07-30 16:45:00+03	MCX	SVO	Arrived	733	2017-07-30 14:30:00+03	2017-07-30 16:46:00+03
26940	PG0678	2017-09-11 14:30:00+03	2017-09-11 16:45:00+03	MCX	SVO	Scheduled	733	\N	\N
26941	PG0526	2017-08-23 14:25:00+03	2017-08-23 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26942	PG0526	2017-09-06 14:25:00+03	2017-09-06 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26943	PG0526	2017-08-30 14:25:00+03	2017-08-30 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26944	PG0526	2017-07-26 14:25:00+03	2017-07-26 16:25:00+03	MCX	KZN	Arrived	CR2	2017-07-26 18:04:00+03	2017-07-26 20:04:00+03
26945	PG0526	2017-08-26 14:25:00+03	2017-08-26 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26946	PG0526	2017-08-12 14:25:00+03	2017-08-12 16:25:00+03	MCX	KZN	Arrived	CR2	2017-08-12 14:31:00+03	2017-08-12 16:31:00+03
26947	PG0526	2017-08-05 14:25:00+03	2017-08-05 16:25:00+03	MCX	KZN	Arrived	CR2	2017-08-05 14:25:00+03	2017-08-05 16:24:00+03
26948	PG0526	2017-09-09 14:25:00+03	2017-09-09 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26949	PG0526	2017-08-19 14:25:00+03	2017-08-19 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26950	PG0526	2017-07-19 14:25:00+03	2017-07-19 16:25:00+03	MCX	KZN	Arrived	CR2	2017-07-19 14:31:00+03	2017-07-19 16:30:00+03
26951	PG0526	2017-07-29 14:25:00+03	2017-07-29 16:25:00+03	MCX	KZN	Arrived	CR2	2017-07-29 14:30:00+03	2017-07-29 16:30:00+03
26952	PG0526	2017-09-02 14:25:00+03	2017-09-02 16:25:00+03	MCX	KZN	Scheduled	CR2	\N	\N
26953	PG0526	2017-08-16 14:25:00+03	2017-08-16 16:25:00+03	MCX	KZN	On Time	CR2	\N	\N
26954	PG0526	2017-07-22 14:25:00+03	2017-07-22 16:25:00+03	MCX	KZN	Arrived	CR2	2017-07-22 14:26:00+03	2017-07-22 16:27:00+03
26955	PG0526	2017-08-09 14:25:00+03	2017-08-09 16:25:00+03	MCX	KZN	Arrived	CR2	2017-08-09 14:28:00+03	2017-08-09 16:29:00+03
26956	PG0526	2017-09-13 14:25:00+03	2017-09-13 16:25:00+03	MCX	KZN	Cancelled	CR2	\N	\N
26957	PG0526	2017-08-02 14:25:00+03	2017-08-02 16:25:00+03	MCX	KZN	Arrived	CR2	2017-08-02 14:30:00+03	2017-08-02 16:28:00+03
26958	PG0151	2017-07-16 14:00:00+03	2017-07-16 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-16 14:05:00+03	2017-07-16 14:35:00+03
26959	PG0151	2017-07-19 14:00:00+03	2017-07-19 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-19 14:05:00+03	2017-07-19 14:35:00+03
26960	PG0151	2017-08-13 14:00:00+03	2017-08-13 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-13 14:01:00+03	2017-08-13 14:31:00+03
26961	PG0151	2017-07-18 14:00:00+03	2017-07-18 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-18 14:03:00+03	2017-07-18 14:33:00+03
26962	PG0151	2017-08-23 14:00:00+03	2017-08-23 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26963	PG0151	2017-08-28 14:00:00+03	2017-08-28 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26964	PG0151	2017-09-10 14:00:00+03	2017-09-10 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26965	PG0151	2017-09-03 14:00:00+03	2017-09-03 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26966	PG0151	2017-08-04 14:00:00+03	2017-08-04 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-04 14:03:00+03	2017-08-04 14:33:00+03
26967	PG0151	2017-09-14 14:00:00+03	2017-09-14 14:30:00+03	MCX	MRV	Cancelled	SU9	\N	\N
26968	PG0151	2017-08-08 14:00:00+03	2017-08-08 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-08 14:03:00+03	2017-08-08 14:33:00+03
26969	PG0151	2017-08-17 14:00:00+03	2017-08-17 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26970	PG0151	2017-07-31 14:00:00+03	2017-07-31 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-31 14:03:00+03	2017-07-31 14:33:00+03
26971	PG0151	2017-08-24 14:00:00+03	2017-08-24 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26972	PG0151	2017-09-05 14:00:00+03	2017-09-05 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26973	PG0151	2017-09-07 14:00:00+03	2017-09-07 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26974	PG0151	2017-08-21 14:00:00+03	2017-08-21 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26975	PG0151	2017-07-26 14:00:00+03	2017-07-26 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-26 14:01:00+03	2017-07-26 14:31:00+03
26976	PG0151	2017-07-21 14:00:00+03	2017-07-21 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-21 14:02:00+03	2017-07-21 14:32:00+03
26977	PG0151	2017-07-17 14:00:00+03	2017-07-17 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-17 14:03:00+03	2017-07-17 14:33:00+03
26978	PG0151	2017-08-16 14:00:00+03	2017-08-16 14:30:00+03	MCX	MRV	On Time	SU9	\N	\N
26979	PG0151	2017-08-29 14:00:00+03	2017-08-29 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26980	PG0151	2017-08-03 14:00:00+03	2017-08-03 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-03 14:05:00+03	2017-08-03 14:35:00+03
26981	PG0151	2017-07-25 14:00:00+03	2017-07-25 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-25 14:06:00+03	2017-07-25 14:36:00+03
26982	PG0151	2017-08-09 14:00:00+03	2017-08-09 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-09 14:04:00+03	2017-08-09 14:33:00+03
26983	PG0151	2017-08-06 14:00:00+03	2017-08-06 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-06 14:06:00+03	2017-08-06 14:36:00+03
26984	PG0151	2017-08-30 14:00:00+03	2017-08-30 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26985	PG0151	2017-07-22 14:00:00+03	2017-07-22 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-22 14:04:00+03	2017-07-22 14:34:00+03
26986	PG0151	2017-07-30 14:00:00+03	2017-07-30 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-30 14:03:00+03	2017-07-30 14:34:00+03
26987	PG0151	2017-07-24 14:00:00+03	2017-07-24 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-24 14:04:00+03	2017-07-24 14:34:00+03
26988	PG0151	2017-07-20 14:00:00+03	2017-07-20 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-20 14:05:00+03	2017-07-20 14:35:00+03
26989	PG0151	2017-09-01 14:00:00+03	2017-09-01 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26990	PG0151	2017-08-18 14:00:00+03	2017-08-18 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26991	PG0151	2017-07-27 14:00:00+03	2017-07-27 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-27 14:03:00+03	2017-07-27 14:33:00+03
26992	PG0151	2017-08-05 14:00:00+03	2017-08-05 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-05 14:08:00+03	2017-08-05 14:38:00+03
26993	PG0151	2017-08-15 14:00:00+03	2017-08-15 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-15 14:02:00+03	2017-08-15 14:31:00+03
26994	PG0151	2017-09-09 14:00:00+03	2017-09-09 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26995	PG0151	2017-08-12 14:00:00+03	2017-08-12 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-12 14:02:00+03	2017-08-12 14:32:00+03
26996	PG0151	2017-08-26 14:00:00+03	2017-08-26 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26997	PG0151	2017-08-27 14:00:00+03	2017-08-27 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26998	PG0151	2017-09-02 14:00:00+03	2017-09-02 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
26999	PG0151	2017-09-06 14:00:00+03	2017-09-06 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27000	PG0151	2017-08-02 14:00:00+03	2017-08-02 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-02 14:02:00+03	2017-08-02 14:32:00+03
27001	PG0151	2017-09-13 14:00:00+03	2017-09-13 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27002	PG0151	2017-08-10 14:00:00+03	2017-08-10 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-10 14:04:00+03	2017-08-10 14:34:00+03
27003	PG0151	2017-09-04 14:00:00+03	2017-09-04 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27004	PG0151	2017-07-28 14:00:00+03	2017-07-28 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-28 14:04:00+03	2017-07-28 14:34:00+03
27005	PG0151	2017-09-12 14:00:00+03	2017-09-12 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27006	PG0151	2017-08-25 14:00:00+03	2017-08-25 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27007	PG0151	2017-08-07 14:00:00+03	2017-08-07 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-07 14:06:00+03	2017-08-07 14:36:00+03
27008	PG0151	2017-08-14 14:00:00+03	2017-08-14 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-14 14:04:00+03	2017-08-14 14:34:00+03
27009	PG0151	2017-09-11 14:00:00+03	2017-09-11 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27010	PG0151	2017-08-22 14:00:00+03	2017-08-22 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27011	PG0151	2017-08-20 14:00:00+03	2017-08-20 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27012	PG0151	2017-08-19 14:00:00+03	2017-08-19 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27013	PG0151	2017-08-31 14:00:00+03	2017-08-31 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27014	PG0151	2017-08-01 14:00:00+03	2017-08-01 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-01 14:02:00+03	2017-08-01 14:32:00+03
27015	PG0151	2017-07-23 14:00:00+03	2017-07-23 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-23 14:03:00+03	2017-07-23 14:33:00+03
27016	PG0151	2017-07-29 14:00:00+03	2017-07-29 14:30:00+03	MCX	MRV	Arrived	SU9	2017-07-29 14:03:00+03	2017-07-29 14:33:00+03
27017	PG0151	2017-09-08 14:00:00+03	2017-09-08 14:30:00+03	MCX	MRV	Scheduled	SU9	\N	\N
27018	PG0151	2017-08-11 14:00:00+03	2017-08-11 14:30:00+03	MCX	MRV	Arrived	SU9	2017-08-11 14:02:00+03	2017-08-11 14:32:00+03
27019	PG0143	2017-07-18 12:05:00+03	2017-07-18 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-18 12:12:00+03	2017-07-18 15:59:00+03
27020	PG0143	2017-09-14 12:05:00+03	2017-09-14 15:55:00+03	TOF	DME	Cancelled	SU9	\N	\N
27021	PG0143	2017-08-12 12:05:00+03	2017-08-12 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-12 12:07:00+03	2017-08-12 15:57:00+03
27022	PG0143	2017-08-24 12:05:00+03	2017-08-24 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27023	PG0143	2017-08-29 12:05:00+03	2017-08-29 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27024	PG0143	2017-08-03 12:05:00+03	2017-08-03 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-03 12:07:00+03	2017-08-03 15:59:00+03
27025	PG0143	2017-07-20 12:05:00+03	2017-07-20 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-20 12:05:00+03	2017-07-20 15:52:00+03
27026	PG0143	2017-07-27 12:05:00+03	2017-07-27 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-27 12:06:00+03	2017-07-27 15:56:00+03
27027	PG0143	2017-08-05 12:05:00+03	2017-08-05 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-05 12:06:00+03	2017-08-05 15:58:00+03
27028	PG0143	2017-08-15 12:05:00+03	2017-08-15 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-15 12:09:00+03	2017-08-15 15:59:00+03
27029	PG0143	2017-09-09 12:05:00+03	2017-09-09 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27030	PG0143	2017-08-26 12:05:00+03	2017-08-26 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27031	PG0143	2017-09-02 12:05:00+03	2017-09-02 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27032	PG0143	2017-08-10 12:05:00+03	2017-08-10 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-10 12:06:00+03	2017-08-10 15:57:00+03
27033	PG0143	2017-07-22 12:05:00+03	2017-07-22 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-22 12:07:00+03	2017-07-22 15:59:00+03
27034	PG0143	2017-09-12 12:05:00+03	2017-09-12 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27035	PG0143	2017-08-22 12:05:00+03	2017-08-22 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27036	PG0143	2017-08-31 12:05:00+03	2017-08-31 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27037	PG0143	2017-08-01 12:05:00+03	2017-08-01 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-01 12:07:00+03	2017-08-01 15:59:00+03
27038	PG0143	2017-07-29 12:05:00+03	2017-07-29 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-29 12:08:00+03	2017-07-29 15:58:00+03
27039	PG0143	2017-07-25 12:05:00+03	2017-07-25 15:55:00+03	TOF	DME	Arrived	SU9	2017-07-25 12:07:00+03	2017-07-25 15:55:00+03
27040	PG0143	2017-08-19 12:05:00+03	2017-08-19 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27041	PG0143	2017-09-07 12:05:00+03	2017-09-07 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27042	PG0143	2017-08-17 12:05:00+03	2017-08-17 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27043	PG0143	2017-08-08 12:05:00+03	2017-08-08 15:55:00+03	TOF	DME	Arrived	SU9	2017-08-08 12:06:00+03	2017-08-08 15:56:00+03
27044	PG0143	2017-09-05 12:05:00+03	2017-09-05 15:55:00+03	TOF	DME	Scheduled	SU9	\N	\N
27045	PG0592	2017-09-06 06:00:00+03	2017-09-06 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27046	PG0592	2017-08-05 06:00:00+03	2017-08-05 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-05 06:02:00+03	2017-08-05 09:52:00+03
27047	PG0592	2017-09-09 06:00:00+03	2017-09-09 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27048	PG0592	2017-08-04 06:00:00+03	2017-08-04 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-04 06:09:00+03	2017-08-04 10:05:00+03
27049	PG0592	2017-08-08 06:00:00+03	2017-08-08 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-08 06:04:00+03	2017-08-08 09:54:00+03
27050	PG0592	2017-09-02 06:00:00+03	2017-09-02 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27051	PG0592	2017-07-30 06:00:00+03	2017-07-30 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-30 06:02:00+03	2017-07-30 10:00:00+03
27052	PG0592	2017-08-29 06:00:00+03	2017-08-29 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27053	PG0592	2017-07-25 06:00:00+03	2017-07-25 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-25 06:03:00+03	2017-07-25 09:58:00+03
27054	PG0592	2017-08-25 06:00:00+03	2017-08-25 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27055	PG0592	2017-07-16 06:00:00+03	2017-07-16 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-16 06:03:00+03	2017-07-16 09:57:00+03
27056	PG0592	2017-07-20 06:00:00+03	2017-07-20 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-20 06:03:00+03	2017-07-20 10:01:00+03
27057	PG0592	2017-08-20 06:00:00+03	2017-08-20 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27058	PG0592	2017-08-16 06:00:00+03	2017-08-16 09:55:00+03	TOF	SVO	On Time	SU9	\N	\N
27059	PG0592	2017-08-03 06:00:00+03	2017-08-03 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-03 06:03:00+03	2017-08-03 09:57:00+03
27060	PG0592	2017-08-06 06:00:00+03	2017-08-06 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-06 08:04:00+03	2017-08-06 12:00:00+03
27061	PG0592	2017-08-19 06:00:00+03	2017-08-19 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27062	PG0592	2017-07-29 06:00:00+03	2017-07-29 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-29 06:03:00+03	2017-07-29 09:58:00+03
27063	PG0592	2017-08-26 06:00:00+03	2017-08-26 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27064	PG0592	2017-07-31 06:00:00+03	2017-07-31 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-31 06:03:00+03	2017-07-31 09:56:00+03
27065	PG0592	2017-08-13 06:00:00+03	2017-08-13 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-13 06:02:00+03	2017-08-13 10:01:00+03
27066	PG0592	2017-08-10 06:00:00+03	2017-08-10 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-10 06:04:00+03	2017-08-10 10:03:00+03
27067	PG0592	2017-08-18 06:00:00+03	2017-08-18 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27068	PG0592	2017-09-01 06:00:00+03	2017-09-01 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27069	PG0592	2017-07-28 06:00:00+03	2017-07-28 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-28 06:01:00+03	2017-07-28 10:00:00+03
27070	PG0592	2017-08-01 06:00:00+03	2017-08-01 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-01 06:05:00+03	2017-08-01 10:00:00+03
27071	PG0592	2017-08-28 06:00:00+03	2017-08-28 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27072	PG0592	2017-09-08 06:00:00+03	2017-09-08 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27073	PG0592	2017-07-21 06:00:00+03	2017-07-21 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-21 06:05:00+03	2017-07-21 09:58:00+03
27074	PG0592	2017-07-17 06:00:00+03	2017-07-17 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-17 09:06:00+03	2017-07-17 13:00:00+03
27075	PG0592	2017-08-30 06:00:00+03	2017-08-30 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27076	PG0592	2017-09-07 06:00:00+03	2017-09-07 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27077	PG0592	2017-07-23 06:00:00+03	2017-07-23 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-23 06:07:00+03	2017-07-23 09:59:00+03
27078	PG0592	2017-07-19 06:00:00+03	2017-07-19 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-19 06:02:00+03	2017-07-19 09:53:00+03
27079	PG0592	2017-08-14 06:00:00+03	2017-08-14 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-14 06:04:00+03	2017-08-14 09:59:00+03
27080	PG0592	2017-09-11 06:00:00+03	2017-09-11 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27081	PG0592	2017-07-27 06:00:00+03	2017-07-27 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-27 06:03:00+03	2017-07-27 10:02:00+03
27082	PG0592	2017-08-21 06:00:00+03	2017-08-21 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27083	PG0592	2017-08-22 06:00:00+03	2017-08-22 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27084	PG0592	2017-08-23 06:00:00+03	2017-08-23 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27085	PG0592	2017-08-09 06:00:00+03	2017-08-09 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-09 06:03:00+03	2017-08-09 10:03:00+03
27086	PG0592	2017-09-14 06:00:00+03	2017-09-14 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27087	PG0592	2017-08-24 06:00:00+03	2017-08-24 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27088	PG0592	2017-07-22 06:00:00+03	2017-07-22 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-22 06:04:00+03	2017-07-22 09:56:00+03
27089	PG0592	2017-08-27 06:00:00+03	2017-08-27 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27090	PG0592	2017-08-02 06:00:00+03	2017-08-02 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-02 06:05:00+03	2017-08-02 09:59:00+03
27091	PG0592	2017-09-13 06:00:00+03	2017-09-13 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27092	PG0592	2017-09-05 06:00:00+03	2017-09-05 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27093	PG0592	2017-08-12 06:00:00+03	2017-08-12 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-12 06:03:00+03	2017-08-12 09:54:00+03
27094	PG0592	2017-09-10 06:00:00+03	2017-09-10 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27095	PG0592	2017-08-11 06:00:00+03	2017-08-11 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-11 06:03:00+03	2017-08-11 09:55:00+03
27096	PG0592	2017-07-26 06:00:00+03	2017-07-26 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-26 06:06:00+03	2017-07-26 10:00:00+03
27097	PG0592	2017-08-15 06:00:00+03	2017-08-15 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-15 06:02:00+03	2017-08-15 09:58:00+03
27098	PG0592	2017-09-03 06:00:00+03	2017-09-03 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27099	PG0592	2017-09-12 06:00:00+03	2017-09-12 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27100	PG0592	2017-07-18 06:00:00+03	2017-07-18 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-18 06:02:00+03	2017-07-18 09:58:00+03
27101	PG0592	2017-09-04 06:00:00+03	2017-09-04 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27102	PG0592	2017-08-31 06:00:00+03	2017-08-31 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27103	PG0592	2017-08-17 06:00:00+03	2017-08-17 09:55:00+03	TOF	SVO	Scheduled	SU9	\N	\N
27104	PG0592	2017-08-07 06:00:00+03	2017-08-07 09:55:00+03	TOF	SVO	Arrived	SU9	2017-08-07 06:02:00+03	2017-08-07 09:54:00+03
27105	PG0592	2017-07-24 06:00:00+03	2017-07-24 09:55:00+03	TOF	SVO	Arrived	SU9	2017-07-24 06:01:00+03	2017-07-24 09:56:00+03
27106	PG0694	2017-09-04 12:40:00+03	2017-09-04 16:55:00+03	TOF	ROV	Scheduled	319	\N	\N
27107	PG0694	2017-07-31 12:40:00+03	2017-07-31 16:55:00+03	TOF	ROV	Arrived	319	2017-07-31 12:47:00+03	2017-07-31 17:03:00+03
27108	PG0694	2017-07-17 12:40:00+03	2017-07-17 16:55:00+03	TOF	ROV	Arrived	319	2017-07-17 12:41:00+03	2017-07-17 16:58:00+03
27109	PG0694	2017-07-24 12:40:00+03	2017-07-24 16:55:00+03	TOF	ROV	Arrived	319	2017-07-24 12:45:00+03	2017-07-24 16:53:00+03
27110	PG0694	2017-08-21 12:40:00+03	2017-08-21 16:55:00+03	TOF	ROV	Scheduled	319	\N	\N
27111	PG0694	2017-08-14 12:40:00+03	2017-08-14 16:55:00+03	TOF	ROV	Arrived	319	2017-08-14 12:43:00+03	2017-08-14 16:58:00+03
27112	PG0694	2017-09-11 12:40:00+03	2017-09-11 16:55:00+03	TOF	ROV	Cancelled	319	\N	\N
27113	PG0694	2017-08-28 12:40:00+03	2017-08-28 16:55:00+03	TOF	ROV	Scheduled	319	\N	\N
27114	PG0694	2017-08-07 12:40:00+03	2017-08-07 16:55:00+03	TOF	ROV	Arrived	319	2017-08-07 12:42:00+03	2017-08-07 16:59:00+03
27115	PG0696	2017-07-18 14:30:00+03	2017-07-18 18:20:00+03	TOF	VOG	Arrived	SU9	2017-07-18 17:58:00+03	2017-07-18 21:48:00+03
27116	PG0696	2017-08-01 14:30:00+03	2017-08-01 18:20:00+03	TOF	VOG	Arrived	SU9	2017-08-01 14:35:00+03	2017-08-01 18:25:00+03
27117	PG0696	2017-08-29 14:30:00+03	2017-08-29 18:20:00+03	TOF	VOG	Scheduled	SU9	\N	\N
27118	PG0696	2017-07-25 14:30:00+03	2017-07-25 18:20:00+03	TOF	VOG	Arrived	SU9	2017-07-25 14:33:00+03	2017-07-25 18:21:00+03
27119	PG0696	2017-09-05 14:30:00+03	2017-09-05 18:20:00+03	TOF	VOG	Scheduled	SU9	\N	\N
27120	PG0696	2017-08-08 14:30:00+03	2017-08-08 18:20:00+03	TOF	VOG	Arrived	SU9	2017-08-08 14:35:00+03	2017-08-08 18:27:00+03
27121	PG0696	2017-09-12 14:30:00+03	2017-09-12 18:20:00+03	TOF	VOG	Scheduled	SU9	\N	\N
27122	PG0696	2017-08-22 14:30:00+03	2017-08-22 18:20:00+03	TOF	VOG	Scheduled	SU9	\N	\N
27123	PG0696	2017-08-15 14:30:00+03	2017-08-15 18:20:00+03	TOF	VOG	Departed	SU9	2017-08-15 14:33:00+03	\N
27124	PG0071	2017-07-31 07:25:00+03	2017-07-31 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-31 07:28:00+03	2017-07-31 09:04:00+03
27125	PG0071	2017-08-25 07:25:00+03	2017-08-25 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27126	PG0071	2017-08-24 07:25:00+03	2017-08-24 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27127	PG0071	2017-08-26 07:25:00+03	2017-08-26 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27128	PG0071	2017-08-23 07:25:00+03	2017-08-23 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27129	PG0071	2017-08-22 07:25:00+03	2017-08-22 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27130	PG0071	2017-08-27 07:25:00+03	2017-08-27 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27131	PG0071	2017-08-21 07:25:00+03	2017-08-21 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27132	PG0071	2017-08-20 07:25:00+03	2017-08-20 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27133	PG0071	2017-08-28 07:25:00+03	2017-08-28 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27134	PG0071	2017-08-19 07:25:00+03	2017-08-19 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27135	PG0071	2017-08-18 07:25:00+03	2017-08-18 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27136	PG0071	2017-08-29 07:25:00+03	2017-08-29 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27137	PG0071	2017-08-17 07:25:00+03	2017-08-17 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27138	PG0071	2017-08-16 07:25:00+03	2017-08-16 09:00:00+03	TOF	ABA	On Time	CN1	\N	\N
27139	PG0071	2017-08-30 07:25:00+03	2017-08-30 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27140	PG0071	2017-08-15 07:25:00+03	2017-08-15 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-15 07:27:00+03	2017-08-15 09:00:00+03
27141	PG0071	2017-08-31 07:25:00+03	2017-08-31 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27142	PG0071	2017-08-14 07:25:00+03	2017-08-14 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-14 07:28:00+03	2017-08-14 09:03:00+03
27143	PG0071	2017-08-13 07:25:00+03	2017-08-13 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-13 07:29:00+03	2017-08-13 09:06:00+03
27144	PG0071	2017-09-01 07:25:00+03	2017-09-01 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27145	PG0071	2017-08-12 07:25:00+03	2017-08-12 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-12 07:29:00+03	2017-08-12 09:03:00+03
27146	PG0071	2017-08-11 07:25:00+03	2017-08-11 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-11 07:29:00+03	2017-08-11 09:04:00+03
27147	PG0071	2017-09-02 07:25:00+03	2017-09-02 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27148	PG0071	2017-08-10 07:25:00+03	2017-08-10 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-10 10:37:00+03	2017-08-10 12:12:00+03
27149	PG0071	2017-08-09 07:25:00+03	2017-08-09 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-09 07:30:00+03	2017-08-09 09:05:00+03
27150	PG0071	2017-09-03 07:25:00+03	2017-09-03 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27151	PG0071	2017-08-08 07:25:00+03	2017-08-08 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-08 07:29:00+03	2017-08-08 09:03:00+03
27152	PG0071	2017-08-07 07:25:00+03	2017-08-07 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-07 07:28:00+03	2017-08-07 09:02:00+03
27153	PG0071	2017-09-04 07:25:00+03	2017-09-04 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27154	PG0071	2017-08-06 07:25:00+03	2017-08-06 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-06 07:28:00+03	2017-08-06 09:02:00+03
27155	PG0071	2017-08-05 07:25:00+03	2017-08-05 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-05 07:27:00+03	2017-08-05 09:01:00+03
27156	PG0071	2017-09-05 07:25:00+03	2017-09-05 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27157	PG0071	2017-08-04 07:25:00+03	2017-08-04 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-04 07:28:00+03	2017-08-04 09:01:00+03
27158	PG0071	2017-08-03 07:25:00+03	2017-08-03 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-03 07:28:00+03	2017-08-03 09:05:00+03
27159	PG0071	2017-09-06 07:25:00+03	2017-09-06 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27160	PG0071	2017-08-02 07:25:00+03	2017-08-02 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-02 07:28:00+03	2017-08-02 09:04:00+03
27161	PG0071	2017-08-01 07:25:00+03	2017-08-01 09:00:00+03	TOF	ABA	Arrived	CN1	2017-08-01 07:27:00+03	2017-08-01 09:01:00+03
27162	PG0071	2017-09-07 07:25:00+03	2017-09-07 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27163	PG0071	2017-07-30 07:25:00+03	2017-07-30 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-30 07:27:00+03	2017-07-30 09:02:00+03
27164	PG0071	2017-09-08 07:25:00+03	2017-09-08 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27165	PG0071	2017-07-29 07:25:00+03	2017-07-29 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-29 07:27:00+03	2017-07-29 09:02:00+03
27166	PG0071	2017-07-28 07:25:00+03	2017-07-28 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-28 07:28:00+03	2017-07-28 09:05:00+03
27167	PG0071	2017-09-09 07:25:00+03	2017-09-09 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27168	PG0071	2017-07-27 07:25:00+03	2017-07-27 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-27 07:26:00+03	2017-07-27 09:01:00+03
27169	PG0071	2017-07-26 07:25:00+03	2017-07-26 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-26 07:27:00+03	2017-07-26 09:03:00+03
27170	PG0071	2017-09-10 07:25:00+03	2017-09-10 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27171	PG0071	2017-07-25 07:25:00+03	2017-07-25 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-25 07:27:00+03	2017-07-25 09:03:00+03
27172	PG0071	2017-07-24 07:25:00+03	2017-07-24 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-24 07:27:00+03	2017-07-24 09:03:00+03
27173	PG0071	2017-09-11 07:25:00+03	2017-09-11 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27174	PG0071	2017-07-23 07:25:00+03	2017-07-23 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-23 07:29:00+03	2017-07-23 09:05:00+03
27175	PG0071	2017-07-22 07:25:00+03	2017-07-22 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-22 07:28:00+03	2017-07-22 09:02:00+03
27176	PG0071	2017-09-12 07:25:00+03	2017-09-12 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27177	PG0071	2017-07-21 07:25:00+03	2017-07-21 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-21 07:28:00+03	2017-07-21 09:03:00+03
27178	PG0071	2017-07-20 07:25:00+03	2017-07-20 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-20 07:29:00+03	2017-07-20 09:05:00+03
27179	PG0071	2017-09-13 07:25:00+03	2017-09-13 09:00:00+03	TOF	ABA	Scheduled	CN1	\N	\N
27180	PG0071	2017-07-19 07:25:00+03	2017-07-19 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-19 07:29:00+03	2017-07-19 09:06:00+03
27181	PG0071	2017-07-18 07:25:00+03	2017-07-18 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-18 07:29:00+03	2017-07-18 09:04:00+03
27182	PG0071	2017-07-17 07:25:00+03	2017-07-17 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-17 07:27:00+03	2017-07-17 09:01:00+03
27183	PG0071	2017-09-14 07:25:00+03	2017-09-14 09:00:00+03	TOF	ABA	Cancelled	CN1	\N	\N
27184	PG0071	2017-07-16 07:25:00+03	2017-07-16 09:00:00+03	TOF	ABA	Arrived	CN1	2017-07-16 07:27:00+03	2017-07-16 09:01:00+03
27185	PG0074	2017-07-17 15:00:00+03	2017-07-17 18:50:00+03	TOF	IAR	Arrived	CR2	2017-07-17 15:02:00+03	2017-07-17 18:50:00+03
27186	PG0074	2017-07-24 15:00:00+03	2017-07-24 18:50:00+03	TOF	IAR	Arrived	CR2	2017-07-24 15:05:00+03	2017-07-24 18:55:00+03
27187	PG0074	2017-07-31 15:00:00+03	2017-07-31 18:50:00+03	TOF	IAR	Arrived	CR2	2017-07-31 15:05:00+03	2017-07-31 18:55:00+03
27188	PG0074	2017-08-28 15:00:00+03	2017-08-28 18:50:00+03	TOF	IAR	Scheduled	CR2	\N	\N
27189	PG0074	2017-09-11 15:00:00+03	2017-09-11 18:50:00+03	TOF	IAR	Cancelled	CR2	\N	\N
27190	PG0074	2017-08-14 15:00:00+03	2017-08-14 18:50:00+03	TOF	IAR	Arrived	CR2	2017-08-14 15:02:00+03	2017-08-14 18:52:00+03
27191	PG0074	2017-09-04 15:00:00+03	2017-09-04 18:50:00+03	TOF	IAR	Scheduled	CR2	\N	\N
27192	PG0074	2017-08-21 15:00:00+03	2017-08-21 18:50:00+03	TOF	IAR	Scheduled	CR2	\N	\N
27193	PG0074	2017-08-07 15:00:00+03	2017-08-07 18:50:00+03	TOF	IAR	Arrived	CR2	2017-08-07 15:02:00+03	2017-08-07 18:56:00+03
27194	PG0182	2017-08-29 05:50:00+03	2017-08-29 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27195	PG0182	2017-07-26 05:50:00+03	2017-07-26 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-26 05:52:00+03	2017-07-26 06:51:00+03
27196	PG0182	2017-08-24 05:50:00+03	2017-08-24 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27197	PG0182	2017-08-12 05:50:00+03	2017-08-12 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-12 05:54:00+03	2017-08-12 06:54:00+03
27198	PG0182	2017-09-04 05:50:00+03	2017-09-04 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27199	PG0182	2017-09-10 05:50:00+03	2017-09-10 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27200	PG0182	2017-09-06 05:50:00+03	2017-09-06 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27201	PG0182	2017-08-01 05:50:00+03	2017-08-01 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-01 05:55:00+03	2017-08-01 06:55:00+03
27202	PG0182	2017-08-03 05:50:00+03	2017-08-03 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-03 05:51:00+03	2017-08-03 06:50:00+03
27203	PG0182	2017-07-21 05:50:00+03	2017-07-21 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-21 05:55:00+03	2017-07-21 06:55:00+03
27204	PG0182	2017-09-14 05:50:00+03	2017-09-14 06:50:00+03	TOF	NOZ	Cancelled	CN1	\N	\N
27205	PG0182	2017-08-22 05:50:00+03	2017-08-22 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27206	PG0182	2017-08-20 05:50:00+03	2017-08-20 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27207	PG0182	2017-08-31 05:50:00+03	2017-08-31 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27208	PG0182	2017-07-28 05:50:00+03	2017-07-28 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-28 05:51:00+03	2017-07-28 06:52:00+03
27209	PG0182	2017-08-02 05:50:00+03	2017-08-02 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-02 05:51:00+03	2017-08-02 06:51:00+03
27210	PG0182	2017-07-20 05:50:00+03	2017-07-20 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-20 05:53:00+03	2017-07-20 06:53:00+03
27211	PG0182	2017-08-06 05:50:00+03	2017-08-06 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-06 05:55:00+03	2017-08-06 06:54:00+03
27212	PG0182	2017-08-14 05:50:00+03	2017-08-14 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-14 05:53:00+03	2017-08-14 06:53:00+03
27213	PG0182	2017-09-09 05:50:00+03	2017-09-09 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27214	PG0182	2017-07-31 05:50:00+03	2017-07-31 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-31 05:55:00+03	2017-07-31 06:55:00+03
27215	PG0182	2017-07-22 05:50:00+03	2017-07-22 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-22 05:52:00+03	2017-07-22 06:52:00+03
27216	PG0182	2017-08-08 05:50:00+03	2017-08-08 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-08 05:52:00+03	2017-08-08 06:52:00+03
27217	PG0182	2017-08-15 05:50:00+03	2017-08-15 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-15 05:54:00+03	2017-08-15 06:55:00+03
27218	PG0182	2017-07-29 05:50:00+03	2017-07-29 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-29 05:52:00+03	2017-07-29 06:53:00+03
27219	PG0182	2017-07-30 05:50:00+03	2017-07-30 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-30 05:53:00+03	2017-07-30 06:53:00+03
27220	PG0182	2017-09-07 05:50:00+03	2017-09-07 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27221	PG0182	2017-08-09 05:50:00+03	2017-08-09 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-09 05:51:00+03	2017-08-09 06:51:00+03
27222	PG0182	2017-09-11 05:50:00+03	2017-09-11 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27223	PG0182	2017-08-13 05:50:00+03	2017-08-13 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-13 05:51:00+03	2017-08-13 06:51:00+03
27224	PG0182	2017-08-16 05:50:00+03	2017-08-16 06:50:00+03	TOF	NOZ	On Time	CN1	\N	\N
27225	PG0182	2017-08-21 05:50:00+03	2017-08-21 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27226	PG0182	2017-09-03 05:50:00+03	2017-09-03 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27227	PG0182	2017-08-11 05:50:00+03	2017-08-11 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-11 05:53:00+03	2017-08-11 06:53:00+03
27228	PG0182	2017-08-05 05:50:00+03	2017-08-05 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-05 05:52:00+03	2017-08-05 06:51:00+03
27229	PG0182	2017-08-27 05:50:00+03	2017-08-27 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27230	PG0182	2017-07-18 05:50:00+03	2017-07-18 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-18 05:53:00+03	2017-07-18 06:53:00+03
27231	PG0182	2017-08-25 05:50:00+03	2017-08-25 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27232	PG0182	2017-08-04 05:50:00+03	2017-08-04 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-04 05:52:00+03	2017-08-04 06:51:00+03
27233	PG0182	2017-07-19 05:50:00+03	2017-07-19 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-19 05:52:00+03	2017-07-19 06:51:00+03
27234	PG0182	2017-08-30 05:50:00+03	2017-08-30 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27235	PG0182	2017-09-05 05:50:00+03	2017-09-05 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27236	PG0182	2017-07-17 05:50:00+03	2017-07-17 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-17 05:54:00+03	2017-07-17 06:54:00+03
27237	PG0182	2017-09-12 05:50:00+03	2017-09-12 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27238	PG0182	2017-08-26 05:50:00+03	2017-08-26 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27239	PG0182	2017-07-27 05:50:00+03	2017-07-27 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-27 05:53:00+03	2017-07-27 06:53:00+03
27240	PG0182	2017-08-23 05:50:00+03	2017-08-23 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27241	PG0182	2017-08-28 05:50:00+03	2017-08-28 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27242	PG0182	2017-09-08 05:50:00+03	2017-09-08 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27243	PG0182	2017-07-23 05:50:00+03	2017-07-23 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-23 05:54:00+03	2017-07-23 06:54:00+03
27244	PG0182	2017-09-02 05:50:00+03	2017-09-02 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27245	PG0182	2017-08-18 05:50:00+03	2017-08-18 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27246	PG0182	2017-09-13 05:50:00+03	2017-09-13 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27247	PG0182	2017-07-16 05:50:00+03	2017-07-16 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-16 05:53:00+03	2017-07-16 06:53:00+03
27248	PG0182	2017-08-19 05:50:00+03	2017-08-19 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27249	PG0182	2017-07-25 05:50:00+03	2017-07-25 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-25 05:54:00+03	2017-07-25 06:53:00+03
27250	PG0182	2017-08-10 05:50:00+03	2017-08-10 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-10 05:54:00+03	2017-08-10 06:54:00+03
27251	PG0182	2017-08-07 05:50:00+03	2017-08-07 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-08-07 05:51:00+03	2017-08-07 06:50:00+03
27252	PG0182	2017-09-01 05:50:00+03	2017-09-01 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27253	PG0182	2017-08-17 05:50:00+03	2017-08-17 06:50:00+03	TOF	NOZ	Scheduled	CN1	\N	\N
27254	PG0182	2017-07-24 05:50:00+03	2017-07-24 06:50:00+03	TOF	NOZ	Arrived	CN1	2017-07-24 05:53:00+03	2017-07-24 06:53:00+03
27255	PG0428	2017-09-03 14:55:00+03	2017-09-03 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27256	PG0428	2017-09-10 14:55:00+03	2017-09-10 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27257	PG0428	2017-08-06 14:55:00+03	2017-08-06 18:35:00+03	TOF	ARH	Arrived	CR2	2017-08-06 14:57:00+03	2017-08-06 18:36:00+03
27258	PG0428	2017-08-24 14:55:00+03	2017-08-24 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27259	PG0428	2017-07-20 14:55:00+03	2017-07-20 18:35:00+03	TOF	ARH	Arrived	CR2	2017-07-20 15:00:00+03	2017-07-20 18:36:00+03
27260	PG0428	2017-09-07 14:55:00+03	2017-09-07 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27261	PG0428	2017-07-16 14:55:00+03	2017-07-16 18:35:00+03	TOF	ARH	Arrived	CR2	2017-07-16 15:02:00+03	2017-07-16 18:41:00+03
27262	PG0428	2017-07-30 14:55:00+03	2017-07-30 18:35:00+03	TOF	ARH	Arrived	CR2	2017-07-30 15:00:00+03	2017-07-30 18:40:00+03
27263	PG0428	2017-08-13 14:55:00+03	2017-08-13 18:35:00+03	TOF	ARH	Arrived	CR2	2017-08-13 17:52:00+03	2017-08-13 21:36:00+03
27264	PG0428	2017-09-14 14:55:00+03	2017-09-14 18:35:00+03	TOF	ARH	Cancelled	CR2	\N	\N
27265	PG0428	2017-07-23 14:55:00+03	2017-07-23 18:35:00+03	TOF	ARH	Arrived	CR2	2017-07-23 14:58:00+03	2017-07-23 18:38:00+03
27266	PG0428	2017-08-17 14:55:00+03	2017-08-17 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27267	PG0428	2017-08-03 14:55:00+03	2017-08-03 18:35:00+03	TOF	ARH	Arrived	CR2	2017-08-03 14:58:00+03	2017-08-03 18:40:00+03
27268	PG0428	2017-08-20 14:55:00+03	2017-08-20 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27269	PG0428	2017-08-27 14:55:00+03	2017-08-27 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27270	PG0428	2017-07-27 14:55:00+03	2017-07-27 18:35:00+03	TOF	ARH	Arrived	CR2	2017-07-27 15:00:00+03	2017-07-27 18:39:00+03
27271	PG0428	2017-08-10 14:55:00+03	2017-08-10 18:35:00+03	TOF	ARH	Arrived	CR2	2017-08-10 14:55:00+03	2017-08-10 18:39:00+03
27272	PG0428	2017-08-31 14:55:00+03	2017-08-31 18:35:00+03	TOF	ARH	Scheduled	CR2	\N	\N
27273	PG0554	2017-08-11 09:35:00+03	2017-08-11 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-11 09:39:00+03	2017-08-11 11:18:00+03
27274	PG0554	2017-09-01 09:35:00+03	2017-09-01 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27275	PG0554	2017-08-12 09:35:00+03	2017-08-12 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-12 09:37:00+03	2017-08-12 11:16:00+03
27276	PG0554	2017-08-28 09:35:00+03	2017-08-28 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27277	PG0554	2017-08-29 09:35:00+03	2017-08-29 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27278	PG0554	2017-08-13 09:35:00+03	2017-08-13 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-13 09:42:00+03	2017-08-13 11:20:00+03
27279	PG0554	2017-08-24 09:35:00+03	2017-08-24 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27280	PG0554	2017-07-23 09:35:00+03	2017-07-23 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-23 09:39:00+03	2017-07-23 11:19:00+03
27281	PG0554	2017-07-21 09:35:00+03	2017-07-21 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-21 09:37:00+03	2017-07-21 11:17:00+03
27282	PG0554	2017-07-20 09:35:00+03	2017-07-20 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-20 09:39:00+03	2017-07-20 11:19:00+03
27283	PG0554	2017-09-12 09:35:00+03	2017-09-12 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27284	PG0554	2017-09-05 09:35:00+03	2017-09-05 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27285	PG0554	2017-08-09 09:35:00+03	2017-08-09 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-09 09:39:00+03	2017-08-09 11:18:00+03
27286	PG0554	2017-08-22 09:35:00+03	2017-08-22 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27287	PG0554	2017-08-19 09:35:00+03	2017-08-19 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27288	PG0554	2017-07-17 09:35:00+03	2017-07-17 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-17 09:39:00+03	2017-07-17 11:19:00+03
27289	PG0554	2017-08-14 09:35:00+03	2017-08-14 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-14 12:57:00+03	2017-08-14 14:38:00+03
27290	PG0554	2017-07-18 09:35:00+03	2017-07-18 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-18 09:36:00+03	2017-07-18 11:14:00+03
27291	PG0554	2017-08-15 09:35:00+03	2017-08-15 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-15 09:37:00+03	2017-08-15 11:16:00+03
27292	PG0554	2017-07-19 09:35:00+03	2017-07-19 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-19 09:38:00+03	2017-07-19 11:17:00+03
27293	PG0554	2017-09-04 09:35:00+03	2017-09-04 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27294	PG0554	2017-09-13 09:35:00+03	2017-09-13 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27295	PG0554	2017-08-04 09:35:00+03	2017-08-04 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-04 09:42:00+03	2017-08-04 11:23:00+03
27296	PG0554	2017-07-24 09:35:00+03	2017-07-24 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-24 09:37:00+03	2017-07-24 11:17:00+03
27297	PG0554	2017-08-25 09:35:00+03	2017-08-25 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27298	PG0554	2017-08-26 09:35:00+03	2017-08-26 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27299	PG0554	2017-08-02 09:35:00+03	2017-08-02 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-02 09:39:00+03	2017-08-02 11:21:00+03
27300	PG0554	2017-08-08 09:35:00+03	2017-08-08 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-08 09:38:00+03	2017-08-08 11:17:00+03
27301	PG0554	2017-08-23 09:35:00+03	2017-08-23 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27302	PG0554	2017-09-14 09:35:00+03	2017-09-14 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27303	PG0554	2017-07-22 09:35:00+03	2017-07-22 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-22 09:37:00+03	2017-07-22 11:16:00+03
27304	PG0554	2017-08-21 09:35:00+03	2017-08-21 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27305	PG0554	2017-07-31 09:35:00+03	2017-07-31 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-31 09:41:00+03	2017-07-31 11:19:00+03
27306	PG0554	2017-07-27 09:35:00+03	2017-07-27 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-27 09:39:00+03	2017-07-27 11:21:00+03
27307	PG0554	2017-08-17 09:35:00+03	2017-08-17 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27308	PG0554	2017-07-30 09:35:00+03	2017-07-30 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-30 09:37:00+03	2017-07-30 11:17:00+03
27309	PG0554	2017-09-02 09:35:00+03	2017-09-02 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27310	PG0554	2017-08-06 09:35:00+03	2017-08-06 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-06 09:38:00+03	2017-08-06 11:17:00+03
27311	PG0554	2017-09-07 09:35:00+03	2017-09-07 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27312	PG0554	2017-07-25 09:35:00+03	2017-07-25 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-25 09:37:00+03	2017-07-25 11:17:00+03
27313	PG0554	2017-08-05 09:35:00+03	2017-08-05 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-05 09:35:00+03	2017-08-05 11:15:00+03
27314	PG0554	2017-08-01 09:35:00+03	2017-08-01 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-01 09:36:00+03	2017-08-01 11:18:00+03
27315	PG0554	2017-08-30 09:35:00+03	2017-08-30 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27316	PG0554	2017-07-26 09:35:00+03	2017-07-26 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-26 09:36:00+03	2017-07-26 11:14:00+03
27317	PG0554	2017-09-06 09:35:00+03	2017-09-06 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27318	PG0554	2017-07-16 09:35:00+03	2017-07-16 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-16 09:39:00+03	2017-07-16 11:19:00+03
27319	PG0554	2017-08-16 09:35:00+03	2017-08-16 11:15:00+03	REN	VKO	On Time	SU9	\N	\N
27320	PG0554	2017-08-18 09:35:00+03	2017-08-18 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27321	PG0554	2017-09-09 09:35:00+03	2017-09-09 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27322	PG0554	2017-09-11 09:35:00+03	2017-09-11 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27323	PG0554	2017-09-03 09:35:00+03	2017-09-03 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27324	PG0554	2017-09-10 09:35:00+03	2017-09-10 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27325	PG0554	2017-08-31 09:35:00+03	2017-08-31 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27326	PG0554	2017-08-03 09:35:00+03	2017-08-03 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-03 09:36:00+03	2017-08-03 11:16:00+03
27327	PG0554	2017-07-29 09:35:00+03	2017-07-29 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-29 09:36:00+03	2017-07-29 11:17:00+03
27328	PG0554	2017-08-20 09:35:00+03	2017-08-20 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27329	PG0554	2017-07-28 09:35:00+03	2017-07-28 11:15:00+03	REN	VKO	Arrived	SU9	2017-07-28 09:38:00+03	2017-07-28 11:18:00+03
27330	PG0554	2017-09-08 09:35:00+03	2017-09-08 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27331	PG0554	2017-08-07 09:35:00+03	2017-08-07 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-07 09:40:00+03	2017-08-07 11:21:00+03
27332	PG0554	2017-08-10 09:35:00+03	2017-08-10 11:15:00+03	REN	VKO	Arrived	SU9	2017-08-10 09:40:00+03	2017-08-10 11:19:00+03
27333	PG0554	2017-08-27 09:35:00+03	2017-08-27 11:15:00+03	REN	VKO	Scheduled	SU9	\N	\N
27334	PG0361	2017-08-10 14:05:00+03	2017-08-10 16:40:00+03	REN	LED	Arrived	CR2	2017-08-10 14:07:00+03	2017-08-10 16:43:00+03
27335	PG0361	2017-07-26 14:05:00+03	2017-07-26 16:40:00+03	REN	LED	Arrived	CR2	2017-07-26 14:07:00+03	2017-07-26 16:41:00+03
27336	PG0361	2017-07-21 14:05:00+03	2017-07-21 16:40:00+03	REN	LED	Arrived	CR2	2017-07-21 14:13:00+03	2017-07-21 16:51:00+03
27337	PG0361	2017-09-03 14:05:00+03	2017-09-03 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27338	PG0361	2017-09-13 14:05:00+03	2017-09-13 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27339	PG0361	2017-09-06 14:05:00+03	2017-09-06 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27340	PG0361	2017-07-27 14:05:00+03	2017-07-27 16:40:00+03	REN	LED	Arrived	CR2	2017-07-27 14:08:00+03	2017-07-27 16:44:00+03
27341	PG0361	2017-08-20 14:05:00+03	2017-08-20 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27342	PG0361	2017-08-07 14:05:00+03	2017-08-07 16:40:00+03	REN	LED	Arrived	CR2	2017-08-07 14:08:00+03	2017-08-07 16:39:00+03
27343	PG0361	2017-08-16 14:05:00+03	2017-08-16 16:40:00+03	REN	LED	On Time	CR2	\N	\N
27344	PG0361	2017-08-02 14:05:00+03	2017-08-02 16:40:00+03	REN	LED	Arrived	CR2	2017-08-02 14:06:00+03	2017-08-02 16:43:00+03
27345	PG0361	2017-07-24 14:05:00+03	2017-07-24 16:40:00+03	REN	LED	Arrived	CR2	2017-07-24 14:08:00+03	2017-07-24 16:44:00+03
27346	PG0361	2017-08-25 14:05:00+03	2017-08-25 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27347	PG0361	2017-08-04 14:05:00+03	2017-08-04 16:40:00+03	REN	LED	Arrived	CR2	2017-08-04 14:08:00+03	2017-08-04 16:45:00+03
27348	PG0361	2017-09-01 14:05:00+03	2017-09-01 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27349	PG0361	2017-08-29 14:05:00+03	2017-08-29 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27350	PG0361	2017-08-14 14:05:00+03	2017-08-14 16:40:00+03	REN	LED	Arrived	CR2	2017-08-14 14:08:00+03	2017-08-14 16:43:00+03
27351	PG0361	2017-07-17 14:05:00+03	2017-07-17 16:40:00+03	REN	LED	Arrived	CR2	2017-07-17 14:11:00+03	2017-07-17 16:48:00+03
27352	PG0361	2017-08-19 14:05:00+03	2017-08-19 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27353	PG0361	2017-08-13 14:05:00+03	2017-08-13 16:40:00+03	REN	LED	Arrived	CR2	2017-08-13 14:10:00+03	2017-08-13 16:45:00+03
27354	PG0361	2017-08-03 14:05:00+03	2017-08-03 16:40:00+03	REN	LED	Arrived	CR2	2017-08-03 14:06:00+03	2017-08-03 16:40:00+03
27355	PG0361	2017-07-23 14:05:00+03	2017-07-23 16:40:00+03	REN	LED	Arrived	CR2	2017-07-23 14:06:00+03	2017-07-23 16:42:00+03
27356	PG0361	2017-09-05 14:05:00+03	2017-09-05 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27357	PG0361	2017-08-31 14:05:00+03	2017-08-31 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27358	PG0361	2017-07-29 14:05:00+03	2017-07-29 16:40:00+03	REN	LED	Arrived	CR2	2017-07-29 14:09:00+03	2017-07-29 16:44:00+03
27359	PG0361	2017-09-08 14:05:00+03	2017-09-08 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27360	PG0361	2017-09-02 14:05:00+03	2017-09-02 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27361	PG0361	2017-08-08 14:05:00+03	2017-08-08 16:40:00+03	REN	LED	Arrived	CR2	2017-08-08 14:09:00+03	2017-08-08 16:42:00+03
27362	PG0361	2017-08-11 14:05:00+03	2017-08-11 16:40:00+03	REN	LED	Arrived	CR2	2017-08-11 14:08:00+03	2017-08-11 16:42:00+03
27363	PG0361	2017-07-30 14:05:00+03	2017-07-30 16:40:00+03	REN	LED	Arrived	CR2	2017-07-30 14:11:00+03	2017-07-30 16:47:00+03
27364	PG0361	2017-08-06 14:05:00+03	2017-08-06 16:40:00+03	REN	LED	Arrived	CR2	2017-08-06 14:07:00+03	2017-08-06 16:43:00+03
27365	PG0361	2017-08-09 14:05:00+03	2017-08-09 16:40:00+03	REN	LED	Arrived	CR2	2017-08-09 14:07:00+03	2017-08-09 16:41:00+03
27366	PG0361	2017-08-23 14:05:00+03	2017-08-23 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27367	PG0361	2017-09-14 14:05:00+03	2017-09-14 16:40:00+03	REN	LED	Cancelled	CR2	\N	\N
27368	PG0361	2017-07-16 14:05:00+03	2017-07-16 16:40:00+03	REN	LED	Arrived	CR2	2017-07-16 14:10:00+03	2017-07-16 16:46:00+03
27369	PG0361	2017-07-28 14:05:00+03	2017-07-28 16:40:00+03	REN	LED	Arrived	CR2	2017-07-28 14:07:00+03	2017-07-28 16:41:00+03
27370	PG0361	2017-09-09 14:05:00+03	2017-09-09 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27371	PG0361	2017-08-18 14:05:00+03	2017-08-18 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27372	PG0361	2017-07-31 14:05:00+03	2017-07-31 16:40:00+03	REN	LED	Arrived	CR2	2017-07-31 17:10:00+03	2017-07-31 19:46:00+03
27373	PG0361	2017-08-21 14:05:00+03	2017-08-21 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27374	PG0361	2017-07-18 14:05:00+03	2017-07-18 16:40:00+03	REN	LED	Arrived	CR2	2017-07-18 14:06:00+03	2017-07-18 16:41:00+03
27375	PG0361	2017-09-10 14:05:00+03	2017-09-10 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27376	PG0361	2017-08-12 14:05:00+03	2017-08-12 16:40:00+03	REN	LED	Arrived	CR2	2017-08-12 14:10:00+03	2017-08-12 16:44:00+03
27377	PG0361	2017-09-12 14:05:00+03	2017-09-12 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27378	PG0361	2017-07-19 14:05:00+03	2017-07-19 16:40:00+03	REN	LED	Arrived	CR2	2017-07-19 14:09:00+03	2017-07-19 16:41:00+03
27379	PG0361	2017-08-15 14:05:00+03	2017-08-15 16:40:00+03	REN	LED	Arrived	CR2	2017-08-15 14:10:00+03	2017-08-15 16:43:00+03
27380	PG0361	2017-08-22 14:05:00+03	2017-08-22 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27381	PG0361	2017-08-28 14:05:00+03	2017-08-28 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27382	PG0361	2017-09-07 14:05:00+03	2017-09-07 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27383	PG0361	2017-07-25 14:05:00+03	2017-07-25 16:40:00+03	REN	LED	Arrived	CR2	2017-07-25 14:09:00+03	2017-07-25 16:42:00+03
27384	PG0361	2017-08-27 14:05:00+03	2017-08-27 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27385	PG0361	2017-08-17 14:05:00+03	2017-08-17 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27386	PG0361	2017-09-04 14:05:00+03	2017-09-04 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27387	PG0361	2017-07-22 14:05:00+03	2017-07-22 16:40:00+03	REN	LED	Arrived	CR2	2017-07-22 14:07:00+03	2017-07-22 16:44:00+03
27388	PG0361	2017-08-26 14:05:00+03	2017-08-26 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27389	PG0361	2017-08-05 14:05:00+03	2017-08-05 16:40:00+03	REN	LED	Arrived	CR2	2017-08-05 14:07:00+03	2017-08-05 16:42:00+03
27390	PG0361	2017-07-20 14:05:00+03	2017-07-20 16:40:00+03	REN	LED	Arrived	CR2	2017-07-20 14:10:00+03	2017-07-20 16:43:00+03
27391	PG0361	2017-08-30 14:05:00+03	2017-08-30 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27392	PG0361	2017-08-01 14:05:00+03	2017-08-01 16:40:00+03	REN	LED	Arrived	CR2	2017-08-01 17:42:00+03	2017-08-01 20:16:00+03
27393	PG0361	2017-09-11 14:05:00+03	2017-09-11 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27394	PG0361	2017-08-24 14:05:00+03	2017-08-24 16:40:00+03	REN	LED	Scheduled	CR2	\N	\N
27395	PG0149	2017-09-12 10:45:00+03	2017-09-12 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27396	PG0149	2017-08-24 10:45:00+03	2017-08-24 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27397	PG0149	2017-08-07 10:45:00+03	2017-08-07 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-07 10:49:00+03	2017-08-07 11:14:00+03
27398	PG0149	2017-07-20 10:45:00+03	2017-07-20 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-20 10:49:00+03	2017-07-20 11:14:00+03
27399	PG0149	2017-08-20 10:45:00+03	2017-08-20 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27400	PG0149	2017-08-25 10:45:00+03	2017-08-25 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27401	PG0149	2017-09-03 10:45:00+03	2017-09-03 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27402	PG0149	2017-07-31 10:45:00+03	2017-07-31 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-31 10:48:00+03	2017-07-31 11:13:00+03
27403	PG0149	2017-08-21 10:45:00+03	2017-08-21 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27404	PG0149	2017-08-10 10:45:00+03	2017-08-10 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-10 10:47:00+03	2017-08-10 11:12:00+03
27405	PG0149	2017-08-12 10:45:00+03	2017-08-12 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-12 13:18:00+03	2017-08-12 13:43:00+03
27406	PG0149	2017-08-08 10:45:00+03	2017-08-08 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-08 10:45:00+03	2017-08-08 11:10:00+03
27407	PG0149	2017-09-07 10:45:00+03	2017-09-07 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27408	PG0149	2017-08-01 10:45:00+03	2017-08-01 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-01 10:46:00+03	2017-08-01 11:11:00+03
27409	PG0149	2017-07-17 10:45:00+03	2017-07-17 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-17 10:49:00+03	2017-07-17 11:14:00+03
27410	PG0149	2017-07-27 10:45:00+03	2017-07-27 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-27 10:49:00+03	2017-07-27 11:14:00+03
27411	PG0149	2017-09-01 10:45:00+03	2017-09-01 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27412	PG0149	2017-08-06 10:45:00+03	2017-08-06 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-06 10:46:00+03	2017-08-06 11:11:00+03
27413	PG0149	2017-08-28 10:45:00+03	2017-08-28 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27414	PG0149	2017-09-08 10:45:00+03	2017-09-08 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27415	PG0149	2017-08-18 10:45:00+03	2017-08-18 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27416	PG0149	2017-07-23 10:45:00+03	2017-07-23 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-23 10:49:00+03	2017-07-23 11:13:00+03
27417	PG0149	2017-07-16 10:45:00+03	2017-07-16 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-16 10:47:00+03	2017-07-16 11:12:00+03
27418	PG0149	2017-08-31 10:45:00+03	2017-08-31 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27419	PG0149	2017-08-30 10:45:00+03	2017-08-30 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27420	PG0149	2017-09-09 10:45:00+03	2017-09-09 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27421	PG0149	2017-09-14 10:45:00+03	2017-09-14 11:10:00+03	REN	UFA	Cancelled	CR2	\N	\N
27422	PG0149	2017-09-05 10:45:00+03	2017-09-05 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27423	PG0149	2017-07-19 10:45:00+03	2017-07-19 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-19 10:49:00+03	2017-07-19 11:14:00+03
27424	PG0149	2017-09-04 10:45:00+03	2017-09-04 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27425	PG0149	2017-08-04 10:45:00+03	2017-08-04 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-04 10:48:00+03	2017-08-04 11:13:00+03
27426	PG0149	2017-07-18 10:45:00+03	2017-07-18 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-18 10:46:00+03	2017-07-18 11:11:00+03
27427	PG0149	2017-08-05 10:45:00+03	2017-08-05 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-05 10:46:00+03	2017-08-05 11:11:00+03
27428	PG0149	2017-08-23 10:45:00+03	2017-08-23 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27429	PG0149	2017-07-22 10:45:00+03	2017-07-22 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-22 10:48:00+03	2017-07-22 11:13:00+03
27430	PG0149	2017-08-16 10:45:00+03	2017-08-16 11:10:00+03	REN	UFA	On Time	CR2	\N	\N
27431	PG0149	2017-08-03 10:45:00+03	2017-08-03 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-03 10:50:00+03	2017-08-03 11:15:00+03
27432	PG0149	2017-09-11 10:45:00+03	2017-09-11 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27433	PG0149	2017-08-27 10:45:00+03	2017-08-27 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27434	PG0149	2017-08-13 10:45:00+03	2017-08-13 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-13 10:49:00+03	2017-08-13 11:14:00+03
27435	PG0149	2017-08-29 10:45:00+03	2017-08-29 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27436	PG0149	2017-08-26 10:45:00+03	2017-08-26 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27437	PG0149	2017-08-14 10:45:00+03	2017-08-14 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-14 10:53:00+03	2017-08-14 11:18:00+03
27438	PG0149	2017-08-17 10:45:00+03	2017-08-17 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27439	PG0149	2017-07-30 10:45:00+03	2017-07-30 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-30 10:47:00+03	2017-07-30 11:12:00+03
27440	PG0149	2017-08-11 10:45:00+03	2017-08-11 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-11 10:48:00+03	2017-08-11 11:13:00+03
27441	PG0149	2017-07-28 10:45:00+03	2017-07-28 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-28 10:48:00+03	2017-07-28 11:13:00+03
27442	PG0149	2017-09-13 10:45:00+03	2017-09-13 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27443	PG0149	2017-08-09 10:45:00+03	2017-08-09 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-09 10:47:00+03	2017-08-09 11:12:00+03
27444	PG0149	2017-08-19 10:45:00+03	2017-08-19 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27445	PG0149	2017-09-02 10:45:00+03	2017-09-02 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27446	PG0149	2017-07-24 10:45:00+03	2017-07-24 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-24 10:47:00+03	2017-07-24 11:12:00+03
27447	PG0149	2017-08-15 10:45:00+03	2017-08-15 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-15 10:46:00+03	2017-08-15 11:11:00+03
27448	PG0149	2017-07-26 10:45:00+03	2017-07-26 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-26 10:46:00+03	2017-07-26 11:11:00+03
27449	PG0149	2017-09-10 10:45:00+03	2017-09-10 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27450	PG0149	2017-07-25 10:45:00+03	2017-07-25 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-25 10:50:00+03	2017-07-25 11:15:00+03
27451	PG0149	2017-07-21 10:45:00+03	2017-07-21 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-21 10:50:00+03	2017-07-21 11:15:00+03
27452	PG0149	2017-08-02 10:45:00+03	2017-08-02 11:10:00+03	REN	UFA	Arrived	CR2	2017-08-02 10:50:00+03	2017-08-02 11:15:00+03
27453	PG0149	2017-09-06 10:45:00+03	2017-09-06 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27454	PG0149	2017-08-22 10:45:00+03	2017-08-22 11:10:00+03	REN	UFA	Scheduled	CR2	\N	\N
27455	PG0149	2017-07-29 10:45:00+03	2017-07-29 11:10:00+03	REN	UFA	Arrived	CR2	2017-07-29 10:48:00+03	2017-07-29 11:13:00+03
27456	PG0534	2017-08-06 11:35:00+03	2017-08-06 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-06 11:39:00+03	2017-08-06 14:59:00+03
27457	PG0534	2017-08-19 11:35:00+03	2017-08-19 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27458	PG0534	2017-09-06 11:35:00+03	2017-09-06 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27459	PG0534	2017-09-02 11:35:00+03	2017-09-02 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27460	PG0534	2017-09-11 11:35:00+03	2017-09-11 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27461	PG0534	2017-08-23 11:35:00+03	2017-08-23 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27462	PG0534	2017-07-19 11:35:00+03	2017-07-19 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-19 11:37:00+03	2017-07-19 14:59:00+03
27463	PG0534	2017-08-18 11:35:00+03	2017-08-18 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27464	PG0534	2017-08-28 11:35:00+03	2017-08-28 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27465	PG0534	2017-07-28 11:35:00+03	2017-07-28 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-28 11:38:00+03	2017-07-28 14:56:00+03
27466	PG0534	2017-08-21 11:35:00+03	2017-08-21 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27467	PG0534	2017-07-29 11:35:00+03	2017-07-29 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-29 11:38:00+03	2017-07-29 14:56:00+03
27468	PG0534	2017-07-17 11:35:00+03	2017-07-17 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-17 11:37:00+03	2017-07-17 15:02:00+03
27469	PG0534	2017-07-20 11:35:00+03	2017-07-20 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-20 11:39:00+03	2017-07-20 15:02:00+03
27470	PG0534	2017-07-22 11:35:00+03	2017-07-22 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-22 11:39:00+03	2017-07-22 15:00:00+03
27471	PG0534	2017-07-26 11:35:00+03	2017-07-26 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-26 11:40:00+03	2017-07-26 15:01:00+03
27472	PG0534	2017-07-31 11:35:00+03	2017-07-31 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-31 11:36:00+03	2017-07-31 14:57:00+03
27473	PG0534	2017-08-15 11:35:00+03	2017-08-15 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-15 11:37:00+03	2017-08-15 14:53:00+03
27474	PG0534	2017-08-11 11:35:00+03	2017-08-11 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-11 11:40:00+03	2017-08-11 15:04:00+03
27475	PG0534	2017-08-20 11:35:00+03	2017-08-20 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27476	PG0534	2017-09-03 11:35:00+03	2017-09-03 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27477	PG0534	2017-08-05 11:35:00+03	2017-08-05 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-05 14:28:00+03	2017-08-05 17:46:00+03
27478	PG0534	2017-08-24 11:35:00+03	2017-08-24 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27479	PG0534	2017-08-13 11:35:00+03	2017-08-13 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-13 11:36:00+03	2017-08-13 14:53:00+03
27480	PG0534	2017-07-25 11:35:00+03	2017-07-25 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-25 11:35:00+03	2017-07-25 14:55:00+03
27481	PG0534	2017-08-27 11:35:00+03	2017-08-27 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27482	PG0534	2017-09-01 11:35:00+03	2017-09-01 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27483	PG0534	2017-07-24 11:35:00+03	2017-07-24 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-24 11:36:00+03	2017-07-24 14:54:00+03
27484	PG0534	2017-07-16 11:35:00+03	2017-07-16 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-16 11:37:00+03	2017-07-16 15:00:00+03
27485	PG0534	2017-08-10 11:35:00+03	2017-08-10 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-10 11:39:00+03	2017-08-10 14:59:00+03
27486	PG0534	2017-08-25 11:35:00+03	2017-08-25 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27487	PG0534	2017-09-14 11:35:00+03	2017-09-14 14:55:00+03	REN	ESL	Cancelled	CN1	\N	\N
27488	PG0534	2017-08-08 11:35:00+03	2017-08-08 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-08 11:38:00+03	2017-08-08 14:58:00+03
27489	PG0534	2017-09-09 11:35:00+03	2017-09-09 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27490	PG0534	2017-08-17 11:35:00+03	2017-08-17 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27491	PG0534	2017-08-16 11:35:00+03	2017-08-16 14:55:00+03	REN	ESL	On Time	CN1	\N	\N
27492	PG0534	2017-09-10 11:35:00+03	2017-09-10 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27493	PG0534	2017-08-29 11:35:00+03	2017-08-29 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27494	PG0534	2017-08-09 11:35:00+03	2017-08-09 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-09 11:37:00+03	2017-08-09 14:58:00+03
27495	PG0534	2017-07-27 11:35:00+03	2017-07-27 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-27 11:36:00+03	2017-07-27 14:53:00+03
27496	PG0534	2017-08-01 11:35:00+03	2017-08-01 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-01 11:40:00+03	2017-08-01 15:02:00+03
27497	PG0534	2017-09-04 11:35:00+03	2017-09-04 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27498	PG0534	2017-07-30 11:35:00+03	2017-07-30 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-30 11:39:00+03	2017-07-30 14:58:00+03
27499	PG0534	2017-07-21 11:35:00+03	2017-07-21 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-21 11:37:00+03	2017-07-21 15:00:00+03
27500	PG0534	2017-08-02 11:35:00+03	2017-08-02 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-02 11:38:00+03	2017-08-02 14:58:00+03
27501	PG0534	2017-08-30 11:35:00+03	2017-08-30 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27502	PG0534	2017-08-07 11:35:00+03	2017-08-07 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-07 15:01:00+03	2017-08-07 18:17:00+03
27503	PG0534	2017-08-14 11:35:00+03	2017-08-14 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-14 11:39:00+03	2017-08-14 15:01:00+03
27504	PG0534	2017-08-26 11:35:00+03	2017-08-26 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27505	PG0534	2017-09-13 11:35:00+03	2017-09-13 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27506	PG0534	2017-08-22 11:35:00+03	2017-08-22 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27507	PG0534	2017-08-12 11:35:00+03	2017-08-12 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-12 11:39:00+03	2017-08-12 15:00:00+03
27508	PG0534	2017-07-18 11:35:00+03	2017-07-18 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-18 11:43:00+03	2017-07-18 15:05:00+03
27509	PG0534	2017-09-05 11:35:00+03	2017-09-05 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27510	PG0534	2017-09-12 11:35:00+03	2017-09-12 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27511	PG0534	2017-08-31 11:35:00+03	2017-08-31 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27512	PG0534	2017-09-07 11:35:00+03	2017-09-07 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27513	PG0534	2017-08-04 11:35:00+03	2017-08-04 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-04 11:39:00+03	2017-08-04 15:00:00+03
27514	PG0534	2017-07-23 11:35:00+03	2017-07-23 14:55:00+03	REN	ESL	Arrived	CN1	2017-07-23 11:38:00+03	2017-07-23 14:59:00+03
27515	PG0534	2017-09-08 11:35:00+03	2017-09-08 14:55:00+03	REN	ESL	Scheduled	CN1	\N	\N
27516	PG0534	2017-08-03 11:35:00+03	2017-08-03 14:55:00+03	REN	ESL	Arrived	CN1	2017-08-03 11:39:00+03	2017-08-03 14:57:00+03
27517	PG0389	2017-08-01 10:40:00+03	2017-08-01 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-01 10:40:00+03	2017-08-01 11:10:00+03
27518	PG0389	2017-07-26 10:40:00+03	2017-07-26 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-26 10:40:00+03	2017-07-26 11:10:00+03
27519	PG0389	2017-09-01 10:40:00+03	2017-09-01 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27520	PG0389	2017-07-20 10:40:00+03	2017-07-20 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-20 10:40:00+03	2017-07-20 11:09:00+03
27521	PG0389	2017-09-04 10:40:00+03	2017-09-04 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27522	PG0389	2017-08-27 10:40:00+03	2017-08-27 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27523	PG0389	2017-07-29 10:40:00+03	2017-07-29 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-29 10:43:00+03	2017-07-29 11:13:00+03
27524	PG0389	2017-08-24 10:40:00+03	2017-08-24 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27525	PG0389	2017-07-17 10:40:00+03	2017-07-17 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-17 10:41:00+03	2017-07-17 11:11:00+03
27526	PG0389	2017-08-06 10:40:00+03	2017-08-06 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-06 10:42:00+03	2017-08-06 11:12:00+03
27527	PG0389	2017-08-16 10:40:00+03	2017-08-16 11:10:00+03	REN	UUA	On Time	CR2	\N	\N
27528	PG0389	2017-08-05 10:40:00+03	2017-08-05 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-05 10:44:00+03	2017-08-05 11:14:00+03
27529	PG0389	2017-08-28 10:40:00+03	2017-08-28 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27530	PG0389	2017-08-08 10:40:00+03	2017-08-08 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-08 10:44:00+03	2017-08-08 11:15:00+03
27531	PG0389	2017-09-06 10:40:00+03	2017-09-06 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27532	PG0389	2017-08-17 10:40:00+03	2017-08-17 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27533	PG0389	2017-09-10 10:40:00+03	2017-09-10 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27534	PG0389	2017-08-23 10:40:00+03	2017-08-23 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27535	PG0389	2017-08-15 10:40:00+03	2017-08-15 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-15 10:44:00+03	2017-08-15 11:14:00+03
27536	PG0389	2017-09-07 10:40:00+03	2017-09-07 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27537	PG0389	2017-08-09 10:40:00+03	2017-08-09 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-09 10:41:00+03	2017-08-09 11:11:00+03
27538	PG0389	2017-08-22 10:40:00+03	2017-08-22 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27539	PG0389	2017-07-16 10:40:00+03	2017-07-16 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-16 10:43:00+03	2017-07-16 11:13:00+03
27540	PG0389	2017-08-12 10:40:00+03	2017-08-12 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-12 10:45:00+03	2017-08-12 11:15:00+03
27541	PG0389	2017-09-11 10:40:00+03	2017-09-11 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27542	PG0389	2017-07-19 10:40:00+03	2017-07-19 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-19 10:43:00+03	2017-07-19 11:13:00+03
27543	PG0389	2017-08-13 10:40:00+03	2017-08-13 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-13 10:44:00+03	2017-08-13 11:14:00+03
27544	PG0389	2017-07-30 10:40:00+03	2017-07-30 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-30 10:41:00+03	2017-07-30 11:10:00+03
27545	PG0389	2017-07-31 10:40:00+03	2017-07-31 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-31 10:47:00+03	2017-07-31 11:17:00+03
27546	PG0389	2017-09-12 10:40:00+03	2017-09-12 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27547	PG0389	2017-09-14 10:40:00+03	2017-09-14 11:10:00+03	REN	UUA	Cancelled	CR2	\N	\N
27548	PG0389	2017-09-09 10:40:00+03	2017-09-09 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27549	PG0389	2017-08-11 10:40:00+03	2017-08-11 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-11 10:44:00+03	2017-08-11 11:14:00+03
27550	PG0389	2017-09-02 10:40:00+03	2017-09-02 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27551	PG0389	2017-08-25 10:40:00+03	2017-08-25 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27552	PG0389	2017-08-26 10:40:00+03	2017-08-26 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27553	PG0389	2017-07-18 10:40:00+03	2017-07-18 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-18 10:42:00+03	2017-07-18 11:12:00+03
27554	PG0389	2017-08-18 10:40:00+03	2017-08-18 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27555	PG0389	2017-08-03 10:40:00+03	2017-08-03 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-03 10:42:00+03	2017-08-03 11:12:00+03
27556	PG0389	2017-09-08 10:40:00+03	2017-09-08 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27557	PG0389	2017-08-31 10:40:00+03	2017-08-31 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27558	PG0389	2017-07-23 10:40:00+03	2017-07-23 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-23 10:45:00+03	2017-07-23 11:15:00+03
27559	PG0389	2017-08-14 10:40:00+03	2017-08-14 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-14 10:43:00+03	2017-08-14 11:13:00+03
27560	PG0389	2017-09-05 10:40:00+03	2017-09-05 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27561	PG0389	2017-08-10 10:40:00+03	2017-08-10 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-10 10:40:00+03	2017-08-10 11:10:00+03
27562	PG0389	2017-07-25 10:40:00+03	2017-07-25 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-25 10:45:00+03	2017-07-25 11:15:00+03
27563	PG0389	2017-07-22 10:40:00+03	2017-07-22 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-22 10:44:00+03	2017-07-22 11:14:00+03
27564	PG0389	2017-08-19 10:40:00+03	2017-08-19 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27565	PG0389	2017-07-27 10:40:00+03	2017-07-27 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-27 10:41:00+03	2017-07-27 11:11:00+03
27566	PG0389	2017-08-20 10:40:00+03	2017-08-20 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27567	PG0389	2017-07-24 10:40:00+03	2017-07-24 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-24 10:43:00+03	2017-07-24 11:13:00+03
27568	PG0389	2017-09-03 10:40:00+03	2017-09-03 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27569	PG0389	2017-08-02 10:40:00+03	2017-08-02 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-02 10:46:00+03	2017-08-02 11:16:00+03
27570	PG0389	2017-08-29 10:40:00+03	2017-08-29 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27571	PG0389	2017-08-04 10:40:00+03	2017-08-04 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-04 10:42:00+03	2017-08-04 11:12:00+03
27572	PG0389	2017-08-30 10:40:00+03	2017-08-30 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27573	PG0389	2017-07-28 10:40:00+03	2017-07-28 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-28 10:42:00+03	2017-07-28 11:13:00+03
27574	PG0389	2017-07-21 10:40:00+03	2017-07-21 11:10:00+03	REN	UUA	Arrived	CR2	2017-07-21 10:43:00+03	2017-07-21 11:13:00+03
27575	PG0389	2017-08-21 10:40:00+03	2017-08-21 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27576	PG0389	2017-08-07 10:40:00+03	2017-08-07 11:10:00+03	REN	UUA	Arrived	CR2	2017-08-07 10:46:00+03	2017-08-07 11:16:00+03
27577	PG0389	2017-09-13 10:40:00+03	2017-09-13 11:10:00+03	REN	UUA	Scheduled	CR2	\N	\N
27578	PG0483	2017-08-24 07:20:00+03	2017-08-24 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27579	PG0483	2017-09-07 07:20:00+03	2017-09-07 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27581	PG0483	2017-08-31 07:20:00+03	2017-08-31 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27582	PG0483	2017-08-12 07:20:00+03	2017-08-12 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-12 07:24:00+03	2017-08-12 11:20:00+03
27583	PG0483	2017-08-03 07:20:00+03	2017-08-03 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-03 07:22:00+03	2017-08-03 11:19:00+03
27584	PG0483	2017-07-25 07:20:00+03	2017-07-25 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-25 07:24:00+03	2017-07-25 11:20:00+03
27585	PG0483	2017-09-05 07:20:00+03	2017-09-05 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27586	PG0483	2017-08-08 07:20:00+03	2017-08-08 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-08 07:23:00+03	2017-08-08 11:22:00+03
27587	PG0483	2017-08-05 07:20:00+03	2017-08-05 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-05 07:22:00+03	2017-08-05 11:23:00+03
27588	PG0483	2017-08-01 07:20:00+03	2017-08-01 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-01 07:22:00+03	2017-08-01 11:22:00+03
27589	PG0483	2017-08-15 07:20:00+03	2017-08-15 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-15 07:23:00+03	2017-08-15 11:23:00+03
27590	PG0483	2017-07-29 07:20:00+03	2017-07-29 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-29 07:22:00+03	2017-07-29 11:20:00+03
27591	PG0483	2017-07-27 07:20:00+03	2017-07-27 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-27 07:21:00+03	2017-07-27 11:24:00+03
27592	PG0483	2017-09-14 07:20:00+03	2017-09-14 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27593	PG0483	2017-09-02 07:20:00+03	2017-09-02 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27594	PG0483	2017-08-26 07:20:00+03	2017-08-26 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27595	PG0483	2017-08-17 07:20:00+03	2017-08-17 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27596	PG0483	2017-07-18 07:20:00+03	2017-07-18 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-18 07:22:00+03	2017-07-18 11:20:00+03
27597	PG0483	2017-07-22 07:20:00+03	2017-07-22 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-22 07:23:00+03	2017-07-22 11:20:00+03
27598	PG0483	2017-08-19 07:20:00+03	2017-08-19 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27599	PG0483	2017-08-10 07:20:00+03	2017-08-10 11:20:00+03	KEJ	DME	Arrived	SU9	2017-08-10 07:24:00+03	2017-08-10 11:26:00+03
27600	PG0483	2017-08-22 07:20:00+03	2017-08-22 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27601	PG0483	2017-08-29 07:20:00+03	2017-08-29 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27602	PG0483	2017-09-09 07:20:00+03	2017-09-09 11:20:00+03	KEJ	DME	Scheduled	SU9	\N	\N
27603	PG0483	2017-07-20 07:20:00+03	2017-07-20 11:20:00+03	KEJ	DME	Arrived	SU9	2017-07-20 07:23:00+03	2017-07-20 11:24:00+03
27604	PG0348	2017-08-12 14:10:00+03	2017-08-12 18:10:00+03	KEJ	VKO	Arrived	319	2017-08-12 14:11:00+03	2017-08-12 18:09:00+03
27605	PG0348	2017-07-29 14:10:00+03	2017-07-29 18:10:00+03	KEJ	VKO	Arrived	319	2017-07-29 14:12:00+03	2017-07-29 18:16:00+03
27606	PG0348	2017-09-13 14:10:00+03	2017-09-13 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27607	PG0348	2017-08-19 14:10:00+03	2017-08-19 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27608	PG0348	2017-07-19 14:10:00+03	2017-07-19 18:10:00+03	KEJ	VKO	Arrived	319	2017-07-19 14:12:00+03	2017-07-19 18:13:00+03
27609	PG0348	2017-09-06 14:10:00+03	2017-09-06 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27610	PG0348	2017-09-09 14:10:00+03	2017-09-09 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27611	PG0348	2017-07-22 14:10:00+03	2017-07-22 18:10:00+03	KEJ	VKO	Arrived	319	2017-07-22 14:13:00+03	2017-07-22 18:12:00+03
27612	PG0348	2017-07-26 14:10:00+03	2017-07-26 18:10:00+03	KEJ	VKO	Arrived	319	2017-07-26 17:38:00+03	2017-07-26 21:37:00+03
27613	PG0348	2017-08-30 14:10:00+03	2017-08-30 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27614	PG0348	2017-09-02 14:10:00+03	2017-09-02 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27615	PG0348	2017-08-26 14:10:00+03	2017-08-26 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27616	PG0348	2017-08-16 14:10:00+03	2017-08-16 18:10:00+03	KEJ	VKO	On Time	319	\N	\N
27617	PG0348	2017-08-23 14:10:00+03	2017-08-23 18:10:00+03	KEJ	VKO	Scheduled	319	\N	\N
27618	PG0348	2017-08-09 14:10:00+03	2017-08-09 18:10:00+03	KEJ	VKO	Arrived	319	2017-08-09 14:13:00+03	2017-08-09 18:14:00+03
27619	PG0348	2017-08-05 14:10:00+03	2017-08-05 18:10:00+03	KEJ	VKO	Arrived	319	2017-08-05 14:12:00+03	2017-08-05 18:10:00+03
27620	PG0348	2017-08-02 14:10:00+03	2017-08-02 18:10:00+03	KEJ	VKO	Arrived	319	2017-08-02 14:11:00+03	2017-08-02 18:11:00+03
27621	PG0664	2017-08-19 07:40:00+03	2017-08-19 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27622	PG0664	2017-07-18 07:40:00+03	2017-07-18 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-07-18 07:42:00+03	2017-07-18 11:39:00+03
27623	PG0664	2017-08-08 07:40:00+03	2017-08-08 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-08-08 07:41:00+03	2017-08-08 11:42:00+03
27624	PG0664	2017-08-01 07:40:00+03	2017-08-01 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-08-01 07:42:00+03	2017-08-01 11:37:00+03
27625	PG0664	2017-07-25 07:40:00+03	2017-07-25 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-07-25 07:41:00+03	2017-07-25 11:40:00+03
27626	PG0664	2017-09-09 07:40:00+03	2017-09-09 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27627	PG0664	2017-09-02 07:40:00+03	2017-09-02 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27628	PG0664	2017-08-26 07:40:00+03	2017-08-26 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27629	PG0664	2017-07-22 07:40:00+03	2017-07-22 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-07-22 07:43:00+03	2017-07-22 11:38:00+03
27630	PG0664	2017-08-15 07:40:00+03	2017-08-15 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-08-15 07:45:00+03	2017-08-15 11:44:00+03
27631	PG0664	2017-09-05 07:40:00+03	2017-09-05 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27632	PG0664	2017-08-22 07:40:00+03	2017-08-22 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27633	PG0664	2017-08-05 07:40:00+03	2017-08-05 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-08-05 07:42:00+03	2017-08-05 11:43:00+03
27634	PG0664	2017-09-12 07:40:00+03	2017-09-12 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27635	PG0664	2017-07-29 07:40:00+03	2017-07-29 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-07-29 07:43:00+03	2017-07-29 11:43:00+03
27636	PG0664	2017-08-29 07:40:00+03	2017-08-29 11:40:00+03	KEJ	SVO	Scheduled	SU9	\N	\N
27637	PG0664	2017-08-12 07:40:00+03	2017-08-12 11:40:00+03	KEJ	SVO	Arrived	SU9	2017-08-12 07:47:00+03	2017-08-12 11:47:00+03
27638	PG0082	2017-07-16 11:00:00+03	2017-07-16 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-07-16 11:03:00+03	2017-07-16 13:16:00+03
27639	PG0082	2017-07-30 11:00:00+03	2017-07-30 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-07-30 11:02:00+03	2017-07-30 13:18:00+03
27640	PG0082	2017-07-23 11:00:00+03	2017-07-23 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-07-23 11:01:00+03	2017-07-23 13:19:00+03
27641	PG0082	2017-08-16 11:00:00+03	2017-08-16 13:15:00+03	KEJ	KYZ	On Time	CN1	\N	\N
27642	PG0082	2017-07-26 11:00:00+03	2017-07-26 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-07-26 11:03:00+03	2017-07-26 13:16:00+03
27643	PG0082	2017-08-09 11:00:00+03	2017-08-09 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-08-09 11:06:00+03	2017-08-09 13:22:00+03
27644	PG0082	2017-07-19 11:00:00+03	2017-07-19 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-07-19 11:04:00+03	2017-07-19 13:20:00+03
27645	PG0082	2017-09-10 11:00:00+03	2017-09-10 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27646	PG0082	2017-09-03 11:00:00+03	2017-09-03 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27647	PG0082	2017-09-06 11:00:00+03	2017-09-06 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27648	PG0082	2017-08-20 11:00:00+03	2017-08-20 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27649	PG0082	2017-08-06 11:00:00+03	2017-08-06 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-08-06 11:07:00+03	2017-08-06 13:21:00+03
27650	PG0082	2017-09-13 11:00:00+03	2017-09-13 13:15:00+03	KEJ	KYZ	Cancelled	CN1	\N	\N
27651	PG0082	2017-08-23 11:00:00+03	2017-08-23 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27652	PG0082	2017-08-30 11:00:00+03	2017-08-30 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27653	PG0082	2017-08-27 11:00:00+03	2017-08-27 13:15:00+03	KEJ	KYZ	Scheduled	CN1	\N	\N
27654	PG0082	2017-08-02 11:00:00+03	2017-08-02 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-08-02 11:02:00+03	2017-08-02 13:16:00+03
27655	PG0082	2017-08-13 11:00:00+03	2017-08-13 13:15:00+03	KEJ	KYZ	Arrived	CN1	2017-08-13 11:03:00+03	2017-08-13 13:19:00+03
27656	PG0552	2017-07-24 08:25:00+03	2017-07-24 11:05:00+03	KEJ	PYJ	Arrived	CR2	2017-07-24 08:27:00+03	2017-07-24 11:07:00+03
27657	PG0552	2017-09-04 08:25:00+03	2017-09-04 11:05:00+03	KEJ	PYJ	Scheduled	CR2	\N	\N
27658	PG0552	2017-07-17 08:25:00+03	2017-07-17 11:05:00+03	KEJ	PYJ	Arrived	CR2	2017-07-17 08:25:00+03	2017-07-17 11:07:00+03
27659	PG0552	2017-08-28 08:25:00+03	2017-08-28 11:05:00+03	KEJ	PYJ	Scheduled	CR2	\N	\N
27660	PG0552	2017-08-14 08:25:00+03	2017-08-14 11:05:00+03	KEJ	PYJ	Arrived	CR2	2017-08-14 08:27:00+03	2017-08-14 11:10:00+03
27661	PG0552	2017-09-11 08:25:00+03	2017-09-11 11:05:00+03	KEJ	PYJ	Cancelled	CR2	\N	\N
27662	PG0552	2017-07-31 08:25:00+03	2017-07-31 11:05:00+03	KEJ	PYJ	Arrived	CR2	2017-07-31 08:27:00+03	2017-07-31 11:08:00+03
27663	PG0552	2017-08-21 08:25:00+03	2017-08-21 11:05:00+03	KEJ	PYJ	Scheduled	CR2	\N	\N
27664	PG0552	2017-08-07 08:25:00+03	2017-08-07 11:05:00+03	KEJ	PYJ	Arrived	CR2	2017-08-07 08:31:00+03	2017-08-07 11:08:00+03
27665	PG0298	2017-09-05 14:30:00+03	2017-09-05 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27666	PG0298	2017-09-08 14:30:00+03	2017-09-08 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27667	PG0297	2017-09-08 08:05:00+03	2017-09-08 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27668	PG0298	2017-08-26 14:30:00+03	2017-08-26 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27669	PG0298	2017-08-13 14:30:00+03	2017-08-13 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-13 14:38:00+03	2017-08-13 15:03:00+03
27670	PG0297	2017-08-28 08:05:00+03	2017-08-28 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27671	PG0298	2017-08-28 14:30:00+03	2017-08-28 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27672	PG0298	2017-08-31 14:30:00+03	2017-08-31 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27673	PG0297	2017-08-31 08:05:00+03	2017-08-31 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27674	PG0297	2017-09-11 08:05:00+03	2017-09-11 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27675	PG0298	2017-09-11 14:30:00+03	2017-09-11 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27676	PG0298	2017-07-29 14:30:00+03	2017-07-29 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-29 14:33:00+03	2017-07-29 14:58:00+03
27677	PG0297	2017-07-29 08:05:00+03	2017-07-29 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-29 08:08:00+03	2017-07-29 08:33:00+03
27678	PG0297	2017-09-14 08:05:00+03	2017-09-14 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27679	PG0298	2017-09-14 14:30:00+03	2017-09-14 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27680	PG0297	2017-08-21 08:05:00+03	2017-08-21 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27681	PG0298	2017-08-23 14:30:00+03	2017-08-23 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27682	PG0297	2017-08-23 08:05:00+03	2017-08-23 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27683	PG0298	2017-09-06 14:30:00+03	2017-09-06 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27684	PG0297	2017-09-06 08:05:00+03	2017-09-06 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27685	PG0298	2017-08-10 14:30:00+03	2017-08-10 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-10 14:31:00+03	2017-08-10 14:56:00+03
27686	PG0297	2017-08-10 08:05:00+03	2017-08-10 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-10 08:08:00+03	2017-08-10 08:33:00+03
27687	PG0297	2017-08-11 08:05:00+03	2017-08-11 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-11 08:11:00+03	2017-08-11 08:37:00+03
27688	PG0298	2017-08-11 14:30:00+03	2017-08-11 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-11 14:34:00+03	2017-08-11 14:59:00+03
27689	PG0297	2017-07-20 08:05:00+03	2017-07-20 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-20 08:08:00+03	2017-07-20 08:33:00+03
27690	PG0297	2017-09-10 08:05:00+03	2017-09-10 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27691	PG0298	2017-09-10 14:30:00+03	2017-09-10 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27692	PG0297	2017-07-16 08:05:00+03	2017-07-16 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-16 08:06:00+03	2017-07-16 08:31:00+03
27693	PG0298	2017-07-16 14:30:00+03	2017-07-16 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-16 14:32:00+03	2017-07-16 14:57:00+03
27694	PG0298	2017-09-01 14:30:00+03	2017-09-01 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27695	PG0297	2017-09-01 08:05:00+03	2017-09-01 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27696	PG0298	2017-08-21 14:30:00+03	2017-08-21 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27697	PG0298	2017-07-20 14:30:00+03	2017-07-20 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-20 14:30:00+03	2017-07-20 14:55:00+03
27698	PG0297	2017-08-27 08:05:00+03	2017-08-27 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27699	PG0298	2017-08-29 14:30:00+03	2017-08-29 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27700	PG0297	2017-08-29 08:05:00+03	2017-08-29 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27701	PG0297	2017-09-04 08:05:00+03	2017-09-04 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27702	PG0298	2017-09-04 14:30:00+03	2017-09-04 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27703	PG0298	2017-09-09 14:30:00+03	2017-09-09 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27704	PG0297	2017-09-09 08:05:00+03	2017-09-09 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27705	PG0297	2017-08-17 08:05:00+03	2017-08-17 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27706	PG0298	2017-08-17 14:30:00+03	2017-08-17 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27707	PG0298	2017-07-31 14:30:00+03	2017-07-31 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-31 14:30:00+03	2017-07-31 14:55:00+03
27708	PG0297	2017-07-31 08:05:00+03	2017-07-31 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-31 08:06:00+03	2017-07-31 08:31:00+03
27709	PG0297	2017-08-30 08:05:00+03	2017-08-30 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27710	PG0298	2017-08-30 14:30:00+03	2017-08-30 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27711	PG0298	2017-08-15 14:30:00+03	2017-08-15 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-15 14:33:00+03	2017-08-15 14:58:00+03
27712	PG0297	2017-08-15 08:05:00+03	2017-08-15 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-15 08:08:00+03	2017-08-15 08:34:00+03
27713	PG0298	2017-08-01 14:30:00+03	2017-08-01 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-01 14:33:00+03	2017-08-01 14:58:00+03
27714	PG0298	2017-09-12 14:30:00+03	2017-09-12 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27715	PG0297	2017-09-12 08:05:00+03	2017-09-12 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27716	PG0297	2017-08-01 08:05:00+03	2017-08-01 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-01 08:07:00+03	2017-08-01 08:32:00+03
27717	PG0298	2017-08-27 14:30:00+03	2017-08-27 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27718	PG0297	2017-09-13 08:05:00+03	2017-09-13 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27719	PG0298	2017-09-13 14:30:00+03	2017-09-13 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27720	PG0297	2017-07-27 08:05:00+03	2017-07-27 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-27 08:06:00+03	2017-07-27 08:31:00+03
27721	PG0298	2017-07-27 14:30:00+03	2017-07-27 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-27 14:32:00+03	2017-07-27 14:57:00+03
27722	PG0298	2017-08-05 14:30:00+03	2017-08-05 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-05 14:33:00+03	2017-08-05 14:58:00+03
27723	PG0297	2017-08-05 08:05:00+03	2017-08-05 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-05 08:07:00+03	2017-08-05 08:32:00+03
27724	PG0297	2017-08-02 08:05:00+03	2017-08-02 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-02 08:09:00+03	2017-08-02 08:34:00+03
27725	PG0298	2017-08-02 14:30:00+03	2017-08-02 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-02 14:34:00+03	2017-08-02 14:59:00+03
27726	PG0298	2017-07-19 14:30:00+03	2017-07-19 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-19 14:31:00+03	2017-07-19 14:56:00+03
27727	PG0297	2017-07-19 08:05:00+03	2017-07-19 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-19 08:10:00+03	2017-07-19 08:35:00+03
27728	PG0297	2017-08-07 08:05:00+03	2017-08-07 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-07 08:07:00+03	2017-08-07 08:32:00+03
27729	PG0298	2017-08-07 14:30:00+03	2017-08-07 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-07 14:32:00+03	2017-08-07 14:56:00+03
27730	PG0298	2017-08-24 14:30:00+03	2017-08-24 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27731	PG0297	2017-08-24 08:05:00+03	2017-08-24 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27732	PG0297	2017-07-21 08:05:00+03	2017-07-21 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-21 08:08:00+03	2017-07-21 08:33:00+03
27733	PG0298	2017-07-21 14:30:00+03	2017-07-21 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-21 14:32:00+03	2017-07-21 14:57:00+03
27734	PG0297	2017-08-16 08:05:00+03	2017-08-16 08:30:00+03	NOZ	OVB	On Time	SU9	\N	\N
27735	PG0297	2017-08-06 08:05:00+03	2017-08-06 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-06 08:08:00+03	2017-08-06 08:33:00+03
27736	PG0298	2017-07-24 14:30:00+03	2017-07-24 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-24 14:31:00+03	2017-07-24 14:56:00+03
27737	PG0298	2017-08-20 14:30:00+03	2017-08-20 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27738	PG0297	2017-07-24 08:05:00+03	2017-07-24 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-24 08:06:00+03	2017-07-24 08:31:00+03
27739	PG0297	2017-08-20 08:05:00+03	2017-08-20 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27740	PG0297	2017-09-07 08:05:00+03	2017-09-07 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27741	PG0297	2017-07-26 08:05:00+03	2017-07-26 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-26 08:06:00+03	2017-07-26 08:31:00+03
27742	PG0298	2017-09-07 14:30:00+03	2017-09-07 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27743	PG0297	2017-08-12 08:05:00+03	2017-08-12 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-12 08:06:00+03	2017-08-12 08:31:00+03
27744	PG0297	2017-08-22 08:05:00+03	2017-08-22 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27745	PG0298	2017-08-22 14:30:00+03	2017-08-22 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27746	PG0298	2017-08-12 14:30:00+03	2017-08-12 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-12 14:33:00+03	2017-08-12 14:57:00+03
27747	PG0297	2017-09-02 08:05:00+03	2017-09-02 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27748	PG0298	2017-09-02 14:30:00+03	2017-09-02 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27749	PG0298	2017-09-03 14:30:00+03	2017-09-03 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27750	PG0297	2017-09-03 08:05:00+03	2017-09-03 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27751	PG0298	2017-07-30 14:30:00+03	2017-07-30 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-30 14:31:00+03	2017-07-30 14:56:00+03
27752	PG0297	2017-07-30 08:05:00+03	2017-07-30 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-30 08:07:00+03	2017-07-30 08:32:00+03
27753	PG0298	2017-08-09 14:30:00+03	2017-08-09 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-09 14:32:00+03	2017-08-09 14:57:00+03
27754	PG0297	2017-08-09 08:05:00+03	2017-08-09 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-09 08:08:00+03	2017-08-09 08:33:00+03
27755	PG0297	2017-08-18 08:05:00+03	2017-08-18 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27756	PG0298	2017-08-18 14:30:00+03	2017-08-18 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27757	PG0297	2017-08-25 08:05:00+03	2017-08-25 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27758	PG0298	2017-08-16 14:30:00+03	2017-08-16 14:55:00+03	NOZ	OVB	On Time	SU9	\N	\N
27759	PG0297	2017-08-26 08:05:00+03	2017-08-26 08:30:00+03	NOZ	OVB	Cancelled	SU9	\N	\N
27760	PG0297	2017-07-17 08:05:00+03	2017-07-17 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-17 08:07:00+03	2017-07-17 08:32:00+03
27761	PG0298	2017-07-26 14:30:00+03	2017-07-26 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-26 14:31:00+03	2017-07-26 14:56:00+03
27762	PG0298	2017-07-17 14:30:00+03	2017-07-17 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-17 14:32:00+03	2017-07-17 14:57:00+03
27763	PG0298	2017-08-14 14:30:00+03	2017-08-14 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-14 14:34:00+03	2017-08-14 14:59:00+03
27764	PG0297	2017-08-14 08:05:00+03	2017-08-14 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-14 08:10:00+03	2017-08-14 08:35:00+03
27765	PG0298	2017-07-25 14:30:00+03	2017-07-25 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-25 14:32:00+03	2017-07-25 14:56:00+03
27766	PG0297	2017-07-25 08:05:00+03	2017-07-25 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-25 08:08:00+03	2017-07-25 08:33:00+03
27767	PG0297	2017-07-28 08:05:00+03	2017-07-28 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-28 08:09:00+03	2017-07-28 08:34:00+03
27768	PG0298	2017-07-28 14:30:00+03	2017-07-28 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-28 14:33:00+03	2017-07-28 14:58:00+03
27769	PG0298	2017-08-06 14:30:00+03	2017-08-06 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-06 14:33:00+03	2017-08-06 14:58:00+03
27770	PG0297	2017-07-22 08:05:00+03	2017-07-22 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-22 08:10:00+03	2017-07-22 08:35:00+03
27771	PG0298	2017-07-22 14:30:00+03	2017-07-22 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-22 14:34:00+03	2017-07-22 14:59:00+03
27772	PG0297	2017-08-03 08:05:00+03	2017-08-03 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-03 08:12:00+03	2017-08-03 08:37:00+03
27773	PG0298	2017-08-03 14:30:00+03	2017-08-03 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-03 14:35:00+03	2017-08-03 14:59:00+03
27774	PG0298	2017-07-18 14:30:00+03	2017-07-18 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-18 14:35:00+03	2017-07-18 15:00:00+03
27775	PG0297	2017-07-18 08:05:00+03	2017-07-18 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-18 08:05:00+03	2017-07-18 08:30:00+03
27776	PG0298	2017-08-25 14:30:00+03	2017-08-25 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27777	PG0298	2017-08-04 14:30:00+03	2017-08-04 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-04 14:31:00+03	2017-08-04 14:56:00+03
27778	PG0297	2017-08-04 08:05:00+03	2017-08-04 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-04 08:06:00+03	2017-08-04 08:31:00+03
27779	PG0298	2017-07-23 14:30:00+03	2017-07-23 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-07-23 14:32:00+03	2017-07-23 14:57:00+03
27780	PG0297	2017-07-23 08:05:00+03	2017-07-23 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-07-23 08:11:00+03	2017-07-23 08:36:00+03
27781	PG0298	2017-08-19 14:30:00+03	2017-08-19 14:55:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27782	PG0297	2017-08-08 08:05:00+03	2017-08-08 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-08 08:07:00+03	2017-08-08 08:32:00+03
27783	PG0298	2017-08-08 14:30:00+03	2017-08-08 14:55:00+03	NOZ	OVB	Arrived	SU9	2017-08-08 14:33:00+03	2017-08-08 14:58:00+03
27784	PG0297	2017-08-19 08:05:00+03	2017-08-19 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27785	PG0297	2017-08-13 08:05:00+03	2017-08-13 08:30:00+03	NOZ	OVB	Arrived	SU9	2017-08-13 08:09:00+03	2017-08-13 08:34:00+03
27786	PG0297	2017-09-05 08:05:00+03	2017-09-05 08:30:00+03	NOZ	OVB	Scheduled	SU9	\N	\N
27787	PG0354	2017-09-03 08:45:00+03	2017-09-03 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27788	PG0353	2017-08-21 11:05:00+03	2017-08-21 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27789	PG0354	2017-08-21 08:45:00+03	2017-08-21 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27790	PG0353	2017-07-26 11:05:00+03	2017-07-26 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-26 11:09:00+03	2017-07-26 12:34:00+03
27791	PG0353	2017-08-16 11:05:00+03	2017-08-16 12:30:00+03	NOZ	KJA	On Time	CN1	\N	\N
27792	PG0354	2017-08-16 08:45:00+03	2017-08-16 10:10:00+03	NOZ	KJA	On Time	CN1	\N	\N
27793	PG0354	2017-07-26 08:45:00+03	2017-07-26 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-26 08:48:00+03	2017-07-26 10:14:00+03
27794	PG0354	2017-08-29 08:45:00+03	2017-08-29 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27795	PG0353	2017-08-29 11:05:00+03	2017-08-29 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27796	PG0353	2017-07-16 11:05:00+03	2017-07-16 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-16 11:11:00+03	2017-07-16 12:36:00+03
27797	PG0354	2017-07-16 08:45:00+03	2017-07-16 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-16 08:48:00+03	2017-07-16 10:13:00+03
27798	PG0354	2017-09-14 08:45:00+03	2017-09-14 10:10:00+03	NOZ	KJA	Cancelled	CN1	\N	\N
27799	PG0354	2017-09-09 08:45:00+03	2017-09-09 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27800	PG0353	2017-09-09 11:05:00+03	2017-09-09 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27801	PG0353	2017-09-10 11:05:00+03	2017-09-10 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27802	PG0354	2017-09-10 08:45:00+03	2017-09-10 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27803	PG0354	2017-08-15 08:45:00+03	2017-08-15 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-15 08:49:00+03	2017-08-15 10:15:00+03
27804	PG0353	2017-08-15 11:05:00+03	2017-08-15 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-15 11:06:00+03	2017-08-15 12:30:00+03
27805	PG0353	2017-08-17 11:05:00+03	2017-08-17 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27806	PG0354	2017-08-17 08:45:00+03	2017-08-17 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27807	PG0353	2017-09-04 11:05:00+03	2017-09-04 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27808	PG0354	2017-09-04 08:45:00+03	2017-09-04 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27809	PG0353	2017-08-30 11:05:00+03	2017-08-30 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27810	PG0354	2017-08-30 08:45:00+03	2017-08-30 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27811	PG0354	2017-08-05 08:45:00+03	2017-08-05 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-05 08:47:00+03	2017-08-05 10:10:00+03
27812	PG0353	2017-08-05 11:05:00+03	2017-08-05 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-05 11:07:00+03	2017-08-05 12:32:00+03
27813	PG0354	2017-08-24 08:45:00+03	2017-08-24 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27814	PG0353	2017-08-24 11:05:00+03	2017-08-24 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27815	PG0354	2017-07-25 08:45:00+03	2017-07-25 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-25 08:45:00+03	2017-07-25 10:10:00+03
27816	PG0353	2017-07-27 11:05:00+03	2017-07-27 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-27 11:10:00+03	2017-07-27 12:35:00+03
27817	PG0354	2017-07-27 08:45:00+03	2017-07-27 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-27 08:49:00+03	2017-07-27 10:13:00+03
27818	PG0353	2017-08-07 11:05:00+03	2017-08-07 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-07 11:13:00+03	2017-08-07 12:38:00+03
27819	PG0354	2017-08-07 08:45:00+03	2017-08-07 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-07 08:51:00+03	2017-08-07 10:17:00+03
27820	PG0354	2017-07-24 08:45:00+03	2017-07-24 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-24 08:46:00+03	2017-07-24 10:12:00+03
27821	PG0353	2017-07-24 11:05:00+03	2017-07-24 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-24 11:06:00+03	2017-07-24 12:31:00+03
27822	PG0353	2017-08-01 11:05:00+03	2017-08-01 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-01 11:11:00+03	2017-08-01 12:35:00+03
27823	PG0353	2017-09-03 11:05:00+03	2017-09-03 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27824	PG0353	2017-08-18 11:05:00+03	2017-08-18 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27825	PG0354	2017-08-14 08:45:00+03	2017-08-14 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-14 08:47:00+03	2017-08-14 10:13:00+03
27826	PG0354	2017-08-25 08:45:00+03	2017-08-25 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27827	PG0354	2017-08-18 08:45:00+03	2017-08-18 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27828	PG0353	2017-08-14 11:05:00+03	2017-08-14 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-14 11:08:00+03	2017-08-14 12:34:00+03
27829	PG0353	2017-07-17 11:05:00+03	2017-07-17 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-17 11:08:00+03	2017-07-17 12:34:00+03
27830	PG0354	2017-07-17 08:45:00+03	2017-07-17 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-17 08:47:00+03	2017-07-17 10:13:00+03
27831	PG0353	2017-07-28 11:05:00+03	2017-07-28 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-28 11:06:00+03	2017-07-28 12:32:00+03
27832	PG0354	2017-07-28 08:45:00+03	2017-07-28 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-28 08:47:00+03	2017-07-28 10:13:00+03
27833	PG0354	2017-08-04 08:45:00+03	2017-08-04 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-04 08:48:00+03	2017-08-04 10:13:00+03
27834	PG0353	2017-08-04 11:05:00+03	2017-08-04 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-04 11:08:00+03	2017-08-04 12:34:00+03
27835	PG0353	2017-08-25 11:05:00+03	2017-08-25 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27836	PG0354	2017-07-23 08:45:00+03	2017-07-23 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-23 08:49:00+03	2017-07-23 10:13:00+03
27837	PG0353	2017-07-23 11:05:00+03	2017-07-23 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-23 11:10:00+03	2017-07-23 12:36:00+03
27838	PG0354	2017-09-08 08:45:00+03	2017-09-08 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27839	PG0353	2017-09-08 11:05:00+03	2017-09-08 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27840	PG0353	2017-08-08 11:05:00+03	2017-08-08 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-08 11:07:00+03	2017-08-08 12:30:00+03
27841	PG0354	2017-08-08 08:45:00+03	2017-08-08 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-08 08:46:00+03	2017-08-08 10:10:00+03
27842	PG0354	2017-08-23 08:45:00+03	2017-08-23 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27843	PG0353	2017-08-23 11:05:00+03	2017-08-23 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27844	PG0353	2017-09-14 11:05:00+03	2017-09-14 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27845	PG0353	2017-09-11 11:05:00+03	2017-09-11 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27846	PG0354	2017-09-11 08:45:00+03	2017-09-11 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27847	PG0353	2017-07-25 11:05:00+03	2017-07-25 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-25 11:05:00+03	2017-07-25 12:27:00+03
27848	PG0354	2017-08-28 08:45:00+03	2017-08-28 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27849	PG0353	2017-08-28 11:05:00+03	2017-08-28 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27850	PG0353	2017-07-29 11:05:00+03	2017-07-29 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-29 11:10:00+03	2017-07-29 12:34:00+03
27851	PG0354	2017-07-29 08:45:00+03	2017-07-29 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-29 08:48:00+03	2017-07-29 10:15:00+03
27852	PG0354	2017-08-13 08:45:00+03	2017-08-13 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-13 08:46:00+03	2017-08-13 10:10:00+03
27853	PG0353	2017-08-13 11:05:00+03	2017-08-13 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-13 11:11:00+03	2017-08-13 12:37:00+03
27854	PG0353	2017-08-31 11:05:00+03	2017-08-31 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27855	PG0354	2017-08-31 08:45:00+03	2017-08-31 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27856	PG0353	2017-09-05 11:05:00+03	2017-09-05 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27857	PG0354	2017-09-05 08:45:00+03	2017-09-05 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27858	PG0353	2017-08-19 11:05:00+03	2017-08-19 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27859	PG0354	2017-08-19 08:45:00+03	2017-08-19 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27860	PG0354	2017-08-03 08:45:00+03	2017-08-03 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-03 08:48:00+03	2017-08-03 10:12:00+03
27861	PG0353	2017-08-03 11:05:00+03	2017-08-03 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-03 11:08:00+03	2017-08-03 12:34:00+03
27862	PG0353	2017-08-26 11:05:00+03	2017-08-26 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27863	PG0354	2017-08-26 08:45:00+03	2017-08-26 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27864	PG0354	2017-07-22 08:45:00+03	2017-07-22 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-22 08:46:00+03	2017-07-22 10:11:00+03
27865	PG0353	2017-07-18 11:05:00+03	2017-07-18 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-18 11:07:00+03	2017-07-18 12:32:00+03
27866	PG0354	2017-07-18 08:45:00+03	2017-07-18 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-18 08:47:00+03	2017-07-18 10:11:00+03
27867	PG0353	2017-07-22 11:05:00+03	2017-07-22 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-22 11:11:00+03	2017-07-22 12:36:00+03
27868	PG0353	2017-08-09 11:05:00+03	2017-08-09 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-09 11:10:00+03	2017-08-09 12:34:00+03
27869	PG0354	2017-08-09 08:45:00+03	2017-08-09 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-09 08:49:00+03	2017-08-09 10:13:00+03
27870	PG0353	2017-07-30 11:05:00+03	2017-07-30 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-30 11:08:00+03	2017-07-30 12:32:00+03
27871	PG0354	2017-07-30 08:45:00+03	2017-07-30 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-30 08:47:00+03	2017-07-30 10:11:00+03
27872	PG0354	2017-09-02 08:45:00+03	2017-09-02 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27873	PG0353	2017-09-02 11:05:00+03	2017-09-02 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27874	PG0354	2017-08-22 08:45:00+03	2017-08-22 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27875	PG0354	2017-08-12 08:45:00+03	2017-08-12 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-12 08:46:00+03	2017-08-12 10:10:00+03
27876	PG0353	2017-08-12 11:05:00+03	2017-08-12 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-12 11:08:00+03	2017-08-12 12:33:00+03
27877	PG0353	2017-08-22 11:05:00+03	2017-08-22 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27878	PG0354	2017-09-07 08:45:00+03	2017-09-07 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27879	PG0353	2017-09-07 11:05:00+03	2017-09-07 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27880	PG0354	2017-07-21 08:45:00+03	2017-07-21 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-21 08:48:00+03	2017-07-21 10:15:00+03
27881	PG0353	2017-07-21 11:05:00+03	2017-07-21 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-21 11:08:00+03	2017-07-21 12:33:00+03
27882	PG0353	2017-08-20 11:05:00+03	2017-08-20 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27883	PG0354	2017-08-20 08:45:00+03	2017-08-20 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27884	PG0354	2017-09-13 08:45:00+03	2017-09-13 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27885	PG0353	2017-09-13 11:05:00+03	2017-09-13 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27886	PG0354	2017-08-02 08:45:00+03	2017-08-02 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-02 08:48:00+03	2017-08-02 10:14:00+03
27887	PG0353	2017-08-02 11:05:00+03	2017-08-02 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-02 11:07:00+03	2017-08-02 12:32:00+03
27888	PG0353	2017-08-06 11:05:00+03	2017-08-06 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-06 11:07:00+03	2017-08-06 12:33:00+03
27889	PG0353	2017-07-19 11:05:00+03	2017-07-19 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-19 11:12:00+03	2017-07-19 12:36:00+03
27890	PG0354	2017-07-19 08:45:00+03	2017-07-19 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-19 08:47:00+03	2017-07-19 10:11:00+03
27891	PG0353	2017-09-12 11:05:00+03	2017-09-12 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27892	PG0354	2017-09-12 08:45:00+03	2017-09-12 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27893	PG0354	2017-08-06 08:45:00+03	2017-08-06 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-06 08:46:00+03	2017-08-06 10:11:00+03
27894	PG0353	2017-07-31 11:05:00+03	2017-07-31 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-31 11:10:00+03	2017-07-31 12:35:00+03
27895	PG0354	2017-07-31 08:45:00+03	2017-07-31 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-31 08:49:00+03	2017-07-31 10:15:00+03
27896	PG0354	2017-08-11 08:45:00+03	2017-08-11 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-11 08:49:00+03	2017-08-11 10:14:00+03
27897	PG0353	2017-08-11 11:05:00+03	2017-08-11 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-11 11:11:00+03	2017-08-11 12:38:00+03
27898	PG0353	2017-09-01 11:05:00+03	2017-09-01 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27899	PG0354	2017-09-01 08:45:00+03	2017-09-01 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27900	PG0353	2017-08-10 11:05:00+03	2017-08-10 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-08-10 11:08:00+03	2017-08-10 12:32:00+03
27901	PG0354	2017-08-27 08:45:00+03	2017-08-27 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27902	PG0353	2017-08-27 11:05:00+03	2017-08-27 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27903	PG0354	2017-08-10 08:45:00+03	2017-08-10 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-10 08:48:00+03	2017-08-10 10:13:00+03
27904	PG0353	2017-09-06 11:05:00+03	2017-09-06 12:30:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27905	PG0354	2017-09-06 08:45:00+03	2017-09-06 10:10:00+03	NOZ	KJA	Scheduled	CN1	\N	\N
27906	PG0354	2017-07-20 08:45:00+03	2017-07-20 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-07-20 08:49:00+03	2017-07-20 10:15:00+03
27907	PG0353	2017-07-20 11:05:00+03	2017-07-20 12:30:00+03	NOZ	KJA	Arrived	CN1	2017-07-20 11:10:00+03	2017-07-20 12:37:00+03
27908	PG0354	2017-08-01 08:45:00+03	2017-08-01 10:10:00+03	NOZ	KJA	Arrived	CN1	2017-08-01 08:49:00+03	2017-08-01 10:15:00+03
27909	PG0195	2017-08-07 11:15:00+03	2017-08-07 16:20:00+03	NOZ	AAQ	Arrived	733	2017-08-07 11:19:00+03	2017-08-07 16:20:00+03
27910	PG0195	2017-07-31 11:15:00+03	2017-07-31 16:20:00+03	NOZ	AAQ	Arrived	733	2017-07-31 11:15:00+03	2017-07-31 16:18:00+03
27911	PG0195	2017-08-14 11:15:00+03	2017-08-14 16:20:00+03	NOZ	AAQ	Arrived	733	2017-08-14 11:23:00+03	2017-08-14 16:32:00+03
27912	PG0195	2017-09-04 11:15:00+03	2017-09-04 16:20:00+03	NOZ	AAQ	Scheduled	733	\N	\N
27913	PG0195	2017-07-24 11:15:00+03	2017-07-24 16:20:00+03	NOZ	AAQ	Arrived	733	2017-07-24 14:16:00+03	2017-07-24 19:27:00+03
27914	PG0195	2017-08-28 11:15:00+03	2017-08-28 16:20:00+03	NOZ	AAQ	Scheduled	733	\N	\N
27915	PG0195	2017-08-21 11:15:00+03	2017-08-21 16:20:00+03	NOZ	AAQ	Scheduled	733	\N	\N
27916	PG0195	2017-07-17 11:15:00+03	2017-07-17 16:20:00+03	NOZ	AAQ	Arrived	733	2017-07-17 11:15:00+03	2017-07-17 16:18:00+03
27917	PG0195	2017-09-11 11:15:00+03	2017-09-11 16:20:00+03	NOZ	AAQ	Scheduled	733	\N	\N
27918	PG0682	2017-09-13 14:55:00+03	2017-09-13 17:05:00+03	NOZ	NYM	Cancelled	CR2	\N	\N
27919	PG0682	2017-08-23 14:55:00+03	2017-08-23 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27920	PG0682	2017-08-02 14:55:00+03	2017-08-02 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-08-02 14:55:00+03	2017-08-02 17:05:00+03
27921	PG0682	2017-08-26 14:55:00+03	2017-08-26 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27922	PG0682	2017-07-29 14:55:00+03	2017-07-29 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-07-29 14:58:00+03	2017-07-29 17:08:00+03
27923	PG0682	2017-07-22 14:55:00+03	2017-07-22 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-07-22 14:56:00+03	2017-07-22 17:07:00+03
27924	PG0682	2017-08-16 14:55:00+03	2017-08-16 17:05:00+03	NOZ	NYM	On Time	CR2	\N	\N
27925	PG0682	2017-09-06 14:55:00+03	2017-09-06 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27926	PG0682	2017-08-19 14:55:00+03	2017-08-19 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27927	PG0682	2017-09-02 14:55:00+03	2017-09-02 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27928	PG0682	2017-07-19 14:55:00+03	2017-07-19 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-07-19 14:58:00+03	2017-07-19 17:09:00+03
27929	PG0682	2017-08-09 14:55:00+03	2017-08-09 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-08-09 15:00:00+03	2017-08-09 17:10:00+03
27930	PG0682	2017-08-12 14:55:00+03	2017-08-12 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-08-12 14:57:00+03	2017-08-12 17:09:00+03
27931	PG0682	2017-08-30 14:55:00+03	2017-08-30 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27932	PG0682	2017-07-26 14:55:00+03	2017-07-26 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-07-26 14:59:00+03	2017-07-26 17:06:00+03
27933	PG0682	2017-08-05 14:55:00+03	2017-08-05 17:05:00+03	NOZ	NYM	Arrived	CR2	2017-08-05 14:56:00+03	2017-08-05 17:05:00+03
27934	PG0682	2017-09-09 14:55:00+03	2017-09-09 17:05:00+03	NOZ	NYM	Scheduled	CR2	\N	\N
27935	PG0500	2017-07-31 15:45:00+03	2017-07-31 20:40:00+03	NOZ	KRR	Arrived	733	2017-07-31 15:51:00+03	2017-07-31 20:49:00+03
27936	PG0500	2017-07-17 15:45:00+03	2017-07-17 20:40:00+03	NOZ	KRR	Arrived	733	2017-07-17 15:51:00+03	2017-07-17 20:41:00+03
27937	PG0500	2017-09-04 15:45:00+03	2017-09-04 20:40:00+03	NOZ	KRR	Scheduled	733	\N	\N
27938	PG0500	2017-08-14 15:45:00+03	2017-08-14 20:40:00+03	NOZ	KRR	Arrived	733	2017-08-14 15:49:00+03	2017-08-14 20:44:00+03
27939	PG0500	2017-07-24 15:45:00+03	2017-07-24 20:40:00+03	NOZ	KRR	Arrived	733	2017-07-24 15:48:00+03	2017-07-24 20:47:00+03
27940	PG0500	2017-08-21 15:45:00+03	2017-08-21 20:40:00+03	NOZ	KRR	Scheduled	733	\N	\N
27941	PG0500	2017-09-11 15:45:00+03	2017-09-11 20:40:00+03	NOZ	KRR	Scheduled	733	\N	\N
27942	PG0500	2017-08-07 15:45:00+03	2017-08-07 20:40:00+03	NOZ	KRR	Arrived	733	2017-08-07 15:47:00+03	2017-08-07 20:42:00+03
27943	PG0500	2017-08-28 15:45:00+03	2017-08-28 20:40:00+03	NOZ	KRR	Scheduled	733	\N	\N
27944	PG0183	2017-07-31 07:35:00+03	2017-07-31 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-31 10:28:00+03	2017-07-31 11:27:00+03
27945	PG0183	2017-09-09 07:35:00+03	2017-09-09 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27946	PG0183	2017-08-22 07:35:00+03	2017-08-22 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27947	PG0183	2017-09-02 07:35:00+03	2017-09-02 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27948	PG0183	2017-07-16 07:35:00+03	2017-07-16 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-16 11:04:00+03	2017-07-16 12:04:00+03
27949	PG0183	2017-07-22 07:35:00+03	2017-07-22 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-22 10:29:00+03	2017-07-22 11:29:00+03
27950	PG0183	2017-08-06 07:35:00+03	2017-08-06 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-06 07:36:00+03	2017-08-06 08:36:00+03
27951	PG0183	2017-08-09 07:35:00+03	2017-08-09 08:35:00+03	NOZ	TOF	Cancelled	CN1	2017-08-09 11:19:00+03	2017-08-09 12:18:00+03
27952	PG0183	2017-08-31 07:35:00+03	2017-08-31 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27953	PG0183	2017-09-03 07:35:00+03	2017-09-03 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27954	PG0183	2017-07-28 07:35:00+03	2017-07-28 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-28 07:39:00+03	2017-07-28 08:39:00+03
27955	PG0183	2017-09-14 07:35:00+03	2017-09-14 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27956	PG0183	2017-09-05 07:35:00+03	2017-09-05 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27957	PG0183	2017-08-19 07:35:00+03	2017-08-19 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27958	PG0183	2017-07-29 07:35:00+03	2017-07-29 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-29 07:36:00+03	2017-07-29 08:36:00+03
27959	PG0183	2017-09-08 07:35:00+03	2017-09-08 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27960	PG0183	2017-08-11 07:35:00+03	2017-08-11 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-11 07:36:00+03	2017-08-11 08:37:00+03
27961	PG0183	2017-07-18 07:35:00+03	2017-07-18 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-18 07:36:00+03	2017-07-18 08:34:00+03
27962	PG0183	2017-07-25 07:35:00+03	2017-07-25 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-25 07:40:00+03	2017-07-25 08:40:00+03
27963	PG0183	2017-08-26 07:35:00+03	2017-08-26 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27964	PG0183	2017-09-13 07:35:00+03	2017-09-13 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27965	PG0183	2017-08-30 07:35:00+03	2017-08-30 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27966	PG0183	2017-07-26 07:35:00+03	2017-07-26 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-26 07:38:00+03	2017-07-26 08:38:00+03
27967	PG0183	2017-08-10 07:35:00+03	2017-08-10 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-10 07:41:00+03	2017-08-10 08:41:00+03
27968	PG0183	2017-08-13 07:35:00+03	2017-08-13 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-13 07:38:00+03	2017-08-13 08:38:00+03
27969	PG0183	2017-08-17 07:35:00+03	2017-08-17 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27970	PG0183	2017-09-06 07:35:00+03	2017-09-06 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27971	PG0183	2017-09-11 07:35:00+03	2017-09-11 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27972	PG0183	2017-07-20 07:35:00+03	2017-07-20 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-20 07:36:00+03	2017-07-20 08:36:00+03
27973	PG0183	2017-08-02 07:35:00+03	2017-08-02 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-02 07:39:00+03	2017-08-02 08:38:00+03
27974	PG0183	2017-09-01 07:35:00+03	2017-09-01 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27975	PG0183	2017-08-07 07:35:00+03	2017-08-07 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-07 07:36:00+03	2017-08-07 08:35:00+03
27976	PG0183	2017-08-08 07:35:00+03	2017-08-08 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-08 07:36:00+03	2017-08-08 08:36:00+03
27977	PG0183	2017-07-21 07:35:00+03	2017-07-21 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-21 07:41:00+03	2017-07-21 08:41:00+03
27978	PG0183	2017-07-27 07:35:00+03	2017-07-27 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-27 07:36:00+03	2017-07-27 08:37:00+03
27979	PG0183	2017-08-01 07:35:00+03	2017-08-01 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-01 11:23:00+03	2017-08-01 12:23:00+03
27980	PG0183	2017-07-23 07:35:00+03	2017-07-23 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-23 07:37:00+03	2017-07-23 08:37:00+03
27981	PG0183	2017-08-14 07:35:00+03	2017-08-14 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-14 07:41:00+03	2017-08-14 08:41:00+03
27982	PG0183	2017-08-15 07:35:00+03	2017-08-15 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-15 07:36:00+03	2017-08-15 08:37:00+03
27983	PG0183	2017-07-30 07:35:00+03	2017-07-30 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-30 07:38:00+03	2017-07-30 08:38:00+03
27984	PG0183	2017-08-29 07:35:00+03	2017-08-29 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27985	PG0183	2017-09-07 07:35:00+03	2017-09-07 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27986	PG0183	2017-09-04 07:35:00+03	2017-09-04 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27987	PG0183	2017-08-05 07:35:00+03	2017-08-05 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-05 07:38:00+03	2017-08-05 08:39:00+03
27988	PG0183	2017-09-10 07:35:00+03	2017-09-10 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27989	PG0183	2017-08-27 07:35:00+03	2017-08-27 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27990	PG0183	2017-08-12 07:35:00+03	2017-08-12 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-12 07:43:00+03	2017-08-12 08:43:00+03
27991	PG0183	2017-07-19 07:35:00+03	2017-07-19 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-19 07:40:00+03	2017-07-19 08:39:00+03
27992	PG0183	2017-09-12 07:35:00+03	2017-09-12 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27993	PG0183	2017-08-16 07:35:00+03	2017-08-16 08:35:00+03	NOZ	TOF	On Time	CN1	\N	\N
27994	PG0183	2017-07-24 07:35:00+03	2017-07-24 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-24 07:36:00+03	2017-07-24 08:36:00+03
27995	PG0183	2017-08-04 07:35:00+03	2017-08-04 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-04 07:38:00+03	2017-08-04 08:38:00+03
27996	PG0183	2017-08-24 07:35:00+03	2017-08-24 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27997	PG0183	2017-08-28 07:35:00+03	2017-08-28 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27998	PG0183	2017-08-25 07:35:00+03	2017-08-25 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
27999	PG0183	2017-08-20 07:35:00+03	2017-08-20 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
28000	PG0183	2017-08-21 07:35:00+03	2017-08-21 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
28001	PG0183	2017-08-18 07:35:00+03	2017-08-18 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
28002	PG0183	2017-08-23 07:35:00+03	2017-08-23 08:35:00+03	NOZ	TOF	Scheduled	CN1	\N	\N
28003	PG0183	2017-07-17 07:35:00+03	2017-07-17 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-07-17 07:38:00+03	2017-07-17 08:38:00+03
28004	PG0183	2017-08-03 07:35:00+03	2017-08-03 08:35:00+03	NOZ	TOF	Arrived	CN1	2017-08-03 07:37:00+03	2017-08-03 08:37:00+03
28005	PG0321	2017-09-05 07:40:00+03	2017-09-05 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28006	PG0321	2017-08-15 07:40:00+03	2017-08-15 12:35:00+03	NOZ	AER	Arrived	733	2017-08-15 07:41:00+03	2017-08-15 12:40:00+03
28007	PG0321	2017-09-12 07:40:00+03	2017-09-12 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28008	PG0321	2017-09-09 07:40:00+03	2017-09-09 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28009	PG0321	2017-08-08 07:40:00+03	2017-08-08 12:35:00+03	NOZ	AER	Arrived	733	2017-08-08 07:43:00+03	2017-08-08 12:39:00+03
28010	PG0321	2017-08-26 07:40:00+03	2017-08-26 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28011	PG0321	2017-07-29 07:40:00+03	2017-07-29 12:35:00+03	NOZ	AER	Arrived	733	2017-07-29 07:45:00+03	2017-07-29 12:39:00+03
28012	PG0321	2017-08-19 07:40:00+03	2017-08-19 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28013	PG0321	2017-07-22 07:40:00+03	2017-07-22 12:35:00+03	NOZ	AER	Arrived	733	2017-07-22 07:42:00+03	2017-07-22 12:34:00+03
28014	PG0321	2017-08-29 07:40:00+03	2017-08-29 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28015	PG0321	2017-08-05 07:40:00+03	2017-08-05 12:35:00+03	NOZ	AER	Arrived	733	2017-08-05 07:42:00+03	2017-08-05 12:39:00+03
28016	PG0321	2017-07-18 07:40:00+03	2017-07-18 12:35:00+03	NOZ	AER	Arrived	733	2017-07-18 07:45:00+03	2017-07-18 12:36:00+03
28017	PG0321	2017-08-12 07:40:00+03	2017-08-12 12:35:00+03	NOZ	AER	Arrived	733	2017-08-12 07:44:00+03	2017-08-12 12:45:00+03
28018	PG0321	2017-08-22 07:40:00+03	2017-08-22 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28019	PG0321	2017-07-25 07:40:00+03	2017-07-25 12:35:00+03	NOZ	AER	Arrived	733	2017-07-25 07:45:00+03	2017-07-25 12:37:00+03
28020	PG0321	2017-08-01 07:40:00+03	2017-08-01 12:35:00+03	NOZ	AER	Arrived	733	2017-08-01 07:45:00+03	2017-08-01 12:38:00+03
28021	PG0321	2017-09-02 07:40:00+03	2017-09-02 12:35:00+03	NOZ	AER	Scheduled	733	\N	\N
28022	PG0615	2017-08-12 06:05:00+03	2017-08-12 10:05:00+03	NOZ	CEE	Arrived	SU9	2017-08-12 06:09:00+03	2017-08-12 10:09:00+03
28023	PG0615	2017-08-26 06:05:00+03	2017-08-26 10:05:00+03	NOZ	CEE	Scheduled	SU9	\N	\N
28024	PG0615	2017-09-09 06:05:00+03	2017-09-09 10:05:00+03	NOZ	CEE	Cancelled	SU9	\N	\N
28025	PG0615	2017-08-19 06:05:00+03	2017-08-19 10:05:00+03	NOZ	CEE	Scheduled	SU9	\N	\N
28026	PG0615	2017-07-29 06:05:00+03	2017-07-29 10:05:00+03	NOZ	CEE	Arrived	SU9	2017-07-29 06:05:00+03	2017-07-29 10:07:00+03
28027	PG0615	2017-08-05 06:05:00+03	2017-08-05 10:05:00+03	NOZ	CEE	Arrived	SU9	2017-08-05 06:09:00+03	2017-08-05 10:10:00+03
28028	PG0615	2017-07-22 06:05:00+03	2017-07-22 10:05:00+03	NOZ	CEE	Arrived	SU9	2017-07-22 06:11:00+03	2017-07-22 10:08:00+03
28029	PG0615	2017-09-02 06:05:00+03	2017-09-02 10:05:00+03	NOZ	CEE	Scheduled	SU9	\N	\N
28030	PG0608	2017-08-29 10:55:00+03	2017-08-29 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28031	PG0608	2017-07-28 10:55:00+03	2017-07-28 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-28 10:59:00+03	2017-07-28 12:45:00+03
28032	PG0608	2017-08-18 10:55:00+03	2017-08-18 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28033	PG0608	2017-09-02 10:55:00+03	2017-09-02 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28034	PG0608	2017-08-08 10:55:00+03	2017-08-08 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-08 10:56:00+03	2017-08-08 12:41:00+03
28035	PG0608	2017-09-09 10:55:00+03	2017-09-09 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28036	PG0608	2017-07-29 10:55:00+03	2017-07-29 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-29 10:59:00+03	2017-07-29 12:43:00+03
28037	PG0608	2017-09-07 10:55:00+03	2017-09-07 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28038	PG0608	2017-08-23 10:55:00+03	2017-08-23 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28039	PG0608	2017-09-11 10:55:00+03	2017-09-11 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28040	PG0608	2017-08-28 10:55:00+03	2017-08-28 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28041	PG0608	2017-08-19 10:55:00+03	2017-08-19 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28042	PG0608	2017-08-12 10:55:00+03	2017-08-12 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-12 10:57:00+03	2017-08-12 12:42:00+03
28043	PG0608	2017-09-13 10:55:00+03	2017-09-13 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28044	PG0608	2017-07-23 10:55:00+03	2017-07-23 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-23 10:58:00+03	2017-07-23 12:43:00+03
28045	PG0608	2017-08-22 10:55:00+03	2017-08-22 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28046	PG0608	2017-08-07 10:55:00+03	2017-08-07 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-07 10:58:00+03	2017-08-07 12:43:00+03
28047	PG0608	2017-09-08 10:55:00+03	2017-09-08 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28048	PG0608	2017-08-04 10:55:00+03	2017-08-04 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-04 10:56:00+03	2017-08-04 12:41:00+03
28049	PG0608	2017-08-30 10:55:00+03	2017-08-30 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28050	PG0608	2017-09-04 10:55:00+03	2017-09-04 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28051	PG0608	2017-07-18 10:55:00+03	2017-07-18 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-18 10:59:00+03	2017-07-18 12:44:00+03
28052	PG0608	2017-08-31 10:55:00+03	2017-08-31 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28053	PG0608	2017-09-05 10:55:00+03	2017-09-05 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28054	PG0608	2017-08-02 10:55:00+03	2017-08-02 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-02 14:02:00+03	2017-08-02 15:46:00+03
28055	PG0608	2017-07-27 10:55:00+03	2017-07-27 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-27 10:56:00+03	2017-07-27 12:40:00+03
28056	PG0608	2017-07-21 10:55:00+03	2017-07-21 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-21 10:57:00+03	2017-07-21 12:41:00+03
28057	PG0608	2017-09-10 10:55:00+03	2017-09-10 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28058	PG0608	2017-08-14 10:55:00+03	2017-08-14 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-14 10:57:00+03	2017-08-14 12:42:00+03
28059	PG0608	2017-08-26 10:55:00+03	2017-08-26 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28060	PG0608	2017-08-17 10:55:00+03	2017-08-17 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28061	PG0608	2017-07-30 10:55:00+03	2017-07-30 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-30 10:58:00+03	2017-07-30 12:43:00+03
28062	PG0608	2017-08-27 10:55:00+03	2017-08-27 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28063	PG0608	2017-08-09 10:55:00+03	2017-08-09 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-09 11:00:00+03	2017-08-09 12:45:00+03
28064	PG0608	2017-08-25 10:55:00+03	2017-08-25 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28065	PG0608	2017-08-16 10:55:00+03	2017-08-16 12:40:00+03	ASF	DME	On Time	CR2	\N	\N
28066	PG0608	2017-07-16 10:55:00+03	2017-07-16 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-16 10:57:00+03	2017-07-16 12:42:00+03
28067	PG0608	2017-09-14 10:55:00+03	2017-09-14 12:40:00+03	ASF	DME	Cancelled	CR2	\N	\N
28068	PG0608	2017-07-24 10:55:00+03	2017-07-24 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-24 10:59:00+03	2017-07-24 12:46:00+03
28069	PG0608	2017-08-10 10:55:00+03	2017-08-10 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-10 10:58:00+03	2017-08-10 12:42:00+03
28070	PG0608	2017-08-11 10:55:00+03	2017-08-11 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-11 10:57:00+03	2017-08-11 12:42:00+03
28071	PG0608	2017-09-12 10:55:00+03	2017-09-12 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28072	PG0608	2017-07-26 10:55:00+03	2017-07-26 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-26 10:56:00+03	2017-07-26 12:41:00+03
28073	PG0608	2017-08-20 10:55:00+03	2017-08-20 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28074	PG0608	2017-08-24 10:55:00+03	2017-08-24 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28075	PG0608	2017-07-20 10:55:00+03	2017-07-20 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-20 10:59:00+03	2017-07-20 12:44:00+03
28076	PG0608	2017-08-05 10:55:00+03	2017-08-05 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-05 10:56:00+03	2017-08-05 12:40:00+03
28077	PG0608	2017-09-01 10:55:00+03	2017-09-01 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28078	PG0608	2017-09-03 10:55:00+03	2017-09-03 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28079	PG0608	2017-08-06 10:55:00+03	2017-08-06 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-06 10:55:00+03	2017-08-06 12:39:00+03
28080	PG0608	2017-08-01 10:55:00+03	2017-08-01 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-01 10:57:00+03	2017-08-01 12:42:00+03
28081	PG0608	2017-08-15 10:55:00+03	2017-08-15 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-15 10:55:00+03	2017-08-15 12:42:00+03
28082	PG0608	2017-07-31 10:55:00+03	2017-07-31 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-31 10:56:00+03	2017-07-31 12:41:00+03
28083	PG0608	2017-07-25 10:55:00+03	2017-07-25 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-25 11:00:00+03	2017-07-25 12:44:00+03
28084	PG0608	2017-07-19 10:55:00+03	2017-07-19 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-19 10:59:00+03	2017-07-19 12:46:00+03
28085	PG0608	2017-08-21 10:55:00+03	2017-08-21 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28086	PG0608	2017-09-06 10:55:00+03	2017-09-06 12:40:00+03	ASF	DME	Scheduled	CR2	\N	\N
28087	PG0608	2017-08-03 10:55:00+03	2017-08-03 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-03 10:55:00+03	2017-08-03 12:39:00+03
28088	PG0608	2017-07-22 10:55:00+03	2017-07-22 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-22 11:00:00+03	2017-07-22 12:45:00+03
28089	PG0608	2017-07-17 10:55:00+03	2017-07-17 12:40:00+03	ASF	DME	Arrived	CR2	2017-07-17 11:01:00+03	2017-07-17 12:46:00+03
28090	PG0608	2017-08-13 10:55:00+03	2017-08-13 12:40:00+03	ASF	DME	Arrived	CR2	2017-08-13 10:57:00+03	2017-08-13 12:41:00+03
28091	PG0129	2017-08-10 13:05:00+03	2017-08-10 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-10 13:11:00+03	2017-08-10 15:02:00+03
28092	PG0129	2017-07-30 13:05:00+03	2017-07-30 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-30 13:09:00+03	2017-07-30 15:01:00+03
28093	PG0129	2017-08-14 13:05:00+03	2017-08-14 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-14 13:11:00+03	2017-08-14 15:02:00+03
28094	PG0129	2017-08-15 13:05:00+03	2017-08-15 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-15 13:11:00+03	2017-08-15 15:00:00+03
28095	PG0129	2017-08-21 13:05:00+03	2017-08-21 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28096	PG0129	2017-08-07 13:05:00+03	2017-08-07 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-07 13:07:00+03	2017-08-07 14:57:00+03
28097	PG0129	2017-07-25 13:05:00+03	2017-07-25 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-25 13:11:00+03	2017-07-25 15:02:00+03
28098	PG0129	2017-08-26 13:05:00+03	2017-08-26 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28099	PG0129	2017-07-18 13:05:00+03	2017-07-18 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-18 13:09:00+03	2017-07-18 15:00:00+03
28100	PG0129	2017-07-16 13:05:00+03	2017-07-16 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-16 13:09:00+03	2017-07-16 14:59:00+03
28101	PG0129	2017-07-31 13:05:00+03	2017-07-31 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-31 13:07:00+03	2017-07-31 14:57:00+03
28102	PG0129	2017-08-08 13:05:00+03	2017-08-08 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-08 13:10:00+03	2017-08-08 14:59:00+03
28103	PG0129	2017-08-02 13:05:00+03	2017-08-02 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-02 13:15:00+03	2017-08-02 15:05:00+03
28104	PG0129	2017-08-04 13:05:00+03	2017-08-04 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-04 13:11:00+03	2017-08-04 15:02:00+03
28105	PG0129	2017-08-23 13:05:00+03	2017-08-23 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28106	PG0129	2017-08-27 13:05:00+03	2017-08-27 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28107	PG0129	2017-09-14 13:05:00+03	2017-09-14 14:55:00+03	ASF	SVO	Cancelled	CR2	\N	\N
28108	PG0129	2017-08-25 13:05:00+03	2017-08-25 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28109	PG0129	2017-09-03 13:05:00+03	2017-09-03 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28110	PG0129	2017-07-19 13:05:00+03	2017-07-19 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-19 13:09:00+03	2017-07-19 14:59:00+03
28111	PG0129	2017-07-27 13:05:00+03	2017-07-27 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-27 13:06:00+03	2017-07-27 14:56:00+03
28112	PG0129	2017-08-17 13:05:00+03	2017-08-17 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28113	PG0129	2017-08-22 13:05:00+03	2017-08-22 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28114	PG0129	2017-08-13 13:05:00+03	2017-08-13 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-13 16:14:00+03	2017-08-13 18:03:00+03
28115	PG0129	2017-08-24 13:05:00+03	2017-08-24 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28116	PG0129	2017-09-06 13:05:00+03	2017-09-06 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28117	PG0129	2017-07-24 13:05:00+03	2017-07-24 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-24 13:07:00+03	2017-07-24 14:57:00+03
28118	PG0129	2017-09-12 13:05:00+03	2017-09-12 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28119	PG0129	2017-08-11 13:05:00+03	2017-08-11 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-11 13:07:00+03	2017-08-11 14:58:00+03
28120	PG0129	2017-09-04 13:05:00+03	2017-09-04 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28121	PG0129	2017-08-05 13:05:00+03	2017-08-05 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-05 13:06:00+03	2017-08-05 14:57:00+03
28122	PG0129	2017-08-29 13:05:00+03	2017-08-29 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28123	PG0129	2017-08-01 13:05:00+03	2017-08-01 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-01 13:10:00+03	2017-08-01 15:00:00+03
28124	PG0129	2017-09-08 13:05:00+03	2017-09-08 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28125	PG0129	2017-08-19 13:05:00+03	2017-08-19 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28126	PG0129	2017-09-13 13:05:00+03	2017-09-13 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28127	PG0129	2017-08-28 13:05:00+03	2017-08-28 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28128	PG0129	2017-09-11 13:05:00+03	2017-09-11 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28129	PG0129	2017-07-29 13:05:00+03	2017-07-29 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-29 13:09:00+03	2017-07-29 15:01:00+03
28130	PG0129	2017-08-18 13:05:00+03	2017-08-18 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28131	PG0129	2017-07-20 13:05:00+03	2017-07-20 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-20 13:08:00+03	2017-07-20 14:59:00+03
28132	PG0129	2017-08-16 13:05:00+03	2017-08-16 14:55:00+03	ASF	SVO	On Time	CR2	\N	\N
28133	PG0129	2017-08-03 13:05:00+03	2017-08-03 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-03 13:08:00+03	2017-08-03 14:57:00+03
28134	PG0129	2017-09-07 13:05:00+03	2017-09-07 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28135	PG0129	2017-09-02 13:05:00+03	2017-09-02 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28136	PG0129	2017-07-22 13:05:00+03	2017-07-22 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-22 13:07:00+03	2017-07-22 14:57:00+03
28137	PG0129	2017-08-31 13:05:00+03	2017-08-31 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28138	PG0129	2017-08-09 13:05:00+03	2017-08-09 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-09 13:09:00+03	2017-08-09 14:58:00+03
28139	PG0129	2017-09-10 13:05:00+03	2017-09-10 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28140	PG0129	2017-07-28 13:05:00+03	2017-07-28 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-28 13:07:00+03	2017-07-28 14:57:00+03
28141	PG0129	2017-09-05 13:05:00+03	2017-09-05 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28142	PG0129	2017-08-12 13:05:00+03	2017-08-12 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-12 13:11:00+03	2017-08-12 15:02:00+03
28143	PG0129	2017-08-30 13:05:00+03	2017-08-30 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28144	PG0129	2017-07-23 13:05:00+03	2017-07-23 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-23 13:06:00+03	2017-07-23 14:58:00+03
28145	PG0129	2017-09-01 13:05:00+03	2017-09-01 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28146	PG0129	2017-07-21 13:05:00+03	2017-07-21 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-21 13:10:00+03	2017-07-21 15:00:00+03
28147	PG0129	2017-08-20 13:05:00+03	2017-08-20 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28148	PG0129	2017-07-17 13:05:00+03	2017-07-17 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-17 13:06:00+03	2017-07-17 14:55:00+03
28149	PG0129	2017-08-06 13:05:00+03	2017-08-06 14:55:00+03	ASF	SVO	Arrived	CR2	2017-08-06 13:06:00+03	2017-08-06 14:56:00+03
28150	PG0129	2017-07-26 13:05:00+03	2017-07-26 14:55:00+03	ASF	SVO	Arrived	CR2	2017-07-26 16:23:00+03	2017-07-26 18:14:00+03
28151	PG0129	2017-09-09 13:05:00+03	2017-09-09 14:55:00+03	ASF	SVO	Scheduled	CR2	\N	\N
28152	PG0427	2017-08-20 08:00:00+03	2017-08-20 14:50:00+03	ASF	CNN	Scheduled	319	\N	\N
28153	PG0427	2017-07-30 08:00:00+03	2017-07-30 14:50:00+03	ASF	CNN	Arrived	319	2017-07-30 08:04:00+03	2017-07-30 14:54:00+03
28154	PG0427	2017-09-10 08:00:00+03	2017-09-10 14:50:00+03	ASF	CNN	Cancelled	319	\N	\N
28155	PG0427	2017-07-23 08:00:00+03	2017-07-23 14:50:00+03	ASF	CNN	Arrived	319	2017-07-23 08:06:00+03	2017-07-23 15:03:00+03
28156	PG0427	2017-07-16 08:00:00+03	2017-07-16 14:50:00+03	ASF	CNN	Arrived	319	2017-07-16 08:02:00+03	2017-07-16 14:46:00+03
28157	PG0427	2017-08-13 08:00:00+03	2017-08-13 14:50:00+03	ASF	CNN	Arrived	319	2017-08-13 08:04:00+03	2017-08-13 14:56:00+03
28158	PG0427	2017-08-27 08:00:00+03	2017-08-27 14:50:00+03	ASF	CNN	Scheduled	319	\N	\N
28159	PG0427	2017-08-06 08:00:00+03	2017-08-06 14:50:00+03	ASF	CNN	Arrived	319	2017-08-06 08:04:00+03	2017-08-06 14:53:00+03
28160	PG0427	2017-09-03 08:00:00+03	2017-09-03 14:50:00+03	ASF	CNN	Scheduled	319	\N	\N
28161	PG0596	2017-09-06 12:55:00+03	2017-09-06 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28162	PG0596	2017-08-12 12:55:00+03	2017-08-12 16:40:00+03	ASF	BAX	Arrived	CR2	2017-08-12 13:00:00+03	2017-08-12 16:46:00+03
28163	PG0596	2017-08-05 12:55:00+03	2017-08-05 16:40:00+03	ASF	BAX	Arrived	CR2	2017-08-05 12:57:00+03	2017-08-05 16:44:00+03
28164	PG0596	2017-08-26 12:55:00+03	2017-08-26 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28165	PG0596	2017-08-16 12:55:00+03	2017-08-16 16:40:00+03	ASF	BAX	On Time	CR2	\N	\N
28166	PG0596	2017-08-09 12:55:00+03	2017-08-09 16:40:00+03	ASF	BAX	Arrived	CR2	2017-08-09 12:59:00+03	2017-08-09 16:45:00+03
28167	PG0596	2017-09-09 12:55:00+03	2017-09-09 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28168	PG0596	2017-08-30 12:55:00+03	2017-08-30 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28169	PG0596	2017-08-19 12:55:00+03	2017-08-19 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28170	PG0596	2017-07-26 12:55:00+03	2017-07-26 16:40:00+03	ASF	BAX	Arrived	CR2	2017-07-26 12:57:00+03	2017-07-26 16:44:00+03
28171	PG0596	2017-09-13 12:55:00+03	2017-09-13 16:40:00+03	ASF	BAX	Cancelled	CR2	\N	\N
28172	PG0596	2017-09-02 12:55:00+03	2017-09-02 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28173	PG0596	2017-07-29 12:55:00+03	2017-07-29 16:40:00+03	ASF	BAX	Arrived	CR2	2017-07-29 15:58:00+03	2017-07-29 19:39:00+03
28174	PG0596	2017-08-02 12:55:00+03	2017-08-02 16:40:00+03	ASF	BAX	Arrived	CR2	2017-08-02 12:57:00+03	2017-08-02 16:41:00+03
28175	PG0596	2017-08-23 12:55:00+03	2017-08-23 16:40:00+03	ASF	BAX	Scheduled	CR2	\N	\N
28176	PG0596	2017-07-22 12:55:00+03	2017-07-22 16:40:00+03	ASF	BAX	Arrived	CR2	2017-07-22 12:58:00+03	2017-07-22 16:40:00+03
28177	PG0596	2017-07-19 12:55:00+03	2017-07-19 16:40:00+03	ASF	BAX	Arrived	CR2	2017-07-19 13:00:00+03	2017-07-19 16:44:00+03
28178	PG0031	2017-07-25 10:25:00+03	2017-07-25 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-25 10:33:00+03	2017-07-25 12:17:00+03
28179	PG0032	2017-09-08 09:00:00+03	2017-09-08 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28180	PG0031	2017-08-22 10:25:00+03	2017-08-22 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28181	PG0031	2017-09-03 10:25:00+03	2017-09-03 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28182	PG0031	2017-08-15 10:25:00+03	2017-08-15 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-15 10:29:00+03	2017-08-15 12:14:00+03
28183	PG0032	2017-08-22 09:00:00+03	2017-08-22 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28184	PG0031	2017-08-11 10:25:00+03	2017-08-11 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-11 10:30:00+03	2017-08-11 12:13:00+03
28185	PG0031	2017-08-25 10:25:00+03	2017-08-25 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28186	PG0032	2017-08-13 09:00:00+03	2017-08-13 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-13 09:02:00+03	2017-08-13 10:46:00+03
28187	PG0032	2017-09-14 09:00:00+03	2017-09-14 10:45:00+03	PEZ	DME	Cancelled	CN1	\N	\N
28188	PG0032	2017-08-15 09:00:00+03	2017-08-15 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-15 09:04:00+03	2017-08-15 10:49:00+03
28189	PG0031	2017-08-24 10:25:00+03	2017-08-24 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28190	PG0031	2017-07-20 10:25:00+03	2017-07-20 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-20 10:28:00+03	2017-07-20 12:12:00+03
28191	PG0031	2017-07-26 10:25:00+03	2017-07-26 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-26 10:28:00+03	2017-07-26 12:14:00+03
28192	PG0032	2017-09-03 09:00:00+03	2017-09-03 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28193	PG0031	2017-09-07 10:25:00+03	2017-09-07 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28194	PG0031	2017-07-31 10:25:00+03	2017-07-31 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-31 10:25:00+03	2017-07-31 12:10:00+03
28195	PG0032	2017-09-07 09:00:00+03	2017-09-07 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28196	PG0032	2017-08-27 09:00:00+03	2017-08-27 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28197	PG0032	2017-07-31 09:00:00+03	2017-07-31 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-31 09:00:00+03	2017-07-31 10:44:00+03
28198	PG0031	2017-08-02 10:25:00+03	2017-08-02 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-02 10:28:00+03	2017-08-02 12:13:00+03
28199	PG0032	2017-08-19 09:00:00+03	2017-08-19 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28200	PG0032	2017-08-02 09:00:00+03	2017-08-02 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-02 09:05:00+03	2017-08-02 10:51:00+03
28201	PG0032	2017-08-12 09:00:00+03	2017-08-12 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-12 09:04:00+03	2017-08-12 10:50:00+03
28202	PG0031	2017-08-12 10:25:00+03	2017-08-12 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-12 10:28:00+03	2017-08-12 12:13:00+03
28203	PG0031	2017-08-27 10:25:00+03	2017-08-27 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28204	PG0031	2017-08-31 10:25:00+03	2017-08-31 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28205	PG0032	2017-07-16 09:00:00+03	2017-07-16 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-16 09:05:00+03	2017-07-16 10:49:00+03
28206	PG0032	2017-08-31 09:00:00+03	2017-08-31 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28207	PG0032	2017-07-18 09:00:00+03	2017-07-18 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-18 09:01:00+03	2017-07-18 10:47:00+03
28208	PG0032	2017-08-25 09:00:00+03	2017-08-25 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28209	PG0031	2017-07-16 10:25:00+03	2017-07-16 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-16 10:26:00+03	2017-07-16 12:13:00+03
28210	PG0032	2017-07-22 09:00:00+03	2017-07-22 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-22 09:05:00+03	2017-07-22 10:48:00+03
28211	PG0031	2017-07-22 10:25:00+03	2017-07-22 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-22 10:29:00+03	2017-07-22 12:15:00+03
28212	PG0031	2017-09-14 10:25:00+03	2017-09-14 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28213	PG0032	2017-08-04 09:00:00+03	2017-08-04 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-04 09:02:00+03	2017-08-04 10:47:00+03
28214	PG0031	2017-08-03 10:25:00+03	2017-08-03 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-03 10:27:00+03	2017-08-03 12:12:00+03
28215	PG0031	2017-07-23 10:25:00+03	2017-07-23 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-23 10:28:00+03	2017-07-23 12:13:00+03
28216	PG0032	2017-08-03 09:00:00+03	2017-08-03 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-03 09:02:00+03	2017-08-03 10:47:00+03
28217	PG0031	2017-07-21 10:25:00+03	2017-07-21 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-21 10:30:00+03	2017-07-21 12:15:00+03
28218	PG0032	2017-07-21 09:00:00+03	2017-07-21 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-21 09:03:00+03	2017-07-21 10:50:00+03
28219	PG0032	2017-07-30 09:00:00+03	2017-07-30 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-30 09:04:00+03	2017-07-30 10:49:00+03
28220	PG0031	2017-08-10 10:25:00+03	2017-08-10 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-10 10:28:00+03	2017-08-10 12:12:00+03
28221	PG0032	2017-08-10 09:00:00+03	2017-08-10 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-10 09:04:00+03	2017-08-10 10:49:00+03
28222	PG0031	2017-08-07 10:25:00+03	2017-08-07 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-07 10:32:00+03	2017-08-07 12:17:00+03
28223	PG0032	2017-07-27 09:00:00+03	2017-07-27 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-27 09:05:00+03	2017-07-27 10:50:00+03
28224	PG0031	2017-07-27 10:25:00+03	2017-07-27 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-27 10:29:00+03	2017-07-27 12:14:00+03
28225	PG0032	2017-07-20 09:00:00+03	2017-07-20 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-20 09:04:00+03	2017-07-20 10:49:00+03
28226	PG0031	2017-08-04 10:25:00+03	2017-08-04 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-04 10:29:00+03	2017-08-04 12:13:00+03
28227	PG0032	2017-08-07 09:00:00+03	2017-08-07 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-07 09:04:00+03	2017-08-07 10:48:00+03
28228	PG0032	2017-07-28 09:00:00+03	2017-07-28 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-28 09:04:00+03	2017-07-28 10:49:00+03
28229	PG0032	2017-09-04 09:00:00+03	2017-09-04 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28230	PG0031	2017-08-30 10:25:00+03	2017-08-30 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28231	PG0032	2017-08-30 09:00:00+03	2017-08-30 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28232	PG0031	2017-08-20 10:25:00+03	2017-08-20 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28233	PG0031	2017-09-04 10:25:00+03	2017-09-04 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28234	PG0032	2017-08-24 09:00:00+03	2017-08-24 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28235	PG0032	2017-08-20 09:00:00+03	2017-08-20 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28236	PG0032	2017-08-08 09:00:00+03	2017-08-08 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-08 09:03:00+03	2017-08-08 10:47:00+03
28237	PG0031	2017-07-24 10:25:00+03	2017-07-24 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-24 10:28:00+03	2017-07-24 12:13:00+03
28238	PG0031	2017-07-28 10:25:00+03	2017-07-28 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-28 10:27:00+03	2017-07-28 12:12:00+03
28239	PG0032	2017-07-24 09:00:00+03	2017-07-24 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-24 09:02:00+03	2017-07-24 10:48:00+03
28240	PG0032	2017-09-11 09:00:00+03	2017-09-11 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28241	PG0032	2017-07-23 09:00:00+03	2017-07-23 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-23 09:01:00+03	2017-07-23 10:46:00+03
28242	PG0031	2017-08-08 10:25:00+03	2017-08-08 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-08 10:27:00+03	2017-08-08 12:12:00+03
28243	PG0032	2017-08-28 09:00:00+03	2017-08-28 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28244	PG0031	2017-08-28 10:25:00+03	2017-08-28 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28245	PG0031	2017-09-12 10:25:00+03	2017-09-12 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28246	PG0031	2017-08-29 10:25:00+03	2017-08-29 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28247	PG0031	2017-08-01 10:25:00+03	2017-08-01 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-01 10:28:00+03	2017-08-01 12:13:00+03
28248	PG0032	2017-08-29 09:00:00+03	2017-08-29 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28249	PG0031	2017-08-26 10:25:00+03	2017-08-26 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28250	PG0031	2017-08-06 10:25:00+03	2017-08-06 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-06 10:28:00+03	2017-08-06 12:14:00+03
28251	PG0032	2017-08-18 09:00:00+03	2017-08-18 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28252	PG0031	2017-08-18 10:25:00+03	2017-08-18 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28253	PG0032	2017-08-06 09:00:00+03	2017-08-06 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-06 09:02:00+03	2017-08-06 10:48:00+03
28254	PG0032	2017-07-29 09:00:00+03	2017-07-29 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-29 09:04:00+03	2017-07-29 10:50:00+03
28255	PG0031	2017-07-18 10:25:00+03	2017-07-18 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-18 10:29:00+03	2017-07-18 12:14:00+03
28256	PG0031	2017-09-08 10:25:00+03	2017-09-08 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28257	PG0032	2017-07-26 09:00:00+03	2017-07-26 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-26 09:03:00+03	2017-07-26 10:47:00+03
28258	PG0031	2017-08-14 10:25:00+03	2017-08-14 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-14 10:29:00+03	2017-08-14 12:13:00+03
28259	PG0032	2017-08-01 09:00:00+03	2017-08-01 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-01 09:03:00+03	2017-08-01 10:47:00+03
28260	PG0031	2017-08-05 10:25:00+03	2017-08-05 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-05 10:26:00+03	2017-08-05 12:10:00+03
28261	PG0032	2017-08-14 09:00:00+03	2017-08-14 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-14 09:05:00+03	2017-08-14 10:52:00+03
28262	PG0032	2017-08-05 09:00:00+03	2017-08-05 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-05 09:04:00+03	2017-08-05 10:49:00+03
28263	PG0031	2017-07-19 10:25:00+03	2017-07-19 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-19 10:28:00+03	2017-07-19 12:12:00+03
28264	PG0032	2017-07-19 09:00:00+03	2017-07-19 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-19 12:19:00+03	2017-07-19 14:05:00+03
28265	PG0031	2017-09-13 10:25:00+03	2017-09-13 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28266	PG0032	2017-09-13 09:00:00+03	2017-09-13 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28267	PG0032	2017-07-17 09:00:00+03	2017-07-17 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-17 09:02:00+03	2017-07-17 10:48:00+03
28268	PG0031	2017-07-17 10:25:00+03	2017-07-17 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-17 10:26:00+03	2017-07-17 12:10:00+03
28269	PG0031	2017-09-09 10:25:00+03	2017-09-09 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28270	PG0032	2017-08-11 09:00:00+03	2017-08-11 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-11 09:07:00+03	2017-08-11 10:53:00+03
28271	PG0031	2017-08-19 10:25:00+03	2017-08-19 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28272	PG0031	2017-09-02 10:25:00+03	2017-09-02 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28273	PG0032	2017-09-09 09:00:00+03	2017-09-09 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28274	PG0032	2017-09-02 09:00:00+03	2017-09-02 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28275	PG0031	2017-08-16 10:25:00+03	2017-08-16 12:10:00+03	PEZ	DME	On Time	CN1	\N	\N
28276	PG0031	2017-07-30 10:25:00+03	2017-07-30 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-30 10:30:00+03	2017-07-30 12:16:00+03
28277	PG0032	2017-09-10 09:00:00+03	2017-09-10 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28278	PG0031	2017-09-10 10:25:00+03	2017-09-10 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28279	PG0031	2017-09-05 10:25:00+03	2017-09-05 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28280	PG0031	2017-08-23 10:25:00+03	2017-08-23 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28281	PG0032	2017-09-05 09:00:00+03	2017-09-05 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28282	PG0032	2017-08-09 09:00:00+03	2017-08-09 10:45:00+03	PEZ	DME	Arrived	CN1	2017-08-09 09:02:00+03	2017-08-09 10:46:00+03
28283	PG0032	2017-09-12 09:00:00+03	2017-09-12 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28284	PG0032	2017-08-21 09:00:00+03	2017-08-21 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28285	PG0031	2017-09-01 10:25:00+03	2017-09-01 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28286	PG0032	2017-09-01 09:00:00+03	2017-09-01 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28287	PG0032	2017-08-26 09:00:00+03	2017-08-26 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28288	PG0032	2017-08-17 09:00:00+03	2017-08-17 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28289	PG0031	2017-08-09 10:25:00+03	2017-08-09 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-09 10:27:00+03	2017-08-09 12:12:00+03
28290	PG0031	2017-09-11 10:25:00+03	2017-09-11 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28291	PG0032	2017-08-16 09:00:00+03	2017-08-16 10:45:00+03	PEZ	DME	On Time	CN1	\N	\N
28292	PG0031	2017-08-21 10:25:00+03	2017-08-21 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28293	PG0031	2017-09-06 10:25:00+03	2017-09-06 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28294	PG0032	2017-09-06 09:00:00+03	2017-09-06 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28295	PG0032	2017-08-23 09:00:00+03	2017-08-23 10:45:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28296	PG0031	2017-07-29 10:25:00+03	2017-07-29 12:10:00+03	PEZ	DME	Arrived	CN1	2017-07-29 13:24:00+03	2017-07-29 15:09:00+03
28297	PG0032	2017-07-25 09:00:00+03	2017-07-25 10:45:00+03	PEZ	DME	Arrived	CN1	2017-07-25 09:02:00+03	2017-07-25 10:46:00+03
28298	PG0031	2017-08-17 10:25:00+03	2017-08-17 12:10:00+03	PEZ	DME	Scheduled	CN1	\N	\N
28299	PG0031	2017-08-13 10:25:00+03	2017-08-13 12:10:00+03	PEZ	DME	Arrived	CN1	2017-08-13 10:29:00+03	2017-08-13 12:15:00+03
28300	PG0514	2017-07-21 14:50:00+03	2017-07-21 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-21 14:54:00+03	2017-07-21 16:49:00+03
28301	PG0514	2017-07-23 14:50:00+03	2017-07-23 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-23 14:53:00+03	2017-07-23 16:48:00+03
28302	PG0514	2017-08-22 14:50:00+03	2017-08-22 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28303	PG0514	2017-08-12 14:50:00+03	2017-08-12 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-12 14:52:00+03	2017-08-12 16:47:00+03
28304	PG0514	2017-08-21 14:50:00+03	2017-08-21 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28305	PG0514	2017-09-08 14:50:00+03	2017-09-08 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28306	PG0514	2017-09-13 14:50:00+03	2017-09-13 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28307	PG0514	2017-08-26 14:50:00+03	2017-08-26 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28308	PG0514	2017-08-19 14:50:00+03	2017-08-19 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28309	PG0514	2017-08-14 14:50:00+03	2017-08-14 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-14 14:52:00+03	2017-08-14 16:45:00+03
28310	PG0514	2017-08-07 14:50:00+03	2017-08-07 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-07 14:51:00+03	2017-08-07 16:47:00+03
28311	PG0514	2017-08-30 14:50:00+03	2017-08-30 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28312	PG0514	2017-08-02 14:50:00+03	2017-08-02 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-02 14:54:00+03	2017-08-02 16:50:00+03
28313	PG0514	2017-07-30 14:50:00+03	2017-07-30 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-30 14:53:00+03	2017-07-30 16:49:00+03
28314	PG0514	2017-08-09 14:50:00+03	2017-08-09 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-09 14:54:00+03	2017-08-09 16:48:00+03
28315	PG0514	2017-07-27 14:50:00+03	2017-07-27 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-27 14:52:00+03	2017-07-27 16:46:00+03
28316	PG0514	2017-09-04 14:50:00+03	2017-09-04 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28317	PG0514	2017-08-08 14:50:00+03	2017-08-08 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-08 14:51:00+03	2017-08-08 16:47:00+03
28318	PG0514	2017-09-02 14:50:00+03	2017-09-02 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28319	PG0514	2017-09-10 14:50:00+03	2017-09-10 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28320	PG0514	2017-08-17 14:50:00+03	2017-08-17 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28321	PG0514	2017-08-18 14:50:00+03	2017-08-18 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28322	PG0514	2017-07-24 14:50:00+03	2017-07-24 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-24 14:52:00+03	2017-07-24 16:48:00+03
28323	PG0514	2017-08-23 14:50:00+03	2017-08-23 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28324	PG0514	2017-08-10 14:50:00+03	2017-08-10 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-10 14:53:00+03	2017-08-10 16:47:00+03
28325	PG0514	2017-08-25 14:50:00+03	2017-08-25 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28326	PG0514	2017-09-09 14:50:00+03	2017-09-09 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28327	PG0514	2017-07-16 14:50:00+03	2017-07-16 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-16 14:55:00+03	2017-07-16 16:50:00+03
28328	PG0514	2017-08-29 14:50:00+03	2017-08-29 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28329	PG0514	2017-09-11 14:50:00+03	2017-09-11 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28330	PG0514	2017-07-22 14:50:00+03	2017-07-22 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-22 14:52:00+03	2017-07-22 16:46:00+03
28331	PG0514	2017-08-03 14:50:00+03	2017-08-03 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-03 14:53:00+03	2017-08-03 16:47:00+03
28332	PG0514	2017-08-24 14:50:00+03	2017-08-24 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28333	PG0514	2017-08-27 14:50:00+03	2017-08-27 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28334	PG0514	2017-08-06 14:50:00+03	2017-08-06 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-06 14:55:00+03	2017-08-06 16:53:00+03
28335	PG0514	2017-08-05 14:50:00+03	2017-08-05 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-05 14:52:00+03	2017-08-05 16:49:00+03
28336	PG0514	2017-09-03 14:50:00+03	2017-09-03 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28337	PG0514	2017-08-20 14:50:00+03	2017-08-20 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28338	PG0514	2017-08-11 14:50:00+03	2017-08-11 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-11 14:54:00+03	2017-08-11 16:48:00+03
28339	PG0514	2017-08-15 14:50:00+03	2017-08-15 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-15 14:56:00+03	2017-08-15 16:51:00+03
28340	PG0514	2017-07-28 14:50:00+03	2017-07-28 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-28 14:54:00+03	2017-07-28 16:50:00+03
28341	PG0514	2017-07-25 14:50:00+03	2017-07-25 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-25 14:53:00+03	2017-07-25 16:47:00+03
28342	PG0514	2017-07-31 14:50:00+03	2017-07-31 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-31 14:55:00+03	2017-07-31 16:49:00+03
28343	PG0514	2017-07-17 14:50:00+03	2017-07-17 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-17 14:51:00+03	2017-07-17 16:46:00+03
28344	PG0514	2017-07-19 14:50:00+03	2017-07-19 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-19 14:53:00+03	2017-07-19 16:50:00+03
28345	PG0514	2017-08-28 14:50:00+03	2017-08-28 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28346	PG0514	2017-09-01 14:50:00+03	2017-09-01 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28347	PG0514	2017-07-26 14:50:00+03	2017-07-26 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-26 14:55:00+03	2017-07-26 16:52:00+03
28348	PG0514	2017-07-20 14:50:00+03	2017-07-20 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-20 14:55:00+03	2017-07-20 16:49:00+03
28349	PG0514	2017-09-12 14:50:00+03	2017-09-12 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28350	PG0514	2017-09-14 14:50:00+03	2017-09-14 16:45:00+03	PEZ	SVO	Cancelled	CN1	\N	\N
28351	PG0514	2017-07-29 14:50:00+03	2017-07-29 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-29 14:53:00+03	2017-07-29 16:47:00+03
28352	PG0514	2017-09-06 14:50:00+03	2017-09-06 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28353	PG0514	2017-08-01 14:50:00+03	2017-08-01 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-01 14:56:00+03	2017-08-01 16:50:00+03
28354	PG0514	2017-08-16 14:50:00+03	2017-08-16 16:45:00+03	PEZ	SVO	On Time	CN1	\N	\N
28355	PG0514	2017-08-04 14:50:00+03	2017-08-04 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-04 14:54:00+03	2017-08-04 16:48:00+03
28356	PG0514	2017-08-13 14:50:00+03	2017-08-13 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-08-13 14:53:00+03	2017-08-13 16:50:00+03
28357	PG0514	2017-09-07 14:50:00+03	2017-09-07 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28358	PG0514	2017-08-31 14:50:00+03	2017-08-31 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28359	PG0514	2017-09-05 14:50:00+03	2017-09-05 16:45:00+03	PEZ	SVO	Scheduled	CN1	\N	\N
28360	PG0514	2017-07-18 14:50:00+03	2017-07-18 16:45:00+03	PEZ	SVO	Arrived	CN1	2017-07-18 14:54:00+03	2017-07-18 16:48:00+03
28361	PG0601	2017-07-25 11:10:00+03	2017-07-25 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-25 11:12:00+03	2017-07-25 15:01:00+03
28362	PG0601	2017-09-09 11:10:00+03	2017-09-09 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28363	PG0601	2017-08-08 11:10:00+03	2017-08-08 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-08 11:10:00+03	2017-08-08 14:58:00+03
28364	PG0601	2017-08-30 11:10:00+03	2017-08-30 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28365	PG0601	2017-07-27 11:10:00+03	2017-07-27 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-27 11:14:00+03	2017-07-27 14:59:00+03
28366	PG0601	2017-08-21 11:10:00+03	2017-08-21 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28367	PG0601	2017-08-04 11:10:00+03	2017-08-04 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-04 11:11:00+03	2017-08-04 14:58:00+03
28368	PG0601	2017-07-30 11:10:00+03	2017-07-30 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-30 11:10:00+03	2017-07-30 14:55:00+03
28369	PG0601	2017-09-14 11:10:00+03	2017-09-14 14:55:00+03	PEZ	AER	Cancelled	CN1	\N	\N
28370	PG0601	2017-08-16 11:10:00+03	2017-08-16 14:55:00+03	PEZ	AER	On Time	CN1	\N	\N
28371	PG0601	2017-07-23 11:10:00+03	2017-07-23 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-23 11:12:00+03	2017-07-23 14:54:00+03
28372	PG0601	2017-08-15 11:10:00+03	2017-08-15 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-15 11:11:00+03	2017-08-15 14:59:00+03
28373	PG0601	2017-08-06 11:10:00+03	2017-08-06 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-06 14:23:00+03	2017-08-06 18:07:00+03
28374	PG0601	2017-09-05 11:10:00+03	2017-09-05 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28375	PG0601	2017-09-04 11:10:00+03	2017-09-04 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28376	PG0601	2017-09-03 11:10:00+03	2017-09-03 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28377	PG0601	2017-07-31 11:10:00+03	2017-07-31 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-31 11:12:00+03	2017-07-31 14:53:00+03
28378	PG0601	2017-08-01 11:10:00+03	2017-08-01 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-01 11:17:00+03	2017-08-01 15:02:00+03
28379	PG0601	2017-09-02 11:10:00+03	2017-09-02 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28380	PG0601	2017-08-19 11:10:00+03	2017-08-19 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28381	PG0601	2017-09-10 11:10:00+03	2017-09-10 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28382	PG0601	2017-07-26 11:10:00+03	2017-07-26 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-26 11:12:00+03	2017-07-26 14:57:00+03
28383	PG0601	2017-09-07 11:10:00+03	2017-09-07 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28384	PG0601	2017-08-26 11:10:00+03	2017-08-26 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28385	PG0601	2017-08-02 11:10:00+03	2017-08-02 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-02 11:14:00+03	2017-08-02 14:59:00+03
28386	PG0601	2017-07-19 11:10:00+03	2017-07-19 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-19 11:14:00+03	2017-07-19 14:58:00+03
28387	PG0601	2017-09-11 11:10:00+03	2017-09-11 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28388	PG0601	2017-08-18 11:10:00+03	2017-08-18 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28389	PG0601	2017-08-29 11:10:00+03	2017-08-29 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28390	PG0601	2017-08-03 11:10:00+03	2017-08-03 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-03 11:12:00+03	2017-08-03 14:58:00+03
28391	PG0601	2017-07-17 11:10:00+03	2017-07-17 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-17 11:15:00+03	2017-07-17 14:57:00+03
28392	PG0601	2017-07-28 11:10:00+03	2017-07-28 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-28 14:28:00+03	2017-07-28 18:11:00+03
28393	PG0601	2017-08-14 11:10:00+03	2017-08-14 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-14 11:14:00+03	2017-08-14 14:59:00+03
28394	PG0601	2017-07-21 11:10:00+03	2017-07-21 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-21 11:16:00+03	2017-07-21 15:03:00+03
28395	PG0601	2017-08-20 11:10:00+03	2017-08-20 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28396	PG0601	2017-09-12 11:10:00+03	2017-09-12 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28397	PG0601	2017-08-13 11:10:00+03	2017-08-13 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-13 11:11:00+03	2017-08-13 14:59:00+03
28398	PG0601	2017-08-12 11:10:00+03	2017-08-12 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-12 11:14:00+03	2017-08-12 15:01:00+03
28399	PG0601	2017-08-05 11:10:00+03	2017-08-05 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-05 11:15:00+03	2017-08-05 15:03:00+03
28400	PG0601	2017-08-07 11:10:00+03	2017-08-07 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-07 11:14:00+03	2017-08-07 15:01:00+03
28401	PG0601	2017-09-13 11:10:00+03	2017-09-13 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28402	PG0601	2017-07-16 11:10:00+03	2017-07-16 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-16 11:12:00+03	2017-07-16 14:55:00+03
28403	PG0601	2017-08-25 11:10:00+03	2017-08-25 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28404	PG0601	2017-08-23 11:10:00+03	2017-08-23 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28405	PG0601	2017-09-06 11:10:00+03	2017-09-06 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28406	PG0601	2017-07-20 11:10:00+03	2017-07-20 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-20 11:13:00+03	2017-07-20 14:59:00+03
28407	PG0601	2017-09-08 11:10:00+03	2017-09-08 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28408	PG0601	2017-08-31 11:10:00+03	2017-08-31 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28409	PG0601	2017-07-29 11:10:00+03	2017-07-29 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-29 11:13:00+03	2017-07-29 14:58:00+03
28410	PG0601	2017-07-18 11:10:00+03	2017-07-18 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-18 11:14:00+03	2017-07-18 14:54:00+03
28411	PG0601	2017-08-27 11:10:00+03	2017-08-27 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28412	PG0601	2017-08-09 11:10:00+03	2017-08-09 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-09 11:12:00+03	2017-08-09 14:58:00+03
28413	PG0601	2017-08-10 11:10:00+03	2017-08-10 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-10 11:16:00+03	2017-08-10 14:59:00+03
28414	PG0601	2017-09-01 11:10:00+03	2017-09-01 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28415	PG0601	2017-08-17 11:10:00+03	2017-08-17 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28416	PG0601	2017-08-24 11:10:00+03	2017-08-24 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28417	PG0601	2017-07-24 11:10:00+03	2017-07-24 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-24 11:12:00+03	2017-07-24 14:53:00+03
28418	PG0601	2017-08-22 11:10:00+03	2017-08-22 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28419	PG0601	2017-08-11 11:10:00+03	2017-08-11 14:55:00+03	PEZ	AER	Arrived	CN1	2017-08-11 11:13:00+03	2017-08-11 14:59:00+03
28420	PG0601	2017-07-22 11:10:00+03	2017-07-22 14:55:00+03	PEZ	AER	Arrived	CN1	2017-07-22 14:23:00+03	2017-07-22 18:06:00+03
28421	PG0601	2017-08-28 11:10:00+03	2017-08-28 14:55:00+03	PEZ	AER	Scheduled	CN1	\N	\N
28422	PG0086	2017-07-20 14:45:00+03	2017-07-20 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-20 18:27:00+03	2017-07-20 19:32:00+03
28423	PG0086	2017-08-08 14:45:00+03	2017-08-08 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-08 14:47:00+03	2017-08-08 15:52:00+03
28424	PG0086	2017-08-03 14:45:00+03	2017-08-03 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-03 14:47:00+03	2017-08-03 15:51:00+03
28425	PG0086	2017-07-29 14:45:00+03	2017-07-29 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-29 14:48:00+03	2017-07-29 15:53:00+03
28426	PG0086	2017-07-27 14:45:00+03	2017-07-27 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-27 14:48:00+03	2017-07-27 15:52:00+03
28427	PG0086	2017-07-25 14:45:00+03	2017-07-25 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-25 14:48:00+03	2017-07-25 15:53:00+03
28428	PG0086	2017-08-22 14:45:00+03	2017-08-22 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28429	PG0086	2017-09-07 14:45:00+03	2017-09-07 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28430	PG0086	2017-09-05 14:45:00+03	2017-09-05 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28431	PG0086	2017-08-31 14:45:00+03	2017-08-31 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28432	PG0086	2017-08-12 14:45:00+03	2017-08-12 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-12 14:50:00+03	2017-08-12 15:55:00+03
28433	PG0086	2017-08-05 14:45:00+03	2017-08-05 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-05 14:49:00+03	2017-08-05 15:54:00+03
28434	PG0086	2017-08-10 14:45:00+03	2017-08-10 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-10 14:50:00+03	2017-08-10 15:55:00+03
28435	PG0086	2017-08-15 14:45:00+03	2017-08-15 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-15 14:51:00+03	2017-08-15 15:56:00+03
28436	PG0086	2017-08-24 14:45:00+03	2017-08-24 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28437	PG0086	2017-08-26 14:45:00+03	2017-08-26 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28438	PG0086	2017-09-02 14:45:00+03	2017-09-02 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28439	PG0086	2017-08-01 14:45:00+03	2017-08-01 15:50:00+03	LPK	DME	Arrived	CN1	2017-08-01 14:48:00+03	2017-08-01 15:53:00+03
28440	PG0086	2017-09-09 14:45:00+03	2017-09-09 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28441	PG0086	2017-08-17 14:45:00+03	2017-08-17 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28442	PG0086	2017-07-22 14:45:00+03	2017-07-22 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-22 14:49:00+03	2017-07-22 15:55:00+03
28443	PG0086	2017-09-14 14:45:00+03	2017-09-14 15:50:00+03	LPK	DME	Cancelled	CN1	\N	\N
28444	PG0086	2017-07-18 14:45:00+03	2017-07-18 15:50:00+03	LPK	DME	Arrived	CN1	2017-07-18 14:48:00+03	2017-07-18 15:53:00+03
28445	PG0086	2017-08-19 14:45:00+03	2017-08-19 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28446	PG0086	2017-08-29 14:45:00+03	2017-08-29 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28447	PG0086	2017-09-12 14:45:00+03	2017-09-12 15:50:00+03	LPK	DME	Scheduled	CN1	\N	\N
28448	PG0431	2017-09-04 15:55:00+03	2017-09-04 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28449	PG0431	2017-07-31 15:55:00+03	2017-07-31 19:25:00+03	LPK	PES	Arrived	CN1	2017-07-31 15:59:00+03	2017-07-31 19:28:00+03
28450	PG0431	2017-07-24 15:55:00+03	2017-07-24 19:25:00+03	LPK	PES	Arrived	CN1	2017-07-24 15:57:00+03	2017-07-24 19:24:00+03
28451	PG0431	2017-08-11 15:55:00+03	2017-08-11 19:25:00+03	LPK	PES	Arrived	CN1	2017-08-11 19:32:00+03	2017-08-11 23:00:00+03
28452	PG0431	2017-09-01 15:55:00+03	2017-09-01 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28453	PG0431	2017-08-04 15:55:00+03	2017-08-04 19:25:00+03	LPK	PES	Arrived	CN1	2017-08-04 15:56:00+03	2017-08-04 19:28:00+03
28454	PG0431	2017-07-21 15:55:00+03	2017-07-21 19:25:00+03	LPK	PES	Arrived	CN1	2017-07-21 15:57:00+03	2017-07-21 19:29:00+03
28455	PG0431	2017-08-14 15:55:00+03	2017-08-14 19:25:00+03	LPK	PES	Arrived	CN1	2017-08-14 15:57:00+03	2017-08-14 19:28:00+03
28456	PG0431	2017-08-07 15:55:00+03	2017-08-07 19:25:00+03	LPK	PES	Arrived	CN1	2017-08-07 15:56:00+03	2017-08-07 19:26:00+03
28457	PG0431	2017-08-18 15:55:00+03	2017-08-18 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28458	PG0431	2017-08-28 15:55:00+03	2017-08-28 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28459	PG0431	2017-08-21 15:55:00+03	2017-08-21 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28460	PG0431	2017-09-11 15:55:00+03	2017-09-11 19:25:00+03	LPK	PES	Cancelled	CN1	\N	\N
28461	PG0431	2017-09-08 15:55:00+03	2017-09-08 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28462	PG0431	2017-07-28 15:55:00+03	2017-07-28 19:25:00+03	LPK	PES	Arrived	CN1	2017-07-28 15:57:00+03	2017-07-28 19:29:00+03
28463	PG0431	2017-08-25 15:55:00+03	2017-08-25 19:25:00+03	LPK	PES	Scheduled	CN1	\N	\N
28464	PG0431	2017-07-17 15:55:00+03	2017-07-17 19:25:00+03	LPK	PES	Arrived	CN1	2017-07-17 15:58:00+03	2017-07-17 19:27:00+03
28465	PG0594	2017-08-28 15:15:00+03	2017-08-28 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28466	PG0594	2017-07-28 15:15:00+03	2017-07-28 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-28 18:22:00+03	2017-07-28 20:51:00+03
28467	PG0594	2017-07-18 15:15:00+03	2017-07-18 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-18 15:17:00+03	2017-07-18 17:47:00+03
28468	PG0594	2017-08-14 15:15:00+03	2017-08-14 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-14 18:53:00+03	2017-08-14 21:22:00+03
28469	PG0594	2017-08-08 15:15:00+03	2017-08-08 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-08 15:16:00+03	2017-08-08 17:48:00+03
28470	PG0594	2017-09-02 15:15:00+03	2017-09-02 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28471	PG0594	2017-09-14 15:15:00+03	2017-09-14 17:45:00+03	KVX	DME	Cancelled	CN1	\N	\N
28472	PG0594	2017-07-21 15:15:00+03	2017-07-21 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-21 15:17:00+03	2017-07-21 17:47:00+03
28473	PG0594	2017-09-01 15:15:00+03	2017-09-01 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28474	PG0594	2017-08-02 15:15:00+03	2017-08-02 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-02 15:22:00+03	2017-08-02 17:53:00+03
28475	PG0594	2017-08-30 15:15:00+03	2017-08-30 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28476	PG0594	2017-07-23 15:15:00+03	2017-07-23 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-23 15:18:00+03	2017-07-23 17:48:00+03
28477	PG0594	2017-08-29 15:15:00+03	2017-08-29 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28478	PG0594	2017-07-17 15:15:00+03	2017-07-17 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-17 15:18:00+03	2017-07-17 17:51:00+03
28479	PG0594	2017-08-12 15:15:00+03	2017-08-12 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-12 15:16:00+03	2017-08-12 17:45:00+03
28480	PG0594	2017-09-10 15:15:00+03	2017-09-10 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28481	PG0594	2017-08-01 15:15:00+03	2017-08-01 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-01 15:20:00+03	2017-08-01 17:53:00+03
28482	PG0594	2017-09-04 15:15:00+03	2017-09-04 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28483	PG0594	2017-07-19 15:15:00+03	2017-07-19 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-19 15:17:00+03	2017-07-19 17:47:00+03
28484	PG0594	2017-09-03 15:15:00+03	2017-09-03 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28485	PG0594	2017-08-23 15:15:00+03	2017-08-23 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28486	PG0594	2017-08-06 15:15:00+03	2017-08-06 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-06 15:18:00+03	2017-08-06 17:47:00+03
28487	PG0594	2017-08-03 15:15:00+03	2017-08-03 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-03 15:16:00+03	2017-08-03 17:46:00+03
28488	PG0594	2017-08-18 15:15:00+03	2017-08-18 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28489	PG0594	2017-08-16 15:15:00+03	2017-08-16 17:45:00+03	KVX	DME	On Time	CN1	\N	\N
28490	PG0594	2017-09-05 15:15:00+03	2017-09-05 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28491	PG0594	2017-08-05 15:15:00+03	2017-08-05 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-05 15:17:00+03	2017-08-05 17:48:00+03
28492	PG0594	2017-07-26 15:15:00+03	2017-07-26 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-26 15:18:00+03	2017-07-26 17:46:00+03
28493	PG0594	2017-08-19 15:15:00+03	2017-08-19 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28494	PG0594	2017-07-31 15:15:00+03	2017-07-31 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-31 15:18:00+03	2017-07-31 17:48:00+03
28495	PG0594	2017-07-30 15:15:00+03	2017-07-30 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-30 15:19:00+03	2017-07-30 17:47:00+03
28496	PG0594	2017-08-04 15:15:00+03	2017-08-04 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-04 15:20:00+03	2017-08-04 17:51:00+03
28497	PG0594	2017-07-16 15:15:00+03	2017-07-16 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-16 15:18:00+03	2017-07-16 17:47:00+03
28498	PG0594	2017-08-15 15:15:00+03	2017-08-15 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-15 15:21:00+03	2017-08-15 17:53:00+03
28499	PG0594	2017-08-22 15:15:00+03	2017-08-22 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28500	PG0594	2017-07-29 15:15:00+03	2017-07-29 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-29 18:08:00+03	2017-07-29 20:40:00+03
28501	PG0594	2017-09-08 15:15:00+03	2017-09-08 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28502	PG0594	2017-07-22 15:15:00+03	2017-07-22 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-22 15:16:00+03	2017-07-22 17:42:00+03
28503	PG0594	2017-09-09 15:15:00+03	2017-09-09 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28504	PG0594	2017-09-13 15:15:00+03	2017-09-13 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28505	PG0594	2017-07-24 15:15:00+03	2017-07-24 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-24 15:18:00+03	2017-07-24 17:48:00+03
28506	PG0594	2017-08-11 15:15:00+03	2017-08-11 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-11 15:16:00+03	2017-08-11 17:45:00+03
28507	PG0594	2017-09-06 15:15:00+03	2017-09-06 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28508	PG0594	2017-08-31 15:15:00+03	2017-08-31 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28509	PG0594	2017-08-07 15:15:00+03	2017-08-07 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-07 15:19:00+03	2017-08-07 17:48:00+03
28510	PG0594	2017-08-17 15:15:00+03	2017-08-17 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28511	PG0594	2017-08-09 15:15:00+03	2017-08-09 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-09 15:17:00+03	2017-08-09 17:48:00+03
28512	PG0594	2017-07-20 15:15:00+03	2017-07-20 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-20 15:17:00+03	2017-07-20 17:47:00+03
28513	PG0594	2017-08-27 15:15:00+03	2017-08-27 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28514	PG0594	2017-09-12 15:15:00+03	2017-09-12 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28515	PG0594	2017-08-25 15:15:00+03	2017-08-25 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28516	PG0594	2017-08-24 15:15:00+03	2017-08-24 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28517	PG0594	2017-08-10 15:15:00+03	2017-08-10 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-10 15:17:00+03	2017-08-10 17:45:00+03
28518	PG0594	2017-08-20 15:15:00+03	2017-08-20 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28519	PG0594	2017-08-21 15:15:00+03	2017-08-21 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28520	PG0594	2017-08-13 15:15:00+03	2017-08-13 17:45:00+03	KVX	DME	Arrived	CN1	2017-08-13 15:17:00+03	2017-08-13 17:47:00+03
28521	PG0594	2017-07-25 15:15:00+03	2017-07-25 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-25 15:17:00+03	2017-07-25 17:48:00+03
28522	PG0594	2017-09-07 15:15:00+03	2017-09-07 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28523	PG0594	2017-07-27 15:15:00+03	2017-07-27 17:45:00+03	KVX	DME	Arrived	CN1	2017-07-27 15:21:00+03	2017-07-27 17:50:00+03
28524	PG0594	2017-09-11 15:15:00+03	2017-09-11 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28525	PG0594	2017-08-26 15:15:00+03	2017-08-26 17:45:00+03	KVX	DME	Scheduled	CN1	\N	\N
28526	PG0638	2017-08-16 19:15:00+03	2017-08-16 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28527	PG0638	2017-09-09 19:15:00+03	2017-09-09 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28528	PG0638	2017-08-29 19:15:00+03	2017-08-29 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28529	PG0638	2017-07-25 19:15:00+03	2017-07-25 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-25 22:36:00+03	2017-07-25 23:36:00+03
28530	PG0638	2017-08-05 19:15:00+03	2017-08-05 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-05 21:46:00+03	2017-08-05 22:46:00+03
28531	PG0638	2017-08-24 19:15:00+03	2017-08-24 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28532	PG0638	2017-08-06 19:15:00+03	2017-08-06 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-06 19:18:00+03	2017-08-06 20:18:00+03
28533	PG0638	2017-07-16 19:15:00+03	2017-07-16 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-16 19:20:00+03	2017-07-16 20:20:00+03
28534	PG0638	2017-08-25 19:15:00+03	2017-08-25 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28535	PG0638	2017-08-04 19:15:00+03	2017-08-04 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-04 19:18:00+03	2017-08-04 20:17:00+03
28536	PG0638	2017-09-04 19:15:00+03	2017-09-04 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28537	PG0638	2017-08-07 19:15:00+03	2017-08-07 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-07 19:21:00+03	2017-08-07 20:20:00+03
28538	PG0638	2017-08-23 19:15:00+03	2017-08-23 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28539	PG0638	2017-07-17 19:15:00+03	2017-07-17 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-17 19:17:00+03	2017-07-17 20:17:00+03
28540	PG0638	2017-08-03 19:15:00+03	2017-08-03 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-03 19:20:00+03	2017-08-03 20:21:00+03
28541	PG0638	2017-09-02 19:15:00+03	2017-09-02 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28542	PG0638	2017-08-08 19:15:00+03	2017-08-08 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-08 19:16:00+03	2017-08-08 20:17:00+03
28543	PG0638	2017-09-13 19:15:00+03	2017-09-13 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28544	PG0638	2017-08-22 19:15:00+03	2017-08-22 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28545	PG0638	2017-08-02 19:15:00+03	2017-08-02 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-02 19:16:00+03	2017-08-02 20:17:00+03
28546	PG0638	2017-07-18 19:15:00+03	2017-07-18 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-18 19:16:00+03	2017-07-18 20:16:00+03
28547	PG0638	2017-09-05 19:15:00+03	2017-09-05 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28548	PG0638	2017-08-26 19:15:00+03	2017-08-26 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28549	PG0638	2017-08-09 19:15:00+03	2017-08-09 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-09 19:18:00+03	2017-08-09 20:18:00+03
28550	PG0638	2017-08-01 19:15:00+03	2017-08-01 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-01 19:20:00+03	2017-08-01 20:20:00+03
28551	PG0638	2017-08-21 19:15:00+03	2017-08-21 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28552	PG0638	2017-07-19 19:15:00+03	2017-07-19 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-19 19:18:00+03	2017-07-19 20:19:00+03
28553	PG0638	2017-09-01 19:15:00+03	2017-09-01 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28554	PG0638	2017-08-10 19:15:00+03	2017-08-10 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-10 19:16:00+03	2017-08-10 20:17:00+03
28555	PG0638	2017-09-12 19:15:00+03	2017-09-12 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28556	PG0638	2017-09-14 19:15:00+03	2017-09-14 20:15:00+03	KVX	SVO	Cancelled	SU9	\N	\N
28557	PG0638	2017-07-31 19:15:00+03	2017-07-31 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-31 19:17:00+03	2017-07-31 20:17:00+03
28558	PG0638	2017-09-06 19:15:00+03	2017-09-06 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28559	PG0638	2017-08-20 19:15:00+03	2017-08-20 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28560	PG0638	2017-07-20 19:15:00+03	2017-07-20 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-20 19:15:00+03	2017-07-20 20:14:00+03
28561	PG0638	2017-08-11 19:15:00+03	2017-08-11 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-11 19:16:00+03	2017-08-11 20:16:00+03
28562	PG0638	2017-09-03 19:15:00+03	2017-09-03 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28563	PG0638	2017-07-30 19:15:00+03	2017-07-30 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-30 19:18:00+03	2017-07-30 20:19:00+03
28564	PG0638	2017-08-27 19:15:00+03	2017-08-27 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28565	PG0638	2017-07-21 19:15:00+03	2017-07-21 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-21 19:20:00+03	2017-07-21 20:20:00+03
28566	PG0638	2017-08-31 19:15:00+03	2017-08-31 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28567	PG0638	2017-08-19 19:15:00+03	2017-08-19 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28568	PG0638	2017-09-11 19:15:00+03	2017-09-11 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28569	PG0638	2017-08-12 19:15:00+03	2017-08-12 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-12 19:16:00+03	2017-08-12 20:16:00+03
28570	PG0638	2017-07-29 19:15:00+03	2017-07-29 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-29 19:18:00+03	2017-07-29 20:17:00+03
28571	PG0638	2017-09-07 19:15:00+03	2017-09-07 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28572	PG0638	2017-07-22 19:15:00+03	2017-07-22 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-22 19:17:00+03	2017-07-22 20:17:00+03
28573	PG0638	2017-08-13 19:15:00+03	2017-08-13 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-13 19:19:00+03	2017-08-13 20:19:00+03
28574	PG0638	2017-08-18 19:15:00+03	2017-08-18 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28575	PG0638	2017-07-28 19:15:00+03	2017-07-28 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-28 19:16:00+03	2017-07-28 20:17:00+03
28576	PG0638	2017-08-30 19:15:00+03	2017-08-30 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28577	PG0638	2017-08-28 19:15:00+03	2017-08-28 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28578	PG0638	2017-07-23 19:15:00+03	2017-07-23 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-23 19:17:00+03	2017-07-23 20:17:00+03
28579	PG0638	2017-09-08 19:15:00+03	2017-09-08 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28580	PG0638	2017-07-27 19:15:00+03	2017-07-27 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-27 19:17:00+03	2017-07-27 20:17:00+03
28581	PG0638	2017-09-10 19:15:00+03	2017-09-10 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28582	PG0638	2017-08-14 19:15:00+03	2017-08-14 20:15:00+03	KVX	SVO	Arrived	SU9	2017-08-14 19:18:00+03	2017-08-14 20:18:00+03
28583	PG0638	2017-08-17 19:15:00+03	2017-08-17 20:15:00+03	KVX	SVO	Scheduled	SU9	\N	\N
28584	PG0638	2017-07-24 19:15:00+03	2017-07-24 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-24 19:21:00+03	2017-07-24 20:20:00+03
28585	PG0638	2017-07-26 19:15:00+03	2017-07-26 20:15:00+03	KVX	SVO	Arrived	SU9	2017-07-26 19:18:00+03	2017-07-26 20:18:00+03
28586	PG0638	2017-08-15 19:15:00+03	2017-08-15 20:15:00+03	KVX	SVO	On Time	SU9	\N	\N
28587	PG0286	2017-08-18 15:45:00+03	2017-08-18 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28588	PG0286	2017-07-26 15:45:00+03	2017-07-26 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-26 15:50:00+03	2017-07-26 17:19:00+03
28589	PG0286	2017-07-28 15:45:00+03	2017-07-28 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-28 15:50:00+03	2017-07-28 17:19:00+03
28590	PG0286	2017-08-14 15:45:00+03	2017-08-14 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-14 15:49:00+03	2017-08-14 17:20:00+03
28591	PG0286	2017-07-22 15:45:00+03	2017-07-22 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-22 15:47:00+03	2017-07-22 17:17:00+03
28592	PG0286	2017-09-08 15:45:00+03	2017-09-08 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28593	PG0286	2017-08-24 15:45:00+03	2017-08-24 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28594	PG0286	2017-07-23 15:45:00+03	2017-07-23 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-23 15:50:00+03	2017-07-23 17:19:00+03
28595	PG0286	2017-07-30 15:45:00+03	2017-07-30 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-30 15:50:00+03	2017-07-30 17:20:00+03
28596	PG0286	2017-08-09 15:45:00+03	2017-08-09 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-09 15:45:00+03	2017-08-09 17:15:00+03
28597	PG0286	2017-09-04 15:45:00+03	2017-09-04 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28598	PG0286	2017-08-02 15:45:00+03	2017-08-02 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-02 15:48:00+03	2017-08-02 17:18:00+03
28599	PG0286	2017-09-03 15:45:00+03	2017-09-03 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28600	PG0286	2017-09-02 15:45:00+03	2017-09-02 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28601	PG0286	2017-08-06 15:45:00+03	2017-08-06 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-06 15:45:00+03	2017-08-06 17:15:00+03
28602	PG0286	2017-08-23 15:45:00+03	2017-08-23 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28603	PG0286	2017-09-06 15:45:00+03	2017-09-06 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28604	PG0286	2017-08-29 15:45:00+03	2017-08-29 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28605	PG0286	2017-09-01 15:45:00+03	2017-09-01 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28606	PG0286	2017-09-05 15:45:00+03	2017-09-05 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28607	PG0286	2017-08-20 15:45:00+03	2017-08-20 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28608	PG0286	2017-07-18 15:45:00+03	2017-07-18 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-18 15:47:00+03	2017-07-18 17:17:00+03
28609	PG0286	2017-07-20 15:45:00+03	2017-07-20 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-20 15:48:00+03	2017-07-20 17:18:00+03
28610	PG0286	2017-07-25 15:45:00+03	2017-07-25 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-25 15:46:00+03	2017-07-25 17:17:00+03
28611	PG0286	2017-08-27 15:45:00+03	2017-08-27 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28612	PG0286	2017-07-19 15:45:00+03	2017-07-19 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-19 15:47:00+03	2017-07-19 17:17:00+03
28613	PG0286	2017-08-04 15:45:00+03	2017-08-04 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-04 15:48:00+03	2017-08-04 17:17:00+03
28614	PG0286	2017-09-12 15:45:00+03	2017-09-12 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28615	PG0286	2017-07-24 15:45:00+03	2017-07-24 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-24 15:48:00+03	2017-07-24 17:18:00+03
28616	PG0286	2017-08-31 15:45:00+03	2017-08-31 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28617	PG0286	2017-08-15 15:45:00+03	2017-08-15 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-15 15:49:00+03	2017-08-15 17:19:00+03
28618	PG0286	2017-08-25 15:45:00+03	2017-08-25 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28619	PG0286	2017-09-11 15:45:00+03	2017-09-11 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28620	PG0286	2017-07-21 15:45:00+03	2017-07-21 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-21 15:47:00+03	2017-07-21 17:19:00+03
28621	PG0286	2017-08-08 15:45:00+03	2017-08-08 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-08 15:48:00+03	2017-08-08 17:18:00+03
28622	PG0286	2017-08-12 15:45:00+03	2017-08-12 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-12 15:48:00+03	2017-08-12 17:18:00+03
28623	PG0286	2017-09-10 15:45:00+03	2017-09-10 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28624	PG0286	2017-09-07 15:45:00+03	2017-09-07 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28625	PG0286	2017-08-16 15:45:00+03	2017-08-16 17:15:00+03	KVX	LED	On Time	SU9	\N	\N
28626	PG0286	2017-08-01 15:45:00+03	2017-08-01 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-01 15:47:00+03	2017-08-01 17:16:00+03
28627	PG0286	2017-09-09 15:45:00+03	2017-09-09 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28628	PG0286	2017-07-16 15:45:00+03	2017-07-16 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-16 15:46:00+03	2017-07-16 17:15:00+03
28629	PG0286	2017-08-28 15:45:00+03	2017-08-28 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28630	PG0286	2017-08-21 15:45:00+03	2017-08-21 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28631	PG0286	2017-07-17 15:45:00+03	2017-07-17 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-17 15:52:00+03	2017-07-17 17:22:00+03
28632	PG0286	2017-07-31 15:45:00+03	2017-07-31 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-31 15:49:00+03	2017-07-31 17:18:00+03
28633	PG0286	2017-09-13 15:45:00+03	2017-09-13 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28634	PG0286	2017-08-07 15:45:00+03	2017-08-07 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-07 15:49:00+03	2017-08-07 17:18:00+03
28635	PG0286	2017-08-13 15:45:00+03	2017-08-13 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-13 15:48:00+03	2017-08-13 17:16:00+03
28636	PG0286	2017-08-05 15:45:00+03	2017-08-05 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-05 15:51:00+03	2017-08-05 17:20:00+03
28637	PG0286	2017-08-19 15:45:00+03	2017-08-19 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28638	PG0286	2017-09-14 15:45:00+03	2017-09-14 17:15:00+03	KVX	LED	Cancelled	SU9	\N	\N
28639	PG0286	2017-08-26 15:45:00+03	2017-08-26 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28640	PG0286	2017-08-17 15:45:00+03	2017-08-17 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28641	PG0286	2017-08-30 15:45:00+03	2017-08-30 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28642	PG0286	2017-08-03 15:45:00+03	2017-08-03 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-03 15:47:00+03	2017-08-03 17:16:00+03
28643	PG0286	2017-08-22 15:45:00+03	2017-08-22 17:15:00+03	KVX	LED	Scheduled	SU9	\N	\N
28644	PG0286	2017-07-27 15:45:00+03	2017-07-27 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-27 15:48:00+03	2017-07-27 17:18:00+03
28645	PG0286	2017-08-10 15:45:00+03	2017-08-10 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-10 15:49:00+03	2017-08-10 17:17:00+03
28646	PG0286	2017-07-29 15:45:00+03	2017-07-29 17:15:00+03	KVX	LED	Arrived	SU9	2017-07-29 15:45:00+03	2017-07-29 17:15:00+03
28647	PG0286	2017-08-11 15:45:00+03	2017-08-11 17:15:00+03	KVX	LED	Arrived	SU9	2017-08-11 15:50:00+03	2017-08-11 17:20:00+03
28648	PG0312	2017-08-26 11:40:00+03	2017-08-26 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28649	PG0312	2017-07-17 11:40:00+03	2017-07-17 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-17 11:42:00+03	2017-07-17 14:23:00+03
28650	PG0312	2017-08-14 11:40:00+03	2017-08-14 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-14 11:43:00+03	2017-08-14 14:30:00+03
28651	PG0312	2017-09-10 11:40:00+03	2017-09-10 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28652	PG0312	2017-07-16 11:40:00+03	2017-07-16 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-16 11:44:00+03	2017-07-16 14:28:00+03
28653	PG0312	2017-09-03 11:40:00+03	2017-09-03 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28654	PG0312	2017-09-09 11:40:00+03	2017-09-09 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28655	PG0312	2017-07-18 11:40:00+03	2017-07-18 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-18 11:45:00+03	2017-07-18 14:33:00+03
28656	PG0312	2017-08-23 11:40:00+03	2017-08-23 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28657	PG0312	2017-08-29 11:40:00+03	2017-08-29 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28658	PG0312	2017-08-03 11:40:00+03	2017-08-03 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-03 11:40:00+03	2017-08-03 14:25:00+03
28659	PG0312	2017-09-14 11:40:00+03	2017-09-14 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28660	PG0312	2017-07-28 11:40:00+03	2017-07-28 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-28 11:42:00+03	2017-07-28 14:28:00+03
28661	PG0312	2017-08-01 11:40:00+03	2017-08-01 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-01 11:41:00+03	2017-08-01 14:24:00+03
28662	PG0312	2017-08-08 11:40:00+03	2017-08-08 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-08 11:44:00+03	2017-08-08 14:31:00+03
28663	PG0312	2017-09-08 11:40:00+03	2017-09-08 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28664	PG0312	2017-07-27 11:40:00+03	2017-07-27 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-27 11:44:00+03	2017-07-27 14:28:00+03
28665	PG0312	2017-09-07 11:40:00+03	2017-09-07 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28666	PG0312	2017-08-20 11:40:00+03	2017-08-20 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28667	PG0312	2017-08-24 11:40:00+03	2017-08-24 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28668	PG0312	2017-07-30 11:40:00+03	2017-07-30 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-30 11:42:00+03	2017-07-30 14:24:00+03
28669	PG0312	2017-08-06 11:40:00+03	2017-08-06 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-06 15:29:00+03	2017-08-06 18:14:00+03
28670	PG0312	2017-07-20 11:40:00+03	2017-07-20 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-20 11:47:00+03	2017-07-20 14:31:00+03
28671	PG0312	2017-07-25 11:40:00+03	2017-07-25 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-25 11:43:00+03	2017-07-25 14:27:00+03
28672	PG0312	2017-08-27 11:40:00+03	2017-08-27 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28673	PG0312	2017-08-09 11:40:00+03	2017-08-09 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-09 11:43:00+03	2017-08-09 14:32:00+03
28674	PG0312	2017-08-05 11:40:00+03	2017-08-05 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-05 11:43:00+03	2017-08-05 14:30:00+03
28675	PG0312	2017-08-12 11:40:00+03	2017-08-12 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-12 11:43:00+03	2017-08-12 14:25:00+03
28676	PG0312	2017-08-21 11:40:00+03	2017-08-21 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28677	PG0312	2017-08-25 11:40:00+03	2017-08-25 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28678	PG0312	2017-07-21 11:40:00+03	2017-07-21 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-21 11:42:00+03	2017-07-21 14:26:00+03
28679	PG0312	2017-09-11 11:40:00+03	2017-09-11 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28680	PG0312	2017-07-26 11:40:00+03	2017-07-26 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-26 11:41:00+03	2017-07-26 14:27:00+03
28681	PG0312	2017-08-16 11:40:00+03	2017-08-16 14:25:00+03	KVX	OVB	On Time	SU9	\N	\N
28682	PG0312	2017-07-29 11:40:00+03	2017-07-29 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-29 11:45:00+03	2017-07-29 14:30:00+03
28683	PG0312	2017-08-30 11:40:00+03	2017-08-30 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28684	PG0312	2017-09-06 11:40:00+03	2017-09-06 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28685	PG0312	2017-07-23 11:40:00+03	2017-07-23 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-23 11:42:00+03	2017-07-23 14:30:00+03
28686	PG0312	2017-08-10 11:40:00+03	2017-08-10 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-10 11:42:00+03	2017-08-10 14:29:00+03
28687	PG0312	2017-08-22 11:40:00+03	2017-08-22 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28688	PG0312	2017-08-02 11:40:00+03	2017-08-02 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-02 11:42:00+03	2017-08-02 14:28:00+03
28689	PG0312	2017-09-13 11:40:00+03	2017-09-13 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28690	PG0312	2017-07-19 11:40:00+03	2017-07-19 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-19 11:43:00+03	2017-07-19 14:30:00+03
28691	PG0312	2017-08-13 11:40:00+03	2017-08-13 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-13 11:47:00+03	2017-08-13 14:31:00+03
28692	PG0312	2017-08-28 11:40:00+03	2017-08-28 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28693	PG0312	2017-08-15 11:40:00+03	2017-08-15 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-15 11:42:00+03	2017-08-15 14:28:00+03
28694	PG0312	2017-08-17 11:40:00+03	2017-08-17 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28695	PG0312	2017-08-31 11:40:00+03	2017-08-31 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28696	PG0312	2017-08-11 11:40:00+03	2017-08-11 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-11 11:45:00+03	2017-08-11 14:32:00+03
28697	PG0312	2017-07-24 11:40:00+03	2017-07-24 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-24 11:45:00+03	2017-07-24 14:33:00+03
28698	PG0312	2017-08-18 11:40:00+03	2017-08-18 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28699	PG0312	2017-08-19 11:40:00+03	2017-08-19 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28700	PG0312	2017-09-05 11:40:00+03	2017-09-05 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28701	PG0312	2017-09-12 11:40:00+03	2017-09-12 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28702	PG0312	2017-09-02 11:40:00+03	2017-09-02 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28703	PG0312	2017-07-22 11:40:00+03	2017-07-22 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-22 11:44:00+03	2017-07-22 14:30:00+03
28704	PG0312	2017-08-04 11:40:00+03	2017-08-04 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-04 11:40:00+03	2017-08-04 14:26:00+03
28705	PG0312	2017-09-04 11:40:00+03	2017-09-04 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28706	PG0312	2017-09-01 11:40:00+03	2017-09-01 14:25:00+03	KVX	OVB	Scheduled	SU9	\N	\N
28707	PG0312	2017-08-07 11:40:00+03	2017-08-07 14:25:00+03	KVX	OVB	Arrived	SU9	2017-08-07 11:50:00+03	2017-08-07 14:34:00+03
28708	PG0312	2017-07-31 11:40:00+03	2017-07-31 14:25:00+03	KVX	OVB	Arrived	SU9	2017-07-31 11:42:00+03	2017-07-31 14:25:00+03
28709	PG0040	2017-07-16 13:45:00+03	2017-07-16 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-16 13:46:00+03	2017-07-16 14:11:00+03
28710	PG0040	2017-08-04 13:45:00+03	2017-08-04 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-04 13:47:00+03	2017-08-04 14:12:00+03
28711	PG0040	2017-07-28 13:45:00+03	2017-07-28 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-28 17:29:00+03	2017-07-28 17:54:00+03
28712	PG0040	2017-08-18 13:45:00+03	2017-08-18 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28713	PG0040	2017-09-02 13:45:00+03	2017-09-02 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28714	PG0040	2017-09-13 13:45:00+03	2017-09-13 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28715	PG0040	2017-08-06 13:45:00+03	2017-08-06 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-06 13:50:00+03	2017-08-06 14:15:00+03
28716	PG0040	2017-08-25 13:45:00+03	2017-08-25 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28717	PG0040	2017-09-07 13:45:00+03	2017-09-07 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28718	PG0040	2017-09-06 13:45:00+03	2017-09-06 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28719	PG0040	2017-08-11 13:45:00+03	2017-08-11 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-11 13:51:00+03	2017-08-11 14:16:00+03
28720	PG0040	2017-09-09 13:45:00+03	2017-09-09 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28721	PG0040	2017-07-23 13:45:00+03	2017-07-23 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-23 13:47:00+03	2017-07-23 14:12:00+03
28722	PG0040	2017-09-08 13:45:00+03	2017-09-08 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28723	PG0040	2017-08-21 13:45:00+03	2017-08-21 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28724	PG0040	2017-07-29 13:45:00+03	2017-07-29 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-29 13:45:00+03	2017-07-29 14:10:00+03
28725	PG0040	2017-08-01 13:45:00+03	2017-08-01 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-01 13:45:00+03	2017-08-01 14:10:00+03
28726	PG0040	2017-08-27 13:45:00+03	2017-08-27 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28727	PG0040	2017-09-12 13:45:00+03	2017-09-12 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28728	PG0040	2017-08-10 13:45:00+03	2017-08-10 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-10 13:48:00+03	2017-08-10 14:13:00+03
28729	PG0040	2017-08-09 13:45:00+03	2017-08-09 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-09 13:48:00+03	2017-08-09 14:13:00+03
28730	PG0040	2017-08-24 13:45:00+03	2017-08-24 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28731	PG0040	2017-08-19 13:45:00+03	2017-08-19 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28732	PG0040	2017-08-23 13:45:00+03	2017-08-23 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28733	PG0040	2017-07-22 13:45:00+03	2017-07-22 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-22 13:51:00+03	2017-07-22 14:16:00+03
28734	PG0040	2017-09-11 13:45:00+03	2017-09-11 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28735	PG0040	2017-08-30 13:45:00+03	2017-08-30 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28736	PG0040	2017-07-20 13:45:00+03	2017-07-20 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-20 13:48:00+03	2017-07-20 14:13:00+03
28737	PG0040	2017-07-17 13:45:00+03	2017-07-17 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-17 13:49:00+03	2017-07-17 14:14:00+03
28738	PG0040	2017-09-10 13:45:00+03	2017-09-10 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28739	PG0040	2017-09-03 13:45:00+03	2017-09-03 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28740	PG0040	2017-08-31 13:45:00+03	2017-08-31 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28741	PG0040	2017-09-05 13:45:00+03	2017-09-05 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28742	PG0040	2017-08-26 13:45:00+03	2017-08-26 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28743	PG0040	2017-07-21 13:45:00+03	2017-07-21 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-21 13:48:00+03	2017-07-21 14:13:00+03
28744	PG0040	2017-07-31 13:45:00+03	2017-07-31 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-31 13:47:00+03	2017-07-31 14:12:00+03
28745	PG0040	2017-08-02 13:45:00+03	2017-08-02 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-02 13:50:00+03	2017-08-02 14:15:00+03
28746	PG0040	2017-07-25 13:45:00+03	2017-07-25 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-25 16:28:00+03	2017-07-25 16:53:00+03
28747	PG0040	2017-08-17 13:45:00+03	2017-08-17 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28748	PG0040	2017-08-28 13:45:00+03	2017-08-28 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28749	PG0040	2017-08-05 13:45:00+03	2017-08-05 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-05 13:49:00+03	2017-08-05 14:14:00+03
28750	PG0040	2017-08-14 13:45:00+03	2017-08-14 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-14 13:51:00+03	2017-08-14 14:16:00+03
28751	PG0040	2017-07-24 13:45:00+03	2017-07-24 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-24 13:50:00+03	2017-07-24 14:15:00+03
28752	PG0040	2017-08-12 13:45:00+03	2017-08-12 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-12 13:47:00+03	2017-08-12 14:12:00+03
28753	PG0040	2017-08-03 13:45:00+03	2017-08-03 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-03 13:48:00+03	2017-08-03 14:13:00+03
28754	PG0040	2017-08-08 13:45:00+03	2017-08-08 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-08 13:47:00+03	2017-08-08 14:12:00+03
28755	PG0040	2017-07-18 13:45:00+03	2017-07-18 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-18 13:46:00+03	2017-07-18 14:11:00+03
28756	PG0040	2017-08-16 13:45:00+03	2017-08-16 14:10:00+03	KVX	KZN	On Time	SU9	\N	\N
28757	PG0040	2017-07-27 13:45:00+03	2017-07-27 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-27 13:49:00+03	2017-07-27 14:13:00+03
28758	PG0040	2017-08-29 13:45:00+03	2017-08-29 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28759	PG0040	2017-07-30 13:45:00+03	2017-07-30 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-30 13:48:00+03	2017-07-30 14:13:00+03
28760	PG0040	2017-08-13 13:45:00+03	2017-08-13 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-13 13:49:00+03	2017-08-13 14:14:00+03
28761	PG0040	2017-09-01 13:45:00+03	2017-09-01 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28762	PG0040	2017-09-14 13:45:00+03	2017-09-14 14:10:00+03	KVX	KZN	Cancelled	SU9	\N	\N
28763	PG0040	2017-08-15 13:45:00+03	2017-08-15 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-15 13:51:00+03	2017-08-15 14:16:00+03
28764	PG0040	2017-08-22 13:45:00+03	2017-08-22 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28765	PG0040	2017-07-26 13:45:00+03	2017-07-26 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-26 13:46:00+03	2017-07-26 14:11:00+03
28766	PG0040	2017-09-04 13:45:00+03	2017-09-04 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28767	PG0040	2017-08-07 13:45:00+03	2017-08-07 14:10:00+03	KVX	KZN	Arrived	SU9	2017-08-07 13:49:00+03	2017-08-07 14:14:00+03
28768	PG0040	2017-08-20 13:45:00+03	2017-08-20 14:10:00+03	KVX	KZN	Scheduled	SU9	\N	\N
28769	PG0040	2017-07-19 13:45:00+03	2017-07-19 14:10:00+03	KVX	KZN	Arrived	SU9	2017-07-19 13:47:00+03	2017-07-19 14:12:00+03
28770	PG0692	2017-09-05 14:05:00+03	2017-09-05 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28771	PG0692	2017-09-14 14:05:00+03	2017-09-14 17:50:00+03	KVX	HMA	Cancelled	CN1	\N	\N
28772	PG0692	2017-07-16 14:05:00+03	2017-07-16 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-16 14:08:00+03	2017-07-16 17:54:00+03
28773	PG0692	2017-07-18 14:05:00+03	2017-07-18 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-18 17:13:00+03	2017-07-18 21:01:00+03
28774	PG0692	2017-08-14 14:05:00+03	2017-08-14 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-14 14:08:00+03	2017-08-14 17:55:00+03
28775	PG0692	2017-08-31 14:05:00+03	2017-08-31 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28776	PG0692	2017-08-10 14:05:00+03	2017-08-10 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-10 14:07:00+03	2017-08-10 17:47:00+03
28777	PG0692	2017-09-12 14:05:00+03	2017-09-12 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28778	PG0692	2017-07-17 14:05:00+03	2017-07-17 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-17 14:08:00+03	2017-07-17 17:51:00+03
28779	PG0692	2017-07-19 14:05:00+03	2017-07-19 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-19 14:08:00+03	2017-07-19 17:56:00+03
28780	PG0692	2017-09-03 14:05:00+03	2017-09-03 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28781	PG0692	2017-07-31 14:05:00+03	2017-07-31 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-31 14:08:00+03	2017-07-31 17:56:00+03
28782	PG0692	2017-08-03 14:05:00+03	2017-08-03 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-03 17:38:00+03	2017-08-03 21:25:00+03
28783	PG0692	2017-08-16 14:05:00+03	2017-08-16 17:50:00+03	KVX	HMA	On Time	CN1	\N	\N
28784	PG0692	2017-08-13 14:05:00+03	2017-08-13 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-13 14:12:00+03	2017-08-13 17:58:00+03
28785	PG0692	2017-09-01 14:05:00+03	2017-09-01 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28786	PG0692	2017-08-18 14:05:00+03	2017-08-18 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28787	PG0692	2017-08-29 14:05:00+03	2017-08-29 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28788	PG0692	2017-07-25 14:05:00+03	2017-07-25 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-25 14:11:00+03	2017-07-25 17:54:00+03
28789	PG0692	2017-08-15 14:05:00+03	2017-08-15 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-15 14:05:00+03	2017-08-15 17:52:00+03
28790	PG0692	2017-09-09 14:05:00+03	2017-09-09 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28791	PG0692	2017-08-24 14:05:00+03	2017-08-24 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28792	PG0692	2017-08-21 14:05:00+03	2017-08-21 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28793	PG0692	2017-08-20 14:05:00+03	2017-08-20 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28794	PG0692	2017-09-06 14:05:00+03	2017-09-06 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28795	PG0692	2017-07-22 14:05:00+03	2017-07-22 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-22 14:11:00+03	2017-07-22 17:52:00+03
28796	PG0692	2017-08-01 14:05:00+03	2017-08-01 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-01 14:11:00+03	2017-08-01 17:56:00+03
28797	PG0692	2017-07-28 14:05:00+03	2017-07-28 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-28 14:07:00+03	2017-07-28 17:53:00+03
28798	PG0692	2017-09-07 14:05:00+03	2017-09-07 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28799	PG0692	2017-09-02 14:05:00+03	2017-09-02 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28800	PG0692	2017-07-20 14:05:00+03	2017-07-20 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-20 14:11:00+03	2017-07-20 17:57:00+03
28801	PG0692	2017-07-24 14:05:00+03	2017-07-24 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-24 17:18:00+03	2017-07-24 21:07:00+03
28802	PG0692	2017-08-06 14:05:00+03	2017-08-06 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-06 14:08:00+03	2017-08-06 17:54:00+03
28803	PG0692	2017-08-30 14:05:00+03	2017-08-30 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28804	PG0692	2017-09-04 14:05:00+03	2017-09-04 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28805	PG0692	2017-08-08 14:05:00+03	2017-08-08 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-08 14:08:00+03	2017-08-08 17:57:00+03
28806	PG0692	2017-09-13 14:05:00+03	2017-09-13 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28807	PG0692	2017-08-07 14:05:00+03	2017-08-07 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-07 14:10:00+03	2017-08-07 17:51:00+03
28808	PG0692	2017-08-26 14:05:00+03	2017-08-26 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28809	PG0692	2017-08-12 14:05:00+03	2017-08-12 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-12 14:09:00+03	2017-08-12 17:55:00+03
28810	PG0692	2017-08-23 14:05:00+03	2017-08-23 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28811	PG0692	2017-07-26 14:05:00+03	2017-07-26 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-26 14:10:00+03	2017-07-26 17:54:00+03
28812	PG0692	2017-08-11 14:05:00+03	2017-08-11 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-11 14:11:00+03	2017-08-11 17:55:00+03
28813	PG0692	2017-07-29 14:05:00+03	2017-07-29 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-29 14:07:00+03	2017-07-29 17:51:00+03
28814	PG0692	2017-08-22 14:05:00+03	2017-08-22 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28815	PG0692	2017-08-09 14:05:00+03	2017-08-09 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-09 14:08:00+03	2017-08-09 17:50:00+03
28816	PG0692	2017-09-10 14:05:00+03	2017-09-10 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28817	PG0692	2017-07-27 14:05:00+03	2017-07-27 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-27 14:09:00+03	2017-07-27 17:53:00+03
28818	PG0692	2017-08-28 14:05:00+03	2017-08-28 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28819	PG0692	2017-07-23 14:05:00+03	2017-07-23 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-23 14:06:00+03	2017-07-23 17:52:00+03
28820	PG0692	2017-09-11 14:05:00+03	2017-09-11 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28821	PG0692	2017-07-30 14:05:00+03	2017-07-30 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-30 14:11:00+03	2017-07-30 17:53:00+03
28822	PG0692	2017-09-08 14:05:00+03	2017-09-08 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28823	PG0692	2017-08-02 14:05:00+03	2017-08-02 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-02 14:07:00+03	2017-08-02 17:52:00+03
28824	PG0692	2017-08-04 14:05:00+03	2017-08-04 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-04 14:13:00+03	2017-08-04 18:00:00+03
28825	PG0692	2017-08-25 14:05:00+03	2017-08-25 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28826	PG0692	2017-08-05 14:05:00+03	2017-08-05 17:50:00+03	KVX	HMA	Arrived	CN1	2017-08-05 14:07:00+03	2017-08-05 17:54:00+03
28827	PG0692	2017-08-17 14:05:00+03	2017-08-17 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28828	PG0692	2017-08-19 14:05:00+03	2017-08-19 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28829	PG0692	2017-07-21 14:05:00+03	2017-07-21 17:50:00+03	KVX	HMA	Arrived	CN1	2017-07-21 14:08:00+03	2017-07-21 17:52:00+03
28830	PG0692	2017-08-27 14:05:00+03	2017-08-27 17:50:00+03	KVX	HMA	Scheduled	CN1	\N	\N
28831	PG0177	2017-09-08 09:25:00+03	2017-09-08 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28832	PG0177	2017-09-14 09:25:00+03	2017-09-14 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28833	PG0177	2017-08-17 09:25:00+03	2017-08-17 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28834	PG0177	2017-07-28 09:25:00+03	2017-07-28 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-28 09:27:00+03	2017-07-28 10:22:00+03
28835	PG0177	2017-08-08 09:25:00+03	2017-08-08 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-08 09:27:00+03	2017-08-08 10:23:00+03
28836	PG0177	2017-07-18 09:25:00+03	2017-07-18 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-18 09:27:00+03	2017-07-18 10:22:00+03
28837	PG0177	2017-08-14 09:25:00+03	2017-08-14 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-14 09:27:00+03	2017-08-14 10:22:00+03
28838	PG0177	2017-09-05 09:25:00+03	2017-09-05 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28839	PG0177	2017-08-02 09:25:00+03	2017-08-02 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-02 09:25:00+03	2017-08-02 10:21:00+03
28840	PG0177	2017-08-30 09:25:00+03	2017-08-30 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28841	PG0177	2017-08-20 09:25:00+03	2017-08-20 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28842	PG0177	2017-08-23 09:25:00+03	2017-08-23 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28843	PG0177	2017-07-21 09:25:00+03	2017-07-21 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-21 09:26:00+03	2017-07-21 10:21:00+03
28844	PG0177	2017-09-04 09:25:00+03	2017-09-04 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28845	PG0177	2017-08-31 09:25:00+03	2017-08-31 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28846	PG0177	2017-09-01 09:25:00+03	2017-09-01 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28847	PG0177	2017-08-05 09:25:00+03	2017-08-05 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-05 09:27:00+03	2017-08-05 10:22:00+03
28848	PG0177	2017-09-13 09:25:00+03	2017-09-13 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28849	PG0177	2017-08-28 09:25:00+03	2017-08-28 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28850	PG0177	2017-08-29 09:25:00+03	2017-08-29 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28851	PG0177	2017-08-22 09:25:00+03	2017-08-22 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28852	PG0177	2017-07-31 09:25:00+03	2017-07-31 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-31 09:26:00+03	2017-07-31 10:21:00+03
28853	PG0177	2017-09-02 09:25:00+03	2017-09-02 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28854	PG0177	2017-09-07 09:25:00+03	2017-09-07 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28855	PG0177	2017-07-25 09:25:00+03	2017-07-25 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-25 09:26:00+03	2017-07-25 10:20:00+03
28856	PG0177	2017-09-11 09:25:00+03	2017-09-11 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28857	PG0177	2017-08-03 09:25:00+03	2017-08-03 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-03 09:27:00+03	2017-08-03 10:22:00+03
28858	PG0177	2017-07-23 09:25:00+03	2017-07-23 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-23 09:28:00+03	2017-07-23 10:22:00+03
28859	PG0177	2017-07-19 09:25:00+03	2017-07-19 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-19 09:29:00+03	2017-07-19 10:24:00+03
28860	PG0177	2017-09-12 09:25:00+03	2017-09-12 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28861	PG0177	2017-07-17 09:25:00+03	2017-07-17 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-17 12:27:00+03	2017-07-17 13:23:00+03
28862	PG0177	2017-08-18 09:25:00+03	2017-08-18 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28863	PG0177	2017-08-19 09:25:00+03	2017-08-19 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28864	PG0177	2017-07-24 09:25:00+03	2017-07-24 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-24 09:29:00+03	2017-07-24 10:24:00+03
28865	PG0177	2017-08-06 09:25:00+03	2017-08-06 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-06 09:28:00+03	2017-08-06 10:23:00+03
28866	PG0177	2017-08-07 09:25:00+03	2017-08-07 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-07 09:31:00+03	2017-08-07 10:26:00+03
28867	PG0177	2017-08-09 09:25:00+03	2017-08-09 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-09 09:25:00+03	2017-08-09 10:21:00+03
28868	PG0177	2017-07-22 09:25:00+03	2017-07-22 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-22 09:26:00+03	2017-07-22 10:20:00+03
28869	PG0177	2017-07-30 09:25:00+03	2017-07-30 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-30 09:29:00+03	2017-07-30 10:24:00+03
28870	PG0177	2017-07-27 09:25:00+03	2017-07-27 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-27 09:26:00+03	2017-07-27 10:22:00+03
28871	PG0177	2017-08-11 09:25:00+03	2017-08-11 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-11 09:29:00+03	2017-08-11 10:24:00+03
28872	PG0177	2017-08-16 09:25:00+03	2017-08-16 10:20:00+03	CSY	VKO	On Time	CR2	\N	\N
28873	PG0177	2017-07-26 09:25:00+03	2017-07-26 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-26 09:28:00+03	2017-07-26 10:24:00+03
28874	PG0177	2017-07-29 09:25:00+03	2017-07-29 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-29 09:27:00+03	2017-07-29 10:22:00+03
28875	PG0177	2017-08-04 09:25:00+03	2017-08-04 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-04 09:28:00+03	2017-08-04 10:23:00+03
28876	PG0177	2017-08-27 09:25:00+03	2017-08-27 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28877	PG0177	2017-08-15 09:25:00+03	2017-08-15 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-15 09:29:00+03	2017-08-15 10:24:00+03
28878	PG0177	2017-08-12 09:25:00+03	2017-08-12 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-12 09:27:00+03	2017-08-12 10:21:00+03
28879	PG0177	2017-08-21 09:25:00+03	2017-08-21 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28880	PG0177	2017-09-09 09:25:00+03	2017-09-09 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28881	PG0177	2017-08-26 09:25:00+03	2017-08-26 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28882	PG0177	2017-09-10 09:25:00+03	2017-09-10 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28883	PG0177	2017-07-16 09:25:00+03	2017-07-16 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-16 09:29:00+03	2017-07-16 10:24:00+03
28884	PG0177	2017-07-20 09:25:00+03	2017-07-20 10:20:00+03	CSY	VKO	Arrived	CR2	2017-07-20 09:29:00+03	2017-07-20 10:24:00+03
28885	PG0177	2017-08-13 09:25:00+03	2017-08-13 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-13 09:26:00+03	2017-08-13 10:20:00+03
28886	PG0177	2017-09-03 09:25:00+03	2017-09-03 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28887	PG0177	2017-08-10 09:25:00+03	2017-08-10 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-10 09:27:00+03	2017-08-10 10:23:00+03
28888	PG0177	2017-08-25 09:25:00+03	2017-08-25 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28889	PG0177	2017-08-01 09:25:00+03	2017-08-01 10:20:00+03	CSY	VKO	Arrived	CR2	2017-08-01 09:25:00+03	2017-08-01 10:21:00+03
28890	PG0177	2017-09-06 09:25:00+03	2017-09-06 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28891	PG0177	2017-08-24 09:25:00+03	2017-08-24 10:20:00+03	CSY	VKO	Scheduled	CR2	\N	\N
28892	PG0242	2017-09-01 12:05:00+03	2017-09-01 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28893	PG0242	2017-08-11 12:05:00+03	2017-08-11 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-11 12:09:00+03	2017-08-11 12:59:00+03
28894	PG0242	2017-08-26 12:05:00+03	2017-08-26 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28895	PG0242	2017-07-22 12:05:00+03	2017-07-22 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-22 14:57:00+03	2017-07-22 15:47:00+03
28896	PG0242	2017-08-31 12:05:00+03	2017-08-31 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28897	PG0242	2017-08-18 12:05:00+03	2017-08-18 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28898	PG0242	2017-08-08 12:05:00+03	2017-08-08 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-08 12:07:00+03	2017-08-08 12:57:00+03
28899	PG0242	2017-09-11 12:05:00+03	2017-09-11 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28900	PG0242	2017-08-04 12:05:00+03	2017-08-04 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-04 12:09:00+03	2017-08-04 12:59:00+03
28901	PG0242	2017-08-24 12:05:00+03	2017-08-24 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28902	PG0242	2017-08-06 12:05:00+03	2017-08-06 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-06 12:08:00+03	2017-08-06 12:58:00+03
28903	PG0242	2017-09-09 12:05:00+03	2017-09-09 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28904	PG0242	2017-07-21 12:05:00+03	2017-07-21 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-21 12:08:00+03	2017-07-21 12:58:00+03
28905	PG0242	2017-09-03 12:05:00+03	2017-09-03 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28906	PG0242	2017-09-14 12:05:00+03	2017-09-14 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28907	PG0242	2017-08-12 12:05:00+03	2017-08-12 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-12 12:08:00+03	2017-08-12 12:58:00+03
28908	PG0242	2017-08-27 12:05:00+03	2017-08-27 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28909	PG0242	2017-08-15 12:05:00+03	2017-08-15 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-15 15:23:00+03	2017-08-15 16:13:00+03
28910	PG0242	2017-08-16 12:05:00+03	2017-08-16 12:55:00+03	CSY	SVO	On Time	SU9	\N	\N
28911	PG0242	2017-09-02 12:05:00+03	2017-09-02 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28912	PG0242	2017-07-19 12:05:00+03	2017-07-19 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-19 12:08:00+03	2017-07-19 12:58:00+03
28913	PG0242	2017-07-18 12:05:00+03	2017-07-18 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-18 15:50:00+03	2017-07-18 16:41:00+03
28914	PG0242	2017-08-23 12:05:00+03	2017-08-23 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28915	PG0242	2017-07-25 12:05:00+03	2017-07-25 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-25 12:07:00+03	2017-07-25 12:57:00+03
28916	PG0242	2017-08-17 12:05:00+03	2017-08-17 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28917	PG0242	2017-08-14 12:05:00+03	2017-08-14 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-14 12:09:00+03	2017-08-14 12:58:00+03
28918	PG0242	2017-08-20 12:05:00+03	2017-08-20 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28919	PG0242	2017-07-30 12:05:00+03	2017-07-30 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-30 12:06:00+03	2017-07-30 12:56:00+03
28920	PG0242	2017-09-12 12:05:00+03	2017-09-12 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28921	PG0242	2017-08-09 12:05:00+03	2017-08-09 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-09 12:12:00+03	2017-08-09 13:02:00+03
28922	PG0242	2017-08-22 12:05:00+03	2017-08-22 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28923	PG0242	2017-07-27 12:05:00+03	2017-07-27 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-27 12:10:00+03	2017-07-27 13:00:00+03
28924	PG0242	2017-09-05 12:05:00+03	2017-09-05 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28925	PG0242	2017-09-07 12:05:00+03	2017-09-07 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28926	PG0242	2017-08-01 12:05:00+03	2017-08-01 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-01 12:08:00+03	2017-08-01 12:58:00+03
28927	PG0242	2017-08-21 12:05:00+03	2017-08-21 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28928	PG0242	2017-08-07 12:05:00+03	2017-08-07 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-07 12:08:00+03	2017-08-07 12:58:00+03
28929	PG0242	2017-07-20 12:05:00+03	2017-07-20 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-20 12:07:00+03	2017-07-20 12:58:00+03
28930	PG0242	2017-08-30 12:05:00+03	2017-08-30 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28931	PG0242	2017-08-25 12:05:00+03	2017-08-25 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28932	PG0242	2017-07-28 12:05:00+03	2017-07-28 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-28 12:05:00+03	2017-07-28 12:55:00+03
28933	PG0242	2017-08-05 12:05:00+03	2017-08-05 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-05 12:06:00+03	2017-08-05 12:56:00+03
28934	PG0242	2017-08-03 12:05:00+03	2017-08-03 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-03 12:10:00+03	2017-08-03 13:00:00+03
28935	PG0242	2017-07-16 12:05:00+03	2017-07-16 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-16 12:09:00+03	2017-07-16 12:59:00+03
28936	PG0242	2017-09-13 12:05:00+03	2017-09-13 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28937	PG0242	2017-09-06 12:05:00+03	2017-09-06 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28938	PG0242	2017-08-13 12:05:00+03	2017-08-13 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-13 12:07:00+03	2017-08-13 12:57:00+03
28939	PG0242	2017-07-17 12:05:00+03	2017-07-17 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-17 12:08:00+03	2017-07-17 12:58:00+03
28940	PG0242	2017-07-31 12:05:00+03	2017-07-31 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-31 12:07:00+03	2017-07-31 12:57:00+03
28941	PG0242	2017-08-10 12:05:00+03	2017-08-10 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-10 12:08:00+03	2017-08-10 12:58:00+03
28942	PG0242	2017-07-24 12:05:00+03	2017-07-24 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-24 12:07:00+03	2017-07-24 12:57:00+03
28943	PG0242	2017-08-02 12:05:00+03	2017-08-02 12:55:00+03	CSY	SVO	Arrived	SU9	2017-08-02 12:09:00+03	2017-08-02 13:00:00+03
28944	PG0242	2017-08-19 12:05:00+03	2017-08-19 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28945	PG0242	2017-08-29 12:05:00+03	2017-08-29 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28946	PG0242	2017-07-26 12:05:00+03	2017-07-26 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-26 15:32:00+03	2017-07-26 16:22:00+03
28947	PG0242	2017-09-04 12:05:00+03	2017-09-04 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28948	PG0242	2017-07-23 12:05:00+03	2017-07-23 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-23 15:57:00+03	2017-07-23 16:47:00+03
28949	PG0242	2017-07-29 12:05:00+03	2017-07-29 12:55:00+03	CSY	SVO	Arrived	SU9	2017-07-29 12:07:00+03	2017-07-29 12:57:00+03
28950	PG0242	2017-09-10 12:05:00+03	2017-09-10 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28951	PG0242	2017-09-08 12:05:00+03	2017-09-08 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28952	PG0242	2017-08-28 12:05:00+03	2017-08-28 12:55:00+03	CSY	SVO	Scheduled	SU9	\N	\N
28953	PG0489	2017-08-11 09:50:00+03	2017-08-11 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-11 09:52:00+03	2017-08-11 11:16:00+03
28954	PG0489	2017-08-28 09:50:00+03	2017-08-28 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28955	PG0489	2017-09-01 09:50:00+03	2017-09-01 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28956	PG0489	2017-07-17 09:50:00+03	2017-07-17 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-17 09:52:00+03	2017-07-17 11:18:00+03
28957	PG0489	2017-08-17 09:50:00+03	2017-08-17 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28958	PG0489	2017-08-09 09:50:00+03	2017-08-09 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-09 13:01:00+03	2017-08-09 14:27:00+03
28959	PG0489	2017-08-16 09:50:00+03	2017-08-16 11:15:00+03	CSY	LED	On Time	SU9	\N	\N
28960	PG0489	2017-08-15 09:50:00+03	2017-08-15 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-15 12:52:00+03	2017-08-15 14:18:00+03
28961	PG0489	2017-08-10 09:50:00+03	2017-08-10 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-10 09:57:00+03	2017-08-10 11:22:00+03
28962	PG0489	2017-07-31 09:50:00+03	2017-07-31 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-31 09:52:00+03	2017-07-31 11:18:00+03
28963	PG0489	2017-09-09 09:50:00+03	2017-09-09 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28964	PG0489	2017-07-28 09:50:00+03	2017-07-28 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-28 09:52:00+03	2017-07-28 11:17:00+03
28965	PG0489	2017-08-07 09:50:00+03	2017-08-07 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-07 09:51:00+03	2017-08-07 11:17:00+03
28966	PG0489	2017-08-03 09:50:00+03	2017-08-03 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-03 09:54:00+03	2017-08-03 11:19:00+03
28967	PG0489	2017-08-22 09:50:00+03	2017-08-22 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28968	PG0489	2017-07-20 09:50:00+03	2017-07-20 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-20 09:53:00+03	2017-07-20 11:18:00+03
28969	PG0489	2017-08-24 09:50:00+03	2017-08-24 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28970	PG0489	2017-08-20 09:50:00+03	2017-08-20 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28971	PG0489	2017-08-23 09:50:00+03	2017-08-23 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28972	PG0489	2017-09-02 09:50:00+03	2017-09-02 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28973	PG0489	2017-07-21 09:50:00+03	2017-07-21 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-21 09:53:00+03	2017-07-21 11:18:00+03
28974	PG0489	2017-08-18 09:50:00+03	2017-08-18 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28975	PG0489	2017-08-05 09:50:00+03	2017-08-05 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-05 09:50:00+03	2017-08-05 11:15:00+03
28976	PG0489	2017-07-29 09:50:00+03	2017-07-29 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-29 09:52:00+03	2017-07-29 11:17:00+03
28977	PG0489	2017-09-14 09:50:00+03	2017-09-14 11:15:00+03	CSY	LED	Cancelled	SU9	\N	\N
28978	PG0489	2017-09-05 09:50:00+03	2017-09-05 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28979	PG0489	2017-07-26 09:50:00+03	2017-07-26 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-26 09:56:00+03	2017-07-26 11:20:00+03
28980	PG0489	2017-08-14 09:50:00+03	2017-08-14 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-14 09:52:00+03	2017-08-14 11:18:00+03
28981	PG0489	2017-08-25 09:50:00+03	2017-08-25 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28982	PG0489	2017-07-23 09:50:00+03	2017-07-23 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-23 09:55:00+03	2017-07-23 11:21:00+03
28983	PG0489	2017-08-19 09:50:00+03	2017-08-19 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28984	PG0489	2017-07-22 09:50:00+03	2017-07-22 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-22 13:22:00+03	2017-07-22 14:47:00+03
28985	PG0489	2017-08-01 09:50:00+03	2017-08-01 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-01 09:51:00+03	2017-08-01 11:15:00+03
28986	PG0489	2017-08-13 09:50:00+03	2017-08-13 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-13 09:54:00+03	2017-08-13 11:19:00+03
28987	PG0489	2017-08-29 09:50:00+03	2017-08-29 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28988	PG0489	2017-09-11 09:50:00+03	2017-09-11 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28989	PG0489	2017-09-04 09:50:00+03	2017-09-04 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28990	PG0489	2017-07-30 09:50:00+03	2017-07-30 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-30 09:52:00+03	2017-07-30 11:17:00+03
28991	PG0489	2017-09-08 09:50:00+03	2017-09-08 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28992	PG0489	2017-08-08 09:50:00+03	2017-08-08 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-08 09:54:00+03	2017-08-08 11:18:00+03
28993	PG0489	2017-07-18 09:50:00+03	2017-07-18 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-18 09:52:00+03	2017-07-18 11:15:00+03
28994	PG0489	2017-09-13 09:50:00+03	2017-09-13 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28995	PG0489	2017-07-19 09:50:00+03	2017-07-19 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-19 09:51:00+03	2017-07-19 11:17:00+03
28996	PG0489	2017-08-30 09:50:00+03	2017-08-30 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28997	PG0489	2017-08-21 09:50:00+03	2017-08-21 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28998	PG0489	2017-09-07 09:50:00+03	2017-09-07 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
28999	PG0489	2017-08-06 09:50:00+03	2017-08-06 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-06 09:52:00+03	2017-08-06 11:17:00+03
29000	PG0489	2017-08-12 09:50:00+03	2017-08-12 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-12 09:52:00+03	2017-08-12 11:16:00+03
29001	PG0489	2017-07-16 09:50:00+03	2017-07-16 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-16 09:52:00+03	2017-07-16 11:16:00+03
29002	PG0489	2017-09-03 09:50:00+03	2017-09-03 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29003	PG0489	2017-08-27 09:50:00+03	2017-08-27 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29004	PG0489	2017-08-31 09:50:00+03	2017-08-31 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29005	PG0489	2017-08-02 09:50:00+03	2017-08-02 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-02 09:52:00+03	2017-08-02 11:18:00+03
29006	PG0489	2017-07-27 09:50:00+03	2017-07-27 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-27 09:54:00+03	2017-07-27 11:19:00+03
29007	PG0489	2017-07-24 09:50:00+03	2017-07-24 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-24 09:54:00+03	2017-07-24 11:20:00+03
29008	PG0489	2017-08-26 09:50:00+03	2017-08-26 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29009	PG0489	2017-09-10 09:50:00+03	2017-09-10 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29010	PG0489	2017-07-25 09:50:00+03	2017-07-25 11:15:00+03	CSY	LED	Arrived	SU9	2017-07-25 09:53:00+03	2017-07-25 11:18:00+03
29011	PG0489	2017-09-06 09:50:00+03	2017-09-06 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29012	PG0489	2017-08-04 09:50:00+03	2017-08-04 11:15:00+03	CSY	LED	Arrived	SU9	2017-08-04 09:52:00+03	2017-08-04 11:17:00+03
29013	PG0489	2017-09-12 09:50:00+03	2017-09-12 11:15:00+03	CSY	LED	Scheduled	SU9	\N	\N
29014	PG0666	2017-08-23 09:15:00+03	2017-08-23 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29015	PG0666	2017-09-12 09:15:00+03	2017-09-12 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29016	PG0666	2017-08-10 09:15:00+03	2017-08-10 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-10 09:21:00+03	2017-08-10 12:05:00+03
29017	PG0666	2017-09-01 09:15:00+03	2017-09-01 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29018	PG0666	2017-08-29 09:15:00+03	2017-08-29 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29019	PG0666	2017-07-31 09:15:00+03	2017-07-31 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-31 09:16:00+03	2017-07-31 11:59:00+03
29020	PG0666	2017-07-19 09:15:00+03	2017-07-19 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-19 09:19:00+03	2017-07-19 12:06:00+03
29021	PG0666	2017-09-09 09:15:00+03	2017-09-09 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29022	PG0666	2017-08-15 09:15:00+03	2017-08-15 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-15 09:17:00+03	2017-08-15 12:00:00+03
29023	PG0666	2017-07-25 09:15:00+03	2017-07-25 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-25 09:18:00+03	2017-07-25 12:06:00+03
29024	PG0666	2017-09-06 09:15:00+03	2017-09-06 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29025	PG0666	2017-08-21 09:15:00+03	2017-08-21 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29026	PG0666	2017-08-05 09:15:00+03	2017-08-05 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-05 09:18:00+03	2017-08-05 12:02:00+03
29027	PG0666	2017-08-01 09:15:00+03	2017-08-01 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-01 09:17:00+03	2017-08-01 11:59:00+03
29028	PG0666	2017-08-20 09:15:00+03	2017-08-20 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29029	PG0666	2017-08-06 09:15:00+03	2017-08-06 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-06 09:17:00+03	2017-08-06 12:03:00+03
29030	PG0666	2017-07-20 09:15:00+03	2017-07-20 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-20 09:18:00+03	2017-07-20 12:07:00+03
29031	PG0666	2017-07-24 09:15:00+03	2017-07-24 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-24 09:20:00+03	2017-07-24 12:06:00+03
29032	PG0666	2017-07-26 09:15:00+03	2017-07-26 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-26 09:16:00+03	2017-07-26 11:58:00+03
29033	PG0666	2017-08-11 09:15:00+03	2017-08-11 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-11 09:19:00+03	2017-08-11 12:04:00+03
29034	PG0666	2017-08-09 09:15:00+03	2017-08-09 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-09 09:18:00+03	2017-08-09 12:06:00+03
29035	PG0666	2017-08-26 09:15:00+03	2017-08-26 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29036	PG0666	2017-07-30 09:15:00+03	2017-07-30 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-30 09:18:00+03	2017-07-30 12:01:00+03
29037	PG0666	2017-07-16 09:15:00+03	2017-07-16 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-16 09:21:00+03	2017-07-16 12:07:00+03
29038	PG0666	2017-08-27 09:15:00+03	2017-08-27 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29039	PG0666	2017-09-05 09:15:00+03	2017-09-05 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29040	PG0666	2017-08-14 09:15:00+03	2017-08-14 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-14 09:18:00+03	2017-08-14 12:05:00+03
29041	PG0666	2017-08-31 09:15:00+03	2017-08-31 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29042	PG0666	2017-08-17 09:15:00+03	2017-08-17 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29043	PG0666	2017-07-18 09:15:00+03	2017-07-18 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-18 09:18:00+03	2017-07-18 12:02:00+03
29044	PG0666	2017-07-21 09:15:00+03	2017-07-21 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-21 09:17:00+03	2017-07-21 12:02:00+03
29045	PG0666	2017-08-24 09:15:00+03	2017-08-24 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29046	PG0666	2017-08-25 09:15:00+03	2017-08-25 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29047	PG0666	2017-08-02 09:15:00+03	2017-08-02 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-02 09:16:00+03	2017-08-02 11:59:00+03
29048	PG0666	2017-08-19 09:15:00+03	2017-08-19 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29049	PG0666	2017-08-04 09:15:00+03	2017-08-04 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-04 09:16:00+03	2017-08-04 11:59:00+03
29050	PG0666	2017-07-27 09:15:00+03	2017-07-27 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-27 09:20:00+03	2017-07-27 12:04:00+03
29051	PG0666	2017-09-08 09:15:00+03	2017-09-08 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29052	PG0666	2017-09-10 09:15:00+03	2017-09-10 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29053	PG0666	2017-09-11 09:15:00+03	2017-09-11 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29054	PG0666	2017-09-03 09:15:00+03	2017-09-03 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29055	PG0666	2017-08-22 09:15:00+03	2017-08-22 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29056	PG0666	2017-07-23 09:15:00+03	2017-07-23 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-23 09:16:00+03	2017-07-23 12:01:00+03
29057	PG0666	2017-08-28 09:15:00+03	2017-08-28 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29058	PG0666	2017-08-12 09:15:00+03	2017-08-12 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-12 09:16:00+03	2017-08-12 12:02:00+03
29059	PG0666	2017-09-13 09:15:00+03	2017-09-13 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29060	PG0666	2017-07-29 09:15:00+03	2017-07-29 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-29 09:21:00+03	2017-07-29 12:05:00+03
29061	PG0666	2017-08-07 09:15:00+03	2017-08-07 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-07 09:16:00+03	2017-08-07 12:03:00+03
29062	PG0666	2017-09-04 09:15:00+03	2017-09-04 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29063	PG0666	2017-08-30 09:15:00+03	2017-08-30 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29064	PG0666	2017-09-14 09:15:00+03	2017-09-14 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29065	PG0666	2017-08-08 09:15:00+03	2017-08-08 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-08 09:20:00+03	2017-08-08 12:06:00+03
29066	PG0666	2017-09-07 09:15:00+03	2017-09-07 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29067	PG0666	2017-08-16 09:15:00+03	2017-08-16 12:00:00+03	CSY	VOG	On Time	CN1	\N	\N
29068	PG0666	2017-07-22 09:15:00+03	2017-07-22 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-22 09:16:00+03	2017-07-22 11:57:00+03
29069	PG0666	2017-09-02 09:15:00+03	2017-09-02 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29070	PG0666	2017-08-13 09:15:00+03	2017-08-13 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-13 09:17:00+03	2017-08-13 12:03:00+03
29071	PG0666	2017-07-28 09:15:00+03	2017-07-28 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-28 09:18:00+03	2017-07-28 12:01:00+03
29072	PG0666	2017-07-17 09:15:00+03	2017-07-17 12:00:00+03	CSY	VOG	Arrived	CN1	2017-07-17 09:18:00+03	2017-07-17 12:00:00+03
29073	PG0666	2017-08-03 09:15:00+03	2017-08-03 12:00:00+03	CSY	VOG	Arrived	CN1	2017-08-03 09:18:00+03	2017-08-03 12:06:00+03
29074	PG0666	2017-08-18 09:15:00+03	2017-08-18 12:00:00+03	CSY	VOG	Scheduled	CN1	\N	\N
29075	PG0254	2017-07-22 13:30:00+03	2017-07-22 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-22 13:32:00+03	2017-07-22 13:57:00+03
29076	PG0254	2017-09-11 13:30:00+03	2017-09-11 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29077	PG0254	2017-09-09 13:30:00+03	2017-09-09 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29078	PG0254	2017-09-03 13:30:00+03	2017-09-03 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29079	PG0254	2017-08-26 13:30:00+03	2017-08-26 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29080	PG0254	2017-07-21 13:30:00+03	2017-07-21 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-21 16:38:00+03	2017-07-21 17:03:00+03
29081	PG0254	2017-08-15 13:30:00+03	2017-08-15 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-15 13:33:00+03	2017-08-15 13:58:00+03
29082	PG0254	2017-07-29 13:30:00+03	2017-07-29 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-29 13:31:00+03	2017-07-29 13:56:00+03
29083	PG0254	2017-08-06 13:30:00+03	2017-08-06 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-06 13:32:00+03	2017-08-06 13:57:00+03
29084	PG0254	2017-08-01 13:30:00+03	2017-08-01 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-01 13:32:00+03	2017-08-01 13:57:00+03
29085	PG0254	2017-07-19 13:30:00+03	2017-07-19 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-19 13:33:00+03	2017-07-19 13:58:00+03
29086	PG0254	2017-09-12 13:30:00+03	2017-09-12 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29087	PG0254	2017-07-23 13:30:00+03	2017-07-23 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-23 16:21:00+03	2017-07-23 16:46:00+03
29088	PG0254	2017-08-31 13:30:00+03	2017-08-31 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29089	PG0254	2017-08-25 13:30:00+03	2017-08-25 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29090	PG0254	2017-09-02 13:30:00+03	2017-09-02 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29091	PG0254	2017-08-23 13:30:00+03	2017-08-23 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29092	PG0254	2017-09-14 13:30:00+03	2017-09-14 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29093	PG0254	2017-07-25 13:30:00+03	2017-07-25 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-25 13:33:00+03	2017-07-25 13:58:00+03
29094	PG0254	2017-09-05 13:30:00+03	2017-09-05 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29095	PG0254	2017-08-04 13:30:00+03	2017-08-04 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-04 13:34:00+03	2017-08-04 13:59:00+03
29096	PG0254	2017-08-12 13:30:00+03	2017-08-12 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-12 13:33:00+03	2017-08-12 13:58:00+03
29097	PG0254	2017-08-08 13:30:00+03	2017-08-08 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-08 13:33:00+03	2017-08-08 13:58:00+03
29098	PG0254	2017-08-05 13:30:00+03	2017-08-05 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-05 13:35:00+03	2017-08-05 14:00:00+03
29099	PG0254	2017-09-08 13:30:00+03	2017-09-08 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29100	PG0254	2017-08-11 13:30:00+03	2017-08-11 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-11 13:35:00+03	2017-08-11 14:01:00+03
29101	PG0254	2017-09-10 13:30:00+03	2017-09-10 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29102	PG0254	2017-08-19 13:30:00+03	2017-08-19 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29103	PG0254	2017-08-10 13:30:00+03	2017-08-10 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-10 13:33:00+03	2017-08-10 13:58:00+03
29104	PG0254	2017-09-06 13:30:00+03	2017-09-06 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29105	PG0254	2017-08-13 13:30:00+03	2017-08-13 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-13 13:32:00+03	2017-08-13 13:57:00+03
29106	PG0254	2017-08-21 13:30:00+03	2017-08-21 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29107	PG0254	2017-07-16 13:30:00+03	2017-07-16 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-16 13:34:00+03	2017-07-16 13:59:00+03
29108	PG0254	2017-08-28 13:30:00+03	2017-08-28 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29109	PG0254	2017-08-07 13:30:00+03	2017-08-07 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-07 13:30:00+03	2017-08-07 13:55:00+03
29110	PG0254	2017-08-20 13:30:00+03	2017-08-20 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29111	PG0254	2017-09-04 13:30:00+03	2017-09-04 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29112	PG0254	2017-08-14 13:30:00+03	2017-08-14 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-14 13:36:00+03	2017-08-14 14:02:00+03
29113	PG0254	2017-09-01 13:30:00+03	2017-09-01 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29114	PG0254	2017-07-24 13:30:00+03	2017-07-24 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-24 13:34:00+03	2017-07-24 13:59:00+03
29115	PG0254	2017-07-18 13:30:00+03	2017-07-18 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-18 13:34:00+03	2017-07-18 13:59:00+03
29116	PG0254	2017-08-17 13:30:00+03	2017-08-17 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29117	PG0254	2017-07-28 13:30:00+03	2017-07-28 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-28 13:31:00+03	2017-07-28 13:56:00+03
29118	PG0254	2017-08-22 13:30:00+03	2017-08-22 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29119	PG0254	2017-09-07 13:30:00+03	2017-09-07 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29120	PG0254	2017-09-13 13:30:00+03	2017-09-13 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29121	PG0254	2017-08-30 13:30:00+03	2017-08-30 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29122	PG0254	2017-08-03 13:30:00+03	2017-08-03 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-03 13:33:00+03	2017-08-03 13:58:00+03
29123	PG0254	2017-08-24 13:30:00+03	2017-08-24 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29124	PG0254	2017-07-27 13:30:00+03	2017-07-27 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-27 13:35:00+03	2017-07-27 14:00:00+03
29125	PG0254	2017-07-17 13:30:00+03	2017-07-17 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-17 13:33:00+03	2017-07-17 13:58:00+03
29126	PG0254	2017-07-31 13:30:00+03	2017-07-31 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-31 13:31:00+03	2017-07-31 13:56:00+03
29127	PG0254	2017-07-20 13:30:00+03	2017-07-20 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-20 13:32:00+03	2017-07-20 13:57:00+03
29128	PG0254	2017-08-29 13:30:00+03	2017-08-29 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29129	PG0254	2017-08-09 13:30:00+03	2017-08-09 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-09 13:33:00+03	2017-08-09 13:58:00+03
29130	PG0254	2017-08-16 13:30:00+03	2017-08-16 13:55:00+03	CSY	NBC	On Time	CR2	\N	\N
29131	PG0254	2017-08-02 13:30:00+03	2017-08-02 13:55:00+03	CSY	NBC	Arrived	CR2	2017-08-02 13:33:00+03	2017-08-02 13:58:00+03
29132	PG0254	2017-08-27 13:30:00+03	2017-08-27 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29133	PG0254	2017-08-18 13:30:00+03	2017-08-18 13:55:00+03	CSY	NBC	Scheduled	CR2	\N	\N
29134	PG0254	2017-07-26 13:30:00+03	2017-07-26 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-26 13:34:00+03	2017-07-26 13:59:00+03
29135	PG0254	2017-07-30 13:30:00+03	2017-07-30 13:55:00+03	CSY	NBC	Arrived	CR2	2017-07-30 13:34:00+03	2017-07-30 13:59:00+03
29136	PG0197	2017-07-29 17:05:00+03	2017-07-29 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-29 17:08:00+03	2017-07-29 18:36:00+03
29137	PG0197	2017-09-12 17:05:00+03	2017-09-12 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29138	PG0197	2017-07-24 17:05:00+03	2017-07-24 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-24 17:07:00+03	2017-07-24 18:36:00+03
29139	PG0197	2017-08-24 17:05:00+03	2017-08-24 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29140	PG0197	2017-07-20 17:05:00+03	2017-07-20 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-20 17:07:00+03	2017-07-20 18:36:00+03
29141	PG0197	2017-08-12 17:05:00+03	2017-08-12 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-12 17:11:00+03	2017-08-12 18:40:00+03
29142	PG0197	2017-07-19 17:05:00+03	2017-07-19 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-19 17:08:00+03	2017-07-19 18:37:00+03
29143	PG0197	2017-08-29 17:05:00+03	2017-08-29 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29144	PG0197	2017-09-09 17:05:00+03	2017-09-09 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29145	PG0197	2017-08-15 17:05:00+03	2017-08-15 18:35:00+03	KGD	DME	Departed	SU9	2017-08-15 17:09:00+03	\N
29146	PG0197	2017-08-07 17:05:00+03	2017-08-07 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-07 17:08:00+03	2017-08-07 18:39:00+03
29147	PG0197	2017-07-27 17:05:00+03	2017-07-27 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-27 17:09:00+03	2017-07-27 18:40:00+03
29148	PG0197	2017-08-09 17:05:00+03	2017-08-09 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-09 17:08:00+03	2017-08-09 18:40:00+03
29149	PG0197	2017-07-30 17:05:00+03	2017-07-30 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-30 20:22:00+03	2017-07-30 21:51:00+03
29150	PG0197	2017-07-16 17:05:00+03	2017-07-16 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-16 17:07:00+03	2017-07-16 18:37:00+03
29151	PG0197	2017-07-22 17:05:00+03	2017-07-22 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-22 17:12:00+03	2017-07-22 18:42:00+03
29152	PG0197	2017-08-31 17:05:00+03	2017-08-31 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29153	PG0197	2017-08-18 17:05:00+03	2017-08-18 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29154	PG0197	2017-09-07 17:05:00+03	2017-09-07 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29155	PG0197	2017-09-02 17:05:00+03	2017-09-02 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29156	PG0197	2017-08-22 17:05:00+03	2017-08-22 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29157	PG0197	2017-07-17 17:05:00+03	2017-07-17 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-17 17:05:00+03	2017-07-17 18:35:00+03
29158	PG0197	2017-07-21 17:05:00+03	2017-07-21 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-21 17:06:00+03	2017-07-21 18:36:00+03
29159	PG0197	2017-09-14 17:05:00+03	2017-09-14 18:35:00+03	KGD	DME	Cancelled	SU9	\N	\N
29160	PG0197	2017-07-31 17:05:00+03	2017-07-31 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-31 17:09:00+03	2017-07-31 18:37:00+03
29161	PG0197	2017-08-16 17:05:00+03	2017-08-16 18:35:00+03	KGD	DME	On Time	SU9	\N	\N
29162	PG0197	2017-08-03 17:05:00+03	2017-08-03 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-03 17:08:00+03	2017-08-03 18:38:00+03
29163	PG0197	2017-08-02 17:05:00+03	2017-08-02 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-02 17:09:00+03	2017-08-02 18:39:00+03
29164	PG0197	2017-08-01 17:05:00+03	2017-08-01 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-01 17:07:00+03	2017-08-01 18:36:00+03
29165	PG0197	2017-08-27 17:05:00+03	2017-08-27 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29166	PG0197	2017-09-01 17:05:00+03	2017-09-01 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29167	PG0197	2017-09-03 17:05:00+03	2017-09-03 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29168	PG0197	2017-09-05 17:05:00+03	2017-09-05 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29169	PG0197	2017-07-26 17:05:00+03	2017-07-26 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-26 17:10:00+03	2017-07-26 18:39:00+03
29170	PG0197	2017-07-28 17:05:00+03	2017-07-28 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-28 17:09:00+03	2017-07-28 18:39:00+03
29171	PG0197	2017-08-28 17:05:00+03	2017-08-28 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29172	PG0197	2017-09-06 17:05:00+03	2017-09-06 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29173	PG0197	2017-08-26 17:05:00+03	2017-08-26 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29174	PG0197	2017-08-17 17:05:00+03	2017-08-17 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29175	PG0197	2017-08-13 17:05:00+03	2017-08-13 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-13 17:09:00+03	2017-08-13 18:38:00+03
29176	PG0197	2017-08-14 17:05:00+03	2017-08-14 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-14 17:07:00+03	2017-08-14 18:37:00+03
29177	PG0197	2017-08-10 17:05:00+03	2017-08-10 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-10 20:13:00+03	2017-08-10 21:44:00+03
29178	PG0197	2017-07-18 17:05:00+03	2017-07-18 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-18 17:08:00+03	2017-07-18 18:40:00+03
29179	PG0197	2017-08-30 17:05:00+03	2017-08-30 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29180	PG0197	2017-09-13 17:05:00+03	2017-09-13 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29181	PG0197	2017-08-23 17:05:00+03	2017-08-23 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29182	PG0197	2017-07-25 17:05:00+03	2017-07-25 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-25 17:07:00+03	2017-07-25 18:37:00+03
29183	PG0197	2017-08-08 17:05:00+03	2017-08-08 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-08 17:08:00+03	2017-08-08 18:39:00+03
29184	PG0197	2017-08-19 17:05:00+03	2017-08-19 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29185	PG0197	2017-09-11 17:05:00+03	2017-09-11 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29186	PG0197	2017-08-11 17:05:00+03	2017-08-11 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-11 17:07:00+03	2017-08-11 18:38:00+03
29187	PG0197	2017-08-04 17:05:00+03	2017-08-04 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-04 17:07:00+03	2017-08-04 18:37:00+03
29188	PG0197	2017-09-10 17:05:00+03	2017-09-10 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29189	PG0197	2017-08-06 17:05:00+03	2017-08-06 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-06 17:05:00+03	2017-08-06 18:35:00+03
29190	PG0197	2017-08-25 17:05:00+03	2017-08-25 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29191	PG0197	2017-09-04 17:05:00+03	2017-09-04 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29192	PG0197	2017-08-21 17:05:00+03	2017-08-21 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29193	PG0197	2017-07-23 17:05:00+03	2017-07-23 18:35:00+03	KGD	DME	Arrived	SU9	2017-07-23 17:07:00+03	2017-07-23 18:36:00+03
29194	PG0197	2017-08-20 17:05:00+03	2017-08-20 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29195	PG0197	2017-08-05 17:05:00+03	2017-08-05 18:35:00+03	KGD	DME	Arrived	SU9	2017-08-05 17:07:00+03	2017-08-05 18:37:00+03
29196	PG0197	2017-09-08 17:05:00+03	2017-09-08 18:35:00+03	KGD	DME	Scheduled	SU9	\N	\N
29197	PG0506	2017-07-16 12:00:00+03	2017-07-16 13:30:00+03	KGD	SVO	Arrived	733	2017-07-16 12:03:00+03	2017-07-16 13:31:00+03
29198	PG0506	2017-08-17 12:00:00+03	2017-08-17 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29199	PG0506	2017-09-12 12:00:00+03	2017-09-12 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29200	PG0506	2017-08-16 12:00:00+03	2017-08-16 13:30:00+03	KGD	SVO	On Time	733	\N	\N
29201	PG0506	2017-09-01 12:00:00+03	2017-09-01 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29202	PG0506	2017-08-30 12:00:00+03	2017-08-30 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29203	PG0506	2017-07-25 12:00:00+03	2017-07-25 13:30:00+03	KGD	SVO	Arrived	733	2017-07-25 12:07:00+03	2017-07-25 13:37:00+03
29204	PG0506	2017-08-03 12:00:00+03	2017-08-03 13:30:00+03	KGD	SVO	Arrived	733	2017-08-03 12:00:00+03	2017-08-03 13:28:00+03
29205	PG0506	2017-09-09 12:00:00+03	2017-09-09 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29206	PG0506	2017-07-28 12:00:00+03	2017-07-28 13:30:00+03	KGD	SVO	Arrived	733	2017-07-28 12:03:00+03	2017-07-28 13:33:00+03
29207	PG0506	2017-07-17 12:00:00+03	2017-07-17 13:30:00+03	KGD	SVO	Arrived	733	2017-07-17 12:02:00+03	2017-07-17 13:30:00+03
29208	PG0506	2017-08-01 12:00:00+03	2017-08-01 13:30:00+03	KGD	SVO	Arrived	733	2017-08-01 12:02:00+03	2017-08-01 13:31:00+03
29209	PG0506	2017-09-13 12:00:00+03	2017-09-13 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29210	PG0506	2017-08-08 12:00:00+03	2017-08-08 13:30:00+03	KGD	SVO	Arrived	733	2017-08-08 12:03:00+03	2017-08-08 13:33:00+03
29211	PG0506	2017-09-14 12:00:00+03	2017-09-14 13:30:00+03	KGD	SVO	Cancelled	733	\N	\N
29212	PG0506	2017-08-23 12:00:00+03	2017-08-23 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29213	PG0506	2017-08-31 12:00:00+03	2017-08-31 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29214	PG0506	2017-09-02 12:00:00+03	2017-09-02 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29215	PG0506	2017-07-24 12:00:00+03	2017-07-24 13:30:00+03	KGD	SVO	Arrived	733	2017-07-24 12:01:00+03	2017-07-24 13:31:00+03
29216	PG0506	2017-08-26 12:00:00+03	2017-08-26 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29217	PG0506	2017-09-03 12:00:00+03	2017-09-03 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29218	PG0506	2017-08-24 12:00:00+03	2017-08-24 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29219	PG0506	2017-08-06 12:00:00+03	2017-08-06 13:30:00+03	KGD	SVO	Arrived	733	2017-08-06 12:01:00+03	2017-08-06 13:31:00+03
29220	PG0506	2017-08-02 12:00:00+03	2017-08-02 13:30:00+03	KGD	SVO	Arrived	733	2017-08-02 12:01:00+03	2017-08-02 13:30:00+03
29221	PG0506	2017-07-30 12:00:00+03	2017-07-30 13:30:00+03	KGD	SVO	Arrived	733	2017-07-30 12:03:00+03	2017-07-30 13:33:00+03
29222	PG0506	2017-08-04 12:00:00+03	2017-08-04 13:30:00+03	KGD	SVO	Arrived	733	2017-08-04 12:01:00+03	2017-08-04 13:31:00+03
29223	PG0506	2017-08-20 12:00:00+03	2017-08-20 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29224	PG0506	2017-08-22 12:00:00+03	2017-08-22 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29225	PG0506	2017-08-25 12:00:00+03	2017-08-25 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29226	PG0506	2017-08-14 12:00:00+03	2017-08-14 13:30:00+03	KGD	SVO	Arrived	733	2017-08-14 12:01:00+03	2017-08-14 13:30:00+03
29227	PG0506	2017-08-27 12:00:00+03	2017-08-27 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29228	PG0506	2017-08-12 12:00:00+03	2017-08-12 13:30:00+03	KGD	SVO	Arrived	733	2017-08-12 12:06:00+03	2017-08-12 13:37:00+03
29229	PG0506	2017-09-07 12:00:00+03	2017-09-07 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29230	PG0506	2017-08-13 12:00:00+03	2017-08-13 13:30:00+03	KGD	SVO	Arrived	733	2017-08-13 12:02:00+03	2017-08-13 13:33:00+03
29231	PG0506	2017-07-18 12:00:00+03	2017-07-18 13:30:00+03	KGD	SVO	Arrived	733	2017-07-18 12:02:00+03	2017-07-18 13:32:00+03
29232	PG0506	2017-07-23 12:00:00+03	2017-07-23 13:30:00+03	KGD	SVO	Arrived	733	2017-07-23 12:03:00+03	2017-07-23 13:33:00+03
29233	PG0506	2017-08-10 12:00:00+03	2017-08-10 13:30:00+03	KGD	SVO	Arrived	733	2017-08-10 12:03:00+03	2017-08-10 13:33:00+03
29234	PG0506	2017-08-05 12:00:00+03	2017-08-05 13:30:00+03	KGD	SVO	Arrived	733	2017-08-05 12:05:00+03	2017-08-05 13:34:00+03
29235	PG0506	2017-07-27 12:00:00+03	2017-07-27 13:30:00+03	KGD	SVO	Arrived	733	2017-07-27 12:04:00+03	2017-07-27 13:35:00+03
29236	PG0506	2017-08-11 12:00:00+03	2017-08-11 13:30:00+03	KGD	SVO	Arrived	733	2017-08-11 12:01:00+03	2017-08-11 13:32:00+03
29237	PG0506	2017-09-08 12:00:00+03	2017-09-08 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29238	PG0506	2017-08-07 12:00:00+03	2017-08-07 13:30:00+03	KGD	SVO	Arrived	733	2017-08-07 12:04:00+03	2017-08-07 13:34:00+03
29239	PG0506	2017-08-15 12:00:00+03	2017-08-15 13:30:00+03	KGD	SVO	Arrived	733	2017-08-15 12:02:00+03	2017-08-15 13:32:00+03
29240	PG0506	2017-09-11 12:00:00+03	2017-09-11 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29241	PG0506	2017-09-05 12:00:00+03	2017-09-05 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29242	PG0506	2017-08-18 12:00:00+03	2017-08-18 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29243	PG0506	2017-09-10 12:00:00+03	2017-09-10 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29244	PG0506	2017-07-29 12:00:00+03	2017-07-29 13:30:00+03	KGD	SVO	Arrived	733	2017-07-29 12:05:00+03	2017-07-29 13:36:00+03
29245	PG0506	2017-09-04 12:00:00+03	2017-09-04 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29246	PG0506	2017-07-22 12:00:00+03	2017-07-22 13:30:00+03	KGD	SVO	Arrived	733	2017-07-22 12:03:00+03	2017-07-22 13:33:00+03
29247	PG0506	2017-07-31 12:00:00+03	2017-07-31 13:30:00+03	KGD	SVO	Arrived	733	2017-07-31 12:03:00+03	2017-07-31 13:33:00+03
29248	PG0506	2017-07-26 12:00:00+03	2017-07-26 13:30:00+03	KGD	SVO	Arrived	733	2017-07-26 12:03:00+03	2017-07-26 13:33:00+03
29249	PG0506	2017-08-09 12:00:00+03	2017-08-09 13:30:00+03	KGD	SVO	Arrived	733	2017-08-09 12:02:00+03	2017-08-09 13:32:00+03
29250	PG0506	2017-07-19 12:00:00+03	2017-07-19 13:30:00+03	KGD	SVO	Arrived	733	2017-07-19 12:06:00+03	2017-07-19 13:35:00+03
29251	PG0506	2017-08-21 12:00:00+03	2017-08-21 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29252	PG0506	2017-08-19 12:00:00+03	2017-08-19 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29253	PG0506	2017-08-29 12:00:00+03	2017-08-29 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29254	PG0506	2017-08-28 12:00:00+03	2017-08-28 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29255	PG0506	2017-09-06 12:00:00+03	2017-09-06 13:30:00+03	KGD	SVO	Scheduled	733	\N	\N
29256	PG0506	2017-07-21 12:00:00+03	2017-07-21 13:30:00+03	KGD	SVO	Arrived	733	2017-07-21 12:02:00+03	2017-07-21 13:31:00+03
29257	PG0506	2017-07-20 12:00:00+03	2017-07-20 13:30:00+03	KGD	SVO	Arrived	733	2017-07-20 12:02:00+03	2017-07-20 13:33:00+03
29258	PG0334	2017-07-22 16:20:00+03	2017-07-22 19:05:00+03	KGD	ESL	Arrived	CR2	2017-07-22 16:21:00+03	2017-07-22 19:08:00+03
29259	PG0334	2017-09-09 16:20:00+03	2017-09-09 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29260	PG0334	2017-08-05 16:20:00+03	2017-08-05 19:05:00+03	KGD	ESL	Arrived	CR2	2017-08-05 16:22:00+03	2017-08-05 19:09:00+03
29261	PG0334	2017-08-15 16:20:00+03	2017-08-15 19:05:00+03	KGD	ESL	Departed	CR2	2017-08-15 16:24:00+03	\N
29262	PG0334	2017-08-01 16:20:00+03	2017-08-01 19:05:00+03	KGD	ESL	Arrived	CR2	2017-08-01 16:21:00+03	2017-08-01 19:06:00+03
29263	PG0334	2017-07-25 16:20:00+03	2017-07-25 19:05:00+03	KGD	ESL	Arrived	CR2	2017-07-25 16:21:00+03	2017-07-25 19:05:00+03
29264	PG0334	2017-09-12 16:20:00+03	2017-09-12 19:05:00+03	KGD	ESL	Cancelled	CR2	\N	\N
29265	PG0334	2017-07-18 16:20:00+03	2017-07-18 19:05:00+03	KGD	ESL	Arrived	CR2	2017-07-18 16:23:00+03	2017-07-18 19:09:00+03
29266	PG0334	2017-09-02 16:20:00+03	2017-09-02 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29267	PG0334	2017-08-29 16:20:00+03	2017-08-29 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29268	PG0334	2017-08-22 16:20:00+03	2017-08-22 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29269	PG0334	2017-08-19 16:20:00+03	2017-08-19 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29270	PG0334	2017-08-08 16:20:00+03	2017-08-08 19:05:00+03	KGD	ESL	Arrived	CR2	2017-08-08 16:20:00+03	2017-08-08 19:05:00+03
29271	PG0334	2017-07-29 16:20:00+03	2017-07-29 19:05:00+03	KGD	ESL	Arrived	CR2	2017-07-29 16:22:00+03	2017-07-29 19:05:00+03
29273	PG0334	2017-08-12 16:20:00+03	2017-08-12 19:05:00+03	KGD	ESL	Arrived	CR2	2017-08-12 16:25:00+03	2017-08-12 19:09:00+03
29274	PG0334	2017-08-26 16:20:00+03	2017-08-26 19:05:00+03	KGD	ESL	Scheduled	CR2	\N	\N
29275	PG0381	2017-08-02 15:55:00+03	2017-08-02 18:20:00+03	KGD	KRR	Arrived	CR2	2017-08-02 15:56:00+03	2017-08-02 18:21:00+03
29276	PG0381	2017-07-30 15:55:00+03	2017-07-30 18:20:00+03	KGD	KRR	Arrived	CR2	2017-07-30 15:56:00+03	2017-07-30 18:20:00+03
29277	PG0381	2017-07-16 15:55:00+03	2017-07-16 18:20:00+03	KGD	KRR	Arrived	CR2	2017-07-16 15:57:00+03	2017-07-16 18:23:00+03
29278	PG0381	2017-08-23 15:55:00+03	2017-08-23 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29279	PG0381	2017-08-13 15:55:00+03	2017-08-13 18:20:00+03	KGD	KRR	Arrived	CR2	2017-08-13 16:00:00+03	2017-08-13 18:25:00+03
29280	PG0381	2017-09-06 15:55:00+03	2017-09-06 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29281	PG0381	2017-09-13 15:55:00+03	2017-09-13 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29282	PG0381	2017-08-16 15:55:00+03	2017-08-16 18:20:00+03	KGD	KRR	On Time	CR2	\N	\N
29283	PG0381	2017-07-23 15:55:00+03	2017-07-23 18:20:00+03	KGD	KRR	Arrived	CR2	2017-07-23 15:58:00+03	2017-07-23 18:23:00+03
29284	PG0381	2017-09-03 15:55:00+03	2017-09-03 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29285	PG0381	2017-08-30 15:55:00+03	2017-08-30 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29286	PG0381	2017-07-26 15:55:00+03	2017-07-26 18:20:00+03	KGD	KRR	Arrived	CR2	2017-07-26 15:56:00+03	2017-07-26 18:20:00+03
29287	PG0381	2017-07-19 15:55:00+03	2017-07-19 18:20:00+03	KGD	KRR	Arrived	CR2	2017-07-19 15:58:00+03	2017-07-19 18:21:00+03
29288	PG0381	2017-08-09 15:55:00+03	2017-08-09 18:20:00+03	KGD	KRR	Arrived	CR2	2017-08-09 15:59:00+03	2017-08-09 18:23:00+03
29289	PG0381	2017-08-06 15:55:00+03	2017-08-06 18:20:00+03	KGD	KRR	Arrived	CR2	2017-08-06 15:56:00+03	2017-08-06 18:19:00+03
29290	PG0381	2017-08-27 15:55:00+03	2017-08-27 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29291	PG0381	2017-08-20 15:55:00+03	2017-08-20 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29292	PG0381	2017-09-10 15:55:00+03	2017-09-10 18:20:00+03	KGD	KRR	Scheduled	CR2	\N	\N
29293	PG0455	2017-07-23 13:05:00+03	2017-07-23 13:40:00+03	URS	DME	Arrived	SU9	2017-07-23 16:03:00+03	2017-07-23 16:38:00+03
29294	PG0455	2017-08-02 13:05:00+03	2017-08-02 13:40:00+03	URS	DME	Arrived	SU9	2017-08-02 13:07:00+03	2017-08-02 13:42:00+03
29295	PG0455	2017-07-20 13:05:00+03	2017-07-20 13:40:00+03	URS	DME	Arrived	SU9	2017-07-20 13:07:00+03	2017-07-20 13:42:00+03
29296	PG0455	2017-07-21 13:05:00+03	2017-07-21 13:40:00+03	URS	DME	Arrived	SU9	2017-07-21 13:09:00+03	2017-07-21 13:44:00+03
29297	PG0455	2017-08-25 13:05:00+03	2017-08-25 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29298	PG0455	2017-08-28 13:05:00+03	2017-08-28 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29299	PG0455	2017-07-31 13:05:00+03	2017-07-31 13:40:00+03	URS	DME	Arrived	SU9	2017-07-31 13:08:00+03	2017-07-31 13:42:00+03
29300	PG0455	2017-08-21 13:05:00+03	2017-08-21 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29301	PG0455	2017-07-22 13:05:00+03	2017-07-22 13:40:00+03	URS	DME	Arrived	SU9	2017-07-22 13:08:00+03	2017-07-22 13:43:00+03
29302	PG0455	2017-08-11 13:05:00+03	2017-08-11 13:40:00+03	URS	DME	Arrived	SU9	2017-08-11 13:09:00+03	2017-08-11 13:45:00+03
29303	PG0455	2017-09-06 13:05:00+03	2017-09-06 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29304	PG0455	2017-08-30 13:05:00+03	2017-08-30 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29305	PG0455	2017-09-07 13:05:00+03	2017-09-07 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29306	PG0455	2017-08-05 13:05:00+03	2017-08-05 13:40:00+03	URS	DME	Arrived	SU9	2017-08-05 13:09:00+03	2017-08-05 13:44:00+03
29307	PG0455	2017-07-17 13:05:00+03	2017-07-17 13:40:00+03	URS	DME	Arrived	SU9	2017-07-17 13:08:00+03	2017-07-17 13:43:00+03
29308	PG0455	2017-08-16 13:05:00+03	2017-08-16 13:40:00+03	URS	DME	On Time	SU9	\N	\N
29309	PG0455	2017-07-16 13:05:00+03	2017-07-16 13:40:00+03	URS	DME	Arrived	SU9	2017-07-16 13:10:00+03	2017-07-16 13:45:00+03
29310	PG0455	2017-07-18 13:05:00+03	2017-07-18 13:40:00+03	URS	DME	Arrived	SU9	2017-07-18 13:06:00+03	2017-07-18 13:42:00+03
29311	PG0455	2017-08-20 13:05:00+03	2017-08-20 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29312	PG0455	2017-09-14 13:05:00+03	2017-09-14 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29313	PG0455	2017-07-27 13:05:00+03	2017-07-27 13:40:00+03	URS	DME	Arrived	SU9	2017-07-27 13:12:00+03	2017-07-27 13:46:00+03
29314	PG0455	2017-08-14 13:05:00+03	2017-08-14 13:40:00+03	URS	DME	Arrived	SU9	2017-08-14 13:11:00+03	2017-08-14 13:46:00+03
29315	PG0455	2017-08-31 13:05:00+03	2017-08-31 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29316	PG0455	2017-09-03 13:05:00+03	2017-09-03 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29317	PG0455	2017-08-03 13:05:00+03	2017-08-03 13:40:00+03	URS	DME	Arrived	SU9	2017-08-03 13:06:00+03	2017-08-03 13:41:00+03
29318	PG0455	2017-08-23 13:05:00+03	2017-08-23 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29319	PG0455	2017-07-19 13:05:00+03	2017-07-19 13:40:00+03	URS	DME	Arrived	SU9	2017-07-19 13:06:00+03	2017-07-19 13:41:00+03
29320	PG0455	2017-08-13 13:05:00+03	2017-08-13 13:40:00+03	URS	DME	Arrived	SU9	2017-08-13 13:09:00+03	2017-08-13 13:44:00+03
29321	PG0455	2017-08-19 13:05:00+03	2017-08-19 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29322	PG0455	2017-08-27 13:05:00+03	2017-08-27 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29323	PG0455	2017-07-25 13:05:00+03	2017-07-25 13:40:00+03	URS	DME	Arrived	SU9	2017-07-25 13:09:00+03	2017-07-25 13:44:00+03
29324	PG0455	2017-09-10 13:05:00+03	2017-09-10 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29325	PG0455	2017-09-11 13:05:00+03	2017-09-11 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29326	PG0455	2017-08-26 13:05:00+03	2017-08-26 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29327	PG0455	2017-08-29 13:05:00+03	2017-08-29 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29328	PG0455	2017-09-12 13:05:00+03	2017-09-12 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29329	PG0455	2017-08-24 13:05:00+03	2017-08-24 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29330	PG0455	2017-07-28 13:05:00+03	2017-07-28 13:40:00+03	URS	DME	Arrived	SU9	2017-07-28 13:10:00+03	2017-07-28 13:45:00+03
29331	PG0455	2017-07-30 13:05:00+03	2017-07-30 13:40:00+03	URS	DME	Arrived	SU9	2017-07-30 16:00:00+03	2017-07-30 16:35:00+03
29332	PG0455	2017-09-02 13:05:00+03	2017-09-02 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29333	PG0455	2017-09-08 13:05:00+03	2017-09-08 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29334	PG0455	2017-08-08 13:05:00+03	2017-08-08 13:40:00+03	URS	DME	Arrived	SU9	2017-08-08 13:08:00+03	2017-08-08 13:44:00+03
29335	PG0455	2017-08-06 13:05:00+03	2017-08-06 13:40:00+03	URS	DME	Arrived	SU9	2017-08-06 13:07:00+03	2017-08-06 13:42:00+03
29336	PG0455	2017-09-05 13:05:00+03	2017-09-05 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29337	PG0455	2017-08-01 13:05:00+03	2017-08-01 13:40:00+03	URS	DME	Arrived	SU9	2017-08-01 13:07:00+03	2017-08-01 13:42:00+03
29338	PG0455	2017-07-26 13:05:00+03	2017-07-26 13:40:00+03	URS	DME	Arrived	SU9	2017-07-26 13:09:00+03	2017-07-26 13:44:00+03
29339	PG0455	2017-08-22 13:05:00+03	2017-08-22 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29340	PG0455	2017-07-29 13:05:00+03	2017-07-29 13:40:00+03	URS	DME	Arrived	SU9	2017-07-29 13:09:00+03	2017-07-29 13:43:00+03
29341	PG0455	2017-08-15 13:05:00+03	2017-08-15 13:40:00+03	URS	DME	Arrived	SU9	2017-08-15 13:07:00+03	2017-08-15 13:42:00+03
29342	PG0455	2017-08-09 13:05:00+03	2017-08-09 13:40:00+03	URS	DME	Arrived	SU9	2017-08-09 13:08:00+03	2017-08-09 13:42:00+03
29343	PG0455	2017-08-04 13:05:00+03	2017-08-04 13:40:00+03	URS	DME	Arrived	SU9	2017-08-04 13:06:00+03	2017-08-04 13:41:00+03
29344	PG0455	2017-09-01 13:05:00+03	2017-09-01 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29345	PG0455	2017-09-09 13:05:00+03	2017-09-09 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29346	PG0455	2017-09-13 13:05:00+03	2017-09-13 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29347	PG0455	2017-07-24 13:05:00+03	2017-07-24 13:40:00+03	URS	DME	Arrived	SU9	2017-07-24 13:09:00+03	2017-07-24 13:44:00+03
29348	PG0455	2017-08-10 13:05:00+03	2017-08-10 13:40:00+03	URS	DME	Arrived	SU9	2017-08-10 13:09:00+03	2017-08-10 13:45:00+03
29349	PG0455	2017-08-17 13:05:00+03	2017-08-17 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29350	PG0455	2017-09-04 13:05:00+03	2017-09-04 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29351	PG0455	2017-08-12 13:05:00+03	2017-08-12 13:40:00+03	URS	DME	Arrived	SU9	2017-08-12 13:08:00+03	2017-08-12 13:43:00+03
29352	PG0455	2017-08-18 13:05:00+03	2017-08-18 13:40:00+03	URS	DME	Scheduled	SU9	\N	\N
29353	PG0455	2017-08-07 13:05:00+03	2017-08-07 13:40:00+03	URS	DME	Arrived	SU9	2017-08-07 13:11:00+03	2017-08-07 13:47:00+03
29354	PG0131	2017-07-19 14:45:00+03	2017-07-19 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-19 14:48:00+03	2017-07-19 17:50:00+03
29355	PG0131	2017-07-31 14:45:00+03	2017-07-31 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-31 14:52:00+03	2017-07-31 17:57:00+03
29356	PG0131	2017-08-12 14:45:00+03	2017-08-12 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-12 14:51:00+03	2017-08-12 17:53:00+03
29357	PG0131	2017-09-06 14:45:00+03	2017-09-06 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29358	PG0131	2017-07-23 14:45:00+03	2017-07-23 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-23 14:47:00+03	2017-07-23 17:50:00+03
29359	PG0131	2017-07-16 14:45:00+03	2017-07-16 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-16 14:48:00+03	2017-07-16 17:51:00+03
29360	PG0131	2017-07-28 14:45:00+03	2017-07-28 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-28 14:48:00+03	2017-07-28 17:51:00+03
29361	PG0131	2017-09-07 14:45:00+03	2017-09-07 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29362	PG0131	2017-07-21 14:45:00+03	2017-07-21 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-21 14:47:00+03	2017-07-21 17:50:00+03
29363	PG0131	2017-09-04 14:45:00+03	2017-09-04 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29364	PG0131	2017-08-20 14:45:00+03	2017-08-20 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29365	PG0131	2017-07-26 14:45:00+03	2017-07-26 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-26 14:49:00+03	2017-07-26 17:56:00+03
29366	PG0131	2017-08-02 14:45:00+03	2017-08-02 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-02 14:48:00+03	2017-08-02 17:55:00+03
29367	PG0131	2017-07-29 14:45:00+03	2017-07-29 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-29 14:45:00+03	2017-07-29 17:50:00+03
29368	PG0131	2017-09-02 14:45:00+03	2017-09-02 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29369	PG0131	2017-08-22 14:45:00+03	2017-08-22 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29370	PG0131	2017-09-12 14:45:00+03	2017-09-12 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29371	PG0131	2017-08-13 14:45:00+03	2017-08-13 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-13 14:46:00+03	2017-08-13 17:53:00+03
29372	PG0131	2017-08-10 14:45:00+03	2017-08-10 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-10 14:47:00+03	2017-08-10 17:53:00+03
29373	PG0131	2017-09-11 14:45:00+03	2017-09-11 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29374	PG0131	2017-08-26 14:45:00+03	2017-08-26 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29375	PG0131	2017-09-14 14:45:00+03	2017-09-14 17:50:00+03	URS	KUF	Cancelled	CN1	\N	\N
29376	PG0131	2017-08-23 14:45:00+03	2017-08-23 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29377	PG0131	2017-08-08 14:45:00+03	2017-08-08 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-08 14:49:00+03	2017-08-08 17:55:00+03
29378	PG0131	2017-09-03 14:45:00+03	2017-09-03 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29379	PG0131	2017-08-24 14:45:00+03	2017-08-24 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29380	PG0131	2017-08-17 14:45:00+03	2017-08-17 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29381	PG0131	2017-07-24 14:45:00+03	2017-07-24 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-24 14:48:00+03	2017-07-24 17:54:00+03
29382	PG0131	2017-08-29 14:45:00+03	2017-08-29 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29383	PG0131	2017-07-25 14:45:00+03	2017-07-25 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-25 14:46:00+03	2017-07-25 17:52:00+03
29384	PG0131	2017-07-18 14:45:00+03	2017-07-18 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-18 14:48:00+03	2017-07-18 17:53:00+03
29385	PG0131	2017-08-30 14:45:00+03	2017-08-30 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29386	PG0131	2017-08-06 14:45:00+03	2017-08-06 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-06 14:49:00+03	2017-08-06 17:54:00+03
29387	PG0131	2017-08-14 14:45:00+03	2017-08-14 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-14 14:49:00+03	2017-08-14 17:54:00+03
29388	PG0131	2017-08-05 14:45:00+03	2017-08-05 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-05 14:49:00+03	2017-08-05 17:55:00+03
29389	PG0131	2017-08-27 14:45:00+03	2017-08-27 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29390	PG0131	2017-09-08 14:45:00+03	2017-09-08 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29391	PG0131	2017-09-13 14:45:00+03	2017-09-13 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29392	PG0131	2017-08-21 14:45:00+03	2017-08-21 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29393	PG0131	2017-08-07 14:45:00+03	2017-08-07 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-07 14:49:00+03	2017-08-07 17:54:00+03
29394	PG0131	2017-09-05 14:45:00+03	2017-09-05 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29395	PG0131	2017-08-11 14:45:00+03	2017-08-11 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-11 14:49:00+03	2017-08-11 17:58:00+03
29396	PG0131	2017-08-31 14:45:00+03	2017-08-31 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29397	PG0131	2017-08-16 14:45:00+03	2017-08-16 17:50:00+03	URS	KUF	On Time	CN1	\N	\N
29398	PG0131	2017-08-15 14:45:00+03	2017-08-15 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-15 14:50:00+03	2017-08-15 17:58:00+03
29399	PG0131	2017-09-01 14:45:00+03	2017-09-01 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29400	PG0131	2017-09-09 14:45:00+03	2017-09-09 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29401	PG0131	2017-08-18 14:45:00+03	2017-08-18 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29402	PG0131	2017-08-01 14:45:00+03	2017-08-01 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-01 14:46:00+03	2017-08-01 17:50:00+03
29403	PG0131	2017-07-17 14:45:00+03	2017-07-17 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-17 14:47:00+03	2017-07-17 17:48:00+03
29404	PG0131	2017-08-28 14:45:00+03	2017-08-28 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29405	PG0131	2017-07-30 14:45:00+03	2017-07-30 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-30 14:47:00+03	2017-07-30 17:52:00+03
29406	PG0131	2017-07-27 14:45:00+03	2017-07-27 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-27 14:47:00+03	2017-07-27 17:49:00+03
29407	PG0131	2017-07-20 14:45:00+03	2017-07-20 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-20 14:47:00+03	2017-07-20 17:51:00+03
29408	PG0131	2017-08-09 14:45:00+03	2017-08-09 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-09 14:46:00+03	2017-08-09 17:52:00+03
29409	PG0131	2017-09-10 14:45:00+03	2017-09-10 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29410	PG0131	2017-08-03 14:45:00+03	2017-08-03 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-03 14:49:00+03	2017-08-03 17:53:00+03
29411	PG0131	2017-07-22 14:45:00+03	2017-07-22 17:50:00+03	URS	KUF	Arrived	CN1	2017-07-22 14:48:00+03	2017-07-22 17:50:00+03
29412	PG0131	2017-08-25 14:45:00+03	2017-08-25 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29413	PG0131	2017-08-19 14:45:00+03	2017-08-19 17:50:00+03	URS	KUF	Scheduled	CN1	\N	\N
29414	PG0131	2017-08-04 14:45:00+03	2017-08-04 17:50:00+03	URS	KUF	Arrived	CN1	2017-08-04 14:49:00+03	2017-08-04 17:52:00+03
29415	PG0613	2017-08-23 13:20:00+03	2017-08-23 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29416	PG0613	2017-08-02 13:20:00+03	2017-08-02 16:50:00+03	URS	SGC	Arrived	CR2	2017-08-02 13:24:00+03	2017-08-02 16:56:00+03
29417	PG0613	2017-07-29 13:20:00+03	2017-07-29 16:50:00+03	URS	SGC	Arrived	CR2	2017-07-29 13:22:00+03	2017-07-29 16:52:00+03
29418	PG0613	2017-07-19 13:20:00+03	2017-07-19 16:50:00+03	URS	SGC	Arrived	CR2	2017-07-19 13:29:00+03	2017-07-19 16:58:00+03
29419	PG0613	2017-08-12 13:20:00+03	2017-08-12 16:50:00+03	URS	SGC	Arrived	CR2	2017-08-12 13:25:00+03	2017-08-12 16:54:00+03
29420	PG0613	2017-09-09 13:20:00+03	2017-09-09 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29421	PG0613	2017-09-02 13:20:00+03	2017-09-02 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29422	PG0613	2017-07-22 13:20:00+03	2017-07-22 16:50:00+03	URS	SGC	Arrived	CR2	2017-07-22 13:21:00+03	2017-07-22 16:49:00+03
29423	PG0613	2017-07-26 13:20:00+03	2017-07-26 16:50:00+03	URS	SGC	Arrived	CR2	2017-07-26 13:22:00+03	2017-07-26 16:53:00+03
29424	PG0613	2017-09-13 13:20:00+03	2017-09-13 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29425	PG0613	2017-08-05 13:20:00+03	2017-08-05 16:50:00+03	URS	SGC	Arrived	CR2	2017-08-05 13:21:00+03	2017-08-05 16:49:00+03
29426	PG0613	2017-08-26 13:20:00+03	2017-08-26 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29427	PG0613	2017-09-06 13:20:00+03	2017-09-06 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29428	PG0613	2017-08-09 13:20:00+03	2017-08-09 16:50:00+03	URS	SGC	Arrived	CR2	2017-08-09 13:24:00+03	2017-08-09 16:53:00+03
29429	PG0613	2017-08-30 13:20:00+03	2017-08-30 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29430	PG0613	2017-08-16 13:20:00+03	2017-08-16 16:50:00+03	URS	SGC	On Time	CR2	\N	\N
29431	PG0613	2017-08-19 13:20:00+03	2017-08-19 16:50:00+03	URS	SGC	Scheduled	CR2	\N	\N
29432	PG0065	2017-09-11 12:15:00+03	2017-09-11 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29433	PG0065	2017-07-22 12:15:00+03	2017-07-22 18:05:00+03	UUD	VKO	Arrived	319	2017-07-22 12:19:00+03	2017-07-22 18:07:00+03
29434	PG0065	2017-09-07 12:15:00+03	2017-09-07 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29435	PG0065	2017-07-29 12:15:00+03	2017-07-29 18:05:00+03	UUD	VKO	Arrived	319	2017-07-29 12:18:00+03	2017-07-29 18:15:00+03
29436	PG0065	2017-07-31 12:15:00+03	2017-07-31 18:05:00+03	UUD	VKO	Arrived	319	2017-07-31 12:17:00+03	2017-07-31 18:07:00+03
29437	PG0065	2017-08-28 12:15:00+03	2017-08-28 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29438	PG0065	2017-08-19 12:15:00+03	2017-08-19 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29439	PG0065	2017-08-03 12:15:00+03	2017-08-03 18:05:00+03	UUD	VKO	Arrived	319	2017-08-03 12:20:00+03	2017-08-03 18:08:00+03
29441	PG0065	2017-08-26 12:15:00+03	2017-08-26 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29442	PG0065	2017-08-10 12:15:00+03	2017-08-10 18:05:00+03	UUD	VKO	Arrived	319	2017-08-10 12:19:00+03	2017-08-10 18:07:00+03
29443	PG0065	2017-08-12 12:15:00+03	2017-08-12 18:05:00+03	UUD	VKO	Arrived	319	2017-08-12 12:20:00+03	2017-08-12 18:11:00+03
29444	PG0065	2017-08-07 12:15:00+03	2017-08-07 18:05:00+03	UUD	VKO	Arrived	319	2017-08-07 12:19:00+03	2017-08-07 18:15:00+03
29445	PG0065	2017-09-04 12:15:00+03	2017-09-04 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29446	PG0065	2017-07-20 12:15:00+03	2017-07-20 18:05:00+03	UUD	VKO	Arrived	319	2017-07-20 12:18:00+03	2017-07-20 18:11:00+03
29447	PG0065	2017-08-24 12:15:00+03	2017-08-24 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29448	PG0065	2017-07-24 12:15:00+03	2017-07-24 18:05:00+03	UUD	VKO	Arrived	319	2017-07-24 12:16:00+03	2017-07-24 18:09:00+03
29449	PG0065	2017-08-17 12:15:00+03	2017-08-17 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29450	PG0065	2017-08-14 12:15:00+03	2017-08-14 18:05:00+03	UUD	VKO	Arrived	319	2017-08-14 12:23:00+03	2017-08-14 18:09:00+03
29451	PG0065	2017-09-09 12:15:00+03	2017-09-09 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29452	PG0065	2017-08-05 12:15:00+03	2017-08-05 18:05:00+03	UUD	VKO	Arrived	319	2017-08-05 12:18:00+03	2017-08-05 18:11:00+03
29453	PG0065	2017-08-21 12:15:00+03	2017-08-21 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29454	PG0065	2017-07-27 12:15:00+03	2017-07-27 18:05:00+03	UUD	VKO	Arrived	319	2017-07-27 12:18:00+03	2017-07-27 18:05:00+03
29455	PG0065	2017-08-31 12:15:00+03	2017-08-31 18:05:00+03	UUD	VKO	Scheduled	319	\N	\N
29456	PG0065	2017-09-14 12:15:00+03	2017-09-14 18:05:00+03	UUD	VKO	Cancelled	319	\N	\N
29457	PG0065	2017-07-17 12:15:00+03	2017-07-17 18:05:00+03	UUD	VKO	Arrived	319	2017-07-17 12:19:00+03	2017-07-17 18:14:00+03
29458	PG0532	2017-08-24 10:45:00+03	2017-08-24 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29459	PG0532	2017-09-04 10:45:00+03	2017-09-04 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29460	PG0532	2017-09-07 10:45:00+03	2017-09-07 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29461	PG0532	2017-07-27 10:45:00+03	2017-07-27 13:15:00+03	UUD	YKS	Arrived	CR2	2017-07-27 10:47:00+03	2017-07-27 13:19:00+03
29462	PG0532	2017-08-03 10:45:00+03	2017-08-03 13:15:00+03	UUD	YKS	Arrived	CR2	2017-08-03 10:50:00+03	2017-08-03 13:19:00+03
29463	PG0532	2017-08-14 10:45:00+03	2017-08-14 13:15:00+03	UUD	YKS	Arrived	CR2	2017-08-14 10:47:00+03	2017-08-14 13:17:00+03
29464	PG0532	2017-07-24 10:45:00+03	2017-07-24 13:15:00+03	UUD	YKS	Arrived	CR2	2017-07-24 10:52:00+03	2017-07-24 13:22:00+03
29465	PG0532	2017-08-17 10:45:00+03	2017-08-17 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29466	PG0532	2017-08-28 10:45:00+03	2017-08-28 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29467	PG0532	2017-08-21 10:45:00+03	2017-08-21 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29468	PG0532	2017-08-07 10:45:00+03	2017-08-07 13:15:00+03	UUD	YKS	Arrived	CR2	2017-08-07 10:49:00+03	2017-08-07 13:20:00+03
29469	PG0532	2017-08-31 10:45:00+03	2017-08-31 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29470	PG0532	2017-07-31 10:45:00+03	2017-07-31 13:15:00+03	UUD	YKS	Arrived	CR2	2017-07-31 10:47:00+03	2017-07-31 13:16:00+03
29471	PG0532	2017-08-10 10:45:00+03	2017-08-10 13:15:00+03	UUD	YKS	Arrived	CR2	2017-08-10 10:46:00+03	2017-08-10 13:15:00+03
29472	PG0532	2017-07-17 10:45:00+03	2017-07-17 13:15:00+03	UUD	YKS	Arrived	CR2	2017-07-17 10:48:00+03	2017-07-17 13:17:00+03
29473	PG0532	2017-09-14 10:45:00+03	2017-09-14 13:15:00+03	UUD	YKS	Cancelled	CR2	\N	\N
29474	PG0532	2017-09-11 10:45:00+03	2017-09-11 13:15:00+03	UUD	YKS	Scheduled	CR2	\N	\N
29475	PG0532	2017-07-20 10:45:00+03	2017-07-20 13:15:00+03	UUD	YKS	Arrived	CR2	2017-07-20 10:49:00+03	2017-07-20 13:19:00+03
29476	PG0310	2017-09-07 09:50:00+03	2017-09-07 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29477	PG0310	2017-07-20 09:50:00+03	2017-07-20 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-20 09:51:00+03	2017-07-20 13:22:00+03
29478	PG0310	2017-08-27 09:50:00+03	2017-08-27 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29479	PG0310	2017-08-10 09:50:00+03	2017-08-10 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-10 09:53:00+03	2017-08-10 13:22:00+03
29480	PG0310	2017-09-12 09:50:00+03	2017-09-12 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29481	PG0310	2017-08-20 09:50:00+03	2017-08-20 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29482	PG0310	2017-08-22 09:50:00+03	2017-08-22 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29483	PG0310	2017-07-30 09:50:00+03	2017-07-30 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-30 09:55:00+03	2017-07-30 13:25:00+03
29484	PG0310	2017-07-18 09:50:00+03	2017-07-18 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-18 09:54:00+03	2017-07-18 13:24:00+03
29485	PG0310	2017-08-03 09:50:00+03	2017-08-03 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-03 09:54:00+03	2017-08-03 13:24:00+03
29486	PG0310	2017-09-05 09:50:00+03	2017-09-05 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29487	PG0310	2017-08-13 09:50:00+03	2017-08-13 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-13 09:52:00+03	2017-08-13 13:22:00+03
29488	PG0310	2017-08-31 09:50:00+03	2017-08-31 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29489	PG0310	2017-08-08 09:50:00+03	2017-08-08 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-08 09:54:00+03	2017-08-08 13:24:00+03
29490	PG0310	2017-07-23 09:50:00+03	2017-07-23 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-23 09:54:00+03	2017-07-23 13:23:00+03
29491	PG0310	2017-08-06 09:50:00+03	2017-08-06 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-06 09:55:00+03	2017-08-06 13:23:00+03
29492	PG0310	2017-09-03 09:50:00+03	2017-09-03 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29493	PG0310	2017-08-24 09:50:00+03	2017-08-24 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29494	PG0310	2017-07-27 09:50:00+03	2017-07-27 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-27 09:54:00+03	2017-07-27 13:24:00+03
29495	PG0310	2017-08-15 09:50:00+03	2017-08-15 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-15 09:54:00+03	2017-08-15 13:26:00+03
29496	PG0310	2017-08-17 09:50:00+03	2017-08-17 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29497	PG0310	2017-09-14 09:50:00+03	2017-09-14 13:20:00+03	UUD	NYM	Cancelled	CR2	\N	\N
29498	PG0310	2017-08-29 09:50:00+03	2017-08-29 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29499	PG0310	2017-07-16 09:50:00+03	2017-07-16 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-16 09:52:00+03	2017-07-16 13:23:00+03
29500	PG0310	2017-09-10 09:50:00+03	2017-09-10 13:20:00+03	UUD	NYM	Scheduled	CR2	\N	\N
29501	PG0310	2017-07-25 09:50:00+03	2017-07-25 13:20:00+03	UUD	NYM	Arrived	CR2	2017-07-25 09:57:00+03	2017-07-25 13:30:00+03
29502	PG0310	2017-08-01 09:50:00+03	2017-08-01 13:20:00+03	UUD	NYM	Arrived	CR2	2017-08-01 09:52:00+03	2017-08-01 13:22:00+03
29503	PG0449	2017-08-06 13:45:00+03	2017-08-06 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-06 13:51:00+03	2017-08-06 15:35:00+03
29504	PG0449	2017-07-25 13:45:00+03	2017-07-25 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-25 13:47:00+03	2017-07-25 15:31:00+03
29505	PG0449	2017-08-20 13:45:00+03	2017-08-20 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29506	PG0449	2017-07-16 13:45:00+03	2017-07-16 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-16 13:50:00+03	2017-07-16 15:35:00+03
29507	PG0449	2017-07-23 13:45:00+03	2017-07-23 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-23 13:49:00+03	2017-07-23 15:35:00+03
29508	PG0449	2017-08-18 13:45:00+03	2017-08-18 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29509	PG0449	2017-09-10 13:45:00+03	2017-09-10 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29510	PG0449	2017-08-04 13:45:00+03	2017-08-04 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-04 13:47:00+03	2017-08-04 15:32:00+03
29511	PG0449	2017-08-08 13:45:00+03	2017-08-08 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-08 13:49:00+03	2017-08-08 15:35:00+03
29512	PG0449	2017-08-22 13:45:00+03	2017-08-22 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29513	PG0449	2017-09-05 13:45:00+03	2017-09-05 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29514	PG0449	2017-09-03 13:45:00+03	2017-09-03 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29515	PG0449	2017-08-29 13:45:00+03	2017-08-29 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29516	PG0449	2017-07-30 13:45:00+03	2017-07-30 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-30 13:47:00+03	2017-07-30 15:31:00+03
29517	PG0449	2017-09-12 13:45:00+03	2017-09-12 15:30:00+03	STW	VKO	Cancelled	CR2	\N	\N
29518	PG0449	2017-07-18 13:45:00+03	2017-07-18 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-18 13:49:00+03	2017-07-18 15:35:00+03
29519	PG0449	2017-08-13 13:45:00+03	2017-08-13 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-13 13:46:00+03	2017-08-13 15:30:00+03
29520	PG0449	2017-08-27 13:45:00+03	2017-08-27 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29521	PG0449	2017-08-11 13:45:00+03	2017-08-11 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-11 13:49:00+03	2017-08-11 15:33:00+03
29522	PG0449	2017-08-25 13:45:00+03	2017-08-25 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29523	PG0449	2017-08-15 13:45:00+03	2017-08-15 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-15 13:46:00+03	2017-08-15 15:32:00+03
29524	PG0449	2017-07-21 13:45:00+03	2017-07-21 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-21 13:48:00+03	2017-07-21 15:33:00+03
29525	PG0449	2017-08-01 13:45:00+03	2017-08-01 15:30:00+03	STW	VKO	Arrived	CR2	2017-08-01 13:46:00+03	2017-08-01 15:31:00+03
29526	PG0449	2017-09-08 13:45:00+03	2017-09-08 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29527	PG0449	2017-07-28 13:45:00+03	2017-07-28 15:30:00+03	STW	VKO	Arrived	CR2	2017-07-28 13:49:00+03	2017-07-28 15:34:00+03
29528	PG0449	2017-09-01 13:45:00+03	2017-09-01 15:30:00+03	STW	VKO	Scheduled	CR2	\N	\N
29529	PG0067	2017-08-11 18:45:00+03	2017-08-11 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-11 18:48:00+03	2017-08-11 20:32:00+03
29530	PG0067	2017-08-12 18:45:00+03	2017-08-12 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-12 18:48:00+03	2017-08-12 20:32:00+03
29531	PG0067	2017-07-30 18:45:00+03	2017-07-30 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-30 18:50:00+03	2017-07-30 20:35:00+03
29532	PG0067	2017-07-28 18:45:00+03	2017-07-28 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-28 18:47:00+03	2017-07-28 20:32:00+03
29533	PG0067	2017-08-13 18:45:00+03	2017-08-13 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-13 18:47:00+03	2017-08-13 20:31:00+03
29534	PG0067	2017-09-02 18:45:00+03	2017-09-02 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29535	PG0067	2017-09-03 18:45:00+03	2017-09-03 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29536	PG0067	2017-09-11 18:45:00+03	2017-09-11 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29537	PG0067	2017-08-15 18:45:00+03	2017-08-15 20:30:00+03	STW	SVO	On Time	CR2	\N	\N
29538	PG0067	2017-07-25 18:45:00+03	2017-07-25 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-25 18:48:00+03	2017-07-25 20:32:00+03
29539	PG0067	2017-08-14 18:45:00+03	2017-08-14 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-14 18:48:00+03	2017-08-14 20:34:00+03
29540	PG0067	2017-07-22 18:45:00+03	2017-07-22 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-22 18:51:00+03	2017-07-22 20:35:00+03
29541	PG0067	2017-07-17 18:45:00+03	2017-07-17 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-17 21:27:00+03	2017-07-17 23:11:00+03
29542	PG0067	2017-08-27 18:45:00+03	2017-08-27 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29543	PG0067	2017-07-19 18:45:00+03	2017-07-19 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-19 18:47:00+03	2017-07-19 20:31:00+03
29544	PG0067	2017-08-24 18:45:00+03	2017-08-24 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29545	PG0067	2017-07-29 18:45:00+03	2017-07-29 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-29 18:47:00+03	2017-07-29 20:32:00+03
29546	PG0067	2017-08-01 18:45:00+03	2017-08-01 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-01 18:46:00+03	2017-08-01 20:33:00+03
29547	PG0067	2017-08-29 18:45:00+03	2017-08-29 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29548	PG0067	2017-09-01 18:45:00+03	2017-09-01 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29549	PG0067	2017-08-22 18:45:00+03	2017-08-22 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29550	PG0067	2017-07-20 18:45:00+03	2017-07-20 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-20 18:47:00+03	2017-07-20 20:33:00+03
29551	PG0067	2017-08-05 18:45:00+03	2017-08-05 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-05 18:49:00+03	2017-08-05 20:33:00+03
29552	PG0067	2017-09-13 18:45:00+03	2017-09-13 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29553	PG0067	2017-08-25 18:45:00+03	2017-08-25 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29554	PG0067	2017-08-30 18:45:00+03	2017-08-30 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29555	PG0067	2017-08-31 18:45:00+03	2017-08-31 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29556	PG0067	2017-08-10 18:45:00+03	2017-08-10 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-10 18:47:00+03	2017-08-10 20:32:00+03
29557	PG0067	2017-08-20 18:45:00+03	2017-08-20 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29558	PG0067	2017-07-21 18:45:00+03	2017-07-21 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-21 18:47:00+03	2017-07-21 20:36:00+03
29559	PG0067	2017-09-04 18:45:00+03	2017-09-04 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29560	PG0067	2017-08-07 18:45:00+03	2017-08-07 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-07 18:52:00+03	2017-08-07 20:38:00+03
29561	PG0067	2017-08-02 18:45:00+03	2017-08-02 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-02 18:49:00+03	2017-08-02 20:34:00+03
29562	PG0067	2017-08-06 18:45:00+03	2017-08-06 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-06 18:46:00+03	2017-08-06 20:31:00+03
29563	PG0067	2017-07-27 18:45:00+03	2017-07-27 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-27 18:45:00+03	2017-07-27 20:31:00+03
29564	PG0067	2017-09-12 18:45:00+03	2017-09-12 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29565	PG0067	2017-08-08 18:45:00+03	2017-08-08 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-08 18:48:00+03	2017-08-08 20:33:00+03
29566	PG0067	2017-07-31 18:45:00+03	2017-07-31 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-31 18:48:00+03	2017-07-31 20:33:00+03
29567	PG0067	2017-07-26 18:45:00+03	2017-07-26 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-26 18:48:00+03	2017-07-26 20:31:00+03
29568	PG0067	2017-07-18 18:45:00+03	2017-07-18 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-18 18:47:00+03	2017-07-18 20:32:00+03
29569	PG0067	2017-09-14 18:45:00+03	2017-09-14 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29570	PG0067	2017-08-28 18:45:00+03	2017-08-28 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29571	PG0067	2017-09-05 18:45:00+03	2017-09-05 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29572	PG0067	2017-09-06 18:45:00+03	2017-09-06 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29573	PG0067	2017-07-16 18:45:00+03	2017-07-16 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-16 18:48:00+03	2017-07-16 20:31:00+03
29574	PG0067	2017-09-09 18:45:00+03	2017-09-09 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29575	PG0067	2017-08-16 18:45:00+03	2017-08-16 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29576	PG0067	2017-08-18 18:45:00+03	2017-08-18 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29577	PG0067	2017-07-23 18:45:00+03	2017-07-23 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-23 18:47:00+03	2017-07-23 20:31:00+03
29578	PG0067	2017-08-17 18:45:00+03	2017-08-17 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29579	PG0067	2017-08-21 18:45:00+03	2017-08-21 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29580	PG0067	2017-09-10 18:45:00+03	2017-09-10 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29581	PG0067	2017-07-24 18:45:00+03	2017-07-24 20:30:00+03	STW	SVO	Arrived	CR2	2017-07-24 18:49:00+03	2017-07-24 20:35:00+03
29582	PG0067	2017-08-09 18:45:00+03	2017-08-09 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-09 18:47:00+03	2017-08-09 20:31:00+03
29583	PG0067	2017-09-08 18:45:00+03	2017-09-08 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29584	PG0067	2017-08-04 18:45:00+03	2017-08-04 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-04 18:47:00+03	2017-08-04 20:32:00+03
29585	PG0067	2017-08-03 18:45:00+03	2017-08-03 20:30:00+03	STW	SVO	Arrived	CR2	2017-08-03 18:47:00+03	2017-08-03 20:32:00+03
29586	PG0067	2017-08-23 18:45:00+03	2017-08-23 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29587	PG0067	2017-09-07 18:45:00+03	2017-09-07 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29588	PG0067	2017-08-19 18:45:00+03	2017-08-19 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29589	PG0067	2017-08-26 18:45:00+03	2017-08-26 20:30:00+03	STW	SVO	Scheduled	CR2	\N	\N
29590	PG0260	2017-07-16 14:25:00+03	2017-07-16 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-16 14:28:00+03	2017-07-16 16:58:00+03
29591	PG0260	2017-08-15 14:25:00+03	2017-08-15 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-15 14:27:00+03	2017-08-15 16:56:00+03
29592	PG0260	2017-08-31 14:25:00+03	2017-08-31 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29593	PG0260	2017-08-06 14:25:00+03	2017-08-06 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-06 18:17:00+03	2017-08-06 20:45:00+03
29594	PG0260	2017-08-10 14:25:00+03	2017-08-10 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-10 14:27:00+03	2017-08-10 16:57:00+03
29595	PG0260	2017-09-14 14:25:00+03	2017-09-14 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29596	PG0260	2017-08-22 14:25:00+03	2017-08-22 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29597	PG0260	2017-08-27 14:25:00+03	2017-08-27 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29598	PG0260	2017-07-27 14:25:00+03	2017-07-27 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-27 14:27:00+03	2017-07-27 16:57:00+03
29599	PG0260	2017-09-12 14:25:00+03	2017-09-12 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29600	PG0260	2017-08-29 14:25:00+03	2017-08-29 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29601	PG0260	2017-08-08 14:25:00+03	2017-08-08 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-08 14:28:00+03	2017-08-08 16:59:00+03
29602	PG0260	2017-08-01 14:25:00+03	2017-08-01 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-01 14:26:00+03	2017-08-01 16:57:00+03
29603	PG0260	2017-08-20 14:25:00+03	2017-08-20 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29604	PG0260	2017-08-24 14:25:00+03	2017-08-24 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29605	PG0260	2017-08-17 14:25:00+03	2017-08-17 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29606	PG0260	2017-07-30 14:25:00+03	2017-07-30 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-30 14:28:00+03	2017-07-30 17:00:00+03
29607	PG0260	2017-07-25 14:25:00+03	2017-07-25 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-25 14:29:00+03	2017-07-25 16:58:00+03
29608	PG0260	2017-09-07 14:25:00+03	2017-09-07 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29609	PG0260	2017-08-13 14:25:00+03	2017-08-13 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-13 14:29:00+03	2017-08-13 17:01:00+03
29610	PG0260	2017-09-05 14:25:00+03	2017-09-05 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29611	PG0260	2017-07-18 14:25:00+03	2017-07-18 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-18 14:27:00+03	2017-07-18 16:58:00+03
29612	PG0260	2017-07-23 14:25:00+03	2017-07-23 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-23 14:30:00+03	2017-07-23 17:01:00+03
29613	PG0260	2017-09-03 14:25:00+03	2017-09-03 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29614	PG0260	2017-08-03 14:25:00+03	2017-08-03 16:55:00+03	STW	CEK	Arrived	CR2	2017-08-03 14:27:00+03	2017-08-03 16:56:00+03
29615	PG0260	2017-09-10 14:25:00+03	2017-09-10 16:55:00+03	STW	CEK	Scheduled	CR2	\N	\N
29616	PG0260	2017-07-20 14:25:00+03	2017-07-20 16:55:00+03	STW	CEK	Arrived	CR2	2017-07-20 14:28:00+03	2017-07-20 16:58:00+03
29617	PG0092	2017-07-18 11:30:00+03	2017-07-18 16:00:00+03	STW	RGK	Arrived	733	2017-07-18 11:31:00+03	2017-07-18 16:03:00+03
29618	PG0092	2017-09-12 11:30:00+03	2017-09-12 16:00:00+03	STW	RGK	Cancelled	733	\N	\N
29619	PG0092	2017-09-05 11:30:00+03	2017-09-05 16:00:00+03	STW	RGK	Scheduled	733	\N	\N
29620	PG0092	2017-08-29 11:30:00+03	2017-08-29 16:00:00+03	STW	RGK	Scheduled	733	\N	\N
29621	PG0092	2017-07-25 11:30:00+03	2017-07-25 16:00:00+03	STW	RGK	Arrived	733	2017-07-25 11:31:00+03	2017-07-25 16:03:00+03
29622	PG0092	2017-08-08 11:30:00+03	2017-08-08 16:00:00+03	STW	RGK	Arrived	733	2017-08-08 11:33:00+03	2017-08-08 16:06:00+03
29623	PG0092	2017-08-15 11:30:00+03	2017-08-15 16:00:00+03	STW	RGK	Arrived	733	2017-08-15 11:31:00+03	2017-08-15 16:04:00+03
29624	PG0092	2017-08-01 11:30:00+03	2017-08-01 16:00:00+03	STW	RGK	Arrived	733	2017-08-01 11:33:00+03	2017-08-01 16:03:00+03
29625	PG0092	2017-08-22 11:30:00+03	2017-08-22 16:00:00+03	STW	RGK	Scheduled	733	\N	\N
29626	PG0516	2017-07-30 08:55:00+03	2017-07-30 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-30 08:57:00+03	2017-07-30 10:59:00+03
29627	PG0516	2017-08-14 08:55:00+03	2017-08-14 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-14 08:57:00+03	2017-08-14 10:58:00+03
29628	PG0516	2017-08-31 08:55:00+03	2017-08-31 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29629	PG0516	2017-09-05 08:55:00+03	2017-09-05 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29630	PG0516	2017-09-07 08:55:00+03	2017-09-07 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29631	PG0516	2017-08-21 08:55:00+03	2017-08-21 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29632	PG0516	2017-09-09 08:55:00+03	2017-09-09 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29633	PG0516	2017-07-25 08:55:00+03	2017-07-25 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-25 08:57:00+03	2017-07-25 10:56:00+03
29634	PG0516	2017-08-01 08:55:00+03	2017-08-01 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-01 12:24:00+03	2017-08-01 14:25:00+03
29635	PG0516	2017-08-29 08:55:00+03	2017-08-29 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29636	PG0516	2017-08-16 08:55:00+03	2017-08-16 10:55:00+03	MQF	VKO	On Time	CR2	\N	\N
29637	PG0516	2017-09-12 08:55:00+03	2017-09-12 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29638	PG0516	2017-08-13 08:55:00+03	2017-08-13 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-13 08:59:00+03	2017-08-13 11:00:00+03
29639	PG0516	2017-07-20 08:55:00+03	2017-07-20 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-20 09:01:00+03	2017-07-20 11:01:00+03
29640	PG0516	2017-07-19 08:55:00+03	2017-07-19 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-19 09:00:00+03	2017-07-19 11:02:00+03
29641	PG0516	2017-09-01 08:55:00+03	2017-09-01 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29642	PG0516	2017-08-28 08:55:00+03	2017-08-28 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29643	PG0516	2017-07-31 08:55:00+03	2017-07-31 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-31 08:57:00+03	2017-07-31 10:56:00+03
29644	PG0516	2017-07-17 08:55:00+03	2017-07-17 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-17 08:58:00+03	2017-07-17 10:57:00+03
29645	PG0516	2017-07-26 08:55:00+03	2017-07-26 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-26 08:58:00+03	2017-07-26 10:57:00+03
29646	PG0516	2017-08-08 08:55:00+03	2017-08-08 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-08 09:01:00+03	2017-08-08 11:00:00+03
29647	PG0516	2017-07-28 08:55:00+03	2017-07-28 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-28 08:59:00+03	2017-07-28 10:59:00+03
29648	PG0516	2017-08-03 08:55:00+03	2017-08-03 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-03 08:56:00+03	2017-08-03 10:56:00+03
29649	PG0516	2017-08-15 08:55:00+03	2017-08-15 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-15 08:58:00+03	2017-08-15 10:59:00+03
29650	PG0516	2017-09-14 08:55:00+03	2017-09-14 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29651	PG0516	2017-08-10 08:55:00+03	2017-08-10 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-10 09:00:00+03	2017-08-10 10:57:00+03
29652	PG0516	2017-08-11 08:55:00+03	2017-08-11 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-11 08:59:00+03	2017-08-11 11:01:00+03
29653	PG0516	2017-09-03 08:55:00+03	2017-09-03 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29654	PG0516	2017-08-05 08:55:00+03	2017-08-05 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-05 08:56:00+03	2017-08-05 10:54:00+03
29655	PG0516	2017-08-23 08:55:00+03	2017-08-23 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29656	PG0516	2017-07-22 08:55:00+03	2017-07-22 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-22 08:58:00+03	2017-07-22 10:59:00+03
29657	PG0516	2017-08-18 08:55:00+03	2017-08-18 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29658	PG0516	2017-07-29 08:55:00+03	2017-07-29 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-29 08:58:00+03	2017-07-29 10:57:00+03
29659	PG0516	2017-09-06 08:55:00+03	2017-09-06 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29660	PG0516	2017-08-20 08:55:00+03	2017-08-20 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29661	PG0516	2017-08-24 08:55:00+03	2017-08-24 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29662	PG0516	2017-08-27 08:55:00+03	2017-08-27 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29663	PG0516	2017-07-16 08:55:00+03	2017-07-16 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-16 08:56:00+03	2017-07-16 10:55:00+03
29664	PG0516	2017-08-06 08:55:00+03	2017-08-06 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-06 09:02:00+03	2017-08-06 11:03:00+03
29665	PG0516	2017-07-24 08:55:00+03	2017-07-24 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-24 09:01:00+03	2017-07-24 11:01:00+03
29666	PG0516	2017-08-25 08:55:00+03	2017-08-25 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29667	PG0516	2017-09-11 08:55:00+03	2017-09-11 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29668	PG0516	2017-09-08 08:55:00+03	2017-09-08 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29669	PG0516	2017-07-23 08:55:00+03	2017-07-23 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-23 08:57:00+03	2017-07-23 10:57:00+03
29670	PG0516	2017-08-17 08:55:00+03	2017-08-17 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29671	PG0516	2017-08-09 08:55:00+03	2017-08-09 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-09 09:01:00+03	2017-08-09 11:01:00+03
29672	PG0516	2017-07-21 08:55:00+03	2017-07-21 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-21 09:00:00+03	2017-07-21 11:00:00+03
29673	PG0516	2017-09-10 08:55:00+03	2017-09-10 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29674	PG0516	2017-08-04 08:55:00+03	2017-08-04 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-04 08:58:00+03	2017-08-04 10:59:00+03
29675	PG0516	2017-08-02 08:55:00+03	2017-08-02 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-02 08:58:00+03	2017-08-02 11:01:00+03
29676	PG0516	2017-09-02 08:55:00+03	2017-09-02 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29677	PG0516	2017-09-04 08:55:00+03	2017-09-04 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29678	PG0516	2017-07-27 08:55:00+03	2017-07-27 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-27 09:00:00+03	2017-07-27 11:01:00+03
29679	PG0516	2017-08-26 08:55:00+03	2017-08-26 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29680	PG0516	2017-09-13 08:55:00+03	2017-09-13 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29681	PG0516	2017-08-30 08:55:00+03	2017-08-30 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29682	PG0516	2017-08-12 08:55:00+03	2017-08-12 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-12 08:59:00+03	2017-08-12 10:59:00+03
29683	PG0516	2017-08-19 08:55:00+03	2017-08-19 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29684	PG0516	2017-08-22 08:55:00+03	2017-08-22 10:55:00+03	MQF	VKO	Scheduled	CR2	\N	\N
29685	PG0516	2017-07-18 08:55:00+03	2017-07-18 10:55:00+03	MQF	VKO	Arrived	CR2	2017-07-18 08:59:00+03	2017-07-18 10:59:00+03
29686	PG0516	2017-08-07 08:55:00+03	2017-08-07 10:55:00+03	MQF	VKO	Arrived	CR2	2017-08-07 08:57:00+03	2017-08-07 10:58:00+03
29687	PG0656	2017-09-12 12:00:00+03	2017-09-12 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29688	PG0656	2017-08-23 12:00:00+03	2017-08-23 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29689	PG0656	2017-08-20 12:00:00+03	2017-08-20 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29690	PG0656	2017-08-01 12:00:00+03	2017-08-01 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-01 12:03:00+03	2017-08-01 14:18:00+03
29691	PG0656	2017-08-30 12:00:00+03	2017-08-30 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29692	PG0656	2017-09-08 12:00:00+03	2017-09-08 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29693	PG0656	2017-07-27 12:00:00+03	2017-07-27 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-27 12:03:00+03	2017-07-27 14:18:00+03
29694	PG0656	2017-08-27 12:00:00+03	2017-08-27 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29695	PG0656	2017-08-24 12:00:00+03	2017-08-24 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29696	PG0656	2017-08-05 12:00:00+03	2017-08-05 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-05 12:06:00+03	2017-08-05 14:20:00+03
29697	PG0656	2017-08-22 12:00:00+03	2017-08-22 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29698	PG0656	2017-07-25 12:00:00+03	2017-07-25 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-25 12:05:00+03	2017-07-25 14:19:00+03
29699	PG0656	2017-09-13 12:00:00+03	2017-09-13 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29700	PG0656	2017-08-21 12:00:00+03	2017-08-21 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29701	PG0656	2017-09-05 12:00:00+03	2017-09-05 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29702	PG0656	2017-07-17 12:00:00+03	2017-07-17 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-17 12:04:00+03	2017-07-17 14:17:00+03
29703	PG0656	2017-09-06 12:00:00+03	2017-09-06 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29704	PG0656	2017-08-14 12:00:00+03	2017-08-14 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-14 12:04:00+03	2017-08-14 14:18:00+03
29705	PG0656	2017-08-10 12:00:00+03	2017-08-10 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-10 12:05:00+03	2017-08-10 14:20:00+03
29706	PG0656	2017-08-15 12:00:00+03	2017-08-15 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-15 12:02:00+03	2017-08-15 14:18:00+03
29707	PG0656	2017-07-22 12:00:00+03	2017-07-22 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-22 12:01:00+03	2017-07-22 14:14:00+03
29708	PG0656	2017-08-04 12:00:00+03	2017-08-04 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-04 12:05:00+03	2017-08-04 14:22:00+03
29709	PG0656	2017-07-29 12:00:00+03	2017-07-29 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-29 12:02:00+03	2017-07-29 14:16:00+03
29710	PG0656	2017-09-02 12:00:00+03	2017-09-02 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29711	PG0656	2017-08-31 12:00:00+03	2017-08-31 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29712	PG0656	2017-09-04 12:00:00+03	2017-09-04 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29713	PG0656	2017-08-07 12:00:00+03	2017-08-07 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-07 12:01:00+03	2017-08-07 14:16:00+03
29714	PG0656	2017-07-19 12:00:00+03	2017-07-19 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-19 12:01:00+03	2017-07-19 14:17:00+03
29715	PG0656	2017-08-17 12:00:00+03	2017-08-17 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29716	PG0656	2017-09-09 12:00:00+03	2017-09-09 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29717	PG0656	2017-07-21 12:00:00+03	2017-07-21 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-21 12:03:00+03	2017-07-21 14:19:00+03
29718	PG0656	2017-08-28 12:00:00+03	2017-08-28 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29719	PG0656	2017-09-10 12:00:00+03	2017-09-10 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29720	PG0656	2017-08-29 12:00:00+03	2017-08-29 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29721	PG0656	2017-07-31 12:00:00+03	2017-07-31 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-31 12:03:00+03	2017-07-31 14:20:00+03
29722	PG0656	2017-07-18 12:00:00+03	2017-07-18 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-18 12:04:00+03	2017-07-18 14:19:00+03
29723	PG0656	2017-08-13 12:00:00+03	2017-08-13 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-13 12:07:00+03	2017-08-13 14:23:00+03
29724	PG0656	2017-07-28 12:00:00+03	2017-07-28 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-28 12:06:00+03	2017-07-28 14:22:00+03
29725	PG0656	2017-07-23 12:00:00+03	2017-07-23 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-23 12:05:00+03	2017-07-23 14:22:00+03
29726	PG0656	2017-08-25 12:00:00+03	2017-08-25 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29727	PG0656	2017-09-01 12:00:00+03	2017-09-01 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29728	PG0656	2017-08-26 12:00:00+03	2017-08-26 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29729	PG0656	2017-09-03 12:00:00+03	2017-09-03 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29730	PG0656	2017-08-19 12:00:00+03	2017-08-19 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29731	PG0656	2017-08-09 12:00:00+03	2017-08-09 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-09 12:04:00+03	2017-08-09 14:16:00+03
29732	PG0656	2017-08-11 12:00:00+03	2017-08-11 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-11 12:02:00+03	2017-08-11 14:14:00+03
29733	PG0656	2017-07-30 12:00:00+03	2017-07-30 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-30 12:05:00+03	2017-07-30 14:21:00+03
29734	PG0656	2017-07-26 12:00:00+03	2017-07-26 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-26 12:03:00+03	2017-07-26 14:19:00+03
29735	PG0656	2017-08-12 12:00:00+03	2017-08-12 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-12 12:04:00+03	2017-08-12 14:20:00+03
29736	PG0656	2017-07-24 12:00:00+03	2017-07-24 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-24 12:05:00+03	2017-07-24 14:17:00+03
29737	PG0656	2017-09-14 12:00:00+03	2017-09-14 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29738	PG0656	2017-08-08 12:00:00+03	2017-08-08 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-08 12:03:00+03	2017-08-08 14:20:00+03
29739	PG0656	2017-08-03 12:00:00+03	2017-08-03 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-03 12:00:00+03	2017-08-03 14:16:00+03
29740	PG0656	2017-09-07 12:00:00+03	2017-09-07 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29741	PG0656	2017-08-18 12:00:00+03	2017-08-18 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29742	PG0656	2017-08-16 12:00:00+03	2017-08-16 14:15:00+03	MQF	OVB	On Time	CR2	\N	\N
29743	PG0656	2017-07-16 12:00:00+03	2017-07-16 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-16 12:02:00+03	2017-07-16 14:16:00+03
29744	PG0656	2017-09-11 12:00:00+03	2017-09-11 14:15:00+03	MQF	OVB	Scheduled	CR2	\N	\N
29745	PG0656	2017-07-20 12:00:00+03	2017-07-20 14:15:00+03	MQF	OVB	Arrived	CR2	2017-07-20 12:01:00+03	2017-07-20 14:15:00+03
29746	PG0656	2017-08-06 12:00:00+03	2017-08-06 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-06 12:04:00+03	2017-08-06 14:20:00+03
29747	PG0656	2017-08-02 12:00:00+03	2017-08-02 14:15:00+03	MQF	OVB	Arrived	CR2	2017-08-02 12:00:00+03	2017-08-02 14:18:00+03
29748	PG0167	2017-07-25 13:45:00+03	2017-07-25 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-25 13:49:00+03	2017-07-25 14:24:00+03
29749	PG0167	2017-09-05 13:45:00+03	2017-09-05 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29750	PG0167	2017-07-23 13:45:00+03	2017-07-23 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-23 13:47:00+03	2017-07-23 14:22:00+03
29751	PG0167	2017-08-31 13:45:00+03	2017-08-31 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29752	PG0167	2017-07-29 13:45:00+03	2017-07-29 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-29 13:50:00+03	2017-07-29 14:26:00+03
29753	PG0167	2017-09-08 13:45:00+03	2017-09-08 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29754	PG0167	2017-08-04 13:45:00+03	2017-08-04 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-04 13:51:00+03	2017-08-04 14:26:00+03
29755	PG0167	2017-09-04 13:45:00+03	2017-09-04 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29756	PG0167	2017-08-19 13:45:00+03	2017-08-19 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29757	PG0167	2017-08-26 13:45:00+03	2017-08-26 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29758	PG0167	2017-08-23 13:45:00+03	2017-08-23 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29759	PG0167	2017-07-18 13:45:00+03	2017-07-18 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-18 13:45:00+03	2017-07-18 14:20:00+03
29760	PG0167	2017-08-14 13:45:00+03	2017-08-14 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-14 13:45:00+03	2017-08-14 14:20:00+03
29761	PG0167	2017-08-08 13:45:00+03	2017-08-08 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-08 13:48:00+03	2017-08-08 14:22:00+03
29762	PG0167	2017-09-11 13:45:00+03	2017-09-11 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29763	PG0167	2017-08-13 13:45:00+03	2017-08-13 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-13 13:50:00+03	2017-08-13 14:24:00+03
29764	PG0167	2017-09-03 13:45:00+03	2017-09-03 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29765	PG0167	2017-07-28 13:45:00+03	2017-07-28 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-28 13:52:00+03	2017-07-28 14:27:00+03
29766	PG0167	2017-07-16 13:45:00+03	2017-07-16 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-16 13:48:00+03	2017-07-16 14:23:00+03
29767	PG0167	2017-08-28 13:45:00+03	2017-08-28 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29768	PG0167	2017-08-03 13:45:00+03	2017-08-03 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-03 13:48:00+03	2017-08-03 14:23:00+03
29769	PG0167	2017-09-10 13:45:00+03	2017-09-10 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29770	PG0167	2017-07-17 13:45:00+03	2017-07-17 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-17 13:49:00+03	2017-07-17 14:24:00+03
29771	PG0167	2017-08-18 13:45:00+03	2017-08-18 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29772	PG0167	2017-08-09 13:45:00+03	2017-08-09 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-09 13:46:00+03	2017-08-09 14:21:00+03
29773	PG0167	2017-07-30 13:45:00+03	2017-07-30 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-30 13:52:00+03	2017-07-30 14:27:00+03
29774	PG0167	2017-07-22 13:45:00+03	2017-07-22 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-22 13:47:00+03	2017-07-22 14:22:00+03
29775	PG0167	2017-07-26 13:45:00+03	2017-07-26 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-26 13:52:00+03	2017-07-26 14:27:00+03
29776	PG0167	2017-08-24 13:45:00+03	2017-08-24 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29777	PG0167	2017-07-24 13:45:00+03	2017-07-24 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-24 13:46:00+03	2017-07-24 14:21:00+03
29778	PG0167	2017-08-20 13:45:00+03	2017-08-20 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29779	PG0167	2017-08-05 13:45:00+03	2017-08-05 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-05 13:49:00+03	2017-08-05 14:24:00+03
29780	PG0167	2017-09-12 13:45:00+03	2017-09-12 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29781	PG0167	2017-08-29 13:45:00+03	2017-08-29 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29782	PG0167	2017-07-19 13:45:00+03	2017-07-19 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-19 13:52:00+03	2017-07-19 14:27:00+03
29783	PG0167	2017-09-09 13:45:00+03	2017-09-09 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29784	PG0167	2017-08-15 13:45:00+03	2017-08-15 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-15 13:48:00+03	2017-08-15 14:23:00+03
29785	PG0167	2017-08-12 13:45:00+03	2017-08-12 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-12 13:51:00+03	2017-08-12 14:27:00+03
29786	PG0167	2017-07-27 13:45:00+03	2017-07-27 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-27 13:46:00+03	2017-07-27 14:21:00+03
29787	PG0167	2017-08-07 13:45:00+03	2017-08-07 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-07 13:46:00+03	2017-08-07 14:21:00+03
29788	PG0167	2017-08-25 13:45:00+03	2017-08-25 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29789	PG0167	2017-09-14 13:45:00+03	2017-09-14 14:20:00+03	MQF	SVX	Cancelled	CR2	\N	\N
29790	PG0167	2017-09-01 13:45:00+03	2017-09-01 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29791	PG0167	2017-07-31 13:45:00+03	2017-07-31 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-31 13:52:00+03	2017-07-31 14:27:00+03
29792	PG0167	2017-09-07 13:45:00+03	2017-09-07 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29793	PG0167	2017-09-02 13:45:00+03	2017-09-02 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29794	PG0167	2017-08-06 13:45:00+03	2017-08-06 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-06 13:47:00+03	2017-08-06 14:22:00+03
29795	PG0167	2017-08-22 13:45:00+03	2017-08-22 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29796	PG0167	2017-07-21 13:45:00+03	2017-07-21 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-21 13:46:00+03	2017-07-21 14:21:00+03
29797	PG0167	2017-08-02 13:45:00+03	2017-08-02 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-02 13:49:00+03	2017-08-02 14:24:00+03
29798	PG0167	2017-09-06 13:45:00+03	2017-09-06 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29799	PG0167	2017-08-01 13:45:00+03	2017-08-01 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-01 13:46:00+03	2017-08-01 14:20:00+03
29800	PG0167	2017-08-10 13:45:00+03	2017-08-10 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-10 13:48:00+03	2017-08-10 14:23:00+03
29801	PG0167	2017-08-17 13:45:00+03	2017-08-17 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29802	PG0167	2017-08-30 13:45:00+03	2017-08-30 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29803	PG0167	2017-09-13 13:45:00+03	2017-09-13 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29804	PG0167	2017-08-16 13:45:00+03	2017-08-16 14:20:00+03	MQF	SVX	On Time	CR2	\N	\N
29805	PG0167	2017-08-27 13:45:00+03	2017-08-27 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29806	PG0167	2017-08-11 13:45:00+03	2017-08-11 14:20:00+03	MQF	SVX	Arrived	CR2	2017-08-11 13:49:00+03	2017-08-11 14:23:00+03
29807	PG0167	2017-08-21 13:45:00+03	2017-08-21 14:20:00+03	MQF	SVX	Scheduled	CR2	\N	\N
29808	PG0167	2017-07-20 13:45:00+03	2017-07-20 14:20:00+03	MQF	SVX	Arrived	CR2	2017-07-20 13:46:00+03	2017-07-20 14:21:00+03
29809	PG0622	2017-08-07 10:55:00+03	2017-08-07 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-07 11:02:00+03	2017-08-07 11:57:00+03
29810	PG0622	2017-08-29 10:55:00+03	2017-08-29 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29811	PG0622	2017-07-31 10:55:00+03	2017-07-31 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-31 11:01:00+03	2017-07-31 11:56:00+03
29812	PG0622	2017-08-05 10:55:00+03	2017-08-05 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-05 11:00:00+03	2017-08-05 11:55:00+03
29813	PG0622	2017-08-24 10:55:00+03	2017-08-24 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29814	PG0622	2017-09-07 10:55:00+03	2017-09-07 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29815	PG0622	2017-08-06 10:55:00+03	2017-08-06 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-06 14:39:00+03	2017-08-06 15:35:00+03
29816	PG0622	2017-07-20 10:55:00+03	2017-07-20 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-20 10:55:00+03	2017-07-20 11:51:00+03
29817	PG0622	2017-08-20 10:55:00+03	2017-08-20 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29818	PG0622	2017-08-30 10:55:00+03	2017-08-30 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29819	PG0622	2017-09-02 10:55:00+03	2017-09-02 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29820	PG0622	2017-07-26 10:55:00+03	2017-07-26 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-26 11:00:00+03	2017-07-26 11:54:00+03
29821	PG0622	2017-08-11 10:55:00+03	2017-08-11 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-11 10:58:00+03	2017-08-11 11:53:00+03
29822	PG0622	2017-08-02 10:55:00+03	2017-08-02 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-02 10:58:00+03	2017-08-02 11:53:00+03
29823	PG0622	2017-07-24 10:55:00+03	2017-07-24 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-24 10:59:00+03	2017-07-24 11:54:00+03
29824	PG0622	2017-08-10 10:55:00+03	2017-08-10 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-10 11:01:00+03	2017-08-10 11:57:00+03
29825	PG0622	2017-08-23 10:55:00+03	2017-08-23 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29826	PG0622	2017-09-14 10:55:00+03	2017-09-14 11:50:00+03	MQF	KZN	Cancelled	CR2	\N	\N
29827	PG0622	2017-08-28 10:55:00+03	2017-08-28 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29828	PG0622	2017-08-09 10:55:00+03	2017-08-09 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-09 14:07:00+03	2017-08-09 15:02:00+03
29829	PG0622	2017-09-11 10:55:00+03	2017-09-11 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29830	PG0622	2017-09-12 10:55:00+03	2017-09-12 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29831	PG0622	2017-07-29 10:55:00+03	2017-07-29 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-29 11:00:00+03	2017-07-29 11:55:00+03
29832	PG0622	2017-08-04 10:55:00+03	2017-08-04 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-04 10:57:00+03	2017-08-04 11:51:00+03
29833	PG0622	2017-08-08 10:55:00+03	2017-08-08 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-08 11:00:00+03	2017-08-08 11:55:00+03
29834	PG0622	2017-08-18 10:55:00+03	2017-08-18 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29835	PG0622	2017-09-05 10:55:00+03	2017-09-05 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29836	PG0622	2017-09-08 10:55:00+03	2017-09-08 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29837	PG0622	2017-07-18 10:55:00+03	2017-07-18 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-18 11:02:00+03	2017-07-18 11:58:00+03
29838	PG0622	2017-09-04 10:55:00+03	2017-09-04 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29839	PG0622	2017-08-19 10:55:00+03	2017-08-19 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29840	PG0622	2017-07-17 10:55:00+03	2017-07-17 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-17 10:55:00+03	2017-07-17 11:50:00+03
29841	PG0622	2017-07-28 10:55:00+03	2017-07-28 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-28 13:52:00+03	2017-07-28 14:47:00+03
29842	PG0622	2017-09-13 10:55:00+03	2017-09-13 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29843	PG0622	2017-09-01 10:55:00+03	2017-09-01 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29844	PG0622	2017-07-19 10:55:00+03	2017-07-19 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-19 10:58:00+03	2017-07-19 11:54:00+03
29845	PG0622	2017-09-06 10:55:00+03	2017-09-06 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29846	PG0622	2017-08-22 10:55:00+03	2017-08-22 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29847	PG0622	2017-08-17 10:55:00+03	2017-08-17 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29848	PG0622	2017-07-23 10:55:00+03	2017-07-23 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-23 10:59:00+03	2017-07-23 11:55:00+03
29849	PG0622	2017-08-26 10:55:00+03	2017-08-26 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29850	PG0622	2017-07-27 10:55:00+03	2017-07-27 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-27 11:00:00+03	2017-07-27 11:55:00+03
29851	PG0622	2017-09-03 10:55:00+03	2017-09-03 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29852	PG0622	2017-08-25 10:55:00+03	2017-08-25 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29853	PG0622	2017-08-27 10:55:00+03	2017-08-27 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29854	PG0622	2017-08-12 10:55:00+03	2017-08-12 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-12 10:56:00+03	2017-08-12 11:51:00+03
29855	PG0622	2017-09-10 10:55:00+03	2017-09-10 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29856	PG0622	2017-08-31 10:55:00+03	2017-08-31 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29857	PG0622	2017-07-21 10:55:00+03	2017-07-21 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-21 10:57:00+03	2017-07-21 11:52:00+03
29858	PG0622	2017-08-21 10:55:00+03	2017-08-21 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29859	PG0622	2017-08-01 10:55:00+03	2017-08-01 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-01 11:00:00+03	2017-08-01 11:55:00+03
29860	PG0622	2017-09-09 10:55:00+03	2017-09-09 11:50:00+03	MQF	KZN	Scheduled	CR2	\N	\N
29861	PG0622	2017-08-14 10:55:00+03	2017-08-14 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-14 11:00:00+03	2017-08-14 11:55:00+03
29862	PG0622	2017-07-30 10:55:00+03	2017-07-30 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-30 10:56:00+03	2017-07-30 11:50:00+03
29863	PG0622	2017-07-16 10:55:00+03	2017-07-16 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-16 10:58:00+03	2017-07-16 11:53:00+03
29864	PG0622	2017-08-15 10:55:00+03	2017-08-15 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-15 10:58:00+03	2017-08-15 11:54:00+03
29865	PG0622	2017-08-16 10:55:00+03	2017-08-16 11:50:00+03	MQF	KZN	On Time	CR2	\N	\N
29866	PG0622	2017-08-13 10:55:00+03	2017-08-13 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-13 10:57:00+03	2017-08-13 11:52:00+03
29867	PG0622	2017-07-25 10:55:00+03	2017-07-25 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-25 10:57:00+03	2017-07-25 11:52:00+03
29868	PG0622	2017-08-03 10:55:00+03	2017-08-03 11:50:00+03	MQF	KZN	Arrived	CR2	2017-08-03 10:59:00+03	2017-08-03 11:55:00+03
29869	PG0622	2017-07-22 10:55:00+03	2017-07-22 11:50:00+03	MQF	KZN	Arrived	CR2	2017-07-22 10:57:00+03	2017-07-22 11:52:00+03
29870	PG0363	2017-08-19 11:45:00+03	2017-08-19 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29871	PG0363	2017-09-02 11:45:00+03	2017-09-02 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29872	PG0363	2017-08-15 11:45:00+03	2017-08-15 13:30:00+03	IWA	SVX	Arrived	CR2	2017-08-15 11:48:00+03	2017-08-15 13:34:00+03
29873	PG0363	2017-07-25 11:45:00+03	2017-07-25 13:30:00+03	IWA	SVX	Arrived	CR2	2017-07-25 11:46:00+03	2017-07-25 13:28:00+03
29874	PG0363	2017-08-05 11:45:00+03	2017-08-05 13:30:00+03	IWA	SVX	Arrived	CR2	2017-08-05 11:45:00+03	2017-08-05 13:29:00+03
29875	PG0363	2017-07-18 11:45:00+03	2017-07-18 13:30:00+03	IWA	SVX	Arrived	CR2	2017-07-18 11:49:00+03	2017-07-18 13:34:00+03
29876	PG0363	2017-09-12 11:45:00+03	2017-09-12 13:30:00+03	IWA	SVX	Cancelled	CR2	\N	\N
29877	PG0363	2017-08-08 11:45:00+03	2017-08-08 13:30:00+03	IWA	SVX	Arrived	CR2	2017-08-08 11:48:00+03	2017-08-08 13:32:00+03
29878	PG0363	2017-08-26 11:45:00+03	2017-08-26 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29879	PG0363	2017-08-22 11:45:00+03	2017-08-22 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29880	PG0363	2017-08-01 11:45:00+03	2017-08-01 13:30:00+03	IWA	SVX	Arrived	CR2	2017-08-01 11:47:00+03	2017-08-01 13:31:00+03
29881	PG0363	2017-08-29 11:45:00+03	2017-08-29 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29882	PG0363	2017-08-12 11:45:00+03	2017-08-12 13:30:00+03	IWA	SVX	Arrived	CR2	2017-08-12 11:48:00+03	2017-08-12 13:34:00+03
29883	PG0363	2017-09-09 11:45:00+03	2017-09-09 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29884	PG0363	2017-09-05 11:45:00+03	2017-09-05 13:30:00+03	IWA	SVX	Scheduled	CR2	\N	\N
29885	PG0363	2017-07-29 11:45:00+03	2017-07-29 13:30:00+03	IWA	SVX	Arrived	CR2	2017-07-29 11:48:00+03	2017-07-29 13:34:00+03
29886	PG0363	2017-07-22 11:45:00+03	2017-07-22 13:30:00+03	IWA	SVX	Arrived	CR2	2017-07-22 11:48:00+03	2017-07-22 13:30:00+03
29887	PG0003	2017-09-02 09:50:00+03	2017-09-02 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29888	PG0003	2017-09-09 09:50:00+03	2017-09-09 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29889	PG0003	2017-07-18 09:50:00+03	2017-07-18 12:00:00+03	IWA	AER	Arrived	CR2	2017-07-18 09:52:00+03	2017-07-18 12:04:00+03
29890	PG0003	2017-08-01 09:50:00+03	2017-08-01 12:00:00+03	IWA	AER	Arrived	CR2	2017-08-01 09:52:00+03	2017-08-01 12:00:00+03
29891	PG0003	2017-08-22 09:50:00+03	2017-08-22 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29892	PG0003	2017-09-12 09:50:00+03	2017-09-12 12:00:00+03	IWA	AER	Cancelled	CR2	\N	\N
29893	PG0003	2017-09-05 09:50:00+03	2017-09-05 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29894	PG0003	2017-07-25 09:50:00+03	2017-07-25 12:00:00+03	IWA	AER	Arrived	CR2	2017-07-25 09:55:00+03	2017-07-25 12:04:00+03
29895	PG0003	2017-08-29 09:50:00+03	2017-08-29 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29896	PG0003	2017-08-26 09:50:00+03	2017-08-26 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29897	PG0003	2017-08-19 09:50:00+03	2017-08-19 12:00:00+03	IWA	AER	Scheduled	CR2	\N	\N
29898	PG0003	2017-08-05 09:50:00+03	2017-08-05 12:00:00+03	IWA	AER	Arrived	CR2	2017-08-05 09:54:00+03	2017-08-05 12:02:00+03
29899	PG0003	2017-07-29 09:50:00+03	2017-07-29 12:00:00+03	IWA	AER	Arrived	CR2	2017-07-29 09:52:00+03	2017-07-29 12:03:00+03
29900	PG0003	2017-07-22 09:50:00+03	2017-07-22 12:00:00+03	IWA	AER	Arrived	CR2	2017-07-22 09:53:00+03	2017-07-22 12:03:00+03
29901	PG0003	2017-08-15 09:50:00+03	2017-08-15 12:00:00+03	IWA	AER	Arrived	CR2	2017-08-15 09:52:00+03	2017-08-15 12:04:00+03
29902	PG0003	2017-08-12 09:50:00+03	2017-08-12 12:00:00+03	IWA	AER	Arrived	CR2	2017-08-12 09:52:00+03	2017-08-12 12:00:00+03
29903	PG0003	2017-08-08 09:50:00+03	2017-08-08 12:00:00+03	IWA	AER	Arrived	CR2	2017-08-08 09:54:00+03	2017-08-08 12:03:00+03
29904	PG0387	2017-08-17 17:05:00+03	2017-08-17 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29905	PG0387	2017-09-02 17:05:00+03	2017-09-02 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29906	PG0386	2017-09-02 19:45:00+03	2017-09-02 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29907	PG0385	2017-09-02 19:30:00+03	2017-09-02 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29908	PG0387	2017-08-26 17:05:00+03	2017-08-26 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29909	PG0386	2017-08-26 19:45:00+03	2017-08-26 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29910	PG0385	2017-08-26 19:30:00+03	2017-08-26 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29911	PG0385	2017-07-30 19:30:00+03	2017-07-30 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-30 22:46:00+03	2017-07-30 23:16:00+03
29912	PG0386	2017-07-30 19:45:00+03	2017-07-30 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-30 19:49:00+03	2017-07-30 20:19:00+03
29913	PG0387	2017-08-14 17:05:00+03	2017-08-14 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-14 17:08:00+03	2017-08-14 17:38:00+03
29914	PG0387	2017-07-30 17:05:00+03	2017-07-30 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-30 17:11:00+03	2017-07-30 17:41:00+03
29915	PG0386	2017-08-14 19:45:00+03	2017-08-14 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-14 19:46:00+03	2017-08-14 20:16:00+03
29916	PG0387	2017-08-12 17:05:00+03	2017-08-12 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-12 20:47:00+03	2017-08-12 21:17:00+03
29917	PG0385	2017-08-14 19:30:00+03	2017-08-14 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-14 19:32:00+03	2017-08-14 20:02:00+03
29918	PG0386	2017-08-12 19:45:00+03	2017-08-12 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-12 23:40:00+03	2017-08-13 00:10:00+03
29919	PG0385	2017-08-09 19:30:00+03	2017-08-09 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-09 19:31:00+03	2017-08-09 20:01:00+03
29920	PG0386	2017-08-09 19:45:00+03	2017-08-09 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-09 19:46:00+03	2017-08-09 20:17:00+03
29921	PG0387	2017-08-09 17:05:00+03	2017-08-09 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-09 17:08:00+03	2017-08-09 17:38:00+03
29922	PG0386	2017-08-01 19:45:00+03	2017-08-01 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-01 19:49:00+03	2017-08-01 20:19:00+03
29923	PG0385	2017-08-12 19:30:00+03	2017-08-12 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-12 19:31:00+03	2017-08-12 20:01:00+03
29924	PG0387	2017-09-07 17:05:00+03	2017-09-07 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29925	PG0386	2017-09-07 19:45:00+03	2017-09-07 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29926	PG0385	2017-09-07 19:30:00+03	2017-09-07 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29927	PG0387	2017-08-07 17:05:00+03	2017-08-07 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-07 17:09:00+03	2017-08-07 17:39:00+03
29928	PG0386	2017-08-07 19:45:00+03	2017-08-07 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-07 19:48:00+03	2017-08-07 20:18:00+03
29929	PG0387	2017-08-22 17:05:00+03	2017-08-22 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29930	PG0386	2017-08-22 19:45:00+03	2017-08-22 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29931	PG0385	2017-08-22 19:30:00+03	2017-08-22 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29932	PG0385	2017-08-01 19:30:00+03	2017-08-01 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-01 19:31:00+03	2017-08-01 20:01:00+03
29933	PG0385	2017-08-07 19:30:00+03	2017-08-07 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-07 19:30:00+03	2017-08-07 20:00:00+03
29934	PG0386	2017-08-08 19:45:00+03	2017-08-08 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-08 19:48:00+03	2017-08-08 20:18:00+03
29935	PG0385	2017-07-22 19:30:00+03	2017-07-22 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-22 19:32:00+03	2017-07-22 20:02:00+03
29936	PG0387	2017-08-19 17:05:00+03	2017-08-19 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29937	PG0385	2017-07-24 19:30:00+03	2017-07-24 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-24 19:32:00+03	2017-07-24 20:02:00+03
29938	PG0386	2017-07-24 19:45:00+03	2017-07-24 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-24 19:47:00+03	2017-07-24 20:17:00+03
29939	PG0387	2017-07-24 17:05:00+03	2017-07-24 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-24 17:10:00+03	2017-07-24 17:41:00+03
29940	PG0385	2017-08-18 19:30:00+03	2017-08-18 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29941	PG0386	2017-07-22 19:45:00+03	2017-07-22 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-22 19:48:00+03	2017-07-22 20:18:00+03
29942	PG0387	2017-07-27 17:05:00+03	2017-07-27 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-27 17:08:00+03	2017-07-27 17:38:00+03
29943	PG0386	2017-07-27 19:45:00+03	2017-07-27 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-27 19:45:00+03	2017-07-27 20:15:00+03
29944	PG0387	2017-07-22 17:05:00+03	2017-07-22 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-22 17:10:00+03	2017-07-22 17:40:00+03
29945	PG0385	2017-07-27 19:30:00+03	2017-07-27 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-27 19:32:00+03	2017-07-27 20:02:00+03
29946	PG0386	2017-08-18 19:45:00+03	2017-08-18 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29947	PG0385	2017-09-03 19:30:00+03	2017-09-03 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29948	PG0386	2017-09-03 19:45:00+03	2017-09-03 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29949	PG0387	2017-09-03 17:05:00+03	2017-09-03 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29950	PG0387	2017-07-25 17:05:00+03	2017-07-25 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-25 17:10:00+03	2017-07-25 17:40:00+03
29951	PG0387	2017-08-18 17:05:00+03	2017-08-18 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29952	PG0387	2017-09-13 17:05:00+03	2017-09-13 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29953	PG0386	2017-08-19 19:45:00+03	2017-08-19 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29954	PG0386	2017-09-13 19:45:00+03	2017-09-13 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29955	PG0385	2017-09-13 19:30:00+03	2017-09-13 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29956	PG0387	2017-08-30 17:05:00+03	2017-08-30 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29957	PG0386	2017-08-30 19:45:00+03	2017-08-30 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29958	PG0385	2017-08-30 19:30:00+03	2017-08-30 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29959	PG0385	2017-08-19 19:30:00+03	2017-08-19 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29960	PG0387	2017-07-21 17:05:00+03	2017-07-21 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-21 20:18:00+03	2017-07-21 20:49:00+03
29961	PG0386	2017-07-21 19:45:00+03	2017-07-21 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-21 19:50:00+03	2017-07-21 20:20:00+03
29962	PG0385	2017-07-21 19:30:00+03	2017-07-21 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-21 22:23:00+03	2017-07-21 22:53:00+03
29963	PG0387	2017-09-05 17:05:00+03	2017-09-05 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29964	PG0385	2017-08-24 19:30:00+03	2017-08-24 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29965	PG0386	2017-08-24 19:45:00+03	2017-08-24 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29966	PG0387	2017-08-24 17:05:00+03	2017-08-24 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29967	PG0385	2017-08-06 19:30:00+03	2017-08-06 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-06 19:33:00+03	2017-08-06 20:03:00+03
29968	PG0387	2017-08-02 17:05:00+03	2017-08-02 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-02 17:10:00+03	2017-08-02 17:40:00+03
29969	PG0386	2017-08-02 19:45:00+03	2017-08-02 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-02 19:48:00+03	2017-08-02 20:18:00+03
29970	PG0385	2017-08-02 19:30:00+03	2017-08-02 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-02 19:32:00+03	2017-08-02 20:02:00+03
29971	PG0387	2017-09-04 17:05:00+03	2017-09-04 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29972	PG0386	2017-09-04 19:45:00+03	2017-09-04 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29973	PG0385	2017-09-04 19:30:00+03	2017-09-04 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29974	PG0385	2017-07-17 19:30:00+03	2017-07-17 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-17 19:32:00+03	2017-07-17 20:02:00+03
29975	PG0386	2017-07-17 19:45:00+03	2017-07-17 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-17 19:50:00+03	2017-07-17 20:19:00+03
29976	PG0386	2017-09-05 19:45:00+03	2017-09-05 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29977	PG0385	2017-08-20 19:30:00+03	2017-08-20 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29978	PG0385	2017-09-05 19:30:00+03	2017-09-05 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29979	PG0386	2017-08-20 19:45:00+03	2017-08-20 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29980	PG0387	2017-07-17 17:05:00+03	2017-07-17 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-17 17:08:00+03	2017-07-17 17:38:00+03
29981	PG0386	2017-08-17 19:45:00+03	2017-08-17 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29982	PG0387	2017-08-20 17:05:00+03	2017-08-20 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29983	PG0385	2017-08-17 19:30:00+03	2017-08-17 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29984	PG0387	2017-08-31 17:05:00+03	2017-08-31 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
29985	PG0386	2017-08-31 19:45:00+03	2017-08-31 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
29986	PG0385	2017-08-21 19:30:00+03	2017-08-21 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29987	PG0385	2017-08-05 19:30:00+03	2017-08-05 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-05 19:34:00+03	2017-08-05 20:05:00+03
29988	PG0385	2017-08-31 19:30:00+03	2017-08-31 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29989	PG0386	2017-08-05 19:45:00+03	2017-08-05 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-05 19:47:00+03	2017-08-05 20:17:00+03
29990	PG0387	2017-08-05 17:05:00+03	2017-08-05 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-05 17:06:00+03	2017-08-05 17:36:00+03
29991	PG0385	2017-09-14 19:30:00+03	2017-09-14 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
29992	PG0387	2017-08-08 17:05:00+03	2017-08-08 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-08 17:11:00+03	2017-08-08 17:41:00+03
29993	PG0385	2017-07-28 19:30:00+03	2017-07-28 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-28 19:37:00+03	2017-07-28 20:06:00+03
29994	PG0385	2017-08-03 19:30:00+03	2017-08-03 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-03 22:32:00+03	2017-08-03 23:02:00+03
29995	PG0386	2017-07-28 19:45:00+03	2017-07-28 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-28 23:00:00+03	2017-07-28 23:30:00+03
29996	PG0387	2017-07-28 17:05:00+03	2017-07-28 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-28 17:08:00+03	2017-07-28 17:38:00+03
29997	PG0386	2017-08-03 19:45:00+03	2017-08-03 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-03 19:46:00+03	2017-08-03 20:16:00+03
29998	PG0387	2017-08-03 17:05:00+03	2017-08-03 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-03 17:06:00+03	2017-08-03 17:37:00+03
29999	PG0387	2017-08-04 17:05:00+03	2017-08-04 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-04 17:09:00+03	2017-08-04 17:40:00+03
30000	PG0387	2017-09-10 17:05:00+03	2017-09-10 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30001	PG0386	2017-09-10 19:45:00+03	2017-09-10 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30002	PG0385	2017-09-10 19:30:00+03	2017-09-10 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30003	PG0385	2017-08-23 19:30:00+03	2017-08-23 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30004	PG0386	2017-08-04 19:45:00+03	2017-08-04 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-04 19:48:00+03	2017-08-04 20:18:00+03
30005	PG0385	2017-07-19 19:30:00+03	2017-07-19 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-19 19:34:00+03	2017-07-19 20:04:00+03
30006	PG0385	2017-08-15 19:30:00+03	2017-08-15 20:00:00+03	BZK	DME	On Time	SU9	\N	\N
30007	PG0386	2017-08-15 19:45:00+03	2017-08-15 20:15:00+03	BZK	DME	Delayed	SU9	\N	\N
30008	PG0387	2017-08-15 17:05:00+03	2017-08-15 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-15 17:08:00+03	2017-08-15 17:38:00+03
30009	PG0386	2017-07-19 19:45:00+03	2017-07-19 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-19 19:47:00+03	2017-07-19 20:17:00+03
30010	PG0387	2017-07-19 17:05:00+03	2017-07-19 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-19 17:08:00+03	2017-07-19 17:38:00+03
30011	PG0385	2017-08-04 19:30:00+03	2017-08-04 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-04 19:33:00+03	2017-08-04 20:03:00+03
30012	PG0387	2017-08-06 17:05:00+03	2017-08-06 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-06 17:09:00+03	2017-08-06 17:39:00+03
30013	PG0387	2017-07-23 17:05:00+03	2017-07-23 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-23 17:09:00+03	2017-07-23 17:39:00+03
30014	PG0385	2017-07-31 19:30:00+03	2017-07-31 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-31 19:35:00+03	2017-07-31 20:05:00+03
30015	PG0386	2017-07-31 19:45:00+03	2017-07-31 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-31 19:48:00+03	2017-07-31 20:18:00+03
30016	PG0385	2017-09-12 19:30:00+03	2017-09-12 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30017	PG0387	2017-07-31 17:05:00+03	2017-07-31 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-31 17:12:00+03	2017-07-31 17:42:00+03
30018	PG0387	2017-07-29 17:05:00+03	2017-07-29 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-29 17:13:00+03	2017-07-29 17:43:00+03
30019	PG0387	2017-07-16 17:05:00+03	2017-07-16 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-16 17:08:00+03	2017-07-16 17:38:00+03
30020	PG0386	2017-07-23 19:45:00+03	2017-07-23 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-23 19:47:00+03	2017-07-23 20:17:00+03
30021	PG0386	2017-07-16 19:45:00+03	2017-07-16 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-16 19:52:00+03	2017-07-16 20:22:00+03
30022	PG0385	2017-07-16 19:30:00+03	2017-07-16 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-16 19:33:00+03	2017-07-16 20:03:00+03
30023	PG0386	2017-09-12 19:45:00+03	2017-09-12 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30024	PG0387	2017-09-12 17:05:00+03	2017-09-12 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30025	PG0385	2017-07-23 19:30:00+03	2017-07-23 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-23 19:34:00+03	2017-07-23 20:04:00+03
30026	PG0386	2017-07-29 19:45:00+03	2017-07-29 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-29 19:49:00+03	2017-07-29 20:19:00+03
30027	PG0385	2017-07-29 19:30:00+03	2017-07-29 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-29 19:32:00+03	2017-07-29 20:02:00+03
30028	PG0387	2017-09-14 17:05:00+03	2017-09-14 17:35:00+03	BZK	DME	Cancelled	SU9	\N	\N
30029	PG0385	2017-09-09 19:30:00+03	2017-09-09 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30030	PG0386	2017-09-09 19:45:00+03	2017-09-09 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30031	PG0387	2017-09-09 17:05:00+03	2017-09-09 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30032	PG0387	2017-08-21 17:05:00+03	2017-08-21 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30033	PG0386	2017-08-23 19:45:00+03	2017-08-23 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30034	PG0387	2017-08-25 17:05:00+03	2017-08-25 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30035	PG0386	2017-08-25 19:45:00+03	2017-08-25 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30036	PG0385	2017-08-25 19:30:00+03	2017-08-25 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30037	PG0387	2017-08-11 17:05:00+03	2017-08-11 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-11 17:07:00+03	2017-08-11 17:38:00+03
30038	PG0385	2017-08-13 19:30:00+03	2017-08-13 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-13 19:31:00+03	2017-08-13 20:01:00+03
30039	PG0386	2017-08-11 19:45:00+03	2017-08-11 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-11 19:49:00+03	2017-08-11 20:19:00+03
30040	PG0385	2017-08-11 19:30:00+03	2017-08-11 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-11 19:34:00+03	2017-08-11 20:04:00+03
30041	PG0386	2017-08-13 19:45:00+03	2017-08-13 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-13 19:47:00+03	2017-08-13 20:17:00+03
30042	PG0387	2017-08-23 17:05:00+03	2017-08-23 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30043	PG0387	2017-09-08 17:05:00+03	2017-09-08 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30044	PG0386	2017-09-08 19:45:00+03	2017-09-08 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30045	PG0385	2017-09-08 19:30:00+03	2017-09-08 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30046	PG0386	2017-08-21 19:45:00+03	2017-08-21 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30047	PG0387	2017-08-13 17:05:00+03	2017-08-13 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-13 17:09:00+03	2017-08-13 17:39:00+03
30048	PG0385	2017-07-25 19:30:00+03	2017-07-25 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-25 19:36:00+03	2017-07-25 20:06:00+03
30049	PG0387	2017-09-11 17:05:00+03	2017-09-11 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30050	PG0386	2017-09-11 19:45:00+03	2017-09-11 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30051	PG0385	2017-09-01 19:30:00+03	2017-09-01 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30052	PG0386	2017-09-01 19:45:00+03	2017-09-01 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30053	PG0385	2017-09-11 19:30:00+03	2017-09-11 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30054	PG0387	2017-09-01 17:05:00+03	2017-09-01 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30055	PG0387	2017-08-27 17:05:00+03	2017-08-27 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30056	PG0385	2017-08-29 19:30:00+03	2017-08-29 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30057	PG0387	2017-08-16 17:05:00+03	2017-08-16 17:35:00+03	BZK	DME	On Time	SU9	\N	\N
30058	PG0386	2017-08-27 19:45:00+03	2017-08-27 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30059	PG0385	2017-08-08 19:30:00+03	2017-08-08 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-08 19:35:00+03	2017-08-08 20:05:00+03
30060	PG0386	2017-08-16 19:45:00+03	2017-08-16 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30061	PG0385	2017-08-16 19:30:00+03	2017-08-16 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30062	PG0386	2017-08-29 19:45:00+03	2017-08-29 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30063	PG0385	2017-08-27 19:30:00+03	2017-08-27 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30064	PG0387	2017-07-26 17:05:00+03	2017-07-26 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-26 17:06:00+03	2017-07-26 17:36:00+03
30065	PG0386	2017-07-26 19:45:00+03	2017-07-26 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-26 19:49:00+03	2017-07-26 20:19:00+03
30066	PG0387	2017-08-29 17:05:00+03	2017-08-29 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30067	PG0385	2017-07-26 19:30:00+03	2017-07-26 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-26 19:32:00+03	2017-07-26 20:02:00+03
30068	PG0385	2017-08-10 19:30:00+03	2017-08-10 20:00:00+03	BZK	DME	Arrived	SU9	2017-08-10 19:30:00+03	2017-08-10 20:00:00+03
30069	PG0387	2017-07-20 17:05:00+03	2017-07-20 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-20 17:10:00+03	2017-07-20 17:40:00+03
30070	PG0386	2017-08-10 19:45:00+03	2017-08-10 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-10 19:47:00+03	2017-08-10 20:16:00+03
30071	PG0386	2017-07-20 19:45:00+03	2017-07-20 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-20 19:47:00+03	2017-07-20 20:17:00+03
30072	PG0385	2017-07-20 19:30:00+03	2017-07-20 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-20 19:32:00+03	2017-07-20 20:02:00+03
30073	PG0387	2017-08-10 17:05:00+03	2017-08-10 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-10 17:10:00+03	2017-08-10 17:40:00+03
30074	PG0386	2017-09-14 19:45:00+03	2017-09-14 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30075	PG0385	2017-08-28 19:30:00+03	2017-08-28 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30076	PG0386	2017-08-28 19:45:00+03	2017-08-28 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30077	PG0386	2017-08-06 19:45:00+03	2017-08-06 20:15:00+03	BZK	DME	Arrived	SU9	2017-08-06 19:48:00+03	2017-08-06 20:18:00+03
30078	PG0387	2017-08-28 17:05:00+03	2017-08-28 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30079	PG0385	2017-09-06 19:30:00+03	2017-09-06 20:00:00+03	BZK	DME	Scheduled	SU9	\N	\N
30080	PG0386	2017-09-06 19:45:00+03	2017-09-06 20:15:00+03	BZK	DME	Scheduled	SU9	\N	\N
30081	PG0387	2017-07-18 17:05:00+03	2017-07-18 17:35:00+03	BZK	DME	Arrived	SU9	2017-07-18 17:07:00+03	2017-07-18 17:37:00+03
30082	PG0386	2017-07-25 19:45:00+03	2017-07-25 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-25 19:45:00+03	2017-07-25 20:16:00+03
30083	PG0387	2017-09-06 17:05:00+03	2017-09-06 17:35:00+03	BZK	DME	Scheduled	SU9	\N	\N
30084	PG0387	2017-08-01 17:05:00+03	2017-08-01 17:35:00+03	BZK	DME	Arrived	SU9	2017-08-01 17:08:00+03	2017-08-01 17:38:00+03
30085	PG0386	2017-07-18 19:45:00+03	2017-07-18 20:15:00+03	BZK	DME	Arrived	SU9	2017-07-18 19:46:00+03	2017-07-18 20:16:00+03
30086	PG0385	2017-07-18 19:30:00+03	2017-07-18 20:00:00+03	BZK	DME	Arrived	SU9	2017-07-18 19:33:00+03	2017-07-18 20:02:00+03
30087	PG0237	2017-08-17 09:20:00+03	2017-08-17 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30088	PG0236	2017-08-17 10:30:00+03	2017-08-17 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30089	PG0238	2017-09-11 11:05:00+03	2017-09-11 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30090	PG0238	2017-09-13 11:05:00+03	2017-09-13 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30091	PG0237	2017-09-13 09:20:00+03	2017-09-13 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30092	PG0237	2017-09-07 09:20:00+03	2017-09-07 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30093	PG0236	2017-09-13 10:30:00+03	2017-09-13 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30094	PG0237	2017-07-30 09:20:00+03	2017-07-30 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-30 09:20:00+03	2017-07-30 09:45:00+03
30095	PG0238	2017-07-30 11:05:00+03	2017-07-30 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-30 11:06:00+03	2017-07-30 11:31:00+03
30096	PG0237	2017-08-23 09:20:00+03	2017-08-23 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30097	PG0237	2017-09-08 09:20:00+03	2017-09-08 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30098	PG0237	2017-07-26 09:20:00+03	2017-07-26 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-26 09:23:00+03	2017-07-26 09:48:00+03
30099	PG0238	2017-09-07 11:05:00+03	2017-09-07 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30100	PG0236	2017-08-08 10:30:00+03	2017-08-08 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-08 10:30:00+03	2017-08-08 10:55:00+03
30101	PG0237	2017-08-08 09:20:00+03	2017-08-08 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-08 09:22:00+03	2017-08-08 09:47:00+03
30102	PG0238	2017-08-07 11:05:00+03	2017-08-07 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-07 11:10:00+03	2017-08-07 11:35:00+03
30103	PG0237	2017-07-29 09:20:00+03	2017-07-29 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-29 13:01:00+03	2017-07-29 13:26:00+03
30104	PG0238	2017-09-12 11:05:00+03	2017-09-12 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30105	PG0238	2017-08-08 11:05:00+03	2017-08-08 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-08 11:06:00+03	2017-08-08 11:31:00+03
30106	PG0238	2017-07-26 11:05:00+03	2017-07-26 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-26 11:09:00+03	2017-07-26 11:34:00+03
30107	PG0237	2017-08-20 09:20:00+03	2017-08-20 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30108	PG0237	2017-08-24 09:20:00+03	2017-08-24 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30109	PG0236	2017-08-20 10:30:00+03	2017-08-20 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30110	PG0237	2017-09-12 09:20:00+03	2017-09-12 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30111	PG0237	2017-08-19 09:20:00+03	2017-08-19 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30112	PG0236	2017-08-19 10:30:00+03	2017-08-19 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30113	PG0237	2017-08-18 09:20:00+03	2017-08-18 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30114	PG0236	2017-09-12 10:30:00+03	2017-09-12 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30115	PG0237	2017-08-09 09:20:00+03	2017-08-09 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-09 09:23:00+03	2017-08-09 09:48:00+03
30116	PG0238	2017-09-04 11:05:00+03	2017-09-04 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30117	PG0237	2017-09-04 09:20:00+03	2017-09-04 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30118	PG0236	2017-09-04 10:30:00+03	2017-09-04 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30119	PG0236	2017-08-21 10:30:00+03	2017-08-21 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30120	PG0238	2017-08-28 11:05:00+03	2017-08-28 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30121	PG0236	2017-09-14 10:30:00+03	2017-09-14 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30122	PG0236	2017-08-10 10:30:00+03	2017-08-10 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-10 10:30:00+03	2017-08-10 10:55:00+03
30123	PG0237	2017-08-28 09:20:00+03	2017-08-28 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30124	PG0236	2017-09-02 10:30:00+03	2017-09-02 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30125	PG0237	2017-09-14 09:20:00+03	2017-09-14 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30126	PG0236	2017-07-29 10:30:00+03	2017-07-29 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-29 10:31:00+03	2017-07-29 10:56:00+03
30127	PG0238	2017-09-14 11:05:00+03	2017-09-14 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30128	PG0238	2017-08-16 11:05:00+03	2017-08-16 11:30:00+03	BZK	VKO	On Time	SU9	\N	\N
30129	PG0237	2017-08-10 09:20:00+03	2017-08-10 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-10 09:26:00+03	2017-08-10 09:51:00+03
30130	PG0238	2017-08-04 11:05:00+03	2017-08-04 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-04 11:10:00+03	2017-08-04 11:35:00+03
30131	PG0237	2017-09-02 09:20:00+03	2017-09-02 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30132	PG0236	2017-07-20 10:30:00+03	2017-07-20 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-20 10:35:00+03	2017-07-20 11:00:00+03
30133	PG0237	2017-08-04 09:20:00+03	2017-08-04 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-04 09:23:00+03	2017-08-04 09:48:00+03
30134	PG0238	2017-08-10 11:05:00+03	2017-08-10 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-10 11:05:00+03	2017-08-10 11:30:00+03
30135	PG0236	2017-09-06 10:30:00+03	2017-09-06 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30136	PG0238	2017-08-18 11:05:00+03	2017-08-18 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30137	PG0237	2017-08-06 09:20:00+03	2017-08-06 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-06 09:21:00+03	2017-08-06 09:46:00+03
30138	PG0238	2017-08-31 11:05:00+03	2017-08-31 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30139	PG0236	2017-08-24 10:30:00+03	2017-08-24 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30140	PG0237	2017-09-06 09:20:00+03	2017-09-06 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30141	PG0236	2017-08-04 10:30:00+03	2017-08-04 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-04 10:31:00+03	2017-08-04 10:57:00+03
30142	PG0236	2017-08-06 10:30:00+03	2017-08-06 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-06 10:33:00+03	2017-08-06 10:58:00+03
30143	PG0238	2017-09-06 11:05:00+03	2017-09-06 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30144	PG0238	2017-07-16 11:05:00+03	2017-07-16 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-16 11:06:00+03	2017-07-16 11:31:00+03
30145	PG0237	2017-07-16 09:20:00+03	2017-07-16 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-16 09:23:00+03	2017-07-16 09:48:00+03
30146	PG0238	2017-08-09 11:05:00+03	2017-08-09 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-09 11:07:00+03	2017-08-09 11:32:00+03
30147	PG0236	2017-08-28 10:30:00+03	2017-08-28 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30148	PG0237	2017-08-31 09:20:00+03	2017-08-31 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30149	PG0238	2017-08-03 11:05:00+03	2017-08-03 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-03 11:06:00+03	2017-08-03 11:31:00+03
30150	PG0238	2017-08-24 11:05:00+03	2017-08-24 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30151	PG0236	2017-08-12 10:30:00+03	2017-08-12 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-12 10:34:00+03	2017-08-12 10:59:00+03
30152	PG0238	2017-08-23 11:05:00+03	2017-08-23 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30153	PG0236	2017-08-31 10:30:00+03	2017-08-31 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30154	PG0237	2017-08-12 09:20:00+03	2017-08-12 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-12 09:25:00+03	2017-08-12 09:50:00+03
30155	PG0238	2017-09-02 11:05:00+03	2017-09-02 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30156	PG0238	2017-07-17 11:05:00+03	2017-07-17 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-17 11:07:00+03	2017-07-17 11:32:00+03
30157	PG0237	2017-08-27 09:20:00+03	2017-08-27 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30158	PG0237	2017-08-01 09:20:00+03	2017-08-01 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-01 09:22:00+03	2017-08-01 09:47:00+03
30159	PG0236	2017-09-03 10:30:00+03	2017-09-03 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30160	PG0236	2017-08-01 10:30:00+03	2017-08-01 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-01 10:34:00+03	2017-08-01 10:59:00+03
30161	PG0236	2017-08-16 10:30:00+03	2017-08-16 10:55:00+03	BZK	VKO	On Time	SU9	\N	\N
30162	PG0237	2017-08-15 09:20:00+03	2017-08-15 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-15 09:23:00+03	2017-08-15 09:48:00+03
30163	PG0238	2017-07-24 11:05:00+03	2017-07-24 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-24 11:13:00+03	2017-07-24 11:38:00+03
30164	PG0236	2017-08-15 10:30:00+03	2017-08-15 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-15 10:33:00+03	2017-08-15 10:58:00+03
30165	PG0237	2017-08-25 09:20:00+03	2017-08-25 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30166	PG0238	2017-08-15 11:05:00+03	2017-08-15 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-15 11:06:00+03	2017-08-15 11:31:00+03
30167	PG0237	2017-07-24 09:20:00+03	2017-07-24 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-24 09:21:00+03	2017-07-24 09:46:00+03
30168	PG0238	2017-07-20 11:05:00+03	2017-07-20 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-20 11:09:00+03	2017-07-20 11:34:00+03
30169	PG0236	2017-07-24 10:30:00+03	2017-07-24 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-24 10:34:00+03	2017-07-24 10:59:00+03
30170	PG0237	2017-09-03 09:20:00+03	2017-09-03 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30171	PG0238	2017-08-22 11:05:00+03	2017-08-22 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30172	PG0238	2017-08-27 11:05:00+03	2017-08-27 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30173	PG0238	2017-09-10 11:05:00+03	2017-09-10 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30174	PG0236	2017-09-08 10:30:00+03	2017-09-08 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30175	PG0237	2017-09-10 09:20:00+03	2017-09-10 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30176	PG0236	2017-09-09 10:30:00+03	2017-09-09 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30177	PG0237	2017-09-09 09:20:00+03	2017-09-09 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30178	PG0238	2017-09-09 11:05:00+03	2017-09-09 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30179	PG0238	2017-08-06 11:05:00+03	2017-08-06 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-06 11:07:00+03	2017-08-06 11:32:00+03
30180	PG0237	2017-08-22 09:20:00+03	2017-08-22 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30181	PG0236	2017-09-10 10:30:00+03	2017-09-10 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30182	PG0236	2017-07-22 10:30:00+03	2017-07-22 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-22 10:33:00+03	2017-07-22 10:58:00+03
30183	PG0238	2017-08-12 11:05:00+03	2017-08-12 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-12 11:10:00+03	2017-08-12 11:35:00+03
30184	PG0238	2017-07-19 11:05:00+03	2017-07-19 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-19 11:09:00+03	2017-07-19 11:34:00+03
30185	PG0236	2017-08-25 10:30:00+03	2017-08-25 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30186	PG0237	2017-08-03 09:20:00+03	2017-08-03 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-03 09:22:00+03	2017-08-03 09:47:00+03
30187	PG0238	2017-07-21 11:05:00+03	2017-07-21 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-21 11:08:00+03	2017-07-21 11:33:00+03
30188	PG0238	2017-07-18 11:05:00+03	2017-07-18 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-18 11:09:00+03	2017-07-18 11:34:00+03
30189	PG0237	2017-07-21 09:20:00+03	2017-07-21 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-21 09:26:00+03	2017-07-21 09:51:00+03
30190	PG0237	2017-08-21 09:20:00+03	2017-08-21 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30191	PG0236	2017-07-21 10:30:00+03	2017-07-21 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-21 10:34:00+03	2017-07-21 10:59:00+03
30192	PG0236	2017-08-29 10:30:00+03	2017-08-29 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30193	PG0237	2017-08-29 09:20:00+03	2017-08-29 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30194	PG0238	2017-08-29 11:05:00+03	2017-08-29 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30195	PG0236	2017-08-22 10:30:00+03	2017-08-22 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30196	PG0237	2017-07-18 09:20:00+03	2017-07-18 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-18 09:21:00+03	2017-07-18 09:46:00+03
30197	PG0238	2017-08-21 11:05:00+03	2017-08-21 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30198	PG0236	2017-07-26 10:30:00+03	2017-07-26 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-26 10:30:00+03	2017-07-26 10:55:00+03
30199	PG0238	2017-08-26 11:05:00+03	2017-08-26 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30200	PG0237	2017-08-26 09:20:00+03	2017-08-26 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30201	PG0236	2017-08-26 10:30:00+03	2017-08-26 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30202	PG0237	2017-07-19 09:20:00+03	2017-07-19 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-19 09:23:00+03	2017-07-19 09:48:00+03
30203	PG0236	2017-07-19 10:30:00+03	2017-07-19 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-19 10:34:00+03	2017-07-19 10:59:00+03
30204	PG0236	2017-07-18 10:30:00+03	2017-07-18 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-18 10:35:00+03	2017-07-18 11:01:00+03
30205	PG0236	2017-07-27 10:30:00+03	2017-07-27 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-27 13:16:00+03	2017-07-27 13:41:00+03
30206	PG0238	2017-08-02 11:05:00+03	2017-08-02 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-02 11:06:00+03	2017-08-02 11:31:00+03
30207	PG0237	2017-08-02 09:20:00+03	2017-08-02 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-02 09:25:00+03	2017-08-02 09:50:00+03
30208	PG0236	2017-08-02 10:30:00+03	2017-08-02 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-02 10:31:00+03	2017-08-02 10:56:00+03
30209	PG0238	2017-08-14 11:05:00+03	2017-08-14 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-14 11:08:00+03	2017-08-14 11:33:00+03
30210	PG0238	2017-09-03 11:05:00+03	2017-09-03 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30211	PG0236	2017-07-31 10:30:00+03	2017-07-31 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-31 10:33:00+03	2017-07-31 10:58:00+03
30212	PG0237	2017-07-31 09:20:00+03	2017-07-31 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-31 09:24:00+03	2017-07-31 09:49:00+03
30213	PG0236	2017-08-07 10:30:00+03	2017-08-07 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-07 10:34:00+03	2017-08-07 10:59:00+03
30214	PG0238	2017-07-31 11:05:00+03	2017-07-31 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-31 11:12:00+03	2017-07-31 11:37:00+03
30215	PG0236	2017-08-27 10:30:00+03	2017-08-27 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30216	PG0237	2017-07-17 09:20:00+03	2017-07-17 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-17 09:23:00+03	2017-07-17 09:48:00+03
30217	PG0237	2017-07-22 09:20:00+03	2017-07-22 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-22 12:12:00+03	2017-07-22 12:37:00+03
30218	PG0238	2017-07-22 11:05:00+03	2017-07-22 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-22 11:09:00+03	2017-07-22 11:34:00+03
30219	PG0237	2017-08-14 09:20:00+03	2017-08-14 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-14 09:23:00+03	2017-08-14 09:48:00+03
30220	PG0237	2017-07-27 09:20:00+03	2017-07-27 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-27 09:21:00+03	2017-07-27 09:46:00+03
30221	PG0238	2017-08-25 11:05:00+03	2017-08-25 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30222	PG0236	2017-08-18 10:30:00+03	2017-08-18 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30223	PG0238	2017-07-27 11:05:00+03	2017-07-27 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-27 11:09:00+03	2017-07-27 11:34:00+03
30224	PG0236	2017-08-14 10:30:00+03	2017-08-14 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-14 10:33:00+03	2017-08-14 10:59:00+03
30225	PG0238	2017-09-05 11:05:00+03	2017-09-05 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30226	PG0238	2017-07-28 11:05:00+03	2017-07-28 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-28 11:07:00+03	2017-07-28 11:32:00+03
30227	PG0238	2017-08-11 11:05:00+03	2017-08-11 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-11 11:07:00+03	2017-08-11 11:32:00+03
30228	PG0236	2017-09-07 10:30:00+03	2017-09-07 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30229	PG0237	2017-07-28 09:20:00+03	2017-07-28 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-28 09:24:00+03	2017-07-28 09:49:00+03
30230	PG0236	2017-07-17 10:30:00+03	2017-07-17 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-17 10:31:00+03	2017-07-17 10:56:00+03
30231	PG0236	2017-08-09 10:30:00+03	2017-08-09 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-09 10:30:00+03	2017-08-09 10:55:00+03
30232	PG0236	2017-07-16 10:30:00+03	2017-07-16 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-16 10:33:00+03	2017-07-16 10:58:00+03
30233	PG0236	2017-07-30 10:30:00+03	2017-07-30 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-30 10:33:00+03	2017-07-30 10:57:00+03
30234	PG0237	2017-09-05 09:20:00+03	2017-09-05 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30235	PG0236	2017-08-03 10:30:00+03	2017-08-03 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-03 10:33:00+03	2017-08-03 10:58:00+03
30236	PG0238	2017-08-05 11:05:00+03	2017-08-05 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-05 11:09:00+03	2017-08-05 11:34:00+03
30237	PG0237	2017-08-11 09:20:00+03	2017-08-11 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-11 09:22:00+03	2017-08-11 09:47:00+03
30238	PG0237	2017-08-05 09:20:00+03	2017-08-05 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-05 09:21:00+03	2017-08-05 09:46:00+03
30239	PG0236	2017-08-13 10:30:00+03	2017-08-13 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-13 10:34:00+03	2017-08-13 10:59:00+03
30240	PG0236	2017-09-05 10:30:00+03	2017-09-05 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30241	PG0236	2017-08-11 10:30:00+03	2017-08-11 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-11 10:33:00+03	2017-08-11 10:58:00+03
30242	PG0236	2017-07-25 10:30:00+03	2017-07-25 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-25 10:34:00+03	2017-07-25 10:59:00+03
30243	PG0236	2017-08-05 10:30:00+03	2017-08-05 10:55:00+03	BZK	VKO	Arrived	SU9	2017-08-05 10:32:00+03	2017-08-05 10:57:00+03
30244	PG0236	2017-09-01 10:30:00+03	2017-09-01 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30245	PG0237	2017-09-01 09:20:00+03	2017-09-01 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30246	PG0238	2017-09-08 11:05:00+03	2017-09-08 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30247	PG0238	2017-08-01 11:05:00+03	2017-08-01 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-01 14:34:00+03	2017-08-01 14:59:00+03
30248	PG0238	2017-08-30 11:05:00+03	2017-08-30 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30249	PG0237	2017-08-30 09:20:00+03	2017-08-30 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30250	PG0236	2017-08-30 10:30:00+03	2017-08-30 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30251	PG0238	2017-09-01 11:05:00+03	2017-09-01 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30252	PG0237	2017-08-13 09:20:00+03	2017-08-13 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-13 09:23:00+03	2017-08-13 09:48:00+03
30253	PG0238	2017-08-13 11:05:00+03	2017-08-13 11:30:00+03	BZK	VKO	Arrived	SU9	2017-08-13 11:09:00+03	2017-08-13 11:34:00+03
30254	PG0236	2017-08-23 10:30:00+03	2017-08-23 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30255	PG0237	2017-07-25 09:20:00+03	2017-07-25 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-25 09:21:00+03	2017-07-25 09:46:00+03
30256	PG0238	2017-07-25 11:05:00+03	2017-07-25 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-25 11:08:00+03	2017-07-25 11:33:00+03
30257	PG0237	2017-08-07 09:20:00+03	2017-08-07 09:45:00+03	BZK	VKO	Arrived	SU9	2017-08-07 09:24:00+03	2017-08-07 09:49:00+03
30258	PG0238	2017-08-17 11:05:00+03	2017-08-17 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30259	PG0238	2017-07-23 11:05:00+03	2017-07-23 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-23 11:13:00+03	2017-07-23 11:38:00+03
30260	PG0238	2017-08-19 11:05:00+03	2017-08-19 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30261	PG0237	2017-07-23 09:20:00+03	2017-07-23 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-23 09:23:00+03	2017-07-23 09:48:00+03
30262	PG0237	2017-07-20 09:20:00+03	2017-07-20 09:45:00+03	BZK	VKO	Arrived	SU9	2017-07-20 09:22:00+03	2017-07-20 09:47:00+03
30263	PG0238	2017-08-20 11:05:00+03	2017-08-20 11:30:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30264	PG0236	2017-07-23 10:30:00+03	2017-07-23 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-23 10:30:00+03	2017-07-23 10:55:00+03
30265	PG0236	2017-09-11 10:30:00+03	2017-09-11 10:55:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30266	PG0236	2017-07-28 10:30:00+03	2017-07-28 10:55:00+03	BZK	VKO	Arrived	SU9	2017-07-28 10:33:00+03	2017-07-28 10:58:00+03
30267	PG0237	2017-08-16 09:20:00+03	2017-08-16 09:45:00+03	BZK	VKO	On Time	SU9	\N	\N
30268	PG0237	2017-09-11 09:20:00+03	2017-09-11 09:45:00+03	BZK	VKO	Scheduled	SU9	\N	\N
30269	PG0238	2017-07-29 11:05:00+03	2017-07-29 11:30:00+03	BZK	VKO	Arrived	SU9	2017-07-29 11:11:00+03	2017-07-29 11:35:00+03
30270	PG0162	2017-09-08 19:00:00+03	2017-09-08 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30271	PG0163	2017-08-06 15:15:00+03	2017-08-06 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-06 15:18:00+03	2017-08-06 15:48:00+03
30272	PG0162	2017-08-06 19:00:00+03	2017-08-06 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-06 19:03:00+03	2017-08-06 19:33:00+03
30273	PG0161	2017-08-06 20:20:00+03	2017-08-06 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-06 20:26:00+03	2017-08-06 20:56:00+03
30274	PG0161	2017-09-04 20:20:00+03	2017-09-04 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30275	PG0162	2017-09-04 19:00:00+03	2017-09-04 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30276	PG0163	2017-09-04 15:15:00+03	2017-09-04 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30277	PG0161	2017-08-07 20:20:00+03	2017-08-07 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-07 20:22:00+03	2017-08-07 20:52:00+03
30278	PG0162	2017-08-07 19:00:00+03	2017-08-07 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-07 19:02:00+03	2017-08-07 19:32:00+03
30279	PG0163	2017-08-07 15:15:00+03	2017-08-07 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-07 15:15:00+03	2017-08-07 15:45:00+03
30280	PG0163	2017-08-05 15:15:00+03	2017-08-05 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-05 15:18:00+03	2017-08-05 15:48:00+03
30281	PG0162	2017-08-05 19:00:00+03	2017-08-05 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-05 19:02:00+03	2017-08-05 19:32:00+03
30282	PG0161	2017-08-05 20:20:00+03	2017-08-05 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-05 20:28:00+03	2017-08-05 20:59:00+03
30283	PG0163	2017-09-03 15:15:00+03	2017-09-03 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30284	PG0162	2017-09-03 19:00:00+03	2017-09-03 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30285	PG0161	2017-09-03 20:20:00+03	2017-09-03 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30286	PG0161	2017-08-08 20:20:00+03	2017-08-08 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-08 20:25:00+03	2017-08-08 20:55:00+03
30287	PG0162	2017-08-08 19:00:00+03	2017-08-08 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-08 19:03:00+03	2017-08-08 19:33:00+03
30288	PG0163	2017-08-08 15:15:00+03	2017-08-08 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-08 15:16:00+03	2017-08-08 15:46:00+03
30289	PG0163	2017-08-04 15:15:00+03	2017-08-04 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-04 15:16:00+03	2017-08-04 15:46:00+03
30290	PG0162	2017-08-04 19:00:00+03	2017-08-04 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-04 19:05:00+03	2017-08-04 19:35:00+03
30291	PG0161	2017-08-04 20:20:00+03	2017-08-04 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-04 23:40:00+03	2017-08-05 00:10:00+03
30292	PG0161	2017-09-05 20:20:00+03	2017-09-05 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30293	PG0162	2017-09-05 19:00:00+03	2017-09-05 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30294	PG0163	2017-09-05 15:15:00+03	2017-09-05 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30295	PG0163	2017-08-03 15:15:00+03	2017-08-03 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-03 15:15:00+03	2017-08-03 15:45:00+03
30296	PG0162	2017-08-03 19:00:00+03	2017-08-03 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-03 19:02:00+03	2017-08-03 19:32:00+03
30297	PG0161	2017-08-03 20:20:00+03	2017-08-03 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-03 20:23:00+03	2017-08-03 20:53:00+03
30298	PG0161	2017-08-09 20:20:00+03	2017-08-09 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-09 20:24:00+03	2017-08-09 20:54:00+03
30299	PG0162	2017-08-09 19:00:00+03	2017-08-09 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-09 19:03:00+03	2017-08-09 19:33:00+03
30300	PG0163	2017-08-09 15:15:00+03	2017-08-09 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-09 15:19:00+03	2017-08-09 15:49:00+03
30301	PG0163	2017-09-02 15:15:00+03	2017-09-02 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30302	PG0162	2017-09-02 19:00:00+03	2017-09-02 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30303	PG0161	2017-09-02 20:20:00+03	2017-09-02 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30304	PG0161	2017-09-06 20:20:00+03	2017-09-06 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30305	PG0162	2017-09-06 19:00:00+03	2017-09-06 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30306	PG0163	2017-09-06 15:15:00+03	2017-09-06 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30307	PG0163	2017-08-02 15:15:00+03	2017-08-02 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-02 15:23:00+03	2017-08-02 15:53:00+03
30308	PG0162	2017-08-02 19:00:00+03	2017-08-02 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-02 19:01:00+03	2017-08-02 19:31:00+03
30309	PG0161	2017-08-02 20:20:00+03	2017-08-02 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-02 20:22:00+03	2017-08-02 20:52:00+03
30310	PG0161	2017-08-10 20:20:00+03	2017-08-10 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-10 20:22:00+03	2017-08-10 20:52:00+03
30311	PG0162	2017-08-10 19:00:00+03	2017-08-10 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-10 19:01:00+03	2017-08-10 19:31:00+03
30312	PG0163	2017-08-10 15:15:00+03	2017-08-10 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-10 15:19:00+03	2017-08-10 15:49:00+03
30313	PG0163	2017-08-01 15:15:00+03	2017-08-01 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-01 15:19:00+03	2017-08-01 15:49:00+03
30314	PG0162	2017-08-01 19:00:00+03	2017-08-01 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-01 19:05:00+03	2017-08-01 19:34:00+03
30315	PG0161	2017-08-01 20:20:00+03	2017-08-01 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-01 20:24:00+03	2017-08-01 20:54:00+03
30316	PG0161	2017-08-11 20:20:00+03	2017-08-11 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-11 20:21:00+03	2017-08-11 20:51:00+03
30317	PG0162	2017-08-11 19:00:00+03	2017-08-11 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-11 19:01:00+03	2017-08-11 19:31:00+03
30318	PG0163	2017-08-11 15:15:00+03	2017-08-11 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-11 15:15:00+03	2017-08-11 15:45:00+03
30319	PG0161	2017-09-07 20:20:00+03	2017-09-07 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30320	PG0162	2017-09-07 19:00:00+03	2017-09-07 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30321	PG0163	2017-09-07 15:15:00+03	2017-09-07 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30322	PG0163	2017-07-31 15:15:00+03	2017-07-31 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-31 15:17:00+03	2017-07-31 15:47:00+03
30323	PG0162	2017-07-31 19:00:00+03	2017-07-31 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-31 19:04:00+03	2017-07-31 19:34:00+03
30324	PG0161	2017-07-31 20:20:00+03	2017-07-31 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-31 20:23:00+03	2017-07-31 20:53:00+03
30325	PG0163	2017-09-01 15:15:00+03	2017-09-01 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30326	PG0162	2017-09-01 19:00:00+03	2017-09-01 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30327	PG0161	2017-09-01 20:20:00+03	2017-09-01 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30328	PG0161	2017-08-12 20:20:00+03	2017-08-12 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-12 20:26:00+03	2017-08-12 20:56:00+03
30329	PG0162	2017-08-12 19:00:00+03	2017-08-12 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-12 19:04:00+03	2017-08-12 19:34:00+03
30330	PG0163	2017-08-12 15:15:00+03	2017-08-12 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-12 15:19:00+03	2017-08-12 15:49:00+03
30331	PG0163	2017-07-30 15:15:00+03	2017-07-30 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-30 15:20:00+03	2017-07-30 15:50:00+03
30332	PG0162	2017-07-30 19:00:00+03	2017-07-30 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-30 19:03:00+03	2017-07-30 19:33:00+03
30333	PG0161	2017-07-30 20:20:00+03	2017-07-30 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-30 20:23:00+03	2017-07-30 20:53:00+03
30334	PG0161	2017-08-13 20:20:00+03	2017-08-13 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-13 20:24:00+03	2017-08-13 20:54:00+03
30335	PG0162	2017-08-13 19:00:00+03	2017-08-13 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-13 19:01:00+03	2017-08-13 19:31:00+03
30336	PG0163	2017-08-13 15:15:00+03	2017-08-13 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-13 15:18:00+03	2017-08-13 15:48:00+03
30337	PG0161	2017-09-08 20:20:00+03	2017-09-08 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30338	PG0163	2017-09-08 15:15:00+03	2017-09-08 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30339	PG0163	2017-07-29 15:15:00+03	2017-07-29 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-29 15:20:00+03	2017-07-29 15:50:00+03
30340	PG0162	2017-07-29 19:00:00+03	2017-07-29 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-29 19:02:00+03	2017-07-29 19:32:00+03
30341	PG0161	2017-07-29 20:20:00+03	2017-07-29 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-29 20:21:00+03	2017-07-29 20:52:00+03
30342	PG0163	2017-08-31 15:15:00+03	2017-08-31 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30343	PG0162	2017-08-31 19:00:00+03	2017-08-31 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30344	PG0161	2017-08-31 20:20:00+03	2017-08-31 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30345	PG0161	2017-08-14 20:20:00+03	2017-08-14 20:50:00+03	BZK	SVO	Arrived	SU9	2017-08-14 20:24:00+03	2017-08-14 20:55:00+03
30346	PG0162	2017-08-14 19:00:00+03	2017-08-14 19:30:00+03	BZK	SVO	Arrived	SU9	2017-08-14 19:01:00+03	2017-08-14 19:31:00+03
30347	PG0163	2017-08-14 15:15:00+03	2017-08-14 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-14 15:17:00+03	2017-08-14 15:48:00+03
30348	PG0163	2017-07-28 15:15:00+03	2017-07-28 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-28 15:18:00+03	2017-07-28 15:48:00+03
30349	PG0162	2017-07-28 19:00:00+03	2017-07-28 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-28 19:01:00+03	2017-07-28 19:31:00+03
30350	PG0161	2017-07-28 20:20:00+03	2017-07-28 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-28 20:25:00+03	2017-07-28 20:55:00+03
30351	PG0161	2017-09-09 20:20:00+03	2017-09-09 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30352	PG0162	2017-09-09 19:00:00+03	2017-09-09 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30353	PG0163	2017-09-09 15:15:00+03	2017-09-09 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30354	PG0161	2017-08-15 20:20:00+03	2017-08-15 20:50:00+03	BZK	SVO	On Time	SU9	\N	\N
30355	PG0162	2017-08-15 19:00:00+03	2017-08-15 19:30:00+03	BZK	SVO	On Time	SU9	\N	\N
30356	PG0163	2017-08-15 15:15:00+03	2017-08-15 15:45:00+03	BZK	SVO	Arrived	SU9	2017-08-15 15:18:00+03	2017-08-15 15:48:00+03
30357	PG0163	2017-07-27 15:15:00+03	2017-07-27 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-27 15:18:00+03	2017-07-27 15:48:00+03
30358	PG0162	2017-07-27 19:00:00+03	2017-07-27 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-27 19:05:00+03	2017-07-27 19:35:00+03
30359	PG0161	2017-07-27 20:20:00+03	2017-07-27 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-27 20:24:00+03	2017-07-27 20:54:00+03
30360	PG0163	2017-08-30 15:15:00+03	2017-08-30 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30361	PG0162	2017-08-30 19:00:00+03	2017-08-30 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30362	PG0161	2017-08-30 20:20:00+03	2017-08-30 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30363	PG0161	2017-08-16 20:20:00+03	2017-08-16 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30364	PG0162	2017-08-16 19:00:00+03	2017-08-16 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30365	PG0163	2017-08-16 15:15:00+03	2017-08-16 15:45:00+03	BZK	SVO	On Time	SU9	\N	\N
30366	PG0163	2017-07-26 15:15:00+03	2017-07-26 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-26 15:17:00+03	2017-07-26 15:47:00+03
30367	PG0162	2017-07-26 19:00:00+03	2017-07-26 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-26 19:04:00+03	2017-07-26 19:34:00+03
30368	PG0161	2017-07-26 20:20:00+03	2017-07-26 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-26 20:24:00+03	2017-07-26 20:54:00+03
30369	PG0161	2017-09-10 20:20:00+03	2017-09-10 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30370	PG0162	2017-09-10 19:00:00+03	2017-09-10 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30371	PG0163	2017-09-10 15:15:00+03	2017-09-10 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30372	PG0163	2017-07-25 15:15:00+03	2017-07-25 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-25 15:17:00+03	2017-07-25 15:47:00+03
30373	PG0162	2017-07-25 19:00:00+03	2017-07-25 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-25 19:05:00+03	2017-07-25 19:35:00+03
30374	PG0161	2017-07-25 20:20:00+03	2017-07-25 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-25 20:22:00+03	2017-07-25 20:52:00+03
30375	PG0161	2017-08-17 20:20:00+03	2017-08-17 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30376	PG0162	2017-08-17 19:00:00+03	2017-08-17 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30377	PG0163	2017-08-17 15:15:00+03	2017-08-17 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30378	PG0163	2017-08-29 15:15:00+03	2017-08-29 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30379	PG0162	2017-08-29 19:00:00+03	2017-08-29 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30380	PG0161	2017-08-29 20:20:00+03	2017-08-29 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30381	PG0163	2017-07-24 15:15:00+03	2017-07-24 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-24 15:16:00+03	2017-07-24 15:46:00+03
30382	PG0162	2017-07-24 19:00:00+03	2017-07-24 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-24 19:04:00+03	2017-07-24 19:34:00+03
30383	PG0161	2017-07-24 20:20:00+03	2017-07-24 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-24 20:23:00+03	2017-07-24 20:53:00+03
30384	PG0161	2017-08-18 20:20:00+03	2017-08-18 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30385	PG0162	2017-08-18 19:00:00+03	2017-08-18 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30386	PG0163	2017-08-18 15:15:00+03	2017-08-18 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30387	PG0161	2017-08-25 20:20:00+03	2017-08-25 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30388	PG0161	2017-09-11 20:20:00+03	2017-09-11 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30389	PG0162	2017-09-11 19:00:00+03	2017-09-11 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30390	PG0163	2017-09-11 15:15:00+03	2017-09-11 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30391	PG0163	2017-07-23 15:15:00+03	2017-07-23 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-23 15:18:00+03	2017-07-23 15:48:00+03
30392	PG0162	2017-07-23 19:00:00+03	2017-07-23 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-23 19:05:00+03	2017-07-23 19:35:00+03
30393	PG0161	2017-07-23 20:20:00+03	2017-07-23 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-23 20:24:00+03	2017-07-23 20:54:00+03
30394	PG0161	2017-08-19 20:20:00+03	2017-08-19 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30395	PG0162	2017-08-19 19:00:00+03	2017-08-19 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30396	PG0163	2017-08-19 15:15:00+03	2017-08-19 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30397	PG0163	2017-08-28 15:15:00+03	2017-08-28 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30398	PG0162	2017-08-28 19:00:00+03	2017-08-28 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30399	PG0161	2017-08-28 20:20:00+03	2017-08-28 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30400	PG0163	2017-07-22 15:15:00+03	2017-07-22 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-22 15:16:00+03	2017-07-22 15:46:00+03
30401	PG0162	2017-07-22 19:00:00+03	2017-07-22 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-22 19:03:00+03	2017-07-22 19:33:00+03
30402	PG0161	2017-07-22 20:20:00+03	2017-07-22 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-22 20:23:00+03	2017-07-22 20:53:00+03
30403	PG0161	2017-08-20 20:20:00+03	2017-08-20 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30404	PG0162	2017-08-20 19:00:00+03	2017-08-20 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30405	PG0163	2017-08-20 15:15:00+03	2017-08-20 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30406	PG0161	2017-09-12 20:20:00+03	2017-09-12 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30407	PG0162	2017-09-12 19:00:00+03	2017-09-12 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30408	PG0163	2017-09-12 15:15:00+03	2017-09-12 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30409	PG0163	2017-07-21 15:15:00+03	2017-07-21 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-21 18:39:00+03	2017-07-21 19:10:00+03
30410	PG0162	2017-07-21 19:00:00+03	2017-07-21 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-21 19:02:00+03	2017-07-21 19:32:00+03
30411	PG0161	2017-07-21 20:20:00+03	2017-07-21 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-21 20:24:00+03	2017-07-21 20:54:00+03
30412	PG0161	2017-08-21 20:20:00+03	2017-08-21 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30413	PG0162	2017-08-21 19:00:00+03	2017-08-21 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30414	PG0163	2017-08-21 15:15:00+03	2017-08-21 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30415	PG0163	2017-07-20 15:15:00+03	2017-07-20 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-20 15:17:00+03	2017-07-20 15:47:00+03
30416	PG0162	2017-07-20 19:00:00+03	2017-07-20 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-20 19:03:00+03	2017-07-20 19:33:00+03
30417	PG0161	2017-07-20 20:20:00+03	2017-07-20 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-20 23:20:00+03	2017-07-20 23:50:00+03
30418	PG0162	2017-08-25 19:00:00+03	2017-08-25 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30419	PG0163	2017-08-27 15:15:00+03	2017-08-27 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30420	PG0162	2017-08-27 19:00:00+03	2017-08-27 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30421	PG0161	2017-08-27 20:20:00+03	2017-08-27 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30422	PG0161	2017-09-13 20:20:00+03	2017-09-13 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30423	PG0162	2017-09-13 19:00:00+03	2017-09-13 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30424	PG0163	2017-09-13 15:15:00+03	2017-09-13 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30425	PG0161	2017-08-22 20:20:00+03	2017-08-22 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30426	PG0162	2017-08-22 19:00:00+03	2017-08-22 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30427	PG0163	2017-08-22 15:15:00+03	2017-08-22 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30428	PG0163	2017-07-19 15:15:00+03	2017-07-19 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-19 15:17:00+03	2017-07-19 15:47:00+03
30429	PG0162	2017-07-19 19:00:00+03	2017-07-19 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-19 19:03:00+03	2017-07-19 19:33:00+03
30430	PG0161	2017-07-19 20:20:00+03	2017-07-19 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-19 20:26:00+03	2017-07-19 20:56:00+03
30431	PG0161	2017-09-14 20:20:00+03	2017-09-14 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30432	PG0162	2017-09-14 19:00:00+03	2017-09-14 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30433	PG0163	2017-09-14 15:15:00+03	2017-09-14 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30434	PG0163	2017-07-18 15:15:00+03	2017-07-18 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-18 15:17:00+03	2017-07-18 15:47:00+03
30435	PG0162	2017-07-18 19:00:00+03	2017-07-18 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-18 19:04:00+03	2017-07-18 19:34:00+03
30436	PG0161	2017-07-18 20:20:00+03	2017-07-18 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-18 20:22:00+03	2017-07-18 20:52:00+03
30437	PG0161	2017-08-23 20:20:00+03	2017-08-23 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30438	PG0162	2017-08-23 19:00:00+03	2017-08-23 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30439	PG0163	2017-08-23 15:15:00+03	2017-08-23 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30440	PG0163	2017-08-25 15:15:00+03	2017-08-25 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30441	PG0163	2017-08-26 15:15:00+03	2017-08-26 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30442	PG0162	2017-08-26 19:00:00+03	2017-08-26 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30443	PG0161	2017-08-26 20:20:00+03	2017-08-26 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30444	PG0163	2017-07-17 15:15:00+03	2017-07-17 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-17 15:18:00+03	2017-07-17 15:48:00+03
30445	PG0162	2017-07-17 19:00:00+03	2017-07-17 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-17 19:04:00+03	2017-07-17 19:34:00+03
30446	PG0161	2017-07-17 20:20:00+03	2017-07-17 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-17 20:22:00+03	2017-07-17 20:51:00+03
30447	PG0161	2017-08-24 20:20:00+03	2017-08-24 20:50:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30448	PG0162	2017-08-24 19:00:00+03	2017-08-24 19:30:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30449	PG0163	2017-08-24 15:15:00+03	2017-08-24 15:45:00+03	BZK	SVO	Scheduled	SU9	\N	\N
30450	PG0163	2017-07-16 15:15:00+03	2017-07-16 15:45:00+03	BZK	SVO	Arrived	SU9	2017-07-16 15:16:00+03	2017-07-16 15:46:00+03
30451	PG0162	2017-07-16 19:00:00+03	2017-07-16 19:30:00+03	BZK	SVO	Arrived	SU9	2017-07-16 19:00:00+03	2017-07-16 19:30:00+03
30452	PG0161	2017-07-16 20:20:00+03	2017-07-16 20:50:00+03	BZK	SVO	Arrived	SU9	2017-07-16 20:23:00+03	2017-07-16 20:53:00+03
30453	PG0649	2017-07-23 15:35:00+03	2017-07-23 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-23 15:36:00+03	2017-07-23 16:01:00+03
30454	PG0649	2017-08-28 15:35:00+03	2017-08-28 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30455	PG0649	2017-09-09 15:35:00+03	2017-09-09 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30456	PG0649	2017-08-14 15:35:00+03	2017-08-14 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-14 15:39:00+03	2017-08-14 16:04:00+03
30457	PG0649	2017-09-08 15:35:00+03	2017-09-08 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30458	PG0649	2017-07-21 15:35:00+03	2017-07-21 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-21 15:37:00+03	2017-07-21 16:02:00+03
30459	PG0649	2017-09-01 15:35:00+03	2017-09-01 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30460	PG0649	2017-09-02 15:35:00+03	2017-09-02 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30461	PG0649	2017-08-29 15:35:00+03	2017-08-29 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30462	PG0649	2017-07-19 15:35:00+03	2017-07-19 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-19 18:42:00+03	2017-07-19 19:07:00+03
30463	PG0649	2017-07-28 15:35:00+03	2017-07-28 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-28 15:42:00+03	2017-07-28 16:07:00+03
30464	PG0649	2017-09-12 15:35:00+03	2017-09-12 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30465	PG0649	2017-08-13 15:35:00+03	2017-08-13 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-13 15:38:00+03	2017-08-13 16:03:00+03
30466	PG0649	2017-07-22 15:35:00+03	2017-07-22 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-22 15:39:00+03	2017-07-22 16:04:00+03
30467	PG0649	2017-08-21 15:35:00+03	2017-08-21 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30468	PG0649	2017-09-11 15:35:00+03	2017-09-11 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30469	PG0649	2017-08-19 15:35:00+03	2017-08-19 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30470	PG0649	2017-08-16 15:35:00+03	2017-08-16 16:00:00+03	BZK	EGO	On Time	SU9	\N	\N
30471	PG0649	2017-07-16 15:35:00+03	2017-07-16 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-16 15:38:00+03	2017-07-16 16:03:00+03
30472	PG0649	2017-07-30 15:35:00+03	2017-07-30 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-30 15:37:00+03	2017-07-30 16:02:00+03
30473	PG0649	2017-07-18 15:35:00+03	2017-07-18 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-18 15:38:00+03	2017-07-18 16:03:00+03
30474	PG0649	2017-08-20 15:35:00+03	2017-08-20 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30475	PG0649	2017-08-15 15:35:00+03	2017-08-15 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-15 15:41:00+03	2017-08-15 16:06:00+03
30476	PG0649	2017-09-03 15:35:00+03	2017-09-03 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30477	PG0649	2017-08-22 15:35:00+03	2017-08-22 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30478	PG0649	2017-09-14 15:35:00+03	2017-09-14 16:00:00+03	BZK	EGO	Cancelled	SU9	\N	\N
30479	PG0649	2017-08-09 15:35:00+03	2017-08-09 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-09 15:41:00+03	2017-08-09 16:06:00+03
30480	PG0649	2017-09-13 15:35:00+03	2017-09-13 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30481	PG0649	2017-08-24 15:35:00+03	2017-08-24 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30482	PG0649	2017-08-01 15:35:00+03	2017-08-01 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-01 15:36:00+03	2017-08-01 16:01:00+03
30483	PG0649	2017-08-27 15:35:00+03	2017-08-27 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30484	PG0649	2017-08-04 15:35:00+03	2017-08-04 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-04 15:38:00+03	2017-08-04 16:03:00+03
30485	PG0649	2017-08-05 15:35:00+03	2017-08-05 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-05 15:37:00+03	2017-08-05 16:02:00+03
30486	PG0649	2017-09-06 15:35:00+03	2017-09-06 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30487	PG0649	2017-08-17 15:35:00+03	2017-08-17 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30488	PG0649	2017-07-25 15:35:00+03	2017-07-25 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-25 15:38:00+03	2017-07-25 16:03:00+03
30489	PG0649	2017-08-25 15:35:00+03	2017-08-25 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30490	PG0649	2017-09-10 15:35:00+03	2017-09-10 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30491	PG0649	2017-08-07 15:35:00+03	2017-08-07 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-07 15:39:00+03	2017-08-07 16:04:00+03
30492	PG0649	2017-08-30 15:35:00+03	2017-08-30 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30493	PG0649	2017-08-23 15:35:00+03	2017-08-23 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30494	PG0649	2017-08-03 15:35:00+03	2017-08-03 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-03 15:40:00+03	2017-08-03 16:05:00+03
30495	PG0649	2017-07-27 15:35:00+03	2017-07-27 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-27 15:36:00+03	2017-07-27 16:00:00+03
30496	PG0649	2017-08-26 15:35:00+03	2017-08-26 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30497	PG0649	2017-07-29 15:35:00+03	2017-07-29 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-29 15:37:00+03	2017-07-29 16:02:00+03
30498	PG0649	2017-08-08 15:35:00+03	2017-08-08 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-08 15:41:00+03	2017-08-08 16:06:00+03
30499	PG0649	2017-07-24 15:35:00+03	2017-07-24 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-24 19:04:00+03	2017-07-24 19:29:00+03
30500	PG0649	2017-09-04 15:35:00+03	2017-09-04 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30501	PG0649	2017-09-07 15:35:00+03	2017-09-07 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30502	PG0649	2017-08-02 15:35:00+03	2017-08-02 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-02 15:39:00+03	2017-08-02 16:05:00+03
30503	PG0649	2017-09-05 15:35:00+03	2017-09-05 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30504	PG0649	2017-07-20 15:35:00+03	2017-07-20 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-20 15:36:00+03	2017-07-20 16:01:00+03
30505	PG0649	2017-08-11 15:35:00+03	2017-08-11 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-11 15:40:00+03	2017-08-11 16:05:00+03
30506	PG0649	2017-08-12 15:35:00+03	2017-08-12 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-12 15:40:00+03	2017-08-12 16:05:00+03
30507	PG0649	2017-07-26 15:35:00+03	2017-07-26 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-26 15:37:00+03	2017-07-26 16:02:00+03
30508	PG0649	2017-08-10 15:35:00+03	2017-08-10 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-10 15:40:00+03	2017-08-10 16:05:00+03
30509	PG0649	2017-07-31 15:35:00+03	2017-07-31 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-31 15:40:00+03	2017-07-31 16:05:00+03
30510	PG0649	2017-07-17 15:35:00+03	2017-07-17 16:00:00+03	BZK	EGO	Arrived	SU9	2017-07-17 15:36:00+03	2017-07-17 16:01:00+03
30511	PG0649	2017-08-06 15:35:00+03	2017-08-06 16:00:00+03	BZK	EGO	Arrived	SU9	2017-08-06 15:39:00+03	2017-08-06 16:04:00+03
30512	PG0649	2017-08-18 15:35:00+03	2017-08-18 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30513	PG0649	2017-08-31 15:35:00+03	2017-08-31 16:00:00+03	BZK	EGO	Scheduled	SU9	\N	\N
30514	PG0562	2017-07-19 17:00:00+03	2017-07-19 18:45:00+03	AER	VKO	Arrived	763	2017-07-19 17:01:00+03	2017-07-19 18:44:00+03
30515	PG0562	2017-08-21 17:00:00+03	2017-08-21 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30516	PG0562	2017-08-04 17:00:00+03	2017-08-04 18:45:00+03	AER	VKO	Arrived	763	2017-08-04 17:05:00+03	2017-08-04 18:51:00+03
30517	PG0562	2017-08-07 17:00:00+03	2017-08-07 18:45:00+03	AER	VKO	Arrived	763	2017-08-07 17:06:00+03	2017-08-07 18:51:00+03
30518	PG0562	2017-09-11 17:00:00+03	2017-09-11 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30519	PG0562	2017-07-22 17:00:00+03	2017-07-22 18:45:00+03	AER	VKO	Arrived	763	2017-07-22 17:03:00+03	2017-07-22 18:46:00+03
30520	PG0562	2017-07-29 17:00:00+03	2017-07-29 18:45:00+03	AER	VKO	Arrived	763	2017-07-29 17:02:00+03	2017-07-29 18:48:00+03
30521	PG0562	2017-07-20 17:00:00+03	2017-07-20 18:45:00+03	AER	VKO	Arrived	763	2017-07-20 17:05:00+03	2017-07-20 18:51:00+03
30522	PG0562	2017-09-09 17:00:00+03	2017-09-09 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30523	PG0562	2017-08-20 17:00:00+03	2017-08-20 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30524	PG0562	2017-07-24 17:00:00+03	2017-07-24 18:45:00+03	AER	VKO	Arrived	763	2017-07-24 17:06:00+03	2017-07-24 18:52:00+03
30525	PG0562	2017-08-14 17:00:00+03	2017-08-14 18:45:00+03	AER	VKO	Arrived	763	2017-08-14 17:03:00+03	2017-08-14 18:47:00+03
30526	PG0562	2017-08-11 17:00:00+03	2017-08-11 18:45:00+03	AER	VKO	Arrived	763	2017-08-11 17:02:00+03	2017-08-11 18:47:00+03
30527	PG0562	2017-08-02 17:00:00+03	2017-08-02 18:45:00+03	AER	VKO	Arrived	763	2017-08-02 17:06:00+03	2017-08-02 18:53:00+03
30528	PG0562	2017-08-26 17:00:00+03	2017-08-26 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30529	PG0562	2017-09-08 17:00:00+03	2017-09-08 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30530	PG0562	2017-07-23 17:00:00+03	2017-07-23 18:45:00+03	AER	VKO	Arrived	763	2017-07-23 17:04:00+03	2017-07-23 18:48:00+03
30531	PG0562	2017-07-16 17:00:00+03	2017-07-16 18:45:00+03	AER	VKO	Arrived	763	2017-07-16 17:04:00+03	2017-07-16 18:49:00+03
30532	PG0562	2017-08-16 17:00:00+03	2017-08-16 18:45:00+03	AER	VKO	On Time	763	\N	\N
30533	PG0562	2017-09-10 17:00:00+03	2017-09-10 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30534	PG0562	2017-09-12 17:00:00+03	2017-09-12 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30535	PG0562	2017-08-27 17:00:00+03	2017-08-27 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30536	PG0562	2017-08-30 17:00:00+03	2017-08-30 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30537	PG0562	2017-08-08 17:00:00+03	2017-08-08 18:45:00+03	AER	VKO	Arrived	763	2017-08-08 17:05:00+03	2017-08-08 18:50:00+03
30538	PG0562	2017-09-06 17:00:00+03	2017-09-06 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30539	PG0562	2017-08-28 17:00:00+03	2017-08-28 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30540	PG0562	2017-08-25 17:00:00+03	2017-08-25 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30541	PG0562	2017-07-17 17:00:00+03	2017-07-17 18:45:00+03	AER	VKO	Arrived	763	2017-07-17 17:03:00+03	2017-07-17 18:47:00+03
30542	PG0562	2017-08-17 17:00:00+03	2017-08-17 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30543	PG0562	2017-07-30 17:00:00+03	2017-07-30 18:45:00+03	AER	VKO	Arrived	763	2017-07-30 17:04:00+03	2017-07-30 18:50:00+03
30544	PG0562	2017-07-25 17:00:00+03	2017-07-25 18:45:00+03	AER	VKO	Arrived	763	2017-07-25 17:04:00+03	2017-07-25 18:48:00+03
30545	PG0562	2017-09-13 17:00:00+03	2017-09-13 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30546	PG0562	2017-08-24 17:00:00+03	2017-08-24 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30547	PG0562	2017-08-05 17:00:00+03	2017-08-05 18:45:00+03	AER	VKO	Arrived	763	2017-08-05 17:03:00+03	2017-08-05 18:48:00+03
30548	PG0562	2017-08-18 17:00:00+03	2017-08-18 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30549	PG0562	2017-07-28 17:00:00+03	2017-07-28 18:45:00+03	AER	VKO	Arrived	763	2017-07-28 17:04:00+03	2017-07-28 18:49:00+03
30550	PG0562	2017-08-06 17:00:00+03	2017-08-06 18:45:00+03	AER	VKO	Arrived	763	2017-08-06 17:03:00+03	2017-08-06 18:47:00+03
30551	PG0562	2017-07-21 17:00:00+03	2017-07-21 18:45:00+03	AER	VKO	Arrived	763	2017-07-21 17:05:00+03	2017-07-21 18:49:00+03
30552	PG0562	2017-09-03 17:00:00+03	2017-09-03 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30553	PG0562	2017-09-14 17:00:00+03	2017-09-14 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30554	PG0562	2017-08-23 17:00:00+03	2017-08-23 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30555	PG0562	2017-08-01 17:00:00+03	2017-08-01 18:45:00+03	AER	VKO	Arrived	763	2017-08-01 17:05:00+03	2017-08-01 18:51:00+03
30556	PG0562	2017-08-15 17:00:00+03	2017-08-15 18:45:00+03	AER	VKO	Departed	763	2017-08-15 17:03:00+03	\N
30557	PG0562	2017-09-01 17:00:00+03	2017-09-01 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30558	PG0562	2017-08-31 17:00:00+03	2017-08-31 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30559	PG0562	2017-07-18 17:00:00+03	2017-07-18 18:45:00+03	AER	VKO	Arrived	763	2017-07-18 17:02:00+03	2017-07-18 18:48:00+03
30560	PG0562	2017-08-13 17:00:00+03	2017-08-13 18:45:00+03	AER	VKO	Arrived	763	2017-08-13 17:03:00+03	2017-08-13 18:49:00+03
30561	PG0562	2017-07-26 17:00:00+03	2017-07-26 18:45:00+03	AER	VKO	Arrived	763	2017-07-26 17:04:00+03	2017-07-26 18:48:00+03
30562	PG0562	2017-08-22 17:00:00+03	2017-08-22 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30563	PG0562	2017-07-31 17:00:00+03	2017-07-31 18:45:00+03	AER	VKO	Arrived	763	2017-07-31 17:02:00+03	2017-07-31 18:48:00+03
30564	PG0562	2017-09-04 17:00:00+03	2017-09-04 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30565	PG0562	2017-08-10 17:00:00+03	2017-08-10 18:45:00+03	AER	VKO	Arrived	763	2017-08-10 17:01:00+03	2017-08-10 18:45:00+03
30566	PG0562	2017-09-05 17:00:00+03	2017-09-05 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30567	PG0562	2017-08-12 17:00:00+03	2017-08-12 18:45:00+03	AER	VKO	Arrived	763	2017-08-12 17:01:00+03	2017-08-12 18:49:00+03
30568	PG0562	2017-08-09 17:00:00+03	2017-08-09 18:45:00+03	AER	VKO	Arrived	763	2017-08-09 19:53:00+03	2017-08-09 21:37:00+03
30569	PG0562	2017-09-02 17:00:00+03	2017-09-02 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30570	PG0562	2017-07-27 17:00:00+03	2017-07-27 18:45:00+03	AER	VKO	Arrived	763	2017-07-27 20:02:00+03	2017-07-27 21:47:00+03
30571	PG0562	2017-08-29 17:00:00+03	2017-08-29 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30572	PG0562	2017-08-03 17:00:00+03	2017-08-03 18:45:00+03	AER	VKO	Arrived	763	2017-08-03 17:03:00+03	2017-08-03 18:49:00+03
30573	PG0562	2017-08-19 17:00:00+03	2017-08-19 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30574	PG0562	2017-09-07 17:00:00+03	2017-09-07 18:45:00+03	AER	VKO	Scheduled	763	\N	\N
30575	PG0013	2017-08-28 18:15:00+03	2017-08-28 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30576	PG0013	2017-08-12 18:15:00+03	2017-08-12 20:00:00+03	AER	SVO	Arrived	773	2017-08-12 18:19:00+03	2017-08-12 20:03:00+03
30577	PG0013	2017-08-25 18:15:00+03	2017-08-25 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30578	PG0013	2017-09-10 18:15:00+03	2017-09-10 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30579	PG0013	2017-08-22 18:15:00+03	2017-08-22 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30580	PG0013	2017-07-22 18:15:00+03	2017-07-22 20:00:00+03	AER	SVO	Arrived	773	2017-07-22 18:15:00+03	2017-07-22 19:59:00+03
30581	PG0013	2017-07-29 18:15:00+03	2017-07-29 20:00:00+03	AER	SVO	Arrived	773	2017-07-29 18:19:00+03	2017-07-29 20:04:00+03
30582	PG0013	2017-08-03 18:15:00+03	2017-08-03 20:00:00+03	AER	SVO	Arrived	773	2017-08-03 18:18:00+03	2017-08-03 20:01:00+03
30583	PG0013	2017-08-20 18:15:00+03	2017-08-20 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30584	PG0013	2017-08-30 18:15:00+03	2017-08-30 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30585	PG0013	2017-07-18 18:15:00+03	2017-07-18 20:00:00+03	AER	SVO	Arrived	773	2017-07-18 18:20:00+03	2017-07-18 20:04:00+03
30586	PG0013	2017-07-28 18:15:00+03	2017-07-28 20:00:00+03	AER	SVO	Arrived	773	2017-07-28 18:19:00+03	2017-07-28 20:03:00+03
30587	PG0013	2017-09-05 18:15:00+03	2017-09-05 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30588	PG0013	2017-08-19 18:15:00+03	2017-08-19 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30589	PG0013	2017-07-17 18:15:00+03	2017-07-17 20:00:00+03	AER	SVO	Arrived	773	2017-07-17 18:17:00+03	2017-07-17 20:02:00+03
30590	PG0013	2017-08-05 18:15:00+03	2017-08-05 20:00:00+03	AER	SVO	Arrived	773	2017-08-05 18:18:00+03	2017-08-05 20:04:00+03
30591	PG0013	2017-08-21 18:15:00+03	2017-08-21 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30592	PG0013	2017-07-30 18:15:00+03	2017-07-30 20:00:00+03	AER	SVO	Arrived	773	2017-07-30 18:17:00+03	2017-07-30 20:02:00+03
30593	PG0013	2017-08-27 18:15:00+03	2017-08-27 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30594	PG0013	2017-07-20 18:15:00+03	2017-07-20 20:00:00+03	AER	SVO	Arrived	773	2017-07-20 18:16:00+03	2017-07-20 20:01:00+03
30595	PG0013	2017-07-19 18:15:00+03	2017-07-19 20:00:00+03	AER	SVO	Arrived	773	2017-07-19 18:22:00+03	2017-07-19 20:08:00+03
30596	PG0013	2017-08-02 18:15:00+03	2017-08-02 20:00:00+03	AER	SVO	Arrived	773	2017-08-02 18:19:00+03	2017-08-02 20:04:00+03
30597	PG0013	2017-08-23 18:15:00+03	2017-08-23 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30598	PG0013	2017-07-25 18:15:00+03	2017-07-25 20:00:00+03	AER	SVO	Arrived	773	2017-07-25 18:16:00+03	2017-07-25 20:01:00+03
30599	PG0013	2017-09-11 18:15:00+03	2017-09-11 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30600	PG0013	2017-08-18 18:15:00+03	2017-08-18 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30601	PG0013	2017-09-12 18:15:00+03	2017-09-12 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30602	PG0013	2017-07-23 18:15:00+03	2017-07-23 20:00:00+03	AER	SVO	Arrived	773	2017-07-23 18:23:00+03	2017-07-23 20:07:00+03
30603	PG0013	2017-07-21 18:15:00+03	2017-07-21 20:00:00+03	AER	SVO	Arrived	773	2017-07-21 18:17:00+03	2017-07-21 20:01:00+03
30604	PG0013	2017-08-13 18:15:00+03	2017-08-13 20:00:00+03	AER	SVO	Arrived	773	2017-08-13 18:20:00+03	2017-08-13 20:04:00+03
30605	PG0013	2017-08-26 18:15:00+03	2017-08-26 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30606	PG0013	2017-07-24 18:15:00+03	2017-07-24 20:00:00+03	AER	SVO	Arrived	773	2017-07-24 18:21:00+03	2017-07-24 20:07:00+03
30607	PG0013	2017-08-29 18:15:00+03	2017-08-29 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30608	PG0013	2017-09-08 18:15:00+03	2017-09-08 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30609	PG0013	2017-09-04 18:15:00+03	2017-09-04 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30610	PG0013	2017-09-01 18:15:00+03	2017-09-01 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30611	PG0013	2017-08-11 18:15:00+03	2017-08-11 20:00:00+03	AER	SVO	Arrived	773	2017-08-11 18:17:00+03	2017-08-11 20:02:00+03
30612	PG0013	2017-09-09 18:15:00+03	2017-09-09 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30613	PG0013	2017-09-02 18:15:00+03	2017-09-02 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30614	PG0013	2017-08-15 18:15:00+03	2017-08-15 20:00:00+03	AER	SVO	On Time	773	\N	\N
30615	PG0013	2017-08-06 18:15:00+03	2017-08-06 20:00:00+03	AER	SVO	Arrived	773	2017-08-06 18:19:00+03	2017-08-06 20:02:00+03
30616	PG0013	2017-09-14 18:15:00+03	2017-09-14 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30617	PG0013	2017-08-16 18:15:00+03	2017-08-16 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30618	PG0013	2017-08-07 18:15:00+03	2017-08-07 20:00:00+03	AER	SVO	Arrived	773	2017-08-07 18:20:00+03	2017-08-07 20:03:00+03
30619	PG0013	2017-07-27 18:15:00+03	2017-07-27 20:00:00+03	AER	SVO	Arrived	773	2017-07-27 21:44:00+03	2017-07-27 23:31:00+03
30620	PG0013	2017-08-09 18:15:00+03	2017-08-09 20:00:00+03	AER	SVO	Arrived	773	2017-08-09 18:17:00+03	2017-08-09 20:03:00+03
30621	PG0013	2017-08-31 18:15:00+03	2017-08-31 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30622	PG0013	2017-08-24 18:15:00+03	2017-08-24 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30623	PG0013	2017-09-06 18:15:00+03	2017-09-06 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30624	PG0013	2017-08-14 18:15:00+03	2017-08-14 20:00:00+03	AER	SVO	Arrived	773	2017-08-14 18:19:00+03	2017-08-14 20:05:00+03
30625	PG0013	2017-07-16 18:15:00+03	2017-07-16 20:00:00+03	AER	SVO	Arrived	773	2017-07-16 18:18:00+03	2017-07-16 20:04:00+03
30626	PG0013	2017-08-10 18:15:00+03	2017-08-10 20:00:00+03	AER	SVO	Arrived	773	2017-08-10 18:18:00+03	2017-08-10 20:02:00+03
30627	PG0013	2017-09-13 18:15:00+03	2017-09-13 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30628	PG0013	2017-07-31 18:15:00+03	2017-07-31 20:00:00+03	AER	SVO	Arrived	773	2017-07-31 18:18:00+03	2017-07-31 20:03:00+03
30629	PG0013	2017-07-26 18:15:00+03	2017-07-26 20:00:00+03	AER	SVO	Arrived	773	2017-07-26 18:18:00+03	2017-07-26 20:05:00+03
30630	PG0013	2017-09-07 18:15:00+03	2017-09-07 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30631	PG0013	2017-08-01 18:15:00+03	2017-08-01 20:00:00+03	AER	SVO	Arrived	773	2017-08-01 18:16:00+03	2017-08-01 20:03:00+03
30632	PG0013	2017-08-04 18:15:00+03	2017-08-04 20:00:00+03	AER	SVO	Arrived	773	2017-08-04 18:17:00+03	2017-08-04 20:04:00+03
30633	PG0013	2017-08-08 18:15:00+03	2017-08-08 20:00:00+03	AER	SVO	Arrived	773	2017-08-08 18:17:00+03	2017-08-08 20:01:00+03
30634	PG0013	2017-08-17 18:15:00+03	2017-08-17 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30635	PG0013	2017-09-03 18:15:00+03	2017-09-03 20:00:00+03	AER	SVO	Scheduled	773	\N	\N
30636	PG0522	2017-08-14 14:10:00+03	2017-08-14 16:00:00+03	AER	KUF	Arrived	733	2017-08-14 14:14:00+03	2017-08-14 16:03:00+03
30637	PG0522	2017-08-30 14:10:00+03	2017-08-30 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30638	PG0522	2017-08-03 14:10:00+03	2017-08-03 16:00:00+03	AER	KUF	Arrived	733	2017-08-03 14:16:00+03	2017-08-03 16:06:00+03
30639	PG0522	2017-08-11 14:10:00+03	2017-08-11 16:00:00+03	AER	KUF	Arrived	733	2017-08-11 14:16:00+03	2017-08-11 16:06:00+03
30640	PG0522	2017-08-20 14:10:00+03	2017-08-20 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30641	PG0522	2017-09-12 14:10:00+03	2017-09-12 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30642	PG0522	2017-08-27 14:10:00+03	2017-08-27 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30643	PG0522	2017-09-09 14:10:00+03	2017-09-09 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30644	PG0522	2017-08-26 14:10:00+03	2017-08-26 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30645	PG0522	2017-07-25 14:10:00+03	2017-07-25 16:00:00+03	AER	KUF	Arrived	733	2017-07-25 14:12:00+03	2017-07-25 16:03:00+03
30646	PG0522	2017-08-29 14:10:00+03	2017-08-29 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30647	PG0522	2017-09-06 14:10:00+03	2017-09-06 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30648	PG0522	2017-08-16 14:10:00+03	2017-08-16 16:00:00+03	AER	KUF	On Time	733	\N	\N
30649	PG0522	2017-07-30 14:10:00+03	2017-07-30 16:00:00+03	AER	KUF	Arrived	733	2017-07-30 14:11:00+03	2017-07-30 16:01:00+03
30650	PG0522	2017-09-01 14:10:00+03	2017-09-01 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30651	PG0522	2017-07-21 14:10:00+03	2017-07-21 16:00:00+03	AER	KUF	Arrived	733	2017-07-21 14:11:00+03	2017-07-21 16:02:00+03
30652	PG0522	2017-07-17 14:10:00+03	2017-07-17 16:00:00+03	AER	KUF	Arrived	733	2017-07-17 14:13:00+03	2017-07-17 16:02:00+03
30653	PG0522	2017-08-02 14:10:00+03	2017-08-02 16:00:00+03	AER	KUF	Arrived	733	2017-08-02 14:14:00+03	2017-08-02 16:01:00+03
30654	PG0522	2017-09-14 14:10:00+03	2017-09-14 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30655	PG0522	2017-08-23 14:10:00+03	2017-08-23 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30656	PG0522	2017-09-13 14:10:00+03	2017-09-13 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30657	PG0522	2017-07-26 14:10:00+03	2017-07-26 16:00:00+03	AER	KUF	Arrived	733	2017-07-26 14:13:00+03	2017-07-26 16:03:00+03
30658	PG0522	2017-08-12 14:10:00+03	2017-08-12 16:00:00+03	AER	KUF	Arrived	733	2017-08-12 14:15:00+03	2017-08-12 16:03:00+03
30659	PG0522	2017-08-15 14:10:00+03	2017-08-15 16:00:00+03	AER	KUF	Arrived	733	2017-08-15 14:16:00+03	2017-08-15 16:08:00+03
30660	PG0522	2017-08-04 14:10:00+03	2017-08-04 16:00:00+03	AER	KUF	Arrived	733	2017-08-04 14:14:00+03	2017-08-04 16:04:00+03
30661	PG0522	2017-09-07 14:10:00+03	2017-09-07 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30662	PG0522	2017-08-31 14:10:00+03	2017-08-31 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30663	PG0522	2017-08-10 14:10:00+03	2017-08-10 16:00:00+03	AER	KUF	Arrived	733	2017-08-10 14:11:00+03	2017-08-10 16:01:00+03
30664	PG0522	2017-08-06 14:10:00+03	2017-08-06 16:00:00+03	AER	KUF	Arrived	733	2017-08-06 14:15:00+03	2017-08-06 16:03:00+03
30665	PG0522	2017-08-19 14:10:00+03	2017-08-19 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30666	PG0522	2017-09-11 14:10:00+03	2017-09-11 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30667	PG0522	2017-09-02 14:10:00+03	2017-09-02 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30668	PG0522	2017-07-29 14:10:00+03	2017-07-29 16:00:00+03	AER	KUF	Arrived	733	2017-07-29 14:13:00+03	2017-07-29 16:02:00+03
30669	PG0522	2017-07-22 14:10:00+03	2017-07-22 16:00:00+03	AER	KUF	Arrived	733	2017-07-22 14:12:00+03	2017-07-22 16:01:00+03
30670	PG0522	2017-08-09 14:10:00+03	2017-08-09 16:00:00+03	AER	KUF	Arrived	733	2017-08-09 14:14:00+03	2017-08-09 16:05:00+03
30671	PG0522	2017-08-21 14:10:00+03	2017-08-21 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30672	PG0522	2017-08-08 14:10:00+03	2017-08-08 16:00:00+03	AER	KUF	Arrived	733	2017-08-08 14:13:00+03	2017-08-08 16:03:00+03
30673	PG0522	2017-07-20 14:10:00+03	2017-07-20 16:00:00+03	AER	KUF	Arrived	733	2017-07-20 14:13:00+03	2017-07-20 16:02:00+03
30674	PG0522	2017-08-07 14:10:00+03	2017-08-07 16:00:00+03	AER	KUF	Arrived	733	2017-08-07 14:16:00+03	2017-08-07 16:07:00+03
30675	PG0522	2017-07-24 14:10:00+03	2017-07-24 16:00:00+03	AER	KUF	Arrived	733	2017-07-24 14:14:00+03	2017-07-24 16:04:00+03
30676	PG0522	2017-08-22 14:10:00+03	2017-08-22 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30677	PG0522	2017-08-01 14:10:00+03	2017-08-01 16:00:00+03	AER	KUF	Arrived	733	2017-08-01 14:13:00+03	2017-08-01 16:05:00+03
30678	PG0522	2017-08-13 14:10:00+03	2017-08-13 16:00:00+03	AER	KUF	Arrived	733	2017-08-13 14:12:00+03	2017-08-13 16:01:00+03
30679	PG0522	2017-09-04 14:10:00+03	2017-09-04 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30680	PG0522	2017-08-17 14:10:00+03	2017-08-17 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30681	PG0522	2017-07-31 14:10:00+03	2017-07-31 16:00:00+03	AER	KUF	Arrived	733	2017-07-31 14:12:00+03	2017-07-31 16:02:00+03
30682	PG0522	2017-08-28 14:10:00+03	2017-08-28 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30683	PG0522	2017-07-28 14:10:00+03	2017-07-28 16:00:00+03	AER	KUF	Arrived	733	2017-07-28 14:11:00+03	2017-07-28 16:02:00+03
30684	PG0522	2017-07-19 14:10:00+03	2017-07-19 16:00:00+03	AER	KUF	Arrived	733	2017-07-19 14:14:00+03	2017-07-19 16:04:00+03
30685	PG0522	2017-08-18 14:10:00+03	2017-08-18 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30686	PG0522	2017-09-10 14:10:00+03	2017-09-10 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30687	PG0522	2017-09-03 14:10:00+03	2017-09-03 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30688	PG0522	2017-08-05 14:10:00+03	2017-08-05 16:00:00+03	AER	KUF	Arrived	733	2017-08-05 14:11:00+03	2017-08-05 16:02:00+03
30689	PG0522	2017-07-18 14:10:00+03	2017-07-18 16:00:00+03	AER	KUF	Arrived	733	2017-07-18 14:12:00+03	2017-07-18 16:01:00+03
30690	PG0522	2017-09-08 14:10:00+03	2017-09-08 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30691	PG0522	2017-07-23 14:10:00+03	2017-07-23 16:00:00+03	AER	KUF	Arrived	733	2017-07-23 14:15:00+03	2017-07-23 16:05:00+03
30692	PG0522	2017-08-24 14:10:00+03	2017-08-24 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30693	PG0522	2017-08-25 14:10:00+03	2017-08-25 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30694	PG0522	2017-09-05 14:10:00+03	2017-09-05 16:00:00+03	AER	KUF	Scheduled	733	\N	\N
30695	PG0522	2017-07-27 14:10:00+03	2017-07-27 16:00:00+03	AER	KUF	Arrived	733	2017-07-27 14:12:00+03	2017-07-27 16:02:00+03
30696	PG0522	2017-07-16 14:10:00+03	2017-07-16 16:00:00+03	AER	KUF	Arrived	733	2017-07-16 14:11:00+03	2017-07-16 16:01:00+03
30697	PG0486	2017-08-08 15:25:00+03	2017-08-08 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-08 15:25:00+03	2017-08-08 15:59:00+03
30698	PG0487	2017-09-07 20:10:00+03	2017-09-07 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30699	PG0487	2017-08-02 20:10:00+03	2017-08-02 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-02 20:13:00+03	2017-08-02 20:48:00+03
30700	PG0486	2017-07-31 15:25:00+03	2017-07-31 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-31 15:28:00+03	2017-07-31 16:03:00+03
30701	PG0487	2017-07-31 20:10:00+03	2017-07-31 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-31 20:16:00+03	2017-07-31 20:51:00+03
30702	PG0486	2017-08-13 15:25:00+03	2017-08-13 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-13 15:27:00+03	2017-08-13 16:02:00+03
30703	PG0487	2017-08-13 20:10:00+03	2017-08-13 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-13 20:11:00+03	2017-08-13 20:46:00+03
30704	PG0487	2017-07-24 20:10:00+03	2017-07-24 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-24 20:16:00+03	2017-07-24 20:50:00+03
30705	PG0486	2017-08-07 15:25:00+03	2017-08-07 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-07 15:29:00+03	2017-08-07 16:04:00+03
30706	PG0486	2017-08-15 15:25:00+03	2017-08-15 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-15 15:26:00+03	2017-08-15 16:01:00+03
30707	PG0486	2017-09-07 15:25:00+03	2017-09-07 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30708	PG0486	2017-08-10 15:25:00+03	2017-08-10 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-10 15:25:00+03	2017-08-10 16:00:00+03
30709	PG0486	2017-08-05 15:25:00+03	2017-08-05 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-05 15:30:00+03	2017-08-05 16:04:00+03
30710	PG0486	2017-08-01 15:25:00+03	2017-08-01 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-01 15:29:00+03	2017-08-01 16:04:00+03
30711	PG0487	2017-08-10 20:10:00+03	2017-08-10 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-10 23:54:00+03	2017-08-11 00:29:00+03
30712	PG0487	2017-07-20 20:10:00+03	2017-07-20 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-20 20:10:00+03	2017-07-20 20:45:00+03
30713	PG0487	2017-08-01 20:10:00+03	2017-08-01 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-01 20:11:00+03	2017-08-01 20:46:00+03
30714	PG0486	2017-08-21 15:25:00+03	2017-08-21 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30715	PG0486	2017-08-19 15:25:00+03	2017-08-19 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30716	PG0487	2017-08-19 20:10:00+03	2017-08-19 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30717	PG0486	2017-08-27 15:25:00+03	2017-08-27 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30718	PG0486	2017-08-31 15:25:00+03	2017-08-31 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30719	PG0487	2017-08-11 20:10:00+03	2017-08-11 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-11 20:14:00+03	2017-08-11 20:49:00+03
30720	PG0487	2017-08-31 20:10:00+03	2017-08-31 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30721	PG0487	2017-09-13 20:10:00+03	2017-09-13 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30722	PG0486	2017-08-11 15:25:00+03	2017-08-11 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-11 15:26:00+03	2017-08-11 16:01:00+03
30723	PG0486	2017-08-02 15:25:00+03	2017-08-02 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-02 15:30:00+03	2017-08-02 16:05:00+03
30724	PG0486	2017-08-06 15:25:00+03	2017-08-06 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-06 15:32:00+03	2017-08-06 16:07:00+03
30725	PG0487	2017-08-07 20:10:00+03	2017-08-07 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-07 20:13:00+03	2017-08-07 20:48:00+03
30726	PG0487	2017-08-04 20:10:00+03	2017-08-04 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-04 20:14:00+03	2017-08-04 20:49:00+03
30727	PG0487	2017-08-15 20:10:00+03	2017-08-15 20:45:00+03	AER	ROV	On Time	SU9	\N	\N
30728	PG0486	2017-07-24 15:25:00+03	2017-07-24 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-24 15:29:00+03	2017-07-24 16:04:00+03
30729	PG0487	2017-08-09 20:10:00+03	2017-08-09 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-09 23:27:00+03	2017-08-10 00:02:00+03
30730	PG0486	2017-08-04 15:25:00+03	2017-08-04 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-04 15:26:00+03	2017-08-04 16:01:00+03
30731	PG0486	2017-07-18 15:25:00+03	2017-07-18 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-18 15:27:00+03	2017-07-18 16:02:00+03
30732	PG0486	2017-08-09 15:25:00+03	2017-08-09 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-09 15:31:00+03	2017-08-09 16:06:00+03
30733	PG0486	2017-08-17 15:25:00+03	2017-08-17 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30734	PG0487	2017-08-17 20:10:00+03	2017-08-17 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30735	PG0487	2017-08-16 20:10:00+03	2017-08-16 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30736	PG0486	2017-08-29 15:25:00+03	2017-08-29 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30737	PG0487	2017-09-02 20:10:00+03	2017-09-02 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30738	PG0487	2017-08-12 20:10:00+03	2017-08-12 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-12 20:10:00+03	2017-08-12 20:46:00+03
30739	PG0486	2017-09-02 15:25:00+03	2017-09-02 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30740	PG0487	2017-08-22 20:10:00+03	2017-08-22 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30741	PG0486	2017-08-12 15:25:00+03	2017-08-12 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-12 15:27:00+03	2017-08-12 16:02:00+03
30742	PG0486	2017-09-06 15:25:00+03	2017-09-06 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30743	PG0486	2017-09-10 15:25:00+03	2017-09-10 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30744	PG0487	2017-09-10 20:10:00+03	2017-09-10 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30745	PG0487	2017-09-06 20:10:00+03	2017-09-06 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30746	PG0487	2017-07-26 20:10:00+03	2017-07-26 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-26 20:12:00+03	2017-07-26 20:47:00+03
30747	PG0486	2017-08-28 15:25:00+03	2017-08-28 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30748	PG0487	2017-08-28 20:10:00+03	2017-08-28 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30749	PG0486	2017-07-26 15:25:00+03	2017-07-26 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-26 15:26:00+03	2017-07-26 16:01:00+03
30750	PG0486	2017-07-17 15:25:00+03	2017-07-17 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-17 15:31:00+03	2017-07-17 16:06:00+03
30751	PG0487	2017-09-04 20:10:00+03	2017-09-04 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30752	PG0486	2017-09-04 15:25:00+03	2017-09-04 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30753	PG0486	2017-08-14 15:25:00+03	2017-08-14 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-14 15:26:00+03	2017-08-14 16:01:00+03
30754	PG0487	2017-08-14 20:10:00+03	2017-08-14 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-14 20:13:00+03	2017-08-14 20:48:00+03
30755	PG0487	2017-07-17 20:10:00+03	2017-07-17 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-17 20:12:00+03	2017-07-17 20:47:00+03
30756	PG0486	2017-07-30 15:25:00+03	2017-07-30 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-30 15:28:00+03	2017-07-30 16:03:00+03
30757	PG0487	2017-07-30 20:10:00+03	2017-07-30 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-30 20:11:00+03	2017-07-30 20:46:00+03
30758	PG0487	2017-07-18 20:10:00+03	2017-07-18 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-18 20:11:00+03	2017-07-18 20:46:00+03
30759	PG0486	2017-08-26 15:25:00+03	2017-08-26 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30760	PG0487	2017-09-14 20:10:00+03	2017-09-14 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30761	PG0486	2017-09-14 15:25:00+03	2017-09-14 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30762	PG0487	2017-07-28 20:10:00+03	2017-07-28 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-28 20:13:00+03	2017-07-28 20:48:00+03
30763	PG0486	2017-07-28 15:25:00+03	2017-07-28 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-28 15:28:00+03	2017-07-28 16:03:00+03
30764	PG0487	2017-08-26 20:10:00+03	2017-08-26 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30765	PG0486	2017-09-13 15:25:00+03	2017-09-13 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30766	PG0487	2017-07-21 20:10:00+03	2017-07-21 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-21 20:13:00+03	2017-07-21 20:49:00+03
30767	PG0486	2017-09-05 15:25:00+03	2017-09-05 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30768	PG0487	2017-09-12 20:10:00+03	2017-09-12 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30769	PG0487	2017-07-16 20:10:00+03	2017-07-16 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-16 20:15:00+03	2017-07-16 20:50:00+03
30770	PG0486	2017-09-12 15:25:00+03	2017-09-12 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30771	PG0487	2017-09-05 20:10:00+03	2017-09-05 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30772	PG0486	2017-07-21 15:25:00+03	2017-07-21 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-21 15:27:00+03	2017-07-21 16:02:00+03
30773	PG0487	2017-09-01 20:10:00+03	2017-09-01 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30774	PG0487	2017-08-23 20:10:00+03	2017-08-23 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30775	PG0487	2017-07-19 20:10:00+03	2017-07-19 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-19 20:12:00+03	2017-07-19 20:47:00+03
30776	PG0486	2017-08-22 15:25:00+03	2017-08-22 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30777	PG0486	2017-08-23 15:25:00+03	2017-08-23 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30778	PG0486	2017-09-08 15:25:00+03	2017-09-08 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30779	PG0487	2017-09-08 20:10:00+03	2017-09-08 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30780	PG0486	2017-08-30 15:25:00+03	2017-08-30 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30781	PG0487	2017-08-18 20:10:00+03	2017-08-18 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30782	PG0486	2017-09-09 15:25:00+03	2017-09-09 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30783	PG0487	2017-08-30 20:10:00+03	2017-08-30 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30784	PG0486	2017-08-18 15:25:00+03	2017-08-18 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30785	PG0486	2017-07-16 15:25:00+03	2017-07-16 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-16 15:29:00+03	2017-07-16 16:04:00+03
30786	PG0486	2017-07-19 15:25:00+03	2017-07-19 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-19 15:28:00+03	2017-07-19 16:03:00+03
30787	PG0487	2017-09-09 20:10:00+03	2017-09-09 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30788	PG0486	2017-09-01 15:25:00+03	2017-09-01 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30789	PG0487	2017-08-06 20:10:00+03	2017-08-06 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-06 23:05:00+03	2017-08-06 23:40:00+03
30790	PG0486	2017-07-23 15:25:00+03	2017-07-23 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-23 15:27:00+03	2017-07-23 16:02:00+03
30791	PG0487	2017-07-23 20:10:00+03	2017-07-23 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-24 00:00:00+03	2017-07-24 00:35:00+03
30792	PG0486	2017-08-03 15:25:00+03	2017-08-03 16:00:00+03	AER	ROV	Arrived	SU9	2017-08-03 15:27:00+03	2017-08-03 16:02:00+03
30793	PG0486	2017-09-03 15:25:00+03	2017-09-03 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30794	PG0487	2017-08-24 20:10:00+03	2017-08-24 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30795	PG0487	2017-08-03 20:10:00+03	2017-08-03 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-03 20:11:00+03	2017-08-03 20:46:00+03
30796	PG0487	2017-07-25 20:10:00+03	2017-07-25 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-25 20:17:00+03	2017-07-25 20:52:00+03
30797	PG0486	2017-08-20 15:25:00+03	2017-08-20 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30798	PG0487	2017-08-08 20:10:00+03	2017-08-08 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-08 20:13:00+03	2017-08-08 20:48:00+03
30799	PG0486	2017-07-27 15:25:00+03	2017-07-27 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-27 15:29:00+03	2017-07-27 16:04:00+03
30800	PG0487	2017-09-03 20:10:00+03	2017-09-03 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30801	PG0487	2017-08-05 20:10:00+03	2017-08-05 20:45:00+03	AER	ROV	Arrived	SU9	2017-08-05 20:13:00+03	2017-08-05 20:48:00+03
30802	PG0487	2017-07-27 20:10:00+03	2017-07-27 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-27 20:13:00+03	2017-07-27 20:49:00+03
30803	PG0487	2017-08-20 20:10:00+03	2017-08-20 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30804	PG0486	2017-07-25 15:25:00+03	2017-07-25 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-25 15:31:00+03	2017-07-25 16:06:00+03
30805	PG0486	2017-08-16 15:25:00+03	2017-08-16 16:00:00+03	AER	ROV	On Time	SU9	\N	\N
30806	PG0486	2017-08-24 15:25:00+03	2017-08-24 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30807	PG0486	2017-08-25 15:25:00+03	2017-08-25 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30808	PG0487	2017-08-29 20:10:00+03	2017-08-29 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30809	PG0487	2017-08-25 20:10:00+03	2017-08-25 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30810	PG0487	2017-08-27 20:10:00+03	2017-08-27 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30811	PG0486	2017-07-20 15:25:00+03	2017-07-20 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-20 15:25:00+03	2017-07-20 16:00:00+03
30812	PG0486	2017-09-11 15:25:00+03	2017-09-11 16:00:00+03	AER	ROV	Scheduled	SU9	\N	\N
30813	PG0487	2017-09-11 20:10:00+03	2017-09-11 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30814	PG0487	2017-07-29 20:10:00+03	2017-07-29 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-29 20:16:00+03	2017-07-29 20:51:00+03
30815	PG0487	2017-07-22 20:10:00+03	2017-07-22 20:45:00+03	AER	ROV	Arrived	SU9	2017-07-22 20:13:00+03	2017-07-22 20:48:00+03
30816	PG0486	2017-07-29 15:25:00+03	2017-07-29 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-29 15:26:00+03	2017-07-29 16:01:00+03
30817	PG0486	2017-07-22 15:25:00+03	2017-07-22 16:00:00+03	AER	ROV	Arrived	SU9	2017-07-22 15:29:00+03	2017-07-22 16:04:00+03
30818	PG0487	2017-08-21 20:10:00+03	2017-08-21 20:45:00+03	AER	ROV	Scheduled	SU9	\N	\N
30819	PG0502	2017-08-13 10:45:00+03	2017-08-13 15:55:00+03	AER	KJA	Arrived	319	2017-08-13 10:48:00+03	2017-08-13 15:53:00+03
30820	PG0502	2017-07-26 10:45:00+03	2017-07-26 15:55:00+03	AER	KJA	Arrived	319	2017-07-26 10:47:00+03	2017-07-26 15:55:00+03
30821	PG0502	2017-08-23 10:45:00+03	2017-08-23 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30822	PG0502	2017-09-06 10:45:00+03	2017-09-06 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30823	PG0502	2017-08-06 10:45:00+03	2017-08-06 15:55:00+03	AER	KJA	Arrived	319	2017-08-06 10:46:00+03	2017-08-06 15:54:00+03
30824	PG0502	2017-07-19 10:45:00+03	2017-07-19 15:55:00+03	AER	KJA	Arrived	319	2017-07-19 10:47:00+03	2017-07-19 15:53:00+03
30825	PG0502	2017-08-27 10:45:00+03	2017-08-27 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30826	PG0502	2017-09-13 10:45:00+03	2017-09-13 15:55:00+03	AER	KJA	Cancelled	319	\N	\N
30827	PG0502	2017-07-30 10:45:00+03	2017-07-30 15:55:00+03	AER	KJA	Arrived	319	2017-07-30 10:50:00+03	2017-07-30 16:04:00+03
30828	PG0502	2017-07-23 10:45:00+03	2017-07-23 15:55:00+03	AER	KJA	Arrived	319	2017-07-23 10:49:00+03	2017-07-23 15:57:00+03
30829	PG0502	2017-08-30 10:45:00+03	2017-08-30 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30830	PG0502	2017-08-16 10:45:00+03	2017-08-16 15:55:00+03	AER	KJA	On Time	319	\N	\N
30831	PG0502	2017-08-09 10:45:00+03	2017-08-09 15:55:00+03	AER	KJA	Arrived	319	2017-08-09 10:45:00+03	2017-08-09 15:58:00+03
30832	PG0502	2017-07-16 10:45:00+03	2017-07-16 15:55:00+03	AER	KJA	Arrived	319	2017-07-16 10:46:00+03	2017-07-16 15:53:00+03
30833	PG0502	2017-08-02 10:45:00+03	2017-08-02 15:55:00+03	AER	KJA	Arrived	319	2017-08-02 10:48:00+03	2017-08-02 15:58:00+03
30834	PG0502	2017-09-03 10:45:00+03	2017-09-03 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30835	PG0502	2017-08-20 10:45:00+03	2017-08-20 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30836	PG0502	2017-09-10 10:45:00+03	2017-09-10 15:55:00+03	AER	KJA	Scheduled	319	\N	\N
30837	PG0248	2017-08-28 09:05:00+03	2017-08-28 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30838	PG0248	2017-08-17 09:05:00+03	2017-08-17 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30839	PG0248	2017-09-09 09:05:00+03	2017-09-09 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30840	PG0248	2017-09-02 09:05:00+03	2017-09-02 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30841	PG0248	2017-07-27 09:05:00+03	2017-07-27 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-27 09:09:00+03	2017-07-27 11:14:00+03
30842	PG0248	2017-09-04 09:05:00+03	2017-09-04 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30843	PG0248	2017-07-24 09:05:00+03	2017-07-24 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-24 09:08:00+03	2017-07-24 11:14:00+03
30844	PG0248	2017-09-14 09:05:00+03	2017-09-14 11:10:00+03	AER	GOJ	Cancelled	CR2	\N	\N
30845	PG0248	2017-08-07 09:05:00+03	2017-08-07 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-07 09:08:00+03	2017-08-07 11:14:00+03
30846	PG0248	2017-08-14 09:05:00+03	2017-08-14 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-14 09:11:00+03	2017-08-14 11:15:00+03
30847	PG0248	2017-08-10 09:05:00+03	2017-08-10 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-10 09:09:00+03	2017-08-10 11:15:00+03
30848	PG0248	2017-08-05 09:05:00+03	2017-08-05 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-05 09:08:00+03	2017-08-05 11:11:00+03
30849	PG0248	2017-09-11 09:05:00+03	2017-09-11 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30850	PG0248	2017-08-24 09:05:00+03	2017-08-24 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30851	PG0248	2017-08-31 09:05:00+03	2017-08-31 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30852	PG0248	2017-07-29 09:05:00+03	2017-07-29 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-29 12:54:00+03	2017-07-29 14:59:00+03
30853	PG0248	2017-08-19 09:05:00+03	2017-08-19 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30854	PG0248	2017-08-03 09:05:00+03	2017-08-03 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-03 09:08:00+03	2017-08-03 11:12:00+03
30855	PG0248	2017-07-17 09:05:00+03	2017-07-17 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-17 09:08:00+03	2017-07-17 11:13:00+03
30856	PG0248	2017-07-22 09:05:00+03	2017-07-22 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-22 09:10:00+03	2017-07-22 11:14:00+03
30857	PG0248	2017-07-20 09:05:00+03	2017-07-20 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-20 09:07:00+03	2017-07-20 11:14:00+03
30858	PG0248	2017-08-21 09:05:00+03	2017-08-21 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30859	PG0248	2017-08-12 09:05:00+03	2017-08-12 11:10:00+03	AER	GOJ	Arrived	CR2	2017-08-12 09:09:00+03	2017-08-12 11:14:00+03
30860	PG0248	2017-09-07 09:05:00+03	2017-09-07 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30861	PG0248	2017-07-31 09:05:00+03	2017-07-31 11:10:00+03	AER	GOJ	Arrived	CR2	2017-07-31 09:05:00+03	2017-07-31 11:10:00+03
30862	PG0248	2017-08-26 09:05:00+03	2017-08-26 11:10:00+03	AER	GOJ	Scheduled	CR2	\N	\N
30863	PG0326	2017-08-19 14:20:00+03	2017-08-19 18:35:00+03	AER	KGP	Scheduled	733	\N	\N
30864	PG0326	2017-09-09 14:20:00+03	2017-09-09 18:35:00+03	AER	KGP	Cancelled	733	\N	\N
30865	PG0326	2017-07-29 14:20:00+03	2017-07-29 18:35:00+03	AER	KGP	Arrived	733	2017-07-29 14:21:00+03	2017-07-29 18:38:00+03
30866	PG0326	2017-08-05 14:20:00+03	2017-08-05 18:35:00+03	AER	KGP	Arrived	733	2017-08-05 14:24:00+03	2017-08-05 18:40:00+03
30867	PG0326	2017-07-22 14:20:00+03	2017-07-22 18:35:00+03	AER	KGP	Arrived	733	2017-07-22 14:25:00+03	2017-07-22 18:40:00+03
30868	PG0326	2017-08-12 14:20:00+03	2017-08-12 18:35:00+03	AER	KGP	Arrived	733	2017-08-12 14:26:00+03	2017-08-12 18:43:00+03
30869	PG0326	2017-08-26 14:20:00+03	2017-08-26 18:35:00+03	AER	KGP	Scheduled	733	\N	\N
30870	PG0326	2017-09-02 14:20:00+03	2017-09-02 18:35:00+03	AER	KGP	Scheduled	733	\N	\N
30871	PG0421	2017-08-27 13:05:00+03	2017-08-27 15:20:00+03	AER	IAR	Scheduled	CR2	\N	\N
30872	PG0421	2017-08-20 13:05:00+03	2017-08-20 15:20:00+03	AER	IAR	Scheduled	CR2	\N	\N
30873	PG0421	2017-08-13 13:05:00+03	2017-08-13 15:20:00+03	AER	IAR	Arrived	CR2	2017-08-13 13:10:00+03	2017-08-13 15:26:00+03
30874	PG0421	2017-09-03 13:05:00+03	2017-09-03 15:20:00+03	AER	IAR	Scheduled	CR2	\N	\N
30875	PG0421	2017-09-10 13:05:00+03	2017-09-10 15:20:00+03	AER	IAR	Scheduled	CR2	\N	\N
30876	PG0421	2017-07-23 13:05:00+03	2017-07-23 15:20:00+03	AER	IAR	Arrived	CR2	2017-07-23 13:09:00+03	2017-07-23 15:25:00+03
30877	PG0421	2017-07-30 13:05:00+03	2017-07-30 15:20:00+03	AER	IAR	Arrived	CR2	2017-07-30 13:07:00+03	2017-07-30 15:22:00+03
30878	PG0421	2017-07-16 13:05:00+03	2017-07-16 15:20:00+03	AER	IAR	Arrived	CR2	2017-07-16 13:10:00+03	2017-07-16 15:27:00+03
30879	PG0421	2017-08-06 13:05:00+03	2017-08-06 15:20:00+03	AER	IAR	Arrived	CR2	2017-08-06 13:09:00+03	2017-08-06 15:22:00+03
30880	PG0322	2017-07-26 10:30:00+03	2017-07-26 15:25:00+03	AER	NOZ	Arrived	733	2017-07-26 10:32:00+03	2017-07-26 15:21:00+03
30881	PG0322	2017-09-13 10:30:00+03	2017-09-13 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30882	PG0322	2017-08-26 10:30:00+03	2017-08-26 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30883	PG0322	2017-07-19 10:30:00+03	2017-07-19 15:25:00+03	AER	NOZ	Arrived	733	2017-07-19 10:34:00+03	2017-07-19 15:32:00+03
30884	PG0322	2017-08-19 10:30:00+03	2017-08-19 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30885	PG0322	2017-08-16 10:30:00+03	2017-08-16 15:25:00+03	AER	NOZ	On Time	733	\N	\N
30886	PG0322	2017-07-22 10:30:00+03	2017-07-22 15:25:00+03	AER	NOZ	Arrived	733	2017-07-22 10:32:00+03	2017-07-22 15:33:00+03
30887	PG0322	2017-08-23 10:30:00+03	2017-08-23 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30888	PG0322	2017-08-30 10:30:00+03	2017-08-30 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30889	PG0322	2017-09-09 10:30:00+03	2017-09-09 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30890	PG0322	2017-09-06 10:30:00+03	2017-09-06 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30891	PG0322	2017-09-02 10:30:00+03	2017-09-02 15:25:00+03	AER	NOZ	Scheduled	733	\N	\N
30892	PG0322	2017-08-09 10:30:00+03	2017-08-09 15:25:00+03	AER	NOZ	Arrived	733	2017-08-09 10:33:00+03	2017-08-09 15:26:00+03
30893	PG0322	2017-07-29 10:30:00+03	2017-07-29 15:25:00+03	AER	NOZ	Arrived	733	2017-07-29 10:36:00+03	2017-07-29 15:27:00+03
30894	PG0322	2017-08-02 10:30:00+03	2017-08-02 15:25:00+03	AER	NOZ	Arrived	733	2017-08-02 10:36:00+03	2017-08-02 15:33:00+03
30895	PG0322	2017-08-05 10:30:00+03	2017-08-05 15:25:00+03	AER	NOZ	Arrived	733	2017-08-05 10:32:00+03	2017-08-05 15:29:00+03
30896	PG0322	2017-08-12 10:30:00+03	2017-08-12 15:25:00+03	AER	NOZ	Arrived	733	2017-08-12 10:34:00+03	2017-08-12 15:29:00+03
30897	PG0602	2017-09-03 11:50:00+03	2017-09-03 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30898	PG0602	2017-08-07 11:50:00+03	2017-08-07 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-07 11:54:00+03	2017-08-07 15:39:00+03
30899	PG0602	2017-08-26 11:50:00+03	2017-08-26 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30900	PG0602	2017-09-12 11:50:00+03	2017-09-12 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30901	PG0602	2017-08-27 11:50:00+03	2017-08-27 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30902	PG0602	2017-08-29 11:50:00+03	2017-08-29 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30903	PG0602	2017-08-02 11:50:00+03	2017-08-02 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-02 11:53:00+03	2017-08-02 15:43:00+03
30904	PG0602	2017-09-04 11:50:00+03	2017-09-04 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30905	PG0602	2017-08-03 11:50:00+03	2017-08-03 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-03 11:53:00+03	2017-08-03 15:38:00+03
30906	PG0602	2017-08-04 11:50:00+03	2017-08-04 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-04 11:53:00+03	2017-08-04 15:38:00+03
30907	PG0602	2017-07-21 11:50:00+03	2017-07-21 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-21 11:52:00+03	2017-07-21 15:38:00+03
30908	PG0602	2017-07-16 11:50:00+03	2017-07-16 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-16 15:10:00+03	2017-07-16 18:54:00+03
30909	PG0602	2017-09-09 11:50:00+03	2017-09-09 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30910	PG0602	2017-08-12 11:50:00+03	2017-08-12 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-12 11:53:00+03	2017-08-12 15:39:00+03
30911	PG0602	2017-09-10 11:50:00+03	2017-09-10 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30912	PG0602	2017-08-05 11:50:00+03	2017-08-05 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-05 15:23:00+03	2017-08-05 19:05:00+03
30913	PG0602	2017-07-30 11:50:00+03	2017-07-30 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-30 11:51:00+03	2017-07-30 15:36:00+03
30914	PG0602	2017-08-13 11:50:00+03	2017-08-13 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-13 11:56:00+03	2017-08-13 15:44:00+03
30915	PG0602	2017-07-19 11:50:00+03	2017-07-19 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-19 11:53:00+03	2017-07-19 15:37:00+03
30916	PG0602	2017-08-20 11:50:00+03	2017-08-20 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30917	PG0602	2017-09-14 11:50:00+03	2017-09-14 15:35:00+03	AER	PEZ	Cancelled	CN1	\N	\N
30918	PG0602	2017-07-29 11:50:00+03	2017-07-29 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-29 11:52:00+03	2017-07-29 15:36:00+03
30919	PG0602	2017-09-02 11:50:00+03	2017-09-02 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30920	PG0602	2017-07-18 11:50:00+03	2017-07-18 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-18 11:53:00+03	2017-07-18 15:36:00+03
30921	PG0602	2017-08-17 11:50:00+03	2017-08-17 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30922	PG0602	2017-07-25 11:50:00+03	2017-07-25 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-25 11:53:00+03	2017-07-25 15:40:00+03
30923	PG0602	2017-08-01 11:50:00+03	2017-08-01 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-01 11:55:00+03	2017-08-01 15:41:00+03
30924	PG0602	2017-09-06 11:50:00+03	2017-09-06 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30925	PG0602	2017-08-30 11:50:00+03	2017-08-30 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30926	PG0602	2017-08-11 11:50:00+03	2017-08-11 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-11 11:52:00+03	2017-08-11 15:33:00+03
30927	PG0602	2017-08-31 11:50:00+03	2017-08-31 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30928	PG0602	2017-08-24 11:50:00+03	2017-08-24 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30929	PG0602	2017-08-25 11:50:00+03	2017-08-25 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30930	PG0602	2017-09-13 11:50:00+03	2017-09-13 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30931	PG0602	2017-07-26 11:50:00+03	2017-07-26 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-26 11:51:00+03	2017-07-26 15:32:00+03
30932	PG0602	2017-07-23 11:50:00+03	2017-07-23 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-23 11:55:00+03	2017-07-23 15:40:00+03
30933	PG0602	2017-07-28 11:50:00+03	2017-07-28 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-28 11:53:00+03	2017-07-28 15:35:00+03
30934	PG0602	2017-09-11 11:50:00+03	2017-09-11 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30935	PG0602	2017-08-18 11:50:00+03	2017-08-18 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30936	PG0602	2017-08-10 11:50:00+03	2017-08-10 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-10 11:53:00+03	2017-08-10 15:38:00+03
30937	PG0602	2017-07-31 11:50:00+03	2017-07-31 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-31 11:52:00+03	2017-07-31 15:38:00+03
30938	PG0602	2017-07-20 11:50:00+03	2017-07-20 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-20 11:53:00+03	2017-07-20 15:37:00+03
30939	PG0602	2017-07-27 11:50:00+03	2017-07-27 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-27 11:54:00+03	2017-07-27 15:33:00+03
30940	PG0602	2017-07-22 11:50:00+03	2017-07-22 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-22 11:59:00+03	2017-07-22 15:43:00+03
30941	PG0602	2017-08-19 11:50:00+03	2017-08-19 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30942	PG0602	2017-08-14 11:50:00+03	2017-08-14 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-14 15:28:00+03	2017-08-14 19:15:00+03
30943	PG0602	2017-09-01 11:50:00+03	2017-09-01 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30944	PG0602	2017-07-17 11:50:00+03	2017-07-17 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-17 11:55:00+03	2017-07-17 15:37:00+03
30945	PG0602	2017-08-06 11:50:00+03	2017-08-06 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-06 11:52:00+03	2017-08-06 15:35:00+03
30946	PG0602	2017-09-05 11:50:00+03	2017-09-05 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30947	PG0602	2017-09-07 11:50:00+03	2017-09-07 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30948	PG0602	2017-09-08 11:50:00+03	2017-09-08 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30949	PG0602	2017-08-15 11:50:00+03	2017-08-15 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-15 11:52:00+03	2017-08-15 15:39:00+03
30950	PG0602	2017-08-09 11:50:00+03	2017-08-09 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-09 11:53:00+03	2017-08-09 15:38:00+03
30951	PG0602	2017-08-23 11:50:00+03	2017-08-23 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30952	PG0602	2017-07-24 11:50:00+03	2017-07-24 15:35:00+03	AER	PEZ	Arrived	CN1	2017-07-24 11:55:00+03	2017-07-24 15:40:00+03
30953	PG0602	2017-08-28 11:50:00+03	2017-08-28 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30954	PG0602	2017-08-21 11:50:00+03	2017-08-21 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30955	PG0602	2017-08-22 11:50:00+03	2017-08-22 15:35:00+03	AER	PEZ	Scheduled	CN1	\N	\N
30956	PG0602	2017-08-16 11:50:00+03	2017-08-16 15:35:00+03	AER	PEZ	On Time	CN1	\N	\N
30957	PG0602	2017-08-08 11:50:00+03	2017-08-08 15:35:00+03	AER	PEZ	Arrived	CN1	2017-08-08 11:54:00+03	2017-08-08 15:39:00+03
30958	PG0004	2017-07-30 12:45:00+03	2017-07-30 14:55:00+03	AER	IWA	Arrived	CR2	2017-07-30 12:45:00+03	2017-07-30 14:55:00+03
30959	PG0004	2017-09-06 12:45:00+03	2017-09-06 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30960	PG0004	2017-08-27 12:45:00+03	2017-08-27 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30961	PG0004	2017-08-16 12:45:00+03	2017-08-16 14:55:00+03	AER	IWA	Delayed	CR2	\N	\N
30962	PG0004	2017-08-02 12:45:00+03	2017-08-02 14:55:00+03	AER	IWA	Arrived	CR2	2017-08-02 12:48:00+03	2017-08-02 14:56:00+03
30963	PG0004	2017-08-23 12:45:00+03	2017-08-23 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30964	PG0004	2017-08-30 12:45:00+03	2017-08-30 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30965	PG0004	2017-07-23 12:45:00+03	2017-07-23 14:55:00+03	AER	IWA	Arrived	CR2	2017-07-23 12:47:00+03	2017-07-23 14:55:00+03
30966	PG0004	2017-08-13 12:45:00+03	2017-08-13 14:55:00+03	AER	IWA	Arrived	CR2	2017-08-13 12:46:00+03	2017-08-13 14:57:00+03
30967	PG0004	2017-07-16 12:45:00+03	2017-07-16 14:55:00+03	AER	IWA	Arrived	CR2	2017-07-16 12:48:00+03	2017-07-16 14:58:00+03
30968	PG0004	2017-08-09 12:45:00+03	2017-08-09 14:55:00+03	AER	IWA	Arrived	CR2	2017-08-09 12:46:00+03	2017-08-09 14:55:00+03
30969	PG0004	2017-07-26 12:45:00+03	2017-07-26 14:55:00+03	AER	IWA	Arrived	CR2	2017-07-26 12:48:00+03	2017-07-26 14:57:00+03
30970	PG0004	2017-09-10 12:45:00+03	2017-09-10 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30971	PG0004	2017-09-13 12:45:00+03	2017-09-13 14:55:00+03	AER	IWA	Cancelled	CR2	\N	\N
30972	PG0004	2017-08-20 12:45:00+03	2017-08-20 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30973	PG0004	2017-08-06 12:45:00+03	2017-08-06 14:55:00+03	AER	IWA	Arrived	CR2	2017-08-06 12:45:00+03	2017-08-06 14:56:00+03
30974	PG0004	2017-09-03 12:45:00+03	2017-09-03 14:55:00+03	AER	IWA	Scheduled	CR2	\N	\N
30975	PG0004	2017-07-19 12:45:00+03	2017-07-19 14:55:00+03	AER	IWA	Arrived	CR2	2017-07-19 12:48:00+03	2017-07-19 15:00:00+03
30976	PG0618	2017-08-31 16:45:00+03	2017-08-31 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30977	PG0617	2017-09-01 14:30:00+03	2017-09-01 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
30978	PG0617	2017-08-06 14:30:00+03	2017-08-06 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-06 14:33:00+03	2017-08-06 17:16:00+03
30979	PG0618	2017-08-26 16:45:00+03	2017-08-26 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30980	PG0617	2017-07-24 14:30:00+03	2017-07-24 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-24 14:32:00+03	2017-07-24 17:17:00+03
30981	PG0617	2017-08-07 14:30:00+03	2017-08-07 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-07 18:32:00+03	2017-08-07 21:18:00+03
30982	PG0617	2017-08-22 14:30:00+03	2017-08-22 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
30983	PG0618	2017-08-07 16:45:00+03	2017-08-07 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-07 16:50:00+03	2017-08-07 19:36:00+03
30984	PG0617	2017-07-29 14:30:00+03	2017-07-29 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-29 14:32:00+03	2017-07-29 17:19:00+03
30985	PG0618	2017-07-24 16:45:00+03	2017-07-24 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-24 16:46:00+03	2017-07-24 19:32:00+03
30986	PG0618	2017-09-01 16:45:00+03	2017-09-01 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30987	PG0618	2017-07-29 16:45:00+03	2017-07-29 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-29 16:47:00+03	2017-07-29 19:35:00+03
30988	PG0617	2017-09-10 14:30:00+03	2017-09-10 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
30989	PG0617	2017-08-11 14:30:00+03	2017-08-11 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-11 14:33:00+03	2017-08-11 17:17:00+03
30990	PG0617	2017-09-07 14:30:00+03	2017-09-07 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
30991	PG0617	2017-08-26 14:30:00+03	2017-08-26 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
30992	PG0618	2017-09-07 16:45:00+03	2017-09-07 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30993	PG0618	2017-08-11 16:45:00+03	2017-08-11 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-11 16:49:00+03	2017-08-11 19:32:00+03
30994	PG0617	2017-07-21 14:30:00+03	2017-07-21 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-21 14:32:00+03	2017-07-21 17:17:00+03
30995	PG0618	2017-07-21 16:45:00+03	2017-07-21 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-21 16:45:00+03	2017-07-21 19:30:00+03
30996	PG0618	2017-09-14 16:45:00+03	2017-09-14 19:30:00+03	AER	EGO	Cancelled	CN1	\N	\N
30997	PG0618	2017-09-02 16:45:00+03	2017-09-02 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30998	PG0618	2017-09-12 16:45:00+03	2017-09-12 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
30999	PG0617	2017-09-12 14:30:00+03	2017-09-12 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31000	PG0617	2017-08-28 14:30:00+03	2017-08-28 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31001	PG0618	2017-08-27 16:45:00+03	2017-08-27 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31002	PG0617	2017-08-27 14:30:00+03	2017-08-27 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31003	PG0617	2017-07-30 14:30:00+03	2017-07-30 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-30 14:32:00+03	2017-07-30 17:16:00+03
31004	PG0618	2017-07-30 16:45:00+03	2017-07-30 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-30 16:47:00+03	2017-07-30 19:31:00+03
31005	PG0617	2017-07-25 14:30:00+03	2017-07-25 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-25 14:34:00+03	2017-07-25 17:18:00+03
31006	PG0618	2017-08-22 16:45:00+03	2017-08-22 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31007	PG0617	2017-09-02 14:30:00+03	2017-09-02 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31008	PG0617	2017-08-15 14:30:00+03	2017-08-15 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-15 14:35:00+03	2017-08-15 17:21:00+03
31009	PG0618	2017-07-25 16:45:00+03	2017-07-25 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-25 16:47:00+03	2017-07-25 19:34:00+03
31010	PG0617	2017-07-17 14:30:00+03	2017-07-17 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-17 14:34:00+03	2017-07-17 17:22:00+03
31011	PG0618	2017-07-17 16:45:00+03	2017-07-17 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-17 20:05:00+03	2017-07-17 22:48:00+03
31012	PG0617	2017-08-04 14:30:00+03	2017-08-04 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-04 14:35:00+03	2017-08-04 17:21:00+03
31013	PG0617	2017-08-31 14:30:00+03	2017-08-31 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31014	PG0618	2017-09-10 16:45:00+03	2017-09-10 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31015	PG0617	2017-08-08 14:30:00+03	2017-08-08 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-08 14:33:00+03	2017-08-08 17:19:00+03
31016	PG0618	2017-07-27 16:45:00+03	2017-07-27 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-27 16:47:00+03	2017-07-27 19:34:00+03
31017	PG0618	2017-08-17 16:45:00+03	2017-08-17 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31018	PG0617	2017-07-20 14:30:00+03	2017-07-20 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-20 14:31:00+03	2017-07-20 17:17:00+03
31019	PG0617	2017-09-13 14:30:00+03	2017-09-13 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31020	PG0618	2017-08-10 16:45:00+03	2017-08-10 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-10 16:48:00+03	2017-08-10 19:35:00+03
31021	PG0618	2017-09-13 16:45:00+03	2017-09-13 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31022	PG0617	2017-08-14 14:30:00+03	2017-08-14 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-14 14:33:00+03	2017-08-14 17:19:00+03
31023	PG0617	2017-08-17 14:30:00+03	2017-08-17 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31024	PG0618	2017-08-14 16:45:00+03	2017-08-14 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-14 16:45:00+03	2017-08-14 19:33:00+03
31025	PG0618	2017-08-08 16:45:00+03	2017-08-08 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-08 16:47:00+03	2017-08-08 19:35:00+03
31026	PG0618	2017-07-20 16:45:00+03	2017-07-20 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-20 16:46:00+03	2017-07-20 19:31:00+03
31027	PG0617	2017-09-06 14:30:00+03	2017-09-06 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31028	PG0618	2017-09-03 16:45:00+03	2017-09-03 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31029	PG0617	2017-07-16 14:30:00+03	2017-07-16 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-16 18:38:00+03	2017-07-16 21:23:00+03
31030	PG0617	2017-09-09 14:30:00+03	2017-09-09 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31031	PG0618	2017-07-16 16:45:00+03	2017-07-16 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-16 16:49:00+03	2017-07-16 19:35:00+03
31032	PG0617	2017-08-10 14:30:00+03	2017-08-10 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-10 14:33:00+03	2017-08-10 17:19:00+03
31033	PG0618	2017-08-15 16:45:00+03	2017-08-15 19:30:00+03	AER	EGO	Departed	CN1	2017-08-15 16:50:00+03	\N
31034	PG0617	2017-09-14 14:30:00+03	2017-09-14 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31035	PG0618	2017-09-09 16:45:00+03	2017-09-09 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31036	PG0617	2017-07-27 14:30:00+03	2017-07-27 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-27 14:33:00+03	2017-07-27 17:17:00+03
31037	PG0617	2017-08-23 14:30:00+03	2017-08-23 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31038	PG0618	2017-08-23 16:45:00+03	2017-08-23 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31039	PG0618	2017-08-20 16:45:00+03	2017-08-20 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31040	PG0618	2017-08-01 16:45:00+03	2017-08-01 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-01 16:49:00+03	2017-08-01 19:35:00+03
31041	PG0617	2017-08-01 14:30:00+03	2017-08-01 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-01 14:35:00+03	2017-08-01 17:18:00+03
31042	PG0617	2017-08-18 14:30:00+03	2017-08-18 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31043	PG0618	2017-08-18 16:45:00+03	2017-08-18 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31044	PG0617	2017-08-20 14:30:00+03	2017-08-20 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31045	PG0617	2017-07-28 14:30:00+03	2017-07-28 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-28 14:32:00+03	2017-07-28 17:19:00+03
31046	PG0618	2017-07-28 16:45:00+03	2017-07-28 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-28 16:47:00+03	2017-07-28 19:31:00+03
31047	PG0617	2017-09-03 14:30:00+03	2017-09-03 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31048	PG0618	2017-09-06 16:45:00+03	2017-09-06 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31049	PG0617	2017-08-29 14:30:00+03	2017-08-29 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31050	PG0618	2017-08-28 16:45:00+03	2017-08-28 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31051	PG0617	2017-08-25 14:30:00+03	2017-08-25 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31052	PG0618	2017-08-13 16:45:00+03	2017-08-13 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-13 16:48:00+03	2017-08-13 19:36:00+03
31053	PG0618	2017-08-25 16:45:00+03	2017-08-25 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31054	PG0617	2017-08-13 14:30:00+03	2017-08-13 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-13 14:31:00+03	2017-08-13 17:14:00+03
31055	PG0618	2017-08-29 16:45:00+03	2017-08-29 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31056	PG0618	2017-08-19 16:45:00+03	2017-08-19 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31057	PG0617	2017-08-19 14:30:00+03	2017-08-19 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31058	PG0618	2017-08-21 16:45:00+03	2017-08-21 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31059	PG0617	2017-08-21 14:30:00+03	2017-08-21 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31060	PG0617	2017-07-19 14:30:00+03	2017-07-19 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-19 14:30:00+03	2017-07-19 17:15:00+03
31061	PG0618	2017-09-05 16:45:00+03	2017-09-05 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31062	PG0617	2017-08-02 14:30:00+03	2017-08-02 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-02 14:35:00+03	2017-08-02 17:21:00+03
31063	PG0618	2017-08-09 16:45:00+03	2017-08-09 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-09 16:45:00+03	2017-08-09 19:32:00+03
31064	PG0618	2017-07-19 16:45:00+03	2017-07-19 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-19 16:46:00+03	2017-07-19 19:32:00+03
31065	PG0617	2017-08-09 14:30:00+03	2017-08-09 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-09 14:33:00+03	2017-08-09 17:19:00+03
31066	PG0617	2017-07-26 14:30:00+03	2017-07-26 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-26 14:34:00+03	2017-07-26 17:22:00+03
31067	PG0617	2017-08-24 14:30:00+03	2017-08-24 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31068	PG0618	2017-07-26 16:45:00+03	2017-07-26 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-26 16:45:00+03	2017-07-26 19:30:00+03
31069	PG0617	2017-09-05 14:30:00+03	2017-09-05 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31070	PG0618	2017-09-08 16:45:00+03	2017-09-08 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31071	PG0618	2017-08-02 16:45:00+03	2017-08-02 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-02 16:47:00+03	2017-08-02 19:31:00+03
31072	PG0618	2017-08-16 16:45:00+03	2017-08-16 19:30:00+03	AER	EGO	On Time	CN1	\N	\N
31073	PG0618	2017-08-24 16:45:00+03	2017-08-24 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31074	PG0617	2017-09-08 14:30:00+03	2017-09-08 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31075	PG0617	2017-08-12 14:30:00+03	2017-08-12 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-12 14:34:00+03	2017-08-12 17:18:00+03
31076	PG0618	2017-07-22 16:45:00+03	2017-07-22 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-22 16:48:00+03	2017-07-22 19:31:00+03
31077	PG0617	2017-07-22 14:30:00+03	2017-07-22 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-22 14:33:00+03	2017-07-22 17:17:00+03
31078	PG0618	2017-08-12 16:45:00+03	2017-08-12 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-12 16:49:00+03	2017-08-12 19:33:00+03
31079	PG0617	2017-08-05 14:30:00+03	2017-08-05 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-05 14:32:00+03	2017-08-05 17:18:00+03
31080	PG0618	2017-08-05 16:45:00+03	2017-08-05 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-05 16:48:00+03	2017-08-05 19:35:00+03
31081	PG0617	2017-07-31 14:30:00+03	2017-07-31 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-31 14:35:00+03	2017-07-31 17:20:00+03
31082	PG0617	2017-08-16 14:30:00+03	2017-08-16 17:15:00+03	AER	EGO	On Time	CN1	\N	\N
31083	PG0617	2017-08-03 14:30:00+03	2017-08-03 17:15:00+03	AER	EGO	Arrived	CN1	2017-08-03 18:05:00+03	2017-08-03 20:48:00+03
31084	PG0617	2017-08-30 14:30:00+03	2017-08-30 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31085	PG0618	2017-08-03 16:45:00+03	2017-08-03 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-03 16:50:00+03	2017-08-03 19:32:00+03
31086	PG0618	2017-07-31 16:45:00+03	2017-07-31 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-31 16:48:00+03	2017-07-31 19:29:00+03
31087	PG0617	2017-09-04 14:30:00+03	2017-09-04 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31088	PG0618	2017-09-04 16:45:00+03	2017-09-04 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31089	PG0618	2017-09-11 16:45:00+03	2017-09-11 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31090	PG0618	2017-07-18 16:45:00+03	2017-07-18 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-18 19:12:00+03	2017-07-18 21:58:00+03
31091	PG0618	2017-08-30 16:45:00+03	2017-08-30 19:30:00+03	AER	EGO	Scheduled	CN1	\N	\N
31092	PG0617	2017-09-11 14:30:00+03	2017-09-11 17:15:00+03	AER	EGO	Scheduled	CN1	\N	\N
31093	PG0617	2017-07-23 14:30:00+03	2017-07-23 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-23 14:34:00+03	2017-07-23 17:21:00+03
31094	PG0617	2017-07-18 14:30:00+03	2017-07-18 17:15:00+03	AER	EGO	Arrived	CN1	2017-07-18 14:32:00+03	2017-07-18 17:16:00+03
31095	PG0618	2017-07-23 16:45:00+03	2017-07-23 19:30:00+03	AER	EGO	Arrived	CN1	2017-07-23 16:47:00+03	2017-07-23 19:32:00+03
31096	PG0618	2017-08-06 16:45:00+03	2017-08-06 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-06 16:48:00+03	2017-08-06 19:31:00+03
31097	PG0618	2017-08-04 16:45:00+03	2017-08-04 19:30:00+03	AER	EGO	Arrived	CN1	2017-08-04 16:47:00+03	2017-08-04 19:32:00+03
31098	PG0119	2017-09-11 15:30:00+03	2017-09-11 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31099	PG0119	2017-07-30 15:30:00+03	2017-07-30 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-30 15:35:00+03	2017-07-30 16:20:00+03
31100	PG0119	2017-09-09 15:30:00+03	2017-09-09 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31101	PG0119	2017-08-23 15:30:00+03	2017-08-23 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31102	PG0119	2017-07-18 15:30:00+03	2017-07-18 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-18 15:32:00+03	2017-07-18 16:17:00+03
31103	PG0119	2017-07-16 15:30:00+03	2017-07-16 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-16 15:34:00+03	2017-07-16 16:19:00+03
31104	PG0119	2017-08-10 15:30:00+03	2017-08-10 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-10 15:33:00+03	2017-08-10 16:18:00+03
31105	PG0119	2017-08-28 15:30:00+03	2017-08-28 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31106	PG0119	2017-08-04 15:30:00+03	2017-08-04 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-04 18:29:00+03	2017-08-04 19:14:00+03
31107	PG0119	2017-08-13 15:30:00+03	2017-08-13 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-13 15:35:00+03	2017-08-13 16:20:00+03
31108	PG0119	2017-08-19 15:30:00+03	2017-08-19 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31109	PG0119	2017-08-02 15:30:00+03	2017-08-02 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-02 15:33:00+03	2017-08-02 16:19:00+03
31110	PG0119	2017-08-26 15:30:00+03	2017-08-26 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31111	PG0119	2017-08-05 15:30:00+03	2017-08-05 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-05 15:33:00+03	2017-08-05 16:18:00+03
31112	PG0119	2017-09-02 15:30:00+03	2017-09-02 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31113	PG0119	2017-09-13 15:30:00+03	2017-09-13 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31114	PG0119	2017-07-25 15:30:00+03	2017-07-25 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-25 15:31:00+03	2017-07-25 16:16:00+03
31115	PG0119	2017-09-08 15:30:00+03	2017-09-08 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31116	PG0119	2017-09-10 15:30:00+03	2017-09-10 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31117	PG0119	2017-09-06 15:30:00+03	2017-09-06 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31118	PG0119	2017-07-20 15:30:00+03	2017-07-20 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-20 15:31:00+03	2017-07-20 16:17:00+03
31119	PG0119	2017-08-12 15:30:00+03	2017-08-12 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-12 15:33:00+03	2017-08-12 16:19:00+03
31120	PG0119	2017-07-17 15:30:00+03	2017-07-17 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-17 15:31:00+03	2017-07-17 16:16:00+03
31121	PG0119	2017-07-31 15:30:00+03	2017-07-31 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-31 15:32:00+03	2017-07-31 16:17:00+03
31122	PG0119	2017-08-21 15:30:00+03	2017-08-21 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31123	PG0119	2017-08-01 15:30:00+03	2017-08-01 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-01 15:31:00+03	2017-08-01 16:16:00+03
31124	PG0119	2017-08-24 15:30:00+03	2017-08-24 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31125	PG0119	2017-08-08 15:30:00+03	2017-08-08 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-08 15:34:00+03	2017-08-08 16:19:00+03
31126	PG0119	2017-08-11 15:30:00+03	2017-08-11 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-11 15:34:00+03	2017-08-11 16:19:00+03
31127	PG0119	2017-08-22 15:30:00+03	2017-08-22 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31128	PG0119	2017-07-28 15:30:00+03	2017-07-28 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-28 15:32:00+03	2017-07-28 16:17:00+03
31129	PG0119	2017-08-20 15:30:00+03	2017-08-20 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31130	PG0119	2017-07-27 15:30:00+03	2017-07-27 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-27 15:33:00+03	2017-07-27 16:19:00+03
31131	PG0119	2017-07-23 15:30:00+03	2017-07-23 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-23 15:31:00+03	2017-07-23 16:16:00+03
31132	PG0119	2017-09-01 15:30:00+03	2017-09-01 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31133	PG0119	2017-07-22 15:30:00+03	2017-07-22 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-22 15:32:00+03	2017-07-22 16:17:00+03
31134	PG0119	2017-08-29 15:30:00+03	2017-08-29 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31135	PG0119	2017-08-16 15:30:00+03	2017-08-16 16:15:00+03	EGO	DME	On Time	SU9	\N	\N
31136	PG0119	2017-07-24 15:30:00+03	2017-07-24 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-24 15:31:00+03	2017-07-24 16:16:00+03
31137	PG0119	2017-08-06 15:30:00+03	2017-08-06 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-06 15:33:00+03	2017-08-06 16:18:00+03
31138	PG0119	2017-08-27 15:30:00+03	2017-08-27 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31139	PG0119	2017-08-14 15:30:00+03	2017-08-14 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-14 15:35:00+03	2017-08-14 16:20:00+03
31140	PG0119	2017-08-07 15:30:00+03	2017-08-07 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-07 15:35:00+03	2017-08-07 16:20:00+03
31141	PG0119	2017-09-14 15:30:00+03	2017-09-14 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31142	PG0119	2017-08-31 15:30:00+03	2017-08-31 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31143	PG0119	2017-09-05 15:30:00+03	2017-09-05 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31144	PG0119	2017-07-21 15:30:00+03	2017-07-21 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-21 15:32:00+03	2017-07-21 16:16:00+03
31145	PG0119	2017-09-04 15:30:00+03	2017-09-04 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31146	PG0119	2017-07-29 15:30:00+03	2017-07-29 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-29 15:34:00+03	2017-07-29 16:19:00+03
31147	PG0119	2017-08-09 15:30:00+03	2017-08-09 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-09 15:32:00+03	2017-08-09 16:17:00+03
31148	PG0119	2017-08-18 15:30:00+03	2017-08-18 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31149	PG0119	2017-09-03 15:30:00+03	2017-09-03 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31150	PG0119	2017-08-15 15:30:00+03	2017-08-15 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-15 15:32:00+03	2017-08-15 16:17:00+03
31151	PG0119	2017-08-25 15:30:00+03	2017-08-25 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31152	PG0119	2017-08-03 15:30:00+03	2017-08-03 16:15:00+03	EGO	DME	Arrived	SU9	2017-08-03 15:31:00+03	2017-08-03 16:16:00+03
31153	PG0119	2017-08-17 15:30:00+03	2017-08-17 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31154	PG0119	2017-07-19 15:30:00+03	2017-07-19 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-19 15:33:00+03	2017-07-19 16:17:00+03
31155	PG0119	2017-09-07 15:30:00+03	2017-09-07 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31156	PG0119	2017-07-26 15:30:00+03	2017-07-26 16:15:00+03	EGO	DME	Arrived	SU9	2017-07-26 15:31:00+03	2017-07-26 16:16:00+03
31157	PG0119	2017-09-12 15:30:00+03	2017-09-12 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31158	PG0119	2017-08-30 15:30:00+03	2017-08-30 16:15:00+03	EGO	DME	Scheduled	SU9	\N	\N
31159	PG0560	2017-09-11 18:00:00+03	2017-09-11 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31160	PG0560	2017-08-28 18:00:00+03	2017-08-28 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31161	PG0560	2017-09-07 18:00:00+03	2017-09-07 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31162	PG0560	2017-08-31 18:00:00+03	2017-08-31 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31163	PG0560	2017-07-22 18:00:00+03	2017-07-22 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-22 18:02:00+03	2017-07-22 19:27:00+03
31164	PG0560	2017-08-27 18:00:00+03	2017-08-27 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31165	PG0560	2017-08-19 18:00:00+03	2017-08-19 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31166	PG0560	2017-09-08 18:00:00+03	2017-09-08 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31167	PG0560	2017-07-17 18:00:00+03	2017-07-17 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-17 18:03:00+03	2017-07-17 19:27:00+03
31168	PG0560	2017-08-01 18:00:00+03	2017-08-01 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-01 18:04:00+03	2017-08-01 19:30:00+03
31169	PG0560	2017-09-14 18:00:00+03	2017-09-14 19:25:00+03	EGO	ROV	Cancelled	CN1	\N	\N
31170	PG0560	2017-08-25 18:00:00+03	2017-08-25 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31171	PG0560	2017-07-31 18:00:00+03	2017-07-31 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-31 18:03:00+03	2017-07-31 19:29:00+03
31172	PG0560	2017-08-10 18:00:00+03	2017-08-10 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-10 18:06:00+03	2017-08-10 19:30:00+03
31173	PG0560	2017-08-14 18:00:00+03	2017-08-14 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-14 18:02:00+03	2017-08-14 19:26:00+03
31174	PG0560	2017-07-30 18:00:00+03	2017-07-30 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-30 18:04:00+03	2017-07-30 19:30:00+03
31175	PG0560	2017-07-18 18:00:00+03	2017-07-18 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-18 18:04:00+03	2017-07-18 19:28:00+03
31176	PG0560	2017-08-13 18:00:00+03	2017-08-13 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-13 18:04:00+03	2017-08-13 19:31:00+03
31177	PG0560	2017-07-24 18:00:00+03	2017-07-24 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-24 18:01:00+03	2017-07-24 19:27:00+03
31178	PG0560	2017-08-22 18:00:00+03	2017-08-22 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31179	PG0560	2017-07-20 18:00:00+03	2017-07-20 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-20 18:04:00+03	2017-07-20 19:30:00+03
31180	PG0560	2017-08-29 18:00:00+03	2017-08-29 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31181	PG0560	2017-08-11 18:00:00+03	2017-08-11 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-11 18:04:00+03	2017-08-11 19:29:00+03
31182	PG0560	2017-09-10 18:00:00+03	2017-09-10 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31183	PG0560	2017-09-04 18:00:00+03	2017-09-04 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31184	PG0560	2017-08-16 18:00:00+03	2017-08-16 19:25:00+03	EGO	ROV	On Time	CN1	\N	\N
31185	PG0560	2017-07-25 18:00:00+03	2017-07-25 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-25 21:54:00+03	2017-07-25 23:19:00+03
31186	PG0560	2017-08-09 18:00:00+03	2017-08-09 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-09 21:34:00+03	2017-08-09 22:59:00+03
31187	PG0560	2017-08-03 18:00:00+03	2017-08-03 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-03 18:03:00+03	2017-08-03 19:29:00+03
31188	PG0560	2017-07-27 18:00:00+03	2017-07-27 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-27 18:01:00+03	2017-07-27 19:26:00+03
31189	PG0560	2017-08-26 18:00:00+03	2017-08-26 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31190	PG0560	2017-08-08 18:00:00+03	2017-08-08 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-08 18:01:00+03	2017-08-08 19:24:00+03
31191	PG0560	2017-07-16 18:00:00+03	2017-07-16 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-16 18:01:00+03	2017-07-16 19:25:00+03
31192	PG0560	2017-08-20 18:00:00+03	2017-08-20 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31193	PG0560	2017-08-23 18:00:00+03	2017-08-23 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31194	PG0560	2017-09-06 18:00:00+03	2017-09-06 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31195	PG0560	2017-08-07 18:00:00+03	2017-08-07 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-07 18:01:00+03	2017-08-07 19:25:00+03
31196	PG0560	2017-08-04 18:00:00+03	2017-08-04 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-04 18:04:00+03	2017-08-04 19:29:00+03
31197	PG0560	2017-08-21 18:00:00+03	2017-08-21 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31198	PG0560	2017-09-02 18:00:00+03	2017-09-02 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31199	PG0560	2017-07-23 18:00:00+03	2017-07-23 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-23 18:00:00+03	2017-07-23 19:27:00+03
31200	PG0560	2017-09-09 18:00:00+03	2017-09-09 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31201	PG0560	2017-07-29 18:00:00+03	2017-07-29 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-29 18:04:00+03	2017-07-29 19:30:00+03
31202	PG0560	2017-08-30 18:00:00+03	2017-08-30 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31203	PG0560	2017-08-24 18:00:00+03	2017-08-24 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31204	PG0560	2017-09-01 18:00:00+03	2017-09-01 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31205	PG0560	2017-08-18 18:00:00+03	2017-08-18 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31206	PG0560	2017-08-05 18:00:00+03	2017-08-05 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-05 18:04:00+03	2017-08-05 19:29:00+03
31207	PG0560	2017-08-15 18:00:00+03	2017-08-15 19:25:00+03	EGO	ROV	On Time	CN1	\N	\N
31208	PG0560	2017-07-28 18:00:00+03	2017-07-28 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-28 18:06:00+03	2017-07-28 19:31:00+03
31209	PG0560	2017-09-13 18:00:00+03	2017-09-13 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31210	PG0560	2017-09-03 18:00:00+03	2017-09-03 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31211	PG0560	2017-08-17 18:00:00+03	2017-08-17 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31212	PG0560	2017-07-19 18:00:00+03	2017-07-19 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-19 18:05:00+03	2017-07-19 19:30:00+03
31213	PG0560	2017-08-12 18:00:00+03	2017-08-12 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-12 18:02:00+03	2017-08-12 19:26:00+03
31214	PG0560	2017-07-26 18:00:00+03	2017-07-26 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-26 18:00:00+03	2017-07-26 19:25:00+03
31215	PG0560	2017-08-06 18:00:00+03	2017-08-06 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-06 18:03:00+03	2017-08-06 19:26:00+03
31216	PG0560	2017-08-02 18:00:00+03	2017-08-02 19:25:00+03	EGO	ROV	Arrived	CN1	2017-08-02 18:05:00+03	2017-08-02 19:31:00+03
31217	PG0560	2017-07-21 18:00:00+03	2017-07-21 19:25:00+03	EGO	ROV	Arrived	CN1	2017-07-21 18:00:00+03	2017-07-21 19:24:00+03
31218	PG0560	2017-09-05 18:00:00+03	2017-09-05 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31219	PG0560	2017-09-12 18:00:00+03	2017-09-12 19:25:00+03	EGO	ROV	Scheduled	CN1	\N	\N
31220	PG0481	2017-08-18 13:00:00+03	2017-08-18 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31221	PG0481	2017-08-07 13:00:00+03	2017-08-07 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-07 13:02:00+03	2017-08-07 13:51:00+03
31222	PG0481	2017-08-23 13:00:00+03	2017-08-23 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31223	PG0481	2017-08-28 13:00:00+03	2017-08-28 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31224	PG0481	2017-07-31 13:00:00+03	2017-07-31 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-31 13:03:00+03	2017-07-31 13:54:00+03
31225	PG0481	2017-09-05 13:00:00+03	2017-09-05 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31226	PG0481	2017-09-08 13:00:00+03	2017-09-08 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31227	PG0481	2017-07-24 13:00:00+03	2017-07-24 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-24 13:00:00+03	2017-07-24 13:50:00+03
31228	PG0481	2017-08-09 13:00:00+03	2017-08-09 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-09 13:03:00+03	2017-08-09 13:53:00+03
31229	PG0481	2017-07-28 13:00:00+03	2017-07-28 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-28 13:01:00+03	2017-07-28 13:52:00+03
31230	PG0481	2017-07-18 13:00:00+03	2017-07-18 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-18 13:03:00+03	2017-07-18 13:54:00+03
31231	PG0481	2017-09-09 13:00:00+03	2017-09-09 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31232	PG0481	2017-07-25 13:00:00+03	2017-07-25 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-25 13:02:00+03	2017-07-25 13:52:00+03
31233	PG0481	2017-08-15 13:00:00+03	2017-08-15 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-15 13:07:00+03	2017-08-15 13:58:00+03
31234	PG0481	2017-08-14 13:00:00+03	2017-08-14 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-14 13:03:00+03	2017-08-14 13:53:00+03
31235	PG0481	2017-08-06 13:00:00+03	2017-08-06 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-06 13:00:00+03	2017-08-06 13:50:00+03
31236	PG0481	2017-07-27 13:00:00+03	2017-07-27 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-27 13:03:00+03	2017-07-27 13:53:00+03
31237	PG0481	2017-08-01 13:00:00+03	2017-08-01 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-01 13:01:00+03	2017-08-01 13:51:00+03
31238	PG0481	2017-08-16 13:00:00+03	2017-08-16 13:50:00+03	EGO	AAQ	On Time	SU9	\N	\N
31239	PG0481	2017-08-12 13:00:00+03	2017-08-12 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-12 13:04:00+03	2017-08-12 13:54:00+03
31240	PG0481	2017-07-29 13:00:00+03	2017-07-29 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-29 13:03:00+03	2017-07-29 13:54:00+03
31241	PG0481	2017-07-30 13:00:00+03	2017-07-30 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-30 16:57:00+03	2017-07-30 17:46:00+03
31242	PG0481	2017-09-07 13:00:00+03	2017-09-07 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31243	PG0481	2017-08-19 13:00:00+03	2017-08-19 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31244	PG0481	2017-09-12 13:00:00+03	2017-09-12 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31245	PG0481	2017-08-04 13:00:00+03	2017-08-04 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-04 13:01:00+03	2017-08-04 13:52:00+03
31246	PG0481	2017-08-17 13:00:00+03	2017-08-17 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31247	PG0481	2017-08-31 13:00:00+03	2017-08-31 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31248	PG0481	2017-07-23 13:00:00+03	2017-07-23 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-23 13:03:00+03	2017-07-23 13:53:00+03
31249	PG0481	2017-08-02 13:00:00+03	2017-08-02 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-02 13:04:00+03	2017-08-02 13:55:00+03
31250	PG0481	2017-08-29 13:00:00+03	2017-08-29 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31251	PG0481	2017-08-27 13:00:00+03	2017-08-27 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31252	PG0481	2017-09-04 13:00:00+03	2017-09-04 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31253	PG0481	2017-07-22 13:00:00+03	2017-07-22 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-22 13:02:00+03	2017-07-22 13:52:00+03
31254	PG0481	2017-07-19 13:00:00+03	2017-07-19 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-19 13:03:00+03	2017-07-19 13:53:00+03
31255	PG0481	2017-07-26 13:00:00+03	2017-07-26 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-26 13:01:00+03	2017-07-26 13:51:00+03
31256	PG0481	2017-09-06 13:00:00+03	2017-09-06 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31257	PG0481	2017-08-25 13:00:00+03	2017-08-25 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31258	PG0481	2017-08-05 13:00:00+03	2017-08-05 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-05 13:02:00+03	2017-08-05 13:52:00+03
31259	PG0481	2017-09-03 13:00:00+03	2017-09-03 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31260	PG0481	2017-09-14 13:00:00+03	2017-09-14 13:50:00+03	EGO	AAQ	Cancelled	SU9	\N	\N
31261	PG0481	2017-08-10 13:00:00+03	2017-08-10 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-10 13:02:00+03	2017-08-10 13:52:00+03
31262	PG0481	2017-08-03 13:00:00+03	2017-08-03 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-03 13:04:00+03	2017-08-03 13:53:00+03
31263	PG0481	2017-09-01 13:00:00+03	2017-09-01 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31264	PG0481	2017-07-17 13:00:00+03	2017-07-17 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-17 13:03:00+03	2017-07-17 13:53:00+03
31265	PG0481	2017-07-20 13:00:00+03	2017-07-20 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-20 13:03:00+03	2017-07-20 13:53:00+03
31266	PG0481	2017-08-21 13:00:00+03	2017-08-21 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31267	PG0481	2017-07-16 13:00:00+03	2017-07-16 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-16 13:02:00+03	2017-07-16 13:52:00+03
31268	PG0481	2017-08-30 13:00:00+03	2017-08-30 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31269	PG0481	2017-09-10 13:00:00+03	2017-09-10 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31270	PG0481	2017-09-11 13:00:00+03	2017-09-11 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31271	PG0481	2017-08-24 13:00:00+03	2017-08-24 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31272	PG0481	2017-08-22 13:00:00+03	2017-08-22 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31273	PG0481	2017-09-13 13:00:00+03	2017-09-13 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31274	PG0481	2017-07-21 13:00:00+03	2017-07-21 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-07-21 13:02:00+03	2017-07-21 13:52:00+03
31275	PG0481	2017-08-11 13:00:00+03	2017-08-11 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-11 13:04:00+03	2017-08-11 13:55:00+03
31276	PG0481	2017-09-02 13:00:00+03	2017-09-02 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31277	PG0481	2017-08-08 13:00:00+03	2017-08-08 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-08 13:05:00+03	2017-08-08 13:55:00+03
31278	PG0481	2017-08-20 13:00:00+03	2017-08-20 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31279	PG0481	2017-08-13 13:00:00+03	2017-08-13 13:50:00+03	EGO	AAQ	Arrived	SU9	2017-08-13 13:04:00+03	2017-08-13 13:54:00+03
31280	PG0481	2017-08-26 13:00:00+03	2017-08-26 13:50:00+03	EGO	AAQ	Scheduled	SU9	\N	\N
31281	PG0650	2017-09-01 13:35:00+03	2017-09-01 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31282	PG0650	2017-07-27 13:35:00+03	2017-07-27 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-27 13:36:00+03	2017-07-27 14:01:00+03
31283	PG0650	2017-08-15 13:35:00+03	2017-08-15 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-15 13:40:00+03	2017-08-15 14:05:00+03
31284	PG0650	2017-08-27 13:35:00+03	2017-08-27 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31285	PG0650	2017-07-30 13:35:00+03	2017-07-30 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-30 13:39:00+03	2017-07-30 14:04:00+03
31286	PG0650	2017-08-29 13:35:00+03	2017-08-29 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31287	PG0650	2017-09-09 13:35:00+03	2017-09-09 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31288	PG0650	2017-08-14 13:35:00+03	2017-08-14 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-14 13:37:00+03	2017-08-14 14:02:00+03
31289	PG0650	2017-09-10 13:35:00+03	2017-09-10 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31290	PG0650	2017-09-08 13:35:00+03	2017-09-08 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31291	PG0650	2017-08-01 13:35:00+03	2017-08-01 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-01 13:38:00+03	2017-08-01 14:03:00+03
31292	PG0650	2017-08-09 13:35:00+03	2017-08-09 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-09 13:36:00+03	2017-08-09 14:01:00+03
31293	PG0650	2017-08-22 13:35:00+03	2017-08-22 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31294	PG0650	2017-07-16 13:35:00+03	2017-07-16 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-16 13:40:00+03	2017-07-16 14:05:00+03
31295	PG0650	2017-08-21 13:35:00+03	2017-08-21 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31296	PG0650	2017-08-06 13:35:00+03	2017-08-06 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-06 13:40:00+03	2017-08-06 14:05:00+03
31297	PG0650	2017-08-13 13:35:00+03	2017-08-13 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-13 13:38:00+03	2017-08-13 14:03:00+03
31298	PG0650	2017-07-28 13:35:00+03	2017-07-28 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-28 13:39:00+03	2017-07-28 14:04:00+03
31299	PG0650	2017-08-16 13:35:00+03	2017-08-16 14:00:00+03	EGO	BZK	On Time	SU9	\N	\N
31300	PG0650	2017-09-02 13:35:00+03	2017-09-02 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31301	PG0650	2017-09-06 13:35:00+03	2017-09-06 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31302	PG0650	2017-08-26 13:35:00+03	2017-08-26 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31303	PG0650	2017-08-18 13:35:00+03	2017-08-18 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31304	PG0650	2017-07-20 13:35:00+03	2017-07-20 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-20 13:37:00+03	2017-07-20 14:02:00+03
31305	PG0650	2017-08-20 13:35:00+03	2017-08-20 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31306	PG0650	2017-08-25 13:35:00+03	2017-08-25 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31307	PG0650	2017-09-13 13:35:00+03	2017-09-13 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31308	PG0650	2017-07-22 13:35:00+03	2017-07-22 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-22 13:39:00+03	2017-07-22 14:04:00+03
31309	PG0650	2017-07-19 13:35:00+03	2017-07-19 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-19 16:53:00+03	2017-07-19 17:18:00+03
31310	PG0650	2017-08-04 13:35:00+03	2017-08-04 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-04 13:37:00+03	2017-08-04 14:02:00+03
31311	PG0650	2017-07-23 13:35:00+03	2017-07-23 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-23 13:38:00+03	2017-07-23 14:03:00+03
31312	PG0650	2017-09-03 13:35:00+03	2017-09-03 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31313	PG0650	2017-08-24 13:35:00+03	2017-08-24 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31314	PG0650	2017-08-28 13:35:00+03	2017-08-28 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31315	PG0650	2017-09-07 13:35:00+03	2017-09-07 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31316	PG0650	2017-09-04 13:35:00+03	2017-09-04 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31317	PG0650	2017-07-29 13:35:00+03	2017-07-29 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-29 13:41:00+03	2017-07-29 14:06:00+03
31318	PG0650	2017-08-07 13:35:00+03	2017-08-07 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-07 13:38:00+03	2017-08-07 14:03:00+03
31319	PG0650	2017-08-05 13:35:00+03	2017-08-05 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-05 13:37:00+03	2017-08-05 14:02:00+03
31320	PG0650	2017-08-08 13:35:00+03	2017-08-08 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-08 13:40:00+03	2017-08-08 14:05:00+03
31321	PG0650	2017-07-26 13:35:00+03	2017-07-26 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-26 13:40:00+03	2017-07-26 14:05:00+03
31322	PG0650	2017-07-24 13:35:00+03	2017-07-24 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-24 13:38:00+03	2017-07-24 14:03:00+03
31323	PG0650	2017-08-03 13:35:00+03	2017-08-03 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-03 13:37:00+03	2017-08-03 14:02:00+03
31324	PG0650	2017-08-12 13:35:00+03	2017-08-12 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-12 13:37:00+03	2017-08-12 14:02:00+03
31325	PG0650	2017-09-11 13:35:00+03	2017-09-11 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31326	PG0650	2017-08-17 13:35:00+03	2017-08-17 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31327	PG0650	2017-08-23 13:35:00+03	2017-08-23 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31328	PG0650	2017-08-02 13:35:00+03	2017-08-02 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-02 13:39:00+03	2017-08-02 14:04:00+03
31329	PG0650	2017-07-25 13:35:00+03	2017-07-25 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-25 13:37:00+03	2017-07-25 14:02:00+03
31330	PG0650	2017-08-19 13:35:00+03	2017-08-19 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31331	PG0650	2017-08-30 13:35:00+03	2017-08-30 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31332	PG0650	2017-08-11 13:35:00+03	2017-08-11 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-11 13:39:00+03	2017-08-11 14:04:00+03
31333	PG0650	2017-09-12 13:35:00+03	2017-09-12 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31334	PG0650	2017-08-31 13:35:00+03	2017-08-31 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31335	PG0650	2017-07-21 13:35:00+03	2017-07-21 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-21 13:38:00+03	2017-07-21 14:03:00+03
31336	PG0650	2017-09-14 13:35:00+03	2017-09-14 14:00:00+03	EGO	BZK	Cancelled	SU9	\N	\N
31337	PG0650	2017-09-05 13:35:00+03	2017-09-05 14:00:00+03	EGO	BZK	Scheduled	SU9	\N	\N
31338	PG0650	2017-07-18 13:35:00+03	2017-07-18 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-18 13:37:00+03	2017-07-18 14:02:00+03
31339	PG0650	2017-07-17 13:35:00+03	2017-07-17 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-17 13:36:00+03	2017-07-17 14:00:00+03
31340	PG0650	2017-08-10 13:35:00+03	2017-08-10 14:00:00+03	EGO	BZK	Arrived	SU9	2017-08-10 13:38:00+03	2017-08-10 14:03:00+03
31341	PG0650	2017-07-31 13:35:00+03	2017-07-31 14:00:00+03	EGO	BZK	Arrived	SU9	2017-07-31 13:39:00+03	2017-07-31 14:04:00+03
31342	PG0620	2017-07-23 12:05:00+03	2017-07-23 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-23 12:05:00+03	2017-07-23 14:50:00+03
31343	PG0619	2017-08-04 11:15:00+03	2017-08-04 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-04 11:16:00+03	2017-08-04 14:02:00+03
31344	PG0619	2017-07-23 11:15:00+03	2017-07-23 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-23 11:18:00+03	2017-07-23 14:03:00+03
31345	PG0619	2017-08-23 11:15:00+03	2017-08-23 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31346	PG0620	2017-08-20 12:05:00+03	2017-08-20 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31347	PG0619	2017-08-01 11:15:00+03	2017-08-01 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-01 11:17:00+03	2017-08-01 14:02:00+03
31348	PG0620	2017-09-05 12:05:00+03	2017-09-05 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31349	PG0620	2017-07-25 12:05:00+03	2017-07-25 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-25 12:07:00+03	2017-07-25 14:54:00+03
31350	PG0619	2017-09-14 11:15:00+03	2017-09-14 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31351	PG0619	2017-09-10 11:15:00+03	2017-09-10 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31352	PG0620	2017-08-01 12:05:00+03	2017-08-01 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-01 12:07:00+03	2017-08-01 14:53:00+03
31353	PG0620	2017-07-20 12:05:00+03	2017-07-20 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-20 12:07:00+03	2017-07-20 14:51:00+03
31354	PG0619	2017-07-20 11:15:00+03	2017-07-20 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-20 11:21:00+03	2017-07-20 14:05:00+03
31355	PG0619	2017-07-25 11:15:00+03	2017-07-25 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-25 11:20:00+03	2017-07-25 14:06:00+03
31356	PG0620	2017-07-16 12:05:00+03	2017-07-16 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-16 12:07:00+03	2017-07-16 14:53:00+03
31357	PG0619	2017-07-16 11:15:00+03	2017-07-16 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-16 11:15:00+03	2017-07-16 14:02:00+03
31358	PG0619	2017-08-14 11:15:00+03	2017-08-14 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-14 11:18:00+03	2017-08-14 14:06:00+03
31359	PG0620	2017-09-13 12:05:00+03	2017-09-13 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31360	PG0619	2017-09-13 11:15:00+03	2017-09-13 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31361	PG0619	2017-08-29 11:15:00+03	2017-08-29 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31362	PG0619	2017-09-05 11:15:00+03	2017-09-05 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31363	PG0619	2017-08-16 11:15:00+03	2017-08-16 14:00:00+03	EGO	AER	Delayed	CN1	\N	\N
31364	PG0619	2017-08-10 11:15:00+03	2017-08-10 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-10 11:17:00+03	2017-08-10 14:01:00+03
31365	PG0619	2017-08-17 11:15:00+03	2017-08-17 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31366	PG0620	2017-08-22 12:05:00+03	2017-08-22 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31367	PG0620	2017-08-17 12:05:00+03	2017-08-17 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31368	PG0619	2017-08-31 11:15:00+03	2017-08-31 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31369	PG0620	2017-07-17 12:05:00+03	2017-07-17 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-17 12:11:00+03	2017-07-17 14:55:00+03
31370	PG0620	2017-09-02 12:05:00+03	2017-09-02 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31371	PG0619	2017-07-17 11:15:00+03	2017-07-17 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-17 11:15:00+03	2017-07-17 14:01:00+03
31372	PG0620	2017-08-10 12:05:00+03	2017-08-10 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-10 14:54:00+03	2017-08-10 17:42:00+03
31373	PG0620	2017-08-31 12:05:00+03	2017-08-31 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31374	PG0619	2017-08-22 11:15:00+03	2017-08-22 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31375	PG0619	2017-07-27 11:15:00+03	2017-07-27 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-27 11:17:00+03	2017-07-27 14:00:00+03
31376	PG0619	2017-08-02 11:15:00+03	2017-08-02 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-02 11:19:00+03	2017-08-02 14:05:00+03
31377	PG0619	2017-08-28 11:15:00+03	2017-08-28 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31378	PG0620	2017-07-18 12:05:00+03	2017-07-18 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-18 12:09:00+03	2017-07-18 14:54:00+03
31379	PG0620	2017-09-14 12:05:00+03	2017-09-14 14:50:00+03	EGO	AER	Cancelled	CN1	\N	\N
31380	PG0620	2017-08-02 12:05:00+03	2017-08-02 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-02 15:10:00+03	2017-08-02 17:54:00+03
31381	PG0620	2017-07-30 12:05:00+03	2017-07-30 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-30 12:09:00+03	2017-07-30 14:54:00+03
31382	PG0620	2017-08-15 12:05:00+03	2017-08-15 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-15 12:12:00+03	2017-08-15 14:56:00+03
31383	PG0619	2017-07-30 11:15:00+03	2017-07-30 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-30 11:16:00+03	2017-07-30 14:01:00+03
31384	PG0619	2017-08-27 11:15:00+03	2017-08-27 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31385	PG0620	2017-08-27 12:05:00+03	2017-08-27 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31386	PG0620	2017-09-07 12:05:00+03	2017-09-07 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31387	PG0619	2017-09-07 11:15:00+03	2017-09-07 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31388	PG0620	2017-09-06 12:05:00+03	2017-09-06 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31389	PG0620	2017-09-01 12:05:00+03	2017-09-01 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31390	PG0619	2017-09-12 11:15:00+03	2017-09-12 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31391	PG0620	2017-07-29 12:05:00+03	2017-07-29 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-29 12:08:00+03	2017-07-29 14:53:00+03
31392	PG0619	2017-09-01 11:15:00+03	2017-09-01 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31393	PG0619	2017-08-11 11:15:00+03	2017-08-11 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-11 11:18:00+03	2017-08-11 14:01:00+03
31394	PG0620	2017-08-30 12:05:00+03	2017-08-30 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31395	PG0619	2017-08-30 11:15:00+03	2017-08-30 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31396	PG0620	2017-07-24 12:05:00+03	2017-07-24 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-24 14:57:00+03	2017-07-24 17:40:00+03
31397	PG0620	2017-08-11 12:05:00+03	2017-08-11 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-11 12:10:00+03	2017-08-11 14:55:00+03
31398	PG0619	2017-07-24 11:15:00+03	2017-07-24 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-24 11:19:00+03	2017-07-24 14:00:00+03
31399	PG0619	2017-07-29 11:15:00+03	2017-07-29 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-29 11:15:00+03	2017-07-29 14:02:00+03
31400	PG0620	2017-08-07 12:05:00+03	2017-08-07 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-07 12:06:00+03	2017-08-07 14:54:00+03
31401	PG0619	2017-08-07 11:15:00+03	2017-08-07 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-07 11:18:00+03	2017-08-07 14:03:00+03
31402	PG0620	2017-07-31 12:05:00+03	2017-07-31 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-31 12:07:00+03	2017-07-31 14:50:00+03
31403	PG0619	2017-07-31 11:15:00+03	2017-07-31 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-31 11:17:00+03	2017-07-31 14:05:00+03
31404	PG0619	2017-08-26 11:15:00+03	2017-08-26 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31405	PG0620	2017-08-26 12:05:00+03	2017-08-26 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31406	PG0620	2017-08-04 12:05:00+03	2017-08-04 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-04 12:07:00+03	2017-08-04 14:52:00+03
31407	PG0620	2017-08-28 12:05:00+03	2017-08-28 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31408	PG0620	2017-09-04 12:05:00+03	2017-09-04 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31409	PG0620	2017-07-21 12:05:00+03	2017-07-21 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-21 12:09:00+03	2017-07-21 14:57:00+03
31410	PG0619	2017-08-06 11:15:00+03	2017-08-06 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-06 11:18:00+03	2017-08-06 14:04:00+03
31411	PG0620	2017-08-06 12:05:00+03	2017-08-06 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-06 12:08:00+03	2017-08-06 14:54:00+03
31412	PG0619	2017-09-04 11:15:00+03	2017-09-04 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31413	PG0619	2017-09-11 11:15:00+03	2017-09-11 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31414	PG0620	2017-09-11 12:05:00+03	2017-09-11 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31415	PG0620	2017-09-12 12:05:00+03	2017-09-12 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31416	PG0620	2017-08-03 12:05:00+03	2017-08-03 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-03 12:09:00+03	2017-08-03 14:54:00+03
31417	PG0619	2017-07-21 11:15:00+03	2017-07-21 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-21 11:18:00+03	2017-07-21 14:01:00+03
31418	PG0619	2017-09-06 11:15:00+03	2017-09-06 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31419	PG0620	2017-08-12 12:05:00+03	2017-08-12 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-12 12:07:00+03	2017-08-12 14:51:00+03
31420	PG0620	2017-08-05 12:05:00+03	2017-08-05 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-05 12:10:00+03	2017-08-05 14:54:00+03
31421	PG0620	2017-09-03 12:05:00+03	2017-09-03 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31422	PG0619	2017-08-12 11:15:00+03	2017-08-12 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-12 11:19:00+03	2017-08-12 14:05:00+03
31423	PG0619	2017-08-03 11:15:00+03	2017-08-03 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-03 11:16:00+03	2017-08-03 14:02:00+03
31424	PG0619	2017-08-05 11:15:00+03	2017-08-05 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-05 11:18:00+03	2017-08-05 14:03:00+03
31425	PG0620	2017-08-24 12:05:00+03	2017-08-24 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31426	PG0619	2017-08-24 11:15:00+03	2017-08-24 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31427	PG0620	2017-07-26 12:05:00+03	2017-07-26 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-26 12:07:00+03	2017-07-26 14:52:00+03
31428	PG0619	2017-07-22 11:15:00+03	2017-07-22 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-22 11:17:00+03	2017-07-22 14:02:00+03
31429	PG0620	2017-07-22 12:05:00+03	2017-07-22 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-22 12:06:00+03	2017-07-22 14:51:00+03
31430	PG0619	2017-07-26 11:15:00+03	2017-07-26 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-26 14:01:00+03	2017-07-26 16:46:00+03
31431	PG0620	2017-09-09 12:05:00+03	2017-09-09 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31432	PG0620	2017-07-19 12:05:00+03	2017-07-19 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-19 12:07:00+03	2017-07-19 14:49:00+03
31433	PG0619	2017-07-19 11:15:00+03	2017-07-19 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-19 11:17:00+03	2017-07-19 14:02:00+03
31434	PG0619	2017-09-08 11:15:00+03	2017-09-08 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31435	PG0620	2017-08-08 12:05:00+03	2017-08-08 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-08 12:08:00+03	2017-08-08 14:55:00+03
31436	PG0620	2017-09-08 12:05:00+03	2017-09-08 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31437	PG0619	2017-08-09 11:15:00+03	2017-08-09 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-09 11:18:00+03	2017-08-09 14:02:00+03
31438	PG0620	2017-08-09 12:05:00+03	2017-08-09 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-09 12:08:00+03	2017-08-09 14:54:00+03
31439	PG0620	2017-08-16 12:05:00+03	2017-08-16 14:50:00+03	EGO	AER	On Time	CN1	\N	\N
31440	PG0619	2017-08-08 11:15:00+03	2017-08-08 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-08 11:21:00+03	2017-08-08 14:06:00+03
31441	PG0620	2017-08-25 12:05:00+03	2017-08-25 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31442	PG0619	2017-08-25 11:15:00+03	2017-08-25 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31443	PG0619	2017-07-18 11:15:00+03	2017-07-18 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-18 11:17:00+03	2017-07-18 14:02:00+03
31444	PG0619	2017-09-02 11:15:00+03	2017-09-02 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31445	PG0619	2017-08-19 11:15:00+03	2017-08-19 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31446	PG0620	2017-08-19 12:05:00+03	2017-08-19 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31447	PG0620	2017-08-29 12:05:00+03	2017-08-29 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31448	PG0619	2017-08-21 11:15:00+03	2017-08-21 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31449	PG0619	2017-09-09 11:15:00+03	2017-09-09 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31450	PG0619	2017-09-03 11:15:00+03	2017-09-03 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31451	PG0619	2017-08-13 11:15:00+03	2017-08-13 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-13 11:17:00+03	2017-08-13 14:01:00+03
31452	PG0619	2017-08-15 11:15:00+03	2017-08-15 14:00:00+03	EGO	AER	Arrived	CN1	2017-08-15 11:17:00+03	2017-08-15 14:03:00+03
31453	PG0620	2017-08-13 12:05:00+03	2017-08-13 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-13 12:06:00+03	2017-08-13 14:51:00+03
31454	PG0620	2017-09-10 12:05:00+03	2017-09-10 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31455	PG0620	2017-08-14 12:05:00+03	2017-08-14 14:50:00+03	EGO	AER	Arrived	CN1	2017-08-14 12:09:00+03	2017-08-14 14:54:00+03
31456	PG0620	2017-08-21 12:05:00+03	2017-08-21 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31457	PG0620	2017-07-27 12:05:00+03	2017-07-27 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-27 12:07:00+03	2017-07-27 14:53:00+03
31458	PG0620	2017-07-28 12:05:00+03	2017-07-28 14:50:00+03	EGO	AER	Arrived	CN1	2017-07-28 12:05:00+03	2017-07-28 14:49:00+03
31459	PG0619	2017-07-28 11:15:00+03	2017-07-28 14:00:00+03	EGO	AER	Arrived	CN1	2017-07-28 11:19:00+03	2017-07-28 14:09:00+03
31460	PG0620	2017-08-18 12:05:00+03	2017-08-18 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31461	PG0619	2017-08-18 11:15:00+03	2017-08-18 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31462	PG0619	2017-08-20 11:15:00+03	2017-08-20 14:00:00+03	EGO	AER	Scheduled	CN1	\N	\N
31463	PG0620	2017-08-23 12:05:00+03	2017-08-23 14:50:00+03	EGO	AER	Scheduled	CN1	\N	\N
31464	PG0338	2017-08-19 15:55:00+03	2017-08-19 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31465	PG0338	2017-09-10 15:55:00+03	2017-09-10 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31466	PG0338	2017-08-09 15:55:00+03	2017-08-09 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-09 15:57:00+03	2017-08-09 17:23:00+03
31467	PG0338	2017-09-07 15:55:00+03	2017-09-07 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31468	PG0338	2017-07-21 15:55:00+03	2017-07-21 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-21 15:57:00+03	2017-07-21 17:21:00+03
31469	PG0338	2017-07-23 15:55:00+03	2017-07-23 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-23 19:48:00+03	2017-07-23 21:12:00+03
31470	PG0338	2017-08-17 15:55:00+03	2017-08-17 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31471	PG0338	2017-08-26 15:55:00+03	2017-08-26 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31472	PG0338	2017-07-22 15:55:00+03	2017-07-22 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-22 16:01:00+03	2017-07-22 17:27:00+03
31473	PG0338	2017-07-27 15:55:00+03	2017-07-27 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-27 16:00:00+03	2017-07-27 17:25:00+03
31474	PG0338	2017-07-17 15:55:00+03	2017-07-17 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-17 16:00:00+03	2017-07-17 17:25:00+03
31475	PG0338	2017-09-13 15:55:00+03	2017-09-13 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31476	PG0338	2017-07-31 15:55:00+03	2017-07-31 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-31 15:55:00+03	2017-07-31 17:20:00+03
31477	PG0338	2017-08-06 15:55:00+03	2017-08-06 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-06 15:59:00+03	2017-08-06 17:23:00+03
31478	PG0338	2017-08-12 15:55:00+03	2017-08-12 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-12 15:57:00+03	2017-08-12 17:22:00+03
31479	PG0338	2017-07-19 15:55:00+03	2017-07-19 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-19 15:57:00+03	2017-07-19 17:21:00+03
31480	PG0338	2017-08-24 15:55:00+03	2017-08-24 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31481	PG0338	2017-08-18 15:55:00+03	2017-08-18 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31482	PG0338	2017-08-03 15:55:00+03	2017-08-03 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-03 16:01:00+03	2017-08-03 17:26:00+03
31483	PG0338	2017-09-12 15:55:00+03	2017-09-12 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31484	PG0338	2017-08-25 15:55:00+03	2017-08-25 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31485	PG0338	2017-08-31 15:55:00+03	2017-08-31 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31486	PG0338	2017-08-11 15:55:00+03	2017-08-11 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-11 15:59:00+03	2017-08-11 17:25:00+03
31487	PG0338	2017-08-23 15:55:00+03	2017-08-23 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31488	PG0338	2017-08-02 15:55:00+03	2017-08-02 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-02 15:59:00+03	2017-08-02 17:24:00+03
31489	PG0338	2017-09-01 15:55:00+03	2017-09-01 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31490	PG0338	2017-08-14 15:55:00+03	2017-08-14 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-14 15:57:00+03	2017-08-14 17:20:00+03
31491	PG0338	2017-07-18 15:55:00+03	2017-07-18 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-18 16:00:00+03	2017-07-18 17:25:00+03
31492	PG0338	2017-09-05 15:55:00+03	2017-09-05 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31493	PG0338	2017-07-30 15:55:00+03	2017-07-30 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-30 15:58:00+03	2017-07-30 17:23:00+03
31494	PG0338	2017-09-06 15:55:00+03	2017-09-06 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31495	PG0338	2017-08-13 15:55:00+03	2017-08-13 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-13 15:58:00+03	2017-08-13 17:22:00+03
31496	PG0338	2017-07-26 15:55:00+03	2017-07-26 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-26 16:01:00+03	2017-07-26 17:27:00+03
31497	PG0338	2017-07-24 15:55:00+03	2017-07-24 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-24 16:00:00+03	2017-07-24 17:25:00+03
31498	PG0338	2017-08-28 15:55:00+03	2017-08-28 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31499	PG0338	2017-08-01 15:55:00+03	2017-08-01 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-01 16:00:00+03	2017-08-01 17:24:00+03
31500	PG0338	2017-07-25 15:55:00+03	2017-07-25 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-25 15:57:00+03	2017-07-25 17:20:00+03
31501	PG0338	2017-09-09 15:55:00+03	2017-09-09 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31502	PG0338	2017-08-16 15:55:00+03	2017-08-16 17:20:00+03	ARH	DME	On Time	CR2	\N	\N
31503	PG0338	2017-08-22 15:55:00+03	2017-08-22 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31504	PG0338	2017-09-08 15:55:00+03	2017-09-08 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31505	PG0338	2017-08-27 15:55:00+03	2017-08-27 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31506	PG0338	2017-07-29 15:55:00+03	2017-07-29 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-29 16:00:00+03	2017-07-29 17:25:00+03
31507	PG0338	2017-08-05 15:55:00+03	2017-08-05 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-05 15:59:00+03	2017-08-05 17:24:00+03
31508	PG0338	2017-08-30 15:55:00+03	2017-08-30 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31509	PG0338	2017-09-02 15:55:00+03	2017-09-02 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31510	PG0338	2017-07-20 15:55:00+03	2017-07-20 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-20 15:58:00+03	2017-07-20 17:22:00+03
31511	PG0338	2017-08-29 15:55:00+03	2017-08-29 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31512	PG0338	2017-09-14 15:55:00+03	2017-09-14 17:20:00+03	ARH	DME	Cancelled	CR2	\N	\N
31513	PG0338	2017-08-07 15:55:00+03	2017-08-07 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-07 15:58:00+03	2017-08-07 17:24:00+03
31514	PG0338	2017-08-15 15:55:00+03	2017-08-15 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-15 15:59:00+03	2017-08-15 17:25:00+03
31515	PG0338	2017-09-04 15:55:00+03	2017-09-04 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31516	PG0338	2017-08-21 15:55:00+03	2017-08-21 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31517	PG0338	2017-09-11 15:55:00+03	2017-09-11 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31518	PG0338	2017-07-28 15:55:00+03	2017-07-28 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-28 15:58:00+03	2017-07-28 17:21:00+03
31519	PG0338	2017-08-10 15:55:00+03	2017-08-10 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-10 15:58:00+03	2017-08-10 17:23:00+03
31520	PG0338	2017-07-16 15:55:00+03	2017-07-16 17:20:00+03	ARH	DME	Arrived	CR2	2017-07-16 15:57:00+03	2017-07-16 17:22:00+03
31521	PG0338	2017-08-08 15:55:00+03	2017-08-08 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-08 15:59:00+03	2017-08-08 17:24:00+03
31522	PG0338	2017-09-03 15:55:00+03	2017-09-03 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31523	PG0338	2017-08-20 15:55:00+03	2017-08-20 17:20:00+03	ARH	DME	Scheduled	CR2	\N	\N
31524	PG0338	2017-08-04 15:55:00+03	2017-08-04 17:20:00+03	ARH	DME	Arrived	CR2	2017-08-04 15:57:00+03	2017-08-04 17:23:00+03
31525	PG0494	2017-08-25 11:35:00+03	2017-08-25 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31526	PG0495	2017-08-25 14:40:00+03	2017-08-25 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31527	PG0494	2017-09-13 11:35:00+03	2017-09-13 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31528	PG0495	2017-08-14 14:40:00+03	2017-08-14 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-14 14:42:00+03	2017-08-14 18:17:00+03
31529	PG0494	2017-08-14 11:35:00+03	2017-08-14 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-14 11:36:00+03	2017-08-14 15:11:00+03
31530	PG0495	2017-07-18 14:40:00+03	2017-07-18 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-18 14:43:00+03	2017-07-18 18:18:00+03
31531	PG0494	2017-08-24 11:35:00+03	2017-08-24 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31532	PG0495	2017-08-24 14:40:00+03	2017-08-24 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31533	PG0494	2017-07-16 11:35:00+03	2017-07-16 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-16 11:39:00+03	2017-07-16 15:15:00+03
31534	PG0495	2017-07-16 14:40:00+03	2017-07-16 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-16 14:42:00+03	2017-07-16 18:18:00+03
31535	PG0495	2017-08-30 14:40:00+03	2017-08-30 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31536	PG0494	2017-08-30 11:35:00+03	2017-08-30 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31537	PG0495	2017-07-27 14:40:00+03	2017-07-27 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-27 14:43:00+03	2017-07-27 18:15:00+03
31538	PG0494	2017-07-27 11:35:00+03	2017-07-27 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-27 11:37:00+03	2017-07-27 15:16:00+03
31539	PG0495	2017-09-12 14:40:00+03	2017-09-12 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31540	PG0495	2017-09-13 14:40:00+03	2017-09-13 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31541	PG0495	2017-09-05 14:40:00+03	2017-09-05 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31542	PG0494	2017-09-05 11:35:00+03	2017-09-05 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31543	PG0495	2017-07-23 14:40:00+03	2017-07-23 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-23 14:46:00+03	2017-07-23 18:18:00+03
31544	PG0494	2017-07-23 11:35:00+03	2017-07-23 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-23 11:38:00+03	2017-07-23 15:13:00+03
31545	PG0494	2017-08-05 11:35:00+03	2017-08-05 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-05 11:37:00+03	2017-08-05 15:13:00+03
31546	PG0495	2017-09-08 14:40:00+03	2017-09-08 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31547	PG0494	2017-09-08 11:35:00+03	2017-09-08 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31548	PG0495	2017-08-05 14:40:00+03	2017-08-05 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-05 14:43:00+03	2017-08-05 18:17:00+03
31549	PG0494	2017-08-18 11:35:00+03	2017-08-18 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31550	PG0495	2017-08-18 14:40:00+03	2017-08-18 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31551	PG0494	2017-07-19 11:35:00+03	2017-07-19 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-19 11:41:00+03	2017-07-19 15:19:00+03
31552	PG0495	2017-07-19 14:40:00+03	2017-07-19 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-19 14:44:00+03	2017-07-19 18:17:00+03
31553	PG0494	2017-07-28 11:35:00+03	2017-07-28 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-28 11:38:00+03	2017-07-28 15:16:00+03
31554	PG0495	2017-07-28 14:40:00+03	2017-07-28 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-28 14:44:00+03	2017-07-28 18:19:00+03
31555	PG0494	2017-09-12 11:35:00+03	2017-09-12 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31556	PG0494	2017-08-26 11:35:00+03	2017-08-26 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31557	PG0495	2017-08-28 14:40:00+03	2017-08-28 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31558	PG0494	2017-08-28 11:35:00+03	2017-08-28 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31559	PG0495	2017-09-10 14:40:00+03	2017-09-10 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31560	PG0494	2017-09-10 11:35:00+03	2017-09-10 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31561	PG0494	2017-07-31 11:35:00+03	2017-07-31 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-31 11:38:00+03	2017-07-31 15:13:00+03
31562	PG0494	2017-09-04 11:35:00+03	2017-09-04 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31563	PG0495	2017-08-26 14:40:00+03	2017-08-26 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31564	PG0495	2017-07-31 14:40:00+03	2017-07-31 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-31 14:44:00+03	2017-07-31 18:19:00+03
31565	PG0495	2017-08-17 14:40:00+03	2017-08-17 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31566	PG0495	2017-09-04 14:40:00+03	2017-09-04 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31567	PG0494	2017-08-17 11:35:00+03	2017-08-17 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31568	PG0495	2017-08-13 14:40:00+03	2017-08-13 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-13 14:44:00+03	2017-08-13 18:22:00+03
31569	PG0494	2017-08-13 11:35:00+03	2017-08-13 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-13 11:38:00+03	2017-08-13 15:13:00+03
31570	PG0494	2017-07-24 11:35:00+03	2017-07-24 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-24 14:59:00+03	2017-07-24 18:37:00+03
31571	PG0495	2017-07-24 14:40:00+03	2017-07-24 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-24 14:43:00+03	2017-07-24 18:19:00+03
31572	PG0495	2017-08-08 14:40:00+03	2017-08-08 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-08 14:45:00+03	2017-08-08 18:18:00+03
31573	PG0494	2017-08-07 11:35:00+03	2017-08-07 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-07 11:38:00+03	2017-08-07 15:11:00+03
31574	PG0495	2017-08-01 14:40:00+03	2017-08-01 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-01 14:41:00+03	2017-08-01 18:20:00+03
31575	PG0495	2017-08-07 14:40:00+03	2017-08-07 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-07 14:43:00+03	2017-08-07 18:21:00+03
31576	PG0494	2017-08-01 11:35:00+03	2017-08-01 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-01 11:40:00+03	2017-08-01 15:15:00+03
31577	PG0495	2017-08-22 14:40:00+03	2017-08-22 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31578	PG0494	2017-09-02 11:35:00+03	2017-09-02 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31579	PG0495	2017-09-02 14:40:00+03	2017-09-02 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31580	PG0494	2017-07-29 11:35:00+03	2017-07-29 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-29 11:40:00+03	2017-07-29 15:15:00+03
31581	PG0495	2017-07-29 14:40:00+03	2017-07-29 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-29 14:43:00+03	2017-07-29 18:19:00+03
31582	PG0495	2017-07-22 14:40:00+03	2017-07-22 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-22 14:44:00+03	2017-07-22 18:16:00+03
31583	PG0494	2017-07-22 11:35:00+03	2017-07-22 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-22 11:36:00+03	2017-07-22 15:11:00+03
31584	PG0494	2017-09-11 11:35:00+03	2017-09-11 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31585	PG0495	2017-09-11 14:40:00+03	2017-09-11 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31586	PG0495	2017-08-21 14:40:00+03	2017-08-21 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31587	PG0494	2017-08-21 11:35:00+03	2017-08-21 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31588	PG0494	2017-08-10 11:35:00+03	2017-08-10 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-10 11:38:00+03	2017-08-10 15:14:00+03
31589	PG0494	2017-08-08 11:35:00+03	2017-08-08 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-08 11:37:00+03	2017-08-08 15:11:00+03
31590	PG0494	2017-09-14 11:35:00+03	2017-09-14 15:10:00+03	ARH	PEE	Cancelled	CN1	\N	\N
31591	PG0494	2017-08-19 11:35:00+03	2017-08-19 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31592	PG0495	2017-08-19 14:40:00+03	2017-08-19 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31593	PG0495	2017-08-10 14:40:00+03	2017-08-10 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-10 14:43:00+03	2017-08-10 18:16:00+03
31594	PG0494	2017-08-22 11:35:00+03	2017-08-22 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31595	PG0495	2017-08-09 14:40:00+03	2017-08-09 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-09 14:41:00+03	2017-08-09 18:15:00+03
31596	PG0494	2017-08-31 11:35:00+03	2017-08-31 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31597	PG0495	2017-08-31 14:40:00+03	2017-08-31 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31598	PG0495	2017-08-04 14:40:00+03	2017-08-04 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-04 14:43:00+03	2017-08-04 18:20:00+03
31599	PG0495	2017-09-07 14:40:00+03	2017-09-07 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31600	PG0494	2017-09-07 11:35:00+03	2017-09-07 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31601	PG0494	2017-08-09 11:35:00+03	2017-08-09 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-09 11:39:00+03	2017-08-09 15:13:00+03
31602	PG0494	2017-08-04 11:35:00+03	2017-08-04 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-04 11:40:00+03	2017-08-04 15:15:00+03
31603	PG0494	2017-08-15 11:35:00+03	2017-08-15 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-15 11:37:00+03	2017-08-15 15:10:00+03
31604	PG0495	2017-08-15 14:40:00+03	2017-08-15 18:15:00+03	ARH	PEE	Departed	CN1	2017-08-15 14:41:00+03	\N
31605	PG0494	2017-08-02 11:35:00+03	2017-08-02 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-02 11:36:00+03	2017-08-02 15:10:00+03
31606	PG0495	2017-08-12 14:40:00+03	2017-08-12 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-12 14:44:00+03	2017-08-12 18:18:00+03
31607	PG0494	2017-08-12 11:35:00+03	2017-08-12 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-12 11:35:00+03	2017-08-12 15:09:00+03
31608	PG0495	2017-08-02 14:40:00+03	2017-08-02 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-02 14:44:00+03	2017-08-02 18:16:00+03
31609	PG0495	2017-07-26 14:40:00+03	2017-07-26 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-26 14:43:00+03	2017-07-26 18:18:00+03
31610	PG0494	2017-07-26 11:35:00+03	2017-07-26 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-26 11:35:00+03	2017-07-26 15:07:00+03
31611	PG0494	2017-08-16 11:35:00+03	2017-08-16 15:10:00+03	ARH	PEE	Delayed	CN1	\N	\N
31612	PG0494	2017-09-06 11:35:00+03	2017-09-06 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31613	PG0495	2017-09-06 14:40:00+03	2017-09-06 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31614	PG0494	2017-07-17 11:35:00+03	2017-07-17 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-17 11:36:00+03	2017-07-17 15:11:00+03
31615	PG0495	2017-07-17 14:40:00+03	2017-07-17 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-17 14:47:00+03	2017-07-17 18:21:00+03
31616	PG0495	2017-08-16 14:40:00+03	2017-08-16 18:15:00+03	ARH	PEE	On Time	CN1	\N	\N
31617	PG0495	2017-09-14 14:40:00+03	2017-09-14 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31618	PG0494	2017-07-30 11:35:00+03	2017-07-30 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-30 11:39:00+03	2017-07-30 15:11:00+03
31619	PG0495	2017-07-30 14:40:00+03	2017-07-30 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-30 14:41:00+03	2017-07-30 18:16:00+03
31620	PG0495	2017-07-21 14:40:00+03	2017-07-21 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-21 14:43:00+03	2017-07-21 18:17:00+03
31621	PG0494	2017-07-21 11:35:00+03	2017-07-21 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-21 11:38:00+03	2017-07-21 15:11:00+03
31622	PG0495	2017-09-01 14:40:00+03	2017-09-01 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31623	PG0494	2017-09-01 11:35:00+03	2017-09-01 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31624	PG0495	2017-08-23 14:40:00+03	2017-08-23 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31625	PG0494	2017-08-23 11:35:00+03	2017-08-23 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31626	PG0494	2017-09-09 11:35:00+03	2017-09-09 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31627	PG0495	2017-09-09 14:40:00+03	2017-09-09 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31628	PG0494	2017-08-06 11:35:00+03	2017-08-06 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-06 11:40:00+03	2017-08-06 15:17:00+03
31629	PG0495	2017-07-25 14:40:00+03	2017-07-25 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-25 14:42:00+03	2017-07-25 18:18:00+03
31630	PG0494	2017-07-25 11:35:00+03	2017-07-25 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-25 11:37:00+03	2017-07-25 15:11:00+03
31631	PG0495	2017-08-06 14:40:00+03	2017-08-06 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-06 14:45:00+03	2017-08-06 18:21:00+03
31632	PG0494	2017-08-20 11:35:00+03	2017-08-20 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31633	PG0495	2017-08-20 14:40:00+03	2017-08-20 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31634	PG0495	2017-08-29 14:40:00+03	2017-08-29 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31635	PG0494	2017-08-03 11:35:00+03	2017-08-03 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-03 11:39:00+03	2017-08-03 15:14:00+03
31636	PG0494	2017-08-29 11:35:00+03	2017-08-29 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31637	PG0495	2017-08-11 14:40:00+03	2017-08-11 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-11 14:43:00+03	2017-08-11 18:17:00+03
31638	PG0495	2017-08-27 14:40:00+03	2017-08-27 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31639	PG0494	2017-08-27 11:35:00+03	2017-08-27 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31640	PG0494	2017-08-11 11:35:00+03	2017-08-11 15:10:00+03	ARH	PEE	Arrived	CN1	2017-08-11 11:38:00+03	2017-08-11 15:11:00+03
31641	PG0494	2017-07-20 11:35:00+03	2017-07-20 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-20 11:39:00+03	2017-07-20 15:11:00+03
31642	PG0495	2017-07-20 14:40:00+03	2017-07-20 18:15:00+03	ARH	PEE	Arrived	CN1	2017-07-20 14:44:00+03	2017-07-20 18:18:00+03
31643	PG0495	2017-08-03 14:40:00+03	2017-08-03 18:15:00+03	ARH	PEE	Arrived	CN1	2017-08-03 14:46:00+03	2017-08-03 18:21:00+03
31644	PG0494	2017-07-18 11:35:00+03	2017-07-18 15:10:00+03	ARH	PEE	Arrived	CN1	2017-07-18 11:36:00+03	2017-07-18 15:07:00+03
31645	PG0495	2017-09-03 14:40:00+03	2017-09-03 18:15:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31646	PG0494	2017-09-03 11:35:00+03	2017-09-03 15:10:00+03	ARH	PEE	Scheduled	CN1	\N	\N
31647	PG0491	2017-09-02 12:50:00+03	2017-09-02 16:50:00+03	ARH	ABA	Scheduled	319	\N	\N
31648	PG0491	2017-08-26 12:50:00+03	2017-08-26 16:50:00+03	ARH	ABA	Scheduled	319	\N	\N
31649	PG0491	2017-08-19 12:50:00+03	2017-08-19 16:50:00+03	ARH	ABA	Scheduled	319	\N	\N
31650	PG0491	2017-07-29 12:50:00+03	2017-07-29 16:50:00+03	ARH	ABA	Arrived	319	2017-07-29 12:52:00+03	2017-07-29 16:54:00+03
31651	PG0491	2017-08-12 12:50:00+03	2017-08-12 16:50:00+03	ARH	ABA	Arrived	319	2017-08-12 12:53:00+03	2017-08-12 16:49:00+03
31652	PG0491	2017-09-09 12:50:00+03	2017-09-09 16:50:00+03	ARH	ABA	Cancelled	319	\N	\N
31653	PG0491	2017-07-22 12:50:00+03	2017-07-22 16:50:00+03	ARH	ABA	Arrived	319	2017-07-22 12:50:00+03	2017-07-22 16:49:00+03
31654	PG0491	2017-08-05 12:50:00+03	2017-08-05 16:50:00+03	ARH	ABA	Arrived	319	2017-08-05 12:52:00+03	2017-08-05 16:52:00+03
31655	PG0258	2017-08-07 11:55:00+03	2017-08-07 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-07 11:56:00+03	2017-08-07 12:51:00+03
31656	PG0258	2017-08-14 11:55:00+03	2017-08-14 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-14 11:58:00+03	2017-08-14 12:52:00+03
31657	PG0258	2017-07-25 11:55:00+03	2017-07-25 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-25 12:01:00+03	2017-07-25 12:56:00+03
31658	PG0258	2017-07-21 11:55:00+03	2017-07-21 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-21 11:57:00+03	2017-07-21 12:52:00+03
31659	PG0258	2017-07-18 11:55:00+03	2017-07-18 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-18 11:59:00+03	2017-07-18 12:54:00+03
31660	PG0258	2017-09-12 11:55:00+03	2017-09-12 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31661	PG0258	2017-08-16 11:55:00+03	2017-08-16 12:50:00+03	ARH	NNM	On Time	CR2	\N	\N
31662	PG0258	2017-09-07 11:55:00+03	2017-09-07 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31663	PG0258	2017-08-12 11:55:00+03	2017-08-12 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-12 11:58:00+03	2017-08-12 12:53:00+03
31664	PG0258	2017-09-04 11:55:00+03	2017-09-04 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31665	PG0258	2017-07-19 11:55:00+03	2017-07-19 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-19 11:57:00+03	2017-07-19 12:52:00+03
31666	PG0258	2017-08-02 11:55:00+03	2017-08-02 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-02 11:58:00+03	2017-08-02 12:53:00+03
31667	PG0258	2017-09-13 11:55:00+03	2017-09-13 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31668	PG0258	2017-08-23 11:55:00+03	2017-08-23 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31669	PG0258	2017-08-05 11:55:00+03	2017-08-05 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-05 11:59:00+03	2017-08-05 12:54:00+03
31670	PG0258	2017-09-06 11:55:00+03	2017-09-06 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31671	PG0258	2017-09-14 11:55:00+03	2017-09-14 12:50:00+03	ARH	NNM	Cancelled	CR2	\N	\N
31672	PG0258	2017-08-27 11:55:00+03	2017-08-27 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31673	PG0258	2017-08-31 11:55:00+03	2017-08-31 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31674	PG0258	2017-08-01 11:55:00+03	2017-08-01 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-01 12:00:00+03	2017-08-01 12:55:00+03
31675	PG0258	2017-08-10 11:55:00+03	2017-08-10 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-10 11:58:00+03	2017-08-10 12:54:00+03
31676	PG0258	2017-09-01 11:55:00+03	2017-09-01 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31677	PG0258	2017-08-04 11:55:00+03	2017-08-04 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-04 11:55:00+03	2017-08-04 12:50:00+03
31678	PG0258	2017-08-26 11:55:00+03	2017-08-26 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31679	PG0258	2017-07-29 11:55:00+03	2017-07-29 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-29 12:00:00+03	2017-07-29 12:55:00+03
31680	PG0258	2017-08-22 11:55:00+03	2017-08-22 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31681	PG0258	2017-08-18 11:55:00+03	2017-08-18 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31682	PG0258	2017-07-24 11:55:00+03	2017-07-24 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-24 11:57:00+03	2017-07-24 12:51:00+03
31683	PG0258	2017-07-27 11:55:00+03	2017-07-27 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-27 12:02:00+03	2017-07-27 12:57:00+03
31684	PG0258	2017-07-30 11:55:00+03	2017-07-30 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-30 11:59:00+03	2017-07-30 12:54:00+03
31685	PG0258	2017-09-08 11:55:00+03	2017-09-08 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31686	PG0258	2017-09-11 11:55:00+03	2017-09-11 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31687	PG0258	2017-08-24 11:55:00+03	2017-08-24 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31688	PG0258	2017-07-23 11:55:00+03	2017-07-23 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-23 11:57:00+03	2017-07-23 12:52:00+03
31689	PG0258	2017-08-17 11:55:00+03	2017-08-17 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31690	PG0258	2017-07-22 11:55:00+03	2017-07-22 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-22 11:57:00+03	2017-07-22 12:51:00+03
31691	PG0258	2017-09-05 11:55:00+03	2017-09-05 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31692	PG0258	2017-09-10 11:55:00+03	2017-09-10 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31693	PG0258	2017-07-17 11:55:00+03	2017-07-17 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-17 11:58:00+03	2017-07-17 12:53:00+03
31694	PG0258	2017-08-30 11:55:00+03	2017-08-30 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31695	PG0258	2017-08-25 11:55:00+03	2017-08-25 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31696	PG0258	2017-07-16 11:55:00+03	2017-07-16 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-16 12:00:00+03	2017-07-16 12:55:00+03
31697	PG0258	2017-08-09 11:55:00+03	2017-08-09 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-09 11:58:00+03	2017-08-09 12:53:00+03
31698	PG0258	2017-07-20 11:55:00+03	2017-07-20 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-20 11:56:00+03	2017-07-20 12:51:00+03
31699	PG0258	2017-07-28 11:55:00+03	2017-07-28 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-28 12:03:00+03	2017-07-28 12:58:00+03
31700	PG0258	2017-08-29 11:55:00+03	2017-08-29 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31701	PG0258	2017-08-08 11:55:00+03	2017-08-08 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-08 12:00:00+03	2017-08-08 12:56:00+03
31702	PG0258	2017-08-28 11:55:00+03	2017-08-28 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31703	PG0258	2017-09-09 11:55:00+03	2017-09-09 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31704	PG0258	2017-08-13 11:55:00+03	2017-08-13 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-13 11:56:00+03	2017-08-13 12:50:00+03
31705	PG0258	2017-08-03 11:55:00+03	2017-08-03 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-03 11:59:00+03	2017-08-03 12:54:00+03
31706	PG0258	2017-09-03 11:55:00+03	2017-09-03 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31707	PG0258	2017-08-19 11:55:00+03	2017-08-19 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31708	PG0258	2017-07-26 11:55:00+03	2017-07-26 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-26 15:31:00+03	2017-07-26 16:25:00+03
31709	PG0258	2017-08-06 11:55:00+03	2017-08-06 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-06 11:59:00+03	2017-08-06 12:55:00+03
31710	PG0258	2017-08-11 11:55:00+03	2017-08-11 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-11 11:57:00+03	2017-08-11 12:52:00+03
31711	PG0258	2017-07-31 11:55:00+03	2017-07-31 12:50:00+03	ARH	NNM	Arrived	CR2	2017-07-31 11:58:00+03	2017-07-31 12:52:00+03
31712	PG0258	2017-09-02 11:55:00+03	2017-09-02 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31713	PG0258	2017-08-20 11:55:00+03	2017-08-20 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31714	PG0258	2017-08-15 11:55:00+03	2017-08-15 12:50:00+03	ARH	NNM	Arrived	CR2	2017-08-15 11:59:00+03	2017-08-15 12:55:00+03
31715	PG0258	2017-08-21 11:55:00+03	2017-08-21 12:50:00+03	ARH	NNM	Scheduled	CR2	\N	\N
31716	PG0688	2017-09-06 13:35:00+03	2017-09-06 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31717	PG0688	2017-08-23 13:35:00+03	2017-08-23 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31718	PG0688	2017-07-23 13:35:00+03	2017-07-23 15:45:00+03	ARH	HMA	Arrived	CR2	2017-07-23 13:37:00+03	2017-07-23 15:47:00+03
31719	PG0688	2017-09-10 13:35:00+03	2017-09-10 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31720	PG0688	2017-09-03 13:35:00+03	2017-09-03 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31721	PG0688	2017-08-02 13:35:00+03	2017-08-02 15:45:00+03	ARH	HMA	Arrived	CR2	2017-08-02 13:36:00+03	2017-08-02 15:42:00+03
31722	PG0688	2017-07-30 13:35:00+03	2017-07-30 15:45:00+03	ARH	HMA	Arrived	CR2	2017-07-30 13:38:00+03	2017-07-30 15:50:00+03
31723	PG0688	2017-08-20 13:35:00+03	2017-08-20 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31724	PG0688	2017-08-13 13:35:00+03	2017-08-13 15:45:00+03	ARH	HMA	Arrived	CR2	2017-08-13 13:38:00+03	2017-08-13 15:49:00+03
31725	PG0688	2017-08-30 13:35:00+03	2017-08-30 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31726	PG0688	2017-09-13 13:35:00+03	2017-09-13 15:45:00+03	ARH	HMA	Cancelled	CR2	\N	\N
31727	PG0688	2017-07-19 13:35:00+03	2017-07-19 15:45:00+03	ARH	HMA	Arrived	CR2	2017-07-19 13:41:00+03	2017-07-19 15:51:00+03
31728	PG0688	2017-07-26 13:35:00+03	2017-07-26 15:45:00+03	ARH	HMA	Arrived	CR2	2017-07-26 16:18:00+03	2017-07-26 18:28:00+03
31729	PG0688	2017-08-09 13:35:00+03	2017-08-09 15:45:00+03	ARH	HMA	Arrived	CR2	2017-08-09 13:37:00+03	2017-08-09 15:49:00+03
31730	PG0688	2017-07-16 13:35:00+03	2017-07-16 15:45:00+03	ARH	HMA	Arrived	CR2	2017-07-16 13:41:00+03	2017-07-16 15:51:00+03
31731	PG0688	2017-08-16 13:35:00+03	2017-08-16 15:45:00+03	ARH	HMA	On Time	CR2	\N	\N
31732	PG0688	2017-08-27 13:35:00+03	2017-08-27 15:45:00+03	ARH	HMA	Scheduled	CR2	\N	\N
31733	PG0688	2017-08-06 13:35:00+03	2017-08-06 15:45:00+03	ARH	HMA	Arrived	CR2	2017-08-06 13:40:00+03	2017-08-06 15:52:00+03
31734	PG0155	2017-09-12 12:45:00+03	2017-09-12 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31735	PG0155	2017-08-01 12:45:00+03	2017-08-01 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-01 12:49:00+03	2017-08-01 15:03:00+03
31736	PG0155	2017-09-10 12:45:00+03	2017-09-10 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31737	PG0155	2017-08-20 12:45:00+03	2017-08-20 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31738	PG0155	2017-08-08 12:45:00+03	2017-08-08 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-08 12:47:00+03	2017-08-08 15:03:00+03
31739	PG0155	2017-08-17 12:45:00+03	2017-08-17 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31740	PG0155	2017-09-03 12:45:00+03	2017-09-03 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31741	PG0155	2017-07-30 12:45:00+03	2017-07-30 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-30 12:48:00+03	2017-07-30 15:03:00+03
31742	PG0155	2017-07-20 12:45:00+03	2017-07-20 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-20 12:46:00+03	2017-07-20 15:03:00+03
31743	PG0155	2017-08-06 12:45:00+03	2017-08-06 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-06 12:49:00+03	2017-08-06 15:04:00+03
31744	PG0155	2017-08-13 12:45:00+03	2017-08-13 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-13 12:47:00+03	2017-08-13 15:02:00+03
31745	PG0155	2017-08-10 12:45:00+03	2017-08-10 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-10 12:48:00+03	2017-08-10 15:02:00+03
31746	PG0155	2017-09-14 12:45:00+03	2017-09-14 15:00:00+03	ARH	TJM	Cancelled	CR2	\N	\N
31747	PG0155	2017-08-27 12:45:00+03	2017-08-27 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31748	PG0155	2017-07-16 12:45:00+03	2017-07-16 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-16 12:50:00+03	2017-07-16 15:04:00+03
31749	PG0155	2017-08-22 12:45:00+03	2017-08-22 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31750	PG0155	2017-07-27 12:45:00+03	2017-07-27 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-27 12:47:00+03	2017-07-27 15:02:00+03
31751	PG0155	2017-08-24 12:45:00+03	2017-08-24 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31752	PG0155	2017-08-15 12:45:00+03	2017-08-15 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-15 12:50:00+03	2017-08-15 15:05:00+03
31753	PG0155	2017-08-03 12:45:00+03	2017-08-03 15:00:00+03	ARH	TJM	Arrived	CR2	2017-08-03 12:49:00+03	2017-08-03 15:02:00+03
31754	PG0155	2017-07-23 12:45:00+03	2017-07-23 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-23 12:48:00+03	2017-07-23 15:03:00+03
31755	PG0155	2017-08-31 12:45:00+03	2017-08-31 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31756	PG0155	2017-08-29 12:45:00+03	2017-08-29 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31757	PG0155	2017-07-18 12:45:00+03	2017-07-18 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-18 12:47:00+03	2017-07-18 15:02:00+03
31758	PG0155	2017-09-05 12:45:00+03	2017-09-05 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31759	PG0155	2017-07-25 12:45:00+03	2017-07-25 15:00:00+03	ARH	TJM	Arrived	CR2	2017-07-25 12:47:00+03	2017-07-25 15:03:00+03
31760	PG0155	2017-09-07 12:45:00+03	2017-09-07 15:00:00+03	ARH	TJM	Scheduled	CR2	\N	\N
31761	PG0375	2017-08-12 10:20:00+03	2017-08-12 15:20:00+03	ARH	IKT	Arrived	319	2017-08-12 10:23:00+03	2017-08-12 15:18:00+03
31762	PG0375	2017-08-26 10:20:00+03	2017-08-26 15:20:00+03	ARH	IKT	Scheduled	319	\N	\N
31763	PG0375	2017-08-19 10:20:00+03	2017-08-19 15:20:00+03	ARH	IKT	Scheduled	319	\N	\N
31764	PG0375	2017-07-22 10:20:00+03	2017-07-22 15:20:00+03	ARH	IKT	Arrived	319	2017-07-22 10:21:00+03	2017-07-22 15:19:00+03
31765	PG0375	2017-09-09 10:20:00+03	2017-09-09 15:20:00+03	ARH	IKT	Cancelled	319	\N	\N
31766	PG0375	2017-09-02 10:20:00+03	2017-09-02 15:20:00+03	ARH	IKT	Scheduled	319	\N	\N
31767	PG0375	2017-08-05 10:20:00+03	2017-08-05 15:20:00+03	ARH	IKT	Arrived	319	2017-08-05 10:25:00+03	2017-08-05 15:25:00+03
31768	PG0375	2017-07-29 10:20:00+03	2017-07-29 15:20:00+03	ARH	IKT	Arrived	319	2017-07-29 10:23:00+03	2017-07-29 15:26:00+03
31769	PG0429	2017-09-10 10:20:00+03	2017-09-10 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31770	PG0429	2017-07-26 10:20:00+03	2017-07-26 14:00:00+03	ARH	TOF	Arrived	CR2	2017-07-26 10:21:00+03	2017-07-26 13:59:00+03
31771	PG0429	2017-08-16 10:20:00+03	2017-08-16 14:00:00+03	ARH	TOF	On Time	CR2	\N	\N
31772	PG0429	2017-08-30 10:20:00+03	2017-08-30 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31773	PG0429	2017-07-16 10:20:00+03	2017-07-16 14:00:00+03	ARH	TOF	Arrived	CR2	2017-07-16 10:26:00+03	2017-07-16 14:05:00+03
31774	PG0429	2017-09-03 10:20:00+03	2017-09-03 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31775	PG0429	2017-07-23 10:20:00+03	2017-07-23 14:00:00+03	ARH	TOF	Arrived	CR2	2017-07-23 10:25:00+03	2017-07-23 14:03:00+03
31776	PG0429	2017-09-13 10:20:00+03	2017-09-13 14:00:00+03	ARH	TOF	Cancelled	CR2	\N	\N
31777	PG0429	2017-08-13 10:20:00+03	2017-08-13 14:00:00+03	ARH	TOF	Arrived	CR2	2017-08-13 10:23:00+03	2017-08-13 14:03:00+03
31778	PG0429	2017-07-30 10:20:00+03	2017-07-30 14:00:00+03	ARH	TOF	Arrived	CR2	2017-07-30 10:21:00+03	2017-07-30 13:59:00+03
31779	PG0429	2017-08-23 10:20:00+03	2017-08-23 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31780	PG0429	2017-08-20 10:20:00+03	2017-08-20 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31781	PG0429	2017-08-27 10:20:00+03	2017-08-27 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31782	PG0429	2017-08-06 10:20:00+03	2017-08-06 14:00:00+03	ARH	TOF	Arrived	CR2	2017-08-06 10:21:00+03	2017-08-06 14:02:00+03
31783	PG0429	2017-09-06 10:20:00+03	2017-09-06 14:00:00+03	ARH	TOF	Scheduled	CR2	\N	\N
31784	PG0429	2017-07-19 10:20:00+03	2017-07-19 14:00:00+03	ARH	TOF	Arrived	CR2	2017-07-19 10:20:00+03	2017-07-19 13:59:00+03
31785	PG0429	2017-08-02 10:20:00+03	2017-08-02 14:00:00+03	ARH	TOF	Arrived	CR2	2017-08-02 10:24:00+03	2017-08-02 14:02:00+03
31786	PG0429	2017-08-09 10:20:00+03	2017-08-09 14:00:00+03	ARH	TOF	Arrived	CR2	2017-08-09 10:22:00+03	2017-08-09 14:02:00+03
31787	PG0288	2017-09-03 13:20:00+03	2017-09-03 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31788	PG0288	2017-09-08 13:20:00+03	2017-09-08 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31789	PG0288	2017-09-01 13:20:00+03	2017-09-01 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31790	PG0288	2017-09-06 13:20:00+03	2017-09-06 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31791	PG0288	2017-07-25 13:20:00+03	2017-07-25 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-25 13:22:00+03	2017-07-25 14:39:00+03
31792	PG0288	2017-08-26 13:20:00+03	2017-08-26 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31793	PG0288	2017-09-11 13:20:00+03	2017-09-11 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31794	PG0288	2017-08-24 13:20:00+03	2017-08-24 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31795	PG0288	2017-08-18 13:20:00+03	2017-08-18 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31796	PG0288	2017-08-29 13:20:00+03	2017-08-29 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31797	PG0288	2017-07-30 13:20:00+03	2017-07-30 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-30 13:25:00+03	2017-07-30 14:40:00+03
31798	PG0288	2017-08-23 13:20:00+03	2017-08-23 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31799	PG0288	2017-08-02 13:20:00+03	2017-08-02 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-02 13:25:00+03	2017-08-02 14:39:00+03
31800	PG0288	2017-08-01 13:20:00+03	2017-08-01 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-01 13:24:00+03	2017-08-01 14:39:00+03
31801	PG0288	2017-07-29 13:20:00+03	2017-07-29 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-29 13:24:00+03	2017-07-29 14:40:00+03
31802	PG0288	2017-08-25 13:20:00+03	2017-08-25 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31803	PG0288	2017-08-16 13:20:00+03	2017-08-16 14:35:00+03	SGC	OVB	On Time	CR2	\N	\N
31804	PG0288	2017-07-24 13:20:00+03	2017-07-24 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-24 13:22:00+03	2017-07-24 14:38:00+03
31805	PG0288	2017-08-31 13:20:00+03	2017-08-31 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31806	PG0288	2017-07-17 13:20:00+03	2017-07-17 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-17 13:22:00+03	2017-07-17 14:37:00+03
31807	PG0288	2017-07-22 13:20:00+03	2017-07-22 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-22 13:22:00+03	2017-07-22 14:36:00+03
31808	PG0288	2017-07-18 13:20:00+03	2017-07-18 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-18 13:21:00+03	2017-07-18 14:36:00+03
31809	PG0288	2017-07-19 13:20:00+03	2017-07-19 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-19 13:24:00+03	2017-07-19 14:38:00+03
31810	PG0288	2017-09-05 13:20:00+03	2017-09-05 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31811	PG0288	2017-08-13 13:20:00+03	2017-08-13 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-13 13:21:00+03	2017-08-13 14:36:00+03
31812	PG0288	2017-08-19 13:20:00+03	2017-08-19 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31813	PG0288	2017-09-04 13:20:00+03	2017-09-04 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31814	PG0288	2017-08-05 13:20:00+03	2017-08-05 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-05 13:23:00+03	2017-08-05 14:36:00+03
31815	PG0288	2017-07-16 13:20:00+03	2017-07-16 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-16 13:23:00+03	2017-07-16 14:37:00+03
31816	PG0288	2017-07-20 13:20:00+03	2017-07-20 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-20 13:26:00+03	2017-07-20 14:42:00+03
31817	PG0288	2017-09-07 13:20:00+03	2017-09-07 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31818	PG0288	2017-07-23 13:20:00+03	2017-07-23 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-23 13:21:00+03	2017-07-23 14:36:00+03
31819	PG0288	2017-09-02 13:20:00+03	2017-09-02 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31820	PG0288	2017-09-09 13:20:00+03	2017-09-09 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31821	PG0288	2017-08-03 13:20:00+03	2017-08-03 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-03 13:22:00+03	2017-08-03 14:38:00+03
31822	PG0288	2017-09-10 13:20:00+03	2017-09-10 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31823	PG0288	2017-08-14 13:20:00+03	2017-08-14 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-14 13:25:00+03	2017-08-14 14:41:00+03
31824	PG0288	2017-08-28 13:20:00+03	2017-08-28 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31825	PG0288	2017-08-20 13:20:00+03	2017-08-20 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31826	PG0288	2017-09-12 13:20:00+03	2017-09-12 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31827	PG0288	2017-07-26 13:20:00+03	2017-07-26 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-26 13:25:00+03	2017-07-26 14:40:00+03
31828	PG0288	2017-07-28 13:20:00+03	2017-07-28 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-28 13:23:00+03	2017-07-28 14:38:00+03
31829	PG0288	2017-07-27 13:20:00+03	2017-07-27 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-27 13:25:00+03	2017-07-27 14:40:00+03
31830	PG0288	2017-08-17 13:20:00+03	2017-08-17 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31831	PG0288	2017-08-09 13:20:00+03	2017-08-09 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-09 13:23:00+03	2017-08-09 14:38:00+03
31832	PG0288	2017-08-11 13:20:00+03	2017-08-11 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-11 13:21:00+03	2017-08-11 14:37:00+03
31833	PG0288	2017-08-22 13:20:00+03	2017-08-22 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31834	PG0288	2017-08-27 13:20:00+03	2017-08-27 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31835	PG0288	2017-08-12 13:20:00+03	2017-08-12 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-12 13:22:00+03	2017-08-12 14:37:00+03
31836	PG0288	2017-08-30 13:20:00+03	2017-08-30 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31837	PG0288	2017-08-04 13:20:00+03	2017-08-04 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-04 13:28:00+03	2017-08-04 14:42:00+03
31838	PG0288	2017-09-13 13:20:00+03	2017-09-13 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31839	PG0288	2017-07-21 13:20:00+03	2017-07-21 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-21 13:23:00+03	2017-07-21 14:38:00+03
31840	PG0288	2017-08-06 13:20:00+03	2017-08-06 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-06 13:21:00+03	2017-08-06 14:36:00+03
31841	PG0288	2017-08-07 13:20:00+03	2017-08-07 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-07 13:23:00+03	2017-08-07 14:38:00+03
31842	PG0288	2017-08-10 13:20:00+03	2017-08-10 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-10 13:25:00+03	2017-08-10 14:40:00+03
31843	PG0288	2017-08-15 13:20:00+03	2017-08-15 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-15 13:27:00+03	2017-08-15 14:42:00+03
31844	PG0288	2017-08-21 13:20:00+03	2017-08-21 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31845	PG0288	2017-07-31 13:20:00+03	2017-07-31 14:35:00+03	SGC	OVB	Arrived	CR2	2017-07-31 13:24:00+03	2017-07-31 14:39:00+03
31846	PG0288	2017-08-08 13:20:00+03	2017-08-08 14:35:00+03	SGC	OVB	Arrived	CR2	2017-08-08 13:22:00+03	2017-08-08 14:37:00+03
31847	PG0288	2017-09-14 13:20:00+03	2017-09-14 14:35:00+03	SGC	OVB	Scheduled	CR2	\N	\N
31848	PG0304	2017-07-18 14:45:00+03	2017-07-18 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-18 14:53:00+03	2017-07-18 16:03:00+03
31849	PG0304	2017-08-24 14:45:00+03	2017-08-24 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31850	PG0304	2017-08-17 14:45:00+03	2017-08-17 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31851	PG0304	2017-08-21 14:45:00+03	2017-08-21 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31852	PG0304	2017-08-20 14:45:00+03	2017-08-20 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31853	PG0304	2017-08-10 14:45:00+03	2017-08-10 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-10 14:50:00+03	2017-08-10 16:00:00+03
31854	PG0304	2017-08-16 14:45:00+03	2017-08-16 15:55:00+03	SGC	SVX	On Time	SU9	\N	\N
31855	PG0304	2017-07-31 14:45:00+03	2017-07-31 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-31 14:50:00+03	2017-07-31 16:00:00+03
31856	PG0304	2017-08-29 14:45:00+03	2017-08-29 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31857	PG0304	2017-08-08 14:45:00+03	2017-08-08 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-08 14:45:00+03	2017-08-08 15:55:00+03
31858	PG0304	2017-08-23 14:45:00+03	2017-08-23 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31859	PG0304	2017-08-03 14:45:00+03	2017-08-03 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-03 14:49:00+03	2017-08-03 15:59:00+03
31860	PG0304	2017-07-25 14:45:00+03	2017-07-25 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-25 14:47:00+03	2017-07-25 15:58:00+03
31861	PG0304	2017-09-10 14:45:00+03	2017-09-10 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31862	PG0304	2017-07-30 14:45:00+03	2017-07-30 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-30 14:49:00+03	2017-07-30 15:59:00+03
31863	PG0304	2017-08-11 14:45:00+03	2017-08-11 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-11 14:46:00+03	2017-08-11 15:56:00+03
31864	PG0304	2017-09-11 14:45:00+03	2017-09-11 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31865	PG0304	2017-08-09 14:45:00+03	2017-08-09 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-09 14:50:00+03	2017-08-09 16:00:00+03
31866	PG0304	2017-08-22 14:45:00+03	2017-08-22 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31867	PG0304	2017-08-15 14:45:00+03	2017-08-15 15:55:00+03	SGC	SVX	Departed	SU9	2017-08-15 17:49:00+03	\N
31868	PG0304	2017-08-30 14:45:00+03	2017-08-30 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31869	PG0304	2017-09-03 14:45:00+03	2017-09-03 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31870	PG0304	2017-09-04 14:45:00+03	2017-09-04 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31871	PG0304	2017-07-26 14:45:00+03	2017-07-26 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-26 14:50:00+03	2017-07-26 16:00:00+03
31872	PG0304	2017-07-17 14:45:00+03	2017-07-17 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-17 14:46:00+03	2017-07-17 15:56:00+03
31873	PG0304	2017-09-13 14:45:00+03	2017-09-13 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31874	PG0304	2017-09-06 14:45:00+03	2017-09-06 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31875	PG0304	2017-08-01 14:45:00+03	2017-08-01 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-01 14:49:00+03	2017-08-01 15:59:00+03
31876	PG0304	2017-08-05 14:45:00+03	2017-08-05 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-05 14:50:00+03	2017-08-05 16:00:00+03
31877	PG0304	2017-09-12 14:45:00+03	2017-09-12 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31878	PG0304	2017-08-07 14:45:00+03	2017-08-07 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-07 14:48:00+03	2017-08-07 15:57:00+03
31879	PG0304	2017-08-19 14:45:00+03	2017-08-19 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31880	PG0304	2017-07-19 14:45:00+03	2017-07-19 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-19 14:45:00+03	2017-07-19 15:56:00+03
31881	PG0304	2017-07-23 14:45:00+03	2017-07-23 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-23 14:49:00+03	2017-07-23 15:58:00+03
31882	PG0304	2017-09-09 14:45:00+03	2017-09-09 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31883	PG0304	2017-08-02 14:45:00+03	2017-08-02 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-02 14:48:00+03	2017-08-02 15:58:00+03
31884	PG0304	2017-07-29 14:45:00+03	2017-07-29 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-29 14:50:00+03	2017-07-29 16:00:00+03
31885	PG0304	2017-09-08 14:45:00+03	2017-09-08 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31886	PG0304	2017-08-27 14:45:00+03	2017-08-27 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31887	PG0304	2017-09-01 14:45:00+03	2017-09-01 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31888	PG0304	2017-09-07 14:45:00+03	2017-09-07 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31889	PG0304	2017-09-05 14:45:00+03	2017-09-05 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31890	PG0304	2017-08-25 14:45:00+03	2017-08-25 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31891	PG0304	2017-08-31 14:45:00+03	2017-08-31 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31892	PG0304	2017-08-12 14:45:00+03	2017-08-12 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-12 14:48:00+03	2017-08-12 15:57:00+03
31893	PG0304	2017-08-13 14:45:00+03	2017-08-13 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-13 14:50:00+03	2017-08-13 16:01:00+03
31894	PG0304	2017-08-14 14:45:00+03	2017-08-14 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-14 14:51:00+03	2017-08-14 16:00:00+03
31895	PG0304	2017-08-28 14:45:00+03	2017-08-28 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31896	PG0304	2017-08-26 14:45:00+03	2017-08-26 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31897	PG0304	2017-07-27 14:45:00+03	2017-07-27 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-27 14:48:00+03	2017-07-27 15:58:00+03
31898	PG0304	2017-09-14 14:45:00+03	2017-09-14 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31899	PG0304	2017-09-02 14:45:00+03	2017-09-02 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31900	PG0304	2017-07-22 14:45:00+03	2017-07-22 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-22 14:47:00+03	2017-07-22 15:57:00+03
31901	PG0304	2017-07-16 14:45:00+03	2017-07-16 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-16 14:48:00+03	2017-07-16 15:58:00+03
31902	PG0304	2017-08-18 14:45:00+03	2017-08-18 15:55:00+03	SGC	SVX	Scheduled	SU9	\N	\N
31903	PG0304	2017-07-20 14:45:00+03	2017-07-20 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-20 14:49:00+03	2017-07-20 15:58:00+03
31904	PG0304	2017-07-21 14:45:00+03	2017-07-21 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-21 14:47:00+03	2017-07-21 15:56:00+03
31905	PG0304	2017-08-04 14:45:00+03	2017-08-04 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-04 14:52:00+03	2017-08-04 16:02:00+03
31906	PG0304	2017-07-28 14:45:00+03	2017-07-28 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-28 14:47:00+03	2017-07-28 15:55:00+03
31907	PG0304	2017-07-24 14:45:00+03	2017-07-24 15:55:00+03	SGC	SVX	Arrived	SU9	2017-07-24 14:49:00+03	2017-07-24 15:58:00+03
31908	PG0304	2017-08-06 14:45:00+03	2017-08-06 15:55:00+03	SGC	SVX	Arrived	SU9	2017-08-06 14:48:00+03	2017-08-06 16:00:00+03
31909	PG0192	2017-08-10 12:35:00+03	2017-08-10 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-10 12:37:00+03	2017-08-10 15:44:00+03
31910	PG0193	2017-07-26 15:20:00+03	2017-07-26 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-26 15:24:00+03	2017-07-26 18:34:00+03
31911	PG0193	2017-07-28 15:20:00+03	2017-07-28 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-28 18:18:00+03	2017-07-28 21:30:00+03
31912	PG0192	2017-07-28 12:35:00+03	2017-07-28 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-28 12:39:00+03	2017-07-28 15:48:00+03
31913	PG0193	2017-08-07 15:20:00+03	2017-08-07 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-07 15:21:00+03	2017-08-07 18:30:00+03
31914	PG0192	2017-08-07 12:35:00+03	2017-08-07 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-07 12:36:00+03	2017-08-07 15:45:00+03
31915	PG0192	2017-08-09 12:35:00+03	2017-08-09 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-09 12:38:00+03	2017-08-09 15:48:00+03
31916	PG0193	2017-09-06 15:20:00+03	2017-09-06 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31917	PG0192	2017-09-06 12:35:00+03	2017-09-06 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31918	PG0193	2017-08-09 15:20:00+03	2017-08-09 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-09 15:24:00+03	2017-08-09 18:32:00+03
31919	PG0192	2017-08-12 12:35:00+03	2017-08-12 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-12 12:40:00+03	2017-08-12 15:46:00+03
31920	PG0193	2017-09-14 15:20:00+03	2017-09-14 18:30:00+03	SGC	CEK	Cancelled	CN1	\N	\N
31921	PG0193	2017-08-12 15:20:00+03	2017-08-12 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-12 15:24:00+03	2017-08-12 18:33:00+03
31922	PG0193	2017-08-18 15:20:00+03	2017-08-18 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31923	PG0192	2017-08-18 12:35:00+03	2017-08-18 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31924	PG0192	2017-08-02 12:35:00+03	2017-08-02 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-02 12:38:00+03	2017-08-02 15:46:00+03
31925	PG0193	2017-08-02 15:20:00+03	2017-08-02 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-02 15:22:00+03	2017-08-02 18:34:00+03
31926	PG0192	2017-07-24 12:35:00+03	2017-07-24 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-24 12:37:00+03	2017-07-24 15:47:00+03
31927	PG0193	2017-07-24 15:20:00+03	2017-07-24 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-24 15:23:00+03	2017-07-24 18:33:00+03
31928	PG0192	2017-08-22 12:35:00+03	2017-08-22 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31929	PG0193	2017-08-22 15:20:00+03	2017-08-22 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31930	PG0192	2017-09-02 12:35:00+03	2017-09-02 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31931	PG0193	2017-09-02 15:20:00+03	2017-09-02 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31932	PG0192	2017-09-10 12:35:00+03	2017-09-10 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31933	PG0192	2017-07-16 12:35:00+03	2017-07-16 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-16 12:39:00+03	2017-07-16 15:47:00+03
31934	PG0192	2017-08-04 12:35:00+03	2017-08-04 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-04 12:37:00+03	2017-08-04 15:44:00+03
31935	PG0193	2017-08-04 15:20:00+03	2017-08-04 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-04 15:21:00+03	2017-08-04 18:31:00+03
31936	PG0192	2017-07-27 12:35:00+03	2017-07-27 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-27 12:39:00+03	2017-07-27 15:51:00+03
31937	PG0193	2017-09-12 15:20:00+03	2017-09-12 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31938	PG0192	2017-08-29 12:35:00+03	2017-08-29 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31939	PG0193	2017-08-29 15:20:00+03	2017-08-29 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31940	PG0192	2017-09-09 12:35:00+03	2017-09-09 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31941	PG0192	2017-09-12 12:35:00+03	2017-09-12 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31942	PG0192	2017-07-18 12:35:00+03	2017-07-18 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-18 12:38:00+03	2017-07-18 15:47:00+03
31943	PG0193	2017-09-09 15:20:00+03	2017-09-09 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31944	PG0192	2017-07-19 12:35:00+03	2017-07-19 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-19 12:37:00+03	2017-07-19 15:47:00+03
31945	PG0192	2017-08-15 12:35:00+03	2017-08-15 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-15 12:38:00+03	2017-08-15 15:49:00+03
31946	PG0193	2017-08-15 15:20:00+03	2017-08-15 18:30:00+03	SGC	CEK	Departed	CN1	2017-08-15 15:24:00+03	\N
31947	PG0193	2017-07-27 15:20:00+03	2017-07-27 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-27 15:21:00+03	2017-07-27 18:29:00+03
31948	PG0193	2017-07-19 15:20:00+03	2017-07-19 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-19 15:24:00+03	2017-07-19 18:36:00+03
31949	PG0193	2017-07-18 15:20:00+03	2017-07-18 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-18 15:21:00+03	2017-07-18 18:30:00+03
31950	PG0193	2017-08-20 15:20:00+03	2017-08-20 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31951	PG0193	2017-08-08 15:20:00+03	2017-08-08 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-08 15:23:00+03	2017-08-08 18:31:00+03
31952	PG0192	2017-08-20 12:35:00+03	2017-08-20 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31953	PG0193	2017-09-10 15:20:00+03	2017-09-10 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31954	PG0192	2017-08-08 12:35:00+03	2017-08-08 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-08 12:39:00+03	2017-08-08 15:54:00+03
31955	PG0192	2017-08-25 12:35:00+03	2017-08-25 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31956	PG0192	2017-08-01 12:35:00+03	2017-08-01 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-01 12:36:00+03	2017-08-01 15:49:00+03
31957	PG0193	2017-08-01 15:20:00+03	2017-08-01 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-01 15:26:00+03	2017-08-01 18:35:00+03
31958	PG0193	2017-09-01 15:20:00+03	2017-09-01 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31959	PG0192	2017-09-01 12:35:00+03	2017-09-01 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31960	PG0193	2017-07-20 15:20:00+03	2017-07-20 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-20 15:23:00+03	2017-07-20 18:32:00+03
31961	PG0192	2017-07-20 12:35:00+03	2017-07-20 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-20 12:39:00+03	2017-07-20 15:49:00+03
31962	PG0193	2017-08-25 15:20:00+03	2017-08-25 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31963	PG0193	2017-07-30 15:20:00+03	2017-07-30 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-30 15:24:00+03	2017-07-30 18:37:00+03
31964	PG0192	2017-07-30 12:35:00+03	2017-07-30 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-30 12:41:00+03	2017-07-30 15:53:00+03
31965	PG0192	2017-09-03 12:35:00+03	2017-09-03 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31966	PG0192	2017-07-22 12:35:00+03	2017-07-22 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-22 12:39:00+03	2017-07-22 15:50:00+03
31967	PG0193	2017-07-25 15:20:00+03	2017-07-25 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-25 15:22:00+03	2017-07-25 18:32:00+03
31968	PG0193	2017-07-22 15:20:00+03	2017-07-22 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-22 15:23:00+03	2017-07-22 18:32:00+03
31969	PG0193	2017-08-23 15:20:00+03	2017-08-23 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31970	PG0192	2017-07-25 12:35:00+03	2017-07-25 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-25 12:38:00+03	2017-07-25 15:49:00+03
31971	PG0193	2017-09-03 15:20:00+03	2017-09-03 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31972	PG0193	2017-07-31 15:20:00+03	2017-07-31 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-31 15:21:00+03	2017-07-31 18:30:00+03
31973	PG0193	2017-08-27 15:20:00+03	2017-08-27 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31974	PG0192	2017-08-28 12:35:00+03	2017-08-28 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31975	PG0193	2017-08-28 15:20:00+03	2017-08-28 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31976	PG0193	2017-08-11 15:20:00+03	2017-08-11 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-11 17:51:00+03	2017-08-11 20:59:00+03
31977	PG0192	2017-07-31 12:35:00+03	2017-07-31 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-31 12:37:00+03	2017-07-31 15:48:00+03
31978	PG0192	2017-08-27 12:35:00+03	2017-08-27 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31979	PG0192	2017-08-23 12:35:00+03	2017-08-23 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31980	PG0192	2017-08-11 12:35:00+03	2017-08-11 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-11 12:40:00+03	2017-08-11 15:54:00+03
31981	PG0192	2017-08-16 12:35:00+03	2017-08-16 15:45:00+03	SGC	CEK	On Time	CN1	\N	\N
31982	PG0192	2017-09-04 12:35:00+03	2017-09-04 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31983	PG0192	2017-07-21 12:35:00+03	2017-07-21 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-21 15:37:00+03	2017-07-21 18:45:00+03
31984	PG0192	2017-08-13 12:35:00+03	2017-08-13 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-13 12:36:00+03	2017-08-13 15:45:00+03
31985	PG0193	2017-08-13 15:20:00+03	2017-08-13 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-13 18:51:00+03	2017-08-13 22:05:00+03
31986	PG0193	2017-07-17 15:20:00+03	2017-07-17 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-17 15:22:00+03	2017-07-17 18:30:00+03
31987	PG0193	2017-07-21 15:20:00+03	2017-07-21 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-21 15:21:00+03	2017-07-21 18:30:00+03
31988	PG0192	2017-07-17 12:35:00+03	2017-07-17 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-17 12:38:00+03	2017-07-17 15:48:00+03
31989	PG0193	2017-09-05 15:20:00+03	2017-09-05 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31990	PG0192	2017-09-07 12:35:00+03	2017-09-07 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31991	PG0193	2017-09-07 15:20:00+03	2017-09-07 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31992	PG0193	2017-08-03 15:20:00+03	2017-08-03 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-03 15:28:00+03	2017-08-03 18:39:00+03
31993	PG0192	2017-08-03 12:35:00+03	2017-08-03 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-03 12:38:00+03	2017-08-03 15:48:00+03
31994	PG0192	2017-09-05 12:35:00+03	2017-09-05 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31995	PG0193	2017-08-19 15:20:00+03	2017-08-19 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31996	PG0192	2017-08-19 12:35:00+03	2017-08-19 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31997	PG0192	2017-08-30 12:35:00+03	2017-08-30 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31998	PG0193	2017-09-04 15:20:00+03	2017-09-04 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
31999	PG0192	2017-09-08 12:35:00+03	2017-09-08 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32000	PG0193	2017-09-08 15:20:00+03	2017-09-08 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32001	PG0193	2017-07-29 15:20:00+03	2017-07-29 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-29 15:24:00+03	2017-07-29 18:33:00+03
32002	PG0193	2017-08-30 15:20:00+03	2017-08-30 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32003	PG0192	2017-07-29 12:35:00+03	2017-07-29 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-29 12:40:00+03	2017-07-29 15:47:00+03
32004	PG0192	2017-08-24 12:35:00+03	2017-08-24 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32005	PG0193	2017-08-24 15:20:00+03	2017-08-24 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32006	PG0192	2017-09-14 12:35:00+03	2017-09-14 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32007	PG0193	2017-08-31 15:20:00+03	2017-08-31 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32008	PG0192	2017-08-31 12:35:00+03	2017-08-31 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32009	PG0192	2017-07-23 12:35:00+03	2017-07-23 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-23 12:39:00+03	2017-07-23 15:49:00+03
32010	PG0193	2017-07-23 15:20:00+03	2017-07-23 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-23 15:20:00+03	2017-07-23 18:35:00+03
32011	PG0193	2017-07-16 15:20:00+03	2017-07-16 18:30:00+03	SGC	CEK	Arrived	CN1	2017-07-16 15:22:00+03	2017-07-16 18:33:00+03
32012	PG0192	2017-08-05 12:35:00+03	2017-08-05 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-05 12:35:00+03	2017-08-05 15:45:00+03
32013	PG0193	2017-08-05 15:20:00+03	2017-08-05 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-05 15:23:00+03	2017-08-05 18:34:00+03
32014	PG0192	2017-08-17 12:35:00+03	2017-08-17 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32015	PG0193	2017-08-17 15:20:00+03	2017-08-17 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32016	PG0193	2017-09-11 15:20:00+03	2017-09-11 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32017	PG0192	2017-09-13 12:35:00+03	2017-09-13 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32018	PG0193	2017-09-13 15:20:00+03	2017-09-13 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32019	PG0192	2017-09-11 12:35:00+03	2017-09-11 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32020	PG0192	2017-07-26 12:35:00+03	2017-07-26 15:45:00+03	SGC	CEK	Arrived	CN1	2017-07-26 12:40:00+03	2017-07-26 15:47:00+03
32021	PG0193	2017-08-26 15:20:00+03	2017-08-26 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32022	PG0192	2017-08-14 12:35:00+03	2017-08-14 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-14 12:38:00+03	2017-08-14 15:46:00+03
32023	PG0193	2017-08-14 15:20:00+03	2017-08-14 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-14 15:23:00+03	2017-08-14 18:34:00+03
32024	PG0193	2017-08-16 15:20:00+03	2017-08-16 18:30:00+03	SGC	CEK	On Time	CN1	\N	\N
32025	PG0192	2017-08-21 12:35:00+03	2017-08-21 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32026	PG0193	2017-08-21 15:20:00+03	2017-08-21 18:30:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32027	PG0192	2017-08-26 12:35:00+03	2017-08-26 15:45:00+03	SGC	CEK	Scheduled	CN1	\N	\N
32028	PG0193	2017-08-06 15:20:00+03	2017-08-06 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-06 15:25:00+03	2017-08-06 18:36:00+03
32029	PG0192	2017-08-06 12:35:00+03	2017-08-06 15:45:00+03	SGC	CEK	Arrived	CN1	2017-08-06 12:39:00+03	2017-08-06 15:47:00+03
32030	PG0193	2017-08-10 15:20:00+03	2017-08-10 18:30:00+03	SGC	CEK	Arrived	CN1	2017-08-10 15:24:00+03	2017-08-10 18:36:00+03
32031	PG0002	2017-08-20 10:10:00+03	2017-08-20 12:30:00+03	SGC	UIK	Scheduled	CR2	\N	\N
32032	PG0002	2017-07-30 10:10:00+03	2017-07-30 12:30:00+03	SGC	UIK	Arrived	CR2	2017-07-30 10:13:00+03	2017-07-30 12:31:00+03
32033	PG0002	2017-08-13 10:10:00+03	2017-08-13 12:30:00+03	SGC	UIK	Arrived	CR2	2017-08-13 10:13:00+03	2017-08-13 12:31:00+03
32034	PG0002	2017-08-06 10:10:00+03	2017-08-06 12:30:00+03	SGC	UIK	Arrived	CR2	2017-08-06 10:14:00+03	2017-08-06 12:35:00+03
32035	PG0002	2017-07-23 10:10:00+03	2017-07-23 12:30:00+03	SGC	UIK	Arrived	CR2	2017-07-23 13:40:00+03	2017-07-23 16:06:00+03
32036	PG0002	2017-08-27 10:10:00+03	2017-08-27 12:30:00+03	SGC	UIK	Scheduled	CR2	\N	\N
32037	PG0002	2017-07-16 10:10:00+03	2017-07-16 12:30:00+03	SGC	UIK	Arrived	CR2	2017-07-16 10:12:00+03	2017-07-16 12:31:00+03
32038	PG0002	2017-09-10 10:10:00+03	2017-09-10 12:30:00+03	SGC	UIK	Cancelled	CR2	\N	\N
32039	PG0002	2017-09-03 10:10:00+03	2017-09-03 12:30:00+03	SGC	UIK	Scheduled	CR2	\N	\N
32040	PG0708	2017-09-04 17:15:00+03	2017-09-04 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32041	PG0708	2017-08-16 17:15:00+03	2017-08-16 18:00:00+03	SGC	OVS	On Time	733	\N	\N
32042	PG0708	2017-07-16 17:15:00+03	2017-07-16 18:00:00+03	SGC	OVS	Arrived	733	2017-07-16 17:15:00+03	2017-07-16 17:59:00+03
32043	PG0708	2017-08-21 17:15:00+03	2017-08-21 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32044	PG0708	2017-08-18 17:15:00+03	2017-08-18 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32045	PG0708	2017-08-19 17:15:00+03	2017-08-19 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32046	PG0708	2017-07-21 17:15:00+03	2017-07-21 18:00:00+03	SGC	OVS	Arrived	733	2017-07-21 17:15:00+03	2017-07-21 18:01:00+03
32047	PG0708	2017-09-02 17:15:00+03	2017-09-02 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32048	PG0708	2017-07-28 17:15:00+03	2017-07-28 18:00:00+03	SGC	OVS	Arrived	733	2017-07-28 17:16:00+03	2017-07-28 18:01:00+03
32049	PG0708	2017-07-17 17:15:00+03	2017-07-17 18:00:00+03	SGC	OVS	Arrived	733	2017-07-17 17:20:00+03	2017-07-17 18:05:00+03
32050	PG0708	2017-08-27 17:15:00+03	2017-08-27 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32051	PG0708	2017-08-28 17:15:00+03	2017-08-28 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32052	PG0708	2017-07-18 17:15:00+03	2017-07-18 18:00:00+03	SGC	OVS	Arrived	733	2017-07-18 17:16:00+03	2017-07-18 18:02:00+03
32053	PG0708	2017-08-26 17:15:00+03	2017-08-26 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32054	PG0708	2017-08-17 17:15:00+03	2017-08-17 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32055	PG0708	2017-08-08 17:15:00+03	2017-08-08 18:00:00+03	SGC	OVS	Arrived	733	2017-08-08 17:18:00+03	2017-08-08 18:03:00+03
32056	PG0708	2017-07-19 17:15:00+03	2017-07-19 18:00:00+03	SGC	OVS	Arrived	733	2017-07-19 17:21:00+03	2017-07-19 18:06:00+03
32057	PG0708	2017-07-24 17:15:00+03	2017-07-24 18:00:00+03	SGC	OVS	Arrived	733	2017-07-24 17:18:00+03	2017-07-24 18:03:00+03
32058	PG0708	2017-09-06 17:15:00+03	2017-09-06 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32059	PG0708	2017-08-20 17:15:00+03	2017-08-20 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32060	PG0708	2017-09-09 17:15:00+03	2017-09-09 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32061	PG0708	2017-09-07 17:15:00+03	2017-09-07 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32062	PG0708	2017-09-13 17:15:00+03	2017-09-13 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32063	PG0708	2017-07-30 17:15:00+03	2017-07-30 18:00:00+03	SGC	OVS	Arrived	733	2017-07-30 17:16:00+03	2017-07-30 18:01:00+03
32064	PG0708	2017-08-12 17:15:00+03	2017-08-12 18:00:00+03	SGC	OVS	Arrived	733	2017-08-12 17:18:00+03	2017-08-12 18:02:00+03
32065	PG0708	2017-08-31 17:15:00+03	2017-08-31 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32066	PG0708	2017-09-08 17:15:00+03	2017-09-08 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32067	PG0708	2017-07-25 17:15:00+03	2017-07-25 18:00:00+03	SGC	OVS	Arrived	733	2017-07-25 17:20:00+03	2017-07-25 18:05:00+03
32068	PG0708	2017-08-11 17:15:00+03	2017-08-11 18:00:00+03	SGC	OVS	Arrived	733	2017-08-11 17:22:00+03	2017-08-11 18:08:00+03
32069	PG0708	2017-09-03 17:15:00+03	2017-09-03 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32070	PG0708	2017-07-29 17:15:00+03	2017-07-29 18:00:00+03	SGC	OVS	Arrived	733	2017-07-29 17:17:00+03	2017-07-29 18:03:00+03
32071	PG0708	2017-08-06 17:15:00+03	2017-08-06 18:00:00+03	SGC	OVS	Arrived	733	2017-08-06 17:19:00+03	2017-08-06 18:04:00+03
32072	PG0708	2017-08-23 17:15:00+03	2017-08-23 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32073	PG0708	2017-08-14 17:15:00+03	2017-08-14 18:00:00+03	SGC	OVS	Arrived	733	2017-08-14 17:17:00+03	2017-08-14 18:03:00+03
32074	PG0708	2017-08-13 17:15:00+03	2017-08-13 18:00:00+03	SGC	OVS	Arrived	733	2017-08-13 17:19:00+03	2017-08-13 18:03:00+03
32075	PG0708	2017-07-27 17:15:00+03	2017-07-27 18:00:00+03	SGC	OVS	Arrived	733	2017-07-27 17:17:00+03	2017-07-27 18:02:00+03
32076	PG0708	2017-08-02 17:15:00+03	2017-08-02 18:00:00+03	SGC	OVS	Arrived	733	2017-08-02 17:17:00+03	2017-08-02 18:02:00+03
32077	PG0708	2017-08-07 17:15:00+03	2017-08-07 18:00:00+03	SGC	OVS	Arrived	733	2017-08-07 17:17:00+03	2017-08-07 18:02:00+03
32078	PG0708	2017-09-01 17:15:00+03	2017-09-01 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32079	PG0708	2017-09-12 17:15:00+03	2017-09-12 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32080	PG0708	2017-08-25 17:15:00+03	2017-08-25 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32081	PG0708	2017-08-04 17:15:00+03	2017-08-04 18:00:00+03	SGC	OVS	Arrived	733	2017-08-04 17:20:00+03	2017-08-04 18:04:00+03
32082	PG0708	2017-08-24 17:15:00+03	2017-08-24 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32083	PG0708	2017-08-15 17:15:00+03	2017-08-15 18:00:00+03	SGC	OVS	Departed	733	2017-08-15 17:17:00+03	\N
32084	PG0708	2017-08-29 17:15:00+03	2017-08-29 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32085	PG0708	2017-08-10 17:15:00+03	2017-08-10 18:00:00+03	SGC	OVS	Arrived	733	2017-08-10 17:19:00+03	2017-08-10 18:05:00+03
32086	PG0708	2017-08-22 17:15:00+03	2017-08-22 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32087	PG0708	2017-08-03 17:15:00+03	2017-08-03 18:00:00+03	SGC	OVS	Arrived	733	2017-08-03 17:19:00+03	2017-08-03 18:03:00+03
32088	PG0708	2017-09-10 17:15:00+03	2017-09-10 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32089	PG0708	2017-07-26 17:15:00+03	2017-07-26 18:00:00+03	SGC	OVS	Arrived	733	2017-07-26 17:18:00+03	2017-07-26 18:03:00+03
32090	PG0708	2017-08-30 17:15:00+03	2017-08-30 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32091	PG0708	2017-08-09 17:15:00+03	2017-08-09 18:00:00+03	SGC	OVS	Arrived	733	2017-08-09 17:19:00+03	2017-08-09 18:04:00+03
32092	PG0708	2017-08-01 17:15:00+03	2017-08-01 18:00:00+03	SGC	OVS	Arrived	733	2017-08-01 17:17:00+03	2017-08-01 18:02:00+03
32093	PG0708	2017-07-22 17:15:00+03	2017-07-22 18:00:00+03	SGC	OVS	Arrived	733	2017-07-22 17:15:00+03	2017-07-22 18:01:00+03
32094	PG0708	2017-09-14 17:15:00+03	2017-09-14 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32095	PG0708	2017-08-05 17:15:00+03	2017-08-05 18:00:00+03	SGC	OVS	Arrived	733	2017-08-05 17:20:00+03	2017-08-05 18:04:00+03
32096	PG0708	2017-09-05 17:15:00+03	2017-09-05 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32097	PG0708	2017-07-31 17:15:00+03	2017-07-31 18:00:00+03	SGC	OVS	Arrived	733	2017-07-31 17:18:00+03	2017-07-31 18:03:00+03
32098	PG0708	2017-07-23 17:15:00+03	2017-07-23 18:00:00+03	SGC	OVS	Arrived	733	2017-07-23 17:19:00+03	2017-07-23 18:05:00+03
32099	PG0708	2017-09-11 17:15:00+03	2017-09-11 18:00:00+03	SGC	OVS	Scheduled	733	\N	\N
32100	PG0708	2017-07-20 17:15:00+03	2017-07-20 18:00:00+03	SGC	OVS	Arrived	733	2017-07-20 17:16:00+03	2017-07-20 18:01:00+03
32101	PG0425	2017-09-03 16:55:00+03	2017-09-03 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32102	PG0424	2017-08-11 12:20:00+03	2017-08-11 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-11 12:22:00+03	2017-08-11 15:04:00+03
32103	PG0425	2017-08-11 16:55:00+03	2017-08-11 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-11 16:55:00+03	2017-08-11 19:34:00+03
32104	PG0425	2017-09-12 16:55:00+03	2017-09-12 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32105	PG0424	2017-09-12 12:20:00+03	2017-09-12 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32106	PG0425	2017-07-31 16:55:00+03	2017-07-31 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-31 16:58:00+03	2017-07-31 19:38:00+03
32107	PG0424	2017-07-31 12:20:00+03	2017-07-31 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-31 12:24:00+03	2017-07-31 15:05:00+03
32108	PG0425	2017-08-06 16:55:00+03	2017-08-06 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-06 16:57:00+03	2017-08-06 19:37:00+03
32109	PG0425	2017-08-08 16:55:00+03	2017-08-08 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-08 17:00:00+03	2017-08-08 19:43:00+03
32110	PG0424	2017-08-08 12:20:00+03	2017-08-08 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-08 12:22:00+03	2017-08-08 15:02:00+03
32111	PG0425	2017-07-20 16:55:00+03	2017-07-20 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-20 16:57:00+03	2017-07-20 19:36:00+03
32112	PG0424	2017-07-20 12:20:00+03	2017-07-20 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-20 12:20:00+03	2017-07-20 15:01:00+03
32113	PG0424	2017-09-01 12:20:00+03	2017-09-01 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32114	PG0425	2017-09-01 16:55:00+03	2017-09-01 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32115	PG0425	2017-08-20 16:55:00+03	2017-08-20 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32116	PG0424	2017-08-20 12:20:00+03	2017-08-20 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32117	PG0424	2017-08-23 12:20:00+03	2017-08-23 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32118	PG0425	2017-08-23 16:55:00+03	2017-08-23 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32119	PG0424	2017-09-14 12:20:00+03	2017-09-14 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32120	PG0425	2017-08-03 16:55:00+03	2017-08-03 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-03 16:58:00+03	2017-08-03 19:39:00+03
32121	PG0424	2017-07-21 12:20:00+03	2017-07-21 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-21 12:24:00+03	2017-07-21 15:04:00+03
32122	PG0424	2017-08-03 12:20:00+03	2017-08-03 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-03 12:22:00+03	2017-08-03 14:59:00+03
32123	PG0425	2017-07-21 16:55:00+03	2017-07-21 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-21 16:57:00+03	2017-07-21 19:38:00+03
32124	PG0425	2017-07-30 16:55:00+03	2017-07-30 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-30 16:58:00+03	2017-07-30 19:37:00+03
32125	PG0424	2017-07-30 12:20:00+03	2017-07-30 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-30 12:22:00+03	2017-07-30 15:03:00+03
32126	PG0424	2017-08-12 12:20:00+03	2017-08-12 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-12 12:26:00+03	2017-08-12 15:06:00+03
32127	PG0425	2017-08-12 16:55:00+03	2017-08-12 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-12 17:00:00+03	2017-08-12 19:42:00+03
32128	PG0425	2017-07-17 16:55:00+03	2017-07-17 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-17 16:57:00+03	2017-07-17 19:37:00+03
32129	PG0424	2017-07-17 12:20:00+03	2017-07-17 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-17 12:23:00+03	2017-07-17 15:05:00+03
32130	PG0424	2017-08-04 12:20:00+03	2017-08-04 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-04 12:21:00+03	2017-08-04 15:04:00+03
32131	PG0424	2017-09-07 12:20:00+03	2017-09-07 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32132	PG0425	2017-09-07 16:55:00+03	2017-09-07 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32133	PG0425	2017-08-04 16:55:00+03	2017-08-04 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-04 16:58:00+03	2017-08-04 19:37:00+03
32134	PG0425	2017-07-25 16:55:00+03	2017-07-25 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-25 17:00:00+03	2017-07-25 19:40:00+03
32135	PG0425	2017-09-06 16:55:00+03	2017-09-06 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32136	PG0424	2017-09-06 12:20:00+03	2017-09-06 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32137	PG0424	2017-08-21 12:20:00+03	2017-08-21 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32138	PG0425	2017-08-21 16:55:00+03	2017-08-21 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32139	PG0425	2017-08-31 16:55:00+03	2017-08-31 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32140	PG0425	2017-08-19 16:55:00+03	2017-08-19 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32141	PG0424	2017-08-31 12:20:00+03	2017-08-31 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32142	PG0424	2017-08-19 12:20:00+03	2017-08-19 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32143	PG0424	2017-07-25 12:20:00+03	2017-07-25 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-25 12:23:00+03	2017-07-25 15:04:00+03
32144	PG0424	2017-07-22 12:20:00+03	2017-07-22 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-22 12:22:00+03	2017-07-22 15:02:00+03
32145	PG0425	2017-07-22 16:55:00+03	2017-07-22 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-22 16:58:00+03	2017-07-22 19:35:00+03
32146	PG0424	2017-08-01 12:20:00+03	2017-08-01 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-01 12:22:00+03	2017-08-01 15:03:00+03
32147	PG0425	2017-08-01 16:55:00+03	2017-08-01 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-01 16:59:00+03	2017-08-01 19:38:00+03
32148	PG0425	2017-08-10 16:55:00+03	2017-08-10 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-10 16:58:00+03	2017-08-10 19:38:00+03
32149	PG0424	2017-08-10 12:20:00+03	2017-08-10 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-10 12:25:00+03	2017-08-10 15:06:00+03
32150	PG0424	2017-09-05 12:20:00+03	2017-09-05 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32151	PG0424	2017-08-06 12:20:00+03	2017-08-06 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-06 12:24:00+03	2017-08-06 15:07:00+03
32152	PG0425	2017-09-05 16:55:00+03	2017-09-05 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32153	PG0425	2017-07-29 16:55:00+03	2017-07-29 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-29 16:59:00+03	2017-07-29 19:38:00+03
32154	PG0424	2017-07-29 12:20:00+03	2017-07-29 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-29 12:25:00+03	2017-07-29 15:06:00+03
32155	PG0425	2017-09-11 16:55:00+03	2017-09-11 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32156	PG0424	2017-09-11 12:20:00+03	2017-09-11 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32157	PG0424	2017-08-13 12:20:00+03	2017-08-13 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-13 12:25:00+03	2017-08-13 15:05:00+03
32158	PG0425	2017-08-13 16:55:00+03	2017-08-13 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-13 16:56:00+03	2017-08-13 19:37:00+03
32159	PG0424	2017-08-28 12:20:00+03	2017-08-28 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32160	PG0425	2017-08-07 16:55:00+03	2017-08-07 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-07 17:01:00+03	2017-08-07 19:43:00+03
32161	PG0425	2017-08-28 16:55:00+03	2017-08-28 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32162	PG0424	2017-08-07 12:20:00+03	2017-08-07 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-07 12:22:00+03	2017-08-07 15:02:00+03
32163	PG0424	2017-08-26 12:20:00+03	2017-08-26 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32164	PG0425	2017-08-26 16:55:00+03	2017-08-26 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32165	PG0424	2017-09-08 12:20:00+03	2017-09-08 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32166	PG0425	2017-09-08 16:55:00+03	2017-09-08 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32167	PG0425	2017-07-28 16:55:00+03	2017-07-28 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-28 16:57:00+03	2017-07-28 19:37:00+03
32168	PG0424	2017-07-28 12:20:00+03	2017-07-28 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-28 12:22:00+03	2017-07-28 15:01:00+03
32169	PG0424	2017-07-18 12:20:00+03	2017-07-18 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-18 12:22:00+03	2017-07-18 15:04:00+03
32170	PG0425	2017-09-04 16:55:00+03	2017-09-04 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32171	PG0424	2017-09-04 12:20:00+03	2017-09-04 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32172	PG0424	2017-07-23 12:20:00+03	2017-07-23 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-23 15:22:00+03	2017-07-23 18:03:00+03
32173	PG0425	2017-07-23 16:55:00+03	2017-07-23 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-23 16:56:00+03	2017-07-23 19:38:00+03
32174	PG0424	2017-09-03 12:20:00+03	2017-09-03 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32175	PG0425	2017-08-18 16:55:00+03	2017-08-18 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32176	PG0424	2017-08-18 12:20:00+03	2017-08-18 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32177	PG0425	2017-07-18 16:55:00+03	2017-07-18 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-18 17:00:00+03	2017-07-18 19:43:00+03
32178	PG0425	2017-07-19 16:55:00+03	2017-07-19 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-19 16:57:00+03	2017-07-19 19:37:00+03
32179	PG0424	2017-07-19 12:20:00+03	2017-07-19 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-19 12:22:00+03	2017-07-19 15:00:00+03
32180	PG0424	2017-08-24 12:20:00+03	2017-08-24 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32181	PG0424	2017-08-14 12:20:00+03	2017-08-14 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-14 12:20:00+03	2017-08-14 15:02:00+03
32182	PG0425	2017-08-14 16:55:00+03	2017-08-14 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-14 17:00:00+03	2017-08-14 19:41:00+03
32183	PG0424	2017-08-05 12:20:00+03	2017-08-05 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-05 12:20:00+03	2017-08-05 15:00:00+03
32184	PG0425	2017-08-05 16:55:00+03	2017-08-05 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-05 17:01:00+03	2017-08-05 19:40:00+03
32185	PG0425	2017-08-24 16:55:00+03	2017-08-24 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32186	PG0425	2017-09-02 16:55:00+03	2017-09-02 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32187	PG0425	2017-07-16 16:55:00+03	2017-07-16 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-16 16:56:00+03	2017-07-16 19:36:00+03
32188	PG0424	2017-07-16 12:20:00+03	2017-07-16 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-16 12:25:00+03	2017-07-16 15:07:00+03
32189	PG0424	2017-09-02 12:20:00+03	2017-09-02 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32190	PG0425	2017-07-27 16:55:00+03	2017-07-27 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-27 16:55:00+03	2017-07-27 19:36:00+03
32191	PG0424	2017-07-27 12:20:00+03	2017-07-27 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-27 12:22:00+03	2017-07-27 15:01:00+03
32192	PG0425	2017-08-30 16:55:00+03	2017-08-30 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32193	PG0424	2017-08-30 12:20:00+03	2017-08-30 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32194	PG0425	2017-08-25 16:55:00+03	2017-08-25 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32195	PG0424	2017-08-25 12:20:00+03	2017-08-25 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32196	PG0424	2017-07-24 12:20:00+03	2017-07-24 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-24 12:22:00+03	2017-07-24 15:01:00+03
32197	PG0425	2017-07-24 16:55:00+03	2017-07-24 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-24 17:03:00+03	2017-07-24 19:44:00+03
32198	PG0425	2017-08-17 16:55:00+03	2017-08-17 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32199	PG0424	2017-08-17 12:20:00+03	2017-08-17 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32200	PG0424	2017-08-02 12:20:00+03	2017-08-02 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-02 12:23:00+03	2017-08-02 15:04:00+03
32201	PG0425	2017-08-02 16:55:00+03	2017-08-02 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-02 17:01:00+03	2017-08-02 19:41:00+03
32202	PG0425	2017-08-22 16:55:00+03	2017-08-22 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32203	PG0425	2017-09-14 16:55:00+03	2017-09-14 19:35:00+03	SGC	VKT	Cancelled	CN1	\N	\N
32204	PG0425	2017-09-10 16:55:00+03	2017-09-10 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32205	PG0424	2017-09-10 12:20:00+03	2017-09-10 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32206	PG0424	2017-08-15 12:20:00+03	2017-08-15 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-15 12:21:00+03	2017-08-15 15:02:00+03
32207	PG0425	2017-08-15 16:55:00+03	2017-08-15 19:35:00+03	SGC	VKT	Departed	CN1	2017-08-15 16:57:00+03	\N
32208	PG0425	2017-08-16 16:55:00+03	2017-08-16 19:35:00+03	SGC	VKT	On Time	CN1	\N	\N
32209	PG0424	2017-08-16 12:20:00+03	2017-08-16 15:00:00+03	SGC	VKT	On Time	CN1	\N	\N
32210	PG0424	2017-09-13 12:20:00+03	2017-09-13 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32211	PG0425	2017-09-13 16:55:00+03	2017-09-13 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32212	PG0424	2017-09-09 12:20:00+03	2017-09-09 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32213	PG0425	2017-09-09 16:55:00+03	2017-09-09 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32214	PG0425	2017-07-26 16:55:00+03	2017-07-26 19:35:00+03	SGC	VKT	Arrived	CN1	2017-07-26 20:47:00+03	2017-07-26 23:27:00+03
32215	PG0424	2017-08-22 12:20:00+03	2017-08-22 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32216	PG0425	2017-08-09 16:55:00+03	2017-08-09 19:35:00+03	SGC	VKT	Arrived	CN1	2017-08-09 16:59:00+03	2017-08-09 19:40:00+03
32217	PG0424	2017-08-09 12:20:00+03	2017-08-09 15:00:00+03	SGC	VKT	Arrived	CN1	2017-08-09 12:21:00+03	2017-08-09 15:03:00+03
32218	PG0424	2017-07-26 12:20:00+03	2017-07-26 15:00:00+03	SGC	VKT	Arrived	CN1	2017-07-26 12:24:00+03	2017-07-26 15:05:00+03
32219	PG0424	2017-08-29 12:20:00+03	2017-08-29 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32220	PG0425	2017-08-29 16:55:00+03	2017-08-29 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32221	PG0424	2017-08-27 12:20:00+03	2017-08-27 15:00:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32222	PG0425	2017-08-27 16:55:00+03	2017-08-27 19:35:00+03	SGC	VKT	Scheduled	CN1	\N	\N
32223	PG0604	2017-09-03 09:35:00+03	2017-09-03 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32224	PG0604	2017-07-20 09:35:00+03	2017-07-20 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-20 09:39:00+03	2017-07-20 12:39:00+03
32225	PG0604	2017-08-20 09:35:00+03	2017-08-20 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32226	PG0604	2017-08-08 09:35:00+03	2017-08-08 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-08 09:38:00+03	2017-08-08 12:39:00+03
32227	PG0604	2017-07-21 09:35:00+03	2017-07-21 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-21 09:38:00+03	2017-07-21 12:36:00+03
32228	PG0604	2017-07-26 09:35:00+03	2017-07-26 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-26 09:36:00+03	2017-07-26 12:36:00+03
32229	PG0604	2017-07-16 09:35:00+03	2017-07-16 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-16 09:37:00+03	2017-07-16 12:34:00+03
32230	PG0604	2017-08-18 09:35:00+03	2017-08-18 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32231	PG0604	2017-07-28 09:35:00+03	2017-07-28 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-28 09:39:00+03	2017-07-28 12:41:00+03
32232	PG0604	2017-08-25 09:35:00+03	2017-08-25 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32233	PG0604	2017-07-30 09:35:00+03	2017-07-30 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-30 09:42:00+03	2017-07-30 12:39:00+03
32234	PG0604	2017-07-18 09:35:00+03	2017-07-18 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-18 09:36:00+03	2017-07-18 12:36:00+03
32235	PG0604	2017-08-01 09:35:00+03	2017-08-01 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-01 09:40:00+03	2017-08-01 12:39:00+03
32236	PG0604	2017-08-13 09:35:00+03	2017-08-13 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-13 09:36:00+03	2017-08-13 12:36:00+03
32237	PG0604	2017-07-19 09:35:00+03	2017-07-19 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-19 09:36:00+03	2017-07-19 12:35:00+03
32238	PG0604	2017-08-21 09:35:00+03	2017-08-21 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32239	PG0604	2017-09-02 09:35:00+03	2017-09-02 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32240	PG0604	2017-09-12 09:35:00+03	2017-09-12 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32241	PG0604	2017-07-22 09:35:00+03	2017-07-22 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-22 09:38:00+03	2017-07-22 12:36:00+03
32242	PG0604	2017-09-04 09:35:00+03	2017-09-04 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32243	PG0604	2017-08-26 09:35:00+03	2017-08-26 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32244	PG0604	2017-08-04 09:35:00+03	2017-08-04 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-04 09:38:00+03	2017-08-04 12:40:00+03
32245	PG0604	2017-08-29 09:35:00+03	2017-08-29 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32246	PG0604	2017-07-25 09:35:00+03	2017-07-25 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-25 09:40:00+03	2017-07-25 12:40:00+03
32247	PG0604	2017-08-16 09:35:00+03	2017-08-16 12:35:00+03	SGC	IKT	Delayed	CR2	\N	\N
32248	PG0604	2017-08-07 09:35:00+03	2017-08-07 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-07 09:41:00+03	2017-08-07 12:41:00+03
32249	PG0604	2017-08-27 09:35:00+03	2017-08-27 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32250	PG0604	2017-08-15 09:35:00+03	2017-08-15 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-15 09:38:00+03	2017-08-15 12:39:00+03
32251	PG0604	2017-07-29 09:35:00+03	2017-07-29 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-29 09:36:00+03	2017-07-29 12:38:00+03
32252	PG0604	2017-09-05 09:35:00+03	2017-09-05 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32253	PG0604	2017-09-07 09:35:00+03	2017-09-07 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32254	PG0604	2017-07-17 09:35:00+03	2017-07-17 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-17 09:39:00+03	2017-07-17 12:40:00+03
32255	PG0604	2017-09-06 09:35:00+03	2017-09-06 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32256	PG0604	2017-08-11 09:35:00+03	2017-08-11 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-11 09:39:00+03	2017-08-11 12:42:00+03
32257	PG0604	2017-07-31 09:35:00+03	2017-07-31 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-31 09:39:00+03	2017-07-31 12:43:00+03
32258	PG0604	2017-09-11 09:35:00+03	2017-09-11 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32259	PG0604	2017-09-01 09:35:00+03	2017-09-01 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32260	PG0604	2017-08-19 09:35:00+03	2017-08-19 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32261	PG0604	2017-08-12 09:35:00+03	2017-08-12 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-12 09:37:00+03	2017-08-12 12:40:00+03
32262	PG0604	2017-08-10 09:35:00+03	2017-08-10 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-10 09:41:00+03	2017-08-10 12:40:00+03
32263	PG0604	2017-08-05 09:35:00+03	2017-08-05 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-05 09:39:00+03	2017-08-05 12:39:00+03
32264	PG0604	2017-08-09 09:35:00+03	2017-08-09 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-09 09:39:00+03	2017-08-09 12:42:00+03
32265	PG0604	2017-08-31 09:35:00+03	2017-08-31 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32266	PG0604	2017-08-24 09:35:00+03	2017-08-24 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32267	PG0604	2017-08-23 09:35:00+03	2017-08-23 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32268	PG0604	2017-08-17 09:35:00+03	2017-08-17 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32269	PG0604	2017-08-02 09:35:00+03	2017-08-02 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-02 09:41:00+03	2017-08-02 12:41:00+03
32270	PG0604	2017-09-10 09:35:00+03	2017-09-10 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32271	PG0604	2017-08-03 09:35:00+03	2017-08-03 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-03 09:39:00+03	2017-08-03 12:43:00+03
32272	PG0604	2017-09-14 09:35:00+03	2017-09-14 12:35:00+03	SGC	IKT	Cancelled	CR2	\N	\N
32273	PG0604	2017-08-14 09:35:00+03	2017-08-14 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-14 09:36:00+03	2017-08-14 12:35:00+03
32274	PG0604	2017-07-27 09:35:00+03	2017-07-27 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-27 09:37:00+03	2017-07-27 12:34:00+03
32275	PG0604	2017-08-30 09:35:00+03	2017-08-30 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32276	PG0604	2017-09-08 09:35:00+03	2017-09-08 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32277	PG0604	2017-08-22 09:35:00+03	2017-08-22 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32278	PG0604	2017-07-24 09:35:00+03	2017-07-24 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-24 09:40:00+03	2017-07-24 12:39:00+03
32279	PG0604	2017-07-23 09:35:00+03	2017-07-23 12:35:00+03	SGC	IKT	Arrived	CR2	2017-07-23 09:37:00+03	2017-07-23 12:39:00+03
32280	PG0604	2017-09-09 09:35:00+03	2017-09-09 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32281	PG0604	2017-08-06 09:35:00+03	2017-08-06 12:35:00+03	SGC	IKT	Arrived	CR2	2017-08-06 09:37:00+03	2017-08-06 12:38:00+03
32282	PG0604	2017-09-13 09:35:00+03	2017-09-13 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32283	PG0604	2017-08-28 09:35:00+03	2017-08-28 12:35:00+03	SGC	IKT	Scheduled	CR2	\N	\N
32284	PG0614	2017-08-16 16:50:00+03	2017-08-16 20:20:00+03	SGC	URS	On Time	CR2	\N	\N
32285	PG0614	2017-07-26 16:50:00+03	2017-07-26 20:20:00+03	SGC	URS	Arrived	CR2	2017-07-26 16:50:00+03	2017-07-26 20:20:00+03
32286	PG0614	2017-08-30 16:50:00+03	2017-08-30 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32287	PG0614	2017-07-22 16:50:00+03	2017-07-22 20:20:00+03	SGC	URS	Arrived	CR2	2017-07-22 16:54:00+03	2017-07-22 20:24:00+03
32288	PG0614	2017-07-29 16:50:00+03	2017-07-29 20:20:00+03	SGC	URS	Arrived	CR2	2017-07-29 20:12:00+03	2017-07-29 23:47:00+03
32289	PG0614	2017-08-12 16:50:00+03	2017-08-12 20:20:00+03	SGC	URS	Arrived	CR2	2017-08-12 16:52:00+03	2017-08-12 20:22:00+03
32290	PG0614	2017-08-19 16:50:00+03	2017-08-19 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32291	PG0614	2017-09-06 16:50:00+03	2017-09-06 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32292	PG0614	2017-07-19 16:50:00+03	2017-07-19 20:20:00+03	SGC	URS	Arrived	CR2	2017-07-19 16:52:00+03	2017-07-19 20:22:00+03
32293	PG0614	2017-08-09 16:50:00+03	2017-08-09 20:20:00+03	SGC	URS	Arrived	CR2	2017-08-09 16:52:00+03	2017-08-09 20:23:00+03
32294	PG0614	2017-08-26 16:50:00+03	2017-08-26 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32295	PG0614	2017-08-02 16:50:00+03	2017-08-02 20:20:00+03	SGC	URS	Arrived	CR2	2017-08-02 20:33:00+03	2017-08-03 00:05:00+03
32296	PG0614	2017-09-13 16:50:00+03	2017-09-13 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32297	PG0614	2017-09-02 16:50:00+03	2017-09-02 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32298	PG0614	2017-08-23 16:50:00+03	2017-08-23 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32299	PG0614	2017-08-05 16:50:00+03	2017-08-05 20:20:00+03	SGC	URS	Arrived	CR2	2017-08-05 16:52:00+03	2017-08-05 20:19:00+03
32300	PG0614	2017-09-09 16:50:00+03	2017-09-09 20:20:00+03	SGC	URS	Scheduled	CR2	\N	\N
32301	PG0068	2017-08-09 11:20:00+03	2017-08-09 15:00:00+03	SGC	HTA	Arrived	CR2	2017-08-09 11:22:00+03	2017-08-09 15:02:00+03
32302	PG0068	2017-08-12 11:20:00+03	2017-08-12 15:00:00+03	SGC	HTA	Arrived	CR2	2017-08-12 11:22:00+03	2017-08-12 15:02:00+03
32303	PG0068	2017-08-16 11:20:00+03	2017-08-16 15:00:00+03	SGC	HTA	On Time	CR2	\N	\N
32304	PG0068	2017-07-29 11:20:00+03	2017-07-29 15:00:00+03	SGC	HTA	Arrived	CR2	2017-07-29 11:24:00+03	2017-07-29 15:08:00+03
32305	PG0068	2017-07-26 11:20:00+03	2017-07-26 15:00:00+03	SGC	HTA	Arrived	CR2	2017-07-26 11:22:00+03	2017-07-26 15:03:00+03
32306	PG0068	2017-09-13 11:20:00+03	2017-09-13 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32307	PG0068	2017-09-06 11:20:00+03	2017-09-06 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32308	PG0068	2017-08-30 11:20:00+03	2017-08-30 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32309	PG0068	2017-08-23 11:20:00+03	2017-08-23 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32310	PG0068	2017-09-09 11:20:00+03	2017-09-09 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32311	PG0068	2017-08-26 11:20:00+03	2017-08-26 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32312	PG0068	2017-08-19 11:20:00+03	2017-08-19 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32313	PG0068	2017-08-05 11:20:00+03	2017-08-05 15:00:00+03	SGC	HTA	Arrived	CR2	2017-08-05 11:20:00+03	2017-08-05 14:58:00+03
32314	PG0068	2017-07-19 11:20:00+03	2017-07-19 15:00:00+03	SGC	HTA	Arrived	CR2	2017-07-19 11:20:00+03	2017-07-19 14:56:00+03
32315	PG0068	2017-08-02 11:20:00+03	2017-08-02 15:00:00+03	SGC	HTA	Arrived	CR2	2017-08-02 11:22:00+03	2017-08-02 15:04:00+03
32316	PG0068	2017-07-22 11:20:00+03	2017-07-22 15:00:00+03	SGC	HTA	Arrived	CR2	2017-07-22 11:23:00+03	2017-07-22 15:03:00+03
32317	PG0068	2017-09-02 11:20:00+03	2017-09-02 15:00:00+03	SGC	HTA	Scheduled	CR2	\N	\N
32318	PG0411	2017-09-03 13:55:00+03	2017-09-03 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32319	PG0411	2017-09-08 13:55:00+03	2017-09-08 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32320	PG0411	2017-08-07 13:55:00+03	2017-08-07 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-07 13:56:00+03	2017-08-07 16:11:00+03
32321	PG0411	2017-08-29 13:55:00+03	2017-08-29 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32322	PG0411	2017-08-05 13:55:00+03	2017-08-05 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-05 14:00:00+03	2017-08-05 16:15:00+03
32323	PG0411	2017-08-14 13:55:00+03	2017-08-14 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-14 14:00:00+03	2017-08-14 16:16:00+03
32324	PG0411	2017-08-06 13:55:00+03	2017-08-06 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-06 13:58:00+03	2017-08-06 16:12:00+03
32325	PG0411	2017-08-21 13:55:00+03	2017-08-21 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32326	PG0411	2017-08-03 13:55:00+03	2017-08-03 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-03 13:59:00+03	2017-08-03 16:14:00+03
32327	PG0411	2017-09-04 13:55:00+03	2017-09-04 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32328	PG0411	2017-07-17 13:55:00+03	2017-07-17 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-17 13:59:00+03	2017-07-17 16:14:00+03
32329	PG0411	2017-09-01 13:55:00+03	2017-09-01 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32330	PG0411	2017-09-02 13:55:00+03	2017-09-02 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32331	PG0411	2017-09-07 13:55:00+03	2017-09-07 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32332	PG0411	2017-08-01 13:55:00+03	2017-08-01 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-01 14:00:00+03	2017-08-01 16:13:00+03
32333	PG0411	2017-07-26 13:55:00+03	2017-07-26 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-26 13:56:00+03	2017-07-26 16:11:00+03
32334	PG0411	2017-09-05 13:55:00+03	2017-09-05 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32335	PG0411	2017-08-20 13:55:00+03	2017-08-20 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32336	PG0411	2017-08-23 13:55:00+03	2017-08-23 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32337	PG0411	2017-08-13 13:55:00+03	2017-08-13 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-13 13:57:00+03	2017-08-13 16:10:00+03
32338	PG0411	2017-08-02 13:55:00+03	2017-08-02 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-02 13:58:00+03	2017-08-02 16:13:00+03
32339	PG0411	2017-09-09 13:55:00+03	2017-09-09 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32340	PG0411	2017-08-16 13:55:00+03	2017-08-16 16:10:00+03	KLF	LED	On Time	CN1	\N	\N
32341	PG0411	2017-08-22 13:55:00+03	2017-08-22 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32342	PG0411	2017-07-22 13:55:00+03	2017-07-22 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-22 13:58:00+03	2017-07-22 16:12:00+03
32343	PG0411	2017-07-18 13:55:00+03	2017-07-18 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-18 13:59:00+03	2017-07-18 16:13:00+03
32344	PG0411	2017-08-17 13:55:00+03	2017-08-17 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32345	PG0411	2017-09-12 13:55:00+03	2017-09-12 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32346	PG0411	2017-07-25 13:55:00+03	2017-07-25 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-25 13:57:00+03	2017-07-25 16:13:00+03
32347	PG0411	2017-08-04 13:55:00+03	2017-08-04 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-04 13:57:00+03	2017-08-04 16:11:00+03
32348	PG0411	2017-09-14 13:55:00+03	2017-09-14 16:10:00+03	KLF	LED	Cancelled	CN1	\N	\N
32349	PG0411	2017-08-09 13:55:00+03	2017-08-09 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-09 13:57:00+03	2017-08-09 16:13:00+03
32350	PG0411	2017-07-31 13:55:00+03	2017-07-31 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-31 17:24:00+03	2017-07-31 19:41:00+03
32351	PG0411	2017-08-26 13:55:00+03	2017-08-26 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32352	PG0411	2017-08-25 13:55:00+03	2017-08-25 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32353	PG0411	2017-07-29 13:55:00+03	2017-07-29 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-29 14:01:00+03	2017-07-29 16:18:00+03
32354	PG0411	2017-07-24 13:55:00+03	2017-07-24 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-24 13:57:00+03	2017-07-24 16:11:00+03
32355	PG0411	2017-07-27 13:55:00+03	2017-07-27 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-27 13:56:00+03	2017-07-27 16:13:00+03
32356	PG0411	2017-08-30 13:55:00+03	2017-08-30 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32357	PG0411	2017-08-24 13:55:00+03	2017-08-24 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32358	PG0411	2017-09-06 13:55:00+03	2017-09-06 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32359	PG0411	2017-07-30 13:55:00+03	2017-07-30 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-30 13:56:00+03	2017-07-30 16:11:00+03
32360	PG0411	2017-08-08 13:55:00+03	2017-08-08 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-08 13:59:00+03	2017-08-08 16:14:00+03
32361	PG0411	2017-08-28 13:55:00+03	2017-08-28 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32362	PG0411	2017-09-10 13:55:00+03	2017-09-10 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32363	PG0411	2017-09-11 13:55:00+03	2017-09-11 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32364	PG0411	2017-08-31 13:55:00+03	2017-08-31 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32365	PG0411	2017-07-20 13:55:00+03	2017-07-20 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-20 14:00:00+03	2017-07-20 16:14:00+03
32366	PG0411	2017-09-13 13:55:00+03	2017-09-13 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32367	PG0411	2017-08-12 13:55:00+03	2017-08-12 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-12 13:58:00+03	2017-08-12 16:15:00+03
32368	PG0411	2017-07-19 13:55:00+03	2017-07-19 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-19 17:02:00+03	2017-07-19 19:17:00+03
32369	PG0411	2017-08-18 13:55:00+03	2017-08-18 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32370	PG0411	2017-07-28 13:55:00+03	2017-07-28 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-28 13:57:00+03	2017-07-28 16:13:00+03
32371	PG0411	2017-08-15 13:55:00+03	2017-08-15 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-15 13:58:00+03	2017-08-15 16:13:00+03
32372	PG0411	2017-07-21 13:55:00+03	2017-07-21 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-21 13:56:00+03	2017-07-21 16:11:00+03
32373	PG0411	2017-08-27 13:55:00+03	2017-08-27 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32374	PG0411	2017-07-16 13:55:00+03	2017-07-16 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-16 13:57:00+03	2017-07-16 16:13:00+03
32375	PG0411	2017-08-10 13:55:00+03	2017-08-10 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-10 13:56:00+03	2017-08-10 16:08:00+03
32376	PG0411	2017-08-19 13:55:00+03	2017-08-19 16:10:00+03	KLF	LED	Scheduled	CN1	\N	\N
32377	PG0411	2017-07-23 13:55:00+03	2017-07-23 16:10:00+03	KLF	LED	Arrived	CN1	2017-07-23 14:02:00+03	2017-07-23 16:18:00+03
32378	PG0411	2017-08-11 13:55:00+03	2017-08-11 16:10:00+03	KLF	LED	Arrived	CN1	2017-08-11 13:57:00+03	2017-08-11 16:13:00+03
32379	PG0048	2017-08-21 09:45:00+03	2017-08-21 13:40:00+03	KLF	OVB	Scheduled	SU9	\N	\N
32380	PG0048	2017-07-24 09:45:00+03	2017-07-24 13:40:00+03	KLF	OVB	Arrived	SU9	2017-07-24 09:47:00+03	2017-07-24 13:46:00+03
32381	PG0048	2017-09-04 09:45:00+03	2017-09-04 13:40:00+03	KLF	OVB	Scheduled	SU9	\N	\N
32382	PG0048	2017-08-07 09:45:00+03	2017-08-07 13:40:00+03	KLF	OVB	Arrived	SU9	2017-08-07 13:24:00+03	2017-08-07 17:22:00+03
32383	PG0048	2017-07-31 09:45:00+03	2017-07-31 13:40:00+03	KLF	OVB	Arrived	SU9	2017-07-31 09:49:00+03	2017-07-31 13:44:00+03
32384	PG0048	2017-07-17 09:45:00+03	2017-07-17 13:40:00+03	KLF	OVB	Arrived	SU9	2017-07-17 09:46:00+03	2017-07-17 13:42:00+03
32385	PG0048	2017-08-28 09:45:00+03	2017-08-28 13:40:00+03	KLF	OVB	Scheduled	SU9	\N	\N
32386	PG0048	2017-08-14 09:45:00+03	2017-08-14 13:40:00+03	KLF	OVB	Arrived	SU9	2017-08-14 13:27:00+03	2017-08-14 17:25:00+03
32387	PG0048	2017-09-11 09:45:00+03	2017-09-11 13:40:00+03	KLF	OVB	Cancelled	SU9	\N	\N
32388	PG0294	2017-07-27 12:05:00+03	2017-07-27 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-27 12:08:00+03	2017-07-27 14:44:00+03
32389	PG0294	2017-08-05 12:05:00+03	2017-08-05 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-05 12:07:00+03	2017-08-05 14:46:00+03
32390	PG0294	2017-08-01 12:05:00+03	2017-08-01 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-01 12:07:00+03	2017-08-01 14:48:00+03
32391	PG0294	2017-07-25 12:05:00+03	2017-07-25 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-25 12:08:00+03	2017-07-25 14:47:00+03
32392	PG0294	2017-09-07 12:05:00+03	2017-09-07 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32393	PG0294	2017-08-24 12:05:00+03	2017-08-24 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32394	PG0294	2017-07-20 12:05:00+03	2017-07-20 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-20 12:08:00+03	2017-07-20 14:47:00+03
32395	PG0294	2017-09-02 12:05:00+03	2017-09-02 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32396	PG0294	2017-09-12 12:05:00+03	2017-09-12 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32397	PG0294	2017-08-29 12:05:00+03	2017-08-29 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32398	PG0294	2017-07-22 12:05:00+03	2017-07-22 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-22 12:11:00+03	2017-07-22 14:52:00+03
32399	PG0294	2017-08-17 12:05:00+03	2017-08-17 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32400	PG0294	2017-09-09 12:05:00+03	2017-09-09 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32401	PG0294	2017-08-22 12:05:00+03	2017-08-22 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32402	PG0294	2017-08-15 12:05:00+03	2017-08-15 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-15 12:09:00+03	2017-08-15 14:48:00+03
32403	PG0294	2017-08-12 12:05:00+03	2017-08-12 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-12 12:05:00+03	2017-08-12 14:45:00+03
32404	PG0294	2017-08-10 12:05:00+03	2017-08-10 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-10 12:05:00+03	2017-08-10 14:48:00+03
32405	PG0294	2017-08-08 12:05:00+03	2017-08-08 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-08 12:08:00+03	2017-08-08 14:50:00+03
32406	PG0294	2017-08-19 12:05:00+03	2017-08-19 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32407	PG0294	2017-08-31 12:05:00+03	2017-08-31 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32408	PG0294	2017-09-14 12:05:00+03	2017-09-14 14:45:00+03	KLF	PES	Cancelled	CN1	\N	\N
32409	PG0294	2017-07-29 12:05:00+03	2017-07-29 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-29 12:06:00+03	2017-07-29 14:46:00+03
32410	PG0294	2017-08-03 12:05:00+03	2017-08-03 14:45:00+03	KLF	PES	Arrived	CN1	2017-08-03 12:07:00+03	2017-08-03 14:45:00+03
32411	PG0294	2017-08-26 12:05:00+03	2017-08-26 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32412	PG0294	2017-07-18 12:05:00+03	2017-07-18 14:45:00+03	KLF	PES	Arrived	CN1	2017-07-18 12:05:00+03	2017-07-18 14:46:00+03
32413	PG0294	2017-09-05 12:05:00+03	2017-09-05 14:45:00+03	KLF	PES	Scheduled	CN1	\N	\N
32414	PG0346	2017-08-17 13:45:00+03	2017-08-17 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32415	PG0346	2017-07-20 13:45:00+03	2017-07-20 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-20 13:49:00+03	2017-07-20 15:31:00+03
32416	PG0346	2017-08-05 13:45:00+03	2017-08-05 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-05 13:50:00+03	2017-08-05 15:30:00+03
32417	PG0346	2017-07-18 13:45:00+03	2017-07-18 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-18 13:49:00+03	2017-07-18 15:29:00+03
32418	PG0346	2017-08-26 13:45:00+03	2017-08-26 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32419	PG0346	2017-08-08 13:45:00+03	2017-08-08 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-08 13:49:00+03	2017-08-08 15:30:00+03
32420	PG0346	2017-09-07 13:45:00+03	2017-09-07 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32421	PG0346	2017-09-02 13:45:00+03	2017-09-02 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32422	PG0346	2017-09-05 13:45:00+03	2017-09-05 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32423	PG0346	2017-08-01 13:45:00+03	2017-08-01 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-01 13:50:00+03	2017-08-01 15:30:00+03
32424	PG0346	2017-08-10 13:45:00+03	2017-08-10 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-10 13:47:00+03	2017-08-10 15:26:00+03
32425	PG0346	2017-08-31 13:45:00+03	2017-08-31 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32426	PG0346	2017-07-29 13:45:00+03	2017-07-29 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-29 13:49:00+03	2017-07-29 15:29:00+03
32427	PG0346	2017-09-09 13:45:00+03	2017-09-09 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32428	PG0346	2017-08-19 13:45:00+03	2017-08-19 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32429	PG0346	2017-08-15 13:45:00+03	2017-08-15 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-15 13:49:00+03	2017-08-15 15:29:00+03
32430	PG0346	2017-07-27 13:45:00+03	2017-07-27 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-27 13:49:00+03	2017-07-27 15:30:00+03
32431	PG0346	2017-08-03 13:45:00+03	2017-08-03 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-03 13:47:00+03	2017-08-03 15:27:00+03
32432	PG0346	2017-07-25 13:45:00+03	2017-07-25 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-25 13:51:00+03	2017-07-25 15:32:00+03
32433	PG0346	2017-08-29 13:45:00+03	2017-08-29 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32434	PG0346	2017-08-12 13:45:00+03	2017-08-12 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-08-12 13:50:00+03	2017-08-12 15:28:00+03
32435	PG0346	2017-09-12 13:45:00+03	2017-09-12 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32436	PG0346	2017-09-14 13:45:00+03	2017-09-14 15:25:00+03	KLF	GOJ	Cancelled	CN1	\N	\N
32437	PG0346	2017-08-22 13:45:00+03	2017-08-22 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32438	PG0346	2017-07-22 13:45:00+03	2017-07-22 15:25:00+03	KLF	GOJ	Arrived	CN1	2017-07-22 13:48:00+03	2017-07-22 15:27:00+03
32439	PG0346	2017-08-24 13:45:00+03	2017-08-24 15:25:00+03	KLF	GOJ	Scheduled	CN1	\N	\N
32440	PG0219	2017-08-02 12:30:00+03	2017-08-02 17:25:00+03	HTA	UFA	Arrived	319	2017-08-02 12:31:00+03	2017-08-02 17:30:00+03
32441	PG0219	2017-09-13 12:30:00+03	2017-09-13 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32442	PG0219	2017-07-26 12:30:00+03	2017-07-26 17:25:00+03	HTA	UFA	Arrived	319	2017-07-26 15:45:00+03	2017-07-26 20:36:00+03
32443	PG0219	2017-09-03 12:30:00+03	2017-09-03 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32444	PG0219	2017-09-06 12:30:00+03	2017-09-06 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32445	PG0219	2017-08-16 12:30:00+03	2017-08-16 17:25:00+03	HTA	UFA	On Time	319	\N	\N
32446	PG0219	2017-08-30 12:30:00+03	2017-08-30 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32447	PG0219	2017-08-09 12:30:00+03	2017-08-09 17:25:00+03	HTA	UFA	Arrived	319	2017-08-09 12:36:00+03	2017-08-09 17:31:00+03
32448	PG0219	2017-07-30 12:30:00+03	2017-07-30 17:25:00+03	HTA	UFA	Arrived	319	2017-07-30 12:32:00+03	2017-07-30 17:27:00+03
32449	PG0219	2017-07-16 12:30:00+03	2017-07-16 17:25:00+03	HTA	UFA	Arrived	319	2017-07-16 12:33:00+03	2017-07-16 17:29:00+03
32450	PG0219	2017-09-10 12:30:00+03	2017-09-10 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32451	PG0219	2017-07-23 12:30:00+03	2017-07-23 17:25:00+03	HTA	UFA	Arrived	319	2017-07-23 12:33:00+03	2017-07-23 17:30:00+03
32452	PG0219	2017-08-06 12:30:00+03	2017-08-06 17:25:00+03	HTA	UFA	Arrived	319	2017-08-06 12:31:00+03	2017-08-06 17:24:00+03
32453	PG0219	2017-08-23 12:30:00+03	2017-08-23 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32454	PG0219	2017-07-19 12:30:00+03	2017-07-19 17:25:00+03	HTA	UFA	Arrived	319	2017-07-19 12:34:00+03	2017-07-19 17:27:00+03
32455	PG0219	2017-08-13 12:30:00+03	2017-08-13 17:25:00+03	HTA	UFA	Arrived	319	2017-08-13 12:31:00+03	2017-08-13 17:28:00+03
32456	PG0219	2017-08-27 12:30:00+03	2017-08-27 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32457	PG0219	2017-08-20 12:30:00+03	2017-08-20 17:25:00+03	HTA	UFA	Scheduled	319	\N	\N
32458	PG0276	2017-07-19 14:05:00+03	2017-07-19 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-19 14:09:00+03	2017-07-19 17:47:00+03
32459	PG0276	2017-08-12 14:05:00+03	2017-08-12 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-12 14:05:00+03	2017-08-12 17:44:00+03
32460	PG0276	2017-08-04 14:05:00+03	2017-08-04 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-04 14:10:00+03	2017-08-04 17:53:00+03
32461	PG0276	2017-09-02 14:05:00+03	2017-09-02 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32462	PG0276	2017-08-22 14:05:00+03	2017-08-22 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32463	PG0276	2017-07-26 14:05:00+03	2017-07-26 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-26 14:08:00+03	2017-07-26 17:49:00+03
32464	PG0276	2017-08-09 14:05:00+03	2017-08-09 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-09 14:09:00+03	2017-08-09 17:47:00+03
32465	PG0276	2017-07-25 14:05:00+03	2017-07-25 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-25 14:10:00+03	2017-07-25 17:51:00+03
32466	PG0276	2017-08-08 14:05:00+03	2017-08-08 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-08 14:08:00+03	2017-08-08 17:50:00+03
32467	PG0276	2017-08-02 14:05:00+03	2017-08-02 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-02 14:11:00+03	2017-08-02 17:47:00+03
32468	PG0276	2017-09-10 14:05:00+03	2017-09-10 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32469	PG0276	2017-09-13 14:05:00+03	2017-09-13 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32470	PG0276	2017-08-17 14:05:00+03	2017-08-17 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32471	PG0276	2017-08-29 14:05:00+03	2017-08-29 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32472	PG0276	2017-08-30 14:05:00+03	2017-08-30 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32473	PG0276	2017-09-09 14:05:00+03	2017-09-09 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32474	PG0276	2017-07-16 14:05:00+03	2017-07-16 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-16 14:07:00+03	2017-07-16 17:48:00+03
32475	PG0276	2017-08-15 14:05:00+03	2017-08-15 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-15 14:06:00+03	2017-08-15 17:46:00+03
32476	PG0276	2017-08-10 14:05:00+03	2017-08-10 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-10 14:07:00+03	2017-08-10 17:45:00+03
32477	PG0276	2017-09-06 14:05:00+03	2017-09-06 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32478	PG0276	2017-07-27 14:05:00+03	2017-07-27 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-27 14:08:00+03	2017-07-27 17:46:00+03
32479	PG0276	2017-09-04 14:05:00+03	2017-09-04 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32480	PG0276	2017-07-24 14:05:00+03	2017-07-24 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-24 14:06:00+03	2017-07-24 17:44:00+03
32481	PG0276	2017-09-14 14:05:00+03	2017-09-14 17:45:00+03	HTA	NUX	Cancelled	CR2	\N	\N
32482	PG0276	2017-08-03 14:05:00+03	2017-08-03 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-03 14:06:00+03	2017-08-03 17:44:00+03
32483	PG0276	2017-08-18 14:05:00+03	2017-08-18 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32484	PG0276	2017-07-18 14:05:00+03	2017-07-18 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-18 14:09:00+03	2017-07-18 17:49:00+03
32485	PG0276	2017-07-28 14:05:00+03	2017-07-28 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-28 14:07:00+03	2017-07-28 17:50:00+03
32486	PG0276	2017-08-14 14:05:00+03	2017-08-14 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-14 14:11:00+03	2017-08-14 17:54:00+03
32487	PG0276	2017-08-01 14:05:00+03	2017-08-01 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-01 14:06:00+03	2017-08-01 17:45:00+03
32488	PG0276	2017-08-07 14:05:00+03	2017-08-07 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-07 14:08:00+03	2017-08-07 17:48:00+03
32489	PG0276	2017-08-05 14:05:00+03	2017-08-05 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-05 14:06:00+03	2017-08-05 17:46:00+03
32490	PG0276	2017-08-27 14:05:00+03	2017-08-27 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32491	PG0276	2017-08-21 14:05:00+03	2017-08-21 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32492	PG0276	2017-07-20 14:05:00+03	2017-07-20 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-20 14:08:00+03	2017-07-20 17:49:00+03
32493	PG0276	2017-08-24 14:05:00+03	2017-08-24 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32494	PG0276	2017-07-23 14:05:00+03	2017-07-23 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-23 14:07:00+03	2017-07-23 17:51:00+03
32495	PG0276	2017-09-11 14:05:00+03	2017-09-11 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32496	PG0276	2017-09-08 14:05:00+03	2017-09-08 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32497	PG0276	2017-08-06 14:05:00+03	2017-08-06 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-06 14:07:00+03	2017-08-06 17:47:00+03
32498	PG0276	2017-08-11 14:05:00+03	2017-08-11 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-11 14:07:00+03	2017-08-11 17:45:00+03
32499	PG0276	2017-08-25 14:05:00+03	2017-08-25 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32500	PG0276	2017-09-05 14:05:00+03	2017-09-05 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32501	PG0276	2017-07-29 14:05:00+03	2017-07-29 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-29 14:06:00+03	2017-07-29 17:44:00+03
32502	PG0276	2017-08-31 14:05:00+03	2017-08-31 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32503	PG0276	2017-09-03 14:05:00+03	2017-09-03 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32504	PG0276	2017-08-26 14:05:00+03	2017-08-26 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32505	PG0276	2017-08-23 14:05:00+03	2017-08-23 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32506	PG0276	2017-09-01 14:05:00+03	2017-09-01 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32507	PG0276	2017-08-19 14:05:00+03	2017-08-19 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32508	PG0276	2017-08-13 14:05:00+03	2017-08-13 17:45:00+03	HTA	NUX	Arrived	CR2	2017-08-13 14:09:00+03	2017-08-13 17:44:00+03
32509	PG0276	2017-08-28 14:05:00+03	2017-08-28 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32510	PG0276	2017-07-31 14:05:00+03	2017-07-31 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-31 14:11:00+03	2017-07-31 17:50:00+03
32511	PG0276	2017-07-22 14:05:00+03	2017-07-22 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-22 14:07:00+03	2017-07-22 17:45:00+03
32512	PG0276	2017-07-17 14:05:00+03	2017-07-17 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-17 17:13:00+03	2017-07-17 20:53:00+03
32513	PG0276	2017-09-12 14:05:00+03	2017-09-12 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32514	PG0276	2017-07-21 14:05:00+03	2017-07-21 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-21 14:06:00+03	2017-07-21 17:46:00+03
32515	PG0276	2017-07-30 14:05:00+03	2017-07-30 17:45:00+03	HTA	NUX	Arrived	CR2	2017-07-30 14:08:00+03	2017-07-30 17:51:00+03
32516	PG0276	2017-08-16 14:05:00+03	2017-08-16 17:45:00+03	HTA	NUX	On Time	CR2	\N	\N
32517	PG0276	2017-09-07 14:05:00+03	2017-09-07 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32518	PG0276	2017-08-20 14:05:00+03	2017-08-20 17:45:00+03	HTA	NUX	Scheduled	CR2	\N	\N
32519	PG0069	2017-09-06 05:05:00+03	2017-09-06 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32520	PG0069	2017-09-09 05:05:00+03	2017-09-09 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32521	PG0069	2017-08-19 05:05:00+03	2017-08-19 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32522	PG0069	2017-08-23 05:05:00+03	2017-08-23 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32523	PG0069	2017-08-05 05:05:00+03	2017-08-05 08:45:00+03	HTA	SGC	Arrived	CR2	2017-08-05 05:09:00+03	2017-08-05 08:50:00+03
32524	PG0069	2017-07-29 05:05:00+03	2017-07-29 08:45:00+03	HTA	SGC	Arrived	CR2	2017-07-29 05:09:00+03	2017-07-29 08:50:00+03
32525	PG0069	2017-08-12 05:05:00+03	2017-08-12 08:45:00+03	HTA	SGC	Arrived	CR2	2017-08-12 05:11:00+03	2017-08-12 08:48:00+03
32526	PG0069	2017-07-22 05:05:00+03	2017-07-22 08:45:00+03	HTA	SGC	Arrived	CR2	2017-07-22 05:09:00+03	2017-07-22 08:49:00+03
32527	PG0069	2017-07-19 05:05:00+03	2017-07-19 08:45:00+03	HTA	SGC	Arrived	CR2	2017-07-19 05:08:00+03	2017-07-19 08:47:00+03
32528	PG0069	2017-08-26 05:05:00+03	2017-08-26 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32529	PG0069	2017-09-13 05:05:00+03	2017-09-13 08:45:00+03	HTA	SGC	Cancelled	CR2	\N	\N
32530	PG0069	2017-08-02 05:05:00+03	2017-08-02 08:45:00+03	HTA	SGC	Arrived	CR2	2017-08-02 05:09:00+03	2017-08-02 08:49:00+03
32531	PG0069	2017-08-16 05:05:00+03	2017-08-16 08:45:00+03	HTA	SGC	On Time	CR2	\N	\N
32532	PG0069	2017-09-02 05:05:00+03	2017-09-02 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32533	PG0069	2017-07-26 05:05:00+03	2017-07-26 08:45:00+03	HTA	SGC	Arrived	CR2	2017-07-26 05:10:00+03	2017-07-26 08:51:00+03
32534	PG0069	2017-08-30 05:05:00+03	2017-08-30 08:45:00+03	HTA	SGC	Scheduled	CR2	\N	\N
32535	PG0069	2017-08-09 05:05:00+03	2017-08-09 08:45:00+03	HTA	SGC	Arrived	CR2	2017-08-09 05:07:00+03	2017-08-09 08:48:00+03
32536	PG0371	2017-07-23 14:25:00+03	2017-07-23 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-23 14:30:00+03	2017-07-23 16:56:00+03
32537	PG0371	2017-08-20 14:25:00+03	2017-08-20 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32538	PG0371	2017-08-10 14:25:00+03	2017-08-10 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-10 14:27:00+03	2017-08-10 16:51:00+03
32539	PG0371	2017-07-30 14:25:00+03	2017-07-30 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-30 14:27:00+03	2017-07-30 16:51:00+03
32540	PG0371	2017-08-13 14:25:00+03	2017-08-13 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-13 14:28:00+03	2017-08-13 16:53:00+03
32541	PG0371	2017-07-16 14:25:00+03	2017-07-16 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-16 18:05:00+03	2017-07-16 20:32:00+03
32542	PG0371	2017-07-18 14:25:00+03	2017-07-18 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-18 14:25:00+03	2017-07-18 16:49:00+03
32543	PG0371	2017-09-14 14:25:00+03	2017-09-14 16:50:00+03	KRO	DME	Cancelled	CR2	\N	\N
32544	PG0371	2017-09-12 14:25:00+03	2017-09-12 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32545	PG0371	2017-07-27 14:25:00+03	2017-07-27 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-27 14:29:00+03	2017-07-27 16:50:00+03
32546	PG0371	2017-08-31 14:25:00+03	2017-08-31 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32547	PG0371	2017-08-06 14:25:00+03	2017-08-06 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-06 14:27:00+03	2017-08-06 16:53:00+03
32548	PG0371	2017-08-17 14:25:00+03	2017-08-17 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32549	PG0371	2017-08-15 14:25:00+03	2017-08-15 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-15 14:29:00+03	2017-08-15 16:55:00+03
32550	PG0371	2017-09-10 14:25:00+03	2017-09-10 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32551	PG0371	2017-08-08 14:25:00+03	2017-08-08 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-08 14:26:00+03	2017-08-08 16:52:00+03
32552	PG0371	2017-09-07 14:25:00+03	2017-09-07 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32553	PG0371	2017-08-29 14:25:00+03	2017-08-29 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32554	PG0371	2017-09-03 14:25:00+03	2017-09-03 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32555	PG0371	2017-07-25 14:25:00+03	2017-07-25 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-25 14:27:00+03	2017-07-25 16:52:00+03
32556	PG0371	2017-08-22 14:25:00+03	2017-08-22 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32557	PG0371	2017-08-27 14:25:00+03	2017-08-27 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32558	PG0371	2017-07-20 14:25:00+03	2017-07-20 16:50:00+03	KRO	DME	Arrived	CR2	2017-07-20 14:28:00+03	2017-07-20 16:51:00+03
32559	PG0371	2017-08-03 14:25:00+03	2017-08-03 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-03 14:27:00+03	2017-08-03 16:53:00+03
32560	PG0371	2017-09-05 14:25:00+03	2017-09-05 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32561	PG0371	2017-08-24 14:25:00+03	2017-08-24 16:50:00+03	KRO	DME	Scheduled	CR2	\N	\N
32562	PG0371	2017-08-01 14:25:00+03	2017-08-01 16:50:00+03	KRO	DME	Arrived	CR2	2017-08-01 14:28:00+03	2017-08-01 16:51:00+03
32563	PG0670	2017-09-07 14:25:00+03	2017-09-07 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32564	PG0670	2017-07-17 14:25:00+03	2017-07-17 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-17 14:27:00+03	2017-07-17 16:59:00+03
32565	PG0670	2017-09-03 14:25:00+03	2017-09-03 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32566	PG0670	2017-08-21 14:25:00+03	2017-08-21 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32567	PG0670	2017-07-23 14:25:00+03	2017-07-23 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-23 14:27:00+03	2017-07-23 16:58:00+03
32568	PG0670	2017-07-27 14:25:00+03	2017-07-27 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-27 14:27:00+03	2017-07-27 16:55:00+03
32569	PG0670	2017-08-16 14:25:00+03	2017-08-16 16:55:00+03	KRO	VKO	On Time	CR2	\N	\N
32570	PG0670	2017-08-01 14:25:00+03	2017-08-01 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-01 14:29:00+03	2017-08-01 16:57:00+03
32571	PG0670	2017-08-25 14:25:00+03	2017-08-25 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32572	PG0670	2017-07-26 14:25:00+03	2017-07-26 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-26 14:28:00+03	2017-07-26 16:58:00+03
32573	PG0670	2017-08-11 14:25:00+03	2017-08-11 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-11 14:31:00+03	2017-08-11 17:03:00+03
32574	PG0670	2017-07-18 14:25:00+03	2017-07-18 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-18 14:28:00+03	2017-07-18 16:58:00+03
32575	PG0670	2017-08-03 14:25:00+03	2017-08-03 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-03 14:26:00+03	2017-08-03 16:56:00+03
32576	PG0670	2017-08-05 14:25:00+03	2017-08-05 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-05 14:27:00+03	2017-08-05 16:59:00+03
32577	PG0670	2017-07-29 14:25:00+03	2017-07-29 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-29 14:30:00+03	2017-07-29 17:01:00+03
32578	PG0670	2017-09-12 14:25:00+03	2017-09-12 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32579	PG0670	2017-08-12 14:25:00+03	2017-08-12 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-12 14:28:00+03	2017-08-12 16:59:00+03
32580	PG0670	2017-09-05 14:25:00+03	2017-09-05 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32581	PG0670	2017-08-31 14:25:00+03	2017-08-31 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32582	PG0670	2017-07-22 14:25:00+03	2017-07-22 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-22 14:27:00+03	2017-07-22 16:57:00+03
32583	PG0670	2017-08-07 14:25:00+03	2017-08-07 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-07 14:25:00+03	2017-08-07 16:55:00+03
32584	PG0670	2017-08-27 14:25:00+03	2017-08-27 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32585	PG0670	2017-09-04 14:25:00+03	2017-09-04 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32586	PG0670	2017-08-08 14:25:00+03	2017-08-08 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-08 14:28:00+03	2017-08-08 17:00:00+03
32587	PG0670	2017-08-23 14:25:00+03	2017-08-23 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32588	PG0670	2017-07-24 14:25:00+03	2017-07-24 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-24 14:30:00+03	2017-07-24 17:02:00+03
32589	PG0670	2017-08-28 14:25:00+03	2017-08-28 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32590	PG0670	2017-09-11 14:25:00+03	2017-09-11 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32591	PG0670	2017-07-25 14:25:00+03	2017-07-25 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-25 14:29:00+03	2017-07-25 17:02:00+03
32592	PG0670	2017-08-15 14:25:00+03	2017-08-15 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-15 14:29:00+03	2017-08-15 17:00:00+03
32593	PG0670	2017-09-06 14:25:00+03	2017-09-06 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32594	PG0670	2017-08-24 14:25:00+03	2017-08-24 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32595	PG0670	2017-09-14 14:25:00+03	2017-09-14 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32596	PG0670	2017-09-09 14:25:00+03	2017-09-09 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32597	PG0670	2017-09-10 14:25:00+03	2017-09-10 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32598	PG0670	2017-08-09 14:25:00+03	2017-08-09 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-09 14:27:00+03	2017-08-09 16:58:00+03
32599	PG0670	2017-08-26 14:25:00+03	2017-08-26 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32600	PG0670	2017-08-04 14:25:00+03	2017-08-04 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-04 14:28:00+03	2017-08-04 16:58:00+03
32601	PG0670	2017-08-20 14:25:00+03	2017-08-20 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32602	PG0670	2017-08-17 14:25:00+03	2017-08-17 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32603	PG0670	2017-07-16 14:25:00+03	2017-07-16 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-16 14:25:00+03	2017-07-16 16:54:00+03
32604	PG0670	2017-09-13 14:25:00+03	2017-09-13 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32605	PG0670	2017-07-30 14:25:00+03	2017-07-30 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-30 14:30:00+03	2017-07-30 16:58:00+03
32606	PG0670	2017-08-30 14:25:00+03	2017-08-30 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32607	PG0670	2017-08-29 14:25:00+03	2017-08-29 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32608	PG0670	2017-09-01 14:25:00+03	2017-09-01 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32609	PG0670	2017-08-14 14:25:00+03	2017-08-14 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-14 17:36:00+03	2017-08-14 20:07:00+03
32610	PG0670	2017-07-20 14:25:00+03	2017-07-20 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-20 14:27:00+03	2017-07-20 16:59:00+03
32611	PG0670	2017-08-13 14:25:00+03	2017-08-13 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-13 17:11:00+03	2017-08-13 19:41:00+03
32612	PG0670	2017-07-19 14:25:00+03	2017-07-19 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-19 14:32:00+03	2017-07-19 17:02:00+03
32613	PG0670	2017-08-06 14:25:00+03	2017-08-06 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-06 14:29:00+03	2017-08-06 17:01:00+03
32614	PG0670	2017-07-21 14:25:00+03	2017-07-21 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-21 14:29:00+03	2017-07-21 16:58:00+03
32615	PG0670	2017-07-28 14:25:00+03	2017-07-28 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-28 14:29:00+03	2017-07-28 17:00:00+03
32616	PG0670	2017-09-08 14:25:00+03	2017-09-08 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32617	PG0670	2017-08-10 14:25:00+03	2017-08-10 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-10 14:26:00+03	2017-08-10 16:56:00+03
32618	PG0670	2017-08-02 14:25:00+03	2017-08-02 16:55:00+03	KRO	VKO	Arrived	CR2	2017-08-02 14:26:00+03	2017-08-02 16:56:00+03
32619	PG0670	2017-08-19 14:25:00+03	2017-08-19 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32620	PG0670	2017-08-18 14:25:00+03	2017-08-18 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32621	PG0670	2017-07-31 14:25:00+03	2017-07-31 16:55:00+03	KRO	VKO	Arrived	CR2	2017-07-31 14:31:00+03	2017-07-31 17:01:00+03
32622	PG0670	2017-09-02 14:25:00+03	2017-09-02 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32623	PG0670	2017-08-22 14:25:00+03	2017-08-22 16:55:00+03	KRO	VKO	Scheduled	CR2	\N	\N
32624	PG0668	2017-07-30 18:10:00+03	2017-07-30 20:40:00+03	KRO	SVO	Arrived	CR2	2017-07-30 18:17:00+03	2017-07-30 20:47:00+03
32625	PG0668	2017-08-10 18:10:00+03	2017-08-10 20:40:00+03	KRO	SVO	Arrived	CR2	2017-08-10 18:14:00+03	2017-08-10 20:44:00+03
32626	PG0668	2017-09-03 18:10:00+03	2017-09-03 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32627	PG0668	2017-08-20 18:10:00+03	2017-08-20 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32628	PG0668	2017-07-20 18:10:00+03	2017-07-20 20:40:00+03	KRO	SVO	Arrived	CR2	2017-07-20 18:12:00+03	2017-07-20 20:41:00+03
32629	PG0668	2017-08-03 18:10:00+03	2017-08-03 20:40:00+03	KRO	SVO	Arrived	CR2	2017-08-03 18:13:00+03	2017-08-03 20:42:00+03
32630	PG0668	2017-08-27 18:10:00+03	2017-08-27 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32631	PG0668	2017-08-31 18:10:00+03	2017-08-31 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32632	PG0668	2017-09-14 18:10:00+03	2017-09-14 20:40:00+03	KRO	SVO	Cancelled	CR2	\N	\N
32633	PG0668	2017-09-07 18:10:00+03	2017-09-07 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32634	PG0668	2017-08-13 18:10:00+03	2017-08-13 20:40:00+03	KRO	SVO	Arrived	CR2	2017-08-13 18:11:00+03	2017-08-13 20:39:00+03
32635	PG0668	2017-07-16 18:10:00+03	2017-07-16 20:40:00+03	KRO	SVO	Arrived	CR2	2017-07-16 18:10:00+03	2017-07-16 20:39:00+03
32636	PG0668	2017-07-23 18:10:00+03	2017-07-23 20:40:00+03	KRO	SVO	Arrived	CR2	2017-07-23 18:14:00+03	2017-07-23 20:46:00+03
32637	PG0668	2017-09-10 18:10:00+03	2017-09-10 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32638	PG0668	2017-07-27 18:10:00+03	2017-07-27 20:40:00+03	KRO	SVO	Arrived	CR2	2017-07-27 18:11:00+03	2017-07-27 20:42:00+03
32639	PG0668	2017-08-17 18:10:00+03	2017-08-17 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32640	PG0668	2017-08-06 18:10:00+03	2017-08-06 20:40:00+03	KRO	SVO	Arrived	CR2	2017-08-06 18:12:00+03	2017-08-06 20:43:00+03
32641	PG0668	2017-08-24 18:10:00+03	2017-08-24 20:40:00+03	KRO	SVO	Scheduled	CR2	\N	\N
32642	PG0674	2017-07-31 09:35:00+03	2017-07-31 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-31 09:35:00+03	2017-07-31 12:00:00+03
32643	PG0674	2017-07-17 09:35:00+03	2017-07-17 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-17 09:37:00+03	2017-07-17 12:03:00+03
32644	PG0674	2017-09-07 09:35:00+03	2017-09-07 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32645	PG0674	2017-09-14 09:35:00+03	2017-09-14 12:00:00+03	KRO	KJA	Cancelled	CR2	\N	\N
32646	PG0674	2017-09-03 09:35:00+03	2017-09-03 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32647	PG0674	2017-09-02 09:35:00+03	2017-09-02 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32648	PG0674	2017-08-25 09:35:00+03	2017-08-25 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32649	PG0674	2017-09-06 09:35:00+03	2017-09-06 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32650	PG0674	2017-08-26 09:35:00+03	2017-08-26 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32651	PG0674	2017-09-09 09:35:00+03	2017-09-09 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32652	PG0674	2017-08-15 09:35:00+03	2017-08-15 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-15 09:37:00+03	2017-08-15 12:05:00+03
32653	PG0674	2017-08-31 09:35:00+03	2017-08-31 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32654	PG0674	2017-08-06 09:35:00+03	2017-08-06 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-06 09:38:00+03	2017-08-06 12:04:00+03
32655	PG0674	2017-07-21 09:35:00+03	2017-07-21 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-21 09:37:00+03	2017-07-21 12:04:00+03
32656	PG0674	2017-07-19 09:35:00+03	2017-07-19 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-19 09:41:00+03	2017-07-19 12:06:00+03
32657	PG0674	2017-07-25 09:35:00+03	2017-07-25 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-25 09:41:00+03	2017-07-25 12:05:00+03
32659	PG0674	2017-08-27 09:35:00+03	2017-08-27 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32660	PG0674	2017-08-09 09:35:00+03	2017-08-09 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-09 09:38:00+03	2017-08-09 12:03:00+03
32661	PG0674	2017-08-24 09:35:00+03	2017-08-24 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32662	PG0674	2017-08-29 09:35:00+03	2017-08-29 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32663	PG0674	2017-08-16 09:35:00+03	2017-08-16 12:00:00+03	KRO	KJA	On Time	CR2	\N	\N
32664	PG0674	2017-07-24 09:35:00+03	2017-07-24 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-24 09:39:00+03	2017-07-24 12:05:00+03
32665	PG0674	2017-08-14 09:35:00+03	2017-08-14 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-14 09:39:00+03	2017-08-14 12:02:00+03
32666	PG0674	2017-09-11 09:35:00+03	2017-09-11 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32667	PG0674	2017-09-13 09:35:00+03	2017-09-13 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32668	PG0674	2017-09-01 09:35:00+03	2017-09-01 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32669	PG0674	2017-08-02 09:35:00+03	2017-08-02 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-02 09:40:00+03	2017-08-02 12:07:00+03
32670	PG0674	2017-08-05 09:35:00+03	2017-08-05 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-05 09:40:00+03	2017-08-05 12:04:00+03
32671	PG0674	2017-07-26 09:35:00+03	2017-07-26 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-26 13:10:00+03	2017-07-26 15:33:00+03
32672	PG0674	2017-09-04 09:35:00+03	2017-09-04 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32673	PG0674	2017-08-17 09:35:00+03	2017-08-17 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32674	PG0674	2017-09-08 09:35:00+03	2017-09-08 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32675	PG0674	2017-07-18 09:35:00+03	2017-07-18 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-18 09:38:00+03	2017-07-18 12:05:00+03
32676	PG0674	2017-08-23 09:35:00+03	2017-08-23 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32677	PG0674	2017-08-07 09:35:00+03	2017-08-07 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-07 09:37:00+03	2017-08-07 12:05:00+03
32678	PG0674	2017-09-10 09:35:00+03	2017-09-10 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32679	PG0674	2017-07-27 09:35:00+03	2017-07-27 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-27 09:37:00+03	2017-07-27 12:00:00+03
32680	PG0674	2017-07-23 09:35:00+03	2017-07-23 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-23 09:35:00+03	2017-07-23 12:01:00+03
32681	PG0674	2017-09-05 09:35:00+03	2017-09-05 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32682	PG0674	2017-08-28 09:35:00+03	2017-08-28 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32683	PG0674	2017-08-12 09:35:00+03	2017-08-12 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-12 09:37:00+03	2017-08-12 12:01:00+03
32684	PG0674	2017-07-29 09:35:00+03	2017-07-29 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-29 09:40:00+03	2017-07-29 12:06:00+03
32685	PG0674	2017-08-11 09:35:00+03	2017-08-11 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-11 09:36:00+03	2017-08-11 12:00:00+03
32686	PG0674	2017-08-08 09:35:00+03	2017-08-08 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-08 09:37:00+03	2017-08-08 12:03:00+03
32687	PG0674	2017-08-03 09:35:00+03	2017-08-03 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-03 09:39:00+03	2017-08-03 12:04:00+03
32688	PG0674	2017-08-30 09:35:00+03	2017-08-30 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32689	PG0674	2017-07-30 09:35:00+03	2017-07-30 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-30 13:17:00+03	2017-07-30 15:42:00+03
32690	PG0674	2017-08-01 09:35:00+03	2017-08-01 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-01 09:35:00+03	2017-08-01 12:01:00+03
32691	PG0674	2017-09-12 09:35:00+03	2017-09-12 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32692	PG0674	2017-07-16 09:35:00+03	2017-07-16 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-16 09:38:00+03	2017-07-16 12:02:00+03
32693	PG0674	2017-08-13 09:35:00+03	2017-08-13 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-13 09:37:00+03	2017-08-13 12:01:00+03
32694	PG0674	2017-07-28 09:35:00+03	2017-07-28 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-28 09:40:00+03	2017-07-28 12:09:00+03
32695	PG0674	2017-08-18 09:35:00+03	2017-08-18 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32696	PG0674	2017-08-21 09:35:00+03	2017-08-21 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32697	PG0674	2017-08-22 09:35:00+03	2017-08-22 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32698	PG0674	2017-07-20 09:35:00+03	2017-07-20 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-20 09:40:00+03	2017-07-20 12:04:00+03
32699	PG0674	2017-08-10 09:35:00+03	2017-08-10 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-10 09:37:00+03	2017-08-10 12:03:00+03
32700	PG0674	2017-07-22 09:35:00+03	2017-07-22 12:00:00+03	KRO	KJA	Arrived	CR2	2017-07-22 09:39:00+03	2017-07-22 12:05:00+03
32701	PG0674	2017-08-20 09:35:00+03	2017-08-20 12:00:00+03	KRO	KJA	Scheduled	CR2	\N	\N
32702	PG0674	2017-08-04 09:35:00+03	2017-08-04 12:00:00+03	KRO	KJA	Arrived	CR2	2017-08-04 09:37:00+03	2017-08-04 12:01:00+03
32703	PG0024	2017-09-02 13:30:00+03	2017-09-02 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32704	PG0024	2017-08-12 13:30:00+03	2017-08-12 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-12 13:32:00+03	2017-08-12 15:42:00+03
32705	PG0024	2017-08-19 13:30:00+03	2017-08-19 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32706	PG0024	2017-09-09 13:30:00+03	2017-09-09 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32707	PG0024	2017-08-05 13:30:00+03	2017-08-05 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-05 13:31:00+03	2017-08-05 15:39:00+03
32708	PG0024	2017-09-07 13:30:00+03	2017-09-07 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32709	PG0024	2017-08-24 13:30:00+03	2017-08-24 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32710	PG0024	2017-08-29 13:30:00+03	2017-08-29 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32711	PG0024	2017-08-22 13:30:00+03	2017-08-22 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32712	PG0024	2017-08-08 13:30:00+03	2017-08-08 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-08 13:33:00+03	2017-08-08 15:45:00+03
32713	PG0024	2017-07-18 13:30:00+03	2017-07-18 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-18 13:31:00+03	2017-07-18 15:42:00+03
32714	PG0024	2017-08-15 13:30:00+03	2017-08-15 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-15 13:33:00+03	2017-08-15 15:42:00+03
32715	PG0024	2017-08-03 13:30:00+03	2017-08-03 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-03 13:35:00+03	2017-08-03 15:44:00+03
32716	PG0024	2017-08-26 13:30:00+03	2017-08-26 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32717	PG0024	2017-08-10 13:30:00+03	2017-08-10 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-10 13:33:00+03	2017-08-10 15:43:00+03
32718	PG0024	2017-07-27 13:30:00+03	2017-07-27 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-27 13:34:00+03	2017-07-27 15:45:00+03
32719	PG0024	2017-08-17 13:30:00+03	2017-08-17 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32720	PG0024	2017-09-12 13:30:00+03	2017-09-12 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32721	PG0024	2017-08-31 13:30:00+03	2017-08-31 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32722	PG0024	2017-07-20 13:30:00+03	2017-07-20 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-20 13:33:00+03	2017-07-20 15:42:00+03
32723	PG0024	2017-08-01 13:30:00+03	2017-08-01 15:40:00+03	KRO	OSW	Arrived	CN1	2017-08-01 13:34:00+03	2017-08-01 15:44:00+03
32724	PG0024	2017-09-14 13:30:00+03	2017-09-14 15:40:00+03	KRO	OSW	Cancelled	CN1	\N	\N
32725	PG0024	2017-07-25 13:30:00+03	2017-07-25 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-25 13:35:00+03	2017-07-25 15:46:00+03
32726	PG0024	2017-07-29 13:30:00+03	2017-07-29 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-29 13:33:00+03	2017-07-29 15:44:00+03
32727	PG0024	2017-09-05 13:30:00+03	2017-09-05 15:40:00+03	KRO	OSW	Scheduled	CN1	\N	\N
32728	PG0024	2017-07-22 13:30:00+03	2017-07-22 15:40:00+03	KRO	OSW	Arrived	CN1	2017-07-22 13:35:00+03	2017-07-22 15:44:00+03
32729	PG0367	2017-08-07 07:25:00+03	2017-08-07 10:25:00+03	KRO	EYK	Arrived	CN1	2017-08-07 07:27:00+03	2017-08-07 10:28:00+03
32730	PG0367	2017-09-04 07:25:00+03	2017-09-04 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32731	PG0367	2017-08-31 07:25:00+03	2017-08-31 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32732	PG0367	2017-08-10 07:25:00+03	2017-08-10 10:25:00+03	KRO	EYK	Arrived	CN1	2017-08-10 07:28:00+03	2017-08-10 10:30:00+03
32733	PG0367	2017-08-03 07:25:00+03	2017-08-03 10:25:00+03	KRO	EYK	Arrived	CN1	2017-08-03 07:29:00+03	2017-08-03 10:30:00+03
32734	PG0367	2017-08-28 07:25:00+03	2017-08-28 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32735	PG0367	2017-08-17 07:25:00+03	2017-08-17 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32736	PG0367	2017-09-07 07:25:00+03	2017-09-07 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32737	PG0367	2017-07-31 07:25:00+03	2017-07-31 10:25:00+03	KRO	EYK	Arrived	CN1	2017-07-31 07:27:00+03	2017-07-31 10:22:00+03
32738	PG0367	2017-08-14 07:25:00+03	2017-08-14 10:25:00+03	KRO	EYK	Arrived	CN1	2017-08-14 07:29:00+03	2017-08-14 10:29:00+03
32739	PG0367	2017-09-14 07:25:00+03	2017-09-14 10:25:00+03	KRO	EYK	Cancelled	CN1	\N	\N
32740	PG0367	2017-07-27 07:25:00+03	2017-07-27 10:25:00+03	KRO	EYK	Arrived	CN1	2017-07-27 07:29:00+03	2017-07-27 10:31:00+03
32741	PG0367	2017-08-24 07:25:00+03	2017-08-24 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32742	PG0367	2017-07-20 07:25:00+03	2017-07-20 10:25:00+03	KRO	EYK	Arrived	CN1	2017-07-20 07:29:00+03	2017-07-20 10:27:00+03
32743	PG0367	2017-07-17 07:25:00+03	2017-07-17 10:25:00+03	KRO	EYK	Arrived	CN1	2017-07-17 07:28:00+03	2017-07-17 10:25:00+03
32744	PG0367	2017-08-21 07:25:00+03	2017-08-21 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32745	PG0367	2017-09-11 07:25:00+03	2017-09-11 10:25:00+03	KRO	EYK	Scheduled	CN1	\N	\N
32746	PG0367	2017-07-24 07:25:00+03	2017-07-24 10:25:00+03	KRO	EYK	Arrived	CN1	2017-07-24 07:27:00+03	2017-07-24 10:27:00+03
32747	PG0079	2017-09-07 12:45:00+03	2017-09-07 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32748	PG0080	2017-07-19 11:25:00+03	2017-07-19 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-19 11:27:00+03	2017-07-19 12:52:00+03
32749	PG0079	2017-08-06 12:45:00+03	2017-08-06 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-06 12:47:00+03	2017-08-06 14:13:00+03
32750	PG0080	2017-09-05 11:25:00+03	2017-09-05 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32751	PG0079	2017-09-05 12:45:00+03	2017-09-05 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32752	PG0079	2017-09-01 12:45:00+03	2017-09-01 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32753	PG0080	2017-09-01 11:25:00+03	2017-09-01 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32754	PG0080	2017-08-20 11:25:00+03	2017-08-20 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32755	PG0079	2017-08-20 12:45:00+03	2017-08-20 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32756	PG0080	2017-09-12 11:25:00+03	2017-09-12 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32757	PG0079	2017-09-12 12:45:00+03	2017-09-12 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32758	PG0080	2017-08-08 11:25:00+03	2017-08-08 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-08 14:55:00+03	2017-08-08 16:19:00+03
32759	PG0080	2017-08-12 11:25:00+03	2017-08-12 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-12 11:28:00+03	2017-08-12 12:54:00+03
32760	PG0080	2017-08-04 11:25:00+03	2017-08-04 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-04 11:28:00+03	2017-08-04 12:51:00+03
32761	PG0079	2017-07-22 12:45:00+03	2017-07-22 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-22 12:47:00+03	2017-07-22 14:11:00+03
32762	PG0080	2017-07-22 11:25:00+03	2017-07-22 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-22 11:26:00+03	2017-07-22 12:52:00+03
32763	PG0079	2017-08-08 12:45:00+03	2017-08-08 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-08 12:47:00+03	2017-08-08 14:13:00+03
32764	PG0079	2017-08-04 12:45:00+03	2017-08-04 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-04 12:46:00+03	2017-08-04 14:12:00+03
32765	PG0079	2017-08-28 12:45:00+03	2017-08-28 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32766	PG0080	2017-08-28 11:25:00+03	2017-08-28 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32767	PG0079	2017-08-12 12:45:00+03	2017-08-12 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-12 12:46:00+03	2017-08-12 14:12:00+03
32768	PG0080	2017-07-16 11:25:00+03	2017-07-16 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-16 11:27:00+03	2017-07-16 12:52:00+03
32769	PG0080	2017-08-26 11:25:00+03	2017-08-26 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32770	PG0079	2017-08-26 12:45:00+03	2017-08-26 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32771	PG0079	2017-07-31 12:45:00+03	2017-07-31 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-31 12:51:00+03	2017-07-31 14:16:00+03
32772	PG0080	2017-07-30 11:25:00+03	2017-07-30 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-30 11:32:00+03	2017-07-30 12:57:00+03
32773	PG0080	2017-07-31 11:25:00+03	2017-07-31 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-31 11:30:00+03	2017-07-31 12:54:00+03
32774	PG0079	2017-07-30 12:45:00+03	2017-07-30 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-30 12:49:00+03	2017-07-30 14:13:00+03
32775	PG0079	2017-08-13 12:45:00+03	2017-08-13 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-13 12:50:00+03	2017-08-13 14:15:00+03
32776	PG0080	2017-08-13 11:25:00+03	2017-08-13 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-13 11:29:00+03	2017-08-13 12:53:00+03
32777	PG0080	2017-07-21 11:25:00+03	2017-07-21 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-21 11:28:00+03	2017-07-21 12:53:00+03
32778	PG0079	2017-07-21 12:45:00+03	2017-07-21 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-21 12:47:00+03	2017-07-21 14:12:00+03
32779	PG0080	2017-09-07 11:25:00+03	2017-09-07 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32780	PG0079	2017-09-08 12:45:00+03	2017-09-08 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32781	PG0080	2017-09-08 11:25:00+03	2017-09-08 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32782	PG0079	2017-08-24 12:45:00+03	2017-08-24 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32783	PG0080	2017-08-24 11:25:00+03	2017-08-24 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32784	PG0080	2017-07-17 11:25:00+03	2017-07-17 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-17 11:27:00+03	2017-07-17 12:51:00+03
32785	PG0079	2017-07-17 12:45:00+03	2017-07-17 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-17 12:47:00+03	2017-07-17 14:12:00+03
32786	PG0080	2017-09-04 11:25:00+03	2017-09-04 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32787	PG0079	2017-07-18 12:45:00+03	2017-07-18 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-18 12:48:00+03	2017-07-18 14:13:00+03
32788	PG0080	2017-07-18 11:25:00+03	2017-07-18 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-18 14:33:00+03	2017-07-18 15:58:00+03
32789	PG0079	2017-08-21 12:45:00+03	2017-08-21 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32790	PG0080	2017-08-19 11:25:00+03	2017-08-19 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32791	PG0079	2017-08-19 12:45:00+03	2017-08-19 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32792	PG0080	2017-08-21 11:25:00+03	2017-08-21 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32793	PG0079	2017-08-05 12:45:00+03	2017-08-05 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-05 12:49:00+03	2017-08-05 14:15:00+03
32794	PG0080	2017-07-29 11:25:00+03	2017-07-29 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-29 11:31:00+03	2017-07-29 12:58:00+03
32795	PG0080	2017-08-05 11:25:00+03	2017-08-05 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-05 11:28:00+03	2017-08-05 12:53:00+03
32796	PG0079	2017-07-29 12:45:00+03	2017-07-29 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-29 12:49:00+03	2017-07-29 14:13:00+03
32797	PG0079	2017-07-23 12:45:00+03	2017-07-23 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-23 12:46:00+03	2017-07-23 14:12:00+03
32798	PG0080	2017-07-23 11:25:00+03	2017-07-23 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-23 11:26:00+03	2017-07-23 12:51:00+03
32799	PG0080	2017-08-11 11:25:00+03	2017-08-11 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-11 11:28:00+03	2017-08-11 12:54:00+03
32800	PG0079	2017-08-11 12:45:00+03	2017-08-11 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-11 12:49:00+03	2017-08-11 14:15:00+03
32801	PG0079	2017-07-19 12:45:00+03	2017-07-19 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-19 12:48:00+03	2017-07-19 14:13:00+03
32802	PG0079	2017-08-01 12:45:00+03	2017-08-01 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-01 12:47:00+03	2017-08-01 14:11:00+03
32803	PG0080	2017-08-01 11:25:00+03	2017-08-01 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-01 11:27:00+03	2017-08-01 12:51:00+03
32804	PG0080	2017-08-31 11:25:00+03	2017-08-31 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32805	PG0079	2017-08-31 12:45:00+03	2017-08-31 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32806	PG0080	2017-09-14 11:25:00+03	2017-09-14 12:50:00+03	CEE	LED	Cancelled	CN1	\N	\N
32807	PG0079	2017-08-14 12:45:00+03	2017-08-14 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-14 12:47:00+03	2017-08-14 14:13:00+03
32808	PG0080	2017-08-14 11:25:00+03	2017-08-14 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-14 11:28:00+03	2017-08-14 12:55:00+03
32809	PG0079	2017-09-04 12:45:00+03	2017-09-04 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32810	PG0079	2017-09-14 12:45:00+03	2017-09-14 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32811	PG0080	2017-08-23 11:25:00+03	2017-08-23 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32812	PG0080	2017-09-11 11:25:00+03	2017-09-11 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32813	PG0079	2017-09-11 12:45:00+03	2017-09-11 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32814	PG0080	2017-07-28 11:25:00+03	2017-07-28 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-28 11:27:00+03	2017-07-28 12:53:00+03
32815	PG0079	2017-07-28 12:45:00+03	2017-07-28 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-28 12:47:00+03	2017-07-28 14:10:00+03
32816	PG0080	2017-07-20 11:25:00+03	2017-07-20 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-20 11:27:00+03	2017-07-20 12:53:00+03
32817	PG0079	2017-07-20 12:45:00+03	2017-07-20 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-20 12:50:00+03	2017-07-20 14:15:00+03
32818	PG0079	2017-08-23 12:45:00+03	2017-08-23 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32819	PG0080	2017-08-18 11:25:00+03	2017-08-18 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32820	PG0079	2017-08-18 12:45:00+03	2017-08-18 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32821	PG0080	2017-08-07 11:25:00+03	2017-08-07 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-07 11:29:00+03	2017-08-07 12:52:00+03
32822	PG0079	2017-07-24 12:45:00+03	2017-07-24 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-24 12:48:00+03	2017-07-24 14:12:00+03
32823	PG0079	2017-08-07 12:45:00+03	2017-08-07 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-07 12:48:00+03	2017-08-07 14:14:00+03
32824	PG0080	2017-07-24 11:25:00+03	2017-07-24 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-24 11:28:00+03	2017-07-24 12:52:00+03
32825	PG0079	2017-08-25 12:45:00+03	2017-08-25 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32826	PG0079	2017-09-13 12:45:00+03	2017-09-13 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32827	PG0079	2017-08-29 12:45:00+03	2017-08-29 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32828	PG0080	2017-08-29 11:25:00+03	2017-08-29 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32829	PG0080	2017-09-13 11:25:00+03	2017-09-13 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32830	PG0079	2017-09-09 12:45:00+03	2017-09-09 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32831	PG0080	2017-09-09 11:25:00+03	2017-09-09 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32832	PG0080	2017-08-25 11:25:00+03	2017-08-25 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32833	PG0079	2017-08-09 12:45:00+03	2017-08-09 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-09 12:47:00+03	2017-08-09 14:13:00+03
32834	PG0079	2017-08-15 12:45:00+03	2017-08-15 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-15 12:48:00+03	2017-08-15 14:13:00+03
32835	PG0080	2017-08-15 11:25:00+03	2017-08-15 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-15 11:28:00+03	2017-08-15 12:53:00+03
32836	PG0080	2017-08-09 11:25:00+03	2017-08-09 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-09 14:12:00+03	2017-08-09 15:37:00+03
32837	PG0080	2017-08-27 11:25:00+03	2017-08-27 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32838	PG0080	2017-07-27 11:25:00+03	2017-07-27 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-27 11:32:00+03	2017-07-27 12:57:00+03
32839	PG0079	2017-07-27 12:45:00+03	2017-07-27 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-27 12:49:00+03	2017-07-27 14:14:00+03
32840	PG0079	2017-08-27 12:45:00+03	2017-08-27 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32841	PG0079	2017-09-02 12:45:00+03	2017-09-02 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32842	PG0080	2017-09-02 11:25:00+03	2017-09-02 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32843	PG0080	2017-08-03 11:25:00+03	2017-08-03 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-03 14:27:00+03	2017-08-03 15:54:00+03
32844	PG0079	2017-08-03 12:45:00+03	2017-08-03 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-03 12:48:00+03	2017-08-03 14:14:00+03
32845	PG0079	2017-08-22 12:45:00+03	2017-08-22 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32846	PG0080	2017-08-22 11:25:00+03	2017-08-22 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32847	PG0079	2017-08-02 12:45:00+03	2017-08-02 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-02 12:49:00+03	2017-08-02 14:14:00+03
32848	PG0080	2017-08-02 11:25:00+03	2017-08-02 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-02 11:30:00+03	2017-08-02 12:55:00+03
32849	PG0080	2017-08-10 11:25:00+03	2017-08-10 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-10 11:28:00+03	2017-08-10 12:53:00+03
32850	PG0079	2017-08-10 12:45:00+03	2017-08-10 14:10:00+03	CEE	LED	Arrived	CN1	2017-08-10 12:46:00+03	2017-08-10 14:11:00+03
32851	PG0079	2017-07-25 12:45:00+03	2017-07-25 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-25 12:50:00+03	2017-07-25 14:17:00+03
32852	PG0080	2017-07-25 11:25:00+03	2017-07-25 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-25 11:30:00+03	2017-07-25 12:56:00+03
32853	PG0080	2017-08-17 11:25:00+03	2017-08-17 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32854	PG0079	2017-08-17 12:45:00+03	2017-08-17 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32855	PG0080	2017-08-30 11:25:00+03	2017-08-30 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32856	PG0079	2017-09-10 12:45:00+03	2017-09-10 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32857	PG0080	2017-09-10 11:25:00+03	2017-09-10 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32858	PG0079	2017-08-30 12:45:00+03	2017-08-30 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32859	PG0080	2017-09-06 11:25:00+03	2017-09-06 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32860	PG0079	2017-09-06 12:45:00+03	2017-09-06 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32861	PG0079	2017-07-16 12:45:00+03	2017-07-16 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-16 12:47:00+03	2017-07-16 14:12:00+03
32862	PG0079	2017-08-16 12:45:00+03	2017-08-16 14:10:00+03	CEE	LED	On Time	CN1	\N	\N
32863	PG0080	2017-08-16 11:25:00+03	2017-08-16 12:50:00+03	CEE	LED	On Time	CN1	\N	\N
32864	PG0079	2017-07-26 12:45:00+03	2017-07-26 14:10:00+03	CEE	LED	Arrived	CN1	2017-07-26 12:48:00+03	2017-07-26 14:11:00+03
32865	PG0080	2017-08-06 11:25:00+03	2017-08-06 12:50:00+03	CEE	LED	Arrived	CN1	2017-08-06 11:30:00+03	2017-08-06 12:55:00+03
32866	PG0079	2017-09-03 12:45:00+03	2017-09-03 14:10:00+03	CEE	LED	Scheduled	CN1	\N	\N
32867	PG0080	2017-09-03 11:25:00+03	2017-09-03 12:50:00+03	CEE	LED	Scheduled	CN1	\N	\N
32868	PG0080	2017-07-26 11:25:00+03	2017-07-26 12:50:00+03	CEE	LED	Arrived	CN1	2017-07-26 14:17:00+03	2017-07-26 15:42:00+03
32869	PG0616	2017-09-03 09:20:00+03	2017-09-03 13:20:00+03	CEE	NOZ	Scheduled	SU9	\N	\N
32870	PG0616	2017-08-13 09:20:00+03	2017-08-13 13:20:00+03	CEE	NOZ	Arrived	SU9	2017-08-13 09:24:00+03	2017-08-13 13:23:00+03
32871	PG0616	2017-09-10 09:20:00+03	2017-09-10 13:20:00+03	CEE	NOZ	Cancelled	SU9	\N	\N
32872	PG0616	2017-08-27 09:20:00+03	2017-08-27 13:20:00+03	CEE	NOZ	Scheduled	SU9	\N	\N
32873	PG0616	2017-08-20 09:20:00+03	2017-08-20 13:20:00+03	CEE	NOZ	Scheduled	SU9	\N	\N
32874	PG0616	2017-07-30 09:20:00+03	2017-07-30 13:20:00+03	CEE	NOZ	Arrived	SU9	2017-07-30 09:23:00+03	2017-07-30 13:19:00+03
32875	PG0616	2017-07-23 09:20:00+03	2017-07-23 13:20:00+03	CEE	NOZ	Arrived	SU9	2017-07-23 09:20:00+03	2017-07-23 13:19:00+03
32876	PG0616	2017-08-06 09:20:00+03	2017-08-06 13:20:00+03	CEE	NOZ	Arrived	SU9	2017-08-06 09:21:00+03	2017-08-06 13:23:00+03
32877	PG0616	2017-07-16 09:20:00+03	2017-07-16 13:20:00+03	CEE	NOZ	Arrived	SU9	2017-07-16 09:22:00+03	2017-07-16 13:25:00+03
32878	PG0147	2017-08-27 16:55:00+03	2017-08-27 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32879	PG0147	2017-07-24 16:55:00+03	2017-07-24 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-24 16:58:00+03	2017-07-24 18:56:00+03
32880	PG0147	2017-08-20 16:55:00+03	2017-08-20 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32881	PG0147	2017-07-22 16:55:00+03	2017-07-22 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-22 17:00:00+03	2017-07-22 19:01:00+03
32882	PG0147	2017-07-23 16:55:00+03	2017-07-23 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-23 16:57:00+03	2017-07-23 18:57:00+03
32883	PG0147	2017-07-20 16:55:00+03	2017-07-20 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-20 16:59:00+03	2017-07-20 18:57:00+03
32884	PG0147	2017-07-19 16:55:00+03	2017-07-19 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-19 16:58:00+03	2017-07-19 18:55:00+03
32885	PG0147	2017-07-21 16:55:00+03	2017-07-21 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-21 16:56:00+03	2017-07-21 18:55:00+03
32886	PG0147	2017-08-02 16:55:00+03	2017-08-02 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-02 16:57:00+03	2017-08-02 18:58:00+03
32887	PG0147	2017-08-23 16:55:00+03	2017-08-23 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32888	PG0147	2017-09-01 16:55:00+03	2017-09-01 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32889	PG0147	2017-08-29 16:55:00+03	2017-08-29 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32890	PG0147	2017-07-30 16:55:00+03	2017-07-30 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-30 16:59:00+03	2017-07-30 19:00:00+03
32891	PG0147	2017-08-26 16:55:00+03	2017-08-26 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32892	PG0147	2017-09-04 16:55:00+03	2017-09-04 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32893	PG0147	2017-09-14 16:55:00+03	2017-09-14 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32894	PG0147	2017-08-01 16:55:00+03	2017-08-01 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-01 16:55:00+03	2017-08-01 18:53:00+03
32895	PG0147	2017-08-30 16:55:00+03	2017-08-30 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32896	PG0147	2017-08-14 16:55:00+03	2017-08-14 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-14 17:01:00+03	2017-08-14 19:02:00+03
32897	PG0147	2017-09-05 16:55:00+03	2017-09-05 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32898	PG0147	2017-08-16 16:55:00+03	2017-08-16 18:55:00+03	OGZ	VKO	On Time	SU9	\N	\N
32899	PG0147	2017-07-18 16:55:00+03	2017-07-18 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-18 16:56:00+03	2017-07-18 18:56:00+03
32900	PG0147	2017-08-05 16:55:00+03	2017-08-05 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-05 16:59:00+03	2017-08-05 18:59:00+03
32901	PG0147	2017-08-11 16:55:00+03	2017-08-11 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-11 19:45:00+03	2017-08-11 21:46:00+03
32902	PG0147	2017-08-21 16:55:00+03	2017-08-21 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32903	PG0147	2017-08-17 16:55:00+03	2017-08-17 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32904	PG0147	2017-07-28 16:55:00+03	2017-07-28 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-28 16:57:00+03	2017-07-28 18:56:00+03
32905	PG0147	2017-08-08 16:55:00+03	2017-08-08 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-08 16:56:00+03	2017-08-08 18:55:00+03
32906	PG0147	2017-08-13 16:55:00+03	2017-08-13 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-13 16:56:00+03	2017-08-13 18:56:00+03
32907	PG0147	2017-07-25 16:55:00+03	2017-07-25 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-25 16:59:00+03	2017-07-25 18:58:00+03
32908	PG0147	2017-09-02 16:55:00+03	2017-09-02 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32909	PG0147	2017-07-29 16:55:00+03	2017-07-29 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-29 16:59:00+03	2017-07-29 19:00:00+03
32910	PG0147	2017-08-04 16:55:00+03	2017-08-04 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-04 19:47:00+03	2017-08-04 21:47:00+03
32911	PG0147	2017-08-10 16:55:00+03	2017-08-10 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-10 17:00:00+03	2017-08-10 19:01:00+03
32912	PG0147	2017-08-07 16:55:00+03	2017-08-07 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-07 17:03:00+03	2017-08-07 19:02:00+03
32913	PG0147	2017-07-17 16:55:00+03	2017-07-17 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-17 17:00:00+03	2017-07-17 18:59:00+03
32914	PG0147	2017-08-19 16:55:00+03	2017-08-19 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32915	PG0147	2017-09-06 16:55:00+03	2017-09-06 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32916	PG0147	2017-09-07 16:55:00+03	2017-09-07 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32917	PG0147	2017-08-24 16:55:00+03	2017-08-24 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32918	PG0147	2017-07-31 16:55:00+03	2017-07-31 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-31 16:58:00+03	2017-07-31 18:59:00+03
32919	PG0147	2017-09-08 16:55:00+03	2017-09-08 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32920	PG0147	2017-07-16 16:55:00+03	2017-07-16 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-16 16:57:00+03	2017-07-16 18:58:00+03
32921	PG0147	2017-08-09 16:55:00+03	2017-08-09 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-09 16:58:00+03	2017-08-09 18:58:00+03
32922	PG0147	2017-08-18 16:55:00+03	2017-08-18 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32923	PG0147	2017-07-26 16:55:00+03	2017-07-26 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-26 16:56:00+03	2017-07-26 18:56:00+03
32924	PG0147	2017-08-28 16:55:00+03	2017-08-28 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32925	PG0147	2017-08-12 16:55:00+03	2017-08-12 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-12 16:59:00+03	2017-08-12 19:01:00+03
32926	PG0147	2017-09-12 16:55:00+03	2017-09-12 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32927	PG0147	2017-09-03 16:55:00+03	2017-09-03 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32928	PG0147	2017-07-27 16:55:00+03	2017-07-27 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-07-27 16:57:00+03	2017-07-27 18:56:00+03
32929	PG0147	2017-09-11 16:55:00+03	2017-09-11 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32930	PG0147	2017-09-10 16:55:00+03	2017-09-10 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32931	PG0147	2017-08-03 16:55:00+03	2017-08-03 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-03 16:59:00+03	2017-08-03 18:58:00+03
32932	PG0147	2017-08-25 16:55:00+03	2017-08-25 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32933	PG0147	2017-08-06 16:55:00+03	2017-08-06 18:55:00+03	OGZ	VKO	Arrived	SU9	2017-08-06 16:58:00+03	2017-08-06 19:00:00+03
32934	PG0147	2017-08-22 16:55:00+03	2017-08-22 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32935	PG0147	2017-09-09 16:55:00+03	2017-09-09 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32936	PG0147	2017-08-31 16:55:00+03	2017-08-31 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32937	PG0147	2017-08-15 16:55:00+03	2017-08-15 18:55:00+03	OGZ	VKO	Departed	SU9	2017-08-15 16:58:00+03	\N
32938	PG0147	2017-09-13 16:55:00+03	2017-09-13 18:55:00+03	OGZ	VKO	Scheduled	SU9	\N	\N
32939	PG0550	2017-09-01 09:05:00+03	2017-09-01 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32940	PG0550	2017-08-18 09:05:00+03	2017-08-18 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32941	PG0550	2017-08-28 09:05:00+03	2017-08-28 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32942	PG0550	2017-08-10 09:05:00+03	2017-08-10 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-10 09:09:00+03	2017-08-10 11:18:00+03
32943	PG0550	2017-08-27 09:05:00+03	2017-08-27 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32944	PG0550	2017-09-08 09:05:00+03	2017-09-08 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32945	PG0550	2017-08-25 09:05:00+03	2017-08-25 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32946	PG0550	2017-09-11 09:05:00+03	2017-09-11 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32947	PG0550	2017-07-23 09:05:00+03	2017-07-23 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-23 09:08:00+03	2017-07-23 11:19:00+03
32948	PG0550	2017-07-16 09:05:00+03	2017-07-16 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-16 09:09:00+03	2017-07-16 11:18:00+03
32949	PG0550	2017-09-02 09:05:00+03	2017-09-02 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32950	PG0550	2017-08-09 09:05:00+03	2017-08-09 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-09 09:09:00+03	2017-08-09 11:20:00+03
32951	PG0550	2017-08-19 09:05:00+03	2017-08-19 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32952	PG0550	2017-08-02 09:05:00+03	2017-08-02 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-02 09:07:00+03	2017-08-02 11:18:00+03
32953	PG0550	2017-09-07 09:05:00+03	2017-09-07 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32954	PG0550	2017-08-30 09:05:00+03	2017-08-30 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32955	PG0550	2017-08-14 09:05:00+03	2017-08-14 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-14 09:05:00+03	2017-08-14 11:16:00+03
32956	PG0550	2017-08-23 09:05:00+03	2017-08-23 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32957	PG0550	2017-07-25 09:05:00+03	2017-07-25 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-25 09:07:00+03	2017-07-25 11:18:00+03
32958	PG0550	2017-09-09 09:05:00+03	2017-09-09 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32959	PG0550	2017-08-16 09:05:00+03	2017-08-16 11:15:00+03	OGZ	SVO	On Time	CR2	\N	\N
32960	PG0550	2017-08-04 09:05:00+03	2017-08-04 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-04 09:07:00+03	2017-08-04 11:17:00+03
32961	PG0550	2017-09-14 09:05:00+03	2017-09-14 11:15:00+03	OGZ	SVO	Cancelled	CR2	\N	\N
32962	PG0550	2017-07-21 09:05:00+03	2017-07-21 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-21 09:09:00+03	2017-07-21 11:19:00+03
32963	PG0550	2017-07-27 09:05:00+03	2017-07-27 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-27 09:14:00+03	2017-07-27 11:26:00+03
32964	PG0550	2017-09-10 09:05:00+03	2017-09-10 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32965	PG0550	2017-08-24 09:05:00+03	2017-08-24 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32966	PG0550	2017-08-31 09:05:00+03	2017-08-31 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32967	PG0550	2017-08-21 09:05:00+03	2017-08-21 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32968	PG0550	2017-08-12 09:05:00+03	2017-08-12 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-12 09:07:00+03	2017-08-12 11:18:00+03
32969	PG0550	2017-08-05 09:05:00+03	2017-08-05 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-05 09:09:00+03	2017-08-05 11:18:00+03
32970	PG0550	2017-08-17 09:05:00+03	2017-08-17 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32971	PG0550	2017-08-26 09:05:00+03	2017-08-26 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32972	PG0550	2017-09-05 09:05:00+03	2017-09-05 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32973	PG0550	2017-09-03 09:05:00+03	2017-09-03 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32974	PG0550	2017-08-01 09:05:00+03	2017-08-01 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-01 09:06:00+03	2017-08-01 11:18:00+03
32975	PG0550	2017-07-19 09:05:00+03	2017-07-19 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-19 09:09:00+03	2017-07-19 11:18:00+03
32976	PG0550	2017-08-22 09:05:00+03	2017-08-22 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32977	PG0550	2017-07-24 09:05:00+03	2017-07-24 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-24 09:09:00+03	2017-07-24 11:20:00+03
32978	PG0550	2017-07-18 09:05:00+03	2017-07-18 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-18 09:08:00+03	2017-07-18 11:20:00+03
32979	PG0550	2017-09-13 09:05:00+03	2017-09-13 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32980	PG0550	2017-07-30 09:05:00+03	2017-07-30 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-30 09:08:00+03	2017-07-30 11:17:00+03
32981	PG0550	2017-08-03 09:05:00+03	2017-08-03 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-03 09:07:00+03	2017-08-03 11:18:00+03
32982	PG0550	2017-07-31 09:05:00+03	2017-07-31 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-31 09:10:00+03	2017-07-31 11:19:00+03
32983	PG0550	2017-07-20 09:05:00+03	2017-07-20 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-20 09:08:00+03	2017-07-20 11:17:00+03
32984	PG0550	2017-08-07 09:05:00+03	2017-08-07 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-07 09:07:00+03	2017-08-07 11:18:00+03
32985	PG0550	2017-09-04 09:05:00+03	2017-09-04 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32986	PG0550	2017-09-12 09:05:00+03	2017-09-12 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32987	PG0550	2017-08-13 09:05:00+03	2017-08-13 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-13 09:06:00+03	2017-08-13 11:16:00+03
32988	PG0550	2017-08-15 09:05:00+03	2017-08-15 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-15 09:08:00+03	2017-08-15 11:17:00+03
32989	PG0550	2017-08-29 09:05:00+03	2017-08-29 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32990	PG0550	2017-07-26 09:05:00+03	2017-07-26 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-26 09:09:00+03	2017-07-26 11:20:00+03
32991	PG0550	2017-08-08 09:05:00+03	2017-08-08 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-08 09:09:00+03	2017-08-08 11:20:00+03
32992	PG0550	2017-08-20 09:05:00+03	2017-08-20 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32993	PG0550	2017-08-06 09:05:00+03	2017-08-06 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-06 09:14:00+03	2017-08-06 11:24:00+03
32994	PG0550	2017-07-22 09:05:00+03	2017-07-22 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-22 09:06:00+03	2017-07-22 11:16:00+03
32995	PG0550	2017-08-11 09:05:00+03	2017-08-11 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-08-11 09:08:00+03	2017-08-11 11:19:00+03
32996	PG0550	2017-07-29 09:05:00+03	2017-07-29 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-29 09:08:00+03	2017-07-29 11:21:00+03
32997	PG0550	2017-09-06 09:05:00+03	2017-09-06 11:15:00+03	OGZ	SVO	Scheduled	CR2	\N	\N
32998	PG0550	2017-07-28 09:05:00+03	2017-07-28 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-28 09:07:00+03	2017-07-28 11:19:00+03
32999	PG0550	2017-07-17 09:05:00+03	2017-07-17 11:15:00+03	OGZ	SVO	Arrived	CR2	2017-07-17 09:07:00+03	2017-07-17 11:16:00+03
33000	PG0359	2017-08-25 14:30:00+03	2017-08-25 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33001	PG0359	2017-08-06 14:30:00+03	2017-08-06 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-06 14:32:00+03	2017-08-06 15:17:00+03
33002	PG0359	2017-07-21 14:30:00+03	2017-07-21 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-21 14:31:00+03	2017-07-21 15:16:00+03
33003	PG0359	2017-08-30 14:30:00+03	2017-08-30 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33004	PG0359	2017-08-22 14:30:00+03	2017-08-22 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33005	PG0359	2017-07-30 14:30:00+03	2017-07-30 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-30 14:32:00+03	2017-07-30 15:16:00+03
33006	PG0359	2017-07-23 14:30:00+03	2017-07-23 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-23 14:34:00+03	2017-07-23 15:19:00+03
33007	PG0359	2017-08-31 14:30:00+03	2017-08-31 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33008	PG0359	2017-08-12 14:30:00+03	2017-08-12 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-12 14:31:00+03	2017-08-12 15:16:00+03
33009	PG0359	2017-08-17 14:30:00+03	2017-08-17 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33010	PG0359	2017-07-31 14:30:00+03	2017-07-31 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-31 14:32:00+03	2017-07-31 15:17:00+03
33011	PG0359	2017-08-08 14:30:00+03	2017-08-08 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-08 14:30:00+03	2017-08-08 15:15:00+03
33012	PG0359	2017-08-26 14:30:00+03	2017-08-26 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33013	PG0359	2017-08-15 14:30:00+03	2017-08-15 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-15 14:33:00+03	2017-08-15 15:19:00+03
33014	PG0359	2017-09-02 14:30:00+03	2017-09-02 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33015	PG0359	2017-09-12 14:30:00+03	2017-09-12 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33016	PG0359	2017-08-11 14:30:00+03	2017-08-11 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-11 14:35:00+03	2017-08-11 15:19:00+03
33017	PG0359	2017-08-28 14:30:00+03	2017-08-28 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33018	PG0359	2017-09-01 14:30:00+03	2017-09-01 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33019	PG0359	2017-08-23 14:30:00+03	2017-08-23 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33020	PG0359	2017-07-29 14:30:00+03	2017-07-29 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-29 14:33:00+03	2017-07-29 15:18:00+03
33021	PG0359	2017-09-08 14:30:00+03	2017-09-08 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33022	PG0359	2017-09-04 14:30:00+03	2017-09-04 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33023	PG0359	2017-09-10 14:30:00+03	2017-09-10 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33024	PG0359	2017-09-11 14:30:00+03	2017-09-11 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33025	PG0359	2017-07-22 14:30:00+03	2017-07-22 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-22 17:24:00+03	2017-07-22 18:08:00+03
33026	PG0359	2017-08-02 14:30:00+03	2017-08-02 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-02 14:35:00+03	2017-08-02 15:20:00+03
33027	PG0359	2017-08-27 14:30:00+03	2017-08-27 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33028	PG0359	2017-07-28 14:30:00+03	2017-07-28 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-28 14:32:00+03	2017-07-28 15:17:00+03
33029	PG0359	2017-09-09 14:30:00+03	2017-09-09 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33030	PG0359	2017-08-05 14:30:00+03	2017-08-05 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-05 14:30:00+03	2017-08-05 15:15:00+03
33031	PG0359	2017-08-01 14:30:00+03	2017-08-01 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-01 14:32:00+03	2017-08-01 15:17:00+03
33032	PG0359	2017-08-07 14:30:00+03	2017-08-07 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-07 14:33:00+03	2017-08-07 15:17:00+03
33033	PG0359	2017-08-19 14:30:00+03	2017-08-19 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33034	PG0359	2017-09-13 14:30:00+03	2017-09-13 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33035	PG0359	2017-08-13 14:30:00+03	2017-08-13 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-13 14:34:00+03	2017-08-13 15:20:00+03
33036	PG0359	2017-08-14 14:30:00+03	2017-08-14 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-14 14:35:00+03	2017-08-14 15:19:00+03
33037	PG0359	2017-09-05 14:30:00+03	2017-09-05 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33038	PG0359	2017-07-25 14:30:00+03	2017-07-25 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-25 14:33:00+03	2017-07-25 15:18:00+03
33039	PG0359	2017-08-04 14:30:00+03	2017-08-04 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-04 14:31:00+03	2017-08-04 15:16:00+03
33040	PG0359	2017-08-18 14:30:00+03	2017-08-18 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33041	PG0359	2017-09-03 14:30:00+03	2017-09-03 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33042	PG0359	2017-07-18 14:30:00+03	2017-07-18 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-18 14:35:00+03	2017-07-18 15:20:00+03
33043	PG0359	2017-08-16 14:30:00+03	2017-08-16 15:15:00+03	SKX	VKO	On Time	CR2	\N	\N
33044	PG0359	2017-08-03 14:30:00+03	2017-08-03 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-03 14:32:00+03	2017-08-03 15:17:00+03
33045	PG0359	2017-07-24 14:30:00+03	2017-07-24 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-24 14:35:00+03	2017-07-24 15:20:00+03
33046	PG0359	2017-09-06 14:30:00+03	2017-09-06 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33047	PG0359	2017-07-19 14:30:00+03	2017-07-19 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-19 14:33:00+03	2017-07-19 15:19:00+03
33048	PG0359	2017-08-09 14:30:00+03	2017-08-09 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-09 14:33:00+03	2017-08-09 15:18:00+03
33049	PG0359	2017-08-21 14:30:00+03	2017-08-21 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33050	PG0359	2017-07-20 14:30:00+03	2017-07-20 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-20 14:33:00+03	2017-07-20 15:17:00+03
33051	PG0359	2017-08-29 14:30:00+03	2017-08-29 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33052	PG0359	2017-09-14 14:30:00+03	2017-09-14 15:15:00+03	SKX	VKO	Cancelled	CR2	\N	\N
33053	PG0359	2017-07-17 14:30:00+03	2017-07-17 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-17 14:35:00+03	2017-07-17 15:20:00+03
33054	PG0359	2017-09-07 14:30:00+03	2017-09-07 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33055	PG0359	2017-07-16 14:30:00+03	2017-07-16 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-16 14:30:00+03	2017-07-16 15:15:00+03
33056	PG0359	2017-08-10 14:30:00+03	2017-08-10 15:15:00+03	SKX	VKO	Arrived	CR2	2017-08-10 14:34:00+03	2017-08-10 15:18:00+03
33057	PG0359	2017-07-26 14:30:00+03	2017-07-26 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-26 14:33:00+03	2017-07-26 15:18:00+03
33058	PG0359	2017-08-24 14:30:00+03	2017-08-24 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33059	PG0359	2017-08-20 14:30:00+03	2017-08-20 15:15:00+03	SKX	VKO	Scheduled	CR2	\N	\N
33060	PG0359	2017-07-27 14:30:00+03	2017-07-27 15:15:00+03	SKX	VKO	Arrived	CR2	2017-07-27 14:33:00+03	2017-07-27 15:19:00+03
33061	PG0063	2017-08-13 19:25:00+03	2017-08-13 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-13 19:26:00+03	2017-08-13 20:10:00+03
33062	PG0063	2017-09-03 19:25:00+03	2017-09-03 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33063	PG0063	2017-08-16 19:25:00+03	2017-08-16 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33064	PG0063	2017-07-25 19:25:00+03	2017-07-25 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-25 19:27:00+03	2017-07-25 20:12:00+03
33065	PG0063	2017-07-26 19:25:00+03	2017-07-26 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-26 19:28:00+03	2017-07-26 20:13:00+03
33066	PG0063	2017-09-10 19:25:00+03	2017-09-10 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33067	PG0063	2017-08-05 19:25:00+03	2017-08-05 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-05 22:31:00+03	2017-08-05 23:16:00+03
33068	PG0063	2017-08-11 19:25:00+03	2017-08-11 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-11 19:26:00+03	2017-08-11 20:11:00+03
33069	PG0063	2017-08-09 19:25:00+03	2017-08-09 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-09 19:26:00+03	2017-08-09 20:11:00+03
33070	PG0063	2017-09-11 19:25:00+03	2017-09-11 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33071	PG0063	2017-07-24 19:25:00+03	2017-07-24 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-24 19:29:00+03	2017-07-24 20:13:00+03
33072	PG0063	2017-08-04 19:25:00+03	2017-08-04 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-04 19:28:00+03	2017-08-04 20:13:00+03
33073	PG0063	2017-07-21 19:25:00+03	2017-07-21 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-21 19:32:00+03	2017-07-21 20:16:00+03
33074	PG0063	2017-08-23 19:25:00+03	2017-08-23 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33075	PG0063	2017-08-14 19:25:00+03	2017-08-14 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-14 19:29:00+03	2017-08-14 20:14:00+03
33076	PG0063	2017-08-19 19:25:00+03	2017-08-19 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33077	PG0063	2017-09-04 19:25:00+03	2017-09-04 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33078	PG0063	2017-08-06 19:25:00+03	2017-08-06 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-06 19:28:00+03	2017-08-06 20:12:00+03
33079	PG0063	2017-09-02 19:25:00+03	2017-09-02 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33080	PG0063	2017-07-27 19:25:00+03	2017-07-27 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-27 19:28:00+03	2017-07-27 20:13:00+03
33081	PG0063	2017-09-09 19:25:00+03	2017-09-09 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33082	PG0063	2017-08-17 19:25:00+03	2017-08-17 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33083	PG0063	2017-09-13 19:25:00+03	2017-09-13 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33084	PG0063	2017-08-27 19:25:00+03	2017-08-27 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33085	PG0063	2017-08-25 19:25:00+03	2017-08-25 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33086	PG0063	2017-09-12 19:25:00+03	2017-09-12 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33087	PG0063	2017-08-20 19:25:00+03	2017-08-20 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33088	PG0063	2017-07-30 19:25:00+03	2017-07-30 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-30 19:29:00+03	2017-07-30 20:15:00+03
33089	PG0063	2017-07-31 19:25:00+03	2017-07-31 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-31 19:29:00+03	2017-07-31 20:14:00+03
33090	PG0063	2017-08-30 19:25:00+03	2017-08-30 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33091	PG0063	2017-08-18 19:25:00+03	2017-08-18 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33092	PG0063	2017-07-16 19:25:00+03	2017-07-16 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-16 19:30:00+03	2017-07-16 20:16:00+03
33093	PG0063	2017-08-24 19:25:00+03	2017-08-24 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33094	PG0063	2017-08-22 19:25:00+03	2017-08-22 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33095	PG0063	2017-08-12 19:25:00+03	2017-08-12 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-12 19:29:00+03	2017-08-12 20:15:00+03
33096	PG0063	2017-07-22 19:25:00+03	2017-07-22 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-22 19:25:00+03	2017-07-22 20:10:00+03
33097	PG0063	2017-09-07 19:25:00+03	2017-09-07 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33098	PG0063	2017-09-01 19:25:00+03	2017-09-01 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33099	PG0063	2017-09-14 19:25:00+03	2017-09-14 20:10:00+03	SKX	SVO	Cancelled	CR2	\N	\N
33100	PG0063	2017-07-23 19:25:00+03	2017-07-23 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-23 19:28:00+03	2017-07-23 20:12:00+03
33101	PG0063	2017-07-20 19:25:00+03	2017-07-20 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-20 19:28:00+03	2017-07-20 20:13:00+03
33102	PG0063	2017-09-05 19:25:00+03	2017-09-05 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33103	PG0063	2017-07-29 19:25:00+03	2017-07-29 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-29 19:28:00+03	2017-07-29 20:12:00+03
33104	PG0063	2017-08-29 19:25:00+03	2017-08-29 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33105	PG0063	2017-07-19 19:25:00+03	2017-07-19 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-19 19:27:00+03	2017-07-19 20:12:00+03
33106	PG0063	2017-08-28 19:25:00+03	2017-08-28 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33107	PG0063	2017-09-06 19:25:00+03	2017-09-06 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33108	PG0063	2017-08-03 19:25:00+03	2017-08-03 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-03 19:29:00+03	2017-08-03 20:13:00+03
33109	PG0063	2017-08-07 19:25:00+03	2017-08-07 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-07 19:31:00+03	2017-08-07 20:15:00+03
33110	PG0063	2017-07-18 19:25:00+03	2017-07-18 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-18 19:26:00+03	2017-07-18 20:11:00+03
33111	PG0063	2017-08-21 19:25:00+03	2017-08-21 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33112	PG0063	2017-08-31 19:25:00+03	2017-08-31 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33113	PG0063	2017-08-10 19:25:00+03	2017-08-10 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-10 19:27:00+03	2017-08-10 20:13:00+03
33114	PG0063	2017-07-17 19:25:00+03	2017-07-17 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-17 19:32:00+03	2017-07-17 20:17:00+03
33115	PG0063	2017-08-08 19:25:00+03	2017-08-08 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-08 19:27:00+03	2017-08-08 20:12:00+03
33116	PG0063	2017-08-15 19:25:00+03	2017-08-15 20:10:00+03	SKX	SVO	On Time	CR2	\N	\N
33117	PG0063	2017-08-02 19:25:00+03	2017-08-02 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-02 19:25:00+03	2017-08-02 20:10:00+03
33118	PG0063	2017-07-28 19:25:00+03	2017-07-28 20:10:00+03	SKX	SVO	Arrived	CR2	2017-07-28 19:30:00+03	2017-07-28 20:15:00+03
33119	PG0063	2017-09-08 19:25:00+03	2017-09-08 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
33120	PG0063	2017-08-01 19:25:00+03	2017-08-01 20:10:00+03	SKX	SVO	Arrived	CR2	2017-08-01 19:26:00+03	2017-08-01 20:12:00+03
33121	PG0063	2017-08-26 19:25:00+03	2017-08-26 20:10:00+03	SKX	SVO	Scheduled	CR2	\N	\N
\.


--
-- Name: flights_flight_id_seq; Type: SEQUENCE SET; Schema: bookings; Owner: -
--

SELECT pg_catalog.setval('flights_flight_id_seq', 33121, true);


--
-- Data for Name: seats; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY seats (aircraft_code, seat_no, fare_conditions) FROM stdin;
319	2A	Business
319	2C	Business
319	2D	Business
319	2F	Business
319	3A	Business
319	3C	Business
319	3D	Business
319	3F	Business
319	4A	Business
319	4C	Business
319	4D	Business
319	4F	Business
319	5A	Business
319	5C	Business
319	5D	Business
319	5F	Business
319	6A	Economy
319	6B	Economy
319	6C	Economy
319	6D	Economy
319	6E	Economy
319	6F	Economy
319	7A	Economy
319	7B	Economy
319	7C	Economy
319	7D	Economy
319	7E	Economy
319	7F	Economy
319	8A	Economy
319	8B	Economy
319	8C	Economy
319	8D	Economy
319	8F	Economy
319	9A	Economy
319	9B	Economy
319	9C	Economy
319	9D	Economy
319	9E	Economy
319	9F	Economy
319	10A	Economy
319	10B	Economy
319	10C	Economy
319	10D	Economy
319	10E	Economy
319	10F	Economy
319	11A	Economy
319	11B	Economy
319	17D	Economy
319	17E	Economy
319	17F	Economy
319	18A	Economy
319	18B	Economy
319	18C	Economy
319	18D	Economy
319	18E	Economy
319	18F	Economy
319	19A	Economy
319	19B	Economy
319	19C	Economy
319	19D	Economy
319	20E	Economy
319	20F	Economy
319	21A	Economy
319	21B	Economy
319	21C	Economy
319	21D	Economy
319	21E	Economy
319	21F	Economy
320	1A	Business
320	1C	Business
320	1D	Business
320	1F	Business
320	2A	Business
320	2C	Business
320	2D	Business
319	8E	Economy
320	2F	Business
320	3A	Business
320	3C	Business
320	3D	Business
320	3F	Business
320	4A	Business
320	4C	Business
320	4D	Business
320	4F	Business
320	5A	Business
320	5C	Business
320	5D	Business
320	5F	Business
320	6A	Economy
320	6B	Economy
320	6C	Economy
320	6D	Economy
320	6E	Economy
320	6F	Economy
320	7A	Economy
320	7B	Economy
320	7C	Economy
320	7D	Economy
320	7E	Economy
320	7F	Economy
320	8A	Economy
320	8B	Economy
320	8C	Economy
320	8D	Economy
320	8E	Economy
320	8F	Economy
320	9A	Economy
320	9B	Economy
320	9C	Economy
320	9D	Economy
320	9E	Economy
320	9F	Economy
320	10A	Economy
320	10B	Economy
320	10C	Economy
320	10D	Economy
320	10E	Economy
320	10F	Economy
320	11A	Economy
320	11B	Economy
320	11C	Economy
320	11D	Economy
320	11E	Economy
320	11F	Economy
320	12A	Economy
320	12B	Economy
320	12C	Economy
320	12D	Economy
320	12E	Economy
320	12F	Economy
320	13A	Economy
320	13B	Economy
320	13C	Economy
320	13D	Economy
320	13E	Economy
320	13F	Economy
320	14A	Economy
320	14B	Economy
320	14C	Economy
320	14D	Economy
320	14E	Economy
320	14F	Economy
320	15A	Economy
320	15B	Economy
319	1A	Business
319	1C	Business
319	1D	Business
319	1F	Business
319	11C	Economy
319	11D	Economy
319	11E	Economy
319	11F	Economy
319	12A	Economy
319	12B	Economy
319	12C	Economy
319	12D	Economy
319	12E	Economy
319	12F	Economy
319	13A	Economy
319	13B	Economy
319	13C	Economy
319	13D	Economy
319	13E	Economy
319	13F	Economy
319	14A	Economy
319	14B	Economy
319	14C	Economy
319	14D	Economy
319	14E	Economy
319	14F	Economy
319	15A	Economy
319	15B	Economy
319	15C	Economy
319	15D	Economy
319	15E	Economy
319	15F	Economy
319	16A	Economy
319	16B	Economy
319	16C	Economy
319	16D	Economy
319	16E	Economy
319	16F	Economy
319	17A	Economy
319	17B	Economy
319	17C	Economy
319	19E	Economy
319	19F	Economy
319	20A	Economy
319	20B	Economy
319	20C	Economy
319	20D	Economy
320	15C	Economy
320	15D	Economy
320	15E	Economy
320	15F	Economy
320	16A	Economy
320	16B	Economy
320	16C	Economy
320	16D	Economy
320	16E	Economy
320	16F	Economy
320	17A	Economy
320	17B	Economy
320	17C	Economy
320	17D	Economy
320	17E	Economy
320	17F	Economy
320	18A	Economy
320	18B	Economy
320	18C	Economy
320	18D	Economy
320	18E	Economy
320	18F	Economy
320	19A	Economy
320	19B	Economy
320	19C	Economy
320	19D	Economy
320	19E	Economy
320	19F	Economy
320	20A	Economy
320	20B	Economy
320	20C	Economy
320	20D	Economy
320	20E	Economy
320	20F	Economy
320	21A	Economy
320	21B	Economy
320	21C	Economy
320	21D	Economy
320	21E	Economy
320	21F	Economy
320	22A	Economy
320	22B	Economy
320	22C	Economy
320	22D	Economy
320	22E	Economy
320	22F	Economy
320	23A	Economy
320	23B	Economy
320	23C	Economy
320	23D	Economy
320	23E	Economy
320	23F	Economy
320	24A	Economy
320	24B	Economy
320	24C	Economy
320	24D	Economy
320	24E	Economy
320	24F	Economy
320	25A	Economy
320	25B	Economy
320	25C	Economy
320	25D	Economy
320	25E	Economy
320	25F	Economy
321	1A	Business
321	1C	Business
321	1D	Business
321	1F	Business
321	2A	Business
321	2C	Business
321	2D	Business
321	2F	Business
321	3A	Business
321	3C	Business
321	3D	Business
321	3F	Business
321	4A	Business
321	4C	Business
321	4D	Business
321	4F	Business
321	5A	Business
321	5C	Business
321	5D	Business
321	5F	Business
321	6A	Business
321	6C	Business
321	6D	Business
321	6F	Business
321	7A	Business
321	7C	Business
321	7D	Business
321	7F	Business
321	8A	Economy
321	8B	Economy
321	8C	Economy
321	8D	Economy
321	8E	Economy
321	8F	Economy
321	9A	Economy
321	9B	Economy
321	9C	Economy
321	9D	Economy
321	9E	Economy
321	9F	Economy
321	10A	Economy
321	10B	Economy
321	10C	Economy
321	10D	Economy
321	10E	Economy
321	10F	Economy
321	11A	Economy
321	11B	Economy
321	11C	Economy
321	11D	Economy
321	11E	Economy
321	11F	Economy
321	12A	Economy
321	12B	Economy
321	12C	Economy
321	12D	Economy
321	12E	Economy
321	12F	Economy
321	13A	Economy
321	13B	Economy
321	13C	Economy
321	13D	Economy
321	13E	Economy
321	13F	Economy
321	14A	Economy
321	14B	Economy
321	14C	Economy
321	14D	Economy
321	14E	Economy
321	14F	Economy
321	15A	Economy
321	15B	Economy
321	15C	Economy
321	15D	Economy
321	15E	Economy
321	15F	Economy
321	16A	Economy
321	16B	Economy
321	16C	Economy
321	16D	Economy
321	16E	Economy
321	16F	Economy
321	17A	Economy
321	17B	Economy
321	17C	Economy
321	17D	Economy
321	17E	Economy
321	17F	Economy
321	18A	Economy
321	18B	Economy
321	18C	Economy
321	18D	Economy
321	18E	Economy
321	18F	Economy
321	19B	Economy
321	19C	Economy
321	19D	Economy
321	19E	Economy
321	20A	Economy
321	20B	Economy
321	20C	Economy
321	20D	Economy
321	20E	Economy
321	20F	Economy
321	21A	Economy
321	21B	Economy
321	21C	Economy
321	21D	Economy
321	21E	Economy
321	21F	Economy
321	22A	Economy
321	22B	Economy
321	22C	Economy
321	22D	Economy
321	22E	Economy
321	22F	Economy
321	23A	Economy
321	23B	Economy
321	23C	Economy
321	23D	Economy
321	23E	Economy
321	23F	Economy
321	24A	Economy
321	24B	Economy
321	24C	Economy
321	24D	Economy
321	24E	Economy
321	24F	Economy
321	25A	Economy
321	25B	Economy
321	25C	Economy
321	25D	Economy
321	25E	Economy
321	25F	Economy
321	26A	Economy
321	26B	Economy
321	26C	Economy
321	26D	Economy
321	26E	Economy
321	26F	Economy
321	27A	Economy
321	27B	Economy
321	27C	Economy
321	27D	Economy
321	27E	Economy
321	27F	Economy
321	28A	Economy
321	28B	Economy
321	28C	Economy
321	28D	Economy
321	28E	Economy
321	28F	Economy
321	29A	Economy
321	29B	Economy
321	29C	Economy
321	29D	Economy
321	29E	Economy
321	29F	Economy
321	30A	Economy
321	30B	Economy
321	30C	Economy
321	30D	Economy
321	30E	Economy
321	30F	Economy
321	31A	Economy
321	31B	Economy
321	31C	Economy
321	31D	Economy
321	31E	Economy
321	31F	Economy
733	1A	Business
733	1C	Business
733	1D	Business
733	1F	Business
733	2A	Business
733	2C	Business
733	2D	Business
733	2F	Business
733	3A	Business
733	3C	Business
733	3D	Business
733	3F	Business
733	4A	Economy
733	4B	Economy
733	4C	Economy
733	4D	Economy
733	4E	Economy
733	4F	Economy
733	5A	Economy
733	5B	Economy
733	5C	Economy
733	5D	Economy
733	5E	Economy
733	5F	Economy
733	6A	Economy
733	6B	Economy
733	6C	Economy
733	6D	Economy
733	6E	Economy
733	6F	Economy
733	7A	Economy
733	7B	Economy
733	7C	Economy
733	7D	Economy
733	7E	Economy
733	7F	Economy
733	8A	Economy
733	8B	Economy
733	8C	Economy
733	8D	Economy
733	8E	Economy
733	8F	Economy
733	9A	Economy
733	9B	Economy
733	9C	Economy
733	9D	Economy
733	9E	Economy
733	9F	Economy
733	10B	Economy
733	10C	Economy
733	10D	Economy
733	10E	Economy
733	11A	Economy
733	11B	Economy
733	11C	Economy
733	11D	Economy
733	11E	Economy
733	11F	Economy
733	12A	Economy
733	12B	Economy
733	12C	Economy
733	12D	Economy
733	12E	Economy
733	12F	Economy
733	13A	Economy
733	13B	Economy
733	13C	Economy
733	13D	Economy
733	13E	Economy
733	13F	Economy
733	14A	Economy
733	14B	Economy
733	14C	Economy
733	14D	Economy
733	14E	Economy
733	14F	Economy
733	15A	Economy
733	15B	Economy
733	15C	Economy
733	15D	Economy
733	15E	Economy
733	15F	Economy
733	16A	Economy
733	16B	Economy
733	16C	Economy
733	16D	Economy
733	16E	Economy
733	16F	Economy
733	17A	Economy
733	17B	Economy
733	17C	Economy
733	17D	Economy
733	17E	Economy
733	17F	Economy
733	18A	Economy
733	18B	Economy
733	18C	Economy
733	18D	Economy
733	18E	Economy
733	18F	Economy
733	19A	Economy
733	19B	Economy
733	19C	Economy
733	19D	Economy
733	19E	Economy
733	19F	Economy
733	20A	Economy
733	20B	Economy
733	20C	Economy
733	20D	Economy
733	20E	Economy
733	20F	Economy
733	21A	Economy
733	21B	Economy
733	21C	Economy
733	21D	Economy
733	21E	Economy
733	21F	Economy
733	22A	Economy
733	22B	Economy
733	22C	Economy
733	22D	Economy
733	22E	Economy
733	22F	Economy
733	23A	Economy
733	23B	Economy
733	23C	Economy
733	23D	Economy
733	23E	Economy
733	23F	Economy
763	1A	Business
763	1B	Business
763	1C	Business
763	1F	Business
763	1G	Business
763	1H	Business
763	2A	Business
763	2B	Business
763	2C	Business
763	2F	Business
763	2G	Business
763	2H	Business
763	3A	Business
763	3B	Business
763	3C	Business
763	3F	Business
763	3G	Business
763	3H	Business
763	4A	Business
763	4B	Business
763	4C	Business
763	4F	Business
763	4G	Business
763	4H	Business
763	5A	Business
763	5B	Business
763	5C	Business
763	5F	Business
763	5G	Business
763	5H	Business
763	9A	Economy
763	9B	Economy
763	9G	Economy
763	9H	Economy
763	11A	Economy
763	11B	Economy
763	11D	Economy
763	11E	Economy
763	11F	Economy
763	11G	Economy
763	11H	Economy
763	12A	Economy
763	12B	Economy
763	12D	Economy
763	12E	Economy
763	12F	Economy
763	12G	Economy
763	12H	Economy
763	13A	Economy
763	13B	Economy
763	13D	Economy
763	13E	Economy
763	13F	Economy
763	13G	Economy
763	13H	Economy
763	14A	Economy
763	14B	Economy
763	14D	Economy
763	14E	Economy
763	14F	Economy
763	14G	Economy
763	14H	Economy
763	15A	Economy
763	15B	Economy
763	15D	Economy
763	15E	Economy
763	15F	Economy
763	15G	Economy
763	15H	Economy
763	16A	Economy
763	16B	Economy
763	16D	Economy
763	16E	Economy
763	16F	Economy
763	16G	Economy
763	16H	Economy
763	17A	Economy
763	17B	Economy
763	17D	Economy
763	17E	Economy
763	17F	Economy
763	17G	Economy
763	17H	Economy
763	18A	Economy
763	18B	Economy
763	18D	Economy
763	18E	Economy
763	18F	Economy
763	18G	Economy
763	18H	Economy
763	19A	Economy
763	19B	Economy
763	19D	Economy
763	19E	Economy
763	19F	Economy
763	19G	Economy
763	19H	Economy
763	20A	Economy
763	20B	Economy
763	20D	Economy
763	20E	Economy
763	20F	Economy
763	20G	Economy
763	20H	Economy
763	21A	Economy
763	21B	Economy
763	21D	Economy
763	21E	Economy
763	21F	Economy
763	21G	Economy
763	21H	Economy
763	22A	Economy
763	22B	Economy
763	22D	Economy
763	22E	Economy
763	22F	Economy
763	22G	Economy
763	22H	Economy
763	23A	Economy
763	23B	Economy
763	23D	Economy
763	23E	Economy
763	23F	Economy
763	23G	Economy
763	23H	Economy
763	24A	Economy
763	24B	Economy
763	24D	Economy
763	24E	Economy
763	24F	Economy
763	24G	Economy
763	24H	Economy
763	25D	Economy
763	25E	Economy
763	25F	Economy
763	27A	Economy
763	27B	Economy
763	27D	Economy
763	27E	Economy
763	27F	Economy
763	27G	Economy
763	27H	Economy
763	28A	Economy
763	28B	Economy
763	28D	Economy
763	28E	Economy
763	28F	Economy
763	28G	Economy
763	28H	Economy
763	29A	Economy
763	29B	Economy
763	29D	Economy
763	29E	Economy
763	29F	Economy
763	29G	Economy
763	29H	Economy
763	30A	Economy
763	30B	Economy
763	30D	Economy
763	30E	Economy
763	30F	Economy
763	30G	Economy
763	30H	Economy
763	31A	Economy
763	31B	Economy
763	31D	Economy
763	31E	Economy
763	31F	Economy
763	31G	Economy
763	31H	Economy
763	32A	Economy
763	32B	Economy
763	32D	Economy
763	32E	Economy
763	32F	Economy
763	32G	Economy
763	32H	Economy
763	33A	Economy
763	33B	Economy
763	33D	Economy
763	33E	Economy
763	33F	Economy
763	33G	Economy
763	33H	Economy
763	34A	Economy
763	34B	Economy
763	34D	Economy
763	34E	Economy
763	34F	Economy
763	34G	Economy
763	34H	Economy
763	35A	Economy
763	35B	Economy
763	35D	Economy
763	35E	Economy
763	35F	Economy
763	35G	Economy
763	35H	Economy
763	36A	Economy
763	36B	Economy
763	36D	Economy
763	36E	Economy
763	36F	Economy
763	36G	Economy
763	36H	Economy
763	37A	Economy
763	37B	Economy
763	37D	Economy
763	37E	Economy
763	37F	Economy
763	37G	Economy
763	37H	Economy
763	38A	Economy
763	38B	Economy
763	38D	Economy
763	38E	Economy
763	38F	Economy
763	38G	Economy
763	38H	Economy
763	39D	Economy
763	39E	Economy
763	39F	Economy
773	1A	Business
773	1C	Business
773	1D	Business
773	1G	Business
773	1H	Business
773	1K	Business
773	2A	Business
773	2C	Business
773	2D	Business
773	2G	Business
773	2H	Business
773	2K	Business
773	4A	Business
773	4C	Business
773	4D	Business
773	4G	Business
773	4H	Business
773	4K	Business
773	5A	Business
773	5C	Business
773	5D	Business
773	5G	Business
773	5H	Business
773	5K	Business
773	11A	Comfort
773	11C	Comfort
773	11D	Comfort
773	11E	Comfort
773	11F	Comfort
773	11G	Comfort
773	11H	Comfort
773	11K	Comfort
773	12A	Comfort
773	12C	Comfort
773	12D	Comfort
773	12E	Comfort
773	12F	Comfort
773	12G	Comfort
773	12H	Comfort
773	12K	Comfort
773	13A	Comfort
773	13C	Comfort
773	13D	Comfort
773	13E	Comfort
773	13F	Comfort
773	13G	Comfort
773	13H	Comfort
773	13K	Comfort
773	14A	Comfort
773	14C	Comfort
773	14D	Comfort
773	14E	Comfort
773	14F	Comfort
773	14G	Comfort
773	14H	Comfort
773	14K	Comfort
773	15A	Comfort
773	15C	Comfort
773	15D	Comfort
773	15E	Comfort
773	15F	Comfort
773	15G	Comfort
773	15H	Comfort
773	15K	Comfort
773	16A	Comfort
773	16C	Comfort
773	16D	Comfort
773	16E	Comfort
773	16F	Comfort
773	16G	Comfort
773	16H	Comfort
773	16K	Comfort
773	17A	Economy
773	17C	Economy
773	17D	Economy
773	17E	Economy
773	17F	Economy
773	17G	Economy
773	17H	Economy
773	17K	Economy
773	18A	Economy
773	18B	Economy
773	18C	Economy
773	18D	Economy
773	18E	Economy
773	18F	Economy
773	18G	Economy
773	18H	Economy
773	18J	Economy
773	18K	Economy
773	19A	Economy
773	19B	Economy
773	19C	Economy
773	19D	Economy
773	19E	Economy
773	19F	Economy
773	19G	Economy
773	19H	Economy
773	19J	Economy
773	3A	Business
773	3C	Business
773	3D	Business
773	3G	Business
773	3H	Business
773	3K	Business
773	19K	Economy
773	20A	Economy
773	20B	Economy
773	20C	Economy
773	20D	Economy
773	20E	Economy
773	20F	Economy
773	20G	Economy
773	20H	Economy
773	20J	Economy
773	20K	Economy
773	21A	Economy
773	21B	Economy
773	21C	Economy
773	21D	Economy
773	21E	Economy
773	21F	Economy
773	21G	Economy
773	21H	Economy
773	21J	Economy
773	21K	Economy
773	22A	Economy
773	22B	Economy
773	22C	Economy
773	22D	Economy
773	22E	Economy
773	22F	Economy
773	22G	Economy
773	22H	Economy
773	22J	Economy
773	22K	Economy
773	23A	Economy
773	23B	Economy
773	23C	Economy
773	23D	Economy
773	23E	Economy
773	23F	Economy
773	23G	Economy
773	23H	Economy
773	23J	Economy
773	23K	Economy
773	24D	Economy
773	24E	Economy
773	24F	Economy
773	24G	Economy
773	25A	Economy
773	25B	Economy
773	25C	Economy
773	25D	Economy
773	25E	Economy
773	25F	Economy
773	25G	Economy
773	25H	Economy
773	25J	Economy
773	25K	Economy
773	26A	Economy
773	26B	Economy
773	26C	Economy
773	26D	Economy
773	26E	Economy
773	26F	Economy
773	26G	Economy
773	26H	Economy
773	26J	Economy
773	26K	Economy
773	27A	Economy
773	27B	Economy
773	27C	Economy
773	27D	Economy
773	27E	Economy
773	27F	Economy
773	27G	Economy
773	27H	Economy
773	27J	Economy
773	27K	Economy
773	28A	Economy
773	28B	Economy
773	28C	Economy
773	28D	Economy
773	28E	Economy
773	28F	Economy
773	28G	Economy
773	28H	Economy
773	28J	Economy
773	28K	Economy
773	29A	Economy
773	29B	Economy
773	29C	Economy
773	29D	Economy
773	29E	Economy
773	29F	Economy
773	29G	Economy
773	29H	Economy
773	29J	Economy
773	29K	Economy
773	30A	Economy
773	30B	Economy
773	30C	Economy
773	30D	Economy
773	30E	Economy
773	30F	Economy
773	30G	Economy
773	30H	Economy
773	30J	Economy
773	30K	Economy
773	31A	Economy
773	31B	Economy
773	31C	Economy
773	31D	Economy
773	31E	Economy
773	31F	Economy
773	31G	Economy
773	31H	Economy
773	31J	Economy
773	31K	Economy
773	32A	Economy
773	32B	Economy
773	32C	Economy
773	32D	Economy
773	32E	Economy
773	32F	Economy
773	32G	Economy
773	32H	Economy
773	32J	Economy
773	32K	Economy
773	33A	Economy
773	33B	Economy
773	33C	Economy
773	33D	Economy
773	33E	Economy
773	33F	Economy
773	33G	Economy
773	33H	Economy
773	33J	Economy
773	33K	Economy
773	34A	Economy
773	34B	Economy
773	34C	Economy
773	34D	Economy
773	34E	Economy
773	34F	Economy
773	34G	Economy
773	34H	Economy
773	34J	Economy
773	34K	Economy
773	35A	Economy
773	35B	Economy
773	35C	Economy
773	35D	Economy
773	35E	Economy
773	35F	Economy
773	35G	Economy
773	35H	Economy
773	35J	Economy
773	35K	Economy
773	36A	Economy
773	36B	Economy
773	36C	Economy
773	36D	Economy
773	36E	Economy
773	36F	Economy
773	36G	Economy
773	36H	Economy
773	36J	Economy
773	36K	Economy
773	37A	Economy
773	37B	Economy
773	37C	Economy
773	37D	Economy
773	37E	Economy
773	37F	Economy
773	37G	Economy
773	37H	Economy
773	37J	Economy
773	37K	Economy
773	38A	Economy
773	38B	Economy
773	38C	Economy
773	38H	Economy
773	38J	Economy
773	38K	Economy
773	39A	Economy
773	39B	Economy
773	39C	Economy
773	39D	Economy
773	39E	Economy
773	39F	Economy
773	39G	Economy
773	39H	Economy
773	39J	Economy
773	39K	Economy
773	40A	Economy
773	40B	Economy
773	40C	Economy
773	40D	Economy
773	40E	Economy
773	40F	Economy
773	40G	Economy
773	40H	Economy
773	40J	Economy
773	40K	Economy
773	41A	Economy
773	41B	Economy
773	41C	Economy
773	41D	Economy
773	41E	Economy
773	41F	Economy
773	41G	Economy
773	41H	Economy
773	41J	Economy
773	41K	Economy
773	42A	Economy
773	42B	Economy
773	42C	Economy
773	42D	Economy
773	42E	Economy
773	42F	Economy
773	42G	Economy
773	42H	Economy
773	42J	Economy
773	42K	Economy
773	43A	Economy
773	43B	Economy
773	43C	Economy
773	43D	Economy
773	43E	Economy
773	43F	Economy
773	43G	Economy
773	43H	Economy
773	43J	Economy
773	43K	Economy
773	44A	Economy
773	44B	Economy
773	44C	Economy
773	44D	Economy
773	44E	Economy
773	44F	Economy
773	44G	Economy
773	44H	Economy
773	44J	Economy
773	44K	Economy
773	45A	Economy
773	45B	Economy
773	45C	Economy
773	45D	Economy
773	45E	Economy
773	45F	Economy
773	45G	Economy
773	45H	Economy
773	45J	Economy
773	45K	Economy
773	46A	Economy
773	46B	Economy
773	46C	Economy
773	46D	Economy
773	46E	Economy
773	46F	Economy
773	46G	Economy
773	46H	Economy
773	46J	Economy
773	46K	Economy
773	47A	Economy
773	47C	Economy
773	47D	Economy
773	47E	Economy
773	49E	Economy
773	49F	Economy
773	49G	Economy
773	49H	Economy
773	49K	Economy
773	50A	Economy
773	50C	Economy
773	50D	Economy
773	50E	Economy
773	50F	Economy
773	50G	Economy
773	50H	Economy
773	50K	Economy
773	51D	Economy
773	51E	Economy
773	51F	Economy
773	51G	Economy
CN1	1A	Economy
CN1	1B	Economy
CN1	2A	Economy
CN1	2B	Economy
CN1	3A	Economy
CN1	3B	Economy
CN1	4A	Economy
CN1	4B	Economy
CN1	5A	Economy
CN1	5B	Economy
CN1	6A	Economy
CN1	6B	Economy
CR2	1A	Economy
CR2	1B	Economy
CR2	1C	Economy
CR2	1D	Economy
CR2	2A	Economy
CR2	2B	Economy
CR2	2C	Economy
CR2	2D	Economy
CR2	3A	Economy
CR2	3B	Economy
CR2	3C	Economy
CR2	3D	Economy
CR2	4A	Economy
CR2	4B	Economy
CR2	4C	Economy
CR2	4D	Economy
CR2	5A	Economy
CR2	5B	Economy
CR2	5C	Economy
CR2	5D	Economy
CR2	6A	Economy
CR2	6B	Economy
CR2	6C	Economy
CR2	6D	Economy
CR2	7A	Economy
CR2	7B	Economy
CR2	7C	Economy
CR2	7D	Economy
CR2	18A	Economy
CR2	18B	Economy
CR2	18C	Economy
CR2	18D	Economy
CR2	19A	Economy
CR2	19B	Economy
CR2	19C	Economy
CR2	19D	Economy
CR2	20A	Economy
CR2	20B	Economy
CR2	20C	Economy
CR2	20D	Economy
CR2	21A	Economy
CR2	21B	Economy
CR2	21C	Economy
CR2	21D	Economy
CR2	22A	Economy
CR2	22B	Economy
CR2	22C	Economy
CR2	22D	Economy
CR2	23A	Economy
CR2	23B	Economy
SU9	1A	Business
SU9	1C	Business
SU9	1D	Business
SU9	1F	Business
SU9	2A	Business
SU9	2C	Business
SU9	2D	Business
SU9	2F	Business
SU9	3A	Business
SU9	3C	Business
SU9	3D	Business
SU9	3F	Business
SU9	4A	Economy
SU9	4C	Economy
SU9	4D	Economy
SU9	4E	Economy
SU9	4F	Economy
SU9	5A	Economy
SU9	5C	Economy
SU9	5D	Economy
SU9	5E	Economy
SU9	5F	Economy
SU9	6A	Economy
SU9	6C	Economy
SU9	6D	Economy
SU9	6E	Economy
SU9	6F	Economy
SU9	7A	Economy
SU9	7C	Economy
SU9	7D	Economy
SU9	7E	Economy
SU9	7F	Economy
SU9	8A	Economy
SU9	8C	Economy
SU9	8D	Economy
SU9	8E	Economy
SU9	8F	Economy
SU9	9A	Economy
SU9	9C	Economy
SU9	9D	Economy
SU9	9E	Economy
SU9	9F	Economy
SU9	10A	Economy
SU9	10C	Economy
SU9	10D	Economy
SU9	10E	Economy
SU9	10F	Economy
SU9	11A	Economy
SU9	11C	Economy
SU9	11D	Economy
SU9	11E	Economy
SU9	11F	Economy
SU9	12A	Economy
SU9	12C	Economy
SU9	12D	Economy
SU9	12E	Economy
SU9	12F	Economy
SU9	13A	Economy
SU9	13C	Economy
SU9	13D	Economy
SU9	13E	Economy
SU9	13F	Economy
SU9	14A	Economy
SU9	14C	Economy
SU9	14D	Economy
SU9	14E	Economy
SU9	14F	Economy
SU9	15A	Economy
SU9	15C	Economy
SU9	15D	Economy
SU9	15E	Economy
SU9	15F	Economy
SU9	16A	Economy
SU9	16C	Economy
SU9	16D	Economy
SU9	16E	Economy
SU9	16F	Economy
SU9	17A	Economy
SU9	17C	Economy
SU9	17D	Economy
SU9	17E	Economy
SU9	17F	Economy
SU9	18A	Economy
SU9	18C	Economy
SU9	18D	Economy
SU9	18E	Economy
SU9	18F	Economy
SU9	19A	Economy
SU9	19C	Economy
SU9	19D	Economy
SU9	19E	Economy
SU9	19F	Economy
SU9	20A	Economy
SU9	20C	Economy
SU9	20D	Economy
SU9	20E	Economy
SU9	20F	Economy
773	47F	Economy
773	47G	Economy
773	47H	Economy
773	47K	Economy
773	48A	Economy
773	48C	Economy
773	48D	Economy
773	48E	Economy
773	48F	Economy
773	48G	Economy
773	48H	Economy
773	48K	Economy
773	49A	Economy
773	49C	Economy
773	49D	Economy
\.


--
-- Data for Name: ticket_flights; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY ticket_flights (ticket_no, flight_id, fare_conditions, amount) FROM stdin;
0005432159776	30625	Business	42100.00
0005435212351	30625	Business	42100.00
0005435212386	30625	Business	42100.00
0005435212381	30625	Business	42100.00
0005432211370	30625	Business	42100.00
0005435212357	30625	Comfort	23900.00
0005435212360	30625	Comfort	23900.00
0005435212393	30625	Comfort	23900.00
0005435212374	30625	Comfort	23900.00
0005435212365	30625	Comfort	23900.00
0005435212378	30625	Comfort	23900.00
0005435212362	30625	Comfort	23900.00
0005435212334	30625	Comfort	23900.00
0005435212329	30625	Comfort	23900.00
0005435212370	30625	Comfort	23900.00
0005435212328	30625	Comfort	23900.00
0005435725513	30625	Comfort	23900.00
0005435630915	30625	Comfort	23900.00
0005435212388	30625	Economy	14000.00
0005432159775	30625	Economy	14000.00
0005435212382	30625	Economy	14000.00
0005432211367	30625	Economy	14000.00
0005435212354	30625	Economy	14000.00
0005432211372	30625	Economy	14000.00
0005435212344	30625	Economy	14000.00
0005435212372	30625	Economy	14000.00
0005435212355	30625	Economy	14000.00
0005435212376	30625	Economy	14000.00
0005435212385	30625	Economy	15400.00
0005435725512	30625	Economy	14000.00
0005435212336	30625	Economy	14000.00
0005435212367	30625	Economy	14000.00
0005435212359	30625	Economy	14000.00
0005435212364	30625	Economy	14000.00
0005435725514	30625	Economy	14000.00
0005435212391	30625	Economy	14000.00
0005435212338	30625	Economy	14000.00
0005435212366	30625	Economy	14000.00
0005435212347	30625	Economy	14000.00
0005432211366	30625	Economy	14000.00
0005435212373	30625	Economy	14000.00
0005435212383	30625	Economy	14000.00
0005433656614	30625	Economy	14000.00
0005435212395	30625	Economy	14000.00
0005435212343	30625	Economy	14000.00
0005435212371	30625	Economy	14000.00
0005435212377	30625	Economy	14000.00
0005435212330	30625	Economy	14000.00
0005435212358	30625	Economy	14000.00
0005432211371	30625	Economy	14000.00
0005435212368	30625	Economy	14000.00
0005435212335	30625	Economy	14000.00
0005435212340	30625	Economy	14000.00
0005435212363	30625	Economy	14000.00
0005435212380	30625	Economy	14000.00
0005435212345	30625	Economy	14000.00
0005435212375	30625	Economy	14000.00
0005435212350	30625	Economy	14000.00
0005432211365	30625	Economy	14000.00
0005435212331	30625	Economy	14000.00
0005435212353	30625	Economy	14000.00
0005435630916	30625	Economy	14000.00
0005435212337	30625	Economy	14000.00
0005432211368	30625	Economy	14000.00
0005432211369	30625	Economy	14000.00
0005435212356	30625	Economy	14000.00
0005435212332	30625	Economy	15400.00
0005435212348	30625	Economy	15400.00
0005435212352	30625	Economy	14000.00
0005435212394	30625	Economy	14000.00
0005435212389	30625	Economy	14000.00
0005435212392	30625	Economy	14000.00
0005435212369	30625	Economy	14000.00
0005435212379	30625	Economy	14000.00
0005435725516	30625	Economy	14000.00
0005435212396	30625	Economy	14000.00
0005432159777	30625	Economy	14000.00
0005433656613	30625	Economy	14000.00
0005435725515	30625	Economy	14000.00
0005435212346	30625	Economy	14000.00
0005435212390	30625	Economy	14000.00
0005435212361	30625	Economy	14000.00
0005435212341	30625	Economy	14000.00
0005435212349	30625	Economy	14000.00
0005435725511	30625	Economy	14000.00
0005432159778	30625	Economy	14000.00
0005435212384	30625	Economy	14000.00
0005435630914	30625	Economy	14000.00
0005435212339	30625	Economy	14000.00
0005435212333	30625	Economy	14000.00
0005435212387	30625	Economy	14000.00
0005435212342	30625	Economy	14000.00
0005433367244	24836	Business	9800.00
0005433367229	24836	Business	9800.00
0005433367230	24836	Business	9800.00
0005433367245	24836	Business	9800.00
0005433367256	24836	Business	9800.00
0005433367225	24836	Business	9800.00
0005433367228	24836	Economy	3300.00
0005433367236	24836	Economy	3300.00
0005433367252	24836	Economy	3300.00
0005433367243	24836	Economy	3300.00
0005433367222	24836	Economy	3300.00
0005433367234	24836	Economy	3300.00
0005433367231	24836	Economy	3300.00
0005433367218	24836	Economy	3600.00
0005433367224	24836	Economy	3600.00
0005433367237	24836	Economy	3300.00
0005433367255	24836	Economy	3300.00
0005433367246	24836	Economy	3300.00
0005433367227	24836	Economy	3300.00
0005433367233	24836	Economy	3300.00
0005433367242	24836	Economy	3300.00
0005433367248	24836	Economy	3300.00
0005433367223	24836	Economy	3300.00
0005433367241	24836	Economy	3300.00
0005433367221	24836	Economy	3300.00
0005433367258	24836	Economy	3300.00
0005433367240	24836	Economy	3300.00
0005433367226	24836	Economy	3300.00
0005433367247	24836	Economy	3300.00
0005433367235	24836	Economy	3300.00
0005433367257	24836	Economy	3300.00
0005433367251	24836	Economy	3300.00
0005433367239	24836	Economy	3300.00
0005433367220	24836	Economy	3300.00
0005433367250	24836	Economy	3300.00
0005433367219	24836	Economy	3300.00
0005433367253	24836	Economy	3300.00
0005433367232	24836	Economy	3300.00
0005433367249	24836	Economy	3300.00
0005433367238	24836	Economy	3300.00
0005433367254	24836	Economy	3300.00
0005434979262	2055	Economy	10500.00
0005434979271	2055	Economy	10500.00
0005434979277	2055	Economy	9500.00
0005434979252	2055	Economy	9500.00
0005434979282	2055	Economy	9500.00
0005434979273	2055	Economy	9500.00
0005434979280	2055	Economy	9500.00
0005434979255	2055	Economy	9500.00
0005434979269	2055	Economy	9500.00
0005434979275	2055	Economy	9500.00
0005435801642	2055	Economy	9500.00
0005434979279	2055	Economy	9500.00
0005434979267	2055	Economy	9500.00
0005434979254	2055	Economy	9500.00
0005434979264	2055	Economy	9500.00
0005434979263	2055	Economy	9500.00
0005434979276	2055	Economy	9500.00
0005434979270	2055	Economy	9500.00
0005434979258	2055	Economy	9500.00
0005434979256	2055	Economy	9500.00
0005434979265	2055	Economy	9500.00
0005434979261	2055	Economy	9500.00
0005434979253	2055	Economy	9500.00
0005434979259	2055	Economy	9500.00
0005435801643	2055	Economy	9500.00
0005434979272	2055	Economy	9500.00
0005434979260	2055	Economy	9500.00
0005434979274	2055	Economy	9500.00
0005434979268	2055	Economy	9500.00
0005434979257	2055	Economy	9500.00
0005434979278	2055	Economy	9500.00
0005434979266	2055	Economy	9500.00
0005435801644	2055	Economy	9500.00
0005434979281	2055	Economy	9500.00
0005434952466	2575	Economy	5300.00
0005434952464	2575	Economy	5300.00
0005434952465	2575	Economy	5300.00
0005434952467	2575	Economy	5300.00
0005433256382	28205	Economy	5300.00
0005433256381	28205	Economy	5300.00
0005433111467	19732	Economy	8700.00
0005433111468	19732	Economy	8700.00
0005433112350	19732	Economy	8700.00
0005433111469	19732	Economy	8700.00
0005434190367	19092	Economy	26000.00
0005434190368	19092	Economy	23600.00
0005433534460	6786	Economy	10900.00
0005433534461	6786	Economy	9900.00
0005433534463	6786	Economy	9900.00
0005433538721	6786	Economy	9900.00
0005433538717	6786	Economy	9900.00
0005433538718	6786	Economy	9900.00
0005433534462	6786	Economy	9900.00
0005433538720	6786	Economy	9900.00
0005433538719	6786	Economy	9900.00
0005433538722	6786	Economy	9900.00
0005433538723	6786	Economy	9900.00
0005433538724	6786	Economy	9900.00
0005435259680	25029	Economy	9900.00
0005435259678	25029	Economy	9900.00
0005435259681	25029	Economy	9900.00
0005435259679	25029	Economy	9900.00
0005433511804	823	Economy	16100.00
0005433511803	823	Economy	14600.00
0005433511809	823	Economy	14600.00
0005433511807	823	Economy	14600.00
0005433511802	823	Economy	14600.00
0005433511801	823	Economy	14600.00
0005433511808	823	Economy	14600.00
0005433511806	823	Economy	14600.00
0005433511805	823	Economy	14600.00
0005432922454	16157	Economy	16100.00
0005432922455	16157	Economy	14600.00
0005432922453	16157	Economy	14600.00
0005433475633	4021	Economy	13500.00
0005433475632	4021	Economy	12300.00
0005433475631	4021	Economy	12300.00
0005433475630	4021	Economy	12300.00
0005435696849	3660	Economy	7900.00
0005435696846	3660	Economy	7900.00
0005434950451	3660	Economy	7200.00
0005435696864	3660	Economy	7200.00
0005435696862	3660	Economy	7200.00
0005435696847	3660	Economy	7200.00
0005435696850	3660	Economy	7200.00
0005435696866	3660	Economy	7200.00
0005435696843	3660	Economy	7200.00
0005435696863	3660	Economy	7200.00
0005435696851	3660	Economy	7200.00
0005434950450	3660	Economy	7200.00
0005435696870	3660	Economy	7200.00
0005434950452	3660	Economy	7200.00
0005435696859	3660	Economy	7200.00
0005435696871	3660	Economy	7200.00
0005435696855	3660	Economy	7200.00
0005435696869	3660	Economy	7200.00
0005435696852	3660	Economy	7200.00
0005435696857	3660	Economy	7200.00
0005435696853	3660	Economy	7200.00
0005435696845	3660	Economy	7200.00
0005435696844	3660	Economy	7200.00
0005435696856	3660	Economy	7200.00
0005435696858	3660	Economy	7200.00
0005435696865	3660	Economy	7200.00
0005435696848	3660	Economy	7200.00
0005435696861	3660	Economy	7200.00
0005435696860	3660	Economy	7200.00
0005435696854	3660	Economy	7200.00
0005435696867	3660	Economy	7200.00
0005435696868	3660	Economy	7200.00
0005435916119	16272	Economy	7200.00
0005435916118	16272	Economy	7200.00
0005432609659	3993	Economy	21300.00
0005432609661	3993	Economy	21300.00
0005432607495	3993	Economy	21300.00
0005434606760	3993	Economy	21300.00
0005432609658	3993	Economy	19300.00
0005434606759	3993	Economy	19300.00
0005434606763	3993	Economy	19300.00
0005433519378	3993	Economy	19300.00
0005432607494	3993	Economy	19300.00
0005433519379	3993	Economy	19300.00
0005434604838	3993	Economy	19300.00
0005434606761	3993	Economy	19300.00
0005433519377	3993	Economy	19300.00
0005432609660	3993	Economy	19300.00
0005434604839	3993	Economy	19300.00
0005434606762	3993	Economy	19300.00
0005433519380	3993	Economy	19300.00
0005432607496	3993	Economy	19300.00
0005434604837	3993	Economy	19300.00
0005435853578	22080	Economy	21300.00
0005435853580	22080	Economy	19300.00
0005435853579	22080	Economy	19300.00
0005435628670	728	Economy	3700.00
0005435628672	728	Economy	3700.00
0005435628669	728	Economy	3700.00
0005435628671	728	Economy	3700.00
0005433348889	15900	Economy	3700.00
0005433348891	15900	Economy	3700.00
0005433348887	15900	Economy	3700.00
0005433348888	15900	Economy	3700.00
0005433348890	15900	Economy	3700.00
0005433159275	17677	Economy	7100.00
0005433159274	17677	Economy	7100.00
0005433159276	17677	Economy	7100.00
0005435132700	7862	Economy	5400.00
0005435132696	7862	Economy	5400.00
0005435132694	7862	Economy	5400.00
0005435132695	7862	Economy	5400.00
0005435132698	7862	Economy	5400.00
0005435132697	7862	Economy	5400.00
0005435132699	7862	Economy	5400.00
0005435132703	7862	Economy	5400.00
0005435132704	7862	Economy	5400.00
0005435132702	7862	Economy	5400.00
0005435132701	7862	Economy	5400.00
0005435383058	33092	Economy	5900.00
0005435383057	33092	Economy	5400.00
0005435383056	33092	Economy	5400.00
0005435383059	33092	Economy	5400.00
0005435383055	33092	Economy	5400.00
0005435160112	7477	Economy	12500.00
0005435160111	7477	Economy	12500.00
0005435160106	7477	Economy	12500.00
0005435160104	7477	Economy	12500.00
0005435160109	7477	Economy	12500.00
0005435160103	7477	Economy	12500.00
0005435160105	7477	Economy	12500.00
0005435160110	7477	Economy	12500.00
0005435160113	7477	Economy	12500.00
0005435160107	7477	Economy	12500.00
0005435160108	7477	Economy	12500.00
0005435390116	29573	Economy	13800.00
0005435390120	29573	Economy	12500.00
0005435390121	29573	Economy	12500.00
0005435390122	29573	Economy	12500.00
0005435390118	29573	Economy	12500.00
0005435390117	29573	Economy	12500.00
0005435390119	29573	Economy	12500.00
0005434503467	6547	Business	48400.00
0005434503492	6547	Business	48400.00
0005434503487	6547	Economy	16100.00
0005434503465	6547	Economy	16100.00
0005434503495	6547	Economy	16100.00
0005434503472	6547	Economy	16100.00
0005434503463	6547	Economy	16100.00
0005434503469	6547	Economy	16100.00
0005434503460	6547	Economy	16100.00
0005434503488	6547	Economy	17800.00
0005434503484	6547	Economy	17800.00
0005434503490	6547	Economy	17800.00
0005434503468	6547	Economy	17800.00
0005434503482	6547	Economy	16100.00
0005435103797	6547	Economy	16100.00
0005435103796	6547	Economy	16100.00
0005434503479	6547	Economy	16100.00
0005435103802	6547	Economy	16100.00
0005434503471	6547	Economy	16100.00
0005434503494	6547	Economy	16100.00
0005434503483	6547	Economy	16100.00
0005434503474	6547	Economy	16100.00
0005434503464	6547	Economy	16100.00
0005434503476	6547	Economy	16100.00
0005435103803	6547	Economy	16100.00
0005434503462	6547	Economy	16100.00
0005434503459	6547	Economy	16100.00
0005435103799	6547	Economy	16100.00
0005434503458	6547	Economy	16100.00
0005434503466	6547	Economy	16100.00
0005434503478	6547	Economy	16100.00
0005434503470	6547	Economy	16100.00
0005434503486	6547	Economy	16100.00
0005434503489	6547	Economy	16100.00
0005434503491	6547	Economy	16100.00
0005435103793	6547	Economy	16100.00
0005435103795	6547	Economy	16100.00
0005434503485	6547	Economy	16100.00
0005434503477	6547	Economy	16100.00
0005434503461	6547	Economy	16100.00
0005434503473	6547	Economy	16100.00
0005434503496	6547	Economy	16100.00
0005435103794	6547	Economy	16100.00
0005434503475	6547	Economy	16100.00
0005434503493	6547	Economy	16100.00
0005435103801	6547	Economy	16100.00
0005435103798	6547	Economy	16100.00
0005435103800	6547	Economy	16100.00
0005434503481	6547	Economy	16100.00
0005434503480	6547	Economy	16100.00
0005435652274	1654	Business	50000.00
0005435652282	1654	Business	50000.00
0005435652261	1654	Business	50000.00
0005435652269	1654	Business	50000.00
0005435652292	1654	Business	50000.00
0005435652275	1654	Economy	16700.00
0005435652281	1654	Economy	16700.00
0005435652283	1654	Economy	16700.00
0005435652263	1654	Economy	16700.00
0005435652260	1654	Economy	18300.00
0005435652264	1654	Economy	18300.00
0005435652278	1654	Economy	16700.00
0005435652266	1654	Economy	16700.00
0005435652272	1654	Economy	16700.00
0005435652250	1654	Economy	16700.00
0005435652254	1654	Economy	16700.00
0005435652268	1654	Economy	16700.00
0005435652253	1654	Economy	16700.00
0005435652279	1654	Economy	16700.00
0005435652276	1654	Economy	16700.00
0005435652251	1654	Economy	16700.00
0005435652273	1654	Economy	16700.00
0005435652252	1654	Economy	16700.00
0005435652295	1654	Economy	16700.00
0005435652284	1654	Economy	16700.00
0005435652259	1654	Economy	16700.00
0005435652265	1654	Economy	16700.00
0005435652262	1654	Economy	16700.00
0005435652267	1654	Economy	16700.00
0005435652280	1654	Economy	16700.00
0005435652294	1654	Economy	16700.00
0005435652296	1654	Economy	16700.00
0005435652257	1654	Economy	16700.00
0005435652288	1654	Economy	16700.00
0005435652271	1654	Economy	16700.00
0005435652285	1654	Economy	16700.00
0005435652258	1654	Economy	16700.00
0005435652286	1654	Economy	16700.00
0005435652291	1654	Economy	16700.00
0005435652256	1654	Economy	16700.00
0005435652293	1654	Economy	16700.00
0005435652270	1654	Economy	16700.00
0005435652289	1654	Economy	16700.00
0005435652287	1654	Economy	16700.00
0005435652290	1654	Economy	16700.00
0005435652277	1654	Economy	16700.00
0005435652255	1654	Economy	16700.00
0005433367257	21707	Business	50000.00
0005433367244	21707	Business	50000.00
0005433367258	21707	Business	50000.00
0005433367221	21707	Business	50000.00
0005433367224	21707	Economy	16700.00
0005433367218	21707	Economy	16700.00
0005433367240	21707	Economy	16700.00
0005433367222	21707	Economy	18300.00
0005433367227	21707	Economy	18300.00
0005433367252	21707	Economy	18300.00
0005433367256	21707	Economy	16700.00
0005433367245	21707	Economy	16700.00
0005433367247	21707	Economy	16700.00
0005433367248	21707	Economy	16700.00
0005433367251	21707	Economy	16700.00
0005433367235	21707	Economy	16700.00
0005433367246	21707	Economy	16700.00
0005433367237	21707	Economy	16700.00
0005433367242	21707	Economy	16700.00
0005433367241	21707	Economy	16700.00
0005433367234	21707	Economy	16700.00
0005433367253	21707	Economy	16700.00
0005433367250	21707	Economy	16700.00
0005433367255	21707	Economy	16700.00
0005433367231	21707	Economy	16700.00
0005433367228	21707	Economy	16700.00
0005433367220	21707	Economy	16700.00
0005433367238	21707	Economy	16700.00
0005433367219	21707	Economy	16700.00
0005433367225	21707	Economy	16700.00
0005433367226	21707	Economy	16700.00
0005433367236	21707	Economy	16700.00
0005433367230	21707	Economy	16700.00
0005433367254	21707	Economy	16700.00
0005433367239	21707	Economy	16700.00
0005433367229	21707	Economy	16700.00
0005433367232	21707	Economy	16700.00
0005433367233	21707	Economy	16700.00
0005433367249	21707	Economy	16700.00
0005433367243	21707	Economy	16700.00
0005433367223	21707	Economy	16700.00
0005433985127	4135	Business	21500.00
0005433985129	4135	Business	21500.00
0005433985123	4135	Business	21500.00
0005433985126	4135	Business	21500.00
0005433985160	4135	Business	21500.00
0005435788725	4135	Business	21500.00
0005433985140	4135	Business	21500.00
0005433985155	4135	Business	21500.00
0005433985137	4135	Economy	7200.00
0005433985159	4135	Economy	7200.00
0005433985125	4135	Economy	7200.00
0005433985154	4135	Economy	7200.00
0005433985161	4135	Economy	7200.00
0005433985122	4135	Economy	7200.00
0005433985136	4135	Economy	7200.00
0005433985148	4135	Economy	7200.00
0005433985143	4135	Economy	7200.00
0005433985131	4135	Economy	7200.00
0005433985133	4135	Economy	7200.00
0005433985158	4135	Economy	7200.00
0005433985141	4135	Economy	7200.00
0005433985134	4135	Economy	7200.00
0005433985139	4135	Economy	7200.00
0005435788726	4135	Economy	7200.00
0005433985145	4135	Economy	7200.00
0005433985152	4135	Economy	7200.00
0005433985144	4135	Economy	7200.00
0005433985147	4135	Economy	7200.00
0005433985146	4135	Economy	7200.00
0005435788727	4135	Economy	7200.00
0005433985124	4135	Economy	7200.00
0005435788728	4135	Economy	7200.00
0005433985153	4135	Economy	7200.00
0005433985156	4135	Economy	7200.00
0005433985130	4135	Economy	7200.00
0005433985150	4135	Economy	7200.00
0005433985132	4135	Economy	7200.00
0005433985151	4135	Economy	7200.00
0005433985157	4135	Economy	7200.00
0005433985135	4135	Economy	7200.00
0005433985142	4135	Economy	7200.00
0005433985128	4135	Economy	7200.00
0005433985149	4135	Economy	7200.00
0005433985138	4135	Economy	7200.00
0005433168301	21332	Economy	15500.00
0005433168299	21332	Economy	15500.00
0005433168302	21332	Economy	15500.00
0005433168300	21332	Economy	15500.00
0005432869415	17856	Business	18000.00
0005432869416	17856	Economy	6000.00
0005432869413	17856	Economy	6000.00
0005434151654	17856	Economy	6000.00
0005434151656	17856	Economy	6000.00
0005432869412	17856	Economy	6000.00
0005434151655	17856	Economy	6000.00
0005432869414	17856	Economy	6000.00
0005432327913	3108	Business	16100.00
0005432327892	3108	Business	16100.00
0005432327911	3108	Business	16100.00
0005432327914	3108	Business	16100.00
0005432287105	3108	Economy	5400.00
0005432287104	3108	Economy	5400.00
0005432287101	3108	Economy	5400.00
0005432327915	3108	Economy	5400.00
0005432327904	3108	Economy	5400.00
0005432327907	3108	Economy	5400.00
0005432327925	3108	Economy	5900.00
0005432327930	3108	Economy	5900.00
0005432327894	3108	Economy	5900.00
0005432287100	3108	Economy	5900.00
0005433438767	3108	Economy	5900.00
0005432327931	3108	Economy	5400.00
0005432327923	3108	Economy	5400.00
0005432327898	3108	Economy	5400.00
0005432327920	3108	Economy	5400.00
0005432327928	3108	Economy	5400.00
0005432327893	3108	Economy	5400.00
0005432327921	3108	Economy	5400.00
0005432327934	3108	Economy	5400.00
0005432327912	3108	Economy	5400.00
0005432327901	3108	Economy	5400.00
0005432327929	3108	Economy	5400.00
0005432327932	3108	Economy	5400.00
0005432287099	3108	Economy	5400.00
0005432327924	3108	Economy	5400.00
0005432327903	3108	Economy	5400.00
0005433438765	3108	Economy	5400.00
0005432327890	3108	Economy	5400.00
0005432327896	3108	Economy	5400.00
0005433438764	3108	Economy	5400.00
0005433438763	3108	Economy	5400.00
0005432327917	3108	Economy	5400.00
0005432327906	3108	Economy	5400.00
0005432327910	3108	Economy	5400.00
0005432287103	3108	Economy	5400.00
0005432327919	3108	Economy	5400.00
0005432327895	3108	Economy	5400.00
0005432327926	3108	Economy	5400.00
0005432327899	3108	Economy	5400.00
0005432327902	3108	Economy	5400.00
0005432327897	3108	Economy	5400.00
0005432327909	3108	Economy	5400.00
0005432287102	3108	Economy	5400.00
0005433438766	3108	Economy	5400.00
0005432327937	3108	Economy	5400.00
0005432327891	3108	Economy	5400.00
0005432327922	3108	Economy	5400.00
0005432327905	3108	Economy	5400.00
0005432327935	3108	Economy	5400.00
0005432327900	3108	Economy	5400.00
0005432327927	3108	Economy	5400.00
0005432327936	3108	Economy	5400.00
0005432327918	3108	Economy	5400.00
0005432327908	3108	Economy	5400.00
0005432327916	3108	Economy	5400.00
0005432327933	3108	Economy	5400.00
0005432905025	31103	Business	16100.00
0005432054254	31103	Economy	5400.00
0005432905022	31103	Economy	5400.00
0005432905024	31103	Economy	5400.00
0005432905023	31103	Economy	5400.00
0005432054252	31103	Economy	5400.00
0005432905019	31103	Economy	5400.00
0005432905020	31103	Economy	5400.00
0005432905021	31103	Economy	5400.00
0005432054253	31103	Economy	5400.00
0005434309500	6223	Business	124600.00
0005434309510	6223	Business	124600.00
0005432146164	6223	Business	124600.00
0005434309502	6223	Business	124600.00
0005435998953	6223	Economy	41500.00
0005435998957	6223	Economy	41500.00
0005434309511	6223	Economy	41500.00
0005435998963	6223	Economy	41500.00
0005434309508	6223	Economy	41500.00
0005434309506	6223	Economy	41500.00
0005435998956	6223	Economy	41500.00
0005435998965	6223	Economy	41500.00
0005434309509	6223	Economy	41500.00
0005435998964	6223	Economy	45700.00
0005435998952	6223	Economy	45700.00
0005435998959	6223	Economy	41500.00
0005434309501	6223	Economy	41500.00
0005435998962	6223	Economy	41500.00
0005434309513	6223	Economy	41500.00
0005434309512	6223	Economy	41500.00
0005435998958	6223	Economy	41500.00
0005435998954	6223	Economy	41500.00
0005432146163	6223	Economy	41500.00
0005435998966	6223	Economy	41500.00
0005435998961	6223	Economy	41500.00
0005435998960	6223	Economy	41500.00
0005434309505	6223	Economy	41500.00
0005434309507	6223	Economy	41500.00
0005434309503	6223	Economy	41500.00
0005435998967	6223	Economy	41500.00
0005434309504	6223	Economy	41500.00
0005432146165	6223	Economy	41500.00
0005435998955	6223	Economy	41500.00
0005435998951	6223	Economy	41500.00
0005435296942	19528	Business	124600.00
0005435296939	19528	Business	124600.00
0005435296941	19528	Economy	41500.00
0005435296938	19528	Economy	41500.00
0005435296943	19528	Economy	41500.00
0005435296940	19528	Economy	41500.00
0005433158094	17534	Economy	12300.00
0005433158093	17534	Economy	12300.00
0005435501945	1567	Business	86000.00
0005435508176	1567	Business	86000.00
0005435501931	1567	Business	86000.00
0005434565681	1567	Business	86000.00
0005435501933	1567	Business	86000.00
0005434565690	1567	Business	86000.00
0005435517599	1567	Business	86000.00
0005435508167	1567	Business	86000.00
0005435501932	1567	Economy	28700.00
0005435501936	1567	Economy	28700.00
0005435501950	1567	Economy	28700.00
0005434565688	1567	Economy	28700.00
0005435517590	1567	Economy	28700.00
0005435517605	1567	Economy	28700.00
0005435508174	1567	Economy	31500.00
0005435501947	1567	Economy	31500.00
0005432291890	1567	Economy	31500.00
0005435508166	1567	Economy	31500.00
0005435501941	1567	Economy	28700.00
0005434565686	1567	Economy	28700.00
0005435517602	1567	Economy	28700.00
0005435517591	1567	Economy	28700.00
0005434565678	1567	Economy	28700.00
0005435517595	1567	Economy	28700.00
0005435501937	1567	Economy	28700.00
0005435508164	1567	Economy	28700.00
0005434565684	1567	Economy	28700.00
0005435501943	1567	Economy	28700.00
0005434565687	1567	Economy	28700.00
0005435517604	1567	Economy	28700.00
0005435501948	1567	Economy	28700.00
0005435517596	1567	Economy	28700.00
0005435501946	1567	Economy	28700.00
0005435517603	1567	Economy	28700.00
0005432291889	1567	Economy	28700.00
0005435517594	1567	Economy	28700.00
0005435508173	1567	Economy	28700.00
0005435501944	1567	Economy	28700.00
0005434565679	1567	Economy	28700.00
0005435508171	1567	Economy	28700.00
0005435517600	1567	Economy	28700.00
0005434565682	1567	Economy	28700.00
0005435508170	1567	Economy	28700.00
0005435501952	1567	Economy	28700.00
0005435501935	1567	Economy	28700.00
0005435508165	1567	Economy	28700.00
0005435501938	1567	Economy	28700.00
0005435508175	1567	Economy	28700.00
0005434565689	1567	Economy	28700.00
0005435517585	1567	Economy	28700.00
0005435517601	1567	Economy	28700.00
0005435501949	1567	Economy	28700.00
0005435517587	1567	Economy	28700.00
0005435517598	1567	Economy	28700.00
0005434565691	1567	Economy	28700.00
0005435517589	1567	Economy	28700.00
0005435508168	1567	Economy	28700.00
0005435517588	1567	Economy	28700.00
0005435501940	1567	Economy	28700.00
0005435501951	1567	Economy	28700.00
0005434565677	1567	Economy	28700.00
0005434565685	1567	Economy	28700.00
0005435517592	1567	Economy	28700.00
0005435501942	1567	Economy	28700.00
0005434565683	1567	Economy	28700.00
0005435517597	1567	Economy	28700.00
0005435501934	1567	Economy	28700.00
0005435508169	1567	Economy	28700.00
0005435517593	1567	Economy	28700.00
0005435517586	1567	Economy	28700.00
0005435501939	1567	Economy	28700.00
0005435517606	1567	Economy	28700.00
0005434565680	1567	Economy	28700.00
0005435508172	1567	Economy	28700.00
0005433185971	20846	Business	86000.00
0005433185974	20846	Business	86000.00
0005433185975	20846	Economy	28700.00
0005433185970	20846	Economy	28700.00
0005433185968	20846	Economy	31500.00
0005433185969	20846	Economy	28700.00
0005433185973	20846	Economy	28700.00
0005433185972	20846	Economy	28700.00
0005435153627	3925	Economy	21600.00
0005435153628	3925	Economy	19700.00
0005435153626	3925	Economy	19700.00
0005435153631	3925	Economy	19700.00
0005435153629	3925	Economy	19700.00
0005435153630	3925	Economy	19700.00
0005435931536	21848	Economy	19700.00
0005435931538	21848	Economy	19700.00
0005435931537	21848	Economy	19700.00
0005432628586	7226	Economy	14300.00
0005432628591	7226	Economy	13000.00
0005432628592	7226	Economy	13000.00
0005432628588	7226	Economy	13000.00
0005432628593	7226	Economy	13000.00
0005432628595	7226	Economy	13000.00
0005432628596	7226	Economy	13000.00
0005432628597	7226	Economy	13000.00
0005432628599	7226	Economy	13000.00
0005432628594	7226	Economy	13000.00
0005432628589	7226	Economy	13000.00
0005432628590	7226	Economy	13000.00
0005432628585	7226	Economy	13000.00
0005432628598	7226	Economy	13000.00
0005432628587	7226	Economy	13000.00
0005435225447	28100	Economy	13000.00
0005435225445	28100	Economy	13000.00
0005435225446	28100	Economy	13000.00
0005435225449	28100	Economy	13000.00
0005435225444	28100	Economy	13000.00
0005435225443	28100	Economy	13000.00
0005435225448	28100	Economy	13000.00
0005435959984	8719	Economy	10500.00
0005435959983	8719	Economy	10500.00
0005435959985	8719	Economy	10500.00
0005435959982	8719	Economy	10500.00
0005434267884	15264	Economy	10500.00
0005434267885	15264	Economy	10500.00
0005434267886	15264	Economy	10500.00
0005432674869	1214	Business	115000.00
0005432674874	1214	Business	115000.00
0005432674868	1214	Business	115000.00
0005432674866	1214	Business	115000.00
0005432674876	1214	Business	115000.00
0005432674865	1214	Business	115000.00
0005432674875	1214	Economy	38300.00
0005432674873	1214	Economy	42200.00
0005432674872	1214	Economy	38300.00
0005432674867	1214	Economy	38300.00
0005432674871	1214	Economy	38300.00
0005432674863	1214	Economy	38300.00
0005432674870	1214	Economy	38300.00
0005432674877	1214	Economy	38300.00
0005432674864	1214	Economy	38300.00
0005432873167	17509	Business	115000.00
0005432873168	17509	Business	115000.00
0005432873172	17509	Business	115000.00
0005432873165	17509	Economy	38300.00
0005432873171	17509	Economy	38300.00
0005432873166	17509	Economy	38300.00
0005432873173	17509	Economy	38300.00
0005432873169	17509	Economy	38300.00
0005432873170	17509	Economy	38300.00
0005434434912	1127	Economy	13900.00
0005434434913	1127	Economy	13900.00
0005434434915	1127	Economy	13900.00
0005434434918	1127	Economy	13900.00
0005434434919	1127	Economy	13900.00
0005434434922	1127	Economy	13900.00
0005434434924	1127	Economy	13900.00
0005434434910	1127	Economy	13900.00
0005434434914	1127	Economy	13900.00
0005434434909	1127	Economy	13900.00
0005434434921	1127	Economy	13900.00
0005434434911	1127	Economy	13900.00
0005434434920	1127	Economy	13900.00
0005434434916	1127	Economy	13900.00
0005434434917	1127	Economy	13900.00
0005434434923	1127	Economy	13900.00
0005433156598	17301	Economy	15200.00
0005433156599	17301	Economy	13900.00
0005433156605	17301	Economy	13900.00
0005433156604	17301	Economy	13900.00
0005433156597	17301	Economy	13900.00
0005433156603	17301	Economy	13900.00
0005433156600	17301	Economy	13900.00
0005433156602	17301	Economy	13900.00
0005433156601	17301	Economy	13900.00
0005435086706	4103	Economy	7500.00
0005435086702	4103	Economy	7500.00
0005435086704	4103	Economy	7500.00
0005435086703	4103	Economy	7500.00
0005435086701	4103	Economy	7500.00
0005435086705	4103	Economy	7500.00
0005435086700	4103	Economy	7500.00
0005435928060	24384	Economy	8200.00
0005435928061	24384	Economy	7500.00
0005435928057	24384	Economy	7500.00
0005435928059	24384	Economy	7500.00
0005435928058	24384	Economy	7500.00
0005435551493	17003	Business	144300.00
0005435551492	17003	Business	144300.00
0005435551491	17003	Business	144300.00
0005435098522	17003	Economy	48100.00
0005435098521	17003	Economy	48100.00
0005435551490	17003	Economy	48100.00
0005434625797	4822	Economy	14700.00
0005434625796	4822	Economy	16200.00
0005434625798	4822	Economy	14700.00
0005434625793	4822	Economy	14700.00
0005434625802	4822	Economy	14700.00
0005434625799	4822	Economy	14700.00
0005434625794	4822	Economy	14700.00
0005434625801	4822	Economy	14700.00
0005434625795	4822	Economy	14700.00
0005434625800	4822	Economy	14700.00
0005435907416	32920	Business	44200.00
0005435907418	32920	Economy	14700.00
0005433194818	32920	Economy	14700.00
0005435907417	32920	Economy	14700.00
0005433194819	32920	Economy	14700.00
0005435907419	32920	Economy	14700.00
0005435907420	32920	Economy	14700.00
0005433194817	32920	Economy	14700.00
0005432195657	13777	Economy	3100.00
0005432195655	13777	Economy	3100.00
0005435937312	13777	Economy	3100.00
0005435937307	13777	Economy	3100.00
0005435937313	13777	Economy	3100.00
0005435937310	13777	Economy	3100.00
0005435937306	13777	Economy	3100.00
0005432195656	13777	Economy	3100.00
0005435937308	13777	Economy	3100.00
0005435937309	13777	Economy	3100.00
0005435937305	13777	Economy	3100.00
0005435937311	13777	Economy	3100.00
0005435310836	20272	Business	12000.00
0005435310855	20272	Business	12000.00
0005435310841	20272	Business	12000.00
0005435310846	20272	Business	12000.00
0005435310848	20272	Business	12000.00
0005435310840	20272	Economy	4000.00
0005435310854	20272	Economy	4400.00
0005432058315	20272	Economy	4000.00
0005435310851	20272	Economy	4000.00
0005435310849	20272	Economy	4000.00
0005435310847	20272	Economy	4000.00
0005432058313	20272	Economy	4000.00
0005435310844	20272	Economy	4000.00
0005435310842	20272	Economy	4000.00
0005435310839	20272	Economy	4000.00
0005435310845	20272	Economy	4000.00
0005435310852	20272	Economy	4000.00
0005435310838	20272	Economy	4000.00
0005435310837	20272	Economy	4000.00
0005435310853	20272	Economy	4000.00
0005435310843	20272	Economy	4000.00
0005435310850	20272	Economy	4000.00
0005432058314	20272	Economy	4000.00
0005432058312	20272	Economy	4000.00
0005434406641	26958	Business	12000.00
0005432153814	26958	Business	12000.00
0005434406650	26958	Business	12000.00
0005434406669	26958	Business	12000.00
0005434406689	26958	Business	12000.00
0005434406685	26958	Business	12000.00
0005434406643	26958	Business	12000.00
0005434406668	26958	Business	12000.00
0005434406665	26958	Business	12000.00
0005434406695	26958	Business	12000.00
0005432153813	26958	Economy	4000.00
0005434406651	26958	Economy	4000.00
0005434406654	26958	Economy	4000.00
0005434406642	26958	Economy	4000.00
0005434406683	26958	Economy	4000.00
0005432153815	26958	Economy	4000.00
0005434406649	26958	Economy	4000.00
0005434406646	26958	Economy	4400.00
0005434406701	26958	Economy	4400.00
0005432153817	26958	Economy	4400.00
0005434406678	26958	Economy	4000.00
0005434406690	26958	Economy	4000.00
0005434406667	26958	Economy	4000.00
0005434406658	26958	Economy	4000.00
0005434406679	26958	Economy	4000.00
0005434406674	26958	Economy	4000.00
0005434406639	26958	Economy	4000.00
0005434406673	26958	Economy	4000.00
0005434406691	26958	Economy	4000.00
0005434406700	26958	Economy	4000.00
0005434406656	26958	Economy	4000.00
0005434406692	26958	Economy	4000.00
0005434406681	26958	Economy	4000.00
0005434406666	26958	Economy	4000.00
0005434406640	26958	Economy	4000.00
0005434406682	26958	Economy	4000.00
0005434406670	26958	Economy	4000.00
0005434406661	26958	Economy	4000.00
0005434406698	26958	Economy	4000.00
0005434406662	26958	Economy	4000.00
0005434406676	26958	Economy	4000.00
0005434406696	26958	Economy	4000.00
0005434406653	26958	Economy	4000.00
0005434406652	26958	Economy	4000.00
0005434406687	26958	Economy	4000.00
0005434406677	26958	Economy	4000.00
0005434406645	26958	Economy	4000.00
0005434406680	26958	Economy	4000.00
0005434406693	26958	Economy	4000.00
0005434406644	26958	Economy	4000.00
0005432153819	26958	Economy	4000.00
0005434406659	26958	Economy	4000.00
0005434406664	26958	Economy	4000.00
0005434406660	26958	Economy	4000.00
0005434406655	26958	Economy	4000.00
0005434406657	26958	Economy	4000.00
0005434406699	26958	Economy	4000.00
0005434406671	26958	Economy	4000.00
0005434406675	26958	Economy	4000.00
0005434406647	26958	Economy	4000.00
0005434406686	26958	Economy	4000.00
0005434406684	26958	Economy	4000.00
0005434406663	26958	Economy	4000.00
0005434406697	26958	Economy	4000.00
0005434406648	26958	Economy	4000.00
0005432153818	26958	Economy	4000.00
0005434406672	26958	Economy	4000.00
0005432153816	26958	Economy	4000.00
0005434406694	26958	Economy	4000.00
0005434406688	26958	Economy	4000.00
0005434319150	5671	Business	43300.00
0005434319142	5671	Economy	14400.00
0005434319149	5671	Economy	15900.00
0005434311182	5671	Economy	14400.00
0005432109655	5671	Economy	14400.00
0005432109656	5671	Economy	14400.00
0005434319144	5671	Economy	14400.00
0005434319148	5671	Economy	14400.00
0005434319143	5671	Economy	14400.00
0005434319141	5671	Economy	14400.00
0005434319147	5671	Economy	14400.00
0005434319145	5671	Economy	14400.00
0005434311181	5671	Economy	14400.00
0005434319146	5671	Economy	14400.00
0005433123577	15695	Business	43300.00
0005433123582	15695	Business	43300.00
0005433123571	15695	Economy	14400.00
0005433123580	15695	Economy	14400.00
0005433123578	15695	Economy	15900.00
0005433123566	15695	Economy	14400.00
0005433123573	15695	Economy	14400.00
0005433123574	15695	Economy	14400.00
0005433123586	15695	Economy	14400.00
0005433123587	15695	Economy	14400.00
0005433123569	15695	Economy	14400.00
0005433123568	15695	Economy	14400.00
0005433123575	15695	Economy	14400.00
0005433123584	15695	Economy	14400.00
0005433123567	15695	Economy	14400.00
0005433123565	15695	Economy	14400.00
0005433123570	15695	Economy	14400.00
0005433123585	15695	Economy	14400.00
0005433123583	15695	Economy	14400.00
0005433123579	15695	Economy	14400.00
0005433123572	15695	Economy	14400.00
0005433123581	15695	Economy	14400.00
0005433123576	15695	Economy	14400.00
0005435219165	31748	Economy	15500.00
0005435220283	31748	Economy	15500.00
0005435220284	31748	Economy	15500.00
0005434484235	9001	Economy	24900.00
0005434484231	9001	Economy	24900.00
0005434484237	9001	Economy	24900.00
0005434484234	9001	Economy	24900.00
0005434484236	9001	Economy	24900.00
0005434484232	9001	Economy	24900.00
0005434484233	9001	Economy	24900.00
0005434189075	16620	Economy	24900.00
0005434189079	16620	Economy	24900.00
0005434189076	16620	Economy	24900.00
0005434189077	16620	Economy	24900.00
0005434189078	16620	Economy	24900.00
0005434189080	16620	Economy	24900.00
0005433123582	7571	Business	11100.00
0005433123572	7571	Business	11100.00
0005433123565	7571	Business	11100.00
0005433123574	7571	Economy	3700.00
0005433123570	7571	Economy	3700.00
0005433123583	7571	Economy	3700.00
0005433123581	7571	Economy	3700.00
0005433123573	7571	Economy	3700.00
0005433123580	7571	Economy	3700.00
0005433123566	7571	Economy	3700.00
0005433123576	7571	Economy	3700.00
0005433123567	7571	Economy	3700.00
0005433123584	7571	Economy	3700.00
0005433123586	7571	Economy	3700.00
0005433123587	7571	Economy	3700.00
0005433123579	7571	Economy	3700.00
0005433123585	7571	Economy	3700.00
0005433123578	7571	Economy	3700.00
0005433123577	7571	Economy	3700.00
0005433123575	7571	Economy	3700.00
0005433123569	7571	Economy	3700.00
0005433123568	7571	Economy	3700.00
0005433123571	7571	Economy	3700.00
0005432720450	7572	Business	11100.00
0005432692555	7572	Business	11100.00
0005432692532	7572	Business	11100.00
0005432720453	7572	Business	11100.00
0005432720446	7572	Business	11100.00
0005432692535	7572	Business	11100.00
0005432720452	7572	Business	11100.00
0005433449584	7572	Business	11100.00
0005432720442	7572	Economy	3700.00
0005432720448	7572	Economy	3700.00
0005432720447	7572	Economy	3700.00
0005432720455	7572	Economy	3700.00
0005433449583	7572	Economy	3700.00
0005432720435	7572	Economy	3700.00
0005432692528	7572	Economy	3700.00
0005432692539	7572	Economy	3700.00
0005432720433	7572	Economy	3700.00
0005432692547	7572	Economy	3700.00
0005432720444	7572	Economy	4100.00
0005432692527	7572	Economy	4100.00
0005433449590	7572	Economy	4100.00
0005432692536	7572	Economy	4100.00
0005433449604	7572	Economy	4100.00
0005432720445	7572	Economy	3700.00
0005432692552	7572	Economy	3700.00
0005432692542	7572	Economy	3700.00
0005432692545	7572	Economy	3700.00
0005432720440	7572	Economy	3700.00
0005433449595	7572	Economy	3700.00
0005432720429	7572	Economy	3700.00
0005432720454	7572	Economy	3700.00
0005432692534	7572	Economy	3700.00
0005432692529	7572	Economy	3700.00
0005432692541	7572	Economy	3700.00
0005432071520	7572	Economy	3700.00
0005432720451	7572	Economy	3700.00
0005433449588	7572	Economy	3700.00
0005433449601	7572	Economy	3700.00
0005432720430	7572	Economy	3700.00
0005432720437	7572	Economy	3700.00
0005432720439	7572	Economy	3700.00
0005432071522	7572	Economy	3700.00
0005433449593	7572	Economy	3700.00
0005433449586	7572	Economy	3700.00
0005432692543	7572	Economy	3700.00
0005432720436	7572	Economy	3700.00
0005432720449	7572	Economy	3700.00
0005432720434	7572	Economy	3700.00
0005433449592	7572	Economy	3700.00
0005432692549	7572	Economy	3700.00
0005432692557	7572	Economy	3700.00
0005433449599	7572	Economy	3700.00
0005433449591	7572	Economy	3700.00
0005432692553	7572	Economy	3700.00
0005432720443	7572	Economy	3700.00
0005432071521	7572	Economy	3700.00
0005432720428	7572	Economy	3700.00
0005432692537	7572	Economy	3700.00
0005432720438	7572	Economy	3700.00
0005432692540	7572	Economy	3700.00
0005432692551	7572	Economy	3700.00
0005433449597	7572	Economy	3700.00
0005432692546	7572	Economy	3700.00
0005432692530	7572	Economy	3700.00
0005432692554	7572	Economy	3700.00
0005432692550	7572	Economy	3700.00
0005433449598	7572	Economy	3700.00
0005432720432	7572	Economy	3700.00
0005432692533	7572	Economy	3700.00
0005432692548	7572	Economy	3700.00
0005432692531	7572	Economy	3700.00
0005433449603	7572	Economy	3700.00
0005432692556	7572	Economy	3700.00
0005433449600	7572	Economy	3700.00
0005433449587	7572	Economy	3700.00
0005432692558	7572	Economy	3700.00
0005433449596	7572	Economy	3700.00
0005433449602	7572	Economy	3700.00
0005433449589	7572	Economy	3700.00
0005433449605	7572	Economy	3700.00
0005433449594	7572	Economy	3700.00
0005432692544	7572	Economy	3700.00
0005432720441	7572	Economy	3700.00
0005432720431	7572	Economy	3700.00
0005433449585	7572	Economy	3700.00
0005432692538	7572	Economy	3700.00
0005433722106	30450	Business	11100.00
0005433722105	30450	Economy	3700.00
0005433722104	30450	Economy	3700.00
0005433722102	30450	Economy	3700.00
0005433722103	30450	Economy	3700.00
0005434586172	1368	Business	70400.00
0005434513533	1368	Business	70400.00
0005434586169	1368	Business	70400.00
0005434586179	1368	Business	70400.00
0005434586161	1368	Business	70400.00
0005433524846	1368	Business	70400.00
0005434514921	1368	Business	70400.00
0005433524850	1368	Business	70400.00
0005432270954	1368	Economy	23500.00
0005434586160	1368	Economy	23500.00
0005433524855	1368	Economy	23500.00
0005434586164	1368	Economy	23500.00
0005434586171	1368	Economy	23500.00
0005432270955	1368	Economy	25800.00
0005434586165	1368	Economy	25800.00
0005434586162	1368	Economy	23500.00
0005434586158	1368	Economy	23500.00
0005433524853	1368	Economy	23500.00
0005434586177	1368	Economy	23500.00
0005434586176	1368	Economy	23500.00
0005434586163	1368	Economy	23500.00
0005433524851	1368	Economy	23500.00
0005432270956	1368	Economy	23500.00
0005433524852	1368	Economy	23500.00
0005434586181	1368	Economy	23500.00
0005434586159	1368	Economy	23500.00
0005433524854	1368	Economy	23500.00
0005433724726	1368	Economy	23500.00
0005433524849	1368	Economy	23500.00
0005434586173	1368	Economy	23500.00
0005433724727	1368	Economy	23500.00
0005434586174	1368	Economy	23500.00
0005434513534	1368	Economy	23500.00
0005434586182	1368	Economy	23500.00
0005434586180	1368	Economy	23500.00
0005433724724	1368	Economy	23500.00
0005434586157	1368	Economy	23500.00
0005434514922	1368	Economy	23500.00
0005434586170	1368	Economy	23500.00
0005434586167	1368	Economy	23500.00
0005434586166	1368	Economy	23500.00
0005434586168	1368	Economy	23500.00
0005433724725	1368	Economy	23500.00
0005434513535	1368	Economy	23500.00
0005434586178	1368	Economy	23500.00
0005433524848	1368	Economy	23500.00
0005434586175	1368	Economy	23500.00
0005433524847	1368	Economy	23500.00
0005434514923	1368	Economy	23500.00
0005433192815	18514	Economy	23500.00
0005433192818	18514	Economy	23500.00
0005433192812	18514	Economy	23500.00
0005433192814	18514	Economy	23500.00
0005433192813	18514	Economy	23500.00
0005433192816	18514	Economy	23500.00
0005433192817	18514	Economy	23500.00
0005433192809	18514	Economy	23500.00
0005433192810	18514	Economy	23500.00
0005433192821	18514	Economy	23500.00
0005433192811	18514	Economy	23500.00
0005433192820	18514	Economy	23500.00
0005433192819	18514	Economy	23500.00
0005434142542	11429	Economy	4000.00
0005434142541	11429	Economy	4000.00
0005434142540	11429	Economy	4000.00
0005434142543	11429	Economy	4000.00
0005435304095	29766	Economy	4000.00
0005435304096	29766	Economy	4000.00
0005435304092	29766	Economy	4000.00
0005435304094	29766	Economy	4000.00
0005435304093	29766	Economy	4000.00
0005435304989	29766	Economy	4000.00
0005435824155	1287	Business	199800.00
0005435824160	1287	Business	199800.00
0005435824158	1287	Business	199800.00
0005435824164	1287	Business	199800.00
0005435824154	1287	Economy	66600.00
0005435824173	1287	Economy	66600.00
0005435824172	1287	Economy	66600.00
0005435824161	1287	Economy	66600.00
0005435824151	1287	Economy	73200.00
0005435824169	1287	Economy	73200.00
0005435824178	1287	Economy	66600.00
0005435824177	1287	Economy	66600.00
0005435824156	1287	Economy	66600.00
0005435824175	1287	Economy	66600.00
0005432284506	1287	Economy	66600.00
0005435824170	1287	Economy	66600.00
0005435824167	1287	Economy	66600.00
0005435824171	1287	Economy	66600.00
0005435824162	1287	Economy	66600.00
0005435824174	1287	Economy	66600.00
0005435824163	1287	Economy	66600.00
0005432284505	1287	Economy	66600.00
0005435824157	1287	Economy	66600.00
0005435824165	1287	Economy	66600.00
0005435824153	1287	Economy	66600.00
0005432284508	1287	Economy	66600.00
0005435824168	1287	Economy	66600.00
0005432284507	1287	Economy	66600.00
0005435824166	1287	Economy	66600.00
0005435824159	1287	Economy	66600.00
0005435824176	1287	Economy	66600.00
0005435824152	1287	Economy	66600.00
0005433415388	17980	Business	199800.00
0005433415381	17980	Business	199800.00
0005433415385	17980	Economy	66600.00
0005433415389	17980	Economy	66600.00
0005433415391	17980	Economy	66600.00
0005433415384	17980	Economy	66600.00
0005433415380	17980	Economy	66600.00
0005433415383	17980	Economy	66600.00
0005433415390	17980	Economy	66600.00
0005433415378	17980	Economy	66600.00
0005433415379	17980	Economy	66600.00
0005433415386	17980	Economy	66600.00
0005433415392	17980	Economy	66600.00
0005433415382	17980	Economy	66600.00
0005433415393	17980	Economy	66600.00
0005433415387	17980	Economy	66600.00
0005432143931	5615	Business	27800.00
0005432782863	5615	Business	27800.00
0005432782838	5615	Business	27800.00
0005432782841	5615	Business	27800.00
0005432782840	5615	Business	27800.00
0005432782847	5615	Business	27800.00
0005432782887	5615	Business	27800.00
0005432782888	5615	Economy	9300.00
0005432782870	5615	Economy	9300.00
0005432782872	5615	Economy	9300.00
0005432143932	5615	Economy	9300.00
0005432782850	5615	Economy	9300.00
0005432782849	5615	Economy	9300.00
0005432782889	5615	Economy	10200.00
0005432782871	5615	Economy	10200.00
0005432782857	5615	Economy	10200.00
0005432782873	5615	Economy	9300.00
0005432782877	5615	Economy	9300.00
0005432782858	5615	Economy	9300.00
0005432782854	5615	Economy	9300.00
0005432782892	5615	Economy	9300.00
0005432782864	5615	Economy	9300.00
0005432782851	5615	Economy	9300.00
0005432782848	5615	Economy	9300.00
0005432782891	5615	Economy	9300.00
0005432782860	5615	Economy	9300.00
0005432782861	5615	Economy	9300.00
0005432782880	5615	Economy	9300.00
0005432782882	5615	Economy	9300.00
0005432782853	5615	Economy	9300.00
0005432782839	5615	Economy	9300.00
0005432782881	5615	Economy	9300.00
0005432782883	5615	Economy	9300.00
0005432782842	5615	Economy	9300.00
0005432782879	5615	Economy	9300.00
0005432782876	5615	Economy	9300.00
0005432782869	5615	Economy	9300.00
0005432782859	5615	Economy	9300.00
0005432782867	5615	Economy	9300.00
0005432782855	5615	Economy	9300.00
0005432782845	5615	Economy	9300.00
0005432782884	5615	Economy	9300.00
0005432782886	5615	Economy	9300.00
0005432782874	5615	Economy	9300.00
0005432782846	5615	Economy	9300.00
0005432143930	5615	Economy	9300.00
0005432782878	5615	Economy	9300.00
0005432782843	5615	Economy	9300.00
0005432143929	5615	Economy	9300.00
0005432782865	5615	Economy	9300.00
0005432782890	5615	Economy	9300.00
0005432782856	5615	Economy	9300.00
0005432782875	5615	Economy	9300.00
0005432782862	5615	Economy	9300.00
0005432782868	5615	Economy	9300.00
0005432782885	5615	Economy	9300.00
0005432782852	5615	Economy	9300.00
0005432782844	5615	Economy	9300.00
0005432782866	5615	Economy	9300.00
0005435476637	15345	Business	27800.00
0005435476646	15345	Economy	9300.00
0005435476647	15345	Economy	9300.00
0005435476640	15345	Economy	9300.00
0005435476634	15345	Economy	9300.00
0005435476636	15345	Economy	10200.00
0005435476643	15345	Economy	9300.00
0005435476645	15345	Economy	9300.00
0005435476635	15345	Economy	9300.00
0005435476641	15345	Economy	9300.00
0005435476639	15345	Economy	9300.00
0005435476642	15345	Economy	9300.00
0005435476638	15345	Economy	9300.00
0005435476648	15345	Economy	9300.00
0005435476644	15345	Economy	9300.00
0005432848055	4384	Economy	7000.00
0005432848056	4384	Economy	6300.00
0005434462753	4384	Economy	6300.00
0005432848057	4384	Economy	6300.00
0005432848064	4384	Economy	6300.00
0005432848059	4384	Economy	6300.00
0005432848066	4384	Economy	6300.00
0005432848062	4384	Economy	6300.00
0005432848067	4384	Economy	6300.00
0005434463892	4384	Economy	6300.00
0005434463891	4384	Economy	6300.00
0005432848060	4384	Economy	6300.00
0005432848061	4384	Economy	6300.00
0005432848070	4384	Economy	6300.00
0005432848068	4384	Economy	6300.00
0005432848058	4384	Economy	6300.00
0005432848065	4384	Economy	6300.00
0005434462752	4384	Economy	6300.00
0005432848069	4384	Economy	6300.00
0005432848063	4384	Economy	6300.00
0005435850752	28883	Economy	7000.00
0005435850751	28883	Economy	6300.00
0005435850756	28883	Economy	6300.00
0005435850750	28883	Economy	6300.00
0005435850754	28883	Economy	6300.00
0005435850755	28883	Economy	6300.00
0005435850753	28883	Economy	6300.00
0005435850757	28883	Economy	6300.00
0005433496438	6253	Business	11900.00
0005433496444	6253	Business	11900.00
0005433496449	6253	Business	11900.00
0005434443432	6253	Business	11900.00
0005434925249	6253	Business	11900.00
0005433496435	6253	Business	11900.00
0005433496432	6253	Business	11900.00
0005434443436	6253	Business	11900.00
0005433496431	6253	Economy	4000.00
0005434925247	6253	Economy	4000.00
0005434925264	6253	Economy	4000.00
0005434925256	6253	Economy	4000.00
0005434443433	6253	Economy	4000.00
0005434925254	6253	Economy	4000.00
0005434443427	6253	Economy	4000.00
0005434925265	6253	Economy	4000.00
0005434443424	6253	Economy	4400.00
0005433496436	6253	Economy	4400.00
0005434925250	6253	Economy	4400.00
0005434925263	6253	Economy	4000.00
0005434925269	6253	Economy	4000.00
0005433496430	6253	Economy	4000.00
0005434925255	6253	Economy	4000.00
0005434925266	6253	Economy	4000.00
0005433496418	6253	Economy	4000.00
0005434443434	6253	Economy	4000.00
0005432075169	6253	Economy	4000.00
0005433496447	6253	Economy	4000.00
0005434443438	6253	Economy	4000.00
0005433496433	6253	Economy	4000.00
0005434925270	6253	Economy	4000.00
0005433496420	6253	Economy	4000.00
0005434925258	6253	Economy	4000.00
0005433496445	6253	Economy	4000.00
0005434925248	6253	Economy	4000.00
0005433496422	6253	Economy	4000.00
0005434443439	6253	Economy	4000.00
0005434925268	6253	Economy	4000.00
0005433496421	6253	Economy	4000.00
0005434925251	6253	Economy	4000.00
0005434925271	6253	Economy	4000.00
0005433496428	6253	Economy	4000.00
0005433496425	6253	Economy	4000.00
0005433496434	6253	Economy	4000.00
0005434925253	6253	Economy	4000.00
0005434925260	6253	Economy	4000.00
0005433496429	6253	Economy	4000.00
0005433496427	6253	Economy	4000.00
0005432075170	6253	Economy	4000.00
0005434443425	6253	Economy	4000.00
0005433496424	6253	Economy	4000.00
0005434443435	6253	Economy	4000.00
0005434925259	6253	Economy	4000.00
0005433496423	6253	Economy	4000.00
0005434443429	6253	Economy	4000.00
0005434443428	6253	Economy	4000.00
0005434443426	6253	Economy	4000.00
0005433496442	6253	Economy	4000.00
0005433496441	6253	Economy	4000.00
0005434443431	6253	Economy	4000.00
0005434925261	6253	Economy	4000.00
0005434925257	6253	Economy	4000.00
0005433496440	6253	Economy	4000.00
0005433496446	6253	Economy	4000.00
0005433496426	6253	Economy	4000.00
0005432075171	6253	Economy	4000.00
0005433496437	6253	Economy	4000.00
0005434925272	6253	Economy	4000.00
0005434925252	6253	Economy	4000.00
0005433496439	6253	Economy	4000.00
0005433496419	6253	Economy	4000.00
0005434925262	6253	Economy	4000.00
0005434443437	6253	Economy	4000.00
0005433496443	6253	Economy	4000.00
0005434925267	6253	Economy	4000.00
0005433496448	6253	Economy	4000.00
0005434443430	6253	Economy	4000.00
0005435242399	12211	Business	41200.00
0005435242390	12211	Business	41200.00
0005435242389	12211	Business	41200.00
0005435242409	12211	Business	41200.00
0005435242393	12211	Economy	13700.00
0005435242400	12211	Economy	13700.00
0005435242403	12211	Economy	13700.00
0005435242404	12211	Economy	13700.00
0005435242394	12211	Economy	13700.00
0005435242401	12211	Economy	13700.00
0005435242414	12211	Economy	13700.00
0005435242413	12211	Economy	13700.00
0005435242396	12211	Economy	13700.00
0005435242410	12211	Economy	13700.00
0005435242411	12211	Economy	13700.00
0005435242398	12211	Economy	13700.00
0005435242407	12211	Economy	13700.00
0005435242391	12211	Economy	13700.00
0005435242395	12211	Economy	13700.00
0005435242388	12211	Economy	13700.00
0005435242408	12211	Economy	13700.00
0005435242392	12211	Economy	13700.00
0005435242405	12211	Economy	13700.00
0005435242402	12211	Economy	13700.00
0005435242412	12211	Economy	13700.00
0005435242406	12211	Economy	13700.00
0005435242387	12211	Economy	13700.00
0005435242415	12211	Economy	13700.00
0005435242397	12211	Economy	13700.00
0005435913849	10095	Business	49700.00
0005434910069	10095	Economy	16600.00
0005434910068	10095	Economy	16600.00
0005434910070	10095	Economy	16600.00
0005435913850	10095	Economy	16600.00
0005434876598	14602	Business	49700.00
0005434876590	14602	Business	49700.00
0005434876624	14602	Business	49700.00
0005434876616	14602	Business	49700.00
0005434876615	14602	Business	49700.00
0005434876582	14602	Business	49700.00
0005434876569	14602	Business	49700.00
0005434876620	14602	Business	49700.00
0005434876636	14602	Business	49700.00
0005434876638	14602	Business	49700.00
0005434876608	14602	Business	49700.00
0005434876601	14602	Business	49700.00
0005434876617	14602	Business	49700.00
0005434876555	14602	Business	49700.00
0005434876564	14602	Business	49700.00
0005434876593	14602	Business	49700.00
0005434876610	14602	Business	49700.00
0005434876629	14602	Economy	16600.00
0005434876574	14602	Economy	16600.00
0005434876650	14602	Economy	16600.00
0005434876621	14602	Economy	16600.00
0005434876648	14602	Economy	16600.00
0005434876618	14602	Economy	16600.00
0005434876579	14602	Economy	16600.00
0005434876565	14602	Economy	16600.00
0005434876641	14602	Economy	16600.00
0005434876635	14602	Economy	16600.00
0005434758853	14602	Economy	16600.00
0005434876557	14602	Economy	18200.00
0005434876558	14602	Economy	18200.00
0005434876600	14602	Economy	18200.00
0005434876611	14602	Economy	16600.00
0005434876563	14602	Economy	16600.00
0005434876570	14602	Economy	16600.00
0005434876637	14602	Economy	16600.00
0005434876639	14602	Economy	16600.00
0005434876583	14602	Economy	16600.00
0005434876612	14602	Economy	16600.00
0005434876595	14602	Economy	16600.00
0005434876573	14602	Economy	16600.00
0005434876580	14602	Economy	16600.00
0005434876626	14602	Economy	16600.00
0005434876592	14602	Economy	16600.00
0005434876586	14602	Economy	16600.00
0005434876560	14602	Economy	16600.00
0005434876581	14602	Economy	16600.00
0005434876568	14602	Economy	16600.00
0005434876607	14602	Economy	16600.00
0005434876559	14602	Economy	16600.00
0005434876619	14602	Economy	16600.00
0005434876603	14602	Economy	16600.00
0005434876609	14602	Economy	16600.00
0005434876651	14602	Economy	16600.00
0005434876614	14602	Economy	16600.00
0005434876649	14602	Economy	16600.00
0005434758854	14602	Economy	16600.00
0005434758852	14602	Economy	16600.00
0005434876562	14602	Economy	16600.00
0005434876633	14602	Economy	16600.00
0005434876646	14602	Economy	16600.00
0005434876606	14602	Economy	16600.00
0005434876596	14602	Economy	16600.00
0005434876556	14602	Economy	16600.00
0005434876561	14602	Economy	16600.00
0005434876634	14602	Economy	16600.00
0005434876640	14602	Economy	16600.00
0005434876631	14602	Economy	16600.00
0005434876625	14602	Economy	16600.00
0005434876627	14602	Economy	16600.00
0005434876575	14602	Economy	16600.00
0005434876623	14602	Economy	16600.00
0005434876588	14602	Economy	16600.00
0005434876597	14602	Economy	16600.00
0005434876642	14602	Economy	16600.00
0005434876572	14602	Economy	16600.00
0005434876587	14602	Economy	16600.00
0005434876585	14602	Economy	16600.00
0005434876602	14602	Economy	16600.00
0005434876605	14602	Economy	16600.00
0005434876589	14602	Economy	16600.00
0005434876628	14602	Economy	16600.00
0005434876567	14602	Economy	16600.00
0005434876599	14602	Economy	16600.00
0005434876647	14602	Economy	16600.00
0005434876645	14602	Economy	16600.00
0005434876644	14602	Economy	16600.00
0005434876576	14602	Economy	16600.00
0005434876591	14602	Economy	16600.00
0005434876604	14602	Economy	16600.00
0005434876632	14602	Economy	16600.00
0005434876578	14602	Economy	16600.00
0005434876622	14602	Economy	16600.00
0005434876566	14602	Economy	16600.00
0005434876594	14602	Economy	16600.00
0005434876643	14602	Economy	16600.00
0005434876584	14602	Economy	16600.00
0005434876571	14602	Economy	16600.00
0005434876630	14602	Economy	16600.00
0005434876577	14602	Economy	16600.00
0005434876613	14602	Economy	16600.00
0005435659943	9262	Economy	22400.00
0005435659937	9262	Economy	22400.00
0005435659948	9262	Economy	22400.00
0005435659946	9262	Economy	20300.00
0005435659939	9262	Economy	20300.00
0005435659941	9262	Economy	20300.00
0005435659940	9262	Economy	20300.00
0005435659944	9262	Economy	20300.00
0005435659938	9262	Economy	20300.00
0005435659945	9262	Economy	20300.00
0005435659947	9262	Economy	20300.00
0005435659942	9262	Economy	20300.00
0005434251798	24676	Economy	22400.00
0005434251800	24676	Economy	20300.00
0005434251802	24676	Economy	20300.00
0005434251795	24676	Economy	20300.00
0005434251801	24676	Economy	20300.00
0005434251797	24676	Economy	20300.00
0005434251804	24676	Economy	20300.00
0005434251803	24676	Economy	20300.00
0005434251796	24676	Economy	20300.00
0005434251799	24676	Economy	20300.00
0005433679726	2796	Business	33000.00
0005433679724	2796	Business	33000.00
0005433679740	2796	Business	33000.00
0005433679728	2796	Business	33000.00
0005433679715	2796	Business	33000.00
0005432222688	2796	Business	33000.00
0005433679754	2796	Business	33000.00
0005432222690	2796	Economy	11000.00
0005433679717	2796	Economy	11000.00
0005433679752	2796	Economy	11000.00
0005433679718	2796	Economy	11000.00
0005433679716	2796	Economy	11000.00
0005433679745	2796	Economy	11000.00
0005433679731	2796	Economy	11000.00
0005433679727	2796	Economy	12100.00
0005433679747	2796	Economy	12100.00
0005433679719	2796	Economy	12100.00
0005433679755	2796	Economy	12100.00
0005433679734	2796	Economy	11000.00
0005433679710	2796	Economy	11000.00
0005433679733	2796	Economy	11000.00
0005433679722	2796	Economy	11000.00
0005433679744	2796	Economy	11000.00
0005433679739	2796	Economy	11000.00
0005433679732	2796	Economy	11000.00
0005433679729	2796	Economy	11000.00
0005433679713	2796	Economy	11000.00
0005433679711	2796	Economy	11000.00
0005433679720	2796	Economy	11000.00
0005433679736	2796	Economy	11000.00
0005433679750	2796	Economy	11000.00
0005433679748	2796	Economy	11000.00
0005432222691	2796	Economy	11000.00
0005433679741	2796	Economy	11000.00
0005433679742	2796	Economy	11000.00
0005433679749	2796	Economy	11000.00
0005432222689	2796	Economy	11000.00
0005433679709	2796	Economy	11000.00
0005433679725	2796	Economy	11000.00
0005433679721	2796	Economy	11000.00
0005433679756	2796	Economy	11000.00
0005433679751	2796	Economy	11000.00
0005433679723	2796	Economy	11000.00
0005433679737	2796	Economy	11000.00
0005433679746	2796	Economy	11000.00
0005433679743	2796	Economy	11000.00
0005433679730	2796	Economy	11000.00
0005433679735	2796	Economy	11000.00
0005433679738	2796	Economy	11000.00
0005433679753	2796	Economy	11000.00
0005433679712	2796	Economy	11000.00
0005433679714	2796	Economy	11000.00
0005432222692	2796	Economy	11000.00
0005432966502	29150	Business	33000.00
0005432966499	29150	Business	33000.00
0005432966486	29150	Business	33000.00
0005432966482	29150	Business	33000.00
0005432966494	29150	Economy	11000.00
0005432966495	29150	Economy	11000.00
0005432966489	29150	Economy	11000.00
0005432966504	29150	Economy	11000.00
0005432966492	29150	Economy	12100.00
0005432966480	29150	Economy	12100.00
0005432966497	29150	Economy	11000.00
0005432005165	29150	Economy	11000.00
0005432966483	29150	Economy	11000.00
0005432005164	29150	Economy	11000.00
0005432966503	29150	Economy	11000.00
0005432966498	29150	Economy	11000.00
0005432966491	29150	Economy	11000.00
0005432966493	29150	Economy	11000.00
0005432966479	29150	Economy	11000.00
0005432966481	29150	Economy	11000.00
0005432966496	29150	Economy	11000.00
0005432966488	29150	Economy	11000.00
0005432966500	29150	Economy	11000.00
0005432966484	29150	Economy	11000.00
0005432966501	29150	Economy	11000.00
0005432005163	29150	Economy	11000.00
0005432966487	29150	Economy	11000.00
0005432966485	29150	Economy	11000.00
0005432966490	29150	Economy	11000.00
0005433577568	9307	Business	132900.00
0005433577564	9307	Business	132900.00
0005433577563	9307	Business	132900.00
0005433577565	9307	Business	132900.00
0005432755016	9307	Business	132900.00
0005432756789	9307	Economy	48700.00
0005433577567	9307	Economy	48700.00
0005433577572	9307	Economy	44300.00
0005433577566	9307	Economy	44300.00
0005432755017	9307	Economy	44300.00
0005433577571	9307	Economy	44300.00
0005432756787	9307	Economy	44300.00
0005433577562	9307	Economy	48700.00
0005432755015	9307	Economy	44300.00
0005433577573	9307	Economy	44300.00
0005433577570	9307	Economy	44300.00
0005433577569	9307	Economy	44300.00
0005432756788	9307	Economy	44300.00
0005433577561	9307	Economy	44300.00
0005432184902	4199	Business	193100.00
0005435986654	4199	Economy	64400.00
0005435986650	4199	Economy	64400.00
0005435986652	4199	Economy	64400.00
0005435986649	4199	Economy	64400.00
0005432184901	4199	Economy	64400.00
0005435986653	4199	Economy	64400.00
0005432184900	4199	Economy	64400.00
0005435986651	4199	Economy	64400.00
0005435947005	26588	Business	193100.00
0005432571260	26588	Business	193100.00
0005432571259	26588	Business	193100.00
0005435947001	26588	Business	193100.00
0005435947010	26588	Business	193100.00
0005435947004	26588	Economy	64400.00
0005435856131	26588	Economy	64400.00
0005435947003	26588	Economy	64400.00
0005435947000	26588	Economy	64400.00
0005435946996	26588	Economy	64400.00
0005435787321	26588	Economy	64400.00
0005432571257	26588	Economy	64400.00
0005435946997	26588	Economy	64400.00
0005435947009	26588	Economy	64400.00
0005432571258	26588	Economy	64400.00
0005435946998	26588	Economy	64400.00
0005435947006	26588	Economy	64400.00
0005435946999	26588	Economy	64400.00
0005435856133	26588	Economy	64400.00
0005435947008	26588	Economy	64400.00
0005435856130	26588	Economy	64400.00
0005435947002	26588	Economy	64400.00
0005435787320	26588	Economy	64400.00
0005435947011	26588	Economy	64400.00
0005435947007	26588	Economy	64400.00
0005435856132	26588	Economy	64400.00
0005433568041	331	Business	21500.00
0005433568033	331	Business	21500.00
0005433568034	331	Business	21500.00
0005433568065	331	Business	21500.00
0005433568043	331	Business	21500.00
0005433568045	331	Business	21500.00
0005433568018	331	Business	21500.00
0005433568061	331	Business	21500.00
0005433568019	331	Business	21500.00
0005433568029	331	Economy	7900.00
0005433568037	331	Economy	7900.00
0005433568057	331	Economy	7200.00
0005433568036	331	Economy	7200.00
0005433568022	331	Economy	7200.00
0005433568038	331	Economy	7200.00
0005433568053	331	Economy	7200.00
0005432238832	331	Economy	7200.00
0005433568060	331	Economy	7200.00
0005433568054	331	Economy	7200.00
0005433568040	331	Economy	7200.00
0005432238829	331	Economy	7200.00
0005433568066	331	Economy	7200.00
0005433568067	331	Economy	7200.00
0005433568042	331	Economy	7200.00
0005433568027	331	Economy	7200.00
0005433568063	331	Economy	7200.00
0005433568028	331	Economy	7200.00
0005432238831	331	Economy	7200.00
0005432238828	331	Economy	7200.00
0005432238830	331	Economy	7200.00
0005433568032	331	Economy	7200.00
0005433568044	331	Economy	7200.00
0005433568023	331	Economy	7200.00
0005433568046	331	Economy	7200.00
0005433568049	331	Economy	7200.00
0005433568047	331	Economy	7900.00
0005433568052	331	Economy	7200.00
0005433568020	331	Economy	7200.00
0005433568039	331	Economy	7200.00
0005433568048	331	Economy	7200.00
0005433568050	331	Economy	7200.00
0005433568056	331	Economy	7200.00
0005433568031	331	Economy	7200.00
0005433568030	331	Economy	7200.00
0005433568035	331	Economy	7200.00
0005433568058	331	Economy	7200.00
0005433568059	331	Economy	7200.00
0005433568062	331	Economy	7200.00
0005432238827	331	Economy	7200.00
0005433568015	331	Economy	7200.00
0005433568025	331	Economy	7200.00
0005433568016	331	Economy	7200.00
0005433568068	331	Economy	7200.00
0005433568064	331	Economy	7200.00
0005433568055	331	Economy	7200.00
0005433568017	331	Economy	7200.00
0005433568051	331	Economy	7200.00
0005433568026	331	Economy	7200.00
0005433568024	331	Economy	7200.00
0005433568021	331	Economy	7200.00
0005433074208	11606	Business	21500.00
0005432192264	11606	Business	21500.00
0005433134056	11606	Business	21500.00
0005433074209	11606	Business	21500.00
0005433074217	11606	Business	21500.00
0005433074203	11606	Business	21500.00
0005433074216	11606	Business	21500.00
0005433074213	11606	Business	21500.00
0005433074204	11606	Economy	7900.00
0005433074219	11606	Economy	7200.00
0005432192265	11606	Economy	7200.00
0005433074225	11606	Economy	7200.00
0005433074214	11606	Economy	7200.00
0005433074199	11606	Economy	7200.00
0005433074197	11606	Economy	7200.00
0005433074207	11606	Economy	7200.00
0005433074196	11606	Economy	7200.00
0005433074211	11606	Economy	7200.00
0005433131627	11606	Economy	7200.00
0005433134059	11606	Economy	7200.00
0005433134058	11606	Economy	7200.00
0005433131629	11606	Economy	7200.00
0005433074222	11606	Economy	7200.00
0005433074205	11606	Economy	7200.00
0005433074218	11606	Economy	7200.00
0005433074210	11606	Economy	7200.00
0005433074201	11606	Economy	7200.00
0005432192263	11606	Economy	7900.00
0005433074223	11606	Economy	7200.00
0005433131626	11606	Economy	7900.00
0005433074212	11606	Economy	7200.00
0005433074200	11606	Economy	7200.00
0005433074221	11606	Economy	7200.00
0005433131628	11606	Economy	7200.00
0005433134057	11606	Economy	7200.00
0005433074206	11606	Economy	7200.00
0005433074198	11606	Economy	7200.00
0005433074220	11606	Economy	7200.00
0005433074224	11606	Economy	7200.00
0005433074215	11606	Economy	7200.00
0005433074202	11606	Economy	7200.00
0005433817405	10005	Economy	6300.00
0005433817407	10005	Economy	6300.00
0005433817406	10005	Economy	6300.00
0005433817404	10005	Economy	6300.00
0005434732921	13968	Economy	6300.00
0005434732918	13968	Economy	6300.00
0005434732920	13968	Economy	6300.00
0005434732919	13968	Economy	6300.00
0005433753223	2323	Business	184500.00
0005433753243	2323	Business	184500.00
0005432655337	2323	Business	184500.00
0005432655327	2323	Business	184500.00
0005433753278	2323	Business	184500.00
0005435981535	2323	Business	184500.00
0005433753262	2323	Business	184500.00
0005433753275	2323	Business	184500.00
0005435981511	2323	Business	184500.00
0005433753244	2323	Business	184500.00
0005433753246	2323	Business	184500.00
0005433753273	2323	Business	184500.00
0005432225946	2323	Business	184500.00
0005435981527	2323	Business	184500.00
0005435981514	2323	Business	184500.00
0005435981510	2323	Business	184500.00
0005433753267	2323	Business	184500.00
0005432655334	2323	Business	184500.00
0005435981519	2323	Economy	67700.00
0005433753268	2323	Economy	61500.00
0005435981537	2323	Economy	61500.00
0005432655335	2323	Economy	61500.00
0005433753249	2323	Economy	61500.00
0005435981513	2323	Economy	61500.00
0005435981534	2323	Economy	61500.00
0005433753269	2323	Economy	61500.00
0005433753258	2323	Economy	61500.00
0005435981533	2323	Economy	61500.00
0005435981509	2323	Economy	61500.00
0005433753228	2323	Economy	61500.00
0005433753227	2323	Economy	61500.00
0005433753240	2323	Economy	61500.00
0005435981515	2323	Economy	61500.00
0005433753251	2323	Economy	61500.00
0005433753221	2323	Economy	61500.00
0005433753241	2323	Economy	61500.00
0005433753271	2323	Economy	61500.00
0005432300163	2323	Economy	61500.00
0005433753239	2323	Economy	61500.00
0005433753250	2323	Economy	61500.00
0005435981528	2323	Economy	61500.00
0005432225947	2323	Economy	61500.00
0005435981545	2323	Economy	61500.00
0005433753253	2323	Economy	61500.00
0005433753266	2323	Economy	61500.00
0005435981518	2323	Economy	61500.00
0005433753224	2323	Economy	61500.00
0005433753242	2323	Economy	61500.00
0005432655331	2323	Economy	61500.00
0005433753254	2323	Economy	61500.00
0005432300165	2323	Economy	61500.00
0005433753232	2323	Economy	61500.00
0005435981540	2323	Economy	61500.00
0005433753259	2323	Economy	61500.00
0005433753237	2323	Economy	61500.00
0005433764644	2323	Economy	61500.00
0005433753233	2323	Economy	61500.00
0005433764643	2323	Economy	61500.00
0005435981546	2323	Economy	61500.00
0005435981523	2323	Economy	61500.00
0005435981543	2323	Economy	61500.00
0005433766573	2323	Economy	61500.00
0005435981531	2323	Economy	61500.00
0005433753261	2323	Economy	61500.00
0005435981542	2323	Economy	61500.00
0005432300161	2323	Economy	61500.00
0005432655332	2323	Economy	61500.00
0005433753255	2323	Economy	61500.00
0005432655333	2323	Economy	61500.00
0005433753235	2323	Economy	61500.00
0005435981530	2323	Economy	61500.00
0005433753263	2323	Economy	61500.00
0005435981547	2323	Economy	61500.00
0005435981517	2323	Economy	61500.00
0005435981516	2323	Economy	61500.00
0005433753245	2323	Economy	61500.00
0005433753272	2323	Economy	61500.00
0005433753230	2323	Economy	61500.00
0005433753225	2323	Economy	61500.00
0005435981539	2323	Economy	61500.00
0005432655336	2323	Economy	67700.00
0005432225952	2323	Economy	61500.00
0005433766575	2323	Economy	61500.00
0005433753231	2323	Economy	61500.00
0005433753277	2323	Economy	67700.00
0005432655328	2323	Economy	67700.00
0005432225950	2323	Economy	61500.00
0005433753238	2323	Economy	61500.00
0005432300162	2323	Economy	61500.00
0005433753229	2323	Economy	61500.00
0005435981522	2323	Economy	61500.00
0005433753260	2323	Economy	61500.00
0005432225949	2323	Economy	61500.00
0005435981521	2323	Economy	61500.00
0005435981532	2323	Economy	61500.00
0005433753265	2323	Economy	61500.00
0005433753274	2323	Economy	61500.00
0005433753247	2323	Economy	61500.00
0005432225951	2323	Economy	61500.00
0005435981536	2323	Economy	61500.00
0005435981526	2323	Economy	61500.00
0005432655326	2323	Economy	61500.00
0005435981538	2323	Economy	61500.00
0005435981529	2323	Economy	61500.00
0005433753256	2323	Economy	61500.00
0005433766572	2323	Economy	61500.00
0005433753226	2323	Economy	61500.00
0005435981508	2323	Economy	61500.00
0005433753248	2323	Economy	61500.00
0005432300164	2323	Economy	61500.00
0005433753222	2323	Economy	61500.00
0005435981520	2323	Economy	61500.00
0005433753234	2323	Economy	61500.00
0005435981512	2323	Economy	61500.00
0005433753236	2323	Economy	61500.00
0005433753270	2323	Economy	61500.00
0005435981544	2323	Economy	61500.00
0005433753264	2323	Economy	61500.00
0005433753257	2323	Economy	61500.00
0005432655330	2323	Economy	61500.00
0005435981541	2323	Economy	61500.00
0005433753252	2323	Economy	61500.00
0005432655329	2323	Economy	61500.00
0005435981524	2323	Economy	61500.00
0005433766574	2323	Economy	61500.00
0005433753276	2323	Economy	61500.00
0005432225948	2323	Economy	61500.00
0005435981525	2323	Economy	61500.00
0005432984529	26185	Business	184500.00
0005432051075	26185	Business	184500.00
0005433434188	26185	Business	184500.00
0005433434192	26185	Business	184500.00
0005432984518	26185	Business	184500.00
0005432984503	26185	Business	184500.00
0005433434184	26185	Business	184500.00
0005432984526	26185	Business	184500.00
0005433434195	26185	Business	184500.00
0005432984506	26185	Business	184500.00
0005432984530	26185	Business	184500.00
0005433434186	26185	Economy	67700.00
0005432984514	26185	Economy	61500.00
0005433434203	26185	Economy	61500.00
0005433434181	26185	Economy	61500.00
0005432984510	26185	Economy	61500.00
0005432984501	26185	Economy	61500.00
0005432984524	26185	Economy	61500.00
0005433434187	26185	Economy	61500.00
0005432984507	26185	Economy	61500.00
0005432984527	26185	Economy	61500.00
0005433434189	26185	Economy	61500.00
0005432984511	26185	Economy	61500.00
0005432984505	26185	Economy	61500.00
0005432984516	26185	Economy	61500.00
0005434731099	26185	Economy	61500.00
0005433434185	26185	Economy	61500.00
0005433434204	26185	Economy	61500.00
0005433434193	26185	Economy	61500.00
0005433434182	26185	Economy	61500.00
0005432984504	26185	Economy	61500.00
0005433434202	26185	Economy	61500.00
0005432984502	26185	Economy	61500.00
0005433434197	26185	Economy	61500.00
0005433434198	26185	Economy	61500.00
0005432984515	26185	Economy	61500.00
0005433434199	26185	Economy	61500.00
0005432984520	26185	Economy	61500.00
0005434731097	26185	Economy	61500.00
0005434731096	26185	Economy	61500.00
0005433434201	26185	Economy	67700.00
0005433434207	26185	Economy	61500.00
0005433434180	26185	Economy	61500.00
0005433434208	26185	Economy	61500.00
0005432984512	26185	Economy	61500.00
0005434731098	26185	Economy	61500.00
0005432051076	26185	Economy	61500.00
0005432049402	26185	Economy	61500.00
0005432984508	26185	Economy	61500.00
0005432984509	26185	Economy	61500.00
0005433434190	26185	Economy	61500.00
0005433434194	26185	Economy	61500.00
0005432051074	26185	Economy	61500.00
0005432049400	26185	Economy	61500.00
0005432984513	26185	Economy	61500.00
0005432984521	26185	Economy	61500.00
0005433434196	26185	Economy	61500.00
0005432984519	26185	Economy	61500.00
0005432984531	26185	Economy	61500.00
0005432984532	26185	Economy	61500.00
0005433434191	26185	Economy	61500.00
0005432984523	26185	Economy	61500.00
0005432984522	26185	Economy	61500.00
0005433434200	26185	Economy	61500.00
0005433434183	26185	Economy	61500.00
0005432984517	26185	Economy	61500.00
0005432984500	26185	Economy	61500.00
0005432049401	26185	Economy	61500.00
0005432984525	26185	Economy	61500.00
0005433434206	26185	Economy	61500.00
0005433434205	26185	Economy	61500.00
0005432984528	26185	Economy	61500.00
0005434373852	1521	Business	38900.00
0005434373860	1521	Business	38900.00
0005434373851	1521	Business	38900.00
0005434373859	1521	Business	38900.00
0005434373870	1521	Business	38900.00
0005434373884	1521	Business	38900.00
0005433460399	1521	Business	38900.00
0005434373856	1521	Economy	13000.00
0005434373887	1521	Economy	13000.00
0005434373897	1521	Economy	13000.00
0005432267782	1521	Economy	13000.00
0005434373874	1521	Economy	13000.00
0005434373854	1521	Economy	13000.00
0005433461550	1521	Economy	13000.00
0005434373857	1521	Economy	13000.00
0005434373846	1521	Economy	13000.00
0005434373872	1521	Economy	13000.00
0005434373855	1521	Economy	13000.00
0005434373879	1521	Economy	13000.00
0005434373890	1521	Economy	13000.00
0005434373876	1521	Economy	13000.00
0005432267778	1521	Economy	13000.00
0005434373867	1521	Economy	13000.00
0005434373869	1521	Economy	13000.00
0005434373861	1521	Economy	13000.00
0005434373847	1521	Economy	13000.00
0005434373878	1521	Economy	14300.00
0005434373894	1521	Economy	14300.00
0005434373881	1521	Economy	14300.00
0005434373891	1521	Economy	14300.00
0005434373873	1521	Economy	14300.00
0005434373888	1521	Economy	13000.00
0005434373895	1521	Economy	13000.00
0005434373877	1521	Economy	13000.00
0005433460398	1521	Economy	13000.00
0005434373853	1521	Economy	13000.00
0005434373864	1521	Economy	13000.00
0005434373893	1521	Economy	13000.00
0005434373849	1521	Economy	13000.00
0005434373885	1521	Economy	13000.00
0005432267780	1521	Economy	13000.00
0005434373880	1521	Economy	13000.00
0005434373848	1521	Economy	13000.00
0005434373883	1521	Economy	13000.00
0005434373862	1521	Economy	13000.00
0005434373875	1521	Economy	13000.00
0005432267779	1521	Economy	13000.00
0005434373863	1521	Economy	13000.00
0005433461551	1521	Economy	13000.00
0005434373882	1521	Economy	13000.00
0005432267777	1521	Economy	13000.00
0005434373865	1521	Economy	13000.00
0005434373868	1521	Economy	13000.00
0005434373889	1521	Economy	13000.00
0005432267781	1521	Economy	13000.00
0005434373886	1521	Economy	13000.00
0005434373866	1521	Economy	13000.00
0005434373850	1521	Economy	13000.00
0005434373871	1521	Economy	13000.00
0005434373858	1521	Economy	13000.00
0005434373892	1521	Economy	13000.00
0005434373896	1521	Economy	13000.00
0005433150802	20159	Business	38900.00
0005433150806	20159	Business	38900.00
0005433150801	20159	Business	38900.00
0005433931415	20159	Business	38900.00
0005433150825	20159	Business	38900.00
0005433150796	20159	Economy	13000.00
0005433931414	20159	Economy	13000.00
0005432056231	20159	Economy	13000.00
0005433150820	20159	Economy	13000.00
0005432056232	20159	Economy	13000.00
0005433150817	20159	Economy	13000.00
0005432056233	20159	Economy	13000.00
0005433150808	20159	Economy	13000.00
0005433150809	20159	Economy	13000.00
0005433931413	20159	Economy	13000.00
0005433150819	20159	Economy	13000.00
0005433150804	20159	Economy	13000.00
0005434029615	20159	Economy	13000.00
0005433150795	20159	Economy	14300.00
0005433764643	20159	Economy	14300.00
0005433150816	20159	Economy	14300.00
0005433150812	20159	Economy	14300.00
0005433150799	20159	Economy	13000.00
0005433150818	20159	Economy	13000.00
0005432056234	20159	Economy	13000.00
0005433931416	20159	Economy	13000.00
0005433150803	20159	Economy	13000.00
0005433150826	20159	Economy	13000.00
0005433150821	20159	Economy	13000.00
0005434029613	20159	Economy	13000.00
0005433150807	20159	Economy	13000.00
0005433150797	20159	Economy	13000.00
0005433150824	20159	Economy	13000.00
0005433150794	20159	Economy	13000.00
0005433150822	20159	Economy	13000.00
0005433150813	20159	Economy	13000.00
0005433150811	20159	Economy	13000.00
0005433150815	20159	Economy	13000.00
0005434029614	20159	Economy	13000.00
0005433150810	20159	Economy	13000.00
0005433150805	20159	Economy	13000.00
0005433150800	20159	Economy	13000.00
0005433150814	20159	Economy	13000.00
0005433150798	20159	Economy	13000.00
0005433150823	20159	Economy	13000.00
0005433150827	20159	Economy	13000.00
0005433764644	20159	Economy	13000.00
0005432423614	533	Business	27500.00
0005432423631	533	Business	27500.00
0005432282742	533	Business	27500.00
0005432282744	533	Business	27500.00
0005432423633	533	Economy	10100.00
0005432423621	533	Economy	10100.00
0005432423607	533	Economy	9200.00
0005432423644	533	Economy	9200.00
0005432423626	533	Economy	9200.00
0005432423605	533	Economy	9200.00
0005432423612	533	Economy	9200.00
0005432282745	533	Economy	9200.00
0005432423618	533	Economy	9200.00
0005432282740	533	Economy	9200.00
0005432423634	533	Economy	9200.00
0005432423623	533	Economy	9200.00
0005432423642	533	Economy	9200.00
0005432423637	533	Economy	9200.00
0005432423632	533	Economy	9200.00
0005432423645	533	Economy	9200.00
0005432423630	533	Economy	9200.00
0005432423604	533	Economy	9200.00
0005432423617	533	Economy	9200.00
0005432423616	533	Economy	9200.00
0005432423643	533	Economy	9200.00
0005432282746	533	Economy	9200.00
0005432423609	533	Economy	9200.00
0005432423610	533	Economy	10100.00
0005432423635	533	Economy	10100.00
0005432423639	533	Economy	9200.00
0005432423646	533	Economy	9200.00
0005432423638	533	Economy	9200.00
0005432423606	533	Economy	9200.00
0005432423628	533	Economy	9200.00
0005432423627	533	Economy	9200.00
0005432423622	533	Economy	9200.00
0005432282739	533	Economy	9200.00
0005432423611	533	Economy	9200.00
0005432423641	533	Economy	9200.00
0005432423640	533	Economy	9200.00
0005432423636	533	Economy	9200.00
0005432423613	533	Economy	9200.00
0005432423625	533	Economy	9200.00
0005432423620	533	Economy	9200.00
0005432423608	533	Economy	9200.00
0005432282743	533	Economy	9200.00
0005432423619	533	Economy	9200.00
0005432423624	533	Economy	9200.00
0005432423629	533	Economy	9200.00
0005432282741	533	Economy	9200.00
0005432423647	533	Economy	9200.00
0005432423615	533	Economy	9200.00
0005432302265	12840	Business	27500.00
0005432302266	12840	Economy	9200.00
0005433158094	12840	Economy	9200.00
0005433158093	12840	Economy	9200.00
0005434022558	478	Business	24500.00
0005434022550	478	Business	24500.00
0005432235505	478	Business	24500.00
0005434022515	478	Business	24500.00
0005434022561	478	Business	24500.00
0005434022537	478	Business	24500.00
0005434022536	478	Business	24500.00
0005434022507	478	Business	24500.00
0005434022534	478	Business	24500.00
0005432235507	478	Business	24500.00
0005434022547	478	Economy	8200.00
0005434022528	478	Economy	8200.00
0005434022520	478	Economy	8200.00
0005434022502	478	Economy	8200.00
0005434022553	478	Economy	8200.00
0005434022525	478	Economy	8200.00
0005434022506	478	Economy	8200.00
0005434022503	478	Economy	8200.00
0005434022562	478	Economy	8200.00
0005434022541	478	Economy	8200.00
0005434022565	478	Economy	8200.00
0005434022521	478	Economy	8200.00
0005432235508	478	Economy	8200.00
0005434022527	478	Economy	8200.00
0005432235512	478	Economy	8200.00
0005434022542	478	Economy	8200.00
0005434022512	478	Economy	8200.00
0005434022524	478	Economy	8200.00
0005434022519	478	Economy	8200.00
0005434022508	478	Economy	8200.00
0005432235506	478	Economy	8200.00
0005434022556	478	Economy	8200.00
0005434022510	478	Economy	8200.00
0005434022538	478	Economy	8200.00
0005434022567	478	Economy	8200.00
0005434022530	478	Economy	8200.00
0005434022539	478	Economy	8200.00
0005434022533	478	Economy	8200.00
0005434022516	478	Economy	8200.00
0005434022531	478	Economy	8200.00
0005434022505	478	Economy	8200.00
0005434022523	478	Economy	8200.00
0005434022535	478	Economy	8200.00
0005434022568	478	Economy	8200.00
0005434022548	478	Economy	8200.00
0005434022540	478	Economy	9000.00
0005434022549	478	Economy	8200.00
0005434022564	478	Economy	8200.00
0005434022513	478	Economy	8200.00
0005434022552	478	Economy	8200.00
0005434022529	478	Economy	8200.00
0005432235509	478	Economy	8200.00
0005434022517	478	Economy	8200.00
0005434022545	478	Economy	8200.00
0005434022557	478	Economy	8200.00
0005434022546	478	Economy	8200.00
0005434022518	478	Economy	8200.00
0005432235510	478	Economy	8200.00
0005434022560	478	Economy	8200.00
0005434022544	478	Economy	8200.00
0005434022543	478	Economy	8200.00
0005434022563	478	Economy	8200.00
0005434022509	478	Economy	8200.00
0005432235504	478	Economy	8200.00
0005434022522	478	Economy	8200.00
0005434022555	478	Economy	8200.00
0005434022566	478	Economy	8200.00
0005434022511	478	Economy	8200.00
0005434022551	478	Economy	8200.00
0005432235511	478	Economy	8200.00
0005434022504	478	Economy	8200.00
0005434022532	478	Economy	8200.00
0005434022559	478	Economy	8200.00
0005434022514	478	Economy	8200.00
0005434022501	478	Economy	8200.00
0005434022526	478	Economy	8200.00
0005434022569	478	Economy	8200.00
0005434022554	478	Economy	8200.00
0005432156288	12679	Business	24500.00
0005434735601	12679	Business	24500.00
0005433057203	12679	Business	24500.00
0005433057204	12679	Business	24500.00
0005433929541	12679	Business	24500.00
0005433057179	12679	Business	24500.00
0005433057198	12679	Business	24500.00
0005433057182	12679	Business	24500.00
0005433057190	12679	Economy	9000.00
0005433057194	12679	Economy	8200.00
0005433929539	12679	Economy	8200.00
0005433057206	12679	Economy	8200.00
0005433057196	12679	Economy	8200.00
0005433929540	12679	Economy	8200.00
0005433057168	12679	Economy	8200.00
0005433057187	12679	Economy	8200.00
0005433057181	12679	Economy	8200.00
0005433057191	12679	Economy	8200.00
0005433057176	12679	Economy	8200.00
0005433057174	12679	Economy	8200.00
0005433057169	12679	Economy	8200.00
0005433057170	12679	Economy	8200.00
0005433057197	12679	Economy	8200.00
0005432156289	12679	Economy	8200.00
0005433057178	12679	Economy	8200.00
0005433057183	12679	Economy	8200.00
0005433057172	12679	Economy	8200.00
0005433057193	12679	Economy	8200.00
0005433057188	12679	Economy	8200.00
0005432156290	12679	Economy	8200.00
0005433057180	12679	Economy	8200.00
0005432156286	12679	Economy	8200.00
0005432157457	12679	Economy	8200.00
0005433057202	12679	Economy	8200.00
0005433057189	12679	Economy	8200.00
0005433057200	12679	Economy	8200.00
0005433057173	12679	Economy	8200.00
0005433057205	12679	Economy	8200.00
0005433057184	12679	Economy	9000.00
0005433057175	12679	Economy	8200.00
0005433057195	12679	Economy	8200.00
0005433057186	12679	Economy	8200.00
0005433057199	12679	Economy	8200.00
0005432156287	12679	Economy	8200.00
0005433057201	12679	Economy	8200.00
0005433057208	12679	Economy	8200.00
0005434735600	12679	Economy	8200.00
0005433057192	12679	Economy	8200.00
0005433929542	12679	Economy	8200.00
0005434735599	12679	Economy	8200.00
0005433057185	12679	Economy	8200.00
0005433684385	12679	Economy	8200.00
0005432157458	12679	Economy	8200.00
0005433684384	12679	Economy	8200.00
0005434735597	12679	Economy	8200.00
0005433057207	12679	Economy	8200.00
0005433057171	12679	Economy	8200.00
0005434735598	12679	Economy	8200.00
0005433057177	12679	Economy	8200.00
0005433921597	2140	Business	34700.00
0005433921601	2140	Business	34700.00
0005432231380	2140	Business	34700.00
0005433921643	2140	Business	34700.00
0005433929540	2140	Business	34700.00
0005433921659	2140	Business	34700.00
0005433931415	2140	Business	34700.00
0005433921667	2140	Business	34700.00
0005433921590	2140	Business	34700.00
0005433921623	2140	Business	34700.00
0005433921655	2140	Business	34700.00
0005433921665	2140	Business	34700.00
0005433921605	2140	Business	34700.00
0005433921624	2140	Business	34700.00
0005432231376	2140	Business	34700.00
0005433921621	2140	Business	34700.00
0005432231384	2140	Economy	12700.00
0005433921673	2140	Economy	12700.00
0005433921661	2140	Economy	12700.00
0005433921650	2140	Economy	11600.00
0005432044477	2140	Economy	11600.00
0005433929539	2140	Economy	11600.00
0005433921632	2140	Economy	11600.00
0005433921594	2140	Economy	11600.00
0005433921660	2140	Economy	11600.00
0005433921639	2140	Economy	11600.00
0005433921642	2140	Economy	11600.00
0005433921684	2140	Economy	11600.00
0005433921668	2140	Economy	11600.00
0005433921680	2140	Economy	11600.00
0005433921603	2140	Economy	11600.00
0005433921615	2140	Economy	11600.00
0005432231377	2140	Economy	11600.00
0005433921600	2140	Economy	11600.00
0005433921629	2140	Economy	11600.00
0005433931416	2140	Economy	11600.00
0005433921675	2140	Economy	11600.00
0005433921611	2140	Economy	11600.00
0005433921619	2140	Economy	11600.00
0005433921656	2140	Economy	11600.00
0005433921654	2140	Economy	11600.00
0005433921618	2140	Economy	11600.00
0005433921666	2140	Economy	11600.00
0005433921634	2140	Economy	11600.00
0005433921630	2140	Economy	11600.00
0005433921644	2140	Economy	11600.00
0005433921636	2140	Economy	11600.00
0005433921671	2140	Economy	11600.00
0005433921648	2140	Economy	11600.00
0005433931414	2140	Economy	11600.00
0005433921587	2140	Economy	11600.00
0005433921649	2140	Economy	11600.00
0005433921622	2140	Economy	11600.00
0005433921682	2140	Economy	11600.00
0005433921664	2140	Economy	11600.00
0005433921683	2140	Economy	11600.00
0005433921638	2140	Economy	11600.00
0005432231379	2140	Economy	11600.00
0005432044476	2140	Economy	11600.00
0005433921606	2140	Economy	11600.00
0005433921633	2140	Economy	11600.00
0005433921646	2140	Economy	11600.00
0005433921598	2140	Economy	11600.00
0005433921610	2140	Economy	11600.00
0005433921672	2140	Economy	11600.00
0005432231378	2140	Economy	11600.00
0005433921626	2140	Economy	11600.00
0005433921658	2140	Economy	11600.00
0005433921663	2140	Economy	11600.00
0005433921676	2140	Economy	11600.00
0005433921631	2140	Economy	11600.00
0005433921662	2140	Economy	11600.00
0005433921670	2140	Economy	12700.00
0005433921645	2140	Economy	11600.00
0005433921678	2140	Economy	11600.00
0005432044475	2140	Economy	11600.00
0005433921608	2140	Economy	12700.00
0005433921681	2140	Economy	11600.00
0005433921669	2140	Economy	11600.00
0005432231375	2140	Economy	11600.00
0005433921637	2140	Economy	11600.00
0005433921652	2140	Economy	11600.00
0005433921604	2140	Economy	11600.00
0005433931413	2140	Economy	11600.00
0005433921641	2140	Economy	11600.00
0005433921635	2140	Economy	11600.00
0005433921651	2140	Economy	11600.00
0005432231383	2140	Economy	11600.00
0005433921627	2140	Economy	11600.00
0005433921628	2140	Economy	11600.00
0005433921647	2140	Economy	11600.00
0005433921588	2140	Economy	11600.00
0005433929542	2140	Economy	11600.00
0005433921620	2140	Economy	11600.00
0005433921674	2140	Economy	11600.00
0005433921614	2140	Economy	11600.00
0005433921653	2140	Economy	11600.00
0005433921679	2140	Economy	11600.00
0005433921595	2140	Economy	11600.00
0005433921613	2140	Economy	11600.00
0005433921616	2140	Economy	11600.00
0005433921677	2140	Economy	11600.00
0005432231382	2140	Economy	11600.00
0005433921612	2140	Economy	11600.00
0005432231381	2140	Economy	11600.00
0005433921589	2140	Economy	11600.00
0005433921609	2140	Economy	11600.00
0005433921602	2140	Economy	11600.00
0005433921640	2140	Economy	11600.00
0005433921657	2140	Economy	11600.00
0005433921593	2140	Economy	11600.00
0005433929541	2140	Economy	11600.00
0005433921617	2140	Economy	11600.00
0005433921592	2140	Economy	11600.00
0005433921599	2140	Economy	11600.00
0005433921625	2140	Economy	11600.00
0005432231374	2140	Economy	11600.00
0005433921596	2140	Economy	11600.00
0005433921591	2140	Economy	11600.00
0005433921607	2140	Economy	11600.00
0005433035392	24118	Business	34700.00
0005433035386	24118	Business	34700.00
0005433035391	24118	Business	34700.00
0005433035374	24118	Business	34700.00
0005433035377	24118	Business	34700.00
0005433035396	24118	Business	34700.00
0005433035388	24118	Business	34700.00
0005433035390	24118	Economy	12700.00
0005433035364	24118	Economy	11600.00
0005433035369	24118	Economy	11600.00
0005433035398	24118	Economy	11600.00
0005433035378	24118	Economy	11600.00
0005432206096	24118	Economy	11600.00
0005432207616	24118	Economy	11600.00
0005433035381	24118	Economy	11600.00
0005433035379	24118	Economy	11600.00
0005433035393	24118	Economy	11600.00
0005433035384	24118	Economy	11600.00
0005433035383	24118	Economy	11600.00
0005433035356	24118	Economy	11600.00
0005433035370	24118	Economy	11600.00
0005432207617	24118	Economy	11600.00
0005433035409	24118	Economy	11600.00
0005433035358	24118	Economy	11600.00
0005433035380	24118	Economy	11600.00
0005433035397	24118	Economy	11600.00
0005433035373	24118	Economy	11600.00
0005433035403	24118	Economy	11600.00
0005432206094	24118	Economy	11600.00
0005433035366	24118	Economy	11600.00
0005433035368	24118	Economy	11600.00
0005432206091	24118	Economy	11600.00
0005433035404	24118	Economy	11600.00
0005433035406	24118	Economy	11600.00
0005433035371	24118	Economy	11600.00
0005433035365	24118	Economy	11600.00
0005433035407	24118	Economy	11600.00
0005433035375	24118	Economy	11600.00
0005434028249	24118	Economy	11600.00
0005433035372	24118	Economy	11600.00
0005433035385	24118	Economy	11600.00
0005433035405	24118	Economy	11600.00
0005433035387	24118	Economy	11600.00
0005432207618	24118	Economy	11600.00
0005432206093	24118	Economy	12700.00
0005433035394	24118	Economy	11600.00
0005433035367	24118	Economy	11600.00
0005433035363	24118	Economy	11600.00
0005433035376	24118	Economy	11600.00
0005433035399	24118	Economy	11600.00
0005434028247	24118	Economy	11600.00
0005432206095	24118	Economy	11600.00
0005433035360	24118	Economy	11600.00
0005433035410	24118	Economy	11600.00
0005433035357	24118	Economy	11600.00
0005433035361	24118	Economy	11600.00
0005433035389	24118	Economy	11600.00
0005433035395	24118	Economy	11600.00
0005433035359	24118	Economy	11600.00
0005433035400	24118	Economy	11600.00
0005433035362	24118	Economy	11600.00
0005434028246	24118	Economy	11600.00
0005432206092	24118	Economy	11600.00
0005432749747	24118	Economy	11600.00
0005433035408	24118	Economy	11600.00
0005433035402	24118	Economy	11600.00
0005433035401	24118	Economy	11600.00
0005433035382	24118	Economy	11600.00
0005434028248	24118	Economy	11600.00
0005432749748	24118	Economy	11600.00
0005434723419	277	Business	83700.00
0005434550284	277	Business	83700.00
0005434723381	277	Business	83700.00
0005434723410	277	Business	83700.00
0005434723388	277	Business	83700.00
0005434550256	277	Business	83700.00
0005434550305	277	Business	83700.00
0005434550307	277	Business	83700.00
0005434723407	277	Business	83700.00
0005434723327	277	Business	83700.00
0005434550275	277	Business	83700.00
0005435142344	277	Business	83700.00
0005434723343	277	Business	83700.00
0005434723399	277	Business	83700.00
0005434723421	277	Business	83700.00
0005434550303	277	Business	83700.00
0005434723346	277	Business	83700.00
0005434723394	277	Comfort	47400.00
0005434723349	277	Comfort	47400.00
0005434550294	277	Comfort	47400.00
0005432277569	277	Comfort	47400.00
0005434302381	277	Comfort	47400.00
0005434723352	277	Comfort	47400.00
0005434550293	277	Comfort	47400.00
0005432277572	277	Comfort	47400.00
0005434723359	277	Comfort	47400.00
0005434723325	277	Comfort	47400.00
0005434723391	277	Comfort	47400.00
0005434550288	277	Comfort	47400.00
0005434550270	277	Comfort	47400.00
0005434723402	277	Comfort	47400.00
0005435142348	277	Comfort	47400.00
0005434550281	277	Comfort	47400.00
0005432277575	277	Comfort	47400.00
0005434550276	277	Comfort	47400.00
0005434550263	277	Comfort	47400.00
0005434723373	277	Comfort	47400.00
0005434723337	277	Comfort	47400.00
0005434723378	277	Comfort	47400.00
0005434723329	277	Economy	27900.00
0005434550286	277	Economy	27900.00
0005434723431	277	Economy	27900.00
0005434550299	277	Economy	27900.00
0005434550260	277	Economy	27900.00
0005434550267	277	Economy	27900.00
0005432277580	277	Economy	27900.00
0005434723334	277	Economy	27900.00
0005434723355	277	Economy	27900.00
0005434550291	277	Economy	27900.00
0005432277574	277	Economy	27900.00
0005434723396	277	Economy	27900.00
0005434550258	277	Economy	27900.00
0005434723395	277	Economy	27900.00
0005435142337	277	Economy	27900.00
0005434723312	277	Economy	27900.00
0005434550277	277	Economy	27900.00
0005434723379	277	Economy	27900.00
0005434550279	277	Economy	27900.00
0005434723351	277	Economy	27900.00
0005434723360	277	Economy	27900.00
0005434723314	277	Economy	27900.00
0005434723424	277	Economy	27900.00
0005434550283	277	Economy	27900.00
0005434723389	277	Economy	27900.00
0005434723414	277	Economy	27900.00
0005434550306	277	Economy	27900.00
0005434550287	277	Economy	27900.00
0005435142347	277	Economy	27900.00
0005434723433	277	Economy	27900.00
0005434723423	277	Economy	27900.00
0005434550309	277	Economy	27900.00
0005434723320	277	Economy	27900.00
0005434723345	277	Economy	27900.00
0005434723365	277	Economy	27900.00
0005435142341	277	Economy	27900.00
0005434302382	277	Economy	27900.00
0005432277577	277	Economy	27900.00
0005435142342	277	Economy	27900.00
0005434723393	277	Economy	30700.00
0005434723366	277	Economy	30700.00
0005434550269	277	Economy	27900.00
0005434723356	277	Economy	27900.00
0005434723335	277	Economy	27900.00
0005434723357	277	Economy	30700.00
0005434550265	277	Economy	27900.00
0005435142346	277	Economy	27900.00
0005435142343	277	Economy	27900.00
0005434550268	277	Economy	27900.00
0005434723374	277	Economy	27900.00
0005434550259	277	Economy	27900.00
0005434723417	277	Economy	27900.00
0005434723406	277	Economy	27900.00
0005434723316	277	Economy	27900.00
0005434723418	277	Economy	27900.00
0005434723368	277	Economy	27900.00
0005432277581	277	Economy	27900.00
0005434723386	277	Economy	27900.00
0005434550262	277	Economy	27900.00
0005434550264	277	Economy	27900.00
0005434723430	277	Economy	27900.00
0005434723403	277	Economy	27900.00
0005434723333	277	Economy	27900.00
0005434723390	277	Economy	27900.00
0005434723341	277	Economy	27900.00
0005434550310	277	Economy	27900.00
0005434723321	277	Economy	27900.00
0005432277571	277	Economy	27900.00
0005434723432	277	Economy	27900.00
0005434723408	277	Economy	27900.00
0005434550280	277	Economy	27900.00
0005434723319	277	Economy	27900.00
0005434723330	277	Economy	27900.00
0005434723411	277	Economy	27900.00
0005434723369	277	Economy	27900.00
0005434550257	277	Economy	27900.00
0005434723323	277	Economy	27900.00
0005434723380	277	Economy	27900.00
0005434723370	277	Economy	27900.00
0005434723354	277	Economy	27900.00
0005434550300	277	Economy	27900.00
0005434723363	277	Economy	27900.00
0005435142340	277	Economy	27900.00
0005434723383	277	Economy	27900.00
0005434550301	277	Economy	27900.00
0005434302853	277	Economy	27900.00
0005434723364	277	Economy	27900.00
0005434723313	277	Economy	27900.00
0005434723331	277	Economy	27900.00
0005434723413	277	Economy	27900.00
0005434723342	277	Economy	27900.00
0005435142335	277	Economy	27900.00
0005434723398	277	Economy	27900.00
0005434723404	277	Economy	27900.00
0005434723427	277	Economy	27900.00
0005434723362	277	Economy	27900.00
0005434723416	277	Economy	27900.00
0005434723361	277	Economy	27900.00
0005434723382	277	Economy	27900.00
0005432277579	277	Economy	27900.00
0005434550272	277	Economy	27900.00
0005435142339	277	Economy	27900.00
0005434723353	277	Economy	27900.00
0005435142338	277	Economy	27900.00
0005434723412	277	Economy	27900.00
0005434723318	277	Economy	27900.00
0005434723387	277	Economy	27900.00
0005434302383	277	Economy	27900.00
0005434550278	277	Economy	27900.00
0005434550298	277	Economy	27900.00
0005434723409	277	Economy	27900.00
0005434723348	277	Economy	30700.00
0005434302384	277	Economy	30700.00
0005434723385	277	Economy	30700.00
0005434550261	277	Economy	27900.00
0005434723311	277	Economy	27900.00
0005434723336	277	Economy	27900.00
0005434723344	277	Economy	27900.00
0005435142336	277	Economy	27900.00
0005434723338	277	Economy	27900.00
0005434723367	277	Economy	27900.00
0005432277576	277	Economy	27900.00
0005434723392	277	Economy	27900.00
0005434723384	277	Economy	27900.00
0005432277573	277	Economy	27900.00
0005434550297	277	Economy	27900.00
0005434550266	277	Economy	27900.00
0005434550285	277	Economy	27900.00
0005434550302	277	Economy	27900.00
0005432277578	277	Economy	27900.00
0005434723428	277	Economy	27900.00
0005434723347	277	Economy	27900.00
0005434723332	277	Economy	27900.00
0005434723426	277	Economy	27900.00
0005434723339	277	Economy	27900.00
0005434723375	277	Economy	27900.00
0005434723425	277	Economy	27900.00
0005434723415	277	Economy	27900.00
0005434723317	277	Economy	27900.00
0005434723324	277	Economy	27900.00
0005434723315	277	Economy	27900.00
0005434723372	277	Economy	27900.00
0005434550290	277	Economy	27900.00
0005434723326	277	Economy	27900.00
0005434723350	277	Economy	27900.00
0005434723340	277	Economy	27900.00
0005434550308	277	Economy	27900.00
0005434723310	277	Economy	27900.00
0005434550274	277	Economy	27900.00
0005434723422	277	Economy	27900.00
0005434723401	277	Economy	27900.00
0005434550282	277	Economy	27900.00
0005434723376	277	Economy	27900.00
0005434723377	277	Economy	27900.00
0005434550289	277	Economy	27900.00
0005434302385	277	Economy	27900.00
0005434723429	277	Economy	27900.00
0005434550296	277	Economy	27900.00
0005434550273	277	Economy	27900.00
0005434723400	277	Economy	27900.00
0005434723322	277	Economy	27900.00
0005434723397	277	Economy	27900.00
0005434550295	277	Economy	27900.00
0005434550271	277	Economy	27900.00
0005434550304	277	Economy	27900.00
0005434723420	277	Economy	27900.00
0005434723358	277	Economy	27900.00
0005434723405	277	Economy	27900.00
0005434550311	277	Economy	27900.00
0005434723371	277	Economy	27900.00
0005432277570	277	Economy	27900.00
0005434723328	277	Economy	27900.00
0005435142345	277	Economy	27900.00
0005434550292	277	Economy	27900.00
0005433233127	9829	Business	83700.00
0005434031947	9829	Business	83700.00
0005433233121	9829	Business	83700.00
0005433180671	9829	Business	83700.00
0005432199129	9829	Business	83700.00
0005433180649	9829	Business	83700.00
0005433180661	9829	Business	83700.00
0005432199128	9829	Business	83700.00
0005433180665	9829	Business	83700.00
0005433233138	9829	Business	83700.00
0005433233096	9829	Business	83700.00
0005432199126	9829	Comfort	47400.00
0005433233093	9829	Comfort	47400.00
0005433180667	9829	Comfort	47400.00
0005433233097	9829	Comfort	47400.00
0005433233111	9829	Comfort	47400.00
0005433233110	9829	Comfort	47400.00
0005433180672	9829	Comfort	47400.00
0005433233112	9829	Comfort	47400.00
0005433180664	9829	Comfort	47400.00
0005433233103	9829	Comfort	47400.00
0005433180657	9829	Comfort	47400.00
0005433233091	9829	Comfort	47400.00
0005433233118	9829	Comfort	47400.00
0005433233102	9829	Comfort	47400.00
0005433233107	9829	Comfort	47400.00
0005433233124	9829	Economy	27900.00
0005433233089	9829	Economy	27900.00
0005433233090	9829	Economy	27900.00
0005433180653	9829	Economy	27900.00
0005433233114	9829	Economy	27900.00
0005433233133	9829	Economy	27900.00
0005433233143	9829	Economy	27900.00
0005433233108	9829	Economy	27900.00
0005433180673	9829	Economy	27900.00
0005433113496	9829	Economy	27900.00
0005433233117	9829	Economy	27900.00
0005434031946	9829	Economy	27900.00
0005433180670	9829	Economy	27900.00
0005433233092	9829	Economy	27900.00
0005432199123	9829	Economy	27900.00
0005433233085	9829	Economy	27900.00
0005433233134	9829	Economy	30700.00
0005433233131	9829	Economy	27900.00
0005433180668	9829	Economy	27900.00
0005433766574	9829	Economy	27900.00
0005433233080	9829	Economy	27900.00
0005433180660	9829	Economy	27900.00
0005433233116	9829	Economy	27900.00
0005432199124	9829	Economy	27900.00
0005433180669	9829	Economy	27900.00
0005433180654	9829	Economy	27900.00
0005433766573	9829	Economy	27900.00
0005433180651	9829	Economy	27900.00
0005433233125	9829	Economy	27900.00
0005433233115	9829	Economy	27900.00
0005432199127	9829	Economy	27900.00
0005433233141	9829	Economy	27900.00
0005433233139	9829	Economy	27900.00
0005433233086	9829	Economy	27900.00
0005433766575	9829	Economy	27900.00
0005432199125	9829	Economy	27900.00
0005433233101	9829	Economy	27900.00
0005433113495	9829	Economy	27900.00
0005433233105	9829	Economy	27900.00
0005433233135	9829	Economy	27900.00
0005433180659	9829	Economy	27900.00
0005433233119	9829	Economy	27900.00
0005433233123	9829	Economy	27900.00
0005433233082	9829	Economy	27900.00
0005433233120	9829	Economy	27900.00
0005433233100	9829	Economy	27900.00
0005433233136	9829	Economy	27900.00
0005433233099	9829	Economy	27900.00
0005433233113	9829	Economy	27900.00
0005433233126	9829	Economy	27900.00
0005433233130	9829	Economy	27900.00
0005433233083	9829	Economy	27900.00
0005434031945	9829	Economy	30700.00
0005433180655	9829	Economy	27900.00
0005433233137	9829	Economy	27900.00
0005433233140	9829	Economy	27900.00
0005434031944	9829	Economy	27900.00
0005433766572	9829	Economy	27900.00
0005433180652	9829	Economy	27900.00
0005433233129	9829	Economy	27900.00
0005433180666	9829	Economy	27900.00
0005433180648	9829	Economy	27900.00
0005433233142	9829	Economy	27900.00
0005433233109	9829	Economy	27900.00
0005433180663	9829	Economy	27900.00
0005433233088	9829	Economy	27900.00
0005433233122	9829	Economy	27900.00
0005433233095	9829	Economy	27900.00
0005433233104	9829	Economy	27900.00
0005433180662	9829	Economy	27900.00
0005433233106	9829	Economy	27900.00
0005433233094	9829	Economy	27900.00
0005433180656	9829	Economy	27900.00
0005433233098	9829	Economy	27900.00
0005433233128	9829	Economy	27900.00
0005433233084	9829	Economy	27900.00
0005433233081	9829	Economy	27900.00
0005433233132	9829	Economy	27900.00
0005433180658	9829	Economy	27900.00
0005433180650	9829	Economy	27900.00
0005433233087	9829	Economy	27900.00
0005432525723	7768	Business	42100.00
0005432525678	7768	Business	42100.00
0005432525677	7768	Business	42100.00
0005432525761	7768	Business	42100.00
0005434066299	7768	Business	42100.00
0005432525709	7768	Business	42100.00
0005434066325	7768	Business	42100.00
0005432525642	7768	Business	42100.00
0005432150061	7768	Business	42100.00
0005434066360	7768	Business	42100.00
0005434066313	7768	Business	42100.00
0005434066354	7768	Business	42100.00
0005432525732	7768	Business	42100.00
0005434066306	7768	Business	42100.00
0005432525674	7768	Business	42100.00
0005432533242	7768	Business	42100.00
0005432525694	7768	Business	42100.00
0005432525731	7768	Business	42100.00
0005432069406	7768	Comfort	23900.00
0005432525634	7768	Comfort	23900.00
0005434066327	7768	Comfort	23900.00
0005432525648	7768	Comfort	23900.00
0005432525645	7768	Comfort	23900.00
0005434066321	7768	Comfort	23900.00
0005432525727	7768	Comfort	23900.00
0005432525744	7768	Comfort	23900.00
0005432525666	7768	Comfort	23900.00
0005434066332	7768	Comfort	23900.00
0005434066351	7768	Comfort	23900.00
0005432525733	7768	Comfort	23900.00
0005432525655	7768	Comfort	23900.00
0005432525686	7768	Comfort	23900.00
0005432150057	7768	Comfort	23900.00
0005434066343	7768	Comfort	23900.00
0005434066322	7768	Comfort	23900.00
0005432535748	7768	Comfort	23900.00
0005432525735	7768	Comfort	23900.00
0005432525730	7768	Comfort	23900.00
0005434066305	7768	Comfort	23900.00
0005432525710	7768	Comfort	23900.00
0005432525667	7768	Comfort	23900.00
0005434066317	7768	Comfort	23900.00
0005432150055	7768	Comfort	23900.00
0005432525701	7768	Comfort	23900.00
0005432525639	7768	Comfort	23900.00
0005434066334	7768	Comfort	23900.00
0005432525669	7768	Comfort	23900.00
0005432525765	7768	Comfort	23900.00
0005434066352	7768	Economy	14000.00
0005432525647	7768	Economy	14000.00
0005432525739	7768	Economy	14000.00
0005432525767	7768	Economy	14000.00
0005434066315	7768	Economy	14000.00
0005434066355	7768	Economy	14000.00
0005432525654	7768	Economy	14000.00
0005432525658	7768	Economy	14000.00
0005432525644	7768	Economy	14000.00
0005434066342	7768	Economy	14000.00
0005434066335	7768	Economy	14000.00
0005432525736	7768	Economy	14000.00
0005432150060	7768	Economy	14000.00
0005434066346	7768	Economy	14000.00
0005434066341	7768	Economy	14000.00
0005432525662	7768	Economy	14000.00
0005432150054	7768	Economy	14000.00
0005432525696	7768	Economy	14000.00
0005432525729	7768	Economy	14000.00
0005432525691	7768	Economy	14000.00
0005432525718	7768	Economy	14000.00
0005432525697	7768	Economy	14000.00
0005432525703	7768	Economy	14000.00
0005434066362	7768	Economy	14000.00
0005432525646	7768	Economy	14000.00
0005434066324	7768	Economy	14000.00
0005434066353	7768	Economy	14000.00
0005432525685	7768	Economy	14000.00
0005432525747	7768	Economy	14000.00
0005434066340	7768	Economy	14000.00
0005432533241	7768	Economy	14000.00
0005434066345	7768	Economy	14000.00
0005434066303	7768	Economy	14000.00
0005432525716	7768	Economy	14000.00
0005434066304	7768	Economy	14000.00
0005432069400	7768	Economy	14000.00
0005432069397	7768	Economy	14000.00
0005432525668	7768	Economy	14000.00
0005434066333	7768	Economy	14000.00
0005432150059	7768	Economy	14000.00
0005432535746	7768	Economy	14000.00
0005432525742	7768	Economy	14000.00
0005434066326	7768	Economy	14000.00
0005434066361	7768	Economy	14000.00
0005434066295	7768	Economy	14000.00
0005434066323	7768	Economy	14000.00
0005432150058	7768	Economy	14000.00
0005432428867	7768	Economy	14000.00
0005432525649	7768	Economy	15400.00
0005434066328	7768	Economy	15400.00
0005434066318	7768	Economy	15400.00
0005434066319	7768	Economy	14000.00
0005432525670	7768	Economy	14000.00
0005432069404	7768	Economy	15400.00
0005432069394	7768	Economy	15400.00
0005432525754	7768	Economy	14000.00
0005432525741	7768	Economy	15400.00
0005434066316	7768	Economy	14000.00
0005434066364	7768	Economy	14000.00
0005432525746	7768	Economy	14000.00
0005432525687	7768	Economy	14000.00
0005432525758	7768	Economy	14000.00
0005432535745	7768	Economy	14000.00
0005434066312	7768	Economy	14000.00
0005432525692	7768	Economy	14000.00
0005432525664	7768	Economy	14000.00
0005432525635	7768	Economy	14000.00
0005434066349	7768	Economy	14000.00
0005432525714	7768	Economy	14000.00
0005432525659	7768	Economy	14000.00
0005432525683	7768	Economy	14000.00
0005434066366	7768	Economy	14000.00
0005432525725	7768	Economy	14000.00
0005432525766	7768	Economy	14000.00
0005434066358	7768	Economy	14000.00
0005432525745	7768	Economy	14000.00
0005432525759	7768	Economy	14000.00
0005434066300	7768	Economy	14000.00
0005432525715	7768	Economy	14000.00
0005432525652	7768	Economy	14000.00
0005434066314	7768	Economy	14000.00
0005432525719	7768	Economy	14000.00
0005432525717	7768	Economy	14000.00
0005432069401	7768	Economy	14000.00
0005432525763	7768	Economy	14000.00
0005432525762	7768	Economy	14000.00
0005434066365	7768	Economy	14000.00
0005434066302	7768	Economy	14000.00
0005432069407	7768	Economy	14000.00
0005432525748	7768	Economy	14000.00
0005434066344	7768	Economy	14000.00
0005432525698	7768	Economy	14000.00
0005432525637	7768	Economy	14000.00
0005432069403	7768	Economy	14000.00
0005432525653	7768	Economy	14000.00
0005432525651	7768	Economy	14000.00
0005432525713	7768	Economy	14000.00
0005432525700	7768	Economy	14000.00
0005432525671	7768	Economy	14000.00
0005432525663	7768	Economy	14000.00
0005434066298	7768	Economy	14000.00
0005434066330	7768	Economy	14000.00
0005434066297	7768	Economy	14000.00
0005434066348	7768	Economy	14000.00
0005434066307	7768	Economy	14000.00
0005432525721	7768	Economy	14000.00
0005432535747	7768	Economy	14000.00
0005432069399	7768	Economy	14000.00
0005432525724	7768	Economy	14000.00
0005434066331	7768	Economy	14000.00
0005432069408	7768	Economy	14000.00
0005432525753	7768	Economy	14000.00
0005432150062	7768	Economy	14000.00
0005434066311	7768	Economy	14000.00
0005432525720	7768	Economy	14000.00
0005432525752	7768	Economy	14000.00
0005432150056	7768	Economy	14000.00
0005434066329	7768	Economy	14000.00
0005432525638	7768	Economy	14000.00
0005432525665	7768	Economy	14000.00
0005432428869	7768	Economy	14000.00
0005432525656	7768	Economy	14000.00
0005432525705	7768	Economy	14000.00
0005434066339	7768	Economy	14000.00
0005432525690	7768	Economy	15400.00
0005434066350	7768	Economy	15400.00
0005432525737	7768	Economy	15400.00
0005432525707	7768	Economy	14000.00
0005434066320	7768	Economy	14000.00
0005432525755	7768	Economy	14000.00
0005432428868	7768	Economy	14000.00
0005432525641	7768	Economy	14000.00
0005432525702	7768	Economy	14000.00
0005432069395	7768	Economy	14000.00
0005432525751	7768	Economy	14000.00
0005434066296	7768	Economy	14000.00
0005434066310	7768	Economy	14000.00
0005432525693	7768	Economy	14000.00
0005432525726	7768	Economy	14000.00
0005432525689	7768	Economy	14000.00
0005432525673	7768	Economy	14000.00
0005432525643	7768	Economy	14000.00
0005432535749	7768	Economy	14000.00
0005432525681	7768	Economy	14000.00
0005432525704	7768	Economy	14000.00
0005432525738	7768	Economy	14000.00
0005432525688	7768	Economy	14000.00
0005432525650	7768	Economy	14000.00
0005434066338	7768	Economy	14000.00
0005432525708	7768	Economy	14000.00
0005432525743	7768	Economy	14000.00
0005432525657	7768	Economy	14000.00
0005432525660	7768	Economy	14000.00
0005432525695	7768	Economy	14000.00
0005432525640	7768	Economy	14000.00
0005432069396	7768	Economy	14000.00
0005432525672	7768	Economy	14000.00
0005432525712	7768	Economy	14000.00
0005432525757	7768	Economy	14000.00
0005434066337	7768	Economy	14000.00
0005434066356	7768	Economy	14000.00
0005432533240	7768	Economy	14000.00
0005432069402	7768	Economy	14000.00
0005432069398	7768	Economy	14000.00
0005432525760	7768	Economy	14000.00
0005432525756	7768	Economy	14000.00
0005434066336	7768	Economy	14000.00
0005432525699	7768	Economy	14000.00
0005432525675	7768	Economy	14000.00
0005432525722	7768	Economy	14000.00
0005434066359	7768	Economy	14000.00
0005432525636	7768	Economy	14000.00
0005432525740	7768	Economy	14000.00
0005432525734	7768	Economy	14000.00
0005434066357	7768	Economy	14000.00
0005432525728	7768	Economy	14000.00
0005432525676	7768	Economy	14000.00
0005432525711	7768	Economy	14000.00
0005432069405	7768	Economy	14000.00
0005434066309	7768	Economy	14000.00
0005432525749	7768	Economy	14000.00
0005432525706	7768	Economy	14000.00
0005434066363	7768	Economy	14000.00
0005432525684	7768	Economy	14000.00
0005432525680	7768	Economy	14000.00
0005432525679	7768	Economy	14000.00
0005432525764	7768	Economy	14000.00
0005432525682	7768	Economy	14000.00
0005432525750	7768	Economy	14000.00
0005434066308	7768	Economy	14000.00
0005434066347	7768	Economy	14000.00
0005434066301	7768	Economy	14000.00
0005432525661	7768	Economy	14000.00
0005435611762	5354	Business	43100.00
0005434343587	5354	Business	43100.00
0005432132951	5354	Business	43100.00
0005434343593	5354	Business	43100.00
0005435611739	5354	Business	43100.00
0005435611766	5354	Business	43100.00
0005435611757	5354	Business	43100.00
0005435097048	5354	Business	43100.00
0005434573103	5354	Business	43100.00
0005435611769	5354	Business	43100.00
0005434343591	5354	Comfort	24400.00
0005434343600	5354	Comfort	24400.00
0005435611727	5354	Comfort	24400.00
0005435097051	5354	Comfort	24400.00
0005432132947	5354	Comfort	24400.00
0005435097047	5354	Comfort	24400.00
0005435611699	5354	Comfort	24400.00
0005435611731	5354	Comfort	24400.00
0005435611713	5354	Comfort	24400.00
0005432132954	5354	Comfort	24400.00
0005432132942	5354	Comfort	24400.00
0005434573110	5354	Comfort	24400.00
0005435611722	5354	Comfort	24400.00
0005434573104	5354	Comfort	24400.00
0005435611700	5354	Comfort	24400.00
0005434343611	5354	Comfort	24400.00
0005435611743	5354	Comfort	24400.00
0005435611754	5354	Economy	14400.00
0005434573106	5354	Economy	14400.00
0005435611701	5354	Economy	14400.00
0005432132955	5354	Economy	14400.00
0005434343609	5354	Economy	14400.00
0005435611746	5354	Economy	14400.00
0005435611755	5354	Economy	14400.00
0005435611748	5354	Economy	14400.00
0005435611737	5354	Economy	14400.00
0005435611715	5354	Economy	14400.00
0005435611733	5354	Economy	14400.00
0005432047485	5354	Economy	14400.00
0005434573101	5354	Economy	14400.00
0005435097044	5354	Economy	14400.00
0005435611740	5354	Economy	14400.00
0005432132941	5354	Economy	14400.00
0005434343605	5354	Economy	14400.00
0005434343608	5354	Economy	14400.00
0005435611738	5354	Economy	14400.00
0005435611698	5354	Economy	14400.00
0005435097043	5354	Economy	14400.00
0005435611717	5354	Economy	14400.00
0005435611750	5354	Economy	14400.00
0005434343610	5354	Economy	14400.00
0005432132953	5354	Economy	14400.00
0005434573102	5354	Economy	14400.00
0005434343599	5354	Economy	14400.00
0005432132944	5354	Economy	14400.00
0005435611742	5354	Economy	14400.00
0005434343603	5354	Economy	14400.00
0005435611714	5354	Economy	14400.00
0005435611734	5354	Economy	14400.00
0005435611712	5354	Economy	14400.00
0005435611702	5354	Economy	14400.00
0005435611741	5354	Economy	14400.00
0005435611751	5354	Economy	14400.00
0005432047484	5354	Economy	14400.00
0005435611708	5354	Economy	14400.00
0005432132952	5354	Economy	14400.00
0005435611719	5354	Economy	14400.00
0005434343589	5354	Economy	14400.00
0005435611756	5354	Economy	14400.00
0005434573107	5354	Economy	14400.00
0005435611764	5354	Economy	14400.00
0005434343613	5354	Economy	14400.00
0005434343597	5354	Economy	14400.00
0005434573115	5354	Economy	14400.00
0005435611753	5354	Economy	14400.00
0005432047486	5354	Economy	14400.00
0005435611707	5354	Economy	14400.00
0005434343586	5354	Economy	14400.00
0005435097049	5354	Economy	14400.00
0005435097050	5354	Economy	14400.00
0005435611763	5354	Economy	14400.00
0005434343595	5354	Economy	14400.00
0005434343615	5354	Economy	14400.00
0005435611730	5354	Economy	14400.00
0005434573114	5354	Economy	14400.00
0005435611725	5354	Economy	14400.00
0005435611710	5354	Economy	14400.00
0005435611723	5354	Economy	14400.00
0005435611726	5354	Economy	14400.00
0005434343585	5354	Economy	14400.00
0005434343602	5354	Economy	14400.00
0005435611771	5354	Economy	14400.00
0005435611718	5354	Economy	14400.00
0005434343604	5354	Economy	14400.00
0005432132945	5354	Economy	14400.00
0005434343590	5354	Economy	14400.00
0005434343582	5354	Economy	14400.00
0005434343592	5354	Economy	14400.00
0005434343601	5354	Economy	14400.00
0005435097046	5354	Economy	15800.00
0005434573108	5354	Economy	15800.00
0005435611765	5354	Economy	15800.00
0005435611761	5354	Economy	15800.00
0005434343594	5354	Economy	15800.00
0005432132948	5354	Economy	14400.00
0005435611706	5354	Economy	14400.00
0005434343584	5354	Economy	14400.00
0005435611760	5354	Economy	14400.00
0005432132943	5354	Economy	14400.00
0005432132949	5354	Economy	14400.00
0005435611745	5354	Economy	14400.00
0005435611705	5354	Economy	14400.00
0005435611728	5354	Economy	14400.00
0005435611759	5354	Economy	14400.00
0005434343606	5354	Economy	14400.00
0005435611711	5354	Economy	14400.00
0005434573111	5354	Economy	14400.00
0005435611709	5354	Economy	14400.00
0005435611724	5354	Economy	14400.00
0005434343588	5354	Economy	14400.00
0005434573105	5354	Economy	14400.00
0005435611752	5354	Economy	14400.00
0005435611767	5354	Economy	14400.00
0005435611758	5354	Economy	14400.00
0005434343607	5354	Economy	14400.00
0005434343596	5354	Economy	14400.00
0005434343583	5354	Economy	14400.00
0005435611772	5354	Economy	14400.00
0005434343598	5354	Economy	14400.00
0005435611768	5354	Economy	14400.00
0005435611720	5354	Economy	14400.00
0005432132946	5354	Economy	14400.00
0005435611747	5354	Economy	14400.00
0005435611721	5354	Economy	14400.00
0005434573113	5354	Economy	14400.00
0005435611732	5354	Economy	14400.00
0005434343612	5354	Economy	14400.00
0005434343614	5354	Economy	14400.00
0005435611703	5354	Economy	14400.00
0005435611716	5354	Economy	14400.00
0005435611729	5354	Economy	14400.00
0005435611770	5354	Economy	14400.00
0005435611749	5354	Economy	14400.00
0005434573109	5354	Economy	14400.00
0005432132950	5354	Economy	14400.00
0005435097045	5354	Economy	14400.00
0005434573112	5354	Economy	14400.00
0005435611736	5354	Economy	14400.00
0005434343616	5354	Economy	14400.00
0005435611704	5354	Economy	14400.00
0005435611744	5354	Economy	14400.00
0005435611735	5354	Economy	14400.00
0005434244460	10895	Business	43100.00
0005432840976	10895	Business	43100.00
0005435423601	10895	Business	43100.00
0005435423610	10895	Business	43100.00
0005434656521	10895	Business	43100.00
0005432166845	10895	Comfort	24400.00
0005432164904	10895	Comfort	24400.00
0005434244482	10895	Comfort	24400.00
0005434244467	10895	Comfort	24400.00
0005435423600	10895	Comfort	24400.00
0005435423613	10895	Comfort	24400.00
0005435423615	10895	Comfort	24400.00
0005434244474	10895	Comfort	24400.00
0005434656520	10895	Comfort	24400.00
0005435423623	10895	Comfort	24400.00
0005434244476	10895	Comfort	24400.00
0005432164906	10895	Comfort	24400.00
0005435423591	10895	Comfort	24400.00
0005434244471	10895	Comfort	24400.00
0005433719080	10895	Comfort	24400.00
0005435423637	10895	Comfort	24400.00
0005435423594	10895	Economy	14400.00
0005435423616	10895	Economy	14400.00
0005435423626	10895	Economy	14400.00
0005435423639	10895	Economy	14400.00
0005435423642	10895	Economy	14400.00
0005435423640	10895	Economy	14400.00
0005434244480	10895	Economy	14400.00
0005434244455	10895	Economy	14400.00
0005434244477	10895	Economy	14400.00
0005435423627	10895	Economy	14400.00
0005435423619	10895	Economy	14400.00
0005434244473	10895	Economy	14400.00
0005435423644	10895	Economy	14400.00
0005435423598	10895	Economy	14400.00
0005435423587	10895	Economy	14400.00
0005434244461	10895	Economy	14400.00
0005435423631	10895	Economy	14400.00
0005435423643	10895	Economy	14400.00
0005434244464	10895	Economy	14400.00
0005435042820	10895	Economy	14400.00
0005435423614	10895	Economy	14400.00
0005434244463	10895	Economy	14400.00
0005435423582	10895	Economy	14400.00
0005435423595	10895	Economy	14400.00
0005435423592	10895	Economy	15800.00
0005433719082	10895	Economy	15800.00
0005434244459	10895	Economy	14400.00
0005434244458	10895	Economy	14400.00
0005435423636	10895	Economy	14400.00
0005432166844	10895	Economy	14400.00
0005435423584	10895	Economy	14400.00
0005435423576	10895	Economy	14400.00
0005435423612	10895	Economy	14400.00
0005435423632	10895	Economy	14400.00
0005435042822	10895	Economy	14400.00
0005434244472	10895	Economy	14400.00
0005435423588	10895	Economy	14400.00
0005435423617	10895	Economy	14400.00
0005434244457	10895	Economy	14400.00
0005432164902	10895	Economy	14400.00
0005435423645	10895	Economy	14400.00
0005435423604	10895	Economy	14400.00
0005435423628	10895	Economy	14400.00
0005435423597	10895	Economy	14400.00
0005435423599	10895	Economy	14400.00
0005432363359	10895	Economy	14400.00
0005435423622	10895	Economy	14400.00
0005432164903	10895	Economy	14400.00
0005435423634	10895	Economy	14400.00
0005434244456	10895	Economy	14400.00
0005432164901	10895	Economy	14400.00
0005434244475	10895	Economy	14400.00
0005434244470	10895	Economy	14400.00
0005435423583	10895	Economy	14400.00
0005435423578	10895	Economy	14400.00
0005434244479	10895	Economy	14400.00
0005434244481	10895	Economy	14400.00
0005435423586	10895	Economy	14400.00
0005435423620	10895	Economy	14400.00
0005432166843	10895	Economy	14400.00
0005435423638	10895	Economy	14400.00
0005435423635	10895	Economy	14400.00
0005434244483	10895	Economy	14400.00
0005433719081	10895	Economy	14400.00
0005435423608	10895	Economy	14400.00
0005435042821	10895	Economy	14400.00
0005435423589	10895	Economy	14400.00
0005435423577	10895	Economy	14400.00
0005435423580	10895	Economy	14400.00
0005435423603	10895	Economy	14400.00
0005432363360	10895	Economy	15800.00
0005434244466	10895	Economy	14400.00
0005435423633	10895	Economy	14400.00
0005434244469	10895	Economy	14400.00
0005435423593	10895	Economy	14400.00
0005435423611	10895	Economy	14400.00
0005435042823	10895	Economy	14400.00
0005434244465	10895	Economy	14400.00
0005433719083	10895	Economy	14400.00
0005435423596	10895	Economy	14400.00
0005435423579	10895	Economy	14400.00
0005435423609	10895	Economy	14400.00
0005435423605	10895	Economy	14400.00
0005435423629	10895	Economy	14400.00
0005434244453	10895	Economy	14400.00
0005432164907	10895	Economy	14400.00
0005435423624	10895	Economy	14400.00
0005435423621	10895	Economy	14400.00
0005435423602	10895	Economy	14400.00
0005435423641	10895	Economy	14400.00
0005434244468	10895	Economy	14400.00
0005435423625	10895	Economy	14400.00
0005435423585	10895	Economy	14400.00
0005435423618	10895	Economy	14400.00
0005435423607	10895	Economy	14400.00
0005435423581	10895	Economy	14400.00
0005434244454	10895	Economy	14400.00
0005434244478	10895	Economy	14400.00
0005432164905	10895	Economy	14400.00
0005435423590	10895	Economy	14400.00
0005432164908	10895	Economy	14400.00
0005435423630	10895	Economy	14400.00
0005435423606	10895	Economy	14400.00
0005434244462	10895	Economy	14400.00
0005435423575	10895	Economy	14400.00
0005433804791	3316	Business	18800.00
0005433804786	3316	Business	18800.00
0005433633228	3316	Business	18800.00
0005433804793	3316	Business	18800.00
0005433506853	3316	Business	18800.00
0005433633225	3316	Business	18800.00
0005433633239	3316	Business	18800.00
0005433633226	3316	Business	18800.00
0005433633227	3316	Business	18800.00
0005432181320	3316	Business	18800.00
0005433633231	3316	Business	18800.00
0005433633217	3316	Business	18800.00
0005433633222	3316	Business	18800.00
0005433506856	3316	Business	18800.00
0005433633214	3316	Business	18800.00
0005433506855	3316	Business	18800.00
0005433804780	3316	Economy	6900.00
0005433633221	3316	Economy	6900.00
0005432181330	3316	Economy	6900.00
0005433804788	3316	Economy	6900.00
0005433633213	3316	Economy	6300.00
0005432181331	3316	Economy	6300.00
0005433633245	3316	Economy	6300.00
0005433633220	3316	Economy	6300.00
0005433506857	3316	Economy	6300.00
0005432181325	3316	Economy	6300.00
0005433506861	3316	Economy	6300.00
0005432181339	3316	Economy	6300.00
0005433633247	3316	Economy	6300.00
0005433633241	3316	Economy	6300.00
0005433804782	3316	Economy	6300.00
0005432181329	3316	Economy	6300.00
0005432181327	3316	Economy	6300.00
0005432181332	3316	Economy	6300.00
0005433506866	3316	Economy	6300.00
0005433804790	3316	Economy	6300.00
0005432181323	3316	Economy	6300.00
0005433633244	3316	Economy	6300.00
0005433506867	3316	Economy	6300.00
0005433804787	3316	Economy	6300.00
0005433633229	3316	Economy	6300.00
0005432181322	3316	Economy	6300.00
0005433506870	3316	Economy	6300.00
0005433633219	3316	Economy	6300.00
0005433804781	3316	Economy	6300.00
0005432181324	3316	Economy	6300.00
0005433804778	3316	Economy	6300.00
0005433804783	3316	Economy	6300.00
0005433633224	3316	Economy	6300.00
0005433804784	3316	Economy	6300.00
0005432181321	3316	Economy	6300.00
0005433506862	3316	Economy	6300.00
0005432181333	3316	Economy	6300.00
0005433506868	3316	Economy	6300.00
0005433633230	3316	Economy	6300.00
0005432181334	3316	Economy	6900.00
0005432181337	3316	Economy	6900.00
0005433633235	3316	Economy	6300.00
0005433633215	3316	Economy	6300.00
0005433633233	3316	Economy	6300.00
0005433633242	3316	Economy	6300.00
0005433506869	3316	Economy	6300.00
0005433506860	3316	Economy	6300.00
0005433633216	3316	Economy	6300.00
0005433633234	3316	Economy	6300.00
0005433633223	3316	Economy	6300.00
0005433506859	3316	Economy	6300.00
0005433506858	3316	Economy	6300.00
0005432181335	3316	Economy	6300.00
0005433633237	3316	Economy	6300.00
0005433506854	3316	Economy	6300.00
0005432181340	3316	Economy	6300.00
0005433804777	3316	Economy	6300.00
0005433506863	3316	Economy	6300.00
0005432181319	3316	Economy	6300.00
0005432181326	3316	Economy	6300.00
0005433804789	3316	Economy	6300.00
0005433506871	3316	Economy	6300.00
0005432181336	3316	Economy	6300.00
0005432181338	3316	Economy	6300.00
0005433633232	3316	Economy	6300.00
0005433633236	3316	Economy	6300.00
0005433804792	3316	Economy	6300.00
0005433804785	3316	Economy	6300.00
0005433633243	3316	Economy	6300.00
0005433633246	3316	Economy	6300.00
0005433506864	3316	Economy	6300.00
0005432181328	3316	Economy	6300.00
0005433804779	3316	Economy	6300.00
0005433633218	3316	Economy	6300.00
0005433633238	3316	Economy	6300.00
0005433633240	3316	Economy	6300.00
0005433506865	3316	Economy	6300.00
0005432458972	8323	Business	18800.00
0005435884382	8323	Business	18800.00
0005432458984	8323	Business	18800.00
0005435884409	8323	Business	18800.00
0005432458964	8323	Business	18800.00
0005432458973	8323	Business	18800.00
0005435884393	8323	Business	18800.00
0005432459008	8323	Business	18800.00
0005432458992	8323	Business	18800.00
0005435884385	8323	Business	18800.00
0005435884375	8323	Business	18800.00
0005435884414	8323	Business	18800.00
0005432458980	8323	Business	18800.00
0005432042479	8323	Business	18800.00
0005432042473	8323	Business	18800.00
0005432458965	8323	Business	18800.00
0005432458991	8323	Business	18800.00
0005432459003	8323	Business	18800.00
0005435884405	8323	Economy	6900.00
0005432458999	8323	Economy	6900.00
0005432042478	8323	Economy	6900.00
0005435884410	8323	Economy	6300.00
0005435884408	8323	Economy	6300.00
0005432458978	8323	Economy	6300.00
0005432458956	8323	Economy	6300.00
0005435884411	8323	Economy	6300.00
0005432459005	8323	Economy	6300.00
0005435884384	8323	Economy	6300.00
0005432042469	8323	Economy	6300.00
0005435884377	8323	Economy	6300.00
0005432458967	8323	Economy	6300.00
0005432458993	8323	Economy	6300.00
0005432458979	8323	Economy	6300.00
0005435884417	8323	Economy	6300.00
0005435884418	8323	Economy	6300.00
0005435884378	8323	Economy	6300.00
0005435884415	8323	Economy	6300.00
0005432458990	8323	Economy	6300.00
0005432458995	8323	Economy	6300.00
0005432042471	8323	Economy	6300.00
0005432458963	8323	Economy	6300.00
0005432458962	8323	Economy	6300.00
0005432459001	8323	Economy	6300.00
0005435884425	8323	Economy	6300.00
0005432458971	8323	Economy	6300.00
0005435884420	8323	Economy	6300.00
0005432458996	8323	Economy	6300.00
0005435884381	8323	Economy	6300.00
0005435884372	8323	Economy	6300.00
0005435884424	8323	Economy	6300.00
0005435884373	8323	Economy	6300.00
0005435884374	8323	Economy	6300.00
0005432458960	8323	Economy	6300.00
0005435884422	8323	Economy	6300.00
0005435884391	8323	Economy	6300.00
0005432458985	8323	Economy	6300.00
0005435884401	8323	Economy	6300.00
0005432458970	8323	Economy	6300.00
0005435884407	8323	Economy	6300.00
0005432458968	8323	Economy	6300.00
0005432459006	8323	Economy	6300.00
0005435884386	8323	Economy	6300.00
0005434312283	8323	Economy	6300.00
0005432458974	8323	Economy	6300.00
0005434312284	8323	Economy	6900.00
0005435884412	8323	Economy	6900.00
0005432458977	8323	Economy	6900.00
0005435884404	8323	Economy	6900.00
0005435884389	8323	Economy	6300.00
0005435884397	8323	Economy	6300.00
0005432459000	8323	Economy	6300.00
0005432042475	8323	Economy	6300.00
0005432458966	8323	Economy	6900.00
0005435884383	8323	Economy	6300.00
0005435884371	8323	Economy	6300.00
0005435884426	8323	Economy	6300.00
0005432458988	8323	Economy	6300.00
0005432458975	8323	Economy	6300.00
0005435884402	8323	Economy	6300.00
0005435884396	8323	Economy	6300.00
0005435884398	8323	Economy	6300.00
0005435884416	8323	Economy	6300.00
0005435884370	8323	Economy	6300.00
0005432458997	8323	Economy	6300.00
0005435884390	8323	Economy	6300.00
0005432458983	8323	Economy	6300.00
0005435884394	8323	Economy	6300.00
0005435884400	8323	Economy	6300.00
0005432042472	8323	Economy	6300.00
0005435884421	8323	Economy	6300.00
0005432042476	8323	Economy	6300.00
0005435884419	8323	Economy	6300.00
0005432459004	8323	Economy	6300.00
0005435884395	8323	Economy	6300.00
0005432458976	8323	Economy	6300.00
0005432458961	8323	Economy	6300.00
0005432459009	8323	Economy	6300.00
0005435884413	8323	Economy	6300.00
0005432458989	8323	Economy	6300.00
0005432042474	8323	Economy	6300.00
0005435884423	8323	Economy	6300.00
0005435884387	8323	Economy	6300.00
0005432458987	8323	Economy	6300.00
0005432458969	8323	Economy	6300.00
0005435884376	8323	Economy	6300.00
0005432458957	8323	Economy	6300.00
0005432459002	8323	Economy	6300.00
0005432459007	8323	Economy	6300.00
0005435884399	8323	Economy	6300.00
0005435884406	8323	Economy	6300.00
0005432042480	8323	Economy	6300.00
0005432458998	8323	Economy	6300.00
0005432458958	8323	Economy	6300.00
0005432458981	8323	Economy	6300.00
0005432458959	8323	Economy	6300.00
0005432042470	8323	Economy	6300.00
0005432458982	8323	Economy	6300.00
0005435884379	8323	Economy	6300.00
0005432042468	8323	Economy	6300.00
0005435884392	8323	Economy	6300.00
0005432042477	8323	Economy	6300.00
0005435884380	8323	Economy	6300.00
0005432458986	8323	Economy	6300.00
0005432458994	8323	Economy	6300.00
0005435884388	8323	Economy	6300.00
0005435884403	8323	Economy	6300.00
0005432382506	4522	Business	9900.00
0005432382517	4522	Business	9900.00
0005432727721	4522	Business	9900.00
0005432382485	4522	Business	9900.00
0005432382509	4522	Business	9900.00
0005432382488	4522	Business	9900.00
0005432727716	4522	Economy	3300.00
0005432727720	4522	Economy	3300.00
0005433722105	4522	Economy	3300.00
0005432382501	4522	Economy	3300.00
0005432382505	4522	Economy	3300.00
0005432382511	4522	Economy	3600.00
0005432382500	4522	Economy	3600.00
0005432727722	4522	Economy	3300.00
0005432382495	4522	Economy	3300.00
0005432382508	4522	Economy	3300.00
0005432727727	4522	Economy	3300.00
0005432382492	4522	Economy	3300.00
0005432727725	4522	Economy	3300.00
0005432382497	4522	Economy	3300.00
0005432382486	4522	Economy	3300.00
0005432382512	4522	Economy	3300.00
0005432382507	4522	Economy	3300.00
0005432382493	4522	Economy	3300.00
0005433722106	4522	Economy	3300.00
0005432382514	4522	Economy	3300.00
0005433722103	4522	Economy	3300.00
0005432382484	4522	Economy	3300.00
0005432382502	4522	Economy	3300.00
0005432382499	4522	Economy	3300.00
0005432382519	4522	Economy	3300.00
0005432382503	4522	Economy	3300.00
0005432382504	4522	Economy	3300.00
0005433722104	4522	Economy	3300.00
0005433453727	4522	Economy	3300.00
0005432382510	4522	Economy	3300.00
0005432727719	4522	Economy	3300.00
0005432727718	4522	Economy	3300.00
0005432382498	4522	Economy	3300.00
0005433722102	4522	Economy	3300.00
0005432382496	4522	Economy	3300.00
0005432382487	4522	Economy	3300.00
0005432382516	4522	Economy	3300.00
0005432727717	4522	Economy	3300.00
0005432727723	4522	Economy	3300.00
0005432382518	4522	Economy	3300.00
0005432382490	4522	Economy	3300.00
0005433454838	4522	Economy	3300.00
0005432382489	4522	Economy	3300.00
0005432727724	4522	Economy	3300.00
0005433453726	4522	Economy	3300.00
0005432727726	4522	Economy	3300.00
0005432382494	4522	Economy	3300.00
0005432382515	4522	Economy	3300.00
0005433454837	4522	Economy	3300.00
0005432382513	4522	Economy	3300.00
0005432382491	4522	Economy	3300.00
0005432382520	4522	Economy	3300.00
0005435528884	1764	Business	57200.00
0005433516726	1764	Business	57200.00
0005432294445	1764	Business	57200.00
0005435540628	1764	Business	57200.00
0005435528879	1764	Business	57200.00
0005435528885	1764	Business	57200.00
0005435528896	1764	Business	57200.00
0005435540640	1764	Economy	19100.00
0005435540625	1764	Economy	19100.00
0005435540639	1764	Economy	19100.00
0005435540638	1764	Economy	19100.00
0005435540630	1764	Economy	19100.00
0005435528894	1764	Economy	21000.00
0005435540627	1764	Economy	21000.00
0005435528893	1764	Economy	21000.00
0005435540633	1764	Economy	19100.00
0005435528898	1764	Economy	19100.00
0005435540635	1764	Economy	19100.00
0005435528891	1764	Economy	19100.00
0005433516727	1764	Economy	19100.00
0005435540643	1764	Economy	19100.00
0005435540641	1764	Economy	19100.00
0005435540634	1764	Economy	19100.00
0005435540632	1764	Economy	19100.00
0005435528880	1764	Economy	19100.00
0005433516722	1764	Economy	19100.00
0005435528887	1764	Economy	19100.00
0005435540629	1764	Economy	19100.00
0005435528883	1764	Economy	19100.00
0005435528881	1764	Economy	19100.00
0005435528882	1764	Economy	19100.00
0005435540631	1764	Economy	19100.00
0005435540623	1764	Economy	19100.00
0005433516729	1764	Economy	19100.00
0005435540637	1764	Economy	19100.00
0005435528895	1764	Economy	19100.00
0005433516721	1764	Economy	19100.00
0005435528899	1764	Economy	19100.00
0005435540642	1764	Economy	19100.00
0005435528892	1764	Economy	19100.00
0005435528900	1764	Economy	19100.00
0005435540636	1764	Economy	19100.00
0005432294446	1764	Economy	19100.00
0005435528886	1764	Economy	19100.00
0005435540626	1764	Economy	19100.00
0005433516723	1764	Economy	19100.00
0005435540622	1764	Economy	19100.00
0005435528890	1764	Economy	19100.00
0005435540624	1764	Economy	19100.00
0005433516725	1764	Economy	19100.00
0005433516724	1764	Economy	19100.00
0005435528888	1764	Economy	19100.00
0005435528889	1764	Economy	19100.00
0005435528897	1764	Economy	19100.00
0005433516728	1764	Economy	19100.00
0005432924953	21969	Economy	21000.00
0005432924951	21969	Economy	19100.00
0005432924955	21969	Economy	19100.00
0005432924952	21969	Economy	19100.00
0005432924954	21969	Economy	19100.00
0005434458440	7364	Business	18500.00
0005432838490	7364	Business	18500.00
0005432838492	7364	Business	18500.00
0005434458439	7364	Business	18500.00
0005432838507	7364	Business	18500.00
0005432838495	7364	Economy	6200.00
0005434458449	7364	Economy	6200.00
0005434458437	7364	Economy	6200.00
0005434458448	7364	Economy	6200.00
0005432838510	7364	Economy	6200.00
0005432838488	7364	Economy	6800.00
0005432073330	7364	Economy	6800.00
0005434458433	7364	Economy	6800.00
0005434458436	7364	Economy	6200.00
0005432838505	7364	Economy	6200.00
0005434458450	7364	Economy	6200.00
0005432838498	7364	Economy	6200.00
0005434458452	7364	Economy	6200.00
0005434458434	7364	Economy	6200.00
0005432838509	7364	Economy	6200.00
0005432838497	7364	Economy	6200.00
0005432073331	7364	Economy	6200.00
0005434458443	7364	Economy	6200.00
0005432838496	7364	Economy	6200.00
0005432838484	7364	Economy	6200.00
0005434458453	7364	Economy	6200.00
0005432838489	7364	Economy	6200.00
0005432838487	7364	Economy	6200.00
0005432838480	7364	Economy	6200.00
0005434458435	7364	Economy	6200.00
0005434458438	7364	Economy	6200.00
0005434458442	7364	Economy	6200.00
0005434458451	7364	Economy	6200.00
0005432838499	7364	Economy	6200.00
0005432073329	7364	Economy	6200.00
0005432838481	7364	Economy	6200.00
0005432838483	7364	Economy	6200.00
0005432838503	7364	Economy	6200.00
0005432838511	7364	Economy	6200.00
0005432838485	7364	Economy	6200.00
0005434458441	7364	Economy	6200.00
0005432838501	7364	Economy	6200.00
0005434458447	7364	Economy	6200.00
0005434458444	7364	Economy	6200.00
0005432838482	7364	Economy	6200.00
0005432838502	7364	Economy	6200.00
0005432838486	7364	Economy	6200.00
0005434458445	7364	Economy	6200.00
0005432838508	7364	Economy	6200.00
0005432838500	7364	Economy	6200.00
0005434458446	7364	Economy	6200.00
0005432838493	7364	Economy	6200.00
0005432838491	7364	Economy	6200.00
0005432838506	7364	Economy	6200.00
0005432838494	7364	Economy	6200.00
0005432838504	7364	Economy	6200.00
0005435252378	28935	Business	18500.00
0005435252382	28935	Business	18500.00
0005435252385	28935	Business	18500.00
0005435252379	28935	Business	18500.00
0005435252390	28935	Business	18500.00
0005435252381	28935	Economy	6200.00
0005435252396	28935	Economy	6200.00
0005435491407	28935	Economy	6800.00
0005435252383	28935	Economy	6800.00
0005432000987	28935	Economy	6200.00
0005435252393	28935	Economy	6200.00
0005435252392	28935	Economy	6200.00
0005435252388	28935	Economy	6200.00
0005432000988	28935	Economy	6200.00
0005434664920	28935	Economy	6200.00
0005435252380	28935	Economy	6200.00
0005434664919	28935	Economy	6200.00
0005435252384	28935	Economy	6200.00
0005435252389	28935	Economy	6200.00
0005435252395	28935	Economy	6200.00
0005435491405	28935	Economy	6200.00
0005435491406	28935	Economy	6200.00
0005435252391	28935	Economy	6200.00
0005435252387	28935	Economy	6200.00
0005435252394	28935	Economy	6200.00
0005435252386	28935	Economy	6200.00
0005435990502	8817	Business	145300.00
0005435990497	8817	Economy	48400.00
0005435990498	8817	Economy	48400.00
0005435990503	8817	Economy	48400.00
0005435990501	8817	Economy	48400.00
0005435990499	8817	Economy	48400.00
0005435990500	8817	Economy	48400.00
0005434275928	15750	Business	145300.00
0005434275925	15750	Economy	48400.00
0005434275926	15750	Economy	48400.00
0005434275924	15750	Economy	48400.00
0005434275927	15750	Economy	48400.00
0005433468183	2079	Economy	13300.00
0005433468182	2079	Economy	12100.00
0005433468185	2079	Economy	12100.00
0005433468184	2079	Economy	12100.00
0005433468181	2079	Economy	12100.00
0005433468186	2079	Economy	12100.00
0005433468180	2079	Economy	12100.00
0005433468187	2079	Economy	12100.00
0005433468188	2079	Economy	12100.00
0005432359506	6411	Business	36600.00
0005432062135	6411	Business	36600.00
0005432359555	6411	Business	36600.00
0005432359536	6411	Business	36600.00
0005432335824	6411	Business	36600.00
0005432335821	6411	Business	36600.00
0005432359533	6411	Business	36600.00
0005432359552	6411	Economy	12200.00
0005432335829	6411	Economy	12200.00
0005432359525	6411	Economy	12200.00
0005432359537	6411	Economy	12200.00
0005432359513	6411	Economy	12200.00
0005432062136	6411	Economy	12200.00
0005432359527	6411	Economy	12200.00
0005432359521	6411	Economy	12200.00
0005432335825	6411	Economy	12200.00
0005432359540	6411	Economy	12200.00
0005432335822	6411	Economy	12200.00
0005432359544	6411	Economy	12200.00
0005432363360	6411	Economy	12200.00
0005432359507	6411	Economy	12200.00
0005432359550	6411	Economy	12200.00
0005432335823	6411	Economy	12200.00
0005432359529	6411	Economy	12200.00
0005432359543	6411	Economy	12200.00
0005432359511	6411	Economy	12200.00
0005432359528	6411	Economy	13400.00
0005432359551	6411	Economy	13400.00
0005432359522	6411	Economy	12200.00
0005432359510	6411	Economy	12200.00
0005432359547	6411	Economy	12200.00
0005432359524	6411	Economy	12200.00
0005432359532	6411	Economy	12200.00
0005432359508	6411	Economy	12200.00
0005432359541	6411	Economy	12200.00
0005432359542	6411	Economy	12200.00
0005432335827	6411	Economy	12200.00
0005432359512	6411	Economy	12200.00
0005432359518	6411	Economy	12200.00
0005432359517	6411	Economy	12200.00
0005432359548	6411	Economy	12200.00
0005432062134	6411	Economy	12200.00
0005432062137	6411	Economy	12200.00
0005432363359	6411	Economy	12200.00
0005432359519	6411	Economy	12200.00
0005432335820	6411	Economy	12200.00
0005432359539	6411	Economy	12200.00
0005432359554	6411	Economy	12200.00
0005432359534	6411	Economy	12200.00
0005432062139	6411	Economy	12200.00
0005432335826	6411	Economy	12200.00
0005432359530	6411	Economy	12200.00
0005432335830	6411	Economy	12200.00
0005432335831	6411	Economy	12200.00
0005432062138	6411	Economy	12200.00
0005432335828	6411	Economy	12200.00
0005432359526	6411	Economy	12200.00
0005432359520	6411	Economy	12200.00
0005432359545	6411	Economy	12200.00
0005432359531	6411	Economy	12200.00
0005432359515	6411	Economy	12200.00
0005432359514	6411	Economy	12200.00
0005432359523	6411	Economy	12200.00
0005432359538	6411	Economy	12200.00
0005432359546	6411	Economy	12200.00
0005432359535	6411	Economy	12200.00
0005432359549	6411	Economy	12200.00
0005432359553	6411	Economy	12200.00
0005432359516	6411	Economy	12200.00
0005432359509	6411	Economy	12200.00
0005435176585	20993	Business	36600.00
0005435723010	20993	Business	36600.00
0005434149526	20993	Business	36600.00
0005435176587	20993	Economy	12200.00
0005435176608	20993	Economy	12200.00
0005434149522	20993	Economy	12200.00
0005435176610	20993	Economy	12200.00
0005435176612	20993	Economy	12200.00
0005435176594	20993	Economy	12200.00
0005435723009	20993	Economy	12200.00
0005435176601	20993	Economy	12200.00
0005435176596	20993	Economy	12200.00
0005435176603	20993	Economy	12200.00
0005432052694	20993	Economy	12200.00
0005435176602	20993	Economy	12200.00
0005434149529	20993	Economy	12200.00
0005432052692	20993	Economy	12200.00
0005435176590	20993	Economy	12200.00
0005434149521	20993	Economy	12200.00
0005435176600	20993	Economy	12200.00
0005435176588	20993	Economy	12200.00
0005435176599	20993	Economy	12200.00
0005434149528	20993	Economy	12200.00
0005435490169	20993	Economy	12200.00
0005432052693	20993	Economy	13400.00
0005435176592	20993	Economy	13400.00
0005434149530	20993	Economy	13400.00
0005435176593	20993	Economy	12200.00
0005432052691	20993	Economy	12200.00
0005435176609	20993	Economy	12200.00
0005435176597	20993	Economy	12200.00
0005435490172	20993	Economy	12200.00
0005435176604	20993	Economy	12200.00
0005434149531	20993	Economy	12200.00
0005435176591	20993	Economy	12200.00
0005435176589	20993	Economy	12200.00
0005435176586	20993	Economy	12200.00
0005434149527	20993	Economy	12200.00
0005435176611	20993	Economy	12200.00
0005435176598	20993	Economy	12200.00
0005435176607	20993	Economy	12200.00
0005434149525	20993	Economy	12200.00
0005435176605	20993	Economy	12200.00
0005435176595	20993	Economy	12200.00
0005435490173	20993	Economy	12200.00
0005435176606	20993	Economy	12200.00
0005434149523	20993	Economy	12200.00
0005435490170	20993	Economy	12200.00
0005434149520	20993	Economy	12200.00
0005435490171	20993	Economy	12200.00
0005434149524	20993	Economy	12200.00
0005434186148	17732	Economy	3100.00
0005434186147	17732	Economy	3100.00
0005434186149	17732	Economy	3100.00
0005434458435	29107	Economy	3400.00
0005434458448	29107	Economy	3100.00
0005434458445	29107	Economy	3100.00
0005434458442	29107	Economy	3100.00
0005434458446	29107	Economy	3100.00
0005434458449	29107	Economy	3100.00
0005434458452	29107	Economy	3100.00
0005434458437	29107	Economy	3100.00
0005434458450	29107	Economy	3100.00
0005434458440	29107	Economy	3100.00
0005434458453	29107	Economy	3100.00
0005434458447	29107	Economy	3100.00
0005434458444	29107	Economy	3100.00
0005434458451	29107	Economy	3100.00
0005434458433	29107	Economy	3100.00
0005434458439	29107	Economy	3100.00
0005434458434	29107	Economy	3100.00
0005434458441	29107	Economy	3100.00
0005434458438	29107	Economy	3100.00
0005434458436	29107	Economy	3100.00
0005434458443	29107	Economy	3100.00
0005435221036	31696	Economy	7300.00
0005435221035	31696	Economy	7300.00
0005435221497	31696	Economy	6600.00
0005433293144	29590	Economy	17800.00
0005433293143	29590	Economy	17800.00
0005433293145	29590	Economy	17800.00
0005433293142	29590	Economy	17800.00
0005433293146	29590	Economy	17800.00
0005433293147	29590	Economy	17800.00
0005433473104	6691	Economy	12700.00
0005433473108	6691	Economy	12700.00
0005433473101	6691	Economy	12700.00
0005433473107	6691	Economy	12700.00
0005433473103	6691	Economy	12700.00
0005433473106	6691	Economy	12700.00
0005433473105	6691	Economy	12700.00
0005433473102	6691	Economy	12700.00
0005433473100	6691	Economy	12700.00
0005432746899	370	Business	44500.00
0005432746871	370	Business	44500.00
0005432746901	370	Business	44500.00
0005432746867	370	Business	44500.00
0005432746878	370	Business	44500.00
0005432746869	370	Economy	14800.00
0005432746898	370	Economy	14800.00
0005432746876	370	Economy	14800.00
0005432746886	370	Economy	14800.00
0005432746872	370	Economy	14800.00
0005432746880	370	Economy	14800.00
0005432746896	370	Economy	14800.00
0005432746893	370	Economy	14800.00
0005432219928	370	Economy	16300.00
0005432746883	370	Economy	14800.00
0005432219929	370	Economy	14800.00
0005432746891	370	Economy	14800.00
0005432746902	370	Economy	14800.00
0005432746875	370	Economy	14800.00
0005432746887	370	Economy	14800.00
0005432746900	370	Economy	14800.00
0005432746895	370	Economy	14800.00
0005432746865	370	Economy	14800.00
0005432746866	370	Economy	14800.00
0005432746884	370	Economy	14800.00
0005432746889	370	Economy	14800.00
0005432746888	370	Economy	14800.00
0005432746873	370	Economy	14800.00
0005432746890	370	Economy	14800.00
0005432746877	370	Economy	14800.00
0005432746879	370	Economy	14800.00
0005432746868	370	Economy	14800.00
0005432746874	370	Economy	14800.00
0005432746892	370	Economy	14800.00
0005432219926	370	Economy	14800.00
0005432746881	370	Economy	14800.00
0005432746864	370	Economy	14800.00
0005432746897	370	Economy	14800.00
0005432746870	370	Economy	14800.00
0005432746882	370	Economy	14800.00
0005432219927	370	Economy	14800.00
0005432746885	370	Economy	14800.00
0005432746894	370	Economy	14800.00
0005432890687	12076	Business	44500.00
0005432890680	12076	Business	44500.00
0005432890679	12076	Business	44500.00
0005432214765	12076	Business	44500.00
0005432890686	12076	Business	44500.00
0005432890688	12076	Economy	14800.00
0005432214766	12076	Economy	14800.00
0005432214764	12076	Economy	16300.00
0005432890670	12076	Economy	14800.00
0005433875352	12076	Economy	14800.00
0005432890675	12076	Economy	14800.00
0005432890671	12076	Economy	14800.00
0005432890689	12076	Economy	14800.00
0005432890672	12076	Economy	14800.00
0005432890677	12076	Economy	14800.00
0005432890678	12076	Economy	14800.00
0005432890674	12076	Economy	14800.00
0005432890683	12076	Economy	14800.00
0005432890669	12076	Economy	14800.00
0005432890673	12076	Economy	14800.00
0005432890682	12076	Economy	14800.00
0005432890684	12076	Economy	14800.00
0005432890681	12076	Economy	14800.00
0005432890676	12076	Economy	14800.00
0005432890685	12076	Economy	14800.00
0005432927886	32474	Economy	25700.00
0005432927885	32474	Economy	25700.00
0005432927888	32474	Economy	25700.00
0005432927889	32474	Economy	25700.00
0005432927887	32474	Economy	25700.00
0005434821383	5254	Business	84000.00
0005434821405	5254	Business	84000.00
0005432396171	5254	Business	84000.00
0005434821341	5254	Business	84000.00
0005434821353	5254	Business	84000.00
0005434821329	5254	Business	84000.00
0005434821372	5254	Business	84000.00
0005434821375	5254	Business	84000.00
0005435149796	5254	Business	84000.00
0005434821347	5254	Business	84000.00
0005434821390	5254	Business	84000.00
0005432394035	5254	Business	84000.00
0005432121094	5254	Business	84000.00
0005434821349	5254	Comfort	47600.00
0005434821389	5254	Comfort	47600.00
0005434821357	5254	Comfort	47600.00
0005434821364	5254	Comfort	47600.00
0005434821419	5254	Comfort	47600.00
0005434821323	5254	Comfort	47600.00
0005434821345	5254	Comfort	47600.00
0005434821346	5254	Comfort	47600.00
0005434821348	5254	Comfort	47600.00
0005434821358	5254	Comfort	47600.00
0005432394033	5254	Comfort	47600.00
0005434821438	5254	Comfort	47600.00
0005434821382	5254	Comfort	47600.00
0005434821437	5254	Comfort	47600.00
0005434821338	5254	Comfort	47600.00
0005434821377	5254	Comfort	47600.00
0005434821340	5254	Comfort	47600.00
0005434821325	5254	Comfort	47600.00
0005434821367	5254	Comfort	47600.00
0005432121085	5254	Comfort	47600.00
0005434821411	5254	Comfort	47600.00
0005432121090	5254	Comfort	47600.00
0005434821426	5254	Comfort	47600.00
0005432121087	5254	Comfort	47600.00
0005434821337	5254	Economy	28000.00
0005434821397	5254	Economy	28000.00
0005434821417	5254	Economy	28000.00
0005434821392	5254	Economy	28000.00
0005434821343	5254	Economy	28000.00
0005434821363	5254	Economy	28000.00
0005434821321	5254	Economy	28000.00
0005434821332	5254	Economy	28000.00
0005434821386	5254	Economy	28000.00
0005434821312	5254	Economy	28000.00
0005434821391	5254	Economy	28000.00
0005434821422	5254	Economy	28000.00
0005434821378	5254	Economy	28000.00
0005434821316	5254	Economy	28000.00
0005434821339	5254	Economy	28000.00
0005432396173	5254	Economy	28000.00
0005434821376	5254	Economy	28000.00
0005434821314	5254	Economy	28000.00
0005434821388	5254	Economy	28000.00
0005434821430	5254	Economy	28000.00
0005434821407	5254	Economy	28000.00
0005434821423	5254	Economy	28000.00
0005434821395	5254	Economy	28000.00
0005434821311	5254	Economy	28000.00
0005434821355	5254	Economy	30800.00
0005432121088	5254	Economy	30800.00
0005434821393	5254	Economy	28000.00
0005434821374	5254	Economy	30800.00
0005434821327	5254	Economy	28000.00
0005434821399	5254	Economy	28000.00
0005435149793	5254	Economy	30800.00
0005434821334	5254	Economy	28000.00
0005434821400	5254	Economy	28000.00
0005432396170	5254	Economy	28000.00
0005435149788	5254	Economy	28000.00
0005434821403	5254	Economy	28000.00
0005434821387	5254	Economy	28000.00
0005434821354	5254	Economy	28000.00
0005434821416	5254	Economy	28000.00
0005434821342	5254	Economy	28000.00
0005434821320	5254	Economy	28000.00
0005434821352	5254	Economy	28000.00
0005434821414	5254	Economy	28000.00
0005434821381	5254	Economy	28000.00
0005434821429	5254	Economy	28000.00
0005434821396	5254	Economy	28000.00
0005434821409	5254	Economy	28000.00
0005435149792	5254	Economy	28000.00
0005434821428	5254	Economy	28000.00
0005434821319	5254	Economy	28000.00
0005434821362	5254	Economy	28000.00
0005432121092	5254	Economy	28000.00
0005435149785	5254	Economy	28000.00
0005432394034	5254	Economy	28000.00
0005434821356	5254	Economy	28000.00
0005434821333	5254	Economy	28000.00
0005434821326	5254	Economy	28000.00
0005434821315	5254	Economy	28000.00
0005432121084	5254	Economy	28000.00
0005435149797	5254	Economy	28000.00
0005434821368	5254	Economy	28000.00
0005435149789	5254	Economy	28000.00
0005434821394	5254	Economy	28000.00
0005434821418	5254	Economy	28000.00
0005434821318	5254	Economy	28000.00
0005434821384	5254	Economy	28000.00
0005434821415	5254	Economy	28000.00
0005434821317	5254	Economy	28000.00
0005434821361	5254	Economy	28000.00
0005432394032	5254	Economy	28000.00
0005434821370	5254	Economy	28000.00
0005434821408	5254	Economy	28000.00
0005434821335	5254	Economy	28000.00
0005434821425	5254	Economy	28000.00
0005434821406	5254	Economy	28000.00
0005434821410	5254	Economy	30800.00
0005435149786	5254	Economy	30800.00
0005434821421	5254	Economy	30800.00
0005435149795	5254	Economy	28000.00
0005434821366	5254	Economy	28000.00
0005434821371	5254	Economy	28000.00
0005434821433	5254	Economy	28000.00
0005432121091	5254	Economy	28000.00
0005434821435	5254	Economy	28000.00
0005432121083	5254	Economy	28000.00
0005434821336	5254	Economy	28000.00
0005435149794	5254	Economy	28000.00
0005434821385	5254	Economy	28000.00
0005434821344	5254	Economy	28000.00
0005434821432	5254	Economy	28000.00
0005434821412	5254	Economy	28000.00
0005434821398	5254	Economy	28000.00
0005432121095	5254	Economy	28000.00
0005434821427	5254	Economy	28000.00
0005434821420	5254	Economy	28000.00
0005435149790	5254	Economy	28000.00
0005432396174	5254	Economy	28000.00
0005434821413	5254	Economy	28000.00
0005434821328	5254	Economy	28000.00
0005432121089	5254	Economy	28000.00
0005434821330	5254	Economy	28000.00
0005434821434	5254	Economy	28000.00
0005434821369	5254	Economy	28000.00
0005432396172	5254	Economy	28000.00
0005434821404	5254	Economy	28000.00
0005434821436	5254	Economy	28000.00
0005434821380	5254	Economy	28000.00
0005434821401	5254	Economy	28000.00
0005434821379	5254	Economy	28000.00
0005432121086	5254	Economy	28000.00
0005434821313	5254	Economy	28000.00
0005434821351	5254	Economy	28000.00
0005434821365	5254	Economy	28000.00
0005434821439	5254	Economy	28000.00
0005435149787	5254	Economy	28000.00
0005432121093	5254	Economy	28000.00
0005434821331	5254	Economy	28000.00
0005434821373	5254	Economy	28000.00
0005434821424	5254	Economy	28000.00
0005434821359	5254	Economy	28000.00
0005434821431	5254	Economy	28000.00
0005434821322	5254	Economy	28000.00
0005435149791	5254	Economy	28000.00
0005434821402	5254	Economy	28000.00
0005434821350	5254	Economy	28000.00
0005434821360	5254	Economy	28000.00
0005434821324	5254	Economy	28000.00
0005435372158	9891	Business	84000.00
0005435372151	9891	Business	84000.00
0005435735057	9891	Business	84000.00
0005435372150	9891	Business	84000.00
0005435372145	9891	Business	84000.00
0005435372110	9891	Comfort	47600.00
0005435372100	9891	Comfort	47600.00
0005435372147	9891	Comfort	47600.00
0005435372157	9891	Comfort	47600.00
0005435372149	9891	Comfort	47600.00
0005435372125	9891	Comfort	47600.00
0005435372107	9891	Comfort	47600.00
0005435372097	9891	Comfort	47600.00
0005432202939	9891	Comfort	47600.00
0005435386455	9891	Comfort	47600.00
0005435661881	9891	Comfort	47600.00
0005435372132	9891	Comfort	47600.00
0005435372103	9891	Comfort	47600.00
0005435372140	9891	Comfort	47600.00
0005435372154	9891	Comfort	47600.00
0005432202933	9891	Economy	28000.00
0005435372104	9891	Economy	28000.00
0005435372102	9891	Economy	28000.00
0005432202936	9891	Economy	28000.00
0005435372094	9891	Economy	28000.00
0005435372142	9891	Economy	28000.00
0005435372136	9891	Economy	28000.00
0005435661880	9891	Economy	28000.00
0005435735055	9891	Economy	28000.00
0005435386456	9891	Economy	28000.00
0005435372115	9891	Economy	28000.00
0005432823415	9891	Economy	28000.00
0005435372105	9891	Economy	28000.00
0005435372121	9891	Economy	28000.00
0005435372144	9891	Economy	30800.00
0005435372153	9891	Economy	30800.00
0005435372114	9891	Economy	30800.00
0005435372137	9891	Economy	28000.00
0005432202940	9891	Economy	28000.00
0005435372106	9891	Economy	28000.00
0005435372113	9891	Economy	28000.00
0005435372143	9891	Economy	28000.00
0005435372129	9891	Economy	28000.00
0005435661879	9891	Economy	28000.00
0005435372099	9891	Economy	28000.00
0005435372123	9891	Economy	28000.00
0005435372133	9891	Economy	28000.00
0005435372126	9891	Economy	28000.00
0005435372127	9891	Economy	28000.00
0005435372130	9891	Economy	28000.00
0005435372118	9891	Economy	28000.00
0005432202938	9891	Economy	28000.00
0005435372096	9891	Economy	28000.00
0005435372098	9891	Economy	28000.00
0005435735059	9891	Economy	28000.00
0005435372122	9891	Economy	28000.00
0005435735056	9891	Economy	28000.00
0005435372138	9891	Economy	28000.00
0005432202937	9891	Economy	28000.00
0005435372124	9891	Economy	28000.00
0005435372156	9891	Economy	28000.00
0005435735058	9891	Economy	28000.00
0005435372109	9891	Economy	28000.00
0005435372152	9891	Economy	28000.00
0005435372141	9891	Economy	28000.00
0005435372095	9891	Economy	28000.00
0005432202935	9891	Economy	28000.00
0005435372131	9891	Economy	28000.00
0005435372146	9891	Economy	28000.00
0005435372134	9891	Economy	28000.00
0005435372117	9891	Economy	28000.00
0005435372128	9891	Economy	28000.00
0005435372112	9891	Economy	28000.00
0005435372116	9891	Economy	28000.00
0005435372101	9891	Economy	28000.00
0005435372155	9891	Economy	28000.00
0005435372135	9891	Economy	28000.00
0005435386457	9891	Economy	28000.00
0005435372139	9891	Economy	28000.00
0005432202934	9891	Economy	28000.00
0005435386454	9891	Economy	28000.00
0005435372119	9891	Economy	28000.00
0005435372120	9891	Economy	28000.00
0005435372148	9891	Economy	28000.00
0005435372111	9891	Economy	28000.00
0005435372108	9891	Economy	28000.00
0005435082647	6978	Economy	8200.00
0005435082645	6978	Economy	7400.00
0005435082646	6978	Economy	7400.00
0005435790256	6978	Economy	7400.00
0005435790255	6978	Economy	7400.00
0005435082644	6978	Economy	7400.00
0005435082643	6978	Economy	7400.00
0005435082649	6978	Economy	7400.00
0005435082648	6978	Economy	7400.00
0005434755729	9528	Business	32800.00
0005434755725	9528	Business	32800.00
0005434755717	9528	Business	32800.00
0005434755712	9528	Business	32800.00
0005434755709	9528	Business	32800.00
0005434755720	9528	Economy	10900.00
0005434755719	9528	Economy	10900.00
0005434755710	9528	Economy	10900.00
0005434755721	9528	Economy	10900.00
0005434755724	9528	Economy	10900.00
0005434755728	9528	Economy	12000.00
0005434755708	9528	Economy	12000.00
0005434755735	9528	Economy	10900.00
0005434755705	9528	Economy	10900.00
0005434755704	9528	Economy	10900.00
0005434755718	9528	Economy	10900.00
0005434755711	9528	Economy	10900.00
0005434755715	9528	Economy	10900.00
0005434755727	9528	Economy	10900.00
0005434755706	9528	Economy	10900.00
0005434755716	9528	Economy	10900.00
0005434755732	9528	Economy	10900.00
0005434755713	9528	Economy	10900.00
0005434755734	9528	Economy	10900.00
0005434755730	9528	Economy	10900.00
0005434755723	9528	Economy	10900.00
0005434755707	9528	Economy	10900.00
0005434755703	9528	Economy	10900.00
0005434755714	9528	Economy	10900.00
0005434755731	9528	Economy	10900.00
0005434755726	9528	Economy	10900.00
0005434755733	9528	Economy	10900.00
0005434755722	9528	Economy	10900.00
0005435100070	10806	Economy	8900.00
0005435100071	10806	Economy	8900.00
0005435100069	10806	Economy	8900.00
0005434760153	31815	Economy	8900.00
0005434760155	31815	Economy	8900.00
0005434760154	31815	Economy	8900.00
0005434638861	1994	Economy	20900.00
0005434638852	1994	Economy	20900.00
0005434638867	1994	Economy	20900.00
0005434638851	1994	Economy	19000.00
0005432290582	1994	Economy	19000.00
0005434638858	1994	Economy	19000.00
0005434638875	1994	Economy	19000.00
0005434638868	1994	Economy	19000.00
0005434638846	1994	Economy	19000.00
0005434638849	1994	Economy	19000.00
0005434638865	1994	Economy	19000.00
0005434638869	1994	Economy	19000.00
0005434638873	1994	Economy	19000.00
0005434638855	1994	Economy	19000.00
0005432290579	1994	Economy	19000.00
0005435948304	1994	Economy	19000.00
0005432290581	1994	Economy	19000.00
0005434638853	1994	Economy	19000.00
0005434638866	1994	Economy	19000.00
0005434638872	1994	Economy	19000.00
0005434638862	1994	Economy	19000.00
0005434638863	1994	Economy	19000.00
0005434638854	1994	Economy	19000.00
0005434638871	1994	Economy	19000.00
0005434638850	1994	Economy	19000.00
0005435948306	1994	Economy	19000.00
0005434638860	1994	Economy	19000.00
0005432290580	1994	Economy	19000.00
0005434638856	1994	Economy	19000.00
0005434638848	1994	Economy	19000.00
0005434638857	1994	Economy	19000.00
0005434638847	1994	Economy	19000.00
0005435948305	1994	Economy	19000.00
0005434638864	1994	Economy	19000.00
0005434638859	1994	Economy	19000.00
0005434638870	1994	Economy	19000.00
0005434638874	1994	Economy	19000.00
0005434600341	6050	Business	69700.00
0005434600351	6050	Business	69700.00
0005434600342	6050	Business	69700.00
0005433531228	6050	Business	69700.00
0005434600333	6050	Business	69700.00
0005433531225	6050	Business	69700.00
0005433533242	6050	Business	69700.00
0005434600346	6050	Business	69700.00
0005434600336	6050	Business	69700.00
0005434600338	6050	Economy	23200.00
0005434600349	6050	Economy	23200.00
0005434600331	6050	Economy	23200.00
0005434600340	6050	Economy	25600.00
0005432111226	6050	Economy	23200.00
0005434600332	6050	Economy	23200.00
0005433533241	6050	Economy	23200.00
0005433531226	6050	Economy	23200.00
0005434600337	6050	Economy	23200.00
0005434600343	6050	Economy	23200.00
0005434600329	6050	Economy	23200.00
0005433533240	6050	Economy	23200.00
0005434600353	6050	Economy	23200.00
0005434600334	6050	Economy	23200.00
0005434600328	6050	Economy	23200.00
0005433533243	6050	Economy	23200.00
0005432111227	6050	Economy	23200.00
0005434600330	6050	Economy	23200.00
0005434600339	6050	Economy	23200.00
0005433531227	6050	Economy	23200.00
0005434600350	6050	Economy	23200.00
0005434600345	6050	Economy	23200.00
0005434600344	6050	Economy	23200.00
0005434600352	6050	Economy	23200.00
0005434600348	6050	Economy	23200.00
0005434600347	6050	Economy	23200.00
0005434600335	6050	Economy	23200.00
0005432111225	6050	Economy	23200.00
0005434600327	6050	Economy	23200.00
0005435326511	18571	Business	69700.00
0005435326498	18571	Economy	23200.00
0005435326500	18571	Economy	23200.00
0005435326507	18571	Economy	25600.00
0005435326510	18571	Economy	23200.00
0005435326497	18571	Economy	23200.00
0005435326506	18571	Economy	23200.00
0005435326501	18571	Economy	23200.00
0005435326509	18571	Economy	23200.00
0005435326499	18571	Economy	23200.00
0005435326504	18571	Economy	23200.00
0005435326505	18571	Economy	23200.00
0005435326502	18571	Economy	23200.00
0005435326503	18571	Economy	23200.00
0005435326508	18571	Economy	23200.00
0005434554024	10653	Economy	3000.00
0005433180671	27692	Business	9100.00
0005433180663	27692	Business	9100.00
0005433180665	27692	Business	9100.00
0005433180648	27692	Business	9100.00
0005433180649	27692	Business	9100.00
0005433180661	27692	Business	9100.00
0005433180650	27692	Economy	3000.00
0005433180667	27692	Economy	3000.00
0005433180662	27692	Economy	3300.00
0005433180672	27692	Economy	3300.00
0005433180659	27692	Economy	3000.00
0005433180670	27692	Economy	3000.00
0005433180657	27692	Economy	3000.00
0005433180652	27692	Economy	3000.00
0005433180656	27692	Economy	3000.00
0005433180673	27692	Economy	3000.00
0005433180655	27692	Economy	3000.00
0005433180654	27692	Economy	3000.00
0005433180658	27692	Economy	3000.00
0005433180666	27692	Economy	3000.00
0005433180660	27692	Economy	3000.00
0005433180664	27692	Economy	3000.00
0005433180653	27692	Economy	3000.00
0005433180651	27692	Economy	3000.00
0005433180668	27692	Economy	3000.00
0005433180669	27692	Economy	3000.00
0005433459143	6148	Economy	11700.00
0005433459145	6148	Economy	11700.00
0005433459146	6148	Economy	11700.00
0005433459144	6148	Economy	11700.00
0005435254429	19301	Economy	11700.00
0005435254430	19301	Economy	11700.00
0005435681419	6733	Business	51100.00
0005435681402	6733	Business	51100.00
0005432136082	6733	Business	51100.00
0005435681386	6733	Business	51100.00
0005432136083	6733	Business	51100.00
0005435681404	6733	Business	51100.00
0005435681421	6733	Economy	17000.00
0005435681423	6733	Economy	17000.00
0005435681425	6733	Economy	17000.00
0005435681403	6733	Economy	17000.00
0005435681390	6733	Economy	18700.00
0005435681408	6733	Economy	18700.00
0005435720118	6733	Economy	18700.00
0005435681384	6733	Economy	18700.00
0005435681422	6733	Economy	18700.00
0005432136081	6733	Economy	17000.00
0005435681411	6733	Economy	17000.00
0005435681392	6733	Economy	17000.00
0005435681389	6733	Economy	17000.00
0005435681401	6733	Economy	17000.00
0005435681385	6733	Economy	17000.00
0005435681415	6733	Economy	17000.00
0005435681395	6733	Economy	17000.00
0005435681396	6733	Economy	17000.00
0005435681399	6733	Economy	17000.00
0005435681410	6733	Economy	17000.00
0005435681391	6733	Economy	17000.00
0005435681414	6733	Economy	17000.00
0005435681420	6733	Economy	17000.00
0005432136079	6733	Economy	17000.00
0005435681417	6733	Economy	17000.00
0005435720119	6733	Economy	17000.00
0005432136084	6733	Economy	17000.00
0005435681407	6733	Economy	17000.00
0005435681427	6733	Economy	17000.00
0005435681393	6733	Economy	17000.00
0005435681405	6733	Economy	17000.00
0005432136080	6733	Economy	17000.00
0005435681394	6733	Economy	17000.00
0005435681397	6733	Economy	17000.00
0005435681426	6733	Economy	17000.00
0005435681387	6733	Economy	17000.00
0005435681424	6733	Economy	17000.00
0005435681388	6733	Economy	17000.00
0005435681413	6733	Economy	17000.00
0005435681409	6733	Economy	17000.00
0005435681412	6733	Economy	17000.00
0005435681400	6733	Economy	17000.00
0005435681398	6733	Economy	17000.00
0005435681418	6733	Economy	17000.00
0005435681406	6733	Economy	17000.00
0005435681416	6733	Economy	17000.00
0005435437570	24574	Business	51100.00
0005435437562	24574	Business	51100.00
0005435437557	24574	Business	51100.00
0005435437568	24574	Business	51100.00
0005435437573	24574	Business	51100.00
0005432533240	24574	Economy	17000.00
0005435437566	24574	Economy	17000.00
0005435437574	24574	Economy	17000.00
0005432305706	24574	Economy	18700.00
0005434828649	24574	Economy	18700.00
0005435437563	24574	Economy	18700.00
0005435437567	24574	Economy	18700.00
0005435437569	24574	Economy	17000.00
0005435437572	24574	Economy	17000.00
0005435437559	24574	Economy	17000.00
0005435437551	24574	Economy	17000.00
0005435437553	24574	Economy	17000.00
0005434828650	24574	Economy	17000.00
0005435437560	24574	Economy	17000.00
0005434828648	24574	Economy	17000.00
0005435437554	24574	Economy	17000.00
0005432305705	24574	Economy	17000.00
0005435437564	24574	Economy	17000.00
0005435437571	24574	Economy	17000.00
0005432533241	24574	Economy	17000.00
0005435437555	24574	Economy	17000.00
0005435437565	24574	Economy	17000.00
0005435437558	24574	Economy	17000.00
0005432533242	24574	Economy	17000.00
0005435437556	24574	Economy	17000.00
0005435437561	24574	Economy	17000.00
0005435437552	24574	Economy	17000.00
0005435105923	11521	Economy	8800.00
0005435105925	11521	Economy	8800.00
0005435105924	11521	Economy	8800.00
0005435558039	31901	Economy	8800.00
0005435558040	31901	Economy	8800.00
0005435558041	31901	Economy	8800.00
0005433397181	13537	Business	36600.00
0005433397182	13537	Business	36600.00
0005433397222	13537	Business	36600.00
0005433397212	13537	Business	36600.00
0005433397220	13537	Business	36600.00
0005433397200	13537	Economy	12200.00
0005433397203	13537	Economy	12200.00
0005433397184	13537	Economy	12200.00
0005433397179	13537	Economy	13400.00
0005433397188	13537	Economy	13400.00
0005433397202	13537	Economy	13400.00
0005433397196	13537	Economy	12200.00
0005433397213	13537	Economy	12200.00
0005433397201	13537	Economy	12200.00
0005433397224	13537	Economy	12200.00
0005433397207	13537	Economy	12200.00
0005433397197	13537	Economy	12200.00
0005433397208	13537	Economy	12200.00
0005433397183	13537	Economy	12200.00
0005433397205	13537	Economy	12200.00
0005433397187	13537	Economy	12200.00
0005433397211	13537	Economy	12200.00
0005433397228	13537	Economy	12200.00
0005433397217	13537	Economy	12200.00
0005433397194	13537	Economy	12200.00
0005433397214	13537	Economy	12200.00
0005433397189	13537	Economy	12200.00
0005433397215	13537	Economy	12200.00
0005433397226	13537	Economy	12200.00
0005433397225	13537	Economy	12200.00
0005433397216	13537	Economy	12200.00
0005433397227	13537	Economy	12200.00
0005433397223	13537	Economy	12200.00
0005433397185	13537	Economy	12200.00
0005433397198	13537	Economy	12200.00
0005433397192	13537	Economy	12200.00
0005433397219	13537	Economy	12200.00
0005433397210	13537	Economy	12200.00
0005433397178	13537	Economy	12200.00
0005433397206	13537	Economy	12200.00
0005433397180	13537	Economy	12200.00
0005433397193	13537	Economy	12200.00
0005433397218	13537	Economy	12200.00
0005433397191	13537	Economy	12200.00
0005433397221	13537	Economy	12200.00
0005433397199	13537	Economy	12200.00
0005433397186	13537	Economy	12200.00
0005433397209	13537	Economy	12200.00
0005433397190	13537	Economy	12200.00
0005433397195	13537	Economy	12200.00
0005433397204	13537	Economy	12200.00
0005435732116	19417	Business	36600.00
0005435732122	19417	Business	36600.00
0005435732117	19417	Business	36600.00
0005435732114	19417	Business	36600.00
0005435732121	19417	Economy	12200.00
0005432297231	19417	Economy	12200.00
0005435732119	19417	Economy	12200.00
0005435732112	19417	Economy	12200.00
0005435732115	19417	Economy	12200.00
0005435732123	19417	Economy	12200.00
0005432297232	19417	Economy	12200.00
0005435732120	19417	Economy	12200.00
0005432297230	19417	Economy	12200.00
0005435732113	19417	Economy	12200.00
0005435732124	19417	Economy	12200.00
0005435732118	19417	Economy	12200.00
0005435925055	13148	Business	11300.00
0005435925051	13148	Business	11300.00
0005435925047	13148	Business	11300.00
0005435925054	13148	Economy	3800.00
0005435925060	13148	Economy	4100.00
0005435925049	13148	Economy	3800.00
0005435925057	13148	Economy	3800.00
0005435925048	13148	Economy	3800.00
0005435925052	13148	Economy	3800.00
0005435925050	13148	Economy	3800.00
0005435925046	13148	Economy	3800.00
0005435925058	13148	Economy	3800.00
0005435925059	13148	Economy	3800.00
0005435925053	13148	Economy	3800.00
0005435925056	13148	Economy	3800.00
0005433407477	29499	Economy	27100.00
0005433407479	29499	Economy	24700.00
0005433407478	29499	Economy	24700.00
0005433407480	29499	Economy	24700.00
0005433407481	29499	Economy	24700.00
0005434213729	10699	Business	61300.00
0005434213726	10699	Business	61300.00
0005434213707	10699	Business	61300.00
0005434213720	10699	Business	61300.00
0005434213731	10699	Business	61300.00
0005434213728	10699	Economy	20400.00
0005434213740	10699	Economy	20400.00
0005434213705	10699	Economy	20400.00
0005434213704	10699	Economy	20400.00
0005434213702	10699	Economy	22500.00
0005434213737	10699	Economy	22500.00
0005434213708	10699	Economy	20400.00
0005434213732	10699	Economy	20400.00
0005434213712	10699	Economy	20400.00
0005434213724	10699	Economy	20400.00
0005434213743	10699	Economy	20400.00
0005434213742	10699	Economy	20400.00
0005434213701	10699	Economy	20400.00
0005434213709	10699	Economy	20400.00
0005434213698	10699	Economy	20400.00
0005434213714	10699	Economy	20400.00
0005434213717	10699	Economy	20400.00
0005434213733	10699	Economy	20400.00
0005434213703	10699	Economy	20400.00
0005434213734	10699	Economy	20400.00
0005434213721	10699	Economy	20400.00
0005434213715	10699	Economy	20400.00
0005434213713	10699	Economy	20400.00
0005434213718	10699	Economy	20400.00
0005434213723	10699	Economy	20400.00
0005434213711	10699	Economy	20400.00
0005434213735	10699	Economy	20400.00
0005434213716	10699	Economy	20400.00
0005434213744	10699	Economy	20400.00
0005434213727	10699	Economy	20400.00
0005434213700	10699	Economy	20400.00
0005434213719	10699	Economy	20400.00
0005434213738	10699	Economy	20400.00
0005434213706	10699	Economy	20400.00
0005434213736	10699	Economy	20400.00
0005434213730	10699	Economy	20400.00
0005434213710	10699	Economy	20400.00
0005434213741	10699	Economy	20400.00
0005434213739	10699	Economy	20400.00
0005434213745	10699	Economy	20400.00
0005434213725	10699	Economy	20400.00
0005434213699	10699	Economy	20400.00
0005434213722	10699	Economy	20400.00
0005435006602	5474	Business	29500.00
0005432125319	5474	Business	29500.00
0005435038610	5474	Business	29500.00
0005435006618	5474	Business	29500.00
0005435006616	5474	Business	29500.00
0005432125321	5474	Business	29500.00
0005435038645	5474	Business	29500.00
0005435038638	5474	Business	29500.00
0005435006611	5474	Business	29500.00
0005432125324	5474	Economy	9800.00
0005435038618	5474	Economy	9800.00
0005435038661	5474	Economy	9800.00
0005435006606	5474	Economy	9800.00
0005435038631	5474	Economy	9800.00
0005435038643	5474	Economy	9800.00
0005435006610	5474	Economy	9800.00
0005435038627	5474	Economy	9800.00
0005432125322	5474	Economy	9800.00
0005435038656	5474	Economy	9800.00
0005435006607	5474	Economy	9800.00
0005435038619	5474	Economy	9800.00
0005435038668	5474	Economy	9800.00
0005435038648	5474	Economy	9800.00
0005435038642	5474	Economy	9800.00
0005435038611	5474	Economy	9800.00
0005435038652	5474	Economy	9800.00
0005435038626	5474	Economy	9800.00
0005435038665	5474	Economy	9800.00
0005435038666	5474	Economy	9800.00
0005435006603	5474	Economy	9800.00
0005435038672	5474	Economy	9800.00
0005435038662	5474	Economy	9800.00
0005435038675	5474	Economy	9800.00
0005435038659	5474	Economy	9800.00
0005435038657	5474	Economy	9800.00
0005435006613	5474	Economy	9800.00
0005435038616	5474	Economy	9800.00
0005435038640	5474	Economy	9800.00
0005435038663	5474	Economy	9800.00
0005432125325	5474	Economy	9800.00
0005435038651	5474	Economy	10800.00
0005435038622	5474	Economy	9800.00
0005435038654	5474	Economy	10800.00
0005435038625	5474	Economy	10800.00
0005435038647	5474	Economy	10800.00
0005435038637	5474	Economy	10800.00
0005432125318	5474	Economy	9800.00
0005435038650	5474	Economy	9800.00
0005435038639	5474	Economy	9800.00
0005435038641	5474	Economy	9800.00
0005435038653	5474	Economy	9800.00
0005435038628	5474	Economy	9800.00
0005435038646	5474	Economy	9800.00
0005435006615	5474	Economy	9800.00
0005435038671	5474	Economy	9800.00
0005435038621	5474	Economy	9800.00
0005435038649	5474	Economy	9800.00
0005435006609	5474	Economy	9800.00
0005435038620	5474	Economy	9800.00
0005435038670	5474	Economy	9800.00
0005435038615	5474	Economy	9800.00
0005435006614	5474	Economy	9800.00
0005435038614	5474	Economy	9800.00
0005435042820	5474	Economy	9800.00
0005435006617	5474	Economy	9800.00
0005435038612	5474	Economy	9800.00
0005435006605	5474	Economy	9800.00
0005435042822	5474	Economy	9800.00
0005435038658	5474	Economy	9800.00
0005435038624	5474	Economy	9800.00
0005435038633	5474	Economy	9800.00
0005435038613	5474	Economy	9800.00
0005435006604	5474	Economy	9800.00
0005435038664	5474	Economy	9800.00
0005435038617	5474	Economy	9800.00
0005435006601	5474	Economy	9800.00
0005432125323	5474	Economy	9800.00
0005432125320	5474	Economy	9800.00
0005435038644	5474	Economy	9800.00
0005435038655	5474	Economy	9800.00
0005435042823	5474	Economy	9800.00
0005435038634	5474	Economy	9800.00
0005435006608	5474	Economy	9800.00
0005435042821	5474	Economy	9800.00
0005435006619	5474	Economy	9800.00
0005435006612	5474	Economy	9800.00
0005435038673	5474	Economy	9800.00
0005435038623	5474	Economy	9800.00
0005435038632	5474	Economy	9800.00
0005435038629	5474	Economy	9800.00
0005435006620	5474	Economy	9800.00
0005435038674	5474	Economy	9800.00
0005435038660	5474	Economy	9800.00
0005435038669	5474	Economy	9800.00
0005435038630	5474	Economy	9800.00
0005435038635	5474	Economy	9800.00
0005435038667	5474	Economy	9800.00
0005435038636	5474	Economy	9800.00
0005432304331	12973	Business	29500.00
0005434228978	12973	Business	29500.00
0005434228981	12973	Economy	9800.00
0005434228980	12973	Economy	9800.00
0005434228970	12973	Economy	9800.00
0005434228986	12973	Economy	9800.00
0005432304330	12973	Economy	9800.00
0005434228975	12973	Economy	10800.00
0005434228988	12973	Economy	10800.00
0005434228967	12973	Economy	9800.00
0005434228968	12973	Economy	9800.00
0005434228977	12973	Economy	9800.00
0005434228985	12973	Economy	9800.00
0005434228971	12973	Economy	9800.00
0005432304329	12973	Economy	9800.00
0005434228979	12973	Economy	9800.00
0005434228982	12973	Economy	9800.00
0005434228973	12973	Economy	9800.00
0005434228983	12973	Economy	9800.00
0005434228987	12973	Economy	9800.00
0005434228984	12973	Economy	9800.00
0005434228972	12973	Economy	9800.00
0005434228974	12973	Economy	9800.00
0005434228966	12973	Economy	9800.00
0005434228969	12973	Economy	9800.00
0005434228976	12973	Economy	9800.00
0005432059471	20234	Business	52900.00
0005435554107	20234	Business	52900.00
0005432059469	20234	Business	52900.00
0005435902395	20234	Business	52900.00
0005435902389	20234	Economy	17600.00
0005435902393	20234	Economy	17600.00
0005435902398	20234	Economy	19400.00
0005435902387	20234	Economy	19400.00
0005435554103	20234	Economy	17600.00
0005435902385	20234	Economy	17600.00
0005435902390	20234	Economy	17600.00
0005432059470	20234	Economy	17600.00
0005435902388	20234	Economy	17600.00
0005435554106	20234	Economy	17600.00
0005435902397	20234	Economy	17600.00
0005435902391	20234	Economy	17600.00
0005435902400	20234	Economy	17600.00
0005435554104	20234	Economy	17600.00
0005435902392	20234	Economy	17600.00
0005435902399	20234	Economy	17600.00
0005435902401	20234	Economy	17600.00
0005435902396	20234	Economy	17600.00
0005435902384	20234	Economy	17600.00
0005435902386	20234	Economy	17600.00
0005435554105	20234	Economy	17600.00
0005435902394	20234	Economy	17600.00
0005434269067	26680	Business	18500.00
0005433434207	26680	Business	18500.00
0005433434206	26680	Business	18500.00
0005433434187	26680	Business	18500.00
0005433434186	26680	Economy	6200.00
0005433434196	26680	Economy	6200.00
0005433434181	26680	Economy	6200.00
0005433434194	26680	Economy	6800.00
0005434269068	26680	Economy	6800.00
0005433434195	26680	Economy	6200.00
0005433434182	26680	Economy	6200.00
0005433434201	26680	Economy	6200.00
0005433434198	26680	Economy	6200.00
0005433434197	26680	Economy	6200.00
0005433434205	26680	Economy	6200.00
0005433434202	26680	Economy	6200.00
0005433434191	26680	Economy	6200.00
0005433434203	26680	Economy	6200.00
0005433434208	26680	Economy	6200.00
0005433434180	26680	Economy	6200.00
0005433434188	26680	Economy	6200.00
0005433434192	26680	Economy	6200.00
0005434270171	26680	Economy	6200.00
0005432051074	26680	Economy	6200.00
0005433434183	26680	Economy	6200.00
0005434269069	26680	Economy	6200.00
0005433434204	26680	Economy	6200.00
0005433434184	26680	Economy	6200.00
0005433434199	26680	Economy	6200.00
0005432051076	26680	Economy	6200.00
0005434271275	26680	Economy	6200.00
0005433434200	26680	Economy	6200.00
0005433434185	26680	Economy	6200.00
0005432051075	26680	Economy	6200.00
0005433434193	26680	Economy	6200.00
0005434270170	26680	Economy	6200.00
0005433434190	26680	Economy	6200.00
0005433434189	26680	Economy	6200.00
0005434271276	26680	Economy	6200.00
0005432583598	3180	Economy	11100.00
0005432583604	3180	Economy	11100.00
0005432583594	3180	Economy	11100.00
0005432583591	3180	Economy	10100.00
0005432583589	3180	Economy	10100.00
0005432583586	3180	Economy	10100.00
0005432583606	3180	Economy	10100.00
0005432583588	3180	Economy	10100.00
0005432583592	3180	Economy	10100.00
0005432583600	3180	Economy	10100.00
0005432583590	3180	Economy	10100.00
0005432583582	3180	Economy	10100.00
0005432583585	3180	Economy	10100.00
0005432583599	3180	Economy	10100.00
0005432583596	3180	Economy	10100.00
0005432583583	3180	Economy	10100.00
0005432583605	3180	Economy	10100.00
0005432583597	3180	Economy	10100.00
0005432583584	3180	Economy	10100.00
0005432583593	3180	Economy	10100.00
0005432583603	3180	Economy	10100.00
0005432216222	3180	Economy	10100.00
0005432583601	3180	Economy	10100.00
0005432216223	3180	Economy	10100.00
0005432583602	3180	Economy	10100.00
0005432583595	3180	Economy	10100.00
0005432583587	3180	Economy	10100.00
0005432216224	3180	Economy	10100.00
0005432857855	31520	Economy	10100.00
0005432857858	31520	Economy	10100.00
0005432857852	31520	Economy	10100.00
0005432857856	31520	Economy	10100.00
0005432857854	31520	Economy	10100.00
0005432857860	31520	Economy	10100.00
0005432857857	31520	Economy	10100.00
0005432857861	31520	Economy	10100.00
0005432857859	31520	Economy	10100.00
0005432857853	31520	Economy	10100.00
0005432857863	31520	Economy	10100.00
0005432857862	31520	Economy	10100.00
0005434943193	912	Economy	8300.00
0005434943187	912	Economy	7500.00
0005434943184	912	Economy	7500.00
0005434943186	912	Economy	7500.00
0005434943191	912	Economy	7500.00
0005434943194	912	Economy	7500.00
0005434943190	912	Economy	7500.00
0005434943185	912	Economy	7500.00
0005434943189	912	Economy	7500.00
0005434943192	912	Economy	7500.00
0005434943188	912	Economy	7500.00
0005433255025	16199	Economy	8300.00
0005433255023	16199	Economy	7500.00
0005433255021	16199	Economy	7500.00
0005433255024	16199	Economy	7500.00
0005433255022	16199	Economy	7500.00
0005433654647	4322	Business	90500.00
0005433654653	4322	Economy	33200.00
0005433654648	4322	Economy	30200.00
0005433654652	4322	Economy	30200.00
0005433654651	4322	Economy	30200.00
0005433654650	4322	Economy	30200.00
0005433654654	4322	Economy	30200.00
0005433654649	4322	Economy	30200.00
0005433804791	9336	Business	186200.00
0005433784317	9336	Business	186200.00
0005433784328	9336	Business	186200.00
0005433762954	9336	Business	186200.00
0005432666352	9336	Business	186200.00
0005433804783	9336	Business	186200.00
0005433804779	9336	Business	186200.00
0005433784321	9336	Business	186200.00
0005433804784	9336	Business	186200.00
0005433762944	9336	Business	186200.00
0005433804788	9336	Business	186200.00
0005433784297	9336	Business	186200.00
0005433784312	9336	Business	186200.00
0005433784306	9336	Economy	62100.00
0005432665238	9336	Economy	62100.00
0005433784316	9336	Economy	62100.00
0005433784327	9336	Economy	62100.00
0005432657393	9336	Economy	62100.00
0005433784305	9336	Economy	62100.00
0005433762942	9336	Economy	62100.00
0005433784294	9336	Economy	62100.00
0005433762949	9336	Economy	62100.00
0005433762953	9336	Economy	62100.00
0005433784299	9336	Economy	62100.00
0005433784326	9336	Economy	62100.00
0005433784302	9336	Economy	62100.00
0005433784313	9336	Economy	62100.00
0005433762955	9336	Economy	62100.00
0005433784292	9336	Economy	62100.00
0005433804780	9336	Economy	62100.00
0005433784322	9336	Economy	62100.00
0005433784324	9336	Economy	62100.00
0005432666353	9336	Economy	62100.00
0005433804785	9336	Economy	62100.00
0005433784320	9336	Economy	62100.00
0005433784318	9336	Economy	62100.00
0005433784295	9336	Economy	62100.00
0005432665237	9336	Economy	62100.00
0005433804790	9336	Economy	62100.00
0005433762943	9336	Economy	62100.00
0005433804792	9336	Economy	62100.00
0005433784301	9336	Economy	62100.00
0005433784319	9336	Economy	62100.00
0005433762948	9336	Economy	62100.00
0005432657395	9336	Economy	62100.00
0005433762950	9336	Economy	68300.00
0005433804787	9336	Economy	62100.00
0005433762956	9336	Economy	68300.00
0005433762951	9336	Economy	68300.00
0005433762946	9336	Economy	62100.00
0005433784296	9336	Economy	62100.00
0005433762947	9336	Economy	62100.00
0005433804781	9336	Economy	62100.00
0005433784311	9336	Economy	62100.00
0005433804782	9336	Economy	62100.00
0005433804778	9336	Economy	62100.00
0005433784315	9336	Economy	62100.00
0005433804777	9336	Economy	62100.00
0005432657394	9336	Economy	62100.00
0005433784293	9336	Economy	62100.00
0005433784304	9336	Economy	62100.00
0005433804789	9336	Economy	62100.00
0005433784325	9336	Economy	62100.00
0005433784300	9336	Economy	62100.00
0005433784309	9336	Economy	62100.00
0005433804793	9336	Economy	62100.00
0005433784298	9336	Economy	62100.00
0005433784307	9336	Economy	62100.00
0005432666351	9336	Economy	62100.00
0005433784310	9336	Economy	62100.00
0005433784314	9336	Economy	62100.00
0005433804786	9336	Economy	62100.00
0005433762952	9336	Economy	62100.00
0005433784303	9336	Economy	62100.00
0005433784323	9336	Economy	62100.00
0005433762945	9336	Economy	62100.00
0005433784308	9336	Economy	62100.00
0005434170798	26277	Business	186200.00
0005435269632	26277	Business	186200.00
0005435269631	26277	Economy	68300.00
0005434170806	26277	Economy	62100.00
0005434170804	26277	Economy	62100.00
0005435269628	26277	Economy	62100.00
0005435269633	26277	Economy	62100.00
0005435269625	26277	Economy	62100.00
0005434170807	26277	Economy	62100.00
0005435269634	26277	Economy	62100.00
0005435269622	26277	Economy	62100.00
0005434170801	26277	Economy	62100.00
0005435269641	26277	Economy	62100.00
0005434170797	26277	Economy	62100.00
0005434170810	26277	Economy	62100.00
0005435269621	26277	Economy	62100.00
0005435269624	26277	Economy	62100.00
0005435269635	26277	Economy	62100.00
0005435269639	26277	Economy	62100.00
0005434170809	26277	Economy	62100.00
0005434170805	26277	Economy	62100.00
0005435269642	26277	Economy	62100.00
0005434170800	26277	Economy	62100.00
0005435269623	26277	Economy	62100.00
0005435269640	26277	Economy	62100.00
0005435269627	26277	Economy	62100.00
0005435269636	26277	Economy	62100.00
0005434170803	26277	Economy	62100.00
0005434170802	26277	Economy	62100.00
0005435269626	26277	Economy	62100.00
0005434170799	26277	Economy	62100.00
0005434170808	26277	Economy	62100.00
0005435269638	26277	Economy	62100.00
0005435269630	26277	Economy	62100.00
0005435269629	26277	Economy	62100.00
0005435269637	26277	Economy	62100.00
0005435135585	4920	Economy	5300.00
0005435135582	4920	Economy	5300.00
0005435135583	4920	Economy	5300.00
0005435135584	4920	Economy	5300.00
0005435929595	33055	Economy	5300.00
0005435929597	33055	Economy	5300.00
0005435929596	33055	Economy	5300.00
0005434983194	9467	Economy	17900.00
0005434983198	9467	Economy	17900.00
0005434983195	9467	Economy	17900.00
0005434983197	9467	Economy	17900.00
0005434983196	9467	Economy	17900.00
0005434983193	9467	Economy	17900.00
0005434217896	27368	Economy	17900.00
0005434217894	27368	Economy	17900.00
0005434217897	27368	Economy	17900.00
0005434217895	27368	Economy	17900.00
0005434217898	27368	Economy	17900.00
0005434479880	923	Economy	25400.00
0005434479885	923	Economy	25400.00
0005434479896	923	Economy	23100.00
0005432269447	923	Economy	23100.00
0005434479888	923	Economy	23100.00
0005434479903	923	Economy	23100.00
0005432269445	923	Economy	23100.00
0005434479893	923	Economy	23100.00
0005434479894	923	Economy	23100.00
0005434479895	923	Economy	23100.00
0005434479879	923	Economy	23100.00
0005434479900	923	Economy	23100.00
0005434479897	923	Economy	23100.00
0005434479886	923	Economy	23100.00
0005434479890	923	Economy	23100.00
0005434479901	923	Economy	23100.00
0005434479878	923	Economy	23100.00
0005432269446	923	Economy	23100.00
0005434479881	923	Economy	23100.00
0005434479898	923	Economy	23100.00
0005434479902	923	Economy	23100.00
0005434479892	923	Economy	23100.00
0005434479883	923	Economy	23100.00
0005434479887	923	Economy	23100.00
0005434479882	923	Economy	23100.00
0005434479884	923	Economy	23100.00
0005434479889	923	Economy	23100.00
0005434479899	923	Economy	23100.00
0005434479891	923	Economy	23100.00
0005433165675	16590	Economy	25400.00
0005433165683	16590	Economy	23100.00
0005433165682	16590	Economy	23100.00
0005433165676	16590	Economy	23100.00
0005433165680	16590	Economy	23100.00
0005433165674	16590	Economy	23100.00
0005433165670	16590	Economy	23100.00
0005433165677	16590	Economy	23100.00
0005433165678	16590	Economy	23100.00
0005433165673	16590	Economy	23100.00
0005433165681	16590	Economy	23100.00
0005433165672	16590	Economy	23100.00
0005433165671	16590	Economy	23100.00
0005433165679	16590	Economy	23100.00
0005433872427	3194	Economy	17200.00
0005433872426	3194	Economy	17200.00
0005433872428	3194	Economy	17200.00
0005435386455	21926	Economy	17000.00
0005435386456	21926	Economy	17000.00
0005433289725	21926	Economy	15400.00
0005435386454	21926	Economy	15400.00
0005433289727	21926	Economy	15400.00
0005433289726	21926	Economy	15400.00
0005433289728	21926	Economy	15400.00
0005435386457	21926	Economy	15400.00
0005433289730	21926	Economy	15400.00
0005433289729	21926	Economy	15400.00
0005435319423	20931	Business	57200.00
0005435319424	20931	Business	57200.00
0005435319429	20931	Economy	19100.00
0005435319431	20931	Economy	21000.00
0005435319426	20931	Economy	19100.00
0005435319427	20931	Economy	19100.00
0005435319425	20931	Economy	19100.00
0005435319428	20931	Economy	19100.00
0005435319430	20931	Economy	19100.00
0005433683291	24306	Economy	17100.00
0005433683290	24306	Economy	17100.00
0005433683293	24306	Economy	17100.00
0005433683292	24306	Economy	17100.00
0005433927397	29277	Economy	17100.00
0005433927396	29277	Economy	17100.00
0005433927395	29277	Economy	17100.00
0005432706316	2926	Business	10300.00
0005432706311	2926	Business	10300.00
0005432706307	2926	Business	10300.00
0005432217726	2926	Business	10300.00
0005432706324	2926	Economy	3400.00
0005432706313	2926	Economy	3400.00
0005432706329	2926	Economy	3800.00
0005432706318	2926	Economy	3800.00
0005432706312	2926	Economy	3800.00
0005432706326	2926	Economy	3400.00
0005432706331	2926	Economy	3400.00
0005432706330	2926	Economy	3400.00
0005432706309	2926	Economy	3400.00
0005432706321	2926	Economy	3400.00
0005432706310	2926	Economy	3400.00
0005432706308	2926	Economy	3400.00
0005432706323	2926	Economy	3400.00
0005432706322	2926	Economy	3400.00
0005432706328	2926	Economy	3400.00
0005432217725	2926	Economy	3400.00
0005432706332	2926	Economy	3400.00
0005432706319	2926	Economy	3400.00
0005432706325	2926	Economy	3400.00
0005432706315	2926	Economy	3400.00
0005432706320	2926	Economy	3400.00
0005432706317	2926	Economy	3400.00
0005432706327	2926	Economy	3400.00
0005432706314	2926	Economy	3400.00
0005432217724	2926	Economy	3400.00
0005432692531	30019	Business	10300.00
0005432692533	30019	Business	10300.00
0005432692527	30019	Business	10300.00
0005432692534	30019	Business	10300.00
0005432880563	30019	Economy	3400.00
0005432880561	30019	Economy	3400.00
0005432692552	30019	Economy	3400.00
0005432692547	30019	Economy	3400.00
0005432880555	30019	Economy	3400.00
0005432692541	30019	Economy	3800.00
0005432692556	30019	Economy	3800.00
0005432692553	30019	Economy	3800.00
0005432692545	30019	Economy	3800.00
0005432692529	30019	Economy	3400.00
0005432692549	30019	Economy	3400.00
0005432692528	30019	Economy	3400.00
0005432880557	30019	Economy	3400.00
0005432880562	30019	Economy	3400.00
0005432692554	30019	Economy	3400.00
0005432692550	30019	Economy	3400.00
0005432692557	30019	Economy	3400.00
0005432692543	30019	Economy	3400.00
0005432692539	30019	Economy	3400.00
0005432880551	30019	Economy	3400.00
0005432692536	30019	Economy	3400.00
0005432692540	30019	Economy	3400.00
0005432880553	30019	Economy	3400.00
0005432880554	30019	Economy	3400.00
0005432692555	30019	Economy	3400.00
0005432692546	30019	Economy	3400.00
0005432880558	30019	Economy	3400.00
0005432692548	30019	Economy	3400.00
0005432692551	30019	Economy	3400.00
0005432880552	30019	Economy	3400.00
0005432880565	30019	Economy	3400.00
0005432880564	30019	Economy	3400.00
0005432692530	30019	Economy	3400.00
0005432880560	30019	Economy	3400.00
0005432692538	30019	Economy	3400.00
0005432692532	30019	Economy	3400.00
0005432692558	30019	Economy	3400.00
0005432692544	30019	Economy	3400.00
0005432692535	30019	Economy	3400.00
0005432880556	30019	Economy	3400.00
0005432692542	30019	Economy	3400.00
0005432692537	30019	Economy	3400.00
0005432880559	30019	Economy	3400.00
0005433113495	19632	Economy	19700.00
0005433113496	19632	Economy	19700.00
0005435068172	3533	Business	26900.00
0005435068190	3533	Business	26900.00
0005435068181	3533	Business	26900.00
0005435068175	3533	Business	26900.00
0005435718830	3533	Business	26900.00
0005435068200	3533	Business	26900.00
0005435068194	3533	Business	26900.00
0005435068180	3533	Economy	9000.00
0005435068207	3533	Economy	9000.00
0005435068210	3533	Economy	9000.00
0005435068163	3533	Economy	9000.00
0005435718828	3533	Economy	9000.00
0005435718827	3533	Economy	9000.00
0005435068160	3533	Economy	9900.00
0005435068161	3533	Economy	9900.00
0005435068176	3533	Economy	9900.00
0005435068170	3533	Economy	9000.00
0005435068168	3533	Economy	9000.00
0005435068199	3533	Economy	9000.00
0005435068162	3533	Economy	9000.00
0005435068169	3533	Economy	9000.00
0005435718831	3533	Economy	9000.00
0005435068184	3533	Economy	9000.00
0005435068195	3533	Economy	9000.00
0005435068208	3533	Economy	9000.00
0005435068178	3533	Economy	9000.00
0005435068192	3533	Economy	9000.00
0005435068174	3533	Economy	9000.00
0005435068183	3533	Economy	9000.00
0005435068198	3533	Economy	9000.00
0005435068166	3533	Economy	9000.00
0005435068191	3533	Economy	9000.00
0005435068187	3533	Economy	9000.00
0005435718829	3533	Economy	9000.00
0005435068173	3533	Economy	9000.00
0005435068158	3533	Economy	9000.00
0005435068171	3533	Economy	9000.00
0005435068202	3533	Economy	9000.00
0005435068209	3533	Economy	9000.00
0005435068164	3533	Economy	9000.00
0005435068159	3533	Economy	9000.00
0005435068197	3533	Economy	9000.00
0005435068204	3533	Economy	9000.00
0005435068179	3533	Economy	9000.00
0005435068205	3533	Economy	9000.00
0005435068185	3533	Economy	9000.00
0005435068193	3533	Economy	9000.00
0005435068201	3533	Economy	9000.00
0005435068188	3533	Economy	9000.00
0005435068206	3533	Economy	9000.00
0005435068186	3533	Economy	9000.00
0005435068189	3533	Economy	9000.00
0005435068196	3533	Economy	9000.00
0005435068203	3533	Economy	9000.00
0005435068177	3533	Economy	9000.00
0005435068182	3533	Economy	9000.00
0005435068167	3533	Economy	9000.00
0005435068165	3533	Economy	9000.00
0005435925060	15302	Economy	9000.00
0005435925056	15302	Economy	9000.00
0005435925051	15302	Economy	9000.00
0005435925049	15302	Economy	9900.00
0005435925048	15302	Economy	9000.00
0005435925057	15302	Economy	9000.00
0005435925052	15302	Economy	9000.00
0005435925046	15302	Economy	9000.00
0005435939856	15302	Economy	9000.00
0005435925053	15302	Economy	9000.00
0005435925058	15302	Economy	9000.00
0005435925047	15302	Economy	9000.00
0005435925059	15302	Economy	9000.00
0005435925055	15302	Economy	9000.00
0005435925050	15302	Economy	9000.00
0005435925054	15302	Economy	9000.00
0005432157458	62	Business	20000.00
0005432157457	62	Economy	6700.00
0005432816945	1	Business	20000.00
0005432261100	1	Business	20000.00
0005432261133	1	Business	20000.00
0005432261098	1	Business	20000.00
0005432261099	1	Business	20000.00
0005432816962	1	Business	20000.00
0005432261101	1	Business	20000.00
0005432261122	1	Business	20000.00
0005432816959	1	Business	20000.00
0005432261110	1	Business	20000.00
0005432261129	1	Business	20000.00
0005432261096	1	Business	20000.00
0005432816955	1	Economy	7300.00
0005432816943	1	Economy	7300.00
0005432261119	1	Economy	7300.00
0005432816938	1	Economy	7300.00
0005432816947	1	Economy	6700.00
0005432261090	1	Economy	6700.00
0005432816951	1	Economy	6700.00
0005432816960	1	Economy	6700.00
0005432261115	1	Economy	6700.00
0005432816954	1	Economy	6700.00
0005432816961	1	Economy	6700.00
0005432261097	1	Economy	6700.00
0005432261092	1	Economy	6700.00
0005432816963	1	Economy	6700.00
0005432261103	1	Economy	6700.00
0005432261116	1	Economy	6700.00
0005432261109	1	Economy	6700.00
0005432816939	1	Economy	6700.00
0005432261121	1	Economy	6700.00
0005432261126	1	Economy	6700.00
0005432816940	1	Economy	6700.00
0005432261120	1	Economy	6700.00
0005432261087	1	Economy	6700.00
0005432816965	1	Economy	6700.00
0005432288927	1	Economy	6700.00
0005432261112	1	Economy	6700.00
0005432261127	1	Economy	6700.00
0005432816958	1	Economy	6700.00
0005432261114	1	Economy	6700.00
0005432816946	1	Economy	6700.00
0005432816964	1	Economy	6700.00
0005432261132	1	Economy	6700.00
0005432816952	1	Economy	6700.00
0005432261113	1	Economy	6700.00
0005432261125	1	Economy	6700.00
0005432261118	1	Economy	6700.00
0005432261102	1	Economy	6700.00
0005432816966	1	Economy	7300.00
0005432288929	1	Economy	7300.00
0005432261128	1	Economy	7300.00
0005432261091	1	Economy	6700.00
0005432261123	1	Economy	6700.00
0005432261107	1	Economy	7300.00
0005432261094	1	Economy	6700.00
0005432816957	1	Economy	6700.00
0005432261111	1	Economy	6700.00
0005432261124	1	Economy	6700.00
0005432261108	1	Economy	6700.00
0005432816948	1	Economy	6700.00
0005432261093	1	Economy	6700.00
0005432816953	1	Economy	6700.00
0005432816949	1	Economy	6700.00
0005432816950	1	Economy	6700.00
0005432261130	1	Economy	6700.00
0005432261095	1	Economy	6700.00
0005432261089	1	Economy	6700.00
0005432816942	1	Economy	6700.00
0005432261117	1	Economy	6700.00
0005432816956	1	Economy	6700.00
0005432261131	1	Economy	6700.00
0005432261105	1	Economy	6700.00
0005432261106	1	Economy	6700.00
0005432288928	1	Economy	6700.00
0005432261104	1	Economy	6700.00
0005432816944	1	Economy	6700.00
0005432261088	1	Economy	6700.00
0005432816941	1	Economy	6700.00
0005433101217	8078	Business	20000.00
0005432391945	8078	Business	20000.00
0005433101189	8078	Business	20000.00
0005433101183	8078	Business	20000.00
0005433101197	8078	Business	20000.00
0005432019787	8078	Business	20000.00
0005432019786	8078	Business	20000.00
0005433101173	8078	Business	20000.00
0005433101216	8078	Business	20000.00
0005433101157	8078	Business	20000.00
0005433101155	8078	Business	20000.00
0005432391946	8078	Business	20000.00
0005433101200	8078	Business	20000.00
0005433101194	8078	Business	20000.00
0005433101161	8078	Business	20000.00
0005433101168	8078	Business	20000.00
0005433101148	8078	Business	20000.00
0005433101176	8078	Business	20000.00
0005432753243	8078	Business	20000.00
0005433101172	8078	Economy	7300.00
0005433101196	8078	Economy	7300.00
0005432751469	8078	Economy	6700.00
0005433101160	8078	Economy	6700.00
0005433101150	8078	Economy	6700.00
0005432019796	8078	Economy	6700.00
0005433101190	8078	Economy	6700.00
0005432045579	8078	Economy	6700.00
0005433101171	8078	Economy	6700.00
0005433101210	8078	Economy	6700.00
0005432019794	8078	Economy	6700.00
0005432019779	8078	Economy	6700.00
0005433101204	8078	Economy	6700.00
0005433101154	8078	Economy	6700.00
0005433101184	8078	Economy	6700.00
0005432753242	8078	Economy	6700.00
0005433101220	8078	Economy	6700.00
0005433101162	8078	Economy	6700.00
0005432019780	8078	Economy	6700.00
0005433101178	8078	Economy	6700.00
0005433101170	8078	Economy	6700.00
0005432019797	8078	Economy	6700.00
0005433101207	8078	Economy	6700.00
0005433101212	8078	Economy	6700.00
0005432019784	8078	Economy	6700.00
0005433101202	8078	Economy	6700.00
0005433101164	8078	Economy	6700.00
0005432019793	8078	Economy	6700.00
0005432677503	8078	Economy	6700.00
0005433101169	8078	Economy	6700.00
0005433101187	8078	Economy	6700.00
0005433101182	8078	Economy	6700.00
0005432044477	8078	Economy	6700.00
0005432019792	8078	Economy	6700.00
0005432044475	8078	Economy	6700.00
0005432019801	8078	Economy	6700.00
0005433101219	8078	Economy	6700.00
0005433101209	8078	Economy	6700.00
0005432045580	8078	Economy	6700.00
0005433101213	8078	Economy	6700.00
0005432019800	8078	Economy	6700.00
0005433101205	8078	Economy	6700.00
0005433101208	8078	Economy	6700.00
0005433101159	8078	Economy	6700.00
0005433101179	8078	Economy	6700.00
0005433101203	8078	Economy	6700.00
0005432019789	8078	Economy	6700.00
0005433101195	8078	Economy	7300.00
0005432019790	8078	Economy	7300.00
0005433101193	8078	Economy	7300.00
0005433101206	8078	Economy	6700.00
0005433101152	8078	Economy	6700.00
0005432019783	8078	Economy	6700.00
0005433101192	8078	Economy	7300.00
0005433101177	8078	Economy	6700.00
0005433101199	8078	Economy	6700.00
0005433101163	8078	Economy	6700.00
0005433101167	8078	Economy	6700.00
0005433101211	8078	Economy	6700.00
0005432019804	8078	Economy	6700.00
0005432019781	8078	Economy	6700.00
0005433101201	8078	Economy	6700.00
0005432751468	8078	Economy	6700.00
0005433101165	8078	Economy	6700.00
0005432045581	8078	Economy	6700.00
0005433101149	8078	Economy	6700.00
0005433101214	8078	Economy	6700.00
0005433101185	8078	Economy	6700.00
0005433101198	8078	Economy	6700.00
0005432019799	8078	Economy	6700.00
0005433101175	8078	Economy	6700.00
0005433101151	8078	Economy	6700.00
0005433101188	8078	Economy	6700.00
0005432019802	8078	Economy	6700.00
0005432019785	8078	Economy	6700.00
0005433101166	8078	Economy	6700.00
0005432677506	8078	Economy	6700.00
0005432391947	8078	Economy	6700.00
0005432019795	8078	Economy	6700.00
0005432019803	8078	Economy	6700.00
0005433101186	8078	Economy	6700.00
0005432677504	8078	Economy	6700.00
0005433101218	8078	Economy	6700.00
0005432019782	8078	Economy	6700.00
0005433101180	8078	Economy	6700.00
0005432019788	8078	Economy	6700.00
0005433101158	8078	Economy	6700.00
0005432019791	8078	Economy	6700.00
0005432677505	8078	Economy	6700.00
0005432044476	8078	Economy	6700.00
0005432753244	8078	Economy	6700.00
0005433101156	8078	Economy	6700.00
0005433101181	8078	Economy	6700.00
0005433101153	8078	Economy	6700.00
0005432019798	8078	Economy	6700.00
0005433101215	8078	Economy	6700.00
0005433101174	8078	Economy	6700.00
0005433101191	8078	Economy	6700.00
0005432901293	8076	Business	20000.00
0005432901302	8076	Business	20000.00
0005432901304	8076	Business	20000.00
0005432901295	8076	Business	20000.00
0005432901298	8076	Economy	7300.00
0005432901310	8076	Economy	7300.00
0005432901307	8076	Economy	7300.00
0005432901309	8076	Economy	6700.00
0005432901308	8076	Economy	6700.00
0005432901297	8076	Economy	6700.00
0005432901300	8076	Economy	6700.00
0005432002040	8076	Economy	6700.00
0005432002041	8076	Economy	6700.00
0005432901299	8076	Economy	6700.00
0005432901303	8076	Economy	7300.00
0005432901296	8076	Economy	6700.00
0005432901306	8076	Economy	6700.00
0005432901294	8076	Economy	6700.00
0005432901311	8076	Economy	6700.00
0005432901301	8076	Economy	6700.00
0005432901305	8076	Economy	6700.00
0005433870692	9671	Economy	6900.00
0005433870691	9671	Economy	6900.00
0005434175681	32374	Economy	6900.00
0005434175678	32374	Economy	6900.00
0005434175680	32374	Economy	6900.00
0005434175679	32374	Economy	6900.00
0005434175682	32374	Economy	6900.00
0005434876559	3490	Business	35000.00
0005435625879	3490	Business	35000.00
0005432798964	3490	Business	35000.00
0005435625862	3490	Business	35000.00
0005435125675	3490	Business	35000.00
0005434876557	3490	Business	35000.00
0005434876620	3490	Business	35000.00
0005434876564	3490	Business	35000.00
0005432798955	3490	Business	35000.00
0005434876651	3490	Business	35000.00
0005432613790	3490	Business	35000.00
0005435125656	3490	Business	35000.00
0005434876581	3490	Business	35000.00
0005435125669	3490	Business	35000.00
0005434876585	3490	Business	35000.00
0005432798962	3490	Business	35000.00
0005435625868	3490	Business	35000.00
0005432798966	3490	Business	35000.00
0005434426109	3490	Business	35000.00
0005435625876	3490	Business	35000.00
0005434426101	3490	Business	35000.00
0005434876593	3490	Business	35000.00
0005434876614	3490	Comfort	19900.00
0005434876575	3490	Business	35000.00
0005435625858	3490	Comfort	19900.00
0005434876565	3490	Comfort	19900.00
0005435125677	3490	Comfort	19900.00
0005434876617	3490	Comfort	19900.00
0005432798969	3490	Comfort	19900.00
0005434876583	3490	Comfort	19900.00
0005435125661	3490	Comfort	19900.00
0005432798961	3490	Comfort	19900.00
0005435625877	3490	Comfort	19900.00
0005434876621	3490	Comfort	19900.00
0005434876636	3490	Comfort	19900.00
0005434937796	3490	Comfort	19900.00
0005435625873	3490	Comfort	19900.00
0005434876558	3490	Comfort	19900.00
0005435125665	3490	Comfort	19900.00
0005435125651	3490	Comfort	19900.00
0005434876650	3490	Comfort	19900.00
0005434876580	3490	Comfort	19900.00
0005434876578	3490	Comfort	19900.00
0005435125663	3490	Comfort	19900.00
0005434426085	3490	Comfort	19900.00
0005432613789	3490	Comfort	19900.00
0005434876633	3490	Comfort	19900.00
0005434426092	3490	Comfort	19900.00
0005435125688	3490	Comfort	19900.00
0005434937810	3490	Comfort	19900.00
0005434426091	3490	Comfort	19900.00
0005434876569	3490	Economy	11700.00
0005435125678	3490	Economy	11700.00
0005434876600	3490	Economy	11700.00
0005432798977	3490	Economy	11700.00
0005434876582	3490	Economy	11700.00
0005434876608	3490	Economy	11700.00
0005434876609	3490	Economy	11700.00
0005432798956	3490	Economy	11700.00
0005434876574	3490	Economy	11700.00
0005434426093	3490	Economy	11700.00
0005434937805	3490	Economy	11700.00
0005435625867	3490	Economy	11700.00
0005434876591	3490	Economy	11700.00
0005435125682	3490	Economy	11700.00
0005435625857	3490	Economy	11700.00
0005434876640	3490	Economy	11700.00
0005435125687	3490	Economy	11700.00
0005435625869	3490	Economy	11700.00
0005434937808	3490	Economy	11700.00
0005435625863	3490	Economy	11700.00
0005434876584	3490	Economy	11700.00
0005435125652	3490	Economy	11700.00
0005435125666	3490	Economy	11700.00
0005434876599	3490	Economy	11700.00
0005435125653	3490	Economy	11700.00
0005434937802	3490	Economy	11700.00
0005435125655	3490	Economy	11700.00
0005435125657	3490	Economy	11700.00
0005435125674	3490	Economy	11700.00
0005432798972	3490	Economy	11700.00
0005434876598	3490	Economy	11700.00
0005434426096	3490	Economy	11700.00
0005434876646	3490	Economy	11700.00
0005434426102	3490	Economy	11700.00
0005435625875	3490	Economy	11700.00
0005434426099	3490	Economy	11700.00
0005435625861	3490	Economy	11700.00
0005434426098	3490	Economy	11700.00
0005434937792	3490	Economy	11700.00
0005434876639	3490	Economy	11700.00
0005434426088	3490	Economy	11700.00
0005434426105	3490	Economy	11700.00
0005434876619	3490	Economy	11700.00
0005434937809	3490	Economy	11700.00
0005434426089	3490	Economy	11700.00
0005434937797	3490	Economy	11700.00
0005434876642	3490	Economy	11700.00
0005435125671	3490	Economy	11700.00
0005432798968	3490	Economy	11700.00
0005432188550	3490	Economy	11700.00
0005434426104	3490	Economy	11700.00
0005434876615	3490	Economy	11700.00
0005434937793	3490	Economy	12800.00
0005432188551	3490	Economy	12800.00
0005434876616	3490	Economy	12800.00
0005434937806	3490	Economy	11700.00
0005434876618	3490	Economy	11700.00
0005434426095	3490	Economy	11700.00
0005435625865	3490	Economy	12800.00
0005432188553	3490	Economy	11700.00
0005434426113	3490	Economy	11700.00
0005434876610	3490	Economy	11700.00
0005434876597	3490	Economy	11700.00
0005432798979	3490	Economy	11700.00
0005434937804	3490	Economy	11700.00
0005434876606	3490	Economy	11700.00
0005434876626	3490	Economy	11700.00
0005432798976	3490	Economy	11700.00
0005434876622	3490	Economy	11700.00
0005434426110	3490	Economy	11700.00
0005435125659	3490	Economy	11700.00
0005434876568	3490	Economy	11700.00
0005434876647	3490	Economy	11700.00
0005435625874	3490	Economy	11700.00
0005434876560	3490	Economy	11700.00
0005432798954	3490	Economy	11700.00
0005432183428	3490	Economy	11700.00
0005435625878	3490	Economy	11700.00
0005432798965	3490	Economy	11700.00
0005434876624	3490	Economy	11700.00
0005434876571	3490	Economy	11700.00
0005432798975	3490	Economy	11700.00
0005434876627	3490	Economy	11700.00
0005435125660	3490	Economy	11700.00
0005432798971	3490	Economy	11700.00
0005435125672	3490	Economy	11700.00
0005434937799	3490	Economy	11700.00
0005434876570	3490	Economy	11700.00
0005434426112	3490	Economy	11700.00
0005434937800	3490	Economy	11700.00
0005434876630	3490	Economy	11700.00
0005434876629	3490	Economy	11700.00
0005434426108	3490	Economy	11700.00
0005434876645	3490	Economy	11700.00
0005432798970	3490	Economy	11700.00
0005435125647	3490	Economy	11700.00
0005434426094	3490	Economy	11700.00
0005434876587	3490	Economy	11700.00
0005434937795	3490	Economy	11700.00
0005432613792	3490	Economy	11700.00
0005435625871	3490	Economy	11700.00
0005435125686	3490	Economy	11700.00
0005432188552	3490	Economy	11700.00
0005434876590	3490	Economy	11700.00
0005434426107	3490	Economy	11700.00
0005434426097	3490	Economy	11700.00
0005432613791	3490	Economy	11700.00
0005435125670	3490	Economy	11700.00
0005434876572	3490	Economy	11700.00
0005434876556	3490	Economy	11700.00
0005435125676	3490	Economy	11700.00
0005434876635	3490	Economy	11700.00
0005434876576	3490	Economy	11700.00
0005434876623	3490	Economy	11700.00
0005435125667	3490	Economy	11700.00
0005434937807	3490	Economy	11700.00
0005434876612	3490	Economy	11700.00
0005434876596	3490	Economy	11700.00
0005434876605	3490	Economy	11700.00
0005432798981	3490	Economy	11700.00
0005434876631	3490	Economy	11700.00
0005434876603	3490	Economy	11700.00
0005434876602	3490	Economy	11700.00
0005435625864	3490	Economy	11700.00
0005434426100	3490	Economy	11700.00
0005434876563	3490	Economy	11700.00
0005434876632	3490	Economy	11700.00
0005434937798	3490	Economy	11700.00
0005434876634	3490	Economy	11700.00
0005434876577	3490	Economy	11700.00
0005435125685	3490	Economy	11700.00
0005435125648	3490	Economy	11700.00
0005434876604	3490	Economy	11700.00
0005434876628	3490	Economy	11700.00
0005435625872	3490	Economy	11700.00
0005432798960	3490	Economy	11700.00
0005434426090	3490	Economy	11700.00
0005434876566	3490	Economy	11700.00
0005434876637	3490	Economy	12800.00
0005434876595	3490	Economy	11700.00
0005435625860	3490	Economy	11700.00
0005434937803	3490	Economy	11700.00
0005435125650	3490	Economy	11700.00
0005434876625	3490	Economy	11700.00
0005432798980	3490	Economy	11700.00
0005434937794	3490	Economy	11700.00
0005434426084	3490	Economy	11700.00
0005432798958	3490	Economy	11700.00
0005432183429	3490	Economy	11700.00
0005435625859	3490	Economy	11700.00
0005434876638	3490	Economy	11700.00
0005435125668	3490	Economy	11700.00
0005435125683	3490	Economy	11700.00
0005434876588	3490	Economy	11700.00
0005434426086	3490	Economy	11700.00
0005434426106	3490	Economy	11700.00
0005432188549	3490	Economy	11700.00
0005434426087	3490	Economy	11700.00
0005435125658	3490	Economy	11700.00
0005435125664	3490	Economy	11700.00
0005434426111	3490	Economy	11700.00
0005432798974	3490	Economy	11700.00
0005434876567	3490	Economy	11700.00
0005434876648	3490	Economy	11700.00
0005434876644	3490	Economy	11700.00
0005434876611	3490	Economy	11700.00
0005434426103	3490	Economy	11700.00
0005432798957	3490	Economy	11700.00
0005435625870	3490	Economy	11700.00
0005434876613	3490	Economy	11700.00
0005432798978	3490	Economy	11700.00
0005435125681	3490	Economy	11700.00
0005434937801	3490	Economy	11700.00
0005434876594	3490	Economy	11700.00
0005432798967	3490	Economy	11700.00
0005435125673	3490	Economy	11700.00
0005432798963	3490	Economy	11700.00
0005434876561	3490	Economy	11700.00
0005432798953	3490	Economy	11700.00
0005434876562	3490	Economy	11700.00
0005434876641	3490	Economy	11700.00
0005432798982	3490	Economy	11700.00
0005432798973	3490	Economy	11700.00
0005434876643	3490	Economy	11700.00
0005434876592	3490	Economy	11700.00
0005434876601	3490	Economy	11700.00
0005434876586	3490	Economy	11700.00
0005434876589	3490	Economy	11700.00
0005435125684	3490	Economy	11700.00
0005435125649	3490	Economy	11700.00
0005434876573	3490	Economy	11700.00
0005435125654	3490	Economy	11700.00
0005435125680	3490	Economy	11700.00
0005434876555	3490	Economy	11700.00
0005435625866	3490	Economy	11700.00
0005434876579	3490	Economy	11700.00
0005435125679	3490	Economy	11700.00
0005434937811	3490	Economy	11700.00
0005432798959	3490	Economy	11700.00
0005435125662	3490	Economy	11700.00
0005434876607	3490	Economy	11700.00
0005434876649	3490	Economy	11700.00
0005435902395	14551	Business	35000.00
0005435902390	14551	Business	35000.00
0005435902388	14551	Business	35000.00
0005432059471	14551	Business	35000.00
0005435902400	14551	Business	35000.00
0005435913849	14551	Comfort	19900.00
0005432059469	14551	Comfort	19900.00
0005435902384	14551	Comfort	19900.00
0005435902389	14551	Economy	12800.00
0005435902386	14551	Economy	11700.00
0005435902385	14551	Economy	11700.00
0005435902401	14551	Economy	11700.00
0005435902398	14551	Economy	11700.00
0005435902396	14551	Economy	11700.00
0005435902387	14551	Economy	11700.00
0005435902397	14551	Economy	11700.00
0005432059470	14551	Economy	11700.00
0005435902399	14551	Economy	11700.00
0005435902394	14551	Economy	11700.00
0005435902393	14551	Economy	11700.00
0005435902391	14551	Economy	11700.00
0005435902392	14551	Economy	11700.00
0005435913850	14551	Economy	11700.00
0005434325452	3625	Economy	16300.00
0005434325451	3625	Economy	16300.00
0005434325445	3625	Economy	16300.00
0005434325450	3625	Economy	14800.00
0005434325446	3625	Economy	14800.00
0005434325453	3625	Economy	14800.00
0005434325448	3625	Economy	14800.00
0005434325447	3625	Economy	14800.00
0005434325444	3625	Economy	14800.00
0005434325443	3625	Economy	14800.00
0005434325449	3625	Economy	14800.00
0005434325454	3625	Economy	14800.00
0005434325455	3625	Economy	14800.00
0005435889790	15639	Economy	14800.00
0005435889793	15639	Economy	14800.00
0005435889791	15639	Economy	14800.00
0005435889789	15639	Economy	14800.00
0005435889788	15639	Economy	14800.00
0005435889792	15639	Economy	14800.00
0005435957441	669	Economy	4500.00
0005435957438	669	Economy	4100.00
0005435957450	669	Economy	4100.00
0005435957447	669	Economy	4100.00
0005435957453	669	Economy	4100.00
0005435957445	669	Economy	4100.00
0005435957449	669	Economy	4100.00
0005435957448	669	Economy	4100.00
0005435957440	669	Economy	4100.00
0005435957439	669	Economy	4100.00
0005435957444	669	Economy	4100.00
0005435957451	669	Economy	4100.00
0005435957443	669	Economy	4100.00
0005435957452	669	Economy	4100.00
0005435957442	669	Economy	4100.00
0005435957446	669	Economy	4100.00
0005433420253	15177	Economy	4500.00
0005433420249	15177	Economy	4100.00
0005433420252	15177	Economy	4100.00
0005433420256	15177	Economy	4100.00
0005433420251	15177	Economy	4100.00
0005433420254	15177	Economy	4100.00
0005433420255	15177	Economy	4100.00
0005433420257	15177	Economy	4100.00
0005433420250	15177	Economy	4100.00
0005435217676	31773	Economy	28100.00
0005435218099	31773	Economy	25500.00
0005435216554	31773	Economy	25500.00
0005435217677	31773	Economy	25500.00
0005435217678	31773	Economy	25500.00
0005435216553	31773	Economy	25500.00
0005435629383	8849	Economy	10400.00
0005434247102	16118	Economy	10400.00
0005434247100	16118	Economy	10400.00
0005434247101	16118	Economy	10400.00
0005434467723	4016	Economy	21200.00
0005434467724	4016	Economy	21200.00
0005435163143	4432	Economy	12200.00
0005435163141	4432	Economy	12200.00
0005435163142	4432	Economy	12200.00
0005435163144	4432	Economy	12200.00
0005435163140	4432	Economy	12200.00
0005435163139	4432	Economy	12200.00
0005435933395	29506	Economy	13400.00
0005435933394	29506	Economy	12200.00
0005432645761	6840	Business	87700.00
0005432645768	6840	Business	87700.00
0005432645773	6840	Business	87700.00
0005432645767	6840	Economy	29200.00
0005432645764	6840	Economy	29200.00
0005432645765	6840	Economy	29200.00
0005432645763	6840	Economy	29200.00
0005432645766	6840	Economy	29200.00
0005432645762	6840	Economy	29200.00
0005432645772	6840	Economy	29200.00
0005432645769	6840	Economy	29200.00
0005432645771	6840	Economy	29200.00
0005432645770	6840	Economy	29200.00
0005435797234	2837	Business	12600.00
0005435797224	2837	Economy	4200.00
0005435797223	2837	Economy	4200.00
0005435797226	2837	Economy	4600.00
0005435797227	2837	Economy	4200.00
0005435797222	2837	Economy	4200.00
0005435797230	2837	Economy	4200.00
0005435797233	2837	Economy	4200.00
0005435797225	2837	Economy	4200.00
0005435797231	2837	Economy	4200.00
0005435797236	2837	Economy	4200.00
0005435797232	2837	Economy	4200.00
0005435797235	2837	Economy	4200.00
0005435797229	2837	Economy	4200.00
0005435797228	2837	Economy	4200.00
0005433404679	29309	Business	12600.00
0005433404677	29309	Business	12600.00
0005433404683	29309	Economy	4200.00
0005433404681	29309	Economy	4200.00
0005433404678	29309	Economy	4200.00
0005433404680	29309	Economy	4200.00
0005433404682	29309	Economy	4200.00
0005434947871	5814	Economy	6800.00
0005434947870	5814	Economy	6800.00
0005434947868	5814	Economy	6800.00
0005434947869	5814	Economy	6800.00
0005434947874	5814	Economy	6800.00
0005434947872	5814	Economy	6800.00
0005434947873	5814	Economy	6800.00
0005435376312	16432	Economy	6800.00
0005435376313	16432	Economy	6800.00
0005435376314	16432	Economy	6800.00
0005433959869	6863	Business	21400.00
0005433959896	6863	Business	21400.00
0005433959866	6863	Business	21400.00
0005433959860	6863	Business	21400.00
0005433959895	6863	Business	21400.00
0005433959903	6863	Business	21400.00
0005433959865	6863	Business	21400.00
0005433959883	6863	Economy	7100.00
0005433959864	6863	Economy	7100.00
0005433959879	6863	Economy	7100.00
0005433959891	6863	Economy	7100.00
0005433959882	6863	Economy	7100.00
0005433959871	6863	Economy	7100.00
0005433959872	6863	Economy	7800.00
0005433959888	6863	Economy	7100.00
0005433959889	6863	Economy	7100.00
0005433959900	6863	Economy	7100.00
0005433959857	6863	Economy	7100.00
0005433959881	6863	Economy	7100.00
0005433959893	6863	Economy	7100.00
0005433959867	6863	Economy	7100.00
0005433959898	6863	Economy	7100.00
0005433959870	6863	Economy	7100.00
0005433959885	6863	Economy	7100.00
0005433959863	6863	Economy	7100.00
0005433959887	6863	Economy	7100.00
0005433959858	6863	Economy	7100.00
0005433959902	6863	Economy	7100.00
0005433959877	6863	Economy	7100.00
0005433959894	6863	Economy	7100.00
0005433959897	6863	Economy	7100.00
0005433959876	6863	Economy	7100.00
0005433959874	6863	Economy	7100.00
0005433959892	6863	Economy	7100.00
0005433959862	6863	Economy	7100.00
0005433959899	6863	Economy	7100.00
0005433959868	6863	Economy	7100.00
0005433959859	6863	Economy	7100.00
0005433959873	6863	Economy	7100.00
0005433959861	6863	Economy	7100.00
0005433959875	6863	Economy	7100.00
0005433959856	6863	Economy	7100.00
0005433959878	6863	Economy	7100.00
0005433959901	6863	Economy	7100.00
0005433959884	6863	Economy	7100.00
0005433959880	6863	Economy	7100.00
0005433959886	6863	Economy	7100.00
0005433959890	6863	Economy	7100.00
0005434244467	5200	Business	18000.00
0005434244459	5200	Business	18000.00
0005434244473	5200	Business	18000.00
0005434244463	5200	Business	18000.00
0005434244453	5200	Economy	6600.00
0005434244466	5200	Economy	6000.00
0005434244470	5200	Economy	6000.00
0005434244469	5200	Economy	6000.00
0005434244479	5200	Economy	6000.00
0005434244457	5200	Economy	6000.00
0005434244462	5200	Economy	6000.00
0005434244456	5200	Economy	6000.00
0005434244480	5200	Economy	6000.00
0005434244477	5200	Economy	6000.00
0005434244458	5200	Economy	6000.00
0005434244455	5200	Economy	6600.00
0005434244478	5200	Economy	6000.00
0005434244481	5200	Economy	6600.00
0005434244476	5200	Economy	6000.00
0005432166843	5200	Economy	6000.00
0005432166845	5200	Economy	6000.00
0005434244468	5200	Economy	6000.00
0005434244464	5200	Economy	6000.00
0005434244474	5200	Economy	6000.00
0005434244471	5200	Economy	6000.00
0005434244475	5200	Economy	6000.00
0005434244461	5200	Economy	6000.00
0005434244454	5200	Economy	6000.00
0005434244482	5200	Economy	6000.00
0005434244483	5200	Economy	6000.00
0005434244472	5200	Economy	6000.00
0005432166844	5200	Economy	6000.00
0005434244465	5200	Economy	6000.00
0005434244460	5200	Economy	6000.00
0005432104729	5204	Business	18000.00
0005433784315	5204	Business	18000.00
0005433613444	5204	Business	18000.00
0005432104738	5204	Business	18000.00
0005433784293	5204	Business	18000.00
0005433784299	5204	Business	18000.00
0005433613453	5204	Business	18000.00
0005432104714	5204	Business	18000.00
0005432104734	5204	Business	18000.00
0005433784312	5204	Business	18000.00
0005432104711	5204	Business	18000.00
0005432104749	5204	Business	18000.00
0005433613386	5204	Business	18000.00
0005433784324	5204	Business	18000.00
0005433613433	5204	Business	18000.00
0005432104740	5204	Business	18000.00
0005433784313	5204	Business	18000.00
0005433613452	5204	Business	18000.00
0005433613388	5204	Business	18000.00
0005433784304	5204	Business	18000.00
0005433613418	5204	Business	18000.00
0005432104735	5204	Business	18000.00
0005432104736	5204	Business	18000.00
0005433613429	5204	Business	18000.00
0005432104742	5204	Business	18000.00
0005432666351	5204	Business	18000.00
0005433784308	5204	Business	18000.00
0005433613421	5204	Business	18000.00
0005432104728	5204	Economy	6600.00
0005433784309	5204	Economy	6600.00
0005432104755	5204	Economy	6600.00
0005432104759	5204	Economy	6600.00
0005432104732	5204	Economy	6600.00
0005433784311	5204	Economy	6600.00
0005433613460	5204	Economy	6000.00
0005433784328	5204	Economy	6000.00
0005433784301	5204	Economy	6000.00
0005433613407	5204	Economy	6000.00
0005432104751	5204	Economy	6000.00
0005433784292	5204	Economy	6000.00
0005432145075	5204	Economy	6000.00
0005433784317	5204	Economy	6000.00
0005432104747	5204	Economy	6000.00
0005433613393	5204	Economy	6000.00
0005433784297	5204	Economy	6000.00
0005433613435	5204	Economy	6000.00
0005433613409	5204	Economy	6000.00
0005432104725	5204	Economy	6000.00
0005433613455	5204	Economy	6000.00
0005432104723	5204	Economy	6000.00
0005432104717	5204	Economy	6000.00
0005433613431	5204	Economy	6000.00
0005432104744	5204	Economy	6000.00
0005433613408	5204	Economy	6000.00
0005433784314	5204	Economy	6000.00
0005433613395	5204	Economy	6000.00
0005433613448	5204	Economy	6000.00
0005432665237	5204	Economy	6000.00
0005432104758	5204	Economy	6000.00
0005433784305	5204	Economy	6000.00
0005432104713	5204	Economy	6000.00
0005433613419	5204	Economy	6000.00
0005433613458	5204	Economy	6000.00
0005432104712	5204	Economy	6000.00
0005433613441	5204	Economy	6000.00
0005433613423	5204	Economy	6000.00
0005433613415	5204	Economy	6000.00
0005433784295	5204	Economy	6000.00
0005433613437	5204	Economy	6000.00
0005432104752	5204	Economy	6000.00
0005432666352	5204	Economy	6000.00
0005433613445	5204	Economy	6000.00
0005433613414	5204	Economy	6000.00
0005433613397	5204	Economy	6000.00
0005433784323	5204	Economy	6000.00
0005432104715	5204	Economy	6000.00
0005433613424	5204	Economy	6000.00
0005432104731	5204	Economy	6000.00
0005433613404	5204	Economy	6000.00
0005433784316	5204	Economy	6000.00
0005432104718	5204	Economy	6000.00
0005433613411	5204	Economy	6000.00
0005433613401	5204	Economy	6000.00
0005433613412	5204	Economy	6000.00
0005433784296	5204	Economy	6000.00
0005433613420	5204	Economy	6000.00
0005432104748	5204	Economy	6000.00
0005433613425	5204	Economy	6000.00
0005433613400	5204	Economy	6000.00
0005433613457	5204	Economy	6000.00
0005432666353	5204	Economy	6000.00
0005433784318	5204	Economy	6000.00
0005433784300	5204	Economy	6000.00
0005432104753	5204	Economy	6600.00
0005433613396	5204	Economy	6600.00
0005432104757	5204	Economy	6600.00
0005433613416	5204	Economy	6600.00
0005433613440	5204	Economy	6600.00
0005433613417	5204	Economy	6000.00
0005433613426	5204	Economy	6000.00
0005433784322	5204	Economy	6000.00
0005432104727	5204	Economy	6000.00
0005433613443	5204	Economy	6600.00
0005433613459	5204	Economy	6000.00
0005432104722	5204	Economy	6000.00
0005433613394	5204	Economy	6000.00
0005433613451	5204	Economy	6000.00
0005433613405	5204	Economy	6000.00
0005432104741	5204	Economy	6000.00
0005432145077	5204	Economy	6000.00
0005433613392	5204	Economy	6000.00
0005433613427	5204	Economy	6000.00
0005433613454	5204	Economy	6000.00
0005432104750	5204	Economy	6000.00
0005432104726	5204	Economy	6000.00
0005432665238	5204	Economy	6000.00
0005433613436	5204	Economy	6000.00
0005433613430	5204	Economy	6000.00
0005433784325	5204	Economy	6000.00
0005433613446	5204	Economy	6000.00
0005432104733	5204	Economy	6000.00
0005433613391	5204	Economy	6000.00
0005433784321	5204	Economy	6000.00
0005433613410	5204	Economy	6000.00
0005433784326	5204	Economy	6000.00
0005433784294	5204	Economy	6000.00
0005433613442	5204	Economy	6000.00
0005433784298	5204	Economy	6000.00
0005433613439	5204	Economy	6000.00
0005433613406	5204	Economy	6000.00
0005433784320	5204	Economy	6000.00
0005432104737	5204	Economy	6000.00
0005433613450	5204	Economy	6000.00
0005433613390	5204	Economy	6000.00
0005433784302	5204	Economy	6000.00
0005433613434	5204	Economy	6000.00
0005433613413	5204	Economy	6000.00
0005433784319	5204	Economy	6000.00
0005432145076	5204	Economy	6000.00
0005432104716	5204	Economy	6000.00
0005432104720	5204	Economy	6000.00
0005433784306	5204	Economy	6000.00
0005433613389	5204	Economy	6000.00
0005432104719	5204	Economy	6000.00
0005432104745	5204	Economy	6000.00
0005433613456	5204	Economy	6000.00
0005433784307	5204	Economy	6000.00
0005432104743	5204	Economy	6000.00
0005433613438	5204	Economy	6000.00
0005433613402	5204	Economy	6000.00
0005432104724	5204	Economy	6000.00
0005432104739	5204	Economy	6000.00
0005433613403	5204	Economy	6000.00
0005433613447	5204	Economy	6000.00
0005433784303	5204	Economy	6000.00
0005433613422	5204	Economy	6000.00
0005432104746	5204	Economy	6000.00
0005433784310	5204	Economy	6000.00
0005433613387	5204	Economy	6000.00
0005432104754	5204	Economy	6000.00
0005433784327	5204	Economy	6000.00
0005433613432	5204	Economy	6000.00
0005432104756	5204	Economy	6000.00
0005433613449	5204	Economy	6000.00
0005432104730	5204	Economy	6000.00
0005433613399	5204	Economy	6000.00
0005433613428	5204	Economy	6000.00
0005433613398	5204	Economy	6000.00
0005432104721	5204	Economy	6000.00
0005434228981	5220	Business	18000.00
0005434149531	5220	Business	18000.00
0005434228967	5220	Business	18000.00
0005434264695	5220	Business	18000.00
0005434149528	5220	Business	18000.00
0005434264681	5220	Business	18000.00
0005434149523	5220	Business	18000.00
0005434149527	5220	Business	18000.00
0005434264679	5220	Business	18000.00
0005434228969	5220	Business	18000.00
0005434264685	5220	Business	18000.00
0005434264686	5220	Business	18000.00
0005434264683	5220	Business	18000.00
0005434228979	5220	Business	18000.00
0005434228977	5220	Business	18000.00
0005434228975	5220	Business	18000.00
0005434149522	5220	Economy	6600.00
0005434264693	5220	Economy	6600.00
0005434264688	5220	Economy	6000.00
0005434264680	5220	Economy	6000.00
0005434264682	5220	Economy	6000.00
0005434228984	5220	Economy	6000.00
0005434264696	5220	Economy	6000.00
0005434264694	5220	Economy	6000.00
0005434228966	5220	Economy	6000.00
0005434149526	5220	Economy	6000.00
0005434149525	5220	Economy	6000.00
0005434228973	5220	Economy	6000.00
0005434264676	5220	Economy	6000.00
0005434149524	5220	Economy	6000.00
0005434264691	5220	Economy	6000.00
0005434264690	5220	Economy	6000.00
0005434228983	5220	Economy	6000.00
0005434228987	5220	Economy	6000.00
0005434228970	5220	Economy	6000.00
0005434149530	5220	Economy	6600.00
0005434264687	5220	Economy	6600.00
0005434149521	5220	Economy	6600.00
0005434264689	5220	Economy	6600.00
0005434228985	5220	Economy	6000.00
0005434149529	5220	Economy	6000.00
0005434264692	5220	Economy	6000.00
0005434228982	5220	Economy	6000.00
0005434264678	5220	Economy	6000.00
0005434264697	5220	Economy	6000.00
0005434228976	5220	Economy	6000.00
0005434264701	5220	Economy	6000.00
0005434228974	5220	Economy	6000.00
0005434173450	5220	Economy	6000.00
0005434228986	5220	Economy	6000.00
0005434173451	5220	Economy	6000.00
0005434149520	5220	Economy	6000.00
0005434264684	5220	Economy	6000.00
0005434228968	5220	Economy	6000.00
0005434228988	5220	Economy	6000.00
0005434228980	5220	Economy	6000.00
0005434264699	5220	Economy	6000.00
0005434264700	5220	Economy	6000.00
0005434264677	5220	Economy	6000.00
0005434228978	5220	Economy	6000.00
0005434228971	5220	Economy	6000.00
0005434228972	5220	Economy	6000.00
0005434264698	5220	Economy	6000.00
0005434264675	5220	Economy	6000.00
0005435269621	8632	Business	18000.00
0005435269636	8632	Business	18000.00
0005435269642	8632	Economy	6600.00
0005435269637	8632	Economy	6000.00
0005435269628	8632	Economy	6000.00
0005435269629	8632	Economy	6000.00
0005435269625	8632	Economy	6000.00
0005435269624	8632	Economy	6000.00
0005435269634	8632	Economy	6000.00
0005435269622	8632	Economy	6000.00
0005435269631	8632	Economy	6000.00
0005435269639	8632	Economy	6000.00
0005435269633	8632	Economy	6000.00
0005435269627	8632	Economy	6000.00
0005435269638	8632	Economy	6000.00
0005435269626	8632	Economy	6000.00
0005435269623	8632	Economy	6000.00
0005435269632	8632	Economy	6000.00
0005435269630	8632	Economy	6000.00
0005435269635	8632	Economy	6000.00
0005435269641	8632	Economy	6000.00
0005435269640	8632	Economy	6000.00
0005435006615	8630	Business	18000.00
0005432034450	8630	Business	18000.00
0005432034469	8630	Business	18000.00
0005435006619	8630	Business	18000.00
0005435006608	8630	Business	18000.00
0005432047484	8630	Business	18000.00
0005432034463	8630	Business	18000.00
0005432335826	8630	Business	18000.00
0005435006610	8630	Business	18000.00
0005435006609	8630	Business	18000.00
0005432034456	8630	Business	18000.00
0005432034459	8630	Business	18000.00
0005433688773	8630	Business	18000.00
0005432335828	8630	Business	18000.00
0005432034468	8630	Business	18000.00
0005435006612	8630	Business	18000.00
0005435006602	8630	Economy	6600.00
0005435006607	8630	Economy	6600.00
0005432034451	8630	Economy	6600.00
0005435006601	8630	Economy	6000.00
0005435006618	8630	Economy	6000.00
0005432335827	8630	Economy	6000.00
0005433815302	8630	Economy	6000.00
0005433688774	8630	Economy	6000.00
0005433534460	8630	Economy	6000.00
0005432047486	8630	Economy	6000.00
0005432034460	8630	Economy	6000.00
0005433534462	8630	Economy	6000.00
0005433689875	8630	Economy	6000.00
0005432034452	8630	Economy	6000.00
0005433815300	8630	Economy	6000.00
0005435006616	8630	Economy	6000.00
0005432034471	8630	Economy	6000.00
0005432335821	8630	Economy	6000.00
0005432034462	8630	Economy	6000.00
0005435006620	8630	Economy	6000.00
0005434311182	8630	Economy	6000.00
0005432034473	8630	Economy	6000.00
0005432034466	8630	Economy	6000.00
0005435006617	8630	Economy	6000.00
0005432034467	8630	Economy	6000.00
0005435006611	8630	Economy	6000.00
0005435006605	8630	Economy	6000.00
0005433815303	8630	Economy	6600.00
0005435006613	8630	Economy	6600.00
0005432034470	8630	Economy	6600.00
0005432335831	8630	Economy	6000.00
0005432034465	8630	Economy	6000.00
0005433815305	8630	Economy	6000.00
0005435006614	8630	Economy	6000.00
0005432034477	8630	Economy	6000.00
0005432335830	8630	Economy	6000.00
0005432034464	8630	Economy	6000.00
0005432034461	8630	Economy	6000.00
0005432034449	8630	Economy	6000.00
0005432034453	8630	Economy	6000.00
0005432034457	8630	Economy	6000.00
0005432335829	8630	Economy	6000.00
0005432034474	8630	Economy	6000.00
0005435006606	8630	Economy	6000.00
0005432034476	8630	Economy	6000.00
0005433689874	8630	Economy	6000.00
0005432047485	8630	Economy	6000.00
0005433534461	8630	Economy	6000.00
0005433815301	8630	Economy	6000.00
0005432034458	8630	Economy	6000.00
0005433815304	8630	Economy	6000.00
0005432335822	8630	Economy	6000.00
0005433690890	8630	Economy	6000.00
0005432335820	8630	Economy	6000.00
0005433534463	8630	Economy	6000.00
0005433690891	8630	Economy	6000.00
0005432034475	8630	Economy	6000.00
0005432335823	8630	Economy	6000.00
0005432034455	8630	Economy	6000.00
0005435006603	8630	Economy	6000.00
0005433690892	8630	Economy	6000.00
0005434311181	8630	Economy	6000.00
0005432335825	8630	Economy	6000.00
0005433688775	8630	Economy	6000.00
0005432034472	8630	Economy	6000.00
0005435006604	8630	Economy	6000.00
0005432335824	8630	Economy	6000.00
0005432034454	8630	Economy	6000.00
0005433202114	12615	Economy	16200.00
0005433202104	12615	Economy	16200.00
0005433202103	12615	Economy	14800.00
0005433202110	12615	Economy	14800.00
0005433202106	12615	Economy	14800.00
0005433202113	12615	Economy	14800.00
0005433202109	12615	Economy	14800.00
0005433202111	12615	Economy	14800.00
0005433202115	12615	Economy	14800.00
0005433202105	12615	Economy	14800.00
0005433202102	12615	Economy	14800.00
0005433202107	12615	Economy	14800.00
0005433202108	12615	Economy	14800.00
0005433202116	12615	Economy	14800.00
0005433202112	12615	Economy	14800.00
0005432054252	21103	Economy	6300.00
0005432054253	21103	Economy	6300.00
0005432054254	21103	Economy	6300.00
0005433642080	2485	Business	89600.00
0005433642085	2485	Business	89600.00
0005433642073	2485	Economy	29900.00
0005433642078	2485	Economy	32800.00
0005433642075	2485	Economy	29900.00
0005433642086	2485	Economy	29900.00
0005433642087	2485	Economy	29900.00
0005433642081	2485	Economy	29900.00
0005433642082	2485	Economy	29900.00
0005433642084	2485	Economy	29900.00
0005433642079	2485	Economy	29900.00
0005433642083	2485	Economy	29900.00
0005433642077	2485	Economy	29900.00
0005433642074	2485	Economy	29900.00
0005433642076	2485	Economy	29900.00
0005432822072	9614	Business	32600.00
0005432816942	9614	Business	32600.00
0005432816945	9614	Business	32600.00
0005432288929	9614	Business	32600.00
0005432816966	9614	Economy	10900.00
0005432822064	9614	Economy	10900.00
0005432816950	9614	Economy	10900.00
0005432816965	9614	Economy	10900.00
0005432816956	9614	Economy	11900.00
0005434448256	9614	Economy	11900.00
0005432816954	9614	Economy	11900.00
0005432816953	9614	Economy	10900.00
0005432816960	9614	Economy	10900.00
0005432816949	9614	Economy	10900.00
0005434448253	9614	Economy	10900.00
0005432816952	9614	Economy	10900.00
0005432816957	9614	Economy	10900.00
0005432822068	9614	Economy	10900.00
0005432816943	9614	Economy	10900.00
0005432822070	9614	Economy	10900.00
0005432816938	9614	Economy	10900.00
0005432816961	9614	Economy	10900.00
0005432822067	9614	Economy	10900.00
0005432816964	9614	Economy	10900.00
0005432288927	9614	Economy	10900.00
0005432816939	9614	Economy	10900.00
0005434448255	9614	Economy	10900.00
0005432822071	9614	Economy	10900.00
0005432816948	9614	Economy	10900.00
0005434448254	9614	Economy	10900.00
0005432816962	9614	Economy	10900.00
0005432816951	9614	Economy	10900.00
0005432816963	9614	Economy	10900.00
0005432816946	9614	Economy	10900.00
0005432816947	9614	Economy	10900.00
0005432822069	9614	Economy	10900.00
0005432816958	9614	Economy	10900.00
0005432288928	9614	Economy	10900.00
0005432816944	9614	Economy	10900.00
0005432816941	9614	Economy	10900.00
0005432816959	9614	Economy	10900.00
0005432816955	9614	Economy	10900.00
0005432822066	9614	Economy	10900.00
0005432822065	9614	Economy	10900.00
0005432816940	9614	Economy	10900.00
0005434157344	29001	Business	32600.00
0005432901298	29001	Business	32600.00
0005432901294	29001	Business	32600.00
0005434157341	29001	Business	32600.00
0005432901306	29001	Business	32600.00
0005432901300	29001	Economy	10900.00
0005432901303	29001	Economy	10900.00
0005432901304	29001	Economy	10900.00
0005432002041	29001	Economy	10900.00
0005432901302	29001	Economy	10900.00
0005432901309	29001	Economy	10900.00
0005432901307	29001	Economy	10900.00
0005432901293	29001	Economy	10900.00
0005434157342	29001	Economy	10900.00
0005434157345	29001	Economy	10900.00
0005432901310	29001	Economy	10900.00
0005432901301	29001	Economy	10900.00
0005432901308	29001	Economy	10900.00
0005432901296	29001	Economy	10900.00
0005432901311	29001	Economy	10900.00
0005432002040	29001	Economy	10900.00
0005432901299	29001	Economy	10900.00
0005432901295	29001	Economy	10900.00
0005432901305	29001	Economy	10900.00
0005434157343	29001	Economy	10900.00
0005432901297	29001	Economy	10900.00
0005434157346	29001	Economy	10900.00
0005432613789	15145	Economy	11000.00
0005432613792	15145	Economy	11000.00
0005432613790	15145	Economy	11000.00
0005432613791	15145	Economy	11000.00
0005432947782	25270	Business	105900.00
0005432947780	25270	Business	105900.00
0005432947789	25270	Business	105900.00
0005432947768	25270	Business	105900.00
0005432947764	25270	Economy	35300.00
0005432947798	25270	Economy	35300.00
0005432947796	25270	Economy	35300.00
0005432947800	25270	Economy	35300.00
0005432947787	25270	Economy	38800.00
0005432947779	25270	Economy	35300.00
0005432947778	25270	Economy	35300.00
0005432947784	25270	Economy	35300.00
0005432947767	25270	Economy	35300.00
0005432947793	25270	Economy	35300.00
0005432947795	25270	Economy	35300.00
0005432947775	25270	Economy	35300.00
0005432947781	25270	Economy	35300.00
0005432947801	25270	Economy	35300.00
0005432947783	25270	Economy	35300.00
0005432947772	25270	Economy	35300.00
0005432947790	25270	Economy	35300.00
0005432947771	25270	Economy	35300.00
0005432947773	25270	Economy	35300.00
0005432947804	25270	Economy	35300.00
0005432947769	25270	Economy	35300.00
0005432947765	25270	Economy	35300.00
0005432947797	25270	Economy	35300.00
0005432947791	25270	Economy	35300.00
0005432947774	25270	Economy	35300.00
0005432947794	25270	Economy	35300.00
0005432947802	25270	Economy	35300.00
0005432947777	25270	Economy	35300.00
0005432947786	25270	Economy	35300.00
0005432947788	25270	Economy	35300.00
0005432947799	25270	Economy	35300.00
0005432947770	25270	Economy	35300.00
0005432947785	25270	Economy	35300.00
0005432947766	25270	Economy	35300.00
0005432947792	25270	Economy	35300.00
0005432947776	25270	Economy	35300.00
0005432947803	25270	Economy	35300.00
0005432430803	14467	Economy	39100.00
0005432430800	14467	Economy	39100.00
0005434026671	14467	Economy	39100.00
0005432430802	14467	Economy	39100.00
0005434026669	14467	Economy	39100.00
0005434026670	14467	Economy	39100.00
0005432430801	14467	Economy	39100.00
0005433808308	30832	Business	117400.00
0005433808307	30832	Economy	39100.00
0005433808309	30832	Economy	39100.00
0005433808304	30832	Economy	39100.00
0005433808305	30832	Economy	39100.00
0005433808306	30832	Economy	39100.00
0005434654168	5381	Business	67200.00
0005434654179	5381	Business	67200.00
0005434654182	5381	Business	67200.00
0005434654172	5381	Business	67200.00
0005434654178	5381	Business	67200.00
0005434654163	5381	Business	67200.00
0005434654170	5381	Economy	22400.00
0005434654166	5381	Economy	22400.00
0005434654167	5381	Economy	22400.00
0005434654174	5381	Economy	22400.00
0005434654186	5381	Economy	22400.00
0005434656521	5381	Economy	22400.00
0005434654187	5381	Economy	24600.00
0005434654162	5381	Economy	24600.00
0005434654169	5381	Economy	22400.00
0005434654181	5381	Economy	22400.00
0005434654184	5381	Economy	22400.00
0005434656520	5381	Economy	22400.00
0005434654176	5381	Economy	22400.00
0005434654173	5381	Economy	22400.00
0005434654175	5381	Economy	22400.00
0005434654164	5381	Economy	22400.00
0005432114146	5381	Economy	22400.00
0005434654161	5381	Economy	22400.00
0005432114145	5381	Economy	22400.00
0005432114147	5381	Economy	22400.00
0005434654183	5381	Economy	22400.00
0005434654165	5381	Economy	22400.00
0005434654188	5381	Economy	22400.00
0005434654177	5381	Economy	22400.00
0005432114148	5381	Economy	22400.00
0005434654185	5381	Economy	22400.00
0005434654160	5381	Economy	22400.00
0005434654171	5381	Economy	22400.00
0005434654180	5381	Economy	22400.00
0005435555335	12554	Business	67200.00
0005435339991	12554	Business	67200.00
0005435339989	12554	Economy	22400.00
0005435339996	12554	Economy	24600.00
0005435339998	12554	Economy	24600.00
0005435339992	12554	Economy	22400.00
0005435340001	12554	Economy	22400.00
0005435555334	12554	Economy	22400.00
0005435340002	12554	Economy	22400.00
0005435340000	12554	Economy	22400.00
0005435339999	12554	Economy	22400.00
0005435339993	12554	Economy	22400.00
0005435339990	12554	Economy	22400.00
0005435339995	12554	Economy	22400.00
0005435340003	12554	Economy	22400.00
0005435339997	12554	Economy	22400.00
0005435339994	12554	Economy	22400.00
0005433715070	7456	Business	32000.00
0005433715087	7456	Business	32000.00
0005433715100	7456	Business	32000.00
0005432078011	7456	Business	32000.00
0005433715080	7456	Business	32000.00
0005433715114	7456	Economy	10700.00
0005433715093	7456	Economy	10700.00
0005433715068	7456	Economy	10700.00
0005432078008	7456	Economy	10700.00
0005433715075	7456	Economy	10700.00
0005433715097	7456	Economy	10700.00
0005433715083	7456	Economy	10700.00
0005433715109	7456	Economy	10700.00
0005433715091	7456	Economy	10700.00
0005433715094	7456	Economy	10700.00
0005432078012	7456	Economy	10700.00
0005433715105	7456	Economy	10700.00
0005433715112	7456	Economy	10700.00
0005433715076	7456	Economy	10700.00
0005433715108	7456	Economy	10700.00
0005433715104	7456	Economy	10700.00
0005433715107	7456	Economy	10700.00
0005432078013	7456	Economy	10700.00
0005433715081	7456	Economy	10700.00
0005432078009	7456	Economy	10700.00
0005433715090	7456	Economy	11700.00
0005433715099	7456	Economy	11700.00
0005433715077	7456	Economy	10700.00
0005433715086	7456	Economy	10700.00
0005433715115	7456	Economy	10700.00
0005433715074	7456	Economy	10700.00
0005433715098	7456	Economy	10700.00
0005433715089	7456	Economy	10700.00
0005433715110	7456	Economy	10700.00
0005433715095	7456	Economy	10700.00
0005433715071	7456	Economy	10700.00
0005433715069	7456	Economy	10700.00
0005433715101	7456	Economy	10700.00
0005433715096	7456	Economy	10700.00
0005433715072	7456	Economy	10700.00
0005433715082	7456	Economy	10700.00
0005433715103	7456	Economy	10700.00
0005432078014	7456	Economy	10700.00
0005433715067	7456	Economy	10700.00
0005433715106	7456	Economy	10700.00
0005433715102	7456	Economy	10700.00
0005433715111	7456	Economy	10700.00
0005433715084	7456	Economy	10700.00
0005433715088	7456	Economy	10700.00
0005433715073	7456	Economy	10700.00
0005433715078	7456	Economy	10700.00
0005433715085	7456	Economy	10700.00
0005433715092	7456	Economy	10700.00
0005432078015	7456	Economy	10700.00
0005432078010	7456	Economy	10700.00
0005433715113	7456	Economy	10700.00
0005433715079	7456	Economy	10700.00
0005432428867	29197	Economy	10700.00
0005432006710	29197	Economy	10700.00
0005432006708	29197	Economy	10700.00
0005432428868	29197	Economy	10700.00
0005432006709	29197	Economy	10700.00
0005432428869	29197	Economy	10700.00
0005435266074	29197	Economy	10700.00
0005434095016	8676	Business	36500.00
0005434095020	8676	Economy	12200.00
0005434095022	8676	Economy	12200.00
0005434095024	8676	Economy	12200.00
0005434095028	8676	Economy	13400.00
0005434095021	8676	Economy	13400.00
0005434095029	8676	Economy	12200.00
0005434095018	8676	Economy	12200.00
0005434095015	8676	Economy	12200.00
0005434095017	8676	Economy	12200.00
0005434095025	8676	Economy	12200.00
0005434095026	8676	Economy	12200.00
0005434095019	8676	Economy	12200.00
0005434095023	8676	Economy	12200.00
0005434095027	8676	Economy	12200.00
0005434181965	11646	Business	36500.00
0005434181957	11646	Economy	12200.00
0005434181959	11646	Economy	12200.00
0005434181964	11646	Economy	13400.00
0005434181963	11646	Economy	12200.00
0005434181962	11646	Economy	12200.00
0005434181966	11646	Economy	12200.00
0005434181961	11646	Economy	12200.00
0005434181967	11646	Economy	12200.00
0005434181968	11646	Economy	12200.00
0005434181960	11646	Economy	12200.00
0005434181958	11646	Economy	12200.00
0005433456897	1452	Economy	12100.00
0005435732120	1452	Economy	12100.00
0005435732116	1452	Economy	11000.00
0005435732115	1452	Economy	11000.00
0005433456898	1452	Economy	11000.00
0005435732117	1452	Economy	11000.00
0005435732124	1452	Economy	11000.00
0005435732122	1452	Economy	11000.00
0005432297231	1452	Economy	11000.00
0005432297232	1452	Economy	11000.00
0005433456900	1452	Economy	11000.00
0005433456899	1452	Economy	11000.00
0005432297230	1452	Economy	11000.00
0005435732119	1452	Economy	11000.00
0005435732118	1452	Economy	11000.00
0005435732114	1452	Economy	11000.00
0005435732123	1452	Economy	11000.00
0005435732113	1452	Economy	11000.00
0005435732121	1452	Economy	11000.00
0005435732112	1452	Economy	11000.00
0005433397213	19231	Business	33000.00
0005433397186	19231	Business	33000.00
0005433397228	19231	Business	33000.00
0005433397225	19231	Business	33000.00
0005433397222	19231	Business	33000.00
0005433397217	19231	Business	33000.00
0005433397187	19231	Business	33000.00
0005433397218	19231	Economy	11000.00
0005433397185	19231	Economy	11000.00
0005433397211	19231	Economy	11000.00
0005433397199	19231	Economy	11000.00
0005433397219	19231	Economy	11000.00
0005433397194	19231	Economy	11000.00
0005433397184	19231	Economy	11000.00
0005433397189	19231	Economy	11000.00
0005433397223	19231	Economy	12100.00
0005433397212	19231	Economy	12100.00
0005433397196	19231	Economy	11000.00
0005432906492	19231	Economy	11000.00
0005433397210	19231	Economy	11000.00
0005433397178	19231	Economy	11000.00
0005433397221	19231	Economy	11000.00
0005433397216	19231	Economy	11000.00
0005433397190	19231	Economy	11000.00
0005433397183	19231	Economy	11000.00
0005433397182	19231	Economy	11000.00
0005433397209	19231	Economy	11000.00
0005433397198	19231	Economy	11000.00
0005433397197	19231	Economy	11000.00
0005433397191	19231	Economy	11000.00
0005433397215	19231	Economy	11000.00
0005433397226	19231	Economy	11000.00
0005433397195	19231	Economy	11000.00
0005432906491	19231	Economy	11000.00
0005433397192	19231	Economy	11000.00
0005433397180	19231	Economy	11000.00
0005433397214	19231	Economy	11000.00
0005433397200	19231	Economy	11000.00
0005433397181	19231	Economy	11000.00
0005433397220	19231	Economy	11000.00
0005433397204	19231	Economy	11000.00
0005433397193	19231	Economy	11000.00
0005433397179	19231	Economy	11000.00
0005433397227	19231	Economy	11000.00
0005433397208	19231	Economy	11000.00
0005433397202	19231	Economy	11000.00
0005433397206	19231	Economy	11000.00
0005433397205	19231	Economy	11000.00
0005433397207	19231	Economy	11000.00
0005433397201	19231	Economy	11000.00
0005433397188	19231	Economy	11000.00
0005433397203	19231	Economy	11000.00
0005433397224	19231	Economy	11000.00
0005434954540	7267	Economy	5800.00
0005434954538	7267	Economy	5800.00
0005434954537	7267	Economy	5800.00
0005434954539	7267	Economy	5800.00
0005435377538	28327	Economy	5800.00
0005435377537	28327	Economy	5800.00
0005434351476	4490	Economy	15400.00
0005434351466	4490	Economy	14000.00
0005434351464	4490	Economy	14000.00
0005434351472	4490	Economy	14000.00
0005434351471	4490	Economy	14000.00
0005434351475	4490	Economy	14000.00
0005434351469	4490	Economy	14000.00
0005434351468	4490	Economy	14000.00
0005434351473	4490	Economy	14000.00
0005434351463	4490	Economy	14000.00
0005434351470	4490	Economy	14000.00
0005434351474	4490	Economy	14000.00
0005434351465	4490	Economy	14000.00
0005434351467	4490	Economy	14000.00
0005435893507	29663	Economy	14000.00
0005435893505	29663	Economy	14000.00
0005435893509	29663	Economy	14000.00
0005435893506	29663	Economy	14000.00
0005435893503	29663	Economy	14000.00
0005435893508	29663	Economy	14000.00
0005435893504	29663	Economy	14000.00
0005435091899	1090	Business	30600.00
0005435091897	1090	Economy	10200.00
0005435091895	1090	Economy	10200.00
0005433462709	1090	Economy	10200.00
0005435091894	1090	Economy	10200.00
0005432293165	1090	Economy	10200.00
0005433463863	1090	Economy	10200.00
0005435091896	1090	Economy	10200.00
0005435091892	1090	Economy	10200.00
0005433463862	1090	Economy	10200.00
0005435091898	1090	Economy	10200.00
0005434445207	1090	Economy	10200.00
0005435091893	1090	Economy	10200.00
0005435091900	1090	Economy	10200.00
0005434446476	1090	Economy	10200.00
0005434445210	1090	Economy	10200.00
0005434445208	1090	Economy	10200.00
0005433463861	1090	Economy	10200.00
0005434445209	1090	Economy	10200.00
0005433462708	1090	Economy	10200.00
0005432293164	1090	Economy	10200.00
0005435091901	1090	Economy	10200.00
0005433269620	17024	Economy	10200.00
0005433269619	17024	Economy	10200.00
0005433269624	17024	Economy	10200.00
0005433269622	17024	Economy	11200.00
0005433269623	17024	Economy	10200.00
0005433269621	17024	Economy	10200.00
0005432851815	18263	Economy	33700.00
0005432851816	18263	Economy	33700.00
0005432851819	18263	Economy	33700.00
0005432851817	18263	Economy	33700.00
0005432851820	18263	Economy	33700.00
0005432851818	18263	Economy	33700.00
0005432159776	12797	Economy	13400.00
0005432433582	12797	Economy	13400.00
0005432433585	12797	Economy	13400.00
0005433812858	12797	Economy	13400.00
0005433812857	12797	Economy	13400.00
0005432433586	12797	Economy	13400.00
0005432161111	12797	Economy	13400.00
0005432161110	12797	Economy	13400.00
0005432433583	12797	Economy	13400.00
0005432159777	12797	Economy	13400.00
0005432159778	12797	Economy	13400.00
0005432433584	12797	Economy	13400.00
0005433812859	12797	Economy	13400.00
0005432159775	12797	Economy	13400.00
0005433989684	30696	Economy	13400.00
0005433989681	30696	Economy	13400.00
0005433989682	30696	Economy	13400.00
0005433989683	30696	Economy	13400.00
0005435765119	5493	Business	35300.00
0005435765148	5493	Business	35300.00
0005435765122	5493	Business	35300.00
0005432140305	5493	Business	35300.00
0005435765106	5493	Business	35300.00
0005435722013	5493	Business	35300.00
0005435765169	5493	Business	35300.00
0005435765146	5493	Business	35300.00
0005435765136	5493	Business	35300.00
0005435765116	5493	Business	35300.00
0005435765134	5493	Business	35300.00
0005433529211	5493	Economy	12900.00
0005432140301	5493	Economy	12900.00
0005435765107	5493	Economy	12900.00
0005435765127	5493	Economy	11800.00
0005435765139	5493	Economy	11800.00
0005432140300	5493	Economy	11800.00
0005435765168	5493	Economy	11800.00
0005435765130	5493	Economy	11800.00
0005435765144	5493	Economy	11800.00
0005435765159	5493	Economy	11800.00
0005435765115	5493	Economy	11800.00
0005435765125	5493	Economy	11800.00
0005435765126	5493	Economy	11800.00
0005435765164	5493	Economy	11800.00
0005435765128	5493	Economy	11800.00
0005435765140	5493	Economy	11800.00
0005435765121	5493	Economy	11800.00
0005435720800	5493	Economy	11800.00
0005433529212	5493	Economy	11800.00
0005432140298	5493	Economy	11800.00
0005435765166	5493	Economy	11800.00
0005435765154	5493	Economy	11800.00
0005435765141	5493	Economy	11800.00
0005432140306	5493	Economy	11800.00
0005435765111	5493	Economy	11800.00
0005433529210	5493	Economy	11800.00
0005435765171	5493	Economy	11800.00
0005435765110	5493	Economy	11800.00
0005435765124	5493	Economy	11800.00
0005435765162	5493	Economy	11800.00
0005435765138	5493	Economy	11800.00
0005435765102	5493	Economy	11800.00
0005435765152	5493	Economy	11800.00
0005435765132	5493	Economy	11800.00
0005435765133	5493	Economy	11800.00
0005435765167	5493	Economy	11800.00
0005432140303	5493	Economy	11800.00
0005432140304	5493	Economy	11800.00
0005435765129	5493	Economy	11800.00
0005435765135	5493	Economy	11800.00
0005435765165	5493	Economy	11800.00
0005435765158	5493	Economy	11800.00
0005435765109	5493	Economy	11800.00
0005435765147	5493	Economy	11800.00
0005435765155	5493	Economy	11800.00
0005435765105	5493	Economy	11800.00
0005435765149	5493	Economy	11800.00
0005435765160	5493	Economy	11800.00
0005435765157	5493	Economy	11800.00
0005433527199	5493	Economy	11800.00
0005433527202	5493	Economy	11800.00
0005435765123	5493	Economy	11800.00
0005435765145	5493	Economy	11800.00
0005432140299	5493	Economy	12900.00
0005435765161	5493	Economy	12900.00
0005435765103	5493	Economy	11800.00
0005435722012	5493	Economy	11800.00
0005435765150	5493	Economy	11800.00
0005435765131	5493	Economy	11800.00
0005435765120	5493	Economy	11800.00
0005435765143	5493	Economy	11800.00
0005435765163	5493	Economy	11800.00
0005435765156	5493	Economy	11800.00
0005433529213	5493	Economy	11800.00
0005435765151	5493	Economy	11800.00
0005435765114	5493	Economy	11800.00
0005432140307	5493	Economy	11800.00
0005435765112	5493	Economy	11800.00
0005435765104	5493	Economy	11800.00
0005435765142	5493	Economy	11800.00
0005435765108	5493	Economy	11800.00
0005435765137	5493	Economy	11800.00
0005435720798	5493	Economy	11800.00
0005435765118	5493	Economy	11800.00
0005432140302	5493	Economy	11800.00
0005435720799	5493	Economy	11800.00
0005435765170	5493	Economy	11800.00
0005433527200	5493	Economy	11800.00
0005435765153	5493	Economy	11800.00
0005435765113	5493	Economy	11800.00
0005433527201	5493	Economy	11800.00
0005435765117	5493	Economy	11800.00
0005432535746	13470	Business	35300.00
0005434264686	13470	Business	35300.00
0005432535749	13470	Business	35300.00
0005434264678	13470	Business	35300.00
0005435461788	13470	Business	35300.00
0005435461769	13470	Business	35300.00
0005434831066	13470	Business	35300.00
0005435461777	13470	Business	35300.00
0005435461773	13470	Business	35300.00
0005435461756	13470	Business	35300.00
0005435461763	13470	Business	35300.00
0005434264696	13470	Business	35300.00
0005435461784	13470	Business	35300.00
0005435461768	13470	Business	35300.00
0005434264683	13470	Economy	11800.00
0005432535747	13470	Economy	11800.00
0005434264685	13470	Economy	11800.00
0005435461787	13470	Economy	11800.00
0005434264691	13470	Economy	11800.00
0005434264681	13470	Economy	11800.00
0005435461774	13470	Economy	11800.00
0005434264677	13470	Economy	11800.00
0005435461780	13470	Economy	11800.00
0005432194435	13470	Economy	11800.00
0005434264690	13470	Economy	11800.00
0005435461776	13470	Economy	11800.00
0005435461786	13470	Economy	11800.00
0005434264700	13470	Economy	11800.00
0005435461762	13470	Economy	11800.00
0005435461781	13470	Economy	11800.00
0005432194438	13470	Economy	11800.00
0005435461791	13470	Economy	11800.00
0005435461779	13470	Economy	11800.00
0005434264699	13470	Economy	11800.00
0005435461772	13470	Economy	11800.00
0005434264695	13470	Economy	11800.00
0005432535745	13470	Economy	11800.00
0005434264701	13470	Economy	11800.00
0005434264687	13470	Economy	11800.00
0005435461790	13470	Economy	11800.00
0005434831068	13470	Economy	11800.00
0005434264697	13470	Economy	11800.00
0005435461760	13470	Economy	11800.00
0005435461789	13470	Economy	11800.00
0005435461794	13470	Economy	11800.00
0005434264684	13470	Economy	11800.00
0005432194436	13470	Economy	11800.00
0005434264676	13470	Economy	11800.00
0005434264692	13470	Economy	12900.00
0005434264698	13470	Economy	11800.00
0005435461792	13470	Economy	11800.00
0005434264682	13470	Economy	12900.00
0005435461766	13470	Economy	11800.00
0005435461765	13470	Economy	11800.00
0005434264689	13470	Economy	11800.00
0005434264688	13470	Economy	11800.00
0005434831067	13470	Economy	11800.00
0005435461770	13470	Economy	11800.00
0005432194437	13470	Economy	11800.00
0005434831070	13470	Economy	11800.00
0005434264693	13470	Economy	11800.00
0005435461764	13470	Economy	11800.00
0005432194439	13470	Economy	11800.00
0005435461758	13470	Economy	11800.00
0005434831069	13470	Economy	11800.00
0005435461759	13470	Economy	11800.00
0005435461771	13470	Economy	11800.00
0005432535748	13470	Economy	11800.00
0005435461757	13470	Economy	11800.00
0005435461778	13470	Economy	11800.00
0005435461793	13470	Economy	11800.00
0005435461785	13470	Economy	11800.00
0005435461767	13470	Economy	11800.00
0005434264694	13470	Economy	11800.00
0005434264680	13470	Economy	11800.00
0005435461775	13470	Economy	11800.00
0005434264679	13470	Economy	11800.00
0005434264675	13470	Economy	11800.00
0005435461761	13470	Economy	11800.00
0005435461783	13470	Economy	11800.00
0005435461782	13470	Economy	11800.00
0005435846191	25096	Economy	29400.00
0005435846188	25096	Economy	29400.00
0005435846190	25096	Economy	29400.00
0005435846189	25096	Economy	29400.00
0005433810491	1819	Business	48700.00
0005432295834	1819	Economy	16200.00
0005432295833	1819	Economy	16200.00
0005433810488	1819	Economy	16200.00
0005433810489	1819	Economy	16200.00
0005433810490	1819	Economy	16200.00
0005432295832	1819	Economy	16200.00
0005433845710	5588	Business	99800.00
0005433845696	5588	Business	99800.00
0005433845663	5588	Business	99800.00
0005432081398	5588	Business	99800.00
0005433845704	5588	Business	99800.00
0005433845679	5588	Business	99800.00
0005433845678	5588	Business	99800.00
0005433845720	5588	Business	99800.00
0005433845712	5588	Business	99800.00
0005433845673	5588	Business	99800.00
0005433845684	5588	Business	99800.00
0005433845691	5588	Economy	33300.00
0005433845716	5588	Economy	33300.00
0005433845690	5588	Economy	33300.00
0005433845714	5588	Economy	33300.00
0005433845689	5588	Economy	33300.00
0005433845681	5588	Economy	33300.00
0005433845692	5588	Economy	33300.00
0005433845705	5588	Economy	33300.00
0005433845701	5588	Economy	33300.00
0005433845676	5588	Economy	36600.00
0005433845708	5588	Economy	36600.00
0005433845668	5588	Economy	33300.00
0005433845715	5588	Economy	33300.00
0005433845695	5588	Economy	33300.00
0005433845719	5588	Economy	33300.00
0005433845697	5588	Economy	33300.00
0005433845665	5588	Economy	33300.00
0005433845667	5588	Economy	33300.00
0005433845713	5588	Economy	33300.00
0005433845683	5588	Economy	33300.00
0005432081394	5588	Economy	33300.00
0005433845682	5588	Economy	33300.00
0005432081396	5588	Economy	33300.00
0005433845721	5588	Economy	33300.00
0005433845706	5588	Economy	33300.00
0005432081393	5588	Economy	33300.00
0005433845711	5588	Economy	33300.00
0005433845688	5588	Economy	33300.00
0005432081400	5588	Economy	33300.00
0005433845687	5588	Economy	33300.00
0005433845722	5588	Economy	33300.00
0005433845680	5588	Economy	33300.00
0005433845685	5588	Economy	33300.00
0005433845702	5588	Economy	33300.00
0005433845666	5588	Economy	33300.00
0005432081397	5588	Economy	33300.00
0005433845703	5588	Economy	33300.00
0005433845677	5588	Economy	33300.00
0005433845672	5588	Economy	33300.00
0005433845699	5588	Economy	33300.00
0005433845693	5588	Economy	33300.00
0005433845671	5588	Economy	33300.00
0005432081399	5588	Economy	33300.00
0005432081395	5588	Economy	33300.00
0005433845717	5588	Economy	33300.00
0005433845670	5588	Economy	33300.00
0005433845674	5588	Economy	33300.00
0005433845707	5588	Economy	33300.00
0005433845669	5588	Economy	33300.00
0005433845686	5588	Economy	33300.00
0005433845664	5588	Economy	33300.00
0005433845709	5588	Economy	33300.00
0005433845675	5588	Economy	33300.00
0005433845718	5588	Economy	33300.00
0005433845700	5588	Economy	33300.00
0005433845694	5588	Economy	33300.00
0005433845698	5588	Economy	33300.00
0005435282067	13884	Business	99800.00
0005435282058	13884	Business	99800.00
0005435282064	13884	Business	99800.00
0005434173451	13884	Business	99800.00
0005435282055	13884	Business	99800.00
0005432003645	13884	Business	99800.00
0005435282069	13884	Economy	33300.00
0005435282059	13884	Economy	36600.00
0005435282057	13884	Economy	33300.00
0005435282054	13884	Economy	33300.00
0005435282053	13884	Economy	33300.00
0005435282062	13884	Economy	33300.00
0005435282061	13884	Economy	33300.00
0005435282050	13884	Economy	33300.00
0005435282063	13884	Economy	33300.00
0005435282049	13884	Economy	33300.00
0005432003647	13884	Economy	33300.00
0005435282052	13884	Economy	33300.00
0005435282051	13884	Economy	33300.00
0005435282060	13884	Economy	33300.00
0005435282068	13884	Economy	33300.00
0005434173450	13884	Economy	33300.00
0005435282065	13884	Economy	33300.00
0005435282056	13884	Economy	33300.00
0005432003646	13884	Economy	33300.00
0005435282066	13884	Economy	33300.00
0005434620228	7843	Economy	16600.00
0005434620230	7843	Economy	16600.00
0005434620232	7843	Economy	15100.00
0005432112476	7843	Economy	15100.00
0005434620233	7843	Economy	15100.00
0005434620240	7843	Economy	15100.00
0005434620226	7843	Economy	15100.00
0005434620242	7843	Economy	15100.00
0005434620223	7843	Economy	15100.00
0005434620222	7843	Economy	15100.00
0005434620238	7843	Economy	15100.00
0005434620227	7843	Economy	15100.00
0005434620241	7843	Economy	15100.00
0005434620239	7843	Economy	15100.00
0005434620229	7843	Economy	15100.00
0005434620231	7843	Economy	15100.00
0005434620234	7843	Economy	15100.00
0005434620235	7843	Economy	15100.00
0005434620236	7843	Economy	15100.00
0005434620224	7843	Economy	15100.00
0005434620237	7843	Economy	15100.00
0005434620225	7843	Economy	15100.00
0005432112475	7843	Economy	15100.00
0005435332153	32948	Economy	15100.00
0005435332154	32948	Economy	15100.00
0005435332149	32948	Economy	15100.00
0005435332156	32948	Economy	15100.00
0005435332150	32948	Economy	15100.00
0005435332152	32948	Economy	15100.00
0005435332155	32948	Economy	15100.00
0005435332146	32948	Economy	15100.00
0005435332148	32948	Economy	15100.00
0005435332147	32948	Economy	15100.00
0005435332151	32948	Economy	15100.00
0005435784754	4260	Business	38000.00
0005435784742	4260	Business	38000.00
0005432190562	4260	Business	38000.00
0005432190561	4260	Business	38000.00
0005435784758	4260	Business	38000.00
0005432190564	4260	Economy	12700.00
0005435784748	4260	Economy	12700.00
0005435784736	4260	Economy	12700.00
0005435784760	4260	Economy	12700.00
0005435784757	4260	Economy	12700.00
0005434993846	4260	Economy	12700.00
0005435784762	4260	Economy	13900.00
0005435784755	4260	Economy	13900.00
0005435784737	4260	Economy	13900.00
0005435784731	4260	Economy	12700.00
0005435784738	4260	Economy	12700.00
0005435784729	4260	Economy	12700.00
0005435784734	4260	Economy	12700.00
0005435784739	4260	Economy	12700.00
0005435784756	4260	Economy	12700.00
0005432190563	4260	Economy	12700.00
0005435784740	4260	Economy	12700.00
0005435784732	4260	Economy	12700.00
0005434993854	4260	Economy	12700.00
0005434993851	4260	Economy	12700.00
0005435784749	4260	Economy	12700.00
0005435784752	4260	Economy	12700.00
0005434993848	4260	Economy	12700.00
0005435784746	4260	Economy	12700.00
0005435784747	4260	Economy	12700.00
0005435784735	4260	Economy	12700.00
0005434993853	4260	Economy	12700.00
0005434993852	4260	Economy	12700.00
0005435784759	4260	Economy	12700.00
0005435784733	4260	Economy	12700.00
0005435784727	4260	Economy	12700.00
0005435784728	4260	Economy	12700.00
0005435784751	4260	Economy	12700.00
0005435784750	4260	Economy	12700.00
0005435784763	4260	Economy	12700.00
0005435784730	4260	Economy	12700.00
0005435784753	4260	Economy	12700.00
0005434993850	4260	Economy	12700.00
0005434993847	4260	Economy	12700.00
0005435784745	4260	Economy	12700.00
0005435784744	4260	Economy	12700.00
0005434993849	4260	Economy	12700.00
0005435784743	4260	Economy	12700.00
0005435784761	4260	Economy	12700.00
0005435784741	4260	Economy	12700.00
0005435918570	27318	Business	38000.00
0005435918572	27318	Economy	12700.00
0005435918571	27318	Economy	12700.00
0005435918569	27318	Economy	12700.00
0005432566574	4695	Business	40900.00
0005434081472	4695	Business	40900.00
0005434081483	4695	Business	40900.00
0005432170270	4695	Business	40900.00
0005432566543	4695	Business	40900.00
0005432566539	4695	Business	40900.00
0005432566545	4695	Business	40900.00
0005432566569	4695	Business	40900.00
0005434081485	4695	Business	40900.00
0005434081479	4695	Business	40900.00
0005432566535	4695	Business	40900.00
0005432566541	4695	Business	40900.00
0005432566575	4695	Business	40900.00
0005434081473	4695	Economy	15000.00
0005432566577	4695	Economy	15000.00
0005432566555	4695	Economy	15000.00
0005432566584	4695	Economy	13600.00
0005432566557	4695	Economy	13600.00
0005432566586	4695	Economy	13600.00
0005432566581	4695	Economy	13600.00
0005432566565	4695	Economy	13600.00
0005434081484	4695	Economy	13600.00
0005432566530	4695	Economy	13600.00
0005432566566	4695	Economy	13600.00
0005432566542	4695	Economy	13600.00
0005432566538	4695	Economy	13600.00
0005432566558	4695	Economy	13600.00
0005432566580	4695	Economy	13600.00
0005432566572	4695	Economy	13600.00
0005432566551	4695	Economy	13600.00
0005434081480	4695	Economy	13600.00
0005432566548	4695	Economy	13600.00
0005432566547	4695	Economy	13600.00
0005432566570	4695	Economy	13600.00
0005432566540	4695	Economy	13600.00
0005432566533	4695	Economy	13600.00
0005432566553	4695	Economy	13600.00
0005432566588	4695	Economy	13600.00
0005432566534	4695	Economy	13600.00
0005432566544	4695	Economy	13600.00
0005434081476	4695	Economy	13600.00
0005432566550	4695	Economy	13600.00
0005432566563	4695	Economy	13600.00
0005432566582	4695	Economy	13600.00
0005432566525	4695	Economy	13600.00
0005434081471	4695	Economy	13600.00
0005434081477	4695	Economy	13600.00
0005432566583	4695	Economy	13600.00
0005433726063	4695	Economy	13600.00
0005432566568	4695	Economy	13600.00
0005432566562	4695	Economy	13600.00
0005433451582	4695	Economy	13600.00
0005432566578	4695	Economy	13600.00
0005432566546	4695	Economy	13600.00
0005432566528	4695	Economy	13600.00
0005433451583	4695	Economy	13600.00
0005434081475	4695	Economy	13600.00
0005432566556	4695	Economy	13600.00
0005432186804	4695	Economy	13600.00
0005432566571	4695	Economy	15000.00
0005434081486	4695	Economy	15000.00
0005432566564	4695	Economy	13600.00
0005432566579	4695	Economy	15000.00
0005432186803	4695	Economy	13600.00
0005432566526	4695	Economy	13600.00
0005432566549	4695	Economy	13600.00
0005432566585	4695	Economy	13600.00
0005434081470	4695	Economy	13600.00
0005432566532	4695	Economy	13600.00
0005432566573	4695	Economy	13600.00
0005432186806	4695	Economy	13600.00
0005433452702	4695	Economy	13600.00
0005432566576	4695	Economy	13600.00
0005432170267	4695	Economy	13600.00
0005432566554	4695	Economy	13600.00
0005434081474	4695	Economy	13600.00
0005432566529	4695	Economy	13600.00
0005434081482	4695	Economy	13600.00
0005432566559	4695	Economy	13600.00
0005434081481	4695	Economy	13600.00
0005432170269	4695	Economy	13600.00
0005432566536	4695	Economy	13600.00
0005432566560	4695	Economy	13600.00
0005432566527	4695	Economy	13600.00
0005434081478	4695	Economy	13600.00
0005432186805	4695	Economy	13600.00
0005432566561	4695	Economy	13600.00
0005432170266	4695	Economy	13600.00
0005432566531	4695	Economy	13600.00
0005432566537	4695	Economy	13600.00
0005432566567	4695	Economy	13600.00
0005433452701	4695	Economy	13600.00
0005432170268	4695	Economy	13600.00
0005433452703	4695	Economy	13600.00
0005432566552	4695	Economy	13600.00
0005432566587	4695	Economy	13600.00
0005432161110	30531	Business	40900.00
0005432213541	30531	Economy	13600.00
0005432213539	30531	Economy	13600.00
0005432161111	30531	Economy	13600.00
0005432213542	30531	Economy	13600.00
0005432213540	30531	Economy	13600.00
0005435720798	13619	Economy	9900.00
0005435720800	13619	Economy	9900.00
0005435722013	13619	Economy	9900.00
0005435720799	13619	Economy	9900.00
0005435722012	13619	Economy	9900.00
0005432295833	22773	Economy	8800.00
0005432295832	22773	Economy	8800.00
0005432295834	22773	Economy	8800.00
0005433341410	11112	Business	23600.00
0005433341429	11112	Business	23600.00
0005433341457	11112	Business	23600.00
0005433341416	11112	Business	23600.00
0005433341395	11112	Business	23600.00
0005433341468	11112	Business	23600.00
0005433341381	11112	Business	23600.00
0005433341463	11112	Business	23600.00
0005433341402	11112	Business	23600.00
0005433341409	11112	Business	23600.00
0005433341464	11112	Economy	7900.00
0005433341456	11112	Economy	7900.00
0005433341417	11112	Economy	7900.00
0005433341379	11112	Economy	7900.00
0005433341452	11112	Economy	7900.00
0005433341389	11112	Economy	7900.00
0005433341408	11112	Economy	7900.00
0005433341446	11112	Economy	7900.00
0005433341467	11112	Economy	7900.00
0005433341436	11112	Economy	7900.00
0005433341398	11112	Economy	7900.00
0005433341448	11112	Economy	7900.00
0005433341420	11112	Economy	7900.00
0005433341478	11112	Economy	7900.00
0005433341425	11112	Economy	7900.00
0005433341378	11112	Economy	7900.00
0005433341384	11112	Economy	7900.00
0005433341462	11112	Economy	7900.00
0005433341422	11112	Economy	7900.00
0005433341434	11112	Economy	7900.00
0005433341405	11112	Economy	7900.00
0005433341455	11112	Economy	7900.00
0005433341471	11112	Economy	7900.00
0005433341470	11112	Economy	7900.00
0005433341401	11112	Economy	7900.00
0005433341458	11112	Economy	7900.00
0005433341419	11112	Economy	7900.00
0005433341406	11112	Economy	7900.00
0005433341387	11112	Economy	7900.00
0005433341394	11112	Economy	7900.00
0005433341423	11112	Economy	7900.00
0005433341443	11112	Economy	7900.00
0005433341465	11112	Economy	8600.00
0005433341426	11112	Economy	8600.00
0005433341380	11112	Economy	7900.00
0005433341445	11112	Economy	7900.00
0005433341459	11112	Economy	7900.00
0005433341449	11112	Economy	7900.00
0005433341450	11112	Economy	7900.00
0005433341454	11112	Economy	7900.00
0005433341382	11112	Economy	7900.00
0005433341411	11112	Economy	7900.00
0005433341430	11112	Economy	7900.00
0005433341412	11112	Economy	7900.00
0005433341391	11112	Economy	7900.00
0005433341439	11112	Economy	7900.00
0005433341451	11112	Economy	7900.00
0005433341400	11112	Economy	7900.00
0005433341393	11112	Economy	7900.00
0005433341385	11112	Economy	7900.00
0005433341461	11112	Economy	7900.00
0005433341447	11112	Economy	7900.00
0005433341396	11112	Economy	7900.00
0005433341390	11112	Economy	7900.00
0005433341432	11112	Economy	7900.00
0005433341414	11112	Economy	7900.00
0005433341472	11112	Economy	7900.00
0005433341437	11112	Economy	7900.00
0005433341444	11112	Economy	7900.00
0005433341440	11112	Economy	7900.00
0005433341418	11112	Economy	7900.00
0005433341476	11112	Economy	7900.00
0005433341383	11112	Economy	7900.00
0005433341386	11112	Economy	7900.00
0005433341424	11112	Economy	7900.00
0005433341407	11112	Economy	7900.00
0005433341399	11112	Economy	7900.00
0005433341428	11112	Economy	7900.00
0005433341431	11112	Economy	7900.00
0005433341392	11112	Economy	7900.00
0005433341466	11112	Economy	7900.00
0005433341433	11112	Economy	7900.00
0005433341404	11112	Economy	7900.00
0005433341415	11112	Economy	7900.00
0005433341441	11112	Economy	7900.00
0005433341435	11112	Economy	7900.00
0005433341479	11112	Economy	7900.00
0005433341469	11112	Economy	7900.00
0005433341477	11112	Economy	7900.00
0005433341427	11112	Economy	7900.00
0005433341460	11112	Economy	7900.00
0005433341474	11112	Economy	7900.00
0005433341473	11112	Economy	7900.00
0005433341421	11112	Economy	7900.00
0005433341438	11112	Economy	7900.00
0005433341475	11112	Economy	7900.00
0005433341413	11112	Economy	7900.00
0005433341453	11112	Economy	7900.00
0005433341397	11112	Economy	7900.00
0005433341403	11112	Economy	7900.00
0005433341442	11112	Economy	7900.00
0005433341388	11112	Economy	7900.00
0005432293165	17112	Economy	7900.00
0005432293164	17112	Economy	7900.00
0005433506861	9116	Business	26600.00
0005433506866	9116	Business	26600.00
0005433506857	9116	Business	26600.00
0005433506863	9116	Business	26600.00
0005433481032	9116	Business	26600.00
0005433506870	9116	Business	26600.00
0005433481029	9116	Economy	8900.00
0005433506859	9116	Economy	8900.00
0005433506860	9116	Economy	8900.00
0005433481031	9116	Economy	9800.00
0005433506856	9116	Economy	9800.00
0005433506862	9116	Economy	8900.00
0005433481030	9116	Economy	8900.00
0005433481027	9116	Economy	8900.00
0005433506864	9116	Economy	8900.00
0005433506871	9116	Economy	8900.00
0005433481034	9116	Economy	8900.00
0005433481033	9116	Economy	8900.00
0005433506869	9116	Economy	8900.00
0005433506855	9116	Economy	8900.00
0005433506865	9116	Economy	8900.00
0005433506854	9116	Economy	8900.00
0005433506867	9116	Economy	8900.00
0005433481028	9116	Economy	8900.00
0005433506868	9116	Economy	8900.00
0005433506853	9116	Economy	8900.00
0005433506858	9116	Economy	8900.00
0005432919520	20490	Business	26600.00
0005432919523	20490	Business	26600.00
0005432919514	20490	Business	26600.00
0005432919504	20490	Business	26600.00
0005434158945	20490	Economy	8900.00
0005432919511	20490	Economy	8900.00
0005432919506	20490	Economy	8900.00
0005432919517	20490	Economy	9800.00
0005432919521	20490	Economy	9800.00
0005432919524	20490	Economy	8900.00
0005432919513	20490	Economy	8900.00
0005432919518	20490	Economy	8900.00
0005434158946	20490	Economy	8900.00
0005432919508	20490	Economy	8900.00
0005432919516	20490	Economy	8900.00
0005434158943	20490	Economy	8900.00
0005432919505	20490	Economy	8900.00
0005432919522	20490	Economy	8900.00
0005432919509	20490	Economy	8900.00
0005432919515	20490	Economy	8900.00
0005432919507	20490	Economy	8900.00
0005432919510	20490	Economy	8900.00
0005434158944	20490	Economy	8900.00
0005432919519	20490	Economy	8900.00
0005432919512	20490	Economy	8900.00
0005432919503	20490	Economy	8900.00
0005434411702	11042	Economy	3200.00
0005434928248	11042	Economy	3200.00
0005434411704	11042	Economy	3200.00
0005434928249	11042	Economy	3200.00
0005434928251	11042	Economy	3200.00
0005434411703	11042	Economy	3200.00
0005434411701	11042	Economy	3200.00
0005434928250	11042	Economy	3200.00
0005435125688	14685	Business	9500.00
0005435125651	14685	Business	9500.00
0005435556647	14685	Business	9500.00
0005435625861	14685	Business	9500.00
0005435625875	14685	Business	9500.00
0005435125680	14685	Business	9500.00
0005435125675	14685	Business	9500.00
0005435125655	14685	Business	9500.00
0005435125673	14685	Business	9500.00
0005435625859	14685	Business	9500.00
0005435125659	14685	Economy	3200.00
0005435125663	14685	Economy	3200.00
0005435625878	14685	Economy	3200.00
0005435625870	14685	Economy	3200.00
0005435125678	14685	Economy	3200.00
0005435125662	14685	Economy	3200.00
0005435125666	14685	Economy	3200.00
0005435125672	14685	Economy	3200.00
0005435556646	14685	Economy	3200.00
0005435125665	14685	Economy	3500.00
0005435125654	14685	Economy	3500.00
0005435125647	14685	Economy	3200.00
0005435625879	14685	Economy	3200.00
0005435625864	14685	Economy	3200.00
0005435125670	14685	Economy	3200.00
0005435125653	14685	Economy	3200.00
0005435556648	14685	Economy	3200.00
0005435125649	14685	Economy	3200.00
0005435625874	14685	Economy	3200.00
0005435556649	14685	Economy	3200.00
0005435625871	14685	Economy	3200.00
0005435125664	14685	Economy	3200.00
0005435625860	14685	Economy	3200.00
0005435125685	14685	Economy	3200.00
0005435625876	14685	Economy	3200.00
0005435125656	14685	Economy	3200.00
0005435125681	14685	Economy	3200.00
0005435625872	14685	Economy	3200.00
0005435625857	14685	Economy	3200.00
0005435625873	14685	Economy	3200.00
0005435125648	14685	Economy	3200.00
0005435625862	14685	Economy	3200.00
0005435625865	14685	Economy	3200.00
0005435125657	14685	Economy	3200.00
0005435125660	14685	Economy	3200.00
0005435625868	14685	Economy	3200.00
0005435125650	14685	Economy	3200.00
0005435625858	14685	Economy	3200.00
0005435625866	14685	Economy	3200.00
0005435125687	14685	Economy	3200.00
0005435125658	14685	Economy	3200.00
0005435125667	14685	Economy	3200.00
0005435125661	14685	Economy	3200.00
0005435625877	14685	Economy	3200.00
0005435125683	14685	Economy	3200.00
0005435125679	14685	Economy	3200.00
0005435625867	14685	Economy	3200.00
0005435125676	14685	Economy	3200.00
0005435125674	14685	Economy	3200.00
0005435125686	14685	Economy	3200.00
0005435125669	14685	Economy	3200.00
0005435125677	14685	Economy	3200.00
0005435625863	14685	Economy	3200.00
0005435125652	14685	Economy	3200.00
0005435625869	14685	Economy	3200.00
0005435125671	14685	Economy	3200.00
0005435125684	14685	Economy	3200.00
0005435125682	14685	Economy	3200.00
0005435125668	14685	Economy	3200.00
0005432400059	7130	Business	86900.00
0005435715162	7130	Business	86900.00
0005435715170	7130	Economy	29000.00
0005432400056	7130	Economy	29000.00
0005432398131	7130	Economy	29000.00
0005432400060	7130	Economy	29000.00
0005432400057	7130	Economy	31900.00
0005435715169	7130	Economy	31900.00
0005435715174	7130	Economy	29000.00
0005435715161	7130	Economy	29000.00
0005435715173	7130	Economy	29000.00
0005432398129	7130	Economy	29000.00
0005435715175	7130	Economy	29000.00
0005435715171	7130	Economy	29000.00
0005435715163	7130	Economy	29000.00
0005435715168	7130	Economy	29000.00
0005435715165	7130	Economy	29000.00
0005435715172	7130	Economy	29000.00
0005435715176	7130	Economy	29000.00
0005435715167	7130	Economy	29000.00
0005432398130	7130	Economy	29000.00
0005432400058	7130	Economy	29000.00
0005435715166	7130	Economy	29000.00
0005435715164	7130	Economy	29000.00
0005435715160	7130	Economy	29000.00
0005435443144	27055	Business	86900.00
0005435443151	27055	Business	86900.00
0005435443148	27055	Economy	29000.00
0005435443149	27055	Economy	29000.00
0005435443145	27055	Economy	29000.00
0005435443150	27055	Economy	29000.00
0005435443147	27055	Economy	29000.00
0005435443146	27055	Economy	29000.00
0005435443152	27055	Economy	29000.00
0005434084849	2725	Economy	7700.00
0005434084848	2725	Economy	7700.00
0005434084851	2725	Economy	7700.00
0005434084850	2725	Economy	7700.00
0005434084852	2725	Economy	7700.00
0005433060366	28497	Economy	7700.00
0005433060367	28497	Economy	7700.00
0005434906370	2294	Business	20200.00
0005434906375	2294	Business	20200.00
0005434906367	2294	Business	20200.00
0005434906395	2294	Business	20200.00
0005434906366	2294	Economy	6700.00
0005434906397	2294	Economy	6700.00
0005434906402	2294	Economy	6700.00
0005434906372	2294	Economy	7400.00
0005434906359	2294	Economy	7400.00
0005434906365	2294	Economy	6700.00
0005434906361	2294	Economy	6700.00
0005434906391	2294	Economy	6700.00
0005434906374	2294	Economy	6700.00
0005434906387	2294	Economy	6700.00
0005434906380	2294	Economy	6700.00
0005434906362	2294	Economy	6700.00
0005434906379	2294	Economy	6700.00
0005434906392	2294	Economy	6700.00
0005434906400	2294	Economy	6700.00
0005434906364	2294	Economy	6700.00
0005434906386	2294	Economy	6700.00
0005434906376	2294	Economy	6700.00
0005434906378	2294	Economy	6700.00
0005434906393	2294	Economy	6700.00
0005434906373	2294	Economy	6700.00
0005434906371	2294	Economy	6700.00
0005434906396	2294	Economy	6700.00
0005434906382	2294	Economy	6700.00
0005434906406	2294	Economy	6700.00
0005434906377	2294	Economy	6700.00
0005434906388	2294	Economy	6700.00
0005434906405	2294	Economy	6700.00
0005434906401	2294	Economy	6700.00
0005434906369	2294	Economy	6700.00
0005434906404	2294	Economy	6700.00
0005434906363	2294	Economy	6700.00
0005434906398	2294	Economy	6700.00
0005434906385	2294	Economy	6700.00
0005434906399	2294	Economy	6700.00
0005434906390	2294	Economy	6700.00
0005434906383	2294	Economy	6700.00
0005434906394	2294	Economy	6700.00
0005434906360	2294	Economy	6700.00
0005434906381	2294	Economy	6700.00
0005434906384	2294	Economy	6700.00
0005434906368	2294	Economy	6700.00
0005434906403	2294	Economy	6700.00
0005434906389	2294	Economy	6700.00
0005433250950	25591	Business	20200.00
0005433250955	25591	Business	20200.00
0005433250929	25591	Business	20200.00
0005433250945	25591	Economy	6700.00
0005433250938	25591	Economy	6700.00
0005433250940	25591	Economy	7400.00
0005433250931	25591	Economy	7400.00
0005433400929	25591	Economy	7400.00
0005433250928	25591	Economy	6700.00
0005433250949	25591	Economy	6700.00
0005433250935	25591	Economy	6700.00
0005433400930	25591	Economy	6700.00
0005433250944	25591	Economy	6700.00
0005433250933	25591	Economy	6700.00
0005433250934	25591	Economy	6700.00
0005433250954	25591	Economy	6700.00
0005433250937	25591	Economy	6700.00
0005433250943	25591	Economy	6700.00
0005433250957	25591	Economy	6700.00
0005433250947	25591	Economy	6700.00
0005433250941	25591	Economy	6700.00
0005433250930	25591	Economy	6700.00
0005433250948	25591	Economy	6700.00
0005433250956	25591	Economy	6700.00
0005433250932	25591	Economy	6700.00
0005433250936	25591	Economy	6700.00
0005433250942	25591	Economy	6700.00
0005433250951	25591	Economy	6700.00
0005433250927	25591	Economy	6700.00
0005433250952	25591	Economy	6700.00
0005433250946	25591	Economy	6700.00
0005433400931	25591	Economy	6700.00
0005433250958	25591	Economy	6700.00
0005433400932	25591	Economy	6700.00
0005433250939	25591	Economy	6700.00
0005433250953	25591	Economy	6700.00
0005432620788	2525	Economy	13600.00
0005432620793	2525	Economy	13600.00
0005432620792	2525	Economy	12400.00
0005432620796	2525	Economy	12400.00
0005432620790	2525	Economy	12400.00
0005432620799	2525	Economy	12400.00
0005432620789	2525	Economy	12400.00
0005432620795	2525	Economy	12400.00
0005432620794	2525	Economy	12400.00
0005432620798	2525	Economy	12400.00
0005432620787	2525	Economy	12400.00
0005432620786	2525	Economy	12400.00
0005432620797	2525	Economy	12400.00
0005432620791	2525	Economy	12400.00
0005432620800	2525	Economy	12400.00
0005432862166	28066	Economy	12400.00
0005432862167	28066	Economy	12400.00
0005432862165	28066	Economy	12400.00
0005432862169	28066	Economy	12400.00
0005432862168	28066	Economy	12400.00
0005432862162	28066	Economy	12400.00
0005432862163	28066	Economy	12400.00
0005432862164	28066	Economy	12400.00
0005434097449	13030	Economy	11300.00
0005433452703	31031	Economy	8400.00
0005433452702	31031	Economy	8400.00
0005433451583	31031	Economy	8400.00
0005433452701	31031	Economy	8400.00
0005433451582	31031	Economy	8400.00
0005433131627	29863	Economy	7200.00
0005433131626	29863	Economy	6600.00
0005434183543	29863	Economy	6600.00
0005434183545	29863	Economy	6600.00
0005433134059	29863	Economy	6600.00
0005434184630	29863	Economy	6600.00
0005433131628	29863	Economy	6600.00
0005433134056	29863	Economy	6600.00
0005434184629	29863	Economy	6600.00
0005433134057	29863	Economy	6600.00
0005433131629	29863	Economy	6600.00
0005434183544	29863	Economy	6600.00
0005434183546	29863	Economy	6600.00
0005433134058	29863	Economy	6600.00
0005435798915	1611	Economy	17200.00
0005435934992	24740	Economy	18100.00
0005435934993	24740	Economy	18100.00
0005435934994	24740	Economy	18100.00
0005435934995	24740	Economy	18100.00
0005432968802	21642	Economy	4400.00
0005432968801	21642	Economy	4400.00
0005432968803	21642	Economy	4400.00
0005434136717	7350	Business	23100.00
0005434136743	7350	Business	23100.00
0005434136697	7350	Business	23100.00
0005434136694	7350	Business	23100.00
0005434136685	7350	Business	23100.00
0005434136752	7350	Business	23100.00
0005434136755	7350	Business	23100.00
0005434136701	7350	Business	23100.00
0005434136733	7350	Business	23100.00
0005434136702	7350	Business	23100.00
0005434136732	7350	Business	23100.00
0005434136704	7350	Economy	7700.00
0005434136678	7350	Economy	7700.00
0005434136683	7350	Economy	7700.00
0005434136734	7350	Economy	7700.00
0005434136742	7350	Economy	7700.00
0005434136713	7350	Economy	7700.00
0005434136750	7350	Economy	7700.00
0005434136758	7350	Economy	7700.00
0005434087429	7350	Economy	8500.00
0005434136709	7350	Economy	8500.00
0005434136710	7350	Economy	8500.00
0005434136721	7350	Economy	8500.00
0005434136692	7350	Economy	7700.00
0005434136757	7350	Economy	7700.00
0005434136698	7350	Economy	7700.00
0005434136716	7350	Economy	7700.00
0005434136675	7350	Economy	7700.00
0005434136748	7350	Economy	7700.00
0005434136753	7350	Economy	7700.00
0005434136691	7350	Economy	7700.00
0005434136686	7350	Economy	7700.00
0005434136723	7350	Economy	7700.00
0005434136722	7350	Economy	7700.00
0005434136736	7350	Economy	7700.00
0005434136741	7350	Economy	7700.00
0005434087428	7350	Economy	7700.00
0005434136726	7350	Economy	7700.00
0005434136688	7350	Economy	7700.00
0005434136676	7350	Economy	7700.00
0005434136693	7350	Economy	7700.00
0005434136700	7350	Economy	7700.00
0005434136744	7350	Economy	7700.00
0005434136679	7350	Economy	7700.00
0005434136759	7350	Economy	7700.00
0005434136687	7350	Economy	7700.00
0005434136728	7350	Economy	7700.00
0005434136705	7350	Economy	7700.00
0005434136756	7350	Economy	7700.00
0005434136695	7350	Economy	7700.00
0005434136719	7350	Economy	7700.00
0005434136681	7350	Economy	7700.00
0005434136684	7350	Economy	7700.00
0005434087427	7350	Economy	7700.00
0005434136751	7350	Economy	7700.00
0005434136746	7350	Economy	7700.00
0005434136731	7350	Economy	7700.00
0005434136738	7350	Economy	7700.00
0005434136745	7350	Economy	7700.00
0005434136718	7350	Economy	7700.00
0005434136714	7350	Economy	7700.00
0005434136740	7350	Economy	7700.00
0005434136725	7350	Economy	7700.00
0005434136707	7350	Economy	7700.00
0005434136737	7350	Economy	7700.00
0005434136720	7350	Economy	7700.00
0005434136708	7350	Economy	7700.00
0005434136727	7350	Economy	7700.00
0005434136729	7350	Economy	7700.00
0005434136703	7350	Economy	7700.00
0005434136730	7350	Economy	7700.00
0005434087430	7350	Economy	7700.00
0005434136690	7350	Economy	7700.00
0005434136711	7350	Economy	7700.00
0005434136682	7350	Economy	7700.00
0005434136689	7350	Economy	7700.00
0005434136739	7350	Economy	7700.00
0005434136706	7350	Economy	7700.00
0005434136680	7350	Economy	7700.00
0005434136712	7350	Economy	7700.00
0005434136677	7350	Economy	7700.00
0005434136754	7350	Economy	7700.00
0005434136696	7350	Economy	7700.00
0005434136749	7350	Economy	7700.00
0005434136699	7350	Economy	7700.00
0005434136747	7350	Economy	7700.00
0005434136735	7350	Economy	7700.00
0005434136715	7350	Economy	7700.00
0005434136724	7350	Economy	7700.00
0005435808052	1943	Economy	21700.00
0005435808054	1943	Economy	21700.00
0005435808055	1943	Economy	21700.00
0005435808058	1943	Economy	21700.00
0005434610167	1943	Economy	21700.00
0005435808049	1943	Economy	21700.00
0005435808051	1943	Economy	21700.00
0005434610166	1943	Economy	21700.00
0005435808050	1943	Economy	21700.00
0005435808059	1943	Economy	21700.00
0005435808057	1943	Economy	21700.00
0005435808053	1943	Economy	21700.00
0005435808056	1943	Economy	21700.00
0005434608276	6496	Economy	17300.00
0005434608277	6496	Economy	17300.00
0005435078071	2231	Economy	7700.00
0005435078075	2231	Economy	7000.00
0005435078079	2231	Economy	7000.00
0005435078069	2231	Economy	7000.00
0005435078070	2231	Economy	7000.00
0005435078063	2231	Economy	7000.00
0005435078072	2231	Economy	7000.00
0005435078068	2231	Economy	7000.00
0005435078064	2231	Economy	7000.00
0005435078065	2231	Economy	7000.00
0005435078076	2231	Economy	7000.00
0005435078078	2231	Economy	7000.00
0005435078077	2231	Economy	7000.00
0005435078067	2231	Economy	7000.00
0005435078074	2231	Economy	7000.00
0005435078073	2231	Economy	7000.00
0005435078066	2231	Economy	7000.00
0005433266564	24372	Economy	7700.00
0005433266562	24372	Economy	7700.00
0005433266563	24372	Economy	7000.00
0005433266565	24372	Economy	7000.00
0005433266559	24372	Economy	7000.00
0005433266561	24372	Economy	7000.00
0005433266560	24372	Economy	7000.00
0005433266557	24372	Economy	7000.00
0005433266558	24372	Economy	7000.00
0005433266566	24372	Economy	7000.00
0005433266556	24372	Economy	7000.00
0005434988556	6650	Economy	10800.00
0005435803211	6650	Economy	10800.00
0005435803210	6650	Economy	9800.00
0005434988555	6650	Economy	9800.00
0005434988559	6650	Economy	9800.00
0005434988563	6650	Economy	9800.00
0005434988561	6650	Economy	9800.00
0005434988558	6650	Economy	9800.00
0005434988557	6650	Economy	9800.00
0005435803212	6650	Economy	9800.00
0005434988564	6650	Economy	9800.00
0005434988562	6650	Economy	9800.00
0005435803213	6650	Economy	9800.00
0005434988560	6650	Economy	9800.00
0005435464473	23602	Economy	9800.00
0005435464472	23602	Economy	9800.00
0005432382491	30471	Business	9900.00
0005433449593	30471	Business	9900.00
0005432382518	30471	Business	9900.00
0005433449595	30471	Business	9900.00
0005433449599	30471	Business	9900.00
0005433449600	30471	Business	9900.00
0005432382487	30471	Business	9900.00
0005432382485	30471	Business	9900.00
0005432382519	30471	Business	9900.00
0005432382495	30471	Economy	3300.00
0005433454838	30471	Economy	3300.00
0005433449586	30471	Economy	3300.00
0005432382505	30471	Economy	3300.00
0005432382493	30471	Economy	3300.00
0005433449589	30471	Economy	3300.00
0005433454837	30471	Economy	3300.00
0005432382501	30471	Economy	3600.00
0005433449588	30471	Economy	3600.00
0005432382499	30471	Economy	3600.00
0005432382514	30471	Economy	3600.00
0005432382510	30471	Economy	3300.00
0005432382484	30471	Economy	3300.00
0005433449596	30471	Economy	3300.00
0005433449594	30471	Economy	3300.00
0005432382490	30471	Economy	3300.00
0005432382492	30471	Economy	3300.00
0005433449590	30471	Economy	3300.00
0005432382496	30471	Economy	3300.00
0005432382506	30471	Economy	3300.00
0005433449605	30471	Economy	3300.00
0005433449584	30471	Economy	3300.00
0005432382515	30471	Economy	3300.00
0005433449592	30471	Economy	3300.00
0005433449604	30471	Economy	3300.00
0005432382500	30471	Economy	3300.00
0005433449603	30471	Economy	3300.00
0005433449591	30471	Economy	3300.00
0005432382520	30471	Economy	3300.00
0005432382498	30471	Economy	3300.00
0005433449583	30471	Economy	3300.00
0005432382504	30471	Economy	3300.00
0005432382508	30471	Economy	3300.00
0005432382513	30471	Economy	3300.00
0005432382489	30471	Economy	3300.00
0005433449587	30471	Economy	3300.00
0005433453727	30471	Economy	3300.00
0005433449597	30471	Economy	3300.00
0005432382488	30471	Economy	3300.00
0005432382486	30471	Economy	3300.00
0005432382517	30471	Economy	3300.00
0005433449602	30471	Economy	3300.00
0005432382516	30471	Economy	3300.00
0005432382497	30471	Economy	3300.00
0005432382502	30471	Economy	3300.00
0005433449598	30471	Economy	3300.00
0005432382511	30471	Economy	3300.00
0005432382509	30471	Economy	3300.00
0005432382507	30471	Economy	3300.00
0005432382503	30471	Economy	3300.00
0005432382494	30471	Economy	3300.00
0005433449585	30471	Economy	3300.00
0005433453726	30471	Economy	3300.00
0005433449601	30471	Economy	3300.00
0005432382512	30471	Economy	3300.00
0005435299698	29743	Economy	17100.00
0005435302120	29743	Economy	17100.00
0005433126769	29743	Economy	17100.00
0005435302119	29743	Economy	15600.00
0005433129199	29743	Economy	15600.00
0005435299697	29743	Economy	15600.00
0005433126768	29743	Economy	15600.00
0005435299696	29743	Economy	15600.00
0005433126771	29743	Economy	15600.00
0005435299699	29743	Economy	15600.00
0005435302123	29743	Economy	15600.00
0005433129198	29743	Economy	15600.00
0005433129201	29743	Economy	15600.00
0005433129200	29743	Economy	15600.00
0005435302122	29743	Economy	15600.00
0005433126770	29743	Economy	15600.00
0005435302121	29743	Economy	15600.00
0005434286911	2412	Economy	17200.00
0005434286899	2412	Economy	17200.00
0005434286894	2412	Economy	15700.00
0005434286895	2412	Economy	15700.00
0005434286905	2412	Economy	15700.00
0005434286912	2412	Economy	15700.00
0005434286900	2412	Economy	15700.00
0005434286914	2412	Economy	15700.00
0005434286892	2412	Economy	15700.00
0005434286893	2412	Economy	15700.00
0005434286909	2412	Economy	15700.00
0005432264431	2412	Economy	15700.00
0005434286910	2412	Economy	15700.00
0005432264432	2412	Economy	15700.00
0005434286901	2412	Economy	15700.00
0005434286896	2412	Economy	15700.00
0005434286903	2412	Economy	15700.00
0005432264433	2412	Economy	15700.00
0005434286898	2412	Economy	15700.00
0005434286897	2412	Economy	15700.00
0005434286906	2412	Economy	15700.00
0005434286902	2412	Economy	15700.00
0005434286913	2412	Economy	15700.00
0005434286904	2412	Economy	15700.00
0005434286907	2412	Economy	15700.00
0005434286908	2412	Economy	15700.00
0005433109843	26879	Economy	15700.00
0005433109846	26879	Economy	15700.00
0005433109845	26879	Economy	15700.00
0005433109847	26879	Economy	15700.00
0005433109837	26879	Economy	15700.00
0005433109848	26879	Economy	15700.00
0005433109841	26879	Economy	15700.00
0005433109844	26879	Economy	15700.00
0005433109842	26879	Economy	15700.00
0005433109840	26879	Economy	15700.00
0005433109839	26879	Economy	15700.00
0005433109838	26879	Economy	15700.00
0005435856133	25496	Economy	22800.00
0005435856130	25496	Economy	22800.00
0005435856131	25496	Economy	22800.00
0005435856132	25496	Economy	22800.00
0005434273046	26658	Economy	22800.00
0005434272161	26658	Economy	22800.00
0005434273047	26658	Economy	22800.00
0005434272162	26658	Economy	22800.00
0005435314767	19070	Economy	22300.00
0005435314769	19070	Economy	22300.00
0005435314770	19070	Economy	22300.00
0005435314768	19070	Economy	22300.00
0005435314771	19070	Economy	22300.00
0005433874293	7786	Economy	17400.00
0005433874292	7786	Economy	17400.00
0005433874291	7786	Economy	17400.00
0005433867752	4809	Economy	19400.00
0005433867734	4809	Economy	19400.00
0005433867757	4809	Economy	19400.00
0005433867751	4809	Economy	19400.00
0005433867740	4809	Economy	17600.00
0005433867755	4809	Economy	17600.00
0005433867732	4809	Economy	17600.00
0005433867731	4809	Economy	17600.00
0005433867739	4809	Economy	17600.00
0005433867762	4809	Economy	17600.00
0005433867754	4809	Economy	17600.00
0005433867748	4809	Economy	17600.00
0005433867749	4809	Economy	17600.00
0005433867766	4809	Economy	17600.00
0005433867728	4809	Economy	17600.00
0005433867746	4809	Economy	17600.00
0005433867733	4809	Economy	17600.00
0005433867730	4809	Economy	17600.00
0005433867735	4809	Economy	17600.00
0005433867753	4809	Economy	17600.00
0005433867767	4809	Economy	17600.00
0005433867741	4809	Economy	17600.00
0005433867737	4809	Economy	17600.00
0005433867729	4809	Economy	17600.00
0005433867761	4809	Economy	17600.00
0005433867747	4809	Economy	17600.00
0005433867756	4809	Economy	17600.00
0005433867763	4809	Economy	17600.00
0005433867768	4809	Economy	17600.00
0005433867727	4809	Economy	17600.00
0005433867760	4809	Economy	17600.00
0005433867736	4809	Economy	17600.00
0005433867742	4809	Economy	17600.00
0005433867743	4809	Economy	17600.00
0005433867745	4809	Economy	17600.00
0005433867764	4809	Economy	17600.00
0005433867750	4809	Economy	17600.00
0005433867738	4809	Economy	17600.00
0005433867769	4809	Economy	17600.00
0005433867765	4809	Economy	17600.00
0005433867758	4809	Economy	17600.00
0005433867744	4809	Economy	17600.00
0005433867759	4809	Economy	17600.00
0005434663174	3415	Economy	24800.00
0005434663168	3415	Economy	22600.00
0005434461608	3415	Economy	22600.00
0005434663172	3415	Economy	22600.00
0005434460466	3415	Economy	22600.00
0005434663169	3415	Economy	22600.00
0005434663166	3415	Economy	22600.00
0005434663176	3415	Economy	22600.00
0005434461609	3415	Economy	22600.00
0005434663165	3415	Economy	22600.00
0005434663173	3415	Economy	22600.00
0005434461610	3415	Economy	22600.00
0005434460467	3415	Economy	22600.00
0005434663175	3415	Economy	22600.00
0005434663178	3415	Economy	22600.00
0005434663167	3415	Economy	22600.00
0005434663171	3415	Economy	22600.00
0005434663170	3415	Economy	22600.00
0005434663177	3415	Economy	22600.00
0005434460468	3415	Economy	22600.00
0005435911321	12445	Economy	22600.00
0005435911315	12445	Economy	22600.00
0005435911316	12445	Economy	22600.00
0005435911322	12445	Economy	22600.00
0005435911319	12445	Economy	22600.00
0005435911317	12445	Economy	22600.00
0005435911320	12445	Economy	22600.00
0005435911318	12445	Economy	22600.00
0005432153818	7072	Business	49100.00
0005434406677	7072	Business	49100.00
0005434299162	7072	Business	49100.00
0005434406659	7072	Business	49100.00
0005434299151	7072	Business	49100.00
0005434406691	7072	Business	49100.00
0005434406673	7072	Business	49100.00
0005434406658	7072	Business	49100.00
0005434299154	7072	Economy	16400.00
0005434406676	7072	Economy	16400.00
0005434299152	7072	Economy	16400.00
0005434406696	7072	Economy	16400.00
0005434406681	7072	Economy	16400.00
0005434406657	7072	Economy	16400.00
0005434406660	7072	Economy	16400.00
0005434299160	7072	Economy	16400.00
0005434406668	7072	Economy	16400.00
0005434406678	7072	Economy	16400.00
0005434299147	7072	Economy	16400.00
0005432153815	7072	Economy	16400.00
0005434299150	7072	Economy	16400.00
0005434406669	7072	Economy	16400.00
0005434406701	7072	Economy	16400.00
0005434406682	7072	Economy	16400.00
0005434406644	7072	Economy	16400.00
0005432153817	7072	Economy	16400.00
0005434406646	7072	Economy	16400.00
0005432153819	7072	Economy	16400.00
0005434299155	7072	Economy	16400.00
0005434406684	7072	Economy	16400.00
0005434406653	7072	Economy	16400.00
0005434406698	7072	Economy	16400.00
0005432153814	7072	Economy	16400.00
0005434406656	7072	Economy	16400.00
0005434406665	7072	Economy	16400.00
0005434406639	7072	Economy	16400.00
0005434406687	7072	Economy	18000.00
0005434406670	7072	Economy	18000.00
0005434406672	7072	Economy	18000.00
0005434406690	7072	Economy	18000.00
0005434406699	7072	Economy	18000.00
0005434406695	7072	Economy	16400.00
0005434406645	7072	Economy	16400.00
0005434406685	7072	Economy	16400.00
0005434406664	7072	Economy	16400.00
0005434406640	7072	Economy	16400.00
0005434406679	7072	Economy	16400.00
0005434299158	7072	Economy	16400.00
0005434406680	7072	Economy	16400.00
0005434406649	7072	Economy	16400.00
0005434299163	7072	Economy	16400.00
0005434406697	7072	Economy	16400.00
0005434406655	7072	Economy	16400.00
0005432153813	7072	Economy	16400.00
0005434299166	7072	Economy	16400.00
0005432153816	7072	Economy	16400.00
0005434406675	7072	Economy	16400.00
0005434406650	7072	Economy	16400.00
0005434299168	7072	Economy	16400.00
0005434406663	7072	Economy	16400.00
0005434406700	7072	Economy	16400.00
0005434406642	7072	Economy	16400.00
0005434299164	7072	Economy	16400.00
0005434406661	7072	Economy	16400.00
0005432108205	7072	Economy	16400.00
0005434406688	7072	Economy	16400.00
0005434406643	7072	Economy	16400.00
0005434299165	7072	Economy	16400.00
0005434299167	7072	Economy	16400.00
0005434406667	7072	Economy	16400.00
0005434406652	7072	Economy	16400.00
0005434406654	7072	Economy	16400.00
0005434299161	7072	Economy	16400.00
0005432108206	7072	Economy	16400.00
0005434299159	7072	Economy	16400.00
0005434406647	7072	Economy	16400.00
0005434406648	7072	Economy	16400.00
0005434299169	7072	Economy	16400.00
0005434406666	7072	Economy	16400.00
0005434299157	7072	Economy	16400.00
0005432108204	7072	Economy	16400.00
0005434406686	7072	Economy	16400.00
0005434299156	7072	Economy	16400.00
0005434406692	7072	Economy	16400.00
0005434406671	7072	Economy	16400.00
0005434406689	7072	Economy	16400.00
0005434299149	7072	Economy	16400.00
0005434406651	7072	Economy	16400.00
0005434406693	7072	Economy	16400.00
0005434406641	7072	Economy	16400.00
0005434299148	7072	Economy	16400.00
0005434299153	7072	Economy	16400.00
0005434406674	7072	Economy	16400.00
0005434406683	7072	Economy	16400.00
0005434406662	7072	Economy	16400.00
0005434406694	7072	Economy	16400.00
0005435293048	26885	Business	49100.00
0005435293050	26885	Business	49100.00
0005435293054	26885	Economy	16400.00
0005435293049	26885	Economy	16400.00
0005435293055	26885	Economy	16400.00
0005435293051	26885	Economy	16400.00
0005435293053	26885	Economy	16400.00
0005435293046	26885	Economy	16400.00
0005435293052	26885	Economy	16400.00
0005435293047	26885	Economy	16400.00
0005435293056	26885	Economy	16400.00
0005435293045	26885	Economy	16400.00
0005432603662	6446	Economy	16500.00
0005432603673	6446	Economy	16500.00
0005432603668	6446	Economy	16500.00
0005432603657	6446	Economy	16500.00
0005432603681	6446	Economy	15000.00
0005432603672	6446	Economy	15000.00
0005432603674	6446	Economy	15000.00
0005432603669	6446	Economy	15000.00
0005432603642	6446	Economy	15000.00
0005432603648	6446	Economy	15000.00
0005432603679	6446	Economy	15000.00
0005432603647	6446	Economy	15000.00
0005434512019	6446	Economy	15000.00
0005434512017	6446	Economy	15000.00
0005432603654	6446	Economy	15000.00
0005432603664	6446	Economy	15000.00
0005432603680	6446	Economy	15000.00
0005432603677	6446	Economy	15000.00
0005432603656	6446	Economy	15000.00
0005432603675	6446	Economy	15000.00
0005432603660	6446	Economy	15000.00
0005432603651	6446	Economy	15000.00
0005432603667	6446	Economy	15000.00
0005432603665	6446	Economy	15000.00
0005432603661	6446	Economy	15000.00
0005434512016	6446	Economy	15000.00
0005432603646	6446	Economy	15000.00
0005432603666	6446	Economy	15000.00
0005434512021	6446	Economy	15000.00
0005434512015	6446	Economy	15000.00
0005434512018	6446	Economy	15000.00
0005432603643	6446	Economy	15000.00
0005434512020	6446	Economy	15000.00
0005432603655	6446	Economy	15000.00
0005432603670	6446	Economy	15000.00
0005432603678	6446	Economy	15000.00
0005432603658	6446	Economy	15000.00
0005432603645	6446	Economy	15000.00
0005432603644	6446	Economy	15000.00
0005432603671	6446	Economy	15000.00
0005432603650	6446	Economy	15000.00
0005432603676	6446	Economy	15000.00
0005432603663	6446	Economy	15000.00
0005432603653	6446	Economy	15000.00
0005432603649	6446	Economy	15000.00
0005432603652	6446	Economy	15000.00
0005432603659	6446	Economy	15000.00
0005435221035	21383	Economy	15000.00
0005435221497	21383	Economy	15000.00
0005435221036	21383	Economy	15000.00
0005433250932	15025	Business	18900.00
0005433250946	15025	Business	18900.00
0005433250928	15025	Business	18900.00
0005433250937	15025	Business	18900.00
0005433250938	15025	Business	18900.00
0005433250956	15025	Business	18900.00
0005433250949	15025	Economy	6300.00
0005433250954	15025	Economy	6300.00
0005433250934	15025	Economy	6900.00
0005433250947	15025	Economy	6300.00
0005433250931	15025	Economy	6300.00
0005433250943	15025	Economy	6300.00
0005433250942	15025	Economy	6300.00
0005433250948	15025	Economy	6300.00
0005433250957	15025	Economy	6300.00
0005433250929	15025	Economy	6300.00
0005433250935	15025	Economy	6300.00
0005433250944	15025	Economy	6300.00
0005433250952	15025	Economy	6300.00
0005433250951	15025	Economy	6300.00
0005433250950	15025	Economy	6300.00
0005433250933	15025	Economy	6300.00
0005433250945	15025	Economy	6300.00
0005433250955	15025	Economy	6300.00
0005433250927	15025	Economy	6300.00
0005433250940	15025	Economy	6300.00
0005433250936	15025	Economy	6300.00
0005433250941	15025	Economy	6300.00
0005433250958	15025	Economy	6300.00
0005433250939	15025	Economy	6300.00
0005433250953	15025	Economy	6300.00
0005433250930	15025	Economy	6300.00
0005433007840	14158	Business	52300.00
0005433007824	14158	Business	52300.00
0005433007835	14158	Business	52300.00
0005433007825	14158	Business	52300.00
0005433007860	14158	Business	52300.00
0005433007845	14158	Business	52300.00
0005433007864	14158	Business	52300.00
0005433007832	14158	Economy	17400.00
0005433007855	14158	Economy	17400.00
0005433007829	14158	Economy	17400.00
0005433007827	14158	Economy	17400.00
0005433007830	14158	Economy	17400.00
0005433007863	14158	Economy	19200.00
0005433007848	14158	Economy	19200.00
0005433007822	14158	Economy	17400.00
0005433007843	14158	Economy	17400.00
0005433007851	14158	Economy	17400.00
0005433007847	14158	Economy	17400.00
0005433007852	14158	Economy	17400.00
0005433007867	14158	Economy	17400.00
0005433007865	14158	Economy	17400.00
0005433007841	14158	Economy	17400.00
0005433007859	14158	Economy	17400.00
0005433007842	14158	Economy	17400.00
0005433007853	14158	Economy	17400.00
0005433007833	14158	Economy	17400.00
0005433007861	14158	Economy	17400.00
0005433007850	14158	Economy	17400.00
0005433007826	14158	Economy	17400.00
0005433007831	14158	Economy	17400.00
0005433007838	14158	Economy	17400.00
0005433007862	14158	Economy	17400.00
0005433007837	14158	Economy	17400.00
0005433007839	14158	Economy	17400.00
0005433007858	14158	Economy	17400.00
0005433007857	14158	Economy	17400.00
0005433007836	14158	Economy	17400.00
0005433007828	14158	Economy	17400.00
0005433007856	14158	Economy	17400.00
0005433007854	14158	Economy	17400.00
0005433007849	14158	Economy	17400.00
0005433007866	14158	Economy	17400.00
0005433007844	14158	Economy	17400.00
0005433007834	14158	Economy	17400.00
0005433007823	14158	Economy	17400.00
0005433007846	14158	Economy	17400.00
0005435487465	15791	Economy	8900.00
0005435487470	15791	Economy	8900.00
0005435487462	15791	Economy	8100.00
0005435487458	15791	Economy	8100.00
0005435487454	15791	Economy	8100.00
0005435487471	15791	Economy	8100.00
0005435487461	15791	Economy	8100.00
0005435487468	15791	Economy	8100.00
0005435487464	15791	Economy	8100.00
0005435487456	15791	Economy	8100.00
0005435487469	15791	Economy	8100.00
0005435487459	15791	Economy	8100.00
0005435487460	15791	Economy	8100.00
0005435487463	15791	Economy	8100.00
0005435487453	15791	Economy	8100.00
0005435487467	15791	Economy	8100.00
0005435487457	15791	Economy	8100.00
0005435487455	15791	Economy	8100.00
0005435487473	15791	Economy	8100.00
0005435487472	15791	Economy	8100.00
0005435487466	15791	Economy	8100.00
0005435487474	15791	Economy	8100.00
0005435838963	5995	Business	199300.00
0005435838980	5995	Business	199300.00
0005435838962	5995	Business	199300.00
0005432659671	5995	Business	199300.00
0005432142198	5995	Business	199300.00
0005435838958	5995	Business	199300.00
0005432142199	5995	Economy	66400.00
0005432658556	5995	Economy	66400.00
0005435838969	5995	Economy	66400.00
0005432142201	5995	Economy	73100.00
0005435838978	5995	Economy	73100.00
0005435838973	5995	Economy	66400.00
0005432142197	5995	Economy	66400.00
0005435838964	5995	Economy	66400.00
0005435838975	5995	Economy	66400.00
0005432659672	5995	Economy	66400.00
0005435838961	5995	Economy	66400.00
0005435838979	5995	Economy	66400.00
0005435838984	5995	Economy	66400.00
0005435838960	5995	Economy	66400.00
0005435838971	5995	Economy	66400.00
0005435838966	5995	Economy	66400.00
0005435838983	5995	Economy	66400.00
0005435838985	5995	Economy	66400.00
0005435838982	5995	Economy	66400.00
0005435838972	5995	Economy	66400.00
0005435838965	5995	Economy	66400.00
0005435838981	5995	Economy	66400.00
0005435838959	5995	Economy	66400.00
0005432142200	5995	Economy	66400.00
0005435838970	5995	Economy	66400.00
0005435838968	5995	Economy	66400.00
0005435838974	5995	Economy	66400.00
0005435838976	5995	Economy	66400.00
0005435838977	5995	Economy	66400.00
0005432658557	5995	Economy	66400.00
0005432658555	5995	Economy	66400.00
0005435838967	5995	Economy	66400.00
0005435472516	18069	Business	199300.00
0005435472521	18069	Business	199300.00
0005435472513	18069	Business	199300.00
0005432537022	18069	Business	199300.00
0005435472525	18069	Economy	66400.00
0005435472512	18069	Economy	66400.00
0005435472515	18069	Economy	73100.00
0005435472523	18069	Economy	66400.00
0005435472511	18069	Economy	66400.00
0005435472522	18069	Economy	66400.00
0005435472526	18069	Economy	66400.00
0005435472519	18069	Economy	66400.00
0005435472524	18069	Economy	66400.00
0005435472520	18069	Economy	66400.00
0005435472517	18069	Economy	66400.00
0005435472528	18069	Economy	66400.00
0005435472527	18069	Economy	66400.00
0005435472518	18069	Economy	66400.00
0005435472514	18069	Economy	66400.00
0005433463862	17263	Business	146400.00
0005433462709	17263	Economy	48800.00
0005433462708	17263	Economy	48800.00
0005433463863	17263	Economy	48800.00
0005433463861	17263	Economy	48800.00
0005433284791	32042	Business	15700.00
0005433284772	32042	Business	15700.00
0005433284792	32042	Business	15700.00
0005433284777	32042	Economy	5200.00
0005433284774	32042	Economy	5200.00
0005433284783	32042	Economy	5200.00
0005433284778	32042	Economy	5200.00
0005433284794	32042	Economy	5200.00
0005433284787	32042	Economy	5200.00
0005433284770	32042	Economy	5200.00
0005433284785	32042	Economy	5200.00
0005433284776	32042	Economy	5200.00
0005433284773	32042	Economy	5200.00
0005433284782	32042	Economy	5200.00
0005433284788	32042	Economy	5200.00
0005433284779	32042	Economy	5200.00
0005433284771	32042	Economy	5200.00
0005433284784	32042	Economy	5200.00
0005433284790	32042	Economy	5200.00
0005433284786	32042	Economy	5200.00
0005433284769	32042	Economy	5200.00
0005433284793	32042	Economy	5200.00
0005433284789	32042	Economy	5200.00
0005433284781	32042	Economy	5200.00
0005433284780	32042	Economy	5200.00
0005433284775	32042	Economy	5200.00
0005433656615	30589	Business	42100.00
0005432159779	30589	Business	42100.00
0005435212416	30589	Business	42100.00
0005432211378	30589	Business	42100.00
0005435212420	30589	Business	42100.00
0005432159781	30589	Business	42100.00
0005435212426	30589	Business	42100.00
0005435630917	30589	Business	42100.00
0005435212405	30589	Business	42100.00
0005435212438	30589	Business	42100.00
0005435212452	30589	Business	42100.00
0005435212400	30589	Comfort	23900.00
0005435212422	30589	Comfort	23900.00
0005435212419	30589	Comfort	23900.00
0005435212454	30589	Comfort	23900.00
0005435212459	30589	Comfort	23900.00
0005435212403	30589	Comfort	23900.00
0005435212429	30589	Comfort	23900.00
0005435212404	30589	Comfort	23900.00
0005432211379	30589	Comfort	23900.00
0005435212428	30589	Economy	14000.00
0005435212445	30589	Economy	14000.00
0005432211377	30589	Economy	14000.00
0005435212406	30589	Economy	14000.00
0005435212464	30589	Economy	14000.00
0005435212451	30589	Economy	14000.00
0005435212447	30589	Economy	14000.00
0005435212424	30589	Economy	14000.00
0005435212441	30589	Economy	14000.00
0005432211375	30589	Economy	14000.00
0005432211376	30589	Economy	14000.00
0005435212463	30589	Economy	14000.00
0005435212461	30589	Economy	14000.00
0005435212397	30589	Economy	14000.00
0005435212433	30589	Economy	14000.00
0005435212413	30589	Economy	14000.00
0005433656616	30589	Economy	14000.00
0005435212423	30589	Economy	14000.00
0005435212409	30589	Economy	14000.00
0005435725520	30589	Economy	14000.00
0005435212458	30589	Economy	15400.00
0005435630918	30589	Economy	14000.00
0005435212443	30589	Economy	14000.00
0005435212462	30589	Economy	15400.00
0005433656617	30589	Economy	14000.00
0005432159780	30589	Economy	14000.00
0005432211373	30589	Economy	14000.00
0005435212457	30589	Economy	14000.00
0005432211374	30589	Economy	14000.00
0005435212448	30589	Economy	14000.00
0005435212418	30589	Economy	14000.00
0005435212407	30589	Economy	14000.00
0005435212430	30589	Economy	14000.00
0005435212434	30589	Economy	14000.00
0005435212450	30589	Economy	14000.00
0005435212437	30589	Economy	14000.00
0005435212408	30589	Economy	14000.00
0005435725517	30589	Economy	14000.00
0005435212444	30589	Economy	14000.00
0005435212466	30589	Economy	14000.00
0005435212411	30589	Economy	14000.00
0005435212432	30589	Economy	14000.00
0005435212412	30589	Economy	14000.00
0005435212427	30589	Economy	14000.00
0005435212440	30589	Economy	14000.00
0005435212442	30589	Economy	14000.00
0005435212446	30589	Economy	14000.00
0005435212439	30589	Economy	14000.00
0005435212410	30589	Economy	14000.00
0005435212431	30589	Economy	14000.00
0005435212401	30589	Economy	14000.00
0005432159783	30589	Economy	14000.00
0005435212421	30589	Economy	14000.00
0005432159782	30589	Economy	14000.00
0005435212460	30589	Economy	14000.00
0005435212455	30589	Economy	14000.00
0005435212415	30589	Economy	14000.00
0005435725519	30589	Economy	14000.00
0005435212398	30589	Economy	14000.00
0005435212436	30589	Economy	14000.00
0005435725518	30589	Economy	14000.00
0005435212414	30589	Economy	14000.00
0005435212399	30589	Economy	14000.00
0005435212425	30589	Economy	14000.00
0005435212402	30589	Economy	14000.00
0005435212435	30589	Economy	14000.00
0005435212453	30589	Economy	14000.00
0005432211380	30589	Economy	14000.00
0005435212456	30589	Economy	14000.00
0005435212417	30589	Economy	14000.00
0005435212465	30589	Economy	14000.00
0005435212449	30589	Economy	14000.00
0005433367281	24833	Business	9800.00
0005433367289	24833	Business	9800.00
0005433367277	24833	Business	9800.00
0005433367275	24833	Business	9800.00
0005433367271	24833	Business	9800.00
0005433367278	24833	Economy	3300.00
0005433367288	24833	Economy	3300.00
0005433367284	24833	Economy	3300.00
0005433367272	24833	Economy	3300.00
0005433367268	24833	Economy	3600.00
0005433367290	24833	Economy	3600.00
0005433367292	24833	Economy	3600.00
0005433367293	24833	Economy	3300.00
0005433367270	24833	Economy	3300.00
0005433367266	24833	Economy	3300.00
0005433367273	24833	Economy	3300.00
0005433367285	24833	Economy	3300.00
0005433367261	24833	Economy	3300.00
0005433367263	24833	Economy	3300.00
0005433367291	24833	Economy	3300.00
0005433367267	24833	Economy	3300.00
0005433367264	24833	Economy	3300.00
0005433367262	24833	Economy	3300.00
0005433367274	24833	Economy	3300.00
0005433367294	24833	Economy	3300.00
0005433367279	24833	Economy	3300.00
0005433367260	24833	Economy	3300.00
0005433367286	24833	Economy	3300.00
0005433367280	24833	Economy	3300.00
0005433367287	24833	Economy	3300.00
0005433367265	24833	Economy	3300.00
0005433367282	24833	Economy	3300.00
0005433367276	24833	Economy	3300.00
0005433367269	24833	Economy	3300.00
0005433367283	24833	Economy	3300.00
0005433367259	24833	Economy	3300.00
0005434979294	2032	Economy	10500.00
0005434979286	2032	Economy	10500.00
0005434979288	2032	Economy	9500.00
0005434979313	2032	Economy	9500.00
0005434979299	2032	Economy	9500.00
0005434979312	2032	Economy	9500.00
0005434979308	2032	Economy	9500.00
0005434979309	2032	Economy	9500.00
0005435801647	2032	Economy	9500.00
0005434979300	2032	Economy	9500.00
0005434979296	2032	Economy	9500.00
0005434979284	2032	Economy	9500.00
0005434979287	2032	Economy	9500.00
0005434979306	2032	Economy	9500.00
0005435801645	2032	Economy	9500.00
0005434979297	2032	Economy	9500.00
0005434979301	2032	Economy	9500.00
0005434979289	2032	Economy	9500.00
0005434979290	2032	Economy	9500.00
0005434979292	2032	Economy	9500.00
0005434979303	2032	Economy	9500.00
0005434979295	2032	Economy	9500.00
0005434979283	2032	Economy	9500.00
0005434979310	2032	Economy	9500.00
0005434979298	2032	Economy	9500.00
0005434979305	2032	Economy	9500.00
0005434979293	2032	Economy	9500.00
0005434979285	2032	Economy	9500.00
0005434979302	2032	Economy	9500.00
0005434979291	2032	Economy	9500.00
0005434979311	2032	Economy	9500.00
0005434979304	2032	Economy	9500.00
0005434979307	2032	Economy	9500.00
0005435801646	2032	Economy	9500.00
0005434952468	2569	Economy	5300.00
0005434952470	2569	Economy	5300.00
0005434952469	2569	Economy	5300.00
0005433256384	28267	Economy	5300.00
0005433256385	28267	Economy	5300.00
0005433256383	28267	Economy	5300.00
0005433111470	19841	Economy	8700.00
0005433111471	19841	Economy	8700.00
0005434136687	28737	Business	9700.00
0005434136723	28737	Business	9700.00
0005434136742	28737	Business	9700.00
0005434136727	28737	Business	9700.00
0005434136751	28737	Business	9700.00
0005434136721	28737	Business	9700.00
0005434136733	28737	Business	9700.00
0005434136696	28737	Business	9700.00
0005434136729	28737	Business	9700.00
0005434136736	28737	Business	9700.00
0005434136722	28737	Business	9700.00
0005434136699	28737	Business	9700.00
0005434136689	28737	Economy	3200.00
0005434136693	28737	Economy	3200.00
0005434136678	28737	Economy	3200.00
0005434136745	28737	Economy	3200.00
0005434136704	28737	Economy	3200.00
0005434136757	28737	Economy	3200.00
0005434136713	28737	Economy	3200.00
0005434136717	28737	Economy	3200.00
0005434136739	28737	Economy	3500.00
0005434136706	28737	Economy	3500.00
0005434136724	28737	Economy	3500.00
0005434136691	28737	Economy	3500.00
0005434136683	28737	Economy	3500.00
0005434136680	28737	Economy	3200.00
0005434136754	28737	Economy	3200.00
0005434136701	28737	Economy	3200.00
0005434136707	28737	Economy	3200.00
0005434136716	28737	Economy	3200.00
0005434136730	28737	Economy	3200.00
0005434136702	28737	Economy	3200.00
0005434136677	28737	Economy	3200.00
0005434136731	28737	Economy	3200.00
0005434136746	28737	Economy	3200.00
0005434136737	28737	Economy	3200.00
0005434136676	28737	Economy	3200.00
0005434136688	28737	Economy	3200.00
0005434136714	28737	Economy	3200.00
0005434136741	28737	Economy	3200.00
0005434136734	28737	Economy	3200.00
0005434136720	28737	Economy	3200.00
0005434136675	28737	Economy	3200.00
0005434136740	28737	Economy	3200.00
0005434136719	28737	Economy	3200.00
0005434136705	28737	Economy	3200.00
0005434136708	28737	Economy	3200.00
0005434136752	28737	Economy	3200.00
0005434136692	28737	Economy	3200.00
0005434136759	28737	Economy	3200.00
0005434136728	28737	Economy	3200.00
0005434136756	28737	Economy	3200.00
0005434136700	28737	Economy	3200.00
0005434136718	28737	Economy	3200.00
0005434136712	28737	Economy	3200.00
0005434136725	28737	Economy	3200.00
0005434136679	28737	Economy	3200.00
0005434136735	28737	Economy	3200.00
0005434136681	28737	Economy	3200.00
0005434136747	28737	Economy	3200.00
0005434136694	28737	Economy	3200.00
0005434136686	28737	Economy	3200.00
0005434136744	28737	Economy	3200.00
0005434136748	28737	Economy	3200.00
0005434136750	28737	Economy	3200.00
0005434136743	28737	Economy	3200.00
0005434136715	28737	Economy	3200.00
0005434136684	28737	Economy	3200.00
0005434136732	28737	Economy	3200.00
0005434136758	28737	Economy	3200.00
0005434136703	28737	Economy	3200.00
0005434136697	28737	Economy	3200.00
0005434136709	28737	Economy	3200.00
0005434136698	28737	Economy	3200.00
0005434136755	28737	Economy	3200.00
0005434136749	28737	Economy	3200.00
0005434136726	28737	Economy	3200.00
0005434136711	28737	Economy	3200.00
0005434136682	28737	Economy	3200.00
0005434136695	28737	Economy	3200.00
0005434136753	28737	Economy	3200.00
0005434136738	28737	Economy	3200.00
0005434136690	28737	Economy	3200.00
0005434136710	28737	Economy	3200.00
0005434136685	28737	Economy	3200.00
0005433538729	6814	Economy	9900.00
0005433538730	6814	Economy	9900.00
0005433538733	6814	Economy	9900.00
0005433538726	6814	Economy	9900.00
0005433538732	6814	Economy	9900.00
0005433538725	6814	Economy	9900.00
0005433538728	6814	Economy	9900.00
0005433538731	6814	Economy	9900.00
0005433538727	6814	Economy	9900.00
0005435259685	25016	Economy	10900.00
0005435259683	25016	Economy	10900.00
0005435259682	25016	Economy	9900.00
0005435259684	25016	Economy	9900.00
0005435259686	25016	Economy	9900.00
0005435259687	25016	Economy	9900.00
0005433511815	806	Economy	14600.00
0005433511813	806	Economy	14600.00
0005433511810	806	Economy	14600.00
0005433511812	806	Economy	14600.00
0005433511811	806	Economy	14600.00
0005433511814	806	Economy	14600.00
0005433511816	806	Economy	14600.00
0005433511817	806	Economy	14600.00
0005432922456	16133	Economy	14600.00
0005432922459	16133	Economy	14600.00
0005432922458	16133	Economy	14600.00
0005432922457	16133	Economy	14600.00
0005434950458	3667	Economy	7900.00
0005434950455	3667	Economy	7900.00
0005435696899	3667	Economy	7900.00
0005435696880	3667	Economy	7900.00
0005435696887	3667	Economy	7200.00
0005435696900	3667	Economy	7200.00
0005434950453	3667	Economy	7200.00
0005435696879	3667	Economy	7200.00
0005435696878	3667	Economy	7200.00
0005435696893	3667	Economy	7200.00
0005435696876	3667	Economy	7200.00
0005434950454	3667	Economy	7200.00
0005435696883	3667	Economy	7200.00
0005434950456	3667	Economy	7200.00
0005435696872	3667	Economy	7200.00
0005435696895	3667	Economy	7200.00
0005435696884	3667	Economy	7200.00
0005434950457	3667	Economy	7200.00
0005435696888	3667	Economy	7200.00
0005435696890	3667	Economy	7200.00
0005435696898	3667	Economy	7200.00
0005435696886	3667	Economy	7200.00
0005435696889	3667	Economy	7200.00
0005435696892	3667	Economy	7200.00
0005435696891	3667	Economy	7200.00
0005435696896	3667	Economy	7200.00
0005435696894	3667	Economy	7200.00
0005435696897	3667	Economy	7200.00
0005435696874	3667	Economy	7200.00
0005435696885	3667	Economy	7200.00
0005435696873	3667	Economy	7200.00
0005435696877	3667	Economy	7200.00
0005435696882	3667	Economy	7200.00
0005435696881	3667	Economy	7200.00
0005435696875	3667	Economy	7200.00
0005435916121	16305	Economy	7900.00
0005435916120	16305	Economy	7200.00
0005435934992	16305	Economy	7200.00
0005435934995	16305	Economy	7200.00
0005435934993	16305	Economy	7200.00
0005435934994	16305	Economy	7200.00
0005435916122	16305	Economy	7200.00
0005433519381	3957	Economy	21300.00
0005432609666	3957	Economy	21300.00
0005434604843	3957	Economy	19300.00
0005434606767	3957	Economy	19300.00
0005433519383	3957	Economy	19300.00
0005434604842	3957	Economy	19300.00
0005433519384	3957	Economy	19300.00
0005432607498	3957	Economy	19300.00
0005434606765	3957	Economy	19300.00
0005432609662	3957	Economy	19300.00
0005432607499	3957	Economy	19300.00
0005433519382	3957	Economy	19300.00
0005434606766	3957	Economy	19300.00
0005434604841	3957	Economy	19300.00
0005433519385	3957	Economy	19300.00
0005432607500	3957	Economy	19300.00
0005434604844	3957	Economy	19300.00
0005434604840	3957	Economy	19300.00
0005432609665	3957	Economy	19300.00
0005434606764	3957	Economy	19300.00
0005432607497	3957	Economy	19300.00
0005432607501	3957	Economy	19300.00
0005432609663	3957	Economy	19300.00
0005432609664	3957	Economy	19300.00
0005433348892	15973	Economy	3700.00
0005433348896	15973	Economy	3700.00
0005433348893	15973	Economy	3700.00
0005433348895	15973	Economy	3700.00
0005433348894	15973	Economy	3700.00
0005433348897	15973	Economy	3700.00
0005434445208	17189	Economy	7100.00
0005434445209	17189	Economy	7100.00
0005434445207	17189	Economy	7100.00
0005434445210	17189	Economy	7100.00
0005434446476	17189	Economy	7100.00
0005433159277	17585	Economy	7100.00
0005433159278	17585	Economy	7100.00
0005435132711	7908	Economy	5400.00
0005435132709	7908	Economy	5400.00
0005435132712	7908	Economy	5400.00
0005435132710	7908	Economy	5400.00
0005435132707	7908	Economy	5400.00
0005435132708	7908	Economy	5400.00
0005435132706	7908	Economy	5400.00
0005435132714	7908	Economy	5400.00
0005435132705	7908	Economy	5400.00
0005435132713	7908	Economy	5400.00
0005435383066	33114	Economy	5400.00
0005435383060	33114	Economy	5400.00
0005435383065	33114	Economy	5400.00
0005435383061	33114	Economy	5400.00
0005435383062	33114	Economy	5400.00
0005435383063	33114	Economy	5400.00
0005435383064	33114	Economy	5400.00
0005435810985	4405	Economy	44400.00
0005435810993	4405	Economy	44400.00
0005435810988	4405	Economy	44400.00
0005435810995	4405	Economy	44400.00
0005435810989	4405	Economy	44400.00
0005435810992	4405	Economy	44400.00
0005435810994	4405	Economy	44400.00
0005435810991	4405	Economy	44400.00
0005435810987	4405	Economy	44400.00
0005435810990	4405	Economy	44400.00
0005435810986	4405	Economy	44400.00
0005435938844	29457	Economy	44400.00
0005435938845	29457	Economy	44400.00
0005435938843	29457	Economy	44400.00
0005435160125	7507	Economy	12500.00
0005435160123	7507	Economy	12500.00
0005435160124	7507	Economy	12500.00
0005435160114	7507	Economy	12500.00
0005435160116	7507	Economy	12500.00
0005435160119	7507	Economy	12500.00
0005435160121	7507	Economy	12500.00
0005435160118	7507	Economy	12500.00
0005435160117	7507	Economy	12500.00
0005435160115	7507	Economy	12500.00
0005435160120	7507	Economy	12500.00
0005435160122	7507	Economy	12500.00
0005435390125	29541	Economy	12500.00
0005435390124	29541	Economy	12500.00
0005435390126	29541	Economy	12500.00
0005435390129	29541	Economy	12500.00
0005435390127	29541	Economy	12500.00
0005435390128	29541	Economy	12500.00
0005435390123	29541	Economy	12500.00
0005435390130	29541	Economy	12500.00
0005435178469	18462	Economy	4900.00
0005435178977	18462	Economy	4900.00
0005435178470	18462	Economy	4900.00
0005432400060	27182	Economy	4900.00
0005432400058	27182	Economy	4900.00
0005432400059	27182	Economy	4900.00
0005432400056	27182	Economy	4900.00
0005432398129	27182	Economy	4900.00
0005432398131	27182	Economy	4900.00
0005432398130	27182	Economy	4900.00
0005432400057	27182	Economy	4900.00
0005435103816	6565	Business	48400.00
0005434503534	6565	Business	48400.00
0005434503498	6565	Business	48400.00
0005434503502	6565	Business	48400.00
0005434503513	6565	Business	48400.00
0005435103809	6565	Business	48400.00
0005434503507	6565	Business	48400.00
0005434503520	6565	Business	48400.00
0005435103804	6565	Economy	16100.00
0005435103814	6565	Economy	16100.00
0005435103810	6565	Economy	16100.00
0005434503497	6565	Economy	16100.00
0005434503526	6565	Economy	16100.00
0005434503532	6565	Economy	16100.00
0005434503517	6565	Economy	16100.00
0005434503529	6565	Economy	16100.00
0005434503536	6565	Economy	17800.00
0005434503527	6565	Economy	16100.00
0005434503530	6565	Economy	16100.00
0005435103817	6565	Economy	16100.00
0005434503528	6565	Economy	16100.00
0005434503516	6565	Economy	16100.00
0005434503505	6565	Economy	16100.00
0005434503500	6565	Economy	16100.00
0005435103808	6565	Economy	16100.00
0005435103812	6565	Economy	16100.00
0005434503499	6565	Economy	16100.00
0005434503514	6565	Economy	16100.00
0005434503503	6565	Economy	16100.00
0005434503535	6565	Economy	16100.00
0005434503524	6565	Economy	16100.00
0005435103811	6565	Economy	16100.00
0005434503511	6565	Economy	16100.00
0005435103818	6565	Economy	16100.00
0005435103805	6565	Economy	16100.00
0005434503515	6565	Economy	16100.00
0005434503501	6565	Economy	16100.00
0005434503508	6565	Economy	16100.00
0005434503512	6565	Economy	16100.00
0005434503506	6565	Economy	16100.00
0005434503509	6565	Economy	16100.00
0005434503521	6565	Economy	16100.00
0005434503519	6565	Economy	16100.00
0005435103815	6565	Economy	16100.00
0005434503518	6565	Economy	16100.00
0005434503523	6565	Economy	16100.00
0005434503522	6565	Economy	16100.00
0005434503531	6565	Economy	16100.00
0005434503533	6565	Economy	16100.00
0005434503525	6565	Economy	16100.00
0005434503510	6565	Economy	16100.00
0005435103807	6565	Economy	16100.00
0005435103813	6565	Economy	16100.00
0005434503504	6565	Economy	16100.00
0005435103806	6565	Economy	16100.00
0005435652303	1664	Business	50000.00
0005435652309	1664	Business	50000.00
0005435652300	1664	Business	50000.00
0005435652317	1664	Business	50000.00
0005435652302	1664	Business	50000.00
0005435652325	1664	Economy	16700.00
0005435652318	1664	Economy	18300.00
0005435652320	1664	Economy	18300.00
0005435652298	1664	Economy	18300.00
0005435652304	1664	Economy	16700.00
0005435652326	1664	Economy	16700.00
0005435652299	1664	Economy	16700.00
0005435652307	1664	Economy	16700.00
0005435652324	1664	Economy	16700.00
0005435652312	1664	Economy	16700.00
0005435652316	1664	Economy	16700.00
0005435652338	1664	Economy	16700.00
0005435652330	1664	Economy	16700.00
0005435652323	1664	Economy	16700.00
0005435652308	1664	Economy	16700.00
0005435652334	1664	Economy	16700.00
0005435652329	1664	Economy	16700.00
0005435652306	1664	Economy	16700.00
0005435652328	1664	Economy	16700.00
0005435652319	1664	Economy	16700.00
0005435652339	1664	Economy	16700.00
0005435652332	1664	Economy	16700.00
0005435652297	1664	Economy	16700.00
0005435652322	1664	Economy	16700.00
0005435652313	1664	Economy	16700.00
0005435652301	1664	Economy	16700.00
0005435652337	1664	Economy	16700.00
0005435652327	1664	Economy	16700.00
0005435652315	1664	Economy	16700.00
0005435652321	1664	Economy	16700.00
0005435652310	1664	Economy	16700.00
0005435652305	1664	Economy	16700.00
0005435652331	1664	Economy	16700.00
0005435652314	1664	Economy	16700.00
0005435652335	1664	Economy	16700.00
0005435652333	1664	Economy	16700.00
0005435652311	1664	Economy	16700.00
0005435652336	1664	Economy	16700.00
0005433367275	21714	Business	50000.00
0005433367270	21714	Business	50000.00
0005433367268	21714	Business	50000.00
0005433367264	21714	Business	50000.00
0005433367290	21714	Business	50000.00
0005433367278	21714	Economy	16700.00
0005433367289	21714	Economy	16700.00
0005433367280	21714	Economy	16700.00
0005433367274	21714	Economy	16700.00
0005433367265	21714	Economy	18300.00
0005433367288	21714	Economy	18300.00
0005433367273	21714	Economy	16700.00
0005433367279	21714	Economy	16700.00
0005433367269	21714	Economy	16700.00
0005433367291	21714	Economy	16700.00
0005433367282	21714	Economy	16700.00
0005433367262	21714	Economy	16700.00
0005433367272	21714	Economy	16700.00
0005433367287	21714	Economy	16700.00
0005433367283	21714	Economy	16700.00
0005433367276	21714	Economy	16700.00
0005433367286	21714	Economy	16700.00
0005433367284	21714	Economy	16700.00
0005433367293	21714	Economy	16700.00
0005433367263	21714	Economy	16700.00
0005433367277	21714	Economy	16700.00
0005433367267	21714	Economy	16700.00
0005433367271	21714	Economy	16700.00
0005433367294	21714	Economy	16700.00
0005433367292	21714	Economy	16700.00
0005433367285	21714	Economy	16700.00
0005433367266	21714	Economy	16700.00
0005433367281	21714	Economy	16700.00
0005433367260	21714	Economy	16700.00
0005433367259	21714	Economy	16700.00
0005433367261	21714	Economy	16700.00
0005433985170	4188	Business	21500.00
0005433985169	4188	Business	21500.00
0005433985210	4188	Business	21500.00
0005433985180	4188	Business	21500.00
0005433985182	4188	Business	21500.00
0005433985171	4188	Economy	7200.00
0005433985176	4188	Economy	7200.00
0005433985186	4188	Economy	7200.00
0005433985201	4188	Economy	7200.00
0005433985191	4188	Economy	7200.00
0005433985172	4188	Economy	7900.00
0005433985200	4188	Economy	7900.00
0005433985167	4188	Economy	7900.00
0005433985184	4188	Economy	7900.00
0005433985195	4188	Economy	7200.00
0005433985197	4188	Economy	7200.00
0005433985175	4188	Economy	7200.00
0005433985190	4188	Economy	7200.00
0005435788730	4188	Economy	7200.00
0005433985211	4188	Economy	7200.00
0005433985173	4188	Economy	7200.00
0005433985193	4188	Economy	7200.00
0005433985199	4188	Economy	7200.00
0005433985165	4188	Economy	7200.00
0005433985174	4188	Economy	7200.00
0005433985166	4188	Economy	7200.00
0005433985181	4188	Economy	7200.00
0005433985203	4188	Economy	7200.00
0005433985179	4188	Economy	7200.00
0005433985178	4188	Economy	7200.00
0005433985209	4188	Economy	7200.00
0005433985194	4188	Economy	7200.00
0005433985185	4188	Economy	7200.00
0005433985183	4188	Economy	7200.00
0005433985204	4188	Economy	7200.00
0005433985163	4188	Economy	7200.00
0005435788729	4188	Economy	7200.00
0005433985187	4188	Economy	7200.00
0005433985198	4188	Economy	7200.00
0005433985208	4188	Economy	7200.00
0005433985192	4188	Economy	7200.00
0005433985188	4188	Economy	7200.00
0005433985205	4188	Economy	7200.00
0005433985164	4188	Economy	7200.00
0005433985202	4188	Economy	7200.00
0005433985207	4188	Economy	7200.00
0005433985206	4188	Economy	7200.00
0005433985162	4188	Economy	7200.00
0005433985189	4188	Economy	7200.00
0005433985196	4188	Economy	7200.00
0005433985168	4188	Economy	7200.00
0005433985177	4188	Economy	7200.00
0005435720119	24782	Economy	9400.00
0005435720118	24782	Economy	9400.00
0005434509023	1614	Economy	15500.00
0005434509016	1614	Economy	15500.00
0005434509025	1614	Economy	15500.00
0005434509015	1614	Economy	15500.00
0005434509022	1614	Economy	15500.00
0005434509024	1614	Economy	15500.00
0005434509028	1614	Economy	15500.00
0005434509027	1614	Economy	15500.00
0005434509018	1614	Economy	15500.00
0005434509014	1614	Economy	15500.00
0005434509021	1614	Economy	15500.00
0005434509026	1614	Economy	15500.00
0005434509019	1614	Economy	15500.00
0005434509017	1614	Economy	15500.00
0005434509030	1614	Economy	15500.00
0005434509029	1614	Economy	15500.00
0005434509020	1614	Economy	15500.00
0005432869418	17829	Business	18000.00
0005432869422	17829	Business	18000.00
0005432869419	17829	Economy	6000.00
0005434151657	17829	Economy	6000.00
0005434151658	17829	Economy	6000.00
0005432869423	17829	Economy	6000.00
0005432869417	17829	Economy	6000.00
0005432869420	17829	Economy	6000.00
0005432869421	17829	Economy	6000.00
0005434151659	17829	Economy	6000.00
0005432666353	26292	Business	18000.00
0005432665238	26292	Business	18000.00
0005432657395	26292	Business	18000.00
0005432657394	26292	Economy	6000.00
0005432657393	26292	Economy	6000.00
0005432666351	26292	Economy	6000.00
0005432666352	26292	Economy	6000.00
0005432665237	26292	Economy	6000.00
0005432865895	25073	Business	87300.00
0005432865897	25073	Business	87300.00
0005432865903	25073	Business	87300.00
0005432865899	25073	Economy	29100.00
0005432865902	25073	Economy	32000.00
0005432865901	25073	Economy	29100.00
0005432865908	25073	Economy	29100.00
0005432865907	25073	Economy	29100.00
0005432865905	25073	Economy	29100.00
0005432865906	25073	Economy	29100.00
0005432865898	25073	Economy	29100.00
0005432865904	25073	Economy	29100.00
0005432865896	25073	Economy	29100.00
0005432865900	25073	Economy	29100.00
0005432865894	25073	Economy	29100.00
0005432327939	3086	Business	16100.00
0005433438776	3086	Business	16100.00
0005432287106	3086	Business	16100.00
0005432327938	3086	Business	16100.00
0005433438771	3086	Business	16100.00
0005432327941	3086	Business	16100.00
0005432327960	3086	Business	16100.00
0005432327980	3086	Business	16100.00
0005432327957	3086	Business	16100.00
0005432327973	3086	Business	16100.00
0005432327951	3086	Business	16100.00
0005432327967	3086	Economy	5400.00
0005432327982	3086	Economy	5400.00
0005432327970	3086	Economy	5400.00
0005432327984	3086	Economy	5400.00
0005433438772	3086	Economy	5400.00
0005432287107	3086	Economy	5400.00
0005433438775	3086	Economy	5400.00
0005432327958	3086	Economy	5400.00
0005433438769	3086	Economy	5900.00
0005432327975	3086	Economy	5900.00
0005432327942	3086	Economy	5400.00
0005432327963	3086	Economy	5400.00
0005432327954	3086	Economy	5400.00
0005432327953	3086	Economy	5400.00
0005432327955	3086	Economy	5400.00
0005432327943	3086	Economy	5400.00
0005432327979	3086	Economy	5400.00
0005432327949	3086	Economy	5400.00
0005432327981	3086	Economy	5400.00
0005432327947	3086	Economy	5400.00
0005432327946	3086	Economy	5400.00
0005432287108	3086	Economy	5400.00
0005432327945	3086	Economy	5400.00
0005432327952	3086	Economy	5400.00
0005432287109	3086	Economy	5400.00
0005432327956	3086	Economy	5400.00
0005432327969	3086	Economy	5400.00
0005432327971	3086	Economy	5400.00
0005432327944	3086	Economy	5400.00
0005432327972	3086	Economy	5400.00
0005432327977	3086	Economy	5400.00
0005433438774	3086	Economy	5400.00
0005433438770	3086	Economy	5400.00
0005432327965	3086	Economy	5400.00
0005432327962	3086	Economy	5400.00
0005432327976	3086	Economy	5400.00
0005432327964	3086	Economy	5400.00
0005432327966	3086	Economy	5400.00
0005432327978	3086	Economy	5400.00
0005432327961	3086	Economy	5400.00
0005432327974	3086	Economy	5400.00
0005432327948	3086	Economy	5400.00
0005432327940	3086	Economy	5400.00
0005432327950	3086	Economy	5400.00
0005433438773	3086	Economy	5400.00
0005433438768	3086	Economy	5400.00
0005432327983	3086	Economy	5400.00
0005432327968	3086	Economy	5400.00
0005432327959	3086	Economy	5400.00
0005432054255	31120	Business	16100.00
0005432905028	31120	Business	16100.00
0005432905027	31120	Economy	5900.00
0005432054256	31120	Economy	5400.00
0005432905026	31120	Economy	5400.00
0005432054257	31120	Economy	5400.00
0005435998981	6201	Business	124600.00
0005435998969	6201	Business	124600.00
0005434309523	6201	Economy	41500.00
0005435998977	6201	Economy	41500.00
0005434309517	6201	Economy	41500.00
0005435998974	6201	Economy	41500.00
0005434309527	6201	Economy	41500.00
0005434309519	6201	Economy	41500.00
0005435998983	6201	Economy	41500.00
0005435998984	6201	Economy	41500.00
0005435998968	6201	Economy	41500.00
0005435998975	6201	Economy	41500.00
0005435998970	6201	Economy	45700.00
0005434309518	6201	Economy	45700.00
0005435998979	6201	Economy	41500.00
0005435998976	6201	Economy	41500.00
0005434309515	6201	Economy	41500.00
0005434309529	6201	Economy	41500.00
0005434309525	6201	Economy	41500.00
0005434309528	6201	Economy	41500.00
0005434309514	6201	Economy	41500.00
0005434309521	6201	Economy	41500.00
0005434309522	6201	Economy	41500.00
0005434309520	6201	Economy	41500.00
0005435998978	6201	Economy	41500.00
0005435998971	6201	Economy	41500.00
0005435998982	6201	Economy	41500.00
0005435998972	6201	Economy	41500.00
0005434309526	6201	Economy	41500.00
0005432146166	6201	Economy	41500.00
0005434309524	6201	Economy	41500.00
0005435998973	6201	Economy	41500.00
0005435998980	6201	Economy	41500.00
0005434309516	6201	Economy	41500.00
0005435487456	19552	Business	124600.00
0005435487465	19552	Business	124600.00
0005435487464	19552	Business	124600.00
0005435487471	19552	Economy	41500.00
0005435296949	19552	Economy	41500.00
0005435296950	19552	Economy	41500.00
0005435296947	19552	Economy	41500.00
0005435487470	19552	Economy	41500.00
0005435487466	19552	Economy	41500.00
0005435487472	19552	Economy	41500.00
0005435296944	19552	Economy	41500.00
0005435487453	19552	Economy	45700.00
0005435487457	19552	Economy	45700.00
0005435487474	19552	Economy	41500.00
0005435487463	19552	Economy	41500.00
0005435487461	19552	Economy	41500.00
0005435296946	19552	Economy	41500.00
0005435487455	19552	Economy	41500.00
0005435487467	19552	Economy	41500.00
0005435296948	19552	Economy	41500.00
0005435487454	19552	Economy	41500.00
0005435487473	19552	Economy	41500.00
0005435487459	19552	Economy	41500.00
0005435296945	19552	Economy	41500.00
0005435487469	19552	Economy	41500.00
0005435487460	19552	Economy	41500.00
0005435487468	19552	Economy	41500.00
0005435487458	19552	Economy	41500.00
0005435487462	19552	Economy	41500.00
0005432291892	1599	Business	86000.00
0005435501954	1599	Business	86000.00
0005434565699	1599	Business	86000.00
0005435501960	1599	Business	86000.00
0005435501964	1599	Business	86000.00
0005434565693	1599	Business	86000.00
0005435501965	1599	Business	86000.00
0005435517612	1599	Business	86000.00
0005435508178	1599	Business	86000.00
0005434565696	1599	Economy	28700.00
0005435517607	1599	Economy	28700.00
0005434565701	1599	Economy	28700.00
0005434565702	1599	Economy	28700.00
0005435508182	1599	Economy	28700.00
0005435517624	1599	Economy	28700.00
0005435501957	1599	Economy	28700.00
0005435501953	1599	Economy	28700.00
0005435517619	1599	Economy	28700.00
0005434565700	1599	Economy	28700.00
0005435517628	1599	Economy	31500.00
0005435517608	1599	Economy	31500.00
0005435508181	1599	Economy	31500.00
0005435501956	1599	Economy	31500.00
0005435501958	1599	Economy	31500.00
0005435517622	1599	Economy	28700.00
0005434565703	1599	Economy	28700.00
0005435517611	1599	Economy	28700.00
0005434565698	1599	Economy	28700.00
0005435501955	1599	Economy	28700.00
0005435501974	1599	Economy	28700.00
0005435508183	1599	Economy	28700.00
0005435501970	1599	Economy	28700.00
0005434565692	1599	Economy	28700.00
0005435501959	1599	Economy	28700.00
0005435517613	1599	Economy	28700.00
0005435517614	1599	Economy	28700.00
0005435501971	1599	Economy	28700.00
0005435501962	1599	Economy	28700.00
0005435501963	1599	Economy	28700.00
0005435517626	1599	Economy	28700.00
0005435517625	1599	Economy	28700.00
0005434565694	1599	Economy	28700.00
0005435517615	1599	Economy	28700.00
0005435501967	1599	Economy	28700.00
0005434565704	1599	Economy	28700.00
0005435508179	1599	Economy	28700.00
0005435517616	1599	Economy	28700.00
0005435501961	1599	Economy	28700.00
0005434565695	1599	Economy	28700.00
0005435501973	1599	Economy	28700.00
0005435517620	1599	Economy	28700.00
0005432291891	1599	Economy	28700.00
0005434565705	1599	Economy	28700.00
0005435517609	1599	Economy	28700.00
0005435508184	1599	Economy	28700.00
0005435517617	1599	Economy	28700.00
0005435508180	1599	Economy	28700.00
0005435517610	1599	Economy	28700.00
0005434565697	1599	Economy	28700.00
0005435501972	1599	Economy	28700.00
0005435517618	1599	Economy	28700.00
0005435508177	1599	Economy	28700.00
0005435517621	1599	Economy	28700.00
0005435501969	1599	Economy	28700.00
0005435501966	1599	Economy	28700.00
0005435517623	1599	Economy	28700.00
0005435517627	1599	Economy	28700.00
0005435501968	1599	Economy	28700.00
0005433185981	20861	Economy	28700.00
0005433185984	20861	Economy	31500.00
0005433185979	20861	Economy	28700.00
0005433185982	20861	Economy	28700.00
0005433185977	20861	Economy	28700.00
0005433185978	20861	Economy	28700.00
0005433185980	20861	Economy	28700.00
0005433185983	20861	Economy	28700.00
0005433185976	20861	Economy	28700.00
0005435153639	3879	Economy	21600.00
0005435153637	3879	Economy	19700.00
0005435153632	3879	Economy	19700.00
0005435153638	3879	Economy	19700.00
0005435153633	3879	Economy	19700.00
0005435153635	3879	Economy	19700.00
0005435153636	3879	Economy	19700.00
0005435153634	3879	Economy	19700.00
0005435931540	21849	Economy	21600.00
0005435931539	21849	Economy	19700.00
0005435931542	21849	Economy	19700.00
0005435931541	21849	Economy	19700.00
0005432628616	7179	Economy	14300.00
0005432628609	7179	Economy	13000.00
0005432628612	7179	Economy	13000.00
0005432628600	7179	Economy	13000.00
0005432628607	7179	Economy	13000.00
0005432628606	7179	Economy	13000.00
0005432628605	7179	Economy	13000.00
0005432628613	7179	Economy	13000.00
0005432628603	7179	Economy	13000.00
0005432628602	7179	Economy	13000.00
0005432628601	7179	Economy	13000.00
0005432628611	7179	Economy	13000.00
0005432628608	7179	Economy	13000.00
0005432628610	7179	Economy	13000.00
0005432628615	7179	Economy	13000.00
0005432628614	7179	Economy	13000.00
0005432628604	7179	Economy	13000.00
0005435225455	28148	Economy	13000.00
0005435225454	28148	Economy	13000.00
0005435225452	28148	Economy	13000.00
0005435225456	28148	Economy	13000.00
0005435225453	28148	Economy	13000.00
0005435225457	28148	Economy	13000.00
0005435225458	28148	Economy	13000.00
0005435225451	28148	Economy	13000.00
0005435225450	28148	Economy	13000.00
0005435959989	8762	Economy	10500.00
0005435959988	8762	Economy	10500.00
0005435959986	8762	Economy	10500.00
0005435959987	8762	Economy	10500.00
0005434267889	15218	Economy	10500.00
0005434267890	15218	Economy	10500.00
0005434267888	15218	Economy	10500.00
0005434267887	15218	Economy	10500.00
0005432677506	1172	Business	115000.00
0005432692551	1172	Business	115000.00
0005432677505	1172	Business	115000.00
0005432692536	1172	Business	115000.00
0005432692554	1172	Business	115000.00
0005432692540	1172	Business	115000.00
0005432692531	1172	Business	115000.00
0005432674888	1172	Business	115000.00
0005432674886	1172	Business	115000.00
0005432692547	1172	Economy	38300.00
0005432692558	1172	Economy	38300.00
0005432692549	1172	Economy	38300.00
0005432692557	1172	Economy	38300.00
0005432692548	1172	Economy	38300.00
0005432692535	1172	Economy	38300.00
0005432692552	1172	Economy	38300.00
0005432674881	1172	Economy	38300.00
0005432674880	1172	Economy	42200.00
0005432674889	1172	Economy	42200.00
0005432692529	1172	Economy	38300.00
0005432692530	1172	Economy	38300.00
0005432674883	1172	Economy	38300.00
0005432674885	1172	Economy	38300.00
0005432692541	1172	Economy	38300.00
0005432692537	1172	Economy	38300.00
0005432677504	1172	Economy	38300.00
0005432692532	1172	Economy	38300.00
0005432692528	1172	Economy	38300.00
0005432692546	1172	Economy	38300.00
0005432692543	1172	Economy	38300.00
0005432674878	1172	Economy	38300.00
0005432692544	1172	Economy	38300.00
0005432692534	1172	Economy	38300.00
0005432692533	1172	Economy	38300.00
0005432674882	1172	Economy	38300.00
0005432674892	1172	Economy	38300.00
0005432674887	1172	Economy	38300.00
0005432674891	1172	Economy	38300.00
0005432674884	1172	Economy	38300.00
0005432692545	1172	Economy	38300.00
0005432674879	1172	Economy	38300.00
0005432692550	1172	Economy	38300.00
0005432692538	1172	Economy	38300.00
0005432677503	1172	Economy	38300.00
0005432692539	1172	Economy	38300.00
0005432692555	1172	Economy	38300.00
0005432674890	1172	Economy	38300.00
0005432692542	1172	Economy	38300.00
0005432692556	1172	Economy	38300.00
0005432692527	1172	Economy	38300.00
0005432692553	1172	Economy	38300.00
0005432873174	17471	Economy	42200.00
0005432873179	17471	Economy	38300.00
0005432873178	17471	Economy	38300.00
0005432873176	17471	Economy	38300.00
0005432873177	17471	Economy	38300.00
0005432873175	17471	Economy	38300.00
0005434434940	1101	Economy	15200.00
0005434434930	1101	Economy	13900.00
0005434434939	1101	Economy	13900.00
0005434434926	1101	Economy	13900.00
0005434434933	1101	Economy	13900.00
0005434434931	1101	Economy	13900.00
0005434434938	1101	Economy	13900.00
0005434434929	1101	Economy	13900.00
0005434434937	1101	Economy	13900.00
0005434434925	1101	Economy	13900.00
0005434434934	1101	Economy	13900.00
0005434434935	1101	Economy	13900.00
0005434434927	1101	Economy	13900.00
0005434434928	1101	Economy	13900.00
0005434434936	1101	Economy	13900.00
0005434434932	1101	Economy	13900.00
0005433156610	17310	Economy	15200.00
0005433156606	17310	Economy	13900.00
0005433156609	17310	Economy	13900.00
0005433156612	17310	Economy	13900.00
0005433156608	17310	Economy	13900.00
0005433156607	17310	Economy	13900.00
0005433156611	17310	Economy	13900.00
0005435086709	4086	Economy	8200.00
0005435086713	4086	Economy	7500.00
0005435086707	4086	Economy	7500.00
0005435086710	4086	Economy	7500.00
0005435086711	4086	Economy	7500.00
0005435086715	4086	Economy	7500.00
0005435086714	4086	Economy	7500.00
0005435086708	4086	Economy	7500.00
0005435086712	4086	Economy	7500.00
0005435928067	24440	Economy	8200.00
0005435928065	24440	Economy	8200.00
0005435928063	24440	Economy	7500.00
0005435928064	24440	Economy	7500.00
0005435928062	24440	Economy	7500.00
0005435928066	24440	Economy	7500.00
0005434963898	1315	Business	203300.00
0005434963930	1315	Business	203300.00
0005434963932	1315	Business	203300.00
0005434963910	1315	Business	203300.00
0005434963927	1315	Business	203300.00
0005434963921	1315	Business	203300.00
0005434963917	1315	Business	203300.00
0005434963902	1315	Business	203300.00
0005434963911	1315	Economy	67800.00
0005434963901	1315	Economy	67800.00
0005432279238	1315	Economy	67800.00
0005434963903	1315	Economy	67800.00
0005434963904	1315	Economy	67800.00
0005434963906	1315	Economy	67800.00
0005434963923	1315	Economy	67800.00
0005432279236	1315	Economy	67800.00
0005434963928	1315	Economy	67800.00
0005434963925	1315	Economy	67800.00
0005432279237	1315	Economy	67800.00
0005434963909	1315	Economy	67800.00
0005434963895	1315	Economy	67800.00
0005434963912	1315	Economy	67800.00
0005434963920	1315	Economy	67800.00
0005434963918	1315	Economy	67800.00
0005434963922	1315	Economy	67800.00
0005434963929	1315	Economy	67800.00
0005434963896	1315	Economy	67800.00
0005434963924	1315	Economy	67800.00
0005434963919	1315	Economy	67800.00
0005432279235	1315	Economy	67800.00
0005434963926	1315	Economy	67800.00
0005434963915	1315	Economy	67800.00
0005434963900	1315	Economy	67800.00
0005434963905	1315	Economy	67800.00
0005434963916	1315	Economy	67800.00
0005434963913	1315	Economy	67800.00
0005434963931	1315	Economy	67800.00
0005434963933	1315	Economy	67800.00
0005434963908	1315	Economy	67800.00
0005434963907	1315	Economy	67800.00
0005434963914	1315	Economy	67800.00
0005434963899	1315	Economy	67800.00
0005434963897	1315	Economy	67800.00
0005433261393	18258	Economy	67800.00
0005433261388	18258	Economy	67800.00
0005433261396	18258	Economy	67800.00
0005433261395	18258	Economy	67800.00
0005433261402	18258	Economy	67800.00
0005433261404	18258	Economy	67800.00
0005433261389	18258	Economy	67800.00
0005433261406	18258	Economy	67800.00
0005433261392	18258	Economy	67800.00
0005433261399	18258	Economy	67800.00
0005433261401	18258	Economy	67800.00
0005433261397	18258	Economy	67800.00
0005433261407	18258	Economy	67800.00
0005433261405	18258	Economy	67800.00
0005433261390	18258	Economy	67800.00
0005433261408	18258	Economy	67800.00
0005433261391	18258	Economy	67800.00
0005433261394	18258	Economy	67800.00
0005433261398	18258	Economy	67800.00
0005433261400	18258	Economy	67800.00
0005433261403	18258	Economy	67800.00
0005434625803	4821	Business	44200.00
0005434625809	4821	Economy	14700.00
0005434625807	4821	Economy	16200.00
0005434625812	4821	Economy	14700.00
0005434625810	4821	Economy	14700.00
0005434625806	4821	Economy	14700.00
0005434625808	4821	Economy	14700.00
0005434625811	4821	Economy	14700.00
0005434625805	4821	Economy	14700.00
0005434625804	4821	Economy	14700.00
0005433194823	32913	Economy	14700.00
0005435907421	32913	Economy	16200.00
0005433194820	32913	Economy	14700.00
0005433194822	32913	Economy	14700.00
0005435907425	32913	Economy	14700.00
0005435907423	32913	Economy	14700.00
0005435907422	32913	Economy	14700.00
0005433194821	32913	Economy	14700.00
0005435907424	32913	Economy	14700.00
0005432195658	13778	Economy	3100.00
0005435937315	13778	Economy	3100.00
0005432195659	13778	Economy	3100.00
0005435937318	13778	Economy	3100.00
0005435937314	13778	Economy	3100.00
0005435937316	13778	Economy	3100.00
0005435937317	13778	Economy	3100.00
0005435784732	27409	Economy	3400.00
0005432190563	27409	Economy	3400.00
0005435784756	27409	Economy	3400.00
0005435784730	27409	Economy	3400.00
0005435784752	27409	Economy	3100.00
0005435784738	27409	Economy	3100.00
0005435784739	27409	Economy	3100.00
0005435784737	27409	Economy	3100.00
0005435784759	27409	Economy	3100.00
0005435784742	27409	Economy	3100.00
0005435784736	27409	Economy	3100.00
0005435784748	27409	Economy	3100.00
0005435784735	27409	Economy	3100.00
0005435784733	27409	Economy	3100.00
0005435784750	27409	Economy	3100.00
0005435784761	27409	Economy	3100.00
0005435784758	27409	Economy	3100.00
0005435784757	27409	Economy	3100.00
0005435784763	27409	Economy	3100.00
0005435784749	27409	Economy	3100.00
0005432190564	27409	Economy	3100.00
0005432190561	27409	Economy	3100.00
0005435784762	27409	Economy	3100.00
0005435784729	27409	Economy	3100.00
0005432190562	27409	Economy	3100.00
0005435784731	27409	Economy	3100.00
0005435784744	27409	Economy	3100.00
0005435784755	27409	Economy	3100.00
0005435784740	27409	Economy	3100.00
0005435784747	27409	Economy	3100.00
0005435784754	27409	Economy	3100.00
0005435784728	27409	Economy	3100.00
0005435784745	27409	Economy	3100.00
0005435784751	27409	Economy	3100.00
0005435784746	27409	Economy	3100.00
0005435784741	27409	Economy	3100.00
0005435784743	27409	Economy	3100.00
0005435784753	27409	Economy	3100.00
0005435784727	27409	Economy	3100.00
0005435784734	27409	Economy	3100.00
0005435784760	27409	Economy	3100.00
0005432058316	20278	Business	12000.00
0005435310873	20278	Business	12000.00
0005435310859	20278	Business	12000.00
0005435310861	20278	Economy	4000.00
0005435310869	20278	Economy	4000.00
0005432058317	20278	Economy	4000.00
0005435310858	20278	Economy	4000.00
0005435310863	20278	Economy	4400.00
0005435310867	20278	Economy	4400.00
0005435310875	20278	Economy	4000.00
0005435310860	20278	Economy	4000.00
0005435310856	20278	Economy	4000.00
0005435310857	20278	Economy	4000.00
0005435310870	20278	Economy	4000.00
0005432058319	20278	Economy	4000.00
0005435310866	20278	Economy	4000.00
0005435310872	20278	Economy	4000.00
0005435310862	20278	Economy	4000.00
0005435310865	20278	Economy	4000.00
0005435310871	20278	Economy	4000.00
0005435310868	20278	Economy	4000.00
0005435310874	20278	Economy	4000.00
0005432058318	20278	Economy	4000.00
0005435310864	20278	Economy	4000.00
0005434406750	26977	Business	12000.00
0005434406732	26977	Business	12000.00
0005434406744	26977	Business	12000.00
0005434406737	26977	Business	12000.00
0005434406755	26977	Business	12000.00
0005434406753	26977	Business	12000.00
0005434406747	26977	Business	12000.00
0005434406721	26977	Business	12000.00
0005434406713	26977	Business	12000.00
0005434406751	26977	Business	12000.00
0005434406726	26977	Economy	4000.00
0005434406763	26977	Economy	4000.00
0005434406722	26977	Economy	4000.00
0005434406709	26977	Economy	4000.00
0005434406703	26977	Economy	4000.00
0005432153826	26977	Economy	4000.00
0005434406716	26977	Economy	4000.00
0005434406707	26977	Economy	4400.00
0005434406715	26977	Economy	4400.00
0005434406759	26977	Economy	4400.00
0005432153822	26977	Economy	4400.00
0005432153821	26977	Economy	4000.00
0005434406740	26977	Economy	4000.00
0005432153827	26977	Economy	4000.00
0005432153824	26977	Economy	4000.00
0005434406735	26977	Economy	4000.00
0005434406719	26977	Economy	4000.00
0005434406734	26977	Economy	4000.00
0005434406741	26977	Economy	4000.00
0005434406764	26977	Economy	4000.00
0005432153820	26977	Economy	4000.00
0005434406748	26977	Economy	4000.00
0005434406757	26977	Economy	4000.00
0005434406723	26977	Economy	4000.00
0005434406731	26977	Economy	4000.00
0005434406702	26977	Economy	4000.00
0005434406728	26977	Economy	4000.00
0005434406704	26977	Economy	4000.00
0005434406718	26977	Economy	4000.00
0005434406742	26977	Economy	4000.00
0005434406761	26977	Economy	4000.00
0005434406733	26977	Economy	4000.00
0005434406711	26977	Economy	4000.00
0005434406749	26977	Economy	4000.00
0005434406708	26977	Economy	4000.00
0005434406724	26977	Economy	4000.00
0005434406727	26977	Economy	4000.00
0005434406738	26977	Economy	4000.00
0005434406739	26977	Economy	4000.00
0005434406714	26977	Economy	4000.00
0005434406760	26977	Economy	4000.00
0005434406712	26977	Economy	4000.00
0005434406752	26977	Economy	4000.00
0005434406745	26977	Economy	4000.00
0005434406730	26977	Economy	4000.00
0005434406758	26977	Economy	4000.00
0005434406729	26977	Economy	4000.00
0005434406705	26977	Economy	4000.00
0005434406743	26977	Economy	4000.00
0005432153825	26977	Economy	4000.00
0005432153823	26977	Economy	4000.00
0005434406720	26977	Economy	4000.00
0005434406736	26977	Economy	4000.00
0005434406746	26977	Economy	4000.00
0005434406717	26977	Economy	4000.00
0005434406754	26977	Economy	4000.00
0005434406762	26977	Economy	4000.00
0005434406725	26977	Economy	4000.00
0005434406756	26977	Economy	4000.00
0005434406710	26977	Economy	4000.00
0005434406706	26977	Economy	4000.00
0005434319151	5673	Business	43300.00
0005432109658	5673	Business	43300.00
0005434319160	5673	Business	43300.00
0005434319156	5673	Business	43300.00
0005434319162	5673	Business	43300.00
0005434319163	5673	Economy	14400.00
0005434319158	5673	Economy	14400.00
0005434319152	5673	Economy	14400.00
0005432109657	5673	Economy	15900.00
0005434319155	5673	Economy	14400.00
0005432109659	5673	Economy	14400.00
0005434319161	5673	Economy	14400.00
0005434311184	5673	Economy	14400.00
0005434319157	5673	Economy	14400.00
0005434319154	5673	Economy	14400.00
0005434319153	5673	Economy	14400.00
0005434311183	5673	Economy	14400.00
0005434319159	5673	Economy	14400.00
0005433123598	15683	Business	43300.00
0005433123606	15683	Business	43300.00
0005433123605	15683	Business	43300.00
0005433123589	15683	Business	43300.00
0005433123602	15683	Business	43300.00
0005433123600	15683	Economy	14400.00
0005433123597	15683	Economy	14400.00
0005433123608	15683	Economy	15900.00
0005433123609	15683	Economy	14400.00
0005433123595	15683	Economy	14400.00
0005433123601	15683	Economy	14400.00
0005433123599	15683	Economy	14400.00
0005433123607	15683	Economy	14400.00
0005433123596	15683	Economy	14400.00
0005433123610	15683	Economy	14400.00
0005433123603	15683	Economy	14400.00
0005433123594	15683	Economy	14400.00
0005433123604	15683	Economy	14400.00
0005433123590	15683	Economy	14400.00
0005433123588	15683	Economy	14400.00
0005433123591	15683	Economy	14400.00
0005433123592	15683	Economy	14400.00
0005433123593	15683	Economy	14400.00
0005434484241	8978	Economy	24900.00
0005434484243	8978	Economy	24900.00
0005434484238	8978	Economy	24900.00
0005434484239	8978	Economy	24900.00
0005434484242	8978	Economy	24900.00
0005434484240	8978	Economy	24900.00
0005434484244	8978	Economy	24900.00
0005434189084	16643	Economy	27400.00
0005434189083	16643	Economy	24900.00
0005434189086	16643	Economy	24900.00
0005434189085	16643	Economy	24900.00
0005434189081	16643	Economy	24900.00
0005434189082	16643	Economy	24900.00
0005433123598	7659	Business	11100.00
0005433123606	7659	Business	11100.00
0005433123601	7659	Economy	3700.00
0005433123593	7659	Economy	3700.00
0005433123610	7659	Economy	3700.00
0005433123602	7659	Economy	4100.00
0005433123599	7659	Economy	3700.00
0005433123604	7659	Economy	3700.00
0005433123589	7659	Economy	3700.00
0005433123596	7659	Economy	3700.00
0005433123590	7659	Economy	3700.00
0005433123608	7659	Economy	3700.00
0005433123605	7659	Economy	3700.00
0005433123603	7659	Economy	3700.00
0005433123588	7659	Economy	3700.00
0005433123594	7659	Economy	3700.00
0005433123607	7659	Economy	3700.00
0005433123592	7659	Economy	3700.00
0005433123600	7659	Economy	3700.00
0005433123591	7659	Economy	3700.00
0005433123609	7659	Economy	3700.00
0005433123597	7659	Economy	3700.00
0005433123595	7659	Economy	3700.00
0005432720474	7660	Business	11100.00
0005432692588	7660	Business	11100.00
0005432692575	7660	Business	11100.00
0005432720471	7660	Business	11100.00
0005433449624	7660	Business	11100.00
0005432720478	7660	Business	11100.00
0005433449627	7660	Business	11100.00
0005432720465	7660	Business	11100.00
0005432692565	7660	Business	11100.00
0005432692566	7660	Business	11100.00
0005432692578	7660	Business	11100.00
0005433449607	7660	Economy	3700.00
0005432692573	7660	Economy	3700.00
0005432692569	7660	Economy	3700.00
0005432720463	7660	Economy	3700.00
0005432720459	7660	Economy	3700.00
0005432720456	7660	Economy	3700.00
0005432692581	7660	Economy	3700.00
0005432720475	7660	Economy	3700.00
0005432692571	7660	Economy	3700.00
0005432692576	7660	Economy	3700.00
0005432692567	7660	Economy	4100.00
0005432720482	7660	Economy	4100.00
0005433449618	7660	Economy	4100.00
0005432720473	7660	Economy	4100.00
0005432720470	7660	Economy	4100.00
0005433449612	7660	Economy	3700.00
0005432692562	7660	Economy	3700.00
0005432720458	7660	Economy	3700.00
0005432692572	7660	Economy	3700.00
0005432720462	7660	Economy	3700.00
0005432071523	7660	Economy	3700.00
0005432720457	7660	Economy	3700.00
0005432720460	7660	Economy	3700.00
0005432692585	7660	Economy	3700.00
0005433449609	7660	Economy	3700.00
0005432692564	7660	Economy	3700.00
0005432720480	7660	Economy	3700.00
0005433449611	7660	Economy	3700.00
0005433449626	7660	Economy	3700.00
0005432692582	7660	Economy	3700.00
0005433449608	7660	Economy	3700.00
0005432692587	7660	Economy	3700.00
0005433449625	7660	Economy	3700.00
0005432071525	7660	Economy	3700.00
0005432071526	7660	Economy	3700.00
0005433449610	7660	Economy	3700.00
0005432720466	7660	Economy	3700.00
0005432692560	7660	Economy	3700.00
0005432692583	7660	Economy	3700.00
0005432692563	7660	Economy	3700.00
0005432692559	7660	Economy	3700.00
0005432720467	7660	Economy	3700.00
0005433449614	7660	Economy	3700.00
0005433449613	7660	Economy	3700.00
0005432692570	7660	Economy	3700.00
0005432692586	7660	Economy	3700.00
0005432071524	7660	Economy	3700.00
0005432692579	7660	Economy	3700.00
0005433449615	7660	Economy	3700.00
0005433449616	7660	Economy	3700.00
0005432692589	7660	Economy	3700.00
0005432692580	7660	Economy	3700.00
0005433449606	7660	Economy	3700.00
0005432720464	7660	Economy	3700.00
0005432720481	7660	Economy	3700.00
0005432692577	7660	Economy	3700.00
0005433449623	7660	Economy	3700.00
0005432720461	7660	Economy	3700.00
0005432720468	7660	Economy	3700.00
0005432692584	7660	Economy	3700.00
0005432720479	7660	Economy	3700.00
0005432692568	7660	Economy	3700.00
0005432720476	7660	Economy	3700.00
0005432692574	7660	Economy	3700.00
0005432692561	7660	Economy	3700.00
0005432720477	7660	Economy	3700.00
0005433449622	7660	Economy	3700.00
0005433449621	7660	Economy	3700.00
0005433449619	7660	Economy	3700.00
0005433449620	7660	Economy	3700.00
0005432720469	7660	Economy	3700.00
0005432720472	7660	Economy	3700.00
0005433449617	7660	Economy	3700.00
0005433722107	30444	Business	11100.00
0005433722114	30444	Economy	4100.00
0005433722117	30444	Economy	3700.00
0005433722111	30444	Economy	3700.00
0005433722112	30444	Economy	3700.00
0005433722108	30444	Economy	3700.00
0005433722116	30444	Economy	3700.00
0005433722115	30444	Economy	3700.00
0005433722109	30444	Economy	3700.00
0005433722113	30444	Economy	3700.00
0005433722110	30444	Economy	3700.00
0005434514925	1393	Business	70400.00
0005434586198	1393	Business	70400.00
0005433524866	1393	Business	70400.00
0005433724731	1393	Business	70400.00
0005434586203	1393	Business	70400.00
0005433524865	1393	Economy	23500.00
0005433524863	1393	Economy	23500.00
0005433524861	1393	Economy	23500.00
0005434586192	1393	Economy	23500.00
0005434586194	1393	Economy	23500.00
0005434514924	1393	Economy	23500.00
0005434586204	1393	Economy	23500.00
0005434586189	1393	Economy	23500.00
0005434586206	1393	Economy	25800.00
0005434586190	1393	Economy	25800.00
0005434513536	1393	Economy	25800.00
0005434586186	1393	Economy	25800.00
0005434586205	1393	Economy	25800.00
0005434586195	1393	Economy	23500.00
0005434586191	1393	Economy	23500.00
0005433524859	1393	Economy	23500.00
0005434586184	1393	Economy	23500.00
0005433524867	1393	Economy	23500.00
0005433524860	1393	Economy	23500.00
0005434586187	1393	Economy	23500.00
0005433524868	1393	Economy	23500.00
0005432270957	1393	Economy	23500.00
0005433724729	1393	Economy	23500.00
0005434586196	1393	Economy	23500.00
0005433524864	1393	Economy	23500.00
0005434586185	1393	Economy	23500.00
0005434586202	1393	Economy	23500.00
0005434586183	1393	Economy	23500.00
0005434586207	1393	Economy	23500.00
0005434586200	1393	Economy	23500.00
0005433724728	1393	Economy	23500.00
0005433524857	1393	Economy	23500.00
0005433524862	1393	Economy	23500.00
0005432270958	1393	Economy	23500.00
0005433524856	1393	Economy	23500.00
0005433724732	1393	Economy	23500.00
0005434586193	1393	Economy	23500.00
0005433524869	1393	Economy	23500.00
0005434586197	1393	Economy	23500.00
0005434586199	1393	Economy	23500.00
0005434586201	1393	Economy	23500.00
0005434586188	1393	Economy	23500.00
0005433524858	1393	Economy	23500.00
0005432270959	1393	Economy	23500.00
0005433724730	1393	Economy	23500.00
0005434586208	1393	Economy	23500.00
0005434513537	1393	Economy	23500.00
0005433192835	18549	Business	70400.00
0005432968802	18549	Business	70400.00
0005432927889	18549	Business	70400.00
0005433192837	18549	Business	70400.00
0005433192836	18549	Economy	23500.00
0005433192825	18549	Economy	23500.00
0005433192823	18549	Economy	23500.00
0005433192827	18549	Economy	25800.00
0005432927886	18549	Economy	23500.00
0005433192831	18549	Economy	23500.00
0005433192832	18549	Economy	23500.00
0005433192822	18549	Economy	23500.00
0005433192834	18549	Economy	23500.00
0005432968803	18549	Economy	23500.00
0005433192830	18549	Economy	23500.00
0005432968801	18549	Economy	23500.00
0005433192826	18549	Economy	23500.00
0005432927885	18549	Economy	23500.00
0005433192833	18549	Economy	23500.00
0005432927887	18549	Economy	23500.00
0005432927888	18549	Economy	23500.00
0005433192829	18549	Economy	23500.00
0005433192828	18549	Economy	23500.00
0005433192824	18549	Economy	23500.00
0005434343582	11432	Economy	4300.00
0005434142545	11432	Economy	4300.00
0005434343592	11432	Economy	4300.00
0005434142546	11432	Economy	4300.00
0005434343608	11432	Economy	4000.00
0005434343597	11432	Economy	4000.00
0005434343590	11432	Economy	4000.00
0005434343607	11432	Economy	4000.00
0005434343603	11432	Economy	4000.00
0005434142544	11432	Economy	4000.00
0005434343587	11432	Economy	4000.00
0005434343611	11432	Economy	4000.00
0005434343584	11432	Economy	4000.00
0005434343615	11432	Economy	4000.00
0005434142547	11432	Economy	4000.00
0005434343606	11432	Economy	4000.00
0005434343602	11432	Economy	4000.00
0005434343599	11432	Economy	4000.00
0005434343600	11432	Economy	4000.00
0005434343589	11432	Economy	4000.00
0005434343596	11432	Economy	4000.00
0005434343614	11432	Economy	4000.00
0005434343609	11432	Economy	4000.00
0005434343585	11432	Economy	4000.00
0005434343610	11432	Economy	4000.00
0005434343605	11432	Economy	4000.00
0005434343616	11432	Economy	4000.00
0005434343586	11432	Economy	4000.00
0005434343591	11432	Economy	4000.00
0005434343595	11432	Economy	4000.00
0005434343598	11432	Economy	4000.00
0005434343588	11432	Economy	4000.00
0005434343593	11432	Economy	4000.00
0005434343583	11432	Economy	4000.00
0005434343594	11432	Economy	4000.00
0005434343613	11432	Economy	4000.00
0005434343612	11432	Economy	4000.00
0005434343604	11432	Economy	4000.00
0005434343601	11432	Economy	4000.00
0005435304097	29770	Economy	4000.00
0005435304098	29770	Economy	4000.00
0005435824187	1252	Business	199800.00
0005435824203	1252	Business	199800.00
0005435824181	1252	Business	199800.00
0005435824192	1252	Business	199800.00
0005435824204	1252	Business	199800.00
0005435824202	1252	Economy	66600.00
0005435824199	1252	Economy	73200.00
0005435824186	1252	Economy	73200.00
0005435824196	1252	Economy	66600.00
0005435824200	1252	Economy	66600.00
0005432284510	1252	Economy	66600.00
0005432284511	1252	Economy	66600.00
0005432284512	1252	Economy	66600.00
0005435824195	1252	Economy	66600.00
0005435824184	1252	Economy	66600.00
0005435824193	1252	Economy	66600.00
0005435824205	1252	Economy	66600.00
0005435824180	1252	Economy	66600.00
0005435824191	1252	Economy	66600.00
0005435824189	1252	Economy	66600.00
0005435824183	1252	Economy	66600.00
0005432284509	1252	Economy	66600.00
0005435824190	1252	Economy	66600.00
0005435824185	1252	Economy	66600.00
0005435824197	1252	Economy	66600.00
0005435824194	1252	Economy	66600.00
0005435824201	1252	Economy	66600.00
0005435824188	1252	Economy	66600.00
0005435824198	1252	Economy	66600.00
0005435824182	1252	Economy	66600.00
0005435824179	1252	Economy	66600.00
0005433415401	18029	Business	199800.00
0005433415394	18029	Business	199800.00
0005433415403	18029	Business	199800.00
0005433415400	18029	Economy	66600.00
0005433415398	18029	Business	199800.00
0005433415404	18029	Economy	66600.00
0005433415407	18029	Economy	66600.00
0005433415395	18029	Economy	66600.00
0005433415408	18029	Economy	66600.00
0005433415410	18029	Economy	66600.00
0005433415402	18029	Economy	66600.00
0005433415406	18029	Economy	66600.00
0005433415396	18029	Economy	66600.00
0005433415397	18029	Economy	66600.00
0005433415399	18029	Economy	66600.00
0005433415405	18029	Economy	66600.00
0005433415409	18029	Economy	66600.00
0005434461608	12579	Economy	14800.00
0005434461609	12579	Economy	13500.00
0005434460467	12579	Economy	13500.00
0005434461610	12579	Economy	13500.00
0005434460466	12579	Economy	13500.00
0005434460468	12579	Economy	13500.00
0005432782922	5636	Business	27800.00
0005432782915	5636	Business	27800.00
0005432782930	5636	Business	27800.00
0005432782912	5636	Business	27800.00
0005432782936	5636	Business	27800.00
0005432143933	5636	Business	27800.00
0005432782940	5636	Business	27800.00
0005432782927	5636	Economy	9300.00
0005432782918	5636	Economy	9300.00
0005432782941	5636	Economy	9300.00
0005432782934	5636	Economy	9300.00
0005432782933	5636	Economy	9300.00
0005432782928	5636	Economy	9300.00
0005432143934	5636	Economy	9300.00
0005432782945	5636	Economy	9300.00
0005432782946	5636	Economy	10200.00
0005432782903	5636	Economy	10200.00
0005432782929	5636	Economy	9300.00
0005432782947	5636	Economy	9300.00
0005432782908	5636	Economy	9300.00
0005432782893	5636	Economy	9300.00
0005432782907	5636	Economy	9300.00
0005432782938	5636	Economy	9300.00
0005432782899	5636	Economy	9300.00
0005432782932	5636	Economy	9300.00
0005432782913	5636	Economy	9300.00
0005432782911	5636	Economy	9300.00
0005432782904	5636	Economy	9300.00
0005432782914	5636	Economy	9300.00
0005432782905	5636	Economy	9300.00
0005432782923	5636	Economy	9300.00
0005432782944	5636	Economy	9300.00
0005432782895	5636	Economy	9300.00
0005432782916	5636	Economy	9300.00
0005432782921	5636	Economy	9300.00
0005432782917	5636	Economy	9300.00
0005432782937	5636	Economy	9300.00
0005432782906	5636	Economy	9300.00
0005432782943	5636	Economy	9300.00
0005432782910	5636	Economy	9300.00
0005432782924	5636	Economy	9300.00
0005432782920	5636	Economy	9300.00
0005432782919	5636	Economy	9300.00
0005432782898	5636	Economy	9300.00
0005432782931	5636	Economy	9300.00
0005432782909	5636	Economy	9300.00
0005432782942	5636	Economy	9300.00
0005432782896	5636	Economy	9300.00
0005432782900	5636	Economy	9300.00
0005432782902	5636	Economy	9300.00
0005432782939	5636	Economy	9300.00
0005432782901	5636	Economy	9300.00
0005432782926	5636	Economy	9300.00
0005432782897	5636	Economy	9300.00
0005432143935	5636	Economy	9300.00
0005432782925	5636	Economy	9300.00
0005432782935	5636	Economy	9300.00
0005432782894	5636	Economy	9300.00
0005432782948	5636	Economy	9300.00
0005435242390	15349	Business	27800.00
0005435242391	15349	Business	27800.00
0005435242406	15349	Business	27800.00
0005435242412	15349	Business	27800.00
0005435242403	15349	Economy	9300.00
0005435242387	15349	Economy	9300.00
0005435242396	15349	Economy	9300.00
0005435242409	15349	Economy	9300.00
0005435242402	15349	Economy	10200.00
0005435242405	15349	Economy	9300.00
0005435242393	15349	Economy	9300.00
0005435242413	15349	Economy	9300.00
0005435242389	15349	Economy	9300.00
0005435242415	15349	Economy	9300.00
0005435476651	15349	Economy	9300.00
0005435242395	15349	Economy	9300.00
0005435242388	15349	Economy	9300.00
0005435242414	15349	Economy	9300.00
0005435242410	15349	Economy	9300.00
0005435242401	15349	Economy	9300.00
0005435242394	15349	Economy	9300.00
0005435242400	15349	Economy	9300.00
0005435242408	15349	Economy	9300.00
0005435242398	15349	Economy	9300.00
0005435476650	15349	Economy	9300.00
0005435476649	15349	Economy	9300.00
0005435242407	15349	Economy	9300.00
0005435242392	15349	Economy	9300.00
0005435242411	15349	Economy	9300.00
0005435242397	15349	Economy	9300.00
0005435242404	15349	Economy	9300.00
0005435242399	15349	Economy	9300.00
0005432848083	4387	Economy	7000.00
0005432848082	4387	Economy	6300.00
0005432848075	4387	Economy	6300.00
0005432848080	4387	Economy	6300.00
0005434463895	4387	Economy	6300.00
0005432848084	4387	Economy	6300.00
0005432848079	4387	Economy	6300.00
0005432848081	4387	Economy	6300.00
0005432848078	4387	Economy	6300.00
0005432848077	4387	Economy	6300.00
0005432848076	4387	Economy	6300.00
0005434462755	4387	Economy	6300.00
0005432848074	4387	Economy	6300.00
0005434462754	4387	Economy	6300.00
0005434463894	4387	Economy	6300.00
0005432848073	4387	Economy	6300.00
0005432848072	4387	Economy	6300.00
0005432848071	4387	Economy	6300.00
0005434463893	4387	Economy	6300.00
0005435850759	28861	Economy	6300.00
0005435850760	28861	Economy	6300.00
0005435850764	28861	Economy	6300.00
0005435850765	28861	Economy	6300.00
0005435850762	28861	Economy	6300.00
0005435850766	28861	Economy	6300.00
0005435850758	28861	Economy	6300.00
0005435850763	28861	Economy	6300.00
0005435850761	28861	Economy	6300.00
0005433496460	6314	Business	11900.00
0005434443452	6314	Business	11900.00
0005434443453	6314	Business	11900.00
0005434925293	6314	Business	11900.00
0005433496452	6314	Business	11900.00
0005433496472	6314	Business	11900.00
0005433496459	6314	Business	11900.00
0005434443448	6314	Business	11900.00
0005433496479	6314	Business	11900.00
0005434443450	6314	Business	11900.00
0005434443441	6314	Business	11900.00
0005432075173	6314	Economy	4000.00
0005433496464	6314	Economy	4000.00
0005433496473	6314	Economy	4000.00
0005434925303	6314	Economy	4000.00
0005433496482	6314	Economy	4000.00
0005433496469	6314	Economy	4000.00
0005434925288	6314	Economy	4000.00
0005433496451	6314	Economy	4000.00
0005432075175	6314	Economy	4400.00
0005434925275	6314	Economy	4400.00
0005434443454	6314	Economy	4400.00
0005434925287	6314	Economy	4400.00
0005434443451	6314	Economy	4400.00
0005434925297	6314	Economy	4000.00
0005434925300	6314	Economy	4000.00
0005434443455	6314	Economy	4000.00
0005433496450	6314	Economy	4000.00
0005433496456	6314	Economy	4000.00
0005434925294	6314	Economy	4000.00
0005434443443	6314	Economy	4000.00
0005434443446	6314	Economy	4000.00
0005434925299	6314	Economy	4000.00
0005433496481	6314	Economy	4000.00
0005434925305	6314	Economy	4000.00
0005434925274	6314	Economy	4000.00
0005434443444	6314	Economy	4000.00
0005432075174	6314	Economy	4000.00
0005434443449	6314	Economy	4000.00
0005434925280	6314	Economy	4000.00
0005432075172	6314	Economy	4000.00
0005434925304	6314	Economy	4000.00
0005433496480	6314	Economy	4000.00
0005434925273	6314	Economy	4000.00
0005433496465	6314	Economy	4000.00
0005434925292	6314	Economy	4000.00
0005434925282	6314	Economy	4000.00
0005433496475	6314	Economy	4000.00
0005434925298	6314	Economy	4000.00
0005433496477	6314	Economy	4000.00
0005433496467	6314	Economy	4000.00
0005434925301	6314	Economy	4000.00
0005434443447	6314	Economy	4000.00
0005434925302	6314	Economy	4000.00
0005433496462	6314	Economy	4000.00
0005433496454	6314	Economy	4000.00
0005433496458	6314	Economy	4000.00
0005434925290	6314	Economy	4000.00
0005433496474	6314	Economy	4000.00
0005434443440	6314	Economy	4000.00
0005433496476	6314	Economy	4000.00
0005433496471	6314	Economy	4000.00
0005434925277	6314	Economy	4000.00
0005434925286	6314	Economy	4000.00
0005433496463	6314	Economy	4000.00
0005433496466	6314	Economy	4000.00
0005434925283	6314	Economy	4000.00
0005433496455	6314	Economy	4000.00
0005433496470	6314	Economy	4000.00
0005433496468	6314	Economy	4000.00
0005434925284	6314	Economy	4000.00
0005434925285	6314	Economy	4000.00
0005434925281	6314	Economy	4000.00
0005434925278	6314	Economy	4000.00
0005433496453	6314	Economy	4000.00
0005433496461	6314	Economy	4000.00
0005433496478	6314	Economy	4000.00
0005433496457	6314	Economy	4000.00
0005434925295	6314	Economy	4000.00
0005434925291	6314	Economy	4000.00
0005434925279	6314	Economy	4000.00
0005434443442	6314	Economy	4000.00
0005434925296	6314	Economy	4000.00
0005434443445	6314	Economy	4000.00
0005434925276	6314	Economy	4000.00
0005434925289	6314	Economy	4000.00
0005435242431	12197	Business	41200.00
0005435242418	12197	Business	41200.00
0005435242430	12197	Business	41200.00
0005435242419	12197	Economy	13700.00
0005435242427	12197	Economy	13700.00
0005435242429	12197	Economy	15100.00
0005435242442	12197	Economy	15100.00
0005435242426	12197	Economy	15100.00
0005435242424	12197	Economy	13700.00
0005435242433	12197	Economy	13700.00
0005435242441	12197	Economy	13700.00
0005435242416	12197	Economy	13700.00
0005435242438	12197	Economy	13700.00
0005435242432	12197	Economy	13700.00
0005435242436	12197	Economy	13700.00
0005435242420	12197	Economy	13700.00
0005435242425	12197	Economy	13700.00
0005435242423	12197	Economy	13700.00
0005435242428	12197	Economy	13700.00
0005435242437	12197	Economy	13700.00
0005435242439	12197	Economy	13700.00
0005435242435	12197	Economy	13700.00
0005435242421	12197	Economy	13700.00
0005435242417	12197	Economy	13700.00
0005435242422	12197	Economy	13700.00
0005435242440	12197	Economy	13700.00
0005435242434	12197	Economy	13700.00
0005432782857	15398	Business	41200.00
0005432782842	15398	Business	41200.00
0005432782890	15398	Business	41200.00
0005432782856	15398	Business	41200.00
0005432782847	15398	Business	41200.00
0005432782855	15398	Economy	13700.00
0005432782859	15398	Economy	13700.00
0005432782873	15398	Economy	13700.00
0005432782880	15398	Economy	13700.00
0005432782891	15398	Economy	13700.00
0005432782879	15398	Economy	13700.00
0005432782850	15398	Economy	15100.00
0005432782862	15398	Economy	15100.00
0005432782884	15398	Economy	13700.00
0005432782846	15398	Economy	13700.00
0005432782848	15398	Economy	13700.00
0005432782877	15398	Economy	13700.00
0005432782887	15398	Economy	13700.00
0005432782868	15398	Economy	13700.00
0005432782858	15398	Economy	13700.00
0005432782875	15398	Economy	13700.00
0005432782864	15398	Economy	13700.00
0005432782881	15398	Economy	13700.00
0005432782882	15398	Economy	13700.00
0005432782865	15398	Economy	13700.00
0005432782843	15398	Economy	13700.00
0005432782866	15398	Economy	13700.00
0005432782876	15398	Economy	13700.00
0005432782870	15398	Economy	13700.00
0005432782885	15398	Economy	13700.00
0005432782841	15398	Economy	13700.00
0005432782883	15398	Economy	13700.00
0005432782839	15398	Economy	13700.00
0005432782851	15398	Economy	13700.00
0005432782869	15398	Economy	13700.00
0005432782888	15398	Economy	13700.00
0005432782844	15398	Economy	13700.00
0005432782849	15398	Economy	13700.00
0005432782860	15398	Economy	13700.00
0005432782863	15398	Economy	13700.00
0005432782874	15398	Economy	13700.00
0005432782840	15398	Economy	13700.00
0005432782854	15398	Economy	13700.00
0005432782838	15398	Economy	13700.00
0005432782872	15398	Economy	13700.00
0005432782886	15398	Economy	13700.00
0005432782853	15398	Economy	13700.00
0005432782852	15398	Economy	13700.00
0005432782867	15398	Economy	13700.00
0005432782871	15398	Economy	13700.00
0005432782845	15398	Economy	13700.00
0005432782861	15398	Economy	13700.00
0005432782889	15398	Economy	13700.00
0005432782892	15398	Economy	13700.00
0005432782878	15398	Economy	13700.00
0005435913855	10111	Business	49700.00
0005434910071	10111	Economy	16600.00
0005435913852	10111	Economy	16600.00
0005435913853	10111	Economy	16600.00
0005434910072	10111	Economy	16600.00
0005435913851	10111	Economy	16600.00
0005435913854	10111	Economy	16600.00
0005435913856	10111	Economy	16600.00
0005435913857	10111	Economy	16600.00
0005434876746	14650	Business	49700.00
0005434876668	14650	Business	49700.00
0005434876654	14650	Business	49700.00
0005434876666	14650	Business	49700.00
0005434876726	14650	Business	49700.00
0005434876740	14650	Business	49700.00
0005434876652	14650	Business	49700.00
0005434876742	14650	Business	49700.00
0005434876737	14650	Business	49700.00
0005434876657	14650	Business	49700.00
0005434876743	14650	Business	49700.00
0005434876658	14650	Business	49700.00
0005434876681	14650	Business	49700.00
0005434876732	14650	Business	49700.00
0005434876679	14650	Business	49700.00
0005434876717	14650	Business	49700.00
0005434876725	14650	Business	49700.00
0005434876669	14650	Economy	16600.00
0005434876703	14650	Business	49700.00
0005434876706	14650	Economy	16600.00
0005434876739	14650	Economy	16600.00
0005434876684	14650	Economy	16600.00
0005434876688	14650	Economy	16600.00
0005434876691	14650	Economy	16600.00
0005434876724	14650	Economy	16600.00
0005434876672	14650	Economy	16600.00
0005434876653	14650	Economy	16600.00
0005434876690	14650	Economy	16600.00
0005434876727	14650	Economy	16600.00
0005434876707	14650	Economy	16600.00
0005434876713	14650	Economy	16600.00
0005434876719	14650	Economy	18200.00
0005434876718	14650	Economy	18200.00
0005434876710	14650	Economy	16600.00
0005434876695	14650	Economy	16600.00
0005434876697	14650	Economy	16600.00
0005434876744	14650	Economy	16600.00
0005434876685	14650	Economy	16600.00
0005434876696	14650	Economy	16600.00
0005434876736	14650	Economy	16600.00
0005434876662	14650	Economy	16600.00
0005434876694	14650	Economy	16600.00
0005434876716	14650	Economy	16600.00
0005434876711	14650	Economy	16600.00
0005434876683	14650	Economy	16600.00
0005434876700	14650	Economy	16600.00
0005434876665	14650	Economy	16600.00
0005434876704	14650	Economy	16600.00
0005434876692	14650	Economy	16600.00
0005434876670	14650	Economy	16600.00
0005434876741	14650	Economy	16600.00
0005434876682	14650	Economy	16600.00
0005434876733	14650	Economy	16600.00
0005434876734	14650	Economy	16600.00
0005434758855	14650	Economy	16600.00
0005434876712	14650	Economy	16600.00
0005434876735	14650	Economy	16600.00
0005434876659	14650	Economy	16600.00
0005434876676	14650	Economy	16600.00
0005434876667	14650	Economy	16600.00
0005434876747	14650	Economy	16600.00
0005434758856	14650	Economy	16600.00
0005434876728	14650	Economy	16600.00
0005434876738	14650	Economy	16600.00
0005434876745	14650	Economy	16600.00
0005434876701	14650	Economy	16600.00
0005434876689	14650	Economy	16600.00
0005434876680	14650	Economy	16600.00
0005434876686	14650	Economy	16600.00
0005434876673	14650	Economy	16600.00
0005434876721	14650	Economy	16600.00
0005434876729	14650	Economy	16600.00
0005434876748	14650	Economy	16600.00
0005434876675	14650	Economy	16600.00
0005434876663	14650	Economy	16600.00
0005434876702	14650	Economy	16600.00
0005434876715	14650	Economy	16600.00
0005434876661	14650	Economy	16600.00
0005434876664	14650	Economy	16600.00
0005434876677	14650	Economy	16600.00
0005434876723	14650	Economy	16600.00
0005434876687	14650	Economy	16600.00
0005434876699	14650	Economy	16600.00
0005434876693	14650	Economy	16600.00
0005434876709	14650	Economy	16600.00
0005434876720	14650	Economy	16600.00
0005434876722	14650	Economy	16600.00
0005434876671	14650	Economy	16600.00
0005434876698	14650	Economy	16600.00
0005434876674	14650	Economy	16600.00
0005434876731	14650	Economy	16600.00
0005434876660	14650	Economy	16600.00
0005434876705	14650	Economy	16600.00
0005434876730	14650	Economy	16600.00
0005434876656	14650	Economy	16600.00
0005434876678	14650	Economy	16600.00
0005434876714	14650	Economy	16600.00
0005434876708	14650	Economy	16600.00
0005434876655	14650	Economy	16600.00
0005435659953	9246	Economy	22400.00
0005435659954	9246	Economy	20300.00
0005435659949	9246	Economy	20300.00
0005435659950	9246	Economy	20300.00
0005435659959	9246	Economy	20300.00
0005435659958	9246	Economy	20300.00
0005435659951	9246	Economy	20300.00
0005435659955	9246	Economy	20300.00
0005435659956	9246	Economy	20300.00
0005435659952	9246	Economy	20300.00
0005435659957	9246	Economy	20300.00
0005434251809	24625	Economy	22400.00
0005434251810	24625	Economy	20300.00
0005434251808	24625	Economy	20300.00
0005434251812	24625	Economy	20300.00
0005434251813	24625	Economy	20300.00
0005434251811	24625	Economy	20300.00
0005434251805	24625	Economy	20300.00
0005434251807	24625	Economy	20300.00
0005434251806	24625	Economy	20300.00
0005434251814	24625	Economy	20300.00
0005433679787	2803	Business	33000.00
0005433679788	2803	Business	33000.00
0005433679790	2803	Business	33000.00
0005433679759	2803	Business	33000.00
0005433679772	2803	Economy	11000.00
0005433684385	2803	Economy	11000.00
0005433679767	2803	Economy	11000.00
0005433679758	2803	Economy	11000.00
0005433679771	2803	Economy	11000.00
0005433679791	2803	Economy	11000.00
0005433679769	2803	Economy	11000.00
0005433679768	2803	Economy	12100.00
0005433679770	2803	Economy	12100.00
0005433679793	2803	Economy	12100.00
0005433679805	2803	Economy	12100.00
0005433679774	2803	Economy	12100.00
0005433679799	2803	Economy	11000.00
0005433679765	2803	Economy	11000.00
0005433679783	2803	Economy	11000.00
0005433679761	2803	Economy	11000.00
0005433679785	2803	Economy	11000.00
0005433679776	2803	Economy	11000.00
0005432222695	2803	Economy	11000.00
0005433679797	2803	Economy	11000.00
0005433679784	2803	Economy	11000.00
0005433679779	2803	Economy	11000.00
0005433679804	2803	Economy	11000.00
0005433679763	2803	Economy	11000.00
0005433679789	2803	Economy	11000.00
0005433679792	2803	Economy	11000.00
0005433679762	2803	Economy	11000.00
0005433679778	2803	Economy	11000.00
0005433679775	2803	Economy	11000.00
0005433679801	2803	Economy	11000.00
0005433679780	2803	Economy	11000.00
0005433679798	2803	Economy	11000.00
0005432222693	2803	Economy	11000.00
0005433679781	2803	Economy	11000.00
0005433684384	2803	Economy	11000.00
0005433679764	2803	Economy	11000.00
0005433679806	2803	Economy	11000.00
0005433679773	2803	Economy	11000.00
0005433679796	2803	Economy	11000.00
0005432222694	2803	Economy	11000.00
0005433679794	2803	Economy	11000.00
0005432222697	2803	Economy	11000.00
0005433679757	2803	Economy	11000.00
0005433679795	2803	Economy	11000.00
0005433679803	2803	Economy	11000.00
0005432222696	2803	Economy	11000.00
0005433679782	2803	Economy	11000.00
0005433679760	2803	Economy	11000.00
0005433679802	2803	Economy	11000.00
0005433679786	2803	Economy	11000.00
0005433679777	2803	Economy	11000.00
0005433679766	2803	Economy	11000.00
0005433679800	2803	Economy	11000.00
0005432966515	29157	Business	33000.00
0005432966513	29157	Economy	11000.00
0005432966526	29157	Economy	11000.00
0005432966530	29157	Economy	11000.00
0005432966512	29157	Economy	12100.00
0005432966508	29157	Economy	12100.00
0005432005166	29157	Economy	11000.00
0005432966507	29157	Economy	11000.00
0005432966516	29157	Economy	11000.00
0005432966525	29157	Economy	11000.00
0005432966514	29157	Economy	11000.00
0005432966518	29157	Economy	11000.00
0005432966522	29157	Economy	11000.00
0005432966505	29157	Economy	11000.00
0005432966528	29157	Economy	11000.00
0005432005167	29157	Economy	11000.00
0005432966520	29157	Economy	11000.00
0005432966510	29157	Economy	11000.00
0005432966521	29157	Economy	11000.00
0005432005168	29157	Economy	11000.00
0005432966531	29157	Economy	11000.00
0005432966527	29157	Economy	11000.00
0005432966511	29157	Economy	11000.00
0005432966523	29157	Economy	11000.00
0005432966519	29157	Economy	11000.00
0005432966529	29157	Economy	11000.00
0005432966506	29157	Economy	11000.00
0005432966524	29157	Economy	11000.00
0005432966509	29157	Economy	11000.00
0005432966517	29157	Economy	11000.00
0005433613431	9319	Business	132900.00
0005433613391	9319	Business	132900.00
0005433613388	9319	Business	132900.00
0005433613440	9319	Business	132900.00
0005433613438	9319	Business	132900.00
0005433613450	9319	Business	132900.00
0005433633240	9319	Business	132900.00
0005433613422	9319	Business	132900.00
0005433613433	9319	Business	132900.00
0005432756792	9319	Business	132900.00
0005433613460	9319	Business	132900.00
0005433613427	9319	Business	132900.00
0005433613447	9319	Business	132900.00
0005433613413	9319	Business	132900.00
0005433613429	9319	Business	132900.00
0005433613399	9319	Business	132900.00
0005433633217	9319	Business	132900.00
0005433633230	9319	Business	132900.00
0005433633214	9319	Business	132900.00
0005433633219	9319	Business	132900.00
0005433613400	9319	Business	132900.00
0005433613446	9319	Business	132900.00
0005433613432	9319	Economy	48700.00
0005433613415	9319	Economy	48700.00
0005433633246	9319	Economy	48700.00
0005433613412	9319	Economy	48700.00
0005433613416	9319	Economy	48700.00
0005433633224	9319	Economy	44300.00
0005433613390	9319	Economy	44300.00
0005433633213	9319	Economy	44300.00
0005433613458	9319	Economy	44300.00
0005433577583	9319	Economy	44300.00
0005433577576	9319	Economy	44300.00
0005432145076	9319	Economy	44300.00
0005433613402	9319	Economy	44300.00
0005433613418	9319	Economy	44300.00
0005433613452	9319	Economy	44300.00
0005433613417	9319	Economy	44300.00
0005433613404	9319	Economy	44300.00
0005433633236	9319	Economy	44300.00
0005433613437	9319	Economy	44300.00
0005432756790	9319	Economy	44300.00
0005433613421	9319	Economy	44300.00
0005433577577	9319	Economy	44300.00
0005433613445	9319	Economy	44300.00
0005433633245	9319	Economy	44300.00
0005433633218	9319	Economy	44300.00
0005433613397	9319	Economy	44300.00
0005433613459	9319	Economy	44300.00
0005433613407	9319	Economy	44300.00
0005433613453	9319	Economy	44300.00
0005433633226	9319	Economy	44300.00
0005433577574	9319	Economy	44300.00
0005433613443	9319	Economy	44300.00
0005433613456	9319	Economy	44300.00
0005433613425	9319	Economy	44300.00
0005433613454	9319	Economy	44300.00
0005433613444	9319	Economy	44300.00
0005433633241	9319	Economy	44300.00
0005433613409	9319	Economy	44300.00
0005433633235	9319	Economy	44300.00
0005433613401	9319	Economy	44300.00
0005433613436	9319	Economy	44300.00
0005433633227	9319	Economy	44300.00
0005433633225	9319	Economy	44300.00
0005433577579	9319	Economy	44300.00
0005433633232	9319	Economy	44300.00
0005433613386	9319	Economy	44300.00
0005433613434	9319	Economy	44300.00
0005433613393	9319	Economy	44300.00
0005433613441	9319	Economy	44300.00
0005433633231	9319	Economy	44300.00
0005433577580	9319	Economy	44300.00
0005433613396	9319	Economy	44300.00
0005433613387	9319	Economy	44300.00
0005433633244	9319	Economy	44300.00
0005433613395	9319	Economy	48700.00
0005433633221	9319	Economy	48700.00
0005433613403	9319	Economy	48700.00
0005433633239	9319	Economy	48700.00
0005433613408	9319	Economy	44300.00
0005433633223	9319	Economy	44300.00
0005433613392	9319	Economy	48700.00
0005433633247	9319	Economy	44300.00
0005433613424	9319	Economy	44300.00
0005433613414	9319	Economy	44300.00
0005433613423	9319	Economy	44300.00
0005433613398	9319	Economy	44300.00
0005433633242	9319	Economy	44300.00
0005433633237	9319	Economy	44300.00
0005433613389	9319	Economy	44300.00
0005433577584	9319	Economy	44300.00
0005432145077	9319	Economy	44300.00
0005433633228	9319	Economy	44300.00
0005433613448	9319	Economy	44300.00
0005433633243	9319	Economy	44300.00
0005432755018	9319	Economy	44300.00
0005433613420	9319	Economy	44300.00
0005433577581	9319	Economy	44300.00
0005432145075	9319	Economy	44300.00
0005433613449	9319	Economy	44300.00
0005433577586	9319	Economy	44300.00
0005433633229	9319	Economy	44300.00
0005433613406	9319	Economy	44300.00
0005433613435	9319	Economy	44300.00
0005433633234	9319	Economy	44300.00
0005433613419	9319	Economy	44300.00
0005432755020	9319	Economy	44300.00
0005433633220	9319	Economy	44300.00
0005432756793	9319	Economy	44300.00
0005433633215	9319	Economy	44300.00
0005433613430	9319	Economy	44300.00
0005433577587	9319	Economy	44300.00
0005433613442	9319	Economy	44300.00
0005432755019	9319	Economy	44300.00
0005433577578	9319	Economy	44300.00
0005433613405	9319	Economy	44300.00
0005433613451	9319	Economy	44300.00
0005433577582	9319	Economy	44300.00
0005433633233	9319	Economy	44300.00
0005433577585	9319	Economy	44300.00
0005433633216	9319	Economy	44300.00
0005433633222	9319	Economy	44300.00
0005433613394	9319	Economy	44300.00
0005433613439	9319	Economy	44300.00
0005433613455	9319	Economy	44300.00
0005433613457	9319	Economy	44300.00
0005433613426	9319	Economy	44300.00
0005433633238	9319	Economy	44300.00
0005432756791	9319	Economy	44300.00
0005433577575	9319	Economy	44300.00
0005433613411	9319	Economy	44300.00
0005433613410	9319	Economy	44300.00
0005433613428	9319	Economy	44300.00
0005434163466	25219	Business	132900.00
0005434273047	25219	Business	132900.00
0005434163467	25219	Business	132900.00
0005434163464	25219	Economy	44300.00
0005434163469	25219	Economy	44300.00
0005434163463	25219	Economy	44300.00
0005434272162	25219	Economy	44300.00
0005434163461	25219	Economy	44300.00
0005434163458	25219	Economy	44300.00
0005434163460	25219	Economy	44300.00
0005434163459	25219	Economy	44300.00
0005434272161	25219	Economy	44300.00
0005434163468	25219	Economy	44300.00
0005434163462	25219	Economy	44300.00
0005434163465	25219	Economy	44300.00
0005434273046	25219	Economy	44300.00
0005435986656	4255	Economy	64400.00
0005432184903	4255	Economy	64400.00
0005432184904	4255	Economy	64400.00
0005435986655	4255	Economy	64400.00
0005432184905	4255	Economy	64400.00
0005435787323	26569	Business	193100.00
0005435787322	26569	Business	193100.00
0005435947021	26569	Business	193100.00
0005435947017	26569	Business	193100.00
0005435947023	26569	Economy	64400.00
0005435947024	26569	Economy	64400.00
0005435947025	26569	Economy	64400.00
0005432571263	26569	Economy	64400.00
0005435947019	26569	Economy	64400.00
0005435856137	26569	Economy	64400.00
0005432571262	26569	Economy	64400.00
0005435947020	26569	Economy	64400.00
0005435947014	26569	Economy	64400.00
0005435947012	26569	Economy	64400.00
0005435947022	26569	Economy	64400.00
0005435947016	26569	Economy	64400.00
0005435947015	26569	Economy	64400.00
0005435947013	26569	Economy	64400.00
0005432571261	26569	Economy	64400.00
0005435856134	26569	Economy	64400.00
0005435947018	26569	Economy	64400.00
0005435856136	26569	Economy	64400.00
0005435856135	26569	Economy	64400.00
0005432238837	363	Business	21500.00
0005433568112	363	Business	21500.00
0005433568086	363	Business	21500.00
0005433568103	363	Business	21500.00
0005433568072	363	Business	21500.00
0005433568083	363	Business	21500.00
0005433568120	363	Business	21500.00
0005433568096	363	Business	21500.00
0005433568102	363	Business	21500.00
0005433568113	363	Business	21500.00
0005433568088	363	Economy	7900.00
0005433568092	363	Economy	7200.00
0005433568100	363	Economy	7200.00
0005433568093	363	Economy	7200.00
0005433568122	363	Economy	7200.00
0005433568111	363	Economy	7200.00
0005433568099	363	Economy	7200.00
0005433568115	363	Economy	7200.00
0005432238839	363	Economy	7200.00
0005433568073	363	Economy	7200.00
0005433568121	363	Economy	7200.00
0005433568123	363	Economy	7200.00
0005433568089	363	Economy	7200.00
0005433568109	363	Economy	7200.00
0005433568107	363	Economy	7200.00
0005433568097	363	Economy	7200.00
0005433568094	363	Economy	7200.00
0005433568104	363	Economy	7200.00
0005433568085	363	Economy	7200.00
0005433568076	363	Economy	7200.00
0005433568078	363	Economy	7200.00
0005433568090	363	Economy	7200.00
0005433568108	363	Economy	7200.00
0005433568071	363	Economy	7200.00
0005432238836	363	Economy	7900.00
0005433568117	363	Economy	7900.00
0005433568084	363	Economy	7900.00
0005432238834	363	Economy	7200.00
0005433568118	363	Economy	7200.00
0005433568077	363	Economy	7200.00
0005433568116	363	Economy	7200.00
0005433568101	363	Economy	7200.00
0005433568091	363	Economy	7200.00
0005433568110	363	Economy	7200.00
0005432238835	363	Economy	7200.00
0005433568082	363	Economy	7200.00
0005432238833	363	Economy	7200.00
0005433568105	363	Economy	7200.00
0005433568098	363	Economy	7200.00
0005433568114	363	Economy	7200.00
0005433568070	363	Economy	7200.00
0005433568080	363	Economy	7200.00
0005433568095	363	Economy	7200.00
0005433568081	363	Economy	7200.00
0005433568087	363	Economy	7200.00
0005433568119	363	Economy	7200.00
0005433568074	363	Economy	7200.00
0005433568079	363	Economy	7200.00
0005432238838	363	Economy	7200.00
0005433568069	363	Economy	7200.00
0005433568106	363	Economy	7200.00
0005433568075	363	Economy	7200.00
0005433074234	11605	Business	21500.00
0005432947798	11605	Business	21500.00
0005432947802	11605	Business	21500.00
0005432947767	11605	Business	21500.00
0005432947785	11605	Business	21500.00
0005433074242	11605	Business	21500.00
0005433074232	11605	Business	21500.00
0005432947775	11605	Business	21500.00
0005432947766	11605	Business	21500.00
0005433074238	11605	Business	21500.00
0005433074254	11605	Business	21500.00
0005432192268	11605	Business	21500.00
0005432947777	11605	Economy	7900.00
0005433074231	11605	Economy	7900.00
0005432947770	11605	Economy	7900.00
0005433074244	11605	Economy	7200.00
0005432947768	11605	Economy	7200.00
0005433074246	11605	Economy	7200.00
0005433134064	11605	Economy	7200.00
0005432192269	11605	Economy	7200.00
0005432947797	11605	Economy	7200.00
0005432947776	11605	Economy	7200.00
0005432947779	11605	Economy	7200.00
0005433074252	11605	Economy	7200.00
0005433074248	11605	Economy	7200.00
0005433131634	11605	Economy	7200.00
0005432947793	11605	Economy	7200.00
0005432947791	11605	Economy	7200.00
0005432947769	11605	Economy	7200.00
0005433074236	11605	Economy	7200.00
0005432947800	11605	Economy	7200.00
0005433074241	11605	Economy	7200.00
0005432947784	11605	Economy	7200.00
0005433074226	11605	Economy	7200.00
0005432947787	11605	Economy	7200.00
0005432947786	11605	Economy	7200.00
0005432192266	11605	Economy	7200.00
0005432947796	11605	Economy	7200.00
0005432947764	11605	Economy	7200.00
0005432947771	11605	Economy	7200.00
0005433074227	11605	Economy	7200.00
0005433074233	11605	Economy	7200.00
0005432947803	11605	Economy	7200.00
0005432192267	11605	Economy	7200.00
0005433074247	11605	Economy	7200.00
0005432947789	11605	Economy	7200.00
0005432947780	11605	Economy	7200.00
0005432947794	11605	Economy	7900.00
0005433134062	11605	Economy	7900.00
0005432947788	11605	Economy	7200.00
0005433074240	11605	Economy	7200.00
0005433131632	11605	Economy	7200.00
0005433074229	11605	Economy	7200.00
0005433134063	11605	Economy	7200.00
0005432947778	11605	Economy	7200.00
0005433074237	11605	Economy	7200.00
0005432947765	11605	Economy	7200.00
0005432947799	11605	Economy	7200.00
0005432947772	11605	Economy	7200.00
0005432947795	11605	Economy	7200.00
0005433074230	11605	Economy	7200.00
0005433074253	11605	Economy	7200.00
0005433131631	11605	Economy	7200.00
0005432947804	11605	Economy	7200.00
0005432947783	11605	Economy	7200.00
0005433074245	11605	Economy	7200.00
0005433074243	11605	Economy	7200.00
0005432947782	11605	Economy	7200.00
0005433074239	11605	Economy	7200.00
0005432947792	11605	Economy	7200.00
0005432947790	11605	Economy	7200.00
0005432947774	11605	Economy	7200.00
0005433131630	11605	Economy	7200.00
0005433074250	11605	Economy	7200.00
0005433134060	11605	Economy	7200.00
0005433074228	11605	Economy	7200.00
0005433074249	11605	Economy	7200.00
0005433134061	11605	Economy	7200.00
0005432947781	11605	Economy	7200.00
0005433074251	11605	Economy	7200.00
0005432947801	11605	Economy	7200.00
0005433131633	11605	Economy	7200.00
0005433074235	11605	Economy	7200.00
0005432947773	11605	Economy	7200.00
0005433817411	10037	Economy	6300.00
0005433817409	10037	Economy	6300.00
0005433817408	10037	Economy	6300.00
0005433817410	10037	Economy	6300.00
0005434732924	13972	Economy	6300.00
0005434732922	13972	Economy	6300.00
0005434732925	13972	Economy	6300.00
0005434732923	13972	Economy	6300.00
0005433753307	2370	Business	184500.00
0005435981586	2370	Business	184500.00
0005433753299	2370	Business	184500.00
0005435981565	2370	Business	184500.00
0005435981560	2370	Business	184500.00
0005432655339	2370	Business	184500.00
0005435981576	2370	Business	184500.00
0005435981559	2370	Business	184500.00
0005433753329	2370	Business	184500.00
0005433753323	2370	Business	184500.00
0005435981567	2370	Business	184500.00
0005433753300	2370	Business	184500.00
0005435981561	2370	Business	184500.00
0005433753288	2370	Business	184500.00
0005433753309	2370	Business	184500.00
0005435981558	2370	Business	184500.00
0005433753333	2370	Business	184500.00
0005433753331	2370	Business	184500.00
0005435981564	2370	Business	184500.00
0005432655347	2370	Economy	67700.00
0005433766579	2370	Economy	67700.00
0005433753281	2370	Economy	67700.00
0005433753335	2370	Economy	61500.00
0005435981589	2370	Economy	61500.00
0005432300169	2370	Economy	61500.00
0005432225956	2370	Economy	61500.00
0005433753330	2370	Economy	61500.00
0005435981571	2370	Economy	61500.00
0005432300170	2370	Economy	61500.00
0005435981588	2370	Economy	61500.00
0005432225954	2370	Economy	61500.00
0005433753321	2370	Economy	61500.00
0005433753308	2370	Economy	61500.00
0005433753314	2370	Economy	61500.00
0005435981574	2370	Economy	61500.00
0005433753327	2370	Economy	61500.00
0005433753294	2370	Economy	61500.00
0005433766576	2370	Economy	61500.00
0005433753291	2370	Economy	61500.00
0005433753310	2370	Economy	61500.00
0005433753334	2370	Economy	61500.00
0005433753284	2370	Economy	61500.00
0005432300168	2370	Economy	61500.00
0005433753304	2370	Economy	61500.00
0005435981583	2370	Economy	61500.00
0005433753326	2370	Economy	61500.00
0005435981590	2370	Economy	61500.00
0005435981581	2370	Economy	61500.00
0005433753282	2370	Economy	61500.00
0005433766578	2370	Economy	61500.00
0005433764645	2370	Economy	61500.00
0005435981569	2370	Economy	61500.00
0005432300167	2370	Economy	61500.00
0005435981572	2370	Economy	61500.00
0005433753320	2370	Economy	61500.00
0005432655338	2370	Economy	61500.00
0005433753280	2370	Economy	61500.00
0005432225958	2370	Economy	61500.00
0005435981568	2370	Economy	61500.00
0005435981584	2370	Economy	61500.00
0005435981552	2370	Economy	61500.00
0005432655340	2370	Economy	61500.00
0005433753328	2370	Economy	61500.00
0005435981551	2370	Economy	61500.00
0005433753317	2370	Economy	61500.00
0005433764646	2370	Economy	61500.00
0005435981573	2370	Economy	61500.00
0005435981548	2370	Economy	61500.00
0005433753319	2370	Economy	61500.00
0005435981577	2370	Economy	61500.00
0005433753311	2370	Economy	61500.00
0005433753293	2370	Economy	61500.00
0005433753295	2370	Economy	61500.00
0005432655346	2370	Economy	61500.00
0005433766580	2370	Economy	61500.00
0005433753298	2370	Economy	61500.00
0005435981570	2370	Economy	61500.00
0005432655342	2370	Economy	61500.00
0005433753302	2370	Economy	61500.00
0005432225953	2370	Economy	61500.00
0005435981587	2370	Economy	61500.00
0005433766577	2370	Economy	61500.00
0005433753312	2370	Economy	61500.00
0005433753296	2370	Economy	61500.00
0005435981592	2370	Economy	67700.00
0005435981591	2370	Economy	61500.00
0005432300171	2370	Economy	61500.00
0005432655344	2370	Economy	61500.00
0005435981555	2370	Economy	61500.00
0005433753332	2370	Economy	61500.00
0005435981585	2370	Economy	61500.00
0005435981575	2370	Economy	61500.00
0005433753322	2370	Economy	61500.00
0005435981553	2370	Economy	61500.00
0005433753287	2370	Economy	61500.00
0005432655348	2370	Economy	61500.00
0005433753289	2370	Economy	61500.00
0005435981562	2370	Economy	61500.00
0005435981549	2370	Economy	61500.00
0005433753283	2370	Economy	61500.00
0005433753286	2370	Economy	61500.00
0005433753290	2370	Economy	61500.00
0005433753279	2370	Economy	61500.00
0005433753285	2370	Economy	61500.00
0005435981550	2370	Economy	61500.00
0005435981566	2370	Economy	61500.00
0005433753318	2370	Economy	61500.00
0005433753297	2370	Economy	61500.00
0005433753306	2370	Economy	61500.00
0005433753292	2370	Economy	61500.00
0005432655343	2370	Economy	61500.00
0005433753324	2370	Economy	61500.00
0005435981580	2370	Economy	61500.00
0005432225959	2370	Economy	61500.00
0005432655345	2370	Economy	61500.00
0005435981593	2370	Economy	61500.00
0005435981563	2370	Economy	61500.00
0005433753316	2370	Economy	61500.00
0005435981557	2370	Economy	61500.00
0005432655349	2370	Economy	61500.00
0005435981556	2370	Economy	61500.00
0005432225957	2370	Economy	61500.00
0005432655341	2370	Economy	61500.00
0005435981554	2370	Economy	61500.00
0005433753303	2370	Economy	61500.00
0005433753301	2370	Economy	61500.00
0005435981579	2370	Economy	61500.00
0005432225955	2370	Economy	61500.00
0005435981582	2370	Economy	61500.00
0005433753313	2370	Economy	61500.00
0005432300166	2370	Economy	61500.00
0005433753325	2370	Economy	61500.00
0005435981578	2370	Economy	61500.00
0005433753305	2370	Economy	61500.00
0005433753315	2370	Economy	61500.00
0005433434217	26174	Business	184500.00
0005432984559	26174	Business	184500.00
0005433434210	26174	Business	184500.00
0005433434225	26174	Business	184500.00
0005432984541	26174	Business	184500.00
0005432984550	26174	Business	184500.00
0005433434212	26174	Business	184500.00
0005432984551	26174	Business	184500.00
0005432869413	26174	Business	184500.00
0005433434211	26174	Business	184500.00
0005433434236	26174	Business	184500.00
0005432984552	26174	Business	184500.00
0005433434220	26174	Economy	61500.00
0005432984540	26174	Economy	61500.00
0005432984536	26174	Economy	61500.00
0005433434228	26174	Economy	61500.00
0005433434209	26174	Economy	61500.00
0005432984555	26174	Economy	61500.00
0005432869414	26174	Economy	61500.00
0005434731102	26174	Economy	61500.00
0005432984543	26174	Economy	61500.00
0005433434218	26174	Economy	61500.00
0005433434234	26174	Economy	61500.00
0005432984546	26174	Economy	61500.00
0005433434226	26174	Economy	61500.00
0005432984544	26174	Economy	61500.00
0005432984564	26174	Economy	61500.00
0005433434221	26174	Economy	61500.00
0005433434231	26174	Economy	61500.00
0005432869416	26174	Economy	61500.00
0005433434213	26174	Economy	61500.00
0005432984542	26174	Economy	61500.00
0005433434229	26174	Economy	61500.00
0005433434232	26174	Economy	61500.00
0005432984534	26174	Economy	61500.00
0005432984557	26174	Economy	61500.00
0005432869415	26174	Economy	61500.00
0005432984554	26174	Economy	61500.00
0005432984556	26174	Economy	61500.00
0005432051078	26174	Economy	61500.00
0005433434233	26174	Economy	61500.00
0005432049405	26174	Economy	61500.00
0005434731101	26174	Economy	61500.00
0005434731100	26174	Economy	61500.00
0005432984561	26174	Economy	61500.00
0005432984545	26174	Economy	61500.00
0005432984537	26174	Economy	61500.00
0005433434223	26174	Economy	61500.00
0005432984535	26174	Economy	61500.00
0005433434227	26174	Economy	61500.00
0005432049406	26174	Economy	61500.00
0005433434230	26174	Economy	61500.00
0005434731103	26174	Economy	61500.00
0005432984560	26174	Economy	61500.00
0005432984549	26174	Economy	61500.00
0005432984538	26174	Economy	61500.00
0005432049404	26174	Economy	61500.00
0005433434222	26174	Economy	61500.00
0005433434224	26174	Economy	61500.00
0005432984558	26174	Economy	61500.00
0005432984566	26174	Economy	61500.00
0005433434216	26174	Economy	61500.00
0005432984553	26174	Economy	61500.00
0005433434235	26174	Economy	61500.00
0005433434219	26174	Economy	61500.00
0005432984547	26174	Economy	61500.00
0005432984562	26174	Economy	61500.00
0005432869412	26174	Economy	61500.00
0005432984533	26174	Economy	61500.00
0005432984539	26174	Economy	61500.00
0005432984563	26174	Economy	61500.00
0005432051077	26174	Economy	61500.00
0005433434214	26174	Economy	61500.00
0005432984565	26174	Economy	61500.00
0005432049403	26174	Economy	61500.00
0005432984548	26174	Economy	61500.00
0005433434215	26174	Economy	61500.00
0005434373922	1502	Business	38900.00
0005434373934	1502	Business	38900.00
0005432267783	1502	Business	38900.00
0005434373944	1502	Business	38900.00
0005434373928	1502	Business	38900.00
0005434373920	1502	Business	38900.00
0005434373900	1502	Economy	13000.00
0005434373931	1502	Economy	13000.00
0005432267787	1502	Economy	13000.00
0005434373905	1502	Economy	13000.00
0005434373919	1502	Economy	13000.00
0005434373915	1502	Economy	13000.00
0005434373910	1502	Economy	13000.00
0005434373914	1502	Economy	13000.00
0005434373936	1502	Economy	13000.00
0005432267786	1502	Economy	13000.00
0005432267784	1502	Economy	13000.00
0005434373902	1502	Economy	13000.00
0005434373935	1502	Economy	13000.00
0005434373940	1502	Economy	13000.00
0005434373933	1502	Economy	13000.00
0005434373937	1502	Economy	13000.00
0005433461553	1502	Economy	13000.00
0005434373912	1502	Economy	14300.00
0005432267789	1502	Economy	14300.00
0005434373907	1502	Economy	14300.00
0005434373899	1502	Economy	13000.00
0005434373908	1502	Economy	13000.00
0005434373926	1502	Economy	13000.00
0005434373942	1502	Economy	13000.00
0005434373932	1502	Economy	13000.00
0005434373941	1502	Economy	13000.00
0005434373901	1502	Economy	13000.00
0005434373930	1502	Economy	13000.00
0005434373903	1502	Economy	13000.00
0005434373925	1502	Economy	13000.00
0005434373916	1502	Economy	13000.00
0005434373939	1502	Economy	13000.00
0005434373924	1502	Economy	13000.00
0005434373906	1502	Economy	13000.00
0005434373917	1502	Economy	13000.00
0005434373929	1502	Economy	13000.00
0005433461552	1502	Economy	13000.00
0005434373943	1502	Economy	13000.00
0005434373911	1502	Economy	13000.00
0005434373918	1502	Economy	13000.00
0005434373927	1502	Economy	13000.00
0005434373913	1502	Economy	13000.00
0005434373898	1502	Economy	13000.00
0005433460400	1502	Economy	13000.00
0005434373938	1502	Economy	13000.00
0005434373909	1502	Economy	13000.00
0005432267785	1502	Economy	13000.00
0005434373904	1502	Economy	13000.00
0005432267788	1502	Economy	13000.00
0005434373923	1502	Economy	13000.00
0005434373921	1502	Economy	13000.00
0005433460401	1502	Economy	13000.00
0005433150840	20115	Business	38900.00
0005433150847	20115	Business	38900.00
0005433150861	20115	Business	38900.00
0005433150850	20115	Business	38900.00
0005434029617	20115	Business	38900.00
0005434029616	20115	Economy	13000.00
0005433150833	20115	Business	38900.00
0005433150837	20115	Economy	13000.00
0005433150856	20115	Economy	13000.00
0005433150836	20115	Economy	13000.00
0005432056235	20115	Economy	13000.00
0005433150849	20115	Economy	13000.00
0005433150842	20115	Economy	13000.00
0005433931417	20115	Economy	13000.00
0005433931419	20115	Economy	13000.00
0005433150843	20115	Economy	13000.00
0005433150832	20115	Economy	13000.00
0005433150853	20115	Economy	14300.00
0005433150852	20115	Economy	14300.00
0005433150851	20115	Economy	13000.00
0005433150848	20115	Economy	13000.00
0005433150829	20115	Economy	13000.00
0005433150863	20115	Economy	13000.00
0005433150831	20115	Economy	13000.00
0005433150860	20115	Economy	13000.00
0005432056238	20115	Economy	13000.00
0005433764645	20115	Economy	13000.00
0005433150845	20115	Economy	13000.00
0005433764646	20115	Economy	13000.00
0005433931418	20115	Economy	13000.00
0005432056236	20115	Economy	13000.00
0005433150854	20115	Economy	13000.00
0005433150834	20115	Economy	13000.00
0005433150830	20115	Economy	13000.00
0005433150839	20115	Economy	13000.00
0005432056237	20115	Economy	13000.00
0005433150846	20115	Economy	13000.00
0005433150858	20115	Economy	13000.00
0005433150838	20115	Economy	13000.00
0005433150841	20115	Economy	13000.00
0005433150857	20115	Economy	13000.00
0005434029618	20115	Economy	13000.00
0005433150859	20115	Economy	13000.00
0005433150855	20115	Economy	13000.00
0005433150862	20115	Economy	13000.00
0005433150828	20115	Economy	13000.00
0005433150835	20115	Economy	13000.00
0005433150844	20115	Economy	13000.00
0005432423653	585	Business	27500.00
0005432423678	585	Business	27500.00
0005432423665	585	Business	27500.00
0005432423662	585	Business	27500.00
0005432423692	585	Business	27500.00
0005432423675	585	Business	27500.00
0005432423686	585	Business	27500.00
0005432423684	585	Business	27500.00
0005432423682	585	Business	27500.00
0005432423685	585	Business	27500.00
0005432423691	585	Business	27500.00
0005432423671	585	Business	27500.00
0005432423661	585	Economy	10100.00
0005432423690	585	Economy	10100.00
0005432282749	585	Economy	9200.00
0005432282752	585	Economy	9200.00
0005432423680	585	Economy	9200.00
0005432282751	585	Economy	9200.00
0005432423683	585	Economy	9200.00
0005432423673	585	Economy	9200.00
0005432423679	585	Economy	9200.00
0005432282750	585	Economy	9200.00
0005432282748	585	Economy	9200.00
0005432423660	585	Economy	9200.00
0005432423676	585	Economy	9200.00
0005432423669	585	Economy	9200.00
0005432282754	585	Economy	9200.00
0005432423658	585	Economy	9200.00
0005432282747	585	Economy	9200.00
0005432282753	585	Economy	9200.00
0005432423693	585	Economy	9200.00
0005432423668	585	Economy	10100.00
0005432423664	585	Economy	9200.00
0005432423681	585	Economy	9200.00
0005432423674	585	Economy	9200.00
0005432423663	585	Economy	9200.00
0005432423688	585	Economy	9200.00
0005432423667	585	Economy	9200.00
0005432423649	585	Economy	9200.00
0005432423657	585	Economy	9200.00
0005432423672	585	Economy	9200.00
0005432423689	585	Economy	9200.00
0005432423659	585	Economy	9200.00
0005432423652	585	Economy	9200.00
0005432423677	585	Economy	9200.00
0005432423687	585	Economy	9200.00
0005432423648	585	Economy	9200.00
0005432423650	585	Economy	9200.00
0005432423654	585	Economy	9200.00
0005432423670	585	Economy	9200.00
0005432423655	585	Economy	9200.00
0005432423656	585	Economy	9200.00
0005432423651	585	Economy	9200.00
0005432423666	585	Economy	9200.00
0005432302267	12907	Economy	9200.00
0005432302271	12907	Economy	10100.00
0005432302270	12907	Economy	9200.00
0005432302268	12907	Economy	9200.00
0005432302269	12907	Economy	9200.00
0005434022621	487	Business	24500.00
0005434022601	487	Business	24500.00
0005434022611	487	Business	24500.00
0005434022594	487	Business	24500.00
0005434022605	487	Business	24500.00
0005434031946	487	Business	24500.00
0005434022618	487	Business	24500.00
0005434022579	487	Business	24500.00
0005434022613	487	Business	24500.00
0005434022631	487	Business	24500.00
0005434022622	487	Business	24500.00
0005434022625	487	Economy	9000.00
0005434022610	487	Economy	8200.00
0005434022630	487	Economy	8200.00
0005434022602	487	Economy	8200.00
0005432235515	487	Economy	8200.00
0005434022638	487	Economy	8200.00
0005434022629	487	Economy	8200.00
0005434022587	487	Economy	8200.00
0005432235516	487	Economy	8200.00
0005434029615	487	Economy	8200.00
0005434022606	487	Economy	8200.00
0005432235517	487	Economy	8200.00
0005432045579	487	Economy	8200.00
0005434022597	487	Economy	8200.00
0005434022620	487	Economy	8200.00
0005434022578	487	Economy	8200.00
0005434022571	487	Economy	8200.00
0005434022590	487	Economy	8200.00
0005434022582	487	Economy	8200.00
0005434022584	487	Economy	8200.00
0005434022633	487	Economy	8200.00
0005434022615	487	Economy	8200.00
0005434022577	487	Economy	8200.00
0005434022627	487	Economy	8200.00
0005434028246	487	Economy	8200.00
0005432235513	487	Economy	8200.00
0005434022637	487	Economy	8200.00
0005434022592	487	Economy	8200.00
0005432235518	487	Economy	8200.00
0005434022608	487	Economy	8200.00
0005434022583	487	Economy	8200.00
0005434022570	487	Economy	8200.00
0005434022635	487	Economy	8200.00
0005434022616	487	Economy	8200.00
0005434022609	487	Economy	8200.00
0005434022595	487	Economy	8200.00
0005434022624	487	Economy	8200.00
0005434022572	487	Economy	8200.00
0005434022585	487	Economy	9000.00
0005434022576	487	Economy	8200.00
0005434029614	487	Economy	8200.00
0005434022619	487	Economy	8200.00
0005434022628	487	Economy	9000.00
0005434022588	487	Economy	8200.00
0005434022607	487	Economy	8200.00
0005434022580	487	Economy	8200.00
0005432045581	487	Economy	8200.00
0005434022623	487	Economy	8200.00
0005434022636	487	Economy	8200.00
0005434022573	487	Economy	8200.00
0005434029613	487	Economy	8200.00
0005434022586	487	Economy	8200.00
0005434022589	487	Economy	8200.00
0005434022634	487	Economy	8200.00
0005432045580	487	Economy	8200.00
0005434022581	487	Economy	8200.00
0005434022574	487	Economy	8200.00
0005434031947	487	Economy	8200.00
0005434022598	487	Economy	8200.00
0005434022593	487	Economy	8200.00
0005434031944	487	Economy	8200.00
0005434028249	487	Economy	8200.00
0005434022612	487	Economy	8200.00
0005434022632	487	Economy	8200.00
0005434031945	487	Economy	8200.00
0005434022599	487	Economy	8200.00
0005434022603	487	Economy	8200.00
0005434028247	487	Economy	8200.00
0005434022596	487	Economy	8200.00
0005432235514	487	Economy	8200.00
0005434022575	487	Economy	8200.00
0005434022614	487	Economy	8200.00
0005434022600	487	Economy	8200.00
0005434022591	487	Economy	8200.00
0005434022617	487	Economy	8200.00
0005434028248	487	Economy	8200.00
0005434022626	487	Economy	8200.00
0005434022604	487	Economy	8200.00
0005433057209	12658	Business	24500.00
0005433057223	12658	Business	24500.00
0005433057237	12658	Business	24500.00
0005433057225	12658	Business	24500.00
0005433057248	12658	Business	24500.00
0005433057247	12658	Economy	9000.00
0005433057238	12658	Economy	8200.00
0005434735603	12658	Economy	8200.00
0005433057227	12658	Economy	8200.00
0005432157459	12658	Economy	8200.00
0005433057231	12658	Economy	8200.00
0005433057242	12658	Economy	8200.00
0005433057224	12658	Economy	8200.00
0005433057212	12658	Economy	8200.00
0005433057236	12658	Economy	8200.00
0005433057217	12658	Economy	8200.00
0005433057240	12658	Economy	8200.00
0005433057219	12658	Economy	8200.00
0005433057211	12658	Economy	8200.00
0005433929546	12658	Economy	8200.00
0005433684388	12658	Economy	8200.00
0005432156293	12658	Economy	8200.00
0005433057246	12658	Economy	8200.00
0005433057214	12658	Economy	8200.00
0005433684387	12658	Economy	8200.00
0005433929543	12658	Economy	8200.00
0005433057229	12658	Economy	8200.00
0005433057213	12658	Economy	8200.00
0005433057239	12658	Economy	8200.00
0005433057249	12658	Economy	8200.00
0005433057226	12658	Economy	8200.00
0005433057232	12658	Economy	8200.00
0005433057220	12658	Economy	8200.00
0005433057216	12658	Economy	8200.00
0005434735604	12658	Economy	8200.00
0005433057228	12658	Economy	8200.00
0005432156291	12658	Economy	8200.00
0005432156292	12658	Economy	8200.00
0005433057234	12658	Economy	9000.00
0005433057222	12658	Economy	9000.00
0005433057243	12658	Economy	8200.00
0005433057210	12658	Economy	8200.00
0005433929545	12658	Economy	8200.00
0005433057218	12658	Economy	8200.00
0005432156294	12658	Economy	8200.00
0005433057244	12658	Economy	8200.00
0005434735606	12658	Economy	8200.00
0005433057241	12658	Economy	8200.00
0005433057215	12658	Economy	8200.00
0005433057233	12658	Economy	8200.00
0005433057230	12658	Economy	8200.00
0005432157460	12658	Economy	8200.00
0005433684386	12658	Economy	8200.00
0005434735602	12658	Economy	8200.00
0005433057221	12658	Economy	8200.00
0005433057245	12658	Economy	8200.00
0005433929544	12658	Economy	8200.00
0005433057235	12658	Economy	8200.00
0005434735605	12658	Economy	8200.00
0005433921738	2153	Business	34700.00
0005433921753	2153	Business	34700.00
0005433921767	2153	Business	34700.00
0005433921771	2153	Business	34700.00
0005433921770	2153	Business	34700.00
0005433921692	2153	Business	34700.00
0005433921776	2153	Business	34700.00
0005432044478	2153	Business	34700.00
0005433921775	2153	Business	34700.00
0005433921711	2153	Business	34700.00
0005433921742	2153	Business	34700.00
0005433929545	2153	Business	34700.00
0005433921710	2153	Business	34700.00
0005433921705	2153	Business	34700.00
0005433921780	2153	Business	34700.00
0005433921694	2153	Business	34700.00
0005433921724	2153	Business	34700.00
0005433921723	2153	Economy	12700.00
0005432044480	2153	Economy	11600.00
0005433921726	2153	Economy	11600.00
0005433921708	2153	Economy	11600.00
0005433921699	2153	Economy	11600.00
0005433921766	2153	Economy	11600.00
0005433921762	2153	Economy	11600.00
0005433921768	2153	Economy	11600.00
0005432231392	2153	Economy	11600.00
0005433921712	2153	Economy	11600.00
0005432231385	2153	Economy	11600.00
0005432231390	2153	Economy	11600.00
0005433921741	2153	Economy	11600.00
0005433921758	2153	Economy	11600.00
0005433921747	2153	Economy	11600.00
0005433921769	2153	Economy	11600.00
0005433921717	2153	Economy	11600.00
0005433929546	2153	Economy	11600.00
0005433921764	2153	Economy	11600.00
0005432231394	2153	Economy	11600.00
0005433921736	2153	Economy	11600.00
0005433921707	2153	Economy	11600.00
0005433921749	2153	Economy	11600.00
0005433921743	2153	Economy	11600.00
0005433921713	2153	Economy	11600.00
0005433921687	2153	Economy	11600.00
0005432231389	2153	Economy	11600.00
0005433921730	2153	Economy	11600.00
0005433921746	2153	Economy	11600.00
0005432231391	2153	Economy	11600.00
0005433921688	2153	Economy	11600.00
0005433921728	2153	Economy	11600.00
0005433921695	2153	Economy	11600.00
0005432231395	2153	Economy	11600.00
0005433921716	2153	Economy	11600.00
0005433921754	2153	Economy	11600.00
0005433921706	2153	Economy	11600.00
0005432231396	2153	Economy	11600.00
0005433921781	2153	Economy	11600.00
0005433921773	2153	Economy	11600.00
0005433921685	2153	Economy	11600.00
0005433921757	2153	Economy	11600.00
0005433875352	2153	Economy	11600.00
0005432044479	2153	Economy	11600.00
0005433921714	2153	Economy	11600.00
0005433921709	2153	Economy	11600.00
0005433921745	2153	Economy	11600.00
0005433921691	2153	Economy	11600.00
0005433921689	2153	Economy	11600.00
0005433921732	2153	Economy	11600.00
0005433921719	2153	Economy	11600.00
0005433921697	2153	Economy	11600.00
0005433921759	2153	Economy	11600.00
0005433921761	2153	Economy	11600.00
0005433921720	2153	Economy	11600.00
0005433921750	2153	Economy	11600.00
0005433921721	2153	Economy	11600.00
0005433931417	2153	Economy	12700.00
0005433921735	2153	Economy	11600.00
0005433921715	2153	Economy	12700.00
0005433921703	2153	Economy	11600.00
0005433921698	2153	Economy	11600.00
0005433921777	2153	Economy	11600.00
0005433921700	2153	Economy	11600.00
0005433921774	2153	Economy	11600.00
0005433921778	2153	Economy	11600.00
0005433921772	2153	Economy	11600.00
0005433921718	2153	Economy	11600.00
0005433931418	2153	Economy	11600.00
0005433921729	2153	Economy	11600.00
0005433921727	2153	Economy	11600.00
0005433921740	2153	Economy	11600.00
0005433921686	2153	Economy	11600.00
0005433921690	2153	Economy	11600.00
0005433931419	2153	Economy	11600.00
0005433921702	2153	Economy	11600.00
0005433921782	2153	Economy	11600.00
0005433921765	2153	Economy	11600.00
0005433921748	2153	Economy	11600.00
0005432231388	2153	Economy	11600.00
0005433921737	2153	Economy	11600.00
0005433921751	2153	Economy	11600.00
0005433921696	2153	Economy	11600.00
0005433929543	2153	Economy	11600.00
0005433921701	2153	Economy	11600.00
0005433921733	2153	Economy	11600.00
0005433921693	2153	Economy	11600.00
0005433921752	2153	Economy	11600.00
0005433921755	2153	Economy	11600.00
0005433921734	2153	Economy	11600.00
0005433921756	2153	Economy	11600.00
0005433921739	2153	Economy	11600.00
0005433921725	2153	Economy	11600.00
0005433921744	2153	Economy	11600.00
0005432231393	2153	Economy	11600.00
0005433921779	2153	Economy	11600.00
0005432231386	2153	Economy	11600.00
0005433921760	2153	Economy	11600.00
0005433921722	2153	Economy	11600.00
0005432231387	2153	Economy	11600.00
0005433929544	2153	Economy	11600.00
0005433921731	2153	Economy	11600.00
0005433921763	2153	Economy	11600.00
0005433921704	2153	Economy	11600.00
0005433035446	24129	Business	34700.00
0005432749750	24129	Business	34700.00
0005433035440	24129	Business	34700.00
0005433035444	24129	Business	34700.00
0005433035449	24129	Business	34700.00
0005433035425	24129	Business	34700.00
0005434028252	24129	Business	34700.00
0005433035430	24129	Business	34700.00
0005432207620	24129	Business	34700.00
0005434028251	24129	Business	34700.00
0005433035426	24129	Business	34700.00
0005433035431	24129	Business	34700.00
0005433035445	24129	Business	34700.00
0005433035442	24129	Economy	12700.00
0005433035457	24129	Economy	12700.00
0005433035415	24129	Economy	11600.00
0005432206102	24129	Economy	11600.00
0005433035439	24129	Economy	11600.00
0005433035419	24129	Economy	11600.00
0005433035421	24129	Economy	11600.00
0005433035452	24129	Economy	11600.00
0005433035463	24129	Economy	11600.00
0005433035450	24129	Economy	11600.00
0005432207621	24129	Economy	11600.00
0005433035437	24129	Economy	11600.00
0005434028250	24129	Economy	11600.00
0005433035462	24129	Economy	11600.00
0005433035422	24129	Economy	11600.00
0005433035428	24129	Economy	11600.00
0005433035424	24129	Economy	11600.00
0005433035448	24129	Economy	11600.00
0005433035435	24129	Economy	11600.00
0005433035458	24129	Economy	11600.00
0005433035427	24129	Economy	11600.00
0005433035456	24129	Economy	11600.00
0005432206100	24129	Economy	11600.00
0005433035454	24129	Economy	11600.00
0005432749749	24129	Economy	11600.00
0005432206101	24129	Economy	11600.00
0005433035412	24129	Economy	11600.00
0005432207619	24129	Economy	11600.00
0005433035411	24129	Economy	11600.00
0005433035429	24129	Economy	11600.00
0005433035461	24129	Economy	11600.00
0005433035420	24129	Economy	11600.00
0005433035416	24129	Economy	11600.00
0005433035418	24129	Economy	11600.00
0005433035432	24129	Economy	11600.00
0005433035433	24129	Economy	11600.00
0005433035453	24129	Economy	11600.00
0005433035459	24129	Economy	11600.00
0005432206098	24129	Economy	11600.00
0005434028253	24129	Economy	11600.00
0005433035413	24129	Economy	11600.00
0005432206097	24129	Economy	11600.00
0005433035455	24129	Economy	11600.00
0005433035443	24129	Economy	11600.00
0005433035438	24129	Economy	11600.00
0005433035451	24129	Economy	11600.00
0005432206099	24129	Economy	11600.00
0005433035436	24129	Economy	11600.00
0005433035414	24129	Economy	11600.00
0005433035423	24129	Economy	11600.00
0005433035447	24129	Economy	11600.00
0005433035417	24129	Economy	11600.00
0005433035460	24129	Economy	11600.00
0005433035441	24129	Economy	11600.00
0005433035434	24129	Economy	11600.00
0005434723483	288	Business	83700.00
0005435142360	288	Business	83700.00
0005432277589	288	Business	83700.00
0005434550314	288	Business	83700.00
0005434723489	288	Business	83700.00
0005432277585	288	Business	83700.00
0005434723440	288	Business	83700.00
0005434550335	288	Business	83700.00
0005434550368	288	Business	83700.00
0005435142349	288	Business	83700.00
0005434550325	288	Business	83700.00
0005434723537	288	Business	83700.00
0005434735598	288	Business	83700.00
0005434723504	288	Business	83700.00
0005434723556	288	Business	83700.00
0005434723540	288	Business	83700.00
0005434723435	288	Comfort	47400.00
0005434723441	288	Comfort	47400.00
0005434550364	288	Comfort	47400.00
0005434723548	288	Comfort	47400.00
0005434550351	288	Comfort	47400.00
0005434550330	288	Comfort	47400.00
0005434723502	288	Comfort	47400.00
0005434550316	288	Comfort	47400.00
0005432277584	288	Comfort	47400.00
0005434731096	288	Comfort	47400.00
0005432277591	288	Comfort	47400.00
0005434723511	288	Comfort	47400.00
0005434723505	288	Comfort	47400.00
0005435142358	288	Comfort	47400.00
0005434723498	288	Comfort	47400.00
0005434723453	288	Comfort	47400.00
0005434723452	288	Comfort	47400.00
0005432277582	288	Comfort	47400.00
0005434723475	288	Comfort	47400.00
0005434723536	288	Comfort	47400.00
0005434550365	288	Comfort	47400.00
0005432277587	288	Comfort	47400.00
0005434723543	288	Comfort	47400.00
0005432277594	288	Comfort	47400.00
0005435142353	288	Comfort	47400.00
0005434723469	288	Economy	27900.00
0005432277592	288	Economy	27900.00
0005434723487	288	Economy	27900.00
0005434550354	288	Economy	27900.00
0005434550357	288	Economy	27900.00
0005434735599	288	Economy	27900.00
0005434723527	288	Economy	27900.00
0005434723507	288	Economy	27900.00
0005434731098	288	Economy	27900.00
0005434723519	288	Economy	27900.00
0005434550362	288	Economy	27900.00
0005434723438	288	Economy	27900.00
0005434723459	288	Economy	27900.00
0005434550336	288	Economy	27900.00
0005434550312	288	Economy	27900.00
0005434550341	288	Economy	27900.00
0005434735601	288	Economy	27900.00
0005434723521	288	Economy	27900.00
0005435142357	288	Economy	27900.00
0005434723526	288	Economy	27900.00
0005434723555	288	Economy	27900.00
0005434550337	288	Economy	27900.00
0005434723530	288	Economy	27900.00
0005434723468	288	Economy	27900.00
0005434723456	288	Economy	27900.00
0005435142352	288	Economy	27900.00
0005434550355	288	Economy	27900.00
0005434550349	288	Economy	27900.00
0005435142356	288	Economy	27900.00
0005434723466	288	Economy	27900.00
0005434723508	288	Economy	27900.00
0005434723494	288	Economy	27900.00
0005434723454	288	Economy	27900.00
0005432277583	288	Economy	27900.00
0005435142361	288	Economy	27900.00
0005434723518	288	Economy	27900.00
0005434723500	288	Economy	27900.00
0005432277595	288	Economy	27900.00
0005434723471	288	Economy	27900.00
0005434723465	288	Economy	27900.00
0005434723478	288	Economy	27900.00
0005434550350	288	Economy	27900.00
0005435142355	288	Economy	30700.00
0005434723464	288	Economy	30700.00
0005434550360	288	Economy	27900.00
0005434723506	288	Economy	27900.00
0005434302388	288	Economy	27900.00
0005434550353	288	Economy	30700.00
0005434550333	288	Economy	27900.00
0005434550317	288	Economy	27900.00
0005434550334	288	Economy	27900.00
0005434723541	288	Economy	27900.00
0005434723534	288	Economy	27900.00
0005434550363	288	Economy	27900.00
0005434550318	288	Economy	27900.00
0005434723538	288	Economy	27900.00
0005434723503	288	Economy	27900.00
0005434550359	288	Economy	27900.00
0005434723515	288	Economy	27900.00
0005434723446	288	Economy	27900.00
0005434302387	288	Economy	27900.00
0005434723514	288	Economy	27900.00
0005434723522	288	Economy	27900.00
0005434723532	288	Economy	27900.00
0005434550323	288	Economy	27900.00
0005434723473	288	Economy	27900.00
0005434723474	288	Economy	27900.00
0005434723513	288	Economy	27900.00
0005434723450	288	Economy	27900.00
0005435142351	288	Economy	27900.00
0005434723510	288	Economy	27900.00
0005434550358	288	Economy	27900.00
0005434723463	288	Economy	27900.00
0005434723444	288	Economy	27900.00
0005434723445	288	Economy	27900.00
0005435142350	288	Economy	27900.00
0005432277593	288	Economy	27900.00
0005434723470	288	Economy	27900.00
0005434735597	288	Economy	27900.00
0005434723436	288	Economy	27900.00
0005434723523	288	Economy	27900.00
0005434723476	288	Economy	27900.00
0005434550345	288	Economy	27900.00
0005434550332	288	Economy	27900.00
0005434723492	288	Economy	27900.00
0005434723488	288	Economy	27900.00
0005434723525	288	Economy	27900.00
0005435142359	288	Economy	27900.00
0005434723486	288	Economy	27900.00
0005434550367	288	Economy	27900.00
0005434723437	288	Economy	27900.00
0005434550339	288	Economy	27900.00
0005434550352	288	Economy	27900.00
0005432277596	288	Economy	27900.00
0005434550343	288	Economy	27900.00
0005434723451	288	Economy	27900.00
0005434550348	288	Economy	27900.00
0005434723533	288	Economy	27900.00
0005434723449	288	Economy	27900.00
0005434723458	288	Economy	27900.00
0005434723493	288	Economy	27900.00
0005434550324	288	Economy	27900.00
0005434723439	288	Economy	27900.00
0005434723484	288	Economy	27900.00
0005434723460	288	Economy	27900.00
0005434723472	288	Economy	27900.00
0005434723529	288	Economy	27900.00
0005434723550	288	Economy	27900.00
0005434302390	288	Economy	27900.00
0005434723481	288	Economy	30700.00
0005434723545	288	Economy	30700.00
0005434723447	288	Economy	27900.00
0005434723495	288	Economy	27900.00
0005434723479	288	Economy	27900.00
0005434723448	288	Economy	27900.00
0005434550331	288	Economy	27900.00
0005434550347	288	Economy	27900.00
0005435142362	288	Economy	27900.00
0005434550327	288	Economy	27900.00
0005432277586	288	Economy	27900.00
0005434723551	288	Economy	27900.00
0005434723553	288	Economy	27900.00
0005434550356	288	Economy	27900.00
0005434723554	288	Economy	27900.00
0005434550340	288	Economy	27900.00
0005434550328	288	Economy	27900.00
0005434723482	288	Economy	27900.00
0005434550346	288	Economy	27900.00
0005434723501	288	Economy	27900.00
0005434723485	288	Economy	27900.00
0005434723462	288	Economy	27900.00
0005435142354	288	Economy	27900.00
0005434723546	288	Economy	27900.00
0005434723467	288	Economy	27900.00
0005434550338	288	Economy	27900.00
0005434723461	288	Economy	27900.00
0005434723509	288	Economy	27900.00
0005434723496	288	Economy	27900.00
0005434723528	288	Economy	27900.00
0005434550322	288	Economy	27900.00
0005434723517	288	Economy	27900.00
0005434723443	288	Economy	27900.00
0005434723544	288	Economy	27900.00
0005434550366	288	Economy	27900.00
0005434723457	288	Economy	27900.00
0005434731099	288	Economy	27900.00
0005434302389	288	Economy	27900.00
0005434723434	288	Economy	27900.00
0005432277588	288	Economy	27900.00
0005434723535	288	Economy	27900.00
0005434550321	288	Economy	27900.00
0005434723455	288	Economy	27900.00
0005434550326	288	Economy	27900.00
0005434723520	288	Economy	27900.00
0005434723531	288	Economy	27900.00
0005434723512	288	Economy	27900.00
0005434735600	288	Economy	27900.00
0005434302386	288	Economy	27900.00
0005434550313	288	Economy	27900.00
0005432277590	288	Economy	27900.00
0005434550315	288	Economy	27900.00
0005434723516	288	Economy	27900.00
0005434723524	288	Economy	27900.00
0005434550320	288	Economy	27900.00
0005434723542	288	Economy	27900.00
0005434723547	288	Economy	27900.00
0005434723497	288	Economy	27900.00
0005434550342	288	Economy	27900.00
0005434723499	288	Economy	27900.00
0005434550344	288	Economy	27900.00
0005434723442	288	Economy	27900.00
0005434723549	288	Economy	27900.00
0005434550361	288	Economy	27900.00
0005434550319	288	Economy	27900.00
0005434550329	288	Economy	27900.00
0005434723491	288	Economy	27900.00
0005434723552	288	Economy	27900.00
0005434723480	288	Economy	27900.00
0005434723477	288	Economy	27900.00
0005434723539	288	Economy	27900.00
0005434723490	288	Economy	27900.00
0005434731097	288	Economy	27900.00
0005433233166	9841	Business	83700.00
0005433233195	9841	Business	83700.00
0005433233170	9841	Business	83700.00
0005433233186	9841	Business	83700.00
0005433233153	9841	Business	83700.00
0005433180691	9841	Business	83700.00
0005433233204	9841	Business	83700.00
0005433180699	9841	Business	83700.00
0005433180697	9841	Business	83700.00
0005433180693	9841	Business	83700.00
0005433180696	9841	Comfort	47400.00
0005433289725	9841	Comfort	47400.00
0005433233188	9841	Comfort	47400.00
0005433289728	9841	Comfort	47400.00
0005433289730	9841	Comfort	47400.00
0005433126768	9841	Comfort	47400.00
0005433233208	9841	Comfort	47400.00
0005433180694	9841	Comfort	47400.00
0005433180679	9841	Comfort	47400.00
0005433233205	9841	Comfort	47400.00
0005433233206	9841	Comfort	47400.00
0005433233152	9841	Comfort	47400.00
0005432199131	9841	Comfort	47400.00
0005433766578	9841	Economy	27900.00
0005433233158	9841	Economy	27900.00
0005433180680	9841	Economy	27900.00
0005432199136	9841	Economy	27900.00
0005433233198	9841	Economy	27900.00
0005433289727	9841	Economy	27900.00
0005433233184	9841	Economy	27900.00
0005433129201	9841	Economy	27900.00
0005433126770	9841	Economy	27900.00
0005432199135	9841	Economy	27900.00
0005433180688	9841	Economy	27900.00
0005433180689	9841	Economy	27900.00
0005433180686	9841	Economy	27900.00
0005433233161	9841	Economy	27900.00
0005433233151	9841	Economy	27900.00
0005433233150	9841	Economy	27900.00
0005433180684	9841	Economy	27900.00
0005433233187	9841	Economy	27900.00
0005433766580	9841	Economy	27900.00
0005433233155	9841	Economy	27900.00
0005432199130	9841	Economy	27900.00
0005433233154	9841	Economy	27900.00
0005433766579	9841	Economy	27900.00
0005433233197	9841	Economy	27900.00
0005433233189	9841	Economy	27900.00
0005433233159	9841	Economy	27900.00
0005433233190	9841	Economy	27900.00
0005433233173	9841	Economy	30700.00
0005433766576	9841	Economy	27900.00
0005433233168	9841	Economy	30700.00
0005433233196	9841	Economy	27900.00
0005433180675	9841	Economy	27900.00
0005433180681	9841	Economy	27900.00
0005433129198	9841	Economy	27900.00
0005433233180	9841	Economy	27900.00
0005434031949	9841	Economy	27900.00
0005434031952	9841	Economy	27900.00
0005433233160	9841	Economy	27900.00
0005433233147	9841	Economy	27900.00
0005433113498	9841	Economy	27900.00
0005433233172	9841	Economy	27900.00
0005433233164	9841	Economy	27900.00
0005433180678	9841	Economy	27900.00
0005433180676	9841	Economy	27900.00
0005433233177	9841	Economy	27900.00
0005433180700	9841	Economy	27900.00
0005433766577	9841	Economy	27900.00
0005433129200	9841	Economy	27900.00
0005433233181	9841	Economy	27900.00
0005433129199	9841	Economy	27900.00
0005433233194	9841	Economy	27900.00
0005433233163	9841	Economy	27900.00
0005433233199	9841	Economy	27900.00
0005433126769	9841	Economy	27900.00
0005433233185	9841	Economy	27900.00
0005433126771	9841	Economy	27900.00
0005433233176	9841	Economy	27900.00
0005433180690	9841	Economy	27900.00
0005433180683	9841	Economy	27900.00
0005432199133	9841	Economy	27900.00
0005433233192	9841	Economy	27900.00
0005433233148	9841	Economy	27900.00
0005433233169	9841	Economy	27900.00
0005433180685	9841	Economy	27900.00
0005434031951	9841	Economy	27900.00
0005433180674	9841	Economy	27900.00
0005433233156	9841	Economy	27900.00
0005434031950	9841	Economy	27900.00
0005433180692	9841	Economy	27900.00
0005433233157	9841	Economy	27900.00
0005433233203	9841	Economy	27900.00
0005433233167	9841	Economy	27900.00
0005433233165	9841	Economy	27900.00
0005433233145	9841	Economy	27900.00
0005433233182	9841	Economy	27900.00
0005433113497	9841	Economy	27900.00
0005433113499	9841	Economy	27900.00
0005433233183	9841	Economy	27900.00
0005433233201	9841	Economy	27900.00
0005433180682	9841	Economy	27900.00
0005433233146	9841	Economy	27900.00
0005433180695	9841	Economy	27900.00
0005433233162	9841	Economy	27900.00
0005433180687	9841	Economy	27900.00
0005432199134	9841	Economy	27900.00
0005433233171	9841	Economy	27900.00
0005433233175	9841	Economy	27900.00
0005433233179	9841	Economy	27900.00
0005433289729	9841	Economy	27900.00
0005433233207	9841	Economy	27900.00
0005433233149	9841	Economy	27900.00
0005433289726	9841	Economy	27900.00
0005433233191	9841	Economy	27900.00
0005433233200	9841	Economy	27900.00
0005433233144	9841	Economy	27900.00
0005433180677	9841	Economy	27900.00
0005432199132	9841	Economy	27900.00
0005433180698	9841	Economy	27900.00
0005433233174	9841	Economy	27900.00
0005433233193	9841	Economy	27900.00
0005433233178	9841	Economy	27900.00
0005434031948	9841	Economy	27900.00
0005433233202	9841	Economy	27900.00
0005434066399	7717	Business	42100.00
0005434066410	7717	Business	42100.00
0005432525771	7717	Business	42100.00
0005434066426	7717	Business	42100.00
0005432525803	7717	Business	42100.00
0005432069413	7717	Business	42100.00
0005434066400	7717	Business	42100.00
0005432525812	7717	Business	42100.00
0005432525798	7717	Business	42100.00
0005432525854	7717	Business	42100.00
0005434066388	7717	Business	42100.00
0005434066417	7717	Business	42100.00
0005434066367	7717	Business	42100.00
0005434066371	7717	Business	42100.00
0005432069420	7717	Business	42100.00
0005434066396	7717	Business	42100.00
0005432525897	7717	Business	42100.00
0005432525855	7717	Business	42100.00
0005432525786	7717	Business	42100.00
0005432525881	7717	Business	42100.00
0005432150063	7717	Business	42100.00
0005432525789	7717	Comfort	23900.00
0005432525810	7717	Comfort	23900.00
0005432525783	7717	Comfort	23900.00
0005432525895	7717	Comfort	23900.00
0005432525872	7717	Comfort	23900.00
0005432069416	7717	Comfort	23900.00
0005432525840	7717	Comfort	23900.00
0005432525831	7717	Comfort	23900.00
0005434066404	7717	Comfort	23900.00
0005434066393	7717	Comfort	23900.00
0005434066439	7717	Comfort	23900.00
0005432525900	7717	Comfort	23900.00
0005432525861	7717	Comfort	23900.00
0005434066395	7717	Comfort	23900.00
0005434066368	7717	Comfort	23900.00
0005432525795	7717	Comfort	23900.00
0005432069423	7717	Comfort	23900.00
0005434066435	7717	Comfort	23900.00
0005432525793	7717	Comfort	23900.00
0005434066427	7717	Comfort	23900.00
0005432525860	7717	Comfort	23900.00
0005432525869	7717	Comfort	23900.00
0005434066406	7717	Comfort	23900.00
0005432525828	7717	Comfort	23900.00
0005432525805	7717	Comfort	23900.00
0005432525837	7717	Comfort	23900.00
0005432525856	7717	Comfort	23900.00
0005432525898	7717	Comfort	23900.00
0005432525780	7717	Comfort	23900.00
0005432525850	7717	Economy	14000.00
0005432525870	7717	Economy	14000.00
0005432525791	7717	Economy	14000.00
0005432525838	7717	Economy	14000.00
0005432525825	7717	Economy	14000.00
0005432150065	7717	Economy	14000.00
0005432525883	7717	Economy	14000.00
0005432525848	7717	Economy	14000.00
0005434066416	7717	Economy	14000.00
0005432525773	7717	Economy	14000.00
0005432525817	7717	Economy	14000.00
0005432525839	7717	Economy	14000.00
0005432525847	7717	Economy	14000.00
0005432525772	7717	Economy	14000.00
0005434066413	7717	Economy	14000.00
0005432150066	7717	Economy	14000.00
0005434066389	7717	Economy	14000.00
0005432525899	7717	Economy	14000.00
0005432525901	7717	Economy	14000.00
0005434066418	7717	Economy	14000.00
0005432069411	7717	Economy	14000.00
0005432525887	7717	Economy	14000.00
0005432525846	7717	Economy	14000.00
0005432525845	7717	Economy	14000.00
0005432150070	7717	Economy	14000.00
0005434066414	7717	Economy	14000.00
0005434066429	7717	Economy	14000.00
0005434066415	7717	Economy	14000.00
0005432535751	7717	Economy	14000.00
0005434066422	7717	Economy	14000.00
0005432069422	7717	Economy	14000.00
0005432525862	7717	Economy	14000.00
0005434066377	7717	Economy	14000.00
0005434066379	7717	Economy	14000.00
0005432525842	7717	Economy	14000.00
0005432069418	7717	Economy	14000.00
0005432150068	7717	Economy	14000.00
0005432150069	7717	Economy	14000.00
0005434066370	7717	Economy	14000.00
0005434066405	7717	Economy	15400.00
0005432525886	7717	Economy	14000.00
0005432525826	7717	Economy	15400.00
0005432069419	7717	Economy	15400.00
0005432525890	7717	Economy	14000.00
0005434066382	7717	Economy	14000.00
0005432069409	7717	Economy	15400.00
0005432525871	7717	Economy	14000.00
0005434066372	7717	Economy	14000.00
0005432525833	7717	Economy	14000.00
0005434066385	7717	Economy	14000.00
0005432525792	7717	Economy	14000.00
0005432150064	7717	Economy	14000.00
0005434066387	7717	Economy	14000.00
0005434066381	7717	Economy	14000.00
0005432525822	7717	Economy	14000.00
0005432525866	7717	Economy	14000.00
0005432150067	7717	Economy	14000.00
0005434066431	7717	Economy	14000.00
0005432525818	7717	Economy	14000.00
0005432525777	7717	Economy	14000.00
0005432525781	7717	Economy	14000.00
0005432525844	7717	Economy	14000.00
0005432525801	7717	Economy	14000.00
0005434066420	7717	Economy	14000.00
0005432525841	7717	Economy	14000.00
0005434066375	7717	Economy	14000.00
0005434066421	7717	Economy	14000.00
0005432525823	7717	Economy	14000.00
0005432525808	7717	Economy	14000.00
0005432525849	7717	Economy	14000.00
0005434066408	7717	Economy	14000.00
0005434066432	7717	Economy	14000.00
0005432525873	7717	Economy	14000.00
0005432525836	7717	Economy	14000.00
0005432535750	7717	Economy	14000.00
0005434066394	7717	Economy	14000.00
0005432525799	7717	Economy	14000.00
0005432428871	7717	Economy	14000.00
0005432535753	7717	Economy	14000.00
0005432525769	7717	Economy	14000.00
0005432069421	7717	Economy	14000.00
0005432525797	7717	Economy	14000.00
0005432525891	7717	Economy	14000.00
0005434066380	7717	Economy	14000.00
0005432525820	7717	Economy	14000.00
0005434066433	7717	Economy	14000.00
0005432525892	7717	Economy	14000.00
0005432525867	7717	Economy	14000.00
0005434066398	7717	Economy	14000.00
0005432525782	7717	Economy	14000.00
0005432525851	7717	Economy	14000.00
0005432525888	7717	Economy	14000.00
0005434066383	7717	Economy	14000.00
0005432525864	7717	Economy	14000.00
0005432525800	7717	Economy	14000.00
0005432525882	7717	Economy	14000.00
0005434066423	7717	Economy	14000.00
0005432525821	7717	Economy	14000.00
0005434066425	7717	Economy	14000.00
0005432525843	7717	Economy	14000.00
0005432069415	7717	Economy	14000.00
0005434066409	7717	Economy	14000.00
0005434066407	7717	Economy	14000.00
0005432525877	7717	Economy	14000.00
0005432525809	7717	Economy	14000.00
0005432525868	7717	Economy	14000.00
0005432525830	7717	Economy	14000.00
0005432525857	7717	Economy	14000.00
0005432525859	7717	Economy	14000.00
0005432525816	7717	Economy	14000.00
0005432525879	7717	Economy	14000.00
0005432533243	7717	Economy	14000.00
0005432525824	7717	Economy	14000.00
0005434066386	7717	Economy	14000.00
0005432525775	7717	Economy	14000.00
0005434066402	7717	Economy	14000.00
0005432525896	7717	Economy	14000.00
0005432525814	7717	Economy	14000.00
0005432428873	7717	Economy	14000.00
0005432537022	7717	Economy	14000.00
0005434066430	7717	Economy	14000.00
0005434066411	7717	Economy	14000.00
0005432533245	7717	Economy	15400.00
0005434066424	7717	Economy	14000.00
0005432069412	7717	Economy	15400.00
0005432525875	7717	Economy	14000.00
0005432535752	7717	Economy	14000.00
0005434066397	7717	Economy	14000.00
0005432525834	7717	Economy	14000.00
0005432525788	7717	Economy	14000.00
0005434066428	7717	Economy	14000.00
0005434066437	7717	Economy	14000.00
0005432069417	7717	Economy	14000.00
0005432535755	7717	Economy	14000.00
0005432525811	7717	Economy	14000.00
0005434066391	7717	Economy	14000.00
0005432525880	7717	Economy	14000.00
0005432525853	7717	Economy	14000.00
0005432525819	7717	Economy	14000.00
0005432525806	7717	Economy	14000.00
0005432525784	7717	Economy	14000.00
0005432533246	7717	Economy	14000.00
0005432525858	7717	Economy	14000.00
0005432525893	7717	Economy	14000.00
0005432525813	7717	Economy	14000.00
0005432525804	7717	Economy	14000.00
0005432525794	7717	Economy	14000.00
0005432525852	7717	Economy	14000.00
0005432525774	7717	Economy	14000.00
0005432525894	7717	Economy	14000.00
0005434066434	7717	Economy	14000.00
0005432525796	7717	Economy	14000.00
0005434066401	7717	Economy	14000.00
0005434066390	7717	Economy	14000.00
0005432525790	7717	Economy	14000.00
0005432069410	7717	Economy	14000.00
0005434066384	7717	Economy	14000.00
0005434066392	7717	Economy	14000.00
0005434066438	7717	Economy	14000.00
0005432525768	7717	Economy	14000.00
0005434066419	7717	Economy	14000.00
0005432525835	7717	Economy	14000.00
0005432525865	7717	Economy	14000.00
0005432525778	7717	Economy	14000.00
0005432525827	7717	Economy	14000.00
0005432525815	7717	Economy	14000.00
0005432533244	7717	Economy	14000.00
0005434066436	7717	Economy	14000.00
0005432535754	7717	Economy	14000.00
0005432525770	7717	Economy	14000.00
0005432525903	7717	Economy	14000.00
0005432069414	7717	Economy	14000.00
0005432525787	7717	Economy	14000.00
0005434066369	7717	Economy	14000.00
0005432525878	7717	Economy	14000.00
0005434066412	7717	Economy	14000.00
0005434066378	7717	Economy	14000.00
0005432525863	7717	Economy	14000.00
0005432525876	7717	Economy	14000.00
0005432525832	7717	Economy	14000.00
0005432525902	7717	Economy	14000.00
0005432525779	7717	Economy	14000.00
0005432428870	7717	Economy	14000.00
0005432525807	7717	Economy	14000.00
0005432525829	7717	Economy	14000.00
0005432525802	7717	Economy	14000.00
0005434066376	7717	Economy	14000.00
0005434066373	7717	Economy	14000.00
0005432525785	7717	Economy	14000.00
0005432525889	7717	Economy	14000.00
0005432525885	7717	Economy	14000.00
0005432525874	7717	Economy	14000.00
0005434066403	7717	Economy	14000.00
0005432525776	7717	Economy	14000.00
0005434066374	7717	Economy	14000.00
0005432525884	7717	Economy	14000.00
0005432428872	7717	Economy	14000.00
0005434573123	5304	Business	43100.00
0005434343650	5304	Business	43100.00
0005435611802	5304	Business	43100.00
0005435611828	5304	Business	43100.00
0005435611825	5304	Business	43100.00
0005435611816	5304	Business	43100.00
0005434343621	5304	Business	43100.00
0005435611788	5304	Business	43100.00
0005435611789	5304	Business	43100.00
0005435611813	5304	Business	43100.00
0005435611870	5304	Business	43100.00
0005435611776	5304	Business	43100.00
0005435611866	5304	Business	43100.00
0005434343645	5304	Comfort	24400.00
0005434343630	5304	Comfort	24400.00
0005435611822	5304	Comfort	24400.00
0005435611841	5304	Comfort	24400.00
0005435611798	5304	Comfort	24400.00
0005435611796	5304	Comfort	24400.00
0005435490173	5304	Comfort	24400.00
0005432132956	5304	Comfort	24400.00
0005434343646	5304	Comfort	24400.00
0005435611799	5304	Comfort	24400.00
0005434343635	5304	Comfort	24400.00
0005434343620	5304	Comfort	24400.00
0005434343643	5304	Comfort	24400.00
0005435611781	5304	Comfort	24400.00
0005434343624	5304	Comfort	24400.00
0005432132965	5304	Comfort	24400.00
0005435611773	5304	Comfort	24400.00
0005435611868	5304	Comfort	24400.00
0005435097056	5304	Comfort	24400.00
0005435611793	5304	Comfort	24400.00
0005434343634	5304	Comfort	24400.00
0005435611811	5304	Comfort	24400.00
0005435611804	5304	Comfort	24400.00
0005435611815	5304	Economy	14400.00
0005434343642	5304	Economy	14400.00
0005435611824	5304	Economy	14400.00
0005435097058	5304	Economy	14400.00
0005435611854	5304	Economy	14400.00
0005435611827	5304	Economy	14400.00
0005435611777	5304	Economy	14400.00
0005434573119	5304	Economy	14400.00
0005435611839	5304	Economy	14400.00
0005432132963	5304	Economy	14400.00
0005435611838	5304	Economy	14400.00
0005435611832	5304	Economy	14400.00
0005435611830	5304	Economy	14400.00
0005435611821	5304	Economy	14400.00
0005434343636	5304	Economy	14400.00
0005435097053	5304	Economy	14400.00
0005435611847	5304	Economy	14400.00
0005434343617	5304	Economy	14400.00
0005435611782	5304	Economy	14400.00
0005434573129	5304	Economy	14400.00
0005435491407	5304	Economy	14400.00
0005434573121	5304	Economy	14400.00
0005434343625	5304	Economy	14400.00
0005435611865	5304	Economy	14400.00
0005435611872	5304	Economy	14400.00
0005434573127	5304	Economy	14400.00
0005435611867	5304	Economy	14400.00
0005435097059	5304	Economy	14400.00
0005435611790	5304	Economy	14400.00
0005434343622	5304	Economy	14400.00
0005434343619	5304	Economy	14400.00
0005435611806	5304	Economy	14400.00
0005435611837	5304	Economy	14400.00
0005434573126	5304	Economy	14400.00
0005435611851	5304	Economy	14400.00
0005432132960	5304	Economy	14400.00
0005435611856	5304	Economy	14400.00
0005432132967	5304	Economy	14400.00
0005435611842	5304	Economy	14400.00
0005435611791	5304	Economy	14400.00
0005434343641	5304	Economy	15800.00
0005434343648	5304	Economy	14400.00
0005432132962	5304	Economy	14400.00
0005434343631	5304	Economy	14400.00
0005434343647	5304	Economy	14400.00
0005435097054	5304	Economy	14400.00
0005435611819	5304	Economy	14400.00
0005435611852	5304	Economy	14400.00
0005434343649	5304	Economy	14400.00
0005435611848	5304	Economy	14400.00
0005432132969	5304	Economy	14400.00
0005435611874	5304	Economy	14400.00
0005435611810	5304	Economy	14400.00
0005434343640	5304	Economy	14400.00
0005435555335	5304	Economy	14400.00
0005435611800	5304	Economy	14400.00
0005435097057	5304	Economy	14400.00
0005432047489	5304	Economy	14400.00
0005435611801	5304	Economy	14400.00
0005435611826	5304	Economy	14400.00
0005435611803	5304	Economy	14400.00
0005435611778	5304	Economy	14400.00
0005435611820	5304	Economy	14400.00
0005435611860	5304	Economy	14400.00
0005435611864	5304	Economy	14400.00
0005435490171	5304	Economy	14400.00
0005435611807	5304	Economy	14400.00
0005435611855	5304	Economy	14400.00
0005435611859	5304	Economy	14400.00
0005434573117	5304	Economy	14400.00
0005435611875	5304	Economy	14400.00
0005435611785	5304	Economy	14400.00
0005432047491	5304	Economy	14400.00
0005435611786	5304	Economy	14400.00
0005435611845	5304	Economy	14400.00
0005435611844	5304	Economy	14400.00
0005434573124	5304	Economy	14400.00
0005435611871	5304	Economy	14400.00
0005432132961	5304	Economy	14400.00
0005435490170	5304	Economy	14400.00
0005435611794	5304	Economy	14400.00
0005434343627	5304	Economy	14400.00
0005435611833	5304	Economy	14400.00
0005435611836	5304	Economy	14400.00
0005432132966	5304	Economy	14400.00
0005434573118	5304	Economy	14400.00
0005434343638	5304	Economy	14400.00
0005435611829	5304	Economy	14400.00
0005435490172	5304	Economy	14400.00
0005434573128	5304	Economy	14400.00
0005435611795	5304	Economy	14400.00
0005435611869	5304	Economy	14400.00
0005434573116	5304	Economy	14400.00
0005432047490	5304	Economy	14400.00
0005435611853	5304	Economy	14400.00
0005435611817	5304	Economy	14400.00
0005435611843	5304	Economy	14400.00
0005435611835	5304	Economy	15800.00
0005435611831	5304	Economy	14400.00
0005435611823	5304	Economy	14400.00
0005434343628	5304	Economy	14400.00
0005435611783	5304	Economy	14400.00
0005435611858	5304	Economy	14400.00
0005435097055	5304	Economy	14400.00
0005432132957	5304	Economy	14400.00
0005434343633	5304	Economy	14400.00
0005435611814	5304	Economy	14400.00
0005434343632	5304	Economy	14400.00
0005435611846	5304	Economy	14400.00
0005434343623	5304	Economy	14400.00
0005435611809	5304	Economy	14400.00
0005435611861	5304	Economy	14400.00
0005435611834	5304	Economy	14400.00
0005434343618	5304	Economy	14400.00
0005434573125	5304	Economy	14400.00
0005435611840	5304	Economy	14400.00
0005435611849	5304	Economy	14400.00
0005432132970	5304	Economy	14400.00
0005435611808	5304	Economy	14400.00
0005435611787	5304	Economy	14400.00
0005435555334	5304	Economy	14400.00
0005435611779	5304	Economy	14400.00
0005435611784	5304	Economy	14400.00
0005435611862	5304	Economy	14400.00
0005435611792	5304	Economy	14400.00
0005434573120	5304	Economy	14400.00
0005432132971	5304	Economy	14400.00
0005432047488	5304	Economy	14400.00
0005434343639	5304	Economy	14400.00
0005435611775	5304	Economy	14400.00
0005435097052	5304	Economy	14400.00
0005432047487	5304	Economy	14400.00
0005432132964	5304	Economy	14400.00
0005435611774	5304	Economy	14400.00
0005435611818	5304	Economy	14400.00
0005435490169	5304	Economy	14400.00
0005432132968	5304	Economy	14400.00
0005432132959	5304	Economy	14400.00
0005435611797	5304	Economy	14400.00
0005432132958	5304	Economy	14400.00
0005434343637	5304	Economy	14400.00
0005435611863	5304	Economy	14400.00
0005435611857	5304	Economy	14400.00
0005434343644	5304	Economy	14400.00
0005434343626	5304	Economy	14400.00
0005435611805	5304	Economy	14400.00
0005434343629	5304	Economy	14400.00
0005435491406	5304	Economy	14400.00
0005435611873	5304	Economy	14400.00
0005435611812	5304	Economy	14400.00
0005434573122	5304	Economy	14400.00
0005435611780	5304	Economy	14400.00
0005435611850	5304	Economy	14400.00
0005435491405	5304	Economy	14400.00
0005435423694	10928	Business	43100.00
0005434244499	10928	Business	43100.00
0005434244489	10928	Business	43100.00
0005435423669	10928	Business	43100.00
0005435319424	10928	Business	43100.00
0005432164915	10928	Business	43100.00
0005434244488	10928	Business	43100.00
0005432164916	10928	Business	43100.00
0005435423704	10928	Business	43100.00
0005435423703	10928	Business	43100.00
0005435423681	10928	Business	43100.00
0005435423696	10928	Business	43100.00
0005435423675	10928	Comfort	24400.00
0005435423660	10928	Comfort	24400.00
0005435423690	10928	Comfort	24400.00
0005432164911	10928	Comfort	24400.00
0005435423673	10928	Comfort	24400.00
0005435423648	10928	Comfort	24400.00
0005435423654	10928	Comfort	24400.00
0005435423652	10928	Comfort	24400.00
0005435423664	10928	Comfort	24400.00
0005435423715	10928	Comfort	24400.00
0005435319427	10928	Comfort	24400.00
0005435423672	10928	Comfort	24400.00
0005432363363	10928	Comfort	24400.00
0005435423674	10928	Comfort	24400.00
0005434244509	10928	Comfort	24400.00
0005434244512	10928	Economy	14400.00
0005433719084	10928	Economy	14400.00
0005432164912	10928	Economy	14400.00
0005435319429	10928	Economy	14400.00
0005434244514	10928	Economy	14400.00
0005435319430	10928	Economy	14400.00
0005435423708	10928	Economy	14400.00
0005435423665	10928	Economy	14400.00
0005434244508	10928	Economy	14400.00
0005435423714	10928	Economy	14400.00
0005434244511	10928	Economy	14400.00
0005435423666	10928	Economy	14400.00
0005435304092	10928	Economy	14400.00
0005435423677	10928	Economy	14400.00
0005432164910	10928	Economy	14400.00
0005432840978	10928	Economy	14400.00
0005434244494	10928	Economy	14400.00
0005435423680	10928	Economy	14400.00
0005434244513	10928	Economy	14400.00
0005434244485	10928	Economy	14400.00
0005434244493	10928	Economy	14400.00
0005434656523	10928	Economy	15800.00
0005435319426	10928	Economy	15800.00
0005435423668	10928	Economy	14400.00
0005435423692	10928	Economy	14400.00
0005435423653	10928	Economy	14400.00
0005435423646	10928	Economy	14400.00
0005434244498	10928	Economy	14400.00
0005435423709	10928	Economy	14400.00
0005435423701	10928	Economy	14400.00
0005435423706	10928	Economy	14400.00
0005432363362	10928	Economy	14400.00
0005435319428	10928	Economy	14400.00
0005432166847	10928	Economy	14400.00
0005433719085	10928	Economy	14400.00
0005435423647	10928	Economy	14400.00
0005434244484	10928	Economy	14400.00
0005434244505	10928	Economy	14400.00
0005435423658	10928	Economy	14400.00
0005435423693	10928	Economy	14400.00
0005435319425	10928	Economy	14400.00
0005432166846	10928	Economy	14400.00
0005434244491	10928	Economy	14400.00
0005432840977	10928	Economy	14400.00
0005434244500	10928	Economy	14400.00
0005434244501	10928	Economy	14400.00
0005435423655	10928	Economy	14400.00
0005435423686	10928	Economy	14400.00
0005434244492	10928	Economy	14400.00
0005435304095	10928	Economy	14400.00
0005435423702	10928	Economy	14400.00
0005434656522	10928	Economy	14400.00
0005435319423	10928	Economy	14400.00
0005435304093	10928	Economy	14400.00
0005434244503	10928	Economy	14400.00
0005432840979	10928	Economy	14400.00
0005432363364	10928	Economy	14400.00
0005435423656	10928	Economy	14400.00
0005435423659	10928	Economy	14400.00
0005435423667	10928	Economy	14400.00
0005435423679	10928	Economy	14400.00
0005435423700	10928	Economy	14400.00
0005435423678	10928	Economy	14400.00
0005434244490	10928	Economy	14400.00
0005435423711	10928	Economy	14400.00
0005435423684	10928	Economy	14400.00
0005434244496	10928	Economy	14400.00
0005435423691	10928	Economy	14400.00
0005435423707	10928	Economy	15800.00
0005435423712	10928	Economy	14400.00
0005432164913	10928	Economy	14400.00
0005434244495	10928	Economy	14400.00
0005435423663	10928	Economy	14400.00
0005434244510	10928	Economy	14400.00
0005432166849	10928	Economy	14400.00
0005435423650	10928	Economy	14400.00
0005435423687	10928	Economy	14400.00
0005434244507	10928	Economy	14400.00
0005432164914	10928	Economy	14400.00
0005434244486	10928	Economy	14400.00
0005435423689	10928	Economy	14400.00
0005432164909	10928	Economy	14400.00
0005435423651	10928	Economy	14400.00
0005434244487	10928	Economy	14400.00
0005435304094	10928	Economy	14400.00
0005434244502	10928	Economy	14400.00
0005435423682	10928	Economy	14400.00
0005435423698	10928	Economy	14400.00
0005435423695	10928	Economy	14400.00
0005434244504	10928	Economy	14400.00
0005435423683	10928	Economy	14400.00
0005435423705	10928	Economy	14400.00
0005435423657	10928	Economy	14400.00
0005435423710	10928	Economy	14400.00
0005435304096	10928	Economy	14400.00
0005432166848	10928	Economy	14400.00
0005433719086	10928	Economy	14400.00
0005435319431	10928	Economy	14400.00
0005435423661	10928	Economy	14400.00
0005433719087	10928	Economy	14400.00
0005434244506	10928	Economy	14400.00
0005435304989	10928	Economy	14400.00
0005435423649	10928	Economy	14400.00
0005435423697	10928	Economy	14400.00
0005435423713	10928	Economy	14400.00
0005435423685	10928	Economy	14400.00
0005434244497	10928	Economy	14400.00
0005435423676	10928	Economy	14400.00
0005435423662	10928	Economy	14400.00
0005435423688	10928	Economy	14400.00
0005435423699	10928	Economy	14400.00
0005432363361	10928	Economy	14400.00
0005435423671	10928	Economy	14400.00
0005435423670	10928	Economy	14400.00
0005432181354	3229	Business	18800.00
0005433804814	3229	Business	18800.00
0005432181352	3229	Business	18800.00
0005433804809	3229	Business	18800.00
0005433633250	3229	Business	18800.00
0005433804825	3229	Business	18800.00
0005432181345	3229	Business	18800.00
0005433804826	3229	Business	18800.00
0005432181362	3229	Business	18800.00
0005433804818	3229	Business	18800.00
0005433804804	3229	Business	18800.00
0005433633248	3229	Business	18800.00
0005432181348	3229	Business	18800.00
0005433633257	3229	Business	18800.00
0005433506887	3229	Business	18800.00
0005433506882	3229	Business	18800.00
0005433506876	3229	Business	18800.00
0005433506874	3229	Economy	6900.00
0005433633260	3229	Economy	6900.00
0005432181357	3229	Economy	6300.00
0005432181361	3229	Economy	6300.00
0005432181341	3229	Economy	6300.00
0005433804799	3229	Economy	6300.00
0005433633258	3229	Economy	6300.00
0005433633253	3229	Economy	6300.00
0005433633271	3229	Economy	6300.00
0005432181363	3229	Economy	6300.00
0005433804820	3229	Economy	6300.00
0005433633279	3229	Economy	6300.00
0005433804808	3229	Economy	6300.00
0005433506883	3229	Economy	6300.00
0005433633268	3229	Economy	6300.00
0005433804812	3229	Economy	6300.00
0005433804803	3229	Economy	6300.00
0005433804801	3229	Economy	6300.00
0005432181347	3229	Economy	6300.00
0005433804824	3229	Economy	6300.00
0005433633259	3229	Economy	6300.00
0005433633272	3229	Economy	6300.00
0005433506890	3229	Economy	6300.00
0005433633256	3229	Economy	6300.00
0005433633261	3229	Economy	6300.00
0005432181350	3229	Economy	6300.00
0005433804798	3229	Economy	6300.00
0005433804810	3229	Economy	6300.00
0005433633265	3229	Economy	6300.00
0005432181351	3229	Economy	6300.00
0005433804805	3229	Economy	6300.00
0005433804816	3229	Economy	6300.00
0005433633264	3229	Economy	6300.00
0005432181360	3229	Economy	6300.00
0005432181346	3229	Economy	6300.00
0005433804806	3229	Economy	6300.00
0005433804800	3229	Economy	6300.00
0005433633274	3229	Economy	6300.00
0005433633249	3229	Economy	6300.00
0005433633280	3229	Economy	6300.00
0005433804811	3229	Economy	6300.00
0005433506884	3229	Economy	6300.00
0005433804794	3229	Economy	6900.00
0005433506877	3229	Economy	6900.00
0005433506875	3229	Economy	6900.00
0005433633254	3229	Economy	6300.00
0005433633267	3229	Economy	6300.00
0005433506881	3229	Economy	6300.00
0005432181353	3229	Economy	6300.00
0005433506878	3229	Economy	6900.00
0005433633276	3229	Economy	6300.00
0005433506886	3229	Economy	6300.00
0005433804827	3229	Economy	6300.00
0005433804807	3229	Economy	6300.00
0005433804795	3229	Economy	6300.00
0005433633282	3229	Economy	6300.00
0005433633266	3229	Economy	6300.00
0005433804815	3229	Economy	6300.00
0005433506888	3229	Economy	6300.00
0005433633273	3229	Economy	6300.00
0005433633269	3229	Economy	6300.00
0005433506885	3229	Economy	6300.00
0005433804802	3229	Economy	6300.00
0005433633262	3229	Economy	6300.00
0005433633277	3229	Economy	6300.00
0005433506873	3229	Economy	6300.00
0005433804819	3229	Economy	6300.00
0005433804822	3229	Economy	6300.00
0005433506879	3229	Economy	6300.00
0005432181344	3229	Economy	6300.00
0005433633251	3229	Economy	6300.00
0005433804821	3229	Economy	6300.00
0005432181356	3229	Economy	6300.00
0005433804828	3229	Economy	6300.00
0005433633270	3229	Economy	6300.00
0005433804813	3229	Economy	6300.00
0005432181359	3229	Economy	6300.00
0005432181349	3229	Economy	6300.00
0005433804796	3229	Economy	6300.00
0005433633281	3229	Economy	6300.00
0005433804817	3229	Economy	6300.00
0005433804823	3229	Economy	6300.00
0005433506889	3229	Economy	6300.00
0005432181355	3229	Economy	6300.00
0005433633252	3229	Economy	6300.00
0005433633275	3229	Economy	6300.00
0005433506880	3229	Economy	6300.00
0005433804797	3229	Economy	6300.00
0005433633255	3229	Economy	6300.00
0005433633278	3229	Economy	6300.00
0005432181342	3229	Economy	6300.00
0005432181358	3229	Economy	6300.00
0005433506872	3229	Economy	6300.00
0005433633263	3229	Economy	6300.00
0005432181343	3229	Economy	6300.00
0005432459023	8205	Business	18800.00
0005435884470	8205	Business	18800.00
0005432459038	8205	Business	18800.00
0005432459061	8205	Business	18800.00
0005435884452	8205	Business	18800.00
0005432459015	8205	Business	18800.00
0005432042493	8205	Business	18800.00
0005435884438	8205	Business	18800.00
0005432459012	8205	Business	18800.00
0005435884460	8205	Business	18800.00
0005432459017	8205	Business	18800.00
0005432459051	8205	Business	18800.00
0005432459058	8205	Business	18800.00
0005435884449	8205	Business	18800.00
0005435884480	8205	Business	18800.00
0005435884444	8205	Business	18800.00
0005435884448	8205	Business	18800.00
0005435884429	8205	Business	18800.00
0005432459043	8205	Business	18800.00
0005432459035	8205	Business	18800.00
0005432459054	8205	Business	18800.00
0005435884465	8205	Economy	6900.00
0005432459046	8205	Economy	6900.00
0005435884467	8205	Economy	6900.00
0005435884454	8205	Economy	6900.00
0005434312286	8205	Economy	6900.00
0005435884469	8205	Economy	6300.00
0005435884433	8205	Economy	6300.00
0005435884477	8205	Economy	6300.00
0005435884446	8205	Economy	6300.00
0005432459029	8205	Economy	6300.00
0005432042481	8205	Economy	6300.00
0005432459060	8205	Economy	6300.00
0005435884443	8205	Economy	6300.00
0005435884451	8205	Economy	6300.00
0005432459014	8205	Economy	6300.00
0005432459037	8205	Economy	6300.00
0005432042488	8205	Economy	6300.00
0005432459059	8205	Economy	6300.00
0005432042487	8205	Economy	6300.00
0005432459039	8205	Economy	6300.00
0005435884435	8205	Economy	6300.00
0005432459018	8205	Economy	6300.00
0005432459022	8205	Economy	6300.00
0005432459041	8205	Economy	6300.00
0005435884476	8205	Economy	6300.00
0005432459025	8205	Economy	6300.00
0005432459036	8205	Economy	6300.00
0005435884447	8205	Economy	6300.00
0005432459024	8205	Economy	6300.00
0005435884457	8205	Economy	6300.00
0005435884481	8205	Economy	6300.00
0005432459050	8205	Economy	6300.00
0005432459049	8205	Economy	6300.00
0005435884440	8205	Economy	6300.00
0005432459055	8205	Economy	6300.00
0005432459057	8205	Economy	6300.00
0005432042482	8205	Economy	6300.00
0005432459047	8205	Economy	6300.00
0005432459062	8205	Economy	6300.00
0005435884428	8205	Economy	6300.00
0005432459053	8205	Economy	6300.00
0005432042492	8205	Economy	6300.00
0005432459052	8205	Economy	6300.00
0005435884439	8205	Economy	6300.00
0005432459056	8205	Economy	6300.00
0005432042489	8205	Economy	6300.00
0005432459044	8205	Economy	6300.00
0005432042490	8205	Economy	6300.00
0005432459026	8205	Economy	6900.00
0005435884431	8205	Economy	6900.00
0005435884459	8205	Economy	6300.00
0005435884466	8205	Economy	6900.00
0005435884461	8205	Economy	6300.00
0005432459019	8205	Economy	6300.00
0005435884456	8205	Economy	6300.00
0005435884442	8205	Economy	6900.00
0005435884437	8205	Economy	6300.00
0005435884471	8205	Economy	6300.00
0005432459010	8205	Economy	6300.00
0005432042485	8205	Economy	6300.00
0005432459013	8205	Economy	6300.00
0005435884463	8205	Economy	6300.00
0005435884468	8205	Economy	6300.00
0005432459033	8205	Economy	6300.00
0005432459011	8205	Economy	6300.00
0005432459028	8205	Economy	6300.00
0005435884478	8205	Economy	6300.00
0005432042484	8205	Economy	6300.00
0005435884455	8205	Economy	6300.00
0005435884430	8205	Economy	6300.00
0005432459031	8205	Economy	6300.00
0005432459016	8205	Economy	6300.00
0005432459034	8205	Economy	6300.00
0005435884475	8205	Economy	6300.00
0005435884445	8205	Economy	6300.00
0005435884441	8205	Economy	6300.00
0005432459027	8205	Economy	6300.00
0005432459030	8205	Economy	6300.00
0005432459042	8205	Economy	6300.00
0005435884462	8205	Economy	6300.00
0005432459020	8205	Economy	6300.00
0005435884436	8205	Economy	6300.00
0005432042483	8205	Economy	6300.00
0005432459048	8205	Economy	6300.00
0005432042491	8205	Economy	6300.00
0005435884479	8205	Economy	6300.00
0005432459021	8205	Economy	6300.00
0005435884434	8205	Economy	6300.00
0005435884458	8205	Economy	6300.00
0005435884427	8205	Economy	6300.00
0005434312285	8205	Economy	6300.00
0005432042494	8205	Economy	6300.00
0005435884464	8205	Economy	6300.00
0005435884432	8205	Economy	6300.00
0005432459045	8205	Economy	6300.00
0005435884450	8205	Economy	6300.00
0005432459032	8205	Economy	6300.00
0005435884453	8205	Economy	6300.00
0005432459040	8205	Economy	6300.00
0005435884474	8205	Economy	6300.00
0005435884473	8205	Economy	6300.00
0005432042486	8205	Economy	6300.00
0005435884472	8205	Economy	6300.00
0005432382539	4576	Business	9900.00
0005432382531	4576	Business	9900.00
0005432382536	4576	Business	9900.00
0005432382542	4576	Business	9900.00
0005432382524	4576	Business	9900.00
0005433454840	4576	Business	9900.00
0005432382543	4576	Business	9900.00
0005432382535	4576	Business	9900.00
0005432382532	4576	Business	9900.00
0005433722114	4576	Business	9900.00
0005432382546	4576	Economy	3300.00
0005432382560	4576	Economy	3300.00
0005433722107	4576	Economy	3300.00
0005432727729	4576	Economy	3300.00
0005433453728	4576	Economy	3300.00
0005433453729	4576	Economy	3600.00
0005432382558	4576	Economy	3600.00
0005433194819	4576	Economy	3600.00
0005432382527	4576	Economy	3600.00
0005433722115	4576	Economy	3600.00
0005432727738	4576	Economy	3300.00
0005432382526	4576	Economy	3300.00
0005432382523	4576	Economy	3300.00
0005432727728	4576	Economy	3300.00
0005432382530	4576	Economy	3300.00
0005433722108	4576	Economy	3300.00
0005432382561	4576	Economy	3300.00
0005432727730	4576	Economy	3300.00
0005432382547	4576	Economy	3300.00
0005433454839	4576	Economy	3300.00
0005433722109	4576	Economy	3300.00
0005433722110	4576	Economy	3300.00
0005432382538	4576	Economy	3300.00
0005432727732	4576	Economy	3300.00
0005432727734	4576	Economy	3300.00
0005432382551	4576	Economy	3300.00
0005433194817	4576	Economy	3300.00
0005432727735	4576	Economy	3300.00
0005432382553	4576	Economy	3300.00
0005432382550	4576	Economy	3300.00
0005432382540	4576	Economy	3300.00
0005432382545	4576	Economy	3300.00
0005432382555	4576	Economy	3300.00
0005432727739	4576	Economy	3300.00
0005432382544	4576	Economy	3300.00
0005432382522	4576	Economy	3300.00
0005432382552	4576	Economy	3300.00
0005432382559	4576	Economy	3300.00
0005432382528	4576	Economy	3300.00
0005432727736	4576	Economy	3300.00
0005432382529	4576	Economy	3300.00
0005432382556	4576	Economy	3300.00
0005432382534	4576	Economy	3300.00
0005432727733	4576	Economy	3300.00
0005433722117	4576	Economy	3300.00
0005432382554	4576	Economy	3300.00
0005432727737	4576	Economy	3300.00
0005432382525	4576	Economy	3300.00
0005433194818	4576	Economy	3300.00
0005432382533	4576	Economy	3300.00
0005432727731	4576	Economy	3300.00
0005432382557	4576	Economy	3300.00
0005433722113	4576	Economy	3300.00
0005432382537	4576	Economy	3300.00
0005433722116	4576	Economy	3300.00
0005432382563	4576	Economy	3300.00
0005432382549	4576	Economy	3300.00
0005432382541	4576	Economy	3300.00
0005432382521	4576	Economy	3300.00
0005432382548	4576	Economy	3300.00
0005432382562	4576	Economy	3300.00
0005433722111	4576	Economy	3300.00
0005433722112	4576	Economy	3300.00
0005432727740	4576	Economy	3300.00
0005435528904	1715	Business	57200.00
0005435528915	1715	Business	57200.00
0005435528917	1715	Business	57200.00
0005435528908	1715	Business	57200.00
0005433516738	1715	Business	57200.00
0005435540664	1715	Business	57200.00
0005435540660	1715	Business	57200.00
0005435540651	1715	Business	57200.00
0005435540646	1715	Business	57200.00
0005435540656	1715	Economy	19100.00
0005435528919	1715	Economy	19100.00
0005432294449	1715	Economy	19100.00
0005432294447	1715	Economy	19100.00
0005435528902	1715	Economy	19100.00
0005435528912	1715	Economy	19100.00
0005435528901	1715	Economy	21000.00
0005435528913	1715	Economy	21000.00
0005433516736	1715	Economy	21000.00
0005435528911	1715	Economy	19100.00
0005433516737	1715	Economy	19100.00
0005435540665	1715	Economy	19100.00
0005433516732	1715	Economy	19100.00
0005433516730	1715	Economy	19100.00
0005433516739	1715	Economy	19100.00
0005435528906	1715	Economy	19100.00
0005435540655	1715	Economy	19100.00
0005435540648	1715	Economy	19100.00
0005435528903	1715	Economy	19100.00
0005435540654	1715	Economy	19100.00
0005433516733	1715	Economy	19100.00
0005435540661	1715	Economy	19100.00
0005433516731	1715	Economy	19100.00
0005433516735	1715	Economy	19100.00
0005435540650	1715	Economy	19100.00
0005435540659	1715	Economy	19100.00
0005435528907	1715	Economy	19100.00
0005435540652	1715	Economy	19100.00
0005435528909	1715	Economy	19100.00
0005435540662	1715	Economy	19100.00
0005435528910	1715	Economy	19100.00
0005435528905	1715	Economy	19100.00
0005435528921	1715	Economy	19100.00
0005435528920	1715	Economy	19100.00
0005435540663	1715	Economy	19100.00
0005433516734	1715	Economy	19100.00
0005435528916	1715	Economy	19100.00
0005435528914	1715	Economy	19100.00
0005435540657	1715	Economy	19100.00
0005432294448	1715	Economy	19100.00
0005435528918	1715	Economy	19100.00
0005435540644	1715	Economy	19100.00
0005435540649	1715	Economy	19100.00
0005435540647	1715	Economy	19100.00
0005435540666	1715	Economy	19100.00
0005435540645	1715	Economy	19100.00
0005435540658	1715	Economy	19100.00
0005435540653	1715	Economy	19100.00
0005432924958	22014	Economy	19100.00
0005432924956	22014	Economy	19100.00
0005432924959	22014	Economy	19100.00
0005432924957	22014	Economy	19100.00
0005432924960	22014	Economy	19100.00
0005432838514	7371	Business	18500.00
0005432838524	7371	Business	18500.00
0005432838520	7371	Business	18500.00
0005434458458	7371	Business	18500.00
0005432838540	7371	Business	18500.00
0005432840976	7371	Business	18500.00
0005432838535	7371	Economy	6200.00
0005432838536	7371	Economy	6200.00
0005432838537	7371	Economy	6200.00
0005432838529	7371	Economy	6200.00
0005432838527	7371	Economy	6200.00
0005432838515	7371	Economy	6200.00
0005434458471	7371	Economy	6800.00
0005432838531	7371	Economy	6800.00
0005432073335	7371	Economy	6800.00
0005432838542	7371	Economy	6800.00
0005432838544	7371	Economy	6200.00
0005432073334	7371	Economy	6200.00
0005432838541	7371	Economy	6200.00
0005432073332	7371	Economy	6200.00
0005432838522	7371	Economy	6200.00
0005434458454	7371	Economy	6200.00
0005434458455	7371	Economy	6200.00
0005434458464	7371	Economy	6200.00
0005434458465	7371	Economy	6200.00
0005432823415	7371	Economy	6200.00
0005432838516	7371	Economy	6200.00
0005434458470	7371	Economy	6200.00
0005434458469	7371	Economy	6200.00
0005432838533	7371	Economy	6200.00
0005432838543	7371	Economy	6200.00
0005432838512	7371	Economy	6200.00
0005434458457	7371	Economy	6200.00
0005432838521	7371	Economy	6200.00
0005432838539	7371	Economy	6200.00
0005432838513	7371	Economy	6200.00
0005434458467	7371	Economy	6200.00
0005432838519	7371	Economy	6200.00
0005434458462	7371	Economy	6200.00
0005432838538	7371	Economy	6200.00
0005432838517	7371	Economy	6200.00
0005432838532	7371	Economy	6200.00
0005432073333	7371	Economy	6200.00
0005434458459	7371	Economy	6200.00
0005434458474	7371	Economy	6200.00
0005432838528	7371	Economy	6200.00
0005434458460	7371	Economy	6200.00
0005432838518	7371	Economy	6200.00
0005434458456	7371	Economy	6200.00
0005432838534	7371	Economy	6200.00
0005432838525	7371	Economy	6200.00
0005432838530	7371	Economy	6200.00
0005434458466	7371	Economy	6200.00
0005434458472	7371	Economy	6200.00
0005432838523	7371	Economy	6200.00
0005434458468	7371	Economy	6200.00
0005434458461	7371	Economy	6200.00
0005434458473	7371	Economy	6200.00
0005434458475	7371	Economy	6200.00
0005434458463	7371	Economy	6200.00
0005432838526	7371	Economy	6200.00
0005434664923	28939	Business	18500.00
0005432000990	28939	Business	18500.00
0005435252398	28939	Economy	6200.00
0005435491408	28939	Economy	6200.00
0005435252407	28939	Economy	6800.00
0005435252417	28939	Economy	6800.00
0005435252408	28939	Economy	6800.00
0005435252397	28939	Economy	6200.00
0005435252406	28939	Economy	6200.00
0005435252401	28939	Economy	6200.00
0005435252404	28939	Economy	6200.00
0005435252405	28939	Economy	6200.00
0005435252399	28939	Economy	6200.00
0005435252409	28939	Economy	6200.00
0005435252403	28939	Economy	6200.00
0005435252410	28939	Economy	6200.00
0005435252414	28939	Economy	6200.00
0005435252400	28939	Economy	6200.00
0005435252413	28939	Economy	6200.00
0005434664924	28939	Economy	6200.00
0005435252402	28939	Economy	6200.00
0005435252416	28939	Economy	6200.00
0005435252412	28939	Economy	6200.00
0005435252411	28939	Economy	6200.00
0005435252415	28939	Economy	6200.00
0005434664922	28939	Economy	6200.00
0005432000989	28939	Economy	6200.00
0005435491409	28939	Economy	6200.00
0005434664921	28939	Economy	6200.00
0005435990506	8796	Economy	53300.00
0005435990511	8796	Economy	48400.00
0005435990512	8796	Economy	48400.00
0005435990510	8796	Economy	48400.00
0005435990508	8796	Economy	48400.00
0005435990505	8796	Economy	48400.00
0005435990504	8796	Economy	48400.00
0005435990507	8796	Economy	48400.00
0005435990509	8796	Economy	48400.00
0005434275929	15753	Economy	48400.00
0005434275930	15753	Economy	48400.00
0005434275931	15753	Economy	48400.00
0005434275937	15753	Economy	48400.00
0005434275936	15753	Economy	48400.00
0005434275933	15753	Economy	48400.00
0005434275932	15753	Economy	48400.00
0005434275934	15753	Economy	48400.00
0005434275935	15753	Economy	48400.00
0005432427109	20619	Economy	15900.00
0005432427106	20619	Economy	14500.00
0005432427107	20619	Economy	14500.00
0005432427108	20619	Economy	14500.00
0005433476856	30855	Economy	14500.00
0005433476858	30855	Economy	14500.00
0005433476857	30855	Economy	14500.00
0005433476855	30855	Economy	14500.00
0005432359599	6364	Business	36600.00
0005432359591	6364	Business	36600.00
0005432359598	6364	Business	36600.00
0005432359602	6364	Business	36600.00
0005432335838	6364	Business	36600.00
0005432335833	6364	Business	36600.00
0005432363363	6364	Economy	12200.00
0005432359559	6364	Economy	12200.00
0005432359567	6364	Economy	12200.00
0005432359603	6364	Economy	12200.00
0005432359586	6364	Economy	12200.00
0005432359581	6364	Economy	12200.00
0005432359563	6364	Economy	12200.00
0005432359577	6364	Economy	12200.00
0005432335835	6364	Economy	12200.00
0005432359572	6364	Economy	12200.00
0005432062141	6364	Economy	12200.00
0005432335839	6364	Economy	12200.00
0005432335844	6364	Economy	12200.00
0005432335842	6364	Economy	12200.00
0005432359560	6364	Economy	12200.00
0005432359589	6364	Economy	12200.00
0005432359585	6364	Economy	12200.00
0005432335832	6364	Economy	12200.00
0005432359594	6364	Economy	12200.00
0005432359574	6364	Economy	12200.00
0005432335841	6364	Economy	12200.00
0005432359584	6364	Economy	13400.00
0005432359605	6364	Economy	13400.00
0005432335834	6364	Economy	12200.00
0005432335840	6364	Economy	12200.00
0005432359592	6364	Economy	12200.00
0005432359597	6364	Economy	12200.00
0005432359573	6364	Economy	12200.00
0005432062143	6364	Economy	12200.00
0005432359568	6364	Economy	12200.00
0005432359569	6364	Economy	12200.00
0005432359564	6364	Economy	12200.00
0005432359562	6364	Economy	12200.00
0005432359588	6364	Economy	12200.00
0005432335837	6364	Economy	12200.00
0005432359576	6364	Economy	12200.00
0005432359601	6364	Economy	12200.00
0005432359587	6364	Economy	12200.00
0005432359561	6364	Economy	12200.00
0005432359558	6364	Economy	12200.00
0005432359595	6364	Economy	12200.00
0005432363364	6364	Economy	12200.00
0005432359575	6364	Economy	12200.00
0005432359570	6364	Economy	12200.00
0005432359582	6364	Economy	12200.00
0005432359590	6364	Economy	12200.00
0005432062142	6364	Economy	12200.00
0005432359593	6364	Economy	12200.00
0005432359596	6364	Economy	12200.00
0005432363362	6364	Economy	12200.00
0005432359565	6364	Economy	12200.00
0005432359600	6364	Economy	12200.00
0005432359566	6364	Economy	12200.00
0005432062140	6364	Economy	12200.00
0005432359579	6364	Economy	12200.00
0005432359556	6364	Economy	12200.00
0005432335843	6364	Economy	12200.00
0005432359580	6364	Economy	12200.00
0005432359604	6364	Economy	12200.00
0005432363361	6364	Economy	12200.00
0005432359557	6364	Economy	12200.00
0005432335836	6364	Economy	12200.00
0005432359571	6364	Economy	12200.00
0005432359578	6364	Economy	12200.00
0005432359583	6364	Economy	12200.00
0005435176637	20982	Business	36600.00
0005432052697	20982	Business	36600.00
0005434149533	20982	Business	36600.00
0005435176628	20982	Business	36600.00
0005435176635	20982	Business	36600.00
0005432052695	20982	Business	36600.00
0005435723012	20982	Business	36600.00
0005435176640	20982	Business	36600.00
0005434149541	20982	Economy	12200.00
0005435490174	20982	Economy	12200.00
0005435176617	20982	Economy	12200.00
0005435176619	20982	Economy	12200.00
0005435490176	20982	Economy	12200.00
0005435176624	20982	Economy	12200.00
0005434149532	20982	Economy	12200.00
0005435176627	20982	Economy	12200.00
0005435176618	20982	Economy	12200.00
0005435176636	20982	Economy	12200.00
0005435176629	20982	Economy	12200.00
0005434149539	20982	Economy	12200.00
0005435176641	20982	Economy	12200.00
0005434149536	20982	Economy	12200.00
0005435176631	20982	Economy	13400.00
0005434149542	20982	Economy	13400.00
0005435176625	20982	Economy	12200.00
0005434149535	20982	Economy	12200.00
0005434149537	20982	Economy	12200.00
0005435176634	20982	Economy	12200.00
0005435176626	20982	Economy	12200.00
0005435176630	20982	Economy	12200.00
0005435490175	20982	Economy	12200.00
0005435176621	20982	Economy	12200.00
0005435176622	20982	Economy	12200.00
0005435723011	20982	Economy	12200.00
0005435176613	20982	Economy	12200.00
0005435176623	20982	Economy	12200.00
0005434149540	20982	Economy	12200.00
0005434149543	20982	Economy	12200.00
0005432052696	20982	Economy	12200.00
0005434149538	20982	Economy	12200.00
0005435176614	20982	Economy	12200.00
0005435176633	20982	Economy	12200.00
0005435176620	20982	Economy	12200.00
0005435176615	20982	Economy	12200.00
0005435176632	20982	Economy	12200.00
0005435176616	20982	Economy	12200.00
0005434149534	20982	Economy	12200.00
0005435176638	20982	Economy	12200.00
0005435176639	20982	Economy	12200.00
0005432052698	20982	Economy	12200.00
0005434186150	17693	Economy	3400.00
0005434186152	17693	Economy	3100.00
0005434186151	17693	Economy	3100.00
0005434458458	29125	Economy	3400.00
0005434458464	29125	Economy	3400.00
0005434458461	29125	Economy	3400.00
0005434463892	29125	Economy	3100.00
0005434458474	29125	Economy	3100.00
0005434458463	29125	Economy	3100.00
0005434458454	29125	Economy	3100.00
0005434462752	29125	Economy	3100.00
0005434458462	29125	Economy	3100.00
0005434458475	29125	Economy	3100.00
0005434458467	29125	Economy	3100.00
0005434458466	29125	Economy	3100.00
0005434458456	29125	Economy	3100.00
0005434458470	29125	Economy	3100.00
0005434458471	29125	Economy	3100.00
0005434458465	29125	Economy	3100.00
0005434448255	29125	Economy	3100.00
0005434458469	29125	Economy	3100.00
0005434458455	29125	Economy	3100.00
0005434458460	29125	Economy	3100.00
0005434458473	29125	Economy	3100.00
0005434463891	29125	Economy	3100.00
0005434462753	29125	Economy	3100.00
0005434458468	29125	Economy	3100.00
0005434448253	29125	Economy	3100.00
0005434458472	29125	Economy	3100.00
0005434448254	29125	Economy	3100.00
0005434458457	29125	Economy	3100.00
0005434448256	29125	Economy	3100.00
0005434458459	29125	Economy	3100.00
0005432603673	21411	Economy	7300.00
0005432603680	21411	Economy	7300.00
0005432603674	21411	Economy	7300.00
0005432603667	21411	Economy	7300.00
0005432603657	21411	Economy	6600.00
0005432603662	21411	Economy	6600.00
0005432603660	21411	Economy	6600.00
0005432603656	21411	Economy	6600.00
0005432603652	21411	Economy	6600.00
0005432603644	21411	Economy	6600.00
0005432603661	21411	Economy	6600.00
0005432603675	21411	Economy	6600.00
0005432603664	21411	Economy	6600.00
0005432603648	21411	Economy	6600.00
0005432603646	21411	Economy	6600.00
0005432603645	21411	Economy	6600.00
0005432603653	21411	Economy	6600.00
0005432603659	21411	Economy	6600.00
0005432603666	21411	Economy	6600.00
0005432603669	21411	Economy	6600.00
0005432603676	21411	Economy	6600.00
0005432603651	21411	Economy	6600.00
0005432603679	21411	Economy	6600.00
0005432603672	21411	Economy	6600.00
0005432603677	21411	Economy	6600.00
0005432603671	21411	Economy	6600.00
0005432603681	21411	Economy	6600.00
0005432603643	21411	Economy	6600.00
0005432603655	21411	Economy	6600.00
0005432603654	21411	Economy	6600.00
0005432603663	21411	Economy	6600.00
0005432603649	21411	Economy	6600.00
0005432603642	21411	Economy	6600.00
0005432603650	21411	Economy	6600.00
0005432603647	21411	Economy	6600.00
0005432603670	21411	Economy	6600.00
0005432603668	21411	Economy	6600.00
0005432603665	21411	Economy	6600.00
0005432603678	21411	Economy	6600.00
0005432603658	21411	Economy	6600.00
0005434606760	22352	Economy	6600.00
0005434606759	22352	Economy	6600.00
0005434606763	22352	Economy	6600.00
0005434606762	22352	Economy	6600.00
0005434606761	22352	Economy	6600.00
0005434604838	22352	Economy	6600.00
0005434604839	22352	Economy	6600.00
0005434604837	22352	Economy	6600.00
0005432746912	376	Business	44500.00
0005432746925	376	Business	44500.00
0005432746923	376	Business	44500.00
0005432746943	376	Business	44500.00
0005432746935	376	Economy	14800.00
0005432746910	376	Economy	14800.00
0005432746921	376	Economy	16300.00
0005432753244	376	Economy	16300.00
0005432753243	376	Economy	14800.00
0005432746924	376	Economy	14800.00
0005432219933	376	Economy	14800.00
0005435154581	376	Economy	14800.00
0005432746940	376	Economy	14800.00
0005432219930	376	Economy	14800.00
0005432746915	376	Economy	14800.00
0005432746922	376	Economy	14800.00
0005432746942	376	Economy	14800.00
0005432746909	376	Economy	14800.00
0005432746908	376	Economy	14800.00
0005432746931	376	Economy	14800.00
0005432746911	376	Economy	14800.00
0005432751468	376	Economy	14800.00
0005432746944	376	Economy	14800.00
0005432746913	376	Economy	14800.00
0005432746929	376	Economy	14800.00
0005432746928	376	Economy	14800.00
0005432746903	376	Economy	14800.00
0005432746916	376	Economy	14800.00
0005432746933	376	Economy	14800.00
0005432746941	376	Economy	14800.00
0005432746927	376	Economy	14800.00
0005432751469	376	Economy	14800.00
0005432746907	376	Economy	14800.00
0005435154580	376	Economy	14800.00
0005432746917	376	Economy	14800.00
0005432749748	376	Economy	14800.00
0005435154582	376	Economy	14800.00
0005432746937	376	Economy	14800.00
0005432746914	376	Economy	14800.00
0005432746930	376	Economy	14800.00
0005432746905	376	Economy	14800.00
0005432753242	376	Economy	14800.00
0005432746920	376	Economy	14800.00
0005432746936	376	Economy	14800.00
0005432746932	376	Economy	14800.00
0005432219932	376	Economy	14800.00
0005432746904	376	Economy	14800.00
0005432219931	376	Economy	14800.00
0005432746934	376	Economy	14800.00
0005432746938	376	Economy	14800.00
0005432746939	376	Economy	14800.00
0005432746926	376	Economy	14800.00
0005432746919	376	Economy	14800.00
0005432746918	376	Economy	14800.00
0005432749747	376	Economy	14800.00
0005432746906	376	Economy	14800.00
0005432890709	12064	Business	44500.00
0005432890693	12064	Business	44500.00
0005432890706	12064	Business	44500.00
0005432890702	12064	Business	44500.00
0005432890707	12064	Business	44500.00
0005433875354	12064	Economy	14800.00
0005432214767	12064	Economy	14800.00
0005432214768	12064	Economy	14800.00
0005433293146	12064	Economy	16300.00
0005432890699	12064	Economy	14800.00
0005432890701	12064	Economy	14800.00
0005433875353	12064	Economy	14800.00
0005433293144	12064	Economy	14800.00
0005433293147	12064	Economy	14800.00
0005433293143	12064	Economy	14800.00
0005432890692	12064	Economy	14800.00
0005432890698	12064	Economy	14800.00
0005432890703	12064	Economy	14800.00
0005433293145	12064	Economy	14800.00
0005432890704	12064	Economy	14800.00
0005432890708	12064	Economy	14800.00
0005432890694	12064	Economy	14800.00
0005432890700	12064	Economy	14800.00
0005432890697	12064	Economy	14800.00
0005433293142	12064	Economy	14800.00
0005432890691	12064	Economy	14800.00
0005432890695	12064	Economy	14800.00
0005432890705	12064	Economy	14800.00
0005432890690	12064	Economy	14800.00
0005432890696	12064	Economy	14800.00
0005433524855	18989	Economy	28200.00
0005433531227	18989	Economy	28200.00
0005433524854	18989	Economy	25700.00
0005433531228	18989	Economy	25700.00
0005433533243	18989	Economy	25700.00
0005433533240	18989	Economy	25700.00
0005433531226	18989	Economy	25700.00
0005433524849	18989	Economy	25700.00
0005433524853	18989	Economy	25700.00
0005433524847	18989	Economy	25700.00
0005433533242	18989	Economy	25700.00
0005433524846	18989	Economy	25700.00
0005433524852	18989	Economy	25700.00
0005433531225	18989	Economy	25700.00
0005433524850	18989	Economy	25700.00
0005433524851	18989	Economy	25700.00
0005433524848	18989	Economy	25700.00
0005433533241	18989	Economy	25700.00
0005432927892	32512	Economy	25700.00
0005432927891	32512	Economy	25700.00
0005432927894	32512	Economy	25700.00
0005432927893	32512	Economy	25700.00
0005432927890	32512	Economy	25700.00
0005432927895	32512	Economy	25700.00
0005432927896	32512	Economy	25700.00
0005434821524	5278	Business	84000.00
0005434821526	5278	Business	84000.00
0005434558146	5278	Business	84000.00
0005434821536	5278	Business	84000.00
0005434558143	5278	Business	84000.00
0005434821470	5278	Business	84000.00
0005434821511	5278	Business	84000.00
0005434821447	5278	Business	84000.00
0005432121103	5278	Comfort	47600.00
0005435149801	5278	Comfort	47600.00
0005434821478	5278	Comfort	47600.00
0005432121102	5278	Comfort	47600.00
0005434821498	5278	Comfort	47600.00
0005434821519	5278	Comfort	47600.00
0005434821501	5278	Comfort	47600.00
0005434831070	5278	Comfort	47600.00
0005434821454	5278	Comfort	47600.00
0005434821458	5278	Comfort	47600.00
0005434821441	5278	Comfort	47600.00
0005432396178	5278	Comfort	47600.00
0005434821445	5278	Comfort	47600.00
0005434821518	5278	Comfort	47600.00
0005434821505	5278	Comfort	47600.00
0005434821527	5278	Comfort	47600.00
0005434821516	5278	Comfort	47600.00
0005435149806	5278	Comfort	47600.00
0005434821538	5278	Comfort	47600.00
0005435149811	5278	Comfort	47600.00
0005434821547	5278	Comfort	47600.00
0005434821532	5278	Comfort	47600.00
0005434821506	5278	Comfort	47600.00
0005434821467	5278	Comfort	47600.00
0005434821549	5278	Economy	28000.00
0005432121107	5278	Economy	28000.00
0005432394038	5278	Economy	28000.00
0005434821540	5278	Economy	28000.00
0005434821533	5278	Economy	28000.00
0005434821488	5278	Economy	28000.00
0005434821512	5278	Economy	28000.00
0005434821514	5278	Economy	28000.00
0005432121101	5278	Economy	28000.00
0005434821503	5278	Economy	28000.00
0005434558140	5278	Economy	28000.00
0005434821554	5278	Economy	28000.00
0005432396177	5278	Economy	28000.00
0005435149800	5278	Economy	28000.00
0005435149805	5278	Economy	28000.00
0005434821449	5278	Economy	28000.00
0005434821555	5278	Economy	28000.00
0005432394039	5278	Economy	28000.00
0005434821551	5278	Economy	28000.00
0005434831067	5278	Economy	28000.00
0005434821440	5278	Economy	28000.00
0005434558145	5278	Economy	28000.00
0005434821491	5278	Economy	28000.00
0005434821492	5278	Economy	28000.00
0005434821556	5278	Economy	28000.00
0005434821565	5278	Economy	28000.00
0005434821530	5278	Economy	28000.00
0005434821496	5278	Economy	28000.00
0005434664920	5278	Economy	28000.00
0005434821563	5278	Economy	28000.00
0005434821463	5278	Economy	28000.00
0005434821539	5278	Economy	28000.00
0005434821567	5278	Economy	28000.00
0005434821558	5278	Economy	28000.00
0005434821515	5278	Economy	28000.00
0005434821466	5278	Economy	28000.00
0005434821568	5278	Economy	28000.00
0005434821468	5278	Economy	28000.00
0005434821490	5278	Economy	28000.00
0005435149804	5278	Economy	28000.00
0005432121097	5278	Economy	28000.00
0005434821507	5278	Economy	28000.00
0005434821508	5278	Economy	30800.00
0005432394036	5278	Economy	30800.00
0005434821500	5278	Economy	28000.00
0005434821570	5278	Economy	28000.00
0005434821509	5278	Economy	28000.00
0005434558141	5278	Economy	28000.00
0005434821452	5278	Economy	28000.00
0005434821461	5278	Economy	28000.00
0005434821480	5278	Economy	28000.00
0005434821531	5278	Economy	28000.00
0005434821513	5278	Economy	28000.00
0005434558148	5278	Economy	28000.00
0005434821525	5278	Economy	28000.00
0005434558144	5278	Economy	28000.00
0005435149807	5278	Economy	28000.00
0005434821485	5278	Economy	28000.00
0005434821450	5278	Economy	28000.00
0005434821502	5278	Economy	28000.00
0005434821469	5278	Economy	28000.00
0005434821517	5278	Economy	28000.00
0005434821543	5278	Economy	28000.00
0005434558142	5278	Economy	28000.00
0005434821444	5278	Economy	28000.00
0005434821564	5278	Economy	28000.00
0005434821520	5278	Economy	28000.00
0005434821475	5278	Economy	28000.00
0005434821484	5278	Economy	28000.00
0005432396175	5278	Economy	28000.00
0005434821541	5278	Economy	28000.00
0005434821442	5278	Economy	28000.00
0005434821456	5278	Economy	28000.00
0005434821542	5278	Economy	28000.00
0005434821521	5278	Economy	28000.00
0005434821471	5278	Economy	28000.00
0005434821473	5278	Economy	28000.00
0005434821497	5278	Economy	28000.00
0005432121098	5278	Economy	28000.00
0005432121110	5278	Economy	28000.00
0005434821481	5278	Economy	28000.00
0005434821557	5278	Economy	28000.00
0005434821569	5278	Economy	28000.00
0005434821460	5278	Economy	28000.00
0005434821464	5278	Economy	28000.00
0005434828648	5278	Economy	28000.00
0005432394037	5278	Economy	28000.00
0005434821453	5278	Economy	28000.00
0005434821529	5278	Economy	28000.00
0005434821495	5278	Economy	28000.00
0005435149809	5278	Economy	28000.00
0005434821523	5278	Economy	28000.00
0005434821535	5278	Economy	28000.00
0005434821476	5278	Economy	28000.00
0005434821493	5278	Economy	28000.00
0005434821499	5278	Economy	28000.00
0005434821472	5278	Economy	28000.00
0005434821482	5278	Economy	28000.00
0005434821446	5278	Economy	28000.00
0005434821552	5278	Economy	28000.00
0005434831066	5278	Economy	28000.00
0005434831069	5278	Economy	28000.00
0005432121099	5278	Economy	28000.00
0005434821479	5278	Economy	28000.00
0005434821489	5278	Economy	30800.00
0005435149812	5278	Economy	30800.00
0005434828649	5278	Economy	28000.00
0005434821544	5278	Economy	28000.00
0005435149808	5278	Economy	28000.00
0005434821494	5278	Economy	28000.00
0005434821528	5278	Economy	28000.00
0005434821443	5278	Economy	28000.00
0005435149799	5278	Economy	28000.00
0005434821561	5278	Economy	28000.00
0005434821455	5278	Economy	28000.00
0005435149803	5278	Economy	28000.00
0005434821546	5278	Economy	28000.00
0005434821483	5278	Economy	28000.00
0005434821451	5278	Economy	28000.00
0005434821477	5278	Economy	28000.00
0005434821486	5278	Economy	28000.00
0005432121109	5278	Economy	28000.00
0005434821553	5278	Economy	28000.00
0005432121096	5278	Economy	28000.00
0005434821548	5278	Economy	28000.00
0005434821566	5278	Economy	28000.00
0005432121108	5278	Economy	28000.00
0005434828650	5278	Economy	28000.00
0005432121100	5278	Economy	28000.00
0005434821550	5278	Economy	28000.00
0005434821559	5278	Economy	28000.00
0005435149802	5278	Economy	28000.00
0005434821487	5278	Economy	28000.00
0005434821465	5278	Economy	28000.00
0005434664919	5278	Economy	28000.00
0005434821459	5278	Economy	28000.00
0005434821504	5278	Economy	28000.00
0005435149798	5278	Economy	28000.00
0005434821510	5278	Economy	28000.00
0005432121106	5278	Economy	28000.00
0005434821560	5278	Economy	28000.00
0005432121105	5278	Economy	28000.00
0005432121104	5278	Economy	28000.00
0005434558147	5278	Economy	28000.00
0005434821534	5278	Economy	28000.00
0005434821474	5278	Economy	28000.00
0005432396176	5278	Economy	28000.00
0005434821448	5278	Economy	28000.00
0005434831068	5278	Economy	28000.00
0005434821562	5278	Economy	28000.00
0005434821537	5278	Economy	28000.00
0005435149810	5278	Economy	28000.00
0005434821457	5278	Economy	28000.00
0005434821522	5278	Economy	28000.00
0005434558139	5278	Economy	28000.00
0005434821545	5278	Economy	28000.00
0005434821462	5278	Economy	28000.00
0005435372202	9883	Business	84000.00
0005435372222	9883	Business	84000.00
0005435372211	9883	Business	84000.00
0005435372218	9883	Business	84000.00
0005435372213	9883	Business	84000.00
0005432202946	9883	Business	84000.00
0005435372204	9883	Business	84000.00
0005435386463	9883	Business	84000.00
0005435386459	9883	Business	84000.00
0005435735061	9883	Business	84000.00
0005435372201	9883	Business	84000.00
0005435372197	9883	Comfort	47600.00
0005435372193	9883	Comfort	47600.00
0005432202942	9883	Comfort	47600.00
0005435735064	9883	Comfort	47600.00
0005435735062	9883	Comfort	47600.00
0005435372166	9883	Comfort	47600.00
0005435179687	9883	Comfort	47600.00
0005432823416	9883	Comfort	47600.00
0005435372210	9883	Comfort	47600.00
0005435372198	9883	Comfort	47600.00
0005435372160	9883	Comfort	47600.00
0005435372187	9883	Comfort	47600.00
0005435372174	9883	Comfort	47600.00
0005432823417	9883	Economy	28000.00
0005435735060	9883	Economy	28000.00
0005435386464	9883	Economy	28000.00
0005435372186	9883	Economy	28000.00
0005435302122	9883	Economy	28000.00
0005435386461	9883	Economy	28000.00
0005435372184	9883	Economy	28000.00
0005435372165	9883	Economy	28000.00
0005435372219	9883	Economy	28000.00
0005435386462	9883	Economy	28000.00
0005435372215	9883	Economy	28000.00
0005435372161	9883	Economy	28000.00
0005432202948	9883	Economy	28000.00
0005435372169	9883	Economy	28000.00
0005432823418	9883	Economy	28000.00
0005435372212	9883	Economy	28000.00
0005435372216	9883	Economy	28000.00
0005435179686	9883	Economy	30800.00
0005435372200	9883	Economy	30800.00
0005435302119	9883	Economy	30800.00
0005435372163	9883	Economy	30800.00
0005435299696	9883	Economy	30800.00
0005435302123	9883	Economy	28000.00
0005435386460	9883	Economy	28000.00
0005435372178	9883	Economy	28000.00
0005435372179	9883	Economy	28000.00
0005435372171	9883	Economy	28000.00
0005435299699	9883	Economy	28000.00
0005435372203	9883	Economy	28000.00
0005435372191	9883	Economy	28000.00
0005435372162	9883	Economy	28000.00
0005435661884	9883	Economy	28000.00
0005435372176	9883	Economy	28000.00
0005435372192	9883	Economy	28000.00
0005435372205	9883	Economy	28000.00
0005435372214	9883	Economy	28000.00
0005435372173	9883	Economy	28000.00
0005435372190	9883	Economy	28000.00
0005435372221	9883	Economy	28000.00
0005435386458	9883	Economy	28000.00
0005435372164	9883	Economy	28000.00
0005435372209	9883	Economy	28000.00
0005435661882	9883	Economy	28000.00
0005435372195	9883	Economy	28000.00
0005435735063	9883	Economy	28000.00
0005435372194	9883	Economy	28000.00
0005432202947	9883	Economy	28000.00
0005435372189	9883	Economy	28000.00
0005435372206	9883	Economy	28000.00
0005435372181	9883	Economy	28000.00
0005435372159	9883	Economy	28000.00
0005435372217	9883	Economy	28000.00
0005435372223	9883	Economy	28000.00
0005435372167	9883	Economy	28000.00
0005435372175	9883	Economy	28000.00
0005432202941	9883	Economy	30800.00
0005432202943	9883	Economy	30800.00
0005435372208	9883	Economy	28000.00
0005435372177	9883	Economy	28000.00
0005435372207	9883	Economy	28000.00
0005435372224	9883	Economy	28000.00
0005435372183	9883	Economy	28000.00
0005435372172	9883	Economy	28000.00
0005435372225	9883	Economy	28000.00
0005435661883	9883	Economy	28000.00
0005435302120	9883	Economy	28000.00
0005435372182	9883	Economy	28000.00
0005435372185	9883	Economy	28000.00
0005435372168	9883	Economy	28000.00
0005432202945	9883	Economy	28000.00
0005435372180	9883	Economy	28000.00
0005435372199	9883	Economy	28000.00
0005435372170	9883	Economy	28000.00
0005435302121	9883	Economy	28000.00
0005435372188	9883	Economy	28000.00
0005435372196	9883	Economy	28000.00
0005432202944	9883	Economy	28000.00
0005435299698	9883	Economy	28000.00
0005435299697	9883	Economy	28000.00
0005435372220	9883	Economy	28000.00
0005435082657	6983	Economy	8200.00
0005435790259	6983	Economy	7400.00
0005435790257	6983	Economy	7400.00
0005435082653	6983	Economy	7400.00
0005435082658	6983	Economy	7400.00
0005435082652	6983	Economy	7400.00
0005435082654	6983	Economy	7400.00
0005435790258	6983	Economy	7400.00
0005435082656	6983	Economy	7400.00
0005435082660	6983	Economy	7400.00
0005435082650	6983	Economy	7400.00
0005435082661	6983	Economy	7400.00
0005435082651	6983	Economy	7400.00
0005435082655	6983	Economy	7400.00
0005435082659	6983	Economy	7400.00
0005434755781	9557	Business	32800.00
0005434755756	9557	Business	32800.00
0005434755771	9557	Business	32800.00
0005434755737	9557	Business	32800.00
0005434755765	9557	Business	32800.00
0005434755759	9557	Economy	10900.00
0005434755766	9557	Economy	10900.00
0005434755757	9557	Economy	10900.00
0005434755746	9557	Economy	10900.00
0005434755773	9557	Economy	10900.00
0005434755747	9557	Economy	12000.00
0005434755774	9557	Economy	12000.00
0005434755739	9557	Economy	10900.00
0005434755763	9557	Economy	10900.00
0005434755743	9557	Economy	10900.00
0005434755738	9557	Economy	10900.00
0005434755758	9557	Economy	10900.00
0005434755772	9557	Economy	10900.00
0005434755762	9557	Economy	10900.00
0005434755760	9557	Economy	10900.00
0005434755776	9557	Economy	10900.00
0005434755778	9557	Economy	10900.00
0005434755767	9557	Economy	10900.00
0005434755764	9557	Economy	10900.00
0005434755745	9557	Economy	10900.00
0005434755755	9557	Economy	10900.00
0005434755742	9557	Economy	10900.00
0005434755749	9557	Economy	10900.00
0005434755752	9557	Economy	10900.00
0005434755780	9557	Economy	10900.00
0005434755769	9557	Economy	10900.00
0005434755748	9557	Economy	10900.00
0005434755761	9557	Economy	10900.00
0005434755736	9557	Economy	10900.00
0005434755750	9557	Economy	10900.00
0005434755754	9557	Economy	10900.00
0005434755740	9557	Economy	10900.00
0005434755744	9557	Economy	10900.00
0005434755777	9557	Economy	10900.00
0005434755779	9557	Economy	10900.00
0005434755741	9557	Economy	10900.00
0005434755753	9557	Economy	10900.00
0005434755775	9557	Economy	10900.00
0005434755751	9557	Economy	10900.00
0005434755768	9557	Economy	10900.00
0005434755770	9557	Economy	10900.00
0005434213722	28631	Business	32800.00
0005434213723	28631	Business	32800.00
0005434213728	28631	Business	32800.00
0005434213734	28631	Business	32800.00
0005434213731	28631	Business	32800.00
0005434213730	28631	Business	32800.00
0005434213715	28631	Business	32800.00
0005434213699	28631	Business	32800.00
0005434213732	28631	Economy	10900.00
0005434213714	28631	Economy	10900.00
0005434213743	28631	Economy	10900.00
0005434213738	28631	Economy	10900.00
0005434213704	28631	Economy	10900.00
0005434213720	28631	Economy	10900.00
0005434213719	28631	Economy	12000.00
0005434213703	28631	Economy	12000.00
0005434213739	28631	Economy	10900.00
0005434213737	28631	Economy	10900.00
0005434213718	28631	Economy	10900.00
0005434213706	28631	Economy	10900.00
0005434213726	28631	Economy	10900.00
0005434213700	28631	Economy	10900.00
0005434213712	28631	Economy	10900.00
0005434213725	28631	Economy	10900.00
0005434213729	28631	Economy	10900.00
0005434213740	28631	Economy	10900.00
0005434213745	28631	Economy	10900.00
0005434213717	28631	Economy	10900.00
0005434213711	28631	Economy	10900.00
0005434213701	28631	Economy	10900.00
0005434213744	28631	Economy	10900.00
0005434213710	28631	Economy	10900.00
0005434213716	28631	Economy	10900.00
0005434213735	28631	Economy	10900.00
0005434213705	28631	Economy	10900.00
0005434213713	28631	Economy	10900.00
0005434213708	28631	Economy	10900.00
0005434213724	28631	Economy	10900.00
0005434213702	28631	Economy	10900.00
0005434213736	28631	Economy	10900.00
0005434213742	28631	Economy	10900.00
0005434213709	28631	Economy	10900.00
0005434213733	28631	Economy	10900.00
0005434213721	28631	Economy	10900.00
0005434213727	28631	Economy	10900.00
0005434213707	28631	Economy	10900.00
0005434213741	28631	Economy	10900.00
0005434213698	28631	Economy	10900.00
0005435100072	10823	Economy	8900.00
0005435100074	10823	Economy	8900.00
0005435100073	10823	Economy	8900.00
0005434760157	31806	Economy	8900.00
0005434760156	31806	Economy	8900.00
0005434638882	1982	Economy	20900.00
0005434638898	1982	Economy	20900.00
0005434638880	1982	Economy	20900.00
0005434638883	1982	Economy	19000.00
0005434638887	1982	Economy	19000.00
0005434638891	1982	Economy	19000.00
0005434638901	1982	Economy	19000.00
0005434638894	1982	Economy	19000.00
0005434638896	1982	Economy	19000.00
0005434638879	1982	Economy	19000.00
0005432290583	1982	Economy	19000.00
0005435948307	1982	Economy	19000.00
0005434638902	1982	Economy	19000.00
0005434638884	1982	Economy	19000.00
0005434638895	1982	Economy	19000.00
0005434638888	1982	Economy	19000.00
0005434638899	1982	Economy	19000.00
0005432290584	1982	Economy	19000.00
0005434638900	1982	Economy	19000.00
0005434638892	1982	Economy	19000.00
0005434638885	1982	Economy	19000.00
0005434638877	1982	Economy	19000.00
0005434638897	1982	Economy	19000.00
0005434638889	1982	Economy	19000.00
0005434638890	1982	Economy	19000.00
0005434638886	1982	Economy	19000.00
0005434638876	1982	Economy	19000.00
0005434638893	1982	Economy	19000.00
0005434638881	1982	Economy	19000.00
0005434638878	1982	Economy	19000.00
0005433202105	23271	Economy	20900.00
0005433202116	23271	Economy	19000.00
0005433202113	23271	Economy	19000.00
0005433202110	23271	Economy	19000.00
0005433202115	23271	Economy	19000.00
0005433202111	23271	Economy	19000.00
0005433202106	23271	Economy	19000.00
0005433202107	23271	Economy	19000.00
0005433202108	23271	Economy	19000.00
0005433202112	23271	Economy	19000.00
0005433202103	23271	Economy	19000.00
0005433202104	23271	Economy	19000.00
0005433202102	23271	Economy	19000.00
0005433202109	23271	Economy	19000.00
0005433202114	23271	Economy	19000.00
0005434600380	6036	Business	69700.00
0005434600372	6036	Business	69700.00
0005432111229	6036	Business	69700.00
0005434600370	6036	Business	69700.00
0005433533245	6036	Business	69700.00
0005434600368	6036	Economy	23200.00
0005434600366	6036	Economy	23200.00
0005434600365	6036	Economy	23200.00
0005433531231	6036	Economy	23200.00
0005434600357	6036	Economy	23200.00
0005434600359	6036	Economy	25600.00
0005433531230	6036	Economy	23200.00
0005433533247	6036	Economy	23200.00
0005434600358	6036	Economy	23200.00
0005434600381	6036	Economy	23200.00
0005434600362	6036	Economy	23200.00
0005434600354	6036	Economy	23200.00
0005432111230	6036	Economy	23200.00
0005434600373	6036	Economy	23200.00
0005434600356	6036	Economy	23200.00
0005433531232	6036	Economy	23200.00
0005434600364	6036	Economy	23200.00
0005434600374	6036	Economy	23200.00
0005434600379	6036	Economy	23200.00
0005434600377	6036	Economy	23200.00
0005434600376	6036	Economy	23200.00
0005433531229	6036	Economy	23200.00
0005433531233	6036	Economy	23200.00
0005434600375	6036	Economy	23200.00
0005434600371	6036	Economy	23200.00
0005434600361	6036	Economy	23200.00
0005434600367	6036	Economy	23200.00
0005433533244	6036	Economy	23200.00
0005433533246	6036	Economy	23200.00
0005434600369	6036	Economy	23200.00
0005434600355	6036	Economy	23200.00
0005434600360	6036	Economy	23200.00
0005434600363	6036	Economy	23200.00
0005434600378	6036	Economy	23200.00
0005432111228	6036	Economy	23200.00
0005435326512	18565	Business	69700.00
0005435326516	18565	Economy	23200.00
0005435326523	18565	Economy	23200.00
0005435326521	18565	Economy	25600.00
0005435326514	18565	Economy	23200.00
0005435326515	18565	Economy	23200.00
0005435326518	18565	Economy	23200.00
0005435326519	18565	Economy	23200.00
0005435326513	18565	Economy	23200.00
0005435326517	18565	Economy	23200.00
0005435326522	18565	Economy	23200.00
0005435326520	18565	Economy	23200.00
0005435326524	18565	Economy	23200.00
0005434550311	10599	Business	9100.00
0005434550267	10599	Business	9100.00
0005434550299	10599	Business	9100.00
0005434550310	10599	Business	9100.00
0005434550288	10599	Business	9100.00
0005434550266	10599	Business	9100.00
0005434550305	10599	Business	9100.00
0005434550292	10599	Economy	3000.00
0005434550263	10599	Economy	3000.00
0005434550289	10599	Economy	3000.00
0005434550271	10599	Economy	3000.00
0005434550306	10599	Economy	3000.00
0005434550279	10599	Economy	3000.00
0005434550309	10599	Economy	3000.00
0005434550259	10599	Economy	3300.00
0005434550297	10599	Economy	3300.00
0005434550293	10599	Economy	3000.00
0005434550274	10599	Economy	3000.00
0005434550277	10599	Economy	3000.00
0005434550287	10599	Economy	3000.00
0005434550281	10599	Economy	3000.00
0005434550276	10599	Economy	3000.00
0005434550283	10599	Economy	3000.00
0005434550272	10599	Economy	3000.00
0005434550260	10599	Economy	3000.00
0005434554025	10599	Economy	3000.00
0005434550286	10599	Economy	3000.00
0005434550257	10599	Economy	3000.00
0005434550265	10599	Economy	3000.00
0005434550262	10599	Economy	3000.00
0005434550303	10599	Economy	3000.00
0005434550256	10599	Economy	3000.00
0005434550268	10599	Economy	3000.00
0005434550269	10599	Economy	3000.00
0005434554026	10599	Economy	3000.00
0005434550300	10599	Economy	3000.00
0005434550296	10599	Economy	3000.00
0005434550261	10599	Economy	3000.00
0005434554027	10599	Economy	3000.00
0005434550308	10599	Economy	3000.00
0005434550298	10599	Economy	3000.00
0005434550264	10599	Economy	3000.00
0005434550291	10599	Economy	3000.00
0005434550280	10599	Economy	3000.00
0005434550284	10599	Economy	3000.00
0005434550285	10599	Economy	3000.00
0005434550275	10599	Economy	3000.00
0005434550290	10599	Economy	3000.00
0005434550301	10599	Economy	3000.00
0005434550295	10599	Economy	3000.00
0005434550282	10599	Economy	3000.00
0005434550294	10599	Economy	3000.00
0005434550273	10599	Economy	3000.00
0005434550302	10599	Economy	3000.00
0005434550270	10599	Economy	3000.00
0005434550304	10599	Economy	3000.00
0005434550307	10599	Economy	3000.00
0005434550278	10599	Economy	3000.00
0005434550258	10599	Economy	3000.00
0005433180686	27760	Business	9100.00
0005433180693	27760	Business	9100.00
0005433180683	27760	Business	9100.00
0005433180688	27760	Business	9100.00
0005433180679	27760	Economy	3000.00
0005433180697	27760	Economy	3000.00
0005433180692	27760	Economy	3000.00
0005433180678	27760	Economy	3300.00
0005433180677	27760	Economy	3000.00
0005433180700	27760	Economy	3000.00
0005433180675	27760	Economy	3000.00
0005433180684	27760	Economy	3000.00
0005433180685	27760	Economy	3000.00
0005433180691	27760	Economy	3000.00
0005433180680	27760	Economy	3000.00
0005433180682	27760	Economy	3000.00
0005433180699	27760	Economy	3000.00
0005433180695	27760	Economy	3000.00
0005433180690	27760	Economy	3000.00
0005433180687	27760	Economy	3000.00
0005433180698	27760	Economy	3000.00
0005433180676	27760	Economy	3000.00
0005433180674	27760	Economy	3000.00
0005433180694	27760	Economy	3000.00
0005433180681	27760	Economy	3000.00
0005433180689	27760	Economy	3000.00
0005433180696	27760	Economy	3000.00
0005433459150	6138	Economy	11700.00
0005433459151	6138	Economy	11700.00
0005433459148	6138	Economy	11700.00
0005433459147	6138	Economy	11700.00
0005433459149	6138	Economy	11700.00
0005435254433	19333	Economy	11700.00
0005435254431	19333	Economy	11700.00
0005435254432	19333	Economy	11700.00
0005435681466	6731	Business	51100.00
0005435681436	6731	Business	51100.00
0005435681433	6731	Business	51100.00
0005435681463	6731	Business	51100.00
0005435681442	6731	Business	51100.00
0005435681438	6731	Business	51100.00
0005435681443	6731	Business	51100.00
0005435681429	6731	Business	51100.00
0005432136085	6731	Economy	17000.00
0005435681437	6731	Economy	17000.00
0005435681444	6731	Economy	17000.00
0005435681446	6731	Economy	17000.00
0005435681432	6731	Economy	18700.00
0005435681456	6731	Economy	18700.00
0005435681454	6731	Economy	18700.00
0005435681450	6731	Economy	18700.00
0005435630915	6731	Economy	18700.00
0005432136089	6731	Economy	17000.00
0005435681428	6731	Economy	17000.00
0005435681464	6731	Economy	17000.00
0005432136087	6731	Economy	17000.00
0005435681452	6731	Economy	17000.00
0005432136088	6731	Economy	17000.00
0005435681445	6731	Economy	17000.00
0005435681462	6731	Economy	17000.00
0005435681458	6731	Economy	17000.00
0005435681431	6731	Economy	17000.00
0005435681455	6731	Economy	17000.00
0005435681430	6731	Economy	17000.00
0005432136086	6731	Economy	17000.00
0005435681457	6731	Economy	17000.00
0005435681439	6731	Economy	17000.00
0005435681440	6731	Economy	17000.00
0005435630914	6731	Economy	17000.00
0005435661879	6731	Economy	17000.00
0005435681460	6731	Economy	17000.00
0005435681465	6731	Economy	17000.00
0005435661881	6731	Economy	17000.00
0005435681447	6731	Economy	17000.00
0005435661880	6731	Economy	17000.00
0005435681451	6731	Economy	17000.00
0005435681453	6731	Economy	17000.00
0005435681449	6731	Economy	17000.00
0005435681448	6731	Economy	17000.00
0005435681459	6731	Economy	17000.00
0005435681441	6731	Economy	17000.00
0005435681434	6731	Economy	17000.00
0005435681435	6731	Economy	17000.00
0005435681461	6731	Economy	17000.00
0005435630916	6731	Economy	17000.00
0005435437587	24572	Business	51100.00
0005435437588	24572	Business	51100.00
0005435437590	24572	Business	51100.00
0005435220284	24572	Business	51100.00
0005432533246	24572	Economy	17000.00
0005435437580	24572	Economy	17000.00
0005432305708	24572	Economy	17000.00
0005435437592	24572	Economy	17000.00
0005434828651	24572	Economy	17000.00
0005435437595	24572	Economy	17000.00
0005435219165	24572	Economy	17000.00
0005435437593	24572	Economy	17000.00
0005435437586	24572	Economy	17000.00
0005432533245	24572	Economy	17000.00
0005435437581	24572	Economy	17000.00
0005435437582	24572	Economy	17000.00
0005434828652	24572	Economy	17000.00
0005435437577	24572	Economy	17000.00
0005435437575	24572	Economy	17000.00
0005432533244	24572	Economy	17000.00
0005435437596	24572	Economy	17000.00
0005435437583	24572	Economy	17000.00
0005435437579	24572	Economy	17000.00
0005435437591	24572	Economy	17000.00
0005435220283	24572	Economy	17000.00
0005435437585	24572	Economy	17000.00
0005434828653	24572	Economy	17000.00
0005435437589	24572	Economy	17000.00
0005435437576	24572	Economy	17000.00
0005435437578	24572	Economy	17000.00
0005432305707	24572	Economy	17000.00
0005435437594	24572	Economy	17000.00
0005435437584	24572	Economy	17000.00
0005432533243	24572	Economy	17000.00
0005435125672	11533	Business	26400.00
0005435125667	11533	Business	26400.00
0005435098522	11533	Business	26400.00
0005435125670	11533	Business	26400.00
0005435125676	11533	Business	26400.00
0005435105926	11533	Business	26400.00
0005435105929	11533	Business	26400.00
0005435105928	11533	Business	26400.00
0005435125685	11533	Economy	8800.00
0005435125658	11533	Economy	8800.00
0005435125675	11533	Economy	8800.00
0005435125686	11533	Economy	8800.00
0005435125678	11533	Economy	8800.00
0005435125679	11533	Economy	9700.00
0005435125662	11533	Economy	8800.00
0005435125659	11533	Economy	8800.00
0005435125666	11533	Economy	8800.00
0005435125665	11533	Economy	8800.00
0005435125669	11533	Economy	8800.00
0005435125652	11533	Economy	8800.00
0005435098521	11533	Economy	8800.00
0005435125682	11533	Economy	8800.00
0005435125674	11533	Economy	8800.00
0005435125687	11533	Economy	8800.00
0005435125671	11533	Economy	8800.00
0005435125673	11533	Economy	8800.00
0005435125657	11533	Economy	8800.00
0005435105927	11533	Economy	8800.00
0005435125664	11533	Economy	8800.00
0005435125684	11533	Economy	8800.00
0005435125680	11533	Economy	8800.00
0005435125649	11533	Economy	8800.00
0005435125648	11533	Economy	8800.00
0005435125663	11533	Economy	8800.00
0005435125647	11533	Economy	8800.00
0005435125681	11533	Economy	8800.00
0005435125668	11533	Economy	8800.00
0005435125660	11533	Economy	8800.00
0005435125655	11533	Economy	8800.00
0005435125654	11533	Economy	8800.00
0005435125677	11533	Economy	8800.00
0005435125688	11533	Economy	8800.00
0005435125650	11533	Economy	8800.00
0005435125651	11533	Economy	8800.00
0005435125683	11533	Economy	8800.00
0005435125653	11533	Economy	8800.00
0005435125656	11533	Economy	8800.00
0005435125661	11533	Economy	8800.00
0005435558044	31872	Economy	8800.00
0005435558045	31872	Economy	8800.00
0005435558043	31872	Economy	9700.00
0005435558042	31872	Economy	8800.00
0005435558046	31872	Economy	8800.00
0005433397267	13533	Business	36600.00
0005433397234	13533	Business	36600.00
0005433397246	13533	Business	36600.00
0005433397245	13533	Business	36600.00
0005433397233	13533	Business	36600.00
0005433397229	13533	Business	36600.00
0005433397253	13533	Business	36600.00
0005433397257	13533	Economy	12200.00
0005433397252	13533	Economy	12200.00
0005433397270	13533	Economy	12200.00
0005433397240	13533	Economy	13400.00
0005433397248	13533	Economy	13400.00
0005433397269	13533	Economy	13400.00
0005433397243	13533	Economy	12200.00
0005433397256	13533	Economy	12200.00
0005433397239	13533	Economy	12200.00
0005433397275	13533	Economy	12200.00
0005433397235	13533	Economy	12200.00
0005433397232	13533	Economy	12200.00
0005433397277	13533	Economy	12200.00
0005433397259	13533	Economy	12200.00
0005433397272	13533	Economy	12200.00
0005433397273	13533	Economy	12200.00
0005433397254	13533	Economy	12200.00
0005433397274	13533	Economy	12200.00
0005433397271	13533	Economy	12200.00
0005433397250	13533	Economy	12200.00
0005433397258	13533	Economy	12200.00
0005433397236	13533	Economy	12200.00
0005433397230	13533	Economy	12200.00
0005433397263	13533	Economy	12200.00
0005433397260	13533	Economy	12200.00
0005433397261	13533	Economy	12200.00
0005433397251	13533	Economy	12200.00
0005433397262	13533	Economy	12200.00
0005433397231	13533	Economy	12200.00
0005433397276	13533	Economy	12200.00
0005433397268	13533	Economy	12200.00
0005433397247	13533	Economy	12200.00
0005433397241	13533	Economy	12200.00
0005433397265	13533	Economy	12200.00
0005433397266	13533	Economy	12200.00
0005433397238	13533	Economy	12200.00
0005433397249	13533	Economy	12200.00
0005433397237	13533	Economy	12200.00
0005433397244	13533	Economy	12200.00
0005433397264	13533	Economy	12200.00
0005433397255	13533	Economy	12200.00
0005433397242	13533	Economy	12200.00
0005435732126	19378	Business	36600.00
0005435732128	19378	Business	36600.00
0005435732127	19378	Business	36600.00
0005432297233	19378	Economy	12200.00
0005435732125	19378	Economy	12200.00
0005432297234	19378	Economy	12200.00
0005435925072	13149	Business	11300.00
0005435925062	13149	Business	11300.00
0005435925070	13149	Economy	3800.00
0005435925063	13149	Economy	3800.00
0005435925061	13149	Economy	3800.00
0005435925073	13149	Economy	3800.00
0005435925074	13149	Economy	3800.00
0005435925067	13149	Economy	3800.00
0005435925076	13149	Economy	3800.00
0005435925065	13149	Economy	3800.00
0005435925068	13149	Economy	3800.00
0005435925075	13149	Economy	3800.00
0005435925066	13149	Economy	3800.00
0005435925064	13149	Economy	3800.00
0005435925077	13149	Economy	3800.00
0005435925071	13149	Economy	3800.00
0005435925069	13149	Economy	3800.00
0005435068201	15478	Business	11300.00
0005435068162	15478	Business	11300.00
0005435068161	15478	Business	11300.00
0005435068181	15478	Business	11300.00
0005435068189	15478	Business	11300.00
0005435068165	15478	Business	11300.00
0005435068203	15478	Economy	3800.00
0005435068188	15478	Economy	3800.00
0005435068190	15478	Economy	3800.00
0005435068171	15478	Economy	3800.00
0005435068183	15478	Economy	3800.00
0005435068207	15478	Economy	3800.00
0005435068186	15478	Economy	3800.00
0005435068163	15478	Economy	3800.00
0005435068167	15478	Economy	3800.00
0005435068166	15478	Economy	3800.00
0005435068184	15478	Economy	3800.00
0005435068168	15478	Economy	3800.00
0005435068208	15478	Economy	3800.00
0005435068196	15478	Economy	3800.00
0005435068160	15478	Economy	3800.00
0005435068200	15478	Economy	3800.00
0005435068193	15478	Economy	3800.00
0005435068169	15478	Economy	3800.00
0005435068209	15478	Economy	3800.00
0005435068187	15478	Economy	3800.00
0005435068158	15478	Economy	3800.00
0005435068180	15478	Economy	3800.00
0005435068174	15478	Economy	3800.00
0005435068185	15478	Economy	3800.00
0005435068204	15478	Economy	3800.00
0005435068159	15478	Economy	3800.00
0005435068175	15478	Economy	3800.00
0005435068176	15478	Economy	3800.00
0005435068198	15478	Economy	3800.00
0005435068197	15478	Economy	3800.00
0005435068178	15478	Economy	3800.00
0005435068192	15478	Economy	3800.00
0005435068194	15478	Economy	3800.00
0005435068199	15478	Economy	3800.00
0005435068177	15478	Economy	3800.00
0005435068202	15478	Economy	3800.00
0005435068191	15478	Economy	3800.00
0005435068164	15478	Economy	3800.00
0005435068210	15478	Economy	3800.00
0005435068206	15478	Economy	3800.00
0005435068170	15478	Economy	3800.00
0005435068179	15478	Economy	3800.00
0005435068172	15478	Economy	3800.00
0005435068173	15478	Economy	3800.00
0005435068182	15478	Economy	3800.00
0005435068195	15478	Economy	3800.00
0005435068205	15478	Economy	3800.00
0005435808058	23194	Economy	24700.00
0005435808049	23194	Economy	24700.00
0005435808057	23194	Economy	24700.00
0005435808055	23194	Economy	24700.00
0005435808051	23194	Economy	24700.00
0005435808053	23194	Economy	24700.00
0005435808056	23194	Economy	24700.00
0005435808054	23194	Economy	24700.00
0005435808050	23194	Economy	24700.00
0005435808059	23194	Economy	24700.00
0005435808052	23194	Economy	24700.00
0005434213772	10689	Business	61300.00
0005434213755	10689	Business	61300.00
0005434213767	10689	Business	61300.00
0005434213784	10689	Business	61300.00
0005434213782	10689	Business	61300.00
0005434213793	10689	Economy	20400.00
0005434213763	10689	Economy	20400.00
0005434213789	10689	Economy	20400.00
0005434213781	10689	Economy	20400.00
0005434213758	10689	Economy	20400.00
0005434213786	10689	Economy	20400.00
0005434213757	10689	Economy	22500.00
0005434213753	10689	Economy	22500.00
0005434213777	10689	Economy	20400.00
0005434213787	10689	Economy	20400.00
0005434213766	10689	Economy	20400.00
0005434213746	10689	Economy	20400.00
0005434213774	10689	Economy	20400.00
0005434213747	10689	Economy	20400.00
0005434213778	10689	Economy	20400.00
0005434213783	10689	Economy	20400.00
0005434213792	10689	Economy	20400.00
0005434213750	10689	Economy	20400.00
0005434213760	10689	Economy	20400.00
0005434213752	10689	Economy	20400.00
0005434213751	10689	Economy	20400.00
0005434213749	10689	Economy	20400.00
0005434213779	10689	Economy	20400.00
0005434213780	10689	Economy	20400.00
0005434213768	10689	Economy	20400.00
0005434213762	10689	Economy	20400.00
0005434213790	10689	Economy	20400.00
0005434213754	10689	Economy	20400.00
0005434213765	10689	Economy	20400.00
0005434213761	10689	Economy	20400.00
0005434213791	10689	Economy	20400.00
0005434213756	10689	Economy	20400.00
0005434213759	10689	Economy	20400.00
0005434213771	10689	Economy	20400.00
0005434213769	10689	Economy	20400.00
0005434213770	10689	Economy	20400.00
0005434213764	10689	Economy	20400.00
0005434213785	10689	Economy	20400.00
0005434213776	10689	Economy	20400.00
0005434213788	10689	Economy	20400.00
0005434213773	10689	Economy	20400.00
0005434213748	10689	Economy	20400.00
0005434213775	10689	Economy	20400.00
0005434755729	28649	Business	61300.00
0005434755707	28649	Business	61300.00
0005434755731	28649	Business	61300.00
0005434755722	28649	Business	61300.00
0005434755733	28649	Economy	20400.00
0005434755732	28649	Economy	20400.00
0005434755714	28649	Economy	20400.00
0005434755730	28649	Economy	20400.00
0005434755726	28649	Economy	20400.00
0005434755715	28649	Economy	20400.00
0005434755725	28649	Economy	22500.00
0005434755728	28649	Economy	22500.00
0005434755706	28649	Economy	20400.00
0005434755717	28649	Economy	20400.00
0005434755703	28649	Economy	20400.00
0005434755718	28649	Economy	20400.00
0005434755712	28649	Economy	20400.00
0005434755727	28649	Economy	20400.00
0005434755704	28649	Economy	20400.00
0005434755724	28649	Economy	20400.00
0005434755719	28649	Economy	20400.00
0005434755711	28649	Economy	20400.00
0005434755709	28649	Economy	20400.00
0005434755710	28649	Economy	20400.00
0005434755723	28649	Economy	20400.00
0005434755721	28649	Economy	20400.00
0005434755705	28649	Economy	20400.00
0005434755735	28649	Economy	20400.00
0005434755713	28649	Economy	20400.00
0005434755720	28649	Economy	20400.00
0005434755734	28649	Economy	20400.00
0005434755708	28649	Economy	20400.00
0005434755716	28649	Economy	20400.00
0005435038681	5456	Business	29500.00
0005435006633	5456	Business	29500.00
0005435038709	5456	Business	29500.00
0005435038715	5456	Business	29500.00
0005435038678	5456	Business	29500.00
0005435006629	5456	Business	29500.00
0005435038708	5456	Business	29500.00
0005435038734	5456	Business	29500.00
0005432125329	5456	Business	29500.00
0005435038721	5456	Business	29500.00
0005435038732	5456	Business	29500.00
0005435038718	5456	Business	29500.00
0005435038738	5456	Economy	9800.00
0005432125327	5456	Economy	9800.00
0005435038719	5456	Economy	9800.00
0005435038704	5456	Economy	9800.00
0005435038737	5456	Economy	9800.00
0005435038703	5456	Economy	9800.00
0005435038726	5456	Economy	9800.00
0005435038727	5456	Economy	9800.00
0005435006630	5456	Economy	9800.00
0005435006621	5456	Economy	9800.00
0005435006636	5456	Economy	9800.00
0005435038682	5456	Economy	9800.00
0005435038698	5456	Economy	9800.00
0005435038725	5456	Economy	9800.00
0005435006623	5456	Economy	9800.00
0005435006625	5456	Economy	9800.00
0005435038710	5456	Economy	9800.00
0005435038680	5456	Economy	9800.00
0005435038731	5456	Economy	9800.00
0005435038707	5456	Economy	9800.00
0005432125328	5456	Economy	9800.00
0005435006644	5456	Economy	9800.00
0005435038716	5456	Economy	9800.00
0005432125330	5456	Economy	9800.00
0005435038705	5456	Economy	9800.00
0005435038735	5456	Economy	9800.00
0005435038676	5456	Economy	9800.00
0005435038728	5456	Economy	9800.00
0005435038679	5456	Economy	10800.00
0005432125331	5456	Economy	10800.00
0005435038730	5456	Economy	10800.00
0005435038687	5456	Economy	10800.00
0005435006622	5456	Economy	10800.00
0005435006634	5456	Economy	10800.00
0005435038702	5456	Economy	9800.00
0005435038696	5456	Economy	9800.00
0005435038684	5456	Economy	9800.00
0005435038724	5456	Economy	9800.00
0005435038713	5456	Economy	9800.00
0005435006628	5456	Economy	9800.00
0005435038699	5456	Economy	9800.00
0005435006643	5456	Economy	9800.00
0005435038686	5456	Economy	9800.00
0005435038688	5456	Economy	9800.00
0005435006626	5456	Economy	9800.00
0005435038711	5456	Economy	9800.00
0005435006645	5456	Economy	9800.00
0005435038685	5456	Economy	9800.00
0005435038693	5456	Economy	9800.00
0005435006641	5456	Economy	9800.00
0005435006640	5456	Economy	9800.00
0005435006642	5456	Economy	9800.00
0005435038695	5456	Economy	9800.00
0005435038677	5456	Economy	9800.00
0005435006631	5456	Economy	9800.00
0005432125333	5456	Economy	9800.00
0005435038690	5456	Economy	9800.00
0005435038689	5456	Economy	9800.00
0005435038729	5456	Economy	9800.00
0005435006646	5456	Economy	9800.00
0005432125332	5456	Economy	9800.00
0005435038722	5456	Economy	9800.00
0005435038717	5456	Economy	9800.00
0005435006638	5456	Economy	9800.00
0005435006639	5456	Economy	9800.00
0005435006637	5456	Economy	9800.00
0005435038733	5456	Economy	9800.00
0005435006632	5456	Economy	9800.00
0005435038714	5456	Economy	9800.00
0005435038701	5456	Economy	9800.00
0005435038723	5456	Economy	9800.00
0005435038683	5456	Economy	9800.00
0005435038694	5456	Economy	9800.00
0005435038697	5456	Economy	9800.00
0005435006635	5456	Economy	9800.00
0005435038692	5456	Economy	9800.00
0005435006624	5456	Economy	9800.00
0005435038691	5456	Economy	9800.00
0005435038700	5456	Economy	9800.00
0005435038736	5456	Economy	9800.00
0005435038720	5456	Economy	9800.00
0005432125326	5456	Economy	9800.00
0005435006627	5456	Economy	9800.00
0005435038712	5456	Economy	9800.00
0005435038706	5456	Economy	9800.00
0005434228995	12969	Business	29500.00
0005434228996	12969	Business	29500.00
0005434228990	12969	Business	29500.00
0005432304334	12969	Business	29500.00
0005434229009	12969	Economy	9800.00
0005434229006	12969	Economy	9800.00
0005432304335	12969	Economy	9800.00
0005434229007	12969	Economy	9800.00
0005434228989	12969	Economy	9800.00
0005434228997	12969	Economy	9800.00
0005434228993	12969	Economy	9800.00
0005434229010	12969	Economy	9800.00
0005432304332	12969	Economy	10800.00
0005434229001	12969	Economy	9800.00
0005432304333	12969	Economy	9800.00
0005434229002	12969	Economy	9800.00
0005434228998	12969	Economy	9800.00
0005434229005	12969	Economy	9800.00
0005434229011	12969	Economy	9800.00
0005432304336	12969	Economy	9800.00
0005434228992	12969	Economy	9800.00
0005434229003	12969	Economy	9800.00
0005432304337	12969	Economy	9800.00
0005434229008	12969	Economy	9800.00
0005434229004	12969	Economy	9800.00
0005434228994	12969	Economy	9800.00
0005434228999	12969	Economy	9800.00
0005434228991	12969	Economy	9800.00
0005434229000	12969	Economy	9800.00
0005432188549	14856	Business	52900.00
0005434411704	14856	Business	52900.00
0005434426101	14856	Business	52900.00
0005434426112	14856	Business	52900.00
0005434426084	14856	Business	52900.00
0005434426093	14856	Economy	17600.00
0005434411703	14856	Economy	17600.00
0005432188550	14856	Economy	17600.00
0005434426094	14856	Economy	17600.00
0005434411701	14856	Economy	17600.00
0005434426100	14856	Economy	19400.00
0005434426095	14856	Economy	19400.00
0005434426098	14856	Economy	17600.00
0005434426089	14856	Economy	17600.00
0005434426088	14856	Economy	17600.00
0005434426087	14856	Economy	17600.00
0005434426108	14856	Economy	17600.00
0005434426103	14856	Economy	17600.00
0005434411702	14856	Economy	17600.00
0005432188553	14856	Economy	17600.00
0005434426105	14856	Economy	17600.00
0005434426104	14856	Economy	17600.00
0005434426106	14856	Economy	17600.00
0005434426109	14856	Economy	17600.00
0005432188552	14856	Economy	17600.00
0005434426091	14856	Economy	17600.00
0005434426113	14856	Economy	17600.00
0005432188551	14856	Economy	17600.00
0005434426110	14856	Economy	17600.00
0005434426085	14856	Economy	17600.00
0005434426092	14856	Economy	17600.00
0005434426090	14856	Economy	17600.00
0005434426099	14856	Economy	17600.00
0005434426107	14856	Economy	17600.00
0005434426096	14856	Economy	17600.00
0005434426111	14856	Economy	17600.00
0005434426086	14856	Economy	17600.00
0005434426097	14856	Economy	17600.00
0005434426102	14856	Economy	17600.00
0005435902410	20208	Business	52900.00
0005435902405	20208	Economy	17600.00
0005435902413	20208	Economy	17600.00
0005435902418	20208	Economy	17600.00
0005435902415	20208	Economy	19400.00
0005435902420	20208	Economy	19400.00
0005435902409	20208	Economy	17600.00
0005435554111	20208	Economy	17600.00
0005435902419	20208	Economy	17600.00
0005435902417	20208	Economy	17600.00
0005435902408	20208	Economy	17600.00
0005435902412	20208	Economy	17600.00
0005435902414	20208	Economy	17600.00
0005435554109	20208	Economy	17600.00
0005435902402	20208	Economy	17600.00
0005435902411	20208	Economy	17600.00
0005435902404	20208	Economy	17600.00
0005435902406	20208	Economy	17600.00
0005435554108	20208	Economy	17600.00
0005435902407	20208	Economy	17600.00
0005435554110	20208	Economy	17600.00
0005432059472	20208	Economy	17600.00
0005435902416	20208	Economy	17600.00
0005435554112	20208	Economy	17600.00
0005435902403	20208	Economy	17600.00
0005435981545	26528	Business	18500.00
0005435981511	26528	Business	18500.00
0005435981540	26528	Business	18500.00
0005432300163	26528	Business	18500.00
0005435981526	26528	Business	18500.00
0005435981539	26528	Business	18500.00
0005435981525	26528	Business	18500.00
0005435981513	26528	Economy	6200.00
0005435981533	26528	Economy	6200.00
0005435981543	26528	Economy	6200.00
0005435981530	26528	Economy	6200.00
0005435981529	26528	Economy	6200.00
0005435981520	26528	Economy	6200.00
0005435981509	26528	Economy	6800.00
0005435981510	26528	Economy	6800.00
0005432300161	26528	Economy	6800.00
0005435981523	26528	Economy	6800.00
0005435981538	26528	Economy	6200.00
0005435981516	26528	Economy	6200.00
0005435981517	26528	Economy	6200.00
0005435981518	26528	Economy	6200.00
0005435981512	26528	Economy	6200.00
0005435981542	26528	Economy	6200.00
0005435981528	26528	Economy	6200.00
0005435981536	26528	Economy	6200.00
0005435981524	26528	Economy	6200.00
0005435981535	26528	Economy	6200.00
0005435981508	26528	Economy	6200.00
0005432300162	26528	Economy	6200.00
0005435981514	26528	Economy	6200.00
0005435981522	26528	Economy	6200.00
0005435981519	26528	Economy	6200.00
0005435981541	26528	Economy	6200.00
0005435981515	26528	Economy	6200.00
0005435981532	26528	Economy	6200.00
0005435981546	26528	Economy	6200.00
0005435981531	26528	Economy	6200.00
0005435981527	26528	Economy	6200.00
0005432300164	26528	Economy	6200.00
0005435981534	26528	Economy	6200.00
0005435981544	26528	Economy	6200.00
0005432300165	26528	Economy	6200.00
0005435981537	26528	Economy	6200.00
0005435981521	26528	Economy	6200.00
0005435981547	26528	Economy	6200.00
0005434270173	26697	Business	18500.00
0005433434218	26697	Business	18500.00
0005433434228	26697	Business	18500.00
0005433434233	26697	Business	18500.00
0005433434231	26697	Business	18500.00
0005433434234	26697	Economy	6200.00
0005433434210	26697	Economy	6200.00
0005432051078	26697	Economy	6200.00
0005433434213	26697	Economy	6200.00
0005433434216	26697	Economy	6800.00
0005433434235	26697	Economy	6800.00
0005433434226	26697	Economy	6800.00
0005432051077	26697	Economy	6200.00
0005433434232	26697	Economy	6200.00
0005433434221	26697	Economy	6200.00
0005433434230	26697	Economy	6200.00
0005434271279	26697	Economy	6200.00
0005433434212	26697	Economy	6200.00
0005433434215	26697	Economy	6200.00
0005434270172	26697	Economy	6200.00
0005433434223	26697	Economy	6200.00
0005433434220	26697	Economy	6200.00
0005433434222	26697	Economy	6200.00
0005434271277	26697	Economy	6200.00
0005433434211	26697	Economy	6200.00
0005433434227	26697	Economy	6200.00
0005433434225	26697	Economy	6200.00
0005433434217	26697	Economy	6200.00
0005434271280	26697	Economy	6200.00
0005434271278	26697	Economy	6200.00
0005433434209	26697	Economy	6200.00
0005433434236	26697	Economy	6200.00
0005433434224	26697	Economy	6200.00
0005433434219	26697	Economy	6200.00
0005433434214	26697	Economy	6200.00
0005433434229	26697	Economy	6200.00
0005432583609	3165	Economy	11100.00
0005432583629	3165	Economy	11100.00
0005432216226	3165	Economy	11100.00
0005432583633	3165	Economy	10100.00
0005432583617	3165	Economy	10100.00
0005432583622	3165	Economy	10100.00
0005432216225	3165	Economy	10100.00
0005432583615	3165	Economy	10100.00
0005432583625	3165	Economy	10100.00
0005432583628	3165	Economy	10100.00
0005432583616	3165	Economy	10100.00
0005432583619	3165	Economy	10100.00
0005432216227	3165	Economy	10100.00
0005432583614	3165	Economy	10100.00
0005432583610	3165	Economy	10100.00
0005432583611	3165	Economy	10100.00
0005432583620	3165	Economy	10100.00
0005432583608	3165	Economy	10100.00
0005432583627	3165	Economy	10100.00
0005432583626	3165	Economy	10100.00
0005432583634	3165	Economy	10100.00
0005432583618	3165	Economy	10100.00
0005432583607	3165	Economy	10100.00
0005432583624	3165	Economy	10100.00
0005432583630	3165	Economy	10100.00
0005432583621	3165	Economy	10100.00
0005432583623	3165	Economy	10100.00
0005432583612	3165	Economy	10100.00
0005432583632	3165	Economy	10100.00
0005432583613	3165	Economy	10100.00
0005432583631	3165	Economy	10100.00
0005432857873	31474	Economy	10100.00
0005432857871	31474	Economy	10100.00
0005432857867	31474	Economy	10100.00
0005432857869	31474	Economy	10100.00
0005432857868	31474	Economy	10100.00
0005432857866	31474	Economy	10100.00
0005432857865	31474	Economy	10100.00
0005432857870	31474	Economy	10100.00
0005432857872	31474	Economy	10100.00
0005432857864	31474	Economy	10100.00
0005434943200	862	Economy	7500.00
0005434943203	862	Economy	7500.00
0005434943202	862	Economy	7500.00
0005434943199	862	Economy	7500.00
0005434943195	862	Economy	7500.00
0005434943196	862	Economy	7500.00
0005434943201	862	Economy	7500.00
0005434943198	862	Economy	7500.00
0005434943197	862	Economy	7500.00
0005433255030	16231	Economy	8300.00
0005433255028	16231	Economy	8300.00
0005433255027	16231	Economy	7500.00
0005433255026	16231	Economy	7500.00
0005433255029	16231	Economy	7500.00
0005433255031	16231	Economy	7500.00
0005435652273	21749	Business	9800.00
0005435652250	21749	Business	9800.00
0005435652277	21749	Business	9800.00
0005435652292	21749	Business	9800.00
0005435652252	21749	Business	9800.00
0005435652284	21749	Business	9800.00
0005435652258	21749	Economy	3300.00
0005435652254	21749	Economy	3300.00
0005435652260	21749	Economy	3300.00
0005435652262	21749	Economy	3300.00
0005435652279	21749	Economy	3600.00
0005435652269	21749	Economy	3300.00
0005435652257	21749	Economy	3300.00
0005435652287	21749	Economy	3300.00
0005435652281	21749	Economy	3300.00
0005435652288	21749	Economy	3300.00
0005435652296	21749	Economy	3300.00
0005435652295	21749	Economy	3300.00
0005435652264	21749	Economy	3300.00
0005435652286	21749	Economy	3300.00
0005435652263	21749	Economy	3300.00
0005435652270	21749	Economy	3300.00
0005435652268	21749	Economy	3300.00
0005435652293	21749	Economy	3300.00
0005435652271	21749	Economy	3300.00
0005435652272	21749	Economy	3300.00
0005435652255	21749	Economy	3300.00
0005435652291	21749	Economy	3300.00
0005435652290	21749	Economy	3300.00
0005435652267	21749	Economy	3300.00
0005435652274	21749	Economy	3300.00
0005435652261	21749	Economy	3300.00
0005435652275	21749	Economy	3300.00
0005435652266	21749	Economy	3300.00
0005435652294	21749	Economy	3300.00
0005435652276	21749	Economy	3300.00
0005435652282	21749	Economy	3300.00
0005435652251	21749	Economy	3300.00
0005435652256	21749	Economy	3300.00
0005435652265	21749	Economy	3300.00
0005435652253	21749	Economy	3300.00
0005435652289	21749	Economy	3300.00
0005435652280	21749	Economy	3300.00
0005435652278	21749	Economy	3300.00
0005435652283	21749	Economy	3300.00
0005435652285	21749	Economy	3300.00
0005435652259	21749	Economy	3300.00
0005433804816	9379	Business	186200.00
0005433804799	9379	Business	186200.00
0005433784351	9379	Business	186200.00
0005432657397	9379	Business	186200.00
0005433762963	9379	Business	186200.00
0005433804813	9379	Business	186200.00
0005433784365	9379	Business	186200.00
0005433784356	9379	Business	186200.00
0005433804805	9379	Business	186200.00
0005433762970	9379	Business	186200.00
0005433762957	9379	Business	186200.00
0005432665239	9379	Business	186200.00
0005433784336	9379	Business	186200.00
0005433804806	9379	Business	186200.00
0005433784331	9379	Business	186200.00
0005433762965	9379	Economy	68300.00
0005433804804	9379	Economy	62100.00
0005433804824	9379	Economy	62100.00
0005433784335	9379	Economy	62100.00
0005433804814	9379	Economy	62100.00
0005433804811	9379	Economy	62100.00
0005433762960	9379	Economy	62100.00
0005433784343	9379	Economy	62100.00
0005433804820	9379	Economy	62100.00
0005433784342	9379	Economy	62100.00
0005433784345	9379	Economy	62100.00
0005433784347	9379	Economy	62100.00
0005432657399	9379	Economy	62100.00
0005433804826	9379	Economy	62100.00
0005433784337	9379	Economy	62100.00
0005433784329	9379	Economy	62100.00
0005433784364	9379	Economy	62100.00
0005433784350	9379	Economy	62100.00
0005433804815	9379	Economy	62100.00
0005433784341	9379	Economy	62100.00
0005433762972	9379	Economy	62100.00
0005433784348	9379	Economy	62100.00
0005433762962	9379	Economy	62100.00
0005432667420	9379	Economy	62100.00
0005433804818	9379	Economy	62100.00
0005433762971	9379	Economy	62100.00
0005433784355	9379	Economy	62100.00
0005433784333	9379	Economy	62100.00
0005433804796	9379	Economy	62100.00
0005433784353	9379	Economy	62100.00
0005432667418	9379	Economy	62100.00
0005433762964	9379	Economy	62100.00
0005433804797	9379	Economy	62100.00
0005433804823	9379	Economy	62100.00
0005433804800	9379	Economy	62100.00
0005433784349	9379	Economy	62100.00
0005433804801	9379	Economy	62100.00
0005433784359	9379	Economy	62100.00
0005433762968	9379	Economy	62100.00
0005433804825	9379	Economy	62100.00
0005433784346	9379	Economy	62100.00
0005433784332	9379	Economy	62100.00
0005433804803	9379	Economy	62100.00
0005432666354	9379	Economy	62100.00
0005433784340	9379	Economy	62100.00
0005433784360	9379	Economy	68300.00
0005433804808	9379	Economy	68300.00
0005433804821	9379	Economy	62100.00
0005433804809	9379	Economy	62100.00
0005432667419	9379	Economy	68300.00
0005433804795	9379	Economy	62100.00
0005433804822	9379	Economy	62100.00
0005433804819	9379	Economy	62100.00
0005433784357	9379	Economy	62100.00
0005433804802	9379	Economy	62100.00
0005433784338	9379	Economy	62100.00
0005433784352	9379	Economy	62100.00
0005433784339	9379	Economy	62100.00
0005433804817	9379	Economy	62100.00
0005433762967	9379	Economy	62100.00
0005433784334	9379	Economy	62100.00
0005433804794	9379	Economy	62100.00
0005433804807	9379	Economy	62100.00
0005433762959	9379	Economy	62100.00
0005432665240	9379	Economy	62100.00
0005432657396	9379	Economy	62100.00
0005433804798	9379	Economy	62100.00
0005433804812	9379	Economy	62100.00
0005432657398	9379	Economy	62100.00
0005433762966	9379	Economy	62100.00
0005433784358	9379	Economy	62100.00
0005433784366	9379	Economy	62100.00
0005433784354	9379	Economy	62100.00
0005433762961	9379	Economy	62100.00
0005433784330	9379	Economy	62100.00
0005433784362	9379	Economy	62100.00
0005433784361	9379	Economy	62100.00
0005433762969	9379	Economy	62100.00
0005433762958	9379	Economy	62100.00
0005433784344	9379	Economy	62100.00
0005433804828	9379	Economy	62100.00
0005433804810	9379	Economy	62100.00
0005433784363	9379	Economy	62100.00
0005433804827	9379	Economy	62100.00
0005434170812	26245	Business	186200.00
0005434269069	26245	Business	186200.00
0005434170815	26245	Business	186200.00
0005434170824	26245	Business	186200.00
0005434170825	26245	Business	186200.00
0005435269643	26245	Business	186200.00
0005434170822	26245	Economy	62100.00
0005435269644	26245	Economy	62100.00
0005434151654	26245	Economy	62100.00
0005434170814	26245	Economy	62100.00
0005434269068	26245	Economy	62100.00
0005434170813	26245	Economy	62100.00
0005435269646	26245	Economy	62100.00
0005434170811	26245	Economy	62100.00
0005434170820	26245	Economy	62100.00
0005434269067	26245	Economy	62100.00
0005434170817	26245	Economy	62100.00
0005434170823	26245	Economy	62100.00
0005434170821	26245	Economy	62100.00
0005435269645	26245	Economy	62100.00
0005434170819	26245	Economy	62100.00
0005434170818	26245	Economy	62100.00
0005434270170	26245	Economy	62100.00
0005435269647	26245	Economy	62100.00
0005434270171	26245	Economy	62100.00
0005434151656	26245	Economy	62100.00
0005434151655	26245	Economy	62100.00
0005434271276	26245	Economy	62100.00
0005434271275	26245	Economy	62100.00
0005434170816	26245	Economy	62100.00
0005435135588	4918	Economy	5300.00
0005435135589	4918	Economy	5300.00
0005435135586	4918	Economy	5300.00
0005435135587	4918	Economy	5300.00
0005435135590	4918	Economy	5300.00
0005435929599	33053	Economy	5300.00
0005435929598	33053	Economy	5300.00
0005434983202	9492	Economy	17900.00
0005434983199	9492	Economy	17900.00
0005434983201	9492	Economy	17900.00
0005434983200	9492	Economy	17900.00
0005434983203	9492	Economy	17900.00
0005434217901	27351	Economy	17900.00
0005434217900	27351	Economy	17900.00
0005434217899	27351	Economy	17900.00
0005433959860	25957	Business	36400.00
0005433985134	25957	Business	36400.00
0005433959872	25957	Business	36400.00
0005433959896	25957	Business	36400.00
0005433959894	25957	Business	36400.00
0005433959879	25957	Business	36400.00
0005433985124	25957	Business	36400.00
0005433959878	25957	Business	36400.00
0005433959901	25957	Business	36400.00
0005433959875	25957	Business	36400.00
0005433959888	25957	Business	36400.00
0005433959903	25957	Business	36400.00
0005433985133	25957	Economy	13400.00
0005433959882	25957	Economy	13400.00
0005433985144	25957	Economy	12100.00
0005433985125	25957	Economy	12100.00
0005433985140	25957	Economy	12100.00
0005433985149	25957	Economy	12100.00
0005433959876	25957	Economy	12100.00
0005433959898	25957	Economy	12100.00
0005433959889	25957	Economy	12100.00
0005433985147	25957	Economy	12100.00
0005433959861	25957	Economy	12100.00
0005433959883	25957	Economy	12100.00
0005433959893	25957	Economy	12100.00
0005433985146	25957	Economy	12100.00
0005433985128	25957	Economy	12100.00
0005433959902	25957	Economy	12100.00
0005433985160	25957	Economy	12100.00
0005433985135	25957	Economy	12100.00
0005433959865	25957	Economy	12100.00
0005433985151	25957	Economy	12100.00
0005433985157	25957	Economy	12100.00
0005433959870	25957	Economy	12100.00
0005433985158	25957	Economy	12100.00
0005433985123	25957	Economy	12100.00
0005433959859	25957	Economy	12100.00
0005433959873	25957	Economy	12100.00
0005433959856	25957	Economy	12100.00
0005433959884	25957	Economy	12100.00
0005433985132	25957	Economy	12100.00
0005433985141	25957	Economy	12100.00
0005433985127	25957	Economy	12100.00
0005433959895	25957	Economy	12100.00
0005433985148	25957	Economy	12100.00
0005433985156	25957	Economy	12100.00
0005433959866	25957	Economy	12100.00
0005433959877	25957	Economy	12100.00
0005433985131	25957	Economy	13400.00
0005433959881	25957	Economy	12100.00
0005433959863	25957	Economy	12100.00
0005433985130	25957	Economy	12100.00
0005433985152	25957	Economy	12100.00
0005433959899	25957	Economy	12100.00
0005433985138	25957	Economy	12100.00
0005433985129	25957	Economy	12100.00
0005433959869	25957	Economy	12100.00
0005433985143	25957	Economy	12100.00
0005433959867	25957	Economy	12100.00
0005433959864	25957	Economy	12100.00
0005433959897	25957	Economy	12100.00
0005433959891	25957	Economy	12100.00
0005433985137	25957	Economy	12100.00
0005433985122	25957	Economy	12100.00
0005433985126	25957	Economy	12100.00
0005433959886	25957	Economy	12100.00
0005433959900	25957	Economy	12100.00
0005433959858	25957	Economy	12100.00
0005433959885	25957	Economy	12100.00
0005433959887	25957	Economy	12100.00
0005433959857	25957	Economy	12100.00
0005433985153	25957	Economy	12100.00
0005433959871	25957	Economy	12100.00
0005433959862	25957	Economy	12100.00
0005433959890	25957	Economy	12100.00
0005433985142	25957	Economy	12100.00
0005433959892	25957	Economy	12100.00
0005433985154	25957	Economy	12100.00
0005433985159	25957	Economy	12100.00
0005433959868	25957	Economy	12100.00
0005433959880	25957	Economy	12100.00
0005433985139	25957	Economy	12100.00
0005433959874	25957	Economy	12100.00
0005433985136	25957	Economy	12100.00
0005433985155	25957	Economy	12100.00
0005433985145	25957	Economy	12100.00
0005433985161	25957	Economy	12100.00
0005433985150	25957	Economy	12100.00
0005434479917	948	Economy	25400.00
0005432269448	948	Economy	25400.00
0005434479923	948	Economy	23100.00
0005434479907	948	Economy	23100.00
0005434479904	948	Economy	23100.00
0005434479913	948	Economy	23100.00
0005434479924	948	Economy	23100.00
0005434479915	948	Economy	23100.00
0005434479910	948	Economy	23100.00
0005434479919	948	Economy	23100.00
0005434479906	948	Economy	23100.00
0005434479912	948	Economy	23100.00
0005434479925	948	Economy	23100.00
0005434479911	948	Economy	23100.00
0005432269449	948	Economy	23100.00
0005434479914	948	Economy	23100.00
0005432269450	948	Economy	23100.00
0005434479920	948	Economy	23100.00
0005434479905	948	Economy	23100.00
0005434479922	948	Economy	23100.00
0005434479909	948	Economy	23100.00
0005434479908	948	Economy	23100.00
0005434479921	948	Economy	23100.00
0005434479918	948	Economy	23100.00
0005434479916	948	Economy	23100.00
0005433165693	16566	Economy	25400.00
0005433165694	16566	Economy	23100.00
0005433165689	16566	Economy	23100.00
0005433165692	16566	Economy	23100.00
0005433165688	16566	Economy	23100.00
0005433165686	16566	Economy	23100.00
0005433165684	16566	Economy	23100.00
0005433165687	16566	Economy	23100.00
0005433165691	16566	Economy	23100.00
0005433165690	16566	Economy	23100.00
0005433165685	16566	Economy	23100.00
0005435149796	10341	Economy	17000.00
0005435142340	10341	Economy	17000.00
0005435149797	10341	Economy	17000.00
0005435149788	10341	Economy	15400.00
0005435142342	10341	Economy	15400.00
0005435149792	10341	Economy	15400.00
0005435149790	10341	Economy	15400.00
0005435142345	10341	Economy	15400.00
0005435142343	10341	Economy	15400.00
0005435149789	10341	Economy	15400.00
0005435149795	10341	Economy	15400.00
0005435149787	10341	Economy	15400.00
0005435149791	10341	Economy	15400.00
0005435142337	10341	Economy	15400.00
0005435142341	10341	Economy	15400.00
0005435142348	10341	Economy	15400.00
0005435142339	10341	Economy	15400.00
0005435149785	10341	Economy	15400.00
0005435142338	10341	Economy	15400.00
0005435142346	10341	Economy	15400.00
0005435149794	10341	Economy	15400.00
0005435142347	10341	Economy	15400.00
0005435142335	10341	Economy	15400.00
0005435142344	10341	Economy	15400.00
0005435149786	10341	Economy	15400.00
0005435149793	10341	Economy	15400.00
0005435142336	10341	Economy	15400.00
0005435386463	21929	Economy	15400.00
0005433289733	21929	Economy	15400.00
0005435386461	21929	Economy	15400.00
0005433289731	21929	Economy	15400.00
0005435386464	21929	Economy	15400.00
0005433289738	21929	Economy	15400.00
0005433289734	21929	Economy	15400.00
0005433289735	21929	Economy	15400.00
0005433289736	21929	Economy	15400.00
0005433289737	21929	Economy	15400.00
0005435386460	21929	Economy	15400.00
0005435386462	21929	Economy	15400.00
0005433289732	21929	Economy	15400.00
0005435386459	21929	Economy	15400.00
0005435386458	21929	Economy	15400.00
0005434573108	11232	Business	57200.00
0005434573104	11232	Economy	21000.00
0005434573109	11232	Economy	19100.00
0005434573111	11232	Economy	19100.00
0005434573113	11232	Economy	19100.00
0005434573105	11232	Economy	19100.00
0005434573107	11232	Economy	19100.00
0005434573112	11232	Economy	19100.00
0005434573110	11232	Economy	19100.00
0005434573115	11232	Economy	19100.00
0005434573102	11232	Economy	19100.00
0005434573106	11232	Economy	19100.00
0005434573101	11232	Economy	19100.00
0005434573114	11232	Economy	19100.00
0005434573103	11232	Economy	19100.00
0005435319436	20961	Business	57200.00
0005435501940	20961	Business	57200.00
0005435517588	20961	Business	57200.00
0005435517599	20961	Business	57200.00
0005435501944	20961	Business	57200.00
0005435501933	20961	Business	57200.00
0005435508176	20961	Business	57200.00
0005435501936	20961	Business	57200.00
0005435501934	20961	Business	57200.00
0005435501952	20961	Economy	19100.00
0005435501939	20961	Economy	19100.00
0005435319438	20961	Economy	19100.00
0005435508175	20961	Economy	19100.00
0005435508170	20961	Economy	19100.00
0005435501951	20961	Economy	19100.00
0005435517606	20961	Economy	19100.00
0005435517585	20961	Economy	21000.00
0005435517596	20961	Economy	21000.00
0005435501931	20961	Economy	21000.00
0005435517592	20961	Economy	21000.00
0005435319439	20961	Economy	19100.00
0005435319432	20961	Economy	19100.00
0005435517603	20961	Economy	19100.00
0005435517605	20961	Economy	19100.00
0005435501938	20961	Economy	19100.00
0005435517594	20961	Economy	19100.00
0005435508164	20961	Economy	19100.00
0005435508168	20961	Economy	19100.00
0005435517591	20961	Economy	19100.00
0005435517587	20961	Economy	19100.00
0005435501949	20961	Economy	19100.00
0005435517604	20961	Economy	19100.00
0005432291890	20961	Economy	19100.00
0005435319434	20961	Economy	19100.00
0005435508172	20961	Economy	19100.00
0005435501942	20961	Economy	19100.00
0005435319435	20961	Economy	19100.00
0005435319440	20961	Economy	19100.00
0005435517602	20961	Economy	19100.00
0005435508169	20961	Economy	19100.00
0005435501937	20961	Economy	19100.00
0005435517598	20961	Economy	19100.00
0005435508174	20961	Economy	19100.00
0005435508165	20961	Economy	19100.00
0005435508173	20961	Economy	19100.00
0005435501941	20961	Economy	19100.00
0005435517590	20961	Economy	19100.00
0005435508171	20961	Economy	19100.00
0005432291889	20961	Economy	19100.00
0005435517597	20961	Economy	19100.00
0005435501945	20961	Economy	19100.00
0005435508166	20961	Economy	19100.00
0005435517595	20961	Economy	19100.00
0005435319433	20961	Economy	19100.00
0005435501943	20961	Economy	19100.00
0005435319437	20961	Economy	19100.00
0005435508167	20961	Economy	19100.00
0005435501935	20961	Economy	19100.00
0005435501932	20961	Economy	19100.00
0005435501948	20961	Economy	19100.00
0005435517593	20961	Economy	19100.00
0005435501946	20961	Economy	19100.00
0005435501950	20961	Economy	19100.00
0005435501947	20961	Economy	19100.00
0005435517589	20961	Economy	19100.00
0005435517586	20961	Economy	19100.00
0005435517600	20961	Economy	19100.00
0005435517601	20961	Economy	19100.00
0005432706358	2911	Business	10300.00
0005432706350	2911	Business	10300.00
0005432217727	2911	Business	10300.00
0005432706354	2911	Business	10300.00
0005432706348	2911	Business	10300.00
0005432706345	2911	Business	10300.00
0005432706335	2911	Economy	3400.00
0005432706352	2911	Economy	3400.00
0005432706351	2911	Economy	3400.00
0005432706349	2911	Economy	3800.00
0005432706333	2911	Economy	3800.00
0005432706357	2911	Economy	3400.00
0005432706346	2911	Economy	3400.00
0005432217729	2911	Economy	3400.00
0005432706339	2911	Economy	3400.00
0005432706338	2911	Economy	3400.00
0005432706355	2911	Economy	3400.00
0005432706359	2911	Economy	3400.00
0005432706353	2911	Economy	3400.00
0005432706337	2911	Economy	3400.00
0005432217728	2911	Economy	3400.00
0005432706334	2911	Economy	3400.00
0005432706342	2911	Economy	3400.00
0005432706340	2911	Economy	3400.00
0005432706343	2911	Economy	3400.00
0005432217730	2911	Economy	3400.00
0005432706347	2911	Economy	3400.00
0005432706336	2911	Economy	3400.00
0005432706356	2911	Economy	3400.00
0005432706344	2911	Economy	3400.00
0005432706341	2911	Economy	3400.00
0005432692577	29980	Business	10300.00
0005432692573	29980	Business	10300.00
0005432692588	29980	Business	10300.00
0005433123575	29980	Business	10300.00
0005432880573	29980	Business	10300.00
0005433123573	29980	Business	10300.00
0005433123567	29980	Business	10300.00
0005433123586	29980	Business	10300.00
0005433123584	29980	Business	10300.00
0005432880576	29980	Business	10300.00
0005433123572	29980	Business	10300.00
0005433194819	29980	Business	10300.00
0005432692565	29980	Economy	3400.00
0005433123583	29980	Economy	3400.00
0005432692589	29980	Economy	3400.00
0005432880569	29980	Economy	3400.00
0005432692581	29980	Economy	3400.00
0005432692587	29980	Economy	3400.00
0005433123581	29980	Economy	3400.00
0005432880577	29980	Economy	3400.00
0005432692568	29980	Economy	3400.00
0005432692585	29980	Economy	3800.00
0005433123582	29980	Economy	3800.00
0005432692582	29980	Economy	3800.00
0005433123569	29980	Economy	3800.00
0005432692562	29980	Economy	3400.00
0005432692576	29980	Economy	3400.00
0005432692574	29980	Economy	3400.00
0005433123565	29980	Economy	3400.00
0005432880578	29980	Economy	3400.00
0005432692563	29980	Economy	3400.00
0005433123574	29980	Economy	3400.00
0005433123585	29980	Economy	3400.00
0005432880579	29980	Economy	3400.00
0005432692578	29980	Economy	3400.00
0005432880572	29980	Economy	3400.00
0005433123566	29980	Economy	3400.00
0005432880567	29980	Economy	3400.00
0005432692561	29980	Economy	3400.00
0005432692569	29980	Economy	3400.00
0005432692566	29980	Economy	3400.00
0005432880580	29980	Economy	3400.00
0005432692571	29980	Economy	3400.00
0005432692579	29980	Economy	3400.00
0005432692567	29980	Economy	3400.00
0005433123587	29980	Economy	3400.00
0005432692580	29980	Economy	3400.00
0005432692572	29980	Economy	3400.00
0005433123568	29980	Economy	3400.00
0005432692570	29980	Economy	3400.00
0005432692559	29980	Economy	3400.00
0005432692560	29980	Economy	3400.00
0005432880568	29980	Economy	3400.00
0005432880570	29980	Economy	3400.00
0005433194817	29980	Economy	3400.00
0005432692584	29980	Economy	3400.00
0005433123571	29980	Economy	3400.00
0005432692564	29980	Economy	3400.00
0005432880574	29980	Economy	3400.00
0005432692586	29980	Economy	3400.00
0005433123579	29980	Economy	3400.00
0005433123570	29980	Economy	3400.00
0005433123578	29980	Economy	3400.00
0005432880571	29980	Economy	3400.00
0005433123577	29980	Economy	3400.00
0005432880566	29980	Economy	3400.00
0005433123576	29980	Economy	3400.00
0005433194818	29980	Economy	3400.00
0005433123580	29980	Economy	3400.00
0005432692575	29980	Economy	3400.00
0005432880575	29980	Economy	3400.00
0005432692583	29980	Economy	3400.00
0005434979265	23701	Economy	4000.00
0005434979258	23701	Economy	4000.00
0005434979278	23701	Economy	4000.00
0005434979272	23701	Economy	4000.00
0005434979254	23701	Economy	3600.00
0005434988557	23701	Economy	3600.00
0005434988561	23701	Economy	3600.00
0005434979269	23701	Economy	3600.00
0005434979275	23701	Economy	3600.00
0005434979260	23701	Economy	3600.00
0005434979276	23701	Economy	3600.00
0005434979263	23701	Economy	3600.00
0005434979252	23701	Economy	3600.00
0005434979271	23701	Economy	3600.00
0005434988562	23701	Economy	3600.00
0005434979273	23701	Economy	3600.00
0005434979277	23701	Economy	3600.00
0005434979255	23701	Economy	3600.00
0005434979262	23701	Economy	3600.00
0005434979268	23701	Economy	3600.00
0005434979267	23701	Economy	3600.00
0005434979261	23701	Economy	3600.00
0005434979259	23701	Economy	3600.00
0005434979264	23701	Economy	3600.00
0005434979281	23701	Economy	3600.00
0005434979266	23701	Economy	3600.00
0005434988558	23701	Economy	3600.00
0005434988560	23701	Economy	3600.00
0005434979279	23701	Economy	3600.00
0005434988559	23701	Economy	3600.00
0005434979282	23701	Economy	3600.00
0005434979253	23701	Economy	3600.00
0005434979280	23701	Economy	3600.00
0005434988555	23701	Economy	3600.00
0005434988564	23701	Economy	3600.00
0005434979270	23701	Economy	3600.00
0005434979257	23701	Economy	3600.00
0005434988563	23701	Economy	3600.00
0005434979256	23701	Economy	3600.00
0005434979274	23701	Economy	3600.00
0005434988556	23701	Economy	3600.00
0005434302383	10258	Economy	19700.00
0005434302385	10258	Economy	19700.00
0005434302382	10258	Economy	19700.00
0005434302381	10258	Economy	19700.00
0005434302384	10258	Economy	19700.00
0005434302853	10258	Economy	19700.00
0005433113499	19645	Economy	19700.00
0005433113497	19645	Economy	19700.00
0005433113498	19645	Economy	19700.00
0005435718834	3553	Business	26900.00
0005435068246	3553	Business	26900.00
0005435068211	3553	Business	26900.00
0005435068238	3553	Business	26900.00
0005435068230	3553	Business	26900.00
0005435068257	3553	Business	26900.00
0005435068237	3553	Business	26900.00
0005435068227	3553	Economy	9000.00
0005435068243	3553	Economy	9000.00
0005435068217	3553	Economy	9000.00
0005435068254	3553	Economy	9000.00
0005435068260	3553	Economy	9000.00
0005435068253	3553	Economy	9000.00
0005435068213	3553	Economy	9000.00
0005435068256	3553	Economy	9000.00
0005435068241	3553	Economy	9900.00
0005435068255	3553	Economy	9900.00
0005435068226	3553	Economy	9900.00
0005435068249	3553	Economy	9900.00
0005435068236	3553	Economy	9000.00
0005435068247	3553	Economy	9000.00
0005435068263	3553	Economy	9000.00
0005435068261	3553	Economy	9000.00
0005435068242	3553	Economy	9000.00
0005435068239	3553	Economy	9000.00
0005435718836	3553	Economy	9000.00
0005435068234	3553	Economy	9000.00
0005435068225	3553	Economy	9000.00
0005435068233	3553	Economy	9000.00
0005435068248	3553	Economy	9000.00
0005435068252	3553	Economy	9000.00
0005435068212	3553	Economy	9000.00
0005435718832	3553	Economy	9000.00
0005435068258	3553	Economy	9000.00
0005435068216	3553	Economy	9000.00
0005435068222	3553	Economy	9000.00
0005435068259	3553	Economy	9000.00
0005435068229	3553	Economy	9000.00
0005435068240	3553	Economy	9000.00
0005435068262	3553	Economy	9000.00
0005435068232	3553	Economy	9000.00
0005435718835	3553	Economy	9000.00
0005435718837	3553	Economy	9000.00
0005435068220	3553	Economy	9000.00
0005435068219	3553	Economy	9000.00
0005435068218	3553	Economy	9000.00
0005435718833	3553	Economy	9000.00
0005435068231	3553	Economy	9000.00
0005435068221	3553	Economy	9000.00
0005435068224	3553	Economy	9000.00
0005435068250	3553	Economy	9000.00
0005435068223	3553	Economy	9000.00
0005435068244	3553	Economy	9000.00
0005435068245	3553	Economy	9000.00
0005435068251	3553	Economy	9000.00
0005435068235	3553	Economy	9000.00
0005435068215	3553	Economy	9000.00
0005435068214	3553	Economy	9000.00
0005435068228	3553	Economy	9000.00
0005435925063	15276	Business	26900.00
0005435925071	15276	Business	26900.00
0005435939858	15276	Business	26900.00
0005435925072	15276	Business	26900.00
0005435925074	15276	Economy	9000.00
0005435925068	15276	Economy	9000.00
0005435925067	15276	Economy	9000.00
0005435925066	15276	Economy	9900.00
0005435925065	15276	Economy	9000.00
0005435925061	15276	Economy	9000.00
0005435925077	15276	Economy	9000.00
0005435925073	15276	Economy	9000.00
0005435939857	15276	Economy	9000.00
0005435925069	15276	Economy	9000.00
0005435925076	15276	Economy	9000.00
0005435925075	15276	Economy	9000.00
0005435925064	15276	Economy	9000.00
0005435925062	15276	Economy	9000.00
0005435925070	15276	Economy	9000.00
0005432658556	18221	Economy	5900.00
0005432659671	18221	Economy	5900.00
0005432658555	18221	Economy	5900.00
0005432658557	18221	Economy	5900.00
0005432659672	18221	Economy	5900.00
0005432157459	88	Business	20000.00
0005432157460	88	Economy	6700.00
0005432261160	87	Business	20000.00
0005432261145	87	Business	20000.00
0005432816986	87	Business	20000.00
0005432261155	87	Business	20000.00
0005432816977	87	Business	20000.00
0005432261149	87	Business	20000.00
0005432261159	87	Business	20000.00
0005432816973	87	Business	20000.00
0005432816983	87	Business	20000.00
0005432261171	87	Economy	7300.00
0005432261152	87	Economy	7300.00
0005432816994	87	Economy	7300.00
0005432816967	87	Economy	6700.00
0005432261144	87	Economy	6700.00
0005432261139	87	Economy	6700.00
0005432816995	87	Economy	6700.00
0005432261174	87	Economy	6700.00
0005432816992	87	Economy	6700.00
0005432261150	87	Economy	6700.00
0005432261161	87	Economy	6700.00
0005432261156	87	Economy	6700.00
0005432261169	87	Economy	6700.00
0005432816978	87	Economy	6700.00
0005432261140	87	Economy	6700.00
0005432261180	87	Economy	6700.00
0005432816970	87	Economy	6700.00
0005432816981	87	Economy	6700.00
0005432261162	87	Economy	6700.00
0005432261142	87	Economy	6700.00
0005432207618	87	Economy	6700.00
0005432816969	87	Economy	6700.00
0005432261172	87	Economy	6700.00
0005432261138	87	Economy	6700.00
0005432261143	87	Economy	6700.00
0005432261148	87	Economy	6700.00
0005432261158	87	Economy	6700.00
0005432816979	87	Economy	6700.00
0005432288932	87	Economy	6700.00
0005432261165	87	Economy	6700.00
0005432261136	87	Economy	6700.00
0005432261146	87	Economy	6700.00
0005432288933	87	Economy	6700.00
0005432261173	87	Economy	7300.00
0005432816980	87	Economy	7300.00
0005432288930	87	Economy	7300.00
0005432816974	87	Economy	6700.00
0005432261137	87	Economy	6700.00
0005432261178	87	Economy	6700.00
0005432207616	87	Economy	6700.00
0005432261151	87	Economy	6700.00
0005432261176	87	Economy	6700.00
0005432261170	87	Economy	6700.00
0005432261166	87	Economy	6700.00
0005432261179	87	Economy	6700.00
0005432261153	87	Economy	6700.00
0005432816984	87	Economy	6700.00
0005432816993	87	Economy	6700.00
0005432288931	87	Economy	6700.00
0005432816997	87	Economy	6700.00
0005432816985	87	Economy	6700.00
0005432816990	87	Economy	6700.00
0005432816989	87	Economy	6700.00
0005432261147	87	Economy	6700.00
0005432261163	87	Economy	6700.00
0005432816976	87	Economy	6700.00
0005432816988	87	Economy	6700.00
0005432816975	87	Economy	6700.00
0005432261177	87	Economy	6700.00
0005432261134	87	Economy	6700.00
0005432261141	87	Economy	6700.00
0005432261164	87	Economy	6700.00
0005432261154	87	Economy	6700.00
0005432261167	87	Economy	6700.00
0005432816968	87	Economy	6700.00
0005432816971	87	Economy	6700.00
0005432261168	87	Economy	6700.00
0005432816991	87	Economy	6700.00
0005432816982	87	Economy	6700.00
0005432261157	87	Economy	6700.00
0005432261175	87	Economy	6700.00
0005432816972	87	Economy	6700.00
0005432816987	87	Economy	6700.00
0005432207617	87	Economy	6700.00
0005432816996	87	Economy	6700.00
0005432261135	87	Economy	6700.00
0005433101258	7947	Business	20000.00
0005433101272	7947	Business	20000.00
0005432019812	7947	Business	20000.00
0005432919516	7947	Business	20000.00
0005432019817	7947	Business	20000.00
0005432019818	7947	Business	20000.00
0005432019805	7947	Business	20000.00
0005432045583	7947	Business	20000.00
0005433101270	7947	Business	20000.00
0005432677510	7947	Business	20000.00
0005432391951	7947	Business	20000.00
0005433101269	7947	Business	20000.00
0005432019823	7947	Business	20000.00
0005432919506	7947	Business	20000.00
0005432019813	7947	Business	20000.00
0005433101271	7947	Business	20000.00
0005432019814	7947	Business	20000.00
0005433101231	7947	Business	20000.00
0005432019832	7947	Business	20000.00
0005432919512	7947	Business	20000.00
0005432919503	7947	Business	20000.00
0005432751473	7947	Economy	7300.00
0005432919515	7947	Economy	7300.00
0005432019821	7947	Economy	7300.00
0005432919517	7947	Economy	7300.00
0005432019808	7947	Economy	7300.00
0005433101266	7947	Economy	7300.00
0005432919521	7947	Economy	6700.00
0005433101226	7947	Economy	6700.00
0005433101267	7947	Economy	6700.00
0005433101263	7947	Economy	6700.00
0005432019816	7947	Economy	6700.00
0005432019820	7947	Economy	6700.00
0005432919504	7947	Economy	6700.00
0005432019815	7947	Economy	6700.00
0005433101251	7947	Economy	6700.00
0005432751472	7947	Economy	6700.00
0005432753245	7947	Economy	6700.00
0005433101223	7947	Economy	6700.00
0005432391948	7947	Economy	6700.00
0005432677507	7947	Economy	6700.00
0005432919510	7947	Economy	6700.00
0005432919511	7947	Economy	6700.00
0005433101224	7947	Economy	6700.00
0005433101248	7947	Economy	6700.00
0005432019826	7947	Economy	6700.00
0005433101250	7947	Economy	6700.00
0005433101232	7947	Economy	6700.00
0005433101221	7947	Economy	6700.00
0005432019809	7947	Economy	6700.00
0005432753246	7947	Economy	6700.00
0005433101245	7947	Economy	6700.00
0005432019830	7947	Economy	6700.00
0005433101261	7947	Economy	6700.00
0005433101275	7947	Economy	6700.00
0005432919524	7947	Economy	6700.00
0005432044479	7947	Economy	6700.00
0005433101257	7947	Economy	6700.00
0005433101288	7947	Economy	6700.00
0005433101241	7947	Economy	6700.00
0005432019831	7947	Economy	6700.00
0005433101228	7947	Economy	6700.00
0005433101289	7947	Economy	6700.00
0005432919519	7947	Economy	6700.00
0005432919522	7947	Economy	6700.00
0005433101239	7947	Economy	6700.00
0005433101265	7947	Economy	6700.00
0005432919507	7947	Economy	6700.00
0005432019810	7947	Economy	6700.00
0005433101235	7947	Economy	6700.00
0005433101276	7947	Economy	6700.00
0005433101278	7947	Economy	6700.00
0005433101290	7947	Economy	6700.00
0005433101268	7947	Economy	6700.00
0005433101246	7947	Economy	7300.00
0005432019828	7947	Economy	7300.00
0005432919505	7947	Economy	7300.00
0005433101233	7947	Economy	7300.00
0005432019829	7947	Economy	6700.00
0005433101252	7947	Economy	6700.00
0005432919520	7947	Economy	6700.00
0005432019827	7947	Economy	7300.00
0005432019825	7947	Economy	6700.00
0005433101225	7947	Economy	6700.00
0005433101264	7947	Economy	6700.00
0005433101259	7947	Economy	6700.00
0005433101277	7947	Economy	6700.00
0005433101255	7947	Economy	6700.00
0005433101236	7947	Economy	6700.00
0005433101243	7947	Economy	6700.00
0005433101229	7947	Economy	6700.00
0005433101234	7947	Economy	6700.00
0005432919508	7947	Economy	6700.00
0005433101279	7947	Economy	6700.00
0005433101247	7947	Economy	6700.00
0005433101254	7947	Economy	6700.00
0005432919514	7947	Economy	6700.00
0005433101262	7947	Economy	6700.00
0005433101283	7947	Economy	6700.00
0005433101286	7947	Economy	6700.00
0005432391950	7947	Economy	6700.00
0005433101230	7947	Economy	6700.00
0005432919513	7947	Economy	6700.00
0005432044480	7947	Economy	6700.00
0005432019807	7947	Economy	6700.00
0005432019819	7947	Economy	6700.00
0005433101237	7947	Economy	6700.00
0005433101260	7947	Economy	6700.00
0005432751470	7947	Economy	6700.00
0005432019806	7947	Economy	6700.00
0005433101242	7947	Economy	6700.00
0005432919523	7947	Economy	6700.00
0005432019822	7947	Economy	6700.00
0005433101273	7947	Economy	6700.00
0005432677508	7947	Economy	6700.00
0005433101284	7947	Economy	6700.00
0005433101240	7947	Economy	6700.00
0005432045582	7947	Economy	6700.00
0005433101249	7947	Economy	6700.00
0005432019824	7947	Economy	6700.00
0005433101281	7947	Economy	6700.00
0005433101222	7947	Economy	6700.00
0005432919518	7947	Economy	6700.00
0005433101282	7947	Economy	6700.00
0005433101227	7947	Economy	6700.00
0005433101256	7947	Economy	6700.00
0005433101285	7947	Economy	6700.00
0005432677509	7947	Economy	6700.00
0005433101274	7947	Economy	6700.00
0005433101253	7947	Economy	6700.00
0005432751471	7947	Economy	6700.00
0005433101280	7947	Economy	6700.00
0005433101244	7947	Economy	6700.00
0005433101238	7947	Economy	6700.00
0005432044478	7947	Economy	6700.00
0005432753247	7947	Economy	6700.00
0005432919509	7947	Economy	6700.00
0005432019811	7947	Economy	6700.00
0005432391949	7947	Economy	6700.00
0005433101287	7947	Economy	6700.00
0005432901316	7945	Business	20000.00
0005432901313	7945	Business	20000.00
0005432901315	7945	Business	20000.00
0005432901327	7945	Business	20000.00
0005432901322	7945	Economy	6700.00
0005432901318	7945	Economy	6700.00
0005432901325	7945	Economy	6700.00
0005432901324	7945	Economy	6700.00
0005432901319	7945	Economy	6700.00
0005432002043	7945	Economy	6700.00
0005432901326	7945	Economy	6700.00
0005432901323	7945	Economy	6700.00
0005432901320	7945	Economy	6700.00
0005432901317	7945	Economy	6700.00
0005432901328	7945	Economy	6700.00
0005432901314	7945	Economy	6700.00
0005432901312	7945	Economy	6700.00
0005432002042	7945	Economy	6700.00
0005432901321	7945	Economy	6700.00
0005433870693	9651	Economy	6900.00
0005433870695	9651	Economy	6900.00
0005433870694	9651	Economy	6900.00
0005434175685	32328	Economy	6900.00
0005434175686	32328	Economy	6900.00
0005434175684	32328	Economy	6900.00
0005434175683	32328	Economy	6900.00
0005434876740	3475	Business	35000.00
0005434876652	3475	Business	35000.00
0005432799001	3475	Business	35000.00
0005434876748	3475	Business	35000.00
0005434876653	3475	Business	35000.00
0005432798997	3475	Business	35000.00
0005435625896	3475	Business	35000.00
0005432188554	3475	Business	35000.00
0005434876703	3475	Business	35000.00
0005435625882	3475	Business	35000.00
0005435125726	3475	Business	35000.00
0005434876718	3475	Business	35000.00
0005434876694	3475	Business	35000.00
0005432188555	3475	Business	35000.00
0005434876689	3475	Business	35000.00
0005434876717	3475	Business	35000.00
0005435625883	3475	Business	35000.00
0005434426138	3475	Business	35000.00
0005434876700	3475	Business	35000.00
0005434876677	3475	Business	35000.00
0005435125699	3475	Comfort	19900.00
0005434876709	3475	Comfort	19900.00
0005434876666	3475	Comfort	19900.00
0005434876656	3475	Comfort	19900.00
0005435625888	3475	Comfort	19900.00
0005434876707	3475	Comfort	19900.00
0005435125708	3475	Comfort	19900.00
0005434876672	3475	Comfort	19900.00
0005435125719	3475	Comfort	19900.00
0005432798994	3475	Comfort	19900.00
0005435125725	3475	Comfort	19900.00
0005434426118	3475	Comfort	19900.00
0005434876714	3475	Comfort	19900.00
0005435125722	3475	Comfort	19900.00
0005435125712	3475	Comfort	19900.00
0005434876669	3475	Comfort	19900.00
0005432798996	3475	Comfort	19900.00
0005434937812	3475	Comfort	19900.00
0005434876711	3475	Comfort	19900.00
0005434876741	3475	Comfort	19900.00
0005434937831	3475	Comfort	19900.00
0005434876723	3475	Comfort	19900.00
0005434426131	3475	Comfort	19900.00
0005435125695	3475	Comfort	19900.00
0005435125717	3475	Comfort	19900.00
0005434426125	3475	Comfort	19900.00
0005434876729	3475	Comfort	19900.00
0005435125704	3475	Economy	11700.00
0005432798992	3475	Comfort	19900.00
0005432798987	3475	Economy	11700.00
0005435625889	3475	Economy	11700.00
0005432799006	3475	Economy	11700.00
0005434937816	3475	Economy	11700.00
0005435625884	3475	Economy	11700.00
0005434876708	3475	Economy	11700.00
0005435125689	3475	Economy	11700.00
0005435125718	3475	Economy	11700.00
0005435125705	3475	Economy	11700.00
0005434937820	3475	Economy	11700.00
0005435625897	3475	Economy	11700.00
0005434876678	3475	Economy	11700.00
0005434876692	3475	Economy	11700.00
0005434876673	3475	Economy	11700.00
0005432611644	3475	Economy	11700.00
0005434937823	3475	Economy	11700.00
0005435125706	3475	Economy	11700.00
0005434937832	3475	Economy	11700.00
0005435125690	3475	Economy	11700.00
0005434937814	3475	Economy	11700.00
0005435125693	3475	Economy	11700.00
0005432611642	3475	Economy	11700.00
0005434426119	3475	Economy	11700.00
0005432798983	3475	Economy	11700.00
0005435125697	3475	Economy	11700.00
0005432798998	3475	Economy	11700.00
0005432611645	3475	Economy	11700.00
0005434876697	3475	Economy	11700.00
0005434426139	3475	Economy	11700.00
0005434876663	3475	Economy	11700.00
0005434937827	3475	Economy	11700.00
0005434426134	3475	Economy	11700.00
0005435625899	3475	Economy	11700.00
0005434876695	3475	Economy	11700.00
0005434426116	3475	Economy	11700.00
0005434876690	3475	Economy	11700.00
0005434876747	3475	Economy	11700.00
0005434876686	3475	Economy	11700.00
0005432799008	3475	Economy	11700.00
0005434876712	3475	Economy	11700.00
0005434876710	3475	Economy	11700.00
0005434876661	3475	Economy	12800.00
0005434876684	3475	Economy	11700.00
0005435125721	3475	Economy	11700.00
0005434876664	3475	Economy	11700.00
0005435125720	3475	Economy	11700.00
0005434937819	3475	Economy	12800.00
0005434876667	3475	Economy	11700.00
0005434426145	3475	Economy	12800.00
0005434876745	3475	Economy	11700.00
0005434426126	3475	Economy	11700.00
0005434876683	3475	Economy	11700.00
0005432799009	3475	Economy	11700.00
0005434876682	3475	Economy	11700.00
0005434876670	3475	Economy	11700.00
0005432798984	3475	Economy	11700.00
0005435125716	3475	Economy	11700.00
0005434876706	3475	Economy	11700.00
0005434876658	3475	Economy	11700.00
0005434876738	3475	Economy	11700.00
0005434937821	3475	Economy	11700.00
0005435125698	3475	Economy	11700.00
0005435625891	3475	Economy	11700.00
0005434876662	3475	Economy	11700.00
0005434426114	3475	Economy	11700.00
0005432799000	3475	Economy	11700.00
0005432798989	3475	Economy	11700.00
0005435125700	3475	Economy	11700.00
0005434876659	3475	Economy	11700.00
0005432798995	3475	Economy	11700.00
0005434426136	3475	Economy	11700.00
0005434876715	3475	Economy	11700.00
0005435625880	3475	Economy	11700.00
0005432799004	3475	Economy	11700.00
0005434876732	3475	Economy	11700.00
0005432799003	3475	Economy	11700.00
0005434876726	3475	Economy	11700.00
0005435125701	3475	Economy	11700.00
0005434426127	3475	Economy	11700.00
0005434876674	3475	Economy	11700.00
0005435125727	3475	Economy	11700.00
0005434937830	3475	Economy	11700.00
0005432613795	3475	Economy	11700.00
0005432613796	3475	Economy	11700.00
0005434426142	3475	Economy	11700.00
0005432799005	3475	Economy	11700.00
0005435625892	3475	Economy	11700.00
0005434876693	3475	Economy	11700.00
0005434876687	3475	Economy	11700.00
0005434426122	3475	Economy	11700.00
0005435625887	3475	Economy	11700.00
0005434876701	3475	Economy	11700.00
0005434876688	3475	Economy	11700.00
0005432798993	3475	Economy	11700.00
0005434876722	3475	Economy	11700.00
0005434876660	3475	Economy	11700.00
0005434876736	3475	Economy	11700.00
0005435125715	3475	Economy	11700.00
0005435625894	3475	Economy	11700.00
0005434876728	3475	Economy	11700.00
0005434426143	3475	Economy	11700.00
0005434876685	3475	Economy	11700.00
0005435125714	3475	Economy	11700.00
0005432798988	3475	Economy	11700.00
0005435125692	3475	Economy	11700.00
0005435125728	3475	Economy	11700.00
0005434426123	3475	Economy	11700.00
0005434876655	3475	Economy	11700.00
0005435625895	3475	Economy	11700.00
0005432613793	3475	Economy	11700.00
0005434937825	3475	Economy	11700.00
0005435625885	3475	Economy	11700.00
0005434426144	3475	Economy	11700.00
0005435125694	3475	Economy	11700.00
0005434876716	3475	Economy	11700.00
0005435125729	3475	Economy	11700.00
0005434876665	3475	Economy	11700.00
0005434876705	3475	Economy	11700.00
0005432183431	3475	Economy	11700.00
0005435125707	3475	Economy	11700.00
0005435125691	3475	Economy	11700.00
0005434876691	3475	Economy	11700.00
0005432798990	3475	Economy	11700.00
0005432798999	3475	Economy	11700.00
0005434937813	3475	Economy	11700.00
0005434937826	3475	Economy	11700.00
0005434426132	3475	Economy	12800.00
0005434426137	3475	Economy	12800.00
0005432798991	3475	Economy	12800.00
0005434876679	3475	Economy	12800.00
0005434876676	3475	Economy	11700.00
0005434876731	3475	Economy	11700.00
0005434876720	3475	Economy	11700.00
0005435625890	3475	Economy	11700.00
0005434426130	3475	Economy	11700.00
0005434426128	3475	Economy	11700.00
0005434876698	3475	Economy	11700.00
0005435625886	3475	Economy	11700.00
0005434426129	3475	Economy	11700.00
0005432799002	3475	Economy	11700.00
0005435125702	3475	Economy	11700.00
0005434876742	3475	Economy	11700.00
0005434426120	3475	Economy	11700.00
0005434876733	3475	Economy	11700.00
0005434937828	3475	Economy	11700.00
0005432183430	3475	Economy	11700.00
0005434876735	3475	Economy	11700.00
0005435125709	3475	Economy	11700.00
0005434426117	3475	Economy	11700.00
0005435125711	3475	Economy	11700.00
0005432188556	3475	Economy	11700.00
0005434876739	3475	Economy	11700.00
0005434426124	3475	Economy	11700.00
0005434876724	3475	Economy	11700.00
0005434876737	3475	Economy	11700.00
0005434876746	3475	Economy	11700.00
0005434937822	3475	Economy	11700.00
0005434876671	3475	Economy	11700.00
0005432799010	3475	Economy	11700.00
0005432799007	3475	Economy	11700.00
0005434937824	3475	Economy	11700.00
0005434876734	3475	Economy	11700.00
0005434876727	3475	Economy	11700.00
0005434937817	3475	Economy	11700.00
0005435125723	3475	Economy	11700.00
0005435125710	3475	Economy	11700.00
0005434937829	3475	Economy	11700.00
0005434426121	3475	Economy	11700.00
0005434876675	3475	Economy	11700.00
0005434876680	3475	Economy	11700.00
0005434876744	3475	Economy	11700.00
0005434876713	3475	Economy	11700.00
0005434426115	3475	Economy	11700.00
0005434876719	3475	Economy	11700.00
0005434937818	3475	Economy	11700.00
0005432611643	3475	Economy	11700.00
0005434876704	3475	Economy	11700.00
0005435125713	3475	Economy	11700.00
0005432611646	3475	Economy	11700.00
0005434876721	3475	Economy	11700.00
0005432798985	3475	Economy	11700.00
0005434876730	3475	Economy	11700.00
0005434426140	3475	Economy	11700.00
0005434876699	3475	Economy	11700.00
0005434876696	3475	Economy	11700.00
0005434876681	3475	Economy	11700.00
0005434426133	3475	Economy	11700.00
0005435625898	3475	Economy	11700.00
0005432613794	3475	Economy	11700.00
0005434876743	3475	Economy	11700.00
0005434876657	3475	Economy	11700.00
0005434937815	3475	Economy	11700.00
0005434876668	3475	Economy	11700.00
0005435125703	3475	Economy	11700.00
0005435625893	3475	Economy	11700.00
0005432798986	3475	Economy	11700.00
0005435625881	3475	Economy	11700.00
0005435125724	3475	Economy	11700.00
0005434426141	3475	Economy	11700.00
0005435125696	3475	Economy	11700.00
0005434876702	3475	Economy	11700.00
0005434876725	3475	Economy	11700.00
0005434426135	3475	Economy	11700.00
0005434876654	3475	Economy	11700.00
0005435902405	14534	Comfort	19900.00
0005435913855	14534	Comfort	19900.00
0005435902404	14534	Comfort	19900.00
0005435902416	14534	Economy	11700.00
0005435913851	14534	Economy	11700.00
0005435902402	14534	Economy	11700.00
0005435842313	14534	Economy	11700.00
0005435902418	14534	Economy	11700.00
0005435902408	14534	Economy	11700.00
0005432059472	14534	Economy	11700.00
0005435902419	14534	Economy	11700.00
0005435902415	14534	Economy	11700.00
0005435913852	14534	Economy	11700.00
0005435914681	14534	Economy	11700.00
0005435902420	14534	Economy	11700.00
0005435902413	14534	Economy	11700.00
0005435902417	14534	Economy	11700.00
0005435913856	14534	Economy	11700.00
0005435842311	14534	Economy	11700.00
0005435902406	14534	Economy	11700.00
0005435902403	14534	Economy	11700.00
0005435914682	14534	Economy	11700.00
0005435902412	14534	Economy	11700.00
0005435902414	14534	Economy	11700.00
0005435913853	14534	Economy	11700.00
0005435913857	14534	Economy	11700.00
0005435902411	14534	Economy	11700.00
0005435913854	14534	Economy	11700.00
0005435902409	14534	Economy	11700.00
0005435902407	14534	Economy	11700.00
0005435902410	14534	Economy	11700.00
0005435842312	14534	Economy	11700.00
0005434325461	3638	Economy	16300.00
0005434325462	3638	Economy	14800.00
0005434312283	3638	Economy	14800.00
0005434325457	3638	Economy	14800.00
0005434325456	3638	Economy	14800.00
0005434325463	3638	Economy	14800.00
0005434325459	3638	Economy	14800.00
0005434325460	3638	Economy	14800.00
0005434325464	3638	Economy	14800.00
0005434325458	3638	Economy	14800.00
0005434312284	3638	Economy	14800.00
0005434325465	3638	Economy	14800.00
0005435889798	15599	Economy	14800.00
0005435889800	15599	Economy	14800.00
0005435889796	15599	Economy	14800.00
0005435889795	15599	Economy	14800.00
0005435889794	15599	Economy	14800.00
0005435889799	15599	Economy	14800.00
0005435889797	15599	Economy	14800.00
0005435957455	616	Economy	4500.00
0005435957465	616	Economy	4100.00
0005435957454	616	Economy	4100.00
0005435957463	616	Economy	4100.00
0005435957466	616	Economy	4100.00
0005435957461	616	Economy	4100.00
0005435957468	616	Economy	4100.00
0005435957462	616	Economy	4100.00
0005435957457	616	Economy	4100.00
0005435957456	616	Economy	4100.00
0005435957464	616	Economy	4100.00
0005435957458	616	Economy	4100.00
0005435957459	616	Economy	4100.00
0005435957467	616	Economy	4100.00
0005435957460	616	Economy	4100.00
0005433420261	15158	Economy	4100.00
0005433420263	15158	Economy	4100.00
0005433420258	15158	Economy	4100.00
0005433420260	15158	Economy	4100.00
0005433420259	15158	Economy	4100.00
0005433420264	15158	Economy	4100.00
0005433420262	15158	Economy	4100.00
0005433420265	15158	Economy	4100.00
0005435629384	8875	Economy	10400.00
0005434247104	16101	Economy	10400.00
0005434247103	16101	Economy	10400.00
0005435797249	2872	Business	12600.00
0005435797247	2872	Economy	4200.00
0005435797238	2872	Economy	4200.00
0005435797240	2872	Economy	4600.00
0005435797250	2872	Economy	4600.00
0005435797242	2872	Economy	4200.00
0005435797237	2872	Economy	4200.00
0005435797246	2872	Economy	4200.00
0005435797248	2872	Economy	4200.00
0005435797241	2872	Economy	4200.00
0005435797251	2872	Economy	4200.00
0005435797244	2872	Economy	4200.00
0005435797239	2872	Economy	4200.00
0005435797243	2872	Economy	4200.00
0005435797245	2872	Economy	4200.00
0005433404687	29307	Economy	4600.00
0005433404688	29307	Economy	4200.00
0005433404689	29307	Economy	4200.00
0005433404686	29307	Economy	4200.00
0005433404690	29307	Economy	4200.00
0005433404685	29307	Economy	4200.00
0005433404684	29307	Economy	4200.00
0005434947879	5830	Economy	6800.00
0005434947884	5830	Economy	6800.00
0005434947881	5830	Economy	6800.00
0005434947876	5830	Economy	6800.00
0005434947882	5830	Economy	6800.00
0005434947875	5830	Economy	6800.00
0005434947878	5830	Economy	6800.00
0005434947883	5830	Economy	6800.00
0005434947877	5830	Economy	6800.00
0005434947880	5830	Economy	6800.00
0005433959919	6890	Business	21400.00
0005433959944	6890	Business	21400.00
0005433959942	6890	Business	21400.00
0005433959954	6890	Business	21400.00
0005433959957	6890	Business	21400.00
0005433959927	6890	Business	21400.00
0005433959908	6890	Business	21400.00
0005433959962	6890	Economy	7100.00
0005433959959	6890	Economy	7100.00
0005433959947	6890	Economy	7100.00
0005433959934	6890	Economy	7100.00
0005433959905	6890	Economy	7100.00
0005433959906	6890	Economy	7100.00
0005433959931	6890	Economy	7100.00
0005433959915	6890	Economy	7100.00
0005433959949	6890	Economy	7100.00
0005433959943	6890	Economy	7800.00
0005433959909	6890	Economy	7800.00
0005433959913	6890	Economy	7800.00
0005433959918	6890	Economy	7100.00
0005433959940	6890	Economy	7100.00
0005433959951	6890	Economy	7100.00
0005433959928	6890	Economy	7100.00
0005433959956	6890	Economy	7100.00
0005433959933	6890	Economy	7100.00
0005433959937	6890	Economy	7100.00
0005433959904	6890	Economy	7100.00
0005433959914	6890	Economy	7100.00
0005433959912	6890	Economy	7100.00
0005433959955	6890	Economy	7100.00
0005433959924	6890	Economy	7100.00
0005433959945	6890	Economy	7100.00
0005433959960	6890	Economy	7100.00
0005433959936	6890	Economy	7100.00
0005433959907	6890	Economy	7100.00
0005433959946	6890	Economy	7100.00
0005433959926	6890	Economy	7100.00
0005433959941	6890	Economy	7100.00
0005433959953	6890	Economy	7100.00
0005433959932	6890	Economy	7100.00
0005433959930	6890	Economy	7100.00
0005433959952	6890	Economy	7100.00
0005433959948	6890	Economy	7100.00
0005433959916	6890	Economy	7100.00
0005433959961	6890	Economy	7100.00
0005433959963	6890	Economy	7100.00
0005433959935	6890	Economy	7100.00
0005433959917	6890	Economy	7100.00
0005433959929	6890	Economy	7100.00
0005433959950	6890	Economy	7100.00
0005433959910	6890	Economy	7100.00
0005433959922	6890	Economy	7100.00
0005433959920	6890	Economy	7100.00
0005433959923	6890	Economy	7100.00
0005433959958	6890	Economy	7100.00
0005433959911	6890	Economy	7100.00
0005433959925	6890	Economy	7100.00
0005433959921	6890	Economy	7100.00
0005433959938	6890	Economy	7100.00
0005433959939	6890	Economy	7100.00
0005435082646	26091	Economy	3900.00
0005435082647	26091	Economy	3900.00
0005435082648	26091	Economy	3900.00
0005435082643	26091	Economy	3900.00
0005435082644	26091	Economy	3900.00
0005435082649	26091	Economy	3900.00
0005435082645	26091	Economy	3900.00
0005434244507	5142	Business	18000.00
0005434244484	5142	Business	18000.00
0005434244503	5142	Business	18000.00
0005434244494	5142	Economy	6600.00
0005434244492	5142	Business	18000.00
0005432166848	5142	Economy	6600.00
0005434244511	5142	Economy	6600.00
0005434244488	5142	Economy	6000.00
0005434244505	5142	Economy	6000.00
0005434244501	5142	Economy	6000.00
0005434244514	5142	Economy	6000.00
0005434244489	5142	Economy	6000.00
0005432166849	5142	Economy	6000.00
0005434244508	5142	Economy	6000.00
0005434244502	5142	Economy	6000.00
0005434244495	5142	Economy	6000.00
0005434244493	5142	Economy	6600.00
0005432166846	5142	Economy	6000.00
0005434244509	5142	Economy	6000.00
0005434244491	5142	Economy	6000.00
0005434244486	5142	Economy	6000.00
0005434244504	5142	Economy	6000.00
0005434244499	5142	Economy	6000.00
0005434244490	5142	Economy	6000.00
0005434244512	5142	Economy	6000.00
0005434244513	5142	Economy	6000.00
0005434244497	5142	Economy	6000.00
0005434244498	5142	Economy	6000.00
0005434244510	5142	Economy	6000.00
0005434244500	5142	Economy	6000.00
0005434244487	5142	Economy	6000.00
0005434244496	5142	Economy	6000.00
0005432166847	5142	Economy	6000.00
0005434244485	5142	Economy	6000.00
0005434244506	5142	Economy	6000.00
0005432104777	5141	Business	18000.00
0005432104764	5141	Business	18000.00
0005432104804	5141	Business	18000.00
0005433613502	5141	Business	18000.00
0005433613535	5141	Business	18000.00
0005433613517	5141	Business	18000.00
0005433613468	5141	Business	18000.00
0005433613509	5141	Business	18000.00
0005432104772	5141	Business	18000.00
0005432104775	5141	Business	18000.00
0005432104781	5141	Business	18000.00
0005433613513	5141	Business	18000.00
0005433784347	5141	Business	18000.00
0005432104798	5141	Business	18000.00
0005433613463	5141	Business	18000.00
0005433613495	5141	Business	18000.00
0005433784340	5141	Business	18000.00
0005432104784	5141	Business	18000.00
0005433613528	5141	Business	18000.00
0005433613533	5141	Business	18000.00
0005433613519	5141	Business	18000.00
0005433613488	5141	Business	18000.00
0005433613486	5141	Business	18000.00
0005433613491	5141	Business	18000.00
0005432104779	5141	Business	18000.00
0005433613525	5141	Business	18000.00
0005433784329	5141	Business	18000.00
0005433784362	5141	Economy	6600.00
0005433613477	5141	Business	18000.00
0005433613480	5141	Economy	6600.00
0005432666354	5141	Economy	6600.00
0005433613510	5141	Economy	6600.00
0005433613467	5141	Economy	6600.00
0005433613485	5141	Economy	6600.00
0005432104799	5141	Economy	6000.00
0005433613529	5141	Economy	6000.00
0005432104761	5141	Economy	6000.00
0005433784349	5141	Economy	6000.00
0005433784332	5141	Economy	6000.00
0005432667420	5141	Economy	6000.00
0005432667418	5141	Economy	6000.00
0005432104770	5141	Economy	6000.00
0005433784345	5141	Economy	6000.00
0005433784357	5141	Economy	6000.00
0005433613505	5141	Economy	6000.00
0005433784353	5141	Economy	6000.00
0005433613479	5141	Economy	6000.00
0005432104803	5141	Economy	6000.00
0005433613516	5141	Economy	6000.00
0005433784358	5141	Economy	6000.00
0005432104763	5141	Economy	6000.00
0005433613490	5141	Economy	6000.00
0005433613527	5141	Economy	6000.00
0005433784365	5141	Economy	6000.00
0005432104805	5141	Economy	6000.00
0005432104802	5141	Economy	6000.00
0005433613464	5141	Economy	6000.00
0005433613487	5141	Economy	6000.00
0005433613489	5141	Economy	6000.00
0005433613508	5141	Economy	6000.00
0005433784336	5141	Economy	6000.00
0005433613469	5141	Economy	6000.00
0005433784330	5141	Economy	6000.00
0005432104806	5141	Economy	6000.00
0005433613492	5141	Economy	6000.00
0005433613523	5141	Economy	6000.00
0005433613493	5141	Economy	6000.00
0005432104762	5141	Economy	6000.00
0005433613532	5141	Economy	6000.00
0005433784351	5141	Economy	6000.00
0005432104786	5141	Economy	6000.00
0005432104787	5141	Economy	6000.00
0005433784334	5141	Economy	6000.00
0005433613507	5141	Economy	6000.00
0005432104785	5141	Economy	6000.00
0005433784342	5141	Economy	6000.00
0005432104789	5141	Economy	6000.00
0005433613476	5141	Economy	6000.00
0005433784337	5141	Economy	6000.00
0005432145078	5141	Economy	6000.00
0005432104801	5141	Economy	6000.00
0005433613471	5141	Economy	6000.00
0005433613499	5141	Economy	6000.00
0005433613515	5141	Economy	6000.00
0005432104771	5141	Economy	6000.00
0005433613461	5141	Economy	6000.00
0005433613494	5141	Economy	6000.00
0005433784363	5141	Economy	6000.00
0005433613526	5141	Economy	6000.00
0005433784344	5141	Economy	6000.00
0005432104800	5141	Economy	6000.00
0005433784366	5141	Economy	6000.00
0005433613498	5141	Economy	6000.00
0005433784350	5141	Economy	6600.00
0005433613506	5141	Economy	6600.00
0005433784354	5141	Economy	6600.00
0005432104793	5141	Economy	6600.00
0005432104807	5141	Economy	6600.00
0005432104766	5141	Economy	6000.00
0005432104778	5141	Economy	6000.00
0005432104767	5141	Economy	6000.00
0005433784331	5141	Economy	6000.00
0005432104765	5141	Economy	6600.00
0005432104783	5141	Economy	6000.00
0005433613465	5141	Economy	6000.00
0005433613521	5141	Economy	6000.00
0005433613462	5141	Economy	6000.00
0005432104760	5141	Economy	6000.00
0005432104791	5141	Economy	6000.00
0005433613482	5141	Economy	6000.00
0005433784360	5141	Economy	6000.00
0005433613512	5141	Economy	6000.00
0005433613474	5141	Economy	6000.00
0005432104776	5141	Economy	6000.00
0005433613497	5141	Economy	6000.00
0005433784343	5141	Economy	6000.00
0005432104795	5141	Economy	6000.00
0005433613520	5141	Economy	6000.00
0005433613500	5141	Economy	6000.00
0005432104774	5141	Economy	6000.00
0005432104796	5141	Economy	6000.00
0005433784335	5141	Economy	6000.00
0005432104782	5141	Economy	6000.00
0005433784348	5141	Economy	6000.00
0005433613501	5141	Economy	6000.00
0005433613524	5141	Economy	6000.00
0005433613466	5141	Economy	6000.00
0005432104769	5141	Economy	6000.00
0005433613496	5141	Economy	6000.00
0005433613470	5141	Economy	6000.00
0005433784352	5141	Economy	6000.00
0005432104797	5141	Economy	6000.00
0005433613478	5141	Economy	6000.00
0005432104780	5141	Economy	6000.00
0005433613518	5141	Economy	6000.00
0005433613514	5141	Economy	6000.00
0005433784361	5141	Economy	6000.00
0005433784364	5141	Economy	6000.00
0005432665240	5141	Economy	6000.00
0005433784333	5141	Economy	6000.00
0005433784356	5141	Economy	6000.00
0005433613472	5141	Economy	6000.00
0005433784341	5141	Economy	6000.00
0005432104808	5141	Economy	6000.00
0005433613530	5141	Economy	6000.00
0005432104768	5141	Economy	6000.00
0005433613484	5141	Economy	6000.00
0005432104788	5141	Economy	6000.00
0005432104792	5141	Economy	6000.00
0005433613511	5141	Economy	6000.00
0005433784359	5141	Economy	6000.00
0005433613473	5141	Economy	6000.00
0005433613531	5141	Economy	6000.00
0005433613534	5141	Economy	6000.00
0005433613504	5141	Economy	6000.00
0005433784338	5141	Economy	6000.00
0005433613483	5141	Economy	6000.00
0005432104790	5141	Economy	6000.00
0005432104773	5141	Economy	6000.00
0005433784339	5141	Economy	6000.00
0005433613481	5141	Economy	6000.00
0005433613475	5141	Economy	6000.00
0005433613522	5141	Economy	6000.00
0005432667419	5141	Economy	6000.00
0005433784346	5141	Economy	6000.00
0005432104794	5141	Economy	6000.00
0005433613503	5141	Economy	6000.00
0005433784355	5141	Economy	6000.00
0005432665239	5141	Economy	6000.00
0005434229008	5137	Business	18000.00
0005434149543	5137	Business	18000.00
0005434264708	5137	Business	18000.00
0005434149535	5137	Business	18000.00
0005434228990	5137	Business	18000.00
0005434149532	5137	Business	18000.00
0005434264727	5137	Business	18000.00
0005434229006	5137	Business	18000.00
0005434229005	5137	Business	18000.00
0005434173452	5137	Business	18000.00
0005434264726	5137	Business	18000.00
0005434228992	5137	Economy	6600.00
0005434264712	5137	Economy	6600.00
0005434229011	5137	Economy	6000.00
0005434149534	5137	Economy	6000.00
0005434264719	5137	Economy	6000.00
0005434264703	5137	Economy	6000.00
0005434229002	5137	Economy	6000.00
0005434264711	5137	Economy	6000.00
0005434228995	5137	Economy	6000.00
0005434264723	5137	Economy	6000.00
0005434264710	5137	Economy	6000.00
0005434264705	5137	Economy	6000.00
0005434264715	5137	Economy	6000.00
0005434228997	5137	Economy	6000.00
0005434173454	5137	Economy	6000.00
0005434229000	5137	Economy	6000.00
0005434264707	5137	Economy	6000.00
0005434264718	5137	Economy	6000.00
0005434228996	5137	Economy	6000.00
0005434229004	5137	Economy	6000.00
0005434264724	5137	Economy	6000.00
0005434229009	5137	Economy	6000.00
0005434149542	5137	Economy	6000.00
0005434149541	5137	Economy	6000.00
0005434228989	5137	Economy	6000.00
0005434264713	5137	Economy	6000.00
0005434264706	5137	Economy	6000.00
0005434149540	5137	Economy	6000.00
0005434149537	5137	Economy	6000.00
0005434149538	5137	Economy	6600.00
0005434228998	5137	Economy	6000.00
0005434264720	5137	Economy	6000.00
0005434173455	5137	Economy	6000.00
0005434264717	5137	Economy	6000.00
0005434229010	5137	Economy	6000.00
0005434264709	5137	Economy	6000.00
0005434264714	5137	Economy	6000.00
0005434228994	5137	Economy	6000.00
0005434264725	5137	Economy	6000.00
0005434229001	5137	Economy	6000.00
0005434264722	5137	Economy	6000.00
0005434149539	5137	Economy	6000.00
0005434229003	5137	Economy	6000.00
0005434173453	5137	Economy	6000.00
0005434264702	5137	Economy	6000.00
0005434229007	5137	Economy	6000.00
0005434228999	5137	Economy	6000.00
0005434264716	5137	Economy	6000.00
0005434264721	5137	Economy	6000.00
0005434149533	5137	Economy	6000.00
0005434264704	5137	Economy	6000.00
0005434228993	5137	Economy	6000.00
0005434228991	5137	Economy	6000.00
0005434149536	5137	Economy	6000.00
0005435269643	8602	Business	18000.00
0005435269647	8602	Economy	6600.00
0005435269645	8602	Economy	6000.00
0005435269646	8602	Economy	6000.00
0005435269644	8602	Economy	6000.00
0005432034495	8600	Business	18000.00
0005433815308	8600	Business	18000.00
0005432335835	8600	Business	18000.00
0005432034481	8600	Business	18000.00
0005432034485	8600	Business	18000.00
0005433689877	8600	Business	18000.00
0005432034492	8600	Business	18000.00
0005435286544	8600	Business	18000.00
0005432335843	8600	Business	18000.00
0005432034479	8600	Business	18000.00
0005435006635	8600	Business	18000.00
0005435006634	8600	Business	18000.00
0005433690893	8600	Business	18000.00
0005432335841	8600	Business	18000.00
0005432034503	8600	Business	18000.00
0005433688776	8600	Business	18000.00
0005435286548	8600	Economy	6600.00
0005435006645	8600	Economy	6600.00
0005432047488	8600	Economy	6600.00
0005432047491	8600	Economy	6600.00
0005435286547	8600	Economy	6600.00
0005435006623	8600	Economy	6000.00
0005432034490	8600	Economy	6000.00
0005435006639	8600	Economy	6000.00
0005435006644	8600	Economy	6000.00
0005432335833	8600	Economy	6000.00
0005435006642	8600	Economy	6000.00
0005432034505	8600	Economy	6000.00
0005432335837	8600	Economy	6000.00
0005432034482	8600	Economy	6000.00
0005432335836	8600	Economy	6000.00
0005432335834	8600	Economy	6000.00
0005432034496	8600	Economy	6000.00
0005435006621	8600	Economy	6000.00
0005435006628	8600	Economy	6000.00
0005432034488	8600	Economy	6000.00
0005433815306	8600	Economy	6000.00
0005435286539	8600	Economy	6000.00
0005435286545	8600	Economy	6000.00
0005435006631	8600	Economy	6000.00
0005432034497	8600	Economy	6000.00
0005433815309	8600	Economy	6000.00
0005435006641	8600	Economy	6000.00
0005432034484	8600	Economy	6000.00
0005435006629	8600	Economy	6000.00
0005432034504	8600	Economy	6000.00
0005432034491	8600	Economy	6000.00
0005432034486	8600	Economy	6000.00
0005435006636	8600	Economy	6000.00
0005435286542	8600	Economy	6000.00
0005435286541	8600	Economy	6000.00
0005435006625	8600	Economy	6000.00
0005435006630	8600	Economy	6000.00
0005432335832	8600	Economy	6600.00
0005435006632	8600	Economy	6600.00
0005432047489	8600	Economy	6600.00
0005432034502	8600	Economy	6000.00
0005435286538	8600	Economy	6600.00
0005434311184	8600	Economy	6000.00
0005435286540	8600	Economy	6000.00
0005432335839	8600	Economy	6000.00
0005432034498	8600	Economy	6000.00
0005435006640	8600	Economy	6000.00
0005432034500	8600	Economy	6000.00
0005435006633	8600	Economy	6000.00
0005432034501	8600	Economy	6000.00
0005432335844	8600	Economy	6000.00
0005432034478	8600	Economy	6000.00
0005432335838	8600	Economy	6000.00
0005435006626	8600	Economy	6000.00
0005435286546	8600	Economy	6000.00
0005433815307	8600	Economy	6000.00
0005435006622	8600	Economy	6000.00
0005432034499	8600	Economy	6000.00
0005432034489	8600	Economy	6000.00
0005433689876	8600	Economy	6000.00
0005435006637	8600	Economy	6000.00
0005432047490	8600	Economy	6000.00
0005432034480	8600	Economy	6000.00
0005432047487	8600	Economy	6000.00
0005432335842	8600	Economy	6000.00
0005432034483	8600	Economy	6000.00
0005432335840	8600	Economy	6000.00
0005435006638	8600	Economy	6000.00
0005432034493	8600	Economy	6000.00
0005435006627	8600	Economy	6000.00
0005435006643	8600	Economy	6000.00
0005435006646	8600	Economy	6000.00
0005435006624	8600	Economy	6000.00
0005432034494	8600	Economy	6000.00
0005432034487	8600	Economy	6000.00
0005434311183	8600	Economy	6000.00
0005435286543	8600	Economy	6000.00
0005433202129	12625	Economy	16200.00
0005433202125	12625	Economy	14800.00
0005433202123	12625	Economy	14800.00
0005433202126	12625	Economy	14800.00
0005433202130	12625	Economy	14800.00
0005433202127	12625	Economy	14800.00
0005433202122	12625	Economy	14800.00
0005433202120	12625	Economy	14800.00
0005433202131	12625	Economy	14800.00
0005433202124	12625	Economy	14800.00
0005433202132	12625	Economy	14800.00
0005433202128	12625	Economy	14800.00
0005433202118	12625	Economy	14800.00
0005433202117	12625	Economy	14800.00
0005433202121	12625	Economy	14800.00
0005433202119	12625	Economy	14800.00
0005434638853	23345	Economy	16200.00
0005434638874	23345	Economy	16200.00
0005434638854	23345	Economy	16200.00
0005434638850	23345	Economy	16200.00
0005432290582	23345	Economy	14800.00
0005434638848	23345	Economy	14800.00
0005434638852	23345	Economy	14800.00
0005432290579	23345	Economy	14800.00
0005432290580	23345	Economy	14800.00
0005434638862	23345	Economy	14800.00
0005434638851	23345	Economy	14800.00
0005434638869	23345	Economy	14800.00
0005434638875	23345	Economy	14800.00
0005434638871	23345	Economy	14800.00
0005434638855	23345	Economy	14800.00
0005434638865	23345	Economy	14800.00
0005434638873	23345	Economy	14800.00
0005432290581	23345	Economy	14800.00
0005434638868	23345	Economy	14800.00
0005434638870	23345	Economy	14800.00
0005434638861	23345	Economy	14800.00
0005434638858	23345	Economy	14800.00
0005434638856	23345	Economy	14800.00
0005434638846	23345	Economy	14800.00
0005434638867	23345	Economy	14800.00
0005434638860	23345	Economy	14800.00
0005434638859	23345	Economy	14800.00
0005434638866	23345	Economy	14800.00
0005434638872	23345	Economy	14800.00
0005434638863	23345	Economy	14800.00
0005434638857	23345	Economy	14800.00
0005434638849	23345	Economy	14800.00
0005434638864	23345	Economy	14800.00
0005434638847	23345	Economy	14800.00
0005432054255	21096	Economy	6300.00
0005432054256	21096	Economy	6300.00
0005432054257	21096	Economy	6300.00
0005432327901	31264	Business	18900.00
0005432287101	31264	Business	18900.00
0005432327922	31264	Business	18900.00
0005432382510	31264	Business	18900.00
0005432327910	31264	Business	18900.00
0005432327936	31264	Business	18900.00
0005432382504	31264	Business	18900.00
0005432327931	31264	Business	18900.00
0005432327897	31264	Business	18900.00
0005432382505	31264	Business	18900.00
0005432327892	31264	Economy	6300.00
0005432327914	31264	Economy	6300.00
0005432382496	31264	Economy	6300.00
0005432382511	31264	Economy	6300.00
0005432382516	31264	Economy	6300.00
0005432382512	31264	Economy	6300.00
0005432327915	31264	Economy	6300.00
0005432327900	31264	Economy	6300.00
0005432382488	31264	Economy	6300.00
0005432382500	31264	Economy	6300.00
0005432327890	31264	Economy	6900.00
0005432382492	31264	Economy	6900.00
0005432382495	31264	Economy	6900.00
0005432327891	31264	Economy	6900.00
0005432382509	31264	Economy	6900.00
0005432327920	31264	Economy	6300.00
0005432382493	31264	Economy	6300.00
0005432327935	31264	Economy	6300.00
0005432382485	31264	Economy	6300.00
0005432327909	31264	Economy	6300.00
0005432327893	31264	Economy	6300.00
0005432327932	31264	Economy	6300.00
0005432327906	31264	Economy	6300.00
0005432327929	31264	Economy	6300.00
0005432382513	31264	Economy	6300.00
0005432327913	31264	Economy	6300.00
0005432327908	31264	Economy	6300.00
0005432327923	31264	Economy	6300.00
0005432327926	31264	Economy	6300.00
0005432382497	31264	Economy	6300.00
0005432327896	31264	Economy	6300.00
0005432287099	31264	Economy	6300.00
0005432327924	31264	Economy	6300.00
0005432382520	31264	Economy	6300.00
0005432327912	31264	Economy	6300.00
0005432382514	31264	Economy	6300.00
0005432287102	31264	Economy	6300.00
0005432382518	31264	Economy	6300.00
0005432327937	31264	Economy	6300.00
0005432382517	31264	Economy	6300.00
0005432287104	31264	Economy	6300.00
0005432327930	31264	Economy	6300.00
0005432382508	31264	Economy	6300.00
0005432382501	31264	Economy	6300.00
0005432287103	31264	Economy	6300.00
0005432382484	31264	Economy	6300.00
0005432382502	31264	Economy	6300.00
0005432382491	31264	Economy	6300.00
0005432382494	31264	Economy	6300.00
0005432327916	31264	Economy	6300.00
0005432327927	31264	Economy	6300.00
0005432327928	31264	Economy	6300.00
0005432382486	31264	Economy	6300.00
0005432382507	31264	Economy	6300.00
0005432327905	31264	Economy	6300.00
0005432287105	31264	Economy	6300.00
0005432382506	31264	Economy	6300.00
0005432382487	31264	Economy	6300.00
0005432327898	31264	Economy	6300.00
0005432382503	31264	Economy	6300.00
0005432327933	31264	Economy	6300.00
0005432327904	31264	Economy	6300.00
0005432382519	31264	Economy	6300.00
0005432327903	31264	Economy	6300.00
0005432327902	31264	Economy	6300.00
0005432327934	31264	Economy	6300.00
0005432327919	31264	Economy	6300.00
0005432327918	31264	Economy	6300.00
0005432382490	31264	Economy	6300.00
0005432327895	31264	Economy	6300.00
0005432382489	31264	Economy	6300.00
0005432382515	31264	Economy	6300.00
0005432327907	31264	Economy	6300.00
0005432327911	31264	Economy	6300.00
0005432327921	31264	Economy	6300.00
0005432287100	31264	Economy	6300.00
0005432327899	31264	Economy	6300.00
0005432382499	31264	Economy	6300.00
0005432327917	31264	Economy	6300.00
0005432327894	31264	Economy	6300.00
0005432382498	31264	Economy	6300.00
0005432327925	31264	Economy	6300.00
0005432423644	13305	Business	12700.00
0005432423643	13305	Business	12700.00
0005432423636	13305	Business	12700.00
0005432423645	13305	Business	12700.00
0005432423647	13305	Business	12700.00
0005432423614	13305	Economy	4200.00
0005432423605	13305	Economy	4200.00
0005432423613	13305	Economy	4200.00
0005432423639	13305	Economy	4200.00
0005432423616	13305	Economy	4700.00
0005432423615	13305	Economy	4700.00
0005432423604	13305	Economy	4200.00
0005432423631	13305	Economy	4200.00
0005432423621	13305	Economy	4200.00
0005432423629	13305	Economy	4200.00
0005432423626	13305	Economy	4200.00
0005432423612	13305	Economy	4200.00
0005432423607	13305	Economy	4200.00
0005432423627	13305	Economy	4200.00
0005432423618	13305	Economy	4200.00
0005432423609	13305	Economy	4200.00
0005432423640	13305	Economy	4200.00
0005432423622	13305	Economy	4200.00
0005432423617	13305	Economy	4200.00
0005432423606	13305	Economy	4200.00
0005432423637	13305	Economy	4200.00
0005432423632	13305	Economy	4200.00
0005432423630	13305	Economy	4200.00
0005432423608	13305	Economy	4200.00
0005432423624	13305	Economy	4200.00
0005432423628	13305	Economy	4200.00
0005432423638	13305	Economy	4200.00
0005432423633	13305	Economy	4200.00
0005432423623	13305	Economy	4200.00
0005432423642	13305	Economy	4200.00
0005432423611	13305	Economy	4200.00
0005432423620	13305	Economy	4200.00
0005432423635	13305	Economy	4200.00
0005432423625	13305	Economy	4200.00
0005432423610	13305	Economy	4200.00
0005432423619	13305	Economy	4200.00
0005432423641	13305	Economy	4200.00
0005432423634	13305	Economy	4200.00
0005432423646	13305	Economy	4200.00
0005432816992	9586	Business	32600.00
0005432822074	9586	Business	32600.00
0005434448259	9586	Business	32600.00
0005432816968	9586	Business	32600.00
0005432816972	9586	Business	32600.00
0005432822077	9586	Business	32600.00
0005434448257	9586	Economy	10900.00
0005432816994	9586	Economy	11900.00
0005432816971	9586	Economy	10900.00
0005432816985	9586	Economy	11900.00
0005434448260	9586	Economy	11900.00
0005432816978	9586	Economy	10900.00
0005432288930	9586	Economy	10900.00
0005432816967	9586	Economy	10900.00
0005432816976	9586	Economy	10900.00
0005432816983	9586	Economy	10900.00
0005432816970	9586	Economy	10900.00
0005432288933	9586	Economy	10900.00
0005432822079	9586	Economy	10900.00
0005432822075	9586	Economy	10900.00
0005432816969	9586	Economy	10900.00
0005432816997	9586	Economy	10900.00
0005432816982	9586	Economy	10900.00
0005432816991	9586	Economy	10900.00
0005432816996	9586	Economy	10900.00
0005432816973	9586	Economy	10900.00
0005432816975	9586	Economy	10900.00
0005432816974	9586	Economy	10900.00
0005432816977	9586	Economy	10900.00
0005434448258	9586	Economy	10900.00
0005432816990	9586	Economy	10900.00
0005432816988	9586	Economy	10900.00
0005432822076	9586	Economy	10900.00
0005432816995	9586	Economy	10900.00
0005432816979	9586	Economy	10900.00
0005432816987	9586	Economy	10900.00
0005432822078	9586	Economy	10900.00
0005432288932	9586	Economy	10900.00
0005432816984	9586	Economy	10900.00
0005432822073	9586	Economy	10900.00
0005432816993	9586	Economy	10900.00
0005432816986	9586	Economy	10900.00
0005432288931	9586	Economy	10900.00
0005432816989	9586	Economy	10900.00
0005432816980	9586	Economy	10900.00
0005432816981	9586	Economy	10900.00
0005434157350	28956	Business	32600.00
0005432901312	28956	Business	32600.00
0005432901322	28956	Business	32600.00
0005432901321	28956	Business	32600.00
0005432901317	28956	Business	32600.00
0005432901328	28956	Business	32600.00
0005434186147	28956	Economy	10900.00
0005432901325	28956	Economy	10900.00
0005434157349	28956	Economy	10900.00
0005434157352	28956	Economy	11900.00
0005432002042	28956	Economy	11900.00
0005434157347	28956	Economy	11900.00
0005432002043	28956	Economy	10900.00
0005432901318	28956	Economy	10900.00
0005432901327	28956	Economy	10900.00
0005434157353	28956	Economy	10900.00
0005432901315	28956	Economy	10900.00
0005434157355	28956	Economy	10900.00
0005432901324	28956	Economy	10900.00
0005432901316	28956	Economy	10900.00
0005432901326	28956	Economy	10900.00
0005432901323	28956	Economy	10900.00
0005434157354	28956	Economy	10900.00
0005434186149	28956	Economy	10900.00
0005432901313	28956	Economy	10900.00
0005434186148	28956	Economy	10900.00
0005432901320	28956	Economy	10900.00
0005432901314	28956	Economy	10900.00
0005434157351	28956	Economy	10900.00
0005434157348	28956	Economy	10900.00
0005432901319	28956	Economy	10900.00
0005432613795	15046	Economy	11000.00
0005432613794	15046	Economy	11000.00
0005432611642	15046	Economy	11000.00
0005432613796	15046	Economy	11000.00
0005432611644	15046	Economy	11000.00
0005432611646	15046	Economy	11000.00
0005432611643	15046	Economy	11000.00
0005432611645	15046	Economy	11000.00
0005432613793	15046	Economy	11000.00
0005435842311	31614	Economy	11000.00
0005435842312	31614	Economy	11000.00
0005435842313	31614	Economy	11000.00
0005433568046	11845	Business	105900.00
0005433568047	11845	Business	105900.00
0005433568026	11845	Business	105900.00
0005433568015	11845	Business	105900.00
0005433568049	11845	Business	105900.00
0005433568055	11845	Business	105900.00
0005433568033	11845	Economy	35300.00
0005433568025	11845	Business	105900.00
0005433568051	11845	Economy	35300.00
0005433568028	11845	Economy	35300.00
0005433568044	11845	Economy	35300.00
0005433568065	11845	Economy	35300.00
0005433568036	11845	Economy	35300.00
0005433568067	11845	Economy	38800.00
0005433568042	11845	Economy	38800.00
0005433568062	11845	Economy	35300.00
0005433568043	11845	Economy	35300.00
0005433568016	11845	Economy	35300.00
0005433568021	11845	Economy	35300.00
0005433568041	11845	Economy	35300.00
0005433568048	11845	Economy	35300.00
0005433568050	11845	Economy	35300.00
0005433568068	11845	Economy	35300.00
0005433568023	11845	Economy	35300.00
0005433568061	11845	Economy	35300.00
0005433568064	11845	Economy	35300.00
0005433568038	11845	Economy	35300.00
0005433568035	11845	Economy	35300.00
0005433568024	11845	Economy	35300.00
0005433568052	11845	Economy	35300.00
0005433568037	11845	Economy	35300.00
0005433568032	11845	Economy	35300.00
0005433568040	11845	Economy	35300.00
0005433568058	11845	Economy	35300.00
0005433568053	11845	Economy	35300.00
0005433568031	11845	Economy	35300.00
0005433568059	11845	Economy	35300.00
0005433568039	11845	Economy	35300.00
0005433568030	11845	Economy	35300.00
0005433568063	11845	Economy	35300.00
0005433568027	11845	Economy	35300.00
0005433568017	11845	Economy	35300.00
0005433568022	11845	Economy	35300.00
0005433568066	11845	Economy	35300.00
0005433568060	11845	Economy	35300.00
0005433568054	11845	Economy	35300.00
0005433568018	11845	Economy	35300.00
0005433568019	11845	Economy	35300.00
0005433568056	11845	Economy	35300.00
0005433568029	11845	Economy	35300.00
0005433568057	11845	Economy	35300.00
0005433568020	11845	Economy	35300.00
0005433568045	11845	Economy	35300.00
0005433568034	11845	Economy	35300.00
0005432947818	25291	Business	105900.00
0005432947821	25291	Business	105900.00
0005432947829	25291	Business	105900.00
0005432947822	25291	Business	105900.00
0005432947842	25291	Business	105900.00
0005432947845	25291	Business	105900.00
0005432947833	25291	Business	105900.00
0005432947837	25291	Economy	35300.00
0005432947831	25291	Economy	35300.00
0005432947816	25291	Economy	35300.00
0005432947828	25291	Economy	38800.00
0005432947835	25291	Economy	38800.00
0005432947826	25291	Economy	35300.00
0005432947809	25291	Economy	35300.00
0005432947810	25291	Economy	35300.00
0005432947836	25291	Economy	35300.00
0005432947807	25291	Economy	35300.00
0005432947840	25291	Economy	35300.00
0005432947844	25291	Economy	35300.00
0005432947815	25291	Economy	35300.00
0005432947843	25291	Economy	35300.00
0005432947839	25291	Economy	35300.00
0005432947814	25291	Economy	35300.00
0005432947832	25291	Economy	35300.00
0005432947820	25291	Economy	35300.00
0005432947841	25291	Economy	35300.00
0005432947819	25291	Economy	35300.00
0005432947830	25291	Economy	35300.00
0005432947823	25291	Economy	35300.00
0005432947834	25291	Economy	35300.00
0005432947838	25291	Economy	35300.00
0005432947806	25291	Economy	35300.00
0005432947817	25291	Economy	35300.00
0005432947825	25291	Economy	35300.00
0005432947805	25291	Economy	35300.00
0005432947813	25291	Economy	35300.00
0005432947808	25291	Economy	35300.00
0005432947824	25291	Economy	35300.00
0005432947811	25291	Economy	35300.00
0005432947812	25291	Economy	35300.00
0005432947827	25291	Economy	35300.00
0005434654217	5367	Business	67200.00
0005434654214	5367	Business	67200.00
0005434654190	5367	Business	67200.00
0005434654199	5367	Business	67200.00
0005434654205	5367	Business	67200.00
0005434654215	5367	Economy	22400.00
0005434654204	5367	Economy	22400.00
0005432114150	5367	Economy	22400.00
0005434654202	5367	Economy	22400.00
0005432114149	5367	Economy	22400.00
0005434654200	5367	Economy	22400.00
0005434656523	5367	Economy	24600.00
0005434654201	5367	Economy	24600.00
0005434654213	5367	Economy	24600.00
0005434654198	5367	Economy	22400.00
0005434656522	5367	Economy	22400.00
0005434654207	5367	Economy	22400.00
0005434654216	5367	Economy	22400.00
0005434654193	5367	Economy	22400.00
0005434654194	5367	Economy	22400.00
0005434654212	5367	Economy	22400.00
0005434654218	5367	Economy	22400.00
0005434654196	5367	Economy	22400.00
0005434654195	5367	Economy	22400.00
0005434654208	5367	Economy	22400.00
0005434654189	5367	Economy	22400.00
0005434654209	5367	Economy	22400.00
0005434654197	5367	Economy	22400.00
0005434654192	5367	Economy	22400.00
0005434654203	5367	Economy	22400.00
0005434654211	5367	Economy	22400.00
0005434654206	5367	Economy	22400.00
0005434654210	5367	Economy	22400.00
0005434654191	5367	Economy	22400.00
0005435340013	12534	Business	67200.00
0005435340016	12534	Business	67200.00
0005435340015	12534	Economy	22400.00
0005435340008	12534	Economy	22400.00
0005435340010	12534	Economy	22400.00
0005435340018	12534	Economy	22400.00
0005435340006	12534	Economy	22400.00
0005435555337	12534	Economy	22400.00
0005435340014	12534	Economy	22400.00
0005435340017	12534	Economy	22400.00
0005435340011	12534	Economy	22400.00
0005435340007	12534	Economy	22400.00
0005435340004	12534	Economy	22400.00
0005435340012	12534	Economy	22400.00
0005435340009	12534	Economy	22400.00
0005435340005	12534	Economy	22400.00
0005435555336	12534	Economy	22400.00
0005433689875	7431	Business	32000.00
0005433715123	7431	Business	32000.00
0005433715121	7431	Business	32000.00
0005433715137	7431	Business	32000.00
0005433715159	7431	Business	32000.00
0005433715120	7431	Business	32000.00
0005433715126	7431	Economy	10700.00
0005433722102	7431	Economy	10700.00
0005433715146	7431	Economy	10700.00
0005433715129	7431	Economy	10700.00
0005433715125	7431	Economy	10700.00
0005433715147	7431	Economy	10700.00
0005433715151	7431	Economy	10700.00
0005433715157	7431	Economy	10700.00
0005433715118	7431	Economy	10700.00
0005433722104	7431	Economy	10700.00
0005433688773	7431	Economy	10700.00
0005433722103	7431	Economy	10700.00
0005433715158	7431	Economy	10700.00
0005433715134	7431	Economy	10700.00
0005433715116	7431	Economy	10700.00
0005433656613	7431	Economy	10700.00
0005433715132	7431	Economy	10700.00
0005433715135	7431	Economy	10700.00
0005433715155	7431	Economy	10700.00
0005433715150	7431	Economy	10700.00
0005433715124	7431	Economy	10700.00
0005433690892	7431	Economy	10700.00
0005433715128	7431	Economy	10700.00
0005433715145	7431	Economy	10700.00
0005433715139	7431	Economy	10700.00
0005433715131	7431	Economy	10700.00
0005433715133	7431	Economy	10700.00
0005433688775	7431	Economy	11700.00
0005433715153	7431	Economy	11700.00
0005433715122	7431	Economy	10700.00
0005433715152	7431	Economy	10700.00
0005433715130	7431	Economy	10700.00
0005433715156	7431	Economy	10700.00
0005433715164	7431	Economy	10700.00
0005433715136	7431	Economy	10700.00
0005433715154	7431	Economy	10700.00
0005433715162	7431	Economy	10700.00
0005433715119	7431	Economy	10700.00
0005433715148	7431	Economy	10700.00
0005433656614	7431	Economy	10700.00
0005433688774	7431	Economy	10700.00
0005433715140	7431	Economy	10700.00
0005433715163	7431	Economy	10700.00
0005433715160	7431	Economy	10700.00
0005432078016	7431	Economy	10700.00
0005433719081	7431	Economy	10700.00
0005433715143	7431	Economy	10700.00
0005433719082	7431	Economy	10700.00
0005433722106	7431	Economy	10700.00
0005433715144	7431	Economy	10700.00
0005433719083	7431	Economy	10700.00
0005433715149	7431	Economy	10700.00
0005433715127	7431	Economy	10700.00
0005433689874	7431	Economy	10700.00
0005432078018	7431	Economy	10700.00
0005433715138	7431	Economy	10700.00
0005433715161	7431	Economy	10700.00
0005433715166	7431	Economy	10700.00
0005433690891	7431	Economy	10700.00
0005433690890	7431	Economy	10700.00
0005433715167	7431	Economy	10700.00
0005433715165	7431	Economy	10700.00
0005433722105	7431	Economy	10700.00
0005433715141	7431	Economy	10700.00
0005433715142	7431	Economy	10700.00
0005433715117	7431	Economy	10700.00
0005433719080	7431	Economy	10700.00
0005432078017	7431	Economy	10700.00
0005432006711	29207	Business	32000.00
0005432428871	29207	Economy	10700.00
0005432428872	29207	Economy	10700.00
0005432006713	29207	Economy	10700.00
0005432428870	29207	Economy	10700.00
0005432006712	29207	Economy	10700.00
0005432428873	29207	Economy	10700.00
0005434095031	8697	Business	36500.00
0005434095030	8697	Business	36500.00
0005434095038	8697	Economy	13400.00
0005434095036	8697	Economy	12200.00
0005434095035	8697	Economy	12200.00
0005434095041	8697	Economy	12200.00
0005434095033	8697	Economy	12200.00
0005434095040	8697	Economy	12200.00
0005434095042	8697	Economy	12200.00
0005434095043	8697	Economy	12200.00
0005434095039	8697	Economy	12200.00
0005434095037	8697	Economy	12200.00
0005434095032	8697	Economy	12200.00
0005434095034	8697	Economy	12200.00
0005434181978	11638	Business	36500.00
0005434181981	11638	Business	36500.00
0005434183544	11638	Economy	12200.00
0005434181974	11638	Economy	12200.00
0005434181969	11638	Economy	13400.00
0005434183543	11638	Economy	13400.00
0005434181976	11638	Economy	12200.00
0005434184629	11638	Economy	12200.00
0005434181977	11638	Economy	12200.00
0005434184630	11638	Economy	12200.00
0005434181973	11638	Economy	12200.00
0005434181970	11638	Economy	12200.00
0005434183546	11638	Economy	12200.00
0005434181972	11638	Economy	12200.00
0005434181980	11638	Economy	12200.00
0005434181975	11638	Economy	12200.00
0005434181979	11638	Economy	12200.00
0005434183545	11638	Economy	12200.00
0005434181971	11638	Economy	12200.00
0005435732127	1430	Economy	11000.00
0005432297233	1430	Economy	11000.00
0005435732126	1430	Economy	11000.00
0005433456901	1430	Economy	11000.00
0005433456903	1430	Economy	11000.00
0005435732128	1430	Economy	11000.00
0005432297234	1430	Economy	11000.00
0005435732125	1430	Economy	11000.00
0005433456904	1430	Economy	11000.00
0005433456902	1430	Economy	11000.00
0005433397260	19277	Business	33000.00
0005433397259	19277	Business	33000.00
0005433397254	19277	Business	33000.00
0005433397266	19277	Business	33000.00
0005433397268	19277	Business	33000.00
0005433397233	19277	Business	33000.00
0005433397269	19277	Economy	11000.00
0005433397235	19277	Economy	11000.00
0005432906495	19277	Economy	11000.00
0005433397261	19277	Economy	12100.00
0005433397256	19277	Economy	12100.00
0005433397253	19277	Economy	12100.00
0005433397243	19277	Economy	12100.00
0005433397272	19277	Economy	11000.00
0005433397234	19277	Economy	11000.00
0005433397277	19277	Economy	11000.00
0005433397231	19277	Economy	11000.00
0005432906493	19277	Economy	11000.00
0005433397267	19277	Economy	11000.00
0005433397247	19277	Economy	11000.00
0005433397237	19277	Economy	11000.00
0005433397271	19277	Economy	11000.00
0005433397262	19277	Economy	11000.00
0005433397230	19277	Economy	11000.00
0005433397276	19277	Economy	11000.00
0005433397264	19277	Economy	11000.00
0005433397245	19277	Economy	11000.00
0005433397275	19277	Economy	11000.00
0005433397274	19277	Economy	11000.00
0005433397241	19277	Economy	11000.00
0005433397229	19277	Economy	11000.00
0005433397250	19277	Economy	11000.00
0005433397255	19277	Economy	11000.00
0005433397232	19277	Economy	11000.00
0005433397246	19277	Economy	11000.00
0005433397240	19277	Economy	11000.00
0005433397251	19277	Economy	11000.00
0005433397258	19277	Economy	11000.00
0005433397257	19277	Economy	11000.00
0005432906494	19277	Economy	11000.00
0005433397249	19277	Economy	11000.00
0005433397239	19277	Economy	11000.00
0005433397270	19277	Economy	11000.00
0005433397252	19277	Economy	11000.00
0005433397273	19277	Economy	11000.00
0005433397244	19277	Economy	11000.00
0005433397238	19277	Economy	11000.00
0005433397263	19277	Economy	11000.00
0005433397242	19277	Economy	11000.00
0005433397248	19277	Economy	11000.00
0005433397236	19277	Economy	11000.00
0005433397265	19277	Economy	11000.00
0005434443425	20554	Economy	14100.00
0005434443434	20554	Economy	14100.00
0005434443432	20554	Economy	14100.00
0005434443439	20554	Economy	14100.00
0005434443433	20554	Economy	14100.00
0005434443435	20554	Economy	14100.00
0005434443430	20554	Economy	14100.00
0005434443424	20554	Economy	14100.00
0005434443426	20554	Economy	14100.00
0005434443436	20554	Economy	14100.00
0005434443429	20554	Economy	14100.00
0005434443438	20554	Economy	14100.00
0005434443437	20554	Economy	14100.00
0005434443427	20554	Economy	14100.00
0005434443431	20554	Economy	14100.00
0005434443428	20554	Economy	14100.00
0005434954542	7285	Economy	5800.00
0005434954541	7285	Economy	5800.00
0005434954543	7285	Economy	5800.00
0005434954545	7285	Economy	5800.00
0005434954544	7285	Economy	5800.00
0005435377540	28343	Economy	5800.00
0005435377539	28343	Economy	5800.00
0005434351483	4494	Economy	14000.00
0005434351481	4494	Economy	14000.00
0005434351480	4494	Economy	14000.00
0005434351488	4494	Economy	14000.00
0005434351478	4494	Economy	14000.00
0005434351489	4494	Economy	14000.00
0005434351487	4494	Economy	14000.00
0005434351486	4494	Economy	14000.00
0005434351484	4494	Economy	14000.00
0005434351485	4494	Economy	14000.00
0005434351477	4494	Economy	14000.00
0005434351479	4494	Economy	14000.00
0005434351482	4494	Economy	14000.00
0005435893516	29644	Economy	15400.00
0005435893512	29644	Economy	14000.00
0005435893510	29644	Economy	14000.00
0005435893515	29644	Economy	14000.00
0005435893513	29644	Economy	14000.00
0005435893511	29644	Economy	14000.00
0005435893514	29644	Economy	14000.00
0005435893517	29644	Economy	14000.00
0005432293166	1076	Business	30600.00
0005434446481	1076	Business	30600.00
0005433463864	1076	Business	30600.00
0005435091904	1076	Economy	10200.00
0005435091909	1076	Economy	10200.00
0005435091908	1076	Economy	10200.00
0005435091903	1076	Economy	10200.00
0005433463865	1076	Economy	10200.00
0005435091910	1076	Economy	10200.00
0005434446477	1076	Economy	10200.00
0005434445211	1076	Economy	10200.00
0005433462712	1076	Economy	10200.00
0005435091907	1076	Economy	10200.00
0005433462710	1076	Economy	10200.00
0005432293167	1076	Economy	10200.00
0005434446480	1076	Economy	10200.00
0005434446479	1076	Economy	10200.00
0005435091912	1076	Economy	11200.00
0005433462711	1076	Economy	11200.00
0005434446478	1076	Economy	10200.00
0005432293168	1076	Economy	10200.00
0005435091905	1076	Economy	10200.00
0005435091911	1076	Economy	10200.00
0005435091906	1076	Economy	10200.00
0005435091902	1076	Economy	10200.00
0005433341411	17071	Business	30600.00
0005433341383	17071	Business	30600.00
0005433341394	17071	Business	30600.00
0005433341452	17071	Business	30600.00
0005433341446	17071	Business	30600.00
0005433341437	17071	Business	30600.00
0005433341413	17071	Business	30600.00
0005433341467	17071	Business	30600.00
0005433341443	17071	Business	30600.00
0005433159275	17071	Business	30600.00
0005433341392	17071	Business	30600.00
0005433341387	17071	Business	30600.00
0005433341439	17071	Business	30600.00
0005433341472	17071	Business	30600.00
0005433341400	17071	Business	30600.00
0005433341415	17071	Economy	11200.00
0005433341427	17071	Business	30600.00
0005433341436	17071	Economy	11200.00
0005433341465	17071	Economy	10200.00
0005433341421	17071	Economy	10200.00
0005433341408	17071	Economy	10200.00
0005433341459	17071	Economy	10200.00
0005433341440	17071	Economy	10200.00
0005433341466	17071	Economy	10200.00
0005433341473	17071	Economy	10200.00
0005433341423	17071	Economy	10200.00
0005433269630	17071	Economy	10200.00
0005433341395	17071	Economy	10200.00
0005433341462	17071	Economy	10200.00
0005433341435	17071	Economy	10200.00
0005433341438	17071	Economy	10200.00
0005433341461	17071	Economy	10200.00
0005433341401	17071	Economy	10200.00
0005433159274	17071	Economy	10200.00
0005433341451	17071	Economy	10200.00
0005433269627	17071	Economy	10200.00
0005433341420	17071	Economy	10200.00
0005433341444	17071	Economy	10200.00
0005433341454	17071	Economy	10200.00
0005433341479	17071	Economy	10200.00
0005433341425	17071	Economy	10200.00
0005433159276	17071	Economy	10200.00
0005433269626	17071	Economy	10200.00
0005433341419	17071	Economy	10200.00
0005433341379	17071	Economy	10200.00
0005433341434	17071	Economy	10200.00
0005433341393	17071	Economy	10200.00
0005433341402	17071	Economy	10200.00
0005433341409	17071	Economy	10200.00
0005433341406	17071	Economy	10200.00
0005433341453	17071	Economy	10200.00
0005433341458	17071	Economy	10200.00
0005433341417	17071	Economy	10200.00
0005433341475	17071	Economy	10200.00
0005433341460	17071	Economy	10200.00
0005433341388	17071	Economy	10200.00
0005433341450	17071	Economy	10200.00
0005433341469	17071	Economy	10200.00
0005433341391	17071	Economy	10200.00
0005433341416	17071	Economy	10200.00
0005433341405	17071	Economy	10200.00
0005433341441	17071	Economy	10200.00
0005433341432	17071	Economy	10200.00
0005433341455	17071	Economy	10200.00
0005433341447	17071	Economy	10200.00
0005433341418	17071	Economy	10200.00
0005433341381	17071	Economy	11200.00
0005433341457	17071	Economy	11200.00
0005433341385	17071	Economy	10200.00
0005433341463	17071	Economy	10200.00
0005433341397	17071	Economy	10200.00
0005433269628	17071	Economy	10200.00
0005433341471	17071	Economy	10200.00
0005433341378	17071	Economy	10200.00
0005433341474	17071	Economy	10200.00
0005433341430	17071	Economy	10200.00
0005433341396	17071	Economy	10200.00
0005433341384	17071	Economy	10200.00
0005433341399	17071	Economy	10200.00
0005433341431	17071	Economy	10200.00
0005433341449	17071	Economy	10200.00
0005433341382	17071	Economy	10200.00
0005433341470	17071	Economy	10200.00
0005433341478	17071	Economy	10200.00
0005433341403	17071	Economy	10200.00
0005433341422	17071	Economy	10200.00
0005433341426	17071	Economy	10200.00
0005433341390	17071	Economy	10200.00
0005433341445	17071	Economy	10200.00
0005433341404	17071	Economy	10200.00
0005433341429	17071	Economy	10200.00
0005433341414	17071	Economy	10200.00
0005433341448	17071	Economy	10200.00
0005433341442	17071	Economy	10200.00
0005433341468	17071	Economy	10200.00
0005433269629	17071	Economy	10200.00
0005433341476	17071	Economy	10200.00
0005433269625	17071	Economy	10200.00
0005433341380	17071	Economy	10200.00
0005433341412	17071	Economy	10200.00
0005433341410	17071	Economy	10200.00
0005433341433	17071	Economy	10200.00
0005433341407	17071	Economy	10200.00
0005433341389	17071	Economy	10200.00
0005433341424	17071	Economy	10200.00
0005433341386	17071	Economy	10200.00
0005433341456	17071	Economy	10200.00
0005433341428	17071	Economy	10200.00
0005433341464	17071	Economy	10200.00
0005433341398	17071	Economy	10200.00
0005433341477	17071	Economy	10200.00
0005432433591	12791	Economy	13400.00
0005432433588	12791	Economy	13400.00
0005432433590	12791	Economy	13400.00
0005432159779	12791	Economy	13400.00
0005433812860	12791	Economy	13400.00
0005432161113	12791	Economy	13400.00
0005432161112	12791	Economy	13400.00
0005432159783	12791	Economy	14800.00
0005432159780	12791	Economy	13400.00
0005432159782	12791	Economy	13400.00
0005432433589	12791	Economy	13400.00
0005432433592	12791	Economy	13400.00
0005432159781	12791	Economy	13400.00
0005432433587	12791	Economy	13400.00
0005433812861	12791	Economy	13400.00
0005434066301	30652	Business	40300.00
0005434066347	30652	Business	40300.00
0005434066361	30652	Business	40300.00
0005434081482	30652	Business	40300.00
0005434081477	30652	Business	40300.00
0005434066322	30652	Business	40300.00
0005434066310	30652	Business	40300.00
0005434066331	30652	Business	40300.00
0005434066319	30652	Business	40300.00
0005434066340	30652	Business	40300.00
0005434066308	30652	Economy	13400.00
0005434066334	30652	Economy	13400.00
0005434081472	30652	Economy	13400.00
0005434066363	30652	Economy	13400.00
0005434066323	30652	Economy	13400.00
0005434066318	30652	Economy	13400.00
0005434066351	30652	Economy	13400.00
0005434066330	30652	Economy	13400.00
0005434066325	30652	Economy	13400.00
0005434026670	30652	Economy	13400.00
0005434066314	30652	Economy	13400.00
0005434066303	30652	Economy	13400.00
0005434066350	30652	Economy	13400.00
0005432186806	30652	Economy	13400.00
0005433989688	30652	Economy	13400.00
0005434066364	30652	Economy	13400.00
0005434081474	30652	Economy	13400.00
0005434066336	30652	Economy	13400.00
0005434066317	30652	Economy	13400.00
0005432150059	30652	Economy	13400.00
0005434066311	30652	Economy	13400.00
0005434066362	30652	Economy	13400.00
0005434066313	30652	Economy	13400.00
0005434066333	30652	Economy	13400.00
0005434066338	30652	Economy	13400.00
0005434066304	30652	Economy	13400.00
0005432150054	30652	Economy	13400.00
0005432150056	30652	Economy	13400.00
0005434066306	30652	Economy	13400.00
0005434066342	30652	Economy	13400.00
0005434081473	30652	Economy	13400.00
0005434066352	30652	Economy	13400.00
0005433989689	30652	Economy	13400.00
0005434066335	30652	Economy	13400.00
0005434066296	30652	Economy	13400.00
0005434066343	30652	Economy	14800.00
0005433989686	30652	Economy	14800.00
0005434066316	30652	Economy	14800.00
0005432150061	30652	Economy	14800.00
0005432150055	30652	Economy	14800.00
0005434066341	30652	Economy	13400.00
0005434066346	30652	Economy	13400.00
0005434081476	30652	Economy	13400.00
0005434026669	30652	Economy	13400.00
0005434066345	30652	Economy	13400.00
0005434081484	30652	Economy	13400.00
0005434066356	30652	Economy	13400.00
0005434066307	30652	Economy	13400.00
0005432186805	30652	Economy	13400.00
0005434066332	30652	Economy	13400.00
0005434066300	30652	Economy	13400.00
0005434066344	30652	Economy	13400.00
0005434066329	30652	Economy	13400.00
0005434066348	30652	Economy	13400.00
0005434066297	30652	Economy	13400.00
0005434066365	30652	Economy	13400.00
0005434066360	30652	Economy	13400.00
0005434026671	30652	Economy	13400.00
0005434066309	30652	Economy	13400.00
0005433989687	30652	Economy	13400.00
0005434066299	30652	Economy	13400.00
0005434081470	30652	Economy	13400.00
0005434081478	30652	Economy	13400.00
0005434081485	30652	Economy	13400.00
0005434081483	30652	Economy	13400.00
0005434066337	30652	Economy	13400.00
0005434066324	30652	Economy	13400.00
0005434066302	30652	Economy	13400.00
0005434066315	30652	Economy	13400.00
0005434066366	30652	Economy	13400.00
0005434081471	30652	Economy	13400.00
0005434066321	30652	Economy	13400.00
0005434066328	30652	Economy	13400.00
0005432150062	30652	Economy	13400.00
0005434066295	30652	Economy	13400.00
0005434066355	30652	Economy	13400.00
0005434066305	30652	Economy	13400.00
0005434066349	30652	Economy	13400.00
0005433989685	30652	Economy	13400.00
0005434066320	30652	Economy	13400.00
0005434066339	30652	Economy	13400.00
0005434066359	30652	Economy	13400.00
0005434066298	30652	Economy	13400.00
0005434066357	30652	Economy	13400.00
0005434066354	30652	Economy	13400.00
0005432186803	30652	Economy	13400.00
0005434066312	30652	Economy	13400.00
0005432150057	30652	Economy	13400.00
0005434066358	30652	Economy	13400.00
0005434081481	30652	Economy	13400.00
0005432150058	30652	Economy	13400.00
0005434081475	30652	Economy	13400.00
0005434081480	30652	Economy	13400.00
0005432186804	30652	Economy	13400.00
0005434081486	30652	Economy	13400.00
0005434066353	30652	Economy	13400.00
0005434066326	30652	Economy	13400.00
0005434081479	30652	Economy	13400.00
0005434066327	30652	Economy	13400.00
0005432150060	30652	Economy	13400.00
0005435765207	5500	Business	35300.00
0005435723010	5500	Business	35300.00
0005435735056	5500	Business	35300.00
0005435765204	5500	Business	35300.00
0005433527205	5500	Business	35300.00
0005433529217	5500	Business	35300.00
0005435765188	5500	Business	35300.00
0005435765187	5500	Business	35300.00
0005435765182	5500	Business	35300.00
0005435765185	5500	Business	35300.00
0005435765178	5500	Business	35300.00
0005435765194	5500	Economy	12900.00
0005435765214	5500	Economy	12900.00
0005435735059	5500	Economy	12900.00
0005435765192	5500	Economy	11800.00
0005435722014	5500	Economy	11800.00
0005435765203	5500	Economy	11800.00
0005435765195	5500	Economy	11800.00
0005435765198	5500	Economy	11800.00
0005435765202	5500	Economy	11800.00
0005435725511	5500	Economy	11800.00
0005432140312	5500	Economy	11800.00
0005435725515	5500	Economy	11800.00
0005435725514	5500	Economy	11800.00
0005435765200	5500	Economy	11800.00
0005435765176	5500	Economy	11800.00
0005433529214	5500	Economy	11800.00
0005435765181	5500	Economy	11800.00
0005435765212	5500	Economy	11800.00
0005435765172	5500	Economy	11800.00
0005435765184	5500	Economy	11800.00
0005435765189	5500	Economy	11800.00
0005435725513	5500	Economy	11800.00
0005435765190	5500	Economy	11800.00
0005435765196	5500	Economy	11800.00
0005435765191	5500	Economy	11800.00
0005435765180	5500	Economy	11800.00
0005433527203	5500	Economy	11800.00
0005435765197	5500	Economy	11800.00
0005435725512	5500	Economy	11800.00
0005435765208	5500	Economy	11800.00
0005433529218	5500	Economy	11800.00
0005435765186	5500	Economy	11800.00
0005435765193	5500	Economy	11800.00
0005432140309	5500	Economy	11800.00
0005432140308	5500	Economy	11800.00
0005435722015	5500	Economy	11800.00
0005435765213	5500	Economy	12900.00
0005432140314	5500	Economy	11800.00
0005433527206	5500	Economy	11800.00
0005433529216	5500	Economy	11800.00
0005435765210	5500	Economy	11800.00
0005435765209	5500	Economy	11800.00
0005435723009	5500	Economy	11800.00
0005435735057	5500	Economy	11800.00
0005435765205	5500	Economy	11800.00
0005435765174	5500	Economy	11800.00
0005435765183	5500	Economy	11800.00
0005432140311	5500	Economy	11800.00
0005432140310	5500	Economy	11800.00
0005435765211	5500	Economy	11800.00
0005435765173	5500	Economy	11800.00
0005433529215	5500	Economy	11800.00
0005435720802	5500	Economy	11800.00
0005432140313	5500	Economy	11800.00
0005435765179	5500	Economy	11800.00
0005435765199	5500	Economy	11800.00
0005435765177	5500	Economy	11800.00
0005435735055	5500	Economy	11800.00
0005435765201	5500	Economy	11800.00
0005435735058	5500	Economy	11800.00
0005433527204	5500	Economy	11800.00
0005435725516	5500	Economy	11800.00
0005435720801	5500	Economy	11800.00
0005435765175	5500	Economy	11800.00
0005435722016	5500	Economy	11800.00
0005435765206	5500	Economy	11800.00
0005434831073	13477	Business	35300.00
0005432535750	13477	Business	35300.00
0005432194443	13477	Business	35300.00
0005435461819	13477	Business	35300.00
0005435461806	13477	Business	35300.00
0005434264727	13477	Business	35300.00
0005434264725	13477	Business	35300.00
0005435461817	13477	Business	35300.00
0005435461818	13477	Economy	12900.00
0005432535754	13477	Economy	12900.00
0005435461830	13477	Economy	11800.00
0005435461828	13477	Economy	11800.00
0005434264709	13477	Economy	11800.00
0005434264705	13477	Economy	11800.00
0005435461823	13477	Economy	11800.00
0005434264718	13477	Economy	11800.00
0005434264711	13477	Economy	11800.00
0005435461804	13477	Economy	11800.00
0005435461826	13477	Economy	11800.00
0005435461814	13477	Economy	11800.00
0005434831075	13477	Economy	11800.00
0005435461802	13477	Economy	11800.00
0005434264717	13477	Economy	11800.00
0005434264719	13477	Economy	11800.00
0005434264708	13477	Economy	11800.00
0005434264703	13477	Economy	11800.00
0005432535751	13477	Economy	11800.00
0005435461807	13477	Economy	11800.00
0005434264712	13477	Economy	11800.00
0005435461813	13477	Economy	11800.00
0005435461805	13477	Economy	11800.00
0005435461821	13477	Economy	11800.00
0005435461803	13477	Economy	11800.00
0005435461831	13477	Economy	11800.00
0005434264726	13477	Economy	11800.00
0005435461809	13477	Economy	11800.00
0005432194442	13477	Economy	11800.00
0005435461825	13477	Economy	11800.00
0005434264713	13477	Economy	11800.00
0005434264715	13477	Economy	11800.00
0005435461832	13477	Economy	11800.00
0005435461796	13477	Economy	11800.00
0005435461800	13477	Economy	11800.00
0005434264714	13477	Economy	11800.00
0005434264720	13477	Economy	11800.00
0005435461799	13477	Economy	12900.00
0005432194441	13477	Economy	11800.00
0005434264706	13477	Economy	12900.00
0005435461795	13477	Economy	11800.00
0005434264704	13477	Economy	11800.00
0005434831071	13477	Economy	11800.00
0005434264723	13477	Economy	11800.00
0005434264702	13477	Economy	11800.00
0005434264724	13477	Economy	11800.00
0005432535755	13477	Economy	11800.00
0005435461797	13477	Economy	11800.00
0005434831074	13477	Economy	11800.00
0005435461816	13477	Economy	11800.00
0005432535753	13477	Economy	11800.00
0005435461810	13477	Economy	11800.00
0005435461811	13477	Economy	11800.00
0005435461820	13477	Economy	11800.00
0005432535752	13477	Economy	11800.00
0005434264722	13477	Economy	11800.00
0005434264721	13477	Economy	11800.00
0005435461827	13477	Economy	11800.00
0005435461815	13477	Economy	11800.00
0005435461824	13477	Economy	11800.00
0005434264707	13477	Economy	11800.00
0005434831072	13477	Economy	11800.00
0005432194440	13477	Economy	11800.00
0005434264710	13477	Economy	11800.00
0005435461829	13477	Economy	11800.00
0005435461822	13477	Economy	11800.00
0005435461812	13477	Economy	11800.00
0005435461808	13477	Economy	11800.00
0005435461801	13477	Economy	11800.00
0005435461798	13477	Economy	11800.00
0005434264716	13477	Economy	11800.00
0005434514921	18702	Economy	3300.00
0005434514923	18702	Economy	3300.00
0005434513535	18702	Economy	3300.00
0005434513534	18702	Economy	3300.00
0005434514922	18702	Economy	3300.00
0005434513533	18702	Economy	3300.00
0005432632623	4108	Business	88300.00
0005432632620	4108	Business	88300.00
0005432632624	4108	Business	88300.00
0005432649304	4108	Business	88300.00
0005432632632	4108	Business	88300.00
0005432632627	4108	Business	88300.00
0005432632630	4108	Business	88300.00
0005432649297	4108	Business	88300.00
0005432632622	4108	Business	88300.00
0005432649296	4108	Economy	29400.00
0005432632626	4108	Economy	32400.00
0005432649299	4108	Economy	29400.00
0005432632631	4108	Economy	29400.00
0005432649306	4108	Economy	29400.00
0005432632625	4108	Economy	29400.00
0005432632629	4108	Economy	29400.00
0005432632628	4108	Economy	29400.00
0005432649303	4108	Economy	29400.00
0005432632634	4108	Economy	29400.00
0005432649300	4108	Economy	29400.00
0005432649302	4108	Economy	29400.00
0005432632621	4108	Economy	29400.00
0005432649298	4108	Economy	29400.00
0005432649307	4108	Economy	29400.00
0005432649305	4108	Economy	29400.00
0005432649301	4108	Economy	29400.00
0005432632633	4108	Economy	29400.00
0005432295837	1798	Business	48700.00
0005432295836	1798	Business	48700.00
0005433810492	1798	Business	48700.00
0005432295835	1798	Economy	16200.00
0005433007859	22549	Business	48700.00
0005433007850	22549	Business	48700.00
0005433007841	22549	Business	48700.00
0005433284788	22549	Business	48700.00
0005433007854	22549	Business	48700.00
0005433284786	22549	Business	48700.00
0005433284773	22549	Business	48700.00
0005433007853	22549	Business	48700.00
0005433007866	22549	Business	48700.00
0005433007825	22549	Economy	16200.00
0005433284791	22549	Economy	16200.00
0005433007849	22549	Economy	16200.00
0005433007835	22549	Economy	16200.00
0005433284780	22549	Economy	16200.00
0005433007865	22549	Economy	16200.00
0005433284790	22549	Economy	16200.00
0005433007834	22549	Economy	16200.00
0005433007838	22549	Economy	17900.00
0005433007831	22549	Economy	17900.00
0005433007867	22549	Economy	17900.00
0005433007832	22549	Economy	17900.00
0005433284779	22549	Economy	16200.00
0005433284782	22549	Economy	16200.00
0005433284783	22549	Economy	16200.00
0005433007827	22549	Economy	16200.00
0005433007828	22549	Economy	16200.00
0005433284770	22549	Economy	16200.00
0005433284769	22549	Economy	16200.00
0005433007857	22549	Economy	16200.00
0005433007845	22549	Economy	16200.00
0005433007829	22549	Economy	16200.00
0005433007836	22549	Economy	16200.00
0005433284775	22549	Economy	16200.00
0005433007833	22549	Economy	16200.00
0005433284793	22549	Economy	16200.00
0005433284784	22549	Economy	16200.00
0005433284792	22549	Economy	16200.00
0005433007846	22549	Economy	16200.00
0005433284774	22549	Economy	16200.00
0005433007843	22549	Economy	16200.00
0005433007847	22549	Economy	16200.00
0005433007861	22549	Economy	16200.00
0005433007840	22549	Economy	16200.00
0005433284781	22549	Economy	16200.00
0005433007851	22549	Economy	16200.00
0005433007823	22549	Economy	16200.00
0005433007855	22549	Economy	16200.00
0005433007826	22549	Economy	16200.00
0005433007824	22549	Economy	16200.00
0005433007858	22549	Economy	16200.00
0005433284776	22549	Economy	16200.00
0005433007830	22549	Economy	16200.00
0005433007822	22549	Economy	16200.00
0005433284794	22549	Economy	16200.00
0005433284789	22549	Economy	16200.00
0005433284787	22549	Economy	16200.00
0005433284772	22549	Economy	16200.00
0005433007844	22549	Economy	16200.00
0005433007848	22549	Economy	16200.00
0005433284777	22549	Economy	16200.00
0005433284785	22549	Economy	16200.00
0005433007862	22549	Economy	16200.00
0005433007852	22549	Economy	16200.00
0005433007856	22549	Economy	16200.00
0005433007864	22549	Economy	16200.00
0005433007863	22549	Economy	16200.00
0005433284771	22549	Economy	16200.00
0005433007837	22549	Economy	16200.00
0005433007839	22549	Economy	16200.00
0005433007842	22549	Economy	16200.00
0005433007860	22549	Economy	16200.00
0005433284778	22549	Economy	16200.00
0005433845724	5568	Business	99800.00
0005433845780	5568	Business	99800.00
0005433845736	5568	Business	99800.00
0005433845769	5568	Business	99800.00
0005432081404	5568	Business	99800.00
0005433845725	5568	Business	99800.00
0005433845744	5568	Business	99800.00
0005433845778	5568	Business	99800.00
0005433845767	5568	Business	99800.00
0005433815304	5568	Business	99800.00
0005433845737	5568	Business	99800.00
0005433845754	5568	Business	99800.00
0005433845729	5568	Business	99800.00
0005433845760	5568	Business	99800.00
0005433815300	5568	Business	99800.00
0005433845747	5568	Business	99800.00
0005432081401	5568	Economy	33300.00
0005433845749	5568	Economy	33300.00
0005433845723	5568	Economy	33300.00
0005433845750	5568	Economy	33300.00
0005433845757	5568	Economy	33300.00
0005433845766	5568	Economy	36600.00
0005433845751	5568	Economy	36600.00
0005432081406	5568	Economy	36600.00
0005433845770	5568	Economy	36600.00
0005433845742	5568	Economy	33300.00
0005433845735	5568	Economy	33300.00
0005432081405	5568	Economy	33300.00
0005433845776	5568	Economy	33300.00
0005433845731	5568	Economy	33300.00
0005433845728	5568	Economy	33300.00
0005433845753	5568	Economy	33300.00
0005433845759	5568	Economy	33300.00
0005433845782	5568	Economy	33300.00
0005433845763	5568	Economy	33300.00
0005433845781	5568	Economy	33300.00
0005433845741	5568	Economy	33300.00
0005433845771	5568	Economy	33300.00
0005433845745	5568	Economy	33300.00
0005433845764	5568	Economy	33300.00
0005433845773	5568	Economy	33300.00
0005433845743	5568	Economy	33300.00
0005433845774	5568	Economy	33300.00
0005433845768	5568	Economy	33300.00
0005433845733	5568	Economy	33300.00
0005433845772	5568	Economy	33300.00
0005433845765	5568	Economy	33300.00
0005433845755	5568	Economy	33300.00
0005433845756	5568	Economy	33300.00
0005432081403	5568	Economy	33300.00
0005433815302	5568	Economy	33300.00
0005433845758	5568	Economy	33300.00
0005433815301	5568	Economy	33300.00
0005433845734	5568	Economy	33300.00
0005433815303	5568	Economy	33300.00
0005433845732	5568	Economy	33300.00
0005433815305	5568	Economy	33300.00
0005433845775	5568	Economy	33300.00
0005433845777	5568	Economy	33300.00
0005433845748	5568	Economy	33300.00
0005433845746	5568	Economy	33300.00
0005433845726	5568	Economy	33300.00
0005433845762	5568	Economy	33300.00
0005433845730	5568	Economy	33300.00
0005433845738	5568	Economy	33300.00
0005433845740	5568	Economy	33300.00
0005433845727	5568	Economy	33300.00
0005433845752	5568	Economy	33300.00
0005433845761	5568	Economy	33300.00
0005433845779	5568	Economy	33300.00
0005432081402	5568	Economy	33300.00
0005433845739	5568	Economy	33300.00
0005435282071	13885	Business	99800.00
0005432003649	13885	Business	99800.00
0005435282092	13885	Business	99800.00
0005435282078	13885	Business	99800.00
0005435282082	13885	Business	99800.00
0005432003648	13885	Business	99800.00
0005435282095	13885	Business	99800.00
0005435282079	13885	Business	99800.00
0005434173453	13885	Economy	33300.00
0005435282076	13885	Economy	33300.00
0005434173455	13885	Economy	33300.00
0005435282090	13885	Economy	33300.00
0005434173452	13885	Economy	33300.00
0005435282087	13885	Economy	36600.00
0005435282086	13885	Economy	36600.00
0005435282070	13885	Economy	33300.00
0005435282085	13885	Economy	33300.00
0005435282081	13885	Economy	33300.00
0005434173454	13885	Economy	33300.00
0005435282077	13885	Economy	33300.00
0005435282091	13885	Economy	33300.00
0005435282088	13885	Economy	33300.00
0005435282073	13885	Economy	33300.00
0005432003650	13885	Economy	33300.00
0005435282084	13885	Economy	33300.00
0005435282094	13885	Economy	33300.00
0005435282074	13885	Economy	33300.00
0005435282093	13885	Economy	33300.00
0005435282080	13885	Economy	33300.00
0005435282089	13885	Economy	33300.00
0005435282075	13885	Economy	33300.00
0005435282072	13885	Economy	33300.00
0005435282083	13885	Economy	33300.00
0005434620247	7828	Economy	16600.00
0005434620245	7828	Economy	15100.00
0005432112477	7828	Economy	15100.00
0005432112478	7828	Economy	15100.00
0005434620243	7828	Economy	15100.00
0005434620259	7828	Economy	15100.00
0005434620253	7828	Economy	15100.00
0005432112479	7828	Economy	15100.00
0005434620252	7828	Economy	15100.00
0005434620255	7828	Economy	15100.00
0005434620260	7828	Economy	15100.00
0005434620251	7828	Economy	15100.00
0005434620254	7828	Economy	15100.00
0005434620248	7828	Economy	15100.00
0005434620250	7828	Economy	15100.00
0005434620258	7828	Economy	15100.00
0005434620257	7828	Economy	15100.00
0005434620263	7828	Economy	15100.00
0005434620261	7828	Economy	15100.00
0005434620262	7828	Economy	15100.00
0005434620244	7828	Economy	15100.00
0005434620249	7828	Economy	15100.00
0005434620246	7828	Economy	15100.00
0005434620256	7828	Economy	15100.00
0005435332165	32999	Economy	16600.00
0005435332157	32999	Economy	15100.00
0005435332161	32999	Economy	15100.00
0005435332162	32999	Economy	15100.00
0005435332164	32999	Economy	15100.00
0005435332167	32999	Economy	15100.00
0005435332163	32999	Economy	15100.00
0005435332159	32999	Economy	15100.00
0005435332158	32999	Economy	15100.00
0005435332166	32999	Economy	15100.00
0005435332160	32999	Economy	15100.00
0005435784767	4273	Business	38000.00
0005435784792	4273	Business	38000.00
0005435784765	4273	Business	38000.00
0005435784789	4273	Business	38000.00
0005434993862	4273	Business	38000.00
0005435784768	4273	Business	38000.00
0005435787320	4273	Business	38000.00
0005434993855	4273	Economy	12700.00
0005435787321	4273	Economy	12700.00
0005435784781	4273	Economy	12700.00
0005434993863	4273	Economy	12700.00
0005435784786	4273	Economy	13900.00
0005432190565	4273	Economy	12700.00
0005434993860	4273	Economy	12700.00
0005435784787	4273	Economy	12700.00
0005432190566	4273	Economy	12700.00
0005435784776	4273	Economy	12700.00
0005435784775	4273	Economy	12700.00
0005435784780	4273	Economy	12700.00
0005435784770	4273	Economy	12700.00
0005435784798	4273	Economy	12700.00
0005435784778	4273	Economy	12700.00
0005434993857	4273	Economy	12700.00
0005434993858	4273	Economy	12700.00
0005435784794	4273	Economy	12700.00
0005435784782	4273	Economy	12700.00
0005435784790	4273	Economy	12700.00
0005435784797	4273	Economy	12700.00
0005435784779	4273	Economy	12700.00
0005435784793	4273	Economy	12700.00
0005435784784	4273	Economy	12700.00
0005434993864	4273	Economy	12700.00
0005435784774	4273	Economy	12700.00
0005435784788	4273	Economy	12700.00
0005435784766	4273	Economy	12700.00
0005435784772	4273	Economy	12700.00
0005435784796	4273	Economy	12700.00
0005435784795	4273	Economy	12700.00
0005432190567	4273	Economy	12700.00
0005435784764	4273	Economy	12700.00
0005435784777	4273	Economy	12700.00
0005435784783	4273	Economy	12700.00
0005434993859	4273	Economy	12700.00
0005435784769	4273	Economy	12700.00
0005435784785	4273	Economy	12700.00
0005435784771	4273	Economy	12700.00
0005435784791	4273	Economy	12700.00
0005435784773	4273	Economy	12700.00
0005434993861	4273	Economy	12700.00
0005434993856	4273	Economy	12700.00
0005435937307	27288	Business	38000.00
0005435918578	27288	Business	38000.00
0005435937305	27288	Economy	13900.00
0005432195655	27288	Economy	12700.00
0005435918573	27288	Economy	12700.00
0005435937313	27288	Economy	12700.00
0005435918574	27288	Economy	12700.00
0005435937308	27288	Economy	12700.00
0005435937312	27288	Economy	12700.00
0005435937309	27288	Economy	12700.00
0005435918575	27288	Economy	12700.00
0005435918577	27288	Economy	12700.00
0005432195656	27288	Economy	12700.00
0005435937306	27288	Economy	12700.00
0005435918576	27288	Economy	12700.00
0005435937311	27288	Economy	12700.00
0005432195657	27288	Economy	12700.00
0005435937310	27288	Economy	12700.00
0005432146165	19872	Economy	12800.00
0005432146164	19872	Economy	12800.00
0005432146163	19872	Economy	12800.00
0005432566599	4693	Business	40900.00
0005432566607	4693	Business	40900.00
0005432458989	4693	Business	40900.00
0005432458975	4693	Business	40900.00
0005432566648	4693	Business	40900.00
0005432566609	4693	Business	40900.00
0005432566605	4693	Business	40900.00
0005432566612	4693	Business	40900.00
0005432566613	4693	Business	40900.00
0005432571258	4693	Business	40900.00
0005432458996	4693	Business	40900.00
0005432566629	4693	Business	40900.00
0005432459009	4693	Business	40900.00
0005432566592	4693	Business	40900.00
0005432458959	4693	Business	40900.00
0005432459003	4693	Business	40900.00
0005434081489	4693	Business	40900.00
0005432186810	4693	Business	40900.00
0005432458999	4693	Business	40900.00
0005432566606	4693	Business	40900.00
0005432186808	4693	Business	40900.00
0005434081505	4693	Business	40900.00
0005432458994	4693	Business	40900.00
0005432566642	4693	Business	40900.00
0005434081492	4693	Business	40900.00
0005432458961	4693	Economy	15000.00
0005434081487	4693	Business	40900.00
0005432566601	4693	Economy	15000.00
0005432458979	4693	Economy	15000.00
0005432566641	4693	Economy	13600.00
0005432458986	4693	Economy	13600.00
0005432566646	4693	Economy	13600.00
0005432566645	4693	Economy	13600.00
0005432566647	4693	Economy	13600.00
0005433726066	4693	Economy	13600.00
0005434081491	4693	Economy	13600.00
0005432459006	4693	Economy	13600.00
0005434081509	4693	Economy	13600.00
0005432566649	4693	Economy	13600.00
0005432458956	4693	Economy	13600.00
0005434081507	4693	Economy	13600.00
0005432566625	4693	Economy	13600.00
0005432566611	4693	Economy	13600.00
0005432170276	4693	Economy	13600.00
0005433451584	4693	Economy	13600.00
0005432566591	4693	Economy	13600.00
0005434081503	4693	Economy	13600.00
0005432566644	4693	Economy	13600.00
0005433452705	4693	Economy	13600.00
0005432566622	4693	Economy	13600.00
0005432458982	4693	Economy	13600.00
0005432458981	4693	Economy	13600.00
0005432458972	4693	Economy	13600.00
0005434081488	4693	Economy	13600.00
0005432458983	4693	Economy	13600.00
0005434081513	4693	Economy	13600.00
0005432170274	4693	Economy	13600.00
0005434081497	4693	Economy	13600.00
0005434081499	4693	Economy	13600.00
0005434081493	4693	Economy	13600.00
0005432458964	4693	Economy	13600.00
0005434081495	4693	Economy	13600.00
0005432566650	4693	Economy	13600.00
0005432566639	4693	Economy	13600.00
0005432566636	4693	Economy	13600.00
0005432566621	4693	Economy	13600.00
0005432566620	4693	Economy	13600.00
0005432566603	4693	Economy	13600.00
0005432458985	4693	Economy	13600.00
0005432458984	4693	Economy	13600.00
0005432458987	4693	Economy	13600.00
0005432458969	4693	Economy	13600.00
0005432458957	4693	Economy	13600.00
0005432566634	4693	Economy	13600.00
0005434081517	4693	Economy	13600.00
0005434081498	4693	Economy	13600.00
0005432186809	4693	Economy	13600.00
0005434081500	4693	Economy	13600.00
0005433726065	4693	Economy	13600.00
0005434081496	4693	Economy	13600.00
0005432571257	4693	Economy	13600.00
0005432566627	4693	Economy	13600.00
0005432566616	4693	Economy	13600.00
0005432458990	4693	Economy	13600.00
0005432459001	4693	Economy	13600.00
0005434081512	4693	Economy	13600.00
0005432458977	4693	Economy	13600.00
0005432459008	4693	Economy	13600.00
0005432566624	4693	Economy	13600.00
0005432566640	4693	Economy	13600.00
0005432566637	4693	Economy	13600.00
0005432458978	4693	Economy	13600.00
0005432458991	4693	Economy	13600.00
0005434081506	4693	Economy	13600.00
0005432566600	4693	Economy	13600.00
0005432566643	4693	Economy	13600.00
0005432566617	4693	Economy	13600.00
0005434081501	4693	Economy	13600.00
0005432458998	4693	Economy	13600.00
0005432566590	4693	Economy	13600.00
0005432458974	4693	Economy	13600.00
0005432571259	4693	Economy	13600.00
0005432458970	4693	Economy	13600.00
0005432170275	4693	Economy	13600.00
0005432458960	4693	Economy	13600.00
0005432458993	4693	Economy	13600.00
0005434081514	4693	Economy	15000.00
0005432458968	4693	Economy	13600.00
0005432566638	4693	Economy	13600.00
0005432458965	4693	Economy	13600.00
0005432170272	4693	Economy	15000.00
0005434081490	4693	Economy	13600.00
0005432566597	4693	Economy	13600.00
0005432170271	4693	Economy	13600.00
0005432566594	4693	Economy	13600.00
0005432458958	4693	Economy	13600.00
0005432458963	4693	Economy	13600.00
0005433726064	4693	Economy	13600.00
0005434081504	4693	Economy	13600.00
0005432566615	4693	Economy	13600.00
0005434081510	4693	Economy	13600.00
0005434081520	4693	Economy	13600.00
0005432458962	4693	Economy	13600.00
0005432566610	4693	Economy	13600.00
0005432458997	4693	Economy	13600.00
0005432458992	4693	Economy	13600.00
0005432566602	4693	Economy	13600.00
0005432566604	4693	Economy	13600.00
0005432566628	4693	Economy	13600.00
0005432566589	4693	Economy	13600.00
0005432459005	4693	Economy	13600.00
0005432566595	4693	Economy	13600.00
0005432566631	4693	Economy	13600.00
0005432458967	4693	Economy	13600.00
0005432170273	4693	Economy	13600.00
0005434081494	4693	Economy	13600.00
0005432571260	4693	Economy	13600.00
0005432566593	4693	Economy	13600.00
0005432566632	4693	Economy	13600.00
0005432458988	4693	Economy	13600.00
0005433451585	4693	Economy	13600.00
0005432566633	4693	Economy	13600.00
0005434081502	4693	Economy	13600.00
0005432566608	4693	Economy	13600.00
0005433452704	4693	Economy	13600.00
0005432566618	4693	Economy	13600.00
0005432459007	4693	Economy	13600.00
0005432458976	4693	Economy	13600.00
0005433451586	4693	Economy	13600.00
0005432459004	4693	Economy	13600.00
0005432566630	4693	Economy	13600.00
0005434081508	4693	Economy	13600.00
0005432566623	4693	Economy	13600.00
0005432458971	4693	Economy	13600.00
0005434081515	4693	Economy	13600.00
0005432566619	4693	Economy	13600.00
0005432566614	4693	Economy	13600.00
0005434081519	4693	Economy	13600.00
0005432458966	4693	Economy	13600.00
0005432458973	4693	Economy	13600.00
0005432566626	4693	Economy	13600.00
0005432186807	4693	Economy	13600.00
0005432459000	4693	Economy	13600.00
0005432566635	4693	Economy	13600.00
0005432566598	4693	Economy	13600.00
0005432458995	4693	Economy	13600.00
0005434081518	4693	Economy	13600.00
0005432170277	4693	Economy	13600.00
0005432458980	4693	Economy	13600.00
0005432566596	4693	Economy	13600.00
0005432459002	4693	Economy	13600.00
0005434081516	4693	Economy	13600.00
0005434081511	4693	Economy	13600.00
0005432213545	30541	Economy	15000.00
0005432161112	30541	Economy	13600.00
0005432161113	30541	Economy	13600.00
0005432213544	30541	Economy	13600.00
0005432213543	30541	Economy	15000.00
0005435720802	13628	Economy	9900.00
0005435722014	13628	Economy	9900.00
0005435722015	13628	Economy	9900.00
0005435722016	13628	Economy	9900.00
0005435720801	13628	Economy	9900.00
0005432295836	22802	Economy	8800.00
0005432295835	22802	Economy	8800.00
0005432295837	22802	Economy	8800.00
0005433341495	11081	Business	23600.00
0005433341548	11081	Business	23600.00
0005433341574	11081	Business	23600.00
0005433341525	11081	Business	23600.00
0005433341517	11081	Business	23600.00
0005433341533	11081	Business	23600.00
0005433341581	11081	Business	23600.00
0005433341572	11081	Business	23600.00
0005433341513	11081	Business	23600.00
0005433341531	11081	Business	23600.00
0005433341481	11081	Economy	7900.00
0005433341577	11081	Economy	7900.00
0005433341563	11081	Economy	7900.00
0005433341567	11081	Economy	7900.00
0005433341491	11081	Economy	7900.00
0005435097048	11081	Economy	7900.00
0005433341524	11081	Economy	7900.00
0005433341504	11081	Economy	7900.00
0005433341506	11081	Economy	7900.00
0005433341550	11081	Economy	7900.00
0005433341562	11081	Economy	7900.00
0005433341514	11081	Economy	7900.00
0005433341579	11081	Economy	7900.00
0005433341509	11081	Economy	7900.00
0005433341560	11081	Economy	7900.00
0005433341536	11081	Economy	7900.00
0005433341553	11081	Economy	7900.00
0005433341490	11081	Economy	7900.00
0005433341489	11081	Economy	7900.00
0005433341571	11081	Economy	7900.00
0005433341498	11081	Economy	7900.00
0005433341527	11081	Economy	7900.00
0005433341512	11081	Economy	7900.00
0005433341578	11081	Economy	7900.00
0005433341557	11081	Economy	7900.00
0005433341558	11081	Economy	7900.00
0005433341552	11081	Economy	7900.00
0005433341486	11081	Economy	7900.00
0005433341484	11081	Economy	7900.00
0005433341582	11081	Economy	7900.00
0005433341541	11081	Economy	7900.00
0005433341519	11081	Economy	7900.00
0005433341521	11081	Economy	7900.00
0005433341493	11081	Economy	7900.00
0005433341522	11081	Economy	7900.00
0005433341544	11081	Economy	8600.00
0005433341503	11081	Economy	8600.00
0005433341573	11081	Economy	8600.00
0005435097047	11081	Economy	8600.00
0005433341576	11081	Economy	8600.00
0005433341540	11081	Economy	8600.00
0005433341494	11081	Economy	7900.00
0005433341500	11081	Economy	7900.00
0005433341580	11081	Economy	7900.00
0005433341520	11081	Economy	7900.00
0005433341492	11081	Economy	7900.00
0005433341559	11081	Economy	7900.00
0005433341499	11081	Economy	7900.00
0005433341508	11081	Economy	7900.00
0005433341561	11081	Economy	7900.00
0005433341488	11081	Economy	7900.00
0005433341556	11081	Economy	7900.00
0005433341555	11081	Economy	7900.00
0005433341543	11081	Economy	7900.00
0005433341538	11081	Economy	7900.00
0005435097050	11081	Economy	7900.00
0005433341542	11081	Economy	7900.00
0005433341554	11081	Economy	7900.00
0005433341507	11081	Economy	7900.00
0005435097046	11081	Economy	7900.00
0005435097045	11081	Economy	7900.00
0005433341529	11081	Economy	7900.00
0005433341569	11081	Economy	7900.00
0005433341568	11081	Economy	7900.00
0005433341565	11081	Economy	7900.00
0005435097044	11081	Economy	7900.00
0005433341570	11081	Economy	7900.00
0005433341487	11081	Economy	7900.00
0005433341482	11081	Economy	7900.00
0005433341547	11081	Economy	7900.00
0005433341535	11081	Economy	7900.00
0005435097051	11081	Economy	7900.00
0005433341505	11081	Economy	7900.00
0005433341511	11081	Economy	7900.00
0005433341480	11081	Economy	7900.00
0005433341501	11081	Economy	7900.00
0005433341549	11081	Economy	7900.00
0005433341516	11081	Economy	7900.00
0005433341532	11081	Economy	7900.00
0005433341539	11081	Economy	7900.00
0005433341510	11081	Economy	7900.00
0005433341545	11081	Economy	7900.00
0005433341534	11081	Economy	7900.00
0005433341564	11081	Economy	7900.00
0005433341537	11081	Economy	7900.00
0005433341485	11081	Economy	7900.00
0005433341546	11081	Economy	7900.00
0005433341502	11081	Economy	7900.00
0005433341551	11081	Economy	7900.00
0005433341530	11081	Economy	7900.00
0005433341496	11081	Economy	7900.00
0005433341526	11081	Economy	7900.00
0005433341497	11081	Economy	7900.00
0005433341518	11081	Economy	7900.00
0005435097049	11081	Economy	7900.00
0005433341523	11081	Economy	7900.00
0005433341515	11081	Economy	7900.00
0005435097043	11081	Economy	7900.00
0005433341483	11081	Economy	7900.00
0005433341566	11081	Economy	7900.00
0005433341528	11081	Economy	7900.00
0005433341575	11081	Economy	7900.00
0005432293168	17128	Economy	7900.00
0005432293166	17128	Economy	7900.00
0005432293167	17128	Economy	7900.00
0005433481037	9088	Business	26600.00
0005433506872	9088	Business	26600.00
0005433506888	9088	Business	26600.00
0005433481041	9088	Economy	8900.00
0005433506883	9088	Economy	8900.00
0005433506877	9088	Economy	8900.00
0005433506889	9088	Economy	9800.00
0005433506880	9088	Economy	8900.00
0005433506879	9088	Economy	8900.00
0005433506881	9088	Economy	8900.00
0005433506887	9088	Economy	8900.00
0005433481042	9088	Economy	8900.00
0005433506885	9088	Economy	8900.00
0005433481043	9088	Economy	8900.00
0005433506874	9088	Economy	8900.00
0005433506884	9088	Economy	8900.00
0005433506882	9088	Economy	8900.00
0005433481038	9088	Economy	8900.00
0005433481039	9088	Economy	8900.00
0005433481035	9088	Economy	8900.00
0005433481036	9088	Economy	8900.00
0005433506875	9088	Economy	8900.00
0005433481040	9088	Economy	8900.00
0005433506890	9088	Economy	8900.00
0005433506886	9088	Economy	8900.00
0005433506876	9088	Economy	8900.00
0005433506878	9088	Economy	8900.00
0005433506873	9088	Economy	8900.00
0005432919527	20483	Business	26600.00
0005432919528	20483	Business	26600.00
0005432919537	20483	Economy	8900.00
0005432919529	20483	Economy	8900.00
0005432919534	20483	Economy	9800.00
0005432919530	20483	Economy	9800.00
0005432919525	20483	Economy	8900.00
0005432919539	20483	Economy	8900.00
0005432919531	20483	Economy	8900.00
0005432919536	20483	Economy	8900.00
0005432919542	20483	Economy	8900.00
0005432919544	20483	Economy	8900.00
0005432919543	20483	Economy	8900.00
0005432919535	20483	Economy	8900.00
0005432919533	20483	Economy	8900.00
0005432919540	20483	Economy	8900.00
0005432919541	20483	Economy	8900.00
0005432919532	20483	Economy	8900.00
0005432919526	20483	Economy	8900.00
0005432919545	20483	Economy	8900.00
0005432919538	20483	Economy	8900.00
0005432396173	10149	Economy	5800.00
0005432394034	10149	Economy	5800.00
0005432396172	10149	Economy	5800.00
0005432394032	10149	Economy	5800.00
0005432396174	10149	Economy	5800.00
0005432394033	10149	Economy	5800.00
0005432394035	10149	Economy	5800.00
0005432396171	10149	Economy	5800.00
0005432396170	10149	Economy	5800.00
0005435179687	18337	Economy	5800.00
0005435179686	18337	Economy	5800.00
0005434928253	10991	Business	9500.00
0005434411708	10991	Business	9500.00
0005434928252	10991	Economy	3200.00
0005434411707	10991	Economy	3200.00
0005434411705	10991	Economy	3200.00
0005434411706	10991	Economy	3200.00
0005434411709	10991	Economy	3200.00
0005435125694	14692	Business	9500.00
0005435125716	14692	Business	9500.00
0005435125697	14692	Business	9500.00
0005435125706	14692	Business	9500.00
0005435625880	14692	Business	9500.00
0005435125714	14692	Business	9500.00
0005435554106	14692	Business	9500.00
0005435625887	14692	Business	9500.00
0005435554103	14692	Economy	3200.00
0005435125712	14692	Economy	3200.00
0005435125707	14692	Economy	3200.00
0005435125727	14692	Economy	3200.00
0005435625898	14692	Economy	3200.00
0005435125726	14692	Economy	3200.00
0005435625894	14692	Economy	3200.00
0005435625883	14692	Economy	3200.00
0005435625892	14692	Economy	3500.00
0005435625896	14692	Economy	3500.00
0005435554104	14692	Economy	3500.00
0005435125724	14692	Economy	3500.00
0005435125703	14692	Economy	3200.00
0005435125723	14692	Economy	3200.00
0005435125713	14692	Economy	3200.00
0005435125690	14692	Economy	3200.00
0005435125728	14692	Economy	3200.00
0005435625882	14692	Economy	3200.00
0005435125709	14692	Economy	3200.00
0005435125704	14692	Economy	3200.00
0005435556650	14692	Economy	3200.00
0005435554107	14692	Economy	3200.00
0005435125725	14692	Economy	3200.00
0005435125692	14692	Economy	3200.00
0005435125711	14692	Economy	3200.00
0005435125699	14692	Economy	3200.00
0005435125715	14692	Economy	3200.00
0005435125721	14692	Economy	3200.00
0005435125718	14692	Economy	3200.00
0005435125702	14692	Economy	3200.00
0005435125691	14692	Economy	3200.00
0005435125705	14692	Economy	3200.00
0005435625888	14692	Economy	3200.00
0005435625899	14692	Economy	3200.00
0005435625881	14692	Economy	3200.00
0005435125729	14692	Economy	3200.00
0005435625890	14692	Economy	3200.00
0005435625886	14692	Economy	3200.00
0005435625889	14692	Economy	3200.00
0005435625891	14692	Economy	3200.00
0005435125689	14692	Economy	3200.00
0005435125695	14692	Economy	3200.00
0005435125710	14692	Economy	3200.00
0005435125696	14692	Economy	3200.00
0005435125700	14692	Economy	3200.00
0005435125698	14692	Economy	3200.00
0005435625897	14692	Economy	3200.00
0005435125701	14692	Economy	3200.00
0005435125717	14692	Economy	3200.00
0005435125693	14692	Economy	3200.00
0005435625895	14692	Economy	3200.00
0005435554105	14692	Economy	3200.00
0005435125722	14692	Economy	3200.00
0005435125720	14692	Economy	3200.00
0005435625885	14692	Economy	3200.00
0005435625884	14692	Economy	3200.00
0005435125719	14692	Economy	3200.00
0005435625893	14692	Economy	3200.00
0005435125708	14692	Economy	3200.00
0005435715178	7144	Business	86900.00
0005435715177	7144	Business	86900.00
0005435715182	7144	Economy	29000.00
0005432400063	7144	Economy	29000.00
0005435715193	7144	Economy	29000.00
0005435715181	7144	Economy	29000.00
0005435715192	7144	Economy	29000.00
0005435715185	7144	Economy	29000.00
0005432400061	7144	Economy	29000.00
0005435715187	7144	Economy	29000.00
0005435715189	7144	Economy	29000.00
0005432400064	7144	Economy	29000.00
0005432398132	7144	Economy	29000.00
0005432400062	7144	Economy	29000.00
0005432398134	7144	Economy	29000.00
0005435715183	7144	Economy	29000.00
0005432398133	7144	Economy	29000.00
0005435715191	7144	Economy	29000.00
0005435715179	7144	Economy	29000.00
0005435715180	7144	Economy	29000.00
0005435715190	7144	Economy	29000.00
0005432398135	7144	Economy	29000.00
0005435715186	7144	Economy	29000.00
0005435715188	7144	Economy	29000.00
0005435715184	7144	Economy	29000.00
0005435443154	27074	Business	86900.00
0005435443158	27074	Economy	29000.00
0005435216553	27074	Economy	31900.00
0005435217676	27074	Economy	29000.00
0005435443153	27074	Economy	29000.00
0005435443161	27074	Economy	29000.00
0005435217678	27074	Economy	29000.00
0005435218099	27074	Economy	29000.00
0005435216554	27074	Economy	29000.00
0005435443160	27074	Economy	29000.00
0005435443157	27074	Economy	29000.00
0005435443156	27074	Economy	29000.00
0005435443159	27074	Economy	29000.00
0005435217677	27074	Economy	29000.00
0005435443155	27074	Economy	29000.00
0005435443162	27074	Economy	29000.00
0005434084856	2758	Economy	7700.00
0005434084854	2758	Economy	7700.00
0005434084855	2758	Economy	7700.00
0005434084853	2758	Economy	7700.00
0005434084857	2758	Economy	7700.00
0005433060369	28478	Economy	7700.00
0005433060368	28478	Economy	7700.00
0005433788147	11165	Economy	24600.00
0005433788141	11165	Economy	24600.00
0005433788140	11165	Economy	24600.00
0005433788144	11165	Economy	24600.00
0005433788145	11165	Economy	24600.00
0005433788143	11165	Economy	24600.00
0005433788148	11165	Economy	24600.00
0005433788142	11165	Economy	24600.00
0005433788146	11165	Economy	24600.00
0005435528891	22263	Business	20200.00
0005435528885	22263	Business	20200.00
0005435540631	22263	Business	20200.00
0005432294445	22263	Business	20200.00
0005435528892	22263	Business	20200.00
0005435540626	22263	Economy	6700.00
0005435528879	22263	Economy	6700.00
0005435528886	22263	Economy	6700.00
0005435540639	22263	Economy	6700.00
0005435540627	22263	Economy	7400.00
0005435540643	22263	Economy	7400.00
0005435528893	22263	Economy	6700.00
0005435540632	22263	Economy	6700.00
0005435528887	22263	Economy	6700.00
0005435528889	22263	Economy	6700.00
0005435528895	22263	Economy	6700.00
0005435540642	22263	Economy	6700.00
0005435540634	22263	Economy	6700.00
0005432294446	22263	Economy	6700.00
0005435540630	22263	Economy	6700.00
0005435540623	22263	Economy	6700.00
0005435528898	22263	Economy	6700.00
0005435540635	22263	Economy	6700.00
0005435540641	22263	Economy	6700.00
0005435528896	22263	Economy	6700.00
0005435528888	22263	Economy	6700.00
0005435528899	22263	Economy	6700.00
0005435540633	22263	Economy	6700.00
0005435540624	22263	Economy	6700.00
0005435528900	22263	Economy	6700.00
0005435528897	22263	Economy	6700.00
0005435528894	22263	Economy	6700.00
0005435528880	22263	Economy	6700.00
0005435540637	22263	Economy	6700.00
0005435540640	22263	Economy	6700.00
0005435540628	22263	Economy	6700.00
0005435528890	22263	Economy	6700.00
0005435540622	22263	Economy	6700.00
0005435528884	22263	Economy	6700.00
0005435540625	22263	Economy	6700.00
0005435528882	22263	Economy	6700.00
0005435528883	22263	Economy	6700.00
0005435540636	22263	Economy	6700.00
0005435540638	22263	Economy	6700.00
0005435528881	22263	Economy	6700.00
0005435540629	22263	Economy	6700.00
0005434906415	2299	Business	20200.00
0005434906442	2299	Business	20200.00
0005434906444	2299	Business	20200.00
0005434906435	2299	Business	20200.00
0005434906441	2299	Economy	6700.00
0005434906452	2299	Economy	6700.00
0005434906426	2299	Economy	6700.00
0005434906422	2299	Economy	6700.00
0005434906407	2299	Economy	7400.00
0005434906419	2299	Economy	6700.00
0005434906418	2299	Economy	6700.00
0005434906421	2299	Economy	6700.00
0005434906433	2299	Economy	6700.00
0005434906453	2299	Economy	6700.00
0005434906454	2299	Economy	6700.00
0005434906431	2299	Economy	6700.00
0005434906438	2299	Economy	6700.00
0005434906416	2299	Economy	6700.00
0005434906429	2299	Economy	6700.00
0005434906430	2299	Economy	6700.00
0005434906448	2299	Economy	6700.00
0005434906436	2299	Economy	6700.00
0005434906434	2299	Economy	6700.00
0005434906449	2299	Economy	6700.00
0005434906425	2299	Economy	6700.00
0005434906451	2299	Economy	6700.00
0005434906412	2299	Economy	6700.00
0005434906445	2299	Economy	6700.00
0005434906450	2299	Economy	6700.00
0005434906409	2299	Economy	6700.00
0005434906408	2299	Economy	6700.00
0005434906440	2299	Economy	6700.00
0005434906428	2299	Economy	6700.00
0005434906423	2299	Economy	6700.00
0005434906420	2299	Economy	6700.00
0005434906437	2299	Economy	6700.00
0005434906410	2299	Economy	6700.00
0005434906411	2299	Economy	6700.00
0005434906413	2299	Economy	6700.00
0005434906443	2299	Economy	6700.00
0005434906439	2299	Economy	6700.00
0005434906446	2299	Economy	6700.00
0005434906432	2299	Economy	6700.00
0005434906447	2299	Economy	6700.00
0005434906427	2299	Economy	6700.00
0005434906424	2299	Economy	6700.00
0005434906455	2299	Economy	6700.00
0005434906414	2299	Economy	6700.00
0005434906417	2299	Economy	6700.00
0005433250959	25619	Business	20200.00
0005433250984	25619	Business	20200.00
0005433400933	25619	Business	20200.00
0005433250981	25619	Business	20200.00
0005433400934	25619	Economy	6700.00
0005433250965	25619	Economy	6700.00
0005433250983	25619	Economy	6700.00
0005433250979	25619	Economy	7400.00
0005433250985	25619	Economy	7400.00
0005433250988	25619	Economy	7400.00
0005433250972	25619	Economy	6700.00
0005433250962	25619	Economy	6700.00
0005433250982	25619	Economy	6700.00
0005433250976	25619	Economy	6700.00
0005433250966	25619	Economy	6700.00
0005433250973	25619	Economy	6700.00
0005433250967	25619	Economy	6700.00
0005433250975	25619	Economy	6700.00
0005433250971	25619	Economy	6700.00
0005433250986	25619	Economy	6700.00
0005433250968	25619	Economy	6700.00
0005433250961	25619	Economy	6700.00
0005433250970	25619	Economy	6700.00
0005433250964	25619	Economy	6700.00
0005433250969	25619	Economy	6700.00
0005433250977	25619	Economy	6700.00
0005433250963	25619	Economy	6700.00
0005433250960	25619	Economy	6700.00
0005433250974	25619	Economy	6700.00
0005433250987	25619	Economy	6700.00
0005433250978	25619	Economy	6700.00
0005433250989	25619	Economy	6700.00
0005433250980	25619	Economy	6700.00
0005432620809	2540	Economy	13600.00
0005432620801	2540	Economy	12400.00
0005432620807	2540	Economy	12400.00
0005432620808	2540	Economy	12400.00
0005432620804	2540	Economy	12400.00
0005432620812	2540	Economy	12400.00
0005432620802	2540	Economy	12400.00
0005432620805	2540	Economy	12400.00
0005432620803	2540	Economy	12400.00
0005432620806	2540	Economy	12400.00
0005432620810	2540	Economy	12400.00
0005432620811	2540	Economy	12400.00
0005432620814	2540	Economy	12400.00
0005432620813	2540	Economy	12400.00
0005432862170	28089	Economy	12400.00
0005432862172	28089	Economy	12400.00
0005432862177	28089	Economy	12400.00
0005432862178	28089	Economy	12400.00
0005432862176	28089	Economy	12400.00
0005432862173	28089	Economy	12400.00
0005432862171	28089	Economy	12400.00
0005432862174	28089	Economy	12400.00
0005432862175	28089	Economy	12400.00
0005434097451	13104	Economy	11300.00
0005434097450	13104	Economy	11300.00
0005433452704	31011	Economy	8400.00
0005433451584	31011	Economy	8400.00
0005433451585	31011	Economy	8400.00
0005433452705	31011	Economy	8400.00
0005433451586	31011	Economy	8400.00
0005434183547	29840	Economy	7200.00
0005433131633	29840	Economy	6600.00
0005433134060	29840	Economy	6600.00
0005433131630	29840	Economy	6600.00
0005434184632	29840	Economy	6600.00
0005433131634	29840	Economy	6600.00
0005433134064	29840	Economy	6600.00
0005433134062	29840	Economy	6600.00
0005433134063	29840	Economy	6600.00
0005434142542	29840	Economy	6600.00
0005433134061	29840	Economy	6600.00
0005434142543	29840	Economy	6600.00
0005434142540	29840	Economy	6600.00
0005434184631	29840	Economy	6600.00
0005433131631	29840	Economy	6600.00
0005433131632	29840	Economy	6600.00
0005434142541	29840	Economy	6600.00
0005435696869	16466	Economy	19900.00
0005435696849	16466	Economy	19900.00
0005435696843	16466	Economy	19900.00
0005435696863	16466	Economy	18100.00
0005435696871	16466	Economy	18100.00
0005435696848	16466	Economy	18100.00
0005435696853	16466	Economy	18100.00
0005435696852	16466	Economy	18100.00
0005435696857	16466	Economy	18100.00
0005435696844	16466	Economy	18100.00
0005435696854	16466	Economy	18100.00
0005435696861	16466	Economy	18100.00
0005435696860	16466	Economy	18100.00
0005435696862	16466	Economy	18100.00
0005435696851	16466	Economy	18100.00
0005435696845	16466	Economy	18100.00
0005435696847	16466	Economy	18100.00
0005435696866	16466	Economy	18100.00
0005435696850	16466	Economy	18100.00
0005435696867	16466	Economy	18100.00
0005435696868	16466	Economy	18100.00
0005435696859	16466	Economy	18100.00
0005435696846	16466	Economy	18100.00
0005435696858	16466	Economy	18100.00
0005435696870	16466	Economy	18100.00
0005435696855	16466	Economy	18100.00
0005435696865	16466	Economy	18100.00
0005435696864	16466	Economy	18100.00
0005435696856	16466	Economy	18100.00
0005435934996	24731	Economy	18100.00
0005435934997	24731	Economy	18100.00
0005435934998	24731	Economy	18100.00
0005433724725	18809	Economy	4400.00
0005433724724	18809	Economy	4400.00
0005433724726	18809	Economy	4400.00
0005433724727	18809	Economy	4400.00
0005432968804	21605	Economy	4400.00
0005432968805	21605	Economy	4400.00
0005434136785	7295	Business	23100.00
0005434136810	7295	Business	23100.00
0005434136774	7295	Business	23100.00
0005434087435	7295	Business	23100.00
0005434136775	7295	Business	23100.00
0005434136811	7295	Business	23100.00
0005434136790	7295	Business	23100.00
0005434136820	7295	Business	23100.00
0005434136788	7295	Business	23100.00
0005434136791	7295	Business	23100.00
0005434136762	7295	Business	23100.00
0005434136822	7295	Economy	7700.00
0005434136841	7295	Economy	7700.00
0005434136805	7295	Economy	7700.00
0005434136839	7295	Economy	7700.00
0005434136800	7295	Economy	7700.00
0005434087432	7295	Economy	7700.00
0005434136836	7295	Economy	7700.00
0005434136797	7295	Economy	7700.00
0005434136783	7295	Economy	7700.00
0005434136803	7295	Economy	7700.00
0005434136781	7295	Economy	8500.00
0005434136763	7295	Economy	8500.00
0005434136840	7295	Economy	8500.00
0005434136779	7295	Economy	8500.00
0005434136838	7295	Economy	8500.00
0005434136782	7295	Economy	7700.00
0005434136802	7295	Economy	7700.00
0005434136787	7295	Economy	7700.00
0005434136776	7295	Economy	7700.00
0005434136829	7295	Economy	7700.00
0005434136826	7295	Economy	7700.00
0005434136834	7295	Economy	7700.00
0005434136817	7295	Economy	7700.00
0005434136765	7295	Economy	7700.00
0005434136798	7295	Economy	7700.00
0005434136830	7295	Economy	7700.00
0005434136770	7295	Economy	7700.00
0005434087431	7295	Economy	7700.00
0005434136784	7295	Economy	7700.00
0005434087433	7295	Economy	7700.00
0005434136760	7295	Economy	7700.00
0005434136804	7295	Economy	7700.00
0005434136833	7295	Economy	7700.00
0005434136799	7295	Economy	7700.00
0005434136825	7295	Economy	7700.00
0005434136835	7295	Economy	7700.00
0005434136761	7295	Economy	7700.00
0005434087434	7295	Economy	7700.00
0005434136843	7295	Economy	7700.00
0005434136831	7295	Economy	7700.00
0005434136771	7295	Economy	7700.00
0005434136778	7295	Economy	7700.00
0005434136777	7295	Economy	7700.00
0005434136844	7295	Economy	7700.00
0005434136789	7295	Economy	7700.00
0005434136786	7295	Economy	7700.00
0005434136809	7295	Economy	7700.00
0005434136837	7295	Economy	7700.00
0005434136842	7295	Economy	7700.00
0005434136769	7295	Economy	7700.00
0005434136808	7295	Economy	7700.00
0005434136773	7295	Economy	7700.00
0005434136792	7295	Economy	7700.00
0005434136795	7295	Economy	7700.00
0005434136821	7295	Economy	7700.00
0005434136806	7295	Economy	7700.00
0005434136796	7295	Economy	7700.00
0005434136814	7295	Economy	7700.00
0005434136812	7295	Economy	7700.00
0005434136780	7295	Economy	7700.00
0005434136815	7295	Economy	7700.00
0005434136764	7295	Economy	7700.00
0005434136772	7295	Economy	7700.00
0005434136807	7295	Economy	7700.00
0005434136824	7295	Economy	7700.00
0005434136827	7295	Economy	7700.00
0005434136768	7295	Economy	7700.00
0005434136828	7295	Economy	7700.00
0005434136823	7295	Economy	7700.00
0005434136793	7295	Economy	7700.00
0005434136818	7295	Economy	7700.00
0005434136813	7295	Economy	7700.00
0005434136816	7295	Economy	7700.00
0005434136819	7295	Economy	7700.00
0005434136832	7295	Economy	7700.00
0005434136766	7295	Economy	7700.00
0005434136767	7295	Economy	7700.00
0005434136801	7295	Economy	7700.00
0005434136794	7295	Economy	7700.00
0005435808070	1904	Economy	23900.00
0005435808065	1904	Economy	23900.00
0005435808061	1904	Economy	21700.00
0005434610169	1904	Economy	21700.00
0005434610170	1904	Economy	21700.00
0005435808067	1904	Economy	21700.00
0005435808062	1904	Economy	21700.00
0005435808068	1904	Economy	21700.00
0005435808060	1904	Economy	21700.00
0005435808064	1904	Economy	21700.00
0005435808063	1904	Economy	21700.00
0005435808066	1904	Economy	21700.00
0005434610168	1904	Economy	21700.00
0005435808069	1904	Economy	21700.00
0005433407480	23062	Economy	23900.00
0005433407481	23062	Economy	21700.00
0005433407478	23062	Economy	21700.00
0005433407479	23062	Economy	21700.00
0005433407477	23062	Economy	21700.00
0005434503460	22907	Economy	7600.00
0005434503461	22907	Economy	7600.00
0005434503463	22907	Economy	6900.00
0005434503476	22907	Economy	6900.00
0005434503475	22907	Economy	6900.00
0005434503485	22907	Economy	6900.00
0005434503491	22907	Economy	6900.00
0005434503473	22907	Economy	6900.00
0005434503458	22907	Economy	6900.00
0005434503474	22907	Economy	6900.00
0005434503492	22907	Economy	6900.00
0005434503471	22907	Economy	6900.00
0005434503465	22907	Economy	6900.00
0005434503469	22907	Economy	6900.00
0005434503490	22907	Economy	6900.00
0005434503489	22907	Economy	6900.00
0005434503466	22907	Economy	6900.00
0005434503470	22907	Economy	6900.00
0005434503487	22907	Economy	6900.00
0005434503494	22907	Economy	6900.00
0005434503477	22907	Economy	6900.00
0005434503480	22907	Economy	6900.00
0005434503488	22907	Economy	6900.00
0005434503495	22907	Economy	6900.00
0005434503464	22907	Economy	6900.00
0005434503459	22907	Economy	6900.00
0005434503478	22907	Economy	6900.00
0005434503482	22907	Economy	6900.00
0005434503493	22907	Economy	6900.00
0005434503462	22907	Economy	6900.00
0005434503479	22907	Economy	6900.00
0005434503484	22907	Economy	6900.00
0005434503481	22907	Economy	6900.00
0005434503496	22907	Economy	6900.00
0005434503486	22907	Economy	6900.00
0005434503468	22907	Economy	6900.00
0005434503483	22907	Economy	6900.00
0005434503467	22907	Economy	6900.00
0005434503472	22907	Economy	6900.00
0005435078080	2196	Economy	7700.00
0005435078090	2196	Economy	7700.00
0005435078095	2196	Economy	7000.00
0005435078093	2196	Economy	7000.00
0005435078091	2196	Economy	7000.00
0005435078085	2196	Economy	7000.00
0005435078082	2196	Economy	7000.00
0005435078087	2196	Economy	7000.00
0005435078089	2196	Economy	7000.00
0005435078094	2196	Economy	7000.00
0005435078081	2196	Economy	7000.00
0005435078088	2196	Economy	7000.00
0005435078084	2196	Economy	7000.00
0005435078086	2196	Economy	7000.00
0005435078092	2196	Economy	7000.00
0005435078083	2196	Economy	7000.00
0005433266571	24332	Economy	7000.00
0005433266569	24332	Economy	7000.00
0005433266568	24332	Economy	7000.00
0005433266573	24332	Economy	7000.00
0005433266570	24332	Economy	7000.00
0005433266574	24332	Economy	7000.00
0005433266567	24332	Economy	7000.00
0005433266572	24332	Economy	7000.00
0005435803215	6651	Economy	10800.00
0005434988567	6651	Economy	10800.00
0005434988569	6651	Economy	9800.00
0005434988570	6651	Economy	9800.00
0005435803216	6651	Economy	9800.00
0005435803217	6651	Economy	9800.00
0005434988565	6651	Economy	9800.00
0005434988566	6651	Economy	9800.00
0005435803214	6651	Economy	9800.00
0005434988568	6651	Economy	9800.00
0005435464474	23613	Economy	9800.00
0005435464475	23613	Economy	9800.00
0005435464476	23613	Economy	9800.00
0005432382530	30510	Business	9900.00
0005433449620	30510	Business	9900.00
0005432382553	30510	Business	9900.00
0005432382555	30510	Business	9900.00
0005432382538	30510	Business	9900.00
0005432382533	30510	Business	9900.00
0005432382546	30510	Business	9900.00
0005432382524	30510	Business	9900.00
0005433449609	30510	Business	9900.00
0005432382540	30510	Business	9900.00
0005433449616	30510	Economy	3300.00
0005432382549	30510	Economy	3300.00
0005433449624	30510	Economy	3300.00
0005432382531	30510	Economy	3300.00
0005433454840	30510	Economy	3300.00
0005432382536	30510	Economy	3300.00
0005433449618	30510	Economy	3600.00
0005433449623	30510	Economy	3600.00
0005432382537	30510	Economy	3600.00
0005432382529	30510	Economy	3300.00
0005433449606	30510	Economy	3300.00
0005432382528	30510	Economy	3300.00
0005433449627	30510	Economy	3300.00
0005433449619	30510	Economy	3300.00
0005432382556	30510	Economy	3300.00
0005432382522	30510	Economy	3300.00
0005432382559	30510	Economy	3300.00
0005432382558	30510	Economy	3300.00
0005432382535	30510	Economy	3300.00
0005432382547	30510	Economy	3300.00
0005432382552	30510	Economy	3300.00
0005433453728	30510	Economy	3300.00
0005433449617	30510	Economy	3300.00
0005433449615	30510	Economy	3300.00
0005432382548	30510	Economy	3300.00
0005433449611	30510	Economy	3300.00
0005432382544	30510	Economy	3300.00
0005432382563	30510	Economy	3300.00
0005433449607	30510	Economy	3300.00
0005432382554	30510	Economy	3300.00
0005432382562	30510	Economy	3300.00
0005432382532	30510	Economy	3300.00
0005433449614	30510	Economy	3300.00
0005432382526	30510	Economy	3300.00
0005432382521	30510	Economy	3300.00
0005432382545	30510	Economy	3300.00
0005432382542	30510	Economy	3300.00
0005432382525	30510	Economy	3300.00
0005432382539	30510	Economy	3300.00
0005432382551	30510	Economy	3300.00
0005433449622	30510	Economy	3300.00
0005433449612	30510	Economy	3300.00
0005432382541	30510	Economy	3300.00
0005432382543	30510	Economy	3300.00
0005432382561	30510	Economy	3300.00
0005433454839	30510	Economy	3300.00
0005433449621	30510	Economy	3300.00
0005433449626	30510	Economy	3300.00
0005433449610	30510	Economy	3300.00
0005432382560	30510	Economy	3300.00
0005432382534	30510	Economy	3300.00
0005432382523	30510	Economy	3300.00
0005433453729	30510	Economy	3300.00
0005433449613	30510	Economy	3300.00
0005433449625	30510	Economy	3300.00
0005432382550	30510	Economy	3300.00
0005432382527	30510	Economy	3300.00
0005432382557	30510	Economy	3300.00
0005433449608	30510	Economy	3300.00
0005435302129	29702	Economy	17100.00
0005435302125	29702	Economy	17100.00
0005433129205	29702	Economy	15600.00
0005435302128	29702	Economy	15600.00
0005435299701	29702	Economy	15600.00
0005435302124	29702	Economy	15600.00
0005433126775	29702	Economy	15600.00
0005433129203	29702	Economy	15600.00
0005433126774	29702	Economy	15600.00
0005433126772	29702	Economy	15600.00
0005435299702	29702	Economy	15600.00
0005433126776	29702	Economy	15600.00
0005433126773	29702	Economy	15600.00
0005433129204	29702	Economy	15600.00
0005433129206	29702	Economy	15600.00
0005435302126	29702	Economy	15600.00
0005435299700	29702	Economy	15600.00
0005433129202	29702	Economy	15600.00
0005435302127	29702	Economy	15600.00
0005435299704	29702	Economy	15600.00
0005435299703	29702	Economy	15600.00
0005434286931	2406	Economy	17200.00
0005434286932	2406	Economy	17200.00
0005434286916	2406	Economy	15700.00
0005434286930	2406	Economy	15700.00
0005434286919	2406	Economy	15700.00
0005434286923	2406	Economy	15700.00
0005434286926	2406	Economy	15700.00
0005434286928	2406	Economy	15700.00
0005434286934	2406	Economy	15700.00
0005434286922	2406	Economy	15700.00
0005434286929	2406	Economy	15700.00
0005434286937	2406	Economy	15700.00
0005434286927	2406	Economy	15700.00
0005434286924	2406	Economy	15700.00
0005434286917	2406	Economy	15700.00
0005434286920	2406	Economy	15700.00
0005434286935	2406	Economy	15700.00
0005434286915	2406	Economy	15700.00
0005434286933	2406	Economy	15700.00
0005434286918	2406	Economy	15700.00
0005432264435	2406	Economy	15700.00
0005432264434	2406	Economy	15700.00
0005434286925	2406	Economy	15700.00
0005434286921	2406	Economy	15700.00
0005434286936	2406	Economy	15700.00
0005433109858	26820	Economy	17200.00
0005433109859	26820	Economy	17200.00
0005433109857	26820	Economy	15700.00
0005433109861	26820	Economy	15700.00
0005433109849	26820	Economy	15700.00
0005433109854	26820	Economy	15700.00
0005433109860	26820	Economy	15700.00
0005433109855	26820	Economy	15700.00
0005433109852	26820	Economy	15700.00
0005433109856	26820	Economy	15700.00
0005433109851	26820	Economy	15700.00
0005433109850	26820	Economy	15700.00
0005433109853	26820	Economy	15700.00
0005435856135	25466	Economy	22800.00
0005435856136	25466	Economy	22800.00
0005435856134	25466	Economy	22800.00
0005435856137	25466	Economy	22800.00
0005434273049	26634	Economy	25000.00
0005434272163	26634	Economy	22800.00
0005434272164	26634	Economy	22800.00
0005434273048	26634	Economy	22800.00
0005433867779	4766	Economy	19400.00
0005433867789	4766	Economy	19400.00
0005433867770	4766	Economy	19400.00
0005433867803	4766	Economy	17600.00
0005433867798	4766	Economy	17600.00
0005433867780	4766	Economy	17600.00
0005433867792	4766	Economy	17600.00
0005433867786	4766	Economy	17600.00
0005433867802	4766	Economy	17600.00
0005433867791	4766	Economy	17600.00
0005433867777	4766	Economy	17600.00
0005433867805	4766	Economy	17600.00
0005433867771	4766	Economy	17600.00
0005433867776	4766	Economy	17600.00
0005433867782	4766	Economy	17600.00
0005433867794	4766	Economy	17600.00
0005433867808	4766	Economy	17600.00
0005433867804	4766	Economy	17600.00
0005433867797	4766	Economy	17600.00
0005433867774	4766	Economy	17600.00
0005433867795	4766	Economy	17600.00
0005433867809	4766	Economy	17600.00
0005433867801	4766	Economy	17600.00
0005433867775	4766	Economy	17600.00
0005433867788	4766	Economy	17600.00
0005433867781	4766	Economy	17600.00
0005433867800	4766	Economy	17600.00
0005433867787	4766	Economy	17600.00
0005433867773	4766	Economy	17600.00
0005433867810	4766	Economy	17600.00
0005433867793	4766	Economy	17600.00
0005433867799	4766	Economy	17600.00
0005433867806	4766	Economy	17600.00
0005433867785	4766	Economy	17600.00
0005433867807	4766	Economy	17600.00
0005433867790	4766	Economy	17600.00
0005433867772	4766	Economy	17600.00
0005433867784	4766	Economy	17600.00
0005433867796	4766	Economy	17600.00
0005433867778	4766	Economy	17600.00
0005433867783	4766	Economy	17600.00
0005435860432	32564	Economy	17600.00
0005435860433	32564	Economy	17600.00
0005434663181	3447	Economy	24800.00
0005434460470	3447	Economy	22600.00
0005434663191	3447	Economy	22600.00
0005434663192	3447	Economy	22600.00
0005434460469	3447	Economy	22600.00
0005434461612	3447	Economy	22600.00
0005434663189	3447	Economy	22600.00
0005434663182	3447	Economy	22600.00
0005434663179	3447	Economy	22600.00
0005434663190	3447	Economy	22600.00
0005434663188	3447	Economy	22600.00
0005434461611	3447	Economy	22600.00
0005434663184	3447	Economy	22600.00
0005434663185	3447	Economy	22600.00
0005434663186	3447	Economy	22600.00
0005434663183	3447	Economy	22600.00
0005434663180	3447	Economy	22600.00
0005434663187	3447	Economy	22600.00
0005435911330	12464	Economy	22600.00
0005435911323	12464	Economy	22600.00
0005435911327	12464	Economy	22600.00
0005435911324	12464	Economy	22600.00
0005435911325	12464	Economy	22600.00
0005435911328	12464	Economy	22600.00
0005435911326	12464	Economy	22600.00
0005435911329	12464	Economy	22600.00
0005435860432	14525	Economy	18500.00
0005435860433	14525	Economy	16800.00
0005433867738	32643	Economy	18500.00
0005433867768	32643	Economy	18500.00
0005433867743	32643	Economy	18500.00
0005433867746	32643	Economy	16800.00
0005433867766	32643	Economy	16800.00
0005433867736	32643	Economy	16800.00
0005433867728	32643	Economy	16800.00
0005433867752	32643	Economy	16800.00
0005433867734	32643	Economy	16800.00
0005433867735	32643	Economy	16800.00
0005433867762	32643	Economy	16800.00
0005433867732	32643	Economy	16800.00
0005433867730	32643	Economy	16800.00
0005433867755	32643	Economy	16800.00
0005433867764	32643	Economy	16800.00
0005433867729	32643	Economy	16800.00
0005433867760	32643	Economy	16800.00
0005433867741	32643	Economy	16800.00
0005433867745	32643	Economy	16800.00
0005433867767	32643	Economy	16800.00
0005433867757	32643	Economy	16800.00
0005433867759	32643	Economy	16800.00
0005433867727	32643	Economy	16800.00
0005433867740	32643	Economy	16800.00
0005433867750	32643	Economy	16800.00
0005433867733	32643	Economy	16800.00
0005433867758	32643	Economy	16800.00
0005433867747	32643	Economy	16800.00
0005433867731	32643	Economy	16800.00
0005433867742	32643	Economy	16800.00
0005433867753	32643	Economy	16800.00
0005433867761	32643	Economy	16800.00
0005433867744	32643	Economy	16800.00
0005433867739	32643	Economy	16800.00
0005433867749	32643	Economy	16800.00
0005433867765	32643	Economy	16800.00
0005433867763	32643	Economy	16800.00
0005433867748	32643	Economy	16800.00
0005433867756	32643	Economy	16800.00
0005433867737	32643	Economy	16800.00
0005433867754	32643	Economy	16800.00
0005433867751	32643	Economy	16800.00
0005433867769	32643	Economy	16800.00
0005432798965	14823	Economy	4900.00
0005432798978	14823	Economy	4900.00
0005432798976	14823	Economy	4900.00
0005432798962	14823	Economy	4400.00
0005432798953	14823	Economy	4400.00
0005432798955	14823	Economy	4400.00
0005432798961	14823	Economy	4400.00
0005432798966	14823	Economy	4400.00
0005432798977	14823	Economy	4400.00
0005432798979	14823	Economy	4400.00
0005432798974	14823	Economy	4400.00
0005432798981	14823	Economy	4400.00
0005432798963	14823	Economy	4400.00
0005432798957	14823	Economy	4400.00
0005432798956	14823	Economy	4400.00
0005432798954	14823	Economy	4400.00
0005432798959	14823	Economy	4400.00
0005432798967	14823	Economy	4400.00
0005432798958	14823	Economy	4400.00
0005432798970	14823	Economy	4400.00
0005432798980	14823	Economy	4400.00
0005432798964	14823	Economy	4400.00
0005432798969	14823	Economy	4400.00
0005432798972	14823	Economy	4400.00
0005432798975	14823	Economy	4400.00
0005432798973	14823	Economy	4400.00
0005432798968	14823	Economy	4400.00
0005432798982	14823	Economy	4400.00
0005432798960	14823	Economy	4400.00
0005432798971	14823	Economy	4400.00
0005434406728	7054	Business	49100.00
0005434299189	7054	Business	49100.00
0005434299186	7054	Business	49100.00
0005434406722	7054	Business	49100.00
0005434299173	7054	Business	49100.00
0005434406711	7054	Business	49100.00
0005434406746	7054	Business	49100.00
0005434406704	7054	Business	49100.00
0005434406705	7054	Business	49100.00
0005434299180	7054	Economy	16400.00
0005434406712	7054	Economy	16400.00
0005434299174	7054	Economy	16400.00
0005434406714	7054	Economy	16400.00
0005434299191	7054	Economy	16400.00
0005434406747	7054	Economy	16400.00
0005434406732	7054	Economy	16400.00
0005434299182	7054	Economy	16400.00
0005434406718	7054	Economy	16400.00
0005434406723	7054	Economy	16400.00
0005434406717	7054	Economy	16400.00
0005434406757	7054	Economy	16400.00
0005434406743	7054	Economy	16400.00
0005434406708	7054	Economy	16400.00
0005434406725	7054	Economy	16400.00
0005434299193	7054	Economy	16400.00
0005434406751	7054	Economy	16400.00
0005434406734	7054	Economy	16400.00
0005434406730	7054	Economy	16400.00
0005432153823	7054	Economy	16400.00
0005434299188	7054	Economy	16400.00
0005434406706	7054	Economy	16400.00
0005434299183	7054	Economy	16400.00
0005434299181	7054	Economy	16400.00
0005432153825	7054	Economy	16400.00
0005434406764	7054	Economy	16400.00
0005434406748	7054	Economy	16400.00
0005432153820	7054	Economy	16400.00
0005432153821	7054	Economy	16400.00
0005434406719	7054	Economy	16400.00
0005434406758	7054	Economy	16400.00
0005434406727	7054	Economy	16400.00
0005434406749	7054	Economy	16400.00
0005434406709	7054	Economy	18000.00
0005434406702	7054	Economy	18000.00
0005434406760	7054	Economy	18000.00
0005432153827	7054	Economy	18000.00
0005434406753	7054	Economy	18000.00
0005434406741	7054	Economy	16400.00
0005434406745	7054	Economy	16400.00
0005434406713	7054	Economy	16400.00
0005434299176	7054	Economy	16400.00
0005434406716	7054	Economy	16400.00
0005434406715	7054	Economy	16400.00
0005434406763	7054	Economy	16400.00
0005434406703	7054	Economy	16400.00
0005434299190	7054	Economy	16400.00
0005434406724	7054	Economy	16400.00
0005434299187	7054	Economy	16400.00
0005432153826	7054	Economy	16400.00
0005434406710	7054	Economy	16400.00
0005434406729	7054	Economy	16400.00
0005434406736	7054	Economy	16400.00
0005434299179	7054	Economy	16400.00
0005434406721	7054	Economy	16400.00
0005434406752	7054	Economy	16400.00
0005434406742	7054	Economy	16400.00
0005434406759	7054	Economy	16400.00
0005434406755	7054	Economy	16400.00
0005434406726	7054	Economy	16400.00
0005434299185	7054	Economy	16400.00
0005434406735	7054	Economy	16400.00
0005432153822	7054	Economy	16400.00
0005434406740	7054	Economy	16400.00
0005434406750	7054	Economy	16400.00
0005432108208	7054	Economy	16400.00
0005432108207	7054	Economy	16400.00
0005434406761	7054	Economy	16400.00
0005434406733	7054	Economy	16400.00
0005434406744	7054	Economy	16400.00
0005434406707	7054	Economy	16400.00
0005434299172	7054	Economy	16400.00
0005434299175	7054	Economy	16400.00
0005434299177	7054	Economy	16400.00
0005434406762	7054	Economy	16400.00
0005434406737	7054	Economy	16400.00
0005434299184	7054	Economy	16400.00
0005434299170	7054	Economy	16400.00
0005434299192	7054	Economy	16400.00
0005434406739	7054	Economy	16400.00
0005434406720	7054	Economy	16400.00
0005434406756	7054	Economy	16400.00
0005434406738	7054	Economy	16400.00
0005434299178	7054	Economy	16400.00
0005434299171	7054	Economy	16400.00
0005434406754	7054	Economy	16400.00
0005434406731	7054	Economy	16400.00
0005432153824	7054	Economy	16400.00
0005435310843	26926	Business	49100.00
0005435310839	26926	Business	49100.00
0005435310841	26926	Economy	16400.00
0005435293064	26926	Economy	16400.00
0005435310836	26926	Economy	16400.00
0005435310851	26926	Economy	16400.00
0005435310855	26926	Economy	16400.00
0005435293067	26926	Economy	16400.00
0005435293065	26926	Economy	16400.00
0005435310842	26926	Economy	16400.00
0005435293069	26926	Economy	16400.00
0005435310844	26926	Economy	16400.00
0005435293061	26926	Economy	16400.00
0005435310849	26926	Economy	16400.00
0005435310845	26926	Economy	16400.00
0005432058312	26926	Economy	18000.00
0005435293068	26926	Economy	16400.00
0005432058315	26926	Economy	16400.00
0005435310838	26926	Economy	16400.00
0005435293058	26926	Economy	16400.00
0005435293063	26926	Economy	16400.00
0005432058314	26926	Economy	16400.00
0005435310840	26926	Economy	16400.00
0005435310850	26926	Economy	16400.00
0005435310847	26926	Economy	16400.00
0005435310854	26926	Economy	16400.00
0005435293066	26926	Economy	16400.00
0005435293060	26926	Economy	16400.00
0005435293059	26926	Economy	16400.00
0005435310848	26926	Economy	16400.00
0005432058313	26926	Economy	16400.00
0005435310846	26926	Economy	16400.00
0005435293057	26926	Economy	16400.00
0005435310853	26926	Economy	16400.00
0005435293070	26926	Economy	16400.00
0005435310837	26926	Economy	16400.00
0005435310852	26926	Economy	16400.00
0005435293062	26926	Economy	16400.00
0005432603722	6465	Economy	16500.00
0005432603700	6465	Economy	16500.00
0005432603705	6465	Economy	16500.00
0005432603707	6465	Economy	16500.00
0005432603683	6465	Economy	15000.00
0005432603711	6465	Economy	15000.00
0005432603718	6465	Economy	15000.00
0005432603690	6465	Economy	15000.00
0005432603701	6465	Economy	15000.00
0005432603704	6465	Economy	15000.00
0005432603708	6465	Economy	15000.00
0005432603697	6465	Economy	15000.00
0005432603685	6465	Economy	15000.00
0005432603682	6465	Economy	15000.00
0005432603703	6465	Economy	15000.00
0005432603713	6465	Economy	15000.00
0005434512026	6465	Economy	15000.00
0005432603696	6465	Economy	15000.00
0005434512023	6465	Economy	15000.00
0005432603714	6465	Economy	15000.00
0005432603687	6465	Economy	15000.00
0005434512022	6465	Economy	15000.00
0005432603695	6465	Economy	15000.00
0005432603684	6465	Economy	15000.00
0005434512027	6465	Economy	15000.00
0005432603709	6465	Economy	15000.00
0005432603719	6465	Economy	15000.00
0005434512024	6465	Economy	15000.00
0005432603694	6465	Economy	15000.00
0005432603689	6465	Economy	15000.00
0005432603699	6465	Economy	15000.00
0005432603698	6465	Economy	15000.00
0005432603712	6465	Economy	15000.00
0005432603702	6465	Economy	15000.00
0005434512025	6465	Economy	15000.00
0005432603716	6465	Economy	15000.00
0005432603691	6465	Economy	15000.00
0005432603693	6465	Economy	15000.00
0005432603706	6465	Economy	15000.00
0005432603686	6465	Economy	15000.00
0005432603721	6465	Economy	15000.00
0005432603688	6465	Economy	15000.00
0005432603715	6465	Economy	15000.00
0005432603717	6465	Economy	15000.00
0005432603710	6465	Economy	15000.00
0005432603692	6465	Economy	15000.00
0005432603720	6465	Economy	15000.00
0005433250989	15002	Business	18900.00
0005433250985	15002	Business	18900.00
0005433250988	15002	Business	18900.00
0005433250968	15002	Economy	6300.00
0005433250979	15002	Economy	6300.00
0005433250972	15002	Economy	6300.00
0005433250959	15002	Economy	6900.00
0005433250961	15002	Economy	6900.00
0005433250962	15002	Economy	6900.00
0005433250981	15002	Economy	6300.00
0005433250974	15002	Economy	6300.00
0005433250965	15002	Economy	6300.00
0005433250983	15002	Economy	6300.00
0005433250987	15002	Economy	6300.00
0005433250971	15002	Economy	6300.00
0005433250967	15002	Economy	6300.00
0005433250966	15002	Economy	6300.00
0005433250980	15002	Economy	6300.00
0005433250970	15002	Economy	6300.00
0005433250963	15002	Economy	6300.00
0005433250978	15002	Economy	6300.00
0005433250975	15002	Economy	6300.00
0005433250984	15002	Economy	6300.00
0005433250977	15002	Economy	6300.00
0005433250969	15002	Economy	6300.00
0005433250964	15002	Economy	6300.00
0005433250982	15002	Economy	6300.00
0005433250986	15002	Economy	6300.00
0005433250973	15002	Economy	6300.00
0005433250960	15002	Economy	6300.00
0005433250976	15002	Economy	6300.00
0005434906406	25859	Business	18900.00
0005434906388	25859	Business	18900.00
0005434906405	25859	Business	18900.00
0005434906368	25859	Business	18900.00
0005434906400	25859	Economy	6300.00
0005434906379	25859	Economy	6300.00
0005434906404	25859	Economy	6300.00
0005434906364	25859	Economy	6300.00
0005434906362	25859	Economy	6300.00
0005434906371	25859	Economy	6300.00
0005434906375	25859	Economy	6300.00
0005434906384	25859	Economy	6900.00
0005434906395	25859	Economy	6900.00
0005434906365	25859	Economy	6300.00
0005434906396	25859	Economy	6300.00
0005434906392	25859	Economy	6300.00
0005434906398	25859	Economy	6300.00
0005434906391	25859	Economy	6300.00
0005434906370	25859	Economy	6300.00
0005434906360	25859	Economy	6300.00
0005434906381	25859	Economy	6300.00
0005434906377	25859	Economy	6300.00
0005434906374	25859	Economy	6300.00
0005434906401	25859	Economy	6300.00
0005434906389	25859	Economy	6300.00
0005434906403	25859	Economy	6300.00
0005434906393	25859	Economy	6300.00
0005434906394	25859	Economy	6300.00
0005434906359	25859	Economy	6300.00
0005434906397	25859	Economy	6300.00
0005434906361	25859	Economy	6300.00
0005434906367	25859	Economy	6300.00
0005434906383	25859	Economy	6300.00
0005434906373	25859	Economy	6300.00
0005434906385	25859	Economy	6300.00
0005434906402	25859	Economy	6300.00
0005434906376	25859	Economy	6300.00
0005434906366	25859	Economy	6300.00
0005434906380	25859	Economy	6300.00
0005434906378	25859	Economy	6300.00
0005434906390	25859	Economy	6300.00
0005434906387	25859	Economy	6300.00
0005434906363	25859	Economy	6300.00
0005434906369	25859	Economy	6300.00
0005434906382	25859	Economy	6300.00
0005434906386	25859	Economy	6300.00
0005434906399	25859	Economy	6300.00
0005434906372	25859	Economy	6300.00
0005433007874	14193	Business	52300.00
0005433007882	14193	Business	52300.00
0005433007890	14193	Business	52300.00
0005433007898	14193	Economy	17400.00
0005433007868	14193	Economy	17400.00
0005433007907	14193	Economy	17400.00
0005433007908	14193	Economy	17400.00
0005433007900	14193	Economy	17400.00
0005433007881	14193	Economy	19200.00
0005433007871	14193	Economy	19200.00
0005433007897	14193	Economy	17400.00
0005433007885	14193	Economy	17400.00
0005433007893	14193	Economy	17400.00
0005433007892	14193	Economy	17400.00
0005433007910	14193	Economy	17400.00
0005433007878	14193	Economy	17400.00
0005433007894	14193	Economy	17400.00
0005433007903	14193	Economy	17400.00
0005433007872	14193	Economy	17400.00
0005433007895	14193	Economy	17400.00
0005433007880	14193	Economy	17400.00
0005433007886	14193	Economy	17400.00
0005433007914	14193	Economy	17400.00
0005433007887	14193	Economy	17400.00
0005433007902	14193	Economy	17400.00
0005433007905	14193	Economy	17400.00
0005433007901	14193	Economy	17400.00
0005433007889	14193	Economy	17400.00
0005433007873	14193	Economy	17400.00
0005433007883	14193	Economy	17400.00
0005433007870	14193	Economy	17400.00
0005433007884	14193	Economy	17400.00
0005433007869	14193	Economy	17400.00
0005433007913	14193	Economy	17400.00
0005433007904	14193	Economy	17400.00
0005433007906	14193	Economy	17400.00
0005433007879	14193	Economy	17400.00
0005433007912	14193	Economy	17400.00
0005433007877	14193	Economy	17400.00
0005433007875	14193	Economy	17400.00
0005433007909	14193	Economy	17400.00
0005433007896	14193	Economy	17400.00
0005433007876	14193	Economy	17400.00
0005433007888	14193	Economy	17400.00
0005433007891	14193	Economy	17400.00
0005433007899	14193	Economy	17400.00
0005433007911	14193	Economy	17400.00
0005433810489	22824	Business	52300.00
0005433810491	22824	Economy	19200.00
0005433810490	22824	Economy	17400.00
0005433810488	22824	Economy	17400.00
0005435718828	15523	Business	85200.00
0005435718829	15523	Business	85200.00
0005435718830	15523	Economy	28400.00
0005435718827	15523	Economy	28400.00
0005435718831	15523	Economy	28400.00
0005434925265	20535	Business	22900.00
0005434925247	20535	Business	22900.00
0005434925272	20535	Business	22900.00
0005434925269	20535	Business	22900.00
0005434925259	20535	Economy	7600.00
0005434925270	20535	Economy	7600.00
0005434925261	20535	Economy	7600.00
0005434925256	20535	Economy	7600.00
0005434925268	20535	Economy	8400.00
0005434925258	20535	Economy	8400.00
0005434925267	20535	Economy	7600.00
0005434925264	20535	Economy	7600.00
0005434925253	20535	Economy	7600.00
0005434925266	20535	Economy	7600.00
0005434925262	20535	Economy	7600.00
0005434925257	20535	Economy	7600.00
0005434925251	20535	Economy	7600.00
0005434925263	20535	Economy	7600.00
0005434925260	20535	Economy	7600.00
0005434925254	20535	Economy	7600.00
0005434925252	20535	Economy	7600.00
0005434925249	20535	Economy	7600.00
0005434925248	20535	Economy	7600.00
0005434925255	20535	Economy	7600.00
0005434925250	20535	Economy	7600.00
0005434925271	20535	Economy	7600.00
0005435487479	15793	Economy	8900.00
0005435487494	15793	Economy	8100.00
0005435487478	15793	Economy	8100.00
0005435487482	15793	Economy	8100.00
0005435487484	15793	Economy	8100.00
0005435487485	15793	Economy	8100.00
0005435487481	15793	Economy	8100.00
0005435487480	15793	Economy	8100.00
0005435487486	15793	Economy	8100.00
0005435487477	15793	Economy	8100.00
0005435487475	15793	Economy	8100.00
0005435487489	15793	Economy	8100.00
0005435487491	15793	Economy	8100.00
0005435487496	15793	Economy	8100.00
0005435487490	15793	Economy	8100.00
0005435487476	15793	Economy	8100.00
0005435487492	15793	Economy	8100.00
0005435487497	15793	Economy	8100.00
0005435487487	15793	Economy	8100.00
0005435487495	15793	Economy	8100.00
0005435487483	15793	Economy	8100.00
0005435487493	15793	Economy	8100.00
0005435487488	15793	Economy	8100.00
0005435998959	19673	Economy	8900.00
0005435998954	19673	Economy	8900.00
0005435998955	19673	Economy	8100.00
0005435998965	19673	Economy	8100.00
0005435998963	19673	Economy	8100.00
0005435998961	19673	Economy	8100.00
0005435998960	19673	Economy	8100.00
0005435998962	19673	Economy	8100.00
0005435998964	19673	Economy	8100.00
0005435998957	19673	Economy	8100.00
0005435998952	19673	Economy	8100.00
0005435998951	19673	Economy	8100.00
0005435998958	19673	Economy	8100.00
0005435998967	19673	Economy	8100.00
0005435998953	19673	Economy	8100.00
0005435998956	19673	Economy	8100.00
0005435998966	19673	Economy	8100.00
0005435838991	5984	Business	199300.00
0005435839013	5984	Business	199300.00
0005432660786	5984	Business	199300.00
0005432660785	5984	Business	199300.00
0005435838993	5984	Business	199300.00
0005435838988	5984	Business	199300.00
0005435838989	5984	Business	199300.00
0005435839011	5984	Business	199300.00
0005435838995	5984	Economy	66400.00
0005435839004	5984	Economy	66400.00
0005435838996	5984	Economy	66400.00
0005435839008	5984	Economy	66400.00
0005435838987	5984	Economy	66400.00
0005435839000	5984	Economy	66400.00
0005432658559	5984	Economy	66400.00
0005435839001	5984	Economy	66400.00
0005432659674	5984	Economy	66400.00
0005432660784	5984	Economy	66400.00
0005435838990	5984	Economy	66400.00
0005435839007	5984	Economy	66400.00
0005432658558	5984	Economy	66400.00
0005435838998	5984	Economy	66400.00
0005435838994	5984	Economy	66400.00
0005435839002	5984	Economy	66400.00
0005435838986	5984	Economy	66400.00
0005435839014	5984	Economy	66400.00
0005432660787	5984	Economy	66400.00
0005435839010	5984	Economy	66400.00
0005435839003	5984	Economy	66400.00
0005435838999	5984	Economy	66400.00
0005435839009	5984	Economy	66400.00
0005435838997	5984	Economy	66400.00
0005435839006	5984	Economy	66400.00
0005435838992	5984	Economy	66400.00
0005432659673	5984	Economy	66400.00
0005435839012	5984	Economy	66400.00
0005432142202	5984	Economy	66400.00
0005435839005	5984	Economy	66400.00
0005435472543	18086	Business	199300.00
0005435472536	18086	Business	199300.00
0005435472539	18086	Economy	73100.00
0005435472531	18086	Economy	73100.00
0005435472535	18086	Economy	66400.00
0005435472530	18086	Economy	66400.00
0005435472532	18086	Economy	66400.00
0005435472541	18086	Economy	66400.00
0005435472529	18086	Economy	66400.00
0005435472537	18086	Economy	66400.00
0005435472544	18086	Economy	66400.00
0005432537023	18086	Economy	66400.00
0005432537024	18086	Economy	66400.00
0005435472534	18086	Economy	66400.00
0005435472540	18086	Economy	66400.00
0005435472538	18086	Economy	66400.00
0005435472542	18086	Economy	66400.00
0005435472533	18086	Economy	66400.00
0005435103796	23047	Business	15700.00
0005435103798	23047	Business	15700.00
0005435103801	23047	Business	15700.00
0005435103799	23047	Economy	5200.00
0005435103797	23047	Economy	5200.00
0005435103793	23047	Economy	5200.00
0005435103803	23047	Economy	5200.00
0005435103802	23047	Economy	5200.00
0005435103794	23047	Economy	5200.00
0005435103795	23047	Economy	5200.00
0005435103800	23047	Economy	5200.00
0005433284805	32049	Business	15700.00
0005433284811	32049	Business	15700.00
0005433284800	32049	Business	15700.00
0005433284817	32049	Economy	5200.00
0005433284795	32049	Economy	5200.00
0005433284814	32049	Economy	5200.00
0005433284801	32049	Economy	5200.00
0005433284816	32049	Economy	5200.00
0005433284806	32049	Economy	5200.00
0005433284802	32049	Economy	5200.00
0005433284812	32049	Economy	5200.00
0005433284813	32049	Economy	5200.00
0005433284807	32049	Economy	5200.00
0005433284820	32049	Economy	5200.00
0005433284798	32049	Economy	5200.00
0005433284796	32049	Economy	5700.00
0005433284804	32049	Economy	5200.00
0005433284797	32049	Economy	5200.00
0005433284803	32049	Economy	5200.00
0005433284810	32049	Economy	5200.00
0005433284819	32049	Economy	5200.00
0005433284808	32049	Economy	5200.00
0005433284799	32049	Economy	5200.00
0005433284815	32049	Economy	5200.00
0005433284809	32049	Economy	5200.00
0005433284818	32049	Economy	5200.00
0005432802433	1478	Business	150400.00
0005432802430	1478	Economy	50100.00
0005432802432	1478	Economy	50100.00
0005432802429	1478	Economy	50100.00
0005432802434	1478	Economy	50100.00
0005432802431	1478	Economy	50100.00
0005432802435	1478	Economy	50100.00
0005435852529	23856	Economy	12300.00
0005435852528	23856	Economy	12300.00
0005435852530	23856	Economy	12300.00
0005435852532	23856	Economy	12300.00
0005435852533	23856	Economy	12300.00
0005435852526	23856	Economy	12300.00
0005435852525	23856	Economy	12300.00
0005435852527	23856	Economy	12300.00
0005435852531	23856	Economy	12300.00
0005435212498	30585	Business	42100.00
0005432211384	30585	Business	42100.00
0005435212468	30585	Business	42100.00
0005435212476	30585	Business	42100.00
0005435212501	30585	Business	42100.00
0005435212519	30585	Business	42100.00
0005435212482	30585	Business	42100.00
0005435212473	30585	Comfort	23900.00
0005432159785	30585	Comfort	23900.00
0005435212485	30585	Comfort	23900.00
0005435725523	30585	Comfort	23900.00
0005435212520	30585	Comfort	23900.00
0005435725525	30585	Comfort	23900.00
0005435212495	30585	Comfort	23900.00
0005435212504	30585	Comfort	23900.00
0005435212507	30585	Comfort	23900.00
0005432211383	30585	Comfort	23900.00
0005432211385	30585	Comfort	23900.00
0005435212516	30585	Comfort	23900.00
0005435212472	30585	Comfort	23900.00
0005435212523	30585	Comfort	23900.00
0005435725524	30585	Comfort	23900.00
0005435212503	30585	Economy	14000.00
0005435212496	30585	Economy	14000.00
0005435212497	30585	Economy	14000.00
0005435212502	30585	Economy	14000.00
0005435212494	30585	Economy	14000.00
0005435212470	30585	Economy	14000.00
0005435212530	30585	Economy	14000.00
0005435212489	30585	Economy	14000.00
0005435212514	30585	Economy	14000.00
0005435212499	30585	Economy	14000.00
0005435212500	30585	Economy	14000.00
0005435212481	30585	Economy	14000.00
0005435212521	30585	Economy	14000.00
0005433656618	30585	Economy	14000.00
0005435212491	30585	Economy	15400.00
0005435725522	30585	Economy	14000.00
0005435212526	30585	Economy	15400.00
0005435212510	30585	Economy	15400.00
0005435212512	30585	Economy	14000.00
0005432211388	30585	Economy	14000.00
0005435212487	30585	Economy	14000.00
0005435212480	30585	Economy	14000.00
0005433656619	30585	Economy	14000.00
0005432211382	30585	Economy	14000.00
0005432159786	30585	Economy	14000.00
0005435212492	30585	Economy	14000.00
0005435212467	30585	Economy	14000.00
0005435212531	30585	Economy	14000.00
0005435212532	30585	Economy	14000.00
0005435630920	30585	Economy	14000.00
0005435212505	30585	Economy	14000.00
0005435212478	30585	Economy	14000.00
0005435725526	30585	Economy	14000.00
0005435212483	30585	Economy	14000.00
0005435212477	30585	Economy	14000.00
0005435212534	30585	Economy	14000.00
0005435212479	30585	Economy	14000.00
0005435212513	30585	Economy	14000.00
0005435212471	30585	Economy	14000.00
0005435212490	30585	Economy	14000.00
0005435212469	30585	Economy	14000.00
0005432211386	30585	Economy	14000.00
0005432159784	30585	Economy	14000.00
0005435212509	30585	Economy	14000.00
0005435212533	30585	Economy	15400.00
0005435212508	30585	Economy	15400.00
0005435212528	30585	Economy	15400.00
0005435212524	30585	Economy	14000.00
0005435630919	30585	Economy	14000.00
0005435725521	30585	Economy	14000.00
0005435212511	30585	Economy	14000.00
0005435212522	30585	Economy	14000.00
0005432211381	30585	Economy	14000.00
0005435212517	30585	Economy	14000.00
0005435212493	30585	Economy	14000.00
0005432159787	30585	Economy	14000.00
0005435212474	30585	Economy	14000.00
0005435212488	30585	Economy	14000.00
0005435212486	30585	Economy	14000.00
0005435212515	30585	Economy	14000.00
0005435630922	30585	Economy	14000.00
0005433656620	30585	Economy	14000.00
0005435212475	30585	Economy	14000.00
0005432211387	30585	Economy	14000.00
0005435212525	30585	Economy	14000.00
0005435212484	30585	Economy	14000.00
0005435212527	30585	Economy	14000.00
0005435212506	30585	Economy	14000.00
0005435212535	30585	Economy	14000.00
0005435630921	30585	Economy	14000.00
0005435212529	30585	Economy	14000.00
0005435212518	30585	Economy	14000.00
0005433367304	24816	Business	9800.00
0005433367329	24816	Business	9800.00
0005433367328	24816	Business	9800.00
0005433367312	24816	Economy	3300.00
0005433367315	24816	Economy	3300.00
0005433367300	24816	Economy	3300.00
0005433367317	24816	Economy	3300.00
0005433367314	24816	Economy	3300.00
0005433367301	24816	Economy	3300.00
0005433367326	24816	Economy	3300.00
0005433367320	24816	Economy	3600.00
0005433367309	24816	Economy	3600.00
0005433367324	24816	Economy	3300.00
0005433367299	24816	Economy	3300.00
0005433367321	24816	Economy	3300.00
0005433367316	24816	Economy	3300.00
0005433367305	24816	Economy	3300.00
0005433367331	24816	Economy	3300.00
0005433367330	24816	Economy	3300.00
0005433367307	24816	Economy	3300.00
0005433367313	24816	Economy	3300.00
0005433367297	24816	Economy	3300.00
0005433367303	24816	Economy	3300.00
0005433367295	24816	Economy	3300.00
0005433367318	24816	Economy	3300.00
0005433367308	24816	Economy	3300.00
0005433367319	24816	Economy	3300.00
0005433367323	24816	Economy	3300.00
0005433367332	24816	Economy	3300.00
0005433367310	24816	Economy	3300.00
0005433367306	24816	Economy	3300.00
0005433367296	24816	Economy	3300.00
0005433367325	24816	Economy	3300.00
0005433367298	24816	Economy	3300.00
0005433367322	24816	Economy	3300.00
0005433367311	24816	Economy	3300.00
0005433367302	24816	Economy	3300.00
0005433367327	24816	Economy	3300.00
0005434979340	2019	Economy	10500.00
0005434979325	2019	Economy	9500.00
0005434979330	2019	Economy	9500.00
0005434979317	2019	Economy	9500.00
0005434979342	2019	Economy	9500.00
0005434979315	2019	Economy	9500.00
0005434979334	2019	Economy	9500.00
0005434979319	2019	Economy	9500.00
0005435801650	2019	Economy	9500.00
0005434979320	2019	Economy	9500.00
0005434979314	2019	Economy	9500.00
0005434979339	2019	Economy	9500.00
0005434979322	2019	Economy	9500.00
0005434979318	2019	Economy	9500.00
0005434979338	2019	Economy	9500.00
0005434979326	2019	Economy	9500.00
0005434979324	2019	Economy	9500.00
0005434979333	2019	Economy	9500.00
0005434979323	2019	Economy	9500.00
0005434979336	2019	Economy	9500.00
0005435801649	2019	Economy	9500.00
0005434979321	2019	Economy	9500.00
0005434979329	2019	Economy	9500.00
0005434979328	2019	Economy	9500.00
0005434979341	2019	Economy	9500.00
0005434979316	2019	Economy	9500.00
0005434979332	2019	Economy	9500.00
0005434979327	2019	Economy	9500.00
0005434979337	2019	Economy	9500.00
0005434979335	2019	Economy	9500.00
0005434979343	2019	Economy	9500.00
0005435801648	2019	Economy	9500.00
0005434979344	2019	Economy	9500.00
0005434979331	2019	Economy	9500.00
0005434952474	2662	Economy	5300.00
0005434952471	2662	Economy	5300.00
0005434952472	2662	Economy	5300.00
0005434952473	2662	Economy	5300.00
0005433256387	28207	Economy	5300.00
0005433256386	28207	Economy	5300.00
0005433112351	19839	Economy	8700.00
0005433112352	19839	Economy	8700.00
0005433111472	19839	Economy	8700.00
0005433111473	19839	Economy	8700.00
0005434136781	28755	Business	9700.00
0005434136822	28755	Business	9700.00
0005434136785	28755	Business	9700.00
0005434136775	28755	Business	9700.00
0005434136799	28755	Business	9700.00
0005434136800	28755	Business	9700.00
0005434136844	28755	Business	9700.00
0005434136811	28755	Business	9700.00
0005434136810	28755	Business	9700.00
0005434136786	28755	Business	9700.00
0005434136790	28755	Business	9700.00
0005434136766	28755	Economy	3200.00
0005434136813	28755	Economy	3200.00
0005434136784	28755	Economy	3200.00
0005434136778	28755	Economy	3200.00
0005434136824	28755	Economy	3200.00
0005434136830	28755	Economy	3200.00
0005434136821	28755	Economy	3200.00
0005434136795	28755	Economy	3200.00
0005434136793	28755	Economy	3200.00
0005434136823	28755	Economy	3500.00
0005434136768	28755	Economy	3500.00
0005434136843	28755	Economy	3500.00
0005434136839	28755	Economy	3500.00
0005434136802	28755	Economy	3500.00
0005434136794	28755	Economy	3200.00
0005434136774	28755	Economy	3200.00
0005434136776	28755	Economy	3200.00
0005434136796	28755	Economy	3200.00
0005434136838	28755	Economy	3200.00
0005434136819	28755	Economy	3200.00
0005434136764	28755	Economy	3200.00
0005434136835	28755	Economy	3200.00
0005434136825	28755	Economy	3200.00
0005434136797	28755	Economy	3200.00
0005434136771	28755	Economy	3200.00
0005434136767	28755	Economy	3200.00
0005434136832	28755	Economy	3200.00
0005434136801	28755	Economy	3200.00
0005434136831	28755	Economy	3200.00
0005434136782	28755	Economy	3200.00
0005434136816	28755	Economy	3200.00
0005434136803	28755	Economy	3200.00
0005434136836	28755	Economy	3200.00
0005434136792	28755	Economy	3200.00
0005434136834	28755	Economy	3200.00
0005434136762	28755	Economy	3200.00
0005434136814	28755	Economy	3200.00
0005434136828	28755	Economy	3200.00
0005434136808	28755	Economy	3200.00
0005434136773	28755	Economy	3200.00
0005434136770	28755	Economy	3200.00
0005434136837	28755	Economy	3200.00
0005434136765	28755	Economy	3200.00
0005434136761	28755	Economy	3200.00
0005434136818	28755	Economy	3200.00
0005434136809	28755	Economy	3200.00
0005434136783	28755	Economy	3200.00
0005434136807	28755	Economy	3200.00
0005434136842	28755	Economy	3200.00
0005434136841	28755	Economy	3200.00
0005434136760	28755	Economy	3200.00
0005434136780	28755	Economy	3200.00
0005434136805	28755	Economy	3200.00
0005434136791	28755	Economy	3200.00
0005434136815	28755	Economy	3200.00
0005434136806	28755	Economy	3200.00
0005434136829	28755	Economy	3200.00
0005434136779	28755	Economy	3200.00
0005434136820	28755	Economy	3200.00
0005434136840	28755	Economy	3200.00
0005434136812	28755	Economy	3200.00
0005434136827	28755	Economy	3200.00
0005434136769	28755	Economy	3200.00
0005434136798	28755	Economy	3200.00
0005434136788	28755	Economy	3200.00
0005434136826	28755	Economy	3200.00
0005434136777	28755	Economy	3200.00
0005434136787	28755	Economy	3200.00
0005434136789	28755	Economy	3200.00
0005434136817	28755	Economy	3200.00
0005434136772	28755	Economy	3200.00
0005434136804	28755	Economy	3200.00
0005434136833	28755	Economy	3200.00
0005434136763	28755	Economy	3200.00
0005434466385	6571	Economy	20900.00
0005434466384	6571	Economy	20900.00
0005434466380	6571	Economy	20900.00
0005434466383	6571	Economy	20900.00
0005434466373	6571	Economy	20900.00
0005434466375	6571	Economy	20900.00
0005434466387	6571	Economy	20900.00
0005434466386	6571	Economy	20900.00
0005434466376	6571	Economy	20900.00
0005434466379	6571	Economy	20900.00
0005434466382	6571	Economy	20900.00
0005434466378	6571	Economy	20900.00
0005434466381	6571	Economy	20900.00
0005434466377	6571	Economy	20900.00
0005434466372	6571	Economy	20900.00
0005434466374	6571	Economy	20900.00
0005433534466	6781	Economy	9900.00
0005433538738	6781	Economy	9900.00
0005433538740	6781	Economy	9900.00
0005433538734	6781	Economy	9900.00
0005433534465	6781	Economy	9900.00
0005433538741	6781	Economy	9900.00
0005433534464	6781	Economy	9900.00
0005433538739	6781	Economy	9900.00
0005433538736	6781	Economy	9900.00
0005433538737	6781	Economy	9900.00
0005433538735	6781	Economy	9900.00
0005435259690	25036	Economy	9900.00
0005435259688	25036	Economy	9900.00
0005435259689	25036	Economy	9900.00
0005433511818	852	Economy	14600.00
0005433511824	852	Economy	14600.00
0005433511823	852	Economy	14600.00
0005433511825	852	Economy	14600.00
0005433511819	852	Economy	14600.00
0005433511820	852	Economy	14600.00
0005433511822	852	Economy	14600.00
0005433511821	852	Economy	14600.00
0005432922460	16155	Economy	14600.00
0005432922462	16155	Economy	14600.00
0005432922463	16155	Economy	14600.00
0005432922461	16155	Economy	14600.00
0005432922464	16155	Economy	14600.00
0005433475638	4026	Economy	13500.00
0005433475635	4026	Economy	12300.00
0005433475634	4026	Economy	12300.00
0005433475640	4026	Economy	12300.00
0005433475641	4026	Economy	12300.00
0005433475642	4026	Economy	12300.00
0005433475636	4026	Economy	12300.00
0005433475639	4026	Economy	12300.00
0005433475637	4026	Economy	12300.00
0005435696918	3686	Economy	7900.00
0005435696924	3686	Economy	7900.00
0005435696912	3686	Economy	7200.00
0005435696902	3686	Economy	7200.00
0005435696917	3686	Economy	7200.00
0005435696904	3686	Economy	7200.00
0005435696927	3686	Economy	7200.00
0005435696919	3686	Economy	7200.00
0005435696901	3686	Economy	7200.00
0005435696905	3686	Economy	7200.00
0005434950460	3686	Economy	7200.00
0005435696928	3686	Economy	7200.00
0005435696925	3686	Economy	7200.00
0005435696915	3686	Economy	7200.00
0005435696926	3686	Economy	7200.00
0005435696914	3686	Economy	7200.00
0005435696910	3686	Economy	7200.00
0005434950462	3686	Economy	7200.00
0005435696911	3686	Economy	7200.00
0005435696923	3686	Economy	7200.00
0005435696916	3686	Economy	7200.00
0005435696909	3686	Economy	7200.00
0005435696913	3686	Economy	7200.00
0005435696920	3686	Economy	7200.00
0005435696921	3686	Economy	7200.00
0005434950459	3686	Economy	7200.00
0005435696907	3686	Economy	7200.00
0005435696922	3686	Economy	7200.00
0005434950461	3686	Economy	7200.00
0005435696908	3686	Economy	7200.00
0005435696903	3686	Economy	7200.00
0005435696906	3686	Economy	7200.00
0005435934997	16282	Economy	7200.00
0005435916125	16282	Economy	7200.00
0005435916126	16282	Economy	7200.00
0005435934998	16282	Economy	7200.00
0005435916123	16282	Economy	7200.00
0005435916124	16282	Economy	7200.00
0005435934996	16282	Economy	7200.00
0005433519386	3948	Economy	21300.00
0005432607504	3948	Economy	21300.00
0005432609671	3948	Economy	21300.00
0005432607502	3948	Economy	19300.00
0005434606770	3948	Economy	19300.00
0005433519389	3948	Economy	19300.00
0005434606769	3948	Economy	19300.00
0005433519388	3948	Economy	19300.00
0005432609670	3948	Economy	19300.00
0005432607505	3948	Economy	19300.00
0005434606771	3948	Economy	19300.00
0005434604845	3948	Economy	19300.00
0005434606768	3948	Economy	19300.00
0005432609669	3948	Economy	19300.00
0005433519387	3948	Economy	19300.00
0005432609667	3948	Economy	19300.00
0005432609668	3948	Economy	19300.00
0005432607503	3948	Economy	19300.00
0005435853581	22043	Economy	21300.00
0005435853584	22043	Economy	19300.00
0005435853582	22043	Economy	19300.00
0005435853583	22043	Economy	19300.00
0005435628673	767	Economy	3700.00
0005435628675	767	Economy	3700.00
0005435628674	767	Economy	3700.00
0005435628676	767	Economy	3700.00
0005433348901	15913	Economy	3700.00
0005433348903	15913	Economy	3700.00
0005433348899	15913	Economy	3700.00
0005433348900	15913	Economy	3700.00
0005433348902	15913	Economy	3700.00
0005433348898	15913	Economy	3700.00
0005434446480	17216	Economy	7100.00
0005434446479	17216	Economy	7100.00
0005434446477	17216	Economy	7100.00
0005434446481	17216	Economy	7100.00
0005434445211	17216	Economy	7100.00
0005434446478	17216	Economy	7100.00
0005433159279	17681	Economy	7100.00
0005433159280	17681	Economy	7100.00
0005435132716	7894	Economy	5900.00
0005435132723	7894	Economy	5400.00
0005435132717	7894	Economy	5400.00
0005435132725	7894	Economy	5400.00
0005435132721	7894	Economy	5400.00
0005435132719	7894	Economy	5400.00
0005435132718	7894	Economy	5400.00
0005435132715	7894	Economy	5400.00
0005435132722	7894	Economy	5400.00
0005435132724	7894	Economy	5400.00
0005435132720	7894	Economy	5400.00
0005435383069	33110	Economy	5900.00
0005435383068	33110	Economy	5400.00
0005435383070	33110	Economy	5400.00
0005435383067	33110	Economy	5400.00
0005435160131	7530	Economy	13800.00
0005435160134	7530	Economy	13800.00
0005435160136	7530	Economy	12500.00
0005435160132	7530	Economy	12500.00
0005435160127	7530	Economy	12500.00
0005435160129	7530	Economy	12500.00
0005435160128	7530	Economy	12500.00
0005435160135	7530	Economy	12500.00
0005435160126	7530	Economy	12500.00
0005435160133	7530	Economy	12500.00
0005435160130	7530	Economy	12500.00
0005435390137	29568	Economy	12500.00
0005435390131	29568	Economy	12500.00
0005435390138	29568	Economy	12500.00
0005435390133	29568	Economy	12500.00
0005435390132	29568	Economy	12500.00
0005435390134	29568	Economy	12500.00
0005435390136	29568	Economy	12500.00
0005435390135	29568	Economy	12500.00
0005435178473	18443	Economy	4900.00
0005435178471	18443	Economy	4900.00
0005435178978	18443	Economy	4900.00
0005435178472	18443	Economy	4900.00
0005432400062	27181	Economy	4900.00
0005432398135	27181	Economy	4900.00
0005432400061	27181	Economy	4900.00
0005432400063	27181	Economy	4900.00
0005432398133	27181	Economy	4900.00
0005432398132	27181	Economy	4900.00
0005432400064	27181	Economy	4900.00
0005432398134	27181	Economy	4900.00
0005432638939	2243	Business	87300.00
0005432638937	2243	Business	87300.00
0005432638932	2243	Business	87300.00
0005432638929	2243	Economy	29100.00
0005432638923	2243	Economy	29100.00
0005432638922	2243	Economy	32000.00
0005432638943	2243	Economy	32000.00
0005432638936	2243	Economy	29100.00
0005432638917	2243	Economy	29100.00
0005432638948	2243	Economy	29100.00
0005432638934	2243	Economy	29100.00
0005432638925	2243	Economy	29100.00
0005432638924	2243	Economy	29100.00
0005432638947	2243	Economy	29100.00
0005432638926	2243	Economy	29100.00
0005432638919	2243	Economy	29100.00
0005432638928	2243	Economy	29100.00
0005432638951	2243	Economy	29100.00
0005432638949	2243	Economy	29100.00
0005432638935	2243	Economy	29100.00
0005432638933	2243	Economy	29100.00
0005432638941	2243	Economy	29100.00
0005432638945	2243	Economy	29100.00
0005432638942	2243	Economy	29100.00
0005432638920	2243	Economy	29100.00
0005432638944	2243	Economy	29100.00
0005432638938	2243	Economy	29100.00
0005432638915	2243	Economy	29100.00
0005432638930	2243	Economy	29100.00
0005432638921	2243	Economy	29100.00
0005432638927	2243	Economy	29100.00
0005432638918	2243	Economy	29100.00
0005432638950	2243	Economy	29100.00
0005432638952	2243	Economy	29100.00
0005432638916	2243	Economy	29100.00
0005432638931	2243	Economy	29100.00
0005432638940	2243	Economy	29100.00
0005432638946	2243	Economy	29100.00
0005434503566	6528	Business	48400.00
0005434503547	6528	Business	48400.00
0005434503553	6528	Business	48400.00
0005435103819	6528	Business	48400.00
0005434503560	6528	Business	48400.00
0005434503544	6528	Business	48400.00
0005434503540	6528	Economy	16100.00
0005434503549	6528	Economy	16100.00
0005434503557	6528	Economy	16100.00
0005434503568	6528	Economy	16100.00
0005434503565	6528	Economy	17800.00
0005434503552	6528	Economy	17800.00
0005434503548	6528	Economy	17800.00
0005434503563	6528	Economy	16100.00
0005434503550	6528	Economy	16100.00
0005434503562	6528	Economy	16100.00
0005434503554	6528	Economy	16100.00
0005434503564	6528	Economy	16100.00
0005434503556	6528	Economy	16100.00
0005434503573	6528	Economy	16100.00
0005434503569	6528	Economy	16100.00
0005434503541	6528	Economy	16100.00
0005434503555	6528	Economy	16100.00
0005434503574	6528	Economy	16100.00
0005434503542	6528	Economy	16100.00
0005434503559	6528	Economy	16100.00
0005435103820	6528	Economy	16100.00
0005434503571	6528	Economy	16100.00
0005434503558	6528	Economy	16100.00
0005434503567	6528	Economy	16100.00
0005434503570	6528	Economy	16100.00
0005434503546	6528	Economy	16100.00
0005434503537	6528	Economy	16100.00
0005434503572	6528	Economy	16100.00
0005434503545	6528	Economy	16100.00
0005434503576	6528	Economy	16100.00
0005434503575	6528	Economy	16100.00
0005434503551	6528	Economy	16100.00
0005435103822	6528	Economy	16100.00
0005434503539	6528	Economy	16100.00
0005435103823	6528	Economy	16100.00
0005434503543	6528	Economy	16100.00
0005435103821	6528	Economy	16100.00
0005434503577	6528	Economy	16100.00
0005435103824	6528	Economy	16100.00
0005434503538	6528	Economy	16100.00
0005434503561	6528	Economy	16100.00
0005435800080	6423	Economy	16800.00
0005435800079	6423	Economy	15300.00
0005435800077	6423	Economy	15300.00
0005435800081	6423	Economy	15300.00
0005435800078	6423	Economy	15300.00
0005435652367	1644	Business	50000.00
0005435652382	1644	Business	50000.00
0005435652351	1644	Business	50000.00
0005435652365	1644	Business	50000.00
0005435652357	1644	Business	50000.00
0005435652340	1644	Economy	16700.00
0005435652354	1644	Economy	16700.00
0005435652377	1644	Economy	16700.00
0005435652374	1644	Economy	16700.00
0005435652348	1644	Economy	18300.00
0005435652373	1644	Economy	18300.00
0005435652376	1644	Economy	18300.00
0005435652350	1644	Economy	16700.00
0005435652343	1644	Economy	16700.00
0005435652379	1644	Economy	16700.00
0005435652341	1644	Economy	16700.00
0005435652349	1644	Economy	16700.00
0005435652383	1644	Economy	16700.00
0005435652352	1644	Economy	16700.00
0005435652355	1644	Economy	16700.00
0005435652346	1644	Economy	16700.00
0005435652381	1644	Economy	16700.00
0005435652364	1644	Economy	16700.00
0005435652370	1644	Economy	16700.00
0005435652358	1644	Economy	16700.00
0005435652366	1644	Economy	16700.00
0005435652344	1644	Economy	16700.00
0005435652372	1644	Economy	16700.00
0005435652380	1644	Economy	16700.00
0005435652368	1644	Economy	16700.00
0005435652342	1644	Economy	16700.00
0005435652359	1644	Economy	16700.00
0005435652345	1644	Economy	16700.00
0005435652361	1644	Economy	16700.00
0005435652375	1644	Economy	16700.00
0005435652353	1644	Economy	16700.00
0005435652362	1644	Economy	16700.00
0005435652356	1644	Economy	16700.00
0005435652347	1644	Economy	16700.00
0005435652360	1644	Economy	16700.00
0005435652378	1644	Economy	16700.00
0005435652369	1644	Economy	16700.00
0005435652371	1644	Economy	16700.00
0005435652363	1644	Economy	16700.00
0005433367308	21718	Business	50000.00
0005433367332	21718	Business	50000.00
0005433367295	21718	Business	50000.00
0005433367299	21718	Economy	16700.00
0005433367315	21718	Economy	16700.00
0005433367311	21718	Economy	16700.00
0005433367314	21718	Economy	16700.00
0005433367306	21718	Economy	16700.00
0005433367302	21718	Economy	16700.00
0005433367319	21718	Economy	18300.00
0005433367317	21718	Economy	18300.00
0005433367310	21718	Economy	18300.00
0005433367307	21718	Economy	16700.00
0005433367331	21718	Economy	16700.00
0005433367312	21718	Economy	16700.00
0005433367304	21718	Economy	16700.00
0005433367326	21718	Economy	16700.00
0005433367330	21718	Economy	16700.00
0005433367329	21718	Economy	16700.00
0005433367300	21718	Economy	16700.00
0005433367320	21718	Economy	16700.00
0005433367327	21718	Economy	16700.00
0005433367305	21718	Economy	16700.00
0005433367322	21718	Economy	16700.00
0005433367297	21718	Economy	16700.00
0005433367321	21718	Economy	16700.00
0005433367298	21718	Economy	16700.00
0005433367313	21718	Economy	16700.00
0005433367323	21718	Economy	16700.00
0005433367324	21718	Economy	16700.00
0005433367296	21718	Economy	16700.00
0005433367316	21718	Economy	16700.00
0005433367303	21718	Economy	16700.00
0005433367309	21718	Economy	16700.00
0005433367301	21718	Economy	16700.00
0005433367318	21718	Economy	16700.00
0005433367325	21718	Economy	16700.00
0005433367328	21718	Economy	16700.00
0005435312764	23227	Economy	23000.00
0005435312766	23227	Economy	20900.00
0005435312765	23227	Economy	20900.00
0005435312767	23227	Economy	20900.00
0005435312769	23227	Economy	20900.00
0005435312768	23227	Economy	20900.00
0005433985218	4172	Business	21500.00
0005433985216	4172	Business	21500.00
0005433985250	4172	Economy	7200.00
0005433985231	4172	Economy	7200.00
0005433985255	4172	Economy	7200.00
0005433985247	4172	Economy	7200.00
0005433985215	4172	Economy	7200.00
0005433985259	4172	Economy	7200.00
0005433985234	4172	Economy	7900.00
0005433985230	4172	Economy	7900.00
0005433985239	4172	Economy	7900.00
0005433985222	4172	Economy	7200.00
0005433985219	4172	Economy	7200.00
0005433985225	4172	Economy	7200.00
0005433985252	4172	Economy	7200.00
0005433985256	4172	Economy	7200.00
0005433985238	4172	Economy	7200.00
0005433985236	4172	Economy	7200.00
0005433985243	4172	Economy	7200.00
0005433985242	4172	Economy	7200.00
0005433985257	4172	Economy	7200.00
0005433985213	4172	Economy	7200.00
0005433985253	4172	Economy	7200.00
0005433985224	4172	Economy	7200.00
0005433985229	4172	Economy	7200.00
0005433985246	4172	Economy	7200.00
0005433985260	4172	Economy	7200.00
0005433985248	4172	Economy	7200.00
0005433985227	4172	Economy	7200.00
0005433985232	4172	Economy	7200.00
0005433985228	4172	Economy	7200.00
0005433985240	4172	Economy	7200.00
0005433985244	4172	Economy	7200.00
0005435788731	4172	Economy	7200.00
0005433985249	4172	Economy	7200.00
0005433985235	4172	Economy	7200.00
0005433985233	4172	Economy	7200.00
0005433985237	4172	Economy	7200.00
0005433985254	4172	Economy	7200.00
0005433985223	4172	Economy	7200.00
0005433985220	4172	Economy	7200.00
0005433985217	4172	Economy	7200.00
0005433985226	4172	Economy	7200.00
0005433985245	4172	Economy	7200.00
0005433985221	4172	Economy	7200.00
0005433985251	4172	Economy	7200.00
0005433985241	4172	Economy	7200.00
0005433985214	4172	Economy	7200.00
0005435788732	4172	Economy	7200.00
0005433985212	4172	Economy	7200.00
0005433985258	4172	Economy	7200.00
0005433168309	21336	Economy	15500.00
0005433168303	21336	Economy	15500.00
0005433168306	21336	Economy	15500.00
0005433168305	21336	Economy	15500.00
0005433168308	21336	Economy	15500.00
0005433168311	21336	Economy	15500.00
0005433168304	21336	Economy	15500.00
0005433168307	21336	Economy	15500.00
0005433168310	21336	Economy	15500.00
0005434151662	17837	Business	18000.00
0005432869429	17837	Business	18000.00
0005432869426	17837	Business	18000.00
0005432869425	17837	Economy	6000.00
0005434151660	17837	Economy	6000.00
0005432869428	17837	Economy	6000.00
0005432869424	17837	Economy	6000.00
0005434151661	17837	Economy	6000.00
0005432869427	17837	Economy	6000.00
0005432869430	17837	Economy	6000.00
0005432665240	26337	Business	18000.00
0005432657399	26337	Business	18000.00
0005432655336	26337	Business	18000.00
0005432655337	26337	Business	18000.00
0005432655330	26337	Economy	6000.00
0005432655326	26337	Economy	6000.00
0005432655335	26337	Economy	6000.00
0005432658556	26337	Economy	6000.00
0005432665239	26337	Economy	6000.00
0005432657396	26337	Economy	6000.00
0005432667419	26337	Economy	6000.00
0005432657397	26337	Economy	6000.00
0005432655328	26337	Economy	6000.00
0005432655331	26337	Economy	6000.00
0005432659672	26337	Economy	6000.00
0005432667418	26337	Economy	6000.00
0005432655332	26337	Economy	6000.00
0005432658555	26337	Economy	6000.00
0005432658557	26337	Economy	6000.00
0005432655333	26337	Economy	6000.00
0005432655334	26337	Economy	6000.00
0005432655327	26337	Economy	6000.00
0005432667420	26337	Economy	6000.00
0005432657398	26337	Economy	6000.00
0005432655329	26337	Economy	6000.00
0005432659671	26337	Economy	6000.00
0005432666354	26337	Economy	6000.00
0005432328001	3075	Business	16100.00
0005432328023	3075	Business	16100.00
0005432328006	3075	Business	16100.00
0005433438780	3075	Business	16100.00
0005432328017	3075	Business	16100.00
0005432328009	3075	Business	16100.00
0005432327987	3075	Business	16100.00
0005432328004	3075	Business	16100.00
0005432328024	3075	Business	16100.00
0005432328027	3075	Business	16100.00
0005432328005	3075	Economy	5400.00
0005432328000	3075	Economy	5400.00
0005432327993	3075	Economy	5400.00
0005432327995	3075	Economy	5400.00
0005432328030	3075	Economy	5400.00
0005432328016	3075	Economy	5400.00
0005433438784	3075	Economy	5900.00
0005432327988	3075	Economy	5900.00
0005432328011	3075	Economy	5900.00
0005432328014	3075	Economy	5400.00
0005432328008	3075	Economy	5400.00
0005432328002	3075	Economy	5400.00
0005432327986	3075	Economy	5400.00
0005432328029	3075	Economy	5400.00
0005432287112	3075	Economy	5400.00
0005432328022	3075	Economy	5400.00
0005432327989	3075	Economy	5400.00
0005432328013	3075	Economy	5400.00
0005432327991	3075	Economy	5400.00
0005432287115	3075	Economy	5400.00
0005433438781	3075	Economy	5400.00
0005433438779	3075	Economy	5400.00
0005433438783	3075	Economy	5400.00
0005432328028	3075	Economy	5400.00
0005433438777	3075	Economy	5400.00
0005432327998	3075	Economy	5400.00
0005432287110	3075	Economy	5400.00
0005432327985	3075	Economy	5400.00
0005432287113	3075	Economy	5400.00
0005432287114	3075	Economy	5400.00
0005432328025	3075	Economy	5400.00
0005432328021	3075	Economy	5400.00
0005432328020	3075	Economy	5400.00
0005432327997	3075	Economy	5400.00
0005432328031	3075	Economy	5400.00
0005432328010	3075	Economy	5400.00
0005432287111	3075	Economy	5400.00
0005432328003	3075	Economy	5400.00
0005433438782	3075	Economy	5400.00
0005432328015	3075	Economy	5400.00
0005432328019	3075	Economy	5400.00
0005432327994	3075	Economy	5400.00
0005432328018	3075	Economy	5400.00
0005432328012	3075	Economy	5400.00
0005432328007	3075	Economy	5400.00
0005432327996	3075	Economy	5400.00
0005432327990	3075	Economy	5400.00
0005432328026	3075	Economy	5400.00
0005432327992	3075	Economy	5400.00
0005433438778	3075	Economy	5400.00
0005432327999	3075	Economy	5400.00
0005432905034	31102	Business	16100.00
0005432054261	31102	Economy	5400.00
0005432905029	31102	Economy	5400.00
0005432054258	31102	Economy	5400.00
0005432905035	31102	Economy	5400.00
0005432054259	31102	Economy	5400.00
0005432905030	31102	Economy	5400.00
0005432905033	31102	Economy	5400.00
0005432054260	31102	Economy	5400.00
0005432905032	31102	Economy	5400.00
0005432905031	31102	Economy	5400.00
0005432848836	31102	Economy	5400.00
0005434309530	6232	Business	124600.00
0005434309531	6232	Business	124600.00
0005434309538	6232	Business	124600.00
0005435998992	6232	Business	124600.00
0005434309537	6232	Economy	41500.00
0005434309534	6232	Economy	41500.00
0005435998993	6232	Economy	41500.00
0005434309540	6232	Economy	41500.00
0005434309539	6232	Economy	41500.00
0005434309541	6232	Economy	41500.00
0005432146168	6232	Economy	41500.00
0005434309532	6232	Economy	41500.00
0005435998986	6232	Economy	41500.00
0005435998998	6232	Economy	41500.00
0005435998994	6232	Economy	41500.00
0005435998991	6232	Economy	41500.00
0005435998997	6232	Economy	45700.00
0005435998987	6232	Economy	41500.00
0005432146169	6232	Economy	41500.00
0005434309533	6232	Economy	41500.00
0005434309542	6232	Economy	41500.00
0005435998990	6232	Economy	41500.00
0005434309535	6232	Economy	41500.00
0005435998988	6232	Economy	41500.00
0005435998996	6232	Economy	41500.00
0005432146167	6232	Economy	41500.00
0005432146170	6232	Economy	41500.00
0005434309536	6232	Economy	41500.00
0005435998995	6232	Economy	41500.00
0005435998985	6232	Economy	41500.00
0005435998989	6232	Economy	41500.00
0005435487480	19534	Business	124600.00
0005435487495	19534	Business	124600.00
0005435487491	19534	Business	124600.00
0005435487476	19534	Economy	41500.00
0005435487478	19534	Economy	41500.00
0005435487489	19534	Economy	41500.00
0005435487493	19534	Economy	41500.00
0005435296953	19534	Economy	41500.00
0005435487484	19534	Economy	41500.00
0005435487488	19534	Economy	41500.00
0005435487479	19534	Economy	45700.00
0005435487486	19534	Economy	45700.00
0005435487483	19534	Economy	41500.00
0005435296952	19534	Economy	41500.00
0005435487490	19534	Economy	41500.00
0005435487496	19534	Economy	41500.00
0005435296955	19534	Economy	41500.00
0005435487494	19534	Economy	41500.00
0005435487487	19534	Economy	41500.00
0005435296951	19534	Economy	41500.00
0005435296957	19534	Economy	41500.00
0005435487482	19534	Economy	41500.00
0005435487485	19534	Economy	41500.00
0005435487481	19534	Economy	41500.00
0005435296954	19534	Economy	41500.00
0005435487497	19534	Economy	41500.00
0005435487475	19534	Economy	41500.00
0005435487492	19534	Economy	41500.00
0005435487477	19534	Economy	41500.00
0005435296956	19534	Economy	41500.00
0005433158098	17533	Economy	12300.00
0005433158095	17533	Economy	12300.00
0005433158097	17533	Economy	12300.00
0005433158096	17533	Economy	12300.00
0005435501986	1548	Business	86000.00
0005435501989	1548	Business	86000.00
0005434565708	1548	Business	86000.00
0005435501997	1548	Business	86000.00
0005434565715	1548	Business	86000.00
0005435517637	1548	Business	86000.00
0005435501988	1548	Economy	28700.00
0005435517647	1548	Economy	28700.00
0005435508189	1548	Economy	28700.00
0005434565713	1548	Economy	28700.00
0005435517630	1548	Economy	28700.00
0005434565716	1548	Economy	28700.00
0005434565711	1548	Economy	28700.00
0005435501983	1548	Economy	28700.00
0005435517640	1548	Economy	28700.00
0005435501993	1548	Economy	31500.00
0005435508190	1548	Economy	31500.00
0005435517646	1548	Economy	31500.00
0005435501982	1548	Economy	31500.00
0005434565709	1548	Economy	31500.00
0005435517644	1548	Economy	28700.00
0005435501991	1548	Economy	28700.00
0005435501984	1548	Economy	28700.00
0005434565710	1548	Economy	28700.00
0005435501992	1548	Economy	28700.00
0005435501980	1548	Economy	28700.00
0005435517634	1548	Economy	28700.00
0005435501978	1548	Economy	28700.00
0005434565717	1548	Economy	28700.00
0005435508195	1548	Economy	28700.00
0005435501985	1548	Economy	28700.00
0005435517635	1548	Economy	28700.00
0005435508196	1548	Economy	28700.00
0005435517645	1548	Economy	28700.00
0005435517636	1548	Economy	28700.00
0005435501979	1548	Economy	28700.00
0005435508197	1548	Economy	28700.00
0005435517641	1548	Economy	28700.00
0005435501995	1548	Economy	28700.00
0005435517629	1548	Economy	28700.00
0005435508198	1548	Economy	28700.00
0005435508194	1548	Economy	28700.00
0005435508188	1548	Economy	28700.00
0005435501994	1548	Economy	28700.00
0005435508185	1548	Economy	28700.00
0005432291893	1548	Economy	28700.00
0005435517631	1548	Economy	28700.00
0005434565707	1548	Economy	28700.00
0005435517633	1548	Economy	28700.00
0005435508186	1548	Economy	28700.00
0005434565714	1548	Economy	28700.00
0005435517638	1548	Economy	28700.00
0005435501990	1548	Economy	28700.00
0005435508191	1548	Economy	28700.00
0005435508187	1548	Economy	28700.00
0005435501996	1548	Economy	28700.00
0005435508193	1548	Economy	28700.00
0005435517632	1548	Economy	28700.00
0005434565706	1548	Economy	28700.00
0005435517642	1548	Economy	28700.00
0005435501977	1548	Economy	28700.00
0005435517639	1548	Economy	28700.00
0005435517643	1548	Economy	28700.00
0005435501976	1548	Economy	28700.00
0005434565712	1548	Economy	28700.00
0005435508192	1548	Economy	28700.00
0005435501987	1548	Economy	28700.00
0005432291894	1548	Economy	28700.00
0005435501975	1548	Economy	28700.00
0005435501981	1548	Economy	28700.00
0005433185989	20867	Business	86000.00
0005433185987	20867	Business	86000.00
0005433185988	20867	Economy	28700.00
0005433185985	20867	Economy	28700.00
0005433185993	20867	Economy	28700.00
0005433185994	20867	Economy	28700.00
0005433185992	20867	Economy	28700.00
0005433185986	20867	Economy	28700.00
0005433185990	20867	Economy	28700.00
0005433185991	20867	Economy	28700.00
0005435153643	3901	Economy	19700.00
0005435153645	3901	Economy	19700.00
0005435153644	3901	Economy	19700.00
0005435153640	3901	Economy	19700.00
0005435153641	3901	Economy	19700.00
0005435153642	3901	Economy	19700.00
0005435931544	21850	Economy	19700.00
0005435931545	21850	Economy	19700.00
0005435931543	21850	Economy	19700.00
0005432628622	7186	Economy	13000.00
0005432628619	7186	Economy	13000.00
0005432628617	7186	Economy	13000.00
0005432628624	7186	Economy	13000.00
0005432628628	7186	Economy	13000.00
0005432628620	7186	Economy	13000.00
0005432628625	7186	Economy	13000.00
0005432628621	7186	Economy	13000.00
0005432628623	7186	Economy	13000.00
0005432628630	7186	Economy	13000.00
0005432628626	7186	Economy	13000.00
0005432628618	7186	Economy	13000.00
0005432628629	7186	Economy	13000.00
0005432628627	7186	Economy	13000.00
0005435225465	28099	Economy	14300.00
0005435225466	28099	Economy	14300.00
0005435225460	28099	Economy	13000.00
0005435225464	28099	Economy	13000.00
0005435225462	28099	Economy	13000.00
0005435225463	28099	Economy	13000.00
0005435225459	28099	Economy	13000.00
0005435225461	28099	Economy	13000.00
0005435959992	8746	Economy	10500.00
0005435959991	8746	Economy	10500.00
0005435959993	8746	Economy	10500.00
0005435959990	8746	Economy	10500.00
0005434267891	15265	Economy	11500.00
0005434267892	15265	Economy	10500.00
0005434267893	15265	Economy	10500.00
0005432674897	1194	Business	115000.00
0005432692589	1194	Business	115000.00
0005432692567	1194	Business	115000.00
0005432692570	1194	Business	115000.00
0005432674899	1194	Business	115000.00
0005432674895	1194	Business	115000.00
0005432677508	1194	Business	115000.00
0005432692566	1194	Business	115000.00
0005432692575	1194	Business	115000.00
0005432692584	1194	Economy	38300.00
0005432674901	1194	Economy	38300.00
0005432692586	1194	Economy	38300.00
0005432692563	1194	Economy	38300.00
0005432692559	1194	Economy	38300.00
0005432692569	1194	Economy	38300.00
0005432692574	1194	Economy	42200.00
0005432692576	1194	Economy	38300.00
0005432692581	1194	Economy	38300.00
0005432692585	1194	Economy	38300.00
0005432677507	1194	Economy	38300.00
0005432692571	1194	Economy	38300.00
0005432677510	1194	Economy	38300.00
0005432692587	1194	Economy	38300.00
0005432692577	1194	Economy	38300.00
0005432674908	1194	Economy	38300.00
0005432677509	1194	Economy	38300.00
0005432692578	1194	Economy	38300.00
0005432674906	1194	Economy	38300.00
0005432674894	1194	Economy	38300.00
0005432692561	1194	Economy	38300.00
0005432692560	1194	Economy	38300.00
0005432674902	1194	Economy	38300.00
0005432692588	1194	Economy	38300.00
0005432674898	1194	Economy	38300.00
0005432674893	1194	Economy	38300.00
0005432692568	1194	Economy	38300.00
0005432674903	1194	Economy	38300.00
0005432674905	1194	Economy	38300.00
0005432692582	1194	Economy	38300.00
0005432674907	1194	Economy	38300.00
0005432692579	1194	Economy	38300.00
0005432674900	1194	Economy	38300.00
0005432692564	1194	Economy	38300.00
0005432692573	1194	Economy	38300.00
0005432692562	1194	Economy	38300.00
0005432692565	1194	Economy	38300.00
0005432674904	1194	Economy	38300.00
0005432692572	1194	Economy	38300.00
0005432692583	1194	Economy	38300.00
0005432674896	1194	Economy	38300.00
0005432692580	1194	Economy	38300.00
0005432873183	17508	Business	115000.00
0005432873186	17508	Business	115000.00
0005432873184	17508	Business	115000.00
0005432873181	17508	Economy	38300.00
0005432873182	17508	Economy	38300.00
0005432873185	17508	Economy	38300.00
0005432873180	17508	Economy	38300.00
0005434434954	1140	Economy	13900.00
0005434434951	1140	Economy	13900.00
0005434434942	1140	Economy	13900.00
0005434434943	1140	Economy	13900.00
0005434434945	1140	Economy	13900.00
0005434434944	1140	Economy	13900.00
0005434434949	1140	Economy	13900.00
0005434434953	1140	Economy	13900.00
0005434434950	1140	Economy	13900.00
0005434434952	1140	Economy	13900.00
0005434434955	1140	Economy	13900.00
0005434434948	1140	Economy	13900.00
0005434434946	1140	Economy	13900.00
0005434434947	1140	Economy	13900.00
0005434434941	1140	Economy	13900.00
0005433156621	17317	Economy	15200.00
0005433156618	17317	Economy	13900.00
0005433156613	17317	Economy	13900.00
0005433156620	17317	Economy	13900.00
0005433156614	17317	Economy	13900.00
0005433156617	17317	Economy	13900.00
0005433156616	17317	Economy	13900.00
0005433156619	17317	Economy	13900.00
0005433156615	17317	Economy	13900.00
0005435086719	4079	Economy	7500.00
0005435086717	4079	Economy	7500.00
0005435086720	4079	Economy	7500.00
0005435086721	4079	Economy	7500.00
0005435086716	4079	Economy	7500.00
0005435086718	4079	Economy	7500.00
0005435086722	4079	Economy	7500.00
0005435928071	24401	Economy	7500.00
0005435928068	24401	Economy	7500.00
0005435928069	24401	Economy	7500.00
0005435928070	24401	Economy	7500.00
0005435706133	2450	Business	86800.00
0005435706113	2450	Business	86800.00
0005435706132	2450	Business	86800.00
0005435706100	2450	Business	86800.00
0005435706135	2450	Economy	28900.00
0005435706114	2450	Economy	28900.00
0005435706122	2450	Economy	28900.00
0005435706112	2450	Economy	28900.00
0005435706127	2450	Economy	28900.00
0005435706108	2450	Economy	28900.00
0005435706105	2450	Economy	31800.00
0005435706118	2450	Economy	31800.00
0005435706134	2450	Economy	31800.00
0005435706125	2450	Economy	28900.00
0005435706110	2450	Economy	28900.00
0005435706121	2450	Economy	28900.00
0005435706144	2450	Economy	28900.00
0005435706129	2450	Economy	28900.00
0005435706119	2450	Economy	28900.00
0005435706103	2450	Economy	28900.00
0005435706120	2450	Economy	28900.00
0005435706101	2450	Economy	28900.00
0005435706141	2450	Economy	28900.00
0005435706130	2450	Economy	28900.00
0005435706097	2450	Economy	28900.00
0005435706139	2450	Economy	28900.00
0005435706143	2450	Economy	28900.00
0005435706138	2450	Economy	28900.00
0005435706106	2450	Economy	28900.00
0005435706126	2450	Economy	28900.00
0005435706136	2450	Economy	28900.00
0005435706109	2450	Economy	28900.00
0005435706142	2450	Economy	28900.00
0005435706131	2450	Economy	28900.00
0005435706140	2450	Economy	28900.00
0005435706123	2450	Economy	28900.00
0005435706124	2450	Economy	28900.00
0005435706107	2450	Economy	28900.00
0005435706096	2450	Economy	28900.00
0005435706128	2450	Economy	28900.00
0005435706115	2450	Economy	28900.00
0005435706099	2450	Economy	28900.00
0005435706117	2450	Economy	28900.00
0005435706116	2450	Economy	28900.00
0005435706098	2450	Economy	28900.00
0005435706095	2450	Economy	28900.00
0005435706111	2450	Economy	28900.00
0005435706102	2450	Economy	28900.00
0005435706104	2450	Economy	28900.00
0005435706137	2450	Economy	28900.00
0005433373382	27019	Business	86800.00
0005433373397	27019	Business	86800.00
0005433373395	27019	Business	86800.00
0005433373392	27019	Business	86800.00
0005433373375	27019	Economy	28900.00
0005433373391	27019	Economy	28900.00
0005433373378	27019	Economy	28900.00
0005433373377	27019	Economy	28900.00
0005433373389	27019	Economy	31800.00
0005433373374	27019	Economy	31800.00
0005433373379	27019	Economy	28900.00
0005433373399	27019	Economy	28900.00
0005433373402	27019	Economy	28900.00
0005433373400	27019	Economy	28900.00
0005433373381	27019	Economy	28900.00
0005433373380	27019	Economy	28900.00
0005433373387	27019	Economy	28900.00
0005433373376	27019	Economy	28900.00
0005433373394	27019	Economy	28900.00
0005433373388	27019	Economy	28900.00
0005433373385	27019	Economy	28900.00
0005433373398	27019	Economy	28900.00
0005433373386	27019	Economy	28900.00
0005433373393	27019	Economy	28900.00
0005433373384	27019	Economy	28900.00
0005433373401	27019	Economy	28900.00
0005433373383	27019	Economy	28900.00
0005433373396	27019	Economy	28900.00
0005433373390	27019	Economy	28900.00
0005434625813	4843	Business	44200.00
0005434625821	4843	Economy	14700.00
0005434625815	4843	Economy	14700.00
0005434625818	4843	Economy	16200.00
0005434625819	4843	Economy	14700.00
0005434625814	4843	Economy	14700.00
0005434625822	4843	Economy	14700.00
0005434625817	4843	Economy	14700.00
0005434625820	4843	Economy	14700.00
0005434625816	4843	Economy	14700.00
0005435907430	32899	Economy	14700.00
0005435907429	32899	Economy	14700.00
0005435907431	32899	Economy	14700.00
0005435907428	32899	Economy	14700.00
0005435907426	32899	Economy	14700.00
0005435907427	32899	Economy	14700.00
0005432195660	13756	Economy	3100.00
0005432195661	13756	Economy	3100.00
0005435937326	13756	Economy	3100.00
0005435937323	13756	Economy	3100.00
0005435937325	13756	Economy	3100.00
0005435937319	13756	Economy	3100.00
0005435937322	13756	Economy	3100.00
0005435937321	13756	Economy	3100.00
0005435937320	13756	Economy	3100.00
0005435937324	13756	Economy	3100.00
0005435784780	27426	Economy	3400.00
0005435784789	27426	Economy	3400.00
0005432190566	27426	Economy	3400.00
0005435784776	27426	Economy	3400.00
0005435784792	27426	Economy	3100.00
0005435787320	27426	Economy	3100.00
0005435784794	27426	Economy	3100.00
0005435784796	27426	Economy	3100.00
0005435784790	27426	Economy	3100.00
0005435784768	27426	Economy	3100.00
0005435784765	27426	Economy	3100.00
0005435784774	27426	Economy	3100.00
0005435784797	27426	Economy	3100.00
0005435784766	27426	Economy	3100.00
0005435784775	27426	Economy	3100.00
0005435784798	27426	Economy	3100.00
0005432190567	27426	Economy	3100.00
0005435784767	27426	Economy	3100.00
0005435784793	27426	Economy	3100.00
0005435784784	27426	Economy	3100.00
0005432190565	27426	Economy	3100.00
0005435784779	27426	Economy	3100.00
0005435784785	27426	Economy	3100.00
0005435787321	27426	Economy	3100.00
0005435784783	27426	Economy	3100.00
0005435784791	27426	Economy	3100.00
0005435784772	27426	Economy	3100.00
0005435784769	27426	Economy	3100.00
0005435784788	27426	Economy	3100.00
0005435784764	27426	Economy	3100.00
0005435784786	27426	Economy	3100.00
0005435784787	27426	Economy	3100.00
0005435784777	27426	Economy	3100.00
0005435784781	27426	Economy	3100.00
0005435784795	27426	Economy	3100.00
0005435784773	27426	Economy	3100.00
0005435784782	27426	Economy	3100.00
0005435784778	27426	Economy	3100.00
0005435784771	27426	Economy	3100.00
0005435784770	27426	Economy	3100.00
0005432058323	20258	Business	12000.00
0005435310876	20258	Business	12000.00
0005435310890	20258	Economy	4000.00
0005432058322	20258	Economy	4000.00
0005435310883	20258	Economy	4000.00
0005435310893	20258	Economy	4400.00
0005435310882	20258	Economy	4400.00
0005435310879	20258	Economy	4400.00
0005432058320	20258	Economy	4000.00
0005435310888	20258	Economy	4000.00
0005435310881	20258	Economy	4000.00
0005435310880	20258	Economy	4000.00
0005432058321	20258	Economy	4000.00
0005435310894	20258	Economy	4000.00
0005435310878	20258	Economy	4000.00
0005435310885	20258	Economy	4000.00
0005435310877	20258	Economy	4000.00
0005435310884	20258	Economy	4000.00
0005432058324	20258	Economy	4000.00
0005435310887	20258	Economy	4000.00
0005435310891	20258	Economy	4000.00
0005435310892	20258	Economy	4000.00
0005435310886	20258	Economy	4000.00
0005435310889	20258	Economy	4000.00
0005434406774	26961	Business	12000.00
0005434406769	26961	Business	12000.00
0005434406770	26961	Business	12000.00
0005434406790	26961	Business	12000.00
0005432153832	26961	Business	12000.00
0005434406829	26961	Business	12000.00
0005434406809	26961	Business	12000.00
0005434406824	26961	Business	12000.00
0005434406784	26961	Economy	4000.00
0005434406817	26961	Economy	4000.00
0005434406772	26961	Economy	4000.00
0005434406810	26961	Economy	4000.00
0005434406822	26961	Economy	4000.00
0005434406777	26961	Economy	4000.00
0005432153831	26961	Economy	4000.00
0005434406799	26961	Economy	4000.00
0005434406807	26961	Economy	4000.00
0005434406825	26961	Economy	4400.00
0005434406785	26961	Economy	4400.00
0005434406818	26961	Economy	4400.00
0005434406828	26961	Economy	4400.00
0005434406773	26961	Economy	4400.00
0005434406795	26961	Economy	4000.00
0005434406797	26961	Economy	4000.00
0005434406826	26961	Economy	4000.00
0005434406811	26961	Economy	4000.00
0005434406793	26961	Economy	4000.00
0005434406796	26961	Economy	4000.00
0005434406791	26961	Economy	4000.00
0005434406804	26961	Economy	4000.00
0005434406806	26961	Economy	4000.00
0005434406765	26961	Economy	4000.00
0005434406812	26961	Economy	4000.00
0005434406801	26961	Economy	4000.00
0005434406768	26961	Economy	4000.00
0005434406767	26961	Economy	4000.00
0005434406814	26961	Economy	4000.00
0005434406775	26961	Economy	4000.00
0005434406823	26961	Economy	4000.00
0005434406808	26961	Economy	4000.00
0005432153833	26961	Economy	4000.00
0005434406815	26961	Economy	4000.00
0005434406800	26961	Economy	4000.00
0005434406802	26961	Economy	4000.00
0005434406782	26961	Economy	4000.00
0005434406794	26961	Economy	4000.00
0005434406827	26961	Economy	4000.00
0005434406787	26961	Economy	4000.00
0005434406778	26961	Economy	4000.00
0005434406803	26961	Economy	4000.00
0005434406821	26961	Economy	4000.00
0005434406789	26961	Economy	4000.00
0005434406816	26961	Economy	4000.00
0005434406780	26961	Economy	4000.00
0005434406820	26961	Economy	4000.00
0005434406792	26961	Economy	4000.00
0005432153828	26961	Economy	4000.00
0005434406781	26961	Economy	4000.00
0005434406771	26961	Economy	4000.00
0005434406813	26961	Economy	4000.00
0005434406805	26961	Economy	4000.00
0005434406819	26961	Economy	4000.00
0005434406788	26961	Economy	4000.00
0005434406786	26961	Economy	4000.00
0005434406783	26961	Economy	4000.00
0005432153829	26961	Economy	4000.00
0005434406766	26961	Economy	4000.00
0005432153830	26961	Economy	4000.00
0005434406779	26961	Economy	4000.00
0005434406776	26961	Economy	4000.00
0005434406798	26961	Economy	4000.00
0005434319179	5674	Business	43300.00
0005434319177	5674	Business	43300.00
0005434319171	5674	Economy	14400.00
0005434319173	5674	Economy	14400.00
0005434319169	5674	Economy	14400.00
0005434319183	5674	Economy	14400.00
0005434311187	5674	Economy	15900.00
0005432109661	5674	Economy	14400.00
0005434319172	5674	Economy	14400.00
0005434319170	5674	Economy	14400.00
0005434319182	5674	Economy	14400.00
0005434319180	5674	Economy	14400.00
0005434319178	5674	Economy	14400.00
0005434319167	5674	Economy	14400.00
0005434311185	5674	Economy	14400.00
0005434319166	5674	Economy	14400.00
0005434319164	5674	Economy	14400.00
0005434311186	5674	Economy	14400.00
0005434319176	5674	Economy	14400.00
0005432109660	5674	Economy	14400.00
0005434319168	5674	Economy	14400.00
0005434319185	5674	Economy	14400.00
0005434319165	5674	Economy	14400.00
0005434319181	5674	Economy	14400.00
0005434319175	5674	Economy	14400.00
0005434319174	5674	Economy	14400.00
0005434319184	5674	Economy	14400.00
0005433123623	15701	Business	43300.00
0005433123624	15701	Business	43300.00
0005433123613	15701	Business	43300.00
0005433123629	15701	Economy	14400.00
0005433123619	15701	Economy	14400.00
0005433123626	15701	Economy	15900.00
0005433123611	15701	Economy	15900.00
0005433123614	15701	Economy	15900.00
0005433123616	15701	Economy	14400.00
0005433123618	15701	Economy	14400.00
0005433123627	15701	Economy	14400.00
0005433123617	15701	Economy	14400.00
0005433123633	15701	Economy	14400.00
0005433123622	15701	Economy	14400.00
0005433123620	15701	Economy	14400.00
0005433123615	15701	Economy	14400.00
0005433123632	15701	Economy	14400.00
0005433123625	15701	Economy	14400.00
0005433123631	15701	Economy	14400.00
0005433123612	15701	Economy	14400.00
0005433123621	15701	Economy	14400.00
0005433123628	15701	Economy	14400.00
0005433123630	15701	Economy	14400.00
0005435220289	31757	Economy	17100.00
0005435219167	31757	Economy	15500.00
0005435220288	31757	Economy	15500.00
0005435219169	31757	Economy	15500.00
0005435219170	31757	Economy	15500.00
0005435220287	31757	Economy	15500.00
0005435220488	31757	Economy	15500.00
0005435219166	31757	Economy	15500.00
0005435220290	31757	Economy	15500.00
0005435220286	31757	Economy	15500.00
0005435219168	31757	Economy	15500.00
0005435220285	31757	Economy	15500.00
0005434484250	8994	Economy	24900.00
0005434484246	8994	Economy	24900.00
0005434484247	8994	Economy	24900.00
0005434484248	8994	Economy	24900.00
0005434484245	8994	Economy	24900.00
0005434484249	8994	Economy	24900.00
0005434484251	8994	Economy	24900.00
0005434189088	16641	Economy	24900.00
0005434189091	16641	Economy	24900.00
0005434189092	16641	Economy	24900.00
0005434189087	16641	Economy	24900.00
0005434189089	16641	Economy	24900.00
0005434189090	16641	Economy	24900.00
0005433123624	7706	Business	11100.00
0005433123617	7706	Business	11100.00
0005433123611	7706	Business	11100.00
0005433123632	7706	Business	11100.00
0005433123620	7706	Business	11100.00
0005433123623	7706	Economy	3700.00
0005433123627	7706	Economy	4100.00
0005433123625	7706	Economy	3700.00
0005433123612	7706	Economy	3700.00
0005433123622	7706	Economy	3700.00
0005433123618	7706	Economy	3700.00
0005433123629	7706	Economy	3700.00
0005433123615	7706	Economy	3700.00
0005433123630	7706	Economy	3700.00
0005433123621	7706	Economy	3700.00
0005433123619	7706	Economy	3700.00
0005433123633	7706	Economy	3700.00
0005433123614	7706	Economy	3700.00
0005433123631	7706	Economy	3700.00
0005433123616	7706	Economy	3700.00
0005433123628	7706	Economy	3700.00
0005433123626	7706	Economy	3700.00
0005433123613	7706	Economy	3700.00
0005432692613	7705	Business	11100.00
0005432692616	7705	Business	11100.00
0005433449641	7705	Business	11100.00
0005432692599	7705	Business	11100.00
0005433449646	7705	Business	11100.00
0005432692592	7705	Business	11100.00
0005433449628	7705	Business	11100.00
0005432720502	7705	Business	11100.00
0005432071528	7705	Business	11100.00
0005432692602	7705	Business	11100.00
0005432071530	7705	Business	11100.00
0005433449636	7705	Economy	3700.00
0005432692620	7705	Economy	3700.00
0005432692617	7705	Economy	3700.00
0005432720491	7705	Economy	3700.00
0005432720497	7705	Economy	3700.00
0005432720500	7705	Economy	3700.00
0005432720492	7705	Economy	3700.00
0005432692612	7705	Economy	3700.00
0005432720485	7705	Economy	4100.00
0005433449645	7705	Economy	4100.00
0005433449640	7705	Economy	4100.00
0005432692615	7705	Economy	4100.00
0005432720493	7705	Economy	3700.00
0005432720508	7705	Economy	3700.00
0005432720496	7705	Economy	3700.00
0005432720509	7705	Economy	3700.00
0005432720489	7705	Economy	3700.00
0005432720486	7705	Economy	3700.00
0005432720488	7705	Economy	3700.00
0005432720498	7705	Economy	3700.00
0005432720494	7705	Economy	3700.00
0005432720504	7705	Economy	3700.00
0005432692605	7705	Economy	3700.00
0005432692609	7705	Economy	3700.00
0005432720501	7705	Economy	3700.00
0005433449633	7705	Economy	3700.00
0005432692595	7705	Economy	3700.00
0005433449644	7705	Economy	3700.00
0005433449631	7705	Economy	3700.00
0005432692600	7705	Economy	3700.00
0005432692598	7705	Economy	3700.00
0005432720487	7705	Economy	3700.00
0005432692596	7705	Economy	3700.00
0005432692606	7705	Economy	3700.00
0005433449635	7705	Economy	3700.00
0005432692594	7705	Economy	3700.00
0005432692590	7705	Economy	3700.00
0005433449629	7705	Economy	3700.00
0005433449639	7705	Economy	3700.00
0005432692610	7705	Economy	3700.00
0005433449637	7705	Economy	3700.00
0005433449632	7705	Economy	3700.00
0005433449643	7705	Economy	3700.00
0005432692593	7705	Economy	3700.00
0005433449642	7705	Economy	3700.00
0005432692597	7705	Economy	3700.00
0005432720506	7705	Economy	3700.00
0005432692608	7705	Economy	3700.00
0005433449647	7705	Economy	3700.00
0005433449634	7705	Economy	3700.00
0005432692601	7705	Economy	3700.00
0005432720495	7705	Economy	3700.00
0005433449638	7705	Economy	3700.00
0005432071529	7705	Economy	3700.00
0005432720483	7705	Economy	3700.00
0005433449648	7705	Economy	3700.00
0005432720499	7705	Economy	3700.00
0005432720507	7705	Economy	3700.00
0005432692604	7705	Economy	3700.00
0005432692619	7705	Economy	3700.00
0005432692607	7705	Economy	3700.00
0005432692621	7705	Economy	3700.00
0005432692591	7705	Economy	3700.00
0005432692611	7705	Economy	3700.00
0005433449649	7705	Economy	3700.00
0005432071527	7705	Economy	3700.00
0005432720490	7705	Economy	3700.00
0005432720484	7705	Economy	3700.00
0005432692614	7705	Economy	3700.00
0005433449630	7705	Economy	3700.00
0005432692618	7705	Economy	3700.00
0005432720503	7705	Economy	3700.00
0005432692603	7705	Economy	3700.00
0005432720505	7705	Economy	3700.00
0005433722118	30434	Economy	3700.00
0005433722120	30434	Economy	3700.00
0005433722119	30434	Economy	3700.00
0005434586218	1365	Business	70400.00
0005434586233	1365	Business	70400.00
0005434586222	1365	Business	70400.00
0005434514927	1365	Business	70400.00
0005434586228	1365	Business	70400.00
0005434513539	1365	Business	70400.00
0005434586234	1365	Business	70400.00
0005433524874	1365	Economy	23500.00
0005434586211	1365	Economy	23500.00
0005434514926	1365	Economy	23500.00
0005433524870	1365	Economy	23500.00
0005433724736	1365	Economy	23500.00
0005434586223	1365	Economy	23500.00
0005433524876	1365	Economy	23500.00
0005434586225	1365	Economy	23500.00
0005434586217	1365	Economy	25800.00
0005434586216	1365	Economy	25800.00
0005433524878	1365	Economy	25800.00
0005434586229	1365	Economy	23500.00
0005434586232	1365	Economy	23500.00
0005433524879	1365	Economy	23500.00
0005433724734	1365	Economy	23500.00
0005434586210	1365	Economy	23500.00
0005434514928	1365	Economy	23500.00
0005434586209	1365	Economy	23500.00
0005433724735	1365	Economy	23500.00
0005434586213	1365	Economy	23500.00
0005433524875	1365	Economy	23500.00
0005433524880	1365	Economy	23500.00
0005434586221	1365	Economy	23500.00
0005434586230	1365	Economy	23500.00
0005433524877	1365	Economy	23500.00
0005433724738	1365	Economy	23500.00
0005434586219	1365	Economy	23500.00
0005434586231	1365	Economy	23500.00
0005434586215	1365	Economy	23500.00
0005434586227	1365	Economy	23500.00
0005432270960	1365	Economy	23500.00
0005433724733	1365	Economy	23500.00
0005433724737	1365	Economy	23500.00
0005434586226	1365	Economy	23500.00
0005433524873	1365	Economy	23500.00
0005434586212	1365	Economy	23500.00
0005433524872	1365	Economy	23500.00
0005434513538	1365	Economy	23500.00
0005434586224	1365	Economy	23500.00
0005432270961	1365	Economy	23500.00
0005434586214	1365	Economy	23500.00
0005434513540	1365	Economy	23500.00
0005434586235	1365	Economy	23500.00
0005433524871	1365	Economy	23500.00
0005434586220	1365	Economy	23500.00
0005433192844	18521	Business	70400.00
0005433192848	18521	Business	70400.00
0005433192847	18521	Business	70400.00
0005433192842	18521	Economy	23500.00
0005432927890	18521	Economy	23500.00
0005432927892	18521	Economy	23500.00
0005432927893	18521	Economy	25800.00
0005433192845	18521	Economy	23500.00
0005432968804	18521	Economy	23500.00
0005433192846	18521	Economy	23500.00
0005432968805	18521	Economy	23500.00
0005433192840	18521	Economy	23500.00
0005432927891	18521	Economy	23500.00
0005433192839	18521	Economy	23500.00
0005432927896	18521	Economy	23500.00
0005433192843	18521	Economy	23500.00
0005433192841	18521	Economy	23500.00
0005432927895	18521	Economy	23500.00
0005433192838	18521	Economy	23500.00
0005432927894	18521	Economy	23500.00
0005433192849	18521	Economy	23500.00
0005434142549	11424	Economy	4300.00
0005434343626	11424	Economy	4300.00
0005434343628	11424	Economy	4300.00
0005434343624	11424	Economy	4300.00
0005434142551	11424	Economy	4000.00
0005434343640	11424	Economy	4000.00
0005434343647	11424	Economy	4000.00
0005434343648	11424	Economy	4000.00
0005434343632	11424	Economy	4000.00
0005434343625	11424	Economy	4000.00
0005434343631	11424	Economy	4000.00
0005434343636	11424	Economy	4000.00
0005434343637	11424	Economy	4000.00
0005434343634	11424	Economy	4000.00
0005434343650	11424	Economy	4000.00
0005434142550	11424	Economy	4000.00
0005434343629	11424	Economy	4000.00
0005434343646	11424	Economy	4000.00
0005434343649	11424	Economy	4000.00
0005434142553	11424	Economy	4000.00
0005434343633	11424	Economy	4000.00
0005434343645	11424	Economy	4000.00
0005434142548	11424	Economy	4000.00
0005434343642	11424	Economy	4000.00
0005434343630	11424	Economy	4000.00
0005434343641	11424	Economy	4000.00
0005434343618	11424	Economy	4000.00
0005434343620	11424	Economy	4000.00
0005434343619	11424	Economy	4000.00
0005434343643	11424	Economy	4000.00
0005434343622	11424	Economy	4000.00
0005434343638	11424	Economy	4000.00
0005434343617	11424	Economy	4000.00
0005434343635	11424	Economy	4000.00
0005434343639	11424	Economy	4000.00
0005434142552	11424	Economy	4000.00
0005434343627	11424	Economy	4000.00
0005434343623	11424	Economy	4000.00
0005434343621	11424	Economy	4000.00
0005434343644	11424	Economy	4000.00
0005435304102	29759	Economy	4000.00
0005435304990	29759	Economy	4000.00
0005435304101	29759	Economy	4000.00
0005435304099	29759	Economy	4000.00
0005435304991	29759	Economy	4000.00
0005435304994	29759	Economy	4000.00
0005435304103	29759	Economy	4000.00
0005435304992	29759	Economy	4000.00
0005435304100	29759	Economy	4000.00
0005435304993	29759	Economy	4000.00
0005435824221	1253	Business	199800.00
0005435824212	1253	Business	199800.00
0005435824216	1253	Business	199800.00
0005435824209	1253	Business	199800.00
0005435824219	1253	Economy	66600.00
0005435824211	1253	Economy	66600.00
0005435824217	1253	Economy	66600.00
0005435824207	1253	Economy	66600.00
0005435824228	1253	Economy	73200.00
0005435824206	1253	Economy	66600.00
0005435824220	1253	Economy	66600.00
0005432284514	1253	Economy	66600.00
0005435824231	1253	Economy	66600.00
0005435824224	1253	Economy	66600.00
0005435824225	1253	Economy	66600.00
0005435824227	1253	Economy	66600.00
0005435824223	1253	Economy	66600.00
0005435824229	1253	Economy	66600.00
0005435824214	1253	Economy	66600.00
0005435824230	1253	Economy	66600.00
0005432284513	1253	Economy	66600.00
0005435824215	1253	Economy	66600.00
0005435824222	1253	Economy	66600.00
0005435824210	1253	Economy	66600.00
0005435824226	1253	Economy	66600.00
0005435824208	1253	Economy	66600.00
0005435824213	1253	Economy	66600.00
0005435824218	1253	Economy	66600.00
0005435824232	1253	Economy	66600.00
0005433415426	17975	Business	199800.00
0005433415420	17975	Business	199800.00
0005433415423	17975	Economy	66600.00
0005433415419	17975	Economy	66600.00
0005433415412	17975	Economy	73200.00
0005433415415	17975	Economy	66600.00
0005433415418	17975	Economy	66600.00
0005433415411	17975	Economy	66600.00
0005433415422	17975	Economy	66600.00
0005433415414	17975	Economy	66600.00
0005433415413	17975	Economy	66600.00
0005433415416	17975	Economy	66600.00
0005433415424	17975	Economy	66600.00
0005433415421	17975	Economy	66600.00
0005433415425	17975	Economy	66600.00
0005433415417	17975	Economy	66600.00
0005432782957	5660	Business	27800.00
0005432782958	5660	Business	27800.00
0005432782953	5660	Business	27800.00
0005432782984	5660	Business	27800.00
0005432782987	5660	Business	27800.00
0005432782962	5660	Business	27800.00
0005432782955	5660	Economy	9300.00
0005432782968	5660	Economy	9300.00
0005432783000	5660	Economy	9300.00
0005432783002	5660	Economy	9300.00
0005432143936	5660	Economy	9300.00
0005432782981	5660	Economy	9300.00
0005432782982	5660	Economy	9300.00
0005432782977	5660	Economy	10200.00
0005432782994	5660	Economy	10200.00
0005432782961	5660	Economy	10200.00
0005432782989	5660	Economy	10200.00
0005432782965	5660	Economy	9300.00
0005432782949	5660	Economy	9300.00
0005432782990	5660	Economy	9300.00
0005432782998	5660	Economy	9300.00
0005432782979	5660	Economy	9300.00
0005432782975	5660	Economy	9300.00
0005432782997	5660	Economy	9300.00
0005432782950	5660	Economy	9300.00
0005432782964	5660	Economy	9300.00
0005432782996	5660	Economy	9300.00
0005432143937	5660	Economy	9300.00
0005432782983	5660	Economy	9300.00
0005432782978	5660	Economy	9300.00
0005432782985	5660	Economy	9300.00
0005432782952	5660	Economy	9300.00
0005432782993	5660	Economy	9300.00
0005432782992	5660	Economy	9300.00
0005432782972	5660	Economy	9300.00
0005432782956	5660	Economy	9300.00
0005432782969	5660	Economy	9300.00
0005432782970	5660	Economy	9300.00
0005432782967	5660	Economy	9300.00
0005432782986	5660	Economy	9300.00
0005432782991	5660	Economy	9300.00
0005432782951	5660	Economy	9300.00
0005432782976	5660	Economy	9300.00
0005432782973	5660	Economy	9300.00
0005432782959	5660	Economy	9300.00
0005432782995	5660	Economy	9300.00
0005432782974	5660	Economy	9300.00
0005432782960	5660	Economy	9300.00
0005432782966	5660	Economy	9300.00
0005432782963	5660	Economy	9300.00
0005432782954	5660	Economy	9300.00
0005432143938	5660	Economy	9300.00
0005432782999	5660	Economy	9300.00
0005432782980	5660	Economy	9300.00
0005432782988	5660	Economy	9300.00
0005432783001	5660	Economy	9300.00
0005432782971	5660	Economy	9300.00
0005435242429	15358	Business	27800.00
0005435476654	15358	Business	27800.00
0005435242421	15358	Business	27800.00
0005435242424	15358	Business	27800.00
0005435242426	15358	Business	27800.00
0005435242419	15358	Business	27800.00
0005435242417	15358	Economy	9300.00
0005435242438	15358	Economy	9300.00
0005435242420	15358	Economy	9300.00
0005435242442	15358	Economy	9300.00
0005435242436	15358	Economy	10200.00
0005435242425	15358	Economy	9300.00
0005435242435	15358	Economy	9300.00
0005435242432	15358	Economy	9300.00
0005435242430	15358	Economy	9300.00
0005435242439	15358	Economy	9300.00
0005435476653	15358	Economy	9300.00
0005435242416	15358	Economy	9300.00
0005435476652	15358	Economy	9300.00
0005435242440	15358	Economy	9300.00
0005435242434	15358	Economy	9300.00
0005435242431	15358	Economy	9300.00
0005435242427	15358	Economy	9300.00
0005435242441	15358	Economy	9300.00
0005435242422	15358	Economy	9300.00
0005435242437	15358	Economy	9300.00
0005435242423	15358	Economy	9300.00
0005435242428	15358	Economy	9300.00
0005435242418	15358	Economy	9300.00
0005435242433	15358	Economy	9300.00
0005432848089	4372	Economy	7000.00
0005432848094	4372	Economy	6300.00
0005432848086	4372	Economy	6300.00
0005432848099	4372	Economy	6300.00
0005432848092	4372	Economy	6300.00
0005434462756	4372	Economy	6300.00
0005432848098	4372	Economy	6300.00
0005434462757	4372	Economy	6300.00
0005434463897	4372	Economy	6300.00
0005432848097	4372	Economy	6300.00
0005432848093	4372	Economy	6300.00
0005432848091	4372	Economy	6300.00
0005434463896	4372	Economy	6300.00
0005434462758	4372	Economy	6300.00
0005432848090	4372	Economy	6300.00
0005432848087	4372	Economy	6300.00
0005432848095	4372	Economy	6300.00
0005432848096	4372	Economy	6300.00
0005432848085	4372	Economy	6300.00
0005432848088	4372	Economy	6300.00
0005435850773	28836	Economy	7000.00
0005435850774	28836	Economy	6300.00
0005435850775	28836	Economy	6300.00
0005435850768	28836	Economy	6300.00
0005435850772	28836	Economy	6300.00
0005435850771	28836	Economy	6300.00
0005435850770	28836	Economy	6300.00
0005435850769	28836	Economy	6300.00
0005435850767	28836	Economy	6300.00
0005434925336	6349	Business	11900.00
0005434925321	6349	Business	11900.00
0005433496502	6349	Business	11900.00
0005432075178	6349	Business	11900.00
0005434925337	6349	Business	11900.00
0005433496504	6349	Business	11900.00
0005433496507	6349	Business	11900.00
0005433496490	6349	Business	11900.00
0005434925327	6349	Business	11900.00
0005434443467	6349	Economy	4000.00
0005434925332	6349	Economy	4000.00
0005434925307	6349	Economy	4000.00
0005434443459	6349	Economy	4000.00
0005434443456	6349	Economy	4000.00
0005433496508	6349	Economy	4000.00
0005434925308	6349	Economy	4000.00
0005434443465	6349	Economy	4000.00
0005434443464	6349	Economy	4000.00
0005434925339	6349	Economy	4000.00
0005433496510	6349	Economy	4400.00
0005434925326	6349	Economy	4400.00
0005433496499	6349	Economy	4400.00
0005433496513	6349	Economy	4400.00
0005432075177	6349	Economy	4400.00
0005433496511	6349	Economy	4000.00
0005434925323	6349	Economy	4000.00
0005433496494	6349	Economy	4000.00
0005434925329	6349	Economy	4000.00
0005434925311	6349	Economy	4000.00
0005434925318	6349	Economy	4000.00
0005434925306	6349	Economy	4000.00
0005434925333	6349	Economy	4000.00
0005434925317	6349	Economy	4000.00
0005433496483	6349	Economy	4000.00
0005434443458	6349	Economy	4000.00
0005434443466	6349	Economy	4000.00
0005433496500	6349	Economy	4000.00
0005434443470	6349	Economy	4000.00
0005434925319	6349	Economy	4000.00
0005433496489	6349	Economy	4000.00
0005433496496	6349	Economy	4000.00
0005433496512	6349	Economy	4000.00
0005434925310	6349	Economy	4000.00
0005433496492	6349	Economy	4000.00
0005434443472	6349	Economy	4000.00
0005434925320	6349	Economy	4000.00
0005432075176	6349	Economy	4000.00
0005434925325	6349	Economy	4000.00
0005433496488	6349	Economy	4000.00
0005434443463	6349	Economy	4000.00
0005434925342	6349	Economy	4000.00
0005434443460	6349	Economy	4000.00
0005433496486	6349	Economy	4000.00
0005432075179	6349	Economy	4000.00
0005433496506	6349	Economy	4000.00
0005434443471	6349	Economy	4000.00
0005434925314	6349	Economy	4000.00
0005434443462	6349	Economy	4000.00
0005433496509	6349	Economy	4000.00
0005433496485	6349	Economy	4000.00
0005433496498	6349	Economy	4000.00
0005434925312	6349	Economy	4000.00
0005434925341	6349	Economy	4000.00
0005434925338	6349	Economy	4000.00
0005434925315	6349	Economy	4000.00
0005434925340	6349	Economy	4000.00
0005434925330	6349	Economy	4000.00
0005434925313	6349	Economy	4000.00
0005434925334	6349	Economy	4000.00
0005433496487	6349	Economy	4000.00
0005433496505	6349	Economy	4000.00
0005434925335	6349	Economy	4000.00
0005433496484	6349	Economy	4000.00
0005433496493	6349	Economy	4000.00
0005433496495	6349	Economy	4000.00
0005434925309	6349	Economy	4000.00
0005434925324	6349	Economy	4000.00
0005433496491	6349	Economy	4000.00
0005434925328	6349	Economy	4000.00
0005434925316	6349	Economy	4000.00
0005433496501	6349	Economy	4000.00
0005434443461	6349	Economy	4000.00
0005434925322	6349	Economy	4000.00
0005433496497	6349	Economy	4000.00
0005434443468	6349	Economy	4000.00
0005433496503	6349	Economy	4000.00
0005434443457	6349	Economy	4000.00
0005434925331	6349	Economy	4000.00
0005434443469	6349	Economy	4000.00
0005433496443	20394	Economy	4000.00
0005433496444	20394	Economy	4000.00
0005435242445	12174	Business	41200.00
0005435242453	12174	Business	41200.00
0005435242459	12174	Business	41200.00
0005435242467	12174	Economy	13700.00
0005435242456	12174	Economy	15100.00
0005435242469	12174	Economy	13700.00
0005435242461	12174	Economy	13700.00
0005435242451	12174	Economy	13700.00
0005435242444	12174	Economy	13700.00
0005435242460	12174	Economy	13700.00
0005435242455	12174	Economy	13700.00
0005435242454	12174	Economy	13700.00
0005435242466	12174	Economy	13700.00
0005435242463	12174	Economy	13700.00
0005435242443	12174	Economy	13700.00
0005435242449	12174	Economy	13700.00
0005435242470	12174	Economy	13700.00
0005435242465	12174	Economy	13700.00
0005435242446	12174	Economy	13700.00
0005435242457	12174	Economy	13700.00
0005435242448	12174	Economy	13700.00
0005435242452	12174	Economy	13700.00
0005435242447	12174	Economy	13700.00
0005435242464	12174	Economy	13700.00
0005435242450	12174	Economy	13700.00
0005435242462	12174	Economy	13700.00
0005435242468	12174	Economy	13700.00
0005435242458	12174	Economy	13700.00
0005432782926	15400	Business	41200.00
0005432782903	15400	Business	41200.00
0005432782915	15400	Business	41200.00
0005432782897	15400	Business	41200.00
0005432782895	15400	Business	41200.00
0005432782904	15400	Economy	13700.00
0005432782913	15400	Economy	13700.00
0005432782916	15400	Economy	13700.00
0005432782932	15400	Economy	13700.00
0005432782896	15400	Economy	13700.00
0005432782914	15400	Economy	13700.00
0005432782930	15400	Economy	15100.00
0005432782921	15400	Economy	15100.00
0005432782948	15400	Economy	15100.00
0005432782901	15400	Economy	15100.00
0005432782900	15400	Economy	13700.00
0005432782927	15400	Economy	13700.00
0005432782905	15400	Economy	13700.00
0005432782909	15400	Economy	13700.00
0005432782893	15400	Economy	13700.00
0005432782943	15400	Economy	13700.00
0005432782935	15400	Economy	13700.00
0005432782923	15400	Economy	13700.00
0005432782941	15400	Economy	13700.00
0005432782939	15400	Economy	13700.00
0005432782931	15400	Economy	13700.00
0005432782918	15400	Economy	13700.00
0005432782912	15400	Economy	13700.00
0005432782908	15400	Economy	13700.00
0005432782947	15400	Economy	13700.00
0005432782911	15400	Economy	13700.00
0005432782942	15400	Economy	13700.00
0005432782899	15400	Economy	13700.00
0005432782928	15400	Economy	13700.00
0005432782938	15400	Economy	13700.00
0005432782945	15400	Economy	13700.00
0005432782940	15400	Economy	13700.00
0005432782898	15400	Economy	13700.00
0005432782946	15400	Economy	13700.00
0005432782920	15400	Economy	13700.00
0005432782907	15400	Economy	13700.00
0005432782933	15400	Economy	13700.00
0005432782906	15400	Economy	13700.00
0005432782919	15400	Economy	13700.00
0005432782894	15400	Economy	13700.00
0005432782937	15400	Economy	13700.00
0005432782917	15400	Economy	13700.00
0005432782929	15400	Economy	13700.00
0005432782922	15400	Economy	13700.00
0005432782925	15400	Economy	13700.00
0005432782910	15400	Economy	13700.00
0005432782936	15400	Economy	13700.00
0005432782944	15400	Economy	13700.00
0005432782924	15400	Economy	13700.00
0005432782934	15400	Economy	13700.00
0005432782902	15400	Economy	13700.00
0005434876770	14596	Business	49700.00
0005434876800	14596	Business	49700.00
0005434876824	14596	Business	49700.00
0005434876807	14596	Business	49700.00
0005434876830	14596	Business	49700.00
0005434876777	14596	Business	49700.00
0005434876789	14596	Business	49700.00
0005434876811	14596	Business	49700.00
0005434876813	14596	Business	49700.00
0005434876835	14596	Business	49700.00
0005434876787	14596	Business	49700.00
0005434876804	14596	Business	49700.00
0005434876771	14596	Business	49700.00
0005434876844	14596	Business	49700.00
0005434876797	14596	Business	49700.00
0005434876815	14596	Business	49700.00
0005434876776	14596	Business	49700.00
0005434876793	14596	Business	49700.00
0005434876798	14596	Economy	16600.00
0005434876758	14596	Economy	16600.00
0005434876790	14596	Economy	16600.00
0005434876806	14596	Economy	16600.00
0005434876827	14596	Economy	16600.00
0005434876832	14596	Economy	16600.00
0005434876751	14596	Economy	16600.00
0005434876750	14596	Economy	16600.00
0005434876765	14596	Economy	16600.00
0005434876836	14596	Economy	16600.00
0005434876839	14596	Economy	16600.00
0005434876753	14596	Economy	18200.00
0005434876773	14596	Economy	18200.00
0005434876846	14596	Economy	18200.00
0005434876796	14596	Economy	16600.00
0005434876814	14596	Economy	16600.00
0005434876761	14596	Economy	16600.00
0005434876780	14596	Economy	16600.00
0005434876818	14596	Economy	16600.00
0005434876762	14596	Economy	16600.00
0005434876799	14596	Economy	16600.00
0005434876826	14596	Economy	16600.00
0005434876756	14596	Economy	16600.00
0005434876759	14596	Economy	16600.00
0005434876841	14596	Economy	16600.00
0005434876794	14596	Economy	16600.00
0005434876825	14596	Economy	16600.00
0005434876840	14596	Economy	16600.00
0005434876779	14596	Economy	16600.00
0005434876833	14596	Economy	16600.00
0005434876769	14596	Economy	16600.00
0005434876831	14596	Economy	16600.00
0005434876795	14596	Economy	16600.00
0005434876782	14596	Economy	16600.00
0005434876767	14596	Economy	16600.00
0005434876752	14596	Economy	16600.00
0005434876809	14596	Economy	16600.00
0005434876791	14596	Economy	16600.00
0005434876805	14596	Economy	16600.00
0005434876828	14596	Economy	16600.00
0005434758858	14596	Economy	16600.00
0005434876786	14596	Economy	16600.00
0005434876816	14596	Economy	16600.00
0005434876819	14596	Economy	16600.00
0005434876763	14596	Economy	16600.00
0005434876781	14596	Economy	16600.00
0005434876838	14596	Economy	16600.00
0005434876801	14596	Economy	16600.00
0005434876803	14596	Economy	16600.00
0005434876842	14596	Economy	16600.00
0005434876785	14596	Economy	16600.00
0005434876757	14596	Economy	16600.00
0005434876802	14596	Economy	16600.00
0005434876768	14596	Economy	16600.00
0005434876764	14596	Economy	16600.00
0005434876837	14596	Economy	16600.00
0005434876792	14596	Economy	16600.00
0005434876820	14596	Economy	16600.00
0005434876775	14596	Economy	16600.00
0005434876783	14596	Economy	16600.00
0005434876843	14596	Economy	16600.00
0005434876778	14596	Economy	16600.00
0005434876754	14596	Economy	16600.00
0005434876810	14596	Economy	16600.00
0005434876766	14596	Economy	16600.00
0005434876784	14596	Economy	16600.00
0005434876749	14596	Economy	16600.00
0005434876755	14596	Economy	16600.00
0005434758857	14596	Economy	16600.00
0005434876808	14596	Economy	16600.00
0005434876822	14596	Economy	16600.00
0005434876774	14596	Economy	16600.00
0005434876829	14596	Economy	16600.00
0005434876772	14596	Economy	16600.00
0005434876788	14596	Economy	16600.00
0005434876821	14596	Economy	16600.00
0005434876812	14596	Economy	16600.00
0005434876760	14596	Economy	16600.00
0005434876834	14596	Economy	16600.00
0005434876823	14596	Economy	16600.00
0005434876845	14596	Economy	16600.00
0005434876817	14596	Economy	16600.00
0005435659962	9233	Economy	22400.00
0005435659965	9233	Economy	20300.00
0005435659964	9233	Economy	20300.00
0005435659968	9233	Economy	20300.00
0005435659970	9233	Economy	20300.00
0005435659963	9233	Economy	20300.00
0005435659960	9233	Economy	20300.00
0005435659966	9233	Economy	20300.00
0005435659961	9233	Economy	20300.00
0005435659967	9233	Economy	20300.00
0005435659969	9233	Economy	20300.00
0005434251824	24661	Economy	22400.00
0005434251822	24661	Economy	22400.00
0005434251817	24661	Economy	22400.00
0005434251815	24661	Economy	20300.00
0005434251823	24661	Economy	20300.00
0005434251821	24661	Economy	20300.00
0005434251820	24661	Economy	20300.00
0005434251818	24661	Economy	20300.00
0005434251819	24661	Economy	20300.00
0005434251816	24661	Economy	20300.00
0005433679820	2767	Business	33000.00
0005433679841	2767	Business	33000.00
0005433679812	2767	Business	33000.00
0005433679853	2767	Business	33000.00
0005433679813	2767	Business	33000.00
0005433679835	2767	Business	33000.00
0005433679834	2767	Business	33000.00
0005433679815	2767	Business	33000.00
0005433679842	2767	Economy	11000.00
0005432222701	2767	Economy	11000.00
0005432222699	2767	Economy	11000.00
0005433679816	2767	Economy	11000.00
0005433679849	2767	Economy	11000.00
0005433679819	2767	Economy	11000.00
0005432222700	2767	Economy	11000.00
0005433679817	2767	Economy	12100.00
0005433679822	2767	Economy	11000.00
0005433679850	2767	Economy	11000.00
0005433679847	2767	Economy	11000.00
0005433679809	2767	Economy	11000.00
0005433679827	2767	Economy	11000.00
0005433679839	2767	Economy	11000.00
0005432222702	2767	Economy	11000.00
0005433679845	2767	Economy	11000.00
0005433679848	2767	Economy	11000.00
0005433679823	2767	Economy	11000.00
0005433679808	2767	Economy	11000.00
0005433679844	2767	Economy	11000.00
0005433679825	2767	Economy	11000.00
0005433679821	2767	Economy	11000.00
0005433684387	2767	Economy	11000.00
0005433679826	2767	Economy	11000.00
0005433679829	2767	Economy	11000.00
0005433679838	2767	Economy	11000.00
0005433679852	2767	Economy	11000.00
0005433679830	2767	Economy	11000.00
0005433679811	2767	Economy	11000.00
0005433679807	2767	Economy	11000.00
0005433679843	2767	Economy	11000.00
0005432222698	2767	Economy	11000.00
0005433679828	2767	Economy	11000.00
0005433684386	2767	Economy	11000.00
0005433679818	2767	Economy	11000.00
0005433679854	2767	Economy	11000.00
0005433679851	2767	Economy	11000.00
0005433679837	2767	Economy	11000.00
0005433684388	2767	Economy	11000.00
0005433679833	2767	Economy	11000.00
0005433679840	2767	Economy	11000.00
0005433679832	2767	Economy	11000.00
0005433679824	2767	Economy	11000.00
0005433679846	2767	Economy	11000.00
0005433679814	2767	Economy	11000.00
0005433679831	2767	Economy	11000.00
0005433679810	2767	Economy	11000.00
0005433679836	2767	Economy	11000.00
0005432966533	29178	Business	33000.00
0005432966534	29178	Business	33000.00
0005432966536	29178	Business	33000.00
0005432966547	29178	Economy	11000.00
0005432966538	29178	Economy	11000.00
0005432966537	29178	Economy	11000.00
0005432966535	29178	Economy	11000.00
0005432005171	29178	Economy	11000.00
0005432966553	29178	Economy	12100.00
0005432966546	29178	Economy	12100.00
0005432966539	29178	Economy	12100.00
0005432966541	29178	Economy	11000.00
0005432966542	29178	Economy	11000.00
0005432005172	29178	Economy	11000.00
0005432966554	29178	Economy	11000.00
0005432966540	29178	Economy	11000.00
0005432005170	29178	Economy	11000.00
0005432005169	29178	Economy	11000.00
0005432966555	29178	Economy	11000.00
0005432966549	29178	Economy	11000.00
0005432966545	29178	Economy	11000.00
0005432966552	29178	Economy	11000.00
0005432966557	29178	Economy	11000.00
0005432966544	29178	Economy	11000.00
0005432966550	29178	Economy	11000.00
0005432966551	29178	Economy	11000.00
0005432966556	29178	Economy	11000.00
0005432966548	29178	Economy	11000.00
0005432966543	29178	Economy	11000.00
0005432966532	29178	Economy	11000.00
0005433633268	9276	Business	132900.00
0005433613521	9276	Business	132900.00
0005433577590	9276	Business	132900.00
0005433613477	9276	Business	132900.00
0005433613486	9276	Business	132900.00
0005433633250	9276	Business	132900.00
0005433613475	9276	Business	132900.00
0005433577589	9276	Business	132900.00
0005433633280	9276	Business	132900.00
0005433613495	9276	Business	132900.00
0005433613516	9276	Business	132900.00
0005433613481	9276	Business	132900.00
0005433633272	9276	Business	132900.00
0005433613530	9276	Business	132900.00
0005433633256	9276	Business	132900.00
0005433577591	9276	Business	132900.00
0005433633270	9276	Business	132900.00
0005433613527	9276	Business	132900.00
0005433613507	9276	Economy	48700.00
0005433613534	9276	Economy	48700.00
0005433633276	9276	Economy	48700.00
0005433613469	9276	Economy	48700.00
0005433577595	9276	Economy	48700.00
0005433633271	9276	Economy	44300.00
0005433613498	9276	Economy	44300.00
0005433613482	9276	Economy	44300.00
0005433613470	9276	Economy	44300.00
0005433633277	9276	Economy	44300.00
0005433633265	9276	Economy	44300.00
0005433613526	9276	Economy	44300.00
0005433613518	9276	Economy	44300.00
0005433613480	9276	Economy	44300.00
0005433633259	9276	Economy	44300.00
0005433613461	9276	Economy	44300.00
0005433633279	9276	Economy	44300.00
0005433613522	9276	Economy	44300.00
0005433633253	9276	Economy	44300.00
0005433613512	9276	Economy	44300.00
0005433613485	9276	Economy	44300.00
0005433613483	9276	Economy	44300.00
0005433577597	9276	Economy	44300.00
0005433613532	9276	Economy	44300.00
0005433633261	9276	Economy	44300.00
0005433633258	9276	Economy	44300.00
0005433613519	9276	Economy	44300.00
0005433577588	9276	Economy	44300.00
0005433613506	9276	Economy	44300.00
0005433633278	9276	Economy	44300.00
0005433633266	9276	Economy	44300.00
0005432756795	9276	Economy	44300.00
0005432756796	9276	Economy	44300.00
0005433633251	9276	Economy	44300.00
0005432755025	9276	Economy	44300.00
0005433633262	9276	Economy	44300.00
0005433633273	9276	Economy	44300.00
0005433633263	9276	Economy	44300.00
0005433633252	9276	Economy	44300.00
0005433613523	9276	Economy	44300.00
0005433633281	9276	Economy	44300.00
0005433577593	9276	Economy	44300.00
0005433633267	9276	Economy	44300.00
0005433613478	9276	Economy	44300.00
0005433613490	9276	Economy	44300.00
0005433613465	9276	Economy	44300.00
0005433613535	9276	Economy	44300.00
0005433613515	9276	Economy	44300.00
0005433633257	9276	Economy	44300.00
0005433577601	9276	Economy	44300.00
0005433613476	9276	Economy	44300.00
0005433633249	9276	Economy	44300.00
0005433613517	9276	Economy	44300.00
0005433613505	9276	Economy	44300.00
0005433613468	9276	Economy	48700.00
0005433613502	9276	Economy	48700.00
0005433613493	9276	Economy	48700.00
0005433613508	9276	Economy	44300.00
0005433613471	9276	Economy	48700.00
0005432145078	9276	Economy	44300.00
0005433613467	9276	Economy	44300.00
0005433613513	9276	Economy	48700.00
0005433613474	9276	Economy	44300.00
0005433633248	9276	Economy	44300.00
0005433613510	9276	Economy	44300.00
0005433613499	9276	Economy	44300.00
0005433613511	9276	Economy	44300.00
0005433613533	9276	Economy	44300.00
0005432756794	9276	Economy	44300.00
0005433613472	9276	Economy	44300.00
0005433633254	9276	Economy	44300.00
0005433633255	9276	Economy	44300.00
0005433613524	9276	Economy	44300.00
0005433577598	9276	Economy	44300.00
0005433613491	9276	Economy	44300.00
0005433613466	9276	Economy	44300.00
0005433633260	9276	Economy	44300.00
0005433613463	9276	Economy	44300.00
0005433577594	9276	Economy	44300.00
0005433577592	9276	Economy	44300.00
0005433613509	9276	Economy	44300.00
0005433613525	9276	Economy	44300.00
0005433613462	9276	Economy	44300.00
0005433613504	9276	Economy	44300.00
0005433577599	9276	Economy	44300.00
0005433613479	9276	Economy	44300.00
0005433613464	9276	Economy	44300.00
0005433613492	9276	Economy	44300.00
0005433613487	9276	Economy	44300.00
0005433633275	9276	Economy	44300.00
0005433613528	9276	Economy	44300.00
0005433613494	9276	Economy	44300.00
0005433633274	9276	Economy	44300.00
0005433613529	9276	Economy	44300.00
0005433613520	9276	Economy	44300.00
0005433633269	9276	Economy	44300.00
0005433577596	9276	Economy	44300.00
0005433613496	9276	Economy	44300.00
0005433633282	9276	Economy	44300.00
0005432755023	9276	Economy	44300.00
0005433613500	9276	Economy	44300.00
0005433577600	9276	Economy	44300.00
0005433613489	9276	Economy	44300.00
0005432755022	9276	Economy	44300.00
0005432755021	9276	Economy	44300.00
0005433633264	9276	Economy	44300.00
0005433613514	9276	Economy	44300.00
0005432755024	9276	Economy	44300.00
0005433613488	9276	Economy	44300.00
0005433613501	9276	Economy	44300.00
0005433613473	9276	Economy	44300.00
0005433577602	9276	Economy	44300.00
0005433613531	9276	Economy	44300.00
0005433613503	9276	Economy	44300.00
0005433613497	9276	Economy	44300.00
0005433613484	9276	Economy	44300.00
0005434163474	25237	Business	132900.00
0005434163477	25237	Business	132900.00
0005434273049	25237	Economy	48700.00
0005434163471	25237	Economy	44300.00
0005434163472	25237	Economy	44300.00
0005434273048	25237	Economy	44300.00
0005434163480	25237	Economy	44300.00
0005434163473	25237	Economy	44300.00
0005434272163	25237	Economy	44300.00
0005434163470	25237	Economy	44300.00
0005434163479	25237	Economy	44300.00
0005434272164	25237	Economy	44300.00
0005434163475	25237	Economy	44300.00
0005434163476	25237	Economy	44300.00
0005434163478	25237	Economy	44300.00
0005435986658	4205	Business	193100.00
0005432184906	4205	Business	193100.00
0005435986657	4205	Business	193100.00
0005435986663	4205	Economy	70800.00
0005435986660	4205	Economy	64400.00
0005435986667	4205	Economy	64400.00
0005432184907	4205	Economy	64400.00
0005435986665	4205	Economy	64400.00
0005435986662	4205	Economy	64400.00
0005435986668	4205	Economy	64400.00
0005435986669	4205	Economy	64400.00
0005435986664	4205	Economy	64400.00
0005435986659	4205	Economy	64400.00
0005432184908	4205	Economy	64400.00
0005435986666	4205	Economy	64400.00
0005435986661	4205	Economy	64400.00
0005435947032	26564	Business	193100.00
0005435947029	26564	Business	193100.00
0005435947040	26564	Business	193100.00
0005435947038	26564	Economy	64400.00
0005435947034	26564	Economy	64400.00
0005435947033	26564	Economy	64400.00
0005435856138	26564	Economy	64400.00
0005435947035	26564	Economy	64400.00
0005435947030	26564	Economy	64400.00
0005435856139	26564	Economy	64400.00
0005432571265	26564	Economy	64400.00
0005435947028	26564	Economy	64400.00
0005435947026	26564	Economy	64400.00
0005435947039	26564	Economy	64400.00
0005435947027	26564	Economy	64400.00
0005432571264	26564	Economy	64400.00
0005435947031	26564	Economy	64400.00
0005435856141	26564	Economy	64400.00
0005432571266	26564	Economy	64400.00
0005435947036	26564	Economy	64400.00
0005435947041	26564	Economy	64400.00
0005432571267	26564	Economy	64400.00
0005435856140	26564	Economy	64400.00
0005435947037	26564	Economy	64400.00
0005433568188	358	Business	21500.00
0005433568187	358	Business	21500.00
0005433568134	358	Business	21500.00
0005433568126	358	Business	21500.00
0005432238840	358	Business	21500.00
0005433568165	358	Business	21500.00
0005433568190	358	Business	21500.00
0005433568173	358	Business	21500.00
0005433568147	358	Business	21500.00
0005433568135	358	Business	21500.00
0005433568144	358	Business	21500.00
0005433568136	358	Business	21500.00
0005433568183	358	Business	21500.00
0005433568129	358	Economy	7900.00
0005433568167	358	Economy	7900.00
0005433568162	358	Economy	7900.00
0005433568164	358	Economy	7200.00
0005433568139	358	Economy	7200.00
0005433568184	358	Economy	7200.00
0005433568142	358	Economy	7200.00
0005433568149	358	Economy	7200.00
0005433568163	358	Economy	7200.00
0005433568185	358	Economy	7200.00
0005433568157	358	Economy	7200.00
0005433568156	358	Economy	7200.00
0005433568125	358	Economy	7200.00
0005433568160	358	Economy	7200.00
0005433568170	358	Economy	7200.00
0005433568153	358	Economy	7200.00
0005433568189	358	Economy	7200.00
0005433568152	358	Economy	7200.00
0005433568151	358	Economy	7200.00
0005433568180	358	Economy	7200.00
0005433568186	358	Economy	7200.00
0005433568140	358	Economy	7200.00
0005433568182	358	Economy	7200.00
0005433568141	358	Economy	7200.00
0005433568169	358	Economy	7200.00
0005433568158	358	Economy	7200.00
0005433568178	358	Economy	7200.00
0005433568159	358	Economy	7200.00
0005433568150	358	Economy	7200.00
0005433568138	358	Economy	7900.00
0005433568176	358	Economy	7900.00
0005433568128	358	Economy	7200.00
0005433568191	358	Economy	7200.00
0005432238843	358	Economy	7200.00
0005433568168	358	Economy	7200.00
0005433568143	358	Economy	7200.00
0005433568175	358	Economy	7200.00
0005433568132	358	Economy	7200.00
0005433568181	358	Economy	7200.00
0005433568161	358	Economy	7200.00
0005433568145	358	Economy	7200.00
0005433568172	358	Economy	7200.00
0005433568127	358	Economy	7200.00
0005433568179	358	Economy	7200.00
0005433568137	358	Economy	7200.00
0005433568130	358	Economy	7200.00
0005433568154	358	Economy	7200.00
0005433568177	358	Economy	7200.00
0005432238845	358	Economy	7200.00
0005432238842	358	Economy	7200.00
0005433568166	358	Economy	7200.00
0005433568171	358	Economy	7200.00
0005433568131	358	Economy	7200.00
0005432238844	358	Economy	7200.00
0005433568146	358	Economy	7200.00
0005432238841	358	Economy	7200.00
0005433568155	358	Economy	7200.00
0005433568148	358	Economy	7200.00
0005433568124	358	Economy	7200.00
0005433568174	358	Economy	7200.00
0005433568133	358	Economy	7200.00
0005433074278	11570	Business	21500.00
0005433074283	11570	Business	21500.00
0005432947834	11570	Business	21500.00
0005432947812	11570	Business	21500.00
0005432947842	11570	Business	21500.00
0005432947839	11570	Business	21500.00
0005433074267	11570	Business	21500.00
0005432192270	11570	Business	21500.00
0005433074264	11570	Business	21500.00
0005432947811	11570	Business	21500.00
0005432947829	11570	Business	21500.00
0005432947809	11570	Business	21500.00
0005432947840	11570	Business	21500.00
0005432947832	11570	Economy	7900.00
0005433131635	11570	Economy	7900.00
0005432192272	11570	Economy	7900.00
0005433074280	11570	Economy	7200.00
0005432947820	11570	Economy	7200.00
0005433134069	11570	Economy	7200.00
0005433134065	11570	Economy	7200.00
0005432947805	11570	Economy	7200.00
0005432947830	11570	Economy	7200.00
0005432947831	11570	Economy	7200.00
0005432947838	11570	Economy	7200.00
0005433074260	11570	Economy	7200.00
0005433074276	11570	Economy	7200.00
0005433074269	11570	Economy	7200.00
0005433074263	11570	Economy	7200.00
0005432947836	11570	Economy	7200.00
0005432947843	11570	Economy	7200.00
0005432947833	11570	Economy	7200.00
0005433074282	11570	Economy	7200.00
0005432947841	11570	Economy	7200.00
0005432947845	11570	Economy	7200.00
0005433131637	11570	Economy	7200.00
0005433074262	11570	Economy	7200.00
0005433074274	11570	Economy	7200.00
0005433074271	11570	Economy	7200.00
0005433074272	11570	Economy	7200.00
0005433131638	11570	Economy	7200.00
0005432947837	11570	Economy	7200.00
0005432947814	11570	Economy	7200.00
0005433131636	11570	Economy	7900.00
0005433074268	11570	Economy	7900.00
0005433074266	11570	Economy	7900.00
0005432947835	11570	Economy	7200.00
0005433134068	11570	Economy	7200.00
0005432947823	11570	Economy	7900.00
0005432947808	11570	Economy	7200.00
0005432947844	11570	Economy	7200.00
0005432947815	11570	Economy	7200.00
0005432947806	11570	Economy	7200.00
0005432947826	11570	Economy	7200.00
0005433074256	11570	Economy	7200.00
0005433134066	11570	Economy	7200.00
0005432947828	11570	Economy	7200.00
0005433074275	11570	Economy	7200.00
0005432947816	11570	Economy	7200.00
0005433074270	11570	Economy	7200.00
0005432947827	11570	Economy	7200.00
0005432192271	11570	Economy	7200.00
0005433074281	11570	Economy	7200.00
0005432947822	11570	Economy	7200.00
0005432947824	11570	Economy	7200.00
0005433074279	11570	Economy	7200.00
0005432947817	11570	Economy	7200.00
0005432947813	11570	Economy	7200.00
0005432947807	11570	Economy	7200.00
0005433074258	11570	Economy	7200.00
0005433074261	11570	Economy	7200.00
0005433074277	11570	Economy	7200.00
0005433131639	11570	Economy	7200.00
0005433134067	11570	Economy	7200.00
0005432947818	11570	Economy	7200.00
0005432947819	11570	Economy	7200.00
0005433074273	11570	Economy	7200.00
0005432947825	11570	Economy	7200.00
0005432947821	11570	Economy	7200.00
0005433074259	11570	Economy	7200.00
0005433074257	11570	Economy	7200.00
0005432947810	11570	Economy	7200.00
0005433074265	11570	Economy	7200.00
0005433074255	11570	Economy	7200.00
0005433817414	10009	Economy	6300.00
0005433817413	10009	Economy	6300.00
0005433817412	10009	Economy	6300.00
0005434732928	13932	Economy	6300.00
0005434732927	13932	Economy	6300.00
0005434732926	13932	Economy	6300.00
0005435981616	2324	Business	184500.00
0005435981603	2324	Business	184500.00
0005433753383	2324	Business	184500.00
0005433753337	2324	Business	184500.00
0005435981630	2324	Business	184500.00
0005435981600	2324	Business	184500.00
0005433753389	2324	Business	184500.00
0005435981622	2324	Business	184500.00
0005433753354	2324	Business	184500.00
0005433753358	2324	Business	184500.00
0005432300177	2324	Business	184500.00
0005433753342	2324	Business	184500.00
0005435981629	2324	Business	184500.00
0005433753361	2324	Business	184500.00
0005432655362	2324	Business	184500.00
0005433753364	2324	Business	184500.00
0005432225962	2324	Business	184500.00
0005433753385	2324	Business	184500.00
0005435981626	2324	Business	184500.00
0005433753351	2324	Business	184500.00
0005433753371	2324	Business	184500.00
0005433753391	2324	Business	184500.00
0005433753360	2324	Business	184500.00
0005435981628	2324	Business	184500.00
0005433753349	2324	Economy	67700.00
0005433753375	2324	Economy	67700.00
0005433753379	2324	Economy	67700.00
0005432655361	2324	Economy	61500.00
0005433764647	2324	Economy	61500.00
0005435981632	2324	Economy	61500.00
0005435981633	2324	Economy	61500.00
0005435981606	2324	Economy	61500.00
0005435981624	2324	Economy	61500.00
0005433753359	2324	Economy	61500.00
0005435981607	2324	Economy	61500.00
0005433753390	2324	Economy	61500.00
0005435981638	2324	Economy	61500.00
0005433753382	2324	Economy	61500.00
0005433753363	2324	Economy	61500.00
0005432300173	2324	Economy	61500.00
0005433753357	2324	Economy	61500.00
0005433753388	2324	Economy	61500.00
0005433753347	2324	Economy	61500.00
0005432225963	2324	Economy	61500.00
0005433753340	2324	Economy	61500.00
0005433766583	2324	Economy	61500.00
0005433753352	2324	Economy	61500.00
0005435981612	2324	Economy	61500.00
0005433753386	2324	Economy	61500.00
0005433753374	2324	Economy	61500.00
0005432225961	2324	Economy	61500.00
0005435981604	2324	Economy	61500.00
0005435981631	2324	Economy	61500.00
0005435981625	2324	Economy	61500.00
0005435981597	2324	Economy	61500.00
0005435981635	2324	Economy	61500.00
0005435981641	2324	Economy	61500.00
0005435981618	2324	Economy	61500.00
0005432300176	2324	Economy	61500.00
0005433764648	2324	Economy	61500.00
0005433753392	2324	Economy	61500.00
0005432225965	2324	Economy	61500.00
0005435981608	2324	Economy	61500.00
0005435981594	2324	Economy	61500.00
0005435981615	2324	Economy	61500.00
0005435981627	2324	Economy	61500.00
0005433753373	2324	Economy	61500.00
0005433753338	2324	Economy	61500.00
0005433753365	2324	Economy	61500.00
0005432655360	2324	Economy	61500.00
0005432655353	2324	Economy	61500.00
0005433753355	2324	Economy	61500.00
0005433753344	2324	Economy	61500.00
0005433753387	2324	Economy	61500.00
0005435981598	2324	Economy	61500.00
0005433753377	2324	Economy	61500.00
0005433766581	2324	Economy	61500.00
0005433753393	2324	Economy	61500.00
0005433753378	2324	Economy	61500.00
0005433753366	2324	Economy	61500.00
0005433753339	2324	Economy	61500.00
0005433753350	2324	Economy	61500.00
0005433753384	2324	Economy	61500.00
0005433753345	2324	Economy	61500.00
0005435981642	2324	Economy	61500.00
0005433753369	2324	Economy	61500.00
0005432300175	2324	Economy	61500.00
0005435981636	2324	Economy	61500.00
0005435981610	2324	Economy	61500.00
0005433753381	2324	Economy	61500.00
0005435981596	2324	Economy	61500.00
0005432655357	2324	Economy	61500.00
0005432300172	2324	Economy	67700.00
0005435981613	2324	Economy	67700.00
0005435981617	2324	Economy	61500.00
0005433753336	2324	Economy	61500.00
0005432655351	2324	Economy	61500.00
0005435981639	2324	Economy	61500.00
0005435981634	2324	Economy	61500.00
0005432655355	2324	Economy	61500.00
0005435981609	2324	Economy	61500.00
0005435981619	2324	Economy	61500.00
0005433766584	2324	Economy	61500.00
0005435981601	2324	Economy	61500.00
0005433753362	2324	Economy	61500.00
0005433753346	2324	Economy	61500.00
0005433764649	2324	Economy	61500.00
0005433766582	2324	Economy	61500.00
0005435981614	2324	Economy	61500.00
0005433753372	2324	Economy	61500.00
0005433753343	2324	Economy	61500.00
0005433753353	2324	Economy	61500.00
0005435981623	2324	Economy	61500.00
0005435981640	2324	Economy	61500.00
0005432300174	2324	Economy	61500.00
0005433753367	2324	Economy	61500.00
0005432655358	2324	Economy	61500.00
0005435981602	2324	Economy	61500.00
0005432655350	2324	Economy	61500.00
0005435981621	2324	Economy	61500.00
0005433753380	2324	Economy	61500.00
0005435981620	2324	Economy	61500.00
0005435981644	2324	Economy	61500.00
0005433753376	2324	Economy	61500.00
0005433753356	2324	Economy	61500.00
0005432225960	2324	Economy	61500.00
0005432655356	2324	Economy	61500.00
0005435981595	2324	Economy	61500.00
0005433753370	2324	Economy	61500.00
0005433753348	2324	Economy	61500.00
0005432655354	2324	Economy	61500.00
0005432225964	2324	Economy	61500.00
0005435981643	2324	Economy	61500.00
0005435981637	2324	Economy	61500.00
0005435981605	2324	Economy	61500.00
0005432655359	2324	Economy	61500.00
0005435981599	2324	Economy	61500.00
0005433753341	2324	Economy	61500.00
0005433753368	2324	Economy	61500.00
0005432655352	2324	Economy	61500.00
0005435981611	2324	Economy	61500.00
0005432984567	26195	Business	184500.00
0005433434250	26195	Business	184500.00
0005433434265	26195	Business	184500.00
0005433434252	26195	Business	184500.00
0005432869419	26195	Business	184500.00
0005433434253	26195	Business	184500.00
0005432984573	26195	Business	184500.00
0005432984591	26195	Business	184500.00
0005432984596	26195	Business	184500.00
0005432984569	26195	Business	184500.00
0005432984578	26195	Economy	67700.00
0005432984572	26195	Economy	67700.00
0005432984597	26195	Economy	61500.00
0005432984590	26195	Economy	61500.00
0005432869418	26195	Economy	61500.00
0005432984571	26195	Economy	61500.00
0005433434257	26195	Economy	61500.00
0005432984595	26195	Economy	61500.00
0005432984576	26195	Economy	61500.00
0005432984592	26195	Economy	61500.00
0005432869421	26195	Economy	61500.00
0005434731108	26195	Economy	61500.00
0005432984574	26195	Economy	61500.00
0005433434254	26195	Economy	61500.00
0005433434239	26195	Economy	61500.00
0005432984581	26195	Economy	61500.00
0005432984568	26195	Economy	61500.00
0005434731105	26195	Economy	61500.00
0005432984599	26195	Economy	61500.00
0005433434237	26195	Economy	61500.00
0005433434262	26195	Economy	61500.00
0005432984588	26195	Economy	61500.00
0005434731107	26195	Economy	61500.00
0005433434249	26195	Economy	61500.00
0005433434246	26195	Economy	61500.00
0005434731106	26195	Economy	61500.00
0005433434258	26195	Economy	61500.00
0005433434251	26195	Economy	61500.00
0005432984570	26195	Economy	61500.00
0005432984589	26195	Economy	61500.00
0005432869422	26195	Economy	61500.00
0005433434263	26195	Economy	61500.00
0005432984598	26195	Economy	61500.00
0005433434238	26195	Economy	61500.00
0005432984575	26195	Economy	61500.00
0005432984579	26195	Economy	61500.00
0005432984594	26195	Economy	61500.00
0005432049407	26195	Economy	67700.00
0005432984584	26195	Economy	61500.00
0005433434244	26195	Economy	67700.00
0005433434256	26195	Economy	61500.00
0005432984593	26195	Economy	61500.00
0005433434242	26195	Economy	61500.00
0005432049410	26195	Economy	61500.00
0005432984583	26195	Economy	61500.00
0005432984577	26195	Economy	61500.00
0005432869420	26195	Economy	61500.00
0005432049409	26195	Economy	61500.00
0005433434259	26195	Economy	61500.00
0005432051079	26195	Economy	61500.00
0005433434261	26195	Economy	61500.00
0005432984586	26195	Economy	61500.00
0005432869417	26195	Economy	61500.00
0005432984580	26195	Economy	61500.00
0005434731104	26195	Economy	61500.00
0005433434248	26195	Economy	61500.00
0005432051080	26195	Economy	61500.00
0005433434240	26195	Economy	61500.00
0005433434243	26195	Economy	61500.00
0005433434247	26195	Economy	61500.00
0005432984585	26195	Economy	61500.00
0005433434241	26195	Economy	61500.00
0005433434264	26195	Economy	61500.00
0005433434260	26195	Economy	61500.00
0005432051081	26195	Economy	61500.00
0005432984582	26195	Economy	61500.00
0005432984587	26195	Economy	61500.00
0005432051082	26195	Economy	61500.00
0005432049408	26195	Economy	61500.00
0005433434255	26195	Economy	61500.00
0005433434245	26195	Economy	61500.00
0005432869423	26195	Economy	61500.00
0005434373955	1494	Business	38900.00
0005434373984	1494	Business	38900.00
0005434373948	1494	Business	38900.00
0005434373988	1494	Economy	13000.00
0005434373987	1494	Economy	13000.00
0005432267795	1494	Economy	13000.00
0005432267792	1494	Economy	13000.00
0005434373994	1494	Economy	13000.00
0005434373974	1494	Economy	13000.00
0005432267791	1494	Economy	13000.00
0005434373973	1494	Economy	13000.00
0005434373968	1494	Economy	13000.00
0005434373977	1494	Economy	13000.00
0005434373978	1494	Economy	13000.00
0005434373966	1494	Economy	13000.00
0005434373956	1494	Economy	13000.00
0005434373964	1494	Economy	13000.00
0005434373991	1494	Economy	13000.00
0005434373975	1494	Economy	13000.00
0005432267790	1494	Economy	13000.00
0005434373971	1494	Economy	13000.00
0005434373957	1494	Economy	13000.00
0005433150827	1494	Economy	14300.00
0005434373952	1494	Economy	14300.00
0005434373963	1494	Economy	14300.00
0005434373979	1494	Economy	13000.00
0005434373993	1494	Economy	13000.00
0005434373945	1494	Economy	13000.00
0005434373958	1494	Economy	13000.00
0005434373960	1494	Economy	13000.00
0005434373982	1494	Economy	13000.00
0005434373970	1494	Economy	13000.00
0005434373967	1494	Economy	13000.00
0005433461554	1494	Economy	13000.00
0005434373983	1494	Economy	13000.00
0005434373959	1494	Economy	13000.00
0005434373986	1494	Economy	13000.00
0005434373962	1494	Economy	13000.00
0005434373950	1494	Economy	13000.00
0005434373980	1494	Economy	13000.00
0005433460403	1494	Economy	13000.00
0005433460404	1494	Economy	13000.00
0005434373961	1494	Economy	13000.00
0005432267793	1494	Economy	13000.00
0005432267796	1494	Economy	13000.00
0005434373969	1494	Economy	13000.00
0005434373965	1494	Economy	13000.00
0005434373976	1494	Economy	13000.00
0005434373990	1494	Economy	13000.00
0005433461555	1494	Economy	13000.00
0005434373953	1494	Economy	13000.00
0005434373989	1494	Economy	13000.00
0005432267794	1494	Economy	13000.00
0005433460402	1494	Economy	13000.00
0005434373954	1494	Economy	13000.00
0005434373985	1494	Economy	13000.00
0005434373981	1494	Economy	13000.00
0005434373946	1494	Economy	13000.00
0005434373949	1494	Economy	13000.00
0005434373992	1494	Economy	13000.00
0005434373951	1494	Economy	13000.00
0005434373947	1494	Economy	13000.00
0005434373972	1494	Economy	13000.00
0005433764648	20123	Business	38900.00
0005433150874	20123	Business	38900.00
0005433150884	20123	Business	38900.00
0005433150877	20123	Business	38900.00
0005433150893	20123	Economy	13000.00
0005433150896	20123	Economy	13000.00
0005433150885	20123	Economy	13000.00
0005433150864	20123	Economy	13000.00
0005433150873	20123	Economy	13000.00
0005433150897	20123	Economy	13000.00
0005434029619	20123	Economy	13000.00
0005433150871	20123	Economy	13000.00
0005432056239	20123	Economy	13000.00
0005434029620	20123	Economy	13000.00
0005433150889	20123	Economy	13000.00
0005433150882	20123	Economy	13000.00
0005433150891	20123	Economy	13000.00
0005433931421	20123	Economy	14300.00
0005433764649	20123	Economy	14300.00
0005433150892	20123	Economy	13000.00
0005433150868	20123	Economy	13000.00
0005433150883	20123	Economy	13000.00
0005433150869	20123	Economy	13000.00
0005433931420	20123	Economy	13000.00
0005433150895	20123	Economy	13000.00
0005433150887	20123	Economy	13000.00
0005432056240	20123	Economy	13000.00
0005433150867	20123	Economy	13000.00
0005433150890	20123	Economy	13000.00
0005433150886	20123	Economy	13000.00
0005433150894	20123	Economy	13000.00
0005433150875	20123	Economy	13000.00
0005433150898	20123	Economy	13000.00
0005433150865	20123	Economy	13000.00
0005433150866	20123	Economy	13000.00
0005433150879	20123	Economy	13000.00
0005433150881	20123	Economy	13000.00
0005432056241	20123	Economy	13000.00
0005433931422	20123	Economy	13000.00
0005433150876	20123	Economy	13000.00
0005432056242	20123	Economy	13000.00
0005433150872	20123	Economy	13000.00
0005433150878	20123	Economy	13000.00
0005433150880	20123	Economy	13000.00
0005433764647	20123	Economy	13000.00
0005433150888	20123	Economy	13000.00
0005433150870	20123	Economy	13000.00
0005432423737	508	Business	27500.00
0005432423717	508	Business	27500.00
0005432282759	508	Business	27500.00
0005432423720	508	Business	27500.00
0005432423730	508	Business	27500.00
0005432282756	508	Business	27500.00
0005432423713	508	Business	27500.00
0005432423695	508	Business	27500.00
0005432423716	508	Business	27500.00
0005432423755	508	Business	27500.00
0005432423761	508	Business	27500.00
0005432423709	508	Economy	10100.00
0005432282757	508	Economy	10100.00
0005432423714	508	Economy	10100.00
0005432423728	508	Economy	9200.00
0005432423722	508	Economy	9200.00
0005432423757	508	Economy	9200.00
0005432423742	508	Economy	9200.00
0005432423754	508	Economy	9200.00
0005432423707	508	Economy	9200.00
0005432282755	508	Economy	9200.00
0005432423701	508	Economy	9200.00
0005432423702	508	Economy	9200.00
0005432423705	508	Economy	9200.00
0005432423731	508	Economy	9200.00
0005432423747	508	Economy	9200.00
0005432423740	508	Economy	9200.00
0005432423724	508	Economy	9200.00
0005432423725	508	Economy	9200.00
0005432423734	508	Economy	9200.00
0005432423718	508	Economy	9200.00
0005432423756	508	Economy	9200.00
0005432423715	508	Economy	9200.00
0005432423745	508	Economy	9200.00
0005432423752	508	Economy	9200.00
0005432423694	508	Economy	9200.00
0005432423760	508	Economy	9200.00
0005432423719	508	Economy	9200.00
0005432423711	508	Economy	9200.00
0005432423736	508	Economy	9200.00
0005432423741	508	Economy	9200.00
0005432423710	508	Economy	10100.00
0005432423762	508	Economy	9200.00
0005432423753	508	Economy	10100.00
0005432423735	508	Economy	9200.00
0005432423697	508	Economy	9200.00
0005432423723	508	Economy	9200.00
0005432423704	508	Economy	9200.00
0005432423706	508	Economy	9200.00
0005432423738	508	Economy	9200.00
0005432423739	508	Economy	9200.00
0005432423744	508	Economy	9200.00
0005432282758	508	Economy	9200.00
0005432423733	508	Economy	9200.00
0005432423703	508	Economy	9200.00
0005432423708	508	Economy	9200.00
0005432423743	508	Economy	9200.00
0005432423751	508	Economy	9200.00
0005432423712	508	Economy	9200.00
0005432423759	508	Economy	9200.00
0005432423700	508	Economy	9200.00
0005432423727	508	Economy	9200.00
0005432423749	508	Economy	9200.00
0005432423726	508	Economy	9200.00
0005432423729	508	Economy	9200.00
0005432423696	508	Economy	9200.00
0005432423746	508	Economy	9200.00
0005432423732	508	Economy	9200.00
0005432423748	508	Economy	9200.00
0005432423699	508	Economy	9200.00
0005432423758	508	Economy	9200.00
0005432423750	508	Economy	9200.00
0005432423721	508	Economy	9200.00
0005432423698	508	Economy	9200.00
0005432302273	12905	Economy	9200.00
0005432302274	12905	Economy	10100.00
0005432302272	12905	Economy	9200.00
0005433158096	12905	Economy	9200.00
0005433158098	12905	Economy	9200.00
0005433158095	12905	Economy	9200.00
0005433158097	12905	Economy	9200.00
0005434022696	440	Business	24500.00
0005434022694	440	Business	24500.00
0005434022671	440	Business	24500.00
0005434022664	440	Business	24500.00
0005434029616	440	Business	24500.00
0005434022684	440	Business	24500.00
0005434022695	440	Business	24500.00
0005434022652	440	Business	24500.00
0005434022643	440	Business	24500.00
0005434022673	440	Business	24500.00
0005432235520	440	Business	24500.00
0005434022707	440	Business	24500.00
0005434022700	440	Business	24500.00
0005432235522	440	Business	24500.00
0005434022670	440	Economy	9000.00
0005432235525	440	Economy	9000.00
0005432235526	440	Economy	9000.00
0005434022649	440	Economy	8200.00
0005432045582	440	Economy	8200.00
0005434022647	440	Economy	8200.00
0005434022686	440	Economy	8200.00
0005434022682	440	Economy	8200.00
0005434022693	440	Economy	8200.00
0005434022685	440	Economy	8200.00
0005434022698	440	Economy	8200.00
0005434022672	440	Economy	8200.00
0005434022680	440	Economy	8200.00
0005434022669	440	Economy	8200.00
0005434031951	440	Economy	8200.00
0005434028252	440	Economy	8200.00
0005434022656	440	Economy	8200.00
0005434022704	440	Economy	8200.00
0005434022676	440	Economy	8200.00
0005434022645	440	Economy	8200.00
0005434022642	440	Economy	8200.00
0005434022678	440	Economy	8200.00
0005434022651	440	Economy	8200.00
0005432235519	440	Economy	8200.00
0005434022702	440	Economy	8200.00
0005434022697	440	Economy	8200.00
0005434028251	440	Economy	8200.00
0005434022701	440	Economy	8200.00
0005434022644	440	Economy	8200.00
0005434022691	440	Economy	8200.00
0005434022662	440	Economy	8200.00
0005434022667	440	Economy	8200.00
0005434022692	440	Economy	8200.00
0005432045583	440	Economy	8200.00
0005434022677	440	Economy	8200.00
0005432235523	440	Economy	8200.00
0005434022654	440	Economy	8200.00
0005434022703	440	Economy	8200.00
0005434022668	440	Economy	8200.00
0005434031950	440	Economy	8200.00
0005434022679	440	Economy	8200.00
0005434022659	440	Economy	8200.00
0005434022705	440	Economy	8200.00
0005434022706	440	Economy	8200.00
0005434029617	440	Economy	8200.00
0005434022699	440	Economy	8200.00
0005434022674	440	Economy	8200.00
0005434022640	440	Economy	8200.00
0005434028250	440	Economy	9000.00
0005434022648	440	Economy	8200.00
0005434022688	440	Economy	9000.00
0005434029618	440	Economy	8200.00
0005434022660	440	Economy	8200.00
0005434022708	440	Economy	8200.00
0005434022663	440	Economy	8200.00
0005434022687	440	Economy	8200.00
0005434022683	440	Economy	8200.00
0005434022681	440	Economy	8200.00
0005434031949	440	Economy	8200.00
0005434022653	440	Economy	8200.00
0005434028253	440	Economy	8200.00
0005434022661	440	Economy	8200.00
0005434022690	440	Economy	8200.00
0005434022666	440	Economy	8200.00
0005434022658	440	Economy	8200.00
0005434022641	440	Economy	8200.00
0005434031948	440	Economy	8200.00
0005434022657	440	Economy	8200.00
0005434022655	440	Economy	8200.00
0005434022646	440	Economy	8200.00
0005434022650	440	Economy	8200.00
0005432235521	440	Economy	8200.00
0005434022689	440	Economy	8200.00
0005434031952	440	Economy	8200.00
0005432235524	440	Economy	8200.00
0005434022639	440	Economy	8200.00
0005434022675	440	Economy	8200.00
0005434022665	440	Economy	8200.00
0005433057258	12671	Business	24500.00
0005432156298	12671	Business	24500.00
0005433057263	12671	Business	24500.00
0005433057262	12671	Business	24500.00
0005433929550	12671	Business	24500.00
0005433057252	12671	Business	24500.00
0005433057280	12671	Business	24500.00
0005433057277	12671	Business	24500.00
0005433684389	12671	Economy	8200.00
0005433057251	12671	Economy	8200.00
0005433057284	12671	Economy	8200.00
0005432156299	12671	Economy	8200.00
0005433057267	12671	Economy	8200.00
0005432157462	12671	Economy	8200.00
0005433057274	12671	Economy	8200.00
0005433057264	12671	Economy	8200.00
0005433929547	12671	Economy	8200.00
0005433057270	12671	Economy	8200.00
0005433057285	12671	Economy	8200.00
0005432157461	12671	Economy	8200.00
0005432157463	12671	Economy	8200.00
0005433057281	12671	Economy	8200.00
0005433057287	12671	Economy	8200.00
0005433057256	12671	Economy	8200.00
0005433057288	12671	Economy	8200.00
0005433057289	12671	Economy	8200.00
0005433929552	12671	Economy	8200.00
0005434735612	12671	Economy	8200.00
0005432156297	12671	Economy	8200.00
0005432156295	12671	Economy	8200.00
0005433057255	12671	Economy	8200.00
0005433057266	12671	Economy	8200.00
0005433057259	12671	Economy	8200.00
0005433057282	12671	Economy	8200.00
0005433057290	12671	Economy	9000.00
0005433057278	12671	Economy	8200.00
0005433057268	12671	Economy	8200.00
0005433057250	12671	Economy	8200.00
0005433929548	12671	Economy	8200.00
0005434735611	12671	Economy	8200.00
0005433057276	12671	Economy	8200.00
0005433057260	12671	Economy	8200.00
0005433057265	12671	Economy	8200.00
0005433057283	12671	Economy	8200.00
0005434735608	12671	Economy	8200.00
0005433057271	12671	Economy	8200.00
0005433057261	12671	Economy	8200.00
0005433057257	12671	Economy	8200.00
0005433929551	12671	Economy	8200.00
0005432156296	12671	Economy	8200.00
0005433057269	12671	Economy	8200.00
0005433057253	12671	Economy	8200.00
0005433057272	12671	Economy	8200.00
0005434735609	12671	Economy	8200.00
0005433929549	12671	Economy	8200.00
0005434735610	12671	Economy	8200.00
0005433057279	12671	Economy	8200.00
0005433057254	12671	Economy	8200.00
0005433057286	12671	Economy	8200.00
0005433057273	12671	Economy	8200.00
0005433057275	12671	Economy	8200.00
0005434735607	12671	Economy	8200.00
0005433921847	2113	Business	34700.00
0005433921826	2113	Business	34700.00
0005433921824	2113	Business	34700.00
0005433921836	2113	Business	34700.00
0005433921830	2113	Business	34700.00
0005433921842	2113	Business	34700.00
0005433921827	2113	Business	34700.00
0005433921865	2113	Business	34700.00
0005433921875	2113	Business	34700.00
0005432231401	2113	Business	34700.00
0005433921816	2113	Business	34700.00
0005432044482	2113	Business	34700.00
0005433921880	2113	Business	34700.00
0005432231403	2113	Business	34700.00
0005433921796	2113	Business	34700.00
0005433921807	2113	Business	34700.00
0005433921806	2113	Business	34700.00
0005433921799	2113	Business	34700.00
0005433921848	2113	Business	34700.00
0005433929550	2113	Economy	12700.00
0005433921783	2113	Business	34700.00
0005433921860	2113	Economy	12700.00
0005433921797	2113	Economy	11600.00
0005433921789	2113	Economy	11600.00
0005433921868	2113	Economy	11600.00
0005433921873	2113	Economy	11600.00
0005433921863	2113	Economy	11600.00
0005432231399	2113	Economy	11600.00
0005432231397	2113	Economy	11600.00
0005433921820	2113	Economy	11600.00
0005433921801	2113	Economy	11600.00
0005433921853	2113	Economy	11600.00
0005433921794	2113	Economy	11600.00
0005433921791	2113	Economy	11600.00
0005433921817	2113	Economy	11600.00
0005433921792	2113	Economy	11600.00
0005433875353	2113	Economy	11600.00
0005433921855	2113	Economy	11600.00
0005433921843	2113	Economy	11600.00
0005433921822	2113	Economy	11600.00
0005433921864	2113	Economy	11600.00
0005433921874	2113	Economy	11600.00
0005433921858	2113	Economy	11600.00
0005433921869	2113	Economy	11600.00
0005433921844	2113	Economy	11600.00
0005432231405	2113	Economy	11600.00
0005433921814	2113	Economy	11600.00
0005433921845	2113	Economy	11600.00
0005433921784	2113	Economy	11600.00
0005433921840	2113	Economy	11600.00
0005433921835	2113	Economy	11600.00
0005433921839	2113	Economy	11600.00
0005433921857	2113	Economy	11600.00
0005433929548	2113	Economy	11600.00
0005433921825	2113	Economy	11600.00
0005433929551	2113	Economy	11600.00
0005433921804	2113	Economy	11600.00
0005432231404	2113	Economy	11600.00
0005433921861	2113	Economy	11600.00
0005433921819	2113	Economy	11600.00
0005433931420	2113	Economy	11600.00
0005433921795	2113	Economy	11600.00
0005433921832	2113	Economy	11600.00
0005433921810	2113	Economy	11600.00
0005433921859	2113	Economy	11600.00
0005433921821	2113	Economy	11600.00
0005433921877	2113	Economy	11600.00
0005433929552	2113	Economy	11600.00
0005433921808	2113	Economy	11600.00
0005433921829	2113	Economy	11600.00
0005433921879	2113	Economy	11600.00
0005433921818	2113	Economy	11600.00
0005433921809	2113	Economy	11600.00
0005433921793	2113	Economy	12700.00
0005433921841	2113	Economy	11600.00
0005433921790	2113	Economy	11600.00
0005433931422	2113	Economy	11600.00
0005433921785	2113	Economy	11600.00
0005433921872	2113	Economy	11600.00
0005432231400	2113	Economy	11600.00
0005433921870	2113	Economy	11600.00
0005433921823	2113	Economy	11600.00
0005433921856	2113	Economy	11600.00
0005433921838	2113	Economy	11600.00
0005432231406	2113	Economy	11600.00
0005433875354	2113	Economy	11600.00
0005432044481	2113	Economy	11600.00
0005433921837	2113	Economy	11600.00
0005433929547	2113	Economy	11600.00
0005433921862	2113	Economy	11600.00
0005433921786	2113	Economy	11600.00
0005433921802	2113	Economy	11600.00
0005433921867	2113	Economy	11600.00
0005433921787	2113	Economy	11600.00
0005433921878	2113	Economy	11600.00
0005433921812	2113	Economy	11600.00
0005432231402	2113	Economy	11600.00
0005433921833	2113	Economy	11600.00
0005433921876	2113	Economy	11600.00
0005433921803	2113	Economy	11600.00
0005433921871	2113	Economy	11600.00
0005433921846	2113	Economy	11600.00
0005433921834	2113	Economy	11600.00
0005433921851	2113	Economy	11600.00
0005433921854	2113	Economy	11600.00
0005433921815	2113	Economy	11600.00
0005433921850	2113	Economy	11600.00
0005433921798	2113	Economy	11600.00
0005433921813	2113	Economy	11600.00
0005432231398	2113	Economy	11600.00
0005433921788	2113	Economy	11600.00
0005433931421	2113	Economy	11600.00
0005433929549	2113	Economy	11600.00
0005433921866	2113	Economy	11600.00
0005433921831	2113	Economy	11600.00
0005433921800	2113	Economy	11600.00
0005433921828	2113	Economy	11600.00
0005433921805	2113	Economy	11600.00
0005433921849	2113	Economy	11600.00
0005433921811	2113	Economy	11600.00
0005433921852	2113	Economy	11600.00
0005433035511	24135	Business	34700.00
0005433035507	24135	Business	34700.00
0005433035515	24135	Business	34700.00
0005433035476	24135	Business	34700.00
0005433035466	24135	Business	34700.00
0005433035494	24135	Business	34700.00
0005433035469	24135	Business	34700.00
0005432749752	24135	Business	34700.00
0005433035484	24135	Economy	12700.00
0005433035468	24135	Economy	11600.00
0005433035514	24135	Economy	11600.00
0005433035495	24135	Economy	11600.00
0005433035490	24135	Economy	11600.00
0005433035474	24135	Economy	11600.00
0005433035516	24135	Economy	11600.00
0005433035491	24135	Economy	11600.00
0005433035488	24135	Economy	11600.00
0005433035475	24135	Economy	11600.00
0005433035506	24135	Economy	11600.00
0005433035499	24135	Economy	11600.00
0005432206103	24135	Economy	11600.00
0005433035512	24135	Economy	11600.00
0005433035497	24135	Economy	11600.00
0005433035510	24135	Economy	11600.00
0005433035485	24135	Economy	11600.00
0005433035472	24135	Economy	11600.00
0005433035513	24135	Economy	11600.00
0005433035489	24135	Economy	11600.00
0005433035501	24135	Economy	11600.00
0005432749751	24135	Economy	11600.00
0005433035465	24135	Economy	11600.00
0005433035500	24135	Economy	11600.00
0005433035478	24135	Economy	11600.00
0005432206108	24135	Economy	11600.00
0005433035481	24135	Economy	11600.00
0005433035493	24135	Economy	11600.00
0005434028254	24135	Economy	11600.00
0005434028256	24135	Economy	11600.00
0005432207623	24135	Economy	11600.00
0005432206109	24135	Economy	11600.00
0005432207622	24135	Economy	11600.00
0005433035477	24135	Economy	11600.00
0005433035464	24135	Economy	12700.00
0005433035487	24135	Economy	11600.00
0005433035473	24135	Economy	11600.00
0005433035509	24135	Economy	12700.00
0005433035480	24135	Economy	11600.00
0005433035518	24135	Economy	11600.00
0005433035498	24135	Economy	11600.00
0005433035503	24135	Economy	11600.00
0005433035517	24135	Economy	11600.00
0005433035496	24135	Economy	11600.00
0005433035504	24135	Economy	11600.00
0005433035471	24135	Economy	11600.00
0005433035482	24135	Economy	11600.00
0005433035505	24135	Economy	11600.00
0005432206105	24135	Economy	11600.00
0005433035470	24135	Economy	11600.00
0005432206104	24135	Economy	11600.00
0005433035479	24135	Economy	11600.00
0005433035467	24135	Economy	11600.00
0005434028255	24135	Economy	11600.00
0005433035492	24135	Economy	11600.00
0005433035483	24135	Economy	11600.00
0005432206106	24135	Economy	11600.00
0005433035502	24135	Economy	11600.00
0005433035486	24135	Economy	11600.00
0005433035508	24135	Economy	11600.00
0005432206107	24135	Economy	11600.00
0005432277598	245	Business	83700.00
0005434550379	245	Business	83700.00
0005434723600	245	Business	83700.00
0005434550397	245	Business	83700.00
0005434550391	245	Business	83700.00
0005434550377	245	Business	83700.00
0005435142369	245	Business	83700.00
0005434550416	245	Business	83700.00
0005434723570	245	Business	83700.00
0005434723680	245	Business	83700.00
0005434723633	245	Business	83700.00
0005434723625	245	Business	83700.00
0005434550392	245	Business	83700.00
0005434550409	245	Business	83700.00
0005434723663	245	Business	83700.00
0005434550407	245	Comfort	47400.00
0005434723589	245	Comfort	47400.00
0005435142367	245	Comfort	47400.00
0005434723669	245	Comfort	47400.00
0005432277600	245	Comfort	47400.00
0005434723656	245	Comfort	47400.00
0005434723575	245	Comfort	47400.00
0005434550412	245	Comfort	47400.00
0005434550373	245	Comfort	47400.00
0005434550393	245	Comfort	47400.00
0005434723594	245	Comfort	47400.00
0005432277609	245	Comfort	47400.00
0005435142374	245	Comfort	47400.00
0005434723557	245	Comfort	47400.00
0005434723559	245	Comfort	47400.00
0005432277608	245	Comfort	47400.00
0005434723657	245	Comfort	47400.00
0005435142373	245	Comfort	47400.00
0005434723562	245	Comfort	47400.00
0005434550371	245	Comfort	47400.00
0005434723627	245	Comfort	47400.00
0005434723558	245	Comfort	47400.00
0005434723621	245	Comfort	47400.00
0005434723564	245	Comfort	47400.00
0005434723672	245	Comfort	47400.00
0005434735606	245	Comfort	47400.00
0005434735605	245	Comfort	47400.00
0005434723666	245	Comfort	47400.00
0005434723606	245	Comfort	47400.00
0005434723642	245	Comfort	47400.00
0005434550411	245	Economy	27900.00
0005434723643	245	Economy	27900.00
0005434723580	245	Economy	27900.00
0005434723645	245	Economy	27900.00
0005434723602	245	Economy	27900.00
0005434550374	245	Economy	27900.00
0005434723639	245	Economy	27900.00
0005434723662	245	Economy	27900.00
0005434723665	245	Economy	27900.00
0005434550389	245	Economy	27900.00
0005434723597	245	Economy	27900.00
0005434723628	245	Economy	27900.00
0005434550406	245	Economy	27900.00
0005434723572	245	Economy	27900.00
0005434723566	245	Economy	27900.00
0005432277606	245	Economy	27900.00
0005434723631	245	Economy	27900.00
0005434550417	245	Economy	27900.00
0005434550418	245	Economy	27900.00
0005434723664	245	Economy	27900.00
0005434723649	245	Economy	27900.00
0005434723578	245	Economy	27900.00
0005434550399	245	Economy	27900.00
0005434723567	245	Economy	27900.00
0005434723682	245	Economy	27900.00
0005434550420	245	Economy	27900.00
0005434723622	245	Economy	27900.00
0005434723626	245	Economy	27900.00
0005434723652	245	Economy	27900.00
0005434723583	245	Economy	27900.00
0005434302391	245	Economy	27900.00
0005435142371	245	Economy	27900.00
0005434723614	245	Economy	27900.00
0005434723667	245	Economy	27900.00
0005434723620	245	Economy	27900.00
0005434550376	245	Economy	27900.00
0005434723582	245	Economy	27900.00
0005434723584	245	Economy	27900.00
0005435142372	245	Economy	27900.00
0005435142366	245	Economy	27900.00
0005434550403	245	Economy	27900.00
0005434550402	245	Economy	27900.00
0005434723660	245	Economy	27900.00
0005434731101	245	Economy	27900.00
0005432277607	245	Economy	27900.00
0005434723679	245	Economy	30700.00
0005432277597	245	Economy	30700.00
0005434550380	245	Economy	30700.00
0005435142370	245	Economy	27900.00
0005434723637	245	Economy	27900.00
0005434550424	245	Economy	27900.00
0005432277602	245	Economy	27900.00
0005434723613	245	Economy	27900.00
0005434723595	245	Economy	27900.00
0005434723644	245	Economy	27900.00
0005434723560	245	Economy	27900.00
0005434723585	245	Economy	27900.00
0005434723617	245	Economy	27900.00
0005434550370	245	Economy	27900.00
0005432277601	245	Economy	27900.00
0005434550404	245	Economy	27900.00
0005434723571	245	Economy	27900.00
0005434723563	245	Economy	27900.00
0005434550369	245	Economy	27900.00
0005434723648	245	Economy	27900.00
0005434731102	245	Economy	27900.00
0005432277599	245	Economy	27900.00
0005432277605	245	Economy	27900.00
0005434723615	245	Economy	27900.00
0005432277604	245	Economy	27900.00
0005434723681	245	Economy	27900.00
0005434735604	245	Economy	27900.00
0005434723610	245	Economy	27900.00
0005434723587	245	Economy	27900.00
0005434723588	245	Economy	27900.00
0005434723673	245	Economy	27900.00
0005434550408	245	Economy	27900.00
0005434550394	245	Economy	27900.00
0005434550372	245	Economy	27900.00
0005434723640	245	Economy	27900.00
0005434723674	245	Economy	27900.00
0005434723561	245	Economy	27900.00
0005434735603	245	Economy	27900.00
0005434723647	245	Economy	27900.00
0005434550375	245	Economy	27900.00
0005434723675	245	Economy	27900.00
0005434723601	245	Economy	27900.00
0005434550423	245	Economy	27900.00
0005434550405	245	Economy	27900.00
0005435142363	245	Economy	27900.00
0005435142364	245	Economy	27900.00
0005434723629	245	Economy	27900.00
0005434550396	245	Economy	27900.00
0005434735602	245	Economy	27900.00
0005434723579	245	Economy	27900.00
0005434550395	245	Economy	27900.00
0005434550378	245	Economy	27900.00
0005434723659	245	Economy	27900.00
0005434723586	245	Economy	27900.00
0005434723670	245	Economy	27900.00
0005434723607	245	Economy	27900.00
0005434723611	245	Economy	27900.00
0005435142365	245	Economy	27900.00
0005434731100	245	Economy	27900.00
0005434723612	245	Economy	27900.00
0005434723576	245	Economy	27900.00
0005435142375	245	Economy	27900.00
0005434550410	245	Economy	27900.00
0005434723609	245	Economy	27900.00
0005434723641	245	Economy	27900.00
0005434723646	245	Economy	27900.00
0005434723593	245	Economy	27900.00
0005434723636	245	Economy	30700.00
0005434550413	245	Economy	30700.00
0005434723632	245	Economy	30700.00
0005434550383	245	Economy	27900.00
0005434723604	245	Economy	27900.00
0005434723568	245	Economy	27900.00
0005434723658	245	Economy	27900.00
0005434550401	245	Economy	27900.00
0005434723653	245	Economy	27900.00
0005434723596	245	Economy	27900.00
0005434723603	245	Economy	27900.00
0005434723661	245	Economy	27900.00
0005434550381	245	Economy	27900.00
0005434723565	245	Economy	27900.00
0005434723573	245	Economy	27900.00
0005434723592	245	Economy	27900.00
0005434723650	245	Economy	27900.00
0005434723676	245	Economy	27900.00
0005434550415	245	Economy	27900.00
0005434550386	245	Economy	27900.00
0005434723671	245	Economy	27900.00
0005432277603	245	Economy	27900.00
0005434302394	245	Economy	27900.00
0005434723634	245	Economy	27900.00
0005434723608	245	Economy	27900.00
0005434723655	245	Economy	27900.00
0005434723623	245	Economy	27900.00
0005434723654	245	Economy	27900.00
0005434550422	245	Economy	27900.00
0005434723581	245	Economy	27900.00
0005434723678	245	Economy	27900.00
0005434550419	245	Economy	27900.00
0005434550421	245	Economy	27900.00
0005434723616	245	Economy	27900.00
0005434302392	245	Economy	27900.00
0005434723677	245	Economy	27900.00
0005434723651	245	Economy	27900.00
0005434723569	245	Economy	27900.00
0005434731103	245	Economy	27900.00
0005434723638	245	Economy	27900.00
0005434550387	245	Economy	27900.00
0005434550398	245	Economy	27900.00
0005434723590	245	Economy	27900.00
0005434723624	245	Economy	27900.00
0005434723619	245	Economy	27900.00
0005434550384	245	Economy	27900.00
0005434723630	245	Economy	27900.00
0005435142376	245	Economy	27900.00
0005434723605	245	Economy	27900.00
0005434723635	245	Economy	27900.00
0005434550414	245	Economy	27900.00
0005435142368	245	Economy	27900.00
0005434723598	245	Economy	27900.00
0005434302393	245	Economy	27900.00
0005434550382	245	Economy	27900.00
0005434723618	245	Economy	27900.00
0005434723668	245	Economy	27900.00
0005434550400	245	Economy	27900.00
0005434723577	245	Economy	27900.00
0005434550388	245	Economy	27900.00
0005434723574	245	Economy	27900.00
0005434723591	245	Economy	27900.00
0005434550385	245	Economy	27900.00
0005434723599	245	Economy	27900.00
0005434550390	245	Economy	27900.00
0005433233261	9858	Business	83700.00
0005433233254	9858	Business	83700.00
0005433180706	9858	Business	83700.00
0005433233263	9858	Business	83700.00
0005433233238	9858	Business	83700.00
0005433766582	9858	Business	83700.00
0005433233211	9858	Business	83700.00
0005433180707	9858	Comfort	47400.00
0005433233244	9858	Comfort	47400.00
0005433233236	9858	Comfort	47400.00
0005432199139	9858	Comfort	47400.00
0005433180704	9858	Comfort	47400.00
0005433233270	9858	Comfort	47400.00
0005433233231	9858	Comfort	47400.00
0005433289732	9858	Comfort	47400.00
0005433113500	9858	Comfort	47400.00
0005433180702	9858	Comfort	47400.00
0005433129203	9858	Comfort	47400.00
0005433233262	9858	Comfort	47400.00
0005433233233	9858	Economy	27900.00
0005432199142	9858	Economy	27900.00
0005433113501	9858	Economy	27900.00
0005433180705	9858	Economy	27900.00
0005433233256	9858	Economy	27900.00
0005433129204	9858	Economy	27900.00
0005433126772	9858	Economy	27900.00
0005433180725	9858	Economy	27900.00
0005433289735	9858	Economy	27900.00
0005433129202	9858	Economy	27900.00
0005433129206	9858	Economy	27900.00
0005433289734	9858	Economy	27900.00
0005433233218	9858	Economy	27900.00
0005433233227	9858	Economy	27900.00
0005433233248	9858	Economy	27900.00
0005432199143	9858	Economy	27900.00
0005432199137	9858	Economy	27900.00
0005432199138	9858	Economy	27900.00
0005433233217	9858	Economy	27900.00
0005433233221	9858	Economy	30700.00
0005433180703	9858	Economy	30700.00
0005433233249	9858	Economy	27900.00
0005433233222	9858	Economy	30700.00
0005433180722	9858	Economy	27900.00
0005433180712	9858	Economy	27900.00
0005433180709	9858	Economy	27900.00
0005433233228	9858	Economy	27900.00
0005433233271	9858	Economy	27900.00
0005433233268	9858	Economy	27900.00
0005433180719	9858	Economy	27900.00
0005433289738	9858	Economy	27900.00
0005433233266	9858	Economy	27900.00
0005433233247	9858	Economy	27900.00
0005433233232	9858	Economy	27900.00
0005433233219	9858	Economy	27900.00
0005432199144	9858	Economy	27900.00
0005433233209	9858	Economy	27900.00
0005434031954	9858	Economy	27900.00
0005433233251	9858	Economy	27900.00
0005432199141	9858	Economy	27900.00
0005433233259	9858	Economy	27900.00
0005433289733	9858	Economy	27900.00
0005433289731	9858	Economy	27900.00
0005433233267	9858	Economy	27900.00
0005433233210	9858	Economy	27900.00
0005433233250	9858	Economy	27900.00
0005433233214	9858	Economy	27900.00
0005433180708	9858	Economy	27900.00
0005433233264	9858	Economy	27900.00
0005433180724	9858	Economy	27900.00
0005433180710	9858	Economy	27900.00
0005433233272	9858	Economy	27900.00
0005433233229	9858	Economy	27900.00
0005433233260	9858	Economy	27900.00
0005434031956	9858	Economy	27900.00
0005433180718	9858	Economy	27900.00
0005433233213	9858	Economy	27900.00
0005433129205	9858	Economy	27900.00
0005433233241	9858	Economy	27900.00
0005433233226	9858	Economy	27900.00
0005434031953	9858	Economy	27900.00
0005433126774	9858	Economy	27900.00
0005433233253	9858	Economy	27900.00
0005433180717	9858	Economy	30700.00
0005433180721	9858	Economy	27900.00
0005433233257	9858	Economy	27900.00
0005433180720	9858	Economy	27900.00
0005433233220	9858	Economy	27900.00
0005433233212	9858	Economy	27900.00
0005433766581	9858	Economy	27900.00
0005433766583	9858	Economy	27900.00
0005433233239	9858	Economy	27900.00
0005433233243	9858	Economy	27900.00
0005433233269	9858	Economy	27900.00
0005433180715	9858	Economy	27900.00
0005433180713	9858	Economy	27900.00
0005433233255	9858	Economy	27900.00
0005433126773	9858	Economy	27900.00
0005433180711	9858	Economy	27900.00
0005433180716	9858	Economy	27900.00
0005433233242	9858	Economy	27900.00
0005433233265	9858	Economy	27900.00
0005433233223	9858	Economy	27900.00
0005433233258	9858	Economy	27900.00
0005432199140	9858	Economy	27900.00
0005433233246	9858	Economy	27900.00
0005433233235	9858	Economy	27900.00
0005433233224	9858	Economy	27900.00
0005433126775	9858	Economy	27900.00
0005433180723	9858	Economy	27900.00
0005433766584	9858	Economy	27900.00
0005433233237	9858	Economy	27900.00
0005433180714	9858	Economy	27900.00
0005433233234	9858	Economy	27900.00
0005433126776	9858	Economy	27900.00
0005433233240	9858	Economy	27900.00
0005433289737	9858	Economy	27900.00
0005433233216	9858	Economy	27900.00
0005433233230	9858	Economy	27900.00
0005433289736	9858	Economy	27900.00
0005433180701	9858	Economy	27900.00
0005434031955	9858	Economy	27900.00
0005433233215	9858	Economy	27900.00
0005433233225	9858	Economy	27900.00
0005433233245	9858	Economy	27900.00
0005433233252	9858	Economy	27900.00
0005432428876	7723	Business	42100.00
0005432526024	7723	Business	42100.00
0005432069438	7723	Business	42100.00
0005432069432	7723	Business	42100.00
0005434066476	7723	Business	42100.00
0005434066486	7723	Business	42100.00
0005432526012	7723	Business	42100.00
0005432526004	7723	Business	42100.00
0005434066468	7723	Business	42100.00
0005432525982	7723	Business	42100.00
0005432526032	7723	Business	42100.00
0005432069431	7723	Business	42100.00
0005434066496	7723	Business	42100.00
0005432525938	7723	Business	42100.00
0005432069427	7723	Business	42100.00
0005432525989	7723	Business	42100.00
0005432526027	7723	Business	42100.00
0005434066458	7723	Business	42100.00
0005432428878	7723	Comfort	23900.00
0005432069437	7723	Business	42100.00
0005432525929	7723	Comfort	23900.00
0005432526015	7723	Comfort	23900.00
0005432525948	7723	Comfort	23900.00
0005432526025	7723	Comfort	23900.00
0005432525915	7723	Comfort	23900.00
0005432535757	7723	Comfort	23900.00
0005432526019	7723	Comfort	23900.00
0005432526028	7723	Comfort	23900.00
0005432525957	7723	Comfort	23900.00
0005434066492	7723	Comfort	23900.00
0005432069426	7723	Comfort	23900.00
0005432428874	7723	Comfort	23900.00
0005432525980	7723	Comfort	23900.00
0005432525928	7723	Comfort	23900.00
0005432150077	7723	Comfort	23900.00
0005432525987	7723	Comfort	23900.00
0005434066490	7723	Comfort	23900.00
0005434066453	7723	Comfort	23900.00
0005434066470	7723	Comfort	23900.00
0005432525942	7723	Comfort	23900.00
0005432525947	7723	Comfort	23900.00
0005432525995	7723	Comfort	23900.00
0005432526006	7723	Comfort	23900.00
0005434066450	7723	Comfort	23900.00
0005432526003	7723	Comfort	23900.00
0005432525936	7723	Comfort	23900.00
0005432525984	7723	Comfort	23900.00
0005434066471	7723	Comfort	23900.00
0005432526001	7723	Comfort	23900.00
0005432525976	7723	Comfort	23900.00
0005432533247	7723	Comfort	23900.00
0005434066488	7723	Comfort	23900.00
0005432525933	7723	Economy	14000.00
0005432525966	7723	Economy	14000.00
0005434066443	7723	Economy	14000.00
0005432069435	7723	Economy	14000.00
0005432525972	7723	Economy	14000.00
0005432525998	7723	Economy	14000.00
0005432525959	7723	Economy	14000.00
0005434066440	7723	Economy	14000.00
0005432526005	7723	Economy	14000.00
0005432525992	7723	Economy	14000.00
0005432525926	7723	Economy	14000.00
0005434066457	7723	Economy	14000.00
0005432526011	7723	Economy	14000.00
0005432525918	7723	Economy	14000.00
0005432525999	7723	Economy	14000.00
0005434066465	7723	Economy	14000.00
0005432525950	7723	Economy	14000.00
0005432526033	7723	Economy	14000.00
0005432525967	7723	Economy	14000.00
0005432069433	7723	Economy	14000.00
0005432525975	7723	Economy	14000.00
0005432525968	7723	Economy	14000.00
0005432525943	7723	Economy	14000.00
0005432526030	7723	Economy	14000.00
0005432525907	7723	Economy	14000.00
0005432525997	7723	Economy	14000.00
0005434066491	7723	Economy	14000.00
0005434066462	7723	Economy	14000.00
0005434066483	7723	Economy	14000.00
0005432069429	7723	Economy	14000.00
0005434066454	7723	Economy	14000.00
0005434066466	7723	Economy	14000.00
0005432150076	7723	Economy	14000.00
0005434066493	7723	Economy	14000.00
0005432525964	7723	Economy	14000.00
0005432526026	7723	Economy	14000.00
0005434066469	7723	Economy	14000.00
0005432069436	7723	Economy	14000.00
0005432525979	7723	Economy	14000.00
0005432525912	7723	Economy	14000.00
0005434066442	7723	Economy	14000.00
0005434066459	7723	Economy	14000.00
0005434066464	7723	Economy	14000.00
0005432525914	7723	Economy	14000.00
0005434066489	7723	Economy	14000.00
0005432525911	7723	Economy	14000.00
0005434066475	7723	Economy	15400.00
0005432525974	7723	Economy	15400.00
0005434066460	7723	Economy	15400.00
0005432069434	7723	Economy	14000.00
0005434066495	7723	Economy	14000.00
0005432428875	7723	Economy	14000.00
0005432069425	7723	Economy	14000.00
0005432525986	7723	Economy	14000.00
0005432526000	7723	Economy	14000.00
0005432525958	7723	Economy	14000.00
0005434066447	7723	Economy	14000.00
0005432526031	7723	Economy	14000.00
0005434066499	7723	Economy	14000.00
0005432526034	7723	Economy	14000.00
0005432525937	7723	Economy	14000.00
0005432525973	7723	Economy	14000.00
0005434066485	7723	Economy	14000.00
0005432526035	7723	Economy	14000.00
0005432525906	7723	Economy	14000.00
0005434066480	7723	Economy	14000.00
0005432526023	7723	Economy	14000.00
0005434066478	7723	Economy	14000.00
0005434066507	7723	Economy	14000.00
0005432525965	7723	Economy	14000.00
0005432525935	7723	Economy	14000.00
0005434066445	7723	Economy	14000.00
0005432525905	7723	Economy	14000.00
0005434066503	7723	Economy	14000.00
0005432525949	7723	Economy	14000.00
0005432525922	7723	Economy	14000.00
0005432526018	7723	Economy	14000.00
0005432535758	7723	Economy	14000.00
0005432525994	7723	Economy	14000.00
0005434066448	7723	Economy	14000.00
0005434066473	7723	Economy	14000.00
0005434066509	7723	Economy	14000.00
0005432526022	7723	Economy	14000.00
0005432526020	7723	Economy	14000.00
0005432525910	7723	Economy	14000.00
0005434066487	7723	Economy	14000.00
0005434066479	7723	Economy	14000.00
0005432150074	7723	Economy	14000.00
0005434066501	7723	Economy	14000.00
0005432525962	7723	Economy	14000.00
0005432525945	7723	Economy	14000.00
0005432525940	7723	Economy	14000.00
0005432525963	7723	Economy	14000.00
0005432525913	7723	Economy	14000.00
0005432525955	7723	Economy	14000.00
0005432525944	7723	Economy	14000.00
0005434066508	7723	Economy	14000.00
0005432525925	7723	Economy	14000.00
0005434066441	7723	Economy	14000.00
0005434066451	7723	Economy	14000.00
0005432525981	7723	Economy	14000.00
0005432525941	7723	Economy	14000.00
0005434066467	7723	Economy	14000.00
0005432526014	7723	Economy	14000.00
0005432525924	7723	Economy	14000.00
0005432069424	7723	Economy	14000.00
0005434066444	7723	Economy	14000.00
0005434066506	7723	Economy	14000.00
0005434066484	7723	Economy	14000.00
0005434066463	7723	Economy	14000.00
0005432525988	7723	Economy	14000.00
0005432150071	7723	Economy	14000.00
0005432526002	7723	Economy	14000.00
0005432526007	7723	Economy	14000.00
0005434066482	7723	Economy	14000.00
0005434066472	7723	Economy	14000.00
0005434066474	7723	Economy	15400.00
0005432525952	7723	Economy	14000.00
0005432525971	7723	Economy	15400.00
0005434066502	7723	Economy	15400.00
0005434066477	7723	Economy	15400.00
0005432525991	7723	Economy	14000.00
0005432525921	7723	Economy	14000.00
0005432525993	7723	Economy	14000.00
0005432526013	7723	Economy	14000.00
0005432150073	7723	Economy	14000.00
0005432525977	7723	Economy	14000.00
0005432526029	7723	Economy	14000.00
0005432537024	7723	Economy	14000.00
0005434066498	7723	Economy	14000.00
0005434066456	7723	Economy	14000.00
0005432533248	7723	Economy	14000.00
0005432526010	7723	Economy	14000.00
0005432525916	7723	Economy	14000.00
0005432069430	7723	Economy	14000.00
0005432525927	7723	Economy	14000.00
0005434066494	7723	Economy	14000.00
0005432525919	7723	Economy	14000.00
0005432525917	7723	Economy	14000.00
0005432525920	7723	Economy	14000.00
0005432525983	7723	Economy	14000.00
0005432525996	7723	Economy	14000.00
0005432525932	7723	Economy	14000.00
0005432525961	7723	Economy	14000.00
0005434066455	7723	Economy	14000.00
0005432525985	7723	Economy	14000.00
0005432428877	7723	Economy	14000.00
0005434066481	7723	Economy	14000.00
0005432525954	7723	Economy	14000.00
0005432526008	7723	Economy	14000.00
0005432535756	7723	Economy	14000.00
0005432150072	7723	Economy	14000.00
0005432525956	7723	Economy	14000.00
0005432525990	7723	Economy	14000.00
0005432526009	7723	Economy	14000.00
0005432525970	7723	Economy	14000.00
0005434066511	7723	Economy	14000.00
0005432525969	7723	Economy	14000.00
0005432525930	7723	Economy	14000.00
0005434066497	7723	Economy	14000.00
0005434066449	7723	Economy	14000.00
0005432526017	7723	Economy	14000.00
0005432525960	7723	Economy	14000.00
0005432525934	7723	Economy	14000.00
0005432535759	7723	Economy	14000.00
0005432525923	7723	Economy	14000.00
0005432526021	7723	Economy	14000.00
0005432525951	7723	Economy	14000.00
0005434066500	7723	Economy	14000.00
0005432525978	7723	Economy	14000.00
0005434066505	7723	Economy	14000.00
0005432150075	7723	Economy	14000.00
0005432525908	7723	Economy	14000.00
0005434066510	7723	Economy	14000.00
0005434066504	7723	Economy	14000.00
0005434066446	7723	Economy	14000.00
0005434066452	7723	Economy	14000.00
0005432525904	7723	Economy	14000.00
0005432525939	7723	Economy	14000.00
0005432525946	7723	Economy	14000.00
0005432526016	7723	Economy	14000.00
0005432525909	7723	Economy	14000.00
0005432537023	7723	Economy	14000.00
0005432525931	7723	Economy	14000.00
0005434066461	7723	Economy	14000.00
0005432525953	7723	Economy	14000.00
0005432069428	7723	Economy	14000.00
0005432132982	5305	Business	43100.00
0005434573143	5305	Business	43100.00
0005435611946	5305	Business	43100.00
0005435611964	5305	Business	43100.00
0005435611891	5305	Business	43100.00
0005435611978	5305	Business	43100.00
0005434343654	5305	Business	43100.00
0005435611919	5305	Business	43100.00
0005434343666	5305	Business	43100.00
0005435611917	5305	Business	43100.00
0005434343672	5305	Business	43100.00
0005435611971	5305	Business	43100.00
0005435611924	5305	Business	43100.00
0005435097062	5305	Business	43100.00
0005434343677	5305	Comfort	24400.00
0005435611983	5305	Comfort	24400.00
0005434343679	5305	Comfort	24400.00
0005434573141	5305	Comfort	24400.00
0005435611948	5305	Comfort	24400.00
0005435611961	5305	Comfort	24400.00
0005435611896	5305	Comfort	24400.00
0005435097061	5305	Comfort	24400.00
0005435490176	5305	Comfort	24400.00
0005432047493	5305	Comfort	24400.00
0005435611906	5305	Comfort	24400.00
0005434343678	5305	Comfort	24400.00
0005435611951	5305	Comfort	24400.00
0005434573135	5305	Comfort	24400.00
0005434573140	5305	Comfort	24400.00
0005435611879	5305	Comfort	24400.00
0005434573136	5305	Comfort	24400.00
0005435611979	5305	Comfort	24400.00
0005435611895	5305	Comfort	24400.00
0005434343670	5305	Comfort	24400.00
0005435423603	5305	Comfort	24400.00
0005435611936	5305	Comfort	24400.00
0005435611888	5305	Comfort	24400.00
0005432132974	5305	Comfort	24400.00
0005434343684	5305	Comfort	24400.00
0005435555337	5305	Comfort	24400.00
0005435611928	5305	Economy	14400.00
0005432132976	5305	Economy	14400.00
0005435555336	5305	Economy	14400.00
0005434343673	5305	Economy	14400.00
0005435611959	5305	Economy	14400.00
0005434343664	5305	Economy	14400.00
0005434343658	5305	Economy	14400.00
0005435611882	5305	Economy	14400.00
0005434343653	5305	Economy	14400.00
0005435611965	5305	Economy	14400.00
0005435611933	5305	Economy	14400.00
0005435611981	5305	Economy	14400.00
0005432132972	5305	Economy	14400.00
0005435097065	5305	Economy	14400.00
0005435611954	5305	Economy	14400.00
0005434343685	5305	Economy	14400.00
0005432132980	5305	Economy	14400.00
0005435611908	5305	Economy	14400.00
0005435423636	5305	Economy	14400.00
0005434343665	5305	Economy	14400.00
0005435611957	5305	Economy	14400.00
0005434343675	5305	Economy	14400.00
0005432132981	5305	Economy	14400.00
0005435611911	5305	Economy	14400.00
0005432047492	5305	Economy	14400.00
0005435611922	5305	Economy	14400.00
0005434573142	5305	Economy	14400.00
0005435611877	5305	Economy	14400.00
0005435611966	5305	Economy	14400.00
0005435611913	5305	Economy	14400.00
0005435611909	5305	Economy	14400.00
0005435611907	5305	Economy	14400.00
0005435611943	5305	Economy	14400.00
0005435611956	5305	Economy	14400.00
0005435611982	5305	Economy	14400.00
0005435611898	5305	Economy	14400.00
0005435611883	5305	Economy	14400.00
0005434343651	5305	Economy	14400.00
0005435611926	5305	Economy	14400.00
0005435611925	5305	Economy	14400.00
0005434573133	5305	Economy	14400.00
0005435611880	5305	Economy	14400.00
0005435611955	5305	Economy	14400.00
0005435611885	5305	Economy	14400.00
0005435611890	5305	Economy	14400.00
0005434343663	5305	Economy	14400.00
0005435611973	5305	Economy	14400.00
0005435097066	5305	Economy	14400.00
0005434343674	5305	Economy	14400.00
0005435491409	5305	Economy	14400.00
0005434573130	5305	Economy	14400.00
0005435611984	5305	Economy	14400.00
0005435611927	5305	Economy	14400.00
0005435611901	5305	Economy	14400.00
0005435611967	5305	Economy	14400.00
0005434573138	5305	Economy	14400.00
0005435611914	5305	Economy	14400.00
0005435611900	5305	Economy	14400.00
0005434343681	5305	Economy	14400.00
0005435490175	5305	Economy	14400.00
0005435611892	5305	Economy	14400.00
0005434343680	5305	Economy	14400.00
0005435611953	5305	Economy	14400.00
0005435611970	5305	Economy	14400.00
0005435611889	5305	Economy	14400.00
0005434573132	5305	Economy	14400.00
0005435611938	5305	Economy	14400.00
0005435611975	5305	Economy	14400.00
0005432132978	5305	Economy	14400.00
0005435611941	5305	Economy	14400.00
0005434573137	5305	Economy	14400.00
0005435611949	5305	Economy	14400.00
0005435611920	5305	Economy	14400.00
0005435611931	5305	Economy	14400.00
0005434343668	5305	Economy	14400.00
0005435611899	5305	Economy	14400.00
0005432132977	5305	Economy	14400.00
0005435611963	5305	Economy	14400.00
0005435611972	5305	Economy	14400.00
0005434573139	5305	Economy	14400.00
0005432132983	5305	Economy	14400.00
0005435611916	5305	Economy	14400.00
0005435611939	5305	Economy	14400.00
0005435611934	5305	Economy	14400.00
0005435611912	5305	Economy	14400.00
0005435611893	5305	Economy	14400.00
0005434343662	5305	Economy	14400.00
0005432047494	5305	Economy	14400.00
0005435097068	5305	Economy	14400.00
0005435097063	5305	Economy	14400.00
0005434343657	5305	Economy	14400.00
0005435423635	5305	Economy	14400.00
0005435097064	5305	Economy	14400.00
0005435611897	5305	Economy	14400.00
0005435611980	5305	Economy	14400.00
0005435611947	5305	Economy	14400.00
0005434343661	5305	Economy	14400.00
0005432132975	5305	Economy	15800.00
0005435611944	5305	Economy	15800.00
0005435611950	5305	Economy	14400.00
0005435611969	5305	Economy	14400.00
0005435611968	5305	Economy	14400.00
0005435611905	5305	Economy	14400.00
0005435611942	5305	Economy	14400.00
0005434343656	5305	Economy	14400.00
0005434343671	5305	Economy	14400.00
0005435611958	5305	Economy	14400.00
0005435611902	5305	Economy	14400.00
0005435611881	5305	Economy	14400.00
0005434573131	5305	Economy	14400.00
0005432132973	5305	Economy	14400.00
0005434343652	5305	Economy	14400.00
0005435611929	5305	Economy	14400.00
0005435611918	5305	Economy	14400.00
0005435611930	5305	Economy	14400.00
0005432132985	5305	Economy	14400.00
0005435491408	5305	Economy	14400.00
0005435611923	5305	Economy	14400.00
0005435611940	5305	Economy	14400.00
0005435097067	5305	Economy	14400.00
0005435490174	5305	Economy	14400.00
0005435611977	5305	Economy	14400.00
0005434343676	5305	Economy	14400.00
0005435423602	5305	Economy	14400.00
0005435611962	5305	Economy	14400.00
0005435611960	5305	Economy	14400.00
0005432132986	5305	Economy	14400.00
0005434343683	5305	Economy	14400.00
0005432132984	5305	Economy	14400.00
0005435611945	5305	Economy	14400.00
0005435611935	5305	Economy	14400.00
0005435611884	5305	Economy	14400.00
0005435611878	5305	Economy	14400.00
0005434343667	5305	Economy	14400.00
0005435097060	5305	Economy	14400.00
0005435611932	5305	Economy	14400.00
0005435611921	5305	Economy	14400.00
0005435611903	5305	Economy	14400.00
0005432132979	5305	Economy	14400.00
0005435611894	5305	Economy	14400.00
0005435611910	5305	Economy	14400.00
0005435611976	5305	Economy	14400.00
0005435611974	5305	Economy	14400.00
0005434343660	5305	Economy	14400.00
0005435611887	5305	Economy	14400.00
0005435611904	5305	Economy	14400.00
0005434343659	5305	Economy	14400.00
0005435611886	5305	Economy	14400.00
0005434343669	5305	Economy	14400.00
0005435611937	5305	Economy	14400.00
0005434343655	5305	Economy	14400.00
0005435611915	5305	Economy	14400.00
0005435611876	5305	Economy	14400.00
0005434573134	5305	Economy	14400.00
0005434343682	5305	Economy	14400.00
0005435611952	5305	Economy	14400.00
0005435423746	10910	Business	43100.00
0005435042825	10910	Business	43100.00
0005435423763	10910	Business	43100.00
0005434244527	10910	Business	43100.00
0005435423780	10910	Business	43100.00
0005432164920	10910	Comfort	24400.00
0005435423724	10910	Comfort	24400.00
0005432164919	10910	Comfort	24400.00
0005433719089	10910	Comfort	24400.00
0005435423778	10910	Comfort	24400.00
0005435423733	10910	Comfort	24400.00
0005432166852	10910	Comfort	24400.00
0005434244529	10910	Comfort	24400.00
0005435423742	10910	Comfort	24400.00
0005435423764	10910	Comfort	24400.00
0005435423757	10910	Comfort	24400.00
0005435423772	10910	Comfort	24400.00
0005434244519	10910	Comfort	24400.00
0005435304097	10910	Comfort	24400.00
0005434244532	10910	Economy	14400.00
0005435423768	10910	Economy	14400.00
0005435319437	10910	Economy	14400.00
0005435423752	10910	Economy	14400.00
0005435423717	10910	Economy	14400.00
0005435423785	10910	Economy	14400.00
0005433719091	10910	Economy	14400.00
0005435423781	10910	Economy	14400.00
0005435423759	10910	Economy	14400.00
0005434244540	10910	Economy	14400.00
0005435042824	10910	Economy	14400.00
0005435423730	10910	Economy	14400.00
0005435423767	10910	Economy	14400.00
0005435423761	10910	Economy	14400.00
0005432166851	10910	Economy	14400.00
0005435423750	10910	Economy	14400.00
0005435423734	10910	Economy	14400.00
0005434244517	10910	Economy	14400.00
0005432164917	10910	Economy	14400.00
0005434244521	10910	Economy	14400.00
0005434244524	10910	Economy	14400.00
0005435423740	10910	Economy	14400.00
0005435423744	10910	Economy	14400.00
0005435423783	10910	Economy	14400.00
0005434244531	10910	Economy	14400.00
0005435423762	10910	Economy	14400.00
0005434244536	10910	Economy	14400.00
0005435423729	10910	Economy	14400.00
0005434244542	10910	Economy	14400.00
0005432166850	10910	Economy	14400.00
0005435423749	10910	Economy	14400.00
0005432164918	10910	Economy	14400.00
0005434244541	10910	Economy	14400.00
0005435423718	10910	Economy	14400.00
0005435423758	10910	Economy	14400.00
0005435319440	10910	Economy	14400.00
0005434244530	10910	Economy	14400.00
0005435423784	10910	Economy	14400.00
0005435319433	10910	Economy	14400.00
0005434244526	10910	Economy	14400.00
0005435423723	10910	Economy	14400.00
0005435423735	10910	Economy	14400.00
0005434244533	10910	Economy	14400.00
0005435423777	10910	Economy	14400.00
0005435423766	10910	Economy	14400.00
0005435423716	10910	Economy	14400.00
0005435423751	10910	Economy	14400.00
0005434244538	10910	Economy	14400.00
0005432363365	10910	Economy	14400.00
0005435423722	10910	Economy	14400.00
0005435423760	10910	Economy	14400.00
0005434244543	10910	Economy	14400.00
0005435319436	10910	Economy	14400.00
0005435423786	10910	Economy	14400.00
0005435423721	10910	Economy	14400.00
0005434244539	10910	Economy	14400.00
0005435423756	10910	Economy	14400.00
0005432363366	10910	Economy	14400.00
0005434244523	10910	Economy	14400.00
0005435423726	10910	Economy	14400.00
0005435423753	10910	Economy	14400.00
0005435423743	10910	Economy	14400.00
0005432840980	10910	Economy	14400.00
0005433719088	10910	Economy	14400.00
0005434244515	10910	Economy	14400.00
0005435423776	10910	Economy	14400.00
0005435423745	10910	Economy	14400.00
0005435319432	10910	Economy	14400.00
0005433719090	10910	Economy	14400.00
0005432164923	10910	Economy	14400.00
0005435423770	10910	Economy	14400.00
0005435423748	10910	Economy	14400.00
0005434244534	10910	Economy	15800.00
0005432164921	10910	Economy	15800.00
0005435423737	10910	Economy	15800.00
0005435423732	10910	Economy	14400.00
0005435423774	10910	Economy	14400.00
0005434244522	10910	Economy	14400.00
0005435423773	10910	Economy	14400.00
0005435423739	10910	Economy	14400.00
0005435319438	10910	Economy	14400.00
0005435423754	10910	Economy	14400.00
0005435423782	10910	Economy	14400.00
0005435423736	10910	Economy	14400.00
0005435423765	10910	Economy	14400.00
0005435423775	10910	Economy	14400.00
0005435423779	10910	Economy	14400.00
0005432164922	10910	Economy	14400.00
0005435304098	10910	Economy	14400.00
0005432840981	10910	Economy	14400.00
0005434244518	10910	Economy	14400.00
0005434244516	10910	Economy	14400.00
0005435423727	10910	Economy	14400.00
0005435423741	10910	Economy	14400.00
0005435319435	10910	Economy	14400.00
0005434244528	10910	Economy	14400.00
0005435423747	10910	Economy	14400.00
0005434656525	10910	Economy	14400.00
0005432840982	10910	Economy	14400.00
0005435423755	10910	Economy	14400.00
0005435319434	10910	Economy	14400.00
0005434244535	10910	Economy	14400.00
0005435423725	10910	Economy	14400.00
0005435423731	10910	Economy	14400.00
0005434244537	10910	Economy	14400.00
0005435423769	10910	Economy	14400.00
0005435423720	10910	Economy	14400.00
0005434244525	10910	Economy	14400.00
0005435319439	10910	Economy	14400.00
0005435423738	10910	Economy	14400.00
0005435423728	10910	Economy	14400.00
0005435423719	10910	Economy	14400.00
0005434244520	10910	Economy	14400.00
0005434656524	10910	Economy	14400.00
0005435423771	10910	Economy	14400.00
0005432181366	3246	Business	18800.00
0005432181374	3246	Business	18800.00
0005433506902	3246	Business	18800.00
0005433633287	3246	Business	18800.00
0005432181370	3246	Business	18800.00
0005433804838	3246	Business	18800.00
0005433804852	3246	Business	18800.00
0005433804849	3246	Business	18800.00
0005432181377	3246	Business	18800.00
0005432181373	3246	Business	18800.00
0005433633313	3246	Business	18800.00
0005433506898	3246	Business	18800.00
0005433804840	3246	Business	18800.00
0005433506910	3246	Business	18800.00
0005433506903	3246	Business	18800.00
0005433633301	3246	Business	18800.00
0005433633316	3246	Business	18800.00
0005432181384	3246	Business	18800.00
0005432181379	3246	Economy	6900.00
0005433804853	3246	Economy	6900.00
0005433633310	3246	Economy	6900.00
0005432181386	3246	Economy	6900.00
0005433506911	3246	Economy	6900.00
0005433633288	3246	Economy	6300.00
0005433804847	3246	Economy	6300.00
0005433804846	3246	Economy	6300.00
0005433506908	3246	Economy	6300.00
0005433633308	3246	Economy	6300.00
0005432181383	3246	Economy	6300.00
0005433633302	3246	Economy	6300.00
0005433804851	3246	Economy	6300.00
0005433804834	3246	Economy	6300.00
0005433804850	3246	Economy	6300.00
0005433804857	3246	Economy	6300.00
0005432181381	3246	Economy	6300.00
0005433633291	3246	Economy	6300.00
0005433804854	3246	Economy	6300.00
0005433804856	3246	Economy	6300.00
0005433633290	3246	Economy	6300.00
0005432181367	3246	Economy	6300.00
0005433633303	3246	Economy	6300.00
0005433506909	3246	Economy	6300.00
0005433633294	3246	Economy	6300.00
0005433633297	3246	Economy	6300.00
0005433633311	3246	Economy	6300.00
0005433506900	3246	Economy	6300.00
0005433506904	3246	Economy	6300.00
0005432181368	3246	Economy	6300.00
0005432181372	3246	Economy	6300.00
0005433633283	3246	Economy	6300.00
0005433804858	3246	Economy	6300.00
0005433633317	3246	Economy	6300.00
0005433633292	3246	Economy	6300.00
0005433633286	3246	Economy	6300.00
0005433804836	3246	Economy	6300.00
0005433506905	3246	Economy	6300.00
0005433633300	3246	Economy	6300.00
0005433506907	3246	Economy	6300.00
0005433633309	3246	Economy	6300.00
0005433633295	3246	Economy	6300.00
0005433506892	3246	Economy	6300.00
0005433804835	3246	Economy	6300.00
0005433804832	3246	Economy	6900.00
0005432181382	3246	Economy	6900.00
0005432181385	3246	Economy	6900.00
0005433804842	3246	Economy	6300.00
0005433633306	3246	Economy	6300.00
0005433506906	3246	Economy	6300.00
0005433506893	3246	Economy	6300.00
0005433633299	3246	Economy	6300.00
0005433506896	3246	Economy	6300.00
0005433804848	3246	Economy	6300.00
0005433804830	3246	Economy	6300.00
0005432181364	3246	Economy	6300.00
0005433633296	3246	Economy	6300.00
0005433633304	3246	Economy	6300.00
0005432181376	3246	Economy	6300.00
0005433804839	3246	Economy	6300.00
0005432181375	3246	Economy	6300.00
0005433804855	3246	Economy	6300.00
0005433633315	3246	Economy	6300.00
0005433633289	3246	Economy	6300.00
0005433804841	3246	Economy	6300.00
0005433804845	3246	Economy	6300.00
0005433506891	3246	Economy	6300.00
0005433633314	3246	Economy	6300.00
0005433633312	3246	Economy	6300.00
0005433804837	3246	Economy	6300.00
0005433633285	3246	Economy	6300.00
0005433633293	3246	Economy	6300.00
0005432181371	3246	Economy	6300.00
0005433633298	3246	Economy	6300.00
0005433633305	3246	Economy	6300.00
0005433804843	3246	Economy	6300.00
0005433804831	3246	Economy	6300.00
0005433506901	3246	Economy	6300.00
0005432181378	3246	Economy	6300.00
0005433804833	3246	Economy	6300.00
0005433804844	3246	Economy	6300.00
0005433506899	3246	Economy	6300.00
0005432181380	3246	Economy	6300.00
0005433506897	3246	Economy	6300.00
0005433804829	3246	Economy	6300.00
0005432181365	3246	Economy	6300.00
0005433633284	3246	Economy	6300.00
0005433633307	3246	Economy	6300.00
0005433506895	3246	Economy	6300.00
0005433506894	3246	Economy	6300.00
0005432181369	3246	Economy	6300.00
0005435884392	3247	Business	18800.00
0005435884408	3247	Economy	6300.00
0005435884393	3247	Economy	6900.00
0005435884409	3247	Economy	6300.00
0005435884391	3247	Economy	6300.00
0005432459110	8287	Business	18800.00
0005432459106	8287	Business	18800.00
0005432459086	8287	Business	18800.00
0005435884524	8287	Business	18800.00
0005432459078	8287	Business	18800.00
0005435884521	8287	Business	18800.00
0005435884523	8287	Business	18800.00
0005435884494	8287	Business	18800.00
0005432042507	8287	Business	18800.00
0005432459088	8287	Business	18800.00
0005432459063	8287	Business	18800.00
0005432459070	8287	Business	18800.00
0005435884506	8287	Business	18800.00
0005435884501	8287	Business	18800.00
0005432459112	8287	Business	18800.00
0005435884497	8287	Business	18800.00
0005432459075	8287	Business	18800.00
0005432042509	8287	Economy	6900.00
0005435884505	8287	Economy	6900.00
0005432459101	8287	Economy	6300.00
0005435884509	8287	Economy	6300.00
0005432459073	8287	Economy	6300.00
0005432459077	8287	Economy	6300.00
0005435884484	8287	Economy	6300.00
0005432459100	8287	Economy	6300.00
0005435884498	8287	Economy	6300.00
0005435884525	8287	Economy	6300.00
0005435884516	8287	Economy	6300.00
0005432459091	8287	Economy	6300.00
0005435884504	8287	Economy	6300.00
0005435884485	8287	Economy	6300.00
0005435884486	8287	Economy	6300.00
0005432042503	8287	Economy	6300.00
0005435884496	8287	Economy	6300.00
0005432459065	8287	Economy	6300.00
0005432459089	8287	Economy	6300.00
0005432459092	8287	Economy	6300.00
0005435884507	8287	Economy	6300.00
0005435884488	8287	Economy	6300.00
0005432042504	8287	Economy	6300.00
0005435884499	8287	Economy	6300.00
0005435884510	8287	Economy	6300.00
0005432042502	8287	Economy	6300.00
0005435884500	8287	Economy	6300.00
0005432459109	8287	Economy	6300.00
0005432459102	8287	Economy	6300.00
0005432459071	8287	Economy	6300.00
0005432042495	8287	Economy	6300.00
0005434312287	8287	Economy	6300.00
0005432459098	8287	Economy	6300.00
0005432459081	8287	Economy	6300.00
0005435884491	8287	Economy	6300.00
0005432459080	8287	Economy	6300.00
0005432042506	8287	Economy	6300.00
0005432459067	8287	Economy	6300.00
0005432042505	8287	Economy	6300.00
0005432459115	8287	Economy	6300.00
0005434312288	8287	Economy	6300.00
0005432042501	8287	Economy	6300.00
0005432459076	8287	Economy	6300.00
0005432459095	8287	Economy	6300.00
0005432042496	8287	Economy	6300.00
0005435884514	8287	Economy	6900.00
0005432459093	8287	Economy	6900.00
0005432042508	8287	Economy	6900.00
0005432459084	8287	Economy	6300.00
0005432042497	8287	Economy	6300.00
0005432042500	8287	Economy	6300.00
0005435884518	8287	Economy	6300.00
0005435884503	8287	Economy	6900.00
0005432459087	8287	Economy	6300.00
0005432459111	8287	Economy	6300.00
0005435884511	8287	Economy	6300.00
0005432459094	8287	Economy	6300.00
0005435884495	8287	Economy	6300.00
0005432459105	8287	Economy	6300.00
0005432459104	8287	Economy	6300.00
0005435884489	8287	Economy	6300.00
0005435884502	8287	Economy	6300.00
0005432459103	8287	Economy	6300.00
0005432459108	8287	Economy	6300.00
0005435884493	8287	Economy	6300.00
0005432459107	8287	Economy	6300.00
0005435884517	8287	Economy	6300.00
0005432459099	8287	Economy	6300.00
0005432459066	8287	Economy	6300.00
0005432459090	8287	Economy	6300.00
0005435884519	8287	Economy	6300.00
0005435884492	8287	Economy	6300.00
0005432459074	8287	Economy	6300.00
0005432459083	8287	Economy	6300.00
0005435884483	8287	Economy	6300.00
0005432459079	8287	Economy	6300.00
0005432459097	8287	Economy	6300.00
0005435884520	8287	Economy	6300.00
0005435884487	8287	Economy	6300.00
0005432459068	8287	Economy	6300.00
0005432459085	8287	Economy	6300.00
0005432459064	8287	Economy	6300.00
0005432459113	8287	Economy	6300.00
0005432459069	8287	Economy	6300.00
0005435884522	8287	Economy	6300.00
0005435884512	8287	Economy	6300.00
0005435884513	8287	Economy	6300.00
0005432459114	8287	Economy	6300.00
0005435884508	8287	Economy	6300.00
0005435884490	8287	Economy	6300.00
0005432042498	8287	Economy	6300.00
0005432042499	8287	Economy	6300.00
0005432459082	8287	Economy	6300.00
0005435884482	8287	Economy	6300.00
0005432459072	8287	Economy	6300.00
0005435884515	8287	Economy	6300.00
0005432459096	8287	Economy	6300.00
0005432727752	4603	Business	9900.00
0005433194822	4603	Business	9900.00
0005432382598	4603	Business	9900.00
0005432382581	4603	Business	9900.00
0005432382570	4603	Business	9900.00
0005432382576	4603	Business	9900.00
0005432382588	4603	Business	9900.00
0005432382601	4603	Economy	3300.00
0005433453731	4603	Economy	3300.00
0005432382604	4603	Economy	3300.00
0005432727745	4603	Economy	3300.00
0005432727741	4603	Economy	3300.00
0005432382591	4603	Economy	3300.00
0005433194821	4603	Economy	3300.00
0005432727743	4603	Economy	3300.00
0005432382571	4603	Economy	3600.00
0005432382575	4603	Economy	3600.00
0005432382577	4603	Economy	3600.00
0005432382589	4603	Economy	3600.00
0005433194823	4603	Economy	3300.00
0005432382578	4603	Economy	3300.00
0005432382599	4603	Economy	3300.00
0005432382580	4603	Economy	3300.00
0005432727750	4603	Economy	3300.00
0005432727753	4603	Economy	3300.00
0005432382565	4603	Economy	3300.00
0005432382596	4603	Economy	3300.00
0005432382600	4603	Economy	3300.00
0005433453732	4603	Economy	3300.00
0005432382568	4603	Economy	3300.00
0005432382592	4603	Economy	3300.00
0005432382566	4603	Economy	3300.00
0005432382595	4603	Economy	3300.00
0005432727742	4603	Economy	3300.00
0005433453730	4603	Economy	3300.00
0005432727751	4603	Economy	3300.00
0005433722119	4603	Economy	3300.00
0005432382586	4603	Economy	3300.00
0005432382572	4603	Economy	3300.00
0005432382585	4603	Economy	3300.00
0005432382587	4603	Economy	3300.00
0005433722118	4603	Economy	3300.00
0005432382567	4603	Economy	3300.00
0005433454841	4603	Economy	3300.00
0005432382579	4603	Economy	3300.00
0005432382574	4603	Economy	3300.00
0005432727748	4603	Economy	3300.00
0005432382597	4603	Economy	3300.00
0005432382573	4603	Economy	3300.00
0005432382590	4603	Economy	3300.00
0005432382582	4603	Economy	3300.00
0005432382594	4603	Economy	3300.00
0005432382593	4603	Economy	3300.00
0005433722120	4603	Economy	3300.00
0005432382602	4603	Economy	3300.00
0005432382583	4603	Economy	3300.00
0005432382605	4603	Economy	3300.00
0005432727744	4603	Economy	3300.00
0005432382584	4603	Economy	3300.00
0005432727747	4603	Economy	3300.00
0005432382564	4603	Economy	3300.00
0005432727746	4603	Economy	3300.00
0005433454842	4603	Economy	3300.00
0005433194820	4603	Economy	3300.00
0005432382569	4603	Economy	3300.00
0005432727749	4603	Economy	3300.00
0005432382603	4603	Economy	3300.00
0005432727754	4603	Economy	3300.00
0005433516748	1729	Business	57200.00
0005435528926	1729	Business	57200.00
0005435540684	1729	Business	57200.00
0005433516743	1729	Business	57200.00
0005435540689	1729	Business	57200.00
0005435528923	1729	Business	57200.00
0005435540678	1729	Business	57200.00
0005432294452	1729	Economy	19100.00
0005435528935	1729	Economy	19100.00
0005435540669	1729	Economy	19100.00
0005435528924	1729	Economy	19100.00
0005435528941	1729	Economy	19100.00
0005433516744	1729	Economy	19100.00
0005435540674	1729	Economy	21000.00
0005435540682	1729	Economy	21000.00
0005435528929	1729	Economy	21000.00
0005435540668	1729	Economy	21000.00
0005435540672	1729	Economy	21000.00
0005435528945	1729	Economy	19100.00
0005435540679	1729	Economy	19100.00
0005435540685	1729	Economy	19100.00
0005433516746	1729	Economy	19100.00
0005435540683	1729	Economy	19100.00
0005435540670	1729	Economy	19100.00
0005435540673	1729	Economy	19100.00
0005435528940	1729	Economy	19100.00
0005435528928	1729	Economy	19100.00
0005433516747	1729	Economy	19100.00
0005435540667	1729	Economy	19100.00
0005435528927	1729	Economy	19100.00
0005435528936	1729	Economy	19100.00
0005435528937	1729	Economy	19100.00
0005435540688	1729	Economy	19100.00
0005435528944	1729	Economy	19100.00
0005435528938	1729	Economy	19100.00
0005435528922	1729	Economy	19100.00
0005435540676	1729	Economy	19100.00
0005432294451	1729	Economy	19100.00
0005435528939	1729	Economy	19100.00
0005435528942	1729	Economy	19100.00
0005432294450	1729	Economy	19100.00
0005435540671	1729	Economy	19100.00
0005433516742	1729	Economy	19100.00
0005435540675	1729	Economy	19100.00
0005435528932	1729	Economy	19100.00
0005433516740	1729	Economy	19100.00
0005435528925	1729	Economy	19100.00
0005433516745	1729	Economy	19100.00
0005435540686	1729	Economy	19100.00
0005435540687	1729	Economy	19100.00
0005435540681	1729	Economy	19100.00
0005435528946	1729	Economy	19100.00
0005435528943	1729	Economy	19100.00
0005435540680	1729	Economy	19100.00
0005435540677	1729	Economy	19100.00
0005435528931	1729	Economy	19100.00
0005433516741	1729	Economy	19100.00
0005435528933	1729	Economy	19100.00
0005435528930	1729	Economy	19100.00
0005435528934	1729	Economy	19100.00
0005432924963	22011	Business	57200.00
0005432924965	22011	Economy	19100.00
0005432924961	22011	Economy	19100.00
0005432924964	22011	Economy	19100.00
0005432924966	22011	Economy	19100.00
0005432924962	22011	Economy	19100.00
0005434458486	7377	Business	18500.00
0005434458495	7377	Business	18500.00
0005432838547	7377	Business	18500.00
0005432823417	7377	Business	18500.00
0005432838575	7377	Business	18500.00
0005432823418	7377	Business	18500.00
0005432838566	7377	Economy	6200.00
0005432840979	7377	Economy	6200.00
0005434458479	7377	Economy	6200.00
0005434458488	7377	Economy	6200.00
0005434458485	7377	Economy	6800.00
0005432838572	7377	Economy	6800.00
0005432838552	7377	Economy	6800.00
0005432073338	7377	Economy	6200.00
0005432838555	7377	Economy	6200.00
0005434458494	7377	Economy	6200.00
0005432838546	7377	Economy	6200.00
0005432838554	7377	Economy	6200.00
0005432838549	7377	Economy	6200.00
0005432838563	7377	Economy	6200.00
0005434458478	7377	Economy	6200.00
0005432838553	7377	Economy	6200.00
0005434458482	7377	Economy	6200.00
0005432838571	7377	Economy	6200.00
0005432838573	7377	Economy	6200.00
0005434458489	7377	Economy	6200.00
0005432073336	7377	Economy	6200.00
0005434458491	7377	Economy	6200.00
0005432838561	7377	Economy	6200.00
0005432838560	7377	Economy	6200.00
0005432838574	7377	Economy	6200.00
0005434458487	7377	Economy	6200.00
0005432838562	7377	Economy	6200.00
0005432838556	7377	Economy	6200.00
0005432838568	7377	Economy	6200.00
0005434458477	7377	Economy	6200.00
0005434458492	7377	Economy	6200.00
0005432840977	7377	Economy	6200.00
0005434458483	7377	Economy	6200.00
0005432838569	7377	Economy	6200.00
0005432838557	7377	Economy	6200.00
0005432073337	7377	Economy	6200.00
0005432823416	7377	Economy	6200.00
0005432838545	7377	Economy	6200.00
0005434458493	7377	Economy	6200.00
0005434458480	7377	Economy	6200.00
0005432838558	7377	Economy	6200.00
0005432838565	7377	Economy	6200.00
0005432838564	7377	Economy	6200.00
0005434458484	7377	Economy	6200.00
0005432838559	7377	Economy	6200.00
0005434458490	7377	Economy	6200.00
0005432840978	7377	Economy	6200.00
0005434458476	7377	Economy	6200.00
0005434458496	7377	Economy	6200.00
0005432838570	7377	Economy	6200.00
0005432838550	7377	Economy	6200.00
0005432838548	7377	Economy	6200.00
0005432838567	7377	Economy	6200.00
0005434458481	7377	Economy	6200.00
0005432838551	7377	Economy	6200.00
0005432000991	28913	Business	18500.00
0005435252431	28913	Business	18500.00
0005435252422	28913	Business	18500.00
0005435252424	28913	Economy	6200.00
0005435252418	28913	Economy	6200.00
0005432000992	28913	Economy	6200.00
0005435252429	28913	Economy	6800.00
0005435252420	28913	Economy	6200.00
0005435252432	28913	Economy	6200.00
0005435252419	28913	Economy	6200.00
0005435252427	28913	Economy	6200.00
0005435491411	28913	Economy	6200.00
0005435252423	28913	Economy	6200.00
0005435252421	28913	Economy	6200.00
0005435252430	28913	Economy	6200.00
0005435491410	28913	Economy	6200.00
0005435252433	28913	Economy	6200.00
0005435252426	28913	Economy	6200.00
0005435252425	28913	Economy	6200.00
0005435252434	28913	Economy	6200.00
0005434664925	28913	Economy	6200.00
0005435491412	28913	Economy	6200.00
0005435252428	28913	Economy	6200.00
0005432000993	28913	Economy	6200.00
0005435990514	8810	Business	145300.00
0005435990518	8810	Economy	48400.00
0005435990515	8810	Economy	53300.00
0005435990516	8810	Economy	48400.00
0005435990513	8810	Economy	48400.00
0005435990517	8810	Economy	48400.00
0005434275939	15733	Economy	48400.00
0005434275938	15733	Economy	48400.00
0005434275941	15733	Economy	48400.00
0005434275940	15733	Economy	48400.00
0005433468194	2083	Economy	13300.00
0005433468195	2083	Economy	12100.00
0005433468198	2083	Economy	12100.00
0005433468203	2083	Economy	12100.00
0005433468200	2083	Economy	12100.00
0005433468206	2083	Economy	12100.00
0005433468190	2083	Economy	12100.00
0005433468197	2083	Economy	12100.00
0005433468202	2083	Economy	12100.00
0005433468201	2083	Economy	12100.00
0005433468193	2083	Economy	12100.00
0005433468205	2083	Economy	12100.00
0005433468196	2083	Economy	12100.00
0005433468204	2083	Economy	12100.00
0005433468192	2083	Economy	12100.00
0005433468189	2083	Economy	12100.00
0005433468191	2083	Economy	12100.00
0005433468199	2083	Economy	12100.00
0005432909206	23838	Economy	13300.00
0005432909200	23838	Economy	13300.00
0005432909204	23838	Economy	12100.00
0005432909197	23838	Economy	12100.00
0005432909196	23838	Economy	12100.00
0005432909191	23838	Economy	12100.00
0005432909194	23838	Economy	12100.00
0005432909195	23838	Economy	12100.00
0005432909198	23838	Economy	12100.00
0005432909193	23838	Economy	12100.00
0005432909189	23838	Economy	12100.00
0005432909205	23838	Economy	12100.00
0005432909190	23838	Economy	12100.00
0005432909202	23838	Economy	12100.00
0005432909201	23838	Economy	12100.00
0005432909199	23838	Economy	12100.00
0005432909192	23838	Economy	12100.00
0005432909203	23838	Economy	12100.00
0005432359622	6363	Business	36600.00
0005432359636	6363	Business	36600.00
0005432359621	6363	Business	36600.00
0005432359637	6363	Business	36600.00
0005432359611	6363	Business	36600.00
0005432359642	6363	Economy	12200.00
0005432363366	6363	Economy	12200.00
0005432359630	6363	Economy	12200.00
0005432335850	6363	Economy	12200.00
0005432359643	6363	Economy	12200.00
0005432359645	6363	Economy	12200.00
0005432062144	6363	Economy	12200.00
0005432359639	6363	Economy	12200.00
0005432359632	6363	Economy	12200.00
0005432359614	6363	Economy	12200.00
0005432359648	6363	Economy	12200.00
0005432359617	6363	Economy	12200.00
0005432363365	6363	Economy	12200.00
0005432359635	6363	Economy	12200.00
0005432359608	6363	Economy	12200.00
0005432359627	6363	Economy	12200.00
0005432359629	6363	Economy	12200.00
0005432359631	6363	Economy	12200.00
0005432359626	6363	Economy	12200.00
0005432359610	6363	Economy	12200.00
0005432359623	6363	Economy	12200.00
0005432335849	6363	Economy	12200.00
0005432359607	6363	Economy	13400.00
0005432359606	6363	Economy	13400.00
0005432359628	6363	Economy	13400.00
0005432359640	6363	Economy	13400.00
0005432359634	6363	Economy	13400.00
0005432335857	6363	Economy	12200.00
0005432359612	6363	Economy	12200.00
0005432335856	6363	Economy	12200.00
0005432359644	6363	Economy	12200.00
0005432335846	6363	Economy	12200.00
0005432062146	6363	Economy	12200.00
0005432359649	6363	Economy	12200.00
0005432062147	6363	Economy	12200.00
0005432359641	6363	Economy	12200.00
0005432335855	6363	Economy	12200.00
0005432335848	6363	Economy	12200.00
0005432359625	6363	Economy	12200.00
0005432335845	6363	Economy	12200.00
0005432062150	6363	Economy	12200.00
0005432359647	6363	Economy	12200.00
0005432359615	6363	Economy	12200.00
0005432359618	6363	Economy	12200.00
0005432062149	6363	Economy	12200.00
0005432359613	6363	Economy	12200.00
0005432359638	6363	Economy	12200.00
0005432359619	6363	Economy	12200.00
0005432359651	6363	Economy	12200.00
0005432359652	6363	Economy	12200.00
0005432359609	6363	Economy	12200.00
0005432335854	6363	Economy	12200.00
0005432335851	6363	Economy	12200.00
0005432359624	6363	Economy	12200.00
0005432335847	6363	Economy	12200.00
0005432062145	6363	Economy	12200.00
0005432359633	6363	Economy	12200.00
0005432359653	6363	Economy	12200.00
0005432335853	6363	Economy	12200.00
0005432359616	6363	Economy	12200.00
0005432359620	6363	Economy	12200.00
0005432359646	6363	Economy	12200.00
0005432359650	6363	Economy	12200.00
0005432335852	6363	Economy	12200.00
0005432062148	6363	Economy	12200.00
0005435176664	21041	Business	36600.00
0005435176662	21041	Business	36600.00
0005435176643	21041	Business	36600.00
0005435176653	21041	Business	36600.00
0005434149546	21041	Economy	12200.00
0005435176649	21041	Economy	12200.00
0005434149549	21041	Economy	12200.00
0005435176656	21041	Economy	12200.00
0005435176642	21041	Economy	12200.00
0005435176644	21041	Economy	12200.00
0005435176668	21041	Economy	12200.00
0005434149550	21041	Economy	12200.00
0005434149545	21041	Economy	12200.00
0005435176647	21041	Economy	12200.00
0005435490179	21041	Economy	12200.00
0005435176648	21041	Economy	12200.00
0005435490178	21041	Economy	12200.00
0005435176659	21041	Economy	12200.00
0005432052699	21041	Economy	12200.00
0005435723015	21041	Economy	12200.00
0005435176665	21041	Economy	12200.00
0005435176663	21041	Economy	12200.00
0005434149547	21041	Economy	12200.00
0005434149551	21041	Economy	12200.00
0005435176657	21041	Economy	12200.00
0005434149556	21041	Economy	12200.00
0005435176667	21041	Economy	13400.00
0005434149555	21041	Economy	13400.00
0005435176655	21041	Economy	13400.00
0005432052700	21041	Economy	13400.00
0005435723013	21041	Economy	12200.00
0005435176652	21041	Economy	12200.00
0005434149548	21041	Economy	12200.00
0005435176646	21041	Economy	12200.00
0005435176645	21041	Economy	12200.00
0005435176661	21041	Economy	12200.00
0005435723014	21041	Economy	12200.00
0005435490180	21041	Economy	12200.00
0005435176666	21041	Economy	12200.00
0005435176669	21041	Economy	12200.00
0005435490177	21041	Economy	12200.00
0005435176660	21041	Economy	12200.00
0005434149553	21041	Economy	12200.00
0005434149544	21041	Economy	12200.00
0005434149552	21041	Economy	12200.00
0005434149554	21041	Economy	12200.00
0005435176658	21041	Economy	12200.00
0005435176654	21041	Economy	12200.00
0005435176651	21041	Economy	12200.00
0005435176650	21041	Economy	12200.00
0005434186154	17694	Economy	3100.00
0005434186153	17694	Economy	3100.00
0005434186155	17694	Economy	3100.00
0005434186156	17694	Economy	3100.00
0005434458476	29115	Economy	3400.00
0005434448259	29115	Economy	3400.00
0005434458494	29115	Economy	3400.00
0005434458484	29115	Economy	3100.00
0005434458486	29115	Economy	3100.00
0005434458487	29115	Economy	3100.00
0005434463894	29115	Economy	3100.00
0005434448257	29115	Economy	3100.00
0005434458477	29115	Economy	3100.00
0005434458496	29115	Economy	3100.00
0005434458485	29115	Economy	3100.00
0005434458495	29115	Economy	3100.00
0005434463893	29115	Economy	3100.00
0005434462754	29115	Economy	3100.00
0005434463895	29115	Economy	3100.00
0005434458482	29115	Economy	3100.00
0005434458480	29115	Economy	3100.00
0005434458483	29115	Economy	3100.00
0005434458478	29115	Economy	3100.00
0005434458488	29115	Economy	3100.00
0005434458492	29115	Economy	3100.00
0005434448260	29115	Economy	3100.00
0005434458479	29115	Economy	3100.00
0005434448258	29115	Economy	3100.00
0005434458491	29115	Economy	3100.00
0005434458490	29115	Economy	3100.00
0005434462755	29115	Economy	3100.00
0005434458481	29115	Economy	3100.00
0005434458489	29115	Economy	3100.00
0005434458493	29115	Economy	3100.00
0005432603717	21469	Economy	7300.00
0005432603716	21469	Economy	7300.00
0005432603699	21469	Economy	7300.00
0005432603704	21469	Economy	6600.00
0005432603720	21469	Economy	6600.00
0005432603683	21469	Economy	6600.00
0005432603695	21469	Economy	6600.00
0005432603706	21469	Economy	6600.00
0005432603703	21469	Economy	6600.00
0005432603697	21469	Economy	6600.00
0005432603718	21469	Economy	6600.00
0005432603709	21469	Economy	6600.00
0005432603719	21469	Economy	6600.00
0005432603686	21469	Economy	6600.00
0005432603708	21469	Economy	6600.00
0005432603701	21469	Economy	6600.00
0005432603693	21469	Economy	6600.00
0005432603711	21469	Economy	6600.00
0005432603712	21469	Economy	6600.00
0005432603684	21469	Economy	6600.00
0005432603700	21469	Economy	6600.00
0005432603713	21469	Economy	6600.00
0005432603691	21469	Economy	6600.00
0005432603715	21469	Economy	6600.00
0005432603714	21469	Economy	6600.00
0005432603682	21469	Economy	6600.00
0005432603696	21469	Economy	6600.00
0005432603692	21469	Economy	6600.00
0005432603687	21469	Economy	6600.00
0005432603722	21469	Economy	6600.00
0005432603698	21469	Economy	6600.00
0005432603705	21469	Economy	6600.00
0005432603721	21469	Economy	6600.00
0005432603702	21469	Economy	6600.00
0005432603710	21469	Economy	6600.00
0005432603707	21469	Economy	6600.00
0005432603685	21469	Economy	6600.00
0005432603690	21469	Economy	6600.00
0005432603689	21469	Economy	6600.00
0005432603694	21469	Economy	6600.00
0005432603688	21469	Economy	6600.00
0005435221498	31659	Economy	6600.00
0005435221500	31659	Economy	6600.00
0005435221037	31659	Economy	6600.00
0005435221499	31659	Economy	6600.00
0005433293148	29611	Economy	19500.00
0005433293155	29611	Economy	17800.00
0005433293150	29611	Economy	17800.00
0005433293149	29611	Economy	17800.00
0005433293158	29611	Economy	17800.00
0005433293152	29611	Economy	17800.00
0005433293154	29611	Economy	17800.00
0005433293161	29611	Economy	17800.00
0005433293157	29611	Economy	17800.00
0005433293159	29611	Economy	17800.00
0005433293162	29611	Economy	17800.00
0005433293151	29611	Economy	17800.00
0005433293153	29611	Economy	17800.00
0005433293156	29611	Economy	17800.00
0005433293160	29611	Economy	17800.00
0005433293163	29611	Economy	17800.00
0005433473113	6678	Economy	14000.00
0005433473111	6678	Economy	12700.00
0005433473109	6678	Economy	12700.00
0005433473110	6678	Economy	12700.00
0005433473118	6678	Economy	12700.00
0005433473119	6678	Economy	12700.00
0005433473121	6678	Economy	12700.00
0005433473114	6678	Economy	12700.00
0005433473122	6678	Economy	12700.00
0005433473126	6678	Economy	12700.00
0005433473112	6678	Economy	12700.00
0005433473117	6678	Economy	12700.00
0005433473125	6678	Economy	12700.00
0005433473127	6678	Economy	12700.00
0005433473116	6678	Economy	12700.00
0005433473120	6678	Economy	12700.00
0005433473123	6678	Economy	12700.00
0005433473115	6678	Economy	12700.00
0005433473124	6678	Economy	12700.00
0005435257149	23897	Economy	14000.00
0005435257151	23897	Economy	14000.00
0005435257153	23897	Economy	12700.00
0005435257145	23897	Economy	12700.00
0005435257148	23897	Economy	12700.00
0005435257147	23897	Economy	12700.00
0005435257154	23897	Economy	12700.00
0005435257157	23897	Economy	12700.00
0005435257144	23897	Economy	12700.00
0005435257155	23897	Economy	12700.00
0005435257150	23897	Economy	12700.00
0005435257143	23897	Economy	12700.00
0005435257146	23897	Economy	12700.00
0005435257152	23897	Economy	12700.00
0005435257156	23897	Economy	12700.00
0005434604843	22401	Economy	6600.00
0005434606764	22401	Economy	6600.00
0005434604844	22401	Economy	6600.00
0005434604840	22401	Economy	6600.00
0005434604842	22401	Economy	6600.00
0005434606767	22401	Economy	6600.00
0005434606765	22401	Economy	6600.00
0005434606766	22401	Economy	6600.00
0005434604841	22401	Economy	6600.00
0005434602867	3837	Economy	24900.00
0005434602864	3837	Economy	24900.00
0005434522380	3837	Economy	22600.00
0005434602865	3837	Economy	22600.00
0005434602863	3837	Economy	22600.00
0005434602862	3837	Economy	22600.00
0005434602860	3837	Economy	22600.00
0005434602858	3837	Economy	22600.00
0005434522381	3837	Economy	22600.00
0005434602861	3837	Economy	22600.00
0005434522379	3837	Economy	22600.00
0005434522383	3837	Economy	22600.00
0005434522377	3837	Economy	22600.00
0005434602859	3837	Economy	22600.00
0005434522386	3837	Economy	22600.00
0005434522382	3837	Economy	22600.00
0005434522378	3837	Economy	22600.00
0005434522385	3837	Economy	22600.00
0005434522387	3837	Economy	22600.00
0005434522376	3837	Economy	22600.00
0005434602866	3837	Economy	22600.00
0005434522384	3837	Economy	22600.00
0005435904370	19059	Economy	24900.00
0005435904369	19059	Economy	22600.00
0005435904368	19059	Economy	22600.00
0005435904371	19059	Economy	22600.00
0005435904366	19059	Economy	22600.00
0005435904367	19059	Economy	22600.00
0005435904365	19059	Economy	22600.00
0005435904372	19059	Economy	22600.00
0005432746953	382	Business	44500.00
0005432746962	382	Business	44500.00
0005432746945	382	Business	44500.00
0005432746973	382	Business	44500.00
0005435154583	382	Business	44500.00
0005432753245	382	Economy	14800.00
0005432746959	382	Economy	14800.00
0005432746968	382	Economy	14800.00
0005432219934	382	Economy	14800.00
0005435154584	382	Economy	14800.00
0005432746972	382	Economy	14800.00
0005432746963	382	Economy	16300.00
0005432746948	382	Economy	16300.00
0005432746969	382	Economy	14800.00
0005432746955	382	Economy	14800.00
0005432749749	382	Economy	14800.00
0005432746954	382	Economy	14800.00
0005432746975	382	Economy	14800.00
0005432219938	382	Economy	14800.00
0005432751473	382	Economy	14800.00
0005432219937	382	Economy	14800.00
0005432746952	382	Economy	14800.00
0005432746956	382	Economy	14800.00
0005432746949	382	Economy	14800.00
0005432751470	382	Economy	14800.00
0005432746971	382	Economy	14800.00
0005432746981	382	Economy	14800.00
0005432749750	382	Economy	14800.00
0005432753246	382	Economy	14800.00
0005432746965	382	Economy	14800.00
0005432746946	382	Economy	14800.00
0005432746979	382	Economy	14800.00
0005432746964	382	Economy	14800.00
0005435154585	382	Economy	14800.00
0005432746970	382	Economy	14800.00
0005432746978	382	Economy	14800.00
0005432219936	382	Economy	14800.00
0005432746967	382	Economy	14800.00
0005432746961	382	Economy	14800.00
0005432746960	382	Economy	14800.00
0005432219935	382	Economy	14800.00
0005432746950	382	Economy	14800.00
0005432746957	382	Economy	14800.00
0005432746977	382	Economy	14800.00
0005432746966	382	Economy	14800.00
0005432746976	382	Economy	14800.00
0005432753247	382	Economy	14800.00
0005432746958	382	Economy	14800.00
0005432746974	382	Economy	14800.00
0005432746980	382	Economy	14800.00
0005432751472	382	Economy	14800.00
0005432746947	382	Economy	14800.00
0005432751471	382	Economy	14800.00
0005432746951	382	Economy	14800.00
0005432890723	12085	Business	44500.00
0005432890727	12085	Business	44500.00
0005432890728	12085	Economy	14800.00
0005433875356	12085	Economy	14800.00
0005432890717	12085	Economy	14800.00
0005432890711	12085	Economy	14800.00
0005434153515	12085	Economy	16300.00
0005432890718	12085	Economy	16300.00
0005432890721	12085	Economy	14800.00
0005432890720	12085	Economy	14800.00
0005432890714	12085	Economy	14800.00
0005432890712	12085	Economy	14800.00
0005432890719	12085	Economy	14800.00
0005432890713	12085	Economy	14800.00
0005432214769	12085	Economy	14800.00
0005432890726	12085	Economy	14800.00
0005433875355	12085	Economy	14800.00
0005432890715	12085	Economy	14800.00
0005432890724	12085	Economy	14800.00
0005432890716	12085	Economy	14800.00
0005432890722	12085	Economy	14800.00
0005432890725	12085	Economy	14800.00
0005432890710	12085	Economy	14800.00
0005432214770	12085	Economy	14800.00
0005433524858	18960	Economy	28200.00
0005433533244	18960	Economy	25700.00
0005433524865	18960	Economy	25700.00
0005433531233	18960	Economy	25700.00
0005433524860	18960	Economy	25700.00
0005433524867	18960	Economy	25700.00
0005433524866	18960	Economy	25700.00
0005433524861	18960	Economy	25700.00
0005433524869	18960	Economy	25700.00
0005433533247	18960	Economy	25700.00
0005433524857	18960	Economy	25700.00
0005433524868	18960	Economy	25700.00
0005433524856	18960	Economy	25700.00
0005433524859	18960	Economy	25700.00
0005433533246	18960	Economy	25700.00
0005433531230	18960	Economy	25700.00
0005433524863	18960	Economy	25700.00
0005433531232	18960	Economy	25700.00
0005433533245	18960	Economy	25700.00
0005433524864	18960	Economy	25700.00
0005433524862	18960	Economy	25700.00
0005433531231	18960	Economy	25700.00
0005433531229	18960	Economy	25700.00
0005432927897	32484	Economy	25700.00
0005432927898	32484	Economy	25700.00
0005432927902	32484	Economy	25700.00
0005432927899	32484	Economy	25700.00
0005432927901	32484	Economy	25700.00
0005432927900	32484	Economy	25700.00
0005434821646	5302	Business	84000.00
0005434821614	5302	Business	84000.00
0005434558150	5302	Business	84000.00
0005434821661	5302	Business	84000.00
0005434831073	5302	Business	84000.00
0005432396181	5302	Business	84000.00
0005434821579	5302	Business	84000.00
0005434831075	5302	Business	84000.00
0005432121121	5302	Business	84000.00
0005434821580	5302	Business	84000.00
0005432121118	5302	Business	84000.00
0005434821677	5302	Business	84000.00
0005434821635	5302	Business	84000.00
0005434821654	5302	Business	84000.00
0005434821583	5302	Business	84000.00
0005435149825	5302	Comfort	47600.00
0005434821637	5302	Comfort	47600.00
0005434821679	5302	Comfort	47600.00
0005434821698	5302	Comfort	47600.00
0005434821616	5302	Comfort	47600.00
0005434821599	5302	Comfort	47600.00
0005434821652	5302	Comfort	47600.00
0005434821607	5302	Comfort	47600.00
0005434821680	5302	Comfort	47600.00
0005434821572	5302	Comfort	47600.00
0005434821629	5302	Comfort	47600.00
0005434821595	5302	Comfort	47600.00
0005434821587	5302	Comfort	47600.00
0005434821673	5302	Comfort	47600.00
0005434821645	5302	Comfort	47600.00
0005434821669	5302	Comfort	47600.00
0005434664923	5302	Comfort	47600.00
0005434821641	5302	Comfort	47600.00
0005435149813	5302	Comfort	47600.00
0005434821697	5302	Comfort	47600.00
0005434821684	5302	Comfort	47600.00
0005434821648	5302	Comfort	47600.00
0005434821597	5302	Economy	28000.00
0005434664924	5302	Economy	28000.00
0005434821658	5302	Economy	28000.00
0005434821601	5302	Economy	28000.00
0005434821626	5302	Economy	28000.00
0005432394040	5302	Economy	28000.00
0005435149824	5302	Economy	28000.00
0005434821582	5302	Economy	28000.00
0005432121117	5302	Economy	28000.00
0005434821590	5302	Economy	28000.00
0005434558153	5302	Economy	28000.00
0005434821577	5302	Economy	28000.00
0005434821651	5302	Economy	28000.00
0005434821603	5302	Economy	28000.00
0005435149817	5302	Economy	28000.00
0005434821682	5302	Economy	28000.00
0005434821574	5302	Economy	28000.00
0005434821624	5302	Economy	28000.00
0005434821585	5302	Economy	28000.00
0005434821620	5302	Economy	28000.00
0005434558149	5302	Economy	28000.00
0005434821586	5302	Economy	28000.00
0005434821691	5302	Economy	28000.00
0005434821605	5302	Economy	28000.00
0005432121116	5302	Economy	28000.00
0005435149815	5302	Economy	28000.00
0005434821578	5302	Economy	28000.00
0005434821699	5302	Economy	28000.00
0005434821666	5302	Economy	28000.00
0005434821647	5302	Economy	28000.00
0005434821685	5302	Economy	28000.00
0005434828651	5302	Economy	28000.00
0005434821619	5302	Economy	28000.00
0005434821628	5302	Economy	28000.00
0005434821689	5302	Economy	28000.00
0005434821664	5302	Economy	28000.00
0005432121112	5302	Economy	28000.00
0005434558151	5302	Economy	30800.00
0005434821631	5302	Economy	30800.00
0005434821692	5302	Economy	28000.00
0005432121114	5302	Economy	28000.00
0005432121119	5302	Economy	28000.00
0005434821694	5302	Economy	28000.00
0005434821676	5302	Economy	28000.00
0005435149822	5302	Economy	28000.00
0005432394042	5302	Economy	28000.00
0005434821592	5302	Economy	28000.00
0005434821672	5302	Economy	28000.00
0005434821695	5302	Economy	28000.00
0005434821611	5302	Economy	28000.00
0005432121115	5302	Economy	28000.00
0005434831071	5302	Economy	28000.00
0005434558154	5302	Economy	28000.00
0005434821632	5302	Economy	28000.00
0005432396182	5302	Economy	28000.00
0005434821674	5302	Economy	28000.00
0005434821623	5302	Economy	28000.00
0005434821596	5302	Economy	28000.00
0005434821589	5302	Economy	28000.00
0005434821653	5302	Economy	28000.00
0005435149816	5302	Economy	28000.00
0005434821591	5302	Economy	28000.00
0005434821622	5302	Economy	28000.00
0005434821642	5302	Economy	28000.00
0005434821667	5302	Economy	28000.00
0005435149820	5302	Economy	28000.00
0005434821604	5302	Economy	28000.00
0005434821576	5302	Economy	28000.00
0005434821606	5302	Economy	28000.00
0005432396180	5302	Economy	28000.00
0005434821696	5302	Economy	28000.00
0005434821675	5302	Economy	28000.00
0005434821665	5302	Economy	28000.00
0005434821593	5302	Economy	28000.00
0005432396179	5302	Economy	28000.00
0005434831072	5302	Economy	28000.00
0005434821655	5302	Economy	28000.00
0005434821687	5302	Economy	28000.00
0005434821598	5302	Economy	28000.00
0005434821615	5302	Economy	28000.00
0005434664922	5302	Economy	28000.00
0005434821693	5302	Economy	28000.00
0005434821594	5302	Economy	28000.00
0005434828652	5302	Economy	28000.00
0005432121122	5302	Economy	28000.00
0005432121120	5302	Economy	28000.00
0005434821659	5302	Economy	28000.00
0005434821636	5302	Economy	28000.00
0005434821639	5302	Economy	28000.00
0005434821613	5302	Economy	30800.00
0005432394041	5302	Economy	30800.00
0005434831074	5302	Economy	30800.00
0005434821668	5302	Economy	28000.00
0005435149818	5302	Economy	28000.00
0005434821625	5302	Economy	28000.00
0005434821571	5302	Economy	28000.00
0005434821671	5302	Economy	28000.00
0005432394043	5302	Economy	28000.00
0005435149826	5302	Economy	28000.00
0005434821644	5302	Economy	28000.00
0005432121113	5302	Economy	28000.00
0005434821683	5302	Economy	28000.00
0005432121123	5302	Economy	28000.00
0005434821600	5302	Economy	28000.00
0005434664921	5302	Economy	28000.00
0005434821588	5302	Economy	28000.00
0005434821575	5302	Economy	28000.00
0005434821630	5302	Economy	28000.00
0005434821612	5302	Economy	28000.00
0005432121124	5302	Economy	28000.00
0005434821610	5302	Economy	28000.00
0005434821618	5302	Economy	28000.00
0005434821617	5302	Economy	28000.00
0005434821662	5302	Economy	28000.00
0005434821656	5302	Economy	28000.00
0005434821573	5302	Economy	28000.00
0005434828653	5302	Economy	28000.00
0005434821584	5302	Economy	28000.00
0005434821690	5302	Economy	28000.00
0005434821643	5302	Economy	28000.00
0005434821688	5302	Economy	28000.00
0005434821649	5302	Economy	28000.00
0005434821640	5302	Economy	28000.00
0005435149821	5302	Economy	28000.00
0005434821633	5302	Economy	28000.00
0005435149819	5302	Economy	28000.00
0005434821657	5302	Economy	28000.00
0005434821670	5302	Economy	28000.00
0005434821650	5302	Economy	28000.00
0005434558152	5302	Economy	28000.00
0005434821663	5302	Economy	28000.00
0005434821608	5302	Economy	28000.00
0005434821678	5302	Economy	28000.00
0005434821681	5302	Economy	28000.00
0005435149814	5302	Economy	28000.00
0005434821660	5302	Economy	28000.00
0005434821686	5302	Economy	28000.00
0005434821627	5302	Economy	28000.00
0005434821609	5302	Economy	28000.00
0005432121111	5302	Economy	28000.00
0005435386455	5302	Economy	28000.00
0005434821581	5302	Economy	28000.00
0005435149823	5302	Economy	28000.00
0005434821638	5302	Economy	28000.00
0005434821634	5302	Economy	28000.00
0005434821621	5302	Economy	28000.00
0005434821602	5302	Economy	28000.00
0005435372280	9879	Business	84000.00
0005435372265	9879	Business	84000.00
0005435179688	9879	Business	84000.00
0005435372270	9879	Business	84000.00
0005435299704	9879	Business	84000.00
0005432202953	9879	Business	84000.00
0005435372256	9879	Business	84000.00
0005435372244	9879	Business	84000.00
0005432202955	9879	Business	84000.00
0005432202952	9879	Business	84000.00
0005435372248	9879	Business	84000.00
0005432823421	9879	Business	84000.00
0005435661885	9879	Business	84000.00
0005435661887	9879	Comfort	47600.00
0005435372260	9879	Comfort	47600.00
0005435372236	9879	Comfort	47600.00
0005435372227	9879	Comfort	47600.00
0005435372232	9879	Comfort	47600.00
0005435372233	9879	Comfort	47600.00
0005432202950	9879	Comfort	47600.00
0005435372257	9879	Comfort	47600.00
0005435372259	9879	Comfort	47600.00
0005435372250	9879	Comfort	47600.00
0005435372253	9879	Comfort	47600.00
0005435735069	9879	Comfort	47600.00
0005435372243	9879	Comfort	47600.00
0005435372246	9879	Comfort	47600.00
0005435372282	9879	Comfort	47600.00
0005435372271	9879	Comfort	47600.00
0005435735067	9879	Comfort	47600.00
0005435661889	9879	Comfort	47600.00
0005435386472	9879	Economy	28000.00
0005435372230	9879	Economy	28000.00
0005435372237	9879	Economy	28000.00
0005435372272	9879	Economy	28000.00
0005435372228	9879	Economy	28000.00
0005435372291	9879	Economy	28000.00
0005435299700	9879	Economy	28000.00
0005435302124	9879	Economy	28000.00
0005435372267	9879	Economy	28000.00
0005435372290	9879	Economy	30800.00
0005435372273	9879	Economy	30800.00
0005435386471	9879	Economy	28000.00
0005435299702	9879	Economy	28000.00
0005435372255	9879	Economy	28000.00
0005435372266	9879	Economy	28000.00
0005435386468	9879	Economy	28000.00
0005435372264	9879	Economy	28000.00
0005435372226	9879	Economy	28000.00
0005435386467	9879	Economy	28000.00
0005432202956	9879	Economy	28000.00
0005435372241	9879	Economy	28000.00
0005435179383	9879	Economy	28000.00
0005435299703	9879	Economy	28000.00
0005435302128	9879	Economy	28000.00
0005435299701	9879	Economy	28000.00
0005435372292	9879	Economy	28000.00
0005435372276	9879	Economy	28000.00
0005435735066	9879	Economy	28000.00
0005435661888	9879	Economy	28000.00
0005435372240	9879	Economy	28000.00
0005435302129	9879	Economy	28000.00
0005435735065	9879	Economy	28000.00
0005435386470	9879	Economy	28000.00
0005435372247	9879	Economy	28000.00
0005435372269	9879	Economy	28000.00
0005435372289	9879	Economy	28000.00
0005435179384	9879	Economy	28000.00
0005435302126	9879	Economy	28000.00
0005435302125	9879	Economy	28000.00
0005435372277	9879	Economy	28000.00
0005435372284	9879	Economy	28000.00
0005435372268	9879	Economy	28000.00
0005435372231	9879	Economy	28000.00
0005435372252	9879	Economy	28000.00
0005435372286	9879	Economy	30800.00
0005435372274	9879	Economy	30800.00
0005435735068	9879	Economy	28000.00
0005435386466	9879	Economy	28000.00
0005435372251	9879	Economy	28000.00
0005435372238	9879	Economy	28000.00
0005435372254	9879	Economy	28000.00
0005435372258	9879	Economy	28000.00
0005435372263	9879	Economy	28000.00
0005435372235	9879	Economy	28000.00
0005435372279	9879	Economy	28000.00
0005435372287	9879	Economy	28000.00
0005432823420	9879	Economy	28000.00
0005435372262	9879	Economy	28000.00
0005432823419	9879	Economy	28000.00
0005435372275	9879	Economy	28000.00
0005435372245	9879	Economy	28000.00
0005435372242	9879	Economy	28000.00
0005435372239	9879	Economy	28000.00
0005435372288	9879	Economy	28000.00
0005435372249	9879	Economy	28000.00
0005435372285	9879	Economy	28000.00
0005435372283	9879	Economy	28000.00
0005435372234	9879	Economy	28000.00
0005435386465	9879	Economy	28000.00
0005432202954	9879	Economy	28000.00
0005435372261	9879	Economy	28000.00
0005432202951	9879	Economy	28000.00
0005435372281	9879	Economy	28000.00
0005435372278	9879	Economy	28000.00
0005432202949	9879	Economy	28000.00
0005435661886	9879	Economy	28000.00
0005435386469	9879	Economy	28000.00
0005435372229	9879	Economy	28000.00
0005435302127	9879	Economy	28000.00
0005435082662	7020	Economy	8200.00
0005435790262	7020	Economy	8200.00
0005435082663	7020	Economy	8200.00
0005435790263	7020	Economy	7400.00
0005435082667	7020	Economy	7400.00
0005435082666	7020	Economy	7400.00
0005435082669	7020	Economy	7400.00
0005435082664	7020	Economy	7400.00
0005435790260	7020	Economy	7400.00
0005435082665	7020	Economy	7400.00
0005435082668	7020	Economy	7400.00
0005435790261	7020	Economy	7400.00
0005434755807	9553	Business	32800.00
0005434755822	9553	Business	32800.00
0005434755806	9553	Business	32800.00
0005434755793	9553	Business	32800.00
0005434755814	9553	Economy	10900.00
0005434755809	9553	Economy	10900.00
0005434755785	9553	Economy	10900.00
0005434755820	9553	Economy	10900.00
0005434755801	9553	Economy	10900.00
0005434755796	9553	Economy	12000.00
0005434755798	9553	Economy	10900.00
0005434755788	9553	Economy	10900.00
0005434755783	9553	Economy	10900.00
0005434755790	9553	Economy	10900.00
0005434755808	9553	Economy	10900.00
0005434755819	9553	Economy	10900.00
0005434755802	9553	Economy	10900.00
0005434755810	9553	Economy	10900.00
0005434755792	9553	Economy	10900.00
0005434755812	9553	Economy	10900.00
0005434755797	9553	Economy	10900.00
0005434755804	9553	Economy	10900.00
0005434755782	9553	Economy	10900.00
0005434755818	9553	Economy	10900.00
0005434755800	9553	Economy	10900.00
0005434755795	9553	Economy	10900.00
0005434755815	9553	Economy	10900.00
0005434755786	9553	Economy	10900.00
0005434755823	9553	Economy	10900.00
0005434755803	9553	Economy	10900.00
0005434755787	9553	Economy	10900.00
0005434755794	9553	Economy	10900.00
0005434755811	9553	Economy	10900.00
0005434755805	9553	Economy	10900.00
0005434755813	9553	Economy	10900.00
0005434755791	9553	Economy	10900.00
0005434755789	9553	Economy	10900.00
0005434755817	9553	Economy	10900.00
0005434755784	9553	Economy	10900.00
0005434755816	9553	Economy	10900.00
0005434755821	9553	Economy	10900.00
0005434755799	9553	Economy	10900.00
0005434213748	28608	Business	32800.00
0005434213766	28608	Business	32800.00
0005434213771	28608	Business	32800.00
0005434213770	28608	Business	32800.00
0005434213764	28608	Business	32800.00
0005434213793	28608	Business	32800.00
0005434213760	28608	Business	32800.00
0005434213779	28608	Economy	10900.00
0005434213787	28608	Economy	10900.00
0005434213789	28608	Economy	10900.00
0005434213746	28608	Economy	10900.00
0005434213780	28608	Economy	10900.00
0005434213752	28608	Economy	12000.00
0005434213749	28608	Economy	12000.00
0005434213753	28608	Economy	12000.00
0005434213761	28608	Economy	10900.00
0005434213782	28608	Economy	10900.00
0005434213758	28608	Economy	10900.00
0005434213776	28608	Economy	10900.00
0005434213788	28608	Economy	10900.00
0005434213763	28608	Economy	10900.00
0005434213768	28608	Economy	10900.00
0005434213755	28608	Economy	10900.00
0005434213769	28608	Economy	10900.00
0005434213765	28608	Economy	10900.00
0005434213754	28608	Economy	10900.00
0005434213792	28608	Economy	10900.00
0005434213791	28608	Economy	10900.00
0005434213756	28608	Economy	10900.00
0005434213762	28608	Economy	10900.00
0005434213775	28608	Economy	10900.00
0005434213790	28608	Economy	10900.00
0005434213747	28608	Economy	10900.00
0005434213785	28608	Economy	10900.00
0005434213777	28608	Economy	10900.00
0005434213773	28608	Economy	10900.00
0005434213759	28608	Economy	10900.00
0005434213784	28608	Economy	10900.00
0005434213767	28608	Economy	10900.00
0005434213750	28608	Economy	10900.00
0005434213772	28608	Economy	10900.00
0005434213783	28608	Economy	10900.00
0005434213781	28608	Economy	10900.00
0005434213786	28608	Economy	10900.00
0005434213774	28608	Economy	10900.00
0005434213751	28608	Economy	10900.00
0005434213757	28608	Economy	10900.00
0005434213778	28608	Economy	10900.00
0005435100076	10805	Economy	8900.00
0005435100077	10805	Economy	8900.00
0005435100075	10805	Economy	8900.00
0005434760160	31808	Economy	8900.00
0005434760158	31808	Economy	8900.00
0005434760159	31808	Economy	8900.00
0005434638906	2010	Economy	20900.00
0005434638914	2010	Economy	19000.00
0005434638920	2010	Economy	19000.00
0005434638921	2010	Economy	19000.00
0005434638911	2010	Economy	19000.00
0005434638903	2010	Economy	19000.00
0005434638918	2010	Economy	19000.00
0005434638905	2010	Economy	19000.00
0005434638904	2010	Economy	19000.00
0005434638919	2010	Economy	19000.00
0005432290587	2010	Economy	19000.00
0005434638915	2010	Economy	19000.00
0005434638908	2010	Economy	19000.00
0005434638913	2010	Economy	19000.00
0005434638925	2010	Economy	19000.00
0005434638916	2010	Economy	19000.00
0005434638924	2010	Economy	19000.00
0005432290585	2010	Economy	19000.00
0005434638907	2010	Economy	19000.00
0005434638926	2010	Economy	19000.00
0005434638927	2010	Economy	19000.00
0005434638923	2010	Economy	19000.00
0005434638917	2010	Economy	19000.00
0005434638909	2010	Economy	19000.00
0005434638910	2010	Economy	19000.00
0005434638912	2010	Economy	19000.00
0005432290586	2010	Economy	19000.00
0005434638922	2010	Economy	19000.00
0005433202131	23246	Economy	20900.00
0005433202127	23246	Economy	19000.00
0005433202118	23246	Economy	19000.00
0005433202120	23246	Economy	19000.00
0005433202125	23246	Economy	19000.00
0005433202117	23246	Economy	19000.00
0005433202119	23246	Economy	19000.00
0005433202132	23246	Economy	19000.00
0005433202130	23246	Economy	19000.00
0005433202129	23246	Economy	19000.00
0005433202123	23246	Economy	19000.00
0005433202128	23246	Economy	19000.00
0005433202121	23246	Economy	19000.00
0005433202126	23246	Economy	19000.00
0005433202124	23246	Economy	19000.00
0005433202122	23246	Economy	19000.00
0005434600404	6093	Business	69700.00
0005433531235	6093	Business	69700.00
0005432111232	6093	Business	69700.00
0005434600384	6093	Business	69700.00
0005434600388	6093	Business	69700.00
0005433533250	6093	Business	69700.00
0005434600382	6093	Economy	23200.00
0005434600405	6093	Economy	23200.00
0005434600395	6093	Economy	23200.00
0005432111231	6093	Economy	23200.00
0005434600406	6093	Economy	25600.00
0005434600389	6093	Economy	25600.00
0005434600402	6093	Economy	25600.00
0005434600400	6093	Economy	23200.00
0005434600407	6093	Economy	23200.00
0005434600385	6093	Economy	23200.00
0005434600394	6093	Economy	23200.00
0005433531234	6093	Economy	23200.00
0005433531236	6093	Economy	23200.00
0005434600408	6093	Economy	23200.00
0005434600409	6093	Economy	23200.00
0005434600397	6093	Economy	23200.00
0005434600403	6093	Economy	23200.00
0005434600386	6093	Economy	23200.00
0005434600392	6093	Economy	23200.00
0005434600390	6093	Economy	23200.00
0005434600391	6093	Economy	23200.00
0005434600401	6093	Economy	23200.00
0005434600387	6093	Economy	23200.00
0005433533251	6093	Economy	23200.00
0005434600399	6093	Economy	23200.00
0005432111233	6093	Economy	23200.00
0005434600398	6093	Economy	23200.00
0005434600383	6093	Economy	23200.00
0005433533249	6093	Economy	23200.00
0005434600396	6093	Economy	23200.00
0005434600393	6093	Economy	23200.00
0005433533248	6093	Economy	23200.00
0005433533252	6093	Economy	23200.00
0005435326533	18572	Business	69700.00
0005435326535	18572	Business	69700.00
0005435326536	18572	Economy	23200.00
0005435326532	18572	Economy	23200.00
0005435326525	18572	Economy	25600.00
0005435326529	18572	Economy	23200.00
0005435326527	18572	Economy	23200.00
0005435326531	18572	Economy	23200.00
0005435326538	18572	Economy	23200.00
0005435326530	18572	Economy	23200.00
0005435326537	18572	Economy	23200.00
0005435326534	18572	Economy	23200.00
0005435326528	18572	Economy	23200.00
0005435326526	18572	Economy	23200.00
0005434550356	10571	Business	9100.00
0005434550347	10571	Business	9100.00
0005434550327	10571	Business	9100.00
0005434550335	10571	Business	9100.00
0005434550343	10571	Business	9100.00
0005434558145	10571	Business	9100.00
0005434558142	10571	Business	9100.00
0005434550338	10571	Business	9100.00
0005434550340	10571	Business	9100.00
0005434550329	10571	Business	9100.00
0005434550362	10571	Business	9100.00
0005434550367	10571	Economy	3000.00
0005434550366	10571	Economy	3000.00
0005434550360	10571	Economy	3000.00
0005434550316	10571	Economy	3000.00
0005434550336	10571	Economy	3000.00
0005434550326	10571	Economy	3000.00
0005434550318	10571	Economy	3000.00
0005434550322	10571	Economy	3300.00
0005434550337	10571	Economy	3300.00
0005434550333	10571	Economy	3300.00
0005434550353	10571	Economy	3000.00
0005434550321	10571	Economy	3000.00
0005434558141	10571	Economy	3000.00
0005434550361	10571	Economy	3000.00
0005434550345	10571	Economy	3000.00
0005434550352	10571	Economy	3000.00
0005434554028	10571	Economy	3000.00
0005434550325	10571	Economy	3000.00
0005434550349	10571	Economy	3000.00
0005434550359	10571	Economy	3000.00
0005434550357	10571	Economy	3000.00
0005434550315	10571	Economy	3000.00
0005434550323	10571	Economy	3000.00
0005434550313	10571	Economy	3000.00
0005434550351	10571	Economy	3000.00
0005434550320	10571	Economy	3000.00
0005434550339	10571	Economy	3000.00
0005434550328	10571	Economy	3000.00
0005434550324	10571	Economy	3000.00
0005434550358	10571	Economy	3000.00
0005434558139	10571	Economy	3000.00
0005434550312	10571	Economy	3000.00
0005434550341	10571	Economy	3000.00
0005434550348	10571	Economy	3000.00
0005434550334	10571	Economy	3000.00
0005434550368	10571	Economy	3000.00
0005434550344	10571	Economy	3000.00
0005434550355	10571	Economy	3000.00
0005434558147	10571	Economy	3000.00
0005434550330	10571	Economy	3000.00
0005434550317	10571	Economy	3000.00
0005434558146	10571	Economy	3000.00
0005434558143	10571	Economy	3000.00
0005434550331	10571	Economy	3000.00
0005434550354	10571	Economy	3000.00
0005434550319	10571	Economy	3000.00
0005434550346	10571	Economy	3000.00
0005434550342	10571	Economy	3000.00
0005434558148	10571	Economy	3000.00
0005434558144	10571	Economy	3000.00
0005434550314	10571	Economy	3000.00
0005434550365	10571	Economy	3000.00
0005434550363	10571	Economy	3000.00
0005434550364	10571	Economy	3000.00
0005434554029	10571	Economy	3000.00
0005434550350	10571	Economy	3000.00
0005434550332	10571	Economy	3000.00
0005434558140	10571	Economy	3000.00
0005433180710	27775	Business	9100.00
0005433180703	27775	Business	9100.00
0005433180719	27775	Economy	3000.00
0005433180723	27775	Economy	3000.00
0005433180701	27775	Economy	3000.00
0005433180720	27775	Economy	3000.00
0005433180709	27775	Economy	3000.00
0005433180705	27775	Economy	3000.00
0005433180716	27775	Economy	3000.00
0005433180702	27775	Economy	3000.00
0005433180718	27775	Economy	3000.00
0005433180724	27775	Economy	3000.00
0005433180712	27775	Economy	3000.00
0005433180714	27775	Economy	3000.00
0005433180722	27775	Economy	3000.00
0005433180708	27775	Economy	3000.00
0005433180707	27775	Economy	3000.00
0005433180704	27775	Economy	3000.00
0005433180713	27775	Economy	3000.00
0005433180711	27775	Economy	3000.00
0005433180706	27775	Economy	3000.00
0005433180715	27775	Economy	3000.00
0005433180721	27775	Economy	3000.00
0005433180725	27775	Economy	3000.00
0005433180717	27775	Economy	3000.00
0005433459152	6161	Economy	11700.00
0005433459155	6161	Economy	11700.00
0005433459153	6161	Economy	11700.00
0005433459154	6161	Economy	11700.00
0005435254434	19290	Economy	11700.00
0005435254435	19290	Economy	11700.00
0005435254436	19290	Economy	11700.00
0005435661883	6723	Business	51100.00
0005435681477	6723	Business	51100.00
0005435719551	6723	Business	51100.00
0005435661884	6723	Business	51100.00
0005435681487	6723	Business	51100.00
0005435681475	6723	Business	51100.00
0005435681498	6723	Business	51100.00
0005435681489	6723	Economy	17000.00
0005435681491	6723	Economy	17000.00
0005435681476	6723	Economy	17000.00
0005435681474	6723	Economy	17000.00
0005435681501	6723	Economy	17000.00
0005435681492	6723	Economy	18700.00
0005435681507	6723	Economy	18700.00
0005435681468	6723	Economy	18700.00
0005435681480	6723	Economy	18700.00
0005435681481	6723	Economy	18700.00
0005435681470	6723	Economy	17000.00
0005435681467	6723	Economy	17000.00
0005435681473	6723	Economy	17000.00
0005435681485	6723	Economy	17000.00
0005432136093	6723	Economy	17000.00
0005435681482	6723	Economy	17000.00
0005435630918	6723	Economy	17000.00
0005435681504	6723	Economy	17000.00
0005435217677	6723	Economy	17000.00
0005435681494	6723	Economy	17000.00
0005435681506	6723	Economy	17000.00
0005435719550	6723	Economy	17000.00
0005435681493	6723	Economy	17000.00
0005435681497	6723	Economy	17000.00
0005435681479	6723	Economy	17000.00
0005435681505	6723	Economy	17000.00
0005435681486	6723	Economy	17000.00
0005435681469	6723	Economy	17000.00
0005435681484	6723	Economy	17000.00
0005435681483	6723	Economy	17000.00
0005435681471	6723	Economy	17000.00
0005432136091	6723	Economy	17000.00
0005435681503	6723	Economy	17000.00
0005432136092	6723	Economy	17000.00
0005435681488	6723	Economy	17000.00
0005435681500	6723	Economy	17000.00
0005435681502	6723	Economy	17000.00
0005435661882	6723	Economy	17000.00
0005435681496	6723	Economy	17000.00
0005435630917	6723	Economy	17000.00
0005435681472	6723	Economy	17000.00
0005435681478	6723	Economy	17000.00
0005435681490	6723	Economy	17000.00
0005432136090	6723	Economy	17000.00
0005435681495	6723	Economy	17000.00
0005435681499	6723	Economy	17000.00
0005435437599	24618	Business	51100.00
0005435437613	24618	Business	51100.00
0005435437601	24618	Economy	17000.00
0005432305711	24618	Economy	17000.00
0005435437605	24618	Economy	17000.00
0005435437615	24618	Economy	18700.00
0005432533247	24618	Economy	18700.00
0005434828654	24618	Economy	17000.00
0005435437617	24618	Economy	17000.00
0005435437616	24618	Economy	17000.00
0005435437619	24618	Economy	17000.00
0005435437603	24618	Economy	17000.00
0005435437600	24618	Economy	17000.00
0005435437606	24618	Economy	17000.00
0005432533248	24618	Economy	17000.00
0005432305709	24618	Economy	17000.00
0005435437604	24618	Economy	17000.00
0005435437602	24618	Economy	17000.00
0005435437609	24618	Economy	17000.00
0005435437610	24618	Economy	17000.00
0005435437612	24618	Economy	17000.00
0005435437618	24618	Economy	17000.00
0005435437597	24618	Economy	17000.00
0005435437614	24618	Economy	17000.00
0005435437607	24618	Economy	17000.00
0005435437598	24618	Economy	17000.00
0005434828655	24618	Economy	17000.00
0005435437608	24618	Economy	17000.00
0005435437611	24618	Economy	17000.00
0005432305710	24618	Economy	17000.00
0005435125693	11538	Business	26400.00
0005435125725	11538	Business	26400.00
0005435125691	11538	Business	26400.00
0005435125727	11538	Business	26400.00
0005435125719	11538	Business	26400.00
0005435125701	11538	Business	26400.00
0005435125709	11538	Business	26400.00
0005435125712	11538	Economy	8800.00
0005435125716	11538	Economy	8800.00
0005435125695	11538	Economy	9700.00
0005435125707	11538	Economy	9700.00
0005435125706	11538	Economy	8800.00
0005435125696	11538	Economy	8800.00
0005435125692	11538	Economy	8800.00
0005435125705	11538	Economy	8800.00
0005435105930	11538	Economy	8800.00
0005435125721	11538	Economy	8800.00
0005435125689	11538	Economy	8800.00
0005435125704	11538	Economy	8800.00
0005435125711	11538	Economy	8800.00
0005435125723	11538	Economy	8800.00
0005435125714	11538	Economy	8800.00
0005435125697	11538	Economy	8800.00
0005435125690	11538	Economy	8800.00
0005435125698	11538	Economy	8800.00
0005435125700	11538	Economy	8800.00
0005435125726	11538	Economy	8800.00
0005435125718	11538	Economy	8800.00
0005435125713	11538	Economy	8800.00
0005435125729	11538	Economy	8800.00
0005435105931	11538	Economy	8800.00
0005435125724	11538	Economy	8800.00
0005435125694	11538	Economy	8800.00
0005435125710	11538	Economy	8800.00
0005435125715	11538	Economy	8800.00
0005435125708	11538	Economy	8800.00
0005435125703	11538	Economy	8800.00
0005435125717	11538	Economy	8800.00
0005435125702	11538	Economy	8800.00
0005435125699	11538	Economy	8800.00
0005435125728	11538	Economy	8800.00
0005435125720	11538	Economy	8800.00
0005435125722	11538	Economy	8800.00
0005435558047	31848	Economy	9700.00
0005433397283	13558	Business	36600.00
0005433397286	13558	Business	36600.00
0005433397321	13558	Business	36600.00
0005433397295	13558	Business	36600.00
0005433397318	13558	Business	36600.00
0005433397311	13558	Business	36600.00
0005433397327	13558	Business	36600.00
0005433397307	13558	Economy	12200.00
0005433397282	13558	Economy	12200.00
0005433397290	13558	Economy	12200.00
0005433397287	13558	Economy	13400.00
0005433397314	13558	Economy	13400.00
0005433397291	13558	Economy	13400.00
0005433397324	13558	Economy	12200.00
0005433397278	13558	Economy	12200.00
0005433397296	13558	Economy	12200.00
0005433397297	13558	Economy	12200.00
0005433397293	13558	Economy	12200.00
0005433397294	13558	Economy	12200.00
0005433397306	13558	Economy	12200.00
0005433397325	13558	Economy	12200.00
0005433397320	13558	Economy	12200.00
0005433397284	13558	Economy	12200.00
0005433397281	13558	Economy	12200.00
0005433397292	13558	Economy	12200.00
0005433397298	13558	Economy	12200.00
0005433397315	13558	Economy	12200.00
0005433397289	13558	Economy	12200.00
0005433397317	13558	Economy	12200.00
0005433397288	13558	Economy	12200.00
0005433397305	13558	Economy	12200.00
0005433397303	13558	Economy	12200.00
0005433397299	13558	Economy	12200.00
0005433397323	13558	Economy	12200.00
0005433397300	13558	Economy	12200.00
0005433397304	13558	Economy	12200.00
0005433397302	13558	Economy	12200.00
0005433397308	13558	Economy	12200.00
0005433397285	13558	Economy	12200.00
0005433397326	13558	Economy	12200.00
0005433397313	13558	Economy	12200.00
0005433397319	13558	Economy	12200.00
0005433397316	13558	Economy	12200.00
0005433397312	13558	Economy	12200.00
0005433397309	13558	Economy	12200.00
0005433397322	13558	Economy	12200.00
0005433397279	13558	Economy	12200.00
0005433397301	13558	Economy	12200.00
0005433397280	13558	Economy	12200.00
0005433397310	13558	Economy	12200.00
0005435732132	19385	Business	36600.00
0005435732147	19385	Business	36600.00
0005432297237	19385	Business	36600.00
0005435732148	19385	Business	36600.00
0005435732135	19385	Economy	12200.00
0005432297236	19385	Economy	12200.00
0005435732131	19385	Economy	12200.00
0005435732138	19385	Economy	13400.00
0005433397219	19385	Economy	13400.00
0005435732149	19385	Economy	13400.00
0005435732142	19385	Economy	13400.00
0005435732134	19385	Economy	12200.00
0005432297235	19385	Economy	12200.00
0005435732151	19385	Economy	12200.00
0005435732139	19385	Economy	12200.00
0005435732144	19385	Economy	12200.00
0005435732141	19385	Economy	12200.00
0005435732129	19385	Economy	12200.00
0005435732136	19385	Economy	12200.00
0005435732133	19385	Economy	12200.00
0005435732140	19385	Economy	12200.00
0005435732146	19385	Economy	12200.00
0005435732145	19385	Economy	12200.00
0005435732137	19385	Economy	12200.00
0005435732130	19385	Economy	12200.00
0005435732150	19385	Economy	12200.00
0005435732143	19385	Economy	12200.00
0005435925084	13144	Business	11300.00
0005435925094	13144	Business	11300.00
0005435925093	13144	Business	11300.00
0005435925087	13144	Economy	3800.00
0005435925095	13144	Economy	3800.00
0005435925090	13144	Economy	3800.00
0005435925092	13144	Economy	4100.00
0005435925085	13144	Economy	4100.00
0005435925081	13144	Economy	3800.00
0005435925079	13144	Economy	3800.00
0005435925080	13144	Economy	3800.00
0005435925089	13144	Economy	3800.00
0005435925088	13144	Economy	3800.00
0005435925091	13144	Economy	3800.00
0005435925078	13144	Economy	3800.00
0005435925082	13144	Economy	3800.00
0005435925086	13144	Economy	3800.00
0005435925083	13144	Economy	3800.00
0005435068254	15500	Business	11300.00
0005435068256	15500	Business	11300.00
0005435068219	15500	Business	11300.00
0005435068248	15500	Business	11300.00
0005435068262	15500	Business	11300.00
0005435068250	15500	Business	11300.00
0005435068252	15500	Business	11300.00
0005435068236	15500	Business	11300.00
0005435068243	15500	Economy	3800.00
0005435068230	15500	Economy	3800.00
0005435068238	15500	Economy	3800.00
0005435068220	15500	Economy	3800.00
0005435068213	15500	Economy	4100.00
0005435068215	15500	Economy	4100.00
0005435068235	15500	Economy	4100.00
0005435068218	15500	Economy	4100.00
0005435068263	15500	Economy	3800.00
0005435068245	15500	Economy	3800.00
0005435068260	15500	Economy	3800.00
0005435068224	15500	Economy	3800.00
0005435068253	15500	Economy	3800.00
0005435068211	15500	Economy	3800.00
0005435068223	15500	Economy	3800.00
0005435068229	15500	Economy	3800.00
0005435068258	15500	Economy	3800.00
0005435068232	15500	Economy	3800.00
0005435068234	15500	Economy	3800.00
0005435068246	15500	Economy	3800.00
0005435068216	15500	Economy	3800.00
0005435068261	15500	Economy	3800.00
0005435068217	15500	Economy	3800.00
0005435068242	15500	Economy	3800.00
0005435068228	15500	Economy	3800.00
0005435068237	15500	Economy	3800.00
0005435068247	15500	Economy	3800.00
0005435068226	15500	Economy	3800.00
0005435068249	15500	Economy	3800.00
0005435068212	15500	Economy	3800.00
0005435068222	15500	Economy	3800.00
0005435068221	15500	Economy	3800.00
0005435068241	15500	Economy	3800.00
0005435068255	15500	Economy	3800.00
0005435068233	15500	Economy	3800.00
0005435068251	15500	Economy	3800.00
0005435068227	15500	Economy	3800.00
0005435068244	15500	Economy	3800.00
0005435068225	15500	Economy	3800.00
0005435068257	15500	Economy	3800.00
0005435068239	15500	Economy	3800.00
0005435068214	15500	Economy	3800.00
0005435068240	15500	Economy	3800.00
0005435068231	15500	Economy	3800.00
0005435068259	15500	Economy	3800.00
0005433407490	29484	Economy	24700.00
0005433407485	29484	Economy	24700.00
0005433407487	29484	Economy	24700.00
0005433407489	29484	Economy	24700.00
0005433407488	29484	Economy	24700.00
0005433407482	29484	Economy	24700.00
0005433407483	29484	Economy	24700.00
0005433407484	29484	Economy	24700.00
0005433407486	29484	Economy	24700.00
0005433407491	29484	Economy	24700.00
0005434213794	10710	Business	61300.00
0005434213800	10710	Business	61300.00
0005434213823	10710	Business	61300.00
0005434213818	10710	Business	61300.00
0005434213810	10710	Business	61300.00
0005434213837	10710	Business	61300.00
0005434213832	10710	Economy	20400.00
0005434213820	10710	Economy	20400.00
0005434213807	10710	Economy	20400.00
0005434213827	10710	Economy	20400.00
0005434213808	10710	Economy	20400.00
0005434213840	10710	Economy	20400.00
0005434213824	10710	Economy	22500.00
0005434213825	10710	Economy	22500.00
0005434213809	10710	Economy	20400.00
0005434213828	10710	Economy	20400.00
0005434213816	10710	Economy	20400.00
0005434213799	10710	Economy	20400.00
0005434213813	10710	Economy	20400.00
0005434213797	10710	Economy	20400.00
0005434213836	10710	Economy	20400.00
0005434213796	10710	Economy	20400.00
0005434213798	10710	Economy	20400.00
0005434213826	10710	Economy	20400.00
0005434213805	10710	Economy	20400.00
0005434213822	10710	Economy	20400.00
0005434213804	10710	Economy	20400.00
0005434213801	10710	Economy	20400.00
0005434213819	10710	Economy	20400.00
0005434213806	10710	Economy	20400.00
0005434213835	10710	Economy	20400.00
0005434213795	10710	Economy	20400.00
0005434213803	10710	Economy	20400.00
0005434213812	10710	Economy	20400.00
0005434213821	10710	Economy	20400.00
0005434213830	10710	Economy	20400.00
0005434213833	10710	Economy	20400.00
0005434213834	10710	Economy	20400.00
0005434213811	10710	Economy	20400.00
0005434213802	10710	Economy	20400.00
0005434213829	10710	Economy	20400.00
0005434213831	10710	Economy	20400.00
0005434213838	10710	Economy	20400.00
0005434213817	10710	Economy	20400.00
0005434213814	10710	Economy	20400.00
0005434213815	10710	Economy	20400.00
0005434213839	10710	Economy	20400.00
0005434755739	28655	Business	61300.00
0005434755754	28655	Business	61300.00
0005434755737	28655	Business	61300.00
0005434755738	28655	Business	61300.00
0005434755760	28655	Business	61300.00
0005434755742	28655	Business	61300.00
0005434755746	28655	Business	61300.00
0005434755743	28655	Business	61300.00
0005434755774	28655	Economy	20400.00
0005434755756	28655	Economy	20400.00
0005434755773	28655	Economy	20400.00
0005434755775	28655	Economy	20400.00
0005434755740	28655	Economy	20400.00
0005434755762	28655	Economy	22500.00
0005434755748	28655	Economy	22500.00
0005434755781	28655	Economy	20400.00
0005434755736	28655	Economy	20400.00
0005434755758	28655	Economy	20400.00
0005434755749	28655	Economy	20400.00
0005434755770	28655	Economy	20400.00
0005434755751	28655	Economy	20400.00
0005434755772	28655	Economy	20400.00
0005434755764	28655	Economy	20400.00
0005434755778	28655	Economy	20400.00
0005434755769	28655	Economy	20400.00
0005434755761	28655	Economy	20400.00
0005434755767	28655	Economy	20400.00
0005434755757	28655	Economy	20400.00
0005434755763	28655	Economy	20400.00
0005434755755	28655	Economy	20400.00
0005434755777	28655	Economy	20400.00
0005434755753	28655	Economy	20400.00
0005434755765	28655	Economy	20400.00
0005434755780	28655	Economy	20400.00
0005434755750	28655	Economy	20400.00
0005434755759	28655	Economy	20400.00
0005434755752	28655	Economy	20400.00
0005434755747	28655	Economy	20400.00
0005434755741	28655	Economy	20400.00
0005434755771	28655	Economy	20400.00
0005434755779	28655	Economy	20400.00
0005434755745	28655	Economy	20400.00
0005434755766	28655	Economy	20400.00
0005434755744	28655	Economy	20400.00
0005434755768	28655	Economy	20400.00
0005434755776	28655	Economy	20400.00
0005435038748	5431	Business	29500.00
0005435038781	5431	Business	29500.00
0005435038762	5431	Business	29500.00
0005435038774	5431	Business	29500.00
0005435038753	5431	Business	29500.00
0005435038780	5431	Business	29500.00
0005435038742	5431	Business	29500.00
0005435038761	5431	Business	29500.00
0005435038771	5431	Business	29500.00
0005435038797	5431	Economy	9800.00
0005435006659	5431	Economy	9800.00
0005435038741	5431	Economy	9800.00
0005435006669	5431	Economy	9800.00
0005435038788	5431	Economy	9800.00
0005435006655	5431	Economy	9800.00
0005435038783	5431	Economy	9800.00
0005435038765	5431	Economy	9800.00
0005435042825	5431	Economy	9800.00
0005435006667	5431	Economy	9800.00
0005435038752	5431	Economy	9800.00
0005435038793	5431	Economy	9800.00
0005435038764	5431	Economy	9800.00
0005435038801	5431	Economy	9800.00
0005435038767	5431	Economy	9800.00
0005435038776	5431	Economy	9800.00
0005435038800	5431	Economy	9800.00
0005435038751	5431	Economy	9800.00
0005435006656	5431	Economy	9800.00
0005435006649	5431	Economy	9800.00
0005435038747	5431	Economy	9800.00
0005435006650	5431	Economy	9800.00
0005435038775	5431	Economy	9800.00
0005435038766	5431	Economy	9800.00
0005435038778	5431	Economy	9800.00
0005435038740	5431	Economy	9800.00
0005432125339	5431	Economy	9800.00
0005435038779	5431	Economy	9800.00
0005435038744	5431	Economy	9800.00
0005435038789	5431	Economy	9800.00
0005435038784	5431	Economy	10800.00
0005435038757	5431	Economy	9800.00
0005435006648	5431	Economy	10800.00
0005435038773	5431	Economy	10800.00
0005435038772	5431	Economy	10800.00
0005435038777	5431	Economy	10800.00
0005435038770	5431	Economy	10800.00
0005435038768	5431	Economy	9800.00
0005435038749	5431	Economy	9800.00
0005432125334	5431	Economy	9800.00
0005435006663	5431	Economy	9800.00
0005435038760	5431	Economy	9800.00
0005435038787	5431	Economy	9800.00
0005435038791	5431	Economy	9800.00
0005435006654	5431	Economy	9800.00
0005435038759	5431	Economy	9800.00
0005435006671	5431	Economy	9800.00
0005435038750	5431	Economy	9800.00
0005435006657	5431	Economy	9800.00
0005435038799	5431	Economy	9800.00
0005435006660	5431	Economy	9800.00
0005435038796	5431	Economy	9800.00
0005432125340	5431	Economy	9800.00
0005432125335	5431	Economy	9800.00
0005435038794	5431	Economy	9800.00
0005435038755	5431	Economy	9800.00
0005435006666	5431	Economy	9800.00
0005435038745	5431	Economy	9800.00
0005435006665	5431	Economy	9800.00
0005435038769	5431	Economy	9800.00
0005435038756	5431	Economy	9800.00
0005435038754	5431	Economy	9800.00
0005435006658	5431	Economy	9800.00
0005435043273	5431	Economy	9800.00
0005432125338	5431	Economy	9800.00
0005435038803	5431	Economy	9800.00
0005435006647	5431	Economy	9800.00
0005435006662	5431	Economy	9800.00
0005435006668	5431	Economy	9800.00
0005435038739	5431	Economy	9800.00
0005435006664	5431	Economy	9800.00
0005435043275	5431	Economy	9800.00
0005435038790	5431	Economy	9800.00
0005435006652	5431	Economy	9800.00
0005435006653	5431	Economy	9800.00
0005435006670	5431	Economy	9800.00
0005432125337	5431	Economy	9800.00
0005435006661	5431	Economy	9800.00
0005432125336	5431	Economy	9800.00
0005435038798	5431	Economy	9800.00
0005435038785	5431	Economy	9800.00
0005435043274	5431	Economy	9800.00
0005435038786	5431	Economy	9800.00
0005435038792	5431	Economy	9800.00
0005435038782	5431	Economy	9800.00
0005435038743	5431	Economy	9800.00
0005435038795	5431	Economy	9800.00
0005435038758	5431	Economy	9800.00
0005435038804	5431	Economy	9800.00
0005435038763	5431	Economy	9800.00
0005435038746	5431	Economy	9800.00
0005435006651	5431	Economy	9800.00
0005435038802	5431	Economy	9800.00
0005435042824	5431	Economy	9800.00
0005432304338	12991	Business	29500.00
0005434229028	12991	Business	29500.00
0005434229029	12991	Economy	9800.00
0005434229034	12991	Economy	9800.00
0005434229021	12991	Economy	9800.00
0005434229027	12991	Economy	9800.00
0005434229014	12991	Economy	9800.00
0005434229026	12991	Economy	10800.00
0005434229012	12991	Economy	9800.00
0005434229020	12991	Economy	9800.00
0005434229022	12991	Economy	9800.00
0005434229016	12991	Economy	9800.00
0005434229023	12991	Economy	9800.00
0005434229017	12991	Economy	9800.00
0005434229031	12991	Economy	9800.00
0005434229013	12991	Economy	9800.00
0005434229024	12991	Economy	9800.00
0005434229018	12991	Economy	9800.00
0005434229030	12991	Economy	9800.00
0005434229025	12991	Economy	9800.00
0005434229033	12991	Economy	9800.00
0005434229015	12991	Economy	9800.00
0005434229032	12991	Economy	9800.00
0005434229019	12991	Economy	9800.00
0005432304339	12991	Economy	9800.00
0005434426129	14871	Business	52900.00
0005434426114	14871	Business	52900.00
0005434411705	14871	Business	52900.00
0005434426117	14871	Business	52900.00
0005434426140	14871	Economy	17600.00
0005434411706	14871	Economy	17600.00
0005432188556	14871	Economy	17600.00
0005434426128	14871	Economy	19400.00
0005434426144	14871	Economy	19400.00
0005434426134	14871	Economy	19400.00
0005434426142	14871	Economy	19400.00
0005434426136	14871	Economy	17600.00
0005434426139	14871	Economy	17600.00
0005434411707	14871	Economy	17600.00
0005432188555	14871	Economy	17600.00
0005434426141	14871	Economy	17600.00
0005434426132	14871	Economy	17600.00
0005434426131	14871	Economy	17600.00
0005434426137	14871	Economy	17600.00
0005434426135	14871	Economy	17600.00
0005434426145	14871	Economy	17600.00
0005434426115	14871	Economy	17600.00
0005434426120	14871	Economy	17600.00
0005434426122	14871	Economy	17600.00
0005434426121	14871	Economy	17600.00
0005434426124	14871	Economy	17600.00
0005434426123	14871	Economy	17600.00
0005434426143	14871	Economy	17600.00
0005434426116	14871	Economy	17600.00
0005434411708	14871	Economy	17600.00
0005434426130	14871	Economy	17600.00
0005434411709	14871	Economy	17600.00
0005434426133	14871	Economy	17600.00
0005434426127	14871	Economy	17600.00
0005434426118	14871	Economy	17600.00
0005434426126	14871	Economy	17600.00
0005434426119	14871	Economy	17600.00
0005434426125	14871	Economy	17600.00
0005432188554	14871	Economy	17600.00
0005434426138	14871	Economy	17600.00
0005432059474	20205	Business	52900.00
0005435902432	20205	Business	52900.00
0005435902422	20205	Economy	17600.00
0005435902431	20205	Economy	17600.00
0005432059475	20205	Economy	19400.00
0005435902436	20205	Economy	19400.00
0005435902425	20205	Economy	17600.00
0005435902435	20205	Economy	17600.00
0005435902421	20205	Economy	17600.00
0005435554115	20205	Economy	17600.00
0005435902430	20205	Economy	17600.00
0005435902427	20205	Economy	17600.00
0005435554114	20205	Economy	17600.00
0005432059473	20205	Economy	17600.00
0005435902428	20205	Economy	17600.00
0005435902433	20205	Economy	17600.00
0005435902424	20205	Economy	17600.00
0005435902434	20205	Economy	17600.00
0005435554113	20205	Economy	17600.00
0005435554117	20205	Economy	17600.00
0005435902437	20205	Economy	17600.00
0005435902426	20205	Economy	17600.00
0005435554116	20205	Economy	17600.00
0005435902429	20205	Economy	17600.00
0005435902423	20205	Economy	17600.00
0005432462483	28016	Economy	35600.00
0005432462480	28016	Economy	35600.00
0005432462484	28016	Economy	35600.00
0005432462478	28016	Economy	35600.00
0005432462479	28016	Economy	35600.00
0005432462481	28016	Economy	35600.00
0005432462482	28016	Economy	35600.00
0005435981551	26526	Business	18500.00
0005435981592	26526	Business	18500.00
0005435981589	26526	Business	18500.00
0005432300170	26526	Business	18500.00
0005435981549	26526	Business	18500.00
0005432300169	26526	Business	18500.00
0005435981557	26526	Business	18500.00
0005435981565	26526	Business	18500.00
0005435981574	26526	Business	18500.00
0005435981566	26526	Economy	6200.00
0005432300166	26526	Economy	6200.00
0005435981573	26526	Economy	6200.00
0005435981579	26526	Economy	6200.00
0005435981561	26526	Economy	6200.00
0005435981555	26526	Economy	6800.00
0005435981569	26526	Economy	6800.00
0005435981582	26526	Economy	6800.00
0005435981577	26526	Economy	6200.00
0005435981560	26526	Economy	6200.00
0005435981567	26526	Economy	6200.00
0005435981585	26526	Economy	6200.00
0005435981559	26526	Economy	6200.00
0005432300171	26526	Economy	6200.00
0005435981571	26526	Economy	6200.00
0005435981548	26526	Economy	6200.00
0005435981562	26526	Economy	6200.00
0005432300168	26526	Economy	6200.00
0005435981576	26526	Economy	6200.00
0005435981553	26526	Economy	6200.00
0005432300167	26526	Economy	6200.00
0005435981581	26526	Economy	6200.00
0005435981563	26526	Economy	6200.00
0005435981568	26526	Economy	6200.00
0005435981554	26526	Economy	6200.00
0005435981580	26526	Economy	6200.00
0005435981552	26526	Economy	6200.00
0005435981591	26526	Economy	6200.00
0005435981587	26526	Economy	6200.00
0005435981550	26526	Economy	6200.00
0005435981572	26526	Economy	6200.00
0005435981584	26526	Economy	6200.00
0005435981558	26526	Economy	6200.00
0005435981590	26526	Economy	6200.00
0005435981556	26526	Economy	6200.00
0005435981575	26526	Economy	6200.00
0005435981583	26526	Economy	6200.00
0005435981564	26526	Economy	6200.00
0005435981593	26526	Economy	6200.00
0005435981588	26526	Economy	6200.00
0005435981586	26526	Economy	6200.00
0005435981578	26526	Economy	6200.00
0005435981570	26526	Economy	6200.00
0005433434265	26681	Business	18500.00
0005434269070	26681	Business	18500.00
0005434269073	26681	Business	18500.00
0005433434258	26681	Business	18500.00
0005433434248	26681	Business	18500.00
0005433434244	26681	Economy	6200.00
0005433434246	26681	Economy	6200.00
0005433434240	26681	Economy	6200.00
0005433434238	26681	Economy	6200.00
0005432051080	26681	Economy	6200.00
0005433434243	26681	Economy	6200.00
0005433434239	26681	Economy	6200.00
0005434269072	26681	Economy	6800.00
0005433434254	26681	Economy	6800.00
0005433434260	26681	Economy	6200.00
0005432051079	26681	Economy	6200.00
0005433434237	26681	Economy	6200.00
0005433434247	26681	Economy	6200.00
0005433434252	26681	Economy	6200.00
0005433434241	26681	Economy	6200.00
0005433434242	26681	Economy	6200.00
0005433434256	26681	Economy	6200.00
0005433434262	26681	Economy	6200.00
0005434270176	26681	Economy	6200.00
0005433434263	26681	Economy	6200.00
0005433434251	26681	Economy	6200.00
0005433434264	26681	Economy	6200.00
0005433434245	26681	Economy	6200.00
0005433434259	26681	Economy	6200.00
0005434270175	26681	Economy	6200.00
0005433434257	26681	Economy	6200.00
0005432051082	26681	Economy	6200.00
0005433434249	26681	Economy	6200.00
0005434269071	26681	Economy	6200.00
0005433434261	26681	Economy	6200.00
0005432051081	26681	Economy	6200.00
0005433434255	26681	Economy	6200.00
0005433434250	26681	Economy	6200.00
0005434270174	26681	Economy	6200.00
0005433434253	26681	Economy	6200.00
0005432583656	3190	Economy	11100.00
0005432583646	3190	Economy	11100.00
0005432583651	3190	Economy	10100.00
0005432583657	3190	Economy	10100.00
0005432583645	3190	Economy	10100.00
0005432583635	3190	Economy	10100.00
0005432583654	3190	Economy	10100.00
0005432583641	3190	Economy	10100.00
0005432583659	3190	Economy	10100.00
0005432583649	3190	Economy	10100.00
0005432583655	3190	Economy	10100.00
0005432583644	3190	Economy	10100.00
0005432216229	3190	Economy	10100.00
0005432216228	3190	Economy	10100.00
0005432583636	3190	Economy	10100.00
0005432583653	3190	Economy	10100.00
0005432583638	3190	Economy	10100.00
0005432216230	3190	Economy	10100.00
0005432583642	3190	Economy	10100.00
0005432583643	3190	Economy	10100.00
0005432583640	3190	Economy	10100.00
0005432583648	3190	Economy	10100.00
0005432583639	3190	Economy	10100.00
0005432583658	3190	Economy	10100.00
0005432583660	3190	Economy	10100.00
0005432583652	3190	Economy	10100.00
0005432583647	3190	Economy	10100.00
0005432583650	3190	Economy	10100.00
0005432583637	3190	Economy	10100.00
0005432857880	31491	Economy	11100.00
0005432857881	31491	Economy	10100.00
0005432857875	31491	Economy	10100.00
0005432857878	31491	Economy	10100.00
0005432857883	31491	Economy	10100.00
0005432857882	31491	Economy	10100.00
0005432857884	31491	Economy	10100.00
0005432857877	31491	Economy	10100.00
0005432857874	31491	Economy	10100.00
0005432857885	31491	Economy	10100.00
0005432857876	31491	Economy	10100.00
0005432857886	31491	Economy	10100.00
0005432857879	31491	Economy	10100.00
0005434943210	899	Economy	8300.00
0005434943211	899	Economy	8300.00
0005434943207	899	Economy	8300.00
0005434943212	899	Economy	7500.00
0005434943206	899	Economy	7500.00
0005434943209	899	Economy	7500.00
0005434943205	899	Economy	7500.00
0005434943208	899	Economy	7500.00
0005434943204	899	Economy	7500.00
0005433255032	16212	Economy	8300.00
0005433255034	16212	Economy	7500.00
0005433255035	16212	Economy	7500.00
0005433255036	16212	Economy	7500.00
0005433255033	16212	Economy	7500.00
0005435652322	21757	Business	9800.00
0005435652323	21757	Business	9800.00
0005435652319	21757	Business	9800.00
0005435652338	21757	Business	9800.00
0005435652315	21757	Economy	3300.00
0005435652330	21757	Economy	3300.00
0005435652324	21757	Economy	3300.00
0005435652318	21757	Economy	3300.00
0005435652320	21757	Economy	3600.00
0005435652306	21757	Economy	3600.00
0005435652297	21757	Economy	3300.00
0005435652316	21757	Economy	3300.00
0005435652314	21757	Economy	3300.00
0005435652312	21757	Economy	3300.00
0005435652317	21757	Economy	3300.00
0005435652321	21757	Economy	3300.00
0005435652304	21757	Economy	3300.00
0005435652336	21757	Economy	3300.00
0005435652326	21757	Economy	3300.00
0005435652311	21757	Economy	3300.00
0005435652325	21757	Economy	3300.00
0005435652313	21757	Economy	3300.00
0005435652327	21757	Economy	3300.00
0005435652299	21757	Economy	3300.00
0005435652302	21757	Economy	3300.00
0005435652328	21757	Economy	3300.00
0005435652305	21757	Economy	3300.00
0005435652329	21757	Economy	3300.00
0005435652303	21757	Economy	3300.00
0005435652310	21757	Economy	3300.00
0005435652300	21757	Economy	3300.00
0005435652339	21757	Economy	3300.00
0005435652334	21757	Economy	3300.00
0005435652332	21757	Economy	3300.00
0005435652308	21757	Economy	3300.00
0005435652331	21757	Economy	3300.00
0005435652335	21757	Economy	3300.00
0005435652301	21757	Economy	3300.00
0005435652307	21757	Economy	3300.00
0005435652298	21757	Economy	3300.00
0005435652337	21757	Economy	3300.00
0005435652333	21757	Economy	3300.00
0005435652309	21757	Economy	3300.00
0005433784393	9359	Business	186200.00
0005433784400	9359	Business	186200.00
0005433762980	9359	Business	186200.00
0005433804856	9359	Business	186200.00
0005433784396	9359	Business	186200.00
0005433762974	9359	Business	186200.00
0005433784372	9359	Business	186200.00
0005432665243	9359	Business	186200.00
0005433804849	9359	Business	186200.00
0005433804836	9359	Business	186200.00
0005433762979	9359	Economy	68300.00
0005432657401	9359	Economy	68300.00
0005433762982	9359	Economy	62100.00
0005433784379	9359	Economy	62100.00
0005433804835	9359	Economy	62100.00
0005433784368	9359	Economy	62100.00
0005433784373	9359	Economy	62100.00
0005433804854	9359	Economy	62100.00
0005433762985	9359	Economy	62100.00
0005432667422	9359	Economy	62100.00
0005433784392	9359	Economy	62100.00
0005433804850	9359	Economy	62100.00
0005433804841	9359	Economy	62100.00
0005432657400	9359	Economy	62100.00
0005433804851	9359	Economy	62100.00
0005432666355	9359	Economy	62100.00
0005433804832	9359	Economy	62100.00
0005433804845	9359	Economy	62100.00
0005433784369	9359	Economy	62100.00
0005433784399	9359	Economy	62100.00
0005433804840	9359	Economy	62100.00
0005433784387	9359	Economy	62100.00
0005433784384	9359	Economy	62100.00
0005433804837	9359	Economy	62100.00
0005433804847	9359	Economy	62100.00
0005433804831	9359	Economy	62100.00
0005433804842	9359	Economy	62100.00
0005433804855	9359	Economy	62100.00
0005433784391	9359	Economy	62100.00
0005432665242	9359	Economy	62100.00
0005433762983	9359	Economy	62100.00
0005433804829	9359	Economy	62100.00
0005433784367	9359	Economy	62100.00
0005433762984	9359	Economy	62100.00
0005433784378	9359	Economy	62100.00
0005432666357	9359	Economy	62100.00
0005433784377	9359	Economy	62100.00
0005433762977	9359	Economy	62100.00
0005433804846	9359	Economy	62100.00
0005433784389	9359	Economy	62100.00
0005433804834	9359	Economy	62100.00
0005433784374	9359	Economy	62100.00
0005433804857	9359	Economy	62100.00
0005433784380	9359	Economy	68300.00
0005433804848	9359	Economy	62100.00
0005433784397	9359	Economy	62100.00
0005433784394	9359	Economy	62100.00
0005433762976	9359	Economy	62100.00
0005433784375	9359	Economy	62100.00
0005433804833	9359	Economy	62100.00
0005433784390	9359	Economy	62100.00
0005433804852	9359	Economy	62100.00
0005433784398	9359	Economy	62100.00
0005433784370	9359	Economy	62100.00
0005433784382	9359	Economy	62100.00
0005433784386	9359	Economy	62100.00
0005433804844	9359	Economy	62100.00
0005433804838	9359	Economy	62100.00
0005432665241	9359	Economy	62100.00
0005433762981	9359	Economy	62100.00
0005433784376	9359	Economy	62100.00
0005433804830	9359	Economy	62100.00
0005433762975	9359	Economy	62100.00
0005433804843	9359	Economy	62100.00
0005433762978	9359	Economy	62100.00
0005433784371	9359	Economy	62100.00
0005433784381	9359	Economy	62100.00
0005432666356	9359	Economy	62100.00
0005433804853	9359	Economy	62100.00
0005433762973	9359	Economy	62100.00
0005433762986	9359	Economy	62100.00
0005433784383	9359	Economy	62100.00
0005433784385	9359	Economy	62100.00
0005433804839	9359	Economy	62100.00
0005433784388	9359	Economy	62100.00
0005433804858	9359	Economy	62100.00
0005433784395	9359	Economy	62100.00
0005432667421	9359	Economy	62100.00
0005434170838	26218	Business	186200.00
0005434170828	26218	Business	186200.00
0005434170837	26218	Economy	62100.00
0005434170831	26218	Economy	62100.00
0005434170839	26218	Economy	62100.00
0005434270172	26218	Economy	62100.00
0005434270173	26218	Economy	62100.00
0005434170830	26218	Economy	62100.00
0005434170836	26218	Economy	62100.00
0005434170832	26218	Economy	62100.00
0005434170826	26218	Economy	62100.00
0005434170835	26218	Economy	62100.00
0005434271278	26218	Economy	62100.00
0005434170840	26218	Economy	62100.00
0005434170827	26218	Economy	62100.00
0005434170829	26218	Economy	62100.00
0005434151658	26218	Economy	62100.00
0005434151657	26218	Economy	62100.00
0005434271279	26218	Economy	62100.00
0005434271277	26218	Economy	62100.00
0005434170834	26218	Economy	62100.00
0005434271280	26218	Economy	62100.00
0005434170833	26218	Economy	62100.00
0005434151659	26218	Economy	62100.00
0005435135592	4934	Economy	5300.00
0005435135594	4934	Economy	5300.00
0005435135591	4934	Economy	5300.00
0005435135593	4934	Economy	5300.00
0005435135595	4934	Economy	5300.00
0005435929601	33042	Economy	5300.00
0005435929600	33042	Economy	5300.00
0005435929602	33042	Economy	5300.00
0005434983205	9503	Economy	17900.00
0005434983207	9503	Economy	17900.00
0005434983204	9503	Economy	17900.00
0005434983208	9503	Economy	17900.00
0005434983206	9503	Economy	17900.00
0005434217907	27374	Economy	19700.00
0005434217903	27374	Economy	17900.00
0005434217906	27374	Economy	17900.00
0005434217905	27374	Economy	17900.00
0005434217904	27374	Economy	17900.00
0005434217902	27374	Economy	17900.00
0005433959920	25910	Business	36400.00
0005433959908	25910	Business	36400.00
0005433985169	25910	Business	36400.00
0005433959940	25910	Business	36400.00
0005433959944	25910	Business	36400.00
0005433959925	25910	Business	36400.00
0005433959926	25910	Business	36400.00
0005433985173	25910	Business	36400.00
0005433959904	25910	Business	36400.00
0005433985184	25910	Business	36400.00
0005433959922	25910	Business	36400.00
0005433985201	25910	Business	36400.00
0005433985202	25910	Business	36400.00
0005433985178	25910	Business	36400.00
0005433985171	25910	Economy	13400.00
0005433959918	25910	Economy	12100.00
0005433985179	25910	Economy	12100.00
0005433985209	25910	Economy	12100.00
0005433985206	25910	Economy	12100.00
0005433959912	25910	Economy	12100.00
0005433985183	25910	Economy	12100.00
0005433985194	25910	Economy	12100.00
0005433985207	25910	Economy	12100.00
0005433959931	25910	Economy	12100.00
0005433959955	25910	Economy	12100.00
0005433985199	25910	Economy	12100.00
0005433959935	25910	Economy	12100.00
0005433959942	25910	Economy	12100.00
0005433959951	25910	Economy	12100.00
0005433959919	25910	Economy	12100.00
0005433985167	25910	Economy	12100.00
0005433959939	25910	Economy	12100.00
0005433959927	25910	Economy	12100.00
0005433985208	25910	Economy	12100.00
0005433959960	25910	Economy	12100.00
0005433985211	25910	Economy	12100.00
0005433959929	25910	Economy	12100.00
0005433959910	25910	Economy	12100.00
0005433959946	25910	Economy	12100.00
0005433959907	25910	Economy	12100.00
0005433959924	25910	Economy	12100.00
0005433985174	25910	Economy	12100.00
0005433985188	25910	Economy	12100.00
0005433985168	25910	Economy	12100.00
0005433985192	25910	Economy	12100.00
0005433985197	25910	Economy	12100.00
0005433985162	25910	Economy	12100.00
0005433985166	25910	Economy	12100.00
0005433985195	25910	Economy	12100.00
0005433985163	25910	Economy	12100.00
0005433985190	25910	Economy	12100.00
0005433959914	25910	Economy	12100.00
0005433959913	25910	Economy	12100.00
0005433985196	25910	Economy	12100.00
0005433985172	25910	Economy	12100.00
0005433959916	25910	Economy	12100.00
0005433985177	25910	Economy	12100.00
0005433985189	25910	Economy	12100.00
0005433959915	25910	Economy	12100.00
0005433985182	25910	Economy	12100.00
0005433959963	25910	Economy	12100.00
0005433985165	25910	Economy	12100.00
0005433959906	25910	Economy	12100.00
0005433959950	25910	Economy	13400.00
0005433959928	25910	Economy	12100.00
0005433959936	25910	Economy	12100.00
0005433985187	25910	Economy	13400.00
0005433959923	25910	Economy	13400.00
0005433959945	25910	Economy	12100.00
0005433985204	25910	Economy	12100.00
0005433985205	25910	Economy	12100.00
0005433985181	25910	Economy	12100.00
0005433985185	25910	Economy	12100.00
0005433959943	25910	Economy	12100.00
0005433985175	25910	Economy	12100.00
0005433959957	25910	Economy	12100.00
0005433985180	25910	Economy	12100.00
0005433959962	25910	Economy	12100.00
0005433959953	25910	Economy	12100.00
0005433959917	25910	Economy	12100.00
0005433985170	25910	Economy	12100.00
0005433985203	25910	Economy	12100.00
0005433985210	25910	Economy	12100.00
0005433985164	25910	Economy	12100.00
0005433959905	25910	Economy	12100.00
0005433959949	25910	Economy	12100.00
0005433959958	25910	Economy	12100.00
0005433959934	25910	Economy	12100.00
0005433959932	25910	Economy	12100.00
0005433985198	25910	Economy	12100.00
0005433985193	25910	Economy	12100.00
0005433959921	25910	Economy	12100.00
0005433959948	25910	Economy	12100.00
0005433959930	25910	Economy	12100.00
0005433959941	25910	Economy	12100.00
0005433985186	25910	Economy	12100.00
0005433959909	25910	Economy	12100.00
0005433959911	25910	Economy	12100.00
0005433959938	25910	Economy	12100.00
0005433959952	25910	Economy	12100.00
0005433985200	25910	Economy	12100.00
0005433959959	25910	Economy	12100.00
0005433959937	25910	Economy	12100.00
0005433959956	25910	Economy	12100.00
0005433959954	25910	Economy	12100.00
0005433985191	25910	Economy	12100.00
0005433985176	25910	Economy	12100.00
0005433959933	25910	Economy	12100.00
0005433959947	25910	Economy	12100.00
0005433959961	25910	Economy	12100.00
0005434479942	941	Economy	25400.00
0005434479937	941	Economy	25400.00
0005434479948	941	Economy	25400.00
0005434479936	941	Economy	23100.00
0005434479938	941	Economy	23100.00
0005434479934	941	Economy	23100.00
0005434479926	941	Economy	23100.00
0005432269452	941	Economy	23100.00
0005434479931	941	Economy	23100.00
0005434479946	941	Economy	23100.00
0005432269451	941	Economy	23100.00
0005432269454	941	Economy	23100.00
0005434479949	941	Economy	23100.00
0005434479945	941	Economy	23100.00
0005434479935	941	Economy	23100.00
0005434479939	941	Economy	23100.00
0005434479928	941	Economy	23100.00
0005434479944	941	Economy	23100.00
0005434479932	941	Economy	23100.00
0005434479951	941	Economy	23100.00
0005434479943	941	Economy	23100.00
0005432269453	941	Economy	23100.00
0005434479947	941	Economy	23100.00
0005434479929	941	Economy	23100.00
0005434479930	941	Economy	23100.00
0005434479933	941	Economy	23100.00
0005434479950	941	Economy	23100.00
0005434479927	941	Economy	23100.00
0005434479940	941	Economy	23100.00
0005434479941	941	Economy	23100.00
0005433165701	16576	Economy	25400.00
0005433165702	16576	Economy	23100.00
0005433165696	16576	Economy	23100.00
0005433165697	16576	Economy	23100.00
0005433165703	16576	Economy	23100.00
0005433165705	16576	Economy	23100.00
0005433165708	16576	Economy	23100.00
0005433165695	16576	Economy	23100.00
0005433165698	16576	Economy	23100.00
0005433165706	16576	Economy	23100.00
0005433165700	16576	Economy	23100.00
0005433165704	16576	Economy	23100.00
0005433165699	16576	Economy	23100.00
0005433165707	16576	Economy	23100.00
0005433872432	3213	Economy	19000.00
0005433872435	3213	Economy	17200.00
0005433872430	3213	Economy	17200.00
0005433872434	3213	Economy	17200.00
0005433872431	3213	Economy	17200.00
0005433872429	3213	Economy	17200.00
0005433872433	3213	Economy	17200.00
0005435149801	10349	Economy	17000.00
0005435149806	10349	Economy	17000.00
0005435142361	10349	Economy	15400.00
0005435142357	10349	Economy	15400.00
0005435149800	10349	Economy	15400.00
0005435142360	10349	Economy	15400.00
0005435142350	10349	Economy	15400.00
0005435149812	10349	Economy	15400.00
0005435149807	10349	Economy	15400.00
0005435142356	10349	Economy	15400.00
0005435142354	10349	Economy	15400.00
0005435142352	10349	Economy	15400.00
0005435142359	10349	Economy	15400.00
0005435142355	10349	Economy	15400.00
0005435149810	10349	Economy	15400.00
0005435149803	10349	Economy	15400.00
0005435142362	10349	Economy	15400.00
0005435149808	10349	Economy	15400.00
0005435142351	10349	Economy	15400.00
0005435149798	10349	Economy	15400.00
0005435149799	10349	Economy	15400.00
0005435149809	10349	Economy	15400.00
0005435142349	10349	Economy	15400.00
0005435149804	10349	Economy	15400.00
0005435142358	10349	Economy	15400.00
0005435149811	10349	Economy	15400.00
0005435142353	10349	Economy	15400.00
0005435149805	10349	Economy	15400.00
0005435149802	10349	Economy	15400.00
0005433289745	21947	Economy	17000.00
0005435386472	21947	Economy	15400.00
0005435386466	21947	Economy	15400.00
0005433289743	21947	Economy	15400.00
0005433289744	21947	Economy	15400.00
0005433289740	21947	Economy	15400.00
0005433289741	21947	Economy	15400.00
0005435386471	21947	Economy	15400.00
0005435386467	21947	Economy	15400.00
0005435386469	21947	Economy	15400.00
0005435386468	21947	Economy	15400.00
0005433289742	21947	Economy	15400.00
0005433289739	21947	Economy	15400.00
0005435386465	21947	Economy	15400.00
0005435386470	21947	Economy	15400.00
0005434573128	11214	Business	57200.00
0005434573121	11214	Business	57200.00
0005434573129	11214	Economy	19100.00
0005434573117	11214	Economy	19100.00
0005434573125	11214	Economy	19100.00
0005434573127	11214	Economy	19100.00
0005434573126	11214	Economy	19100.00
0005434573116	11214	Economy	19100.00
0005434573122	11214	Economy	19100.00
0005434573118	11214	Economy	19100.00
0005434573124	11214	Economy	19100.00
0005434573119	11214	Economy	19100.00
0005434573120	11214	Economy	19100.00
0005434573123	11214	Economy	19100.00
0005432291891	20939	Business	57200.00
0005435501958	20939	Business	57200.00
0005435517625	20939	Business	57200.00
0005435319446	20939	Business	57200.00
0005435501966	20939	Business	57200.00
0005435501955	20939	Business	57200.00
0005435517612	20939	Business	57200.00
0005435319441	20939	Business	57200.00
0005435517608	20939	Business	57200.00
0005435517622	20939	Economy	19100.00
0005435501957	20939	Economy	19100.00
0005435501964	20939	Economy	19100.00
0005435319444	20939	Economy	19100.00
0005435501968	20939	Economy	19100.00
0005435517624	20939	Economy	19100.00
0005435517611	20939	Economy	19100.00
0005435501974	20939	Economy	21000.00
0005435517617	20939	Economy	21000.00
0005435319449	20939	Economy	21000.00
0005435517618	20939	Economy	21000.00
0005435501962	20939	Economy	19100.00
0005435501973	20939	Economy	19100.00
0005435501963	20939	Economy	19100.00
0005435508178	20939	Economy	19100.00
0005435517615	20939	Economy	19100.00
0005435508177	20939	Economy	19100.00
0005435501972	20939	Economy	19100.00
0005435319448	20939	Economy	19100.00
0005435501970	20939	Economy	19100.00
0005432291892	20939	Economy	19100.00
0005435517616	20939	Economy	19100.00
0005435501969	20939	Economy	19100.00
0005435319445	20939	Economy	19100.00
0005435501961	20939	Economy	19100.00
0005435517619	20939	Economy	19100.00
0005435508182	20939	Economy	19100.00
0005435508183	20939	Economy	19100.00
0005435517610	20939	Economy	19100.00
0005435517626	20939	Economy	19100.00
0005435508180	20939	Economy	19100.00
0005435508181	20939	Economy	19100.00
0005435517627	20939	Economy	19100.00
0005435319447	20939	Economy	19100.00
0005435508184	20939	Economy	19100.00
0005435501953	20939	Economy	19100.00
0005435501971	20939	Economy	19100.00
0005435508179	20939	Economy	19100.00
0005435501956	20939	Economy	19100.00
0005435501960	20939	Economy	19100.00
0005435501967	20939	Economy	19100.00
0005435501959	20939	Economy	19100.00
0005435501965	20939	Economy	19100.00
0005435517614	20939	Economy	19100.00
0005435517609	20939	Economy	19100.00
0005435319443	20939	Economy	19100.00
0005435517621	20939	Economy	19100.00
0005435319442	20939	Economy	19100.00
0005435517607	20939	Economy	19100.00
0005435517620	20939	Economy	19100.00
0005435517623	20939	Economy	19100.00
0005435501954	20939	Economy	19100.00
0005435517628	20939	Economy	19100.00
0005435517613	20939	Economy	19100.00
0005432706385	2968	Business	10300.00
0005432706370	2968	Business	10300.00
0005432706383	2968	Business	10300.00
0005432706364	2968	Business	10300.00
0005432706381	2968	Business	10300.00
0005432706369	2968	Economy	3400.00
0005432706377	2968	Economy	3400.00
0005432706380	2968	Economy	3400.00
0005432706367	2968	Economy	3400.00
0005432706373	2968	Economy	3800.00
0005432706360	2968	Economy	3800.00
0005432706368	2968	Economy	3400.00
0005432706372	2968	Economy	3400.00
0005432706362	2968	Economy	3400.00
0005432706366	2968	Economy	3400.00
0005432217731	2968	Economy	3400.00
0005432706363	2968	Economy	3400.00
0005432706365	2968	Economy	3400.00
0005432706378	2968	Economy	3400.00
0005432706379	2968	Economy	3400.00
0005432706374	2968	Economy	3400.00
0005432706361	2968	Economy	3400.00
0005432706375	2968	Economy	3400.00
0005432217732	2968	Economy	3400.00
0005432706382	2968	Economy	3400.00
0005432706376	2968	Economy	3400.00
0005432706384	2968	Economy	3400.00
0005432706371	2968	Economy	3400.00
0005432692604	30081	Business	10300.00
0005432692613	30081	Business	10300.00
0005432880581	30081	Business	10300.00
0005432692607	30081	Business	10300.00
0005432692614	30081	Business	10300.00
0005432692621	30081	Business	10300.00
0005432880591	30081	Business	10300.00
0005433123588	30081	Business	10300.00
0005432880593	30081	Business	10300.00
0005432692612	30081	Business	10300.00
0005432692608	30081	Economy	3400.00
0005433123593	30081	Economy	3400.00
0005432880584	30081	Economy	3400.00
0005432692598	30081	Economy	3400.00
0005433123598	30081	Economy	3400.00
0005432692597	30081	Economy	3400.00
0005432692616	30081	Economy	3400.00
0005432692609	30081	Economy	3800.00
0005433123599	30081	Economy	3800.00
0005432880594	30081	Economy	3800.00
0005433123597	30081	Economy	3800.00
0005432880582	30081	Economy	3400.00
0005433123603	30081	Economy	3400.00
0005433123606	30081	Economy	3400.00
0005433123604	30081	Economy	3400.00
0005432692602	30081	Economy	3400.00
0005433123591	30081	Economy	3400.00
0005433123596	30081	Economy	3400.00
0005432692615	30081	Economy	3400.00
0005432880586	30081	Economy	3400.00
0005432692596	30081	Economy	3400.00
0005432706344	30081	Economy	3400.00
0005432692617	30081	Economy	3400.00
0005432692620	30081	Economy	3400.00
0005432880587	30081	Economy	3400.00
0005433194820	30081	Economy	3400.00
0005432692601	30081	Economy	3400.00
0005433123592	30081	Economy	3400.00
0005433123594	30081	Economy	3400.00
0005432692593	30081	Economy	3400.00
0005433194823	30081	Economy	3400.00
0005432692591	30081	Economy	3400.00
0005433123605	30081	Economy	3400.00
0005433123602	30081	Economy	3400.00
0005432692590	30081	Economy	3400.00
0005433123590	30081	Economy	3400.00
0005432692605	30081	Economy	3400.00
0005432880589	30081	Economy	3400.00
0005432692595	30081	Economy	3400.00
0005432880595	30081	Economy	3400.00
0005432692606	30081	Economy	3400.00
0005432692618	30081	Economy	3400.00
0005432880583	30081	Economy	3400.00
0005432692592	30081	Economy	3400.00
0005433123589	30081	Economy	3400.00
0005433123608	30081	Economy	3400.00
0005432880592	30081	Economy	3400.00
0005432692600	30081	Economy	3400.00
0005432692603	30081	Economy	3400.00
0005433194821	30081	Economy	3400.00
0005432692619	30081	Economy	3400.00
0005433123595	30081	Economy	3400.00
0005433194822	30081	Economy	3400.00
0005432880588	30081	Economy	3400.00
0005432692594	30081	Economy	3400.00
0005433123609	30081	Economy	3400.00
0005433123600	30081	Economy	3400.00
0005433123601	30081	Economy	3400.00
0005433123607	30081	Economy	3400.00
0005432692599	30081	Economy	3400.00
0005432880585	30081	Economy	3400.00
0005432880590	30081	Economy	3400.00
0005432692611	30081	Economy	3400.00
0005432692610	30081	Economy	3400.00
0005433123610	30081	Economy	3400.00
0005434979296	23647	Economy	4000.00
0005434979283	23647	Economy	4000.00
0005434979292	23647	Economy	3600.00
0005434979290	23647	Economy	3600.00
0005434979308	23647	Economy	3600.00
0005434988565	23647	Economy	3600.00
0005434979313	23647	Economy	3600.00
0005434979297	23647	Economy	3600.00
0005434979312	23647	Economy	3600.00
0005434979299	23647	Economy	3600.00
0005434979311	23647	Economy	3600.00
0005434979310	23647	Economy	3600.00
0005434979284	23647	Economy	3600.00
0005434979295	23647	Economy	3600.00
0005434979303	23647	Economy	3600.00
0005434988567	23647	Economy	3600.00
0005434979286	23647	Economy	3600.00
0005434979288	23647	Economy	3600.00
0005434979309	23647	Economy	3600.00
0005434979285	23647	Economy	3600.00
0005434988566	23647	Economy	3600.00
0005434988568	23647	Economy	3600.00
0005434979287	23647	Economy	3600.00
0005434979294	23647	Economy	3600.00
0005434979304	23647	Economy	3600.00
0005434988570	23647	Economy	3600.00
0005434979305	23647	Economy	3600.00
0005434979289	23647	Economy	3600.00
0005434979307	23647	Economy	3600.00
0005434979301	23647	Economy	3600.00
0005434979291	23647	Economy	3600.00
0005434979306	23647	Economy	3600.00
0005434979298	23647	Economy	3600.00
0005434979293	23647	Economy	3600.00
0005434988569	23647	Economy	3600.00
0005434979300	23647	Economy	3600.00
0005434979302	23647	Economy	3600.00
0005434302388	10280	Economy	19700.00
0005434302387	10280	Economy	19700.00
0005434302390	10280	Economy	19700.00
0005434302386	10280	Economy	19700.00
0005434302389	10280	Economy	19700.00
0005433113500	19598	Economy	19700.00
0005433113501	19598	Economy	19700.00
0005435068273	3523	Business	26900.00
0005435068294	3523	Business	26900.00
0005435068309	3523	Business	26900.00
0005435068306	3523	Business	26900.00
0005435068311	3523	Business	26900.00
0005435068299	3523	Business	26900.00
0005435068275	3523	Economy	9000.00
0005435068285	3523	Economy	9000.00
0005435068292	3523	Economy	9000.00
0005435068282	3523	Economy	9000.00
0005435068288	3523	Economy	9000.00
0005435068307	3523	Economy	9000.00
0005435068297	3523	Economy	9000.00
0005435068277	3523	Economy	9000.00
0005435068316	3523	Economy	9900.00
0005435068286	3523	Economy	9900.00
0005435718842	3523	Economy	9000.00
0005435718838	3523	Economy	9000.00
0005435068312	3523	Economy	9000.00
0005435068315	3523	Economy	9000.00
0005435068317	3523	Economy	9000.00
0005435068308	3523	Economy	9000.00
0005435068313	3523	Economy	9000.00
0005435068272	3523	Economy	9000.00
0005435068265	3523	Economy	9000.00
0005435068267	3523	Economy	9000.00
0005435068290	3523	Economy	9000.00
0005435068314	3523	Economy	9000.00
0005435068264	3523	Economy	9000.00
0005435068291	3523	Economy	9000.00
0005435068301	3523	Economy	9000.00
0005435068271	3523	Economy	9000.00
0005435718839	3523	Economy	9000.00
0005435068298	3523	Economy	9000.00
0005435068304	3523	Economy	9000.00
0005435718844	3523	Economy	9000.00
0005435068302	3523	Economy	9000.00
0005435068280	3523	Economy	9000.00
0005435068279	3523	Economy	9000.00
0005435718847	3523	Economy	9000.00
0005435718845	3523	Economy	9000.00
0005435068287	3523	Economy	9000.00
0005435718843	3523	Economy	9000.00
0005435068276	3523	Economy	9000.00
0005435068274	3523	Economy	9000.00
0005435068268	3523	Economy	9000.00
0005435068270	3523	Economy	9000.00
0005435068296	3523	Economy	9000.00
0005435718841	3523	Economy	9000.00
0005435068305	3523	Economy	9000.00
0005435068293	3523	Economy	9000.00
0005435068283	3523	Economy	9000.00
0005435068281	3523	Economy	9000.00
0005435068278	3523	Economy	9000.00
0005435068269	3523	Economy	9000.00
0005435068300	3523	Economy	9000.00
0005435068284	3523	Economy	9000.00
0005435068289	3523	Economy	9000.00
0005435718840	3523	Economy	9000.00
0005435068295	3523	Economy	9000.00
0005435068303	3523	Economy	9000.00
0005435718846	3523	Economy	9000.00
0005435068266	3523	Economy	9000.00
0005435068310	3523	Economy	9000.00
0005435925089	15298	Business	26900.00
0005435925079	15298	Business	26900.00
0005435925081	15298	Business	26900.00
0005435925090	15298	Business	26900.00
0005435925085	15298	Economy	9000.00
0005435925080	15298	Economy	9000.00
0005435925086	15298	Economy	9900.00
0005435925082	15298	Economy	9000.00
0005435925095	15298	Economy	9000.00
0005435939861	15298	Economy	9000.00
0005435925088	15298	Economy	9000.00
0005435939860	15298	Economy	9000.00
0005435939859	15298	Economy	9000.00
0005435925094	15298	Economy	9000.00
0005435925078	15298	Economy	9000.00
0005435925093	15298	Economy	9000.00
0005435925083	15298	Economy	9000.00
0005435925092	15298	Economy	9000.00
0005435925084	15298	Economy	9000.00
0005435925091	15298	Economy	9000.00
0005435925087	15298	Economy	9000.00
0005432660784	18167	Economy	5900.00
0005432658558	18167	Economy	5900.00
0005432660787	18167	Economy	5900.00
0005432660785	18167	Economy	5900.00
0005432659673	18167	Economy	5900.00
0005432658559	18167	Economy	5900.00
0005432659674	18167	Economy	5900.00
0005432660786	18167	Economy	5900.00
0005432157461	55	Economy	6700.00
0005432157463	55	Economy	6700.00
0005432157462	55	Economy	6700.00
0005432261189	54	Business	20000.00
0005432817007	54	Business	20000.00
0005432261208	54	Business	20000.00
0005432817010	54	Business	20000.00
0005432261219	54	Business	20000.00
0005432261185	54	Business	20000.00
0005432207621	54	Business	20000.00
0005432817008	54	Business	20000.00
0005432261217	54	Business	20000.00
0005432817017	54	Business	20000.00
0005432261193	54	Economy	7300.00
0005432261206	54	Economy	7300.00
0005432817020	54	Economy	7300.00
0005432817022	54	Economy	7300.00
0005432817027	54	Economy	6700.00
0005432261184	54	Economy	6700.00
0005432261209	54	Economy	6700.00
0005432261197	54	Economy	6700.00
0005432261204	54	Economy	6700.00
0005432817000	54	Economy	6700.00
0005432817014	54	Economy	6700.00
0005432261226	54	Economy	6700.00
0005432261214	54	Economy	6700.00
0005432817005	54	Economy	6700.00
0005432817016	54	Economy	6700.00
0005432261200	54	Economy	6700.00
0005432261188	54	Economy	6700.00
0005432261225	54	Economy	6700.00
0005432261205	54	Economy	6700.00
0005432261216	54	Economy	6700.00
0005432261203	54	Economy	6700.00
0005432817021	54	Economy	6700.00
0005432261194	54	Economy	6700.00
0005432261207	54	Economy	6700.00
0005432817018	54	Economy	6700.00
0005432261202	54	Economy	6700.00
0005432817012	54	Economy	6700.00
0005432207620	54	Economy	6700.00
0005432817013	54	Economy	6700.00
0005432817024	54	Economy	6700.00
0005432261223	54	Economy	6700.00
0005432261192	54	Economy	6700.00
0005432261221	54	Economy	6700.00
0005432261213	54	Economy	6700.00
0005432817011	54	Economy	6700.00
0005432261198	54	Economy	6700.00
0005432261183	54	Economy	6700.00
0005432817015	54	Economy	7300.00
0005432817001	54	Economy	6700.00
0005432817025	54	Economy	6700.00
0005432207619	54	Economy	6700.00
0005432261201	54	Economy	6700.00
0005432261220	54	Economy	6700.00
0005432816999	54	Economy	6700.00
0005432261186	54	Economy	6700.00
0005432817009	54	Economy	6700.00
0005432288934	54	Economy	6700.00
0005432261212	54	Economy	6700.00
0005432261190	54	Economy	6700.00
0005432288935	54	Economy	6700.00
0005432261182	54	Economy	6700.00
0005432817019	54	Economy	6700.00
0005432817002	54	Economy	6700.00
0005432261187	54	Economy	6700.00
0005432261211	54	Economy	6700.00
0005432817006	54	Economy	6700.00
0005432261191	54	Economy	6700.00
0005432816998	54	Economy	6700.00
0005432261196	54	Economy	6700.00
0005432261227	54	Economy	6700.00
0005432261215	54	Economy	6700.00
0005432261199	54	Economy	6700.00
0005432261222	54	Economy	6700.00
0005432261218	54	Economy	6700.00
0005432817026	54	Economy	6700.00
0005432817003	54	Economy	6700.00
0005432817004	54	Economy	6700.00
0005432288936	54	Economy	6700.00
0005432817023	54	Economy	6700.00
0005432261195	54	Economy	6700.00
0005432261181	54	Economy	6700.00
0005432261210	54	Economy	6700.00
0005432261224	54	Economy	6700.00
0005433101340	7988	Business	20000.00
0005432391952	7988	Business	20000.00
0005433101302	7988	Business	20000.00
0005433101295	7988	Business	20000.00
0005432919536	7988	Business	20000.00
0005433101316	7988	Business	20000.00
0005433101328	7988	Business	20000.00
0005432019858	7988	Business	20000.00
0005432919545	7988	Business	20000.00
0005433101293	7988	Business	20000.00
0005433101345	7988	Business	20000.00
0005432019842	7988	Business	20000.00
0005432019835	7988	Business	20000.00
0005432019844	7988	Business	20000.00
0005432019839	7988	Business	20000.00
0005433101341	7988	Business	20000.00
0005433101317	7988	Business	20000.00
0005433101298	7988	Business	20000.00
0005432019840	7988	Business	20000.00
0005432019846	7988	Economy	7300.00
0005433101336	7988	Economy	7300.00
0005432019852	7988	Economy	7300.00
0005432753251	7988	Economy	6700.00
0005432019834	7988	Economy	6700.00
0005433101327	7988	Economy	6700.00
0005432019855	7988	Economy	6700.00
0005433101306	7988	Economy	6700.00
0005432019847	7988	Economy	6700.00
0005432753250	7988	Economy	6700.00
0005432019850	7988	Economy	6700.00
0005433101326	7988	Economy	6700.00
0005432919538	7988	Economy	6700.00
0005433101323	7988	Economy	6700.00
0005433101303	7988	Economy	6700.00
0005433101335	7988	Economy	6700.00
0005432919535	7988	Economy	6700.00
0005433101301	7988	Economy	6700.00
0005433101333	7988	Economy	6700.00
0005432019849	7988	Economy	6700.00
0005433101325	7988	Economy	6700.00
0005432753249	7988	Economy	6700.00
0005433101299	7988	Economy	6700.00
0005432019845	7988	Economy	6700.00
0005433101300	7988	Economy	6700.00
0005433101292	7988	Economy	6700.00
0005432919543	7988	Economy	6700.00
0005433101343	7988	Economy	6700.00
0005432019848	7988	Economy	6700.00
0005432019833	7988	Economy	6700.00
0005432019856	7988	Economy	6700.00
0005432919527	7988	Economy	6700.00
0005433101337	7988	Economy	6700.00
0005432919528	7988	Economy	6700.00
0005432677511	7988	Economy	6700.00
0005433101339	7988	Economy	6700.00
0005433101321	7988	Economy	6700.00
0005433101310	7988	Economy	6700.00
0005432019836	7988	Economy	6700.00
0005432019843	7988	Economy	6700.00
0005433101322	7988	Economy	6700.00
0005433101319	7988	Economy	6700.00
0005432919534	7988	Economy	6700.00
0005433101330	7988	Economy	6700.00
0005433101318	7988	Economy	6700.00
0005432677514	7988	Economy	6700.00
0005432919542	7988	Economy	6700.00
0005432919541	7988	Economy	7300.00
0005433101304	7988	Economy	7300.00
0005432919533	7988	Economy	7300.00
0005432751474	7988	Economy	7300.00
0005433101338	7988	Economy	6700.00
0005433101344	7988	Economy	6700.00
0005432019838	7988	Economy	6700.00
0005433101297	7988	Economy	6700.00
0005433101294	7988	Economy	6700.00
0005432919531	7988	Economy	6700.00
0005433101320	7988	Economy	6700.00
0005432044481	7988	Economy	6700.00
0005433101291	7988	Economy	6700.00
0005433101329	7988	Economy	6700.00
0005432391953	7988	Economy	6700.00
0005433101331	7988	Economy	6700.00
0005432919544	7988	Economy	6700.00
0005432919537	7988	Economy	6700.00
0005432753248	7988	Economy	6700.00
0005433101315	7988	Economy	6700.00
0005433101324	7988	Economy	6700.00
0005432677513	7988	Economy	6700.00
0005432019859	7988	Economy	6700.00
0005433101296	7988	Economy	6700.00
0005433101334	7988	Economy	6700.00
0005432919526	7988	Economy	6700.00
0005432677512	7988	Economy	6700.00
0005433101311	7988	Economy	6700.00
0005433101332	7988	Economy	6700.00
0005432919532	7988	Economy	6700.00
0005432751475	7988	Economy	6700.00
0005433101312	7988	Economy	6700.00
0005432919539	7988	Economy	6700.00
0005433101305	7988	Economy	6700.00
0005432751476	7988	Economy	6700.00
0005432044482	7988	Economy	6700.00
0005432019854	7988	Economy	6700.00
0005433101307	7988	Economy	6700.00
0005432919530	7988	Economy	6700.00
0005432019857	7988	Economy	6700.00
0005432919540	7988	Economy	6700.00
0005433101313	7988	Economy	6700.00
0005432019853	7988	Economy	6700.00
0005432919525	7988	Economy	6700.00
0005433101342	7988	Economy	6700.00
0005432391954	7988	Economy	6700.00
0005432019841	7988	Economy	6700.00
0005433101314	7988	Economy	6700.00
0005432919529	7988	Economy	6700.00
0005432045584	7988	Economy	6700.00
0005433101309	7988	Economy	6700.00
0005433101308	7988	Economy	6700.00
0005432019851	7988	Economy	6700.00
0005432019837	7988	Economy	6700.00
0005432901330	7989	Business	20000.00
0005432901336	7989	Business	20000.00
0005432901342	7989	Economy	7300.00
0005432901340	7989	Economy	7300.00
0005432901343	7989	Economy	7300.00
0005432002045	7989	Economy	6700.00
0005432901339	7989	Economy	6700.00
0005432901333	7989	Economy	6700.00
0005432901329	7989	Economy	6700.00
0005432901332	7989	Economy	6700.00
0005432901338	7989	Economy	6700.00
0005432901344	7989	Economy	6700.00
0005432901331	7989	Economy	6700.00
0005432901341	7989	Economy	6700.00
0005432901345	7989	Economy	6700.00
0005432901337	7989	Economy	6700.00
0005432901335	7989	Economy	6700.00
0005432002044	7989	Economy	6700.00
0005432901346	7989	Economy	6700.00
0005432901334	7989	Economy	6700.00
0005433870698	9656	Economy	6900.00
0005433870696	9656	Economy	6900.00
0005433870697	9656	Economy	6900.00
0005434175690	32343	Economy	6900.00
0005434175688	32343	Economy	6900.00
0005434175687	32343	Economy	6900.00
0005434175689	32343	Economy	6900.00
0005434426152	3512	Business	35000.00
0005434876819	3512	Business	35000.00
0005434876775	3512	Business	35000.00
0005434426169	3512	Business	35000.00
0005432799016	3512	Business	35000.00
0005434426162	3512	Business	35000.00
0005435625911	3512	Business	35000.00
0005435125733	3512	Business	35000.00
0005432799036	3512	Business	35000.00
0005434876776	3512	Business	35000.00
0005435125739	3512	Business	35000.00
0005432799024	3512	Business	35000.00
0005435125766	3512	Business	35000.00
0005434426172	3512	Business	35000.00
0005434876785	3512	Business	35000.00
0005434937835	3512	Comfort	19900.00
0005434426156	3512	Comfort	19900.00
0005434876780	3512	Comfort	19900.00
0005434876760	3512	Comfort	19900.00
0005434876808	3512	Comfort	19900.00
0005434876834	3512	Comfort	19900.00
0005434426157	3512	Comfort	19900.00
0005434937847	3512	Comfort	19900.00
0005434876809	3512	Comfort	19900.00
0005432613800	3512	Comfort	19900.00
0005434937851	3512	Comfort	19900.00
0005434876797	3512	Comfort	19900.00
0005432799018	3512	Comfort	19900.00
0005434876778	3512	Comfort	19900.00
0005434876822	3512	Comfort	19900.00
0005434876829	3512	Comfort	19900.00
0005434876801	3512	Comfort	19900.00
0005434876828	3512	Comfort	19900.00
0005434876799	3512	Comfort	19900.00
0005432611649	3512	Comfort	19900.00
0005434426146	3512	Comfort	19900.00
0005434876761	3512	Comfort	19900.00
0005434876831	3512	Comfort	19900.00
0005434876750	3512	Comfort	19900.00
0005434876759	3512	Comfort	19900.00
0005435125731	3512	Comfort	19900.00
0005434876754	3512	Comfort	19900.00
0005432799017	3512	Comfort	19900.00
0005432799022	3512	Comfort	19900.00
0005432183435	3512	Comfort	19900.00
0005434876764	3512	Comfort	19900.00
0005432188560	3512	Comfort	19900.00
0005432799031	3512	Economy	11700.00
0005434876820	3512	Economy	11700.00
0005434876786	3512	Economy	11700.00
0005432799028	3512	Economy	11700.00
0005434876752	3512	Economy	11700.00
0005434876836	3512	Economy	11700.00
0005435125751	3512	Economy	11700.00
0005434876788	3512	Economy	11700.00
0005434937844	3512	Economy	11700.00
0005434876832	3512	Economy	11700.00
0005434426155	3512	Economy	11700.00
0005435125730	3512	Economy	11700.00
0005434876777	3512	Economy	11700.00
0005432799023	3512	Economy	11700.00
0005435125764	3512	Economy	11700.00
0005434426171	3512	Economy	11700.00
0005435125736	3512	Economy	11700.00
0005434876804	3512	Economy	11700.00
0005434426165	3512	Economy	11700.00
0005434876802	3512	Economy	11700.00
0005435625909	3512	Economy	11700.00
0005435125757	3512	Economy	11700.00
0005435625910	3512	Economy	11700.00
0005432799034	3512	Economy	11700.00
0005434876782	3512	Economy	11700.00
0005432183433	3512	Economy	11700.00
0005434426167	3512	Economy	11700.00
0005434426161	3512	Economy	11700.00
0005435625902	3512	Economy	11700.00
0005434876755	3512	Economy	11700.00
0005434876846	3512	Economy	11700.00
0005432799030	3512	Economy	11700.00
0005432188559	3512	Economy	11700.00
0005432799039	3512	Economy	11700.00
0005432611647	3512	Economy	11700.00
0005434876805	3512	Economy	11700.00
0005432799019	3512	Economy	11700.00
0005434876787	3512	Economy	11700.00
0005434426147	3512	Economy	11700.00
0005434876781	3512	Economy	11700.00
0005432799011	3512	Economy	11700.00
0005434426148	3512	Economy	11700.00
0005435625912	3512	Economy	11700.00
0005434426170	3512	Economy	12800.00
0005435125768	3512	Economy	11700.00
0005434426166	3512	Economy	12800.00
0005434876806	3512	Economy	12800.00
0005435125732	3512	Economy	11700.00
0005434876763	3512	Economy	11700.00
0005432799037	3512	Economy	11700.00
0005435625901	3512	Economy	11700.00
0005432188557	3512	Economy	11700.00
0005434876774	3512	Economy	11700.00
0005435125760	3512	Economy	11700.00
0005434876792	3512	Economy	11700.00
0005432183434	3512	Economy	11700.00
0005434876758	3512	Economy	11700.00
0005434876771	3512	Economy	11700.00
0005432799020	3512	Economy	11700.00
0005434426153	3512	Economy	11700.00
0005435125737	3512	Economy	11700.00
0005435125742	3512	Economy	11700.00
0005435625900	3512	Economy	11700.00
0005434876751	3512	Economy	11700.00
0005435125752	3512	Economy	11700.00
0005432613797	3512	Economy	11700.00
0005434876770	3512	Economy	11700.00
0005435125767	3512	Economy	11700.00
0005434937840	3512	Economy	11700.00
0005434876837	3512	Economy	11700.00
0005435625905	3512	Economy	11700.00
0005435125734	3512	Economy	11700.00
0005432611648	3512	Economy	11700.00
0005432188558	3512	Economy	11700.00
0005432799015	3512	Economy	11700.00
0005432799021	3512	Economy	11700.00
0005434876793	3512	Economy	11700.00
0005434426159	3512	Economy	11700.00
0005432799013	3512	Economy	11700.00
0005435125753	3512	Economy	11700.00
0005434876757	3512	Economy	11700.00
0005434876823	3512	Economy	11700.00
0005435625907	3512	Economy	11700.00
0005434426149	3512	Economy	11700.00
0005435125754	3512	Economy	11700.00
0005435125770	3512	Economy	11700.00
0005434876773	3512	Economy	11700.00
0005434876844	3512	Economy	11700.00
0005434876821	3512	Economy	11700.00
0005435125738	3512	Economy	11700.00
0005434426164	3512	Economy	11700.00
0005432799035	3512	Economy	11700.00
0005434876803	3512	Economy	11700.00
0005435125749	3512	Economy	11700.00
0005434876817	3512	Economy	11700.00
0005434426158	3512	Economy	11700.00
0005434937846	3512	Economy	11700.00
0005435125740	3512	Economy	11700.00
0005434876824	3512	Economy	11700.00
0005434876825	3512	Economy	11700.00
0005434876810	3512	Economy	11700.00
0005434876766	3512	Economy	11700.00
0005432799025	3512	Economy	11700.00
0005434937839	3512	Economy	11700.00
0005434426151	3512	Economy	11700.00
0005432799027	3512	Economy	11700.00
0005434876753	3512	Economy	11700.00
0005435125759	3512	Economy	11700.00
0005434876768	3512	Economy	11700.00
0005434876800	3512	Economy	11700.00
0005432799014	3512	Economy	11700.00
0005432799033	3512	Economy	11700.00
0005435625906	3512	Economy	11700.00
0005434876827	3512	Economy	11700.00
0005434876769	3512	Economy	12800.00
0005434426160	3512	Economy	11700.00
0005434426150	3512	Economy	12800.00
0005435125765	3512	Economy	12800.00
0005432613798	3512	Economy	12800.00
0005435125741	3512	Economy	12800.00
0005434876765	3512	Economy	11700.00
0005434876813	3512	Economy	11700.00
0005434876833	3512	Economy	11700.00
0005435625903	3512	Economy	11700.00
0005434937849	3512	Economy	11700.00
0005435125747	3512	Economy	11700.00
0005434876767	3512	Economy	11700.00
0005434937841	3512	Economy	11700.00
0005435125769	3512	Economy	11700.00
0005434876789	3512	Economy	11700.00
0005434937842	3512	Economy	11700.00
0005434937833	3512	Economy	11700.00
0005434876784	3512	Economy	11700.00
0005434937838	3512	Economy	11700.00
0005435125748	3512	Economy	11700.00
0005432799038	3512	Economy	11700.00
0005434937834	3512	Economy	11700.00
0005435125756	3512	Economy	11700.00
0005435125758	3512	Economy	11700.00
0005434876762	3512	Economy	11700.00
0005434937850	3512	Economy	11700.00
0005434876826	3512	Economy	11700.00
0005434876796	3512	Economy	11700.00
0005434876749	3512	Economy	11700.00
0005435125744	3512	Economy	11700.00
0005435125755	3512	Economy	11700.00
0005434876790	3512	Economy	11700.00
0005435125746	3512	Economy	11700.00
0005432611650	3512	Economy	11700.00
0005434876794	3512	Economy	11700.00
0005432799029	3512	Economy	11700.00
0005434876795	3512	Economy	11700.00
0005435125761	3512	Economy	11700.00
0005435125735	3512	Economy	11700.00
0005434876815	3512	Economy	11700.00
0005435125762	3512	Economy	11700.00
0005434876798	3512	Economy	11700.00
0005435125771	3512	Economy	11700.00
0005434876842	3512	Economy	11700.00
0005434937848	3512	Economy	11700.00
0005435625904	3512	Economy	11700.00
0005432613799	3512	Economy	11700.00
0005434876835	3512	Economy	11700.00
0005434876756	3512	Economy	11700.00
0005434426173	3512	Economy	11700.00
0005435125750	3512	Economy	11700.00
0005434937837	3512	Economy	11700.00
0005435625908	3512	Economy	11700.00
0005434937845	3512	Economy	11700.00
0005434876812	3512	Economy	11700.00
0005434876816	3512	Economy	11700.00
0005435125743	3512	Economy	11700.00
0005434876818	3512	Economy	11700.00
0005434937836	3512	Economy	11700.00
0005434876814	3512	Economy	11700.00
0005434876838	3512	Economy	11700.00
0005434876840	3512	Economy	11700.00
0005434426168	3512	Economy	11700.00
0005434876772	3512	Economy	11700.00
0005432799032	3512	Economy	11700.00
0005434426163	3512	Economy	11700.00
0005434937843	3512	Economy	11700.00
0005434876779	3512	Economy	11700.00
0005434876783	3512	Economy	11700.00
0005434876843	3512	Economy	11700.00
0005434876811	3512	Economy	11700.00
0005432799012	3512	Economy	11700.00
0005435125745	3512	Economy	11700.00
0005434876830	3512	Economy	11700.00
0005434876807	3512	Economy	11700.00
0005432183432	3512	Economy	11700.00
0005434426154	3512	Economy	11700.00
0005435125763	3512	Economy	11700.00
0005434876791	3512	Economy	11700.00
0005434876841	3512	Economy	11700.00
0005434876839	3512	Economy	11700.00
0005432799026	3512	Economy	11700.00
0005434876845	3512	Economy	11700.00
0005435902434	14543	Business	35000.00
0005435902429	14543	Comfort	19900.00
0005435902437	14543	Economy	11700.00
0005435902431	14543	Economy	11700.00
0005435902426	14543	Economy	11700.00
0005435902427	14543	Economy	11700.00
0005435902433	14543	Economy	11700.00
0005435902430	14543	Economy	11700.00
0005435902436	14543	Economy	11700.00
0005432059475	14543	Economy	11700.00
0005432059473	14543	Economy	11700.00
0005435842314	14543	Economy	11700.00
0005435902435	14543	Economy	11700.00
0005435902425	14543	Economy	11700.00
0005432059474	14543	Economy	11700.00
0005435902428	14543	Economy	11700.00
0005435902424	14543	Economy	11700.00
0005435902422	14543	Economy	11700.00
0005435841810	14543	Economy	11700.00
0005435902421	14543	Economy	11700.00
0005435902432	14543	Economy	11700.00
0005435902423	14543	Economy	11700.00
0005434325469	3589	Economy	14800.00
0005434312286	3589	Economy	14800.00
0005434312285	3589	Economy	14800.00
0005434325477	3589	Economy	14800.00
0005434325473	3589	Economy	14800.00
0005434325467	3589	Economy	14800.00
0005434325471	3589	Economy	14800.00
0005434325468	3589	Economy	14800.00
0005434325476	3589	Economy	14800.00
0005434325474	3589	Economy	14800.00
0005434325470	3589	Economy	14800.00
0005434325472	3589	Economy	14800.00
0005434325466	3589	Economy	14800.00
0005434325475	3589	Economy	14800.00
0005435889804	15604	Economy	14800.00
0005435889805	15604	Economy	14800.00
0005435889802	15604	Economy	14800.00
0005435889803	15604	Economy	14800.00
0005435889806	15604	Economy	14800.00
0005435889801	15604	Economy	14800.00
0005435957471	666	Economy	4500.00
0005435957470	666	Economy	4500.00
0005435957474	666	Economy	4100.00
0005435957483	666	Economy	4100.00
0005435957477	666	Economy	4100.00
0005435957476	666	Economy	4100.00
0005435957473	666	Economy	4100.00
0005435957472	666	Economy	4100.00
0005435957469	666	Economy	4100.00
0005435957480	666	Economy	4100.00
0005435957475	666	Economy	4100.00
0005435957482	666	Economy	4100.00
0005435957481	666	Economy	4100.00
0005435957478	666	Economy	4100.00
0005435957479	666	Economy	4100.00
0005433420270	15173	Economy	4500.00
0005433420268	15173	Economy	4500.00
0005433420274	15173	Economy	4100.00
0005433420267	15173	Economy	4100.00
0005433420273	15173	Economy	4100.00
0005433420272	15173	Economy	4100.00
0005433420269	15173	Economy	4100.00
0005433420266	15173	Economy	4100.00
0005433420271	15173	Economy	4100.00
0005433420275	15173	Economy	4100.00
0005435629386	8905	Economy	10400.00
0005435629387	8905	Economy	10400.00
0005435629385	8905	Economy	10400.00
0005434247110	16087	Economy	10400.00
0005434247106	16087	Economy	10400.00
0005434247108	16087	Economy	10400.00
0005434247109	16087	Economy	10400.00
0005434247107	16087	Economy	10400.00
0005434247105	16087	Economy	10400.00
0005435163148	4446	Economy	13400.00
0005435163145	4446	Economy	12200.00
0005435163147	4446	Economy	12200.00
0005435163149	4446	Economy	12200.00
0005435163154	4446	Economy	12200.00
0005435163151	4446	Economy	12200.00
0005435163150	4446	Economy	12200.00
0005435163146	4446	Economy	12200.00
0005435163153	4446	Economy	12200.00
0005435163152	4446	Economy	12200.00
0005435163155	4446	Economy	12200.00
0005435933396	29518	Economy	13400.00
0005435933403	29518	Economy	12200.00
0005435933400	29518	Economy	12200.00
0005435933402	29518	Economy	12200.00
0005435933397	29518	Economy	12200.00
0005435933399	29518	Economy	12200.00
0005435933398	29518	Economy	12200.00
0005435933401	29518	Economy	12200.00
0005435797262	2862	Business	12600.00
0005435797257	2862	Business	12600.00
0005435797252	2862	Economy	4200.00
0005435797263	2862	Economy	4200.00
0005435797261	2862	Economy	4200.00
0005435797260	2862	Economy	4200.00
0005435797256	2862	Economy	4200.00
0005435797253	2862	Economy	4200.00
0005435797255	2862	Economy	4200.00
0005435797254	2862	Economy	4200.00
0005435797259	2862	Economy	4200.00
0005435797258	2862	Economy	4200.00
0005435797264	2862	Economy	4200.00
0005433404691	29310	Business	12600.00
0005433404695	29310	Economy	4200.00
0005433404698	29310	Economy	4200.00
0005433404692	29310	Economy	4200.00
0005433404697	29310	Economy	4200.00
0005433404696	29310	Economy	4200.00
0005433404693	29310	Economy	4200.00
0005433404694	29310	Economy	4200.00
0005434947888	5762	Economy	6800.00
0005434947892	5762	Economy	6800.00
0005434947885	5762	Economy	6800.00
0005434947890	5762	Economy	6800.00
0005434947887	5762	Economy	6800.00
0005434947893	5762	Economy	6800.00
0005434947891	5762	Economy	6800.00
0005434947889	5762	Economy	6800.00
0005434947886	5762	Economy	6800.00
0005435376316	16423	Economy	6800.00
0005435376315	16423	Economy	6800.00
0005435376317	16423	Economy	6800.00
0005433960020	6919	Business	21400.00
0005433959993	6919	Business	21400.00
0005433959970	6919	Business	21400.00
0005433959981	6919	Business	21400.00
0005433959992	6919	Business	21400.00
0005433960017	6919	Business	21400.00
0005433960003	6919	Business	21400.00
0005433960001	6919	Business	21400.00
0005433960024	6919	Business	21400.00
0005433959978	6919	Business	21400.00
0005433959998	6919	Economy	7100.00
0005433959994	6919	Economy	7100.00
0005433959972	6919	Economy	7100.00
0005433959973	6919	Economy	7100.00
0005433960022	6919	Economy	7100.00
0005433959974	6919	Economy	7100.00
0005433959983	6919	Economy	7100.00
0005433959990	6919	Economy	7800.00
0005433960013	6919	Economy	7800.00
0005433960014	6919	Economy	7800.00
0005433959967	6919	Economy	7100.00
0005433960007	6919	Economy	7100.00
0005433959997	6919	Economy	7100.00
0005433959995	6919	Economy	7100.00
0005433959985	6919	Economy	7100.00
0005433960010	6919	Economy	7100.00
0005433960027	6919	Economy	7100.00
0005433959996	6919	Economy	7100.00
0005433959982	6919	Economy	7100.00
0005433959968	6919	Economy	7100.00
0005433960016	6919	Economy	7100.00
0005433960000	6919	Economy	7100.00
0005433960023	6919	Economy	7100.00
0005433959976	6919	Economy	7100.00
0005433960002	6919	Economy	7100.00
0005433959980	6919	Economy	7100.00
0005433959966	6919	Economy	7100.00
0005433960019	6919	Economy	7100.00
0005433959969	6919	Economy	7100.00
0005433960026	6919	Economy	7100.00
0005433959988	6919	Economy	7100.00
0005433960012	6919	Economy	7100.00
0005433960025	6919	Economy	7100.00
0005433960006	6919	Economy	7100.00
0005433959965	6919	Economy	7100.00
0005433959987	6919	Economy	7100.00
0005433959991	6919	Economy	7100.00
0005433959984	6919	Economy	7100.00
0005433960021	6919	Economy	7100.00
0005433960009	6919	Economy	7100.00
0005433959975	6919	Economy	7100.00
0005433960011	6919	Economy	7100.00
0005433959989	6919	Economy	7100.00
0005433959964	6919	Economy	7100.00
0005433959971	6919	Economy	7100.00
0005433959999	6919	Economy	7100.00
0005433960004	6919	Economy	7100.00
0005433960008	6919	Economy	7100.00
0005433960005	6919	Economy	7100.00
0005433959986	6919	Economy	7100.00
0005433959979	6919	Economy	7100.00
0005433959977	6919	Economy	7100.00
0005433960018	6919	Economy	7100.00
0005433960015	6919	Economy	7100.00
0005435082652	26095	Economy	3900.00
0005435082656	26095	Economy	3900.00
0005435082655	26095	Economy	3900.00
0005435082661	26095	Economy	3900.00
0005435082654	26095	Economy	3900.00
0005435082653	26095	Economy	3900.00
0005435082651	26095	Economy	3900.00
0005435082650	26095	Economy	3900.00
0005435082659	26095	Economy	3900.00
0005435082658	26095	Economy	3900.00
0005435082657	26095	Economy	3900.00
0005435082660	26095	Economy	3900.00
0005434244534	5036	Business	18000.00
0005434244524	5036	Business	18000.00
0005434244520	5036	Business	18000.00
0005434244527	5036	Business	18000.00
0005434244533	5036	Economy	6000.00
0005434244516	5036	Economy	6000.00
0005434244526	5036	Economy	6000.00
0005434244525	5036	Economy	6000.00
0005432166850	5036	Economy	6000.00
0005434244519	5036	Economy	6000.00
0005434244515	5036	Economy	6000.00
0005434244532	5036	Economy	6000.00
0005434244522	5036	Economy	6000.00
0005434244521	5036	Economy	6000.00
0005434244538	5036	Economy	6000.00
0005434244523	5036	Economy	6000.00
0005434244530	5036	Economy	6000.00
0005434244539	5036	Economy	6000.00
0005432166851	5036	Economy	6000.00
0005434244542	5036	Economy	6000.00
0005434244535	5036	Economy	6000.00
0005434244537	5036	Economy	6000.00
0005432166852	5036	Economy	6000.00
0005434244531	5036	Economy	6000.00
0005434244518	5036	Economy	6000.00
0005434244529	5036	Economy	6000.00
0005434244517	5036	Economy	6000.00
0005434244541	5036	Economy	6000.00
0005434244528	5036	Economy	6000.00
0005434244543	5036	Economy	6000.00
0005434244536	5036	Economy	6000.00
0005434244540	5036	Economy	6000.00
0005433613543	5035	Business	18000.00
0005433613582	5035	Business	18000.00
0005433784383	5035	Business	18000.00
0005433613546	5035	Business	18000.00
0005432667421	5035	Business	18000.00
0005433784384	5035	Business	18000.00
0005433613557	5035	Business	18000.00
0005433613554	5035	Business	18000.00
0005433613544	5035	Business	18000.00
0005433613552	5035	Business	18000.00
0005433784397	5035	Business	18000.00
0005433784368	5035	Business	18000.00
0005432104821	5035	Business	18000.00
0005433613606	5035	Business	18000.00
0005433613571	5035	Business	18000.00
0005433613547	5035	Business	18000.00
0005433784393	5035	Business	18000.00
0005433613570	5035	Business	18000.00
0005433613592	5035	Business	18000.00
0005432104840	5035	Business	18000.00
0005433613541	5035	Business	18000.00
0005433613590	5035	Business	18000.00
0005432104855	5035	Business	18000.00
0005432145081	5035	Business	18000.00
0005432104844	5035	Business	18000.00
0005433784385	5035	Business	18000.00
0005432104842	5035	Business	18000.00
0005433784388	5035	Business	18000.00
0005432104822	5035	Economy	6600.00
0005433613558	5035	Economy	6600.00
0005433784391	5035	Economy	6600.00
0005433613561	5035	Economy	6600.00
0005432104857	5035	Economy	6600.00
0005433784370	5035	Economy	6600.00
0005433613566	5035	Economy	6000.00
0005433613560	5035	Economy	6000.00
0005433784386	5035	Economy	6000.00
0005432104814	5035	Economy	6000.00
0005432665241	5035	Economy	6000.00
0005432145079	5035	Economy	6000.00
0005432666357	5035	Economy	6000.00
0005433613593	5035	Economy	6000.00
0005433784396	5035	Economy	6000.00
0005432104832	5035	Economy	6000.00
0005433613605	5035	Economy	6000.00
0005433784387	5035	Economy	6000.00
0005433613550	5035	Economy	6000.00
0005433613537	5035	Economy	6000.00
0005432104853	5035	Economy	6000.00
0005433613584	5035	Economy	6000.00
0005433784376	5035	Economy	6000.00
0005433784374	5035	Economy	6000.00
0005432104816	5035	Economy	6000.00
0005433784400	5035	Economy	6000.00
0005432104830	5035	Economy	6000.00
0005432104847	5035	Economy	6000.00
0005433613598	5035	Economy	6000.00
0005432666355	5035	Economy	6000.00
0005433784379	5035	Economy	6000.00
0005433784395	5035	Economy	6000.00
0005432666356	5035	Economy	6000.00
0005432104825	5035	Economy	6000.00
0005433613572	5035	Economy	6000.00
0005433784390	5035	Economy	6000.00
0005433613538	5035	Economy	6000.00
0005433613607	5035	Economy	6000.00
0005433784372	5035	Economy	6000.00
0005433613587	5035	Economy	6000.00
0005433613540	5035	Economy	6000.00
0005433613604	5035	Economy	6000.00
0005432104851	5035	Economy	6000.00
0005432104812	5035	Economy	6000.00
0005432104829	5035	Economy	6000.00
0005432104838	5035	Economy	6000.00
0005433613549	5035	Economy	6000.00
0005432104839	5035	Economy	6000.00
0005433613563	5035	Economy	6000.00
0005432104811	5035	Economy	6000.00
0005433784389	5035	Economy	6000.00
0005433613562	5035	Economy	6000.00
0005433613602	5035	Economy	6000.00
0005432667422	5035	Economy	6000.00
0005433613565	5035	Economy	6000.00
0005433613595	5035	Economy	6000.00
0005433784392	5035	Economy	6000.00
0005432104831	5035	Economy	6000.00
0005432104837	5035	Economy	6000.00
0005433613548	5035	Economy	6000.00
0005433784371	5035	Economy	6000.00
0005432104843	5035	Economy	6000.00
0005433784398	5035	Economy	6000.00
0005433613559	5035	Economy	6000.00
0005433784399	5035	Economy	6000.00
0005432145080	5035	Economy	6000.00
0005433613545	5035	Economy	6600.00
0005432104856	5035	Economy	6600.00
0005433613555	5035	Economy	6600.00
0005433613601	5035	Economy	6600.00
0005433784381	5035	Economy	6600.00
0005433613574	5035	Economy	6000.00
0005432104834	5035	Economy	6000.00
0005432104841	5035	Economy	6000.00
0005433784378	5035	Economy	6000.00
0005433613576	5035	Economy	6000.00
0005433613539	5035	Economy	6600.00
0005432104850	5035	Economy	6000.00
0005432104826	5035	Economy	6000.00
0005432104836	5035	Economy	6000.00
0005433613600	5035	Economy	6000.00
0005432104833	5035	Economy	6000.00
0005433613583	5035	Economy	6000.00
0005433784375	5035	Economy	6000.00
0005433613588	5035	Economy	6000.00
0005433613597	5035	Economy	6000.00
0005432104849	5035	Economy	6000.00
0005433613577	5035	Economy	6000.00
0005432104846	5035	Economy	6000.00
0005433613564	5035	Economy	6000.00
0005432104827	5035	Economy	6000.00
0005433613585	5035	Economy	6000.00
0005433613603	5035	Economy	6000.00
0005433784373	5035	Economy	6000.00
0005433613610	5035	Economy	6000.00
0005432104818	5035	Economy	6000.00
0005433784377	5035	Economy	6000.00
0005433613556	5035	Economy	6000.00
0005432104809	5035	Economy	6000.00
0005433613591	5035	Economy	6000.00
0005433613579	5035	Economy	6000.00
0005432104835	5035	Economy	6000.00
0005432104820	5035	Economy	6000.00
0005432104858	5035	Economy	6000.00
0005433784369	5035	Economy	6000.00
0005432104815	5035	Economy	6000.00
0005433784394	5035	Economy	6000.00
0005433613575	5035	Economy	6000.00
0005433784367	5035	Economy	6000.00
0005433613567	5035	Economy	6000.00
0005432104810	5035	Economy	6000.00
0005433613608	5035	Economy	6000.00
0005433613568	5035	Economy	6000.00
0005433613581	5035	Economy	6000.00
0005432104823	5035	Economy	6000.00
0005432665242	5035	Economy	6000.00
0005433613609	5035	Economy	6000.00
0005432104813	5035	Economy	6000.00
0005432665243	5035	Economy	6000.00
0005433613553	5035	Economy	6000.00
0005433613594	5035	Economy	6000.00
0005433613596	5035	Economy	6000.00
0005433613569	5035	Economy	6000.00
0005433613580	5035	Economy	6000.00
0005432104828	5035	Economy	6000.00
0005432104845	5035	Economy	6000.00
0005433613536	5035	Economy	6000.00
0005433784382	5035	Economy	6000.00
0005432104848	5035	Economy	6000.00
0005433613573	5035	Economy	6000.00
0005432104824	5035	Economy	6000.00
0005433613542	5035	Economy	6000.00
0005432104852	5035	Economy	6000.00
0005432104819	5035	Economy	6000.00
0005433613586	5035	Economy	6000.00
0005433613578	5035	Economy	6000.00
0005432104854	5035	Economy	6000.00
0005433784380	5035	Economy	6000.00
0005433613599	5035	Economy	6000.00
0005433613589	5035	Economy	6000.00
0005433613551	5035	Economy	6000.00
0005432104817	5035	Economy	6000.00
0005434173456	5033	Business	18000.00
0005434229015	5033	Business	18000.00
0005434229017	5033	Business	18000.00
0005434229028	5033	Business	18000.00
0005434264752	5033	Business	18000.00
0005434149555	5033	Business	18000.00
0005434149545	5033	Business	18000.00
0005434264740	5033	Business	18000.00
0005434264745	5033	Business	18000.00
0005434229031	5033	Business	18000.00
0005434173458	5033	Economy	6600.00
0005434173457	5033	Economy	6600.00
0005434264731	5033	Economy	6000.00
0005434229016	5033	Economy	6000.00
0005434229018	5033	Economy	6000.00
0005434229021	5033	Economy	6000.00
0005434149550	5033	Economy	6000.00
0005434264736	5033	Economy	6000.00
0005434264743	5033	Economy	6000.00
0005434264753	5033	Economy	6000.00
0005434149547	5033	Economy	6000.00
0005434264747	5033	Economy	6000.00
0005434149556	5033	Economy	6000.00
0005434229032	5033	Economy	6000.00
0005434229030	5033	Economy	6000.00
0005434264749	5033	Economy	6000.00
0005434264733	5033	Economy	6000.00
0005434264748	5033	Economy	6000.00
0005434149552	5033	Economy	6000.00
0005434264730	5033	Economy	6000.00
0005434264737	5033	Economy	6000.00
0005434229026	5033	Economy	6000.00
0005434149549	5033	Economy	6000.00
0005434229033	5033	Economy	6000.00
0005434149553	5033	Economy	6000.00
0005434229029	5033	Economy	6000.00
0005434229013	5033	Economy	6000.00
0005434264741	5033	Economy	6000.00
0005434264732	5033	Economy	6000.00
0005434229034	5033	Economy	6000.00
0005434264729	5033	Economy	6600.00
0005434229019	5033	Economy	6600.00
0005434149544	5033	Economy	6000.00
0005434229014	5033	Economy	6000.00
0005434264750	5033	Economy	6000.00
0005434229020	5033	Economy	6000.00
0005434229022	5033	Economy	6000.00
0005434229027	5033	Economy	6000.00
0005434149551	5033	Economy	6000.00
0005434149554	5033	Economy	6000.00
0005434264742	5033	Economy	6000.00
0005434229025	5033	Economy	6000.00
0005434229012	5033	Economy	6000.00
0005434264735	5033	Economy	6000.00
0005434264728	5033	Economy	6000.00
0005434264746	5033	Economy	6000.00
0005434149548	5033	Economy	6000.00
0005434264744	5033	Economy	6000.00
0005434149546	5033	Economy	6000.00
0005434264734	5033	Economy	6000.00
0005434229023	5033	Economy	6000.00
0005434264739	5033	Economy	6000.00
0005434264751	5033	Economy	6000.00
0005434229024	5033	Economy	6000.00
0005434173459	5033	Economy	6000.00
0005434264738	5033	Economy	6000.00
0005432034525	8570	Business	18000.00
0005432335854	8570	Business	18000.00
0005432034517	8570	Business	18000.00
0005432034509	8570	Business	18000.00
0005432034533	8570	Business	18000.00
0005432034521	8570	Business	18000.00
0005433534464	8570	Business	18000.00
0005435006668	8570	Business	18000.00
0005433534465	8570	Business	18000.00
0005432335857	8570	Business	18000.00
0005433815310	8570	Business	18000.00
0005432034514	8570	Business	18000.00
0005433690896	8570	Business	18000.00
0005432034523	8570	Business	18000.00
0005435006648	8570	Business	18000.00
0005432034508	8570	Business	18000.00
0005432335849	8570	Business	18000.00
0005432034515	8570	Business	18000.00
0005432034510	8570	Business	18000.00
0005433689878	8570	Economy	6600.00
0005435006662	8570	Economy	6600.00
0005432034527	8570	Economy	6600.00
0005435006652	8570	Economy	6000.00
0005433815313	8570	Economy	6000.00
0005432034528	8570	Economy	6000.00
0005433815314	8570	Economy	6000.00
0005434311187	8570	Economy	6000.00
0005432047492	8570	Economy	6000.00
0005435006653	8570	Economy	6000.00
0005435006666	8570	Economy	6000.00
0005435286552	8570	Economy	6000.00
0005432034529	8570	Economy	6000.00
0005435006664	8570	Economy	6000.00
0005432335845	8570	Economy	6000.00
0005432047493	8570	Economy	6000.00
0005432335853	8570	Economy	6000.00
0005432335852	8570	Economy	6000.00
0005435006649	8570	Economy	6000.00
0005435006656	8570	Economy	6000.00
0005432034522	8570	Economy	6000.00
0005432034531	8570	Economy	6000.00
0005434311186	8570	Economy	6000.00
0005432034507	8570	Economy	6000.00
0005435006665	8570	Economy	6000.00
0005433689881	8570	Economy	6000.00
0005432034532	8570	Economy	6000.00
0005433690894	8570	Economy	6000.00
0005433690895	8570	Economy	6000.00
0005432335847	8570	Economy	6000.00
0005432335855	8570	Economy	6000.00
0005435006651	8570	Economy	6000.00
0005435006650	8570	Economy	6000.00
0005432034516	8570	Economy	6000.00
0005435006659	8570	Economy	6000.00
0005433689879	8570	Economy	6000.00
0005432034520	8570	Economy	6000.00
0005435286551	8570	Economy	6600.00
0005435006669	8570	Economy	6600.00
0005435006654	8570	Economy	6600.00
0005434311185	8570	Economy	6000.00
0005432335851	8570	Economy	6000.00
0005432034518	8570	Economy	6000.00
0005432034526	8570	Economy	6000.00
0005432335848	8570	Economy	6000.00
0005432034511	8570	Economy	6000.00
0005435286553	8570	Economy	6000.00
0005433815311	8570	Economy	6000.00
0005432047494	8570	Economy	6000.00
0005435006670	8570	Economy	6000.00
0005432034513	8570	Economy	6000.00
0005435006663	8570	Economy	6000.00
0005435286549	8570	Economy	6000.00
0005435006667	8570	Economy	6000.00
0005435006658	8570	Economy	6000.00
0005433688778	8570	Economy	6000.00
0005432034506	8570	Economy	6000.00
0005433815312	8570	Economy	6000.00
0005433534466	8570	Economy	6000.00
0005432335850	8570	Economy	6000.00
0005435006671	8570	Economy	6000.00
0005435006647	8570	Economy	6000.00
0005433688777	8570	Economy	6000.00
0005432335846	8570	Economy	6000.00
0005435006661	8570	Economy	6000.00
0005433689880	8570	Economy	6000.00
0005435286550	8570	Economy	6000.00
0005435006655	8570	Economy	6000.00
0005432034530	8570	Economy	6000.00
0005435006657	8570	Economy	6000.00
0005432034512	8570	Economy	6000.00
0005432034524	8570	Economy	6000.00
0005432034519	8570	Economy	6000.00
0005435006660	8570	Economy	6000.00
0005432335856	8570	Economy	6000.00
0005433202137	12637	Economy	16200.00
0005433202141	12637	Economy	14800.00
0005433202142	12637	Economy	14800.00
0005433202145	12637	Economy	14800.00
0005433202140	12637	Economy	14800.00
0005433202139	12637	Economy	14800.00
0005433202133	12637	Economy	14800.00
0005433202144	12637	Economy	14800.00
0005433202136	12637	Economy	14800.00
0005433202135	12637	Economy	14800.00
0005433202143	12637	Economy	14800.00
0005433202134	12637	Economy	14800.00
0005433202138	12637	Economy	14800.00
0005433202146	12637	Economy	14800.00
0005434638899	23344	Economy	16200.00
0005432290583	23344	Economy	16200.00
0005434638888	23344	Economy	16200.00
0005434638890	23344	Economy	16200.00
0005434638893	23344	Economy	14800.00
0005434638883	23344	Economy	14800.00
0005434638882	23344	Economy	14800.00
0005434638894	23344	Economy	14800.00
0005434638897	23344	Economy	14800.00
0005434638898	23344	Economy	14800.00
0005434638878	23344	Economy	14800.00
0005434638885	23344	Economy	14800.00
0005434638879	23344	Economy	14800.00
0005432290584	23344	Economy	14800.00
0005434638881	23344	Economy	14800.00
0005434638901	23344	Economy	14800.00
0005434638876	23344	Economy	14800.00
0005434638877	23344	Economy	14800.00
0005434638887	23344	Economy	14800.00
0005434638892	23344	Economy	14800.00
0005434638895	23344	Economy	14800.00
0005434638886	23344	Economy	14800.00
0005434638896	23344	Economy	14800.00
0005434638902	23344	Economy	14800.00
0005434638880	23344	Economy	14800.00
0005434638900	23344	Economy	14800.00
0005434638891	23344	Economy	14800.00
0005434638884	23344	Economy	14800.00
0005434638889	23344	Economy	14800.00
0005432054258	21084	Business	18900.00
0005432848836	21084	Economy	6300.00
0005432054260	21084	Economy	6300.00
0005432054259	21084	Economy	6300.00
0005432054261	21084	Economy	6300.00
0005432327978	31230	Business	18900.00
0005432287109	31230	Business	18900.00
0005432327981	31230	Business	18900.00
0005432382526	31230	Business	18900.00
0005432382543	31230	Business	18900.00
0005432382521	31230	Business	18900.00
0005432327973	31230	Business	18900.00
0005432382561	31230	Business	18900.00
0005432327940	31230	Business	18900.00
0005432382531	31230	Business	18900.00
0005432327969	31230	Business	18900.00
0005432382541	31230	Business	18900.00
0005432327959	31230	Economy	6300.00
0005432327948	31230	Economy	6300.00
0005432327938	31230	Economy	6300.00
0005432382529	31230	Economy	6300.00
0005432327960	31230	Economy	6300.00
0005432382551	31230	Economy	6300.00
0005432382528	31230	Economy	6300.00
0005432382540	31230	Economy	6300.00
0005432382562	31230	Economy	6300.00
0005432327968	31230	Economy	6900.00
0005432382549	31230	Economy	6900.00
0005432327957	31230	Economy	6900.00
0005432382558	31230	Economy	6900.00
0005432382544	31230	Economy	6300.00
0005432382524	31230	Economy	6300.00
0005432327945	31230	Economy	6300.00
0005432327963	31230	Economy	6300.00
0005432382535	31230	Economy	6300.00
0005432327976	31230	Economy	6300.00
0005432382527	31230	Economy	6300.00
0005432327971	31230	Economy	6300.00
0005432327982	31230	Economy	6300.00
0005432327949	31230	Economy	6300.00
0005432327983	31230	Economy	6300.00
0005432382559	31230	Economy	6300.00
0005432382539	31230	Economy	6300.00
0005432327979	31230	Economy	6300.00
0005432382522	31230	Economy	6300.00
0005432327953	31230	Economy	6300.00
0005432327967	31230	Economy	6300.00
0005432327952	31230	Economy	6300.00
0005432382532	31230	Economy	6300.00
0005432382557	31230	Economy	6300.00
0005432327943	31230	Economy	6300.00
0005432327975	31230	Economy	6300.00
0005432382552	31230	Economy	6300.00
0005432382523	31230	Economy	6300.00
0005432327939	31230	Economy	6300.00
0005432382563	31230	Economy	6300.00
0005432382553	31230	Economy	6300.00
0005432382545	31230	Economy	6300.00
0005432327956	31230	Economy	6300.00
0005432327942	31230	Economy	6300.00
0005432327964	31230	Economy	6300.00
0005432382547	31230	Economy	6300.00
0005432287108	31230	Economy	6300.00
0005432327941	31230	Economy	6300.00
0005432327961	31230	Economy	6300.00
0005432382546	31230	Economy	6300.00
0005432382525	31230	Economy	6300.00
0005432382548	31230	Economy	6300.00
0005432327965	31230	Economy	6300.00
0005432327954	31230	Economy	6300.00
0005432382536	31230	Economy	6300.00
0005432327946	31230	Economy	6300.00
0005432327950	31230	Economy	6300.00
0005432382554	31230	Economy	6300.00
0005432382550	31230	Economy	6300.00
0005432382556	31230	Economy	6300.00
0005432287106	31230	Economy	6300.00
0005432327980	31230	Economy	6300.00
0005432382555	31230	Economy	6300.00
0005432382537	31230	Economy	6300.00
0005432382534	31230	Economy	6300.00
0005432327955	31230	Economy	6300.00
0005432327944	31230	Economy	6300.00
0005432327962	31230	Economy	6300.00
0005432327970	31230	Economy	6300.00
0005432327977	31230	Economy	6300.00
0005432327951	31230	Economy	6300.00
0005432382538	31230	Economy	6300.00
0005432287107	31230	Economy	6300.00
0005432382560	31230	Economy	6300.00
0005432327966	31230	Economy	6300.00
0005432327984	31230	Economy	6300.00
0005432382530	31230	Economy	6300.00
0005432327958	31230	Economy	6300.00
0005432327972	31230	Economy	6300.00
0005432382533	31230	Economy	6300.00
0005432327947	31230	Economy	6300.00
0005432382542	31230	Economy	6300.00
0005432327974	31230	Economy	6300.00
0005433642091	2491	Business	89600.00
0005433642100	2491	Business	89600.00
0005433642109	2491	Business	89600.00
0005433642114	2491	Business	89600.00
0005433642117	2491	Business	89600.00
0005433642108	2491	Economy	29900.00
0005433642119	2491	Economy	29900.00
0005433642090	2491	Economy	32800.00
0005433642088	2491	Economy	29900.00
0005433642112	2491	Economy	29900.00
0005433642102	2491	Economy	29900.00
0005433642106	2491	Economy	29900.00
0005433642095	2491	Economy	29900.00
0005433642103	2491	Economy	29900.00
0005433642092	2491	Economy	29900.00
0005433642118	2491	Economy	29900.00
0005433642115	2491	Economy	29900.00
0005433642101	2491	Economy	29900.00
0005433642110	2491	Economy	29900.00
0005433642097	2491	Economy	29900.00
0005433642094	2491	Economy	29900.00
0005433642098	2491	Economy	29900.00
0005433642104	2491	Economy	29900.00
0005433642113	2491	Economy	29900.00
0005433642116	2491	Economy	29900.00
0005433642111	2491	Economy	29900.00
0005433642105	2491	Economy	29900.00
0005433642093	2491	Economy	29900.00
0005433642089	2491	Economy	29900.00
0005433642099	2491	Economy	29900.00
0005433642096	2491	Economy	29900.00
0005433642107	2491	Economy	29900.00
0005432953791	27596	Business	89600.00
0005432953802	27596	Business	89600.00
0005432953798	27596	Business	89600.00
0005432953808	27596	Business	89600.00
0005432953811	27596	Business	89600.00
0005432953809	27596	Business	89600.00
0005432953807	27596	Business	89600.00
0005432953806	27596	Economy	29900.00
0005432953796	27596	Economy	29900.00
0005432953793	27596	Economy	29900.00
0005432953799	27596	Economy	29900.00
0005432953785	27596	Economy	29900.00
0005432953801	27596	Economy	29900.00
0005432953797	27596	Economy	29900.00
0005432953803	27596	Economy	29900.00
0005432953795	27596	Economy	29900.00
0005432953788	27596	Economy	29900.00
0005432953810	27596	Economy	29900.00
0005432953790	27596	Economy	29900.00
0005432953805	27596	Economy	29900.00
0005432953789	27596	Economy	29900.00
0005432953794	27596	Economy	29900.00
0005432953786	27596	Economy	29900.00
0005432953804	27596	Economy	29900.00
0005432953787	27596	Economy	29900.00
0005432953800	27596	Economy	29900.00
0005432953792	27596	Economy	29900.00
0005432423649	13331	Business	12700.00
0005432423656	13331	Business	12700.00
0005432423682	13331	Business	12700.00
0005432423671	13331	Business	12700.00
0005432423652	13331	Business	12700.00
0005432423658	13331	Business	12700.00
0005432423690	13331	Business	12700.00
0005432423677	13331	Economy	4200.00
0005432423657	13331	Economy	4200.00
0005432423660	13331	Economy	4200.00
0005432423664	13331	Economy	4200.00
0005432423665	13331	Economy	4200.00
0005432423670	13331	Economy	4200.00
0005432423663	13331	Economy	4200.00
0005432423667	13331	Economy	4200.00
0005432423668	13331	Economy	4700.00
0005432423693	13331	Economy	4700.00
0005432423674	13331	Economy	4700.00
0005432423653	13331	Economy	4200.00
0005432423662	13331	Economy	4200.00
0005432423650	13331	Economy	4200.00
0005432423679	13331	Economy	4200.00
0005432423681	13331	Economy	4200.00
0005432423684	13331	Economy	4200.00
0005432423687	13331	Economy	4200.00
0005432423661	13331	Economy	4200.00
0005432423675	13331	Economy	4200.00
0005432423685	13331	Economy	4200.00
0005432423666	13331	Economy	4200.00
0005432423659	13331	Economy	4200.00
0005432423654	13331	Economy	4200.00
0005432423651	13331	Economy	4200.00
0005432423655	13331	Economy	4200.00
0005432423678	13331	Economy	4200.00
0005432423672	13331	Economy	4200.00
0005432423673	13331	Economy	4200.00
0005432423648	13331	Economy	4200.00
0005432423683	13331	Economy	4200.00
0005432423676	13331	Economy	4200.00
0005432423691	13331	Economy	4200.00
0005432423688	13331	Economy	4200.00
0005432423692	13331	Economy	4200.00
0005432423669	13331	Economy	4200.00
0005432423680	13331	Economy	4200.00
0005432423689	13331	Economy	4200.00
0005432423686	13331	Economy	4200.00
0005434448261	9596	Business	32600.00
0005432822084	9596	Business	32600.00
0005432817020	9596	Business	32600.00
0005432817013	9596	Business	32600.00
0005432817004	9596	Business	32600.00
0005432816998	9596	Business	32600.00
0005434448264	9596	Economy	10900.00
0005434448263	9596	Economy	10900.00
0005432817018	9596	Economy	10900.00
0005432817011	9596	Economy	10900.00
0005432288936	9596	Economy	11900.00
0005432288935	9596	Economy	11900.00
0005432817003	9596	Economy	11900.00
0005432822087	9596	Economy	11900.00
0005432817000	9596	Economy	11900.00
0005432817016	9596	Economy	10900.00
0005432817024	9596	Economy	10900.00
0005432817007	9596	Economy	10900.00
0005432817025	9596	Economy	10900.00
0005432822085	9596	Economy	10900.00
0005432817010	9596	Economy	10900.00
0005432817019	9596	Economy	10900.00
0005434448262	9596	Economy	10900.00
0005432817006	9596	Economy	10900.00
0005432817026	9596	Economy	10900.00
0005432817017	9596	Economy	10900.00
0005432817015	9596	Economy	10900.00
0005432816999	9596	Economy	10900.00
0005432822082	9596	Economy	10900.00
0005432822086	9596	Economy	10900.00
0005432817009	9596	Economy	10900.00
0005432817027	9596	Economy	10900.00
0005432288934	9596	Economy	10900.00
0005432822080	9596	Economy	10900.00
0005432817005	9596	Economy	10900.00
0005432822081	9596	Economy	10900.00
0005432817002	9596	Economy	10900.00
0005432817023	9596	Economy	10900.00
0005432817014	9596	Economy	10900.00
0005432817022	9596	Economy	10900.00
0005432817001	9596	Economy	10900.00
0005432817021	9596	Economy	10900.00
0005432817012	9596	Economy	10900.00
0005432822083	9596	Economy	10900.00
0005432817008	9596	Economy	10900.00
0005432901346	28993	Business	32600.00
0005434157356	28993	Business	32600.00
0005432002045	28993	Business	32600.00
0005432901345	28993	Business	32600.00
0005432901335	28993	Business	32600.00
0005434157360	28993	Business	32600.00
0005432901331	28993	Business	32600.00
0005434157358	28993	Economy	10900.00
0005434157361	28993	Economy	11900.00
0005432901342	28993	Economy	10900.00
0005432901336	28993	Economy	10900.00
0005434157362	28993	Economy	10900.00
0005432901330	28993	Economy	10900.00
0005434186152	28993	Economy	10900.00
0005432901344	28993	Economy	10900.00
0005432901339	28993	Economy	10900.00
0005432901341	28993	Economy	10900.00
0005432901333	28993	Economy	10900.00
0005432901338	28993	Economy	10900.00
0005432901332	28993	Economy	10900.00
0005434186150	28993	Economy	10900.00
0005432901337	28993	Economy	10900.00
0005432901329	28993	Economy	10900.00
0005434157359	28993	Economy	10900.00
0005432901340	28993	Economy	10900.00
0005432901334	28993	Economy	10900.00
0005432002044	28993	Economy	10900.00
0005434186151	28993	Economy	10900.00
0005434157357	28993	Economy	10900.00
0005432901343	28993	Economy	10900.00
0005432613797	15058	Economy	11000.00
0005432611647	15058	Economy	11000.00
0005432611650	15058	Economy	11000.00
0005432611649	15058	Economy	11000.00
0005432613799	15058	Economy	11000.00
0005432611648	15058	Economy	11000.00
0005432613800	15058	Economy	11000.00
0005432613798	15058	Economy	11000.00
0005435842314	31644	Economy	11000.00
0005435841810	31644	Economy	11000.00
0005433568088	11866	Business	105900.00
0005433568084	11866	Business	105900.00
0005433568117	11866	Business	105900.00
0005433568079	11866	Business	105900.00
0005433568102	11866	Business	105900.00
0005433568122	11866	Business	105900.00
0005433568087	11866	Business	105900.00
0005433568076	11866	Business	105900.00
0005433568069	11866	Economy	35300.00
0005433568072	11866	Economy	35300.00
0005433568090	11866	Economy	35300.00
0005433568121	11866	Economy	35300.00
0005433568113	11866	Economy	38800.00
0005433568110	11866	Economy	35300.00
0005433568112	11866	Economy	35300.00
0005433568095	11866	Economy	35300.00
0005433568114	11866	Economy	35300.00
0005433568104	11866	Economy	35300.00
0005433568101	11866	Economy	35300.00
0005433568085	11866	Economy	35300.00
0005433568073	11866	Economy	35300.00
0005433568119	11866	Economy	35300.00
0005433568107	11866	Economy	35300.00
0005433568094	11866	Economy	35300.00
0005433568070	11866	Economy	35300.00
0005433568091	11866	Economy	35300.00
0005433568081	11866	Economy	35300.00
0005433568118	11866	Economy	35300.00
0005433568086	11866	Economy	35300.00
0005433568115	11866	Economy	35300.00
0005433568108	11866	Economy	35300.00
0005433568093	11866	Economy	35300.00
0005433568120	11866	Economy	35300.00
0005433568099	11866	Economy	35300.00
0005433568123	11866	Economy	35300.00
0005433568083	11866	Economy	35300.00
0005433568071	11866	Economy	35300.00
0005433568097	11866	Economy	35300.00
0005433568080	11866	Economy	35300.00
0005433568075	11866	Economy	35300.00
0005433568089	11866	Economy	35300.00
0005433568106	11866	Economy	35300.00
0005433568078	11866	Economy	35300.00
0005433568100	11866	Economy	35300.00
0005433568082	11866	Economy	35300.00
0005433568096	11866	Economy	35300.00
0005433568109	11866	Economy	35300.00
0005433568105	11866	Economy	35300.00
0005433568074	11866	Economy	35300.00
0005433568111	11866	Economy	35300.00
0005433568098	11866	Economy	35300.00
0005433568103	11866	Economy	35300.00
0005433568092	11866	Economy	35300.00
0005433568077	11866	Economy	35300.00
0005433568116	11866	Economy	35300.00
0005432947885	25328	Business	105900.00
0005432947850	25328	Business	105900.00
0005432947868	25328	Business	105900.00
0005432947873	25328	Business	105900.00
0005432947877	25328	Business	105900.00
0005432947874	25328	Business	105900.00
0005432947855	25328	Business	105900.00
0005432947852	25328	Economy	35300.00
0005432947861	25328	Economy	35300.00
0005432947875	25328	Economy	35300.00
0005432947860	25328	Economy	35300.00
0005432947853	25328	Economy	35300.00
0005432947872	25328	Economy	35300.00
0005432947849	25328	Economy	35300.00
0005432947876	25328	Economy	35300.00
0005432947883	25328	Economy	38800.00
0005432947888	25328	Economy	38800.00
0005432947863	25328	Economy	38800.00
0005432947882	25328	Economy	35300.00
0005432947857	25328	Economy	35300.00
0005432947862	25328	Economy	35300.00
0005432947856	25328	Economy	35300.00
0005432947879	25328	Economy	35300.00
0005432947869	25328	Economy	35300.00
0005432947866	25328	Economy	35300.00
0005432947880	25328	Economy	35300.00
0005432947871	25328	Economy	35300.00
0005432947847	25328	Economy	35300.00
0005432947851	25328	Economy	35300.00
0005432947864	25328	Economy	35300.00
0005432947878	25328	Economy	35300.00
0005432947887	25328	Economy	35300.00
0005432947865	25328	Economy	35300.00
0005432947858	25328	Economy	35300.00
0005432947846	25328	Economy	35300.00
0005432947884	25328	Economy	35300.00
0005432947867	25328	Economy	35300.00
0005432947870	25328	Economy	35300.00
0005432947881	25328	Economy	35300.00
0005432947848	25328	Economy	35300.00
0005432947886	25328	Economy	35300.00
0005432947854	25328	Economy	35300.00
0005432947859	25328	Economy	35300.00
0005434654244	5387	Business	67200.00
0005434654239	5387	Business	67200.00
0005434654225	5387	Business	67200.00
0005434654221	5387	Business	67200.00
0005434654236	5387	Economy	22400.00
0005434654228	5387	Economy	22400.00
0005434654241	5387	Economy	22400.00
0005434654223	5387	Economy	22400.00
0005434654230	5387	Economy	22400.00
0005434654248	5387	Economy	22400.00
0005434654232	5387	Economy	22400.00
0005434654240	5387	Economy	22400.00
0005434656525	5387	Economy	22400.00
0005434654224	5387	Economy	22400.00
0005434654243	5387	Economy	22400.00
0005432114151	5387	Economy	22400.00
0005434654234	5387	Economy	22400.00
0005434654235	5387	Economy	22400.00
0005434654245	5387	Economy	22400.00
0005434654229	5387	Economy	22400.00
0005434654231	5387	Economy	22400.00
0005434654227	5387	Economy	22400.00
0005434654246	5387	Economy	22400.00
0005434654226	5387	Economy	22400.00
0005432114154	5387	Economy	22400.00
0005432114153	5387	Economy	22400.00
0005434654222	5387	Economy	22400.00
0005434654242	5387	Economy	22400.00
0005432114152	5387	Economy	22400.00
0005434656524	5387	Economy	22400.00
0005434654220	5387	Economy	22400.00
0005434654233	5387	Economy	22400.00
0005434654238	5387	Economy	22400.00
0005434654237	5387	Economy	22400.00
0005434654247	5387	Economy	22400.00
0005434654219	5387	Economy	22400.00
0005435340019	12533	Business	67200.00
0005435555340	12533	Economy	22400.00
0005435340024	12533	Economy	24600.00
0005435340028	12533	Economy	24600.00
0005435340032	12533	Economy	24600.00
0005435340029	12533	Economy	22400.00
0005435340034	12533	Economy	22400.00
0005435340021	12533	Economy	22400.00
0005435340023	12533	Economy	22400.00
0005435555339	12533	Economy	22400.00
0005435555338	12533	Economy	22400.00
0005435340026	12533	Economy	22400.00
0005435340027	12533	Economy	22400.00
0005435340022	12533	Economy	22400.00
0005435340025	12533	Economy	22400.00
0005435340030	12533	Economy	22400.00
0005435340031	12533	Economy	22400.00
0005435340020	12533	Economy	22400.00
0005435340033	12533	Economy	22400.00
0005433715170	7422	Business	32000.00
0005433722113	7422	Business	32000.00
0005433715197	7422	Business	32000.00
0005433722107	7422	Business	32000.00
0005433722109	7422	Business	32000.00
0005433715216	7422	Business	32000.00
0005433715202	7422	Economy	10700.00
0005433715179	7422	Economy	10700.00
0005433715201	7422	Economy	10700.00
0005433715188	7422	Economy	10700.00
0005433715219	7422	Economy	10700.00
0005432078019	7422	Economy	10700.00
0005433715213	7422	Economy	10700.00
0005433715194	7422	Economy	10700.00
0005432078024	7422	Economy	10700.00
0005433715168	7422	Economy	10700.00
0005433715184	7422	Economy	10700.00
0005433715178	7422	Economy	10700.00
0005433722110	7422	Economy	10700.00
0005433715186	7422	Economy	10700.00
0005433722111	7422	Economy	10700.00
0005433722115	7422	Economy	10700.00
0005433715173	7422	Economy	10700.00
0005433715189	7422	Economy	10700.00
0005433715205	7422	Economy	10700.00
0005432078023	7422	Economy	10700.00
0005433719085	7422	Economy	10700.00
0005433715176	7422	Economy	10700.00
0005433715212	7422	Economy	10700.00
0005433715171	7422	Economy	10700.00
0005433715182	7422	Economy	11700.00
0005433715180	7422	Economy	11700.00
0005433722108	7422	Economy	11700.00
0005433715215	7422	Economy	10700.00
0005433719084	7422	Economy	10700.00
0005433715199	7422	Economy	10700.00
0005433715187	7422	Economy	10700.00
0005433715191	7422	Economy	10700.00
0005433715209	7422	Economy	10700.00
0005433715198	7422	Economy	10700.00
0005433715183	7422	Economy	10700.00
0005433722112	7422	Economy	10700.00
0005433690893	7422	Economy	10700.00
0005433715172	7422	Economy	10700.00
0005433715169	7422	Economy	10700.00
0005433719086	7422	Economy	10700.00
0005433689877	7422	Economy	10700.00
0005433689876	7422	Economy	10700.00
0005432078021	7422	Economy	10700.00
0005433715196	7422	Economy	10700.00
0005433715190	7422	Economy	10700.00
0005433715211	7422	Economy	10700.00
0005433715203	7422	Economy	10700.00
0005433656615	7422	Economy	10700.00
0005433656616	7422	Economy	10700.00
0005433715217	7422	Economy	10700.00
0005433715192	7422	Economy	10700.00
0005433715204	7422	Economy	10700.00
0005433715218	7422	Economy	10700.00
0005433715185	7422	Economy	10700.00
0005433715195	7422	Economy	10700.00
0005433719087	7422	Economy	10700.00
0005433688776	7422	Economy	10700.00
0005433722117	7422	Economy	10700.00
0005433715177	7422	Economy	10700.00
0005433715181	7422	Economy	10700.00
0005432078022	7422	Economy	10700.00
0005433715208	7422	Economy	10700.00
0005433715210	7422	Economy	10700.00
0005433715193	7422	Economy	10700.00
0005433722114	7422	Economy	10700.00
0005433715200	7422	Economy	10700.00
0005433715175	7422	Economy	10700.00
0005433656617	7422	Economy	10700.00
0005432078020	7422	Economy	10700.00
0005433715214	7422	Economy	10700.00
0005433722116	7422	Economy	10700.00
0005433715207	7422	Economy	10700.00
0005433715206	7422	Economy	10700.00
0005433715174	7422	Economy	10700.00
0005432006714	29231	Business	32000.00
0005432006718	29231	Economy	10700.00
0005432428874	29231	Economy	10700.00
0005432428876	29231	Economy	10700.00
0005432006717	29231	Economy	10700.00
0005432006715	29231	Economy	10700.00
0005432006716	29231	Economy	10700.00
0005432428878	29231	Economy	10700.00
0005432428877	29231	Economy	10700.00
0005432428875	29231	Economy	10700.00
0005434095051	8672	Business	36500.00
0005434095054	8672	Economy	12200.00
0005434095049	8672	Economy	12200.00
0005434095057	8672	Economy	12200.00
0005434095048	8672	Economy	12200.00
0005434095045	8672	Economy	12200.00
0005434095046	8672	Economy	12200.00
0005434095052	8672	Economy	12200.00
0005434095058	8672	Economy	12200.00
0005434095047	8672	Economy	12200.00
0005434181964	8672	Economy	12200.00
0005434181963	8672	Economy	12200.00
0005434095050	8672	Economy	12200.00
0005434095053	8672	Economy	12200.00
0005434095055	8672	Economy	12200.00
0005434095044	8672	Economy	12200.00
0005434095056	8672	Economy	12200.00
0005434181986	11683	Business	36500.00
0005434181984	11683	Business	36500.00
0005434181993	11683	Business	36500.00
0005434181983	11683	Economy	12200.00
0005434181987	11683	Economy	13400.00
0005434184632	11683	Economy	12200.00
0005434181988	11683	Economy	12200.00
0005434181994	11683	Economy	12200.00
0005434181990	11683	Economy	12200.00
0005434181982	11683	Economy	12200.00
0005434181989	11683	Economy	12200.00
0005434181992	11683	Economy	12200.00
0005434181985	11683	Economy	12200.00
0005434183547	11683	Economy	12200.00
0005434181991	11683	Economy	12200.00
0005434184631	11683	Economy	12200.00
0005433456906	1449	Business	33000.00
0005435732145	1449	Business	33000.00
0005433456908	1449	Business	33000.00
0005435732148	1449	Business	33000.00
0005435732137	1449	Business	33000.00
0005433456907	1449	Business	33000.00
0005435732149	1449	Economy	11000.00
0005435732140	1449	Economy	11000.00
0005435732151	1449	Economy	11000.00
0005435732138	1449	Economy	11000.00
0005435732135	1449	Economy	11000.00
0005435732141	1449	Economy	12100.00
0005433456905	1449	Economy	12100.00
0005435732131	1449	Economy	11000.00
0005435732134	1449	Economy	11000.00
0005435732133	1449	Economy	11000.00
0005435732129	1449	Economy	11000.00
0005435732142	1449	Economy	11000.00
0005433397219	1449	Economy	11000.00
0005432297235	1449	Economy	11000.00
0005435732132	1449	Economy	11000.00
0005432297237	1449	Economy	11000.00
0005435732144	1449	Economy	11000.00
0005435732130	1449	Economy	11000.00
0005435732147	1449	Economy	11000.00
0005435732146	1449	Economy	11000.00
0005435732143	1449	Economy	11000.00
0005435732139	1449	Economy	11000.00
0005432297236	1449	Economy	11000.00
0005435732136	1449	Economy	11000.00
0005435732150	1449	Economy	11000.00
0005433397327	19260	Business	33000.00
0005433397310	19260	Business	33000.00
0005433397312	19260	Business	33000.00
0005433397324	19260	Business	33000.00
0005433397304	19260	Business	33000.00
0005433397311	19260	Business	33000.00
0005433397296	19260	Business	33000.00
0005433397282	19260	Business	33000.00
0005433397285	19260	Economy	11000.00
0005433397306	19260	Economy	11000.00
0005433397317	19260	Economy	11000.00
0005433397295	19260	Economy	12100.00
0005433397318	19260	Economy	12100.00
0005433397281	19260	Economy	12100.00
0005433397278	19260	Economy	12100.00
0005433397279	19260	Economy	11000.00
0005433397292	19260	Economy	11000.00
0005433397319	19260	Economy	11000.00
0005433397287	19260	Economy	11000.00
0005433397322	19260	Economy	11000.00
0005433397305	19260	Economy	11000.00
0005433397299	19260	Economy	11000.00
0005433397298	19260	Economy	11000.00
0005433397288	19260	Economy	11000.00
0005433397316	19260	Economy	11000.00
0005433397314	19260	Economy	11000.00
0005433397280	19260	Economy	11000.00
0005433397326	19260	Economy	11000.00
0005433397286	19260	Economy	11000.00
0005433397313	19260	Economy	11000.00
0005433397315	19260	Economy	11000.00
0005433397291	19260	Economy	11000.00
0005433397320	19260	Economy	11000.00
0005433397321	19260	Economy	11000.00
0005433397323	19260	Economy	11000.00
0005433397303	19260	Economy	11000.00
0005432906496	19260	Economy	11000.00
0005433397309	19260	Economy	11000.00
0005433397301	19260	Economy	11000.00
0005432906497	19260	Economy	11000.00
0005433397307	19260	Economy	11000.00
0005433397300	19260	Economy	11000.00
0005433397302	19260	Economy	11000.00
0005433397283	19260	Economy	11000.00
0005433397284	19260	Economy	11000.00
0005433397308	19260	Economy	11000.00
0005433397297	19260	Economy	11000.00
0005433397294	19260	Economy	11000.00
0005433397293	19260	Economy	11000.00
0005433397325	19260	Economy	11000.00
0005433397290	19260	Economy	11000.00
0005433397289	19260	Economy	11000.00
0005434443455	20576	Economy	15600.00
0005434443452	20576	Economy	15600.00
0005434443454	20576	Economy	14100.00
0005434443446	20576	Economy	14100.00
0005434443453	20576	Economy	14100.00
0005434443451	20576	Economy	14100.00
0005434443449	20576	Economy	14100.00
0005434443443	20576	Economy	14100.00
0005434443447	20576	Economy	14100.00
0005434443448	20576	Economy	14100.00
0005434443444	20576	Economy	14100.00
0005434443440	20576	Economy	14100.00
0005434443450	20576	Economy	14100.00
0005434443445	20576	Economy	14100.00
0005434443442	20576	Economy	14100.00
0005434443441	20576	Economy	14100.00
0005435377537	7246	Economy	5800.00
0005434954546	7246	Economy	5800.00
0005434954549	7246	Economy	5800.00
0005434954547	7246	Economy	5800.00
0005434954548	7246	Economy	5800.00
0005434954550	7246	Economy	5800.00
0005435377543	28360	Economy	5800.00
0005435377542	28360	Economy	5800.00
0005435377541	28360	Economy	5800.00
0005434351501	4486	Economy	14000.00
0005434351493	4486	Economy	14000.00
0005434351502	4486	Economy	14000.00
0005434351497	4486	Economy	14000.00
0005434351499	4486	Economy	14000.00
0005434351492	4486	Economy	14000.00
0005434351498	4486	Economy	14000.00
0005434351491	4486	Economy	14000.00
0005434351494	4486	Economy	14000.00
0005434351496	4486	Economy	14000.00
0005434351490	4486	Economy	14000.00
0005434351495	4486	Economy	14000.00
0005434351500	4486	Economy	14000.00
0005435893521	29685	Economy	14000.00
0005435893519	29685	Economy	14000.00
0005435893523	29685	Economy	14000.00
0005435893522	29685	Economy	14000.00
0005435893520	29685	Economy	14000.00
0005435893518	29685	Economy	14000.00
0005432293170	1050	Business	30600.00
0005435545615	1050	Economy	10200.00
0005434445212	1050	Economy	10200.00
0005435091922	1050	Economy	10200.00
0005435091917	1050	Economy	10200.00
0005434446485	1050	Economy	10200.00
0005433463867	1050	Economy	10200.00
0005435545614	1050	Economy	10200.00
0005433462713	1050	Economy	10200.00
0005435091918	1050	Economy	10200.00
0005435091921	1050	Economy	10200.00
0005434445213	1050	Economy	10200.00
0005435091914	1050	Economy	10200.00
0005433463866	1050	Economy	10200.00
0005435091915	1050	Economy	10200.00
0005435091920	1050	Economy	10200.00
0005432293169	1050	Economy	10200.00
0005435091919	1050	Economy	11200.00
0005435545613	1050	Economy	10200.00
0005435091923	1050	Economy	10200.00
0005434446486	1050	Economy	10200.00
0005435545616	1050	Economy	10200.00
0005434446483	1050	Economy	10200.00
0005435091916	1050	Economy	10200.00
0005435091913	1050	Economy	10200.00
0005434446484	1050	Economy	10200.00
0005434446482	1050	Economy	10200.00
0005433269633	17031	Business	30600.00
0005433341526	17031	Business	30600.00
0005433341517	17031	Business	30600.00
0005433341571	17031	Business	30600.00
0005433341550	17031	Business	30600.00
0005433341497	17031	Business	30600.00
0005433341480	17031	Business	30600.00
0005433341546	17031	Business	30600.00
0005433341507	17031	Business	30600.00
0005433341523	17031	Business	30600.00
0005433341555	17031	Business	30600.00
0005433341541	17031	Business	30600.00
0005433341529	17031	Business	30600.00
0005433341561	17031	Economy	11200.00
0005433341494	17031	Economy	10200.00
0005433159277	17031	Economy	10200.00
0005433341481	17031	Economy	10200.00
0005433341558	17031	Economy	10200.00
0005433269632	17031	Economy	10200.00
0005433341499	17031	Economy	10200.00
0005433341506	17031	Economy	10200.00
0005433341553	17031	Economy	10200.00
0005433341537	17031	Economy	10200.00
0005433269631	17031	Economy	10200.00
0005433341493	17031	Economy	10200.00
0005433341578	17031	Economy	10200.00
0005433341524	17031	Economy	10200.00
0005433341569	17031	Economy	10200.00
0005433341581	17031	Economy	10200.00
0005433341536	17031	Economy	10200.00
0005433341522	17031	Economy	10200.00
0005433341579	17031	Economy	10200.00
0005433341498	17031	Economy	10200.00
0005433341514	17031	Economy	10200.00
0005433341551	17031	Economy	10200.00
0005433341518	17031	Economy	10200.00
0005433341580	17031	Economy	10200.00
0005433341534	17031	Economy	10200.00
0005433341531	17031	Economy	10200.00
0005433341491	17031	Economy	10200.00
0005433341508	17031	Economy	10200.00
0005433341548	17031	Economy	10200.00
0005433341503	17031	Economy	10200.00
0005433341510	17031	Economy	10200.00
0005433341484	17031	Economy	10200.00
0005433341504	17031	Economy	10200.00
0005433341485	17031	Economy	10200.00
0005433269634	17031	Economy	10200.00
0005433341512	17031	Economy	10200.00
0005433341511	17031	Economy	10200.00
0005433341542	17031	Economy	10200.00
0005433341502	17031	Economy	10200.00
0005433341528	17031	Economy	10200.00
0005433341574	17031	Economy	10200.00
0005433341545	17031	Economy	10200.00
0005433341519	17031	Economy	10200.00
0005433341554	17031	Economy	10200.00
0005433341577	17031	Economy	10200.00
0005433341505	17031	Economy	10200.00
0005433341488	17031	Economy	10200.00
0005433341525	17031	Economy	10200.00
0005433341544	17031	Economy	10200.00
0005433341582	17031	Economy	10200.00
0005433341532	17031	Economy	10200.00
0005433341564	17031	Economy	10200.00
0005433341500	17031	Economy	10200.00
0005433341576	17031	Economy	11200.00
0005433341516	17031	Economy	10200.00
0005433341549	17031	Economy	10200.00
0005433341568	17031	Economy	10200.00
0005433341560	17031	Economy	10200.00
0005433341501	17031	Economy	10200.00
0005433269635	17031	Economy	10200.00
0005433341492	17031	Economy	10200.00
0005433341557	17031	Economy	10200.00
0005433341572	17031	Economy	10200.00
0005433341486	17031	Economy	10200.00
0005433341483	17031	Economy	10200.00
0005433341515	17031	Economy	10200.00
0005433341565	17031	Economy	10200.00
0005433159278	17031	Economy	10200.00
0005433341575	17031	Economy	10200.00
0005433341547	17031	Economy	10200.00
0005433341513	17031	Economy	10200.00
0005433341521	17031	Economy	10200.00
0005433341482	17031	Economy	10200.00
0005433341527	17031	Economy	10200.00
0005433341496	17031	Economy	10200.00
0005433341563	17031	Economy	10200.00
0005433341562	17031	Economy	10200.00
0005433341559	17031	Economy	10200.00
0005433341556	17031	Economy	10200.00
0005433341540	17031	Economy	10200.00
0005433341530	17031	Economy	10200.00
0005433341538	17031	Economy	10200.00
0005433341533	17031	Economy	10200.00
0005433341495	17031	Economy	10200.00
0005433341490	17031	Economy	10200.00
0005433341543	17031	Economy	10200.00
0005433341566	17031	Economy	10200.00
0005433341487	17031	Economy	10200.00
0005433341573	17031	Economy	10200.00
0005433341520	17031	Economy	10200.00
0005433341539	17031	Economy	10200.00
0005433341552	17031	Economy	10200.00
0005433341567	17031	Economy	10200.00
0005433341489	17031	Economy	10200.00
0005433341535	17031	Economy	10200.00
0005433341570	17031	Economy	10200.00
0005433341509	17031	Economy	10200.00
0005432389938	1341	Business	101000.00
0005432389958	1341	Business	101000.00
0005432389962	1341	Business	101000.00
0005432391951	1341	Business	101000.00
0005432389963	1341	Business	101000.00
0005432389935	1341	Business	101000.00
0005432389966	1341	Business	101000.00
0005432389942	1341	Economy	33700.00
0005432389954	1341	Economy	33700.00
0005432389933	1341	Economy	33700.00
0005432389936	1341	Economy	37000.00
0005432389961	1341	Economy	37000.00
0005432389967	1341	Economy	33700.00
0005432389956	1341	Economy	33700.00
0005432389943	1341	Economy	33700.00
0005432389941	1341	Economy	33700.00
0005432389934	1341	Economy	33700.00
0005432389946	1341	Economy	33700.00
0005432391946	1341	Economy	33700.00
0005432389944	1341	Economy	33700.00
0005432389952	1341	Economy	33700.00
0005432389949	1341	Economy	33700.00
0005432389939	1341	Economy	33700.00
0005432389955	1341	Economy	33700.00
0005432389957	1341	Economy	33700.00
0005432389945	1341	Economy	33700.00
0005432389964	1341	Economy	33700.00
0005432391945	1341	Economy	33700.00
0005432389959	1341	Economy	33700.00
0005432389960	1341	Economy	33700.00
0005432389950	1341	Economy	33700.00
0005432389951	1341	Economy	33700.00
0005432391947	1341	Economy	33700.00
0005432389953	1341	Economy	33700.00
0005432389948	1341	Economy	33700.00
0005432389937	1341	Economy	33700.00
0005432389947	1341	Economy	33700.00
0005432389965	1341	Economy	33700.00
0005432389940	1341	Economy	33700.00
0005432391950	1341	Economy	33700.00
0005432391948	1341	Economy	33700.00
0005432391949	1341	Economy	33700.00
0005432159784	12786	Business	40300.00
0005432159786	12786	Business	40300.00
0005432433597	12786	Business	40300.00
0005432159785	12786	Business	40300.00
0005432433593	12786	Economy	13400.00
0005432159787	12786	Economy	13400.00
0005432161116	12786	Economy	13400.00
0005432433594	12786	Economy	13400.00
0005433812863	12786	Economy	13400.00
0005433812862	12786	Economy	13400.00
0005432433596	12786	Economy	13400.00
0005432433595	12786	Economy	13400.00
0005432161115	12786	Economy	13400.00
0005432161114	12786	Economy	13400.00
0005432150066	30689	Business	40300.00
0005434066407	30689	Business	40300.00
0005432150064	30689	Business	40300.00
0005434081509	30689	Business	40300.00
0005434081498	30689	Business	40300.00
0005434066410	30689	Business	40300.00
0005434081504	30689	Business	40300.00
0005434066417	30689	Business	40300.00
0005434081520	30689	Business	40300.00
0005434081487	30689	Business	40300.00
0005432150070	30689	Business	40300.00
0005433989690	30689	Economy	13400.00
0005434081495	30689	Economy	13400.00
0005434066427	30689	Economy	13400.00
0005432150067	30689	Economy	13400.00
0005434081505	30689	Economy	13400.00
0005434081511	30689	Economy	13400.00
0005434066383	30689	Economy	13400.00
0005434066423	30689	Economy	13400.00
0005434066411	30689	Economy	13400.00
0005434081496	30689	Economy	13400.00
0005434081512	30689	Economy	13400.00
0005434066430	30689	Economy	13400.00
0005432186808	30689	Economy	13400.00
0005434081490	30689	Economy	13400.00
0005434066387	30689	Economy	13400.00
0005434066436	30689	Economy	13400.00
0005434081507	30689	Economy	13400.00
0005434066385	30689	Economy	13400.00
0005434066439	30689	Economy	13400.00
0005434066429	30689	Economy	13400.00
0005434066416	30689	Economy	13400.00
0005434066425	30689	Economy	13400.00
0005434081497	30689	Economy	13400.00
0005434066406	30689	Economy	13400.00
0005434066400	30689	Economy	13400.00
0005434066379	30689	Economy	13400.00
0005434066396	30689	Economy	13400.00
0005434066434	30689	Economy	13400.00
0005434066402	30689	Economy	13400.00
0005433989694	30689	Economy	13400.00
0005434066403	30689	Economy	13400.00
0005434066369	30689	Economy	13400.00
0005434066432	30689	Economy	13400.00
0005434081513	30689	Economy	13400.00
0005434081493	30689	Economy	13400.00
0005434066404	30689	Economy	13400.00
0005434066386	30689	Economy	13400.00
0005434066422	30689	Economy	13400.00
0005434081508	30689	Economy	14800.00
0005434066375	30689	Economy	14800.00
0005433989692	30689	Economy	14800.00
0005434081499	30689	Economy	14800.00
0005434066392	30689	Economy	14800.00
0005434066437	30689	Economy	14800.00
0005434066367	30689	Economy	13400.00
0005434066426	30689	Economy	13400.00
0005434066412	30689	Economy	13400.00
0005434081500	30689	Economy	13400.00
0005434066389	30689	Economy	13400.00
0005434066397	30689	Economy	13400.00
0005434081510	30689	Economy	13400.00
0005434066408	30689	Economy	13400.00
0005434066413	30689	Economy	13400.00
0005434066368	30689	Economy	13400.00
0005434066409	30689	Economy	13400.00
0005434081515	30689	Economy	13400.00
0005434066390	30689	Economy	13400.00
0005434066380	30689	Economy	13400.00
0005434066415	30689	Economy	13400.00
0005434066435	30689	Economy	13400.00
0005434066421	30689	Economy	13400.00
0005434066393	30689	Economy	13400.00
0005434081503	30689	Economy	13400.00
0005433989693	30689	Economy	13400.00
0005432150065	30689	Economy	13400.00
0005434066428	30689	Economy	13400.00
0005434066395	30689	Economy	13400.00
0005434066414	30689	Economy	13400.00
0005432150063	30689	Economy	13400.00
0005434066424	30689	Economy	13400.00
0005434081514	30689	Economy	13400.00
0005434066370	30689	Economy	13400.00
0005434066377	30689	Economy	13400.00
0005434066431	30689	Economy	13400.00
0005434081491	30689	Economy	13400.00
0005434066378	30689	Economy	13400.00
0005434066391	30689	Economy	13400.00
0005432150069	30689	Economy	13400.00
0005434066381	30689	Economy	13400.00
0005434066388	30689	Economy	13400.00
0005432150068	30689	Economy	13400.00
0005434081488	30689	Economy	13400.00
0005434081506	30689	Economy	13400.00
0005434066405	30689	Economy	13400.00
0005434081489	30689	Economy	13400.00
0005434066371	30689	Economy	13400.00
0005434081494	30689	Economy	13400.00
0005434081519	30689	Economy	13400.00
0005434066394	30689	Economy	13400.00
0005434066419	30689	Economy	13400.00
0005434081492	30689	Economy	13400.00
0005434066418	30689	Economy	13400.00
0005434081501	30689	Economy	13400.00
0005434066438	30689	Economy	13400.00
0005434066384	30689	Economy	13400.00
0005434066399	30689	Economy	13400.00
0005434066373	30689	Economy	13400.00
0005434081517	30689	Economy	13400.00
0005434066374	30689	Economy	13400.00
0005434066420	30689	Economy	13400.00
0005433989691	30689	Economy	13400.00
0005434066398	30689	Economy	13400.00
0005434066382	30689	Economy	13400.00
0005432186810	30689	Economy	13400.00
0005434066433	30689	Economy	13400.00
0005434081516	30689	Economy	13400.00
0005434066401	30689	Economy	13400.00
0005434066376	30689	Economy	13400.00
0005434081502	30689	Economy	13400.00
0005432186807	30689	Economy	13400.00
0005434066372	30689	Economy	13400.00
0005434081518	30689	Economy	13400.00
0005432186809	30689	Economy	13400.00
0005435765234	5507	Business	35300.00
0005435765237	5507	Business	35300.00
0005435765222	5507	Business	35300.00
0005435765287	5507	Business	35300.00
0005435765221	5507	Business	35300.00
0005435765267	5507	Business	35300.00
0005435765220	5507	Business	35300.00
0005435735060	5507	Business	35300.00
0005435720806	5507	Business	35300.00
0005435765275	5507	Business	35300.00
0005435765230	5507	Business	35300.00
0005432140315	5507	Business	35300.00
0005435765266	5507	Business	35300.00
0005435765274	5507	Business	35300.00
0005435765257	5507	Business	35300.00
0005435765235	5507	Business	35300.00
0005435722019	5507	Business	35300.00
0005435765270	5507	Economy	12900.00
0005432140317	5507	Economy	11800.00
0005435720804	5507	Economy	11800.00
0005435720805	5507	Economy	11800.00
0005435765240	5507	Economy	11800.00
0005433527209	5507	Economy	11800.00
0005435765223	5507	Economy	11800.00
0005435765271	5507	Economy	11800.00
0005433529219	5507	Economy	11800.00
0005433529220	5507	Economy	11800.00
0005435765286	5507	Economy	11800.00
0005432140322	5507	Economy	11800.00
0005435765268	5507	Economy	11800.00
0005435765279	5507	Economy	11800.00
0005435765219	5507	Economy	11800.00
0005435765254	5507	Economy	11800.00
0005432140319	5507	Economy	11800.00
0005435765278	5507	Economy	11800.00
0005435765285	5507	Economy	11800.00
0005435720803	5507	Economy	11800.00
0005435765248	5507	Economy	11800.00
0005435765226	5507	Economy	11800.00
0005435765233	5507	Economy	11800.00
0005435735062	5507	Economy	11800.00
0005435765288	5507	Economy	11800.00
0005435765249	5507	Economy	11800.00
0005435765250	5507	Economy	11800.00
0005435765283	5507	Economy	11800.00
0005435725517	5507	Economy	11800.00
0005435765215	5507	Economy	11800.00
0005435765277	5507	Economy	11800.00
0005435765264	5507	Economy	11800.00
0005435765261	5507	Economy	11800.00
0005435765252	5507	Economy	11800.00
0005435765262	5507	Economy	11800.00
0005435765258	5507	Economy	11800.00
0005435765218	5507	Economy	11800.00
0005435735064	5507	Economy	11800.00
0005435765280	5507	Economy	11800.00
0005433529221	5507	Economy	11800.00
0005435765253	5507	Economy	11800.00
0005435765229	5507	Economy	11800.00
0005432140318	5507	Economy	11800.00
0005435765260	5507	Economy	11800.00
0005435723012	5507	Economy	11800.00
0005435723011	5507	Economy	11800.00
0005435722017	5507	Economy	11800.00
0005435765265	5507	Economy	11800.00
0005435725519	5507	Economy	11800.00
0005435765225	5507	Economy	11800.00
0005435725518	5507	Economy	11800.00
0005435722018	5507	Economy	12900.00
0005435765269	5507	Economy	11800.00
0005433527208	5507	Economy	11800.00
0005435765236	5507	Economy	11800.00
0005435765259	5507	Economy	11800.00
0005432140321	5507	Economy	11800.00
0005435765256	5507	Economy	11800.00
0005435765241	5507	Economy	11800.00
0005435765255	5507	Economy	11800.00
0005435765244	5507	Economy	11800.00
0005435765243	5507	Economy	11800.00
0005435735061	5507	Economy	11800.00
0005433527207	5507	Economy	11800.00
0005435765284	5507	Economy	11800.00
0005432140316	5507	Economy	11800.00
0005435765232	5507	Economy	11800.00
0005435765239	5507	Economy	11800.00
0005435765238	5507	Economy	11800.00
0005435765245	5507	Economy	11800.00
0005435765231	5507	Economy	11800.00
0005435765276	5507	Economy	11800.00
0005435765272	5507	Economy	11800.00
0005435765251	5507	Economy	11800.00
0005433527210	5507	Economy	11800.00
0005435765228	5507	Economy	11800.00
0005435765282	5507	Economy	11800.00
0005435765227	5507	Economy	11800.00
0005435765273	5507	Economy	11800.00
0005435765246	5507	Economy	11800.00
0005435765247	5507	Economy	11800.00
0005435765263	5507	Economy	11800.00
0005435765242	5507	Economy	11800.00
0005435765281	5507	Economy	11800.00
0005435765216	5507	Economy	11800.00
0005435725520	5507	Economy	11800.00
0005432140320	5507	Economy	11800.00
0005435735063	5507	Economy	11800.00
0005435765224	5507	Economy	11800.00
0005435765217	5507	Economy	11800.00
0005432535756	13451	Business	35300.00
0005432194445	13451	Business	35300.00
0005434264733	13451	Business	35300.00
0005434264731	13451	Business	35300.00
0005435461847	13451	Business	35300.00
0005435461835	13451	Business	35300.00
0005434264728	13451	Business	35300.00
0005434264750	13451	Business	35300.00
0005435461855	13451	Business	35300.00
0005435461857	13451	Business	35300.00
0005434264748	13451	Economy	12900.00
0005434264742	13451	Economy	12900.00
0005435461858	13451	Economy	11800.00
0005435461865	13451	Economy	11800.00
0005435461843	13451	Economy	11800.00
0005435461868	13451	Economy	11800.00
0005435461862	13451	Economy	11800.00
0005435461844	13451	Economy	11800.00
0005434264738	13451	Economy	11800.00
0005434264744	13451	Economy	11800.00
0005435461852	13451	Economy	11800.00
0005435461853	13451	Economy	11800.00
0005434264743	13451	Economy	11800.00
0005434264734	13451	Economy	11800.00
0005434264753	13451	Economy	11800.00
0005435461860	13451	Economy	11800.00
0005435043274	13451	Economy	11800.00
0005435461842	13451	Economy	11800.00
0005435461845	13451	Economy	11800.00
0005435043273	13451	Economy	11800.00
0005434264739	13451	Economy	11800.00
0005435461833	13451	Economy	11800.00
0005435461854	13451	Economy	11800.00
0005434831079	13451	Economy	11800.00
0005434831078	13451	Economy	11800.00
0005434831081	13451	Economy	11800.00
0005434264740	13451	Economy	11800.00
0005435461872	13451	Economy	11800.00
0005434264735	13451	Economy	11800.00
0005434264732	13451	Economy	11800.00
0005432535758	13451	Economy	11800.00
0005434264729	13451	Economy	11800.00
0005435043275	13451	Economy	11800.00
0005435461859	13451	Economy	11800.00
0005434264746	13451	Economy	11800.00
0005435461863	13451	Economy	11800.00
0005434264749	13451	Economy	11800.00
0005435461838	13451	Economy	11800.00
0005435461848	13451	Economy	12900.00
0005435461870	13451	Economy	11800.00
0005434264752	13451	Economy	11800.00
0005432535759	13451	Economy	11800.00
0005435461849	13451	Economy	11800.00
0005435461839	13451	Economy	11800.00
0005432535757	13451	Economy	11800.00
0005434831077	13451	Economy	11800.00
0005435461840	13451	Economy	11800.00
0005432194444	13451	Economy	11800.00
0005432194446	13451	Economy	11800.00
0005435461867	13451	Economy	11800.00
0005435461834	13451	Economy	11800.00
0005435461837	13451	Economy	11800.00
0005434264747	13451	Economy	11800.00
0005434264751	13451	Economy	11800.00
0005435461866	13451	Economy	11800.00
0005434264737	13451	Economy	11800.00
0005435461856	13451	Economy	11800.00
0005435461836	13451	Economy	11800.00
0005435461846	13451	Economy	11800.00
0005434264730	13451	Economy	11800.00
0005435461871	13451	Economy	11800.00
0005432194447	13451	Economy	11800.00
0005434831076	13451	Economy	11800.00
0005435461841	13451	Economy	11800.00
0005435461861	13451	Economy	11800.00
0005434264736	13451	Economy	11800.00
0005435461869	13451	Economy	11800.00
0005434264741	13451	Economy	11800.00
0005434264745	13451	Economy	11800.00
0005435461850	13451	Economy	11800.00
0005434831080	13451	Economy	11800.00
0005435461851	13451	Economy	11800.00
0005435461864	13451	Economy	11800.00
0005434513537	18735	Economy	3300.00
0005434514925	18735	Economy	3300.00
0005434513536	18735	Economy	3300.00
0005434514924	18735	Economy	3300.00
0005435846195	25092	Economy	29400.00
0005435846194	25092	Economy	32400.00
0005435846197	25092	Economy	29400.00
0005435846199	25092	Economy	29400.00
0005435846192	25092	Economy	29400.00
0005435846196	25092	Economy	29400.00
0005435846198	25092	Economy	29400.00
0005435846193	25092	Economy	29400.00
0005432295838	1846	Business	48700.00
0005433810494	1846	Economy	16200.00
0005433810493	1846	Economy	16200.00
0005433810495	1846	Economy	16200.00
0005432295839	1846	Economy	16200.00
0005433007907	22565	Business	48700.00
0005433007888	22565	Business	48700.00
0005433284803	22565	Business	48700.00
0005433284806	22565	Business	48700.00
0005433007910	22565	Business	48700.00
0005433284810	22565	Business	48700.00
0005433007909	22565	Business	48700.00
0005433007900	22565	Business	48700.00
0005433284813	22565	Economy	16200.00
0005433007897	22565	Economy	16200.00
0005433007878	22565	Economy	16200.00
0005433007872	22565	Economy	16200.00
0005433007871	22565	Economy	16200.00
0005433284808	22565	Economy	16200.00
0005433007882	22565	Economy	16200.00
0005433007895	22565	Economy	17900.00
0005433007911	22565	Economy	17900.00
0005433284818	22565	Economy	17900.00
0005433007874	22565	Economy	17900.00
0005433007912	22565	Economy	16200.00
0005433007913	22565	Economy	16200.00
0005433007903	22565	Economy	16200.00
0005433007886	22565	Economy	16200.00
0005433284812	22565	Economy	16200.00
0005433284804	22565	Economy	16200.00
0005433284798	22565	Economy	16200.00
0005433007902	22565	Economy	16200.00
0005433007870	22565	Economy	16200.00
0005433284815	22565	Economy	16200.00
0005433284795	22565	Economy	16200.00
0005433007914	22565	Economy	16200.00
0005433284802	22565	Economy	16200.00
0005433007875	22565	Economy	16200.00
0005433007883	22565	Economy	16200.00
0005433007908	22565	Economy	16200.00
0005433007879	22565	Economy	16200.00
0005433007898	22565	Economy	16200.00
0005433007881	22565	Economy	16200.00
0005433007904	22565	Economy	16200.00
0005433284797	22565	Economy	16200.00
0005433284801	22565	Economy	16200.00
0005433284807	22565	Economy	16200.00
0005433284800	22565	Economy	16200.00
0005433007891	22565	Economy	16200.00
0005433007901	22565	Economy	16200.00
0005433284817	22565	Economy	16200.00
0005433007896	22565	Economy	16200.00
0005433007884	22565	Economy	16200.00
0005433284811	22565	Economy	16200.00
0005433007905	22565	Economy	16200.00
0005433284805	22565	Economy	16200.00
0005433007869	22565	Economy	16200.00
0005433007876	22565	Economy	16200.00
0005433284819	22565	Economy	16200.00
0005433007880	22565	Economy	16200.00
0005433007906	22565	Economy	16200.00
0005433007877	22565	Economy	16200.00
0005433007894	22565	Economy	16200.00
0005433007873	22565	Economy	16200.00
0005433284816	22565	Economy	16200.00
0005433007885	22565	Economy	16200.00
0005433007887	22565	Economy	16200.00
0005433007889	22565	Economy	16200.00
0005433284814	22565	Economy	16200.00
0005433007893	22565	Economy	16200.00
0005433007892	22565	Economy	16200.00
0005433007890	22565	Economy	16200.00
0005433284809	22565	Economy	16200.00
0005433284796	22565	Economy	16200.00
0005433007899	22565	Economy	16200.00
0005433284799	22565	Economy	16200.00
0005433007868	22565	Economy	16200.00
0005433284820	22565	Economy	16200.00
0005434152757	12285	Business	83800.00
0005434152751	12285	Economy	27900.00
0005434152754	12285	Economy	30700.00
0005434152752	12285	Economy	27900.00
0005434152756	12285	Economy	27900.00
0005434152753	12285	Economy	27900.00
0005434152759	12285	Economy	27900.00
0005434152755	12285	Economy	27900.00
0005434152758	12285	Economy	27900.00
0005433845814	5596	Business	99800.00
0005433845820	5596	Business	99800.00
0005432081410	5596	Business	99800.00
0005433845819	5596	Business	99800.00
0005433845836	5596	Business	99800.00
0005433845796	5596	Business	99800.00
0005433845823	5596	Business	99800.00
0005433845826	5596	Business	99800.00
0005433815307	5596	Business	99800.00
0005433845808	5596	Business	99800.00
0005433845831	5596	Business	99800.00
0005433845797	5596	Business	99800.00
0005432081413	5596	Business	99800.00
0005432081407	5596	Business	99800.00
0005433845807	5596	Economy	33300.00
0005433845839	5596	Economy	33300.00
0005433845815	5596	Economy	33300.00
0005433845828	5596	Economy	33300.00
0005433845813	5596	Economy	33300.00
0005433845818	5596	Economy	33300.00
0005433845821	5596	Economy	33300.00
0005433845789	5596	Economy	33300.00
0005433845783	5596	Economy	33300.00
0005433845794	5596	Economy	33300.00
0005433845799	5596	Economy	33300.00
0005433845834	5596	Economy	33300.00
0005433845842	5596	Economy	33300.00
0005433845809	5596	Economy	33300.00
0005433845829	5596	Economy	33300.00
0005433845812	5596	Economy	33300.00
0005433845803	5596	Economy	33300.00
0005433845801	5596	Economy	33300.00
0005433845805	5596	Economy	33300.00
0005433845840	5596	Economy	33300.00
0005433845788	5596	Economy	33300.00
0005433845784	5596	Economy	33300.00
0005433845835	5596	Economy	33300.00
0005433845827	5596	Economy	33300.00
0005433845804	5596	Economy	33300.00
0005433845837	5596	Economy	33300.00
0005433845790	5596	Economy	33300.00
0005432081412	5596	Economy	33300.00
0005433845833	5596	Economy	33300.00
0005433845822	5596	Economy	33300.00
0005433845798	5596	Economy	33300.00
0005433815309	5596	Economy	33300.00
0005432081409	5596	Economy	33300.00
0005433845786	5596	Economy	33300.00
0005433845810	5596	Economy	33300.00
0005433845841	5596	Economy	33300.00
0005433845830	5596	Economy	33300.00
0005433845793	5596	Economy	33300.00
0005433845787	5596	Economy	33300.00
0005433845824	5596	Economy	33300.00
0005433845817	5596	Economy	33300.00
0005432081408	5596	Economy	33300.00
0005433845806	5596	Economy	33300.00
0005433845816	5596	Economy	33300.00
0005433845838	5596	Economy	33300.00
0005433845792	5596	Economy	33300.00
0005433845802	5596	Economy	33300.00
0005433845800	5596	Economy	33300.00
0005433815306	5596	Economy	33300.00
0005433845795	5596	Economy	33300.00
0005433815308	5596	Economy	33300.00
0005433845785	5596	Economy	33300.00
0005433845791	5596	Economy	33300.00
0005432081411	5596	Economy	33300.00
0005433845825	5596	Economy	33300.00
0005433845811	5596	Economy	33300.00
0005433845832	5596	Economy	33300.00
0005435282119	13836	Business	99800.00
0005435282100	13836	Business	99800.00
0005435282105	13836	Economy	33300.00
0005435282103	13836	Economy	33300.00
0005432003653	13836	Economy	33300.00
0005435282108	13836	Economy	33300.00
0005435282113	13836	Economy	33300.00
0005435282114	13836	Economy	33300.00
0005435282121	13836	Economy	33300.00
0005435282102	13836	Economy	33300.00
0005435282111	13836	Economy	33300.00
0005434173459	13836	Economy	33300.00
0005435282120	13836	Economy	33300.00
0005434173458	13836	Economy	33300.00
0005435282099	13836	Economy	33300.00
0005432003652	13836	Economy	33300.00
0005435282118	13836	Economy	33300.00
0005434173456	13836	Economy	33300.00
0005435282112	13836	Economy	33300.00
0005435282101	13836	Economy	33300.00
0005435282096	13836	Economy	33300.00
0005435282110	13836	Economy	33300.00
0005432003654	13836	Economy	33300.00
0005435282115	13836	Economy	33300.00
0005435282117	13836	Economy	33300.00
0005435282097	13836	Economy	33300.00
0005435282106	13836	Economy	33300.00
0005435282098	13836	Economy	33300.00
0005435282116	13836	Economy	33300.00
0005435282123	13836	Economy	33300.00
0005432003651	13836	Economy	33300.00
0005435282122	13836	Economy	33300.00
0005435282107	13836	Economy	33300.00
0005435282104	13836	Economy	33300.00
0005434173457	13836	Economy	33300.00
0005432003655	13836	Economy	33300.00
0005435282109	13836	Economy	33300.00
0005434620274	7815	Economy	16600.00
0005434620282	7815	Economy	15100.00
0005434620272	7815	Economy	15100.00
0005434620270	7815	Economy	15100.00
0005434620268	7815	Economy	15100.00
0005434620276	7815	Economy	15100.00
0005434620275	7815	Economy	15100.00
0005434620265	7815	Economy	15100.00
0005434620281	7815	Economy	15100.00
0005434620269	7815	Economy	15100.00
0005434620273	7815	Economy	15100.00
0005434620284	7815	Economy	15100.00
0005432112481	7815	Economy	15100.00
0005434620271	7815	Economy	15100.00
0005434620266	7815	Economy	15100.00
0005434620279	7815	Economy	15100.00
0005434620283	7815	Economy	15100.00
0005434620277	7815	Economy	15100.00
0005434620267	7815	Economy	15100.00
0005434620264	7815	Economy	15100.00
0005432112480	7815	Economy	15100.00
0005434620278	7815	Economy	15100.00
0005434620280	7815	Economy	15100.00
0005435332170	32978	Economy	15100.00
0005435332168	32978	Economy	15100.00
0005435332173	32978	Economy	15100.00
0005435332172	32978	Economy	15100.00
0005435332169	32978	Economy	15100.00
0005435332175	32978	Economy	15100.00
0005435332171	32978	Economy	15100.00
0005435332174	32978	Economy	15100.00
0005435332176	32978	Economy	15100.00
0005435332177	32978	Economy	15100.00
0005435784808	4285	Business	38000.00
0005435784804	4285	Business	38000.00
0005435784821	4285	Business	38000.00
0005435784827	4285	Business	38000.00
0005435784807	4285	Business	38000.00
0005435784799	4285	Economy	12700.00
0005434993872	4285	Economy	12700.00
0005435784805	4285	Economy	12700.00
0005435784829	4285	Economy	12700.00
0005435784809	4285	Economy	13900.00
0005435784819	4285	Economy	13900.00
0005435784824	4285	Economy	12700.00
0005435784820	4285	Economy	12700.00
0005435784831	4285	Economy	12700.00
0005435784811	4285	Economy	12700.00
0005435784816	4285	Economy	12700.00
0005435784814	4285	Economy	12700.00
0005435784832	4285	Economy	12700.00
0005434993865	4285	Economy	12700.00
0005434993874	4285	Economy	12700.00
0005434993869	4285	Economy	12700.00
0005435784815	4285	Economy	12700.00
0005432190570	4285	Economy	12700.00
0005435784801	4285	Economy	12700.00
0005435784806	4285	Economy	12700.00
0005434993870	4285	Economy	12700.00
0005435784800	4285	Economy	12700.00
0005435784818	4285	Economy	12700.00
0005435784825	4285	Economy	12700.00
0005434993867	4285	Economy	12700.00
0005435784830	4285	Economy	12700.00
0005434993875	4285	Economy	12700.00
0005435784817	4285	Economy	12700.00
0005435784812	4285	Economy	12700.00
0005435787323	4285	Economy	12700.00
0005435784810	4285	Economy	12700.00
0005435787322	4285	Economy	12700.00
0005435784822	4285	Economy	12700.00
0005435784823	4285	Economy	12700.00
0005432190568	4285	Economy	12700.00
0005435784828	4285	Economy	12700.00
0005434993871	4285	Economy	12700.00
0005434993873	4285	Economy	12700.00
0005432190569	4285	Economy	12700.00
0005435784813	4285	Economy	12700.00
0005435784826	4285	Economy	12700.00
0005434993866	4285	Economy	12700.00
0005435784802	4285	Economy	12700.00
0005434993868	4285	Economy	12700.00
0005435784833	4285	Economy	12700.00
0005435784803	4285	Economy	12700.00
0005435918581	27290	Business	38000.00
0005435918580	27290	Business	38000.00
0005432195659	27290	Business	38000.00
0005432195658	27290	Economy	12700.00
0005435937316	27290	Economy	13900.00
0005435937315	27290	Economy	12700.00
0005435918582	27290	Economy	12700.00
0005435937318	27290	Economy	12700.00
0005435918579	27290	Economy	12700.00
0005435937317	27290	Economy	12700.00
0005435918583	27290	Economy	12700.00
0005435937314	27290	Economy	12700.00
0005432146166	19858	Economy	12800.00
0005432459054	4705	Business	40900.00
0005434081531	4705	Business	40900.00
0005432170279	4705	Business	40900.00
0005432170281	4705	Business	40900.00
0005432170278	4705	Business	40900.00
0005434081538	4705	Business	40900.00
0005432566708	4705	Business	40900.00
0005432170283	4705	Business	40900.00
0005432566661	4705	Business	40900.00
0005432571261	4705	Business	40900.00
0005432459032	4705	Business	40900.00
0005432566681	4705	Business	40900.00
0005432459038	4705	Business	40900.00
0005434081539	4705	Business	40900.00
0005432566687	4705	Business	40900.00
0005432186811	4705	Business	40900.00
0005432459015	4705	Business	40900.00
0005434081549	4705	Business	40900.00
0005432566690	4705	Business	40900.00
0005432566682	4705	Business	40900.00
0005434081526	4705	Business	40900.00
0005432566684	4705	Business	40900.00
0005432566657	4705	Economy	15000.00
0005433452707	4705	Economy	15000.00
0005432459016	4705	Economy	15000.00
0005432566664	4705	Economy	15000.00
0005432459027	4705	Economy	13600.00
0005432459010	4705	Economy	13600.00
0005432566702	4705	Economy	13600.00
0005432459035	4705	Economy	13600.00
0005432566700	4705	Economy	13600.00
0005432459037	4705	Economy	13600.00
0005432459050	4705	Economy	13600.00
0005432566653	4705	Economy	13600.00
0005434081525	4705	Economy	13600.00
0005432566674	4705	Economy	13600.00
0005432566656	4705	Economy	13600.00
0005432459033	4705	Economy	13600.00
0005432459030	4705	Economy	13600.00
0005434081544	4705	Economy	13600.00
0005432459029	4705	Economy	13600.00
0005433451588	4705	Economy	13600.00
0005434081536	4705	Economy	13600.00
0005432459055	4705	Economy	13600.00
0005432566695	4705	Economy	13600.00
0005434081541	4705	Economy	13600.00
0005432459043	4705	Economy	13600.00
0005432566678	4705	Economy	13600.00
0005432186812	4705	Economy	13600.00
0005432459062	4705	Economy	13600.00
0005432459013	4705	Economy	13600.00
0005432566703	4705	Economy	13600.00
0005434081546	4705	Economy	13600.00
0005432459040	4705	Economy	13600.00
0005432566677	4705	Economy	13600.00
0005432566706	4705	Economy	13600.00
0005434081540	4705	Economy	13600.00
0005432459057	4705	Economy	13600.00
0005432566676	4705	Economy	13600.00
0005432459046	4705	Economy	13600.00
0005434081521	4705	Economy	13600.00
0005432566671	4705	Economy	13600.00
0005432566693	4705	Economy	13600.00
0005434081534	4705	Economy	13600.00
0005432566683	4705	Economy	13600.00
0005432459023	4705	Economy	13600.00
0005434081543	4705	Economy	13600.00
0005434081547	4705	Economy	13600.00
0005432566712	4705	Economy	13600.00
0005432566651	4705	Economy	13600.00
0005432170280	4705	Economy	13600.00
0005432566663	4705	Economy	13600.00
0005432566699	4705	Economy	13600.00
0005432566705	4705	Economy	13600.00
0005432459017	4705	Economy	13600.00
0005433726067	4705	Economy	13600.00
0005432566679	4705	Economy	13600.00
0005432459028	4705	Economy	13600.00
0005432459025	4705	Economy	13600.00
0005432459060	4705	Economy	13600.00
0005432566692	4705	Economy	13600.00
0005432566696	4705	Economy	13600.00
0005432459044	4705	Economy	13600.00
0005432459022	4705	Economy	13600.00
0005432566710	4705	Economy	13600.00
0005432459056	4705	Economy	13600.00
0005432566697	4705	Economy	13600.00
0005434081528	4705	Economy	13600.00
0005432459026	4705	Economy	13600.00
0005432566673	4705	Economy	13600.00
0005432459048	4705	Economy	13600.00
0005432566652	4705	Economy	13600.00
0005432566701	4705	Economy	13600.00
0005434081523	4705	Economy	13600.00
0005432566670	4705	Economy	13600.00
0005432571263	4705	Economy	13600.00
0005434081542	4705	Economy	13600.00
0005432459014	4705	Economy	13600.00
0005433452706	4705	Economy	13600.00
0005433451587	4705	Economy	13600.00
0005432459020	4705	Economy	13600.00
0005432459011	4705	Economy	15000.00
0005432459051	4705	Economy	15000.00
0005432459012	4705	Economy	13600.00
0005432170282	4705	Economy	13600.00
0005432566658	4705	Economy	13600.00
0005432566711	4705	Economy	15000.00
0005432459047	4705	Economy	15000.00
0005432566689	4705	Economy	13600.00
0005432566655	4705	Economy	13600.00
0005432566659	4705	Economy	13600.00
0005434081529	4705	Economy	13600.00
0005432459031	4705	Economy	13600.00
0005434081535	4705	Economy	13600.00
0005432566704	4705	Economy	13600.00
0005432459036	4705	Economy	13600.00
0005432566707	4705	Economy	13600.00
0005432459053	4705	Economy	13600.00
0005432459019	4705	Economy	13600.00
0005432566669	4705	Economy	13600.00
0005432459058	4705	Economy	13600.00
0005432459021	4705	Economy	13600.00
0005432459041	4705	Economy	13600.00
0005432459024	4705	Economy	13600.00
0005432459059	4705	Economy	13600.00
0005432459039	4705	Economy	13600.00
0005434081530	4705	Economy	13600.00
0005432459042	4705	Economy	13600.00
0005432566665	4705	Economy	13600.00
0005432566672	4705	Economy	13600.00
0005432186813	4705	Economy	13600.00
0005434081545	4705	Economy	13600.00
0005432170284	4705	Economy	13600.00
0005434081550	4705	Economy	13600.00
0005432459018	4705	Economy	13600.00
0005432566666	4705	Economy	13600.00
0005432566688	4705	Economy	13600.00
0005432186814	4705	Economy	13600.00
0005434081527	4705	Economy	13600.00
0005432566698	4705	Economy	13600.00
0005432566660	4705	Economy	13600.00
0005434081524	4705	Economy	13600.00
0005432566709	4705	Economy	13600.00
0005434081537	4705	Economy	13600.00
0005432459052	4705	Economy	13600.00
0005432571262	4705	Economy	13600.00
0005432566686	4705	Economy	13600.00
0005432566694	4705	Economy	13600.00
0005434081533	4705	Economy	13600.00
0005434081532	4705	Economy	13600.00
0005434081548	4705	Economy	13600.00
0005432459049	4705	Economy	13600.00
0005432459045	4705	Economy	13600.00
0005434081522	4705	Economy	13600.00
0005432566691	4705	Economy	13600.00
0005432566680	4705	Economy	13600.00
0005432566668	4705	Economy	13600.00
0005432566685	4705	Economy	13600.00
0005432566654	4705	Economy	13600.00
0005433726069	4705	Economy	13600.00
0005432566675	4705	Economy	13600.00
0005432459034	4705	Economy	13600.00
0005432566667	4705	Economy	13600.00
0005432459061	4705	Economy	13600.00
0005432566662	4705	Economy	13600.00
0005433726068	4705	Economy	13600.00
0005432213546	30559	Business	40900.00
0005432213547	30559	Business	40900.00
0005432213549	30559	Economy	13600.00
0005432161114	30559	Economy	13600.00
0005432213548	30559	Economy	13600.00
0005432161115	30559	Economy	13600.00
0005432161116	30559	Economy	13600.00
0005435720805	13618	Economy	9900.00
0005435722018	13618	Economy	9900.00
0005435720803	13618	Economy	9900.00
0005435720804	13618	Economy	9900.00
0005435722019	13618	Economy	9900.00
0005435722017	13618	Economy	9900.00
0005435720806	13618	Economy	9900.00
0005432295838	22779	Economy	8800.00
0005432295839	22779	Economy	8800.00
0005433341645	11079	Business	23600.00
0005433341680	11079	Business	23600.00
0005433341601	11079	Business	23600.00
0005433341661	11079	Business	23600.00
0005435097058	11079	Business	23600.00
0005433341646	11079	Business	23600.00
0005433341666	11079	Business	23600.00
0005433341608	11079	Business	23600.00
0005433341596	11079	Business	23600.00
0005433341595	11079	Business	23600.00
0005433341617	11079	Economy	7900.00
0005433341616	11079	Economy	7900.00
0005433341642	11079	Economy	7900.00
0005433341648	11079	Economy	7900.00
0005433341638	11079	Economy	7900.00
0005433341650	11079	Economy	7900.00
0005433341583	11079	Economy	7900.00
0005433341618	11079	Economy	7900.00
0005433341677	11079	Economy	7900.00
0005433341678	11079	Economy	7900.00
0005433341673	11079	Economy	7900.00
0005433341637	11079	Economy	7900.00
0005433341656	11079	Economy	7900.00
0005433341681	11079	Economy	7900.00
0005433341647	11079	Economy	7900.00
0005433341667	11079	Economy	7900.00
0005433341672	11079	Economy	7900.00
0005433341633	11079	Economy	7900.00
0005433341652	11079	Economy	7900.00
0005433341655	11079	Economy	7900.00
0005433341599	11079	Economy	7900.00
0005433341603	11079	Economy	7900.00
0005433341622	11079	Economy	7900.00
0005433341620	11079	Economy	7900.00
0005435097059	11079	Economy	7900.00
0005433341636	11079	Economy	7900.00
0005433341671	11079	Economy	7900.00
0005433341676	11079	Economy	7900.00
0005433341659	11079	Economy	7900.00
0005433341590	11079	Economy	7900.00
0005435097053	11079	Economy	7900.00
0005433341589	11079	Economy	7900.00
0005433341682	11079	Economy	7900.00
0005433341651	11079	Economy	7900.00
0005433341594	11079	Economy	8600.00
0005433341613	11079	Economy	8600.00
0005433341598	11079	Economy	8600.00
0005433341630	11079	Economy	8600.00
0005433341624	11079	Economy	8600.00
0005433341629	11079	Economy	8600.00
0005433341649	11079	Economy	7900.00
0005435097052	11079	Economy	7900.00
0005433341597	11079	Economy	7900.00
0005433341610	11079	Economy	7900.00
0005435097056	11079	Economy	7900.00
0005433341658	11079	Economy	7900.00
0005433341631	11079	Economy	7900.00
0005433341611	11079	Economy	7900.00
0005433341607	11079	Economy	7900.00
0005433341587	11079	Economy	7900.00
0005433341621	11079	Economy	7900.00
0005433341668	11079	Economy	7900.00
0005433341604	11079	Economy	7900.00
0005433341593	11079	Economy	7900.00
0005433341606	11079	Economy	7900.00
0005433341644	11079	Economy	7900.00
0005433341632	11079	Economy	7900.00
0005433341635	11079	Economy	7900.00
0005433341614	11079	Economy	7900.00
0005435097057	11079	Economy	7900.00
0005433341584	11079	Economy	7900.00
0005433341665	11079	Economy	7900.00
0005433341634	11079	Economy	7900.00
0005433341628	11079	Economy	7900.00
0005433341663	11079	Economy	7900.00
0005433341679	11079	Economy	7900.00
0005433341605	11079	Economy	7900.00
0005433341653	11079	Economy	7900.00
0005433341627	11079	Economy	7900.00
0005433341625	11079	Economy	7900.00
0005433341641	11079	Economy	7900.00
0005435097055	11079	Economy	7900.00
0005433341600	11079	Economy	7900.00
0005433341602	11079	Economy	7900.00
0005433341623	11079	Economy	7900.00
0005433341615	11079	Economy	7900.00
0005433341683	11079	Economy	7900.00
0005433341669	11079	Economy	7900.00
0005433341674	11079	Economy	7900.00
0005433341662	11079	Economy	7900.00
0005433341643	11079	Economy	7900.00
0005433341640	11079	Economy	7900.00
0005433341639	11079	Economy	7900.00
0005433341619	11079	Economy	7900.00
0005435097054	11079	Economy	7900.00
0005433341592	11079	Economy	7900.00
0005433341660	11079	Economy	7900.00
0005433341670	11079	Economy	7900.00
0005433341586	11079	Economy	7900.00
0005433341654	11079	Economy	7900.00
0005433341609	11079	Economy	7900.00
0005433341591	11079	Economy	7900.00
0005433341657	11079	Economy	7900.00
0005433341664	11079	Economy	7900.00
0005433341626	11079	Economy	7900.00
0005433341588	11079	Economy	7900.00
0005433341612	11079	Economy	7900.00
0005433341675	11079	Economy	7900.00
0005433341585	11079	Economy	7900.00
0005432293170	17107	Economy	7900.00
0005432293169	17107	Economy	7900.00
0005435545614	17107	Economy	7900.00
0005435545613	17107	Economy	7900.00
0005435380227	17107	Economy	7900.00
0005435545616	17107	Economy	7900.00
0005435380226	17107	Economy	7900.00
0005435380224	17107	Economy	7900.00
0005435380225	17107	Economy	7900.00
0005435545615	17107	Economy	7900.00
0005433481047	9085	Business	26600.00
0005433506909	9085	Business	26600.00
0005433506911	9085	Business	26600.00
0005433506908	9085	Business	26600.00
0005433506897	9085	Business	26600.00
0005433481048	9085	Economy	8900.00
0005433506898	9085	Economy	8900.00
0005433481045	9085	Economy	9800.00
0005433506893	9085	Economy	8900.00
0005433506910	9085	Economy	8900.00
0005433506896	9085	Economy	8900.00
0005433506903	9085	Economy	8900.00
0005433506891	9085	Economy	8900.00
0005433506895	9085	Economy	8900.00
0005433506904	9085	Economy	8900.00
0005433506892	9085	Economy	8900.00
0005433506906	9085	Economy	8900.00
0005433481049	9085	Economy	8900.00
0005433506902	9085	Economy	8900.00
0005433481044	9085	Economy	8900.00
0005433506901	9085	Economy	8900.00
0005433506905	9085	Economy	8900.00
0005433481046	9085	Economy	8900.00
0005433506894	9085	Economy	8900.00
0005433481050	9085	Economy	8900.00
0005433506899	9085	Economy	8900.00
0005433506900	9085	Economy	8900.00
0005433506907	9085	Economy	8900.00
0005432919558	20475	Business	26600.00
0005432919550	20475	Business	26600.00
0005432919565	20475	Business	26600.00
0005432919548	20475	Economy	8900.00
0005434158950	20475	Economy	8900.00
0005432919555	20475	Economy	8900.00
0005432919564	20475	Economy	9800.00
0005434158949	20475	Economy	9800.00
0005432919566	20475	Economy	8900.00
0005432919551	20475	Economy	8900.00
0005432919562	20475	Economy	8900.00
0005432919559	20475	Economy	8900.00
0005432919557	20475	Economy	8900.00
0005432919561	20475	Economy	8900.00
0005432919553	20475	Economy	8900.00
0005434158947	20475	Economy	8900.00
0005432919560	20475	Economy	8900.00
0005434158948	20475	Economy	8900.00
0005432919549	20475	Economy	8900.00
0005432919547	20475	Economy	8900.00
0005432919554	20475	Economy	8900.00
0005432919552	20475	Economy	8900.00
0005432919546	20475	Economy	8900.00
0005432919563	20475	Economy	8900.00
0005432919556	20475	Economy	8900.00
0005432394036	10164	Economy	5800.00
0005432394037	10164	Economy	5800.00
0005432396178	10164	Economy	5800.00
0005432396175	10164	Economy	5800.00
0005432394038	10164	Economy	5800.00
0005432396176	10164	Economy	5800.00
0005432396177	10164	Economy	5800.00
0005432394039	10164	Economy	5800.00
0005435179384	18304	Economy	5800.00
0005435179688	18304	Economy	5800.00
0005435179383	18304	Economy	5800.00
0005434928257	10935	Business	9500.00
0005434411713	10935	Economy	3200.00
0005434928255	10935	Economy	3200.00
0005434411714	10935	Economy	3200.00
0005434411712	10935	Economy	3200.00
0005434411711	10935	Economy	3200.00
0005434928256	10935	Economy	3200.00
0005434411710	10935	Economy	3200.00
0005434928254	10935	Economy	3200.00
0005435125740	14726	Business	9500.00
0005435554112	14726	Business	9500.00
0005435125732	14726	Business	9500.00
0005435125765	14726	Business	9500.00
0005435125735	14726	Business	9500.00
0005435125739	14726	Business	9500.00
0005435125748	14726	Business	9500.00
0005435125753	14726	Business	9500.00
0005435125771	14726	Economy	3200.00
0005435125733	14726	Economy	3200.00
0005435125744	14726	Economy	3200.00
0005435625909	14726	Economy	3200.00
0005435125760	14726	Economy	3200.00
0005435125734	14726	Economy	3200.00
0005435125743	14726	Economy	3500.00
0005435625911	14726	Economy	3500.00
0005435554109	14726	Economy	3500.00
0005435125756	14726	Economy	3200.00
0005435625906	14726	Economy	3200.00
0005435556653	14726	Economy	3200.00
0005435625908	14726	Economy	3200.00
0005435125761	14726	Economy	3200.00
0005435554110	14726	Economy	3200.00
0005435625904	14726	Economy	3200.00
0005435625902	14726	Economy	3200.00
0005435125736	14726	Economy	3200.00
0005435125730	14726	Economy	3200.00
0005435125755	14726	Economy	3200.00
0005435625905	14726	Economy	3200.00
0005435125768	14726	Economy	3200.00
0005435125737	14726	Economy	3200.00
0005435625900	14726	Economy	3200.00
0005435125759	14726	Economy	3200.00
0005435125751	14726	Economy	3200.00
0005435554111	14726	Economy	3200.00
0005435556651	14726	Economy	3200.00
0005435125754	14726	Economy	3200.00
0005435625912	14726	Economy	3200.00
0005435556652	14726	Economy	3200.00
0005435625903	14726	Economy	3200.00
0005435125747	14726	Economy	3200.00
0005435554108	14726	Economy	3200.00
0005435125752	14726	Economy	3200.00
0005435125749	14726	Economy	3200.00
0005435125763	14726	Economy	3200.00
0005435125764	14726	Economy	3200.00
0005435125766	14726	Economy	3200.00
0005435125769	14726	Economy	3200.00
0005435125746	14726	Economy	3200.00
0005435125767	14726	Economy	3200.00
0005435125745	14726	Economy	3200.00
0005435125731	14726	Economy	3200.00
0005435125741	14726	Economy	3200.00
0005435125770	14726	Economy	3200.00
0005435125742	14726	Economy	3200.00
0005435125762	14726	Economy	3200.00
0005435125738	14726	Economy	3200.00
0005435625901	14726	Economy	3200.00
0005435625910	14726	Economy	3200.00
0005435625907	14726	Economy	3200.00
0005435125750	14726	Economy	3200.00
0005435125758	14726	Economy	3200.00
0005435125757	14726	Economy	3200.00
0005435715199	7107	Business	86900.00
0005435715201	7107	Business	86900.00
0005432398138	7107	Business	86900.00
0005432398136	7107	Business	86900.00
0005432400067	7107	Business	86900.00
0005432400065	7107	Business	86900.00
0005432400066	7107	Economy	29000.00
0005432398141	7107	Economy	29000.00
0005435715203	7107	Economy	29000.00
0005435715206	7107	Economy	29000.00
0005435715197	7107	Economy	29000.00
0005435715204	7107	Economy	31900.00
0005435715209	7107	Economy	31900.00
0005435715210	7107	Economy	29000.00
0005432398137	7107	Economy	29000.00
0005435715198	7107	Economy	29000.00
0005435715196	7107	Economy	29000.00
0005435715194	7107	Economy	29000.00
0005432398139	7107	Economy	29000.00
0005435715195	7107	Economy	29000.00
0005435715208	7107	Economy	29000.00
0005435715205	7107	Economy	29000.00
0005435715211	7107	Economy	29000.00
0005432400068	7107	Economy	29000.00
0005432398140	7107	Economy	29000.00
0005435715202	7107	Economy	29000.00
0005435715207	7107	Economy	29000.00
0005435715200	7107	Economy	29000.00
0005435178470	27100	Business	86900.00
0005435443164	27100	Business	86900.00
0005435443165	27100	Economy	29000.00
0005435178977	27100	Economy	29000.00
0005435443168	27100	Economy	29000.00
0005435443171	27100	Economy	29000.00
0005435443163	27100	Economy	29000.00
0005435443169	27100	Economy	29000.00
0005435178469	27100	Economy	29000.00
0005435443170	27100	Economy	29000.00
0005435443172	27100	Economy	29000.00
0005435443166	27100	Economy	29000.00
0005435443167	27100	Economy	29000.00
0005434084859	2734	Economy	7700.00
0005434084860	2734	Economy	7700.00
0005434084858	2734	Economy	7700.00
0005433060371	28467	Economy	7700.00
0005433060370	28467	Economy	7700.00
0005433060372	28467	Economy	7700.00
0005435528913	22230	Business	20200.00
0005435528920	22230	Business	20200.00
0005435528912	22230	Business	20200.00
0005435540649	22230	Business	20200.00
0005435540646	22230	Business	20200.00
0005435540644	22230	Business	20200.00
0005435540653	22230	Business	20200.00
0005435540664	22230	Economy	6700.00
0005435528905	22230	Economy	6700.00
0005435540647	22230	Economy	6700.00
0005435528917	22230	Economy	6700.00
0005435540645	22230	Economy	7400.00
0005435540659	22230	Economy	7400.00
0005435528907	22230	Economy	6700.00
0005435540657	22230	Economy	6700.00
0005432294448	22230	Economy	6700.00
0005435528921	22230	Economy	6700.00
0005432294449	22230	Economy	6700.00
0005435540656	22230	Economy	6700.00
0005435528919	22230	Economy	6700.00
0005435540663	22230	Economy	6700.00
0005435540648	22230	Economy	6700.00
0005435528908	22230	Economy	6700.00
0005435540661	22230	Economy	6700.00
0005435540658	22230	Economy	6700.00
0005435528901	22230	Economy	6700.00
0005435540650	22230	Economy	6700.00
0005435528915	22230	Economy	6700.00
0005435528902	22230	Economy	6700.00
0005435540666	22230	Economy	6700.00
0005435540665	22230	Economy	6700.00
0005435540651	22230	Economy	6700.00
0005435528906	22230	Economy	6700.00
0005435528909	22230	Economy	6700.00
0005435540655	22230	Economy	6700.00
0005435540662	22230	Economy	6700.00
0005435528914	22230	Economy	6700.00
0005435528910	22230	Economy	6700.00
0005435528918	22230	Economy	6700.00
0005435528916	22230	Economy	6700.00
0005435528911	22230	Economy	6700.00
0005435540654	22230	Economy	6700.00
0005432294447	22230	Economy	6700.00
0005435528904	22230	Economy	6700.00
0005435540652	22230	Economy	6700.00
0005435528903	22230	Economy	6700.00
0005435540660	22230	Economy	6700.00
0005434906472	2261	Business	20200.00
0005434906460	2261	Business	20200.00
0005434906480	2261	Business	20200.00
0005434906471	2261	Business	20200.00
0005434906511	2261	Business	20200.00
0005434906470	2261	Business	20200.00
0005434906494	2261	Business	20200.00
0005434906500	2261	Business	20200.00
0005434906482	2261	Economy	6700.00
0005434906490	2261	Economy	6700.00
0005434906496	2261	Economy	6700.00
0005434906499	2261	Economy	6700.00
0005434906501	2261	Economy	6700.00
0005434906465	2261	Economy	7400.00
0005434906486	2261	Economy	7400.00
0005434906469	2261	Economy	6700.00
0005434906468	2261	Economy	6700.00
0005434906492	2261	Economy	6700.00
0005434906458	2261	Economy	6700.00
0005434906485	2261	Economy	6700.00
0005434906457	2261	Economy	6700.00
0005434906515	2261	Economy	6700.00
0005434906479	2261	Economy	6700.00
0005434906497	2261	Economy	6700.00
0005434906476	2261	Economy	6700.00
0005434906493	2261	Economy	6700.00
0005434906504	2261	Economy	6700.00
0005434906508	2261	Economy	6700.00
0005434906513	2261	Economy	6700.00
0005434906489	2261	Economy	6700.00
0005434906506	2261	Economy	6700.00
0005434906510	2261	Economy	6700.00
0005434906466	2261	Economy	6700.00
0005434906507	2261	Economy	6700.00
0005434906491	2261	Economy	6700.00
0005434906478	2261	Economy	6700.00
0005434906459	2261	Economy	6700.00
0005434906484	2261	Economy	6700.00
0005434906473	2261	Economy	6700.00
0005434906474	2261	Economy	6700.00
0005434906498	2261	Economy	6700.00
0005433400929	2261	Economy	6700.00
0005434906505	2261	Economy	6700.00
0005434906488	2261	Economy	6700.00
0005434906509	2261	Economy	6700.00
0005434906456	2261	Economy	6700.00
0005434906503	2261	Economy	6700.00
0005434906481	2261	Economy	6700.00
0005434906512	2261	Economy	6700.00
0005434906463	2261	Economy	6700.00
0005434906461	2261	Economy	6700.00
0005434906483	2261	Economy	6700.00
0005434906477	2261	Economy	6700.00
0005434906487	2261	Economy	6700.00
0005434906502	2261	Economy	6700.00
0005434906475	2261	Economy	6700.00
0005434906464	2261	Economy	6700.00
0005434906495	2261	Economy	6700.00
0005434906514	2261	Economy	6700.00
0005434906467	2261	Economy	6700.00
0005434906462	2261	Economy	6700.00
0005433250991	25615	Business	20200.00
0005433400939	25615	Business	20200.00
0005433250990	25615	Economy	6700.00
0005433251004	25615	Economy	6700.00
0005433250994	25615	Economy	6700.00
0005433251018	25615	Economy	6700.00
0005433400938	25615	Economy	7400.00
0005433250995	25615	Economy	7400.00
0005433251007	25615	Economy	7400.00
0005433251012	25615	Economy	6700.00
0005433251019	25615	Economy	6700.00
0005433251000	25615	Economy	6700.00
0005433251002	25615	Economy	6700.00
0005433251014	25615	Economy	6700.00
0005433400935	25615	Economy	6700.00
0005433251008	25615	Economy	6700.00
0005433251020	25615	Economy	6700.00
0005433400936	25615	Economy	6700.00
0005433250997	25615	Economy	6700.00
0005433251001	25615	Economy	6700.00
0005433251003	25615	Economy	6700.00
0005433251010	25615	Economy	6700.00
0005433251006	25615	Economy	6700.00
0005433251015	25615	Economy	6700.00
0005433251011	25615	Economy	6700.00
0005433250998	25615	Economy	6700.00
0005433251013	25615	Economy	6700.00
0005433250993	25615	Economy	6700.00
0005433400937	25615	Economy	6700.00
0005433250992	25615	Economy	6700.00
0005433251021	25615	Economy	6700.00
0005433250996	25615	Economy	6700.00
0005433251017	25615	Economy	6700.00
0005433251016	25615	Economy	6700.00
0005433251009	25615	Economy	6700.00
0005433250999	25615	Economy	6700.00
0005433251005	25615	Economy	6700.00
0005432620817	2520	Economy	13600.00
0005432620818	2520	Economy	13600.00
0005432620825	2520	Economy	12400.00
0005432620819	2520	Economy	12400.00
0005432620826	2520	Economy	12400.00
0005432620821	2520	Economy	12400.00
0005432620822	2520	Economy	12400.00
0005432620827	2520	Economy	12400.00
0005432620824	2520	Economy	12400.00
0005432620816	2520	Economy	12400.00
0005432620828	2520	Economy	12400.00
0005432620820	2520	Economy	12400.00
0005432620815	2520	Economy	12400.00
0005432620823	2520	Economy	12400.00
0005432862184	28051	Economy	12400.00
0005432862185	28051	Economy	12400.00
0005432862183	28051	Economy	12400.00
0005432862181	28051	Economy	12400.00
0005432862179	28051	Economy	12400.00
0005432862182	28051	Economy	12400.00
0005432862180	28051	Economy	12400.00
0005434097452	13122	Economy	11300.00
0005434097453	13122	Economy	11300.00
0005433452706	31090	Economy	8400.00
0005433451588	31090	Economy	8400.00
0005433451587	31090	Economy	8400.00
0005433452707	31090	Economy	8400.00
0005434142547	29837	Economy	7200.00
0005433134067	29837	Economy	6600.00
0005434142546	29837	Economy	6600.00
0005433134066	29837	Economy	6600.00
0005433131637	29837	Economy	6600.00
0005434142544	29837	Economy	6600.00
0005433134065	29837	Economy	6600.00
0005434183548	29837	Economy	6600.00
0005434184634	29837	Economy	6600.00
0005433134069	29837	Economy	6600.00
0005433134068	29837	Economy	6600.00
0005434183549	29837	Economy	6600.00
0005433131638	29837	Economy	6600.00
0005433131635	29837	Economy	6600.00
0005433131636	29837	Economy	6600.00
0005434142545	29837	Economy	6600.00
0005434184633	29837	Economy	6600.00
0005434184635	29837	Economy	6600.00
0005433131639	29837	Economy	6600.00
0005435696892	16463	Economy	19900.00
0005435696878	16463	Economy	19900.00
0005435696899	16463	Economy	18100.00
0005435696874	16463	Economy	18100.00
0005435696890	16463	Economy	18100.00
0005435696894	16463	Economy	18100.00
0005435696889	16463	Economy	18100.00
0005435696893	16463	Economy	18100.00
0005435696884	16463	Economy	18100.00
0005435696886	16463	Economy	18100.00
0005435696900	16463	Economy	18100.00
0005435696898	16463	Economy	18100.00
0005435696876	16463	Economy	18100.00
0005435696885	16463	Economy	18100.00
0005435696888	16463	Economy	18100.00
0005435696879	16463	Economy	18100.00
0005435696873	16463	Economy	18100.00
0005435696881	16463	Economy	18100.00
0005435696887	16463	Economy	18100.00
0005435696882	16463	Economy	18100.00
0005435696897	16463	Economy	18100.00
0005435696896	16463	Economy	18100.00
0005435696891	16463	Economy	18100.00
0005435696883	16463	Economy	18100.00
0005435696872	16463	Economy	18100.00
0005435696895	16463	Economy	18100.00
0005435696880	16463	Economy	18100.00
0005435696877	16463	Economy	18100.00
0005435696875	16463	Economy	18100.00
0005435934999	24720	Economy	18100.00
0005435935002	24720	Economy	18100.00
0005435935001	24720	Economy	18100.00
0005435935000	24720	Economy	18100.00
0005433724728	18772	Economy	4400.00
0005433724731	18772	Economy	4400.00
0005433724730	18772	Economy	4400.00
0005433724732	18772	Economy	4400.00
0005433724729	18772	Economy	4400.00
0005432968806	21600	Economy	4400.00
0005432968807	21600	Economy	4400.00
0005434087437	7309	Business	23100.00
0005434136884	7309	Business	23100.00
0005434136876	7309	Business	23100.00
0005434136859	7309	Business	23100.00
0005434136865	7309	Business	23100.00
0005434136888	7309	Business	23100.00
0005434136908	7309	Business	23100.00
0005434136889	7309	Business	23100.00
0005434136855	7309	Business	23100.00
0005434136848	7309	Business	23100.00
0005434136854	7309	Business	23100.00
0005434136926	7309	Business	23100.00
0005434136914	7309	Economy	7700.00
0005434136882	7309	Economy	7700.00
0005434136858	7309	Economy	7700.00
0005434136863	7309	Economy	7700.00
0005434136900	7309	Economy	7700.00
0005434136890	7309	Economy	7700.00
0005434136849	7309	Economy	7700.00
0005434136852	7309	Economy	7700.00
0005434136886	7309	Economy	7700.00
0005434136929	7309	Economy	7700.00
0005434136877	7309	Economy	8500.00
0005434087436	7309	Economy	8500.00
0005434136857	7309	Economy	8500.00
0005434136924	7309	Economy	8500.00
0005434136898	7309	Economy	8500.00
0005434136879	7309	Economy	7700.00
0005434136846	7309	Economy	7700.00
0005434136916	7309	Economy	7700.00
0005434087440	7309	Economy	7700.00
0005434136918	7309	Economy	7700.00
0005434136861	7309	Economy	7700.00
0005434136921	7309	Economy	7700.00
0005434136903	7309	Economy	7700.00
0005434136869	7309	Economy	7700.00
0005434136845	7309	Economy	7700.00
0005434136860	7309	Economy	7700.00
0005434087439	7309	Economy	7700.00
0005434136868	7309	Economy	7700.00
0005434136907	7309	Economy	7700.00
0005434136925	7309	Economy	7700.00
0005434136883	7309	Economy	7700.00
0005434136913	7309	Economy	7700.00
0005434136931	7309	Economy	7700.00
0005434136894	7309	Economy	7700.00
0005434136871	7309	Economy	7700.00
0005434136901	7309	Economy	7700.00
0005434136878	7309	Economy	7700.00
0005434136875	7309	Economy	7700.00
0005434136862	7309	Economy	7700.00
0005434136870	7309	Economy	7700.00
0005434136934	7309	Economy	7700.00
0005434136895	7309	Economy	7700.00
0005434136912	7309	Economy	7700.00
0005434136927	7309	Economy	7700.00
0005434136897	7309	Economy	7700.00
0005434136919	7309	Economy	7700.00
0005434136885	7309	Economy	7700.00
0005434136891	7309	Economy	7700.00
0005434136853	7309	Economy	7700.00
0005434136881	7309	Economy	7700.00
0005434136917	7309	Economy	7700.00
0005434136872	7309	Economy	7700.00
0005434136899	7309	Economy	7700.00
0005434136873	7309	Economy	7700.00
0005434136911	7309	Economy	7700.00
0005434136851	7309	Economy	7700.00
0005434136906	7309	Economy	7700.00
0005434136864	7309	Economy	7700.00
0005434136887	7309	Economy	7700.00
0005434136893	7309	Economy	7700.00
0005434136915	7309	Economy	7700.00
0005434136930	7309	Economy	7700.00
0005434136905	7309	Economy	7700.00
0005434136932	7309	Economy	7700.00
0005434136847	7309	Economy	7700.00
0005434136922	7309	Economy	7700.00
0005434136904	7309	Economy	7700.00
0005434136902	7309	Economy	7700.00
0005434136910	7309	Economy	7700.00
0005434136920	7309	Economy	7700.00
0005434087438	7309	Economy	7700.00
0005434136933	7309	Economy	7700.00
0005434136880	7309	Economy	7700.00
0005434136850	7309	Economy	7700.00
0005434136909	7309	Economy	7700.00
0005434136928	7309	Economy	7700.00
0005434136896	7309	Economy	7700.00
0005434136856	7309	Economy	7700.00
0005434136923	7309	Economy	7700.00
0005434136874	7309	Economy	7700.00
0005434136866	7309	Economy	7700.00
0005434136867	7309	Economy	7700.00
0005434136892	7309	Economy	7700.00
0005435808077	1923	Economy	23900.00
0005434610172	1923	Economy	23900.00
0005435808072	1923	Economy	23900.00
0005435808074	1923	Economy	21700.00
0005435808075	1923	Economy	21700.00
0005435808071	1923	Economy	21700.00
0005434610171	1923	Economy	21700.00
0005434610174	1923	Economy	21700.00
0005435808079	1923	Economy	21700.00
0005435808073	1923	Economy	21700.00
0005434610173	1923	Economy	21700.00
0005434610175	1923	Economy	21700.00
0005435808076	1923	Economy	21700.00
0005435808078	1923	Economy	21700.00
0005435808080	1923	Economy	21700.00
0005434503528	22906	Economy	7600.00
0005434503497	22906	Economy	7600.00
0005434503519	22906	Economy	7600.00
0005434503505	22906	Economy	7600.00
0005434503525	22906	Economy	6900.00
0005434503527	22906	Economy	6900.00
0005434503499	22906	Economy	6900.00
0005434503535	22906	Economy	6900.00
0005434503530	22906	Economy	6900.00
0005434503518	22906	Economy	6900.00
0005434503520	22906	Economy	6900.00
0005434503515	22906	Economy	6900.00
0005434503508	22906	Economy	6900.00
0005434503506	22906	Economy	6900.00
0005434503524	22906	Economy	6900.00
0005434503532	22906	Economy	6900.00
0005434503513	22906	Economy	6900.00
0005434503512	22906	Economy	6900.00
0005434503534	22906	Economy	6900.00
0005434503507	22906	Economy	6900.00
0005434503517	22906	Economy	6900.00
0005434503521	22906	Economy	6900.00
0005434503536	22906	Economy	6900.00
0005434503502	22906	Economy	6900.00
0005434503498	22906	Economy	6900.00
0005434503522	22906	Economy	6900.00
0005434503504	22906	Economy	6900.00
0005434503500	22906	Economy	6900.00
0005434503526	22906	Economy	6900.00
0005434503516	22906	Economy	6900.00
0005434503531	22906	Economy	6900.00
0005434503529	22906	Economy	6900.00
0005434503501	22906	Economy	6900.00
0005434503523	22906	Economy	6900.00
0005434503510	22906	Economy	6900.00
0005434503533	22906	Economy	6900.00
0005434503509	22906	Economy	6900.00
0005434503511	22906	Economy	6900.00
0005434503503	22906	Economy	6900.00
0005434503514	22906	Economy	6900.00
0005435078101	2171	Economy	7700.00
0005435078105	2171	Economy	7700.00
0005435078096	2171	Economy	7000.00
0005435078110	2171	Economy	7000.00
0005435078109	2171	Economy	7000.00
0005435078108	2171	Economy	7000.00
0005435078098	2171	Economy	7000.00
0005435078097	2171	Economy	7000.00
0005435078100	2171	Economy	7000.00
0005435078111	2171	Economy	7000.00
0005435078102	2171	Economy	7000.00
0005435078107	2171	Economy	7000.00
0005435078103	2171	Economy	7000.00
0005435078106	2171	Economy	7000.00
0005435078112	2171	Economy	7000.00
0005435078104	2171	Economy	7000.00
0005435078099	2171	Economy	7000.00
0005433266583	24373	Economy	7000.00
0005433266584	24373	Economy	7000.00
0005433266580	24373	Economy	7000.00
0005433266575	24373	Economy	7000.00
0005433266578	24373	Economy	7000.00
0005433266579	24373	Economy	7000.00
0005433266577	24373	Economy	7000.00
0005433266582	24373	Economy	7000.00
0005433266581	24373	Economy	7000.00
0005433266576	24373	Economy	7000.00
0005434988576	6641	Economy	10800.00
0005434988579	6641	Economy	9800.00
0005435803218	6641	Economy	9800.00
0005434988578	6641	Economy	9800.00
0005434988572	6641	Economy	9800.00
0005434988573	6641	Economy	9800.00
0005434988575	6641	Economy	9800.00
0005435803219	6641	Economy	9800.00
0005434988577	6641	Economy	9800.00
0005434988571	6641	Economy	9800.00
0005434988574	6641	Economy	9800.00
0005435464477	23624	Economy	9800.00
0005432382585	30473	Business	9900.00
0005433449647	30473	Business	9900.00
0005433454842	30473	Business	9900.00
0005432382584	30473	Business	9900.00
0005432382570	30473	Business	9900.00
0005433449645	30473	Business	9900.00
0005432382598	30473	Business	9900.00
0005432382603	30473	Economy	3300.00
0005432382594	30473	Economy	3300.00
0005432382590	30473	Economy	3300.00
0005432382592	30473	Economy	3300.00
0005433449640	30473	Economy	3300.00
0005433449637	30473	Economy	3300.00
0005433449646	30473	Economy	3600.00
0005433449638	30473	Economy	3600.00
0005432382605	30473	Economy	3600.00
0005432382569	30473	Economy	3600.00
0005433449634	30473	Economy	3300.00
0005433449649	30473	Economy	3300.00
0005432382574	30473	Economy	3300.00
0005433449639	30473	Economy	3300.00
0005432382572	30473	Economy	3300.00
0005432382599	30473	Economy	3300.00
0005433454841	30473	Economy	3300.00
0005432382566	30473	Economy	3300.00
0005432382595	30473	Economy	3300.00
0005432382601	30473	Economy	3300.00
0005432382576	30473	Economy	3300.00
0005433449632	30473	Economy	3300.00
0005432382593	30473	Economy	3300.00
0005433449631	30473	Economy	3300.00
0005432382575	30473	Economy	3300.00
0005433449643	30473	Economy	3300.00
0005432382583	30473	Economy	3300.00
0005432382588	30473	Economy	3300.00
0005433449635	30473	Economy	3300.00
0005433453731	30473	Economy	3300.00
0005433449628	30473	Economy	3300.00
0005432382581	30473	Economy	3300.00
0005432382589	30473	Economy	3300.00
0005433449630	30473	Economy	3300.00
0005432382567	30473	Economy	3300.00
0005432382568	30473	Economy	3300.00
0005433453730	30473	Economy	3300.00
0005432382586	30473	Economy	3300.00
0005433449642	30473	Economy	3300.00
0005432382564	30473	Economy	3300.00
0005433449641	30473	Economy	3300.00
0005432382604	30473	Economy	3300.00
0005433453732	30473	Economy	3300.00
0005432382577	30473	Economy	3300.00
0005432382571	30473	Economy	3300.00
0005432382602	30473	Economy	3300.00
0005433449633	30473	Economy	3300.00
0005433449644	30473	Economy	3300.00
0005433449629	30473	Economy	3300.00
0005432382573	30473	Economy	3300.00
0005432382597	30473	Economy	3300.00
0005432382600	30473	Economy	3300.00
0005433449636	30473	Economy	3300.00
0005432382591	30473	Economy	3300.00
0005432382579	30473	Economy	3300.00
0005433449648	30473	Economy	3300.00
0005432382596	30473	Economy	3300.00
0005432382565	30473	Economy	3300.00
0005432382580	30473	Economy	3300.00
0005432382587	30473	Economy	3300.00
0005432382578	30473	Economy	3300.00
0005432382582	30473	Economy	3300.00
0005433788147	20813	Economy	26200.00
0005433788145	20813	Economy	23800.00
0005433788148	20813	Economy	23800.00
0005433788146	20813	Economy	23800.00
0005433788144	20813	Economy	23800.00
0005433788142	20813	Economy	23800.00
0005433788140	20813	Economy	23800.00
0005433788143	20813	Economy	23800.00
0005433788141	20813	Economy	23800.00
0005435548427	26479	Economy	23800.00
0005435548418	26479	Economy	23800.00
0005435548431	26479	Economy	23800.00
0005435548428	26479	Economy	23800.00
0005435548429	26479	Economy	23800.00
0005435548424	26479	Economy	23800.00
0005435548421	26479	Economy	23800.00
0005435548430	26479	Economy	23800.00
0005435548420	26479	Economy	23800.00
0005435548423	26479	Economy	23800.00
0005435548432	26479	Economy	23800.00
0005435548425	26479	Economy	23800.00
0005435548426	26479	Economy	23800.00
0005435548417	26479	Economy	23800.00
0005435548422	26479	Economy	23800.00
0005435548419	26479	Economy	23800.00
0005433126778	29722	Economy	17100.00
0005433129209	29722	Economy	17100.00
0005435299705	29722	Economy	15600.00
0005435299707	29722	Economy	15600.00
0005433126780	29722	Economy	15600.00
0005433129207	29722	Economy	15600.00
0005435302132	29722	Economy	15600.00
0005433129208	29722	Economy	15600.00
0005435302131	29722	Economy	15600.00
0005435299706	29722	Economy	15600.00
0005433129211	29722	Economy	15600.00
0005433126777	29722	Economy	15600.00
0005435299709	29722	Economy	15600.00
0005433126779	29722	Economy	15600.00
0005435299708	29722	Economy	15600.00
0005435302133	29722	Economy	15600.00
0005435302130	29722	Economy	15600.00
0005433129210	29722	Economy	15600.00
0005434286955	2431	Economy	17200.00
0005434286942	2431	Economy	17200.00
0005434286947	2431	Economy	15700.00
0005434286956	2431	Economy	15700.00
0005434286941	2431	Economy	15700.00
0005434286943	2431	Economy	15700.00
0005432264436	2431	Economy	15700.00
0005432264437	2431	Economy	15700.00
0005434286944	2431	Economy	15700.00
0005434286959	2431	Economy	15700.00
0005434286953	2431	Economy	15700.00
0005434286939	2431	Economy	15700.00
0005432264438	2431	Economy	15700.00
0005434286951	2431	Economy	15700.00
0005434286946	2431	Economy	15700.00
0005434286948	2431	Economy	15700.00
0005434286952	2431	Economy	15700.00
0005434286957	2431	Economy	15700.00
0005434286954	2431	Economy	15700.00
0005434286958	2431	Economy	15700.00
0005434286938	2431	Economy	15700.00
0005434286940	2431	Economy	15700.00
0005434286949	2431	Economy	15700.00
0005434286945	2431	Economy	15700.00
0005434286950	2431	Economy	15700.00
0005433109872	26854	Economy	17200.00
0005433109870	26854	Economy	15700.00
0005433109871	26854	Economy	15700.00
0005433109868	26854	Economy	15700.00
0005433109862	26854	Economy	15700.00
0005433109865	26854	Economy	15700.00
0005433109864	26854	Economy	15700.00
0005433109873	26854	Economy	15700.00
0005433109867	26854	Economy	15700.00
0005433109869	26854	Economy	15700.00
0005433109863	26854	Economy	15700.00
0005433109866	26854	Economy	15700.00
0005435856140	25456	Economy	22800.00
0005435856138	25456	Economy	22800.00
0005435856141	25456	Economy	22800.00
0005435856139	25456	Economy	22800.00
0005434273050	26623	Economy	25000.00
0005434273051	26623	Economy	22800.00
0005434272165	26623	Economy	22800.00
0005434272166	26623	Economy	22800.00
0005434520144	6099	Economy	24600.00
0005434520134	6099	Economy	24600.00
0005434520128	6099	Economy	24600.00
0005434520138	6099	Economy	22300.00
0005434520149	6099	Economy	22300.00
0005434520147	6099	Economy	22300.00
0005434520131	6099	Economy	22300.00
0005434520127	6099	Economy	22300.00
0005434520139	6099	Economy	22300.00
0005434520129	6099	Economy	22300.00
0005434520150	6099	Economy	22300.00
0005434520136	6099	Economy	22300.00
0005434520151	6099	Economy	22300.00
0005434520146	6099	Economy	22300.00
0005434520130	6099	Economy	22300.00
0005434520148	6099	Economy	22300.00
0005434520145	6099	Economy	22300.00
0005434520143	6099	Economy	22300.00
0005434520137	6099	Economy	22300.00
0005434520132	6099	Economy	22300.00
0005434520140	6099	Economy	22300.00
0005434520135	6099	Economy	22300.00
0005434520126	6099	Economy	22300.00
0005434520133	6099	Economy	22300.00
0005434520141	6099	Economy	22300.00
0005434520142	6099	Economy	22300.00
0005433650389	7160	Business	89800.00
0005433650379	7160	Business	89800.00
0005433650365	7160	Business	89800.00
0005433650373	7160	Business	89800.00
0005433650371	7160	Business	89800.00
0005433650393	7160	Business	89800.00
0005433650381	7160	Business	89800.00
0005433650406	7160	Business	89800.00
0005433650408	7160	Business	89800.00
0005433650387	7160	Economy	29900.00
0005433650376	7160	Economy	29900.00
0005433650411	7160	Economy	29900.00
0005433650404	7160	Economy	32900.00
0005433650390	7160	Economy	32900.00
0005433650401	7160	Economy	29900.00
0005433650410	7160	Economy	29900.00
0005433650412	7160	Economy	29900.00
0005433650375	7160	Economy	29900.00
0005433650367	7160	Economy	29900.00
0005433650409	7160	Economy	29900.00
0005433650380	7160	Economy	29900.00
0005433650400	7160	Economy	29900.00
0005433650403	7160	Economy	29900.00
0005433650398	7160	Economy	29900.00
0005433650402	7160	Economy	29900.00
0005433650377	7160	Economy	29900.00
0005433650384	7160	Economy	29900.00
0005433650407	7160	Economy	29900.00
0005433650391	7160	Economy	29900.00
0005433650392	7160	Economy	29900.00
0005433650369	7160	Economy	29900.00
0005433650370	7160	Economy	29900.00
0005433650374	7160	Economy	29900.00
0005433650372	7160	Economy	29900.00
0005433650368	7160	Economy	29900.00
0005433650399	7160	Economy	29900.00
0005433650386	7160	Economy	29900.00
0005433650405	7160	Economy	29900.00
0005433650366	7160	Economy	29900.00
0005433650388	7160	Economy	29900.00
0005433650378	7160	Economy	29900.00
0005433650382	7160	Economy	29900.00
0005433650394	7160	Economy	29900.00
0005433650397	7160	Economy	29900.00
0005433650385	7160	Economy	29900.00
0005433650396	7160	Economy	29900.00
0005433650395	7160	Economy	29900.00
0005433650383	7160	Economy	29900.00
0005435263502	27622	Business	89800.00
0005435263492	27622	Business	89800.00
0005435263494	27622	Business	89800.00
0005435263484	27622	Business	89800.00
0005435263483	27622	Economy	29900.00
0005435263495	27622	Economy	29900.00
0005435263488	27622	Economy	29900.00
0005435263490	27622	Economy	29900.00
0005435263501	27622	Economy	29900.00
0005435263485	27622	Economy	29900.00
0005435263491	27622	Economy	29900.00
0005435263487	27622	Economy	29900.00
0005435263497	27622	Economy	29900.00
0005435263479	27622	Economy	29900.00
0005435263481	27622	Economy	29900.00
0005435263489	27622	Economy	29900.00
0005435263482	27622	Economy	29900.00
0005435263480	27622	Economy	29900.00
0005435263486	27622	Economy	29900.00
0005435263493	27622	Economy	29900.00
0005435263496	27622	Economy	29900.00
0005435263499	27622	Economy	29900.00
0005435263500	27622	Economy	29900.00
0005435263498	27622	Economy	29900.00
0005433867823	4782	Economy	19400.00
0005433867845	4782	Economy	19400.00
0005433867824	4782	Economy	19400.00
0005433867821	4782	Economy	19400.00
0005433867837	4782	Economy	17600.00
0005433867829	4782	Economy	17600.00
0005433867847	4782	Economy	17600.00
0005433867838	4782	Economy	17600.00
0005433867818	4782	Economy	17600.00
0005433867835	4782	Economy	17600.00
0005433867830	4782	Economy	17600.00
0005433867826	4782	Economy	17600.00
0005433867833	4782	Economy	17600.00
0005433867850	4782	Economy	17600.00
0005433867844	4782	Economy	17600.00
0005433867842	4782	Economy	17600.00
0005433867836	4782	Economy	17600.00
0005433867828	4782	Economy	17600.00
0005433867834	4782	Economy	17600.00
0005433867831	4782	Economy	17600.00
0005433867849	4782	Economy	17600.00
0005433867841	4782	Economy	17600.00
0005433867811	4782	Economy	17600.00
0005433867817	4782	Economy	17600.00
0005433867839	4782	Economy	17600.00
0005433867832	4782	Economy	17600.00
0005433867820	4782	Economy	17600.00
0005433867812	4782	Economy	17600.00
0005433867827	4782	Economy	17600.00
0005433867819	4782	Economy	17600.00
0005433867822	4782	Economy	17600.00
0005433867843	4782	Economy	17600.00
0005433867813	4782	Economy	17600.00
0005433867840	4782	Economy	17600.00
0005433867825	4782	Economy	17600.00
0005433867814	4782	Economy	17600.00
0005433867816	4782	Economy	17600.00
0005433867846	4782	Economy	17600.00
0005433867815	4782	Economy	17600.00
0005433867848	4782	Economy	17600.00
0005435860436	32574	Economy	17600.00
0005435860435	32574	Economy	17600.00
0005435860434	32574	Economy	17600.00
0005435860437	32574	Economy	17600.00
0005434663205	3417	Economy	22600.00
0005434663200	3417	Economy	22600.00
0005434663201	3417	Economy	22600.00
0005434461613	3417	Economy	22600.00
0005434663203	3417	Economy	22600.00
0005434663206	3417	Economy	22600.00
0005434663196	3417	Economy	22600.00
0005434460472	3417	Economy	22600.00
0005434663194	3417	Economy	22600.00
0005434460471	3417	Economy	22600.00
0005434663202	3417	Economy	22600.00
0005434663199	3417	Economy	22600.00
0005434461614	3417	Economy	22600.00
0005434663193	3417	Economy	22600.00
0005434663197	3417	Economy	22600.00
0005434663195	3417	Economy	22600.00
0005434663204	3417	Economy	22600.00
0005434663198	3417	Economy	22600.00
0005435911334	12500	Economy	24800.00
0005435911336	12500	Economy	22600.00
0005435911332	12500	Economy	22600.00
0005435911339	12500	Economy	22600.00
0005435911333	12500	Economy	22600.00
0005435911337	12500	Economy	22600.00
0005435911338	12500	Economy	22600.00
0005435911331	12500	Economy	22600.00
0005435911335	12500	Economy	22600.00
0005435860437	14488	Economy	16800.00
0005435860434	14488	Economy	16800.00
0005435860436	14488	Economy	16800.00
0005435860435	14488	Economy	16800.00
0005433867810	32675	Economy	18500.00
0005433867781	32675	Economy	18500.00
0005433867783	32675	Economy	16800.00
0005433867772	32675	Economy	16800.00
0005433867793	32675	Economy	16800.00
0005433867804	32675	Economy	16800.00
0005433867808	32675	Economy	16800.00
0005433867774	32675	Economy	16800.00
0005433867806	32675	Economy	16800.00
0005433867777	32675	Economy	16800.00
0005433867807	32675	Economy	16800.00
0005433867787	32675	Economy	16800.00
0005433867802	32675	Economy	16800.00
0005433867773	32675	Economy	16800.00
0005433867800	32675	Economy	16800.00
0005433867797	32675	Economy	16800.00
0005433867792	32675	Economy	16800.00
0005433867791	32675	Economy	16800.00
0005433867798	32675	Economy	16800.00
0005433867801	32675	Economy	16800.00
0005433867775	32675	Economy	16800.00
0005433867786	32675	Economy	16800.00
0005433867795	32675	Economy	16800.00
0005433867794	32675	Economy	16800.00
0005433867778	32675	Economy	16800.00
0005433867771	32675	Economy	16800.00
0005433867782	32675	Economy	16800.00
0005433867805	32675	Economy	16800.00
0005433867784	32675	Economy	16800.00
0005433867770	32675	Economy	16800.00
0005433867788	32675	Economy	16800.00
0005433867779	32675	Economy	16800.00
0005433867796	32675	Economy	16800.00
0005433867785	32675	Economy	16800.00
0005433867790	32675	Economy	16800.00
0005433867776	32675	Economy	16800.00
0005433867789	32675	Economy	16800.00
0005433867799	32675	Economy	16800.00
0005433867809	32675	Economy	16800.00
0005433867780	32675	Economy	16800.00
0005433867803	32675	Economy	16800.00
0005432798984	14837	Economy	4900.00
0005432798985	14837	Economy	4900.00
0005432798992	14837	Economy	4900.00
0005432799004	14837	Economy	4900.00
0005432798990	14837	Economy	4400.00
0005432798996	14837	Economy	4400.00
0005432799000	14837	Economy	4400.00
0005432798991	14837	Economy	4400.00
0005432798983	14837	Economy	4400.00
0005432799009	14837	Economy	4400.00
0005432798986	14837	Economy	4400.00
0005432798999	14837	Economy	4400.00
0005432799007	14837	Economy	4400.00
0005432798997	14837	Economy	4400.00
0005432799005	14837	Economy	4400.00
0005432798987	14837	Economy	4400.00
0005432799002	14837	Economy	4400.00
0005432798993	14837	Economy	4400.00
0005432799006	14837	Economy	4400.00
0005432798995	14837	Economy	4400.00
0005432799003	14837	Economy	4400.00
0005432799010	14837	Economy	4400.00
0005432799008	14837	Economy	4400.00
0005432799001	14837	Economy	4400.00
0005432798989	14837	Economy	4400.00
0005432798994	14837	Economy	4400.00
0005432798998	14837	Economy	4400.00
0005432798988	14837	Economy	4400.00
0005434406788	7036	Business	49100.00
0005434406822	7036	Business	49100.00
0005434406767	7036	Business	49100.00
0005434406816	7036	Business	49100.00
0005434406813	7036	Business	49100.00
0005434406817	7036	Business	49100.00
0005434406821	7036	Business	49100.00
0005432153832	7036	Business	49100.00
0005432108210	7036	Business	49100.00
0005434299198	7036	Business	49100.00
0005434406773	7036	Business	49100.00
0005434299199	7036	Economy	16400.00
0005434406827	7036	Economy	16400.00
0005434299214	7036	Economy	16400.00
0005434406776	7036	Economy	16400.00
0005434406787	7036	Economy	16400.00
0005434299216	7036	Economy	16400.00
0005434299208	7036	Economy	16400.00
0005434406793	7036	Economy	16400.00
0005434406815	7036	Economy	16400.00
0005434406774	7036	Economy	16400.00
0005434299202	7036	Economy	16400.00
0005434406779	7036	Economy	16400.00
0005434406794	7036	Economy	16400.00
0005434406792	7036	Economy	16400.00
0005434406771	7036	Economy	16400.00
0005434299215	7036	Economy	16400.00
0005434406809	7036	Economy	16400.00
0005434406795	7036	Economy	16400.00
0005434299200	7036	Economy	16400.00
0005432153833	7036	Economy	16400.00
0005434299210	7036	Economy	16400.00
0005434299205	7036	Economy	16400.00
0005434406790	7036	Economy	16400.00
0005434299204	7036	Economy	16400.00
0005434406819	7036	Economy	16400.00
0005434406812	7036	Economy	16400.00
0005434406811	7036	Economy	16400.00
0005434299206	7036	Economy	16400.00
0005434406825	7036	Economy	16400.00
0005432108211	7036	Economy	16400.00
0005432108212	7036	Economy	16400.00
0005432153831	7036	Economy	16400.00
0005434406828	7036	Economy	18000.00
0005434299201	7036	Economy	18000.00
0005434406775	7036	Economy	18000.00
0005434406778	7036	Economy	18000.00
0005432153828	7036	Economy	18000.00
0005434406784	7036	Economy	16400.00
0005434406814	7036	Economy	16400.00
0005434406768	7036	Economy	16400.00
0005434299209	7036	Economy	16400.00
0005434299196	7036	Economy	16400.00
0005434406783	7036	Economy	16400.00
0005434406786	7036	Economy	16400.00
0005434406781	7036	Economy	16400.00
0005432153830	7036	Economy	16400.00
0005432108209	7036	Economy	16400.00
0005434406777	7036	Economy	16400.00
0005434406796	7036	Economy	16400.00
0005434406797	7036	Economy	16400.00
0005434406801	7036	Economy	16400.00
0005434406810	7036	Economy	16400.00
0005434406804	7036	Economy	16400.00
0005434406789	7036	Economy	16400.00
0005434406791	7036	Economy	16400.00
0005434406803	7036	Economy	16400.00
0005434406766	7036	Economy	16400.00
0005434406772	7036	Economy	16400.00
0005434299213	7036	Economy	16400.00
0005434299197	7036	Economy	16400.00
0005434406808	7036	Economy	16400.00
0005434299207	7036	Economy	16400.00
0005434406780	7036	Economy	16400.00
0005434406765	7036	Economy	16400.00
0005434406770	7036	Economy	16400.00
0005434406826	7036	Economy	16400.00
0005434299212	7036	Economy	16400.00
0005434406782	7036	Economy	16400.00
0005434406802	7036	Economy	16400.00
0005434406818	7036	Economy	16400.00
0005434406823	7036	Economy	16400.00
0005434406785	7036	Economy	16400.00
0005434299211	7036	Economy	16400.00
0005434406799	7036	Economy	16400.00
0005432153829	7036	Economy	16400.00
0005434406820	7036	Economy	16400.00
0005434406805	7036	Economy	16400.00
0005434406807	7036	Economy	16400.00
0005434299194	7036	Economy	16400.00
0005434406798	7036	Economy	16400.00
0005434406806	7036	Economy	16400.00
0005434299203	7036	Economy	16400.00
0005434406829	7036	Economy	16400.00
0005434406800	7036	Economy	16400.00
0005434406824	7036	Economy	16400.00
0005434299195	7036	Economy	16400.00
0005434406769	7036	Economy	16400.00
0005435293075	26880	Business	49100.00
0005432058318	26880	Business	49100.00
0005435310874	26880	Business	49100.00
0005435310873	26880	Economy	16400.00
0005435293073	26880	Economy	16400.00
0005435310865	26880	Economy	16400.00
0005435293078	26880	Economy	16400.00
0005435310868	26880	Economy	16400.00
0005435310860	26880	Economy	16400.00
0005435310869	26880	Economy	16400.00
0005435310861	26880	Economy	16400.00
0005435310859	26880	Economy	16400.00
0005435310863	26880	Economy	16400.00
0005435293077	26880	Economy	16400.00
0005435293080	26880	Economy	16400.00
0005435310862	26880	Economy	16400.00
0005432058316	26880	Economy	16400.00
0005432058319	26880	Economy	16400.00
0005435293072	26880	Economy	16400.00
0005435310856	26880	Economy	16400.00
0005435310872	26880	Economy	16400.00
0005435310858	26880	Economy	16400.00
0005435310871	26880	Economy	16400.00
0005435310867	26880	Economy	16400.00
0005435293071	26880	Economy	16400.00
0005435310864	26880	Economy	16400.00
0005432058317	26880	Economy	16400.00
0005435310866	26880	Economy	16400.00
0005435293076	26880	Economy	16400.00
0005435293081	26880	Economy	16400.00
0005435310875	26880	Economy	16400.00
0005435293082	26880	Economy	16400.00
0005435310857	26880	Economy	16400.00
0005435310870	26880	Economy	16400.00
0005435293079	26880	Economy	16400.00
0005435293074	26880	Economy	16400.00
0005434512033	6483	Economy	16500.00
0005432603754	6483	Economy	16500.00
0005432603752	6483	Economy	16500.00
0005432603740	6483	Economy	16500.00
0005432603738	6483	Economy	15000.00
0005432603728	6483	Economy	15000.00
0005432603749	6483	Economy	15000.00
0005432603758	6483	Economy	15000.00
0005434512034	6483	Economy	15000.00
0005432603762	6483	Economy	15000.00
0005432603745	6483	Economy	15000.00
0005434512030	6483	Economy	15000.00
0005432603731	6483	Economy	15000.00
0005432603746	6483	Economy	15000.00
0005432603747	6483	Economy	15000.00
0005432603761	6483	Economy	15000.00
0005432603757	6483	Economy	15000.00
0005432603736	6483	Economy	15000.00
0005432603750	6483	Economy	15000.00
0005432603730	6483	Economy	15000.00
0005432603723	6483	Economy	15000.00
0005432603753	6483	Economy	15000.00
0005432603725	6483	Economy	15000.00
0005432603759	6483	Economy	15000.00
0005434512029	6483	Economy	15000.00
0005432603742	6483	Economy	15000.00
0005432603727	6483	Economy	15000.00
0005432603732	6483	Economy	15000.00
0005432603737	6483	Economy	15000.00
0005432603751	6483	Economy	15000.00
0005432603756	6483	Economy	15000.00
0005432603748	6483	Economy	15000.00
0005432603733	6483	Economy	15000.00
0005432603741	6483	Economy	15000.00
0005434512028	6483	Economy	15000.00
0005432603734	6483	Economy	15000.00
0005432603743	6483	Economy	15000.00
0005432603729	6483	Economy	15000.00
0005432603755	6483	Economy	15000.00
0005432603735	6483	Economy	15000.00
0005432603724	6483	Economy	15000.00
0005432603760	6483	Economy	15000.00
0005434512031	6483	Economy	15000.00
0005432603744	6483	Economy	15000.00
0005434512032	6483	Economy	15000.00
0005432603739	6483	Economy	15000.00
0005432603726	6483	Economy	15000.00
0005435221037	21346	Economy	16500.00
0005435221500	21346	Economy	15000.00
0005435221499	21346	Economy	15000.00
0005435221498	21346	Economy	15000.00
0005433251014	15007	Business	18900.00
0005433250990	15007	Business	18900.00
0005433251018	15007	Business	18900.00
0005433251016	15007	Business	18900.00
0005433251011	15007	Economy	6300.00
0005433251003	15007	Economy	6300.00
0005433251001	15007	Economy	6300.00
0005433250998	15007	Economy	6300.00
0005433251006	15007	Economy	6300.00
0005433251013	15007	Economy	6900.00
0005433251005	15007	Economy	6900.00
0005433251004	15007	Economy	6300.00
0005433250997	15007	Economy	6300.00
0005433250996	15007	Economy	6300.00
0005433251012	15007	Economy	6300.00
0005433251015	15007	Economy	6300.00
0005433250999	15007	Economy	6300.00
0005433250992	15007	Economy	6300.00
0005433251008	15007	Economy	6300.00
0005433250994	15007	Economy	6300.00
0005433251002	15007	Economy	6300.00
0005433251000	15007	Economy	6300.00
0005433251019	15007	Economy	6300.00
0005433251020	15007	Economy	6300.00
0005433250993	15007	Economy	6300.00
0005433251009	15007	Economy	6300.00
0005433250995	15007	Economy	6300.00
0005433251007	15007	Economy	6300.00
0005433251017	15007	Economy	6300.00
0005433251021	15007	Economy	6300.00
0005433250991	15007	Economy	6300.00
0005433251010	15007	Economy	6300.00
0005434906447	25822	Business	18900.00
0005434906418	25822	Business	18900.00
0005434906443	25822	Business	18900.00
0005434906412	25822	Business	18900.00
0005434906428	25822	Business	18900.00
0005434906423	25822	Business	18900.00
0005434906411	25822	Economy	6300.00
0005434906432	25822	Economy	6300.00
0005434906427	25822	Economy	6300.00
0005434906453	25822	Economy	6300.00
0005434906407	25822	Economy	6900.00
0005434906417	25822	Economy	6300.00
0005434906449	25822	Economy	6300.00
0005434906420	25822	Economy	6300.00
0005434906425	25822	Economy	6300.00
0005434906441	25822	Economy	6300.00
0005434906429	25822	Economy	6300.00
0005434906437	25822	Economy	6300.00
0005434906448	25822	Economy	6300.00
0005434906408	25822	Economy	6300.00
0005434906414	25822	Economy	6300.00
0005434906450	25822	Economy	6300.00
0005434906416	25822	Economy	6300.00
0005434906446	25822	Economy	6300.00
0005434906436	25822	Economy	6300.00
0005434906421	25822	Economy	6300.00
0005434906431	25822	Economy	6300.00
0005434906434	25822	Economy	6300.00
0005434906442	25822	Economy	6300.00
0005434906433	25822	Economy	6300.00
0005434906438	25822	Economy	6300.00
0005434906439	25822	Economy	6300.00
0005434906454	25822	Economy	6300.00
0005434906413	25822	Economy	6300.00
0005434906455	25822	Economy	6300.00
0005434906440	25822	Economy	6300.00
0005434906419	25822	Economy	6300.00
0005434906426	25822	Economy	6300.00
0005434906445	25822	Economy	6300.00
0005434906452	25822	Economy	6300.00
0005434906410	25822	Economy	6300.00
0005434906415	25822	Economy	6300.00
0005434906451	25822	Economy	6300.00
0005434906409	25822	Economy	6300.00
0005434906444	25822	Economy	6300.00
0005434906435	25822	Economy	6300.00
0005434906424	25822	Economy	6300.00
0005434906430	25822	Economy	6300.00
0005434906422	25822	Economy	6300.00
0005433007939	14152	Business	52300.00
0005433007958	14152	Business	52300.00
0005433007959	14152	Business	52300.00
0005433007923	14152	Business	52300.00
0005433007953	14152	Economy	17400.00
0005433007938	14152	Economy	17400.00
0005433007933	14152	Economy	17400.00
0005433007934	14152	Economy	17400.00
0005433007952	14152	Economy	17400.00
0005433007922	14152	Economy	17400.00
0005433007928	14152	Economy	17400.00
0005433007948	14152	Economy	17400.00
0005433007929	14152	Economy	17400.00
0005433007955	14152	Economy	19200.00
0005433007951	14152	Economy	19200.00
0005433007930	14152	Economy	17400.00
0005433007926	14152	Economy	17400.00
0005433007919	14152	Economy	17400.00
0005433007946	14152	Economy	17400.00
0005433007915	14152	Economy	17400.00
0005433007935	14152	Economy	17400.00
0005433007918	14152	Economy	17400.00
0005433007945	14152	Economy	17400.00
0005433007925	14152	Economy	17400.00
0005433007943	14152	Economy	17400.00
0005433007937	14152	Economy	17400.00
0005433007942	14152	Economy	17400.00
0005433007944	14152	Economy	17400.00
0005433007932	14152	Economy	17400.00
0005433007954	14152	Economy	17400.00
0005433007960	14152	Economy	17400.00
0005433007936	14152	Economy	17400.00
0005433007949	14152	Economy	17400.00
0005433007917	14152	Economy	17400.00
0005433007921	14152	Economy	17400.00
0005433007924	14152	Economy	17400.00
0005433007950	14152	Economy	17400.00
0005433007931	14152	Economy	17400.00
0005433007920	14152	Economy	17400.00
0005433007916	14152	Economy	17400.00
0005433007957	14152	Economy	17400.00
0005433007927	14152	Economy	17400.00
0005433007947	14152	Economy	17400.00
0005433007941	14152	Economy	17400.00
0005433007940	14152	Economy	17400.00
0005433007956	14152	Economy	17400.00
0005433810492	22853	Economy	17400.00
0005434925302	20549	Business	22900.00
0005434925286	20549	Business	22900.00
0005434925274	20549	Business	22900.00
0005434925295	20549	Business	22900.00
0005434925275	20549	Business	22900.00
0005434925282	20549	Business	22900.00
0005434925290	20549	Business	22900.00
0005434925303	20549	Economy	7600.00
0005434925294	20549	Economy	7600.00
0005434925289	20549	Economy	8400.00
0005434925281	20549	Economy	8400.00
0005434925284	20549	Economy	7600.00
0005434925304	20549	Economy	7600.00
0005434925296	20549	Economy	7600.00
0005434925297	20549	Economy	7600.00
0005434925279	20549	Economy	7600.00
0005434925278	20549	Economy	7600.00
0005434925283	20549	Economy	7600.00
0005434925277	20549	Economy	7600.00
0005434925285	20549	Economy	7600.00
0005434925300	20549	Economy	7600.00
0005434925288	20549	Economy	7600.00
0005434925298	20549	Economy	7600.00
0005434925273	20549	Economy	7600.00
0005434925293	20549	Economy	7600.00
0005434925301	20549	Economy	7600.00
0005434925291	20549	Economy	7600.00
0005434925305	20549	Economy	7600.00
0005434925276	20549	Economy	7600.00
0005434925280	20549	Economy	7600.00
0005434925292	20549	Economy	7600.00
0005434925287	20549	Economy	7600.00
0005434925299	20549	Economy	7600.00
0005435487515	15798	Economy	8900.00
0005435487503	15798	Economy	8900.00
0005435487499	15798	Economy	8100.00
0005435487500	15798	Economy	8100.00
0005435487511	15798	Economy	8100.00
0005435487508	15798	Economy	8100.00
0005435487514	15798	Economy	8100.00
0005435487516	15798	Economy	8100.00
0005435487506	15798	Economy	8100.00
0005435487513	15798	Economy	8100.00
0005435487519	15798	Economy	8100.00
0005435487501	15798	Economy	8100.00
0005435487502	15798	Economy	8100.00
0005435487507	15798	Economy	8100.00
0005435487509	15798	Economy	8100.00
0005435487518	15798	Economy	8100.00
0005435487510	15798	Economy	8100.00
0005435487504	15798	Economy	8100.00
0005435487505	15798	Economy	8100.00
0005435487512	15798	Economy	8100.00
0005435487498	15798	Economy	8100.00
0005435487517	15798	Economy	8100.00
0005435998970	19680	Economy	8900.00
0005435998969	19680	Economy	8900.00
0005435998975	19680	Economy	8900.00
0005435998981	19680	Economy	8100.00
0005435998979	19680	Economy	8100.00
0005435998972	19680	Economy	8100.00
0005435998984	19680	Economy	8100.00
0005435998971	19680	Economy	8100.00
0005435998978	19680	Economy	8100.00
0005435998976	19680	Economy	8100.00
0005435998974	19680	Economy	8100.00
0005435998968	19680	Economy	8100.00
0005435998977	19680	Economy	8100.00
0005435998980	19680	Economy	8100.00
0005435998973	19680	Economy	8100.00
0005435998983	19680	Economy	8100.00
0005435998982	19680	Economy	8100.00
0005435839044	5993	Business	199300.00
0005435839028	5993	Business	199300.00
0005435839043	5993	Business	199300.00
0005435839027	5993	Economy	66400.00
0005435839026	5993	Economy	66400.00
0005435839040	5993	Economy	66400.00
0005432658561	5993	Economy	66400.00
0005435839042	5993	Economy	66400.00
0005432659676	5993	Economy	66400.00
0005432142204	5993	Economy	66400.00
0005435839039	5993	Economy	66400.00
0005435839030	5993	Economy	73100.00
0005432658560	5993	Economy	66400.00
0005432660788	5993	Economy	66400.00
0005435839031	5993	Economy	66400.00
0005435839029	5993	Economy	66400.00
0005432142203	5993	Economy	66400.00
0005435839023	5993	Economy	66400.00
0005435839032	5993	Economy	66400.00
0005432142205	5993	Economy	66400.00
0005432659675	5993	Economy	66400.00
0005435839017	5993	Economy	66400.00
0005435839020	5993	Economy	66400.00
0005435839034	5993	Economy	66400.00
0005435839019	5993	Economy	66400.00
0005435839015	5993	Economy	66400.00
0005435839021	5993	Economy	66400.00
0005435839035	5993	Economy	66400.00
0005435839038	5993	Economy	66400.00
0005435839018	5993	Economy	66400.00
0005435839033	5993	Economy	66400.00
0005435839041	5993	Economy	66400.00
0005435839036	5993	Economy	66400.00
0005435839016	5993	Economy	66400.00
0005435839024	5993	Economy	66400.00
0005435839037	5993	Economy	66400.00
0005435839022	5993	Economy	66400.00
0005435839025	5993	Economy	66400.00
0005432660789	5993	Economy	66400.00
0005432537026	18044	Business	199300.00
0005435472547	18044	Economy	66400.00
0005435472556	18044	Economy	66400.00
0005435472558	18044	Economy	66400.00
0005435472559	18044	Economy	66400.00
0005435472545	18044	Economy	66400.00
0005432537025	18044	Economy	66400.00
0005435472560	18044	Economy	66400.00
0005435472548	18044	Economy	66400.00
0005435472557	18044	Economy	66400.00
0005435472549	18044	Economy	66400.00
0005435472550	18044	Economy	66400.00
0005435472552	18044	Economy	66400.00
0005435472546	18044	Economy	66400.00
0005435472554	18044	Economy	66400.00
0005435472553	18044	Economy	66400.00
0005435472555	18044	Economy	66400.00
0005432537027	18044	Economy	66400.00
0005435472551	18044	Economy	66400.00
0005435472561	18044	Economy	66400.00
0005435103811	23007	Economy	5200.00
0005435103814	23007	Economy	5200.00
0005435103816	23007	Economy	5200.00
0005435103817	23007	Economy	5200.00
0005435103806	23007	Economy	5200.00
0005435103815	23007	Economy	5700.00
0005435103808	23007	Economy	5200.00
0005435103813	23007	Economy	5200.00
0005435103804	23007	Economy	5200.00
0005435103809	23007	Economy	5200.00
0005435103818	23007	Economy	5200.00
0005435103807	23007	Economy	5200.00
0005435103810	23007	Economy	5200.00
0005435103805	23007	Economy	5200.00
0005435103812	23007	Economy	5200.00
0005433284831	32052	Business	15700.00
0005433284838	32052	Business	15700.00
0005433284847	32052	Economy	5200.00
0005433284839	32052	Economy	5200.00
0005433284844	32052	Economy	5200.00
0005433284833	32052	Economy	5200.00
0005433284836	32052	Economy	5200.00
0005433284834	32052	Economy	5200.00
0005433284837	32052	Economy	5200.00
0005433284824	32052	Economy	5200.00
0005433284821	32052	Economy	5200.00
0005433284832	32052	Economy	5200.00
0005433284848	32052	Economy	5700.00
0005433284846	32052	Economy	5700.00
0005433284830	32052	Economy	5700.00
0005433284835	32052	Economy	5700.00
0005433284841	32052	Economy	5200.00
0005433284825	32052	Economy	5200.00
0005433284823	32052	Economy	5200.00
0005433284826	32052	Economy	5200.00
0005433284827	32052	Economy	5200.00
0005433284822	32052	Economy	5200.00
0005433284828	32052	Economy	5200.00
0005433284840	32052	Economy	5200.00
0005433284842	32052	Economy	5200.00
0005433284829	32052	Economy	5200.00
0005433284845	32052	Economy	5200.00
0005433284843	32052	Economy	5200.00
0005433111468	19951	Business	150400.00
0005432892721	19951	Business	150400.00
0005433111470	19951	Business	150400.00
0005432892724	19951	Economy	50100.00
0005433112350	19951	Economy	50100.00
0005432892722	19951	Economy	50100.00
0005432892720	19951	Economy	50100.00
0005432892719	19951	Economy	50100.00
0005432892723	19951	Economy	50100.00
0005433111471	19951	Economy	50100.00
0005432892725	19951	Economy	50100.00
0005433111469	19951	Economy	50100.00
0005433111467	19951	Economy	50100.00
0005435630923	30595	Business	42100.00
0005435212545	30595	Business	42100.00
0005435212587	30595	Business	42100.00
0005433656624	30595	Business	42100.00
0005435212539	30595	Business	42100.00
0005432159792	30595	Business	42100.00
0005435212552	30595	Business	42100.00
0005435212561	30595	Business	42100.00
0005435212600	30595	Business	42100.00
0005435630924	30595	Business	42100.00
0005435212603	30595	Comfort	23900.00
0005432159789	30595	Comfort	23900.00
0005435725530	30595	Comfort	23900.00
0005435212536	30595	Comfort	23900.00
0005435212560	30595	Comfort	23900.00
0005435212583	30595	Comfort	23900.00
0005435212572	30595	Comfort	23900.00
0005435212566	30595	Economy	14000.00
0005435212537	30595	Economy	14000.00
0005435212590	30595	Economy	14000.00
0005435212593	30595	Economy	14000.00
0005435212565	30595	Economy	14000.00
0005432159790	30595	Economy	14000.00
0005435212549	30595	Economy	14000.00
0005432211396	30595	Economy	14000.00
0005435212555	30595	Economy	14000.00
0005435212540	30595	Economy	14000.00
0005435725529	30595	Economy	14000.00
0005435212597	30595	Economy	14000.00
0005435212550	30595	Economy	14000.00
0005435212547	30595	Economy	14000.00
0005435212576	30595	Economy	15400.00
0005435212541	30595	Economy	14000.00
0005435725527	30595	Economy	14000.00
0005435212581	30595	Economy	14000.00
0005432211389	30595	Economy	14000.00
0005435212592	30595	Economy	14000.00
0005435212596	30595	Economy	14000.00
0005435212562	30595	Economy	14000.00
0005435212553	30595	Economy	14000.00
0005435212554	30595	Economy	14000.00
0005435212582	30595	Economy	14000.00
0005432211394	30595	Economy	14000.00
0005435212579	30595	Economy	14000.00
0005435212605	30595	Economy	14000.00
0005435212595	30595	Economy	14000.00
0005435212570	30595	Economy	14000.00
0005435212580	30595	Economy	14000.00
0005435212602	30595	Economy	14000.00
0005435212575	30595	Economy	14000.00
0005435212544	30595	Economy	14000.00
0005435212543	30595	Economy	14000.00
0005432159788	30595	Economy	14000.00
0005433656623	30595	Economy	14000.00
0005435212591	30595	Economy	14000.00
0005435212568	30595	Economy	14000.00
0005435212604	30595	Economy	14000.00
0005435212563	30595	Economy	14000.00
0005435212585	30595	Economy	14000.00
0005435212571	30595	Economy	14000.00
0005435212556	30595	Economy	14000.00
0005435212567	30595	Economy	14000.00
0005435212601	30595	Economy	15400.00
0005435630925	30595	Economy	15400.00
0005432211391	30595	Economy	14000.00
0005435212578	30595	Economy	14000.00
0005435212584	30595	Economy	14000.00
0005435212557	30595	Economy	14000.00
0005432211392	30595	Economy	14000.00
0005435725528	30595	Economy	14000.00
0005435212559	30595	Economy	14000.00
0005435212589	30595	Economy	14000.00
0005435212577	30595	Economy	14000.00
0005435212588	30595	Economy	14000.00
0005435212594	30595	Economy	14000.00
0005432159791	30595	Economy	14000.00
0005435212569	30595	Economy	14000.00
0005432211395	30595	Economy	14000.00
0005435212574	30595	Economy	14000.00
0005435212551	30595	Economy	14000.00
0005435212586	30595	Economy	14000.00
0005432211390	30595	Economy	14000.00
0005435212546	30595	Economy	14000.00
0005435212542	30595	Economy	14000.00
0005432211393	30595	Economy	14000.00
0005435212598	30595	Economy	14000.00
0005435212599	30595	Economy	14000.00
0005435212538	30595	Economy	14000.00
0005435212558	30595	Economy	14000.00
0005433656622	30595	Economy	14000.00
0005435725531	30595	Economy	14000.00
0005433656621	30595	Economy	14000.00
0005435212564	30595	Economy	14000.00
0005435212548	30595	Economy	14000.00
0005435212573	30595	Economy	14000.00
0005433367355	24854	Business	9800.00
0005433367334	24854	Business	9800.00
0005433367361	24854	Business	9800.00
0005433367367	24854	Business	9800.00
0005433367333	24854	Business	9800.00
0005433367341	24854	Business	9800.00
0005433367336	24854	Economy	3300.00
0005433367362	24854	Economy	3300.00
0005433367353	24854	Economy	3300.00
0005433367358	24854	Economy	3600.00
0005433367350	24854	Economy	3600.00
0005433367337	24854	Economy	3600.00
0005433367368	24854	Economy	3300.00
0005433367338	24854	Economy	3300.00
0005433367371	24854	Economy	3300.00
0005433367342	24854	Economy	3300.00
0005433367339	24854	Economy	3300.00
0005433367359	24854	Economy	3300.00
0005433367349	24854	Economy	3300.00
0005433367348	24854	Economy	3300.00
0005433367363	24854	Economy	3300.00
0005433367369	24854	Economy	3300.00
0005433367344	24854	Economy	3300.00
0005433367357	24854	Economy	3300.00
0005433367356	24854	Economy	3300.00
0005433367370	24854	Economy	3300.00
0005433367364	24854	Economy	3300.00
0005433367354	24854	Economy	3300.00
0005433367346	24854	Economy	3300.00
0005433367343	24854	Economy	3300.00
0005433367360	24854	Economy	3300.00
0005433367347	24854	Economy	3300.00
0005433367365	24854	Economy	3300.00
0005433367340	24854	Economy	3300.00
0005433367352	24854	Economy	3300.00
0005433367351	24854	Economy	3300.00
0005433367366	24854	Economy	3300.00
0005433367345	24854	Economy	3300.00
0005433367335	24854	Economy	3300.00
0005435949736	6594	Economy	20600.00
0005435949735	6594	Economy	18700.00
0005435949739	6594	Economy	18700.00
0005435949742	6594	Economy	18700.00
0005435949740	6594	Economy	18700.00
0005435949734	6594	Economy	18700.00
0005435949733	6594	Economy	18700.00
0005435949738	6594	Economy	18700.00
0005435949741	6594	Economy	18700.00
0005435949732	6594	Economy	18700.00
0005435949737	6594	Economy	18700.00
0005434979362	2031	Economy	10500.00
0005434979371	2031	Economy	10500.00
0005434979363	2031	Economy	10500.00
0005434979352	2031	Economy	9500.00
0005434979359	2031	Economy	9500.00
0005434979357	2031	Economy	9500.00
0005434979350	2031	Economy	9500.00
0005434979368	2031	Economy	9500.00
0005434979349	2031	Economy	9500.00
0005434979358	2031	Economy	9500.00
0005434979353	2031	Economy	9500.00
0005434979346	2031	Economy	9500.00
0005434979360	2031	Economy	9500.00
0005434979356	2031	Economy	9500.00
0005434979367	2031	Economy	9500.00
0005434979364	2031	Economy	9500.00
0005435801654	2031	Economy	9500.00
0005434979373	2031	Economy	9500.00
0005434979354	2031	Economy	9500.00
0005434979351	2031	Economy	9500.00
0005434979348	2031	Economy	9500.00
0005434979361	2031	Economy	9500.00
0005434979372	2031	Economy	9500.00
0005434979365	2031	Economy	9500.00
0005434979355	2031	Economy	9500.00
0005434979345	2031	Economy	9500.00
0005435801651	2031	Economy	9500.00
0005435801653	2031	Economy	9500.00
0005434979366	2031	Economy	9500.00
0005434979369	2031	Economy	9500.00
0005434979370	2031	Economy	9500.00
0005434979374	2031	Economy	9500.00
0005435801652	2031	Economy	9500.00
0005434979347	2031	Economy	9500.00
0005434952479	2561	Economy	5300.00
0005434952475	2561	Economy	5300.00
0005434952478	2561	Economy	5300.00
0005434952477	2561	Economy	5300.00
0005434952476	2561	Economy	5300.00
0005433256388	28264	Economy	5300.00
0005433256389	28264	Economy	5300.00
0005433256390	28264	Economy	5300.00
0005433112355	19830	Economy	8700.00
0005433111474	19830	Economy	8700.00
0005433111475	19830	Economy	8700.00
0005433112354	19830	Economy	8700.00
0005433112353	19830	Economy	8700.00
0005434136853	28769	Business	9700.00
0005434136869	28769	Business	9700.00
0005434136933	28769	Business	9700.00
0005434136916	28769	Business	9700.00
0005434136856	28769	Business	9700.00
0005434136898	28769	Business	9700.00
0005434136881	28769	Business	9700.00
0005434136885	28769	Business	9700.00
0005434136863	28769	Business	9700.00
0005434136896	28769	Business	9700.00
0005434136934	28769	Business	9700.00
0005434136901	28769	Economy	3200.00
0005434136922	28769	Economy	3200.00
0005434136919	28769	Economy	3200.00
0005434136884	28769	Economy	3200.00
0005434136889	28769	Economy	3200.00
0005434136907	28769	Economy	3200.00
0005434136923	28769	Economy	3200.00
0005434136908	28769	Economy	3200.00
0005434136877	28769	Economy	3200.00
0005434136859	28769	Economy	3200.00
0005434136893	28769	Economy	3500.00
0005434136850	28769	Economy	3500.00
0005434136880	28769	Economy	3500.00
0005434136906	28769	Economy	3500.00
0005434136852	28769	Economy	3200.00
0005434136847	28769	Economy	3200.00
0005434136854	28769	Economy	3200.00
0005434136861	28769	Economy	3200.00
0005434136900	28769	Economy	3200.00
0005434136855	28769	Economy	3200.00
0005434136888	28769	Economy	3200.00
0005434136873	28769	Economy	3200.00
0005434136883	28769	Economy	3200.00
0005434136845	28769	Economy	3200.00
0005434136904	28769	Economy	3200.00
0005434136913	28769	Economy	3200.00
0005434136930	28769	Economy	3200.00
0005434136912	28769	Economy	3200.00
0005434136932	28769	Economy	3200.00
0005434136886	28769	Economy	3200.00
0005434136862	28769	Economy	3200.00
0005434136903	28769	Economy	3200.00
0005434136914	28769	Economy	3200.00
0005434136909	28769	Economy	3200.00
0005434136925	28769	Economy	3200.00
0005434136890	28769	Economy	3200.00
0005434136915	28769	Economy	3200.00
0005434136874	28769	Economy	3200.00
0005434136848	28769	Economy	3200.00
0005434136860	28769	Economy	3200.00
0005434136899	28769	Economy	3200.00
0005434136910	28769	Economy	3200.00
0005434136858	28769	Economy	3200.00
0005434136917	28769	Economy	3200.00
0005434136868	28769	Economy	3200.00
0005434136870	28769	Economy	3200.00
0005434136921	28769	Economy	3200.00
0005434136864	28769	Economy	3200.00
0005434136851	28769	Economy	3200.00
0005434136882	28769	Economy	3200.00
0005434136887	28769	Economy	3200.00
0005434136902	28769	Economy	3200.00
0005434136927	28769	Economy	3200.00
0005434136875	28769	Economy	3200.00
0005434136878	28769	Economy	3200.00
0005434136867	28769	Economy	3200.00
0005434136924	28769	Economy	3200.00
0005434136931	28769	Economy	3200.00
0005434136879	28769	Economy	3200.00
0005434136894	28769	Economy	3200.00
0005434136846	28769	Economy	3200.00
0005434136895	28769	Economy	3200.00
0005434136876	28769	Economy	3200.00
0005434136926	28769	Economy	3200.00
0005434136891	28769	Economy	3200.00
0005434136849	28769	Economy	3200.00
0005434136897	28769	Economy	3200.00
0005434136866	28769	Economy	3200.00
0005434136911	28769	Economy	3200.00
0005434136918	28769	Economy	3200.00
0005434136929	28769	Economy	3200.00
0005434136928	28769	Economy	3200.00
0005434136872	28769	Economy	3200.00
0005434136857	28769	Economy	3200.00
0005434136920	28769	Economy	3200.00
0005434136905	28769	Economy	3200.00
0005434136892	28769	Economy	3200.00
0005434136865	28769	Economy	3200.00
0005434136871	28769	Economy	3200.00
0005433538750	6785	Economy	10900.00
0005433538746	6785	Economy	10900.00
0005433534468	6785	Economy	9900.00
0005433538749	6785	Economy	9900.00
0005433538743	6785	Economy	9900.00
0005433534467	6785	Economy	9900.00
0005433538744	6785	Economy	9900.00
0005433538747	6785	Economy	9900.00
0005433538745	6785	Economy	9900.00
0005433538742	6785	Economy	9900.00
0005433538748	6785	Economy	9900.00
0005435259695	25027	Economy	9900.00
0005435259694	25027	Economy	9900.00
0005435259692	25027	Economy	9900.00
0005435259691	25027	Economy	9900.00
0005435259693	25027	Economy	9900.00
0005433511834	800	Economy	14600.00
0005433511830	800	Economy	14600.00
0005433511831	800	Economy	14600.00
0005433511828	800	Economy	14600.00
0005433511835	800	Economy	14600.00
0005433511833	800	Economy	14600.00
0005433511829	800	Economy	14600.00
0005433511826	800	Economy	14600.00
0005433511827	800	Economy	14600.00
0005433511832	800	Economy	14600.00
0005432922467	16130	Economy	14600.00
0005432922468	16130	Economy	14600.00
0005432922466	16130	Economy	14600.00
0005432922465	16130	Economy	14600.00
0005435696931	3664	Economy	7900.00
0005435696952	3664	Economy	7900.00
0005434950467	3664	Economy	7900.00
0005434950465	3664	Economy	7200.00
0005435696940	3664	Economy	7200.00
0005435696943	3664	Economy	7200.00
0005435696944	3664	Economy	7200.00
0005435696937	3664	Economy	7200.00
0005435696954	3664	Economy	7200.00
0005435696955	3664	Economy	7200.00
0005435696953	3664	Economy	7200.00
0005435696938	3664	Economy	7200.00
0005435696947	3664	Economy	7200.00
0005435696930	3664	Economy	7200.00
0005435696929	3664	Economy	7200.00
0005434950466	3664	Economy	7200.00
0005435696949	3664	Economy	7200.00
0005435696956	3664	Economy	7200.00
0005435696932	3664	Economy	7200.00
0005435696939	3664	Economy	7200.00
0005435696933	3664	Economy	7200.00
0005435696948	3664	Economy	7200.00
0005435696951	3664	Economy	7200.00
0005435696934	3664	Economy	7200.00
0005434950464	3664	Economy	7200.00
0005435696936	3664	Economy	7200.00
0005435696941	3664	Economy	7200.00
0005435696935	3664	Economy	7200.00
0005435696957	3664	Economy	7200.00
0005434950463	3664	Economy	7200.00
0005435696942	3664	Economy	7200.00
0005435696950	3664	Economy	7200.00
0005435696946	3664	Economy	7200.00
0005435696945	3664	Economy	7200.00
0005435916128	16270	Economy	7200.00
0005435916127	16270	Economy	7200.00
0005435935001	16270	Economy	7200.00
0005435935000	16270	Economy	7200.00
0005435935002	16270	Economy	7200.00
0005435934999	16270	Economy	7200.00
0005434606772	3980	Economy	21300.00
0005432609675	3980	Economy	19300.00
0005433519391	3980	Economy	19300.00
0005435842312	3980	Economy	19300.00
0005432609674	3980	Economy	19300.00
0005432609673	3980	Economy	19300.00
0005432609672	3980	Economy	19300.00
0005432607507	3980	Economy	19300.00
0005434606775	3980	Economy	19300.00
0005432607506	3980	Economy	19300.00
0005433519393	3980	Economy	19300.00
0005433519390	3980	Economy	19300.00
0005433519394	3980	Economy	19300.00
0005434604846	3980	Economy	19300.00
0005433519392	3980	Economy	19300.00
0005434604847	3980	Economy	19300.00
0005435842313	3980	Economy	19300.00
0005432607509	3980	Economy	19300.00
0005434604848	3980	Economy	19300.00
0005434606773	3980	Economy	19300.00
0005432607508	3980	Economy	19300.00
0005434606774	3980	Economy	19300.00
0005435853586	22041	Economy	19300.00
0005435853585	22041	Economy	19300.00
0005435628678	680	Economy	3700.00
0005435628677	680	Economy	3700.00
0005433348906	15963	Economy	3700.00
0005433348907	15963	Economy	3700.00
0005433348905	15963	Economy	3700.00
0005433348908	15963	Economy	3700.00
0005433348909	15963	Economy	3700.00
0005433348904	15963	Economy	3700.00
0005434446482	17243	Economy	7100.00
0005434446485	17243	Economy	7100.00
0005434446483	17243	Economy	7100.00
0005434446484	17243	Economy	7100.00
0005434445213	17243	Economy	7100.00
0005434446486	17243	Economy	7100.00
0005434445212	17243	Economy	7100.00
0005433159281	17640	Economy	7100.00
0005433159282	17640	Economy	7100.00
0005435132728	7871	Economy	5400.00
0005435132732	7871	Economy	5400.00
0005435132734	7871	Economy	5400.00
0005435132733	7871	Economy	5400.00
0005435132737	7871	Economy	5400.00
0005435132727	7871	Economy	5400.00
0005435132736	7871	Economy	5400.00
0005435132726	7871	Economy	5400.00
0005435132730	7871	Economy	5400.00
0005435132735	7871	Economy	5400.00
0005435132729	7871	Economy	5400.00
0005435132731	7871	Economy	5400.00
0005435383073	33105	Economy	5400.00
0005435132702	33105	Economy	5400.00
0005435383075	33105	Economy	5400.00
0005435132704	33105	Economy	5400.00
0005435132699	33105	Economy	5400.00
0005435383072	33105	Economy	5400.00
0005435132703	33105	Economy	5400.00
0005435383074	33105	Economy	5400.00
0005435132700	33105	Economy	5400.00
0005435383071	33105	Economy	5400.00
0005435160145	7478	Economy	12500.00
0005435160149	7478	Economy	12500.00
0005435160144	7478	Economy	12500.00
0005435160146	7478	Economy	12500.00
0005435160142	7478	Economy	12500.00
0005435160138	7478	Economy	12500.00
0005435160139	7478	Economy	12500.00
0005435160140	7478	Economy	12500.00
0005435160148	7478	Economy	12500.00
0005435160141	7478	Economy	12500.00
0005435160137	7478	Economy	12500.00
0005435160143	7478	Economy	12500.00
0005435160147	7478	Economy	12500.00
0005435390144	29543	Economy	13800.00
0005435390143	29543	Economy	13800.00
0005435390141	29543	Economy	12500.00
0005435390142	29543	Economy	12500.00
0005435390140	29543	Economy	12500.00
0005435390139	29543	Economy	12500.00
0005435178475	18437	Economy	4900.00
0005435178474	18437	Economy	4900.00
0005432398138	27180	Economy	4900.00
0005432398139	27180	Economy	4900.00
0005432398140	27180	Economy	4900.00
0005432398141	27180	Economy	4900.00
0005432398136	27180	Economy	4900.00
0005432400066	27180	Economy	4900.00
0005432400067	27180	Economy	4900.00
0005432398137	27180	Economy	4900.00
0005432400065	27180	Economy	4900.00
0005432400068	27180	Economy	4900.00
0005434503607	6520	Business	48400.00
0005434503612	6520	Business	48400.00
0005434503600	6520	Business	48400.00
0005434503584	6520	Business	48400.00
0005434503592	6520	Economy	16100.00
0005434503595	6520	Economy	16100.00
0005435103826	6520	Economy	16100.00
0005434503591	6520	Economy	16100.00
0005434503613	6520	Economy	17800.00
0005434503601	6520	Economy	17800.00
0005434503589	6520	Economy	16100.00
0005434503581	6520	Economy	16100.00
0005434503585	6520	Economy	16100.00
0005434503582	6520	Economy	16100.00
0005434503611	6520	Economy	16100.00
0005434503596	6520	Economy	16100.00
0005434503616	6520	Economy	16100.00
0005434503579	6520	Economy	16100.00
0005434503608	6520	Economy	16100.00
0005434503602	6520	Economy	16100.00
0005434503618	6520	Economy	16100.00
0005435103827	6520	Economy	16100.00
0005434503609	6520	Economy	16100.00
0005434503605	6520	Economy	16100.00
0005434503606	6520	Economy	16100.00
0005434503604	6520	Economy	16100.00
0005434503598	6520	Economy	16100.00
0005434503597	6520	Economy	16100.00
0005435103825	6520	Economy	16100.00
0005434503587	6520	Economy	16100.00
0005434503617	6520	Economy	16100.00
0005434503599	6520	Economy	16100.00
0005434503586	6520	Economy	16100.00
0005434503593	6520	Economy	16100.00
0005434503614	6520	Economy	16100.00
0005434503603	6520	Economy	16100.00
0005434503580	6520	Economy	16100.00
0005434503615	6520	Economy	16100.00
0005434503588	6520	Economy	16100.00
0005434503590	6520	Economy	16100.00
0005434503583	6520	Economy	16100.00
0005434503578	6520	Economy	16100.00
0005434503594	6520	Economy	16100.00
0005434503610	6520	Economy	16100.00
0005435652390	1683	Business	50000.00
0005435652385	1683	Business	50000.00
0005435652388	1683	Business	50000.00
0005435652400	1683	Business	50000.00
0005435652427	1683	Business	50000.00
0005435652397	1683	Business	50000.00
0005435652406	1683	Economy	16700.00
0005435652408	1683	Economy	16700.00
0005435652414	1683	Economy	16700.00
0005435652415	1683	Economy	16700.00
0005435652420	1683	Economy	16700.00
0005435652425	1683	Economy	16700.00
0005435652434	1683	Economy	18300.00
0005435652391	1683	Economy	18300.00
0005435652392	1683	Economy	18300.00
0005435652410	1683	Economy	16700.00
0005435652401	1683	Economy	16700.00
0005435652430	1683	Economy	16700.00
0005435652384	1683	Economy	16700.00
0005435652403	1683	Economy	16700.00
0005435652432	1683	Economy	16700.00
0005435652404	1683	Economy	16700.00
0005435652429	1683	Economy	16700.00
0005435652407	1683	Economy	16700.00
0005435652435	1683	Economy	16700.00
0005435652409	1683	Economy	16700.00
0005435652398	1683	Economy	16700.00
0005435652424	1683	Economy	16700.00
0005435652389	1683	Economy	16700.00
0005435652393	1683	Economy	16700.00
0005435652402	1683	Economy	16700.00
0005435652418	1683	Economy	16700.00
0005435652399	1683	Economy	16700.00
0005435652428	1683	Economy	16700.00
0005435652416	1683	Economy	16700.00
0005435652387	1683	Economy	16700.00
0005435652413	1683	Economy	16700.00
0005435652422	1683	Economy	16700.00
0005435652396	1683	Economy	16700.00
0005435652433	1683	Economy	16700.00
0005435652417	1683	Economy	16700.00
0005435652421	1683	Economy	16700.00
0005435652431	1683	Economy	16700.00
0005435652386	1683	Economy	16700.00
0005435652426	1683	Economy	16700.00
0005435652411	1683	Economy	16700.00
0005435652405	1683	Economy	16700.00
0005435652412	1683	Economy	16700.00
0005435652395	1683	Economy	16700.00
0005435652394	1683	Economy	16700.00
0005435652419	1683	Economy	16700.00
0005435652423	1683	Economy	16700.00
0005433367363	21689	Business	50000.00
0005433367343	21689	Business	50000.00
0005433367345	21689	Business	50000.00
0005433367371	21689	Business	50000.00
0005433367357	21689	Business	50000.00
0005433367370	21689	Economy	16700.00
0005433367347	21689	Economy	16700.00
0005433367349	21689	Economy	16700.00
0005433367341	21689	Economy	16700.00
0005433367353	21689	Economy	18300.00
0005433367342	21689	Economy	16700.00
0005433367358	21689	Economy	16700.00
0005433367362	21689	Economy	16700.00
0005433367336	21689	Economy	16700.00
0005433367350	21689	Economy	16700.00
0005433367368	21689	Economy	16700.00
0005433367352	21689	Economy	16700.00
0005433367335	21689	Economy	16700.00
0005433367355	21689	Economy	16700.00
0005433367367	21689	Economy	16700.00
0005433367348	21689	Economy	16700.00
0005433367365	21689	Economy	16700.00
0005433367351	21689	Economy	16700.00
0005433367366	21689	Economy	16700.00
0005433367369	21689	Economy	16700.00
0005433367360	21689	Economy	16700.00
0005433367344	21689	Economy	16700.00
0005433367361	21689	Economy	16700.00
0005433367356	21689	Economy	16700.00
0005433367337	21689	Economy	16700.00
0005433367338	21689	Economy	16700.00
0005433367359	21689	Economy	16700.00
0005433367364	21689	Economy	16700.00
0005433367346	21689	Economy	16700.00
0005433367354	21689	Economy	16700.00
0005433367340	21689	Economy	16700.00
0005433367334	21689	Economy	16700.00
0005433367333	21689	Economy	16700.00
0005433367339	21689	Economy	16700.00
0005433985263	4159	Business	21500.00
0005435788735	4159	Business	21500.00
0005433985287	4159	Business	21500.00
0005433985301	4159	Business	21500.00
0005433985288	4159	Business	21500.00
0005433985275	4159	Business	21500.00
0005433985267	4159	Economy	7200.00
0005433985268	4159	Economy	7200.00
0005433985262	4159	Economy	7200.00
0005433985272	4159	Economy	7200.00
0005433985299	4159	Economy	7200.00
0005433985279	4159	Economy	7900.00
0005433985266	4159	Economy	7900.00
0005433985261	4159	Economy	7200.00
0005435788733	4159	Economy	7200.00
0005433985273	4159	Economy	7200.00
0005433985265	4159	Economy	7200.00
0005433985264	4159	Economy	7200.00
0005433985282	4159	Economy	7200.00
0005433985297	4159	Economy	7200.00
0005433985294	4159	Economy	7200.00
0005433985280	4159	Economy	7200.00
0005433985269	4159	Economy	7200.00
0005433985302	4159	Economy	7200.00
0005433985270	4159	Economy	7200.00
0005433985281	4159	Economy	7200.00
0005433985303	4159	Economy	7200.00
0005433985289	4159	Economy	7200.00
0005433985293	4159	Economy	7200.00
0005433985286	4159	Economy	7200.00
0005433985290	4159	Economy	7200.00
0005433985296	4159	Economy	7200.00
0005433985271	4159	Economy	7200.00
0005433985278	4159	Economy	7200.00
0005433985298	4159	Economy	7200.00
0005433985284	4159	Economy	7200.00
0005433985291	4159	Economy	7200.00
0005433985274	4159	Economy	7200.00
0005433985277	4159	Economy	7200.00
0005433985276	4159	Economy	7200.00
0005435788734	4159	Economy	7200.00
0005433985295	4159	Economy	7200.00
0005433985285	4159	Economy	7200.00
0005433985306	4159	Economy	7200.00
0005433985292	4159	Economy	7200.00
0005433985305	4159	Economy	7200.00
0005433985300	4159	Economy	7200.00
0005433985283	4159	Economy	7200.00
0005433985304	4159	Economy	7200.00
0005433985307	4159	Economy	7200.00
0005435719551	24767	Economy	9400.00
0005435719550	24767	Economy	9400.00
0005434516045	9024	Economy	23600.00
0005434516043	9024	Economy	23600.00
0005434516049	9024	Economy	23600.00
0005434516051	9024	Economy	23600.00
0005434516047	9024	Economy	23600.00
0005434516048	9024	Economy	23600.00
0005434516050	9024	Economy	23600.00
0005434516052	9024	Economy	23600.00
0005434516046	9024	Economy	23600.00
0005434516044	9024	Economy	23600.00
0005434151664	17850	Business	18000.00
0005432869433	17850	Business	18000.00
0005432869434	17850	Economy	6000.00
0005432869432	17850	Economy	6600.00
0005432869431	17850	Economy	6000.00
0005432869435	17850	Economy	6000.00
0005434151663	17850	Economy	6000.00
0005432869436	17850	Economy	6000.00
0005432869437	17850	Economy	6000.00
0005434151665	17850	Economy	6000.00
0005432657400	26329	Business	18000.00
0005432659673	26329	Business	18000.00
0005432666356	26329	Business	18000.00
0005432655345	26329	Business	18000.00
0005432665241	26329	Business	18000.00
0005432660787	26329	Economy	6000.00
0005432659674	26329	Economy	6000.00
0005432660785	26329	Economy	6000.00
0005432655342	26329	Economy	6000.00
0005432655341	26329	Economy	6000.00
0005432660784	26329	Economy	6600.00
0005432655347	26329	Economy	6600.00
0005432657401	26329	Economy	6600.00
0005432658558	26329	Economy	6000.00
0005432655343	26329	Economy	6000.00
0005432655340	26329	Economy	6000.00
0005432665243	26329	Economy	6000.00
0005432655344	26329	Economy	6000.00
0005432655338	26329	Economy	6000.00
0005432658559	26329	Economy	6000.00
0005432667421	26329	Economy	6000.00
0005432655348	26329	Economy	6000.00
0005432666357	26329	Economy	6000.00
0005432655346	26329	Economy	6000.00
0005432655339	26329	Economy	6000.00
0005432655349	26329	Economy	6000.00
0005432667422	26329	Economy	6000.00
0005432660786	26329	Economy	6000.00
0005432666355	26329	Economy	6000.00
0005432665242	26329	Economy	6000.00
0005432328052	3129	Business	16100.00
0005432287116	3129	Business	16100.00
0005432328060	3129	Business	16100.00
0005432328070	3129	Business	16100.00
0005432328073	3129	Business	16100.00
0005432328058	3129	Business	16100.00
0005432328039	3129	Business	16100.00
0005432328047	3129	Business	16100.00
0005432328059	3129	Economy	5400.00
0005432328043	3129	Economy	5400.00
0005432328076	3129	Economy	5400.00
0005432328042	3129	Economy	5400.00
0005432328044	3129	Economy	5400.00
0005432328038	3129	Economy	5900.00
0005432328066	3129	Economy	5900.00
0005432328048	3129	Economy	5900.00
0005432328041	3129	Economy	5400.00
0005432328051	3129	Economy	5400.00
0005432328033	3129	Economy	5400.00
0005432328067	3129	Economy	5400.00
0005432328056	3129	Economy	5400.00
0005432328050	3129	Economy	5400.00
0005432328036	3129	Economy	5400.00
0005432328032	3129	Economy	5400.00
0005432328037	3129	Economy	5400.00
0005432328054	3129	Economy	5400.00
0005432287118	3129	Economy	5400.00
0005432328046	3129	Economy	5400.00
0005432328065	3129	Economy	5400.00
0005432328061	3129	Economy	5400.00
0005432328069	3129	Economy	5400.00
0005432328063	3129	Economy	5400.00
0005432328077	3129	Economy	5400.00
0005432328057	3129	Economy	5400.00
0005432328055	3129	Economy	5400.00
0005432328071	3129	Economy	5400.00
0005432328072	3129	Economy	5400.00
0005432328075	3129	Economy	5400.00
0005432287119	3129	Economy	5400.00
0005432328062	3129	Economy	5400.00
0005432328053	3129	Economy	5400.00
0005432328068	3129	Economy	5400.00
0005432328064	3129	Economy	5400.00
0005432328035	3129	Economy	5400.00
0005432328045	3129	Economy	5400.00
0005432287117	3129	Economy	5400.00
0005432328049	3129	Economy	5400.00
0005432328040	3129	Economy	5400.00
0005432328034	3129	Economy	5400.00
0005432328074	3129	Economy	5400.00
0005432905037	31154	Business	16100.00
0005432054262	31154	Business	16100.00
0005432905041	31154	Business	16100.00
0005432905040	31154	Economy	5400.00
0005432905036	31154	Economy	5900.00
0005432327965	31154	Economy	5400.00
0005432905038	31154	Economy	5400.00
0005432905039	31154	Economy	5400.00
0005432054263	31154	Economy	5400.00
0005434309554	6196	Business	124600.00
0005434309548	6196	Business	124600.00
0005434309543	6196	Business	124600.00
0005434309553	6196	Business	124600.00
0005434309547	6196	Economy	41500.00
0005435999008	6196	Economy	41500.00
0005435998999	6196	Economy	41500.00
0005435999002	6196	Economy	41500.00
0005435999003	6196	Economy	41500.00
0005435999011	6196	Economy	41500.00
0005435999007	6196	Economy	41500.00
0005435999000	6196	Economy	41500.00
0005434309544	6196	Economy	41500.00
0005434309555	6196	Economy	41500.00
0005434309545	6196	Economy	41500.00
0005435999005	6196	Economy	41500.00
0005434309546	6196	Economy	41500.00
0005435999006	6196	Economy	41500.00
0005435999010	6196	Economy	41500.00
0005435999001	6196	Economy	41500.00
0005434309550	6196	Economy	41500.00
0005434309551	6196	Economy	41500.00
0005435999004	6196	Economy	41500.00
0005435999009	6196	Economy	41500.00
0005434309552	6196	Economy	41500.00
0005434309549	6196	Economy	41500.00
0005435999012	6196	Economy	41500.00
0005435296958	19581	Business	124600.00
0005435487507	19581	Economy	41500.00
0005435487517	19581	Economy	41500.00
0005435487519	19581	Economy	41500.00
0005435487500	19581	Economy	41500.00
0005435296960	19581	Economy	41500.00
0005435487512	19581	Economy	41500.00
0005435296959	19581	Economy	41500.00
0005435487511	19581	Economy	41500.00
0005435487514	19581	Economy	41500.00
0005435296963	19581	Economy	41500.00
0005435487499	19581	Economy	41500.00
0005435296964	19581	Economy	41500.00
0005435487510	19581	Economy	41500.00
0005435487518	19581	Economy	41500.00
0005435487501	19581	Economy	41500.00
0005435487515	19581	Economy	41500.00
0005435296961	19581	Economy	41500.00
0005435487504	19581	Economy	41500.00
0005435487505	19581	Economy	41500.00
0005435296962	19581	Economy	41500.00
0005435487509	19581	Economy	41500.00
0005435487506	19581	Economy	41500.00
0005435487508	19581	Economy	41500.00
0005435487513	19581	Economy	41500.00
0005435487498	19581	Economy	41500.00
0005435487503	19581	Economy	41500.00
0005435487516	19581	Economy	41500.00
0005435487502	19581	Economy	41500.00
0005434565728	1563	Business	86000.00
0005435517661	1563	Business	86000.00
0005434565724	1563	Business	86000.00
0005435502012	1563	Business	86000.00
0005435517650	1563	Business	86000.00
0005434565725	1563	Business	86000.00
0005435517666	1563	Business	86000.00
0005432291896	1563	Business	86000.00
0005435501998	1563	Business	86000.00
0005435502019	1563	Business	86000.00
0005435517656	1563	Economy	28700.00
0005434565729	1563	Economy	28700.00
0005434565720	1563	Economy	28700.00
0005435517657	1563	Economy	28700.00
0005434565726	1563	Economy	28700.00
0005435502000	1563	Economy	28700.00
0005435502004	1563	Economy	28700.00
0005435517648	1563	Economy	28700.00
0005435517649	1563	Economy	31500.00
0005435502011	1563	Economy	31500.00
0005435502005	1563	Economy	31500.00
0005435508205	1563	Economy	31500.00
0005435502015	1563	Economy	28700.00
0005434565722	1563	Economy	28700.00
0005435502017	1563	Economy	28700.00
0005435508206	1563	Economy	28700.00
0005435508200	1563	Economy	28700.00
0005435517654	1563	Economy	28700.00
0005435517665	1563	Economy	28700.00
0005435517662	1563	Economy	28700.00
0005435502020	1563	Economy	28700.00
0005435502008	1563	Economy	28700.00
0005435517655	1563	Economy	28700.00
0005435517660	1563	Economy	28700.00
0005435502009	1563	Economy	28700.00
0005435502010	1563	Economy	28700.00
0005435508204	1563	Economy	28700.00
0005434565721	1563	Economy	28700.00
0005432291895	1563	Economy	28700.00
0005435508203	1563	Economy	28700.00
0005434565730	1563	Economy	28700.00
0005434565733	1563	Economy	28700.00
0005435517663	1563	Economy	28700.00
0005434565723	1563	Economy	28700.00
0005435502001	1563	Economy	28700.00
0005435502016	1563	Economy	28700.00
0005435508208	1563	Economy	28700.00
0005435502014	1563	Economy	28700.00
0005435508209	1563	Economy	28700.00
0005435508199	1563	Economy	28700.00
0005435517667	1563	Economy	28700.00
0005435517664	1563	Economy	28700.00
0005435517658	1563	Economy	28700.00
0005432291897	1563	Economy	28700.00
0005435517653	1563	Economy	28700.00
0005435502006	1563	Economy	28700.00
0005435508202	1563	Economy	28700.00
0005435517652	1563	Economy	28700.00
0005435502013	1563	Economy	28700.00
0005434565727	1563	Economy	28700.00
0005435502003	1563	Economy	28700.00
0005435502018	1563	Economy	28700.00
0005434565731	1563	Economy	28700.00
0005435502007	1563	Economy	28700.00
0005434565719	1563	Economy	28700.00
0005434565732	1563	Economy	28700.00
0005434565718	1563	Economy	28700.00
0005435501999	1563	Economy	28700.00
0005435502002	1563	Economy	28700.00
0005435517651	1563	Economy	28700.00
0005435508201	1563	Economy	28700.00
0005435517659	1563	Economy	28700.00
0005435508207	1563	Economy	28700.00
0005433186000	20894	Economy	28700.00
0005433185999	20894	Economy	28700.00
0005433185996	20894	Economy	31500.00
0005433185998	20894	Economy	28700.00
0005433186002	20894	Economy	28700.00
0005433186001	20894	Economy	28700.00
0005433185995	20894	Economy	28700.00
0005433185997	20894	Economy	28700.00
0005433186003	20894	Economy	28700.00
0005435153652	3926	Economy	21600.00
0005435153646	3926	Economy	19700.00
0005435153648	3926	Economy	19700.00
0005435153651	3926	Economy	19700.00
0005435153647	3926	Economy	19700.00
0005435153649	3926	Economy	19700.00
0005435153650	3926	Economy	19700.00
0005435931548	21851	Economy	19700.00
0005435931550	21851	Economy	19700.00
0005435931549	21851	Economy	19700.00
0005435931551	21851	Economy	19700.00
0005435931547	21851	Economy	19700.00
0005435931546	21851	Economy	19700.00
0005432628635	7193	Economy	14300.00
0005432628642	7193	Economy	14300.00
0005432628646	7193	Economy	13000.00
0005432628643	7193	Economy	13000.00
0005432628639	7193	Economy	13000.00
0005432628640	7193	Economy	13000.00
0005432628644	7193	Economy	13000.00
0005432628634	7193	Economy	13000.00
0005432628632	7193	Economy	13000.00
0005432628645	7193	Economy	13000.00
0005432628633	7193	Economy	13000.00
0005432628638	7193	Economy	13000.00
0005432628631	7193	Economy	13000.00
0005432628641	7193	Economy	13000.00
0005432628636	7193	Economy	13000.00
0005432628637	7193	Economy	13000.00
0005435225468	28110	Economy	13000.00
0005435225469	28110	Economy	13000.00
0005435225470	28110	Economy	13000.00
0005435225474	28110	Economy	13000.00
0005435225467	28110	Economy	13000.00
0005435225471	28110	Economy	13000.00
0005435225473	28110	Economy	13000.00
0005435225472	28110	Economy	13000.00
0005435959995	8724	Economy	11500.00
0005435959994	8724	Economy	11500.00
0005435959996	8724	Economy	10500.00
0005435959997	8724	Economy	10500.00
0005434267894	15270	Economy	11500.00
0005434267895	15270	Economy	10500.00
0005434267897	15270	Economy	10500.00
0005434267898	15270	Economy	10500.00
0005434267896	15270	Economy	10500.00
0005432692598	1162	Business	115000.00
0005432692619	1162	Business	115000.00
0005432692605	1162	Business	115000.00
0005432692614	1162	Business	115000.00
0005432674911	1162	Business	115000.00
0005432692611	1162	Business	115000.00
0005432674919	1162	Business	115000.00
0005432674909	1162	Economy	38300.00
0005432674923	1162	Economy	38300.00
0005432692613	1162	Economy	38300.00
0005432692591	1162	Economy	38300.00
0005432692608	1162	Economy	38300.00
0005432692615	1162	Economy	42200.00
0005432674913	1162	Economy	42200.00
0005432692621	1162	Economy	42200.00
0005432674914	1162	Economy	38300.00
0005432677514	1162	Economy	38300.00
0005432677511	1162	Economy	38300.00
0005432692606	1162	Economy	38300.00
0005432692600	1162	Economy	38300.00
0005432674920	1162	Economy	38300.00
0005432692602	1162	Economy	38300.00
0005432692609	1162	Economy	38300.00
0005432692601	1162	Economy	38300.00
0005432692612	1162	Economy	38300.00
0005432692610	1162	Economy	38300.00
0005432677512	1162	Economy	38300.00
0005432692595	1162	Economy	38300.00
0005432692599	1162	Economy	38300.00
0005432692618	1162	Economy	38300.00
0005432692620	1162	Economy	38300.00
0005432674917	1162	Economy	38300.00
0005432692617	1162	Economy	38300.00
0005432674910	1162	Economy	38300.00
0005432692616	1162	Economy	38300.00
0005432692597	1162	Economy	38300.00
0005432674916	1162	Economy	38300.00
0005432692594	1162	Economy	38300.00
0005432692590	1162	Economy	38300.00
0005432674922	1162	Economy	38300.00
0005432674921	1162	Economy	38300.00
0005432674912	1162	Economy	38300.00
0005432692603	1162	Economy	38300.00
0005432692596	1162	Economy	38300.00
0005432692592	1162	Economy	38300.00
0005432692607	1162	Economy	38300.00
0005432674918	1162	Economy	38300.00
0005432692604	1162	Economy	38300.00
0005432674915	1162	Economy	38300.00
0005432692593	1162	Economy	38300.00
0005432677513	1162	Economy	38300.00
0005432873187	17463	Business	115000.00
0005432873195	17463	Business	115000.00
0005432873190	17463	Economy	38300.00
0005432873188	17463	Economy	38300.00
0005432674872	17463	Economy	38300.00
0005432873189	17463	Economy	38300.00
0005432873192	17463	Economy	38300.00
0005432873191	17463	Economy	38300.00
0005432873193	17463	Economy	38300.00
0005432873194	17463	Economy	38300.00
0005434434963	1132	Economy	13900.00
0005434434959	1132	Economy	13900.00
0005434434956	1132	Economy	13900.00
0005434434958	1132	Economy	13900.00
0005434434970	1132	Economy	13900.00
0005434434965	1132	Economy	13900.00
0005434434960	1132	Economy	13900.00
0005434434967	1132	Economy	13900.00
0005434434969	1132	Economy	13900.00
0005434434968	1132	Economy	13900.00
0005434434961	1132	Economy	13900.00
0005434434964	1132	Economy	13900.00
0005434434957	1132	Economy	13900.00
0005434434962	1132	Economy	13900.00
0005434434966	1132	Economy	13900.00
0005433156623	17312	Economy	13900.00
0005433156629	17312	Economy	13900.00
0005433156625	17312	Economy	13900.00
0005433156627	17312	Economy	13900.00
0005433156626	17312	Economy	13900.00
0005433156628	17312	Economy	13900.00
0005433156630	17312	Economy	13900.00
0005433156622	17312	Economy	13900.00
0005433156624	17312	Economy	13900.00
0005435086724	4063	Economy	8200.00
0005435086727	4063	Economy	7500.00
0005435086725	4063	Economy	7500.00
0005435086726	4063	Economy	7500.00
0005435086730	4063	Economy	7500.00
0005435086728	4063	Economy	7500.00
0005435086723	4063	Economy	7500.00
0005435086729	4063	Economy	7500.00
0005435928077	24402	Economy	7500.00
0005435928076	24402	Economy	7500.00
0005435928075	24402	Economy	7500.00
0005435928072	24402	Economy	7500.00
0005435928073	24402	Economy	7500.00
0005435928074	24402	Economy	7500.00
0005435551509	17011	Business	144300.00
0005435098524	17011	Business	144300.00
0005435551495	17011	Business	144300.00
0005435551500	17011	Business	144300.00
0005435098525	17011	Business	144300.00
0005435551511	17011	Business	144300.00
0005435098526	17011	Economy	52900.00
0005435551498	17011	Economy	52900.00
0005435551499	17011	Economy	48100.00
0005435098527	17011	Economy	48100.00
0005435551504	17011	Economy	48100.00
0005435098528	17011	Economy	48100.00
0005435551497	17011	Economy	48100.00
0005435551506	17011	Economy	48100.00
0005435098523	17011	Economy	48100.00
0005435551505	17011	Economy	48100.00
0005435551496	17011	Economy	48100.00
0005435551512	17011	Economy	48100.00
0005435551507	17011	Economy	48100.00
0005435551501	17011	Economy	48100.00
0005435551494	17011	Economy	48100.00
0005435551510	17011	Economy	48100.00
0005435551503	17011	Economy	48100.00
0005435551502	17011	Economy	48100.00
0005435551508	17011	Economy	48100.00
0005433261414	18242	Business	203300.00
0005433261427	18242	Economy	67800.00
0005433261423	18242	Economy	67800.00
0005433261410	18242	Economy	67800.00
0005433261417	18242	Economy	67800.00
0005433261425	18242	Economy	67800.00
0005433261419	18242	Economy	67800.00
0005433261428	18242	Economy	67800.00
0005433261411	18242	Economy	67800.00
0005433261422	18242	Economy	67800.00
0005433261420	18242	Economy	67800.00
0005433261424	18242	Economy	67800.00
0005433261413	18242	Economy	67800.00
0005433261426	18242	Economy	67800.00
0005433261415	18242	Economy	74500.00
0005433261412	18242	Economy	67800.00
0005433261409	18242	Economy	67800.00
0005433261421	18242	Economy	67800.00
0005433261416	18242	Economy	67800.00
0005434963906	18242	Economy	67800.00
0005433261418	18242	Economy	67800.00
0005433261429	18242	Economy	67800.00
0005434625824	4849	Business	44200.00
0005434625830	4849	Economy	14700.00
0005434625825	4849	Economy	14700.00
0005434625831	4849	Economy	14700.00
0005434625823	4849	Economy	14700.00
0005434625827	4849	Economy	14700.00
0005434625828	4849	Economy	14700.00
0005434625829	4849	Economy	14700.00
0005434625832	4849	Economy	14700.00
0005434625826	4849	Economy	14700.00
0005435907436	32884	Business	44200.00
0005435907437	32884	Economy	14700.00
0005435907433	32884	Economy	14700.00
0005435907435	32884	Economy	14700.00
0005433194824	32884	Economy	14700.00
0005435907434	32884	Economy	14700.00
0005433194825	32884	Economy	14700.00
0005435907432	32884	Economy	14700.00
0005432195662	13752	Economy	3100.00
0005435937328	13752	Economy	3100.00
0005435937327	13752	Economy	3100.00
0005432195663	13752	Economy	3100.00
0005435784803	27423	Economy	3400.00
0005435784817	27423	Economy	3400.00
0005435784809	27423	Economy	3400.00
0005435784815	27423	Economy	3400.00
0005432190570	27423	Economy	3100.00
0005435784804	27423	Economy	3100.00
0005435784818	27423	Economy	3100.00
0005435784828	27423	Economy	3100.00
0005435784824	27423	Economy	3100.00
0005435784801	27423	Economy	3100.00
0005435784810	27423	Economy	3100.00
0005435784805	27423	Economy	3100.00
0005435787322	27423	Economy	3100.00
0005435784832	27423	Economy	3100.00
0005432190568	27423	Economy	3100.00
0005435784808	27423	Economy	3100.00
0005435784831	27423	Economy	3100.00
0005435784812	27423	Economy	3100.00
0005435784813	27423	Economy	3100.00
0005435784820	27423	Economy	3100.00
0005435784829	27423	Economy	3100.00
0005435784825	27423	Economy	3100.00
0005435784800	27423	Economy	3100.00
0005435787323	27423	Economy	3100.00
0005435784802	27423	Economy	3100.00
0005435784814	27423	Economy	3100.00
0005435784821	27423	Economy	3100.00
0005435784816	27423	Economy	3100.00
0005435784833	27423	Economy	3100.00
0005435784823	27423	Economy	3100.00
0005435784830	27423	Economy	3100.00
0005435784826	27423	Economy	3100.00
0005435784819	27423	Economy	3100.00
0005435784807	27423	Economy	3100.00
0005435784822	27423	Economy	3100.00
0005435784806	27423	Economy	3100.00
0005432190569	27423	Economy	3100.00
0005435784827	27423	Economy	3100.00
0005435784811	27423	Economy	3100.00
0005435784799	27423	Economy	3100.00
0005435310903	20251	Business	12000.00
0005435310900	20251	Economy	4000.00
0005435310901	20251	Economy	4000.00
0005435310904	20251	Economy	4000.00
0005435310896	20251	Economy	4000.00
0005435310895	20251	Economy	4000.00
0005432058326	20251	Economy	4000.00
0005435310897	20251	Economy	4000.00
0005435310899	20251	Economy	4000.00
0005432058327	20251	Economy	4000.00
0005435310905	20251	Economy	4000.00
0005435310902	20251	Economy	4000.00
0005435310898	20251	Economy	4000.00
0005432058325	20251	Economy	4000.00
0005434406850	26959	Business	12000.00
0005434406877	26959	Business	12000.00
0005432153838	26959	Business	12000.00
0005434406856	26959	Business	12000.00
0005434406830	26959	Business	12000.00
0005434406858	26959	Business	12000.00
0005432153834	26959	Business	12000.00
0005434406865	26959	Economy	4000.00
0005434406894	26959	Economy	4000.00
0005434406870	26959	Economy	4000.00
0005434406881	26959	Economy	4000.00
0005434406886	26959	Economy	4000.00
0005434406879	26959	Economy	4000.00
0005432153840	26959	Economy	4000.00
0005434406889	26959	Economy	4400.00
0005434406866	26959	Economy	4400.00
0005434406857	26959	Economy	4400.00
0005434406864	26959	Economy	4400.00
0005434406837	26959	Economy	4400.00
0005434406835	26959	Economy	4000.00
0005434406892	26959	Economy	4000.00
0005434406884	26959	Economy	4000.00
0005434406832	26959	Economy	4000.00
0005432153842	26959	Economy	4000.00
0005434406855	26959	Economy	4000.00
0005434406851	26959	Economy	4000.00
0005434406867	26959	Economy	4000.00
0005434406842	26959	Economy	4000.00
0005434406847	26959	Economy	4000.00
0005434406831	26959	Economy	4000.00
0005434406836	26959	Economy	4000.00
0005434406844	26959	Economy	4000.00
0005434406846	26959	Economy	4000.00
0005434406868	26959	Economy	4000.00
0005432153837	26959	Economy	4000.00
0005434406882	26959	Economy	4000.00
0005434406839	26959	Economy	4000.00
0005434406880	26959	Economy	4000.00
0005434406853	26959	Economy	4000.00
0005434406890	26959	Economy	4000.00
0005434406888	26959	Economy	4000.00
0005434406860	26959	Economy	4000.00
0005434406862	26959	Economy	4000.00
0005432153836	26959	Economy	4000.00
0005434406852	26959	Economy	4000.00
0005434406887	26959	Economy	4000.00
0005434406873	26959	Economy	4000.00
0005434406875	26959	Economy	4000.00
0005432153835	26959	Economy	4000.00
0005434406840	26959	Economy	4000.00
0005434406878	26959	Economy	4000.00
0005434406833	26959	Economy	4000.00
0005434406863	26959	Economy	4000.00
0005434406859	26959	Economy	4000.00
0005434406883	26959	Economy	4000.00
0005434406885	26959	Economy	4000.00
0005434406874	26959	Economy	4000.00
0005434406854	26959	Economy	4000.00
0005434406838	26959	Economy	4000.00
0005434406845	26959	Economy	4000.00
0005434406861	26959	Economy	4000.00
0005434406841	26959	Economy	4000.00
0005434406893	26959	Economy	4000.00
0005434406849	26959	Economy	4000.00
0005432153839	26959	Economy	4000.00
0005434406876	26959	Economy	4000.00
0005434406848	26959	Economy	4000.00
0005432153841	26959	Economy	4000.00
0005434406834	26959	Economy	4000.00
0005434406871	26959	Economy	4000.00
0005434406843	26959	Economy	4000.00
0005434406869	26959	Economy	4000.00
0005434406872	26959	Economy	4000.00
0005434406891	26959	Economy	4000.00
0005432109664	5676	Business	43300.00
0005434319190	5676	Business	43300.00
0005432109662	5676	Economy	15900.00
0005434319191	5676	Economy	14400.00
0005432109666	5676	Economy	14400.00
0005434319187	5676	Economy	14400.00
0005434319192	5676	Economy	14400.00
0005434319189	5676	Economy	14400.00
0005432109663	5676	Economy	14400.00
0005432109665	5676	Economy	14400.00
0005432109667	5676	Economy	14400.00
0005434319186	5676	Economy	14400.00
0005434319188	5676	Economy	14400.00
0005434311188	5676	Economy	14400.00
0005433123648	15679	Business	43300.00
0005433123640	15679	Business	43300.00
0005433123638	15679	Business	43300.00
0005433123634	15679	Economy	14400.00
0005433123645	15679	Economy	14400.00
0005433123642	15679	Economy	14400.00
0005433123646	15679	Economy	15900.00
0005433123650	15679	Economy	14400.00
0005433123641	15679	Economy	14400.00
0005433123636	15679	Economy	14400.00
0005433123635	15679	Economy	14400.00
0005433123644	15679	Economy	14400.00
0005433123643	15679	Economy	14400.00
0005433123651	15679	Economy	14400.00
0005433123655	15679	Economy	14400.00
0005433123653	15679	Economy	14400.00
0005433123649	15679	Economy	14400.00
0005433123652	15679	Economy	14400.00
0005433123637	15679	Economy	14400.00
0005433123647	15679	Economy	14400.00
0005433123654	15679	Economy	14400.00
0005433123639	15679	Economy	14400.00
0005435217677	24965	Economy	15500.00
0005434484253	8997	Economy	27400.00
0005434484252	8997	Economy	24900.00
0005434484257	8997	Economy	24900.00
0005434484256	8997	Economy	24900.00
0005434484254	8997	Economy	24900.00
0005434484255	8997	Economy	24900.00
0005434189097	16669	Economy	24900.00
0005434189094	16669	Economy	24900.00
0005434189096	16669	Economy	24900.00
0005434189095	16669	Economy	24900.00
0005434189098	16669	Economy	24900.00
0005434189093	16669	Economy	24900.00
0005433123649	7599	Business	11100.00
0005433123651	7599	Business	11100.00
0005433123638	7599	Business	11100.00
0005433123636	7599	Business	11100.00
0005433123654	7599	Business	11100.00
0005433123640	7599	Economy	3700.00
0005433123639	7599	Economy	3700.00
0005433123647	7599	Economy	4100.00
0005433123646	7599	Economy	3700.00
0005433123645	7599	Economy	3700.00
0005433123643	7599	Economy	3700.00
0005433123641	7599	Economy	3700.00
0005433123642	7599	Economy	3700.00
0005433123653	7599	Economy	3700.00
0005433123634	7599	Economy	3700.00
0005433123655	7599	Economy	3700.00
0005433123648	7599	Economy	3700.00
0005433123644	7599	Economy	3700.00
0005433123637	7599	Economy	3700.00
0005433123635	7599	Economy	3700.00
0005433123652	7599	Economy	3700.00
0005433123650	7599	Economy	3700.00
0005432692630	7598	Business	11100.00
0005432720518	7598	Business	11100.00
0005433449656	7598	Business	11100.00
0005433449666	7598	Business	11100.00
0005432720515	7598	Business	11100.00
0005433449667	7598	Business	11100.00
0005432692627	7598	Business	11100.00
0005433449650	7598	Business	11100.00
0005433449652	7598	Business	11100.00
0005433449657	7598	Business	11100.00
0005432071531	7598	Business	11100.00
0005432692652	7598	Economy	3700.00
0005432720514	7598	Economy	3700.00
0005433449659	7598	Economy	3700.00
0005432692622	7598	Economy	3700.00
0005432720534	7598	Economy	3700.00
0005432720510	7598	Economy	3700.00
0005432720521	7598	Economy	3700.00
0005432692635	7598	Economy	3700.00
0005433449662	7598	Economy	4100.00
0005433449658	7598	Economy	4100.00
0005432720511	7598	Economy	4100.00
0005433449669	7598	Economy	4100.00
0005432692648	7598	Economy	3700.00
0005432692637	7598	Economy	3700.00
0005432720532	7598	Economy	3700.00
0005432720523	7598	Economy	3700.00
0005432071532	7598	Economy	3700.00
0005433449661	7598	Economy	3700.00
0005432720527	7598	Economy	3700.00
0005432692642	7598	Economy	3700.00
0005432692625	7598	Economy	3700.00
0005432720530	7598	Economy	3700.00
0005432720535	7598	Economy	3700.00
0005432692650	7598	Economy	3700.00
0005432692641	7598	Economy	3700.00
0005432720516	7598	Economy	3700.00
0005432720519	7598	Economy	3700.00
0005432692651	7598	Economy	3700.00
0005432720520	7598	Economy	3700.00
0005432692643	7598	Economy	3700.00
0005432692645	7598	Economy	3700.00
0005432692631	7598	Economy	3700.00
0005432720522	7598	Economy	3700.00
0005432720513	7598	Economy	3700.00
0005432692640	7598	Economy	3700.00
0005432692636	7598	Economy	3700.00
0005432720533	7598	Economy	3700.00
0005432720528	7598	Economy	3700.00
0005432692632	7598	Economy	3700.00
0005432692633	7598	Economy	3700.00
0005432692639	7598	Economy	3700.00
0005432720524	7598	Economy	3700.00
0005432692638	7598	Economy	3700.00
0005433449651	7598	Economy	3700.00
0005432720526	7598	Economy	3700.00
0005432692629	7598	Economy	3700.00
0005432692623	7598	Economy	3700.00
0005432692634	7598	Economy	3700.00
0005432720517	7598	Economy	3700.00
0005433449663	7598	Economy	3700.00
0005432720537	7598	Economy	3700.00
0005432720536	7598	Economy	3700.00
0005432692626	7598	Economy	3700.00
0005432692647	7598	Economy	3700.00
0005433449660	7598	Economy	3700.00
0005432692628	7598	Economy	3700.00
0005432720512	7598	Economy	3700.00
0005433449671	7598	Economy	3700.00
0005433449668	7598	Economy	3700.00
0005432720525	7598	Economy	3700.00
0005432692624	7598	Economy	3700.00
0005433449665	7598	Economy	3700.00
0005432720531	7598	Economy	3700.00
0005433449655	7598	Economy	3700.00
0005432692644	7598	Economy	3700.00
0005433449670	7598	Economy	3700.00
0005433449654	7598	Economy	3700.00
0005433449664	7598	Economy	3700.00
0005432720529	7598	Economy	3700.00
0005432692649	7598	Economy	3700.00
0005433449653	7598	Economy	3700.00
0005432692646	7598	Economy	3700.00
0005433722127	30428	Business	11100.00
0005433722125	30428	Economy	3700.00
0005432720477	30428	Economy	3700.00
0005433722124	30428	Economy	4100.00
0005433722121	30428	Economy	3700.00
0005433722126	30428	Economy	3700.00
0005433722123	30428	Economy	3700.00
0005433722122	30428	Economy	3700.00
0005434586238	1357	Business	70400.00
0005434586239	1357	Business	70400.00
0005434586251	1357	Business	70400.00
0005433524881	1357	Business	70400.00
0005434586260	1357	Business	70400.00
0005434586261	1357	Business	70400.00
0005433524888	1357	Business	70400.00
0005433524885	1357	Business	70400.00
0005434586259	1357	Economy	23500.00
0005433524886	1357	Economy	23500.00
0005433524889	1357	Economy	23500.00
0005434586252	1357	Economy	23500.00
0005432270965	1357	Economy	23500.00
0005432270962	1357	Economy	23500.00
0005433724741	1357	Economy	23500.00
0005434586243	1357	Economy	25800.00
0005434586244	1357	Economy	25800.00
0005434586242	1357	Economy	23500.00
0005434513541	1357	Economy	23500.00
0005434586247	1357	Economy	23500.00
0005434586250	1357	Economy	23500.00
0005434586249	1357	Economy	23500.00
0005434586253	1357	Economy	23500.00
0005434586256	1357	Economy	23500.00
0005433724739	1357	Economy	23500.00
0005434514930	1357	Economy	23500.00
0005434586257	1357	Economy	23500.00
0005433524887	1357	Economy	23500.00
0005434514929	1357	Economy	23500.00
0005434586241	1357	Economy	23500.00
0005434586258	1357	Economy	23500.00
0005433524882	1357	Economy	23500.00
0005434586236	1357	Economy	23500.00
0005433724740	1357	Economy	23500.00
0005433524883	1357	Economy	23500.00
0005434513542	1357	Economy	23500.00
0005434586245	1357	Economy	23500.00
0005434586240	1357	Economy	23500.00
0005433524884	1357	Economy	23500.00
0005432270963	1357	Economy	23500.00
0005434586248	1357	Economy	23500.00
0005432270964	1357	Economy	23500.00
0005434586246	1357	Economy	23500.00
0005433724742	1357	Economy	23500.00
0005434586237	1357	Economy	23500.00
0005434586255	1357	Economy	23500.00
0005434514931	1357	Economy	23500.00
0005434586254	1357	Economy	23500.00
0005434586165	18548	Business	70400.00
0005432927901	18548	Business	70400.00
0005432968807	18548	Business	70400.00
0005433192857	18548	Business	70400.00
0005433192854	18548	Economy	23500.00
0005432927898	18548	Economy	23500.00
0005433192855	18548	Economy	25800.00
0005434586164	18548	Economy	25800.00
0005433192863	18548	Economy	23500.00
0005433192851	18548	Economy	23500.00
0005433192852	18548	Economy	23500.00
0005433192856	18548	Economy	23500.00
0005432927902	18548	Economy	23500.00
0005433192861	18548	Economy	23500.00
0005433192853	18548	Economy	23500.00
0005433192850	18548	Economy	23500.00
0005433192858	18548	Economy	23500.00
0005433192860	18548	Economy	23500.00
0005432968806	18548	Economy	23500.00
0005432927900	18548	Economy	23500.00
0005434586177	18548	Economy	23500.00
0005432927897	18548	Economy	23500.00
0005433192862	18548	Economy	23500.00
0005432927899	18548	Economy	23500.00
0005433192859	18548	Economy	23500.00
0005434343680	11444	Economy	4300.00
0005434343671	11444	Economy	4300.00
0005434343677	11444	Economy	4000.00
0005434343681	11444	Economy	4000.00
0005434343659	11444	Economy	4000.00
0005434142554	11444	Economy	4000.00
0005434343668	11444	Economy	4000.00
0005434343670	11444	Economy	4000.00
0005434343683	11444	Economy	4000.00
0005434343678	11444	Economy	4000.00
0005434343682	11444	Economy	4000.00
0005434343665	11444	Economy	4000.00
0005434343667	11444	Economy	4000.00
0005434343654	11444	Economy	4000.00
0005434343679	11444	Economy	4000.00
0005434343660	11444	Economy	4000.00
0005434343662	11444	Economy	4000.00
0005434343669	11444	Economy	4000.00
0005434343664	11444	Economy	4000.00
0005434343676	11444	Economy	4000.00
0005434343674	11444	Economy	4000.00
0005434343661	11444	Economy	4000.00
0005434343685	11444	Economy	4000.00
0005434343652	11444	Economy	4000.00
0005434343675	11444	Economy	4000.00
0005434343651	11444	Economy	4000.00
0005434343656	11444	Economy	4000.00
0005434343684	11444	Economy	4000.00
0005434343663	11444	Economy	4000.00
0005434343653	11444	Economy	4000.00
0005434142555	11444	Economy	4000.00
0005434343672	11444	Economy	4000.00
0005434343673	11444	Economy	4000.00
0005434343655	11444	Economy	4000.00
0005434343657	11444	Economy	4000.00
0005434343658	11444	Economy	4000.00
0005434343666	11444	Economy	4000.00
0005435304995	29782	Economy	4300.00
0005435304107	29782	Economy	4000.00
0005435304105	29782	Economy	4000.00
0005435304996	29782	Economy	4000.00
0005435304106	29782	Economy	4000.00
0005435304104	29782	Economy	4000.00
0005435304108	29782	Economy	4000.00
0005435304997	29782	Economy	4000.00
0005435824253	1302	Business	199800.00
0005435824259	1302	Business	199800.00
0005435824242	1302	Business	199800.00
0005435824243	1302	Business	199800.00
0005435824248	1302	Economy	66600.00
0005435824235	1302	Economy	66600.00
0005435824257	1302	Economy	66600.00
0005435824236	1302	Economy	66600.00
0005435824247	1302	Economy	66600.00
0005435824254	1302	Economy	73200.00
0005432284516	1302	Economy	66600.00
0005435824233	1302	Economy	66600.00
0005432284515	1302	Economy	66600.00
0005435824255	1302	Economy	66600.00
0005435824244	1302	Economy	66600.00
0005435824239	1302	Economy	66600.00
0005435824246	1302	Economy	66600.00
0005435824234	1302	Economy	66600.00
0005435824237	1302	Economy	66600.00
0005435824249	1302	Economy	66600.00
0005435824241	1302	Economy	66600.00
0005435824258	1302	Economy	66600.00
0005435824245	1302	Economy	66600.00
0005435824260	1302	Economy	66600.00
0005435824250	1302	Economy	66600.00
0005435824240	1302	Economy	66600.00
0005435824251	1302	Economy	66600.00
0005435824252	1302	Economy	66600.00
0005435824261	1302	Economy	66600.00
0005435824256	1302	Economy	66600.00
0005435824238	1302	Economy	66600.00
0005432284517	1302	Economy	66600.00
0005433415429	17995	Business	199800.00
0005433415433	17995	Economy	66600.00
0005433415427	17995	Economy	66600.00
0005433415435	17995	Economy	66600.00
0005433415442	17995	Economy	66600.00
0005433415441	17995	Economy	66600.00
0005433415431	17995	Economy	66600.00
0005433415434	17995	Economy	66600.00
0005433415438	17995	Economy	66600.00
0005433415430	17995	Economy	66600.00
0005433415428	17995	Economy	66600.00
0005433415444	17995	Economy	66600.00
0005433415437	17995	Economy	66600.00
0005433415439	17995	Economy	66600.00
0005433415443	17995	Economy	66600.00
0005433415436	17995	Economy	66600.00
0005433415440	17995	Economy	66600.00
0005433415432	17995	Economy	66600.00
0005432783047	5634	Business	27800.00
0005432143942	5634	Business	27800.00
0005432783043	5634	Business	27800.00
0005432783017	5634	Business	27800.00
0005432783024	5634	Business	27800.00
0005432783003	5634	Business	27800.00
0005432783051	5634	Business	27800.00
0005432783029	5634	Business	27800.00
0005432783005	5634	Business	27800.00
0005432143941	5634	Economy	9300.00
0005432783028	5634	Economy	9300.00
0005432783048	5634	Economy	9300.00
0005432783046	5634	Economy	9300.00
0005432783031	5634	Economy	9300.00
0005432783035	5634	Economy	9300.00
0005432783006	5634	Economy	10200.00
0005432783033	5634	Economy	10200.00
0005432783007	5634	Economy	9300.00
0005432783011	5634	Economy	9300.00
0005432783056	5634	Economy	9300.00
0005432783038	5634	Economy	9300.00
0005432783041	5634	Economy	9300.00
0005432783012	5634	Economy	9300.00
0005432783004	5634	Economy	9300.00
0005432783015	5634	Economy	9300.00
0005432783053	5634	Economy	9300.00
0005432783016	5634	Economy	9300.00
0005432783008	5634	Economy	9300.00
0005432783057	5634	Economy	9300.00
0005432783019	5634	Economy	9300.00
0005432783049	5634	Economy	9300.00
0005432783025	5634	Economy	9300.00
0005432783023	5634	Economy	9300.00
0005432783037	5634	Economy	9300.00
0005432783014	5634	Economy	9300.00
0005432783018	5634	Economy	9300.00
0005432783040	5634	Economy	9300.00
0005432783009	5634	Economy	9300.00
0005432783020	5634	Economy	9300.00
0005432783034	5634	Economy	9300.00
0005432783027	5634	Economy	9300.00
0005432783022	5634	Economy	9300.00
0005432783026	5634	Economy	9300.00
0005432783030	5634	Economy	9300.00
0005432783055	5634	Economy	9300.00
0005432783013	5634	Economy	9300.00
0005432143939	5634	Economy	9300.00
0005432783042	5634	Economy	9300.00
0005432783039	5634	Economy	9300.00
0005432783010	5634	Economy	9300.00
0005432783050	5634	Economy	9300.00
0005432783021	5634	Economy	9300.00
0005432783054	5634	Economy	9300.00
0005432143940	5634	Economy	9300.00
0005432783032	5634	Economy	9300.00
0005432783036	5634	Economy	9300.00
0005432783044	5634	Economy	9300.00
0005432783052	5634	Economy	9300.00
0005432783045	5634	Economy	9300.00
0005435242453	15392	Business	27800.00
0005435242455	15392	Business	27800.00
0005435242460	15392	Business	27800.00
0005435242463	15392	Business	27800.00
0005435242449	15392	Economy	9300.00
0005435242456	15392	Economy	9300.00
0005435242464	15392	Economy	9300.00
0005435242448	15392	Economy	10200.00
0005435476655	15392	Economy	9300.00
0005435242451	15392	Economy	9300.00
0005435242443	15392	Economy	9300.00
0005435242458	15392	Economy	9300.00
0005435242445	15392	Economy	9300.00
0005435242469	15392	Economy	9300.00
0005435242452	15392	Economy	9300.00
0005435242446	15392	Economy	9300.00
0005435242462	15392	Economy	9300.00
0005435476656	15392	Economy	9300.00
0005435242459	15392	Economy	9300.00
0005435242465	15392	Economy	9300.00
0005435242468	15392	Economy	9300.00
0005435242447	15392	Economy	9300.00
0005435242467	15392	Economy	9300.00
0005435242450	15392	Economy	9300.00
0005435242461	15392	Economy	9300.00
0005435242457	15392	Economy	9300.00
0005435242470	15392	Economy	9300.00
0005435242444	15392	Economy	9300.00
0005435476657	15392	Economy	9300.00
0005435476658	15392	Economy	9300.00
0005435242454	15392	Economy	9300.00
0005435242466	15392	Economy	9300.00
0005432848105	4364	Economy	7000.00
0005432848111	4364	Economy	7000.00
0005434463899	4364	Economy	6300.00
0005432848103	4364	Economy	6300.00
0005432848112	4364	Economy	6300.00
0005432848101	4364	Economy	6300.00
0005432848107	4364	Economy	6300.00
0005432848106	4364	Economy	6300.00
0005432848113	4364	Economy	6300.00
0005432848109	4364	Economy	6300.00
0005434463898	4364	Economy	6300.00
0005434462760	4364	Economy	6300.00
0005434462759	4364	Economy	6300.00
0005432848108	4364	Economy	6300.00
0005432848100	4364	Economy	6300.00
0005432848104	4364	Economy	6300.00
0005432848102	4364	Economy	6300.00
0005432848110	4364	Economy	6300.00
0005435850784	28859	Economy	7000.00
0005435850779	28859	Economy	6300.00
0005435850781	28859	Economy	6300.00
0005435850783	28859	Economy	6300.00
0005435850780	28859	Economy	6300.00
0005435850785	28859	Economy	6300.00
0005435850786	28859	Economy	6300.00
0005435850776	28859	Economy	6300.00
0005435850778	28859	Economy	6300.00
0005435850777	28859	Economy	6300.00
0005435850782	28859	Economy	6300.00
0005433496528	6244	Business	11900.00
0005433496517	6244	Business	11900.00
0005434443484	6244	Business	11900.00
0005434925357	6244	Business	11900.00
0005433496535	6244	Business	11900.00
0005433496529	6244	Economy	4000.00
0005433496532	6244	Economy	4000.00
0005433496521	6244	Economy	4000.00
0005433496543	6244	Economy	4000.00
0005434925347	6244	Economy	4000.00
0005434443478	6244	Economy	4000.00
0005434925358	6244	Economy	4000.00
0005433496514	6244	Economy	4000.00
0005433496519	6244	Economy	4400.00
0005434925353	6244	Economy	4400.00
0005433496526	6244	Economy	4400.00
0005434925345	6244	Economy	4400.00
0005433496536	6244	Economy	4400.00
0005434925343	6244	Economy	4000.00
0005433496544	6244	Economy	4000.00
0005433496522	6244	Economy	4000.00
0005433496525	6244	Economy	4000.00
0005434925359	6244	Economy	4000.00
0005433496530	6244	Economy	4000.00
0005434443479	6244	Economy	4000.00
0005434925348	6244	Economy	4000.00
0005433496516	6244	Economy	4000.00
0005434925351	6244	Economy	4000.00
0005433496533	6244	Economy	4000.00
0005434443485	6244	Economy	4000.00
0005433496545	6244	Economy	4000.00
0005433496542	6244	Economy	4000.00
0005433496540	6244	Economy	4000.00
0005433496524	6244	Economy	4000.00
0005434925363	6244	Economy	4000.00
0005433496527	6244	Economy	4000.00
0005434925352	6244	Economy	4000.00
0005434443473	6244	Economy	4000.00
0005434925362	6244	Economy	4000.00
0005433496531	6244	Economy	4000.00
0005434925355	6244	Economy	4000.00
0005434925361	6244	Economy	4000.00
0005432075181	6244	Economy	4000.00
0005433496541	6244	Economy	4000.00
0005434925346	6244	Economy	4000.00
0005434925349	6244	Economy	4000.00
0005434443476	6244	Economy	4000.00
0005434925354	6244	Economy	4000.00
0005434443480	6244	Economy	4000.00
0005434443488	6244	Economy	4000.00
0005434443477	6244	Economy	4000.00
0005434443487	6244	Economy	4000.00
0005434443481	6244	Economy	4000.00
0005434925356	6244	Economy	4000.00
0005434925344	6244	Economy	4000.00
0005434443474	6244	Economy	4000.00
0005434925350	6244	Economy	4000.00
0005433496537	6244	Economy	4000.00
0005433496534	6244	Economy	4000.00
0005433496523	6244	Economy	4000.00
0005433496538	6244	Economy	4000.00
0005433496515	6244	Economy	4000.00
0005434443483	6244	Economy	4000.00
0005432075180	6244	Economy	4000.00
0005432075182	6244	Economy	4000.00
0005433496539	6244	Economy	4000.00
0005434443486	6244	Economy	4000.00
0005434925360	6244	Economy	4000.00
0005433496520	6244	Economy	4000.00
0005434925364	6244	Economy	4000.00
0005433496546	6244	Economy	4000.00
0005434443482	6244	Economy	4000.00
0005434443475	6244	Economy	4000.00
0005433496518	6244	Economy	4000.00
0005433496476	20371	Economy	4000.00
0005433496477	20371	Economy	4000.00
0005435242495	12168	Business	41200.00
0005435242483	12168	Business	41200.00
0005435242474	12168	Business	41200.00
0005435242491	12168	Business	41200.00
0005435242484	12168	Business	41200.00
0005435242496	12168	Business	41200.00
0005435242497	12168	Economy	13700.00
0005435242490	12168	Economy	13700.00
0005435242477	12168	Economy	13700.00
0005435242475	12168	Economy	15100.00
0005435242488	12168	Economy	13700.00
0005435242471	12168	Economy	13700.00
0005435242481	12168	Economy	13700.00
0005435242493	12168	Economy	13700.00
0005435242478	12168	Economy	13700.00
0005435242473	12168	Economy	13700.00
0005435242485	12168	Economy	13700.00
0005432782839	12168	Economy	13700.00
0005435242479	12168	Economy	13700.00
0005435242492	12168	Economy	13700.00
0005435242489	12168	Economy	13700.00
0005435242472	12168	Economy	13700.00
0005435242487	12168	Economy	13700.00
0005435242476	12168	Economy	13700.00
0005435242480	12168	Economy	13700.00
0005435242486	12168	Economy	13700.00
0005435242494	12168	Economy	13700.00
0005435242482	12168	Economy	13700.00
0005432783000	15401	Business	41200.00
0005432782970	15401	Business	41200.00
0005432782958	15401	Business	41200.00
0005432782993	15401	Business	41200.00
0005432782965	15401	Economy	13700.00
0005432782961	15401	Economy	13700.00
0005432782975	15401	Economy	13700.00
0005432782978	15401	Economy	13700.00
0005432782988	15401	Economy	13700.00
0005432782998	15401	Economy	15100.00
0005432782986	15401	Economy	15100.00
0005432782972	15401	Economy	15100.00
0005432783002	15401	Economy	15100.00
0005432783001	15401	Economy	13700.00
0005432782983	15401	Economy	13700.00
0005432782992	15401	Economy	13700.00
0005432782999	15401	Economy	13700.00
0005432782959	15401	Economy	13700.00
0005432782966	15401	Economy	13700.00
0005432782982	15401	Economy	13700.00
0005432782962	15401	Economy	13700.00
0005432782980	15401	Economy	13700.00
0005432782956	15401	Economy	13700.00
0005432782976	15401	Economy	13700.00
0005432782981	15401	Economy	13700.00
0005432782950	15401	Economy	13700.00
0005432782964	15401	Economy	13700.00
0005432782951	15401	Economy	13700.00
0005432782996	15401	Economy	13700.00
0005432782974	15401	Economy	13700.00
0005432782985	15401	Economy	13700.00
0005432782995	15401	Economy	13700.00
0005432782969	15401	Economy	13700.00
0005432782977	15401	Economy	13700.00
0005432782953	15401	Economy	13700.00
0005432782997	15401	Economy	13700.00
0005432782967	15401	Economy	13700.00
0005432782979	15401	Economy	13700.00
0005432782960	15401	Economy	13700.00
0005432782954	15401	Economy	13700.00
0005432782971	15401	Economy	13700.00
0005432782989	15401	Economy	13700.00
0005432782957	15401	Economy	13700.00
0005432782990	15401	Economy	13700.00
0005432782991	15401	Economy	13700.00
0005432782987	15401	Economy	13700.00
0005432782984	15401	Economy	13700.00
0005432782968	15401	Economy	13700.00
0005432782963	15401	Economy	13700.00
0005432782949	15401	Economy	13700.00
0005432782994	15401	Economy	13700.00
0005432782955	15401	Economy	13700.00
0005432782973	15401	Economy	13700.00
0005432782952	15401	Economy	13700.00
0005434910075	10122	Business	49700.00
0005435913865	10122	Business	49700.00
0005435913862	10122	Economy	16600.00
0005435913864	10122	Economy	16600.00
0005435913859	10122	Economy	16600.00
0005434876642	10122	Economy	16600.00
0005435913858	10122	Economy	16600.00
0005435913861	10122	Economy	16600.00
0005434910073	10122	Economy	16600.00
0005435913863	10122	Economy	16600.00
0005435913860	10122	Economy	16600.00
0005434910074	10122	Economy	16600.00
0005434876859	14624	Business	49700.00
0005434876917	14624	Business	49700.00
0005434876877	14624	Business	49700.00
0005434876924	14624	Business	49700.00
0005434876874	14624	Business	49700.00
0005434876868	14624	Business	49700.00
0005434876925	14624	Business	49700.00
0005434876921	14624	Business	49700.00
0005434876928	14624	Business	49700.00
0005434876848	14624	Business	49700.00
0005434876910	14624	Business	49700.00
0005434876909	14624	Business	49700.00
0005434876931	14624	Business	49700.00
0005434876922	14624	Business	49700.00
0005434876911	14624	Business	49700.00
0005434876914	14624	Business	49700.00
0005434758860	14624	Business	49700.00
0005434876915	14624	Economy	16600.00
0005434876861	14624	Economy	16600.00
0005434876847	14624	Economy	16600.00
0005434876900	14624	Economy	16600.00
0005434876857	14624	Economy	16600.00
0005434876938	14624	Economy	16600.00
0005434876934	14624	Economy	16600.00
0005434876899	14624	Economy	16600.00
0005434876869	14624	Economy	16600.00
0005434876932	14624	Economy	16600.00
0005434876881	14624	Economy	16600.00
0005434876940	14624	Economy	18200.00
0005434876903	14624	Economy	18200.00
0005434876865	14624	Economy	18200.00
0005434758861	14624	Economy	18200.00
0005434876892	14624	Economy	16600.00
0005434876916	14624	Economy	16600.00
0005434876860	14624	Economy	16600.00
0005434876871	14624	Economy	16600.00
0005434876885	14624	Economy	16600.00
0005434876858	14624	Economy	16600.00
0005434876893	14624	Economy	16600.00
0005434876930	14624	Economy	16600.00
0005434876913	14624	Economy	16600.00
0005434876912	14624	Economy	16600.00
0005434876895	14624	Economy	16600.00
0005434876849	14624	Economy	16600.00
0005434876937	14624	Economy	16600.00
0005434876887	14624	Economy	16600.00
0005434876908	14624	Economy	16600.00
0005434876862	14624	Economy	16600.00
0005434758859	14624	Economy	16600.00
0005434876918	14624	Economy	16600.00
0005434876853	14624	Economy	16600.00
0005434876920	14624	Economy	16600.00
0005434876904	14624	Economy	16600.00
0005434876883	14624	Economy	16600.00
0005434876866	14624	Economy	16600.00
0005434876863	14624	Economy	16600.00
0005434876856	14624	Economy	16600.00
0005434876870	14624	Economy	16600.00
0005434876876	14624	Economy	16600.00
0005434876927	14624	Economy	16600.00
0005434876878	14624	Economy	16600.00
0005434876850	14624	Economy	16600.00
0005434876867	14624	Economy	16600.00
0005434876901	14624	Economy	16600.00
0005434876855	14624	Economy	16600.00
0005434876872	14624	Economy	16600.00
0005434876851	14624	Economy	16600.00
0005434876854	14624	Economy	16600.00
0005434876902	14624	Economy	16600.00
0005434876942	14624	Economy	16600.00
0005434876923	14624	Economy	16600.00
0005434876879	14624	Economy	16600.00
0005434876935	14624	Economy	16600.00
0005434876939	14624	Economy	16600.00
0005434876882	14624	Economy	16600.00
0005434876896	14624	Economy	16600.00
0005434876891	14624	Economy	16600.00
0005434876919	14624	Economy	16600.00
0005434876941	14624	Economy	16600.00
0005434876889	14624	Economy	16600.00
0005434876852	14624	Economy	16600.00
0005434876886	14624	Economy	16600.00
0005434876907	14624	Economy	16600.00
0005434876933	14624	Economy	16600.00
0005434876894	14624	Economy	16600.00
0005434876936	14624	Economy	16600.00
0005434876898	14624	Economy	16600.00
0005434876897	14624	Economy	16600.00
0005434876906	14624	Economy	16600.00
0005434876864	14624	Economy	16600.00
0005434876873	14624	Economy	16600.00
0005434876890	14624	Economy	16600.00
0005434876905	14624	Economy	16600.00
0005434876926	14624	Economy	16600.00
0005434876880	14624	Economy	16600.00
0005434876875	14624	Economy	16600.00
0005434876929	14624	Economy	16600.00
0005434876884	14624	Economy	16600.00
0005434876888	14624	Economy	16600.00
0005435659972	9217	Economy	22400.00
0005435659976	9217	Economy	20300.00
0005435659974	9217	Economy	20300.00
0005435659979	9217	Economy	20300.00
0005435659975	9217	Economy	20300.00
0005435659971	9217	Economy	20300.00
0005435659981	9217	Economy	20300.00
0005435659980	9217	Economy	20300.00
0005435659978	9217	Economy	20300.00
0005435659973	9217	Economy	20300.00
0005435659977	9217	Economy	20300.00
0005435659982	9217	Economy	20300.00
0005434251831	24640	Economy	20300.00
0005434251830	24640	Economy	20300.00
0005434251825	24640	Economy	20300.00
0005434251828	24640	Economy	20300.00
0005434251827	24640	Economy	20300.00
0005434251834	24640	Economy	20300.00
0005434251829	24640	Economy	20300.00
0005434251826	24640	Economy	20300.00
0005434251832	24640	Economy	20300.00
0005434251833	24640	Economy	20300.00
0005433679887	2821	Business	33000.00
0005432222704	2821	Business	33000.00
0005433679863	2821	Business	33000.00
0005433679870	2821	Business	33000.00
0005433679861	2821	Business	33000.00
0005433679881	2821	Business	33000.00
0005433679859	2821	Business	33000.00
0005433679896	2821	Economy	11000.00
0005433679874	2821	Economy	11000.00
0005433679892	2821	Economy	11000.00
0005432222706	2821	Economy	11000.00
0005432222705	2821	Economy	11000.00
0005433679880	2821	Economy	11000.00
0005433684389	2821	Economy	11000.00
0005433679860	2821	Economy	11000.00
0005433679904	2821	Economy	12100.00
0005433679897	2821	Economy	12100.00
0005432222707	2821	Economy	11000.00
0005433679894	2821	Economy	11000.00
0005433679871	2821	Economy	11000.00
0005433679875	2821	Economy	11000.00
0005433679873	2821	Economy	11000.00
0005433679867	2821	Economy	11000.00
0005433679868	2821	Economy	11000.00
0005433679878	2821	Economy	11000.00
0005433679857	2821	Economy	11000.00
0005433679900	2821	Economy	11000.00
0005432222703	2821	Economy	11000.00
0005432222708	2821	Economy	11000.00
0005433679855	2821	Economy	11000.00
0005433679899	2821	Economy	11000.00
0005433679877	2821	Economy	11000.00
0005433679869	2821	Economy	11000.00
0005433679866	2821	Economy	11000.00
0005433679864	2821	Economy	11000.00
0005433679883	2821	Economy	11000.00
0005433679879	2821	Economy	11000.00
0005433679898	2821	Economy	11000.00
0005433679888	2821	Economy	11000.00
0005433679890	2821	Economy	11000.00
0005433679872	2821	Economy	11000.00
0005433679889	2821	Economy	11000.00
0005433679865	2821	Economy	11000.00
0005433679862	2821	Economy	11000.00
0005433679884	2821	Economy	11000.00
0005433679886	2821	Economy	11000.00
0005433679902	2821	Economy	11000.00
0005433679891	2821	Economy	11000.00
0005433679856	2821	Economy	11000.00
0005433679876	2821	Economy	11000.00
0005433679858	2821	Economy	11000.00
0005433679895	2821	Economy	11000.00
0005433679893	2821	Economy	11000.00
0005433679901	2821	Economy	11000.00
0005433679903	2821	Economy	11000.00
0005433679885	2821	Economy	11000.00
0005433679882	2821	Economy	11000.00
0005432966579	29142	Business	33000.00
0005432966566	29142	Business	33000.00
0005432966565	29142	Business	33000.00
0005432966562	29142	Business	33000.00
0005432966573	29142	Business	33000.00
0005433679729	29142	Business	33000.00
0005432966577	29142	Economy	11000.00
0005432966581	29142	Economy	12100.00
0005432966563	29142	Economy	11000.00
0005432005173	29142	Economy	11000.00
0005432966560	29142	Economy	11000.00
0005432966582	29142	Economy	11000.00
0005432966572	29142	Economy	11000.00
0005432966559	29142	Economy	11000.00
0005432966564	29142	Economy	11000.00
0005432966561	29142	Economy	11000.00
0005432966575	29142	Economy	11000.00
0005432966578	29142	Economy	11000.00
0005432966568	29142	Economy	11000.00
0005432966571	29142	Economy	11000.00
0005432966569	29142	Economy	11000.00
0005432966576	29142	Economy	11000.00
0005432966567	29142	Economy	11000.00
0005432966574	29142	Economy	11000.00
0005432966570	29142	Economy	11000.00
0005432966580	29142	Economy	11000.00
0005432966558	29142	Economy	11000.00
0005432966583	29142	Economy	11000.00
0005433613594	9290	Business	132900.00
0005433613542	9290	Business	132900.00
0005433613552	9290	Business	132900.00
0005433613593	9290	Business	132900.00
0005433613558	9290	Business	132900.00
0005433613564	9290	Business	132900.00
0005433613545	9290	Business	132900.00
0005433577604	9290	Business	132900.00
0005433577611	9290	Business	132900.00
0005433613568	9290	Business	132900.00
0005433633304	9290	Business	132900.00
0005433633301	9290	Business	132900.00
0005433613576	9290	Business	132900.00
0005433633292	9290	Business	132900.00
0005433613547	9290	Business	132900.00
0005433613539	9290	Business	132900.00
0005433633310	9290	Business	132900.00
0005433613575	9290	Business	132900.00
0005433613598	9290	Business	132900.00
0005433613587	9290	Business	132900.00
0005433613573	9290	Business	132900.00
0005433613604	9290	Business	132900.00
0005433633300	9290	Business	132900.00
0005433633295	9290	Economy	48700.00
0005433613560	9290	Economy	48700.00
0005433613544	9290	Economy	48700.00
0005433613557	9290	Economy	48700.00
0005433613580	9290	Economy	48700.00
0005433633313	9290	Economy	48700.00
0005433633285	9290	Economy	44300.00
0005433633288	9290	Economy	44300.00
0005433633289	9290	Economy	44300.00
0005433613596	9290	Economy	44300.00
0005433577608	9290	Economy	44300.00
0005433613599	9290	Economy	44300.00
0005433613574	9290	Economy	44300.00
0005432756799	9290	Economy	44300.00
0005433633296	9290	Economy	44300.00
0005433633293	9290	Economy	44300.00
0005433633303	9290	Economy	44300.00
0005433613554	9290	Economy	44300.00
0005433613543	9290	Economy	44300.00
0005433613548	9290	Economy	44300.00
0005433577603	9290	Economy	44300.00
0005433633283	9290	Economy	44300.00
0005433577607	9290	Economy	44300.00
0005433613572	9290	Economy	44300.00
0005433633308	9290	Economy	44300.00
0005433613588	9290	Economy	44300.00
0005433613536	9290	Economy	44300.00
0005432755028	9290	Economy	44300.00
0005433613582	9290	Economy	44300.00
0005433613608	9290	Economy	44300.00
0005433577610	9290	Economy	44300.00
0005433633306	9290	Economy	44300.00
0005433613553	9290	Economy	44300.00
0005433613559	9290	Economy	44300.00
0005433613592	9290	Economy	44300.00
0005433577605	9290	Economy	44300.00
0005433633307	9290	Economy	44300.00
0005433613566	9290	Economy	44300.00
0005433633314	9290	Economy	44300.00
0005433613595	9290	Economy	44300.00
0005433633316	9290	Economy	44300.00
0005433613567	9290	Economy	44300.00
0005432756798	9290	Economy	44300.00
0005433613562	9290	Economy	44300.00
0005432145081	9290	Economy	44300.00
0005433613538	9290	Economy	44300.00
0005433613597	9290	Economy	44300.00
0005433613603	9290	Economy	44300.00
0005433613563	9290	Economy	48700.00
0005433613609	9290	Economy	48700.00
0005433577613	9290	Economy	48700.00
0005433633284	9290	Economy	44300.00
0005433613607	9290	Economy	44300.00
0005433633286	9290	Economy	44300.00
0005433613585	9290	Economy	44300.00
0005433613555	9290	Economy	48700.00
0005433577609	9290	Economy	44300.00
0005433613577	9290	Economy	44300.00
0005433577614	9290	Economy	44300.00
0005433633315	9290	Economy	44300.00
0005433613586	9290	Economy	44300.00
0005433633297	9290	Economy	44300.00
0005433613584	9290	Economy	44300.00
0005433613583	9290	Economy	44300.00
0005433613537	9290	Economy	44300.00
0005433613579	9290	Economy	44300.00
0005433633290	9290	Economy	44300.00
0005433613590	9290	Economy	44300.00
0005432755027	9290	Economy	44300.00
0005433613589	9290	Economy	44300.00
0005433613540	9290	Economy	44300.00
0005432145080	9290	Economy	44300.00
0005433613550	9290	Economy	44300.00
0005432756800	9290	Economy	44300.00
0005433613569	9290	Economy	44300.00
0005433613610	9290	Economy	44300.00
0005433633294	9290	Economy	44300.00
0005433613602	9290	Economy	44300.00
0005433613570	9290	Economy	44300.00
0005433633311	9290	Economy	44300.00
0005433613546	9290	Economy	44300.00
0005433633302	9290	Economy	44300.00
0005433633291	9290	Economy	44300.00
0005432755026	9290	Economy	44300.00
0005433577606	9290	Economy	44300.00
0005433613565	9290	Economy	44300.00
0005433613591	9290	Economy	44300.00
0005433633298	9290	Economy	44300.00
0005433633287	9290	Economy	44300.00
0005433613541	9290	Economy	44300.00
0005433613606	9290	Economy	44300.00
0005433613581	9290	Economy	44300.00
0005433577612	9290	Economy	44300.00
0005433613600	9290	Economy	44300.00
0005433613561	9290	Economy	44300.00
0005433633305	9290	Economy	44300.00
0005432145079	9290	Economy	44300.00
0005433613551	9290	Economy	44300.00
0005433633299	9290	Economy	44300.00
0005433613556	9290	Economy	44300.00
0005433613571	9290	Economy	44300.00
0005433613578	9290	Economy	44300.00
0005433613601	9290	Economy	44300.00
0005433633312	9290	Economy	44300.00
0005433633317	9290	Economy	44300.00
0005432756797	9290	Economy	44300.00
0005433613549	9290	Economy	44300.00
0005433633309	9290	Economy	44300.00
0005433613605	9290	Economy	44300.00
0005434152751	25223	Business	132900.00
0005434152757	25223	Business	132900.00
0005434163488	25223	Business	132900.00
0005434273050	25223	Business	132900.00
0005434152758	25223	Business	132900.00
0005434163484	25223	Business	132900.00
0005434163486	25223	Business	132900.00
0005434163490	25223	Economy	48700.00
0005434163487	25223	Economy	44300.00
0005434152752	25223	Economy	44300.00
0005434163489	25223	Economy	44300.00
0005434163491	25223	Economy	44300.00
0005434273051	25223	Economy	44300.00
0005434152759	25223	Economy	44300.00
0005434163482	25223	Economy	44300.00
0005434152756	25223	Economy	44300.00
0005434152755	25223	Economy	44300.00
0005434272165	25223	Economy	44300.00
0005434163481	25223	Economy	44300.00
0005434152753	25223	Economy	44300.00
0005434163485	25223	Economy	44300.00
0005434152754	25223	Economy	44300.00
0005434163483	25223	Economy	44300.00
0005434272166	25223	Economy	44300.00
0005432184909	4241	Economy	64400.00
0005432184910	4241	Economy	64400.00
0005432184911	4241	Economy	64400.00
0005435856143	26598	Business	193100.00
0005435856146	26598	Economy	64400.00
0005435856145	26598	Economy	64400.00
0005435947045	26598	Economy	64400.00
0005435947053	26598	Economy	64400.00
0005435856144	26598	Economy	64400.00
0005432571268	26598	Economy	64400.00
0005435947052	26598	Economy	64400.00
0005435947054	26598	Economy	64400.00
0005435947056	26598	Economy	64400.00
0005435947044	26598	Economy	64400.00
0005435947046	26598	Economy	70800.00
0005435947049	26598	Economy	64400.00
0005435856142	26598	Economy	64400.00
0005435947042	26598	Economy	64400.00
0005435947055	26598	Economy	64400.00
0005435787324	26598	Economy	64400.00
0005432571271	26598	Economy	64400.00
0005435947047	26598	Economy	64400.00
0005432571269	26598	Economy	64400.00
0005435947043	26598	Economy	64400.00
0005435947051	26598	Economy	64400.00
0005432571270	26598	Economy	64400.00
0005435787325	26598	Economy	64400.00
0005435947050	26598	Economy	64400.00
0005435947048	26598	Economy	64400.00
0005433568195	352	Business	21500.00
0005433568219	352	Business	21500.00
0005433568202	352	Business	21500.00
0005433568224	352	Business	21500.00
0005433568201	352	Business	21500.00
0005433568244	352	Business	21500.00
0005433568194	352	Business	21500.00
0005433568208	352	Business	21500.00
0005432238847	352	Business	21500.00
0005432238850	352	Business	21500.00
0005433568197	352	Business	21500.00
0005433568234	352	Business	21500.00
0005433568207	352	Business	21500.00
0005433568227	352	Business	21500.00
0005433568230	352	Economy	7900.00
0005433568214	352	Economy	7900.00
0005433568210	352	Economy	7200.00
0005433568206	352	Economy	7200.00
0005433568239	352	Economy	7200.00
0005433568249	352	Economy	7200.00
0005433568228	352	Economy	7200.00
0005433568225	352	Economy	7200.00
0005433568245	352	Economy	7200.00
0005433568218	352	Economy	7200.00
0005433568257	352	Economy	7200.00
0005432238849	352	Economy	7200.00
0005433568192	352	Economy	7200.00
0005433568196	352	Economy	7200.00
0005433568233	352	Economy	7200.00
0005433568251	352	Economy	7200.00
0005433568220	352	Economy	7200.00
0005433568212	352	Economy	7200.00
0005433568209	352	Economy	7200.00
0005433568252	352	Economy	7200.00
0005433568236	352	Economy	7200.00
0005433568247	352	Economy	7200.00
0005432238848	352	Economy	7200.00
0005433568231	352	Economy	7200.00
0005433568204	352	Economy	7200.00
0005433568222	352	Economy	7200.00
0005433568248	352	Economy	7200.00
0005433568203	352	Economy	7200.00
0005433568226	352	Economy	7200.00
0005433568229	352	Economy	7200.00
0005432238851	352	Economy	7200.00
0005433568193	352	Economy	7900.00
0005433568215	352	Economy	7200.00
0005433568200	352	Economy	7200.00
0005433568213	352	Economy	7200.00
0005433568237	352	Economy	7200.00
0005433568243	352	Economy	7200.00
0005433568246	352	Economy	7200.00
0005433568221	352	Economy	7200.00
0005433568235	352	Economy	7200.00
0005433568199	352	Economy	7200.00
0005433568253	352	Economy	7200.00
0005433568258	352	Economy	7200.00
0005433568205	352	Economy	7200.00
0005433568211	352	Economy	7200.00
0005433568241	352	Economy	7200.00
0005433568198	352	Economy	7200.00
0005433568254	352	Economy	7200.00
0005433568216	352	Economy	7200.00
0005433568223	352	Economy	7200.00
0005432238846	352	Economy	7200.00
0005433568255	352	Economy	7200.00
0005433568238	352	Economy	7200.00
0005433568242	352	Economy	7200.00
0005433568232	352	Economy	7200.00
0005433568250	352	Economy	7200.00
0005433568240	352	Economy	7200.00
0005433568217	352	Economy	7200.00
0005433568256	352	Economy	7200.00
0005433074301	11603	Business	21500.00
0005433074291	11603	Business	21500.00
0005433074300	11603	Business	21500.00
0005432947881	11603	Business	21500.00
0005432947884	11603	Business	21500.00
0005433074313	11603	Business	21500.00
0005433074296	11603	Business	21500.00
0005432947861	11603	Business	21500.00
0005432947859	11603	Business	21500.00
0005432947876	11603	Business	21500.00
0005433074307	11603	Business	21500.00
0005432947849	11603	Business	21500.00
0005433134071	11603	Business	21500.00
0005432947879	11603	Business	21500.00
0005432947854	11603	Business	21500.00
0005432947863	11603	Business	21500.00
0005432947867	11603	Economy	7900.00
0005432947868	11603	Economy	7900.00
0005432947886	11603	Economy	7900.00
0005432947864	11603	Economy	7200.00
0005432947860	11603	Economy	7200.00
0005433134075	11603	Economy	7200.00
0005432947870	11603	Economy	7200.00
0005433074284	11603	Economy	7200.00
0005433074308	11603	Economy	7200.00
0005432947858	11603	Economy	7200.00
0005433074304	11603	Economy	7200.00
0005432947888	11603	Economy	7200.00
0005432947877	11603	Economy	7200.00
0005433074303	11603	Economy	7200.00
0005432947855	11603	Economy	7200.00
0005432947885	11603	Economy	7200.00
0005432947874	11603	Economy	7200.00
0005432947865	11603	Economy	7200.00
0005433074289	11603	Economy	7200.00
0005432947852	11603	Economy	7200.00
0005433074302	11603	Economy	7200.00
0005433074294	11603	Economy	7200.00
0005433074287	11603	Economy	7200.00
0005433131643	11603	Economy	7200.00
0005433074292	11603	Economy	7200.00
0005432192274	11603	Economy	7200.00
0005432947862	11603	Economy	7200.00
0005433131642	11603	Economy	7200.00
0005432947887	11603	Economy	7200.00
0005433074286	11603	Economy	7200.00
0005432192276	11603	Economy	7200.00
0005432947872	11603	Economy	7200.00
0005433134070	11603	Economy	7900.00
0005433134072	11603	Economy	7900.00
0005432947856	11603	Economy	7200.00
0005433131640	11603	Economy	7200.00
0005432192275	11603	Economy	7200.00
0005433074305	11603	Economy	7200.00
0005433074290	11603	Economy	7200.00
0005433131641	11603	Economy	7200.00
0005433074295	11603	Economy	7200.00
0005432947866	11603	Economy	7200.00
0005432947869	11603	Economy	7200.00
0005432947853	11603	Economy	7200.00
0005433074312	11603	Economy	7200.00
0005433074293	11603	Economy	7200.00
0005433074306	11603	Economy	7200.00
0005432947857	11603	Economy	7200.00
0005433134073	11603	Economy	7200.00
0005432947875	11603	Economy	7200.00
0005433074285	11603	Economy	7200.00
0005432947848	11603	Economy	7200.00
0005432947882	11603	Economy	7200.00
0005433074309	11603	Economy	7200.00
0005433074310	11603	Economy	7200.00
0005432947851	11603	Economy	7200.00
0005432947846	11603	Economy	7200.00
0005433074297	11603	Economy	7200.00
0005432947878	11603	Economy	7200.00
0005433074288	11603	Economy	7200.00
0005432947883	11603	Economy	7200.00
0005432947873	11603	Economy	7200.00
0005432947850	11603	Economy	7200.00
0005432192273	11603	Economy	7200.00
0005432947847	11603	Economy	7200.00
0005433131644	11603	Economy	7200.00
0005432947871	11603	Economy	7200.00
0005433074314	11603	Economy	7200.00
0005432947880	11603	Economy	7200.00
0005433074298	11603	Economy	7200.00
0005433074311	11603	Economy	7200.00
0005433074299	11603	Economy	7200.00
0005433134074	11603	Economy	7200.00
0005433817418	9940	Economy	6300.00
0005433817416	9940	Economy	6300.00
0005433817415	9940	Economy	6300.00
0005433817417	9940	Economy	6300.00
0005434732929	13948	Economy	6300.00
0005434732932	13948	Economy	6300.00
0005434732930	13948	Economy	6300.00
0005434732931	13948	Economy	6300.00
0005435981656	2342	Business	184500.00
0005435981658	2342	Business	184500.00
0005432984502	2342	Business	184500.00
0005432225966	2342	Business	184500.00
0005433753423	2342	Business	184500.00
0005432300180	2342	Business	184500.00
0005435981673	2342	Business	184500.00
0005435981653	2342	Business	184500.00
0005433753435	2342	Business	184500.00
0005435981681	2342	Business	184500.00
0005433753430	2342	Business	184500.00
0005435981659	2342	Business	184500.00
0005435981678	2342	Business	184500.00
0005433766587	2342	Business	184500.00
0005435981687	2342	Business	184500.00
0005432655364	2342	Economy	67700.00
0005435981654	2342	Business	184500.00
0005435981667	2342	Economy	67700.00
0005435981677	2342	Economy	67700.00
0005435981671	2342	Economy	61500.00
0005433753420	2342	Economy	61500.00
0005433753412	2342	Economy	61500.00
0005433753403	2342	Economy	61500.00
0005435981686	2342	Economy	61500.00
0005433753395	2342	Economy	61500.00
0005432655370	2342	Economy	61500.00
0005435981646	2342	Economy	61500.00
0005435981664	2342	Economy	61500.00
0005432655363	2342	Economy	61500.00
0005433753436	2342	Economy	61500.00
0005432300184	2342	Economy	61500.00
0005433753397	2342	Economy	61500.00
0005432655371	2342	Economy	61500.00
0005432655373	2342	Economy	61500.00
0005435981668	2342	Economy	61500.00
0005435981660	2342	Economy	61500.00
0005433753399	2342	Economy	61500.00
0005435981652	2342	Economy	61500.00
0005433753410	2342	Economy	61500.00
0005433753434	2342	Economy	61500.00
0005433753406	2342	Economy	61500.00
0005432225970	2342	Economy	61500.00
0005433753401	2342	Economy	61500.00
0005433753402	2342	Economy	61500.00
0005433766586	2342	Economy	61500.00
0005435981674	2342	Economy	61500.00
0005433764650	2342	Economy	61500.00
0005432984501	2342	Economy	61500.00
0005433753400	2342	Economy	61500.00
0005433753426	2342	Economy	61500.00
0005432225967	2342	Economy	61500.00
0005433753415	2342	Economy	61500.00
0005433753424	2342	Economy	61500.00
0005433753432	2342	Economy	61500.00
0005435981684	2342	Economy	61500.00
0005433753408	2342	Economy	61500.00
0005433753409	2342	Economy	61500.00
0005433753443	2342	Economy	61500.00
0005435981651	2342	Economy	61500.00
0005433753438	2342	Economy	61500.00
0005433753447	2342	Economy	61500.00
0005432655369	2342	Economy	61500.00
0005432300181	2342	Economy	61500.00
0005433753414	2342	Economy	61500.00
0005435981665	2342	Economy	61500.00
0005433753418	2342	Economy	61500.00
0005435981661	2342	Economy	61500.00
0005432225969	2342	Economy	61500.00
0005433753416	2342	Economy	61500.00
0005433753425	2342	Economy	61500.00
0005435981675	2342	Economy	61500.00
0005435981685	2342	Economy	61500.00
0005432300179	2342	Economy	61500.00
0005433753445	2342	Economy	61500.00
0005435981683	2342	Economy	61500.00
0005435981647	2342	Economy	61500.00
0005433753427	2342	Economy	61500.00
0005433753450	2342	Economy	61500.00
0005433753404	2342	Economy	61500.00
0005433753411	2342	Economy	67700.00
0005433753437	2342	Economy	61500.00
0005435981672	2342	Economy	61500.00
0005435981645	2342	Economy	61500.00
0005435981676	2342	Economy	67700.00
0005435981682	2342	Economy	61500.00
0005433753413	2342	Economy	61500.00
0005432655367	2342	Economy	61500.00
0005433753444	2342	Economy	61500.00
0005433753449	2342	Economy	61500.00
0005435981648	2342	Economy	61500.00
0005433753394	2342	Economy	61500.00
0005433766585	2342	Economy	61500.00
0005435981689	2342	Economy	61500.00
0005433753428	2342	Economy	61500.00
0005435981669	2342	Economy	61500.00
0005432655372	2342	Economy	61500.00
0005432300183	2342	Economy	61500.00
0005433753429	2342	Economy	61500.00
0005432300178	2342	Economy	61500.00
0005433753419	2342	Economy	61500.00
0005435981680	2342	Economy	61500.00
0005432300182	2342	Economy	61500.00
0005435981662	2342	Economy	61500.00
0005433753407	2342	Economy	61500.00
0005433753405	2342	Economy	61500.00
0005433753417	2342	Economy	61500.00
0005433753421	2342	Economy	61500.00
0005433753398	2342	Economy	61500.00
0005435981688	2342	Economy	61500.00
0005433753448	2342	Economy	61500.00
0005433753422	2342	Economy	61500.00
0005435981657	2342	Economy	61500.00
0005432655365	2342	Economy	61500.00
0005435981655	2342	Economy	61500.00
0005433753431	2342	Economy	61500.00
0005432655366	2342	Economy	61500.00
0005432225968	2342	Economy	61500.00
0005433753396	2342	Economy	61500.00
0005435981670	2342	Economy	61500.00
0005435981649	2342	Economy	61500.00
0005433753446	2342	Economy	61500.00
0005435981666	2342	Economy	61500.00
0005432655368	2342	Economy	61500.00
0005433753442	2342	Economy	61500.00
0005433753441	2342	Economy	61500.00
0005435981679	2342	Economy	61500.00
0005433753433	2342	Economy	61500.00
0005433753440	2342	Economy	61500.00
0005435981663	2342	Economy	61500.00
0005432655374	2342	Economy	61500.00
0005435981650	2342	Economy	61500.00
0005433753439	2342	Economy	61500.00
0005432051085	26206	Business	184500.00
0005433434290	26206	Business	184500.00
0005433434277	26206	Business	184500.00
0005432984615	26206	Business	184500.00
0005433434284	26206	Business	184500.00
0005432984618	26206	Business	184500.00
0005433434275	26206	Business	184500.00
0005432984609	26206	Business	184500.00
0005432984621	26206	Business	184500.00
0005432984612	26206	Business	184500.00
0005432984631	26206	Business	184500.00
0005433434292	26206	Business	184500.00
0005432984600	26206	Economy	67700.00
0005432984617	26206	Economy	67700.00
0005433434267	26206	Economy	61500.00
0005433434273	26206	Economy	61500.00
0005432049413	26206	Economy	61500.00
0005433434272	26206	Economy	61500.00
0005432984619	26206	Economy	61500.00
0005432984616	26206	Economy	61500.00
0005433434266	26206	Economy	61500.00
0005433434286	26206	Economy	61500.00
0005432984604	26206	Economy	61500.00
0005432049412	26206	Economy	61500.00
0005432984613	26206	Economy	61500.00
0005433434285	26206	Economy	61500.00
0005432984606	26206	Economy	61500.00
0005433434276	26206	Economy	61500.00
0005432869429	26206	Economy	61500.00
0005432869426	26206	Economy	61500.00
0005433434279	26206	Economy	61500.00
0005432984602	26206	Economy	61500.00
0005433434278	26206	Economy	61500.00
0005432869430	26206	Economy	61500.00
0005433434287	26206	Economy	61500.00
0005434731112	26206	Economy	61500.00
0005432984627	26206	Economy	61500.00
0005433753280	26206	Economy	61500.00
0005432049411	26206	Economy	61500.00
0005433434288	26206	Economy	61500.00
0005432984630	26206	Economy	61500.00
0005432984622	26206	Economy	61500.00
0005432984607	26206	Economy	61500.00
0005432984611	26206	Economy	61500.00
0005433434281	26206	Economy	61500.00
0005433434282	26206	Economy	61500.00
0005432984601	26206	Economy	61500.00
0005432051083	26206	Economy	61500.00
0005432869425	26206	Economy	61500.00
0005433434274	26206	Economy	61500.00
0005433434270	26206	Economy	61500.00
0005434731111	26206	Economy	67700.00
0005433434269	26206	Economy	61500.00
0005433434289	26206	Economy	61500.00
0005433434294	26206	Economy	61500.00
0005433434283	26206	Economy	61500.00
0005432984614	26206	Economy	61500.00
0005432984623	26206	Economy	61500.00
0005434731110	26206	Economy	61500.00
0005432984608	26206	Economy	61500.00
0005432984610	26206	Economy	61500.00
0005432984629	26206	Economy	61500.00
0005433434280	26206	Economy	61500.00
0005432984620	26206	Economy	61500.00
0005433434271	26206	Economy	61500.00
0005433753227	26206	Economy	61500.00
0005432869424	26206	Economy	61500.00
0005433434293	26206	Economy	61500.00
0005432984605	26206	Economy	61500.00
0005432984632	26206	Economy	61500.00
0005432984625	26206	Economy	61500.00
0005432984603	26206	Economy	61500.00
0005432869427	26206	Economy	61500.00
0005432984624	26206	Economy	61500.00
0005432869428	26206	Economy	61500.00
0005432984628	26206	Economy	61500.00
0005433434268	26206	Economy	61500.00
0005432984626	26206	Economy	61500.00
0005433434291	26206	Economy	61500.00
0005434731109	26206	Economy	61500.00
0005432051084	26206	Economy	61500.00
0005434374028	1486	Business	38900.00
0005434374016	1486	Business	38900.00
0005433460405	1486	Business	38900.00
0005434374015	1486	Business	38900.00
0005434374010	1486	Business	38900.00
0005434374011	1486	Business	38900.00
0005434374005	1486	Economy	13000.00
0005434374041	1486	Economy	13000.00
0005434374043	1486	Economy	13000.00
0005432267797	1486	Economy	13000.00
0005434374006	1486	Economy	13000.00
0005434374034	1486	Economy	13000.00
0005432267803	1486	Economy	13000.00
0005433460407	1486	Economy	13000.00
0005434374019	1486	Economy	13000.00
0005434374036	1486	Economy	13000.00
0005434374032	1486	Economy	13000.00
0005434374021	1486	Economy	13000.00
0005434373997	1486	Economy	13000.00
0005434374004	1486	Economy	13000.00
0005434374050	1486	Economy	13000.00
0005434374025	1486	Economy	13000.00
0005434374024	1486	Economy	13000.00
0005434374030	1486	Economy	13000.00
0005433460406	1486	Economy	13000.00
0005434374031	1486	Economy	13000.00
0005433461556	1486	Economy	13000.00
0005434374040	1486	Economy	14300.00
0005434374049	1486	Economy	14300.00
0005434374017	1486	Economy	14300.00
0005434374046	1486	Economy	13000.00
0005434374035	1486	Economy	13000.00
0005434374047	1486	Economy	13000.00
0005433461558	1486	Economy	13000.00
0005432267802	1486	Economy	13000.00
0005432267801	1486	Economy	13000.00
0005434374013	1486	Economy	13000.00
0005433150857	1486	Economy	13000.00
0005434373998	1486	Economy	13000.00
0005434373996	1486	Economy	13000.00
0005434374045	1486	Economy	13000.00
0005434374037	1486	Economy	13000.00
0005434374020	1486	Economy	13000.00
0005434374002	1486	Economy	13000.00
0005434374003	1486	Economy	13000.00
0005434374012	1486	Economy	13000.00
0005434374027	1486	Economy	13000.00
0005433461557	1486	Economy	13000.00
0005434374007	1486	Economy	13000.00
0005434374029	1486	Economy	13000.00
0005434374026	1486	Economy	13000.00
0005434374038	1486	Economy	13000.00
0005434374023	1486	Economy	13000.00
0005433150826	1486	Economy	13000.00
0005434374022	1486	Economy	13000.00
0005434373999	1486	Economy	13000.00
0005432267800	1486	Economy	13000.00
0005434374044	1486	Economy	13000.00
0005434374042	1486	Economy	13000.00
0005434374009	1486	Economy	13000.00
0005434374001	1486	Economy	13000.00
0005434374008	1486	Economy	13000.00
0005432267799	1486	Economy	13000.00
0005433150825	1486	Economy	13000.00
0005434374048	1486	Economy	13000.00
0005434374018	1486	Economy	13000.00
0005434374039	1486	Economy	13000.00
0005434374033	1486	Economy	13000.00
0005434374000	1486	Economy	13000.00
0005434374014	1486	Economy	13000.00
0005434373995	1486	Economy	13000.00
0005432267798	1486	Economy	13000.00
0005433150923	20131	Business	38900.00
0005433150904	20131	Business	38900.00
0005433150920	20131	Business	38900.00
0005433150916	20131	Business	38900.00
0005433150922	20131	Business	38900.00
0005433150927	20131	Economy	13000.00
0005433150899	20131	Economy	13000.00
0005434029623	20131	Economy	13000.00
0005433150907	20131	Economy	13000.00
0005433150925	20131	Economy	13000.00
0005433150933	20131	Economy	13000.00
0005433150917	20131	Economy	13000.00
0005433150912	20131	Economy	13000.00
0005433150926	20131	Economy	13000.00
0005432056245	20131	Economy	13000.00
0005433764650	20131	Economy	13000.00
0005432056246	20131	Economy	13000.00
0005433150928	20131	Economy	13000.00
0005433150905	20131	Economy	13000.00
0005433150924	20131	Economy	13000.00
0005434029621	20131	Economy	13000.00
0005433150902	20131	Economy	13000.00
0005433150915	20131	Economy	13000.00
0005433150903	20131	Economy	13000.00
0005433150930	20131	Economy	13000.00
0005433150929	20131	Economy	13000.00
0005433150919	20131	Economy	13000.00
0005433931424	20131	Economy	13000.00
0005433150921	20131	Economy	13000.00
0005433150932	20131	Economy	13000.00
0005432056247	20131	Economy	13000.00
0005433150913	20131	Economy	13000.00
0005433150908	20131	Economy	13000.00
0005434029622	20131	Economy	13000.00
0005433150906	20131	Economy	13000.00
0005433150910	20131	Economy	13000.00
0005433931423	20131	Economy	13000.00
0005433150900	20131	Economy	13000.00
0005433150918	20131	Economy	13000.00
0005433150909	20131	Economy	13000.00
0005433150901	20131	Economy	13000.00
0005433150911	20131	Economy	13000.00
0005432056244	20131	Economy	13000.00
0005433150914	20131	Economy	13000.00
0005433150931	20131	Economy	13000.00
0005433931425	20131	Economy	13000.00
0005432056243	20131	Economy	13000.00
0005432282764	536	Business	27500.00
0005432423776	536	Business	27500.00
0005432423778	536	Business	27500.00
0005432423767	536	Business	27500.00
0005432423784	536	Business	27500.00
0005432423796	536	Business	27500.00
0005432423806	536	Business	27500.00
0005432423774	536	Business	27500.00
0005432423807	536	Business	27500.00
0005432423789	536	Economy	10100.00
0005432423809	536	Economy	10100.00
0005432423793	536	Economy	10100.00
0005432423764	536	Economy	10100.00
0005432423794	536	Economy	9200.00
0005432423766	536	Economy	9200.00
0005432423797	536	Economy	9200.00
0005432423763	536	Economy	9200.00
0005432423800	536	Economy	9200.00
0005432423770	536	Economy	9200.00
0005432423781	536	Economy	9200.00
0005432423773	536	Economy	9200.00
0005432423765	536	Economy	9200.00
0005432423780	536	Economy	9200.00
0005432423803	536	Economy	9200.00
0005432423790	536	Economy	9200.00
0005432423768	536	Economy	9200.00
0005432423775	536	Economy	9200.00
0005432423779	536	Economy	9200.00
0005432423769	536	Economy	9200.00
0005432423795	536	Economy	9200.00
0005432423798	536	Economy	10100.00
0005432423802	536	Economy	10100.00
0005432423792	536	Economy	9200.00
0005432282767	536	Economy	9200.00
0005432282760	536	Economy	9200.00
0005432423788	536	Economy	9200.00
0005432423782	536	Economy	9200.00
0005432423777	536	Economy	9200.00
0005432282762	536	Economy	9200.00
0005432423799	536	Economy	9200.00
0005432282761	536	Economy	9200.00
0005432423808	536	Economy	9200.00
0005432423783	536	Economy	9200.00
0005432423786	536	Economy	9200.00
0005432423804	536	Economy	9200.00
0005432423772	536	Economy	9200.00
0005432423787	536	Economy	9200.00
0005432423785	536	Economy	9200.00
0005432423805	536	Economy	9200.00
0005432282765	536	Economy	9200.00
0005432423801	536	Economy	9200.00
0005432282763	536	Economy	9200.00
0005432282766	536	Economy	9200.00
0005432423771	536	Economy	9200.00
0005432423791	536	Economy	9200.00
0005432302277	12877	Business	27500.00
0005432302275	12877	Business	27500.00
0005432302276	12877	Economy	9200.00
0005432302278	12877	Economy	9200.00
0005434022725	465	Business	24500.00
0005434031953	465	Business	24500.00
0005434022724	465	Business	24500.00
0005434022713	465	Business	24500.00
0005434022736	465	Business	24500.00
0005434022721	465	Business	24500.00
0005432235532	465	Business	24500.00
0005434029620	465	Business	24500.00
0005434022774	465	Business	24500.00
0005434022734	465	Business	24500.00
0005434022729	465	Business	24500.00
0005434022714	465	Business	24500.00
0005434029619	465	Economy	9000.00
0005434028255	465	Economy	8200.00
0005434022718	465	Economy	8200.00
0005434022711	465	Economy	8200.00
0005434022762	465	Economy	8200.00
0005434022709	465	Economy	8200.00
0005434022732	465	Economy	8200.00
0005434022763	465	Economy	8200.00
0005434022756	465	Economy	8200.00
0005434031955	465	Economy	8200.00
0005434022772	465	Economy	8200.00
0005434022722	465	Economy	8200.00
0005434022752	465	Economy	8200.00
0005434022717	465	Economy	8200.00
0005434022712	465	Economy	8200.00
0005434022768	465	Economy	8200.00
0005434028254	465	Economy	8200.00
0005434022715	465	Economy	8200.00
0005434022748	465	Economy	8200.00
0005434022746	465	Economy	8200.00
0005434022735	465	Economy	8200.00
0005434022723	465	Economy	8200.00
0005434022726	465	Economy	8200.00
0005432235533	465	Economy	8200.00
0005434022710	465	Economy	8200.00
0005434022720	465	Economy	8200.00
0005434022753	465	Economy	8200.00
0005434022730	465	Economy	8200.00
0005434022731	465	Economy	8200.00
0005434022773	465	Economy	8200.00
0005434022737	465	Economy	8200.00
0005434022716	465	Economy	8200.00
0005434028256	465	Economy	8200.00
0005434022751	465	Economy	8200.00
0005433057197	465	Economy	8200.00
0005434022767	465	Economy	8200.00
0005434022754	465	Economy	8200.00
0005434022760	465	Economy	8200.00
0005434022750	465	Economy	8200.00
0005434022719	465	Economy	8200.00
0005434031956	465	Economy	8200.00
0005434022742	465	Economy	8200.00
0005434022757	465	Economy	9000.00
0005434022777	465	Economy	8200.00
0005434022740	465	Economy	8200.00
0005434022741	465	Economy	8200.00
0005432235530	465	Economy	9000.00
0005434022758	465	Economy	8200.00
0005434022744	465	Economy	8200.00
0005434031954	465	Economy	8200.00
0005434022743	465	Economy	8200.00
0005434022761	465	Economy	8200.00
0005434022739	465	Economy	8200.00
0005432235527	465	Economy	8200.00
0005434022764	465	Economy	8200.00
0005432235531	465	Economy	8200.00
0005434022759	465	Economy	8200.00
0005432045584	465	Economy	8200.00
0005434022766	465	Economy	8200.00
0005432235528	465	Economy	8200.00
0005434022738	465	Economy	8200.00
0005432235534	465	Economy	8200.00
0005434022775	465	Economy	8200.00
0005434022733	465	Economy	8200.00
0005432235529	465	Economy	8200.00
0005433057196	465	Economy	8200.00
0005434022755	465	Economy	8200.00
0005434022769	465	Economy	8200.00
0005434022771	465	Economy	8200.00
0005434022728	465	Economy	8200.00
0005434022749	465	Economy	8200.00
0005434022747	465	Economy	8200.00
0005434022776	465	Economy	8200.00
0005433057195	465	Economy	8200.00
0005434022745	465	Economy	8200.00
0005434022770	465	Economy	8200.00
0005434022765	465	Economy	8200.00
0005434022727	465	Economy	8200.00
0005433684392	12677	Business	24500.00
0005433057293	12677	Business	24500.00
0005434735614	12677	Business	24500.00
0005434022545	12677	Business	24500.00
0005432156303	12677	Business	24500.00
0005433057291	12677	Business	24500.00
0005432156302	12677	Business	24500.00
0005434735613	12677	Economy	9000.00
0005433057299	12677	Economy	9000.00
0005433684390	12677	Economy	8200.00
0005433929553	12677	Economy	8200.00
0005433057320	12677	Economy	8200.00
0005433057303	12677	Economy	8200.00
0005433057316	12677	Economy	8200.00
0005433057305	12677	Economy	8200.00
0005433057323	12677	Economy	8200.00
0005433057296	12677	Economy	8200.00
0005433057332	12677	Economy	8200.00
0005433057322	12677	Economy	8200.00
0005434735616	12677	Economy	8200.00
0005433057327	12677	Economy	8200.00
0005432157464	12677	Economy	8200.00
0005434735617	12677	Economy	8200.00
0005433057317	12677	Economy	8200.00
0005434735615	12677	Economy	8200.00
0005433057306	12677	Economy	8200.00
0005433057326	12677	Economy	8200.00
0005433057297	12677	Economy	8200.00
0005433057294	12677	Economy	8200.00
0005433057328	12677	Economy	8200.00
0005433057324	12677	Economy	8200.00
0005433057292	12677	Economy	8200.00
0005433057311	12677	Economy	9000.00
0005433929554	12677	Economy	8200.00
0005433057308	12677	Economy	8200.00
0005433684391	12677	Economy	8200.00
0005433057330	12677	Economy	8200.00
0005432156300	12677	Economy	8200.00
0005433057321	12677	Economy	8200.00
0005433057309	12677	Economy	8200.00
0005433057314	12677	Economy	8200.00
0005433057310	12677	Economy	8200.00
0005433057307	12677	Economy	8200.00
0005433057304	12677	Economy	8200.00
0005433057300	12677	Economy	8200.00
0005433057319	12677	Economy	8200.00
0005433057295	12677	Economy	8200.00
0005433929555	12677	Economy	8200.00
0005433057325	12677	Economy	8200.00
0005433057315	12677	Economy	8200.00
0005433057329	12677	Economy	8200.00
0005433057331	12677	Economy	8200.00
0005433057301	12677	Economy	8200.00
0005433057298	12677	Economy	8200.00
0005432156301	12677	Economy	8200.00
0005433057302	12677	Economy	8200.00
0005433057318	12677	Economy	8200.00
0005433057313	12677	Economy	8200.00
0005433057312	12677	Economy	8200.00
0005433529216	13824	Business	111600.00
0005433527207	13824	Business	111600.00
0005433527200	13824	Business	111600.00
0005433529211	13824	Business	111600.00
0005433527203	13824	Business	111600.00
0005433527205	13824	Economy	37200.00
0005433529219	13824	Economy	37200.00
0005433527202	13824	Economy	37200.00
0005433529214	13824	Economy	40900.00
0005433529218	13824	Economy	37200.00
0005433527199	13824	Economy	37200.00
0005433527210	13824	Economy	37200.00
0005433529213	13824	Economy	37200.00
0005433529220	13824	Economy	37200.00
0005433529215	13824	Economy	37200.00
0005433529210	13824	Economy	37200.00
0005433527201	13824	Economy	37200.00
0005433529221	13824	Economy	37200.00
0005433529212	13824	Economy	37200.00
0005433527206	13824	Economy	37200.00
0005433527208	13824	Economy	37200.00
0005433527209	13824	Economy	37200.00
0005433529217	13824	Economy	37200.00
0005433527204	13824	Economy	37200.00
0005433921964	2142	Business	34700.00
0005433921888	2142	Business	34700.00
0005433921950	2142	Business	34700.00
0005433921899	2142	Business	34700.00
0005433921893	2142	Business	34700.00
0005433921926	2142	Business	34700.00
0005433921937	2142	Business	34700.00
0005433929555	2142	Business	34700.00
0005432231410	2142	Business	34700.00
0005432231415	2142	Business	34700.00
0005433921890	2142	Business	34700.00
0005433921975	2142	Business	34700.00
0005433921883	2142	Business	34700.00
0005433921898	2142	Business	34700.00
0005433931423	2142	Business	34700.00
0005433921911	2142	Business	34700.00
0005433921885	2142	Economy	12700.00
0005433921927	2142	Economy	11600.00
0005433921948	2142	Economy	11600.00
0005432044485	2142	Economy	11600.00
0005433921921	2142	Economy	11600.00
0005433921925	2142	Economy	11600.00
0005433921979	2142	Economy	11600.00
0005433921952	2142	Economy	11600.00
0005433921961	2142	Economy	11600.00
0005433921908	2142	Economy	11600.00
0005432231414	2142	Economy	11600.00
0005433921906	2142	Economy	11600.00
0005433921959	2142	Economy	11600.00
0005433921946	2142	Economy	11600.00
0005433921918	2142	Economy	11600.00
0005433921960	2142	Economy	11600.00
0005433921936	2142	Economy	11600.00
0005433875355	2142	Economy	11600.00
0005433921882	2142	Economy	11600.00
0005433921943	2142	Economy	11600.00
0005433921892	2142	Economy	11600.00
0005433921938	2142	Economy	11600.00
0005433921969	2142	Economy	11600.00
0005433931424	2142	Economy	11600.00
0005433921903	2142	Economy	11600.00
0005432044484	2142	Economy	11600.00
0005433921919	2142	Economy	11600.00
0005433929554	2142	Economy	11600.00
0005433921913	2142	Economy	11600.00
0005433921970	2142	Economy	11600.00
0005433921958	2142	Economy	11600.00
0005433921945	2142	Economy	11600.00
0005433921956	2142	Economy	11600.00
0005433921957	2142	Economy	11600.00
0005433921884	2142	Economy	11600.00
0005433921891	2142	Economy	11600.00
0005433921909	2142	Economy	11600.00
0005433921972	2142	Economy	11600.00
0005433921977	2142	Economy	11600.00
0005433921933	2142	Economy	11600.00
0005433921910	2142	Economy	11600.00
0005433921942	2142	Economy	11600.00
0005433921915	2142	Economy	11600.00
0005433921973	2142	Economy	11600.00
0005433921955	2142	Economy	11600.00
0005433931425	2142	Economy	11600.00
0005433921914	2142	Economy	11600.00
0005433921889	2142	Economy	11600.00
0005433921967	2142	Economy	11600.00
0005433921941	2142	Economy	11600.00
0005433921904	2142	Economy	11600.00
0005432231412	2142	Economy	11600.00
0005433921887	2142	Economy	11600.00
0005432231409	2142	Economy	11600.00
0005433921917	2142	Economy	11600.00
0005433921968	2142	Economy	11600.00
0005433921901	2142	Economy	11600.00
0005433921895	2142	Economy	11600.00
0005433921894	2142	Economy	11600.00
0005433921932	2142	Economy	11600.00
0005433921940	2142	Economy	11600.00
0005433921929	2142	Economy	11600.00
0005432231408	2142	Economy	11600.00
0005432231413	2142	Economy	12700.00
0005433921939	2142	Economy	12700.00
0005433921920	2142	Economy	11600.00
0005433921971	2142	Economy	11600.00
0005433921949	2142	Economy	11600.00
0005433921922	2142	Economy	11600.00
0005432231407	2142	Economy	11600.00
0005433921897	2142	Economy	11600.00
0005433921928	2142	Economy	11600.00
0005433921907	2142	Economy	11600.00
0005433921976	2142	Economy	11600.00
0005433921935	2142	Economy	11600.00
0005433921931	2142	Economy	11600.00
0005433921962	2142	Economy	11600.00
0005433921963	2142	Economy	11600.00
0005433921912	2142	Economy	11600.00
0005433921923	2142	Economy	11600.00
0005433921947	2142	Economy	11600.00
0005433921881	2142	Economy	11600.00
0005432044483	2142	Economy	11600.00
0005433921924	2142	Economy	11600.00
0005433921896	2142	Economy	11600.00
0005433921934	2142	Economy	11600.00
0005433921953	2142	Economy	11600.00
0005432231416	2142	Economy	11600.00
0005433921965	2142	Economy	11600.00
0005433921905	2142	Economy	11600.00
0005433921954	2142	Economy	11600.00
0005433921900	2142	Economy	11600.00
0005433921966	2142	Economy	11600.00
0005433921978	2142	Economy	11600.00
0005432231411	2142	Economy	11600.00
0005433921886	2142	Economy	11600.00
0005433929553	2142	Economy	11600.00
0005433921916	2142	Economy	11600.00
0005433875356	2142	Economy	11600.00
0005433921974	2142	Economy	11600.00
0005433921930	2142	Economy	11600.00
0005433921944	2142	Economy	11600.00
0005433921951	2142	Economy	11600.00
0005433921902	2142	Economy	11600.00
0005433035558	24117	Business	34700.00
0005432206114	24117	Business	34700.00
0005433035552	24117	Business	34700.00
0005433035521	24117	Business	34700.00
0005434028258	24117	Business	34700.00
0005433035547	24117	Business	34700.00
0005433035524	24117	Business	34700.00
0005433035565	24117	Business	34700.00
0005433035548	24117	Business	34700.00
0005432749753	24117	Business	34700.00
0005433035569	24117	Business	34700.00
0005433035536	24117	Business	34700.00
0005433035527	24117	Business	34700.00
0005433035543	24117	Business	34700.00
0005433035523	24117	Business	34700.00
0005433035519	24117	Economy	12700.00
0005432206111	24117	Economy	11600.00
0005433035531	24117	Economy	11600.00
0005433035540	24117	Economy	11600.00
0005433035563	24117	Economy	11600.00
0005433035526	24117	Economy	11600.00
0005432206110	24117	Economy	11600.00
0005433035553	24117	Economy	11600.00
0005433035532	24117	Economy	11600.00
0005432207626	24117	Economy	11600.00
0005433035525	24117	Economy	11600.00
0005433035562	24117	Economy	11600.00
0005433035535	24117	Economy	11600.00
0005433035530	24117	Economy	11600.00
0005434028260	24117	Economy	11600.00
0005433035557	24117	Economy	11600.00
0005432749754	24117	Economy	11600.00
0005433035554	24117	Economy	11600.00
0005433035537	24117	Economy	11600.00
0005433035546	24117	Economy	11600.00
0005433035522	24117	Economy	11600.00
0005433035566	24117	Economy	11600.00
0005434028259	24117	Economy	11600.00
0005433035550	24117	Economy	11600.00
0005432206112	24117	Economy	11600.00
0005433035551	24117	Economy	11600.00
0005433035568	24117	Economy	11600.00
0005433035533	24117	Economy	11600.00
0005433035549	24117	Economy	11600.00
0005433035528	24117	Economy	11600.00
0005432206113	24117	Economy	11600.00
0005433035567	24117	Economy	11600.00
0005433035571	24117	Economy	11600.00
0005433035545	24117	Economy	11600.00
0005433035520	24117	Economy	11600.00
0005433035534	24117	Economy	11600.00
0005434028257	24117	Economy	11600.00
0005433035561	24117	Economy	11600.00
0005433035539	24117	Economy	11600.00
0005433035560	24117	Economy	11600.00
0005433035570	24117	Economy	11600.00
0005432207625	24117	Economy	11600.00
0005432207624	24117	Economy	11600.00
0005433035564	24117	Economy	11600.00
0005433035541	24117	Economy	11600.00
0005433035542	24117	Economy	11600.00
0005433035555	24117	Economy	11600.00
0005433035559	24117	Economy	11600.00
0005433035538	24117	Economy	11600.00
0005433035556	24117	Economy	11600.00
0005433035544	24117	Economy	11600.00
0005433035529	24117	Economy	11600.00
0005434550440	251	Business	83700.00
0005434723801	251	Business	83700.00
0005434723687	251	Business	83700.00
0005434723695	251	Business	83700.00
0005434723791	251	Business	83700.00
0005434723782	251	Business	83700.00
0005435142380	251	Business	83700.00
0005434723768	251	Business	83700.00
0005434550470	251	Business	83700.00
0005434723796	251	Business	83700.00
0005434723795	251	Business	83700.00
0005432277616	251	Business	83700.00
0005434723743	251	Business	83700.00
0005434735610	251	Business	83700.00
0005432277611	251	Business	83700.00
0005434723731	251	Business	83700.00
0005435142384	251	Business	83700.00
0005434723765	251	Business	83700.00
0005434550432	251	Comfort	47400.00
0005434723778	251	Comfort	47400.00
0005434723720	251	Comfort	47400.00
0005434723751	251	Comfort	47400.00
0005434723771	251	Comfort	47400.00
0005435142387	251	Comfort	47400.00
0005434723692	251	Comfort	47400.00
0005434550436	251	Comfort	47400.00
0005434723757	251	Comfort	47400.00
0005434723774	251	Comfort	47400.00
0005434723735	251	Comfort	47400.00
0005434550425	251	Comfort	47400.00
0005434550449	251	Comfort	47400.00
0005434723721	251	Comfort	47400.00
0005434550434	251	Comfort	47400.00
0005432277618	251	Comfort	47400.00
0005434550448	251	Comfort	47400.00
0005434723736	251	Comfort	47400.00
0005434723775	251	Comfort	47400.00
0005434550469	251	Comfort	47400.00
0005434723754	251	Comfort	47400.00
0005434723724	251	Comfort	47400.00
0005434550451	251	Comfort	47400.00
0005434550444	251	Comfort	47400.00
0005434723730	251	Comfort	47400.00
0005434723688	251	Economy	27900.00
0005432277610	251	Economy	27900.00
0005434723714	251	Economy	27900.00
0005434723694	251	Economy	27900.00
0005434550426	251	Economy	27900.00
0005434723710	251	Economy	27900.00
0005434723733	251	Economy	27900.00
0005434550471	251	Economy	27900.00
0005434550464	251	Economy	27900.00
0005434723793	251	Economy	27900.00
0005434723685	251	Economy	27900.00
0005434550476	251	Economy	27900.00
0005434550437	251	Economy	27900.00
0005434550473	251	Economy	27900.00
0005434731108	251	Economy	27900.00
0005434302397	251	Economy	27900.00
0005434550455	251	Economy	27900.00
0005434550465	251	Economy	27900.00
0005434550458	251	Economy	27900.00
0005434731106	251	Economy	27900.00
0005434550481	251	Economy	27900.00
0005434723698	251	Economy	27900.00
0005434723707	251	Economy	27900.00
0005434723752	251	Economy	27900.00
0005434723763	251	Economy	27900.00
0005434302396	251	Economy	27900.00
0005434723725	251	Economy	27900.00
0005434550463	251	Economy	27900.00
0005434723717	251	Economy	27900.00
0005435142379	251	Economy	27900.00
0005435142389	251	Economy	27900.00
0005434550478	251	Economy	27900.00
0005434550438	251	Economy	27900.00
0005434723729	251	Economy	27900.00
0005434723781	251	Economy	30700.00
0005434550453	251	Economy	30700.00
0005434550452	251	Economy	27900.00
0005434550456	251	Economy	27900.00
0005434550475	251	Economy	30700.00
0005432277620	251	Economy	30700.00
0005434731107	251	Economy	27900.00
0005434723804	251	Economy	27900.00
0005434731104	251	Economy	27900.00
0005434723705	251	Economy	27900.00
0005432277612	251	Economy	27900.00
0005434723691	251	Economy	27900.00
0005434723715	251	Economy	27900.00
0005434550468	251	Economy	27900.00
0005434735609	251	Economy	27900.00
0005434550435	251	Economy	27900.00
0005434723683	251	Economy	27900.00
0005434731105	251	Economy	27900.00
0005434723789	251	Economy	27900.00
0005434723776	251	Economy	27900.00
0005434723699	251	Economy	27900.00
0005434723784	251	Economy	27900.00
0005434550442	251	Economy	27900.00
0005434723690	251	Economy	27900.00
0005434723734	251	Economy	27900.00
0005432277614	251	Economy	27900.00
0005434723684	251	Economy	27900.00
0005434723709	251	Economy	27900.00
0005434550461	251	Economy	27900.00
0005434723756	251	Economy	27900.00
0005434723758	251	Economy	27900.00
0005434723788	251	Economy	27900.00
0005434550460	251	Economy	27900.00
0005434723786	251	Economy	27900.00
0005434723693	251	Economy	27900.00
0005434723708	251	Economy	27900.00
0005434550427	251	Economy	27900.00
0005434723728	251	Economy	27900.00
0005434723779	251	Economy	27900.00
0005434550447	251	Economy	27900.00
0005434723719	251	Economy	27900.00
0005434723700	251	Economy	27900.00
0005434723802	251	Economy	27900.00
0005434723803	251	Economy	27900.00
0005434723746	251	Economy	27900.00
0005434302398	251	Economy	27900.00
0005434550459	251	Economy	27900.00
0005434723732	251	Economy	27900.00
0005434723742	251	Economy	27900.00
0005434723761	251	Economy	27900.00
0005434550429	251	Economy	27900.00
0005434550477	251	Economy	27900.00
0005434723773	251	Economy	27900.00
0005434723777	251	Economy	27900.00
0005434723738	251	Economy	27900.00
0005434723718	251	Economy	27900.00
0005434723759	251	Economy	27900.00
0005434723712	251	Economy	27900.00
0005432277622	251	Economy	27900.00
0005434735611	251	Economy	27900.00
0005434550431	251	Economy	27900.00
0005434723722	251	Economy	27900.00
0005434723740	251	Economy	27900.00
0005434723794	251	Economy	27900.00
0005434723696	251	Economy	27900.00
0005434723797	251	Economy	27900.00
0005434550428	251	Economy	27900.00
0005434550467	251	Economy	27900.00
0005434723780	251	Economy	27900.00
0005434723769	251	Economy	27900.00
0005434550479	251	Economy	27900.00
0005434723744	251	Economy	30700.00
0005434550443	251	Economy	30700.00
0005432277621	251	Economy	27900.00
0005432277615	251	Economy	27900.00
0005434723783	251	Economy	27900.00
0005434550433	251	Economy	27900.00
0005435142377	251	Economy	27900.00
0005434723745	251	Economy	27900.00
0005434723739	251	Economy	27900.00
0005434723689	251	Economy	27900.00
0005434735612	251	Economy	27900.00
0005434723747	251	Economy	27900.00
0005434550462	251	Economy	27900.00
0005434723755	251	Economy	27900.00
0005434550445	251	Economy	27900.00
0005434723711	251	Economy	27900.00
0005434550439	251	Economy	27900.00
0005435142383	251	Economy	27900.00
0005434723716	251	Economy	27900.00
0005434723702	251	Economy	27900.00
0005434550466	251	Economy	27900.00
0005434723767	251	Economy	27900.00
0005434302395	251	Economy	27900.00
0005434723753	251	Economy	27900.00
0005434723785	251	Economy	27900.00
0005435142385	251	Economy	27900.00
0005434723737	251	Economy	27900.00
0005434723741	251	Economy	27900.00
0005434723766	251	Economy	27900.00
0005435142378	251	Economy	27900.00
0005434550457	251	Economy	27900.00
0005434723790	251	Economy	27900.00
0005434723706	251	Economy	27900.00
0005434723760	251	Economy	27900.00
0005434550454	251	Economy	27900.00
0005434723772	251	Economy	27900.00
0005434723727	251	Economy	27900.00
0005434723750	251	Economy	27900.00
0005434550446	251	Economy	27900.00
0005434723764	251	Economy	27900.00
0005434723799	251	Economy	27900.00
0005434735607	251	Economy	27900.00
0005432277613	251	Economy	27900.00
0005434550480	251	Economy	27900.00
0005434550472	251	Economy	27900.00
0005434550450	251	Economy	27900.00
0005435142381	251	Economy	27900.00
0005434723713	251	Economy	27900.00
0005434550430	251	Economy	27900.00
0005434723787	251	Economy	27900.00
0005435142382	251	Economy	27900.00
0005435142386	251	Economy	27900.00
0005434723762	251	Economy	27900.00
0005433233099	251	Economy	27900.00
0005434723726	251	Economy	27900.00
0005434723800	251	Economy	27900.00
0005434723770	251	Economy	27900.00
0005434735608	251	Economy	27900.00
0005434723703	251	Economy	27900.00
0005434723748	251	Economy	27900.00
0005434550474	251	Economy	27900.00
0005434723686	251	Economy	27900.00
0005434723723	251	Economy	27900.00
0005434723701	251	Economy	27900.00
0005434723798	251	Economy	27900.00
0005434723749	251	Economy	27900.00
0005434723697	251	Economy	27900.00
0005432277619	251	Economy	27900.00
0005435142388	251	Economy	27900.00
0005433233100	251	Economy	27900.00
0005434723792	251	Economy	27900.00
0005434550441	251	Economy	27900.00
0005432277617	251	Economy	27900.00
0005434723704	251	Economy	27900.00
0005433766586	9861	Business	83700.00
0005433233332	9861	Business	83700.00
0005433233310	9861	Business	83700.00
0005433233304	9861	Business	83700.00
0005433233328	9861	Business	83700.00
0005433289742	9861	Business	83700.00
0005434031958	9861	Comfort	47400.00
0005433180745	9861	Comfort	47400.00
0005433180735	9861	Comfort	47400.00
0005433233333	9861	Comfort	47400.00
0005433233294	9861	Comfort	47400.00
0005433129208	9861	Comfort	47400.00
0005433233287	9861	Comfort	47400.00
0005433233290	9861	Comfort	47400.00
0005434723311	9861	Comfort	47400.00
0005433233288	9861	Comfort	47400.00
0005432199145	9861	Comfort	47400.00
0005433233300	9861	Comfort	47400.00
0005432199146	9861	Comfort	47400.00
0005433180727	9861	Comfort	47400.00
0005433233281	9861	Comfort	47400.00
0005433129211	9861	Comfort	47400.00
0005433289743	9861	Economy	27900.00
0005432199148	9861	Economy	27900.00
0005433113504	9861	Economy	27900.00
0005433233320	9861	Economy	27900.00
0005433233318	9861	Economy	27900.00
0005433233327	9861	Economy	27900.00
0005433233283	9861	Economy	27900.00
0005433129210	9861	Economy	27900.00
0005433126777	9861	Economy	27900.00
0005433180733	9861	Economy	27900.00
0005433233286	9861	Economy	27900.00
0005433233282	9861	Economy	27900.00
0005433233311	9861	Economy	27900.00
0005433233317	9861	Economy	27900.00
0005434031960	9861	Economy	27900.00
0005433180730	9861	Economy	27900.00
0005433233331	9861	Economy	27900.00
0005433233303	9861	Economy	27900.00
0005433126779	9861	Economy	27900.00
0005433233334	9861	Economy	27900.00
0005433233316	9861	Economy	27900.00
0005433233284	9861	Economy	30700.00
0005433180747	9861	Economy	30700.00
0005433233309	9861	Economy	27900.00
0005433766587	9861	Economy	30700.00
0005433233321	9861	Economy	27900.00
0005433180732	9861	Economy	27900.00
0005433233336	9861	Economy	27900.00
0005433233277	9861	Economy	27900.00
0005433233280	9861	Economy	27900.00
0005432199147	9861	Economy	27900.00
0005433233326	9861	Economy	27900.00
0005433233308	9861	Economy	27900.00
0005433233323	9861	Economy	27900.00
0005433126778	9861	Economy	27900.00
0005433289745	9861	Economy	27900.00
0005432199149	9861	Economy	27900.00
0005433180744	9861	Economy	27900.00
0005434031961	9861	Economy	27900.00
0005433233324	9861	Economy	27900.00
0005433113503	9861	Economy	27900.00
0005433233301	9861	Economy	27900.00
0005433233298	9861	Economy	27900.00
0005433233291	9861	Economy	27900.00
0005433180736	9861	Economy	27900.00
0005433180729	9861	Economy	27900.00
0005433233306	9861	Economy	27900.00
0005433233293	9861	Economy	27900.00
0005433180741	9861	Economy	27900.00
0005433233289	9861	Economy	27900.00
0005433233299	9861	Economy	27900.00
0005433233302	9861	Economy	27900.00
0005433289740	9861	Economy	27900.00
0005432199152	9861	Economy	27900.00
0005433180726	9861	Economy	27900.00
0005433233278	9861	Economy	27900.00
0005433180743	9861	Economy	27900.00
0005433233296	9861	Economy	27900.00
0005433180738	9861	Economy	27900.00
0005433233285	9861	Economy	27900.00
0005433180739	9861	Economy	27900.00
0005433233297	9861	Economy	27900.00
0005433180737	9861	Economy	27900.00
0005433233275	9861	Economy	27900.00
0005433180728	9861	Economy	27900.00
0005432199150	9861	Economy	27900.00
0005433233307	9861	Economy	27900.00
0005433233292	9861	Economy	27900.00
0005433129209	9861	Economy	27900.00
0005434031959	9861	Economy	27900.00
0005433766585	9861	Economy	27900.00
0005433289739	9861	Economy	27900.00
0005433233335	9861	Economy	27900.00
0005433233313	9861	Economy	27900.00
0005433233312	9861	Economy	27900.00
0005433129207	9861	Economy	27900.00
0005433180746	9861	Economy	27900.00
0005433180742	9861	Economy	27900.00
0005434031957	9861	Economy	27900.00
0005433233274	9861	Economy	27900.00
0005433289744	9861	Economy	27900.00
0005433233279	9861	Economy	27900.00
0005433180749	9861	Economy	27900.00
0005433233276	9861	Economy	27900.00
0005433233295	9861	Economy	27900.00
0005433233319	9861	Economy	27900.00
0005433289741	9861	Economy	27900.00
0005433126780	9861	Economy	27900.00
0005433233329	9861	Economy	27900.00
0005433233330	9861	Economy	27900.00
0005433233315	9861	Economy	27900.00
0005433233325	9861	Economy	27900.00
0005433180731	9861	Economy	27900.00
0005433233322	9861	Economy	27900.00
0005433233273	9861	Economy	27900.00
0005433233305	9861	Economy	27900.00
0005434723312	9861	Economy	27900.00
0005433113502	9861	Economy	27900.00
0005433180748	9861	Economy	27900.00
0005432199151	9861	Economy	27900.00
0005433233314	9861	Economy	27900.00
0005433180750	9861	Economy	27900.00
0005433180740	9861	Economy	27900.00
0005433180734	9861	Economy	27900.00
0005435212331	7763	Business	42100.00
0005434066551	7763	Business	42100.00
0005432069444	7763	Business	42100.00
0005432069440	7763	Business	42100.00
0005434066564	7763	Business	42100.00
0005434066531	7763	Business	42100.00
0005432526090	7763	Business	42100.00
0005434066524	7763	Business	42100.00
0005432526135	7763	Business	42100.00
0005432150085	7763	Business	42100.00
0005432526110	7763	Business	42100.00
0005432526136	7763	Business	42100.00
0005432535761	7763	Business	42100.00
0005434066575	7763	Business	42100.00
0005432526126	7763	Business	42100.00
0005432535764	7763	Business	42100.00
0005432526077	7763	Business	42100.00
0005434066579	7763	Business	42100.00
0005432526042	7763	Comfort	23900.00
0005432526082	7763	Comfort	23900.00
0005432526153	7763	Comfort	23900.00
0005432526078	7763	Comfort	23900.00
0005434066553	7763	Comfort	23900.00
0005432526115	7763	Comfort	23900.00
0005432150082	7763	Comfort	23900.00
0005432069446	7763	Comfort	23900.00
0005434066565	7763	Comfort	23900.00
0005434066567	7763	Comfort	23900.00
0005432526166	7763	Comfort	23900.00
0005432069445	7763	Comfort	23900.00
0005432526105	7763	Comfort	23900.00
0005432526137	7763	Comfort	23900.00
0005434066583	7763	Comfort	23900.00
0005432533249	7763	Comfort	23900.00
0005432069447	7763	Comfort	23900.00
0005432150083	7763	Comfort	23900.00
0005432526049	7763	Comfort	23900.00
0005434066577	7763	Comfort	23900.00
0005434066532	7763	Comfort	23900.00
0005434066528	7763	Comfort	23900.00
0005434066554	7763	Comfort	23900.00
0005432526051	7763	Comfort	23900.00
0005432526104	7763	Comfort	23900.00
0005434066574	7763	Comfort	23900.00
0005434066530	7763	Economy	14000.00
0005432526095	7763	Economy	14000.00
0005432526121	7763	Economy	14000.00
0005432526168	7763	Economy	14000.00
0005432535762	7763	Economy	14000.00
0005432533250	7763	Economy	14000.00
0005432069439	7763	Economy	14000.00
0005432526036	7763	Economy	14000.00
0005432526160	7763	Economy	14000.00
0005432526107	7763	Economy	14000.00
0005432526145	7763	Economy	14000.00
0005434066563	7763	Economy	14000.00
0005432526099	7763	Economy	14000.00
0005432526098	7763	Economy	14000.00
0005432526056	7763	Economy	14000.00
0005432526144	7763	Economy	14000.00
0005434066544	7763	Economy	14000.00
0005432526059	7763	Economy	14000.00
0005432526119	7763	Economy	14000.00
0005434066578	7763	Economy	14000.00
0005432526112	7763	Economy	14000.00
0005432526162	7763	Economy	14000.00
0005432069451	7763	Economy	14000.00
0005432526054	7763	Economy	14000.00
0005432526155	7763	Economy	14000.00
0005434066519	7763	Economy	14000.00
0005432526152	7763	Economy	14000.00
0005432526109	7763	Economy	14000.00
0005432428880	7763	Economy	14000.00
0005434066522	7763	Economy	14000.00
0005432526062	7763	Economy	14000.00
0005432526118	7763	Economy	14000.00
0005432526103	7763	Economy	14000.00
0005432535763	7763	Economy	14000.00
0005432526123	7763	Economy	14000.00
0005432526061	7763	Economy	14000.00
0005432526128	7763	Economy	14000.00
0005432526066	7763	Economy	15400.00
0005432526125	7763	Economy	14000.00
0005432526124	7763	Economy	15400.00
0005432535760	7763	Economy	14000.00
0005432526106	7763	Economy	14000.00
0005432150080	7763	Economy	14000.00
0005432526080	7763	Economy	15400.00
0005432069443	7763	Economy	14000.00
0005432526130	7763	Economy	14000.00
0005432526132	7763	Economy	14000.00
0005432526169	7763	Economy	14000.00
0005432428879	7763	Economy	14000.00
0005432526140	7763	Economy	14000.00
0005432526093	7763	Economy	14000.00
0005432526113	7763	Economy	14000.00
0005434066537	7763	Economy	14000.00
0005434066570	7763	Economy	14000.00
0005432526040	7763	Economy	14000.00
0005434066549	7763	Economy	14000.00
0005432526122	7763	Economy	14000.00
0005432150079	7763	Economy	14000.00
0005434066566	7763	Economy	14000.00
0005434066560	7763	Economy	14000.00
0005434066539	7763	Economy	14000.00
0005432526094	7763	Economy	14000.00
0005432526089	7763	Economy	14000.00
0005434066536	7763	Economy	14000.00
0005432526111	7763	Economy	14000.00
0005432526075	7763	Economy	14000.00
0005434066558	7763	Economy	14000.00
0005434066526	7763	Economy	14000.00
0005432526043	7763	Economy	14000.00
0005434066547	7763	Economy	14000.00
0005434066516	7763	Economy	14000.00
0005432526092	7763	Economy	14000.00
0005432150084	7763	Economy	14000.00
0005432526100	7763	Economy	14000.00
0005432526046	7763	Economy	14000.00
0005432526055	7763	Economy	14000.00
0005432526148	7763	Economy	14000.00
0005432069448	7763	Economy	14000.00
0005432526045	7763	Economy	14000.00
0005432526101	7763	Economy	14000.00
0005432537025	7763	Economy	14000.00
0005434066556	7763	Economy	14000.00
0005432526087	7763	Economy	14000.00
0005432526053	7763	Economy	14000.00
0005432526142	7763	Economy	14000.00
0005432526131	7763	Economy	14000.00
0005434066535	7763	Economy	14000.00
0005434066512	7763	Economy	14000.00
0005432150078	7763	Economy	14000.00
0005434066582	7763	Economy	14000.00
0005432526167	7763	Economy	14000.00
0005432526079	7763	Economy	14000.00
0005434066562	7763	Economy	14000.00
0005434066517	7763	Economy	14000.00
0005432526057	7763	Economy	14000.00
0005432526129	7763	Economy	14000.00
0005434066542	7763	Economy	14000.00
0005434066545	7763	Economy	14000.00
0005432526097	7763	Economy	14000.00
0005432526037	7763	Economy	14000.00
0005432526070	7763	Economy	14000.00
0005432069449	7763	Economy	14000.00
0005432069450	7763	Economy	14000.00
0005434066559	7763	Economy	14000.00
0005434066523	7763	Economy	14000.00
0005432526146	7763	Economy	14000.00
0005432526143	7763	Economy	14000.00
0005432526084	7763	Economy	14000.00
0005432526091	7763	Economy	14000.00
0005434066576	7763	Economy	14000.00
0005432526074	7763	Economy	14000.00
0005434066534	7763	Economy	14000.00
0005432526151	7763	Economy	14000.00
0005432526076	7763	Economy	14000.00
0005432526139	7763	Economy	14000.00
0005434066572	7763	Economy	14000.00
0005434066569	7763	Economy	14000.00
0005432526047	7763	Economy	14000.00
0005434066521	7763	Economy	14000.00
0005432526086	7763	Economy	14000.00
0005432526065	7763	Economy	14000.00
0005432526083	7763	Economy	14000.00
0005432526058	7763	Economy	14000.00
0005434066552	7763	Economy	14000.00
0005432537027	7763	Economy	14000.00
0005432526158	7763	Economy	15400.00
0005434066541	7763	Economy	15400.00
0005432526088	7763	Economy	15400.00
0005432526044	7763	Economy	15400.00
0005434066525	7763	Economy	15400.00
0005432537026	7763	Economy	14000.00
0005432526165	7763	Economy	14000.00
0005432526060	7763	Economy	14000.00
0005434066527	7763	Economy	14000.00
0005434066513	7763	Economy	14000.00
0005434066561	7763	Economy	14000.00
0005434066580	7763	Economy	14000.00
0005432526141	7763	Economy	14000.00
0005432526068	7763	Economy	14000.00
0005434066520	7763	Economy	14000.00
0005432526048	7763	Economy	14000.00
0005434066514	7763	Economy	14000.00
0005434066548	7763	Economy	14000.00
0005432526069	7763	Economy	14000.00
0005434066518	7763	Economy	14000.00
0005432526164	7763	Economy	14000.00
0005432526163	7763	Economy	14000.00
0005434066546	7763	Economy	14000.00
0005432069441	7763	Economy	14000.00
0005434066581	7763	Economy	14000.00
0005434066550	7763	Economy	14000.00
0005434066573	7763	Economy	14000.00
0005432526138	7763	Economy	14000.00
0005432526052	7763	Economy	14000.00
0005432526081	7763	Economy	14000.00
0005432535765	7763	Economy	14000.00
0005432526127	7763	Economy	14000.00
0005434066533	7763	Economy	14000.00
0005432526117	7763	Economy	14000.00
0005432526096	7763	Economy	14000.00
0005434066515	7763	Economy	14000.00
0005432526039	7763	Economy	14000.00
0005432150081	7763	Economy	14000.00
0005432526108	7763	Economy	14000.00
0005434066543	7763	Economy	14000.00
0005432526041	7763	Economy	14000.00
0005432526102	7763	Economy	14000.00
0005432526156	7763	Economy	14000.00
0005432526073	7763	Economy	14000.00
0005432526085	7763	Economy	14000.00
0005432526120	7763	Economy	14000.00
0005434066540	7763	Economy	14000.00
0005432526072	7763	Economy	14000.00
0005432526149	7763	Economy	14000.00
0005432526038	7763	Economy	14000.00
0005432526116	7763	Economy	14000.00
0005432526134	7763	Economy	14000.00
0005432526154	7763	Economy	14000.00
0005434066529	7763	Economy	14000.00
0005432526159	7763	Economy	14000.00
0005432069452	7763	Economy	14000.00
0005434066568	7763	Economy	14000.00
0005432069453	7763	Economy	14000.00
0005432526063	7763	Economy	14000.00
0005432526147	7763	Economy	14000.00
0005432069442	7763	Economy	14000.00
0005432526150	7763	Economy	14000.00
0005434066555	7763	Economy	14000.00
0005432526157	7763	Economy	14000.00
0005434066571	7763	Economy	14000.00
0005432526133	7763	Economy	14000.00
0005432526067	7763	Economy	14000.00
0005432526050	7763	Economy	14000.00
0005432526071	7763	Economy	14000.00
0005432526114	7763	Economy	14000.00
0005434066584	7763	Economy	14000.00
0005434066538	7763	Economy	14000.00
0005432533251	7763	Economy	14000.00
0005432526064	7763	Economy	14000.00
0005434066557	7763	Economy	14000.00
0005432526161	7763	Economy	14000.00
0005435612094	5352	Business	43100.00
0005435612060	5352	Business	43100.00
0005435612075	5352	Business	43100.00
0005435612013	5352	Business	43100.00
0005435612026	5352	Business	43100.00
0005432132996	5352	Business	43100.00
0005435611988	5352	Business	43100.00
0005435097077	5352	Business	43100.00
0005435490179	5352	Business	43100.00
0005434343701	5352	Business	43100.00
0005435612022	5352	Business	43100.00
0005434343716	5352	Business	43100.00
0005434343715	5352	Business	43100.00
0005434343686	5352	Business	43100.00
0005435611997	5352	Business	43100.00
0005434343724	5352	Business	43100.00
0005435611995	5352	Business	43100.00
0005435612027	5352	Business	43100.00
0005435612098	5352	Comfort	24400.00
0005435612076	5352	Business	43100.00
0005435612007	5352	Comfort	24400.00
0005432047495	5352	Comfort	24400.00
0005434573153	5352	Comfort	24400.00
0005435097069	5352	Comfort	24400.00
0005435612067	5352	Comfort	24400.00
0005435423580	5352	Comfort	24400.00
0005435491411	5352	Comfort	24400.00
0005435612001	5352	Comfort	24400.00
0005435611994	5352	Comfort	24400.00
0005435612082	5352	Comfort	24400.00
0005434343705	5352	Comfort	24400.00
0005435612086	5352	Comfort	24400.00
0005435611991	5352	Comfort	24400.00
0005435612059	5352	Comfort	24400.00
0005435097078	5352	Comfort	24400.00
0005435612025	5352	Comfort	24400.00
0005432132987	5352	Comfort	24400.00
0005434343717	5352	Comfort	24400.00
0005435611992	5352	Comfort	24400.00
0005435612079	5352	Comfort	24400.00
0005435612044	5352	Comfort	24400.00
0005435612011	5352	Comfort	24400.00
0005434343703	5352	Comfort	24400.00
0005435612042	5352	Comfort	24400.00
0005435612045	5352	Comfort	24400.00
0005435612019	5352	Comfort	24400.00
0005434343694	5352	Economy	14400.00
0005435555338	5352	Economy	14400.00
0005435612017	5352	Economy	14400.00
0005434573149	5352	Economy	14400.00
0005435612064	5352	Economy	14400.00
0005435097076	5352	Economy	14400.00
0005435612012	5352	Economy	14400.00
0005434343698	5352	Economy	14400.00
0005435612088	5352	Economy	14400.00
0005434343687	5352	Economy	14400.00
0005434343714	5352	Economy	14400.00
0005435612084	5352	Economy	14400.00
0005435555340	5352	Economy	14400.00
0005435490180	5352	Economy	14400.00
0005435612029	5352	Economy	14400.00
0005432132994	5352	Economy	14400.00
0005432133003	5352	Economy	14400.00
0005432133002	5352	Economy	14400.00
0005435612093	5352	Economy	14400.00
0005434343723	5352	Economy	14400.00
0005435612078	5352	Economy	14400.00
0005435612052	5352	Economy	14400.00
0005432132995	5352	Economy	14400.00
0005435612072	5352	Economy	14400.00
0005435423585	5352	Economy	14400.00
0005435612102	5352	Economy	14400.00
0005435612080	5352	Economy	14400.00
0005435612038	5352	Economy	14400.00
0005435612100	5352	Economy	14400.00
0005435612090	5352	Economy	14400.00
0005434343722	5352	Economy	14400.00
0005434343692	5352	Economy	14400.00
0005434343695	5352	Economy	14400.00
0005434343713	5352	Economy	14400.00
0005434343691	5352	Economy	14400.00
0005435612023	5352	Economy	14400.00
0005434573157	5352	Economy	14400.00
0005435423579	5352	Economy	14400.00
0005435612018	5352	Economy	14400.00
0005434343709	5352	Economy	14400.00
0005435612062	5352	Economy	14400.00
0005434573154	5352	Economy	14400.00
0005435612085	5352	Economy	14400.00
0005435612014	5352	Economy	14400.00
0005435612041	5352	Economy	15800.00
0005435612005	5352	Economy	15800.00
0005434573150	5352	Economy	14400.00
0005435612083	5352	Economy	15800.00
0005435612034	5352	Economy	15800.00
0005435612058	5352	Economy	15800.00
0005435612077	5352	Economy	14400.00
0005435612000	5352	Economy	14400.00
0005435612089	5352	Economy	14400.00
0005432132999	5352	Economy	14400.00
0005432132998	5352	Economy	14400.00
0005435612016	5352	Economy	14400.00
0005435612095	5352	Economy	14400.00
0005435097073	5352	Economy	14400.00
0005432132993	5352	Economy	14400.00
0005435612092	5352	Economy	14400.00
0005435612040	5352	Economy	14400.00
0005435612036	5352	Economy	14400.00
0005435611989	5352	Economy	14400.00
0005432133000	5352	Economy	14400.00
0005434573156	5352	Economy	14400.00
0005435612104	5352	Economy	14400.00
0005434343718	5352	Economy	14400.00
0005435612028	5352	Economy	14400.00
0005435612065	5352	Economy	14400.00
0005434343719	5352	Economy	14400.00
0005432132991	5352	Economy	14400.00
0005435612054	5352	Economy	14400.00
0005435612020	5352	Economy	14400.00
0005435612037	5352	Economy	14400.00
0005435612099	5352	Economy	14400.00
0005434343688	5352	Economy	14400.00
0005434343721	5352	Economy	14400.00
0005435097074	5352	Economy	14400.00
0005434573146	5352	Economy	14400.00
0005435612043	5352	Economy	14400.00
0005435612069	5352	Economy	14400.00
0005435612033	5352	Economy	14400.00
0005435612103	5352	Economy	14400.00
0005435612003	5352	Economy	14400.00
0005434343704	5352	Economy	14400.00
0005434343711	5352	Economy	14400.00
0005435611999	5352	Economy	14400.00
0005432132992	5352	Economy	14400.00
0005435612051	5352	Economy	14400.00
0005434573158	5352	Economy	14400.00
0005434343707	5352	Economy	14400.00
0005435612050	5352	Economy	14400.00
0005434343706	5352	Economy	14400.00
0005435612032	5352	Economy	14400.00
0005434343712	5352	Economy	14400.00
0005435097070	5352	Economy	14400.00
0005435612068	5352	Economy	14400.00
0005435612024	5352	Economy	14400.00
0005435612105	5352	Economy	14400.00
0005434573148	5352	Economy	14400.00
0005435490177	5352	Economy	14400.00
0005435612091	5352	Economy	14400.00
0005435612008	5352	Economy	14400.00
0005435555339	5352	Economy	14400.00
0005435612056	5352	Economy	14400.00
0005435612073	5352	Economy	14400.00
0005435612047	5352	Economy	14400.00
0005435611990	5352	Economy	14400.00
0005435612004	5352	Economy	14400.00
0005432132990	5352	Economy	14400.00
0005435490178	5352	Economy	14400.00
0005435423578	5352	Economy	14400.00
0005435612039	5352	Economy	15800.00
0005435611996	5352	Economy	14400.00
0005435612048	5352	Economy	14400.00
0005435612101	5352	Economy	14400.00
0005434343697	5352	Economy	14400.00
0005434343689	5352	Economy	14400.00
0005435612061	5352	Economy	14400.00
0005435612015	5352	Economy	14400.00
0005435612002	5352	Economy	14400.00
0005435097071	5352	Economy	14400.00
0005435612010	5352	Economy	14400.00
0005434343699	5352	Economy	14400.00
0005432132988	5352	Economy	14400.00
0005434343696	5352	Economy	14400.00
0005435612074	5352	Economy	14400.00
0005435611987	5352	Economy	14400.00
0005434343700	5352	Economy	14400.00
0005435612063	5352	Economy	14400.00
0005435612066	5352	Economy	14400.00
0005434573151	5352	Economy	14400.00
0005434573152	5352	Economy	14400.00
0005432047497	5352	Economy	14400.00
0005434573145	5352	Economy	14400.00
0005434343720	5352	Economy	14400.00
0005435612035	5352	Economy	14400.00
0005435612070	5352	Economy	14400.00
0005435611993	5352	Economy	14400.00
0005435612031	5352	Economy	14400.00
0005434573155	5352	Economy	14400.00
0005435611986	5352	Economy	14400.00
0005435611985	5352	Economy	14400.00
0005435491412	5352	Economy	14400.00
0005435612049	5352	Economy	14400.00
0005434343710	5352	Economy	14400.00
0005434573144	5352	Economy	14400.00
0005435612053	5352	Economy	14400.00
0005435612081	5352	Economy	14400.00
0005435612097	5352	Economy	14400.00
0005432047496	5352	Economy	14400.00
0005435423584	5352	Economy	14400.00
0005435097075	5352	Economy	14400.00
0005432133001	5352	Economy	14400.00
0005432132989	5352	Economy	14400.00
0005435612096	5352	Economy	14400.00
0005435612006	5352	Economy	14400.00
0005435612030	5352	Economy	14400.00
0005435612021	5352	Economy	14400.00
0005435612046	5352	Economy	14400.00
0005434343702	5352	Economy	14400.00
0005434343690	5352	Economy	14400.00
0005435612071	5352	Economy	14400.00
0005435611998	5352	Economy	14400.00
0005434343693	5352	Economy	14400.00
0005434573147	5352	Economy	14400.00
0005435491410	5352	Economy	14400.00
0005435612055	5352	Economy	14400.00
0005435612009	5352	Economy	14400.00
0005435612057	5352	Economy	14400.00
0005435612087	5352	Economy	14400.00
0005435097072	5352	Economy	14400.00
0005432132997	5352	Economy	14400.00
0005434343708	5352	Economy	14400.00
0005435423857	10920	Business	43100.00
0005435423832	10920	Business	43100.00
0005435423798	10920	Business	43100.00
0005433719092	10920	Business	43100.00
0005435380227	10920	Business	43100.00
0005434244558	10920	Business	43100.00
0005435423853	10920	Business	43100.00
0005435423794	10920	Business	43100.00
0005435423816	10920	Comfort	24400.00
0005432166854	10920	Comfort	24400.00
0005435423829	10920	Comfort	24400.00
0005435423850	10920	Comfort	24400.00
0005435423789	10920	Comfort	24400.00
0005434656526	10920	Comfort	24400.00
0005435304102	10920	Comfort	24400.00
0005432164931	10920	Comfort	24400.00
0005435423806	10920	Comfort	24400.00
0005432164928	10920	Comfort	24400.00
0005435423822	10920	Comfort	24400.00
0005435319443	10920	Comfort	24400.00
0005434244555	10920	Economy	14400.00
0005435423793	10920	Economy	14400.00
0005434244569	10920	Economy	14400.00
0005435423819	10920	Economy	14400.00
0005434244564	10920	Economy	14400.00
0005432164925	10920	Economy	14400.00
0005435319446	10920	Economy	14400.00
0005434244561	10920	Economy	14400.00
0005435423800	10920	Economy	14400.00
0005435423796	10920	Economy	14400.00
0005432840983	10920	Economy	14400.00
0005435423826	10920	Economy	14400.00
0005435319441	10920	Economy	14400.00
0005434656527	10920	Economy	14400.00
0005435319442	10920	Economy	14400.00
0005434244559	10920	Economy	14400.00
0005435423847	10920	Economy	14400.00
0005435423795	10920	Economy	14400.00
0005435380225	10920	Economy	14400.00
0005435319448	10920	Economy	14400.00
0005435423841	10920	Economy	14400.00
0005435304101	10920	Economy	14400.00
0005435423790	10920	Economy	14400.00
0005435423839	10920	Economy	14400.00
0005435319445	10920	Economy	14400.00
0005432164927	10920	Economy	14400.00
0005435423818	10920	Economy	14400.00
0005435304099	10920	Economy	14400.00
0005435423835	10920	Economy	14400.00
0005435304992	10920	Economy	14400.00
0005435423814	10920	Economy	14400.00
0005435423856	10920	Economy	14400.00
0005435423807	10920	Economy	14400.00
0005435423824	10920	Economy	14400.00
0005434244565	10920	Economy	14400.00
0005435423845	10920	Economy	15800.00
0005434244568	10920	Economy	15800.00
0005432164930	10920	Economy	15800.00
0005435319444	10920	Economy	14400.00
0005435423849	10920	Economy	14400.00
0005434244554	10920	Economy	14400.00
0005432840984	10920	Economy	14400.00
0005432363368	10920	Economy	14400.00
0005435304993	10920	Economy	14400.00
0005435423788	10920	Economy	14400.00
0005435423804	10920	Economy	14400.00
0005435423791	10920	Economy	14400.00
0005435423808	10920	Economy	14400.00
0005435423810	10920	Economy	14400.00
0005435423787	10920	Economy	14400.00
0005435423851	10920	Economy	14400.00
0005434244550	10920	Economy	14400.00
0005435423805	10920	Economy	14400.00
0005434244548	10920	Economy	14400.00
0005434244553	10920	Economy	14400.00
0005435423797	10920	Economy	14400.00
0005435423809	10920	Economy	14400.00
0005434244560	10920	Economy	14400.00
0005434244549	10920	Economy	14400.00
0005435423801	10920	Economy	14400.00
0005434244571	10920	Economy	14400.00
0005434244566	10920	Economy	14400.00
0005435423817	10920	Economy	14400.00
0005434244552	10920	Economy	14400.00
0005435423848	10920	Economy	14400.00
0005434244557	10920	Economy	14400.00
0005434244545	10920	Economy	14400.00
0005435423840	10920	Economy	14400.00
0005435423823	10920	Economy	14400.00
0005434244544	10920	Economy	14400.00
0005434244547	10920	Economy	14400.00
0005435423844	10920	Economy	14400.00
0005435423843	10920	Economy	14400.00
0005432166853	10920	Economy	14400.00
0005435423828	10920	Economy	14400.00
0005435423838	10920	Economy	14400.00
0005435423799	10920	Economy	14400.00
0005435423827	10920	Economy	14400.00
0005435319447	10920	Economy	15800.00
0005435423831	10920	Economy	14400.00
0005435304994	10920	Economy	14400.00
0005435423846	10920	Economy	14400.00
0005435423836	10920	Economy	14400.00
0005434244567	10920	Economy	14400.00
0005435423803	10920	Economy	14400.00
0005435319449	10920	Economy	14400.00
0005434244546	10920	Economy	14400.00
0005435423834	10920	Economy	14400.00
0005432363370	10920	Economy	14400.00
0005434244563	10920	Economy	14400.00
0005435423820	10920	Economy	14400.00
0005435423837	10920	Economy	14400.00
0005435423842	10920	Economy	14400.00
0005435423833	10920	Economy	14400.00
0005435304100	10920	Economy	14400.00
0005434244572	10920	Economy	14400.00
0005435423852	10920	Economy	14400.00
0005435423802	10920	Economy	14400.00
0005435304990	10920	Economy	14400.00
0005432164924	10920	Economy	14400.00
0005432164929	10920	Economy	14400.00
0005435423815	10920	Economy	14400.00
0005435423825	10920	Economy	14400.00
0005432164926	10920	Economy	14400.00
0005433719093	10920	Economy	14400.00
0005434244556	10920	Economy	14400.00
0005435423811	10920	Economy	14400.00
0005435423813	10920	Economy	14400.00
0005432363371	10920	Economy	14400.00
0005432363367	10920	Economy	14400.00
0005435423854	10920	Economy	14400.00
0005434244551	10920	Economy	14400.00
0005435423830	10920	Economy	14400.00
0005435423821	10920	Economy	14400.00
0005435423812	10920	Economy	14400.00
0005435423792	10920	Economy	14400.00
0005435304103	10920	Economy	14400.00
0005434244570	10920	Economy	14400.00
0005435380224	10920	Economy	14400.00
0005432363369	10920	Economy	14400.00
0005434244562	10920	Economy	14400.00
0005435423855	10920	Economy	14400.00
0005435380226	10920	Economy	14400.00
0005432166855	10920	Economy	14400.00
0005435304991	10920	Economy	14400.00
0005433633331	3264	Business	18800.00
0005433633334	3264	Business	18800.00
0005433633339	3264	Business	18800.00
0005432181393	3264	Business	18800.00
0005433506928	3264	Business	18800.00
0005433506923	3264	Business	18800.00
0005433804865	3264	Business	18800.00
0005433804881	3264	Business	18800.00
0005433633348	3264	Business	18800.00
0005433633332	3264	Business	18800.00
0005433506924	3264	Business	18800.00
0005433804886	3264	Business	18800.00
0005433633342	3264	Business	18800.00
0005433633333	3264	Business	18800.00
0005433804887	3264	Business	18800.00
0005433633350	3264	Business	18800.00
0005433633351	3264	Business	18800.00
0005432181388	3264	Business	18800.00
0005433633354	3264	Business	18800.00
0005432181409	3264	Business	18800.00
0005433804885	3264	Business	18800.00
0005432181394	3264	Business	18800.00
0005433633340	3264	Business	18800.00
0005432181404	3264	Economy	6900.00
0005433633324	3264	Economy	6900.00
0005433804890	3264	Economy	6900.00
0005433804873	3264	Economy	6900.00
0005433804877	3264	Economy	6300.00
0005433506922	3264	Economy	6300.00
0005433633321	3264	Economy	6300.00
0005433633318	3264	Economy	6300.00
0005433633322	3264	Economy	6300.00
0005433804891	3264	Economy	6300.00
0005433804868	3264	Economy	6300.00
0005433804883	3264	Economy	6300.00
0005432181401	3264	Economy	6300.00
0005433804878	3264	Economy	6300.00
0005433633353	3264	Economy	6300.00
0005433804871	3264	Economy	6300.00
0005433633341	3264	Economy	6300.00
0005433804884	3264	Economy	6300.00
0005433804861	3264	Economy	6300.00
0005433804874	3264	Economy	6300.00
0005432181402	3264	Economy	6300.00
0005433506914	3264	Economy	6300.00
0005433506926	3264	Economy	6300.00
0005433633346	3264	Economy	6300.00
0005433804869	3264	Economy	6300.00
0005432181398	3264	Economy	6300.00
0005433804888	3264	Economy	6300.00
0005433633326	3264	Economy	6300.00
0005433804875	3264	Economy	6300.00
0005433804872	3264	Economy	6300.00
0005433633328	3264	Economy	6300.00
0005433804864	3264	Economy	6300.00
0005432181389	3264	Economy	6300.00
0005433633352	3264	Economy	6300.00
0005432181396	3264	Economy	6300.00
0005433633327	3264	Economy	6300.00
0005432181403	3264	Economy	6300.00
0005433506921	3264	Economy	6300.00
0005433506929	3264	Economy	6300.00
0005433804892	3264	Economy	6300.00
0005433633338	3264	Economy	6300.00
0005433506920	3264	Economy	6300.00
0005433633343	3264	Economy	6300.00
0005432181390	3264	Economy	6900.00
0005433506925	3264	Economy	6900.00
0005432181387	3264	Economy	6900.00
0005433804862	3264	Economy	6300.00
0005433506915	3264	Economy	6900.00
0005433804860	3264	Economy	6300.00
0005433506913	3264	Economy	6300.00
0005433804866	3264	Economy	6300.00
0005432181406	3264	Economy	6300.00
0005433633319	3264	Economy	6300.00
0005433633337	3264	Economy	6300.00
0005433506919	3264	Economy	6300.00
0005433804870	3264	Economy	6300.00
0005432181408	3264	Economy	6300.00
0005433804879	3264	Economy	6300.00
0005432181392	3264	Economy	6300.00
0005432181400	3264	Economy	6300.00
0005433804876	3264	Economy	6300.00
0005433804863	3264	Economy	6300.00
0005433506927	3264	Economy	6300.00
0005433633330	3264	Economy	6300.00
0005432181399	3264	Economy	6300.00
0005433804882	3264	Economy	6300.00
0005432181407	3264	Economy	6300.00
0005433506917	3264	Economy	6300.00
0005433633336	3264	Economy	6300.00
0005433633349	3264	Economy	6300.00
0005433633344	3264	Economy	6300.00
0005432181391	3264	Economy	6300.00
0005433804867	3264	Economy	6300.00
0005433633329	3264	Economy	6300.00
0005433633345	3264	Economy	6300.00
0005433506916	3264	Economy	6300.00
0005432181397	3264	Economy	6300.00
0005433633323	3264	Economy	6300.00
0005433633347	3264	Economy	6300.00
0005433506918	3264	Economy	6300.00
0005433633320	3264	Economy	6300.00
0005433804859	3264	Economy	6300.00
0005433804889	3264	Economy	6300.00
0005433804880	3264	Economy	6300.00
0005433633325	3264	Economy	6300.00
0005432181405	3264	Economy	6300.00
0005433506912	3264	Economy	6300.00
0005432181395	3264	Economy	6300.00
0005433633335	3264	Economy	6300.00
0005432459154	8226	Business	18800.00
0005432459136	8226	Business	18800.00
0005435884558	8226	Business	18800.00
0005432459119	8226	Business	18800.00
0005435884555	8226	Business	18800.00
0005435884563	8226	Business	18800.00
0005432459169	8226	Business	18800.00
0005432042522	8226	Business	18800.00
0005432459155	8226	Business	18800.00
0005435884528	8226	Business	18800.00
0005435884532	8226	Business	18800.00
0005432042511	8226	Business	18800.00
0005435884572	8226	Business	18800.00
0005432042517	8226	Business	18800.00
0005432459116	8226	Business	18800.00
0005432042520	8226	Business	18800.00
0005435884540	8226	Business	18800.00
0005432459156	8226	Business	18800.00
0005432459143	8226	Business	18800.00
0005432459132	8226	Business	18800.00
0005432459164	8226	Business	18800.00
0005435884543	8226	Economy	6900.00
0005432459158	8226	Economy	6900.00
0005435884560	8226	Economy	6900.00
0005432459127	8226	Economy	6900.00
0005435884571	8226	Economy	6900.00
0005435884545	8226	Economy	6300.00
0005434312289	8226	Economy	6300.00
0005432042510	8226	Economy	6300.00
0005435884547	8226	Economy	6300.00
0005432459134	8226	Economy	6300.00
0005435884565	8226	Economy	6300.00
0005432459152	8226	Economy	6300.00
0005432042523	8226	Economy	6300.00
0005432459117	8226	Economy	6300.00
0005435884541	8226	Economy	6300.00
0005435884534	8226	Economy	6300.00
0005435884574	8226	Economy	6300.00
0005432459140	8226	Economy	6300.00
0005432459129	8226	Economy	6300.00
0005435884575	8226	Economy	6300.00
0005435884548	8226	Economy	6300.00
0005434312291	8226	Economy	6300.00
0005432459142	8226	Economy	6300.00
0005432459120	8226	Economy	6300.00
0005434326260	8226	Economy	6300.00
0005432459148	8226	Economy	6300.00
0005435884542	8226	Economy	6300.00
0005432459157	8226	Economy	6300.00
0005432459126	8226	Economy	6300.00
0005435884553	8226	Economy	6300.00
0005435884527	8226	Economy	6300.00
0005432042524	8226	Economy	6300.00
0005435884561	8226	Economy	6300.00
0005435884533	8226	Economy	6300.00
0005432042521	8226	Economy	6300.00
0005435884577	8226	Economy	6300.00
0005432459130	8226	Economy	6300.00
0005435884530	8226	Economy	6300.00
0005432459160	8226	Economy	6300.00
0005435884566	8226	Economy	6300.00
0005432459163	8226	Economy	6300.00
0005432042513	8226	Economy	6300.00
0005432459121	8226	Economy	6300.00
0005435884556	8226	Economy	6300.00
0005432459146	8226	Economy	6300.00
0005435884544	8226	Economy	6300.00
0005432459144	8226	Economy	6300.00
0005435884529	8226	Economy	6300.00
0005435884539	8226	Economy	6300.00
0005435884537	8226	Economy	6300.00
0005432459170	8226	Economy	6900.00
0005432042515	8226	Economy	6900.00
0005435884570	8226	Economy	6300.00
0005435884538	8226	Economy	6300.00
0005432042514	8226	Economy	6300.00
0005432459123	8226	Economy	6900.00
0005435884576	8226	Economy	6300.00
0005432459124	8226	Economy	6300.00
0005435884526	8226	Economy	6300.00
0005435884573	8226	Economy	6300.00
0005435884569	8226	Economy	6300.00
0005435884567	8226	Economy	6300.00
0005432459159	8226	Economy	6300.00
0005432459141	8226	Economy	6300.00
0005435884568	8226	Economy	6300.00
0005432459131	8226	Economy	6300.00
0005432459135	8226	Economy	6300.00
0005434312290	8226	Economy	6300.00
0005435884552	8226	Economy	6300.00
0005435884551	8226	Economy	6300.00
0005432459125	8226	Economy	6300.00
0005435884554	8226	Economy	6300.00
0005432459122	8226	Economy	6300.00
0005432042519	8226	Economy	6300.00
0005432459167	8226	Economy	6300.00
0005434326259	8226	Economy	6300.00
0005432042512	8226	Economy	6300.00
0005435884557	8226	Economy	6300.00
0005432459166	8226	Economy	6300.00
0005432459153	8226	Economy	6300.00
0005435884536	8226	Economy	6300.00
0005432459162	8226	Economy	6300.00
0005432459139	8226	Economy	6300.00
0005432459151	8226	Economy	6300.00
0005435884562	8226	Economy	6300.00
0005432459137	8226	Economy	6300.00
0005432459150	8226	Economy	6300.00
0005435884578	8226	Economy	6300.00
0005432459128	8226	Economy	6300.00
0005435884549	8226	Economy	6300.00
0005432459118	8226	Economy	6300.00
0005435884546	8226	Economy	6300.00
0005432042518	8226	Economy	6300.00
0005435884559	8226	Economy	6300.00
0005435884531	8226	Economy	6300.00
0005432042516	8226	Economy	6300.00
0005432459138	8226	Economy	6300.00
0005435884535	8226	Economy	6300.00
0005435884550	8226	Economy	6300.00
0005435884564	8226	Economy	6300.00
0005432459145	8226	Economy	6300.00
0005432459161	8226	Economy	6300.00
0005432459147	8226	Economy	6300.00
0005432459165	8226	Economy	6300.00
0005432459133	8226	Economy	6300.00
0005432459149	8226	Economy	6300.00
0005432459168	8226	Economy	6300.00
0005432382623	4515	Business	9900.00
0005432382637	4515	Business	9900.00
0005432382607	4515	Business	9900.00
0005432727762	4515	Business	9900.00
0005432727755	4515	Business	9900.00
0005432727759	4515	Business	9900.00
0005432382639	4515	Business	9900.00
0005433453733	4515	Business	9900.00
0005432382606	4515	Economy	3300.00
0005432382636	4515	Economy	3300.00
0005432382629	4515	Economy	3300.00
0005432382608	4515	Economy	3300.00
0005432382630	4515	Economy	3300.00
0005432382619	4515	Economy	3300.00
0005432382628	4515	Economy	3300.00
0005432727766	4515	Economy	3600.00
0005433453734	4515	Economy	3600.00
0005432382634	4515	Economy	3600.00
0005432382620	4515	Economy	3600.00
0005432382611	4515	Economy	3300.00
0005432727765	4515	Economy	3300.00
0005432382644	4515	Economy	3300.00
0005433454846	4515	Economy	3300.00
0005433722122	4515	Economy	3300.00
0005432382631	4515	Economy	3300.00
0005432382643	4515	Economy	3300.00
0005432727763	4515	Economy	3300.00
0005432727760	4515	Economy	3300.00
0005432382618	4515	Economy	3300.00
0005432382613	4515	Economy	3300.00
0005433722126	4515	Economy	3300.00
0005432382627	4515	Economy	3300.00
0005432382622	4515	Economy	3300.00
0005432382641	4515	Economy	3300.00
0005432382610	4515	Economy	3300.00
0005432727757	4515	Economy	3300.00
0005432382624	4515	Economy	3300.00
0005433722121	4515	Economy	3300.00
0005432382646	4515	Economy	3300.00
0005432382617	4515	Economy	3300.00
0005433454843	4515	Economy	3300.00
0005432382640	4515	Economy	3300.00
0005432382621	4515	Economy	3300.00
0005432727761	4515	Economy	3300.00
0005432382635	4515	Economy	3300.00
0005432727764	4515	Economy	3300.00
0005433454844	4515	Economy	3300.00
0005433722124	4515	Economy	3300.00
0005432382615	4515	Economy	3300.00
0005433722127	4515	Economy	3300.00
0005432382633	4515	Economy	3300.00
0005432382648	4515	Economy	3300.00
0005432382642	4515	Economy	3300.00
0005432382647	4515	Economy	3300.00
0005432382626	4515	Economy	3300.00
0005432382612	4515	Economy	3300.00
0005433722125	4515	Economy	3300.00
0005432382632	4515	Economy	3300.00
0005432727756	4515	Economy	3300.00
0005432382614	4515	Economy	3300.00
0005433454845	4515	Economy	3300.00
0005432382616	4515	Economy	3300.00
0005432382645	4515	Economy	3300.00
0005432382609	4515	Economy	3300.00
0005432727758	4515	Economy	3300.00
0005433722123	4515	Economy	3300.00
0005432382625	4515	Economy	3300.00
0005432382638	4515	Economy	3300.00
0005435540691	1738	Business	57200.00
0005435540704	1738	Business	57200.00
0005435528958	1738	Business	57200.00
0005435540697	1738	Business	57200.00
0005435528949	1738	Business	57200.00
0005435528964	1738	Business	57200.00
0005435540709	1738	Business	57200.00
0005435540705	1738	Economy	19100.00
0005435540708	1738	Economy	19100.00
0005435540695	1738	Economy	19100.00
0005433516750	1738	Economy	19100.00
0005432294453	1738	Economy	19100.00
0005435540710	1738	Economy	21000.00
0005433516751	1738	Economy	21000.00
0005435528960	1738	Economy	21000.00
0005435528952	1738	Economy	19100.00
0005435528961	1738	Economy	19100.00
0005435540696	1738	Economy	19100.00
0005435528955	1738	Economy	19100.00
0005435540706	1738	Economy	19100.00
0005435540692	1738	Economy	19100.00
0005435528950	1738	Economy	19100.00
0005435528959	1738	Economy	19100.00
0005435540690	1738	Economy	19100.00
0005435528947	1738	Economy	19100.00
0005435528957	1738	Economy	19100.00
0005433516755	1738	Economy	19100.00
0005433516749	1738	Economy	19100.00
0005435528953	1738	Economy	19100.00
0005435528965	1738	Economy	19100.00
0005433516757	1738	Economy	19100.00
0005433516754	1738	Economy	19100.00
0005435540693	1738	Economy	19100.00
0005435540698	1738	Economy	19100.00
0005435540700	1738	Economy	19100.00
0005435528956	1738	Economy	19100.00
0005435540694	1738	Economy	19100.00
0005435528948	1738	Economy	19100.00
0005435540699	1738	Economy	19100.00
0005435540701	1738	Economy	19100.00
0005435540702	1738	Economy	19100.00
0005432294454	1738	Economy	19100.00
0005435540707	1738	Economy	19100.00
0005435528966	1738	Economy	19100.00
0005435528951	1738	Economy	19100.00
0005435540703	1738	Economy	19100.00
0005433516752	1738	Economy	19100.00
0005435528962	1738	Economy	19100.00
0005435528963	1738	Economy	19100.00
0005435528954	1738	Economy	19100.00
0005433516753	1738	Economy	19100.00
0005433516756	1738	Economy	19100.00
0005432924968	21993	Economy	19100.00
0005432924967	21993	Economy	19100.00
0005432924969	21993	Economy	19100.00
0005432924970	21993	Economy	19100.00
0005432838583	7354	Business	18500.00
0005434458499	7354	Business	18500.00
0005432838593	7354	Business	18500.00
0005432838581	7354	Business	18500.00
0005434458518	7354	Business	18500.00
0005432838598	7354	Business	18500.00
0005432823419	7354	Economy	6200.00
0005432838597	7354	Economy	6200.00
0005432838588	7354	Economy	6200.00
0005432073339	7354	Economy	6200.00
0005432838596	7354	Economy	6200.00
0005432838578	7354	Economy	6200.00
0005434458505	7354	Economy	6200.00
0005432838582	7354	Economy	6200.00
0005434458510	7354	Economy	6800.00
0005434458500	7354	Economy	6800.00
0005434458501	7354	Economy	6800.00
0005432838604	7354	Economy	6800.00
0005432838585	7354	Economy	6200.00
0005434458511	7354	Economy	6200.00
0005434458509	7354	Economy	6200.00
0005432838592	7354	Economy	6200.00
0005432838580	7354	Economy	6200.00
0005432073340	7354	Economy	6200.00
0005432838594	7354	Economy	6200.00
0005434458506	7354	Economy	6200.00
0005434458513	7354	Economy	6200.00
0005434458516	7354	Economy	6200.00
0005434458512	7354	Economy	6200.00
0005434458508	7354	Economy	6200.00
0005434458515	7354	Economy	6200.00
0005432840982	7354	Economy	6200.00
0005432838576	7354	Economy	6200.00
0005432838586	7354	Economy	6200.00
0005432073341	7354	Economy	6200.00
0005432838601	7354	Economy	6200.00
0005432838602	7354	Economy	6200.00
0005434458504	7354	Economy	6200.00
0005432823421	7354	Economy	6200.00
0005432840981	7354	Economy	6200.00
0005432838579	7354	Economy	6200.00
0005432073342	7354	Economy	6200.00
0005434458498	7354	Economy	6200.00
0005432838577	7354	Economy	6200.00
0005432838589	7354	Economy	6200.00
0005432823420	7354	Economy	6200.00
0005432840980	7354	Economy	6200.00
0005434458503	7354	Economy	6200.00
0005432838587	7354	Economy	6200.00
0005432838591	7354	Economy	6200.00
0005432838599	7354	Economy	6200.00
0005434458502	7354	Economy	6200.00
0005432838605	7354	Economy	6200.00
0005432838606	7354	Economy	6200.00
0005432838600	7354	Economy	6200.00
0005432838590	7354	Economy	6200.00
0005434458507	7354	Economy	6200.00
0005432838595	7354	Economy	6200.00
0005434458514	7354	Economy	6200.00
0005432838603	7354	Economy	6200.00
0005434458497	7354	Economy	6200.00
0005432838584	7354	Economy	6200.00
0005434458517	7354	Economy	6200.00
0005435252443	28912	Business	18500.00
0005435252445	28912	Business	18500.00
0005435252439	28912	Economy	6200.00
0005434664927	28912	Economy	6200.00
0005435491414	28912	Economy	6200.00
0005435252441	28912	Economy	6200.00
0005435252448	28912	Economy	6800.00
0005432000994	28912	Economy	6800.00
0005434664929	28912	Economy	6200.00
0005432838505	28912	Economy	6200.00
0005435252437	28912	Economy	6200.00
0005435252440	28912	Economy	6200.00
0005435252449	28912	Economy	6200.00
0005435252451	28912	Economy	6200.00
0005435252444	28912	Economy	6200.00
0005435252435	28912	Economy	6200.00
0005435252436	28912	Economy	6200.00
0005434664928	28912	Economy	6200.00
0005435252442	28912	Economy	6200.00
0005435252447	28912	Economy	6200.00
0005435252446	28912	Economy	6200.00
0005435252438	28912	Economy	6200.00
0005435252452	28912	Economy	6200.00
0005435252450	28912	Economy	6200.00
0005432838480	28912	Economy	6200.00
0005432000995	28912	Economy	6200.00
0005432838504	28912	Economy	6200.00
0005434664926	28912	Economy	6200.00
0005435491413	28912	Economy	6200.00
0005435990523	8786	Business	145300.00
0005435990521	8786	Business	145300.00
0005435990519	8786	Business	145300.00
0005435990520	8786	Economy	48400.00
0005435990522	8786	Economy	48400.00
0005435990524	8786	Economy	48400.00
0005435990525	8786	Economy	48400.00
0005435990526	8786	Economy	48400.00
0005434275944	15722	Business	145300.00
0005434275943	15722	Economy	48400.00
0005434275942	15722	Economy	48400.00
0005434275945	15722	Economy	48400.00
0005434275946	15722	Economy	48400.00
0005432427113	20635	Economy	15900.00
0005432427112	20635	Economy	14500.00
0005432427111	20635	Economy	14500.00
0005432427110	20635	Economy	14500.00
0005432427114	20635	Economy	14500.00
0005432359667	6381	Business	36600.00
0005432359690	6381	Business	36600.00
0005432335860	6381	Business	36600.00
0005432363371	6381	Business	36600.00
0005432359688	6381	Business	36600.00
0005432359664	6381	Economy	12200.00
0005432335865	6381	Economy	12200.00
0005432363367	6381	Economy	12200.00
0005432359702	6381	Economy	12200.00
0005432359679	6381	Economy	12200.00
0005432359683	6381	Economy	12200.00
0005432359682	6381	Economy	12200.00
0005432359676	6381	Economy	12200.00
0005432062152	6381	Economy	12200.00
0005432359658	6381	Economy	12200.00
0005432363368	6381	Economy	12200.00
0005432359654	6381	Economy	12200.00
0005432359668	6381	Economy	12200.00
0005432359670	6381	Economy	12200.00
0005432359672	6381	Economy	12200.00
0005432359693	6381	Economy	12200.00
0005432359656	6381	Economy	12200.00
0005432359663	6381	Economy	12200.00
0005432359681	6381	Economy	12200.00
0005432359700	6381	Economy	13400.00
0005432359685	6381	Economy	13400.00
0005432359695	6381	Economy	13400.00
0005432359671	6381	Economy	13400.00
0005432335863	6381	Economy	12200.00
0005432359699	6381	Economy	13400.00
0005432359657	6381	Economy	12200.00
0005432335861	6381	Economy	12200.00
0005432359674	6381	Economy	12200.00
0005432359665	6381	Economy	12200.00
0005432359662	6381	Economy	12200.00
0005432359660	6381	Economy	12200.00
0005432359703	6381	Economy	12200.00
0005432359689	6381	Economy	12200.00
0005432359698	6381	Economy	12200.00
0005432359684	6381	Economy	12200.00
0005435176604	6381	Economy	12200.00
0005432335867	6381	Economy	12200.00
0005432335864	6381	Economy	12200.00
0005432363370	6381	Economy	12200.00
0005432359692	6381	Economy	12200.00
0005432359678	6381	Economy	12200.00
0005432335862	6381	Economy	12200.00
0005432359680	6381	Economy	12200.00
0005432359675	6381	Economy	12200.00
0005432335859	6381	Economy	12200.00
0005432359659	6381	Economy	12200.00
0005432359677	6381	Economy	12200.00
0005432359694	6381	Economy	12200.00
0005432359661	6381	Economy	12200.00
0005432062151	6381	Economy	12200.00
0005432359655	6381	Economy	12200.00
0005432363369	6381	Economy	12200.00
0005432335858	6381	Economy	12200.00
0005435176603	6381	Economy	12200.00
0005432359691	6381	Economy	12200.00
0005432359669	6381	Economy	12200.00
0005432359696	6381	Economy	12200.00
0005432359701	6381	Economy	12200.00
0005432335868	6381	Economy	12200.00
0005432062153	6381	Economy	12200.00
0005432359687	6381	Economy	12200.00
0005432335866	6381	Economy	12200.00
0005432359666	6381	Economy	12200.00
0005432359697	6381	Economy	12200.00
0005432359686	6381	Economy	12200.00
0005432062154	6381	Economy	12200.00
0005432359673	6381	Economy	12200.00
0005435176689	21014	Business	36600.00
0005435490183	21014	Economy	12200.00
0005435176688	21014	Economy	12200.00
0005435176692	21014	Economy	12200.00
0005434149561	21014	Economy	12200.00
0005435176675	21014	Economy	12200.00
0005435176677	21014	Economy	12200.00
0005434149560	21014	Economy	12200.00
0005434149566	21014	Economy	12200.00
0005434149563	21014	Economy	12200.00
0005435176683	21014	Economy	12200.00
0005435176674	21014	Economy	12200.00
0005435176691	21014	Economy	12200.00
0005434149557	21014	Economy	12200.00
0005435490181	21014	Economy	12200.00
0005435176693	21014	Economy	13400.00
0005432052702	21014	Economy	12200.00
0005435490182	21014	Economy	12200.00
0005435723017	21014	Economy	12200.00
0005435176680	21014	Economy	12200.00
0005435176684	21014	Economy	12200.00
0005435176673	21014	Economy	12200.00
0005432052701	21014	Economy	12200.00
0005434149567	21014	Economy	12200.00
0005432052703	21014	Economy	12200.00
0005435176671	21014	Economy	12200.00
0005435723018	21014	Economy	12200.00
0005435176685	21014	Economy	12200.00
0005435176694	21014	Economy	12200.00
0005435176695	21014	Economy	12200.00
0005435723019	21014	Economy	12200.00
0005434149562	21014	Economy	12200.00
0005435176682	21014	Economy	12200.00
0005435176676	21014	Economy	12200.00
0005435176686	21014	Economy	12200.00
0005434149558	21014	Economy	12200.00
0005435176679	21014	Economy	12200.00
0005435176678	21014	Economy	12200.00
0005434149564	21014	Economy	12200.00
0005435723016	21014	Economy	12200.00
0005435176672	21014	Economy	12200.00
0005434149565	21014	Economy	12200.00
0005435176687	21014	Economy	12200.00
0005435176681	21014	Economy	12200.00
0005435176670	21014	Economy	12200.00
0005435176697	21014	Economy	12200.00
0005434149559	21014	Economy	12200.00
0005435176696	21014	Economy	12200.00
0005435176690	21014	Economy	12200.00
0005434186158	17720	Economy	3100.00
0005434186157	17720	Economy	3100.00
0005434186159	17720	Economy	3100.00
0005434458499	29085	Economy	3400.00
0005434458505	29085	Economy	3400.00
0005434458513	29085	Economy	3400.00
0005434458512	29085	Economy	3400.00
0005434448262	29085	Economy	3100.00
0005434458500	29085	Economy	3100.00
0005434458514	29085	Economy	3100.00
0005434458507	29085	Economy	3100.00
0005434458508	29085	Economy	3100.00
0005434448263	29085	Economy	3100.00
0005434458502	29085	Economy	3100.00
0005434458503	29085	Economy	3100.00
0005434448261	29085	Economy	3100.00
0005434458515	29085	Economy	3100.00
0005434463897	29085	Economy	3100.00
0005434448264	29085	Economy	3100.00
0005434458517	29085	Economy	3100.00
0005434458511	29085	Economy	3100.00
0005434458498	29085	Economy	3100.00
0005434458510	29085	Economy	3100.00
0005434458509	29085	Economy	3100.00
0005434462757	29085	Economy	3100.00
0005434462758	29085	Economy	3100.00
0005434463896	29085	Economy	3100.00
0005434458504	29085	Economy	3100.00
0005434458516	29085	Economy	3100.00
0005434458518	29085	Economy	3100.00
0005434458497	29085	Economy	3100.00
0005434462756	29085	Economy	3100.00
0005434458506	29085	Economy	3100.00
0005434458501	29085	Economy	3100.00
0005432603737	21458	Economy	7300.00
0005432603760	21458	Economy	7300.00
0005432603751	21458	Economy	7300.00
0005432603734	21458	Economy	6600.00
0005432603724	21458	Economy	6600.00
0005432603745	21458	Economy	6600.00
0005432603750	21458	Economy	6600.00
0005432603744	21458	Economy	6600.00
0005432603743	21458	Economy	6600.00
0005432603742	21458	Economy	6600.00
0005432603740	21458	Economy	6600.00
0005432603727	21458	Economy	6600.00
0005432603736	21458	Economy	6600.00
0005432603733	21458	Economy	6600.00
0005432603728	21458	Economy	6600.00
0005432603753	21458	Economy	6600.00
0005432603747	21458	Economy	6600.00
0005432603738	21458	Economy	6600.00
0005432603735	21458	Economy	6600.00
0005432603758	21458	Economy	6600.00
0005432603752	21458	Economy	6600.00
0005432603739	21458	Economy	6600.00
0005432603757	21458	Economy	6600.00
0005432603726	21458	Economy	6600.00
0005432603725	21458	Economy	6600.00
0005432603732	21458	Economy	6600.00
0005432603746	21458	Economy	6600.00
0005432603748	21458	Economy	6600.00
0005432603729	21458	Economy	6600.00
0005432603749	21458	Economy	6600.00
0005432603723	21458	Economy	6600.00
0005432603731	21458	Economy	6600.00
0005432603754	21458	Economy	6600.00
0005432603761	21458	Economy	6600.00
0005432603759	21458	Economy	6600.00
0005432603762	21458	Economy	6600.00
0005432603730	21458	Economy	6600.00
0005432603741	21458	Economy	6600.00
0005432603755	21458	Economy	6600.00
0005432603756	21458	Economy	6600.00
0005435221501	31665	Economy	6600.00
0005435221502	31665	Economy	6600.00
0005435221040	31665	Economy	6600.00
0005435221038	31665	Economy	6600.00
0005435221039	31665	Economy	6600.00
0005435154580	12304	Economy	19500.00
0005435154583	12304	Economy	17800.00
0005435154581	12304	Economy	17800.00
0005435154582	12304	Economy	17800.00
0005435154584	12304	Economy	17800.00
0005435154585	12304	Economy	17800.00
0005434606769	22389	Economy	6600.00
0005434604845	22389	Economy	6600.00
0005434606768	22389	Economy	6600.00
0005434606770	22389	Economy	6600.00
0005434606771	22389	Economy	6600.00
0005432747005	387	Business	44500.00
0005432751476	387	Business	44500.00
0005432747013	387	Business	44500.00
0005432747016	387	Business	44500.00
0005432219942	387	Business	44500.00
0005432751474	387	Business	44500.00
0005432747006	387	Business	44500.00
0005432747008	387	Business	44500.00
0005432746995	387	Economy	14800.00
0005432747019	387	Economy	14800.00
0005432746990	387	Economy	14800.00
0005432746985	387	Economy	14800.00
0005432746994	387	Economy	14800.00
0005432753248	387	Economy	16300.00
0005435154587	387	Economy	16300.00
0005432749752	387	Economy	16300.00
0005432746997	387	Economy	16300.00
0005432746999	387	Economy	14800.00
0005432747002	387	Economy	14800.00
0005432219941	387	Economy	14800.00
0005432219940	387	Economy	14800.00
0005432747012	387	Economy	14800.00
0005432747010	387	Economy	14800.00
0005432746984	387	Economy	14800.00
0005432753250	387	Economy	14800.00
0005432747001	387	Economy	14800.00
0005432747020	387	Economy	14800.00
0005432746988	387	Economy	14800.00
0005432751475	387	Economy	14800.00
0005432747021	387	Economy	14800.00
0005432747011	387	Economy	14800.00
0005432749751	387	Economy	14800.00
0005432746986	387	Economy	14800.00
0005432746998	387	Economy	14800.00
0005432746982	387	Economy	14800.00
0005432746993	387	Economy	14800.00
0005432747017	387	Economy	14800.00
0005435154588	387	Economy	14800.00
0005432746992	387	Economy	14800.00
0005435154586	387	Economy	14800.00
0005432746996	387	Economy	14800.00
0005432747018	387	Economy	14800.00
0005432747004	387	Economy	14800.00
0005432753249	387	Economy	14800.00
0005432746989	387	Economy	14800.00
0005432746991	387	Economy	14800.00
0005432747015	387	Economy	14800.00
0005432746987	387	Economy	14800.00
0005432747003	387	Economy	14800.00
0005432219939	387	Economy	14800.00
0005432753251	387	Economy	14800.00
0005432747007	387	Economy	14800.00
0005432746983	387	Economy	14800.00
0005432747009	387	Economy	14800.00
0005432747014	387	Economy	14800.00
0005432747000	387	Economy	14800.00
0005433293157	12074	Business	44500.00
0005432890743	12074	Business	44500.00
0005432890748	12074	Business	44500.00
0005432890731	12074	Business	44500.00
0005432890735	12074	Business	44500.00
0005432890739	12074	Business	44500.00
0005433293156	12074	Economy	14800.00
0005433293152	12074	Economy	14800.00
0005432890745	12074	Economy	14800.00
0005433293148	12074	Economy	14800.00
0005432890730	12074	Economy	14800.00
0005432890741	12074	Economy	14800.00
0005433293149	12074	Economy	14800.00
0005433293150	12074	Economy	16300.00
0005433293158	12074	Economy	14800.00
0005432214771	12074	Economy	14800.00
0005432890747	12074	Economy	14800.00
0005432890736	12074	Economy	14800.00
0005432890737	12074	Economy	14800.00
0005434153517	12074	Economy	14800.00
0005432214772	12074	Economy	14800.00
0005432890733	12074	Economy	14800.00
0005432890746	12074	Economy	14800.00
0005432746864	12074	Economy	14800.00
0005434153516	12074	Economy	14800.00
0005432890734	12074	Economy	14800.00
0005433293153	12074	Economy	14800.00
0005432890742	12074	Economy	14800.00
0005433293163	12074	Economy	14800.00
0005432890744	12074	Economy	14800.00
0005433293155	12074	Economy	14800.00
0005433293159	12074	Economy	14800.00
0005432890732	12074	Economy	14800.00
0005433875357	12074	Economy	14800.00
0005432890738	12074	Economy	14800.00
0005433293154	12074	Economy	14800.00
0005433293162	12074	Economy	14800.00
0005433293161	12074	Economy	14800.00
0005432890729	12074	Economy	14800.00
0005433293151	12074	Economy	14800.00
0005432890740	12074	Economy	14800.00
0005433293160	12074	Economy	14800.00
0005433524879	18940	Economy	28200.00
0005433524880	18940	Economy	28200.00
0005433533249	18940	Economy	25700.00
0005433533248	18940	Economy	25700.00
0005433533250	18940	Economy	25700.00
0005433524876	18940	Economy	25700.00
0005433524873	18940	Economy	25700.00
0005433524877	18940	Economy	25700.00
0005433524874	18940	Economy	25700.00
0005433533251	18940	Economy	25700.00
0005433524871	18940	Economy	25700.00
0005433524875	18940	Economy	25700.00
0005433531235	18940	Economy	25700.00
0005433533252	18940	Economy	25700.00
0005433524870	18940	Economy	25700.00
0005433531236	18940	Economy	25700.00
0005433524872	18940	Economy	25700.00
0005433524878	18940	Economy	25700.00
0005433531234	18940	Economy	25700.00
0005432927906	32458	Economy	28200.00
0005432927903	32458	Economy	25700.00
0005432927904	32458	Economy	25700.00
0005432927907	32458	Economy	25700.00
0005432927908	32458	Economy	25700.00
0005432927905	32458	Economy	25700.00
0005434821732	5286	Business	84000.00
0005434821726	5286	Business	84000.00
0005434821742	5286	Business	84000.00
0005434821706	5286	Business	84000.00
0005434821757	5286	Business	84000.00
0005434821777	5286	Business	84000.00
0005434821767	5286	Business	84000.00
0005434821704	5286	Business	84000.00
0005434821790	5286	Business	84000.00
0005435149840	5286	Business	84000.00
0005434821703	5286	Business	84000.00
0005434821785	5286	Business	84000.00
0005434821756	5286	Comfort	47600.00
0005434821759	5286	Comfort	47600.00
0005434821824	5286	Comfort	47600.00
0005434821774	5286	Comfort	47600.00
0005434821710	5286	Comfort	47600.00
0005434821723	5286	Comfort	47600.00
0005434821739	5286	Comfort	47600.00
0005432396185	5286	Comfort	47600.00
0005434821713	5286	Comfort	47600.00
0005434821709	5286	Comfort	47600.00
0005434828654	5286	Comfort	47600.00
0005434821809	5286	Comfort	47600.00
0005434558158	5286	Comfort	47600.00
0005432396183	5286	Comfort	47600.00
0005434821720	5286	Comfort	47600.00
0005434821735	5286	Comfort	47600.00
0005434821789	5286	Comfort	47600.00
0005432121126	5286	Comfort	47600.00
0005434821778	5286	Comfort	47600.00
0005434821734	5286	Comfort	47600.00
0005434821718	5286	Comfort	47600.00
0005435372139	5286	Comfort	47600.00
0005434821803	5286	Comfort	47600.00
0005434821754	5286	Comfort	47600.00
0005432121136	5286	Economy	28000.00
0005434821702	5286	Economy	28000.00
0005434821729	5286	Economy	28000.00
0005434821725	5286	Economy	28000.00
0005434821769	5286	Economy	28000.00
0005434821822	5286	Economy	28000.00
0005434821764	5286	Economy	28000.00
0005435149832	5286	Economy	28000.00
0005435149831	5286	Economy	28000.00
0005434821804	5286	Economy	28000.00
0005434821708	5286	Economy	28000.00
0005434821793	5286	Economy	28000.00
0005434821786	5286	Economy	28000.00
0005434821750	5286	Economy	28000.00
0005432394046	5286	Economy	28000.00
0005434821808	5286	Economy	28000.00
0005432121125	5286	Economy	28000.00
0005434821755	5286	Economy	28000.00
0005434821727	5286	Economy	28000.00
0005434821773	5286	Economy	28000.00
0005434821807	5286	Economy	28000.00
0005434821768	5286	Economy	28000.00
0005435149837	5286	Economy	28000.00
0005435149833	5286	Economy	28000.00
0005434821795	5286	Economy	28000.00
0005434821766	5286	Economy	28000.00
0005434821744	5286	Economy	30800.00
0005434821771	5286	Economy	28000.00
0005434821775	5286	Economy	30800.00
0005434821783	5286	Economy	28000.00
0005434821797	5286	Economy	30800.00
0005435149836	5286	Economy	28000.00
0005432121132	5286	Economy	28000.00
0005434831079	5286	Economy	28000.00
0005434821811	5286	Economy	28000.00
0005432121134	5286	Economy	28000.00
0005434821707	5286	Economy	28000.00
0005434821737	5286	Economy	28000.00
0005432121135	5286	Economy	28000.00
0005434821736	5286	Economy	28000.00
0005434821782	5286	Economy	28000.00
0005434821792	5286	Economy	28000.00
0005432121128	5286	Economy	28000.00
0005434821753	5286	Economy	28000.00
0005434821788	5286	Economy	28000.00
0005434821714	5286	Economy	28000.00
0005434821776	5286	Economy	28000.00
0005432121138	5286	Economy	28000.00
0005434821794	5286	Economy	28000.00
0005432121130	5286	Economy	28000.00
0005434558159	5286	Economy	28000.00
0005432121139	5286	Economy	28000.00
0005432394045	5286	Economy	28000.00
0005435149827	5286	Economy	28000.00
0005434821801	5286	Economy	28000.00
0005434828655	5286	Economy	28000.00
0005434821825	5286	Economy	28000.00
0005434821791	5286	Economy	28000.00
0005434831076	5286	Economy	28000.00
0005432394044	5286	Economy	28000.00
0005434821760	5286	Economy	28000.00
0005434821780	5286	Economy	28000.00
0005434821712	5286	Economy	28000.00
0005435149830	5286	Economy	28000.00
0005432396184	5286	Economy	28000.00
0005434821762	5286	Economy	28000.00
0005434821813	5286	Economy	28000.00
0005434821823	5286	Economy	28000.00
0005434558157	5286	Economy	28000.00
0005434821716	5286	Economy	28000.00
0005434831080	5286	Economy	28000.00
0005434821829	5286	Economy	28000.00
0005434821814	5286	Economy	28000.00
0005434821733	5286	Economy	28000.00
0005434821711	5286	Economy	28000.00
0005435149828	5286	Economy	28000.00
0005434821724	5286	Economy	28000.00
0005434821802	5286	Economy	28000.00
0005434821799	5286	Economy	28000.00
0005434821815	5286	Economy	28000.00
0005434821806	5286	Economy	28000.00
0005434821743	5286	Economy	28000.00
0005434821800	5286	Economy	28000.00
0005432121127	5286	Economy	28000.00
0005435149838	5286	Economy	28000.00
0005434821701	5286	Economy	28000.00
0005434821748	5286	Economy	28000.00
0005434821763	5286	Economy	28000.00
0005434831077	5286	Economy	28000.00
0005434821700	5286	Economy	30800.00
0005434821705	5286	Economy	30800.00
0005434821821	5286	Economy	30800.00
0005434558155	5286	Economy	28000.00
0005432394047	5286	Economy	28000.00
0005434821745	5286	Economy	28000.00
0005434821761	5286	Economy	28000.00
0005434821818	5286	Economy	28000.00
0005432396186	5286	Economy	28000.00
0005434821749	5286	Economy	28000.00
0005434821798	5286	Economy	28000.00
0005434821731	5286	Economy	28000.00
0005434821751	5286	Economy	28000.00
0005432121129	5286	Economy	28000.00
0005434821784	5286	Economy	28000.00
0005435149829	5286	Economy	28000.00
0005434821741	5286	Economy	28000.00
0005434821819	5286	Economy	28000.00
0005434821820	5286	Economy	28000.00
0005434821826	5286	Economy	28000.00
0005434821738	5286	Economy	28000.00
0005434821715	5286	Economy	28000.00
0005434821817	5286	Economy	28000.00
0005434821728	5286	Economy	28000.00
0005432121137	5286	Economy	28000.00
0005434821779	5286	Economy	28000.00
0005434821721	5286	Economy	28000.00
0005434821747	5286	Economy	28000.00
0005434821812	5286	Economy	28000.00
0005434831081	5286	Economy	28000.00
0005434558156	5286	Economy	28000.00
0005434821781	5286	Economy	28000.00
0005434821746	5286	Economy	28000.00
0005434821772	5286	Economy	28000.00
0005434821758	5286	Economy	28000.00
0005434821787	5286	Economy	28000.00
0005434821717	5286	Economy	28000.00
0005432121133	5286	Economy	28000.00
0005435149834	5286	Economy	28000.00
0005432121131	5286	Economy	28000.00
0005434821719	5286	Economy	28000.00
0005434831078	5286	Economy	28000.00
0005434821828	5286	Economy	28000.00
0005434821827	5286	Economy	28000.00
0005434821740	5286	Economy	28000.00
0005434821796	5286	Economy	28000.00
0005434821730	5286	Economy	28000.00
0005434821816	5286	Economy	28000.00
0005434821722	5286	Economy	28000.00
0005435149835	5286	Economy	28000.00
0005434664925	5286	Economy	28000.00
0005434821765	5286	Economy	28000.00
0005434821805	5286	Economy	28000.00
0005434821752	5286	Economy	28000.00
0005434821810	5286	Economy	28000.00
0005435149839	5286	Economy	28000.00
0005434821770	5286	Economy	28000.00
0005435735074	9929	Business	84000.00
0005435735070	9929	Business	84000.00
0005435372344	9929	Business	84000.00
0005435372298	9929	Business	84000.00
0005435386476	9929	Business	84000.00
0005435735073	9929	Business	84000.00
0005435372354	9929	Business	84000.00
0005435372345	9929	Comfort	47600.00
0005435386479	9929	Comfort	47600.00
0005435386475	9929	Comfort	47600.00
0005435372300	9929	Comfort	47600.00
0005435372333	9929	Comfort	47600.00
0005435372324	9929	Comfort	47600.00
0005435372327	9929	Comfort	47600.00
0005435372330	9929	Comfort	47600.00
0005435386480	9929	Economy	28000.00
0005435372336	9929	Economy	28000.00
0005435372309	9929	Economy	28000.00
0005435372359	9929	Economy	28000.00
0005435372355	9929	Economy	28000.00
0005435372329	9929	Economy	28000.00
0005435372341	9929	Economy	28000.00
0005435372358	9929	Economy	28000.00
0005435372337	9929	Economy	28000.00
0005435372296	9929	Economy	28000.00
0005435302130	9929	Economy	28000.00
0005435372319	9929	Economy	28000.00
0005435302131	9929	Economy	28000.00
0005435372304	9929	Economy	28000.00
0005435372360	9929	Economy	30800.00
0005435386477	9929	Economy	28000.00
0005435372356	9929	Economy	28000.00
0005435372348	9929	Economy	28000.00
0005432823423	9929	Economy	28000.00
0005432202958	9929	Economy	28000.00
0005435372299	9929	Economy	28000.00
0005435372328	9929	Economy	28000.00
0005435372318	9929	Economy	28000.00
0005435372347	9929	Economy	28000.00
0005432202962	9929	Economy	28000.00
0005435372294	9929	Economy	28000.00
0005435372315	9929	Economy	28000.00
0005435372308	9929	Economy	28000.00
0005435372340	9929	Economy	28000.00
0005435372310	9929	Economy	28000.00
0005435372331	9929	Economy	28000.00
0005435372313	9929	Economy	28000.00
0005435386473	9929	Economy	28000.00
0005435372334	9929	Economy	28000.00
0005432202959	9929	Economy	28000.00
0005435299709	9929	Economy	28000.00
0005435299707	9929	Economy	28000.00
0005435372349	9929	Economy	28000.00
0005435735071	9929	Economy	28000.00
0005435372312	9929	Economy	28000.00
0005435372295	9929	Economy	28000.00
0005435372338	9929	Economy	28000.00
0005432202960	9929	Economy	28000.00
0005435372352	9929	Economy	28000.00
0005432202961	9929	Economy	28000.00
0005435372332	9929	Economy	28000.00
0005435372316	9929	Economy	28000.00
0005435372323	9929	Economy	28000.00
0005435372305	9929	Economy	28000.00
0005435372346	9929	Economy	28000.00
0005435372335	9929	Economy	30800.00
0005432202957	9929	Economy	30800.00
0005435372351	9929	Economy	28000.00
0005435372357	9929	Economy	28000.00
0005435386478	9929	Economy	28000.00
0005435302133	9929	Economy	28000.00
0005435372322	9929	Economy	28000.00
0005434821415	9929	Economy	28000.00
0005435302132	9929	Economy	28000.00
0005435372297	9929	Economy	28000.00
0005435372314	9929	Economy	28000.00
0005435372303	9929	Economy	28000.00
0005435372311	9929	Economy	28000.00
0005435372307	9929	Economy	28000.00
0005435372302	9929	Economy	28000.00
0005435372321	9929	Economy	28000.00
0005435372293	9929	Economy	28000.00
0005435372353	9929	Economy	28000.00
0005435372326	9929	Economy	28000.00
0005435372343	9929	Economy	28000.00
0005435299708	9929	Economy	28000.00
0005435372317	9929	Economy	28000.00
0005435372342	9929	Economy	28000.00
0005435372301	9929	Economy	28000.00
0005435299706	9929	Economy	28000.00
0005432823422	9929	Economy	28000.00
0005435735072	9929	Economy	28000.00
0005435372350	9929	Economy	28000.00
0005435372320	9929	Economy	28000.00
0005435661890	9929	Economy	28000.00
0005435299705	9929	Economy	28000.00
0005435386474	9929	Economy	28000.00
0005435372325	9929	Economy	28000.00
0005435372339	9929	Economy	28000.00
0005435372306	9929	Economy	28000.00
0005435082674	7014	Economy	8200.00
0005435082671	7014	Economy	7400.00
0005435082673	7014	Economy	7400.00
0005435082672	7014	Economy	7400.00
0005435790265	7014	Economy	7400.00
0005435082670	7014	Economy	7400.00
0005435082676	7014	Economy	7400.00
0005435082675	7014	Economy	7400.00
0005435790264	7014	Economy	7400.00
0005435082677	7014	Economy	7400.00
0005434755845	9563	Business	32800.00
0005434755824	9563	Business	32800.00
0005434755865	9563	Business	32800.00
0005434755844	9563	Business	32800.00
0005434755830	9563	Business	32800.00
0005434755855	9563	Business	32800.00
0005434755857	9563	Economy	10900.00
0005434755869	9563	Economy	10900.00
0005434755851	9563	Economy	10900.00
0005434755862	9563	Economy	10900.00
0005434755849	9563	Economy	10900.00
0005434755836	9563	Economy	10900.00
0005434755864	9563	Economy	12000.00
0005434755868	9563	Economy	12000.00
0005434755867	9563	Economy	10900.00
0005434755861	9563	Economy	10900.00
0005434755853	9563	Economy	10900.00
0005434755856	9563	Economy	10900.00
0005434755841	9563	Economy	10900.00
0005434755852	9563	Economy	10900.00
0005434755854	9563	Economy	10900.00
0005434755827	9563	Economy	10900.00
0005434755834	9563	Economy	10900.00
0005434755831	9563	Economy	10900.00
0005434755866	9563	Economy	10900.00
0005434755835	9563	Economy	10900.00
0005434755850	9563	Economy	10900.00
0005434755826	9563	Economy	10900.00
0005434755837	9563	Economy	10900.00
0005434755825	9563	Economy	10900.00
0005434755860	9563	Economy	10900.00
0005434755828	9563	Economy	10900.00
0005434755838	9563	Economy	10900.00
0005434755843	9563	Economy	10900.00
0005434755832	9563	Economy	10900.00
0005434755840	9563	Economy	10900.00
0005434755847	9563	Economy	10900.00
0005434755863	9563	Economy	10900.00
0005434755858	9563	Economy	10900.00
0005434755846	9563	Economy	10900.00
0005434755870	9563	Economy	10900.00
0005434755859	9563	Economy	10900.00
0005434755829	9563	Economy	10900.00
0005434755842	9563	Economy	10900.00
0005434755839	9563	Economy	10900.00
0005434755833	9563	Economy	10900.00
0005434755848	9563	Economy	10900.00
0005434213798	28612	Business	32800.00
0005434213805	28612	Business	32800.00
0005434213801	28612	Business	32800.00
0005434213809	28612	Business	32800.00
0005434213833	28612	Business	32800.00
0005434213835	28612	Business	32800.00
0005434213810	28612	Business	32800.00
0005434213807	28612	Economy	10900.00
0005434213797	28612	Economy	10900.00
0005434213832	28612	Economy	10900.00
0005434213837	28612	Economy	10900.00
0005434213795	28612	Economy	10900.00
0005434213840	28612	Economy	10900.00
0005434213827	28612	Economy	10900.00
0005434213802	28612	Economy	10900.00
0005434213816	28612	Economy	12000.00
0005434213824	28612	Economy	12000.00
0005434213817	28612	Economy	10900.00
0005434213829	28612	Economy	10900.00
0005434213839	28612	Economy	10900.00
0005434213823	28612	Economy	10900.00
0005434213808	28612	Economy	10900.00
0005434213815	28612	Economy	10900.00
0005434213831	28612	Economy	10900.00
0005434213814	28612	Economy	10900.00
0005434213803	28612	Economy	10900.00
0005434213820	28612	Economy	10900.00
0005434213819	28612	Economy	10900.00
0005434213821	28612	Economy	10900.00
0005434213800	28612	Economy	10900.00
0005434213818	28612	Economy	10900.00
0005434213830	28612	Economy	10900.00
0005434213828	28612	Economy	10900.00
0005434213838	28612	Economy	10900.00
0005434213806	28612	Economy	10900.00
0005434213804	28612	Economy	10900.00
0005434213796	28612	Economy	10900.00
0005434213836	28612	Economy	10900.00
0005434213834	28612	Economy	10900.00
0005434213822	28612	Economy	10900.00
0005434213813	28612	Economy	10900.00
0005434213811	28612	Economy	10900.00
0005434213825	28612	Economy	10900.00
0005434213794	28612	Economy	10900.00
0005434213799	28612	Economy	10900.00
0005434213826	28612	Economy	10900.00
0005434213812	28612	Economy	10900.00
0005435100079	10828	Economy	8900.00
0005435100080	10828	Economy	8900.00
0005435100078	10828	Economy	8900.00
0005434760161	31809	Economy	9800.00
0005434760162	31809	Economy	8900.00
0005434638938	1965	Economy	20900.00
0005434638944	1965	Economy	20900.00
0005434638933	1965	Economy	20900.00
0005434638939	1965	Economy	19000.00
0005434638942	1965	Economy	19000.00
0005435948308	1965	Economy	19000.00
0005434638941	1965	Economy	19000.00
0005435948310	1965	Economy	19000.00
0005434638929	1965	Economy	19000.00
0005434638952	1965	Economy	19000.00
0005434638935	1965	Economy	19000.00
0005434638936	1965	Economy	19000.00
0005432290589	1965	Economy	19000.00
0005435948309	1965	Economy	19000.00
0005434638937	1965	Economy	19000.00
0005434638953	1965	Economy	19000.00
0005434638947	1965	Economy	19000.00
0005434638943	1965	Economy	19000.00
0005434638934	1965	Economy	19000.00
0005434638945	1965	Economy	19000.00
0005434638954	1965	Economy	19000.00
0005434638931	1965	Economy	19000.00
0005434638928	1965	Economy	19000.00
0005432290590	1965	Economy	19000.00
0005434638949	1965	Economy	19000.00
0005434638948	1965	Economy	19000.00
0005434638946	1965	Economy	19000.00
0005432290588	1965	Economy	19000.00
0005434638950	1965	Economy	19000.00
0005434638951	1965	Economy	19000.00
0005434638940	1965	Economy	19000.00
0005434638932	1965	Economy	19000.00
0005434638955	1965	Economy	19000.00
0005434638930	1965	Economy	19000.00
0005433202134	23256	Economy	20900.00
0005433202135	23256	Economy	20900.00
0005433202133	23256	Economy	19000.00
0005433202145	23256	Economy	19000.00
0005433202143	23256	Economy	19000.00
0005433202142	23256	Economy	19000.00
0005433202140	23256	Economy	19000.00
0005433202141	23256	Economy	19000.00
0005433202139	23256	Economy	19000.00
0005433202144	23256	Economy	19000.00
0005433202138	23256	Economy	19000.00
0005433202146	23256	Economy	19000.00
0005433202136	23256	Economy	19000.00
0005433202137	23256	Economy	19000.00
0005434600411	6040	Business	69700.00
0005434600410	6040	Business	69700.00
0005432111234	6040	Business	69700.00
0005434600424	6040	Business	69700.00
0005434600428	6040	Business	69700.00
0005432111236	6040	Economy	23200.00
0005434600429	6040	Economy	23200.00
0005434600433	6040	Economy	25600.00
0005433531238	6040	Economy	25600.00
0005434600430	6040	Economy	25600.00
0005434600423	6040	Economy	23200.00
0005434600427	6040	Economy	23200.00
0005433533253	6040	Economy	23200.00
0005433531237	6040	Economy	23200.00
0005434600425	6040	Economy	23200.00
0005434600418	6040	Economy	23200.00
0005433531240	6040	Economy	23200.00
0005434600422	6040	Economy	23200.00
0005434600415	6040	Economy	23200.00
0005432111235	6040	Economy	23200.00
0005434600414	6040	Economy	23200.00
0005433533254	6040	Economy	23200.00
0005434600417	6040	Economy	23200.00
0005434600412	6040	Economy	23200.00
0005433533255	6040	Economy	23200.00
0005433533256	6040	Economy	23200.00
0005434600420	6040	Economy	23200.00
0005434600419	6040	Economy	23200.00
0005434600426	6040	Economy	23200.00
0005434600413	6040	Economy	23200.00
0005433531239	6040	Economy	23200.00
0005434600432	6040	Economy	23200.00
0005434600421	6040	Economy	23200.00
0005434600434	6040	Economy	23200.00
0005434600416	6040	Economy	23200.00
0005434600431	6040	Economy	23200.00
0005434600436	6040	Economy	23200.00
0005434600435	6040	Economy	23200.00
0005435326553	18579	Business	69700.00
0005435326547	18579	Business	69700.00
0005435326551	18579	Economy	23200.00
0005435326549	18579	Economy	23200.00
0005435326543	18579	Economy	23200.00
0005435326548	18579	Economy	23200.00
0005435326539	18579	Economy	23200.00
0005435326542	18579	Economy	23200.00
0005435326544	18579	Economy	23200.00
0005435326540	18579	Economy	23200.00
0005435326552	18579	Economy	23200.00
0005435326546	18579	Economy	23200.00
0005435326541	18579	Economy	23200.00
0005435326550	18579	Economy	23200.00
0005435326545	18579	Economy	23200.00
0005434550388	10640	Business	9100.00
0005434550394	10640	Business	9100.00
0005434550415	10640	Business	9100.00
0005434550400	10640	Business	9100.00
0005434550404	10640	Business	9100.00
0005434550420	10640	Business	9100.00
0005434550407	10640	Business	9100.00
0005434554030	10640	Business	9100.00
0005434550372	10640	Economy	3000.00
0005434554031	10640	Economy	3000.00
0005434550381	10640	Economy	3000.00
0005434550369	10640	Economy	3000.00
0005434550393	10640	Economy	3000.00
0005434550376	10640	Economy	3000.00
0005434550380	10640	Economy	3000.00
0005434550386	10640	Economy	3000.00
0005434550373	10640	Economy	3000.00
0005434550375	10640	Economy	3000.00
0005434550423	10640	Economy	3300.00
0005434550398	10640	Economy	3300.00
0005434550387	10640	Economy	3300.00
0005434550410	10640	Economy	3300.00
0005434550418	10640	Economy	3000.00
0005434550411	10640	Economy	3000.00
0005434550370	10640	Economy	3000.00
0005434550396	10640	Economy	3000.00
0005434550378	10640	Economy	3000.00
0005434550374	10640	Economy	3000.00
0005434550402	10640	Economy	3000.00
0005434550403	10640	Economy	3000.00
0005434550408	10640	Economy	3000.00
0005434550379	10640	Economy	3000.00
0005434550382	10640	Economy	3000.00
0005434550424	10640	Economy	3000.00
0005434558154	10640	Economy	3000.00
0005434550377	10640	Economy	3000.00
0005434550417	10640	Economy	3000.00
0005434558151	10640	Economy	3000.00
0005434558150	10640	Economy	3000.00
0005434550416	10640	Economy	3000.00
0005434550392	10640	Economy	3000.00
0005434550390	10640	Economy	3000.00
0005434558152	10640	Economy	3000.00
0005434550422	10640	Economy	3000.00
0005434558153	10640	Economy	3000.00
0005434550385	10640	Economy	3000.00
0005434550389	10640	Economy	3000.00
0005434550397	10640	Economy	3000.00
0005434550405	10640	Economy	3000.00
0005434550406	10640	Economy	3000.00
0005434550384	10640	Economy	3000.00
0005434558149	10640	Economy	3000.00
0005434550414	10640	Economy	3000.00
0005434550409	10640	Economy	3000.00
0005434550399	10640	Economy	3000.00
0005434550383	10640	Economy	3000.00
0005434550421	10640	Economy	3000.00
0005434550395	10640	Economy	3000.00
0005434550412	10640	Economy	3000.00
0005434550413	10640	Economy	3000.00
0005434550371	10640	Economy	3000.00
0005434550401	10640	Economy	3000.00
0005434550391	10640	Economy	3000.00
0005434550419	10640	Economy	3000.00
0005433180734	27727	Business	9100.00
0005433180736	27727	Business	9100.00
0005433180730	27727	Economy	3000.00
0005433180749	27727	Economy	3000.00
0005433180738	27727	Economy	3000.00
0005433180726	27727	Economy	3000.00
0005433180739	27727	Economy	3000.00
0005433180735	27727	Economy	3000.00
0005433180744	27727	Economy	3000.00
0005433180727	27727	Economy	3000.00
0005433180745	27727	Economy	3000.00
0005433180728	27727	Economy	3000.00
0005433180750	27727	Economy	3000.00
0005433180737	27727	Economy	3000.00
0005433180729	27727	Economy	3000.00
0005433180743	27727	Economy	3000.00
0005433180748	27727	Economy	3000.00
0005433180740	27727	Economy	3000.00
0005433180742	27727	Economy	3000.00
0005433180733	27727	Economy	3000.00
0005433180746	27727	Economy	3000.00
0005433180731	27727	Economy	3000.00
0005433180732	27727	Economy	3000.00
0005433180741	27727	Economy	3000.00
0005433180747	27727	Economy	3000.00
0005434550291	27726	Economy	3000.00
0005434550290	27726	Economy	3000.00
0005433459157	6133	Economy	11700.00
0005433459158	6133	Economy	11700.00
0005433459156	6133	Economy	11700.00
0005433459159	6133	Economy	11700.00
0005435254437	19297	Economy	11700.00
0005435254439	19297	Economy	11700.00
0005435254438	19297	Economy	11700.00
0005435661887	6750	Business	51100.00
0005435681542	6750	Business	51100.00
0005435681513	6750	Business	51100.00
0005435681526	6750	Business	51100.00
0005432136095	6750	Business	51100.00
0005435661888	6750	Business	51100.00
0005435681548	6750	Business	51100.00
0005435681533	6750	Economy	17000.00
0005435661885	6750	Economy	17000.00
0005435681518	6750	Economy	17000.00
0005435681547	6750	Economy	17000.00
0005435681525	6750	Economy	17000.00
0005435720120	6750	Economy	17000.00
0005435681535	6750	Economy	18700.00
0005435681541	6750	Economy	18700.00
0005435630922	6750	Economy	17000.00
0005435681540	6750	Economy	17000.00
0005435681508	6750	Economy	17000.00
0005435681522	6750	Economy	17000.00
0005435681523	6750	Economy	17000.00
0005435681543	6750	Economy	17000.00
0005435681517	6750	Economy	17000.00
0005435681524	6750	Economy	17000.00
0005435681544	6750	Economy	17000.00
0005435681530	6750	Economy	17000.00
0005432136094	6750	Economy	17000.00
0005435681531	6750	Economy	17000.00
0005435681515	6750	Economy	17000.00
0005435681537	6750	Economy	17000.00
0005435681534	6750	Economy	17000.00
0005435681546	6750	Economy	17000.00
0005435630921	6750	Economy	17000.00
0005432136096	6750	Economy	17000.00
0005435681511	6750	Economy	17000.00
0005435681520	6750	Economy	17000.00
0005432136097	6750	Economy	17000.00
0005435681545	6750	Economy	17000.00
0005432136099	6750	Economy	17000.00
0005435681529	6750	Economy	17000.00
0005435681528	6750	Economy	17000.00
0005435681536	6750	Economy	17000.00
0005435681532	6750	Economy	17000.00
0005435681514	6750	Economy	17000.00
0005435681538	6750	Economy	17000.00
0005435661886	6750	Economy	17000.00
0005435681509	6750	Economy	17000.00
0005435681521	6750	Economy	17000.00
0005435681519	6750	Economy	17000.00
0005435681527	6750	Economy	17000.00
0005435720121	6750	Economy	17000.00
0005435661889	6750	Economy	17000.00
0005435681516	6750	Economy	17000.00
0005432136098	6750	Economy	17000.00
0005435681510	6750	Economy	17000.00
0005432136100	6750	Economy	17000.00
0005435630919	6750	Economy	17000.00
0005435681512	6750	Economy	17000.00
0005435681539	6750	Economy	17000.00
0005435719552	6750	Economy	17000.00
0005435630920	6750	Economy	17000.00
0005435219169	24609	Business	51100.00
0005435437621	24609	Business	51100.00
0005435437620	24609	Business	51100.00
0005435437639	24609	Business	51100.00
0005435220286	24609	Business	51100.00
0005435437623	24609	Economy	17000.00
0005435437630	24609	Economy	17000.00
0005432533250	24609	Economy	17000.00
0005432305713	24609	Economy	17000.00
0005434828656	24609	Economy	17000.00
0005435220289	24609	Economy	18700.00
0005435219166	24609	Economy	18700.00
0005435219167	24609	Economy	18700.00
0005434828657	24609	Economy	17000.00
0005435437638	24609	Economy	17000.00
0005435437629	24609	Economy	17000.00
0005435437640	24609	Economy	17000.00
0005435437634	24609	Economy	17000.00
0005435437636	24609	Economy	17000.00
0005435437632	24609	Economy	17000.00
0005435220288	24609	Economy	17000.00
0005435437633	24609	Economy	17000.00
0005435220488	24609	Economy	17000.00
0005435437625	24609	Economy	17000.00
0005435220287	24609	Economy	17000.00
0005435220285	24609	Economy	17000.00
0005432533249	24609	Economy	17000.00
0005435437622	24609	Economy	17000.00
0005435437631	24609	Economy	17000.00
0005434828658	24609	Economy	17000.00
0005432305712	24609	Economy	17000.00
0005435219168	24609	Economy	17000.00
0005435437637	24609	Economy	17000.00
0005432533251	24609	Economy	17000.00
0005435437628	24609	Economy	17000.00
0005435437641	24609	Economy	17000.00
0005435437642	24609	Economy	17000.00
0005435437624	24609	Economy	17000.00
0005435220290	24609	Economy	17000.00
0005435437626	24609	Economy	17000.00
0005435219170	24609	Economy	17000.00
0005435437635	24609	Economy	17000.00
0005435437627	24609	Economy	17000.00
0005435125733	11543	Business	26400.00
0005435125759	11543	Business	26400.00
0005435125758	11543	Business	26400.00
0005435125750	11543	Business	26400.00
0005435125731	11543	Business	26400.00
0005435125756	11543	Business	26400.00
0005435125769	11543	Economy	8800.00
0005435125765	11543	Economy	8800.00
0005435125734	11543	Economy	8800.00
0005435105933	11543	Economy	9700.00
0005435125745	11543	Economy	9700.00
0005435125738	11543	Economy	9700.00
0005435125749	11543	Economy	9700.00
0005435125763	11543	Economy	8800.00
0005435125743	11543	Economy	8800.00
0005435125762	11543	Economy	8800.00
0005435125737	11543	Economy	8800.00
0005435125736	11543	Economy	8800.00
0005435125768	11543	Economy	8800.00
0005435105932	11543	Economy	8800.00
0005435125732	11543	Economy	8800.00
0005435125764	11543	Economy	8800.00
0005435125767	11543	Economy	8800.00
0005435125730	11543	Economy	8800.00
0005435125746	11543	Economy	8800.00
0005435125748	11543	Economy	8800.00
0005435125747	11543	Economy	8800.00
0005435125766	11543	Economy	8800.00
0005435105934	11543	Economy	8800.00
0005435125751	11543	Economy	8800.00
0005435125760	11543	Economy	8800.00
0005435125741	11543	Economy	8800.00
0005435125753	11543	Economy	8800.00
0005435125742	11543	Economy	8800.00
0005435125739	11543	Economy	8800.00
0005435125771	11543	Economy	8800.00
0005435125770	11543	Economy	8800.00
0005435125754	11543	Economy	8800.00
0005435125757	11543	Economy	8800.00
0005435105935	11543	Economy	8800.00
0005435105936	11543	Economy	8800.00
0005435125761	11543	Economy	8800.00
0005435125744	11543	Economy	8800.00
0005435125735	11543	Economy	8800.00
0005435125755	11543	Economy	8800.00
0005435125752	11543	Economy	8800.00
0005435125740	11543	Economy	8800.00
0005435558049	31880	Business	26400.00
0005435105929	31880	Economy	8800.00
0005435558048	31880	Economy	8800.00
0005435558050	31880	Economy	8800.00
0005435105928	31880	Economy	8800.00
0005433397344	13505	Business	36600.00
0005433397338	13505	Business	36600.00
0005433397365	13505	Business	36600.00
0005433397369	13505	Business	36600.00
0005433397328	13505	Business	36600.00
0005433397342	13505	Business	36600.00
0005433397345	13505	Business	36600.00
0005433397331	13505	Business	36600.00
0005433397378	13505	Economy	12200.00
0005433397355	13505	Economy	12200.00
0005433397332	13505	Economy	13400.00
0005433397362	13505	Economy	13400.00
0005433397353	13505	Economy	13400.00
0005433397366	13505	Economy	12200.00
0005433397347	13505	Economy	12200.00
0005433397370	13505	Economy	12200.00
0005433397364	13505	Economy	12200.00
0005433397343	13505	Economy	12200.00
0005433397358	13505	Economy	12200.00
0005433397357	13505	Economy	12200.00
0005433397333	13505	Economy	12200.00
0005433397363	13505	Economy	12200.00
0005433397371	13505	Economy	12200.00
0005433397341	13505	Economy	12200.00
0005433397354	13505	Economy	12200.00
0005433397352	13505	Economy	12200.00
0005433397336	13505	Economy	12200.00
0005433397340	13505	Economy	12200.00
0005433397376	13505	Economy	12200.00
0005433397367	13505	Economy	12200.00
0005433397330	13505	Economy	12200.00
0005433397346	13505	Economy	12200.00
0005433397348	13505	Economy	12200.00
0005433397368	13505	Economy	12200.00
0005433397375	13505	Economy	12200.00
0005433397349	13505	Economy	12200.00
0005433397360	13505	Economy	12200.00
0005433397377	13505	Economy	12200.00
0005433397373	13505	Economy	12200.00
0005433397356	13505	Economy	12200.00
0005433397337	13505	Economy	12200.00
0005433397350	13505	Economy	12200.00
0005433397359	13505	Economy	12200.00
0005433397372	13505	Economy	12200.00
0005433397339	13505	Economy	12200.00
0005433397334	13505	Economy	12200.00
0005433397374	13505	Economy	12200.00
0005433397335	13505	Economy	12200.00
0005433397361	13505	Economy	12200.00
0005433397351	13505	Economy	12200.00
0005433397329	13505	Economy	12200.00
0005432297240	19393	Business	36600.00
0005432297238	19393	Economy	12200.00
0005435732156	19393	Economy	13400.00
0005435732152	19393	Economy	13400.00
0005435732154	19393	Economy	12200.00
0005435732159	19393	Economy	12200.00
0005435732155	19393	Economy	12200.00
0005435732158	19393	Economy	12200.00
0005435732157	19393	Economy	12200.00
0005435732161	19393	Economy	12200.00
0005435732160	19393	Economy	12200.00
0005432297239	19393	Economy	12200.00
0005435732153	19393	Economy	12200.00
0005435068283	15515	Business	11300.00
0005435068282	15515	Business	11300.00
0005435068296	15515	Business	11300.00
0005435068288	15515	Business	11300.00
0005435068280	15515	Business	11300.00
0005435068317	15515	Economy	3800.00
0005435068308	15515	Economy	3800.00
0005435068309	15515	Economy	3800.00
0005435068311	15515	Economy	3800.00
0005435068273	15515	Economy	4100.00
0005435068284	15515	Economy	4100.00
0005435068276	15515	Economy	3800.00
0005435068285	15515	Economy	3800.00
0005435068305	15515	Economy	3800.00
0005435068270	15515	Economy	3800.00
0005435068295	15515	Economy	3800.00
0005435068268	15515	Economy	3800.00
0005435068287	15515	Economy	3800.00
0005435068293	15515	Economy	3800.00
0005435068315	15515	Economy	3800.00
0005435068290	15515	Economy	3800.00
0005435068306	15515	Economy	3800.00
0005435068297	15515	Economy	3800.00
0005435068286	15515	Economy	3800.00
0005435068264	15515	Economy	3800.00
0005435068300	15515	Economy	3800.00
0005435068304	15515	Economy	3800.00
0005435068310	15515	Economy	3800.00
0005435068279	15515	Economy	3800.00
0005435068275	15515	Economy	3800.00
0005435068294	15515	Economy	3800.00
0005435068274	15515	Economy	3800.00
0005435068272	15515	Economy	3800.00
0005435068316	15515	Economy	3800.00
0005435068298	15515	Economy	3800.00
0005435068271	15515	Economy	3800.00
0005435068269	15515	Economy	3800.00
0005435068313	15515	Economy	3800.00
0005435068314	15515	Economy	3800.00
0005435068312	15515	Economy	3800.00
0005435068281	15515	Economy	3800.00
0005435068266	15515	Economy	3800.00
0005435068303	15515	Economy	3800.00
0005435068265	15515	Economy	3800.00
0005435068277	15515	Economy	3800.00
0005435068289	15515	Economy	3800.00
0005435068292	15515	Economy	3800.00
0005435068299	15515	Economy	3800.00
0005435068301	15515	Economy	3800.00
0005435068307	15515	Economy	3800.00
0005435068291	15515	Economy	3800.00
0005435068267	15515	Economy	3800.00
0005435068278	15515	Economy	3800.00
0005435068302	15515	Economy	3800.00
0005435808068	23192	Economy	27100.00
0005435808067	23192	Economy	27100.00
0005435808078	23192	Economy	24700.00
0005435808076	23192	Economy	24700.00
0005435808073	23192	Economy	24700.00
0005435808074	23192	Economy	24700.00
0005435808077	23192	Economy	24700.00
0005435808080	23192	Economy	24700.00
0005435808063	23192	Economy	24700.00
0005435808066	23192	Economy	24700.00
0005435808075	23192	Economy	24700.00
0005435808071	23192	Economy	24700.00
0005435808060	23192	Economy	24700.00
0005435808065	23192	Economy	24700.00
0005435808062	23192	Economy	24700.00
0005435808072	23192	Economy	24700.00
0005435808061	23192	Economy	24700.00
0005435808069	23192	Economy	24700.00
0005435808064	23192	Economy	24700.00
0005435808079	23192	Economy	24700.00
0005435808070	23192	Economy	24700.00
0005434213851	10735	Business	61300.00
0005434213852	10735	Business	61300.00
0005434213866	10735	Business	61300.00
0005434213876	10735	Business	61300.00
0005434213870	10735	Economy	20400.00
0005434213874	10735	Economy	20400.00
0005434213862	10735	Economy	20400.00
0005434213863	10735	Economy	20400.00
0005434213883	10735	Economy	20400.00
0005434213855	10735	Economy	20400.00
0005434213871	10735	Economy	22500.00
0005434213861	10735	Economy	22500.00
0005434213882	10735	Economy	22500.00
0005434213850	10735	Economy	20400.00
0005434213860	10735	Economy	20400.00
0005434213864	10735	Economy	20400.00
0005434213867	10735	Economy	20400.00
0005434213842	10735	Economy	20400.00
0005434213848	10735	Economy	20400.00
0005434213859	10735	Economy	20400.00
0005434213875	10735	Economy	20400.00
0005434213880	10735	Economy	20400.00
0005434213879	10735	Economy	20400.00
0005434213878	10735	Economy	20400.00
0005434213853	10735	Economy	20400.00
0005434213877	10735	Economy	20400.00
0005434213888	10735	Economy	20400.00
0005434213843	10735	Economy	20400.00
0005434213854	10735	Economy	20400.00
0005434213856	10735	Economy	20400.00
0005434213869	10735	Economy	20400.00
0005434213886	10735	Economy	20400.00
0005434213885	10735	Economy	20400.00
0005434213841	10735	Economy	20400.00
0005434213857	10735	Economy	20400.00
0005434213845	10735	Economy	20400.00
0005434213846	10735	Economy	20400.00
0005434213858	10735	Economy	20400.00
0005434213849	10735	Economy	20400.00
0005434213881	10735	Economy	20400.00
0005434213868	10735	Economy	20400.00
0005434213873	10735	Economy	20400.00
0005434213847	10735	Economy	20400.00
0005434213844	10735	Economy	20400.00
0005434213872	10735	Economy	20400.00
0005434213865	10735	Economy	20400.00
0005434213887	10735	Economy	20400.00
0005434213884	10735	Economy	20400.00
0005434755803	28690	Business	61300.00
0005434755798	28690	Business	61300.00
0005434755813	28690	Economy	20400.00
0005434755801	28690	Economy	20400.00
0005434755800	28690	Economy	20400.00
0005434755820	28690	Economy	20400.00
0005434755784	28690	Economy	22500.00
0005434755793	28690	Economy	22500.00
0005434755789	28690	Economy	22500.00
0005434755786	28690	Economy	22500.00
0005434755817	28690	Economy	20400.00
0005434755805	28690	Economy	20400.00
0005434755808	28690	Economy	20400.00
0005434755802	28690	Economy	20400.00
0005434755791	28690	Economy	20400.00
0005434755806	28690	Economy	20400.00
0005434755818	28690	Economy	20400.00
0005434755823	28690	Economy	20400.00
0005434755812	28690	Economy	20400.00
0005434755794	28690	Economy	20400.00
0005434755796	28690	Economy	20400.00
0005434755821	28690	Economy	20400.00
0005434755816	28690	Economy	20400.00
0005434755782	28690	Economy	20400.00
0005434755822	28690	Economy	20400.00
0005434755785	28690	Economy	20400.00
0005434755783	28690	Economy	20400.00
0005434755795	28690	Economy	20400.00
0005434755815	28690	Economy	20400.00
0005434755819	28690	Economy	20400.00
0005434755804	28690	Economy	20400.00
0005434755792	28690	Economy	20400.00
0005434755814	28690	Economy	20400.00
0005434755811	28690	Economy	20400.00
0005434755797	28690	Economy	20400.00
0005434755809	28690	Economy	20400.00
0005434755807	28690	Economy	20400.00
0005434755790	28690	Economy	20400.00
0005434755788	28690	Economy	20400.00
0005434755799	28690	Economy	20400.00
0005434755810	28690	Economy	20400.00
0005434755787	28690	Economy	20400.00
0005432125345	5435	Business	29500.00
0005435038824	5435	Business	29500.00
0005435038811	5435	Business	29500.00
0005435038839	5435	Business	29500.00
0005432125342	5435	Business	29500.00
0005435006673	5435	Business	29500.00
0005435038849	5435	Business	29500.00
0005435038859	5435	Business	29500.00
0005435038829	5435	Business	29500.00
0005435038867	5435	Economy	9800.00
0005435038808	5435	Economy	9800.00
0005435006685	5435	Economy	9800.00
0005435006697	5435	Economy	9800.00
0005435038843	5435	Economy	9800.00
0005435038825	5435	Economy	9800.00
0005435038818	5435	Economy	9800.00
0005435006682	5435	Economy	9800.00
0005435006684	5435	Economy	9800.00
0005435038846	5435	Economy	9800.00
0005435038863	5435	Economy	9800.00
0005435038827	5435	Economy	9800.00
0005435006674	5435	Economy	9800.00
0005435038865	5435	Economy	9800.00
0005435006691	5435	Economy	9800.00
0005435038837	5435	Economy	9800.00
0005435006676	5435	Economy	9800.00
0005435038864	5435	Economy	9800.00
0005435038822	5435	Economy	9800.00
0005435006677	5435	Economy	9800.00
0005435006690	5435	Economy	9800.00
0005435038830	5435	Economy	9800.00
0005435038813	5435	Economy	9800.00
0005435038840	5435	Economy	9800.00
0005435038853	5435	Economy	9800.00
0005435038852	5435	Economy	9800.00
0005435006696	5435	Economy	9800.00
0005435006681	5435	Economy	9800.00
0005435038857	5435	Economy	9800.00
0005435038854	5435	Economy	9800.00
0005435038845	5435	Economy	9800.00
0005435038870	5435	Economy	9800.00
0005435038847	5435	Economy	9800.00
0005435006679	5435	Economy	9800.00
0005435006692	5435	Economy	9800.00
0005435006672	5435	Economy	10800.00
0005435006687	5435	Economy	10800.00
0005435038817	5435	Economy	10800.00
0005435038821	5435	Economy	10800.00
0005435038819	5435	Economy	10800.00
0005435038834	5435	Economy	10800.00
0005435038815	5435	Economy	9800.00
0005435038823	5435	Economy	9800.00
0005435038835	5435	Economy	9800.00
0005432125348	5435	Economy	9800.00
0005435038812	5435	Economy	9800.00
0005435006688	5435	Economy	9800.00
0005432125347	5435	Economy	9800.00
0005435038861	5435	Economy	9800.00
0005435006680	5435	Economy	9800.00
0005435038805	5435	Economy	9800.00
0005432125344	5435	Economy	9800.00
0005435038832	5435	Economy	9800.00
0005435006689	5435	Economy	9800.00
0005435038869	5435	Economy	9800.00
0005435038855	5435	Economy	9800.00
0005435006683	5435	Economy	9800.00
0005435038868	5435	Economy	9800.00
0005435038814	5435	Economy	9800.00
0005435038842	5435	Economy	9800.00
0005435006693	5435	Economy	9800.00
0005435038828	5435	Economy	9800.00
0005435038858	5435	Economy	9800.00
0005435038838	5435	Economy	9800.00
0005435038856	5435	Economy	9800.00
0005435038831	5435	Economy	9800.00
0005435006695	5435	Economy	9800.00
0005435038810	5435	Economy	9800.00
0005435006694	5435	Economy	9800.00
0005435038850	5435	Economy	9800.00
0005435038826	5435	Economy	9800.00
0005435038866	5435	Economy	9800.00
0005435006686	5435	Economy	9800.00
0005432125343	5435	Economy	9800.00
0005435038844	5435	Economy	9800.00
0005432125341	5435	Economy	9800.00
0005435038809	5435	Economy	9800.00
0005432125346	5435	Economy	9800.00
0005435038807	5435	Economy	9800.00
0005435038806	5435	Economy	9800.00
0005435038833	5435	Economy	9800.00
0005435038841	5435	Economy	9800.00
0005435038816	5435	Economy	9800.00
0005435038836	5435	Economy	9800.00
0005435038848	5435	Economy	9800.00
0005435038862	5435	Economy	9800.00
0005435038851	5435	Economy	9800.00
0005435038860	5435	Economy	9800.00
0005435038820	5435	Economy	9800.00
0005435006678	5435	Economy	9800.00
0005435006675	5435	Economy	9800.00
0005434229056	12985	Business	29500.00
0005434229058	12985	Business	29500.00
0005434229054	12985	Economy	9800.00
0005434229041	12985	Economy	9800.00
0005434229055	12985	Economy	9800.00
0005434229049	12985	Economy	9800.00
0005434229038	12985	Economy	9800.00
0005432304343	12985	Economy	9800.00
0005434229052	12985	Economy	9800.00
0005434229040	12985	Economy	9800.00
0005434229036	12985	Economy	9800.00
0005434229050	12985	Economy	9800.00
0005434229044	12985	Economy	9800.00
0005434229051	12985	Economy	9800.00
0005434229048	12985	Economy	9800.00
0005434229047	12985	Economy	9800.00
0005434229039	12985	Economy	9800.00
0005434229057	12985	Economy	9800.00
0005434229053	12985	Economy	9800.00
0005432304340	12985	Economy	9800.00
0005432304342	12985	Economy	9800.00
0005434229043	12985	Economy	9800.00
0005432304341	12985	Economy	9800.00
0005434229046	12985	Economy	9800.00
0005434229035	12985	Economy	9800.00
0005434229037	12985	Economy	9800.00
0005435377900	12985	Economy	9800.00
0005434229045	12985	Economy	9800.00
0005434229042	12985	Economy	9800.00
0005434426172	14901	Business	52900.00
0005434411711	14901	Business	52900.00
0005434426173	14901	Business	52900.00
0005434426159	14901	Business	52900.00
0005434426163	14901	Economy	17600.00
0005434426157	14901	Economy	17600.00
0005434426154	14901	Economy	19400.00
0005434426161	14901	Economy	19400.00
0005434426169	14901	Economy	17600.00
0005434426167	14901	Economy	17600.00
0005434426156	14901	Economy	17600.00
0005434426158	14901	Economy	17600.00
0005434426170	14901	Economy	17600.00
0005434426146	14901	Economy	17600.00
0005434426151	14901	Economy	17600.00
0005434426148	14901	Economy	17600.00
0005434411712	14901	Economy	17600.00
0005434411710	14901	Economy	17600.00
0005434426147	14901	Economy	17600.00
0005434426160	14901	Economy	17600.00
0005434426150	14901	Economy	17600.00
0005434426155	14901	Economy	17600.00
0005432188557	14901	Economy	17600.00
0005434426165	14901	Economy	17600.00
0005434426149	14901	Economy	17600.00
0005434426153	14901	Economy	17600.00
0005432188558	14901	Economy	17600.00
0005434426171	14901	Economy	17600.00
0005434426162	14901	Economy	17600.00
0005434426152	14901	Economy	17600.00
0005434426164	14901	Economy	17600.00
0005434411713	14901	Economy	17600.00
0005434411714	14901	Economy	17600.00
0005432188559	14901	Economy	17600.00
0005432188560	14901	Economy	17600.00
0005434426166	14901	Economy	17600.00
0005434426168	14901	Economy	17600.00
0005435902448	20188	Business	52900.00
0005435902455	20188	Business	52900.00
0005435902454	20188	Business	52900.00
0005435902452	20188	Economy	17600.00
0005435902447	20188	Economy	19400.00
0005435902456	20188	Economy	19400.00
0005435902451	20188	Economy	17600.00
0005435554119	20188	Economy	17600.00
0005435902446	20188	Economy	17600.00
0005435902453	20188	Economy	17600.00
0005435902440	20188	Economy	17600.00
0005435902438	20188	Economy	17600.00
0005435902443	20188	Economy	17600.00
0005435902449	20188	Economy	17600.00
0005435902445	20188	Economy	17600.00
0005435902442	20188	Economy	17600.00
0005435554118	20188	Economy	17600.00
0005435902444	20188	Economy	17600.00
0005435554122	20188	Economy	17600.00
0005435554121	20188	Economy	17600.00
0005432059476	20188	Economy	17600.00
0005435902441	20188	Economy	17600.00
0005435902439	20188	Economy	17600.00
0005435554120	20188	Economy	17600.00
0005435902450	20188	Economy	17600.00
0005434523738	30883	Business	106800.00
0005434523739	30883	Economy	35600.00
0005434523732	30883	Economy	35600.00
0005434523736	30883	Economy	35600.00
0005434523740	30883	Economy	35600.00
0005434523734	30883	Economy	39200.00
0005434523735	30883	Economy	35600.00
0005434523731	30883	Economy	35600.00
0005434523733	30883	Economy	35600.00
0005434523737	30883	Economy	35600.00
0005435981625	26540	Business	18500.00
0005435981634	26540	Business	18500.00
0005435981623	26540	Business	18500.00
0005432300176	26540	Business	18500.00
0005435981619	26540	Business	18500.00
0005435981644	26540	Business	18500.00
0005435981607	26540	Business	18500.00
0005435981631	26540	Economy	6200.00
0005435981617	26540	Economy	6200.00
0005435981614	26540	Economy	6200.00
0005435981594	26540	Economy	6200.00
0005432300172	26540	Economy	6800.00
0005435981643	26540	Economy	6800.00
0005435981635	26540	Economy	6200.00
0005435981604	26540	Economy	6200.00
0005435981626	26540	Economy	6200.00
0005435981605	26540	Economy	6200.00
0005435981640	26540	Economy	6200.00
0005435981642	26540	Economy	6200.00
0005435981621	26540	Economy	6200.00
0005435981633	26540	Economy	6200.00
0005435981595	26540	Economy	6200.00
0005435981636	26540	Economy	6200.00
0005435981602	26540	Economy	6200.00
0005435981637	26540	Economy	6200.00
0005435981630	26540	Economy	6200.00
0005435981624	26540	Economy	6200.00
0005432300177	26540	Economy	6200.00
0005435981613	26540	Economy	6200.00
0005435981622	26540	Economy	6200.00
0005435981628	26540	Economy	6200.00
0005435981618	26540	Economy	6200.00
0005435981612	26540	Economy	6200.00
0005435981639	26540	Economy	6200.00
0005432300173	26540	Economy	6200.00
0005435981641	26540	Economy	6200.00
0005435981608	26540	Economy	6200.00
0005435981599	26540	Economy	6200.00
0005432300174	26540	Economy	6200.00
0005435981620	26540	Economy	6200.00
0005435981600	26540	Economy	6200.00
0005435981615	26540	Economy	6200.00
0005435981606	26540	Economy	6200.00
0005435981638	26540	Economy	6200.00
0005435981603	26540	Economy	6200.00
0005435981627	26540	Economy	6200.00
0005435981610	26540	Economy	6200.00
0005435981611	26540	Economy	6200.00
0005435981596	26540	Economy	6200.00
0005435981601	26540	Economy	6200.00
0005435981629	26540	Economy	6200.00
0005435981632	26540	Economy	6200.00
0005432300175	26540	Economy	6200.00
0005435981616	26540	Economy	6200.00
0005435981597	26540	Economy	6200.00
0005435981598	26540	Economy	6200.00
0005435981609	26540	Economy	6200.00
0005433434270	26696	Business	18500.00
0005433434281	26696	Business	18500.00
0005433434286	26696	Business	18500.00
0005433434287	26696	Business	18500.00
0005433434284	26696	Business	18500.00
0005433434282	26696	Economy	6200.00
0005433434288	26696	Economy	6200.00
0005433434293	26696	Economy	6200.00
0005433434272	26696	Economy	6200.00
0005434269075	26696	Economy	6200.00
0005433434294	26696	Economy	6800.00
0005433434268	26696	Economy	6800.00
0005433434275	26696	Economy	6200.00
0005433434280	26696	Economy	6200.00
0005433434289	26696	Economy	6200.00
0005433434278	26696	Economy	6200.00
0005433434276	26696	Economy	6200.00
0005433434267	26696	Economy	6200.00
0005433434266	26696	Economy	6200.00
0005433434279	26696	Economy	6200.00
0005433434285	26696	Economy	6200.00
0005433434290	26696	Economy	6200.00
0005433434271	26696	Economy	6200.00
0005432051083	26696	Economy	6200.00
0005433434269	26696	Economy	6200.00
0005433434291	26696	Economy	6200.00
0005433434283	26696	Economy	6200.00
0005433434274	26696	Economy	6200.00
0005432051085	26696	Economy	6200.00
0005434271281	26696	Economy	6200.00
0005434271283	26696	Economy	6200.00
0005433434292	26696	Economy	6200.00
0005432051084	26696	Economy	6200.00
0005433434273	26696	Economy	6200.00
0005434269074	26696	Economy	6200.00
0005434271282	26696	Economy	6200.00
0005434270177	26696	Economy	6200.00
0005433434277	26696	Economy	6200.00
0005432583676	3137	Economy	11100.00
0005432583667	3137	Economy	11100.00
0005432583680	3137	Economy	10100.00
0005432583662	3137	Economy	10100.00
0005432583681	3137	Economy	10100.00
0005432583673	3137	Economy	10100.00
0005432583665	3137	Economy	10100.00
0005432216232	3137	Economy	10100.00
0005432583670	3137	Economy	10100.00
0005432583679	3137	Economy	10100.00
0005432583666	3137	Economy	10100.00
0005432583669	3137	Economy	10100.00
0005432583661	3137	Economy	10100.00
0005432216231	3137	Economy	10100.00
0005432583668	3137	Economy	10100.00
0005432583685	3137	Economy	10100.00
0005432583675	3137	Economy	10100.00
0005432583672	3137	Economy	10100.00
0005432583683	3137	Economy	10100.00
0005432583677	3137	Economy	10100.00
0005432583682	3137	Economy	10100.00
0005432216233	3137	Economy	10100.00
0005432583674	3137	Economy	10100.00
0005432583671	3137	Economy	10100.00
0005432583663	3137	Economy	10100.00
0005432583678	3137	Economy	10100.00
0005432583664	3137	Economy	10100.00
0005432583684	3137	Economy	10100.00
0005432857887	31479	Economy	10100.00
0005432857893	31479	Economy	10100.00
0005432857892	31479	Economy	10100.00
0005432857891	31479	Economy	10100.00
0005432857896	31479	Economy	10100.00
0005432857889	31479	Economy	10100.00
0005432857897	31479	Economy	10100.00
0005432857895	31479	Economy	10100.00
0005432857894	31479	Economy	10100.00
0005432857898	31479	Economy	10100.00
0005432857890	31479	Economy	10100.00
0005432857888	31479	Economy	10100.00
0005434943218	870	Economy	7500.00
0005434943217	870	Economy	7500.00
0005434943219	870	Economy	7500.00
0005434943213	870	Economy	7500.00
0005434943220	870	Economy	7500.00
0005433255024	870	Economy	7500.00
0005433255025	870	Economy	7500.00
0005434943215	870	Economy	7500.00
0005434943214	870	Economy	7500.00
0005434943216	870	Economy	7500.00
0005434943221	870	Economy	7500.00
0005433255038	16196	Economy	7500.00
0005433255041	16196	Economy	7500.00
0005433255042	16196	Economy	7500.00
0005433255039	16196	Economy	7500.00
0005433255037	16196	Economy	7500.00
0005433255040	16196	Economy	7500.00
0005435858495	27608	Business	90500.00
0005435858487	27608	Business	90500.00
0005435858497	27608	Economy	30200.00
0005435858491	27608	Economy	30200.00
0005435858484	27608	Economy	33200.00
0005435858493	27608	Economy	30200.00
0005435858485	27608	Economy	30200.00
0005435858483	27608	Economy	30200.00
0005435858496	27608	Economy	30200.00
0005435858498	27608	Economy	30200.00
0005435858492	27608	Economy	30200.00
0005435858489	27608	Economy	30200.00
0005435858488	27608	Economy	30200.00
0005435858494	27608	Economy	30200.00
0005435858486	27608	Economy	30200.00
0005435858482	27608	Economy	30200.00
0005435858490	27608	Economy	30200.00
0005435858499	27608	Economy	30200.00
0005435652380	21758	Business	9800.00
0005435652366	21758	Business	9800.00
0005435652376	21758	Business	9800.00
0005435652342	21758	Business	9800.00
0005435652345	21758	Economy	3300.00
0005435652347	21758	Economy	3300.00
0005435652368	21758	Economy	3300.00
0005435652360	21758	Economy	3300.00
0005435652381	21758	Economy	3300.00
0005435652378	21758	Economy	3600.00
0005435652371	21758	Economy	3600.00
0005435652365	21758	Economy	3300.00
0005435652340	21758	Economy	3300.00
0005435652370	21758	Economy	3300.00
0005435652359	21758	Economy	3300.00
0005435652355	21758	Economy	3300.00
0005435652361	21758	Economy	3300.00
0005435652341	21758	Economy	3300.00
0005435652356	21758	Economy	3300.00
0005435652377	21758	Economy	3300.00
0005435652373	21758	Economy	3300.00
0005435652362	21758	Economy	3300.00
0005435652354	21758	Economy	3300.00
0005435652346	21758	Economy	3300.00
0005435652349	21758	Economy	3300.00
0005435652352	21758	Economy	3300.00
0005435652350	21758	Economy	3300.00
0005435652379	21758	Economy	3300.00
0005435652375	21758	Economy	3300.00
0005435652369	21758	Economy	3300.00
0005435652348	21758	Economy	3300.00
0005435652374	21758	Economy	3300.00
0005435652372	21758	Economy	3300.00
0005435652364	21758	Economy	3300.00
0005435652357	21758	Economy	3300.00
0005435652383	21758	Economy	3300.00
0005435652367	21758	Economy	3300.00
0005435652363	21758	Economy	3300.00
0005435652353	21758	Economy	3300.00
0005435652358	21758	Economy	3300.00
0005435652343	21758	Economy	3300.00
0005435652382	21758	Economy	3300.00
0005435652344	21758	Economy	3300.00
0005435652351	21758	Economy	3300.00
0005432657404	9374	Business	186200.00
0005433804868	9374	Business	186200.00
0005433804860	9374	Business	186200.00
0005433784435	9374	Business	186200.00
0005432657406	9374	Business	186200.00
0005433804889	9374	Business	186200.00
0005432657403	9374	Business	186200.00
0005433763000	9374	Business	186200.00
0005433762993	9374	Business	186200.00
0005433762990	9374	Business	186200.00
0005433804887	9374	Business	186200.00
0005432665245	9374	Business	186200.00
0005433762996	9374	Business	186200.00
0005433784409	9374	Business	186200.00
0005433763001	9374	Business	186200.00
0005433784438	9374	Business	186200.00
0005433784437	9374	Economy	68300.00
0005432657405	9374	Economy	62100.00
0005433784424	9374	Economy	62100.00
0005433784418	9374	Economy	62100.00
0005434170803	9374	Economy	62100.00
0005433804863	9374	Economy	62100.00
0005433784408	9374	Economy	62100.00
0005433784439	9374	Economy	62100.00
0005433784419	9374	Economy	62100.00
0005433804867	9374	Economy	62100.00
0005433762991	9374	Economy	62100.00
0005433804888	9374	Economy	62100.00
0005433804862	9374	Economy	62100.00
0005433784414	9374	Economy	62100.00
0005432665244	9374	Economy	62100.00
0005433804882	9374	Economy	62100.00
0005433804861	9374	Economy	62100.00
0005433784427	9374	Economy	62100.00
0005433784428	9374	Economy	62100.00
0005433804869	9374	Economy	62100.00
0005433784421	9374	Economy	62100.00
0005433804884	9374	Economy	62100.00
0005433804877	9374	Economy	62100.00
0005433784430	9374	Economy	62100.00
0005433762995	9374	Economy	62100.00
0005433804865	9374	Economy	62100.00
0005432667424	9374	Economy	62100.00
0005433804892	9374	Economy	62100.00
0005433784423	9374	Economy	62100.00
0005433804872	9374	Economy	62100.00
0005433784407	9374	Economy	62100.00
0005433784434	9374	Economy	62100.00
0005433784436	9374	Economy	62100.00
0005433804881	9374	Economy	62100.00
0005433804876	9374	Economy	62100.00
0005432667425	9374	Economy	62100.00
0005433804890	9374	Economy	62100.00
0005433762999	9374	Economy	62100.00
0005433784420	9374	Economy	62100.00
0005433784402	9374	Economy	62100.00
0005433804870	9374	Economy	62100.00
0005433784412	9374	Economy	68300.00
0005432667423	9374	Economy	62100.00
0005433784404	9374	Economy	62100.00
0005433804875	9374	Economy	62100.00
0005433784413	9374	Economy	68300.00
0005432657402	9374	Economy	62100.00
0005433804878	9374	Economy	68300.00
0005433762998	9374	Economy	62100.00
0005433784417	9374	Economy	62100.00
0005433784416	9374	Economy	62100.00
0005434170797	9374	Economy	62100.00
0005433784422	9374	Economy	62100.00
0005433784405	9374	Economy	62100.00
0005433784429	9374	Economy	62100.00
0005433804873	9374	Economy	62100.00
0005433804886	9374	Economy	62100.00
0005433784432	9374	Economy	62100.00
0005432666358	9374	Economy	62100.00
0005433784411	9374	Economy	62100.00
0005433804874	9374	Economy	62100.00
0005433804880	9374	Economy	62100.00
0005433784426	9374	Economy	62100.00
0005433762987	9374	Economy	62100.00
0005433784403	9374	Economy	62100.00
0005433762992	9374	Economy	62100.00
0005433784410	9374	Economy	62100.00
0005433762994	9374	Economy	62100.00
0005433804871	9374	Economy	62100.00
0005433804879	9374	Economy	62100.00
0005433784433	9374	Economy	62100.00
0005433784406	9374	Economy	62100.00
0005433762988	9374	Economy	62100.00
0005433784431	9374	Economy	62100.00
0005433804859	9374	Economy	62100.00
0005433784425	9374	Economy	62100.00
0005433784415	9374	Economy	62100.00
0005433804885	9374	Economy	62100.00
0005433804891	9374	Economy	62100.00
0005433804866	9374	Economy	62100.00
0005433784401	9374	Economy	62100.00
0005433804864	9374	Economy	62100.00
0005433804883	9374	Economy	62100.00
0005434170802	9374	Economy	62100.00
0005433762989	9374	Economy	62100.00
0005433762997	9374	Economy	62100.00
0005434151662	26229	Business	186200.00
0005434170843	26229	Business	186200.00
0005435269652	26229	Economy	62100.00
0005434170845	26229	Economy	62100.00
0005434151661	26229	Economy	62100.00
0005434269073	26229	Economy	62100.00
0005434270176	26229	Economy	62100.00
0005435269648	26229	Economy	62100.00
0005434170850	26229	Economy	62100.00
0005434170853	26229	Economy	62100.00
0005434170849	26229	Economy	62100.00
0005434170844	26229	Economy	62100.00
0005434170841	26229	Economy	62100.00
0005433784296	26229	Economy	62100.00
0005435269650	26229	Economy	62100.00
0005434269072	26229	Economy	62100.00
0005434170851	26229	Economy	62100.00
0005434170847	26229	Economy	62100.00
0005434170852	26229	Economy	62100.00
0005434269071	26229	Economy	62100.00
0005435269651	26229	Economy	62100.00
0005434269070	26229	Economy	62100.00
0005434170846	26229	Economy	62100.00
0005435269649	26229	Economy	62100.00
0005434170854	26229	Economy	62100.00
0005434151660	26229	Economy	62100.00
0005434170848	26229	Economy	62100.00
0005434270175	26229	Economy	62100.00
0005434270174	26229	Economy	62100.00
0005434170842	26229	Economy	62100.00
0005435135600	4906	Economy	5300.00
0005435135597	4906	Economy	5300.00
0005435135596	4906	Economy	5300.00
0005435135599	4906	Economy	5300.00
0005435135601	4906	Economy	5300.00
0005435135598	4906	Economy	5300.00
0005435929603	33047	Economy	5900.00
0005435929605	33047	Economy	5300.00
0005435929604	33047	Economy	5300.00
0005434983209	9473	Economy	17900.00
0005434983211	9473	Economy	17900.00
0005434983213	9473	Economy	17900.00
0005434983210	9473	Economy	17900.00
0005434983212	9473	Economy	17900.00
0005434983214	9473	Economy	17900.00
0005434217910	27378	Economy	17900.00
0005434217908	27378	Economy	17900.00
0005434217911	27378	Economy	17900.00
0005434217909	27378	Economy	17900.00
0005433960020	25934	Business	36400.00
0005433985224	25934	Business	36400.00
0005433985229	25934	Business	36400.00
0005433959980	25934	Business	36400.00
0005433960005	25934	Business	36400.00
0005433985253	25934	Business	36400.00
0005433959974	25934	Business	36400.00
0005433960027	25934	Business	36400.00
0005433960003	25934	Business	36400.00
0005433985219	25934	Business	36400.00
0005433960025	25934	Business	36400.00
0005433959989	25934	Business	36400.00
0005433959997	25934	Business	36400.00
0005433985249	25934	Business	36400.00
0005433960023	25934	Economy	13400.00
0005433985220	25934	Economy	13400.00
0005433959981	25934	Economy	13400.00
0005433959971	25934	Economy	12100.00
0005433985240	25934	Economy	12100.00
0005433959964	25934	Economy	12100.00
0005433985227	25934	Economy	12100.00
0005433959970	25934	Economy	12100.00
0005433960024	25934	Economy	12100.00
0005433960021	25934	Economy	12100.00
0005433960000	25934	Economy	12100.00
0005433985244	25934	Economy	12100.00
0005433959976	25934	Economy	12100.00
0005433959988	25934	Economy	12100.00
0005433985233	25934	Economy	12100.00
0005433960026	25934	Economy	12100.00
0005433959979	25934	Economy	12100.00
0005433985235	25934	Economy	12100.00
0005433985225	25934	Economy	12100.00
0005433959999	25934	Economy	12100.00
0005433959993	25934	Economy	12100.00
0005433959991	25934	Economy	12100.00
0005433959984	25934	Economy	12100.00
0005433985231	25934	Economy	12100.00
0005433985255	25934	Economy	12100.00
0005433985247	25934	Economy	12100.00
0005433959973	25934	Economy	12100.00
0005433985221	25934	Economy	12100.00
0005433960014	25934	Economy	12100.00
0005433960009	25934	Economy	12100.00
0005433985256	25934	Economy	12100.00
0005433985215	25934	Economy	12100.00
0005433959987	25934	Economy	12100.00
0005433985216	25934	Economy	12100.00
0005433985258	25934	Economy	12100.00
0005433985213	25934	Economy	12100.00
0005433985250	25934	Economy	12100.00
0005433960017	25934	Economy	12100.00
0005433959990	25934	Economy	12100.00
0005433985248	25934	Economy	12100.00
0005433959985	25934	Economy	12100.00
0005433985214	25934	Economy	12100.00
0005433959994	25934	Economy	12100.00
0005433959977	25934	Economy	12100.00
0005433960011	25934	Economy	12100.00
0005433959975	25934	Economy	12100.00
0005433985241	25934	Economy	12100.00
0005433985242	25934	Economy	12100.00
0005433959995	25934	Economy	12100.00
0005433985223	25934	Economy	12100.00
0005433960012	25934	Economy	12100.00
0005433985237	25934	Economy	12100.00
0005433959992	25934	Economy	12100.00
0005433959966	25934	Economy	12100.00
0005433985228	25934	Economy	12100.00
0005433959965	25934	Economy	13400.00
0005433985243	25934	Economy	13400.00
0005433960004	25934	Economy	12100.00
0005433960008	25934	Economy	12100.00
0005433959967	25934	Economy	12100.00
0005433959983	25934	Economy	12100.00
0005433985232	25934	Economy	12100.00
0005433985230	25934	Economy	12100.00
0005433960016	25934	Economy	12100.00
0005433959978	25934	Economy	12100.00
0005433960013	25934	Economy	12100.00
0005433985260	25934	Economy	12100.00
0005433985217	25934	Economy	12100.00
0005433959982	25934	Economy	12100.00
0005433960022	25934	Economy	12100.00
0005433985246	25934	Economy	12100.00
0005433985245	25934	Economy	12100.00
0005433985257	25934	Economy	12100.00
0005433985212	25934	Economy	12100.00
0005433985259	25934	Economy	12100.00
0005433960019	25934	Economy	12100.00
0005433959998	25934	Economy	12100.00
0005433985218	25934	Economy	12100.00
0005433985238	25934	Economy	12100.00
0005433959968	25934	Economy	12100.00
0005433960018	25934	Economy	12100.00
0005433960007	25934	Economy	12100.00
0005433960002	25934	Economy	12100.00
0005433985254	25934	Economy	12100.00
0005433960015	25934	Economy	12100.00
0005433985251	25934	Economy	12100.00
0005433959986	25934	Economy	12100.00
0005433959972	25934	Economy	12100.00
0005433960001	25934	Economy	12100.00
0005433985236	25934	Economy	12100.00
0005433985252	25934	Economy	12100.00
0005433985239	25934	Economy	12100.00
0005433959996	25934	Economy	12100.00
0005433959969	25934	Economy	12100.00
0005433985226	25934	Economy	12100.00
0005433985234	25934	Economy	12100.00
0005433960006	25934	Economy	12100.00
0005433960010	25934	Economy	12100.00
0005433985222	25934	Economy	12100.00
0005434479956	931	Economy	25400.00
0005434479954	931	Economy	25400.00
0005434479970	931	Economy	25400.00
0005434479976	931	Economy	23100.00
0005434479965	931	Economy	23100.00
0005434479952	931	Economy	23100.00
0005432269456	931	Economy	23100.00
0005434479977	931	Economy	23100.00
0005434479962	931	Economy	23100.00
0005434479973	931	Economy	23100.00
0005434479969	931	Economy	23100.00
0005434479960	931	Economy	23100.00
0005434479953	931	Economy	23100.00
0005434479975	931	Economy	23100.00
0005434479961	931	Economy	23100.00
0005434479967	931	Economy	23100.00
0005434479971	931	Economy	23100.00
0005434479966	931	Economy	23100.00
0005434479964	931	Economy	23100.00
0005434479959	931	Economy	23100.00
0005434479974	931	Economy	23100.00
0005434479955	931	Economy	23100.00
0005434479963	931	Economy	23100.00
0005432269455	931	Economy	23100.00
0005434479958	931	Economy	23100.00
0005434479972	931	Economy	23100.00
0005434479968	931	Economy	23100.00
0005434479957	931	Economy	23100.00
0005433165719	16549	Economy	25400.00
0005433165710	16549	Economy	23100.00
0005433165712	16549	Economy	23100.00
0005433165715	16549	Economy	23100.00
0005433165721	16549	Economy	23100.00
0005433165713	16549	Economy	23100.00
0005433165720	16549	Economy	23100.00
0005433165714	16549	Economy	23100.00
0005433165717	16549	Economy	23100.00
0005433165711	16549	Economy	23100.00
0005433165716	16549	Economy	23100.00
0005433165718	16549	Economy	23100.00
0005433165709	16549	Economy	23100.00
0005435386455	10342	Economy	17000.00
0005435142369	10342	Economy	17000.00
0005435142370	10342	Economy	15400.00
0005435149821	10342	Economy	15400.00
0005435149826	10342	Economy	15400.00
0005435142364	10342	Economy	15400.00
0005435142372	10342	Economy	15400.00
0005435142376	10342	Economy	15400.00
0005435142363	10342	Economy	15400.00
0005435149814	10342	Economy	15400.00
0005435142371	10342	Economy	15400.00
0005435149820	10342	Economy	15400.00
0005435149819	10342	Economy	15400.00
0005435142367	10342	Economy	15400.00
0005435142365	10342	Economy	15400.00
0005435149817	10342	Economy	15400.00
0005435149818	10342	Economy	15400.00
0005435142375	10342	Economy	15400.00
0005435149825	10342	Economy	15400.00
0005435142366	10342	Economy	15400.00
0005435142374	10342	Economy	15400.00
0005435149813	10342	Economy	15400.00
0005435149822	10342	Economy	15400.00
0005435149816	10342	Economy	15400.00
0005435142373	10342	Economy	15400.00
0005435142368	10342	Economy	15400.00
0005435149823	10342	Economy	15400.00
0005435149824	10342	Economy	15400.00
0005435149815	10342	Economy	15400.00
0005435386478	21949	Economy	17000.00
0005435386475	21949	Economy	17000.00
0005435386476	21949	Economy	15400.00
0005433289753	21949	Economy	15400.00
0005433289752	21949	Economy	15400.00
0005433289750	21949	Economy	15400.00
0005435386479	21949	Economy	15400.00
0005433289749	21949	Economy	15400.00
0005433289751	21949	Economy	15400.00
0005433289747	21949	Economy	15400.00
0005435386473	21949	Economy	15400.00
0005435386474	21949	Economy	15400.00
0005433289746	21949	Economy	15400.00
0005435386480	21949	Economy	15400.00
0005435386477	21949	Economy	15400.00
0005433289748	21949	Economy	15400.00
0005434573130	11186	Economy	19100.00
0005434573134	11186	Economy	19100.00
0005434573140	11186	Economy	19100.00
0005434573136	11186	Economy	19100.00
0005434573141	11186	Economy	19100.00
0005434573131	11186	Economy	19100.00
0005434573138	11186	Economy	19100.00
0005434573137	11186	Economy	19100.00
0005434573132	11186	Economy	19100.00
0005434573133	11186	Economy	19100.00
0005434573135	11186	Economy	19100.00
0005434573142	11186	Economy	19100.00
0005434573143	11186	Economy	19100.00
0005434573139	11186	Economy	19100.00
0005435517644	20921	Business	57200.00
0005435517638	20921	Business	57200.00
0005435501982	20921	Business	57200.00
0005435517637	20921	Business	57200.00
0005435501990	20921	Business	57200.00
0005435501988	20921	Business	57200.00
0005432291894	20921	Business	57200.00
0005435319455	20921	Business	57200.00
0005435501986	20921	Economy	19100.00
0005435501994	20921	Economy	19100.00
0005435508195	20921	Economy	19100.00
0005435508191	20921	Economy	19100.00
0005435517633	20921	Economy	19100.00
0005435517642	20921	Economy	19100.00
0005435501975	20921	Economy	21000.00
0005435501992	20921	Economy	19100.00
0005435517631	20921	Economy	19100.00
0005435517640	20921	Economy	19100.00
0005435501989	20921	Economy	19100.00
0005435517635	20921	Economy	19100.00
0005435508192	20921	Economy	19100.00
0005435508190	20921	Economy	19100.00
0005435508198	20921	Economy	19100.00
0005435508194	20921	Economy	19100.00
0005435517641	20921	Economy	19100.00
0005435501976	20921	Economy	19100.00
0005435501991	20921	Economy	19100.00
0005435319456	20921	Economy	19100.00
0005435517646	20921	Economy	19100.00
0005435517630	20921	Economy	19100.00
0005435319452	20921	Economy	19100.00
0005435319459	20921	Economy	19100.00
0005435517639	20921	Economy	19100.00
0005435508197	20921	Economy	19100.00
0005435517647	20921	Economy	19100.00
0005435508189	20921	Economy	19100.00
0005435517645	20921	Economy	19100.00
0005435517634	20921	Economy	19100.00
0005435501979	20921	Economy	19100.00
0005435501983	20921	Economy	19100.00
0005435501996	20921	Economy	19100.00
0005435517632	20921	Economy	19100.00
0005435508196	20921	Economy	19100.00
0005435319458	20921	Economy	19100.00
0005435508187	20921	Economy	19100.00
0005435319457	20921	Economy	19100.00
0005435508185	20921	Economy	19100.00
0005435501985	20921	Economy	19100.00
0005435508188	20921	Economy	19100.00
0005435501981	20921	Economy	19100.00
0005435501997	20921	Economy	19100.00
0005435508193	20921	Economy	19100.00
0005435508186	20921	Economy	19100.00
0005435501987	20921	Economy	19100.00
0005435319453	20921	Economy	19100.00
0005435517636	20921	Economy	19100.00
0005432291893	20921	Economy	19100.00
0005435501984	20921	Economy	19100.00
0005435319454	20921	Economy	19100.00
0005435517643	20921	Economy	19100.00
0005435319450	20921	Economy	19100.00
0005435501978	20921	Economy	19100.00
0005435501995	20921	Economy	19100.00
0005435501993	20921	Economy	19100.00
0005435319451	20921	Economy	19100.00
0005435517629	20921	Economy	19100.00
0005435501977	20921	Economy	19100.00
0005435501980	20921	Economy	19100.00
0005433683295	24303	Economy	18800.00
0005433683299	24303	Economy	17100.00
0005433683298	24303	Economy	17100.00
0005433683294	24303	Economy	17100.00
0005433683297	24303	Economy	17100.00
0005433683296	24303	Economy	17100.00
0005433683300	24303	Economy	17100.00
0005433927404	29287	Economy	17100.00
0005433927405	29287	Economy	17100.00
0005433927400	29287	Economy	17100.00
0005433927399	29287	Economy	17100.00
0005433927402	29287	Economy	17100.00
0005433927398	29287	Economy	17100.00
0005433927401	29287	Economy	17100.00
0005433927403	29287	Economy	17100.00
0005432217733	2918	Business	10300.00
0005432706408	2918	Business	10300.00
0005432706405	2918	Economy	3400.00
0005432706390	2918	Economy	3400.00
0005432706392	2918	Economy	3400.00
0005432706400	2918	Economy	3400.00
0005432706389	2918	Economy	3800.00
0005432217735	2918	Economy	3800.00
0005432706397	2918	Economy	3400.00
0005432217734	2918	Economy	3400.00
0005432706404	2918	Economy	3400.00
0005432706401	2918	Economy	3400.00
0005432706403	2918	Economy	3400.00
0005432706411	2918	Economy	3400.00
0005432706393	2918	Economy	3400.00
0005432706391	2918	Economy	3400.00
0005432706410	2918	Economy	3400.00
0005432706388	2918	Economy	3400.00
0005432706399	2918	Economy	3400.00
0005432706386	2918	Economy	3400.00
0005432706407	2918	Economy	3400.00
0005432706402	2918	Economy	3400.00
0005432706395	2918	Economy	3400.00
0005432706396	2918	Economy	3400.00
0005432706387	2918	Economy	3400.00
0005432706398	2918	Economy	3400.00
0005432706409	2918	Economy	3400.00
0005432706406	2918	Economy	3400.00
0005432706394	2918	Economy	3400.00
0005432692639	30010	Business	10300.00
0005432692625	30010	Business	10300.00
0005432692627	30010	Business	10300.00
0005432692637	30010	Business	10300.00
0005432880600	30010	Business	10300.00
0005432880606	30010	Business	10300.00
0005432880609	30010	Business	10300.00
0005432880601	30010	Economy	3400.00
0005432692645	30010	Economy	3400.00
0005433123616	30010	Economy	3400.00
0005433123621	30010	Economy	3400.00
0005432692650	30010	Economy	3400.00
0005432692643	30010	Economy	3400.00
0005432692652	30010	Economy	3400.00
0005433123619	30010	Economy	3400.00
0005433123632	30010	Economy	3400.00
0005433123620	30010	Economy	3800.00
0005432692632	30010	Economy	3800.00
0005432692641	30010	Economy	3800.00
0005432880596	30010	Economy	3400.00
0005432692642	30010	Economy	3400.00
0005433123624	30010	Economy	3400.00
0005432692640	30010	Economy	3400.00
0005433123618	30010	Economy	3400.00
0005433123614	30010	Economy	3400.00
0005432692628	30010	Economy	3400.00
0005433123611	30010	Economy	3400.00
0005432692634	30010	Economy	3400.00
0005433123626	30010	Economy	3400.00
0005433123629	30010	Economy	3400.00
0005432692626	30010	Economy	3400.00
0005433123625	30010	Economy	3400.00
0005432880597	30010	Economy	3400.00
0005432880608	30010	Economy	3400.00
0005432692636	30010	Economy	3400.00
0005432880607	30010	Economy	3400.00
0005432692623	30010	Economy	3400.00
0005433123613	30010	Economy	3400.00
0005432692649	30010	Economy	3400.00
0005432880605	30010	Economy	3400.00
0005432692633	30010	Economy	3400.00
0005432692622	30010	Economy	3400.00
0005433123612	30010	Economy	3400.00
0005432880603	30010	Economy	3400.00
0005432692629	30010	Economy	3400.00
0005432692647	30010	Economy	3400.00
0005432880602	30010	Economy	3400.00
0005433123622	30010	Economy	3400.00
0005433123617	30010	Economy	3400.00
0005432692638	30010	Economy	3400.00
0005432880598	30010	Economy	3400.00
0005432692648	30010	Economy	3400.00
0005432692646	30010	Economy	3400.00
0005432692651	30010	Economy	3400.00
0005433123630	30010	Economy	3400.00
0005433123627	30010	Economy	3400.00
0005432880604	30010	Economy	3400.00
0005432692631	30010	Economy	3400.00
0005432692630	30010	Economy	3400.00
0005432880599	30010	Economy	3400.00
0005432692635	30010	Economy	3400.00
0005433123633	30010	Economy	3400.00
0005432692644	30010	Economy	3400.00
0005433123623	30010	Economy	3400.00
0005433123628	30010	Economy	3400.00
0005432692624	30010	Economy	3400.00
0005433123615	30010	Economy	3400.00
0005432880610	30010	Economy	3400.00
0005433123631	30010	Economy	3400.00
0005434979331	23689	Economy	4000.00
0005434979316	23689	Economy	4000.00
0005434979317	23689	Economy	4000.00
0005434979342	23689	Economy	3600.00
0005434979344	23689	Economy	3600.00
0005434979340	23689	Economy	3600.00
0005434979341	23689	Economy	3600.00
0005434988571	23689	Economy	3600.00
0005434979334	23689	Economy	3600.00
0005434979326	23689	Economy	3600.00
0005434979323	23689	Economy	3600.00
0005434979329	23689	Economy	3600.00
0005434988574	23689	Economy	3600.00
0005434988576	23689	Economy	3600.00
0005434979339	23689	Economy	3600.00
0005434979324	23689	Economy	3600.00
0005434979336	23689	Economy	3600.00
0005434979335	23689	Economy	3600.00
0005434979318	23689	Economy	3600.00
0005434988572	23689	Economy	3600.00
0005434988579	23689	Economy	3600.00
0005434979333	23689	Economy	3600.00
0005434988578	23689	Economy	3600.00
0005434979332	23689	Economy	3600.00
0005434979322	23689	Economy	3600.00
0005434988573	23689	Economy	3600.00
0005434979321	23689	Economy	3600.00
0005434979337	23689	Economy	3600.00
0005434979319	23689	Economy	3600.00
0005434979325	23689	Economy	3600.00
0005434979338	23689	Economy	3600.00
0005434988577	23689	Economy	3600.00
0005434979314	23689	Economy	3600.00
0005434979330	23689	Economy	3600.00
0005434979343	23689	Economy	3600.00
0005434979315	23689	Economy	3600.00
0005434988575	23689	Economy	3600.00
0005434979327	23689	Economy	3600.00
0005434979328	23689	Economy	3600.00
0005434979320	23689	Economy	3600.00
0005434302394	10305	Economy	19700.00
0005434302393	10305	Economy	19700.00
0005434302391	10305	Economy	19700.00
0005434302392	10305	Economy	19700.00
0005433113502	19626	Economy	19700.00
0005433113504	19626	Economy	19700.00
0005433113503	19626	Economy	19700.00
0005435068369	3540	Business	26900.00
0005435068336	3540	Business	26900.00
0005435068365	3540	Business	26900.00
0005435068355	3540	Business	26900.00
0005435068354	3540	Business	26900.00
0005435068370	3540	Business	26900.00
0005435068356	3540	Business	26900.00
0005435068366	3540	Economy	9000.00
0005435068359	3540	Economy	9000.00
0005435068343	3540	Economy	9000.00
0005435068322	3540	Economy	9000.00
0005435068331	3540	Economy	9000.00
0005435068340	3540	Economy	9000.00
0005435068348	3540	Economy	9900.00
0005435068362	3540	Economy	9900.00
0005435068367	3540	Economy	9000.00
0005435068339	3540	Economy	9000.00
0005435718849	3540	Economy	9000.00
0005435068329	3540	Economy	9000.00
0005435068350	3540	Economy	9000.00
0005435068326	3540	Economy	9000.00
0005435068334	3540	Economy	9000.00
0005435068338	3540	Economy	9000.00
0005435718850	3540	Economy	9000.00
0005435068358	3540	Economy	9000.00
0005435068344	3540	Economy	9000.00
0005435068349	3540	Economy	9000.00
0005435718855	3540	Economy	9000.00
0005435068318	3540	Economy	9000.00
0005435068364	3540	Economy	9000.00
0005435068352	3540	Economy	9000.00
0005435068324	3540	Economy	9000.00
0005435068333	3540	Economy	9000.00
0005435718848	3540	Economy	9000.00
0005435068320	3540	Economy	9000.00
0005435068347	3540	Economy	9000.00
0005435068353	3540	Economy	9000.00
0005435068351	3540	Economy	9000.00
0005435068360	3540	Economy	9000.00
0005435068357	3540	Economy	9000.00
0005435068332	3540	Economy	9000.00
0005435068361	3540	Economy	9000.00
0005435068328	3540	Economy	9000.00
0005435068346	3540	Economy	9000.00
0005435068327	3540	Economy	9000.00
0005435068323	3540	Economy	9000.00
0005435068368	3540	Economy	9000.00
0005435718851	3540	Economy	9000.00
0005435068363	3540	Economy	9000.00
0005435718854	3540	Economy	9000.00
0005435068337	3540	Economy	9000.00
0005435068335	3540	Economy	9000.00
0005435068321	3540	Economy	9000.00
0005435068341	3540	Economy	9000.00
0005435068345	3540	Economy	9000.00
0005435718852	3540	Economy	9000.00
0005435068319	3540	Economy	9000.00
0005435068330	3540	Economy	9000.00
0005435068342	3540	Economy	9000.00
0005435718853	3540	Economy	9000.00
0005435068325	3540	Economy	9000.00
0005432659676	18207	Economy	5900.00
0005432660789	18207	Economy	5900.00
0005432658561	18207	Economy	5900.00
0005432659675	18207	Economy	5900.00
0005432658560	18207	Economy	5900.00
0005432660788	18207	Economy	5900.00
0005432157464	22	Economy	6700.00
0005432261249	21	Business	20000.00
0005432817033	21	Business	20000.00
0005432817044	21	Business	20000.00
0005432817039	21	Business	20000.00
0005432261254	21	Business	20000.00
0005432261257	21	Business	20000.00
0005432288937	21	Business	20000.00
0005432261242	21	Business	20000.00
0005432817043	21	Business	20000.00
0005432261255	21	Business	20000.00
0005432261239	21	Business	20000.00
0005432261234	21	Business	20000.00
0005432261251	21	Economy	7300.00
0005432817050	21	Economy	7300.00
0005432817048	21	Economy	7300.00
0005432261238	21	Economy	6700.00
0005432261265	21	Economy	6700.00
0005432261229	21	Economy	6700.00
0005432261273	21	Economy	6700.00
0005432261240	21	Economy	6700.00
0005432261245	21	Economy	6700.00
0005432817049	21	Economy	6700.00
0005432261232	21	Economy	6700.00
0005432261258	21	Economy	6700.00
0005432261233	21	Economy	6700.00
0005432261250	21	Economy	6700.00
0005432261244	21	Economy	6700.00
0005432261247	21	Economy	6700.00
0005432261264	21	Economy	6700.00
0005432817028	21	Economy	6700.00
0005432817031	21	Economy	6700.00
0005432261270	21	Economy	6700.00
0005432207623	21	Economy	6700.00
0005432261246	21	Economy	6700.00
0005432261261	21	Economy	6700.00
0005432817036	21	Economy	6700.00
0005432817037	21	Economy	6700.00
0005432261262	21	Economy	6700.00
0005432817045	21	Economy	6700.00
0005432261235	21	Economy	6700.00
0005432261243	21	Economy	6700.00
0005432817055	21	Economy	6700.00
0005432261260	21	Economy	6700.00
0005432261253	21	Economy	6700.00
0005432817051	21	Economy	6700.00
0005432261274	21	Economy	6700.00
0005432261271	21	Economy	6700.00
0005432261269	21	Economy	7300.00
0005432817054	21	Economy	6700.00
0005432261267	21	Economy	6700.00
0005432817058	21	Economy	6700.00
0005432261259	21	Economy	6700.00
0005432261266	21	Economy	6700.00
0005432817052	21	Economy	6700.00
0005432261252	21	Economy	6700.00
0005432207622	21	Economy	6700.00
0005432261272	21	Economy	6700.00
0005432261228	21	Economy	6700.00
0005432261268	21	Economy	6700.00
0005432288938	21	Economy	6700.00
0005432817038	21	Economy	6700.00
0005432817032	21	Economy	6700.00
0005432261241	21	Economy	6700.00
0005432817056	21	Economy	6700.00
0005432817042	21	Economy	6700.00
0005432261263	21	Economy	6700.00
0005432261231	21	Economy	6700.00
0005432261256	21	Economy	6700.00
0005432261236	21	Economy	6700.00
0005432817040	21	Economy	6700.00
0005432261230	21	Economy	6700.00
0005432817046	21	Economy	6700.00
0005432817057	21	Economy	6700.00
0005432261248	21	Economy	6700.00
0005432261275	21	Economy	6700.00
0005432288939	21	Economy	6700.00
0005432817047	21	Economy	6700.00
0005432817041	21	Economy	6700.00
0005432817053	21	Economy	6700.00
0005432817029	21	Economy	6700.00
0005434153515	21	Economy	6700.00
0005432817030	21	Economy	6700.00
0005432817034	21	Economy	6700.00
0005432817035	21	Economy	6700.00
0005432261237	21	Economy	6700.00
0005433101351	8122	Business	20000.00
0005432753253	8122	Business	20000.00
0005433101371	8122	Business	20000.00
0005433101366	8122	Business	20000.00
0005432019884	8122	Business	20000.00
0005432919552	8122	Business	20000.00
0005432019870	8122	Business	20000.00
0005432919559	8122	Business	20000.00
0005432019880	8122	Business	20000.00
0005432019860	8122	Business	20000.00
0005432019872	8122	Business	20000.00
0005432019874	8122	Business	20000.00
0005432919557	8122	Business	20000.00
0005432919555	8122	Business	20000.00
0005432019876	8122	Business	20000.00
0005433101355	8122	Business	20000.00
0005433101370	8122	Business	20000.00
0005433101376	8122	Business	20000.00
0005432391957	8122	Business	20000.00
0005432019867	8122	Business	20000.00
0005432045586	8122	Business	20000.00
0005432019871	8122	Business	20000.00
0005432045585	8122	Economy	7300.00
0005433101365	8122	Economy	7300.00
0005433101367	8122	Economy	7300.00
0005433101369	8122	Economy	7300.00
0005433101347	8122	Economy	6700.00
0005432019873	8122	Economy	6700.00
0005432391956	8122	Economy	6700.00
0005433101364	8122	Economy	6700.00
0005433101368	8122	Economy	6700.00
0005432019865	8122	Economy	6700.00
0005432751480	8122	Economy	6700.00
0005433101348	8122	Economy	6700.00
0005432019866	8122	Economy	6700.00
0005433101387	8122	Economy	6700.00
0005433101346	8122	Economy	6700.00
0005433101372	8122	Economy	6700.00
0005433101352	8122	Economy	6700.00
0005432677515	8122	Economy	6700.00
0005433101357	8122	Economy	6700.00
0005432919546	8122	Economy	6700.00
0005432919558	8122	Economy	6700.00
0005432019864	8122	Economy	6700.00
0005432044485	8122	Economy	6700.00
0005433101353	8122	Economy	6700.00
0005433101380	8122	Economy	6700.00
0005432753254	8122	Economy	6700.00
0005432677519	8122	Economy	6700.00
0005432677517	8122	Economy	6700.00
0005432019881	8122	Economy	6700.00
0005432751477	8122	Economy	6700.00
0005432919550	8122	Economy	6700.00
0005432044484	8122	Economy	6700.00
0005432019887	8122	Economy	6700.00
0005433101349	8122	Economy	6700.00
0005432019886	8122	Economy	6700.00
0005433101356	8122	Economy	6700.00
0005432751478	8122	Economy	6700.00
0005433101381	8122	Economy	6700.00
0005432919561	8122	Economy	6700.00
0005432019878	8122	Economy	6700.00
0005432919549	8122	Economy	6700.00
0005433101382	8122	Economy	6700.00
0005433101386	8122	Economy	6700.00
0005432919565	8122	Economy	6700.00
0005433101359	8122	Economy	7300.00
0005432919556	8122	Economy	7300.00
0005432919547	8122	Economy	7300.00
0005432919563	8122	Economy	7300.00
0005433101361	8122	Economy	6700.00
0005432019877	8122	Economy	6700.00
0005432391955	8122	Economy	6700.00
0005432677516	8122	Economy	6700.00
0005432753252	8122	Economy	6700.00
0005432919554	8122	Economy	6700.00
0005432019875	8122	Economy	6700.00
0005433101358	8122	Economy	6700.00
0005433101385	8122	Economy	6700.00
0005433101354	8122	Economy	6700.00
0005433101389	8122	Economy	6700.00
0005433101390	8122	Economy	6700.00
0005432044483	8122	Economy	6700.00
0005432019883	8122	Economy	6700.00
0005432677518	8122	Economy	6700.00
0005432019861	8122	Economy	6700.00
0005433101373	8122	Economy	6700.00
0005432919553	8122	Economy	6700.00
0005433101388	8122	Economy	6700.00
0005433101377	8122	Economy	6700.00
0005432019863	8122	Economy	6700.00
0005432019869	8122	Economy	6700.00
0005432919562	8122	Economy	6700.00
0005433101350	8122	Economy	6700.00
0005432019882	8122	Economy	6700.00
0005433101374	8122	Economy	6700.00
0005432919560	8122	Economy	6700.00
0005433101378	8122	Economy	6700.00
0005432019868	8122	Economy	6700.00
0005433101362	8122	Economy	6700.00
0005433101383	8122	Economy	6700.00
0005433101360	8122	Economy	6700.00
0005432919566	8122	Economy	6700.00
0005432919564	8122	Economy	6700.00
0005432391958	8122	Economy	6700.00
0005432019879	8122	Economy	6700.00
0005433101384	8122	Economy	6700.00
0005433101363	8122	Economy	6700.00
0005432019862	8122	Economy	6700.00
0005432751479	8122	Economy	6700.00
0005432919548	8122	Economy	6700.00
0005433101375	8122	Economy	6700.00
0005433101379	8122	Economy	6700.00
0005432919551	8122	Economy	6700.00
0005432019885	8122	Economy	6700.00
0005432901355	8123	Business	20000.00
0005432901364	8123	Business	20000.00
0005432002046	8123	Economy	6700.00
0005432901349	8123	Economy	6700.00
0005432901357	8123	Economy	6700.00
0005432901353	8123	Economy	6700.00
0005432901350	8123	Economy	6700.00
0005432901361	8123	Economy	6700.00
0005432901363	8123	Economy	7300.00
0005432901347	8123	Economy	6700.00
0005432901354	8123	Economy	6700.00
0005432901358	8123	Economy	6700.00
0005432901362	8123	Economy	6700.00
0005432901360	8123	Economy	6700.00
0005432901359	8123	Economy	6700.00
0005432901348	8123	Economy	6700.00
0005432901352	8123	Economy	6700.00
0005432901356	8123	Economy	6700.00
0005432901351	8123	Economy	6700.00
0005432002047	8123	Economy	6700.00
0005433870699	9684	Economy	6900.00
0005434175693	32368	Economy	6900.00
0005434175691	32368	Economy	6900.00
0005434175692	32368	Economy	6900.00
0005434426198	3473	Business	35000.00
0005435125806	3473	Business	35000.00
0005435125795	3473	Business	35000.00
0005434876933	3473	Business	35000.00
0005434876872	3473	Business	35000.00
0005435125808	3473	Business	35000.00
0005434876847	3473	Business	35000.00
0005434876926	3473	Business	35000.00
0005434876923	3473	Business	35000.00
0005432799050	3473	Business	35000.00
0005435125779	3473	Business	35000.00
0005435125811	3473	Business	35000.00
0005435125788	3473	Business	35000.00
0005432611653	3473	Business	35000.00
0005434937852	3473	Business	35000.00
0005434876857	3473	Business	35000.00
0005434876873	3473	Comfort	19900.00
0005435625921	3473	Comfort	19900.00
0005434937868	3473	Comfort	19900.00
0005432799041	3473	Comfort	19900.00
0005434426177	3473	Comfort	19900.00
0005434876910	3473	Comfort	19900.00
0005432611652	3473	Comfort	19900.00
0005432613801	3473	Comfort	19900.00
0005434426188	3473	Comfort	19900.00
0005435125784	3473	Comfort	19900.00
0005435125772	3473	Comfort	19900.00
0005434876925	3473	Comfort	19900.00
0005434876882	3473	Comfort	19900.00
0005434426180	3473	Comfort	19900.00
0005434426178	3473	Comfort	19900.00
0005434876907	3473	Comfort	19900.00
0005435125786	3473	Comfort	19900.00
0005434876874	3473	Comfort	19900.00
0005434876876	3473	Comfort	19900.00
0005435125798	3473	Comfort	19900.00
0005435125800	3473	Comfort	19900.00
0005434876887	3473	Comfort	19900.00
0005432799063	3473	Comfort	19900.00
0005434937853	3473	Comfort	19900.00
0005434937870	3473	Comfort	19900.00
0005434876918	3473	Comfort	19900.00
0005432799064	3473	Comfort	19900.00
0005434876866	3473	Comfort	19900.00
0005434426199	3473	Comfort	19900.00
0005432799048	3473	Comfort	19900.00
0005434876854	3473	Comfort	19900.00
0005432799066	3473	Economy	11700.00
0005434876929	3473	Comfort	19900.00
0005434876861	3473	Economy	11700.00
0005432799054	3473	Economy	11700.00
0005432613802	3473	Economy	11700.00
0005434876877	3473	Economy	11700.00
0005434876941	3473	Economy	11700.00
0005434876905	3473	Economy	11700.00
0005434426174	3473	Economy	11700.00
0005434876902	3473	Economy	11700.00
0005434876919	3473	Economy	11700.00
0005434876924	3473	Economy	11700.00
0005434937865	3473	Economy	11700.00
0005434876906	3473	Economy	11700.00
0005434876850	3473	Economy	11700.00
0005434426204	3473	Economy	11700.00
0005434876859	3473	Economy	11700.00
0005432799045	3473	Economy	11700.00
0005434876894	3473	Economy	11700.00
0005434876885	3473	Economy	11700.00
0005435125790	3473	Economy	11700.00
0005434876930	3473	Economy	11700.00
0005435125803	3473	Economy	11700.00
0005435625923	3473	Economy	11700.00
0005435125783	3473	Economy	11700.00
0005432613803	3473	Economy	11700.00
0005435125794	3473	Economy	11700.00
0005432188562	3473	Economy	11700.00
0005434876858	3473	Economy	11700.00
0005435125782	3473	Economy	11700.00
0005434426185	3473	Economy	11700.00
0005434937867	3473	Economy	11700.00
0005435125804	3473	Economy	11700.00
0005432799065	3473	Economy	11700.00
0005434426184	3473	Economy	11700.00
0005432799044	3473	Economy	11700.00
0005434876899	3473	Economy	11700.00
0005432613804	3473	Economy	11700.00
0005434876935	3473	Economy	11700.00
0005434876903	3473	Economy	11700.00
0005434876851	3473	Economy	11700.00
0005432799067	3473	Economy	11700.00
0005434426181	3473	Economy	11700.00
0005434426191	3473	Economy	11700.00
0005435125774	3473	Economy	11700.00
0005435125785	3473	Economy	11700.00
0005435125796	3473	Economy	11700.00
0005434876865	3473	Economy	12800.00
0005435125787	3473	Economy	12800.00
0005434426183	3473	Economy	11700.00
0005434876892	3473	Economy	11700.00
0005432799049	3473	Economy	12800.00
0005434876888	3473	Economy	11700.00
0005434426182	3473	Economy	12800.00
0005434876912	3473	Economy	11700.00
0005434937856	3473	Economy	11700.00
0005434876890	3473	Economy	11700.00
0005434937869	3473	Economy	11700.00
0005432611654	3473	Economy	11700.00
0005434937864	3473	Economy	11700.00
0005435625918	3473	Economy	11700.00
0005434876860	3473	Economy	11700.00
0005434876939	3473	Economy	11700.00
0005434876863	3473	Economy	11700.00
0005434876921	3473	Economy	11700.00
0005435125777	3473	Economy	11700.00
0005434876869	3473	Economy	11700.00
0005434937858	3473	Economy	11700.00
0005434876901	3473	Economy	11700.00
0005434876886	3473	Economy	11700.00
0005435625913	3473	Economy	11700.00
0005434426200	3473	Economy	11700.00
0005434937862	3473	Economy	11700.00
0005434876914	3473	Economy	11700.00
0005434876849	3473	Economy	11700.00
0005434876883	3473	Economy	11700.00
0005432799052	3473	Economy	11700.00
0005435125797	3473	Economy	11700.00
0005435625916	3473	Economy	11700.00
0005434876898	3473	Economy	11700.00
0005432799060	3473	Economy	11700.00
0005434426189	3473	Economy	11700.00
0005435625919	3473	Economy	11700.00
0005434876891	3473	Economy	11700.00
0005432799055	3473	Economy	11700.00
0005435125805	3473	Economy	11700.00
0005435125809	3473	Economy	11700.00
0005434876884	3473	Economy	11700.00
0005434426187	3473	Economy	11700.00
0005434876893	3473	Economy	11700.00
0005435125773	3473	Economy	11700.00
0005435625926	3473	Economy	11700.00
0005432799058	3473	Economy	11700.00
0005435125778	3473	Economy	11700.00
0005434426176	3473	Economy	11700.00
0005434876942	3473	Economy	11700.00
0005435125780	3473	Economy	11700.00
0005432188561	3473	Economy	11700.00
0005435125793	3473	Economy	11700.00
0005435125807	3473	Economy	11700.00
0005432799040	3473	Economy	11700.00
0005432799051	3473	Economy	11700.00
0005432611651	3473	Economy	11700.00
0005434876881	3473	Economy	11700.00
0005432799047	3473	Economy	11700.00
0005434426190	3473	Economy	11700.00
0005434937854	3473	Economy	11700.00
0005434876870	3473	Economy	11700.00
0005434937855	3473	Economy	11700.00
0005432799043	3473	Economy	11700.00
0005434426194	3473	Economy	11700.00
0005434876936	3473	Economy	11700.00
0005434426179	3473	Economy	11700.00
0005434876920	3473	Economy	11700.00
0005434876852	3473	Economy	11700.00
0005435625914	3473	Economy	11700.00
0005434876889	3473	Economy	11700.00
0005435125802	3473	Economy	11700.00
0005434876853	3473	Economy	11700.00
0005434937859	3473	Economy	11700.00
0005434426192	3473	Economy	11700.00
0005435125799	3473	Economy	11700.00
0005434426196	3473	Economy	11700.00
0005434876928	3473	Economy	11700.00
0005434876934	3473	Economy	11700.00
0005434876864	3473	Economy	11700.00
0005434876909	3473	Economy	12800.00
0005435125781	3473	Economy	12800.00
0005434426203	3473	Economy	12800.00
0005434937863	3473	Economy	12800.00
0005432799046	3473	Economy	11700.00
0005432799062	3473	Economy	11700.00
0005434876916	3473	Economy	11700.00
0005434876908	3473	Economy	11700.00
0005435625925	3473	Economy	11700.00
0005432613805	3473	Economy	11700.00
0005434426195	3473	Economy	11700.00
0005434937860	3473	Economy	11700.00
0005434876913	3473	Economy	11700.00
0005434876917	3473	Economy	11700.00
0005435125776	3473	Economy	11700.00
0005435125792	3473	Economy	11700.00
0005435625924	3473	Economy	11700.00
0005435125789	3473	Economy	11700.00
0005434426186	3473	Economy	11700.00
0005434426201	3473	Economy	11700.00
0005434876896	3473	Economy	11700.00
0005434876904	3473	Economy	11700.00
0005434876900	3473	Economy	11700.00
0005434876848	3473	Economy	11700.00
0005435625915	3473	Economy	11700.00
0005434426202	3473	Economy	11700.00
0005432799053	3473	Economy	11700.00
0005435125791	3473	Economy	11700.00
0005435625917	3473	Economy	11700.00
0005435625920	3473	Economy	11700.00
0005434876867	3473	Economy	11700.00
0005432799056	3473	Economy	11700.00
0005434876895	3473	Economy	11700.00
0005434937871	3473	Economy	11700.00
0005432799059	3473	Economy	11700.00
0005432799042	3473	Economy	11700.00
0005434876868	3473	Economy	11700.00
0005434876938	3473	Economy	11700.00
0005435125775	3473	Economy	11700.00
0005435125812	3473	Economy	11700.00
0005434876878	3473	Economy	11700.00
0005434876927	3473	Economy	11700.00
0005434937866	3473	Economy	11700.00
0005434876880	3473	Economy	11700.00
0005434876911	3473	Economy	11700.00
0005434876856	3473	Economy	11700.00
0005432799057	3473	Economy	11700.00
0005434937857	3473	Economy	11700.00
0005435625922	3473	Economy	11700.00
0005435125813	3473	Economy	11700.00
0005434876897	3473	Economy	11700.00
0005434876915	3473	Economy	11700.00
0005434876855	3473	Economy	11700.00
0005434876862	3473	Economy	11700.00
0005432799061	3473	Economy	11700.00
0005434426197	3473	Economy	11700.00
0005434876871	3473	Economy	11700.00
0005434876937	3473	Economy	11700.00
0005434426193	3473	Economy	11700.00
0005434876922	3473	Economy	11700.00
0005435125810	3473	Economy	11700.00
0005434937861	3473	Economy	11700.00
0005435625927	3473	Economy	11700.00
0005435125801	3473	Economy	11700.00
0005434876875	3473	Economy	11700.00
0005434876932	3473	Economy	11700.00
0005434876879	3473	Economy	11700.00
0005434876940	3473	Economy	11700.00
0005434876931	3473	Economy	11700.00
0005432799068	3473	Economy	11700.00
0005434426175	3473	Economy	11700.00
0005435913865	14563	Business	35000.00
0005435913858	14563	Business	35000.00
0005435902449	14563	Business	35000.00
0005435902455	14563	Business	35000.00
0005432059476	14563	Business	35000.00
0005435913861	14563	Business	35000.00
0005435902450	14563	Comfort	19900.00
0005435902438	14563	Comfort	19900.00
0005435902439	14563	Comfort	19900.00
0005435902454	14563	Comfort	19900.00
0005435913859	14563	Comfort	19900.00
0005435902448	14563	Comfort	19900.00
0005434876642	14563	Economy	11700.00
0005435841811	14563	Economy	11700.00
0005435902456	14563	Economy	11700.00
0005435902446	14563	Economy	11700.00
0005435902441	14563	Economy	12800.00
0005435902440	14563	Economy	12800.00
0005435902452	14563	Economy	11700.00
0005435902443	14563	Economy	11700.00
0005435902445	14563	Economy	11700.00
0005435842315	14563	Economy	11700.00
0005435902451	14563	Economy	11700.00
0005435913860	14563	Economy	11700.00
0005435913864	14563	Economy	11700.00
0005435902442	14563	Economy	11700.00
0005435842316	14563	Economy	11700.00
0005435902444	14563	Economy	11700.00
0005435913862	14563	Economy	11700.00
0005435902453	14563	Economy	11700.00
0005435914683	14563	Economy	11700.00
0005435902447	14563	Economy	11700.00
0005435913863	14563	Economy	11700.00
0005434312288	3636	Economy	14800.00
0005434312287	3636	Economy	14800.00
0005434325484	3636	Economy	14800.00
0005434325487	3636	Economy	14800.00
0005434325478	3636	Economy	14800.00
0005434325479	3636	Economy	14800.00
0005434325489	3636	Economy	14800.00
0005434325483	3636	Economy	14800.00
0005434325481	3636	Economy	14800.00
0005434325482	3636	Economy	14800.00
0005434325485	3636	Economy	14800.00
0005434325486	3636	Economy	14800.00
0005434325480	3636	Economy	14800.00
0005434325488	3636	Economy	14800.00
0005434325490	3636	Economy	14800.00
0005435889807	15610	Economy	14800.00
0005435889810	15610	Economy	14800.00
0005435889809	15610	Economy	14800.00
0005435889808	15610	Economy	14800.00
0005435889812	15610	Economy	14800.00
0005435889811	15610	Economy	14800.00
0005435889813	15610	Economy	14800.00
0005435957497	648	Economy	4500.00
0005435957494	648	Economy	4100.00
0005435957492	648	Economy	4100.00
0005435957489	648	Economy	4100.00
0005435957487	648	Economy	4100.00
0005435957491	648	Economy	4100.00
0005435957498	648	Economy	4100.00
0005435957485	648	Economy	4100.00
0005435957484	648	Economy	4100.00
0005435957486	648	Economy	4100.00
0005435957490	648	Economy	4100.00
0005435957495	648	Economy	4100.00
0005435957496	648	Economy	4100.00
0005435957488	648	Economy	4100.00
0005435957493	648	Economy	4100.00
0005433420279	15181	Economy	4100.00
0005433420276	15181	Economy	4100.00
0005433420278	15181	Economy	4100.00
0005433420282	15181	Economy	4100.00
0005433420280	15181	Economy	4100.00
0005433420283	15181	Economy	4100.00
0005433420284	15181	Economy	4100.00
0005433420281	15181	Economy	4100.00
0005433420277	15181	Economy	4100.00
0005435217683	31784	Economy	25500.00
0005435217681	31784	Economy	25500.00
0005435218100	31784	Economy	25500.00
0005435216555	31784	Economy	25500.00
0005435216557	31784	Economy	25500.00
0005435218104	31784	Economy	25500.00
0005435217680	31784	Economy	25500.00
0005435216560	31784	Economy	25500.00
0005435217679	31784	Economy	25500.00
0005435218103	31784	Economy	25500.00
0005435216558	31784	Economy	25500.00
0005435218102	31784	Economy	25500.00
0005435216559	31784	Economy	25500.00
0005435217684	31784	Economy	25500.00
0005435216556	31784	Economy	25500.00
0005435218101	31784	Economy	25500.00
0005435217682	31784	Economy	25500.00
0005434995277	6697	Business	94000.00
0005434995276	6697	Business	94000.00
0005434995275	6697	Economy	31300.00
0005434995278	6697	Economy	31300.00
0005434995280	6697	Economy	34500.00
0005434995281	6697	Economy	31300.00
0005434995282	6697	Economy	31300.00
0005434995279	6697	Economy	31300.00
0005434467725	4010	Economy	21200.00
0005434467726	4010	Economy	21200.00
0005434467728	4010	Economy	21200.00
0005434467730	4010	Economy	21200.00
0005434467729	4010	Economy	21200.00
0005434467727	4010	Economy	21200.00
0005434467731	4010	Economy	21200.00
0005434096711	20178	Economy	14700.00
0005434096708	20178	Economy	13400.00
0005434096709	20178	Economy	13400.00
0005434096710	20178	Economy	13400.00
0005434096713	20178	Economy	13400.00
0005434096712	20178	Economy	13400.00
0005434096707	20178	Economy	13400.00
0005432645797	6837	Business	87700.00
0005432645781	6837	Business	87700.00
0005432645783	6837	Business	87700.00
0005432645804	6837	Business	87700.00
0005432645799	6837	Business	87700.00
0005432645801	6837	Business	87700.00
0005432645777	6837	Business	87700.00
0005432645803	6837	Economy	29200.00
0005432645774	6837	Economy	29200.00
0005432645806	6837	Economy	32200.00
0005432645807	6837	Economy	32200.00
0005432645805	6837	Economy	29200.00
0005432645786	6837	Economy	29200.00
0005432645779	6837	Economy	29200.00
0005432645800	6837	Economy	29200.00
0005432645796	6837	Economy	29200.00
0005432645785	6837	Economy	29200.00
0005432645794	6837	Economy	29200.00
0005432645793	6837	Economy	29200.00
0005432645787	6837	Economy	29200.00
0005432645789	6837	Economy	29200.00
0005432645782	6837	Economy	29200.00
0005432645811	6837	Economy	29200.00
0005432645795	6837	Economy	29200.00
0005432645788	6837	Economy	29200.00
0005432645784	6837	Economy	29200.00
0005432645812	6837	Economy	29200.00
0005432645776	6837	Economy	29200.00
0005432645778	6837	Economy	29200.00
0005432645802	6837	Economy	29200.00
0005432645798	6837	Economy	29200.00
0005432645792	6837	Economy	29200.00
0005432645791	6837	Economy	29200.00
0005432645775	6837	Economy	29200.00
0005432645780	6837	Economy	29200.00
0005432645808	6837	Economy	29200.00
0005432645809	6837	Economy	29200.00
0005432645810	6837	Economy	29200.00
0005432645790	6837	Economy	29200.00
0005435229314	25108	Business	87700.00
0005435229323	25108	Business	87700.00
0005435229317	25108	Business	87700.00
0005435229318	25108	Business	87700.00
0005435229319	25108	Business	87700.00
0005435229301	25108	Economy	29200.00
0005435229326	25108	Economy	29200.00
0005435229303	25108	Economy	29200.00
0005435229330	25108	Economy	29200.00
0005435229315	25108	Economy	29200.00
0005435229308	25108	Economy	29200.00
0005435229307	25108	Economy	29200.00
0005435229313	25108	Economy	29200.00
0005435229324	25108	Economy	29200.00
0005435229320	25108	Economy	29200.00
0005435229327	25108	Economy	29200.00
0005435229311	25108	Economy	29200.00
0005435229305	25108	Economy	29200.00
0005435229312	25108	Economy	29200.00
0005435229322	25108	Economy	29200.00
0005435229316	25108	Economy	29200.00
0005435229321	25108	Economy	29200.00
0005435229309	25108	Economy	29200.00
0005435229304	25108	Economy	29200.00
0005435229302	25108	Economy	29200.00
0005435229329	25108	Economy	29200.00
0005435229310	25108	Economy	29200.00
0005435229328	25108	Economy	29200.00
0005435229325	25108	Economy	29200.00
0005435229306	25108	Economy	29200.00
0005435797273	2838	Business	12600.00
0005435797272	2838	Business	12600.00
0005435797276	2838	Business	12600.00
0005435797274	2838	Economy	4600.00
0005435797269	2838	Economy	4200.00
0005435797266	2838	Economy	4200.00
0005435797277	2838	Economy	4200.00
0005435797275	2838	Economy	4200.00
0005435797267	2838	Economy	4200.00
0005435797278	2838	Economy	4200.00
0005435797279	2838	Economy	4200.00
0005435797268	2838	Economy	4200.00
0005435797271	2838	Economy	4200.00
0005435797265	2838	Economy	4200.00
0005435797270	2838	Economy	4200.00
0005433404699	29319	Business	12600.00
0005433404700	29319	Economy	4200.00
0005433404703	29319	Economy	4200.00
0005433404701	29319	Economy	4200.00
0005433404705	29319	Economy	4200.00
0005433404704	29319	Economy	4200.00
0005433404702	29319	Economy	4200.00
0005434947900	5750	Economy	6800.00
0005434947896	5750	Economy	6800.00
0005434947894	5750	Economy	6800.00
0005434947902	5750	Economy	6800.00
0005434947899	5750	Economy	6800.00
0005434947903	5750	Economy	6800.00
0005434947898	5750	Economy	6800.00
0005434947897	5750	Economy	6800.00
0005434947895	5750	Economy	6800.00
0005434947901	5750	Economy	6800.00
0005434947875	16419	Economy	6800.00
0005435376318	16419	Economy	6800.00
0005433960054	6963	Business	21400.00
0005433960057	6963	Business	21400.00
0005433960032	6963	Business	21400.00
0005433960070	6963	Business	21400.00
0005433960056	6963	Business	21400.00
0005433960068	6963	Business	21400.00
0005433960074	6963	Business	21400.00
0005433960051	6963	Business	21400.00
0005433960065	6963	Economy	7100.00
0005433960042	6963	Economy	7100.00
0005433960058	6963	Economy	7100.00
0005433960079	6963	Economy	7100.00
0005433960081	6963	Economy	7100.00
0005433960063	6963	Economy	7100.00
0005433960071	6963	Economy	7800.00
0005433960075	6963	Economy	7800.00
0005433960030	6963	Economy	7800.00
0005433960036	6963	Economy	7100.00
0005433960048	6963	Economy	7100.00
0005433960080	6963	Economy	7100.00
0005433960077	6963	Economy	7100.00
0005433960069	6963	Economy	7100.00
0005433960035	6963	Economy	7100.00
0005433960059	6963	Economy	7100.00
0005433960043	6963	Economy	7100.00
0005433960038	6963	Economy	7100.00
0005433960060	6963	Economy	7100.00
0005433960041	6963	Economy	7100.00
0005433960078	6963	Economy	7100.00
0005433960064	6963	Economy	7100.00
0005433960050	6963	Economy	7100.00
0005433960076	6963	Economy	7100.00
0005433960040	6963	Economy	7100.00
0005433960067	6963	Economy	7100.00
0005433960061	6963	Economy	7100.00
0005433960037	6963	Economy	7100.00
0005433960055	6963	Economy	7100.00
0005433960073	6963	Economy	7100.00
0005433960062	6963	Economy	7100.00
0005433960047	6963	Economy	7100.00
0005433960033	6963	Economy	7100.00
0005433960031	6963	Economy	7100.00
0005433960072	6963	Economy	7100.00
0005433960029	6963	Economy	7100.00
0005433960045	6963	Economy	7100.00
0005433960053	6963	Economy	7100.00
0005433960066	6963	Economy	7100.00
0005433960046	6963	Economy	7100.00
0005433960039	6963	Economy	7100.00
0005433960044	6963	Economy	7100.00
0005433960034	6963	Economy	7100.00
0005433960028	6963	Economy	7100.00
0005433960049	6963	Economy	7100.00
0005433960052	6963	Economy	7100.00
0005435082669	26076	Economy	3900.00
0005435082662	26076	Economy	3900.00
0005435082663	26076	Economy	3900.00
0005435082668	26076	Economy	3900.00
0005435082667	26076	Economy	3900.00
0005435082666	26076	Economy	3900.00
0005435082664	26076	Economy	3900.00
0005435082665	26076	Economy	3900.00
0005434244560	4956	Business	18000.00
0005434244547	4956	Business	18000.00
0005434244562	4956	Business	18000.00
0005434244558	4956	Business	18000.00
0005432166854	4956	Business	18000.00
0005434244572	4956	Economy	6600.00
0005434244556	4956	Economy	6000.00
0005434244548	4956	Economy	6000.00
0005434244549	4956	Economy	6000.00
0005434244552	4956	Economy	6000.00
0005434244561	4956	Economy	6000.00
0005434244569	4956	Economy	6000.00
0005434244559	4956	Economy	6000.00
0005434244568	4956	Economy	6000.00
0005434244545	4956	Economy	6000.00
0005432166855	4956	Economy	6000.00
0005434244551	4956	Economy	6000.00
0005434244550	4956	Economy	6000.00
0005434244553	4956	Economy	6000.00
0005432166853	4956	Economy	6600.00
0005434244555	4956	Economy	6600.00
0005434244570	4956	Economy	6000.00
0005434244571	4956	Economy	6000.00
0005434244565	4956	Economy	6000.00
0005434244554	4956	Economy	6000.00
0005434244546	4956	Economy	6000.00
0005434244544	4956	Economy	6000.00
0005434244566	4956	Economy	6000.00
0005434244563	4956	Economy	6000.00
0005434244564	4956	Economy	6000.00
0005434244557	4956	Economy	6000.00
0005434244567	4956	Economy	6000.00
0005433784423	4957	Business	18000.00
0005433613678	4957	Business	18000.00
0005433784436	4957	Business	18000.00
0005433613681	4957	Business	18000.00
0005432104871	4957	Business	18000.00
0005433613612	4957	Business	18000.00
0005433613657	4957	Business	18000.00
0005432104903	4957	Business	18000.00
0005432667423	4957	Business	18000.00
0005433613637	4957	Business	18000.00
0005433784427	4957	Business	18000.00
0005432104889	4957	Business	18000.00
0005433613672	4957	Business	18000.00
0005432104879	4957	Business	18000.00
0005433613614	4957	Business	18000.00
0005433613643	4957	Business	18000.00
0005432104865	4957	Business	18000.00
0005432104880	4957	Business	18000.00
0005433784408	4957	Business	18000.00
0005432667424	4957	Business	18000.00
0005433784420	4957	Business	18000.00
0005433613669	4957	Business	18000.00
0005433613676	4957	Business	18000.00
0005433784435	4957	Business	18000.00
0005433613618	4957	Business	18000.00
0005433613673	4957	Business	18000.00
0005432104867	4957	Business	18000.00
0005432667425	4957	Economy	6600.00
0005432665245	4957	Business	18000.00
0005433613624	4957	Economy	6600.00
0005433784415	4957	Economy	6600.00
0005433613634	4957	Economy	6600.00
0005433784402	4957	Economy	6600.00
0005433784438	4957	Economy	6600.00
0005433784418	4957	Economy	6000.00
0005433784426	4957	Economy	6000.00
0005432104892	4957	Economy	6000.00
0005432104875	4957	Economy	6000.00
0005433613646	4957	Economy	6000.00
0005433613659	4957	Economy	6000.00
0005433613623	4957	Economy	6000.00
0005433613619	4957	Economy	6000.00
0005432104868	4957	Economy	6000.00
0005433784413	4957	Economy	6000.00
0005432104862	4957	Economy	6000.00
0005433613654	4957	Economy	6000.00
0005433784417	4957	Economy	6000.00
0005433784405	4957	Economy	6000.00
0005432104895	4957	Economy	6000.00
0005433613629	4957	Economy	6000.00
0005433613650	4957	Economy	6000.00
0005432104887	4957	Economy	6000.00
0005433613655	4957	Economy	6000.00
0005432104902	4957	Economy	6000.00
0005433613625	4957	Economy	6000.00
0005432104869	4957	Economy	6000.00
0005433613636	4957	Economy	6000.00
0005433613644	4957	Economy	6000.00
0005433613671	4957	Economy	6000.00
0005432104888	4957	Economy	6000.00
0005432104878	4957	Economy	6000.00
0005433613667	4957	Economy	6000.00
0005433613638	4957	Economy	6000.00
0005433613641	4957	Economy	6000.00
0005432104893	4957	Economy	6000.00
0005433613668	4957	Economy	6000.00
0005432104859	4957	Economy	6000.00
0005433784434	4957	Economy	6000.00
0005433784430	4957	Economy	6000.00
0005433613653	4957	Economy	6000.00
0005433613651	4957	Economy	6000.00
0005433784437	4957	Economy	6000.00
0005433613630	4957	Economy	6000.00
0005433613686	4957	Economy	6000.00
0005432104874	4957	Economy	6000.00
0005432104860	4957	Economy	6000.00
0005432104897	4957	Economy	6000.00
0005432104901	4957	Economy	6000.00
0005432104873	4957	Economy	6000.00
0005432104900	4957	Economy	6000.00
0005433613661	4957	Economy	6000.00
0005432104870	4957	Economy	6000.00
0005433613685	4957	Economy	6000.00
0005432104876	4957	Economy	6000.00
0005432104899	4957	Economy	6000.00
0005432104891	4957	Economy	6000.00
0005433784414	4957	Economy	6000.00
0005433784428	4957	Economy	6000.00
0005433613658	4957	Economy	6000.00
0005432104881	4957	Economy	6000.00
0005433613670	4957	Economy	6000.00
0005432104884	4957	Economy	6000.00
0005432104883	4957	Economy	6000.00
0005433784421	4957	Economy	6000.00
0005433613613	4957	Economy	6600.00
0005433784429	4957	Economy	6600.00
0005433613662	4957	Economy	6600.00
0005433613679	4957	Economy	6600.00
0005433613665	4957	Economy	6600.00
0005433784412	4957	Economy	6000.00
0005433784431	4957	Economy	6000.00
0005433613621	4957	Economy	6000.00
0005433613682	4957	Economy	6000.00
0005433613640	4957	Economy	6000.00
0005433784404	4957	Economy	6600.00
0005433613617	4957	Economy	6000.00
0005433613616	4957	Economy	6000.00
0005432104877	4957	Economy	6000.00
0005432104894	4957	Economy	6000.00
0005433613684	4957	Economy	6000.00
0005432104885	4957	Economy	6000.00
0005433613622	4957	Economy	6000.00
0005433613660	4957	Economy	6000.00
0005433613649	4957	Economy	6000.00
0005432104872	4957	Economy	6000.00
0005433784424	4957	Economy	6000.00
0005432104866	4957	Economy	6000.00
0005433784411	4957	Economy	6000.00
0005433613663	4957	Economy	6000.00
0005433613666	4957	Economy	6000.00
0005433613615	4957	Economy	6000.00
0005432104906	4957	Economy	6000.00
0005432665244	4957	Economy	6000.00
0005433613628	4957	Economy	6000.00
0005432104863	4957	Economy	6000.00
0005432666358	4957	Economy	6000.00
0005432104904	4957	Economy	6000.00
0005432104898	4957	Economy	6000.00
0005433784416	4957	Economy	6000.00
0005433613664	4957	Economy	6000.00
0005433784410	4957	Economy	6000.00
0005433613674	4957	Economy	6000.00
0005433613648	4957	Economy	6000.00
0005433784419	4957	Economy	6000.00
0005433613642	4957	Economy	6000.00
0005433613611	4957	Economy	6000.00
0005433784401	4957	Economy	6000.00
0005433784406	4957	Economy	6000.00
0005433613631	4957	Economy	6000.00
0005433613680	4957	Economy	6000.00
0005433613620	4957	Economy	6000.00
0005433613635	4957	Economy	6000.00
0005433784407	4957	Economy	6000.00
0005432104890	4957	Economy	6000.00
0005433784422	4957	Economy	6000.00
0005433613633	4957	Economy	6000.00
0005433613683	4957	Economy	6000.00
0005433784439	4957	Economy	6000.00
0005432104905	4957	Economy	6000.00
0005433784432	4957	Economy	6000.00
0005433613675	4957	Economy	6000.00
0005433613626	4957	Economy	6000.00
0005433784425	4957	Economy	6000.00
0005432104861	4957	Economy	6000.00
0005433613645	4957	Economy	6000.00
0005433613647	4957	Economy	6000.00
0005433613656	4957	Economy	6000.00
0005433784403	4957	Economy	6000.00
0005433784433	4957	Economy	6000.00
0005433613627	4957	Economy	6000.00
0005433613652	4957	Economy	6000.00
0005433613677	4957	Economy	6000.00
0005433613632	4957	Economy	6000.00
0005432104882	4957	Economy	6000.00
0005432145082	4957	Economy	6000.00
0005432104896	4957	Economy	6000.00
0005433784409	4957	Economy	6000.00
0005433613639	4957	Economy	6000.00
0005432104886	4957	Economy	6000.00
0005432104864	4957	Economy	6000.00
0005434229036	4959	Business	18000.00
0005434149564	4959	Business	18000.00
0005434229042	4959	Business	18000.00
0005434264761	4959	Business	18000.00
0005434173461	4959	Business	18000.00
0005434229056	4959	Business	18000.00
0005434264776	4959	Business	18000.00
0005434264771	4959	Business	18000.00
0005434229037	4959	Business	18000.00
0005434264759	4959	Business	18000.00
0005434173464	4959	Business	18000.00
0005434264777	4959	Business	18000.00
0005434264764	4959	Business	18000.00
0005434264757	4959	Economy	6600.00
0005434229050	4959	Economy	6600.00
0005434173460	4959	Economy	6000.00
0005434264773	4959	Economy	6000.00
0005434149565	4959	Economy	6000.00
0005434264769	4959	Economy	6000.00
0005434264765	4959	Economy	6000.00
0005434264780	4959	Economy	6000.00
0005434264763	4959	Economy	6000.00
0005434264768	4959	Economy	6000.00
0005434264762	4959	Economy	6000.00
0005434229038	4959	Economy	6000.00
0005434264756	4959	Economy	6000.00
0005434229044	4959	Economy	6000.00
0005434229052	4959	Economy	6000.00
0005434229035	4959	Economy	6000.00
0005434173462	4959	Economy	6000.00
0005434229058	4959	Economy	6000.00
0005434229041	4959	Economy	6000.00
0005434149562	4959	Economy	6000.00
0005434264766	4959	Economy	6000.00
0005434229045	4959	Economy	6000.00
0005434264779	4959	Economy	6600.00
0005434229049	4959	Economy	6600.00
0005434149559	4959	Economy	6600.00
0005434264760	4959	Economy	6000.00
0005434229047	4959	Economy	6600.00
0005434173463	4959	Economy	6000.00
0005434149557	4959	Economy	6000.00
0005434229053	4959	Economy	6000.00
0005434229057	4959	Economy	6000.00
0005434264770	4959	Economy	6000.00
0005434229039	4959	Economy	6000.00
0005434149560	4959	Economy	6000.00
0005434264755	4959	Economy	6000.00
0005434229054	4959	Economy	6000.00
0005434229055	4959	Economy	6000.00
0005434149561	4959	Economy	6000.00
0005434229043	4959	Economy	6000.00
0005434264775	4959	Economy	6000.00
0005434264772	4959	Economy	6000.00
0005434229048	4959	Economy	6000.00
0005434149567	4959	Economy	6000.00
0005434264774	4959	Economy	6000.00
0005434229040	4959	Economy	6000.00
0005434229051	4959	Economy	6000.00
0005434264778	4959	Economy	6000.00
0005434149563	4959	Economy	6000.00
0005434264758	4959	Economy	6000.00
0005434264767	4959	Economy	6000.00
0005434229046	4959	Economy	6000.00
0005434149558	4959	Economy	6000.00
0005434149566	4959	Economy	6000.00
0005434264754	4959	Economy	6000.00
0005435269652	8542	Business	18000.00
0005434244457	8542	Business	18000.00
0005435269648	8542	Economy	6000.00
0005434244460	8542	Economy	6000.00
0005435269651	8542	Economy	6000.00
0005434244458	8542	Economy	6000.00
0005435269650	8542	Economy	6000.00
0005435269649	8542	Economy	6000.00
0005434244461	8542	Economy	6000.00
0005433784296	8542	Economy	6000.00
0005433815316	8540	Business	18000.00
0005433534468	8540	Business	18000.00
0005433688781	8540	Business	18000.00
0005433689883	8540	Business	18000.00
0005432034560	8540	Business	18000.00
0005432034545	8540	Business	18000.00
0005432034553	8540	Business	18000.00
0005435006691	8540	Business	18000.00
0005432047496	8540	Business	18000.00
0005435006692	8540	Business	18000.00
0005433815317	8540	Business	18000.00
0005432034535	8540	Business	18000.00
0005435006683	8540	Economy	6600.00
0005432034546	8540	Economy	6600.00
0005435006695	8540	Economy	6600.00
0005432335863	8540	Economy	6000.00
0005432034543	8540	Economy	6000.00
0005432034555	8540	Economy	6000.00
0005432335862	8540	Economy	6000.00
0005435006676	8540	Economy	6000.00
0005432034556	8540	Economy	6000.00
0005432034541	8540	Economy	6000.00
0005435006673	8540	Economy	6000.00
0005432034539	8540	Economy	6000.00
0005432034552	8540	Economy	6000.00
0005435006697	8540	Economy	6000.00
0005432034536	8540	Economy	6000.00
0005435006688	8540	Economy	6000.00
0005432034558	8540	Economy	6000.00
0005434264681	8540	Economy	6000.00
0005432034550	8540	Economy	6000.00
0005432034544	8540	Economy	6000.00
0005432335861	8540	Economy	6000.00
0005433815315	8540	Economy	6000.00
0005432034542	8540	Economy	6000.00
0005434311188	8540	Economy	6000.00
0005435006694	8540	Economy	6000.00
0005435006687	8540	Economy	6000.00
0005432034538	8540	Economy	6000.00
0005435006675	8540	Economy	6000.00
0005435006686	8540	Economy	6000.00
0005432335868	8540	Economy	6000.00
0005435006684	8540	Economy	6000.00
0005433688780	8540	Economy	6000.00
0005432335865	8540	Economy	6000.00
0005432034562	8540	Economy	6000.00
0005432034537	8540	Economy	6000.00
0005432034549	8540	Economy	6600.00
0005432034559	8540	Economy	6600.00
0005432335866	8540	Economy	6000.00
0005435006678	8540	Economy	6000.00
0005435006696	8540	Economy	6000.00
0005432034534	8540	Economy	6000.00
0005435006681	8540	Economy	6000.00
0005433534467	8540	Economy	6000.00
0005432047495	8540	Economy	6000.00
0005435006685	8540	Economy	6000.00
0005432034551	8540	Economy	6000.00
0005432034540	8540	Economy	6000.00
0005435006689	8540	Economy	6000.00
0005435006677	8540	Economy	6000.00
0005435006679	8540	Economy	6000.00
0005433815319	8540	Economy	6000.00
0005432047497	8540	Economy	6000.00
0005433815318	8540	Economy	6000.00
0005435006690	8540	Economy	6000.00
0005435006682	8540	Economy	6000.00
0005432034557	8540	Economy	6000.00
0005433690897	8540	Economy	6000.00
0005433689882	8540	Economy	6000.00
0005432335864	8540	Economy	6000.00
0005432034547	8540	Economy	6000.00
0005433688779	8540	Economy	6000.00
0005432034554	8540	Economy	6000.00
0005435006693	8540	Economy	6000.00
0005432335858	8540	Economy	6000.00
0005432335867	8540	Economy	6000.00
0005435006672	8540	Economy	6000.00
0005432034561	8540	Economy	6000.00
0005435006680	8540	Economy	6000.00
0005434264680	8540	Economy	6000.00
0005435286554	8540	Economy	6000.00
0005433690898	8540	Economy	6000.00
0005435006674	8540	Economy	6000.00
0005435286555	8540	Economy	6000.00
0005432034548	8540	Economy	6000.00
0005432335860	8540	Economy	6000.00
0005432335859	8540	Economy	6000.00
0005433202153	12640	Economy	14800.00
0005433202158	12640	Economy	14800.00
0005433202162	12640	Economy	14800.00
0005433202155	12640	Economy	14800.00
0005433202151	12640	Economy	14800.00
0005433202157	12640	Economy	14800.00
0005433202150	12640	Economy	14800.00
0005433202147	12640	Economy	14800.00
0005433202149	12640	Economy	14800.00
0005433202160	12640	Economy	14800.00
0005433202154	12640	Economy	14800.00
0005433202148	12640	Economy	14800.00
0005433202159	12640	Economy	14800.00
0005433202152	12640	Economy	14800.00
0005433202161	12640	Economy	14800.00
0005433202156	12640	Economy	14800.00
0005434638917	23348	Economy	14800.00
0005434638919	23348	Economy	14800.00
0005434638914	23348	Economy	14800.00
0005434638924	23348	Economy	14800.00
0005434638915	23348	Economy	14800.00
0005434638908	23348	Economy	14800.00
0005434638916	23348	Economy	14800.00
0005434638913	23348	Economy	14800.00
0005432290585	23348	Economy	14800.00
0005434638911	23348	Economy	14800.00
0005434638920	23348	Economy	14800.00
0005434638918	23348	Economy	14800.00
0005434638926	23348	Economy	14800.00
0005434638923	23348	Economy	14800.00
0005434638912	23348	Economy	14800.00
0005434638909	23348	Economy	14800.00
0005434638906	23348	Economy	14800.00
0005434638921	23348	Economy	14800.00
0005434638910	23348	Economy	14800.00
0005434638907	23348	Economy	14800.00
0005432290587	23348	Economy	14800.00
0005432290586	23348	Economy	14800.00
0005434638927	23348	Economy	14800.00
0005434638925	23348	Economy	14800.00
0005434638905	23348	Economy	14800.00
0005434638903	23348	Economy	14800.00
0005434638922	23348	Economy	14800.00
0005434638904	23348	Economy	14800.00
0005432054262	21073	Economy	6300.00
0005432327965	21073	Economy	6300.00
0005432054263	21073	Economy	6300.00
0005432382569	31254	Business	18900.00
0005432328027	31254	Business	18900.00
0005432382570	31254	Business	18900.00
0005432328011	31254	Business	18900.00
0005432328020	31254	Business	18900.00
0005432382592	31254	Business	18900.00
0005432382566	31254	Business	18900.00
0005432382568	31254	Business	18900.00
0005432327999	31254	Business	18900.00
0005432328013	31254	Business	18900.00
0005432328030	31254	Business	18900.00
0005432382575	31254	Business	18900.00
0005432382588	31254	Economy	6300.00
0005432328023	31254	Economy	6300.00
0005432328004	31254	Economy	6300.00
0005432328002	31254	Economy	6300.00
0005432382584	31254	Economy	6300.00
0005432382565	31254	Economy	6300.00
0005432382594	31254	Economy	6300.00
0005432382571	31254	Economy	6300.00
0005432382599	31254	Economy	6300.00
0005432327996	31254	Economy	6300.00
0005432328007	31254	Economy	6900.00
0005432382598	31254	Economy	6900.00
0005432382572	31254	Economy	6900.00
0005432328019	31254	Economy	6900.00
0005432382595	31254	Economy	6900.00
0005432382579	31254	Economy	6300.00
0005432328016	31254	Economy	6300.00
0005432382573	31254	Economy	6300.00
0005432382603	31254	Economy	6300.00
0005432328008	31254	Economy	6300.00
0005432287114	31254	Economy	6300.00
0005432328001	31254	Economy	6300.00
0005432327995	31254	Economy	6300.00
0005432328000	31254	Economy	6300.00
0005432328003	31254	Economy	6300.00
0005432327986	31254	Economy	6300.00
0005432327994	31254	Economy	6300.00
0005432328021	31254	Economy	6300.00
0005432382574	31254	Economy	6300.00
0005432327985	31254	Economy	6300.00
0005432287112	31254	Economy	6300.00
0005432382583	31254	Economy	6300.00
0005432382601	31254	Economy	6300.00
0005432327998	31254	Economy	6300.00
0005432327993	31254	Economy	6300.00
0005432328005	31254	Economy	6300.00
0005432327988	31254	Economy	6300.00
0005432382597	31254	Economy	6300.00
0005432382589	31254	Economy	6300.00
0005432328014	31254	Economy	6300.00
0005432382580	31254	Economy	6300.00
0005432287113	31254	Economy	6300.00
0005432328006	31254	Economy	6300.00
0005432382587	31254	Economy	6300.00
0005432382600	31254	Economy	6300.00
0005432382585	31254	Economy	6300.00
0005432327991	31254	Economy	6300.00
0005432287110	31254	Economy	6300.00
0005432328025	31254	Economy	6300.00
0005432328026	31254	Economy	6300.00
0005432382564	31254	Economy	6300.00
0005432328012	31254	Economy	6300.00
0005432382602	31254	Economy	6300.00
0005432327987	31254	Economy	6300.00
0005432328015	31254	Economy	6300.00
0005432328024	31254	Economy	6300.00
0005432327990	31254	Economy	6300.00
0005432382586	31254	Economy	6300.00
0005432382605	31254	Economy	6300.00
0005432382590	31254	Economy	6300.00
0005432327989	31254	Economy	6300.00
0005432287111	31254	Economy	6300.00
0005432328009	31254	Economy	6300.00
0005432382591	31254	Economy	6300.00
0005432287115	31254	Economy	6300.00
0005432328010	31254	Economy	6300.00
0005432328018	31254	Economy	6300.00
0005432382582	31254	Economy	6300.00
0005432382578	31254	Economy	6300.00
0005432382577	31254	Economy	6300.00
0005432382593	31254	Economy	6300.00
0005432328022	31254	Economy	6300.00
0005432328017	31254	Economy	6300.00
0005432382581	31254	Economy	6300.00
0005432327992	31254	Economy	6300.00
0005432382576	31254	Economy	6300.00
0005432382567	31254	Economy	6300.00
0005432328031	31254	Economy	6300.00
0005432328029	31254	Economy	6300.00
0005432327997	31254	Economy	6300.00
0005432328028	31254	Economy	6300.00
0005432382604	31254	Economy	6300.00
0005432382596	31254	Economy	6300.00
0005432423698	13273	Business	12700.00
0005432423718	13273	Business	12700.00
0005432423712	13273	Business	12700.00
0005432423734	13273	Business	12700.00
0005432423758	13273	Business	12700.00
0005432423725	13273	Business	12700.00
0005432423701	13273	Business	12700.00
0005432423759	13273	Business	12700.00
0005432423754	13273	Business	12700.00
0005432423751	13273	Business	12700.00
0005432423735	13273	Economy	4200.00
0005432423731	13273	Economy	4200.00
0005432423748	13273	Economy	4200.00
0005432423723	13273	Economy	4200.00
0005432423696	13273	Economy	4200.00
0005432423757	13273	Economy	4200.00
0005432423707	13273	Economy	4200.00
0005432423704	13273	Economy	4200.00
0005432423747	13273	Economy	4700.00
0005432423741	13273	Economy	4700.00
0005432423742	13273	Economy	4700.00
0005432423755	13273	Economy	4700.00
0005432423730	13273	Economy	4200.00
0005432423753	13273	Economy	4200.00
0005432423697	13273	Economy	4200.00
0005432423716	13273	Economy	4200.00
0005432423738	13273	Economy	4200.00
0005432423729	13273	Economy	4200.00
0005432423695	13273	Economy	4200.00
0005432423745	13273	Economy	4200.00
0005432423709	13273	Economy	4200.00
0005432423714	13273	Economy	4200.00
0005432423708	13273	Economy	4200.00
0005432423703	13273	Economy	4200.00
0005432423719	13273	Economy	4200.00
0005432423740	13273	Economy	4200.00
0005432423721	13273	Economy	4200.00
0005432423733	13273	Economy	4200.00
0005432423727	13273	Economy	4200.00
0005432423699	13273	Economy	4200.00
0005432423710	13273	Economy	4200.00
0005432423711	13273	Economy	4200.00
0005432423715	13273	Economy	4200.00
0005432423717	13273	Economy	4200.00
0005432423694	13273	Economy	4200.00
0005432423750	13273	Economy	4200.00
0005432423706	13273	Economy	4200.00
0005432423739	13273	Economy	4200.00
0005432423744	13273	Economy	4200.00
0005432423726	13273	Economy	4200.00
0005432423762	13273	Economy	4200.00
0005432423746	13273	Economy	4200.00
0005432423749	13273	Economy	4200.00
0005432423736	13273	Economy	4200.00
0005432423720	13273	Economy	4200.00
0005432423760	13273	Economy	4200.00
0005432423700	13273	Economy	4200.00
0005432423732	13273	Economy	4200.00
0005432423743	13273	Economy	4200.00
0005432423761	13273	Economy	4200.00
0005432423722	13273	Economy	4200.00
0005432423713	13273	Economy	4200.00
0005432423724	13273	Economy	4200.00
0005432423728	13273	Economy	4200.00
0005432423752	13273	Economy	4200.00
0005432423705	13273	Economy	4200.00
0005432423756	13273	Economy	4200.00
0005432423737	13273	Economy	4200.00
0005432423702	13273	Economy	4200.00
0005432822096	9587	Business	32600.00
0005434448267	9587	Business	32600.00
0005432822092	9587	Business	32600.00
0005432817057	9587	Business	32600.00
0005432822095	9587	Business	32600.00
0005432817039	9587	Business	32600.00
0005432817040	9587	Economy	10900.00
0005432817042	9587	Economy	10900.00
0005432817041	9587	Economy	10900.00
0005432817037	9587	Economy	10900.00
0005432817032	9587	Economy	10900.00
0005432817044	9587	Economy	10900.00
0005432817038	9587	Economy	11900.00
0005432817055	9587	Economy	10900.00
0005432817029	9587	Economy	10900.00
0005432817045	9587	Economy	10900.00
0005432822091	9587	Economy	10900.00
0005432822090	9587	Economy	10900.00
0005432817035	9587	Economy	10900.00
0005432817036	9587	Economy	10900.00
0005432817046	9587	Economy	10900.00
0005432817028	9587	Economy	10900.00
0005432288937	9587	Economy	10900.00
0005432817049	9587	Economy	10900.00
0005434448265	9587	Economy	10900.00
0005432817048	9587	Economy	10900.00
0005432817034	9587	Economy	10900.00
0005432822089	9587	Economy	10900.00
0005432817058	9587	Economy	10900.00
0005432817050	9587	Economy	10900.00
0005432817043	9587	Economy	10900.00
0005432822093	9587	Economy	10900.00
0005432817033	9587	Economy	10900.00
0005432817056	9587	Economy	10900.00
0005432817051	9587	Economy	10900.00
0005432817031	9587	Economy	10900.00
0005432822094	9587	Economy	10900.00
0005432817054	9587	Economy	10900.00
0005432288938	9587	Economy	10900.00
0005432822088	9587	Economy	10900.00
0005432822097	9587	Economy	10900.00
0005432817047	9587	Economy	10900.00
0005432288939	9587	Economy	10900.00
0005432817053	9587	Economy	10900.00
0005432817052	9587	Economy	10900.00
0005432817030	9587	Economy	10900.00
0005434448266	9587	Economy	10900.00
0005432901363	28995	Business	32600.00
0005434186156	28995	Business	32600.00
0005432901354	28995	Economy	10900.00
0005434157364	28995	Economy	10900.00
0005432901356	28995	Economy	11900.00
0005434157369	28995	Economy	10900.00
0005432901359	28995	Economy	10900.00
0005432901357	28995	Economy	10900.00
0005432901364	28995	Economy	10900.00
0005434157367	28995	Economy	10900.00
0005434157366	28995	Economy	10900.00
0005432002047	28995	Economy	10900.00
0005432901360	28995	Economy	10900.00
0005432002046	28995	Economy	10900.00
0005434157363	28995	Economy	10900.00
0005432901351	28995	Economy	10900.00
0005434186155	28995	Economy	10900.00
0005432901352	28995	Economy	10900.00
0005432901348	28995	Economy	10900.00
0005434157365	28995	Economy	10900.00
0005432901355	28995	Economy	10900.00
0005432901349	28995	Economy	10900.00
0005434157368	28995	Economy	10900.00
0005432901353	28995	Economy	10900.00
0005432901350	28995	Economy	10900.00
0005432901358	28995	Economy	10900.00
0005432901347	28995	Economy	10900.00
0005432901361	28995	Economy	10900.00
0005434157370	28995	Economy	10900.00
0005434186154	28995	Economy	10900.00
0005434186153	28995	Economy	10900.00
0005432901362	28995	Economy	10900.00
0005432613804	15115	Economy	11000.00
0005432613803	15115	Economy	11000.00
0005432611654	15115	Economy	11000.00
0005432611652	15115	Economy	11000.00
0005432613801	15115	Economy	11000.00
0005432613805	15115	Economy	11000.00
0005432611653	15115	Economy	11000.00
0005432613802	15115	Economy	11000.00
0005432611651	15115	Economy	11000.00
0005435842315	31551	Economy	11000.00
0005435842316	31551	Economy	11000.00
0005435841811	31551	Economy	11000.00
0005433568189	11846	Business	105900.00
0005433568148	11846	Business	105900.00
0005433568150	11846	Business	105900.00
0005433568160	11846	Business	105900.00
0005433568183	11846	Business	105900.00
0005433568124	11846	Business	105900.00
0005433568136	11846	Business	105900.00
0005433568157	11846	Business	105900.00
0005433568159	11846	Business	105900.00
0005433568169	11846	Business	105900.00
0005433568141	11846	Business	105900.00
0005433568125	11846	Business	105900.00
0005433568163	11846	Economy	35300.00
0005433568142	11846	Business	105900.00
0005433568151	11846	Economy	35300.00
0005433568127	11846	Economy	35300.00
0005433568152	11846	Economy	35300.00
0005433568134	11846	Economy	35300.00
0005433568177	11846	Economy	35300.00
0005433568188	11846	Economy	35300.00
0005433568133	11846	Economy	38800.00
0005433568184	11846	Economy	38800.00
0005433568191	11846	Economy	38800.00
0005433568174	11846	Economy	35300.00
0005433568153	11846	Economy	35300.00
0005433568145	11846	Economy	35300.00
0005433568126	11846	Economy	35300.00
0005433568171	11846	Economy	35300.00
0005433568128	11846	Economy	35300.00
0005433568166	11846	Economy	35300.00
0005433568138	11846	Economy	35300.00
0005433568144	11846	Economy	35300.00
0005433568149	11846	Economy	35300.00
0005433568179	11846	Economy	35300.00
0005433568158	11846	Economy	35300.00
0005433568175	11846	Economy	35300.00
0005433568180	11846	Economy	35300.00
0005433568176	11846	Economy	35300.00
0005433568187	11846	Economy	35300.00
0005433568155	11846	Economy	35300.00
0005433568181	11846	Economy	35300.00
0005433568182	11846	Economy	35300.00
0005433568154	11846	Economy	35300.00
0005433568168	11846	Economy	35300.00
0005433568190	11846	Economy	35300.00
0005433568130	11846	Economy	35300.00
0005433568156	11846	Economy	35300.00
0005433568170	11846	Economy	35300.00
0005433568161	11846	Economy	35300.00
0005433568172	11846	Economy	35300.00
0005433568164	11846	Economy	35300.00
0005433568129	11846	Economy	35300.00
0005433568146	11846	Economy	35300.00
0005433568185	11846	Economy	35300.00
0005433568132	11846	Economy	35300.00
0005433568186	11846	Economy	35300.00
0005433568137	11846	Economy	35300.00
0005433568140	11846	Economy	35300.00
0005433568165	11846	Economy	35300.00
0005433568143	11846	Economy	35300.00
0005433568131	11846	Economy	35300.00
0005433568135	11846	Economy	35300.00
0005433568178	11846	Economy	35300.00
0005433568162	11846	Economy	35300.00
0005433568147	11846	Economy	35300.00
0005433568167	11846	Economy	35300.00
0005433568139	11846	Economy	35300.00
0005433568173	11846	Economy	35300.00
0005432947920	25281	Business	105900.00
0005432947926	25281	Business	105900.00
0005432947929	25281	Business	105900.00
0005432947897	25281	Business	105900.00
0005432947889	25281	Business	105900.00
0005432947922	25281	Business	105900.00
0005432947916	25281	Business	105900.00
0005432947894	25281	Business	105900.00
0005432947919	25281	Business	105900.00
0005432947903	25281	Business	105900.00
0005432947891	25281	Economy	35300.00
0005432947912	25281	Economy	35300.00
0005432947904	25281	Economy	35300.00
0005432947921	25281	Economy	35300.00
0005432947917	25281	Economy	35300.00
0005432947896	25281	Economy	35300.00
0005432947901	25281	Economy	35300.00
0005432947905	25281	Economy	35300.00
0005432947899	25281	Economy	35300.00
0005432947893	25281	Economy	35300.00
0005432947927	25281	Economy	35300.00
0005432947911	25281	Economy	35300.00
0005432947918	25281	Economy	35300.00
0005432947924	25281	Economy	35300.00
0005432947925	25281	Economy	35300.00
0005432947902	25281	Economy	35300.00
0005432947907	25281	Economy	35300.00
0005432947909	25281	Economy	35300.00
0005432947898	25281	Economy	35300.00
0005432947892	25281	Economy	35300.00
0005432947906	25281	Economy	35300.00
0005432947908	25281	Economy	35300.00
0005432947914	25281	Economy	35300.00
0005432947915	25281	Economy	35300.00
0005432947890	25281	Economy	35300.00
0005432947913	25281	Economy	35300.00
0005432947923	25281	Economy	35300.00
0005432947895	25281	Economy	35300.00
0005432947900	25281	Economy	35300.00
0005432947928	25281	Economy	35300.00
0005432947910	25281	Economy	35300.00
0005433808317	30824	Business	117400.00
0005433808313	30824	Business	117400.00
0005433808310	30824	Business	117400.00
0005433812862	30824	Economy	39100.00
0005433812860	30824	Economy	39100.00
0005433808314	30824	Economy	39100.00
0005433812857	30824	Economy	39100.00
0005433808316	30824	Economy	39100.00
0005433812858	30824	Economy	39100.00
0005433808311	30824	Economy	39100.00
0005433812859	30824	Economy	39100.00
0005433808312	30824	Economy	39100.00
0005433808318	30824	Economy	39100.00
0005433808319	30824	Economy	39100.00
0005433812861	30824	Economy	39100.00
0005433808315	30824	Economy	39100.00
0005433812863	30824	Economy	39100.00
0005434654270	5384	Business	67200.00
0005432114157	5384	Business	67200.00
0005434654253	5384	Business	67200.00
0005434654272	5384	Business	67200.00
0005434654268	5384	Economy	22400.00
0005434654266	5384	Economy	22400.00
0005434654251	5384	Economy	22400.00
0005434654267	5384	Economy	22400.00
0005434654264	5384	Economy	22400.00
0005434654250	5384	Economy	24600.00
0005434654260	5384	Economy	24600.00
0005434654255	5384	Economy	22400.00
0005434654276	5384	Economy	22400.00
0005434654262	5384	Economy	22400.00
0005434656526	5384	Economy	22400.00
0005434654271	5384	Economy	22400.00
0005434654278	5384	Economy	22400.00
0005434654252	5384	Economy	22400.00
0005434654280	5384	Economy	22400.00
0005434654277	5384	Economy	22400.00
0005434654257	5384	Economy	22400.00
0005434654279	5384	Economy	22400.00
0005434654274	5384	Economy	22400.00
0005432114156	5384	Economy	22400.00
0005434654254	5384	Economy	22400.00
0005434656527	5384	Economy	22400.00
0005434654269	5384	Economy	22400.00
0005434654259	5384	Economy	22400.00
0005434654249	5384	Economy	22400.00
0005434654258	5384	Economy	22400.00
0005434654275	5384	Economy	22400.00
0005434654263	5384	Economy	22400.00
0005434654256	5384	Economy	22400.00
0005432114155	5384	Economy	22400.00
0005434654265	5384	Economy	22400.00
0005434654261	5384	Economy	22400.00
0005434654273	5384	Economy	22400.00
0005435340045	12510	Business	67200.00
0005435555341	12510	Business	67200.00
0005435340044	12510	Business	67200.00
0005435340047	12510	Economy	22400.00
0005435340038	12510	Economy	22400.00
0005435340041	12510	Economy	22400.00
0005435340049	12510	Economy	22400.00
0005435340039	12510	Economy	22400.00
0005435340043	12510	Economy	22400.00
0005435340037	12510	Economy	22400.00
0005435340046	12510	Economy	22400.00
0005435340050	12510	Economy	22400.00
0005435340035	12510	Economy	22400.00
0005435340048	12510	Economy	22400.00
0005435340036	12510	Economy	22400.00
0005435340042	12510	Economy	22400.00
0005435340040	12510	Economy	22400.00
0005433715221	7465	Business	32000.00
0005433715267	7465	Business	32000.00
0005433722120	7465	Business	32000.00
0005433715254	7465	Economy	10700.00
0005433715243	7465	Business	32000.00
0005433690895	7465	Economy	10700.00
0005433656619	7465	Economy	10700.00
0005433715235	7465	Economy	10700.00
0005433715256	7465	Economy	10700.00
0005433715223	7465	Economy	10700.00
0005432078031	7465	Economy	10700.00
0005433715236	7465	Economy	10700.00
0005433715251	7465	Economy	10700.00
0005433715268	7465	Economy	10700.00
0005433715237	7465	Economy	10700.00
0005433688778	7465	Economy	10700.00
0005433715242	7465	Economy	10700.00
0005433722118	7465	Economy	10700.00
0005433689881	7465	Economy	10700.00
0005433715247	7465	Economy	10700.00
0005433689878	7465	Economy	10700.00
0005432078028	7465	Economy	10700.00
0005433715241	7465	Economy	10700.00
0005433715264	7465	Economy	10700.00
0005433715261	7465	Economy	10700.00
0005433715230	7465	Economy	10700.00
0005433715238	7465	Economy	10700.00
0005433715233	7465	Economy	11700.00
0005432078029	7465	Economy	11700.00
0005433715226	7465	Economy	11700.00
0005433715270	7465	Economy	11700.00
0005433715240	7465	Economy	11700.00
0005433715269	7465	Economy	10700.00
0005433715266	7465	Economy	10700.00
0005433690896	7465	Economy	10700.00
0005433715259	7465	Economy	10700.00
0005433689879	7465	Economy	10700.00
0005433715265	7465	Economy	10700.00
0005432078025	7465	Economy	10700.00
0005433715262	7465	Economy	10700.00
0005433715228	7465	Economy	10700.00
0005432078027	7465	Economy	10700.00
0005432078026	7465	Economy	10700.00
0005433690894	7465	Economy	10700.00
0005433688777	7465	Economy	10700.00
0005432078030	7465	Economy	10700.00
0005433715244	7465	Economy	10700.00
0005433715232	7465	Economy	10700.00
0005433689880	7465	Economy	10700.00
0005433719089	7465	Economy	10700.00
0005433715253	7465	Economy	10700.00
0005433715245	7465	Economy	10700.00
0005433715220	7465	Economy	10700.00
0005433715249	7465	Economy	10700.00
0005433719090	7465	Economy	10700.00
0005433715263	7465	Economy	10700.00
0005433715227	7465	Economy	10700.00
0005433719088	7465	Economy	10700.00
0005433715222	7465	Economy	10700.00
0005433715252	7465	Economy	10700.00
0005433715255	7465	Economy	10700.00
0005433715257	7465	Economy	10700.00
0005433715234	7465	Economy	10700.00
0005433656618	7465	Economy	10700.00
0005433715248	7465	Economy	10700.00
0005433722119	7465	Economy	10700.00
0005433715239	7465	Economy	10700.00
0005433715260	7465	Economy	10700.00
0005433715224	7465	Economy	10700.00
0005433715231	7465	Economy	10700.00
0005433715246	7465	Economy	10700.00
0005433719091	7465	Economy	10700.00
0005433656620	7465	Economy	10700.00
0005433715258	7465	Economy	10700.00
0005433715225	7465	Economy	10700.00
0005433715250	7465	Economy	10700.00
0005433715229	7465	Economy	10700.00
0005432428879	29250	Business	32000.00
0005435266078	29250	Economy	10700.00
0005435266075	29250	Economy	10700.00
0005435266076	29250	Economy	10700.00
0005435266079	29250	Economy	10700.00
0005432428880	29250	Economy	10700.00
0005432006719	29250	Economy	10700.00
0005435266077	29250	Economy	10700.00
0005434095069	8677	Business	36500.00
0005434095071	8677	Economy	12200.00
0005434095062	8677	Economy	12200.00
0005434095065	8677	Economy	12200.00
0005434095066	8677	Economy	12200.00
0005434095060	8677	Economy	12200.00
0005434095063	8677	Economy	12200.00
0005434095072	8677	Economy	12200.00
0005434095067	8677	Economy	12200.00
0005434095070	8677	Economy	12200.00
0005434095064	8677	Economy	12200.00
0005434095061	8677	Economy	12200.00
0005434095068	8677	Economy	12200.00
0005434095059	8677	Economy	12200.00
0005434095073	8677	Economy	12200.00
0005434181997	11642	Business	36500.00
0005434182001	11642	Business	36500.00
0005434182003	11642	Economy	12200.00
0005434182005	11642	Economy	12200.00
0005434182007	11642	Economy	13400.00
0005434184633	11642	Economy	13400.00
0005434183548	11642	Economy	12200.00
0005434181998	11642	Economy	12200.00
0005434183549	11642	Economy	12200.00
0005434181999	11642	Economy	12200.00
0005434181995	11642	Economy	12200.00
0005434182002	11642	Economy	12200.00
0005434184634	11642	Economy	12200.00
0005434182004	11642	Economy	12200.00
0005434181996	11642	Economy	12200.00
0005434184635	11642	Economy	12200.00
0005434182000	11642	Economy	12200.00
0005434182006	11642	Economy	12200.00
0005435732154	1443	Business	33000.00
0005432297239	1443	Business	33000.00
0005433456909	1443	Business	33000.00
0005432297240	1443	Business	33000.00
0005433456911	1443	Economy	11000.00
0005432297238	1443	Economy	11000.00
0005435732156	1443	Economy	11000.00
0005435732157	1443	Economy	12100.00
0005435732152	1443	Economy	11000.00
0005433456910	1443	Economy	11000.00
0005435732153	1443	Economy	11000.00
0005435732155	1443	Economy	11000.00
0005435732160	1443	Economy	11000.00
0005435732161	1443	Economy	11000.00
0005435732158	1443	Economy	11000.00
0005435732159	1443	Economy	11000.00
0005432906500	19230	Business	33000.00
0005433397376	19230	Business	33000.00
0005433397352	19230	Business	33000.00
0005433397368	19230	Business	33000.00
0005433397332	19230	Business	33000.00
0005432906498	19230	Business	33000.00
0005433397344	19230	Business	33000.00
0005433397328	19230	Business	33000.00
0005433397360	19230	Business	33000.00
0005433397341	19230	Economy	11000.00
0005433397346	19230	Economy	11000.00
0005433397342	19230	Economy	11000.00
0005433397338	19230	Economy	11000.00
0005433397358	19230	Economy	11000.00
0005432906499	19230	Economy	12100.00
0005433397337	19230	Economy	12100.00
0005433397365	19230	Economy	12100.00
0005433397356	19230	Economy	11000.00
0005433397340	19230	Economy	11000.00
0005433397335	19230	Economy	11000.00
0005433397362	19230	Economy	11000.00
0005433397347	19230	Economy	11000.00
0005433397349	19230	Economy	11000.00
0005433397377	19230	Economy	11000.00
0005433397345	19230	Economy	11000.00
0005433397353	19230	Economy	11000.00
0005433397339	19230	Economy	11000.00
0005433397367	19230	Economy	11000.00
0005433397370	19230	Economy	11000.00
0005433397348	19230	Economy	11000.00
0005433397354	19230	Economy	11000.00
0005433397361	19230	Economy	11000.00
0005433397333	19230	Economy	11000.00
0005433397366	19230	Economy	11000.00
0005433397363	19230	Economy	11000.00
0005433397355	19230	Economy	11000.00
0005433397375	19230	Economy	11000.00
0005433397359	19230	Economy	11000.00
0005433397351	19230	Economy	11000.00
0005433397374	19230	Economy	11000.00
0005433397329	19230	Economy	11000.00
0005433397378	19230	Economy	11000.00
0005433397371	19230	Economy	11000.00
0005433397350	19230	Economy	11000.00
0005433397336	19230	Economy	11000.00
0005433397369	19230	Economy	11000.00
0005433397373	19230	Economy	11000.00
0005433397372	19230	Economy	11000.00
0005433397357	19230	Economy	11000.00
0005433397364	19230	Economy	11000.00
0005433397330	19230	Economy	11000.00
0005433397343	19230	Economy	11000.00
0005433397334	19230	Economy	11000.00
0005433397331	19230	Economy	11000.00
0005434443465	20575	Economy	15600.00
0005434443462	20575	Economy	15600.00
0005434443471	20575	Economy	14100.00
0005434443467	20575	Economy	14100.00
0005434443461	20575	Economy	14100.00
0005434443460	20575	Economy	14100.00
0005434443472	20575	Economy	14100.00
0005434443458	20575	Economy	14100.00
0005434443456	20575	Economy	14100.00
0005434443470	20575	Economy	14100.00
0005434443463	20575	Economy	14100.00
0005434443468	20575	Economy	14100.00
0005434443464	20575	Economy	14100.00
0005434443457	20575	Economy	14100.00
0005434443459	20575	Economy	14100.00
0005434443466	20575	Economy	14100.00
0005434443469	20575	Economy	14100.00
0005434954553	7232	Economy	5800.00
0005434954551	7232	Economy	5800.00
0005434954552	7232	Economy	5800.00
0005435377545	28344	Economy	5800.00
0005435377544	28344	Economy	5800.00
0005434351512	4473	Economy	14000.00
0005434351504	4473	Economy	14000.00
0005434351508	4473	Economy	14000.00
0005434351515	4473	Economy	14000.00
0005434351514	4473	Economy	14000.00
0005434351506	4473	Economy	14000.00
0005434351507	4473	Economy	14000.00
0005434351510	4473	Economy	14000.00
0005434326260	4473	Economy	14000.00
0005434351511	4473	Economy	14000.00
0005434351503	4473	Economy	14000.00
0005434351509	4473	Economy	14000.00
0005434351513	4473	Economy	14000.00
0005434351505	4473	Economy	14000.00
0005434326259	4473	Economy	14000.00
0005435893526	29640	Economy	14000.00
0005435893531	29640	Economy	14000.00
0005435893528	29640	Economy	14000.00
0005435893527	29640	Economy	14000.00
0005435893532	29640	Economy	14000.00
0005435893529	29640	Economy	14000.00
0005435893530	29640	Economy	14000.00
0005435893525	29640	Economy	14000.00
0005435893524	29640	Economy	14000.00
0005433463869	1077	Business	30600.00
0005434445214	1077	Business	30600.00
0005435545630	1077	Business	30600.00
0005432293173	1077	Economy	10200.00
0005435545633	1077	Economy	10200.00
0005435091930	1077	Economy	10200.00
0005432293172	1077	Economy	10200.00
0005435545619	1077	Economy	10200.00
0005435091924	1077	Economy	10200.00
0005435545620	1077	Economy	10200.00
0005435091929	1077	Economy	10200.00
0005435545618	1077	Economy	10200.00
0005435545623	1077	Economy	10200.00
0005435091927	1077	Economy	10200.00
0005435545627	1077	Economy	10200.00
0005435545631	1077	Economy	10200.00
0005435091926	1077	Economy	10200.00
0005435545625	1077	Economy	10200.00
0005433462716	1077	Economy	10200.00
0005435545621	1077	Economy	10200.00
0005435545617	1077	Economy	10200.00
0005433462715	1077	Economy	10200.00
0005435091931	1077	Economy	10200.00
0005435545629	1077	Economy	10200.00
0005435545632	1077	Economy	10200.00
0005435091928	1077	Economy	10200.00
0005435091925	1077	Economy	10200.00
0005435545628	1077	Economy	10200.00
0005435545635	1077	Economy	10200.00
0005435545622	1077	Economy	10200.00
0005435545634	1077	Economy	10200.00
0005435091932	1077	Economy	10200.00
0005435545624	1077	Economy	10200.00
0005433463868	1077	Economy	10200.00
0005433462714	1077	Economy	10200.00
0005432293171	1077	Economy	10200.00
0005435545626	1077	Economy	10200.00
0005433341614	17040	Business	30600.00
0005433341623	17040	Business	30600.00
0005433341622	17040	Business	30600.00
0005433341588	17040	Business	30600.00
0005433341650	17040	Business	30600.00
0005433341630	17040	Business	30600.00
0005433341592	17040	Business	30600.00
0005433341633	17040	Business	30600.00
0005433341590	17040	Business	30600.00
0005433341615	17040	Business	30600.00
0005433341670	17040	Business	30600.00
0005433341671	17040	Business	30600.00
0005433159279	17040	Business	30600.00
0005433341663	17040	Business	30600.00
0005433341591	17040	Economy	11200.00
0005433341583	17040	Economy	11200.00
0005433341644	17040	Economy	11200.00
0005433341603	17040	Economy	10200.00
0005433269639	17040	Economy	10200.00
0005433341638	17040	Economy	10200.00
0005433341627	17040	Economy	10200.00
0005433341596	17040	Economy	10200.00
0005433341647	17040	Economy	10200.00
0005433341674	17040	Economy	10200.00
0005435091894	17040	Economy	10200.00
0005433341604	17040	Economy	10200.00
0005433341660	17040	Economy	10200.00
0005433341678	17040	Economy	10200.00
0005433341665	17040	Economy	10200.00
0005433341677	17040	Economy	10200.00
0005433341662	17040	Economy	10200.00
0005433341675	17040	Economy	10200.00
0005433341676	17040	Economy	10200.00
0005433341680	17040	Economy	10200.00
0005433341599	17040	Economy	10200.00
0005433341683	17040	Economy	10200.00
0005433341639	17040	Economy	10200.00
0005433269638	17040	Economy	10200.00
0005433341666	17040	Economy	10200.00
0005433341617	17040	Economy	10200.00
0005433341606	17040	Economy	10200.00
0005433341624	17040	Economy	10200.00
0005433341612	17040	Economy	10200.00
0005433341618	17040	Economy	10200.00
0005433341625	17040	Economy	10200.00
0005433269637	17040	Economy	10200.00
0005433341611	17040	Economy	10200.00
0005433341651	17040	Economy	10200.00
0005433341629	17040	Economy	10200.00
0005433341664	17040	Economy	10200.00
0005433341679	17040	Economy	10200.00
0005433341602	17040	Economy	10200.00
0005433341605	17040	Economy	10200.00
0005433341657	17040	Economy	10200.00
0005433341667	17040	Economy	10200.00
0005433269642	17040	Economy	10200.00
0005433269636	17040	Economy	10200.00
0005433341619	17040	Economy	10200.00
0005433341673	17040	Economy	10200.00
0005433341608	17040	Economy	10200.00
0005433341672	17040	Economy	10200.00
0005433341653	17040	Economy	10200.00
0005433269641	17040	Economy	10200.00
0005433341634	17040	Economy	10200.00
0005433341600	17040	Economy	10200.00
0005433341681	17040	Economy	10200.00
0005433341682	17040	Economy	10200.00
0005433341585	17040	Economy	10200.00
0005433341621	17040	Economy	10200.00
0005433341669	17040	Economy	10200.00
0005433341594	17040	Economy	11200.00
0005433341642	17040	Economy	11200.00
0005433341643	17040	Economy	11200.00
0005433341589	17040	Economy	10200.00
0005433341584	17040	Economy	10200.00
0005433341620	17040	Economy	10200.00
0005433341656	17040	Economy	10200.00
0005433341646	17040	Economy	10200.00
0005433341613	17040	Economy	10200.00
0005433341668	17040	Economy	10200.00
0005433341640	17040	Economy	10200.00
0005433341607	17040	Economy	10200.00
0005433159280	17040	Economy	10200.00
0005433341641	17040	Economy	10200.00
0005433341637	17040	Economy	10200.00
0005433341658	17040	Economy	10200.00
0005433341628	17040	Economy	10200.00
0005433341635	17040	Economy	10200.00
0005433341661	17040	Economy	10200.00
0005433341652	17040	Economy	10200.00
0005433341595	17040	Economy	10200.00
0005433341632	17040	Economy	10200.00
0005433341587	17040	Economy	10200.00
0005433341597	17040	Economy	10200.00
0005433341645	17040	Economy	10200.00
0005433341655	17040	Economy	10200.00
0005433341586	17040	Economy	10200.00
0005433341659	17040	Economy	10200.00
0005433341609	17040	Economy	10200.00
0005433341636	17040	Economy	10200.00
0005433341598	17040	Economy	10200.00
0005433269640	17040	Economy	10200.00
0005433341626	17040	Economy	10200.00
0005433341631	17040	Economy	10200.00
0005433341593	17040	Economy	10200.00
0005433341601	17040	Economy	10200.00
0005433341616	17040	Economy	10200.00
0005433341654	17040	Economy	10200.00
0005433341649	17040	Economy	10200.00
0005433341648	17040	Economy	10200.00
0005433341610	17040	Economy	10200.00
0005432851832	18274	Business	101000.00
0005432851826	18274	Business	101000.00
0005432851837	18274	Business	101000.00
0005432851839	18274	Business	101000.00
0005432851829	18274	Economy	33700.00
0005432851823	18274	Economy	33700.00
0005432851825	18274	Economy	33700.00
0005432851830	18274	Economy	33700.00
0005432851827	18274	Economy	33700.00
0005432851824	18274	Economy	33700.00
0005432851836	18274	Economy	33700.00
0005432851840	18274	Economy	33700.00
0005432851828	18274	Economy	33700.00
0005432851838	18274	Economy	33700.00
0005432851821	18274	Economy	33700.00
0005432851833	18274	Economy	33700.00
0005432851834	18274	Economy	33700.00
0005432851831	18274	Economy	33700.00
0005432851822	18274	Economy	33700.00
0005432851835	18274	Economy	33700.00
0005433812864	12798	Business	40300.00
0005432161117	12798	Economy	13400.00
0005433812866	12798	Economy	13400.00
0005432161118	12798	Economy	13400.00
0005432433604	12798	Economy	14800.00
0005432433600	12798	Economy	13400.00
0005432159788	12798	Economy	13400.00
0005432159792	12798	Economy	13400.00
0005432159790	12798	Economy	13400.00
0005433812865	12798	Economy	13400.00
0005432159789	12798	Economy	13400.00
0005432433602	12798	Economy	13400.00
0005432159791	12798	Economy	13400.00
0005432433598	12798	Economy	13400.00
0005432433599	12798	Economy	13400.00
0005432433603	12798	Economy	13400.00
0005432433601	12798	Economy	13400.00
0005434066447	30684	Business	40300.00
0005434066467	30684	Business	40300.00
0005434066444	30684	Business	40300.00
0005434081531	30684	Business	40300.00
0005434066465	30684	Business	40300.00
0005434066461	30684	Business	40300.00
0005434066480	30684	Business	40300.00
0005434066449	30684	Business	40300.00
0005434066471	30684	Business	40300.00
0005434066495	30684	Business	40300.00
0005434066484	30684	Business	40300.00
0005432150075	30684	Business	40300.00
0005434081541	30684	Economy	13400.00
0005434081538	30684	Economy	13400.00
0005434081533	30684	Economy	13400.00
0005434081530	30684	Economy	13400.00
0005434066440	30684	Economy	13400.00
0005434066493	30684	Economy	13400.00
0005434066479	30684	Economy	13400.00
0005432150077	30684	Economy	13400.00
0005434066442	30684	Economy	13400.00
0005432186811	30684	Economy	13400.00
0005434081534	30684	Economy	13400.00
0005434066501	30684	Economy	13400.00
0005434081543	30684	Economy	13400.00
0005434066457	30684	Economy	13400.00
0005434066487	30684	Economy	13400.00
0005434081535	30684	Economy	13400.00
0005433989698	30684	Economy	13400.00
0005434066475	30684	Economy	13400.00
0005434066474	30684	Economy	13400.00
0005434066441	30684	Economy	13400.00
0005434066505	30684	Economy	13400.00
0005433989699	30684	Economy	13400.00
0005434066443	30684	Economy	13400.00
0005434081529	30684	Economy	13400.00
0005434066507	30684	Economy	13400.00
0005434066497	30684	Economy	13400.00
0005434066469	30684	Economy	13400.00
0005434066454	30684	Economy	13400.00
0005434066448	30684	Economy	13400.00
0005434066482	30684	Economy	13400.00
0005434066498	30684	Economy	13400.00
0005434066470	30684	Economy	13400.00
0005432150071	30684	Economy	13400.00
0005434066504	30684	Economy	14800.00
0005434066476	30684	Economy	14800.00
0005434081539	30684	Economy	14800.00
0005434066462	30684	Economy	14800.00
0005434081540	30684	Economy	14800.00
0005434066453	30684	Economy	13400.00
0005434066481	30684	Economy	13400.00
0005434066446	30684	Economy	13400.00
0005434081542	30684	Economy	13400.00
0005434066491	30684	Economy	13400.00
0005434066509	30684	Economy	13400.00
0005434066500	30684	Economy	13400.00
0005434081537	30684	Economy	13400.00
0005434081545	30684	Economy	13400.00
0005434066472	30684	Economy	13400.00
0005434066463	30684	Economy	13400.00
0005434066473	30684	Economy	13400.00
0005434066477	30684	Economy	13400.00
0005432150073	30684	Economy	13400.00
0005434066464	30684	Economy	13400.00
0005434066489	30684	Economy	13400.00
0005432150076	30684	Economy	13400.00
0005434081528	30684	Economy	13400.00
0005434066456	30684	Economy	13400.00
0005434066466	30684	Economy	13400.00
0005434081522	30684	Economy	13400.00
0005434081549	30684	Economy	13400.00
0005434066451	30684	Economy	13400.00
0005434066496	30684	Economy	13400.00
0005434066508	30684	Economy	13400.00
0005434081548	30684	Economy	13400.00
0005434066510	30684	Economy	13400.00
0005434066503	30684	Economy	13400.00
0005432186812	30684	Economy	13400.00
0005432150072	30684	Economy	13400.00
0005434066502	30684	Economy	13400.00
0005434066452	30684	Economy	13400.00
0005434066445	30684	Economy	13400.00
0005432186813	30684	Economy	13400.00
0005434066499	30684	Economy	13400.00
0005434066494	30684	Economy	13400.00
0005434066483	30684	Economy	13400.00
0005434081524	30684	Economy	13400.00
0005434066460	30684	Economy	13400.00
0005433989695	30684	Economy	13400.00
0005434066478	30684	Economy	13400.00
0005434066511	30684	Economy	13400.00
0005434081547	30684	Economy	13400.00
0005434066486	30684	Economy	13400.00
0005433989696	30684	Economy	13400.00
0005434066488	30684	Economy	13400.00
0005434066468	30684	Economy	13400.00
0005434081525	30684	Economy	13400.00
0005434081536	30684	Economy	13400.00
0005434081521	30684	Economy	13400.00
0005434081526	30684	Economy	13400.00
0005434081544	30684	Economy	13400.00
0005434066490	30684	Economy	13400.00
0005434066450	30684	Economy	13400.00
0005432150074	30684	Economy	13400.00
0005434081523	30684	Economy	13400.00
0005433989697	30684	Economy	13400.00
0005434066485	30684	Economy	13400.00
0005434066492	30684	Economy	13400.00
0005434081527	30684	Economy	13400.00
0005434081550	30684	Economy	13400.00
0005434066458	30684	Economy	13400.00
0005432186814	30684	Economy	13400.00
0005434081546	30684	Economy	13400.00
0005434066459	30684	Economy	13400.00
0005434081532	30684	Economy	13400.00
0005434066506	30684	Economy	13400.00
0005434066455	30684	Economy	13400.00
0005433685498	9048	Economy	19300.00
0005433686609	9048	Economy	17600.00
0005433685497	9048	Economy	17600.00
0005433685494	9048	Economy	17600.00
0005433687679	9048	Economy	17600.00
0005433685491	9048	Economy	17600.00
0005433686607	9048	Economy	17600.00
0005433685492	9048	Economy	17600.00
0005433686602	9048	Economy	17600.00
0005433687675	9048	Economy	17600.00
0005433686603	9048	Economy	17600.00
0005433687678	9048	Economy	17600.00
0005433686606	9048	Economy	17600.00
0005433686605	9048	Economy	17600.00
0005433687677	9048	Economy	17600.00
0005433687680	9048	Economy	17600.00
0005433687681	9048	Economy	17600.00
0005433685499	9048	Economy	17600.00
0005433687676	9048	Economy	17600.00
0005433685493	9048	Economy	17600.00
0005433685496	9048	Economy	17600.00
0005433686608	9048	Economy	17600.00
0005433686604	9048	Economy	17600.00
0005433685495	9048	Economy	17600.00
0005435765308	5505	Business	35300.00
0005433529222	5505	Business	35300.00
0005435723015	5505	Business	35300.00
0005435765291	5505	Business	35300.00
0005435765344	5505	Business	35300.00
0005435765294	5505	Business	35300.00
0005435765323	5505	Business	35300.00
0005432140331	5505	Business	35300.00
0005435765296	5505	Business	35300.00
0005435765324	5505	Business	35300.00
0005433527213	5505	Business	35300.00
0005433529225	5505	Business	35300.00
0005435765289	5505	Economy	12900.00
0005435765334	5505	Economy	11800.00
0005435725522	5505	Economy	11800.00
0005435765295	5505	Economy	11800.00
0005435765339	5505	Economy	11800.00
0005435725526	5505	Economy	11800.00
0005435765311	5505	Economy	11800.00
0005432140326	5505	Economy	11800.00
0005435735067	5505	Economy	11800.00
0005435735065	5505	Economy	11800.00
0005435765340	5505	Economy	11800.00
0005435765331	5505	Economy	11800.00
0005435765299	5505	Economy	11800.00
0005435765301	5505	Economy	11800.00
0005435765307	5505	Economy	11800.00
0005435725525	5505	Economy	11800.00
0005432140328	5505	Economy	11800.00
0005435765302	5505	Economy	11800.00
0005433529223	5505	Economy	11800.00
0005435765293	5505	Economy	11800.00
0005435765346	5505	Economy	11800.00
0005435765303	5505	Economy	11800.00
0005435765305	5505	Economy	11800.00
0005435765325	5505	Economy	11800.00
0005435765345	5505	Economy	11800.00
0005435765326	5505	Economy	11800.00
0005435765300	5505	Economy	11800.00
0005432140324	5505	Economy	11800.00
0005435765314	5505	Economy	11800.00
0005435765309	5505	Economy	11800.00
0005435725521	5505	Economy	11800.00
0005435765341	5505	Economy	11800.00
0005433527214	5505	Economy	11800.00
0005435765312	5505	Economy	11800.00
0005435765338	5505	Economy	11800.00
0005435765298	5505	Economy	11800.00
0005435723013	5505	Economy	11800.00
0005435765304	5505	Economy	11800.00
0005435725524	5505	Economy	11800.00
0005435765327	5505	Economy	11800.00
0005435765320	5505	Economy	11800.00
0005435765316	5505	Economy	11800.00
0005435765336	5505	Economy	11800.00
0005435765319	5505	Economy	11800.00
0005435722020	5505	Economy	11800.00
0005435722021	5505	Economy	12900.00
0005435765306	5505	Economy	11800.00
0005432140323	5505	Economy	12900.00
0005435765310	5505	Economy	11800.00
0005435725523	5505	Economy	11800.00
0005435765317	5505	Economy	11800.00
0005435765342	5505	Economy	11800.00
0005433527212	5505	Economy	11800.00
0005435765333	5505	Economy	11800.00
0005435723014	5505	Economy	11800.00
0005433527211	5505	Economy	11800.00
0005435720807	5505	Economy	11800.00
0005435765313	5505	Economy	11800.00
0005435765322	5505	Economy	11800.00
0005435765321	5505	Economy	11800.00
0005435765343	5505	Economy	11800.00
0005435765337	5505	Economy	11800.00
0005435765292	5505	Economy	11800.00
0005432140325	5505	Economy	11800.00
0005435765335	5505	Economy	11800.00
0005435765328	5505	Economy	11800.00
0005435735068	5505	Economy	11800.00
0005432140330	5505	Economy	11800.00
0005435765330	5505	Economy	11800.00
0005435765318	5505	Economy	11800.00
0005435735069	5505	Economy	11800.00
0005432140327	5505	Economy	11800.00
0005435765315	5505	Economy	11800.00
0005435765290	5505	Economy	11800.00
0005435735066	5505	Economy	11800.00
0005432140329	5505	Economy	11800.00
0005435765329	5505	Economy	11800.00
0005435765297	5505	Economy	11800.00
0005433529224	5505	Economy	11800.00
0005435765332	5505	Economy	11800.00
0005435461900	13486	Business	35300.00
0005435461902	13486	Business	35300.00
0005434264773	13486	Business	35300.00
0005434264768	13486	Business	35300.00
0005432194451	13486	Business	35300.00
0005435461880	13486	Business	35300.00
0005434264755	13486	Economy	12900.00
0005434264766	13486	Economy	11800.00
0005434264757	13486	Economy	11800.00
0005434831082	13486	Economy	11800.00
0005434264776	13486	Economy	11800.00
0005435617167	13486	Economy	11800.00
0005434264758	13486	Economy	11800.00
0005434264769	13486	Economy	11800.00
0005434264765	13486	Economy	11800.00
0005435461881	13486	Economy	11800.00
0005435461878	13486	Economy	11800.00
0005435461882	13486	Economy	11800.00
0005435461905	13486	Economy	11800.00
0005435461883	13486	Economy	11800.00
0005435461886	13486	Economy	11800.00
0005434264772	13486	Economy	11800.00
0005434264764	13486	Economy	11800.00
0005434264780	13486	Economy	11800.00
0005435461904	13486	Economy	11800.00
0005435461894	13486	Economy	11800.00
0005434264767	13486	Economy	11800.00
0005432535762	13486	Economy	11800.00
0005435461892	13486	Economy	11800.00
0005434831084	13486	Economy	11800.00
0005435461873	13486	Economy	11800.00
0005434264759	13486	Economy	11800.00
0005435617168	13486	Economy	11800.00
0005434264760	13486	Economy	11800.00
0005434264771	13486	Economy	11800.00
0005432194448	13486	Economy	11800.00
0005435461897	13486	Economy	11800.00
0005435461909	13486	Economy	11800.00
0005435461907	13486	Economy	11800.00
0005434264756	13486	Economy	11800.00
0005434831085	13486	Economy	11800.00
0005435461874	13486	Economy	11800.00
0005434264774	13486	Economy	11800.00
0005434264763	13486	Economy	11800.00
0005435617166	13486	Economy	11800.00
0005434264754	13486	Economy	11800.00
0005435461896	13486	Economy	11800.00
0005435461889	13486	Economy	12900.00
0005432194449	13486	Economy	11800.00
0005434831083	13486	Economy	11800.00
0005434264777	13486	Economy	12900.00
0005435461906	13486	Economy	11800.00
0005435461888	13486	Economy	11800.00
0005432535763	13486	Economy	11800.00
0005435461893	13486	Economy	11800.00
0005435461891	13486	Economy	11800.00
0005434264778	13486	Economy	11800.00
0005435461890	13486	Economy	11800.00
0005434264779	13486	Economy	11800.00
0005435461901	13486	Economy	11800.00
0005432535761	13486	Economy	11800.00
0005434264761	13486	Economy	11800.00
0005434264770	13486	Economy	11800.00
0005434264775	13486	Economy	11800.00
0005435461885	13486	Economy	11800.00
0005435461875	13486	Economy	11800.00
0005435461895	13486	Economy	11800.00
0005435461884	13486	Economy	11800.00
0005435461876	13486	Economy	11800.00
0005435461908	13486	Economy	11800.00
0005432535765	13486	Economy	11800.00
0005435461903	13486	Economy	11800.00
0005434264762	13486	Economy	11800.00
0005432194450	13486	Economy	11800.00
0005432535764	13486	Economy	11800.00
0005435461877	13486	Economy	11800.00
0005435461899	13486	Economy	11800.00
0005435461887	13486	Economy	11800.00
0005432535760	13486	Economy	11800.00
0005435461910	13486	Economy	11800.00
0005435461879	13486	Economy	11800.00
0005435461898	13486	Economy	11800.00
0005434513539	18673	Economy	3300.00
0005434514927	18673	Economy	3300.00
0005434513540	18673	Economy	3300.00
0005434513538	18673	Economy	3300.00
0005434514928	18673	Economy	3300.00
0005434514926	18673	Economy	3300.00
0005434602864	19147	Economy	3300.00
0005434602858	19147	Economy	3300.00
0005434602862	19147	Economy	3300.00
0005434602867	19147	Economy	3300.00
0005434602865	19147	Economy	3300.00
0005434602859	19147	Economy	3300.00
0005434602863	19147	Economy	3300.00
0005434602860	19147	Economy	3300.00
0005434602866	19147	Economy	3300.00
0005434602861	19147	Economy	3300.00
0005433810498	1800	Business	48700.00
0005433810502	1800	Business	48700.00
0005432295841	1800	Economy	16200.00
0005432295843	1800	Economy	17900.00
0005433810497	1800	Economy	16200.00
0005433810496	1800	Economy	16200.00
0005433810500	1800	Economy	16200.00
0005433810503	1800	Economy	16200.00
0005433810499	1800	Economy	16200.00
0005433810501	1800	Economy	16200.00
0005433810504	1800	Economy	16200.00
0005432295840	1800	Economy	16200.00
0005432295842	1800	Economy	16200.00
0005433810505	1800	Economy	16200.00
0005433284825	22589	Business	48700.00
0005433007919	22589	Business	48700.00
0005433284838	22589	Business	48700.00
0005433007924	22589	Business	48700.00
0005433284842	22589	Business	48700.00
0005433007926	22589	Business	48700.00
0005433284836	22589	Business	48700.00
0005433007953	22589	Business	48700.00
0005433284832	22589	Business	48700.00
0005433007934	22589	Business	48700.00
0005433007932	22589	Economy	16200.00
0005433007943	22589	Economy	16200.00
0005433007946	22589	Economy	16200.00
0005433007937	22589	Economy	16200.00
0005433284831	22589	Economy	16200.00
0005433007958	22589	Economy	16200.00
0005433007948	22589	Economy	16200.00
0005433007915	22589	Economy	16200.00
0005433007933	22589	Economy	16200.00
0005433007931	22589	Economy	17900.00
0005433007935	22589	Economy	17900.00
0005433007951	22589	Economy	17900.00
0005433007921	22589	Economy	17900.00
0005433007941	22589	Economy	17900.00
0005433284844	22589	Economy	16200.00
0005433284822	22589	Economy	16200.00
0005433007916	22589	Economy	16200.00
0005433284826	22589	Economy	16200.00
0005433007956	22589	Economy	16200.00
0005433007955	22589	Economy	16200.00
0005433007936	22589	Economy	16200.00
0005433284827	22589	Economy	16200.00
0005433007952	22589	Economy	16200.00
0005433007949	22589	Economy	16200.00
0005433284841	22589	Economy	16200.00
0005433007917	22589	Economy	16200.00
0005433284821	22589	Economy	16200.00
0005433284829	22589	Economy	16200.00
0005433284828	22589	Economy	16200.00
0005433007960	22589	Economy	16200.00
0005433007938	22589	Economy	16200.00
0005433284830	22589	Economy	16200.00
0005433007945	22589	Economy	16200.00
0005433284839	22589	Economy	16200.00
0005433284845	22589	Economy	16200.00
0005433007939	22589	Economy	16200.00
0005433007950	22589	Economy	16200.00
0005433007920	22589	Economy	16200.00
0005433007957	22589	Economy	16200.00
0005433284823	22589	Economy	16200.00
0005433007954	22589	Economy	16200.00
0005433007944	22589	Economy	16200.00
0005433007959	22589	Economy	16200.00
0005433284840	22589	Economy	16200.00
0005433284834	22589	Economy	16200.00
0005433007947	22589	Economy	16200.00
0005433284835	22589	Economy	16200.00
0005433007925	22589	Economy	16200.00
0005433284824	22589	Economy	16200.00
0005433007922	22589	Economy	16200.00
0005433007942	22589	Economy	16200.00
0005433284833	22589	Economy	16200.00
0005433284846	22589	Economy	16200.00
0005433284837	22589	Economy	16200.00
0005433007929	22589	Economy	16200.00
0005433007940	22589	Economy	16200.00
0005433007927	22589	Economy	16200.00
0005433284843	22589	Economy	16200.00
0005433007918	22589	Economy	16200.00
0005433007930	22589	Economy	16200.00
0005433284847	22589	Economy	16200.00
0005433007923	22589	Economy	16200.00
0005433007928	22589	Economy	16200.00
0005433284848	22589	Economy	16200.00
0005432756788	25334	Business	83800.00
0005432756789	25334	Economy	30700.00
0005432756790	25334	Economy	30700.00
0005432755018	25334	Economy	27900.00
0005432756795	25334	Economy	27900.00
0005432756792	25334	Economy	27900.00
0005432755016	25334	Economy	27900.00
0005432755020	25334	Economy	27900.00
0005432755025	25334	Economy	27900.00
0005432755023	25334	Economy	27900.00
0005432755017	25334	Economy	27900.00
0005432755021	25334	Economy	27900.00
0005432755024	25334	Economy	27900.00
0005432756794	25334	Economy	27900.00
0005432755019	25334	Economy	27900.00
0005432755015	25334	Economy	27900.00
0005432756793	25334	Economy	27900.00
0005432756796	25334	Economy	27900.00
0005432756787	25334	Economy	27900.00
0005432755022	25334	Economy	27900.00
0005432756791	25334	Economy	27900.00
0005433845856	5556	Business	99800.00
0005433845901	5556	Business	99800.00
0005433845871	5556	Business	99800.00
0005433845900	5556	Business	99800.00
0005433845872	5556	Business	99800.00
0005433845854	5556	Business	99800.00
0005432081419	5556	Business	99800.00
0005432081416	5556	Business	99800.00
0005433845902	5556	Business	99800.00
0005433845892	5556	Business	99800.00
0005433845877	5556	Economy	33300.00
0005433845894	5556	Economy	33300.00
0005433845847	5556	Economy	33300.00
0005433845866	5556	Economy	33300.00
0005433815313	5556	Economy	33300.00
0005432081417	5556	Economy	33300.00
0005433845851	5556	Economy	33300.00
0005432081420	5556	Economy	36600.00
0005433845858	5556	Economy	33300.00
0005433845862	5556	Economy	33300.00
0005433845896	5556	Economy	33300.00
0005433845889	5556	Economy	33300.00
0005433845849	5556	Economy	33300.00
0005433845876	5556	Economy	33300.00
0005433815312	5556	Economy	33300.00
0005433845875	5556	Economy	33300.00
0005433845873	5556	Economy	33300.00
0005433815311	5556	Economy	33300.00
0005433845879	5556	Economy	33300.00
0005433845870	5556	Economy	33300.00
0005433845853	5556	Economy	33300.00
0005433845887	5556	Economy	33300.00
0005433845860	5556	Economy	33300.00
0005433845864	5556	Economy	33300.00
0005433845852	5556	Economy	33300.00
0005433845857	5556	Economy	33300.00
0005433845888	5556	Economy	33300.00
0005433845846	5556	Economy	33300.00
0005433845845	5556	Economy	33300.00
0005433845869	5556	Economy	33300.00
0005433845899	5556	Economy	33300.00
0005433845881	5556	Economy	33300.00
0005433845865	5556	Economy	33300.00
0005432081418	5556	Economy	33300.00
0005432081415	5556	Economy	33300.00
0005433845878	5556	Economy	33300.00
0005433845885	5556	Economy	33300.00
0005433845895	5556	Economy	33300.00
0005433845890	5556	Economy	33300.00
0005433845863	5556	Economy	33300.00
0005432081422	5556	Economy	33300.00
0005433845880	5556	Economy	33300.00
0005433845859	5556	Economy	33300.00
0005433815314	5556	Economy	33300.00
0005433845893	5556	Economy	33300.00
0005433845861	5556	Economy	33300.00
0005433845850	5556	Economy	33300.00
0005433845886	5556	Economy	33300.00
0005433845898	5556	Economy	33300.00
0005432081421	5556	Economy	33300.00
0005433845843	5556	Economy	33300.00
0005432081414	5556	Economy	33300.00
0005433845897	5556	Economy	33300.00
0005433845891	5556	Economy	33300.00
0005433845882	5556	Economy	33300.00
0005433845874	5556	Economy	33300.00
0005433845844	5556	Economy	33300.00
0005433845855	5556	Economy	33300.00
0005433845868	5556	Economy	33300.00
0005433815310	5556	Economy	33300.00
0005433845867	5556	Economy	33300.00
0005433845883	5556	Economy	33300.00
0005433845848	5556	Economy	33300.00
0005433845884	5556	Economy	33300.00
0005432003656	13874	Business	99800.00
0005435282146	13874	Business	99800.00
0005435282152	13874	Business	99800.00
0005435282140	13874	Business	99800.00
0005435282139	13874	Business	99800.00
0005435282130	13874	Business	99800.00
0005432003657	13874	Business	99800.00
0005435282144	13874	Business	99800.00
0005434173463	13874	Business	99800.00
0005434173462	13874	Business	99800.00
0005435282126	13874	Economy	33300.00
0005434173464	13874	Economy	33300.00
0005435282133	13874	Economy	33300.00
0005434173460	13874	Economy	33300.00
0005435282127	13874	Economy	33300.00
0005435282136	13874	Economy	33300.00
0005435282150	13874	Economy	33300.00
0005435282124	13874	Economy	33300.00
0005435282129	13874	Economy	33300.00
0005435282137	13874	Economy	33300.00
0005435282148	13874	Economy	33300.00
0005435282141	13874	Economy	33300.00
0005435282125	13874	Economy	33300.00
0005435282135	13874	Economy	33300.00
0005433845698	13874	Economy	33300.00
0005435282134	13874	Economy	33300.00
0005435282128	13874	Economy	33300.00
0005435282147	13874	Economy	33300.00
0005435282143	13874	Economy	33300.00
0005434173461	13874	Economy	33300.00
0005435282145	13874	Economy	33300.00
0005435282149	13874	Economy	33300.00
0005435282132	13874	Economy	33300.00
0005435282131	13874	Economy	33300.00
0005435282151	13874	Economy	33300.00
0005435282138	13874	Economy	33300.00
0005435282142	13874	Economy	33300.00
0005434620295	7800	Economy	16600.00
0005434620290	7800	Economy	16600.00
0005434620303	7800	Economy	16600.00
0005434620285	7800	Economy	15100.00
0005434620287	7800	Economy	15100.00
0005434620288	7800	Economy	15100.00
0005434620286	7800	Economy	15100.00
0005434620299	7800	Economy	15100.00
0005434620300	7800	Economy	15100.00
0005434620291	7800	Economy	15100.00
0005434620297	7800	Economy	15100.00
0005434620302	7800	Economy	15100.00
0005434620301	7800	Economy	15100.00
0005434620294	7800	Economy	15100.00
0005432112482	7800	Economy	15100.00
0005434620292	7800	Economy	15100.00
0005432112483	7800	Economy	15100.00
0005434620298	7800	Economy	15100.00
0005435332149	7800	Economy	15100.00
0005434620293	7800	Economy	15100.00
0005434620296	7800	Economy	15100.00
0005434620305	7800	Economy	15100.00
0005434620289	7800	Economy	15100.00
0005434620304	7800	Economy	15100.00
0005435332180	32975	Economy	15100.00
0005435332185	32975	Economy	15100.00
0005435332184	32975	Economy	15100.00
0005435332181	32975	Economy	15100.00
0005435332186	32975	Economy	15100.00
0005435332182	32975	Economy	15100.00
0005435332178	32975	Economy	15100.00
0005435332183	32975	Economy	15100.00
0005435332188	32975	Economy	15100.00
0005435332179	32975	Economy	15100.00
0005435332187	32975	Economy	15100.00
0005435784865	4300	Business	38000.00
0005435784850	4300	Business	38000.00
0005435784864	4300	Business	38000.00
0005435784855	4300	Business	38000.00
0005435784861	4300	Business	38000.00
0005435784852	4300	Business	38000.00
0005435784847	4300	Business	38000.00
0005434993876	4300	Economy	12700.00
0005432190572	4300	Economy	12700.00
0005435784857	4300	Economy	12700.00
0005435784836	4300	Economy	12700.00
0005435784853	4300	Economy	13900.00
0005435784841	4300	Economy	13900.00
0005435784862	4300	Economy	13900.00
0005435784837	4300	Economy	12700.00
0005434993880	4300	Economy	12700.00
0005434993883	4300	Economy	12700.00
0005434993878	4300	Economy	12700.00
0005434993886	4300	Economy	12700.00
0005435784840	4300	Economy	12700.00
0005435784845	4300	Economy	12700.00
0005434993879	4300	Economy	12700.00
0005435784866	4300	Economy	12700.00
0005435784842	4300	Economy	12700.00
0005435784854	4300	Economy	12700.00
0005435784834	4300	Economy	12700.00
0005435784868	4300	Economy	12700.00
0005435784858	4300	Economy	12700.00
0005435784849	4300	Economy	12700.00
0005434993877	4300	Economy	12700.00
0005435784843	4300	Economy	12700.00
0005435784844	4300	Economy	12700.00
0005432190573	4300	Economy	12700.00
0005434993885	4300	Economy	12700.00
0005435784856	4300	Economy	12700.00
0005434993881	4300	Economy	12700.00
0005435784867	4300	Economy	12700.00
0005432190571	4300	Economy	12700.00
0005435784860	4300	Economy	12700.00
0005434993884	4300	Economy	12700.00
0005435784851	4300	Economy	12700.00
0005435784863	4300	Economy	12700.00
0005435784835	4300	Economy	12700.00
0005432190574	4300	Economy	12700.00
0005435784839	4300	Economy	12700.00
0005435784846	4300	Economy	12700.00
0005434993882	4300	Economy	12700.00
0005435784859	4300	Economy	12700.00
0005435784848	4300	Economy	12700.00
0005435784838	4300	Economy	12700.00
0005435918585	27292	Business	38000.00
0005435937320	27292	Economy	12700.00
0005432195661	27292	Economy	13900.00
0005435918586	27292	Economy	12700.00
0005435937322	27292	Economy	12700.00
0005435937325	27292	Economy	12700.00
0005435937326	27292	Economy	12700.00
0005435937323	27292	Economy	12700.00
0005435937321	27292	Economy	12700.00
0005435937324	27292	Economy	12700.00
0005435937319	27292	Economy	12700.00
0005432195660	27292	Economy	12700.00
0005435918584	27292	Economy	12700.00
0005435918587	27292	Economy	12700.00
0005432146168	19873	Economy	12800.00
0005432146167	19873	Economy	12800.00
0005432146169	19873	Economy	12800.00
0005432146170	19873	Economy	12800.00
0005432459072	4718	Business	40900.00
0005432566761	4718	Business	40900.00
0005432459097	4718	Business	40900.00
0005434081567	4718	Business	40900.00
0005432459073	4718	Business	40900.00
0005433726072	4718	Business	40900.00
0005432459098	4718	Business	40900.00
0005432459096	4718	Business	40900.00
0005432459085	4718	Business	40900.00
0005432566740	4718	Business	40900.00
0005432170290	4718	Business	40900.00
0005434081555	4718	Business	40900.00
0005432459112	4718	Business	40900.00
0005432566741	4718	Business	40900.00
0005434081556	4718	Business	40900.00
0005432566767	4718	Business	40900.00
0005432459087	4718	Business	40900.00
0005432459093	4718	Business	40900.00
0005432459067	4718	Business	40900.00
0005432566726	4718	Business	40900.00
0005432459063	4718	Business	40900.00
0005434081558	4718	Business	40900.00
0005432566770	4718	Business	40900.00
0005432566738	4718	Economy	15000.00
0005432566736	4718	Economy	15000.00
0005432566749	4718	Economy	15000.00
0005432459104	4718	Economy	13600.00
0005432566754	4718	Economy	13600.00
0005432566751	4718	Economy	13600.00
0005433451590	4718	Economy	13600.00
0005433452708	4718	Economy	13600.00
0005434081559	4718	Economy	13600.00
0005434081573	4718	Economy	13600.00
0005432566724	4718	Economy	13600.00
0005432459092	4718	Economy	13600.00
0005432566755	4718	Economy	13600.00
0005432566729	4718	Economy	13600.00
0005432170288	4718	Economy	13600.00
0005432566721	4718	Economy	13600.00
0005432459079	4718	Economy	13600.00
0005432459065	4718	Economy	13600.00
0005432459066	4718	Economy	13600.00
0005432566713	4718	Economy	13600.00
0005432566728	4718	Economy	13600.00
0005434081562	4718	Economy	13600.00
0005432459105	4718	Economy	13600.00
0005432566743	4718	Economy	13600.00
0005432459108	4718	Economy	13600.00
0005432566752	4718	Economy	13600.00
0005432566725	4718	Economy	13600.00
0005432459070	4718	Economy	13600.00
0005432459088	4718	Economy	13600.00
0005433451589	4718	Economy	13600.00
0005432566715	4718	Economy	13600.00
0005432186817	4718	Economy	13600.00
0005434081574	4718	Economy	13600.00
0005432566750	4718	Economy	13600.00
0005432566731	4718	Economy	13600.00
0005432186815	4718	Economy	13600.00
0005432566771	4718	Economy	13600.00
0005434081560	4718	Economy	13600.00
0005432459078	4718	Economy	13600.00
0005432459089	4718	Economy	13600.00
0005432459090	4718	Economy	13600.00
0005432170285	4718	Economy	13600.00
0005432566763	4718	Economy	13600.00
0005432459109	4718	Economy	13600.00
0005432566775	4718	Economy	13600.00
0005432566732	4718	Economy	13600.00
0005432459110	4718	Economy	13600.00
0005434081571	4718	Economy	13600.00
0005434081563	4718	Economy	13600.00
0005432566773	4718	Economy	13600.00
0005432459083	4718	Economy	13600.00
0005432459095	4718	Economy	13600.00
0005432566764	4718	Economy	13600.00
0005432459114	4718	Economy	13600.00
0005432459106	4718	Economy	13600.00
0005432459107	4718	Economy	13600.00
0005432571265	4718	Economy	13600.00
0005432566734	4718	Economy	13600.00
0005432566757	4718	Economy	13600.00
0005434081575	4718	Economy	13600.00
0005432459076	4718	Economy	13600.00
0005432566727	4718	Economy	13600.00
0005432459111	4718	Economy	13600.00
0005433726070	4718	Economy	13600.00
0005432459102	4718	Economy	13600.00
0005432459094	4718	Economy	13600.00
0005432459081	4718	Economy	13600.00
0005432566769	4718	Economy	13600.00
0005434081561	4718	Economy	13600.00
0005432566722	4718	Economy	13600.00
0005433452709	4718	Economy	13600.00
0005432459113	4718	Economy	13600.00
0005432566746	4718	Economy	13600.00
0005434081553	4718	Economy	13600.00
0005432459064	4718	Economy	13600.00
0005432170289	4718	Economy	13600.00
0005432459069	4718	Economy	13600.00
0005432566742	4718	Economy	13600.00
0005434081566	4718	Economy	13600.00
0005432566756	4718	Economy	13600.00
0005432186816	4718	Economy	13600.00
0005434081554	4718	Economy	15000.00
0005432566733	4718	Economy	15000.00
0005432566719	4718	Economy	13600.00
0005432566730	4718	Economy	13600.00
0005432186818	4718	Economy	13600.00
0005434081572	4718	Economy	13600.00
0005432566760	4718	Economy	13600.00
0005432170287	4718	Economy	13600.00
0005434081565	4718	Economy	13600.00
0005432566723	4718	Economy	13600.00
0005432459103	4718	Economy	13600.00
0005432566718	4718	Economy	13600.00
0005432566745	4718	Economy	13600.00
0005434081551	4718	Economy	13600.00
0005432566714	4718	Economy	13600.00
0005434081568	4718	Economy	13600.00
0005434081564	4718	Economy	13600.00
0005432566720	4718	Economy	13600.00
0005434081552	4718	Economy	13600.00
0005432459082	4718	Economy	13600.00
0005432566774	4718	Economy	13600.00
0005432571266	4718	Economy	13600.00
0005432566748	4718	Economy	13600.00
0005432566737	4718	Economy	13600.00
0005434081569	4718	Economy	13600.00
0005432459084	4718	Economy	13600.00
0005432566753	4718	Economy	13600.00
0005434081557	4718	Economy	13600.00
0005432566716	4718	Economy	13600.00
0005432459115	4718	Economy	13600.00
0005432459075	4718	Economy	13600.00
0005432566739	4718	Economy	13600.00
0005432459086	4718	Economy	13600.00
0005432459071	4718	Economy	13600.00
0005432459099	4718	Economy	13600.00
0005432566759	4718	Economy	13600.00
0005434081576	4718	Economy	13600.00
0005432566766	4718	Economy	13600.00
0005432571264	4718	Economy	13600.00
0005433726071	4718	Economy	13600.00
0005432566772	4718	Economy	13600.00
0005432459068	4718	Economy	13600.00
0005434081570	4718	Economy	13600.00
0005432566765	4718	Economy	13600.00
0005432566717	4718	Economy	13600.00
0005432459100	4718	Economy	13600.00
0005432459074	4718	Economy	13600.00
0005432566758	4718	Economy	13600.00
0005432459101	4718	Economy	13600.00
0005432571267	4718	Economy	13600.00
0005432566768	4718	Economy	13600.00
0005432566762	4718	Economy	13600.00
0005432566744	4718	Economy	13600.00
0005432459077	4718	Economy	13600.00
0005432566735	4718	Economy	13600.00
0005432459080	4718	Economy	13600.00
0005432566747	4718	Economy	13600.00
0005432459091	4718	Economy	13600.00
0005432170291	4718	Economy	13600.00
0005432170286	4718	Economy	13600.00
0005432213552	30514	Business	40900.00
0005432161117	30514	Business	40900.00
0005432566687	30514	Economy	13600.00
0005432161118	30514	Economy	13600.00
0005432566688	30514	Economy	13600.00
0005432213551	30514	Economy	13600.00
0005432566623	30514	Economy	13600.00
0005432213550	30514	Economy	13600.00
0005432566590	30514	Economy	13600.00
0005432213553	30514	Economy	13600.00
0005432566589	30514	Economy	13600.00
0005435720807	13602	Economy	9900.00
0005435722021	13602	Economy	9900.00
0005435722020	13602	Economy	9900.00
0005432295840	22801	Economy	8800.00
0005432295843	22801	Economy	8800.00
0005432295842	22801	Economy	8800.00
0005432295841	22801	Economy	8800.00
0005433341745	11115	Business	23600.00
0005433341741	11115	Business	23600.00
0005433341764	11115	Business	23600.00
0005433341758	11115	Business	23600.00
0005433341717	11115	Business	23600.00
0005433341733	11115	Business	23600.00
0005433341771	11115	Business	23600.00
0005433341720	11115	Business	23600.00
0005433341691	11115	Business	23600.00
0005433341773	11115	Business	23600.00
0005433341744	11115	Business	23600.00
0005433341684	11115	Economy	7900.00
0005433341721	11115	Economy	7900.00
0005433341782	11115	Economy	7900.00
0005433341706	11115	Economy	7900.00
0005435097064	11115	Economy	7900.00
0005433341697	11115	Economy	7900.00
0005433341784	11115	Economy	7900.00
0005433341757	11115	Economy	7900.00
0005433341767	11115	Economy	7900.00
0005433341752	11115	Economy	7900.00
0005433341692	11115	Economy	7900.00
0005433341689	11115	Economy	7900.00
0005433341778	11115	Economy	7900.00
0005433341735	11115	Economy	7900.00
0005433341687	11115	Economy	7900.00
0005433341722	11115	Economy	7900.00
0005433341755	11115	Economy	7900.00
0005433341723	11115	Economy	7900.00
0005433341785	11115	Economy	7900.00
0005433341761	11115	Economy	7900.00
0005433341726	11115	Economy	7900.00
0005433341749	11115	Economy	7900.00
0005433341769	11115	Economy	7900.00
0005433341760	11115	Economy	7900.00
0005433341705	11115	Economy	7900.00
0005435097061	11115	Economy	7900.00
0005433341685	11115	Economy	7900.00
0005433341728	11115	Economy	7900.00
0005433341738	11115	Economy	7900.00
0005433341779	11115	Economy	7900.00
0005433341710	11115	Economy	7900.00
0005433341777	11115	Economy	7900.00
0005433341759	11115	Economy	7900.00
0005433341742	11115	Economy	7900.00
0005433341772	11115	Economy	7900.00
0005433341736	11115	Economy	8600.00
0005433341698	11115	Economy	8600.00
0005433341699	11115	Economy	8600.00
0005433341774	11115	Economy	8600.00
0005435097067	11115	Economy	8600.00
0005433341729	11115	Economy	7900.00
0005433341702	11115	Economy	7900.00
0005433341727	11115	Economy	7900.00
0005433341730	11115	Economy	7900.00
0005433341686	11115	Economy	7900.00
0005433341765	11115	Economy	7900.00
0005433341688	11115	Economy	7900.00
0005433341756	11115	Economy	7900.00
0005433341737	11115	Economy	7900.00
0005433341715	11115	Economy	7900.00
0005433341711	11115	Economy	7900.00
0005433341775	11115	Economy	7900.00
0005435097063	11115	Economy	7900.00
0005433341770	11115	Economy	7900.00
0005433341700	11115	Economy	7900.00
0005433341768	11115	Economy	7900.00
0005433341712	11115	Economy	7900.00
0005433341724	11115	Economy	7900.00
0005433341739	11115	Economy	7900.00
0005433341734	11115	Economy	7900.00
0005433341743	11115	Economy	7900.00
0005433341731	11115	Economy	7900.00
0005433341695	11115	Economy	7900.00
0005433341754	11115	Economy	7900.00
0005433341690	11115	Economy	7900.00
0005433341746	11115	Economy	7900.00
0005433341763	11115	Economy	7900.00
0005433341783	11115	Economy	7900.00
0005435097060	11115	Economy	7900.00
0005435097065	11115	Economy	7900.00
0005433341732	11115	Economy	7900.00
0005435097062	11115	Economy	7900.00
0005433341716	11115	Economy	7900.00
0005435097068	11115	Economy	7900.00
0005433341780	11115	Economy	7900.00
0005433341751	11115	Economy	7900.00
0005433341740	11115	Economy	7900.00
0005433341747	11115	Economy	7900.00
0005433341703	11115	Economy	7900.00
0005435097066	11115	Economy	7900.00
0005433341781	11115	Economy	7900.00
0005433341766	11115	Economy	7900.00
0005433341708	11115	Economy	7900.00
0005433341725	11115	Economy	7900.00
0005433341719	11115	Economy	7900.00
0005433341709	11115	Economy	7900.00
0005433341714	11115	Economy	7900.00
0005433341786	11115	Economy	7900.00
0005433341694	11115	Economy	7900.00
0005433341707	11115	Economy	7900.00
0005433341762	11115	Economy	7900.00
0005433341701	11115	Economy	7900.00
0005433341704	11115	Economy	7900.00
0005433341718	11115	Economy	7900.00
0005433341753	11115	Economy	7900.00
0005433341696	11115	Economy	7900.00
0005433341693	11115	Economy	7900.00
0005433341750	11115	Economy	7900.00
0005433341748	11115	Economy	7900.00
0005433341776	11115	Economy	7900.00
0005433341713	11115	Economy	7900.00
0005435545628	17111	Business	23600.00
0005435545617	17111	Economy	7900.00
0005435545626	17111	Economy	7900.00
0005435545624	17111	Economy	7900.00
0005432293171	17111	Economy	7900.00
0005435545632	17111	Economy	7900.00
0005435545630	17111	Economy	7900.00
0005432293173	17111	Economy	7900.00
0005435380229	17111	Economy	7900.00
0005435545627	17111	Economy	7900.00
0005435380234	17111	Economy	7900.00
0005435545618	17111	Economy	7900.00
0005435380233	17111	Economy	7900.00
0005435545622	17111	Economy	7900.00
0005435380232	17111	Economy	7900.00
0005435545633	17111	Economy	7900.00
0005435545634	17111	Economy	7900.00
0005435545620	17111	Economy	7900.00
0005435380230	17111	Economy	7900.00
0005435545629	17111	Economy	7900.00
0005435380231	17111	Economy	7900.00
0005435545623	17111	Economy	7900.00
0005432293172	17111	Economy	7900.00
0005435545619	17111	Economy	7900.00
0005435380228	17111	Economy	7900.00
0005435545635	17111	Economy	7900.00
0005435545625	17111	Economy	7900.00
0005435545631	17111	Economy	7900.00
0005435545621	17111	Economy	7900.00
0005433506915	9115	Business	26600.00
0005433506921	9115	Business	26600.00
0005433506928	9115	Business	26600.00
0005433506924	9115	Economy	8900.00
0005433506917	9115	Economy	8900.00
0005433506922	9115	Economy	8900.00
0005433506912	9115	Economy	9800.00
0005433481056	9115	Economy	8900.00
0005433506919	9115	Economy	8900.00
0005433506923	9115	Economy	8900.00
0005433506916	9115	Economy	8900.00
0005433506927	9115	Economy	8900.00
0005433506913	9115	Economy	8900.00
0005433506925	9115	Economy	8900.00
0005433506918	9115	Economy	8900.00
0005433506920	9115	Economy	8900.00
0005433481053	9115	Economy	8900.00
0005433506914	9115	Economy	8900.00
0005433506926	9115	Economy	8900.00
0005433481058	9115	Economy	8900.00
0005433481054	9115	Economy	8900.00
0005433481051	9115	Economy	8900.00
0005433506929	9115	Economy	8900.00
0005433481057	9115	Economy	8900.00
0005433481052	9115	Economy	8900.00
0005433481059	9115	Economy	8900.00
0005433481055	9115	Economy	8900.00
0005432919572	20467	Business	26600.00
0005432919568	20467	Business	26600.00
0005432919581	20467	Business	26600.00
0005432919585	20467	Business	26600.00
0005432919567	20467	Economy	8900.00
0005432919576	20467	Economy	8900.00
0005432919579	20467	Economy	8900.00
0005432919582	20467	Economy	8900.00
0005432919586	20467	Economy	8900.00
0005432919580	20467	Economy	8900.00
0005432919587	20467	Economy	8900.00
0005432919573	20467	Economy	8900.00
0005432919569	20467	Economy	8900.00
0005432919574	20467	Economy	8900.00
0005432919570	20467	Economy	8900.00
0005432919571	20467	Economy	8900.00
0005432919577	20467	Economy	8900.00
0005432919575	20467	Economy	8900.00
0005432919584	20467	Economy	8900.00
0005432919578	20467	Economy	8900.00
0005432919583	20467	Economy	8900.00
0005432396181	10125	Economy	5800.00
0005432394041	10125	Economy	5800.00
0005432394042	10125	Economy	5800.00
0005432396180	10125	Economy	5800.00
0005432396179	10125	Economy	5800.00
0005432396182	10125	Economy	5800.00
0005432394040	10125	Economy	5800.00
0005432394043	10125	Economy	5800.00
0005434928258	11025	Business	9500.00
0005434928259	11025	Economy	3200.00
0005434928260	11025	Economy	3500.00
0005434411716	11025	Economy	3200.00
0005434411715	11025	Economy	3200.00
0005434411717	11025	Economy	3200.00
0005434411718	11025	Economy	3200.00
0005435125797	14764	Business	9500.00
0005435625913	14764	Business	9500.00
0005435125812	14764	Business	9500.00
0005435125800	14764	Business	9500.00
0005435625923	14764	Business	9500.00
0005435556656	14764	Business	9500.00
0005435125806	14764	Business	9500.00
0005435625922	14764	Business	9500.00
0005435125793	14764	Business	9500.00
0005435125775	14764	Economy	3200.00
0005435125799	14764	Economy	3200.00
0005435125794	14764	Economy	3200.00
0005435625925	14764	Economy	3200.00
0005435625917	14764	Economy	3200.00
0005435625926	14764	Economy	3200.00
0005435125798	14764	Economy	3200.00
0005435125790	14764	Economy	3500.00
0005435554117	14764	Economy	3500.00
0005435125805	14764	Economy	3500.00
0005435125809	14764	Economy	3500.00
0005435625924	14764	Economy	3200.00
0005435125781	14764	Economy	3200.00
0005435125780	14764	Economy	3200.00
0005435554115	14764	Economy	3200.00
0005435125803	14764	Economy	3200.00
0005435125804	14764	Economy	3200.00
0005435125785	14764	Economy	3200.00
0005435125789	14764	Economy	3200.00
0005435125807	14764	Economy	3200.00
0005435625927	14764	Economy	3200.00
0005435125808	14764	Economy	3200.00
0005435125788	14764	Economy	3200.00
0005435125801	14764	Economy	3200.00
0005435625921	14764	Economy	3200.00
0005435125786	14764	Economy	3200.00
0005435125811	14764	Economy	3200.00
0005435625920	14764	Economy	3200.00
0005435125782	14764	Economy	3200.00
0005435554114	14764	Economy	3200.00
0005435125777	14764	Economy	3200.00
0005435625914	14764	Economy	3200.00
0005435125783	14764	Economy	3200.00
0005435125784	14764	Economy	3200.00
0005435125779	14764	Economy	3200.00
0005435125810	14764	Economy	3200.00
0005435556657	14764	Economy	3200.00
0005435625915	14764	Economy	3200.00
0005435554116	14764	Economy	3200.00
0005435125796	14764	Economy	3200.00
0005435125792	14764	Economy	3200.00
0005435554113	14764	Economy	3200.00
0005435125787	14764	Economy	3200.00
0005435625919	14764	Economy	3200.00
0005435556655	14764	Economy	3200.00
0005435125795	14764	Economy	3200.00
0005435125813	14764	Economy	3200.00
0005435125774	14764	Economy	3200.00
0005435125802	14764	Economy	3200.00
0005435125791	14764	Economy	3200.00
0005435625918	14764	Economy	3200.00
0005435625916	14764	Economy	3200.00
0005435556654	14764	Economy	3200.00
0005435125776	14764	Economy	3200.00
0005435125778	14764	Economy	3200.00
0005435125772	14764	Economy	3200.00
0005435125773	14764	Economy	3200.00
0005435715219	7131	Business	86900.00
0005432400070	7131	Business	86900.00
0005435715215	7131	Business	86900.00
0005435715227	7131	Business	86900.00
0005435715224	7131	Economy	29000.00
0005432398145	7131	Economy	29000.00
0005435715214	7131	Economy	29000.00
0005435715216	7131	Economy	29000.00
0005435715212	7131	Economy	29000.00
0005435715218	7131	Economy	29000.00
0005435715223	7131	Economy	29000.00
0005432400071	7131	Economy	29000.00
0005435715217	7131	Economy	29000.00
0005432400069	7131	Economy	29000.00
0005435715226	7131	Economy	29000.00
0005432400072	7131	Economy	29000.00
0005432398143	7131	Economy	29000.00
0005435715222	7131	Economy	29000.00
0005435715213	7131	Economy	29000.00
0005435715220	7131	Economy	29000.00
0005435715225	7131	Economy	29000.00
0005435715221	7131	Economy	29000.00
0005432398142	7131	Economy	29000.00
0005432398144	7131	Economy	29000.00
0005435715228	7131	Economy	29000.00
0005435443180	27078	Business	86900.00
0005435178473	27078	Business	86900.00
0005435443176	27078	Economy	29000.00
0005435443179	27078	Economy	29000.00
0005435443173	27078	Economy	29000.00
0005435178978	27078	Economy	31900.00
0005435443181	27078	Economy	29000.00
0005435178472	27078	Economy	29000.00
0005435178471	27078	Economy	29000.00
0005435443178	27078	Economy	29000.00
0005435443174	27078	Economy	29000.00
0005435443175	27078	Economy	29000.00
0005435443177	27078	Economy	29000.00
0005434084863	2745	Economy	7700.00
0005434084865	2745	Economy	7700.00
0005434084861	2745	Economy	7700.00
0005434084862	2745	Economy	7700.00
0005434084864	2745	Economy	7700.00
0005433060375	28483	Economy	7700.00
0005433060374	28483	Economy	7700.00
0005433060376	28483	Economy	7700.00
0005433060373	28483	Economy	7700.00
0005432632632	25192	Economy	26400.00
0005432632634	25192	Economy	26400.00
0005432632629	25192	Economy	26400.00
0005432632631	25192	Economy	26400.00
0005432632628	25192	Economy	26400.00
0005432632626	25192	Economy	26400.00
0005432632624	25192	Economy	26400.00
0005432632622	25192	Economy	26400.00
0005432632625	25192	Economy	26400.00
0005432632627	25192	Economy	26400.00
0005432632630	25192	Economy	26400.00
0005432632633	25192	Economy	26400.00
0005432632620	25192	Economy	26400.00
0005432632623	25192	Economy	26400.00
0005432632621	25192	Economy	26400.00
0005435844270	28177	Economy	26400.00
0005435844267	28177	Economy	26400.00
0005435844261	28177	Economy	26400.00
0005435844260	28177	Economy	26400.00
0005435844266	28177	Economy	26400.00
0005435844265	28177	Economy	26400.00
0005435844269	28177	Economy	26400.00
0005435844264	28177	Economy	26400.00
0005435844268	28177	Economy	26400.00
0005435844262	28177	Economy	26400.00
0005435844263	28177	Economy	26400.00
0005432294451	22222	Business	20200.00
0005435528930	22222	Business	20200.00
0005435528944	22222	Business	20200.00
0005435540676	22222	Business	20200.00
0005435540681	22222	Business	20200.00
0005435528923	22222	Economy	6700.00
0005432294450	22222	Economy	6700.00
0005435540689	22222	Economy	6700.00
0005435528934	22222	Economy	6700.00
0005435528926	22222	Economy	6700.00
0005435528929	22222	Economy	6700.00
0005435528931	22222	Economy	6700.00
0005435540671	22222	Economy	7400.00
0005435540667	22222	Economy	7400.00
0005435540677	22222	Economy	7400.00
0005435540670	22222	Economy	6700.00
0005435528924	22222	Economy	6700.00
0005435528935	22222	Economy	6700.00
0005435540682	22222	Economy	6700.00
0005432294452	22222	Economy	6700.00
0005435540686	22222	Economy	6700.00
0005435540683	22222	Economy	6700.00
0005435528936	22222	Economy	6700.00
0005435540680	22222	Economy	6700.00
0005435540672	22222	Economy	6700.00
0005435528943	22222	Economy	6700.00
0005435528922	22222	Economy	6700.00
0005435528928	22222	Economy	6700.00
0005435540684	22222	Economy	6700.00
0005435540679	22222	Economy	6700.00
0005435528927	22222	Economy	6700.00
0005435540674	22222	Economy	6700.00
0005435528925	22222	Economy	6700.00
0005435528941	22222	Economy	6700.00
0005435528940	22222	Economy	6700.00
0005435540669	22222	Economy	6700.00
0005435528939	22222	Economy	6700.00
0005435528942	22222	Economy	6700.00
0005435540687	22222	Economy	6700.00
0005435540678	22222	Economy	6700.00
0005435528933	22222	Economy	6700.00
0005435540673	22222	Economy	6700.00
0005435528945	22222	Economy	6700.00
0005435540685	22222	Economy	6700.00
0005435528946	22222	Economy	6700.00
0005435540668	22222	Economy	6700.00
0005435540688	22222	Economy	6700.00
0005435540675	22222	Economy	6700.00
0005435528932	22222	Economy	6700.00
0005435528937	22222	Economy	6700.00
0005435528938	22222	Economy	6700.00
0005434906523	2298	Business	20200.00
0005434906519	2298	Business	20200.00
0005434906563	2298	Business	20200.00
0005434906567	2298	Business	20200.00
0005434906565	2298	Business	20200.00
0005434906518	2298	Business	20200.00
0005434906522	2298	Economy	6700.00
0005434906566	2298	Economy	6700.00
0005434906531	2298	Economy	6700.00
0005434906554	2298	Economy	6700.00
0005434906539	2298	Economy	6700.00
0005434906520	2298	Economy	6700.00
0005434906545	2298	Economy	6700.00
0005434906557	2298	Economy	7400.00
0005434906550	2298	Economy	7400.00
0005434906537	2298	Economy	7400.00
0005434906526	2298	Economy	6700.00
0005434906532	2298	Economy	6700.00
0005434906564	2298	Economy	6700.00
0005434906559	2298	Economy	6700.00
0005434906534	2298	Economy	6700.00
0005434906553	2298	Economy	6700.00
0005434906525	2298	Economy	6700.00
0005434906535	2298	Economy	6700.00
0005434906570	2298	Economy	6700.00
0005434906527	2298	Economy	6700.00
0005434906561	2298	Economy	6700.00
0005434906547	2298	Economy	6700.00
0005434906536	2298	Economy	6700.00
0005434906541	2298	Economy	6700.00
0005434906556	2298	Economy	6700.00
0005434906533	2298	Economy	6700.00
0005434906529	2298	Economy	6700.00
0005434906551	2298	Economy	6700.00
0005434906528	2298	Economy	6700.00
0005434906544	2298	Economy	6700.00
0005434906524	2298	Economy	6700.00
0005434906552	2298	Economy	6700.00
0005434906543	2298	Economy	6700.00
0005434906555	2298	Economy	6700.00
0005434906546	2298	Economy	6700.00
0005434906568	2298	Economy	6700.00
0005434906549	2298	Economy	6700.00
0005434906538	2298	Economy	6700.00
0005434906542	2298	Economy	6700.00
0005434906517	2298	Economy	6700.00
0005434906521	2298	Economy	6700.00
0005434906560	2298	Economy	6700.00
0005434906540	2298	Economy	6700.00
0005434906558	2298	Economy	6700.00
0005434906569	2298	Economy	6700.00
0005434906530	2298	Economy	6700.00
0005434906562	2298	Economy	6700.00
0005434906516	2298	Economy	6700.00
0005434906548	2298	Economy	6700.00
0005434906571	2298	Economy	6700.00
0005433251046	25610	Business	20200.00
0005433251038	25610	Business	20200.00
0005433400943	25610	Business	20200.00
0005433251036	25610	Business	20200.00
0005433251025	25610	Economy	6700.00
0005433251048	25610	Economy	6700.00
0005433251042	25610	Economy	6700.00
0005433251022	25610	Economy	6700.00
0005433251047	25610	Economy	6700.00
0005433251029	25610	Economy	7400.00
0005433251023	25610	Economy	7400.00
0005433400941	25610	Economy	6700.00
0005433251026	25610	Economy	6700.00
0005433251035	25610	Economy	6700.00
0005433251039	25610	Economy	6700.00
0005433251049	25610	Economy	6700.00
0005433251027	25610	Economy	6700.00
0005433251041	25610	Economy	6700.00
0005433251024	25610	Economy	6700.00
0005433251033	25610	Economy	6700.00
0005433251040	25610	Economy	6700.00
0005433400940	25610	Economy	6700.00
0005433251051	25610	Economy	6700.00
0005433251043	25610	Economy	6700.00
0005433251030	25610	Economy	6700.00
0005433251052	25610	Economy	6700.00
0005433251045	25610	Economy	6700.00
0005433251037	25610	Economy	6700.00
0005433251053	25610	Economy	6700.00
0005433400942	25610	Economy	6700.00
0005433251050	25610	Economy	6700.00
0005433251031	25610	Economy	6700.00
0005433251028	25610	Economy	6700.00
0005433251032	25610	Economy	6700.00
0005433251044	25610	Economy	6700.00
0005433251034	25610	Economy	6700.00
0005432620831	2546	Economy	13600.00
0005432620835	2546	Economy	12400.00
0005432620837	2546	Economy	12400.00
0005432620841	2546	Economy	12400.00
0005432620834	2546	Economy	12400.00
0005432620836	2546	Economy	12400.00
0005432620829	2546	Economy	12400.00
0005432620843	2546	Economy	12400.00
0005432620830	2546	Economy	12400.00
0005432620840	2546	Economy	12400.00
0005432620832	2546	Economy	12400.00
0005432620839	2546	Economy	12400.00
0005432620838	2546	Economy	12400.00
0005432620842	2546	Economy	12400.00
0005432620833	2546	Economy	12400.00
0005432862193	28084	Economy	13600.00
0005432862192	28084	Economy	12400.00
0005432862190	28084	Economy	12400.00
0005432862187	28084	Economy	12400.00
0005432862189	28084	Economy	12400.00
0005432862191	28084	Economy	12400.00
0005432862186	28084	Economy	12400.00
0005432862194	28084	Economy	12400.00
0005432862188	28084	Economy	12400.00
0005434097454	13059	Economy	11300.00
0005434097455	13059	Economy	11300.00
0005433451589	31064	Economy	8400.00
0005433451590	31064	Economy	8400.00
0005433452709	31064	Economy	8400.00
0005433452708	31064	Economy	8400.00
0005433131644	29844	Economy	6600.00
0005434142548	29844	Economy	6600.00
0005434142552	29844	Economy	6600.00
0005433134070	29844	Economy	6600.00
0005433131642	29844	Economy	6600.00
0005433131643	29844	Economy	6600.00
0005433134073	29844	Economy	6600.00
0005434142553	29844	Economy	6600.00
0005433131640	29844	Economy	6600.00
0005433131641	29844	Economy	6600.00
0005434184636	29844	Economy	6600.00
0005434183551	29844	Economy	6600.00
0005434142551	29844	Economy	6600.00
0005434183550	29844	Economy	6600.00
0005434142549	29844	Economy	6600.00
0005433134075	29844	Economy	6600.00
0005433134074	29844	Economy	6600.00
0005434142550	29844	Economy	6600.00
0005433134072	29844	Economy	6600.00
0005433134071	29844	Economy	6600.00
0005435696921	16446	Economy	19900.00
0005435696903	16446	Economy	19900.00
0005435696914	16446	Economy	18100.00
0005435696919	16446	Economy	18100.00
0005435696912	16446	Economy	18100.00
0005435696917	16446	Economy	18100.00
0005435696926	16446	Economy	18100.00
0005435696920	16446	Economy	18100.00
0005435696904	16446	Economy	18100.00
0005435696924	16446	Economy	18100.00
0005435696927	16446	Economy	18100.00
0005435696916	16446	Economy	18100.00
0005435696918	16446	Economy	18100.00
0005435696906	16446	Economy	18100.00
0005435696913	16446	Economy	18100.00
0005435696902	16446	Economy	18100.00
0005435696909	16446	Economy	18100.00
0005435696910	16446	Economy	18100.00
0005435696907	16446	Economy	18100.00
0005435696905	16446	Economy	18100.00
0005435696915	16446	Economy	18100.00
0005435696911	16446	Economy	18100.00
0005435696922	16446	Economy	18100.00
0005435696925	16446	Economy	18100.00
0005435696908	16446	Economy	18100.00
0005435696901	16446	Economy	18100.00
0005435696923	16446	Economy	18100.00
0005435696928	16446	Economy	18100.00
0005435935003	24686	Economy	18100.00
0005433724736	18810	Economy	4400.00
0005433724735	18810	Economy	4400.00
0005433724738	18810	Economy	4400.00
0005433724733	18810	Economy	4400.00
0005433724737	18810	Economy	4400.00
0005433724734	18810	Economy	4400.00
0005432968810	21627	Economy	4400.00
0005432968808	21627	Economy	4400.00
0005432968809	21627	Economy	4400.00
0005434136970	7316	Business	23100.00
0005434136957	7316	Business	23100.00
0005434136946	7316	Business	23100.00
0005434136949	7316	Business	23100.00
0005434136950	7316	Business	23100.00
0005434136983	7316	Business	23100.00
0005434136997	7316	Business	23100.00
0005434137009	7316	Business	23100.00
0005434136985	7316	Business	23100.00
0005434136937	7316	Business	23100.00
0005434136988	7316	Business	23100.00
0005434136991	7316	Economy	7700.00
0005434136947	7316	Economy	7700.00
0005434137001	7316	Economy	7700.00
0005434136977	7316	Economy	7700.00
0005434087444	7316	Economy	7700.00
0005434137006	7316	Economy	7700.00
0005434136973	7316	Economy	7700.00
0005434136982	7316	Economy	7700.00
0005434087442	7316	Economy	8500.00
0005434137004	7316	Economy	8500.00
0005434136960	7316	Economy	8500.00
0005434137008	7316	Economy	8500.00
0005434136966	7316	Economy	8500.00
0005434136968	7316	Economy	7700.00
0005434136979	7316	Economy	7700.00
0005434136943	7316	Economy	7700.00
0005434136995	7316	Economy	7700.00
0005434136971	7316	Economy	7700.00
0005434136959	7316	Economy	7700.00
0005434136975	7316	Economy	7700.00
0005434137012	7316	Economy	7700.00
0005434136944	7316	Economy	7700.00
0005434087443	7316	Economy	7700.00
0005434137000	7316	Economy	7700.00
0005434136958	7316	Economy	7700.00
0005434136987	7316	Economy	7700.00
0005434136956	7316	Economy	7700.00
0005434136998	7316	Economy	7700.00
0005434136965	7316	Economy	7700.00
0005434136938	7316	Economy	7700.00
0005434087446	7316	Economy	7700.00
0005434136990	7316	Economy	7700.00
0005434136992	7316	Economy	7700.00
0005434136939	7316	Economy	7700.00
0005434137011	7316	Economy	7700.00
0005434136993	7316	Economy	7700.00
0005434137013	7316	Economy	7700.00
0005434136967	7316	Economy	7700.00
0005434136986	7316	Economy	7700.00
0005434137005	7316	Economy	7700.00
0005434136976	7316	Economy	7700.00
0005434137010	7316	Economy	7700.00
0005434136984	7316	Economy	7700.00
0005434136935	7316	Economy	7700.00
0005434136969	7316	Economy	7700.00
0005434136994	7316	Economy	7700.00
0005434136972	7316	Economy	7700.00
0005434136953	7316	Economy	7700.00
0005434137003	7316	Economy	7700.00
0005434136955	7316	Economy	7700.00
0005434136962	7316	Economy	7700.00
0005434136963	7316	Economy	7700.00
0005434136961	7316	Economy	7700.00
0005434136980	7316	Economy	7700.00
0005434136951	7316	Economy	7700.00
0005434136936	7316	Economy	7700.00
0005434087441	7316	Economy	7700.00
0005434136945	7316	Economy	7700.00
0005434136954	7316	Economy	7700.00
0005434136942	7316	Economy	7700.00
0005434136974	7316	Economy	7700.00
0005434136948	7316	Economy	7700.00
0005434137007	7316	Economy	7700.00
0005434136989	7316	Economy	7700.00
0005434136952	7316	Economy	7700.00
0005434136964	7316	Economy	7700.00
0005434136978	7316	Economy	7700.00
0005434136940	7316	Economy	7700.00
0005434137002	7316	Economy	7700.00
0005434087445	7316	Economy	7700.00
0005434136999	7316	Economy	7700.00
0005434136981	7316	Economy	7700.00
0005434136941	7316	Economy	7700.00
0005434136996	7316	Economy	7700.00
0005434610177	1898	Economy	21700.00
0005435808081	1898	Economy	21700.00
0005435808092	1898	Economy	21700.00
0005435808082	1898	Economy	21700.00
0005435808086	1898	Economy	21700.00
0005435808091	1898	Economy	21700.00
0005435808085	1898	Economy	21700.00
0005435808090	1898	Economy	21700.00
0005435808084	1898	Economy	21700.00
0005434610178	1898	Economy	21700.00
0005435808087	1898	Economy	21700.00
0005434610176	1898	Economy	21700.00
0005435808083	1898	Economy	21700.00
0005434610179	1898	Economy	21700.00
0005435808089	1898	Economy	21700.00
0005435808088	1898	Economy	21700.00
0005433407484	23119	Economy	23900.00
0005433407487	23119	Economy	21700.00
0005433407489	23119	Economy	21700.00
0005433407482	23119	Economy	21700.00
0005433407485	23119	Economy	21700.00
0005433407488	23119	Economy	21700.00
0005433407490	23119	Economy	21700.00
0005433407491	23119	Economy	21700.00
0005433407483	23119	Economy	21700.00
0005433407486	23119	Economy	21700.00
0005434503568	22878	Economy	7600.00
0005434503564	22878	Economy	7600.00
0005434503575	22878	Economy	7600.00
0005434503544	22878	Economy	7600.00
0005434503573	22878	Economy	6900.00
0005434503562	22878	Economy	6900.00
0005434503551	22878	Economy	6900.00
0005434503539	22878	Economy	6900.00
0005434503547	22878	Economy	6900.00
0005434503541	22878	Economy	6900.00
0005434503558	22878	Economy	6900.00
0005434503576	22878	Economy	6900.00
0005434503571	22878	Economy	6900.00
0005434503550	22878	Economy	6900.00
0005434503540	22878	Economy	6900.00
0005434503543	22878	Economy	6900.00
0005434503559	22878	Economy	6900.00
0005434503548	22878	Economy	6900.00
0005434503565	22878	Economy	6900.00
0005434503545	22878	Economy	6900.00
0005434503577	22878	Economy	6900.00
0005434503552	22878	Economy	6900.00
0005434503556	22878	Economy	6900.00
0005434503538	22878	Economy	6900.00
0005434503567	22878	Economy	6900.00
0005434503554	22878	Economy	6900.00
0005434503563	22878	Economy	6900.00
0005434503566	22878	Economy	6900.00
0005434503572	22878	Economy	6900.00
0005434503570	22878	Economy	6900.00
0005434503560	22878	Economy	6900.00
0005434503574	22878	Economy	6900.00
0005434503542	22878	Economy	6900.00
0005434503549	22878	Economy	6900.00
0005434503557	22878	Economy	6900.00
0005434503561	22878	Economy	6900.00
0005434503537	22878	Economy	6900.00
0005434503555	22878	Economy	6900.00
0005434503553	22878	Economy	6900.00
0005434503569	22878	Economy	6900.00
0005434503546	22878	Economy	6900.00
0005435078122	2199	Economy	7700.00
0005435078113	2199	Economy	7000.00
0005435078117	2199	Economy	7000.00
0005435078121	2199	Economy	7000.00
0005435078119	2199	Economy	7000.00
0005435078126	2199	Economy	7000.00
0005435078114	2199	Economy	7000.00
0005435078127	2199	Economy	7000.00
0005435078116	2199	Economy	7000.00
0005435078125	2199	Economy	7000.00
0005435078123	2199	Economy	7000.00
0005435078124	2199	Economy	7000.00
0005435078115	2199	Economy	7000.00
0005435078118	2199	Economy	7000.00
0005435078120	2199	Economy	7000.00
0005433266589	24355	Economy	7700.00
0005433266592	24355	Economy	7000.00
0005433266587	24355	Economy	7000.00
0005433266585	24355	Economy	7000.00
0005433266588	24355	Economy	7000.00
0005433266590	24355	Economy	7000.00
0005433266591	24355	Economy	7000.00
0005433266593	24355	Economy	7000.00
0005435078064	24355	Economy	7000.00
0005433266586	24355	Economy	7000.00
0005435803220	6626	Economy	10800.00
0005434988587	6626	Economy	10800.00
0005435803222	6626	Economy	9800.00
0005434988585	6626	Economy	9800.00
0005434988584	6626	Economy	9800.00
0005435803221	6626	Economy	9800.00
0005434988582	6626	Economy	9800.00
0005434988580	6626	Economy	9800.00
0005434988583	6626	Economy	9800.00
0005434988586	6626	Economy	9800.00
0005435803223	6626	Economy	9800.00
0005434988581	6626	Economy	9800.00
0005435464478	23625	Economy	10800.00
0005435464479	23625	Economy	9800.00
0005432382610	30462	Business	9900.00
0005433449669	30462	Business	9900.00
0005432382623	30462	Business	9900.00
0005432382634	30462	Business	9900.00
0005432382609	30462	Business	9900.00
0005432382628	30462	Business	9900.00
0005433449667	30462	Business	9900.00
0005432382622	30462	Business	9900.00
0005433449654	30462	Business	9900.00
0005432382615	30462	Business	9900.00
0005433449668	30462	Business	9900.00
0005432382637	30462	Business	9900.00
0005432382640	30462	Economy	3300.00
0005432382643	30462	Economy	3300.00
0005432382635	30462	Economy	3300.00
0005432382645	30462	Economy	3300.00
0005433449670	30462	Economy	3600.00
0005433449660	30462	Economy	3600.00
0005432382641	30462	Economy	3600.00
0005432382606	30462	Economy	3300.00
0005433454843	30462	Economy	3300.00
0005432382618	30462	Economy	3300.00
0005432382632	30462	Economy	3300.00
0005433449661	30462	Economy	3300.00
0005432382633	30462	Economy	3300.00
0005432382648	30462	Economy	3300.00
0005432382613	30462	Economy	3300.00
0005432382617	30462	Economy	3300.00
0005432382639	30462	Economy	3300.00
0005432382619	30462	Economy	3300.00
0005432382627	30462	Economy	3300.00
0005432382608	30462	Economy	3300.00
0005433449651	30462	Economy	3300.00
0005432382616	30462	Economy	3300.00
0005432382647	30462	Economy	3300.00
0005432382630	30462	Economy	3300.00
0005433454845	30462	Economy	3300.00
0005432382624	30462	Economy	3300.00
0005433449665	30462	Economy	3300.00
0005432382621	30462	Economy	3300.00
0005433449666	30462	Economy	3300.00
0005433449650	30462	Economy	3300.00
0005432382626	30462	Economy	3300.00
0005432382636	30462	Economy	3300.00
0005433449662	30462	Economy	3300.00
0005432382611	30462	Economy	3300.00
0005433449656	30462	Economy	3300.00
0005433449657	30462	Economy	3300.00
0005433453733	30462	Economy	3300.00
0005432382607	30462	Economy	3300.00
0005433449652	30462	Economy	3300.00
0005432382642	30462	Economy	3300.00
0005433449658	30462	Economy	3300.00
0005432382620	30462	Economy	3300.00
0005432382629	30462	Economy	3300.00
0005433449659	30462	Economy	3300.00
0005433449655	30462	Economy	3300.00
0005432382638	30462	Economy	3300.00
0005433449653	30462	Economy	3300.00
0005432382625	30462	Economy	3300.00
0005432382631	30462	Economy	3300.00
0005433453734	30462	Economy	3300.00
0005432382614	30462	Economy	3300.00
0005433454844	30462	Economy	3300.00
0005433454846	30462	Economy	3300.00
0005433449671	30462	Economy	3300.00
0005433449664	30462	Economy	3300.00
0005432382644	30462	Economy	3300.00
0005433449663	30462	Economy	3300.00
0005432382646	30462	Economy	3300.00
0005432382612	30462	Economy	3300.00
0005435302136	29714	Economy	17100.00
0005433129216	29714	Economy	15600.00
0005435299711	29714	Economy	15600.00
0005433126781	29714	Economy	15600.00
0005433129215	29714	Economy	15600.00
0005433129213	29714	Economy	15600.00
0005435299710	29714	Economy	15600.00
0005433126785	29714	Economy	15600.00
0005435302135	29714	Economy	15600.00
0005435302134	29714	Economy	15600.00
0005433126784	29714	Economy	15600.00
0005435302137	29714	Economy	15600.00
0005433129212	29714	Economy	15600.00
0005435302138	29714	Economy	15600.00
0005435299714	29714	Economy	15600.00
0005435299712	29714	Economy	15600.00
0005433129214	29714	Economy	15600.00
0005433129217	29714	Economy	15600.00
0005433126782	29714	Economy	15600.00
0005435299713	29714	Economy	15600.00
0005433126783	29714	Economy	15600.00
0005434286960	2402	Economy	17200.00
0005434286974	2402	Economy	17200.00
0005434286964	2402	Economy	15700.00
0005434286966	2402	Economy	15700.00
0005434286979	2402	Economy	15700.00
0005434286976	2402	Economy	15700.00
0005432264439	2402	Economy	15700.00
0005434286977	2402	Economy	15700.00
0005434286961	2402	Economy	15700.00
0005434286975	2402	Economy	15700.00
0005434286972	2402	Economy	15700.00
0005434286970	2402	Economy	15700.00
0005434286967	2402	Economy	15700.00
0005434286962	2402	Economy	15700.00
0005434286981	2402	Economy	15700.00
0005434286965	2402	Economy	15700.00
0005434286980	2402	Economy	15700.00
0005432264440	2402	Economy	15700.00
0005434286971	2402	Economy	15700.00
0005434286963	2402	Economy	15700.00
0005434286969	2402	Economy	15700.00
0005434286968	2402	Economy	15700.00
0005434286978	2402	Economy	15700.00
0005434286973	2402	Economy	15700.00
0005434286982	2402	Economy	15700.00
0005433109875	26865	Economy	15700.00
0005433109886	26865	Economy	15700.00
0005433109881	26865	Economy	15700.00
0005433109882	26865	Economy	15700.00
0005433109879	26865	Economy	15700.00
0005433109878	26865	Economy	15700.00
0005433109888	26865	Economy	15700.00
0005433109877	26865	Economy	15700.00
0005433109885	26865	Economy	15700.00
0005433109883	26865	Economy	15700.00
0005433109876	26865	Economy	15700.00
0005433109887	26865	Economy	15700.00
0005433109884	26865	Economy	15700.00
0005433109880	26865	Economy	15700.00
0005433109874	26865	Economy	15700.00
0005435856143	25446	Economy	25000.00
0005435856146	25446	Economy	25000.00
0005435856142	25446	Economy	22800.00
0005435856145	25446	Economy	22800.00
0005435856144	25446	Economy	22800.00
0005434273053	26641	Economy	22800.00
0005434272168	26641	Economy	22800.00
0005434272167	26641	Economy	22800.00
0005434273054	26641	Economy	22800.00
0005434273052	26641	Economy	22800.00
0005433867852	4781	Economy	19400.00
0005433867873	4781	Economy	17600.00
0005433867887	4781	Economy	17600.00
0005433867869	4781	Economy	17600.00
0005433867875	4781	Economy	17600.00
0005433867851	4781	Economy	17600.00
0005433867865	4781	Economy	17600.00
0005433867872	4781	Economy	17600.00
0005433867889	4781	Economy	17600.00
0005433867882	4781	Economy	17600.00
0005433867879	4781	Economy	17600.00
0005433867886	4781	Economy	17600.00
0005433867874	4781	Economy	17600.00
0005433867855	4781	Economy	17600.00
0005433867878	4781	Economy	17600.00
0005433867871	4781	Economy	17600.00
0005433867859	4781	Economy	17600.00
0005433867867	4781	Economy	17600.00
0005433867876	4781	Economy	17600.00
0005433867853	4781	Economy	17600.00
0005433867884	4781	Economy	17600.00
0005433867885	4781	Economy	17600.00
0005433867860	4781	Economy	17600.00
0005433867862	4781	Economy	17600.00
0005433867857	4781	Economy	17600.00
0005433867868	4781	Economy	17600.00
0005433867877	4781	Economy	17600.00
0005433867881	4781	Economy	17600.00
0005433867861	4781	Economy	17600.00
0005433867863	4781	Economy	17600.00
0005433867854	4781	Economy	17600.00
0005433867870	4781	Economy	17600.00
0005433867866	4781	Economy	17600.00
0005433867883	4781	Economy	17600.00
0005433867888	4781	Economy	17600.00
0005433867880	4781	Economy	17600.00
0005433867858	4781	Economy	17600.00
0005433867864	4781	Economy	17600.00
0005433867856	4781	Economy	17600.00
0005435860441	32612	Economy	17600.00
0005435860439	32612	Economy	17600.00
0005435860440	32612	Economy	17600.00
0005435860438	32612	Economy	17600.00
0005434461617	3437	Economy	24800.00
0005434663219	3437	Economy	22600.00
0005434663218	3437	Economy	22600.00
0005434663220	3437	Economy	22600.00
0005434663221	3437	Economy	22600.00
0005434461615	3437	Economy	22600.00
0005434663212	3437	Economy	22600.00
0005434663208	3437	Economy	22600.00
0005434663207	3437	Economy	22600.00
0005434663209	3437	Economy	22600.00
0005434663216	3437	Economy	22600.00
0005434461616	3437	Economy	22600.00
0005434663213	3437	Economy	22600.00
0005434460474	3437	Economy	22600.00
0005434663217	3437	Economy	22600.00
0005434663210	3437	Economy	22600.00
0005434663214	3437	Economy	22600.00
0005434663215	3437	Economy	22600.00
0005434460473	3437	Economy	22600.00
0005434663211	3437	Economy	22600.00
0005435911341	12446	Economy	22600.00
0005435911343	12446	Economy	22600.00
0005435911340	12446	Economy	22600.00
0005435911345	12446	Economy	22600.00
0005435911344	12446	Economy	22600.00
0005435911346	12446	Economy	22600.00
0005435911342	12446	Economy	22600.00
0005435860440	14508	Economy	18500.00
0005435860441	14508	Economy	16800.00
0005435860438	14508	Economy	16800.00
0005435860439	14508	Economy	16800.00
0005433867821	32656	Economy	18500.00
0005433867814	32656	Economy	18500.00
0005433867832	32656	Economy	18500.00
0005433867827	32656	Economy	18500.00
0005433867831	32656	Economy	16800.00
0005433867846	32656	Economy	16800.00
0005433867839	32656	Economy	16800.00
0005433867833	32656	Economy	16800.00
0005433867823	32656	Economy	16800.00
0005433867822	32656	Economy	16800.00
0005433867834	32656	Economy	16800.00
0005433867813	32656	Economy	16800.00
0005433867836	32656	Economy	16800.00
0005433867812	32656	Economy	16800.00
0005433867841	32656	Economy	16800.00
0005433867845	32656	Economy	16800.00
0005433867818	32656	Economy	16800.00
0005433867847	32656	Economy	16800.00
0005433867816	32656	Economy	16800.00
0005433867844	32656	Economy	16800.00
0005433867825	32656	Economy	16800.00
0005433867849	32656	Economy	16800.00
0005433867842	32656	Economy	16800.00
0005433867815	32656	Economy	16800.00
0005433867850	32656	Economy	16800.00
0005433867837	32656	Economy	16800.00
0005433867817	32656	Economy	16800.00
0005433867840	32656	Economy	16800.00
0005433867824	32656	Economy	16800.00
0005433867830	32656	Economy	16800.00
0005433867828	32656	Economy	16800.00
0005433867820	32656	Economy	16800.00
0005433867819	32656	Economy	16800.00
0005433867835	32656	Economy	16800.00
0005433867843	32656	Economy	16800.00
0005433867811	32656	Economy	16800.00
0005433867848	32656	Economy	16800.00
0005433867838	32656	Economy	16800.00
0005433867829	32656	Economy	16800.00
0005433867826	32656	Economy	16800.00
0005432799030	14786	Economy	4900.00
0005432799022	14786	Economy	4900.00
0005432799023	14786	Economy	4900.00
0005432799028	14786	Economy	4400.00
0005432799038	14786	Economy	4400.00
0005432799016	14786	Economy	4400.00
0005432799018	14786	Economy	4400.00
0005432799019	14786	Economy	4400.00
0005432799027	14786	Economy	4400.00
0005432799013	14786	Economy	4400.00
0005432799012	14786	Economy	4400.00
0005432799017	14786	Economy	4400.00
0005432799039	14786	Economy	4400.00
0005432799015	14786	Economy	4400.00
0005432799036	14786	Economy	4400.00
0005432799031	14786	Economy	4400.00
0005432799035	14786	Economy	4400.00
0005432799029	14786	Economy	4400.00
0005432799026	14786	Economy	4400.00
0005432799014	14786	Economy	4400.00
0005432799025	14786	Economy	4400.00
0005432799032	14786	Economy	4400.00
0005432799034	14786	Economy	4400.00
0005432799033	14786	Economy	4400.00
0005432799021	14786	Economy	4400.00
0005432799011	14786	Economy	4400.00
0005432799024	14786	Economy	4400.00
0005432799037	14786	Economy	4400.00
0005432799020	14786	Economy	4400.00
0005434406893	7031	Business	49100.00
0005434299217	7031	Business	49100.00
0005434299221	7031	Business	49100.00
0005434299236	7031	Business	49100.00
0005434406849	7031	Business	49100.00
0005434406844	7031	Business	49100.00
0005434406847	7031	Business	49100.00
0005432153839	7031	Business	49100.00
0005432153840	7031	Business	49100.00
0005432108214	7031	Business	49100.00
0005434406861	7031	Economy	16400.00
0005434406851	7031	Economy	16400.00
0005434406892	7031	Economy	16400.00
0005434406855	7031	Economy	16400.00
0005434406856	7031	Economy	16400.00
0005434299240	7031	Economy	16400.00
0005434299233	7031	Economy	16400.00
0005434299224	7031	Economy	16400.00
0005434406833	7031	Economy	16400.00
0005434406879	7031	Economy	16400.00
0005434299231	7031	Economy	16400.00
0005434406841	7031	Economy	16400.00
0005434406846	7031	Economy	16400.00
0005434406859	7031	Economy	16400.00
0005434406871	7031	Economy	16400.00
0005434406887	7031	Economy	16400.00
0005434299223	7031	Economy	16400.00
0005434406831	7031	Economy	16400.00
0005434406882	7031	Economy	16400.00
0005434406832	7031	Economy	16400.00
0005434406830	7031	Economy	16400.00
0005434406888	7031	Economy	16400.00
0005434299226	7031	Economy	16400.00
0005434406872	7031	Economy	16400.00
0005434406835	7031	Economy	16400.00
0005432153838	7031	Economy	16400.00
0005434406848	7031	Economy	16400.00
0005434406868	7031	Economy	16400.00
0005434406858	7031	Economy	16400.00
0005434406860	7031	Economy	16400.00
0005434406836	7031	Economy	16400.00
0005434406880	7031	Economy	18000.00
0005432153835	7031	Economy	18000.00
0005434406864	7031	Economy	18000.00
0005434406876	7031	Economy	18000.00
0005432108213	7031	Economy	18000.00
0005434406845	7031	Economy	16400.00
0005434299237	7031	Economy	16400.00
0005434406843	7031	Economy	16400.00
0005432153842	7031	Economy	16400.00
0005434406862	7031	Economy	16400.00
0005434406873	7031	Economy	16400.00
0005434406854	7031	Economy	16400.00
0005434406884	7031	Economy	16400.00
0005434406870	7031	Economy	16400.00
0005432153836	7031	Economy	16400.00
0005434406866	7031	Economy	16400.00
0005434406834	7031	Economy	16400.00
0005434406875	7031	Economy	16400.00
0005432153834	7031	Economy	16400.00
0005434406838	7031	Economy	16400.00
0005434406878	7031	Economy	16400.00
0005434406867	7031	Economy	16400.00
0005434299230	7031	Economy	16400.00
0005434406869	7031	Economy	16400.00
0005434299218	7031	Economy	16400.00
0005434299225	7031	Economy	16400.00
0005434406883	7031	Economy	16400.00
0005434299232	7031	Economy	16400.00
0005434406853	7031	Economy	16400.00
0005434406857	7031	Economy	16400.00
0005434406874	7031	Economy	16400.00
0005434406881	7031	Economy	16400.00
0005434406886	7031	Economy	16400.00
0005432153837	7031	Economy	16400.00
0005432153841	7031	Economy	16400.00
0005434299234	7031	Economy	16400.00
0005434406850	7031	Economy	16400.00
0005434406877	7031	Economy	16400.00
0005434406840	7031	Economy	16400.00
0005434406852	7031	Economy	16400.00
0005434406837	7031	Economy	16400.00
0005434299229	7031	Economy	16400.00
0005434406885	7031	Economy	16400.00
0005434406865	7031	Economy	16400.00
0005434299228	7031	Economy	16400.00
0005434406891	7031	Economy	16400.00
0005434406890	7031	Economy	16400.00
0005434299220	7031	Economy	16400.00
0005434406839	7031	Economy	16400.00
0005434406894	7031	Economy	16400.00
0005434299239	7031	Economy	16400.00
0005434299227	7031	Economy	16400.00
0005434406889	7031	Economy	16400.00
0005434299238	7031	Economy	16400.00
0005434299235	7031	Economy	16400.00
0005434406863	7031	Economy	16400.00
0005434299222	7031	Economy	16400.00
0005434406842	7031	Economy	16400.00
0005434299219	7031	Economy	16400.00
0005435310880	26889	Business	49100.00
0005435293090	26889	Business	49100.00
0005435293087	26889	Business	49100.00
0005435293092	26889	Business	49100.00
0005435293084	26889	Business	49100.00
0005432058321	26889	Economy	16400.00
0005432058324	26889	Economy	16400.00
0005435310885	26889	Economy	16400.00
0005435310881	26889	Economy	16400.00
0005435310890	26889	Economy	16400.00
0005435310884	26889	Economy	16400.00
0005435310877	26889	Economy	16400.00
0005435293083	26889	Economy	16400.00
0005435293091	26889	Economy	16400.00
0005435310891	26889	Economy	16400.00
0005432058322	26889	Economy	18000.00
0005435310886	26889	Economy	18000.00
0005432058323	26889	Economy	16400.00
0005435310879	26889	Economy	16400.00
0005435310894	26889	Economy	16400.00
0005435293089	26889	Economy	16400.00
0005435293093	26889	Economy	16400.00
0005435310893	26889	Economy	16400.00
0005432058320	26889	Economy	16400.00
0005435310876	26889	Economy	16400.00
0005435310883	26889	Economy	16400.00
0005435310889	26889	Economy	16400.00
0005435310892	26889	Economy	16400.00
0005435310887	26889	Economy	16400.00
0005435293085	26889	Economy	16400.00
0005435310882	26889	Economy	16400.00
0005435293095	26889	Economy	16400.00
0005435293088	26889	Economy	16400.00
0005435293086	26889	Economy	16400.00
0005435293094	26889	Economy	16400.00
0005435310878	26889	Economy	16400.00
0005435310888	26889	Economy	16400.00
0005434512037	6462	Economy	16500.00
0005432603787	6462	Economy	16500.00
0005432603803	6462	Economy	16500.00
0005432603786	6462	Economy	15000.00
0005432603774	6462	Economy	15000.00
0005432603780	6462	Economy	15000.00
0005432603783	6462	Economy	15000.00
0005432603784	6462	Economy	15000.00
0005432603773	6462	Economy	15000.00
0005432603768	6462	Economy	15000.00
0005432603778	6462	Economy	15000.00
0005432603770	6462	Economy	15000.00
0005432603767	6462	Economy	15000.00
0005432603791	6462	Economy	15000.00
0005432603775	6462	Economy	15000.00
0005432603797	6462	Economy	15000.00
0005432603792	6462	Economy	15000.00
0005432603795	6462	Economy	15000.00
0005432603802	6462	Economy	15000.00
0005432603799	6462	Economy	15000.00
0005434512036	6462	Economy	15000.00
0005432603777	6462	Economy	15000.00
0005432603766	6462	Economy	15000.00
0005432603781	6462	Economy	15000.00
0005432603764	6462	Economy	15000.00
0005432603772	6462	Economy	15000.00
0005432603800	6462	Economy	15000.00
0005432603776	6462	Economy	15000.00
0005432603785	6462	Economy	15000.00
0005432603789	6462	Economy	15000.00
0005432603794	6462	Economy	15000.00
0005432603790	6462	Economy	15000.00
0005432603771	6462	Economy	15000.00
0005432603782	6462	Economy	15000.00
0005434512035	6462	Economy	15000.00
0005432603798	6462	Economy	15000.00
0005432603793	6462	Economy	15000.00
0005432603796	6462	Economy	15000.00
0005432603763	6462	Economy	15000.00
0005432603801	6462	Economy	15000.00
0005432603769	6462	Economy	15000.00
0005432603779	6462	Economy	15000.00
0005432603788	6462	Economy	15000.00
0005432603765	6462	Economy	15000.00
0005435221038	21339	Economy	15000.00
0005435221040	21339	Economy	15000.00
0005435221039	21339	Economy	15000.00
0005435221502	21339	Economy	15000.00
0005435221501	21339	Economy	15000.00
0005433251028	15022	Business	18900.00
0005433251050	15022	Business	18900.00
0005433251036	15022	Business	18900.00
0005433251048	15022	Business	18900.00
0005433251030	15022	Business	18900.00
0005433251047	15022	Economy	6300.00
0005433251033	15022	Economy	6300.00
0005433251039	15022	Economy	6300.00
0005433251023	15022	Economy	6300.00
0005433251045	15022	Economy	6900.00
0005433251038	15022	Economy	6900.00
0005433251022	15022	Economy	6300.00
0005433251025	15022	Economy	6300.00
0005433251049	15022	Economy	6300.00
0005433251046	15022	Economy	6300.00
0005433251029	15022	Economy	6300.00
0005433251041	15022	Economy	6300.00
0005433251027	15022	Economy	6300.00
0005433251026	15022	Economy	6300.00
0005433251051	15022	Economy	6300.00
0005433251037	15022	Economy	6300.00
0005433251043	15022	Economy	6300.00
0005433251034	15022	Economy	6300.00
0005433251044	15022	Economy	6300.00
0005433251035	15022	Economy	6300.00
0005433251024	15022	Economy	6300.00
0005433251042	15022	Economy	6300.00
0005433251053	15022	Economy	6300.00
0005433251031	15022	Economy	6300.00
0005433251032	15022	Economy	6300.00
0005433251040	15022	Economy	6300.00
0005433251052	15022	Economy	6300.00
0005434906506	25821	Business	18900.00
0005434906468	25821	Business	18900.00
0005434906483	25821	Business	18900.00
0005434906490	25821	Business	18900.00
0005434906482	25821	Business	18900.00
0005434906498	25821	Economy	6300.00
0005434906463	25821	Economy	6300.00
0005434906508	25821	Economy	6300.00
0005434906515	25821	Economy	6300.00
0005434906500	25821	Economy	6300.00
0005434906509	25821	Economy	6300.00
0005434906469	25821	Economy	6300.00
0005434906510	25821	Economy	6300.00
0005434906471	25821	Economy	6900.00
0005434906476	25821	Economy	6900.00
0005434906503	25821	Economy	6900.00
0005434906460	25821	Economy	6300.00
0005434906487	25821	Economy	6300.00
0005434906512	25821	Economy	6300.00
0005434906496	25821	Economy	6300.00
0005434906505	25821	Economy	6300.00
0005434906458	25821	Economy	6300.00
0005434906489	25821	Economy	6300.00
0005434906470	25821	Economy	6300.00
0005434906462	25821	Economy	6300.00
0005434906504	25821	Economy	6300.00
0005434906465	25821	Economy	6300.00
0005434906466	25821	Economy	6300.00
0005434906461	25821	Economy	6300.00
0005434906457	25821	Economy	6300.00
0005434906497	25821	Economy	6300.00
0005434906464	25821	Economy	6300.00
0005434906474	25821	Economy	6300.00
0005434906486	25821	Economy	6300.00
0005434906488	25821	Economy	6300.00
0005434906481	25821	Economy	6300.00
0005434906475	25821	Economy	6300.00
0005434906507	25821	Economy	6300.00
0005434906511	25821	Economy	6300.00
0005434906480	25821	Economy	6300.00
0005434906492	25821	Economy	6300.00
0005434906479	25821	Economy	6300.00
0005434906493	25821	Economy	6300.00
0005434906477	25821	Economy	6300.00
0005434906485	25821	Economy	6300.00
0005434906514	25821	Economy	6300.00
0005434906499	25821	Economy	6300.00
0005434906473	25821	Economy	6300.00
0005434906491	25821	Economy	6300.00
0005434906478	25821	Economy	6300.00
0005434906467	25821	Economy	6300.00
0005434906495	25821	Economy	6300.00
0005434906494	25821	Economy	6300.00
0005434906501	25821	Economy	6300.00
0005434906472	25821	Economy	6300.00
0005434906513	25821	Economy	6300.00
0005434906502	25821	Economy	6300.00
0005434906456	25821	Economy	6300.00
0005434906484	25821	Economy	6300.00
0005434906459	25821	Economy	6300.00
0005432607497	22468	Economy	16400.00
0005432609664	22468	Economy	14900.00
0005432607500	22468	Economy	14900.00
0005432609665	22468	Economy	14900.00
0005432607501	22468	Economy	14900.00
0005432607495	22468	Economy	14900.00
0005432609669	22468	Economy	14900.00
0005432609658	22468	Economy	14900.00
0005432609663	22468	Economy	14900.00
0005432609668	22468	Economy	14900.00
0005432607504	22468	Economy	14900.00
0005432607505	22468	Economy	14900.00
0005432609659	22468	Economy	14900.00
0005432607498	22468	Economy	14900.00
0005432607502	22468	Economy	14900.00
0005432609670	22468	Economy	14900.00
0005432609671	22468	Economy	14900.00
0005432609667	22468	Economy	14900.00
0005432609661	22468	Economy	14900.00
0005432607496	22468	Economy	14900.00
0005432609662	22468	Economy	14900.00
0005432607499	22468	Economy	14900.00
0005432607494	22468	Economy	14900.00
0005432609660	22468	Economy	14900.00
0005432607503	22468	Economy	14900.00
0005432609666	22468	Economy	14900.00
0005435841461	31727	Economy	14900.00
0005435841462	31727	Economy	14900.00
0005435841085	31727	Economy	14900.00
0005435841463	31727	Economy	14900.00
0005435841086	31727	Economy	14900.00
0005435841082	31727	Economy	14900.00
0005435841464	31727	Economy	14900.00
0005435841081	31727	Economy	14900.00
0005435841084	31727	Economy	14900.00
0005435841083	31727	Economy	14900.00
0005433007997	14196	Business	52300.00
0005433007994	14196	Business	52300.00
0005433007990	14196	Business	52300.00
0005433007975	14196	Business	52300.00
0005433007985	14196	Business	52300.00
0005433007988	14196	Business	52300.00
0005433007965	14196	Business	52300.00
0005433007962	14196	Business	52300.00
0005433007974	14196	Economy	17400.00
0005433007992	14196	Economy	17400.00
0005433007966	14196	Economy	17400.00
0005433007995	14196	Economy	17400.00
0005433007963	14196	Economy	19200.00
0005433007969	14196	Economy	17400.00
0005433008004	14196	Economy	17400.00
0005433007961	14196	Economy	17400.00
0005433007964	14196	Economy	17400.00
0005433007968	14196	Economy	17400.00
0005433007972	14196	Economy	17400.00
0005433007989	14196	Economy	17400.00
0005433008000	14196	Economy	17400.00
0005433007977	14196	Economy	17400.00
0005433007986	14196	Economy	17400.00
0005433007993	14196	Economy	17400.00
0005433008005	14196	Economy	17400.00
0005433007981	14196	Economy	17400.00
0005433008003	14196	Economy	17400.00
0005433007971	14196	Economy	17400.00
0005433007999	14196	Economy	17400.00
0005433007984	14196	Economy	17400.00
0005433007970	14196	Economy	17400.00
0005433007967	14196	Economy	17400.00
0005433007987	14196	Economy	17400.00
0005433007980	14196	Economy	17400.00
0005433007996	14196	Economy	17400.00
0005433008006	14196	Economy	17400.00
0005433007978	14196	Economy	17400.00
0005433007998	14196	Economy	17400.00
0005433007979	14196	Economy	17400.00
0005433008007	14196	Economy	17400.00
0005433007982	14196	Economy	17400.00
0005433007976	14196	Economy	17400.00
0005433007983	14196	Economy	17400.00
0005433008001	14196	Economy	17400.00
0005433008002	14196	Economy	17400.00
0005433007991	14196	Economy	17400.00
0005433007973	14196	Economy	17400.00
0005433810493	22856	Economy	17400.00
0005433810495	22856	Economy	17400.00
0005433810494	22856	Economy	17400.00
0005434925322	20516	Business	22900.00
0005434925319	20516	Business	22900.00
0005434925310	20516	Business	22900.00
0005434925315	20516	Business	22900.00
0005434925318	20516	Business	22900.00
0005434925326	20516	Business	22900.00
0005434925325	20516	Business	22900.00
0005434925314	20516	Economy	7600.00
0005434925335	20516	Economy	8400.00
0005434925307	20516	Economy	8400.00
0005434925312	20516	Economy	7600.00
0005434925342	20516	Economy	7600.00
0005434925339	20516	Economy	7600.00
0005434925337	20516	Economy	7600.00
0005434925317	20516	Economy	7600.00
0005434925334	20516	Economy	7600.00
0005434925309	20516	Economy	7600.00
0005434925308	20516	Economy	7600.00
0005434925338	20516	Economy	7600.00
0005434925327	20516	Economy	7600.00
0005434925328	20516	Economy	7600.00
0005434925341	20516	Economy	7600.00
0005434925306	20516	Economy	7600.00
0005434925323	20516	Economy	7600.00
0005434925311	20516	Economy	7600.00
0005434925313	20516	Economy	7600.00
0005434925331	20516	Economy	7600.00
0005434925321	20516	Economy	7600.00
0005434925320	20516	Economy	7600.00
0005434925316	20516	Economy	7600.00
0005434925336	20516	Economy	7600.00
0005434925330	20516	Economy	7600.00
0005434925332	20516	Economy	7600.00
0005434925329	20516	Economy	7600.00
0005434925340	20516	Economy	7600.00
0005434925333	20516	Economy	7600.00
0005434925324	20516	Economy	7600.00
0005435487542	15799	Economy	8900.00
0005435487526	15799	Economy	8100.00
0005435487531	15799	Economy	8100.00
0005435487538	15799	Economy	8100.00
0005435487522	15799	Economy	8100.00
0005435487525	15799	Economy	8100.00
0005435487533	15799	Economy	8100.00
0005435487528	15799	Economy	8100.00
0005435487535	15799	Economy	8100.00
0005435487541	15799	Economy	8100.00
0005435487540	15799	Economy	8100.00
0005435487530	15799	Economy	8100.00
0005435487529	15799	Economy	8100.00
0005435487520	15799	Economy	8100.00
0005435487534	15799	Economy	8100.00
0005435487536	15799	Economy	8100.00
0005435487539	15799	Economy	8100.00
0005435487537	15799	Economy	8100.00
0005435487532	15799	Economy	8100.00
0005435487527	15799	Economy	8100.00
0005435487521	15799	Economy	8100.00
0005435487523	15799	Economy	8100.00
0005435487524	15799	Economy	8100.00
0005435998992	19721	Economy	8900.00
0005435998988	19721	Economy	8900.00
0005435998996	19721	Economy	8900.00
0005435998991	19721	Economy	8100.00
0005435998987	19721	Economy	8100.00
0005435998994	19721	Economy	8100.00
0005435998990	19721	Economy	8100.00
0005435998993	19721	Economy	8100.00
0005435998995	19721	Economy	8100.00
0005435998998	19721	Economy	8100.00
0005435998985	19721	Economy	8100.00
0005435998997	19721	Economy	8100.00
0005435998986	19721	Economy	8100.00
0005435998989	19721	Economy	8100.00
0005432142210	5988	Business	199300.00
0005432659677	5988	Business	199300.00
0005435839068	5988	Business	199300.00
0005435839056	5988	Business	199300.00
0005435839047	5988	Business	199300.00
0005435472516	5988	Business	199300.00
0005435839050	5988	Business	199300.00
0005435839053	5988	Business	199300.00
0005435839065	5988	Business	199300.00
0005435839063	5988	Business	199300.00
0005435839055	5988	Economy	66400.00
0005435839062	5988	Economy	66400.00
0005435839067	5988	Economy	66400.00
0005432658562	5988	Economy	66400.00
0005435839066	5988	Economy	73100.00
0005435839059	5988	Economy	73100.00
0005435839069	5988	Economy	66400.00
0005435839052	5988	Economy	66400.00
0005435839058	5988	Economy	66400.00
0005435839061	5988	Economy	66400.00
0005432658563	5988	Economy	66400.00
0005435839054	5988	Economy	66400.00
0005435839071	5988	Economy	66400.00
0005432142209	5988	Economy	66400.00
0005432142206	5988	Economy	66400.00
0005435839060	5988	Economy	66400.00
0005435472515	5988	Economy	66400.00
0005435839048	5988	Economy	66400.00
0005435839064	5988	Economy	66400.00
0005435839051	5988	Economy	66400.00
0005435839049	5988	Economy	66400.00
0005435839057	5988	Economy	66400.00
0005435839045	5988	Economy	66400.00
0005435839070	5988	Economy	66400.00
0005432659678	5988	Economy	66400.00
0005435839046	5988	Economy	66400.00
0005435839072	5988	Economy	66400.00
0005432142208	5988	Economy	66400.00
0005432142207	5988	Economy	66400.00
0005432660790	5988	Economy	66400.00
0005435472573	18048	Business	199300.00
0005435472568	18048	Business	199300.00
0005435472570	18048	Business	199300.00
0005432537028	18048	Business	199300.00
0005435472575	18048	Economy	66400.00
0005432537029	18048	Economy	66400.00
0005435472578	18048	Economy	66400.00
0005435472564	18048	Economy	73100.00
0005435472579	18048	Economy	66400.00
0005435472562	18048	Economy	66400.00
0005435472571	18048	Economy	66400.00
0005435472569	18048	Economy	66400.00
0005435472574	18048	Economy	66400.00
0005435472566	18048	Economy	66400.00
0005435472577	18048	Economy	66400.00
0005435472567	18048	Economy	66400.00
0005435472572	18048	Economy	66400.00
0005435472565	18048	Economy	66400.00
0005435472563	18048	Economy	66400.00
0005435472576	18048	Economy	66400.00
0005435103822	23022	Business	15700.00
0005435103821	23022	Economy	5200.00
0005435103820	23022	Economy	5200.00
0005435103823	23022	Economy	5200.00
0005435103819	23022	Economy	5700.00
0005435103824	23022	Economy	5200.00
0005433284875	32056	Business	15700.00
0005433284855	32056	Business	15700.00
0005433284877	32056	Economy	5200.00
0005433284863	32056	Economy	5200.00
0005433284873	32056	Economy	5200.00
0005433284874	32056	Economy	5200.00
0005433284853	32056	Economy	5200.00
0005433284865	32056	Economy	5200.00
0005433284876	32056	Economy	5200.00
0005433284860	32056	Economy	5200.00
0005433284861	32056	Economy	5200.00
0005433284864	32056	Economy	5700.00
0005433284871	32056	Economy	5700.00
0005433284850	32056	Economy	5200.00
0005433284862	32056	Economy	5200.00
0005433284856	32056	Economy	5200.00
0005433284849	32056	Economy	5200.00
0005433284870	32056	Economy	5200.00
0005433284878	32056	Economy	5200.00
0005433284872	32056	Economy	5200.00
0005433284852	32056	Economy	5200.00
0005433284851	32056	Economy	5200.00
0005433284854	32056	Economy	5200.00
0005433284859	32056	Economy	5200.00
0005433284867	32056	Economy	5200.00
0005433284858	32056	Economy	5200.00
0005433284866	32056	Economy	5200.00
0005433284868	32056	Economy	5200.00
0005433284869	32056	Economy	5200.00
0005433284857	32056	Economy	5200.00
0005435852537	23863	Economy	12300.00
0005435852536	23863	Economy	12300.00
0005435852535	23863	Economy	12300.00
0005435852539	23863	Economy	12300.00
0005435852534	23863	Economy	12300.00
0005435852538	23863	Economy	12300.00
0005432211402	30594	Business	42100.00
0005435212656	30594	Business	42100.00
0005435212674	30594	Business	42100.00
0005435212612	30594	Business	42100.00
0005435212664	30594	Business	42100.00
0005432211401	30594	Comfort	23900.00
0005435212647	30594	Comfort	23900.00
0005435212644	30594	Comfort	23900.00
0005435212643	30594	Comfort	23900.00
0005435212657	30594	Comfort	23900.00
0005435630926	30594	Comfort	23900.00
0005432211400	30594	Comfort	23900.00
0005435725534	30594	Comfort	23900.00
0005435725535	30594	Comfort	23900.00
0005435212635	30594	Comfort	23900.00
0005432211398	30594	Comfort	23900.00
0005435212648	30594	Comfort	23900.00
0005435212672	30594	Comfort	23900.00
0005435212669	30594	Comfort	23900.00
0005435212621	30594	Economy	14000.00
0005435212614	30594	Economy	14000.00
0005432159796	30594	Economy	14000.00
0005435212624	30594	Economy	14000.00
0005435725536	30594	Economy	14000.00
0005435212622	30594	Economy	14000.00
0005432525896	30594	Economy	14000.00
0005434066361	30594	Economy	14000.00
0005435212629	30594	Economy	14000.00
0005435212630	30594	Economy	14000.00
0005435212645	30594	Economy	14000.00
0005435212667	30594	Economy	14000.00
0005435212671	30594	Economy	14000.00
0005435212633	30594	Economy	14000.00
0005435212641	30594	Economy	15400.00
0005432159797	30594	Economy	14000.00
0005435212668	30594	Economy	14000.00
0005435212663	30594	Economy	14000.00
0005435212628	30594	Economy	14000.00
0005435630928	30594	Economy	14000.00
0005435212670	30594	Economy	14000.00
0005432159793	30594	Economy	14000.00
0005433656625	30594	Economy	14000.00
0005435212642	30594	Economy	14000.00
0005435212655	30594	Economy	14000.00
0005435630927	30594	Economy	14000.00
0005435725532	30594	Economy	14000.00
0005435212638	30594	Economy	14000.00
0005435212640	30594	Economy	14000.00
0005435212660	30594	Economy	14000.00
0005435212661	30594	Economy	14000.00
0005435212636	30594	Economy	14000.00
0005433656627	30594	Economy	14000.00
0005435212659	30594	Economy	14000.00
0005432159794	30594	Economy	14000.00
0005435212631	30594	Economy	14000.00
0005435212616	30594	Economy	14000.00
0005432159795	30594	Economy	14000.00
0005435212626	30594	Economy	14000.00
0005432211399	30594	Economy	14000.00
0005435212618	30594	Economy	14000.00
0005433656626	30594	Economy	14000.00
0005432525895	30594	Economy	14000.00
0005435212632	30594	Economy	14000.00
0005435212650	30594	Economy	14000.00
0005435212652	30594	Economy	14000.00
0005435212619	30594	Economy	14000.00
0005432525694	30594	Economy	14000.00
0005435212666	30594	Economy	14000.00
0005435212637	30594	Economy	14000.00
0005435212620	30594	Economy	15400.00
0005435212608	30594	Economy	15400.00
0005435212625	30594	Economy	14000.00
0005435725533	30594	Economy	14000.00
0005435212673	30594	Economy	14000.00
0005435212613	30594	Economy	14000.00
0005435212639	30594	Economy	14000.00
0005435212665	30594	Economy	14000.00
0005435212662	30594	Economy	14000.00
0005435212627	30594	Economy	14000.00
0005435212615	30594	Economy	14000.00
0005435212623	30594	Economy	14000.00
0005435212653	30594	Economy	14000.00
0005435212651	30594	Economy	14000.00
0005435212611	30594	Economy	14000.00
0005435212634	30594	Economy	14000.00
0005432211403	30594	Economy	14000.00
0005432525637	30594	Economy	14000.00
0005435212649	30594	Economy	14000.00
0005435212607	30594	Economy	14000.00
0005435212606	30594	Economy	14000.00
0005432525636	30594	Economy	14000.00
0005435212658	30594	Economy	14000.00
0005435212617	30594	Economy	14000.00
0005435212654	30594	Economy	14000.00
0005435212610	30594	Economy	14000.00
0005432211397	30594	Economy	14000.00
0005435212609	30594	Economy	14000.00
0005435212646	30594	Economy	14000.00
0005433367384	24841	Business	9800.00
0005433367396	24841	Business	9800.00
0005433367374	24841	Business	9800.00
0005433367398	24841	Business	9800.00
0005433367379	24841	Economy	3300.00
0005433367377	24841	Economy	3300.00
0005433367382	24841	Economy	3300.00
0005433367402	24841	Economy	3600.00
0005433367381	24841	Economy	3600.00
0005433367392	24841	Economy	3600.00
0005433367385	24841	Economy	3600.00
0005433367394	24841	Economy	3300.00
0005433367380	24841	Economy	3300.00
0005433367387	24841	Economy	3300.00
0005433367373	24841	Economy	3300.00
0005433367372	24841	Economy	3300.00
0005433367399	24841	Economy	3300.00
0005433367401	24841	Economy	3300.00
0005433367406	24841	Economy	3300.00
0005433367389	24841	Economy	3300.00
0005433367395	24841	Economy	3300.00
0005433367407	24841	Economy	3300.00
0005433367376	24841	Economy	3300.00
0005433367393	24841	Economy	3300.00
0005433367378	24841	Economy	3300.00
0005433367386	24841	Economy	3300.00
0005433367388	24841	Economy	3300.00
0005433367397	24841	Economy	3300.00
0005433367400	24841	Economy	3300.00
0005433367408	24841	Economy	3300.00
0005433367403	24841	Economy	3300.00
0005433367391	24841	Economy	3300.00
0005433367383	24841	Economy	3300.00
0005433367405	24841	Economy	3300.00
0005433367404	24841	Economy	3300.00
0005433367409	24841	Economy	3300.00
0005433367375	24841	Economy	3300.00
0005433367390	24841	Economy	3300.00
0005434979404	2057	Economy	10500.00
0005434979400	2057	Economy	10500.00
0005434979394	2057	Economy	10500.00
0005434979389	2057	Economy	10500.00
0005434979403	2057	Economy	9500.00
0005434979380	2057	Economy	9500.00
0005435801657	2057	Economy	9500.00
0005434979393	2057	Economy	9500.00
0005434979385	2057	Economy	9500.00
0005434979399	2057	Economy	9500.00
0005434979384	2057	Economy	9500.00
0005434979405	2057	Economy	9500.00
0005434979401	2057	Economy	9500.00
0005434979383	2057	Economy	9500.00
0005434979388	2057	Economy	9500.00
0005434979375	2057	Economy	9500.00
0005434979382	2057	Economy	9500.00
0005434979392	2057	Economy	9500.00
0005434979387	2057	Economy	9500.00
0005434979381	2057	Economy	9500.00
0005434979398	2057	Economy	9500.00
0005434979386	2057	Economy	9500.00
0005434979376	2057	Economy	9500.00
0005434979395	2057	Economy	9500.00
0005434979378	2057	Economy	9500.00
0005434979391	2057	Economy	9500.00
0005435801656	2057	Economy	9500.00
0005434979406	2057	Economy	9500.00
0005434979397	2057	Economy	9500.00
0005434979390	2057	Economy	9500.00
0005435801655	2057	Economy	9500.00
0005434979396	2057	Economy	9500.00
0005434979402	2057	Economy	9500.00
0005434979379	2057	Economy	9500.00
0005434979377	2057	Economy	9500.00
0005434952480	2591	Economy	5300.00
0005434952481	2591	Economy	5300.00
0005434952482	2591	Economy	5300.00
0005434952483	2591	Economy	5300.00
0005433256391	28225	Economy	5300.00
0005433256392	28225	Economy	5300.00
0005433111477	19828	Economy	8700.00
0005433112356	19828	Economy	8700.00
0005433112357	19828	Economy	8700.00
0005433111478	19828	Economy	8700.00
0005433111476	19828	Economy	8700.00
0005434136675	11964	Business	9700.00
0005434136822	11964	Economy	3500.00
0005434136723	11964	Economy	3200.00
0005434136836	11964	Economy	3200.00
0005434136676	11964	Economy	3200.00
0005434136821	11964	Economy	3200.00
0005434136997	28736	Business	9700.00
0005434137008	28736	Business	9700.00
0005434136978	28736	Business	9700.00
0005434136965	28736	Business	9700.00
0005434136940	28736	Business	9700.00
0005434137004	28736	Business	9700.00
0005434136983	28736	Business	9700.00
0005434136971	28736	Business	9700.00
0005434137007	28736	Business	9700.00
0005434137003	28736	Business	9700.00
0005434136954	28736	Business	9700.00
0005434136947	28736	Economy	3200.00
0005434136948	28736	Economy	3200.00
0005434136992	28736	Economy	3200.00
0005434136964	28736	Economy	3200.00
0005434136968	28736	Economy	3200.00
0005434136977	28736	Economy	3200.00
0005434137011	28736	Economy	3200.00
0005434136993	28736	Economy	3200.00
0005434136958	28736	Economy	3500.00
0005434136946	28736	Economy	3500.00
0005434137009	28736	Economy	3500.00
0005434136961	28736	Economy	3500.00
0005434136974	28736	Economy	3500.00
0005434136969	28736	Economy	3200.00
0005434136970	28736	Economy	3200.00
0005434136975	28736	Economy	3200.00
0005434136987	28736	Economy	3200.00
0005434137002	28736	Economy	3200.00
0005434136986	28736	Economy	3200.00
0005434137010	28736	Economy	3200.00
0005434137000	28736	Economy	3200.00
0005434136943	28736	Economy	3200.00
0005434136984	28736	Economy	3200.00
0005434137005	28736	Economy	3200.00
0005434136963	28736	Economy	3200.00
0005434136998	28736	Economy	3200.00
0005434136942	28736	Economy	3200.00
0005434136960	28736	Economy	3200.00
0005434136995	28736	Economy	3200.00
0005434136937	28736	Economy	3200.00
0005434137012	28736	Economy	3200.00
0005434136976	28736	Economy	3200.00
0005434136994	28736	Economy	3200.00
0005434136991	28736	Economy	3200.00
0005434136935	28736	Economy	3200.00
0005434136949	28736	Economy	3200.00
0005434136955	28736	Economy	3200.00
0005434136988	28736	Economy	3200.00
0005434136952	28736	Economy	3200.00
0005434136999	28736	Economy	3200.00
0005434136945	28736	Economy	3200.00
0005434136962	28736	Economy	3200.00
0005434136973	28736	Economy	3200.00
0005434136980	28736	Economy	3200.00
0005434136996	28736	Economy	3200.00
0005434136951	28736	Economy	3200.00
0005434136990	28736	Economy	3200.00
0005434136944	28736	Economy	3200.00
0005434137013	28736	Economy	3200.00
0005434136941	28736	Economy	3200.00
0005434136956	28736	Economy	3200.00
0005434136989	28736	Economy	3200.00
0005434136972	28736	Economy	3200.00
0005434136936	28736	Economy	3200.00
0005434136950	28736	Economy	3200.00
0005434136938	28736	Economy	3200.00
0005434137006	28736	Economy	3200.00
0005434136959	28736	Economy	3200.00
0005434136966	28736	Economy	3200.00
0005434136982	28736	Economy	3200.00
0005434136957	28736	Economy	3200.00
0005434136953	28736	Economy	3200.00
0005434136985	28736	Economy	3200.00
0005434136979	28736	Economy	3200.00
0005434136939	28736	Economy	3200.00
0005434137001	28736	Economy	3200.00
0005434136981	28736	Economy	3200.00
0005434136967	28736	Economy	3200.00
0005434466389	6580	Economy	23000.00
0005434466395	6580	Economy	20900.00
0005434466391	6580	Economy	20900.00
0005434466393	6580	Economy	20900.00
0005434466396	6580	Economy	20900.00
0005434466392	6580	Economy	20900.00
0005434466390	6580	Economy	20900.00
0005434466394	6580	Economy	20900.00
0005434466388	6580	Economy	20900.00
0005434466397	6580	Economy	20900.00
0005434190369	19090	Economy	23600.00
0005434190370	19090	Economy	23600.00
0005434190375	19090	Economy	23600.00
0005434190373	19090	Economy	23600.00
0005434190376	19090	Economy	23600.00
0005434190378	19090	Economy	23600.00
0005434190372	19090	Economy	23600.00
0005434190374	19090	Economy	23600.00
0005434190371	19090	Economy	23600.00
0005434190377	19090	Economy	23600.00
0005433538753	6773	Economy	10900.00
0005433534470	6773	Economy	9900.00
0005433538755	6773	Economy	9900.00
0005433538751	6773	Economy	9900.00
0005433538756	6773	Economy	9900.00
0005433538752	6773	Economy	9900.00
0005433534471	6773	Economy	9900.00
0005435259683	6773	Economy	9900.00
0005433538757	6773	Economy	9900.00
0005433538758	6773	Economy	9900.00
0005433538759	6773	Economy	9900.00
0005433538754	6773	Economy	9900.00
0005433534469	6773	Economy	9900.00
0005435259697	24990	Economy	10900.00
0005435259696	24990	Economy	9900.00
0005435259700	24990	Economy	9900.00
0005435259699	24990	Economy	9900.00
0005435259698	24990	Economy	9900.00
0005433511838	842	Economy	14600.00
0005433511841	842	Economy	14600.00
0005433511837	842	Economy	14600.00
0005433511842	842	Economy	14600.00
0005433511836	842	Economy	14600.00
0005433511839	842	Economy	14600.00
0005433511840	842	Economy	14600.00
0005433511843	842	Economy	14600.00
0005432922471	16153	Economy	14600.00
0005432922472	16153	Economy	14600.00
0005432922469	16153	Economy	14600.00
0005432922470	16153	Economy	14600.00
0005435696973	3698	Economy	7900.00
0005435696960	3698	Economy	7200.00
0005435696963	3698	Economy	7200.00
0005435696966	3698	Economy	7200.00
0005435696985	3698	Economy	7200.00
0005435696967	3698	Economy	7200.00
0005435696961	3698	Economy	7200.00
0005435696972	3698	Economy	7200.00
0005434950471	3698	Economy	7200.00
0005435696965	3698	Economy	7200.00
0005435696969	3698	Economy	7200.00
0005435696964	3698	Economy	7200.00
0005434950470	3698	Economy	7200.00
0005434950468	3698	Economy	7200.00
0005435696984	3698	Economy	7200.00
0005435696958	3698	Economy	7200.00
0005435696978	3698	Economy	7200.00
0005435696974	3698	Economy	7200.00
0005435696971	3698	Economy	7200.00
0005435696968	3698	Economy	7200.00
0005435696962	3698	Economy	7200.00
0005434950469	3698	Economy	7200.00
0005435696976	3698	Economy	7200.00
0005435696979	3698	Economy	7200.00
0005435696983	3698	Economy	7200.00
0005435696975	3698	Economy	7200.00
0005435696959	3698	Economy	7200.00
0005435696980	3698	Economy	7200.00
0005435696981	3698	Economy	7200.00
0005435696977	3698	Economy	7200.00
0005435696970	3698	Economy	7200.00
0005435696982	3698	Economy	7200.00
0005435916129	16254	Economy	7200.00
0005435916131	16254	Economy	7200.00
0005435935003	16254	Economy	7200.00
0005435916130	16254	Economy	7200.00
0005434604851	3950	Economy	21300.00
0005432607511	3950	Economy	21300.00
0005433519397	3950	Economy	21300.00
0005434606780	3950	Economy	19300.00
0005434606777	3950	Economy	19300.00
0005432607513	3950	Economy	19300.00
0005432609676	3950	Economy	19300.00
0005434606776	3950	Economy	19300.00
0005432609678	3950	Economy	19300.00
0005432609679	3950	Economy	19300.00
0005432607512	3950	Economy	19300.00
0005434604850	3950	Economy	19300.00
0005432609680	3950	Economy	19300.00
0005434604849	3950	Economy	19300.00
0005434606779	3950	Economy	19300.00
0005433519398	3950	Economy	19300.00
0005433519399	3950	Economy	19300.00
0005432607514	3950	Economy	19300.00
0005433519395	3950	Economy	19300.00
0005434606778	3950	Economy	19300.00
0005433519396	3950	Economy	19300.00
0005432607510	3950	Economy	19300.00
0005432609677	3950	Economy	19300.00
0005434606781	3950	Economy	19300.00
0005434604853	3950	Economy	19300.00
0005434604852	3950	Economy	19300.00
0005435841462	22052	Economy	21300.00
0005435841461	22052	Economy	21300.00
0005435841082	22052	Economy	21300.00
0005435841086	22052	Economy	21300.00
0005435841085	22052	Economy	19300.00
0005435841084	22052	Economy	19300.00
0005435841081	22052	Economy	19300.00
0005435841464	22052	Economy	19300.00
0005435841463	22052	Economy	19300.00
0005435841083	22052	Economy	19300.00
0005435628680	780	Economy	3700.00
0005435628685	780	Economy	3700.00
0005435628684	780	Economy	3700.00
0005435628681	780	Economy	3700.00
0005435628682	780	Economy	3700.00
0005435628679	780	Economy	3700.00
0005435628683	780	Economy	3700.00
0005435628686	780	Economy	3700.00
0005433348912	15989	Economy	3700.00
0005433348914	15989	Economy	3700.00
0005433348911	15989	Economy	3700.00
0005433348913	15989	Economy	3700.00
0005433348915	15989	Economy	3700.00
0005433348910	15989	Economy	3700.00
0005434445214	17234	Economy	7100.00
0005433159283	17615	Economy	7100.00
0005433159284	17615	Economy	7100.00
0005433159285	17615	Economy	7100.00
0005435132744	7904	Economy	5900.00
0005435132738	7904	Economy	5400.00
0005435132747	7904	Economy	5400.00
0005435132742	7904	Economy	5400.00
0005435132741	7904	Economy	5400.00
0005435132745	7904	Economy	5400.00
0005435132739	7904	Economy	5400.00
0005435132746	7904	Economy	5400.00
0005435132743	7904	Economy	5400.00
0005435132740	7904	Economy	5400.00
0005435383078	33101	Economy	5900.00
0005435383076	33101	Economy	5400.00
0005435383080	33101	Economy	5400.00
0005435383081	33101	Economy	5400.00
0005435383079	33101	Economy	5400.00
0005435383077	33101	Economy	5400.00
0005435810996	4416	Business	133200.00
0005435811010	4416	Business	133200.00
0005435811001	4416	Business	133200.00
0005435810999	4416	Economy	44400.00
0005435811000	4416	Economy	44400.00
0005435811002	4416	Economy	44400.00
0005435811009	4416	Economy	44400.00
0005435810998	4416	Economy	44400.00
0005435810997	4416	Economy	44400.00
0005435811004	4416	Economy	44400.00
0005435811008	4416	Economy	44400.00
0005435811003	4416	Economy	44400.00
0005435811007	4416	Economy	44400.00
0005435811005	4416	Economy	44400.00
0005435811006	4416	Economy	44400.00
0005435938848	29446	Business	133200.00
0005435938852	29446	Business	133200.00
0005435938853	29446	Business	133200.00
0005435938849	29446	Economy	44400.00
0005435938846	29446	Economy	44400.00
0005435938847	29446	Economy	44400.00
0005435938851	29446	Economy	44400.00
0005435938850	29446	Economy	44400.00
0005435160158	7523	Economy	13800.00
0005435160157	7523	Economy	12500.00
0005435160150	7523	Economy	12500.00
0005435160152	7523	Economy	12500.00
0005435160159	7523	Economy	12500.00
0005435160153	7523	Economy	12500.00
0005435160154	7523	Economy	12500.00
0005435160156	7523	Economy	12500.00
0005435160151	7523	Economy	12500.00
0005435160155	7523	Economy	12500.00
0005435390146	29550	Economy	13800.00
0005435390152	29550	Economy	13800.00
0005435390151	29550	Economy	12500.00
0005435390148	29550	Economy	12500.00
0005435390147	29550	Economy	12500.00
0005435390149	29550	Economy	12500.00
0005435390145	29550	Economy	12500.00
0005435390150	29550	Economy	12500.00
0005435178980	18478	Economy	4900.00
0005435178979	18478	Economy	4900.00
0005432400070	27178	Economy	4900.00
0005432398145	27178	Economy	4900.00
0005432398142	27178	Economy	4900.00
0005432400071	27178	Economy	4900.00
0005432398144	27178	Economy	4900.00
0005432400072	27178	Economy	4900.00
0005432398143	27178	Economy	4900.00
0005432400069	27178	Economy	4900.00
0005432638961	2240	Business	87300.00
0005432638956	2240	Business	87300.00
0005432638971	2240	Business	87300.00
0005432638969	2240	Economy	29100.00
0005432638960	2240	Economy	29100.00
0005432638954	2240	Economy	29100.00
0005432638968	2240	Economy	29100.00
0005432638966	2240	Economy	29100.00
0005432638974	2240	Economy	29100.00
0005432638970	2240	Economy	29100.00
0005432638962	2240	Economy	29100.00
0005432638976	2240	Economy	29100.00
0005432638958	2240	Economy	29100.00
0005432638977	2240	Economy	29100.00
0005432638959	2240	Economy	29100.00
0005432638953	2240	Economy	29100.00
0005432638957	2240	Economy	29100.00
0005432638965	2240	Economy	29100.00
0005432638975	2240	Economy	29100.00
0005432638978	2240	Economy	29100.00
0005432638973	2240	Economy	29100.00
0005432638964	2240	Economy	29100.00
0005432638972	2240	Economy	29100.00
0005432638967	2240	Economy	29100.00
0005432638955	2240	Economy	29100.00
0005432638963	2240	Economy	29100.00
0005435103836	6563	Business	48400.00
0005434503633	6563	Business	48400.00
0005434503641	6563	Business	48400.00
0005434503654	6563	Economy	16100.00
0005435103828	6563	Economy	16100.00
0005435103835	6563	Economy	16100.00
0005435103832	6563	Economy	16100.00
0005434503644	6563	Economy	16100.00
0005434503623	6563	Economy	17800.00
0005434503631	6563	Economy	17800.00
0005434503643	6563	Economy	17800.00
0005434503659	6563	Economy	17800.00
0005434503649	6563	Economy	16100.00
0005435103834	6563	Economy	16100.00
0005434503652	6563	Economy	16100.00
0005434503622	6563	Economy	16100.00
0005434503634	6563	Economy	16100.00
0005434503653	6563	Economy	16100.00
0005434503637	6563	Economy	16100.00
0005434503638	6563	Economy	16100.00
0005434503656	6563	Economy	16100.00
0005434503630	6563	Economy	16100.00
0005434503645	6563	Economy	16100.00
0005434503619	6563	Economy	16100.00
0005434503635	6563	Economy	16100.00
0005434503651	6563	Economy	16100.00
0005434503628	6563	Economy	16100.00
0005434503640	6563	Economy	16100.00
0005434503620	6563	Economy	16100.00
0005434503636	6563	Economy	16100.00
0005434503627	6563	Economy	16100.00
0005435103829	6563	Economy	16100.00
0005434503642	6563	Economy	16100.00
0005434503624	6563	Economy	16100.00
0005435103837	6563	Economy	16100.00
0005435103831	6563	Economy	16100.00
0005434503655	6563	Economy	16100.00
0005434503646	6563	Economy	16100.00
0005434503657	6563	Economy	16100.00
0005434503629	6563	Economy	16100.00
0005434503647	6563	Economy	16100.00
0005434503626	6563	Economy	16100.00
0005434503621	6563	Economy	16100.00
0005434503658	6563	Economy	16100.00
0005434503625	6563	Economy	16100.00
0005434503639	6563	Economy	16100.00
0005434503632	6563	Economy	16100.00
0005434503648	6563	Economy	16100.00
0005434503650	6563	Economy	16100.00
0005435103833	6563	Economy	16100.00
0005435103830	6563	Economy	16100.00
0005435652477	1669	Business	50000.00
0005435652451	1669	Business	50000.00
0005435652480	1669	Business	50000.00
0005435652455	1669	Business	50000.00
0005435652473	1669	Business	50000.00
0005435652436	1669	Business	50000.00
0005435652444	1669	Economy	16700.00
0005435652456	1669	Economy	16700.00
0005435652463	1669	Economy	16700.00
0005435652474	1669	Economy	16700.00
0005435652476	1669	Economy	16700.00
0005435652461	1669	Economy	16700.00
0005435652452	1669	Economy	18300.00
0005435652454	1669	Economy	18300.00
0005435652468	1669	Economy	16700.00
0005435652439	1669	Economy	16700.00
0005435652458	1669	Economy	16700.00
0005435652482	1669	Economy	16700.00
0005435652488	1669	Economy	16700.00
0005435652450	1669	Economy	16700.00
0005435652486	1669	Economy	16700.00
0005435652481	1669	Economy	16700.00
0005435652443	1669	Economy	16700.00
0005435652475	1669	Economy	16700.00
0005435652487	1669	Economy	16700.00
0005435652478	1669	Economy	16700.00
0005435652448	1669	Economy	16700.00
0005435652469	1669	Economy	16700.00
0005435652471	1669	Economy	16700.00
0005435652446	1669	Economy	16700.00
0005435652466	1669	Economy	16700.00
0005435652438	1669	Economy	16700.00
0005435652447	1669	Economy	16700.00
0005435652484	1669	Economy	16700.00
0005435652457	1669	Economy	16700.00
0005435652470	1669	Economy	16700.00
0005435652453	1669	Economy	16700.00
0005435652441	1669	Economy	16700.00
0005435652442	1669	Economy	16700.00
0005435652459	1669	Economy	16700.00
0005435652449	1669	Economy	16700.00
0005435652485	1669	Economy	16700.00
0005435652460	1669	Economy	16700.00
0005435652462	1669	Economy	16700.00
0005435652464	1669	Economy	16700.00
0005435652467	1669	Economy	16700.00
0005435652440	1669	Economy	16700.00
0005435652483	1669	Economy	16700.00
0005435652465	1669	Economy	16700.00
0005435652479	1669	Economy	16700.00
0005435652445	1669	Economy	16700.00
0005435652437	1669	Economy	16700.00
0005435652472	1669	Economy	16700.00
0005433367378	21681	Business	50000.00
0005433367404	21681	Business	50000.00
0005433367388	21681	Business	50000.00
0005433367379	21681	Business	50000.00
0005433367400	21681	Business	50000.00
0005433367408	21681	Business	50000.00
0005433367380	21681	Economy	16700.00
0005433367373	21681	Economy	16700.00
0005433367398	21681	Economy	16700.00
0005433367396	21681	Economy	16700.00
0005433367407	21681	Economy	18300.00
0005433367389	21681	Economy	18300.00
0005433367375	21681	Economy	18300.00
0005433367409	21681	Economy	16700.00
0005433367381	21681	Economy	16700.00
0005433367386	21681	Economy	16700.00
0005433367406	21681	Economy	16700.00
0005433367399	21681	Economy	16700.00
0005433367395	21681	Economy	16700.00
0005433367402	21681	Economy	16700.00
0005433367377	21681	Economy	16700.00
0005433367405	21681	Economy	16700.00
0005433367383	21681	Economy	16700.00
0005433367382	21681	Economy	16700.00
0005433367376	21681	Economy	16700.00
0005433367394	21681	Economy	16700.00
0005433367391	21681	Economy	16700.00
0005433367401	21681	Economy	16700.00
0005433367397	21681	Economy	16700.00
0005433367387	21681	Economy	16700.00
0005433367384	21681	Economy	16700.00
0005433367390	21681	Economy	16700.00
0005433367372	21681	Economy	16700.00
0005433367385	21681	Economy	16700.00
0005433367393	21681	Economy	16700.00
0005433367374	21681	Economy	16700.00
0005433367403	21681	Economy	16700.00
0005433367392	21681	Economy	16700.00
0005435312774	23228	Economy	23000.00
0005435312773	23228	Economy	23000.00
0005435312771	23228	Economy	20900.00
0005435312772	23228	Economy	20900.00
0005435312770	23228	Economy	20900.00
0005433985351	4161	Business	21500.00
0005433985320	4161	Business	21500.00
0005433985324	4161	Business	21500.00
0005433985357	4161	Business	21500.00
0005433985334	4161	Business	21500.00
0005433985313	4161	Business	21500.00
0005433985344	4161	Economy	7200.00
0005433985311	4161	Economy	7200.00
0005433985352	4161	Economy	7200.00
0005433985325	4161	Economy	7200.00
0005433985328	4161	Economy	7200.00
0005433985340	4161	Economy	7200.00
0005433985335	4161	Economy	7900.00
0005433985345	4161	Economy	7900.00
0005433985337	4161	Economy	7200.00
0005433985354	4161	Economy	7200.00
0005435788736	4161	Economy	7200.00
0005433985349	4161	Economy	7200.00
0005433985329	4161	Economy	7200.00
0005433985339	4161	Economy	7200.00
0005433985338	4161	Economy	7200.00
0005433985314	4161	Economy	7200.00
0005433985331	4161	Economy	7200.00
0005433985317	4161	Economy	7200.00
0005433985341	4161	Economy	7200.00
0005433985348	4161	Economy	7200.00
0005433985327	4161	Economy	7200.00
0005433985308	4161	Economy	7200.00
0005433985326	4161	Economy	7200.00
0005433985342	4161	Economy	7200.00
0005433985323	4161	Economy	7200.00
0005433985336	4161	Economy	7200.00
0005433985353	4161	Economy	7200.00
0005433985356	4161	Economy	7200.00
0005433985318	4161	Economy	7200.00
0005433985309	4161	Economy	7200.00
0005433985343	4161	Economy	7200.00
0005433985316	4161	Economy	7200.00
0005433985332	4161	Economy	7200.00
0005433985330	4161	Economy	7200.00
0005433985333	4161	Economy	7200.00
0005433985315	4161	Economy	7200.00
0005433985319	4161	Economy	7200.00
0005433985346	4161	Economy	7200.00
0005433985355	4161	Economy	7200.00
0005433985310	4161	Economy	7200.00
0005433985312	4161	Economy	7200.00
0005433985322	4161	Economy	7200.00
0005435788737	4161	Economy	7200.00
0005433985350	4161	Economy	7200.00
0005433985321	4161	Economy	7200.00
0005433985347	4161	Economy	7200.00
0005435720120	24774	Economy	9400.00
0005435720121	24774	Economy	9400.00
0005435719552	24774	Economy	9400.00
0005434509033	1622	Economy	17000.00
0005434509035	1622	Economy	17000.00
0005434509044	1622	Economy	17000.00
0005434509038	1622	Economy	15500.00
0005434509036	1622	Economy	15500.00
0005434509051	1622	Economy	15500.00
0005434509043	1622	Economy	15500.00
0005434509041	1622	Economy	15500.00
0005434509039	1622	Economy	15500.00
0005434509032	1622	Economy	15500.00
0005434509042	1622	Economy	15500.00
0005434509040	1622	Economy	15500.00
0005434509045	1622	Economy	15500.00
0005434509034	1622	Economy	15500.00
0005434509047	1622	Economy	15500.00
0005434509037	1622	Economy	15500.00
0005434509049	1622	Economy	15500.00
0005434509046	1622	Economy	15500.00
0005434509050	1622	Economy	15500.00
0005434509048	1622	Economy	15500.00
0005434509052	1622	Economy	15500.00
0005434509031	1622	Economy	15500.00
0005432869443	17863	Economy	6600.00
0005432869445	17863	Economy	6000.00
0005432869444	17863	Economy	6000.00
0005432869442	17863	Economy	6000.00
0005432869440	17863	Economy	6000.00
0005432869439	17863	Economy	6000.00
0005432869438	17863	Economy	6000.00
0005432869441	17863	Economy	6000.00
0005434151668	17863	Economy	6000.00
0005434151669	17863	Economy	6000.00
0005434151667	17863	Economy	6000.00
0005434151666	17863	Economy	6000.00
0005432665244	26317	Business	18000.00
0005432657406	26317	Business	18000.00
0005432658561	26317	Business	18000.00
0005432655356	26317	Business	18000.00
0005432655358	26317	Economy	6000.00
0005432657404	26317	Economy	6000.00
0005432660788	26317	Economy	6600.00
0005432667423	26317	Economy	6600.00
0005432655359	26317	Economy	6600.00
0005432659676	26317	Economy	6000.00
0005432655352	26317	Economy	6000.00
0005432655361	26317	Economy	6000.00
0005432657402	26317	Economy	6000.00
0005432667425	26317	Economy	6000.00
0005432655350	26317	Economy	6000.00
0005432655362	26317	Economy	6000.00
0005432655355	26317	Economy	6000.00
0005432665245	26317	Economy	6000.00
0005432655357	26317	Economy	6000.00
0005432655360	26317	Economy	6000.00
0005432657403	26317	Economy	6000.00
0005432667424	26317	Economy	6000.00
0005432659675	26317	Economy	6000.00
0005432666358	26317	Economy	6000.00
0005432660789	26317	Economy	6000.00
0005432658560	26317	Economy	6000.00
0005432655351	26317	Economy	6000.00
0005432655353	26317	Economy	6000.00
0005432657405	26317	Economy	6000.00
0005432655354	26317	Economy	6000.00
0005432865909	25075	Business	87300.00
0005432865926	25075	Economy	29100.00
0005432865927	25075	Economy	29100.00
0005432865924	25075	Economy	29100.00
0005432865916	25075	Economy	32000.00
0005432865918	25075	Economy	29100.00
0005432865923	25075	Economy	29100.00
0005432865920	25075	Economy	29100.00
0005432865914	25075	Economy	29100.00
0005432865917	25075	Economy	29100.00
0005432865910	25075	Economy	29100.00
0005432865925	25075	Economy	29100.00
0005432865928	25075	Economy	29100.00
0005432865919	25075	Economy	29100.00
0005432865912	25075	Economy	29100.00
0005432865921	25075	Economy	29100.00
0005432865911	25075	Economy	29100.00
0005432865915	25075	Economy	29100.00
0005432865922	25075	Economy	29100.00
0005432865913	25075	Economy	29100.00
0005432328092	3091	Business	16100.00
0005432328109	3091	Business	16100.00
0005432328106	3091	Business	16100.00
0005432328094	3091	Business	16100.00
0005432328105	3091	Business	16100.00
0005432328085	3091	Business	16100.00
0005432328091	3091	Business	16100.00
0005432328098	3091	Business	16100.00
0005432328122	3091	Economy	5400.00
0005432328124	3091	Economy	5400.00
0005432328096	3091	Economy	5400.00
0005432328123	3091	Economy	5400.00
0005432328116	3091	Economy	5900.00
0005432328097	3091	Economy	5900.00
0005432905023	3091	Economy	5900.00
0005432328078	3091	Economy	5900.00
0005432287121	3091	Economy	5400.00
0005432328110	3091	Economy	5400.00
0005432328115	3091	Economy	5400.00
0005432328083	3091	Economy	5400.00
0005433438787	3091	Economy	5400.00
0005432328121	3091	Economy	5400.00
0005432287122	3091	Economy	5400.00
0005433438795	3091	Economy	5400.00
0005432328087	3091	Economy	5400.00
0005432287123	3091	Economy	5400.00
0005432328080	3091	Economy	5400.00
0005432328103	3091	Economy	5400.00
0005432328090	3091	Economy	5400.00
0005433438789	3091	Economy	5400.00
0005432328084	3091	Economy	5400.00
0005432328100	3091	Economy	5400.00
0005432287124	3091	Economy	5400.00
0005432328099	3091	Economy	5400.00
0005432328102	3091	Economy	5400.00
0005432328104	3091	Economy	5400.00
0005433438793	3091	Economy	5400.00
0005433438792	3091	Economy	5400.00
0005432328095	3091	Economy	5400.00
0005432328086	3091	Economy	5400.00
0005432328088	3091	Economy	5400.00
0005433438786	3091	Economy	5400.00
0005433438791	3091	Economy	5400.00
0005432328120	3091	Economy	5400.00
0005432328119	3091	Economy	5400.00
0005433438788	3091	Economy	5400.00
0005432328113	3091	Economy	5400.00
0005432328089	3091	Economy	5400.00
0005432328114	3091	Economy	5400.00
0005433438785	3091	Economy	5400.00
0005432328112	3091	Economy	5400.00
0005432287120	3091	Economy	5400.00
0005432328093	3091	Economy	5400.00
0005432328111	3091	Economy	5400.00
0005432328082	3091	Economy	5400.00
0005432328079	3091	Economy	5400.00
0005433438790	3091	Economy	5400.00
0005432328117	3091	Economy	5400.00
0005432328108	3091	Economy	5400.00
0005432328118	3091	Economy	5400.00
0005432328081	3091	Economy	5400.00
0005432328107	3091	Economy	5400.00
0005433438794	3091	Economy	5400.00
0005432328101	3091	Economy	5400.00
0005432327914	31118	Business	16100.00
0005432905046	31118	Business	16100.00
0005432905044	31118	Business	16100.00
0005432905047	31118	Economy	5400.00
0005432054266	31118	Economy	5900.00
0005432054264	31118	Economy	5900.00
0005432905042	31118	Economy	5400.00
0005432054265	31118	Economy	5400.00
0005432905043	31118	Economy	5400.00
0005432905048	31118	Economy	5400.00
0005432905045	31118	Economy	5400.00
0005434309567	6205	Business	124600.00
0005435999019	6205	Business	124600.00
0005435999021	6205	Business	124600.00
0005435999034	6205	Economy	41500.00
0005434309564	6205	Economy	41500.00
0005435999023	6205	Economy	41500.00
0005435999020	6205	Economy	41500.00
0005435999027	6205	Economy	41500.00
0005435999025	6205	Economy	41500.00
0005434309558	6205	Economy	41500.00
0005432146172	6205	Economy	41500.00
0005432146174	6205	Economy	41500.00
0005435999022	6205	Economy	41500.00
0005434309562	6205	Economy	41500.00
0005434309569	6205	Economy	45700.00
0005435999014	6205	Economy	45700.00
0005432146171	6205	Economy	45700.00
0005435999018	6205	Economy	41500.00
0005434309556	6205	Economy	41500.00
0005434309560	6205	Economy	41500.00
0005435999026	6205	Economy	41500.00
0005435999017	6205	Economy	41500.00
0005434309566	6205	Economy	41500.00
0005435999029	6205	Economy	41500.00
0005434309557	6205	Economy	41500.00
0005435999028	6205	Economy	41500.00
0005435999016	6205	Economy	41500.00
0005432146173	6205	Economy	41500.00
0005435999033	6205	Economy	41500.00
0005434309559	6205	Economy	41500.00
0005435999030	6205	Economy	41500.00
0005435999015	6205	Economy	41500.00
0005434309565	6205	Economy	41500.00
0005435999032	6205	Economy	41500.00
0005435999031	6205	Economy	41500.00
0005435999013	6205	Economy	41500.00
0005434309568	6205	Economy	41500.00
0005435999024	6205	Economy	41500.00
0005434309561	6205	Economy	41500.00
0005434309563	6205	Economy	41500.00
0005435487536	19546	Business	124600.00
0005435487527	19546	Business	124600.00
0005435487530	19546	Business	124600.00
0005435296968	19546	Economy	41500.00
0005435487540	19546	Economy	41500.00
0005435296971	19546	Economy	41500.00
0005435487528	19546	Economy	41500.00
0005435487537	19546	Economy	41500.00
0005435296970	19546	Economy	41500.00
0005435296969	19546	Economy	41500.00
0005435296967	19546	Economy	41500.00
0005435487521	19546	Economy	45700.00
0005435487538	19546	Economy	45700.00
0005435487531	19546	Economy	41500.00
0005435487535	19546	Economy	41500.00
0005435487524	19546	Economy	41500.00
0005435296965	19546	Economy	41500.00
0005435487532	19546	Economy	41500.00
0005435487542	19546	Economy	41500.00
0005435487523	19546	Economy	41500.00
0005435487533	19546	Economy	41500.00
0005435296966	19546	Economy	41500.00
0005435487534	19546	Economy	41500.00
0005435487541	19546	Economy	41500.00
0005435487529	19546	Economy	41500.00
0005435487525	19546	Economy	41500.00
0005435487539	19546	Economy	41500.00
0005435487522	19546	Economy	41500.00
0005435487526	19546	Economy	41500.00
0005435487520	19546	Economy	41500.00
0005433158102	17539	Economy	13600.00
0005433158101	17539	Economy	12300.00
0005433158100	17539	Economy	12300.00
0005433158103	17539	Economy	12300.00
0005433158099	17539	Economy	12300.00
0005434565736	1552	Business	86000.00
0005434565744	1552	Business	86000.00
0005435502039	1552	Business	86000.00
0005435517675	1552	Business	86000.00
0005432291899	1552	Business	86000.00
0005435502034	1552	Business	86000.00
0005435502024	1552	Business	86000.00
0005435502028	1552	Economy	28700.00
0005435517670	1552	Economy	28700.00
0005435502031	1552	Economy	28700.00
0005435517687	1552	Economy	28700.00
0005435517684	1552	Economy	28700.00
0005434565739	1552	Economy	28700.00
0005435502036	1552	Economy	28700.00
0005435517677	1552	Economy	31500.00
0005435517683	1552	Economy	31500.00
0005435508210	1552	Economy	31500.00
0005435502026	1552	Economy	31500.00
0005435517679	1552	Economy	28700.00
0005435502023	1552	Economy	28700.00
0005435508212	1552	Economy	28700.00
0005435502021	1552	Economy	28700.00
0005435508215	1552	Economy	28700.00
0005435517676	1552	Economy	28700.00
0005435517673	1552	Economy	28700.00
0005435517674	1552	Economy	28700.00
0005435517672	1552	Economy	28700.00
0005435508213	1552	Economy	28700.00
0005432291898	1552	Economy	28700.00
0005434565734	1552	Economy	28700.00
0005435508217	1552	Economy	28700.00
0005435517671	1552	Economy	28700.00
0005435502027	1552	Economy	28700.00
0005435517681	1552	Economy	28700.00
0005435508214	1552	Economy	28700.00
0005435502025	1552	Economy	28700.00
0005434565742	1552	Economy	28700.00
0005435502032	1552	Economy	28700.00
0005435502041	1552	Economy	28700.00
0005435508211	1552	Economy	28700.00
0005435517678	1552	Economy	28700.00
0005435517685	1552	Economy	28700.00
0005435508219	1552	Economy	28700.00
0005435502035	1552	Economy	28700.00
0005435508218	1552	Economy	28700.00
0005435502038	1552	Economy	28700.00
0005434565743	1552	Economy	28700.00
0005434565745	1552	Economy	28700.00
0005435508220	1552	Economy	28700.00
0005435502029	1552	Economy	28700.00
0005435517686	1552	Economy	28700.00
0005435502037	1552	Economy	28700.00
0005435517682	1552	Economy	28700.00
0005435517669	1552	Economy	28700.00
0005435517668	1552	Economy	28700.00
0005435502030	1552	Economy	28700.00
0005435517680	1552	Economy	28700.00
0005435508221	1552	Economy	28700.00
0005434565740	1552	Economy	28700.00
0005434565737	1552	Economy	28700.00
0005435508216	1552	Economy	28700.00
0005434565741	1552	Economy	28700.00
0005435502033	1552	Economy	28700.00
0005435517688	1552	Economy	28700.00
0005433185968	1552	Economy	28700.00
0005434565735	1552	Economy	28700.00
0005435502040	1552	Economy	28700.00
0005434565738	1552	Economy	28700.00
0005435502022	1552	Economy	28700.00
0005433186007	20856	Economy	28700.00
0005433186008	20856	Economy	28700.00
0005433186010	20856	Economy	28700.00
0005433186009	20856	Economy	28700.00
0005433186005	20856	Economy	28700.00
0005433186004	20856	Economy	28700.00
0005433186006	20856	Economy	28700.00
0005435153656	3918	Economy	19700.00
0005435153657	3918	Economy	19700.00
0005435153655	3918	Economy	19700.00
0005435153658	3918	Economy	19700.00
0005435153653	3918	Economy	19700.00
0005435153654	3918	Economy	19700.00
0005435931553	21852	Economy	19700.00
0005435931552	21852	Economy	19700.00
0005432628660	7202	Economy	14300.00
0005432628653	7202	Economy	13000.00
0005432628650	7202	Economy	13000.00
0005432628655	7202	Economy	13000.00
0005432628657	7202	Economy	13000.00
0005432628648	7202	Economy	13000.00
0005432628654	7202	Economy	13000.00
0005432628656	7202	Economy	13000.00
0005432628647	7202	Economy	13000.00
0005432628649	7202	Economy	13000.00
0005432628651	7202	Economy	13000.00
0005432628658	7202	Economy	13000.00
0005432628652	7202	Economy	13000.00
0005432628659	7202	Economy	13000.00
0005435225482	28131	Economy	14300.00
0005435225480	28131	Economy	13000.00
0005435225477	28131	Economy	13000.00
0005435225476	28131	Economy	13000.00
0005435225478	28131	Economy	13000.00
0005435225481	28131	Economy	13000.00
0005432628585	28131	Economy	13000.00
0005435225479	28131	Economy	13000.00
0005435225475	28131	Economy	13000.00
0005435960000	8744	Economy	10500.00
0005435960001	8744	Economy	10500.00
0005435959998	8744	Economy	10500.00
0005435959999	8744	Economy	10500.00
0005434267901	15259	Economy	11500.00
0005434267899	15259	Economy	10500.00
0005434267900	15259	Economy	10500.00
0005432674936	1198	Business	115000.00
0005432692623	1198	Business	115000.00
0005432692645	1198	Business	115000.00
0005432674938	1198	Business	115000.00
0005432692648	1198	Business	115000.00
0005432692639	1198	Business	115000.00
0005432674930	1198	Business	115000.00
0005432677516	1198	Business	115000.00
0005432674937	1198	Business	115000.00
0005432692651	1198	Business	115000.00
0005432692642	1198	Economy	38300.00
0005432677515	1198	Economy	38300.00
0005432692636	1198	Economy	38300.00
0005432692634	1198	Economy	38300.00
0005432692630	1198	Economy	38300.00
0005432674926	1198	Economy	38300.00
0005432692622	1198	Economy	42200.00
0005432692647	1198	Economy	38300.00
0005432692635	1198	Economy	38300.00
0005432674924	1198	Economy	38300.00
0005432692649	1198	Economy	38300.00
0005432674933	1198	Economy	38300.00
0005432692628	1198	Economy	38300.00
0005432692643	1198	Economy	38300.00
0005432674925	1198	Economy	38300.00
0005432692646	1198	Economy	38300.00
0005432692640	1198	Economy	38300.00
0005432692631	1198	Economy	38300.00
0005432692650	1198	Economy	38300.00
0005432677517	1198	Economy	38300.00
0005432677519	1198	Economy	38300.00
0005432674931	1198	Economy	38300.00
0005432674932	1198	Economy	38300.00
0005432692629	1198	Economy	38300.00
0005432692625	1198	Economy	38300.00
0005432692633	1198	Economy	38300.00
0005432692652	1198	Economy	38300.00
0005432674927	1198	Economy	38300.00
0005432692632	1198	Economy	38300.00
0005432674929	1198	Economy	38300.00
0005432692624	1198	Economy	38300.00
0005432692644	1198	Economy	38300.00
0005432677518	1198	Economy	38300.00
0005432674928	1198	Economy	38300.00
0005432674935	1198	Economy	38300.00
0005432692626	1198	Economy	38300.00
0005432692641	1198	Economy	38300.00
0005432692637	1198	Economy	38300.00
0005432692627	1198	Economy	38300.00
0005432674934	1198	Economy	38300.00
0005432692638	1198	Economy	38300.00
0005432873197	17482	Business	115000.00
0005432873201	17482	Economy	38300.00
0005432873196	17482	Economy	38300.00
0005432873199	17482	Economy	38300.00
0005432873200	17482	Economy	38300.00
0005432873198	17482	Economy	38300.00
0005434434983	1143	Economy	15200.00
0005434434972	1143	Economy	13900.00
0005434434980	1143	Economy	13900.00
0005434434982	1143	Economy	13900.00
0005434434976	1143	Economy	13900.00
0005434434974	1143	Economy	13900.00
0005434434977	1143	Economy	13900.00
0005434434978	1143	Economy	13900.00
0005434434975	1143	Economy	13900.00
0005434434984	1143	Economy	13900.00
0005434434971	1143	Economy	13900.00
0005434434986	1143	Economy	13900.00
0005434434979	1143	Economy	13900.00
0005434434981	1143	Economy	13900.00
0005434434985	1143	Economy	13900.00
0005434434973	1143	Economy	13900.00
0005433156638	17300	Economy	13900.00
0005433156637	17300	Economy	13900.00
0005433156631	17300	Economy	13900.00
0005433156639	17300	Economy	13900.00
0005433156634	17300	Economy	13900.00
0005433156632	17300	Economy	13900.00
0005433156635	17300	Economy	13900.00
0005433156633	17300	Economy	13900.00
0005433156636	17300	Economy	13900.00
0005435086737	4057	Economy	8200.00
0005435086735	4057	Economy	7500.00
0005435086734	4057	Economy	7500.00
0005435086733	4057	Economy	7500.00
0005435086738	4057	Economy	7500.00
0005435086732	4057	Economy	7500.00
0005435928061	4057	Economy	7500.00
0005435086731	4057	Economy	7500.00
0005435086736	4057	Economy	7500.00
0005435928081	24426	Economy	8200.00
0005435928080	24426	Economy	7500.00
0005435928079	24426	Economy	7500.00
0005435928078	24426	Economy	7500.00
0005435706171	2442	Business	86800.00
0005435706153	2442	Economy	28900.00
0005435706168	2442	Economy	28900.00
0005435706147	2442	Economy	28900.00
0005435706149	2442	Economy	31800.00
0005435706145	2442	Economy	31800.00
0005435706164	2442	Economy	28900.00
0005435706172	2442	Economy	28900.00
0005435706157	2442	Economy	28900.00
0005435706165	2442	Economy	28900.00
0005435706146	2442	Economy	28900.00
0005435706158	2442	Economy	28900.00
0005435706148	2442	Economy	28900.00
0005435706170	2442	Economy	28900.00
0005435706152	2442	Economy	28900.00
0005435706167	2442	Economy	28900.00
0005435706174	2442	Economy	28900.00
0005435706166	2442	Economy	28900.00
0005435706156	2442	Economy	28900.00
0005435706177	2442	Economy	28900.00
0005435706175	2442	Economy	28900.00
0005435706151	2442	Economy	28900.00
0005435706169	2442	Economy	28900.00
0005435706154	2442	Economy	28900.00
0005435706176	2442	Economy	28900.00
0005435706163	2442	Economy	28900.00
0005435706150	2442	Economy	28900.00
0005435706180	2442	Economy	28900.00
0005435706161	2442	Economy	28900.00
0005435706179	2442	Economy	28900.00
0005435706159	2442	Economy	28900.00
0005435706155	2442	Economy	28900.00
0005435706178	2442	Economy	28900.00
0005435706173	2442	Economy	28900.00
0005435706160	2442	Economy	28900.00
0005435706162	2442	Economy	28900.00
0005433373417	27025	Business	86800.00
0005433373408	27025	Business	86800.00
0005433373410	27025	Economy	31800.00
0005433373413	27025	Economy	28900.00
0005433373409	27025	Economy	28900.00
0005433373414	27025	Economy	28900.00
0005433373419	27025	Economy	28900.00
0005433373406	27025	Economy	28900.00
0005433373404	27025	Economy	28900.00
0005433373405	27025	Economy	28900.00
0005433373412	27025	Economy	28900.00
0005433373415	27025	Economy	28900.00
0005433373407	27025	Economy	28900.00
0005433373416	27025	Economy	28900.00
0005433373403	27025	Economy	28900.00
0005433373418	27025	Economy	28900.00
0005433373411	27025	Economy	28900.00
0005434963989	1322	Business	203300.00
0005434963948	1322	Business	203300.00
0005434963965	1322	Business	203300.00
0005434963952	1322	Business	203300.00
0005434963953	1322	Business	203300.00
0005434963958	1322	Business	203300.00
0005434963957	1322	Business	203300.00
0005434963959	1322	Business	203300.00
0005434963937	1322	Business	203300.00
0005434963943	1322	Business	203300.00
0005434963980	1322	Business	203300.00
0005434963988	1322	Business	203300.00
0005434963935	1322	Business	203300.00
0005434963971	1322	Business	203300.00
0005434963940	1322	Business	203300.00
0005434963968	1322	Business	203300.00
0005434963941	1322	Economy	74500.00
0005433261392	1322	Economy	74500.00
0005434963950	1322	Economy	67800.00
0005434963939	1322	Economy	67800.00
0005434963949	1322	Economy	67800.00
0005434963990	1322	Economy	67800.00
0005434963983	1322	Economy	67800.00
0005434963961	1322	Economy	67800.00
0005434963967	1322	Economy	67800.00
0005434963991	1322	Economy	67800.00
0005434963966	1322	Economy	67800.00
0005434963981	1322	Economy	67800.00
0005434963987	1322	Economy	67800.00
0005434963955	1322	Economy	67800.00
0005434963947	1322	Economy	67800.00
0005434963954	1322	Economy	67800.00
0005434963969	1322	Economy	67800.00
0005432279240	1322	Economy	67800.00
0005434963936	1322	Economy	67800.00
0005434963938	1322	Economy	67800.00
0005434963973	1322	Economy	67800.00
0005434963972	1322	Economy	67800.00
0005433261393	1322	Economy	67800.00
0005434963986	1322	Economy	67800.00
0005432279244	1322	Economy	67800.00
0005434963978	1322	Economy	67800.00
0005432279242	1322	Economy	67800.00
0005434963985	1322	Economy	67800.00
0005434963979	1322	Economy	67800.00
0005434963946	1322	Economy	67800.00
0005434963944	1322	Economy	67800.00
0005434963984	1322	Economy	67800.00
0005434963982	1322	Economy	67800.00
0005434963960	1322	Economy	67800.00
0005434963942	1322	Economy	67800.00
0005434963934	1322	Economy	67800.00
0005434963977	1322	Economy	67800.00
0005434963945	1322	Economy	67800.00
0005434963951	1322	Economy	67800.00
0005434963974	1322	Economy	67800.00
0005432279239	1322	Economy	67800.00
0005434963963	1322	Economy	67800.00
0005434963975	1322	Economy	67800.00
0005434963976	1322	Economy	67800.00
0005434963962	1322	Economy	67800.00
0005434963956	1322	Economy	67800.00
0005434963964	1322	Economy	67800.00
0005432279241	1322	Economy	67800.00
0005432279243	1322	Economy	67800.00
0005434963970	1322	Economy	67800.00
0005434625838	4871	Business	44200.00
0005434625834	4871	Business	44200.00
0005434625836	4871	Economy	14700.00
0005434625833	4871	Economy	16200.00
0005434625841	4871	Economy	16200.00
0005434625840	4871	Economy	14700.00
0005434625835	4871	Economy	14700.00
0005434625839	4871	Economy	14700.00
0005434625837	4871	Economy	14700.00
0005435907440	32883	Business	44200.00
0005435907443	32883	Business	44200.00
0005435907438	32883	Economy	14700.00
0005435907439	32883	Economy	14700.00
0005435907441	32883	Economy	14700.00
0005433194827	32883	Economy	14700.00
0005433194826	32883	Economy	14700.00
0005435907442	32883	Economy	14700.00
0005434625811	32883	Economy	14700.00
0005432195666	13772	Economy	3400.00
0005432195665	13772	Economy	3100.00
0005432195664	13772	Economy	3100.00
0005435784847	27398	Economy	3400.00
0005435784867	27398	Economy	3400.00
0005435784862	27398	Economy	3400.00
0005435784834	27398	Economy	3400.00
0005435784856	27398	Economy	3100.00
0005435784860	27398	Economy	3100.00
0005435784843	27398	Economy	3100.00
0005435784844	27398	Economy	3100.00
0005435784837	27398	Economy	3100.00
0005435784852	27398	Economy	3100.00
0005435784838	27398	Economy	3100.00
0005435784849	27398	Economy	3100.00
0005435784853	27398	Economy	3100.00
0005435784848	27398	Economy	3100.00
0005432190571	27398	Economy	3100.00
0005435784836	27398	Economy	3100.00
0005432190574	27398	Economy	3100.00
0005432190572	27398	Economy	3100.00
0005435784855	27398	Economy	3100.00
0005435784866	27398	Economy	3100.00
0005435784864	27398	Economy	3100.00
0005435784840	27398	Economy	3100.00
0005435784854	27398	Economy	3100.00
0005435784835	27398	Economy	3100.00
0005435784841	27398	Economy	3100.00
0005435784857	27398	Economy	3100.00
0005435784845	27398	Economy	3100.00
0005435784851	27398	Economy	3100.00
0005432190573	27398	Economy	3100.00
0005435784863	27398	Economy	3100.00
0005435784846	27398	Economy	3100.00
0005435784858	27398	Economy	3100.00
0005435784859	27398	Economy	3100.00
0005435784865	27398	Economy	3100.00
0005435784850	27398	Economy	3100.00
0005435784868	27398	Economy	3100.00
0005435784839	27398	Economy	3100.00
0005435784861	27398	Economy	3100.00
0005435784842	27398	Economy	3100.00
0005435310924	20280	Business	12000.00
0005435310925	20280	Business	12000.00
0005435310923	20280	Business	12000.00
0005435310917	20280	Economy	4000.00
0005435310928	20280	Economy	4000.00
0005434406691	20280	Economy	4000.00
0005434406690	20280	Economy	4400.00
0005435310908	20280	Economy	4400.00
0005435310921	20280	Economy	4000.00
0005435310914	20280	Economy	4000.00
0005434406673	20280	Economy	4000.00
0005435310909	20280	Economy	4000.00
0005435310926	20280	Economy	4000.00
0005435310912	20280	Economy	4000.00
0005435310920	20280	Economy	4000.00
0005435310929	20280	Economy	4000.00
0005435310927	20280	Economy	4000.00
0005435310911	20280	Economy	4000.00
0005435310918	20280	Economy	4000.00
0005435310915	20280	Economy	4000.00
0005435310913	20280	Economy	4000.00
0005432058328	20280	Economy	4000.00
0005435310919	20280	Economy	4000.00
0005435310906	20280	Economy	4000.00
0005432058330	20280	Economy	4000.00
0005435310916	20280	Economy	4000.00
0005432058329	20280	Economy	4000.00
0005435310910	20280	Economy	4000.00
0005435310922	20280	Economy	4000.00
0005435310907	20280	Economy	4000.00
0005434406799	20280	Economy	4000.00
0005432058331	20280	Economy	4000.00
0005432153847	26988	Business	12000.00
0005434406945	26988	Business	12000.00
0005432153849	26988	Business	12000.00
0005434406906	26988	Business	12000.00
0005434406957	26988	Business	12000.00
0005434406938	26988	Business	12000.00
0005434406902	26988	Business	12000.00
0005434406949	26988	Business	12000.00
0005434406922	26988	Economy	4000.00
0005434406921	26988	Economy	4000.00
0005434406948	26988	Economy	4000.00
0005434406934	26988	Economy	4000.00
0005434406933	26988	Economy	4000.00
0005434406897	26988	Economy	4000.00
0005434406907	26988	Economy	4000.00
0005434406905	26988	Economy	4000.00
0005434406932	26988	Economy	4000.00
0005434406952	26988	Economy	4400.00
0005434406939	26988	Economy	4400.00
0005434406940	26988	Economy	4400.00
0005432153848	26988	Economy	4400.00
0005434406942	26988	Economy	4000.00
0005432153843	26988	Economy	4000.00
0005434406911	26988	Economy	4000.00
0005434406899	26988	Economy	4000.00
0005434406908	26988	Economy	4000.00
0005432153844	26988	Economy	4000.00
0005434406924	26988	Economy	4000.00
0005434406951	26988	Economy	4000.00
0005434406943	26988	Economy	4000.00
0005434406955	26988	Economy	4000.00
0005434406904	26988	Economy	4000.00
0005434406916	26988	Economy	4000.00
0005434406910	26988	Economy	4000.00
0005432153845	26988	Economy	4000.00
0005434406898	26988	Economy	4000.00
0005434406944	26988	Economy	4000.00
0005434406920	26988	Economy	4000.00
0005434406918	26988	Economy	4000.00
0005434406913	26988	Economy	4000.00
0005434406930	26988	Economy	4000.00
0005434406926	26988	Economy	4000.00
0005434406954	26988	Economy	4000.00
0005434406936	26988	Economy	4000.00
0005434406917	26988	Economy	4000.00
0005434406901	26988	Economy	4000.00
0005434406958	26988	Economy	4000.00
0005434406941	26988	Economy	4000.00
0005434406928	26988	Economy	4000.00
0005434406896	26988	Economy	4000.00
0005434406929	26988	Economy	4000.00
0005434406903	26988	Economy	4000.00
0005434406909	26988	Economy	4000.00
0005434406956	26988	Economy	4000.00
0005434406953	26988	Economy	4000.00
0005434406950	26988	Economy	4000.00
0005434406900	26988	Economy	4000.00
0005434406923	26988	Economy	4000.00
0005434406895	26988	Economy	4000.00
0005432153846	26988	Economy	4000.00
0005434406937	26988	Economy	4000.00
0005434406915	26988	Economy	4000.00
0005434406927	26988	Economy	4000.00
0005434406925	26988	Economy	4000.00
0005434406946	26988	Economy	4000.00
0005434406947	26988	Economy	4000.00
0005434406935	26988	Economy	4000.00
0005434406914	26988	Economy	4000.00
0005434406919	26988	Economy	4000.00
0005434406912	26988	Economy	4000.00
0005434406931	26988	Economy	4000.00
0005434319198	5679	Business	43300.00
0005434319201	5679	Business	43300.00
0005434319195	5679	Business	43300.00
0005434319197	5679	Economy	14400.00
0005434319202	5679	Economy	14400.00
0005434319206	5679	Economy	14400.00
0005434319203	5679	Economy	14400.00
0005434311189	5679	Economy	14400.00
0005434319200	5679	Economy	14400.00
0005434319193	5679	Economy	14400.00
0005434319194	5679	Economy	14400.00
0005434319205	5679	Economy	14400.00
0005434319199	5679	Economy	14400.00
0005434319209	5679	Economy	14400.00
0005434319208	5679	Economy	14400.00
0005434319207	5679	Economy	14400.00
0005434319204	5679	Economy	14400.00
0005434311190	5679	Economy	14400.00
0005434319196	5679	Economy	14400.00
0005433123672	15697	Business	43300.00
0005433123661	15697	Economy	14400.00
0005433123675	15697	Economy	14400.00
0005433123671	15697	Economy	15900.00
0005433123658	15697	Economy	15900.00
0005433123670	15697	Economy	14400.00
0005433123667	15697	Economy	14400.00
0005433123677	15697	Economy	14400.00
0005433123660	15697	Economy	14400.00
0005433123674	15697	Economy	14400.00
0005433123676	15697	Economy	14400.00
0005433123668	15697	Economy	14400.00
0005433123663	15697	Economy	14400.00
0005433123664	15697	Economy	14400.00
0005433123666	15697	Economy	14400.00
0005433123678	15697	Economy	14400.00
0005433123673	15697	Economy	14400.00
0005433123669	15697	Economy	14400.00
0005433123657	15697	Economy	14400.00
0005433123659	15697	Economy	14400.00
0005433123662	15697	Economy	14400.00
0005433123656	15697	Economy	14400.00
0005433123665	15697	Economy	14400.00
0005435219171	31742	Economy	15500.00
0005435220293	31742	Economy	15500.00
0005435219174	31742	Economy	15500.00
0005435219173	31742	Economy	15500.00
0005435220294	31742	Economy	15500.00
0005435220291	31742	Economy	15500.00
0005435219172	31742	Economy	15500.00
0005435220292	31742	Economy	15500.00
0005434484263	8976	Economy	27400.00
0005434484262	8976	Economy	24900.00
0005434484260	8976	Economy	24900.00
0005434484258	8976	Economy	24900.00
0005434484259	8976	Economy	24900.00
0005434484264	8976	Economy	24900.00
0005434484261	8976	Economy	24900.00
0005434189099	16625	Economy	24900.00
0005434189100	16625	Economy	24900.00
0005434189104	16625	Economy	24900.00
0005434189101	16625	Economy	24900.00
0005434189103	16625	Economy	24900.00
0005434189102	16625	Economy	24900.00
0005433123666	7633	Business	11100.00
0005433123661	7633	Business	11100.00
0005433123674	7633	Business	11100.00
0005433123657	7633	Business	11100.00
0005433123673	7633	Economy	3700.00
0005433123672	7633	Economy	3700.00
0005433123671	7633	Economy	4100.00
0005433123662	7633	Economy	4100.00
0005433123659	7633	Economy	3700.00
0005433123678	7633	Economy	3700.00
0005433123677	7633	Economy	3700.00
0005433123658	7633	Economy	3700.00
0005433123665	7633	Economy	3700.00
0005433123660	7633	Economy	3700.00
0005433123669	7633	Economy	3700.00
0005433123670	7633	Economy	3700.00
0005433123667	7633	Economy	3700.00
0005433123656	7633	Economy	3700.00
0005433123675	7633	Economy	3700.00
0005433123663	7633	Economy	3700.00
0005433123668	7633	Economy	3700.00
0005433123676	7633	Economy	3700.00
0005433123664	7633	Economy	3700.00
0005432692656	7640	Business	11100.00
0005433449678	7640	Business	11100.00
0005432692664	7640	Business	11100.00
0005433449672	7640	Business	11100.00
0005432720545	7640	Business	11100.00
0005432720547	7640	Business	11100.00
0005432692666	7640	Business	11100.00
0005432692679	7640	Business	11100.00
0005432692684	7640	Business	11100.00
0005432692682	7640	Business	11100.00
0005433449694	7640	Business	11100.00
0005432692657	7640	Business	11100.00
0005432720554	7640	Economy	3700.00
0005432071534	7640	Economy	3700.00
0005432692676	7640	Economy	3700.00
0005432720542	7640	Economy	3700.00
0005432692675	7640	Economy	3700.00
0005432692655	7640	Economy	3700.00
0005432720541	7640	Economy	3700.00
0005432692677	7640	Economy	3700.00
0005433449679	7640	Economy	3700.00
0005432720556	7640	Economy	3700.00
0005432720552	7640	Economy	4100.00
0005432071533	7640	Economy	4100.00
0005432692683	7640	Economy	4100.00
0005432720546	7640	Economy	4100.00
0005432720561	7640	Economy	3700.00
0005432692658	7640	Economy	3700.00
0005432692678	7640	Economy	3700.00
0005432720543	7640	Economy	3700.00
0005432692673	7640	Economy	3700.00
0005433449693	7640	Economy	3700.00
0005433449674	7640	Economy	3700.00
0005432692667	7640	Economy	3700.00
0005433449690	7640	Economy	3700.00
0005432692661	7640	Economy	3700.00
0005432720549	7640	Economy	3700.00
0005432692668	7640	Economy	3700.00
0005432720563	7640	Economy	3700.00
0005432720560	7640	Economy	3700.00
0005432692659	7640	Economy	3700.00
0005432720553	7640	Economy	3700.00
0005432692685	7640	Economy	3700.00
0005432720558	7640	Economy	3700.00
0005432692663	7640	Economy	3700.00
0005432071535	7640	Economy	3700.00
0005432720557	7640	Economy	3700.00
0005432692654	7640	Economy	3700.00
0005433449687	7640	Economy	3700.00
0005432720550	7640	Economy	3700.00
0005432692671	7640	Economy	3700.00
0005433449685	7640	Economy	3700.00
0005432692672	7640	Economy	3700.00
0005432720564	7640	Economy	3700.00
0005432692660	7640	Economy	3700.00
0005432720548	7640	Economy	3700.00
0005433449684	7640	Economy	3700.00
0005432720539	7640	Economy	3700.00
0005432720544	7640	Economy	3700.00
0005432720551	7640	Economy	3700.00
0005433449673	7640	Economy	3700.00
0005432692681	7640	Economy	3700.00
0005433449683	7640	Economy	3700.00
0005433449677	7640	Economy	3700.00
0005433449686	7640	Economy	3700.00
0005433449692	7640	Economy	3700.00
0005433449676	7640	Economy	3700.00
0005432720559	7640	Economy	3700.00
0005433449688	7640	Economy	3700.00
0005432720555	7640	Economy	3700.00
0005432692662	7640	Economy	3700.00
0005432692665	7640	Economy	3700.00
0005432692653	7640	Economy	3700.00
0005433449682	7640	Economy	3700.00
0005433449691	7640	Economy	3700.00
0005433449681	7640	Economy	3700.00
0005433449689	7640	Economy	3700.00
0005433449680	7640	Economy	3700.00
0005432692674	7640	Economy	3700.00
0005432692670	7640	Economy	3700.00
0005432692669	7640	Economy	3700.00
0005432692680	7640	Economy	3700.00
0005432720562	7640	Economy	3700.00
0005432720540	7640	Economy	3700.00
0005432071536	7640	Economy	3700.00
0005432720538	7640	Economy	3700.00
0005433449675	7640	Economy	3700.00
0005432720467	30415	Business	11100.00
0005433722131	30415	Economy	3700.00
0005433722130	30415	Economy	3700.00
0005433722128	30415	Economy	3700.00
0005433722129	30415	Economy	3700.00
0005434586277	1395	Business	70400.00
0005434586269	1395	Business	70400.00
0005434586275	1395	Business	70400.00
0005434586284	1395	Business	70400.00
0005434586265	1395	Business	70400.00
0005434586273	1395	Business	70400.00
0005434586271	1395	Business	70400.00
0005433192825	1395	Business	70400.00
0005433524894	1395	Economy	23500.00
0005433524899	1395	Economy	23500.00
0005434586266	1395	Economy	23500.00
0005433524891	1395	Economy	23500.00
0005433724747	1395	Economy	25800.00
0005434513544	1395	Economy	25800.00
0005434586263	1395	Economy	23500.00
0005433524898	1395	Economy	23500.00
0005434586270	1395	Economy	23500.00
0005434586281	1395	Economy	23500.00
0005433524896	1395	Economy	23500.00
0005434513545	1395	Economy	23500.00
0005434586278	1395	Economy	23500.00
0005434586264	1395	Economy	23500.00
0005434586280	1395	Economy	23500.00
0005434586268	1395	Economy	23500.00
0005434586282	1395	Economy	23500.00
0005434586274	1395	Economy	23500.00
0005433524893	1395	Economy	23500.00
0005434586285	1395	Economy	23500.00
0005434586262	1395	Economy	23500.00
0005433524895	1395	Economy	23500.00
0005433524900	1395	Economy	23500.00
0005434586267	1395	Economy	23500.00
0005434513543	1395	Economy	23500.00
0005434586286	1395	Economy	23500.00
0005434586276	1395	Economy	23500.00
0005432270967	1395	Economy	23500.00
0005434586283	1395	Economy	23500.00
0005433192815	1395	Economy	23500.00
0005434513546	1395	Economy	23500.00
0005433724745	1395	Economy	23500.00
0005433724744	1395	Economy	23500.00
0005434586287	1395	Economy	23500.00
0005433524890	1395	Economy	23500.00
0005434586272	1395	Economy	23500.00
0005434586279	1395	Economy	23500.00
0005434514932	1395	Economy	23500.00
0005433524892	1395	Economy	23500.00
0005433524897	1395	Economy	23500.00
0005434514933	1395	Economy	23500.00
0005433724743	1395	Economy	23500.00
0005432270966	1395	Economy	23500.00
0005433724746	1395	Economy	23500.00
0005433192873	18530	Business	70400.00
0005432927903	18530	Business	70400.00
0005432927908	18530	Economy	23500.00
0005433192871	18530	Economy	25800.00
0005433192874	18530	Economy	23500.00
0005434586208	18530	Economy	23500.00
0005433192875	18530	Economy	23500.00
0005433192866	18530	Economy	23500.00
0005433192869	18530	Economy	23500.00
0005432927905	18530	Economy	23500.00
0005433192865	18530	Economy	23500.00
0005433192870	18530	Economy	23500.00
0005432927904	18530	Economy	23500.00
0005432927907	18530	Economy	23500.00
0005433192867	18530	Economy	23500.00
0005432968809	18530	Economy	23500.00
0005433192872	18530	Economy	23500.00
0005433192876	18530	Economy	23500.00
0005432968808	18530	Economy	23500.00
0005432927906	18530	Economy	23500.00
0005433192864	18530	Economy	23500.00
0005434586168	18530	Economy	23500.00
0005432968810	18530	Economy	23500.00
0005433192868	18530	Economy	23500.00
0005434343698	11458	Economy	4300.00
0005434343687	11458	Economy	4300.00
0005434343701	11458	Economy	4300.00
0005434343700	11458	Economy	4300.00
0005434343705	11458	Economy	4000.00
0005434343689	11458	Economy	4000.00
0005434343691	11458	Economy	4000.00
0005434142559	11458	Economy	4000.00
0005434343697	11458	Economy	4000.00
0005434343696	11458	Economy	4000.00
0005434343713	11458	Economy	4000.00
0005434343686	11458	Economy	4000.00
0005434343716	11458	Economy	4000.00
0005434343721	11458	Economy	4000.00
0005434343718	11458	Economy	4000.00
0005434343724	11458	Economy	4000.00
0005434343710	11458	Economy	4000.00
0005434343704	11458	Economy	4000.00
0005434343690	11458	Economy	4000.00
0005434343723	11458	Economy	4000.00
0005434343715	11458	Economy	4000.00
0005434142560	11458	Economy	4000.00
0005434343714	11458	Economy	4000.00
0005434343717	11458	Economy	4000.00
0005434142556	11458	Economy	4000.00
0005434343703	11458	Economy	4000.00
0005434343708	11458	Economy	4000.00
0005434343720	11458	Economy	4000.00
0005434343709	11458	Economy	4000.00
0005434343719	11458	Economy	4000.00
0005434343702	11458	Economy	4000.00
0005434142557	11458	Economy	4000.00
0005434343692	11458	Economy	4000.00
0005434343722	11458	Economy	4000.00
0005434343694	11458	Economy	4000.00
0005434142558	11458	Economy	4000.00
0005434343695	11458	Economy	4000.00
0005434343693	11458	Economy	4000.00
0005434343699	11458	Economy	4000.00
0005434343706	11458	Economy	4000.00
0005434343711	11458	Economy	4000.00
0005434343688	11458	Economy	4000.00
0005434343712	11458	Economy	4000.00
0005434343707	11458	Economy	4000.00
0005435304113	29808	Economy	4300.00
0005435304112	29808	Economy	4000.00
0005435304114	29808	Economy	4000.00
0005435304109	29808	Economy	4000.00
0005435304999	29808	Economy	4000.00
0005435304110	29808	Economy	4000.00
0005435304111	29808	Economy	4000.00
0005435304998	29808	Economy	4000.00
0005435824265	1266	Business	199800.00
0005435824277	1266	Business	199800.00
0005435824267	1266	Business	199800.00
0005432284519	1266	Business	199800.00
0005435824279	1266	Economy	66600.00
0005435824273	1266	Economy	66600.00
0005435824282	1266	Economy	66600.00
0005435824271	1266	Economy	66600.00
0005435824272	1266	Economy	73200.00
0005435824278	1266	Economy	66600.00
0005435824280	1266	Economy	66600.00
0005435824268	1266	Economy	66600.00
0005435824284	1266	Economy	66600.00
0005435824264	1266	Economy	66600.00
0005435824275	1266	Economy	66600.00
0005435824274	1266	Economy	66600.00
0005435824263	1266	Economy	66600.00
0005435824283	1266	Economy	66600.00
0005435824287	1266	Economy	66600.00
0005432284521	1266	Economy	66600.00
0005435824270	1266	Economy	66600.00
0005435824269	1266	Economy	66600.00
0005432284520	1266	Economy	66600.00
0005435824286	1266	Economy	66600.00
0005435824266	1266	Economy	66600.00
0005435824281	1266	Economy	66600.00
0005435824285	1266	Economy	66600.00
0005435824262	1266	Economy	66600.00
0005432284518	1266	Economy	66600.00
0005435824276	1266	Economy	66600.00
0005433415447	17990	Business	199800.00
0005433415449	17990	Business	199800.00
0005433415453	17990	Business	199800.00
0005433415450	17990	Economy	66600.00
0005433415458	17990	Economy	66600.00
0005433415446	17990	Economy	66600.00
0005433415455	17990	Economy	66600.00
0005433415457	17990	Economy	66600.00
0005433415459	17990	Economy	66600.00
0005433415452	17990	Economy	66600.00
0005433415445	17990	Economy	66600.00
0005433415456	17990	Economy	66600.00
0005433415451	17990	Economy	66600.00
0005433415448	17990	Economy	66600.00
0005433415454	17990	Economy	66600.00
0005432783064	5647	Business	27800.00
0005432783077	5647	Business	27800.00
0005432783061	5647	Business	27800.00
0005432783067	5647	Business	27800.00
0005432783086	5647	Business	27800.00
0005432783112	5647	Business	27800.00
0005432783110	5647	Business	27800.00
0005432783095	5647	Business	27800.00
0005432783089	5647	Business	27800.00
0005432783066	5647	Business	27800.00
0005432783099	5647	Economy	9300.00
0005432783094	5647	Economy	9300.00
0005432783079	5647	Economy	9300.00
0005432783090	5647	Economy	9300.00
0005432783105	5647	Economy	10200.00
0005432783065	5647	Economy	10200.00
0005432783078	5647	Economy	9300.00
0005432783074	5647	Economy	9300.00
0005432783098	5647	Economy	9300.00
0005432783071	5647	Economy	9300.00
0005432783072	5647	Economy	9300.00
0005432783073	5647	Economy	9300.00
0005432783063	5647	Economy	9300.00
0005432783101	5647	Economy	9300.00
0005432783080	5647	Economy	9300.00
0005432143944	5647	Economy	9300.00
0005432783060	5647	Economy	9300.00
0005432783062	5647	Economy	9300.00
0005432783104	5647	Economy	9300.00
0005432783084	5647	Economy	9300.00
0005432783108	5647	Economy	9300.00
0005432143945	5647	Economy	9300.00
0005432783081	5647	Economy	9300.00
0005432783107	5647	Economy	9300.00
0005432783096	5647	Economy	9300.00
0005432783100	5647	Economy	9300.00
0005432783076	5647	Economy	9300.00
0005432783091	5647	Economy	9300.00
0005432783058	5647	Economy	9300.00
0005432783092	5647	Economy	9300.00
0005432783087	5647	Economy	9300.00
0005432783103	5647	Economy	9300.00
0005432783102	5647	Economy	9300.00
0005432783111	5647	Economy	9300.00
0005432783068	5647	Economy	9300.00
0005432783082	5647	Economy	9300.00
0005432783088	5647	Economy	9300.00
0005432783097	5647	Economy	9300.00
0005432143943	5647	Economy	9300.00
0005432783069	5647	Economy	9300.00
0005432783083	5647	Economy	9300.00
0005432783093	5647	Economy	9300.00
0005432783106	5647	Economy	9300.00
0005432783109	5647	Economy	9300.00
0005432783070	5647	Economy	9300.00
0005432783085	5647	Economy	9300.00
0005432783075	5647	Economy	9300.00
0005432783059	5647	Economy	9300.00
0005435242489	15368	Business	27800.00
0005435476661	15368	Business	27800.00
0005435242490	15368	Business	27800.00
0005435242480	15368	Business	27800.00
0005435242488	15368	Economy	9300.00
0005435242487	15368	Economy	9300.00
0005435242485	15368	Economy	9300.00
0005435476659	15368	Economy	10200.00
0005435242478	15368	Economy	9300.00
0005435476663	15368	Economy	9300.00
0005435242492	15368	Economy	9300.00
0005435242472	15368	Economy	9300.00
0005432782839	15368	Economy	9300.00
0005435242477	15368	Economy	9300.00
0005435476668	15368	Economy	9300.00
0005435242491	15368	Economy	9300.00
0005435242484	15368	Economy	9300.00
0005435242497	15368	Economy	9300.00
0005435242481	15368	Economy	9300.00
0005435476664	15368	Economy	9300.00
0005435242471	15368	Economy	9300.00
0005435242479	15368	Economy	9300.00
0005435476660	15368	Economy	9300.00
0005435476662	15368	Economy	9300.00
0005435242495	15368	Economy	9300.00
0005435242476	15368	Economy	9300.00
0005435476667	15368	Economy	9300.00
0005435476666	15368	Economy	9300.00
0005435242483	15368	Economy	9300.00
0005435242475	15368	Economy	9300.00
0005435242473	15368	Economy	9300.00
0005435476665	15368	Economy	9300.00
0005435242482	15368	Economy	9300.00
0005435242493	15368	Economy	9300.00
0005435242474	15368	Economy	9300.00
0005435242486	15368	Economy	9300.00
0005435242494	15368	Economy	9300.00
0005435242496	15368	Economy	9300.00
0005432848121	4355	Economy	7000.00
0005432848125	4355	Economy	7000.00
0005434462763	4355	Economy	7000.00
0005432848124	4355	Economy	6300.00
0005435850755	4355	Economy	6300.00
0005432848119	4355	Economy	6300.00
0005432848128	4355	Economy	6300.00
0005432848118	4355	Economy	6300.00
0005434463901	4355	Economy	6300.00
0005435850754	4355	Economy	6300.00
0005432848114	4355	Economy	6300.00
0005432848123	4355	Economy	6300.00
0005434463900	4355	Economy	6300.00
0005432848117	4355	Economy	6300.00
0005432848127	4355	Economy	6300.00
0005432848122	4355	Economy	6300.00
0005432848120	4355	Economy	6300.00
0005434462761	4355	Economy	6300.00
0005432848126	4355	Economy	6300.00
0005432848116	4355	Economy	6300.00
0005434463902	4355	Economy	6300.00
0005434462762	4355	Economy	6300.00
0005432848115	4355	Economy	6300.00
0005435850788	28884	Economy	7000.00
0005435850793	28884	Economy	6300.00
0005435850792	28884	Economy	6300.00
0005435850789	28884	Economy	6300.00
0005435850791	28884	Economy	6300.00
0005435850787	28884	Economy	6300.00
0005435850790	28884	Economy	6300.00
0005435850794	28884	Economy	6300.00
0005434925382	6260	Business	11900.00
0005433496548	6260	Business	11900.00
0005434925376	6260	Business	11900.00
0005433496549	6260	Business	11900.00
0005434925385	6260	Business	11900.00
0005434443489	6260	Business	11900.00
0005434925365	6260	Business	11900.00
0005434443505	6260	Business	11900.00
0005434925381	6260	Business	11900.00
0005434925395	6260	Business	11900.00
0005434443496	6260	Economy	4000.00
0005434925369	6260	Economy	4000.00
0005434443491	6260	Economy	4000.00
0005433496567	6260	Economy	4000.00
0005433496565	6260	Economy	4000.00
0005434443494	6260	Economy	4000.00
0005434925375	6260	Economy	4000.00
0005433496547	6260	Economy	4000.00
0005432075184	6260	Economy	4000.00
0005434925384	6260	Economy	4400.00
0005434925377	6260	Economy	4400.00
0005434925368	6260	Economy	4400.00
0005434443500	6260	Economy	4400.00
0005434925371	6260	Economy	4400.00
0005433496557	6260	Economy	4000.00
0005434443499	6260	Economy	4000.00
0005434443492	6260	Economy	4000.00
0005434925379	6260	Economy	4000.00
0005434443498	6260	Economy	4000.00
0005434443502	6260	Economy	4000.00
0005434925390	6260	Economy	4000.00
0005434925378	6260	Economy	4000.00
0005434925367	6260	Economy	4000.00
0005433496561	6260	Economy	4000.00
0005433496575	6260	Economy	4000.00
0005434925370	6260	Economy	4000.00
0005434925380	6260	Economy	4000.00
0005433496572	6260	Economy	4000.00
0005434443501	6260	Economy	4000.00
0005433496570	6260	Economy	4000.00
0005433496553	6260	Economy	4000.00
0005434925394	6260	Economy	4000.00
0005433496562	6260	Economy	4000.00
0005434443506	6260	Economy	4000.00
0005433496556	6260	Economy	4000.00
0005432075186	6260	Economy	4000.00
0005432075185	6260	Economy	4000.00
0005434443504	6260	Economy	4000.00
0005434443493	6260	Economy	4000.00
0005434925388	6260	Economy	4000.00
0005434925387	6260	Economy	4000.00
0005433496569	6260	Economy	4000.00
0005433496574	6260	Economy	4000.00
0005433496552	6260	Economy	4000.00
0005434925366	6260	Economy	4000.00
0005434925373	6260	Economy	4000.00
0005434925383	6260	Economy	4000.00
0005433496577	6260	Economy	4000.00
0005434925374	6260	Economy	4000.00
0005433496558	6260	Economy	4000.00
0005433496560	6260	Economy	4000.00
0005433496568	6260	Economy	4000.00
0005434925392	6260	Economy	4000.00
0005434443495	6260	Economy	4000.00
0005433496566	6260	Economy	4000.00
0005433496555	6260	Economy	4000.00
0005434443497	6260	Economy	4000.00
0005433496573	6260	Economy	4000.00
0005433496554	6260	Economy	4000.00
0005434443490	6260	Economy	4000.00
0005433496576	6260	Economy	4000.00
0005432075183	6260	Economy	4000.00
0005434925391	6260	Economy	4000.00
0005434925396	6260	Economy	4000.00
0005433496564	6260	Economy	4000.00
0005433496563	6260	Economy	4000.00
0005434925389	6260	Economy	4000.00
0005433496559	6260	Economy	4000.00
0005434925372	6260	Economy	4000.00
0005433496571	6260	Economy	4000.00
0005433496550	6260	Economy	4000.00
0005433496551	6260	Economy	4000.00
0005434925393	6260	Economy	4000.00
0005434443503	6260	Economy	4000.00
0005434925386	6260	Economy	4000.00
0005433496436	20423	Economy	4000.00
0005435242510	12167	Business	41200.00
0005435242515	12167	Business	41200.00
0005435242506	12167	Business	41200.00
0005435242505	12167	Business	41200.00
0005435242503	12167	Business	41200.00
0005435242520	12167	Business	41200.00
0005435242524	12167	Economy	13700.00
0005435242499	12167	Economy	13700.00
0005435242514	12167	Economy	13700.00
0005435242500	12167	Economy	15100.00
0005435242517	12167	Economy	13700.00
0005435242509	12167	Economy	13700.00
0005435242516	12167	Economy	13700.00
0005435242498	12167	Economy	13700.00
0005435242525	12167	Economy	13700.00
0005435242502	12167	Economy	13700.00
0005435242513	12167	Economy	13700.00
0005435242521	12167	Economy	13700.00
0005435242507	12167	Economy	13700.00
0005435242522	12167	Economy	13700.00
0005435242511	12167	Economy	13700.00
0005435242501	12167	Economy	13700.00
0005435242523	12167	Economy	13700.00
0005435242504	12167	Economy	13700.00
0005435242512	12167	Economy	13700.00
0005435242519	12167	Economy	13700.00
0005435242526	12167	Economy	13700.00
0005435242518	12167	Economy	13700.00
0005432782863	12167	Economy	13700.00
0005435242508	12167	Economy	13700.00
0005432783018	15403	Business	41200.00
0005432783009	15403	Business	41200.00
0005432783055	15403	Business	41200.00
0005432783049	15403	Business	41200.00
0005432783046	15403	Business	41200.00
0005432783027	15403	Business	41200.00
0005432783010	15403	Business	41200.00
0005432783033	15403	Business	41200.00
0005432783029	15403	Economy	13700.00
0005432783024	15403	Economy	13700.00
0005432783053	15403	Economy	13700.00
0005432783019	15403	Economy	13700.00
0005432783006	15403	Economy	13700.00
0005432783017	15403	Economy	13700.00
0005432783028	15403	Economy	15100.00
0005432783020	15403	Economy	13700.00
0005432783037	15403	Economy	13700.00
0005432783048	15403	Economy	13700.00
0005432783047	15403	Economy	13700.00
0005432783052	15403	Economy	13700.00
0005432783036	15403	Economy	13700.00
0005432783035	15403	Economy	13700.00
0005432783012	15403	Economy	13700.00
0005432783044	15403	Economy	13700.00
0005432783031	15403	Economy	13700.00
0005432783013	15403	Economy	13700.00
0005432783054	15403	Economy	13700.00
0005432783041	15403	Economy	13700.00
0005432783007	15403	Economy	13700.00
0005432783016	15403	Economy	13700.00
0005432783005	15403	Economy	13700.00
0005432783057	15403	Economy	13700.00
0005432783008	15403	Economy	13700.00
0005432783034	15403	Economy	13700.00
0005432783030	15403	Economy	13700.00
0005432783043	15403	Economy	13700.00
0005432783015	15403	Economy	13700.00
0005432783056	15403	Economy	13700.00
0005432783026	15403	Economy	13700.00
0005432783011	15403	Economy	13700.00
0005432783042	15403	Economy	13700.00
0005432783003	15403	Economy	13700.00
0005432783051	15403	Economy	13700.00
0005432783021	15403	Economy	13700.00
0005432783050	15403	Economy	13700.00
0005432783023	15403	Economy	13700.00
0005432783025	15403	Economy	13700.00
0005432783045	15403	Economy	13700.00
0005432783039	15403	Economy	13700.00
0005432783014	15403	Economy	13700.00
0005432783004	15403	Economy	13700.00
0005432783032	15403	Economy	13700.00
0005432783038	15403	Economy	13700.00
0005432783022	15403	Economy	13700.00
0005432783040	15403	Economy	13700.00
0005435913870	10112	Business	49700.00
0005435913873	10112	Business	49700.00
0005434910076	10112	Economy	16600.00
0005435913874	10112	Economy	16600.00
0005434910078	10112	Economy	16600.00
0005435913868	10112	Economy	16600.00
0005435913872	10112	Economy	16600.00
0005435913871	10112	Economy	16600.00
0005435913867	10112	Economy	16600.00
0005435913866	10112	Economy	16600.00
0005434910077	10112	Economy	16600.00
0005435913869	10112	Economy	16600.00
0005434876696	10112	Economy	16600.00
0005434758863	14612	Business	49700.00
0005434876995	14612	Business	49700.00
0005434877007	14612	Business	49700.00
0005434877020	14612	Business	49700.00
0005434877035	14612	Business	49700.00
0005434876962	14612	Business	49700.00
0005434876963	14612	Business	49700.00
0005434876988	14612	Business	49700.00
0005434877003	14612	Business	49700.00
0005434876953	14612	Business	49700.00
0005434877039	14612	Business	49700.00
0005434877005	14612	Business	49700.00
0005434876969	14612	Business	49700.00
0005434877026	14612	Business	49700.00
0005434876968	14612	Business	49700.00
0005434877022	14612	Business	49700.00
0005434876974	14612	Business	49700.00
0005434876950	14612	Business	49700.00
0005434877016	14612	Economy	16600.00
0005434877013	14612	Economy	16600.00
0005434876966	14612	Economy	16600.00
0005434877034	14612	Economy	16600.00
0005434877028	14612	Economy	16600.00
0005434877000	14612	Economy	16600.00
0005434876959	14612	Economy	16600.00
0005434876970	14612	Economy	16600.00
0005434877032	14612	Economy	18200.00
0005434876948	14612	Economy	18200.00
0005434876956	14612	Economy	18200.00
0005434876989	14612	Economy	18200.00
0005434877029	14612	Economy	16600.00
0005434876991	14612	Economy	16600.00
0005434877004	14612	Economy	16600.00
0005434758862	14612	Economy	16600.00
0005434877014	14612	Economy	16600.00
0005434877030	14612	Economy	16600.00
0005434876993	14612	Economy	16600.00
0005434876973	14612	Economy	16600.00
0005434877011	14612	Economy	16600.00
0005434876967	14612	Economy	16600.00
0005434876981	14612	Economy	16600.00
0005434877006	14612	Economy	16600.00
0005434876945	14612	Economy	16600.00
0005434877033	14612	Economy	16600.00
0005434877037	14612	Economy	16600.00
0005434876954	14612	Economy	16600.00
0005434876985	14612	Economy	16600.00
0005434876994	14612	Economy	16600.00
0005434876947	14612	Economy	16600.00
0005434876979	14612	Economy	16600.00
0005434876975	14612	Economy	16600.00
0005434877036	14612	Economy	16600.00
0005434876998	14612	Economy	16600.00
0005434877012	14612	Economy	16600.00
0005434876982	14612	Economy	16600.00
0005434876943	14612	Economy	16600.00
0005434877025	14612	Economy	16600.00
0005434877024	14612	Economy	16600.00
0005434876949	14612	Economy	16600.00
0005434876984	14612	Economy	16600.00
0005434876999	14612	Economy	16600.00
0005434877015	14612	Economy	16600.00
0005434877018	14612	Economy	16600.00
0005434876957	14612	Economy	16600.00
0005434877023	14612	Economy	16600.00
0005434876996	14612	Economy	16600.00
0005434876972	14612	Economy	16600.00
0005434910068	14612	Economy	16600.00
0005434876955	14612	Economy	16600.00
0005434877008	14612	Economy	16600.00
0005434876978	14612	Economy	16600.00
0005434876971	14612	Economy	16600.00
0005434876987	14612	Economy	16600.00
0005434877009	14612	Economy	16600.00
0005434877001	14612	Economy	16600.00
0005434876997	14612	Economy	16600.00
0005434876992	14612	Economy	16600.00
0005434876965	14612	Economy	16600.00
0005434877031	14612	Economy	16600.00
0005434876980	14612	Economy	16600.00
0005434877002	14612	Economy	16600.00
0005434876990	14612	Economy	16600.00
0005434876983	14612	Economy	16600.00
0005434877027	14612	Economy	16600.00
0005434876944	14612	Economy	16600.00
0005434877019	14612	Economy	16600.00
0005434876946	14612	Economy	16600.00
0005434876977	14612	Economy	16600.00
0005434876960	14612	Economy	16600.00
0005434876964	14612	Economy	16600.00
0005434877017	14612	Economy	16600.00
0005434876986	14612	Economy	16600.00
0005434876958	14612	Economy	16600.00
0005434877021	14612	Economy	16600.00
0005434876952	14612	Economy	16600.00
0005434876961	14612	Economy	16600.00
0005434876951	14612	Economy	16600.00
0005434877038	14612	Economy	16600.00
0005434876976	14612	Economy	16600.00
0005434877010	14612	Economy	16600.00
0005435659990	9265	Economy	22400.00
0005435659985	9265	Economy	20300.00
0005435659984	9265	Economy	20300.00
0005435659983	9265	Economy	20300.00
0005435659993	9265	Economy	20300.00
0005435659988	9265	Economy	20300.00
0005435659991	9265	Economy	20300.00
0005435659986	9265	Economy	20300.00
0005435659987	9265	Economy	20300.00
0005435659989	9265	Economy	20300.00
0005435659992	9265	Economy	20300.00
0005434251841	24665	Economy	20300.00
0005434251836	24665	Economy	20300.00
0005434251837	24665	Economy	20300.00
0005434251835	24665	Economy	20300.00
0005434251839	24665	Economy	20300.00
0005434251838	24665	Economy	20300.00
0005434251842	24665	Economy	20300.00
0005434251840	24665	Economy	20300.00
0005434251843	24665	Economy	20300.00
0005433679912	2771	Business	33000.00
0005433679924	2771	Business	33000.00
0005432222711	2771	Business	33000.00
0005432222710	2771	Business	33000.00
0005433679931	2771	Business	33000.00
0005433679907	2771	Business	33000.00
0005432222709	2771	Economy	11000.00
0005433679905	2771	Economy	11000.00
0005433679935	2771	Economy	11000.00
0005433679920	2771	Economy	11000.00
0005433679937	2771	Economy	11000.00
0005433679933	2771	Economy	11000.00
0005433679910	2771	Economy	11000.00
0005433679945	2771	Economy	12100.00
0005433679906	2771	Economy	12100.00
0005433679952	2771	Economy	11000.00
0005432222712	2771	Economy	11000.00
0005433679919	2771	Economy	11000.00
0005433679916	2771	Economy	11000.00
0005433679950	2771	Economy	11000.00
0005433679908	2771	Economy	11000.00
0005433679942	2771	Economy	11000.00
0005433684391	2771	Economy	11000.00
0005433679951	2771	Economy	11000.00
0005433679934	2771	Economy	11000.00
0005433679923	2771	Economy	11000.00
0005433679944	2771	Economy	11000.00
0005433679918	2771	Economy	11000.00
0005433679913	2771	Economy	11000.00
0005433679921	2771	Economy	11000.00
0005433679947	2771	Economy	11000.00
0005433679948	2771	Economy	11000.00
0005433679953	2771	Economy	11000.00
0005433679938	2771	Economy	11000.00
0005433679929	2771	Economy	11000.00
0005432222713	2771	Economy	11000.00
0005433679914	2771	Economy	11000.00
0005433679941	2771	Economy	11000.00
0005433679943	2771	Economy	11000.00
0005433679936	2771	Economy	11000.00
0005433679930	2771	Economy	11000.00
0005433679926	2771	Economy	11000.00
0005433679949	2771	Economy	11000.00
0005433679911	2771	Economy	11000.00
0005433684390	2771	Economy	11000.00
0005433679915	2771	Economy	11000.00
0005433679946	2771	Economy	11000.00
0005433679922	2771	Economy	11000.00
0005433679909	2771	Economy	11000.00
0005433679932	2771	Economy	11000.00
0005433684392	2771	Economy	11000.00
0005433679927	2771	Economy	11000.00
0005433679939	2771	Economy	11000.00
0005433679925	2771	Economy	11000.00
0005433679917	2771	Economy	11000.00
0005433679928	2771	Economy	11000.00
0005433679940	2771	Economy	11000.00
0005432966585	29140	Business	33000.00
0005432966588	29140	Business	33000.00
0005432966607	29140	Business	33000.00
0005432966589	29140	Economy	11000.00
0005432966596	29140	Economy	11000.00
0005433679767	29140	Economy	11000.00
0005433679768	29140	Economy	11000.00
0005432966598	29140	Economy	12100.00
0005432966593	29140	Economy	11000.00
0005433679710	29140	Economy	11000.00
0005433679838	29140	Economy	11000.00
0005432005177	29140	Economy	11000.00
0005432966594	29140	Economy	11000.00
0005432966602	29140	Economy	11000.00
0005432966587	29140	Economy	11000.00
0005432966599	29140	Economy	11000.00
0005433679764	29140	Economy	11000.00
0005432966601	29140	Economy	11000.00
0005433679799	29140	Economy	11000.00
0005432966595	29140	Economy	11000.00
0005433679749	29140	Economy	11000.00
0005432966590	29140	Economy	11000.00
0005432966604	29140	Economy	11000.00
0005432005174	29140	Economy	11000.00
0005432005176	29140	Economy	11000.00
0005432966606	29140	Economy	11000.00
0005432966609	29140	Economy	11000.00
0005432966584	29140	Economy	11000.00
0005432966608	29140	Economy	11000.00
0005432966600	29140	Economy	11000.00
0005432966603	29140	Economy	11000.00
0005432966591	29140	Economy	11000.00
0005433679772	29140	Economy	11000.00
0005432966592	29140	Economy	11000.00
0005432966605	29140	Economy	11000.00
0005432966586	29140	Economy	11000.00
0005432966597	29140	Economy	11000.00
0005432005175	29140	Economy	11000.00
0005433679797	29140	Economy	11000.00
0005433633327	9272	Business	132900.00
0005433613676	9272	Business	132900.00
0005432755029	9272	Business	132900.00
0005433613649	9272	Business	132900.00
0005433613668	9272	Business	132900.00
0005433613639	9272	Business	132900.00
0005432756803	9272	Business	132900.00
0005433633322	9272	Business	132900.00
0005433633326	9272	Business	132900.00
0005433613636	9272	Business	132900.00
0005433613667	9272	Business	132900.00
0005433613671	9272	Business	132900.00
0005433633324	9272	Business	132900.00
0005433613655	9272	Business	132900.00
0005433633337	9272	Business	132900.00
0005433633331	9272	Business	132900.00
0005433613651	9272	Business	132900.00
0005433613633	9272	Business	132900.00
0005433613616	9272	Business	132900.00
0005433613629	9272	Business	132900.00
0005433613686	9272	Business	132900.00
0005433633347	9272	Business	132900.00
0005433613679	9272	Business	132900.00
0005433633325	9272	Business	132900.00
0005433613632	9272	Economy	48700.00
0005433633330	9272	Economy	48700.00
0005433633341	9272	Economy	48700.00
0005433613624	9272	Economy	48700.00
0005433613643	9272	Economy	44300.00
0005433613615	9272	Economy	44300.00
0005433633321	9272	Economy	44300.00
0005433613630	9272	Economy	44300.00
0005433613672	9272	Economy	44300.00
0005433633318	9272	Economy	44300.00
0005432756801	9272	Economy	44300.00
0005433613621	9272	Economy	44300.00
0005433613664	9272	Economy	44300.00
0005433613637	9272	Economy	44300.00
0005433633345	9272	Economy	44300.00
0005433633349	9272	Economy	44300.00
0005433577619	9272	Economy	44300.00
0005433577624	9272	Economy	44300.00
0005433613642	9272	Economy	44300.00
0005433577627	9272	Economy	44300.00
0005433613685	9272	Economy	44300.00
0005433613631	9272	Economy	44300.00
0005433577622	9272	Economy	44300.00
0005433613670	9272	Economy	44300.00
0005433613661	9272	Economy	44300.00
0005433613659	9272	Economy	44300.00
0005433613622	9272	Economy	44300.00
0005433633332	9272	Economy	44300.00
0005433577616	9272	Economy	44300.00
0005433577623	9272	Economy	44300.00
0005433633340	9272	Economy	44300.00
0005433633348	9272	Economy	44300.00
0005433613653	9272	Economy	44300.00
0005433613626	9272	Economy	44300.00
0005433613623	9272	Economy	44300.00
0005433577621	9272	Economy	44300.00
0005433613640	9272	Economy	44300.00
0005432756802	9272	Economy	44300.00
0005433613683	9272	Economy	44300.00
0005433633319	9272	Economy	44300.00
0005433633351	9272	Economy	44300.00
0005433577617	9272	Economy	44300.00
0005433613618	9272	Economy	44300.00
0005433633333	9272	Economy	44300.00
0005433613662	9272	Economy	44300.00
0005433633354	9272	Economy	44300.00
0005433613647	9272	Economy	44300.00
0005433633346	9272	Economy	48700.00
0005433633344	9272	Economy	48700.00
0005433613645	9272	Economy	48700.00
0005433577615	9272	Economy	44300.00
0005433613635	9272	Economy	44300.00
0005433613665	9272	Economy	44300.00
0005433577620	9272	Economy	44300.00
0005433633338	9272	Economy	48700.00
0005433613627	9272	Economy	44300.00
0005433613681	9272	Economy	44300.00
0005433613673	9272	Economy	44300.00
0005433613625	9272	Economy	44300.00
0005433613614	9272	Economy	44300.00
0005433633339	9272	Economy	44300.00
0005433633334	9272	Economy	44300.00
0005433613675	9272	Economy	44300.00
0005433613654	9272	Economy	44300.00
0005432145082	9272	Economy	44300.00
0005433613658	9272	Economy	44300.00
0005433613663	9272	Economy	44300.00
0005433613657	9272	Economy	44300.00
0005433633352	9272	Economy	44300.00
0005433613617	9272	Economy	44300.00
0005433613646	9272	Economy	44300.00
0005433613611	9272	Economy	44300.00
0005433633343	9272	Economy	44300.00
0005433613684	9272	Economy	44300.00
0005433633329	9272	Economy	44300.00
0005433577628	9272	Economy	44300.00
0005433613644	9272	Economy	44300.00
0005433633328	9272	Economy	44300.00
0005433613638	9272	Economy	44300.00
0005433613666	9272	Economy	44300.00
0005433633336	9272	Economy	44300.00
0005433613648	9272	Economy	44300.00
0005433633320	9272	Economy	44300.00
0005432755031	9272	Economy	44300.00
0005433613677	9272	Economy	44300.00
0005433613613	9272	Economy	44300.00
0005433613641	9272	Economy	44300.00
0005433613656	9272	Economy	44300.00
0005433633353	9272	Economy	44300.00
0005433613612	9272	Economy	44300.00
0005433577618	9272	Economy	44300.00
0005433633335	9272	Economy	44300.00
0005433633350	9272	Economy	44300.00
0005433613620	9272	Economy	44300.00
0005433633323	9272	Economy	44300.00
0005433613669	9272	Economy	44300.00
0005433613674	9272	Economy	44300.00
0005433613650	9272	Economy	44300.00
0005433577626	9272	Economy	44300.00
0005433613652	9272	Economy	44300.00
0005433613619	9272	Economy	44300.00
0005433613634	9272	Economy	44300.00
0005432755030	9272	Economy	44300.00
0005433577625	9272	Economy	44300.00
0005433613660	9272	Economy	44300.00
0005433633342	9272	Economy	44300.00
0005433613680	9272	Economy	44300.00
0005433613682	9272	Economy	44300.00
0005433613628	9272	Economy	44300.00
0005433613678	9272	Economy	44300.00
0005434273053	25207	Business	132900.00
0005434163492	25207	Business	132900.00
0005434273052	25207	Business	132900.00
0005434163494	25207	Business	132900.00
0005435854044	25207	Business	132900.00
0005434163497	25207	Economy	44300.00
0005435854043	25207	Economy	44300.00
0005434163496	25207	Economy	44300.00
0005434272168	25207	Economy	44300.00
0005434163502	25207	Economy	44300.00
0005434163498	25207	Economy	44300.00
0005434273054	25207	Economy	44300.00
0005435854042	25207	Economy	44300.00
0005434163499	25207	Economy	44300.00
0005434163493	25207	Economy	44300.00
0005434272167	25207	Economy	44300.00
0005434163501	25207	Economy	44300.00
0005434163500	25207	Economy	44300.00
0005435854041	25207	Economy	44300.00
0005434163495	25207	Economy	44300.00
0005435986675	4204	Business	193100.00
0005435986670	4204	Business	193100.00
0005435986677	4204	Business	193100.00
0005435986673	4204	Business	193100.00
0005432184912	4204	Business	193100.00
0005435986679	4204	Economy	64400.00
0005435986678	4204	Economy	64400.00
0005435986674	4204	Economy	64400.00
0005432184913	4204	Economy	64400.00
0005435986671	4204	Economy	64400.00
0005435986672	4204	Economy	64400.00
0005435986676	4204	Economy	64400.00
0005435856147	26597	Business	193100.00
0005435856149	26597	Business	193100.00
0005435947063	26597	Business	193100.00
0005435856150	26597	Economy	70800.00
0005435947061	26597	Economy	64400.00
0005435947068	26597	Economy	64400.00
0005432571275	26597	Economy	64400.00
0005435947070	26597	Economy	64400.00
0005435947067	26597	Economy	64400.00
0005435947065	26597	Economy	64400.00
0005435947059	26597	Economy	64400.00
0005432571273	26597	Economy	64400.00
0005435947058	26597	Economy	64400.00
0005435947057	26597	Economy	64400.00
0005435787327	26597	Economy	64400.00
0005432571274	26597	Economy	64400.00
0005435947064	26597	Economy	64400.00
0005435856148	26597	Economy	64400.00
0005432571272	26597	Economy	64400.00
0005435947069	26597	Economy	64400.00
0005435947062	26597	Economy	64400.00
0005435947066	26597	Economy	64400.00
0005435787326	26597	Economy	64400.00
0005435947060	26597	Economy	64400.00
0005433568282	344	Business	21500.00
0005433568307	344	Business	21500.00
0005433568278	344	Business	21500.00
0005433134060	344	Business	21500.00
0005433568283	344	Business	21500.00
0005433568272	344	Business	21500.00
0005432238852	344	Business	21500.00
0005433568267	344	Economy	7900.00
0005433568296	344	Economy	7200.00
0005433568262	344	Economy	7200.00
0005433568260	344	Economy	7200.00
0005433568270	344	Economy	7200.00
0005433568271	344	Economy	7200.00
0005432238857	344	Economy	7200.00
0005433568269	344	Economy	7200.00
0005433568261	344	Economy	7200.00
0005433568298	344	Economy	7200.00
0005432238853	344	Economy	7200.00
0005433568259	344	Economy	7200.00
0005433568268	344	Economy	7200.00
0005433568292	344	Economy	7200.00
0005433568305	344	Economy	7200.00
0005433568276	344	Economy	7200.00
0005433074237	344	Economy	7200.00
0005433074236	344	Economy	7200.00
0005433568299	344	Economy	7200.00
0005433074196	344	Economy	7200.00
0005433568279	344	Economy	7200.00
0005433568304	344	Economy	7200.00
0005433568275	344	Economy	7200.00
0005433568277	344	Economy	7200.00
0005433568281	344	Economy	7200.00
0005433568288	344	Economy	7200.00
0005432238856	344	Economy	7200.00
0005433568301	344	Economy	7900.00
0005433568285	344	Economy	7200.00
0005433568266	344	Economy	7200.00
0005433568287	344	Economy	7200.00
0005433568295	344	Economy	7200.00
0005432238855	344	Economy	7200.00
0005433568265	344	Economy	7200.00
0005433568294	344	Economy	7200.00
0005433568264	344	Economy	7200.00
0005433568306	344	Economy	7200.00
0005433568280	344	Economy	7200.00
0005432238854	344	Economy	7200.00
0005433568303	344	Economy	7200.00
0005433568293	344	Economy	7200.00
0005433568274	344	Economy	7200.00
0005433568297	344	Economy	7200.00
0005433568290	344	Economy	7200.00
0005433568263	344	Economy	7200.00
0005433568291	344	Economy	7200.00
0005433568273	344	Economy	7200.00
0005433568286	344	Economy	7200.00
0005433568284	344	Economy	7200.00
0005433568289	344	Economy	7200.00
0005433568300	344	Economy	7200.00
0005433568302	344	Economy	7200.00
0005432947914	11598	Business	21500.00
0005433074338	11598	Business	21500.00
0005433074333	11598	Business	21500.00
0005432947928	11598	Business	21500.00
0005432947916	11598	Business	21500.00
0005432947902	11598	Business	21500.00
0005432947911	11598	Business	21500.00
0005432947894	11598	Business	21500.00
0005433074318	11598	Business	21500.00
0005433074335	11598	Business	21500.00
0005433074320	11598	Business	21500.00
0005432947926	11598	Business	21500.00
0005432947904	11598	Business	21500.00
0005433074327	11598	Business	21500.00
0005432947897	11598	Economy	7900.00
0005433074325	11598	Economy	7900.00
0005432192278	11598	Economy	7900.00
0005432947912	11598	Economy	7900.00
0005433131647	11598	Economy	7200.00
0005432947922	11598	Economy	7200.00
0005432192279	11598	Economy	7200.00
0005433074319	11598	Economy	7200.00
0005432947924	11598	Economy	7200.00
0005433074322	11598	Economy	7200.00
0005432947913	11598	Economy	7200.00
0005432947898	11598	Economy	7200.00
0005433074332	11598	Economy	7200.00
0005432947895	11598	Economy	7200.00
0005432947925	11598	Economy	7200.00
0005433074334	11598	Economy	7200.00
0005432947908	11598	Economy	7200.00
0005432947917	11598	Economy	7200.00
0005432947910	11598	Economy	7200.00
0005433131645	11598	Economy	7200.00
0005433134078	11598	Economy	7200.00
0005432192277	11598	Economy	7200.00
0005433074321	11598	Economy	7200.00
0005433074331	11598	Economy	7200.00
0005432947929	11598	Economy	7200.00
0005432947909	11598	Economy	7200.00
0005432947893	11598	Economy	7200.00
0005433074323	11598	Economy	7200.00
0005433074337	11598	Economy	7900.00
0005433074341	11598	Economy	7900.00
0005433134076	11598	Economy	7200.00
0005432947896	11598	Economy	7200.00
0005433074339	11598	Economy	7900.00
0005433074328	11598	Economy	7200.00
0005432947899	11598	Economy	7200.00
0005432947919	11598	Economy	7200.00
0005432947906	11598	Economy	7200.00
0005433074336	11598	Economy	7200.00
0005433074329	11598	Economy	7200.00
0005433074340	11598	Economy	7200.00
0005432947907	11598	Economy	7200.00
0005433074326	11598	Economy	7200.00
0005432947923	11598	Economy	7200.00
0005433074324	11598	Economy	7200.00
0005433131648	11598	Economy	7200.00
0005432947920	11598	Economy	7200.00
0005432947901	11598	Economy	7200.00
0005432947900	11598	Economy	7200.00
0005433074315	11598	Economy	7200.00
0005432947903	11598	Economy	7200.00
0005433074330	11598	Economy	7200.00
0005433074317	11598	Economy	7200.00
0005432947889	11598	Economy	7200.00
0005432947891	11598	Economy	7200.00
0005432947892	11598	Economy	7200.00
0005432947921	11598	Economy	7200.00
0005432947890	11598	Economy	7200.00
0005433074316	11598	Economy	7200.00
0005432947918	11598	Economy	7200.00
0005432947927	11598	Economy	7200.00
0005432947905	11598	Economy	7200.00
0005433131646	11598	Economy	7200.00
0005432947915	11598	Economy	7200.00
0005433134077	11598	Economy	7200.00
0005433817421	9998	Economy	6300.00
0005433817422	9998	Economy	6300.00
0005433817419	9998	Economy	6300.00
0005433817420	9998	Economy	6300.00
0005434732933	13966	Economy	6300.00
0005434732934	13966	Economy	6300.00
0005434732935	13966	Economy	6300.00
0005435981696	2361	Business	184500.00
0005433753497	2361	Business	184500.00
0005433753458	2361	Business	184500.00
0005435981697	2361	Business	184500.00
0005435981691	2361	Business	184500.00
0005435981727	2361	Business	184500.00
0005433753479	2361	Business	184500.00
0005432655384	2361	Business	184500.00
0005435981709	2361	Business	184500.00
0005432655386	2361	Business	184500.00
0005435981724	2361	Business	184500.00
0005433753502	2361	Business	184500.00
0005433766590	2361	Business	184500.00
0005433753464	2361	Business	184500.00
0005435981712	2361	Business	184500.00
0005432300191	2361	Business	184500.00
0005433753494	2361	Business	184500.00
0005432655381	2361	Business	184500.00
0005433764652	2361	Economy	67700.00
0005435981729	2361	Economy	67700.00
0005435981695	2361	Economy	61500.00
0005433753487	2361	Economy	61500.00
0005433753454	2361	Economy	61500.00
0005435981702	2361	Economy	61500.00
0005432225977	2361	Economy	61500.00
0005435981716	2361	Economy	61500.00
0005432655376	2361	Economy	61500.00
0005433764653	2361	Economy	61500.00
0005435981698	2361	Economy	61500.00
0005433753491	2361	Economy	61500.00
0005435981723	2361	Economy	61500.00
0005432655380	2361	Economy	61500.00
0005433753495	2361	Economy	61500.00
0005432300190	2361	Economy	61500.00
0005433753488	2361	Economy	61500.00
0005435981721	2361	Economy	61500.00
0005435981707	2361	Economy	61500.00
0005433753490	2361	Economy	61500.00
0005435981730	2361	Economy	61500.00
0005435981694	2361	Economy	61500.00
0005433766589	2361	Economy	61500.00
0005433753503	2361	Economy	61500.00
0005432984597	2361	Economy	61500.00
0005432300189	2361	Economy	61500.00
0005435981718	2361	Economy	61500.00
0005435981733	2361	Economy	61500.00
0005433753508	2361	Economy	61500.00
0005433753472	2361	Economy	61500.00
0005435981708	2361	Economy	61500.00
0005433753507	2361	Economy	61500.00
0005435981734	2361	Economy	61500.00
0005433753475	2361	Economy	61500.00
0005433753470	2361	Economy	61500.00
0005432984596	2361	Economy	61500.00
0005433753509	2361	Economy	61500.00
0005432225976	2361	Economy	61500.00
0005433753459	2361	Economy	61500.00
0005433753501	2361	Economy	61500.00
0005433766592	2361	Economy	61500.00
0005432655379	2361	Economy	61500.00
0005433753456	2361	Economy	61500.00
0005435981728	2361	Economy	61500.00
0005433753493	2361	Economy	61500.00
0005435981722	2361	Economy	61500.00
0005435981725	2361	Economy	61500.00
0005435981710	2361	Economy	61500.00
0005432225972	2361	Economy	61500.00
0005432655385	2361	Economy	61500.00
0005432300187	2361	Economy	61500.00
0005435981705	2361	Economy	61500.00
0005433753473	2361	Economy	61500.00
0005433753474	2361	Economy	61500.00
0005435981713	2361	Economy	61500.00
0005433766591	2361	Economy	61500.00
0005432655375	2361	Economy	61500.00
0005435981700	2361	Economy	61500.00
0005432300188	2361	Economy	61500.00
0005435981717	2361	Economy	61500.00
0005435981693	2361	Economy	61500.00
0005433753452	2361	Economy	61500.00
0005433753485	2361	Economy	61500.00
0005433753483	2361	Economy	61500.00
0005433753466	2361	Economy	61500.00
0005435981701	2361	Economy	61500.00
0005433753506	2361	Economy	61500.00
0005435981714	2361	Economy	67700.00
0005432225973	2361	Economy	67700.00
0005435981720	2361	Economy	61500.00
0005432655378	2361	Economy	67700.00
0005433753498	2361	Economy	67700.00
0005433753468	2361	Economy	61500.00
0005435981732	2361	Economy	61500.00
0005432655383	2361	Economy	61500.00
0005433753477	2361	Economy	61500.00
0005433766588	2361	Economy	61500.00
0005433753453	2361	Economy	61500.00
0005432655377	2361	Economy	61500.00
0005433753465	2361	Economy	61500.00
0005435981731	2361	Economy	61500.00
0005433753478	2361	Economy	61500.00
0005432225971	2361	Economy	61500.00
0005432984598	2361	Economy	61500.00
0005433753504	2361	Economy	61500.00
0005433753451	2361	Economy	61500.00
0005433753476	2361	Economy	61500.00
0005433753500	2361	Economy	61500.00
0005435981726	2361	Economy	61500.00
0005433753489	2361	Economy	61500.00
0005433753481	2361	Economy	61500.00
0005433753482	2361	Economy	61500.00
0005433753460	2361	Economy	61500.00
0005435981703	2361	Economy	61500.00
0005435981692	2361	Economy	61500.00
0005435981690	2361	Economy	61500.00
0005433753480	2361	Economy	61500.00
0005433753486	2361	Economy	61500.00
0005435981699	2361	Economy	61500.00
0005433753492	2361	Economy	61500.00
0005435981719	2361	Economy	61500.00
0005435981711	2361	Economy	61500.00
0005433753471	2361	Economy	61500.00
0005433753469	2361	Economy	61500.00
0005433764651	2361	Economy	61500.00
0005433753463	2361	Economy	61500.00
0005433753467	2361	Economy	61500.00
0005432300186	2361	Economy	61500.00
0005432655382	2361	Economy	61500.00
0005432225975	2361	Economy	61500.00
0005433753461	2361	Economy	61500.00
0005433753462	2361	Economy	61500.00
0005433753499	2361	Economy	61500.00
0005435981715	2361	Economy	61500.00
0005435981706	2361	Economy	61500.00
0005433753484	2361	Economy	61500.00
0005435981704	2361	Economy	61500.00
0005433753496	2361	Economy	61500.00
0005432225974	2361	Economy	61500.00
0005433753505	2361	Economy	61500.00
0005433753455	2361	Economy	61500.00
0005432300185	2361	Economy	61500.00
0005433753457	2361	Economy	61500.00
0005432984664	26197	Business	184500.00
0005433434295	26197	Business	184500.00
0005432984637	26197	Business	184500.00
0005432051088	26197	Business	184500.00
0005432984656	26197	Business	184500.00
0005433434320	26197	Business	184500.00
0005432984643	26197	Business	184500.00
0005433434314	26197	Business	184500.00
0005432984638	26197	Business	184500.00
0005433434298	26197	Business	184500.00
0005432984642	26197	Economy	67700.00
0005432984657	26197	Economy	67700.00
0005432869437	26197	Economy	67700.00
0005433434297	26197	Economy	61500.00
0005434731113	26197	Economy	61500.00
0005433434309	26197	Economy	61500.00
0005433434305	26197	Economy	61500.00
0005434731115	26197	Economy	61500.00
0005433434306	26197	Economy	61500.00
0005433434317	26197	Economy	61500.00
0005432984653	26197	Economy	61500.00
0005432984641	26197	Economy	61500.00
0005433434322	26197	Economy	61500.00
0005433753258	26197	Economy	61500.00
0005432984635	26197	Economy	61500.00
0005433434296	26197	Economy	61500.00
0005434731114	26197	Economy	61500.00
0005432984644	26197	Economy	61500.00
0005432869431	26197	Economy	61500.00
0005433434310	26197	Economy	61500.00
0005433434307	26197	Economy	61500.00
0005433434319	26197	Economy	61500.00
0005433434316	26197	Economy	61500.00
0005432049414	26197	Economy	61500.00
0005432051086	26197	Economy	61500.00
0005432984652	26197	Economy	61500.00
0005432984654	26197	Economy	61500.00
0005432984639	26197	Economy	61500.00
0005434731116	26197	Economy	61500.00
0005433434301	26197	Economy	61500.00
0005433434302	26197	Economy	61500.00
0005432984660	26197	Economy	61500.00
0005432869432	26197	Economy	61500.00
0005433434311	26197	Economy	61500.00
0005433434315	26197	Economy	61500.00
0005432984640	26197	Economy	61500.00
0005433434313	26197	Economy	61500.00
0005433434318	26197	Economy	61500.00
0005433434323	26197	Economy	61500.00
0005433434300	26197	Economy	67700.00
0005432984663	26197	Economy	61500.00
0005433753257	26197	Economy	67700.00
0005433434303	26197	Economy	61500.00
0005432984634	26197	Economy	61500.00
0005432869435	26197	Economy	61500.00
0005432051087	26197	Economy	61500.00
0005432984662	26197	Economy	61500.00
0005432984658	26197	Economy	61500.00
0005432984661	26197	Economy	61500.00
0005432984655	26197	Economy	61500.00
0005432984666	26197	Economy	61500.00
0005432049417	26197	Economy	61500.00
0005433434324	26197	Economy	61500.00
0005432869434	26197	Economy	61500.00
0005432869433	26197	Economy	61500.00
0005433434304	26197	Economy	61500.00
0005432984645	26197	Economy	61500.00
0005432984647	26197	Economy	61500.00
0005432984659	26197	Economy	61500.00
0005432984651	26197	Economy	61500.00
0005432984648	26197	Economy	61500.00
0005433766572	26197	Economy	61500.00
0005432984636	26197	Economy	61500.00
0005433434321	26197	Economy	61500.00
0005432984650	26197	Economy	61500.00
0005432049415	26197	Economy	61500.00
0005432869436	26197	Economy	61500.00
0005432984665	26197	Economy	61500.00
0005433434312	26197	Economy	61500.00
0005432984646	26197	Economy	61500.00
0005433434308	26197	Economy	61500.00
0005433434299	26197	Economy	61500.00
0005432049416	26197	Economy	61500.00
0005432984633	26197	Economy	61500.00
0005432984649	26197	Economy	61500.00
0005432267805	1508	Business	38900.00
0005434374065	1508	Business	38900.00
0005432267807	1508	Business	38900.00
0005434374053	1508	Economy	13000.00
0005434374067	1508	Economy	13000.00
0005434374079	1508	Economy	13000.00
0005434374070	1508	Economy	13000.00
0005433460408	1508	Economy	13000.00
0005434374076	1508	Economy	13000.00
0005433150855	1508	Economy	13000.00
0005434374072	1508	Economy	13000.00
0005434374055	1508	Economy	13000.00
0005434374081	1508	Economy	13000.00
0005434374068	1508	Economy	13000.00
0005434374066	1508	Economy	13000.00
0005434374051	1508	Economy	13000.00
0005434374075	1508	Economy	13000.00
0005434374078	1508	Economy	14300.00
0005434374080	1508	Economy	14300.00
0005434374064	1508	Economy	13000.00
0005434374077	1508	Economy	13000.00
0005433150928	1508	Economy	13000.00
0005433461560	1508	Economy	13000.00
0005434374060	1508	Economy	13000.00
0005434374062	1508	Economy	13000.00
0005434374057	1508	Economy	13000.00
0005432267808	1508	Economy	13000.00
0005434374063	1508	Economy	13000.00
0005434374061	1508	Economy	13000.00
0005434374073	1508	Economy	13000.00
0005434374058	1508	Economy	13000.00
0005432267809	1508	Economy	13000.00
0005433150926	1508	Economy	13000.00
0005433150927	1508	Economy	13000.00
0005434374074	1508	Economy	13000.00
0005434374071	1508	Economy	13000.00
0005434374052	1508	Economy	13000.00
0005432267804	1508	Economy	13000.00
0005433461559	1508	Economy	13000.00
0005434374069	1508	Economy	13000.00
0005434374054	1508	Economy	13000.00
0005432267806	1508	Economy	13000.00
0005434374056	1508	Economy	13000.00
0005434374059	1508	Economy	13000.00
0005433150961	20147	Business	38900.00
0005432056248	20147	Business	38900.00
0005433150958	20147	Business	38900.00
0005433764651	20147	Business	38900.00
0005433764653	20147	Business	38900.00
0005433150950	20147	Business	38900.00
0005433150960	20147	Economy	13000.00
0005433150946	20147	Economy	13000.00
0005434373867	20147	Economy	13000.00
0005433150949	20147	Economy	13000.00
0005433150939	20147	Economy	13000.00
0005433150959	20147	Economy	13000.00
0005433150968	20147	Economy	13000.00
0005432056250	20147	Economy	13000.00
0005433150941	20147	Economy	13000.00
0005433150934	20147	Economy	13000.00
0005433150942	20147	Economy	13000.00
0005433150937	20147	Economy	13000.00
0005433150944	20147	Economy	13000.00
0005432056249	20147	Economy	13000.00
0005433150969	20147	Economy	13000.00
0005433764652	20147	Economy	14300.00
0005433150954	20147	Economy	13000.00
0005433150965	20147	Economy	13000.00
0005433150967	20147	Economy	13000.00
0005433150943	20147	Economy	13000.00
0005433150935	20147	Economy	13000.00
0005433150956	20147	Economy	13000.00
0005433150955	20147	Economy	13000.00
0005433150953	20147	Economy	13000.00
0005433150936	20147	Economy	13000.00
0005433150945	20147	Economy	13000.00
0005433150952	20147	Economy	13000.00
0005434029625	20147	Economy	13000.00
0005433150966	20147	Economy	13000.00
0005433150962	20147	Economy	13000.00
0005433150964	20147	Economy	13000.00
0005433150951	20147	Economy	13000.00
0005433150947	20147	Economy	13000.00
0005434029624	20147	Economy	13000.00
0005433150948	20147	Economy	13000.00
0005433150938	20147	Economy	13000.00
0005433931426	20147	Economy	13000.00
0005433150940	20147	Economy	13000.00
0005433150963	20147	Economy	13000.00
0005433150957	20147	Economy	13000.00
0005432282773	544	Business	27500.00
0005432423837	544	Business	27500.00
0005432423853	544	Business	27500.00
0005432423840	544	Business	27500.00
0005432282771	544	Business	27500.00
0005432423836	544	Business	27500.00
0005432423845	544	Business	27500.00
0005432423816	544	Business	27500.00
0005432423832	544	Business	27500.00
0005432282772	544	Business	27500.00
0005432423824	544	Economy	10100.00
0005432423826	544	Economy	10100.00
0005432423819	544	Economy	10100.00
0005432423813	544	Economy	9200.00
0005432423856	544	Economy	9200.00
0005432423844	544	Economy	9200.00
0005432423834	544	Economy	9200.00
0005432423828	544	Economy	9200.00
0005432423846	544	Economy	9200.00
0005432423858	544	Economy	9200.00
0005432423831	544	Economy	9200.00
0005432423829	544	Economy	9200.00
0005432423849	544	Economy	9200.00
0005432282769	544	Economy	9200.00
0005432423835	544	Economy	9200.00
0005432423850	544	Economy	9200.00
0005432423830	544	Economy	9200.00
0005432282770	544	Economy	9200.00
0005432423841	544	Economy	9200.00
0005432423827	544	Economy	9200.00
0005432423843	544	Economy	10100.00
0005432423823	544	Economy	9200.00
0005432423838	544	Economy	9200.00
0005432423859	544	Economy	9200.00
0005432423818	544	Economy	9200.00
0005432423855	544	Economy	9200.00
0005432423839	544	Economy	9200.00
0005432423820	544	Economy	9200.00
0005432423842	544	Economy	9200.00
0005432423822	544	Economy	9200.00
0005432423833	544	Economy	9200.00
0005432423854	544	Economy	9200.00
0005432423817	544	Economy	9200.00
0005432423821	544	Economy	9200.00
0005432282768	544	Economy	9200.00
0005432423815	544	Economy	9200.00
0005432423848	544	Economy	9200.00
0005432423811	544	Economy	9200.00
0005432423825	544	Economy	9200.00
0005432423852	544	Economy	9200.00
0005432423810	544	Economy	9200.00
0005432423851	544	Economy	9200.00
0005432423814	544	Economy	9200.00
0005432423857	544	Economy	9200.00
0005432423812	544	Economy	9200.00
0005432423847	544	Economy	9200.00
0005432302279	12938	Economy	9200.00
0005433158099	12938	Economy	9200.00
0005432302281	12938	Economy	9200.00
0005433158103	12938	Economy	9200.00
0005433158102	12938	Economy	9200.00
0005433158101	12938	Economy	9200.00
0005433158100	12938	Economy	9200.00
0005432302282	12938	Economy	9200.00
0005432302280	12938	Economy	9200.00
0005433057169	475	Business	24500.00
0005434022785	475	Business	24500.00
0005434022830	475	Business	24500.00
0005434022843	475	Business	24500.00
0005433057259	475	Business	24500.00
0005432045585	475	Business	24500.00
0005434022789	475	Business	24500.00
0005434022840	475	Business	24500.00
0005434022790	475	Business	24500.00
0005434022844	475	Business	24500.00
0005434022811	475	Business	24500.00
0005434022804	475	Economy	9000.00
0005434022812	475	Economy	9000.00
0005434022803	475	Economy	9000.00
0005434022783	475	Economy	9000.00
0005434031957	475	Economy	8200.00
0005434022809	475	Economy	8200.00
0005434022837	475	Economy	8200.00
0005434029621	475	Economy	8200.00
0005432045586	475	Economy	8200.00
0005434022801	475	Economy	8200.00
0005434022792	475	Economy	8200.00
0005434022824	475	Economy	8200.00
0005434022816	475	Economy	8200.00
0005434022825	475	Economy	8200.00
0005434022826	475	Economy	8200.00
0005434022784	475	Economy	8200.00
0005434022821	475	Economy	8200.00
0005434022817	475	Economy	8200.00
0005434022794	475	Economy	8200.00
0005434022795	475	Economy	8200.00
0005434022787	475	Economy	8200.00
0005434022788	475	Economy	8200.00
0005434022779	475	Economy	8200.00
0005434022818	475	Economy	8200.00
0005434022805	475	Economy	8200.00
0005434022797	475	Economy	8200.00
0005434022791	475	Economy	8200.00
0005432235535	475	Economy	8200.00
0005434031961	475	Economy	8200.00
0005434022829	475	Economy	8200.00
0005434022802	475	Economy	8200.00
0005433057211	475	Economy	8200.00
0005434022834	475	Economy	8200.00
0005434022819	475	Economy	8200.00
0005434022831	475	Economy	8200.00
0005432235538	475	Economy	8200.00
0005434022839	475	Economy	8200.00
0005434028257	475	Economy	8200.00
0005434022836	475	Economy	8200.00
0005434028259	475	Economy	8200.00
0005434022845	475	Economy	8200.00
0005434031959	475	Economy	8200.00
0005433057168	475	Economy	8200.00
0005434022806	475	Economy	8200.00
0005434022820	475	Economy	8200.00
0005433057260	475	Economy	8200.00
0005434022781	475	Economy	8200.00
0005434022823	475	Economy	8200.00
0005434022815	475	Economy	8200.00
0005434022827	475	Economy	8200.00
0005433057170	475	Economy	8200.00
0005434022786	475	Economy	9000.00
0005432235539	475	Economy	8200.00
0005434022796	475	Economy	9000.00
0005434022814	475	Economy	9000.00
0005434022832	475	Economy	8200.00
0005434022835	475	Economy	8200.00
0005434031960	475	Economy	8200.00
0005434022833	475	Economy	8200.00
0005434022798	475	Economy	8200.00
0005434022778	475	Economy	8200.00
0005434022808	475	Economy	8200.00
0005434022780	475	Economy	8200.00
0005434022822	475	Economy	8200.00
0005434022841	475	Economy	8200.00
0005432235540	475	Economy	8200.00
0005434022813	475	Economy	8200.00
0005432235541	475	Economy	8200.00
0005434029623	475	Economy	8200.00
0005434022838	475	Economy	8200.00
0005434022846	475	Economy	8200.00
0005434022782	475	Economy	8200.00
0005433057247	475	Economy	8200.00
0005434029622	475	Economy	8200.00
0005434022799	475	Economy	8200.00
0005434028260	475	Economy	8200.00
0005434022800	475	Economy	8200.00
0005434022828	475	Economy	8200.00
0005434022810	475	Economy	8200.00
0005434028258	475	Economy	8200.00
0005434031958	475	Economy	8200.00
0005434022793	475	Economy	8200.00
0005432235536	475	Economy	8200.00
0005434022842	475	Economy	8200.00
0005434022807	475	Economy	8200.00
0005432235537	475	Economy	8200.00
0005432156304	12666	Business	24500.00
0005433057357	12666	Business	24500.00
0005432156308	12666	Business	24500.00
0005432157465	12666	Business	24500.00
0005433057370	12666	Business	24500.00
0005433057367	12666	Business	24500.00
0005433057337	12666	Business	24500.00
0005433929558	12666	Business	24500.00
0005433057339	12666	Economy	8200.00
0005433057360	12666	Economy	8200.00
0005433057373	12666	Economy	8200.00
0005433057336	12666	Economy	8200.00
0005433057372	12666	Economy	8200.00
0005433057368	12666	Economy	8200.00
0005434735621	12666	Economy	8200.00
0005433057346	12666	Economy	8200.00
0005433057362	12666	Economy	8200.00
0005433057344	12666	Economy	8200.00
0005433684393	12666	Economy	8200.00
0005433057353	12666	Economy	8200.00
0005433057363	12666	Economy	8200.00
0005433057366	12666	Economy	8200.00
0005433057351	12666	Economy	8200.00
0005433057334	12666	Economy	8200.00
0005433929556	12666	Economy	8200.00
0005434735620	12666	Economy	8200.00
0005433057356	12666	Economy	8200.00
0005433057364	12666	Economy	8200.00
0005433057348	12666	Economy	8200.00
0005433057358	12666	Economy	8200.00
0005432156307	12666	Economy	8200.00
0005433057347	12666	Economy	8200.00
0005433057345	12666	Economy	8200.00
0005433057354	12666	Economy	8200.00
0005433057349	12666	Economy	8200.00
0005433057342	12666	Economy	8200.00
0005434735622	12666	Economy	8200.00
0005433684394	12666	Economy	8200.00
0005432156306	12666	Economy	8200.00
0005434735619	12666	Economy	8200.00
0005433057350	12666	Economy	9000.00
0005433057369	12666	Economy	8200.00
0005432156305	12666	Economy	8200.00
0005434022539	12666	Economy	8200.00
0005433057343	12666	Economy	8200.00
0005433057352	12666	Economy	8200.00
0005434735623	12666	Economy	8200.00
0005433057338	12666	Economy	8200.00
0005433057361	12666	Economy	8200.00
0005433057340	12666	Economy	8200.00
0005433929559	12666	Economy	8200.00
0005433057341	12666	Economy	8200.00
0005433057365	12666	Economy	8200.00
0005433057335	12666	Economy	8200.00
0005434735618	12666	Economy	8200.00
0005433057355	12666	Economy	8200.00
0005432157466	12666	Economy	8200.00
0005433929557	12666	Economy	8200.00
0005433057359	12666	Economy	8200.00
0005433057371	12666	Economy	8200.00
0005433057333	12666	Economy	8200.00
0005433922017	2157	Business	34700.00
0005433922030	2157	Business	34700.00
0005433922005	2157	Business	34700.00
0005433921982	2157	Business	34700.00
0005433922062	2157	Business	34700.00
0005433922070	2157	Business	34700.00
0005433035364	2157	Business	34700.00
0005433922029	2157	Business	34700.00
0005432044486	2157	Business	34700.00
0005433922045	2157	Business	34700.00
0005433922025	2157	Business	34700.00
0005433922011	2157	Business	34700.00
0005432231423	2157	Business	34700.00
0005433921987	2157	Business	34700.00
0005433922023	2157	Economy	12700.00
0005433922013	2157	Business	34700.00
0005433929556	2157	Economy	12700.00
0005433922063	2157	Economy	12700.00
0005433921984	2157	Economy	12700.00
0005433922056	2157	Economy	11600.00
0005433922024	2157	Economy	11600.00
0005433922071	2157	Economy	11600.00
0005433922001	2157	Economy	11600.00
0005433922007	2157	Economy	11600.00
0005433922069	2157	Economy	11600.00
0005432231420	2157	Economy	11600.00
0005433922020	2157	Economy	11600.00
0005433922068	2157	Economy	11600.00
0005432231427	2157	Economy	11600.00
0005433921981	2157	Economy	11600.00
0005433921995	2157	Economy	11600.00
0005433922004	2157	Economy	11600.00
0005433922009	2157	Economy	11600.00
0005433922052	2157	Economy	11600.00
0005433922076	2157	Economy	11600.00
0005433922027	2157	Economy	11600.00
0005433922008	2157	Economy	11600.00
0005433922047	2157	Economy	11600.00
0005433922066	2157	Economy	11600.00
0005432231417	2157	Economy	11600.00
0005433035399	2157	Economy	11600.00
0005433922065	2157	Economy	11600.00
0005433922072	2157	Economy	11600.00
0005433922033	2157	Economy	11600.00
0005432231421	2157	Economy	11600.00
0005433922015	2157	Economy	11600.00
0005433929557	2157	Economy	11600.00
0005433922022	2157	Economy	11600.00
0005433921986	2157	Economy	11600.00
0005433922059	2157	Economy	11600.00
0005432231424	2157	Economy	11600.00
0005433921999	2157	Economy	11600.00
0005433035450	2157	Economy	11600.00
0005433922000	2157	Economy	11600.00
0005433922055	2157	Economy	11600.00
0005433922036	2157	Economy	11600.00
0005433929559	2157	Economy	11600.00
0005433922057	2157	Economy	11600.00
0005433921985	2157	Economy	11600.00
0005433922048	2157	Economy	11600.00
0005433922039	2157	Economy	11600.00
0005433922018	2157	Economy	11600.00
0005433921980	2157	Economy	11600.00
0005433922028	2157	Economy	11600.00
0005432231426	2157	Economy	11600.00
0005433922050	2157	Economy	11600.00
0005433921983	2157	Economy	11600.00
0005433922073	2157	Economy	11600.00
0005433921996	2157	Economy	11600.00
0005433922006	2157	Economy	11600.00
0005433921997	2157	Economy	11600.00
0005433875357	2157	Economy	11600.00
0005433922051	2157	Economy	11600.00
0005432231425	2157	Economy	11600.00
0005433922061	2157	Economy	11600.00
0005432231419	2157	Economy	11600.00
0005433922038	2157	Economy	11600.00
0005433922074	2157	Economy	12700.00
0005433922012	2157	Economy	12700.00
0005433922040	2157	Economy	11600.00
0005433922041	2157	Economy	12700.00
0005433921993	2157	Economy	12700.00
0005433921990	2157	Economy	11600.00
0005433922010	2157	Economy	11600.00
0005433922032	2157	Economy	11600.00
0005433922003	2157	Economy	11600.00
0005433922067	2157	Economy	11600.00
0005433922049	2157	Economy	11600.00
0005433922064	2157	Economy	11600.00
0005433921989	2157	Economy	11600.00
0005433922042	2157	Economy	11600.00
0005433922002	2157	Economy	11600.00
0005433921998	2157	Economy	11600.00
0005433921991	2157	Economy	11600.00
0005432044487	2157	Economy	11600.00
0005433922060	2157	Economy	11600.00
0005433921988	2157	Economy	11600.00
0005433922026	2157	Economy	11600.00
0005433921992	2157	Economy	11600.00
0005432231418	2157	Economy	11600.00
0005433922037	2157	Economy	11600.00
0005433922021	2157	Economy	11600.00
0005433922019	2157	Economy	11600.00
0005433922058	2157	Economy	11600.00
0005433922075	2157	Economy	11600.00
0005433922016	2157	Economy	11600.00
0005433931426	2157	Economy	11600.00
0005432044488	2157	Economy	11600.00
0005433922034	2157	Economy	11600.00
0005433922053	2157	Economy	11600.00
0005433922035	2157	Economy	11600.00
0005433921994	2157	Economy	11600.00
0005432231422	2157	Economy	11600.00
0005433922077	2157	Economy	11600.00
0005433922031	2157	Economy	11600.00
0005433922044	2157	Economy	11600.00
0005433922014	2157	Economy	11600.00
0005433922054	2157	Economy	11600.00
0005433929558	2157	Economy	11600.00
0005433922043	2157	Economy	11600.00
0005433922046	2157	Economy	11600.00
0005433035613	24142	Business	34700.00
0005433921780	24142	Business	34700.00
0005433035604	24142	Business	34700.00
0005433035602	24142	Business	34700.00
0005433035576	24142	Business	34700.00
0005433035608	24142	Business	34700.00
0005433035590	24142	Business	34700.00
0005433035620	24142	Business	34700.00
0005433035612	24142	Business	34700.00
0005433035607	24142	Business	34700.00
0005432206121	24142	Business	34700.00
0005433035588	24142	Business	34700.00
0005433035614	24142	Business	34700.00
0005433035585	24142	Economy	11600.00
0005433035596	24142	Economy	11600.00
0005433035586	24142	Economy	11600.00
0005433035575	24142	Economy	11600.00
0005433035616	24142	Economy	11600.00
0005432207627	24142	Economy	11600.00
0005433035601	24142	Economy	11600.00
0005433035606	24142	Economy	11600.00
0005433035621	24142	Economy	11600.00
0005433035577	24142	Economy	11600.00
0005433035619	24142	Economy	11600.00
0005433035582	24142	Economy	11600.00
0005433035603	24142	Economy	11600.00
0005433035622	24142	Economy	11600.00
0005433035609	24142	Economy	11600.00
0005433035595	24142	Economy	11600.00
0005432207628	24142	Economy	11600.00
0005433035597	24142	Economy	11600.00
0005433035581	24142	Economy	11600.00
0005433035574	24142	Economy	11600.00
0005433035599	24142	Economy	11600.00
0005433035583	24142	Economy	11600.00
0005433035605	24142	Economy	11600.00
0005433035592	24142	Economy	11600.00
0005432749756	24142	Economy	11600.00
0005433035584	24142	Economy	11600.00
0005433035615	24142	Economy	11600.00
0005432206118	24142	Economy	11600.00
0005432206116	24142	Economy	11600.00
0005433921781	24142	Economy	11600.00
0005433035598	24142	Economy	11600.00
0005433035594	24142	Economy	12700.00
0005432206117	24142	Economy	11600.00
0005432206119	24142	Economy	11600.00
0005433035623	24142	Economy	11600.00
0005433035578	24142	Economy	11600.00
0005433035579	24142	Economy	11600.00
0005433035591	24142	Economy	11600.00
0005433035600	24142	Economy	11600.00
0005433035611	24142	Economy	11600.00
0005433035572	24142	Economy	11600.00
0005433035593	24142	Economy	11600.00
0005432749755	24142	Economy	11600.00
0005433035618	24142	Economy	11600.00
0005433035617	24142	Economy	11600.00
0005433035589	24142	Economy	11600.00
0005433035573	24142	Economy	11600.00
0005433035624	24142	Economy	11600.00
0005432206115	24142	Economy	11600.00
0005433035580	24142	Economy	11600.00
0005433035587	24142	Economy	11600.00
0005432206120	24142	Economy	11600.00
0005433035610	24142	Economy	11600.00
0005433035625	24142	Economy	11600.00
0005434723809	255	Business	83700.00
0005434723878	255	Business	83700.00
0005434550484	255	Business	83700.00
0005433233132	255	Business	83700.00
0005434723843	255	Business	83700.00
0005434723820	255	Business	83700.00
0005434550502	255	Business	83700.00
0005434550491	255	Business	83700.00
0005434723811	255	Business	83700.00
0005435142393	255	Business	83700.00
0005434550534	255	Business	83700.00
0005434723865	255	Business	83700.00
0005433233134	255	Business	83700.00
0005434550507	255	Business	83700.00
0005433233133	255	Comfort	47400.00
0005434302403	255	Comfort	47400.00
0005434723916	255	Comfort	47400.00
0005434550521	255	Comfort	47400.00
0005432277636	255	Comfort	47400.00
0005434723896	255	Comfort	47400.00
0005434723830	255	Comfort	47400.00
0005434723840	255	Comfort	47400.00
0005434723892	255	Comfort	47400.00
0005435142401	255	Comfort	47400.00
0005433233119	255	Comfort	47400.00
0005434550532	255	Comfort	47400.00
0005435142403	255	Comfort	47400.00
0005434550508	255	Comfort	47400.00
0005434550488	255	Comfort	47400.00
0005434723835	255	Comfort	47400.00
0005434723837	255	Comfort	47400.00
0005432277631	255	Comfort	47400.00
0005434723819	255	Comfort	47400.00
0005434550487	255	Comfort	47400.00
0005434723890	255	Comfort	47400.00
0005434550536	255	Comfort	47400.00
0005434550504	255	Comfort	47400.00
0005434723887	255	Comfort	47400.00
0005434723870	255	Comfort	47400.00
0005434723832	255	Economy	27900.00
0005432277626	255	Economy	27900.00
0005434735616	255	Economy	27900.00
0005434550519	255	Economy	27900.00
0005434550514	255	Economy	27900.00
0005432277632	255	Economy	27900.00
0005434723881	255	Economy	27900.00
0005434723929	255	Economy	27900.00
0005434550510	255	Economy	27900.00
0005434723924	255	Economy	27900.00
0005434550518	255	Economy	27900.00
0005434723918	255	Economy	27900.00
0005434723874	255	Economy	27900.00
0005434723861	255	Economy	27900.00
0005434723893	255	Economy	27900.00
0005434550489	255	Economy	27900.00
0005434302401	255	Economy	27900.00
0005434723836	255	Economy	27900.00
0005432277635	255	Economy	27900.00
0005432277628	255	Economy	27900.00
0005434723907	255	Economy	27900.00
0005434550511	255	Economy	27900.00
0005432277627	255	Economy	27900.00
0005435142391	255	Economy	27900.00
0005434723884	255	Economy	27900.00
0005434550524	255	Economy	27900.00
0005434723901	255	Economy	27900.00
0005434302402	255	Economy	27900.00
0005432277629	255	Economy	27900.00
0005434302399	255	Economy	27900.00
0005434731111	255	Economy	27900.00
0005434723806	255	Economy	27900.00
0005434723812	255	Economy	27900.00
0005434550496	255	Economy	27900.00
0005434731109	255	Economy	27900.00
0005434735615	255	Economy	27900.00
0005435142402	255	Economy	27900.00
0005434550497	255	Economy	30700.00
0005434735613	255	Economy	27900.00
0005434550533	255	Economy	27900.00
0005434723823	255	Economy	27900.00
0005434550523	255	Economy	27900.00
0005434723828	255	Economy	27900.00
0005434723849	255	Economy	27900.00
0005434723808	255	Economy	27900.00
0005434550495	255	Economy	27900.00
0005434723846	255	Economy	27900.00
0005434723927	255	Economy	27900.00
0005434723919	255	Economy	27900.00
0005434723877	255	Economy	27900.00
0005434723860	255	Economy	27900.00
0005434550516	255	Economy	27900.00
0005434723814	255	Economy	27900.00
0005434723851	255	Economy	27900.00
0005434723895	255	Economy	27900.00
0005432277625	255	Economy	27900.00
0005434723875	255	Economy	27900.00
0005434723921	255	Economy	27900.00
0005434723889	255	Economy	27900.00
0005434723852	255	Economy	27900.00
0005434723913	255	Economy	27900.00
0005434723926	255	Economy	27900.00
0005434723868	255	Economy	27900.00
0005434735614	255	Economy	27900.00
0005434723908	255	Economy	27900.00
0005434723842	255	Economy	27900.00
0005434723886	255	Economy	27900.00
0005434723805	255	Economy	27900.00
0005434723824	255	Economy	27900.00
0005435142400	255	Economy	27900.00
0005434723910	255	Economy	27900.00
0005435142399	255	Economy	27900.00
0005434723914	255	Economy	27900.00
0005434550509	255	Economy	27900.00
0005434550522	255	Economy	27900.00
0005434550513	255	Economy	27900.00
0005434550493	255	Economy	27900.00
0005434723904	255	Economy	27900.00
0005434550499	255	Economy	27900.00
0005435142404	255	Economy	27900.00
0005434723911	255	Economy	27900.00
0005432277623	255	Economy	27900.00
0005434723822	255	Economy	27900.00
0005434723825	255	Economy	27900.00
0005434723853	255	Economy	27900.00
0005434723891	255	Economy	27900.00
0005434550520	255	Economy	27900.00
0005434723900	255	Economy	27900.00
0005434723839	255	Economy	27900.00
0005434550531	255	Economy	27900.00
0005434723848	255	Economy	27900.00
0005434723909	255	Economy	27900.00
0005434550500	255	Economy	27900.00
0005434723818	255	Economy	27900.00
0005434550505	255	Economy	27900.00
0005434723879	255	Economy	27900.00
0005432277624	255	Economy	27900.00
0005434723826	255	Economy	27900.00
0005434550501	255	Economy	27900.00
0005434723854	255	Economy	27900.00
0005434723810	255	Economy	27900.00
0005434723922	255	Economy	27900.00
0005435142396	255	Economy	27900.00
0005432277634	255	Economy	27900.00
0005434723880	255	Economy	27900.00
0005434723902	255	Economy	27900.00
0005435142390	255	Economy	27900.00
0005434550512	255	Economy	27900.00
0005434550525	255	Economy	27900.00
0005434723855	255	Economy	27900.00
0005434723831	255	Economy	27900.00
0005434550528	255	Economy	30700.00
0005434723882	255	Economy	30700.00
0005434723833	255	Economy	30700.00
0005435142394	255	Economy	27900.00
0005433233118	255	Economy	30700.00
0005434723905	255	Economy	30700.00
0005434723838	255	Economy	27900.00
0005434550506	255	Economy	27900.00
0005432277633	255	Economy	27900.00
0005435142395	255	Economy	27900.00
0005434723898	255	Economy	27900.00
0005434723815	255	Economy	27900.00
0005434550486	255	Economy	27900.00
0005434550494	255	Economy	27900.00
0005434723894	255	Economy	27900.00
0005434723873	255	Economy	27900.00
0005434723883	255	Economy	27900.00
0005434723847	255	Economy	27900.00
0005434550492	255	Economy	27900.00
0005434723857	255	Economy	27900.00
0005434723925	255	Economy	27900.00
0005434723858	255	Economy	27900.00
0005434723869	255	Economy	27900.00
0005434723813	255	Economy	27900.00
0005434723888	255	Economy	27900.00
0005434723903	255	Economy	27900.00
0005434723817	255	Economy	27900.00
0005434723866	255	Economy	27900.00
0005434723920	255	Economy	27900.00
0005434723845	255	Economy	27900.00
0005434550527	255	Economy	27900.00
0005434731112	255	Economy	27900.00
0005434723915	255	Economy	27900.00
0005434723923	255	Economy	27900.00
0005434550482	255	Economy	27900.00
0005434723885	255	Economy	27900.00
0005434723912	255	Economy	27900.00
0005432277630	255	Economy	27900.00
0005434723917	255	Economy	27900.00
0005435142392	255	Economy	27900.00
0005434550529	255	Economy	27900.00
0005434550530	255	Economy	27900.00
0005434723864	255	Economy	27900.00
0005434550526	255	Economy	27900.00
0005434550498	255	Economy	27900.00
0005434723816	255	Economy	27900.00
0005434302400	255	Economy	27900.00
0005434723876	255	Economy	27900.00
0005434723821	255	Economy	27900.00
0005434550517	255	Economy	27900.00
0005434550515	255	Economy	27900.00
0005434731110	255	Economy	27900.00
0005435142398	255	Economy	27900.00
0005434723863	255	Economy	27900.00
0005434723844	255	Economy	27900.00
0005434723862	255	Economy	27900.00
0005434550485	255	Economy	27900.00
0005434723872	255	Economy	27900.00
0005434723867	255	Economy	27900.00
0005434723841	255	Economy	27900.00
0005434723829	255	Economy	27900.00
0005433233139	255	Economy	27900.00
0005434723897	255	Economy	27900.00
0005434723871	255	Economy	27900.00
0005434723856	255	Economy	27900.00
0005435142397	255	Economy	27900.00
0005434723834	255	Economy	27900.00
0005434723928	255	Economy	27900.00
0005434550535	255	Economy	27900.00
0005434723859	255	Economy	27900.00
0005434723827	255	Economy	27900.00
0005434723899	255	Economy	27900.00
0005434550503	255	Economy	27900.00
0005434550490	255	Economy	27900.00
0005434550483	255	Economy	27900.00
0005434735617	255	Economy	27900.00
0005434723850	255	Economy	27900.00
0005434723807	255	Economy	27900.00
0005434723906	255	Economy	27900.00
0005433233362	9834	Business	83700.00
0005432199153	9834	Business	83700.00
0005433233341	9834	Business	83700.00
0005433233399	9834	Business	83700.00
0005433180775	9834	Business	83700.00
0005432199154	9834	Business	83700.00
0005433180763	9834	Business	83700.00
0005433766591	9834	Business	83700.00
0005433233363	9834	Business	83700.00
0005433289749	9834	Comfort	47400.00
0005433233387	9834	Comfort	47400.00
0005433180757	9834	Comfort	47400.00
0005433233351	9834	Comfort	47400.00
0005433180774	9834	Comfort	47400.00
0005433180771	9834	Comfort	47400.00
0005433233358	9834	Comfort	47400.00
0005433180758	9834	Comfort	47400.00
0005433180754	9834	Comfort	47400.00
0005433233379	9834	Comfort	47400.00
0005433233385	9834	Comfort	47400.00
0005433289750	9834	Comfort	47400.00
0005433180761	9834	Comfort	47400.00
0005433233376	9834	Comfort	47400.00
0005434031964	9834	Comfort	47400.00
0005433233348	9834	Comfort	47400.00
0005434723346	9834	Comfort	47400.00
0005433180767	9834	Comfort	47400.00
0005433233400	9834	Comfort	47400.00
0005433180752	9834	Economy	27900.00
0005433233354	9834	Economy	27900.00
0005433233394	9834	Economy	27900.00
0005433233368	9834	Economy	27900.00
0005433233366	9834	Economy	27900.00
0005433126785	9834	Economy	27900.00
0005433233390	9834	Economy	27900.00
0005433233386	9834	Economy	27900.00
0005433180766	9834	Economy	27900.00
0005433233380	9834	Economy	27900.00
0005433233389	9834	Economy	27900.00
0005433233339	9834	Economy	27900.00
0005433233364	9834	Economy	27900.00
0005434550290	9834	Economy	27900.00
0005433233401	9834	Economy	27900.00
0005433233372	9834	Economy	27900.00
0005433180772	9834	Economy	27900.00
0005433129212	9834	Economy	27900.00
0005433126782	9834	Economy	27900.00
0005433766592	9834	Economy	27900.00
0005433180765	9834	Economy	30700.00
0005433233365	9834	Economy	30700.00
0005433129216	9834	Economy	27900.00
0005433233347	9834	Economy	30700.00
0005433129215	9834	Economy	27900.00
0005433233350	9834	Economy	27900.00
0005433233360	9834	Economy	27900.00
0005433233392	9834	Economy	27900.00
0005433233359	9834	Economy	27900.00
0005433180751	9834	Economy	27900.00
0005433233377	9834	Economy	27900.00
0005433233356	9834	Economy	27900.00
0005433233340	9834	Economy	27900.00
0005433233381	9834	Economy	27900.00
0005433233382	9834	Economy	27900.00
0005433233383	9834	Economy	27900.00
0005433233388	9834	Economy	27900.00
0005433126783	9834	Economy	27900.00
0005433180768	9834	Economy	27900.00
0005433129214	9834	Economy	27900.00
0005433233374	9834	Economy	27900.00
0005433766588	9834	Economy	27900.00
0005434031963	9834	Economy	27900.00
0005433233343	9834	Economy	27900.00
0005433180762	9834	Economy	27900.00
0005432199157	9834	Economy	27900.00
0005433233375	9834	Economy	27900.00
0005433129213	9834	Economy	27900.00
0005433233397	9834	Economy	27900.00
0005433233396	9834	Economy	27900.00
0005433233391	9834	Economy	27900.00
0005434031965	9834	Economy	27900.00
0005433180760	9834	Economy	27900.00
0005433233342	9834	Economy	27900.00
0005433289746	9834	Economy	27900.00
0005434031966	9834	Economy	27900.00
0005433233353	9834	Economy	27900.00
0005433233378	9834	Economy	27900.00
0005433180759	9834	Economy	27900.00
0005433766590	9834	Economy	30700.00
0005433289747	9834	Economy	30700.00
0005434723679	9834	Economy	30700.00
0005433233346	9834	Economy	30700.00
0005433233367	9834	Economy	30700.00
0005433233369	9834	Economy	27900.00
0005433233384	9834	Economy	27900.00
0005433233371	9834	Economy	27900.00
0005433233393	9834	Economy	27900.00
0005433233398	9834	Economy	27900.00
0005433233349	9834	Economy	27900.00
0005433233344	9834	Economy	27900.00
0005433180770	9834	Economy	27900.00
0005433180776	9834	Economy	27900.00
0005433180764	9834	Economy	27900.00
0005433233361	9834	Economy	27900.00
0005433289752	9834	Economy	27900.00
0005433766589	9834	Economy	27900.00
0005433233370	9834	Economy	27900.00
0005433289753	9834	Economy	27900.00
0005433233345	9834	Economy	27900.00
0005433233337	9834	Economy	27900.00
0005432199156	9834	Economy	27900.00
0005433233357	9834	Economy	27900.00
0005434550291	9834	Economy	27900.00
0005433180773	9834	Economy	27900.00
0005433289751	9834	Economy	27900.00
0005433180753	9834	Economy	27900.00
0005433180769	9834	Economy	27900.00
0005433233395	9834	Economy	27900.00
0005433180755	9834	Economy	27900.00
0005433233338	9834	Economy	27900.00
0005432199158	9834	Economy	27900.00
0005433233352	9834	Economy	27900.00
0005433289748	9834	Economy	27900.00
0005433129217	9834	Economy	27900.00
0005432199155	9834	Economy	27900.00
0005434031962	9834	Economy	27900.00
0005433126784	9834	Economy	27900.00
0005433180756	9834	Economy	27900.00
0005434723316	9834	Economy	27900.00
0005433233373	9834	Economy	27900.00
0005433126781	9834	Economy	27900.00
0005433233355	9834	Economy	27900.00
0005433113505	9834	Economy	27900.00
0005432150092	7719	Business	42100.00
0005432069468	7719	Business	42100.00
0005432526290	7719	Business	42100.00
0005434066610	7719	Business	42100.00
0005432526202	7719	Business	42100.00
0005432526277	7719	Business	42100.00
0005434066620	7719	Business	42100.00
0005432526275	7719	Business	42100.00
0005432526291	7719	Business	42100.00
0005432526196	7719	Business	42100.00
0005432069466	7719	Business	42100.00
0005432526257	7719	Business	42100.00
0005432069464	7719	Business	42100.00
0005432526236	7719	Business	42100.00
0005434066609	7719	Business	42100.00
0005434066590	7719	Business	42100.00
0005434066654	7719	Comfort	23900.00
0005432526281	7719	Comfort	23900.00
0005434066586	7719	Comfort	23900.00
0005432526183	7719	Comfort	23900.00
0005434066613	7719	Comfort	23900.00
0005434066623	7719	Comfort	23900.00
0005432526249	7719	Comfort	23900.00
0005432526267	7719	Comfort	23900.00
0005432526211	7719	Comfort	23900.00
0005432526174	7719	Comfort	23900.00
0005432428884	7719	Comfort	23900.00
0005432526223	7719	Comfort	23900.00
0005434066634	7719	Comfort	23900.00
0005432526283	7719	Comfort	23900.00
0005432526177	7719	Comfort	23900.00
0005432150086	7719	Comfort	23900.00
0005434066646	7719	Comfort	23900.00
0005432526232	7719	Comfort	23900.00
0005432069463	7719	Comfort	23900.00
0005432526214	7719	Comfort	23900.00
0005432526190	7719	Comfort	23900.00
0005434066632	7719	Comfort	23900.00
0005432526241	7719	Comfort	23900.00
0005434066637	7719	Comfort	23900.00
0005434066628	7719	Comfort	23900.00
0005434066655	7719	Comfort	23900.00
0005434066647	7719	Comfort	23900.00
0005434066603	7719	Economy	14000.00
0005432526198	7719	Economy	14000.00
0005434066625	7719	Economy	14000.00
0005432526296	7719	Economy	14000.00
0005432526271	7719	Economy	14000.00
0005432428883	7719	Economy	14000.00
0005434066635	7719	Economy	14000.00
0005432526259	7719	Economy	14000.00
0005434066636	7719	Economy	14000.00
0005432526293	7719	Economy	14000.00
0005432526303	7719	Economy	14000.00
0005432526215	7719	Economy	14000.00
0005434066622	7719	Economy	14000.00
0005432428881	7719	Economy	14000.00
0005432526282	7719	Economy	14000.00
0005432526297	7719	Economy	14000.00
0005432526204	7719	Economy	14000.00
0005432533254	7719	Economy	14000.00
0005432526298	7719	Economy	14000.00
0005432526213	7719	Economy	14000.00
0005432526184	7719	Economy	14000.00
0005434066599	7719	Economy	14000.00
0005432526205	7719	Economy	14000.00
0005432526234	7719	Economy	14000.00
0005432526253	7719	Economy	14000.00
0005432526170	7719	Economy	14000.00
0005432526258	7719	Economy	14000.00
0005432526302	7719	Economy	14000.00
0005434066649	7719	Economy	14000.00
0005434066596	7719	Economy	14000.00
0005434066600	7719	Economy	14000.00
0005432526188	7719	Economy	14000.00
0005432526212	7719	Economy	14000.00
0005432526262	7719	Economy	14000.00
0005432526270	7719	Economy	14000.00
0005432526264	7719	Economy	14000.00
0005432526178	7719	Economy	14000.00
0005432526284	7719	Economy	14000.00
0005432526235	7719	Economy	14000.00
0005434066587	7719	Economy	14000.00
0005432526248	7719	Economy	14000.00
0005432526220	7719	Economy	14000.00
0005434066629	7719	Economy	15400.00
0005432069461	7719	Economy	14000.00
0005434066657	7719	Economy	15400.00
0005434066591	7719	Economy	14000.00
0005432526288	7719	Economy	15400.00
0005432526286	7719	Economy	15400.00
0005432526192	7719	Economy	14000.00
0005432526247	7719	Economy	14000.00
0005432150088	7719	Economy	14000.00
0005432526217	7719	Economy	14000.00
0005432526219	7719	Economy	14000.00
0005432526254	7719	Economy	14000.00
0005432535766	7719	Economy	14000.00
0005432526292	7719	Economy	14000.00
0005434066619	7719	Economy	14000.00
0005432526289	7719	Economy	14000.00
0005432069454	7719	Economy	14000.00
0005432526278	7719	Economy	14000.00
0005432526221	7719	Economy	14000.00
0005434066650	7719	Economy	14000.00
0005432428882	7719	Economy	14000.00
0005432526244	7719	Economy	14000.00
0005434066611	7719	Economy	14000.00
0005434066585	7719	Economy	14000.00
0005434066615	7719	Economy	14000.00
0005432526300	7719	Economy	14000.00
0005432526251	7719	Economy	14000.00
0005434066644	7719	Economy	14000.00
0005432069455	7719	Economy	14000.00
0005432526268	7719	Economy	14000.00
0005432069460	7719	Economy	14000.00
0005434066608	7719	Economy	14000.00
0005434066614	7719	Economy	14000.00
0005432069467	7719	Economy	14000.00
0005432526179	7719	Economy	14000.00
0005432069457	7719	Economy	14000.00
0005432526252	7719	Economy	14000.00
0005434066612	7719	Economy	14000.00
0005432069456	7719	Economy	14000.00
0005432526208	7719	Economy	14000.00
0005432150090	7719	Economy	14000.00
0005434066601	7719	Economy	14000.00
0005434066642	7719	Economy	14000.00
0005432533253	7719	Economy	14000.00
0005432526237	7719	Economy	14000.00
0005432526180	7719	Economy	14000.00
0005432526238	7719	Economy	14000.00
0005435212365	7719	Economy	14000.00
0005434066598	7719	Economy	14000.00
0005432069459	7719	Economy	14000.00
0005432526239	7719	Economy	14000.00
0005434066604	7719	Economy	14000.00
0005434066617	7719	Economy	14000.00
0005432150093	7719	Economy	14000.00
0005432526266	7719	Economy	14000.00
0005432526229	7719	Economy	14000.00
0005432526227	7719	Economy	14000.00
0005432526181	7719	Economy	14000.00
0005434066595	7719	Economy	14000.00
0005434066588	7719	Economy	14000.00
0005432526191	7719	Economy	14000.00
0005432537028	7719	Economy	14000.00
0005432526285	7719	Economy	14000.00
0005432526228	7719	Economy	14000.00
0005432526256	7719	Economy	14000.00
0005434066648	7719	Economy	14000.00
0005434066626	7719	Economy	14000.00
0005432526276	7719	Economy	14000.00
0005432526299	7719	Economy	14000.00
0005434066631	7719	Economy	14000.00
0005434066593	7719	Economy	14000.00
0005432526250	7719	Economy	14000.00
0005432069465	7719	Economy	14000.00
0005432526304	7719	Economy	14000.00
0005432526230	7719	Economy	14000.00
0005432526272	7719	Economy	14000.00
0005434066592	7719	Economy	14000.00
0005434066597	7719	Economy	14000.00
0005434066638	7719	Economy	14000.00
0005434066589	7719	Economy	14000.00
0005432526295	7719	Economy	14000.00
0005432526189	7719	Economy	14000.00
0005432526193	7719	Economy	14000.00
0005432526246	7719	Economy	14000.00
0005434066616	7719	Economy	14000.00
0005432526255	7719	Economy	14000.00
0005432526185	7719	Economy	14000.00
0005432526242	7719	Economy	15400.00
0005432526222	7719	Economy	15400.00
0005432526226	7719	Economy	15400.00
0005434066624	7719	Economy	15400.00
0005432069462	7719	Economy	14000.00
0005434066618	7719	Economy	14000.00
0005432526216	7719	Economy	14000.00
0005432535769	7719	Economy	14000.00
0005432526263	7719	Economy	14000.00
0005432526218	7719	Economy	14000.00
0005432526186	7719	Economy	14000.00
0005432537029	7719	Economy	14000.00
0005432526279	7719	Economy	14000.00
0005432526201	7719	Economy	14000.00
0005432535768	7719	Economy	14000.00
0005432526194	7719	Economy	14000.00
0005432526195	7719	Economy	14000.00
0005432526224	7719	Economy	14000.00
0005432526245	7719	Economy	14000.00
0005434066641	7719	Economy	14000.00
0005432526273	7719	Economy	14000.00
0005432526203	7719	Economy	14000.00
0005432526187	7719	Economy	14000.00
0005434066627	7719	Economy	14000.00
0005432526200	7719	Economy	14000.00
0005432069458	7719	Economy	14000.00
0005434066605	7719	Economy	14000.00
0005434066621	7719	Economy	14000.00
0005432526265	7719	Economy	14000.00
0005432526176	7719	Economy	14000.00
0005432533252	7719	Economy	14000.00
0005432526182	7719	Economy	14000.00
0005434066653	7719	Economy	14000.00
0005434066652	7719	Economy	14000.00
0005432526243	7719	Economy	14000.00
0005434066639	7719	Economy	14000.00
0005432526210	7719	Economy	14000.00
0005432526280	7719	Economy	14000.00
0005432526197	7719	Economy	14000.00
0005435725512	7719	Economy	14000.00
0005434066630	7719	Economy	14000.00
0005432535767	7719	Economy	14000.00
0005432526301	7719	Economy	14000.00
0005432526172	7719	Economy	14000.00
0005432150091	7719	Economy	14000.00
0005434066633	7719	Economy	14000.00
0005432526175	7719	Economy	14000.00
0005432526240	7719	Economy	14000.00
0005432526173	7719	Economy	14000.00
0005434066656	7719	Economy	14000.00
0005434066640	7719	Economy	14000.00
0005432526199	7719	Economy	14000.00
0005432150089	7719	Economy	14000.00
0005432526287	7719	Economy	14000.00
0005432526231	7719	Economy	14000.00
0005432526261	7719	Economy	14000.00
0005434066607	7719	Economy	14000.00
0005432526171	7719	Economy	14000.00
0005432526260	7719	Economy	14000.00
0005432526209	7719	Economy	14000.00
0005434066602	7719	Economy	14000.00
0005432526207	7719	Economy	14000.00
0005432526225	7719	Economy	14000.00
0005432526274	7719	Economy	14000.00
0005434066645	7719	Economy	14000.00
0005432526233	7719	Economy	14000.00
0005432526206	7719	Economy	14000.00
0005434066651	7719	Economy	14000.00
0005434066594	7719	Economy	14000.00
0005434066643	7719	Economy	14000.00
0005432150087	7719	Economy	14000.00
0005432526294	7719	Economy	14000.00
0005432526269	7719	Economy	14000.00
0005434066606	7719	Economy	14000.00
0005434244458	5309	Business	43100.00
0005434573162	5309	Business	43100.00
0005434343746	5309	Business	43100.00
0005435490182	5309	Business	43100.00
0005434343753	5309	Business	43100.00
0005435612234	5309	Business	43100.00
0005435612162	5309	Business	43100.00
0005434573160	5309	Business	43100.00
0005435612236	5309	Business	43100.00
0005435612106	5309	Business	43100.00
0005435612230	5309	Business	43100.00
0005434343737	5309	Business	43100.00
0005435612195	5309	Business	43100.00
0005435423616	5309	Business	43100.00
0005434343742	5309	Business	43100.00
0005432133007	5309	Business	43100.00
0005435612130	5309	Business	43100.00
0005435612123	5309	Business	43100.00
0005435612214	5309	Business	43100.00
0005435612210	5309	Comfort	24400.00
0005435612204	5309	Comfort	24400.00
0005435612142	5309	Comfort	24400.00
0005435612175	5309	Comfort	24400.00
0005435612136	5309	Comfort	24400.00
0005435612129	5309	Comfort	24400.00
0005434343726	5309	Comfort	24400.00
0005435612177	5309	Comfort	24400.00
0005435617167	5309	Comfort	24400.00
0005432047500	5309	Comfort	24400.00
0005435491413	5309	Comfort	24400.00
0005435612182	5309	Comfort	24400.00
0005435490181	5309	Comfort	24400.00
0005435612189	5309	Comfort	24400.00
0005435612187	5309	Comfort	24400.00
0005432133008	5309	Comfort	24400.00
0005435612232	5309	Comfort	24400.00
0005435612235	5309	Comfort	24400.00
0005435612224	5309	Comfort	24400.00
0005434343750	5309	Comfort	24400.00
0005434343739	5309	Comfort	24400.00
0005435612178	5309	Comfort	24400.00
0005435612205	5309	Comfort	24400.00
0005435612228	5309	Comfort	24400.00
0005434343755	5309	Comfort	24400.00
0005435612180	5309	Comfort	24400.00
0005435612110	5309	Comfort	24400.00
0005434343744	5309	Economy	14400.00
0005435612223	5309	Economy	14400.00
0005434343757	5309	Economy	14400.00
0005432133015	5309	Economy	14400.00
0005434573165	5309	Economy	14400.00
0005435612146	5309	Economy	14400.00
0005435612183	5309	Economy	14400.00
0005435612220	5309	Economy	14400.00
0005435612186	5309	Economy	14400.00
0005435612115	5309	Economy	14400.00
0005435612151	5309	Economy	14400.00
0005432133009	5309	Economy	14400.00
0005435612233	5309	Economy	14400.00
0005435097079	5309	Economy	14400.00
0005435612179	5309	Economy	14400.00
0005432133011	5309	Economy	14400.00
0005435612145	5309	Economy	14400.00
0005435612169	5309	Economy	14400.00
0005434343738	5309	Economy	14400.00
0005434343734	5309	Economy	14400.00
0005432133012	5309	Economy	14400.00
0005435612199	5309	Economy	14400.00
0005435423630	5309	Economy	14400.00
0005435612113	5309	Economy	14400.00
0005432133006	5309	Economy	14400.00
0005432133013	5309	Economy	14400.00
0005435612172	5309	Economy	14400.00
0005435612133	5309	Economy	14400.00
0005434343756	5309	Economy	14400.00
0005435612212	5309	Economy	14400.00
0005435612121	5309	Economy	14400.00
0005434343727	5309	Economy	14400.00
0005435612139	5309	Economy	14400.00
0005434343735	5309	Economy	14400.00
0005435612203	5309	Economy	14400.00
0005435612198	5309	Economy	14400.00
0005435612171	5309	Economy	14400.00
0005435612174	5309	Economy	14400.00
0005435612227	5309	Economy	15800.00
0005435612143	5309	Economy	15800.00
0005434244460	5309	Economy	14400.00
0005435612201	5309	Economy	15800.00
0005435612240	5309	Economy	14400.00
0005435612152	5309	Economy	14400.00
0005435612148	5309	Economy	15800.00
0005435612200	5309	Economy	14400.00
0005435612197	5309	Economy	14400.00
0005435612166	5309	Economy	14400.00
0005435612188	5309	Economy	14400.00
0005435612208	5309	Economy	14400.00
0005432133005	5309	Economy	14400.00
0005435612190	5309	Economy	14400.00
0005434343758	5309	Economy	14400.00
0005434573168	5309	Economy	14400.00
0005435612202	5309	Economy	14400.00
0005434343760	5309	Economy	14400.00
0005434343745	5309	Economy	14400.00
0005435612138	5309	Economy	14400.00
0005435612173	5309	Economy	14400.00
0005435612160	5309	Economy	14400.00
0005435612137	5309	Economy	14400.00
0005435423593	5309	Economy	14400.00
0005432047501	5309	Economy	14400.00
0005435612191	5309	Economy	14400.00
0005435612108	5309	Economy	14400.00
0005434573170	5309	Economy	14400.00
0005434343729	5309	Economy	14400.00
0005435612226	5309	Economy	14400.00
0005435612196	5309	Economy	14400.00
0005434343740	5309	Economy	14400.00
0005434244461	5309	Economy	14400.00
0005432133016	5309	Economy	14400.00
0005434343730	5309	Economy	14400.00
0005435097083	5309	Economy	14400.00
0005435612217	5309	Economy	14400.00
0005435612163	5309	Economy	14400.00
0005435612147	5309	Economy	14400.00
0005435097081	5309	Economy	14400.00
0005435612225	5309	Economy	14400.00
0005435490183	5309	Economy	14400.00
0005435612209	5309	Economy	14400.00
0005434343732	5309	Economy	14400.00
0005435612132	5309	Economy	14400.00
0005434343752	5309	Economy	14400.00
0005432133017	5309	Economy	14400.00
0005435612117	5309	Economy	14400.00
0005435612111	5309	Economy	14400.00
0005435612213	5309	Economy	14400.00
0005435612193	5309	Economy	14400.00
0005435612150	5309	Economy	14400.00
0005435612144	5309	Economy	14400.00
0005435612161	5309	Economy	14400.00
0005435612194	5309	Economy	14400.00
0005432133014	5309	Economy	14400.00
0005434573159	5309	Economy	14400.00
0005435612149	5309	Economy	14400.00
0005435612181	5309	Economy	14400.00
0005435612239	5309	Economy	14400.00
0005435612134	5309	Economy	14400.00
0005435097087	5309	Economy	14400.00
0005435612109	5309	Economy	14400.00
0005435617168	5309	Economy	14400.00
0005435612131	5309	Economy	14400.00
0005435612218	5309	Economy	14400.00
0005435612125	5309	Economy	14400.00
0005435612124	5309	Economy	14400.00
0005435612135	5309	Economy	14400.00
0005435612221	5309	Economy	14400.00
0005434343743	5309	Economy	14400.00
0005434343749	5309	Economy	14400.00
0005435612126	5309	Economy	14400.00
0005435612211	5309	Economy	14400.00
0005434343741	5309	Economy	15800.00
0005435491414	5309	Economy	15800.00
0005434343751	5309	Economy	15800.00
0005434343733	5309	Economy	15800.00
0005435612119	5309	Economy	15800.00
0005435612141	5309	Economy	14400.00
0005435097085	5309	Economy	15800.00
0005435097084	5309	Economy	14400.00
0005435612231	5309	Economy	14400.00
0005435612159	5309	Economy	14400.00
0005435612241	5309	Economy	14400.00
0005435612168	5309	Economy	14400.00
0005435612237	5309	Economy	14400.00
0005435612176	5309	Economy	14400.00
0005434573161	5309	Economy	14400.00
0005435612238	5309	Economy	14400.00
0005434573163	5309	Economy	14400.00
0005432133004	5309	Economy	14400.00
0005434343748	5309	Economy	14400.00
0005434343747	5309	Economy	14400.00
0005435612167	5309	Economy	14400.00
0005435097082	5309	Economy	14400.00
0005434343725	5309	Economy	14400.00
0005435612222	5309	Economy	14400.00
0005435612112	5309	Economy	14400.00
0005435612107	5309	Economy	14400.00
0005435612164	5309	Economy	14400.00
0005434573167	5309	Economy	14400.00
0005435612128	5309	Economy	14400.00
0005434343759	5309	Economy	14400.00
0005435612114	5309	Economy	14400.00
0005435612156	5309	Economy	14400.00
0005435612127	5309	Economy	14400.00
0005435612154	5309	Economy	14400.00
0005435612140	5309	Economy	14400.00
0005435097086	5309	Economy	14400.00
0005435612118	5309	Economy	14400.00
0005435612155	5309	Economy	14400.00
0005434573171	5309	Economy	14400.00
0005434343728	5309	Economy	14400.00
0005434573166	5309	Economy	14400.00
0005435612157	5309	Economy	14400.00
0005435612229	5309	Economy	14400.00
0005434573172	5309	Economy	14400.00
0005434573164	5309	Economy	14400.00
0005432047498	5309	Economy	14400.00
0005435612120	5309	Economy	14400.00
0005435612165	5309	Economy	14400.00
0005434343736	5309	Economy	14400.00
0005432047499	5309	Economy	14400.00
0005434343754	5309	Economy	14400.00
0005432133010	5309	Economy	14400.00
0005435617166	5309	Economy	14400.00
0005435612170	5309	Economy	14400.00
0005434573169	5309	Economy	14400.00
0005435612158	5309	Economy	14400.00
0005435612185	5309	Economy	14400.00
0005435612207	5309	Economy	14400.00
0005434244457	5309	Economy	14400.00
0005435612219	5309	Economy	14400.00
0005435612116	5309	Economy	14400.00
0005435612184	5309	Economy	14400.00
0005435097080	5309	Economy	14400.00
0005435612192	5309	Economy	14400.00
0005435612216	5309	Economy	14400.00
0005435612122	5309	Economy	14400.00
0005435612215	5309	Economy	14400.00
0005435612153	5309	Economy	14400.00
0005434343731	5309	Economy	14400.00
0005435555341	5309	Economy	14400.00
0005435612206	5309	Economy	14400.00
0005434244578	10901	Business	43100.00
0005435423907	10901	Business	43100.00
0005435380232	10901	Business	43100.00
0005435319457	10901	Business	43100.00
0005435042830	10901	Business	43100.00
0005435319454	10901	Business	43100.00
0005434244575	10901	Business	43100.00
0005435423887	10901	Business	43100.00
0005435423916	10901	Business	43100.00
0005435423867	10901	Business	43100.00
0005435319458	10901	Business	43100.00
0005435423895	10901	Business	43100.00
0005435423927	10901	Comfort	24400.00
0005434244583	10901	Comfort	24400.00
0005434244576	10901	Comfort	24400.00
0005434244602	10901	Comfort	24400.00
0005435423901	10901	Comfort	24400.00
0005435423921	10901	Comfort	24400.00
0005435423894	10901	Comfort	24400.00
0005435042827	10901	Comfort	24400.00
0005435423892	10901	Comfort	24400.00
0005435423924	10901	Comfort	24400.00
0005435423922	10901	Comfort	24400.00
0005435304106	10901	Comfort	24400.00
0005435423879	10901	Comfort	24400.00
0005434244579	10901	Comfort	24400.00
0005435423886	10901	Comfort	24400.00
0005433719094	10901	Economy	14400.00
0005435423913	10901	Economy	14400.00
0005435423889	10901	Economy	14400.00
0005434244574	10901	Economy	14400.00
0005435423917	10901	Economy	14400.00
0005435423888	10901	Economy	14400.00
0005435304108	10901	Economy	14400.00
0005432164935	10901	Economy	14400.00
0005435423869	10901	Economy	14400.00
0005434244597	10901	Economy	14400.00
0005435319453	10901	Economy	14400.00
0005435304995	10901	Economy	14400.00
0005435319452	10901	Economy	14400.00
0005434656528	10901	Economy	14400.00
0005435380230	10901	Economy	14400.00
0005434244582	10901	Economy	14400.00
0005435423926	10901	Economy	14400.00
0005435380234	10901	Economy	14400.00
0005435423905	10901	Economy	14400.00
0005435423909	10901	Economy	14400.00
0005435423893	10901	Economy	14400.00
0005435423859	10901	Economy	14400.00
0005432164938	10901	Economy	14400.00
0005435423873	10901	Economy	14400.00
0005435423919	10901	Economy	14400.00
0005435423896	10901	Economy	14400.00
0005434244598	10901	Economy	14400.00
0005435423885	10901	Economy	14400.00
0005435042829	10901	Economy	14400.00
0005435319459	10901	Economy	14400.00
0005435423881	10901	Economy	14400.00
0005435423925	10901	Economy	14400.00
0005435423866	10901	Economy	14400.00
0005435380231	10901	Economy	15800.00
0005432164939	10901	Economy	14400.00
0005434244595	10901	Economy	14400.00
0005434244596	10901	Economy	14400.00
0005435423862	10901	Economy	14400.00
0005435423878	10901	Economy	14400.00
0005434244600	10901	Economy	14400.00
0005435423906	10901	Economy	14400.00
0005435423883	10901	Economy	14400.00
0005435423899	10901	Economy	14400.00
0005434244573	10901	Economy	14400.00
0005435319456	10901	Economy	14400.00
0005434244594	10901	Economy	14400.00
0005434244591	10901	Economy	14400.00
0005435423863	10901	Economy	14400.00
0005432363373	10901	Economy	14400.00
0005435042826	10901	Economy	14400.00
0005432164932	10901	Economy	14400.00
0005435423897	10901	Economy	14400.00
0005435423882	10901	Economy	14400.00
0005435423898	10901	Economy	14400.00
0005435423911	10901	Economy	14400.00
0005435423865	10901	Economy	14400.00
0005434244603	10901	Economy	14400.00
0005432166857	10901	Economy	14400.00
0005435380233	10901	Economy	14400.00
0005432840986	10901	Economy	14400.00
0005434244581	10901	Economy	14400.00
0005433719095	10901	Economy	14400.00
0005435423910	10901	Economy	14400.00
0005435423891	10901	Economy	14400.00
0005434244587	10901	Economy	14400.00
0005435380229	10901	Economy	14400.00
0005434244585	10901	Economy	14400.00
0005435042828	10901	Economy	14400.00
0005432166856	10901	Economy	14400.00
0005435423875	10901	Economy	14400.00
0005434244601	10901	Economy	14400.00
0005435423903	10901	Economy	14400.00
0005432840985	10901	Economy	14400.00
0005435319451	10901	Economy	14400.00
0005435423868	10901	Economy	14400.00
0005434244590	10901	Economy	14400.00
0005432166859	10901	Economy	15800.00
0005432164934	10901	Economy	15800.00
0005432164933	10901	Economy	15800.00
0005434656529	10901	Economy	14400.00
0005432164936	10901	Economy	14400.00
0005435304997	10901	Economy	14400.00
0005435423884	10901	Economy	14400.00
0005435423860	10901	Economy	14400.00
0005435319450	10901	Economy	14400.00
0005434244577	10901	Economy	14400.00
0005435423902	10901	Economy	14400.00
0005435423912	10901	Economy	14400.00
0005435423914	10901	Economy	14400.00
0005432363372	10901	Economy	14400.00
0005434244593	10901	Economy	14400.00
0005435380228	10901	Economy	14400.00
0005435423874	10901	Economy	14400.00
0005435423861	10901	Economy	14400.00
0005434244589	10901	Economy	14400.00
0005435423918	10901	Economy	14400.00
0005434244588	10901	Economy	14400.00
0005434244592	10901	Economy	14400.00
0005434244599	10901	Economy	14400.00
0005435423880	10901	Economy	14400.00
0005435304104	10901	Economy	14400.00
0005433719097	10901	Economy	14400.00
0005435304107	10901	Economy	14400.00
0005435423871	10901	Economy	14400.00
0005435319455	10901	Economy	14400.00
0005435423858	10901	Economy	14400.00
0005435423900	10901	Economy	14400.00
0005435423864	10901	Economy	14400.00
0005434244584	10901	Economy	14400.00
0005435423890	10901	Economy	14400.00
0005435304105	10901	Economy	14400.00
0005432166858	10901	Economy	14400.00
0005432164937	10901	Economy	14400.00
0005435423876	10901	Economy	14400.00
0005435423908	10901	Economy	14400.00
0005433719096	10901	Economy	14400.00
0005434244580	10901	Economy	14400.00
0005435423923	10901	Economy	14400.00
0005434244586	10901	Economy	14400.00
0005435423870	10901	Economy	14400.00
0005435423877	10901	Economy	14400.00
0005435423904	10901	Economy	14400.00
0005435423915	10901	Economy	14400.00
0005435304996	10901	Economy	14400.00
0005435423920	10901	Economy	14400.00
0005435423872	10901	Economy	14400.00
0005432181426	3282	Business	18800.00
0005433506936	3282	Business	18800.00
0005432181423	3282	Business	18800.00
0005433506941	3282	Business	18800.00
0005432181425	3282	Business	18800.00
0005433804926	3282	Business	18800.00
0005433804909	3282	Business	18800.00
0005433804902	3282	Business	18800.00
0005433633369	3282	Business	18800.00
0005433804916	3282	Business	18800.00
0005432181413	3282	Business	18800.00
0005433633364	3282	Business	18800.00
0005434143703	3282	Business	18800.00
0005433804919	3282	Business	18800.00
0005433804910	3282	Business	18800.00
0005432181415	3282	Business	18800.00
0005433633378	3282	Business	18800.00
0005432181430	3282	Business	18800.00
0005433804895	3282	Business	18800.00
0005433804925	3282	Business	18800.00
0005432181412	3282	Business	18800.00
0005433633384	3282	Economy	6900.00
0005433804924	3282	Economy	6900.00
0005434143701	3282	Economy	6900.00
0005432181414	3282	Economy	6900.00
0005433506935	3282	Economy	6300.00
0005433633383	3282	Economy	6300.00
0005434143705	3282	Economy	6300.00
0005433506940	3282	Economy	6300.00
0005433506939	3282	Economy	6300.00
0005433804893	3282	Economy	6300.00
0005434143698	3282	Economy	6300.00
0005433506938	3282	Economy	6300.00
0005433633361	3282	Economy	6300.00
0005434143699	3282	Economy	6300.00
0005432181421	3282	Economy	6300.00
0005433804912	3282	Economy	6300.00
0005433804908	3282	Economy	6300.00
0005432181416	3282	Economy	6300.00
0005433804921	3282	Economy	6300.00
0005432181417	3282	Economy	6300.00
0005433506932	3282	Economy	6300.00
0005433506943	3282	Economy	6300.00
0005433804901	3282	Economy	6300.00
0005433804927	3282	Economy	6300.00
0005433804913	3282	Economy	6300.00
0005433804907	3282	Economy	6300.00
0005433804922	3282	Economy	6300.00
0005432181429	3282	Economy	6300.00
0005434143700	3282	Economy	6300.00
0005433633385	3282	Economy	6300.00
0005433804906	3282	Economy	6300.00
0005433804923	3282	Economy	6300.00
0005433804930	3282	Economy	6300.00
0005432181428	3282	Economy	6300.00
0005433633367	3282	Economy	6300.00
0005433633366	3282	Economy	6300.00
0005433506931	3282	Economy	6300.00
0005433804898	3282	Economy	6300.00
0005433804900	3282	Economy	6300.00
0005433633363	3282	Economy	6300.00
0005433804911	3282	Economy	6300.00
0005433506933	3282	Economy	6300.00
0005433633355	3282	Economy	6300.00
0005433633375	3282	Economy	6300.00
0005433804929	3282	Economy	6300.00
0005433633379	3282	Economy	6300.00
0005432181411	3282	Economy	6300.00
0005433804914	3282	Economy	6300.00
0005433804899	3282	Economy	6900.00
0005433804903	3282	Economy	6900.00
0005433633372	3282	Economy	6900.00
0005433633374	3282	Economy	6900.00
0005432181424	3282	Economy	6300.00
0005433804894	3282	Economy	6300.00
0005433633370	3282	Economy	6300.00
0005433804920	3282	Economy	6900.00
0005433804896	3282	Economy	6300.00
0005433804897	3282	Economy	6300.00
0005433633360	3282	Economy	6300.00
0005433804904	3282	Economy	6300.00
0005433633376	3282	Economy	6300.00
0005433506942	3282	Economy	6300.00
0005433633362	3282	Economy	6300.00
0005433633356	3282	Economy	6300.00
0005433633380	3282	Economy	6300.00
0005432181419	3282	Economy	6300.00
0005433506934	3282	Economy	6300.00
0005433633358	3282	Economy	6300.00
0005433633387	3282	Economy	6300.00
0005432181427	3282	Economy	6300.00
0005434143702	3282	Economy	6300.00
0005433633386	3282	Economy	6300.00
0005433506930	3282	Economy	6300.00
0005433804932	3282	Economy	6300.00
0005433804917	3282	Economy	6300.00
0005433804933	3282	Economy	6300.00
0005432181422	3282	Economy	6300.00
0005433633371	3282	Economy	6300.00
0005433633368	3282	Economy	6300.00
0005432181420	3282	Economy	6300.00
0005433804928	3282	Economy	6300.00
0005433804905	3282	Economy	6300.00
0005433506937	3282	Economy	6300.00
0005433633382	3282	Economy	6300.00
0005432181410	3282	Economy	6300.00
0005432181418	3282	Economy	6300.00
0005433804931	3282	Economy	6300.00
0005433633381	3282	Economy	6300.00
0005433633359	3282	Economy	6300.00
0005432181431	3282	Economy	6300.00
0005433804918	3282	Economy	6300.00
0005433633373	3282	Economy	6300.00
0005433633377	3282	Economy	6300.00
0005433804915	3282	Economy	6300.00
0005433633365	3282	Economy	6300.00
0005434143704	3282	Economy	6300.00
0005433633357	3282	Economy	6300.00
0005435884507	3283	Economy	6900.00
0005435884427	3283	Economy	6300.00
0005435884506	3283	Economy	6300.00
0005435884505	3283	Economy	6300.00
0005435884583	8184	Business	18800.00
0005432042531	8184	Business	18800.00
0005432459177	8184	Business	18800.00
0005435884605	8184	Business	18800.00
0005432042532	8184	Business	18800.00
0005432042534	8184	Business	18800.00
0005435884611	8184	Business	18800.00
0005432459218	8184	Business	18800.00
0005435884601	8184	Business	18800.00
0005435884613	8184	Business	18800.00
0005432459186	8184	Business	18800.00
0005432042526	8184	Business	18800.00
0005432459222	8184	Business	18800.00
0005435884618	8184	Business	18800.00
0005435884615	8184	Business	18800.00
0005434326261	8184	Business	18800.00
0005432459187	8184	Business	18800.00
0005435884599	8184	Business	18800.00
0005432459211	8184	Economy	6900.00
0005432459188	8184	Economy	6900.00
0005432459178	8184	Economy	6300.00
0005432459212	8184	Economy	6900.00
0005432042527	8184	Economy	6300.00
0005432459195	8184	Economy	6300.00
0005435884606	8184	Economy	6300.00
0005432042528	8184	Economy	6300.00
0005435884602	8184	Economy	6300.00
0005432459217	8184	Economy	6300.00
0005432459221	8184	Economy	6300.00
0005435884621	8184	Economy	6300.00
0005432459219	8184	Economy	6300.00
0005432459200	8184	Economy	6300.00
0005435884579	8184	Economy	6300.00
0005435884582	8184	Economy	6300.00
0005432459171	8184	Economy	6300.00
0005435884600	8184	Economy	6300.00
0005432042529	8184	Economy	6300.00
0005432459174	8184	Economy	6300.00
0005432459216	8184	Economy	6300.00
0005435884586	8184	Economy	6300.00
0005432459204	8184	Economy	6300.00
0005432459210	8184	Economy	6300.00
0005435884589	8184	Economy	6300.00
0005435884584	8184	Economy	6300.00
0005432459214	8184	Economy	6300.00
0005432459172	8184	Economy	6300.00
0005435884581	8184	Economy	6300.00
0005432459199	8184	Economy	6300.00
0005432459213	8184	Economy	6300.00
0005435884619	8184	Economy	6300.00
0005435884608	8184	Economy	6300.00
0005432042525	8184	Economy	6300.00
0005432042530	8184	Economy	6300.00
0005432042537	8184	Economy	6300.00
0005432459197	8184	Economy	6300.00
0005432459183	8184	Economy	6300.00
0005432042533	8184	Economy	6300.00
0005435884620	8184	Economy	6300.00
0005435884595	8184	Economy	6900.00
0005432459184	8184	Economy	6900.00
0005432459203	8184	Economy	6900.00
0005432459198	8184	Economy	6300.00
0005435884603	8184	Economy	6900.00
0005432459196	8184	Economy	6300.00
0005432042536	8184	Economy	6300.00
0005432459220	8184	Economy	6300.00
0005432459193	8184	Economy	6300.00
0005434312292	8184	Economy	6300.00
0005432459189	8184	Economy	6300.00
0005432459205	8184	Economy	6300.00
0005432459215	8184	Economy	6300.00
0005432459208	8184	Economy	6300.00
0005432459175	8184	Economy	6300.00
0005432459179	8184	Economy	6300.00
0005435884612	8184	Economy	6300.00
0005435884614	8184	Economy	6300.00
0005432459191	8184	Economy	6300.00
0005435884596	8184	Economy	6300.00
0005435884593	8184	Economy	6300.00
0005432459185	8184	Economy	6300.00
0005435884592	8184	Economy	6300.00
0005432459202	8184	Economy	6300.00
0005435884580	8184	Economy	6300.00
0005435884607	8184	Economy	6300.00
0005432042535	8184	Economy	6300.00
0005432459201	8184	Economy	6300.00
0005435884617	8184	Economy	6300.00
0005435884591	8184	Economy	6300.00
0005435884610	8184	Economy	6300.00
0005432459194	8184	Economy	6300.00
0005432459176	8184	Economy	6300.00
0005435884609	8184	Economy	6300.00
0005432459173	8184	Economy	6300.00
0005435884594	8184	Economy	6300.00
0005435884604	8184	Economy	6300.00
0005435884616	8184	Economy	6300.00
0005435884585	8184	Economy	6300.00
0005432459209	8184	Economy	6300.00
0005432459190	8184	Economy	6300.00
0005435884587	8184	Economy	6300.00
0005432459206	8184	Economy	6300.00
0005432459207	8184	Economy	6300.00
0005434312293	8184	Economy	6300.00
0005432459182	8184	Economy	6300.00
0005435884597	8184	Economy	6300.00
0005435884598	8184	Economy	6300.00
0005435884588	8184	Economy	6300.00
0005432459180	8184	Economy	6300.00
0005432459192	8184	Economy	6300.00
0005435884590	8184	Economy	6300.00
0005432459181	8184	Economy	6300.00
0005435854042	8183	Economy	6900.00
0005435854041	8183	Economy	6300.00
0005435854043	8183	Economy	6300.00
0005435854044	8183	Economy	6300.00
0005434183544	8338	Economy	6300.00
0005432382662	4565	Business	9900.00
0005432382663	4565	Business	9900.00
0005432382661	4565	Business	9900.00
0005432382676	4565	Business	9900.00
0005432727772	4565	Business	9900.00
0005432382668	4565	Business	9900.00
0005432382664	4565	Business	9900.00
0005432727778	4565	Economy	3300.00
0005432382683	4565	Economy	3300.00
0005432382651	4565	Economy	3300.00
0005432382652	4565	Economy	3300.00
0005432727777	4565	Economy	3600.00
0005432727773	4565	Economy	3600.00
0005432382660	4565	Economy	3600.00
0005433453735	4565	Economy	3600.00
0005432382684	4565	Economy	3300.00
0005432382656	4565	Economy	3300.00
0005432382679	4565	Economy	3300.00
0005432382674	4565	Economy	3300.00
0005432382655	4565	Economy	3300.00
0005432382659	4565	Economy	3300.00
0005432382665	4565	Economy	3300.00
0005432727776	4565	Economy	3300.00
0005432382681	4565	Economy	3300.00
0005432382667	4565	Economy	3300.00
0005432727770	4565	Economy	3300.00
0005432382649	4565	Economy	3300.00
0005432727769	4565	Economy	3300.00
0005432382682	4565	Economy	3300.00
0005432382672	4565	Economy	3300.00
0005432727768	4565	Economy	3300.00
0005433722129	4565	Economy	3300.00
0005432382658	4565	Economy	3300.00
0005432727771	4565	Economy	3300.00
0005432382669	4565	Economy	3300.00
0005433454847	4565	Economy	3300.00
0005432727775	4565	Economy	3300.00
0005432382677	4565	Economy	3300.00
0005432382678	4565	Economy	3300.00
0005433722131	4565	Economy	3300.00
0005433453736	4565	Economy	3300.00
0005432382687	4565	Economy	3300.00
0005433194825	4565	Economy	3300.00
0005432382657	4565	Economy	3300.00
0005433722130	4565	Economy	3300.00
0005433194824	4565	Economy	3300.00
0005432382685	4565	Economy	3300.00
0005432727767	4565	Economy	3300.00
0005432382673	4565	Economy	3300.00
0005432382653	4565	Economy	3300.00
0005432382675	4565	Economy	3300.00
0005432382690	4565	Economy	3300.00
0005432727774	4565	Economy	3300.00
0005432382650	4565	Economy	3300.00
0005432727779	4565	Economy	3300.00
0005433722128	4565	Economy	3300.00
0005432382671	4565	Economy	3300.00
0005432382654	4565	Economy	3300.00
0005432382686	4565	Economy	3300.00
0005432382689	4565	Economy	3300.00
0005432382666	4565	Economy	3300.00
0005432382670	4565	Economy	3300.00
0005432382688	4565	Economy	3300.00
0005432382680	4565	Economy	3300.00
0005432727718	30262	Business	9900.00
0005432727738	30262	Economy	3300.00
0005433516763	1750	Business	57200.00
0005433516767	1750	Business	57200.00
0005435540726	1750	Business	57200.00
0005435528977	1750	Business	57200.00
0005435528970	1750	Business	57200.00
0005435528973	1750	Business	57200.00
0005435528987	1750	Business	57200.00
0005432924951	1750	Business	57200.00
0005433516762	1750	Business	57200.00
0005433516761	1750	Business	57200.00
0005435540730	1750	Economy	19100.00
0005435540723	1750	Economy	19100.00
0005435528978	1750	Economy	19100.00
0005435540725	1750	Economy	19100.00
0005435540728	1750	Economy	21000.00
0005435540711	1750	Economy	21000.00
0005435528974	1750	Economy	21000.00
0005435528988	1750	Economy	21000.00
0005435540717	1750	Economy	19100.00
0005432924952	1750	Economy	19100.00
0005435528981	1750	Economy	19100.00
0005435528982	1750	Economy	19100.00
0005435528975	1750	Economy	19100.00
0005435528968	1750	Economy	19100.00
0005435528972	1750	Economy	19100.00
0005433516765	1750	Economy	19100.00
0005435528985	1750	Economy	19100.00
0005435528967	1750	Economy	19100.00
0005435528986	1750	Economy	19100.00
0005435540714	1750	Economy	19100.00
0005435528979	1750	Economy	19100.00
0005435540715	1750	Economy	19100.00
0005435540724	1750	Economy	19100.00
0005435540720	1750	Economy	19100.00
0005435540719	1750	Economy	19100.00
0005435540727	1750	Economy	19100.00
0005433516760	1750	Economy	19100.00
0005435528976	1750	Economy	19100.00
0005435540732	1750	Economy	19100.00
0005435528983	1750	Economy	19100.00
0005435540716	1750	Economy	19100.00
0005432294456	1750	Economy	19100.00
0005435540718	1750	Economy	19100.00
0005433516766	1750	Economy	19100.00
0005435528984	1750	Economy	19100.00
0005435540721	1750	Economy	19100.00
0005435540713	1750	Economy	19100.00
0005435540733	1750	Economy	19100.00
0005435540729	1750	Economy	19100.00
0005433516759	1750	Economy	19100.00
0005435528971	1750	Economy	19100.00
0005435528980	1750	Economy	19100.00
0005435540731	1750	Economy	19100.00
0005435540722	1750	Economy	19100.00
0005432294455	1750	Economy	19100.00
0005435528969	1750	Economy	19100.00
0005435540712	1750	Economy	19100.00
0005433516758	1750	Economy	19100.00
0005433516764	1750	Economy	19100.00
0005432924974	22008	Business	57200.00
0005432924971	22008	Economy	19100.00
0005432924975	22008	Economy	19100.00
0005432924973	22008	Economy	19100.00
0005432924972	22008	Economy	19100.00
0005432924976	22008	Economy	19100.00
0005432838627	7388	Business	18500.00
0005432838640	7388	Business	18500.00
0005432838629	7388	Business	18500.00
0005432838612	7388	Business	18500.00
0005434458537	7388	Business	18500.00
0005434458535	7388	Business	18500.00
0005432838637	7388	Business	18500.00
0005432838636	7388	Business	18500.00
0005432838626	7388	Economy	6200.00
0005432823422	7388	Economy	6200.00
0005432838633	7388	Economy	6200.00
0005434458522	7388	Economy	6200.00
0005434458529	7388	Economy	6200.00
0005434458539	7388	Economy	6200.00
0005432838631	7388	Economy	6200.00
0005432073345	7388	Economy	6200.00
0005432838609	7388	Economy	6200.00
0005432838618	7388	Economy	6800.00
0005434458531	7388	Economy	6800.00
0005434458519	7388	Economy	6200.00
0005434458527	7388	Economy	6200.00
0005434458520	7388	Economy	6200.00
0005432838619	7388	Economy	6200.00
0005432838624	7388	Economy	6200.00
0005432838610	7388	Economy	6200.00
0005432838632	7388	Economy	6200.00
0005432838623	7388	Economy	6200.00
0005434458534	7388	Economy	6200.00
0005432823423	7388	Economy	6200.00
0005432838639	7388	Economy	6200.00
0005434458525	7388	Economy	6200.00
0005434458521	7388	Economy	6200.00
0005432838608	7388	Economy	6200.00
0005432073344	7388	Economy	6200.00
0005432838621	7388	Economy	6200.00
0005432838615	7388	Economy	6200.00
0005434458536	7388	Economy	6200.00
0005434458524	7388	Economy	6200.00
0005432838635	7388	Economy	6200.00
0005432073343	7388	Economy	6200.00
0005434458528	7388	Economy	6200.00
0005434458530	7388	Economy	6200.00
0005432838630	7388	Economy	6200.00
0005432838622	7388	Economy	6200.00
0005432838634	7388	Economy	6200.00
0005432838613	7388	Economy	6200.00
0005432838625	7388	Economy	6200.00
0005432838638	7388	Economy	6200.00
0005432838607	7388	Economy	6200.00
0005434458533	7388	Economy	6200.00
0005432838614	7388	Economy	6200.00
0005432838628	7388	Economy	6200.00
0005432838620	7388	Economy	6200.00
0005432838611	7388	Economy	6200.00
0005432840983	7388	Economy	6200.00
0005432838617	7388	Economy	6200.00
0005434458526	7388	Economy	6200.00
0005434458523	7388	Economy	6200.00
0005432838616	7388	Economy	6200.00
0005434458532	7388	Economy	6200.00
0005434458538	7388	Economy	6200.00
0005432840984	7388	Economy	6200.00
0005435252467	28929	Business	18500.00
0005435252458	28929	Economy	6200.00
0005435252455	28929	Economy	6800.00
0005435252453	28929	Economy	6800.00
0005434664931	28929	Economy	6200.00
0005435252470	28929	Economy	6200.00
0005435252464	28929	Economy	6200.00
0005435252471	28929	Economy	6200.00
0005435252469	28929	Economy	6200.00
0005435252460	28929	Economy	6200.00
0005435252466	28929	Economy	6200.00
0005435252457	28929	Economy	6200.00
0005432000996	28929	Economy	6200.00
0005434664930	28929	Economy	6200.00
0005435252456	28929	Economy	6200.00
0005435252459	28929	Economy	6200.00
0005435252462	28929	Economy	6200.00
0005435252463	28929	Economy	6200.00
0005435252465	28929	Economy	6200.00
0005435252461	28929	Economy	6200.00
0005435252468	28929	Economy	6200.00
0005435252454	28929	Economy	6200.00
0005435990527	8779	Business	145300.00
0005435990529	8779	Business	145300.00
0005435990530	8779	Economy	48400.00
0005435990532	8779	Economy	48400.00
0005435990531	8779	Economy	48400.00
0005435990528	8779	Economy	48400.00
0005434275950	15759	Business	145300.00
0005434275949	15759	Business	145300.00
0005434275948	15759	Economy	53300.00
0005434275947	15759	Economy	48400.00
0005434275952	15759	Economy	48400.00
0005434275951	15759	Economy	48400.00
0005433476861	30857	Economy	14500.00
0005433476860	30857	Economy	14500.00
0005433476865	30857	Economy	14500.00
0005433476863	30857	Economy	14500.00
0005433476862	30857	Economy	14500.00
0005433476859	30857	Economy	14500.00
0005433476864	30857	Economy	14500.00
0005432909207	23832	Economy	13300.00
0005432909210	23832	Economy	12100.00
0005432909208	23832	Economy	12100.00
0005432909214	23832	Economy	12100.00
0005432909215	23832	Economy	12100.00
0005432909209	23832	Economy	12100.00
0005432909211	23832	Economy	12100.00
0005432909212	23832	Economy	12100.00
0005432909216	23832	Economy	12100.00
0005432909213	23832	Economy	12100.00
0005432335879	6365	Business	36600.00
0005432359735	6365	Business	36600.00
0005432359736	6365	Business	36600.00
0005432359704	6365	Business	36600.00
0005432359708	6365	Economy	12200.00
0005432359731	6365	Economy	12200.00
0005432359733	6365	Economy	12200.00
0005432335871	6365	Economy	12200.00
0005432359751	6365	Economy	12200.00
0005432359719	6365	Economy	12200.00
0005432359740	6365	Economy	12200.00
0005432359732	6365	Economy	12200.00
0005432359726	6365	Economy	12200.00
0005432359718	6365	Economy	12200.00
0005432359734	6365	Economy	12200.00
0005432359748	6365	Economy	12200.00
0005432335870	6365	Economy	12200.00
0005432062156	6365	Economy	12200.00
0005432363373	6365	Economy	12200.00
0005432335876	6365	Economy	12200.00
0005432359717	6365	Economy	12200.00
0005432359738	6365	Economy	12200.00
0005432363372	6365	Economy	12200.00
0005432359721	6365	Economy	12200.00
0005432359711	6365	Economy	12200.00
0005432359713	6365	Economy	12200.00
0005432359743	6365	Economy	12200.00
0005432359707	6365	Economy	12200.00
0005432359709	6365	Economy	12200.00
0005432359729	6365	Economy	12200.00
0005432359741	6365	Economy	12200.00
0005432335874	6365	Economy	12200.00
0005432062160	6365	Economy	12200.00
0005432062159	6365	Economy	13400.00
0005432359730	6365	Economy	13400.00
0005432359706	6365	Economy	13400.00
0005432062158	6365	Economy	13400.00
0005432335872	6365	Economy	12200.00
0005432335880	6365	Economy	12200.00
0005432359746	6365	Economy	12200.00
0005432359728	6365	Economy	12200.00
0005432359752	6365	Economy	12200.00
0005432335877	6365	Economy	12200.00
0005432359720	6365	Economy	12200.00
0005432359747	6365	Economy	12200.00
0005432335873	6365	Economy	12200.00
0005432359739	6365	Economy	12200.00
0005432335875	6365	Economy	12200.00
0005432359727	6365	Economy	12200.00
0005432359745	6365	Economy	12200.00
0005432359724	6365	Economy	12200.00
0005432359725	6365	Economy	12200.00
0005432359710	6365	Economy	12200.00
0005432359744	6365	Economy	12200.00
0005432359714	6365	Economy	12200.00
0005432359750	6365	Economy	12200.00
0005432359712	6365	Economy	12200.00
0005432359723	6365	Economy	12200.00
0005432359737	6365	Economy	12200.00
0005435176637	6365	Economy	12200.00
0005432359749	6365	Economy	12200.00
0005432335878	6365	Economy	12200.00
0005432062155	6365	Economy	12200.00
0005432359742	6365	Economy	12200.00
0005432359705	6365	Economy	12200.00
0005432062157	6365	Economy	12200.00
0005432359715	6365	Economy	12200.00
0005432359722	6365	Economy	12200.00
0005432359716	6365	Economy	12200.00
0005432335869	6365	Economy	12200.00
0005434149578	21002	Business	36600.00
0005435490184	21002	Business	36600.00
0005435176713	21002	Business	36600.00
0005435176708	21002	Business	36600.00
0005432052704	21002	Business	36600.00
0005435176719	21002	Business	36600.00
0005435176710	21002	Business	36600.00
0005435176715	21002	Business	36600.00
0005435176702	21002	Economy	12200.00
0005435176707	21002	Economy	12200.00
0005434149574	21002	Economy	12200.00
0005434149577	21002	Economy	12200.00
0005432359547	21002	Economy	12200.00
0005434149569	21002	Economy	12200.00
0005432359557	21002	Economy	12200.00
0005435176700	21002	Economy	12200.00
0005435176725	21002	Economy	12200.00
0005432052707	21002	Economy	12200.00
0005435176704	21002	Economy	12200.00
0005432052708	21002	Economy	12200.00
0005432052705	21002	Economy	12200.00
0005435176724	21002	Economy	13400.00
0005434149571	21002	Economy	13400.00
0005435176703	21002	Economy	13400.00
0005435176716	21002	Economy	13400.00
0005435176723	21002	Economy	12200.00
0005435176712	21002	Economy	12200.00
0005432052706	21002	Economy	12200.00
0005435176699	21002	Economy	12200.00
0005434149573	21002	Economy	12200.00
0005434149572	21002	Economy	12200.00
0005434149579	21002	Economy	12200.00
0005435176717	21002	Economy	12200.00
0005435176705	21002	Economy	12200.00
0005435176714	21002	Economy	12200.00
0005435176718	21002	Economy	12200.00
0005435176722	21002	Economy	12200.00
0005435176720	21002	Economy	12200.00
0005435176709	21002	Economy	12200.00
0005435176711	21002	Economy	12200.00
0005435176698	21002	Economy	12200.00
0005434149576	21002	Economy	12200.00
0005435176706	21002	Economy	12200.00
0005432359546	21002	Economy	12200.00
0005435176701	21002	Economy	12200.00
0005432359558	21002	Economy	12200.00
0005434149570	21002	Economy	12200.00
0005435176721	21002	Economy	12200.00
0005434149568	21002	Economy	12200.00
0005434149575	21002	Economy	12200.00
0005434458464	17698	Economy	3400.00
0005434186162	17698	Economy	3100.00
0005434186161	17698	Economy	3100.00
0005434458465	17698	Economy	3100.00
0005434461608	17698	Economy	3100.00
0005434186160	17698	Economy	3100.00
0005434448267	29127	Economy	3400.00
0005434458527	29127	Economy	3400.00
0005434458525	29127	Economy	3400.00
0005434458539	29127	Economy	3100.00
0005434458523	29127	Economy	3100.00
0005434462760	29127	Economy	3100.00
0005434458519	29127	Economy	3100.00
0005434458531	29127	Economy	3100.00
0005434458529	29127	Economy	3100.00
0005434458535	29127	Economy	3100.00
0005434458532	29127	Economy	3100.00
0005434458522	29127	Economy	3100.00
0005434458520	29127	Economy	3100.00
0005434448266	29127	Economy	3100.00
0005434458521	29127	Economy	3100.00
0005434458537	29127	Economy	3100.00
0005434458524	29127	Economy	3100.00
0005434458528	29127	Economy	3100.00
0005434458530	29127	Economy	3100.00
0005434458534	29127	Economy	3100.00
0005434458538	29127	Economy	3100.00
0005434458536	29127	Economy	3100.00
0005434448265	29127	Economy	3100.00
0005434463899	29127	Economy	3100.00
0005434463898	29127	Economy	3100.00
0005434462759	29127	Economy	3100.00
0005434458533	29127	Economy	3100.00
0005434458526	29127	Economy	3100.00
0005432603774	21422	Economy	7300.00
0005432603778	21422	Economy	7300.00
0005432603767	21422	Economy	7300.00
0005432603784	21422	Economy	7300.00
0005432603790	21422	Economy	6600.00
0005432603801	21422	Economy	6600.00
0005432603803	21422	Economy	6600.00
0005432603797	21422	Economy	6600.00
0005432603780	21422	Economy	6600.00
0005432603789	21422	Economy	6600.00
0005432603764	21422	Economy	6600.00
0005432603783	21422	Economy	6600.00
0005432603763	21422	Economy	6600.00
0005432603773	21422	Economy	6600.00
0005432603796	21422	Economy	6600.00
0005432603779	21422	Economy	6600.00
0005432603795	21422	Economy	6600.00
0005432603786	21422	Economy	6600.00
0005432603800	21422	Economy	6600.00
0005432603791	21422	Economy	6600.00
0005432603768	21422	Economy	6600.00
0005432603785	21422	Economy	6600.00
0005432603799	21422	Economy	6600.00
0005432603766	21422	Economy	6600.00
0005432603775	21422	Economy	6600.00
0005432603802	21422	Economy	6600.00
0005432603776	21422	Economy	6600.00
0005432603771	21422	Economy	6600.00
0005432603792	21422	Economy	6600.00
0005432603777	21422	Economy	6600.00
0005432603770	21422	Economy	6600.00
0005432603793	21422	Economy	6600.00
0005432603769	21422	Economy	6600.00
0005432603787	21422	Economy	6600.00
0005432603781	21422	Economy	6600.00
0005432603765	21422	Economy	6600.00
0005432603782	21422	Economy	6600.00
0005432603772	21422	Economy	6600.00
0005432603794	21422	Economy	6600.00
0005432603788	21422	Economy	6600.00
0005432603798	21422	Economy	6600.00
0005433293170	29616	Economy	19500.00
0005433293175	29616	Economy	19500.00
0005433293164	29616	Economy	17800.00
0005433293173	29616	Economy	17800.00
0005433293165	29616	Economy	17800.00
0005433293167	29616	Economy	17800.00
0005433293169	29616	Economy	17800.00
0005433293177	29616	Economy	17800.00
0005433293171	29616	Economy	17800.00
0005433293176	29616	Economy	17800.00
0005433293172	29616	Economy	17800.00
0005433293166	29616	Economy	17800.00
0005433293174	29616	Economy	17800.00
0005433293168	29616	Economy	17800.00
0005433473146	6679	Economy	12700.00
0005433473143	6679	Economy	12700.00
0005433473142	6679	Economy	12700.00
0005433473131	6679	Economy	12700.00
0005433473138	6679	Economy	12700.00
0005433473136	6679	Economy	12700.00
0005433473145	6679	Economy	12700.00
0005433473134	6679	Economy	12700.00
0005433473129	6679	Economy	12700.00
0005433473130	6679	Economy	12700.00
0005433473147	6679	Economy	12700.00
0005433473132	6679	Economy	12700.00
0005433473133	6679	Economy	12700.00
0005433473135	6679	Economy	12700.00
0005433473140	6679	Economy	12700.00
0005433473137	6679	Economy	12700.00
0005433473141	6679	Economy	12700.00
0005433473144	6679	Economy	12700.00
0005433473139	6679	Economy	12700.00
0005433473128	6679	Economy	12700.00
0005435257163	23888	Economy	14000.00
0005435257160	23888	Economy	14000.00
0005435257169	23888	Economy	12700.00
0005435257167	23888	Economy	12700.00
0005435257164	23888	Economy	12700.00
0005435257168	23888	Economy	12700.00
0005435257162	23888	Economy	12700.00
0005435257166	23888	Economy	12700.00
0005435257159	23888	Economy	12700.00
0005435257161	23888	Economy	12700.00
0005435257170	23888	Economy	12700.00
0005435257158	23888	Economy	12700.00
0005435257165	23888	Economy	12700.00
0005434606772	22347	Economy	6600.00
0005434606775	22347	Economy	6600.00
0005434606774	22347	Economy	6600.00
0005434604848	22347	Economy	6600.00
0005434604846	22347	Economy	6600.00
0005434606773	22347	Economy	6600.00
0005434604847	22347	Economy	6600.00
0005434602872	3844	Economy	24900.00
0005434522395	3844	Economy	22600.00
0005434522388	3844	Economy	22600.00
0005434522390	3844	Economy	22600.00
0005434522392	3844	Economy	22600.00
0005434602873	3844	Economy	22600.00
0005434522394	3844	Economy	22600.00
0005434602874	3844	Economy	22600.00
0005434602868	3844	Economy	22600.00
0005434602870	3844	Economy	22600.00
0005434522389	3844	Economy	22600.00
0005434522393	3844	Economy	22600.00
0005434602871	3844	Economy	22600.00
0005434602869	3844	Economy	22600.00
0005434522391	3844	Economy	22600.00
0005435904374	19051	Economy	22600.00
0005435904376	19051	Economy	22600.00
0005435904375	19051	Economy	22600.00
0005435904377	19051	Economy	22600.00
0005435904373	19051	Economy	22600.00
0005432747058	392	Business	44500.00
0005432747052	392	Business	44500.00
0005432747046	392	Business	44500.00
0005432747053	392	Business	44500.00
0005432747055	392	Business	44500.00
0005432747032	392	Business	44500.00
0005432751477	392	Business	44500.00
0005432747022	392	Business	44500.00
0005432747040	392	Economy	14800.00
0005432747027	392	Economy	14800.00
0005432747029	392	Economy	14800.00
0005432747060	392	Economy	14800.00
0005432749754	392	Economy	14800.00
0005432747023	392	Economy	14800.00
0005432747041	392	Economy	16300.00
0005432747056	392	Economy	14800.00
0005432751480	392	Economy	14800.00
0005432747042	392	Economy	14800.00
0005432747033	392	Economy	14800.00
0005432747044	392	Economy	14800.00
0005432747048	392	Economy	14800.00
0005432747031	392	Economy	14800.00
0005432219943	392	Economy	14800.00
0005432219946	392	Economy	14800.00
0005432747057	392	Economy	14800.00
0005432747051	392	Economy	14800.00
0005432747035	392	Economy	14800.00
0005432747043	392	Economy	14800.00
0005432749753	392	Economy	14800.00
0005432747026	392	Economy	14800.00
0005432747047	392	Economy	14800.00
0005432753254	392	Economy	14800.00
0005432747034	392	Economy	14800.00
0005432747059	392	Economy	14800.00
0005432751479	392	Economy	14800.00
0005432753253	392	Economy	14800.00
0005432747024	392	Economy	14800.00
0005432747054	392	Economy	14800.00
0005432747050	392	Economy	14800.00
0005432751478	392	Economy	14800.00
0005432747038	392	Economy	14800.00
0005432747036	392	Economy	14800.00
0005432747049	392	Economy	14800.00
0005432747045	392	Economy	14800.00
0005432747039	392	Economy	14800.00
0005432219944	392	Economy	14800.00
0005435154589	392	Economy	14800.00
0005432747037	392	Economy	14800.00
0005435154590	392	Economy	14800.00
0005432747030	392	Economy	14800.00
0005432747025	392	Economy	14800.00
0005432753252	392	Economy	14800.00
0005432219945	392	Economy	14800.00
0005432747028	392	Economy	14800.00
0005432747061	392	Economy	14800.00
0005432214775	12063	Business	44500.00
0005432890754	12063	Business	44500.00
0005432890757	12063	Business	44500.00
0005432890750	12063	Business	44500.00
0005432890752	12063	Economy	14800.00
0005432214776	12063	Economy	14800.00
0005432214774	12063	Economy	14800.00
0005434153518	12063	Economy	14800.00
0005432890759	12063	Economy	16300.00
0005432890751	12063	Economy	16300.00
0005432890760	12063	Economy	14800.00
0005432890768	12063	Economy	14800.00
0005432746899	12063	Economy	14800.00
0005432890765	12063	Economy	14800.00
0005432890763	12063	Economy	14800.00
0005432890755	12063	Economy	14800.00
0005432890749	12063	Economy	14800.00
0005432890766	12063	Economy	14800.00
0005432746934	12063	Economy	14800.00
0005432746875	12063	Economy	14800.00
0005433875359	12063	Economy	14800.00
0005432890761	12063	Economy	14800.00
0005432214773	12063	Economy	14800.00
0005433875358	12063	Economy	14800.00
0005432890753	12063	Economy	14800.00
0005432890767	12063	Economy	14800.00
0005432890764	12063	Economy	14800.00
0005432890756	12063	Economy	14800.00
0005432890758	12063	Economy	14800.00
0005432746876	12063	Economy	14800.00
0005432890762	12063	Economy	14800.00
0005433531240	18985	Economy	28200.00
0005433524886	18985	Economy	25700.00
0005433533256	18985	Economy	25700.00
0005433531239	18985	Economy	25700.00
0005433531237	18985	Economy	25700.00
0005433524885	18985	Economy	25700.00
0005433524888	18985	Economy	25700.00
0005433524889	18985	Economy	25700.00
0005433533255	18985	Economy	25700.00
0005433524887	18985	Economy	25700.00
0005433524883	18985	Economy	25700.00
0005433533253	18985	Economy	25700.00
0005433524881	18985	Economy	25700.00
0005433524882	18985	Economy	25700.00
0005433524884	18985	Economy	25700.00
0005433531238	18985	Economy	25700.00
0005433533254	18985	Economy	25700.00
0005432927913	32492	Economy	28200.00
0005433531228	32492	Economy	25700.00
0005433531227	32492	Economy	25700.00
0005432927910	32492	Economy	25700.00
0005432927912	32492	Economy	25700.00
0005432927911	32492	Economy	25700.00
0005432927909	32492	Economy	25700.00
0005434821914	5274	Business	84000.00
0005435304095	5274	Business	84000.00
0005434821841	5274	Business	84000.00
0005434821961	5274	Business	84000.00
0005434821929	5274	Business	84000.00
0005434821879	5274	Business	84000.00
0005434821953	5274	Business	84000.00
0005434664927	5274	Business	84000.00
0005434821919	5274	Business	84000.00
0005434821895	5274	Business	84000.00
0005434821894	5274	Comfort	47600.00
0005435149847	5274	Comfort	47600.00
0005432121140	5274	Comfort	47600.00
0005432121143	5274	Comfort	47600.00
0005432396190	5274	Comfort	47600.00
0005434831084	5274	Comfort	47600.00
0005434821926	5274	Comfort	47600.00
0005435149855	5274	Comfort	47600.00
0005434821932	5274	Comfort	47600.00
0005434821899	5274	Comfort	47600.00
0005434821836	5274	Comfort	47600.00
0005434821872	5274	Comfort	47600.00
0005432394051	5274	Comfort	47600.00
0005435149854	5274	Comfort	47600.00
0005432121144	5274	Comfort	47600.00
0005434821867	5274	Comfort	47600.00
0005434821934	5274	Comfort	47600.00
0005434821859	5274	Comfort	47600.00
0005434821896	5274	Comfort	47600.00
0005434821908	5274	Comfort	47600.00
0005434821903	5274	Comfort	47600.00
0005434821912	5274	Economy	28000.00
0005434821846	5274	Economy	28000.00
0005434821944	5274	Economy	28000.00
0005434821897	5274	Economy	28000.00
0005434821863	5274	Economy	28000.00
0005434821881	5274	Economy	28000.00
0005435149849	5274	Economy	28000.00
0005434821940	5274	Economy	28000.00
0005434821869	5274	Economy	28000.00
0005432394049	5274	Economy	28000.00
0005435149850	5274	Economy	28000.00
0005434821957	5274	Economy	28000.00
0005434821840	5274	Economy	28000.00
0005434828658	5274	Economy	28000.00
0005434821956	5274	Economy	28000.00
0005434821854	5274	Economy	28000.00
0005435149844	5274	Economy	28000.00
0005434821909	5274	Economy	28000.00
0005434821922	5274	Economy	28000.00
0005434558162	5274	Economy	28000.00
0005434821838	5274	Economy	28000.00
0005434821835	5274	Economy	28000.00
0005434821941	5274	Economy	28000.00
0005434821865	5274	Economy	28000.00
0005434821937	5274	Economy	28000.00
0005434821842	5274	Economy	28000.00
0005434558161	5274	Economy	28000.00
0005434821890	5274	Economy	28000.00
0005434664929	5274	Economy	28000.00
0005434821866	5274	Economy	28000.00
0005434821893	5274	Economy	28000.00
0005434821883	5274	Economy	28000.00
0005434821839	5274	Economy	30800.00
0005432121150	5274	Economy	30800.00
0005432396188	5274	Economy	28000.00
0005432121153	5274	Economy	28000.00
0005434558167	5274	Economy	30800.00
0005434821935	5274	Economy	30800.00
0005434821936	5274	Economy	28000.00
0005434821945	5274	Economy	28000.00
0005434821959	5274	Economy	28000.00
0005434821939	5274	Economy	28000.00
0005434821855	5274	Economy	28000.00
0005434558169	5274	Economy	28000.00
0005434821916	5274	Economy	28000.00
0005434821845	5274	Economy	28000.00
0005434821904	5274	Economy	28000.00
0005434821847	5274	Economy	28000.00
0005434821892	5274	Economy	28000.00
0005434821853	5274	Economy	28000.00
0005434558168	5274	Economy	28000.00
0005432394048	5274	Economy	28000.00
0005434821886	5274	Economy	28000.00
0005434821943	5274	Economy	28000.00
0005434558166	5274	Economy	28000.00
0005435149848	5274	Economy	28000.00
0005434821834	5274	Economy	28000.00
0005434821902	5274	Economy	28000.00
0005435304096	5274	Economy	28000.00
0005434828657	5274	Economy	28000.00
0005434821875	5274	Economy	28000.00
0005434558163	5274	Economy	28000.00
0005434821927	5274	Economy	28000.00
0005432121149	5274	Economy	28000.00
0005435149841	5274	Economy	28000.00
0005432396187	5274	Economy	28000.00
0005434821862	5274	Economy	28000.00
0005434821888	5274	Economy	28000.00
0005434831085	5274	Economy	28000.00
0005434821887	5274	Economy	28000.00
0005434821948	5274	Economy	28000.00
0005432121152	5274	Economy	28000.00
0005434821889	5274	Economy	28000.00
0005432121145	5274	Economy	28000.00
0005434821877	5274	Economy	28000.00
0005434821931	5274	Economy	28000.00
0005434821849	5274	Economy	28000.00
0005432121142	5274	Economy	28000.00
0005434821925	5274	Economy	28000.00
0005434821852	5274	Economy	28000.00
0005434831083	5274	Economy	28000.00
0005434821856	5274	Economy	28000.00
0005435149843	5274	Economy	28000.00
0005434821844	5274	Economy	28000.00
0005434821910	5274	Economy	28000.00
0005434821891	5274	Economy	28000.00
0005434821884	5274	Economy	28000.00
0005434828656	5274	Economy	28000.00
0005434821898	5274	Economy	28000.00
0005434821947	5274	Economy	28000.00
0005434821831	5274	Economy	28000.00
0005432396191	5274	Economy	28000.00
0005434821882	5274	Economy	28000.00
0005434821873	5274	Economy	28000.00
0005434821880	5274	Economy	28000.00
0005432121147	5274	Economy	30800.00
0005434821950	5274	Economy	30800.00
0005434821901	5274	Economy	30800.00
0005432394050	5274	Economy	28000.00
0005434821843	5274	Economy	30800.00
0005434821960	5274	Economy	30800.00
0005434821857	5274	Economy	28000.00
0005434821952	5274	Economy	28000.00
0005434821871	5274	Economy	28000.00
0005434821858	5274	Economy	28000.00
0005434821832	5274	Economy	28000.00
0005434821850	5274	Economy	28000.00
0005434821874	5274	Economy	28000.00
0005434821946	5274	Economy	28000.00
0005434821915	5274	Economy	28000.00
0005432121148	5274	Economy	28000.00
0005434821928	5274	Economy	28000.00
0005434821949	5274	Economy	28000.00
0005434831082	5274	Economy	28000.00
0005434821924	5274	Economy	28000.00
0005434664926	5274	Economy	28000.00
0005432121154	5274	Economy	28000.00
0005434821876	5274	Economy	28000.00
0005435149851	5274	Economy	28000.00
0005434821900	5274	Economy	28000.00
0005434821920	5274	Economy	28000.00
0005434821868	5274	Economy	28000.00
0005434821954	5274	Economy	28000.00
0005434821851	5274	Economy	28000.00
0005432121151	5274	Economy	28000.00
0005434821878	5274	Economy	28000.00
0005434558160	5274	Economy	28000.00
0005432396189	5274	Economy	28000.00
0005434821951	5274	Economy	28000.00
0005434821830	5274	Economy	28000.00
0005434821923	5274	Economy	28000.00
0005435149842	5274	Economy	28000.00
0005434821933	5274	Economy	28000.00
0005434821917	5274	Economy	28000.00
0005434821930	5274	Economy	28000.00
0005435149846	5274	Economy	28000.00
0005432121141	5274	Economy	28000.00
0005434821938	5274	Economy	28000.00
0005434821955	5274	Economy	28000.00
0005434821833	5274	Economy	28000.00
0005434821958	5274	Economy	28000.00
0005435149853	5274	Economy	28000.00
0005434558170	5274	Economy	28000.00
0005432121146	5274	Economy	28000.00
0005434821921	5274	Economy	28000.00
0005434821905	5274	Economy	28000.00
0005434558164	5274	Economy	28000.00
0005434821942	5274	Economy	28000.00
0005435149852	5274	Economy	28000.00
0005434821864	5274	Economy	28000.00
0005434821911	5274	Economy	28000.00
0005434821870	5274	Economy	28000.00
0005434821885	5274	Economy	28000.00
0005434821837	5274	Economy	28000.00
0005434821907	5274	Economy	28000.00
0005434821913	5274	Economy	28000.00
0005435149845	5274	Economy	28000.00
0005434821848	5274	Economy	28000.00
0005434821918	5274	Economy	28000.00
0005434821906	5274	Economy	28000.00
0005434821861	5274	Economy	28000.00
0005434558165	5274	Economy	28000.00
0005434821860	5274	Economy	28000.00
0005434664928	5274	Economy	28000.00
0005435372406	9936	Business	84000.00
0005435179386	9936	Business	84000.00
0005432202969	9936	Business	84000.00
0005435372425	9936	Business	84000.00
0005435372409	9936	Business	84000.00
0005435372365	9936	Business	84000.00
0005435735075	9936	Business	84000.00
0005435661892	9936	Business	84000.00
0005435735079	9936	Business	84000.00
0005435372400	9936	Business	84000.00
0005435735076	9936	Comfort	47600.00
0005435372369	9936	Comfort	47600.00
0005435735080	9936	Comfort	47600.00
0005435372370	9936	Comfort	47600.00
0005435372403	9936	Comfort	47600.00
0005435386486	9936	Comfort	47600.00
0005435372423	9936	Comfort	47600.00
0005435372376	9936	Comfort	47600.00
0005432202968	9936	Comfort	47600.00
0005435302136	9936	Comfort	47600.00
0005432202966	9936	Economy	28000.00
0005435372411	9936	Economy	28000.00
0005435372418	9936	Economy	28000.00
0005435372421	9936	Economy	28000.00
0005435372363	9936	Economy	28000.00
0005435372387	9936	Economy	28000.00
0005435372395	9936	Economy	28000.00
0005435372401	9936	Economy	28000.00
0005435372396	9936	Economy	28000.00
0005435372388	9936	Economy	28000.00
0005435386482	9936	Economy	28000.00
0005435299713	9936	Economy	28000.00
0005435372407	9936	Economy	28000.00
0005435302138	9936	Economy	28000.00
0005435299711	9936	Economy	28000.00
0005435372404	9936	Economy	28000.00
0005435372378	9936	Economy	28000.00
0005435372386	9936	Economy	28000.00
0005435372372	9936	Economy	30800.00
0005435372361	9936	Economy	28000.00
0005435372393	9936	Economy	30800.00
0005435372362	9936	Economy	30800.00
0005435372380	9936	Economy	28000.00
0005435372368	9936	Economy	28000.00
0005435372379	9936	Economy	28000.00
0005435372424	9936	Economy	28000.00
0005435386484	9936	Economy	28000.00
0005435372366	9936	Economy	28000.00
0005435661893	9936	Economy	28000.00
0005435302134	9936	Economy	28000.00
0005435386485	9936	Economy	28000.00
0005435372399	9936	Economy	28000.00
0005435372389	9936	Economy	28000.00
0005435386481	9936	Economy	28000.00
0005435661891	9936	Economy	28000.00
0005435372364	9936	Economy	28000.00
0005435372383	9936	Economy	28000.00
0005432202964	9936	Economy	28000.00
0005435372371	9936	Economy	28000.00
0005435372394	9936	Economy	28000.00
0005435372367	9936	Economy	28000.00
0005435299710	9936	Economy	28000.00
0005435372375	9936	Economy	28000.00
0005435372390	9936	Economy	28000.00
0005435372417	9936	Economy	28000.00
0005435179385	9936	Economy	28000.00
0005435372398	9936	Economy	28000.00
0005435372392	9936	Economy	28000.00
0005435302137	9936	Economy	28000.00
0005435372410	9936	Economy	28000.00
0005435372414	9936	Economy	28000.00
0005435372377	9936	Economy	28000.00
0005435299714	9936	Economy	28000.00
0005435372374	9936	Economy	28000.00
0005435372397	9936	Economy	28000.00
0005435372413	9936	Economy	28000.00
0005435302135	9936	Economy	28000.00
0005434821357	9936	Economy	28000.00
0005435372384	9936	Economy	30800.00
0005435372391	9936	Economy	28000.00
0005435372381	9936	Economy	28000.00
0005435372402	9936	Economy	28000.00
0005432202963	9936	Economy	28000.00
0005435372419	9936	Economy	28000.00
0005435372416	9936	Economy	28000.00
0005435372422	9936	Economy	28000.00
0005435386488	9936	Economy	28000.00
0005435299712	9936	Economy	28000.00
0005434821426	9936	Economy	28000.00
0005435372408	9936	Economy	28000.00
0005434821392	9936	Economy	28000.00
0005435372415	9936	Economy	28000.00
0005432202967	9936	Economy	28000.00
0005432202965	9936	Economy	28000.00
0005432823424	9936	Economy	28000.00
0005435386483	9936	Economy	28000.00
0005435372373	9936	Economy	28000.00
0005435735077	9936	Economy	28000.00
0005435386487	9936	Economy	28000.00
0005435372412	9936	Economy	28000.00
0005434821342	9936	Economy	28000.00
0005435372385	9936	Economy	28000.00
0005435735078	9936	Economy	28000.00
0005435372382	9936	Economy	28000.00
0005435372420	9936	Economy	28000.00
0005435372405	9936	Economy	28000.00
0005435082681	6991	Economy	8200.00
0005435790266	6991	Economy	7400.00
0005435790268	6991	Economy	7400.00
0005435790269	6991	Economy	7400.00
0005435082680	6991	Economy	7400.00
0005435082678	6991	Economy	7400.00
0005435082683	6991	Economy	7400.00
0005435790267	6991	Economy	7400.00
0005435082682	6991	Economy	7400.00
0005435082679	6991	Economy	7400.00
0005434755916	9560	Business	32800.00
0005434755902	9560	Business	32800.00
0005434755876	9560	Business	32800.00
0005434755896	9560	Business	32800.00
0005434755903	9560	Business	32800.00
0005434755888	9560	Business	32800.00
0005434755919	9560	Business	32800.00
0005434755918	9560	Economy	10900.00
0005434755908	9560	Economy	10900.00
0005434755911	9560	Economy	10900.00
0005434755898	9560	Economy	10900.00
0005434755879	9560	Economy	10900.00
0005434755891	9560	Economy	10900.00
0005434755889	9560	Economy	10900.00
0005434755914	9560	Economy	12000.00
0005434755872	9560	Economy	10900.00
0005434755899	9560	Economy	10900.00
0005434755907	9560	Economy	10900.00
0005434755877	9560	Economy	10900.00
0005434755880	9560	Economy	10900.00
0005434755882	9560	Economy	10900.00
0005434755912	9560	Economy	10900.00
0005434755886	9560	Economy	10900.00
0005434755910	9560	Economy	10900.00
0005434755892	9560	Economy	10900.00
0005434755901	9560	Economy	10900.00
0005434755921	9560	Economy	10900.00
0005434755895	9560	Economy	10900.00
0005434755875	9560	Economy	10900.00
0005434755897	9560	Economy	10900.00
0005434755884	9560	Economy	10900.00
0005434755904	9560	Economy	10900.00
0005434755883	9560	Economy	10900.00
0005434755871	9560	Economy	10900.00
0005434755887	9560	Economy	10900.00
0005434755913	9560	Economy	10900.00
0005434755873	9560	Economy	10900.00
0005434755900	9560	Economy	10900.00
0005434755885	9560	Economy	10900.00
0005434755917	9560	Economy	10900.00
0005434755906	9560	Economy	10900.00
0005434755905	9560	Economy	10900.00
0005434755881	9560	Economy	10900.00
0005434755915	9560	Economy	10900.00
0005434755874	9560	Economy	10900.00
0005434755909	9560	Economy	10900.00
0005434755890	9560	Economy	10900.00
0005434755878	9560	Economy	10900.00
0005434755920	9560	Economy	10900.00
0005434755894	9560	Economy	10900.00
0005434755893	9560	Economy	10900.00
0005434213853	28609	Business	32800.00
0005434213878	28609	Business	32800.00
0005434213858	28609	Business	32800.00
0005434213884	28609	Business	32800.00
0005434213864	28609	Business	32800.00
0005434213886	28609	Business	32800.00
0005434213862	28609	Business	32800.00
0005434213885	28609	Business	32800.00
0005434213883	28609	Business	32800.00
0005434213873	28609	Economy	10900.00
0005434213846	28609	Economy	10900.00
0005434213866	28609	Economy	10900.00
0005434213871	28609	Economy	10900.00
0005434213877	28609	Economy	10900.00
0005434213874	28609	Economy	12000.00
0005434213841	28609	Economy	12000.00
0005434213888	28609	Economy	10900.00
0005434213870	28609	Economy	10900.00
0005434213887	28609	Economy	10900.00
0005434213872	28609	Economy	10900.00
0005434213857	28609	Economy	10900.00
0005434213867	28609	Economy	10900.00
0005434213845	28609	Economy	10900.00
0005434213852	28609	Economy	10900.00
0005434213851	28609	Economy	10900.00
0005434213882	28609	Economy	10900.00
0005434213844	28609	Economy	10900.00
0005434213865	28609	Economy	10900.00
0005434213843	28609	Economy	10900.00
0005434213849	28609	Economy	10900.00
0005434213880	28609	Economy	10900.00
0005434213856	28609	Economy	10900.00
0005434213854	28609	Economy	10900.00
0005434213861	28609	Economy	10900.00
0005434213850	28609	Economy	10900.00
0005434213879	28609	Economy	10900.00
0005434213881	28609	Economy	10900.00
0005434213875	28609	Economy	10900.00
0005434213847	28609	Economy	10900.00
0005434213869	28609	Economy	10900.00
0005434213855	28609	Economy	10900.00
0005434213842	28609	Economy	10900.00
0005434213860	28609	Economy	10900.00
0005434213868	28609	Economy	10900.00
0005434213876	28609	Economy	10900.00
0005434213859	28609	Economy	10900.00
0005434213848	28609	Economy	10900.00
0005434213863	28609	Economy	10900.00
0005435100083	10829	Economy	9800.00
0005434760154	10829	Economy	8900.00
0005435100081	10829	Economy	8900.00
0005435100082	10829	Economy	8900.00
0005434760155	10829	Economy	8900.00
0005435100084	10829	Economy	8900.00
0005434760164	31816	Economy	8900.00
0005434760165	31816	Economy	8900.00
0005434760163	31816	Economy	8900.00
0005434638957	1999	Economy	20900.00
0005434638973	1999	Economy	20900.00
0005432290591	1999	Economy	20900.00
0005434638972	1999	Economy	19000.00
0005434638963	1999	Economy	19000.00
0005434638981	1999	Economy	19000.00
0005435948311	1999	Economy	19000.00
0005434638961	1999	Economy	19000.00
0005434638984	1999	Economy	19000.00
0005434638964	1999	Economy	19000.00
0005434638983	1999	Economy	19000.00
0005434638974	1999	Economy	19000.00
0005434638969	1999	Economy	19000.00
0005432290592	1999	Economy	19000.00
0005434638968	1999	Economy	19000.00
0005432290593	1999	Economy	19000.00
0005434638978	1999	Economy	19000.00
0005434638976	1999	Economy	19000.00
0005434638979	1999	Economy	19000.00
0005434638960	1999	Economy	19000.00
0005434638967	1999	Economy	19000.00
0005434638956	1999	Economy	19000.00
0005434638958	1999	Economy	19000.00
0005434638971	1999	Economy	19000.00
0005434638966	1999	Economy	19000.00
0005434638975	1999	Economy	19000.00
0005434638962	1999	Economy	19000.00
0005434638980	1999	Economy	19000.00
0005434638970	1999	Economy	19000.00
0005434638965	1999	Economy	19000.00
0005434638959	1999	Economy	19000.00
0005434638977	1999	Economy	19000.00
0005434638982	1999	Economy	19000.00
0005433202150	23275	Economy	19000.00
0005433202162	23275	Economy	19000.00
0005433202155	23275	Economy	19000.00
0005433202159	23275	Economy	19000.00
0005433202161	23275	Economy	19000.00
0005433202160	23275	Economy	19000.00
0005433202158	23275	Economy	19000.00
0005433202151	23275	Economy	19000.00
0005433202156	23275	Economy	19000.00
0005433202148	23275	Economy	19000.00
0005433202154	23275	Economy	19000.00
0005433202153	23275	Economy	19000.00
0005433202157	23275	Economy	19000.00
0005433202152	23275	Economy	19000.00
0005433202147	23275	Economy	19000.00
0005433202149	23275	Economy	19000.00
0005434600440	6048	Business	69700.00
0005434600439	6048	Business	69700.00
0005434600456	6048	Business	69700.00
0005432111239	6048	Business	69700.00
0005434600461	6048	Business	69700.00
0005434600442	6048	Business	69700.00
0005434600446	6048	Business	69700.00
0005434600459	6048	Economy	23200.00
0005434600444	6048	Economy	23200.00
0005434600441	6048	Economy	23200.00
0005434600447	6048	Economy	23200.00
0005434600450	6048	Economy	23200.00
0005434600449	6048	Economy	25600.00
0005433531241	6048	Economy	23200.00
0005434600457	6048	Economy	23200.00
0005434600443	6048	Economy	23200.00
0005434600448	6048	Economy	23200.00
0005433531243	6048	Economy	23200.00
0005433533258	6048	Economy	23200.00
0005434600463	6048	Economy	23200.00
0005434600462	6048	Economy	23200.00
0005434600451	6048	Economy	23200.00
0005434600438	6048	Economy	23200.00
0005432111240	6048	Economy	23200.00
0005433533257	6048	Economy	23200.00
0005434600437	6048	Economy	23200.00
0005434600445	6048	Economy	23200.00
0005434600453	6048	Economy	23200.00
0005433533259	6048	Economy	23200.00
0005433531244	6048	Economy	23200.00
0005434600460	6048	Economy	23200.00
0005434600452	6048	Economy	23200.00
0005433531242	6048	Economy	23200.00
0005434600464	6048	Economy	23200.00
0005434600458	6048	Economy	23200.00
0005434600455	6048	Economy	23200.00
0005434600454	6048	Economy	23200.00
0005432111238	6048	Economy	23200.00
0005432111237	6048	Economy	23200.00
0005435326558	18586	Business	69700.00
0005435326554	18586	Economy	23200.00
0005435326560	18586	Economy	23200.00
0005435326555	18586	Economy	23200.00
0005435326563	18586	Economy	23200.00
0005435326567	18586	Economy	23200.00
0005435326559	18586	Economy	23200.00
0005435326565	18586	Economy	23200.00
0005435326564	18586	Economy	23200.00
0005435326566	18586	Economy	23200.00
0005435326561	18586	Economy	23200.00
0005435326557	18586	Economy	23200.00
0005435326556	18586	Economy	23200.00
0005435326562	18586	Economy	23200.00
0005434550451	10637	Business	9100.00
0005434554032	10637	Business	9100.00
0005434550450	10637	Business	9100.00
0005434550429	10637	Business	9100.00
0005434550453	10637	Business	9100.00
0005434550464	10637	Business	9100.00
0005434550444	10637	Business	9100.00
0005434550455	10637	Business	9100.00
0005434550468	10637	Economy	3000.00
0005434550448	10637	Economy	3000.00
0005434550447	10637	Economy	3000.00
0005434550446	10637	Economy	3300.00
0005434550480	10637	Economy	3300.00
0005434554034	10637	Economy	3300.00
0005434550440	10637	Economy	3300.00
0005434550452	10637	Economy	3300.00
0005434550473	10637	Economy	3000.00
0005434550479	10637	Economy	3000.00
0005434550443	10637	Economy	3000.00
0005434550456	10637	Economy	3000.00
0005434550465	10637	Economy	3000.00
0005434558155	10637	Economy	3000.00
0005434550426	10637	Economy	3000.00
0005434558159	10637	Economy	3000.00
0005434558156	10637	Economy	3000.00
0005434550454	10637	Economy	3000.00
0005434550478	10637	Economy	3000.00
0005434550428	10637	Economy	3000.00
0005434550477	10637	Economy	3000.00
0005434550445	10637	Economy	3000.00
0005434550425	10637	Economy	3000.00
0005434550461	10637	Economy	3000.00
0005434550430	10637	Economy	3000.00
0005434550471	10637	Economy	3000.00
0005434550475	10637	Economy	3000.00
0005434550472	10637	Economy	3000.00
0005434550459	10637	Economy	3000.00
0005434558158	10637	Economy	3000.00
0005434550460	10637	Economy	3000.00
0005434550435	10637	Economy	3000.00
0005434550474	10637	Economy	3000.00
0005434550458	10637	Economy	3000.00
0005434550457	10637	Economy	3000.00
0005434554033	10637	Economy	3000.00
0005434550434	10637	Economy	3000.00
0005434550438	10637	Economy	3000.00
0005434550437	10637	Economy	3000.00
0005434550462	10637	Economy	3000.00
0005434558157	10637	Economy	3000.00
0005434550463	10637	Economy	3000.00
0005434550469	10637	Economy	3000.00
0005434550476	10637	Economy	3000.00
0005434550449	10637	Economy	3000.00
0005434550481	10637	Economy	3000.00
0005434550432	10637	Economy	3000.00
0005434550470	10637	Economy	3000.00
0005434550427	10637	Economy	3000.00
0005434550442	10637	Economy	3000.00
0005434550436	10637	Economy	3000.00
0005434550441	10637	Economy	3000.00
0005434550439	10637	Economy	3000.00
0005434550467	10637	Economy	3000.00
0005434550433	10637	Economy	3000.00
0005434550431	10637	Economy	3000.00
0005434550466	10637	Economy	3000.00
0005433180757	27689	Business	9100.00
0005433180769	27689	Business	9100.00
0005433180763	27689	Economy	3000.00
0005433180771	27689	Economy	3000.00
0005433180770	27689	Economy	3000.00
0005433180751	27689	Economy	3000.00
0005433180768	27689	Economy	3300.00
0005433180758	27689	Economy	3300.00
0005433180767	27689	Economy	3000.00
0005433180755	27689	Economy	3000.00
0005433180765	27689	Economy	3000.00
0005433180776	27689	Economy	3000.00
0005433180766	27689	Economy	3000.00
0005433180752	27689	Economy	3000.00
0005433180761	27689	Economy	3000.00
0005433180762	27689	Economy	3000.00
0005433180772	27689	Economy	3000.00
0005433180775	27689	Economy	3000.00
0005433180773	27689	Economy	3000.00
0005433180760	27689	Economy	3000.00
0005433180774	27689	Economy	3000.00
0005433180764	27689	Economy	3000.00
0005433180756	27689	Economy	3000.00
0005433180754	27689	Economy	3000.00
0005433180759	27689	Economy	3000.00
0005433180753	27689	Economy	3000.00
0005434550256	27697	Economy	3000.00
0005434550258	27697	Economy	3300.00
0005434550257	27697	Economy	3000.00
0005433459160	6135	Economy	11700.00
0005433459164	6135	Economy	11700.00
0005433459162	6135	Economy	11700.00
0005433459163	6135	Economy	11700.00
0005433459161	6135	Economy	11700.00
0005435254440	19343	Economy	11700.00
0005435254441	19343	Economy	11700.00
0005435681580	6747	Business	51100.00
0005435681584	6747	Business	51100.00
0005435681582	6747	Business	51100.00
0005435681566	6747	Business	51100.00
0005435681591	6747	Business	51100.00
0005435681571	6747	Business	51100.00
0005435681579	6747	Business	51100.00
0005435681574	6747	Economy	17000.00
0005435681552	6747	Economy	17000.00
0005435681593	6747	Economy	17000.00
0005435681572	6747	Economy	17000.00
0005435630923	6747	Economy	17000.00
0005435681556	6747	Economy	17000.00
0005435681561	6747	Economy	18700.00
0005432136102	6747	Economy	17000.00
0005435437574	6747	Economy	17000.00
0005435681567	6747	Economy	17000.00
0005435630924	6747	Economy	17000.00
0005435630925	6747	Economy	17000.00
0005435681573	6747	Economy	17000.00
0005435681581	6747	Economy	17000.00
0005435681587	6747	Economy	17000.00
0005435681592	6747	Economy	17000.00
0005435681585	6747	Economy	17000.00
0005435681559	6747	Economy	17000.00
0005435681595	6747	Economy	17000.00
0005435681568	6747	Economy	17000.00
0005435681554	6747	Economy	17000.00
0005435681558	6747	Economy	17000.00
0005435681586	6747	Economy	17000.00
0005435681578	6747	Economy	17000.00
0005435437573	6747	Economy	17000.00
0005435681551	6747	Economy	17000.00
0005435681557	6747	Economy	17000.00
0005435681570	6747	Economy	17000.00
0005435681560	6747	Economy	17000.00
0005435681590	6747	Economy	17000.00
0005435681589	6747	Economy	17000.00
0005435681549	6747	Economy	17000.00
0005435681555	6747	Economy	17000.00
0005435681550	6747	Economy	17000.00
0005435681565	6747	Economy	17000.00
0005435661890	6747	Economy	17000.00
0005435681588	6747	Economy	17000.00
0005435681564	6747	Economy	17000.00
0005435681576	6747	Economy	17000.00
0005435681575	6747	Economy	17000.00
0005432136103	6747	Economy	17000.00
0005432136101	6747	Economy	17000.00
0005435681562	6747	Economy	17000.00
0005435681569	6747	Economy	17000.00
0005435681563	6747	Economy	17000.00
0005435681594	6747	Economy	17000.00
0005435719553	6747	Economy	17000.00
0005435681553	6747	Economy	17000.00
0005435681583	6747	Economy	17000.00
0005435681577	6747	Economy	17000.00
0005435681413	24595	Business	51100.00
0005432305716	24595	Business	51100.00
0005435437664	24595	Business	51100.00
0005435437643	24595	Economy	17000.00
0005434828659	24595	Economy	17000.00
0005435437661	24595	Economy	17000.00
0005435437656	24595	Economy	17000.00
0005435437651	24595	Economy	17000.00
0005435437645	24595	Economy	18700.00
0005434828660	24595	Economy	17000.00
0005435437646	24595	Economy	17000.00
0005435437647	24595	Economy	17000.00
0005432533253	24595	Economy	17000.00
0005435437660	24595	Economy	17000.00
0005435437650	24595	Economy	17000.00
0005432305714	24595	Economy	17000.00
0005435437649	24595	Economy	17000.00
0005435437657	24595	Economy	17000.00
0005435437644	24595	Economy	17000.00
0005435437648	24595	Economy	17000.00
0005435437663	24595	Economy	17000.00
0005435681414	24595	Economy	17000.00
0005435437658	24595	Economy	17000.00
0005432533254	24595	Economy	17000.00
0005435437655	24595	Economy	17000.00
0005435437659	24595	Economy	17000.00
0005435437665	24595	Economy	17000.00
0005434828661	24595	Economy	17000.00
0005432533252	24595	Economy	17000.00
0005435437662	24595	Economy	17000.00
0005435437653	24595	Economy	17000.00
0005432305715	24595	Economy	17000.00
0005435437652	24595	Economy	17000.00
0005435437654	24595	Economy	17000.00
0005435125772	11519	Business	26400.00
0005435125784	11519	Business	26400.00
0005435105937	11519	Business	26400.00
0005435125779	11519	Business	26400.00
0005435125788	11519	Business	26400.00
0005435125802	11519	Business	26400.00
0005435125773	11519	Economy	8800.00
0005435125787	11519	Economy	8800.00
0005435125796	11519	Economy	8800.00
0005435125776	11519	Economy	8800.00
0005435125792	11519	Economy	8800.00
0005435125783	11519	Economy	9700.00
0005435125785	11519	Economy	8800.00
0005435125806	11519	Economy	8800.00
0005435125810	11519	Economy	8800.00
0005435098523	11519	Economy	8800.00
0005435098527	11519	Economy	8800.00
0005435125801	11519	Economy	8800.00
0005435125793	11519	Economy	8800.00
0005435125809	11519	Economy	8800.00
0005435125800	11519	Economy	8800.00
0005435125807	11519	Economy	8800.00
0005435125812	11519	Economy	8800.00
0005435125808	11519	Economy	8800.00
0005435098526	11519	Economy	8800.00
0005435125775	11519	Economy	8800.00
0005435098524	11519	Economy	8800.00
0005435125794	11519	Economy	8800.00
0005435125803	11519	Economy	8800.00
0005435125798	11519	Economy	8800.00
0005435125805	11519	Economy	8800.00
0005435125782	11519	Economy	8800.00
0005435098525	11519	Economy	8800.00
0005435125780	11519	Economy	8800.00
0005435125797	11519	Economy	8800.00
0005435098528	11519	Economy	8800.00
0005435125789	11519	Economy	8800.00
0005435125791	11519	Economy	8800.00
0005435105938	11519	Economy	8800.00
0005435125778	11519	Economy	8800.00
0005435125795	11519	Economy	8800.00
0005435125777	11519	Economy	8800.00
0005435125813	11519	Economy	8800.00
0005435125811	11519	Economy	8800.00
0005435125804	11519	Economy	8800.00
0005435125781	11519	Economy	8800.00
0005435125786	11519	Economy	8800.00
0005435125799	11519	Economy	8800.00
0005435125790	11519	Economy	8800.00
0005435125774	11519	Economy	8800.00
0005435558052	31903	Business	26400.00
0005435558051	31903	Economy	8800.00
0005435558053	31903	Economy	8800.00
0005433397392	13503	Business	36600.00
0005433397405	13503	Business	36600.00
0005433397382	13503	Business	36600.00
0005433397423	13503	Business	36600.00
0005433397416	13503	Business	36600.00
0005433397391	13503	Business	36600.00
0005433397427	13503	Business	36600.00
0005433397388	13503	Economy	12200.00
0005433397401	13503	Economy	12200.00
0005433397407	13503	Economy	12200.00
0005433397397	13503	Economy	12200.00
0005433397421	13503	Economy	12200.00
0005433397399	13503	Economy	12200.00
0005433397413	13503	Economy	12200.00
0005433397409	13503	Economy	13400.00
0005433397385	13503	Economy	12200.00
0005433397394	13503	Economy	12200.00
0005433397403	13503	Economy	12200.00
0005433397390	13503	Economy	12200.00
0005433397379	13503	Economy	12200.00
0005433397422	13503	Economy	12200.00
0005433397411	13503	Economy	12200.00
0005433397380	13503	Economy	12200.00
0005433397419	13503	Economy	12200.00
0005433397420	13503	Economy	12200.00
0005433397389	13503	Economy	12200.00
0005433397402	13503	Economy	12200.00
0005433397414	13503	Economy	12200.00
0005433397383	13503	Economy	12200.00
0005433397410	13503	Economy	12200.00
0005433397425	13503	Economy	12200.00
0005433397415	13503	Economy	12200.00
0005433397398	13503	Economy	12200.00
0005433397396	13503	Economy	12200.00
0005433397418	13503	Economy	12200.00
0005433397395	13503	Economy	12200.00
0005433397387	13503	Economy	12200.00
0005433397400	13503	Economy	12200.00
0005433397384	13503	Economy	12200.00
0005433397406	13503	Economy	12200.00
0005433397408	13503	Economy	12200.00
0005433397393	13503	Economy	12200.00
0005433397386	13503	Economy	12200.00
0005433397412	13503	Economy	12200.00
0005433397424	13503	Economy	12200.00
0005433397404	13503	Economy	12200.00
0005433397426	13503	Economy	12200.00
0005433397381	13503	Economy	12200.00
0005433397417	13503	Economy	12200.00
0005433397197	19418	Business	36600.00
0005435732165	19418	Economy	12200.00
0005432297241	19418	Economy	12200.00
0005435732162	19418	Economy	12200.00
0005432297242	19418	Economy	12200.00
0005433397224	19418	Economy	12200.00
0005433397178	19418	Economy	12200.00
0005433397182	19418	Economy	12200.00
0005435732164	19418	Economy	12200.00
0005433397181	19418	Economy	12200.00
0005435732163	19418	Economy	12200.00
0005433397321	19418	Economy	12200.00
0005433397195	19418	Economy	12200.00
0005433397322	19418	Economy	12200.00
0005435925098	13173	Business	11300.00
0005435925117	13173	Business	11300.00
0005435925106	13173	Business	11300.00
0005435925097	13173	Business	11300.00
0005435925100	13173	Economy	3800.00
0005435925105	13173	Economy	3800.00
0005435925114	13173	Economy	3800.00
0005435925111	13173	Economy	3800.00
0005435925102	13173	Economy	3800.00
0005435925096	13173	Economy	3800.00
0005435925107	13173	Economy	3800.00
0005435925099	13173	Economy	3800.00
0005435925101	13173	Economy	3800.00
0005435925109	13173	Economy	3800.00
0005435925119	13173	Economy	3800.00
0005435925112	13173	Economy	3800.00
0005435925116	13173	Economy	3800.00
0005435925120	13173	Economy	3800.00
0005435925104	13173	Economy	3800.00
0005435925113	13173	Economy	3800.00
0005435925103	13173	Economy	3800.00
0005435925110	13173	Economy	3800.00
0005435925108	13173	Economy	3800.00
0005435925118	13173	Economy	3800.00
0005435925115	13173	Economy	3800.00
0005435068370	15468	Business	11300.00
0005435068358	15468	Business	11300.00
0005435068342	15468	Business	11300.00
0005435068355	15468	Business	11300.00
0005435068329	15468	Business	11300.00
0005435068350	15468	Business	11300.00
0005435068332	15468	Business	11300.00
0005435068363	15468	Business	11300.00
0005435068354	15468	Business	11300.00
0005435068349	15468	Economy	3800.00
0005435068366	15468	Economy	3800.00
0005435068335	15468	Economy	3800.00
0005435068331	15468	Economy	3800.00
0005435068333	15468	Economy	4100.00
0005435068341	15468	Economy	4100.00
0005435068336	15468	Economy	3800.00
0005435068327	15468	Economy	3800.00
0005435068338	15468	Economy	3800.00
0005435068357	15468	Economy	3800.00
0005435068321	15468	Economy	3800.00
0005435068367	15468	Economy	3800.00
0005435068348	15468	Economy	3800.00
0005435068322	15468	Economy	3800.00
0005435068368	15468	Economy	3800.00
0005435068340	15468	Economy	3800.00
0005435068319	15468	Economy	3800.00
0005435068345	15468	Economy	3800.00
0005435068326	15468	Economy	3800.00
0005435068359	15468	Economy	3800.00
0005435068361	15468	Economy	3800.00
0005435068356	15468	Economy	3800.00
0005435068325	15468	Economy	3800.00
0005435068343	15468	Economy	3800.00
0005435068365	15468	Economy	3800.00
0005435068337	15468	Economy	3800.00
0005435068324	15468	Economy	3800.00
0005435068353	15468	Economy	3800.00
0005435068328	15468	Economy	3800.00
0005435068347	15468	Economy	3800.00
0005435068362	15468	Economy	3800.00
0005435068346	15468	Economy	3800.00
0005435068369	15468	Economy	3800.00
0005435068318	15468	Economy	3800.00
0005435068330	15468	Economy	3800.00
0005435068344	15468	Economy	3800.00
0005435068360	15468	Economy	3800.00
0005435068320	15468	Economy	3800.00
0005435068334	15468	Economy	3800.00
0005435068339	15468	Economy	3800.00
0005435068364	15468	Economy	3800.00
0005435068352	15468	Economy	3800.00
0005435068323	15468	Economy	3800.00
0005435068351	15468	Economy	3800.00
0005433407499	29477	Economy	24700.00
0005433407495	29477	Economy	24700.00
0005433407500	29477	Economy	24700.00
0005433407492	29477	Economy	24700.00
0005433407494	29477	Economy	24700.00
0005433407502	29477	Economy	24700.00
0005433407497	29477	Economy	24700.00
0005433407496	29477	Economy	24700.00
0005433407498	29477	Economy	24700.00
0005433407501	29477	Economy	24700.00
0005433407493	29477	Economy	24700.00
0005434213907	10713	Business	61300.00
0005434213926	10713	Business	61300.00
0005434213897	10713	Business	61300.00
0005434213895	10713	Business	61300.00
0005434213933	10713	Business	61300.00
0005434213929	10713	Business	61300.00
0005434213891	10713	Business	61300.00
0005434213908	10713	Economy	20400.00
0005434213889	10713	Economy	20400.00
0005434213914	10713	Economy	20400.00
0005434213912	10713	Economy	20400.00
0005434213901	10713	Economy	22500.00
0005434213922	10713	Economy	22500.00
0005434213920	10713	Economy	20400.00
0005434213909	10713	Economy	20400.00
0005434213917	10713	Economy	20400.00
0005434213927	10713	Economy	20400.00
0005434213932	10713	Economy	20400.00
0005434213918	10713	Economy	20400.00
0005434213900	10713	Economy	20400.00
0005434213925	10713	Economy	20400.00
0005434213921	10713	Economy	20400.00
0005434213916	10713	Economy	20400.00
0005434213893	10713	Economy	20400.00
0005434213915	10713	Economy	20400.00
0005434213923	10713	Economy	20400.00
0005434213903	10713	Economy	20400.00
0005434213906	10713	Economy	20400.00
0005434213896	10713	Economy	20400.00
0005434213894	10713	Economy	20400.00
0005434213913	10713	Economy	20400.00
0005434213919	10713	Economy	20400.00
0005434213902	10713	Economy	20400.00
0005434213930	10713	Economy	20400.00
0005434213911	10713	Economy	20400.00
0005434213935	10713	Economy	20400.00
0005434213934	10713	Economy	20400.00
0005434213910	10713	Economy	20400.00
0005434213890	10713	Economy	20400.00
0005434213905	10713	Economy	20400.00
0005434213928	10713	Economy	20400.00
0005434213931	10713	Economy	20400.00
0005434213904	10713	Economy	20400.00
0005434213892	10713	Economy	20400.00
0005434213899	10713	Economy	20400.00
0005434213898	10713	Economy	20400.00
0005434213924	10713	Economy	20400.00
0005434755824	28670	Business	61300.00
0005434755830	28670	Business	61300.00
0005434755870	28670	Business	61300.00
0005434755858	28670	Business	61300.00
0005434755852	28670	Economy	20400.00
0005434755843	28670	Economy	20400.00
0005434755827	28670	Economy	20400.00
0005434755846	28670	Economy	20400.00
0005434755837	28670	Economy	20400.00
0005434755826	28670	Economy	22500.00
0005434755862	28670	Economy	22500.00
0005434755845	28670	Economy	22500.00
0005434755868	28670	Economy	20400.00
0005434755836	28670	Economy	20400.00
0005434755831	28670	Economy	20400.00
0005434755829	28670	Economy	20400.00
0005434755863	28670	Economy	20400.00
0005434755849	28670	Economy	20400.00
0005434755835	28670	Economy	20400.00
0005434755834	28670	Economy	20400.00
0005434755861	28670	Economy	20400.00
0005434755854	28670	Economy	20400.00
0005434755839	28670	Economy	20400.00
0005434755856	28670	Economy	20400.00
0005434755869	28670	Economy	20400.00
0005434755855	28670	Economy	20400.00
0005434755840	28670	Economy	20400.00
0005434755841	28670	Economy	20400.00
0005434755857	28670	Economy	20400.00
0005434755859	28670	Economy	20400.00
0005434755842	28670	Economy	20400.00
0005434755847	28670	Economy	20400.00
0005434755864	28670	Economy	20400.00
0005434755832	28670	Economy	20400.00
0005434755828	28670	Economy	20400.00
0005434755851	28670	Economy	20400.00
0005434755850	28670	Economy	20400.00
0005434755853	28670	Economy	20400.00
0005434755833	28670	Economy	20400.00
0005434755825	28670	Economy	20400.00
0005434755865	28670	Economy	20400.00
0005434755844	28670	Economy	20400.00
0005434755860	28670	Economy	20400.00
0005434755866	28670	Economy	20400.00
0005434755838	28670	Economy	20400.00
0005434755867	28670	Economy	20400.00
0005434755848	28670	Economy	20400.00
0005435042830	5462	Business	29500.00
0005435038917	5462	Business	29500.00
0005435038893	5462	Business	29500.00
0005432125351	5462	Business	29500.00
0005435006720	5462	Business	29500.00
0005435038910	5462	Business	29500.00
0005435038875	5462	Business	29500.00
0005435038922	5462	Business	29500.00
0005435006713	5462	Business	29500.00
0005435006701	5462	Business	29500.00
0005435038924	5462	Economy	9800.00
0005435006704	5462	Economy	9800.00
0005435038913	5462	Economy	9800.00
0005435038896	5462	Economy	9800.00
0005432125352	5462	Economy	9800.00
0005435038912	5462	Economy	9800.00
0005435006722	5462	Economy	9800.00
0005435006703	5462	Economy	9800.00
0005435042829	5462	Economy	9800.00
0005435006721	5462	Economy	9800.00
0005435006705	5462	Economy	9800.00
0005435006708	5462	Economy	9800.00
0005435006702	5462	Economy	9800.00
0005435006698	5462	Economy	9800.00
0005432125349	5462	Economy	9800.00
0005435038887	5462	Economy	9800.00
0005435038888	5462	Economy	9800.00
0005435006714	5462	Economy	9800.00
0005435038925	5462	Economy	9800.00
0005435006712	5462	Economy	9800.00
0005435038891	5462	Economy	9800.00
0005435042827	5462	Economy	9800.00
0005432125355	5462	Economy	9800.00
0005435038928	5462	Economy	9800.00
0005435038911	5462	Economy	9800.00
0005435006717	5462	Economy	9800.00
0005435006707	5462	Economy	9800.00
0005435006719	5462	Economy	9800.00
0005435038876	5462	Economy	9800.00
0005435006716	5462	Economy	9800.00
0005435038905	5462	Economy	9800.00
0005435038894	5462	Economy	10800.00
0005435038907	5462	Economy	9800.00
0005435038918	5462	Economy	10800.00
0005435038909	5462	Economy	10800.00
0005435038927	5462	Economy	10800.00
0005435038873	5462	Economy	9800.00
0005435038921	5462	Economy	9800.00
0005435038901	5462	Economy	9800.00
0005432125350	5462	Economy	9800.00
0005435038906	5462	Economy	9800.00
0005435038885	5462	Economy	9800.00
0005435006715	5462	Economy	9800.00
0005435038877	5462	Economy	9800.00
0005435038884	5462	Economy	9800.00
0005435038920	5462	Economy	9800.00
0005435038881	5462	Economy	9800.00
0005435038878	5462	Economy	9800.00
0005435042828	5462	Economy	9800.00
0005435006710	5462	Economy	9800.00
0005435038890	5462	Economy	9800.00
0005435038882	5462	Economy	9800.00
0005435038892	5462	Economy	9800.00
0005435038903	5462	Economy	9800.00
0005435038900	5462	Economy	9800.00
0005435038919	5462	Economy	9800.00
0005435038898	5462	Economy	9800.00
0005435038872	5462	Economy	9800.00
0005435042826	5462	Economy	9800.00
0005435038874	5462	Economy	9800.00
0005435006700	5462	Economy	9800.00
0005435038871	5462	Economy	9800.00
0005435038923	5462	Economy	9800.00
0005435006711	5462	Economy	9800.00
0005435038899	5462	Economy	9800.00
0005435038879	5462	Economy	9800.00
0005435038926	5462	Economy	9800.00
0005435006709	5462	Economy	9800.00
0005435038889	5462	Economy	9800.00
0005435038914	5462	Economy	9800.00
0005435038929	5462	Economy	9800.00
0005435038916	5462	Economy	9800.00
0005435038931	5462	Economy	9800.00
0005432125354	5462	Economy	9800.00
0005435006706	5462	Economy	9800.00
0005435038908	5462	Economy	9800.00
0005435038915	5462	Economy	9800.00
0005435006718	5462	Economy	9800.00
0005435038883	5462	Economy	9800.00
0005435038895	5462	Economy	9800.00
0005435038897	5462	Economy	9800.00
0005435006699	5462	Economy	9800.00
0005435038880	5462	Economy	9800.00
0005435038886	5462	Economy	9800.00
0005432125353	5462	Economy	9800.00
0005435038902	5462	Economy	9800.00
0005435038930	5462	Economy	9800.00
0005435038904	5462	Economy	9800.00
0005434229073	12949	Business	29500.00
0005435006641	12949	Business	29500.00
0005435038652	12949	Business	29500.00
0005434229062	12949	Business	29500.00
0005435006639	12949	Business	29500.00
0005434229063	12949	Economy	9800.00
0005434229067	12949	Economy	9800.00
0005434229061	12949	Economy	9800.00
0005432304346	12949	Economy	9800.00
0005434229074	12949	Economy	9800.00
0005432304344	12949	Economy	9800.00
0005432304347	12949	Economy	9800.00
0005434229069	12949	Economy	10800.00
0005435006613	12949	Economy	9800.00
0005434229079	12949	Economy	9800.00
0005435038653	12949	Economy	9800.00
0005432304345	12949	Economy	9800.00
0005435006640	12949	Economy	9800.00
0005434229060	12949	Economy	9800.00
0005434229070	12949	Economy	9800.00
0005435038624	12949	Economy	9800.00
0005434229075	12949	Economy	9800.00
0005434229066	12949	Economy	9800.00
0005434229071	12949	Economy	9800.00
0005434229068	12949	Economy	9800.00
0005434229072	12949	Economy	9800.00
0005434229064	12949	Economy	9800.00
0005434229076	12949	Economy	9800.00
0005435038623	12949	Economy	9800.00
0005434229065	12949	Economy	9800.00
0005434229078	12949	Economy	9800.00
0005435038631	12949	Economy	9800.00
0005434229080	12949	Economy	9800.00
0005434229059	12949	Economy	9800.00
0005434229077	12949	Economy	9800.00
0005434411715	14862	Business	52900.00
0005434426176	14862	Business	52900.00
0005432188561	14862	Business	52900.00
0005434426180	14862	Business	52900.00
0005434426203	14862	Business	52900.00
0005434426188	14862	Business	52900.00
0005432188562	14862	Economy	17600.00
0005434426177	14862	Economy	17600.00
0005434426182	14862	Economy	17600.00
0005434426195	14862	Economy	17600.00
0005434426184	14862	Economy	17600.00
0005434411717	14862	Economy	17600.00
0005434426191	14862	Economy	17600.00
0005434426201	14862	Economy	17600.00
0005434426194	14862	Economy	17600.00
0005434426179	14862	Economy	17600.00
0005434426186	14862	Economy	17600.00
0005434426202	14862	Economy	17600.00
0005434426187	14862	Economy	17600.00
0005434426190	14862	Economy	17600.00
0005434411718	14862	Economy	17600.00
0005434426193	14862	Economy	17600.00
0005434426183	14862	Economy	17600.00
0005434426204	14862	Economy	17600.00
0005434426198	14862	Economy	17600.00
0005434426174	14862	Economy	17600.00
0005434426200	14862	Economy	17600.00
0005434426185	14862	Economy	17600.00
0005434426197	14862	Economy	17600.00
0005434426192	14862	Economy	17600.00
0005434426189	14862	Economy	17600.00
0005434411716	14862	Economy	17600.00
0005434426178	14862	Economy	17600.00
0005434426196	14862	Economy	17600.00
0005434426181	14862	Economy	17600.00
0005434426199	14862	Economy	17600.00
0005434426175	14862	Economy	17600.00
0005435902474	20203	Business	52900.00
0005435902458	20203	Business	52900.00
0005435902462	20203	Economy	17600.00
0005435902460	20203	Economy	17600.00
0005435554124	20203	Economy	17600.00
0005435902466	20203	Economy	19400.00
0005432059477	20203	Economy	17600.00
0005434426096	20203	Economy	17600.00
0005435554126	20203	Economy	17600.00
0005435902461	20203	Economy	17600.00
0005435902459	20203	Economy	17600.00
0005435554127	20203	Economy	17600.00
0005435902468	20203	Economy	17600.00
0005434426098	20203	Economy	17600.00
0005434426097	20203	Economy	17600.00
0005435902465	20203	Economy	17600.00
0005435902469	20203	Economy	17600.00
0005435554123	20203	Economy	17600.00
0005435554125	20203	Economy	17600.00
0005435902464	20203	Economy	17600.00
0005435902473	20203	Economy	17600.00
0005435902467	20203	Economy	17600.00
0005435902471	20203	Economy	17600.00
0005434426092	20203	Economy	17600.00
0005435902457	20203	Economy	17600.00
0005435902472	20203	Economy	17600.00
0005432059478	20203	Economy	17600.00
0005435902463	20203	Economy	17600.00
0005435554128	20203	Economy	17600.00
0005435902470	20203	Economy	17600.00
0005435981654	26545	Business	18500.00
0005435981677	26545	Business	18500.00
0005435981688	26545	Business	18500.00
0005432300179	26545	Business	18500.00
0005435981655	26545	Economy	6200.00
0005432300184	26545	Economy	6200.00
0005435981670	26545	Economy	6200.00
0005432300178	26545	Economy	6200.00
0005435981672	26545	Economy	6200.00
0005435981666	26545	Economy	6200.00
0005435981647	26545	Economy	6200.00
0005435981684	26545	Economy	6200.00
0005435981681	26545	Economy	6200.00
0005435981660	26545	Economy	6200.00
0005435981664	26545	Economy	6200.00
0005432300181	26545	Economy	6200.00
0005435981659	26545	Economy	6200.00
0005435981673	26545	Economy	6200.00
0005435981665	26545	Economy	6200.00
0005435981663	26545	Economy	6200.00
0005435981668	26545	Economy	6200.00
0005435981656	26545	Economy	6200.00
0005435981661	26545	Economy	6200.00
0005435981648	26545	Economy	6200.00
0005432300182	26545	Economy	6200.00
0005435981687	26545	Economy	6200.00
0005435981676	26545	Economy	6200.00
0005435981653	26545	Economy	6200.00
0005435981652	26545	Economy	6200.00
0005435981657	26545	Economy	6200.00
0005435981667	26545	Economy	6200.00
0005435981685	26545	Economy	6200.00
0005435981662	26545	Economy	6200.00
0005435981669	26545	Economy	6200.00
0005435981674	26545	Economy	6200.00
0005435981675	26545	Economy	6200.00
0005435981671	26545	Economy	6200.00
0005435981650	26545	Economy	6200.00
0005435981678	26545	Economy	6200.00
0005435981680	26545	Economy	6200.00
0005435981686	26545	Economy	6200.00
0005432300180	26545	Economy	6200.00
0005435981689	26545	Economy	6200.00
0005435981646	26545	Economy	6200.00
0005435981679	26545	Economy	6200.00
0005435981682	26545	Economy	6200.00
0005435981651	26545	Economy	6200.00
0005432300183	26545	Economy	6200.00
0005435981683	26545	Economy	6200.00
0005435981649	26545	Economy	6200.00
0005435981645	26545	Economy	6200.00
0005435981658	26545	Economy	6200.00
0005433434304	26710	Business	18500.00
0005433434296	26710	Business	18500.00
0005433434314	26710	Business	18500.00
0005433434303	26710	Business	18500.00
0005433434299	26710	Business	18500.00
0005432051086	26710	Business	18500.00
0005433434316	26710	Business	18500.00
0005433434310	26710	Economy	6200.00
0005433434305	26710	Economy	6200.00
0005433434306	26710	Economy	6200.00
0005433434321	26710	Economy	6200.00
0005433434322	26710	Economy	6800.00
0005433434315	26710	Economy	6200.00
0005433434300	26710	Economy	6200.00
0005433434324	26710	Economy	6200.00
0005433434318	26710	Economy	6200.00
0005432051088	26710	Economy	6200.00
0005433434311	26710	Economy	6200.00
0005433434309	26710	Economy	6200.00
0005434271284	26710	Economy	6200.00
0005433434323	26710	Economy	6200.00
0005433434308	26710	Economy	6200.00
0005434270179	26710	Economy	6200.00
0005433434317	26710	Economy	6200.00
0005433434307	26710	Economy	6200.00
0005433434297	26710	Economy	6200.00
0005433434302	26710	Economy	6200.00
0005433434298	26710	Economy	6200.00
0005433434320	26710	Economy	6200.00
0005433434319	26710	Economy	6200.00
0005433434301	26710	Economy	6200.00
0005434270178	26710	Economy	6200.00
0005434271285	26710	Economy	6200.00
0005432051087	26710	Economy	6200.00
0005433434313	26710	Economy	6200.00
0005433434312	26710	Economy	6200.00
0005433434295	26710	Economy	6200.00
0005434269076	26710	Economy	6200.00
0005432583696	3178	Economy	11100.00
0005432216236	3178	Economy	11100.00
0005432583692	3178	Economy	10100.00
0005432583690	3178	Economy	10100.00
0005432583697	3178	Economy	10100.00
0005432583693	3178	Economy	10100.00
0005432583705	3178	Economy	10100.00
0005432583694	3178	Economy	10100.00
0005432583695	3178	Economy	10100.00
0005432583708	3178	Economy	10100.00
0005432583687	3178	Economy	10100.00
0005432583698	3178	Economy	10100.00
0005432216235	3178	Economy	10100.00
0005432216234	3178	Economy	10100.00
0005432583689	3178	Economy	10100.00
0005432583709	3178	Economy	10100.00
0005432583691	3178	Economy	10100.00
0005432583702	3178	Economy	10100.00
0005432583707	3178	Economy	10100.00
0005432583706	3178	Economy	10100.00
0005432583688	3178	Economy	10100.00
0005432583699	3178	Economy	10100.00
0005432583704	3178	Economy	10100.00
0005432583703	3178	Economy	10100.00
0005432583701	3178	Economy	10100.00
0005432583710	3178	Economy	10100.00
0005432583686	3178	Economy	10100.00
0005432583700	3178	Economy	10100.00
0005432857907	31510	Economy	11100.00
0005432857899	31510	Economy	11100.00
0005432583593	31510	Economy	10100.00
0005432857908	31510	Economy	10100.00
0005432857903	31510	Economy	10100.00
0005432857910	31510	Economy	10100.00
0005432857909	31510	Economy	10100.00
0005432583592	31510	Economy	10100.00
0005432857901	31510	Economy	10100.00
0005432857904	31510	Economy	10100.00
0005432857905	31510	Economy	10100.00
0005432857906	31510	Economy	10100.00
0005432857902	31510	Economy	10100.00
0005432857900	31510	Economy	10100.00
0005434943225	897	Economy	7500.00
0005434943229	897	Economy	7500.00
0005434943230	897	Economy	7500.00
0005434943222	897	Economy	7500.00
0005434943226	897	Economy	7500.00
0005434943231	897	Economy	7500.00
0005434943228	897	Economy	7500.00
0005434943224	897	Economy	7500.00
0005434943227	897	Economy	7500.00
0005434943223	897	Economy	7500.00
0005433255048	16237	Economy	8300.00
0005434943191	16237	Economy	7500.00
0005433255047	16237	Economy	7500.00
0005433255043	16237	Economy	7500.00
0005433255045	16237	Economy	7500.00
0005433255046	16237	Economy	7500.00
0005433255044	16237	Economy	7500.00
0005434943192	16237	Economy	7500.00
0005433654676	4328	Business	90500.00
0005433654662	4328	Business	90500.00
0005433654678	4328	Economy	30200.00
0005433654677	4328	Economy	30200.00
0005433654656	4328	Economy	30200.00
0005433654659	4328	Economy	33200.00
0005433654673	4328	Economy	30200.00
0005433654667	4328	Economy	30200.00
0005433654663	4328	Economy	30200.00
0005433654664	4328	Economy	30200.00
0005433654681	4328	Economy	30200.00
0005433654683	4328	Economy	30200.00
0005433654666	4328	Economy	30200.00
0005433654674	4328	Economy	30200.00
0005433654658	4328	Economy	30200.00
0005433654655	4328	Economy	30200.00
0005433654671	4328	Economy	30200.00
0005433654669	4328	Economy	30200.00
0005433654670	4328	Economy	30200.00
0005433654679	4328	Economy	30200.00
0005433654675	4328	Economy	30200.00
0005433654657	4328	Economy	30200.00
0005433654684	4328	Economy	30200.00
0005433654665	4328	Economy	30200.00
0005433654661	4328	Economy	30200.00
0005433654672	4328	Economy	30200.00
0005433654680	4328	Economy	30200.00
0005433654682	4328	Economy	30200.00
0005433654660	4328	Economy	30200.00
0005433654668	4328	Economy	30200.00
0005435652390	21778	Business	9800.00
0005435652433	21778	Business	9800.00
0005435652396	21778	Business	9800.00
0005435652384	21778	Business	9800.00
0005435652424	21778	Business	9800.00
0005435652406	21778	Business	9800.00
0005435652413	21778	Business	9800.00
0005435652400	21778	Economy	3300.00
0005435652405	21778	Economy	3300.00
0005435652386	21778	Economy	3300.00
0005435652432	21778	Economy	3300.00
0005435652420	21778	Economy	3300.00
0005435652418	21778	Economy	3300.00
0005435652429	21778	Economy	3300.00
0005435652404	21778	Economy	3600.00
0005435652419	21778	Economy	3600.00
0005435652407	21778	Economy	3300.00
0005435652415	21778	Economy	3300.00
0005435652434	21778	Economy	3300.00
0005435652402	21778	Economy	3300.00
0005435652422	21778	Economy	3300.00
0005435652411	21778	Economy	3300.00
0005435652427	21778	Economy	3300.00
0005435652403	21778	Economy	3300.00
0005435652408	21778	Economy	3300.00
0005435652389	21778	Economy	3300.00
0005435652398	21778	Economy	3300.00
0005435652401	21778	Economy	3300.00
0005435652392	21778	Economy	3300.00
0005435652428	21778	Economy	3300.00
0005435652425	21778	Economy	3300.00
0005435652388	21778	Economy	3300.00
0005435652410	21778	Economy	3300.00
0005435652430	21778	Economy	3300.00
0005435652385	21778	Economy	3300.00
0005435652395	21778	Economy	3300.00
0005435652423	21778	Economy	3300.00
0005435652435	21778	Economy	3300.00
0005435652431	21778	Economy	3300.00
0005435652414	21778	Economy	3300.00
0005435652412	21778	Economy	3300.00
0005435652416	21778	Economy	3300.00
0005435652397	21778	Economy	3300.00
0005435652394	21778	Economy	3300.00
0005435652417	21778	Economy	3300.00
0005435652426	21778	Economy	3300.00
0005435652387	21778	Economy	3300.00
0005435652391	21778	Economy	3300.00
0005435652409	21778	Economy	3300.00
0005435652399	21778	Economy	3300.00
0005435652421	21778	Economy	3300.00
0005435652393	21778	Economy	3300.00
0005432665248	9356	Business	186200.00
0005433784446	9356	Business	186200.00
0005433784442	9356	Business	186200.00
0005433804897	9356	Business	186200.00
0005433763016	9356	Business	186200.00
0005433763005	9356	Business	186200.00
0005433763008	9356	Business	186200.00
0005432667426	9356	Business	186200.00
0005433804926	9356	Business	186200.00
0005433804899	9356	Business	186200.00
0005432665247	9356	Business	186200.00
0005433804904	9356	Business	186200.00
0005433804906	9356	Business	186200.00
0005433804908	9356	Economy	68300.00
0005433804902	9356	Economy	62100.00
0005432666359	9356	Economy	62100.00
0005433784466	9356	Economy	62100.00
0005433784449	9356	Economy	62100.00
0005433763015	9356	Economy	62100.00
0005432665246	9356	Economy	62100.00
0005433804905	9356	Economy	62100.00
0005433784463	9356	Economy	62100.00
0005432666360	9356	Economy	62100.00
0005433804909	9356	Economy	62100.00
0005433804930	9356	Economy	62100.00
0005433784462	9356	Economy	62100.00
0005433804895	9356	Economy	62100.00
0005433804910	9356	Economy	62100.00
0005433763007	9356	Economy	62100.00
0005433804901	9356	Economy	62100.00
0005432667427	9356	Economy	62100.00
0005433763004	9356	Economy	62100.00
0005433784474	9356	Economy	62100.00
0005433804919	9356	Economy	62100.00
0005433804922	9356	Economy	62100.00
0005433784454	9356	Economy	62100.00
0005433804896	9356	Economy	62100.00
0005433784458	9356	Economy	62100.00
0005432657407	9356	Economy	62100.00
0005433804907	9356	Economy	62100.00
0005433763003	9356	Economy	62100.00
0005433804913	9356	Economy	62100.00
0005433784451	9356	Economy	62100.00
0005433804912	9356	Economy	62100.00
0005433784450	9356	Economy	62100.00
0005433804925	9356	Economy	62100.00
0005433804923	9356	Economy	62100.00
0005433784469	9356	Economy	62100.00
0005433763010	9356	Economy	62100.00
0005433784467	9356	Economy	62100.00
0005433784457	9356	Economy	62100.00
0005433804911	9356	Economy	62100.00
0005433784470	9356	Economy	62100.00
0005433784453	9356	Economy	62100.00
0005433784476	9356	Economy	62100.00
0005433804898	9356	Economy	62100.00
0005433804900	9356	Economy	62100.00
0005433804917	9356	Economy	62100.00
0005433804928	9356	Economy	62100.00
0005433804893	9356	Economy	62100.00
0005433784445	9356	Economy	62100.00
0005433784448	9356	Economy	62100.00
0005433784444	9356	Economy	62100.00
0005433784461	9356	Economy	62100.00
0005433784473	9356	Economy	62100.00
0005433784472	9356	Economy	68300.00
0005433763006	9356	Economy	68300.00
0005433784456	9356	Economy	62100.00
0005433804933	9356	Economy	62100.00
0005433804924	9356	Economy	62100.00
0005433763002	9356	Economy	62100.00
0005433784452	9356	Economy	62100.00
0005433804921	9356	Economy	62100.00
0005433763013	9356	Economy	62100.00
0005433784455	9356	Economy	62100.00
0005433784468	9356	Economy	62100.00
0005433784460	9356	Economy	62100.00
0005433804927	9356	Economy	62100.00
0005433784471	9356	Economy	62100.00
0005433804931	9356	Economy	62100.00
0005433804903	9356	Economy	62100.00
0005432657408	9356	Economy	62100.00
0005433804920	9356	Economy	62100.00
0005434170800	9356	Economy	62100.00
0005433804918	9356	Economy	62100.00
0005433804929	9356	Economy	62100.00
0005433804916	9356	Economy	62100.00
0005433804915	9356	Economy	62100.00
0005433784443	9356	Economy	62100.00
0005433784447	9356	Economy	62100.00
0005434170832	9356	Economy	62100.00
0005433784440	9356	Economy	62100.00
0005433804894	9356	Economy	62100.00
0005433804914	9356	Economy	62100.00
0005433784441	9356	Economy	62100.00
0005433784475	9356	Economy	62100.00
0005433763014	9356	Economy	62100.00
0005433784459	9356	Economy	62100.00
0005433763012	9356	Economy	62100.00
0005433763009	9356	Economy	62100.00
0005433784464	9356	Economy	62100.00
0005433763011	9356	Economy	62100.00
0005433784465	9356	Economy	62100.00
0005433804932	9356	Economy	62100.00
0005435269658	26241	Business	186200.00
0005435269661	26241	Business	186200.00
0005434170856	26241	Economy	68300.00
0005435269663	26241	Economy	62100.00
0005434151663	26241	Economy	62100.00
0005434170861	26241	Economy	62100.00
0005434151664	26241	Economy	62100.00
0005434170855	26241	Economy	62100.00
0005434170869	26241	Economy	62100.00
0005434269075	26241	Economy	62100.00
0005435269664	26241	Economy	62100.00
0005434271282	26241	Economy	62100.00
0005434170866	26241	Economy	62100.00
0005434170863	26241	Economy	62100.00
0005434170857	26241	Economy	62100.00
0005434170862	26241	Economy	62100.00
0005434151665	26241	Economy	62100.00
0005434170865	26241	Economy	62100.00
0005435269659	26241	Economy	62100.00
0005435269662	26241	Economy	62100.00
0005434170864	26241	Economy	62100.00
0005435269655	26241	Economy	62100.00
0005434170860	26241	Economy	62100.00
0005434269074	26241	Economy	62100.00
0005434170867	26241	Economy	62100.00
0005435269660	26241	Economy	62100.00
0005434270177	26241	Economy	62100.00
0005434271281	26241	Economy	62100.00
0005435269657	26241	Economy	62100.00
0005435269656	26241	Economy	62100.00
0005435269654	26241	Economy	62100.00
0005435269653	26241	Economy	62100.00
0005434170858	26241	Economy	62100.00
0005434170859	26241	Economy	62100.00
0005434170868	26241	Economy	62100.00
0005434271283	26241	Economy	62100.00
0005435135604	4914	Economy	5900.00
0005435135605	4914	Economy	5300.00
0005435135603	4914	Economy	5300.00
0005435135602	4914	Economy	5300.00
0005435929606	33050	Economy	5300.00
0005435929608	33050	Economy	5300.00
0005435929607	33050	Economy	5300.00
0005434983217	9498	Economy	19700.00
0005434983216	9498	Economy	17900.00
0005434983220	9498	Economy	17900.00
0005434983219	9498	Economy	17900.00
0005434983215	9498	Economy	17900.00
0005434983218	9498	Economy	17900.00
0005434217914	27390	Economy	17900.00
0005434217915	27390	Economy	17900.00
0005434217913	27390	Economy	17900.00
0005434217912	27390	Economy	17900.00
0005433985267	25927	Business	36400.00
0005433960037	25927	Business	36400.00
0005433960047	25927	Business	36400.00
0005433960074	25927	Business	36400.00
0005433985295	25927	Business	36400.00
0005433985289	25927	Business	36400.00
0005433960044	25927	Business	36400.00
0005433960035	25927	Business	36400.00
0005433985273	25927	Business	36400.00
0005433985283	25927	Business	36400.00
0005433985264	25927	Business	36400.00
0005433985306	25927	Business	36400.00
0005433960073	25927	Business	36400.00
0005433985285	25927	Business	36400.00
0005433985291	25927	Economy	13400.00
0005433985280	25927	Economy	12100.00
0005433960040	25927	Economy	12100.00
0005433960031	25927	Economy	12100.00
0005433985268	25927	Economy	12100.00
0005433960066	25927	Economy	12100.00
0005433985297	25927	Economy	12100.00
0005433985305	25927	Economy	12100.00
0005433960059	25927	Economy	12100.00
0005433960041	25927	Economy	12100.00
0005433960081	25927	Economy	12100.00
0005433960032	25927	Economy	12100.00
0005433960053	25927	Economy	12100.00
0005433985266	25927	Economy	12100.00
0005433985262	25927	Economy	12100.00
0005433985263	25927	Economy	12100.00
0005433960028	25927	Economy	12100.00
0005433960029	25927	Economy	12100.00
0005433960077	25927	Economy	12100.00
0005433985301	25927	Economy	12100.00
0005433960070	25927	Economy	12100.00
0005433985287	25927	Economy	12100.00
0005433985307	25927	Economy	12100.00
0005433985272	25927	Economy	12100.00
0005433960057	25927	Economy	12100.00
0005433960076	25927	Economy	12100.00
0005433985293	25927	Economy	12100.00
0005433960065	25927	Economy	12100.00
0005433960061	25927	Economy	12100.00
0005433985288	25927	Economy	12100.00
0005433960036	25927	Economy	12100.00
0005433985278	25927	Economy	12100.00
0005433960033	25927	Economy	12100.00
0005433960039	25927	Economy	12100.00
0005433960056	25927	Economy	12100.00
0005433985277	25927	Economy	12100.00
0005433960050	25927	Economy	12100.00
0005433960045	25927	Economy	12100.00
0005433960063	25927	Economy	12100.00
0005433985299	25927	Economy	12100.00
0005433985269	25927	Economy	12100.00
0005433985290	25927	Economy	12100.00
0005433960049	25927	Economy	12100.00
0005433960052	25927	Economy	12100.00
0005433985304	25927	Economy	12100.00
0005433985292	25927	Economy	13400.00
0005433985279	25927	Economy	12100.00
0005433960042	25927	Economy	13400.00
0005433960075	25927	Economy	12100.00
0005433985276	25927	Economy	12100.00
0005433985271	25927	Economy	12100.00
0005433960055	25927	Economy	12100.00
0005433960069	25927	Economy	12100.00
0005433960046	25927	Economy	12100.00
0005433960071	25927	Economy	12100.00
0005433960054	25927	Economy	12100.00
0005433985303	25927	Economy	12100.00
0005433985282	25927	Economy	12100.00
0005433985274	25927	Economy	12100.00
0005433985298	25927	Economy	12100.00
0005433960048	25927	Economy	12100.00
0005433960038	25927	Economy	12100.00
0005433960034	25927	Economy	12100.00
0005433960058	25927	Economy	12100.00
0005433985286	25927	Economy	12100.00
0005433985275	25927	Economy	12100.00
0005433960078	25927	Economy	12100.00
0005433985296	25927	Economy	12100.00
0005433985281	25927	Economy	12100.00
0005433960051	25927	Economy	12100.00
0005433985284	25927	Economy	12100.00
0005433960060	25927	Economy	12100.00
0005433985265	25927	Economy	12100.00
0005433985270	25927	Economy	12100.00
0005433960079	25927	Economy	12100.00
0005433960043	25927	Economy	12100.00
0005433960068	25927	Economy	12100.00
0005433960080	25927	Economy	12100.00
0005433985300	25927	Economy	12100.00
0005433985261	25927	Economy	12100.00
0005433960072	25927	Economy	12100.00
0005433960064	25927	Economy	12100.00
0005433960030	25927	Economy	12100.00
0005433985294	25927	Economy	12100.00
0005433960062	25927	Economy	12100.00
0005433985302	25927	Economy	12100.00
0005433960067	25927	Economy	12100.00
0005432269458	970	Economy	25400.00
0005434479984	970	Economy	23100.00
0005434479978	970	Economy	23100.00
0005434479990	970	Economy	23100.00
0005434479993	970	Economy	23100.00
0005434479988	970	Economy	23100.00
0005434479989	970	Economy	23100.00
0005434479979	970	Economy	23100.00
0005434479981	970	Economy	23100.00
0005434479991	970	Economy	23100.00
0005434479999	970	Economy	23100.00
0005433165674	970	Economy	23100.00
0005434480001	970	Economy	23100.00
0005434479992	970	Economy	23100.00
0005434479980	970	Economy	23100.00
0005434480003	970	Economy	23100.00
0005434480002	970	Economy	23100.00
0005434479997	970	Economy	23100.00
0005434479985	970	Economy	23100.00
0005434479987	970	Economy	23100.00
0005434479982	970	Economy	23100.00
0005434480000	970	Economy	23100.00
0005434479994	970	Economy	23100.00
0005434479998	970	Economy	23100.00
0005434479995	970	Economy	23100.00
0005434479983	970	Economy	23100.00
0005434479986	970	Economy	23100.00
0005432269457	970	Economy	23100.00
0005434479996	970	Economy	23100.00
0005433165732	16560	Economy	25400.00
0005433165733	16560	Economy	23100.00
0005433165728	16560	Economy	23100.00
0005433165723	16560	Economy	23100.00
0005433165734	16560	Economy	23100.00
0005434479923	16560	Economy	23100.00
0005433165730	16560	Economy	23100.00
0005433165724	16560	Economy	23100.00
0005433165727	16560	Economy	23100.00
0005433165731	16560	Economy	23100.00
0005433165726	16560	Economy	23100.00
0005433165729	16560	Economy	23100.00
0005433165722	16560	Economy	23100.00
0005433165725	16560	Economy	23100.00
0005433872439	3193	Economy	17200.00
0005433872440	3193	Economy	17200.00
0005433872441	3193	Economy	17200.00
0005433872438	3193	Economy	17200.00
0005433872442	3193	Economy	17200.00
0005433872436	3193	Economy	17200.00
0005433872437	3193	Economy	17200.00
0005435149832	10340	Economy	17000.00
0005435149828	10340	Economy	15400.00
0005435142382	10340	Economy	15400.00
0005435149837	10340	Economy	15400.00
0005435142380	10340	Economy	15400.00
0005435142384	10340	Economy	15400.00
0005435142389	10340	Economy	15400.00
0005435149829	10340	Economy	15400.00
0005435149833	10340	Economy	15400.00
0005435142381	10340	Economy	15400.00
0005435149830	10340	Economy	15400.00
0005435142383	10340	Economy	15400.00
0005435149835	10340	Economy	15400.00
0005435149838	10340	Economy	15400.00
0005435142388	10340	Economy	15400.00
0005435149834	10340	Economy	15400.00
0005435142378	10340	Economy	15400.00
0005435142387	10340	Economy	15400.00
0005435149836	10340	Economy	15400.00
0005435149839	10340	Economy	15400.00
0005435142379	10340	Economy	15400.00
0005435149827	10340	Economy	15400.00
0005435149840	10340	Economy	15400.00
0005435142386	10340	Economy	15400.00
0005435142377	10340	Economy	15400.00
0005435149831	10340	Economy	15400.00
0005435142385	10340	Economy	15400.00
0005435386481	21956	Economy	17000.00
0005435386487	21956	Economy	15400.00
0005433289754	21956	Economy	15400.00
0005435386485	21956	Economy	15400.00
0005433289761	21956	Economy	15400.00
0005433289758	21956	Economy	15400.00
0005433289755	21956	Economy	15400.00
0005435386482	21956	Economy	15400.00
0005433289760	21956	Economy	15400.00
0005435386484	21956	Economy	15400.00
0005435386483	21956	Economy	15400.00
0005435386488	21956	Economy	15400.00
0005433289757	21956	Economy	15400.00
0005433289759	21956	Economy	15400.00
0005435386486	21956	Economy	15400.00
0005433289756	21956	Economy	15400.00
0005434573155	11189	Business	57200.00
0005434573144	11189	Economy	19100.00
0005434573146	11189	Economy	19100.00
0005434573147	11189	Economy	19100.00
0005434573156	11189	Economy	19100.00
0005434573149	11189	Economy	19100.00
0005434573153	11189	Economy	19100.00
0005434573158	11189	Economy	19100.00
0005434573154	11189	Economy	19100.00
0005434573148	11189	Economy	19100.00
0005434573152	11189	Economy	19100.00
0005434573151	11189	Economy	19100.00
0005434573145	11189	Economy	19100.00
0005434573150	11189	Economy	19100.00
0005434573157	11189	Economy	19100.00
0005435508209	20962	Business	57200.00
0005435508208	20962	Business	57200.00
0005435508203	20962	Business	57200.00
0005435502006	20962	Business	57200.00
0005435508207	20962	Business	57200.00
0005435502008	20962	Business	57200.00
0005435502001	20962	Business	57200.00
0005435319461	20962	Business	57200.00
0005435517660	20962	Business	57200.00
0005435319464	20962	Economy	19100.00
0005432291895	20962	Economy	19100.00
0005435502015	20962	Economy	19100.00
0005435319462	20962	Economy	19100.00
0005435517657	20962	Economy	19100.00
0005435319465	20962	Economy	19100.00
0005435502018	20962	Economy	19100.00
0005435319463	20962	Economy	19100.00
0005435508205	20962	Economy	19100.00
0005435502003	20962	Economy	21000.00
0005435517652	20962	Economy	21000.00
0005435517649	20962	Economy	21000.00
0005435508199	20962	Economy	21000.00
0005435508200	20962	Economy	19100.00
0005435517659	20962	Economy	19100.00
0005435502000	20962	Economy	19100.00
0005435502012	20962	Economy	19100.00
0005435502019	20962	Economy	19100.00
0005435502010	20962	Economy	19100.00
0005435502013	20962	Economy	19100.00
0005435517662	20962	Economy	19100.00
0005435517656	20962	Economy	19100.00
0005435508206	20962	Economy	19100.00
0005435517653	20962	Economy	19100.00
0005435502005	20962	Economy	19100.00
0005435501998	20962	Economy	19100.00
0005432291896	20962	Economy	19100.00
0005435502020	20962	Economy	19100.00
0005435502014	20962	Economy	19100.00
0005435517650	20962	Economy	19100.00
0005435517664	20962	Economy	19100.00
0005435502011	20962	Economy	19100.00
0005435517655	20962	Economy	19100.00
0005435502016	20962	Economy	19100.00
0005435502002	20962	Economy	19100.00
0005435517666	20962	Economy	19100.00
0005435502007	20962	Economy	19100.00
0005435517663	20962	Economy	19100.00
0005434573122	20962	Economy	19100.00
0005435508202	20962	Economy	19100.00
0005435517654	20962	Economy	19100.00
0005432291897	20962	Economy	19100.00
0005435517651	20962	Economy	19100.00
0005435517658	20962	Economy	19100.00
0005435501999	20962	Economy	19100.00
0005435517667	20962	Economy	19100.00
0005435508201	20962	Economy	19100.00
0005435508204	20962	Economy	19100.00
0005435517648	20962	Economy	19100.00
0005435502017	20962	Economy	19100.00
0005435517665	20962	Economy	19100.00
0005435319466	20962	Economy	19100.00
0005435319467	20962	Economy	19100.00
0005435319460	20962	Economy	19100.00
0005435517661	20962	Economy	19100.00
0005435502004	20962	Economy	19100.00
0005435502009	20962	Economy	19100.00
0005432706431	2971	Business	10300.00
0005432706435	2971	Business	10300.00
0005432706422	2971	Economy	3400.00
0005432706414	2971	Economy	3400.00
0005432706437	2971	Economy	3400.00
0005432706419	2971	Economy	3400.00
0005432706430	2971	Economy	3400.00
0005432706412	2971	Economy	3400.00
0005432706421	2971	Economy	3800.00
0005432706436	2971	Economy	3800.00
0005432706432	2971	Economy	3400.00
0005432217737	2971	Economy	3400.00
0005432706427	2971	Economy	3400.00
0005432706428	2971	Economy	3400.00
0005432706418	2971	Economy	3400.00
0005432217738	2971	Economy	3400.00
0005432706429	2971	Economy	3400.00
0005432706433	2971	Economy	3400.00
0005432217739	2971	Economy	3400.00
0005432706417	2971	Economy	3400.00
0005432706415	2971	Economy	3400.00
0005432706420	2971	Economy	3400.00
0005432706424	2971	Economy	3400.00
0005432706413	2971	Economy	3400.00
0005432706426	2971	Economy	3400.00
0005432706423	2971	Economy	3400.00
0005432706416	2971	Economy	3400.00
0005432217736	2971	Economy	3400.00
0005432706434	2971	Economy	3400.00
0005432706425	2971	Economy	3400.00
0005432692660	30069	Business	10300.00
0005433123647	30069	Business	10300.00
0005432880612	30069	Business	10300.00
0005432706330	30069	Business	10300.00
0005432692681	30069	Business	10300.00
0005432692655	30069	Business	10300.00
0005432692662	30069	Business	10300.00
0005432880614	30069	Business	10300.00
0005433123641	30069	Business	10300.00
0005433123643	30069	Business	10300.00
0005432880623	30069	Business	10300.00
0005433123645	30069	Economy	3400.00
0005432692684	30069	Economy	3400.00
0005432880624	30069	Economy	3400.00
0005432880621	30069	Economy	3400.00
0005432692653	30069	Economy	3800.00
0005432880619	30069	Economy	3800.00
0005432880611	30069	Economy	3800.00
0005432880617	30069	Economy	3800.00
0005432692679	30069	Economy	3800.00
0005432692665	30069	Economy	3400.00
0005432692685	30069	Economy	3400.00
0005433123653	30069	Economy	3400.00
0005433123642	30069	Economy	3400.00
0005432692671	30069	Economy	3400.00
0005433123650	30069	Economy	3400.00
0005433123639	30069	Economy	3400.00
0005432706316	30069	Economy	3400.00
0005432880620	30069	Economy	3400.00
0005433194825	30069	Economy	3400.00
0005432706329	30069	Economy	3400.00
0005432692673	30069	Economy	3400.00
0005432692656	30069	Economy	3400.00
0005432692675	30069	Economy	3400.00
0005432880613	30069	Economy	3400.00
0005433123635	30069	Economy	3400.00
0005432692678	30069	Economy	3400.00
0005432880615	30069	Economy	3400.00
0005432692677	30069	Economy	3400.00
0005433123654	30069	Economy	3400.00
0005433123640	30069	Economy	3400.00
0005432692664	30069	Economy	3400.00
0005432880625	30069	Economy	3400.00
0005432692659	30069	Economy	3400.00
0005432880622	30069	Economy	3400.00
0005432692668	30069	Economy	3400.00
0005433123646	30069	Economy	3400.00
0005432692683	30069	Economy	3400.00
0005432880618	30069	Economy	3400.00
0005433123636	30069	Economy	3400.00
0005432692661	30069	Economy	3400.00
0005432692657	30069	Economy	3400.00
0005432692654	30069	Economy	3400.00
0005432692680	30069	Economy	3400.00
0005433123649	30069	Economy	3400.00
0005432692658	30069	Economy	3400.00
0005433194824	30069	Economy	3400.00
0005433123637	30069	Economy	3400.00
0005433123648	30069	Economy	3400.00
0005432692670	30069	Economy	3400.00
0005432692672	30069	Economy	3400.00
0005433123638	30069	Economy	3400.00
0005432706315	30069	Economy	3400.00
0005433123652	30069	Economy	3400.00
0005433123644	30069	Economy	3400.00
0005432692667	30069	Economy	3400.00
0005432692666	30069	Economy	3400.00
0005432706307	30069	Economy	3400.00
0005432692682	30069	Economy	3400.00
0005432706314	30069	Economy	3400.00
0005432692674	30069	Economy	3400.00
0005432692663	30069	Economy	3400.00
0005432692676	30069	Economy	3400.00
0005432880616	30069	Economy	3400.00
0005432692669	30069	Economy	3400.00
0005433123634	30069	Economy	3400.00
0005433123651	30069	Economy	3400.00
0005433123655	30069	Economy	3400.00
0005434988583	23648	Economy	4000.00
0005434979348	23648	Economy	4000.00
0005434979367	23648	Economy	4000.00
0005434979358	23648	Economy	3600.00
0005434979360	23648	Economy	3600.00
0005434979355	23648	Economy	3600.00
0005434988587	23648	Economy	3600.00
0005434979366	23648	Economy	3600.00
0005434979371	23648	Economy	3600.00
0005434979345	23648	Economy	3600.00
0005434979369	23648	Economy	3600.00
0005434988582	23648	Economy	3600.00
0005434988584	23648	Economy	3600.00
0005434979373	23648	Economy	3600.00
0005434979362	23648	Economy	3600.00
0005434979372	23648	Economy	3600.00
0005434979359	23648	Economy	3600.00
0005434979364	23648	Economy	3600.00
0005434979349	23648	Economy	3600.00
0005434988585	23648	Economy	3600.00
0005434979346	23648	Economy	3600.00
0005434979363	23648	Economy	3600.00
0005434979352	23648	Economy	3600.00
0005434979354	23648	Economy	3600.00
0005434979374	23648	Economy	3600.00
0005434979351	23648	Economy	3600.00
0005434979350	23648	Economy	3600.00
0005434979365	23648	Economy	3600.00
0005434979370	23648	Economy	3600.00
0005434979357	23648	Economy	3600.00
0005434988586	23648	Economy	3600.00
0005434979368	23648	Economy	3600.00
0005434979347	23648	Economy	3600.00
0005434979353	23648	Economy	3600.00
0005434988581	23648	Economy	3600.00
0005434979361	23648	Economy	3600.00
0005434988580	23648	Economy	3600.00
0005434979356	23648	Economy	3600.00
0005434302397	10276	Economy	19700.00
0005434302396	10276	Economy	19700.00
0005434302395	10276	Economy	19700.00
0005434302398	10276	Economy	19700.00
0005433113505	19593	Economy	19700.00
0005435068399	3559	Business	26900.00
0005435068400	3559	Business	26900.00
0005435068378	3559	Business	26900.00
0005435068418	3559	Business	26900.00
0005435068398	3559	Economy	9000.00
0005435068388	3559	Economy	9000.00
0005435068382	3559	Economy	9000.00
0005435068371	3559	Economy	9000.00
0005435068376	3559	Economy	9000.00
0005435068374	3559	Economy	9000.00
0005435068402	3559	Economy	9000.00
0005435068372	3559	Economy	9900.00
0005435718856	3559	Economy	9900.00
0005435068395	3559	Economy	9900.00
0005435068419	3559	Economy	9900.00
0005435068403	3559	Economy	9000.00
0005435068373	3559	Economy	9000.00
0005435068396	3559	Economy	9000.00
0005435068413	3559	Economy	9000.00
0005435068407	3559	Economy	9000.00
0005435718857	3559	Economy	9000.00
0005435068410	3559	Economy	9000.00
0005435068392	3559	Economy	9000.00
0005435068412	3559	Economy	9000.00
0005435068417	3559	Economy	9000.00
0005435068381	3559	Economy	9000.00
0005435068408	3559	Economy	9000.00
0005435068397	3559	Economy	9000.00
0005435068420	3559	Economy	9000.00
0005435068389	3559	Economy	9000.00
0005435068377	3559	Economy	9000.00
0005435068391	3559	Economy	9000.00
0005435068415	3559	Economy	9000.00
0005435068386	3559	Economy	9000.00
0005435718860	3559	Economy	9000.00
0005435068375	3559	Economy	9000.00
0005435718861	3559	Economy	9000.00
0005435068379	3559	Economy	9000.00
0005435068414	3559	Economy	9000.00
0005435068383	3559	Economy	9000.00
0005435068390	3559	Economy	9000.00
0005435718862	3559	Economy	9000.00
0005435068406	3559	Economy	9000.00
0005435068393	3559	Economy	9000.00
0005435068387	3559	Economy	9000.00
0005435068401	3559	Economy	9000.00
0005435068411	3559	Economy	9000.00
0005435068409	3559	Economy	9000.00
0005435068416	3559	Economy	9000.00
0005435068384	3559	Economy	9000.00
0005435718858	3559	Economy	9000.00
0005435068394	3559	Economy	9000.00
0005435068421	3559	Economy	9000.00
0005435068405	3559	Economy	9000.00
0005435068385	3559	Economy	9000.00
0005435068404	3559	Economy	9000.00
0005435068422	3559	Economy	9000.00
0005435068380	3559	Economy	9000.00
0005435718859	3559	Economy	9000.00
0005435925120	15305	Business	26900.00
0005435925099	15305	Business	26900.00
0005435925117	15305	Economy	9000.00
0005435925114	15305	Economy	9000.00
0005435925101	15305	Economy	9900.00
0005435925102	15305	Economy	9000.00
0005435925107	15305	Economy	9000.00
0005435925103	15305	Economy	9000.00
0005435925098	15305	Economy	9000.00
0005435925111	15305	Economy	9000.00
0005435925115	15305	Economy	9000.00
0005435925113	15305	Economy	9000.00
0005435925118	15305	Economy	9000.00
0005435925108	15305	Economy	9000.00
0005435925116	15305	Economy	9000.00
0005435925112	15305	Economy	9000.00
0005435925097	15305	Economy	9000.00
0005435925109	15305	Economy	9000.00
0005435939862	15305	Economy	9000.00
0005435925106	15305	Economy	9000.00
0005435925110	15305	Economy	9000.00
0005435925096	15305	Economy	9000.00
0005435925105	15305	Economy	9000.00
0005435925119	15305	Economy	9000.00
0005435925104	15305	Economy	9000.00
0005435925100	15305	Economy	9000.00
0005432658563	18200	Economy	5900.00
0005432659678	18200	Economy	5900.00
0005432658562	18200	Economy	5900.00
0005432660790	18200	Economy	5900.00
0005432659677	18200	Economy	5900.00
0005432901308	240	Business	20000.00
0005432157466	240	Economy	6700.00
0005432157465	240	Economy	6700.00
0005432901309	240	Economy	6700.00
0005432207624	239	Business	20000.00
0005432288941	239	Business	20000.00
0005432261314	239	Business	20000.00
0005432817082	239	Business	20000.00
0005432261299	239	Business	20000.00
0005432261301	239	Business	20000.00
0005432261279	239	Business	20000.00
0005432817073	239	Business	20000.00
0005432261294	239	Business	20000.00
0005432261276	239	Business	20000.00
0005432261303	239	Business	20000.00
0005432261297	239	Economy	7300.00
0005432817074	239	Economy	7300.00
0005432261307	239	Economy	7300.00
0005432207625	239	Economy	6700.00
0005432261317	239	Economy	6700.00
0005434153517	239	Economy	6700.00
0005432261286	239	Economy	6700.00
0005432261285	239	Economy	6700.00
0005432817063	239	Economy	6700.00
0005432817088	239	Economy	6700.00
0005432261305	239	Economy	6700.00
0005432261291	239	Economy	6700.00
0005432261310	239	Economy	6700.00
0005432817077	239	Economy	6700.00
0005432817079	239	Economy	6700.00
0005432261306	239	Economy	6700.00
0005432817081	239	Economy	6700.00
0005432817087	239	Economy	6700.00
0005432207626	239	Economy	6700.00
0005432261309	239	Economy	6700.00
0005432261277	239	Economy	6700.00
0005432817084	239	Economy	6700.00
0005432288943	239	Economy	6700.00
0005432261300	239	Economy	6700.00
0005432261281	239	Economy	6700.00
0005432817078	239	Economy	6700.00
0005432817067	239	Economy	6700.00
0005432817070	239	Economy	6700.00
0005432261296	239	Economy	6700.00
0005432261319	239	Economy	6700.00
0005432261293	239	Economy	6700.00
0005432261290	239	Economy	6700.00
0005432261280	239	Economy	6700.00
0005432261316	239	Economy	6700.00
0005432817080	239	Economy	6700.00
0005432817085	239	Economy	7300.00
0005432817072	239	Economy	7300.00
0005432288942	239	Economy	6700.00
0005432261292	239	Economy	6700.00
0005432261315	239	Economy	7300.00
0005432817069	239	Economy	6700.00
0005432817061	239	Economy	6700.00
0005432261311	239	Economy	6700.00
0005432817076	239	Economy	6700.00
0005432261320	239	Economy	6700.00
0005432261283	239	Economy	6700.00
0005432261304	239	Economy	6700.00
0005432817068	239	Economy	6700.00
0005432817059	239	Economy	6700.00
0005432817066	239	Economy	6700.00
0005432817062	239	Economy	6700.00
0005432261287	239	Economy	6700.00
0005432261288	239	Economy	6700.00
0005432817060	239	Economy	6700.00
0005432261321	239	Economy	6700.00
0005432817071	239	Economy	6700.00
0005432817064	239	Economy	6700.00
0005432261298	239	Economy	6700.00
0005432817086	239	Economy	6700.00
0005432261318	239	Economy	6700.00
0005432261313	239	Economy	6700.00
0005432261308	239	Economy	6700.00
0005432261278	239	Economy	6700.00
0005432261284	239	Economy	6700.00
0005432261312	239	Economy	6700.00
0005432261282	239	Economy	6700.00
0005432288940	239	Economy	6700.00
0005432817065	239	Economy	6700.00
0005434153516	239	Economy	6700.00
0005432261302	239	Economy	6700.00
0005432261289	239	Economy	6700.00
0005432261295	239	Economy	6700.00
0005432817083	239	Economy	6700.00
0005432817075	239	Economy	6700.00
0005432019910	8069	Business	20000.00
0005433101404	8069	Business	20000.00
0005432019913	8069	Business	20000.00
0005432919572	8069	Business	20000.00
0005432919568	8069	Business	20000.00
0005433101426	8069	Business	20000.00
0005432751481	8069	Business	20000.00
0005432919582	8069	Business	20000.00
0005432019898	8069	Business	20000.00
0005432919579	8069	Business	20000.00
0005433101411	8069	Business	20000.00
0005432919569	8069	Business	20000.00
0005432677521	8069	Business	20000.00
0005432019892	8069	Business	20000.00
0005433101444	8069	Business	20000.00
0005432919571	8069	Business	20000.00
0005432044487	8069	Business	20000.00
0005433101425	8069	Business	20000.00
0005433101407	8069	Business	20000.00
0005433101402	8069	Business	20000.00
0005433101417	8069	Business	20000.00
0005432019893	8069	Business	20000.00
0005432919586	8069	Economy	7300.00
0005433101394	8069	Economy	7300.00
0005433101398	8069	Economy	7300.00
0005432391960	8069	Economy	7300.00
0005433101415	8069	Economy	7300.00
0005433101431	8069	Economy	6700.00
0005432919570	8069	Economy	6700.00
0005432753258	8069	Economy	6700.00
0005432919575	8069	Economy	6700.00
0005433101439	8069	Economy	6700.00
0005432019912	8069	Economy	6700.00
0005433101450	8069	Economy	6700.00
0005433101416	8069	Economy	6700.00
0005432044488	8069	Economy	6700.00
0005432919574	8069	Economy	6700.00
0005433101446	8069	Economy	6700.00
0005433101451	8069	Economy	6700.00
0005433101391	8069	Economy	6700.00
0005432919576	8069	Economy	6700.00
0005432019900	8069	Economy	6700.00
0005433101423	8069	Economy	6700.00
0005432677523	8069	Economy	6700.00
0005432919580	8069	Economy	6700.00
0005432044486	8069	Economy	6700.00
0005433101418	8069	Economy	6700.00
0005433101453	8069	Economy	6700.00
0005432019889	8069	Economy	6700.00
0005433101410	8069	Economy	6700.00
0005433101401	8069	Economy	6700.00
0005432919567	8069	Economy	6700.00
0005433101409	8069	Economy	6700.00
0005433101438	8069	Economy	6700.00
0005432019902	8069	Economy	6700.00
0005433101406	8069	Economy	6700.00
0005432019891	8069	Economy	6700.00
0005432045587	8069	Economy	6700.00
0005433101424	8069	Economy	6700.00
0005432753256	8069	Economy	6700.00
0005433101422	8069	Economy	6700.00
0005433101435	8069	Economy	6700.00
0005433101427	8069	Economy	6700.00
0005432019899	8069	Economy	6700.00
0005432751482	8069	Economy	6700.00
0005432019888	8069	Economy	6700.00
0005432019894	8069	Economy	6700.00
0005433101433	8069	Economy	6700.00
0005432677520	8069	Economy	6700.00
0005433101420	8069	Economy	6700.00
0005433101436	8069	Economy	7300.00
0005433101396	8069	Economy	7300.00
0005432019904	8069	Economy	7300.00
0005433101437	8069	Economy	6700.00
0005433101432	8069	Economy	7300.00
0005432677522	8069	Economy	6700.00
0005432753255	8069	Economy	6700.00
0005432019903	8069	Economy	6700.00
0005433101440	8069	Economy	6700.00
0005432919578	8069	Economy	7300.00
0005432919573	8069	Economy	6700.00
0005432919581	8069	Economy	6700.00
0005433101448	8069	Economy	6700.00
0005433101441	8069	Economy	6700.00
0005433101454	8069	Economy	6700.00
0005433101413	8069	Economy	6700.00
0005433101414	8069	Economy	6700.00
0005432919584	8069	Economy	6700.00
0005433101419	8069	Economy	6700.00
0005433101455	8069	Economy	6700.00
0005433101408	8069	Economy	6700.00
0005433101405	8069	Economy	6700.00
0005433101456	8069	Economy	6700.00
0005433101421	8069	Economy	6700.00
0005432019905	8069	Economy	6700.00
0005432019901	8069	Economy	6700.00
0005433101430	8069	Economy	6700.00
0005432019909	8069	Economy	6700.00
0005433101403	8069	Economy	6700.00
0005433101443	8069	Economy	6700.00
0005432391959	8069	Economy	6700.00
0005433101434	8069	Economy	6700.00
0005432019897	8069	Economy	6700.00
0005432751483	8069	Economy	6700.00
0005432019908	8069	Economy	6700.00
0005433101447	8069	Economy	6700.00
0005432019895	8069	Economy	6700.00
0005433101393	8069	Economy	6700.00
0005433101442	8069	Economy	6700.00
0005432919583	8069	Economy	6700.00
0005432919587	8069	Economy	6700.00
0005432019896	8069	Economy	6700.00
0005433101399	8069	Economy	6700.00
0005432019906	8069	Economy	6700.00
0005433101400	8069	Economy	6700.00
0005432753257	8069	Economy	6700.00
0005433101449	8069	Economy	6700.00
0005433101445	8069	Economy	6700.00
0005433101395	8069	Economy	6700.00
0005432919585	8069	Economy	6700.00
0005432019907	8069	Economy	6700.00
0005433101458	8069	Economy	6700.00
0005433101397	8069	Economy	6700.00
0005432019911	8069	Economy	6700.00
0005433101457	8069	Economy	6700.00
0005432019914	8069	Economy	6700.00
0005432045588	8069	Economy	6700.00
0005432019890	8069	Economy	6700.00
0005433101429	8069	Economy	6700.00
0005433101452	8069	Economy	6700.00
0005433101428	8069	Economy	6700.00
0005432919577	8069	Economy	6700.00
0005433101392	8069	Economy	6700.00
0005433101412	8069	Economy	6700.00
0005432019915	8069	Economy	6700.00
0005432901378	8068	Business	20000.00
0005432901370	8068	Business	20000.00
0005432901382	8068	Business	20000.00
0005432901374	8068	Business	20000.00
0005432002049	8068	Business	20000.00
0005432901381	8068	Business	20000.00
0005432901375	8068	Economy	6700.00
0005432901372	8068	Economy	6700.00
0005432901380	8068	Economy	6700.00
0005432901377	8068	Economy	6700.00
0005432901383	8068	Economy	6700.00
0005432901368	8068	Economy	6700.00
0005432901366	8068	Economy	6700.00
0005432901373	8068	Economy	6700.00
0005432901367	8068	Economy	6700.00
0005432816958	8068	Economy	6700.00
0005432901376	8068	Economy	7300.00
0005432816959	8068	Economy	6700.00
0005432901379	8068	Economy	6700.00
0005432002048	8068	Economy	6700.00
0005432901365	8068	Economy	6700.00
0005432901371	8068	Economy	6700.00
0005432901369	8068	Economy	6700.00
0005433870701	9640	Economy	6900.00
0005433870700	9640	Economy	6900.00
0005433870702	9640	Economy	6900.00
0005434175696	32365	Economy	6900.00
0005434175695	32365	Economy	6900.00
0005434175694	32365	Economy	6900.00
0005434175697	32365	Economy	6900.00
0005434426229	3495	Business	35000.00
0005435625929	3495	Business	35000.00
0005434937882	3495	Business	35000.00
0005435125840	3495	Business	35000.00
0005434877021	3495	Business	35000.00
0005434876979	3495	Business	35000.00
0005434877036	3495	Business	35000.00
0005434876981	3495	Business	35000.00
0005434876982	3495	Business	35000.00
0005434876992	3495	Business	35000.00
0005434877020	3495	Business	35000.00
0005435625944	3495	Business	35000.00
0005435125850	3495	Business	35000.00
0005434876969	3495	Business	35000.00
0005434876946	3495	Business	35000.00
0005435125834	3495	Business	35000.00
0005435125816	3495	Business	35000.00
0005434877002	3495	Business	35000.00
0005434426215	3495	Business	35000.00
0005434876988	3495	Business	35000.00
0005432799091	3495	Business	35000.00
0005434876960	3495	Comfort	19900.00
0005434877005	3495	Comfort	19900.00
0005434877033	3495	Comfort	19900.00
0005434937878	3495	Comfort	19900.00
0005434876966	3495	Comfort	19900.00
0005434877008	3495	Comfort	19900.00
0005434877009	3495	Comfort	19900.00
0005434426217	3495	Comfort	19900.00
0005434877031	3495	Comfort	19900.00
0005432799070	3495	Comfort	19900.00
0005432613808	3495	Comfort	19900.00
0005435125851	3495	Comfort	19900.00
0005432611658	3495	Comfort	19900.00
0005434877018	3495	Comfort	19900.00
0005434426214	3495	Comfort	19900.00
0005434877030	3495	Comfort	19900.00
0005435625939	3495	Comfort	19900.00
0005432799081	3495	Comfort	19900.00
0005432799084	3495	Comfort	19900.00
0005435625934	3495	Comfort	19900.00
0005434426208	3495	Comfort	19900.00
0005432611656	3495	Comfort	19900.00
0005434877006	3495	Comfort	19900.00
0005434876991	3495	Comfort	19900.00
0005434426216	3495	Comfort	19900.00
0005434876955	3495	Comfort	19900.00
0005435125843	3495	Comfort	19900.00
0005434876967	3495	Comfort	19900.00
0005434876949	3495	Comfort	19900.00
0005435125817	3495	Comfort	19900.00
0005432799079	3495	Economy	11700.00
0005434426220	3495	Economy	11700.00
0005435125818	3495	Economy	11700.00
0005432799075	3495	Economy	11700.00
0005434877027	3495	Economy	11700.00
0005434937873	3495	Economy	11700.00
0005435125846	3495	Economy	11700.00
0005434877035	3495	Economy	11700.00
0005434877003	3495	Economy	11700.00
0005434426227	3495	Economy	11700.00
0005435625933	3495	Economy	11700.00
0005434876994	3495	Economy	11700.00
0005435625942	3495	Economy	11700.00
0005432799089	3495	Economy	11700.00
0005432799073	3495	Economy	11700.00
0005435125832	3495	Economy	11700.00
0005434937875	3495	Economy	11700.00
0005434877039	3495	Economy	11700.00
0005434937874	3495	Economy	11700.00
0005434876944	3495	Economy	11700.00
0005434877037	3495	Economy	11700.00
0005435625937	3495	Economy	11700.00
0005434877012	3495	Economy	11700.00
0005435125819	3495	Economy	11700.00
0005434937876	3495	Economy	11700.00
0005435625948	3495	Economy	11700.00
0005435625941	3495	Economy	11700.00
0005434426213	3495	Economy	11700.00
0005432188563	3495	Economy	11700.00
0005434877016	3495	Economy	11700.00
0005435625945	3495	Economy	11700.00
0005435625936	3495	Economy	11700.00
0005435625938	3495	Economy	11700.00
0005434876974	3495	Economy	11700.00
0005432611655	3495	Economy	11700.00
0005435125844	3495	Economy	11700.00
0005435125839	3495	Economy	11700.00
0005434877038	3495	Economy	11700.00
0005434877014	3495	Economy	11700.00
0005435125815	3495	Economy	11700.00
0005434876952	3495	Economy	11700.00
0005434877011	3495	Economy	11700.00
0005434876963	3495	Economy	11700.00
0005435125833	3495	Economy	11700.00
0005435125847	3495	Economy	11700.00
0005435125849	3495	Economy	11700.00
0005432613806	3495	Economy	11700.00
0005435125821	3495	Economy	11700.00
0005432613807	3495	Economy	12800.00
0005435125836	3495	Economy	12800.00
0005435625943	3495	Economy	11700.00
0005434426218	3495	Economy	12800.00
0005434426212	3495	Economy	11700.00
0005435125820	3495	Economy	12800.00
0005434876996	3495	Economy	12800.00
0005434937890	3495	Economy	11700.00
0005432188565	3495	Economy	11700.00
0005434876987	3495	Economy	11700.00
0005435125830	3495	Economy	11700.00
0005432799071	3495	Economy	11700.00
0005434876954	3495	Economy	11700.00
0005434426206	3495	Economy	11700.00
0005434937884	3495	Economy	11700.00
0005435125837	3495	Economy	11700.00
0005434877013	3495	Economy	11700.00
0005434876953	3495	Economy	11700.00
0005434877032	3495	Economy	11700.00
0005435125835	3495	Economy	11700.00
0005434426232	3495	Economy	11700.00
0005435125822	3495	Economy	11700.00
0005434937872	3495	Economy	11700.00
0005434876956	3495	Economy	11700.00
0005434426234	3495	Economy	11700.00
0005434937885	3495	Economy	11700.00
0005434876997	3495	Economy	11700.00
0005434876968	3495	Economy	11700.00
0005434876984	3495	Economy	11700.00
0005432799069	3495	Economy	11700.00
0005435125848	3495	Economy	11700.00
0005434876962	3495	Economy	11700.00
0005435625946	3495	Economy	11700.00
0005432799095	3495	Economy	11700.00
0005434876978	3495	Economy	11700.00
0005435125841	3495	Economy	11700.00
0005434876973	3495	Economy	11700.00
0005434876945	3495	Economy	11700.00
0005432799077	3495	Economy	11700.00
0005432611657	3495	Economy	11700.00
0005434876950	3495	Economy	11700.00
0005435125845	3495	Economy	11700.00
0005432799086	3495	Economy	11700.00
0005435625932	3495	Economy	11700.00
0005434937889	3495	Economy	11700.00
0005435125827	3495	Economy	11700.00
0005434877000	3495	Economy	11700.00
0005434877010	3495	Economy	11700.00
0005434876957	3495	Economy	11700.00
0005434937880	3495	Economy	11700.00
0005435125823	3495	Economy	11700.00
0005435625930	3495	Economy	11700.00
0005434877024	3495	Economy	11700.00
0005434876976	3495	Economy	11700.00
0005434426225	3495	Economy	11700.00
0005434877029	3495	Economy	11700.00
0005432799080	3495	Economy	11700.00
0005432799074	3495	Economy	11700.00
0005434426209	3495	Economy	11700.00
0005432799087	3495	Economy	11700.00
0005434877034	3495	Economy	11700.00
0005432188564	3495	Economy	11700.00
0005432183437	3495	Economy	11700.00
0005434876977	3495	Economy	11700.00
0005434426235	3495	Economy	11700.00
0005434426207	3495	Economy	11700.00
0005434937891	3495	Economy	11700.00
0005435125831	3495	Economy	11700.00
0005434876983	3495	Economy	11700.00
0005434876971	3495	Economy	11700.00
0005434937886	3495	Economy	11700.00
0005434876985	3495	Economy	11700.00
0005434426223	3495	Economy	11700.00
0005434426221	3495	Economy	11700.00
0005435625935	3495	Economy	11700.00
0005434876964	3495	Economy	12800.00
0005432799078	3495	Economy	12800.00
0005434876943	3495	Economy	12800.00
0005434876970	3495	Economy	11700.00
0005432799076	3495	Economy	12800.00
0005434426233	3495	Economy	11700.00
0005435125838	3495	Economy	11700.00
0005435125829	3495	Economy	11700.00
0005435125814	3495	Economy	11700.00
0005435625947	3495	Economy	11700.00
0005434876993	3495	Economy	11700.00
0005432799088	3495	Economy	11700.00
0005435125826	3495	Economy	11700.00
0005434876986	3495	Economy	11700.00
0005434426205	3495	Economy	11700.00
0005434876948	3495	Economy	11700.00
0005434426230	3495	Economy	11700.00
0005434937881	3495	Economy	11700.00
0005434937877	3495	Economy	11700.00
0005435125824	3495	Economy	11700.00
0005434876975	3495	Economy	11700.00
0005432799090	3495	Economy	11700.00
0005435625928	3495	Economy	11700.00
0005434426224	3495	Economy	11700.00
0005434877025	3495	Economy	11700.00
0005434876965	3495	Economy	11700.00
0005434937879	3495	Economy	11700.00
0005434876961	3495	Economy	11700.00
0005434876980	3495	Economy	11700.00
0005434426231	3495	Economy	11700.00
0005434877022	3495	Economy	11700.00
0005432799082	3495	Economy	11700.00
0005435125855	3495	Economy	11700.00
0005434937883	3495	Economy	11700.00
0005434876999	3495	Economy	11700.00
0005432799097	3495	Economy	11700.00
0005434877017	3495	Economy	11700.00
0005434876990	3495	Economy	11700.00
0005432799093	3495	Economy	11700.00
0005434876972	3495	Economy	11700.00
0005435625940	3495	Economy	11700.00
0005434877026	3495	Economy	11700.00
0005434876995	3495	Economy	11700.00
0005432183438	3495	Economy	11700.00
0005434876959	3495	Economy	11700.00
0005435125828	3495	Economy	11700.00
0005434877019	3495	Economy	11700.00
0005434426219	3495	Economy	11700.00
0005432799096	3495	Economy	11700.00
0005434426211	3495	Economy	11700.00
0005435914681	3495	Economy	11700.00
0005432799083	3495	Economy	11700.00
0005434426222	3495	Economy	11700.00
0005434876947	3495	Economy	11700.00
0005434877015	3495	Economy	11700.00
0005434877001	3495	Economy	11700.00
0005434877004	3495	Economy	11700.00
0005434876998	3495	Economy	11700.00
0005434937888	3495	Economy	11700.00
0005434876958	3495	Economy	11700.00
0005432799094	3495	Economy	11700.00
0005434877023	3495	Economy	11700.00
0005435125842	3495	Economy	11700.00
0005432799072	3495	Economy	11700.00
0005434426226	3495	Economy	11700.00
0005435125825	3495	Economy	11700.00
0005432183436	3495	Economy	11700.00
0005435125852	3495	Economy	11700.00
0005434877007	3495	Economy	11700.00
0005434877028	3495	Economy	11700.00
0005432799092	3495	Economy	11700.00
0005434426210	3495	Economy	11700.00
0005435625931	3495	Economy	11700.00
0005434426228	3495	Economy	11700.00
0005434937887	3495	Economy	11700.00
0005435125854	3495	Economy	11700.00
0005434876951	3495	Economy	11700.00
0005435125853	3495	Economy	11700.00
0005432799085	3495	Economy	11700.00
0005434876989	3495	Economy	11700.00
0005432059478	14557	Business	35000.00
0005435902467	14557	Business	35000.00
0005435902457	14557	Business	35000.00
0005434876696	14557	Business	35000.00
0005435902459	14557	Business	35000.00
0005435913866	14557	Business	35000.00
0005434426097	14557	Business	35000.00
0005432799047	14557	Comfort	19900.00
0005435902464	14557	Comfort	19900.00
0005432799046	14557	Comfort	19900.00
0005435902460	14557	Economy	11700.00
0005435913869	14557	Economy	11700.00
0005435913867	14557	Economy	11700.00
0005435902470	14557	Economy	11700.00
0005434937815	14557	Economy	11700.00
0005432059477	14557	Economy	11700.00
0005435902474	14557	Economy	11700.00
0005434426098	14557	Economy	11700.00
0005435902466	14557	Economy	11700.00
0005435902465	14557	Economy	11700.00
0005435902469	14557	Economy	11700.00
0005435902468	14557	Economy	11700.00
0005435902472	14557	Economy	11700.00
0005435913873	14557	Economy	11700.00
0005432798989	14557	Economy	11700.00
0005435913868	14557	Economy	11700.00
0005432798988	14557	Economy	11700.00
0005434937814	14557	Economy	11700.00
0005435902458	14557	Economy	11700.00
0005435913872	14557	Economy	11700.00
0005435902473	14557	Economy	11700.00
0005435902463	14557	Economy	11700.00
0005435902471	14557	Economy	11700.00
0005435902461	14557	Economy	11700.00
0005434426096	14557	Economy	11700.00
0005434426092	14557	Economy	11700.00
0005435913874	14557	Economy	11700.00
0005435913871	14557	Economy	11700.00
0005435902462	14557	Economy	11700.00
0005435913870	14557	Economy	11700.00
0005434325496	3604	Economy	16300.00
0005434325491	3604	Economy	14800.00
0005434325495	3604	Economy	14800.00
0005434325498	3604	Economy	14800.00
0005434325492	3604	Economy	14800.00
0005434312291	3604	Economy	14800.00
0005434312290	3604	Economy	14800.00
0005434325503	3604	Economy	14800.00
0005434325493	3604	Economy	14800.00
0005434325494	3604	Economy	14800.00
0005434325502	3604	Economy	14800.00
0005434312289	3604	Economy	14800.00
0005434325497	3604	Economy	14800.00
0005434325500	3604	Economy	14800.00
0005434325499	3604	Economy	14800.00
0005434325501	3604	Economy	14800.00
0005435889814	15616	Economy	14800.00
0005435889816	15616	Economy	14800.00
0005435889815	15616	Economy	14800.00
0005435889818	15616	Economy	14800.00
0005435889817	15616	Economy	14800.00
0005435957511	665	Economy	4500.00
0005435957501	665	Economy	4100.00
0005435957510	665	Economy	4100.00
0005435957513	665	Economy	4100.00
0005435957505	665	Economy	4100.00
0005435957509	665	Economy	4100.00
0005435957512	665	Economy	4100.00
0005435957504	665	Economy	4100.00
0005435957508	665	Economy	4100.00
0005435957499	665	Economy	4100.00
0005435957500	665	Economy	4100.00
0005435957503	665	Economy	4100.00
0005435957506	665	Economy	4100.00
0005435957502	665	Economy	4100.00
0005435957507	665	Economy	4100.00
0005433420290	15170	Economy	4100.00
0005433420287	15170	Economy	4100.00
0005433420286	15170	Economy	4100.00
0005433420291	15170	Economy	4100.00
0005433420288	15170	Economy	4100.00
0005433420285	15170	Economy	4100.00
0005433420292	15170	Economy	4100.00
0005433420289	15170	Economy	4100.00
0005435629388	8940	Economy	10400.00
0005434247111	16060	Economy	10400.00
0005434247112	16060	Economy	10400.00
0005434247113	16060	Economy	10400.00
0005435163165	4423	Economy	13400.00
0005435163159	4423	Economy	12200.00
0005435163164	4423	Economy	12200.00
0005435163158	4423	Economy	12200.00
0005435163160	4423	Economy	12200.00
0005435163156	4423	Economy	12200.00
0005435163162	4423	Economy	12200.00
0005435163157	4423	Economy	12200.00
0005435163163	4423	Economy	12200.00
0005435163161	4423	Economy	12200.00
0005435797283	2844	Business	12600.00
0005435797293	2844	Business	12600.00
0005435797282	2844	Economy	4200.00
0005435797288	2844	Economy	4200.00
0005435797291	2844	Economy	4200.00
0005435797289	2844	Economy	4200.00
0005435797287	2844	Economy	4600.00
0005435797285	2844	Economy	4200.00
0005435797284	2844	Economy	4200.00
0005435797290	2844	Economy	4200.00
0005435797281	2844	Economy	4200.00
0005435797292	2844	Economy	4200.00
0005435797280	2844	Economy	4200.00
0005435797286	2844	Economy	4200.00
0005433404712	29295	Economy	4200.00
0005433404708	29295	Economy	4200.00
0005433404714	29295	Economy	4600.00
0005433404709	29295	Economy	4200.00
0005433404711	29295	Economy	4200.00
0005433404713	29295	Economy	4200.00
0005433404710	29295	Economy	4200.00
0005433404707	29295	Economy	4200.00
0005433404706	29295	Economy	4200.00
0005435376313	5759	Economy	6800.00
0005434947909	5732	Economy	6800.00
0005434947910	5732	Economy	6800.00
0005434947906	5732	Economy	6800.00
0005434947907	5732	Economy	6800.00
0005434947905	5732	Economy	6800.00
0005434947908	5732	Economy	6800.00
0005434947912	5732	Economy	6800.00
0005434947913	5732	Economy	6800.00
0005434947904	5732	Economy	6800.00
0005434947911	5732	Economy	6800.00
0005435376321	16415	Economy	6800.00
0005435376319	16415	Economy	6800.00
0005435376320	16415	Economy	6800.00
0005433960088	6940	Business	21400.00
0005433960139	6940	Business	21400.00
0005433960097	6940	Business	21400.00
0005433960090	6940	Business	21400.00
0005433960085	6940	Economy	7100.00
0005433960126	6940	Economy	7100.00
0005433960098	6940	Economy	7100.00
0005433960112	6940	Economy	7100.00
0005433960140	6940	Economy	7100.00
0005433960138	6940	Economy	7100.00
0005433960095	6940	Economy	7800.00
0005433960094	6940	Economy	7800.00
0005433960102	6940	Economy	7800.00
0005433960125	6940	Economy	7800.00
0005433960089	6940	Economy	7100.00
0005433960083	6940	Economy	7100.00
0005433960091	6940	Economy	7100.00
0005433960111	6940	Economy	7100.00
0005433960137	6940	Economy	7100.00
0005433960116	6940	Economy	7100.00
0005433960119	6940	Economy	7100.00
0005433960100	6940	Economy	7100.00
0005433960130	6940	Economy	7100.00
0005433960092	6940	Economy	7100.00
0005433960135	6940	Economy	7100.00
0005433960104	6940	Economy	7100.00
0005433960141	6940	Economy	7100.00
0005433960110	6940	Economy	7100.00
0005433960134	6940	Economy	7100.00
0005433960136	6940	Economy	7100.00
0005433960131	6940	Economy	7100.00
0005433960121	6940	Economy	7100.00
0005433960132	6940	Economy	7100.00
0005433960118	6940	Economy	7100.00
0005433960133	6940	Economy	7100.00
0005433960108	6940	Economy	7100.00
0005433960087	6940	Economy	7100.00
0005433960096	6940	Economy	7100.00
0005433960115	6940	Economy	7100.00
0005433960084	6940	Economy	7100.00
0005433960109	6940	Economy	7100.00
0005433960082	6940	Economy	7100.00
0005433960107	6940	Economy	7100.00
0005433960114	6940	Economy	7100.00
0005433960093	6940	Economy	7100.00
0005433960086	6940	Economy	7100.00
0005433960105	6940	Economy	7100.00
0005433960120	6940	Economy	7100.00
0005433960122	6940	Economy	7100.00
0005433960099	6940	Economy	7100.00
0005433960113	6940	Economy	7100.00
0005433960129	6940	Economy	7100.00
0005433960123	6940	Economy	7100.00
0005433960103	6940	Economy	7100.00
0005433960106	6940	Economy	7100.00
0005433960127	6940	Economy	7100.00
0005433960128	6940	Economy	7100.00
0005433960101	6940	Economy	7100.00
0005433960117	6940	Economy	7100.00
0005433960124	6940	Economy	7100.00
0005435082673	26137	Economy	3900.00
0005435082671	26137	Economy	3900.00
0005435082670	26137	Economy	3900.00
0005435082676	26137	Economy	3900.00
0005435082674	26137	Economy	3900.00
0005435082677	26137	Economy	3900.00
0005435082675	26137	Economy	3900.00
0005435082672	26137	Economy	3900.00
0005434244577	5073	Business	18000.00
0005434244595	5073	Business	18000.00
0005434244579	5073	Business	18000.00
0005434244588	5073	Business	18000.00
0005434244591	5073	Business	18000.00
0005434244601	5073	Business	18000.00
0005434244581	5073	Business	18000.00
0005434244590	5073	Economy	6600.00
0005434244573	5073	Economy	6600.00
0005434244594	5073	Economy	6000.00
0005434244598	5073	Economy	6000.00
0005434244589	5073	Economy	6000.00
0005434244584	5073	Economy	6000.00
0005434244603	5073	Economy	6000.00
0005434244575	5073	Economy	6000.00
0005434244596	5073	Economy	6000.00
0005434244585	5073	Economy	6000.00
0005434244600	5073	Economy	6000.00
0005432166858	5073	Economy	6000.00
0005434244592	5073	Economy	6000.00
0005432166857	5073	Economy	6000.00
0005434244574	5073	Economy	6000.00
0005434244580	5073	Economy	6600.00
0005434244602	5073	Economy	6000.00
0005434244576	5073	Economy	6000.00
0005434244578	5073	Economy	6000.00
0005434244586	5073	Economy	6000.00
0005434244583	5073	Economy	6000.00
0005434244597	5073	Economy	6000.00
0005432166856	5073	Economy	6000.00
0005434244593	5073	Economy	6000.00
0005432166859	5073	Economy	6000.00
0005434244587	5073	Economy	6000.00
0005434244582	5073	Economy	6000.00
0005434244599	5073	Economy	6000.00
0005433784470	5074	Business	18000.00
0005433784467	5074	Business	18000.00
0005433613727	5074	Business	18000.00
0005433784445	5074	Business	18000.00
0005433613758	5074	Business	18000.00
0005432145085	5074	Business	18000.00
0005433613704	5074	Business	18000.00
0005433784453	5074	Business	18000.00
0005432104927	5074	Business	18000.00
0005433613739	5074	Business	18000.00
0005432104939	5074	Business	18000.00
0005433613731	5074	Business	18000.00
0005433613751	5074	Business	18000.00
0005433613732	5074	Business	18000.00
0005433613734	5074	Business	18000.00
0005433784450	5074	Business	18000.00
0005433613720	5074	Business	18000.00
0005432104918	5074	Business	18000.00
0005433613689	5074	Business	18000.00
0005433784463	5074	Business	18000.00
0005433613710	5074	Business	18000.00
0005433613749	5074	Business	18000.00
0005433613752	5074	Business	18000.00
0005433613717	5074	Business	18000.00
0005432666359	5074	Business	18000.00
0005432665248	5074	Business	18000.00
0005433613721	5074	Business	18000.00
0005432665247	5074	Business	18000.00
0005433613737	5074	Economy	6600.00
0005433613707	5074	Economy	6600.00
0005433613742	5074	Economy	6600.00
0005432104913	5074	Economy	6600.00
0005433784471	5074	Economy	6600.00
0005432104923	5074	Economy	6600.00
0005433784459	5074	Economy	6000.00
0005433613696	5074	Economy	6000.00
0005433613733	5074	Economy	6000.00
0005433784449	5074	Economy	6000.00
0005433784457	5074	Economy	6000.00
0005432667426	5074	Economy	6000.00
0005432104910	5074	Economy	6000.00
0005432104914	5074	Economy	6000.00
0005432104915	5074	Economy	6000.00
0005433784442	5074	Economy	6000.00
0005433613702	5074	Economy	6000.00
0005432104950	5074	Economy	6000.00
0005432104922	5074	Economy	6000.00
0005432104934	5074	Economy	6000.00
0005432667427	5074	Economy	6000.00
0005433613698	5074	Economy	6000.00
0005432104932	5074	Economy	6000.00
0005433613690	5074	Economy	6000.00
0005433784440	5074	Economy	6000.00
0005433784474	5074	Economy	6000.00
0005432104942	5074	Economy	6000.00
0005433613713	5074	Economy	6000.00
0005432104908	5074	Economy	6000.00
0005433613746	5074	Economy	6000.00
0005433613715	5074	Economy	6000.00
0005432104912	5074	Economy	6000.00
0005433613687	5074	Economy	6000.00
0005433613747	5074	Economy	6000.00
0005433613740	5074	Economy	6000.00
0005433613711	5074	Economy	6000.00
0005433613691	5074	Economy	6000.00
0005432104931	5074	Economy	6000.00
0005433613705	5074	Economy	6000.00
0005432104948	5074	Economy	6000.00
0005432104955	5074	Economy	6000.00
0005433784455	5074	Economy	6000.00
0005433613692	5074	Economy	6000.00
0005433784476	5074	Economy	6000.00
0005433613693	5074	Economy	6000.00
0005432104919	5074	Economy	6000.00
0005433613694	5074	Economy	6000.00
0005433613741	5074	Economy	6000.00
0005432104928	5074	Economy	6000.00
0005433613688	5074	Economy	6000.00
0005433784468	5074	Economy	6000.00
0005432104907	5074	Economy	6000.00
0005433784475	5074	Economy	6000.00
0005433784464	5074	Economy	6000.00
0005432104936	5074	Economy	6000.00
0005432665246	5074	Economy	6000.00
0005433613738	5074	Economy	6000.00
0005433613714	5074	Economy	6000.00
0005433613718	5074	Economy	6000.00
0005433613750	5074	Economy	6000.00
0005432104925	5074	Economy	6000.00
0005432666360	5074	Economy	6000.00
0005433784458	5074	Economy	6000.00
0005433613754	5074	Economy	6000.00
0005433613719	5074	Economy	6000.00
0005433613748	5074	Economy	6000.00
0005432104943	5074	Economy	6600.00
0005432104941	5074	Economy	6600.00
0005433784473	5074	Economy	6600.00
0005433784456	5074	Economy	6600.00
0005433784462	5074	Economy	6600.00
0005432104951	5074	Economy	6000.00
0005433613708	5074	Economy	6000.00
0005433613736	5074	Economy	6000.00
0005433784441	5074	Economy	6000.00
0005433613703	5074	Economy	6600.00
0005433784469	5074	Economy	6000.00
0005433784446	5074	Economy	6000.00
0005433784466	5074	Economy	6000.00
0005433613709	5074	Economy	6000.00
0005432104954	5074	Economy	6000.00
0005433613760	5074	Economy	6000.00
0005433613724	5074	Economy	6000.00
0005433613728	5074	Economy	6000.00
0005433613723	5074	Economy	6000.00
0005432104945	5074	Economy	6000.00
0005433613699	5074	Economy	6000.00
0005432104917	5074	Economy	6000.00
0005433613730	5074	Economy	6000.00
0005433613735	5074	Economy	6000.00
0005433784444	5074	Economy	6000.00
0005433613706	5074	Economy	6000.00
0005433613744	5074	Economy	6000.00
0005432104946	5074	Economy	6000.00
0005432104926	5074	Economy	6000.00
0005433613701	5074	Economy	6000.00
0005432104921	5074	Economy	6000.00
0005433613716	5074	Economy	6000.00
0005433613695	5074	Economy	6000.00
0005433613753	5074	Economy	6000.00
0005432145084	5074	Economy	6000.00
0005433613759	5074	Economy	6000.00
0005433613697	5074	Economy	6000.00
0005432104933	5074	Economy	6000.00
0005433784472	5074	Economy	6000.00
0005433613745	5074	Economy	6000.00
0005432104937	5074	Economy	6000.00
0005432104929	5074	Economy	6000.00
0005432104930	5074	Economy	6000.00
0005433784454	5074	Economy	6000.00
0005433784460	5074	Economy	6000.00
0005432104938	5074	Economy	6000.00
0005432104909	5074	Economy	6000.00
0005432104940	5074	Economy	6000.00
0005433613757	5074	Economy	6000.00
0005433784443	5074	Economy	6000.00
0005433784461	5074	Economy	6000.00
0005433613743	5074	Economy	6000.00
0005432104911	5074	Economy	6000.00
0005432145083	5074	Economy	6000.00
0005433784448	5074	Economy	6000.00
0005433613755	5074	Economy	6000.00
0005432104944	5074	Economy	6000.00
0005433613725	5074	Economy	6000.00
0005433613726	5074	Economy	6000.00
0005432104920	5074	Economy	6000.00
0005432104947	5074	Economy	6000.00
0005433613729	5074	Economy	6000.00
0005433784447	5074	Economy	6000.00
0005432104935	5074	Economy	6000.00
0005433784465	5074	Economy	6000.00
0005432104916	5074	Economy	6000.00
0005432104949	5074	Economy	6000.00
0005433784451	5074	Economy	6000.00
0005433613712	5074	Economy	6000.00
0005433784452	5074	Economy	6000.00
0005433613700	5074	Economy	6000.00
0005432104953	5074	Economy	6000.00
0005432104924	5074	Economy	6000.00
0005433613756	5074	Economy	6000.00
0005433613722	5074	Economy	6000.00
0005432104952	5074	Economy	6000.00
0005434229066	5076	Business	18000.00
0005434229071	5076	Business	18000.00
0005434264784	5076	Business	18000.00
0005434173465	5076	Business	18000.00
0005434264806	5076	Business	18000.00
0005434229069	5076	Business	18000.00
0005434229080	5076	Business	18000.00
0005434149579	5076	Business	18000.00
0005434229061	5076	Business	18000.00
0005434229077	5076	Business	18000.00
0005434264789	5076	Business	18000.00
0005434173466	5076	Business	18000.00
0005434264799	5076	Economy	6600.00
0005434149578	5076	Economy	6600.00
0005434149575	5076	Economy	6000.00
0005434229078	5076	Economy	6000.00
0005435006639	5076	Economy	6000.00
0005434149574	5076	Economy	6000.00
0005434264805	5076	Economy	6000.00
0005434229062	5076	Economy	6000.00
0005434149568	5076	Economy	6000.00
0005434264783	5076	Economy	6000.00
0005434149577	5076	Economy	6000.00
0005434264792	5076	Economy	6000.00
0005434264790	5076	Economy	6000.00
0005434229060	5076	Economy	6000.00
0005434149571	5076	Economy	6000.00
0005434264788	5076	Economy	6000.00
0005434229064	5076	Economy	6000.00
0005435006640	5076	Economy	6000.00
0005434229068	5076	Economy	6000.00
0005434264791	5076	Economy	6000.00
0005435006613	5076	Economy	6000.00
0005434264785	5076	Economy	6000.00
0005434229065	5076	Economy	6000.00
0005434264800	5076	Economy	6000.00
0005434229075	5076	Economy	6000.00
0005434264807	5076	Economy	6600.00
0005434229063	5076	Economy	6000.00
0005434264781	5076	Economy	6000.00
0005434264787	5076	Economy	6000.00
0005434264801	5076	Economy	6000.00
0005434264803	5076	Economy	6000.00
0005434229073	5076	Economy	6000.00
0005434229059	5076	Economy	6000.00
0005434264782	5076	Economy	6000.00
0005434264802	5076	Economy	6000.00
0005434229067	5076	Economy	6000.00
0005434264794	5076	Economy	6000.00
0005434229072	5076	Economy	6000.00
0005435006641	5076	Economy	6000.00
0005434229079	5076	Economy	6000.00
0005434264797	5076	Economy	6000.00
0005434149569	5076	Economy	6000.00
0005434264786	5076	Economy	6000.00
0005434229076	5076	Economy	6000.00
0005434264795	5076	Economy	6000.00
0005434149570	5076	Economy	6000.00
0005434229074	5076	Economy	6000.00
0005434264804	5076	Economy	6000.00
0005434149573	5076	Economy	6000.00
0005434173467	5076	Economy	6000.00
0005434264793	5076	Economy	6000.00
0005434149572	5076	Economy	6000.00
0005434229070	5076	Economy	6000.00
0005434264798	5076	Economy	6000.00
0005434264796	5076	Economy	6000.00
0005434149576	5076	Economy	6000.00
0005435269661	8517	Business	18000.00
0005435269657	8517	Business	18000.00
0005435269659	8517	Business	18000.00
0005435269662	8517	Economy	6600.00
0005435269654	8517	Economy	6600.00
0005435269653	8517	Economy	6000.00
0005435269656	8517	Economy	6000.00
0005435269660	8517	Economy	6000.00
0005435269664	8517	Economy	6000.00
0005435269658	8517	Economy	6600.00
0005435269663	8517	Economy	6000.00
0005435269655	8517	Economy	6000.00
0005432034574	8515	Business	18000.00
0005432034568	8515	Business	18000.00
0005432034587	8515	Business	18000.00
0005432335878	8515	Business	18000.00
0005433534471	8515	Business	18000.00
0005435006704	8515	Business	18000.00
0005432335875	8515	Business	18000.00
0005433688782	8515	Business	18000.00
0005432034567	8515	Business	18000.00
0005432335876	8515	Business	18000.00
0005432047501	8515	Business	18000.00
0005432034564	8515	Business	18000.00
0005435006708	8515	Business	18000.00
0005435006713	8515	Business	18000.00
0005432335874	8515	Business	18000.00
0005435006698	8515	Business	18000.00
0005432034569	8515	Economy	6600.00
0005432335871	8515	Economy	6600.00
0005435006699	8515	Economy	6000.00
0005435006722	8515	Economy	6000.00
0005432034590	8515	Economy	6000.00
0005432034578	8515	Economy	6000.00
0005432335877	8515	Economy	6000.00
0005432034586	8515	Economy	6000.00
0005434311190	8515	Economy	6000.00
0005435286561	8515	Economy	6000.00
0005432034572	8515	Economy	6000.00
0005433815323	8515	Economy	6000.00
0005432034581	8515	Economy	6000.00
0005435006707	8515	Economy	6000.00
0005433534469	8515	Economy	6000.00
0005432034566	8515	Economy	6000.00
0005435006720	8515	Economy	6000.00
0005435006718	8515	Economy	6000.00
0005435286558	8515	Economy	6000.00
0005435006703	8515	Economy	6000.00
0005432047499	8515	Economy	6000.00
0005435006705	8515	Economy	6000.00
0005433534470	8515	Economy	6000.00
0005433815321	8515	Economy	6000.00
0005432034582	8515	Economy	6000.00
0005435006709	8515	Economy	6000.00
0005435286560	8515	Economy	6000.00
0005433815324	8515	Economy	6000.00
0005432034573	8515	Economy	6000.00
0005432034580	8515	Economy	6000.00
0005432034588	8515	Economy	6000.00
0005432034584	8515	Economy	6000.00
0005432034571	8515	Economy	6000.00
0005432335873	8515	Economy	6000.00
0005435006716	8515	Economy	6000.00
0005433689884	8515	Economy	6600.00
0005433815320	8515	Economy	6000.00
0005435006717	8515	Economy	6000.00
0005432335880	8515	Economy	6600.00
0005433688783	8515	Economy	6000.00
0005432034589	8515	Economy	6000.00
0005435006710	8515	Economy	6000.00
0005435006719	8515	Economy	6000.00
0005432034570	8515	Economy	6000.00
0005435006714	8515	Economy	6000.00
0005432034565	8515	Economy	6000.00
0005433690899	8515	Economy	6000.00
0005432335870	8515	Economy	6000.00
0005432034583	8515	Economy	6000.00
0005435286559	8515	Economy	6000.00
0005432034563	8515	Economy	6000.00
0005435006711	8515	Economy	6000.00
0005432335872	8515	Economy	6000.00
0005435006721	8515	Economy	6000.00
0005435006715	8515	Economy	6000.00
0005434264725	8515	Economy	6000.00
0005432034585	8515	Economy	6000.00
0005435006702	8515	Economy	6000.00
0005435006701	8515	Economy	6000.00
0005433815322	8515	Economy	6000.00
0005432034575	8515	Economy	6000.00
0005432335869	8515	Economy	6000.00
0005435006712	8515	Economy	6000.00
0005432047500	8515	Economy	6000.00
0005435006700	8515	Economy	6000.00
0005432335879	8515	Economy	6000.00
0005432034579	8515	Economy	6000.00
0005434311189	8515	Economy	6000.00
0005432047498	8515	Economy	6000.00
0005435006706	8515	Economy	6000.00
0005432034576	8515	Economy	6000.00
0005435286557	8515	Economy	6000.00
0005435286556	8515	Economy	6000.00
0005435286562	8515	Economy	6000.00
0005432034577	8515	Economy	6000.00
0005433202168	12589	Economy	14800.00
0005433202175	12589	Economy	14800.00
0005433202174	12589	Economy	14800.00
0005433202167	12589	Economy	14800.00
0005433202166	12589	Economy	14800.00
0005433202169	12589	Economy	14800.00
0005433202163	12589	Economy	14800.00
0005433202164	12589	Economy	14800.00
0005433202176	12589	Economy	14800.00
0005433202171	12589	Economy	14800.00
0005433202173	12589	Economy	14800.00
0005433202165	12589	Economy	14800.00
0005433202170	12589	Economy	14800.00
0005433202172	12589	Economy	14800.00
0005434638932	23389	Economy	16200.00
0005434638948	23389	Economy	16200.00
0005434638928	23389	Economy	16200.00
0005434638937	23389	Economy	14800.00
0005432290590	23389	Economy	14800.00
0005434638946	23389	Economy	14800.00
0005434638953	23389	Economy	14800.00
0005434638939	23389	Economy	14800.00
0005434638950	23389	Economy	14800.00
0005434638935	23389	Economy	14800.00
0005434638931	23389	Economy	14800.00
0005434638940	23389	Economy	14800.00
0005434638955	23389	Economy	14800.00
0005434638943	23389	Economy	14800.00
0005434638952	23389	Economy	14800.00
0005432290588	23389	Economy	14800.00
0005434638936	23389	Economy	14800.00
0005434638949	23389	Economy	14800.00
0005434638951	23389	Economy	14800.00
0005434638942	23389	Economy	14800.00
0005432290589	23389	Economy	14800.00
0005434638944	23389	Economy	14800.00
0005434638941	23389	Economy	14800.00
0005434638947	23389	Economy	14800.00
0005434638934	23389	Economy	14800.00
0005434638954	23389	Economy	14800.00
0005434638929	23389	Economy	14800.00
0005434638938	23389	Economy	14800.00
0005434638930	23389	Economy	14800.00
0005434638945	23389	Economy	14800.00
0005434638933	23389	Economy	14800.00
0005432054266	21065	Business	18900.00
0005432054264	21065	Economy	6300.00
0005432054265	21065	Economy	6300.00
0005432327914	21065	Economy	6300.00
0005432328057	31265	Business	18900.00
0005432382641	31265	Business	18900.00
0005432382639	31265	Business	18900.00
0005432382643	31265	Business	18900.00
0005432382624	31265	Business	18900.00
0005432328055	31265	Business	18900.00
0005432382614	31265	Business	18900.00
0005432328053	31265	Business	18900.00
0005432382606	31265	Business	18900.00
0005432328054	31265	Business	18900.00
0005432382627	31265	Business	18900.00
0005432328064	31265	Business	18900.00
0005432382646	31265	Economy	6300.00
0005432382636	31265	Economy	6300.00
0005432328070	31265	Economy	6300.00
0005432328072	31265	Economy	6300.00
0005432328076	31265	Economy	6300.00
0005432328074	31265	Economy	6300.00
0005432382634	31265	Economy	6300.00
0005432382609	31265	Economy	6300.00
0005432328032	31265	Economy	6300.00
0005432328067	31265	Economy	6300.00
0005432328063	31265	Economy	6900.00
0005432382622	31265	Economy	6900.00
0005432328038	31265	Economy	6900.00
0005432328077	31265	Economy	6900.00
0005432382628	31265	Economy	6300.00
0005432328034	31265	Economy	6300.00
0005432382618	31265	Economy	6300.00
0005432382637	31265	Economy	6300.00
0005432287117	31265	Economy	6300.00
0005432382648	31265	Economy	6300.00
0005432328069	31265	Economy	6300.00
0005432382645	31265	Economy	6300.00
0005432382612	31265	Economy	6300.00
0005432328043	31265	Economy	6300.00
0005432287119	31265	Economy	6300.00
0005432328061	31265	Economy	6300.00
0005432382611	31265	Economy	6300.00
0005432382630	31265	Economy	6300.00
0005432382632	31265	Economy	6300.00
0005432382613	31265	Economy	6300.00
0005432328065	31265	Economy	6300.00
0005432382647	31265	Economy	6300.00
0005432382642	31265	Economy	6300.00
0005432382608	31265	Economy	6300.00
0005432328048	31265	Economy	6300.00
0005432382619	31265	Economy	6300.00
0005432328046	31265	Economy	6300.00
0005432328073	31265	Economy	6300.00
0005432382616	31265	Economy	6300.00
0005432328050	31265	Economy	6300.00
0005432328042	31265	Economy	6300.00
0005432328066	31265	Economy	6300.00
0005432382633	31265	Economy	6300.00
0005432382617	31265	Economy	6300.00
0005432328047	31265	Economy	6300.00
0005432382615	31265	Economy	6300.00
0005432328075	31265	Economy	6300.00
0005432382629	31265	Economy	6300.00
0005432328033	31265	Economy	6300.00
0005432328071	31265	Economy	6300.00
0005432382620	31265	Economy	6300.00
0005432328035	31265	Economy	6300.00
0005432328049	31265	Economy	6300.00
0005432328068	31265	Economy	6300.00
0005432382638	31265	Economy	6300.00
0005432328052	31265	Economy	6300.00
0005432382621	31265	Economy	6300.00
0005432328041	31265	Economy	6300.00
0005432328040	31265	Economy	6300.00
0005432328036	31265	Economy	6300.00
0005432382644	31265	Economy	6300.00
0005432382625	31265	Economy	6300.00
0005432287118	31265	Economy	6300.00
0005432328062	31265	Economy	6300.00
0005432328039	31265	Economy	6300.00
0005432328037	31265	Economy	6300.00
0005432382635	31265	Economy	6300.00
0005432382640	31265	Economy	6300.00
0005432382626	31265	Economy	6300.00
0005432328056	31265	Economy	6300.00
0005432382623	31265	Economy	6300.00
0005432382607	31265	Economy	6300.00
0005432287116	31265	Economy	6300.00
0005432328058	31265	Economy	6300.00
0005432382631	31265	Economy	6300.00
0005432328044	31265	Economy	6300.00
0005432382610	31265	Economy	6300.00
0005432328045	31265	Economy	6300.00
0005432328060	31265	Economy	6300.00
0005432328059	31265	Economy	6300.00
0005432328051	31265	Economy	6300.00
0005433642141	2486	Business	89600.00
0005433642123	2486	Business	89600.00
0005433642135	2486	Business	89600.00
0005433642120	2486	Business	89600.00
0005433642146	2486	Business	89600.00
0005433642126	2486	Economy	29900.00
0005433642136	2486	Economy	29900.00
0005433642130	2486	Economy	29900.00
0005433642142	2486	Economy	29900.00
0005433642125	2486	Economy	29900.00
0005433642137	2486	Economy	29900.00
0005433642132	2486	Economy	29900.00
0005433642133	2486	Economy	29900.00
0005433642134	2486	Economy	29900.00
0005433642144	2486	Economy	29900.00
0005433642128	2486	Economy	29900.00
0005433642143	2486	Economy	29900.00
0005433642131	2486	Economy	29900.00
0005433642148	2486	Economy	29900.00
0005433642122	2486	Economy	29900.00
0005433642139	2486	Economy	29900.00
0005433642147	2486	Economy	29900.00
0005433642140	2486	Economy	29900.00
0005433642127	2486	Economy	29900.00
0005433642149	2486	Economy	29900.00
0005433642138	2486	Economy	29900.00
0005433642124	2486	Economy	29900.00
0005433642121	2486	Economy	29900.00
0005433642145	2486	Economy	29900.00
0005433642129	2486	Economy	29900.00
0005432953812	27603	Business	89600.00
0005432953813	27603	Business	89600.00
0005432953826	27603	Economy	29900.00
0005432953827	27603	Economy	29900.00
0005433642082	27603	Economy	29900.00
0005432953819	27603	Economy	29900.00
0005432953824	27603	Economy	29900.00
0005432953828	27603	Economy	29900.00
0005432953823	27603	Economy	29900.00
0005433642083	27603	Economy	29900.00
0005432953817	27603	Economy	29900.00
0005432953818	27603	Economy	29900.00
0005432953816	27603	Economy	29900.00
0005432953820	27603	Economy	29900.00
0005432953825	27603	Economy	29900.00
0005432953821	27603	Economy	29900.00
0005432953815	27603	Economy	29900.00
0005432953822	27603	Economy	29900.00
0005432953829	27603	Economy	29900.00
0005432953814	27603	Economy	29900.00
0005432423791	13281	Business	12700.00
0005432423804	13281	Business	12700.00
0005432423768	13281	Business	12700.00
0005432423799	13281	Business	12700.00
0005432423770	13281	Business	12700.00
0005432423789	13281	Economy	4200.00
0005432423785	13281	Economy	4200.00
0005432423803	13281	Economy	4200.00
0005432423792	13281	Economy	4200.00
0005432423793	13281	Economy	4200.00
0005432423778	13281	Economy	4700.00
0005432423788	13281	Economy	4700.00
0005432423790	13281	Economy	4700.00
0005432423796	13281	Economy	4200.00
0005432423777	13281	Economy	4200.00
0005432423773	13281	Economy	4200.00
0005432423784	13281	Economy	4200.00
0005432423764	13281	Economy	4200.00
0005432423800	13281	Economy	4200.00
0005432423809	13281	Economy	4200.00
0005432423774	13281	Economy	4200.00
0005432423781	13281	Economy	4200.00
0005432423797	13281	Economy	4200.00
0005432423780	13281	Economy	4200.00
0005432423769	13281	Economy	4200.00
0005432423806	13281	Economy	4200.00
0005432423783	13281	Economy	4200.00
0005432423779	13281	Economy	4200.00
0005432423765	13281	Economy	4200.00
0005432423807	13281	Economy	4200.00
0005432423805	13281	Economy	4200.00
0005432423795	13281	Economy	4200.00
0005432423808	13281	Economy	4200.00
0005432423776	13281	Economy	4200.00
0005432423787	13281	Economy	4200.00
0005432423782	13281	Economy	4200.00
0005432423786	13281	Economy	4200.00
0005432423763	13281	Economy	4200.00
0005432423798	13281	Economy	4200.00
0005432423794	13281	Economy	4200.00
0005432423772	13281	Economy	4200.00
0005432423766	13281	Economy	4200.00
0005432423801	13281	Economy	4200.00
0005432423771	13281	Economy	4200.00
0005432423775	13281	Economy	4200.00
0005432423802	13281	Economy	4200.00
0005432423767	13281	Economy	4200.00
0005432817072	9629	Business	32600.00
0005432817063	9629	Business	32600.00
0005432817062	9629	Business	32600.00
0005432817068	9629	Economy	10900.00
0005432817081	9629	Economy	10900.00
0005434448268	9629	Economy	10900.00
0005432817083	9629	Economy	10900.00
0005432817076	9629	Economy	10900.00
0005432817066	9629	Economy	10900.00
0005432817065	9629	Economy	11900.00
0005434448269	9629	Economy	11900.00
0005432817073	9629	Economy	10900.00
0005432817069	9629	Economy	10900.00
0005432822101	9629	Economy	10900.00
0005432817067	9629	Economy	10900.00
0005432817088	9629	Economy	10900.00
0005432288940	9629	Economy	10900.00
0005432817070	9629	Economy	10900.00
0005432817080	9629	Economy	10900.00
0005434448270	9629	Economy	10900.00
0005432288942	9629	Economy	10900.00
0005432817059	9629	Economy	10900.00
0005432817064	9629	Economy	10900.00
0005432288943	9629	Economy	10900.00
0005432817082	9629	Economy	10900.00
0005432817060	9629	Economy	10900.00
0005432817061	9629	Economy	10900.00
0005432817085	9629	Economy	10900.00
0005432817075	9629	Economy	10900.00
0005432822099	9629	Economy	10900.00
0005432822098	9629	Economy	10900.00
0005432817078	9629	Economy	10900.00
0005432822100	9629	Economy	10900.00
0005432822102	9629	Economy	10900.00
0005432822103	9629	Economy	10900.00
0005432822105	9629	Economy	10900.00
0005432817079	9629	Economy	10900.00
0005432288941	9629	Economy	10900.00
0005432817084	9629	Economy	10900.00
0005432822104	9629	Economy	10900.00
0005432817086	9629	Economy	10900.00
0005432817087	9629	Economy	10900.00
0005432817071	9629	Economy	10900.00
0005432817074	9629	Economy	10900.00
0005432817077	9629	Economy	10900.00
0005432901368	28968	Business	32600.00
0005434157375	28968	Business	32600.00
0005434157374	28968	Business	32600.00
0005432901373	28968	Business	32600.00
0005432901382	28968	Business	32600.00
0005432002048	28968	Economy	10900.00
0005434157376	28968	Economy	10900.00
0005432901378	28968	Economy	11900.00
0005434157378	28968	Economy	10900.00
0005432901372	28968	Economy	10900.00
0005432901381	28968	Economy	10900.00
0005432901365	28968	Economy	10900.00
0005434157372	28968	Economy	10900.00
0005432901369	28968	Economy	10900.00
0005432901371	28968	Economy	10900.00
0005432816958	28968	Economy	10900.00
0005432901379	28968	Economy	10900.00
0005432901383	28968	Economy	10900.00
0005434186158	28968	Economy	10900.00
0005432901377	28968	Economy	10900.00
0005432002049	28968	Economy	10900.00
0005434157377	28968	Economy	10900.00
0005434186159	28968	Economy	10900.00
0005434186157	28968	Economy	10900.00
0005432901367	28968	Economy	10900.00
0005434157373	28968	Economy	10900.00
0005432901370	28968	Economy	10900.00
0005432901366	28968	Economy	10900.00
0005432901375	28968	Economy	10900.00
0005432816959	28968	Economy	10900.00
0005432901374	28968	Economy	10900.00
0005432901380	28968	Economy	10900.00
0005434157371	28968	Economy	10900.00
0005432901376	28968	Economy	10900.00
0005432611658	15119	Economy	11000.00
0005432611657	15119	Economy	11000.00
0005432613808	15119	Economy	11000.00
0005432611656	15119	Economy	11000.00
0005432611655	15119	Economy	11000.00
0005432613807	15119	Economy	11000.00
0005432613806	15119	Economy	11000.00
0005433568217	11850	Business	105900.00
0005433568209	11850	Business	105900.00
0005433568212	11850	Business	105900.00
0005433568204	11850	Business	105900.00
0005433568233	11850	Business	105900.00
0005433568214	11850	Business	105900.00
0005433568238	11850	Business	105900.00
0005433568234	11850	Business	105900.00
0005433568216	11850	Business	105900.00
0005433568218	11850	Business	105900.00
0005433568207	11850	Economy	35300.00
0005433568220	11850	Economy	35300.00
0005433568226	11850	Economy	35300.00
0005433568242	11850	Economy	35300.00
0005433568250	11850	Economy	35300.00
0005433568239	11850	Economy	35300.00
0005433568232	11850	Economy	35300.00
0005433568231	11850	Economy	35300.00
0005433568229	11850	Economy	35300.00
0005433568228	11850	Economy	38800.00
0005433568199	11850	Economy	38800.00
0005433568241	11850	Economy	38800.00
0005433568253	11850	Economy	35300.00
0005433568197	11850	Economy	35300.00
0005433568223	11850	Economy	35300.00
0005433568256	11850	Economy	35300.00
0005433568201	11850	Economy	35300.00
0005433568211	11850	Economy	35300.00
0005433568243	11850	Economy	35300.00
0005433568257	11850	Economy	35300.00
0005433568224	11850	Economy	35300.00
0005433568193	11850	Economy	35300.00
0005433568206	11850	Economy	35300.00
0005433568195	11850	Economy	35300.00
0005433568258	11850	Economy	35300.00
0005433568237	11850	Economy	35300.00
0005433568245	11850	Economy	35300.00
0005433568240	11850	Economy	35300.00
0005433568219	11850	Economy	35300.00
0005433568225	11850	Economy	35300.00
0005433568202	11850	Economy	35300.00
0005433568208	11850	Economy	35300.00
0005433568196	11850	Economy	35300.00
0005433568247	11850	Economy	35300.00
0005433568236	11850	Economy	35300.00
0005433568210	11850	Economy	35300.00
0005433568198	11850	Economy	35300.00
0005433568213	11850	Economy	35300.00
0005433568244	11850	Economy	35300.00
0005433568230	11850	Economy	35300.00
0005433568235	11850	Economy	35300.00
0005433568215	11850	Economy	35300.00
0005433568221	11850	Economy	35300.00
0005433568205	11850	Economy	35300.00
0005433568227	11850	Economy	35300.00
0005433568192	11850	Economy	35300.00
0005433568203	11850	Economy	35300.00
0005433568222	11850	Economy	35300.00
0005433568246	11850	Economy	35300.00
0005433568249	11850	Economy	35300.00
0005433568248	11850	Economy	35300.00
0005433568252	11850	Economy	35300.00
0005433568255	11850	Economy	35300.00
0005433568251	11850	Economy	35300.00
0005433568254	11850	Economy	35300.00
0005433568200	11850	Economy	35300.00
0005433568194	11850	Economy	35300.00
0005432947931	25312	Business	105900.00
0005432947948	25312	Business	105900.00
0005432947953	25312	Business	105900.00
0005432947965	25312	Business	105900.00
0005432947959	25312	Economy	35300.00
0005432947932	25312	Economy	35300.00
0005432947967	25312	Economy	35300.00
0005432947949	25312	Economy	35300.00
0005432947947	25312	Economy	35300.00
0005432947963	25312	Economy	35300.00
0005432947956	25312	Economy	35300.00
0005432947941	25312	Economy	35300.00
0005432947945	25312	Economy	38800.00
0005432947950	25312	Economy	35300.00
0005432947934	25312	Economy	35300.00
0005432947970	25312	Economy	35300.00
0005432947964	25312	Economy	35300.00
0005432947944	25312	Economy	35300.00
0005432947954	25312	Economy	35300.00
0005432947940	25312	Economy	35300.00
0005432947943	25312	Economy	35300.00
0005432947961	25312	Economy	35300.00
0005432947952	25312	Economy	35300.00
0005432947942	25312	Economy	35300.00
0005432947933	25312	Economy	35300.00
0005432947962	25312	Economy	35300.00
0005432947955	25312	Economy	35300.00
0005432947937	25312	Economy	35300.00
0005432947960	25312	Economy	35300.00
0005432947968	25312	Economy	35300.00
0005432947969	25312	Economy	35300.00
0005432947966	25312	Economy	35300.00
0005432947930	25312	Economy	35300.00
0005432947936	25312	Economy	35300.00
0005432947935	25312	Economy	35300.00
0005432947946	25312	Economy	35300.00
0005432947971	25312	Economy	35300.00
0005432947938	25312	Economy	35300.00
0005432947957	25312	Economy	35300.00
0005432947939	25312	Economy	35300.00
0005432947951	25312	Economy	35300.00
0005432947958	25312	Economy	35300.00
0005432430816	14459	Business	117400.00
0005434026680	14459	Business	117400.00
0005432430810	14459	Business	117400.00
0005432430815	14459	Business	117400.00
0005432430813	14459	Business	117400.00
0005432430814	14459	Economy	39100.00
0005432430806	14459	Economy	39100.00
0005432430807	14459	Economy	39100.00
0005434026677	14459	Economy	39100.00
0005432430804	14459	Economy	39100.00
0005434026672	14459	Economy	39100.00
0005432430808	14459	Economy	39100.00
0005432430811	14459	Economy	39100.00
0005434026676	14459	Economy	39100.00
0005434026675	14459	Economy	39100.00
0005434026678	14459	Economy	39100.00
0005432430818	14459	Economy	39100.00
0005434026674	14459	Economy	39100.00
0005434026673	14459	Economy	39100.00
0005432430817	14459	Economy	39100.00
0005434026679	14459	Economy	39100.00
0005432430805	14459	Economy	39100.00
0005432430812	14459	Economy	39100.00
0005432430809	14459	Economy	39100.00
0005434654292	5413	Business	67200.00
0005434656529	5413	Economy	22400.00
0005434654291	5413	Economy	22400.00
0005434654305	5413	Economy	24600.00
0005434654294	5413	Economy	24600.00
0005434654283	5413	Economy	22400.00
0005434654290	5413	Economy	22400.00
0005434654282	5413	Economy	22400.00
0005434654284	5413	Economy	22400.00
0005434654289	5413	Economy	22400.00
0005434654296	5413	Economy	22400.00
0005434654303	5413	Economy	22400.00
0005434654288	5413	Economy	22400.00
0005432114160	5413	Economy	22400.00
0005434654286	5413	Economy	22400.00
0005434654287	5413	Economy	22400.00
0005434654298	5413	Economy	22400.00
0005435340000	5413	Economy	22400.00
0005434654300	5413	Economy	22400.00
0005432114159	5413	Economy	22400.00
0005434654307	5413	Economy	22400.00
0005434654306	5413	Economy	22400.00
0005434656528	5413	Economy	22400.00
0005434654297	5413	Economy	22400.00
0005434654301	5413	Economy	22400.00
0005432114161	5413	Economy	22400.00
0005434654295	5413	Economy	22400.00
0005434654308	5413	Economy	22400.00
0005434654304	5413	Economy	22400.00
0005434654302	5413	Economy	22400.00
0005434654285	5413	Economy	22400.00
0005434654293	5413	Economy	22400.00
0005434654281	5413	Economy	22400.00
0005432114158	5413	Economy	22400.00
0005434654299	5413	Economy	22400.00
0005435555343	12523	Business	67200.00
0005435340055	12523	Economy	22400.00
0005435340059	12523	Economy	22400.00
0005435340051	12523	Economy	24600.00
0005435340056	12523	Economy	24600.00
0005435340065	12523	Economy	22400.00
0005435340063	12523	Economy	22400.00
0005435340061	12523	Economy	22400.00
0005435340060	12523	Economy	22400.00
0005435340053	12523	Economy	22400.00
0005435340062	12523	Economy	22400.00
0005435340057	12523	Economy	22400.00
0005435340052	12523	Economy	22400.00
0005435340058	12523	Economy	22400.00
0005435555342	12523	Economy	22400.00
0005435340054	12523	Economy	22400.00
0005435340064	12523	Economy	22400.00
0005433715285	7461	Business	32000.00
0005433715302	7461	Business	32000.00
0005433715304	7461	Business	32000.00
0005433719092	7461	Business	32000.00
0005433715272	7461	Business	32000.00
0005433715319	7461	Business	32000.00
0005433715290	7461	Business	32000.00
0005433715288	7461	Business	32000.00
0005433715273	7461	Economy	10700.00
0005433715297	7461	Economy	10700.00
0005433715315	7461	Economy	10700.00
0005433715295	7461	Economy	10700.00
0005432078036	7461	Economy	10700.00
0005433715280	7461	Economy	10700.00
0005433715303	7461	Economy	10700.00
0005433656621	7461	Economy	10700.00
0005433715300	7461	Economy	10700.00
0005433715289	7461	Economy	10700.00
0005433715278	7461	Economy	10700.00
0005433715292	7461	Economy	10700.00
0005433715308	7461	Economy	10700.00
0005432078034	7461	Economy	10700.00
0005433689883	7461	Economy	10700.00
0005433722127	7461	Economy	10700.00
0005433715275	7461	Economy	10700.00
0005432078033	7461	Economy	10700.00
0005433688781	7461	Economy	10700.00
0005433690898	7461	Economy	10700.00
0005433715294	7461	Economy	10700.00
0005433715305	7461	Economy	10700.00
0005433722124	7461	Economy	11700.00
0005433722123	7461	Economy	10700.00
0005432078032	7461	Economy	10700.00
0005433715311	7461	Economy	10700.00
0005433715284	7461	Economy	10700.00
0005433715298	7461	Economy	10700.00
0005433715281	7461	Economy	10700.00
0005433722122	7461	Economy	10700.00
0005433715271	7461	Economy	10700.00
0005433715318	7461	Economy	10700.00
0005433715293	7461	Economy	10700.00
0005433715316	7461	Economy	10700.00
0005433715317	7461	Economy	10700.00
0005433715296	7461	Economy	10700.00
0005433715286	7461	Economy	10700.00
0005433722126	7461	Economy	10700.00
0005433722121	7461	Economy	10700.00
0005433715321	7461	Economy	10700.00
0005433715276	7461	Economy	10700.00
0005433719093	7461	Economy	10700.00
0005433722125	7461	Economy	10700.00
0005433715299	7461	Economy	10700.00
0005433715277	7461	Economy	10700.00
0005433688779	7461	Economy	10700.00
0005433688780	7461	Economy	10700.00
0005433715312	7461	Economy	10700.00
0005433715314	7461	Economy	10700.00
0005433715306	7461	Economy	10700.00
0005433715279	7461	Economy	10700.00
0005433656622	7461	Economy	10700.00
0005433715320	7461	Economy	10700.00
0005433689882	7461	Economy	10700.00
0005433715310	7461	Economy	10700.00
0005433656623	7461	Economy	10700.00
0005433656624	7461	Economy	10700.00
0005433715309	7461	Economy	10700.00
0005433715307	7461	Economy	10700.00
0005433715301	7461	Economy	10700.00
0005433715274	7461	Economy	10700.00
0005433715282	7461	Economy	10700.00
0005433715287	7461	Economy	10700.00
0005433690897	7461	Economy	10700.00
0005433715283	7461	Economy	10700.00
0005433715291	7461	Economy	10700.00
0005433715313	7461	Economy	10700.00
0005432078035	7461	Economy	10700.00
0005432428881	29257	Economy	10700.00
0005432428882	29257	Economy	10700.00
0005432006721	29257	Economy	10700.00
0005432428884	29257	Economy	10700.00
0005432006723	29257	Economy	10700.00
0005432428883	29257	Economy	10700.00
0005432006722	29257	Economy	10700.00
0005432006724	29257	Economy	10700.00
0005432006720	29257	Economy	10700.00
0005434095085	8680	Business	36500.00
0005434095076	8680	Business	36500.00
0005434326084	8680	Economy	12200.00
0005434143701	8680	Economy	12200.00
0005434095078	8680	Economy	13400.00
0005434143698	8680	Economy	13400.00
0005434095074	8680	Economy	12200.00
0005434143705	8680	Economy	12200.00
0005434095081	8680	Economy	12200.00
0005434095083	8680	Economy	12200.00
0005434095088	8680	Economy	12200.00
0005434143704	8680	Economy	12200.00
0005434095077	8680	Economy	12200.00
0005434143700	8680	Economy	12200.00
0005434095079	8680	Economy	12200.00
0005434095075	8680	Economy	12200.00
0005434095080	8680	Economy	12200.00
0005434095084	8680	Economy	12200.00
0005434095086	8680	Economy	12200.00
0005434143699	8680	Economy	12200.00
0005434143703	8680	Economy	12200.00
0005434095087	8680	Economy	12200.00
0005434143702	8680	Economy	12200.00
0005434095082	8680	Economy	12200.00
0005434182020	11670	Business	36500.00
0005434182021	11670	Business	36500.00
0005434182009	11670	Economy	12200.00
0005434182016	11670	Economy	12200.00
0005434182010	11670	Economy	12200.00
0005434182012	11670	Economy	12200.00
0005434182015	11670	Economy	12200.00
0005434182008	11670	Economy	12200.00
0005434095032	11670	Economy	12200.00
0005434182018	11670	Economy	12200.00
0005434182013	11670	Economy	12200.00
0005434182011	11670	Economy	12200.00
0005434182014	11670	Economy	12200.00
0005434183551	11670	Economy	12200.00
0005434182019	11670	Economy	12200.00
0005434095031	11670	Economy	12200.00
0005434183550	11670	Economy	12200.00
0005434184636	11670	Economy	12200.00
0005434182017	11670	Economy	12200.00
0005433397322	1429	Business	33000.00
0005433397197	1429	Economy	11000.00
0005435732163	1429	Economy	12100.00
0005433456914	1429	Economy	12100.00
0005433397181	1429	Economy	11000.00
0005433456915	1429	Economy	11000.00
0005432297241	1429	Economy	11000.00
0005433397178	1429	Economy	11000.00
0005435732165	1429	Economy	11000.00
0005433456913	1429	Economy	11000.00
0005435732162	1429	Economy	11000.00
0005435732164	1429	Economy	11000.00
0005433397321	1429	Economy	11000.00
0005433397195	1429	Economy	11000.00
0005433397182	1429	Economy	11000.00
0005433456912	1429	Economy	11000.00
0005433456916	1429	Economy	11000.00
0005433397224	1429	Economy	11000.00
0005432297242	1429	Economy	11000.00
0005433397426	19281	Business	33000.00
0005433397424	19281	Business	33000.00
0005433397384	19281	Business	33000.00
0005433397411	19281	Business	33000.00
0005433397389	19281	Business	33000.00
0005433397407	19281	Business	33000.00
0005433397390	19281	Business	33000.00
0005433397417	19281	Business	33000.00
0005433397423	19281	Business	33000.00
0005433397427	19281	Economy	11000.00
0005433397383	19281	Economy	11000.00
0005433397397	19281	Economy	11000.00
0005433397381	19281	Economy	11000.00
0005433397400	19281	Economy	11000.00
0005433397401	19281	Economy	12100.00
0005433397399	19281	Economy	12100.00
0005433397415	19281	Economy	11000.00
0005433397413	19281	Economy	11000.00
0005433397422	19281	Economy	11000.00
0005433397388	19281	Economy	11000.00
0005433397409	19281	Economy	11000.00
0005433397380	19281	Economy	11000.00
0005433397420	19281	Economy	11000.00
0005433397425	19281	Economy	11000.00
0005433397416	19281	Economy	11000.00
0005433397392	19281	Economy	11000.00
0005433397394	19281	Economy	11000.00
0005433397403	19281	Economy	11000.00
0005433397398	19281	Economy	11000.00
0005433397406	19281	Economy	11000.00
0005433397404	19281	Economy	11000.00
0005433397385	19281	Economy	11000.00
0005433397386	19281	Economy	11000.00
0005433397421	19281	Economy	11000.00
0005433397419	19281	Economy	11000.00
0005432906502	19281	Economy	11000.00
0005433397396	19281	Economy	11000.00
0005433397402	19281	Economy	11000.00
0005432906501	19281	Economy	11000.00
0005433397387	19281	Economy	11000.00
0005433397410	19281	Economy	11000.00
0005433397418	19281	Economy	11000.00
0005432906503	19281	Economy	11000.00
0005433397408	19281	Economy	11000.00
0005433397391	19281	Economy	11000.00
0005433397382	19281	Economy	11000.00
0005433397412	19281	Economy	11000.00
0005433397395	19281	Economy	11000.00
0005433397379	19281	Economy	11000.00
0005433397414	19281	Economy	11000.00
0005433397393	19281	Economy	11000.00
0005433397405	19281	Economy	11000.00
0005434443482	20558	Economy	15600.00
0005434443478	20558	Economy	14100.00
0005434443479	20558	Economy	14100.00
0005434443475	20558	Economy	14100.00
0005434443488	20558	Economy	14100.00
0005434443485	20558	Economy	14100.00
0005434443481	20558	Economy	14100.00
0005434443477	20558	Economy	14100.00
0005434443474	20558	Economy	14100.00
0005434443486	20558	Economy	14100.00
0005434443487	20558	Economy	14100.00
0005434443473	20558	Economy	14100.00
0005434443483	20558	Economy	14100.00
0005434443476	20558	Economy	14100.00
0005434443484	20558	Economy	14100.00
0005434443480	20558	Economy	14100.00
0005434954556	7278	Economy	5800.00
0005434954555	7278	Economy	5800.00
0005434954557	7278	Economy	5800.00
0005434954558	7278	Economy	5800.00
0005434954554	7278	Economy	5800.00
0005435377549	28348	Economy	5800.00
0005435377548	28348	Economy	5800.00
0005435377547	28348	Economy	5800.00
0005435377546	28348	Economy	5800.00
0005434351524	4462	Economy	14000.00
0005434351528	4462	Economy	14000.00
0005434351521	4462	Economy	14000.00
0005434351525	4462	Economy	14000.00
0005434351520	4462	Economy	14000.00
0005434351519	4462	Economy	14000.00
0005434326261	4462	Economy	14000.00
0005434351522	4462	Economy	14000.00
0005434351516	4462	Economy	14000.00
0005434351517	4462	Economy	14000.00
0005434351518	4462	Economy	14000.00
0005434351527	4462	Economy	14000.00
0005434351526	4462	Economy	14000.00
0005434351523	4462	Economy	14000.00
0005435893534	29639	Economy	15400.00
0005435893536	29639	Economy	14000.00
0005435893538	29639	Economy	14000.00
0005435893535	29639	Economy	14000.00
0005435893533	29639	Economy	14000.00
0005435893537	29639	Economy	14000.00
0005435893539	29639	Economy	14000.00
0005433463871	1081	Business	30600.00
0005435091938	1081	Business	30600.00
0005435545639	1081	Business	30600.00
0005433341476	1081	Business	30600.00
0005434446489	1081	Economy	10200.00
0005435091934	1081	Economy	10200.00
0005433463872	1081	Economy	10200.00
0005435091937	1081	Economy	10200.00
0005432293174	1081	Economy	10200.00
0005434446488	1081	Economy	10200.00
0005435091941	1081	Economy	10200.00
0005435545637	1081	Economy	10200.00
0005435091940	1081	Economy	10200.00
0005433341580	1081	Economy	10200.00
0005434446487	1081	Economy	10200.00
0005434445215	1081	Economy	10200.00
0005435091935	1081	Economy	10200.00
0005435545636	1081	Economy	10200.00
0005435091933	1081	Economy	10200.00
0005433462717	1081	Economy	10200.00
0005435545638	1081	Economy	10200.00
0005433463870	1081	Economy	10200.00
0005435091936	1081	Economy	10200.00
0005435091942	1081	Economy	10200.00
0005434445216	1081	Economy	10200.00
0005435545640	1081	Economy	10200.00
0005434446490	1081	Economy	10200.00
0005433462718	1081	Economy	10200.00
0005435091939	1081	Economy	10200.00
0005432293175	1081	Economy	10200.00
0005433341716	17067	Business	30600.00
0005433341785	17067	Business	30600.00
0005433341707	17067	Business	30600.00
0005433341709	17067	Business	30600.00
0005433341762	17067	Business	30600.00
0005433341732	17067	Business	30600.00
0005433341758	17067	Business	30600.00
0005433341779	17067	Business	30600.00
0005433341717	17067	Business	30600.00
0005433341777	17067	Business	30600.00
0005433341734	17067	Business	30600.00
0005433341774	17067	Business	30600.00
0005433341771	17067	Business	30600.00
0005433341719	17067	Business	30600.00
0005433341722	17067	Business	30600.00
0005433341691	17067	Business	30600.00
0005433341727	17067	Business	30600.00
0005433341755	17067	Economy	11200.00
0005433341692	17067	Business	30600.00
0005433341750	17067	Economy	10200.00
0005433341746	17067	Economy	10200.00
0005433341739	17067	Economy	10200.00
0005433341743	17067	Economy	10200.00
0005433341740	17067	Economy	10200.00
0005433341782	17067	Economy	10200.00
0005433341748	17067	Economy	10200.00
0005433341704	17067	Economy	10200.00
0005433341749	17067	Economy	10200.00
0005433269644	17067	Economy	10200.00
0005433341690	17067	Economy	10200.00
0005433341765	17067	Economy	10200.00
0005433341687	17067	Economy	10200.00
0005433341761	17067	Economy	10200.00
0005433341741	17067	Economy	10200.00
0005433341731	17067	Economy	10200.00
0005433341753	17067	Economy	10200.00
0005433341759	17067	Economy	10200.00
0005433341711	17067	Economy	10200.00
0005433341720	17067	Economy	10200.00
0005433341712	17067	Economy	10200.00
0005433341784	17067	Economy	10200.00
0005433341751	17067	Economy	10200.00
0005433341710	17067	Economy	10200.00
0005433341780	17067	Economy	10200.00
0005433341760	17067	Economy	10200.00
0005433341745	17067	Economy	10200.00
0005433341786	17067	Economy	10200.00
0005433341686	17067	Economy	10200.00
0005433341697	17067	Economy	10200.00
0005433341726	17067	Economy	10200.00
0005433341730	17067	Economy	10200.00
0005433341714	17067	Economy	10200.00
0005433269645	17067	Economy	10200.00
0005433341733	17067	Economy	10200.00
0005433341718	17067	Economy	10200.00
0005433341752	17067	Economy	10200.00
0005433159282	17067	Economy	10200.00
0005433341685	17067	Economy	10200.00
0005433341773	17067	Economy	10200.00
0005433341757	17067	Economy	10200.00
0005433341768	17067	Economy	10200.00
0005433341738	17067	Economy	10200.00
0005433341754	17067	Economy	10200.00
0005433341725	17067	Economy	10200.00
0005433341737	17067	Economy	10200.00
0005433341693	17067	Economy	10200.00
0005433341735	17067	Economy	11200.00
0005433341699	17067	Economy	11200.00
0005433341705	17067	Economy	10200.00
0005433341713	17067	Economy	10200.00
0005433341769	17067	Economy	11200.00
0005433341695	17067	Economy	10200.00
0005433341706	17067	Economy	10200.00
0005433341767	17067	Economy	10200.00
0005433341694	17067	Economy	10200.00
0005433341775	17067	Economy	10200.00
0005433341783	17067	Economy	10200.00
0005433341702	17067	Economy	10200.00
0005433341778	17067	Economy	10200.00
0005433341742	17067	Economy	10200.00
0005433341696	17067	Economy	10200.00
0005433341764	17067	Economy	10200.00
0005433341729	17067	Economy	10200.00
0005433341763	17067	Economy	10200.00
0005433159281	17067	Economy	10200.00
0005433341723	17067	Economy	10200.00
0005433341698	17067	Economy	10200.00
0005433341715	17067	Economy	10200.00
0005433269643	17067	Economy	10200.00
0005433341781	17067	Economy	10200.00
0005433341724	17067	Economy	10200.00
0005433341744	17067	Economy	10200.00
0005433341684	17067	Economy	10200.00
0005435091893	17067	Economy	10200.00
0005433341700	17067	Economy	10200.00
0005433341747	17067	Economy	10200.00
0005433341776	17067	Economy	10200.00
0005433341708	17067	Economy	10200.00
0005433341701	17067	Economy	10200.00
0005433341728	17067	Economy	10200.00
0005433341766	17067	Economy	10200.00
0005433341703	17067	Economy	10200.00
0005433341772	17067	Economy	10200.00
0005433341689	17067	Economy	10200.00
0005433341756	17067	Economy	10200.00
0005433341770	17067	Economy	10200.00
0005433269646	17067	Economy	10200.00
0005433341721	17067	Economy	10200.00
0005433341688	17067	Economy	10200.00
0005433341736	17067	Economy	10200.00
0005432159796	12790	Business	40300.00
0005432433607	12790	Business	40300.00
0005433812867	12790	Economy	13400.00
0005432159795	12790	Economy	13400.00
0005432161122	12790	Economy	13400.00
0005432433606	12790	Economy	13400.00
0005432433608	12790	Economy	13400.00
0005433812868	12790	Economy	14800.00
0005432433605	12790	Economy	13400.00
0005432161121	12790	Economy	13400.00
0005432161119	12790	Economy	13400.00
0005432161123	12790	Economy	13400.00
0005432159797	12790	Economy	13400.00
0005432159793	12790	Economy	13400.00
0005434066361	12790	Economy	13400.00
0005432159794	12790	Economy	13400.00
0005432161120	12790	Economy	13400.00
0005434081553	30673	Business	40300.00
0005434066529	30673	Business	40300.00
0005434081567	30673	Business	40300.00
0005434066532	30673	Business	40300.00
0005432150080	30673	Business	40300.00
0005434066564	30673	Business	40300.00
0005434066521	30673	Business	40300.00
0005434066566	30673	Business	40300.00
0005434081554	30673	Business	40300.00
0005434081551	30673	Economy	13400.00
0005434066557	30673	Economy	13400.00
0005434066525	30673	Economy	13400.00
0005433989701	30673	Economy	13400.00
0005434066574	30673	Economy	13400.00
0005434066514	30673	Economy	13400.00
0005434066570	30673	Economy	13400.00
0005432150079	30673	Economy	13400.00
0005434066520	30673	Economy	13400.00
0005434066526	30673	Economy	13400.00
0005434066584	30673	Economy	13400.00
0005434081563	30673	Economy	13400.00
0005434066581	30673	Economy	13400.00
0005434081575	30673	Economy	13400.00
0005434066576	30673	Economy	13400.00
0005434081557	30673	Economy	13400.00
0005434066544	30673	Economy	13400.00
0005434066518	30673	Economy	13400.00
0005433989700	30673	Economy	13400.00
0005433989704	30673	Economy	13400.00
0005434066527	30673	Economy	13400.00
0005434066538	30673	Economy	13400.00
0005434066578	30673	Economy	13400.00
0005434066553	30673	Economy	13400.00
0005434066537	30673	Economy	13400.00
0005434081569	30673	Economy	13400.00
0005432150085	30673	Economy	13400.00
0005434066519	30673	Economy	13400.00
0005434066565	30673	Economy	13400.00
0005433989703	30673	Economy	13400.00
0005434081565	30673	Economy	13400.00
0005434081564	30673	Economy	13400.00
0005434081572	30673	Economy	13400.00
0005434066561	30673	Economy	13400.00
0005434081559	30673	Economy	13400.00
0005434066540	30673	Economy	13400.00
0005434066516	30673	Economy	13400.00
0005432150082	30673	Economy	14800.00
0005434081573	30673	Economy	14800.00
0005434066517	30673	Economy	14800.00
0005432150081	30673	Economy	14800.00
0005434066583	30673	Economy	14800.00
0005432186818	30673	Economy	14800.00
0005434066580	30673	Economy	13400.00
0005434066558	30673	Economy	13400.00
0005432186816	30673	Economy	13400.00
0005434066541	30673	Economy	13400.00
0005434066556	30673	Economy	13400.00
0005434066542	30673	Economy	13400.00
0005434081558	30673	Economy	13400.00
0005434066551	30673	Economy	13400.00
0005434066573	30673	Economy	13400.00
0005434066534	30673	Economy	13400.00
0005434081560	30673	Economy	13400.00
0005434066562	30673	Economy	13400.00
0005434066523	30673	Economy	13400.00
0005434066513	30673	Economy	13400.00
0005434066549	30673	Economy	13400.00
0005432150084	30673	Economy	13400.00
0005434081555	30673	Economy	13400.00
0005434081571	30673	Economy	13400.00
0005434066545	30673	Economy	13400.00
0005434081556	30673	Economy	13400.00
0005434066560	30673	Economy	13400.00
0005434066554	30673	Economy	13400.00
0005434081561	30673	Economy	13400.00
0005434066522	30673	Economy	13400.00
0005434066539	30673	Economy	13400.00
0005432186815	30673	Economy	13400.00
0005434066535	30673	Economy	13400.00
0005434066531	30673	Economy	13400.00
0005434081574	30673	Economy	13400.00
0005434066567	30673	Economy	13400.00
0005434066552	30673	Economy	13400.00
0005434066548	30673	Economy	13400.00
0005434066555	30673	Economy	13400.00
0005434066543	30673	Economy	13400.00
0005434066572	30673	Economy	13400.00
0005434081568	30673	Economy	13400.00
0005434066515	30673	Economy	13400.00
0005434066563	30673	Economy	13400.00
0005434081576	30673	Economy	13400.00
0005434066546	30673	Economy	13400.00
0005434066569	30673	Economy	13400.00
0005434066577	30673	Economy	13400.00
0005434081552	30673	Economy	13400.00
0005434066530	30673	Economy	13400.00
0005433989702	30673	Economy	13400.00
0005434066550	30673	Economy	13400.00
0005434066568	30673	Economy	13400.00
0005434066575	30673	Economy	13400.00
0005432150083	30673	Economy	13400.00
0005434066512	30673	Economy	13400.00
0005434066559	30673	Economy	13400.00
0005434066582	30673	Economy	13400.00
0005432150078	30673	Economy	13400.00
0005434066528	30673	Economy	13400.00
0005434066547	30673	Economy	13400.00
0005434081562	30673	Economy	13400.00
0005434081566	30673	Economy	13400.00
0005434066571	30673	Economy	13400.00
0005434066536	30673	Economy	13400.00
0005434066533	30673	Economy	13400.00
0005434081570	30673	Economy	13400.00
0005432186817	30673	Economy	13400.00
0005434066524	30673	Economy	13400.00
0005434066579	30673	Economy	13400.00
0005435765358	5531	Business	35300.00
0005432140338	5531	Business	35300.00
0005435722022	5531	Business	35300.00
0005435720810	5531	Business	35300.00
0005432140341	5531	Business	35300.00
0005435765367	5531	Business	35300.00
0005432140332	5531	Business	35300.00
0005432140337	5531	Business	35300.00
0005435765351	5531	Business	35300.00
0005435765399	5531	Business	35300.00
0005433529227	5531	Business	35300.00
0005435765356	5531	Business	35300.00
0005435765385	5531	Business	35300.00
0005435720809	5531	Economy	12900.00
0005435765395	5531	Economy	12900.00
0005432140336	5531	Economy	12900.00
0005435765374	5531	Economy	12900.00
0005435765387	5531	Economy	11800.00
0005435765363	5531	Economy	11800.00
0005435765401	5531	Economy	11800.00
0005435765359	5531	Economy	11800.00
0005435720808	5531	Economy	11800.00
0005432140334	5531	Economy	11800.00
0005435765347	5531	Economy	11800.00
0005435765369	5531	Economy	11800.00
0005435765365	5531	Economy	11800.00
0005435765350	5531	Economy	11800.00
0005432140333	5531	Economy	11800.00
0005435765381	5531	Economy	11800.00
0005435765362	5531	Economy	11800.00
0005435765404	5531	Economy	11800.00
0005435765360	5531	Economy	11800.00
0005433527216	5531	Economy	11800.00
0005435765383	5531	Economy	11800.00
0005435725528	5531	Economy	11800.00
0005432140339	5531	Economy	11800.00
0005435765397	5531	Economy	11800.00
0005435765371	5531	Economy	11800.00
0005435735072	5531	Economy	11800.00
0005435765405	5531	Economy	11800.00
0005435765394	5531	Economy	11800.00
0005435765398	5531	Economy	11800.00
0005435765366	5531	Economy	11800.00
0005433529228	5531	Economy	11800.00
0005435725531	5531	Economy	11800.00
0005434264680	5531	Economy	11800.00
0005432140340	5531	Economy	11800.00
0005435461759	5531	Economy	11800.00
0005432140335	5531	Economy	11800.00
0005435461761	5531	Economy	11800.00
0005435723018	5531	Economy	11800.00
0005435725529	5531	Economy	11800.00
0005435765375	5531	Economy	11800.00
0005435765400	5531	Economy	11800.00
0005435723016	5531	Economy	11800.00
0005435765389	5531	Economy	11800.00
0005435765388	5531	Economy	11800.00
0005435735073	5531	Economy	11800.00
0005434264681	5531	Economy	11800.00
0005435735074	5531	Economy	11800.00
0005435765378	5531	Economy	11800.00
0005435765354	5531	Economy	11800.00
0005435765402	5531	Economy	11800.00
0005433527215	5531	Economy	11800.00
0005435765382	5531	Economy	11800.00
0005435725530	5531	Economy	11800.00
0005435765391	5531	Economy	11800.00
0005435765379	5531	Economy	12900.00
0005435765364	5531	Economy	11800.00
0005433527217	5531	Economy	12900.00
0005435765355	5531	Economy	11800.00
0005435765348	5531	Economy	11800.00
0005435723019	5531	Economy	11800.00
0005433529229	5531	Economy	11800.00
0005433529226	5531	Economy	11800.00
0005435765357	5531	Economy	11800.00
0005435765396	5531	Economy	11800.00
0005435765403	5531	Economy	11800.00
0005433527218	5531	Economy	11800.00
0005435765386	5531	Economy	11800.00
0005435765352	5531	Economy	11800.00
0005435735071	5531	Economy	11800.00
0005435765349	5531	Economy	11800.00
0005435765377	5531	Economy	11800.00
0005435765376	5531	Economy	11800.00
0005435765370	5531	Economy	11800.00
0005435725527	5531	Economy	11800.00
0005435765373	5531	Economy	11800.00
0005435765384	5531	Economy	11800.00
0005435765372	5531	Economy	11800.00
0005435722023	5531	Economy	11800.00
0005435723017	5531	Economy	11800.00
0005435765353	5531	Economy	11800.00
0005435765361	5531	Economy	11800.00
0005435735070	5531	Economy	11800.00
0005435765393	5531	Economy	11800.00
0005435765380	5531	Economy	11800.00
0005435765390	5531	Economy	11800.00
0005435765392	5531	Economy	11800.00
0005435765368	5531	Economy	11800.00
0005434831088	13465	Business	35300.00
0005434264785	13465	Business	35300.00
0005435725512	13465	Business	35300.00
0005434264782	13465	Business	35300.00
0005434264798	13465	Business	35300.00
0005434264786	13465	Business	35300.00
0005435461924	13465	Business	35300.00
0005435461942	13465	Business	35300.00
0005432535769	13465	Business	35300.00
0005435461936	13465	Economy	12900.00
0005435461925	13465	Economy	11800.00
0005434264781	13465	Economy	11800.00
0005432194454	13465	Economy	11800.00
0005434264800	13465	Economy	11800.00
0005432535767	13465	Economy	11800.00
0005435461914	13465	Economy	11800.00
0005435461946	13465	Economy	11800.00
0005435461939	13465	Economy	11800.00
0005435461921	13465	Economy	11800.00
0005434264797	13465	Economy	11800.00
0005435461931	13465	Economy	11800.00
0005435461912	13465	Economy	11800.00
0005434264802	13465	Economy	11800.00
0005435461935	13465	Economy	11800.00
0005434264807	13465	Economy	11800.00
0005435461920	13465	Economy	11800.00
0005435461932	13465	Economy	11800.00
0005432194453	13465	Economy	11800.00
0005435461944	13465	Economy	11800.00
0005435461941	13465	Economy	11800.00
0005435461934	13465	Economy	11800.00
0005432194456	13465	Economy	11800.00
0005435461940	13465	Economy	11800.00
0005435461928	13465	Economy	11800.00
0005435461930	13465	Economy	11800.00
0005435461947	13465	Economy	11800.00
0005434264789	13465	Economy	11800.00
0005435461943	13465	Economy	11800.00
0005434264793	13465	Economy	11800.00
0005434264794	13465	Economy	11800.00
0005435461929	13465	Economy	11800.00
0005435461915	13465	Economy	11800.00
0005435461948	13465	Economy	11800.00
0005434264806	13465	Economy	11800.00
0005435461911	13465	Economy	11800.00
0005432194452	13465	Economy	11800.00
0005432194455	13465	Economy	11800.00
0005434264788	13465	Economy	11800.00
0005434264804	13465	Economy	11800.00
0005435461927	13465	Economy	11800.00
0005435461926	13465	Economy	12900.00
0005434264805	13465	Economy	11800.00
0005434831087	13465	Economy	11800.00
0005435461913	13465	Economy	11800.00
0005434264801	13465	Economy	11800.00
0005434264790	13465	Economy	11800.00
0005435461938	13465	Economy	11800.00
0005435461918	13465	Economy	11800.00
0005434831086	13465	Economy	11800.00
0005435461933	13465	Economy	11800.00
0005434264783	13465	Economy	11800.00
0005435461919	13465	Economy	11800.00
0005435461923	13465	Economy	11800.00
0005434264796	13465	Economy	11800.00
0005435461916	13465	Economy	11800.00
0005434264795	13465	Economy	11800.00
0005434264787	13465	Economy	11800.00
0005435461922	13465	Economy	11800.00
0005432535766	13465	Economy	11800.00
0005434264791	13465	Economy	11800.00
0005432535768	13465	Economy	11800.00
0005434831089	13465	Economy	11800.00
0005434264784	13465	Economy	11800.00
0005434264792	13465	Economy	11800.00
0005435461945	13465	Economy	11800.00
0005434264803	13465	Economy	11800.00
0005435461937	13465	Economy	11800.00
0005435461917	13465	Economy	11800.00
0005434264799	13465	Economy	11800.00
0005434514929	18703	Economy	3300.00
0005434514931	18703	Economy	3300.00
0005434513542	18703	Economy	3300.00
0005434514930	18703	Economy	3300.00
0005434513541	18703	Economy	3300.00
0005432649310	4115	Business	88300.00
0005432632638	4115	Business	88300.00
0005432632637	4115	Business	88300.00
0005432632635	4115	Business	88300.00
0005432632643	4115	Business	88300.00
0005432649324	4115	Economy	29400.00
0005432649312	4115	Economy	29400.00
0005432632647	4115	Economy	29400.00
0005432649314	4115	Economy	32400.00
0005432649326	4115	Economy	32400.00
0005432632650	4115	Economy	32400.00
0005432632640	4115	Economy	29400.00
0005432649318	4115	Economy	29400.00
0005432649319	4115	Economy	29400.00
0005432632654	4115	Economy	29400.00
0005432632649	4115	Economy	29400.00
0005432649315	4115	Economy	29400.00
0005432632641	4115	Economy	29400.00
0005432649308	4115	Economy	29400.00
0005432632639	4115	Economy	29400.00
0005432649321	4115	Economy	29400.00
0005432649309	4115	Economy	29400.00
0005432649313	4115	Economy	29400.00
0005432632642	4115	Economy	29400.00
0005432649325	4115	Economy	29400.00
0005432649317	4115	Economy	29400.00
0005432632648	4115	Economy	29400.00
0005432632653	4115	Economy	29400.00
0005432649322	4115	Economy	29400.00
0005432632644	4115	Economy	29400.00
0005432649316	4115	Economy	29400.00
0005432649320	4115	Economy	29400.00
0005432632646	4115	Economy	29400.00
0005432632636	4115	Economy	29400.00
0005432649311	4115	Economy	29400.00
0005432632651	4115	Economy	29400.00
0005432632652	4115	Economy	29400.00
0005432649323	4115	Economy	29400.00
0005432632645	4115	Economy	29400.00
0005433007854	1803	Business	48700.00
0005432295845	1803	Business	48700.00
0005433284794	1803	Economy	16200.00
0005433284793	1803	Economy	16200.00
0005433284770	1803	Economy	16200.00
0005432295844	1803	Economy	16200.00
0005433007852	1803	Economy	16200.00
0005433007965	22607	Business	48700.00
0005433007961	22607	Business	48700.00
0005433007988	22607	Business	48700.00
0005433007981	22607	Business	48700.00
0005433007979	22607	Business	48700.00
0005433284872	22607	Business	48700.00
0005433007998	22607	Business	48700.00
0005433007982	22607	Business	48700.00
0005433284853	22607	Business	48700.00
0005433008002	22607	Economy	16200.00
0005433284860	22607	Economy	16200.00
0005433284874	22607	Economy	16200.00
0005433008007	22607	Economy	16200.00
0005433008001	22607	Economy	16200.00
0005433284861	22607	Economy	16200.00
0005433284866	22607	Economy	16200.00
0005433008003	22607	Economy	16200.00
0005433007970	22607	Economy	17900.00
0005433284856	22607	Economy	17900.00
0005433008006	22607	Economy	17900.00
0005433007968	22607	Economy	17900.00
0005433284854	22607	Economy	16200.00
0005433284862	22607	Economy	16200.00
0005433008005	22607	Economy	16200.00
0005433284852	22607	Economy	16200.00
0005433007993	22607	Economy	16200.00
0005433284873	22607	Economy	16200.00
0005433284858	22607	Economy	16200.00
0005433007983	22607	Economy	16200.00
0005433007997	22607	Economy	16200.00
0005433284855	22607	Economy	16200.00
0005433284857	22607	Economy	16200.00
0005433007962	22607	Economy	16200.00
0005433007989	22607	Economy	16200.00
0005433284865	22607	Economy	16200.00
0005433007969	22607	Economy	16200.00
0005433284877	22607	Economy	16200.00
0005433007996	22607	Economy	16200.00
0005433284871	22607	Economy	16200.00
0005433007994	22607	Economy	16200.00
0005433284869	22607	Economy	16200.00
0005433284849	22607	Economy	16200.00
0005433007964	22607	Economy	16200.00
0005433007992	22607	Economy	16200.00
0005433007986	22607	Economy	16200.00
0005433008000	22607	Economy	16200.00
0005433284851	22607	Economy	16200.00
0005433007977	22607	Economy	16200.00
0005433007995	22607	Economy	16200.00
0005433007991	22607	Economy	16200.00
0005433007966	22607	Economy	16200.00
0005433284864	22607	Economy	16200.00
0005433284859	22607	Economy	16200.00
0005433007971	22607	Economy	16200.00
0005433007974	22607	Economy	16200.00
0005433284850	22607	Economy	16200.00
0005433007972	22607	Economy	16200.00
0005433284876	22607	Economy	16200.00
0005433284863	22607	Economy	16200.00
0005433007985	22607	Economy	16200.00
0005433284867	22607	Economy	16200.00
0005433007975	22607	Economy	16200.00
0005433007987	22607	Economy	16200.00
0005433007978	22607	Economy	16200.00
0005433007984	22607	Economy	16200.00
0005433007999	22607	Economy	16200.00
0005433007990	22607	Economy	16200.00
0005433284868	22607	Economy	16200.00
0005433007967	22607	Economy	16200.00
0005433007963	22607	Economy	16200.00
0005433007976	22607	Economy	16200.00
0005433007980	22607	Economy	16200.00
0005433284870	22607	Economy	16200.00
0005433008004	22607	Economy	16200.00
0005433284878	22607	Economy	16200.00
0005433007973	22607	Economy	16200.00
0005433284875	22607	Economy	16200.00
0005433845907	5573	Business	99800.00
0005433845934	5573	Business	99800.00
0005433845924	5573	Business	99800.00
0005433845923	5573	Business	99800.00
0005433845955	5573	Business	99800.00
0005433845957	5573	Business	99800.00
0005433845913	5573	Business	99800.00
0005433845928	5573	Business	99800.00
0005433845910	5573	Business	99800.00
0005433845961	5573	Business	99800.00
0005433845903	5573	Business	99800.00
0005433845954	5573	Economy	33300.00
0005433845947	5573	Economy	33300.00
0005433845929	5573	Economy	33300.00
0005433845916	5573	Economy	33300.00
0005433845935	5573	Economy	36600.00
0005435282082	5573	Economy	36600.00
0005433815318	5573	Economy	36600.00
0005433845940	5573	Economy	33300.00
0005432081425	5573	Economy	33300.00
0005433845936	5573	Economy	33300.00
0005433845939	5573	Economy	33300.00
0005433845906	5573	Economy	33300.00
0005433845951	5573	Economy	33300.00
0005433845937	5573	Economy	33300.00
0005433845956	5573	Economy	33300.00
0005433845904	5573	Economy	33300.00
0005433815319	5573	Economy	33300.00
0005433845938	5573	Economy	33300.00
0005433845912	5573	Economy	33300.00
0005433845918	5573	Economy	33300.00
0005433845921	5573	Economy	33300.00
0005433845943	5573	Economy	33300.00
0005433845958	5573	Economy	33300.00
0005433845915	5573	Economy	33300.00
0005433845919	5573	Economy	33300.00
0005433845945	5573	Economy	33300.00
0005433845927	5573	Economy	33300.00
0005433845922	5573	Economy	33300.00
0005433845905	5573	Economy	33300.00
0005433845942	5573	Economy	33300.00
0005433845931	5573	Economy	33300.00
0005433845960	5573	Economy	33300.00
0005433845911	5573	Economy	33300.00
0005433845914	5573	Economy	33300.00
0005433845909	5573	Economy	33300.00
0005432081424	5573	Economy	33300.00
0005433845946	5573	Economy	33300.00
0005433845926	5573	Economy	33300.00
0005433815315	5573	Economy	33300.00
0005433845950	5573	Economy	33300.00
0005433845925	5573	Economy	33300.00
0005433815317	5573	Economy	33300.00
0005433815316	5573	Economy	33300.00
0005433845917	5573	Economy	33300.00
0005433845944	5573	Economy	33300.00
0005433845908	5573	Economy	33300.00
0005433845933	5573	Economy	33300.00
0005433845953	5573	Economy	33300.00
0005433845920	5573	Economy	33300.00
0005432081423	5573	Economy	33300.00
0005433845941	5573	Economy	33300.00
0005433845952	5573	Economy	33300.00
0005433845959	5573	Economy	33300.00
0005433845949	5573	Economy	33300.00
0005433845948	5573	Economy	33300.00
0005433845932	5573	Economy	33300.00
0005433845930	5573	Economy	33300.00
0005435282158	13877	Business	99800.00
0005435282162	13877	Business	99800.00
0005433845673	13877	Business	99800.00
0005432003659	13877	Business	99800.00
0005435282168	13877	Business	99800.00
0005433845670	13877	Business	99800.00
0005435282180	13877	Economy	33300.00
0005433845757	13877	Economy	33300.00
0005435282172	13877	Economy	33300.00
0005434173465	13877	Economy	33300.00
0005435282174	13877	Economy	33300.00
0005435282170	13877	Economy	33300.00
0005435282153	13877	Economy	33300.00
0005435282178	13877	Economy	36600.00
0005435282171	13877	Economy	33300.00
0005434173467	13877	Economy	33300.00
0005435282177	13877	Economy	33300.00
0005435282156	13877	Economy	33300.00
0005433845758	13877	Economy	33300.00
0005435282159	13877	Economy	33300.00
0005435282167	13877	Economy	33300.00
0005435282166	13877	Economy	33300.00
0005433845671	13877	Economy	33300.00
0005433845672	13877	Economy	33300.00
0005435282179	13877	Economy	33300.00
0005435282164	13877	Economy	33300.00
0005435282176	13877	Economy	33300.00
0005432003658	13877	Economy	33300.00
0005435282169	13877	Economy	33300.00
0005435282161	13877	Economy	33300.00
0005435282165	13877	Economy	33300.00
0005432003660	13877	Economy	33300.00
0005434173466	13877	Economy	33300.00
0005435282154	13877	Economy	33300.00
0005435282160	13877	Economy	33300.00
0005435282163	13877	Economy	33300.00
0005433845814	13877	Economy	33300.00
0005435282155	13877	Economy	33300.00
0005435282175	13877	Economy	33300.00
0005435282173	13877	Economy	33300.00
0005435282157	13877	Economy	33300.00
0005435332147	7811	Economy	16600.00
0005434620316	7811	Economy	15100.00
0005434620318	7811	Economy	15100.00
0005434620319	7811	Economy	15100.00
0005434620307	7811	Economy	15100.00
0005434620326	7811	Economy	15100.00
0005434620323	7811	Economy	15100.00
0005432112484	7811	Economy	15100.00
0005434620317	7811	Economy	15100.00
0005434620312	7811	Economy	15100.00
0005435332148	7811	Economy	15100.00
0005434620320	7811	Economy	15100.00
0005434620306	7811	Economy	15100.00
0005434620315	7811	Economy	15100.00
0005434620325	7811	Economy	15100.00
0005434620308	7811	Economy	15100.00
0005434620314	7811	Economy	15100.00
0005434620322	7811	Economy	15100.00
0005434620311	7811	Economy	15100.00
0005434620309	7811	Economy	15100.00
0005434620310	7811	Economy	15100.00
0005434620313	7811	Economy	15100.00
0005434620321	7811	Economy	15100.00
0005432112485	7811	Economy	15100.00
0005434620324	7811	Economy	15100.00
0005435332193	32983	Economy	16600.00
0005435332198	32983	Economy	15100.00
0005435332190	32983	Economy	15100.00
0005435332191	32983	Economy	15100.00
0005435332196	32983	Economy	15100.00
0005435332192	32983	Economy	15100.00
0005435332195	32983	Economy	15100.00
0005435332189	32983	Economy	15100.00
0005435332194	32983	Economy	15100.00
0005435332197	32983	Economy	15100.00
0005435784893	4313	Business	38000.00
0005432190575	4313	Business	38000.00
0005435784888	4313	Business	38000.00
0005432190578	4313	Business	38000.00
0005435787324	4313	Business	38000.00
0005435784901	4313	Business	38000.00
0005434993891	4313	Business	38000.00
0005432190576	4313	Economy	12700.00
0005435784889	4313	Economy	12700.00
0005435787325	4313	Economy	12700.00
0005435784896	4313	Economy	12700.00
0005435784902	4313	Economy	12700.00
0005434993890	4313	Economy	12700.00
0005435784894	4313	Economy	13900.00
0005435784871	4313	Economy	13900.00
0005435784895	4313	Economy	13900.00
0005435784872	4313	Economy	12700.00
0005435784869	4313	Economy	12700.00
0005434993892	4313	Economy	12700.00
0005435784881	4313	Economy	12700.00
0005435784899	4313	Economy	12700.00
0005435784885	4313	Economy	12700.00
0005435784884	4313	Economy	12700.00
0005434993887	4313	Economy	12700.00
0005435784879	4313	Economy	12700.00
0005435784890	4313	Economy	12700.00
0005435784891	4313	Economy	12700.00
0005432190577	4313	Economy	12700.00
0005435784870	4313	Economy	12700.00
0005435784898	4313	Economy	12700.00
0005435784883	4313	Economy	12700.00
0005434993893	4313	Economy	12700.00
0005435784892	4313	Economy	12700.00
0005435784880	4313	Economy	12700.00
0005435784903	4313	Economy	12700.00
0005434993888	4313	Economy	12700.00
0005435784875	4313	Economy	12700.00
0005435784887	4313	Economy	12700.00
0005435784878	4313	Economy	12700.00
0005435784882	4313	Economy	12700.00
0005435784876	4313	Economy	12700.00
0005435784877	4313	Economy	12700.00
0005435784904	4313	Economy	12700.00
0005435784873	4313	Economy	12700.00
0005435784900	4313	Economy	12700.00
0005435784874	4313	Economy	12700.00
0005435784886	4313	Economy	12700.00
0005435784897	4313	Economy	12700.00
0005434993889	4313	Economy	12700.00
0005434993894	4313	Economy	12700.00
0005435937328	27282	Business	38000.00
0005435937327	27282	Business	38000.00
0005432195663	27282	Business	38000.00
0005435918590	27282	Business	38000.00
0005435918589	27282	Economy	12700.00
0005432195662	27282	Economy	13900.00
0005435918592	27282	Economy	13900.00
0005435918588	27282	Economy	12700.00
0005435918591	27282	Economy	12700.00
0005432459121	4703	Business	40900.00
0005432566796	4703	Business	40900.00
0005432459140	4703	Business	40900.00
0005432566785	4703	Business	40900.00
0005432571270	4703	Business	40900.00
0005432566818	4703	Business	40900.00
0005434081591	4703	Business	40900.00
0005432566779	4703	Business	40900.00
0005432566813	4703	Business	40900.00
0005432459165	4703	Business	40900.00
0005432459158	4703	Business	40900.00
0005432566797	4703	Business	40900.00
0005432566803	4703	Business	40900.00
0005432459153	4703	Business	40900.00
0005433726075	4703	Business	40900.00
0005432459146	4703	Business	40900.00
0005432459144	4703	Business	40900.00
0005432459135	4703	Business	40900.00
0005432566784	4703	Business	40900.00
0005432566804	4703	Business	40900.00
0005434081583	4703	Economy	15000.00
0005432566830	4703	Business	40900.00
0005432566807	4703	Economy	15000.00
0005434081588	4703	Economy	15000.00
0005432459157	4703	Economy	13600.00
0005434081584	4703	Economy	13600.00
0005432566808	4703	Economy	13600.00
0005432566829	4703	Economy	13600.00
0005432459141	4703	Economy	13600.00
0005434081587	4703	Economy	13600.00
0005432566822	4703	Economy	13600.00
0005432566792	4703	Economy	13600.00
0005432459168	4703	Economy	13600.00
0005434559082	4703	Economy	13600.00
0005432459148	4703	Economy	13600.00
0005432459133	4703	Economy	13600.00
0005432566832	4703	Economy	13600.00
0005432459129	4703	Economy	13600.00
0005432459152	4703	Economy	13600.00
0005432566805	4703	Economy	13600.00
0005432459138	4703	Economy	13600.00
0005432459150	4703	Economy	13600.00
0005432186819	4703	Economy	13600.00
0005432566833	4703	Economy	13600.00
0005432566800	4703	Economy	13600.00
0005432170295	4703	Economy	13600.00
0005432566812	4703	Economy	13600.00
0005432566776	4703	Economy	13600.00
0005434081596	4703	Economy	13600.00
0005432571269	4703	Economy	13600.00
0005432186820	4703	Economy	13600.00
0005432566821	4703	Economy	13600.00
0005434081581	4703	Economy	13600.00
0005432566831	4703	Economy	13600.00
0005434081589	4703	Economy	13600.00
0005433452710	4703	Economy	13600.00
0005434081577	4703	Economy	13600.00
0005432566817	4703	Economy	13600.00
0005432459127	4703	Economy	13600.00
0005432566825	4703	Economy	13600.00
0005432459156	4703	Economy	13600.00
0005432459132	4703	Economy	13600.00
0005434081580	4703	Economy	13600.00
0005432459160	4703	Economy	13600.00
0005433451591	4703	Economy	13600.00
0005432566815	4703	Economy	13600.00
0005432566835	4703	Economy	13600.00
0005432566816	4703	Economy	13600.00
0005432566794	4703	Economy	13600.00
0005432566809	4703	Economy	13600.00
0005432459162	4703	Economy	13600.00
0005432186821	4703	Economy	13600.00
0005432566836	4703	Economy	13600.00
0005432571271	4703	Economy	13600.00
0005432170298	4703	Economy	13600.00
0005434081578	4703	Economy	13600.00
0005432566786	4703	Economy	13600.00
0005432566795	4703	Economy	13600.00
0005432566798	4703	Economy	13600.00
0005432459124	4703	Economy	13600.00
0005433452711	4703	Economy	13600.00
0005432566824	4703	Economy	13600.00
0005432566827	4703	Economy	13600.00
0005432566788	4703	Economy	13600.00
0005432566826	4703	Economy	13600.00
0005432459164	4703	Economy	13600.00
0005432459128	4703	Economy	13600.00
0005432459125	4703	Economy	13600.00
0005432566793	4703	Economy	13600.00
0005432459154	4703	Economy	13600.00
0005432459161	4703	Economy	13600.00
0005432459134	4703	Economy	13600.00
0005432459126	4703	Economy	13600.00
0005432566834	4703	Economy	13600.00
0005432566790	4703	Economy	15000.00
0005432566789	4703	Economy	15000.00
0005434081593	4703	Economy	13600.00
0005434081582	4703	Economy	13600.00
0005432459118	4703	Economy	13600.00
0005432566828	4703	Economy	15000.00
0005432459136	4703	Economy	15000.00
0005432186822	4703	Economy	13600.00
0005432459145	4703	Economy	13600.00
0005432459155	4703	Economy	13600.00
0005432459151	4703	Economy	13600.00
0005432566820	4703	Economy	13600.00
0005434081595	4703	Economy	13600.00
0005432170292	4703	Economy	13600.00
0005432566810	4703	Economy	13600.00
0005432459142	4703	Economy	13600.00
0005432459147	4703	Economy	13600.00
0005432566837	4703	Economy	13600.00
0005432459169	4703	Economy	13600.00
0005432566811	4703	Economy	13600.00
0005432459166	4703	Economy	13600.00
0005432566791	4703	Economy	13600.00
0005432566780	4703	Economy	13600.00
0005432170296	4703	Economy	13600.00
0005432566777	4703	Economy	13600.00
0005433451592	4703	Economy	13600.00
0005432571268	4703	Economy	13600.00
0005432566799	4703	Economy	13600.00
0005432459131	4703	Economy	13600.00
0005433726073	4703	Economy	13600.00
0005434081590	4703	Economy	13600.00
0005432459137	4703	Economy	13600.00
0005432566781	4703	Economy	13600.00
0005434081585	4703	Economy	13600.00
0005432459130	4703	Economy	13600.00
0005432459123	4703	Economy	13600.00
0005432566823	4703	Economy	13600.00
0005432566802	4703	Economy	13600.00
0005432459117	4703	Economy	13600.00
0005432459120	4703	Economy	13600.00
0005432459116	4703	Economy	13600.00
0005434081592	4703	Economy	13600.00
0005432170294	4703	Economy	13600.00
0005432459149	4703	Economy	13600.00
0005434081579	4703	Economy	13600.00
0005432566806	4703	Economy	13600.00
0005434081597	4703	Economy	13600.00
0005432170297	4703	Economy	13600.00
0005432459167	4703	Economy	13600.00
0005433726074	4703	Economy	13600.00
0005432566782	4703	Economy	13600.00
0005432459170	4703	Economy	13600.00
0005432566783	4703	Economy	13600.00
0005432459159	4703	Economy	13600.00
0005432459143	4703	Economy	13600.00
0005432459122	4703	Economy	13600.00
0005432566787	4703	Economy	13600.00
0005432566778	4703	Economy	13600.00
0005432459139	4703	Economy	13600.00
0005434081594	4703	Economy	13600.00
0005432170293	4703	Economy	13600.00
0005434081586	4703	Economy	13600.00
0005432566819	4703	Economy	13600.00
0005432566814	4703	Economy	13600.00
0005432459119	4703	Economy	13600.00
0005432566801	4703	Economy	13600.00
0005432459163	4703	Economy	13600.00
0005432213556	30521	Business	40900.00
0005432161119	30521	Economy	15000.00
0005432213555	30521	Economy	13600.00
0005432161121	30521	Economy	13600.00
0005432213554	30521	Economy	13600.00
0005432161120	30521	Economy	13600.00
0005432566705	30521	Economy	13600.00
0005432161123	30521	Economy	13600.00
0005432566537	30521	Economy	13600.00
0005432161122	30521	Economy	13600.00
0005432566562	30521	Economy	13600.00
0005435722022	13631	Economy	9900.00
0005435720808	13631	Economy	9900.00
0005435720810	13631	Economy	9900.00
0005435720809	13631	Economy	9900.00
0005435722023	13631	Economy	9900.00
0005432295845	22796	Economy	8800.00
0005432295844	22796	Economy	8800.00
0005433341839	11117	Business	23600.00
0005433341876	11117	Business	23600.00
0005433341846	11117	Business	23600.00
0005433341868	11117	Business	23600.00
0005433341818	11117	Business	23600.00
0005433341838	11117	Business	23600.00
0005433341792	11117	Business	23600.00
0005433341822	11117	Business	23600.00
0005433341858	11117	Business	23600.00
0005433341821	11117	Business	23600.00
0005433341810	11117	Economy	7900.00
0005433341854	11117	Economy	7900.00
0005435097071	11117	Economy	7900.00
0005433341845	11117	Economy	7900.00
0005433341871	11117	Economy	7900.00
0005433341865	11117	Economy	7900.00
0005435097073	11117	Economy	7900.00
0005433341859	11117	Economy	7900.00
0005433341867	11117	Economy	7900.00
0005435097076	11117	Economy	7900.00
0005433341799	11117	Economy	7900.00
0005435097072	11117	Economy	7900.00
0005435097070	11117	Economy	7900.00
0005433341805	11117	Economy	7900.00
0005433341793	11117	Economy	7900.00
0005433341878	11117	Economy	7900.00
0005433341848	11117	Economy	7900.00
0005433341790	11117	Economy	7900.00
0005433341820	11117	Economy	7900.00
0005433341788	11117	Economy	7900.00
0005433341835	11117	Economy	7900.00
0005433341807	11117	Economy	7900.00
0005433341812	11117	Economy	7900.00
0005435097077	11117	Economy	7900.00
0005433341841	11117	Economy	7900.00
0005433341877	11117	Economy	7900.00
0005433341842	11117	Economy	7900.00
0005433341817	11117	Economy	7900.00
0005433341870	11117	Economy	7900.00
0005433341851	11117	Economy	7900.00
0005433341833	11117	Economy	7900.00
0005433341806	11117	Economy	7900.00
0005433341827	11117	Economy	7900.00
0005435097075	11117	Economy	7900.00
0005433341855	11117	Economy	7900.00
0005433341884	11117	Economy	8600.00
0005433341857	11117	Economy	8600.00
0005433341843	11117	Economy	8600.00
0005433341885	11117	Economy	8600.00
0005433341828	11117	Economy	8600.00
0005433341882	11117	Economy	7900.00
0005433341824	11117	Economy	7900.00
0005433341830	11117	Economy	7900.00
0005433341811	11117	Economy	7900.00
0005433341863	11117	Economy	7900.00
0005433341798	11117	Economy	7900.00
0005433341880	11117	Economy	7900.00
0005433341862	11117	Economy	7900.00
0005433341832	11117	Economy	7900.00
0005433341879	11117	Economy	7900.00
0005433341795	11117	Economy	7900.00
0005433341844	11117	Economy	7900.00
0005433341860	11117	Economy	7900.00
0005433341881	11117	Economy	7900.00
0005435097069	11117	Economy	7900.00
0005433341819	11117	Economy	7900.00
0005433341875	11117	Economy	7900.00
0005433341802	11117	Economy	7900.00
0005433341814	11117	Economy	7900.00
0005433341866	11117	Economy	7900.00
0005433341801	11117	Economy	7900.00
0005433341815	11117	Economy	7900.00
0005433341787	11117	Economy	7900.00
0005433341864	11117	Economy	7900.00
0005433341850	11117	Economy	7900.00
0005433341847	11117	Economy	7900.00
0005433341836	11117	Economy	7900.00
0005433341826	11117	Economy	7900.00
0005433341834	11117	Economy	7900.00
0005433341840	11117	Economy	7900.00
0005433341829	11117	Economy	7900.00
0005433341837	11117	Economy	7900.00
0005433341872	11117	Economy	7900.00
0005433341804	11117	Economy	7900.00
0005433341887	11117	Economy	7900.00
0005435097074	11117	Economy	7900.00
0005433341825	11117	Economy	7900.00
0005433341813	11117	Economy	7900.00
0005433341853	11117	Economy	7900.00
0005433341809	11117	Economy	7900.00
0005433341856	11117	Economy	7900.00
0005433341849	11117	Economy	7900.00
0005433341791	11117	Economy	7900.00
0005433341886	11117	Economy	7900.00
0005433341789	11117	Economy	7900.00
0005433341794	11117	Economy	7900.00
0005433341816	11117	Economy	7900.00
0005433341869	11117	Economy	7900.00
0005433341874	11117	Economy	7900.00
0005435097078	11117	Economy	7900.00
0005433341803	11117	Economy	7900.00
0005433341883	11117	Economy	7900.00
0005433341823	11117	Economy	7900.00
0005433341852	11117	Economy	7900.00
0005433341861	11117	Economy	7900.00
0005433341797	11117	Economy	7900.00
0005433341873	11117	Economy	7900.00
0005433341796	11117	Economy	7900.00
0005433341831	11117	Economy	7900.00
0005433341808	11117	Economy	7900.00
0005433341800	11117	Economy	7900.00
0005432293175	17125	Business	23600.00
0005432293174	17125	Economy	7900.00
0005435545638	17125	Economy	7900.00
0005435380239	17125	Economy	7900.00
0005433341476	17125	Economy	7900.00
0005435545636	17125	Economy	7900.00
0005435380237	17125	Economy	7900.00
0005435380235	17125	Economy	7900.00
0005435380236	17125	Economy	7900.00
0005435545640	17125	Economy	7900.00
0005435545637	17125	Economy	7900.00
0005433341580	17125	Economy	7900.00
0005435380238	17125	Economy	7900.00
0005435545639	17125	Economy	7900.00
0005433481063	9079	Business	26600.00
0005433506936	9079	Business	26600.00
0005433506935	9079	Economy	8900.00
0005433506938	9079	Economy	8900.00
0005433506941	9079	Economy	8900.00
0005433506937	9079	Economy	9800.00
0005433506933	9079	Economy	9800.00
0005433506930	9079	Economy	8900.00
0005433481065	9079	Economy	8900.00
0005433506942	9079	Economy	8900.00
0005433506931	9079	Economy	8900.00
0005433481062	9079	Economy	8900.00
0005433481066	9079	Economy	8900.00
0005433506934	9079	Economy	8900.00
0005433506940	9079	Economy	8900.00
0005433481061	9079	Economy	8900.00
0005433506939	9079	Economy	8900.00
0005433506943	9079	Economy	8900.00
0005433481064	9079	Economy	8900.00
0005433481060	9079	Economy	8900.00
0005433506932	9079	Economy	8900.00
0005432919600	20459	Business	26600.00
0005432919606	20459	Business	26600.00
0005432919589	20459	Economy	8900.00
0005432919605	20459	Economy	8900.00
0005432919603	20459	Economy	8900.00
0005432919596	20459	Economy	8900.00
0005432919594	20459	Economy	8900.00
0005432919604	20459	Economy	8900.00
0005432919597	20459	Economy	8900.00
0005432919609	20459	Economy	8900.00
0005432919602	20459	Economy	8900.00
0005432919607	20459	Economy	8900.00
0005432919592	20459	Economy	8900.00
0005432919590	20459	Economy	8900.00
0005432919598	20459	Economy	8900.00
0005432919591	20459	Economy	8900.00
0005432919599	20459	Economy	8900.00
0005432919601	20459	Economy	8900.00
0005432919593	20459	Economy	8900.00
0005432919595	20459	Economy	8900.00
0005433506884	20459	Economy	8900.00
0005433506867	20459	Economy	8900.00
0005432919608	20459	Economy	8900.00
0005433506883	20459	Economy	8900.00
0005432919588	20459	Economy	8900.00
0005432394047	10224	Economy	5800.00
0005432396186	10224	Economy	5800.00
0005432394045	10224	Economy	5800.00
0005432394044	10224	Economy	5800.00
0005432396183	10224	Economy	5800.00
0005432396184	10224	Economy	5800.00
0005432394046	10224	Economy	5800.00
0005432396185	10224	Economy	5800.00
0005435179385	18347	Economy	5800.00
0005435179386	18347	Economy	5800.00
0005434928262	10975	Business	9500.00
0005434411719	10975	Business	9500.00
0005434411722	10975	Economy	3200.00
0005434411723	10975	Economy	3200.00
0005434411721	10975	Economy	3200.00
0005434928261	10975	Economy	3200.00
0005434411720	10975	Economy	3200.00
0005435625937	14748	Business	9500.00
0005435125823	14748	Business	9500.00
0005435556658	14748	Business	9500.00
0005435125849	14748	Business	9500.00
0005435125821	14748	Business	9500.00
0005435125850	14748	Business	9500.00
0005435125817	14748	Business	9500.00
0005435125818	14748	Business	9500.00
0005435625935	14748	Business	9500.00
0005435125815	14748	Business	9500.00
0005435625933	14748	Business	9500.00
0005435625934	14748	Economy	3200.00
0005435125828	14748	Economy	3200.00
0005435125842	14748	Economy	3200.00
0005435125832	14748	Economy	3200.00
0005435554122	14748	Economy	3200.00
0005435625940	14748	Economy	3200.00
0005435625945	14748	Economy	3200.00
0005435625946	14748	Economy	3500.00
0005435125851	14748	Economy	3500.00
0005435125825	14748	Economy	3500.00
0005435625930	14748	Economy	3200.00
0005435625944	14748	Economy	3200.00
0005435625928	14748	Economy	3200.00
0005435125841	14748	Economy	3200.00
0005435125838	14748	Economy	3200.00
0005435125837	14748	Economy	3200.00
0005435625948	14748	Economy	3200.00
0005435125834	14748	Economy	3200.00
0005435125840	14748	Economy	3200.00
0005435125831	14748	Economy	3200.00
0005435125854	14748	Economy	3200.00
0005435625932	14748	Economy	3200.00
0005435125826	14748	Economy	3200.00
0005435125827	14748	Economy	3200.00
0005435625929	14748	Economy	3200.00
0005435125830	14748	Economy	3200.00
0005435125846	14748	Economy	3200.00
0005435625938	14748	Economy	3200.00
0005435125836	14748	Economy	3200.00
0005435125855	14748	Economy	3200.00
0005435625947	14748	Economy	3200.00
0005435554121	14748	Economy	3200.00
0005435125824	14748	Economy	3200.00
0005435125835	14748	Economy	3200.00
0005435625939	14748	Economy	3200.00
0005435125845	14748	Economy	3200.00
0005435125843	14748	Economy	3200.00
0005435125814	14748	Economy	3200.00
0005435554120	14748	Economy	3200.00
0005435554119	14748	Economy	3200.00
0005435625931	14748	Economy	3200.00
0005435125822	14748	Economy	3200.00
0005435125853	14748	Economy	3200.00
0005435125829	14748	Economy	3200.00
0005435125820	14748	Economy	3200.00
0005435125852	14748	Economy	3200.00
0005435625936	14748	Economy	3200.00
0005435625941	14748	Economy	3200.00
0005435554118	14748	Economy	3200.00
0005435625943	14748	Economy	3200.00
0005435125833	14748	Economy	3200.00
0005435625942	14748	Economy	3200.00
0005435125847	14748	Economy	3200.00
0005435125839	14748	Economy	3200.00
0005435125819	14748	Economy	3200.00
0005435125848	14748	Economy	3200.00
0005435125816	14748	Economy	3200.00
0005435125844	14748	Economy	3200.00
0005432398148	7092	Business	86900.00
0005435715244	7092	Business	86900.00
0005435715247	7092	Economy	29000.00
0005435715240	7092	Economy	29000.00
0005435715239	7092	Economy	29000.00
0005435715232	7092	Economy	29000.00
0005432400076	7092	Economy	31900.00
0005435715235	7092	Economy	29000.00
0005435715242	7092	Economy	29000.00
0005432398147	7092	Economy	29000.00
0005432400074	7092	Economy	29000.00
0005435715246	7092	Economy	29000.00
0005435715237	7092	Economy	29000.00
0005435715241	7092	Economy	29000.00
0005435715233	7092	Economy	29000.00
0005435715236	7092	Economy	29000.00
0005435715238	7092	Economy	29000.00
0005435715231	7092	Economy	29000.00
0005435715229	7092	Economy	29000.00
0005435715234	7092	Economy	29000.00
0005432400073	7092	Economy	29000.00
0005432398146	7092	Economy	29000.00
0005435715230	7092	Economy	29000.00
0005435715245	7092	Economy	29000.00
0005432400075	7092	Economy	29000.00
0005435715243	7092	Economy	29000.00
0005435715248	7092	Economy	29000.00
0005435715162	27056	Economy	29000.00
0005435216558	27056	Economy	31900.00
0005435216559	27056	Economy	31900.00
0005435443186	27056	Economy	31900.00
0005435218101	27056	Economy	29000.00
0005435715160	27056	Economy	29000.00
0005435443182	27056	Economy	29000.00
0005435443188	27056	Economy	29000.00
0005435216556	27056	Economy	29000.00
0005435218104	27056	Economy	29000.00
0005435217679	27056	Economy	29000.00
0005435217684	27056	Economy	29000.00
0005435218102	27056	Economy	29000.00
0005435443191	27056	Economy	29000.00
0005435443185	27056	Economy	29000.00
0005435443184	27056	Economy	29000.00
0005435715161	27056	Economy	29000.00
0005435178474	27056	Economy	29000.00
0005435217682	27056	Economy	29000.00
0005435178475	27056	Economy	29000.00
0005435218100	27056	Economy	29000.00
0005435443187	27056	Economy	29000.00
0005435715171	27056	Economy	29000.00
0005435715163	27056	Economy	29000.00
0005435715172	27056	Economy	29000.00
0005435443189	27056	Economy	29000.00
0005435443190	27056	Economy	29000.00
0005435216557	27056	Economy	29000.00
0005435443183	27056	Economy	29000.00
0005435218103	27056	Economy	29000.00
0005435217680	27056	Economy	29000.00
0005435217683	27056	Economy	29000.00
0005435216560	27056	Economy	29000.00
0005435216555	27056	Economy	29000.00
0005435217681	27056	Economy	29000.00
0005434084866	2718	Economy	7700.00
0005434084868	2718	Economy	7700.00
0005434084869	2718	Economy	7700.00
0005434084867	2718	Economy	7700.00
0005433060379	28512	Economy	7700.00
0005433060377	28512	Economy	7700.00
0005433060378	28512	Economy	7700.00
0005433788156	11163	Economy	27100.00
0005433788154	11163	Economy	24600.00
0005433788160	11163	Economy	24600.00
0005433788159	11163	Economy	24600.00
0005433788158	11163	Economy	24600.00
0005433788157	11163	Economy	24600.00
0005433788153	11163	Economy	24600.00
0005433788152	11163	Economy	24600.00
0005433788151	11163	Economy	24600.00
0005433788149	11163	Economy	24600.00
0005433788155	11163	Economy	24600.00
0005433788150	11163	Economy	24600.00
0005435548422	20677	Economy	27100.00
0005435548427	20677	Economy	27100.00
0005435548430	20677	Economy	24600.00
0005435548432	20677	Economy	24600.00
0005435548426	20677	Economy	24600.00
0005435548435	20677	Economy	24600.00
0005435548420	20677	Economy	24600.00
0005435548436	20677	Economy	24600.00
0005435548421	20677	Economy	24600.00
0005435548439	20677	Economy	24600.00
0005435548437	20677	Economy	24600.00
0005435548438	20677	Economy	24600.00
0005435548428	20677	Economy	24600.00
0005435548419	20677	Economy	24600.00
0005435548425	20677	Economy	24600.00
0005435548424	20677	Economy	24600.00
0005435548417	20677	Economy	24600.00
0005435548433	20677	Economy	24600.00
0005435548423	20677	Economy	24600.00
0005435548429	20677	Economy	24600.00
0005435548431	20677	Economy	24600.00
0005435548434	20677	Economy	24600.00
0005435548418	20677	Economy	24600.00
0005435540700	22269	Business	20200.00
0005435528950	22269	Business	20200.00
0005435540697	22269	Business	20200.00
0005435528961	22269	Business	20200.00
0005435528952	22269	Business	20200.00
0005435528957	22269	Business	20200.00
0005435540710	22269	Business	20200.00
0005435540693	22269	Business	20200.00
0005435528947	22269	Business	20200.00
0005435528954	22269	Economy	6700.00
0005435540694	22269	Economy	6700.00
0005435540702	22269	Economy	6700.00
0005435528955	22269	Economy	6700.00
0005435528948	22269	Economy	6700.00
0005435528958	22269	Economy	6700.00
0005435540692	22269	Economy	7400.00
0005435540707	22269	Economy	7400.00
0005435528962	22269	Economy	6700.00
0005432294454	22269	Economy	6700.00
0005435540691	22269	Economy	6700.00
0005435528965	22269	Economy	6700.00
0005435540708	22269	Economy	6700.00
0005435540705	22269	Economy	6700.00
0005435528959	22269	Economy	6700.00
0005432294453	22269	Economy	6700.00
0005435528953	22269	Economy	6700.00
0005435540709	22269	Economy	6700.00
0005435540703	22269	Economy	6700.00
0005435528964	22269	Economy	6700.00
0005435540696	22269	Economy	6700.00
0005435528960	22269	Economy	6700.00
0005435540701	22269	Economy	6700.00
0005435540699	22269	Economy	6700.00
0005435528966	22269	Economy	6700.00
0005435528951	22269	Economy	6700.00
0005435528963	22269	Economy	6700.00
0005435540690	22269	Economy	6700.00
0005435540698	22269	Economy	6700.00
0005435540706	22269	Economy	6700.00
0005435528956	22269	Economy	6700.00
0005435528949	22269	Economy	6700.00
0005435540695	22269	Economy	6700.00
0005435540704	22269	Economy	6700.00
0005434906610	2287	Business	20200.00
0005434906615	2287	Business	20200.00
0005434906631	2287	Business	20200.00
0005434906593	2287	Business	20200.00
0005434906630	2287	Business	20200.00
0005434906575	2287	Business	20200.00
0005434906621	2287	Business	20200.00
0005434906600	2287	Economy	6700.00
0005434906619	2287	Economy	6700.00
0005434906622	2287	Economy	6700.00
0005434906618	2287	Economy	6700.00
0005434906632	2287	Economy	6700.00
0005434906576	2287	Economy	6700.00
0005434906573	2287	Economy	6700.00
0005434906616	2287	Economy	6700.00
0005434906578	2287	Economy	7400.00
0005434906601	2287	Economy	7400.00
0005434906572	2287	Economy	6700.00
0005434906624	2287	Economy	6700.00
0005434906582	2287	Economy	6700.00
0005434906606	2287	Economy	6700.00
0005434906611	2287	Economy	6700.00
0005434906583	2287	Economy	6700.00
0005434906604	2287	Economy	6700.00
0005434906633	2287	Economy	6700.00
0005434906627	2287	Economy	6700.00
0005434906602	2287	Economy	6700.00
0005434906599	2287	Economy	6700.00
0005434906587	2287	Economy	6700.00
0005434906588	2287	Economy	6700.00
0005434906592	2287	Economy	6700.00
0005434906589	2287	Economy	6700.00
0005434906623	2287	Economy	6700.00
0005434906579	2287	Economy	6700.00
0005434906629	2287	Economy	6700.00
0005434906605	2287	Economy	6700.00
0005434906617	2287	Economy	6700.00
0005434906625	2287	Economy	6700.00
0005434906580	2287	Economy	6700.00
0005434906594	2287	Economy	6700.00
0005434906609	2287	Economy	6700.00
0005434906584	2287	Economy	6700.00
0005434906581	2287	Economy	6700.00
0005434906591	2287	Economy	6700.00
0005434906626	2287	Economy	6700.00
0005434906608	2287	Economy	6700.00
0005434906597	2287	Economy	6700.00
0005434906598	2287	Economy	6700.00
0005433250982	2287	Economy	6700.00
0005434906628	2287	Economy	6700.00
0005434906577	2287	Economy	6700.00
0005434906595	2287	Economy	6700.00
0005434906620	2287	Economy	6700.00
0005434906596	2287	Economy	6700.00
0005434906590	2287	Economy	6700.00
0005434906603	2287	Economy	6700.00
0005434906612	2287	Economy	6700.00
0005434906585	2287	Economy	6700.00
0005434906574	2287	Economy	6700.00
0005434906613	2287	Economy	6700.00
0005434906614	2287	Economy	6700.00
0005434906607	2287	Economy	6700.00
0005434906586	2287	Economy	6700.00
0005433251084	25612	Business	20200.00
0005433400945	25612	Business	20200.00
0005433251059	25612	Business	20200.00
0005433251069	25612	Business	20200.00
0005433251061	25612	Business	20200.00
0005433251054	25612	Economy	6700.00
0005433251064	25612	Economy	6700.00
0005433251081	25612	Economy	6700.00
0005433251071	25612	Economy	7400.00
0005433251058	25612	Economy	6700.00
0005433400944	25612	Economy	6700.00
0005433251072	25612	Economy	6700.00
0005433251083	25612	Economy	6700.00
0005433251055	25612	Economy	6700.00
0005433251070	25612	Economy	6700.00
0005433251068	25612	Economy	6700.00
0005433251066	25612	Economy	6700.00
0005433251073	25612	Economy	6700.00
0005433251074	25612	Economy	6700.00
0005433251080	25612	Economy	6700.00
0005433251076	25612	Economy	6700.00
0005433251060	25612	Economy	6700.00
0005433251067	25612	Economy	6700.00
0005433251079	25612	Economy	6700.00
0005433251057	25612	Economy	6700.00
0005433251065	25612	Economy	6700.00
0005433251056	25612	Economy	6700.00
0005433251082	25612	Economy	6700.00
0005433251075	25612	Economy	6700.00
0005433251078	25612	Economy	6700.00
0005433251077	25612	Economy	6700.00
0005433251063	25612	Economy	6700.00
0005433251062	25612	Economy	6700.00
0005432620852	2517	Economy	13600.00
0005432620853	2517	Economy	12400.00
0005432620855	2517	Economy	12400.00
0005432620851	2517	Economy	12400.00
0005432620856	2517	Economy	12400.00
0005432620847	2517	Economy	12400.00
0005432620854	2517	Economy	12400.00
0005432620848	2517	Economy	12400.00
0005432620850	2517	Economy	12400.00
0005432620849	2517	Economy	12400.00
0005432620857	2517	Economy	12400.00
0005432620845	2517	Economy	12400.00
0005432620844	2517	Economy	12400.00
0005432620846	2517	Economy	12400.00
0005432862197	28075	Economy	13600.00
0005432862201	28075	Economy	13600.00
0005432862196	28075	Economy	12400.00
0005432862195	28075	Economy	12400.00
0005432862200	28075	Economy	12400.00
0005432862198	28075	Economy	12400.00
0005432862199	28075	Economy	12400.00
0005433451591	31026	Economy	8400.00
0005433452711	31026	Economy	8400.00
0005433451592	31026	Economy	8400.00
0005433452710	31026	Economy	8400.00
0005433134060	11990	Economy	6600.00
0005434142554	29816	Economy	7200.00
0005433131647	29816	Economy	6600.00
0005434184638	29816	Economy	6600.00
0005434184637	29816	Economy	6600.00
0005433131645	29816	Economy	6600.00
0005434184639	29816	Economy	6600.00
0005433134078	29816	Economy	6600.00
0005434183553	29816	Economy	6600.00
0005434183554	29816	Economy	6600.00
0005433134077	29816	Economy	6600.00
0005434183552	29816	Economy	6600.00
0005433134076	29816	Economy	6600.00
0005433131648	29816	Economy	6600.00
0005434142555	29816	Economy	6600.00
0005433131646	29816	Economy	6600.00
0005435696930	16456	Economy	19900.00
0005435696950	16456	Economy	19900.00
0005435696943	16456	Economy	19900.00
0005435696949	16456	Economy	19900.00
0005435696945	16456	Economy	18100.00
0005435696934	16456	Economy	18100.00
0005435696953	16456	Economy	18100.00
0005435696955	16456	Economy	18100.00
0005435696944	16456	Economy	18100.00
0005435696954	16456	Economy	18100.00
0005435696948	16456	Economy	18100.00
0005435696939	16456	Economy	18100.00
0005435696956	16456	Economy	18100.00
0005435696937	16456	Economy	18100.00
0005435696952	16456	Economy	18100.00
0005435696947	16456	Economy	18100.00
0005435696938	16456	Economy	18100.00
0005435696935	16456	Economy	18100.00
0005435696957	16456	Economy	18100.00
0005435696929	16456	Economy	18100.00
0005435696951	16456	Economy	18100.00
0005435696931	16456	Economy	18100.00
0005435696942	16456	Economy	18100.00
0005435696936	16456	Economy	18100.00
0005435696940	16456	Economy	18100.00
0005435696932	16456	Economy	18100.00
0005435696946	16456	Economy	18100.00
0005435696933	16456	Economy	18100.00
0005435696941	16456	Economy	18100.00
0005435935006	24685	Economy	18100.00
0005435696886	24685	Economy	18100.00
0005435696887	24685	Economy	18100.00
0005435935005	24685	Economy	18100.00
0005435935007	24685	Economy	18100.00
0005435935004	24685	Economy	18100.00
0005433724741	18770	Economy	4400.00
0005433724742	18770	Economy	4400.00
0005433724740	18770	Economy	4400.00
0005433724739	18770	Economy	4400.00
0005432968811	21628	Economy	4400.00
0005432968812	21628	Economy	4400.00
0005434137096	7308	Business	23100.00
0005434137082	7308	Business	23100.00
0005434137038	7308	Business	23100.00
0005434137055	7308	Business	23100.00
0005434137083	7308	Business	23100.00
0005434137045	7308	Business	23100.00
0005434137034	7308	Business	23100.00
0005434137070	7308	Business	23100.00
0005434137023	7308	Business	23100.00
0005434137071	7308	Business	23100.00
0005434087449	7308	Business	23100.00
0005434137099	7308	Economy	7700.00
0005434137100	7308	Economy	7700.00
0005434137048	7308	Economy	7700.00
0005434137094	7308	Economy	7700.00
0005434137042	7308	Economy	7700.00
0005434137063	7308	Economy	7700.00
0005434137078	7308	Economy	7700.00
0005434137026	7308	Economy	7700.00
0005434137037	7308	Economy	7700.00
0005434137031	7308	Economy	8500.00
0005434137097	7308	Economy	8500.00
0005434137061	7308	Economy	8500.00
0005434137059	7308	Economy	8500.00
0005434137049	7308	Economy	8500.00
0005434137076	7308	Economy	7700.00
0005434137033	7308	Economy	7700.00
0005434087450	7308	Economy	7700.00
0005434137072	7308	Economy	7700.00
0005434137015	7308	Economy	7700.00
0005434137058	7308	Economy	7700.00
0005434137039	7308	Economy	7700.00
0005434137067	7308	Economy	7700.00
0005434137064	7308	Economy	7700.00
0005434137021	7308	Economy	7700.00
0005434137054	7308	Economy	7700.00
0005434137081	7308	Economy	7700.00
0005434137066	7308	Economy	7700.00
0005434137088	7308	Economy	7700.00
0005434137069	7308	Economy	7700.00
0005434137051	7308	Economy	7700.00
0005434137046	7308	Economy	7700.00
0005434137028	7308	Economy	7700.00
0005434137019	7308	Economy	7700.00
0005434137035	7308	Economy	7700.00
0005434137014	7308	Economy	7700.00
0005434137068	7308	Economy	7700.00
0005434137092	7308	Economy	7700.00
0005434087447	7308	Economy	7700.00
0005434137016	7308	Economy	7700.00
0005434137077	7308	Economy	7700.00
0005434137024	7308	Economy	7700.00
0005434137053	7308	Economy	7700.00
0005434137065	7308	Economy	7700.00
0005434137040	7308	Economy	7700.00
0005434137029	7308	Economy	7700.00
0005434137050	7308	Economy	7700.00
0005434137060	7308	Economy	7700.00
0005434137017	7308	Economy	7700.00
0005434137079	7308	Economy	7700.00
0005434137062	7308	Economy	7700.00
0005434137084	7308	Economy	7700.00
0005434137044	7308	Economy	7700.00
0005434137036	7308	Economy	7700.00
0005434137056	7308	Economy	7700.00
0005434137032	7308	Economy	7700.00
0005434137018	7308	Economy	7700.00
0005434087448	7308	Economy	7700.00
0005434137074	7308	Economy	7700.00
0005434137089	7308	Economy	7700.00
0005434137030	7308	Economy	7700.00
0005434137075	7308	Economy	7700.00
0005434137043	7308	Economy	7700.00
0005434137090	7308	Economy	7700.00
0005434137080	7308	Economy	7700.00
0005434137087	7308	Economy	7700.00
0005434137095	7308	Economy	7700.00
0005434137098	7308	Economy	7700.00
0005434137086	7308	Economy	7700.00
0005434137022	7308	Economy	7700.00
0005434137020	7308	Economy	7700.00
0005434137025	7308	Economy	7700.00
0005434137057	7308	Economy	7700.00
0005434137052	7308	Economy	7700.00
0005434137091	7308	Economy	7700.00
0005434137085	7308	Economy	7700.00
0005434137047	7308	Economy	7700.00
0005434137027	7308	Economy	7700.00
0005434137073	7308	Economy	7700.00
0005434137041	7308	Economy	7700.00
0005434137093	7308	Economy	7700.00
0005434087451	7308	Economy	7700.00
0005434087436	28560	Economy	7700.00
0005435808095	1892	Economy	21700.00
0005434610182	1892	Economy	21700.00
0005435808096	1892	Economy	21700.00
0005435808101	1892	Economy	21700.00
0005435808099	1892	Economy	21700.00
0005435808098	1892	Economy	21700.00
0005434610181	1892	Economy	21700.00
0005435808100	1892	Economy	21700.00
0005435808093	1892	Economy	21700.00
0005435808094	1892	Economy	21700.00
0005434610180	1892	Economy	21700.00
0005435808102	1892	Economy	21700.00
0005434610183	1892	Economy	21700.00
0005435808097	1892	Economy	21700.00
0005434503486	16719	Economy	7600.00
0005434503612	22930	Economy	7600.00
0005434503608	22930	Economy	7600.00
0005434503603	22930	Economy	7600.00
0005434503578	22930	Economy	6900.00
0005434503616	22930	Economy	6900.00
0005434503592	22930	Economy	6900.00
0005434503588	22930	Economy	6900.00
0005434503587	22930	Economy	6900.00
0005434503591	22930	Economy	6900.00
0005434503618	22930	Economy	6900.00
0005434503606	22930	Economy	6900.00
0005434503610	22930	Economy	6900.00
0005434503598	22930	Economy	6900.00
0005434503601	22930	Economy	6900.00
0005434503604	22930	Economy	6900.00
0005434503596	22930	Economy	6900.00
0005434503613	22930	Economy	6900.00
0005434503579	22930	Economy	6900.00
0005434503597	22930	Economy	6900.00
0005434503611	22930	Economy	6900.00
0005434503605	22930	Economy	6900.00
0005434503590	22930	Economy	6900.00
0005434503595	22930	Economy	6900.00
0005434503583	22930	Economy	6900.00
0005434503602	22930	Economy	6900.00
0005434503593	22930	Economy	6900.00
0005434503581	22930	Economy	6900.00
0005434503582	22930	Economy	6900.00
0005434503584	22930	Economy	6900.00
0005434503585	22930	Economy	6900.00
0005434503615	22930	Economy	6900.00
0005434503580	22930	Economy	6900.00
0005434503609	22930	Economy	6900.00
0005434503617	22930	Economy	6900.00
0005434503614	22930	Economy	6900.00
0005434503594	22930	Economy	6900.00
0005434503600	22930	Economy	6900.00
0005434503599	22930	Economy	6900.00
0005434503607	22930	Economy	6900.00
0005434503586	22930	Economy	6900.00
0005434503589	22930	Economy	6900.00
0005435078129	2175	Economy	7000.00
0005435078133	2175	Economy	7000.00
0005435078140	2175	Economy	7000.00
0005435078141	2175	Economy	7000.00
0005435078132	2175	Economy	7000.00
0005435078136	2175	Economy	7000.00
0005435078137	2175	Economy	7000.00
0005435078135	2175	Economy	7000.00
0005435078139	2175	Economy	7000.00
0005435078134	2175	Economy	7000.00
0005435078138	2175	Economy	7000.00
0005435078131	2175	Economy	7000.00
0005435078130	2175	Economy	7000.00
0005435078142	2175	Economy	7000.00
0005435078128	2175	Economy	7000.00
0005433266594	24365	Economy	7700.00
0005433266597	24365	Economy	7000.00
0005433266599	24365	Economy	7000.00
0005433266603	24365	Economy	7000.00
0005433266600	24365	Economy	7000.00
0005433266598	24365	Economy	7000.00
0005433266596	24365	Economy	7000.00
0005433266595	24365	Economy	7000.00
0005433266601	24365	Economy	7000.00
0005433266602	24365	Economy	7000.00
0005434988598	6635	Economy	10800.00
0005434988592	6635	Economy	10800.00
0005434988594	6635	Economy	9800.00
0005435803224	6635	Economy	9800.00
0005434988589	6635	Economy	9800.00
0005434988595	6635	Economy	9800.00
0005434988588	6635	Economy	9800.00
0005434988593	6635	Economy	9800.00
0005434988597	6635	Economy	9800.00
0005434988596	6635	Economy	9800.00
0005435803225	6635	Economy	9800.00
0005434988591	6635	Economy	9800.00
0005434988590	6635	Economy	9800.00
0005435464481	23599	Economy	9800.00
0005435464480	23599	Economy	9800.00
0005432382660	30504	Business	9900.00
0005432382686	30504	Business	9900.00
0005432382652	30504	Business	9900.00
0005432382687	30504	Business	9900.00
0005433449683	30504	Business	9900.00
0005432382668	30504	Business	9900.00
0005432382679	30504	Business	9900.00
0005432382674	30504	Business	9900.00
0005432382658	30504	Business	9900.00
0005433453736	30504	Economy	3300.00
0005432382670	30504	Economy	3300.00
0005433449685	30504	Economy	3300.00
0005432382661	30504	Economy	3300.00
0005433449684	30504	Economy	3300.00
0005432382653	30504	Economy	3300.00
0005432382682	30504	Economy	3300.00
0005432382685	30504	Economy	3600.00
0005433449681	30504	Economy	3600.00
0005432382657	30504	Economy	3600.00
0005432382683	30504	Economy	3600.00
0005433449693	30504	Economy	3600.00
0005432382669	30504	Economy	3300.00
0005432382673	30504	Economy	3300.00
0005432382650	30504	Economy	3300.00
0005432382664	30504	Economy	3300.00
0005432382678	30504	Economy	3300.00
0005432382667	30504	Economy	3300.00
0005432382671	30504	Economy	3300.00
0005432382681	30504	Economy	3300.00
0005433449679	30504	Economy	3300.00
0005432382680	30504	Economy	3300.00
0005433449687	30504	Economy	3300.00
0005433449682	30504	Economy	3300.00
0005433453735	30504	Economy	3300.00
0005432382655	30504	Economy	3300.00
0005432382663	30504	Economy	3300.00
0005433449690	30504	Economy	3300.00
0005433449692	30504	Economy	3300.00
0005432382676	30504	Economy	3300.00
0005432382666	30504	Economy	3300.00
0005432382662	30504	Economy	3300.00
0005433449694	30504	Economy	3300.00
0005432382688	30504	Economy	3300.00
0005432382651	30504	Economy	3300.00
0005433449678	30504	Economy	3300.00
0005433449691	30504	Economy	3300.00
0005433449672	30504	Economy	3300.00
0005433449677	30504	Economy	3300.00
0005432382675	30504	Economy	3300.00
0005432382665	30504	Economy	3300.00
0005432382677	30504	Economy	3300.00
0005433449689	30504	Economy	3300.00
0005433449676	30504	Economy	3300.00
0005433449686	30504	Economy	3300.00
0005432382656	30504	Economy	3300.00
0005433449688	30504	Economy	3300.00
0005433449675	30504	Economy	3300.00
0005433449674	30504	Economy	3300.00
0005433449673	30504	Economy	3300.00
0005432382659	30504	Economy	3300.00
0005433454847	30504	Economy	3300.00
0005432382654	30504	Economy	3300.00
0005432382684	30504	Economy	3300.00
0005432382689	30504	Economy	3300.00
0005432382672	30504	Economy	3300.00
0005432382690	30504	Economy	3300.00
0005433449680	30504	Economy	3300.00
0005432382649	30504	Economy	3300.00
0005435548439	26472	Economy	23800.00
0005435548436	26472	Economy	23800.00
0005435548433	26472	Economy	23800.00
0005435548438	26472	Economy	23800.00
0005435548435	26472	Economy	23800.00
0005435548437	26472	Economy	23800.00
0005435548434	26472	Economy	23800.00
0005435299715	29745	Economy	17100.00
0005435302141	29745	Economy	17100.00
0005433126789	29745	Economy	17100.00
0005435302142	29745	Economy	15600.00
0005433129219	29745	Economy	15600.00
0005433129220	29745	Economy	15600.00
0005435302140	29745	Economy	15600.00
0005433126790	29745	Economy	15600.00
0005433126788	29745	Economy	15600.00
0005435299718	29745	Economy	15600.00
0005433126787	29745	Economy	15600.00
0005433126786	29745	Economy	15600.00
0005435299716	29745	Economy	15600.00
0005435299719	29745	Economy	15600.00
0005435302139	29745	Economy	15600.00
0005435299717	29745	Economy	15600.00
0005435302143	29745	Economy	15600.00
0005433129218	29745	Economy	15600.00
0005434287003	2436	Economy	17200.00
0005434287002	2436	Economy	17200.00
0005434286998	2436	Economy	15700.00
0005434286987	2436	Economy	15700.00
0005433109861	2436	Economy	15700.00
0005434286999	2436	Economy	15700.00
0005434286995	2436	Economy	15700.00
0005434286997	2436	Economy	15700.00
0005434286992	2436	Economy	15700.00
0005434286989	2436	Economy	15700.00
0005434287004	2436	Economy	15700.00
0005432264441	2436	Economy	15700.00
0005434287001	2436	Economy	15700.00
0005434286984	2436	Economy	15700.00
0005434286991	2436	Economy	15700.00
0005434286994	2436	Economy	15700.00
0005432264443	2436	Economy	15700.00
0005434287005	2436	Economy	15700.00
0005434286990	2436	Economy	15700.00
0005432264442	2436	Economy	15700.00
0005434286996	2436	Economy	15700.00
0005434286983	2436	Economy	15700.00
0005433109860	2436	Economy	15700.00
0005434286986	2436	Economy	15700.00
0005434286993	2436	Economy	15700.00
0005434286985	2436	Economy	15700.00
0005434287000	2436	Economy	15700.00
0005434286988	2436	Economy	15700.00
0005433109891	26856	Economy	17200.00
0005433109892	26856	Economy	17200.00
0005433109889	26856	Economy	15700.00
0005433109895	26856	Economy	15700.00
0005433109897	26856	Economy	15700.00
0005433109896	26856	Economy	15700.00
0005434286913	26856	Economy	15700.00
0005433109894	26856	Economy	15700.00
0005434286900	26856	Economy	15700.00
0005433109898	26856	Economy	15700.00
0005433109893	26856	Economy	15700.00
0005433109890	26856	Economy	15700.00
0005435856150	25450	Economy	25000.00
0005435856149	25450	Economy	22800.00
0005435856148	25450	Economy	22800.00
0005435856147	25450	Economy	22800.00
0005434272169	26659	Economy	25000.00
0005434272170	26659	Economy	22800.00
0005434272171	26659	Economy	22800.00
0005434273055	26659	Economy	22800.00
0005434273056	26659	Economy	22800.00
0005435314782	19077	Economy	22300.00
0005435314784	19077	Economy	22300.00
0005435314772	19077	Economy	22300.00
0005435314774	19077	Economy	22300.00
0005435314781	19077	Economy	22300.00
0005435314780	19077	Economy	22300.00
0005435314776	19077	Economy	22300.00
0005435314778	19077	Economy	22300.00
0005435314787	19077	Economy	22300.00
0005435314783	19077	Economy	22300.00
0005435314773	19077	Economy	22300.00
0005435314777	19077	Economy	22300.00
0005435314786	19077	Economy	22300.00
0005435314785	19077	Economy	22300.00
0005435314779	19077	Economy	22300.00
0005435314775	19077	Economy	22300.00
0005433874297	7785	Economy	17400.00
0005433874307	7785	Economy	17400.00
0005433874298	7785	Economy	17400.00
0005433874303	7785	Economy	17400.00
0005433874300	7785	Economy	17400.00
0005433874296	7785	Economy	17400.00
0005433874301	7785	Economy	17400.00
0005433874295	7785	Economy	17400.00
0005433874302	7785	Economy	17400.00
0005433874305	7785	Economy	17400.00
0005433874294	7785	Economy	17400.00
0005433874304	7785	Economy	17400.00
0005433874299	7785	Economy	17400.00
0005433874306	7785	Economy	17400.00
0005433867890	4762	Economy	19400.00
0005433867923	4762	Economy	19400.00
0005433867928	4762	Economy	19400.00
0005433867905	4762	Economy	17600.00
0005433867922	4762	Economy	17600.00
0005433867930	4762	Economy	17600.00
0005433867902	4762	Economy	17600.00
0005433867915	4762	Economy	17600.00
0005433867925	4762	Economy	17600.00
0005433867909	4762	Economy	17600.00
0005433867910	4762	Economy	17600.00
0005433867894	4762	Economy	17600.00
0005433867921	4762	Economy	17600.00
0005433867895	4762	Economy	17600.00
0005433867908	4762	Economy	17600.00
0005433867891	4762	Economy	17600.00
0005433867911	4762	Economy	17600.00
0005433867903	4762	Economy	17600.00
0005433867912	4762	Economy	17600.00
0005433867906	4762	Economy	17600.00
0005433867892	4762	Economy	17600.00
0005433867919	4762	Economy	17600.00
0005433867916	4762	Economy	17600.00
0005433867907	4762	Economy	17600.00
0005433867897	4762	Economy	17600.00
0005433867914	4762	Economy	17600.00
0005433867899	4762	Economy	17600.00
0005433867927	4762	Economy	17600.00
0005433867898	4762	Economy	17600.00
0005433867929	4762	Economy	17600.00
0005433867893	4762	Economy	17600.00
0005433867904	4762	Economy	17600.00
0005433867926	4762	Economy	17600.00
0005433867900	4762	Economy	17600.00
0005433867917	4762	Economy	17600.00
0005433867920	4762	Economy	17600.00
0005433867918	4762	Economy	17600.00
0005433867924	4762	Economy	17600.00
0005433867901	4762	Economy	17600.00
0005433867896	4762	Economy	17600.00
0005433867913	4762	Economy	17600.00
0005435860442	32610	Economy	19400.00
0005434461620	3420	Economy	24800.00
0005434663228	3420	Economy	24800.00
0005434663229	3420	Economy	22600.00
0005434460475	3420	Economy	22600.00
0005434461618	3420	Economy	22600.00
0005434663231	3420	Economy	22600.00
0005434663230	3420	Economy	22600.00
0005434663225	3420	Economy	22600.00
0005434663224	3420	Economy	22600.00
0005434663222	3420	Economy	22600.00
0005434460476	3420	Economy	22600.00
0005434663226	3420	Economy	22600.00
0005434663234	3420	Economy	22600.00
0005434663233	3420	Economy	22600.00
0005434461619	3420	Economy	22600.00
0005434663227	3420	Economy	22600.00
0005434663232	3420	Economy	22600.00
0005434663223	3420	Economy	22600.00
0005435911349	12460	Economy	24800.00
0005435911351	12460	Economy	22600.00
0005435911348	12460	Economy	22600.00
0005435911347	12460	Economy	22600.00
0005435911353	12460	Economy	22600.00
0005435911350	12460	Economy	22600.00
0005435911352	12460	Economy	22600.00
0005435860442	14532	Economy	16800.00
0005433867876	32698	Economy	18500.00
0005433867859	32698	Economy	18500.00
0005433867862	32698	Economy	18500.00
0005433867868	32698	Economy	18500.00
0005433867867	32698	Economy	16800.00
0005433867866	32698	Economy	16800.00
0005433867873	32698	Economy	16800.00
0005433867864	32698	Economy	16800.00
0005433867888	32698	Economy	16800.00
0005433867887	32698	Economy	16800.00
0005433867865	32698	Economy	16800.00
0005433867881	32698	Economy	16800.00
0005433867860	32698	Economy	16800.00
0005433867853	32698	Economy	16800.00
0005433867879	32698	Economy	16800.00
0005433867884	32698	Economy	16800.00
0005433867877	32698	Economy	16800.00
0005433867856	32698	Economy	16800.00
0005433867882	32698	Economy	16800.00
0005433867863	32698	Economy	16800.00
0005433867872	32698	Economy	16800.00
0005433867885	32698	Economy	16800.00
0005433867886	32698	Economy	16800.00
0005433867874	32698	Economy	16800.00
0005433867875	32698	Economy	16800.00
0005433867869	32698	Economy	16800.00
0005433867854	32698	Economy	16800.00
0005433867857	32698	Economy	16800.00
0005433867880	32698	Economy	16800.00
0005433867852	32698	Economy	16800.00
0005433867851	32698	Economy	16800.00
0005433867883	32698	Economy	16800.00
0005433867858	32698	Economy	16800.00
0005433867871	32698	Economy	16800.00
0005433867878	32698	Economy	16800.00
0005433867870	32698	Economy	16800.00
0005433867861	32698	Economy	16800.00
0005433867855	32698	Economy	16800.00
0005433867889	32698	Economy	16800.00
0005432798988	12136	Economy	4400.00
0005432799046	12136	Economy	4400.00
0005432798989	12136	Economy	4400.00
0005432799047	12136	Economy	4400.00
0005432799058	14816	Economy	4900.00
0005432799041	14816	Economy	4900.00
0005432799047	14816	Economy	4400.00
0005432799056	14816	Economy	4400.00
0005432799060	14816	Economy	4400.00
0005432799062	14816	Economy	4400.00
0005432799051	14816	Economy	4400.00
0005432799059	14816	Economy	4400.00
0005432799055	14816	Economy	4400.00
0005432799061	14816	Economy	4400.00
0005432799063	14816	Economy	4400.00
0005432799043	14816	Economy	4400.00
0005432799066	14816	Economy	4400.00
0005432799057	14816	Economy	4400.00
0005432799048	14816	Economy	4400.00
0005432799052	14816	Economy	4400.00
0005432799054	14816	Economy	4400.00
0005432799064	14816	Economy	4400.00
0005432799067	14816	Economy	4400.00
0005432799068	14816	Economy	4400.00
0005432799065	14816	Economy	4400.00
0005432799050	14816	Economy	4400.00
0005432799044	14816	Economy	4400.00
0005432799045	14816	Economy	4400.00
0005432799053	14816	Economy	4400.00
0005432799042	14816	Economy	4400.00
0005432799049	14816	Economy	4400.00
0005432799040	14816	Economy	4400.00
0005432799046	14816	Economy	4400.00
0005434406930	7038	Business	49100.00
0005434299247	7038	Business	49100.00
0005434299260	7038	Business	49100.00
0005434406936	7038	Business	49100.00
0005434299254	7038	Business	49100.00
0005434406958	7038	Business	49100.00
0005432108215	7038	Business	49100.00
0005432153845	7038	Economy	16400.00
0005434406895	7038	Economy	16400.00
0005434406952	7038	Economy	16400.00
0005434406925	7038	Economy	16400.00
0005434406941	7038	Economy	16400.00
0005434406946	7038	Economy	16400.00
0005434406944	7038	Economy	16400.00
0005434406934	7038	Economy	16400.00
0005434406953	7038	Economy	16400.00
0005434406922	7038	Economy	16400.00
0005434299259	7038	Economy	16400.00
0005434299264	7038	Economy	16400.00
0005434406914	7038	Economy	16400.00
0005432153847	7038	Economy	16400.00
0005434406900	7038	Economy	16400.00
0005434406923	7038	Economy	16400.00
0005434299243	7038	Economy	16400.00
0005434406955	7038	Economy	16400.00
0005434406945	7038	Economy	16400.00
0005434299242	7038	Economy	16400.00
0005434406954	7038	Economy	16400.00
0005432153844	7038	Economy	16400.00
0005434406940	7038	Economy	16400.00
0005432153848	7038	Economy	16400.00
0005434406938	7038	Economy	16400.00
0005434299245	7038	Economy	16400.00
0005434406902	7038	Economy	16400.00
0005432153849	7038	Economy	16400.00
0005432153843	7038	Economy	16400.00
0005434406943	7038	Economy	18000.00
0005434406927	7038	Economy	18000.00
0005434406916	7038	Economy	18000.00
0005432108217	7038	Economy	18000.00
0005434406928	7038	Economy	18000.00
0005434299256	7038	Economy	16400.00
0005434406899	7038	Economy	16400.00
0005434406896	7038	Economy	16400.00
0005434406906	7038	Economy	16400.00
0005434406908	7038	Economy	16400.00
0005434406915	7038	Economy	16400.00
0005432153846	7038	Economy	16400.00
0005434406929	7038	Economy	16400.00
0005434299249	7038	Economy	16400.00
0005434299241	7038	Economy	16400.00
0005434406951	7038	Economy	16400.00
0005434406910	7038	Economy	16400.00
0005434406957	7038	Economy	16400.00
0005434299257	7038	Economy	16400.00
0005434299248	7038	Economy	16400.00
0005432108216	7038	Economy	16400.00
0005434406918	7038	Economy	16400.00
0005434299261	7038	Economy	16400.00
0005434406949	7038	Economy	16400.00
0005434406909	7038	Economy	16400.00
0005434406920	7038	Economy	16400.00
0005434406917	7038	Economy	16400.00
0005434406926	7038	Economy	16400.00
0005434406939	7038	Economy	16400.00
0005434406950	7038	Economy	16400.00
0005434406919	7038	Economy	16400.00
0005434406924	7038	Economy	16400.00
0005434299252	7038	Economy	16400.00
0005434299263	7038	Economy	16400.00
0005434406897	7038	Economy	16400.00
0005434406932	7038	Economy	16400.00
0005434406912	7038	Economy	16400.00
0005434406933	7038	Economy	16400.00
0005434406903	7038	Economy	16400.00
0005434406905	7038	Economy	16400.00
0005434406948	7038	Economy	16400.00
0005434406898	7038	Economy	16400.00
0005434406956	7038	Economy	16400.00
0005434299262	7038	Economy	16400.00
0005434406947	7038	Economy	16400.00
0005434299258	7038	Economy	16400.00
0005434299250	7038	Economy	16400.00
0005434299246	7038	Economy	16400.00
0005434406937	7038	Economy	16400.00
0005434406911	7038	Economy	16400.00
0005434406921	7038	Economy	16400.00
0005434299255	7038	Economy	16400.00
0005434406901	7038	Economy	16400.00
0005434299244	7038	Economy	16400.00
0005434406907	7038	Economy	16400.00
0005434406942	7038	Economy	16400.00
0005434406931	7038	Economy	16400.00
0005434406935	7038	Economy	16400.00
0005434406913	7038	Economy	16400.00
0005434299251	7038	Economy	16400.00
0005434299253	7038	Economy	16400.00
0005434406904	7038	Economy	16400.00
0005435310901	26925	Business	49100.00
0005435310903	26925	Business	49100.00
0005435310896	26925	Economy	16400.00
0005432058325	26925	Economy	16400.00
0005435310899	26925	Economy	16400.00
0005435293104	26925	Economy	16400.00
0005435293097	26925	Economy	16400.00
0005435310898	26925	Economy	16400.00
0005435310902	26925	Economy	16400.00
0005435293101	26925	Economy	16400.00
0005435293108	26925	Economy	16400.00
0005435310900	26925	Economy	16400.00
0005435293099	26925	Economy	16400.00
0005435310897	26925	Economy	16400.00
0005435293103	26925	Economy	16400.00
0005435293100	26925	Economy	16400.00
0005435293096	26925	Economy	16400.00
0005435310895	26925	Economy	16400.00
0005432058327	26925	Economy	16400.00
0005435293107	26925	Economy	16400.00
0005432058326	26925	Economy	16400.00
0005435293106	26925	Economy	16400.00
0005435293098	26925	Economy	16400.00
0005435293102	26925	Economy	16400.00
0005435310905	26925	Economy	16400.00
0005435293105	26925	Economy	16400.00
0005435310904	26925	Economy	16400.00
0005434512040	6482	Economy	16500.00
0005432603811	6482	Economy	16500.00
0005432603838	6482	Economy	16500.00
0005432603813	6482	Economy	15000.00
0005432603822	6482	Economy	15000.00
0005432603828	6482	Economy	15000.00
0005432603839	6482	Economy	15000.00
0005434512042	6482	Economy	15000.00
0005432603829	6482	Economy	15000.00
0005432603825	6482	Economy	15000.00
0005432603805	6482	Economy	15000.00
0005432603842	6482	Economy	15000.00
0005432603807	6482	Economy	15000.00
0005434512043	6482	Economy	15000.00
0005432603815	6482	Economy	15000.00
0005432603827	6482	Economy	15000.00
0005432603808	6482	Economy	15000.00
0005432603830	6482	Economy	15000.00
0005432603821	6482	Economy	15000.00
0005432603806	6482	Economy	15000.00
0005432603819	6482	Economy	15000.00
0005432603812	6482	Economy	15000.00
0005432603818	6482	Economy	15000.00
0005432603834	6482	Economy	15000.00
0005432603832	6482	Economy	15000.00
0005432603816	6482	Economy	15000.00
0005432603810	6482	Economy	15000.00
0005432603823	6482	Economy	15000.00
0005432603833	6482	Economy	15000.00
0005432603820	6482	Economy	15000.00
0005432603826	6482	Economy	15000.00
0005432603836	6482	Economy	15000.00
0005432603824	6482	Economy	15000.00
0005432603841	6482	Economy	15000.00
0005434512038	6482	Economy	15000.00
0005432603835	6482	Economy	15000.00
0005432603814	6482	Economy	15000.00
0005434512039	6482	Economy	15000.00
0005432603809	6482	Economy	15000.00
0005432603837	6482	Economy	15000.00
0005434512041	6482	Economy	15000.00
0005432603831	6482	Economy	15000.00
0005432603843	6482	Economy	15000.00
0005432603840	6482	Economy	15000.00
0005432603804	6482	Economy	15000.00
0005432603817	6482	Economy	15000.00
0005433251058	14997	Business	18900.00
0005433251079	14997	Business	18900.00
0005433251082	14997	Business	18900.00
0005433251065	14997	Business	18900.00
0005433251059	14997	Economy	6300.00
0005433251074	14997	Economy	6300.00
0005433251063	14997	Economy	6300.00
0005433251072	14997	Economy	6300.00
0005433251066	14997	Economy	6900.00
0005433251061	14997	Economy	6900.00
0005433251077	14997	Economy	6900.00
0005433251054	14997	Economy	6300.00
0005433251056	14997	Economy	6300.00
0005433251081	14997	Economy	6300.00
0005433251084	14997	Economy	6300.00
0005433251078	14997	Economy	6300.00
0005433251068	14997	Economy	6300.00
0005433251070	14997	Economy	6300.00
0005433251060	14997	Economy	6300.00
0005433251075	14997	Economy	6300.00
0005433251073	14997	Economy	6300.00
0005433251071	14997	Economy	6300.00
0005433251069	14997	Economy	6300.00
0005433251083	14997	Economy	6300.00
0005433251062	14997	Economy	6300.00
0005433251067	14997	Economy	6300.00
0005433251057	14997	Economy	6300.00
0005433251064	14997	Economy	6300.00
0005433251080	14997	Economy	6300.00
0005433251055	14997	Economy	6300.00
0005433251076	14997	Economy	6300.00
0005434906551	25824	Business	18900.00
0005434906520	25824	Business	18900.00
0005434906547	25824	Business	18900.00
0005434906544	25824	Business	18900.00
0005434906550	25824	Business	18900.00
0005434906535	25824	Business	18900.00
0005434906524	25824	Business	18900.00
0005434906552	25824	Economy	6300.00
0005434906540	25824	Economy	6300.00
0005434906516	25824	Economy	6300.00
0005434906569	25824	Economy	6300.00
0005434906525	25824	Economy	6300.00
0005434906554	25824	Economy	6300.00
0005434906549	25824	Economy	6300.00
0005434906517	25824	Economy	6900.00
0005434906563	25824	Economy	6300.00
0005434906570	25824	Economy	6300.00
0005434906528	25824	Economy	6300.00
0005434906542	25824	Economy	6300.00
0005434906553	25824	Economy	6300.00
0005434906566	25824	Economy	6300.00
0005434906559	25824	Economy	6300.00
0005434906521	25824	Economy	6300.00
0005434906548	25824	Economy	6300.00
0005434906534	25824	Economy	6300.00
0005434906567	25824	Economy	6300.00
0005434906519	25824	Economy	6300.00
0005434906537	25824	Economy	6300.00
0005434906532	25824	Economy	6300.00
0005434906541	25824	Economy	6300.00
0005434906561	25824	Economy	6300.00
0005434906557	25824	Economy	6300.00
0005434906545	25824	Economy	6300.00
0005434906523	25824	Economy	6300.00
0005434906533	25824	Economy	6300.00
0005434906539	25824	Economy	6300.00
0005434906558	25824	Economy	6300.00
0005434906571	25824	Economy	6300.00
0005434906529	25824	Economy	6300.00
0005434906538	25824	Economy	6300.00
0005434906536	25824	Economy	6300.00
0005434906526	25824	Economy	6300.00
0005434906562	25824	Economy	6300.00
0005434906531	25824	Economy	6300.00
0005434906556	25824	Economy	6300.00
0005434906518	25824	Economy	6300.00
0005434906546	25824	Economy	6300.00
0005434906530	25824	Economy	6300.00
0005434906560	25824	Economy	6300.00
0005434906568	25824	Economy	6300.00
0005434906522	25824	Economy	6300.00
0005434906564	25824	Economy	6300.00
0005434906565	25824	Economy	6300.00
0005434906555	25824	Economy	6300.00
0005434906527	25824	Economy	6300.00
0005434906543	25824	Economy	6300.00
0005433008027	14181	Business	52300.00
0005433008046	14181	Business	52300.00
0005433008012	14181	Business	52300.00
0005433008019	14181	Business	52300.00
0005433008024	14181	Economy	17400.00
0005433008021	14181	Economy	17400.00
0005433008051	14181	Economy	17400.00
0005433008013	14181	Economy	17400.00
0005433008030	14181	Economy	19200.00
0005433008033	14181	Economy	19200.00
0005433008020	14181	Economy	19200.00
0005433008028	14181	Economy	17400.00
0005433008044	14181	Economy	17400.00
0005433008016	14181	Economy	17400.00
0005433008040	14181	Economy	17400.00
0005433008029	14181	Economy	17400.00
0005433008017	14181	Economy	17400.00
0005433008039	14181	Economy	17400.00
0005433008023	14181	Economy	17400.00
0005433008037	14181	Economy	17400.00
0005433008010	14181	Economy	17400.00
0005433008034	14181	Economy	17400.00
0005433008045	14181	Economy	17400.00
0005433008031	14181	Economy	17400.00
0005433008050	14181	Economy	17400.00
0005433008026	14181	Economy	17400.00
0005433008052	14181	Economy	17400.00
0005433008043	14181	Economy	17400.00
0005433008038	14181	Economy	17400.00
0005433008015	14181	Economy	17400.00
0005433008036	14181	Economy	17400.00
0005433008025	14181	Economy	17400.00
0005433008047	14181	Economy	17400.00
0005433008054	14181	Economy	17400.00
0005433008011	14181	Economy	17400.00
0005433008041	14181	Economy	17400.00
0005433008014	14181	Economy	17400.00
0005433008032	14181	Economy	17400.00
0005433008049	14181	Economy	17400.00
0005433008035	14181	Economy	17400.00
0005433008018	14181	Economy	17400.00
0005433008009	14181	Economy	17400.00
0005433008048	14181	Economy	17400.00
0005433008008	14181	Economy	17400.00
0005433008022	14181	Economy	17400.00
0005433008053	14181	Economy	17400.00
0005433008042	14181	Economy	17400.00
0005433810502	22828	Business	52300.00
0005433810500	22828	Business	52300.00
0005433810504	22828	Economy	17400.00
0005433810501	22828	Economy	17400.00
0005433810499	22828	Economy	17400.00
0005433810503	22828	Economy	17400.00
0005433810505	22828	Economy	17400.00
0005433810497	22828	Economy	17400.00
0005433810496	22828	Economy	17400.00
0005433810498	22828	Economy	17400.00
0005434925344	20498	Business	22900.00
0005434925358	20498	Business	22900.00
0005434925363	20498	Business	22900.00
0005434925357	20498	Economy	7600.00
0005434925360	20498	Economy	8400.00
0005434925364	20498	Economy	8400.00
0005434925343	20498	Economy	7600.00
0005434925361	20498	Economy	7600.00
0005434925348	20498	Economy	7600.00
0005434925349	20498	Economy	7600.00
0005434925345	20498	Economy	7600.00
0005434925356	20498	Economy	7600.00
0005434925355	20498	Economy	7600.00
0005434925353	20498	Economy	7600.00
0005434925354	20498	Economy	7600.00
0005434925346	20498	Economy	7600.00
0005434925351	20498	Economy	7600.00
0005434925352	20498	Economy	7600.00
0005434925362	20498	Economy	7600.00
0005434925359	20498	Economy	7600.00
0005434925347	20498	Economy	7600.00
0005434925350	20498	Economy	7600.00
0005435487550	15801	Economy	8900.00
0005435487559	15801	Economy	8900.00
0005435487562	15801	Economy	8900.00
0005435487547	15801	Economy	8100.00
0005435487549	15801	Economy	8100.00
0005435487552	15801	Economy	8100.00
0005435487558	15801	Economy	8100.00
0005435487544	15801	Economy	8100.00
0005435487561	15801	Economy	8100.00
0005435487560	15801	Economy	8100.00
0005435487551	15801	Economy	8100.00
0005435487545	15801	Economy	8100.00
0005435487543	15801	Economy	8100.00
0005435487557	15801	Economy	8100.00
0005435487553	15801	Economy	8100.00
0005435487556	15801	Economy	8100.00
0005435487546	15801	Economy	8100.00
0005435487563	15801	Economy	8100.00
0005435487555	15801	Economy	8100.00
0005435487548	15801	Economy	8100.00
0005435487554	15801	Economy	8100.00
0005435999012	19715	Economy	8900.00
0005435999008	19715	Economy	8900.00
0005435999006	19715	Economy	8100.00
0005435999004	19715	Economy	8100.00
0005435998999	19715	Economy	8100.00
0005435999002	19715	Economy	8100.00
0005435999003	19715	Economy	8100.00
0005435999007	19715	Economy	8100.00
0005435999010	19715	Economy	8100.00
0005435999000	19715	Economy	8100.00
0005435999001	19715	Economy	8100.00
0005435999009	19715	Economy	8100.00
0005435999011	19715	Economy	8100.00
0005435999005	19715	Economy	8100.00
0005435839091	6030	Business	199300.00
0005435839089	6030	Business	199300.00
0005435839077	6030	Business	199300.00
0005435839096	6030	Business	199300.00
0005435839083	6030	Business	199300.00
0005435839097	6030	Business	199300.00
0005435839087	6030	Business	199300.00
0005435839088	6030	Business	199300.00
0005432660791	6030	Business	199300.00
0005432658565	6030	Business	199300.00
0005435839079	6030	Economy	66400.00
0005435839073	6030	Economy	66400.00
0005435839080	6030	Economy	66400.00
0005435839082	6030	Economy	66400.00
0005435839092	6030	Economy	66400.00
0005435839085	6030	Economy	73100.00
0005435839081	6030	Economy	73100.00
0005432658566	6030	Economy	66400.00
0005435839093	6030	Economy	66400.00
0005435839084	6030	Economy	66400.00
0005432658564	6030	Economy	66400.00
0005435839099	6030	Economy	66400.00
0005435839074	6030	Economy	66400.00
0005432142212	6030	Economy	66400.00
0005432659680	6030	Economy	66400.00
0005435839100	6030	Economy	66400.00
0005435839101	6030	Economy	66400.00
0005435839076	6030	Economy	66400.00
0005435839094	6030	Economy	66400.00
0005432142211	6030	Economy	66400.00
0005435839098	6030	Economy	66400.00
0005435839086	6030	Economy	66400.00
0005435839078	6030	Economy	66400.00
0005432660792	6030	Economy	66400.00
0005435839095	6030	Economy	66400.00
0005435839075	6030	Economy	66400.00
0005435839090	6030	Economy	66400.00
0005432659681	6030	Economy	66400.00
0005432659679	6030	Economy	66400.00
0005435472591	18080	Business	199300.00
0005435472582	18080	Business	199300.00
0005435472581	18080	Business	199300.00
0005435472583	18080	Economy	66400.00
0005432537030	18080	Economy	66400.00
0005435472594	18080	Economy	66400.00
0005435472585	18080	Economy	66400.00
0005435472593	18080	Economy	66400.00
0005435472595	18080	Economy	66400.00
0005435472587	18080	Economy	66400.00
0005435472589	18080	Economy	66400.00
0005435472588	18080	Economy	66400.00
0005435472580	18080	Economy	66400.00
0005435472584	18080	Economy	66400.00
0005435472590	18080	Economy	66400.00
0005435472586	18080	Economy	66400.00
0005435472592	18080	Economy	66400.00
0005432537031	18080	Economy	66400.00
0005435103827	23038	Economy	5200.00
0005433284793	23038	Economy	5200.00
0005433284794	23038	Economy	5200.00
0005435103825	23038	Economy	5200.00
0005435103826	23038	Economy	5200.00
0005433284770	23038	Economy	5200.00
0005433284898	32100	Business	15700.00
0005433284886	32100	Business	15700.00
0005433284897	32100	Business	15700.00
0005433284889	32100	Business	15700.00
0005433284879	32100	Economy	5200.00
0005433284905	32100	Economy	5200.00
0005433284880	32100	Economy	5200.00
0005433284881	32100	Economy	5200.00
0005433284903	32100	Economy	5200.00
0005433284890	32100	Economy	5200.00
0005433284893	32100	Economy	5200.00
0005433284885	32100	Economy	5200.00
0005433284902	32100	Economy	5200.00
0005433284887	32100	Economy	5200.00
0005433284884	32100	Economy	5700.00
0005433284882	32100	Economy	5700.00
0005433284900	32100	Economy	5200.00
0005433284888	32100	Economy	5200.00
0005433284895	32100	Economy	5200.00
0005433284907	32100	Economy	5200.00
0005433284896	32100	Economy	5200.00
0005433284904	32100	Economy	5200.00
0005433284908	32100	Economy	5200.00
0005433284892	32100	Economy	5200.00
0005433284910	32100	Economy	5200.00
0005433284891	32100	Economy	5200.00
0005433284894	32100	Economy	5200.00
0005433284883	32100	Economy	5200.00
0005433284906	32100	Economy	5200.00
0005433284899	32100	Economy	5200.00
0005433284909	32100	Economy	5200.00
0005433284901	32100	Economy	5200.00
0005435212724	30603	Business	42100.00
0005433656628	30603	Business	42100.00
0005435212692	30603	Business	42100.00
0005434066349	30603	Business	42100.00
0005435212709	30603	Business	42100.00
0005434066421	30603	Business	42100.00
0005433656629	30603	Business	42100.00
0005435212729	30603	Business	42100.00
0005435212686	30603	Business	42100.00
0005435212676	30603	Comfort	23900.00
0005435212736	30603	Comfort	23900.00
0005435212710	30603	Comfort	23900.00
0005435212681	30603	Comfort	23900.00
0005435212704	30603	Comfort	23900.00
0005435212675	30603	Comfort	23900.00
0005432211406	30603	Comfort	23900.00
0005435212697	30603	Comfort	23900.00
0005435212740	30603	Comfort	23900.00
0005435212732	30603	Comfort	23900.00
0005435212687	30603	Comfort	23900.00
0005435212717	30603	Comfort	23900.00
0005432525942	30603	Comfort	23900.00
0005435212684	30603	Comfort	23900.00
0005435212698	30603	Comfort	23900.00
0005435212743	30603	Comfort	23900.00
0005435212739	30603	Comfort	23900.00
0005435212713	30603	Comfort	23900.00
0005432525697	30603	Comfort	23900.00
0005432211408	30603	Comfort	23900.00
0005435212716	30603	Comfort	23900.00
0005435212718	30603	Economy	14000.00
0005434066330	30603	Economy	14000.00
0005435212722	30603	Economy	14000.00
0005435212715	30603	Economy	14000.00
0005435212737	30603	Economy	14000.00
0005435212677	30603	Economy	14000.00
0005435212693	30603	Economy	14000.00
0005435212683	30603	Economy	14000.00
0005433656632	30603	Economy	14000.00
0005435630932	30603	Economy	14000.00
0005435212706	30603	Economy	14000.00
0005435725541	30603	Economy	14000.00
0005433656631	30603	Economy	14000.00
0005435212711	30603	Economy	14000.00
0005435212731	30603	Economy	14000.00
0005435212705	30603	Economy	14000.00
0005435725540	30603	Economy	14000.00
0005435212688	30603	Economy	14000.00
0005435212703	30603	Economy	14000.00
0005435725537	30603	Economy	14000.00
0005432525801	30603	Economy	14000.00
0005435212725	30603	Economy	15400.00
0005435630929	30603	Economy	15400.00
0005432525664	30603	Economy	14000.00
0005432211410	30603	Economy	14000.00
0005435212741	30603	Economy	14000.00
0005435212695	30603	Economy	14000.00
0005432525722	30603	Economy	14000.00
0005435212733	30603	Economy	14000.00
0005435630931	30603	Economy	14000.00
0005435212707	30603	Economy	14000.00
0005435212714	30603	Economy	14000.00
0005435212727	30603	Economy	14000.00
0005435212689	30603	Economy	14000.00
0005435212721	30603	Economy	14000.00
0005432525696	30603	Economy	14000.00
0005432525740	30603	Economy	14000.00
0005432211409	30603	Economy	14000.00
0005435212742	30603	Economy	14000.00
0005432211404	30603	Economy	14000.00
0005435212734	30603	Economy	14000.00
0005432159799	30603	Economy	14000.00
0005432211411	30603	Economy	14000.00
0005434066505	30603	Economy	14000.00
0005432159800	30603	Economy	14000.00
0005435212679	30603	Economy	14000.00
0005432159802	30603	Economy	14000.00
0005435630930	30603	Economy	14000.00
0005435212685	30603	Economy	14000.00
0005432526138	30603	Economy	14000.00
0005432159798	30603	Economy	14000.00
0005435212702	30603	Economy	14000.00
0005434066390	30603	Economy	14000.00
0005435212730	30603	Economy	15400.00
0005432211405	30603	Economy	15400.00
0005434066307	30603	Economy	14000.00
0005435212696	30603	Economy	14000.00
0005435725539	30603	Economy	14000.00
0005432525849	30603	Economy	14000.00
0005433656630	30603	Economy	14000.00
0005432525754	30603	Economy	14000.00
0005432159801	30603	Economy	14000.00
0005435212690	30603	Economy	14000.00
0005435212699	30603	Economy	14000.00
0005435212691	30603	Economy	14000.00
0005435212726	30603	Economy	14000.00
0005435212678	30603	Economy	14000.00
0005435212728	30603	Economy	14000.00
0005435212694	30603	Economy	14000.00
0005435725538	30603	Economy	14000.00
0005435212708	30603	Economy	14000.00
0005432211407	30603	Economy	14000.00
0005435212719	30603	Economy	14000.00
0005435212680	30603	Economy	14000.00
0005435212720	30603	Economy	14000.00
0005432525665	30603	Economy	14000.00
0005435212700	30603	Economy	14000.00
0005435212723	30603	Economy	14000.00
0005435212735	30603	Economy	14000.00
0005435212738	30603	Economy	14000.00
0005435212682	30603	Economy	14000.00
0005435212712	30603	Economy	14000.00
0005432525875	30603	Economy	14000.00
0005435212701	30603	Economy	14000.00
0005433367451	24861	Business	9800.00
0005433367445	24861	Business	9800.00
0005433367437	24861	Business	9800.00
0005433367450	24861	Business	9800.00
0005433367433	24861	Business	9800.00
0005433367422	24861	Economy	3300.00
0005433367439	24861	Economy	3300.00
0005433367432	24861	Economy	3300.00
0005433367427	24861	Economy	3300.00
0005433367428	24861	Economy	3300.00
0005433367421	24861	Economy	3300.00
0005433367449	24861	Economy	3300.00
0005433367418	24861	Economy	3600.00
0005433367441	24861	Economy	3600.00
0005433367424	24861	Economy	3600.00
0005433367417	24861	Economy	3600.00
0005433367452	24861	Economy	3300.00
0005433367420	24861	Economy	3300.00
0005433367435	24861	Economy	3300.00
0005433367415	24861	Economy	3300.00
0005433367426	24861	Economy	3300.00
0005433367412	24861	Economy	3300.00
0005433367434	24861	Economy	3300.00
0005433367414	24861	Economy	3300.00
0005433367430	24861	Economy	3300.00
0005433367447	24861	Economy	3300.00
0005433367446	24861	Economy	3300.00
0005433367429	24861	Economy	3300.00
0005433367440	24861	Economy	3300.00
0005433367411	24861	Economy	3300.00
0005433367425	24861	Economy	3300.00
0005433367444	24861	Economy	3300.00
0005433367438	24861	Economy	3300.00
0005433367442	24861	Economy	3300.00
0005433367410	24861	Economy	3300.00
0005433367419	24861	Economy	3300.00
0005433367413	24861	Economy	3300.00
0005433367431	24861	Economy	3300.00
0005433367436	24861	Economy	3300.00
0005433367443	24861	Economy	3300.00
0005433367448	24861	Economy	3300.00
0005433367416	24861	Economy	3300.00
0005433367423	24861	Economy	3300.00
0005434979415	2053	Economy	10500.00
0005435801659	2053	Economy	10500.00
0005434979409	2053	Economy	10500.00
0005434979436	2053	Economy	9500.00
0005434979421	2053	Economy	9500.00
0005434979410	2053	Economy	9500.00
0005435801658	2053	Economy	9500.00
0005434979423	2053	Economy	9500.00
0005434979426	2053	Economy	9500.00
0005434979413	2053	Economy	9500.00
0005434979407	2053	Economy	9500.00
0005434979414	2053	Economy	9500.00
0005434979432	2053	Economy	9500.00
0005434979418	2053	Economy	9500.00
0005434979422	2053	Economy	9500.00
0005434979428	2053	Economy	9500.00
0005434979416	2053	Economy	9500.00
0005435801660	2053	Economy	9500.00
0005434979425	2053	Economy	9500.00
0005434979420	2053	Economy	9500.00
0005434979417	2053	Economy	9500.00
0005434979424	2053	Economy	9500.00
0005434979419	2053	Economy	9500.00
0005434979431	2053	Economy	9500.00
0005434979429	2053	Economy	9500.00
0005434979430	2053	Economy	9500.00
0005434979427	2053	Economy	9500.00
0005434979412	2053	Economy	9500.00
0005434979434	2053	Economy	9500.00
0005434979435	2053	Economy	9500.00
0005434979433	2053	Economy	9500.00
0005434979411	2053	Economy	9500.00
0005434979408	2053	Economy	9500.00
0005434952486	2622	Economy	5300.00
0005434952484	2622	Economy	5300.00
0005434952485	2622	Economy	5300.00
0005433256387	2623	Economy	5300.00
0005433256393	28218	Economy	5300.00
0005433256394	28218	Economy	5300.00
0005433111479	19824	Economy	8700.00
0005433111480	19824	Economy	8700.00
0005433112358	19824	Economy	8700.00
0005433112359	19824	Economy	8700.00
0005434137029	28743	Business	9700.00
0005434137076	28743	Business	9700.00
0005434137084	28743	Business	9700.00
0005434137051	28743	Business	9700.00
0005434137019	28743	Business	9700.00
0005434137038	28743	Business	9700.00
0005434137078	28743	Business	9700.00
0005434137046	28743	Business	9700.00
0005434137088	28743	Business	9700.00
0005434137079	28743	Business	9700.00
0005434137085	28743	Business	9700.00
0005434137067	28743	Business	9700.00
0005434137036	28743	Economy	3200.00
0005434137054	28743	Economy	3200.00
0005434137093	28743	Economy	3200.00
0005434137032	28743	Economy	3200.00
0005434137073	28743	Economy	3200.00
0005434137061	28743	Economy	3200.00
0005434137081	28743	Economy	3200.00
0005434137020	28743	Economy	3200.00
0005434137057	28743	Economy	3500.00
0005434137027	28743	Economy	3500.00
0005434137071	28743	Economy	3500.00
0005434137090	28743	Economy	3500.00
0005434137096	28743	Economy	3500.00
0005434137053	28743	Economy	3200.00
0005434137026	28743	Economy	3200.00
0005434137100	28743	Economy	3200.00
0005434137070	28743	Economy	3200.00
0005434137066	28743	Economy	3200.00
0005434137050	28743	Economy	3200.00
0005434137014	28743	Economy	3200.00
0005434137063	28743	Economy	3200.00
0005434137077	28743	Economy	3200.00
0005434137018	28743	Economy	3200.00
0005434137047	28743	Economy	3200.00
0005434137048	28743	Economy	3200.00
0005434137039	28743	Economy	3200.00
0005434137045	28743	Economy	3200.00
0005434137028	28743	Economy	3200.00
0005434137034	28743	Economy	3200.00
0005434137042	28743	Economy	3200.00
0005434137060	28743	Economy	3200.00
0005434137062	28743	Economy	3200.00
0005434137055	28743	Economy	3200.00
0005434137083	28743	Economy	3200.00
0005434137068	28743	Economy	3200.00
0005434137075	28743	Economy	3200.00
0005434137086	28743	Economy	3200.00
0005434137044	28743	Economy	3200.00
0005434137041	28743	Economy	3200.00
0005434137059	28743	Economy	3200.00
0005434137033	28743	Economy	3200.00
0005434137095	28743	Economy	3200.00
0005434137092	28743	Economy	3200.00
0005434137030	28743	Economy	3200.00
0005434137091	28743	Economy	3200.00
0005434137040	28743	Economy	3200.00
0005434137016	28743	Economy	3200.00
0005434137065	28743	Economy	3200.00
0005434137052	28743	Economy	3200.00
0005434137097	28743	Economy	3200.00
0005434137080	28743	Economy	3200.00
0005434137064	28743	Economy	3200.00
0005434137023	28743	Economy	3200.00
0005434137024	28743	Economy	3200.00
0005434137043	28743	Economy	3200.00
0005434137069	28743	Economy	3200.00
0005434137058	28743	Economy	3200.00
0005434137087	28743	Economy	3200.00
0005434137035	28743	Economy	3200.00
0005434137094	28743	Economy	3200.00
0005434137022	28743	Economy	3200.00
0005434137037	28743	Economy	3200.00
0005434137082	28743	Economy	3200.00
0005434137089	28743	Economy	3200.00
0005434137015	28743	Economy	3200.00
0005434137098	28743	Economy	3200.00
0005434137021	28743	Economy	3200.00
0005434137072	28743	Economy	3200.00
0005434137049	28743	Economy	3200.00
0005434137099	28743	Economy	3200.00
0005434137017	28743	Economy	3200.00
0005434137025	28743	Economy	3200.00
0005434137031	28743	Economy	3200.00
0005434137056	28743	Economy	3200.00
0005434137074	28743	Economy	3200.00
0005433538764	6774	Economy	10900.00
0005433538762	6774	Economy	9900.00
0005433534472	6774	Economy	9900.00
0005433538760	6774	Economy	9900.00
0005433538763	6774	Economy	9900.00
0005433538766	6774	Economy	9900.00
0005433538761	6774	Economy	9900.00
0005433538768	6774	Economy	9900.00
0005433538767	6774	Economy	9900.00
0005435259681	6774	Economy	9900.00
0005433538765	6774	Economy	9900.00
0005433538730	24993	Economy	10900.00
0005435259703	24993	Economy	9900.00
0005435259702	24993	Economy	9900.00
0005435259701	24993	Economy	9900.00
0005433538719	24993	Economy	9900.00
0005435259704	24993	Economy	9900.00
0005435259705	24993	Economy	9900.00
0005433538731	24993	Economy	9900.00
0005433538729	24993	Economy	9900.00
0005433511849	824	Economy	14600.00
0005433511848	824	Economy	14600.00
0005433511844	824	Economy	14600.00
0005433511850	824	Economy	14600.00
0005433511846	824	Economy	14600.00
0005433511845	824	Economy	14600.00
0005433511851	824	Economy	14600.00
0005433511847	824	Economy	14600.00
0005433511812	16121	Economy	16100.00
0005433511811	16121	Economy	14600.00
0005433511810	16121	Economy	14600.00
0005432922474	16121	Economy	14600.00
0005432922473	16121	Economy	14600.00
0005432922476	16121	Economy	14600.00
0005432922475	16121	Economy	14600.00
0005433475645	4039	Economy	13500.00
0005433475647	4039	Economy	13500.00
0005433475655	4039	Economy	12300.00
0005433475649	4039	Economy	12300.00
0005433475650	4039	Economy	12300.00
0005433475656	4039	Economy	12300.00
0005433475646	4039	Economy	12300.00
0005433475652	4039	Economy	12300.00
0005433475648	4039	Economy	12300.00
0005433475653	4039	Economy	12300.00
0005433475654	4039	Economy	12300.00
0005433475644	4039	Economy	12300.00
0005433475643	4039	Economy	12300.00
0005433475651	4039	Economy	12300.00
0005435696990	3679	Economy	7900.00
0005434950473	3679	Economy	7200.00
0005435697011	3679	Economy	7200.00
0005434950474	3679	Economy	7200.00
0005434950476	3679	Economy	7200.00
0005435696996	3679	Economy	7200.00
0005435697010	3679	Economy	7200.00
0005435696992	3679	Economy	7200.00
0005435696986	3679	Economy	7200.00
0005434950472	3679	Economy	7200.00
0005435696989	3679	Economy	7200.00
0005435697005	3679	Economy	7200.00
0005435696999	3679	Economy	7200.00
0005435697014	3679	Economy	7200.00
0005435696988	3679	Economy	7200.00
0005435697007	3679	Economy	7200.00
0005435697001	3679	Economy	7200.00
0005435696995	3679	Economy	7200.00
0005435697013	3679	Economy	7200.00
0005435696997	3679	Economy	7200.00
0005434950475	3679	Economy	7200.00
0005435697006	3679	Economy	7200.00
0005435696994	3679	Economy	7200.00
0005435697004	3679	Economy	7200.00
0005435697008	3679	Economy	7200.00
0005435935002	3679	Economy	7200.00
0005435696998	3679	Economy	7200.00
0005435696993	3679	Economy	7200.00
0005435697003	3679	Economy	7200.00
0005435697009	3679	Economy	7200.00
0005435697002	3679	Economy	7200.00
0005435697012	3679	Economy	7200.00
0005435935001	3679	Economy	7200.00
0005435696991	3679	Economy	7200.00
0005435697000	3679	Economy	7200.00
0005435696987	3679	Economy	7200.00
0005435696887	16256	Economy	7200.00
0005435696886	16256	Economy	7200.00
0005435935004	16256	Economy	7200.00
0005435916132	16256	Economy	7200.00
0005435935005	16256	Economy	7200.00
0005434950450	16256	Economy	7200.00
0005435916133	16256	Economy	7200.00
0005435935006	16256	Economy	7200.00
0005435916135	16256	Economy	7200.00
0005435916134	16256	Economy	7200.00
0005435935007	16256	Economy	7200.00
0005434950451	16256	Economy	7200.00
0005433519403	3961	Economy	21300.00
0005434606784	3961	Economy	21300.00
0005433519400	3961	Economy	19300.00
0005434604858	3961	Economy	19300.00
0005432609681	3961	Economy	19300.00
0005435853578	3961	Economy	19300.00
0005432609683	3961	Economy	19300.00
0005434604857	3961	Economy	19300.00
0005434606782	3961	Economy	19300.00
0005434606783	3961	Economy	19300.00
0005434604854	3961	Economy	19300.00
0005433519401	3961	Economy	19300.00
0005432609682	3961	Economy	19300.00
0005434604855	3961	Economy	19300.00
0005433519402	3961	Economy	19300.00
0005432607517	3961	Economy	19300.00
0005432607516	3961	Economy	19300.00
0005434604856	3961	Economy	19300.00
0005432607515	3961	Economy	19300.00
0005433519381	22063	Economy	19300.00
0005435853587	22063	Economy	19300.00
0005435628688	682	Economy	3700.00
0005435628687	682	Economy	3700.00
0005435628689	682	Economy	3700.00
0005433348917	15886	Economy	3700.00
0005433348921	15886	Economy	3700.00
0005433348918	15886	Economy	3700.00
0005433348920	15886	Economy	3700.00
0005433348916	15886	Economy	3700.00
0005433348919	15886	Economy	3700.00
0005434446487	17177	Economy	7100.00
0005434446488	17177	Economy	7100.00
0005434446489	17177	Economy	7100.00
0005434445215	17177	Economy	7100.00
0005434445216	17177	Economy	7100.00
0005434446490	17177	Economy	7100.00
0005433159288	17608	Economy	7100.00
0005433159287	17608	Economy	7100.00
0005433159286	17608	Economy	7100.00
0005435132750	7899	Economy	5400.00
0005435132752	7899	Economy	5400.00
0005435132757	7899	Economy	5400.00
0005435132755	7899	Economy	5400.00
0005435132751	7899	Economy	5400.00
0005435132758	7899	Economy	5400.00
0005435132748	7899	Economy	5400.00
0005435132756	7899	Economy	5400.00
0005435132749	7899	Economy	5400.00
0005435132754	7899	Economy	5400.00
0005435132753	7899	Economy	5400.00
0005435383086	33073	Economy	5400.00
0005435383085	33073	Economy	5400.00
0005435383082	33073	Economy	5400.00
0005435383087	33073	Economy	5400.00
0005435383084	33073	Economy	5400.00
0005435383083	33073	Economy	5400.00
0005435132714	33073	Economy	5400.00
0005435160168	7521	Economy	12500.00
0005435160166	7521	Economy	12500.00
0005435160170	7521	Economy	12500.00
0005435160167	7521	Economy	12500.00
0005435160164	7521	Economy	12500.00
0005435160169	7521	Economy	12500.00
0005435160163	7521	Economy	12500.00
0005435160165	7521	Economy	12500.00
0005435390129	7521	Economy	12500.00
0005435160171	7521	Economy	12500.00
0005435160162	7521	Economy	12500.00
0005435160160	7521	Economy	12500.00
0005435160161	7521	Economy	12500.00
0005435390130	7521	Economy	12500.00
0005435390153	29558	Economy	12500.00
0005435390158	29558	Economy	12500.00
0005435160113	29558	Economy	12500.00
0005435390156	29558	Economy	12500.00
0005435390157	29558	Economy	12500.00
0005435390154	29558	Economy	12500.00
0005435390155	29558	Economy	12500.00
0005435160103	29558	Economy	12500.00
0005435160104	29558	Economy	12500.00
0005435390159	29558	Economy	12500.00
0005435178476	18450	Economy	4900.00
0005435178982	18450	Economy	4900.00
0005435178477	18450	Economy	4900.00
0005435178981	18450	Economy	4900.00
0005432398148	27177	Economy	4900.00
0005432400076	27177	Economy	4900.00
0005432398146	27177	Economy	4900.00
0005432398147	27177	Economy	4900.00
0005432400074	27177	Economy	4900.00
0005432400075	27177	Economy	4900.00
0005432400073	27177	Economy	4900.00
0005434503690	6509	Business	48400.00
0005434503680	6509	Business	48400.00
0005434503691	6509	Business	48400.00
0005434503670	6509	Business	48400.00
0005434503666	6509	Business	48400.00
0005435103847	6509	Business	48400.00
0005434503674	6509	Business	48400.00
0005434503673	6509	Economy	16100.00
0005434503677	6509	Economy	16100.00
0005434503692	6509	Economy	16100.00
0005434503669	6509	Economy	17800.00
0005434503699	6509	Economy	17800.00
0005434503696	6509	Economy	16100.00
0005434503681	6509	Economy	16100.00
0005434503676	6509	Economy	16100.00
0005435103844	6509	Economy	16100.00
0005435103845	6509	Economy	16100.00
0005434503687	6509	Economy	16100.00
0005434503688	6509	Economy	16100.00
0005434503694	6509	Economy	16100.00
0005434503678	6509	Economy	16100.00
0005435103841	6509	Economy	16100.00
0005434503689	6509	Economy	16100.00
0005434503695	6509	Economy	16100.00
0005435103839	6509	Economy	16100.00
0005434503661	6509	Economy	16100.00
0005434503698	6509	Economy	16100.00
0005434503683	6509	Economy	16100.00
0005434503682	6509	Economy	16100.00
0005434503668	6509	Economy	16100.00
0005434503663	6509	Economy	16100.00
0005434503660	6509	Economy	16100.00
0005434503667	6509	Economy	16100.00
0005434503697	6509	Economy	16100.00
0005434503665	6509	Economy	16100.00
0005434503679	6509	Economy	16100.00
0005434503684	6509	Economy	16100.00
0005435103843	6509	Economy	16100.00
0005434503662	6509	Economy	16100.00
0005435103846	6509	Economy	16100.00
0005434503686	6509	Economy	16100.00
0005434503671	6509	Economy	16100.00
0005435103848	6509	Economy	16100.00
0005434503685	6509	Economy	16100.00
0005435103849	6509	Economy	16100.00
0005434503664	6509	Economy	16100.00
0005435103838	6509	Economy	16100.00
0005434503675	6509	Economy	16100.00
0005435103840	6509	Economy	16100.00
0005434503693	6509	Economy	16100.00
0005434503672	6509	Economy	16100.00
0005435103842	6509	Economy	16100.00
0005434503486	22667	Economy	16100.00
0005435652506	1695	Business	50000.00
0005435652513	1695	Business	50000.00
0005435652522	1695	Business	50000.00
0005435652519	1695	Business	50000.00
0005435652496	1695	Economy	16700.00
0005435652517	1695	Economy	16700.00
0005435652508	1695	Economy	16700.00
0005435652494	1695	Economy	16700.00
0005433367241	1695	Economy	18300.00
0005435652514	1695	Economy	18300.00
0005435652503	1695	Economy	18300.00
0005435652524	1695	Economy	16700.00
0005435652523	1695	Economy	16700.00
0005435652510	1695	Economy	16700.00
0005435652489	1695	Economy	16700.00
0005435652515	1695	Economy	16700.00
0005435652490	1695	Economy	16700.00
0005435652507	1695	Economy	16700.00
0005435652499	1695	Economy	16700.00
0005435652505	1695	Economy	16700.00
0005435652512	1695	Economy	16700.00
0005435652498	1695	Economy	16700.00
0005435652495	1695	Economy	16700.00
0005435652491	1695	Economy	16700.00
0005435652525	1695	Economy	16700.00
0005435652504	1695	Economy	16700.00
0005435652520	1695	Economy	16700.00
0005435652493	1695	Economy	16700.00
0005435652511	1695	Economy	16700.00
0005435652521	1695	Economy	16700.00
0005435652518	1695	Economy	16700.00
0005433367223	1695	Economy	16700.00
0005435652502	1695	Economy	16700.00
0005435652516	1695	Economy	16700.00
0005435652509	1695	Economy	16700.00
0005435652492	1695	Economy	16700.00
0005435652526	1695	Economy	16700.00
0005435652500	1695	Economy	16700.00
0005433367234	1695	Economy	16700.00
0005435652501	1695	Economy	16700.00
0005435652497	1695	Economy	16700.00
0005433367441	21673	Business	50000.00
0005433367428	21673	Business	50000.00
0005433367442	21673	Business	50000.00
0005433367439	21673	Business	50000.00
0005433367431	21673	Business	50000.00
0005433367411	21673	Economy	16700.00
0005433367433	21673	Economy	16700.00
0005433367417	21673	Economy	16700.00
0005433367446	21673	Economy	16700.00
0005433367432	21673	Economy	16700.00
0005433367414	21673	Economy	18300.00
0005433367410	21673	Economy	18300.00
0005433367430	21673	Economy	16700.00
0005433367413	21673	Economy	16700.00
0005433367445	21673	Economy	16700.00
0005433367425	21673	Economy	16700.00
0005433367427	21673	Economy	16700.00
0005433367412	21673	Economy	16700.00
0005433367447	21673	Economy	16700.00
0005433367420	21673	Economy	16700.00
0005433367448	21673	Economy	16700.00
0005433367422	21673	Economy	16700.00
0005433367429	21673	Economy	16700.00
0005433367415	21673	Economy	16700.00
0005433367424	21673	Economy	16700.00
0005433367437	21673	Economy	16700.00
0005433367418	21673	Economy	16700.00
0005433367421	21673	Economy	16700.00
0005433367426	21673	Economy	16700.00
0005433367440	21673	Economy	16700.00
0005433367443	21673	Economy	16700.00
0005433367423	21673	Economy	16700.00
0005433367435	21673	Economy	16700.00
0005433367449	21673	Economy	16700.00
0005433367452	21673	Economy	16700.00
0005433367436	21673	Economy	16700.00
0005433367438	21673	Economy	16700.00
0005433367434	21673	Economy	16700.00
0005433367416	21673	Economy	16700.00
0005433367451	21673	Economy	16700.00
0005433367450	21673	Economy	16700.00
0005433367419	21673	Economy	16700.00
0005433367444	21673	Economy	16700.00
0005433985404	4154	Business	21500.00
0005433985378	4154	Business	21500.00
0005435788740	4154	Business	21500.00
0005433985392	4154	Business	21500.00
0005433985361	4154	Business	21500.00
0005433985389	4154	Business	21500.00
0005433985380	4154	Business	21500.00
0005433985367	4154	Economy	7200.00
0005433985390	4154	Economy	7200.00
0005433985369	4154	Economy	7200.00
0005433985385	4154	Economy	7200.00
0005433985368	4154	Economy	7200.00
0005433985372	4154	Economy	7900.00
0005433985371	4154	Economy	7900.00
0005433985381	4154	Economy	7900.00
0005433985384	4154	Economy	7200.00
0005433985377	4154	Economy	7200.00
0005433985399	4154	Economy	7200.00
0005433985387	4154	Economy	7200.00
0005433985366	4154	Economy	7200.00
0005433985375	4154	Economy	7200.00
0005433985391	4154	Economy	7200.00
0005433985401	4154	Economy	7200.00
0005433985359	4154	Economy	7200.00
0005433985407	4154	Economy	7200.00
0005433985363	4154	Economy	7200.00
0005433985394	4154	Economy	7200.00
0005433985370	4154	Economy	7200.00
0005433985360	4154	Economy	7200.00
0005433985383	4154	Economy	7200.00
0005433985358	4154	Economy	7200.00
0005433985397	4154	Economy	7200.00
0005433985400	4154	Economy	7200.00
0005433985364	4154	Economy	7200.00
0005433985396	4154	Economy	7200.00
0005433985388	4154	Economy	7200.00
0005433985398	4154	Economy	7200.00
0005433985376	4154	Economy	7200.00
0005433985362	4154	Economy	7200.00
0005433985406	4154	Economy	7200.00
0005433985365	4154	Economy	7200.00
0005433985403	4154	Economy	7200.00
0005433985395	4154	Economy	7200.00
0005433985379	4154	Economy	7200.00
0005435788739	4154	Economy	7200.00
0005433985393	4154	Economy	7200.00
0005433985382	4154	Economy	7200.00
0005433985405	4154	Economy	7200.00
0005433985402	4154	Economy	7200.00
0005433985374	4154	Economy	7200.00
0005435788738	4154	Economy	7200.00
0005433985373	4154	Economy	7200.00
0005433985386	4154	Economy	7200.00
0005435788730	25647	Economy	7200.00
0005433985159	25647	Economy	7200.00
0005433985153	25647	Economy	7200.00
0005433985183	25647	Economy	7200.00
0005435720798	21259	Economy	9400.00
0005435720799	21259	Economy	9400.00
0005435720800	21259	Economy	9400.00
0005435719553	24800	Economy	9400.00
0005433168313	21320	Economy	15500.00
0005433168321	21320	Economy	15500.00
0005433168320	21320	Economy	15500.00
0005433168317	21320	Economy	15500.00
0005434509019	21320	Economy	15500.00
0005433168316	21320	Economy	15500.00
0005433168318	21320	Economy	15500.00
0005433168322	21320	Economy	15500.00
0005433168324	21320	Economy	15500.00
0005433168314	21320	Economy	15500.00
0005433168312	21320	Economy	15500.00
0005433168315	21320	Economy	15500.00
0005434509024	21320	Economy	15500.00
0005433168323	21320	Economy	15500.00
0005433168319	21320	Economy	15500.00
0005432869446	17870	Business	18000.00
0005432869450	17870	Economy	6000.00
0005434151670	17870	Economy	6600.00
0005432869449	17870	Economy	6000.00
0005432869447	17870	Economy	6000.00
0005432869448	17870	Economy	6000.00
0005434151671	17870	Economy	6000.00
0005432657394	17870	Economy	6000.00
0005432657407	26285	Business	18000.00
0005432655371	26285	Economy	6000.00
0005432665246	26285	Economy	6600.00
0005432655366	26285	Economy	6000.00
0005432657408	26285	Economy	6000.00
0005432667427	26285	Economy	6000.00
0005432667426	26285	Economy	6000.00
0005432655368	26285	Economy	6000.00
0005432655374	26285	Economy	6000.00
0005432655365	26285	Economy	6000.00
0005432655370	26285	Economy	6000.00
0005432666360	26285	Economy	6000.00
0005432666359	26285	Economy	6000.00
0005432655367	26285	Economy	6000.00
0005432655369	26285	Economy	6000.00
0005432655363	26285	Economy	6000.00
0005432655372	26285	Economy	6000.00
0005432655373	26285	Economy	6000.00
0005432660790	26285	Economy	6000.00
0005432665247	26285	Economy	6000.00
0005432658563	26285	Economy	6000.00
0005432659677	26285	Economy	6000.00
0005432655364	26285	Economy	6000.00
0005432659678	26285	Economy	6000.00
0005432665248	26285	Economy	6000.00
0005432658562	26285	Economy	6000.00
0005433438796	3125	Business	16100.00
0005432287128	3125	Business	16100.00
0005432328161	3125	Business	16100.00
0005432328149	3125	Business	16100.00
0005432328160	3125	Business	16100.00
0005433438799	3125	Business	16100.00
0005432328148	3125	Business	16100.00
0005432328156	3125	Economy	5400.00
0005433438801	3125	Economy	5400.00
0005432328142	3125	Economy	5400.00
0005432328167	3125	Economy	5400.00
0005432287127	3125	Economy	5400.00
0005432328150	3125	Economy	5400.00
0005432328145	3125	Economy	5400.00
0005432328139	3125	Economy	5400.00
0005432287126	3125	Economy	5900.00
0005432328164	3125	Economy	5900.00
0005432328131	3125	Economy	5900.00
0005432328137	3125	Economy	5400.00
0005432328159	3125	Economy	5400.00
0005432328151	3125	Economy	5400.00
0005432328169	3125	Economy	5400.00
0005432328143	3125	Economy	5400.00
0005433438797	3125	Economy	5400.00
0005432328132	3125	Economy	5400.00
0005433438803	3125	Economy	5400.00
0005432328168	3125	Economy	5400.00
0005432328172	3125	Economy	5400.00
0005433438802	3125	Economy	5400.00
0005432328155	3125	Economy	5400.00
0005432287129	3125	Economy	5400.00
0005432328144	3125	Economy	5400.00
0005432328171	3125	Economy	5400.00
0005432328162	3125	Economy	5400.00
0005432328153	3125	Economy	5400.00
0005432328166	3125	Economy	5400.00
0005432328157	3125	Economy	5400.00
0005432328163	3125	Economy	5400.00
0005432328130	3125	Economy	5400.00
0005432328152	3125	Economy	5400.00
0005432328154	3125	Economy	5400.00
0005432287125	3125	Economy	5400.00
0005432328138	3125	Economy	5400.00
0005432328141	3125	Economy	5400.00
0005432328135	3125	Economy	5400.00
0005432328146	3125	Economy	5400.00
0005432287131	3125	Economy	5400.00
0005433438800	3125	Economy	5400.00
0005432328158	3125	Economy	5400.00
0005432328133	3125	Economy	5400.00
0005433438798	3125	Economy	5400.00
0005432328129	3125	Economy	5400.00
0005432328165	3125	Economy	5400.00
0005432328136	3125	Economy	5400.00
0005432328128	3125	Economy	5400.00
0005432328126	3125	Economy	5400.00
0005432328127	3125	Economy	5400.00
0005432328134	3125	Economy	5400.00
0005432287130	3125	Economy	5400.00
0005432328147	3125	Economy	5400.00
0005432328125	3125	Economy	5400.00
0005432328170	3125	Economy	5400.00
0005432328140	3125	Economy	5400.00
0005432327962	31144	Business	16100.00
0005432905050	31144	Economy	5900.00
0005432905051	31144	Economy	5400.00
0005432054268	31144	Economy	5400.00
0005432905052	31144	Economy	5400.00
0005432905054	31144	Economy	5400.00
0005432905049	31144	Economy	5400.00
0005432054267	31144	Economy	5400.00
0005432054269	31144	Economy	5400.00
0005433438764	31144	Economy	5400.00
0005432328009	31144	Economy	5400.00
0005432905053	31144	Economy	5400.00
0005432328012	31144	Economy	5400.00
0005432905055	31144	Economy	5400.00
0005435999038	6233	Business	124600.00
0005434309574	6233	Business	124600.00
0005434309573	6233	Business	124600.00
0005435999046	6233	Economy	41500.00
0005434309580	6233	Economy	41500.00
0005435999040	6233	Economy	41500.00
0005435999037	6233	Economy	41500.00
0005434309583	6233	Economy	41500.00
0005434309582	6233	Economy	41500.00
0005435999042	6233	Economy	41500.00
0005434309579	6233	Economy	41500.00
0005434309575	6233	Economy	41500.00
0005434309577	6233	Economy	41500.00
0005435999044	6233	Economy	41500.00
0005435999043	6233	Economy	41500.00
0005435999039	6233	Economy	41500.00
0005434309570	6233	Economy	41500.00
0005435999036	6233	Economy	41500.00
0005434309571	6233	Economy	41500.00
0005432146175	6233	Economy	41500.00
0005434309572	6233	Economy	41500.00
0005434309578	6233	Economy	41500.00
0005434309581	6233	Economy	41500.00
0005435999041	6233	Economy	41500.00
0005434309576	6233	Economy	41500.00
0005435999035	6233	Economy	41500.00
0005435999045	6233	Economy	41500.00
0005435487560	19567	Business	124600.00
0005435487563	19567	Business	124600.00
0005435487557	19567	Economy	41500.00
0005435296978	19567	Economy	41500.00
0005435296973	19567	Economy	41500.00
0005435296977	19567	Economy	41500.00
0005435487550	19567	Economy	41500.00
0005435487546	19567	Economy	41500.00
0005435487554	19567	Economy	41500.00
0005435296972	19567	Economy	41500.00
0005435296975	19567	Economy	45700.00
0005435487552	19567	Economy	45700.00
0005435487543	19567	Economy	41500.00
0005435487556	19567	Economy	41500.00
0005435487551	19567	Economy	41500.00
0005435487561	19567	Economy	41500.00
0005435487547	19567	Economy	41500.00
0005435487555	19567	Economy	41500.00
0005435296974	19567	Economy	41500.00
0005435487548	19567	Economy	41500.00
0005435296976	19567	Economy	41500.00
0005435487544	19567	Economy	41500.00
0005435487553	19567	Economy	41500.00
0005435487558	19567	Economy	41500.00
0005435487549	19567	Economy	41500.00
0005435487559	19567	Economy	41500.00
0005435487562	19567	Economy	41500.00
0005435487545	19567	Economy	41500.00
0005435502059	1558	Business	86000.00
0005435517689	1558	Business	86000.00
0005434565754	1558	Business	86000.00
0005435508225	1558	Business	86000.00
0005434565757	1558	Business	86000.00
0005434565748	1558	Business	86000.00
0005435517709	1558	Business	86000.00
0005435517692	1558	Business	86000.00
0005435508224	1558	Business	86000.00
0005435517699	1558	Business	86000.00
0005434565752	1558	Business	86000.00
0005435502054	1558	Economy	28700.00
0005432291902	1558	Economy	28700.00
0005435517696	1558	Economy	28700.00
0005435517702	1558	Economy	28700.00
0005435517710	1558	Economy	28700.00
0005435502048	1558	Economy	28700.00
0005435502058	1558	Economy	28700.00
0005435517708	1558	Economy	31500.00
0005434565755	1558	Economy	31500.00
0005435517695	1558	Economy	31500.00
0005435508222	1558	Economy	28700.00
0005434565746	1558	Economy	28700.00
0005435502052	1558	Economy	28700.00
0005435502051	1558	Economy	28700.00
0005432291900	1558	Economy	28700.00
0005435517698	1558	Economy	28700.00
0005435508228	1558	Economy	28700.00
0005435502055	1558	Economy	28700.00
0005434565749	1558	Economy	28700.00
0005435502045	1558	Economy	28700.00
0005435517700	1558	Economy	28700.00
0005435508223	1558	Economy	28700.00
0005435502044	1558	Economy	28700.00
0005435517701	1558	Economy	28700.00
0005435508226	1558	Economy	28700.00
0005434565751	1558	Economy	28700.00
0005435502056	1558	Economy	28700.00
0005432291901	1558	Economy	28700.00
0005435502047	1558	Economy	28700.00
0005435502057	1558	Economy	28700.00
0005434565753	1558	Economy	28700.00
0005435517690	1558	Economy	28700.00
0005435517707	1558	Economy	28700.00
0005434565747	1558	Economy	28700.00
0005435502060	1558	Economy	28700.00
0005435517693	1558	Economy	28700.00
0005435517703	1558	Economy	28700.00
0005435502061	1558	Economy	28700.00
0005435517694	1558	Economy	28700.00
0005435517704	1558	Economy	28700.00
0005434565750	1558	Economy	28700.00
0005435502043	1558	Economy	28700.00
0005435517697	1558	Economy	28700.00
0005435502049	1558	Economy	28700.00
0005435502062	1558	Economy	28700.00
0005435517705	1558	Economy	28700.00
0005434565756	1558	Economy	28700.00
0005435517706	1558	Economy	28700.00
0005435517691	1558	Economy	28700.00
0005435508227	1558	Economy	28700.00
0005435502046	1558	Economy	28700.00
0005435502063	1558	Economy	28700.00
0005435502042	1558	Economy	28700.00
0005434565759	1558	Economy	28700.00
0005435502053	1558	Economy	28700.00
0005434565758	1558	Economy	28700.00
0005435502050	1558	Economy	28700.00
0005433186020	20847	Business	86000.00
0005434565686	20847	Business	86000.00
0005433186019	20847	Economy	28700.00
0005433186015	20847	Economy	28700.00
0005433186014	20847	Economy	28700.00
0005433186012	20847	Economy	28700.00
0005433186018	20847	Economy	28700.00
0005433186013	20847	Economy	28700.00
0005433186011	20847	Economy	28700.00
0005433186016	20847	Economy	28700.00
0005433186017	20847	Economy	28700.00
0005435153664	3891	Economy	21600.00
0005435153662	3891	Economy	19700.00
0005435153663	3891	Economy	19700.00
0005435153660	3891	Economy	19700.00
0005435153661	3891	Economy	19700.00
0005435153665	3891	Economy	19700.00
0005435153659	3891	Economy	19700.00
0005435931558	21853	Economy	19700.00
0005435931557	21853	Economy	19700.00
0005435931555	21853	Economy	19700.00
0005435931556	21853	Economy	19700.00
0005435931554	21853	Economy	19700.00
0005432628665	7209	Economy	14300.00
0005432628674	7209	Economy	13000.00
0005432628666	7209	Economy	13000.00
0005432628670	7209	Economy	13000.00
0005432628663	7209	Economy	13000.00
0005432628671	7209	Economy	13000.00
0005435225447	7209	Economy	13000.00
0005432628662	7209	Economy	13000.00
0005432628661	7209	Economy	13000.00
0005432628668	7209	Economy	13000.00
0005435225456	7209	Economy	13000.00
0005432628673	7209	Economy	13000.00
0005432628669	7209	Economy	13000.00
0005432628675	7209	Economy	13000.00
0005435225454	7209	Economy	13000.00
0005435225455	7209	Economy	13000.00
0005432628664	7209	Economy	13000.00
0005432628667	7209	Economy	13000.00
0005432628672	7209	Economy	13000.00
0005435225485	28146	Economy	14300.00
0005432628587	28146	Economy	13000.00
0005435225491	28146	Economy	13000.00
0005435225484	28146	Economy	13000.00
0005435225486	28146	Economy	13000.00
0005432628588	28146	Economy	13000.00
0005435225488	28146	Economy	13000.00
0005435225483	28146	Economy	13000.00
0005435225490	28146	Economy	13000.00
0005435225489	28146	Economy	13000.00
0005435225487	28146	Economy	13000.00
0005435960004	8728	Economy	10500.00
0005435960003	8728	Economy	10500.00
0005435960002	8728	Economy	10500.00
0005435960005	8728	Economy	10500.00
0005434267905	15244	Economy	10500.00
0005434267904	15244	Economy	10500.00
0005434267902	15244	Economy	10500.00
0005434267903	15244	Economy	10500.00
0005432692667	1177	Business	115000.00
0005432674946	1177	Business	115000.00
0005432692668	1177	Business	115000.00
0005432692661	1177	Business	115000.00
0005432692674	1177	Business	115000.00
0005432674954	1177	Business	115000.00
0005432692671	1177	Business	115000.00
0005432674939	1177	Business	115000.00
0005432677520	1177	Business	115000.00
0005432692654	1177	Business	115000.00
0005432674949	1177	Business	115000.00
0005432692662	1177	Business	115000.00
0005432677523	1177	Business	115000.00
0005432674947	1177	Economy	38300.00
0005432692685	1177	Economy	38300.00
0005432692677	1177	Economy	38300.00
0005432692659	1177	Economy	38300.00
0005432873171	1177	Economy	38300.00
0005432692680	1177	Economy	38300.00
0005432692664	1177	Economy	38300.00
0005432692666	1177	Economy	38300.00
0005432692663	1177	Economy	38300.00
0005432692665	1177	Economy	38300.00
0005432692670	1177	Economy	38300.00
0005432692678	1177	Economy	38300.00
0005432692655	1177	Economy	38300.00
0005432692656	1177	Economy	38300.00
0005432692658	1177	Economy	38300.00
0005432674948	1177	Economy	38300.00
0005432692683	1177	Economy	38300.00
0005432677521	1177	Economy	38300.00
0005432692681	1177	Economy	38300.00
0005432674941	1177	Economy	38300.00
0005432692676	1177	Economy	38300.00
0005432692669	1177	Economy	38300.00
0005432692675	1177	Economy	38300.00
0005432674944	1177	Economy	38300.00
0005432674942	1177	Economy	38300.00
0005432674951	1177	Economy	38300.00
0005432692673	1177	Economy	38300.00
0005432674953	1177	Economy	38300.00
0005432692684	1177	Economy	38300.00
0005432692672	1177	Economy	38300.00
0005432692657	1177	Economy	38300.00
0005432674952	1177	Economy	38300.00
0005432674950	1177	Economy	38300.00
0005432692679	1177	Economy	38300.00
0005432692660	1177	Economy	38300.00
0005432674945	1177	Economy	38300.00
0005432692653	1177	Economy	38300.00
0005432674955	1177	Economy	38300.00
0005432692682	1177	Economy	38300.00
0005432674940	1177	Economy	38300.00
0005432677522	1177	Economy	38300.00
0005432674943	1177	Economy	38300.00
0005432873202	17478	Business	115000.00
0005432674885	17478	Economy	38300.00
0005432873204	17478	Economy	38300.00
0005432873205	17478	Economy	38300.00
0005432873208	17478	Economy	38300.00
0005432692565	17478	Economy	38300.00
0005432873207	17478	Economy	38300.00
0005432873203	17478	Economy	38300.00
0005432873206	17478	Economy	38300.00
0005432674886	17478	Economy	38300.00
0005434434992	1134	Economy	15200.00
0005434435000	1134	Economy	13900.00
0005434434995	1134	Economy	13900.00
0005434434998	1134	Economy	13900.00
0005433156599	1134	Economy	13900.00
0005434434988	1134	Economy	13900.00
0005434434999	1134	Economy	13900.00
0005434434997	1134	Economy	13900.00
0005433156610	1134	Economy	13900.00
0005433156597	1134	Economy	13900.00
0005434434993	1134	Economy	13900.00
0005434434994	1134	Economy	13900.00
0005433156598	1134	Economy	13900.00
0005434434991	1134	Economy	13900.00
0005434434989	1134	Economy	13900.00
0005434434996	1134	Economy	13900.00
0005434434990	1134	Economy	13900.00
0005434435001	1134	Economy	13900.00
0005434434987	1134	Economy	13900.00
0005434435002	1134	Economy	13900.00
0005434434924	17295	Economy	15200.00
0005433156644	17295	Economy	13900.00
0005433156641	17295	Economy	13900.00
0005433156642	17295	Economy	13900.00
0005433156648	17295	Economy	13900.00
0005433156640	17295	Economy	13900.00
0005433156645	17295	Economy	13900.00
0005434434923	17295	Economy	13900.00
0005433156646	17295	Economy	13900.00
0005433156647	17295	Economy	13900.00
0005433156643	17295	Economy	13900.00
0005435086740	4078	Economy	8200.00
0005435086744	4078	Economy	7500.00
0005435086742	4078	Economy	7500.00
0005435086743	4078	Economy	7500.00
0005435086741	4078	Economy	7500.00
0005435086739	4078	Economy	7500.00
0005435086745	4078	Economy	7500.00
0005435928083	24414	Economy	7500.00
0005435928085	24414	Economy	7500.00
0005435086713	24414	Economy	7500.00
0005435928084	24414	Economy	7500.00
0005435928086	24414	Economy	7500.00
0005435086712	24414	Economy	7500.00
0005435928082	24414	Economy	7500.00
0005434625845	4851	Business	44200.00
0005434625847	4851	Business	44200.00
0005434625846	4851	Business	44200.00
0005434625852	4851	Economy	14700.00
0005434625848	4851	Economy	14700.00
0005434625842	4851	Economy	14700.00
0005434625844	4851	Economy	14700.00
0005434625851	4851	Economy	14700.00
0005434625850	4851	Economy	14700.00
0005434625843	4851	Economy	14700.00
0005434625849	4851	Economy	14700.00
0005435907446	32885	Business	44200.00
0005435907447	32885	Economy	14700.00
0005435907445	32885	Economy	14700.00
0005435907444	32885	Economy	14700.00
0005432195667	13774	Economy	3100.00
0005435784781	13774	Economy	3100.00
0005435784904	27451	Economy	3400.00
0005435784898	27451	Economy	3400.00
0005432190575	27451	Economy	3400.00
0005435784894	27451	Economy	3100.00
0005435784892	27451	Economy	3100.00
0005435784891	27451	Economy	3100.00
0005435784885	27451	Economy	3100.00
0005435784900	27451	Economy	3100.00
0005435784884	27451	Economy	3100.00
0005435784873	27451	Economy	3100.00
0005435784883	27451	Economy	3100.00
0005435784869	27451	Economy	3100.00
0005435784899	27451	Economy	3100.00
0005435784881	27451	Economy	3100.00
0005435784901	27451	Economy	3100.00
0005435784896	27451	Economy	3100.00
0005435784902	27451	Economy	3100.00
0005435784874	27451	Economy	3100.00
0005432190578	27451	Economy	3100.00
0005435787324	27451	Economy	3100.00
0005435784871	27451	Economy	3100.00
0005435784888	27451	Economy	3100.00
0005435784875	27451	Economy	3100.00
0005435784886	27451	Economy	3100.00
0005432190576	27451	Economy	3100.00
0005435784893	27451	Economy	3100.00
0005435784872	27451	Economy	3100.00
0005435784889	27451	Economy	3100.00
0005435784878	27451	Economy	3100.00
0005432190577	27451	Economy	3100.00
0005435784882	27451	Economy	3100.00
0005435784895	27451	Economy	3100.00
0005435784870	27451	Economy	3100.00
0005435784877	27451	Economy	3100.00
0005435784890	27451	Economy	3100.00
0005435784876	27451	Economy	3100.00
0005435784903	27451	Economy	3100.00
0005435784887	27451	Economy	3100.00
0005435787325	27451	Economy	3100.00
0005435784879	27451	Economy	3100.00
0005435784897	27451	Economy	3100.00
0005435784880	27451	Economy	3100.00
0005432058333	20298	Economy	4000.00
0005432058336	20298	Economy	4000.00
0005432058334	20298	Economy	4000.00
0005432058332	20298	Economy	4000.00
0005432058335	20298	Economy	4000.00
0005434406969	26976	Business	12000.00
0005434406984	26976	Business	12000.00
0005434406961	26976	Business	12000.00
0005434406973	26976	Business	12000.00
0005434407005	26976	Business	12000.00
0005434406991	26976	Business	12000.00
0005434407023	26976	Business	12000.00
0005434406996	26976	Business	12000.00
0005434407000	26976	Business	12000.00
0005434406988	26976	Business	12000.00
0005434406981	26976	Economy	4000.00
0005434406992	26976	Economy	4000.00
0005434406995	26976	Economy	4000.00
0005434407010	26976	Economy	4000.00
0005434406980	26976	Economy	4000.00
0005432153850	26976	Economy	4000.00
0005434406983	26976	Economy	4000.00
0005434406982	26976	Economy	4000.00
0005434407004	26976	Economy	4400.00
0005434406979	26976	Economy	4400.00
0005434406999	26976	Economy	4400.00
0005434407017	26976	Economy	4400.00
0005434407003	26976	Economy	4000.00
0005434406970	26976	Economy	4000.00
0005434406967	26976	Economy	4000.00
0005434406978	26976	Economy	4000.00
0005434407009	26976	Economy	4000.00
0005434406964	26976	Economy	4000.00
0005434406959	26976	Economy	4000.00
0005434406993	26976	Economy	4000.00
0005432153855	26976	Economy	4000.00
0005434407022	26976	Economy	4000.00
0005434407015	26976	Economy	4000.00
0005434407016	26976	Economy	4000.00
0005434406985	26976	Economy	4000.00
0005434406971	26976	Economy	4000.00
0005434407012	26976	Economy	4000.00
0005434406997	26976	Economy	4000.00
0005434406990	26976	Economy	4000.00
0005434407013	26976	Economy	4000.00
0005434407002	26976	Economy	4000.00
0005434406974	26976	Economy	4000.00
0005434406960	26976	Economy	4000.00
0005434406977	26976	Economy	4000.00
0005434406968	26976	Economy	4000.00
0005434407019	26976	Economy	4000.00
0005434406987	26976	Economy	4000.00
0005434406998	26976	Economy	4000.00
0005432153854	26976	Economy	4000.00
0005434406975	26976	Economy	4000.00
0005432153852	26976	Economy	4000.00
0005434406966	26976	Economy	4000.00
0005434407008	26976	Economy	4000.00
0005434407014	26976	Economy	4000.00
0005434406965	26976	Economy	4000.00
0005434407011	26976	Economy	4000.00
0005432153851	26976	Economy	4000.00
0005434406972	26976	Economy	4000.00
0005434407001	26976	Economy	4000.00
0005434407020	26976	Economy	4000.00
0005434406976	26976	Economy	4000.00
0005432153853	26976	Economy	4000.00
0005434407006	26976	Economy	4000.00
0005434407018	26976	Economy	4000.00
0005434406963	26976	Economy	4000.00
0005434406962	26976	Economy	4000.00
0005434406986	26976	Economy	4000.00
0005434407007	26976	Economy	4000.00
0005434406989	26976	Economy	4000.00
0005434406994	26976	Economy	4000.00
0005434407021	26976	Economy	4000.00
0005434319221	5681	Business	43300.00
0005434319213	5681	Business	43300.00
0005434319218	5681	Business	43300.00
0005434319225	5681	Business	43300.00
0005432109669	5681	Business	43300.00
0005434319212	5681	Economy	14400.00
0005434311192	5681	Economy	14400.00
0005434319210	5681	Economy	14400.00
0005434319217	5681	Economy	14400.00
0005434311191	5681	Economy	14400.00
0005432109668	5681	Economy	15900.00
0005434319219	5681	Economy	15900.00
0005434319216	5681	Economy	14400.00
0005434319224	5681	Economy	14400.00
0005432109670	5681	Economy	14400.00
0005434319223	5681	Economy	14400.00
0005434319215	5681	Economy	14400.00
0005434319222	5681	Economy	14400.00
0005433123575	5681	Economy	14400.00
0005434319228	5681	Economy	14400.00
0005434319214	5681	Economy	14400.00
0005434319220	5681	Economy	14400.00
0005434319211	5681	Economy	14400.00
0005434319226	5681	Economy	14400.00
0005434311193	5681	Economy	14400.00
0005434319227	5681	Economy	14400.00
0005433123693	15672	Business	43300.00
0005433123681	15672	Business	43300.00
0005433123695	15672	Business	43300.00
0005433123696	15672	Business	43300.00
0005433123689	15672	Economy	14400.00
0005433123691	15672	Economy	14400.00
0005433123686	15672	Economy	14400.00
0005433123688	15672	Economy	14400.00
0005433123680	15672	Economy	14400.00
0005433123698	15672	Economy	14400.00
0005433123697	15672	Economy	14400.00
0005433123690	15672	Economy	14400.00
0005433123684	15672	Economy	14400.00
0005433123679	15672	Economy	14400.00
0005433123687	15672	Economy	14400.00
0005433123682	15672	Economy	14400.00
0005433123692	15672	Economy	14400.00
0005433123683	15672	Economy	14400.00
0005433123694	15672	Economy	14400.00
0005433123685	15672	Economy	14400.00
0005434484268	8963	Economy	24900.00
0005434484266	8963	Economy	24900.00
0005434484270	8963	Economy	24900.00
0005434484269	8963	Economy	24900.00
0005434484265	8963	Economy	24900.00
0005434484267	8963	Economy	24900.00
0005434189106	16627	Economy	24900.00
0005434189108	16627	Economy	24900.00
0005434189110	16627	Economy	24900.00
0005434189109	16627	Economy	24900.00
0005434189105	16627	Economy	24900.00
0005434189107	16627	Economy	24900.00
0005433123690	7646	Business	11100.00
0005433123679	7646	Business	11100.00
0005433123692	7646	Business	11100.00
0005433123687	7646	Business	11100.00
0005433123681	7646	Business	11100.00
0005433123698	7646	Economy	3700.00
0005433123684	7646	Economy	3700.00
0005433123682	7646	Economy	3700.00
0005433123697	7646	Economy	4100.00
0005433123686	7646	Economy	4100.00
0005433123680	7646	Economy	3700.00
0005433123696	7646	Economy	3700.00
0005433123694	7646	Economy	3700.00
0005433123689	7646	Economy	3700.00
0005433123693	7646	Economy	3700.00
0005433123695	7646	Economy	3700.00
0005433123688	7646	Economy	3700.00
0005433123691	7646	Economy	3700.00
0005433123685	7646	Economy	3700.00
0005433123683	7646	Economy	3700.00
0005432720584	7647	Business	11100.00
0005432692702	7647	Business	11100.00
0005432692698	7647	Business	11100.00
0005432720576	7647	Business	11100.00
0005432720575	7647	Business	11100.00
0005432692715	7647	Business	11100.00
0005433449707	7647	Business	11100.00
0005432720591	7647	Business	11100.00
0005432692700	7647	Business	11100.00
0005432692689	7647	Business	11100.00
0005433449699	7647	Business	11100.00
0005432692701	7647	Economy	3700.00
0005432692691	7647	Economy	3700.00
0005432692697	7647	Economy	3700.00
0005432692703	7647	Economy	3700.00
0005432720583	7647	Economy	3700.00
0005432692690	7647	Economy	3700.00
0005432692708	7647	Economy	3700.00
0005433449708	7647	Economy	3700.00
0005432692692	7647	Economy	3700.00
0005432720568	7647	Economy	3700.00
0005432692711	7647	Economy	4100.00
0005432692695	7647	Economy	4100.00
0005432720573	7647	Economy	4100.00
0005432720565	7647	Economy	4100.00
0005433449715	7647	Economy	3700.00
0005432720572	7647	Economy	3700.00
0005433449709	7647	Economy	3700.00
0005432692705	7647	Economy	3700.00
0005432720566	7647	Economy	3700.00
0005432720569	7647	Economy	3700.00
0005432692686	7647	Economy	3700.00
0005432692714	7647	Economy	3700.00
0005432071538	7647	Economy	3700.00
0005433449712	7647	Economy	3700.00
0005433449703	7647	Economy	3700.00
0005433449706	7647	Economy	3700.00
0005432720587	7647	Economy	3700.00
0005433449713	7647	Economy	3700.00
0005432692694	7647	Economy	3700.00
0005433449716	7647	Economy	3700.00
0005433449705	7647	Economy	3700.00
0005432720578	7647	Economy	3700.00
0005432692709	7647	Economy	3700.00
0005433449700	7647	Economy	3700.00
0005433449714	7647	Economy	3700.00
0005433449704	7647	Economy	3700.00
0005432692693	7647	Economy	3700.00
0005432720582	7647	Economy	3700.00
0005432720590	7647	Economy	3700.00
0005432720580	7647	Economy	3700.00
0005432720567	7647	Economy	3700.00
0005432720589	7647	Economy	3700.00
0005432720579	7647	Economy	3700.00
0005432720581	7647	Economy	3700.00
0005433449695	7647	Economy	3700.00
0005432071537	7647	Economy	3700.00
0005432692696	7647	Economy	3700.00
0005433449697	7647	Economy	3700.00
0005432720586	7647	Economy	3700.00
0005432692712	7647	Economy	3700.00
0005432692688	7647	Economy	3700.00
0005433449711	7647	Economy	3700.00
0005433449710	7647	Economy	3700.00
0005432720570	7647	Economy	3700.00
0005433449696	7647	Economy	3700.00
0005432720588	7647	Economy	3700.00
0005432692706	7647	Economy	3700.00
0005432692716	7647	Economy	3700.00
0005432692699	7647	Economy	3700.00
0005432720574	7647	Economy	3700.00
0005432720577	7647	Economy	3700.00
0005433449702	7647	Economy	3700.00
0005432692704	7647	Economy	3700.00
0005432692710	7647	Economy	3700.00
0005432720585	7647	Economy	3700.00
0005433449701	7647	Economy	3700.00
0005433449698	7647	Economy	3700.00
0005432692707	7647	Economy	3700.00
0005432692713	7647	Economy	3700.00
0005432720592	7647	Economy	3700.00
0005432720571	7647	Economy	3700.00
0005432692687	7647	Economy	3700.00
0005433449588	30410	Economy	3700.00
0005432692565	30410	Economy	3700.00
0005433449604	30410	Economy	3700.00
0005433449605	30410	Economy	3700.00
0005432720470	30409	Business	11100.00
0005432720451	30409	Business	11100.00
0005433123575	30409	Economy	3700.00
0005433722138	30409	Economy	3700.00
0005433722133	30409	Economy	4100.00
0005432720452	30409	Economy	3700.00
0005432720461	30409	Economy	3700.00
0005433722135	30409	Economy	3700.00
0005433722140	30409	Economy	3700.00
0005433722139	30409	Economy	3700.00
0005432720460	30409	Economy	3700.00
0005433722136	30409	Economy	3700.00
0005433722137	30409	Economy	3700.00
0005433722132	30409	Economy	3700.00
0005433722134	30409	Economy	3700.00
0005432720462	30409	Economy	3700.00
0005434586289	1353	Business	70400.00
0005433524903	1353	Business	70400.00
0005434586297	1353	Business	70400.00
0005434586313	1353	Business	70400.00
0005433192841	1353	Business	70400.00
0005433524907	1353	Economy	23500.00
0005434586312	1353	Economy	23500.00
0005434513547	1353	Economy	23500.00
0005432270968	1353	Economy	23500.00
0005434586294	1353	Economy	23500.00
0005434586292	1353	Economy	25800.00
0005433724749	1353	Economy	25800.00
0005434586298	1353	Economy	25800.00
0005434586290	1353	Economy	23500.00
0005434586305	1353	Economy	23500.00
0005433524901	1353	Economy	23500.00
0005434586302	1353	Economy	23500.00
0005433524904	1353	Economy	23500.00
0005434514935	1353	Economy	23500.00
0005433724750	1353	Economy	23500.00
0005434586306	1353	Economy	23500.00
0005434586309	1353	Economy	23500.00
0005434513548	1353	Economy	23500.00
0005433192826	1353	Economy	23500.00
0005434586310	1353	Economy	23500.00
0005434586288	1353	Economy	23500.00
0005434586307	1353	Economy	23500.00
0005433524905	1353	Economy	23500.00
0005433524902	1353	Economy	23500.00
0005434586293	1353	Economy	23500.00
0005434586308	1353	Economy	23500.00
0005433724748	1353	Economy	23500.00
0005434586303	1353	Economy	23500.00
0005434586300	1353	Economy	23500.00
0005434586295	1353	Economy	23500.00
0005434586296	1353	Economy	23500.00
0005433524911	1353	Economy	23500.00
0005434586291	1353	Economy	23500.00
0005434586301	1353	Economy	23500.00
0005433524906	1353	Economy	23500.00
0005433524909	1353	Economy	23500.00
0005433724751	1353	Economy	23500.00
0005432270970	1353	Economy	23500.00
0005432270969	1353	Economy	23500.00
0005434586311	1353	Economy	23500.00
0005434514934	1353	Economy	23500.00
0005433524908	1353	Economy	23500.00
0005434586304	1353	Economy	23500.00
0005434514936	1353	Economy	23500.00
0005433724752	1353	Economy	23500.00
0005434586299	1353	Economy	23500.00
0005433524910	1353	Economy	23500.00
0005432927913	18501	Business	70400.00
0005433192889	18501	Business	70400.00
0005432927911	18501	Business	70400.00
0005432968811	18501	Economy	23500.00
0005433192888	18501	Economy	23500.00
0005434586160	18501	Economy	25800.00
0005433192886	18501	Economy	23500.00
0005433192880	18501	Economy	23500.00
0005433192887	18501	Economy	23500.00
0005433192878	18501	Economy	23500.00
0005432968812	18501	Economy	23500.00
0005433192884	18501	Economy	23500.00
0005433192883	18501	Economy	23500.00
0005433192879	18501	Economy	23500.00
0005433192881	18501	Economy	23500.00
0005433192885	18501	Economy	23500.00
0005433192890	18501	Economy	23500.00
0005433192877	18501	Economy	23500.00
0005432927909	18501	Economy	23500.00
0005433192882	18501	Economy	23500.00
0005432927910	18501	Economy	23500.00
0005432927912	18501	Economy	23500.00
0005434343738	11452	Economy	4300.00
0005434343745	11452	Economy	4300.00
0005434343736	11452	Economy	4300.00
0005434343744	11452	Economy	4300.00
0005434343729	11452	Economy	4000.00
0005434343730	11452	Economy	4000.00
0005434343754	11452	Economy	4000.00
0005434343750	11452	Economy	4000.00
0005434343757	11452	Economy	4000.00
0005434343734	11452	Economy	4000.00
0005434343758	11452	Economy	4000.00
0005434142562	11452	Economy	4000.00
0005434343751	11452	Economy	4000.00
0005434343726	11452	Economy	4000.00
0005434343748	11452	Economy	4000.00
0005434142564	11452	Economy	4000.00
0005434343735	11452	Economy	4000.00
0005434142561	11452	Economy	4000.00
0005434343727	11452	Economy	4000.00
0005434343741	11452	Economy	4000.00
0005434343760	11452	Economy	4000.00
0005434343759	11452	Economy	4000.00
0005434343728	11452	Economy	4000.00
0005434343740	11452	Economy	4000.00
0005434343731	11452	Economy	4000.00
0005434343746	11452	Economy	4000.00
0005434343739	11452	Economy	4000.00
0005434142563	11452	Economy	4000.00
0005434343725	11452	Economy	4000.00
0005434343732	11452	Economy	4000.00
0005434343743	11452	Economy	4000.00
0005434343755	11452	Economy	4000.00
0005434343737	11452	Economy	4000.00
0005434343749	11452	Economy	4000.00
0005434343756	11452	Economy	4000.00
0005434343752	11452	Economy	4000.00
0005434343747	11452	Economy	4000.00
0005434343753	11452	Economy	4000.00
0005434343742	11452	Economy	4000.00
0005434343733	11452	Economy	4000.00
0005435824300	1274	Business	199800.00
0005435824302	1274	Business	199800.00
0005435824299	1274	Business	199800.00
0005435824295	1274	Business	199800.00
0005435824297	1274	Business	199800.00
0005435824316	1274	Business	199800.00
0005435824288	1274	Economy	66600.00
0005435824293	1274	Economy	66600.00
0005433415385	1274	Economy	66600.00
0005435824315	1274	Economy	66600.00
0005435824305	1274	Economy	73200.00
0005432284523	1274	Economy	73200.00
0005435824304	1274	Economy	66600.00
0005435824306	1274	Economy	66600.00
0005435824301	1274	Economy	66600.00
0005433415426	1274	Economy	66600.00
0005435824312	1274	Economy	66600.00
0005435824290	1274	Economy	66600.00
0005435824291	1274	Economy	66600.00
0005433415383	1274	Economy	66600.00
0005435824307	1274	Economy	66600.00
0005435824298	1274	Economy	66600.00
0005435824310	1274	Economy	66600.00
0005435824308	1274	Economy	66600.00
0005435824289	1274	Economy	66600.00
0005435824292	1274	Economy	66600.00
0005435824294	1274	Economy	66600.00
0005435824309	1274	Economy	66600.00
0005435824296	1274	Economy	66600.00
0005435824313	1274	Economy	66600.00
0005435824303	1274	Economy	66600.00
0005433415384	1274	Economy	66600.00
0005435824314	1274	Economy	66600.00
0005432284522	1274	Economy	66600.00
0005435824311	1274	Economy	66600.00
0005433415472	18000	Business	199800.00
0005433415461	18000	Business	199800.00
0005433415468	18000	Business	199800.00
0005433415473	18000	Business	199800.00
0005433415464	18000	Economy	66600.00
0005433415474	18000	Economy	66600.00
0005435824161	18000	Economy	73200.00
0005435824200	18000	Economy	73200.00
0005433415470	18000	Economy	73200.00
0005433415466	18000	Economy	66600.00
0005433415463	18000	Economy	66600.00
0005433415465	18000	Economy	66600.00
0005435824191	18000	Economy	66600.00
0005435824160	18000	Economy	66600.00
0005435824202	18000	Economy	66600.00
0005433415467	18000	Economy	66600.00
0005435824204	18000	Economy	66600.00
0005433415471	18000	Economy	66600.00
0005435824203	18000	Economy	66600.00
0005433415460	18000	Economy	66600.00
0005435824205	18000	Economy	66600.00
0005435824201	18000	Economy	66600.00
0005433415475	18000	Economy	66600.00
0005433415469	18000	Economy	66600.00
0005433415462	18000	Economy	66600.00
0005434460470	12578	Economy	14800.00
0005434461615	12578	Economy	13500.00
0005434461617	12578	Economy	13500.00
0005434461619	12578	Economy	13500.00
0005434461612	12578	Economy	13500.00
0005434461614	12578	Economy	13500.00
0005434461618	12578	Economy	13500.00
0005434460472	12578	Economy	13500.00
0005434461611	12578	Economy	13500.00
0005434461613	12578	Economy	13500.00
0005434461620	12578	Economy	13500.00
0005434460469	12578	Economy	13500.00
0005434460474	12578	Economy	13500.00
0005434460473	12578	Economy	13500.00
0005434460471	12578	Economy	13500.00
0005434460475	12578	Economy	13500.00
0005434461616	12578	Economy	13500.00
0005434460476	12578	Economy	13500.00
0005432783113	5652	Business	27800.00
0005432783167	5652	Business	27800.00
0005432783147	5652	Business	27800.00
0005432783138	5652	Business	27800.00
0005432783136	5652	Business	27800.00
0005432783158	5652	Business	27800.00
0005432783141	5652	Business	27800.00
0005432783120	5652	Business	27800.00
0005432783140	5652	Business	27800.00
0005432783160	5652	Economy	9300.00
0005432783163	5652	Economy	9300.00
0005432783117	5652	Economy	9300.00
0005432783162	5652	Economy	9300.00
0005432783155	5652	Economy	9300.00
0005432783159	5652	Economy	10200.00
0005432783121	5652	Economy	10200.00
0005432783125	5652	Economy	10200.00
0005432783161	5652	Economy	9300.00
0005432783124	5652	Economy	9300.00
0005432783127	5652	Economy	9300.00
0005432783154	5652	Economy	9300.00
0005435242400	5652	Economy	9300.00
0005432783144	5652	Economy	9300.00
0005432783143	5652	Economy	9300.00
0005432783118	5652	Economy	9300.00
0005432783151	5652	Economy	9300.00
0005432783139	5652	Economy	9300.00
0005432783115	5652	Economy	9300.00
0005432783164	5652	Economy	9300.00
0005432783145	5652	Economy	9300.00
0005432783157	5652	Economy	9300.00
0005432783122	5652	Economy	9300.00
0005432783165	5652	Economy	9300.00
0005432783148	5652	Economy	9300.00
0005432783119	5652	Economy	9300.00
0005435242401	5652	Economy	9300.00
0005432783142	5652	Economy	9300.00
0005432783133	5652	Economy	9300.00
0005432783130	5652	Economy	9300.00
0005432783132	5652	Economy	9300.00
0005432783149	5652	Economy	9300.00
0005432783128	5652	Economy	9300.00
0005432783114	5652	Economy	9300.00
0005432783146	5652	Economy	9300.00
0005432783123	5652	Economy	9300.00
0005432783131	5652	Economy	9300.00
0005432783135	5652	Economy	9300.00
0005432783152	5652	Economy	9300.00
0005432143946	5652	Economy	9300.00
0005432783150	5652	Economy	9300.00
0005432783134	5652	Economy	9300.00
0005432783168	5652	Economy	9300.00
0005432783166	5652	Economy	9300.00
0005432783116	5652	Economy	9300.00
0005432783129	5652	Economy	9300.00
0005432783153	5652	Economy	9300.00
0005432783126	5652	Economy	9300.00
0005432143947	5652	Economy	9300.00
0005432783137	5652	Economy	9300.00
0005432783156	5652	Economy	9300.00
0005432143948	5652	Economy	9300.00
0005435242498	15360	Business	27800.00
0005435242520	15360	Business	27800.00
0005435242514	15360	Business	27800.00
0005435476672	15360	Business	27800.00
0005435242500	15360	Business	27800.00
0005435242502	15360	Business	27800.00
0005435242508	15360	Business	27800.00
0005435476676	15360	Economy	9300.00
0005435476677	15360	Economy	9300.00
0005435242513	15360	Economy	9300.00
0005435476670	15360	Economy	10200.00
0005435242523	15360	Economy	9300.00
0005432782863	15360	Economy	9300.00
0005435242511	15360	Economy	9300.00
0005435242519	15360	Economy	9300.00
0005435242504	15360	Economy	9300.00
0005435242510	15360	Economy	9300.00
0005435242512	15360	Economy	9300.00
0005435242521	15360	Economy	9300.00
0005435242499	15360	Economy	9300.00
0005435242522	15360	Economy	9300.00
0005435242526	15360	Economy	9300.00
0005435242505	15360	Economy	9300.00
0005435242503	15360	Economy	9300.00
0005435242517	15360	Economy	9300.00
0005435476669	15360	Economy	9300.00
0005435242509	15360	Economy	9300.00
0005435242524	15360	Economy	9300.00
0005435476679	15360	Economy	9300.00
0005435242516	15360	Economy	9300.00
0005435476675	15360	Economy	9300.00
0005435476674	15360	Economy	9300.00
0005435242515	15360	Economy	9300.00
0005435242525	15360	Economy	9300.00
0005435476678	15360	Economy	9300.00
0005435242518	15360	Economy	9300.00
0005435242501	15360	Economy	9300.00
0005435242506	15360	Economy	9300.00
0005435242507	15360	Economy	9300.00
0005435476671	15360	Economy	9300.00
0005435476673	15360	Economy	9300.00
0005435476680	15360	Economy	9300.00
0005432848138	4367	Economy	7000.00
0005434463903	4367	Economy	6300.00
0005432848137	4367	Economy	6300.00
0005432848133	4367	Economy	6300.00
0005432848141	4367	Economy	6300.00
0005432848135	4367	Economy	6300.00
0005435850772	4367	Economy	6300.00
0005435850775	4367	Economy	6300.00
0005432848136	4367	Economy	6300.00
0005432848140	4367	Economy	6300.00
0005432848132	4367	Economy	6300.00
0005432848134	4367	Economy	6300.00
0005434462764	4367	Economy	6300.00
0005432848143	4367	Economy	6300.00
0005432848142	4367	Economy	6300.00
0005432848131	4367	Economy	6300.00
0005435850750	4367	Economy	6300.00
0005432848139	4367	Economy	6300.00
0005435850751	4367	Economy	6300.00
0005432848129	4367	Economy	6300.00
0005432848130	4367	Economy	6300.00
0005432848058	28843	Economy	7000.00
0005435850800	28843	Economy	6300.00
0005435850798	28843	Economy	6300.00
0005435850804	28843	Economy	6300.00
0005435850796	28843	Economy	6300.00
0005434461608	28843	Economy	6300.00
0005435850801	28843	Economy	6300.00
0005435850797	28843	Economy	6300.00
0005435850799	28843	Economy	6300.00
0005435850802	28843	Economy	6300.00
0005435850803	28843	Economy	6300.00
0005435850795	28843	Economy	6300.00
0005433496604	6281	Business	11900.00
0005434925431	6281	Business	11900.00
0005433496588	6281	Business	11900.00
0005433496591	6281	Business	11900.00
0005434443509	6281	Business	11900.00
0005433496600	6281	Business	11900.00
0005434925430	6281	Business	11900.00
0005433496612	6281	Business	11900.00
0005433496586	6281	Business	11900.00
0005434925422	6281	Business	11900.00
0005434443519	6281	Business	11900.00
0005434925432	6281	Economy	4000.00
0005433496599	6281	Economy	4000.00
0005434443508	6281	Economy	4000.00
0005434925421	6281	Economy	4000.00
0005434443518	6281	Economy	4000.00
0005434925420	6281	Economy	4000.00
0005434925424	6281	Economy	4000.00
0005434443517	6281	Economy	4000.00
0005434925403	6281	Economy	4000.00
0005434925427	6281	Economy	4400.00
0005434925398	6281	Economy	4400.00
0005433496594	6281	Economy	4400.00
0005434443521	6281	Economy	4400.00
0005433496598	6281	Economy	4400.00
0005433496608	6281	Economy	4000.00
0005434443520	6281	Economy	4000.00
0005433496596	6281	Economy	4000.00
0005434925415	6281	Economy	4000.00
0005434443511	6281	Economy	4000.00
0005433496581	6281	Economy	4000.00
0005434925423	6281	Economy	4000.00
0005434925404	6281	Economy	4000.00
0005433496609	6281	Economy	4000.00
0005434925408	6281	Economy	4000.00
0005434443507	6281	Economy	4000.00
0005434925407	6281	Economy	4000.00
0005434925402	6281	Economy	4000.00
0005433496587	6281	Economy	4000.00
0005434925401	6281	Economy	4000.00
0005434925410	6281	Economy	4000.00
0005434925426	6281	Economy	4000.00
0005434925417	6281	Economy	4000.00
0005434925400	6281	Economy	4000.00
0005433496607	6281	Economy	4000.00
0005433496578	6281	Economy	4000.00
0005433496582	6281	Economy	4000.00
0005432075187	6281	Economy	4000.00
0005433496603	6281	Economy	4000.00
0005434443513	6281	Economy	4000.00
0005433496590	6281	Economy	4000.00
0005434925412	6281	Economy	4000.00
0005434925399	6281	Economy	4000.00
0005433496589	6281	Economy	4000.00
0005434925419	6281	Economy	4000.00
0005433496605	6281	Economy	4000.00
0005433496584	6281	Economy	4000.00
0005434443510	6281	Economy	4000.00
0005432075189	6281	Economy	4000.00
0005433496579	6281	Economy	4000.00
0005434925409	6281	Economy	4000.00
0005433496597	6281	Economy	4000.00
0005434925406	6281	Economy	4000.00
0005432075188	6281	Economy	4000.00
0005434443516	6281	Economy	4000.00
0005434925418	6281	Economy	4000.00
0005434443514	6281	Economy	4000.00
0005433496593	6281	Economy	4000.00
0005433496606	6281	Economy	4000.00
0005433496602	6281	Economy	4000.00
0005434925414	6281	Economy	4000.00
0005434925413	6281	Economy	4000.00
0005434925397	6281	Economy	4000.00
0005433496585	6281	Economy	4000.00
0005433496610	6281	Economy	4000.00
0005433496583	6281	Economy	4000.00
0005434925429	6281	Economy	4000.00
0005434443512	6281	Economy	4000.00
0005434925428	6281	Economy	4000.00
0005433496580	6281	Economy	4000.00
0005433496592	6281	Economy	4000.00
0005433496601	6281	Economy	4000.00
0005434925416	6281	Economy	4000.00
0005434925425	6281	Economy	4000.00
0005433496595	6281	Economy	4000.00
0005434443515	6281	Economy	4000.00
0005434925405	6281	Economy	4000.00
0005434925411	6281	Economy	4000.00
0005433496611	6281	Economy	4000.00
0005433496423	20367	Business	11900.00
0005434443430	20367	Business	11900.00
0005433496422	20367	Business	11900.00
0005433496497	20367	Economy	4000.00
0005433496472	20367	Economy	4400.00
0005433496471	20367	Economy	4000.00
0005434443432	20367	Economy	4000.00
0005434443429	20367	Economy	4000.00
0005434443431	20367	Economy	4000.00
0005433496440	20367	Economy	4000.00
0005435242534	12206	Business	41200.00
0005435242539	12206	Business	41200.00
0005435242546	12206	Business	41200.00
0005435242547	12206	Business	41200.00
0005435242540	12206	Economy	13700.00
0005435242536	12206	Economy	13700.00
0005432782869	12206	Economy	13700.00
0005435242549	12206	Economy	13700.00
0005435242537	12206	Economy	15100.00
0005435242538	12206	Economy	15100.00
0005435242550	12206	Economy	13700.00
0005435242530	12206	Economy	13700.00
0005432782847	12206	Economy	13700.00
0005435242535	12206	Economy	13700.00
0005432783022	12206	Economy	13700.00
0005435242541	12206	Economy	13700.00
0005435242553	12206	Economy	13700.00
0005432782890	12206	Economy	13700.00
0005435242529	12206	Economy	13700.00
0005435242527	12206	Economy	13700.00
0005435242531	12206	Economy	13700.00
0005435242533	12206	Economy	13700.00
0005435242552	12206	Economy	13700.00
0005435242532	12206	Economy	13700.00
0005435242542	12206	Economy	13700.00
0005432782844	12206	Economy	13700.00
0005435242544	12206	Economy	13700.00
0005435242543	12206	Economy	13700.00
0005435242551	12206	Economy	13700.00
0005435242548	12206	Economy	13700.00
0005432782870	12206	Economy	13700.00
0005435242528	12206	Economy	13700.00
0005435242545	12206	Economy	13700.00
0005432783069	15404	Business	41200.00
0005432783068	15404	Business	41200.00
0005432783097	15404	Business	41200.00
0005432783076	15404	Business	41200.00
0005432783070	15404	Business	41200.00
0005432783107	15404	Business	41200.00
0005432783080	15404	Business	41200.00
0005432783071	15404	Economy	13700.00
0005432783082	15404	Economy	13700.00
0005432783095	15404	Economy	13700.00
0005432783067	15404	Economy	13700.00
0005432783063	15404	Economy	13700.00
0005432783084	15404	Economy	13700.00
0005432783112	15404	Economy	13700.00
0005432783096	15404	Economy	15100.00
0005432783091	15404	Economy	13700.00
0005432783086	15404	Economy	13700.00
0005432783106	15404	Economy	13700.00
0005432783074	15404	Economy	13700.00
0005432783099	15404	Economy	13700.00
0005432783103	15404	Economy	13700.00
0005432783101	15404	Economy	13700.00
0005432783090	15404	Economy	13700.00
0005432783089	15404	Economy	13700.00
0005432783058	15404	Economy	13700.00
0005432783094	15404	Economy	13700.00
0005432783087	15404	Economy	13700.00
0005432783092	15404	Economy	13700.00
0005432783109	15404	Economy	13700.00
0005432783060	15404	Economy	13700.00
0005432783075	15404	Economy	13700.00
0005432783093	15404	Economy	13700.00
0005432783108	15404	Economy	13700.00
0005432783100	15404	Economy	13700.00
0005432783072	15404	Economy	13700.00
0005432783062	15404	Economy	13700.00
0005432783066	15404	Economy	13700.00
0005432783098	15404	Economy	13700.00
0005432783088	15404	Economy	13700.00
0005432783102	15404	Economy	13700.00
0005432783105	15404	Economy	13700.00
0005432783085	15404	Economy	13700.00
0005432783104	15404	Economy	13700.00
0005432783083	15404	Economy	13700.00
0005432783059	15404	Economy	13700.00
0005432783111	15404	Economy	13700.00
0005432783081	15404	Economy	13700.00
0005432783061	15404	Economy	13700.00
0005432783064	15404	Economy	13700.00
0005432783078	15404	Economy	13700.00
0005432783110	15404	Economy	13700.00
0005432783073	15404	Economy	13700.00
0005432783065	15404	Economy	13700.00
0005432783077	15404	Economy	13700.00
0005432783079	15404	Economy	13700.00
0005434876788	10074	Business	49700.00
0005434910081	10074	Business	49700.00
0005435913880	10074	Business	49700.00
0005435913885	10074	Economy	16600.00
0005434758853	10074	Economy	16600.00
0005435913875	10074	Economy	16600.00
0005434876789	10074	Economy	16600.00
0005435913883	10074	Economy	16600.00
0005434876622	10074	Economy	18200.00
0005434876655	10074	Economy	18200.00
0005434876608	10074	Economy	16600.00
0005434910080	10074	Economy	16600.00
0005434910079	10074	Economy	16600.00
0005435913877	10074	Economy	16600.00
0005435913884	10074	Economy	16600.00
0005434758854	10074	Economy	16600.00
0005434876568	10074	Economy	16600.00
0005435913887	10074	Economy	16600.00
0005435913876	10074	Economy	16600.00
0005435913878	10074	Economy	16600.00
0005435913886	10074	Economy	16600.00
0005435913881	10074	Economy	16600.00
0005435913888	10074	Economy	16600.00
0005435913879	10074	Economy	16600.00
0005435913882	10074	Economy	16600.00
0005434876654	10074	Economy	16600.00
0005434877053	14631	Business	49700.00
0005434877123	14631	Business	49700.00
0005434877067	14631	Business	49700.00
0005434877042	14631	Business	49700.00
0005434877085	14631	Business	49700.00
0005434877069	14631	Business	49700.00
0005434877068	14631	Business	49700.00
0005434877077	14631	Business	49700.00
0005434877105	14631	Business	49700.00
0005434877104	14631	Business	49700.00
0005434877098	14631	Business	49700.00
0005434877065	14631	Business	49700.00
0005434877091	14631	Business	49700.00
0005434877113	14631	Business	49700.00
0005434877109	14631	Business	49700.00
0005434877082	14631	Business	49700.00
0005434877086	14631	Business	49700.00
0005434877103	14631	Business	49700.00
0005434877136	14631	Business	49700.00
0005434877064	14631	Business	49700.00
0005434877102	14631	Economy	16600.00
0005434877051	14631	Economy	16600.00
0005434877124	14631	Economy	16600.00
0005434877059	14631	Economy	16600.00
0005434877044	14631	Economy	16600.00
0005434877047	14631	Economy	16600.00
0005434877093	14631	Economy	16600.00
0005434877099	14631	Economy	16600.00
0005434877050	14631	Economy	16600.00
0005434877056	14631	Economy	16600.00
0005434758864	14631	Economy	16600.00
0005434877122	14631	Economy	16600.00
0005434877070	14631	Economy	18200.00
0005434877052	14631	Economy	18200.00
0005434877089	14631	Economy	16600.00
0005434877097	14631	Economy	16600.00
0005434877108	14631	Economy	16600.00
0005434877084	14631	Economy	16600.00
0005434877080	14631	Economy	16600.00
0005434877071	14631	Economy	16600.00
0005434877125	14631	Economy	16600.00
0005434877126	14631	Economy	16600.00
0005434877049	14631	Economy	16600.00
0005434877110	14631	Economy	16600.00
0005434877112	14631	Economy	16600.00
0005434877062	14631	Economy	16600.00
0005434877114	14631	Economy	16600.00
0005434877048	14631	Economy	16600.00
0005434877079	14631	Economy	16600.00
0005434877088	14631	Economy	16600.00
0005434877043	14631	Economy	16600.00
0005434877045	14631	Economy	16600.00
0005434877072	14631	Economy	16600.00
0005434877120	14631	Economy	16600.00
0005434877111	14631	Economy	16600.00
0005434877118	14631	Economy	16600.00
0005434877132	14631	Economy	16600.00
0005434877087	14631	Economy	16600.00
0005434877135	14631	Economy	16600.00
0005434877119	14631	Economy	16600.00
0005434877092	14631	Economy	16600.00
0005434877095	14631	Economy	16600.00
0005434877117	14631	Economy	16600.00
0005434877040	14631	Economy	16600.00
0005434877116	14631	Economy	16600.00
0005434877060	14631	Economy	16600.00
0005434877115	14631	Economy	16600.00
0005434877054	14631	Economy	16600.00
0005434877081	14631	Economy	16600.00
0005434877101	14631	Economy	16600.00
0005434877078	14631	Economy	16600.00
0005434877074	14631	Economy	16600.00
0005434877083	14631	Economy	16600.00
0005434877128	14631	Economy	16600.00
0005434877100	14631	Economy	16600.00
0005434877046	14631	Economy	16600.00
0005434877061	14631	Economy	16600.00
0005434877073	14631	Economy	16600.00
0005434877134	14631	Economy	16600.00
0005434877055	14631	Economy	16600.00
0005434877137	14631	Economy	16600.00
0005434877075	14631	Economy	16600.00
0005434758865	14631	Economy	16600.00
0005434877066	14631	Economy	16600.00
0005434877058	14631	Economy	16600.00
0005434877094	14631	Economy	16600.00
0005434877063	14631	Economy	16600.00
0005434877130	14631	Economy	16600.00
0005434877076	14631	Economy	16600.00
0005434877041	14631	Economy	16600.00
0005434877121	14631	Economy	16600.00
0005434877129	14631	Economy	16600.00
0005434877133	14631	Economy	16600.00
0005434877131	14631	Economy	16600.00
0005434877057	14631	Economy	16600.00
0005434877107	14631	Economy	16600.00
0005434877096	14631	Economy	16600.00
0005434877106	14631	Economy	16600.00
0005434877127	14631	Economy	16600.00
0005434877090	14631	Economy	16600.00
0005435659996	9237	Economy	22400.00
0005435660000	9237	Economy	20300.00
0005435659998	9237	Economy	20300.00
0005435660002	9237	Economy	20300.00
0005435659995	9237	Economy	20300.00
0005435660003	9237	Economy	20300.00
0005435659997	9237	Economy	20300.00
0005435660005	9237	Economy	20300.00
0005435659994	9237	Economy	20300.00
0005435659999	9237	Economy	20300.00
0005435660004	9237	Economy	20300.00
0005435660001	9237	Economy	20300.00
0005434251844	24674	Economy	20300.00
0005434251850	24674	Economy	20300.00
0005434251845	24674	Economy	20300.00
0005434251851	24674	Economy	20300.00
0005434251847	24674	Economy	20300.00
0005434251853	24674	Economy	20300.00
0005434251846	24674	Economy	20300.00
0005434251854	24674	Economy	20300.00
0005434251852	24674	Economy	20300.00
0005434251848	24674	Economy	20300.00
0005434251849	24674	Economy	20300.00
0005433679994	2797	Business	33000.00
0005433679962	2797	Business	33000.00
0005433679993	2797	Business	33000.00
0005432222718	2797	Business	33000.00
0005433679968	2797	Business	33000.00
0005433679978	2797	Business	33000.00
0005432966503	2797	Business	33000.00
0005433679990	2797	Economy	11000.00
0005433679973	2797	Economy	11000.00
0005433680001	2797	Economy	11000.00
0005433679985	2797	Economy	11000.00
0005433684393	2797	Economy	11000.00
0005432222716	2797	Economy	12100.00
0005433679971	2797	Economy	12100.00
0005433679963	2797	Economy	11000.00
0005433679981	2797	Economy	11000.00
0005433679970	2797	Economy	11000.00
0005433679988	2797	Economy	11000.00
0005433679977	2797	Economy	11000.00
0005433679967	2797	Economy	11000.00
0005432966504	2797	Economy	11000.00
0005433679983	2797	Economy	11000.00
0005433679965	2797	Economy	11000.00
0005433679995	2797	Economy	11000.00
0005433679991	2797	Economy	11000.00
0005432222719	2797	Economy	11000.00
0005433679986	2797	Economy	11000.00
0005433679996	2797	Economy	11000.00
0005433679982	2797	Economy	11000.00
0005433679956	2797	Economy	11000.00
0005433679955	2797	Economy	11000.00
0005433679961	2797	Economy	11000.00
0005433679999	2797	Economy	11000.00
0005433679984	2797	Economy	11000.00
0005433679979	2797	Economy	11000.00
0005432222715	2797	Economy	11000.00
0005433679992	2797	Economy	11000.00
0005433679998	2797	Economy	11000.00
0005432222714	2797	Economy	11000.00
0005432966494	2797	Economy	11000.00
0005433679980	2797	Economy	11000.00
0005433680002	2797	Economy	11000.00
0005433679957	2797	Economy	11000.00
0005433679958	2797	Economy	11000.00
0005432222717	2797	Economy	11000.00
0005433679997	2797	Economy	11000.00
0005433679972	2797	Economy	11000.00
0005433679960	2797	Economy	11000.00
0005433679976	2797	Economy	11000.00
0005433679987	2797	Economy	11000.00
0005433679975	2797	Economy	11000.00
0005433679959	2797	Economy	11000.00
0005433679966	2797	Economy	11000.00
0005433684394	2797	Economy	11000.00
0005433679964	2797	Economy	11000.00
0005433679989	2797	Economy	11000.00
0005433680000	2797	Economy	11000.00
0005433679969	2797	Economy	11000.00
0005433679954	2797	Economy	11000.00
0005433679974	2797	Economy	11000.00
0005432966610	29158	Business	33000.00
0005433679753	29158	Business	33000.00
0005432966618	29158	Business	33000.00
0005433679780	29158	Business	33000.00
0005432966628	29158	Economy	11000.00
0005432966617	29158	Economy	11000.00
0005432966621	29158	Economy	11000.00
0005432966627	29158	Economy	11000.00
0005432966615	29158	Economy	11000.00
0005432966613	29158	Economy	11000.00
0005432966635	29158	Economy	11000.00
0005432966634	29158	Economy	11000.00
0005433690890	29158	Economy	11000.00
0005432966616	29158	Economy	11000.00
0005432966624	29158	Economy	11000.00
0005432966620	29158	Economy	11000.00
0005433679828	29158	Economy	11000.00
0005432966611	29158	Economy	11000.00
0005432966612	29158	Economy	11000.00
0005432966625	29158	Economy	11000.00
0005432966622	29158	Economy	11000.00
0005433679748	29158	Economy	11000.00
0005432966623	29158	Economy	11000.00
0005432966629	29158	Economy	11000.00
0005433679725	29158	Economy	11000.00
0005432966626	29158	Economy	11000.00
0005432966619	29158	Economy	11000.00
0005432966631	29158	Economy	11000.00
0005432005178	29158	Economy	11000.00
0005432005179	29158	Economy	11000.00
0005432966633	29158	Economy	11000.00
0005432966632	29158	Economy	11000.00
0005432966630	29158	Economy	11000.00
0005433690893	29158	Economy	11000.00
0005433679781	29158	Economy	11000.00
0005433679752	29158	Economy	11000.00
0005432966614	29158	Economy	11000.00
0005433613745	9284	Business	132900.00
0005433633381	9284	Business	132900.00
0005433577640	9284	Business	132900.00
0005433633385	9284	Business	132900.00
0005433613739	9284	Business	132900.00
0005433613754	9284	Business	132900.00
0005433613729	9284	Business	132900.00
0005432756807	9284	Business	132900.00
0005433613738	9284	Business	132900.00
0005433613720	9284	Business	132900.00
0005433613712	9284	Business	132900.00
0005433577641	9284	Business	132900.00
0005433613719	9284	Business	132900.00
0005432145083	9284	Business	132900.00
0005433613707	9284	Business	132900.00
0005433577629	9284	Business	132900.00
0005433613752	9284	Business	132900.00
0005433577632	9284	Business	132900.00
0005432756804	9284	Business	132900.00
0005433633384	9284	Business	132900.00
0005433633376	9284	Business	132900.00
0005433613742	9284	Business	132900.00
0005433613744	9284	Economy	48700.00
0005433613733	9284	Economy	48700.00
0005433577636	9284	Economy	48700.00
0005433613698	9284	Economy	48700.00
0005433613690	9284	Economy	48700.00
0005433633364	9284	Economy	44300.00
0005433633373	9284	Economy	44300.00
0005433613697	9284	Economy	44300.00
0005433577630	9284	Economy	44300.00
0005432755033	9284	Economy	44300.00
0005433613711	9284	Economy	44300.00
0005433613700	9284	Economy	44300.00
0005433613737	9284	Economy	44300.00
0005433633370	9284	Economy	44300.00
0005433613726	9284	Economy	44300.00
0005433633369	9284	Economy	44300.00
0005433613691	9284	Economy	44300.00
0005433633355	9284	Economy	44300.00
0005433613702	9284	Economy	44300.00
0005433613709	9284	Economy	44300.00
0005433577637	9284	Economy	44300.00
0005433633378	9284	Economy	44300.00
0005433633366	9284	Economy	44300.00
0005433613708	9284	Economy	44300.00
0005433613757	9284	Economy	44300.00
0005433613688	9284	Economy	44300.00
0005433613693	9284	Economy	44300.00
0005433577638	9284	Economy	44300.00
0005433613740	9284	Economy	44300.00
0005433613689	9284	Economy	44300.00
0005433633368	9284	Economy	44300.00
0005433613750	9284	Economy	44300.00
0005433633379	9284	Economy	44300.00
0005433633359	9284	Economy	44300.00
0005433613714	9284	Economy	44300.00
0005433577642	9284	Economy	44300.00
0005433613704	9284	Economy	44300.00
0005433577635	9284	Economy	44300.00
0005433577639	9284	Economy	44300.00
0005433613713	9284	Economy	44300.00
0005432755032	9284	Economy	44300.00
0005433613760	9284	Economy	44300.00
0005433633367	9284	Economy	44300.00
0005433633362	9284	Economy	44300.00
0005433633374	9284	Economy	44300.00
0005433613694	9284	Economy	44300.00
0005433613736	9284	Economy	44300.00
0005433577631	9284	Economy	44300.00
0005433633358	9284	Economy	44300.00
0005433613721	9284	Economy	44300.00
0005433613743	9284	Economy	48700.00
0005433613749	9284	Economy	48700.00
0005433633371	9284	Economy	48700.00
0005433577634	9284	Economy	48700.00
0005433613718	9284	Economy	44300.00
0005433613756	9284	Economy	44300.00
0005433613723	9284	Economy	44300.00
0005432756806	9284	Economy	48700.00
0005433613725	9284	Economy	44300.00
0005433633383	9284	Economy	44300.00
0005433613717	9284	Economy	44300.00
0005433613710	9284	Economy	44300.00
0005432145085	9284	Economy	44300.00
0005433613695	9284	Economy	44300.00
0005433613755	9284	Economy	44300.00
0005433613727	9284	Economy	44300.00
0005433633363	9284	Economy	44300.00
0005432756805	9284	Economy	44300.00
0005433613747	9284	Economy	44300.00
0005433613759	9284	Economy	44300.00
0005432145084	9284	Economy	44300.00
0005433613741	9284	Economy	44300.00
0005433613751	9284	Economy	44300.00
0005433577633	9284	Economy	44300.00
0005433613703	9284	Economy	44300.00
0005433613746	9284	Economy	44300.00
0005433613748	9284	Economy	44300.00
0005433633372	9284	Economy	44300.00
0005433613735	9284	Economy	44300.00
0005433613722	9284	Economy	44300.00
0005433613732	9284	Economy	44300.00
0005433633365	9284	Economy	44300.00
0005433613706	9284	Economy	44300.00
0005433613730	9284	Economy	44300.00
0005433613699	9284	Economy	44300.00
0005433633361	9284	Economy	44300.00
0005433613734	9284	Economy	44300.00
0005433633356	9284	Economy	44300.00
0005433613728	9284	Economy	44300.00
0005433633375	9284	Economy	44300.00
0005433633387	9284	Economy	44300.00
0005433613687	9284	Economy	44300.00
0005433613701	9284	Economy	44300.00
0005433633386	9284	Economy	44300.00
0005433613705	9284	Economy	44300.00
0005433613724	9284	Economy	44300.00
0005433613716	9284	Economy	44300.00
0005433633357	9284	Economy	44300.00
0005433613696	9284	Economy	44300.00
0005433613731	9284	Economy	44300.00
0005433633382	9284	Economy	44300.00
0005433613753	9284	Economy	44300.00
0005433633377	9284	Economy	44300.00
0005432755034	9284	Economy	44300.00
0005433613692	9284	Economy	44300.00
0005433613758	9284	Economy	44300.00
0005433633360	9284	Economy	44300.00
0005433633380	9284	Economy	44300.00
0005433613715	9284	Economy	44300.00
0005434163504	25265	Business	132900.00
0005434273055	25265	Business	132900.00
0005434163510	25265	Economy	44300.00
0005434163509	25265	Economy	44300.00
0005433613471	25265	Economy	44300.00
0005434163511	25265	Economy	44300.00
0005434163508	25265	Economy	44300.00
0005433613610	25265	Economy	44300.00
0005434272169	25265	Economy	44300.00
0005434163512	25265	Economy	44300.00
0005434163505	25265	Economy	44300.00
0005434273056	25265	Economy	44300.00
0005434163507	25265	Economy	48700.00
0005433633216	25265	Economy	44300.00
0005434272171	25265	Economy	44300.00
0005433633217	25265	Economy	44300.00
0005434272170	25265	Economy	44300.00
0005434163513	25265	Economy	44300.00
0005433577610	25265	Economy	44300.00
0005434163503	25265	Economy	44300.00
0005434163506	25265	Economy	44300.00
0005432184915	4201	Business	193100.00
0005435986680	4201	Business	193100.00
0005432184914	4201	Business	193100.00
0005435986682	4201	Economy	64400.00
0005435986681	4201	Economy	64400.00
0005432184916	4201	Economy	64400.00
0005435856152	26613	Business	193100.00
0005435947071	26613	Business	193100.00
0005435947083	26613	Business	193100.00
0005435947074	26613	Business	193100.00
0005435947076	26613	Economy	70800.00
0005435947072	26613	Economy	64400.00
0005435787329	26613	Economy	64400.00
0005432571279	26613	Economy	64400.00
0005435787328	26613	Economy	64400.00
0005435947079	26613	Economy	64400.00
0005435947077	26613	Economy	64400.00
0005432571278	26613	Economy	64400.00
0005435947078	26613	Economy	64400.00
0005435856151	26613	Economy	64400.00
0005435947075	26613	Economy	64400.00
0005435947084	26613	Economy	64400.00
0005435947080	26613	Economy	64400.00
0005435947085	26613	Economy	64400.00
0005435856154	26613	Economy	64400.00
0005435947073	26613	Economy	64400.00
0005435947082	26613	Economy	64400.00
0005435856153	26613	Economy	64400.00
0005432571277	26613	Economy	64400.00
0005432571276	26613	Economy	64400.00
0005435947081	26613	Economy	64400.00
0005432238861	340	Business	21500.00
0005432947787	340	Business	21500.00
0005433568338	340	Business	21500.00
0005432238860	340	Business	21500.00
0005433568336	340	Business	21500.00
0005433568343	340	Business	21500.00
0005432947772	340	Business	21500.00
0005433568325	340	Business	21500.00
0005433568322	340	Business	21500.00
0005433568313	340	Business	21500.00
0005433568346	340	Business	21500.00
0005433568314	340	Business	21500.00
0005433568359	340	Economy	7900.00
0005433568323	340	Economy	7900.00
0005432238858	340	Economy	7200.00
0005433568320	340	Economy	7200.00
0005433568329	340	Economy	7200.00
0005433568363	340	Economy	7200.00
0005433074206	340	Economy	7200.00
0005433568315	340	Economy	7200.00
0005433568321	340	Economy	7200.00
0005433568341	340	Economy	7200.00
0005433568332	340	Economy	7200.00
0005433568352	340	Economy	7200.00
0005433568365	340	Economy	7200.00
0005433568347	340	Economy	7200.00
0005433568344	340	Economy	7200.00
0005433568364	340	Economy	7200.00
0005433568311	340	Economy	7200.00
0005433568372	340	Economy	7200.00
0005433568349	340	Economy	7200.00
0005433568345	340	Economy	7200.00
0005433568351	340	Economy	7200.00
0005433568317	340	Economy	7200.00
0005433568335	340	Economy	7200.00
0005433568361	340	Economy	7200.00
0005433568355	340	Economy	7200.00
0005433568367	340	Economy	7200.00
0005433568368	340	Economy	7200.00
0005433568369	340	Economy	7200.00
0005433568339	340	Economy	7200.00
0005433568370	340	Economy	7200.00
0005433568327	340	Economy	7200.00
0005433568326	340	Economy	7900.00
0005432238859	340	Economy	7900.00
0005433568316	340	Economy	7200.00
0005433568371	340	Economy	7200.00
0005433568357	340	Economy	7200.00
0005433568310	340	Economy	7200.00
0005433568312	340	Economy	7200.00
0005433568362	340	Economy	7200.00
0005433568353	340	Economy	7200.00
0005432947786	340	Economy	7200.00
0005433568319	340	Economy	7200.00
0005433568358	340	Economy	7200.00
0005433568308	340	Economy	7200.00
0005433568354	340	Economy	7200.00
0005433568366	340	Economy	7200.00
0005433568333	340	Economy	7200.00
0005433568337	340	Economy	7200.00
0005433074207	340	Economy	7200.00
0005433568350	340	Economy	7200.00
0005433568328	340	Economy	7200.00
0005433568330	340	Economy	7200.00
0005433568360	340	Economy	7200.00
0005433568356	340	Economy	7200.00
0005433568324	340	Economy	7200.00
0005433568348	340	Economy	7200.00
0005433568373	340	Economy	7200.00
0005433568318	340	Economy	7200.00
0005433568342	340	Economy	7200.00
0005433568309	340	Economy	7200.00
0005433568334	340	Economy	7200.00
0005433568331	340	Economy	7200.00
0005432238863	340	Economy	7200.00
0005433568340	340	Economy	7200.00
0005432238862	340	Economy	7200.00
0005433134081	11594	Business	21500.00
0005432947938	11594	Business	21500.00
0005433074354	11594	Business	21500.00
0005433074364	11594	Business	21500.00
0005433134079	11594	Business	21500.00
0005432947955	11594	Business	21500.00
0005432947965	11594	Business	21500.00
0005433131653	11594	Business	21500.00
0005432947936	11594	Business	21500.00
0005433074356	11594	Business	21500.00
0005432947963	11594	Business	21500.00
0005433074349	11594	Business	21500.00
0005433134080	11594	Business	21500.00
0005432192282	11594	Business	21500.00
0005433074361	11594	Business	21500.00
0005433074362	11594	Business	21500.00
0005432947931	11594	Economy	7900.00
0005432947940	11594	Economy	7900.00
0005433074369	11594	Economy	7900.00
0005432947966	11594	Economy	7900.00
0005432947962	11594	Economy	7900.00
0005432947951	11594	Economy	7200.00
0005432947970	11594	Economy	7200.00
0005432947953	11594	Economy	7200.00
0005432947948	11594	Economy	7200.00
0005432947954	11594	Economy	7200.00
0005432947967	11594	Economy	7200.00
0005432947971	11594	Economy	7200.00
0005432192280	11594	Economy	7200.00
0005433074360	11594	Economy	7200.00
0005433074365	11594	Economy	7200.00
0005432947957	11594	Economy	7200.00
0005433074363	11594	Economy	7200.00
0005433074343	11594	Economy	7200.00
0005433074367	11594	Economy	7200.00
0005432947945	11594	Economy	7200.00
0005432947964	11594	Economy	7200.00
0005432947949	11594	Economy	7200.00
0005433074342	11594	Economy	7200.00
0005433074357	11594	Economy	7200.00
0005432947937	11594	Economy	7200.00
0005432947950	11594	Economy	7200.00
0005432947944	11594	Economy	7200.00
0005432947960	11594	Economy	7200.00
0005432947935	11594	Economy	7200.00
0005432947946	11594	Economy	7200.00
0005432947932	11594	Economy	7200.00
0005433074358	11594	Economy	7200.00
0005432947956	11594	Economy	7200.00
0005433074350	11594	Economy	7900.00
0005433134083	11594	Economy	7900.00
0005432947939	11594	Economy	7200.00
0005433131651	11594	Economy	7200.00
0005432947959	11594	Economy	7200.00
0005433074344	11594	Economy	7200.00
0005433074352	11594	Economy	7200.00
0005433131650	11594	Economy	7200.00
0005433074366	11594	Economy	7200.00
0005432947930	11594	Economy	7200.00
0005432947933	11594	Economy	7200.00
0005433131652	11594	Economy	7200.00
0005432947961	11594	Economy	7200.00
0005432947958	11594	Economy	7200.00
0005432947952	11594	Economy	7200.00
0005433074347	11594	Economy	7200.00
0005432947934	11594	Economy	7200.00
0005432947968	11594	Economy	7200.00
0005432947969	11594	Economy	7200.00
0005433074353	11594	Economy	7200.00
0005433074370	11594	Economy	7200.00
0005432947947	11594	Economy	7200.00
0005432947941	11594	Economy	7200.00
0005432947943	11594	Economy	7200.00
0005432192281	11594	Economy	7200.00
0005433074346	11594	Economy	7200.00
0005433074345	11594	Economy	7200.00
0005433074351	11594	Economy	7200.00
0005433074348	11594	Economy	7200.00
0005432947942	11594	Economy	7200.00
0005433134082	11594	Economy	7200.00
0005433074355	11594	Economy	7200.00
0005433074368	11594	Economy	7200.00
0005433074359	11594	Economy	7200.00
0005433131649	11594	Economy	7200.00
0005433817426	10011	Economy	6300.00
0005433817423	10011	Economy	6300.00
0005433817425	10011	Economy	6300.00
0005433817424	10011	Economy	6300.00
0005434732937	13911	Economy	6300.00
0005434732938	13911	Economy	6300.00
0005434732939	13911	Economy	6300.00
0005434732936	13911	Economy	6300.00
0005435981785	2335	Business	184500.00
0005433753525	2335	Business	184500.00
0005435981764	2335	Business	184500.00
0005433753510	2335	Business	184500.00
0005435981766	2335	Business	184500.00
0005435981763	2335	Business	184500.00
0005433753535	2335	Business	184500.00
0005435981745	2335	Business	184500.00
0005435981753	2335	Business	184500.00
0005435981737	2335	Business	184500.00
0005432300192	2335	Business	184500.00
0005432655394	2335	Business	184500.00
0005432300195	2335	Business	184500.00
0005435981776	2335	Business	184500.00
0005435981768	2335	Business	184500.00
0005433753563	2335	Business	184500.00
0005435981742	2335	Business	184500.00
0005435981772	2335	Business	184500.00
0005435981771	2335	Economy	67700.00
0005435981748	2335	Economy	67700.00
0005432225979	2335	Economy	67700.00
0005432655398	2335	Economy	61500.00
0005435981773	2335	Economy	61500.00
0005433753514	2335	Economy	61500.00
0005432655391	2335	Economy	61500.00
0005435981746	2335	Economy	61500.00
0005433753554	2335	Economy	61500.00
0005435981765	2335	Economy	61500.00
0005435981750	2335	Economy	61500.00
0005432225980	2335	Economy	61500.00
0005433753537	2335	Economy	61500.00
0005435981777	2335	Economy	61500.00
0005433753530	2335	Economy	61500.00
0005435981781	2335	Economy	61500.00
0005433753567	2335	Economy	61500.00
0005433764654	2335	Economy	61500.00
0005433753558	2335	Economy	61500.00
0005435981759	2335	Economy	61500.00
0005433753522	2335	Economy	61500.00
0005433766594	2335	Economy	61500.00
0005435981761	2335	Economy	61500.00
0005432655388	2335	Economy	61500.00
0005433753513	2335	Economy	61500.00
0005433753550	2335	Economy	61500.00
0005433753560	2335	Economy	61500.00
0005435981769	2335	Economy	61500.00
0005432655389	2335	Economy	61500.00
0005432225982	2335	Economy	61500.00
0005435981738	2335	Economy	61500.00
0005433753526	2335	Economy	61500.00
0005433753520	2335	Economy	61500.00
0005435981767	2335	Economy	61500.00
0005433753545	2335	Economy	61500.00
0005432655397	2335	Economy	61500.00
0005433753561	2335	Economy	61500.00
0005433753528	2335	Economy	61500.00
0005433753515	2335	Economy	61500.00
0005433766593	2335	Economy	61500.00
0005432655399	2335	Economy	61500.00
0005433753556	2335	Economy	61500.00
0005432655395	2335	Economy	61500.00
0005432300194	2335	Economy	61500.00
0005435981751	2335	Economy	61500.00
0005435981735	2335	Economy	61500.00
0005435981749	2335	Economy	61500.00
0005433434182	2335	Economy	61500.00
0005433753534	2335	Economy	61500.00
0005433753541	2335	Economy	61500.00
0005432655393	2335	Economy	61500.00
0005433753519	2335	Economy	61500.00
0005433753524	2335	Economy	61500.00
0005435981754	2335	Economy	61500.00
0005433753548	2335	Economy	61500.00
0005435981743	2335	Economy	61500.00
0005435981756	2335	Economy	61500.00
0005433434221	2335	Economy	61500.00
0005433753565	2335	Economy	61500.00
0005435981787	2335	Economy	61500.00
0005433753518	2335	Economy	61500.00
0005433753549	2335	Economy	61500.00
0005433753529	2335	Economy	61500.00
0005433753539	2335	Economy	61500.00
0005432655387	2335	Economy	61500.00
0005435981788	2335	Economy	61500.00
0005435981755	2335	Economy	61500.00
0005433753511	2335	Economy	67700.00
0005435981760	2335	Economy	61500.00
0005433753553	2335	Economy	61500.00
0005433753516	2335	Economy	67700.00
0005432225978	2335	Economy	61500.00
0005433434197	2335	Economy	61500.00
0005435981736	2335	Economy	61500.00
0005435981786	2335	Economy	61500.00
0005435981762	2335	Economy	61500.00
0005433753562	2335	Economy	61500.00
0005433753533	2335	Economy	61500.00
0005433753536	2335	Economy	61500.00
0005433753521	2335	Economy	61500.00
0005433753543	2335	Economy	61500.00
0005433753542	2335	Economy	61500.00
0005433753540	2335	Economy	61500.00
0005435981782	2335	Economy	61500.00
0005435981757	2335	Economy	61500.00
0005432225981	2335	Economy	61500.00
0005433753551	2335	Economy	61500.00
0005433434183	2335	Economy	61500.00
0005435981783	2335	Economy	61500.00
0005433753566	2335	Economy	61500.00
0005432984545	2335	Economy	61500.00
0005433753559	2335	Economy	61500.00
0005433753517	2335	Economy	61500.00
0005432655396	2335	Economy	61500.00
0005433753544	2335	Economy	61500.00
0005432300193	2335	Economy	61500.00
0005435981752	2335	Economy	61500.00
0005433753555	2335	Economy	61500.00
0005435981778	2335	Economy	61500.00
0005435981774	2335	Economy	61500.00
0005435981758	2335	Economy	61500.00
0005433753523	2335	Economy	61500.00
0005433753564	2335	Economy	61500.00
0005435981740	2335	Economy	61500.00
0005432984546	2335	Economy	61500.00
0005435981780	2335	Economy	61500.00
0005433753552	2335	Economy	61500.00
0005432225983	2335	Economy	61500.00
0005435981784	2335	Economy	61500.00
0005432655390	2335	Economy	61500.00
0005435981739	2335	Economy	61500.00
0005433753531	2335	Economy	61500.00
0005433434198	2335	Economy	61500.00
0005433753538	2335	Economy	61500.00
0005435981744	2335	Economy	61500.00
0005435981747	2335	Economy	61500.00
0005433753527	2335	Economy	61500.00
0005432655392	2335	Economy	61500.00
0005433753547	2335	Economy	61500.00
0005435981779	2335	Economy	61500.00
0005435981775	2335	Economy	61500.00
0005433753532	2335	Economy	61500.00
0005433753546	2335	Economy	61500.00
0005435981741	2335	Economy	61500.00
0005435981770	2335	Economy	61500.00
0005433753512	2335	Economy	61500.00
0005433753557	2335	Economy	61500.00
0005434731120	26203	Business	184500.00
0005432984698	26203	Business	184500.00
0005433434348	26203	Business	184500.00
0005433434337	26203	Business	184500.00
0005434731118	26203	Business	184500.00
0005432984679	26203	Business	184500.00
0005432984691	26203	Business	184500.00
0005432984674	26203	Business	184500.00
0005432984670	26203	Business	184500.00
0005433434341	26203	Business	184500.00
0005432984695	26203	Economy	67700.00
0005433434332	26203	Economy	67700.00
0005432984668	26203	Economy	61500.00
0005432869445	26203	Economy	61500.00
0005432049420	26203	Economy	61500.00
0005432984676	26203	Economy	61500.00
0005432869442	26203	Economy	61500.00
0005434731117	26203	Economy	61500.00
0005433434325	26203	Economy	61500.00
0005432984678	26203	Economy	61500.00
0005432869444	26203	Economy	61500.00
0005433434327	26203	Economy	61500.00
0005434731119	26203	Economy	61500.00
0005432984692	26203	Economy	61500.00
0005432051089	26203	Economy	61500.00
0005432984673	26203	Economy	61500.00
0005433434335	26203	Economy	61500.00
0005433434351	26203	Economy	61500.00
0005433434343	26203	Economy	61500.00
0005432049419	26203	Economy	61500.00
0005432869438	26203	Economy	61500.00
0005432984688	26203	Economy	61500.00
0005432984696	26203	Economy	61500.00
0005433434347	26203	Economy	61500.00
0005432984677	26203	Economy	61500.00
0005434731121	26203	Economy	61500.00
0005433434350	26203	Economy	61500.00
0005433434345	26203	Economy	61500.00
0005433434328	26203	Economy	61500.00
0005433434340	26203	Economy	61500.00
0005433434326	26203	Economy	61500.00
0005432984694	26203	Economy	61500.00
0005432984690	26203	Economy	61500.00
0005432984675	26203	Economy	61500.00
0005433434331	26203	Economy	61500.00
0005432984686	26203	Economy	61500.00
0005432984693	26203	Economy	61500.00
0005433434330	26203	Economy	61500.00
0005432869439	26203	Economy	61500.00
0005432984672	26203	Economy	61500.00
0005432984669	26203	Economy	67700.00
0005432984671	26203	Economy	61500.00
0005432051090	26203	Economy	61500.00
0005432051091	26203	Economy	61500.00
0005433434338	26203	Economy	61500.00
0005432049421	26203	Economy	61500.00
0005432984697	26203	Economy	61500.00
0005432984680	26203	Economy	61500.00
0005432984681	26203	Economy	61500.00
0005433434346	26203	Economy	61500.00
0005433434352	26203	Economy	61500.00
0005432984667	26203	Economy	61500.00
0005433434344	26203	Economy	61500.00
0005432049418	26203	Economy	61500.00
0005433434342	26203	Economy	61500.00
0005432869443	26203	Economy	61500.00
0005433434349	26203	Economy	61500.00
0005433434334	26203	Economy	61500.00
0005432984683	26203	Economy	61500.00
0005433764644	26203	Economy	61500.00
0005433434353	26203	Economy	61500.00
0005432984682	26203	Economy	61500.00
0005433753238	26203	Economy	61500.00
0005433434339	26203	Economy	61500.00
0005433434336	26203	Economy	61500.00
0005432869440	26203	Economy	61500.00
0005432984687	26203	Economy	61500.00
0005432984685	26203	Economy	61500.00
0005432984684	26203	Economy	61500.00
0005433434329	26203	Economy	61500.00
0005432984689	26203	Economy	61500.00
0005433434333	26203	Economy	61500.00
0005432869441	26203	Economy	61500.00
0005434374118	1499	Business	38900.00
0005432267811	1499	Business	38900.00
0005434374095	1499	Business	38900.00
0005433150831	1499	Business	38900.00
0005434374086	1499	Business	38900.00
0005434374123	1499	Business	38900.00
0005434374106	1499	Business	38900.00
0005434374117	1499	Business	38900.00
0005433460410	1499	Economy	13000.00
0005434374085	1499	Economy	13000.00
0005434374102	1499	Economy	13000.00
0005434374122	1499	Economy	13000.00
0005434374111	1499	Economy	13000.00
0005433460409	1499	Economy	13000.00
0005433150795	1499	Economy	13000.00
0005434374107	1499	Economy	13000.00
0005432267816	1499	Economy	13000.00
0005434374098	1499	Economy	13000.00
0005434374092	1499	Economy	13000.00
0005434374082	1499	Economy	13000.00
0005434374099	1499	Economy	13000.00
0005434374110	1499	Economy	13000.00
0005434374112	1499	Economy	13000.00
0005434374093	1499	Economy	13000.00
0005432267813	1499	Economy	14300.00
0005434374121	1499	Economy	14300.00
0005434374088	1499	Economy	14300.00
0005432267815	1499	Economy	13000.00
0005432267812	1499	Economy	13000.00
0005434374105	1499	Economy	13000.00
0005434374091	1499	Economy	13000.00
0005434374104	1499	Economy	13000.00
0005434374115	1499	Economy	13000.00
0005434374097	1499	Economy	13000.00
0005434374109	1499	Economy	13000.00
0005434374108	1499	Economy	13000.00
0005434374103	1499	Economy	13000.00
0005433150796	1499	Economy	13000.00
0005433461562	1499	Economy	13000.00
0005434374083	1499	Economy	13000.00
0005434374094	1499	Economy	13000.00
0005434374084	1499	Economy	13000.00
0005434374119	1499	Economy	13000.00
0005434374114	1499	Economy	13000.00
0005433150939	1499	Economy	13000.00
0005434374089	1499	Economy	13000.00
0005433150936	1499	Economy	13000.00
0005434374100	1499	Economy	13000.00
0005434374120	1499	Economy	13000.00
0005434374116	1499	Economy	13000.00
0005433150937	1499	Economy	13000.00
0005433150938	1499	Economy	13000.00
0005434374113	1499	Economy	13000.00
0005432267814	1499	Economy	13000.00
0005434374096	1499	Economy	13000.00
0005433461561	1499	Economy	13000.00
0005434374087	1499	Economy	13000.00
0005434374090	1499	Economy	13000.00
0005432267810	1499	Economy	13000.00
0005434374101	1499	Economy	13000.00
0005433151002	20153	Business	38900.00
0005433151004	20153	Business	38900.00
0005433150985	20153	Business	38900.00
0005434029626	20153	Business	38900.00
0005433150973	20153	Business	38900.00
0005433150992	20153	Economy	13000.00
0005433150994	20153	Economy	13000.00
0005433150996	20153	Economy	13000.00
0005433150987	20153	Economy	13000.00
0005433150975	20153	Economy	13000.00
0005433151001	20153	Economy	13000.00
0005433150978	20153	Economy	13000.00
0005433150989	20153	Economy	13000.00
0005433151000	20153	Economy	13000.00
0005433150972	20153	Economy	13000.00
0005433150990	20153	Economy	13000.00
0005433150981	20153	Economy	13000.00
0005433931427	20153	Economy	13000.00
0005433931429	20153	Economy	13000.00
0005433151003	20153	Economy	13000.00
0005433150997	20153	Economy	14300.00
0005433150970	20153	Economy	14300.00
0005433150971	20153	Economy	13000.00
0005433150976	20153	Economy	13000.00
0005433150986	20153	Economy	13000.00
0005433150982	20153	Economy	13000.00
0005433150999	20153	Economy	13000.00
0005433150980	20153	Economy	13000.00
0005433764654	20153	Economy	13000.00
0005433150979	20153	Economy	13000.00
0005433150993	20153	Economy	13000.00
0005432056253	20153	Economy	13000.00
0005433931428	20153	Economy	13000.00
0005432056251	20153	Economy	13000.00
0005433150995	20153	Economy	13000.00
0005433150977	20153	Economy	13000.00
0005433150974	20153	Economy	13000.00
0005433150991	20153	Economy	13000.00
0005433150998	20153	Economy	13000.00
0005433150984	20153	Economy	13000.00
0005432056252	20153	Economy	13000.00
0005433150988	20153	Economy	13000.00
0005433150983	20153	Economy	13000.00
0005432282780	588	Business	27500.00
0005432423874	588	Business	27500.00
0005432423899	588	Business	27500.00
0005432282781	588	Business	27500.00
0005432423901	588	Business	27500.00
0005432423868	588	Business	27500.00
0005432423862	588	Business	27500.00
0005432423867	588	Business	27500.00
0005432423907	588	Business	27500.00
0005432423893	588	Business	27500.00
0005432423891	588	Business	27500.00
0005432423896	588	Business	27500.00
0005432423895	588	Business	27500.00
0005432423872	588	Economy	10100.00
0005432282776	588	Economy	10100.00
0005432282775	588	Economy	10100.00
0005432423883	588	Economy	9200.00
0005432423860	588	Economy	9200.00
0005432282774	588	Economy	9200.00
0005432423870	588	Economy	9200.00
0005432423894	588	Economy	9200.00
0005432282779	588	Economy	9200.00
0005432282777	588	Economy	9200.00
0005432423881	588	Economy	9200.00
0005432423869	588	Economy	9200.00
0005432423904	588	Economy	9200.00
0005432423873	588	Economy	9200.00
0005432423871	588	Economy	9200.00
0005432423884	588	Economy	9200.00
0005432423902	588	Economy	9200.00
0005432423890	588	Economy	9200.00
0005432423876	588	Economy	9200.00
0005432423900	588	Economy	9200.00
0005432423889	588	Economy	9200.00
0005432423861	588	Economy	9200.00
0005432423879	588	Economy	9200.00
0005432423882	588	Economy	9200.00
0005432423880	588	Economy	9200.00
0005432423903	588	Economy	9200.00
0005432423877	588	Economy	9200.00
0005432423875	588	Economy	9200.00
0005432423898	588	Economy	9200.00
0005432282778	588	Economy	9200.00
0005432423909	588	Economy	9200.00
0005432423878	588	Economy	9200.00
0005432423863	588	Economy	9200.00
0005432423908	588	Economy	9200.00
0005432423885	588	Economy	9200.00
0005432423866	588	Economy	9200.00
0005432423886	588	Economy	9200.00
0005432423892	588	Economy	9200.00
0005432423905	588	Economy	9200.00
0005432423865	588	Economy	9200.00
0005432423887	588	Economy	9200.00
0005432423897	588	Economy	9200.00
0005432423864	588	Economy	9200.00
0005432423906	588	Economy	9200.00
0005432423888	588	Economy	9200.00
0005432302283	12898	Economy	9200.00
0005432302285	12898	Economy	9200.00
0005432302284	12898	Economy	9200.00
0005432302286	12898	Economy	9200.00
0005433057240	443	Business	24500.00
0005434022916	443	Business	24500.00
0005433057272	443	Business	24500.00
0005434022906	443	Business	24500.00
0005434022861	443	Business	24500.00
0005432045587	443	Business	24500.00
0005434022903	443	Business	24500.00
0005434022889	443	Business	24500.00
0005434022914	443	Business	24500.00
0005434022856	443	Business	24500.00
0005434022865	443	Business	24500.00
0005434022878	443	Business	24500.00
0005432235545	443	Business	24500.00
0005434022862	443	Business	24500.00
0005434022851	443	Business	24500.00
0005434022874	443	Economy	9000.00
0005434022894	443	Economy	9000.00
0005434022888	443	Economy	8200.00
0005434022850	443	Economy	8200.00
0005434022895	443	Economy	8200.00
0005433057189	443	Economy	8200.00
0005434022909	443	Economy	8200.00
0005434022907	443	Economy	8200.00
0005434022910	443	Economy	8200.00
0005434022893	443	Economy	8200.00
0005434029624	443	Economy	8200.00
0005434022882	443	Economy	8200.00
0005434031966	443	Economy	8200.00
0005433057274	443	Economy	8200.00
0005434022905	443	Economy	8200.00
0005433057193	443	Economy	8200.00
0005432235543	443	Economy	8200.00
0005434022867	443	Economy	8200.00
0005434022871	443	Economy	8200.00
0005433057172	443	Economy	8200.00
0005434022908	443	Economy	8200.00
0005434022852	443	Economy	8200.00
0005434022847	443	Economy	8200.00
0005434022900	443	Economy	8200.00
0005434022891	443	Economy	8200.00
0005434031962	443	Economy	8200.00
0005434022877	443	Economy	8200.00
0005433057239	443	Economy	8200.00
0005434022896	443	Economy	8200.00
0005434022858	443	Economy	8200.00
0005434022915	443	Economy	8200.00
0005434022866	443	Economy	8200.00
0005434022884	443	Economy	8200.00
0005434031965	443	Economy	8200.00
0005434022868	443	Economy	8200.00
0005432235546	443	Economy	8200.00
0005432235548	443	Economy	8200.00
0005432235542	443	Economy	8200.00
0005432235547	443	Economy	8200.00
0005432235544	443	Economy	8200.00
0005434022854	443	Economy	8200.00
0005434022887	443	Economy	8200.00
0005434022886	443	Economy	8200.00
0005434022879	443	Economy	8200.00
0005434022864	443	Economy	8200.00
0005434022904	443	Economy	8200.00
0005434029625	443	Economy	8200.00
0005434022860	443	Economy	8200.00
0005434022883	443	Economy	8200.00
0005434022892	443	Economy	9000.00
0005432235549	443	Economy	9000.00
0005434022872	443	Economy	8200.00
0005434022912	443	Economy	8200.00
0005434022902	443	Economy	9000.00
0005434022859	443	Economy	8200.00
0005434022885	443	Economy	8200.00
0005434022911	443	Economy	8200.00
0005434022855	443	Economy	8200.00
0005434022849	443	Economy	8200.00
0005434022876	443	Economy	8200.00
0005434022869	443	Economy	8200.00
0005432045588	443	Economy	8200.00
0005434022901	443	Economy	8200.00
0005434022897	443	Economy	8200.00
0005434022873	443	Economy	8200.00
0005434031963	443	Economy	8200.00
0005434022853	443	Economy	8200.00
0005434022899	443	Economy	8200.00
0005434022890	443	Economy	8200.00
0005433057311	443	Economy	8200.00
0005434022863	443	Economy	8200.00
0005434022913	443	Economy	8200.00
0005434022898	443	Economy	8200.00
0005434022857	443	Economy	8200.00
0005434031964	443	Economy	8200.00
0005434022881	443	Economy	8200.00
0005434022875	443	Economy	8200.00
0005434022870	443	Economy	8200.00
0005434022848	443	Economy	8200.00
0005434022880	443	Economy	8200.00
0005433057273	443	Economy	8200.00
0005433057228	443	Economy	8200.00
0005433057390	12674	Business	24500.00
0005433057378	12674	Business	24500.00
0005434022599	12674	Business	24500.00
0005434022541	12674	Business	24500.00
0005433057407	12674	Business	24500.00
0005433057389	12674	Business	24500.00
0005434022557	12674	Business	24500.00
0005433057380	12674	Business	24500.00
0005433057411	12674	Economy	9000.00
0005433057409	12674	Economy	9000.00
0005433057393	12674	Economy	8200.00
0005433929562	12674	Economy	8200.00
0005433057385	12674	Economy	8200.00
0005434022543	12674	Economy	8200.00
0005433057391	12674	Economy	8200.00
0005432156312	12674	Economy	8200.00
0005433057396	12674	Economy	8200.00
0005433057377	12674	Economy	8200.00
0005434022512	12674	Economy	8200.00
0005433057414	12674	Economy	8200.00
0005433057392	12674	Economy	8200.00
0005433057386	12674	Economy	8200.00
0005433929561	12674	Economy	8200.00
0005434735624	12674	Economy	8200.00
0005433929564	12674	Economy	8200.00
0005433057408	12674	Economy	8200.00
0005434735627	12674	Economy	8200.00
0005433057376	12674	Economy	8200.00
0005433057401	12674	Economy	8200.00
0005433057402	12674	Economy	8200.00
0005433684396	12674	Economy	8200.00
0005432156310	12674	Economy	8200.00
0005433057412	12674	Economy	8200.00
0005433057405	12674	Economy	8200.00
0005434022562	12674	Economy	8200.00
0005433057399	12674	Economy	8200.00
0005433057388	12674	Economy	8200.00
0005433057400	12674	Economy	9000.00
0005433057404	12674	Economy	8200.00
0005433057383	12674	Economy	8200.00
0005434735626	12674	Economy	8200.00
0005433057406	12674	Economy	8200.00
0005433057398	12674	Economy	8200.00
0005432157467	12674	Economy	8200.00
0005433057387	12674	Economy	8200.00
0005433057382	12674	Economy	8200.00
0005434735625	12674	Economy	8200.00
0005433057374	12674	Economy	8200.00
0005433057410	12674	Economy	8200.00
0005433057381	12674	Economy	8200.00
0005433929563	12674	Economy	8200.00
0005432156309	12674	Economy	8200.00
0005434735628	12674	Economy	8200.00
0005433057413	12674	Economy	8200.00
0005432156311	12674	Economy	8200.00
0005433929560	12674	Economy	8200.00
0005434022542	12674	Economy	8200.00
0005433057384	12674	Economy	8200.00
0005433057379	12674	Economy	8200.00
0005433057394	12674	Economy	8200.00
0005433684395	12674	Economy	8200.00
0005433057375	12674	Economy	8200.00
0005433057397	12674	Economy	8200.00
0005433057395	12674	Economy	8200.00
0005432157468	12674	Economy	8200.00
0005433057403	12674	Economy	8200.00
0005433931427	2152	Business	34700.00
0005432044490	2152	Business	34700.00
0005433922122	2152	Business	34700.00
0005433922131	2152	Business	34700.00
0005433922089	2152	Business	34700.00
0005432231432	2152	Business	34700.00
0005433931429	2152	Business	34700.00
0005433922090	2152	Business	34700.00
0005433922128	2152	Business	34700.00
0005433922139	2152	Business	34700.00
0005433922161	2152	Business	34700.00
0005433922123	2152	Business	34700.00
0005433922100	2152	Business	34700.00
0005433929560	2152	Business	34700.00
0005433922173	2152	Business	34700.00
0005433922103	2152	Business	34700.00
0005433929563	2152	Business	34700.00
0005433922127	2152	Business	34700.00
0005432231428	2152	Business	34700.00
0005432231429	2152	Business	34700.00
0005433922104	2152	Economy	12700.00
0005433922106	2152	Economy	12700.00
0005433922094	2152	Economy	12700.00
0005433922109	2152	Economy	11600.00
0005432231433	2152	Economy	11600.00
0005433922078	2152	Economy	11600.00
0005432231438	2152	Economy	11600.00
0005433922165	2152	Economy	11600.00
0005433922087	2152	Economy	11600.00
0005433922137	2152	Economy	11600.00
0005433922149	2152	Economy	11600.00
0005433922156	2152	Economy	11600.00
0005433922143	2152	Economy	11600.00
0005433922124	2152	Economy	11600.00
0005433922092	2152	Economy	11600.00
0005433922119	2152	Economy	11600.00
0005433922151	2152	Economy	11600.00
0005433922133	2152	Economy	11600.00
0005433922157	2152	Economy	11600.00
0005433922110	2152	Economy	11600.00
0005433922112	2152	Economy	11600.00
0005433922146	2152	Economy	11600.00
0005433922121	2152	Economy	11600.00
0005433922099	2152	Economy	11600.00
0005433929564	2152	Economy	11600.00
0005432231436	2152	Economy	11600.00
0005433922107	2152	Economy	11600.00
0005433922120	2152	Economy	11600.00
0005433922115	2152	Economy	11600.00
0005433922091	2152	Economy	11600.00
0005433922111	2152	Economy	11600.00
0005433922079	2152	Economy	11600.00
0005433922152	2152	Economy	11600.00
0005432231431	2152	Economy	11600.00
0005433922175	2152	Economy	11600.00
0005433922145	2152	Economy	11600.00
0005433922093	2152	Economy	11600.00
0005433922166	2152	Economy	11600.00
0005433922132	2152	Economy	11600.00
0005433922118	2152	Economy	11600.00
0005433931428	2152	Economy	11600.00
0005433922114	2152	Economy	11600.00
0005433922097	2152	Economy	11600.00
0005433922171	2152	Economy	11600.00
0005433875358	2152	Economy	11600.00
0005433922154	2152	Economy	11600.00
0005433922155	2152	Economy	11600.00
0005433922105	2152	Economy	11600.00
0005432044489	2152	Economy	11600.00
0005433922096	2152	Economy	11600.00
0005433922102	2152	Economy	11600.00
0005432231437	2152	Economy	11600.00
0005433922113	2152	Economy	11600.00
0005433922081	2152	Economy	11600.00
0005433922125	2152	Economy	11600.00
0005433922136	2152	Economy	11600.00
0005433875359	2152	Economy	11600.00
0005433922084	2152	Economy	11600.00
0005433035360	2152	Economy	11600.00
0005433922141	2152	Economy	12700.00
0005433922162	2152	Economy	12700.00
0005433922169	2152	Economy	11600.00
0005433922142	2152	Economy	11600.00
0005433922086	2152	Economy	12700.00
0005432231430	2152	Economy	11600.00
0005433922129	2152	Economy	12700.00
0005433922164	2152	Economy	11600.00
0005433922135	2152	Economy	11600.00
0005433922150	2152	Economy	11600.00
0005432231434	2152	Economy	11600.00
0005433922160	2152	Economy	11600.00
0005433922082	2152	Economy	11600.00
0005433922098	2152	Economy	11600.00
0005433922174	2152	Economy	11600.00
0005433922167	2152	Economy	11600.00
0005433922140	2152	Economy	11600.00
0005433922159	2152	Economy	11600.00
0005433922163	2152	Economy	11600.00
0005433922138	2152	Economy	11600.00
0005433922126	2152	Economy	11600.00
0005433922148	2152	Economy	11600.00
0005433922170	2152	Economy	11600.00
0005433922108	2152	Economy	11600.00
0005433922134	2152	Economy	11600.00
0005432231439	2152	Economy	11600.00
0005433922083	2152	Economy	11600.00
0005433922088	2152	Economy	11600.00
0005433922168	2152	Economy	11600.00
0005433922085	2152	Economy	11600.00
0005433035359	2152	Economy	11600.00
0005433922117	2152	Economy	11600.00
0005433922172	2152	Economy	11600.00
0005433922080	2152	Economy	11600.00
0005433922147	2152	Economy	11600.00
0005433922116	2152	Economy	11600.00
0005433929561	2152	Economy	11600.00
0005433929562	2152	Economy	11600.00
0005433922130	2152	Economy	11600.00
0005433922095	2152	Economy	11600.00
0005432231435	2152	Economy	11600.00
0005433922153	2152	Economy	11600.00
0005433922144	2152	Economy	11600.00
0005433922101	2152	Economy	11600.00
0005432044491	2152	Economy	11600.00
0005433922158	2152	Economy	11600.00
0005434028262	24087	Business	34700.00
0005433035676	24087	Business	34700.00
0005432206124	24087	Business	34700.00
0005433035653	24087	Business	34700.00
0005433035662	24087	Business	34700.00
0005433035672	24087	Business	34700.00
0005433035655	24087	Business	34700.00
0005433035627	24087	Business	34700.00
0005433035650	24087	Business	34700.00
0005433035674	24087	Business	34700.00
0005433035664	24087	Business	34700.00
0005434028261	24087	Business	34700.00
0005433035647	24087	Business	34700.00
0005433035677	24087	Economy	12700.00
0005433035657	24087	Economy	12700.00
0005433921725	24087	Economy	11600.00
0005433035648	24087	Economy	11600.00
0005433035636	24087	Economy	11600.00
0005433921693	24087	Economy	11600.00
0005433921660	24087	Economy	11600.00
0005433035669	24087	Economy	11600.00
0005433035652	24087	Economy	11600.00
0005433035644	24087	Economy	11600.00
0005433035659	24087	Economy	11600.00
0005432207631	24087	Economy	11600.00
0005433921659	24087	Economy	11600.00
0005432749758	24087	Economy	11600.00
0005433921742	24087	Economy	11600.00
0005433035678	24087	Economy	11600.00
0005433035632	24087	Economy	11600.00
0005433921694	24087	Economy	11600.00
0005433035646	24087	Economy	11600.00
0005433035628	24087	Economy	11600.00
0005433035658	24087	Economy	11600.00
0005433035637	24087	Economy	11600.00
0005433035651	24087	Economy	11600.00
0005433035670	24087	Economy	11600.00
0005433035679	24087	Economy	11600.00
0005433921612	24087	Economy	11600.00
0005433035642	24087	Economy	11600.00
0005433035635	24087	Economy	11600.00
0005432206127	24087	Economy	11600.00
0005433035660	24087	Economy	11600.00
0005433035663	24087	Economy	11600.00
0005432749759	24087	Economy	11600.00
0005433035661	24087	Economy	12700.00
0005433035667	24087	Economy	12700.00
0005433921677	24087	Economy	11600.00
0005433921741	24087	Economy	11600.00
0005433035629	24087	Economy	12700.00
0005433035639	24087	Economy	12700.00
0005433035666	24087	Economy	11600.00
0005432207630	24087	Economy	11600.00
0005433035630	24087	Economy	11600.00
0005432206123	24087	Economy	11600.00
0005433035633	24087	Economy	11600.00
0005432206125	24087	Economy	11600.00
0005433035640	24087	Economy	11600.00
0005433035675	24087	Economy	11600.00
0005433035643	24087	Economy	11600.00
0005433035649	24087	Economy	11600.00
0005432206122	24087	Economy	11600.00
0005433921665	24087	Economy	11600.00
0005433035673	24087	Economy	11600.00
0005432207629	24087	Economy	11600.00
0005433035641	24087	Economy	11600.00
0005433035631	24087	Economy	11600.00
0005433035626	24087	Economy	11600.00
0005433035634	24087	Economy	11600.00
0005433035645	24087	Economy	11600.00
0005433921740	24087	Economy	11600.00
0005433035665	24087	Economy	11600.00
0005433035671	24087	Economy	11600.00
0005433035656	24087	Economy	11600.00
0005433035668	24087	Economy	11600.00
0005433035638	24087	Economy	11600.00
0005432206126	24087	Economy	11600.00
0005432749757	24087	Economy	11600.00
0005433035654	24087	Economy	11600.00
0005434724022	278	Business	83700.00
0005434723943	278	Business	83700.00
0005434550554	278	Business	83700.00
0005434723949	278	Business	83700.00
0005434550556	278	Business	83700.00
0005433766572	278	Business	83700.00
0005432277638	278	Business	83700.00
0005434723956	278	Business	83700.00
0005434550538	278	Business	83700.00
0005434724049	278	Business	83700.00
0005433233086	278	Business	83700.00
0005434550580	278	Business	83700.00
0005435142410	278	Business	83700.00
0005432277647	278	Business	83700.00
0005434550592	278	Comfort	47400.00
0005434723995	278	Business	83700.00
0005432277642	278	Comfort	47400.00
0005434550537	278	Comfort	47400.00
0005434550558	278	Comfort	47400.00
0005434724021	278	Comfort	47400.00
0005434550588	278	Comfort	47400.00
0005434550568	278	Comfort	47400.00
0005434550573	278	Comfort	47400.00
0005434550569	278	Comfort	47400.00
0005434550553	278	Comfort	47400.00
0005434723948	278	Comfort	47400.00
0005434723932	278	Comfort	47400.00
0005434724023	278	Comfort	47400.00
0005434731115	278	Comfort	47400.00
0005434723965	278	Comfort	47400.00
0005434723967	278	Comfort	47400.00
0005434550551	278	Comfort	47400.00
0005434550559	278	Comfort	47400.00
0005432277651	278	Comfort	47400.00
0005434731116	278	Comfort	47400.00
0005434550572	278	Comfort	47400.00
0005434724011	278	Comfort	47400.00
0005434731114	278	Comfort	47400.00
0005434550547	278	Comfort	47400.00
0005434724009	278	Comfort	47400.00
0005434723992	278	Comfort	47400.00
0005434550578	278	Economy	27900.00
0005434724033	278	Economy	27900.00
0005434550560	278	Economy	27900.00
0005434550586	278	Economy	27900.00
0005434724036	278	Economy	27900.00
0005434550565	278	Economy	27900.00
0005434724019	278	Economy	27900.00
0005434723998	278	Economy	27900.00
0005434550579	278	Economy	27900.00
0005432277640	278	Economy	27900.00
0005434723931	278	Economy	27900.00
0005434723952	278	Economy	27900.00
0005434723962	278	Economy	27900.00
0005434550555	278	Economy	27900.00
0005434723999	278	Economy	27900.00
0005434550587	278	Economy	27900.00
0005434550561	278	Economy	27900.00
0005434723972	278	Economy	27900.00
0005434723934	278	Economy	27900.00
0005434723939	278	Economy	27900.00
0005434550576	278	Economy	27900.00
0005434723936	278	Economy	27900.00
0005434550543	278	Economy	27900.00
0005434723993	278	Economy	27900.00
0005434723964	278	Economy	27900.00
0005434724048	278	Economy	27900.00
0005434724002	278	Economy	27900.00
0005434550552	278	Economy	27900.00
0005434723971	278	Economy	27900.00
0005434724013	278	Economy	27900.00
0005434731113	278	Economy	27900.00
0005434724006	278	Economy	27900.00
0005434550548	278	Economy	27900.00
0005434723969	278	Economy	27900.00
0005434724041	278	Economy	27900.00
0005435142408	278	Economy	27900.00
0005434723980	278	Economy	27900.00
0005435142414	278	Economy	27900.00
0005434723989	278	Economy	27900.00
0005434724034	278	Economy	27900.00
0005434550540	278	Economy	27900.00
0005432277649	278	Economy	27900.00
0005434724038	278	Economy	27900.00
0005434735618	278	Economy	30700.00
0005434723959	278	Economy	27900.00
0005434723954	278	Economy	27900.00
0005433233121	278	Economy	27900.00
0005434723996	278	Economy	27900.00
0005434735619	278	Economy	27900.00
0005434735620	278	Economy	27900.00
0005435142405	278	Economy	27900.00
0005434723938	278	Economy	27900.00
0005434723958	278	Economy	27900.00
0005434723990	278	Economy	27900.00
0005435142411	278	Economy	27900.00
0005434724014	278	Economy	27900.00
0005434723966	278	Economy	27900.00
0005434550549	278	Economy	27900.00
0005432277639	278	Economy	27900.00
0005434550557	278	Economy	27900.00
0005434550550	278	Economy	27900.00
0005434723981	278	Economy	27900.00
0005434550571	278	Economy	27900.00
0005432277641	278	Economy	27900.00
0005434550539	278	Economy	27900.00
0005434723977	278	Economy	27900.00
0005434723978	278	Economy	27900.00
0005434550582	278	Economy	27900.00
0005435142407	278	Economy	27900.00
0005435142409	278	Economy	27900.00
0005434723935	278	Economy	27900.00
0005434723988	278	Economy	27900.00
0005432277644	278	Economy	27900.00
0005434723955	278	Economy	27900.00
0005434550584	278	Economy	27900.00
0005434724043	278	Economy	27900.00
0005435142406	278	Economy	27900.00
0005434724031	278	Economy	27900.00
0005434724050	278	Economy	27900.00
0005434302406	278	Economy	27900.00
0005434723957	278	Economy	27900.00
0005434724008	278	Economy	27900.00
0005434723983	278	Economy	27900.00
0005434723950	278	Economy	27900.00
0005434550585	278	Economy	27900.00
0005434723937	278	Economy	27900.00
0005434724012	278	Economy	27900.00
0005434724018	278	Economy	27900.00
0005434724004	278	Economy	27900.00
0005434550567	278	Economy	27900.00
0005434550564	278	Economy	27900.00
0005432277645	278	Economy	27900.00
0005435142415	278	Economy	27900.00
0005434724015	278	Economy	27900.00
0005435142416	278	Economy	27900.00
0005434723974	278	Economy	27900.00
0005434550563	278	Economy	27900.00
0005434302407	278	Economy	27900.00
0005434723941	278	Economy	27900.00
0005434724029	278	Economy	27900.00
0005434724035	278	Economy	27900.00
0005434723994	278	Economy	27900.00
0005434550575	278	Economy	27900.00
0005434550591	278	Economy	27900.00
0005434724003	278	Economy	27900.00
0005434723979	278	Economy	27900.00
0005435142412	278	Economy	27900.00
0005432277648	278	Economy	27900.00
0005432277650	278	Economy	27900.00
0005434724047	278	Economy	27900.00
0005434550581	278	Economy	27900.00
0005434550566	278	Economy	27900.00
0005434723970	278	Economy	27900.00
0005434723987	278	Economy	27900.00
0005434723975	278	Economy	27900.00
0005434723944	278	Economy	27900.00
0005434723984	278	Economy	27900.00
0005434550544	278	Economy	27900.00
0005434723963	278	Economy	27900.00
0005433180660	278	Economy	30700.00
0005434724010	278	Economy	30700.00
0005434723945	278	Economy	30700.00
0005434723985	278	Economy	30700.00
0005434724044	278	Economy	27900.00
0005434550542	278	Economy	27900.00
0005434724046	278	Economy	27900.00
0005434735623	278	Economy	27900.00
0005434723930	278	Economy	27900.00
0005434550590	278	Economy	27900.00
0005434724016	278	Economy	27900.00
0005434724007	278	Economy	27900.00
0005433233175	278	Economy	27900.00
0005434723946	278	Economy	27900.00
0005434723982	278	Economy	27900.00
0005434723942	278	Economy	27900.00
0005432277643	278	Economy	27900.00
0005434550583	278	Economy	27900.00
0005434724028	278	Economy	27900.00
0005434724045	278	Economy	27900.00
0005434724005	278	Economy	27900.00
0005435142413	278	Economy	27900.00
0005434724051	278	Economy	27900.00
0005432277646	278	Economy	27900.00
0005434735622	278	Economy	27900.00
0005434723997	278	Economy	27900.00
0005434724024	278	Economy	27900.00
0005434724017	278	Economy	27900.00
0005434550541	278	Economy	27900.00
0005434724039	278	Economy	27900.00
0005434723951	278	Economy	27900.00
0005434724032	278	Economy	27900.00
0005434723961	278	Economy	27900.00
0005434302405	278	Economy	27900.00
0005434723953	278	Economy	27900.00
0005434724000	278	Economy	27900.00
0005434723940	278	Economy	27900.00
0005434723947	278	Economy	27900.00
0005434550562	278	Economy	27900.00
0005434550589	278	Economy	27900.00
0005434723968	278	Economy	27900.00
0005434724040	278	Economy	27900.00
0005434550574	278	Economy	27900.00
0005434724020	278	Economy	27900.00
0005434724030	278	Economy	27900.00
0005434724053	278	Economy	27900.00
0005434550570	278	Economy	27900.00
0005434724052	278	Economy	27900.00
0005434724037	278	Economy	27900.00
0005434724027	278	Economy	27900.00
0005434724025	278	Economy	27900.00
0005435142417	278	Economy	27900.00
0005434723933	278	Economy	27900.00
0005434724026	278	Economy	27900.00
0005434723976	278	Economy	27900.00
0005434723986	278	Economy	27900.00
0005434550546	278	Economy	27900.00
0005434723973	278	Economy	27900.00
0005434724001	278	Economy	27900.00
0005434735621	278	Economy	27900.00
0005434723991	278	Economy	27900.00
0005434724042	278	Economy	27900.00
0005434302404	278	Economy	27900.00
0005434723960	278	Economy	27900.00
0005432277637	278	Economy	27900.00
0005433233122	278	Economy	27900.00
0005434550545	278	Economy	27900.00
0005434550577	278	Economy	27900.00
0005433233463	9873	Business	83700.00
0005433233453	9873	Business	83700.00
0005434031969	9873	Business	83700.00
0005433233428	9873	Business	83700.00
0005433233441	9873	Business	83700.00
0005433233438	9873	Business	83700.00
0005433233414	9873	Business	83700.00
0005433233406	9873	Business	83700.00
0005433129220	9873	Business	83700.00
0005432199164	9873	Business	83700.00
0005433180796	9873	Business	83700.00
0005433233417	9873	Comfort	47400.00
0005433233445	9873	Comfort	47400.00
0005434723521	9873	Comfort	47400.00
0005432199163	9873	Comfort	47400.00
0005433289755	9873	Comfort	47400.00
0005433233432	9873	Comfort	47400.00
0005433180788	9873	Comfort	47400.00
0005433233436	9873	Comfort	47400.00
0005433233402	9873	Comfort	47400.00
0005433233423	9873	Comfort	47400.00
0005433126789	9873	Comfort	47400.00
0005433289761	9873	Comfort	47400.00
0005434723365	9873	Comfort	47400.00
0005433233447	9873	Comfort	47400.00
0005433180778	9873	Comfort	47400.00
0005434723393	9873	Economy	27900.00
0005433233415	9873	Economy	27900.00
0005434723341	9873	Economy	27900.00
0005433180785	9873	Economy	27900.00
0005433113506	9873	Economy	27900.00
0005433233448	9873	Economy	27900.00
0005434723402	9873	Economy	27900.00
0005434723359	9873	Economy	27900.00
0005433233440	9873	Economy	27900.00
0005433180789	9873	Economy	27900.00
0005433233458	9873	Economy	27900.00
0005433180792	9873	Economy	27900.00
0005433233421	9873	Economy	27900.00
0005433289757	9873	Economy	27900.00
0005433180797	9873	Economy	27900.00
0005434550256	9873	Economy	27900.00
0005433129218	9873	Economy	27900.00
0005433233416	9873	Economy	27900.00
0005433233430	9873	Economy	27900.00
0005433233408	9873	Economy	27900.00
0005433766593	9873	Economy	27900.00
0005434031970	9873	Economy	27900.00
0005433180787	9873	Economy	30700.00
0005433233444	9873	Economy	27900.00
0005433129219	9873	Economy	27900.00
0005433180780	9873	Economy	30700.00
0005433233456	9873	Economy	27900.00
0005433180798	9873	Economy	30700.00
0005433233407	9873	Economy	27900.00
0005433233460	9873	Economy	27900.00
0005433233410	9873	Economy	27900.00
0005433233439	9873	Economy	27900.00
0005433233454	9873	Economy	27900.00
0005433233452	9873	Economy	27900.00
0005433289754	9873	Economy	27900.00
0005433180790	9873	Economy	27900.00
0005433126790	9873	Economy	27900.00
0005433180784	9873	Economy	27900.00
0005433126787	9873	Economy	27900.00
0005433233434	9873	Economy	27900.00
0005433233433	9873	Economy	27900.00
0005432199161	9873	Economy	27900.00
0005433126788	9873	Economy	27900.00
0005433113507	9873	Economy	27900.00
0005433233409	9873	Economy	27900.00
0005433180786	9873	Economy	27900.00
0005433233462	9873	Economy	27900.00
0005434723415	9873	Economy	27900.00
0005433233457	9873	Economy	27900.00
0005433233404	9873	Economy	27900.00
0005433180777	9873	Economy	27900.00
0005434550257	9873	Economy	27900.00
0005432199159	9873	Economy	27900.00
0005433233461	9873	Economy	27900.00
0005434031971	9873	Economy	27900.00
0005433233412	9873	Economy	27900.00
0005433289760	9873	Economy	27900.00
0005433289756	9873	Economy	27900.00
0005433233422	9873	Economy	27900.00
0005433180783	9873	Economy	27900.00
0005433233435	9873	Economy	27900.00
0005433766594	9873	Economy	27900.00
0005433233451	9873	Economy	27900.00
0005433233419	9873	Economy	27900.00
0005434723403	9873	Economy	27900.00
0005433233405	9873	Economy	27900.00
0005433180800	9873	Economy	27900.00
0005432199165	9873	Economy	27900.00
0005432199160	9873	Economy	27900.00
0005433180781	9873	Economy	27900.00
0005434723390	9873	Economy	27900.00
0005433126786	9873	Economy	27900.00
0005434723366	9873	Economy	27900.00
0005433233420	9873	Economy	27900.00
0005433289758	9873	Economy	27900.00
0005433233443	9873	Economy	27900.00
0005433233426	9873	Economy	27900.00
0005433233442	9873	Economy	27900.00
0005433233465	9873	Economy	27900.00
0005433180802	9873	Economy	27900.00
0005433233431	9873	Economy	27900.00
0005433233464	9873	Economy	27900.00
0005433180791	9873	Economy	27900.00
0005433233450	9873	Economy	27900.00
0005433233429	9873	Economy	27900.00
0005433233413	9873	Economy	27900.00
0005434031968	9873	Economy	27900.00
0005433233459	9873	Economy	27900.00
0005433233446	9873	Economy	27900.00
0005433180794	9873	Economy	27900.00
0005433180799	9873	Economy	27900.00
0005434723430	9873	Economy	27900.00
0005433180779	9873	Economy	27900.00
0005433233427	9873	Economy	27900.00
0005433180801	9873	Economy	27900.00
0005434723536	9873	Economy	27900.00
0005434550258	9873	Economy	27900.00
0005434723392	9873	Economy	27900.00
0005433233424	9873	Economy	27900.00
0005433233418	9873	Economy	27900.00
0005432199162	9873	Economy	27900.00
0005433233403	9873	Economy	27900.00
0005434031967	9873	Economy	27900.00
0005433233455	9873	Economy	27900.00
0005434723520	9873	Economy	27900.00
0005433233411	9873	Economy	27900.00
0005433289759	9873	Economy	27900.00
0005433180793	9873	Economy	27900.00
0005433233425	9873	Economy	27900.00
0005433180795	9873	Economy	27900.00
0005433180782	9873	Economy	27900.00
0005433113508	9873	Economy	27900.00
0005433233437	9873	Economy	27900.00
0005433233449	9873	Economy	27900.00
0005434066662	7727	Business	42100.00
0005432526333	7727	Business	42100.00
0005432535773	7727	Business	42100.00
0005432526428	7727	Business	42100.00
0005432526363	7727	Business	42100.00
0005432526394	7727	Business	42100.00
0005432526340	7727	Business	42100.00
0005432526364	7727	Business	42100.00
0005434066682	7727	Business	42100.00
0005432526362	7727	Business	42100.00
0005432526410	7727	Business	42100.00
0005434066677	7727	Business	42100.00
0005432526368	7727	Business	42100.00
0005432526416	7727	Business	42100.00
0005432526414	7727	Business	42100.00
0005434066681	7727	Business	42100.00
0005432526334	7727	Business	42100.00
0005434066723	7727	Business	42100.00
0005432526338	7727	Business	42100.00
0005432526349	7727	Comfort	23900.00
0005432526395	7727	Comfort	23900.00
0005434066712	7727	Comfort	23900.00
0005432526345	7727	Comfort	23900.00
0005432526378	7727	Comfort	23900.00
0005435212343	7727	Comfort	23900.00
0005432150095	7727	Comfort	23900.00
0005432526424	7727	Comfort	23900.00
0005432526422	7727	Comfort	23900.00
0005434066694	7727	Comfort	23900.00
0005432150099	7727	Comfort	23900.00
0005432526353	7727	Comfort	23900.00
0005432526335	7727	Comfort	23900.00
0005432069473	7727	Comfort	23900.00
0005434066667	7727	Comfort	23900.00
0005434066725	7727	Comfort	23900.00
0005434066719	7727	Comfort	23900.00
0005434066659	7727	Comfort	23900.00
0005434066690	7727	Comfort	23900.00
0005434066666	7727	Comfort	23900.00
0005432150097	7727	Comfort	23900.00
0005434066720	7727	Comfort	23900.00
0005432526322	7727	Comfort	23900.00
0005432526326	7727	Comfort	23900.00
0005432526385	7727	Comfort	23900.00
0005434066703	7727	Comfort	23900.00
0005432535770	7727	Comfort	23900.00
0005432526377	7727	Comfort	23900.00
0005432526398	7727	Comfort	23900.00
0005432526383	7727	Comfort	23900.00
0005434066661	7727	Comfort	23900.00
0005434066728	7727	Comfort	23900.00
0005432526325	7727	Comfort	23900.00
0005432428887	7727	Comfort	23900.00
0005432526307	7727	Comfort	23900.00
0005432150100	7727	Comfort	23900.00
0005434066688	7727	Comfort	23900.00
0005432526316	7727	Economy	14000.00
0005434066658	7727	Economy	14000.00
0005432150096	7727	Economy	14000.00
0005432526373	7727	Economy	14000.00
0005432526425	7727	Economy	14000.00
0005434066683	7727	Economy	14000.00
0005432526356	7727	Economy	14000.00
0005432526437	7727	Economy	14000.00
0005432526342	7727	Economy	14000.00
0005434066715	7727	Economy	14000.00
0005434066680	7727	Economy	14000.00
0005432526386	7727	Economy	14000.00
0005432526370	7727	Economy	14000.00
0005432535774	7727	Economy	14000.00
0005432428886	7727	Economy	14000.00
0005432526360	7727	Economy	14000.00
0005432526397	7727	Economy	14000.00
0005432526418	7727	Economy	14000.00
0005432526402	7727	Economy	14000.00
0005434066717	7727	Economy	14000.00
0005434066676	7727	Economy	14000.00
0005432526430	7727	Economy	14000.00
0005432069472	7727	Economy	14000.00
0005432150094	7727	Economy	14000.00
0005432069482	7727	Economy	14000.00
0005432526415	7727	Economy	14000.00
0005432526308	7727	Economy	14000.00
0005432069469	7727	Economy	14000.00
0005432526317	7727	Economy	14000.00
0005432526351	7727	Economy	14000.00
0005434066696	7727	Economy	14000.00
0005434066705	7727	Economy	14000.00
0005432526311	7727	Economy	14000.00
0005432526409	7727	Economy	14000.00
0005432526421	7727	Economy	14000.00
0005432526330	7727	Economy	14000.00
0005432526361	7727	Economy	14000.00
0005432535771	7727	Economy	14000.00
0005434066684	7727	Economy	14000.00
0005434066687	7727	Economy	14000.00
0005432069479	7727	Economy	14000.00
0005432526320	7727	Economy	15400.00
0005434066704	7727	Economy	15400.00
0005432526350	7727	Economy	14000.00
0005434066695	7727	Economy	14000.00
0005434066729	7727	Economy	14000.00
0005432526438	7727	Economy	14000.00
0005432526329	7727	Economy	15400.00
0005432526336	7727	Economy	14000.00
0005434066713	7727	Economy	15400.00
0005432526339	7727	Economy	14000.00
0005432526359	7727	Economy	14000.00
0005434066691	7727	Economy	14000.00
0005432526399	7727	Economy	14000.00
0005432537031	7727	Economy	14000.00
0005434066679	7727	Economy	14000.00
0005434066693	7727	Economy	14000.00
0005432526426	7727	Economy	14000.00
0005434066686	7727	Economy	14000.00
0005432526436	7727	Economy	14000.00
0005432526331	7727	Economy	14000.00
0005434066707	7727	Economy	14000.00
0005432069476	7727	Economy	14000.00
0005434066698	7727	Economy	14000.00
0005434066670	7727	Economy	14000.00
0005432526434	7727	Economy	14000.00
0005432069481	7727	Economy	14000.00
0005434066671	7727	Economy	14000.00
0005432526306	7727	Economy	14000.00
0005432526346	7727	Economy	14000.00
0005432526369	7727	Economy	14000.00
0005434066699	7727	Economy	14000.00
0005432150102	7727	Economy	14000.00
0005432069470	7727	Economy	14000.00
0005432526406	7727	Economy	14000.00
0005432526403	7727	Economy	14000.00
0005432526332	7727	Economy	14000.00
0005432526328	7727	Economy	14000.00
0005432526341	7727	Economy	14000.00
0005432526417	7727	Economy	14000.00
0005432526420	7727	Economy	14000.00
0005432526337	7727	Economy	14000.00
0005432526407	7727	Economy	14000.00
0005432526324	7727	Economy	14000.00
0005434066675	7727	Economy	14000.00
0005432428885	7727	Economy	14000.00
0005432526413	7727	Economy	14000.00
0005434066724	7727	Economy	14000.00
0005434066709	7727	Economy	14000.00
0005432533255	7727	Economy	14000.00
0005432526310	7727	Economy	14000.00
0005432526391	7727	Economy	14000.00
0005432526365	7727	Economy	14000.00
0005434066706	7727	Economy	14000.00
0005432069474	7727	Economy	14000.00
0005432526375	7727	Economy	14000.00
0005432526440	7727	Economy	14000.00
0005432526400	7727	Economy	14000.00
0005432526381	7727	Economy	14000.00
0005434066711	7727	Economy	14000.00
0005432526314	7727	Economy	14000.00
0005432526344	7727	Economy	14000.00
0005432526390	7727	Economy	14000.00
0005434066678	7727	Economy	14000.00
0005432526309	7727	Economy	14000.00
0005432535772	7727	Economy	14000.00
0005432526315	7727	Economy	14000.00
0005432526354	7727	Economy	14000.00
0005432526367	7727	Economy	14000.00
0005434066697	7727	Economy	14000.00
0005432526408	7727	Economy	14000.00
0005432526372	7727	Economy	14000.00
0005432069471	7727	Economy	14000.00
0005432069477	7727	Economy	14000.00
0005432526396	7727	Economy	15400.00
0005434066726	7727	Economy	14000.00
0005432526327	7727	Economy	15400.00
0005432526321	7727	Economy	15400.00
0005434066689	7727	Economy	15400.00
0005434066664	7727	Economy	14000.00
0005434066672	7727	Economy	14000.00
0005432526357	7727	Economy	14000.00
0005432526412	7727	Economy	14000.00
0005432526348	7727	Economy	14000.00
0005432526393	7727	Economy	14000.00
0005432526312	7727	Economy	14000.00
0005432526358	7727	Economy	14000.00
0005432526404	7727	Economy	14000.00
0005432526419	7727	Economy	14000.00
0005432526371	7727	Economy	14000.00
0005434066663	7727	Economy	14000.00
0005432526387	7727	Economy	14000.00
0005432526405	7727	Economy	14000.00
0005432526429	7727	Economy	14000.00
0005432533257	7727	Economy	14000.00
0005432526379	7727	Economy	14000.00
0005432526366	7727	Economy	14000.00
0005432526352	7727	Economy	14000.00
0005432526384	7727	Economy	14000.00
0005432526392	7727	Economy	14000.00
0005434066727	7727	Economy	14000.00
0005432526423	7727	Economy	14000.00
0005432526376	7727	Economy	14000.00
0005432533256	7727	Economy	14000.00
0005432150101	7727	Economy	14000.00
0005432537030	7727	Economy	14000.00
0005432526427	7727	Economy	14000.00
0005432526305	7727	Economy	14000.00
0005432526319	7727	Economy	14000.00
0005432526389	7727	Economy	14000.00
0005434066669	7727	Economy	14000.00
0005434066702	7727	Economy	14000.00
0005432526439	7727	Economy	14000.00
0005432526323	7727	Economy	14000.00
0005434066685	7727	Economy	14000.00
0005432526411	7727	Economy	14000.00
0005434066674	7727	Economy	14000.00
0005432526388	7727	Economy	14000.00
0005434066721	7727	Economy	14000.00
0005434066714	7727	Economy	14000.00
0005432526355	7727	Economy	14000.00
0005434066692	7727	Economy	14000.00
0005432069475	7727	Economy	14000.00
0005432526347	7727	Economy	14000.00
0005434066710	7727	Economy	14000.00
0005434066722	7727	Economy	14000.00
0005432069478	7727	Economy	14000.00
0005434066718	7727	Economy	14000.00
0005432526431	7727	Economy	14000.00
0005434066668	7727	Economy	14000.00
0005434066660	7727	Economy	14000.00
0005432069480	7727	Economy	14000.00
0005432526433	7727	Economy	14000.00
0005432150098	7727	Economy	14000.00
0005432526382	7727	Economy	14000.00
0005432526343	7727	Economy	14000.00
0005434066701	7727	Economy	14000.00
0005434066665	7727	Economy	14000.00
0005434066708	7727	Economy	14000.00
0005432526435	7727	Economy	14000.00
0005434066716	7727	Economy	14000.00
0005432526401	7727	Economy	14000.00
0005434066673	7727	Economy	14000.00
0005434066700	7727	Economy	14000.00
0005432526374	7727	Economy	14000.00
0005432526313	7727	Economy	14000.00
0005432526318	7727	Economy	14000.00
0005432526432	7727	Economy	14000.00
0005435212428	7727	Economy	14000.00
0005432526380	7727	Economy	14000.00
0005435612263	5345	Business	43100.00
0005434343780	5345	Business	43100.00
0005435612353	5345	Business	43100.00
0005435612258	5345	Business	43100.00
0005432133021	5345	Business	43100.00
0005435612272	5345	Business	43100.00
0005435423650	5345	Business	43100.00
0005435612344	5345	Business	43100.00
0005434343773	5345	Business	43100.00
0005435612244	5345	Business	43100.00
0005435612276	5345	Business	43100.00
0005432047504	5345	Business	43100.00
0005435612305	5345	Business	43100.00
0005435612311	5345	Comfort	24400.00
0005435612343	5345	Comfort	24400.00
0005435612349	5345	Comfort	24400.00
0005435555342	5345	Comfort	24400.00
0005435612283	5345	Comfort	24400.00
0005435612291	5345	Comfort	24400.00
0005435612307	5345	Comfort	24400.00
0005435612318	5345	Comfort	24400.00
0005435612362	5345	Comfort	24400.00
0005434343765	5345	Comfort	24400.00
0005432133020	5345	Comfort	24400.00
0005434343792	5345	Comfort	24400.00
0005434343789	5345	Comfort	24400.00
0005435612280	5345	Comfort	24400.00
0005434343767	5345	Comfort	24400.00
0005434343761	5345	Comfort	24400.00
0005435423730	5345	Comfort	24400.00
0005435612331	5345	Comfort	24400.00
0005435612259	5345	Comfort	24400.00
0005434573185	5345	Comfort	24400.00
0005435612269	5345	Comfort	24400.00
0005434343777	5345	Comfort	24400.00
0005435612297	5345	Comfort	24400.00
0005435490184	5345	Economy	14400.00
0005435612314	5345	Economy	14400.00
0005435423596	5345	Economy	14400.00
0005432133031	5345	Economy	14400.00
0005435097091	5345	Economy	14400.00
0005434573176	5345	Economy	14400.00
0005435612359	5345	Economy	14400.00
0005435612321	5345	Economy	14400.00
0005435612300	5345	Economy	14400.00
0005434343762	5345	Economy	14400.00
0005434343796	5345	Economy	14400.00
0005435612267	5345	Economy	14400.00
0005435612293	5345	Economy	14400.00
0005435612287	5345	Economy	14400.00
0005434343770	5345	Economy	14400.00
0005434573178	5345	Economy	14400.00
0005434343788	5345	Economy	14400.00
0005434343764	5345	Economy	14400.00
0005435612285	5345	Economy	14400.00
0005435612340	5345	Economy	14400.00
0005434343774	5345	Economy	14400.00
0005435612320	5345	Economy	14400.00
0005435097096	5345	Economy	14400.00
0005435612250	5345	Economy	14400.00
0005435612332	5345	Economy	14400.00
0005432133019	5345	Economy	14400.00
0005435612335	5345	Economy	14400.00
0005432133030	5345	Economy	14400.00
0005435612333	5345	Economy	14400.00
0005435612346	5345	Economy	14400.00
0005434573182	5345	Economy	14400.00
0005435423592	5345	Economy	14400.00
0005432133024	5345	Economy	14400.00
0005434343769	5345	Economy	14400.00
0005435612326	5345	Economy	14400.00
0005435423699	5345	Economy	14400.00
0005432133023	5345	Economy	14400.00
0005435612299	5345	Economy	14400.00
0005435097093	5345	Economy	15800.00
0005435097094	5345	Economy	15800.00
0005434343776	5345	Economy	14400.00
0005435612292	5345	Economy	14400.00
0005435612282	5345	Economy	14400.00
0005432133029	5345	Economy	14400.00
0005435555343	5345	Economy	14400.00
0005435612319	5345	Economy	14400.00
0005435423628	5345	Economy	14400.00
0005434343771	5345	Economy	14400.00
0005435612345	5345	Economy	14400.00
0005434343790	5345	Economy	14400.00
0005435097098	5345	Economy	14400.00
0005434343782	5345	Economy	14400.00
0005435612356	5345	Economy	14400.00
0005435612242	5345	Economy	14400.00
0005434573183	5345	Economy	14400.00
0005434573177	5345	Economy	14400.00
0005435612334	5345	Economy	14400.00
0005432133034	5345	Economy	14400.00
0005435612261	5345	Economy	14400.00
0005435612281	5345	Economy	14400.00
0005434573173	5345	Economy	14400.00
0005434343793	5345	Economy	14400.00
0005435612302	5345	Economy	14400.00
0005435612288	5345	Economy	14400.00
0005435612350	5345	Economy	14400.00
0005434343768	5345	Economy	14400.00
0005432133026	5345	Economy	14400.00
0005435612361	5345	Economy	14400.00
0005435097095	5345	Economy	14400.00
0005432133033	5345	Economy	14400.00
0005435423613	5345	Economy	14400.00
0005435097088	5345	Economy	14400.00
0005434343775	5345	Economy	14400.00
0005435612325	5345	Economy	14400.00
0005435612347	5345	Economy	14400.00
0005434343784	5345	Economy	14400.00
0005435612290	5345	Economy	14400.00
0005435612339	5345	Economy	14400.00
0005435612338	5345	Economy	14400.00
0005435612296	5345	Economy	14400.00
0005435612279	5345	Economy	14400.00
0005435097089	5345	Economy	14400.00
0005435612328	5345	Economy	14400.00
0005435612317	5345	Economy	14400.00
0005435612358	5345	Economy	14400.00
0005435612357	5345	Economy	14400.00
0005435612327	5345	Economy	14400.00
0005435612323	5345	Economy	14400.00
0005435612251	5345	Economy	14400.00
0005435612248	5345	Economy	14400.00
0005435423698	5345	Economy	14400.00
0005434343797	5345	Economy	14400.00
0005435612265	5345	Economy	14400.00
0005435612354	5345	Economy	14400.00
0005435612246	5345	Economy	14400.00
0005435612268	5345	Economy	14400.00
0005434343779	5345	Economy	14400.00
0005434573186	5345	Economy	14400.00
0005435612355	5345	Economy	14400.00
0005435612360	5345	Economy	14400.00
0005435319424	5345	Economy	14400.00
0005435612351	5345	Economy	14400.00
0005435612342	5345	Economy	14400.00
0005435612255	5345	Economy	14400.00
0005435612249	5345	Economy	14400.00
0005435097090	5345	Economy	14400.00
0005435612304	5345	Economy	14400.00
0005434343772	5345	Economy	14400.00
0005434343795	5345	Economy	14400.00
0005435097092	5345	Economy	14400.00
0005434343783	5345	Economy	14400.00
0005435612247	5345	Economy	14400.00
0005435612266	5345	Economy	14400.00
0005434573180	5345	Economy	14400.00
0005435612253	5345	Economy	14400.00
0005434343786	5345	Economy	14400.00
0005435612309	5345	Economy	14400.00
0005435612306	5345	Economy	14400.00
0005435612273	5345	Economy	14400.00
0005435612295	5345	Economy	14400.00
0005435612313	5345	Economy	14400.00
0005435612286	5345	Economy	15800.00
0005435612348	5345	Economy	14400.00
0005435423693	5345	Economy	15800.00
0005435612277	5345	Economy	15800.00
0005435612294	5345	Economy	15800.00
0005434343778	5345	Economy	15800.00
0005434573184	5345	Economy	14400.00
0005434343785	5345	Economy	14400.00
0005435612243	5345	Economy	14400.00
0005432133032	5345	Economy	14400.00
0005432133025	5345	Economy	14400.00
0005435612329	5345	Economy	14400.00
0005432133018	5345	Economy	14400.00
0005435423761	5345	Economy	14400.00
0005435612257	5345	Economy	14400.00
0005435612316	5345	Economy	14400.00
0005435612252	5345	Economy	14400.00
0005435612256	5345	Economy	14400.00
0005435612245	5345	Economy	14400.00
0005435612315	5345	Economy	14400.00
0005434343763	5345	Economy	14400.00
0005435612324	5345	Economy	14400.00
0005435612274	5345	Economy	14400.00
0005435097097	5345	Economy	14400.00
0005434573175	5345	Economy	14400.00
0005434343791	5345	Economy	14400.00
0005435612270	5345	Economy	14400.00
0005435612310	5345	Economy	14400.00
0005434343794	5345	Economy	14400.00
0005434573181	5345	Economy	14400.00
0005435612260	5345	Economy	14400.00
0005432133022	5345	Economy	14400.00
0005435612337	5345	Economy	14400.00
0005434573174	5345	Economy	14400.00
0005435612284	5345	Economy	14400.00
0005435612352	5345	Economy	14400.00
0005435612298	5345	Economy	14400.00
0005432047502	5345	Economy	14400.00
0005432133027	5345	Economy	14400.00
0005434343787	5345	Economy	14400.00
0005432047503	5345	Economy	14400.00
0005435612330	5345	Economy	14400.00
0005435423645	5345	Economy	14400.00
0005435612312	5345	Economy	14400.00
0005435612264	5345	Economy	14400.00
0005435612308	5345	Economy	14400.00
0005435612301	5345	Economy	14400.00
0005435423620	5345	Economy	14400.00
0005435612262	5345	Economy	14400.00
0005435612341	5345	Economy	14400.00
0005434343798	5345	Economy	14400.00
0005435319425	5345	Economy	14400.00
0005434573187	5345	Economy	14400.00
0005434573179	5345	Economy	14400.00
0005434343766	5345	Economy	14400.00
0005435612271	5345	Economy	14400.00
0005434343781	5345	Economy	14400.00
0005435612275	5345	Economy	14400.00
0005435612303	5345	Economy	14400.00
0005432133028	5345	Economy	14400.00
0005432047505	5345	Economy	14400.00
0005435612336	5345	Economy	14400.00
0005435423644	5345	Economy	14400.00
0005435612254	5345	Economy	14400.00
0005435612289	5345	Economy	14400.00
0005435612322	5345	Economy	14400.00
0005435612278	5345	Economy	14400.00
0005432164940	10892	Business	43100.00
0005435423945	10892	Business	43100.00
0005432164944	10892	Business	43100.00
0005435423928	10892	Business	43100.00
0005435423982	10892	Business	43100.00
0005435423964	10892	Business	43100.00
0005435319467	10892	Business	43100.00
0005435423969	10892	Business	43100.00
0005435423934	10892	Business	43100.00
0005435304113	10892	Business	43100.00
0005434244628	10892	Business	43100.00
0005434656530	10892	Business	43100.00
0005432164947	10892	Business	43100.00
0005434244606	10892	Business	43100.00
0005435611717	10892	Business	43100.00
0005435319462	10892	Comfort	24400.00
0005435611867	10892	Comfort	24400.00
0005434244604	10892	Comfort	24400.00
0005435423932	10892	Comfort	24400.00
0005435423929	10892	Comfort	24400.00
0005435423991	10892	Comfort	24400.00
0005435423972	10892	Comfort	24400.00
0005435611774	10892	Comfort	24400.00
0005434244612	10892	Comfort	24400.00
0005433719099	10892	Comfort	24400.00
0005434244607	10892	Comfort	24400.00
0005435380237	10892	Comfort	24400.00
0005435423942	10892	Comfort	24400.00
0005435423941	10892	Comfort	24400.00
0005434244608	10892	Comfort	24400.00
0005434244623	10892	Comfort	24400.00
0005435423973	10892	Comfort	24400.00
0005435423951	10892	Economy	14400.00
0005435380235	10892	Economy	14400.00
0005435304111	10892	Economy	14400.00
0005435423943	10892	Economy	14400.00
0005435423938	10892	Economy	14400.00
0005433719098	10892	Economy	14400.00
0005435423979	10892	Economy	14400.00
0005432166860	10892	Economy	14400.00
0005435423977	10892	Economy	14400.00
0005435423997	10892	Economy	14400.00
0005434244625	10892	Economy	14400.00
0005435423953	10892	Economy	14400.00
0005435304109	10892	Economy	14400.00
0005435319460	10892	Economy	14400.00
0005435423931	10892	Economy	14400.00
0005435423962	10892	Economy	14400.00
0005432164943	10892	Economy	14400.00
0005435423980	10892	Economy	14400.00
0005435423961	10892	Economy	14400.00
0005435423993	10892	Economy	14400.00
0005435611719	10892	Economy	14400.00
0005435423966	10892	Economy	14400.00
0005432166862	10892	Economy	14400.00
0005435423975	10892	Economy	14400.00
0005435423948	10892	Economy	14400.00
0005432363374	10892	Economy	14400.00
0005435423935	10892	Economy	14400.00
0005435423974	10892	Economy	14400.00
0005435319464	10892	Economy	15800.00
0005434244613	10892	Economy	14400.00
0005434244611	10892	Economy	14400.00
0005434244605	10892	Economy	14400.00
0005435423995	10892	Economy	14400.00
0005434244617	10892	Economy	14400.00
0005435319465	10892	Economy	14400.00
0005435423988	10892	Economy	14400.00
0005435304999	10892	Economy	14400.00
0005435423956	10892	Economy	14400.00
0005435423955	10892	Economy	14400.00
0005435423944	10892	Economy	14400.00
0005435423984	10892	Economy	14400.00
0005435423957	10892	Economy	14400.00
0005434244626	10892	Economy	14400.00
0005435319461	10892	Economy	14400.00
0005435612046	10892	Economy	14400.00
0005435611764	10892	Economy	14400.00
0005435423952	10892	Economy	14400.00
0005435612045	10892	Economy	14400.00
0005435423976	10892	Economy	14400.00
0005435423981	10892	Economy	14400.00
0005435423946	10892	Economy	14400.00
0005435423978	10892	Economy	14400.00
0005434244633	10892	Economy	14400.00
0005432840988	10892	Economy	14400.00
0005432164942	10892	Economy	14400.00
0005434573122	10892	Economy	14400.00
0005435611763	10892	Economy	14400.00
0005435423949	10892	Economy	14400.00
0005432164946	10892	Economy	14400.00
0005434244620	10892	Economy	14400.00
0005434244629	10892	Economy	14400.00
0005435611715	10892	Economy	14400.00
0005435423989	10892	Economy	14400.00
0005435423967	10892	Economy	14400.00
0005435423958	10892	Economy	14400.00
0005435380238	10892	Economy	14400.00
0005435304110	10892	Economy	14400.00
0005435380236	10892	Economy	14400.00
0005433719100	10892	Economy	14400.00
0005434244631	10892	Economy	14400.00
0005435423983	10892	Economy	14400.00
0005435423950	10892	Economy	14400.00
0005435611716	10892	Economy	14400.00
0005435423960	10892	Economy	14400.00
0005434244632	10892	Economy	14400.00
0005435423933	10892	Economy	14400.00
0005435423930	10892	Economy	14400.00
0005434244610	10892	Economy	14400.00
0005435423971	10892	Economy	15800.00
0005434244614	10892	Economy	15800.00
0005435423965	10892	Economy	15800.00
0005434244627	10892	Economy	14400.00
0005435304112	10892	Economy	14400.00
0005435319463	10892	Economy	14400.00
0005435423968	10892	Economy	14400.00
0005434656531	10892	Economy	14400.00
0005435304998	10892	Economy	14400.00
0005434244616	10892	Economy	14400.00
0005435319466	10892	Economy	14400.00
0005435423959	10892	Economy	14400.00
0005435423987	10892	Economy	14400.00
0005434244622	10892	Economy	14400.00
0005435611720	10892	Economy	14400.00
0005435304114	10892	Economy	14400.00
0005434244624	10892	Economy	14400.00
0005432164945	10892	Economy	14400.00
0005434244619	10892	Economy	14400.00
0005434244615	10892	Economy	14400.00
0005434244630	10892	Economy	14400.00
0005435423985	10892	Economy	14400.00
0005432840987	10892	Economy	14400.00
0005435423992	10892	Economy	14400.00
0005434244618	10892	Economy	14400.00
0005435423986	10892	Economy	14400.00
0005435423970	10892	Economy	14400.00
0005435423937	10892	Economy	14400.00
0005435423994	10892	Economy	14400.00
0005435423947	10892	Economy	14400.00
0005435423996	10892	Economy	14400.00
0005432363375	10892	Economy	14400.00
0005432363376	10892	Economy	14400.00
0005435423954	10892	Economy	14400.00
0005435423990	10892	Economy	14400.00
0005432164948	10892	Economy	14400.00
0005434244609	10892	Economy	14400.00
0005435423940	10892	Economy	14400.00
0005435423939	10892	Economy	14400.00
0005432164941	10892	Economy	14400.00
0005435380239	10892	Economy	14400.00
0005435423936	10892	Economy	14400.00
0005434244621	10892	Economy	14400.00
0005435423963	10892	Economy	14400.00
0005432166861	10892	Economy	14400.00
0005432181441	3299	Business	18800.00
0005433804959	3299	Business	18800.00
0005433506952	3299	Business	18800.00
0005433633417	3299	Business	18800.00
0005432181449	3299	Business	18800.00
0005433506954	3299	Business	18800.00
0005433633394	3299	Business	18800.00
0005433633398	3299	Business	18800.00
0005432181433	3299	Business	18800.00
0005433804958	3299	Business	18800.00
0005433633402	3299	Business	18800.00
0005433804947	3299	Business	18800.00
0005433633391	3299	Business	18800.00
0005433804961	3299	Business	18800.00
0005433804936	3299	Economy	6900.00
0005433633411	3299	Economy	6900.00
0005433804949	3299	Economy	6900.00
0005432181438	3299	Economy	6900.00
0005433506944	3299	Economy	6900.00
0005433506947	3299	Economy	6300.00
0005433804941	3299	Economy	6300.00
0005433804956	3299	Economy	6300.00
0005433506953	3299	Economy	6300.00
0005433804963	3299	Economy	6300.00
0005433633390	3299	Economy	6300.00
0005433633416	3299	Economy	6300.00
0005433804948	3299	Economy	6300.00
0005433804967	3299	Economy	6300.00
0005432181439	3299	Economy	6300.00
0005433633393	3299	Economy	6300.00
0005433804942	3299	Economy	6300.00
0005433804966	3299	Economy	6300.00
0005433633397	3299	Economy	6300.00
0005433633412	3299	Economy	6300.00
0005433633389	3299	Economy	6300.00
0005432181435	3299	Economy	6300.00
0005433633399	3299	Economy	6300.00
0005433804944	3299	Economy	6300.00
0005432181453	3299	Economy	6300.00
0005433506950	3299	Economy	6300.00
0005432181447	3299	Economy	6300.00
0005432181434	3299	Economy	6300.00
0005433506958	3299	Economy	6300.00
0005433633414	3299	Economy	6300.00
0005433633419	3299	Economy	6300.00
0005433804952	3299	Economy	6300.00
0005432181443	3299	Economy	6300.00
0005432181437	3299	Economy	6300.00
0005433804943	3299	Economy	6300.00
0005432181445	3299	Economy	6300.00
0005433633418	3299	Economy	6300.00
0005433633395	3299	Economy	6300.00
0005433633396	3299	Economy	6300.00
0005433633406	3299	Economy	6300.00
0005433804935	3299	Economy	6300.00
0005433633404	3299	Economy	6300.00
0005432181446	3299	Economy	6300.00
0005433633388	3299	Economy	6900.00
0005432181452	3299	Economy	6900.00
0005433633401	3299	Economy	6300.00
0005433633392	3299	Economy	6900.00
0005433804950	3299	Economy	6300.00
0005433506948	3299	Economy	6300.00
0005433633415	3299	Economy	6300.00
0005433633409	3299	Economy	6300.00
0005433804953	3299	Economy	6300.00
0005432181450	3299	Economy	6300.00
0005433633410	3299	Economy	6300.00
0005433506955	3299	Economy	6300.00
0005432181432	3299	Economy	6300.00
0005433804946	3299	Economy	6300.00
0005433633413	3299	Economy	6300.00
0005433804940	3299	Economy	6300.00
0005433633405	3299	Economy	6300.00
0005432181436	3299	Economy	6300.00
0005432181448	3299	Economy	6300.00
0005432181444	3299	Economy	6300.00
0005432181440	3299	Economy	6300.00
0005433506945	3299	Economy	6300.00
0005432181451	3299	Economy	6300.00
0005433506957	3299	Economy	6300.00
0005433804955	3299	Economy	6300.00
0005433804934	3299	Economy	6300.00
0005433633421	3299	Economy	6300.00
0005433506946	3299	Economy	6300.00
0005433804937	3299	Economy	6300.00
0005433804960	3299	Economy	6300.00
0005433804945	3299	Economy	6300.00
0005432181442	3299	Economy	6300.00
0005433804938	3299	Economy	6300.00
0005432181454	3299	Economy	6300.00
0005433804954	3299	Economy	6300.00
0005433633408	3299	Economy	6300.00
0005433633400	3299	Economy	6300.00
0005433804951	3299	Economy	6300.00
0005433506956	3299	Economy	6300.00
0005433633420	3299	Economy	6300.00
0005433804965	3299	Economy	6300.00
0005433804957	3299	Economy	6300.00
0005433633403	3299	Economy	6300.00
0005433506949	3299	Economy	6300.00
0005433804962	3299	Economy	6300.00
0005433804939	3299	Economy	6300.00
0005433804964	3299	Economy	6300.00
0005433506951	3299	Economy	6300.00
0005433633407	3299	Economy	6300.00
0005435884372	3300	Business	18800.00
0005435884463	3300	Business	18800.00
0005435884476	3300	Economy	6300.00
0005435884465	3300	Economy	6300.00
0005435884373	3300	Economy	6300.00
0005435884477	3300	Economy	6300.00
0005435884464	3300	Economy	6300.00
0005435884462	3300	Economy	6300.00
0005435884375	3300	Economy	6300.00
0005435884399	3300	Economy	6300.00
0005435884387	3300	Economy	6300.00
0005435884417	3300	Economy	6300.00
0005435884374	3300	Economy	6900.00
0005435884478	3300	Economy	6300.00
0005435884473	3300	Economy	6300.00
0005435884577	3300	Economy	6300.00
0005432459257	8166	Business	18800.00
0005435884642	8166	Business	18800.00
0005432459238	8166	Business	18800.00
0005432459256	8166	Business	18800.00
0005432459269	8166	Business	18800.00
0005435884664	8166	Business	18800.00
0005435884659	8166	Business	18800.00
0005435884631	8166	Business	18800.00
0005435884635	8166	Business	18800.00
0005432042538	8166	Business	18800.00
0005435884653	8166	Business	18800.00
0005432042548	8166	Business	18800.00
0005435884671	8166	Business	18800.00
0005432042540	8166	Business	18800.00
0005432042546	8166	Business	18800.00
0005435884657	8166	Business	18800.00
0005432459229	8166	Business	18800.00
0005435884623	8166	Business	18800.00
0005432459224	8166	Business	18800.00
0005432459240	8166	Business	18800.00
0005435884637	8166	Business	18800.00
0005432459270	8166	Business	18800.00
0005435884626	8166	Business	18800.00
0005435884656	8166	Economy	6900.00
0005432042552	8166	Economy	6900.00
0005432459276	8166	Economy	6900.00
0005432459262	8166	Economy	6900.00
0005435884674	8166	Economy	6900.00
0005435884628	8166	Economy	6300.00
0005432459268	8166	Economy	6300.00
0005435884640	8166	Economy	6300.00
0005432042551	8166	Economy	6300.00
0005432042541	8166	Economy	6300.00
0005434326262	8166	Economy	6300.00
0005435884672	8166	Economy	6300.00
0005435884662	8166	Economy	6300.00
0005435884636	8166	Economy	6300.00
0005435884639	8166	Economy	6300.00
0005433506867	8166	Economy	6300.00
0005432459228	8166	Economy	6300.00
0005435884673	8166	Economy	6300.00
0005432042547	8166	Economy	6300.00
0005432459227	8166	Economy	6300.00
0005432042539	8166	Economy	6300.00
0005432459265	8166	Economy	6300.00
0005435884675	8166	Economy	6300.00
0005432459241	8166	Economy	6300.00
0005432459245	8166	Economy	6300.00
0005432042545	8166	Economy	6300.00
0005433506884	8166	Economy	6300.00
0005432459233	8166	Economy	6300.00
0005432459243	8166	Economy	6300.00
0005432459267	8166	Economy	6300.00
0005435884625	8166	Economy	6300.00
0005432459251	8166	Economy	6300.00
0005435884630	8166	Economy	6300.00
0005432459263	8166	Economy	6300.00
0005432459258	8166	Economy	6300.00
0005432459244	8166	Economy	6300.00
0005435884638	8166	Economy	6300.00
0005435884648	8166	Economy	6300.00
0005432042544	8166	Economy	6300.00
0005432459271	8166	Economy	6300.00
0005435884670	8166	Economy	6300.00
0005432459255	8166	Economy	6300.00
0005435884669	8166	Economy	6300.00
0005435884665	8166	Economy	6300.00
0005432459272	8166	Economy	6300.00
0005435884651	8166	Economy	6300.00
0005433506883	8166	Economy	6300.00
0005435884654	8166	Economy	6300.00
0005432459260	8166	Economy	6300.00
0005435884663	8166	Economy	6300.00
0005435884652	8166	Economy	6300.00
0005432459254	8166	Economy	6300.00
0005432459232	8166	Economy	6300.00
0005432459264	8166	Economy	6900.00
0005432459274	8166	Economy	6900.00
0005432459236	8166	Economy	6900.00
0005432459253	8166	Economy	6900.00
0005432042550	8166	Economy	6900.00
0005432459234	8166	Economy	6300.00
0005435884624	8166	Economy	6300.00
0005432459266	8166	Economy	6300.00
0005435884667	8166	Economy	6300.00
0005432459230	8166	Economy	6900.00
0005432459223	8166	Economy	6300.00
0005435884644	8166	Economy	6300.00
0005435884634	8166	Economy	6300.00
0005435884643	8166	Economy	6300.00
0005432459246	8166	Economy	6300.00
0005432459249	8166	Economy	6300.00
0005435884641	8166	Economy	6300.00
0005432459235	8166	Economy	6300.00
0005435884646	8166	Economy	6300.00
0005432459225	8166	Economy	6300.00
0005435884629	8166	Economy	6300.00
0005432459231	8166	Economy	6300.00
0005435884666	8166	Economy	6300.00
0005435884632	8166	Economy	6300.00
0005435884645	8166	Economy	6300.00
0005432459248	8166	Economy	6300.00
0005435884660	8166	Economy	6300.00
0005435884661	8166	Economy	6300.00
0005435884622	8166	Economy	6300.00
0005435884627	8166	Economy	6300.00
0005432042543	8166	Economy	6300.00
0005432459242	8166	Economy	6300.00
0005432459252	8166	Economy	6300.00
0005432042549	8166	Economy	6300.00
0005432459237	8166	Economy	6300.00
0005432459239	8166	Economy	6300.00
0005435884650	8166	Economy	6300.00
0005435884658	8166	Economy	6300.00
0005432459250	8166	Economy	6300.00
0005432459273	8166	Economy	6300.00
0005432459226	8166	Economy	6300.00
0005434312295	8166	Economy	6300.00
0005435884668	8166	Economy	6300.00
0005434312294	8166	Economy	6300.00
0005435884633	8166	Economy	6300.00
0005432042542	8166	Economy	6300.00
0005434326263	8166	Economy	6300.00
0005435884655	8166	Economy	6300.00
0005432459261	8166	Economy	6300.00
0005432459259	8166	Economy	6300.00
0005435884647	8166	Economy	6300.00
0005432459247	8166	Economy	6300.00
0005432459275	8166	Economy	6300.00
0005435884649	8166	Economy	6300.00
0005433633216	8163	Economy	6300.00
0005433804780	8163	Economy	6300.00
0005433804792	8163	Economy	6300.00
0005433804879	8163	Economy	6300.00
0005433633217	8163	Economy	6300.00
0005433804779	8163	Economy	6300.00
0005432382710	4661	Business	9900.00
0005432727781	4661	Business	9900.00
0005432727786	4661	Business	9900.00
0005432727790	4661	Business	9900.00
0005433722138	4661	Business	9900.00
0005432382722	4661	Business	9900.00
0005432727782	4661	Business	9900.00
0005432382713	4661	Business	9900.00
0005432382706	4661	Business	9900.00
0005432382692	4661	Economy	3300.00
0005433722132	4661	Economy	3300.00
0005432382717	4661	Economy	3300.00
0005433454850	4661	Economy	3300.00
0005432382724	4661	Economy	3300.00
0005433722133	4661	Economy	3300.00
0005432382714	4661	Economy	3300.00
0005432382702	4661	Economy	3600.00
0005432382726	4661	Economy	3600.00
0005433454848	4661	Economy	3600.00
0005433194826	4661	Economy	3300.00
0005432382719	4661	Economy	3300.00
0005432382720	4661	Economy	3300.00
0005433453739	4661	Economy	3300.00
0005432382711	4661	Economy	3300.00
0005433453737	4661	Economy	3300.00
0005432382695	4661	Economy	3300.00
0005432382716	4661	Economy	3300.00
0005432727784	4661	Economy	3300.00
0005432382703	4661	Economy	3300.00
0005432727789	4661	Economy	3300.00
0005432382693	4661	Economy	3300.00
0005432382696	4661	Economy	3300.00
0005432382707	4661	Economy	3300.00
0005432382718	4661	Economy	3300.00
0005432727788	4661	Economy	3300.00
0005433454849	4661	Economy	3300.00
0005432382721	4661	Economy	3300.00
0005432382698	4661	Economy	3300.00
0005432382712	4661	Economy	3300.00
0005433453738	4661	Economy	3300.00
0005433194827	4661	Economy	3300.00
0005433722139	4661	Economy	3300.00
0005433722134	4661	Economy	3300.00
0005432382699	4661	Economy	3300.00
0005432727791	4661	Economy	3300.00
0005433722136	4661	Economy	3300.00
0005432727780	4661	Economy	3300.00
0005432382694	4661	Economy	3300.00
0005432382704	4661	Economy	3300.00
0005432382708	4661	Economy	3300.00
0005432382701	4661	Economy	3300.00
0005432382691	4661	Economy	3300.00
0005432727783	4661	Economy	3300.00
0005432382697	4661	Economy	3300.00
0005433722135	4661	Economy	3300.00
0005433722140	4661	Economy	3300.00
0005432382700	4661	Economy	3300.00
0005432382709	4661	Economy	3300.00
0005432382725	4661	Economy	3300.00
0005432382723	4661	Economy	3300.00
0005433722137	4661	Economy	3300.00
0005432382715	4661	Economy	3300.00
0005432727787	4661	Economy	3300.00
0005432727785	4661	Economy	3300.00
0005432382705	4661	Economy	3300.00
0005432727759	30189	Business	9900.00
0005432727732	30189	Economy	3300.00
0005432727723	30189	Economy	3300.00
0005432727733	30189	Economy	3300.00
0005432727741	30189	Economy	3300.00
0005435528999	1760	Business	57200.00
0005435529000	1760	Business	57200.00
0005433516775	1760	Business	57200.00
0005435540734	1760	Business	57200.00
0005435540752	1760	Business	57200.00
0005435540748	1760	Business	57200.00
0005435528989	1760	Business	57200.00
0005435528991	1760	Business	57200.00
0005435540739	1760	Business	57200.00
0005435528996	1760	Business	57200.00
0005435529002	1760	Economy	19100.00
0005435529009	1760	Economy	19100.00
0005435540736	1760	Economy	19100.00
0005435529006	1760	Economy	19100.00
0005435528993	1760	Economy	19100.00
0005435540743	1760	Economy	21000.00
0005435529003	1760	Economy	21000.00
0005433516772	1760	Economy	21000.00
0005435528992	1760	Economy	19100.00
0005435540741	1760	Economy	19100.00
0005432294459	1760	Economy	19100.00
0005435540750	1760	Economy	19100.00
0005433516774	1760	Economy	19100.00
0005435540745	1760	Economy	19100.00
0005433516768	1760	Economy	19100.00
0005433516776	1760	Economy	19100.00
0005435528998	1760	Economy	19100.00
0005433516777	1760	Economy	19100.00
0005433516771	1760	Economy	19100.00
0005435529010	1760	Economy	19100.00
0005435540737	1760	Economy	19100.00
0005435540754	1760	Economy	19100.00
0005435540740	1760	Economy	19100.00
0005432294457	1760	Economy	19100.00
0005435540735	1760	Economy	19100.00
0005435529001	1760	Economy	19100.00
0005435540744	1760	Economy	19100.00
0005435528997	1760	Economy	19100.00
0005435529005	1760	Economy	19100.00
0005435540753	1760	Economy	19100.00
0005433516770	1760	Economy	19100.00
0005435528995	1760	Economy	19100.00
0005433516769	1760	Economy	19100.00
0005435540746	1760	Economy	19100.00
0005435540738	1760	Economy	19100.00
0005435528990	1760	Economy	19100.00
0005432294458	1760	Economy	19100.00
0005435529007	1760	Economy	19100.00
0005435528994	1760	Economy	19100.00
0005435540747	1760	Economy	19100.00
0005435529004	1760	Economy	19100.00
0005435540755	1760	Economy	19100.00
0005433516773	1760	Economy	19100.00
0005435540751	1760	Economy	19100.00
0005435540749	1760	Economy	19100.00
0005435540742	1760	Economy	19100.00
0005435529008	1760	Economy	19100.00
0005433516721	22025	Business	57200.00
0005432924981	22025	Economy	19100.00
0005432924977	22025	Economy	19100.00
0005432924978	22025	Economy	19100.00
0005432924979	22025	Economy	19100.00
0005432924980	22025	Economy	19100.00
0005432838654	7400	Business	18500.00
0005432838656	7400	Business	18500.00
0005432838645	7400	Business	18500.00
0005432838650	7400	Business	18500.00
0005432838665	7400	Business	18500.00
0005434458555	7400	Business	18500.00
0005432838667	7400	Business	18500.00
0005432838658	7400	Business	18500.00
0005432838652	7400	Business	18500.00
0005432838666	7400	Economy	6200.00
0005434458548	7400	Economy	6200.00
0005432073348	7400	Economy	6200.00
0005434458546	7400	Economy	6200.00
0005434458550	7400	Economy	6200.00
0005434458549	7400	Economy	6200.00
0005432823424	7400	Economy	6200.00
0005432838664	7400	Economy	6800.00
0005432838660	7400	Economy	6800.00
0005432840986	7400	Economy	6800.00
0005434458560	7400	Economy	6800.00
0005432838644	7400	Economy	6800.00
0005432838663	7400	Economy	6200.00
0005432838646	7400	Economy	6200.00
0005432838647	7400	Economy	6200.00
0005432838669	7400	Economy	6200.00
0005432073349	7400	Economy	6200.00
0005434458541	7400	Economy	6200.00
0005434458558	7400	Economy	6200.00
0005434458544	7400	Economy	6200.00
0005432838670	7400	Economy	6200.00
0005432838649	7400	Economy	6200.00
0005434458547	7400	Economy	6200.00
0005434458552	7400	Economy	6200.00
0005434458540	7400	Economy	6200.00
0005434458554	7400	Economy	6200.00
0005432838668	7400	Economy	6200.00
0005434458556	7400	Economy	6200.00
0005432838642	7400	Economy	6200.00
0005432838651	7400	Economy	6200.00
0005434458551	7400	Economy	6200.00
0005432838659	7400	Economy	6200.00
0005434458557	7400	Economy	6200.00
0005432838643	7400	Economy	6200.00
0005432838661	7400	Economy	6200.00
0005432838662	7400	Economy	6200.00
0005432838671	7400	Economy	6200.00
0005434458545	7400	Economy	6200.00
0005432073347	7400	Economy	6200.00
0005435252378	7400	Economy	6200.00
0005432840985	7400	Economy	6200.00
0005432838648	7400	Economy	6200.00
0005432838655	7400	Economy	6200.00
0005434458543	7400	Economy	6200.00
0005434458553	7400	Economy	6200.00
0005432838641	7400	Economy	6200.00
0005432073346	7400	Economy	6200.00
0005432838653	7400	Economy	6200.00
0005434458542	7400	Economy	6200.00
0005434458559	7400	Economy	6200.00
0005432838657	7400	Economy	6200.00
0005432838516	28904	Business	18500.00
0005432000998	28904	Business	18500.00
0005435252484	28904	Business	18500.00
0005435252476	28904	Business	18500.00
0005435252472	28904	Economy	6200.00
0005435252475	28904	Economy	6200.00
0005435252479	28904	Economy	6200.00
0005432838536	28904	Economy	6800.00
0005432838512	28904	Economy	6200.00
0005435252482	28904	Economy	6200.00
0005434664932	28904	Economy	6200.00
0005435252474	28904	Economy	6200.00
0005435491415	28904	Economy	6200.00
0005435252490	28904	Economy	6200.00
0005435252483	28904	Economy	6200.00
0005432000999	28904	Economy	6200.00
0005432838489	28904	Economy	6200.00
0005435252478	28904	Economy	6200.00
0005432838571	28904	Economy	6200.00
0005432838517	28904	Economy	6200.00
0005432823415	28904	Economy	6200.00
0005435252488	28904	Economy	6200.00
0005435252477	28904	Economy	6200.00
0005435252480	28904	Economy	6200.00
0005435252489	28904	Economy	6200.00
0005432838490	28904	Economy	6200.00
0005432838572	28904	Economy	6200.00
0005435252485	28904	Economy	6200.00
0005434458465	28904	Economy	6200.00
0005432838482	28904	Economy	6200.00
0005435252473	28904	Economy	6200.00
0005434458464	28904	Economy	6200.00
0005435491416	28904	Economy	6200.00
0005435252481	28904	Economy	6200.00
0005432838570	28904	Economy	6200.00
0005435252486	28904	Economy	6200.00
0005435252487	28904	Economy	6200.00
0005432000997	28904	Economy	6200.00
0005434275925	8829	Business	145300.00
0005435990538	8829	Economy	48400.00
0005434275924	8829	Economy	48400.00
0005435990535	8829	Economy	48400.00
0005435990533	8829	Economy	48400.00
0005435990536	8829	Economy	48400.00
0005435990537	8829	Economy	48400.00
0005435990534	8829	Economy	48400.00
0005435990539	8829	Economy	48400.00
0005435990507	15770	Business	145300.00
0005434275957	15770	Economy	48400.00
0005434275956	15770	Economy	48400.00
0005434275953	15770	Economy	48400.00
0005434275958	15770	Economy	48400.00
0005434275954	15770	Economy	48400.00
0005434275955	15770	Economy	48400.00
0005435990498	15770	Economy	48400.00
0005433468227	2091	Economy	13300.00
0005433468213	2091	Economy	13300.00
0005433468209	2091	Economy	13300.00
0005433468210	2091	Economy	12100.00
0005433468211	2091	Economy	12100.00
0005433468226	2091	Economy	12100.00
0005433468216	2091	Economy	12100.00
0005433468228	2091	Economy	12100.00
0005433468215	2091	Economy	12100.00
0005433468230	2091	Economy	12100.00
0005433468225	2091	Economy	12100.00
0005433468222	2091	Economy	12100.00
0005433468232	2091	Economy	12100.00
0005433468220	2091	Economy	12100.00
0005433468214	2091	Economy	12100.00
0005433468212	2091	Economy	12100.00
0005433468231	2091	Economy	12100.00
0005433468207	2091	Economy	12100.00
0005433468224	2091	Economy	12100.00
0005433468219	2091	Economy	12100.00
0005433468233	2091	Economy	12100.00
0005433468221	2091	Economy	12100.00
0005433468223	2091	Economy	12100.00
0005433468229	2091	Economy	12100.00
0005433468217	2091	Economy	12100.00
0005433468218	2091	Economy	12100.00
0005433468208	2091	Economy	12100.00
0005432359765	6384	Business	36600.00
0005432359756	6384	Business	36600.00
0005432359758	6384	Business	36600.00
0005432359796	6384	Business	36600.00
0005432359771	6384	Business	36600.00
0005432335891	6384	Business	36600.00
0005434149525	6384	Business	36600.00
0005432335888	6384	Business	36600.00
0005432335881	6384	Economy	12200.00
0005432359768	6384	Economy	12200.00
0005432335883	6384	Economy	12200.00
0005432359788	6384	Economy	12200.00
0005432359790	6384	Economy	12200.00
0005432359772	6384	Economy	12200.00
0005432359792	6384	Economy	12200.00
0005432359773	6384	Economy	12200.00
0005432359763	6384	Economy	12200.00
0005435176606	6384	Economy	12200.00
0005432359799	6384	Economy	12200.00
0005432359795	6384	Economy	12200.00
0005432359779	6384	Economy	12200.00
0005432335894	6384	Economy	12200.00
0005432359786	6384	Economy	12200.00
0005432359787	6384	Economy	12200.00
0005432335892	6384	Economy	12200.00
0005432062163	6384	Economy	12200.00
0005432359757	6384	Economy	12200.00
0005432359780	6384	Economy	12200.00
0005432335885	6384	Economy	12200.00
0005432363375	6384	Economy	12200.00
0005432359783	6384	Economy	12200.00
0005432335887	6384	Economy	13400.00
0005432363374	6384	Economy	13400.00
0005432359769	6384	Economy	13400.00
0005432359791	6384	Economy	13400.00
0005432062165	6384	Economy	12200.00
0005432062162	6384	Economy	12200.00
0005432335886	6384	Economy	12200.00
0005432335890	6384	Economy	12200.00
0005432359760	6384	Economy	12200.00
0005432359781	6384	Economy	12200.00
0005432359762	6384	Economy	12200.00
0005435176598	6384	Economy	12200.00
0005432359754	6384	Economy	12200.00
0005432359789	6384	Economy	12200.00
0005432359794	6384	Economy	12200.00
0005432359784	6384	Economy	12200.00
0005432062164	6384	Economy	12200.00
0005432359798	6384	Economy	12200.00
0005432335882	6384	Economy	12200.00
0005432062161	6384	Economy	12200.00
0005435176630	6384	Economy	12200.00
0005432359797	6384	Economy	12200.00
0005432359778	6384	Economy	12200.00
0005432359785	6384	Economy	12200.00
0005432359793	6384	Economy	12200.00
0005435176629	6384	Economy	12200.00
0005432359774	6384	Economy	12200.00
0005432359782	6384	Economy	12200.00
0005432359767	6384	Economy	12200.00
0005432359777	6384	Economy	12200.00
0005432359800	6384	Economy	12200.00
0005432335889	6384	Economy	12200.00
0005432359753	6384	Economy	12200.00
0005432359761	6384	Economy	12200.00
0005432363376	6384	Economy	12200.00
0005432335893	6384	Economy	12200.00
0005432359766	6384	Economy	12200.00
0005432359759	6384	Economy	12200.00
0005432359776	6384	Economy	12200.00
0005432359755	6384	Economy	12200.00
0005432335884	6384	Economy	12200.00
0005432359775	6384	Economy	12200.00
0005432359770	6384	Economy	12200.00
0005432359764	6384	Economy	12200.00
0005435176607	6384	Economy	12200.00
0005435176730	20981	Business	36600.00
0005435176726	20981	Business	36600.00
0005435176754	20981	Business	36600.00
0005435176740	20981	Business	36600.00
0005435176736	20981	Business	36600.00
0005435723022	20981	Business	36600.00
0005435176739	20981	Business	36600.00
0005435176731	20981	Business	36600.00
0005435176729	20981	Business	36600.00
0005434149590	20981	Economy	12200.00
0005434149591	20981	Economy	12200.00
0005434149588	20981	Economy	12200.00
0005435490187	20981	Economy	12200.00
0005435176741	20981	Economy	12200.00
0005434149592	20981	Economy	12200.00
0005435176732	20981	Economy	12200.00
0005435176744	20981	Economy	12200.00
0005435176727	20981	Economy	12200.00
0005435176750	20981	Economy	12200.00
0005435176749	20981	Economy	12200.00
0005434149587	20981	Economy	12200.00
0005435176735	20981	Economy	12200.00
0005435176734	20981	Economy	12200.00
0005434149586	20981	Economy	12200.00
0005435176752	20981	Economy	12200.00
0005432052709	20981	Economy	12200.00
0005435176748	20981	Economy	13400.00
0005432359583	20981	Economy	12200.00
0005435176755	20981	Economy	12200.00
0005435176753	20981	Economy	12200.00
0005434149582	20981	Economy	12200.00
0005435176738	20981	Economy	12200.00
0005434149580	20981	Economy	12200.00
0005435723021	20981	Economy	12200.00
0005435176737	20981	Economy	12200.00
0005432359582	20981	Economy	12200.00
0005434149589	20981	Economy	12200.00
0005435176742	20981	Economy	12200.00
0005435176728	20981	Economy	12200.00
0005435176743	20981	Economy	12200.00
0005432359529	20981	Economy	12200.00
0005434149584	20981	Economy	12200.00
0005434149585	20981	Economy	12200.00
0005435176733	20981	Economy	12200.00
0005435176751	20981	Economy	12200.00
0005434149583	20981	Economy	12200.00
0005435176745	20981	Economy	12200.00
0005432359588	20981	Economy	12200.00
0005435723020	20981	Economy	12200.00
0005435490186	20981	Economy	12200.00
0005435490185	20981	Economy	12200.00
0005435176747	20981	Economy	12200.00
0005435176746	20981	Economy	12200.00
0005434149581	20981	Economy	12200.00
0005434458471	17740	Economy	3400.00
0005434186163	17740	Economy	3100.00
0005434186164	17740	Economy	3100.00
0005434458490	17740	Economy	3100.00
0005434448259	17740	Economy	3100.00
0005434458439	17740	Economy	3100.00
0005434458453	17740	Economy	3100.00
0005434458438	17740	Economy	3100.00
0005434448260	17740	Economy	3100.00
0005434463902	29080	Economy	3400.00
0005434458555	29080	Economy	3400.00
0005434458559	29080	Economy	3400.00
0005434458557	29080	Economy	3100.00
0005434458545	29080	Economy	3100.00
0005434458550	29080	Economy	3100.00
0005434448270	29080	Economy	3100.00
0005434458552	29080	Economy	3100.00
0005434458554	29080	Economy	3100.00
0005434458548	29080	Economy	3100.00
0005434463900	29080	Economy	3100.00
0005434462762	29080	Economy	3100.00
0005434458553	29080	Economy	3100.00
0005434458556	29080	Economy	3100.00
0005434458549	29080	Economy	3100.00
0005434458546	29080	Economy	3100.00
0005434458541	29080	Economy	3100.00
0005434458543	29080	Economy	3100.00
0005434462761	29080	Economy	3100.00
0005434448269	29080	Economy	3100.00
0005434462763	29080	Economy	3100.00
0005434458540	29080	Economy	3100.00
0005434458558	29080	Economy	3100.00
0005434458542	29080	Economy	3100.00
0005434458547	29080	Economy	3100.00
0005434458551	29080	Economy	3100.00
0005434463901	29080	Economy	3100.00
0005434458544	29080	Economy	3100.00
0005434458560	29080	Economy	3100.00
0005434448268	29080	Economy	3100.00
0005432603815	21437	Economy	7300.00
0005432603822	21437	Economy	7300.00
0005432603826	21437	Economy	7300.00
0005432603810	21437	Economy	6600.00
0005432603807	21437	Economy	6600.00
0005432603811	21437	Economy	6600.00
0005432603827	21437	Economy	6600.00
0005432603805	21437	Economy	6600.00
0005432603838	21437	Economy	6600.00
0005432603834	21437	Economy	6600.00
0005432603843	21437	Economy	6600.00
0005432603804	21437	Economy	6600.00
0005432603806	21437	Economy	6600.00
0005432603823	21437	Economy	6600.00
0005432603830	21437	Economy	6600.00
0005432603812	21437	Economy	6600.00
0005432603820	21437	Economy	6600.00
0005432603824	21437	Economy	6600.00
0005432603837	21437	Economy	6600.00
0005432603841	21437	Economy	6600.00
0005432603819	21437	Economy	6600.00
0005432603818	21437	Economy	6600.00
0005432603816	21437	Economy	6600.00
0005432603833	21437	Economy	6600.00
0005432603839	21437	Economy	6600.00
0005432603842	21437	Economy	6600.00
0005432603831	21437	Economy	6600.00
0005432603829	21437	Economy	6600.00
0005432603817	21437	Economy	6600.00
0005432603840	21437	Economy	6600.00
0005432603821	21437	Economy	6600.00
0005432603814	21437	Economy	6600.00
0005432603836	21437	Economy	6600.00
0005432603809	21437	Economy	6600.00
0005432603835	21437	Economy	6600.00
0005432603828	21437	Economy	6600.00
0005432603813	21437	Economy	6600.00
0005432603808	21437	Economy	6600.00
0005432603825	21437	Economy	6600.00
0005432603832	21437	Economy	6600.00
0005435221043	31658	Economy	6600.00
0005432603657	31658	Economy	6600.00
0005432603675	31658	Economy	6600.00
0005435221042	31658	Economy	6600.00
0005435221041	31658	Economy	6600.00
0005432603676	31658	Economy	6600.00
0005435221503	31658	Economy	6600.00
0005435904889	18820	Economy	6600.00
0005434604850	22317	Economy	6600.00
0005434604852	22317	Economy	6600.00
0005434606780	22317	Economy	6600.00
0005434606778	22317	Economy	6600.00
0005434606776	22317	Economy	6600.00
0005434604849	22317	Economy	6600.00
0005434604853	22317	Economy	6600.00
0005434606781	22317	Economy	6600.00
0005434606779	22317	Economy	6600.00
0005434604851	22317	Economy	6600.00
0005434606777	22317	Economy	6600.00
0005432747070	399	Business	44500.00
0005432747092	399	Business	44500.00
0005432747096	399	Business	44500.00
0005432747063	399	Business	44500.00
0005432747100	399	Business	44500.00
0005432747082	399	Economy	14800.00
0005432747088	399	Economy	14800.00
0005432751481	399	Economy	14800.00
0005432747079	399	Economy	14800.00
0005432749755	399	Economy	14800.00
0005432747068	399	Economy	14800.00
0005432747085	399	Economy	16300.00
0005432747074	399	Economy	16300.00
0005432747089	399	Economy	16300.00
0005432747078	399	Economy	14800.00
0005432753256	399	Economy	14800.00
0005432219951	399	Economy	14800.00
0005432747064	399	Economy	14800.00
0005432747080	399	Economy	14800.00
0005432747069	399	Economy	14800.00
0005432747087	399	Economy	14800.00
0005432747083	399	Economy	14800.00
0005432219947	399	Economy	14800.00
0005432747076	399	Economy	14800.00
0005432753258	399	Economy	14800.00
0005432747075	399	Economy	14800.00
0005432747062	399	Economy	14800.00
0005432747094	399	Economy	14800.00
0005432747077	399	Economy	14800.00
0005432747095	399	Economy	14800.00
0005432747084	399	Economy	14800.00
0005432747081	399	Economy	14800.00
0005432747071	399	Economy	14800.00
0005432219948	399	Economy	14800.00
0005432753257	399	Economy	14800.00
0005432747097	399	Economy	14800.00
0005432747086	399	Economy	14800.00
0005432753255	399	Economy	14800.00
0005432747066	399	Economy	14800.00
0005432749756	399	Economy	14800.00
0005432751483	399	Economy	14800.00
0005432747073	399	Economy	14800.00
0005432751482	399	Economy	14800.00
0005432219950	399	Economy	14800.00
0005432747098	399	Economy	14800.00
0005432747091	399	Economy	14800.00
0005432747093	399	Economy	14800.00
0005432747067	399	Economy	14800.00
0005432747065	399	Economy	14800.00
0005432219949	399	Economy	14800.00
0005432747090	399	Economy	14800.00
0005432747072	399	Economy	14800.00
0005432747099	399	Economy	14800.00
0005433293164	12079	Business	44500.00
0005432890772	12079	Business	44500.00
0005434153520	12079	Business	44500.00
0005432890779	12079	Business	44500.00
0005432890780	12079	Business	44500.00
0005433293168	12079	Business	44500.00
0005433293173	12079	Business	44500.00
0005432890783	12079	Economy	14800.00
0005432890781	12079	Economy	14800.00
0005433293170	12079	Economy	14800.00
0005432890788	12079	Economy	14800.00
0005433293174	12079	Economy	16300.00
0005433875360	12079	Economy	16300.00
0005433293169	12079	Economy	16300.00
0005433293165	12079	Economy	14800.00
0005432890778	12079	Economy	14800.00
0005432746902	12079	Economy	14800.00
0005432890776	12079	Economy	14800.00
0005432890769	12079	Economy	14800.00
0005432214777	12079	Economy	14800.00
0005433293175	12079	Economy	14800.00
0005433875362	12079	Economy	14800.00
0005432890773	12079	Economy	14800.00
0005432890770	12079	Economy	14800.00
0005432746887	12079	Economy	14800.00
0005432746932	12079	Economy	14800.00
0005432890787	12079	Economy	14800.00
0005432746930	12079	Economy	14800.00
0005432890777	12079	Economy	14800.00
0005433293177	12079	Economy	14800.00
0005433293171	12079	Economy	14800.00
0005433293172	12079	Economy	14800.00
0005433293167	12079	Economy	14800.00
0005432746890	12079	Economy	14800.00
0005433293166	12079	Economy	14800.00
0005433293176	12079	Economy	14800.00
0005432890775	12079	Economy	14800.00
0005432890771	12079	Economy	14800.00
0005432890785	12079	Economy	14800.00
0005432890786	12079	Economy	14800.00
0005433875363	12079	Economy	14800.00
0005432890774	12079	Economy	14800.00
0005433875361	12079	Economy	14800.00
0005432890782	12079	Economy	14800.00
0005432890784	12079	Economy	14800.00
0005434153519	12079	Economy	14800.00
0005432746929	12079	Economy	14800.00
0005433524898	18982	Economy	28200.00
0005433524900	18982	Economy	25700.00
0005433531244	18982	Economy	25700.00
0005433533257	18982	Economy	25700.00
0005433524896	18982	Economy	25700.00
0005433531241	18982	Economy	25700.00
0005433524891	18982	Economy	25700.00
0005433524892	18982	Economy	25700.00
0005433533258	18982	Economy	25700.00
0005433531242	18982	Economy	25700.00
0005433524893	18982	Economy	25700.00
0005433524890	18982	Economy	25700.00
0005433524895	18982	Economy	25700.00
0005433524899	18982	Economy	25700.00
0005433524894	18982	Economy	25700.00
0005433533259	18982	Economy	25700.00
0005433531243	18982	Economy	25700.00
0005433524897	18982	Economy	25700.00
0005432927919	32514	Economy	25700.00
0005432927916	32514	Economy	25700.00
0005433524855	32514	Economy	25700.00
0005432927920	32514	Economy	25700.00
0005432927918	32514	Economy	25700.00
0005432927917	32514	Economy	25700.00
0005433524856	32514	Economy	25700.00
0005432927915	32514	Economy	25700.00
0005432927914	32514	Economy	25700.00
0005432121160	5260	Business	84000.00
0005434821999	5260	Business	84000.00
0005434821977	5260	Business	84000.00
0005432121156	5260	Business	84000.00
0005434822070	5260	Business	84000.00
0005434821983	5260	Business	84000.00
0005434822043	5260	Business	84000.00
0005434822027	5260	Business	84000.00
0005434821966	5260	Business	84000.00
0005434822075	5260	Business	84000.00
0005434822048	5260	Business	84000.00
0005434822060	5260	Business	84000.00
0005434822038	5260	Comfort	47600.00
0005434822078	5260	Business	84000.00
0005434822037	5260	Comfort	47600.00
0005434822051	5260	Comfort	47600.00
0005434822042	5260	Comfort	47600.00
0005434822014	5260	Comfort	47600.00
0005434558179	5260	Comfort	47600.00
0005434821987	5260	Comfort	47600.00
0005434822049	5260	Comfort	47600.00
0005434822044	5260	Comfort	47600.00
0005434822007	5260	Comfort	47600.00
0005434822085	5260	Comfort	47600.00
0005434822087	5260	Comfort	47600.00
0005432396194	5260	Comfort	47600.00
0005435149869	5260	Comfort	47600.00
0005434822056	5260	Comfort	47600.00
0005434558174	5260	Comfort	47600.00
0005434822024	5260	Comfort	47600.00
0005435372150	5260	Comfort	47600.00
0005432121159	5260	Comfort	47600.00
0005434822068	5260	Comfort	47600.00
0005434822004	5260	Comfort	47600.00
0005434821997	5260	Comfort	47600.00
0005434822018	5260	Economy	28000.00
0005434821964	5260	Economy	28000.00
0005434821972	5260	Economy	28000.00
0005434822036	5260	Economy	28000.00
0005434821996	5260	Economy	28000.00
0005435149862	5260	Economy	28000.00
0005434821969	5260	Economy	28000.00
0005434822017	5260	Economy	28000.00
0005432121165	5260	Economy	28000.00
0005434831086	5260	Economy	28000.00
0005432121161	5260	Economy	28000.00
0005434664931	5260	Economy	28000.00
0005434822019	5260	Economy	28000.00
0005435372250	5260	Economy	28000.00
0005434822032	5260	Economy	28000.00
0005434822055	5260	Economy	28000.00
0005434822011	5260	Economy	28000.00
0005434558175	5260	Economy	28000.00
0005435149857	5260	Economy	28000.00
0005434822025	5260	Economy	28000.00
0005434821979	5260	Economy	28000.00
0005434821982	5260	Economy	28000.00
0005435372249	5260	Economy	28000.00
0005434822054	5260	Economy	28000.00
0005434822012	5260	Economy	28000.00
0005434822015	5260	Economy	28000.00
0005434828661	5260	Economy	28000.00
0005435149861	5260	Economy	28000.00
0005435149866	5260	Economy	28000.00
0005434822080	5260	Economy	28000.00
0005432121157	5260	Economy	28000.00
0005434821975	5260	Economy	28000.00
0005434822086	5260	Economy	28000.00
0005434822063	5260	Economy	30800.00
0005434822059	5260	Economy	28000.00
0005434822076	5260	Economy	28000.00
0005435149859	5260	Economy	28000.00
0005435149856	5260	Economy	28000.00
0005434821968	5260	Economy	28000.00
0005435372145	5260	Economy	28000.00
0005434831088	5260	Economy	28000.00
0005434821973	5260	Economy	28000.00
0005435149860	5260	Economy	28000.00
0005434821985	5260	Economy	28000.00
0005434822003	5260	Economy	28000.00
0005432121158	5260	Economy	28000.00
0005434822035	5260	Economy	28000.00
0005432121163	5260	Economy	28000.00
0005434822047	5260	Economy	28000.00
0005434822021	5260	Economy	28000.00
0005432396193	5260	Economy	28000.00
0005434822072	5260	Economy	28000.00
0005434822009	5260	Economy	28000.00
0005432394053	5260	Economy	28000.00
0005434822079	5260	Economy	28000.00
0005434822000	5260	Economy	28000.00
0005434822084	5260	Economy	28000.00
0005434822064	5260	Economy	28000.00
0005432121166	5260	Economy	28000.00
0005434822071	5260	Economy	28000.00
0005434822001	5260	Economy	28000.00
0005434822058	5260	Economy	28000.00
0005434822088	5260	Economy	28000.00
0005435149867	5260	Economy	28000.00
0005434558171	5260	Economy	28000.00
0005432394056	5260	Economy	28000.00
0005434822028	5260	Economy	28000.00
0005434822030	5260	Economy	28000.00
0005434822090	5260	Economy	28000.00
0005434831089	5260	Economy	28000.00
0005434821994	5260	Economy	28000.00
0005432121162	5260	Economy	28000.00
0005435149865	5260	Economy	28000.00
0005434822033	5260	Economy	28000.00
0005434822089	5260	Economy	28000.00
0005434822077	5260	Economy	28000.00
0005434822005	5260	Economy	28000.00
0005434821976	5260	Economy	28000.00
0005434558178	5260	Economy	28000.00
0005434822010	5260	Economy	28000.00
0005434821965	5260	Economy	28000.00
0005432121167	5260	Economy	28000.00
0005434821984	5260	Economy	28000.00
0005434822081	5260	Economy	28000.00
0005434821986	5260	Economy	28000.00
0005435149863	5260	Economy	28000.00
0005435304098	5260	Economy	28000.00
0005434558173	5260	Economy	28000.00
0005434821962	5260	Economy	28000.00
0005434822029	5260	Economy	28000.00
0005434822006	5260	Economy	28000.00
0005434822016	5260	Economy	28000.00
0005434822065	5260	Economy	28000.00
0005434828660	5260	Economy	28000.00
0005435372281	5260	Economy	28000.00
0005434821967	5260	Economy	28000.00
0005434822046	5260	Economy	28000.00
0005434822002	5260	Economy	28000.00
0005432121155	5260	Economy	28000.00
0005434822083	5260	Economy	28000.00
0005434822008	5260	Economy	30800.00
0005434822026	5260	Economy	28000.00
0005432394055	5260	Economy	28000.00
0005434822069	5260	Economy	28000.00
0005435149868	5260	Economy	28000.00
0005434822045	5260	Economy	28000.00
0005435372279	5260	Economy	28000.00
0005432121164	5260	Economy	28000.00
0005434822040	5260	Economy	28000.00
0005435149858	5260	Economy	28000.00
0005434822067	5260	Economy	28000.00
0005434822061	5260	Economy	28000.00
0005435372280	5260	Economy	28000.00
0005434821978	5260	Economy	28000.00
0005434822053	5260	Economy	28000.00
0005434822074	5260	Economy	28000.00
0005434821963	5260	Economy	28000.00
0005434822050	5260	Economy	28000.00
0005434821998	5260	Economy	28000.00
0005434558172	5260	Economy	28000.00
0005434822062	5260	Economy	28000.00
0005434831087	5260	Economy	28000.00
0005435372159	5260	Economy	28000.00
0005435372190	5260	Economy	28000.00
0005434821990	5260	Economy	28000.00
0005434821970	5260	Economy	28000.00
0005434828659	5260	Economy	28000.00
0005434822082	5260	Economy	28000.00
0005434821989	5260	Economy	28000.00
0005434821995	5260	Economy	28000.00
0005434821971	5260	Economy	28000.00
0005434821992	5260	Economy	28000.00
0005432121168	5260	Economy	28000.00
0005434822031	5260	Economy	28000.00
0005435149864	5260	Economy	28000.00
0005434822023	5260	Economy	28000.00
0005434822039	5260	Economy	28000.00
0005432396195	5260	Economy	28000.00
0005434822034	5260	Economy	28000.00
0005432394054	5260	Economy	28000.00
0005434821988	5260	Economy	28000.00
0005434558176	5260	Economy	28000.00
0005432394052	5260	Economy	28000.00
0005434558177	5260	Economy	28000.00
0005434664930	5260	Economy	28000.00
0005434822020	5260	Economy	28000.00
0005434822022	5260	Economy	28000.00
0005434821993	5260	Economy	28000.00
0005434822057	5260	Economy	28000.00
0005434822066	5260	Economy	28000.00
0005434822073	5260	Economy	28000.00
0005434821980	5260	Economy	28000.00
0005434821981	5260	Economy	28000.00
0005434821991	5260	Economy	28000.00
0005434821974	5260	Economy	28000.00
0005434822052	5260	Economy	28000.00
0005435372146	5260	Economy	28000.00
0005432396192	5260	Economy	28000.00
0005434822041	5260	Economy	28000.00
0005434822013	5260	Economy	28000.00
0005435372476	9935	Business	84000.00
0005435372493	9935	Business	84000.00
0005435302141	9935	Business	84000.00
0005432396172	9935	Business	84000.00
0005435372465	9935	Business	84000.00
0005435302143	9935	Business	84000.00
0005435372445	9935	Business	84000.00
0005435386489	9935	Business	84000.00
0005435302140	9935	Business	84000.00
0005435299719	9935	Comfort	47600.00
0005435372490	9935	Comfort	47600.00
0005435299718	9935	Comfort	47600.00
0005435372456	9935	Comfort	47600.00
0005432823425	9935	Comfort	47600.00
0005435372458	9935	Comfort	47600.00
0005435661895	9935	Comfort	47600.00
0005435372453	9935	Comfort	47600.00
0005435372434	9935	Comfort	47600.00
0005434821409	9935	Comfort	47600.00
0005434821353	9935	Comfort	47600.00
0005434821669	9935	Comfort	47600.00
0005435302139	9935	Comfort	47600.00
0005432202973	9935	Comfort	47600.00
0005435372478	9935	Economy	28000.00
0005432823426	9935	Economy	28000.00
0005435302142	9935	Economy	28000.00
0005435386490	9935	Economy	28000.00
0005434821408	9935	Economy	28000.00
0005435735085	9935	Economy	28000.00
0005435299717	9935	Economy	28000.00
0005435372460	9935	Economy	28000.00
0005435372486	9935	Economy	28000.00
0005435372473	9935	Economy	28000.00
0005434821421	9935	Economy	28000.00
0005435372430	9935	Economy	28000.00
0005435386492	9935	Economy	28000.00
0005435372462	9935	Economy	28000.00
0005435372487	9935	Economy	28000.00
0005434821384	9935	Economy	28000.00
0005435735082	9935	Economy	28000.00
0005432202972	9935	Economy	28000.00
0005434821698	9935	Economy	28000.00
0005435735081	9935	Economy	28000.00
0005435372455	9935	Economy	28000.00
0005434821370	9935	Economy	28000.00
0005435386496	9935	Economy	28000.00
0005432202974	9935	Economy	28000.00
0005435372436	9935	Economy	30800.00
0005435372441	9935	Economy	28000.00
0005435372444	9935	Economy	28000.00
0005435372442	9935	Economy	28000.00
0005435661894	9935	Economy	28000.00
0005435299715	9935	Economy	28000.00
0005435372466	9935	Economy	28000.00
0005435372467	9935	Economy	28000.00
0005435372439	9935	Economy	28000.00
0005435386493	9935	Economy	28000.00
0005435372435	9935	Economy	28000.00
0005435386495	9935	Economy	28000.00
0005434821671	9935	Economy	28000.00
0005434821490	9935	Economy	28000.00
0005435372479	9935	Economy	28000.00
0005434821385	9935	Economy	28000.00
0005435372438	9935	Economy	28000.00
0005435372449	9935	Economy	28000.00
0005435372440	9935	Economy	28000.00
0005435372484	9935	Economy	28000.00
0005435372469	9935	Economy	28000.00
0005435372492	9935	Economy	28000.00
0005435372489	9935	Economy	28000.00
0005435372431	9935	Economy	28000.00
0005435372452	9935	Economy	28000.00
0005435372472	9935	Economy	28000.00
0005435372428	9935	Economy	28000.00
0005435372446	9935	Economy	28000.00
0005435372426	9935	Economy	28000.00
0005435372432	9935	Economy	28000.00
0005435735083	9935	Economy	28000.00
0005435372450	9935	Economy	28000.00
0005435386491	9935	Economy	28000.00
0005432202977	9935	Economy	28000.00
0005434821410	9935	Economy	28000.00
0005435372468	9935	Economy	28000.00
0005435372483	9935	Economy	28000.00
0005435372461	9935	Economy	28000.00
0005435372448	9935	Economy	28000.00
0005434821394	9935	Economy	28000.00
0005432202975	9935	Economy	28000.00
0005435372447	9935	Economy	28000.00
0005435372491	9935	Economy	30800.00
0005435661896	9935	Economy	28000.00
0005435372485	9935	Economy	28000.00
0005432202971	9935	Economy	28000.00
0005435372480	9935	Economy	28000.00
0005435372464	9935	Economy	28000.00
0005435372457	9935	Economy	28000.00
0005435372429	9935	Economy	28000.00
0005434821378	9935	Economy	28000.00
0005432202970	9935	Economy	28000.00
0005435372451	9935	Economy	28000.00
0005435372437	9935	Economy	28000.00
0005432396170	9935	Economy	28000.00
0005432396171	9935	Economy	28000.00
0005435372471	9935	Economy	28000.00
0005435386494	9935	Economy	28000.00
0005434821395	9935	Economy	28000.00
0005435372481	9935	Economy	28000.00
0005432202976	9935	Economy	28000.00
0005435372474	9935	Economy	28000.00
0005435372470	9935	Economy	28000.00
0005435735084	9935	Economy	28000.00
0005432202978	9935	Economy	28000.00
0005435372443	9935	Economy	28000.00
0005435372433	9935	Economy	28000.00
0005435372454	9935	Economy	28000.00
0005435372463	9935	Economy	28000.00
0005435372427	9935	Economy	28000.00
0005435299716	9935	Economy	28000.00
0005435372488	9935	Economy	28000.00
0005434821393	9935	Economy	28000.00
0005435372459	9935	Economy	28000.00
0005435372475	9935	Economy	28000.00
0005435386497	9935	Economy	28000.00
0005435372482	9935	Economy	28000.00
0005435372477	9935	Economy	28000.00
0005434821555	9935	Economy	28000.00
0005435082686	7016	Economy	8200.00
0005435082689	7016	Economy	7400.00
0005435082690	7016	Economy	7400.00
0005435082692	7016	Economy	7400.00
0005435790271	7016	Economy	7400.00
0005435082688	7016	Economy	7400.00
0005435082693	7016	Economy	7400.00
0005435082684	7016	Economy	7400.00
0005435082694	7016	Economy	7400.00
0005435082691	7016	Economy	7400.00
0005435082685	7016	Economy	7400.00
0005435790270	7016	Economy	7400.00
0005435082687	7016	Economy	7400.00
0005435082643	26017	Economy	8200.00
0005435082648	26017	Economy	7400.00
0005435082649	26017	Economy	7400.00
0005434755942	9526	Business	32800.00
0005434755945	9526	Business	32800.00
0005434755949	9526	Business	32800.00
0005434755929	9526	Economy	10900.00
0005434755953	9526	Economy	10900.00
0005434755923	9526	Economy	10900.00
0005434755926	9526	Economy	12000.00
0005434755938	9526	Economy	12000.00
0005434755935	9526	Economy	12000.00
0005434755956	9526	Economy	12000.00
0005434755939	9526	Economy	10900.00
0005434755957	9526	Economy	10900.00
0005434755958	9526	Economy	10900.00
0005434755952	9526	Economy	10900.00
0005434755930	9526	Economy	10900.00
0005434755931	9526	Economy	10900.00
0005434755960	9526	Economy	10900.00
0005434755955	9526	Economy	10900.00
0005434755959	9526	Economy	10900.00
0005434755944	9526	Economy	10900.00
0005434755922	9526	Economy	10900.00
0005434755941	9526	Economy	10900.00
0005434755936	9526	Economy	10900.00
0005434755951	9526	Economy	10900.00
0005434755937	9526	Economy	10900.00
0005434755927	9526	Economy	10900.00
0005434755948	9526	Economy	10900.00
0005434213705	9526	Economy	10900.00
0005434213712	9526	Economy	10900.00
0005434755947	9526	Economy	10900.00
0005434755940	9526	Economy	10900.00
0005434755925	9526	Economy	10900.00
0005434213706	9526	Economy	10900.00
0005434755933	9526	Economy	10900.00
0005434755946	9526	Economy	10900.00
0005434755934	9526	Economy	10900.00
0005434755932	9526	Economy	10900.00
0005434755928	9526	Economy	10900.00
0005434755950	9526	Economy	10900.00
0005434755943	9526	Economy	10900.00
0005434755924	9526	Economy	10900.00
0005434755954	9526	Economy	10900.00
0005434213900	28620	Business	32800.00
0005434213920	28620	Business	32800.00
0005434213927	28620	Business	32800.00
0005434213921	28620	Business	32800.00
0005434213913	28620	Business	32800.00
0005434213935	28620	Business	32800.00
0005434213910	28620	Economy	10900.00
0005434213901	28620	Economy	10900.00
0005434213914	28620	Economy	10900.00
0005434213894	28620	Economy	10900.00
0005434213932	28620	Economy	12000.00
0005434213906	28620	Economy	12000.00
0005434213931	28620	Economy	12000.00
0005434213929	28620	Economy	10900.00
0005434213890	28620	Economy	10900.00
0005434213891	28620	Economy	10900.00
0005434213899	28620	Economy	10900.00
0005434213924	28620	Economy	10900.00
0005434213925	28620	Economy	10900.00
0005434213892	28620	Economy	10900.00
0005434213923	28620	Economy	10900.00
0005434213895	28620	Economy	10900.00
0005434213930	28620	Economy	10900.00
0005434213908	28620	Economy	10900.00
0005434213909	28620	Economy	10900.00
0005434213926	28620	Economy	10900.00
0005434213896	28620	Economy	10900.00
0005434213934	28620	Economy	10900.00
0005434213912	28620	Economy	10900.00
0005434213928	28620	Economy	10900.00
0005434213905	28620	Economy	10900.00
0005434213907	28620	Economy	10900.00
0005434213915	28620	Economy	10900.00
0005434213911	28620	Economy	10900.00
0005434213918	28620	Economy	10900.00
0005434213919	28620	Economy	10900.00
0005434213904	28620	Economy	10900.00
0005434213902	28620	Economy	10900.00
0005434213916	28620	Economy	10900.00
0005434213933	28620	Economy	10900.00
0005434213893	28620	Economy	10900.00
0005434213897	28620	Economy	10900.00
0005434213917	28620	Economy	10900.00
0005434213903	28620	Economy	10900.00
0005434213922	28620	Economy	10900.00
0005434213898	28620	Economy	10900.00
0005434213889	28620	Economy	10900.00
0005435100086	10851	Economy	8900.00
0005435100085	10851	Economy	8900.00
0005435100073	31839	Economy	9800.00
0005434760166	31839	Economy	8900.00
0005434760167	31839	Economy	8900.00
0005435100072	31839	Economy	8900.00
0005434639008	1970	Economy	20900.00
0005434639005	1970	Economy	20900.00
0005434639006	1970	Economy	19000.00
0005432290595	1970	Economy	19000.00
0005434638996	1970	Economy	19000.00
0005432290597	1970	Economy	19000.00
0005432290594	1970	Economy	19000.00
0005434639010	1970	Economy	19000.00
0005434639011	1970	Economy	19000.00
0005434639012	1970	Economy	19000.00
0005434638997	1970	Economy	19000.00
0005434639007	1970	Economy	19000.00
0005434638994	1970	Economy	19000.00
0005434638990	1970	Economy	19000.00
0005434638998	1970	Economy	19000.00
0005434638991	1970	Economy	19000.00
0005434638992	1970	Economy	19000.00
0005434638986	1970	Economy	19000.00
0005434639000	1970	Economy	19000.00
0005434638987	1970	Economy	19000.00
0005434639009	1970	Economy	19000.00
0005434638988	1970	Economy	19000.00
0005434638999	1970	Economy	19000.00
0005434639003	1970	Economy	19000.00
0005434638995	1970	Economy	19000.00
0005434639002	1970	Economy	19000.00
0005434639001	1970	Economy	19000.00
0005434638985	1970	Economy	19000.00
0005432290596	1970	Economy	19000.00
0005434639004	1970	Economy	19000.00
0005434638993	1970	Economy	19000.00
0005434638989	1970	Economy	19000.00
0005433202167	23289	Economy	20900.00
0005433202168	23289	Economy	19000.00
0005433202169	23289	Economy	19000.00
0005433202164	23289	Economy	19000.00
0005433202165	23289	Economy	19000.00
0005433202174	23289	Economy	19000.00
0005433202163	23289	Economy	19000.00
0005433202171	23289	Economy	19000.00
0005433202175	23289	Economy	19000.00
0005433202170	23289	Economy	19000.00
0005433202176	23289	Economy	19000.00
0005433202173	23289	Economy	19000.00
0005433202166	23289	Economy	19000.00
0005433202172	23289	Economy	19000.00
0005434600479	6091	Business	69700.00
0005434600485	6091	Business	69700.00
0005434600488	6091	Economy	23200.00
0005433533262	6091	Economy	23200.00
0005432111244	6091	Economy	23200.00
0005434600466	6091	Economy	23200.00
0005434600477	6091	Economy	23200.00
0005432111242	6091	Economy	25600.00
0005433533260	6091	Economy	25600.00
0005434600490	6091	Economy	23200.00
0005434600471	6091	Economy	23200.00
0005434600474	6091	Economy	23200.00
0005434600470	6091	Economy	23200.00
0005434600472	6091	Economy	23200.00
0005433531248	6091	Economy	23200.00
0005435326506	6091	Economy	23200.00
0005434600491	6091	Economy	23200.00
0005435326507	6091	Economy	23200.00
0005434600478	6091	Economy	23200.00
0005434600473	6091	Economy	23200.00
0005434600465	6091	Economy	23200.00
0005434600493	6091	Economy	23200.00
0005432111241	6091	Economy	23200.00
0005433533261	6091	Economy	23200.00
0005434600492	6091	Economy	23200.00
0005434600486	6091	Economy	23200.00
0005432111243	6091	Economy	23200.00
0005433531245	6091	Economy	23200.00
0005434600487	6091	Economy	23200.00
0005434600481	6091	Economy	23200.00
0005434600480	6091	Economy	23200.00
0005434600469	6091	Economy	23200.00
0005434600475	6091	Economy	23200.00
0005434600467	6091	Economy	23200.00
0005433531246	6091	Economy	23200.00
0005434600468	6091	Economy	23200.00
0005434600483	6091	Economy	23200.00
0005433531247	6091	Economy	23200.00
0005434600484	6091	Economy	23200.00
0005434600476	6091	Economy	23200.00
0005434600482	6091	Economy	23200.00
0005434600489	6091	Economy	23200.00
0005435326570	18591	Economy	23200.00
0005435326579	18591	Economy	23200.00
0005435326578	18591	Economy	23200.00
0005435326581	18591	Economy	25600.00
0005435326580	18591	Economy	23200.00
0005435326575	18591	Economy	23200.00
0005435326568	18591	Economy	23200.00
0005435326573	18591	Economy	23200.00
0005435326574	18591	Economy	23200.00
0005433531227	18591	Economy	23200.00
0005435326577	18591	Economy	23200.00
0005435326571	18591	Economy	23200.00
0005435326576	18591	Economy	23200.00
0005435326569	18591	Economy	23200.00
0005435326572	18591	Economy	23200.00
0005433531228	18591	Economy	23200.00
0005434600332	18591	Economy	23200.00
0005434550485	10609	Business	9100.00
0005434550495	10609	Business	9100.00
0005434558168	10609	Business	9100.00
0005434550491	10609	Business	9100.00
0005434550525	10609	Business	9100.00
0005434550531	10609	Business	9100.00
0005434550494	10609	Business	9100.00
0005434550490	10609	Economy	3000.00
0005434550518	10609	Economy	3000.00
0005434550526	10609	Economy	3000.00
0005434550499	10609	Economy	3000.00
0005434550504	10609	Economy	3000.00
0005434550497	10609	Economy	3000.00
0005434550506	10609	Economy	3000.00
0005434550535	10609	Economy	3000.00
0005434550532	10609	Economy	3300.00
0005434550484	10609	Economy	3300.00
0005434550489	10609	Economy	3300.00
0005434550488	10609	Economy	3300.00
0005434550508	10609	Economy	3000.00
0005434550528	10609	Economy	3000.00
0005434558160	10609	Economy	3000.00
0005434550487	10609	Economy	3000.00
0005434558167	10609	Economy	3000.00
0005434550517	10609	Economy	3000.00
0005434558166	10609	Economy	3000.00
0005434558170	10609	Economy	3000.00
0005434558161	10609	Economy	3000.00
0005434550502	10609	Economy	3000.00
0005434550521	10609	Economy	3000.00
0005434558164	10609	Economy	3000.00
0005434554035	10609	Economy	3000.00
0005434550498	10609	Economy	3000.00
0005434550519	10609	Economy	3000.00
0005434558163	10609	Economy	3000.00
0005434550533	10609	Economy	3000.00
0005434550510	10609	Economy	3000.00
0005434550482	10609	Economy	3000.00
0005434550527	10609	Economy	3000.00
0005434550486	10609	Economy	3000.00
0005434550515	10609	Economy	3000.00
0005434550530	10609	Economy	3000.00
0005434550536	10609	Economy	3000.00
0005434554036	10609	Economy	3000.00
0005434550529	10609	Economy	3000.00
0005434550512	10609	Economy	3000.00
0005434550523	10609	Economy	3000.00
0005434558169	10609	Economy	3000.00
0005434550522	10609	Economy	3000.00
0005434550496	10609	Economy	3000.00
0005434550511	10609	Economy	3000.00
0005434550501	10609	Economy	3000.00
0005434550493	10609	Economy	3000.00
0005434550507	10609	Economy	3000.00
0005434550513	10609	Economy	3000.00
0005434550500	10609	Economy	3000.00
0005434550505	10609	Economy	3000.00
0005434550509	10609	Economy	3000.00
0005434558162	10609	Economy	3000.00
0005434550483	10609	Economy	3000.00
0005434550516	10609	Economy	3000.00
0005434550514	10609	Economy	3000.00
0005434558165	10609	Economy	3000.00
0005434550524	10609	Economy	3000.00
0005434550520	10609	Economy	3000.00
0005434550534	10609	Economy	3000.00
0005434550492	10609	Economy	3000.00
0005434550503	10609	Economy	3000.00
0005434554037	10609	Economy	3000.00
0005433180797	27732	Business	9100.00
0005433180782	27732	Business	9100.00
0005433180798	27732	Business	9100.00
0005433180795	27732	Business	9100.00
0005433180788	27732	Economy	3000.00
0005433180794	27732	Economy	3000.00
0005433180781	27732	Economy	3000.00
0005433180777	27732	Economy	3300.00
0005433180784	27732	Economy	3000.00
0005433180780	27732	Economy	3000.00
0005433180785	27732	Economy	3000.00
0005433180783	27732	Economy	3000.00
0005433180789	27732	Economy	3000.00
0005433180802	27732	Economy	3000.00
0005433180787	27732	Economy	3000.00
0005433180792	27732	Economy	3000.00
0005433180793	27732	Economy	3000.00
0005433180791	27732	Economy	3000.00
0005433180801	27732	Economy	3000.00
0005433180799	27732	Economy	3000.00
0005433180779	27732	Economy	3000.00
0005433180778	27732	Economy	3000.00
0005433180796	27732	Economy	3000.00
0005433180800	27732	Economy	3000.00
0005433180790	27732	Economy	3000.00
0005433180786	27732	Economy	3000.00
0005434550334	27733	Economy	3000.00
0005434550333	27733	Economy	3000.00
0005433459167	6168	Economy	11700.00
0005433459166	6168	Economy	11700.00
0005433459165	6168	Economy	11700.00
0005433459168	6168	Economy	11700.00
0005435254442	19319	Economy	11700.00
0005435254444	19319	Economy	11700.00
0005435254443	19319	Economy	11700.00
0005435681597	6732	Business	51100.00
0005435681604	6732	Business	51100.00
0005435681639	6732	Business	51100.00
0005435681600	6732	Business	51100.00
0005435681627	6732	Business	51100.00
0005435630927	6732	Business	51100.00
0005435681611	6732	Business	51100.00
0005435681619	6732	Business	51100.00
0005435681607	6732	Business	51100.00
0005435681618	6732	Economy	17000.00
0005435681631	6732	Economy	17000.00
0005435681606	6732	Economy	17000.00
0005435681638	6732	Economy	17000.00
0005435681641	6732	Economy	17000.00
0005435681621	6732	Economy	17000.00
0005435681625	6732	Economy	17000.00
0005435437561	6732	Economy	18700.00
0005435681605	6732	Economy	18700.00
0005435661891	6732	Economy	18700.00
0005435720123	6732	Economy	18700.00
0005435720124	6732	Economy	17000.00
0005435630926	6732	Economy	17000.00
0005435681617	6732	Economy	17000.00
0005435681629	6732	Economy	17000.00
0005435437567	6732	Economy	17000.00
0005435681640	6732	Economy	17000.00
0005435437571	6732	Economy	17000.00
0005435681613	6732	Economy	17000.00
0005435681612	6732	Economy	17000.00
0005435719554	6732	Economy	17000.00
0005435681608	6732	Economy	17000.00
0005435681615	6732	Economy	17000.00
0005432136106	6732	Economy	17000.00
0005435681624	6732	Economy	17000.00
0005435681642	6732	Economy	17000.00
0005435681609	6732	Economy	17000.00
0005432136104	6732	Economy	17000.00
0005435681616	6732	Economy	17000.00
0005435681633	6732	Economy	17000.00
0005435720122	6732	Economy	17000.00
0005435681603	6732	Economy	17000.00
0005435681623	6732	Economy	17000.00
0005435630928	6732	Economy	17000.00
0005435681622	6732	Economy	17000.00
0005435681610	6732	Economy	17000.00
0005432136108	6732	Economy	17000.00
0005435681599	6732	Economy	17000.00
0005435681598	6732	Economy	17000.00
0005435661893	6732	Economy	17000.00
0005435437595	6732	Economy	17000.00
0005435681596	6732	Economy	17000.00
0005435719555	6732	Economy	17000.00
0005435437609	6732	Economy	17000.00
0005432136105	6732	Economy	17000.00
0005435681620	6732	Economy	17000.00
0005435681634	6732	Economy	17000.00
0005435437596	6732	Economy	17000.00
0005435681602	6732	Economy	17000.00
0005432136107	6732	Economy	17000.00
0005435681630	6732	Economy	17000.00
0005435681614	6732	Economy	17000.00
0005435661892	6732	Economy	17000.00
0005435681628	6732	Economy	17000.00
0005435681626	6732	Economy	17000.00
0005435437568	6732	Economy	17000.00
0005435681632	6732	Economy	17000.00
0005435681635	6732	Economy	17000.00
0005435681637	6732	Economy	17000.00
0005435681636	6732	Economy	17000.00
0005435681601	6732	Economy	17000.00
0005435437684	24566	Business	51100.00
0005435681427	24566	Business	51100.00
0005435437668	24566	Business	51100.00
0005435437682	24566	Business	51100.00
0005435437680	24566	Business	51100.00
0005432305719	24566	Economy	17000.00
0005435220294	24566	Economy	17000.00
0005435437672	24566	Economy	17000.00
0005435437673	24566	Economy	17000.00
0005435219171	24566	Economy	17000.00
0005435220291	24566	Economy	17000.00
0005435219173	24566	Economy	17000.00
0005435437674	24566	Economy	18700.00
0005435437686	24566	Economy	17000.00
0005435437687	24566	Economy	17000.00
0005432533256	24566	Economy	17000.00
0005435437670	24566	Economy	17000.00
0005435437677	24566	Economy	17000.00
0005435437666	24566	Economy	17000.00
0005435437671	24566	Economy	17000.00
0005435681420	24566	Economy	17000.00
0005435681384	24566	Economy	17000.00
0005434828663	24566	Economy	17000.00
0005434828664	24566	Economy	17000.00
0005435437685	24566	Economy	17000.00
0005435437667	24566	Economy	17000.00
0005432533257	24566	Economy	17000.00
0005435437678	24566	Economy	17000.00
0005435681426	24566	Economy	17000.00
0005435437679	24566	Economy	17000.00
0005435437681	24566	Economy	17000.00
0005435681457	24566	Economy	17000.00
0005435681432	24566	Economy	17000.00
0005434828662	24566	Economy	17000.00
0005435220293	24566	Economy	17000.00
0005432533255	24566	Economy	17000.00
0005435437676	24566	Economy	17000.00
0005432305717	24566	Economy	17000.00
0005435219174	24566	Economy	17000.00
0005432305718	24566	Economy	17000.00
0005435681449	24566	Economy	17000.00
0005435437669	24566	Economy	17000.00
0005435437675	24566	Economy	17000.00
0005435437683	24566	Economy	17000.00
0005435681458	24566	Economy	17000.00
0005435220292	24566	Economy	17000.00
0005435219172	24566	Economy	17000.00
0005435681410	24566	Economy	17000.00
0005435105939	11510	Business	26400.00
0005435125848	11510	Business	26400.00
0005435125820	11510	Business	26400.00
0005435125852	11510	Business	26400.00
0005435125853	11510	Business	26400.00
0005435125819	11510	Business	26400.00
0005435125839	11510	Business	26400.00
0005435125821	11510	Economy	8800.00
0005435125843	11510	Economy	8800.00
0005435125844	11510	Economy	8800.00
0005435125837	11510	Economy	8800.00
0005435125826	11510	Economy	8800.00
0005435125838	11510	Economy	8800.00
0005435125835	11510	Economy	9700.00
0005435125851	11510	Economy	9700.00
0005435125818	11510	Economy	8800.00
0005435125849	11510	Economy	8800.00
0005435125816	11510	Economy	8800.00
0005435125845	11510	Economy	8800.00
0005435125840	11510	Economy	8800.00
0005435125830	11510	Economy	8800.00
0005435125814	11510	Economy	8800.00
0005435125833	11510	Economy	8800.00
0005435125854	11510	Economy	8800.00
0005435125846	11510	Economy	8800.00
0005435125841	11510	Economy	8800.00
0005435125824	11510	Economy	8800.00
0005435105943	11510	Economy	8800.00
0005435125834	11510	Economy	8800.00
0005435125822	11510	Economy	8800.00
0005435125825	11510	Economy	8800.00
0005435125842	11510	Economy	8800.00
0005435125850	11510	Economy	8800.00
0005435125815	11510	Economy	8800.00
0005435125823	11510	Economy	8800.00
0005435105940	11510	Economy	8800.00
0005435125829	11510	Economy	8800.00
0005435125831	11510	Economy	8800.00
0005435125828	11510	Economy	8800.00
0005435105941	11510	Economy	8800.00
0005435125817	11510	Economy	8800.00
0005435125832	11510	Economy	8800.00
0005435105942	11510	Economy	8800.00
0005435125836	11510	Economy	8800.00
0005435125847	11510	Economy	8800.00
0005435125855	11510	Economy	8800.00
0005435125827	11510	Economy	8800.00
0005435125657	31904	Business	26400.00
0005435125669	31904	Economy	8800.00
0005435125649	31904	Economy	8800.00
0005435125684	31904	Economy	8800.00
0005435125668	31904	Economy	8800.00
0005435558055	31904	Economy	8800.00
0005435558054	31904	Economy	8800.00
0005433397476	13541	Business	36600.00
0005433397457	13541	Business	36600.00
0005433397450	13541	Business	36600.00
0005433397434	13541	Business	36600.00
0005433397474	13541	Business	36600.00
0005433397436	13541	Business	36600.00
0005433397463	13541	Business	36600.00
0005433397465	13541	Economy	12200.00
0005433397445	13541	Economy	12200.00
0005433397440	13541	Economy	12200.00
0005433397439	13541	Economy	12200.00
0005433397461	13541	Economy	12200.00
0005433397430	13541	Economy	13400.00
0005433397428	13541	Economy	13400.00
0005433397448	13541	Economy	13400.00
0005435732113	13541	Economy	12200.00
0005433397456	13541	Economy	12200.00
0005433397464	13541	Economy	12200.00
0005433397435	13541	Economy	12200.00
0005433397467	13541	Economy	12200.00
0005433397455	13541	Economy	12200.00
0005433397443	13541	Economy	12200.00
0005433397447	13541	Economy	12200.00
0005433397470	13541	Economy	12200.00
0005433397452	13541	Economy	12200.00
0005433397444	13541	Economy	12200.00
0005433397466	13541	Economy	12200.00
0005433397453	13541	Economy	12200.00
0005433397441	13541	Economy	12200.00
0005433397429	13541	Economy	12200.00
0005433397458	13541	Economy	12200.00
0005433397472	13541	Economy	12200.00
0005433397469	13541	Economy	12200.00
0005433397437	13541	Economy	12200.00
0005433397438	13541	Economy	12200.00
0005433397442	13541	Economy	12200.00
0005433397462	13541	Economy	12200.00
0005433397432	13541	Economy	12200.00
0005433397446	13541	Economy	12200.00
0005433397471	13541	Economy	12200.00
0005433397460	13541	Economy	12200.00
0005433397459	13541	Economy	12200.00
0005433397449	13541	Economy	12200.00
0005433397431	13541	Economy	12200.00
0005433397473	13541	Economy	12200.00
0005433397475	13541	Economy	12200.00
0005433397433	13541	Economy	12200.00
0005433397451	13541	Economy	12200.00
0005433397468	13541	Economy	12200.00
0005433397454	13541	Economy	12200.00
0005435732171	19398	Business	36600.00
0005433397185	19398	Business	36600.00
0005433397246	19398	Economy	12200.00
0005432297244	19398	Economy	12200.00
0005433397228	19398	Economy	13400.00
0005435732168	19398	Economy	12200.00
0005435732175	19398	Economy	12200.00
0005435732177	19398	Economy	12200.00
0005435732169	19398	Economy	12200.00
0005435732176	19398	Economy	12200.00
0005432297245	19398	Economy	12200.00
0005435732174	19398	Economy	12200.00
0005435732166	19398	Economy	12200.00
0005433397198	19398	Economy	12200.00
0005433397184	19398	Economy	12200.00
0005435732178	19398	Economy	12200.00
0005435732179	19398	Economy	12200.00
0005433397227	19398	Economy	12200.00
0005435732170	19398	Economy	12200.00
0005435732173	19398	Economy	12200.00
0005435732172	19398	Economy	12200.00
0005435732167	19398	Economy	12200.00
0005432297243	19398	Economy	12200.00
0005435068190	13145	Business	11300.00
0005435925123	13145	Economy	4100.00
0005435925128	13145	Economy	4100.00
0005435925124	13145	Economy	4100.00
0005435925121	13145	Economy	3800.00
0005435925125	13145	Economy	3800.00
0005435925127	13145	Economy	3800.00
0005435925122	13145	Economy	3800.00
0005435068264	13145	Economy	3800.00
0005435068191	13145	Economy	3800.00
0005435925126	13145	Economy	3800.00
0005435068384	15458	Business	11300.00
0005435068417	15458	Business	11300.00
0005435068420	15458	Business	11300.00
0005435068406	15458	Business	11300.00
0005435068412	15458	Business	11300.00
0005435068401	15458	Business	11300.00
0005435068416	15458	Business	11300.00
0005435068410	15458	Economy	3800.00
0005435068379	15458	Economy	3800.00
0005435068405	15458	Economy	3800.00
0005435068375	15458	Economy	3800.00
0005435068414	15458	Economy	3800.00
0005435068377	15458	Economy	3800.00
0005435068411	15458	Economy	3800.00
0005435068372	15458	Economy	3800.00
0005435068390	15458	Economy	3800.00
0005435068393	15458	Economy	3800.00
0005435068422	15458	Economy	3800.00
0005435068397	15458	Economy	3800.00
0005435068398	15458	Economy	3800.00
0005435068389	15458	Economy	3800.00
0005435068392	15458	Economy	3800.00
0005435068403	15458	Economy	3800.00
0005435068404	15458	Economy	3800.00
0005435068396	15458	Economy	3800.00
0005435068421	15458	Economy	3800.00
0005435068413	15458	Economy	3800.00
0005435068374	15458	Economy	3800.00
0005435068381	15458	Economy	3800.00
0005435068394	15458	Economy	3800.00
0005435068383	15458	Economy	3800.00
0005435068386	15458	Economy	3800.00
0005435068387	15458	Economy	3800.00
0005435068408	15458	Economy	3800.00
0005435068378	15458	Economy	3800.00
0005435068419	15458	Economy	3800.00
0005435068400	15458	Economy	3800.00
0005435068418	15458	Economy	3800.00
0005435068395	15458	Economy	3800.00
0005435068371	15458	Economy	3800.00
0005435068376	15458	Economy	3800.00
0005435068385	15458	Economy	3800.00
0005435068399	15458	Economy	3800.00
0005435068391	15458	Economy	3800.00
0005435068407	15458	Economy	3800.00
0005435068382	15458	Economy	3800.00
0005435068409	15458	Economy	3800.00
0005435068402	15458	Economy	3800.00
0005435068380	15458	Economy	3800.00
0005435068415	15458	Economy	3800.00
0005435068388	15458	Economy	3800.00
0005435068373	15458	Economy	3800.00
0005434213975	10696	Business	61300.00
0005434213962	10696	Business	61300.00
0005434213964	10696	Business	61300.00
0005434213965	10696	Business	61300.00
0005434213938	10696	Economy	20400.00
0005434213973	10696	Economy	20400.00
0005434213936	10696	Economy	20400.00
0005434213966	10696	Economy	20400.00
0005434213960	10696	Economy	22500.00
0005434213961	10696	Economy	22500.00
0005434213959	10696	Economy	20400.00
0005434213952	10696	Economy	20400.00
0005434213982	10696	Economy	20400.00
0005434213944	10696	Economy	20400.00
0005434213976	10696	Economy	20400.00
0005434213940	10696	Economy	20400.00
0005434213950	10696	Economy	20400.00
0005434213980	10696	Economy	20400.00
0005434213974	10696	Economy	20400.00
0005434213957	10696	Economy	20400.00
0005434213953	10696	Economy	20400.00
0005434213941	10696	Economy	20400.00
0005434213971	10696	Economy	20400.00
0005434213945	10696	Economy	20400.00
0005434213937	10696	Economy	20400.00
0005434213956	10696	Economy	20400.00
0005434213963	10696	Economy	20400.00
0005434213955	10696	Economy	20400.00
0005434213951	10696	Economy	20400.00
0005434213946	10696	Economy	20400.00
0005434213977	10696	Economy	20400.00
0005434213958	10696	Economy	20400.00
0005434213969	10696	Economy	20400.00
0005434213968	10696	Economy	20400.00
0005434213949	10696	Economy	20400.00
0005434213979	10696	Economy	20400.00
0005434213981	10696	Economy	20400.00
0005434213970	10696	Economy	20400.00
0005434213978	10696	Economy	20400.00
0005434213972	10696	Economy	20400.00
0005434213939	10696	Economy	20400.00
0005434213943	10696	Economy	20400.00
0005434213947	10696	Economy	20400.00
0005434213983	10696	Economy	20400.00
0005434213967	10696	Economy	20400.00
0005434213942	10696	Economy	20400.00
0005434213954	10696	Economy	20400.00
0005434213948	10696	Economy	20400.00
0005434755892	28678	Business	61300.00
0005434755888	28678	Business	61300.00
0005434755874	28678	Business	61300.00
0005434755881	28678	Business	61300.00
0005434755905	28678	Economy	20400.00
0005434755911	28678	Economy	20400.00
0005434755902	28678	Economy	20400.00
0005434755891	28678	Economy	20400.00
0005434755900	28678	Economy	20400.00
0005434755916	28678	Economy	20400.00
0005434755913	28678	Economy	22500.00
0005434755875	28678	Economy	22500.00
0005434755921	28678	Economy	22500.00
0005434755919	28678	Economy	20400.00
0005434755897	28678	Economy	20400.00
0005434755895	28678	Economy	20400.00
0005434755878	28678	Economy	20400.00
0005434755894	28678	Economy	20400.00
0005434755917	28678	Economy	20400.00
0005434755880	28678	Economy	20400.00
0005434755879	28678	Economy	20400.00
0005434755893	28678	Economy	20400.00
0005434755896	28678	Economy	20400.00
0005434755909	28678	Economy	20400.00
0005434755886	28678	Economy	20400.00
0005434755898	28678	Economy	20400.00
0005434755873	28678	Economy	20400.00
0005434755890	28678	Economy	20400.00
0005434755883	28678	Economy	20400.00
0005434755903	28678	Economy	20400.00
0005434755914	28678	Economy	20400.00
0005434755872	28678	Economy	20400.00
0005434755910	28678	Economy	20400.00
0005434755912	28678	Economy	20400.00
0005434755882	28678	Economy	20400.00
0005434755918	28678	Economy	20400.00
0005434755907	28678	Economy	20400.00
0005434755885	28678	Economy	20400.00
0005434755877	28678	Economy	20400.00
0005434755889	28678	Economy	20400.00
0005434755920	28678	Economy	20400.00
0005434755904	28678	Economy	20400.00
0005434755901	28678	Economy	20400.00
0005434755908	28678	Economy	20400.00
0005434755915	28678	Economy	20400.00
0005434755876	28678	Economy	20400.00
0005434755899	28678	Economy	20400.00
0005434755887	28678	Economy	20400.00
0005434755884	28678	Economy	20400.00
0005434755906	28678	Economy	20400.00
0005434755871	28678	Economy	20400.00
0005435006743	5425	Business	29500.00
0005435038988	5425	Business	29500.00
0005435038972	5425	Business	29500.00
0005432125364	5425	Business	29500.00
0005435038977	5425	Business	29500.00
0005435038942	5425	Business	29500.00
0005435038981	5425	Business	29500.00
0005435038962	5425	Economy	9800.00
0005432125359	5425	Economy	9800.00
0005435038932	5425	Economy	9800.00
0005435006732	5425	Economy	9800.00
0005435006733	5425	Economy	9800.00
0005435038935	5425	Economy	9800.00
0005432125357	5425	Economy	9800.00
0005432125356	5425	Economy	9800.00
0005434228968	5425	Economy	9800.00
0005435038979	5425	Economy	9800.00
0005435038976	5425	Economy	9800.00
0005435038967	5425	Economy	9800.00
0005434228966	5425	Economy	9800.00
0005435038950	5425	Economy	9800.00
0005435006736	5425	Economy	9800.00
0005435038965	5425	Economy	9800.00
0005435038948	5425	Economy	9800.00
0005435006735	5425	Economy	9800.00
0005435038956	5425	Economy	9800.00
0005435038952	5425	Economy	9800.00
0005435038958	5425	Economy	9800.00
0005434228967	5425	Economy	9800.00
0005435038982	5425	Economy	9800.00
0005435038959	5425	Economy	9800.00
0005435038934	5425	Economy	9800.00
0005435038937	5425	Economy	9800.00
0005435006724	5425	Economy	9800.00
0005432125358	5425	Economy	9800.00
0005434228977	5425	Economy	9800.00
0005435038960	5425	Economy	9800.00
0005435038978	5425	Economy	9800.00
0005435038933	5425	Economy	9800.00
0005435006744	5425	Economy	10800.00
0005435006731	5425	Economy	10800.00
0005435006737	5425	Economy	10800.00
0005435038939	5425	Economy	9800.00
0005432125363	5425	Economy	9800.00
0005435038941	5425	Economy	9800.00
0005435006723	5425	Economy	9800.00
0005435006738	5425	Economy	9800.00
0005435038975	5425	Economy	9800.00
0005435006728	5425	Economy	9800.00
0005435038943	5425	Economy	9800.00
0005435038953	5425	Economy	9800.00
0005435038936	5425	Economy	9800.00
0005435038944	5425	Economy	9800.00
0005435038947	5425	Economy	9800.00
0005435038938	5425	Economy	9800.00
0005435038963	5425	Economy	9800.00
0005435038957	5425	Economy	9800.00
0005435006727	5425	Economy	9800.00
0005435038951	5425	Economy	9800.00
0005435006734	5425	Economy	9800.00
0005435038984	5425	Economy	9800.00
0005435006741	5425	Economy	9800.00
0005435006726	5425	Economy	9800.00
0005435006742	5425	Economy	9800.00
0005435038966	5425	Economy	9800.00
0005432125361	5425	Economy	9800.00
0005435038969	5425	Economy	9800.00
0005435038964	5425	Economy	9800.00
0005435038986	5425	Economy	9800.00
0005432125362	5425	Economy	9800.00
0005435006740	5425	Economy	9800.00
0005435006725	5425	Economy	9800.00
0005432125360	5425	Economy	9800.00
0005435038946	5425	Economy	9800.00
0005435038987	5425	Economy	9800.00
0005435038983	5425	Economy	9800.00
0005435038989	5425	Economy	9800.00
0005435038961	5425	Economy	9800.00
0005435038985	5425	Economy	9800.00
0005435038949	5425	Economy	9800.00
0005435038955	5425	Economy	9800.00
0005435038954	5425	Economy	9800.00
0005435038968	5425	Economy	9800.00
0005435006739	5425	Economy	9800.00
0005435038974	5425	Economy	9800.00
0005435006729	5425	Economy	9800.00
0005435038980	5425	Economy	9800.00
0005435038973	5425	Economy	9800.00
0005435006730	5425	Economy	9800.00
0005435038971	5425	Economy	9800.00
0005435006745	5425	Economy	9800.00
0005435038940	5425	Economy	9800.00
0005435038970	5425	Economy	9800.00
0005435038945	5425	Economy	9800.00
0005432304349	12972	Business	29500.00
0005435006602	12972	Business	29500.00
0005434229093	12972	Business	29500.00
0005434229094	12972	Business	29500.00
0005434229096	12972	Business	29500.00
0005434229081	12972	Economy	9800.00
0005432304351	12972	Economy	9800.00
0005434229086	12972	Economy	9800.00
0005432304348	12972	Economy	9800.00
0005434229098	12972	Economy	9800.00
0005435006633	12972	Economy	9800.00
0005434229100	12972	Economy	9800.00
0005434229085	12972	Economy	9800.00
0005434229097	12972	Economy	9800.00
0005434229089	12972	Economy	9800.00
0005435006603	12972	Economy	10800.00
0005434229091	12972	Economy	10800.00
0005434229092	12972	Economy	10800.00
0005434229082	12972	Economy	9800.00
0005434229103	12972	Economy	9800.00
0005434229084	12972	Economy	9800.00
0005434229088	12972	Economy	9800.00
0005435006632	12972	Economy	9800.00
0005434229102	12972	Economy	9800.00
0005434229095	12972	Economy	9800.00
0005435006601	12972	Economy	9800.00
0005434229087	12972	Economy	9800.00
0005434229099	12972	Economy	9800.00
0005432304350	12972	Economy	9800.00
0005434229101	12972	Economy	9800.00
0005435006629	12972	Economy	9800.00
0005434229083	12972	Economy	9800.00
0005434229090	12972	Economy	9800.00
0005434426233	14890	Business	52900.00
0005434426234	14890	Business	52900.00
0005434426221	14890	Business	52900.00
0005434426210	14890	Business	52900.00
0005434426212	14890	Business	52900.00
0005434426213	14890	Economy	17600.00
0005434426230	14890	Economy	17600.00
0005434426226	14890	Economy	17600.00
0005434411720	14890	Economy	17600.00
0005434411721	14890	Economy	17600.00
0005434426222	14890	Economy	19400.00
0005434426225	14890	Economy	17600.00
0005434426214	14890	Economy	17600.00
0005434411719	14890	Economy	17600.00
0005434426219	14890	Economy	17600.00
0005434426211	14890	Economy	17600.00
0005432188563	14890	Economy	17600.00
0005434426231	14890	Economy	17600.00
0005432188564	14890	Economy	17600.00
0005434426215	14890	Economy	17600.00
0005434426207	14890	Economy	17600.00
0005434411722	14890	Economy	17600.00
0005434411723	14890	Economy	17600.00
0005434426228	14890	Economy	17600.00
0005432188565	14890	Economy	17600.00
0005434426224	14890	Economy	17600.00
0005434426229	14890	Economy	17600.00
0005434426223	14890	Economy	17600.00
0005434426227	14890	Economy	17600.00
0005434426209	14890	Economy	17600.00
0005434426235	14890	Economy	17600.00
0005434426206	14890	Economy	17600.00
0005434426208	14890	Economy	17600.00
0005434426216	14890	Economy	17600.00
0005434426217	14890	Economy	17600.00
0005434426205	14890	Economy	17600.00
0005434426232	14890	Economy	17600.00
0005434426220	14890	Economy	17600.00
0005434426218	14890	Economy	17600.00
0005435902492	20198	Business	52900.00
0005435902488	20198	Business	52900.00
0005435902477	20198	Business	52900.00
0005435902491	20198	Economy	17600.00
0005435902480	20198	Economy	17600.00
0005435902482	20198	Economy	17600.00
0005432059480	20198	Economy	17600.00
0005435902476	20198	Economy	17600.00
0005434426090	20198	Economy	17600.00
0005432059479	20198	Economy	17600.00
0005432059481	20198	Economy	17600.00
0005435554131	20198	Economy	17600.00
0005435902490	20198	Economy	17600.00
0005435554132	20198	Economy	17600.00
0005435902489	20198	Economy	17600.00
0005435902483	20198	Economy	17600.00
0005435902478	20198	Economy	17600.00
0005435554130	20198	Economy	17600.00
0005434426084	20198	Economy	17600.00
0005435902475	20198	Economy	17600.00
0005435902481	20198	Economy	17600.00
0005435902486	20198	Economy	17600.00
0005435902479	20198	Economy	17600.00
0005435902487	20198	Economy	17600.00
0005434426089	20198	Economy	17600.00
0005435902485	20198	Economy	17600.00
0005435902484	20198	Economy	17600.00
0005435554129	20198	Economy	17600.00
0005435981698	26523	Business	18500.00
0005435981713	26523	Business	18500.00
0005435981702	26523	Business	18500.00
0005435981694	26523	Business	18500.00
0005435981721	26523	Business	18500.00
0005435981692	26523	Business	18500.00
0005435981711	26523	Economy	6200.00
0005435981732	26523	Economy	6200.00
0005435981708	26523	Economy	6200.00
0005432300191	26523	Economy	6200.00
0005432300186	26523	Economy	6800.00
0005435981707	26523	Economy	6200.00
0005435981690	26523	Economy	6200.00
0005435981726	26523	Economy	6200.00
0005435981733	26523	Economy	6200.00
0005435981697	26523	Economy	6200.00
0005435981725	26523	Economy	6200.00
0005432300189	26523	Economy	6200.00
0005435981729	26523	Economy	6200.00
0005435981704	26523	Economy	6200.00
0005432300188	26523	Economy	6200.00
0005435981719	26523	Economy	6200.00
0005435981701	26523	Economy	6200.00
0005435981693	26523	Economy	6200.00
0005435981710	26523	Economy	6200.00
0005435981727	26523	Economy	6200.00
0005435981700	26523	Economy	6200.00
0005435981696	26523	Economy	6200.00
0005435981706	26523	Economy	6200.00
0005435981718	26523	Economy	6200.00
0005432300185	26523	Economy	6200.00
0005435981731	26523	Economy	6200.00
0005435981724	26523	Economy	6200.00
0005432300187	26523	Economy	6200.00
0005432300190	26523	Economy	6200.00
0005435981712	26523	Economy	6200.00
0005435981714	26523	Economy	6200.00
0005435981728	26523	Economy	6200.00
0005435981730	26523	Economy	6200.00
0005435981720	26523	Economy	6200.00
0005435981703	26523	Economy	6200.00
0005435981691	26523	Economy	6200.00
0005435981709	26523	Economy	6200.00
0005435981705	26523	Economy	6200.00
0005435981722	26523	Economy	6200.00
0005435981715	26523	Economy	6200.00
0005435981734	26523	Economy	6200.00
0005435981717	26523	Economy	6200.00
0005435981716	26523	Economy	6200.00
0005435981723	26523	Economy	6200.00
0005435981699	26523	Economy	6200.00
0005435981695	26523	Economy	6200.00
0005434270181	26736	Business	18500.00
0005432051089	26736	Business	18500.00
0005432051090	26736	Business	18500.00
0005434269077	26736	Business	18500.00
0005433434353	26736	Business	18500.00
0005434270180	26736	Economy	6200.00
0005432051091	26736	Economy	6200.00
0005433434335	26736	Economy	6200.00
0005433434337	26736	Economy	6200.00
0005433434339	26736	Economy	6200.00
0005433434332	26736	Economy	6200.00
0005433434338	26736	Economy	6800.00
0005433434334	26736	Economy	6200.00
0005434271287	26736	Economy	6200.00
0005433434351	26736	Economy	6200.00
0005433434344	26736	Economy	6200.00
0005433434342	26736	Economy	6200.00
0005433434328	26736	Economy	6200.00
0005433434347	26736	Economy	6200.00
0005433434341	26736	Economy	6200.00
0005433434349	26736	Economy	6200.00
0005433434345	26736	Economy	6200.00
0005434271286	26736	Economy	6200.00
0005433434327	26736	Economy	6200.00
0005433434343	26736	Economy	6200.00
0005434269078	26736	Economy	6200.00
0005433434336	26736	Economy	6200.00
0005433434329	26736	Economy	6200.00
0005433434326	26736	Economy	6200.00
0005433434333	26736	Economy	6200.00
0005433434325	26736	Economy	6200.00
0005433434346	26736	Economy	6200.00
0005434269079	26736	Economy	6200.00
0005433434340	26736	Economy	6200.00
0005433434352	26736	Economy	6200.00
0005433434331	26736	Economy	6200.00
0005433434348	26736	Economy	6200.00
0005433434350	26736	Economy	6200.00
0005433434330	26736	Economy	6200.00
0005432583723	3153	Economy	11100.00
0005432583714	3153	Economy	10100.00
0005432583718	3153	Economy	10100.00
0005432583734	3153	Economy	10100.00
0005432583731	3153	Economy	10100.00
0005432583722	3153	Economy	10100.00
0005432583726	3153	Economy	10100.00
0005432583724	3153	Economy	10100.00
0005432583713	3153	Economy	10100.00
0005432583711	3153	Economy	10100.00
0005432583720	3153	Economy	10100.00
0005432216237	3153	Economy	10100.00
0005432583730	3153	Economy	10100.00
0005432583719	3153	Economy	10100.00
0005432583725	3153	Economy	10100.00
0005432216238	3153	Economy	10100.00
0005432583729	3153	Economy	10100.00
0005432583728	3153	Economy	10100.00
0005432583733	3153	Economy	10100.00
0005432583735	3153	Economy	10100.00
0005432583721	3153	Economy	10100.00
0005432857883	3153	Economy	10100.00
0005432583716	3153	Economy	10100.00
0005432583712	3153	Economy	10100.00
0005432583732	3153	Economy	10100.00
0005432583727	3153	Economy	10100.00
0005432583715	3153	Economy	10100.00
0005432583717	3153	Economy	10100.00
0005432857922	31468	Economy	11100.00
0005432857914	31468	Economy	10100.00
0005432857912	31468	Economy	10100.00
0005432857915	31468	Economy	10100.00
0005432857913	31468	Economy	10100.00
0005432857919	31468	Economy	10100.00
0005432857920	31468	Economy	10100.00
0005432583589	31468	Economy	10100.00
0005432583615	31468	Economy	10100.00
0005432583594	31468	Economy	10100.00
0005432583606	31468	Economy	10100.00
0005432583590	31468	Economy	10100.00
0005432857917	31468	Economy	10100.00
0005432857918	31468	Economy	10100.00
0005432857916	31468	Economy	10100.00
0005432583596	31468	Economy	10100.00
0005432583605	31468	Economy	10100.00
0005432857911	31468	Economy	10100.00
0005432857921	31468	Economy	10100.00
0005432857923	31468	Economy	10100.00
0005434943239	861	Economy	7500.00
0005434943238	861	Economy	7500.00
0005434943240	861	Economy	7500.00
0005434943236	861	Economy	7500.00
0005434943234	861	Economy	7500.00
0005434943237	861	Economy	7500.00
0005434943241	861	Economy	7500.00
0005434943233	861	Economy	7500.00
0005434943232	861	Economy	7500.00
0005434943235	861	Economy	7500.00
0005434943189	16236	Economy	7500.00
0005433255053	16236	Economy	7500.00
0005433255052	16236	Economy	7500.00
0005433255051	16236	Economy	7500.00
0005433255049	16236	Economy	7500.00
0005433255050	16236	Economy	7500.00
0005434943188	16236	Economy	7500.00
0005435652485	21729	Business	9800.00
0005435652463	21729	Business	9800.00
0005435652447	21729	Business	9800.00
0005435652484	21729	Business	9800.00
0005435652488	21729	Business	9800.00
0005435652471	21729	Business	9800.00
0005435652457	21729	Business	9800.00
0005435652452	21729	Business	9800.00
0005435652439	21729	Economy	3300.00
0005435652436	21729	Economy	3300.00
0005435652458	21729	Economy	3300.00
0005435652445	21729	Economy	3300.00
0005435652478	21729	Economy	3300.00
0005435652487	21729	Economy	3600.00
0005435652464	21729	Economy	3600.00
0005435652466	21729	Economy	3600.00
0005435652472	21729	Economy	3600.00
0005435652482	21729	Economy	3300.00
0005435652473	21729	Economy	3300.00
0005435652483	21729	Economy	3300.00
0005435652446	21729	Economy	3300.00
0005435652455	21729	Economy	3300.00
0005435652449	21729	Economy	3300.00
0005435652437	21729	Economy	3300.00
0005435652442	21729	Economy	3300.00
0005435652440	21729	Economy	3300.00
0005435652460	21729	Economy	3300.00
0005435652479	21729	Economy	3300.00
0005435652477	21729	Economy	3300.00
0005435652468	21729	Economy	3300.00
0005435652448	21729	Economy	3300.00
0005435652475	21729	Economy	3300.00
0005435652469	21729	Economy	3300.00
0005435652465	21729	Economy	3300.00
0005435652438	21729	Economy	3300.00
0005435652476	21729	Economy	3300.00
0005435652480	21729	Economy	3300.00
0005435652486	21729	Economy	3300.00
0005435652459	21729	Economy	3300.00
0005435652441	21729	Economy	3300.00
0005435652450	21729	Economy	3300.00
0005435652456	21729	Economy	3300.00
0005435652444	21729	Economy	3300.00
0005435652454	21729	Economy	3300.00
0005435652461	21729	Economy	3300.00
0005435652467	21729	Economy	3300.00
0005435652474	21729	Economy	3300.00
0005435652453	21729	Economy	3300.00
0005435652462	21729	Economy	3300.00
0005435652470	21729	Economy	3300.00
0005435652443	21729	Economy	3300.00
0005435652451	21729	Economy	3300.00
0005435652481	21729	Economy	3300.00
0005433763028	9332	Business	186200.00
0005433784499	9332	Business	186200.00
0005433804960	9332	Business	186200.00
0005433804967	9332	Business	186200.00
0005433763032	9332	Business	186200.00
0005433804938	9332	Business	186200.00
0005433763025	9332	Business	186200.00
0005433804959	9332	Business	186200.00
0005433784516	9332	Business	186200.00
0005433804946	9332	Business	186200.00
0005434170833	9332	Business	186200.00
0005433763030	9332	Business	186200.00
0005433763020	9332	Economy	68300.00
0005433784506	9332	Economy	62100.00
0005433784487	9332	Economy	62100.00
0005433784495	9332	Economy	62100.00
0005433804941	9332	Economy	62100.00
0005432666361	9332	Economy	62100.00
0005433784510	9332	Economy	62100.00
0005433763023	9332	Economy	62100.00
0005433804957	9332	Economy	62100.00
0005432665249	9332	Economy	62100.00
0005433804953	9332	Economy	62100.00
0005433784512	9332	Economy	62100.00
0005433784511	9332	Economy	62100.00
0005432657412	9332	Economy	62100.00
0005433784494	9332	Economy	62100.00
0005433763024	9332	Economy	62100.00
0005433784477	9332	Economy	62100.00
0005434170809	9332	Economy	62100.00
0005433763019	9332	Economy	62100.00
0005434170808	9332	Economy	62100.00
0005433804949	9332	Economy	62100.00
0005433784509	9332	Economy	62100.00
0005433784490	9332	Economy	62100.00
0005434170807	9332	Economy	62100.00
0005433804962	9332	Economy	62100.00
0005433804966	9332	Economy	62100.00
0005433763026	9332	Economy	62100.00
0005432657410	9332	Economy	62100.00
0005433784517	9332	Economy	62100.00
0005433784489	9332	Economy	62100.00
0005433804942	9332	Economy	62100.00
0005433784500	9332	Economy	62100.00
0005432657409	9332	Economy	62100.00
0005433784508	9332	Economy	62100.00
0005433784481	9332	Economy	62100.00
0005433784488	9332	Economy	62100.00
0005433804943	9332	Economy	62100.00
0005433784483	9332	Economy	62100.00
0005433784480	9332	Economy	62100.00
0005433804939	9332	Economy	62100.00
0005433804947	9332	Economy	62100.00
0005433784485	9332	Economy	62100.00
0005433804937	9332	Economy	62100.00
0005433804940	9332	Economy	62100.00
0005432657411	9332	Economy	62100.00
0005433784486	9332	Economy	62100.00
0005433804954	9332	Economy	62100.00
0005433804952	9332	Economy	62100.00
0005433784493	9332	Economy	62100.00
0005433804963	9332	Economy	68300.00
0005433804934	9332	Economy	62100.00
0005433784504	9332	Economy	68300.00
0005432657413	9332	Economy	62100.00
0005433784515	9332	Economy	62100.00
0005433784492	9332	Economy	62100.00
0005433784479	9332	Economy	62100.00
0005433804936	9332	Economy	62100.00
0005433804935	9332	Economy	62100.00
0005433763021	9332	Economy	62100.00
0005433784514	9332	Economy	62100.00
0005433784513	9332	Economy	62100.00
0005433804955	9332	Economy	62100.00
0005433804956	9332	Economy	62100.00
0005433804964	9332	Economy	62100.00
0005433763018	9332	Economy	62100.00
0005433763027	9332	Economy	62100.00
0005433784478	9332	Economy	62100.00
0005433804961	9332	Economy	62100.00
0005432666362	9332	Economy	62100.00
0005433784482	9332	Economy	62100.00
0005433784505	9332	Economy	62100.00
0005433804950	9332	Economy	62100.00
0005433804965	9332	Economy	62100.00
0005433784497	9332	Economy	62100.00
0005433804945	9332	Economy	62100.00
0005433784491	9332	Economy	62100.00
0005433804944	9332	Economy	62100.00
0005433784507	9332	Economy	62100.00
0005432667428	9332	Economy	62100.00
0005433784502	9332	Economy	62100.00
0005433763022	9332	Economy	62100.00
0005433763029	9332	Economy	62100.00
0005433804948	9332	Economy	62100.00
0005433784496	9332	Economy	62100.00
0005433763031	9332	Economy	62100.00
0005433784498	9332	Economy	62100.00
0005433804958	9332	Economy	62100.00
0005433763017	9332	Economy	62100.00
0005433804951	9332	Economy	62100.00
0005433784484	9332	Economy	62100.00
0005433784503	9332	Economy	62100.00
0005433784501	9332	Economy	62100.00
0005434151667	26256	Business	186200.00
0005433784314	26256	Business	186200.00
0005434170874	26256	Business	186200.00
0005435269666	26256	Business	186200.00
0005435269665	26256	Business	186200.00
0005433804779	26256	Business	186200.00
0005434170882	26256	Economy	68300.00
0005434270179	26256	Economy	62100.00
0005434170870	26256	Economy	62100.00
0005433784324	26256	Economy	62100.00
0005434170872	26256	Economy	62100.00
0005433762986	26256	Economy	62100.00
0005434170875	26256	Economy	62100.00
0005433784360	26256	Economy	62100.00
0005434271285	26256	Economy	62100.00
0005435269669	26256	Economy	62100.00
0005433804792	26256	Economy	62100.00
0005434170878	26256	Economy	62100.00
0005433784315	26256	Economy	62100.00
0005435269668	26256	Economy	62100.00
0005433784361	26256	Economy	62100.00
0005434170880	26256	Economy	62100.00
0005434270178	26256	Economy	62100.00
0005434170877	26256	Economy	62100.00
0005434151669	26256	Economy	62100.00
0005434170871	26256	Economy	62100.00
0005434269076	26256	Economy	68300.00
0005434170873	26256	Economy	68300.00
0005433784313	26256	Economy	62100.00
0005434170881	26256	Economy	62100.00
0005434170884	26256	Economy	62100.00
0005434271284	26256	Economy	62100.00
0005434170879	26256	Economy	62100.00
0005433804879	26256	Economy	62100.00
0005435269670	26256	Economy	62100.00
0005434170883	26256	Economy	62100.00
0005434151668	26256	Economy	62100.00
0005433804780	26256	Economy	62100.00
0005433784323	26256	Economy	62100.00
0005435269667	26256	Economy	62100.00
0005434170876	26256	Economy	62100.00
0005433784363	26256	Economy	62100.00
0005435269671	26256	Economy	62100.00
0005434151666	26256	Economy	62100.00
0005435135608	4912	Economy	5300.00
0005435135609	4912	Economy	5300.00
0005435135607	4912	Economy	5300.00
0005435135610	4912	Economy	5300.00
0005435135606	4912	Economy	5300.00
0005435929611	33002	Economy	5900.00
0005435929609	33002	Economy	5900.00
0005435929610	33002	Economy	5300.00
0005434983224	9475	Economy	19700.00
0005434983222	9475	Economy	17900.00
0005434983221	9475	Economy	17900.00
0005434983223	9475	Economy	17900.00
0005434217917	27336	Economy	19700.00
0005434983195	27336	Economy	17900.00
0005434983196	27336	Economy	17900.00
0005434983199	27336	Economy	17900.00
0005434217916	27336	Economy	17900.00
0005434217918	27336	Economy	17900.00
0005433985153	24257	Economy	12100.00
0005433985183	24257	Economy	12100.00
0005433985159	24257	Economy	12100.00
0005433960098	25948	Business	36400.00
0005433960116	25948	Business	36400.00
0005433985335	25948	Business	36400.00
0005433985331	25948	Business	36400.00
0005433985312	25948	Business	36400.00
0005433960126	25948	Business	36400.00
0005433960085	25948	Business	36400.00
0005433960092	25948	Business	36400.00
0005433960132	25948	Business	36400.00
0005433960123	25948	Business	36400.00
0005433985343	25948	Business	36400.00
0005433960089	25948	Business	36400.00
0005433960129	25948	Economy	13400.00
0005433985352	25948	Business	36400.00
0005433960109	25948	Economy	12100.00
0005433985347	25948	Economy	12100.00
0005433985321	25948	Economy	12100.00
0005433960082	25948	Economy	12100.00
0005433985314	25948	Economy	12100.00
0005433960139	25948	Economy	12100.00
0005433985320	25948	Economy	12100.00
0005433960104	25948	Economy	12100.00
0005433960122	25948	Economy	12100.00
0005433985313	25948	Economy	12100.00
0005433985355	25948	Economy	12100.00
0005433960117	25948	Economy	12100.00
0005433985324	25948	Economy	12100.00
0005433960119	25948	Economy	12100.00
0005433960094	25948	Economy	12100.00
0005433960091	25948	Economy	12100.00
0005433985356	25948	Economy	12100.00
0005433985323	25948	Economy	12100.00
0005433985315	25948	Economy	12100.00
0005433985340	25948	Economy	12100.00
0005433960141	25948	Economy	12100.00
0005433985332	25948	Economy	12100.00
0005433985357	25948	Economy	12100.00
0005433960111	25948	Economy	12100.00
0005433985351	25948	Economy	12100.00
0005433985325	25948	Economy	12100.00
0005433985317	25948	Economy	12100.00
0005433960108	25948	Economy	12100.00
0005433985345	25948	Economy	12100.00
0005433960135	25948	Economy	12100.00
0005433960101	25948	Economy	12100.00
0005433985309	25948	Economy	12100.00
0005433985339	25948	Economy	12100.00
0005433960110	25948	Economy	12100.00
0005433960124	25948	Economy	12100.00
0005433960134	25948	Economy	12100.00
0005433985327	25948	Economy	12100.00
0005433960112	25948	Economy	12100.00
0005433960102	25948	Economy	12100.00
0005433960121	25948	Economy	12100.00
0005433960113	25948	Economy	12100.00
0005433960088	25948	Economy	12100.00
0005433960114	25948	Economy	12100.00
0005433960128	25948	Economy	12100.00
0005433985344	25948	Economy	12100.00
0005433985336	25948	Economy	12100.00
0005433960095	25948	Economy	12100.00
0005433985330	25948	Economy	12100.00
0005433960127	25948	Economy	12100.00
0005433985349	25948	Economy	12100.00
0005433960138	25948	Economy	13400.00
0005433985353	25948	Economy	12100.00
0005433960130	25948	Economy	12100.00
0005433985311	25948	Economy	12100.00
0005433985338	25948	Economy	12100.00
0005433985348	25948	Economy	12100.00
0005433960105	25948	Economy	12100.00
0005433960125	25948	Economy	12100.00
0005433960099	25948	Economy	12100.00
0005433985326	25948	Economy	12100.00
0005433960100	25948	Economy	12100.00
0005433960103	25948	Economy	12100.00
0005433985318	25948	Economy	12100.00
0005433985310	25948	Economy	12100.00
0005433960097	25948	Economy	12100.00
0005433985354	25948	Economy	12100.00
0005433985342	25948	Economy	12100.00
0005433985350	25948	Economy	12100.00
0005433960083	25948	Economy	12100.00
0005433985333	25948	Economy	12100.00
0005433960137	25948	Economy	12100.00
0005433960133	25948	Economy	12100.00
0005433960140	25948	Economy	12100.00
0005433960086	25948	Economy	12100.00
0005433985329	25948	Economy	12100.00
0005433960084	25948	Economy	12100.00
0005433985322	25948	Economy	12100.00
0005433960118	25948	Economy	12100.00
0005433960106	25948	Economy	12100.00
0005433985334	25948	Economy	12100.00
0005433960120	25948	Economy	12100.00
0005433960090	25948	Economy	12100.00
0005433985346	25948	Economy	12100.00
0005433985341	25948	Economy	12100.00
0005433960096	25948	Economy	12100.00
0005433985319	25948	Economy	12100.00
0005433985328	25948	Economy	12100.00
0005433985308	25948	Economy	12100.00
0005433960136	25948	Economy	12100.00
0005433960115	25948	Economy	12100.00
0005433960087	25948	Economy	12100.00
0005433985337	25948	Economy	12100.00
0005433985316	25948	Economy	12100.00
0005433960131	25948	Economy	12100.00
0005433960093	25948	Economy	12100.00
0005433960107	25948	Economy	12100.00
0005434480023	940	Economy	25400.00
0005434480014	940	Economy	25400.00
0005434480019	940	Economy	25400.00
0005434480025	940	Economy	23100.00
0005434480007	940	Economy	23100.00
0005432269461	940	Economy	23100.00
0005434480010	940	Economy	23100.00
0005434480030	940	Economy	23100.00
0005434480004	940	Economy	23100.00
0005434480005	940	Economy	23100.00
0005434480013	940	Economy	23100.00
0005434480016	940	Economy	23100.00
0005434480017	940	Economy	23100.00
0005434480026	940	Economy	23100.00
0005434480018	940	Economy	23100.00
0005434480020	940	Economy	23100.00
0005434480021	940	Economy	23100.00
0005432269462	940	Economy	23100.00
0005434480006	940	Economy	23100.00
0005434480011	940	Economy	23100.00
0005434480008	940	Economy	23100.00
0005434480022	940	Economy	23100.00
0005434480027	940	Economy	23100.00
0005434480024	940	Economy	23100.00
0005434480028	940	Economy	23100.00
0005432269460	940	Economy	23100.00
0005434480009	940	Economy	23100.00
0005432269459	940	Economy	23100.00
0005434480029	940	Economy	23100.00
0005434480012	940	Economy	23100.00
0005434480015	940	Economy	23100.00
0005433165744	16577	Economy	25400.00
0005433165741	16577	Economy	23100.00
0005433165747	16577	Economy	23100.00
0005433165743	16577	Economy	23100.00
0005433165738	16577	Economy	23100.00
0005433165748	16577	Economy	23100.00
0005433165735	16577	Economy	23100.00
0005434479915	16577	Economy	23100.00
0005433165736	16577	Economy	23100.00
0005433165746	16577	Economy	23100.00
0005434479898	16577	Economy	23100.00
0005433165737	16577	Economy	23100.00
0005433165749	16577	Economy	23100.00
0005433165739	16577	Economy	23100.00
0005434479916	16577	Economy	23100.00
0005433165742	16577	Economy	23100.00
0005433165740	16577	Economy	23100.00
0005433165745	16577	Economy	23100.00
0005435149854	10359	Economy	17000.00
0005435149844	10359	Economy	17000.00
0005435149848	10359	Economy	17000.00
0005435149845	10359	Economy	15400.00
0005435149847	10359	Economy	15400.00
0005435142392	10359	Economy	15400.00
0005435142401	10359	Economy	15400.00
0005435142402	10359	Economy	15400.00
0005435142404	10359	Economy	15400.00
0005435149850	10359	Economy	15400.00
0005435149853	10359	Economy	15400.00
0005435142391	10359	Economy	15400.00
0005435142396	10359	Economy	15400.00
0005435142400	10359	Economy	15400.00
0005435149841	10359	Economy	15400.00
0005435142390	10359	Economy	15400.00
0005435142394	10359	Economy	15400.00
0005435149855	10359	Economy	15400.00
0005435149846	10359	Economy	15400.00
0005435142393	10359	Economy	15400.00
0005435149842	10359	Economy	15400.00
0005435142399	10359	Economy	15400.00
0005435149849	10359	Economy	15400.00
0005435149852	10359	Economy	15400.00
0005435142397	10359	Economy	15400.00
0005435142403	10359	Economy	15400.00
0005435142398	10359	Economy	15400.00
0005435149851	10359	Economy	15400.00
0005435149843	10359	Economy	15400.00
0005435142395	10359	Economy	15400.00
0005433289765	21925	Economy	17000.00
0005435386493	21925	Economy	17000.00
0005435386497	21925	Economy	15400.00
0005435386496	21925	Economy	15400.00
0005435386492	21925	Economy	15400.00
0005433289764	21925	Economy	15400.00
0005435386495	21925	Economy	15400.00
0005433289762	21925	Economy	15400.00
0005435386490	21925	Economy	15400.00
0005435386491	21925	Economy	15400.00
0005433289766	21925	Economy	15400.00
0005433289767	21925	Economy	15400.00
0005433289763	21925	Economy	15400.00
0005435386489	21925	Economy	15400.00
0005435386494	21925	Economy	15400.00
0005434573165	11221	Economy	19100.00
0005434573170	11221	Economy	19100.00
0005435528883	11221	Economy	19100.00
0005434573163	11221	Economy	21000.00
0005434573166	11221	Economy	21000.00
0005434573164	11221	Economy	19100.00
0005434573159	11221	Economy	19100.00
0005434573172	11221	Economy	19100.00
0005435501938	11221	Economy	19100.00
0005434573160	11221	Economy	19100.00
0005434573168	11221	Economy	19100.00
0005435501980	11221	Economy	19100.00
0005434573162	11221	Economy	19100.00
0005434573171	11221	Economy	19100.00
0005434573161	11221	Economy	19100.00
0005435501981	11221	Economy	19100.00
0005434573169	11221	Economy	19100.00
0005434573167	11221	Economy	19100.00
0005435517677	20932	Business	57200.00
0005435508219	20932	Business	57200.00
0005435517683	20932	Business	57200.00
0005435508216	20932	Business	57200.00
0005435502033	20932	Business	57200.00
0005435502023	20932	Business	57200.00
0005435517688	20932	Business	57200.00
0005435517685	20932	Business	57200.00
0005435319470	20932	Economy	19100.00
0005435502027	20932	Economy	19100.00
0005435319474	20932	Economy	19100.00
0005432291898	20932	Economy	19100.00
0005435319477	20932	Economy	19100.00
0005435502037	20932	Economy	19100.00
0005435502026	20932	Economy	21000.00
0005435517669	20932	Economy	21000.00
0005435319472	20932	Economy	21000.00
0005435502024	20932	Economy	19100.00
0005435502035	20932	Economy	19100.00
0005432291899	20932	Economy	19100.00
0005435517681	20932	Economy	19100.00
0005435508218	20932	Economy	19100.00
0005435502039	20932	Economy	19100.00
0005435517668	20932	Economy	19100.00
0005435517674	20932	Economy	19100.00
0005435319473	20932	Economy	19100.00
0005435319468	20932	Economy	19100.00
0005435517673	20932	Economy	19100.00
0005435502031	20932	Economy	19100.00
0005435502040	20932	Economy	19100.00
0005435502038	20932	Economy	19100.00
0005435319471	20932	Economy	19100.00
0005435517676	20932	Economy	19100.00
0005435502022	20932	Economy	19100.00
0005435517682	20932	Economy	19100.00
0005435502041	20932	Economy	19100.00
0005435319475	20932	Economy	19100.00
0005435502030	20932	Economy	19100.00
0005435508221	20932	Economy	19100.00
0005435517679	20932	Economy	19100.00
0005435517671	20932	Economy	19100.00
0005435319476	20932	Economy	19100.00
0005435319469	20932	Economy	19100.00
0005435517670	20932	Economy	19100.00
0005435508211	20932	Economy	19100.00
0005435517687	20932	Economy	19100.00
0005435517672	20932	Economy	19100.00
0005435517680	20932	Economy	19100.00
0005435502032	20932	Economy	19100.00
0005435502028	20932	Economy	19100.00
0005435517686	20932	Economy	19100.00
0005435508210	20932	Economy	19100.00
0005435508217	20932	Economy	19100.00
0005435508213	20932	Economy	19100.00
0005435517678	20932	Economy	19100.00
0005435502021	20932	Economy	19100.00
0005435502034	20932	Economy	19100.00
0005435502025	20932	Economy	19100.00
0005435502029	20932	Economy	19100.00
0005435517684	20932	Economy	19100.00
0005435517675	20932	Economy	19100.00
0005435508214	20932	Economy	19100.00
0005435508212	20932	Economy	19100.00
0005435508215	20932	Economy	19100.00
0005435508220	20932	Economy	19100.00
0005435502036	20932	Economy	19100.00
0005432692565	2956	Economy	3400.00
0005432706451	2957	Business	10300.00
0005432706456	2957	Business	10300.00
0005432706461	2957	Business	10300.00
0005432706439	2957	Business	10300.00
0005432706442	2957	Business	10300.00
0005432706462	2957	Economy	3400.00
0005432706443	2957	Economy	3400.00
0005433123575	2957	Economy	3800.00
0005432706440	2957	Economy	3800.00
0005432706459	2957	Economy	3800.00
0005432706463	2957	Economy	3400.00
0005432706448	2957	Economy	3400.00
0005432706449	2957	Economy	3400.00
0005432706452	2957	Economy	3400.00
0005432706438	2957	Economy	3400.00
0005432706453	2957	Economy	3400.00
0005432706458	2957	Economy	3400.00
0005432706455	2957	Economy	3400.00
0005432706450	2957	Economy	3400.00
0005432217741	2957	Economy	3400.00
0005432706457	2957	Economy	3400.00
0005432706441	2957	Economy	3400.00
0005432706447	2957	Economy	3400.00
0005432706454	2957	Economy	3400.00
0005432706446	2957	Economy	3400.00
0005432217740	2957	Economy	3400.00
0005432706444	2957	Economy	3400.00
0005432706460	2957	Economy	3400.00
0005432706445	2957	Economy	3400.00
0005432706464	2957	Economy	3400.00
0005432692688	29960	Business	10300.00
0005433123661	29960	Business	10300.00
0005433123656	29960	Business	10300.00
0005432880627	29960	Business	10300.00
0005432692708	29960	Business	10300.00
0005433123674	29960	Business	10300.00
0005432706349	29960	Business	10300.00
0005432692686	29960	Business	10300.00
0005433123675	29960	Business	10300.00
0005432692709	29960	Business	10300.00
0005433123676	29960	Business	10300.00
0005433123670	29960	Economy	3400.00
0005432880640	29960	Economy	3400.00
0005433123665	29960	Economy	3400.00
0005432692712	29960	Economy	3400.00
0005432692716	29960	Economy	3400.00
0005433123667	29960	Economy	3400.00
0005432692711	29960	Economy	3400.00
0005433123677	29960	Economy	3400.00
0005432692703	29960	Economy	3400.00
0005432692702	29960	Economy	3800.00
0005432692704	29960	Economy	3800.00
0005432692706	29960	Economy	3800.00
0005432706348	29960	Economy	3400.00
0005432880637	29960	Economy	3400.00
0005433194826	29960	Economy	3400.00
0005432880633	29960	Economy	3400.00
0005433123657	29960	Economy	3400.00
0005432880634	29960	Economy	3400.00
0005432880639	29960	Economy	3400.00
0005432692705	29960	Economy	3400.00
0005432692710	29960	Economy	3400.00
0005432692693	29960	Economy	3400.00
0005432692687	29960	Economy	3400.00
0005433123668	29960	Economy	3400.00
0005433123664	29960	Economy	3400.00
0005432706327	29960	Economy	3400.00
0005432692695	29960	Economy	3400.00
0005432880635	29960	Economy	3400.00
0005433123666	29960	Economy	3400.00
0005432880638	29960	Economy	3400.00
0005432880628	29960	Economy	3400.00
0005432692700	29960	Economy	3400.00
0005432692692	29960	Economy	3400.00
0005433123672	29960	Economy	3400.00
0005432692714	29960	Economy	3400.00
0005433123658	29960	Economy	3400.00
0005432692699	29960	Economy	3400.00
0005433123673	29960	Economy	3400.00
0005433123671	29960	Economy	3400.00
0005432692694	29960	Economy	3400.00
0005432692691	29960	Economy	3400.00
0005432880626	29960	Economy	3400.00
0005433123662	29960	Economy	3400.00
0005433123669	29960	Economy	3400.00
0005432706328	29960	Economy	3400.00
0005432880630	29960	Economy	3400.00
0005433123659	29960	Economy	3400.00
0005432692707	29960	Economy	3400.00
0005432880632	29960	Economy	3400.00
0005432692689	29960	Economy	3400.00
0005432692697	29960	Economy	3400.00
0005432692701	29960	Economy	3400.00
0005432692713	29960	Economy	3400.00
0005432692696	29960	Economy	3400.00
0005432880631	29960	Economy	3400.00
0005432706323	29960	Economy	3400.00
0005433194827	29960	Economy	3400.00
0005433123660	29960	Economy	3400.00
0005432692715	29960	Economy	3400.00
0005432880629	29960	Economy	3400.00
0005432706350	29960	Economy	3400.00
0005432880636	29960	Economy	3400.00
0005433123663	29960	Economy	3400.00
0005432692690	29960	Economy	3400.00
0005433123678	29960	Economy	3400.00
0005432692698	29960	Economy	3400.00
0005434988596	23667	Economy	4000.00
0005434979385	23667	Economy	3600.00
0005434979389	23667	Economy	3600.00
0005434988597	23667	Economy	3600.00
0005434979393	23667	Economy	3600.00
0005434979406	23667	Economy	3600.00
0005434979398	23667	Economy	3600.00
0005434979400	23667	Economy	3600.00
0005434979388	23667	Economy	3600.00
0005434979378	23667	Economy	3600.00
0005434979403	23667	Economy	3600.00
0005434988598	23667	Economy	3600.00
0005434979394	23667	Economy	3600.00
0005434988592	23667	Economy	3600.00
0005434979379	23667	Economy	3600.00
0005434979401	23667	Economy	3600.00
0005434979375	23667	Economy	3600.00
0005434979404	23667	Economy	3600.00
0005434979383	23667	Economy	3600.00
0005434979390	23667	Economy	3600.00
0005434979377	23667	Economy	3600.00
0005434979382	23667	Economy	3600.00
0005434979402	23667	Economy	3600.00
0005434979376	23667	Economy	3600.00
0005434979380	23667	Economy	3600.00
0005434988588	23667	Economy	3600.00
0005434979384	23667	Economy	3600.00
0005434979391	23667	Economy	3600.00
0005434979395	23667	Economy	3600.00
0005434979405	23667	Economy	3600.00
0005434988594	23667	Economy	3600.00
0005434988591	23667	Economy	3600.00
0005434988595	23667	Economy	3600.00
0005434979396	23667	Economy	3600.00
0005434988593	23667	Economy	3600.00
0005434979397	23667	Economy	3600.00
0005434979381	23667	Economy	3600.00
0005434979392	23667	Economy	3600.00
0005434988590	23667	Economy	3600.00
0005434979399	23667	Economy	3600.00
0005434979387	23667	Economy	3600.00
0005434988589	23667	Economy	3600.00
0005434979386	23667	Economy	3600.00
0005434979285	27574	Economy	4000.00
0005434979273	27574	Economy	3600.00
0005434979272	27574	Economy	3600.00
0005434979286	27574	Economy	3600.00
0005434979259	27574	Economy	3600.00
0005434979258	27574	Economy	3600.00
0005434302400	10287	Economy	21600.00
0005434302403	10287	Economy	19700.00
0005434302401	10287	Economy	19700.00
0005434302399	10287	Economy	19700.00
0005434302402	10287	Economy	19700.00
0005433113508	19604	Economy	19700.00
0005433113507	19604	Economy	19700.00
0005433113506	19604	Economy	19700.00
0005435068431	3524	Business	26900.00
0005435068459	3524	Business	26900.00
0005435718867	3524	Business	26900.00
0005435068475	3524	Business	26900.00
0005435068456	3524	Business	26900.00
0005435068437	3524	Business	26900.00
0005435068424	3524	Business	26900.00
0005435068474	3524	Business	26900.00
0005435718864	3524	Business	26900.00
0005435068458	3524	Business	26900.00
0005435068441	3524	Economy	9000.00
0005435068448	3524	Economy	9000.00
0005435068444	3524	Economy	9000.00
0005435068451	3524	Economy	9000.00
0005435068462	3524	Economy	9000.00
0005435068433	3524	Economy	9000.00
0005435068432	3524	Economy	9000.00
0005435068423	3524	Economy	9900.00
0005435068469	3524	Economy	9900.00
0005435068435	3524	Economy	9900.00
0005435068455	3524	Economy	9000.00
0005435068460	3524	Economy	9000.00
0005435718869	3524	Economy	9000.00
0005435068439	3524	Economy	9000.00
0005435068436	3524	Economy	9000.00
0005435068466	3524	Economy	9000.00
0005435718863	3524	Economy	9000.00
0005435068445	3524	Economy	9000.00
0005435068426	3524	Economy	9000.00
0005435068440	3524	Economy	9000.00
0005435068463	3524	Economy	9000.00
0005435068473	3524	Economy	9000.00
0005435068468	3524	Economy	9000.00
0005435068449	3524	Economy	9000.00
0005435068446	3524	Economy	9000.00
0005435068471	3524	Economy	9000.00
0005435068427	3524	Economy	9000.00
0005435068429	3524	Economy	9000.00
0005435068467	3524	Economy	9000.00
0005435718870	3524	Economy	9000.00
0005435068470	3524	Economy	9000.00
0005435718868	3524	Economy	9000.00
0005435068454	3524	Economy	9000.00
0005435068472	3524	Economy	9000.00
0005435068442	3524	Economy	9000.00
0005435068434	3524	Economy	9000.00
0005435068465	3524	Economy	9000.00
0005435068452	3524	Economy	9000.00
0005435068464	3524	Economy	9000.00
0005435068443	3524	Economy	9000.00
0005435068453	3524	Economy	9000.00
0005435068438	3524	Economy	9000.00
0005435068430	3524	Economy	9000.00
0005435068450	3524	Economy	9000.00
0005435068457	3524	Economy	9000.00
0005435068425	3524	Economy	9000.00
0005435718866	3524	Economy	9000.00
0005435718865	3524	Economy	9000.00
0005435068447	3524	Economy	9000.00
0005435068428	3524	Economy	9000.00
0005435068461	3524	Economy	9000.00
0005435925125	15293	Business	26900.00
0005435925127	15293	Economy	9000.00
0005435925124	15293	Economy	9000.00
0005435068190	15293	Economy	9000.00
0005435925123	15293	Economy	9000.00
0005435925121	15293	Economy	9000.00
0005435068191	15293	Economy	9000.00
0005435068264	15293	Economy	9000.00
0005435925122	15293	Economy	9000.00
0005435925126	15293	Economy	9000.00
0005435925128	15293	Economy	9000.00
0005432658565	18145	Economy	5900.00
0005432658566	18145	Economy	5900.00
0005432660791	18145	Economy	5900.00
0005432658564	18145	Economy	5900.00
0005432659680	18145	Economy	5900.00
0005432659681	18145	Economy	5900.00
0005432659679	18145	Economy	5900.00
0005432660792	18145	Economy	5900.00
0005432901300	211	Business	20000.00
0005432157467	211	Economy	6700.00
0005432901312	211	Economy	6700.00
0005432157468	211	Economy	6700.00
0005432901335	211	Economy	6700.00
0005432261344	210	Business	20000.00
0005432288945	210	Business	20000.00
0005432261346	210	Business	20000.00
0005432261359	210	Business	20000.00
0005432817117	210	Business	20000.00
0005432261358	210	Business	20000.00
0005432817100	210	Business	20000.00
0005432261338	210	Business	20000.00
0005432261325	210	Business	20000.00
0005432817112	210	Business	20000.00
0005432817108	210	Business	20000.00
0005432261362	210	Business	20000.00
0005432261361	210	Business	20000.00
0005432261323	210	Economy	7300.00
0005432817118	210	Economy	6700.00
0005432288944	210	Economy	6700.00
0005432817094	210	Economy	6700.00
0005432817095	210	Economy	6700.00
0005432261354	210	Economy	6700.00
0005432261331	210	Economy	6700.00
0005432261327	210	Economy	6700.00
0005432261350	210	Economy	6700.00
0005432817102	210	Economy	6700.00
0005432817106	210	Economy	6700.00
0005432207628	210	Economy	6700.00
0005432261328	210	Economy	6700.00
0005432261347	210	Economy	6700.00
0005432817114	210	Economy	6700.00
0005432261326	210	Economy	6700.00
0005432261364	210	Economy	6700.00
0005432261333	210	Economy	6700.00
0005432261345	210	Economy	6700.00
0005432261322	210	Economy	6700.00
0005434153518	210	Economy	6700.00
0005432261334	210	Economy	6700.00
0005432817104	210	Economy	6700.00
0005432207627	210	Economy	6700.00
0005432261330	210	Economy	6700.00
0005432817105	210	Economy	6700.00
0005432817113	210	Economy	6700.00
0005432817097	210	Economy	6700.00
0005432817089	210	Economy	6700.00
0005432817116	210	Economy	6700.00
0005432261365	210	Economy	7300.00
0005432261337	210	Economy	7300.00
0005432261339	210	Economy	7300.00
0005432261363	210	Economy	7300.00
0005432261357	210	Economy	6700.00
0005432261353	210	Economy	6700.00
0005432288946	210	Economy	6700.00
0005432817101	210	Economy	6700.00
0005432817091	210	Economy	6700.00
0005432261342	210	Economy	6700.00
0005432817092	210	Economy	6700.00
0005432261360	210	Economy	6700.00
0005432261355	210	Economy	6700.00
0005432261340	210	Economy	6700.00
0005432261356	210	Economy	6700.00
0005432817099	210	Economy	6700.00
0005432261324	210	Economy	6700.00
0005432261349	210	Economy	6700.00
0005432261351	210	Economy	6700.00
0005432817109	210	Economy	6700.00
0005432261367	210	Economy	6700.00
0005432817090	210	Economy	6700.00
0005432817110	210	Economy	6700.00
0005432261343	210	Economy	6700.00
0005432261341	210	Economy	6700.00
0005432261352	210	Economy	6700.00
0005432817098	210	Economy	6700.00
0005432817103	210	Economy	6700.00
0005432261336	210	Economy	6700.00
0005432261332	210	Economy	6700.00
0005432817111	210	Economy	6700.00
0005432261348	210	Economy	6700.00
0005432817096	210	Economy	6700.00
0005432817093	210	Economy	6700.00
0005432261329	210	Economy	6700.00
0005432817115	210	Economy	6700.00
0005432261335	210	Economy	6700.00
0005432817107	210	Economy	6700.00
0005432261366	210	Economy	6700.00
0005432751486	7942	Business	20000.00
0005432753260	7942	Business	20000.00
0005433101483	7942	Business	20000.00
0005433101466	7942	Business	20000.00
0005432019920	7942	Business	20000.00
0005432045589	7942	Business	20000.00
0005433101470	7942	Business	20000.00
0005433101491	7942	Business	20000.00
0005432019936	7942	Business	20000.00
0005432045591	7942	Business	20000.00
0005433101475	7942	Business	20000.00
0005432919594	7942	Business	20000.00
0005432677524	7942	Business	20000.00
0005433101500	7942	Business	20000.00
0005432919590	7942	Business	20000.00
0005432919605	7942	Business	20000.00
0005433101480	7942	Business	20000.00
0005433101465	7942	Business	20000.00
0005433101459	7942	Business	20000.00
0005432391962	7942	Business	20000.00
0005432044491	7942	Business	20000.00
0005432919591	7942	Business	20000.00
0005432019937	7942	Business	20000.00
0005432019942	7942	Economy	7300.00
0005433101477	7942	Economy	7300.00
0005432677526	7942	Economy	7300.00
0005432753259	7942	Economy	7300.00
0005432019928	7942	Economy	6700.00
0005433101494	7942	Economy	6700.00
0005432019926	7942	Economy	6700.00
0005432019943	7942	Economy	6700.00
0005433101514	7942	Economy	6700.00
0005433101496	7942	Economy	6700.00
0005433101515	7942	Economy	6700.00
0005432019923	7942	Economy	6700.00
0005432919596	7942	Economy	6700.00
0005432677525	7942	Economy	6700.00
0005432019939	7942	Economy	6700.00
0005432751485	7942	Economy	6700.00
0005433101513	7942	Economy	6700.00
0005433101508	7942	Economy	6700.00
0005432677527	7942	Economy	6700.00
0005433101476	7942	Economy	6700.00
0005432919588	7942	Economy	6700.00
0005432019921	7942	Economy	6700.00
0005433101511	7942	Economy	6700.00
0005433101460	7942	Economy	6700.00
0005433101509	7942	Economy	6700.00
0005432919607	7942	Economy	6700.00
0005432919606	7942	Economy	6700.00
0005432391961	7942	Economy	6700.00
0005432019925	7942	Economy	6700.00
0005432019938	7942	Economy	6700.00
0005432019932	7942	Economy	6700.00
0005433101481	7942	Economy	6700.00
0005433101510	7942	Economy	6700.00
0005432019919	7942	Economy	6700.00
0005432019924	7942	Economy	6700.00
0005432751487	7942	Economy	6700.00
0005433101489	7942	Economy	6700.00
0005432919595	7942	Economy	6700.00
0005433101485	7942	Economy	6700.00
0005433101503	7942	Economy	6700.00
0005433101487	7942	Economy	6700.00
0005432019929	7942	Economy	6700.00
0005433101482	7942	Economy	6700.00
0005433101462	7942	Economy	6700.00
0005432919589	7942	Economy	6700.00
0005432019927	7942	Economy	6700.00
0005433101516	7942	Economy	6700.00
0005433101479	7942	Economy	6700.00
0005433101501	7942	Economy	6700.00
0005432919600	7942	Economy	6700.00
0005433101464	7942	Economy	6700.00
0005432019930	7942	Economy	7300.00
0005432753261	7942	Economy	7300.00
0005432044490	7942	Economy	7300.00
0005433101474	7942	Economy	7300.00
0005432919601	7942	Economy	6700.00
0005433101497	7942	Economy	6700.00
0005432391964	7942	Economy	6700.00
0005433101502	7942	Economy	6700.00
0005433101498	7942	Economy	7300.00
0005433101472	7942	Economy	6700.00
0005433101506	7942	Economy	6700.00
0005432019922	7942	Economy	6700.00
0005433101505	7942	Economy	6700.00
0005433101471	7942	Economy	6700.00
0005433101473	7942	Economy	6700.00
0005433101493	7942	Economy	6700.00
0005433101512	7942	Economy	6700.00
0005433101468	7942	Economy	6700.00
0005432019935	7942	Economy	6700.00
0005433101488	7942	Economy	6700.00
0005432919593	7942	Economy	6700.00
0005432919602	7942	Economy	6700.00
0005432919604	7942	Economy	6700.00
0005433101469	7942	Economy	6700.00
0005432019940	7942	Economy	6700.00
0005433101467	7942	Economy	6700.00
0005432919599	7942	Economy	6700.00
0005432919592	7942	Economy	6700.00
0005432045590	7942	Economy	6700.00
0005432391963	7942	Economy	6700.00
0005432919608	7942	Economy	6700.00
0005432019918	7942	Economy	6700.00
0005432019933	7942	Economy	6700.00
0005433101490	7942	Economy	6700.00
0005432019934	7942	Economy	6700.00
0005432019917	7942	Economy	6700.00
0005433101492	7942	Economy	6700.00
0005432044489	7942	Economy	6700.00
0005433101461	7942	Economy	6700.00
0005433101507	7942	Economy	6700.00
0005432019916	7942	Economy	6700.00
0005433101486	7942	Economy	6700.00
0005433101478	7942	Economy	6700.00
0005432919603	7942	Economy	6700.00
0005433101484	7942	Economy	6700.00
0005432919598	7942	Economy	6700.00
0005433101463	7942	Economy	6700.00
0005432019941	7942	Economy	6700.00
0005433101504	7942	Economy	6700.00
0005432751484	7942	Economy	6700.00
0005433101495	7942	Economy	6700.00
0005432019931	7942	Economy	6700.00
0005432919609	7942	Economy	6700.00
0005433101499	7942	Economy	6700.00
0005432919597	7942	Economy	6700.00
0005432901393	7938	Business	20000.00
0005432901394	7938	Business	20000.00
0005432901390	7938	Economy	6700.00
0005432901389	7938	Economy	6700.00
0005432901388	7938	Economy	6700.00
0005432901396	7938	Economy	6700.00
0005432901386	7938	Economy	6700.00
0005432901387	7938	Economy	6700.00
0005432901401	7938	Economy	6700.00
0005432816972	7938	Economy	6700.00
0005432901399	7938	Economy	6700.00
0005432901384	7938	Economy	6700.00
0005432816938	7938	Economy	6700.00
0005432002050	7938	Economy	7300.00
0005432901397	7938	Economy	6700.00
0005432901395	7938	Economy	6700.00
0005432901392	7938	Economy	6700.00
0005432901400	7938	Economy	6700.00
0005432901398	7938	Economy	6700.00
0005432901385	7938	Economy	6700.00
0005432002051	7938	Economy	6700.00
0005432901391	7938	Economy	6700.00
0005433870703	9659	Economy	6900.00
0005433870704	9659	Economy	6900.00
0005434175700	32372	Economy	6900.00
0005434175701	32372	Economy	6900.00
0005434175699	32372	Economy	6900.00
0005434175698	32372	Economy	6900.00
0005434877111	3518	Business	35000.00
0005432188567	3518	Business	35000.00
0005434877097	3518	Business	35000.00
0005434877065	3518	Business	35000.00
0005434877128	3518	Business	35000.00
0005434877091	3518	Business	35000.00
0005435125882	3518	Business	35000.00
0005434877114	3518	Business	35000.00
0005434877053	3518	Business	35000.00
0005434877095	3518	Business	35000.00
0005434877113	3518	Business	35000.00
0005434426239	3518	Business	35000.00
0005434877080	3518	Business	35000.00
0005434426237	3518	Business	35000.00
0005434877067	3518	Business	35000.00
0005432799118	3518	Business	35000.00
0005434937907	3518	Business	35000.00
0005435125876	3518	Business	35000.00
0005434877108	3518	Business	35000.00
0005434426257	3518	Business	35000.00
0005432613809	3518	Business	35000.00
0005435625953	3518	Business	35000.00
0005434877055	3518	Business	35000.00
0005432188566	3518	Business	35000.00
0005434877051	3518	Business	35000.00
0005434937896	3518	Comfort	19900.00
0005434426255	3518	Comfort	19900.00
0005434877056	3518	Comfort	19900.00
0005435625970	3518	Comfort	19900.00
0005435625963	3518	Comfort	19900.00
0005434937897	3518	Comfort	19900.00
0005434877112	3518	Comfort	19900.00
0005434877060	3518	Comfort	19900.00
0005434877057	3518	Comfort	19900.00
0005434877074	3518	Comfort	19900.00
0005432183439	3518	Comfort	19900.00
0005434877118	3518	Comfort	19900.00
0005435125883	3518	Comfort	19900.00
0005434426240	3518	Comfort	19900.00
0005434937898	3518	Comfort	19900.00
0005434877109	3518	Comfort	19900.00
0005434877105	3518	Comfort	19900.00
0005434937906	3518	Comfort	19900.00
0005434877062	3518	Comfort	19900.00
0005432799123	3518	Comfort	19900.00
0005434877127	3518	Comfort	19900.00
0005434426246	3518	Comfort	19900.00
0005434937905	3518	Comfort	19900.00
0005434877131	3518	Comfort	19900.00
0005435125874	3518	Comfort	19900.00
0005432613811	3518	Comfort	19900.00
0005435125887	3518	Comfort	19900.00
0005434937911	3518	Comfort	19900.00
0005432799105	3518	Comfort	19900.00
0005434877119	3518	Comfort	19900.00
0005434877092	3518	Economy	11700.00
0005432799106	3518	Economy	11700.00
0005435125872	3518	Economy	11700.00
0005434426243	3518	Economy	11700.00
0005434426250	3518	Economy	11700.00
0005435125885	3518	Economy	11700.00
0005434877082	3518	Economy	11700.00
0005435125875	3518	Economy	11700.00
0005434877099	3518	Economy	11700.00
0005434877043	3518	Economy	11700.00
0005434877052	3518	Economy	11700.00
0005435125884	3518	Economy	11700.00
0005435125865	3518	Economy	11700.00
0005434877096	3518	Economy	11700.00
0005432183440	3518	Economy	11700.00
0005435125891	3518	Economy	11700.00
0005435625949	3518	Economy	11700.00
0005435125873	3518	Economy	11700.00
0005435125868	3518	Economy	11700.00
0005434877066	3518	Economy	11700.00
0005434877132	3518	Economy	11700.00
0005432611659	3518	Economy	11700.00
0005435125879	3518	Economy	11700.00
0005432799120	3518	Economy	11700.00
0005434426256	3518	Economy	11700.00
0005435125863	3518	Economy	11700.00
0005432799110	3518	Economy	11700.00
0005435625952	3518	Economy	11700.00
0005434937900	3518	Economy	11700.00
0005434426245	3518	Economy	11700.00
0005434877063	3518	Economy	11700.00
0005434426261	3518	Economy	11700.00
0005435125867	3518	Economy	11700.00
0005435125877	3518	Economy	11700.00
0005432799119	3518	Economy	11700.00
0005434877087	3518	Economy	11700.00
0005435625950	3518	Economy	11700.00
0005434877130	3518	Economy	11700.00
0005435625969	3518	Economy	11700.00
0005434877058	3518	Economy	11700.00
0005434877048	3518	Economy	11700.00
0005434877040	3518	Economy	11700.00
0005435125862	3518	Economy	11700.00
0005432799111	3518	Economy	11700.00
0005435125864	3518	Economy	11700.00
0005434426247	3518	Economy	11700.00
0005434877044	3518	Economy	11700.00
0005435125871	3518	Economy	12800.00
0005434877126	3518	Economy	11700.00
0005434426238	3518	Economy	11700.00
0005434877098	3518	Economy	11700.00
0005434877117	3518	Economy	11700.00
0005435125878	3518	Economy	12800.00
0005435625957	3518	Economy	12800.00
0005435625966	3518	Economy	11700.00
0005434426258	3518	Economy	11700.00
0005434877079	3518	Economy	11700.00
0005435625960	3518	Economy	11700.00
0005434877090	3518	Economy	11700.00
0005435125889	3518	Economy	11700.00
0005434877072	3518	Economy	11700.00
0005434877064	3518	Economy	11700.00
0005434877069	3518	Economy	11700.00
0005434877101	3518	Economy	11700.00
0005432799107	3518	Economy	11700.00
0005434426241	3518	Economy	11700.00
0005434426236	3518	Economy	11700.00
0005434877075	3518	Economy	11700.00
0005434426249	3518	Economy	11700.00
0005432799109	3518	Economy	11700.00
0005432799122	3518	Economy	11700.00
0005434877071	3518	Economy	11700.00
0005434877121	3518	Economy	11700.00
0005434877136	3518	Economy	11700.00
0005435625959	3518	Economy	11700.00
0005435125893	3518	Economy	11700.00
0005435125881	3518	Economy	11700.00
0005435125861	3518	Economy	11700.00
0005434877042	3518	Economy	11700.00
0005434877129	3518	Economy	11700.00
0005435125895	3518	Economy	11700.00
0005434426253	3518	Economy	11700.00
0005435625954	3518	Economy	11700.00
0005434426254	3518	Economy	11700.00
0005435125858	3518	Economy	11700.00
0005435125896	3518	Economy	11700.00
0005434877070	3518	Economy	11700.00
0005432799100	3518	Economy	11700.00
0005434426264	3518	Economy	11700.00
0005435125880	3518	Economy	11700.00
0005434426252	3518	Economy	11700.00
0005435125866	3518	Economy	11700.00
0005434877103	3518	Economy	11700.00
0005434877059	3518	Economy	11700.00
0005435125859	3518	Economy	11700.00
0005432799103	3518	Economy	11700.00
0005434877100	3518	Economy	11700.00
0005434937892	3518	Economy	11700.00
0005434877123	3518	Economy	11700.00
0005434877134	3518	Economy	11700.00
0005434877115	3518	Economy	11700.00
0005434877073	3518	Economy	11700.00
0005432613812	3518	Economy	11700.00
0005434426260	3518	Economy	11700.00
0005434426262	3518	Economy	11700.00
0005434877078	3518	Economy	11700.00
0005434877093	3518	Economy	11700.00
0005432611660	3518	Economy	11700.00
0005434937909	3518	Economy	11700.00
0005434877107	3518	Economy	11700.00
0005435125892	3518	Economy	11700.00
0005434877081	3518	Economy	11700.00
0005434877088	3518	Economy	11700.00
0005434937904	3518	Economy	11700.00
0005434937899	3518	Economy	11700.00
0005434877041	3518	Economy	11700.00
0005432799104	3518	Economy	11700.00
0005435625955	3518	Economy	11700.00
0005434877102	3518	Economy	11700.00
0005434877085	3518	Economy	11700.00
0005434877122	3518	Economy	11700.00
0005432799113	3518	Economy	12800.00
0005434877047	3518	Economy	11700.00
0005434877045	3518	Economy	12800.00
0005432613810	3518	Economy	12800.00
0005434937908	3518	Economy	11700.00
0005434877094	3518	Economy	12800.00
0005434426259	3518	Economy	11700.00
0005435625967	3518	Economy	11700.00
0005434877061	3518	Economy	11700.00
0005434937910	3518	Economy	11700.00
0005435625958	3518	Economy	11700.00
0005432799108	3518	Economy	11700.00
0005435625962	3518	Economy	11700.00
0005435625951	3518	Economy	11700.00
0005434877046	3518	Economy	11700.00
0005435902393	3518	Economy	11700.00
0005434877137	3518	Economy	11700.00
0005435125869	3518	Economy	11700.00
0005432799117	3518	Economy	11700.00
0005435625964	3518	Economy	11700.00
0005432611661	3518	Economy	11700.00
0005434426244	3518	Economy	11700.00
0005435125856	3518	Economy	11700.00
0005434877106	3518	Economy	11700.00
0005434937893	3518	Economy	11700.00
0005434426248	3518	Economy	11700.00
0005435625965	3518	Economy	11700.00
0005434877125	3518	Economy	11700.00
0005434877054	3518	Economy	11700.00
0005434877110	3518	Economy	11700.00
0005432188568	3518	Economy	11700.00
0005432799099	3518	Economy	11700.00
0005434877089	3518	Economy	11700.00
0005432799121	3518	Economy	11700.00
0005434877135	3518	Economy	11700.00
0005434877084	3518	Economy	11700.00
0005432799115	3518	Economy	11700.00
0005435625968	3518	Economy	11700.00
0005432799125	3518	Economy	11700.00
0005434877133	3518	Economy	11700.00
0005434426242	3518	Economy	11700.00
0005434937903	3518	Economy	11700.00
0005432799112	3518	Economy	11700.00
0005435125870	3518	Economy	11700.00
0005432799116	3518	Economy	11700.00
0005434937901	3518	Economy	11700.00
0005434426251	3518	Economy	11700.00
0005435125860	3518	Economy	11700.00
0005435125894	3518	Economy	11700.00
0005434877120	3518	Economy	11700.00
0005435125888	3518	Economy	11700.00
0005435125890	3518	Economy	11700.00
0005434877124	3518	Economy	11700.00
0005432799102	3518	Economy	11700.00
0005435125857	3518	Economy	11700.00
0005435625961	3518	Economy	11700.00
0005435125886	3518	Economy	11700.00
0005434877083	3518	Economy	11700.00
0005434877104	3518	Economy	11700.00
0005432799101	3518	Economy	11700.00
0005434937902	3518	Economy	11700.00
0005434877077	3518	Economy	11700.00
0005432799114	3518	Economy	11700.00
0005434877086	3518	Economy	11700.00
0005434877049	3518	Economy	11700.00
0005434877076	3518	Economy	11700.00
0005432611662	3518	Economy	11700.00
0005434877116	3518	Economy	11700.00
0005434877050	3518	Economy	11700.00
0005435625956	3518	Economy	11700.00
0005434937895	3518	Economy	11700.00
0005434877068	3518	Economy	11700.00
0005432799098	3518	Economy	11700.00
0005434426263	3518	Economy	11700.00
0005432799124	3518	Economy	11700.00
0005434937894	3518	Economy	11700.00
0005434937805	14540	Business	35000.00
0005435913879	14540	Business	35000.00
0005434937817	14540	Business	35000.00
0005434876654	14540	Business	35000.00
0005435913882	14540	Business	35000.00
0005435902485	14540	Business	35000.00
0005435913878	14540	Business	35000.00
0005435902484	14540	Business	35000.00
0005435902490	14540	Comfort	19900.00
0005435913886	14540	Comfort	19900.00
0005435902480	14540	Comfort	19900.00
0005435913880	14540	Comfort	19900.00
0005435913885	14540	Comfort	19900.00
0005434426084	14540	Comfort	19900.00
0005434876789	14540	Comfort	19900.00
0005435902475	14540	Comfort	19900.00
0005435902486	14540	Comfort	19900.00
0005435913887	14540	Comfort	19900.00
0005435842318	14540	Comfort	19900.00
0005435913877	14540	Comfort	19900.00
0005434876655	14540	Comfort	19900.00
0005434937816	14540	Comfort	19900.00
0005435902487	14540	Economy	11700.00
0005435913875	14540	Economy	11700.00
0005435913888	14540	Economy	11700.00
0005434937798	14540	Economy	11700.00
0005435902488	14540	Economy	11700.00
0005434876788	14540	Economy	11700.00
0005434876608	14540	Economy	11700.00
0005435902481	14540	Economy	11700.00
0005434426090	14540	Economy	11700.00
0005435914684	14540	Economy	11700.00
0005435913881	14540	Economy	11700.00
0005435902478	14540	Economy	11700.00
0005434876568	14540	Economy	11700.00
0005435902479	14540	Economy	11700.00
0005435902491	14540	Economy	11700.00
0005435914687	14540	Economy	11700.00
0005435902476	14540	Economy	11700.00
0005435902483	14540	Economy	11700.00
0005434937797	14540	Economy	11700.00
0005435913883	14540	Economy	11700.00
0005432059481	14540	Economy	11700.00
0005432059479	14540	Economy	11700.00
0005435902482	14540	Economy	12800.00
0005435902477	14540	Economy	11700.00
0005435842317	14540	Economy	11700.00
0005435902489	14540	Economy	11700.00
0005434937804	14540	Economy	11700.00
0005435902492	14540	Economy	11700.00
0005435914686	14540	Economy	11700.00
0005432059480	14540	Economy	11700.00
0005435914685	14540	Economy	11700.00
0005434876622	14540	Economy	11700.00
0005435913884	14540	Economy	11700.00
0005435841812	14540	Economy	11700.00
0005434426089	14540	Economy	11700.00
0005435913876	14540	Economy	11700.00
0005434325506	3621	Economy	16300.00
0005434312292	3621	Economy	14800.00
0005434325508	3621	Economy	14800.00
0005434325509	3621	Economy	14800.00
0005434325510	3621	Economy	14800.00
0005434312293	3621	Economy	14800.00
0005434325507	3621	Economy	14800.00
0005434325505	3621	Economy	14800.00
0005434325511	3621	Economy	14800.00
0005434325512	3621	Economy	14800.00
0005434325504	3621	Economy	14800.00
0005434325513	3621	Economy	14800.00
0005434325444	15623	Economy	16300.00
0005435889824	15623	Economy	14800.00
0005435889822	15623	Economy	14800.00
0005435889820	15623	Economy	14800.00
0005435889819	15623	Economy	14800.00
0005435889823	15623	Economy	14800.00
0005435889821	15623	Economy	14800.00
0005434325460	15623	Economy	14800.00
0005435957516	663	Economy	4500.00
0005435957524	663	Economy	4500.00
0005435957523	663	Economy	4500.00
0005435957520	663	Economy	4100.00
0005435957525	663	Economy	4100.00
0005435957522	663	Economy	4100.00
0005435957527	663	Economy	4100.00
0005433420253	663	Economy	4100.00
0005433420252	663	Economy	4100.00
0005435957517	663	Economy	4100.00
0005435957521	663	Economy	4100.00
0005435957528	663	Economy	4100.00
0005435957518	663	Economy	4100.00
0005435957515	663	Economy	4100.00
0005435957514	663	Economy	4100.00
0005435957526	663	Economy	4100.00
0005435957519	663	Economy	4100.00
0005433420300	15166	Economy	4100.00
0005433420295	15166	Economy	4100.00
0005433420297	15166	Economy	4100.00
0005433420293	15166	Economy	4100.00
0005433420296	15166	Economy	4100.00
0005433420294	15166	Economy	4100.00
0005433420299	15166	Economy	4100.00
0005433420298	15166	Economy	4100.00
0005435629390	8904	Economy	10400.00
0005435629389	8904	Economy	10400.00
0005434247115	16049	Economy	10400.00
0005434247114	16049	Economy	10400.00
0005434247116	16049	Economy	10400.00
0005435933405	29524	Economy	12200.00
0005435933413	29524	Economy	12200.00
0005435933407	29524	Economy	12200.00
0005435933409	29524	Economy	12200.00
0005435933408	29524	Economy	12200.00
0005435933406	29524	Economy	12200.00
0005435933410	29524	Economy	12200.00
0005435933411	29524	Economy	12200.00
0005435933404	29524	Economy	12200.00
0005435933412	29524	Economy	12200.00
0005435797299	2835	Business	12600.00
0005435797296	2835	Business	12600.00
0005435797306	2835	Economy	4200.00
0005435797297	2835	Economy	4200.00
0005435797303	2835	Economy	4600.00
0005435797300	2835	Economy	4200.00
0005435797308	2835	Economy	4200.00
0005435797301	2835	Economy	4200.00
0005435797307	2835	Economy	4200.00
0005435797294	2835	Economy	4200.00
0005435797302	2835	Economy	4200.00
0005435797304	2835	Economy	4200.00
0005435797298	2835	Economy	4200.00
0005435797295	2835	Economy	4200.00
0005435797305	2835	Economy	4200.00
0005435797227	29296	Business	12600.00
0005435797244	29296	Economy	4200.00
0005433404720	29296	Economy	4200.00
0005433404719	29296	Economy	4200.00
0005435797224	29296	Economy	4200.00
0005435797225	29296	Economy	4200.00
0005433404718	29296	Economy	4200.00
0005433404721	29296	Economy	4200.00
0005433404716	29296	Economy	4200.00
0005433404717	29296	Economy	4200.00
0005433404715	29296	Economy	4200.00
0005435376314	5740	Economy	6800.00
0005434947920	5798	Economy	6800.00
0005434947921	5798	Economy	6800.00
0005434947916	5798	Economy	6800.00
0005434947915	5798	Economy	6800.00
0005434947919	5798	Economy	6800.00
0005434947914	5798	Economy	6800.00
0005434947918	5798	Economy	6800.00
0005434947917	5798	Economy	6800.00
0005435376325	16411	Economy	6800.00
0005435376322	16411	Economy	6800.00
0005435376323	16411	Economy	6800.00
0005434947868	16411	Economy	6800.00
0005435376324	16411	Economy	6800.00
0005433960159	6909	Business	21400.00
0005433960149	6909	Business	21400.00
0005433960200	6909	Business	21400.00
0005433960198	6909	Business	21400.00
0005433960152	6909	Business	21400.00
0005433960196	6909	Business	21400.00
0005433960175	6909	Business	21400.00
0005433960189	6909	Economy	7100.00
0005433960193	6909	Economy	7100.00
0005433960168	6909	Economy	7100.00
0005433960206	6909	Economy	7100.00
0005433960204	6909	Economy	7100.00
0005433960195	6909	Economy	7100.00
0005433960160	6909	Economy	7100.00
0005433960197	6909	Economy	7100.00
0005433960182	6909	Economy	7800.00
0005433960184	6909	Economy	7800.00
0005433960199	6909	Economy	7100.00
0005433960173	6909	Economy	7100.00
0005433960144	6909	Economy	7100.00
0005433960179	6909	Economy	7100.00
0005433960164	6909	Economy	7100.00
0005433960181	6909	Economy	7100.00
0005433960188	6909	Economy	7100.00
0005433960157	6909	Economy	7100.00
0005433960142	6909	Economy	7100.00
0005433960162	6909	Economy	7100.00
0005433960201	6909	Economy	7100.00
0005433960171	6909	Economy	7100.00
0005433960191	6909	Economy	7100.00
0005433960170	6909	Economy	7100.00
0005433960174	6909	Economy	7100.00
0005433960172	6909	Economy	7100.00
0005433960169	6909	Economy	7100.00
0005433960185	6909	Economy	7100.00
0005433960167	6909	Economy	7100.00
0005433960145	6909	Economy	7100.00
0005433960151	6909	Economy	7100.00
0005433960194	6909	Economy	7100.00
0005433960153	6909	Economy	7100.00
0005433960176	6909	Economy	7100.00
0005433960178	6909	Economy	7100.00
0005433960177	6909	Economy	7100.00
0005433960187	6909	Economy	7100.00
0005433960190	6909	Economy	7100.00
0005433960165	6909	Economy	7100.00
0005433960205	6909	Economy	7100.00
0005433960203	6909	Economy	7100.00
0005433960143	6909	Economy	7100.00
0005433960146	6909	Economy	7100.00
0005433960150	6909	Economy	7100.00
0005433960183	6909	Economy	7100.00
0005433960192	6909	Economy	7100.00
0005433960155	6909	Economy	7100.00
0005433960208	6909	Economy	7100.00
0005433960161	6909	Economy	7100.00
0005433960148	6909	Economy	7100.00
0005433960163	6909	Economy	7100.00
0005433960147	6909	Economy	7100.00
0005433960158	6909	Economy	7100.00
0005433960166	6909	Economy	7100.00
0005433960186	6909	Economy	7100.00
0005433960156	6909	Economy	7100.00
0005433960207	6909	Economy	7100.00
0005433960180	6909	Economy	7100.00
0005433960202	6909	Economy	7100.00
0005433960154	6909	Economy	7100.00
0005435082648	24458	Economy	3900.00
0005435082643	24458	Economy	3900.00
0005435082649	24458	Economy	3900.00
0005435082680	26090	Economy	3900.00
0005435082679	26090	Economy	3900.00
0005435082678	26090	Economy	3900.00
0005435082681	26090	Economy	3900.00
0005435082682	26090	Economy	3900.00
0005435082683	26090	Economy	3900.00
0005434244614	5196	Business	18000.00
0005434244610	5196	Business	18000.00
0005434244623	5196	Business	18000.00
0005434244611	5196	Business	18000.00
0005434244609	5196	Business	18000.00
0005434244618	5196	Business	18000.00
0005434244620	5196	Economy	6000.00
0005434244630	5196	Economy	6000.00
0005434244631	5196	Economy	6000.00
0005434244629	5196	Economy	6000.00
0005432166862	5196	Economy	6000.00
0005434244628	5196	Economy	6000.00
0005434244605	5196	Economy	6000.00
0005434244621	5196	Economy	6000.00
0005434244633	5196	Economy	6000.00
0005434244615	5196	Economy	6000.00
0005434244608	5196	Economy	6000.00
0005432166860	5196	Economy	6000.00
0005434244604	5196	Economy	6600.00
0005434244624	5196	Economy	6600.00
0005434244616	5196	Economy	6000.00
0005434244625	5196	Economy	6000.00
0005434244612	5196	Economy	6000.00
0005434244613	5196	Economy	6000.00
0005432166861	5196	Economy	6000.00
0005434244607	5196	Economy	6000.00
0005434244606	5196	Economy	6000.00
0005434244617	5196	Economy	6000.00
0005434244632	5196	Economy	6000.00
0005434244626	5196	Economy	6000.00
0005434244619	5196	Economy	6000.00
0005434244627	5196	Economy	6000.00
0005434244622	5196	Economy	6000.00
0005433784517	5197	Business	18000.00
0005433784500	5197	Business	18000.00
0005433613830	5197	Business	18000.00
0005433613798	5197	Business	18000.00
0005433784483	5197	Business	18000.00
0005432666361	5197	Business	18000.00
0005433613797	5197	Business	18000.00
0005432104972	5197	Business	18000.00
0005433784513	5197	Business	18000.00
0005433784498	5197	Business	18000.00
0005432104995	5197	Business	18000.00
0005433613811	5197	Business	18000.00
0005433784481	5197	Business	18000.00
0005432104977	5197	Business	18000.00
0005432104970	5197	Business	18000.00
0005432105000	5197	Business	18000.00
0005433613813	5197	Business	18000.00
0005433613810	5197	Business	18000.00
0005433613778	5197	Business	18000.00
0005432104967	5197	Business	18000.00
0005432104958	5197	Business	18000.00
0005433613823	5197	Business	18000.00
0005433613819	5197	Business	18000.00
0005433784478	5197	Business	18000.00
0005433784506	5197	Business	18000.00
0005433784488	5197	Business	18000.00
0005433613834	5197	Business	18000.00
0005433613776	5197	Business	18000.00
0005432104987	5197	Economy	6600.00
0005432104981	5197	Economy	6600.00
0005433613792	5197	Economy	6600.00
0005432104986	5197	Economy	6600.00
0005433613820	5197	Economy	6600.00
0005433784477	5197	Economy	6600.00
0005433784516	5197	Economy	6000.00
0005432104956	5197	Economy	6000.00
0005432104962	5197	Economy	6000.00
0005433784493	5197	Economy	6000.00
0005433784507	5197	Economy	6000.00
0005432104989	5197	Economy	6000.00
0005432104960	5197	Economy	6000.00
0005433613793	5197	Economy	6000.00
0005433784491	5197	Economy	6000.00
0005433613773	5197	Economy	6000.00
0005433613775	5197	Economy	6000.00
0005432104996	5197	Economy	6000.00
0005432666362	5197	Economy	6000.00
0005432104965	5197	Economy	6000.00
0005433613777	5197	Economy	6000.00
0005433613807	5197	Economy	6000.00
0005432104957	5197	Economy	6000.00
0005432104983	5197	Economy	6000.00
0005433784508	5197	Economy	6000.00
0005432104976	5197	Economy	6000.00
0005433613800	5197	Economy	6000.00
0005433613786	5197	Economy	6000.00
0005433784485	5197	Economy	6000.00
0005433784480	5197	Economy	6000.00
0005432104968	5197	Economy	6000.00
0005432104961	5197	Economy	6000.00
0005433613781	5197	Economy	6000.00
0005432105004	5197	Economy	6000.00
0005433613815	5197	Economy	6000.00
0005433613818	5197	Economy	6000.00
0005433613806	5197	Economy	6000.00
0005433613832	5197	Economy	6000.00
0005433613791	5197	Economy	6000.00
0005433784501	5197	Economy	6000.00
0005433613804	5197	Economy	6000.00
0005433784504	5197	Economy	6000.00
0005433784495	5197	Economy	6000.00
0005433613790	5197	Economy	6000.00
0005433784502	5197	Economy	6000.00
0005432104963	5197	Economy	6000.00
0005432104988	5197	Economy	6000.00
0005433784487	5197	Economy	6000.00
0005432665249	5197	Economy	6000.00
0005432104994	5197	Economy	6000.00
0005432104993	5197	Economy	6000.00
0005432104974	5197	Economy	6000.00
0005432104966	5197	Economy	6000.00
0005433784509	5197	Economy	6000.00
0005433784482	5197	Economy	6000.00
0005433613826	5197	Economy	6000.00
0005433613816	5197	Economy	6000.00
0005433613769	5197	Economy	6000.00
0005433613827	5197	Economy	6000.00
0005433613765	5197	Economy	6000.00
0005433613808	5197	Economy	6000.00
0005433784505	5197	Economy	6000.00
0005433613774	5197	Economy	6000.00
0005433613814	5197	Economy	6000.00
0005433613821	5197	Economy	6000.00
0005433613768	5197	Economy	6600.00
0005432104980	5197	Economy	6000.00
0005433784479	5197	Economy	6600.00
0005433784503	5197	Economy	6600.00
0005432104997	5197	Economy	6600.00
0005433613767	5197	Economy	6600.00
0005433784497	5197	Economy	6000.00
0005433613766	5197	Economy	6000.00
0005433613779	5197	Economy	6000.00
0005433613805	5197	Economy	6000.00
0005433613833	5197	Economy	6600.00
0005433613824	5197	Economy	6000.00
0005433784512	5197	Economy	6000.00
0005432104998	5197	Economy	6000.00
0005432104992	5197	Economy	6000.00
0005433613772	5197	Economy	6000.00
0005432104969	5197	Economy	6000.00
0005433784490	5197	Economy	6000.00
0005433613771	5197	Economy	6000.00
0005432105001	5197	Economy	6000.00
0005433613764	5197	Economy	6000.00
0005432145086	5197	Economy	6000.00
0005433613794	5197	Economy	6000.00
0005432104973	5197	Economy	6000.00
0005433613787	5197	Economy	6000.00
0005432145087	5197	Economy	6000.00
0005433613788	5197	Economy	6000.00
0005433613801	5197	Economy	6000.00
0005433613822	5197	Economy	6000.00
0005433613817	5197	Economy	6000.00
0005432104979	5197	Economy	6000.00
0005432104964	5197	Economy	6000.00
0005433784510	5197	Economy	6000.00
0005432667428	5197	Economy	6000.00
0005433613782	5197	Economy	6000.00
0005433613763	5197	Economy	6000.00
0005433613828	5197	Economy	6000.00
0005433784496	5197	Economy	6000.00
0005433613831	5197	Economy	6000.00
0005433784489	5197	Economy	6000.00
0005433613789	5197	Economy	6000.00
0005433613803	5197	Economy	6000.00
0005433784499	5197	Economy	6000.00
0005432105002	5197	Economy	6000.00
0005433784511	5197	Economy	6000.00
0005433784484	5197	Economy	6000.00
0005433784486	5197	Economy	6000.00
0005432104959	5197	Economy	6000.00
0005433613785	5197	Economy	6000.00
0005433613762	5197	Economy	6000.00
0005432104985	5197	Economy	6000.00
0005433784492	5197	Economy	6000.00
0005433613796	5197	Economy	6000.00
0005433613795	5197	Economy	6000.00
0005433613761	5197	Economy	6000.00
0005433613809	5197	Economy	6000.00
0005432104991	5197	Economy	6000.00
0005433613825	5197	Economy	6000.00
0005433613802	5197	Economy	6000.00
0005433613780	5197	Economy	6000.00
0005432104982	5197	Economy	6000.00
0005432104984	5197	Economy	6000.00
0005433784515	5197	Economy	6000.00
0005433613812	5197	Economy	6000.00
0005433613829	5197	Economy	6000.00
0005432104971	5197	Economy	6000.00
0005433784514	5197	Economy	6000.00
0005432104975	5197	Economy	6000.00
0005432105003	5197	Economy	6000.00
0005432104990	5197	Economy	6000.00
0005432104978	5197	Economy	6000.00
0005433613784	5197	Economy	6000.00
0005433613799	5197	Economy	6000.00
0005432104999	5197	Economy	6000.00
0005433613783	5197	Economy	6000.00
0005433784494	5197	Economy	6000.00
0005433613770	5197	Economy	6000.00
0005434229100	5202	Business	18000.00
0005435006602	5202	Business	18000.00
0005434173471	5202	Business	18000.00
0005434264815	5202	Business	18000.00
0005434229096	5202	Business	18000.00
0005434264825	5202	Business	18000.00
0005434264814	5202	Business	18000.00
0005434264833	5202	Business	18000.00
0005434149580	5202	Business	18000.00
0005434149591	5202	Business	18000.00
0005434149592	5202	Economy	6000.00
0005434173472	5202	Economy	6000.00
0005434264821	5202	Economy	6000.00
0005434264829	5202	Economy	6000.00
0005434264828	5202	Economy	6000.00
0005434264823	5202	Economy	6000.00
0005434229082	5202	Economy	6000.00
0005434264817	5202	Economy	6000.00
0005434264809	5202	Economy	6000.00
0005434149587	5202	Economy	6000.00
0005434149584	5202	Economy	6000.00
0005435006601	5202	Economy	6000.00
0005435006629	5202	Economy	6000.00
0005434229097	5202	Economy	6000.00
0005434149583	5202	Economy	6000.00
0005434229084	5202	Economy	6000.00
0005434229092	5202	Economy	6000.00
0005434229095	5202	Economy	6000.00
0005434229094	5202	Economy	6000.00
0005434229090	5202	Economy	6000.00
0005434264819	5202	Economy	6000.00
0005434173468	5202	Economy	6000.00
0005434149585	5202	Economy	6000.00
0005434264818	5202	Economy	6000.00
0005435006603	5202	Economy	6000.00
0005434229089	5202	Economy	6000.00
0005434264830	5202	Economy	6000.00
0005434264832	5202	Economy	6000.00
0005434229103	5202	Economy	6600.00
0005434264834	5202	Economy	6600.00
0005434149581	5202	Economy	6000.00
0005434264822	5202	Economy	6000.00
0005434264812	5202	Economy	6600.00
0005434229086	5202	Economy	6000.00
0005434264831	5202	Economy	6000.00
0005434149589	5202	Economy	6000.00
0005434173469	5202	Economy	6000.00
0005434229098	5202	Economy	6000.00
0005434264820	5202	Economy	6000.00
0005434149582	5202	Economy	6000.00
0005434173470	5202	Economy	6000.00
0005434264811	5202	Economy	6000.00
0005434264810	5202	Economy	6000.00
0005434149586	5202	Economy	6000.00
0005434229083	5202	Economy	6000.00
0005434149588	5202	Economy	6000.00
0005434264824	5202	Economy	6000.00
0005434149590	5202	Economy	6000.00
0005435006633	5202	Economy	6000.00
0005435006632	5202	Economy	6000.00
0005434264813	5202	Economy	6000.00
0005434264808	5202	Economy	6000.00
0005434264827	5202	Economy	6000.00
0005434229088	5202	Economy	6000.00
0005434229102	5202	Economy	6000.00
0005434229101	5202	Economy	6000.00
0005434264826	5202	Economy	6000.00
0005434229087	5202	Economy	6000.00
0005434229093	5202	Economy	6000.00
0005434264816	5202	Economy	6000.00
0005434229081	5202	Economy	6000.00
0005434229085	5202	Economy	6000.00
0005434229091	5202	Economy	6000.00
0005434229099	5202	Economy	6000.00
0005435269668	8492	Business	18000.00
0005433784323	8492	Business	18000.00
0005433784363	8492	Business	18000.00
0005435269665	8492	Economy	6600.00
0005433784324	8492	Economy	6600.00
0005435269669	8492	Economy	6000.00
0005433784315	8492	Economy	6000.00
0005434244484	8492	Economy	6000.00
0005435269670	8492	Economy	6000.00
0005433784314	8492	Economy	6000.00
0005435269671	8492	Economy	6000.00
0005435269666	8492	Economy	6600.00
0005433784361	8492	Economy	6600.00
0005434244473	8492	Economy	6000.00
0005433784313	8492	Economy	6000.00
0005434244456	8492	Economy	6000.00
0005433784360	8492	Economy	6000.00
0005435269667	8492	Economy	6000.00
0005433613610	8491	Economy	6000.00
0005433613471	8491	Economy	6000.00
0005432034619	8490	Business	18000.00
0005432335890	8490	Business	18000.00
0005432335891	8490	Business	18000.00
0005435006727	8490	Business	18000.00
0005432335889	8490	Business	18000.00
0005432034599	8490	Business	18000.00
0005432034596	8490	Business	18000.00
0005432335894	8490	Business	18000.00
0005435006733	8490	Business	18000.00
0005435006732	8490	Business	18000.00
0005433690902	8490	Business	18000.00
0005433690901	8490	Business	18000.00
0005433815329	8490	Business	18000.00
0005435006742	8490	Business	18000.00
0005432034609	8490	Economy	6600.00
0005432034603	8490	Economy	6600.00
0005432335884	8490	Economy	6600.00
0005432047503	8490	Economy	6600.00
0005435006736	8490	Economy	6600.00
0005434264696	8490	Economy	6600.00
0005432034613	8490	Economy	6000.00
0005434228967	8490	Economy	6000.00
0005435006745	8490	Economy	6000.00
0005432034601	8490	Economy	6000.00
0005433689886	8490	Economy	6000.00
0005435006744	8490	Economy	6000.00
0005434311191	8490	Economy	6000.00
0005433689885	8490	Economy	6000.00
0005432034595	8490	Economy	6000.00
0005435006728	8490	Economy	6000.00
0005432034605	8490	Economy	6000.00
0005432034602	8490	Economy	6000.00
0005434149525	8490	Economy	6000.00
0005432335893	8490	Economy	6000.00
0005432034591	8490	Economy	6000.00
0005432335882	8490	Economy	6000.00
0005435006738	8490	Economy	6000.00
0005433815328	8490	Economy	6000.00
0005432335881	8490	Economy	6000.00
0005432034600	8490	Economy	6000.00
0005433815325	8490	Economy	6000.00
0005432034606	8490	Economy	6000.00
0005432034615	8490	Economy	6000.00
0005434311193	8490	Economy	6000.00
0005432335886	8490	Economy	6000.00
0005435006731	8490	Economy	6000.00
0005435006741	8490	Economy	6000.00
0005432034592	8490	Economy	6000.00
0005435006735	8490	Economy	6000.00
0005434264697	8490	Economy	6600.00
0005432034593	8490	Economy	6600.00
0005432034610	8490	Economy	6000.00
0005433815327	8490	Economy	6000.00
0005433690900	8490	Economy	6000.00
0005432047502	8490	Economy	6600.00
0005435006729	8490	Economy	6000.00
0005435006734	8490	Economy	6000.00
0005434228977	8490	Economy	6000.00
0005434228966	8490	Economy	6000.00
0005434228968	8490	Economy	6000.00
0005433688784	8490	Economy	6000.00
0005432335887	8490	Economy	6000.00
0005432034604	8490	Economy	6000.00
0005435006725	8490	Economy	6000.00
0005432034608	8490	Economy	6000.00
0005432034607	8490	Economy	6000.00
0005432034594	8490	Economy	6000.00
0005435006739	8490	Economy	6000.00
0005432034614	8490	Economy	6000.00
0005435006723	8490	Economy	6000.00
0005432034612	8490	Economy	6000.00
0005432335888	8490	Economy	6000.00
0005432034616	8490	Economy	6000.00
0005432335885	8490	Economy	6000.00
0005432034618	8490	Economy	6000.00
0005435006730	8490	Economy	6000.00
0005435006740	8490	Economy	6000.00
0005432335892	8490	Economy	6000.00
0005432047504	8490	Economy	6000.00
0005434311192	8490	Economy	6000.00
0005432335883	8490	Economy	6000.00
0005432047505	8490	Economy	6000.00
0005435006737	8490	Economy	6000.00
0005433815326	8490	Economy	6000.00
0005435006743	8490	Economy	6000.00
0005433534472	8490	Economy	6000.00
0005435006726	8490	Economy	6000.00
0005432034617	8490	Economy	6000.00
0005432034598	8490	Economy	6000.00
0005432034611	8490	Economy	6000.00
0005435006724	8490	Economy	6000.00
0005432034597	8490	Economy	6000.00
0005433202183	12606	Economy	16200.00
0005434638878	12606	Economy	16200.00
0005433202189	12606	Economy	14800.00
0005433202184	12606	Economy	14800.00
0005433202178	12606	Economy	14800.00
0005434638905	12606	Economy	14800.00
0005433202179	12606	Economy	14800.00
0005433202180	12606	Economy	14800.00
0005433202182	12606	Economy	14800.00
0005433202185	12606	Economy	14800.00
0005434638846	12606	Economy	14800.00
0005433202181	12606	Economy	14800.00
0005433202188	12606	Economy	14800.00
0005434638847	12606	Economy	14800.00
0005433202186	12606	Economy	14800.00
0005433202190	12606	Economy	14800.00
0005433202191	12606	Economy	14800.00
0005433202187	12606	Economy	14800.00
0005433202177	12606	Economy	14800.00
0005434638976	23363	Economy	16200.00
0005432290591	23363	Economy	16200.00
0005434638982	23363	Economy	16200.00
0005434638973	23363	Economy	14800.00
0005434638969	23363	Economy	14800.00
0005434638964	23363	Economy	14800.00
0005434638974	23363	Economy	14800.00
0005434638957	23363	Economy	14800.00
0005434638984	23363	Economy	14800.00
0005432290592	23363	Economy	14800.00
0005434638983	23363	Economy	14800.00
0005434638967	23363	Economy	14800.00
0005434638966	23363	Economy	14800.00
0005434638972	23363	Economy	14800.00
0005434638965	23363	Economy	14800.00
0005434638961	23363	Economy	14800.00
0005434638981	23363	Economy	14800.00
0005434638956	23363	Economy	14800.00
0005434638977	23363	Economy	14800.00
0005434638960	23363	Economy	14800.00
0005432290593	23363	Economy	14800.00
0005434638962	23363	Economy	14800.00
0005434638979	23363	Economy	14800.00
0005434638975	23363	Economy	14800.00
0005434638970	23363	Economy	14800.00
0005434638959	23363	Economy	14800.00
0005434638958	23363	Economy	14800.00
0005434638980	23363	Economy	14800.00
0005434638978	23363	Economy	14800.00
0005434638968	23363	Economy	14800.00
0005434638971	23363	Economy	14800.00
0005434638963	23363	Economy	14800.00
0005432382491	21058	Business	18900.00
0005432054267	21058	Economy	6300.00
0005432054269	21058	Economy	6300.00
0005432327962	21058	Economy	6300.00
0005432382492	21058	Economy	6300.00
0005432328012	21058	Economy	6300.00
0005432054268	21058	Economy	6300.00
0005432328009	21058	Economy	6300.00
0005432328095	31274	Business	18900.00
0005432328090	31274	Business	18900.00
0005432287121	31274	Business	18900.00
0005432382669	31274	Business	18900.00
0005432328117	31274	Business	18900.00
0005432328101	31274	Business	18900.00
0005432382662	31274	Business	18900.00
0005432382687	31274	Business	18900.00
0005432328088	31274	Business	18900.00
0005432328082	31274	Business	18900.00
0005432328112	31274	Business	18900.00
0005432382679	31274	Business	18900.00
0005432328120	31274	Economy	6300.00
0005432328080	31274	Economy	6300.00
0005432382678	31274	Economy	6300.00
0005432382655	31274	Economy	6300.00
0005432382686	31274	Economy	6300.00
0005432382681	31274	Economy	6300.00
0005432382650	31274	Economy	6300.00
0005432328103	31274	Economy	6300.00
0005432328105	31274	Economy	6300.00
0005432287123	31274	Economy	6300.00
0005432328115	31274	Economy	6900.00
0005432382661	31274	Economy	6900.00
0005432382665	31274	Economy	6900.00
0005432328106	31274	Economy	6900.00
0005432382666	31274	Economy	6900.00
0005432328122	31274	Economy	6300.00
0005432328118	31274	Economy	6300.00
0005432382663	31274	Economy	6300.00
0005432328084	31274	Economy	6300.00
0005432382685	31274	Economy	6300.00
0005432382670	31274	Economy	6300.00
0005432382660	31274	Economy	6300.00
0005432328089	31274	Economy	6300.00
0005432287124	31274	Economy	6300.00
0005432328110	31274	Economy	6300.00
0005432382668	31274	Economy	6300.00
0005432328091	31274	Economy	6300.00
0005432382653	31274	Economy	6300.00
0005432382688	31274	Economy	6300.00
0005432382664	31274	Economy	6300.00
0005432382658	31274	Economy	6300.00
0005432328097	31274	Economy	6300.00
0005432382667	31274	Economy	6300.00
0005432328121	31274	Economy	6300.00
0005432382672	31274	Economy	6300.00
0005432328108	31274	Economy	6300.00
0005432328098	31274	Economy	6300.00
0005432382683	31274	Economy	6300.00
0005432328093	31274	Economy	6300.00
0005432328104	31274	Economy	6300.00
0005432382690	31274	Economy	6300.00
0005432328092	31274	Economy	6300.00
0005432382651	31274	Economy	6300.00
0005432328119	31274	Economy	6300.00
0005432328086	31274	Economy	6300.00
0005432287120	31274	Economy	6300.00
0005432328124	31274	Economy	6300.00
0005432328085	31274	Economy	6300.00
0005432328094	31274	Economy	6300.00
0005432382676	31274	Economy	6300.00
0005432382677	31274	Economy	6300.00
0005432382682	31274	Economy	6300.00
0005432382652	31274	Economy	6300.00
0005432328123	31274	Economy	6300.00
0005432328102	31274	Economy	6300.00
0005432287122	31274	Economy	6300.00
0005432328083	31274	Economy	6300.00
0005432328099	31274	Economy	6300.00
0005432328116	31274	Economy	6300.00
0005432382649	31274	Economy	6300.00
0005432382671	31274	Economy	6300.00
0005432328109	31274	Economy	6300.00
0005432382654	31274	Economy	6300.00
0005432328100	31274	Economy	6300.00
0005432328087	31274	Economy	6300.00
0005432382656	31274	Economy	6300.00
0005432328113	31274	Economy	6300.00
0005432382659	31274	Economy	6300.00
0005432328081	31274	Economy	6300.00
0005432382680	31274	Economy	6300.00
0005432328079	31274	Economy	6300.00
0005432382657	31274	Economy	6300.00
0005432382673	31274	Economy	6300.00
0005432382689	31274	Economy	6300.00
0005432328096	31274	Economy	6300.00
0005432328107	31274	Economy	6300.00
0005432328114	31274	Economy	6300.00
0005432382674	31274	Economy	6300.00
0005432328111	31274	Economy	6300.00
0005432328078	31274	Economy	6300.00
0005432382684	31274	Economy	6300.00
0005432382675	31274	Economy	6300.00
0005432423835	13283	Business	12700.00
0005432423828	13283	Business	12700.00
0005432423824	13283	Business	12700.00
0005432423852	13283	Business	12700.00
0005432423837	13283	Business	12700.00
0005432423815	13283	Business	12700.00
0005432423827	13283	Business	12700.00
0005432423838	13283	Economy	4200.00
0005432423812	13283	Economy	4200.00
0005432423810	13283	Economy	4200.00
0005432423834	13283	Economy	4200.00
0005432423811	13283	Economy	4700.00
0005432423848	13283	Economy	4700.00
0005432423820	13283	Economy	4700.00
0005432423839	13283	Economy	4200.00
0005432423818	13283	Economy	4200.00
0005432423859	13283	Economy	4200.00
0005432423841	13283	Economy	4200.00
0005432423833	13283	Economy	4200.00
0005432423836	13283	Economy	4200.00
0005432423821	13283	Economy	4200.00
0005432423814	13283	Economy	4200.00
0005432423846	13283	Economy	4200.00
0005432423850	13283	Economy	4200.00
0005432423851	13283	Economy	4200.00
0005432423853	13283	Economy	4200.00
0005432423832	13283	Economy	4200.00
0005432423843	13283	Economy	4200.00
0005432423813	13283	Economy	4200.00
0005432423845	13283	Economy	4200.00
0005432423830	13283	Economy	4200.00
0005432423856	13283	Economy	4200.00
0005432423854	13283	Economy	4200.00
0005432423857	13283	Economy	4200.00
0005432423842	13283	Economy	4200.00
0005432423844	13283	Economy	4200.00
0005432423825	13283	Economy	4200.00
0005432423822	13283	Economy	4200.00
0005432423840	13283	Economy	4200.00
0005432423831	13283	Economy	4200.00
0005432423823	13283	Economy	4200.00
0005432423847	13283	Economy	4200.00
0005432423816	13283	Economy	4200.00
0005432423849	13283	Economy	4200.00
0005432423826	13283	Economy	4200.00
0005432423858	13283	Economy	4200.00
0005432423855	13283	Economy	4200.00
0005432423817	13283	Economy	4200.00
0005432423819	13283	Economy	4200.00
0005432423829	13283	Economy	4200.00
0005432817108	9576	Business	32600.00
0005432817100	9576	Business	32600.00
0005434448271	9576	Business	32600.00
0005432817109	9576	Business	32600.00
0005432817111	9576	Business	32600.00
0005432817089	9576	Business	32600.00
0005432822111	9576	Business	32600.00
0005432817097	9576	Economy	10900.00
0005432288945	9576	Economy	10900.00
0005432817092	9576	Economy	11900.00
0005432817102	9576	Economy	11900.00
0005432822106	9576	Economy	10900.00
0005432817117	9576	Economy	10900.00
0005432817118	9576	Economy	10900.00
0005432822112	9576	Economy	10900.00
0005432817113	9576	Economy	10900.00
0005432901309	9576	Economy	10900.00
0005434157346	9576	Economy	10900.00
0005432288944	9576	Economy	10900.00
0005432817107	9576	Economy	10900.00
0005432817115	9576	Economy	10900.00
0005432817091	9576	Economy	10900.00
0005432817099	9576	Economy	10900.00
0005432817094	9576	Economy	10900.00
0005432901308	9576	Economy	10900.00
0005432817101	9576	Economy	10900.00
0005432817106	9576	Economy	10900.00
0005432817098	9576	Economy	10900.00
0005432817110	9576	Economy	10900.00
0005432822109	9576	Economy	10900.00
0005434448272	9576	Economy	10900.00
0005432822108	9576	Economy	10900.00
0005434448274	9576	Economy	10900.00
0005432817103	9576	Economy	10900.00
0005432817090	9576	Economy	10900.00
0005432817114	9576	Economy	10900.00
0005432822107	9576	Economy	10900.00
0005432817104	9576	Economy	10900.00
0005432817093	9576	Economy	10900.00
0005432822110	9576	Economy	10900.00
0005434448273	9576	Economy	10900.00
0005432817105	9576	Economy	10900.00
0005432817116	9576	Economy	10900.00
0005432817095	9576	Economy	10900.00
0005432817112	9576	Economy	10900.00
0005432288946	9576	Economy	10900.00
0005432817096	9576	Economy	10900.00
0005434157384	28973	Business	32600.00
0005432901384	28973	Business	32600.00
0005434186161	28973	Economy	10900.00
0005432901391	28973	Economy	10900.00
0005432901387	28973	Economy	10900.00
0005432901396	28973	Economy	10900.00
0005432901390	28973	Economy	10900.00
0005434157385	28973	Economy	10900.00
0005434186162	28973	Economy	11900.00
0005432901394	28973	Economy	10900.00
0005432901397	28973	Economy	10900.00
0005434157380	28973	Economy	10900.00
0005432002050	28973	Economy	10900.00
0005434157381	28973	Economy	10900.00
0005434157379	28973	Economy	10900.00
0005432901389	28973	Economy	10900.00
0005434157382	28973	Economy	10900.00
0005432901400	28973	Economy	10900.00
0005432901386	28973	Economy	10900.00
0005434186160	28973	Economy	10900.00
0005432901401	28973	Economy	10900.00
0005432901393	28973	Economy	10900.00
0005432816938	28973	Economy	10900.00
0005432901399	28973	Economy	10900.00
0005434157383	28973	Economy	10900.00
0005432002051	28973	Economy	10900.00
0005432901398	28973	Economy	10900.00
0005432901395	28973	Economy	10900.00
0005432901388	28973	Economy	10900.00
0005432816972	28973	Economy	10900.00
0005434157386	28973	Economy	10900.00
0005432901392	28973	Economy	10900.00
0005432901385	28973	Economy	10900.00
0005432611660	15040	Economy	11000.00
0005432611661	15040	Economy	11000.00
0005432611662	15040	Economy	11000.00
0005432613810	15040	Economy	11000.00
0005432613811	15040	Economy	11000.00
0005432613812	15040	Economy	11000.00
0005432613809	15040	Economy	11000.00
0005432611659	15040	Economy	11000.00
0005435841812	31621	Economy	11000.00
0005435842317	31621	Economy	11000.00
0005435842318	31621	Economy	11000.00
0005433568298	11838	Business	105900.00
0005433568296	11838	Business	105900.00
0005433568272	11838	Business	105900.00
0005433568301	11838	Business	105900.00
0005433568307	11838	Business	105900.00
0005433568306	11838	Business	105900.00
0005433568285	11838	Economy	35300.00
0005433568269	11838	Economy	35300.00
0005433568281	11838	Economy	35300.00
0005433568305	11838	Economy	35300.00
0005433568293	11838	Economy	35300.00
0005433568279	11838	Economy	35300.00
0005433568274	11838	Economy	35300.00
0005433568261	11838	Economy	35300.00
0005433568263	11838	Economy	35300.00
0005433568276	11838	Economy	35300.00
0005433568294	11838	Economy	35300.00
0005433568302	11838	Economy	35300.00
0005433568295	11838	Economy	35300.00
0005433568290	11838	Economy	35300.00
0005433568283	11838	Economy	35300.00
0005433568264	11838	Economy	35300.00
0005433568299	11838	Economy	35300.00
0005433568288	11838	Economy	35300.00
0005433568297	11838	Economy	35300.00
0005433568271	11838	Economy	35300.00
0005433568265	11838	Economy	35300.00
0005433568286	11838	Economy	35300.00
0005433568268	11838	Economy	35300.00
0005433568273	11838	Economy	35300.00
0005433568287	11838	Economy	35300.00
0005433568291	11838	Economy	35300.00
0005433568262	11838	Economy	35300.00
0005433568270	11838	Economy	35300.00
0005433568303	11838	Economy	35300.00
0005433568278	11838	Economy	35300.00
0005433568267	11838	Economy	35300.00
0005433568284	11838	Economy	35300.00
0005433568289	11838	Economy	35300.00
0005433568282	11838	Economy	35300.00
0005433568259	11838	Economy	35300.00
0005433568304	11838	Economy	35300.00
0005433568280	11838	Economy	35300.00
0005433568260	11838	Economy	35300.00
0005433568266	11838	Economy	35300.00
0005433568277	11838	Economy	35300.00
0005433568292	11838	Economy	35300.00
0005433568300	11838	Economy	35300.00
0005433568275	11838	Economy	35300.00
0005432947985	25326	Business	105900.00
0005432948012	25326	Business	105900.00
0005432947978	25326	Business	105900.00
0005432947994	25326	Business	105900.00
0005432947980	25326	Business	105900.00
0005432948005	25326	Business	105900.00
0005432947987	25326	Business	105900.00
0005432948007	25326	Business	105900.00
0005432948000	25326	Economy	35300.00
0005432948010	25326	Economy	35300.00
0005432948004	25326	Economy	35300.00
0005432947996	25326	Economy	35300.00
0005432947995	25326	Economy	35300.00
0005432947988	25326	Economy	35300.00
0005432948003	25326	Economy	38800.00
0005432947989	25326	Economy	38800.00
0005432947990	25326	Economy	35300.00
0005432947999	25326	Economy	35300.00
0005432947986	25326	Economy	35300.00
0005432948009	25326	Economy	35300.00
0005432947981	25326	Economy	35300.00
0005432947977	25326	Economy	35300.00
0005432947993	25326	Economy	35300.00
0005432947991	25326	Economy	35300.00
0005432948002	25326	Economy	35300.00
0005432947974	25326	Economy	35300.00
0005432948006	25326	Economy	35300.00
0005432947979	25326	Economy	35300.00
0005432947992	25326	Economy	35300.00
0005432947973	25326	Economy	35300.00
0005432947984	25326	Economy	35300.00
0005432948011	25326	Economy	35300.00
0005432948001	25326	Economy	35300.00
0005432948008	25326	Economy	35300.00
0005432947972	25326	Economy	35300.00
0005432947997	25326	Economy	35300.00
0005432947976	25326	Economy	35300.00
0005432947998	25326	Economy	35300.00
0005432947983	25326	Economy	35300.00
0005432947982	25326	Economy	35300.00
0005432947975	25326	Economy	35300.00
0005434654327	5422	Business	67200.00
0005434654314	5422	Business	67200.00
0005434654325	5422	Business	67200.00
0005434656530	5422	Business	67200.00
0005434654309	5422	Business	67200.00
0005434654315	5422	Economy	22400.00
0005434656531	5422	Economy	22400.00
0005434654338	5422	Economy	22400.00
0005434654316	5422	Economy	24600.00
0005434654324	5422	Economy	24600.00
0005434654334	5422	Economy	24600.00
0005434654331	5422	Economy	22400.00
0005432114164	5422	Economy	22400.00
0005434654337	5422	Economy	22400.00
0005432114163	5422	Economy	22400.00
0005434654326	5422	Economy	22400.00
0005434654312	5422	Economy	22400.00
0005434654317	5422	Economy	22400.00
0005432114162	5422	Economy	22400.00
0005434654313	5422	Economy	22400.00
0005434654318	5422	Economy	22400.00
0005434654333	5422	Economy	22400.00
0005434654319	5422	Economy	22400.00
0005434654336	5422	Economy	22400.00
0005434654329	5422	Economy	22400.00
0005434654328	5422	Economy	22400.00
0005434654321	5422	Economy	22400.00
0005434654330	5422	Economy	22400.00
0005434654311	5422	Economy	22400.00
0005434654320	5422	Economy	22400.00
0005434654323	5422	Economy	22400.00
0005434654335	5422	Economy	22400.00
0005434654332	5422	Economy	22400.00
0005434654322	5422	Economy	22400.00
0005434654310	5422	Economy	22400.00
0005435555345	12548	Business	67200.00
0005435340069	12548	Business	67200.00
0005435555347	12548	Economy	22400.00
0005435340066	12548	Economy	24600.00
0005435340080	12548	Economy	22400.00
0005435340070	12548	Economy	22400.00
0005435340073	12548	Economy	22400.00
0005435555344	12548	Economy	22400.00
0005435340068	12548	Economy	22400.00
0005435340079	12548	Economy	22400.00
0005435340081	12548	Economy	22400.00
0005435340072	12548	Economy	22400.00
0005435340074	12548	Economy	22400.00
0005435340075	12548	Economy	22400.00
0005435340078	12548	Economy	22400.00
0005435340067	12548	Economy	22400.00
0005435555346	12548	Economy	22400.00
0005435340077	12548	Economy	22400.00
0005435340071	12548	Economy	22400.00
0005435340076	12548	Economy	22400.00
0005433719094	7451	Business	32000.00
0005433715331	7451	Business	32000.00
0005433688782	7451	Business	32000.00
0005433722128	7451	Business	32000.00
0005433715346	7451	Business	32000.00
0005433715322	7451	Economy	10700.00
0005433715344	7451	Economy	10700.00
0005433715335	7451	Economy	10700.00
0005433715336	7451	Economy	10700.00
0005433715350	7451	Economy	10700.00
0005433715328	7451	Economy	10700.00
0005433715371	7451	Economy	10700.00
0005433715343	7451	Economy	10700.00
0005433715345	7451	Economy	10700.00
0005433656626	7451	Economy	10700.00
0005433715326	7451	Economy	10700.00
0005433715372	7451	Economy	10700.00
0005433715364	7451	Economy	10700.00
0005433722129	7451	Economy	10700.00
0005433715337	7451	Economy	10700.00
0005433715349	7451	Economy	10700.00
0005433715333	7451	Economy	10700.00
0005433715342	7451	Economy	10700.00
0005432078038	7451	Economy	10700.00
0005433656625	7451	Economy	10700.00
0005433722130	7451	Economy	10700.00
0005433715353	7451	Economy	11700.00
0005433688783	7451	Economy	11700.00
0005433715357	7451	Economy	11700.00
0005433715348	7451	Economy	11700.00
0005433715324	7451	Economy	10700.00
0005433715370	7451	Economy	10700.00
0005433715338	7451	Economy	10700.00
0005433715358	7451	Economy	10700.00
0005433715355	7451	Economy	10700.00
0005433715363	7451	Economy	10700.00
0005433715367	7451	Economy	10700.00
0005433715352	7451	Economy	10700.00
0005433715334	7451	Economy	10700.00
0005433715351	7451	Economy	10700.00
0005433715325	7451	Economy	10700.00
0005433715361	7451	Economy	10700.00
0005433715329	7451	Economy	10700.00
0005432078037	7451	Economy	10700.00
0005433715365	7451	Economy	10700.00
0005433715354	7451	Economy	10700.00
0005433715340	7451	Economy	10700.00
0005433715356	7451	Economy	10700.00
0005433715369	7451	Economy	10700.00
0005433715366	7451	Economy	10700.00
0005433715360	7451	Economy	10700.00
0005433715341	7451	Economy	10700.00
0005433719095	7451	Economy	10700.00
0005433719097	7451	Economy	10700.00
0005433715368	7451	Economy	10700.00
0005433715359	7451	Economy	10700.00
0005433715327	7451	Economy	10700.00
0005433722131	7451	Economy	10700.00
0005433715323	7451	Economy	10700.00
0005433690899	7451	Economy	10700.00
0005433715362	7451	Economy	10700.00
0005433656627	7451	Economy	10700.00
0005433715332	7451	Economy	10700.00
0005433719096	7451	Economy	10700.00
0005433715339	7451	Economy	10700.00
0005433689884	7451	Economy	10700.00
0005433715347	7451	Economy	10700.00
0005432078041	7451	Economy	10700.00
0005433715330	7451	Economy	10700.00
0005432078039	7451	Economy	10700.00
0005432078040	7451	Economy	10700.00
0005435266085	29256	Business	32000.00
0005433715076	29256	Business	32000.00
0005435266083	29256	Business	32000.00
0005435266088	29256	Economy	10700.00
0005435266080	29256	Economy	10700.00
0005432428887	29256	Economy	10700.00
0005432006725	29256	Economy	10700.00
0005435266089	29256	Economy	10700.00
0005435266090	29256	Economy	10700.00
0005435266084	29256	Economy	10700.00
0005432428885	29256	Economy	10700.00
0005435266091	29256	Economy	10700.00
0005433715184	29256	Economy	10700.00
0005435266081	29256	Economy	10700.00
0005435266087	29256	Economy	10700.00
0005433715074	29256	Economy	10700.00
0005435266082	29256	Economy	10700.00
0005435266086	29256	Economy	10700.00
0005433715075	29256	Economy	10700.00
0005432428886	29256	Economy	10700.00
0005434095100	8668	Business	36500.00
0005434095093	8668	Business	36500.00
0005434095101	8668	Business	36500.00
0005434095091	8668	Economy	12200.00
0005434095103	8668	Economy	13400.00
0005434095097	8668	Economy	12200.00
0005434181966	8668	Economy	12200.00
0005434095090	8668	Economy	12200.00
0005434095099	8668	Economy	12200.00
0005434095096	8668	Economy	12200.00
0005434095102	8668	Economy	12200.00
0005434181962	8668	Economy	12200.00
0005434181965	8668	Economy	12200.00
0005434095095	8668	Economy	12200.00
0005434095092	8668	Economy	12200.00
0005434095089	8668	Economy	12200.00
0005434095098	8668	Economy	12200.00
0005434095094	8668	Economy	12200.00
0005434183554	11640	Business	36500.00
0005434182034	11640	Business	36500.00
0005434184639	11640	Business	36500.00
0005434183553	11640	Economy	12200.00
0005434182033	11640	Economy	12200.00
0005434182025	11640	Economy	12200.00
0005434182028	11640	Economy	12200.00
0005434095027	11640	Economy	12200.00
0005434182031	11640	Economy	12200.00
0005434182024	11640	Economy	12200.00
0005434182022	11640	Economy	12200.00
0005434182027	11640	Economy	12200.00
0005434183552	11640	Economy	12200.00
0005434184637	11640	Economy	12200.00
0005434182026	11640	Economy	12200.00
0005434184638	11640	Economy	12200.00
0005434095026	11640	Economy	12200.00
0005434182023	11640	Economy	12200.00
0005434182029	11640	Economy	12200.00
0005434182032	11640	Economy	12200.00
0005434182030	11640	Economy	12200.00
0005433456918	1412	Business	33000.00
0005435732169	1412	Business	33000.00
0005435732175	1412	Business	33000.00
0005432297245	1412	Business	33000.00
0005433397246	1412	Business	33000.00
0005435732177	1412	Economy	11000.00
0005432297244	1412	Economy	11000.00
0005433397228	1412	Economy	12100.00
0005433456920	1412	Economy	11000.00
0005432297243	1412	Economy	11000.00
0005433397184	1412	Economy	11000.00
0005435732170	1412	Economy	11000.00
0005433397198	1412	Economy	11000.00
0005435732166	1412	Economy	11000.00
0005433456919	1412	Economy	11000.00
0005435732174	1412	Economy	11000.00
0005435732176	1412	Economy	11000.00
0005435732178	1412	Economy	11000.00
0005433397185	1412	Economy	11000.00
0005433397227	1412	Economy	11000.00
0005435732167	1412	Economy	11000.00
0005433456917	1412	Economy	11000.00
0005435732179	1412	Economy	11000.00
0005435732173	1412	Economy	11000.00
0005435732172	1412	Economy	11000.00
0005435732168	1412	Economy	11000.00
0005435732171	1412	Economy	11000.00
0005433397448	19247	Business	33000.00
0005433397440	19247	Business	33000.00
0005433397432	19247	Business	33000.00
0005433397451	19247	Business	33000.00
0005433397460	19247	Economy	11000.00
0005433397473	19247	Economy	11000.00
0005433397434	19247	Economy	11000.00
0005433397461	19247	Economy	11000.00
0005433397436	19247	Economy	11000.00
0005433397428	19247	Economy	11000.00
0005433397459	19247	Economy	11000.00
0005433397439	19247	Economy	12100.00
0005433397458	19247	Economy	12100.00
0005433397443	19247	Economy	12100.00
0005433397457	19247	Economy	11000.00
0005433397464	19247	Economy	11000.00
0005433397455	19247	Economy	11000.00
0005433397465	19247	Economy	11000.00
0005433397462	19247	Economy	11000.00
0005435732113	19247	Economy	11000.00
0005433397433	19247	Economy	11000.00
0005433397476	19247	Economy	11000.00
0005433397441	19247	Economy	11000.00
0005433397472	19247	Economy	11000.00
0005433397474	19247	Economy	11000.00
0005433397471	19247	Economy	11000.00
0005432906505	19247	Economy	11000.00
0005433397467	19247	Economy	11000.00
0005433397447	19247	Economy	11000.00
0005433397431	19247	Economy	11000.00
0005433397446	19247	Economy	11000.00
0005432906504	19247	Economy	11000.00
0005433397444	19247	Economy	11000.00
0005433397475	19247	Economy	11000.00
0005433397430	19247	Economy	11000.00
0005432906506	19247	Economy	11000.00
0005433397442	19247	Economy	11000.00
0005433397454	19247	Economy	11000.00
0005433397453	19247	Economy	11000.00
0005433397445	19247	Economy	11000.00
0005433397463	19247	Economy	11000.00
0005433397429	19247	Economy	11000.00
0005433397449	19247	Economy	11000.00
0005433397452	19247	Economy	11000.00
0005433397470	19247	Economy	11000.00
0005433397437	19247	Economy	11000.00
0005433397466	19247	Economy	11000.00
0005433397438	19247	Economy	11000.00
0005433397469	19247	Economy	11000.00
0005433397435	19247	Economy	11000.00
0005433397456	19247	Economy	11000.00
0005433397468	19247	Economy	11000.00
0005433397450	19247	Economy	11000.00
0005434443432	17377	Economy	14100.00
0005434443430	17377	Economy	14100.00
0005434443431	17377	Economy	14100.00
0005434443429	17377	Economy	14100.00
0005434443501	20582	Economy	14100.00
0005434443493	20582	Economy	14100.00
0005434443494	20582	Economy	14100.00
0005434443492	20582	Economy	14100.00
0005434443490	20582	Economy	14100.00
0005434443496	20582	Economy	14100.00
0005434443503	20582	Economy	14100.00
0005434443498	20582	Economy	14100.00
0005434443506	20582	Economy	14100.00
0005434443499	20582	Economy	14100.00
0005434443504	20582	Economy	14100.00
0005434443495	20582	Economy	14100.00
0005434443497	20582	Economy	14100.00
0005434443491	20582	Economy	14100.00
0005434443502	20582	Economy	14100.00
0005434443489	20582	Economy	14100.00
0005434443500	20582	Economy	14100.00
0005434443505	20582	Economy	14100.00
0005434954559	7236	Economy	5800.00
0005434954560	7236	Economy	5800.00
0005434954561	7236	Economy	5800.00
0005435377550	28300	Economy	5800.00
0005434351529	4452	Economy	15400.00
0005434351538	4452	Economy	14000.00
0005434351535	4452	Economy	14000.00
0005434351532	4452	Economy	14000.00
0005434351530	4452	Economy	14000.00
0005434183544	4452	Economy	14000.00
0005434326263	4452	Economy	14000.00
0005434351534	4452	Economy	14000.00
0005434351537	4452	Economy	14000.00
0005434351539	4452	Economy	14000.00
0005434326262	4452	Economy	14000.00
0005434351533	4452	Economy	14000.00
0005434351531	4452	Economy	14000.00
0005434351536	4452	Economy	14000.00
0005434351541	4452	Economy	14000.00
0005434351540	4452	Economy	14000.00
0005435893545	29672	Economy	14000.00
0005435893541	29672	Economy	14000.00
0005435893540	29672	Economy	14000.00
0005435893543	29672	Economy	14000.00
0005435893544	29672	Economy	14000.00
0005435893542	29672	Economy	14000.00
0005435091951	1091	Business	30600.00
0005433462721	1091	Business	30600.00
0005433463874	1091	Economy	11200.00
0005433269628	1091	Economy	10200.00
0005434445217	1091	Economy	10200.00
0005435545641	1091	Economy	10200.00
0005435091953	1091	Economy	10200.00
0005434445219	1091	Economy	10200.00
0005435091943	1091	Economy	10200.00
0005432293178	1091	Economy	10200.00
0005434446491	1091	Economy	10200.00
0005435091944	1091	Economy	10200.00
0005432293177	1091	Economy	10200.00
0005435091950	1091	Economy	10200.00
0005435091952	1091	Economy	10200.00
0005435091945	1091	Economy	10200.00
0005434445220	1091	Economy	10200.00
0005435091949	1091	Economy	10200.00
0005433269623	1091	Economy	11200.00
0005433341432	1091	Economy	10200.00
0005435091947	1091	Economy	10200.00
0005435545642	1091	Economy	10200.00
0005433269646	1091	Economy	10200.00
0005433462719	1091	Economy	10200.00
0005433463873	1091	Economy	10200.00
0005434445218	1091	Economy	10200.00
0005435091946	1091	Economy	10200.00
0005433462720	1091	Economy	10200.00
0005432293176	1091	Economy	10200.00
0005435091948	1091	Economy	10200.00
0005433341841	17034	Business	30600.00
0005433341796	17034	Business	30600.00
0005433341862	17034	Business	30600.00
0005433341877	17034	Business	30600.00
0005433341813	17034	Business	30600.00
0005433341789	17034	Business	30600.00
0005433341816	17034	Business	30600.00
0005433341846	17034	Business	30600.00
0005433341810	17034	Business	30600.00
0005433341824	17034	Business	30600.00
0005435091895	17034	Business	30600.00
0005433341854	17034	Business	30600.00
0005433341803	17034	Business	30600.00
0005433341887	17034	Business	30600.00
0005433341864	17034	Business	30600.00
0005433341787	17034	Economy	11200.00
0005433341883	17034	Economy	11200.00
0005433341821	17034	Economy	11200.00
0005433341878	17034	Economy	10200.00
0005433341849	17034	Economy	10200.00
0005433341836	17034	Economy	10200.00
0005433341855	17034	Economy	10200.00
0005433269650	17034	Economy	10200.00
0005433341881	17034	Economy	10200.00
0005433341839	17034	Economy	10200.00
0005433341801	17034	Economy	10200.00
0005433341856	17034	Economy	10200.00
0005433341860	17034	Economy	10200.00
0005433341848	17034	Economy	10200.00
0005433341814	17034	Economy	10200.00
0005433159285	17034	Economy	10200.00
0005433341882	17034	Economy	10200.00
0005433341798	17034	Economy	10200.00
0005433341838	17034	Economy	10200.00
0005433341808	17034	Economy	10200.00
0005433269652	17034	Economy	10200.00
0005433341859	17034	Economy	10200.00
0005433341852	17034	Economy	10200.00
0005433341818	17034	Economy	10200.00
0005433341843	17034	Economy	10200.00
0005433341823	17034	Economy	10200.00
0005433341806	17034	Economy	10200.00
0005433341867	17034	Economy	10200.00
0005433341809	17034	Economy	10200.00
0005433341866	17034	Economy	10200.00
0005433341875	17034	Economy	10200.00
0005433341835	17034	Economy	10200.00
0005433341851	17034	Economy	10200.00
0005433341794	17034	Economy	10200.00
0005433341827	17034	Economy	10200.00
0005433341791	17034	Economy	10200.00
0005433341840	17034	Economy	10200.00
0005433341872	17034	Economy	10200.00
0005433341799	17034	Economy	10200.00
0005433341832	17034	Economy	10200.00
0005433341830	17034	Economy	10200.00
0005433341788	17034	Economy	10200.00
0005433341834	17034	Economy	10200.00
0005433341822	17034	Economy	10200.00
0005433341792	17034	Economy	10200.00
0005433341847	17034	Economy	10200.00
0005433341815	17034	Economy	10200.00
0005433341802	17034	Economy	10200.00
0005433341842	17034	Economy	10200.00
0005433341861	17034	Economy	10200.00
0005433341807	17034	Economy	10200.00
0005433341819	17034	Economy	10200.00
0005433341865	17034	Economy	10200.00
0005433341817	17034	Economy	10200.00
0005433341879	17034	Economy	10200.00
0005433341790	17034	Economy	10200.00
0005433341873	17034	Economy	11200.00
0005433341800	17034	Economy	10200.00
0005433341853	17034	Economy	11200.00
0005433159284	17034	Economy	10200.00
0005433269649	17034	Economy	10200.00
0005433341812	17034	Economy	10200.00
0005433341869	17034	Economy	11200.00
0005433341885	17034	Economy	11200.00
0005433341880	17034	Economy	10200.00
0005435091896	17034	Economy	10200.00
0005433341825	17034	Economy	10200.00
0005433341793	17034	Economy	10200.00
0005433341831	17034	Economy	10200.00
0005433341811	17034	Economy	10200.00
0005433341871	17034	Economy	10200.00
0005433341884	17034	Economy	10200.00
0005433341863	17034	Economy	10200.00
0005433341858	17034	Economy	10200.00
0005433341845	17034	Economy	10200.00
0005433341826	17034	Economy	10200.00
0005435091919	17034	Economy	10200.00
0005433341886	17034	Economy	10200.00
0005433341828	17034	Economy	10200.00
0005433341829	17034	Economy	10200.00
0005433341857	17034	Economy	10200.00
0005433341870	17034	Economy	10200.00
0005433341844	17034	Economy	10200.00
0005433341868	17034	Economy	10200.00
0005433341795	17034	Economy	10200.00
0005433341797	17034	Economy	10200.00
0005433341876	17034	Economy	10200.00
0005433341850	17034	Economy	10200.00
0005433269651	17034	Economy	10200.00
0005433269648	17034	Economy	10200.00
0005433341804	17034	Economy	10200.00
0005433341820	17034	Economy	10200.00
0005433341833	17034	Economy	10200.00
0005433159283	17034	Economy	10200.00
0005433341874	17034	Economy	10200.00
0005433341805	17034	Economy	10200.00
0005433341837	17034	Economy	10200.00
0005433269647	17034	Economy	10200.00
0005433812869	12774	Business	40300.00
0005433812870	12774	Business	40300.00
0005432159798	12774	Economy	13400.00
0005432433611	12774	Economy	13400.00
0005432433612	12774	Economy	13400.00
0005432159800	12774	Economy	13400.00
0005432159802	12774	Economy	13400.00
0005433812871	12774	Economy	13400.00
0005434066307	12774	Economy	13400.00
0005434066330	12774	Economy	14800.00
0005432159801	12774	Economy	14800.00
0005434066505	12774	Economy	14800.00
0005432433613	12774	Economy	13400.00
0005434066349	12774	Economy	13400.00
0005432433614	12774	Economy	13400.00
0005432159799	12774	Economy	13400.00
0005434081516	12774	Economy	13400.00
0005434066421	12774	Economy	13400.00
0005432433610	12774	Economy	13400.00
0005434066390	12774	Economy	13400.00
0005432433609	12774	Economy	13400.00
0005434066585	30651	Business	40300.00
0005434081580	30651	Business	40300.00
0005434081587	30651	Business	40300.00
0005433989707	30651	Business	40300.00
0005434066624	30651	Business	40300.00
0005434026676	30651	Business	40300.00
0005434081581	30651	Business	40300.00
0005433989708	30651	Business	40300.00
0005434081579	30651	Business	40300.00
0005434066612	30651	Business	40300.00
0005434066632	30651	Business	40300.00
0005434066622	30651	Economy	13400.00
0005432186820	30651	Economy	13400.00
0005434081578	30651	Economy	13400.00
0005434066650	30651	Economy	13400.00
0005434066655	30651	Economy	13400.00
0005434081584	30651	Economy	13400.00
0005434066645	30651	Economy	13400.00
0005434066648	30651	Economy	13400.00
0005434066597	30651	Economy	13400.00
0005434066636	30651	Economy	13400.00
0005434066592	30651	Economy	13400.00
0005434081577	30651	Economy	13400.00
0005434081589	30651	Economy	13400.00
0005434066652	30651	Economy	13400.00
0005434081593	30651	Economy	13400.00
0005434081588	30651	Economy	13400.00
0005434081591	30651	Economy	13400.00
0005434066621	30651	Economy	13400.00
0005434066627	30651	Economy	13400.00
0005434066629	30651	Economy	13400.00
0005432186819	30651	Economy	13400.00
0005434066600	30651	Economy	13400.00
0005434026678	30651	Economy	13400.00
0005432150091	30651	Economy	13400.00
0005434066654	30651	Economy	13400.00
0005434066623	30651	Economy	13400.00
0005434066626	30651	Economy	13400.00
0005434066620	30651	Economy	13400.00
0005434066603	30651	Economy	13400.00
0005434066605	30651	Economy	13400.00
0005434066594	30651	Economy	13400.00
0005434081595	30651	Economy	13400.00
0005432150086	30651	Economy	13400.00
0005434066599	30651	Economy	13400.00
0005434081583	30651	Economy	13400.00
0005434066588	30651	Economy	13400.00
0005434026675	30651	Economy	13400.00
0005434066607	30651	Economy	14800.00
0005434066606	30651	Economy	14800.00
0005434081586	30651	Economy	14800.00
0005434066656	30651	Economy	14800.00
0005434066602	30651	Economy	14800.00
0005434081590	30651	Economy	14800.00
0005434066618	30651	Economy	13400.00
0005434066589	30651	Economy	13400.00
0005432150092	30651	Economy	13400.00
0005433989706	30651	Economy	13400.00
0005434066595	30651	Economy	13400.00
0005434066591	30651	Economy	13400.00
0005434066598	30651	Economy	13400.00
0005434066635	30651	Economy	13400.00
0005432186821	30651	Economy	13400.00
0005432186822	30651	Economy	13400.00
0005434066586	30651	Economy	13400.00
0005434066653	30651	Economy	13400.00
0005432433592	30651	Economy	13400.00
0005434066590	30651	Economy	13400.00
0005434066651	30651	Economy	13400.00
0005434066596	30651	Economy	13400.00
0005434066604	30651	Economy	13400.00
0005434081597	30651	Economy	13400.00
0005433989709	30651	Economy	13400.00
0005434066647	30651	Economy	13400.00
0005434066638	30651	Economy	13400.00
0005434081582	30651	Economy	13400.00
0005434066637	30651	Economy	13400.00
0005432150087	30651	Economy	13400.00
0005434066644	30651	Economy	13400.00
0005434066613	30651	Economy	13400.00
0005434066616	30651	Economy	13400.00
0005434066610	30651	Economy	13400.00
0005434066630	30651	Economy	13400.00
0005434066641	30651	Economy	13400.00
0005434066601	30651	Economy	13400.00
0005434066619	30651	Economy	13400.00
0005434066649	30651	Economy	13400.00
0005433989705	30651	Economy	13400.00
0005434066639	30651	Economy	13400.00
0005434066609	30651	Economy	13400.00
0005434066634	30651	Economy	13400.00
0005434066642	30651	Economy	13400.00
0005434081585	30651	Economy	13400.00
0005434066625	30651	Economy	13400.00
0005434066640	30651	Economy	13400.00
0005434081596	30651	Economy	13400.00
0005434066611	30651	Economy	13400.00
0005434066628	30651	Economy	13400.00
0005434026674	30651	Economy	13400.00
0005432150088	30651	Economy	13400.00
0005434026679	30651	Economy	13400.00
0005434066643	30651	Economy	13400.00
0005434066631	30651	Economy	13400.00
0005432150093	30651	Economy	13400.00
0005434066646	30651	Economy	13400.00
0005434081592	30651	Economy	13400.00
0005434081594	30651	Economy	13400.00
0005434066614	30651	Economy	13400.00
0005434026677	30651	Economy	13400.00
0005434066633	30651	Economy	13400.00
0005434066615	30651	Economy	13400.00
0005434066587	30651	Economy	13400.00
0005434066617	30651	Economy	13400.00
0005434066593	30651	Economy	13400.00
0005434026680	30651	Economy	13400.00
0005434066608	30651	Economy	13400.00
0005434066657	30651	Economy	13400.00
0005434026673	30651	Economy	13400.00
0005432150089	30651	Economy	13400.00
0005432150090	30651	Economy	13400.00
0005434026672	30651	Economy	13400.00
0005435765448	5496	Business	35300.00
0005435765445	5496	Business	35300.00
0005433527220	5496	Business	35300.00
0005435765408	5496	Business	35300.00
0005435735079	5496	Business	35300.00
0005433527219	5496	Business	35300.00
0005433527221	5496	Business	35300.00
0005435765450	5496	Business	35300.00
0005435765455	5496	Business	35300.00
0005435765420	5496	Business	35300.00
0005435765422	5496	Economy	12900.00
0005433529232	5496	Economy	11800.00
0005435765446	5496	Economy	11800.00
0005435765428	5496	Economy	11800.00
0005435765459	5496	Economy	11800.00
0005435725535	5496	Economy	11800.00
0005435765412	5496	Economy	11800.00
0005435765463	5496	Economy	11800.00
0005435765426	5496	Economy	11800.00
0005432140342	5496	Economy	11800.00
0005435765456	5496	Economy	11800.00
0005435765452	5496	Economy	11800.00
0005435461847	5496	Economy	11800.00
0005435765469	5496	Economy	11800.00
0005435725532	5496	Economy	11800.00
0005435735077	5496	Economy	11800.00
0005435461829	5496	Economy	11800.00
0005435765458	5496	Economy	11800.00
0005435765462	5496	Economy	11800.00
0005432140348	5496	Economy	11800.00
0005435765434	5496	Economy	11800.00
0005435765427	5496	Economy	11800.00
0005435765440	5496	Economy	11800.00
0005435765454	5496	Economy	11800.00
0005435725536	5496	Economy	11800.00
0005435765466	5496	Economy	11800.00
0005435765460	5496	Economy	11800.00
0005435765465	5496	Economy	11800.00
0005435765471	5496	Economy	11800.00
0005435765431	5496	Economy	11800.00
0005433529230	5496	Economy	11800.00
0005432140343	5496	Economy	11800.00
0005435765413	5496	Economy	11800.00
0005434264725	5496	Economy	11800.00
0005435765475	5496	Economy	11800.00
0005435765472	5496	Economy	11800.00
0005435765430	5496	Economy	11800.00
0005435765423	5496	Economy	11800.00
0005435735080	5496	Economy	11800.00
0005435765444	5496	Economy	11800.00
0005435765410	5496	Economy	11800.00
0005435765414	5496	Economy	11800.00
0005435765461	5496	Economy	11800.00
0005435765435	5496	Economy	11800.00
0005435765421	5496	Economy	11800.00
0005435461830	5496	Economy	11800.00
0005435765474	5496	Economy	11800.00
0005435765406	5496	Economy	11800.00
0005435765447	5496	Economy	11800.00
0005435765457	5496	Economy	11800.00
0005435765442	5496	Economy	11800.00
0005435765416	5496	Economy	11800.00
0005435765439	5496	Economy	11800.00
0005435725533	5496	Economy	11800.00
0005435722025	5496	Economy	12900.00
0005435735076	5496	Economy	12900.00
0005435765476	5496	Economy	12900.00
0005432140346	5496	Economy	11800.00
0005435765443	5496	Economy	12900.00
0005435735078	5496	Economy	11800.00
0005435765432	5496	Economy	11800.00
0005435725534	5496	Economy	11800.00
0005435765436	5496	Economy	11800.00
0005435461845	5496	Economy	11800.00
0005435765415	5496	Economy	11800.00
0005435765441	5496	Economy	11800.00
0005435765473	5496	Economy	11800.00
0005435765453	5496	Economy	11800.00
0005435765438	5496	Economy	11800.00
0005435765417	5496	Economy	11800.00
0005435765449	5496	Economy	11800.00
0005435765467	5496	Economy	11800.00
0005432140345	5496	Economy	11800.00
0005435765424	5496	Economy	11800.00
0005432140344	5496	Economy	11800.00
0005435765418	5496	Economy	11800.00
0005435765470	5496	Economy	11800.00
0005435765411	5496	Economy	11800.00
0005435722024	5496	Economy	11800.00
0005433529231	5496	Economy	11800.00
0005435765451	5496	Economy	11800.00
0005433529233	5496	Economy	11800.00
0005435765464	5496	Economy	11800.00
0005435735075	5496	Economy	11800.00
0005435765409	5496	Economy	11800.00
0005435765468	5496	Economy	11800.00
0005433529234	5496	Economy	11800.00
0005432140347	5496	Economy	11800.00
0005435765429	5496	Economy	11800.00
0005435461780	5496	Economy	11800.00
0005435765425	5496	Economy	11800.00
0005435765407	5496	Economy	11800.00
0005435765419	5496	Economy	11800.00
0005435765433	5496	Economy	11800.00
0005435765437	5496	Economy	11800.00
0005435765147	13463	Business	35300.00
0005434264809	13463	Business	35300.00
0005432535774	13463	Business	35300.00
0005435765259	13463	Business	35300.00
0005434264813	13463	Business	35300.00
0005432194458	13463	Business	35300.00
0005434264833	13463	Business	35300.00
0005435461952	13463	Business	35300.00
0005435461964	13463	Business	35300.00
0005435461958	13463	Business	35300.00
0005435461971	13463	Business	35300.00
0005432535773	13463	Business	35300.00
0005434264812	13463	Business	35300.00
0005434264829	13463	Business	35300.00
0005435461965	13463	Business	35300.00
0005434264828	13463	Economy	12900.00
0005435461978	13463	Economy	11800.00
0005435461968	13463	Economy	11800.00
0005435461976	13463	Economy	11800.00
0005432535771	13463	Economy	11800.00
0005434264831	13463	Economy	11800.00
0005434264810	13463	Economy	11800.00
0005432535770	13463	Economy	11800.00
0005434831094	13463	Economy	11800.00
0005434831093	13463	Economy	11800.00
0005434264819	13463	Economy	11800.00
0005435461973	13463	Economy	11800.00
0005432194460	13463	Economy	11800.00
0005435461966	13463	Economy	11800.00
0005434264827	13463	Economy	11800.00
0005434264830	13463	Economy	11800.00
0005432194459	13463	Economy	11800.00
0005435461986	13463	Economy	11800.00
0005434264814	13463	Economy	11800.00
0005435461977	13463	Economy	11800.00
0005435765144	13463	Economy	11800.00
0005435461975	13463	Economy	11800.00
0005434264815	13463	Economy	11800.00
0005434264808	13463	Economy	11800.00
0005434264824	13463	Economy	11800.00
0005435765169	13463	Economy	11800.00
0005435461950	13463	Economy	11800.00
0005434264823	13463	Economy	11800.00
0005435461951	13463	Economy	11800.00
0005434264834	13463	Economy	11800.00
0005435461983	13463	Economy	11800.00
0005435765239	13463	Economy	11800.00
0005435461985	13463	Economy	11800.00
0005435461960	13463	Economy	11800.00
0005435461967	13463	Economy	11800.00
0005435461969	13463	Economy	11800.00
0005435461970	13463	Economy	11800.00
0005435461987	13463	Economy	11800.00
0005435461953	13463	Economy	11800.00
0005434264825	13463	Economy	11800.00
0005434264817	13463	Economy	11800.00
0005435765238	13463	Economy	12900.00
0005435461959	13463	Economy	12900.00
0005435461961	13463	Economy	11800.00
0005434831091	13463	Economy	11800.00
0005434264820	13463	Economy	11800.00
0005434831092	13463	Economy	11800.00
0005435461979	13463	Economy	11800.00
0005435765274	13463	Economy	11800.00
0005435461949	13463	Economy	11800.00
0005435461963	13463	Economy	11800.00
0005434831090	13463	Economy	11800.00
0005435461954	13463	Economy	11800.00
0005435461957	13463	Economy	11800.00
0005432535772	13463	Economy	11800.00
0005435461980	13463	Economy	11800.00
0005435461981	13463	Economy	11800.00
0005432194457	13463	Economy	11800.00
0005435461984	13463	Economy	11800.00
0005434264811	13463	Economy	11800.00
0005435765132	13463	Economy	11800.00
0005435461956	13463	Economy	11800.00
0005435461962	13463	Economy	11800.00
0005434264816	13463	Economy	11800.00
0005434264822	13463	Economy	11800.00
0005434264826	13463	Economy	11800.00
0005435461972	13463	Economy	11800.00
0005434264832	13463	Economy	11800.00
0005435461974	13463	Economy	11800.00
0005434264818	13463	Economy	11800.00
0005435461982	13463	Economy	11800.00
0005435461955	13463	Economy	11800.00
0005434264821	13463	Economy	11800.00
0005434514932	18739	Economy	3300.00
0005434514933	18739	Economy	3300.00
0005434513543	18739	Economy	3300.00
0005434513546	18739	Economy	3300.00
0005434513545	18739	Economy	3300.00
0005434513544	18739	Economy	3300.00
0005434602874	19225	Economy	3300.00
0005434602871	19225	Economy	3300.00
0005434602872	19225	Economy	3300.00
0005434602869	19225	Economy	3300.00
0005434602868	19225	Economy	3300.00
0005434602873	19225	Economy	3300.00
0005434602870	19225	Economy	3300.00
0005435844267	25083	Business	88300.00
0005435844263	25083	Business	88300.00
0005435844268	25083	Business	88300.00
0005435844261	25083	Economy	29400.00
0005435846206	25083	Economy	32400.00
0005435844265	25083	Economy	29400.00
0005435846208	25083	Economy	29400.00
0005435846204	25083	Economy	29400.00
0005435844266	25083	Economy	29400.00
0005435844260	25083	Economy	29400.00
0005435844264	25083	Economy	29400.00
0005435846209	25083	Economy	29400.00
0005435846207	25083	Economy	29400.00
0005435846200	25083	Economy	29400.00
0005435844270	25083	Economy	29400.00
0005435846201	25083	Economy	29400.00
0005435846203	25083	Economy	29400.00
0005435844269	25083	Economy	29400.00
0005435846202	25083	Economy	29400.00
0005435844262	25083	Economy	29400.00
0005435846205	25083	Economy	29400.00
0005433007840	1855	Business	48700.00
0005432295847	1855	Business	48700.00
0005433007842	1855	Business	48700.00
0005433007909	1855	Economy	16200.00
0005433007851	1855	Economy	16200.00
0005433007885	1855	Economy	16200.00
0005433810506	1855	Economy	16200.00
0005433007857	1855	Economy	16200.00
0005432295846	1855	Economy	16200.00
0005433810507	1855	Economy	16200.00
0005433008016	22625	Business	48700.00
0005433284902	22625	Business	48700.00
0005433008030	22625	Business	48700.00
0005433008021	22625	Business	48700.00
0005433284886	22625	Business	48700.00
0005433284905	22625	Business	48700.00
0005433284906	22625	Business	48700.00
0005433284883	22625	Business	48700.00
0005433284896	22625	Economy	16200.00
0005433008029	22625	Economy	16200.00
0005433008010	22625	Economy	16200.00
0005433008014	22625	Economy	16200.00
0005433008009	22625	Economy	16200.00
0005433008026	22625	Economy	16200.00
0005433008051	22625	Economy	16200.00
0005433284893	22625	Economy	16200.00
0005433008035	22625	Economy	17900.00
0005433284888	22625	Economy	17900.00
0005433284898	22625	Economy	17900.00
0005433008049	22625	Economy	17900.00
0005433008045	22625	Economy	16200.00
0005433008032	22625	Economy	16200.00
0005433008036	22625	Economy	16200.00
0005433008054	22625	Economy	16200.00
0005433284890	22625	Economy	16200.00
0005433284897	22625	Economy	16200.00
0005433284907	22625	Economy	16200.00
0005433284880	22625	Economy	16200.00
0005433284909	22625	Economy	16200.00
0005433008020	22625	Economy	16200.00
0005433008023	22625	Economy	16200.00
0005433008031	22625	Economy	16200.00
0005433284885	22625	Economy	16200.00
0005433008025	22625	Economy	16200.00
0005433008037	22625	Economy	16200.00
0005433284884	22625	Economy	16200.00
0005433008041	22625	Economy	16200.00
0005433008011	22625	Economy	16200.00
0005433284887	22625	Economy	16200.00
0005433284881	22625	Economy	16200.00
0005433284882	22625	Economy	16200.00
0005433008033	22625	Economy	16200.00
0005433008038	22625	Economy	16200.00
0005433284903	22625	Economy	16200.00
0005433008022	22625	Economy	16200.00
0005433284879	22625	Economy	16200.00
0005433008008	22625	Economy	16200.00
0005433008013	22625	Economy	16200.00
0005433008046	22625	Economy	16200.00
0005433008019	22625	Economy	16200.00
0005433008034	22625	Economy	16200.00
0005433284908	22625	Economy	16200.00
0005433284894	22625	Economy	16200.00
0005433284891	22625	Economy	16200.00
0005433008044	22625	Economy	16200.00
0005433008012	22625	Economy	16200.00
0005433008040	22625	Economy	16200.00
0005433008042	22625	Economy	16200.00
0005433008015	22625	Economy	16200.00
0005433008053	22625	Economy	16200.00
0005433008050	22625	Economy	16200.00
0005433008028	22625	Economy	16200.00
0005433008047	22625	Economy	16200.00
0005433284910	22625	Economy	16200.00
0005433008018	22625	Economy	16200.00
0005433008017	22625	Economy	16200.00
0005433008024	22625	Economy	16200.00
0005433008039	22625	Economy	16200.00
0005433008052	22625	Economy	16200.00
0005433284889	22625	Economy	16200.00
0005433284900	22625	Economy	16200.00
0005433284899	22625	Economy	16200.00
0005433284901	22625	Economy	16200.00
0005433008048	22625	Economy	16200.00
0005433284892	22625	Economy	16200.00
0005433008027	22625	Economy	16200.00
0005433008043	22625	Economy	16200.00
0005433284904	22625	Economy	16200.00
0005433284895	22625	Economy	16200.00
0005433845983	5583	Business	99800.00
0005433845971	5583	Business	99800.00
0005433845974	5583	Business	99800.00
0005433846011	5583	Business	99800.00
0005432081426	5583	Business	99800.00
0005435282121	5583	Business	99800.00
0005433846005	5583	Business	99800.00
0005433815324	5583	Business	99800.00
0005433845965	5583	Business	99800.00
0005433845987	5583	Business	99800.00
0005433846015	5583	Business	99800.00
0005433845975	5583	Business	99800.00
0005433846016	5583	Economy	33300.00
0005433845964	5583	Economy	33300.00
0005433845992	5583	Economy	33300.00
0005432081427	5583	Economy	33300.00
0005433845962	5583	Economy	33300.00
0005433845994	5583	Economy	33300.00
0005433845973	5583	Economy	33300.00
0005433845977	5583	Economy	33300.00
0005433846017	5583	Economy	33300.00
0005433815322	5583	Economy	33300.00
0005433845998	5583	Economy	36600.00
0005433845986	5583	Economy	36600.00
0005433846014	5583	Economy	36600.00
0005433845997	5583	Economy	36600.00
0005432081430	5583	Economy	33300.00
0005433846010	5583	Economy	33300.00
0005433846002	5583	Economy	33300.00
0005433845979	5583	Economy	33300.00
0005433815320	5583	Economy	33300.00
0005433845976	5583	Economy	33300.00
0005433815323	5583	Economy	33300.00
0005433846006	5583	Economy	33300.00
0005433845999	5583	Economy	33300.00
0005433846018	5583	Economy	33300.00
0005433845963	5583	Economy	33300.00
0005433845996	5583	Economy	33300.00
0005433845982	5583	Economy	33300.00
0005433845980	5583	Economy	33300.00
0005433845970	5583	Economy	33300.00
0005433846000	5583	Economy	33300.00
0005433845985	5583	Economy	33300.00
0005433845990	5583	Economy	33300.00
0005433845972	5583	Economy	33300.00
0005433846008	5583	Economy	33300.00
0005433845991	5583	Economy	33300.00
0005433845981	5583	Economy	33300.00
0005432081429	5583	Economy	33300.00
0005433846004	5583	Economy	33300.00
0005433845989	5583	Economy	33300.00
0005433846003	5583	Economy	33300.00
0005433815321	5583	Economy	33300.00
0005432081432	5583	Economy	33300.00
0005433846009	5583	Economy	33300.00
0005433845966	5583	Economy	33300.00
0005432081431	5583	Economy	33300.00
0005433846001	5583	Economy	33300.00
0005433846020	5583	Economy	33300.00
0005433845993	5583	Economy	33300.00
0005433846021	5583	Economy	33300.00
0005433845967	5583	Economy	33300.00
0005433845969	5583	Economy	33300.00
0005433845995	5583	Economy	33300.00
0005433845968	5583	Economy	33300.00
0005433845988	5583	Economy	33300.00
0005432081428	5583	Economy	33300.00
0005433846012	5583	Economy	33300.00
0005433845984	5583	Economy	33300.00
0005433846013	5583	Economy	33300.00
0005433846019	5583	Economy	33300.00
0005433845978	5583	Economy	33300.00
0005433846007	5583	Economy	33300.00
0005435282192	13851	Business	99800.00
0005435282185	13851	Business	99800.00
0005435282196	13851	Business	99800.00
0005435282195	13851	Business	99800.00
0005435282181	13851	Business	99800.00
0005435282202	13851	Business	99800.00
0005435282187	13851	Business	99800.00
0005432003662	13851	Business	99800.00
0005434173469	13851	Business	99800.00
0005433845754	13851	Economy	33300.00
0005432003663	13851	Economy	33300.00
0005435282182	13851	Economy	33300.00
0005435282190	13851	Economy	33300.00
0005435282205	13851	Economy	33300.00
0005432003661	13851	Economy	33300.00
0005434173471	13851	Economy	33300.00
0005435282189	13851	Economy	33300.00
0005433845667	13851	Economy	33300.00
0005434173472	13851	Economy	33300.00
0005435282186	13851	Economy	33300.00
0005435282194	13851	Economy	33300.00
0005435282200	13851	Economy	33300.00
0005435282199	13851	Economy	33300.00
0005435282184	13851	Economy	33300.00
0005435282193	13851	Economy	33300.00
0005435282201	13851	Economy	33300.00
0005434173468	13851	Economy	33300.00
0005433845704	13851	Economy	33300.00
0005435282197	13851	Economy	33300.00
0005435282191	13851	Economy	33300.00
0005435282198	13851	Economy	33300.00
0005433845718	13851	Economy	33300.00
0005435282206	13851	Economy	33300.00
0005434173470	13851	Economy	33300.00
0005435282204	13851	Economy	33300.00
0005435282188	13851	Economy	33300.00
0005435282207	13851	Economy	33300.00
0005435282203	13851	Economy	33300.00
0005435282183	13851	Economy	33300.00
0005434620328	7825	Economy	16600.00
0005432112487	7825	Economy	16600.00
0005434620343	7825	Economy	15100.00
0005434620342	7825	Economy	15100.00
0005434620332	7825	Economy	15100.00
0005434620334	7825	Economy	15100.00
0005434620338	7825	Economy	15100.00
0005435332160	7825	Economy	15100.00
0005434620329	7825	Economy	15100.00
0005434620333	7825	Economy	15100.00
0005434620339	7825	Economy	15100.00
0005434620327	7825	Economy	15100.00
0005434620344	7825	Economy	15100.00
0005434620335	7825	Economy	15100.00
0005434620346	7825	Economy	15100.00
0005434620340	7825	Economy	15100.00
0005432112488	7825	Economy	15100.00
0005434620345	7825	Economy	15100.00
0005434620341	7825	Economy	15100.00
0005434620337	7825	Economy	15100.00
0005434620347	7825	Economy	15100.00
0005434620330	7825	Economy	15100.00
0005432112486	7825	Economy	15100.00
0005434620331	7825	Economy	15100.00
0005434620336	7825	Economy	15100.00
0005435332201	32962	Economy	15100.00
0005435332208	32962	Economy	15100.00
0005435332209	32962	Economy	15100.00
0005435332200	32962	Economy	15100.00
0005435332206	32962	Economy	15100.00
0005435332205	32962	Economy	15100.00
0005435332207	32962	Economy	15100.00
0005435332199	32962	Economy	15100.00
0005435332203	32962	Economy	15100.00
0005435332202	32962	Economy	15100.00
0005435332204	32962	Economy	15100.00
0005434620284	32962	Economy	15100.00
0005435784917	4303	Business	38000.00
0005435784937	4303	Business	38000.00
0005435784908	4303	Business	38000.00
0005435784916	4303	Business	38000.00
0005435784921	4303	Business	38000.00
0005435784910	4303	Economy	12700.00
0005435784912	4303	Economy	12700.00
0005435784928	4303	Economy	12700.00
0005435784922	4303	Economy	12700.00
0005434993899	4303	Economy	12700.00
0005435784915	4303	Economy	12700.00
0005435918573	4303	Economy	13900.00
0005434993901	4303	Economy	13900.00
0005435784913	4303	Economy	13900.00
0005435784933	4303	Economy	13900.00
0005435784924	4303	Economy	12700.00
0005435784919	4303	Economy	12700.00
0005435784906	4303	Economy	12700.00
0005435784920	4303	Economy	12700.00
0005435784911	4303	Economy	12700.00
0005435784932	4303	Economy	12700.00
0005434993898	4303	Economy	12700.00
0005434993902	4303	Economy	12700.00
0005435784938	4303	Economy	12700.00
0005432190582	4303	Economy	12700.00
0005435784914	4303	Economy	12700.00
0005435784929	4303	Economy	12700.00
0005434993897	4303	Economy	12700.00
0005435784926	4303	Economy	12700.00
0005434993896	4303	Economy	12700.00
0005435784905	4303	Economy	12700.00
0005435784934	4303	Economy	12700.00
0005435784918	4303	Economy	12700.00
0005435784927	4303	Economy	12700.00
0005434993900	4303	Economy	12700.00
0005435784923	4303	Economy	12700.00
0005435787326	4303	Economy	12700.00
0005434993903	4303	Economy	12700.00
0005435784907	4303	Economy	12700.00
0005435784936	4303	Economy	12700.00
0005432190579	4303	Economy	12700.00
0005435787327	4303	Economy	12700.00
0005435784935	4303	Economy	12700.00
0005435784930	4303	Economy	12700.00
0005432190581	4303	Economy	12700.00
0005434993905	4303	Economy	12700.00
0005432190580	4303	Economy	12700.00
0005434993895	4303	Economy	12700.00
0005435784931	4303	Economy	12700.00
0005435784925	4303	Economy	12700.00
0005435784909	4303	Economy	12700.00
0005434993904	4303	Economy	12700.00
0005435918596	27281	Economy	13900.00
0005432195666	27281	Economy	13900.00
0005432195664	27281	Economy	12700.00
0005434993864	27281	Economy	12700.00
0005435918594	27281	Economy	12700.00
0005432195665	27281	Economy	12700.00
0005435918595	27281	Economy	12700.00
0005435918597	27281	Economy	12700.00
0005435918593	27281	Economy	12700.00
0005432146173	19882	Economy	14000.00
0005432146171	19882	Economy	12800.00
0005432146172	19882	Economy	12800.00
0005432146174	19882	Economy	12800.00
0005432566877	4737	Business	40900.00
0005432566839	4737	Business	40900.00
0005432459173	4737	Business	40900.00
0005432566848	4737	Business	40900.00
0005432170300	4737	Business	40900.00
0005434081611	4737	Business	40900.00
0005434081621	4737	Business	40900.00
0005432566899	4737	Business	40900.00
0005432571275	4737	Business	40900.00
0005432566884	4737	Business	40900.00
0005432170304	4737	Business	40900.00
0005432566879	4737	Business	40900.00
0005432459190	4737	Business	40900.00
0005432459200	4737	Business	40900.00
0005432566838	4737	Business	40900.00
0005432566856	4737	Business	40900.00
0005432566880	4737	Business	40900.00
0005434081615	4737	Business	40900.00
0005432459183	4737	Business	40900.00
0005432459222	4737	Business	40900.00
0005432459194	4737	Business	40900.00
0005432459204	4737	Business	40900.00
0005432566858	4737	Economy	15000.00
0005432571274	4737	Economy	15000.00
0005434081616	4737	Economy	13600.00
0005434081602	4737	Economy	13600.00
0005432459186	4737	Economy	13600.00
0005432459195	4737	Economy	13600.00
0005432566850	4737	Economy	13600.00
0005433451593	4737	Economy	13600.00
0005432459185	4737	Economy	13600.00
0005432566892	4737	Economy	13600.00
0005432459191	4737	Economy	13600.00
0005432459213	4737	Economy	13600.00
0005432566855	4737	Economy	13600.00
0005432459184	4737	Economy	13600.00
0005432459176	4737	Economy	13600.00
0005432459198	4737	Economy	13600.00
0005432566898	4737	Economy	13600.00
0005434081607	4737	Economy	13600.00
0005432566896	4737	Economy	13600.00
0005432459209	4737	Economy	13600.00
0005433452713	4737	Economy	13600.00
0005432170301	4737	Economy	13600.00
0005434081608	4737	Economy	13600.00
0005432459215	4737	Economy	13600.00
0005434081601	4737	Economy	13600.00
0005432459179	4737	Economy	13600.00
0005432566883	4737	Economy	13600.00
0005432566859	4737	Economy	13600.00
0005432566857	4737	Economy	13600.00
0005434081625	4737	Economy	13600.00
0005432566852	4737	Economy	13600.00
0005432459187	4737	Economy	13600.00
0005434081617	4737	Economy	13600.00
0005432566845	4737	Economy	13600.00
0005432459219	4737	Economy	13600.00
0005434081606	4737	Economy	13600.00
0005432459192	4737	Economy	13600.00
0005432459174	4737	Economy	13600.00
0005434081618	4737	Economy	13600.00
0005432459188	4737	Economy	13600.00
0005434081604	4737	Economy	13600.00
0005432459172	4737	Economy	13600.00
0005432566870	4737	Economy	13600.00
0005432566885	4737	Economy	13600.00
0005434081623	4737	Economy	13600.00
0005432566851	4737	Economy	13600.00
0005434081612	4737	Economy	13600.00
0005433451595	4737	Economy	13600.00
0005434559087	4737	Economy	13600.00
0005432566864	4737	Economy	13600.00
0005432459203	4737	Economy	13600.00
0005432459218	4737	Economy	13600.00
0005432566897	4737	Economy	13600.00
0005432566894	4737	Economy	13600.00
0005432566874	4737	Economy	13600.00
0005432566889	4737	Economy	13600.00
0005432170305	4737	Economy	13600.00
0005432566887	4737	Economy	13600.00
0005432459206	4737	Economy	13600.00
0005432566846	4737	Economy	13600.00
0005434081620	4737	Economy	13600.00
0005432459189	4737	Economy	13600.00
0005432566891	4737	Economy	13600.00
0005432170299	4737	Economy	13600.00
0005434081613	4737	Economy	13600.00
0005434081605	4737	Economy	13600.00
0005434081614	4737	Economy	13600.00
0005432186826	4737	Economy	13600.00
0005432459205	4737	Economy	13600.00
0005432170302	4737	Economy	13600.00
0005432566863	4737	Economy	13600.00
0005432459208	4737	Economy	13600.00
0005432459197	4737	Economy	13600.00
0005432459175	4737	Economy	13600.00
0005432566866	4737	Economy	13600.00
0005434081598	4737	Economy	13600.00
0005432566860	4737	Economy	13600.00
0005432459212	4737	Economy	13600.00
0005432459221	4737	Economy	13600.00
0005432566843	4737	Economy	13600.00
0005434081609	4737	Economy	13600.00
0005432459216	4737	Economy	13600.00
0005432566842	4737	Economy	13600.00
0005432566895	4737	Economy	15000.00
0005432459207	4737	Economy	13600.00
0005434081599	4737	Economy	15000.00
0005432459211	4737	Economy	15000.00
0005432459196	4737	Economy	13600.00
0005432566840	4737	Economy	13600.00
0005432186825	4737	Economy	13600.00
0005432459199	4737	Economy	13600.00
0005432459193	4737	Economy	13600.00
0005432459201	4737	Economy	13600.00
0005432459180	4737	Economy	13600.00
0005434559086	4737	Economy	13600.00
0005432566875	4737	Economy	13600.00
0005432459171	4737	Economy	13600.00
0005432459220	4737	Economy	13600.00
0005432566886	4737	Economy	13600.00
0005432459217	4737	Economy	13600.00
0005432566893	4737	Economy	13600.00
0005433451594	4737	Economy	13600.00
0005432566869	4737	Economy	13600.00
0005432566878	4737	Economy	13600.00
0005432571273	4737	Economy	13600.00
0005432566881	4737	Economy	13600.00
0005432566890	4737	Economy	13600.00
0005434081622	4737	Economy	13600.00
0005432566867	4737	Economy	13600.00
0005432566882	4737	Economy	13600.00
0005434081603	4737	Economy	13600.00
0005432566871	4737	Economy	13600.00
0005433451596	4737	Economy	13600.00
0005432459202	4737	Economy	13600.00
0005432571272	4737	Economy	13600.00
0005432566888	4737	Economy	13600.00
0005432566862	4737	Economy	13600.00
0005432566853	4737	Economy	13600.00
0005432459178	4737	Economy	13600.00
0005432566872	4737	Economy	13600.00
0005432566849	4737	Economy	13600.00
0005432566841	4737	Economy	13600.00
0005432566847	4737	Economy	13600.00
0005432566900	4737	Economy	13600.00
0005432566876	4737	Economy	13600.00
0005432566873	4737	Economy	13600.00
0005434559083	4737	Economy	13600.00
0005432459177	4737	Economy	13600.00
0005432566861	4737	Economy	13600.00
0005434081619	4737	Economy	13600.00
0005432566854	4737	Economy	13600.00
0005433452712	4737	Economy	13600.00
0005432459210	4737	Economy	13600.00
0005432170303	4737	Economy	13600.00
0005432566865	4737	Economy	13600.00
0005432566844	4737	Economy	13600.00
0005432459181	4737	Economy	13600.00
0005434559085	4737	Economy	13600.00
0005434081624	4737	Economy	13600.00
0005434081610	4737	Economy	13600.00
0005432186824	4737	Economy	13600.00
0005432186823	4737	Economy	13600.00
0005434081600	4737	Economy	13600.00
0005432459182	4737	Economy	13600.00
0005434559084	4737	Economy	13600.00
0005432459214	4737	Economy	13600.00
0005432566868	4737	Economy	13600.00
0005432566530	30551	Business	40900.00
0005432566616	30551	Business	40900.00
0005432213557	30551	Business	40900.00
0005432566586	30551	Business	40900.00
0005432566615	30551	Business	40900.00
0005432213558	30551	Economy	13600.00
0005432459031	30551	Economy	13600.00
0005432566548	30551	Economy	13600.00
0005432566588	30551	Economy	13600.00
0005432566614	30551	Economy	13600.00
0005432566557	30551	Economy	13600.00
0005432566560	30551	Economy	13600.00
0005434081516	30551	Economy	13600.00
0005432566567	30551	Economy	13600.00
0005432213560	30551	Economy	13600.00
0005432566617	30551	Economy	15000.00
0005432566618	30551	Economy	13600.00
0005432213559	30551	Economy	13600.00
0005432566559	30551	Economy	13600.00
0005432566553	30551	Economy	13600.00
0005432566587	30551	Economy	13600.00
0005432458956	30551	Economy	13600.00
0005432458980	30551	Economy	13600.00
0005432459007	30551	Economy	13600.00
0005432459008	30551	Economy	13600.00
0005435722024	13614	Economy	9900.00
0005435722025	13614	Economy	9900.00
0005432295846	22815	Economy	9700.00
0005432295847	22815	Economy	8800.00
0005435097086	11083	Business	23600.00
0005433341899	11083	Business	23600.00
0005433341987	11083	Business	23600.00
0005433341905	11083	Business	23600.00
0005433341893	11083	Business	23600.00
0005433341967	11083	Business	23600.00
0005433341934	11083	Business	23600.00
0005435097083	11083	Business	23600.00
0005433341918	11083	Business	23600.00
0005433341958	11083	Business	23600.00
0005435097087	11083	Business	23600.00
0005433341916	11083	Economy	7900.00
0005433341945	11083	Economy	7900.00
0005433341975	11083	Economy	7900.00
0005433341915	11083	Economy	7900.00
0005433341946	11083	Economy	7900.00
0005433341978	11083	Economy	7900.00
0005433341911	11083	Economy	7900.00
0005433341964	11083	Economy	7900.00
0005433341900	11083	Economy	7900.00
0005433341888	11083	Economy	7900.00
0005433341942	11083	Economy	7900.00
0005433341917	11083	Economy	7900.00
0005435097081	11083	Economy	7900.00
0005433341980	11083	Economy	7900.00
0005433341935	11083	Economy	7900.00
0005433341938	11083	Economy	7900.00
0005433341970	11083	Economy	7900.00
0005433341972	11083	Economy	7900.00
0005433341923	11083	Economy	7900.00
0005433341986	11083	Economy	7900.00
0005433341952	11083	Economy	7900.00
0005433341933	11083	Economy	7900.00
0005433341947	11083	Economy	7900.00
0005433341949	11083	Economy	7900.00
0005433341896	11083	Economy	7900.00
0005433341895	11083	Economy	7900.00
0005433341944	11083	Economy	7900.00
0005433341983	11083	Economy	7900.00
0005433341950	11083	Economy	7900.00
0005433341955	11083	Economy	7900.00
0005433341953	11083	Economy	7900.00
0005433341913	11083	Economy	7900.00
0005433341943	11083	Economy	7900.00
0005433341904	11083	Economy	8600.00
0005433341903	11083	Economy	8600.00
0005433341981	11083	Economy	8600.00
0005435097079	11083	Economy	8600.00
0005433341920	11083	Economy	7900.00
0005433341931	11083	Economy	7900.00
0005433341977	11083	Economy	7900.00
0005433341906	11083	Economy	7900.00
0005433341979	11083	Economy	7900.00
0005433341937	11083	Economy	7900.00
0005433341924	11083	Economy	7900.00
0005433341930	11083	Economy	7900.00
0005433341936	11083	Economy	7900.00
0005433341894	11083	Economy	7900.00
0005433341897	11083	Economy	7900.00
0005433341941	11083	Economy	7900.00
0005433341907	11083	Economy	7900.00
0005433341982	11083	Economy	7900.00
0005433341971	11083	Economy	7900.00
0005433341976	11083	Economy	7900.00
0005433341956	11083	Economy	7900.00
0005433341951	11083	Economy	7900.00
0005435097084	11083	Economy	7900.00
0005433341901	11083	Economy	7900.00
0005433341939	11083	Economy	7900.00
0005433341984	11083	Economy	7900.00
0005433341914	11083	Economy	7900.00
0005433341959	11083	Economy	7900.00
0005433341891	11083	Economy	7900.00
0005433341908	11083	Economy	7900.00
0005433341968	11083	Economy	7900.00
0005435097082	11083	Economy	7900.00
0005433341927	11083	Economy	7900.00
0005433341889	11083	Economy	7900.00
0005433341925	11083	Economy	7900.00
0005433341922	11083	Economy	7900.00
0005433341966	11083	Economy	7900.00
0005433341909	11083	Economy	7900.00
0005433341910	11083	Economy	7900.00
0005435097085	11083	Economy	7900.00
0005433341919	11083	Economy	7900.00
0005433341974	11083	Economy	7900.00
0005433341929	11083	Economy	7900.00
0005433341921	11083	Economy	7900.00
0005433341965	11083	Economy	7900.00
0005435097080	11083	Economy	7900.00
0005433341940	11083	Economy	7900.00
0005433341962	11083	Economy	7900.00
0005433341985	11083	Economy	7900.00
0005433341954	11083	Economy	7900.00
0005433341912	11083	Economy	7900.00
0005433341928	11083	Economy	7900.00
0005433341948	11083	Economy	7900.00
0005433341969	11083	Economy	7900.00
0005433341957	11083	Economy	7900.00
0005433341973	11083	Economy	7900.00
0005433341892	11083	Economy	7900.00
0005433341960	11083	Economy	7900.00
0005433341963	11083	Economy	7900.00
0005433341890	11083	Economy	7900.00
0005433341898	11083	Economy	7900.00
0005433341902	11083	Economy	7900.00
0005433341961	11083	Economy	7900.00
0005433341926	11083	Economy	7900.00
0005433341932	11083	Economy	7900.00
0005435380245	17089	Business	23600.00
0005432293178	17089	Economy	7900.00
0005432293177	17089	Economy	7900.00
0005435545641	17089	Economy	7900.00
0005435380246	17089	Economy	7900.00
0005435380240	17089	Economy	7900.00
0005435380242	17089	Economy	7900.00
0005432293176	17089	Economy	7900.00
0005435380241	17089	Economy	7900.00
0005433341432	17089	Economy	7900.00
0005435380243	17089	Economy	7900.00
0005435545642	17089	Economy	7900.00
0005435380244	17089	Economy	7900.00
0005433481071	9103	Business	26600.00
0005433506949	9103	Business	26600.00
0005433506954	9103	Business	26600.00
0005433481067	9103	Economy	8900.00
0005433481069	9103	Economy	8900.00
0005433506953	9103	Economy	9800.00
0005433506944	9103	Economy	8900.00
0005433481075	9103	Economy	8900.00
0005433506957	9103	Economy	8900.00
0005433481074	9103	Economy	8900.00
0005433506952	9103	Economy	8900.00
0005433506956	9103	Economy	8900.00
0005433481070	9103	Economy	8900.00
0005433506955	9103	Economy	8900.00
0005433481072	9103	Economy	8900.00
0005433506945	9103	Economy	8900.00
0005433506948	9103	Economy	8900.00
0005433506951	9103	Economy	8900.00
0005433506950	9103	Economy	8900.00
0005433506947	9103	Economy	8900.00
0005433481073	9103	Economy	8900.00
0005433506946	9103	Economy	8900.00
0005433481068	9103	Economy	8900.00
0005433506958	9103	Economy	8900.00
0005433506886	20453	Business	26600.00
0005433481030	20453	Business	26600.00
0005432919619	20453	Business	26600.00
0005432919610	20453	Business	26600.00
0005433506869	20453	Business	26600.00
0005432919618	20453	Economy	8900.00
0005432919612	20453	Economy	8900.00
0005432919630	20453	Economy	9800.00
0005432919624	20453	Economy	9800.00
0005432919614	20453	Economy	9800.00
0005432919628	20453	Economy	8900.00
0005434158952	20453	Economy	8900.00
0005432919611	20453	Economy	8900.00
0005432919620	20453	Economy	8900.00
0005432919616	20453	Economy	8900.00
0005432919622	20453	Economy	8900.00
0005432919621	20453	Economy	8900.00
0005432919617	20453	Economy	8900.00
0005432919615	20453	Economy	8900.00
0005433481029	20453	Economy	8900.00
0005434158951	20453	Economy	8900.00
0005432919623	20453	Economy	8900.00
0005432919613	20453	Economy	8900.00
0005433506863	20453	Economy	8900.00
0005432919626	20453	Economy	8900.00
0005432919629	20453	Economy	8900.00
0005432919625	20453	Economy	8900.00
0005434158953	20453	Economy	8900.00
0005432919627	20453	Economy	8900.00
0005432394051	10143	Economy	5800.00
0005432396190	10143	Economy	5800.00
0005432394049	10143	Economy	5800.00
0005432396188	10143	Economy	5800.00
0005432394050	10143	Economy	5800.00
0005432396191	10143	Economy	5800.00
0005432396187	10143	Economy	5800.00
0005432394048	10143	Economy	5800.00
0005432396189	10143	Economy	5800.00
0005432396170	18292	Economy	5800.00
0005432396171	18292	Economy	5800.00
0005432396172	18292	Economy	5800.00
0005434928265	10967	Business	9500.00
0005434411724	10967	Business	9500.00
0005434411726	10967	Economy	3200.00
0005434928263	10967	Economy	3200.00
0005434411725	10967	Economy	3200.00
0005434411727	10967	Economy	3200.00
0005434928264	10967	Economy	3200.00
0005435125878	14711	Business	9500.00
0005435125863	14711	Business	9500.00
0005435625965	14711	Business	9500.00
0005435125873	14711	Business	9500.00
0005435125880	14711	Business	9500.00
0005435125868	14711	Business	9500.00
0005435125882	14711	Business	9500.00
0005435625967	14711	Business	9500.00
0005435625957	14711	Business	9500.00
0005435625954	14711	Business	9500.00
0005435625959	14711	Business	9500.00
0005435625953	14711	Economy	3200.00
0005435125862	14711	Economy	3200.00
0005435125883	14711	Economy	3200.00
0005435125860	14711	Economy	3200.00
0005435125871	14711	Economy	3200.00
0005435625951	14711	Economy	3500.00
0005435625962	14711	Economy	3500.00
0005435625958	14711	Economy	3500.00
0005435125866	14711	Economy	3200.00
0005435554123	14711	Economy	3200.00
0005435125884	14711	Economy	3200.00
0005435125896	14711	Economy	3200.00
0005435625961	14711	Economy	3200.00
0005435125870	14711	Economy	3200.00
0005435125857	14711	Economy	3200.00
0005435554128	14711	Economy	3200.00
0005435125881	14711	Economy	3200.00
0005435625949	14711	Economy	3200.00
0005435125858	14711	Economy	3200.00
0005435125859	14711	Economy	3200.00
0005435125864	14711	Economy	3200.00
0005435556660	14711	Economy	3200.00
0005435125861	14711	Economy	3200.00
0005434928252	14711	Economy	3200.00
0005435125891	14711	Economy	3200.00
0005435125890	14711	Economy	3200.00
0005435125877	14711	Economy	3200.00
0005435125893	14711	Economy	3200.00
0005435125869	14711	Economy	3200.00
0005435125856	14711	Economy	3200.00
0005435625955	14711	Economy	3200.00
0005435125892	14711	Economy	3200.00
0005435125872	14711	Economy	3200.00
0005435125888	14711	Economy	3200.00
0005435554127	14711	Economy	3200.00
0005435625968	14711	Economy	3200.00
0005435625950	14711	Economy	3200.00
0005435625966	14711	Economy	3200.00
0005435554125	14711	Economy	3200.00
0005435125874	14711	Economy	3200.00
0005435556659	14711	Economy	3200.00
0005435125886	14711	Economy	3200.00
0005435625960	14711	Economy	3200.00
0005435125894	14711	Economy	3200.00
0005435625964	14711	Economy	3200.00
0005435625963	14711	Economy	3200.00
0005435125879	14711	Economy	3200.00
0005435625952	14711	Economy	3200.00
0005435125889	14711	Economy	3200.00
0005435125887	14711	Economy	3200.00
0005435554124	14711	Economy	3200.00
0005435125895	14711	Economy	3200.00
0005435625956	14711	Economy	3200.00
0005435125875	14711	Economy	3200.00
0005435125885	14711	Economy	3200.00
0005435625969	14711	Economy	3200.00
0005435625970	14711	Economy	3200.00
0005435125865	14711	Economy	3200.00
0005435554126	14711	Economy	3200.00
0005435125876	14711	Economy	3200.00
0005435125867	14711	Economy	3200.00
0005435715249	7098	Business	86900.00
0005435715263	7098	Business	86900.00
0005432398150	7098	Business	86900.00
0005435715252	7098	Economy	29000.00
0005432400080	7098	Economy	31900.00
0005435715258	7098	Economy	29000.00
0005435715259	7098	Economy	29000.00
0005435715261	7098	Economy	29000.00
0005432400081	7098	Economy	29000.00
0005435715262	7098	Economy	29000.00
0005435715254	7098	Economy	29000.00
0005432398149	7098	Economy	29000.00
0005432398151	7098	Economy	29000.00
0005435715250	7098	Economy	29000.00
0005432400079	7098	Economy	29000.00
0005432400077	7098	Economy	29000.00
0005435715260	7098	Economy	29000.00
0005435715253	7098	Economy	29000.00
0005432400078	7098	Economy	29000.00
0005435715251	7098	Economy	29000.00
0005435715257	7098	Economy	29000.00
0005435443156	7098	Economy	29000.00
0005435715256	7098	Economy	29000.00
0005435715255	7098	Economy	29000.00
0005435443157	7098	Economy	29000.00
0005435443195	27073	Business	86900.00
0005435715178	27073	Business	86900.00
0005435178980	27073	Economy	29000.00
0005435715179	27073	Economy	29000.00
0005435443197	27073	Economy	29000.00
0005435443200	27073	Economy	29000.00
0005435443193	27073	Economy	29000.00
0005435443199	27073	Economy	29000.00
0005435443201	27073	Economy	29000.00
0005435178979	27073	Economy	29000.00
0005435443198	27073	Economy	29000.00
0005435443194	27073	Economy	29000.00
0005435443196	27073	Economy	29000.00
0005435443192	27073	Economy	29000.00
0005434084874	2723	Economy	7700.00
0005433060375	2723	Economy	7700.00
0005433060376	2723	Economy	7700.00
0005434084871	2723	Economy	7700.00
0005434084872	2723	Economy	7700.00
0005433060369	2723	Economy	7700.00
0005434084870	2723	Economy	7700.00
0005434084873	2723	Economy	7700.00
0005433060380	28472	Economy	7700.00
0005435540665	11374	Business	20200.00
0005435517606	11374	Economy	7400.00
0005435540666	11374	Economy	6700.00
0005435517605	11374	Economy	6700.00
0005435528987	22250	Business	20200.00
0005435528969	22250	Business	20200.00
0005435528983	22250	Business	20200.00
0005435540727	22250	Business	20200.00
0005435528968	22250	Business	20200.00
0005432294455	22250	Business	20200.00
0005435540718	22250	Business	20200.00
0005435540711	22250	Business	20200.00
0005435540714	22250	Economy	6700.00
0005435540725	22250	Economy	6700.00
0005432294456	22250	Economy	6700.00
0005435540724	22250	Economy	7400.00
0005435540721	22250	Economy	7400.00
0005435540732	22250	Economy	7400.00
0005435540712	22250	Economy	6700.00
0005435540729	22250	Economy	6700.00
0005435528982	22250	Economy	6700.00
0005435528976	22250	Economy	6700.00
0005435540722	22250	Economy	6700.00
0005435528979	22250	Economy	6700.00
0005435540726	22250	Economy	6700.00
0005435528988	22250	Economy	6700.00
0005435528970	22250	Economy	6700.00
0005435528971	22250	Economy	6700.00
0005435540723	22250	Economy	6700.00
0005435528975	22250	Economy	6700.00
0005435528974	22250	Economy	6700.00
0005435540731	22250	Economy	6700.00
0005435540713	22250	Economy	6700.00
0005435540719	22250	Economy	6700.00
0005435528980	22250	Economy	6700.00
0005435540716	22250	Economy	6700.00
0005435528986	22250	Economy	6700.00
0005435528972	22250	Economy	6700.00
0005435528977	22250	Economy	6700.00
0005435528981	22250	Economy	6700.00
0005435540717	22250	Economy	6700.00
0005435528967	22250	Economy	6700.00
0005435540733	22250	Economy	6700.00
0005435540715	22250	Economy	6700.00
0005435528984	22250	Economy	6700.00
0005435528978	22250	Economy	6700.00
0005435540728	22250	Economy	6700.00
0005435540730	22250	Economy	6700.00
0005435528985	22250	Economy	6700.00
0005435528973	22250	Economy	6700.00
0005435540720	22250	Economy	6700.00
0005434906660	2310	Business	20200.00
0005433250966	2310	Business	20200.00
0005434906638	2310	Business	20200.00
0005433250942	2310	Business	20200.00
0005434906679	2310	Business	20200.00
0005434906657	2310	Business	20200.00
0005434906667	2310	Business	20200.00
0005434906685	2310	Business	20200.00
0005434906656	2310	Business	20200.00
0005434906687	2310	Business	20200.00
0005434906645	2310	Economy	6700.00
0005434906680	2310	Economy	6700.00
0005434906644	2310	Economy	6700.00
0005434906659	2310	Economy	6700.00
0005434906684	2310	Economy	6700.00
0005434906652	2310	Economy	6700.00
0005434906634	2310	Economy	7400.00
0005434906663	2310	Economy	7400.00
0005434906661	2310	Economy	7400.00
0005434906678	2310	Economy	6700.00
0005433400934	2310	Economy	6700.00
0005434906653	2310	Economy	6700.00
0005434906639	2310	Economy	6700.00
0005434906692	2310	Economy	6700.00
0005434906651	2310	Economy	6700.00
0005434906674	2310	Economy	6700.00
0005434906646	2310	Economy	6700.00
0005434906636	2310	Economy	6700.00
0005434906640	2310	Economy	6700.00
0005434906658	2310	Economy	6700.00
0005434906635	2310	Economy	6700.00
0005434906637	2310	Economy	6700.00
0005434906689	2310	Economy	6700.00
0005434906682	2310	Economy	6700.00
0005433250951	2310	Economy	6700.00
0005433250933	2310	Economy	6700.00
0005434906686	2310	Economy	6700.00
0005434906688	2310	Economy	6700.00
0005434906690	2310	Economy	6700.00
0005434906681	2310	Economy	6700.00
0005434906673	2310	Economy	6700.00
0005434906669	2310	Economy	6700.00
0005434906665	2310	Economy	6700.00
0005434906655	2310	Economy	6700.00
0005434906672	2310	Economy	6700.00
0005434906648	2310	Economy	6700.00
0005434906650	2310	Economy	6700.00
0005434906642	2310	Economy	6700.00
0005434906666	2310	Economy	6700.00
0005434906683	2310	Economy	6700.00
0005434906641	2310	Economy	6700.00
0005434906670	2310	Economy	6700.00
0005434906691	2310	Economy	6700.00
0005434906643	2310	Economy	6700.00
0005433250937	2310	Economy	6700.00
0005434906649	2310	Economy	6700.00
0005434906677	2310	Economy	6700.00
0005434906671	2310	Economy	6700.00
0005434906647	2310	Economy	6700.00
0005434906676	2310	Economy	6700.00
0005434906675	2310	Economy	6700.00
0005434906664	2310	Economy	6700.00
0005434906668	2310	Economy	6700.00
0005433250934	2310	Economy	6700.00
0005434906662	2310	Economy	6700.00
0005434906654	2310	Economy	6700.00
0005433251098	25624	Business	20200.00
0005433251110	25624	Business	20200.00
0005433251106	25624	Business	20200.00
0005433251099	25624	Economy	6700.00
0005433251107	25624	Economy	6700.00
0005433251100	25624	Economy	7400.00
0005433251102	25624	Economy	7400.00
0005433251111	25624	Economy	6700.00
0005433251108	25624	Economy	6700.00
0005433251116	25624	Economy	6700.00
0005433251115	25624	Economy	6700.00
0005433251117	25624	Economy	6700.00
0005433251109	25624	Economy	6700.00
0005433251092	25624	Economy	6700.00
0005433251104	25624	Economy	6700.00
0005433251095	25624	Economy	6700.00
0005433251085	25624	Economy	6700.00
0005433251097	25624	Economy	6700.00
0005433251088	25624	Economy	6700.00
0005433251113	25624	Economy	6700.00
0005433251090	25624	Economy	6700.00
0005433251103	25624	Economy	6700.00
0005433251093	25624	Economy	6700.00
0005433251101	25624	Economy	6700.00
0005433251114	25624	Economy	6700.00
0005433251112	25624	Economy	6700.00
0005433251094	25624	Economy	6700.00
0005433251086	25624	Economy	6700.00
0005433251087	25624	Economy	6700.00
0005433251089	25624	Economy	6700.00
0005433251096	25624	Economy	6700.00
0005433400946	25624	Economy	6700.00
0005433251105	25624	Economy	6700.00
0005433400947	25624	Economy	6700.00
0005433251091	25624	Economy	6700.00
0005432620864	2543	Economy	13600.00
0005432862176	2543	Economy	12400.00
0005432620871	2543	Economy	12400.00
0005432620859	2543	Economy	12400.00
0005432862175	2543	Economy	12400.00
0005432620868	2543	Economy	12400.00
0005432620862	2543	Economy	12400.00
0005432620866	2543	Economy	12400.00
0005432620870	2543	Economy	12400.00
0005432620861	2543	Economy	12400.00
0005432620867	2543	Economy	12400.00
0005432620865	2543	Economy	12400.00
0005432620860	2543	Economy	12400.00
0005432620872	2543	Economy	12400.00
0005432620863	2543	Economy	12400.00
0005432620858	2543	Economy	12400.00
0005432862173	2543	Economy	12400.00
0005432620869	2543	Economy	12400.00
0005432862209	28056	Economy	12400.00
0005432862204	28056	Economy	12400.00
0005432620787	28056	Economy	12400.00
0005432862208	28056	Economy	12400.00
0005432862203	28056	Economy	12400.00
0005432862206	28056	Economy	12400.00
0005432862207	28056	Economy	12400.00
0005432620789	28056	Economy	12400.00
0005432862205	28056	Economy	12400.00
0005432862202	28056	Economy	12400.00
0005432620786	28056	Economy	12400.00
0005434097456	13091	Economy	11300.00
0005434097458	13091	Economy	11300.00
0005434097457	13091	Economy	11300.00
0005433452713	30995	Economy	8400.00
0005433451593	30995	Economy	8400.00
0005433451594	30995	Economy	8400.00
0005433451596	30995	Economy	8400.00
0005433451595	30995	Economy	8400.00
0005433452712	30995	Economy	8400.00
0005434142542	11982	Economy	6600.00
0005434326084	11982	Economy	6600.00
0005434142541	11982	Economy	6600.00
0005433134079	29857	Economy	7200.00
0005434142560	29857	Economy	6600.00
0005433131652	29857	Economy	6600.00
0005433134083	29857	Economy	6600.00
0005433131650	29857	Economy	6600.00
0005433134080	29857	Economy	6600.00
0005434142559	29857	Economy	6600.00
0005434142557	29857	Economy	6600.00
0005433131651	29857	Economy	6600.00
0005433131653	29857	Economy	6600.00
0005433134082	29857	Economy	6600.00
0005434142558	29857	Economy	6600.00
0005434183555	29857	Economy	6600.00
0005434142556	29857	Economy	6600.00
0005433134081	29857	Economy	6600.00
0005434184640	29857	Economy	6600.00
0005433131649	29857	Economy	6600.00
0005435696964	16457	Economy	19900.00
0005435696976	16457	Economy	19900.00
0005435696985	16457	Economy	19900.00
0005435696975	16457	Economy	18100.00
0005435696967	16457	Economy	18100.00
0005435696972	16457	Economy	18100.00
0005435696984	16457	Economy	18100.00
0005435696962	16457	Economy	18100.00
0005435696970	16457	Economy	18100.00
0005435696958	16457	Economy	18100.00
0005435696971	16457	Economy	18100.00
0005435696974	16457	Economy	18100.00
0005435696968	16457	Economy	18100.00
0005435696981	16457	Economy	18100.00
0005435696980	16457	Economy	18100.00
0005435696982	16457	Economy	18100.00
0005435696979	16457	Economy	18100.00
0005435696963	16457	Economy	18100.00
0005435696969	16457	Economy	18100.00
0005435696977	16457	Economy	18100.00
0005435696965	16457	Economy	18100.00
0005435696966	16457	Economy	18100.00
0005435696960	16457	Economy	18100.00
0005435696983	16457	Economy	18100.00
0005435696978	16457	Economy	18100.00
0005435696961	16457	Economy	18100.00
0005435696959	16457	Economy	18100.00
0005435696973	16457	Economy	18100.00
0005435935010	24743	Economy	18100.00
0005435696847	24743	Economy	18100.00
0005435935011	24743	Economy	18100.00
0005435935009	24743	Economy	18100.00
0005435935008	24743	Economy	18100.00
0005435696866	24743	Economy	18100.00
0005433724746	18781	Economy	4400.00
0005433724743	18781	Economy	4400.00
0005433724745	18781	Economy	4400.00
0005433724747	18781	Economy	4400.00
0005433724744	18781	Economy	4400.00
0005432968813	21616	Economy	4400.00
0005432968814	21616	Economy	4400.00
0005434137136	7323	Business	23100.00
0005434137109	7323	Business	23100.00
0005434087453	7323	Business	23100.00
0005434137139	7323	Business	23100.00
0005434137148	7323	Business	23100.00
0005434137114	7323	Business	23100.00
0005434137152	7323	Business	23100.00
0005434137168	7323	Business	23100.00
0005434137161	7323	Business	23100.00
0005434087452	7323	Business	23100.00
0005434137150	7323	Business	23100.00
0005434087456	7323	Business	23100.00
0005434137106	7323	Economy	7700.00
0005434137151	7323	Economy	7700.00
0005434137115	7323	Economy	7700.00
0005434137156	7323	Economy	7700.00
0005434137144	7323	Economy	7700.00
0005434137146	7323	Economy	7700.00
0005434137125	7323	Economy	7700.00
0005434137137	7323	Economy	7700.00
0005434137103	7323	Economy	7700.00
0005434137101	7323	Economy	8500.00
0005434137116	7323	Economy	8500.00
0005434137165	7323	Economy	8500.00
0005434137120	7323	Economy	8500.00
0005434137140	7323	Economy	7700.00
0005434137105	7323	Economy	7700.00
0005434137108	7323	Economy	7700.00
0005434137117	7323	Economy	7700.00
0005434137149	7323	Economy	7700.00
0005434137154	7323	Economy	7700.00
0005434087457	7323	Economy	7700.00
0005434137126	7323	Economy	7700.00
0005434137132	7323	Economy	7700.00
0005434137160	7323	Economy	7700.00
0005434137121	7323	Economy	7700.00
0005434137119	7323	Economy	7700.00
0005434137102	7323	Economy	7700.00
0005434137118	7323	Economy	7700.00
0005434137129	7323	Economy	7700.00
0005434137164	7323	Economy	7700.00
0005434137175	7323	Economy	7700.00
0005434137143	7323	Economy	7700.00
0005434137135	7323	Economy	7700.00
0005434137104	7323	Economy	7700.00
0005434137110	7323	Economy	7700.00
0005434137169	7323	Economy	7700.00
0005434137174	7323	Economy	7700.00
0005434137157	7323	Economy	7700.00
0005434137163	7323	Economy	7700.00
0005434137159	7323	Economy	7700.00
0005434137134	7323	Economy	7700.00
0005434137130	7323	Economy	7700.00
0005434137122	7323	Economy	7700.00
0005434137133	7323	Economy	7700.00
0005434137173	7323	Economy	7700.00
0005434137112	7323	Economy	7700.00
0005434087455	7323	Economy	7700.00
0005434137123	7323	Economy	7700.00
0005434137153	7323	Economy	7700.00
0005434137147	7323	Economy	7700.00
0005434137107	7323	Economy	7700.00
0005434137141	7323	Economy	7700.00
0005434137155	7323	Economy	7700.00
0005434137172	7323	Economy	7700.00
0005434137113	7323	Economy	7700.00
0005434137138	7323	Economy	7700.00
0005434137170	7323	Economy	7700.00
0005434137124	7323	Economy	7700.00
0005434137171	7323	Economy	7700.00
0005434137158	7323	Economy	7700.00
0005434137166	7323	Economy	7700.00
0005434137111	7323	Economy	7700.00
0005434137131	7323	Economy	7700.00
0005434137128	7323	Economy	7700.00
0005434137142	7323	Economy	7700.00
0005434137127	7323	Economy	7700.00
0005434137145	7323	Economy	7700.00
0005434137167	7323	Economy	7700.00
0005434087454	7323	Economy	7700.00
0005434137162	7323	Economy	7700.00
0005434136676	28565	Business	23100.00
0005434136822	28565	Economy	7700.00
0005434136675	28565	Economy	7700.00
0005434136821	28565	Economy	7700.00
0005434136836	28565	Economy	7700.00
0005434136723	28565	Economy	7700.00
0005435808111	1942	Economy	23900.00
0005435808103	1942	Economy	23900.00
0005434610186	1942	Economy	23900.00
0005435808108	1942	Economy	21700.00
0005434610187	1942	Economy	21700.00
0005435808105	1942	Economy	21700.00
0005435808104	1942	Economy	21700.00
0005434610184	1942	Economy	21700.00
0005435808109	1942	Economy	21700.00
0005435808112	1942	Economy	21700.00
0005435808106	1942	Economy	21700.00
0005435808107	1942	Economy	21700.00
0005434610185	1942	Economy	21700.00
0005435808110	1942	Economy	21700.00
0005433407493	23087	Economy	23900.00
0005433407500	23087	Economy	21700.00
0005433407499	23087	Economy	21700.00
0005433407496	23087	Economy	21700.00
0005433407502	23087	Economy	21700.00
0005433407498	23087	Economy	21700.00
0005433407497	23087	Economy	21700.00
0005433407492	23087	Economy	21700.00
0005433407495	23087	Economy	21700.00
0005433407501	23087	Economy	21700.00
0005433407494	23087	Economy	21700.00
0005434503623	22897	Economy	7600.00
0005434503649	22897	Economy	7600.00
0005434503651	22897	Economy	7600.00
0005434503624	22897	Economy	7600.00
0005434503621	22897	Economy	6900.00
0005434503627	22897	Economy	6900.00
0005434503629	22897	Economy	6900.00
0005434503656	22897	Economy	6900.00
0005434503640	22897	Economy	6900.00
0005434503641	22897	Economy	6900.00
0005434503620	22897	Economy	6900.00
0005434503659	22897	Economy	6900.00
0005434503637	22897	Economy	6900.00
0005434503626	22897	Economy	6900.00
0005434503647	22897	Economy	6900.00
0005434503643	22897	Economy	6900.00
0005434503642	22897	Economy	6900.00
0005434503625	22897	Economy	6900.00
0005434503636	22897	Economy	6900.00
0005434503628	22897	Economy	6900.00
0005434503630	22897	Economy	6900.00
0005434503634	22897	Economy	6900.00
0005434503648	22897	Economy	6900.00
0005434503638	22897	Economy	6900.00
0005434503653	22897	Economy	6900.00
0005434503650	22897	Economy	6900.00
0005434503654	22897	Economy	6900.00
0005434503632	22897	Economy	6900.00
0005434503622	22897	Economy	6900.00
0005434503658	22897	Economy	6900.00
0005434503619	22897	Economy	6900.00
0005434503639	22897	Economy	6900.00
0005434503652	22897	Economy	6900.00
0005434503657	22897	Economy	6900.00
0005434503635	22897	Economy	6900.00
0005434503644	22897	Economy	6900.00
0005434503633	22897	Economy	6900.00
0005434503646	22897	Economy	6900.00
0005434503631	22897	Economy	6900.00
0005434503655	22897	Economy	6900.00
0005434503645	22897	Economy	6900.00
0005435078151	2218	Economy	7700.00
0005435078147	2218	Economy	7000.00
0005435078156	2218	Economy	7000.00
0005435078155	2218	Economy	7000.00
0005435078145	2218	Economy	7000.00
0005435078152	2218	Economy	7000.00
0005435078144	2218	Economy	7000.00
0005435078146	2218	Economy	7000.00
0005435078157	2218	Economy	7000.00
0005435078148	2218	Economy	7000.00
0005435078149	2218	Economy	7000.00
0005435078154	2218	Economy	7000.00
0005435078153	2218	Economy	7000.00
0005435078143	2218	Economy	7000.00
0005435078150	2218	Economy	7000.00
0005435078158	2218	Economy	7000.00
0005433266611	24350	Economy	7700.00
0005433266612	24350	Economy	7000.00
0005433266604	24350	Economy	7000.00
0005433266607	24350	Economy	7000.00
0005433266608	24350	Economy	7000.00
0005433266609	24350	Economy	7000.00
0005433266610	24350	Economy	7000.00
0005433266606	24350	Economy	7000.00
0005433266605	24350	Economy	7000.00
0005433266613	24350	Economy	7000.00
0005434988600	6617	Economy	10800.00
0005434988602	6617	Economy	9800.00
0005435803226	6617	Economy	9800.00
0005434988606	6617	Economy	9800.00
0005434988599	6617	Economy	9800.00
0005434988601	6617	Economy	9800.00
0005434988605	6617	Economy	9800.00
0005434988603	6617	Economy	9800.00
0005434988607	6617	Economy	9800.00
0005434988604	6617	Economy	9800.00
0005435803227	6617	Economy	9800.00
0005435464482	23592	Economy	9800.00
0005435803210	23592	Economy	9800.00
0005435464483	23592	Economy	9800.00
0005435803211	23592	Economy	9800.00
0005432382694	30458	Business	9900.00
0005432382710	30458	Business	9900.00
0005432382724	30458	Business	9900.00
0005432382714	30458	Business	9900.00
0005432382700	30458	Business	9900.00
0005433454850	30458	Business	9900.00
0005432382697	30458	Business	9900.00
0005433449709	30458	Business	9900.00
0005432382703	30458	Economy	3300.00
0005433449701	30458	Economy	3300.00
0005432382713	30458	Economy	3300.00
0005433454848	30458	Economy	3300.00
0005432382720	30458	Economy	3300.00
0005432382708	30458	Economy	3300.00
0005432382707	30458	Economy	3300.00
0005433449710	30458	Economy	3300.00
0005433453738	30458	Economy	3600.00
0005432382691	30458	Economy	3600.00
0005433449711	30458	Economy	3600.00
0005433449712	30458	Economy	3600.00
0005433453739	30458	Economy	3300.00
0005433449715	30458	Economy	3300.00
0005433449700	30458	Economy	3300.00
0005433449697	30458	Economy	3300.00
0005433449704	30458	Economy	3300.00
0005432382706	30458	Economy	3300.00
0005433449699	30458	Economy	3300.00
0005433449705	30458	Economy	3300.00
0005432382696	30458	Economy	3300.00
0005433449703	30458	Economy	3300.00
0005433449714	30458	Economy	3300.00
0005432382726	30458	Economy	3300.00
0005432382698	30458	Economy	3300.00
0005432382716	30458	Economy	3300.00
0005432382725	30458	Economy	3300.00
0005432382718	30458	Economy	3300.00
0005432382722	30458	Economy	3300.00
0005433449695	30458	Economy	3300.00
0005433449707	30458	Economy	3300.00
0005432382702	30458	Economy	3300.00
0005433449702	30458	Economy	3300.00
0005433454849	30458	Economy	3300.00
0005432382723	30458	Economy	3300.00
0005432382719	30458	Economy	3300.00
0005433449716	30458	Economy	3300.00
0005432382717	30458	Economy	3300.00
0005433449698	30458	Economy	3300.00
0005432382693	30458	Economy	3300.00
0005432382695	30458	Economy	3300.00
0005433453737	30458	Economy	3300.00
0005432382711	30458	Economy	3300.00
0005433449706	30458	Economy	3300.00
0005432382721	30458	Economy	3300.00
0005432382705	30458	Economy	3300.00
0005432382699	30458	Economy	3300.00
0005433449708	30458	Economy	3300.00
0005433449696	30458	Economy	3300.00
0005432382715	30458	Economy	3300.00
0005432382712	30458	Economy	3300.00
0005432382709	30458	Economy	3300.00
0005432382701	30458	Economy	3300.00
0005433449713	30458	Economy	3300.00
0005432382704	30458	Economy	3300.00
0005432382692	30458	Economy	3300.00
0005433449604	31335	Economy	3300.00
0005433449605	31335	Economy	3300.00
0005433449588	31335	Economy	3300.00
0005435304096	10765	Economy	15600.00
0005435304095	10765	Economy	15600.00
0005435299721	29717	Economy	17100.00
0005433129222	29717	Economy	15600.00
0005435302147	29717	Economy	15600.00
0005435302146	29717	Economy	15600.00
0005435302145	29717	Economy	15600.00
0005433126793	29717	Economy	15600.00
0005433129225	29717	Economy	15600.00
0005435299720	29717	Economy	15600.00
0005433129224	29717	Economy	15600.00
0005433129223	29717	Economy	15600.00
0005433126792	29717	Economy	15600.00
0005435302144	29717	Economy	15600.00
0005433129221	29717	Economy	15600.00
0005435299722	29717	Economy	15600.00
0005435299723	29717	Economy	15600.00
0005433126794	29717	Economy	15600.00
0005435302148	29717	Economy	15600.00
0005433126791	29717	Economy	15600.00
0005435299724	29717	Economy	15600.00
0005434287022	2398	Economy	17200.00
0005434287017	2398	Economy	17200.00
0005434287009	2398	Economy	17200.00
0005434287019	2398	Economy	15700.00
0005434287026	2398	Economy	15700.00
0005434287014	2398	Economy	15700.00
0005434287010	2398	Economy	15700.00
0005434287025	2398	Economy	15700.00
0005434287011	2398	Economy	15700.00
0005434287028	2398	Economy	15700.00
0005434287016	2398	Economy	15700.00
0005432264444	2398	Economy	15700.00
0005434287015	2398	Economy	15700.00
0005434287013	2398	Economy	15700.00
0005433109844	2398	Economy	15700.00
0005434287021	2398	Economy	15700.00
0005434287024	2398	Economy	15700.00
0005434287008	2398	Economy	15700.00
0005434287006	2398	Economy	15700.00
0005434287018	2398	Economy	15700.00
0005434287007	2398	Economy	15700.00
0005432264445	2398	Economy	15700.00
0005434287020	2398	Economy	15700.00
0005434287012	2398	Economy	15700.00
0005434287023	2398	Economy	15700.00
0005434287027	2398	Economy	15700.00
0005433109906	26827	Economy	17200.00
0005433109899	26827	Economy	15700.00
0005433109900	26827	Economy	15700.00
0005434286892	26827	Economy	15700.00
0005433109903	26827	Economy	15700.00
0005433109902	26827	Economy	15700.00
0005433109904	26827	Economy	15700.00
0005433109909	26827	Economy	15700.00
0005433109907	26827	Economy	15700.00
0005433109908	26827	Economy	15700.00
0005433109911	26827	Economy	15700.00
0005433109901	26827	Economy	15700.00
0005433109910	26827	Economy	15700.00
0005433109905	26827	Economy	15700.00
0005435856152	25491	Economy	22800.00
0005435856154	25491	Economy	22800.00
0005435856153	25491	Economy	22800.00
0005435856151	25491	Economy	22800.00
0005434273057	26670	Economy	22800.00
0005434273058	26670	Economy	22800.00
0005434272172	26670	Economy	22800.00
0005434272173	26670	Economy	22800.00
0005433650442	7155	Business	89800.00
0005433650450	7155	Business	89800.00
0005433650457	7155	Business	89800.00
0005433650461	7155	Business	89800.00
0005433650449	7155	Business	89800.00
0005433650453	7155	Business	89800.00
0005433650441	7155	Economy	29900.00
0005433650436	7155	Economy	29900.00
0005433650420	7155	Economy	29900.00
0005433650413	7155	Economy	29900.00
0005433650448	7155	Economy	29900.00
0005433650445	7155	Economy	29900.00
0005433650418	7155	Economy	29900.00
0005433650438	7155	Economy	32900.00
0005433650456	7155	Economy	32900.00
0005433650439	7155	Economy	29900.00
0005433650423	7155	Economy	29900.00
0005433650415	7155	Economy	29900.00
0005433650422	7155	Economy	29900.00
0005433650462	7155	Economy	29900.00
0005433650429	7155	Economy	29900.00
0005433650427	7155	Economy	29900.00
0005433650444	7155	Economy	29900.00
0005433650435	7155	Economy	29900.00
0005433650440	7155	Economy	29900.00
0005433650443	7155	Economy	29900.00
0005433650414	7155	Economy	29900.00
0005433650451	7155	Economy	29900.00
0005433650452	7155	Economy	29900.00
0005433650428	7155	Economy	29900.00
0005433650426	7155	Economy	29900.00
0005433650437	7155	Economy	29900.00
0005433650458	7155	Economy	29900.00
0005433650421	7155	Economy	29900.00
0005433650433	7155	Economy	29900.00
0005433650455	7155	Economy	29900.00
0005433650432	7155	Economy	29900.00
0005433650434	7155	Economy	29900.00
0005433650447	7155	Economy	29900.00
0005433650416	7155	Economy	29900.00
0005433650431	7155	Economy	29900.00
0005433650430	7155	Economy	29900.00
0005433650419	7155	Economy	29900.00
0005433650446	7155	Economy	29900.00
0005433650454	7155	Economy	29900.00
0005433650460	7155	Economy	29900.00
0005433650425	7155	Economy	29900.00
0005433650417	7155	Economy	29900.00
0005433650424	7155	Economy	29900.00
0005433650459	7155	Economy	29900.00
0005433867967	4784	Economy	19400.00
0005433867957	4784	Economy	19400.00
0005433867955	4784	Economy	19400.00
0005433867944	4784	Economy	17600.00
0005433867950	4784	Economy	17600.00
0005433867937	4784	Economy	17600.00
0005433867931	4784	Economy	17600.00
0005433867932	4784	Economy	17600.00
0005433867963	4784	Economy	17600.00
0005433867933	4784	Economy	17600.00
0005433867945	4784	Economy	17600.00
0005433867952	4784	Economy	17600.00
0005433867951	4784	Economy	17600.00
0005433867934	4784	Economy	17600.00
0005433867969	4784	Economy	17600.00
0005433867961	4784	Economy	17600.00
0005433867941	4784	Economy	17600.00
0005433867958	4784	Economy	17600.00
0005433867935	4784	Economy	17600.00
0005433867936	4784	Economy	17600.00
0005433867962	4784	Economy	17600.00
0005433867942	4784	Economy	17600.00
0005433867943	4784	Economy	17600.00
0005433867960	4784	Economy	17600.00
0005433867964	4784	Economy	17600.00
0005433867949	4784	Economy	17600.00
0005433867954	4784	Economy	17600.00
0005433867959	4784	Economy	17600.00
0005433867953	4784	Economy	17600.00
0005433867947	4784	Economy	17600.00
0005433867940	4784	Economy	17600.00
0005433867939	4784	Economy	17600.00
0005433867938	4784	Economy	17600.00
0005433867946	4784	Economy	17600.00
0005433867948	4784	Economy	17600.00
0005433867968	4784	Economy	17600.00
0005433867965	4784	Economy	17600.00
0005433867956	4784	Economy	17600.00
0005433867966	4784	Economy	17600.00
0005433867760	32614	Economy	17600.00
0005435860445	32614	Economy	17600.00
0005433867759	32614	Economy	17600.00
0005433867758	32614	Economy	17600.00
0005435860444	32614	Economy	17600.00
0005435860443	32614	Economy	17600.00
0005435860446	32614	Economy	17600.00
0005435860447	32614	Economy	17600.00
0005434663241	3423	Economy	24800.00
0005435911323	3423	Economy	24800.00
0005434663240	3423	Economy	22600.00
0005434663239	3423	Economy	22600.00
0005434663238	3423	Economy	22600.00
0005434663236	3423	Economy	22600.00
0005434460478	3423	Economy	22600.00
0005434663237	3423	Economy	22600.00
0005434663247	3423	Economy	22600.00
0005434663244	3423	Economy	22600.00
0005434663246	3423	Economy	22600.00
0005434663248	3423	Economy	22600.00
0005434460479	3423	Economy	22600.00
0005434663235	3423	Economy	22600.00
0005434460477	3423	Economy	22600.00
0005434663242	3423	Economy	22600.00
0005434663243	3423	Economy	22600.00
0005434663245	3423	Economy	22600.00
0005435911359	12492	Economy	24800.00
0005435911354	12492	Economy	22600.00
0005435911361	12492	Economy	22600.00
0005435911358	12492	Economy	22600.00
0005435911362	12492	Economy	22600.00
0005435911357	12492	Economy	22600.00
0005435911356	12492	Economy	22600.00
0005435911355	12492	Economy	22600.00
0005435911363	12492	Economy	22600.00
0005435911360	12492	Economy	22600.00
0005435860443	14527	Economy	18500.00
0005435860445	14527	Economy	18500.00
0005435860444	14527	Economy	18500.00
0005433867759	14527	Economy	16800.00
0005435860447	14527	Economy	16800.00
0005433867758	14527	Economy	16800.00
0005433867760	14527	Economy	16800.00
0005435860446	14527	Economy	16800.00
0005433867902	32655	Economy	18500.00
0005433867920	32655	Economy	18500.00
0005433867890	32655	Economy	18500.00
0005433867927	32655	Economy	18500.00
0005433867910	32655	Economy	16800.00
0005433867918	32655	Economy	16800.00
0005433867896	32655	Economy	16800.00
0005433867891	32655	Economy	16800.00
0005433867903	32655	Economy	16800.00
0005433867892	32655	Economy	16800.00
0005433867919	32655	Economy	16800.00
0005433867923	32655	Economy	16800.00
0005433867925	32655	Economy	16800.00
0005433867916	32655	Economy	16800.00
0005433867913	32655	Economy	16800.00
0005433867905	32655	Economy	16800.00
0005433867895	32655	Economy	16800.00
0005433867904	32655	Economy	16800.00
0005433867915	32655	Economy	16800.00
0005433867894	32655	Economy	16800.00
0005433867911	32655	Economy	16800.00
0005433867921	32655	Economy	16800.00
0005433867893	32655	Economy	16800.00
0005433867907	32655	Economy	16800.00
0005433867897	32655	Economy	16800.00
0005433867914	32655	Economy	16800.00
0005433867924	32655	Economy	16800.00
0005433867900	32655	Economy	16800.00
0005433867929	32655	Economy	16800.00
0005433867930	32655	Economy	16800.00
0005433867912	32655	Economy	16800.00
0005433867909	32655	Economy	16800.00
0005433867917	32655	Economy	16800.00
0005433867898	32655	Economy	16800.00
0005433867928	32655	Economy	16800.00
0005433867926	32655	Economy	16800.00
0005433867906	32655	Economy	16800.00
0005433867922	32655	Economy	16800.00
0005433867899	32655	Economy	16800.00
0005433867901	32655	Economy	16800.00
0005433867908	32655	Economy	16800.00
0005432799094	14802	Economy	4900.00
0005432799090	14802	Economy	4900.00
0005432799087	14802	Economy	4900.00
0005432799097	14802	Economy	4900.00
0005432799089	14802	Economy	4400.00
0005432799077	14802	Economy	4400.00
0005432799079	14802	Economy	4400.00
0005432799084	14802	Economy	4400.00
0005432799070	14802	Economy	4400.00
0005432799093	14802	Economy	4400.00
0005432799080	14802	Economy	4400.00
0005432799086	14802	Economy	4400.00
0005432799075	14802	Economy	4400.00
0005432799081	14802	Economy	4400.00
0005432799071	14802	Economy	4400.00
0005432799091	14802	Economy	4400.00
0005432799074	14802	Economy	4400.00
0005432799078	14802	Economy	4400.00
0005432799092	14802	Economy	4400.00
0005432799069	14802	Economy	4400.00
0005432799076	14802	Economy	4400.00
0005432799095	14802	Economy	4400.00
0005432799072	14802	Economy	4400.00
0005432799083	14802	Economy	4400.00
0005432799096	14802	Economy	4400.00
0005432799088	14802	Economy	4400.00
0005432799082	14802	Economy	4400.00
0005432799085	14802	Economy	4400.00
0005432799073	14802	Economy	4400.00
0005434299288	7057	Business	49100.00
0005434407000	7057	Business	49100.00
0005434406981	7057	Business	49100.00
0005434407022	7057	Business	49100.00
0005434299280	7057	Business	49100.00
0005434406999	7057	Business	49100.00
0005434406967	7057	Business	49100.00
0005434407006	7057	Business	49100.00
0005434299281	7057	Business	49100.00
0005432108219	7057	Economy	16400.00
0005434406975	7057	Economy	16400.00
0005434406963	7057	Economy	16400.00
0005434407020	7057	Economy	16400.00
0005434406984	7057	Economy	16400.00
0005434299274	7057	Economy	16400.00
0005434299278	7057	Economy	16400.00
0005434407008	7057	Economy	16400.00
0005432153854	7057	Economy	16400.00
0005434406968	7057	Economy	16400.00
0005434406992	7057	Economy	16400.00
0005434407021	7057	Economy	16400.00
0005434299284	7057	Economy	16400.00
0005434299276	7057	Economy	16400.00
0005434407018	7057	Economy	16400.00
0005434406966	7057	Economy	16400.00
0005434407004	7057	Economy	16400.00
0005434406970	7057	Economy	16400.00
0005434406982	7057	Economy	16400.00
0005434406978	7057	Economy	16400.00
0005432153853	7057	Economy	16400.00
0005434299287	7057	Economy	16400.00
0005434299286	7057	Economy	16400.00
0005434406971	7057	Economy	16400.00
0005434406988	7057	Economy	16400.00
0005434407012	7057	Economy	18000.00
0005434299279	7057	Economy	18000.00
0005434406997	7057	Economy	18000.00
0005434406974	7057	Economy	18000.00
0005434299268	7057	Economy	18000.00
0005434406977	7057	Economy	16400.00
0005434406961	7057	Economy	16400.00
0005434407010	7057	Economy	16400.00
0005434406990	7057	Economy	16400.00
0005432153851	7057	Economy	16400.00
0005434406979	7057	Economy	16400.00
0005434299266	7057	Economy	16400.00
0005434299267	7057	Economy	16400.00
0005434299272	7057	Economy	16400.00
0005434406962	7057	Economy	16400.00
0005434407015	7057	Economy	16400.00
0005434406995	7057	Economy	16400.00
0005434407007	7057	Economy	16400.00
0005434407003	7057	Economy	16400.00
0005432153855	7057	Economy	16400.00
0005434406989	7057	Economy	16400.00
0005434406969	7057	Economy	16400.00
0005434406991	7057	Economy	16400.00
0005434406959	7057	Economy	16400.00
0005434407005	7057	Economy	16400.00
0005434407019	7057	Economy	16400.00
0005432153852	7057	Economy	16400.00
0005434406986	7057	Economy	16400.00
0005434299283	7057	Economy	16400.00
0005434299273	7057	Economy	16400.00
0005434299270	7057	Economy	16400.00
0005434406998	7057	Economy	16400.00
0005434299277	7057	Economy	16400.00
0005434406993	7057	Economy	16400.00
0005434407001	7057	Economy	16400.00
0005434406996	7057	Economy	16400.00
0005434406976	7057	Economy	16400.00
0005434407013	7057	Economy	16400.00
0005434299275	7057	Economy	16400.00
0005434406972	7057	Economy	16400.00
0005434406960	7057	Economy	16400.00
0005434407023	7057	Economy	16400.00
0005434407017	7057	Economy	16400.00
0005432153850	7057	Economy	16400.00
0005434299282	7057	Economy	16400.00
0005434407002	7057	Economy	16400.00
0005434406985	7057	Economy	16400.00
0005434406987	7057	Economy	16400.00
0005434299265	7057	Economy	16400.00
0005432108218	7057	Economy	16400.00
0005434299285	7057	Economy	16400.00
0005434406964	7057	Economy	16400.00
0005434299271	7057	Economy	16400.00
0005434406994	7057	Economy	16400.00
0005434407014	7057	Economy	16400.00
0005434406973	7057	Economy	16400.00
0005434299269	7057	Economy	16400.00
0005434406965	7057	Economy	16400.00
0005434406980	7057	Economy	16400.00
0005434406983	7057	Economy	16400.00
0005434407011	7057	Economy	16400.00
0005434407016	7057	Economy	16400.00
0005434407009	7057	Economy	16400.00
0005432058329	26936	Economy	16400.00
0005435310928	26936	Economy	16400.00
0005435310908	26936	Economy	16400.00
0005434299154	26936	Economy	16400.00
0005435293113	26936	Economy	16400.00
0005434299151	26936	Economy	16400.00
0005432058331	26936	Economy	16400.00
0005435293112	26936	Economy	16400.00
0005435293116	26936	Economy	16400.00
0005435293111	26936	Economy	16400.00
0005435310922	26936	Economy	16400.00
0005435293120	26936	Economy	16400.00
0005435310907	26936	Economy	16400.00
0005435310919	26936	Economy	16400.00
0005434299175	26936	Economy	16400.00
0005435310918	26936	Economy	16400.00
0005435310921	26936	Economy	16400.00
0005435310926	26936	Economy	16400.00
0005435310927	26936	Economy	18000.00
0005435293109	26936	Economy	18000.00
0005435293115	26936	Economy	16400.00
0005435293117	26936	Economy	16400.00
0005435310910	26936	Economy	16400.00
0005435293114	26936	Economy	16400.00
0005435293118	26936	Economy	16400.00
0005435310917	26936	Economy	16400.00
0005435310911	26936	Economy	16400.00
0005435310929	26936	Economy	16400.00
0005432058328	26936	Economy	16400.00
0005434406691	26936	Economy	16400.00
0005435310912	26936	Economy	16400.00
0005434406673	26936	Economy	16400.00
0005435310925	26936	Economy	16400.00
0005434406690	26936	Economy	16400.00
0005435310906	26936	Economy	16400.00
0005435293110	26936	Economy	16400.00
0005435293119	26936	Economy	16400.00
0005435310914	26936	Economy	16400.00
0005435310913	26936	Economy	16400.00
0005432058330	26936	Economy	16400.00
0005434406799	26936	Economy	16400.00
0005435310924	26936	Economy	16400.00
0005435310915	26936	Economy	16400.00
0005435310916	26936	Economy	16400.00
0005434299186	26936	Economy	16400.00
0005435310909	26936	Economy	16400.00
0005434299169	26936	Economy	16400.00
0005435310920	26936	Economy	16400.00
0005434299155	26936	Economy	16400.00
0005434299168	26936	Economy	16400.00
0005434299185	26936	Economy	16400.00
0005435310923	26936	Economy	16400.00
0005434512044	6463	Economy	16500.00
0005434512050	6463	Economy	16500.00
0005434512048	6463	Economy	16500.00
0005432603847	6463	Economy	16500.00
0005432603867	6463	Economy	15000.00
0005432603880	6463	Economy	15000.00
0005432603862	6463	Economy	15000.00
0005432603854	6463	Economy	15000.00
0005432603865	6463	Economy	15000.00
0005434512045	6463	Economy	15000.00
0005432603848	6463	Economy	15000.00
0005432603856	6463	Economy	15000.00
0005432603860	6463	Economy	15000.00
0005432603863	6463	Economy	15000.00
0005432603846	6463	Economy	15000.00
0005432603877	6463	Economy	15000.00
0005432603881	6463	Economy	15000.00
0005432603875	6463	Economy	15000.00
0005432603844	6463	Economy	15000.00
0005434512051	6463	Economy	15000.00
0005432603858	6463	Economy	15000.00
0005432603878	6463	Economy	15000.00
0005432603845	6463	Economy	15000.00
0005432603850	6463	Economy	15000.00
0005432603853	6463	Economy	15000.00
0005432603849	6463	Economy	15000.00
0005432603876	6463	Economy	15000.00
0005432603861	6463	Economy	15000.00
0005432603882	6463	Economy	15000.00
0005432603879	6463	Economy	15000.00
0005432603884	6463	Economy	15000.00
0005432603874	6463	Economy	15000.00
0005432603852	6463	Economy	15000.00
0005434512049	6463	Economy	15000.00
0005432603872	6463	Economy	15000.00
0005432603883	6463	Economy	15000.00
0005432603870	6463	Economy	15000.00
0005434512046	6463	Economy	15000.00
0005432603869	6463	Economy	15000.00
0005432603864	6463	Economy	15000.00
0005432603851	6463	Economy	15000.00
0005432603866	6463	Economy	15000.00
0005432603873	6463	Economy	15000.00
0005432603855	6463	Economy	15000.00
0005432603859	6463	Economy	15000.00
0005432603871	6463	Economy	15000.00
0005432603868	6463	Economy	15000.00
0005432603857	6463	Economy	15000.00
0005434512047	6463	Economy	15000.00
0005435221041	21362	Economy	15000.00
0005435221043	21362	Economy	15000.00
0005432603657	21362	Economy	15000.00
0005432603676	21362	Economy	15000.00
0005435221503	21362	Economy	15000.00
0005435221042	21362	Economy	15000.00
0005432603675	21362	Economy	15000.00
0005433251108	14973	Business	18900.00
0005433251098	14973	Business	18900.00
0005433251095	14973	Business	18900.00
0005433251115	14973	Business	18900.00
0005433251109	14973	Business	18900.00
0005433251116	14973	Economy	6300.00
0005433251099	14973	Economy	6300.00
0005433251093	14973	Economy	6300.00
0005433251111	14973	Economy	6900.00
0005433251088	14973	Economy	6300.00
0005433251090	14973	Economy	6300.00
0005433251086	14973	Economy	6300.00
0005433251091	14973	Economy	6300.00
0005433251110	14973	Economy	6300.00
0005433251106	14973	Economy	6300.00
0005433251089	14973	Economy	6300.00
0005433251087	14973	Economy	6300.00
0005433251101	14973	Economy	6300.00
0005433251112	14973	Economy	6300.00
0005433251085	14973	Economy	6300.00
0005433251103	14973	Economy	6300.00
0005433251107	14973	Economy	6300.00
0005433251104	14973	Economy	6300.00
0005433251117	14973	Economy	6300.00
0005433251097	14973	Economy	6300.00
0005433251096	14973	Economy	6300.00
0005433251105	14973	Economy	6300.00
0005433251113	14973	Economy	6300.00
0005433251102	14973	Economy	6300.00
0005433251094	14973	Economy	6300.00
0005433251092	14973	Economy	6300.00
0005433251114	14973	Economy	6300.00
0005433251100	14973	Economy	6300.00
0005434906574	25836	Business	18900.00
0005434906596	25836	Business	18900.00
0005434906588	25836	Business	18900.00
0005434906579	25836	Business	18900.00
0005434906624	25836	Business	18900.00
0005434906595	25836	Business	18900.00
0005434906631	25836	Business	18900.00
0005434906615	25836	Business	18900.00
0005434906572	25836	Economy	6300.00
0005434906616	25836	Economy	6300.00
0005434906609	25836	Economy	6300.00
0005434906590	25836	Economy	6300.00
0005434906617	25836	Economy	6900.00
0005434906580	25836	Economy	6900.00
0005434906612	25836	Economy	6300.00
0005434906600	25836	Economy	6300.00
0005434906584	25836	Economy	6300.00
0005434906608	25836	Economy	6300.00
0005434906598	25836	Economy	6300.00
0005434906605	25836	Economy	6300.00
0005434906587	25836	Economy	6300.00
0005434906628	25836	Economy	6300.00
0005433250982	25836	Economy	6300.00
0005434906592	25836	Economy	6300.00
0005434906630	25836	Economy	6300.00
0005434906575	25836	Economy	6300.00
0005434906618	25836	Economy	6300.00
0005434906576	25836	Economy	6300.00
0005434906594	25836	Economy	6300.00
0005434906627	25836	Economy	6300.00
0005434906573	25836	Economy	6300.00
0005434906581	25836	Economy	6300.00
0005434906593	25836	Economy	6300.00
0005434906614	25836	Economy	6300.00
0005434906613	25836	Economy	6300.00
0005434906632	25836	Economy	6300.00
0005434906606	25836	Economy	6300.00
0005434906607	25836	Economy	6300.00
0005434906633	25836	Economy	6300.00
0005434906629	25836	Economy	6300.00
0005434906583	25836	Economy	6300.00
0005434906601	25836	Economy	6300.00
0005434906622	25836	Economy	6300.00
0005434906599	25836	Economy	6300.00
0005434906582	25836	Economy	6300.00
0005434906585	25836	Economy	6300.00
0005434906602	25836	Economy	6300.00
0005434906578	25836	Economy	6300.00
0005434906619	25836	Economy	6300.00
0005434906610	25836	Economy	6300.00
0005434906621	25836	Economy	6300.00
0005434906604	25836	Economy	6300.00
0005434906577	25836	Economy	6300.00
0005434906586	25836	Economy	6300.00
0005434906620	25836	Economy	6300.00
0005434906589	25836	Economy	6300.00
0005434906626	25836	Economy	6300.00
0005434906597	25836	Economy	6300.00
0005434906603	25836	Economy	6300.00
0005434906591	25836	Economy	6300.00
0005434906611	25836	Economy	6300.00
0005434906625	25836	Economy	6300.00
0005434906623	25836	Economy	6300.00
0005433008060	14183	Business	52300.00
0005433008073	14183	Business	52300.00
0005433008067	14183	Business	52300.00
0005433008088	14183	Business	52300.00
0005433008092	14183	Economy	17400.00
0005433008059	14183	Economy	17400.00
0005433008065	14183	Economy	17400.00
0005433008080	14183	Economy	17400.00
0005433008086	14183	Economy	19200.00
0005433008093	14183	Economy	19200.00
0005433008089	14183	Economy	19200.00
0005433008099	14183	Economy	17400.00
0005433008085	14183	Economy	17400.00
0005433008087	14183	Economy	17400.00
0005433008084	14183	Economy	17400.00
0005433008063	14183	Economy	17400.00
0005433008095	14183	Economy	17400.00
0005433008066	14183	Economy	17400.00
0005433008069	14183	Economy	17400.00
0005433008064	14183	Economy	17400.00
0005433008090	14183	Economy	17400.00
0005433008076	14183	Economy	17400.00
0005433008097	14183	Economy	17400.00
0005433008071	14183	Economy	17400.00
0005433008075	14183	Economy	17400.00
0005433008094	14183	Economy	17400.00
0005433008078	14183	Economy	17400.00
0005433008057	14183	Economy	17400.00
0005433008083	14183	Economy	17400.00
0005433008091	14183	Economy	17400.00
0005433008096	14183	Economy	17400.00
0005433008056	14183	Economy	17400.00
0005433008072	14183	Economy	17400.00
0005433008058	14183	Economy	17400.00
0005433008098	14183	Economy	17400.00
0005433008055	14183	Economy	17400.00
0005433008079	14183	Economy	17400.00
0005433008081	14183	Economy	17400.00
0005433008070	14183	Economy	17400.00
0005433008068	14183	Economy	17400.00
0005433008082	14183	Economy	17400.00
0005433008077	14183	Economy	17400.00
0005433008062	14183	Economy	17400.00
0005433008061	14183	Economy	17400.00
0005433008074	14183	Economy	17400.00
0005433007854	22818	Business	52300.00
0005433007852	22818	Economy	17400.00
0005434925367	20551	Business	22900.00
0005434925368	20551	Business	22900.00
0005434925370	20551	Business	22900.00
0005434925396	20551	Business	22900.00
0005434925369	20551	Economy	7600.00
0005434925385	20551	Economy	7600.00
0005434925383	20551	Economy	7600.00
0005434925391	20551	Economy	7600.00
0005434925371	20551	Economy	8400.00
0005434925376	20551	Economy	7600.00
0005434925386	20551	Economy	7600.00
0005434925375	20551	Economy	7600.00
0005434925365	20551	Economy	7600.00
0005434925387	20551	Economy	7600.00
0005434925382	20551	Economy	7600.00
0005434925389	20551	Economy	7600.00
0005434925381	20551	Economy	7600.00
0005434925378	20551	Economy	7600.00
0005434925392	20551	Economy	7600.00
0005434925380	20551	Economy	7600.00
0005434925390	20551	Economy	7600.00
0005434925379	20551	Economy	7600.00
0005434925374	20551	Economy	7600.00
0005434925388	20551	Economy	7600.00
0005434925373	20551	Economy	7600.00
0005434925377	20551	Economy	7600.00
0005434925372	20551	Economy	7600.00
0005434925395	20551	Economy	7600.00
0005434925384	20551	Economy	7600.00
0005434925366	20551	Economy	7600.00
0005434925393	20551	Economy	7600.00
0005434925394	20551	Economy	7600.00
0005435487577	15804	Economy	8900.00
0005435487576	15804	Economy	8900.00
0005435487572	15804	Economy	8100.00
0005435487584	15804	Economy	8100.00
0005435487583	15804	Economy	8100.00
0005435487565	15804	Economy	8100.00
0005435487579	15804	Economy	8100.00
0005435487566	15804	Economy	8100.00
0005435487567	15804	Economy	8100.00
0005435487573	15804	Economy	8100.00
0005435487578	15804	Economy	8100.00
0005435487582	15804	Economy	8100.00
0005435487574	15804	Economy	8100.00
0005435487568	15804	Economy	8100.00
0005435487585	15804	Economy	8100.00
0005435487569	15804	Economy	8100.00
0005435487575	15804	Economy	8100.00
0005435487581	15804	Economy	8100.00
0005435487571	15804	Economy	8100.00
0005435487570	15804	Economy	8100.00
0005435487564	15804	Economy	8100.00
0005435487580	15804	Economy	8100.00
0005435999020	19707	Economy	8900.00
0005435999031	19707	Economy	8900.00
0005435999024	19707	Economy	8900.00
0005435999032	19707	Economy	8100.00
0005435999029	19707	Economy	8100.00
0005435999016	19707	Economy	8100.00
0005435999026	19707	Economy	8100.00
0005435999033	19707	Economy	8100.00
0005435999025	19707	Economy	8100.00
0005435999028	19707	Economy	8100.00
0005435999027	19707	Economy	8100.00
0005435999019	19707	Economy	8100.00
0005435999014	19707	Economy	8100.00
0005435999017	19707	Economy	8100.00
0005435999013	19707	Economy	8100.00
0005435999034	19707	Economy	8100.00
0005435999021	19707	Economy	8100.00
0005435999015	19707	Economy	8100.00
0005435999022	19707	Economy	8100.00
0005435999030	19707	Economy	8100.00
0005435999018	19707	Economy	8100.00
0005435999023	19707	Economy	8100.00
0005435839105	6005	Business	199300.00
0005435839124	6005	Business	199300.00
0005432660794	6005	Business	199300.00
0005435839111	6005	Business	199300.00
0005435839128	6005	Business	199300.00
0005435839118	6005	Business	199300.00
0005435839103	6005	Business	199300.00
0005435839129	6005	Economy	66400.00
0005432659682	6005	Economy	66400.00
0005435839116	6005	Economy	66400.00
0005435839125	6005	Economy	66400.00
0005432659683	6005	Economy	66400.00
0005435839104	6005	Economy	66400.00
0005435472518	6005	Economy	66400.00
0005432142215	6005	Economy	66400.00
0005435839107	6005	Economy	66400.00
0005432142213	6005	Economy	66400.00
0005435839119	6005	Economy	66400.00
0005435839130	6005	Economy	66400.00
0005435839120	6005	Economy	66400.00
0005432660793	6005	Economy	66400.00
0005435839122	6005	Economy	66400.00
0005435472517	6005	Economy	66400.00
0005432142214	6005	Economy	66400.00
0005435839123	6005	Economy	66400.00
0005435839106	6005	Economy	66400.00
0005435839127	6005	Economy	66400.00
0005435839109	6005	Economy	66400.00
0005435839113	6005	Economy	66400.00
0005435839110	6005	Economy	66400.00
0005435839108	6005	Economy	66400.00
0005435839115	6005	Economy	66400.00
0005435839112	6005	Economy	66400.00
0005435839102	6005	Economy	66400.00
0005432658567	6005	Economy	66400.00
0005435839114	6005	Economy	66400.00
0005435839121	6005	Economy	66400.00
0005435839126	6005	Economy	66400.00
0005435839117	6005	Economy	66400.00
0005435472609	18088	Business	199300.00
0005432537034	18088	Business	199300.00
0005432537033	18088	Business	199300.00
0005432537032	18088	Business	199300.00
0005435472603	18088	Business	199300.00
0005435472606	18088	Economy	66400.00
0005435472607	18088	Economy	66400.00
0005435472604	18088	Economy	66400.00
0005432537035	18088	Economy	66400.00
0005435472602	18088	Economy	73100.00
0005435472611	18088	Economy	66400.00
0005435838981	18088	Economy	66400.00
0005435472598	18088	Economy	66400.00
0005435472601	18088	Economy	66400.00
0005435472605	18088	Economy	66400.00
0005435472610	18088	Economy	66400.00
0005435472600	18088	Economy	66400.00
0005435472597	18088	Economy	66400.00
0005435472599	18088	Economy	66400.00
0005435472612	18088	Economy	66400.00
0005435472596	18088	Economy	66400.00
0005435472608	18088	Economy	66400.00
0005435103830	23037	Business	15700.00
0005435103829	23037	Economy	5200.00
0005435103834	23037	Economy	5200.00
0005435103837	23037	Economy	5200.00
0005435103831	23037	Economy	5700.00
0005435103833	23037	Economy	5200.00
0005435103835	23037	Economy	5200.00
0005435103828	23037	Economy	5200.00
0005435103836	23037	Economy	5200.00
0005435103832	23037	Economy	5200.00
0005433284921	32046	Business	15700.00
0005433284935	32046	Business	15700.00
0005433284939	32046	Business	15700.00
0005433284923	32046	Economy	5200.00
0005433284924	32046	Economy	5200.00
0005433284930	32046	Economy	5200.00
0005433284934	32046	Economy	5200.00
0005433284942	32046	Economy	5200.00
0005433284936	32046	Economy	5200.00
0005433284933	32046	Economy	5200.00
0005433284919	32046	Economy	5200.00
0005433284931	32046	Economy	5200.00
0005433284928	32046	Economy	5200.00
0005433284938	32046	Economy	5700.00
0005433284932	32046	Economy	5700.00
0005433284922	32046	Economy	5200.00
0005433284918	32046	Economy	5200.00
0005433284927	32046	Economy	5200.00
0005433284940	32046	Economy	5200.00
0005433284913	32046	Economy	5200.00
0005433284929	32046	Economy	5200.00
0005433284937	32046	Economy	5200.00
0005433284912	32046	Economy	5200.00
0005433284915	32046	Economy	5200.00
0005433284916	32046	Economy	5200.00
0005433284917	32046	Economy	5200.00
0005433284925	32046	Economy	5200.00
0005433284911	32046	Economy	5200.00
0005433284941	32046	Economy	5200.00
0005433284920	32046	Economy	5200.00
0005433284926	32046	Economy	5200.00
0005433284914	32046	Economy	5200.00
0005435852542	23877	Economy	12300.00
0005435852540	23877	Economy	12300.00
0005435852541	23877	Economy	12300.00
0005433475640	23877	Economy	12300.00
0005435852543	23877	Economy	12300.00
0005432525730	30580	Business	42100.00
0005435212766	30580	Business	42100.00
0005432525767	30580	Business	42100.00
0005435212747	30580	Business	42100.00
0005432211413	30580	Business	42100.00
0005432525865	30580	Business	42100.00
0005435212759	30580	Business	42100.00
0005435212788	30580	Business	42100.00
0005432159805	30580	Business	42100.00
0005434066305	30580	Business	42100.00
0005432211415	30580	Comfort	23900.00
0005435212793	30580	Comfort	23900.00
0005432525993	30580	Comfort	23900.00
0005432211418	30580	Comfort	23900.00
0005432525748	30580	Comfort	23900.00
0005435212776	30580	Comfort	23900.00
0005432525747	30580	Comfort	23900.00
0005432211416	30580	Comfort	23900.00
0005435725542	30580	Comfort	23900.00
0005432525795	30580	Comfort	23900.00
0005435212790	30580	Comfort	23900.00
0005435212801	30580	Comfort	23900.00
0005435212748	30580	Comfort	23900.00
0005432211417	30580	Comfort	23900.00
0005435212813	30580	Comfort	23900.00
0005433656634	30580	Comfort	23900.00
0005435212746	30580	Comfort	23900.00
0005432526270	30580	Economy	14000.00
0005435212789	30580	Economy	14000.00
0005432525678	30580	Economy	14000.00
0005434066510	30580	Economy	14000.00
0005435212785	30580	Economy	14000.00
0005435212782	30580	Economy	14000.00
0005435630933	30580	Economy	14000.00
0005432525817	30580	Economy	14000.00
0005435212770	30580	Economy	14000.00
0005432525644	30580	Economy	14000.00
0005435212750	30580	Economy	14000.00
0005435212805	30580	Economy	14000.00
0005433656633	30580	Economy	14000.00
0005435212799	30580	Economy	14000.00
0005435212806	30580	Economy	14000.00
0005434066351	30580	Economy	14000.00
0005435212795	30580	Economy	14000.00
0005435212775	30580	Economy	14000.00
0005435725545	30580	Economy	14000.00
0005435212768	30580	Economy	14000.00
0005435212798	30580	Economy	14000.00
0005435212763	30580	Economy	14000.00
0005435212808	30580	Economy	14000.00
0005435212794	30580	Economy	15400.00
0005432525687	30580	Economy	15400.00
0005435212797	30580	Economy	14000.00
0005432525732	30580	Economy	15400.00
0005432525723	30580	Economy	15400.00
0005435212769	30580	Economy	15400.00
0005435212762	30580	Economy	14000.00
0005432525893	30580	Economy	14000.00
0005432211412	30580	Economy	14000.00
0005434066350	30580	Economy	14000.00
0005432526136	30580	Economy	14000.00
0005435212786	30580	Economy	14000.00
0005434066331	30580	Economy	14000.00
0005435212783	30580	Economy	14000.00
0005435212753	30580	Economy	14000.00
0005435212754	30580	Economy	14000.00
0005435212796	30580	Economy	14000.00
0005435212804	30580	Economy	14000.00
0005435212764	30580	Economy	14000.00
0005435212767	30580	Economy	14000.00
0005435212779	30580	Economy	14000.00
0005435212760	30580	Economy	14000.00
0005435212802	30580	Economy	14000.00
0005435212780	30580	Economy	14000.00
0005435212800	30580	Economy	14000.00
0005432159803	30580	Economy	14000.00
0005435212784	30580	Economy	14000.00
0005435212771	30580	Economy	14000.00
0005432525939	30580	Economy	14000.00
0005432525645	30580	Economy	14000.00
0005435212777	30580	Economy	14000.00
0005435212773	30580	Economy	14000.00
0005435212757	30580	Economy	14000.00
0005435725544	30580	Economy	14000.00
0005435725546	30580	Economy	14000.00
0005432525757	30580	Economy	14000.00
0005435212765	30580	Economy	14000.00
0005432525724	30580	Economy	14000.00
0005435212756	30580	Economy	14000.00
0005435630934	30580	Economy	14000.00
0005435212749	30580	Economy	14000.00
0005434066304	30580	Economy	14000.00
0005435212755	30580	Economy	14000.00
0005432159806	30580	Economy	14000.00
0005435212745	30580	Economy	14000.00
0005435212807	30580	Economy	14000.00
0005432159804	30580	Economy	14000.00
0005432525634	30580	Economy	14000.00
0005435212791	30580	Economy	14000.00
0005435212803	30580	Economy	14000.00
0005432211414	30580	Economy	14000.00
0005435212812	30580	Economy	14000.00
0005435212809	30580	Economy	14000.00
0005432525679	30580	Economy	14000.00
0005435212761	30580	Economy	14000.00
0005434066384	30580	Economy	14000.00
0005435212772	30580	Economy	14000.00
0005435212774	30580	Economy	14000.00
0005435212810	30580	Economy	14000.00
0005435212781	30580	Economy	14000.00
0005435212758	30580	Economy	14000.00
0005432525649	30580	Economy	14000.00
0005435212752	30580	Economy	14000.00
0005435212778	30580	Economy	14000.00
0005435212787	30580	Economy	14000.00
0005432525894	30580	Economy	14000.00
0005435212744	30580	Economy	14000.00
0005432525933	30580	Economy	14000.00
0005435212811	30580	Economy	14000.00
0005432525759	30580	Economy	14000.00
0005432525731	30580	Economy	14000.00
0005432525766	30580	Economy	14000.00
0005435725543	30580	Economy	14000.00
0005435212792	30580	Economy	14000.00
0005435212751	30580	Economy	14000.00
0005433367463	24837	Business	9800.00
0005433367462	24837	Business	9800.00
0005433367465	24837	Business	9800.00
0005433367483	24837	Business	9800.00
0005433367470	24837	Business	9800.00
0005433367459	24837	Business	9800.00
0005433367474	24837	Business	9800.00
0005433367453	24837	Economy	3300.00
0005433367469	24837	Economy	3300.00
0005433367479	24837	Economy	3300.00
0005433367481	24837	Economy	3300.00
0005433367480	24837	Economy	3300.00
0005433367486	24837	Economy	3300.00
0005433367477	24837	Economy	3300.00
0005433367461	24837	Economy	3300.00
0005433367467	24837	Economy	3300.00
0005433367455	24837	Economy	3300.00
0005433367482	24837	Economy	3300.00
0005433367478	24837	Economy	3300.00
0005433367473	24837	Economy	3300.00
0005433367460	24837	Economy	3300.00
0005433367476	24837	Economy	3300.00
0005433367485	24837	Economy	3300.00
0005433367475	24837	Economy	3300.00
0005433367471	24837	Economy	3300.00
0005433367468	24837	Economy	3300.00
0005433367484	24837	Economy	3300.00
0005433367454	24837	Economy	3300.00
0005433367456	24837	Economy	3300.00
0005433367464	24837	Economy	3300.00
0005433367472	24837	Economy	3300.00
0005433367458	24837	Economy	3300.00
0005433367466	24837	Economy	3300.00
0005433367457	24837	Economy	3300.00
0005435949748	6596	Economy	18700.00
0005435949745	6596	Economy	18700.00
0005435949749	6596	Economy	18700.00
0005435949744	6596	Economy	18700.00
0005435949750	6596	Economy	18700.00
0005435949751	6596	Economy	18700.00
0005435949747	6596	Economy	18700.00
0005435949746	6596	Economy	18700.00
0005435949743	6596	Economy	18700.00
0005434979439	2064	Economy	10500.00
0005434979443	2064	Economy	10500.00
0005434979463	2064	Economy	10500.00
0005434979446	2064	Economy	9500.00
0005434979462	2064	Economy	9500.00
0005434979466	2064	Economy	9500.00
0005434979447	2064	Economy	9500.00
0005434979437	2064	Economy	9500.00
0005434979445	2064	Economy	9500.00
0005434979452	2064	Economy	9500.00
0005435801663	2064	Economy	9500.00
0005434979457	2064	Economy	9500.00
0005434979440	2064	Economy	9500.00
0005434979451	2064	Economy	9500.00
0005435801662	2064	Economy	9500.00
0005434979464	2064	Economy	9500.00
0005434979460	2064	Economy	9500.00
0005434979459	2064	Economy	9500.00
0005434979455	2064	Economy	9500.00
0005435801661	2064	Economy	9500.00
0005434979456	2064	Economy	9500.00
0005434979449	2064	Economy	9500.00
0005434979461	2064	Economy	9500.00
0005434979442	2064	Economy	9500.00
0005434979458	2064	Economy	9500.00
0005434979453	2064	Economy	9500.00
0005434979465	2064	Economy	9500.00
0005434979438	2064	Economy	9500.00
0005434979448	2064	Economy	9500.00
0005434979454	2064	Economy	9500.00
0005434979444	2064	Economy	9500.00
0005434979450	2064	Economy	9500.00
0005434979441	2064	Economy	9500.00
0005434979259	23538	Economy	9500.00
0005434979285	23538	Economy	9500.00
0005434979273	23538	Economy	9500.00
0005434979272	23538	Economy	9500.00
0005434979258	23538	Economy	9500.00
0005434979286	23538	Economy	9500.00
0005434952487	2643	Economy	5300.00
0005434952489	2643	Economy	5300.00
0005434952490	2643	Economy	5300.00
0005434952488	2643	Economy	5300.00
0005434952491	2643	Economy	5300.00
0005433256398	28210	Economy	5300.00
0005434952469	28210	Economy	5300.00
0005433256397	28210	Economy	5300.00
0005434952468	28210	Economy	5300.00
0005433256395	28210	Economy	5300.00
0005433256396	28210	Economy	5300.00
0005433111482	19820	Economy	8700.00
0005433112360	19820	Economy	8700.00
0005433111481	19820	Economy	8700.00
0005433112361	19820	Economy	8700.00
0005434136722	11940	Economy	3200.00
0005434136738	11940	Economy	3200.00
0005434136739	11940	Economy	3200.00
0005434136680	11940	Economy	3200.00
0005434136719	11940	Economy	3200.00
0005434137108	28733	Business	9700.00
0005434137169	28733	Business	9700.00
0005434137126	28733	Business	9700.00
0005434137137	28733	Business	9700.00
0005434137148	28733	Business	9700.00
0005434137170	28733	Business	9700.00
0005434137171	28733	Economy	3200.00
0005434137132	28733	Economy	3200.00
0005434137158	28733	Economy	3200.00
0005434137142	28733	Economy	3200.00
0005434137127	28733	Economy	3200.00
0005434137113	28733	Economy	3500.00
0005434137164	28733	Economy	3500.00
0005434137143	28733	Economy	3500.00
0005434137149	28733	Economy	3500.00
0005434137119	28733	Economy	3500.00
0005434137163	28733	Economy	3200.00
0005434137123	28733	Economy	3200.00
0005434137141	28733	Economy	3200.00
0005434137168	28733	Economy	3200.00
0005434137146	28733	Economy	3200.00
0005434137125	28733	Economy	3200.00
0005434137122	28733	Economy	3200.00
0005434137175	28733	Economy	3200.00
0005434137130	28733	Economy	3200.00
0005434137161	28733	Economy	3200.00
0005434137138	28733	Economy	3200.00
0005434137131	28733	Economy	3200.00
0005434137155	28733	Economy	3200.00
0005434137165	28733	Economy	3200.00
0005434137139	28733	Economy	3200.00
0005434137157	28733	Economy	3200.00
0005434137128	28733	Economy	3200.00
0005434137134	28733	Economy	3200.00
0005434137172	28733	Economy	3200.00
0005434137106	28733	Economy	3200.00
0005434137116	28733	Economy	3200.00
0005434137154	28733	Economy	3200.00
0005434137152	28733	Economy	3200.00
0005434137117	28733	Economy	3200.00
0005434137136	28733	Economy	3200.00
0005434137103	28733	Economy	3200.00
0005434137133	28733	Economy	3200.00
0005434137115	28733	Economy	3200.00
0005434137109	28733	Economy	3200.00
0005434137160	28733	Economy	3200.00
0005434137120	28733	Economy	3200.00
0005434137144	28733	Economy	3200.00
0005434137162	28733	Economy	3200.00
0005434137173	28733	Economy	3200.00
0005434137112	28733	Economy	3200.00
0005434137111	28733	Economy	3200.00
0005434137102	28733	Economy	3200.00
0005434137110	28733	Economy	3200.00
0005434137105	28733	Economy	3200.00
0005434137150	28733	Economy	3200.00
0005434137151	28733	Economy	3200.00
0005434137159	28733	Economy	3200.00
0005434137156	28733	Economy	3200.00
0005434137174	28733	Economy	3200.00
0005434137153	28733	Economy	3200.00
0005434137147	28733	Economy	3200.00
0005434137118	28733	Economy	3200.00
0005434137140	28733	Economy	3200.00
0005434137121	28733	Economy	3200.00
0005434137167	28733	Economy	3200.00
0005434137145	28733	Economy	3200.00
0005434137124	28733	Economy	3200.00
0005434137114	28733	Economy	3200.00
0005434137104	28733	Economy	3200.00
0005434137107	28733	Economy	3200.00
0005434137135	28733	Economy	3200.00
0005434137129	28733	Economy	3200.00
0005434137101	28733	Economy	3200.00
0005434137166	28733	Economy	3200.00
0005434466402	6583	Economy	20900.00
0005434466398	6583	Economy	20900.00
0005434466403	6583	Economy	20900.00
0005434466408	6583	Economy	20900.00
0005434466407	6583	Economy	20900.00
0005434466401	6583	Economy	20900.00
0005434466404	6583	Economy	20900.00
0005434466400	6583	Economy	20900.00
0005434466399	6583	Economy	20900.00
0005434466406	6583	Economy	20900.00
0005434466405	6583	Economy	20900.00
0005433538770	6770	Economy	10900.00
0005433534473	6770	Economy	9900.00
0005433538772	6770	Economy	9900.00
0005433538774	6770	Economy	9900.00
0005433538776	6770	Economy	9900.00
0005433538769	6770	Economy	9900.00
0005433538777	6770	Economy	9900.00
0005433538773	6770	Economy	9900.00
0005433534474	6770	Economy	9900.00
0005433538775	6770	Economy	9900.00
0005433538771	6770	Economy	9900.00
0005435259708	25046	Economy	9900.00
0005435259707	25046	Economy	9900.00
0005435259706	25046	Economy	9900.00
0005433511857	798	Economy	14600.00
0005433511852	798	Economy	14600.00
0005433511858	798	Economy	14600.00
0005433511854	798	Economy	14600.00
0005433511853	798	Economy	14600.00
0005433511856	798	Economy	14600.00
0005433511855	798	Economy	14600.00
0005433511859	798	Economy	14600.00
0005433511860	798	Economy	14600.00
0005432922480	16145	Economy	14600.00
0005432922479	16145	Economy	14600.00
0005433511821	16145	Economy	14600.00
0005433511801	16145	Economy	14600.00
0005433511822	16145	Economy	14600.00
0005433511820	16145	Economy	14600.00
0005432922477	16145	Economy	14600.00
0005432922478	16145	Economy	14600.00
0005435916118	3673	Economy	7900.00
0005435697022	3673	Economy	7900.00
0005435697036	3673	Economy	7900.00
0005435697025	3673	Economy	7200.00
0005435697016	3673	Economy	7200.00
0005435697026	3673	Economy	7200.00
0005435697041	3673	Economy	7200.00
0005435697020	3673	Economy	7200.00
0005435697034	3673	Economy	7200.00
0005435697043	3673	Economy	7200.00
0005435697023	3673	Economy	7200.00
0005435697032	3673	Economy	7200.00
0005435697029	3673	Economy	7200.00
0005435916119	3673	Economy	7200.00
0005435697017	3673	Economy	7200.00
0005435697033	3673	Economy	7200.00
0005435697015	3673	Economy	7200.00
0005434950480	3673	Economy	7200.00
0005435697027	3673	Economy	7200.00
0005435697024	3673	Economy	7200.00
0005435697035	3673	Economy	7200.00
0005435697018	3673	Economy	7200.00
0005435697037	3673	Economy	7200.00
0005434950478	3673	Economy	7200.00
0005435697038	3673	Economy	7200.00
0005435697039	3673	Economy	7200.00
0005434950479	3673	Economy	7200.00
0005435697042	3673	Economy	7200.00
0005435697021	3673	Economy	7200.00
0005434950477	3673	Economy	7200.00
0005435934997	3673	Economy	7200.00
0005435697030	3673	Economy	7200.00
0005435697028	3673	Economy	7200.00
0005435697031	3673	Economy	7200.00
0005435697040	3673	Economy	7200.00
0005435697019	3673	Economy	7200.00
0005435696847	16291	Economy	7200.00
0005435935010	16291	Economy	7200.00
0005434950457	16291	Economy	7200.00
0005434950458	16291	Economy	7200.00
0005435935009	16291	Economy	7200.00
0005435916137	16291	Economy	7200.00
0005435916136	16291	Economy	7200.00
0005435696866	16291	Economy	7200.00
0005435935008	16291	Economy	7200.00
0005435935011	16291	Economy	7200.00
0005434606786	3947	Economy	21300.00
0005434604862	3947	Economy	21300.00
0005433519406	3947	Economy	19300.00
0005432609685	3947	Economy	19300.00
0005432607518	3947	Economy	19300.00
0005434604859	3947	Economy	19300.00
0005434604860	3947	Economy	19300.00
0005434606787	3947	Economy	19300.00
0005433519407	3947	Economy	19300.00
0005434606788	3947	Economy	19300.00
0005432609687	3947	Economy	19300.00
0005432609686	3947	Economy	19300.00
0005432609684	3947	Economy	19300.00
0005432607519	3947	Economy	19300.00
0005432607522	3947	Economy	19300.00
0005432609688	3947	Economy	19300.00
0005432607520	3947	Economy	19300.00
0005433519405	3947	Economy	19300.00
0005433519408	3947	Economy	19300.00
0005434606785	3947	Economy	19300.00
0005433519404	3947	Economy	19300.00
0005434604861	3947	Economy	19300.00
0005432607521	3947	Economy	19300.00
0005435853588	22062	Economy	19300.00
0005435853589	22062	Economy	19300.00
0005435853590	22062	Economy	19300.00
0005435904889	22062	Economy	19300.00
0005433348901	733	Economy	3700.00
0005435628691	733	Economy	3700.00
0005435628690	733	Economy	3700.00
0005433348926	15979	Economy	3700.00
0005433348927	15979	Economy	3700.00
0005433348924	15979	Economy	3700.00
0005433348922	15979	Economy	3700.00
0005433348923	15979	Economy	3700.00
0005433348925	15979	Economy	3700.00
0005434446491	17175	Economy	7100.00
0005434445218	17175	Economy	7100.00
0005434445219	17175	Economy	7100.00
0005434445217	17175	Economy	7100.00
0005434445220	17175	Economy	7100.00
0005433159289	17607	Economy	7100.00
0005434445210	17607	Economy	7100.00
0005435132762	7863	Economy	5900.00
0005435132769	7863	Economy	5400.00
0005435132765	7863	Economy	5400.00
0005435132768	7863	Economy	5400.00
0005435132767	7863	Economy	5400.00
0005435132764	7863	Economy	5400.00
0005435383060	7863	Economy	5400.00
0005435132759	7863	Economy	5400.00
0005435132761	7863	Economy	5400.00
0005435132766	7863	Economy	5400.00
0005435132760	7863	Economy	5400.00
0005435132763	7863	Economy	5400.00
0005435383092	33096	Economy	5400.00
0005435383090	33096	Economy	5400.00
0005435383089	33096	Economy	5400.00
0005435383091	33096	Economy	5400.00
0005435383088	33096	Economy	5400.00
0005435811014	4412	Business	133200.00
0005435811017	4412	Business	133200.00
0005435811018	4412	Business	133200.00
0005435811011	4412	Economy	44400.00
0005435811015	4412	Economy	44400.00
0005435811013	4412	Economy	44400.00
0005435811019	4412	Economy	44400.00
0005435811020	4412	Economy	44400.00
0005435811021	4412	Economy	44400.00
0005435811012	4412	Economy	44400.00
0005435811016	4412	Economy	44400.00
0005435938854	29433	Economy	44400.00
0005435938856	29433	Economy	44400.00
0005435810990	29433	Economy	48800.00
0005435938855	29433	Economy	44400.00
0005435938859	29433	Economy	44400.00
0005435938858	29433	Economy	44400.00
0005435938857	29433	Economy	44400.00
0005435390126	7501	Economy	13800.00
0005435160174	7501	Economy	13800.00
0005435160181	7501	Economy	12500.00
0005435160175	7501	Economy	12500.00
0005435160179	7501	Economy	12500.00
0005435160182	7501	Economy	12500.00
0005435160176	7501	Economy	12500.00
0005435160177	7501	Economy	12500.00
0005435160180	7501	Economy	12500.00
0005435160172	7501	Economy	12500.00
0005435160178	7501	Economy	12500.00
0005435160173	7501	Economy	12500.00
0005435390127	7501	Economy	12500.00
0005435390162	29540	Economy	12500.00
0005435390160	29540	Economy	12500.00
0005435390164	29540	Economy	12500.00
0005435390166	29540	Economy	12500.00
0005435390161	29540	Economy	12500.00
0005435390163	29540	Economy	12500.00
0005435390165	29540	Economy	12500.00
0005432394035	18451	Economy	4900.00
0005432394036	18451	Economy	4900.00
0005432400078	27175	Economy	4900.00
0005432398149	27175	Economy	4900.00
0005432400077	27175	Economy	4900.00
0005432400080	27175	Economy	4900.00
0005432400079	27175	Economy	4900.00
0005432398150	27175	Economy	4900.00
0005432398151	27175	Economy	4900.00
0005432400081	27175	Economy	4900.00
0005432639003	2255	Business	87300.00
0005432638991	2255	Business	87300.00
0005432639000	2255	Business	87300.00
0005432638998	2255	Business	87300.00
0005432638999	2255	Economy	29100.00
0005432638989	2255	Economy	29100.00
0005432639001	2255	Economy	29100.00
0005432638983	2255	Economy	32000.00
0005432638993	2255	Economy	32000.00
0005432638981	2255	Economy	32000.00
0005432638982	2255	Economy	29100.00
0005432638988	2255	Economy	29100.00
0005432638987	2255	Economy	29100.00
0005432638990	2255	Economy	29100.00
0005432639002	2255	Economy	29100.00
0005432639004	2255	Economy	29100.00
0005432638984	2255	Economy	29100.00
0005432865900	2255	Economy	29100.00
0005432638996	2255	Economy	29100.00
0005432638980	2255	Economy	29100.00
0005432638994	2255	Economy	29100.00
0005432638985	2255	Economy	29100.00
0005432638992	2255	Economy	29100.00
0005432865899	2255	Economy	29100.00
0005432638995	2255	Economy	29100.00
0005432638997	2255	Economy	29100.00
0005432638986	2255	Economy	29100.00
0005432638979	2255	Economy	29100.00
0005433811618	24296	Business	105400.00
0005433811615	24296	Economy	35100.00
0005433811614	24296	Economy	35100.00
0005433811613	24296	Economy	35100.00
0005433811620	24296	Economy	35100.00
0005433811617	24296	Economy	35100.00
0005433811610	24296	Economy	35100.00
0005433811611	24296	Economy	35100.00
0005433811619	24296	Economy	35100.00
0005433811612	24296	Economy	35100.00
0005433811616	24296	Economy	35100.00
0005434191257	32761	Economy	4400.00
0005434191261	32761	Economy	4400.00
0005434191251	32761	Economy	4400.00
0005434191253	32761	Economy	4400.00
0005434191258	32761	Economy	4400.00
0005434191259	32761	Economy	4400.00
0005434191255	32761	Economy	4400.00
0005434191260	32761	Economy	4400.00
0005434191252	32761	Economy	4400.00
0005434191256	32761	Economy	4400.00
0005434191254	32761	Economy	4400.00
0005434503713	6515	Business	48400.00
0005434503702	6515	Business	48400.00
0005434503725	6515	Business	48400.00
0005434503739	6515	Business	48400.00
0005434503734	6515	Business	48400.00
0005434503731	6515	Business	48400.00
0005434503715	6515	Business	48400.00
0005434503722	6515	Economy	16100.00
0005434503737	6515	Economy	16100.00
0005434503707	6515	Economy	16100.00
0005434503727	6515	Economy	16100.00
0005435103852	6515	Economy	16100.00
0005434503723	6515	Economy	17800.00
0005434503728	6515	Economy	16100.00
0005434503729	6515	Economy	16100.00
0005434503719	6515	Economy	16100.00
0005435103850	6515	Economy	16100.00
0005434503721	6515	Economy	16100.00
0005434503732	6515	Economy	16100.00
0005434503705	6515	Economy	16100.00
0005434503718	6515	Economy	16100.00
0005434503706	6515	Economy	16100.00
0005434503716	6515	Economy	16100.00
0005434503703	6515	Economy	16100.00
0005434503710	6515	Economy	16100.00
0005434503711	6515	Economy	16100.00
0005435103851	6515	Economy	16100.00
0005434503730	6515	Economy	16100.00
0005434503700	6515	Economy	16100.00
0005434503724	6515	Economy	16100.00
0005434503704	6515	Economy	16100.00
0005434503733	6515	Economy	16100.00
0005434503708	6515	Economy	16100.00
0005434503740	6515	Economy	16100.00
0005434503738	6515	Economy	16100.00
0005434503709	6515	Economy	16100.00
0005434503714	6515	Economy	16100.00
0005434503701	6515	Economy	16100.00
0005434503712	6515	Economy	16100.00
0005434503720	6515	Economy	16100.00
0005434503726	6515	Economy	16100.00
0005434503717	6515	Economy	16100.00
0005434503736	6515	Economy	16100.00
0005434503735	6515	Economy	16100.00
0005435652558	1642	Business	50000.00
0005433367282	1642	Business	50000.00
0005433367236	1642	Business	50000.00
0005435652543	1642	Business	50000.00
0005435652537	1642	Business	50000.00
0005435652534	1642	Business	50000.00
0005433367247	1642	Economy	16700.00
0005435652555	1642	Economy	16700.00
0005435652539	1642	Economy	16700.00
0005435652529	1642	Economy	16700.00
0005435652542	1642	Economy	16700.00
0005435652547	1642	Economy	18300.00
0005435652554	1642	Economy	18300.00
0005435652548	1642	Economy	18300.00
0005433367291	1642	Economy	16700.00
0005435652553	1642	Economy	16700.00
0005433367220	1642	Economy	16700.00
0005435652557	1642	Economy	16700.00
0005433367235	1642	Economy	16700.00
0005435652527	1642	Economy	16700.00
0005435652536	1642	Economy	16700.00
0005435652551	1642	Economy	16700.00
0005435652531	1642	Economy	16700.00
0005435652549	1642	Economy	16700.00
0005435652560	1642	Economy	16700.00
0005435652528	1642	Economy	16700.00
0005433367248	1642	Economy	16700.00
0005435652544	1642	Economy	16700.00
0005435652556	1642	Economy	16700.00
0005435652530	1642	Economy	16700.00
0005435652559	1642	Economy	16700.00
0005435652538	1642	Economy	16700.00
0005435652535	1642	Economy	16700.00
0005435652550	1642	Economy	16700.00
0005435652541	1642	Economy	16700.00
0005435652546	1642	Economy	16700.00
0005435652552	1642	Economy	16700.00
0005435652533	1642	Economy	16700.00
0005435652532	1642	Economy	16700.00
0005435652545	1642	Economy	16700.00
0005435652540	1642	Economy	16700.00
0005433367313	1642	Economy	16700.00
0005433367479	21688	Business	50000.00
0005433367468	21688	Business	50000.00
0005433367471	21688	Business	50000.00
0005433367476	21688	Economy	16700.00
0005433367484	21688	Economy	16700.00
0005433367482	21688	Economy	16700.00
0005433367469	21688	Economy	16700.00
0005433367486	21688	Economy	16700.00
0005433367460	21688	Economy	16700.00
0005433367453	21688	Economy	16700.00
0005433367467	21688	Economy	16700.00
0005433367478	21688	Economy	16700.00
0005433367474	21688	Economy	16700.00
0005433367473	21688	Economy	16700.00
0005433367458	21688	Economy	16700.00
0005433367457	21688	Economy	16700.00
0005433367455	21688	Economy	16700.00
0005433367472	21688	Economy	16700.00
0005433367477	21688	Economy	16700.00
0005433367483	21688	Economy	16700.00
0005433367485	21688	Economy	16700.00
0005433367480	21688	Economy	16700.00
0005433367475	21688	Economy	16700.00
0005433367466	21688	Economy	16700.00
0005433367456	21688	Economy	16700.00
0005433367459	21688	Economy	16700.00
0005433367464	21688	Economy	16700.00
0005433367454	21688	Economy	16700.00
0005433367470	21688	Economy	16700.00
0005433367463	21688	Economy	16700.00
0005433367465	21688	Economy	16700.00
0005433367481	21688	Economy	16700.00
0005433367462	21688	Economy	16700.00
0005433367461	21688	Economy	16700.00
0005435312776	23242	Economy	20900.00
0005435312779	23242	Economy	20900.00
0005435312775	23242	Economy	20900.00
0005435312777	23242	Economy	20900.00
0005435312778	23242	Economy	20900.00
0005433985420	4134	Business	21500.00
0005433985455	4134	Business	21500.00
0005433985453	4134	Business	21500.00
0005433985418	4134	Business	21500.00
0005433985413	4134	Business	21500.00
0005433985440	4134	Business	21500.00
0005433985415	4134	Business	21500.00
0005433985454	4134	Business	21500.00
0005433985409	4134	Economy	7200.00
0005433985425	4134	Economy	7200.00
0005433985432	4134	Economy	7200.00
0005433985444	4134	Economy	7200.00
0005433985412	4134	Economy	7900.00
0005433985414	4134	Economy	7900.00
0005433985458	4134	Economy	7900.00
0005433985439	4134	Economy	7900.00
0005433985428	4134	Economy	7200.00
0005433985460	4134	Economy	7200.00
0005433985445	4134	Economy	7200.00
0005433985422	4134	Economy	7200.00
0005433985463	4134	Economy	7200.00
0005433985433	4134	Economy	7200.00
0005435788742	4134	Economy	7200.00
0005433985457	4134	Economy	7200.00
0005433985459	4134	Economy	7200.00
0005433985424	4134	Economy	7200.00
0005433985443	4134	Economy	7200.00
0005433985416	4134	Economy	7200.00
0005433985431	4134	Economy	7200.00
0005433985441	4134	Economy	7200.00
0005433985452	4134	Economy	7200.00
0005433985427	4134	Economy	7200.00
0005433985446	4134	Economy	7200.00
0005433985430	4134	Economy	7200.00
0005433985423	4134	Economy	7200.00
0005433985411	4134	Economy	7200.00
0005433985451	4134	Economy	7200.00
0005433985449	4134	Economy	7200.00
0005433985410	4134	Economy	7200.00
0005433985462	4134	Economy	7200.00
0005433985442	4134	Economy	7200.00
0005435788743	4134	Economy	7200.00
0005433985437	4134	Economy	7200.00
0005433985408	4134	Economy	7200.00
0005433985447	4134	Economy	7200.00
0005433985434	4134	Economy	7200.00
0005433985435	4134	Economy	7200.00
0005433985426	4134	Economy	7200.00
0005433985438	4134	Economy	7200.00
0005433985456	4134	Economy	7200.00
0005435788741	4134	Economy	7200.00
0005433985461	4134	Economy	7200.00
0005433985448	4134	Economy	7200.00
0005433985450	4134	Economy	7200.00
0005433985436	4134	Economy	7200.00
0005433985419	4134	Economy	7200.00
0005433985421	4134	Economy	7200.00
0005433985417	4134	Economy	7200.00
0005433985429	4134	Economy	7200.00
0005433985150	25667	Economy	7200.00
0005433985134	25667	Economy	7200.00
0005433985126	25667	Economy	7200.00
0005435719555	24806	Economy	9400.00
0005435720123	24806	Economy	9400.00
0005435720122	24806	Economy	9400.00
0005435719554	24806	Economy	9400.00
0005435720124	24806	Economy	9400.00
0005434509059	1635	Economy	17000.00
0005434509067	1635	Economy	15500.00
0005434509055	1635	Economy	15500.00
0005434509056	1635	Economy	15500.00
0005433168303	1635	Economy	15500.00
0005434509064	1635	Economy	15500.00
0005434509058	1635	Economy	15500.00
0005434509065	1635	Economy	15500.00
0005434509061	1635	Economy	15500.00
0005434509062	1635	Economy	15500.00
0005433168300	1635	Economy	15500.00
0005434509066	1635	Economy	15500.00
0005433168301	1635	Economy	15500.00
0005434509054	1635	Economy	15500.00
0005434509068	1635	Economy	15500.00
0005434509060	1635	Economy	15500.00
0005434509057	1635	Economy	15500.00
0005434509063	1635	Economy	15500.00
0005434509053	1635	Economy	15500.00
0005434516054	9021	Economy	26000.00
0005434516056	9021	Economy	23600.00
0005434516053	9021	Economy	23600.00
0005434516057	9021	Economy	23600.00
0005434516055	9021	Economy	23600.00
0005432869455	17868	Business	18000.00
0005434151673	17868	Business	18000.00
0005432666351	17868	Business	18000.00
0005434151674	17868	Economy	6000.00
0005432869458	17868	Economy	6600.00
0005432869454	17868	Economy	6600.00
0005432869451	17868	Economy	6000.00
0005432869452	17868	Economy	6000.00
0005432869456	17868	Economy	6000.00
0005432869453	17868	Economy	6000.00
0005434151672	17868	Economy	6000.00
0005432869457	17868	Economy	6000.00
0005432667428	26281	Business	18000.00
0005432666361	26281	Economy	6000.00
0005432655377	26281	Economy	6000.00
0005432660791	26281	Economy	6000.00
0005432659681	26281	Economy	6000.00
0005432655385	26281	Economy	6600.00
0005432655379	26281	Economy	6600.00
0005432658565	26281	Economy	6000.00
0005432659679	26281	Economy	6000.00
0005432657413	26281	Economy	6000.00
0005432666362	26281	Economy	6000.00
0005432655378	26281	Economy	6000.00
0005432657410	26281	Economy	6000.00
0005432655376	26281	Economy	6000.00
0005432657409	26281	Economy	6000.00
0005432657412	26281	Economy	6000.00
0005432659680	26281	Economy	6000.00
0005432655383	26281	Economy	6000.00
0005432655386	26281	Economy	6000.00
0005432655380	26281	Economy	6000.00
0005432655384	26281	Economy	6000.00
0005432658564	26281	Economy	6000.00
0005432665249	26281	Economy	6000.00
0005432657411	26281	Economy	6000.00
0005432655375	26281	Economy	6000.00
0005432655382	26281	Economy	6000.00
0005432660792	26281	Economy	6000.00
0005432658566	26281	Economy	6000.00
0005432655381	26281	Economy	6000.00
0005432865935	25064	Business	87300.00
0005432865936	25064	Business	87300.00
0005432865932	25064	Business	87300.00
0005432865940	25064	Economy	29100.00
0005432865929	25064	Economy	29100.00
0005432865943	25064	Economy	29100.00
0005432865939	25064	Economy	32000.00
0005432865941	25064	Economy	32000.00
0005432865931	25064	Economy	29100.00
0005432865933	25064	Economy	29100.00
0005432865942	25064	Economy	29100.00
0005432865930	25064	Economy	29100.00
0005432865934	25064	Economy	29100.00
0005432865938	25064	Economy	29100.00
0005432865937	25064	Economy	29100.00
0005432328217	3080	Business	16100.00
0005432328213	3080	Business	16100.00
0005432328204	3080	Business	16100.00
0005432328181	3080	Business	16100.00
0005432328205	3080	Business	16100.00
0005432328189	3080	Business	16100.00
0005432328185	3080	Business	16100.00
0005432328188	3080	Economy	5400.00
0005432287135	3080	Economy	5400.00
0005432328202	3080	Economy	5400.00
0005433438810	3080	Economy	5400.00
0005433438806	3080	Economy	5400.00
0005433438811	3080	Economy	5400.00
0005432328199	3080	Economy	5400.00
0005432328190	3080	Economy	5400.00
0005432328214	3080	Economy	5900.00
0005432287132	3080	Economy	5900.00
0005432328216	3080	Economy	5900.00
0005432328207	3080	Economy	5400.00
0005432328177	3080	Economy	5400.00
0005432328203	3080	Economy	5400.00
0005433438804	3080	Economy	5400.00
0005432328179	3080	Economy	5400.00
0005432328197	3080	Economy	5400.00
0005432328194	3080	Economy	5400.00
0005432328212	3080	Economy	5400.00
0005432905032	3080	Economy	5400.00
0005432328208	3080	Economy	5400.00
0005432328195	3080	Economy	5400.00
0005432328210	3080	Economy	5400.00
0005433438805	3080	Economy	5400.00
0005432328175	3080	Economy	5400.00
0005432328191	3080	Economy	5400.00
0005432328176	3080	Economy	5400.00
0005432328201	3080	Economy	5400.00
0005432328209	3080	Economy	5400.00
0005432328198	3080	Economy	5400.00
0005432328180	3080	Economy	5400.00
0005432328193	3080	Economy	5400.00
0005432328182	3080	Economy	5400.00
0005433438807	3080	Economy	5400.00
0005432328196	3080	Economy	5400.00
0005432328192	3080	Economy	5400.00
0005432328215	3080	Economy	5400.00
0005432328174	3080	Economy	5400.00
0005433438809	3080	Economy	5400.00
0005432287133	3080	Economy	5400.00
0005432328178	3080	Economy	5400.00
0005432328183	3080	Economy	5400.00
0005432328211	3080	Economy	5400.00
0005432328187	3080	Economy	5400.00
0005432328173	3080	Economy	5400.00
0005432328218	3080	Economy	5400.00
0005432287134	3080	Economy	5400.00
0005433438808	3080	Economy	5400.00
0005432328206	3080	Economy	5400.00
0005432328184	3080	Economy	5400.00
0005432328200	3080	Economy	5400.00
0005432328186	3080	Economy	5400.00
0005432905056	31133	Business	16100.00
0005432905061	31133	Business	16100.00
0005432905060	31133	Business	16100.00
0005432054271	31133	Economy	5400.00
0005432054270	31133	Economy	5900.00
0005432054272	31133	Economy	5400.00
0005432905057	31133	Economy	5400.00
0005432327945	31133	Economy	5400.00
0005432905059	31133	Economy	5400.00
0005432327989	31133	Economy	5400.00
0005432905058	31133	Economy	5400.00
0005432905062	31133	Economy	5400.00
0005434309595	6220	Business	124600.00
0005435999066	6220	Business	124600.00
0005432146177	6220	Economy	41500.00
0005435999058	6220	Economy	41500.00
0005435999055	6220	Economy	41500.00
0005435999060	6220	Economy	41500.00
0005435999061	6220	Economy	41500.00
0005435999064	6220	Economy	41500.00
0005435999063	6220	Economy	41500.00
0005434309584	6220	Economy	41500.00
0005434309594	6220	Economy	41500.00
0005432146176	6220	Economy	41500.00
0005435999049	6220	Economy	41500.00
0005435999054	6220	Economy	41500.00
0005434309590	6220	Economy	41500.00
0005435999050	6220	Economy	41500.00
0005434309585	6220	Economy	41500.00
0005434309589	6220	Economy	41500.00
0005435999048	6220	Economy	45700.00
0005435999059	6220	Economy	41500.00
0005435999065	6220	Economy	41500.00
0005434309596	6220	Economy	41500.00
0005435999052	6220	Economy	41500.00
0005434309587	6220	Economy	41500.00
0005434309586	6220	Economy	41500.00
0005435999067	6220	Economy	41500.00
0005434309588	6220	Economy	41500.00
0005434309592	6220	Economy	41500.00
0005435999056	6220	Economy	41500.00
0005435296938	6220	Economy	41500.00
0005435999051	6220	Economy	41500.00
0005435999053	6220	Economy	41500.00
0005435999062	6220	Economy	41500.00
0005435999057	6220	Economy	41500.00
0005435999047	6220	Economy	41500.00
0005435999068	6220	Economy	41500.00
0005434309597	6220	Economy	41500.00
0005434309591	6220	Economy	41500.00
0005434309593	6220	Economy	41500.00
0005434309539	19565	Business	124600.00
0005435487569	19565	Business	124600.00
0005435487577	19565	Economy	41500.00
0005435487582	19565	Economy	41500.00
0005435296979	19565	Economy	41500.00
0005435487564	19565	Economy	41500.00
0005435487571	19565	Economy	41500.00
0005435487583	19565	Economy	41500.00
0005435487575	19565	Economy	41500.00
0005435487576	19565	Economy	41500.00
0005435296986	19565	Economy	41500.00
0005435487567	19565	Economy	41500.00
0005435296981	19565	Economy	41500.00
0005435487584	19565	Economy	41500.00
0005435487568	19565	Economy	41500.00
0005435296980	19565	Economy	41500.00
0005435487580	19565	Economy	41500.00
0005435487581	19565	Economy	41500.00
0005435296982	19565	Economy	41500.00
0005435487572	19565	Economy	41500.00
0005435487579	19565	Economy	41500.00
0005435487578	19565	Economy	41500.00
0005435487570	19565	Economy	41500.00
0005435487573	19565	Economy	41500.00
0005435487566	19565	Economy	41500.00
0005435487565	19565	Economy	41500.00
0005434309540	19565	Economy	41500.00
0005435296985	19565	Economy	41500.00
0005435296983	19565	Economy	41500.00
0005435296984	19565	Economy	41500.00
0005435487585	19565	Economy	41500.00
0005435487574	19565	Economy	41500.00
0005435517721	1566	Business	86000.00
0005435517727	1566	Business	86000.00
0005435517720	1566	Business	86000.00
0005435502068	1566	Business	86000.00
0005435502071	1566	Business	86000.00
0005435502079	1566	Business	86000.00
0005434565760	1566	Business	86000.00
0005434565767	1566	Business	86000.00
0005434565766	1566	Business	86000.00
0005435502073	1566	Economy	28700.00
0005435508234	1566	Economy	28700.00
0005435517723	1566	Economy	28700.00
0005435502084	1566	Economy	28700.00
0005435517713	1566	Economy	28700.00
0005435502072	1566	Economy	28700.00
0005435517729	1566	Economy	28700.00
0005435517730	1566	Economy	31500.00
0005435502080	1566	Economy	31500.00
0005435502067	1566	Economy	31500.00
0005435502082	1566	Economy	31500.00
0005434565761	1566	Economy	31500.00
0005432291904	1566	Economy	28700.00
0005435517717	1566	Economy	28700.00
0005435508232	1566	Economy	28700.00
0005435502081	1566	Economy	28700.00
0005434565768	1566	Economy	28700.00
0005435517725	1566	Economy	28700.00
0005435517712	1566	Economy	28700.00
0005435502065	1566	Economy	28700.00
0005435502070	1566	Economy	28700.00
0005435502066	1566	Economy	28700.00
0005434565770	1566	Economy	28700.00
0005435517714	1566	Economy	28700.00
0005434565764	1566	Economy	28700.00
0005435502074	1566	Economy	28700.00
0005435502078	1566	Economy	28700.00
0005435502064	1566	Economy	28700.00
0005435502075	1566	Economy	28700.00
0005435517711	1566	Economy	28700.00
0005435517726	1566	Economy	28700.00
0005434565762	1566	Economy	28700.00
0005434565769	1566	Economy	28700.00
0005435508233	1566	Economy	28700.00
0005434565774	1566	Economy	28700.00
0005435502077	1566	Economy	28700.00
0005434565773	1566	Economy	28700.00
0005435502076	1566	Economy	28700.00
0005435517724	1566	Economy	28700.00
0005435508230	1566	Economy	28700.00
0005435517716	1566	Economy	28700.00
0005435517731	1566	Economy	28700.00
0005435517715	1566	Economy	28700.00
0005435502069	1566	Economy	28700.00
0005435502083	1566	Economy	28700.00
0005435517722	1566	Economy	28700.00
0005435517728	1566	Economy	28700.00
0005432291903	1566	Economy	28700.00
0005434565771	1566	Economy	28700.00
0005434565763	1566	Economy	28700.00
0005435517718	1566	Economy	28700.00
0005435508229	1566	Economy	28700.00
0005435517719	1566	Economy	28700.00
0005434565772	1566	Economy	28700.00
0005435508231	1566	Economy	28700.00
0005435502085	1566	Economy	28700.00
0005434565765	1566	Economy	28700.00
0005435501980	20868	Business	86000.00
0005433186026	20868	Economy	28700.00
0005433186027	20868	Economy	28700.00
0005435501981	20868	Economy	31500.00
0005433186029	20868	Economy	28700.00
0005433186022	20868	Economy	28700.00
0005433186028	20868	Economy	28700.00
0005433186025	20868	Economy	28700.00
0005435528883	20868	Economy	28700.00
0005433186021	20868	Economy	28700.00
0005435501938	20868	Economy	28700.00
0005433186024	20868	Economy	28700.00
0005433186023	20868	Economy	28700.00
0005435153667	3875	Economy	21600.00
0005435153673	3875	Economy	19700.00
0005435153672	3875	Economy	19700.00
0005435153669	3875	Economy	19700.00
0005435153671	3875	Economy	19700.00
0005435153670	3875	Economy	19700.00
0005435153666	3875	Economy	19700.00
0005435153668	3875	Economy	19700.00
0005435931560	21854	Economy	21600.00
0005435931562	21854	Economy	19700.00
0005435931561	21854	Economy	19700.00
0005435931559	21854	Economy	19700.00
0005432628686	7216	Economy	14300.00
0005432628690	7216	Economy	14300.00
0005432628684	7216	Economy	13000.00
0005432628677	7216	Economy	13000.00
0005432628688	7216	Economy	13000.00
0005432628682	7216	Economy	13000.00
0005432628687	7216	Economy	13000.00
0005432628679	7216	Economy	13000.00
0005432628689	7216	Economy	13000.00
0005432628676	7216	Economy	13000.00
0005435225465	7216	Economy	13000.00
0005432628680	7216	Economy	13000.00
0005432628685	7216	Economy	13000.00
0005432628678	7216	Economy	13000.00
0005432628683	7216	Economy	13000.00
0005432628681	7216	Economy	13000.00
0005435225492	28136	Economy	14300.00
0005432628613	28136	Economy	13000.00
0005432628601	28136	Economy	13000.00
0005432628594	28136	Economy	13000.00
0005435225494	28136	Economy	13000.00
0005435225498	28136	Economy	13000.00
0005435225495	28136	Economy	13000.00
0005435225497	28136	Economy	13000.00
0005435225499	28136	Economy	13000.00
0005435225496	28136	Economy	13000.00
0005432628596	28136	Economy	13000.00
0005435225493	28136	Economy	13000.00
0005435960009	8754	Economy	10500.00
0005435960007	8754	Economy	10500.00
0005435960008	8754	Economy	10500.00
0005435960006	8754	Economy	10500.00
0005434267906	15213	Economy	10500.00
0005434267910	15213	Economy	10500.00
0005434267907	15213	Economy	10500.00
0005434267908	15213	Economy	10500.00
0005434267909	15213	Economy	10500.00
0005432692704	1166	Business	115000.00
0005432692712	1166	Business	115000.00
0005432677525	1166	Business	115000.00
0005432674970	1166	Business	115000.00
0005432692710	1166	Business	115000.00
0005432692687	1166	Business	115000.00
0005432692707	1166	Business	115000.00
0005432692696	1166	Business	115000.00
0005432692702	1166	Business	115000.00
0005432674963	1166	Economy	38300.00
0005432692686	1166	Economy	38300.00
0005432692699	1166	Economy	38300.00
0005432674968	1166	Economy	38300.00
0005432677524	1166	Economy	38300.00
0005432692715	1166	Economy	38300.00
0005432692695	1166	Economy	38300.00
0005432873172	1166	Economy	42200.00
0005432674962	1166	Economy	42200.00
0005432692706	1166	Economy	38300.00
0005432692694	1166	Economy	38300.00
0005432692688	1166	Economy	38300.00
0005432692716	1166	Economy	38300.00
0005432692691	1166	Economy	38300.00
0005432692700	1166	Economy	38300.00
0005432692709	1166	Economy	38300.00
0005432692701	1166	Economy	38300.00
0005432674965	1166	Economy	38300.00
0005432873173	1166	Economy	38300.00
0005432674957	1166	Economy	38300.00
0005432692705	1166	Economy	38300.00
0005432677526	1166	Economy	38300.00
0005432677527	1166	Economy	38300.00
0005432692692	1166	Economy	38300.00
0005432873175	1166	Economy	38300.00
0005432674960	1166	Economy	38300.00
0005432674964	1166	Economy	38300.00
0005432674956	1166	Economy	38300.00
0005432674966	1166	Economy	38300.00
0005432692703	1166	Economy	38300.00
0005432692708	1166	Economy	38300.00
0005432692714	1166	Economy	38300.00
0005432692693	1166	Economy	38300.00
0005432692711	1166	Economy	38300.00
0005432692698	1166	Economy	38300.00
0005432674967	1166	Economy	38300.00
0005432692697	1166	Economy	38300.00
0005432692690	1166	Economy	38300.00
0005432674958	1166	Economy	38300.00
0005432692689	1166	Economy	38300.00
0005432674969	1166	Economy	38300.00
0005432674961	1166	Economy	38300.00
0005432873176	1166	Economy	38300.00
0005432674959	1166	Economy	38300.00
0005432692713	1166	Economy	38300.00
0005432873211	17459	Business	115000.00
0005432873210	17459	Economy	38300.00
0005432692552	17459	Economy	38300.00
0005432692551	17459	Economy	38300.00
0005432873214	17459	Economy	38300.00
0005432873213	17459	Economy	38300.00
0005432873212	17459	Economy	38300.00
0005432873215	17459	Economy	38300.00
0005432873216	17459	Economy	38300.00
0005432873209	17459	Economy	38300.00
0005434435004	1125	Economy	15200.00
0005434435013	1125	Economy	15200.00
0005434435007	1125	Economy	13900.00
0005434435019	1125	Economy	13900.00
0005434435008	1125	Economy	13900.00
0005434435011	1125	Economy	13900.00
0005433156605	1125	Economy	13900.00
0005434435009	1125	Economy	13900.00
0005434435006	1125	Economy	13900.00
0005433156609	1125	Economy	13900.00
0005434435017	1125	Economy	13900.00
0005434435003	1125	Economy	13900.00
0005434435014	1125	Economy	13900.00
0005434435010	1125	Economy	13900.00
0005434435012	1125	Economy	13900.00
0005434435016	1125	Economy	13900.00
0005434435005	1125	Economy	13900.00
0005433156604	1125	Economy	13900.00
0005434435015	1125	Economy	13900.00
0005433156618	1125	Economy	13900.00
0005434435018	1125	Economy	13900.00
0005433156619	1125	Economy	13900.00
0005433156652	17278	Economy	13900.00
0005433156656	17278	Economy	13900.00
0005433156655	17278	Economy	13900.00
0005433156651	17278	Economy	13900.00
0005433156657	17278	Economy	13900.00
0005433156650	17278	Economy	13900.00
0005433156653	17278	Economy	13900.00
0005434434936	17278	Economy	13900.00
0005433156654	17278	Economy	13900.00
0005433156649	17278	Economy	13900.00
0005435086752	4092	Economy	8200.00
0005435928062	4092	Economy	8200.00
0005435086750	4092	Economy	7500.00
0005435928063	4092	Economy	7500.00
0005435086751	4092	Economy	7500.00
0005435086747	4092	Economy	7500.00
0005435086754	4092	Economy	7500.00
0005435086749	4092	Economy	7500.00
0005435086753	4092	Economy	7500.00
0005435086748	4092	Economy	7500.00
0005435086746	4092	Economy	7500.00
0005435928087	24391	Economy	7500.00
0005435928088	24391	Economy	7500.00
0005435086710	24391	Economy	7500.00
0005435928091	24391	Economy	7500.00
0005435086711	24391	Economy	7500.00
0005435928090	24391	Economy	7500.00
0005435928089	24391	Economy	7500.00
0005435706199	2462	Business	86800.00
0005435706182	2462	Business	86800.00
0005435706207	2462	Business	86800.00
0005435706197	2462	Business	86800.00
0005435706209	2462	Business	86800.00
0005435706206	2462	Business	86800.00
0005435706195	2462	Business	86800.00
0005435706196	2462	Business	86800.00
0005435706210	2462	Economy	28900.00
0005435706189	2462	Economy	28900.00
0005433373382	2462	Economy	28900.00
0005435706192	2462	Economy	28900.00
0005435706194	2462	Economy	28900.00
0005435706212	2462	Economy	28900.00
0005435706185	2462	Economy	28900.00
0005435706187	2462	Economy	28900.00
0005435706201	2462	Economy	28900.00
0005435706204	2462	Economy	28900.00
0005435706205	2462	Economy	28900.00
0005435706190	2462	Economy	28900.00
0005435706203	2462	Economy	28900.00
0005435706186	2462	Economy	28900.00
0005435706188	2462	Economy	28900.00
0005435706181	2462	Economy	28900.00
0005435706198	2462	Economy	28900.00
0005435706211	2462	Economy	28900.00
0005435706193	2462	Economy	28900.00
0005435706183	2462	Economy	28900.00
0005435706184	2462	Economy	28900.00
0005435706208	2462	Economy	28900.00
0005435706191	2462	Economy	28900.00
0005435706202	2462	Economy	28900.00
0005435706200	2462	Economy	28900.00
0005433373423	27033	Business	86800.00
0005433373437	27033	Economy	28900.00
0005435706139	27033	Economy	28900.00
0005433373428	27033	Economy	28900.00
0005433373429	27033	Economy	31800.00
0005433373425	27033	Economy	28900.00
0005433373420	27033	Economy	28900.00
0005433373434	27033	Economy	28900.00
0005433373427	27033	Economy	28900.00
0005435706126	27033	Economy	28900.00
0005435706125	27033	Economy	28900.00
0005435706140	27033	Economy	28900.00
0005433373435	27033	Economy	28900.00
0005435706127	27033	Economy	28900.00
0005433373431	27033	Economy	28900.00
0005433373426	27033	Economy	28900.00
0005433373424	27033	Economy	28900.00
0005433373436	27033	Economy	28900.00
0005433373421	27033	Economy	28900.00
0005433373422	27033	Economy	28900.00
0005433373430	27033	Economy	28900.00
0005433373438	27033	Economy	28900.00
0005433373432	27033	Economy	28900.00
0005433373433	27033	Economy	28900.00
0005434964012	1313	Business	203300.00
0005434964000	1313	Business	203300.00
0005434964025	1313	Business	203300.00
0005434964009	1313	Business	203300.00
0005434964026	1313	Business	203300.00
0005434963995	1313	Business	203300.00
0005434963996	1313	Business	203300.00
0005434964029	1313	Economy	74500.00
0005434964008	1313	Economy	67800.00
0005434964015	1313	Economy	67800.00
0005434963992	1313	Economy	67800.00
0005434964022	1313	Economy	67800.00
0005434963994	1313	Economy	67800.00
0005434964002	1313	Economy	67800.00
0005434964010	1313	Economy	67800.00
0005434964030	1313	Economy	67800.00
0005432279245	1313	Economy	67800.00
0005434963998	1313	Economy	67800.00
0005434964027	1313	Economy	67800.00
0005434963999	1313	Economy	67800.00
0005434964013	1313	Economy	67800.00
0005432279249	1313	Economy	67800.00
0005432279248	1313	Economy	67800.00
0005434964001	1313	Economy	67800.00
0005432279246	1313	Economy	67800.00
0005432279247	1313	Economy	67800.00
0005434964004	1313	Economy	67800.00
0005434964018	1313	Economy	67800.00
0005434964014	1313	Economy	67800.00
0005434963997	1313	Economy	74500.00
0005434963993	1313	Economy	67800.00
0005434964028	1313	Economy	67800.00
0005434964003	1313	Economy	67800.00
0005434964005	1313	Economy	67800.00
0005434964011	1313	Economy	67800.00
0005434964020	1313	Economy	67800.00
0005434964024	1313	Economy	67800.00
0005434964007	1313	Economy	67800.00
0005434964016	1313	Economy	67800.00
0005434964023	1313	Economy	67800.00
0005434964017	1313	Economy	67800.00
0005434964006	1313	Economy	67800.00
0005434964019	1313	Economy	67800.00
0005434964021	1313	Economy	67800.00
0005433261454	18249	Business	203300.00
0005433261446	18249	Business	203300.00
0005433261443	18249	Business	203300.00
0005433261456	18249	Business	203300.00
0005433261460	18249	Business	203300.00
0005433261459	18249	Business	203300.00
0005434963930	18249	Business	203300.00
0005433261431	18249	Economy	67800.00
0005434963909	18249	Economy	67800.00
0005433261461	18249	Economy	67800.00
0005433261433	18249	Economy	67800.00
0005433261455	18249	Economy	67800.00
0005433261438	18249	Economy	67800.00
0005433261450	18249	Economy	67800.00
0005434963917	18249	Economy	67800.00
0005433261442	18249	Economy	67800.00
0005433261439	18249	Economy	67800.00
0005433261432	18249	Economy	67800.00
0005433261448	18249	Economy	67800.00
0005433261444	18249	Economy	67800.00
0005433261452	18249	Economy	67800.00
0005434963910	18249	Economy	67800.00
0005433261449	18249	Economy	67800.00
0005433261434	18249	Economy	67800.00
0005433261430	18249	Economy	67800.00
0005433261445	18249	Economy	67800.00
0005433261437	18249	Economy	67800.00
0005433261457	18249	Economy	67800.00
0005433261435	18249	Economy	67800.00
0005433261453	18249	Economy	67800.00
0005433261440	18249	Economy	67800.00
0005434963908	18249	Economy	67800.00
0005433261441	18249	Economy	67800.00
0005433261436	18249	Economy	67800.00
0005433261451	18249	Economy	67800.00
0005433261458	18249	Economy	67800.00
0005433261447	18249	Economy	67800.00
0005434625855	4829	Business	44200.00
0005434625854	4829	Economy	14700.00
0005434625860	4829	Economy	14700.00
0005434625858	4829	Economy	14700.00
0005434625862	4829	Economy	14700.00
0005434625863	4829	Economy	14700.00
0005434625861	4829	Economy	14700.00
0005434625856	4829	Economy	14700.00
0005434625857	4829	Economy	14700.00
0005434625853	4829	Economy	14700.00
0005434625859	4829	Economy	14700.00
0005434625817	32881	Business	44200.00
0005434625825	32881	Business	44200.00
0005435907450	32881	Economy	14700.00
0005434625801	32881	Economy	14700.00
0005434625795	32881	Economy	14700.00
0005435907448	32881	Economy	14700.00
0005435907451	32881	Economy	14700.00
0005435907449	32881	Economy	14700.00
0005435907452	32881	Economy	14700.00
0005434625802	32881	Economy	14700.00
0005432195670	13763	Economy	3400.00
0005435937329	13763	Economy	3400.00
0005435937330	13763	Economy	3100.00
0005435784735	13763	Economy	3100.00
0005435784790	13763	Economy	3100.00
0005432195668	13763	Economy	3100.00
0005435937332	13763	Economy	3100.00
0005432195669	13763	Economy	3100.00
0005435937331	13763	Economy	3100.00
0005435937333	13763	Economy	3100.00
0005435784817	13763	Economy	3100.00
0005435784909	27429	Economy	3400.00
0005435784919	27429	Economy	3400.00
0005435784912	27429	Economy	3100.00
0005435784938	27429	Economy	3100.00
0005435784931	27429	Economy	3100.00
0005435784908	27429	Economy	3100.00
0005435784913	27429	Economy	3100.00
0005435787327	27429	Economy	3100.00
0005435784923	27429	Economy	3100.00
0005435784924	27429	Economy	3100.00
0005435784916	27429	Economy	3100.00
0005435784935	27429	Economy	3100.00
0005435784928	27429	Economy	3100.00
0005435784905	27429	Economy	3100.00
0005435784922	27429	Economy	3100.00
0005435784911	27429	Economy	3100.00
0005435784937	27429	Economy	3100.00
0005435784910	27429	Economy	3100.00
0005435784926	27429	Economy	3100.00
0005435784934	27429	Economy	3100.00
0005435784933	27429	Economy	3100.00
0005435784927	27429	Economy	3100.00
0005435784921	27429	Economy	3100.00
0005435784915	27429	Economy	3100.00
0005432190582	27429	Economy	3100.00
0005435784907	27429	Economy	3100.00
0005435784917	27429	Economy	3100.00
0005435787326	27429	Economy	3100.00
0005435784929	27429	Economy	3100.00
0005435784920	27429	Economy	3100.00
0005435784914	27429	Economy	3100.00
0005432190580	27429	Economy	3100.00
0005435784906	27429	Economy	3100.00
0005435784918	27429	Economy	3100.00
0005435784932	27429	Economy	3100.00
0005435784925	27429	Economy	3100.00
0005435784930	27429	Economy	3100.00
0005432190579	27429	Economy	3100.00
0005435784936	27429	Economy	3100.00
0005432190581	27429	Economy	3100.00
0005435310938	20293	Business	12000.00
0005435310932	20293	Economy	4000.00
0005432058338	20293	Economy	4400.00
0005434406733	20293	Economy	4400.00
0005434406747	20293	Economy	4400.00
0005435310931	20293	Economy	4000.00
0005435310933	20293	Economy	4000.00
0005435310936	20293	Economy	4000.00
0005435310935	20293	Economy	4000.00
0005434406722	20293	Economy	4000.00
0005435310934	20293	Economy	4000.00
0005435310939	20293	Economy	4000.00
0005434406693	20293	Economy	4000.00
0005434406661	20293	Economy	4000.00
0005435310941	20293	Economy	4000.00
0005432058339	20293	Economy	4000.00
0005435310940	20293	Economy	4000.00
0005432058337	20293	Economy	4000.00
0005434406716	20293	Economy	4000.00
0005434406675	20293	Economy	4000.00
0005435310930	20293	Economy	4000.00
0005435310937	20293	Economy	4000.00
0005434406666	20293	Economy	4000.00
0005434407059	26985	Business	12000.00
0005434407049	26985	Business	12000.00
0005434407062	26985	Business	12000.00
0005434407066	26985	Business	12000.00
0005434407067	26985	Business	12000.00
0005434407024	26985	Business	12000.00
0005434407044	26985	Business	12000.00
0005434407063	26985	Business	12000.00
0005434407080	26985	Business	12000.00
0005434407027	26985	Business	12000.00
0005434407040	26985	Economy	4000.00
0005432153861	26985	Economy	4000.00
0005434407033	26985	Economy	4000.00
0005434407056	26985	Economy	4000.00
0005434407069	26985	Economy	4000.00
0005432153858	26985	Economy	4000.00
0005434407028	26985	Economy	4400.00
0005434407036	26985	Economy	4400.00
0005434407087	26985	Economy	4400.00
0005434407031	26985	Economy	4400.00
0005434407030	26985	Economy	4400.00
0005434407086	26985	Economy	4000.00
0005434407048	26985	Economy	4000.00
0005434407035	26985	Economy	4000.00
0005432153860	26985	Economy	4000.00
0005434407046	26985	Economy	4000.00
0005434407029	26985	Economy	4000.00
0005434407081	26985	Economy	4000.00
0005434407026	26985	Economy	4000.00
0005432153862	26985	Economy	4000.00
0005434407065	26985	Economy	4000.00
0005434407072	26985	Economy	4000.00
0005434407074	26985	Economy	4000.00
0005434407045	26985	Economy	4000.00
0005434407083	26985	Economy	4000.00
0005434407068	26985	Economy	4000.00
0005434407055	26985	Economy	4000.00
0005434407061	26985	Economy	4000.00
0005434407034	26985	Economy	4000.00
0005434407054	26985	Economy	4000.00
0005434407032	26985	Economy	4000.00
0005434407064	26985	Economy	4000.00
0005432153863	26985	Economy	4000.00
0005434407037	26985	Economy	4000.00
0005434407050	26985	Economy	4000.00
0005434407038	26985	Economy	4000.00
0005434407060	26985	Economy	4000.00
0005434407078	26985	Economy	4000.00
0005434407042	26985	Economy	4000.00
0005434407047	26985	Economy	4000.00
0005434407053	26985	Economy	4000.00
0005434407070	26985	Economy	4000.00
0005434407077	26985	Economy	4000.00
0005434407082	26985	Economy	4000.00
0005434407025	26985	Economy	4000.00
0005434407075	26985	Economy	4000.00
0005434407052	26985	Economy	4000.00
0005434407051	26985	Economy	4000.00
0005434407043	26985	Economy	4000.00
0005434407073	26985	Economy	4000.00
0005432153859	26985	Economy	4000.00
0005434407076	26985	Economy	4000.00
0005434407058	26985	Economy	4000.00
0005434407084	26985	Economy	4000.00
0005434407057	26985	Economy	4000.00
0005434407071	26985	Economy	4000.00
0005434407085	26985	Economy	4000.00
0005434407079	26985	Economy	4000.00
0005434407041	26985	Economy	4000.00
0005432153857	26985	Economy	4000.00
0005432153856	26985	Economy	4000.00
0005434407039	26985	Economy	4000.00
0005434319230	5683	Business	43300.00
0005432109673	5683	Business	43300.00
0005434311194	5683	Economy	14400.00
0005432109671	5683	Economy	14400.00
0005434311195	5683	Economy	14400.00
0005434319233	5683	Economy	14400.00
0005433123581	5683	Economy	14400.00
0005433123586	5683	Economy	15900.00
0005434319229	5683	Economy	15900.00
0005434319234	5683	Economy	14400.00
0005432109672	5683	Economy	14400.00
0005433123587	5683	Economy	14400.00
0005434319238	5683	Economy	14400.00
0005432109674	5683	Economy	14400.00
0005434319240	5683	Economy	14400.00
0005434319232	5683	Economy	14400.00
0005433123609	5683	Economy	14400.00
0005434319239	5683	Economy	14400.00
0005434311196	5683	Economy	14400.00
0005434319237	5683	Economy	14400.00
0005433123580	5683	Economy	14400.00
0005433123571	5683	Economy	14400.00
0005434319235	5683	Economy	14400.00
0005433123593	5683	Economy	14400.00
0005434319231	5683	Economy	14400.00
0005434319236	5683	Economy	14400.00
0005433123702	15704	Business	43300.00
0005433123712	15704	Business	43300.00
0005433123700	15704	Economy	14400.00
0005433123707	15704	Economy	14400.00
0005433123706	15704	Economy	14400.00
0005434312285	15704	Economy	14400.00
0005433123703	15704	Economy	14400.00
0005433123711	15704	Economy	14400.00
0005433123708	15704	Economy	14400.00
0005433123701	15704	Economy	14400.00
0005433123705	15704	Economy	14400.00
0005433123713	15704	Economy	14400.00
0005433123699	15704	Economy	14400.00
0005433123709	15704	Economy	14400.00
0005433123710	15704	Economy	14400.00
0005433123704	15704	Economy	14400.00
0005434312286	15704	Economy	14400.00
0005434484271	8957	Economy	24900.00
0005434484276	8957	Economy	24900.00
0005434484273	8957	Economy	24900.00
0005434484272	8957	Economy	24900.00
0005434484274	8957	Economy	24900.00
0005434484277	8957	Economy	24900.00
0005434484275	8957	Economy	24900.00
0005434189112	16653	Economy	24900.00
0005434189116	16653	Economy	24900.00
0005434189114	16653	Economy	24900.00
0005434189111	16653	Economy	24900.00
0005434189115	16653	Economy	24900.00
0005434189113	16653	Economy	24900.00
0005433123700	7699	Business	11100.00
0005433123707	7699	Business	11100.00
0005433123699	7699	Economy	3700.00
0005433123709	7699	Economy	4100.00
0005433123704	7699	Economy	3700.00
0005433123706	7699	Economy	3700.00
0005433123705	7699	Economy	3700.00
0005433123708	7699	Economy	3700.00
0005433123712	7699	Economy	3700.00
0005433123703	7699	Economy	3700.00
0005433123711	7699	Economy	3700.00
0005433123702	7699	Economy	3700.00
0005433123710	7699	Economy	3700.00
0005433123701	7699	Economy	3700.00
0005433123713	7699	Economy	3700.00
0005432720610	7697	Business	11100.00
0005432071541	7697	Business	11100.00
0005432692737	7697	Business	11100.00
0005432692719	7697	Business	11100.00
0005432720614	7697	Business	11100.00
0005433449724	7697	Business	11100.00
0005432720599	7697	Business	11100.00
0005432692742	7697	Business	11100.00
0005432692743	7697	Business	11100.00
0005432692735	7697	Business	11100.00
0005432720611	7697	Economy	3700.00
0005433449734	7697	Economy	3700.00
0005432692747	7697	Economy	3700.00
0005432692730	7697	Economy	3700.00
0005432692740	7697	Economy	3700.00
0005432720596	7697	Economy	3700.00
0005432720601	7697	Economy	3700.00
0005432692726	7697	Economy	3700.00
0005432692723	7697	Economy	3700.00
0005432692722	7697	Economy	4100.00
0005433449723	7697	Economy	4100.00
0005432720612	7697	Economy	4100.00
0005432692720	7697	Economy	4100.00
0005433449727	7697	Economy	4100.00
0005433449717	7697	Economy	3700.00
0005432692739	7697	Economy	3700.00
0005432720602	7697	Economy	3700.00
0005432720607	7697	Economy	3700.00
0005432720605	7697	Economy	3700.00
0005432692717	7697	Economy	3700.00
0005432692736	7697	Economy	3700.00
0005432692738	7697	Economy	3700.00
0005432720608	7697	Economy	3700.00
0005433449719	7697	Economy	3700.00
0005433449730	7697	Economy	3700.00
0005432071540	7697	Economy	3700.00
0005432692732	7697	Economy	3700.00
0005432692727	7697	Economy	3700.00
0005433449731	7697	Economy	3700.00
0005432692721	7697	Economy	3700.00
0005432692741	7697	Economy	3700.00
0005432720616	7697	Economy	3700.00
0005433449738	7697	Economy	3700.00
0005432720618	7697	Economy	3700.00
0005432692744	7697	Economy	3700.00
0005432720619	7697	Economy	3700.00
0005432692746	7697	Economy	3700.00
0005432692718	7697	Economy	3700.00
0005433449726	7697	Economy	3700.00
0005432720593	7697	Economy	3700.00
0005432720617	7697	Economy	3700.00
0005432692728	7697	Economy	3700.00
0005433449720	7697	Economy	3700.00
0005433449722	7697	Economy	3700.00
0005433449718	7697	Economy	3700.00
0005433449733	7697	Economy	3700.00
0005433449729	7697	Economy	3700.00
0005432720600	7697	Economy	3700.00
0005432720606	7697	Economy	3700.00
0005432692729	7697	Economy	3700.00
0005432720595	7697	Economy	3700.00
0005432692731	7697	Economy	3700.00
0005433449736	7697	Economy	3700.00
0005432720615	7697	Economy	3700.00
0005432720594	7697	Economy	3700.00
0005433449728	7697	Economy	3700.00
0005433449732	7697	Economy	3700.00
0005433449725	7697	Economy	3700.00
0005432720597	7697	Economy	3700.00
0005432720598	7697	Economy	3700.00
0005432692724	7697	Economy	3700.00
0005432720613	7697	Economy	3700.00
0005432692725	7697	Economy	3700.00
0005433449737	7697	Economy	3700.00
0005432720603	7697	Economy	3700.00
0005432071539	7697	Economy	3700.00
0005432720604	7697	Economy	3700.00
0005433449735	7697	Economy	3700.00
0005432720609	7697	Economy	3700.00
0005433449721	7697	Economy	3700.00
0005432692734	7697	Economy	3700.00
0005432692745	7697	Economy	3700.00
0005432692733	7697	Economy	3700.00
0005432692552	30401	Business	11100.00
0005433449648	30401	Economy	3700.00
0005432692551	30401	Economy	3700.00
0005433449603	30401	Economy	3700.00
0005433449591	30401	Economy	3700.00
0005433449664	30401	Economy	3700.00
0005433449602	30401	Economy	3700.00
0005433449649	30401	Economy	3700.00
0005433722145	30400	Business	11100.00
0005433123571	30400	Business	11100.00
0005433123586	30400	Business	11100.00
0005433722146	30400	Business	11100.00
0005432720501	30400	Business	11100.00
0005433123609	30400	Economy	3700.00
0005433123580	30400	Economy	3700.00
0005432720455	30400	Economy	4100.00
0005433722152	30400	Economy	4100.00
0005433123593	30400	Economy	4100.00
0005432720429	30400	Economy	3700.00
0005433722141	30400	Economy	3700.00
0005432720572	30400	Economy	3700.00
0005433722149	30400	Economy	3700.00
0005433722142	30400	Economy	3700.00
0005432720500	30400	Economy	3700.00
0005432720453	30400	Economy	3700.00
0005433722144	30400	Economy	3700.00
0005433722151	30400	Economy	3700.00
0005433722150	30400	Economy	3700.00
0005433722153	30400	Economy	3700.00
0005432720450	30400	Economy	3700.00
0005432720571	30400	Economy	3700.00
0005433123581	30400	Economy	3700.00
0005432720475	30400	Economy	3700.00
0005433722148	30400	Economy	3700.00
0005433722143	30400	Economy	3700.00
0005432720446	30400	Economy	3700.00
0005433722154	30400	Economy	3700.00
0005432720454	30400	Economy	3700.00
0005433722147	30400	Economy	3700.00
0005433123587	30400	Economy	3700.00
0005432720464	30400	Economy	3700.00
0005433724758	1361	Business	70400.00
0005434514939	1361	Business	70400.00
0005434513549	1361	Business	70400.00
0005433524913	1361	Business	70400.00
0005434586315	1361	Business	70400.00
0005433192810	1361	Business	70400.00
0005433724756	1361	Business	70400.00
0005433524918	1361	Business	70400.00
0005434586316	1361	Economy	23500.00
0005434586339	1361	Economy	23500.00
0005433524912	1361	Economy	25800.00
0005434586328	1361	Economy	25800.00
0005434586319	1361	Economy	23500.00
0005432270973	1361	Economy	23500.00
0005434586329	1361	Economy	23500.00
0005434586317	1361	Economy	23500.00
0005433524919	1361	Economy	23500.00
0005434586333	1361	Economy	23500.00
0005434586335	1361	Economy	23500.00
0005434586331	1361	Economy	23500.00
0005434586340	1361	Economy	23500.00
0005434586324	1361	Economy	23500.00
0005433524916	1361	Economy	23500.00
0005434586318	1361	Economy	23500.00
0005434586320	1361	Economy	23500.00
0005432270972	1361	Economy	23500.00
0005434514937	1361	Economy	23500.00
0005434586332	1361	Economy	23500.00
0005434586334	1361	Economy	23500.00
0005434513550	1361	Economy	23500.00
0005433724754	1361	Economy	23500.00
0005433524920	1361	Economy	23500.00
0005434586338	1361	Economy	23500.00
0005433192809	1361	Economy	23500.00
0005434586337	1361	Economy	23500.00
0005433524921	1361	Economy	23500.00
0005434514938	1361	Economy	23500.00
0005434586326	1361	Economy	23500.00
0005434586336	1361	Economy	23500.00
0005433724757	1361	Economy	23500.00
0005433724753	1361	Economy	23500.00
0005434586323	1361	Economy	23500.00
0005433524914	1361	Economy	23500.00
0005434586322	1361	Economy	23500.00
0005434586321	1361	Economy	23500.00
0005433524917	1361	Economy	23500.00
0005434586330	1361	Economy	23500.00
0005433524922	1361	Economy	23500.00
0005434586325	1361	Economy	23500.00
0005434586314	1361	Economy	23500.00
0005433192814	1361	Economy	23500.00
0005433724755	1361	Economy	23500.00
0005434586327	1361	Economy	23500.00
0005433192813	1361	Economy	23500.00
0005434586341	1361	Economy	23500.00
0005432270971	1361	Economy	23500.00
0005433524915	1361	Economy	23500.00
0005433192891	18498	Business	70400.00
0005433192896	18498	Economy	23500.00
0005433192901	18498	Economy	23500.00
0005432927917	18498	Economy	23500.00
0005434586170	18498	Economy	23500.00
0005433192898	18498	Economy	23500.00
0005433524855	18498	Economy	25800.00
0005433192892	18498	Economy	23500.00
0005433192903	18498	Economy	23500.00
0005433192893	18498	Economy	23500.00
0005433192897	18498	Economy	23500.00
0005433192900	18498	Economy	23500.00
0005433192902	18498	Economy	23500.00
0005432927914	18498	Economy	23500.00
0005432968814	18498	Economy	23500.00
0005432927919	18498	Economy	23500.00
0005434586169	18498	Economy	23500.00
0005433524856	18498	Economy	23500.00
0005432927915	18498	Economy	23500.00
0005433192899	18498	Economy	23500.00
0005433192894	18498	Economy	23500.00
0005432927920	18498	Economy	23500.00
0005432927916	18498	Economy	23500.00
0005432968813	18498	Economy	23500.00
0005434586157	18498	Economy	23500.00
0005433192895	18498	Economy	23500.00
0005432927918	18498	Economy	23500.00
0005434343782	11464	Economy	4300.00
0005434343773	11464	Economy	4300.00
0005434343795	11464	Economy	4300.00
0005434343772	11464	Economy	4000.00
0005434343776	11464	Economy	4000.00
0005434343765	11464	Economy	4000.00
0005434343775	11464	Economy	4000.00
0005434142567	11464	Economy	4000.00
0005434343768	11464	Economy	4000.00
0005434343787	11464	Economy	4000.00
0005434343793	11464	Economy	4000.00
0005434343763	11464	Economy	4000.00
0005434343783	11464	Economy	4000.00
0005434343771	11464	Economy	4000.00
0005434343777	11464	Economy	4000.00
0005434343791	11464	Economy	4000.00
0005434142565	11464	Economy	4000.00
0005434343779	11464	Economy	4000.00
0005434343790	11464	Economy	4000.00
0005434343798	11464	Economy	4000.00
0005434343794	11464	Economy	4000.00
0005434343792	11464	Economy	4000.00
0005434343774	11464	Economy	4000.00
0005434142568	11464	Economy	4000.00
0005434343784	11464	Economy	4000.00
0005434343789	11464	Economy	4000.00
0005434343761	11464	Economy	4000.00
0005434343785	11464	Economy	4000.00
0005434343786	11464	Economy	4000.00
0005434343778	11464	Economy	4000.00
0005434343780	11464	Economy	4000.00
0005434343769	11464	Economy	4000.00
0005434343764	11464	Economy	4000.00
0005434343767	11464	Economy	4000.00
0005434343781	11464	Economy	4000.00
0005434343788	11464	Economy	4000.00
0005434142566	11464	Economy	4000.00
0005434343762	11464	Economy	4000.00
0005434343796	11464	Economy	4000.00
0005434343766	11464	Economy	4000.00
0005434343797	11464	Economy	4000.00
0005434343770	11464	Economy	4000.00
0005434343654	29774	Economy	4300.00
0005435304115	29774	Economy	4300.00
0005434343653	29774	Economy	4000.00
0005435304116	29774	Economy	4000.00
0005434343676	29774	Economy	4000.00
0005434142542	29774	Economy	4000.00
0005435304117	29774	Economy	4000.00
0005434343594	29774	Economy	4000.00
0005434142541	29774	Economy	4000.00
0005435824321	1295	Business	199800.00
0005435824319	1295	Business	199800.00
0005433415381	1295	Business	199800.00
0005433415397	1295	Business	199800.00
0005433415452	1295	Business	199800.00
0005435824336	1295	Business	199800.00
0005435824340	1295	Business	199800.00
0005435824339	1295	Business	199800.00
0005433415405	1295	Business	199800.00
0005433415451	1295	Economy	66600.00
0005435824323	1295	Economy	66600.00
0005433415387	1295	Economy	66600.00
0005435824332	1295	Economy	66600.00
0005435824334	1295	Economy	66600.00
0005435824318	1295	Economy	66600.00
0005433415380	1295	Economy	73200.00
0005435824322	1295	Economy	66600.00
0005435824320	1295	Economy	66600.00
0005435824317	1295	Economy	66600.00
0005435824328	1295	Economy	66600.00
0005435824330	1295	Economy	66600.00
0005435824341	1295	Economy	66600.00
0005432284525	1295	Economy	66600.00
0005435824331	1295	Economy	66600.00
0005435824333	1295	Economy	66600.00
0005435824325	1295	Economy	66600.00
0005435824326	1295	Economy	66600.00
0005435824338	1295	Economy	66600.00
0005433415403	1295	Economy	66600.00
0005432284526	1295	Economy	66600.00
0005433415382	1295	Economy	66600.00
0005435824324	1295	Economy	66600.00
0005435824342	1295	Economy	66600.00
0005435824335	1295	Economy	66600.00
0005433415404	1295	Economy	66600.00
0005435824337	1295	Economy	66600.00
0005435824329	1295	Economy	66600.00
0005432284524	1295	Economy	66600.00
0005435824327	1295	Economy	66600.00
0005435824179	17997	Business	199800.00
0005435824162	17997	Business	199800.00
0005433415482	17997	Economy	66600.00
0005435824213	17997	Economy	66600.00
0005435824206	17997	Economy	66600.00
0005433415486	17997	Economy	66600.00
0005435824178	17997	Economy	73200.00
0005433415476	17997	Economy	73200.00
0005435824163	17997	Economy	66600.00
0005433415490	17997	Economy	66600.00
0005433415488	17997	Economy	66600.00
0005433415477	17997	Economy	66600.00
0005433415483	17997	Economy	66600.00
0005433415491	17997	Economy	66600.00
0005433415489	17997	Economy	66600.00
0005435824181	17997	Economy	66600.00
0005433415485	17997	Economy	66600.00
0005433415478	17997	Economy	66600.00
0005435824164	17997	Economy	66600.00
0005433415481	17997	Economy	66600.00
0005433415484	17997	Economy	66600.00
0005433415480	17997	Economy	66600.00
0005433415487	17997	Economy	66600.00
0005435824176	17997	Economy	66600.00
0005433415479	17997	Economy	66600.00
0005435824177	17997	Economy	66600.00
0005434460467	17525	Economy	13500.00
0005432783194	5621	Business	27800.00
0005432783185	5621	Business	27800.00
0005432783200	5621	Business	27800.00
0005432143953	5621	Business	27800.00
0005432783218	5621	Economy	9300.00
0005432783181	5621	Economy	9300.00
0005432783213	5621	Economy	9300.00
0005432783187	5621	Economy	9300.00
0005432783212	5621	Economy	9300.00
0005432783208	5621	Economy	9300.00
0005432783197	5621	Economy	10200.00
0005432783209	5621	Economy	10200.00
0005432783178	5621	Economy	10200.00
0005432783174	5621	Economy	9300.00
0005432783220	5621	Economy	9300.00
0005432783211	5621	Economy	9300.00
0005432783217	5621	Economy	9300.00
0005432783214	5621	Economy	9300.00
0005432783222	5621	Economy	9300.00
0005432783182	5621	Economy	9300.00
0005432783221	5621	Economy	9300.00
0005432783183	5621	Economy	9300.00
0005432783201	5621	Economy	9300.00
0005432783198	5621	Economy	9300.00
0005432783170	5621	Economy	9300.00
0005432783219	5621	Economy	9300.00
0005432783184	5621	Economy	9300.00
0005432143951	5621	Economy	9300.00
0005432783192	5621	Economy	9300.00
0005432783224	5621	Economy	9300.00
0005432783172	5621	Economy	9300.00
0005432143949	5621	Economy	9300.00
0005432783175	5621	Economy	9300.00
0005432783207	5621	Economy	9300.00
0005432783216	5621	Economy	9300.00
0005432783171	5621	Economy	9300.00
0005432783210	5621	Economy	9300.00
0005432783195	5621	Economy	9300.00
0005432783223	5621	Economy	9300.00
0005432783189	5621	Economy	9300.00
0005432783204	5621	Economy	9300.00
0005432783180	5621	Economy	9300.00
0005432783203	5621	Economy	9300.00
0005432783191	5621	Economy	9300.00
0005432783199	5621	Economy	9300.00
0005432783193	5621	Economy	9300.00
0005432143952	5621	Economy	9300.00
0005432783176	5621	Economy	9300.00
0005432143950	5621	Economy	9300.00
0005432783202	5621	Economy	9300.00
0005432783190	5621	Economy	9300.00
0005432783188	5621	Economy	9300.00
0005432783186	5621	Economy	9300.00
0005432783196	5621	Economy	9300.00
0005432783169	5621	Economy	9300.00
0005432783205	5621	Economy	9300.00
0005432783179	5621	Economy	9300.00
0005432783177	5621	Economy	9300.00
0005432783215	5621	Economy	9300.00
0005432783206	5621	Economy	9300.00
0005432783173	5621	Economy	9300.00
0005432782870	15351	Business	27800.00
0005435242529	15351	Business	27800.00
0005435476687	15351	Business	27800.00
0005435242542	15351	Business	27800.00
0005435476681	15351	Business	27800.00
0005435242538	15351	Economy	9300.00
0005435476688	15351	Economy	9300.00
0005432782890	15351	Economy	9300.00
0005435242534	15351	Economy	9300.00
0005435242532	15351	Economy	10200.00
0005435242547	15351	Economy	10200.00
0005435242527	15351	Economy	9300.00
0005435476684	15351	Economy	9300.00
0005435242548	15351	Economy	9300.00
0005435242543	15351	Economy	9300.00
0005435242544	15351	Economy	9300.00
0005432782844	15351	Economy	9300.00
0005435242540	15351	Economy	9300.00
0005435242533	15351	Economy	9300.00
0005435242546	15351	Economy	9300.00
0005435242550	15351	Economy	9300.00
0005435242552	15351	Economy	9300.00
0005435242535	15351	Economy	9300.00
0005435242553	15351	Economy	9300.00
0005435242539	15351	Economy	9300.00
0005432783022	15351	Economy	9300.00
0005432782847	15351	Economy	9300.00
0005435242531	15351	Economy	9300.00
0005435476686	15351	Economy	9300.00
0005435242537	15351	Economy	9300.00
0005435242536	15351	Economy	9300.00
0005435476685	15351	Economy	9300.00
0005435242545	15351	Economy	9300.00
0005435242541	15351	Economy	9300.00
0005435242551	15351	Economy	9300.00
0005435242530	15351	Economy	9300.00
0005435476682	15351	Economy	9300.00
0005435242528	15351	Economy	9300.00
0005435476683	15351	Economy	9300.00
0005435242549	15351	Economy	9300.00
0005432782869	15351	Economy	9300.00
0005432848149	4374	Economy	7000.00
0005434462765	4374	Economy	6300.00
0005432848145	4374	Economy	6300.00
0005432848148	4374	Economy	6300.00
0005432848153	4374	Economy	6300.00
0005432848144	4374	Economy	6300.00
0005434463904	4374	Economy	6300.00
0005432848158	4374	Economy	6300.00
0005432848150	4374	Economy	6300.00
0005432848156	4374	Economy	6300.00
0005435850767	4374	Economy	6300.00
0005432848151	4374	Economy	6300.00
0005432848154	4374	Economy	6300.00
0005435850774	4374	Economy	6300.00
0005432848152	4374	Economy	6300.00
0005432848157	4374	Economy	6300.00
0005435850757	4374	Economy	6300.00
0005432848155	4374	Economy	6300.00
0005432848146	4374	Economy	6300.00
0005434463905	4374	Economy	6300.00
0005432848147	4374	Economy	6300.00
0005434462766	4374	Economy	6300.00
0005435850807	28868	Economy	6300.00
0005435850808	28868	Economy	6300.00
0005435850809	28868	Economy	6300.00
0005435850805	28868	Economy	6300.00
0005435850813	28868	Economy	6300.00
0005435850812	28868	Economy	6300.00
0005435850811	28868	Economy	6300.00
0005435850810	28868	Economy	6300.00
0005435850806	28868	Economy	6300.00
0005434925468	6330	Business	11900.00
0005434443533	6330	Business	11900.00
0005434925451	6330	Business	11900.00
0005434925469	6330	Business	11900.00
0005434925433	6330	Business	11900.00
0005433496638	6330	Business	11900.00
0005434443532	6330	Business	11900.00
0005434925439	6330	Business	11900.00
0005433496639	6330	Business	11900.00
0005434925448	6330	Business	11900.00
0005434925456	6330	Business	11900.00
0005434925473	6330	Economy	4000.00
0005434925457	6330	Business	11900.00
0005433496616	6330	Economy	4000.00
0005434925446	6330	Economy	4000.00
0005433496622	6330	Economy	4000.00
0005434925441	6330	Economy	4000.00
0005434925444	6330	Economy	4000.00
0005434443536	6330	Economy	4000.00
0005434443535	6330	Economy	4000.00
0005433496640	6330	Economy	4000.00
0005434925452	6330	Economy	4400.00
0005432075190	6330	Economy	4400.00
0005433496614	6330	Economy	4400.00
0005433496615	6330	Economy	4400.00
0005434925437	6330	Economy	4000.00
0005433496630	6330	Economy	4000.00
0005434925466	6330	Economy	4000.00
0005433496618	6330	Economy	4000.00
0005434443524	6330	Economy	4000.00
0005432075192	6330	Economy	4000.00
0005434925471	6330	Economy	4000.00
0005433496613	6330	Economy	4000.00
0005434443534	6330	Economy	4000.00
0005434443525	6330	Economy	4000.00
0005434925435	6330	Economy	4000.00
0005434925447	6330	Economy	4000.00
0005434443523	6330	Economy	4000.00
0005434925450	6330	Economy	4000.00
0005434925434	6330	Economy	4000.00
0005433496625	6330	Economy	4000.00
0005434443538	6330	Economy	4000.00
0005433496619	6330	Economy	4000.00
0005434925463	6330	Economy	4000.00
0005434925462	6330	Economy	4000.00
0005434925472	6330	Economy	4000.00
0005434925461	6330	Economy	4000.00
0005433496633	6330	Economy	4000.00
0005434925458	6330	Economy	4000.00
0005432075193	6330	Economy	4000.00
0005434925459	6330	Economy	4000.00
0005434925436	6330	Economy	4000.00
0005433496636	6330	Economy	4000.00
0005434925453	6330	Economy	4000.00
0005433496621	6330	Economy	4000.00
0005433496620	6330	Economy	4000.00
0005434925443	6330	Economy	4000.00
0005433496635	6330	Economy	4000.00
0005433496632	6330	Economy	4000.00
0005434443526	6330	Economy	4000.00
0005434443537	6330	Economy	4000.00
0005434925470	6330	Economy	4000.00
0005434925438	6330	Economy	4000.00
0005433496624	6330	Economy	4000.00
0005433496641	6330	Economy	4000.00
0005434443529	6330	Economy	4000.00
0005432075191	6330	Economy	4000.00
0005433496626	6330	Economy	4000.00
0005434443522	6330	Economy	4000.00
0005433496628	6330	Economy	4000.00
0005434443530	6330	Economy	4000.00
0005433496617	6330	Economy	4000.00
0005433496627	6330	Economy	4000.00
0005434925464	6330	Economy	4000.00
0005434443527	6330	Economy	4000.00
0005433496637	6330	Economy	4000.00
0005434925460	6330	Economy	4000.00
0005434925455	6330	Economy	4000.00
0005434443531	6330	Economy	4000.00
0005434925442	6330	Economy	4000.00
0005433496629	6330	Economy	4000.00
0005434925467	6330	Economy	4000.00
0005434925440	6330	Economy	4000.00
0005434443528	6330	Economy	4000.00
0005434925465	6330	Economy	4000.00
0005434925449	6330	Economy	4000.00
0005434925445	6330	Economy	4000.00
0005434925454	6330	Economy	4000.00
0005433496634	6330	Economy	4000.00
0005433496623	6330	Economy	4000.00
0005433496631	6330	Economy	4000.00
0005433496494	20385	Business	11900.00
0005433496434	20385	Business	11900.00
0005433496418	20385	Business	11900.00
0005433496490	20385	Business	11900.00
0005433496451	20385	Economy	4000.00
0005433496448	20385	Economy	4400.00
0005433496433	20385	Economy	4400.00
0005433496491	20385	Economy	4000.00
0005433496492	20385	Economy	4000.00
0005433496449	20385	Economy	4000.00
0005433496419	20385	Economy	4000.00
0005433496432	20385	Economy	4000.00
0005433496450	20385	Economy	4000.00
0005433496452	20385	Economy	4000.00
0005433496464	20385	Economy	4000.00
0005433496445	20385	Economy	4000.00
0005433496453	20385	Economy	4000.00
0005433496503	20385	Economy	4000.00
0005433496495	20385	Economy	4000.00
0005433496486	20385	Economy	4000.00
0005435242571	12155	Business	41200.00
0005435242576	12155	Business	41200.00
0005435242561	12155	Business	41200.00
0005432782848	12155	Business	41200.00
0005435242574	12155	Business	41200.00
0005432782904	12155	Economy	13700.00
0005435242558	12155	Economy	13700.00
0005435242577	12155	Economy	13700.00
0005435242555	12155	Economy	13700.00
0005435242570	12155	Economy	13700.00
0005435242567	12155	Economy	15100.00
0005432782879	12155	Economy	13700.00
0005435242557	12155	Economy	13700.00
0005435242573	12155	Economy	13700.00
0005432782911	12155	Economy	13700.00
0005435242568	12155	Economy	13700.00
0005435242565	12155	Economy	13700.00
0005435242580	12155	Economy	13700.00
0005435242572	12155	Economy	13700.00
0005435242569	12155	Economy	13700.00
0005432782868	12155	Economy	13700.00
0005435242563	12155	Economy	13700.00
0005432782899	12155	Economy	13700.00
0005435242559	12155	Economy	13700.00
0005432782902	12155	Economy	13700.00
0005435242578	12155	Economy	13700.00
0005435242556	12155	Economy	13700.00
0005435242562	12155	Economy	13700.00
0005435242581	12155	Economy	13700.00
0005432782885	12155	Economy	13700.00
0005432782849	12155	Economy	13700.00
0005435242564	12155	Economy	13700.00
0005435242554	12155	Economy	13700.00
0005435242579	12155	Economy	13700.00
0005432782955	12155	Economy	13700.00
0005435242575	12155	Economy	13700.00
0005432782880	12155	Economy	13700.00
0005435242566	12155	Economy	13700.00
0005435242560	12155	Economy	13700.00
0005432783132	15406	Business	41200.00
0005432783168	15406	Business	41200.00
0005432783156	15406	Business	41200.00
0005432783127	15406	Business	41200.00
0005432783163	15406	Business	41200.00
0005432783126	15406	Business	41200.00
0005432783116	15406	Business	41200.00
0005432783129	15406	Business	41200.00
0005432783136	15406	Economy	13700.00
0005432783150	15406	Economy	13700.00
0005432783166	15406	Economy	13700.00
0005432783134	15406	Economy	13700.00
0005432783161	15406	Economy	13700.00
0005435242401	15406	Economy	13700.00
0005432783151	15406	Economy	15100.00
0005432783148	15406	Economy	15100.00
0005432783133	15406	Economy	15100.00
0005432783131	15406	Economy	15100.00
0005432783121	15406	Economy	15100.00
0005435242400	15406	Economy	13700.00
0005432783160	15406	Economy	13700.00
0005432783113	15406	Economy	13700.00
0005432783155	15406	Economy	13700.00
0005432783157	15406	Economy	13700.00
0005432783141	15406	Economy	13700.00
0005432783165	15406	Economy	13700.00
0005432783119	15406	Economy	13700.00
0005432783123	15406	Economy	13700.00
0005432783114	15406	Economy	13700.00
0005432783144	15406	Economy	13700.00
0005432783138	15406	Economy	13700.00
0005432783159	15406	Economy	13700.00
0005432783146	15406	Economy	13700.00
0005432783143	15406	Economy	13700.00
0005432783135	15406	Economy	13700.00
0005432783162	15406	Economy	13700.00
0005432783130	15406	Economy	13700.00
0005432783149	15406	Economy	13700.00
0005432783154	15406	Economy	13700.00
0005432783140	15406	Economy	13700.00
0005432783128	15406	Economy	13700.00
0005432783153	15406	Economy	13700.00
0005432783117	15406	Economy	13700.00
0005432783158	15406	Economy	13700.00
0005432783147	15406	Economy	13700.00
0005432783122	15406	Economy	13700.00
0005432783164	15406	Economy	13700.00
0005432783137	15406	Economy	13700.00
0005432783145	15406	Economy	13700.00
0005432783125	15406	Economy	13700.00
0005432783124	15406	Economy	13700.00
0005432783139	15406	Economy	13700.00
0005432783142	15406	Economy	13700.00
0005432783120	15406	Economy	13700.00
0005432783167	15406	Economy	13700.00
0005432783118	15406	Economy	13700.00
0005432783115	15406	Economy	13700.00
0005432783152	15406	Economy	13700.00
0005434876784	10082	Business	49700.00
0005434876574	10082	Business	49700.00
0005434876611	10082	Business	49700.00
0005434876581	10082	Business	49700.00
0005434876626	10082	Business	49700.00
0005434876630	10082	Economy	16600.00
0005434876625	10082	Economy	16600.00
0005434876571	10082	Economy	18200.00
0005434876588	10082	Economy	18200.00
0005435913889	10082	Economy	18200.00
0005434876575	10082	Economy	16600.00
0005434876586	10082	Economy	16600.00
0005434876606	10082	Economy	16600.00
0005434876686	10082	Economy	16600.00
0005434876576	10082	Economy	16600.00
0005434876582	10082	Economy	16600.00
0005434910083	10082	Economy	16600.00
0005435913891	10082	Economy	16600.00
0005435913890	10082	Economy	16600.00
0005434876632	10082	Economy	16600.00
0005434876617	10082	Economy	16600.00
0005434876782	10082	Economy	16600.00
0005434876556	10082	Economy	16600.00
0005434876717	10082	Economy	16600.00
0005434876650	10082	Economy	16600.00
0005434876555	10082	Economy	16600.00
0005435913892	10082	Economy	16600.00
0005434876783	10082	Economy	16600.00
0005434910082	10082	Economy	16600.00
0005434877177	14639	Business	49700.00
0005434877153	14639	Business	49700.00
0005434877218	14639	Business	49700.00
0005434877179	14639	Business	49700.00
0005434877156	14639	Business	49700.00
0005434877164	14639	Business	49700.00
0005434877186	14639	Business	49700.00
0005434877233	14639	Business	49700.00
0005434877165	14639	Business	49700.00
0005434877228	14639	Business	49700.00
0005434877170	14639	Business	49700.00
0005434877195	14639	Business	49700.00
0005434877173	14639	Business	49700.00
0005434877152	14639	Business	49700.00
0005434877140	14639	Business	49700.00
0005434877219	14639	Business	49700.00
0005434877220	14639	Business	49700.00
0005434877146	14639	Business	49700.00
0005434877151	14639	Business	49700.00
0005434877182	14639	Economy	16600.00
0005434877138	14639	Business	49700.00
0005434877192	14639	Economy	16600.00
0005434877141	14639	Economy	16600.00
0005434877174	14639	Economy	16600.00
0005434877162	14639	Economy	16600.00
0005434877193	14639	Economy	16600.00
0005434877163	14639	Economy	16600.00
0005434877178	14639	Economy	16600.00
0005434877148	14639	Economy	16600.00
0005434877230	14639	Economy	16600.00
0005434877227	14639	Economy	16600.00
0005434877181	14639	Economy	18200.00
0005434877185	14639	Economy	18200.00
0005434877229	14639	Economy	18200.00
0005434877231	14639	Economy	16600.00
0005434877159	14639	Economy	18200.00
0005434877171	14639	Economy	16600.00
0005434758867	14639	Economy	16600.00
0005434877224	14639	Economy	16600.00
0005434877143	14639	Economy	16600.00
0005434877226	14639	Economy	16600.00
0005434877225	14639	Economy	16600.00
0005434877212	14639	Economy	16600.00
0005434877150	14639	Economy	16600.00
0005434877202	14639	Economy	16600.00
0005434910070	14639	Economy	16600.00
0005434877184	14639	Economy	16600.00
0005434877203	14639	Economy	16600.00
0005434877155	14639	Economy	16600.00
0005434877208	14639	Economy	16600.00
0005434877169	14639	Economy	16600.00
0005434877175	14639	Economy	16600.00
0005434877172	14639	Economy	16600.00
0005434877216	14639	Economy	16600.00
0005434877161	14639	Economy	16600.00
0005434877222	14639	Economy	16600.00
0005434910069	14639	Economy	16600.00
0005434877194	14639	Economy	16600.00
0005434877196	14639	Economy	16600.00
0005434877139	14639	Economy	16600.00
0005434877215	14639	Economy	16600.00
0005434877210	14639	Economy	16600.00
0005434877149	14639	Economy	16600.00
0005434877168	14639	Economy	16600.00
0005434877223	14639	Economy	16600.00
0005434877166	14639	Economy	16600.00
0005434877200	14639	Economy	16600.00
0005434877189	14639	Economy	16600.00
0005434877232	14639	Economy	16600.00
0005434877157	14639	Economy	16600.00
0005434877158	14639	Economy	16600.00
0005434877217	14639	Economy	16600.00
0005434877199	14639	Economy	16600.00
0005434877213	14639	Economy	16600.00
0005434877206	14639	Economy	16600.00
0005434877147	14639	Economy	16600.00
0005434877221	14639	Economy	16600.00
0005434877187	14639	Economy	16600.00
0005434877142	14639	Economy	16600.00
0005434877160	14639	Economy	16600.00
0005434877167	14639	Economy	16600.00
0005434877183	14639	Economy	16600.00
0005434877211	14639	Economy	16600.00
0005434877145	14639	Economy	16600.00
0005434877154	14639	Economy	16600.00
0005434877205	14639	Economy	16600.00
0005434877176	14639	Economy	16600.00
0005434877207	14639	Economy	16600.00
0005434877197	14639	Economy	16600.00
0005434877188	14639	Economy	16600.00
0005434877201	14639	Economy	16600.00
0005434877191	14639	Economy	16600.00
0005434877144	14639	Economy	16600.00
0005434877198	14639	Economy	16600.00
0005434758866	14639	Economy	16600.00
0005434877234	14639	Economy	16600.00
0005434877204	14639	Economy	16600.00
0005434877180	14639	Economy	16600.00
0005434877209	14639	Economy	16600.00
0005434877214	14639	Economy	16600.00
0005434877190	14639	Economy	16600.00
0005435660008	9267	Economy	22400.00
0005435660014	9267	Economy	22400.00
0005435660013	9267	Economy	22400.00
0005434251797	9267	Economy	20300.00
0005435660011	9267	Economy	20300.00
0005435660006	9267	Economy	20300.00
0005434251811	9267	Economy	20300.00
0005435660012	9267	Economy	20300.00
0005435660009	9267	Economy	20300.00
0005435660010	9267	Economy	20300.00
0005435660015	9267	Economy	20300.00
0005435660007	9267	Economy	20300.00
0005435660016	9267	Economy	20300.00
0005434251858	24651	Economy	22400.00
0005434251857	24651	Economy	20300.00
0005434251862	24651	Economy	20300.00
0005434251859	24651	Economy	20300.00
0005434251855	24651	Economy	20300.00
0005434251856	24651	Economy	20300.00
0005434251860	24651	Economy	20300.00
0005434251861	24651	Economy	20300.00
0005433680016	2818	Business	33000.00
0005433680032	2818	Business	33000.00
0005433680019	2818	Business	33000.00
0005433680028	2818	Business	33000.00
0005432222720	2818	Business	33000.00
0005433680033	2818	Business	33000.00
0005433680009	2818	Business	33000.00
0005433680037	2818	Business	33000.00
0005432966525	2818	Business	33000.00
0005433680047	2818	Business	33000.00
0005433680039	2818	Business	33000.00
0005433680003	2818	Economy	11000.00
0005433680051	2818	Economy	11000.00
0005433684396	2818	Economy	11000.00
0005432222721	2818	Economy	11000.00
0005433680036	2818	Economy	11000.00
0005433680035	2818	Economy	11000.00
0005433680024	2818	Economy	11000.00
0005433680011	2818	Economy	12100.00
0005433680029	2818	Economy	11000.00
0005433680030	2818	Economy	11000.00
0005432222722	2818	Economy	11000.00
0005433684395	2818	Economy	11000.00
0005432966536	2818	Economy	11000.00
0005433680040	2818	Economy	11000.00
0005433680045	2818	Economy	11000.00
0005433680048	2818	Economy	11000.00
0005433680026	2818	Economy	11000.00
0005433680012	2818	Economy	11000.00
0005432966526	2818	Economy	11000.00
0005433680023	2818	Economy	11000.00
0005433680020	2818	Economy	11000.00
0005433680046	2818	Economy	11000.00
0005433680027	2818	Economy	11000.00
0005433680021	2818	Economy	11000.00
0005433680043	2818	Economy	11000.00
0005433680031	2818	Economy	11000.00
0005432222723	2818	Economy	11000.00
0005432222724	2818	Economy	11000.00
0005433680008	2818	Economy	11000.00
0005433680044	2818	Economy	11000.00
0005433680007	2818	Economy	11000.00
0005433680005	2818	Economy	11000.00
0005433680034	2818	Economy	11000.00
0005433680013	2818	Economy	11000.00
0005433680018	2818	Economy	11000.00
0005433680050	2818	Economy	11000.00
0005433680042	2818	Economy	11000.00
0005433680014	2818	Economy	11000.00
0005432222725	2818	Economy	11000.00
0005433680006	2818	Economy	11000.00
0005433680041	2818	Economy	11000.00
0005433680038	2818	Economy	11000.00
0005433680022	2818	Economy	11000.00
0005432966486	2818	Economy	11000.00
0005433680010	2818	Economy	11000.00
0005433680049	2818	Economy	11000.00
0005433680025	2818	Economy	11000.00
0005433680004	2818	Economy	11000.00
0005433680017	2818	Economy	11000.00
0005433680015	2818	Economy	11000.00
0005433679711	29151	Business	33000.00
0005432966644	29151	Business	33000.00
0005432966661	29151	Business	33000.00
0005432966660	29151	Business	33000.00
0005433679746	29151	Business	33000.00
0005432966653	29151	Business	33000.00
0005432966643	29151	Business	33000.00
0005433679723	29151	Business	33000.00
0005432966639	29151	Business	33000.00
0005432966652	29151	Economy	11000.00
0005432966655	29151	Economy	11000.00
0005433679734	29151	Economy	11000.00
0005432005183	29151	Economy	11000.00
0005433679791	29151	Economy	11000.00
0005432966640	29151	Economy	12100.00
0005433679762	29151	Economy	12100.00
0005433679745	29151	Economy	11000.00
0005432966659	29151	Economy	11000.00
0005432966636	29151	Economy	11000.00
0005432966642	29151	Economy	11000.00
0005432966641	29151	Economy	11000.00
0005432966646	29151	Economy	11000.00
0005433679735	29151	Economy	11000.00
0005432966662	29151	Economy	11000.00
0005433679755	29151	Economy	11000.00
0005432966657	29151	Economy	11000.00
0005433679744	29151	Economy	11000.00
0005432966638	29151	Economy	11000.00
0005433679736	29151	Economy	11000.00
0005432966648	29151	Economy	11000.00
0005432966650	29151	Economy	11000.00
0005432966645	29151	Economy	11000.00
0005432966651	29151	Economy	11000.00
0005433679826	29151	Economy	11000.00
0005433679756	29151	Economy	11000.00
0005433679757	29151	Economy	11000.00
0005432966654	29151	Economy	11000.00
0005433679844	29151	Economy	11000.00
0005433684389	29151	Economy	11000.00
0005433679716	29151	Economy	11000.00
0005432005180	29151	Economy	11000.00
0005432966658	29151	Economy	11000.00
0005433679843	29151	Economy	11000.00
0005432966647	29151	Economy	11000.00
0005433679722	29151	Economy	11000.00
0005433679852	29151	Economy	11000.00
0005433679754	29151	Economy	11000.00
0005432005181	29151	Economy	11000.00
0005433679803	29151	Economy	11000.00
0005432005182	29151	Economy	11000.00
0005432966637	29151	Economy	11000.00
0005432966649	29151	Economy	11000.00
0005432966656	29151	Economy	11000.00
0005433633389	9328	Business	132900.00
0005433633412	9328	Business	132900.00
0005433577657	9328	Business	132900.00
0005433613824	9328	Business	132900.00
0005433613794	9328	Business	132900.00
0005433613809	9328	Business	132900.00
0005433577644	9328	Business	132900.00
0005433613781	9328	Business	132900.00
0005433613802	9328	Business	132900.00
0005433613821	9328	Business	132900.00
0005433613828	9328	Business	132900.00
0005433633411	9328	Business	132900.00
0005433633402	9328	Business	132900.00
0005433633398	9328	Business	132900.00
0005433613810	9328	Business	132900.00
0005432756809	9328	Business	132900.00
0005433633401	9328	Business	132900.00
0005432755036	9328	Business	132900.00
0005433633406	9328	Business	132900.00
0005433633397	9328	Business	132900.00
0005433633419	9328	Business	132900.00
0005433613769	9328	Business	132900.00
0005433613831	9328	Business	132900.00
0005433613811	9328	Economy	48700.00
0005433613779	9328	Economy	48700.00
0005432145086	9328	Economy	48700.00
0005433613806	9328	Economy	48700.00
0005433613804	9328	Economy	44300.00
0005433613774	9328	Economy	44300.00
0005433577653	9328	Economy	44300.00
0005433633414	9328	Economy	44300.00
0005433613787	9328	Economy	44300.00
0005433613782	9328	Economy	44300.00
0005433633400	9328	Economy	44300.00
0005433613826	9328	Economy	44300.00
0005433613788	9328	Economy	44300.00
0005433633399	9328	Economy	44300.00
0005433613815	9328	Economy	44300.00
0005433633421	9328	Economy	44300.00
0005433613796	9328	Economy	44300.00
0005433633407	9328	Economy	44300.00
0005433577656	9328	Economy	44300.00
0005433613833	9328	Economy	44300.00
0005433613797	9328	Economy	44300.00
0005433613814	9328	Economy	44300.00
0005432145087	9328	Economy	44300.00
0005433613784	9328	Economy	44300.00
0005433633420	9328	Economy	44300.00
0005434163473	9328	Economy	44300.00
0005433613813	9328	Economy	44300.00
0005432755035	9328	Economy	44300.00
0005433613827	9328	Economy	44300.00
0005433577650	9328	Economy	44300.00
0005433613798	9328	Economy	44300.00
0005433633388	9328	Economy	44300.00
0005433633405	9328	Economy	44300.00
0005433613834	9328	Economy	44300.00
0005434163472	9328	Economy	44300.00
0005433613808	9328	Economy	44300.00
0005433633403	9328	Economy	44300.00
0005433613770	9328	Economy	44300.00
0005433633404	9328	Economy	44300.00
0005433577652	9328	Economy	44300.00
0005433613767	9328	Economy	44300.00
0005433613762	9328	Economy	44300.00
0005433613792	9328	Economy	44300.00
0005433613818	9328	Economy	44300.00
0005433633418	9328	Economy	44300.00
0005433613790	9328	Economy	44300.00
0005433613807	9328	Economy	44300.00
0005433613800	9328	Economy	44300.00
0005433613822	9328	Economy	48700.00
0005432756808	9328	Economy	48700.00
0005433613799	9328	Economy	48700.00
0005433613832	9328	Economy	48700.00
0005433577658	9328	Economy	48700.00
0005433613829	9328	Economy	44300.00
0005434163459	9328	Economy	44300.00
0005433633417	9328	Economy	48700.00
0005433613778	9328	Economy	44300.00
0005433613819	9328	Economy	44300.00
0005433613771	9328	Economy	44300.00
0005433613791	9328	Economy	44300.00
0005433613820	9328	Economy	44300.00
0005432756810	9328	Economy	44300.00
0005433613823	9328	Economy	44300.00
0005433577647	9328	Economy	44300.00
0005433613805	9328	Economy	44300.00
0005433613775	9328	Economy	44300.00
0005433613766	9328	Economy	44300.00
0005433613765	9328	Economy	44300.00
0005433613761	9328	Economy	44300.00
0005433577645	9328	Economy	44300.00
0005433633396	9328	Economy	44300.00
0005432755037	9328	Economy	44300.00
0005433577651	9328	Economy	44300.00
0005433613803	9328	Economy	44300.00
0005433613764	9328	Economy	44300.00
0005433613776	9328	Economy	44300.00
0005433613785	9328	Economy	44300.00
0005433633390	9328	Economy	44300.00
0005433613789	9328	Economy	44300.00
0005433613763	9328	Economy	44300.00
0005433613772	9328	Economy	44300.00
0005433613825	9328	Economy	44300.00
0005433633408	9328	Economy	44300.00
0005433577654	9328	Economy	44300.00
0005432755038	9328	Economy	44300.00
0005433613816	9328	Economy	44300.00
0005433577646	9328	Economy	44300.00
0005433633416	9328	Economy	44300.00
0005433613812	9328	Economy	44300.00
0005433633395	9328	Economy	44300.00
0005433633410	9328	Economy	44300.00
0005433633413	9328	Economy	44300.00
0005433613773	9328	Economy	44300.00
0005433613801	9328	Economy	44300.00
0005433633415	9328	Economy	44300.00
0005433577649	9328	Economy	44300.00
0005433613777	9328	Economy	44300.00
0005433633391	9328	Economy	44300.00
0005433613830	9328	Economy	44300.00
0005433577648	9328	Economy	44300.00
0005433633392	9328	Economy	44300.00
0005433633393	9328	Economy	44300.00
0005433577655	9328	Economy	44300.00
0005433613793	9328	Economy	44300.00
0005433613783	9328	Economy	44300.00
0005433613786	9328	Economy	44300.00
0005433613817	9328	Economy	44300.00
0005433613768	9328	Economy	44300.00
0005433613795	9328	Economy	44300.00
0005433577643	9328	Economy	44300.00
0005433613780	9328	Economy	44300.00
0005433633409	9328	Economy	44300.00
0005433633394	9328	Economy	44300.00
0005434163524	25220	Business	132900.00
0005434163521	25220	Business	132900.00
0005433613398	25220	Business	132900.00
0005433633246	25220	Business	132900.00
0005434272173	25220	Business	132900.00
0005433633213	25220	Business	132900.00
0005433633233	25220	Economy	48700.00
0005434163516	25220	Economy	48700.00
0005433613424	25220	Economy	48700.00
0005434163517	25220	Economy	44300.00
0005433633215	25220	Economy	44300.00
0005434163519	25220	Economy	44300.00
0005433577565	25220	Economy	44300.00
0005433633214	25220	Economy	44300.00
0005433577571	25220	Economy	44300.00
0005433577572	25220	Economy	44300.00
0005433613439	25220	Economy	44300.00
0005434273058	25220	Economy	44300.00
0005434163523	25220	Economy	44300.00
0005433613452	25220	Economy	44300.00
0005433613520	25220	Economy	44300.00
0005433633232	25220	Economy	48700.00
0005434273057	25220	Economy	44300.00
0005434163515	25220	Economy	44300.00
0005433613451	25220	Economy	44300.00
0005434163522	25220	Economy	44300.00
0005434163520	25220	Economy	44300.00
0005434163518	25220	Economy	44300.00
0005434272172	25220	Economy	44300.00
0005433577579	25220	Economy	44300.00
0005433613490	25220	Economy	44300.00
0005433577566	25220	Economy	44300.00
0005434163514	25220	Economy	44300.00
0005433613397	25220	Economy	44300.00
0005433577573	25220	Economy	44300.00
0005433613459	25220	Economy	44300.00
0005435986683	4219	Business	193100.00
0005435947012	4219	Business	193100.00
0005435986691	4219	Business	193100.00
0005432184919	4219	Business	193100.00
0005435947007	4219	Economy	64400.00
0005435986692	4219	Economy	64400.00
0005435986689	4219	Economy	64400.00
0005435986693	4219	Economy	64400.00
0005432184917	4219	Economy	64400.00
0005435947021	4219	Economy	64400.00
0005435947022	4219	Economy	64400.00
0005435986690	4219	Economy	64400.00
0005432184918	4219	Economy	70800.00
0005435986685	4219	Economy	64400.00
0005435986688	4219	Economy	64400.00
0005435986686	4219	Economy	64400.00
0005435986684	4219	Economy	64400.00
0005435947020	4219	Economy	64400.00
0005432184920	4219	Economy	64400.00
0005435986687	4219	Economy	64400.00
0005435946996	4219	Economy	64400.00
0005435947095	26616	Business	193100.00
0005432571280	26616	Business	193100.00
0005435947099	26616	Business	193100.00
0005435787331	26616	Business	193100.00
0005435947092	26616	Business	193100.00
0005435856157	26616	Economy	70800.00
0005432571283	26616	Economy	64400.00
0005435947093	26616	Economy	64400.00
0005435947090	26616	Economy	64400.00
0005435947101	26616	Economy	64400.00
0005435947089	26616	Economy	64400.00
0005435947098	26616	Economy	64400.00
0005435856155	26616	Economy	64400.00
0005435787330	26616	Economy	64400.00
0005435947094	26616	Economy	64400.00
0005435947086	26616	Economy	64400.00
0005435947096	26616	Economy	64400.00
0005435947088	26616	Economy	64400.00
0005435856156	26616	Economy	64400.00
0005432571281	26616	Economy	64400.00
0005435947097	26616	Economy	64400.00
0005435856158	26616	Economy	64400.00
0005435947091	26616	Economy	64400.00
0005435856159	26616	Economy	64400.00
0005435947087	26616	Economy	64400.00
0005432571282	26616	Economy	64400.00
0005435947100	26616	Economy	64400.00
0005433074199	333	Business	21500.00
0005433568396	333	Business	21500.00
0005432947774	333	Business	21500.00
0005433568402	333	Business	21500.00
0005433568414	333	Business	21500.00
0005433568415	333	Business	21500.00
0005433568411	333	Business	21500.00
0005433568397	333	Business	21500.00
0005432947773	333	Business	21500.00
0005433568419	333	Business	21500.00
0005432238870	333	Business	21500.00
0005433568391	333	Business	21500.00
0005433568385	333	Economy	7900.00
0005433568420	333	Economy	7900.00
0005433134057	333	Economy	7900.00
0005433568390	333	Economy	7200.00
0005433074201	333	Economy	7200.00
0005433568379	333	Economy	7200.00
0005433074234	333	Economy	7200.00
0005433568413	333	Economy	7200.00
0005433568386	333	Economy	7200.00
0005433568410	333	Economy	7200.00
0005433074210	333	Economy	7200.00
0005433568412	333	Economy	7200.00
0005433568406	333	Economy	7200.00
0005432947826	333	Economy	7200.00
0005432238868	333	Economy	7200.00
0005433568388	333	Economy	7200.00
0005433568375	333	Economy	7200.00
0005433568404	333	Economy	7200.00
0005433568374	333	Economy	7200.00
0005432238867	333	Economy	7200.00
0005433568376	333	Economy	7200.00
0005433568398	333	Economy	7200.00
0005432238866	333	Economy	7200.00
0005433568381	333	Economy	7200.00
0005433568399	333	Economy	7200.00
0005433568403	333	Economy	7200.00
0005433568382	333	Economy	7200.00
0005433568408	333	Economy	7200.00
0005433568416	333	Economy	7200.00
0005432238864	333	Economy	7200.00
0005433568394	333	Economy	7200.00
0005433074200	333	Economy	7200.00
0005432947798	333	Economy	7200.00
0005432238865	333	Economy	7200.00
0005433568383	333	Economy	7200.00
0005433568407	333	Economy	7200.00
0005433074205	333	Economy	7200.00
0005433568409	333	Economy	7200.00
0005432238869	333	Economy	7200.00
0005433568417	333	Economy	7200.00
0005433568378	333	Economy	7200.00
0005432947812	333	Economy	7200.00
0005433568387	333	Economy	7200.00
0005433568389	333	Economy	7200.00
0005433568422	333	Economy	7200.00
0005432947830	333	Economy	7200.00
0005433568421	333	Economy	7200.00
0005433568384	333	Economy	7200.00
0005433568392	333	Economy	7200.00
0005433568377	333	Economy	7200.00
0005433074238	333	Economy	7200.00
0005433568400	333	Economy	7200.00
0005433568405	333	Economy	7200.00
0005433568393	333	Economy	7200.00
0005433568418	333	Economy	7200.00
0005433568401	333	Economy	7200.00
0005433568380	333	Economy	7200.00
0005433568395	333	Economy	7200.00
0005432948005	11592	Business	21500.00
0005433131658	11592	Business	21500.00
0005433074379	11592	Business	21500.00
0005432948010	11592	Business	21500.00
0005433074377	11592	Business	21500.00
0005433074381	11592	Business	21500.00
0005432948012	11592	Business	21500.00
0005432948000	11592	Business	21500.00
0005433074380	11592	Business	21500.00
0005433131657	11592	Business	21500.00
0005432947972	11592	Business	21500.00
0005432947997	11592	Business	21500.00
0005433074397	11592	Business	21500.00
0005433074395	11592	Business	21500.00
0005433074387	11592	Business	21500.00
0005433074376	11592	Business	21500.00
0005432947976	11592	Business	21500.00
0005433074386	11592	Business	21500.00
0005433074378	11592	Economy	7900.00
0005433131655	11592	Economy	7900.00
0005433134086	11592	Economy	7900.00
0005433131656	11592	Economy	7200.00
0005432192283	11592	Economy	7200.00
0005433074382	11592	Economy	7200.00
0005433074385	11592	Economy	7200.00
0005433074383	11592	Economy	7200.00
0005432947992	11592	Economy	7200.00
0005433074372	11592	Economy	7200.00
0005433131659	11592	Economy	7200.00
0005432948004	11592	Economy	7200.00
0005432192285	11592	Economy	7200.00
0005432947981	11592	Economy	7200.00
0005433074394	11592	Economy	7200.00
0005432947988	11592	Economy	7200.00
0005432947998	11592	Economy	7200.00
0005432947983	11592	Economy	7200.00
0005432947973	11592	Economy	7200.00
0005432947993	11592	Economy	7200.00
0005432947996	11592	Economy	7200.00
0005433074393	11592	Economy	7200.00
0005433134088	11592	Economy	7200.00
0005433074389	11592	Economy	7200.00
0005432948001	11592	Economy	7200.00
0005433074388	11592	Economy	7200.00
0005433074371	11592	Economy	7200.00
0005433131654	11592	Economy	7200.00
0005432947989	11592	Economy	7200.00
0005433074400	11592	Economy	7200.00
0005432947974	11592	Economy	7200.00
0005432947975	11592	Economy	7200.00
0005432947987	11592	Economy	7900.00
0005433074391	11592	Economy	7200.00
0005433134085	11592	Economy	7900.00
0005433074392	11592	Economy	7900.00
0005432948003	11592	Economy	7200.00
0005432947982	11592	Economy	7200.00
0005432947991	11592	Economy	7200.00
0005433074398	11592	Economy	7200.00
0005432192284	11592	Economy	7200.00
0005432947990	11592	Economy	7200.00
0005432948006	11592	Economy	7200.00
0005433074374	11592	Economy	7200.00
0005433074384	11592	Economy	7200.00
0005433074399	11592	Economy	7200.00
0005432947985	11592	Economy	7200.00
0005433074375	11592	Economy	7200.00
0005432947986	11592	Economy	7200.00
0005433074390	11592	Economy	7200.00
0005432947977	11592	Economy	7200.00
0005432947984	11592	Economy	7200.00
0005433074373	11592	Economy	7200.00
0005432948007	11592	Economy	7200.00
0005432947980	11592	Economy	7200.00
0005432948008	11592	Economy	7200.00
0005433134087	11592	Economy	7200.00
0005432947978	11592	Economy	7200.00
0005432947995	11592	Economy	7200.00
0005432947979	11592	Economy	7200.00
0005433134084	11592	Economy	7200.00
0005432948002	11592	Economy	7200.00
0005432948011	11592	Economy	7200.00
0005432947994	11592	Economy	7200.00
0005432947999	11592	Economy	7200.00
0005432948009	11592	Economy	7200.00
0005433074396	11592	Economy	7200.00
0005433817428	10051	Economy	6300.00
0005433817427	10051	Economy	6300.00
0005433817429	10051	Economy	6300.00
0005433817430	10051	Economy	6300.00
0005434732942	14007	Economy	6300.00
0005434732940	14007	Economy	6300.00
0005433817404	14007	Economy	6300.00
0005434732943	14007	Economy	6300.00
0005434732944	14007	Economy	6300.00
0005434732941	14007	Economy	6300.00
0005432984529	2331	Business	184500.00
0005432655408	2331	Business	184500.00
0005432655407	2331	Business	184500.00
0005435981821	2331	Business	184500.00
0005432984541	2331	Business	184500.00
0005432225990	2331	Business	184500.00
0005433753580	2331	Business	184500.00
0005433753573	2331	Business	184500.00
0005432300196	2331	Business	184500.00
0005433753577	2331	Business	184500.00
0005433766598	2331	Business	184500.00
0005432655405	2331	Business	184500.00
0005433753604	2331	Business	184500.00
0005435981810	2331	Business	184500.00
0005432300198	2331	Business	184500.00
0005433753582	2331	Business	184500.00
0005433753591	2331	Business	184500.00
0005433753598	2331	Business	184500.00
0005435981794	2331	Business	184500.00
0005433753578	2331	Economy	61500.00
0005432869431	2331	Economy	67700.00
0005433766596	2331	Economy	61500.00
0005433753583	2331	Economy	61500.00
0005435981825	2331	Economy	61500.00
0005435981827	2331	Economy	61500.00
0005433753599	2331	Economy	61500.00
0005433753587	2331	Economy	61500.00
0005435981803	2331	Economy	61500.00
0005433753612	2331	Economy	61500.00
0005435981824	2331	Economy	61500.00
0005433753568	2331	Economy	61500.00
0005435981800	2331	Economy	61500.00
0005432300197	2331	Economy	61500.00
0005435981811	2331	Economy	61500.00
0005435981840	2331	Economy	61500.00
0005435981809	2331	Economy	61500.00
0005435981828	2331	Economy	61500.00
0005432300201	2331	Economy	61500.00
0005433764655	2331	Economy	61500.00
0005432869416	2331	Economy	61500.00
0005432984528	2331	Economy	61500.00
0005433753608	2331	Economy	61500.00
0005435981830	2331	Economy	61500.00
0005435981795	2331	Economy	61500.00
0005432655400	2331	Economy	61500.00
0005433753605	2331	Economy	61500.00
0005433753581	2331	Economy	61500.00
0005433753593	2331	Economy	61500.00
0005433753588	2331	Economy	61500.00
0005435981813	2331	Economy	61500.00
0005432225988	2331	Economy	61500.00
0005435981820	2331	Economy	61500.00
0005435981798	2331	Economy	61500.00
0005435981806	2331	Economy	61500.00
0005435981797	2331	Economy	61500.00
0005435981831	2331	Economy	61500.00
0005433753601	2331	Economy	61500.00
0005435981823	2331	Economy	61500.00
0005433753619	2331	Economy	61500.00
0005433766595	2331	Economy	61500.00
0005432655406	2331	Economy	61500.00
0005432655404	2331	Economy	61500.00
0005433753618	2331	Economy	61500.00
0005433753590	2331	Economy	61500.00
0005432225984	2331	Economy	61500.00
0005432984563	2331	Economy	61500.00
0005435981822	2331	Economy	61500.00
0005433753607	2331	Economy	61500.00
0005435981829	2331	Economy	61500.00
0005433753584	2331	Economy	61500.00
0005433753616	2331	Economy	61500.00
0005435981832	2331	Economy	61500.00
0005435981812	2331	Economy	61500.00
0005435981838	2331	Economy	61500.00
0005433764656	2331	Economy	61500.00
0005435981804	2331	Economy	61500.00
0005433753585	2331	Economy	61500.00
0005435981817	2331	Economy	61500.00
0005435981818	2331	Economy	61500.00
0005432225989	2331	Economy	61500.00
0005433753571	2331	Economy	61500.00
0005433753606	2331	Economy	61500.00
0005435981799	2331	Economy	61500.00
0005435981837	2331	Economy	61500.00
0005433753602	2331	Economy	61500.00
0005435981819	2331	Economy	61500.00
0005435981815	2331	Economy	61500.00
0005433753574	2331	Economy	61500.00
0005433753579	2331	Economy	61500.00
0005435981814	2331	Economy	61500.00
0005433753570	2331	Economy	61500.00
0005435981836	2331	Economy	61500.00
0005432300199	2331	Economy	61500.00
0005435981826	2331	Economy	61500.00
0005433753576	2331	Economy	61500.00
0005435981789	2331	Economy	61500.00
0005435981796	2331	Economy	61500.00
0005432300202	2331	Economy	67700.00
0005432225985	2331	Economy	61500.00
0005433434193	2331	Economy	61500.00
0005433753617	2331	Economy	61500.00
0005433753613	2331	Economy	67700.00
0005433766597	2331	Economy	67700.00
0005433753609	2331	Economy	61500.00
0005435981833	2331	Economy	61500.00
0005433753621	2331	Economy	61500.00
0005435981816	2331	Economy	61500.00
0005433753592	2331	Economy	61500.00
0005433753611	2331	Economy	61500.00
0005432225986	2331	Economy	61500.00
0005433753603	2331	Economy	61500.00
0005432984523	2331	Economy	61500.00
0005435981808	2331	Economy	61500.00
0005435981793	2331	Economy	61500.00
0005435981841	2331	Economy	61500.00
0005435981802	2331	Economy	61500.00
0005432655403	2331	Economy	61500.00
0005432984531	2331	Economy	61500.00
0005435981805	2331	Economy	61500.00
0005435981790	2331	Economy	61500.00
0005433753597	2331	Economy	61500.00
0005433753595	2331	Economy	61500.00
0005435981807	2331	Economy	61500.00
0005433753615	2331	Economy	61500.00
0005432984589	2331	Economy	61500.00
0005432655410	2331	Economy	61500.00
0005432300200	2331	Economy	61500.00
0005433753622	2331	Economy	61500.00
0005432655402	2331	Economy	61500.00
0005433753572	2331	Economy	61500.00
0005433764657	2331	Economy	61500.00
0005433753589	2331	Economy	61500.00
0005433753586	2331	Economy	61500.00
0005433753596	2331	Economy	61500.00
0005435981801	2331	Economy	61500.00
0005435981835	2331	Economy	61500.00
0005435981839	2331	Economy	61500.00
0005432869415	2331	Economy	61500.00
0005433753575	2331	Economy	61500.00
0005435981791	2331	Economy	61500.00
0005433753614	2331	Economy	61500.00
0005435981834	2331	Economy	61500.00
0005433753620	2331	Economy	61500.00
0005433753600	2331	Economy	61500.00
0005433753594	2331	Economy	61500.00
0005432225987	2331	Economy	61500.00
0005433753610	2331	Economy	61500.00
0005433753569	2331	Economy	61500.00
0005432655401	2331	Economy	61500.00
0005435981792	2331	Economy	61500.00
0005432655409	2331	Economy	61500.00
0005433753623	2331	Economy	61500.00
0005432984707	26183	Business	184500.00
0005433434368	26183	Business	184500.00
0005433434355	26183	Business	184500.00
0005433753446	26183	Business	184500.00
0005432984724	26183	Business	184500.00
0005433434354	26183	Business	184500.00
0005432984721	26183	Business	184500.00
0005432984715	26183	Business	184500.00
0005433434359	26183	Business	184500.00
0005432984706	26183	Business	184500.00
0005433434377	26183	Business	184500.00
0005434731124	26183	Business	184500.00
0005432984711	26183	Economy	67700.00
0005433434371	26183	Economy	61500.00
0005432869450	26183	Economy	61500.00
0005432051094	26183	Economy	61500.00
0005433753264	26183	Economy	61500.00
0005432049425	26183	Economy	61500.00
0005433753390	26183	Economy	61500.00
0005432984703	26183	Economy	61500.00
0005433753275	26183	Economy	61500.00
0005432984709	26183	Economy	61500.00
0005433434370	26183	Economy	61500.00
0005432984728	26183	Economy	61500.00
0005433434378	26183	Economy	61500.00
0005433434379	26183	Economy	61500.00
0005433434366	26183	Economy	61500.00
0005432984725	26183	Economy	61500.00
0005432051093	26183	Economy	61500.00
0005432869446	26183	Economy	61500.00
0005432984705	26183	Economy	61500.00
0005432984708	26183	Economy	61500.00
0005432984729	26183	Economy	61500.00
0005433434357	26183	Economy	61500.00
0005435981565	26183	Economy	61500.00
0005433434362	26183	Economy	61500.00
0005433753274	26183	Economy	61500.00
0005432984714	26183	Economy	61500.00
0005433434374	26183	Economy	61500.00
0005433753265	26183	Economy	61500.00
0005432869449	26183	Economy	61500.00
0005433434373	26183	Economy	61500.00
0005432869448	26183	Economy	61500.00
0005432984730	26183	Economy	61500.00
0005432984731	26183	Economy	61500.00
0005432984719	26183	Economy	61500.00
0005433434361	26183	Economy	61500.00
0005432984701	26183	Economy	61500.00
0005433753288	26183	Economy	61500.00
0005432984713	26183	Economy	61500.00
0005433434376	26183	Economy	61500.00
0005432049422	26183	Economy	61500.00
0005433434369	26183	Economy	61500.00
0005432984723	26183	Economy	61500.00
0005433753276	26183	Economy	61500.00
0005432984704	26183	Economy	61500.00
0005432984726	26183	Economy	67700.00
0005433434375	26183	Economy	61500.00
0005432984710	26183	Economy	61500.00
0005433434364	26183	Economy	61500.00
0005432869447	26183	Economy	61500.00
0005432051092	26183	Economy	61500.00
0005432049423	26183	Economy	61500.00
0005433753230	26183	Economy	61500.00
0005432984716	26183	Economy	61500.00
0005433434358	26183	Economy	61500.00
0005432984722	26183	Economy	61500.00
0005432984717	26183	Economy	61500.00
0005432984699	26183	Economy	61500.00
0005433434360	26183	Economy	61500.00
0005433434380	26183	Economy	61500.00
0005433753391	26183	Economy	61500.00
0005433753393	26183	Economy	61500.00
0005432984720	26183	Economy	61500.00
0005432984702	26183	Economy	61500.00
0005432984700	26183	Economy	61500.00
0005432984718	26183	Economy	61500.00
0005432049424	26183	Economy	61500.00
0005432984712	26183	Economy	61500.00
0005433434372	26183	Economy	61500.00
0005433434365	26183	Economy	61500.00
0005434731122	26183	Economy	61500.00
0005433434356	26183	Economy	61500.00
0005433434367	26183	Economy	61500.00
0005433434363	26183	Economy	61500.00
0005434731125	26183	Economy	61500.00
0005434731123	26183	Economy	61500.00
0005432984727	26183	Economy	61500.00
0005435981533	26183	Economy	61500.00
0005433150819	1510	Business	38900.00
0005432267819	1510	Business	38900.00
0005434374124	1510	Business	38900.00
0005434374150	1510	Business	38900.00
0005432267817	1510	Economy	13000.00
0005433460411	1510	Economy	13000.00
0005434374132	1510	Economy	13000.00
0005432267822	1510	Economy	13000.00
0005433461564	1510	Economy	13000.00
0005434374146	1510	Economy	13000.00
0005434374154	1510	Economy	13000.00
0005434374138	1510	Economy	13000.00
0005433150896	1510	Economy	13000.00
0005433150812	1510	Economy	13000.00
0005432267824	1510	Economy	13000.00
0005433461563	1510	Economy	13000.00
0005434374131	1510	Economy	13000.00
0005434374139	1510	Economy	13000.00
0005434374130	1510	Economy	13000.00
0005434374126	1510	Economy	14300.00
0005433150813	1510	Economy	14300.00
0005433460412	1510	Economy	14300.00
0005434374143	1510	Economy	13000.00
0005433150814	1510	Economy	13000.00
0005433150811	1510	Economy	13000.00
0005434374133	1510	Economy	13000.00
0005434374151	1510	Economy	13000.00
0005434374141	1510	Economy	13000.00
0005432267818	1510	Economy	13000.00
0005434374144	1510	Economy	13000.00
0005434374152	1510	Economy	13000.00
0005434374135	1510	Economy	13000.00
0005434374149	1510	Economy	13000.00
0005434374153	1510	Economy	13000.00
0005434374134	1510	Economy	13000.00
0005434374140	1510	Economy	13000.00
0005433764644	1510	Economy	13000.00
0005434374157	1510	Economy	13000.00
0005434374156	1510	Economy	13000.00
0005432267821	1510	Economy	13000.00
0005434374136	1510	Economy	13000.00
0005432267823	1510	Economy	13000.00
0005434374142	1510	Economy	13000.00
0005434374145	1510	Economy	13000.00
0005434374137	1510	Economy	13000.00
0005434374148	1510	Economy	13000.00
0005434374128	1510	Economy	13000.00
0005434374125	1510	Economy	13000.00
0005433150799	1510	Economy	13000.00
0005433150853	1510	Economy	13000.00
0005433150798	1510	Economy	13000.00
0005433150820	1510	Economy	13000.00
0005434374147	1510	Economy	13000.00
0005434374155	1510	Economy	13000.00
0005432267820	1510	Economy	13000.00
0005434374129	1510	Economy	13000.00
0005434374127	1510	Economy	13000.00
0005433151019	20161	Business	38900.00
0005432056254	20161	Business	38900.00
0005433151028	20161	Business	38900.00
0005433151006	20161	Business	38900.00
0005433151016	20161	Business	38900.00
0005433151025	20161	Business	38900.00
0005433151034	20161	Economy	13000.00
0005434373890	20161	Economy	13000.00
0005433151027	20161	Economy	13000.00
0005433151026	20161	Economy	13000.00
0005433151024	20161	Economy	13000.00
0005433764656	20161	Economy	13000.00
0005434029628	20161	Economy	13000.00
0005433151038	20161	Economy	13000.00
0005433151007	20161	Economy	13000.00
0005433151031	20161	Economy	13000.00
0005434373968	20161	Economy	13000.00
0005434029627	20161	Economy	13000.00
0005433151023	20161	Economy	13000.00
0005433931432	20161	Economy	13000.00
0005434373876	20161	Economy	13000.00
0005434373914	20161	Economy	13000.00
0005433764655	20161	Economy	13000.00
0005433151021	20161	Economy	13000.00
0005433931431	20161	Economy	13000.00
0005433151030	20161	Economy	13000.00
0005434373859	20161	Economy	13000.00
0005434373878	20161	Economy	13000.00
0005434373854	20161	Economy	13000.00
0005432056255	20161	Economy	13000.00
0005433151020	20161	Economy	14300.00
0005434373881	20161	Economy	13000.00
0005434373877	20161	Economy	13000.00
0005433151014	20161	Economy	13000.00
0005433151035	20161	Economy	13000.00
0005434373882	20161	Economy	13000.00
0005433151009	20161	Economy	13000.00
0005434373864	20161	Economy	13000.00
0005433931430	20161	Economy	13000.00
0005434373872	20161	Economy	13000.00
0005434373865	20161	Economy	13000.00
0005434373915	20161	Economy	13000.00
0005432056256	20161	Economy	13000.00
0005433151015	20161	Economy	13000.00
0005433151037	20161	Economy	13000.00
0005433151013	20161	Economy	13000.00
0005433151018	20161	Economy	13000.00
0005433151032	20161	Economy	13000.00
0005433151022	20161	Economy	13000.00
0005433151008	20161	Economy	13000.00
0005433151029	20161	Economy	13000.00
0005432056257	20161	Economy	13000.00
0005434373860	20161	Economy	13000.00
0005433151011	20161	Economy	13000.00
0005434373871	20161	Economy	13000.00
0005433151012	20161	Economy	13000.00
0005433151005	20161	Economy	13000.00
0005433764657	20161	Economy	13000.00
0005434373852	20161	Economy	13000.00
0005433151010	20161	Economy	13000.00
0005434029629	20161	Economy	13000.00
0005433151036	20161	Economy	13000.00
0005433151033	20161	Economy	13000.00
0005433151017	20161	Economy	13000.00
0005432423943	595	Business	27500.00
0005432423935	595	Business	27500.00
0005432423936	595	Business	27500.00
0005432423934	595	Business	27500.00
0005432423951	595	Business	27500.00
0005432423948	595	Business	27500.00
0005432423946	595	Business	27500.00
0005432423914	595	Business	27500.00
0005432423932	595	Business	27500.00
0005432423912	595	Business	27500.00
0005432423922	595	Business	27500.00
0005432423913	595	Economy	10100.00
0005432423945	595	Economy	10100.00
0005432282788	595	Economy	9200.00
0005432423931	595	Economy	9200.00
0005432423954	595	Economy	9200.00
0005432423955	595	Economy	9200.00
0005432423942	595	Economy	9200.00
0005432423927	595	Economy	9200.00
0005432423926	595	Economy	9200.00
0005432423938	595	Economy	9200.00
0005432423920	595	Economy	9200.00
0005432282784	595	Economy	9200.00
0005432423925	595	Economy	9200.00
0005432423953	595	Economy	9200.00
0005432282786	595	Economy	9200.00
0005432423947	595	Economy	9200.00
0005432423944	595	Economy	9200.00
0005432423916	595	Economy	9200.00
0005432423940	595	Economy	9200.00
0005432282783	595	Economy	9200.00
0005432423924	595	Economy	9200.00
0005432423919	595	Economy	9200.00
0005432423921	595	Economy	9200.00
0005432423939	595	Economy	9200.00
0005432423933	595	Economy	10100.00
0005432423950	595	Economy	10100.00
0005432282785	595	Economy	9200.00
0005432423917	595	Economy	9200.00
0005432423949	595	Economy	9200.00
0005432423930	595	Economy	9200.00
0005432423941	595	Economy	9200.00
0005432423918	595	Economy	9200.00
0005432423915	595	Economy	9200.00
0005432423952	595	Economy	9200.00
0005432423928	595	Economy	9200.00
0005432423910	595	Economy	9200.00
0005432423937	595	Economy	9200.00
0005432423929	595	Economy	9200.00
0005432423911	595	Economy	9200.00
0005432282787	595	Economy	9200.00
0005432423923	595	Economy	9200.00
0005432282782	595	Economy	9200.00
0005432302289	12943	Business	27500.00
0005432302290	12943	Economy	9200.00
0005432302288	12943	Economy	9200.00
0005432302287	12943	Economy	9200.00
0005434022966	451	Business	24500.00
0005434022983	451	Business	24500.00
0005434022924	451	Business	24500.00
0005432235555	451	Business	24500.00
0005433057177	451	Business	24500.00
0005433057221	451	Business	24500.00
0005432235556	451	Business	24500.00
0005434022925	451	Business	24500.00
0005434022984	451	Business	24500.00
0005434028261	451	Business	24500.00
0005434022975	451	Business	24500.00
0005433057202	451	Business	24500.00
0005434022954	451	Business	24500.00
0005434022958	451	Business	24500.00
0005434022927	451	Business	24500.00
0005434022973	451	Economy	9000.00
0005434022940	451	Economy	8200.00
0005434022937	451	Economy	8200.00
0005433057246	451	Economy	8200.00
0005434022935	451	Economy	8200.00
0005434022957	451	Economy	8200.00
0005434022976	451	Economy	8200.00
0005434022959	451	Economy	8200.00
0005434022938	451	Economy	8200.00
0005433057271	451	Economy	8200.00
0005433057314	451	Economy	8200.00
0005433057212	451	Economy	8200.00
0005434022930	451	Economy	8200.00
0005434022956	451	Economy	8200.00
0005434022961	451	Economy	8200.00
0005434022917	451	Economy	8200.00
0005434022943	451	Economy	8200.00
0005434022955	451	Economy	8200.00
0005434022932	451	Economy	8200.00
0005434022971	451	Economy	8200.00
0005433057188	451	Economy	8200.00
0005434022918	451	Economy	8200.00
0005434022941	451	Economy	8200.00
0005434022962	451	Economy	8200.00
0005434022977	451	Economy	8200.00
0005432235554	451	Economy	8200.00
0005434022974	451	Economy	8200.00
0005434022985	451	Economy	8200.00
0005432235552	451	Economy	8200.00
0005434031970	451	Economy	8200.00
0005434022965	451	Economy	8200.00
0005433057295	451	Economy	8200.00
0005434022947	451	Economy	8200.00
0005434022921	451	Economy	8200.00
0005434022942	451	Economy	8200.00
0005432235551	451	Economy	8200.00
0005433057179	451	Economy	8200.00
0005433057192	451	Economy	8200.00
0005433057232	451	Economy	8200.00
0005434022969	451	Economy	8200.00
0005434022939	451	Economy	8200.00
0005433057222	451	Economy	8200.00
0005434022980	451	Economy	8200.00
0005434022979	451	Economy	8200.00
0005432235553	451	Economy	8200.00
0005434022949	451	Economy	8200.00
0005434022934	451	Economy	8200.00
0005434022952	451	Economy	8200.00
0005434022953	451	Economy	8200.00
0005432045589	451	Economy	8200.00
0005434029626	451	Economy	8200.00
0005434022923	451	Economy	9000.00
0005434028262	451	Economy	8200.00
0005433057286	451	Economy	9000.00
0005434022936	451	Economy	8200.00
0005433057237	451	Economy	8200.00
0005434022968	451	Economy	8200.00
0005433057267	451	Economy	8200.00
0005434031968	451	Economy	8200.00
0005434022928	451	Economy	8200.00
0005434022920	451	Economy	8200.00
0005434022982	451	Economy	8200.00
0005434022926	451	Economy	8200.00
0005434022951	451	Economy	8200.00
0005434022970	451	Economy	8200.00
0005434022981	451	Economy	8200.00
0005434022946	451	Economy	8200.00
0005432045591	451	Economy	8200.00
0005434022931	451	Economy	8200.00
0005434031969	451	Economy	8200.00
0005434022964	451	Economy	8200.00
0005434022945	451	Economy	8200.00
0005434022963	451	Economy	8200.00
0005434022922	451	Economy	8200.00
0005434022919	451	Economy	8200.00
0005434022944	451	Economy	8200.00
0005434022948	451	Economy	8200.00
0005433057223	451	Economy	8200.00
0005432045590	451	Economy	8200.00
0005434022967	451	Economy	8200.00
0005434031967	451	Economy	8200.00
0005434022929	451	Economy	8200.00
0005432235557	451	Economy	8200.00
0005434022933	451	Economy	8200.00
0005434022960	451	Economy	8200.00
0005432235550	451	Economy	8200.00
0005434031971	451	Economy	8200.00
0005434022978	451	Economy	8200.00
0005434022972	451	Economy	8200.00
0005434022950	451	Economy	8200.00
0005433057421	12691	Business	24500.00
0005433057439	12691	Business	24500.00
0005433929568	12691	Business	24500.00
0005433057431	12691	Business	24500.00
0005433057433	12691	Business	24500.00
0005434031944	12691	Business	24500.00
0005434022604	12691	Business	24500.00
0005433057417	12691	Business	24500.00
0005433057435	12691	Business	24500.00
0005433057437	12691	Business	24500.00
0005433057441	12691	Business	24500.00
0005434022531	12691	Business	24500.00
0005433057428	12691	Economy	9000.00
0005434022746	12691	Economy	8200.00
0005433057453	12691	Economy	8200.00
0005433057430	12691	Economy	8200.00
0005433929566	12691	Economy	8200.00
0005434735633	12691	Economy	8200.00
0005432156316	12691	Economy	8200.00
0005433929565	12691	Economy	8200.00
0005433057427	12691	Economy	8200.00
0005433057422	12691	Economy	8200.00
0005433057452	12691	Economy	8200.00
0005433057434	12691	Economy	8200.00
0005433057448	12691	Economy	8200.00
0005434735630	12691	Economy	8200.00
0005433057455	12691	Economy	8200.00
0005434022640	12691	Economy	8200.00
0005433057444	12691	Economy	8200.00
0005433057429	12691	Economy	8200.00
0005434022602	12691	Economy	8200.00
0005433057436	12691	Economy	8200.00
0005433057425	12691	Economy	8200.00
0005433057416	12691	Economy	8200.00
0005434022603	12691	Economy	8200.00
0005432157470	12691	Economy	8200.00
0005434735629	12691	Economy	8200.00
0005434022593	12691	Economy	8200.00
0005432157469	12691	Economy	8200.00
0005433057423	12691	Economy	8200.00
0005434031952	12691	Economy	8200.00
0005432156315	12691	Economy	9000.00
0005433057443	12691	Economy	8200.00
0005433057451	12691	Economy	8200.00
0005433057415	12691	Economy	8200.00
0005433057432	12691	Economy	8200.00
0005433057419	12691	Economy	8200.00
0005433057424	12691	Economy	8200.00
0005434735634	12691	Economy	8200.00
0005433057454	12691	Economy	8200.00
0005433057426	12691	Economy	8200.00
0005432156317	12691	Economy	8200.00
0005432156313	12691	Economy	8200.00
0005433929567	12691	Economy	8200.00
0005433684398	12691	Economy	8200.00
0005433057420	12691	Economy	8200.00
0005434735631	12691	Economy	8200.00
0005433057446	12691	Economy	8200.00
0005433057445	12691	Economy	8200.00
0005433057418	12691	Economy	8200.00
0005433057447	12691	Economy	8200.00
0005433057440	12691	Economy	8200.00
0005432156314	12691	Economy	8200.00
0005433057450	12691	Economy	8200.00
0005434735632	12691	Economy	8200.00
0005434022639	12691	Economy	8200.00
0005434735635	12691	Economy	8200.00
0005433057442	12691	Economy	8200.00
0005433057449	12691	Economy	8200.00
0005434022532	12691	Economy	8200.00
0005434022517	12691	Economy	8200.00
0005433057438	12691	Economy	8200.00
0005433684397	12691	Economy	8200.00
0005433922209	2118	Business	34700.00
0005433922177	2118	Business	34700.00
0005433875360	2118	Business	34700.00
0005433922255	2118	Business	34700.00
0005433922189	2118	Business	34700.00
0005433922227	2118	Business	34700.00
0005433922225	2118	Business	34700.00
0005433922206	2118	Business	34700.00
0005432231447	2118	Business	34700.00
0005433035373	2118	Business	34700.00
0005433922181	2118	Business	34700.00
0005433922196	2118	Business	34700.00
0005433922268	2118	Business	34700.00
0005432231441	2118	Business	34700.00
0005432231440	2118	Business	34700.00
0005433922242	2118	Business	34700.00
0005432231446	2118	Business	34700.00
0005433922186	2118	Business	34700.00
0005433922234	2118	Business	34700.00
0005433922230	2118	Business	34700.00
0005433922223	2118	Business	34700.00
0005433922203	2118	Economy	12700.00
0005433922237	2118	Economy	12700.00
0005433922263	2118	Economy	11600.00
0005433922179	2118	Economy	11600.00
0005433922262	2118	Economy	11600.00
0005433922210	2118	Economy	11600.00
0005433922198	2118	Economy	11600.00
0005433922271	2118	Economy	11600.00
0005433922253	2118	Economy	11600.00
0005433922194	2118	Economy	11600.00
0005433922180	2118	Economy	11600.00
0005433922249	2118	Economy	11600.00
0005433035453	2118	Economy	11600.00
0005433922272	2118	Economy	11600.00
0005433922260	2118	Economy	11600.00
0005433035443	2118	Economy	11600.00
0005433922184	2118	Economy	11600.00
0005433922188	2118	Economy	11600.00
0005433922265	2118	Economy	11600.00
0005432231442	2118	Economy	11600.00
0005433922214	2118	Economy	11600.00
0005433922226	2118	Economy	11600.00
0005433035382	2118	Economy	11600.00
0005433035407	2118	Economy	11600.00
0005433035398	2118	Economy	11600.00
0005433922212	2118	Economy	11600.00
0005433922183	2118	Economy	11600.00
0005433922266	2118	Economy	11600.00
0005432231445	2118	Economy	11600.00
0005433922235	2118	Economy	11600.00
0005433922259	2118	Economy	11600.00
0005433922217	2118	Economy	11600.00
0005433035381	2118	Economy	11600.00
0005433922201	2118	Economy	11600.00
0005433922207	2118	Economy	11600.00
0005432044493	2118	Economy	11600.00
0005433929566	2118	Economy	11600.00
0005433922236	2118	Economy	11600.00
0005433922251	2118	Economy	11600.00
0005432044494	2118	Economy	11600.00
0005433929567	2118	Economy	11600.00
0005433922213	2118	Economy	11600.00
0005433922247	2118	Economy	11600.00
0005433922219	2118	Economy	11600.00
0005433922239	2118	Economy	11600.00
0005433922243	2118	Economy	11600.00
0005433922202	2118	Economy	11600.00
0005433931431	2118	Economy	11600.00
0005433922205	2118	Economy	11600.00
0005432231443	2118	Economy	11600.00
0005433922261	2118	Economy	11600.00
0005433922193	2118	Economy	11600.00
0005433922218	2118	Economy	11600.00
0005433922250	2118	Economy	11600.00
0005433035412	2118	Economy	11600.00
0005433922254	2118	Economy	11600.00
0005433922252	2118	Economy	11600.00
0005433922244	2118	Economy	11600.00
0005433922246	2118	Economy	11600.00
0005433922238	2118	Economy	11600.00
0005433922197	2118	Economy	11600.00
0005433922216	2118	Economy	11600.00
0005433922248	2118	Economy	11600.00
0005433922208	2118	Economy	11600.00
0005433922200	2118	Economy	11600.00
0005433922264	2118	Economy	11600.00
0005433035384	2118	Economy	12700.00
0005433922222	2118	Economy	11600.00
0005433931430	2118	Economy	11600.00
0005433922229	2118	Economy	12700.00
0005433922245	2118	Economy	12700.00
0005433922228	2118	Economy	11600.00
0005433922190	2118	Economy	11600.00
0005433922215	2118	Economy	11600.00
0005433922221	2118	Economy	11600.00
0005433922233	2118	Economy	11600.00
0005433931432	2118	Economy	11600.00
0005433922176	2118	Economy	11600.00
0005433922256	2118	Economy	11600.00
0005432231449	2118	Economy	11600.00
0005433922269	2118	Economy	11600.00
0005433875361	2118	Economy	11600.00
0005433922199	2118	Economy	11600.00
0005433035374	2118	Economy	11600.00
0005433035361	2118	Economy	11600.00
0005432231444	2118	Economy	11600.00
0005433035397	2118	Economy	11600.00
0005432231448	2118	Economy	11600.00
0005433922257	2118	Economy	11600.00
0005433875362	2118	Economy	11600.00
0005433929565	2118	Economy	11600.00
0005433035396	2118	Economy	11600.00
0005433922258	2118	Economy	11600.00
0005433922195	2118	Economy	11600.00
0005433922273	2118	Economy	11600.00
0005433922185	2118	Economy	11600.00
0005433922274	2118	Economy	11600.00
0005433035411	2118	Economy	11600.00
0005433922204	2118	Economy	11600.00
0005433922211	2118	Economy	11600.00
0005433922231	2118	Economy	11600.00
0005433929568	2118	Economy	11600.00
0005433922178	2118	Economy	11600.00
0005433035406	2118	Economy	11600.00
0005433875363	2118	Economy	11600.00
0005433922267	2118	Economy	11600.00
0005433922270	2118	Economy	11600.00
0005433922220	2118	Economy	11600.00
0005433922224	2118	Economy	11600.00
0005432044492	2118	Economy	11600.00
0005433922240	2118	Economy	11600.00
0005433922241	2118	Economy	11600.00
0005433922191	2118	Economy	11600.00
0005433922187	2118	Economy	11600.00
0005433922182	2118	Economy	11600.00
0005433922232	2118	Economy	11600.00
0005433035388	2118	Economy	11600.00
0005433922192	2118	Economy	11600.00
0005433035444	2118	Economy	11600.00
0005433035686	24085	Business	34700.00
0005433035724	24085	Business	34700.00
0005433931417	24085	Business	34700.00
0005433035707	24085	Business	34700.00
0005433035703	24085	Business	34700.00
0005433921627	24085	Business	34700.00
0005433035708	24085	Business	34700.00
0005433035705	24085	Business	34700.00
0005433035683	24085	Business	34700.00
0005432749761	24085	Business	34700.00
0005433035680	24085	Business	34700.00
0005433035706	24085	Business	34700.00
0005433035693	24085	Business	34700.00
0005433035692	24085	Business	34700.00
0005433035716	24085	Business	34700.00
0005433035727	24085	Business	34700.00
0005433921597	24085	Business	34700.00
0005434028265	24085	Economy	12700.00
0005433035702	24085	Economy	12700.00
0005434028266	24085	Economy	11600.00
0005433921675	24085	Economy	11600.00
0005433035699	24085	Economy	11600.00
0005433035690	24085	Economy	11600.00
0005433921641	24085	Economy	11600.00
0005433921800	24085	Economy	11600.00
0005433921664	24085	Economy	11600.00
0005433035711	24085	Economy	11600.00
0005432207633	24085	Economy	11600.00
0005432206129	24085	Economy	11600.00
0005433035725	24085	Economy	11600.00
0005433929546	24085	Economy	11600.00
0005433035691	24085	Economy	11600.00
0005432749760	24085	Economy	11600.00
0005433035715	24085	Economy	11600.00
0005433035688	24085	Economy	11600.00
0005432206128	24085	Economy	11600.00
0005433035696	24085	Economy	11600.00
0005433035701	24085	Economy	11600.00
0005433035734	24085	Economy	11600.00
0005433921663	24085	Economy	11600.00
0005433035689	24085	Economy	11600.00
0005433035732	24085	Economy	11600.00
0005433035684	24085	Economy	11600.00
0005433035697	24085	Economy	11600.00
0005433035710	24085	Economy	11600.00
0005433035730	24085	Economy	11600.00
0005433035722	24085	Economy	11600.00
0005432207632	24085	Economy	11600.00
0005433035698	24085	Economy	11600.00
0005432206132	24085	Economy	11600.00
0005433035729	24085	Economy	11600.00
0005433035700	24085	Economy	11600.00
0005433035709	24085	Economy	11600.00
0005433035731	24085	Economy	11600.00
0005433035685	24085	Economy	11600.00
0005432206131	24085	Economy	11600.00
0005433035694	24085	Economy	11600.00
0005433035723	24085	Economy	11600.00
0005433035682	24085	Economy	11600.00
0005433035720	24085	Economy	12700.00
0005433035712	24085	Economy	11600.00
0005433035726	24085	Economy	11600.00
0005433035687	24085	Economy	11600.00
0005433921686	24085	Economy	12700.00
0005434028264	24085	Economy	11600.00
0005433921775	24085	Economy	11600.00
0005433921620	24085	Economy	11600.00
0005432206130	24085	Economy	11600.00
0005433921596	24085	Economy	11600.00
0005433921674	24085	Economy	11600.00
0005433921726	24085	Economy	11600.00
0005433035695	24085	Economy	11600.00
0005433035721	24085	Economy	11600.00
0005434028263	24085	Economy	11600.00
0005433035714	24085	Economy	11600.00
0005433035718	24085	Economy	11600.00
0005433035704	24085	Economy	11600.00
0005433035681	24085	Economy	11600.00
0005433921787	24085	Economy	11600.00
0005433035717	24085	Economy	11600.00
0005433035713	24085	Economy	11600.00
0005433035719	24085	Economy	11600.00
0005433035728	24085	Economy	11600.00
0005433035733	24085	Economy	11600.00
0005433921701	24085	Economy	11600.00
0005433921727	24085	Economy	11600.00
0005432277658	266	Business	83700.00
0005434550621	266	Business	83700.00
0005434724074	266	Business	83700.00
0005434724099	266	Business	83700.00
0005434724106	266	Business	83700.00
0005434550595	266	Business	83700.00
0005434724093	266	Business	83700.00
0005433180670	266	Business	83700.00
0005434550600	266	Business	83700.00
0005434550608	266	Business	83700.00
0005434724158	266	Business	83700.00
0005433233309	266	Business	83700.00
0005434550598	266	Business	83700.00
0005434724104	266	Business	83700.00
0005434724145	266	Business	83700.00
0005434724159	266	Business	83700.00
0005434550604	266	Business	83700.00
0005434724105	266	Business	83700.00
0005434550599	266	Business	83700.00
0005434724065	266	Business	83700.00
0005432277655	266	Comfort	47400.00
0005434724121	266	Comfort	47400.00
0005433233213	266	Comfort	47400.00
0005434550628	266	Comfort	47400.00
0005434724154	266	Comfort	47400.00
0005434724155	266	Comfort	47400.00
0005433180720	266	Comfort	47400.00
0005434724063	266	Comfort	47400.00
0005434724160	266	Comfort	47400.00
0005434724087	266	Comfort	47400.00
0005434724083	266	Comfort	47400.00
0005434550643	266	Comfort	47400.00
0005433233189	266	Comfort	47400.00
0005434550623	266	Comfort	47400.00
0005434550610	266	Comfort	47400.00
0005432277653	266	Comfort	47400.00
0005435142421	266	Comfort	47400.00
0005434550613	266	Comfort	47400.00
0005434550614	266	Comfort	47400.00
0005433233333	266	Comfort	47400.00
0005434724056	266	Comfort	47400.00
0005434724144	266	Comfort	47400.00
0005434724089	266	Comfort	47400.00
0005434550649	266	Comfort	47400.00
0005434550619	266	Comfort	47400.00
0005434724090	266	Comfort	47400.00
0005434724151	266	Comfort	47400.00
0005434724150	266	Comfort	47400.00
0005434724088	266	Comfort	47400.00
0005434724077	266	Comfort	47400.00
0005434731120	266	Comfort	47400.00
0005433233143	266	Comfort	47400.00
0005434724176	266	Economy	27900.00
0005434550616	266	Economy	27900.00
0005434724149	266	Economy	27900.00
0005434550632	266	Economy	27900.00
0005434724072	266	Economy	27900.00
0005434550645	266	Economy	27900.00
0005435142431	266	Economy	27900.00
0005434724085	266	Economy	27900.00
0005434550607	266	Economy	27900.00
0005434724068	266	Economy	27900.00
0005435142418	266	Economy	27900.00
0005434724080	266	Economy	27900.00
0005434724097	266	Economy	27900.00
0005434724117	266	Economy	27900.00
0005434550639	266	Economy	27900.00
0005434724153	266	Economy	27900.00
0005434724152	266	Economy	27900.00
0005434550615	266	Economy	27900.00
0005434724157	266	Economy	27900.00
0005434724082	266	Economy	27900.00
0005432277654	266	Economy	27900.00
0005432277661	266	Economy	27900.00
0005434724069	266	Economy	27900.00
0005434550602	266	Economy	27900.00
0005434302408	266	Economy	27900.00
0005434724101	266	Economy	27900.00
0005434550618	266	Economy	27900.00
0005434724163	266	Economy	27900.00
0005433233145	266	Economy	27900.00
0005434724118	266	Economy	27900.00
0005434724071	266	Economy	27900.00
0005434724073	266	Economy	27900.00
0005434550594	266	Economy	27900.00
0005434550635	266	Economy	27900.00
0005434550611	266	Economy	27900.00
0005434724136	266	Economy	27900.00
0005434550597	266	Economy	27900.00
0005434735625	266	Economy	27900.00
0005434724161	266	Economy	27900.00
0005434724169	266	Economy	27900.00
0005434550612	266	Economy	27900.00
0005434724094	266	Economy	27900.00
0005435142420	266	Economy	27900.00
0005435142425	266	Economy	27900.00
0005434724129	266	Economy	27900.00
0005434724130	266	Economy	30700.00
0005434550634	266	Economy	30700.00
0005434724061	266	Economy	27900.00
0005434550637	266	Economy	27900.00
0005434550622	266	Economy	30700.00
0005434724135	266	Economy	27900.00
0005434724103	266	Economy	27900.00
0005434724067	266	Economy	27900.00
0005434550606	266	Economy	27900.00
0005433180669	266	Economy	27900.00
0005434724114	266	Economy	27900.00
0005434550626	266	Economy	27900.00
0005434550648	266	Economy	27900.00
0005434724115	266	Economy	27900.00
0005432277663	266	Economy	27900.00
0005433233188	266	Economy	27900.00
0005433233168	266	Economy	27900.00
0005434724137	266	Economy	27900.00
0005434724125	266	Economy	27900.00
0005434550640	266	Economy	27900.00
0005434724084	266	Economy	27900.00
0005434550627	266	Economy	27900.00
0005434724128	266	Economy	27900.00
0005434724110	266	Economy	27900.00
0005434724086	266	Economy	27900.00
0005434724177	266	Economy	27900.00
0005434302409	266	Economy	27900.00
0005432277662	266	Economy	27900.00
0005434724172	266	Economy	27900.00
0005434550625	266	Economy	27900.00
0005433233142	266	Economy	27900.00
0005434550631	266	Economy	27900.00
0005434724167	266	Economy	27900.00
0005434724127	266	Economy	27900.00
0005434731119	266	Economy	27900.00
0005434550647	266	Economy	27900.00
0005434735624	266	Economy	27900.00
0005434724100	266	Economy	27900.00
0005432277660	266	Economy	27900.00
0005435142428	266	Economy	27900.00
0005434731118	266	Economy	27900.00
0005434724102	266	Economy	27900.00
0005434550593	266	Economy	27900.00
0005434724111	266	Economy	27900.00
0005434724075	266	Economy	27900.00
0005434724140	266	Economy	27900.00
0005434724146	266	Economy	27900.00
0005434724081	266	Economy	27900.00
0005434550641	266	Economy	27900.00
0005434724076	266	Economy	27900.00
0005434724143	266	Economy	27900.00
0005434724131	266	Economy	27900.00
0005435142419	266	Economy	27900.00
0005434724079	266	Economy	27900.00
0005434724109	266	Economy	27900.00
0005434724055	266	Economy	27900.00
0005433233334	266	Economy	27900.00
0005434724057	266	Economy	27900.00
0005432277659	266	Economy	27900.00
0005433180652	266	Economy	27900.00
0005435142422	266	Economy	27900.00
0005434724108	266	Economy	27900.00
0005434550642	266	Economy	27900.00
0005434724060	266	Economy	27900.00
0005433233326	266	Economy	27900.00
0005434550650	266	Economy	27900.00
0005433180648	266	Economy	27900.00
0005434724174	266	Economy	27900.00
0005434550629	266	Economy	27900.00
0005434724098	266	Economy	27900.00
0005435142423	266	Economy	27900.00
0005434550646	266	Economy	27900.00
0005433233136	266	Economy	27900.00
0005434550603	266	Economy	27900.00
0005434724092	266	Economy	27900.00
0005434550624	266	Economy	27900.00
0005432277664	266	Economy	27900.00
0005434724113	266	Economy	30700.00
0005432277656	266	Economy	30700.00
0005434724148	266	Economy	30700.00
0005434724120	266	Economy	30700.00
0005434724168	266	Economy	27900.00
0005435142429	266	Economy	27900.00
0005434302411	266	Economy	27900.00
0005434724142	266	Economy	27900.00
0005434724070	266	Economy	27900.00
0005434735626	266	Economy	27900.00
0005433180692	266	Economy	27900.00
0005434724124	266	Economy	27900.00
0005434724123	266	Economy	27900.00
0005434724132	266	Economy	27900.00
0005434724134	266	Economy	27900.00
0005434724139	266	Economy	27900.00
0005434724054	266	Economy	27900.00
0005434724156	266	Economy	27900.00
0005435142427	266	Economy	27900.00
0005434724126	266	Economy	27900.00
0005435142430	266	Economy	27900.00
0005434724095	266	Economy	27900.00
0005434724147	266	Economy	27900.00
0005433233094	266	Economy	27900.00
0005435142426	266	Economy	27900.00
0005435142424	266	Economy	27900.00
0005434550636	266	Economy	27900.00
0005434724175	266	Economy	27900.00
0005434724059	266	Economy	27900.00
0005434724133	266	Economy	27900.00
0005433180649	266	Economy	27900.00
0005434731121	266	Economy	27900.00
0005434724141	266	Economy	27900.00
0005434724162	266	Economy	27900.00
0005434724112	266	Economy	27900.00
0005434550633	266	Economy	27900.00
0005434724173	266	Economy	27900.00
0005434724096	266	Economy	27900.00
0005434302410	266	Economy	27900.00
0005434724062	266	Economy	27900.00
0005434550638	266	Economy	27900.00
0005434724064	266	Economy	27900.00
0005434724170	266	Economy	27900.00
0005434550620	266	Economy	27900.00
0005434724165	266	Economy	27900.00
0005434550605	266	Economy	27900.00
0005433180691	266	Economy	27900.00
0005434735627	266	Economy	27900.00
0005434724119	266	Economy	27900.00
0005433131630	266	Economy	27900.00
0005434724091	266	Economy	27900.00
0005434724164	266	Economy	27900.00
0005434724078	266	Economy	27900.00
0005433233095	266	Economy	27900.00
0005434550644	266	Economy	27900.00
0005434724138	266	Economy	27900.00
0005434724066	266	Economy	27900.00
0005434724166	266	Economy	27900.00
0005434724171	266	Economy	27900.00
0005434735628	266	Economy	27900.00
0005434724107	266	Economy	27900.00
0005434731117	266	Economy	27900.00
0005434550609	266	Economy	27900.00
0005432277652	266	Economy	27900.00
0005434724122	266	Economy	27900.00
0005434724116	266	Economy	27900.00
0005434550617	266	Economy	27900.00
0005434302412	266	Economy	27900.00
0005433180721	266	Economy	27900.00
0005434550596	266	Economy	27900.00
0005434724058	266	Economy	27900.00
0005434550601	266	Economy	27900.00
0005432277657	266	Economy	27900.00
0005434550630	266	Economy	27900.00
0005433233491	9845	Business	83700.00
0005433129224	9845	Business	83700.00
0005433233511	9845	Business	83700.00
0005433289767	9845	Business	83700.00
0005433233488	9845	Business	83700.00
0005432199168	9845	Business	83700.00
0005433180827	9845	Business	83700.00
0005433129223	9845	Business	83700.00
0005433180809	9845	Business	83700.00
0005433126794	9845	Comfort	47400.00
0005433233518	9845	Comfort	47400.00
0005433233528	9845	Comfort	47400.00
0005433233506	9845	Comfort	47400.00
0005433233495	9845	Comfort	47400.00
0005434031973	9845	Comfort	47400.00
0005433233469	9845	Comfort	47400.00
0005434723523	9845	Comfort	47400.00
0005433180813	9845	Comfort	47400.00
0005433233483	9845	Comfort	47400.00
0005433126793	9845	Comfort	47400.00
0005433129222	9845	Comfort	47400.00
0005434723660	9845	Comfort	47400.00
0005433233505	9845	Comfort	47400.00
0005433233510	9845	Comfort	47400.00
0005434723661	9845	Comfort	47400.00
0005433233473	9845	Comfort	47400.00
0005434735601	9845	Comfort	47400.00
0005433233531	9845	Comfort	47400.00
0005433126792	9845	Comfort	47400.00
0005433233494	9845	Comfort	47400.00
0005433766597	9845	Economy	27900.00
0005433233504	9845	Economy	27900.00
0005433180814	9845	Economy	27900.00
0005434723492	9845	Economy	27900.00
0005433233485	9845	Economy	27900.00
0005434550333	9845	Economy	27900.00
0005433233529	9845	Economy	27900.00
0005433180818	9845	Economy	27900.00
0005433180817	9845	Economy	27900.00
0005434302382	9845	Economy	27900.00
0005433289766	9845	Economy	27900.00
0005433233516	9845	Economy	27900.00
0005433233475	9845	Economy	27900.00
0005433180812	9845	Economy	27900.00
0005433113510	9845	Economy	27900.00
0005433233512	9845	Economy	27900.00
0005433113509	9845	Economy	27900.00
0005433180811	9845	Economy	27900.00
0005433180806	9845	Economy	27900.00
0005433233471	9845	Economy	27900.00
0005433766598	9845	Economy	27900.00
0005433233482	9845	Economy	27900.00
0005433233489	9845	Economy	27900.00
0005433233496	9845	Economy	27900.00
0005433233497	9845	Economy	27900.00
0005434723399	9845	Economy	27900.00
0005433233524	9845	Economy	27900.00
0005433233522	9845	Economy	27900.00
0005432199169	9845	Economy	30700.00
0005434723460	9845	Economy	30700.00
0005432199166	9845	Economy	30700.00
0005433233525	9845	Economy	27900.00
0005433233474	9845	Economy	27900.00
0005433289765	9845	Economy	27900.00
0005432199172	9845	Economy	27900.00
0005433289762	9845	Economy	27900.00
0005434723400	9845	Economy	27900.00
0005433180824	9845	Economy	27900.00
0005433180821	9845	Economy	27900.00
0005433233484	9845	Economy	27900.00
0005433233527	9845	Economy	27900.00
0005433180823	9845	Economy	27900.00
0005433233530	9845	Economy	27900.00
0005433233487	9845	Economy	27900.00
0005433233478	9845	Economy	27900.00
0005433233520	9845	Economy	27900.00
0005433766595	9845	Economy	27900.00
0005433180805	9845	Economy	27900.00
0005433233479	9845	Economy	27900.00
0005433233468	9845	Economy	27900.00
0005434723382	9845	Economy	27900.00
0005432199170	9845	Economy	27900.00
0005433233467	9845	Economy	27900.00
0005433129225	9845	Economy	27900.00
0005433233493	9845	Economy	27900.00
0005433233500	9845	Economy	27900.00
0005433233476	9845	Economy	27900.00
0005433233519	9845	Economy	27900.00
0005433233499	9845	Economy	27900.00
0005433233466	9845	Economy	27900.00
0005433233526	9845	Economy	27900.00
0005433233507	9845	Economy	27900.00
0005433233508	9845	Economy	27900.00
0005433233498	9845	Economy	27900.00
0005433766596	9845	Economy	27900.00
0005433233486	9845	Economy	27900.00
0005434550334	9845	Economy	27900.00
0005433180808	9845	Economy	27900.00
0005433180825	9845	Economy	27900.00
0005433233513	9845	Economy	27900.00
0005433233490	9845	Economy	27900.00
0005433180803	9845	Economy	27900.00
0005433180810	9845	Economy	27900.00
0005434031972	9845	Economy	27900.00
0005433180804	9845	Economy	27900.00
0005434723482	9845	Economy	27900.00
0005434723381	9845	Economy	30700.00
0005432199167	9845	Economy	30700.00
0005433233481	9845	Economy	27900.00
0005433233480	9845	Economy	27900.00
0005433233502	9845	Economy	27900.00
0005433233470	9845	Economy	27900.00
0005433180807	9845	Economy	27900.00
0005433233523	9845	Economy	27900.00
0005433129221	9845	Economy	27900.00
0005433233472	9845	Economy	27900.00
0005434735606	9845	Economy	27900.00
0005433289763	9845	Economy	27900.00
0005434723449	9845	Economy	27900.00
0005433233501	9845	Economy	27900.00
0005433180826	9845	Economy	27900.00
0005434723567	9845	Economy	27900.00
0005433233515	9845	Economy	27900.00
0005433126791	9845	Economy	27900.00
0005433180820	9845	Economy	27900.00
0005433233477	9845	Economy	27900.00
0005434031975	9845	Economy	27900.00
0005433233492	9845	Economy	27900.00
0005433180822	9845	Economy	27900.00
0005433233514	9845	Economy	27900.00
0005433180819	9845	Economy	27900.00
0005434735600	9845	Economy	27900.00
0005434723543	9845	Economy	27900.00
0005433233509	9845	Economy	27900.00
0005433180828	9845	Economy	27900.00
0005434723544	9845	Economy	27900.00
0005434723459	9845	Economy	27900.00
0005433180815	9845	Economy	27900.00
0005432199171	9845	Economy	27900.00
0005434723638	9845	Economy	27900.00
0005433233521	9845	Economy	27900.00
0005433180816	9845	Economy	27900.00
0005433233503	9845	Economy	27900.00
0005433233517	9845	Economy	27900.00
0005434723335	9845	Economy	27900.00
0005433289764	9845	Economy	27900.00
0005434031974	9845	Economy	27900.00
0005432526573	7726	Business	42100.00
0005432526567	7726	Business	42100.00
0005432537035	7726	Business	42100.00
0005432428891	7726	Business	42100.00
0005432535776	7726	Business	42100.00
0005432526538	7726	Business	42100.00
0005432526549	7726	Business	42100.00
0005432526492	7726	Business	42100.00
0005432526522	7726	Business	42100.00
0005434066765	7726	Business	42100.00
0005432537033	7726	Business	42100.00
0005432526530	7726	Business	42100.00
0005434066736	7726	Business	42100.00
0005432526451	7726	Business	42100.00
0005432428890	7726	Business	42100.00
0005434066763	7726	Business	42100.00
0005434066745	7726	Business	42100.00
0005434066793	7726	Business	42100.00
0005432526480	7726	Business	42100.00
0005432069497	7726	Business	42100.00
0005434066780	7726	Comfort	23900.00
0005432526477	7726	Business	42100.00
0005432526541	7726	Comfort	23900.00
0005432526468	7726	Comfort	23900.00
0005432526461	7726	Comfort	23900.00
0005432526523	7726	Comfort	23900.00
0005434066753	7726	Comfort	23900.00
0005432526532	7726	Comfort	23900.00
0005432526478	7726	Comfort	23900.00
0005432526470	7726	Comfort	23900.00
0005432526537	7726	Comfort	23900.00
0005434066752	7726	Comfort	23900.00
0005432526499	7726	Comfort	23900.00
0005434066731	7726	Comfort	23900.00
0005432428889	7726	Comfort	23900.00
0005432069493	7726	Comfort	23900.00
0005432526502	7726	Comfort	23900.00
0005432526572	7726	Comfort	23900.00
0005432526486	7726	Comfort	23900.00
0005434066787	7726	Comfort	23900.00
0005434066766	7726	Comfort	23900.00
0005434066802	7726	Comfort	23900.00
0005432150109	7726	Comfort	23900.00
0005432526481	7726	Comfort	23900.00
0005432526517	7726	Comfort	23900.00
0005432526574	7726	Comfort	23900.00
0005432526473	7726	Comfort	23900.00
0005432150106	7726	Comfort	23900.00
0005432526554	7726	Comfort	23900.00
0005432526508	7726	Economy	14000.00
0005432526509	7726	Economy	14000.00
0005432526561	7726	Economy	14000.00
0005432526511	7726	Economy	14000.00
0005432150103	7726	Economy	14000.00
0005432526527	7726	Economy	14000.00
0005432069492	7726	Economy	14000.00
0005432526484	7726	Economy	14000.00
0005434066771	7726	Economy	14000.00
0005434066738	7726	Economy	14000.00
0005432526545	7726	Economy	14000.00
0005432526465	7726	Economy	14000.00
0005434066791	7726	Economy	14000.00
0005434066772	7726	Economy	14000.00
0005434066774	7726	Economy	14000.00
0005432069491	7726	Economy	14000.00
0005434066803	7726	Economy	14000.00
0005432526565	7726	Economy	14000.00
0005434066748	7726	Economy	14000.00
0005432526495	7726	Economy	14000.00
0005432069490	7726	Economy	14000.00
0005434066760	7726	Economy	14000.00
0005432069488	7726	Economy	14000.00
0005434066762	7726	Economy	14000.00
0005432526489	7726	Economy	14000.00
0005435212356	7726	Economy	14000.00
0005434066781	7726	Economy	14000.00
0005432069495	7726	Economy	14000.00
0005434066730	7726	Economy	14000.00
0005432526449	7726	Economy	14000.00
0005434066732	7726	Economy	14000.00
0005434066768	7726	Economy	14000.00
0005432526442	7726	Economy	14000.00
0005432526459	7726	Economy	14000.00
0005432526550	7726	Economy	14000.00
0005432526516	7726	Economy	14000.00
0005432526564	7726	Economy	14000.00
0005432526506	7726	Economy	14000.00
0005432526524	7726	Economy	14000.00
0005434066797	7726	Economy	14000.00
0005432526474	7726	Economy	14000.00
0005432526444	7726	Economy	14000.00
0005434066743	7726	Economy	14000.00
0005432150104	7726	Economy	14000.00
0005432526462	7726	Economy	14000.00
0005432533260	7726	Economy	14000.00
0005434066742	7726	Economy	14000.00
0005434066734	7726	Economy	14000.00
0005434066755	7726	Economy	14000.00
0005432526456	7726	Economy	15400.00
0005432526455	7726	Economy	14000.00
0005434066795	7726	Economy	14000.00
0005432526548	7726	Economy	15400.00
0005432526475	7726	Economy	15400.00
0005434066782	7726	Economy	15400.00
0005434066733	7726	Economy	14000.00
0005432526445	7726	Economy	14000.00
0005432526528	7726	Economy	14000.00
0005432526490	7726	Economy	14000.00
0005435212418	7726	Economy	14000.00
0005434066754	7726	Economy	14000.00
0005435212355	7726	Economy	14000.00
0005434066779	7726	Economy	14000.00
0005432526535	7726	Economy	14000.00
0005432526544	7726	Economy	14000.00
0005434066784	7726	Economy	14000.00
0005432526571	7726	Economy	14000.00
0005432526546	7726	Economy	14000.00
0005432526557	7726	Economy	14000.00
0005434066757	7726	Economy	14000.00
0005432526488	7726	Economy	14000.00
0005432526539	7726	Economy	14000.00
0005432069486	7726	Economy	14000.00
0005434066792	7726	Economy	14000.00
0005432069487	7726	Economy	14000.00
0005434066741	7726	Economy	14000.00
0005432526514	7726	Economy	14000.00
0005432526487	7726	Economy	14000.00
0005432526471	7726	Economy	14000.00
0005434066777	7726	Economy	14000.00
0005434066790	7726	Economy	14000.00
0005432526496	7726	Economy	14000.00
0005432526447	7726	Economy	14000.00
0005432526498	7726	Economy	14000.00
0005434066796	7726	Economy	14000.00
0005432526542	7726	Economy	14000.00
0005432526507	7726	Economy	14000.00
0005432526566	7726	Economy	14000.00
0005434066799	7726	Economy	14000.00
0005432526460	7726	Economy	14000.00
0005432526483	7726	Economy	14000.00
0005432526526	7726	Economy	14000.00
0005432526485	7726	Economy	14000.00
0005432526458	7726	Economy	14000.00
0005434066737	7726	Economy	14000.00
0005432526533	7726	Economy	14000.00
0005432537034	7726	Economy	14000.00
0005432526466	7726	Economy	14000.00
0005432526529	7726	Economy	14000.00
0005432526512	7726	Economy	14000.00
0005435212383	7726	Economy	14000.00
0005432526543	7726	Economy	14000.00
0005432069494	7726	Economy	14000.00
0005434066747	7726	Economy	14000.00
0005435212382	7726	Economy	14000.00
0005432526547	7726	Economy	14000.00
0005432526560	7726	Economy	14000.00
0005432526452	7726	Economy	14000.00
0005432069489	7726	Economy	14000.00
0005432526570	7726	Economy	14000.00
0005432526493	7726	Economy	14000.00
0005434066801	7726	Economy	14000.00
0005432533259	7726	Economy	14000.00
0005434066773	7726	Economy	14000.00
0005434066750	7726	Economy	14000.00
0005434066735	7726	Economy	14000.00
0005432535778	7726	Economy	14000.00
0005432428888	7726	Economy	14000.00
0005432526556	7726	Economy	14000.00
0005434066756	7726	Economy	14000.00
0005432526464	7726	Economy	14000.00
0005432526450	7726	Economy	14000.00
0005432069496	7726	Economy	14000.00
0005434066776	7726	Economy	14000.00
0005432526510	7726	Economy	14000.00
0005432526559	7726	Economy	14000.00
0005432526555	7726	Economy	14000.00
0005435212419	7726	Economy	14000.00
0005432526536	7726	Economy	14000.00
0005432526534	7726	Economy	14000.00
0005434066749	7726	Economy	14000.00
0005432535780	7726	Economy	15400.00
0005432526520	7726	Economy	14000.00
0005432526482	7726	Economy	15400.00
0005432150108	7726	Economy	14000.00
0005432526518	7726	Economy	14000.00
0005434066778	7726	Economy	14000.00
0005434066767	7726	Economy	14000.00
0005432535777	7726	Economy	14000.00
0005432526515	7726	Economy	14000.00
0005432526463	7726	Economy	14000.00
0005432526454	7726	Economy	14000.00
0005432526504	7726	Economy	14000.00
0005432526467	7726	Economy	14000.00
0005432526479	7726	Economy	14000.00
0005432069484	7726	Economy	14000.00
0005434066783	7726	Economy	14000.00
0005432526521	7726	Economy	14000.00
0005434066744	7726	Economy	14000.00
0005434066764	7726	Economy	14000.00
0005432526569	7726	Economy	14000.00
0005432526453	7726	Economy	14000.00
0005432535775	7726	Economy	14000.00
0005432526491	7726	Economy	14000.00
0005432526494	7726	Economy	14000.00
0005432537032	7726	Economy	14000.00
0005434066761	7726	Economy	14000.00
0005432526448	7726	Economy	14000.00
0005432535779	7726	Economy	14000.00
0005432526513	7726	Economy	14000.00
0005434066751	7726	Economy	14000.00
0005432526503	7726	Economy	14000.00
0005432526472	7726	Economy	14000.00
0005432526441	7726	Economy	14000.00
0005435212376	7726	Economy	14000.00
0005432526476	7726	Economy	14000.00
0005432069485	7726	Economy	14000.00
0005432526500	7726	Economy	14000.00
0005434066739	7726	Economy	14000.00
0005434066759	7726	Economy	14000.00
0005435212420	7726	Economy	14000.00
0005432526568	7726	Economy	14000.00
0005434066786	7726	Economy	14000.00
0005434066775	7726	Economy	14000.00
0005434066788	7726	Economy	14000.00
0005432533258	7726	Economy	14000.00
0005432526497	7726	Economy	14000.00
0005435212348	7726	Economy	14000.00
0005434066785	7726	Economy	14000.00
0005432526505	7726	Economy	14000.00
0005434066770	7726	Economy	14000.00
0005434066740	7726	Economy	14000.00
0005434066794	7726	Economy	14000.00
0005432526552	7726	Economy	14000.00
0005432526501	7726	Economy	14000.00
0005434066746	7726	Economy	14000.00
0005434066798	7726	Economy	14000.00
0005435212386	7726	Economy	14000.00
0005432150105	7726	Economy	14000.00
0005432526563	7726	Economy	14000.00
0005434066769	7726	Economy	14000.00
0005432526540	7726	Economy	14000.00
0005432526443	7726	Economy	14000.00
0005434066789	7726	Economy	14000.00
0005432526553	7726	Economy	14000.00
0005432150107	7726	Economy	14000.00
0005432526446	7726	Economy	14000.00
0005432526562	7726	Economy	14000.00
0005432526525	7726	Economy	14000.00
0005432069483	7726	Economy	14000.00
0005432526457	7726	Economy	14000.00
0005434066758	7726	Economy	14000.00
0005432526531	7726	Economy	14000.00
0005432526519	7726	Economy	14000.00
0005432526558	7726	Economy	14000.00
0005434066800	7726	Economy	14000.00
0005432526551	7726	Economy	14000.00
0005432526469	7726	Economy	14000.00
0005434343829	5337	Business	43100.00
0005435612466	5337	Business	43100.00
0005435423589	5337	Business	43100.00
0005435612427	5337	Business	43100.00
0005435612393	5337	Business	43100.00
0005435612439	5337	Business	43100.00
0005435612479	5337	Business	43100.00
0005432133039	5337	Business	43100.00
0005434343833	5337	Business	43100.00
0005435612407	5337	Business	43100.00
0005435612469	5337	Business	43100.00
0005435612443	5337	Business	43100.00
0005434573197	5337	Business	43100.00
0005435423599	5337	Business	43100.00
0005435423640	5337	Comfort	24400.00
0005435612386	5337	Business	43100.00
0005435097103	5337	Comfort	24400.00
0005435612412	5337	Comfort	24400.00
0005435612402	5337	Comfort	24400.00
0005435612434	5337	Comfort	24400.00
0005432133047	5337	Comfort	24400.00
0005432047506	5337	Comfort	24400.00
0005435612389	5337	Comfort	24400.00
0005434343824	5337	Comfort	24400.00
0005435612392	5337	Comfort	24400.00
0005435612476	5337	Comfort	24400.00
0005432133036	5337	Comfort	24400.00
0005435612391	5337	Comfort	24400.00
0005435555344	5337	Comfort	24400.00
0005435423898	5337	Comfort	24400.00
0005435612461	5337	Comfort	24400.00
0005435097100	5337	Comfort	24400.00
0005434573188	5337	Comfort	24400.00
0005434343837	5337	Comfort	24400.00
0005435423641	5337	Comfort	24400.00
0005435612441	5337	Comfort	24400.00
0005435612374	5337	Comfort	24400.00
0005434343823	5337	Comfort	24400.00
0005434573196	5337	Comfort	24400.00
0005434343810	5337	Comfort	24400.00
0005435097107	5337	Comfort	24400.00
0005432133037	5337	Comfort	24400.00
0005434573200	5337	Comfort	24400.00
0005435612444	5337	Economy	14400.00
0005434343822	5337	Economy	14400.00
0005435612475	5337	Economy	14400.00
0005435612463	5337	Economy	14400.00
0005434343835	5337	Economy	14400.00
0005435612426	5337	Economy	14400.00
0005435612377	5337	Economy	14400.00
0005435612387	5337	Economy	14400.00
0005435097101	5337	Economy	14400.00
0005435555345	5337	Economy	14400.00
0005435612445	5337	Economy	14400.00
0005435612406	5337	Economy	14400.00
0005435612450	5337	Economy	14400.00
0005432133042	5337	Economy	14400.00
0005434573194	5337	Economy	14400.00
0005435612471	5337	Economy	14400.00
0005435423587	5337	Economy	14400.00
0005435423676	5337	Economy	14400.00
0005435612373	5337	Economy	14400.00
0005434343804	5337	Economy	14400.00
0005432133043	5337	Economy	14400.00
0005435612474	5337	Economy	14400.00
0005434573195	5337	Economy	14400.00
0005435423707	5337	Economy	14400.00
0005435423595	5337	Economy	14400.00
0005435612384	5337	Economy	14400.00
0005435612447	5337	Economy	14400.00
0005432133045	5337	Economy	14400.00
0005435097108	5337	Economy	14400.00
0005435612395	5337	Economy	14400.00
0005435612423	5337	Economy	14400.00
0005435612416	5337	Economy	14400.00
0005435612372	5337	Economy	14400.00
0005434244456	5337	Economy	14400.00
0005435423836	5337	Economy	14400.00
0005432133038	5337	Economy	14400.00
0005435612435	5337	Economy	14400.00
0005435097109	5337	Economy	14400.00
0005435612473	5337	Economy	14400.00
0005435423716	5337	Economy	14400.00
0005435612418	5337	Economy	14400.00
0005435555347	5337	Economy	14400.00
0005432133044	5337	Economy	14400.00
0005435612428	5337	Economy	14400.00
0005435612388	5337	Economy	15800.00
0005432047508	5337	Economy	14400.00
0005435612480	5337	Economy	14400.00
0005435423692	5337	Economy	14400.00
0005435612419	5337	Economy	14400.00
0005435612379	5337	Economy	14400.00
0005435612456	5337	Economy	14400.00
0005435612399	5337	Economy	14400.00
0005435612478	5337	Economy	14400.00
0005434343834	5337	Economy	14400.00
0005434343802	5337	Economy	14400.00
0005435490187	5337	Economy	14400.00
0005435612438	5337	Economy	14400.00
0005435423639	5337	Economy	14400.00
0005435612378	5337	Economy	14400.00
0005434343807	5337	Economy	14400.00
0005435612483	5337	Economy	14400.00
0005435612431	5337	Economy	14400.00
0005435612446	5337	Economy	14400.00
0005435423843	5337	Economy	14400.00
0005434343832	5337	Economy	14400.00
0005435612369	5337	Economy	14400.00
0005434244484	5337	Economy	14400.00
0005434343799	5337	Economy	14400.00
0005432047507	5337	Economy	14400.00
0005435612436	5337	Economy	14400.00
0005435612396	5337	Economy	14400.00
0005435423835	5337	Economy	14400.00
0005435612432	5337	Economy	14400.00
0005435612464	5337	Economy	14400.00
0005435423796	5337	Economy	14400.00
0005435612468	5337	Economy	14400.00
0005435612459	5337	Economy	14400.00
0005435612413	5337	Economy	14400.00
0005435612437	5337	Economy	14400.00
0005435612451	5337	Economy	14400.00
0005434343805	5337	Economy	14400.00
0005435612403	5337	Economy	14400.00
0005435612364	5337	Economy	14400.00
0005434343800	5337	Economy	14400.00
0005435612458	5337	Economy	14400.00
0005435612465	5337	Economy	14400.00
0005435491415	5337	Economy	14400.00
0005434343820	5337	Economy	14400.00
0005435612383	5337	Economy	14400.00
0005435612424	5337	Economy	14400.00
0005435612400	5337	Economy	14400.00
0005434343828	5337	Economy	14400.00
0005435097105	5337	Economy	14400.00
0005435423588	5337	Economy	14400.00
0005434343827	5337	Economy	14400.00
0005435612460	5337	Economy	14400.00
0005434343831	5337	Economy	14400.00
0005435097104	5337	Economy	14400.00
0005435612380	5337	Economy	14400.00
0005434343801	5337	Economy	14400.00
0005435423622	5337	Economy	14400.00
0005435612382	5337	Economy	14400.00
0005435491416	5337	Economy	14400.00
0005435612452	5337	Economy	14400.00
0005435612454	5337	Economy	14400.00
0005435612414	5337	Economy	14400.00
0005435097106	5337	Economy	14400.00
0005435612477	5337	Economy	14400.00
0005435612370	5337	Economy	14400.00
0005435612453	5337	Economy	14400.00
0005434343830	5337	Economy	14400.00
0005435612398	5337	Economy	14400.00
0005434343808	5337	Economy	14400.00
0005435612401	5337	Economy	14400.00
0005435612482	5337	Economy	14400.00
0005434343825	5337	Economy	14400.00
0005434343803	5337	Economy	14400.00
0005435423601	5337	Economy	14400.00
0005434343818	5337	Economy	15800.00
0005435612420	5337	Economy	15800.00
0005435612433	5337	Economy	15800.00
0005434573198	5337	Economy	15800.00
0005434343809	5337	Economy	15800.00
0005435612365	5337	Economy	15800.00
0005435612410	5337	Economy	14400.00
0005435423598	5337	Economy	14400.00
0005435423631	5337	Economy	14400.00
0005435423685	5337	Economy	14400.00
0005435612411	5337	Economy	14400.00
0005435097099	5337	Economy	14400.00
0005435612404	5337	Economy	14400.00
0005434573199	5337	Economy	14400.00
0005435423788	5337	Economy	14400.00
0005434343836	5337	Economy	14400.00
0005435612472	5337	Economy	14400.00
0005435612368	5337	Economy	14400.00
0005435423691	5337	Economy	14400.00
0005435612405	5337	Economy	14400.00
0005435612449	5337	Economy	14400.00
0005435612470	5337	Economy	14400.00
0005435612421	5337	Economy	14400.00
0005432133041	5337	Economy	14400.00
0005434343813	5337	Economy	14400.00
0005435612390	5337	Economy	14400.00
0005432133046	5337	Economy	14400.00
0005435490185	5337	Economy	14400.00
0005434573201	5337	Economy	14400.00
0005435612381	5337	Economy	14400.00
0005432133040	5337	Economy	14400.00
0005435612367	5337	Economy	14400.00
0005434573191	5337	Economy	14400.00
0005434343819	5337	Economy	14400.00
0005434343816	5337	Economy	14400.00
0005435612408	5337	Economy	14400.00
0005435612429	5337	Economy	14400.00
0005435612481	5337	Economy	14400.00
0005435612448	5337	Economy	14400.00
0005434343806	5337	Economy	14400.00
0005435612366	5337	Economy	14400.00
0005434343811	5337	Economy	14400.00
0005435612455	5337	Economy	14400.00
0005435302119	5337	Economy	14400.00
0005434343826	5337	Economy	14400.00
0005435097102	5337	Economy	14400.00
0005435612376	5337	Economy	14400.00
0005435612415	5337	Economy	14400.00
0005435612375	5337	Economy	14400.00
0005435612430	5337	Economy	14400.00
0005434343814	5337	Economy	14400.00
0005435612467	5337	Economy	14400.00
0005435612422	5337	Economy	14400.00
0005434343821	5337	Economy	14400.00
0005435612440	5337	Economy	14400.00
0005435612462	5337	Economy	14400.00
0005435423844	5337	Economy	14400.00
0005432047509	5337	Economy	14400.00
0005435319423	5337	Economy	14400.00
0005435423576	5337	Economy	14400.00
0005434573190	5337	Economy	14400.00
0005435490186	5337	Economy	14400.00
0005434573202	5337	Economy	14400.00
0005435612417	5337	Economy	14400.00
0005435612363	5337	Economy	14400.00
0005434343812	5337	Economy	14400.00
0005434573193	5337	Economy	14400.00
0005435612397	5337	Economy	14400.00
0005435612394	5337	Economy	14400.00
0005435612442	5337	Economy	14400.00
0005434343815	5337	Economy	14400.00
0005434244473	5337	Economy	14400.00
0005435612457	5337	Economy	14400.00
0005435612409	5337	Economy	14400.00
0005434573192	5337	Economy	14400.00
0005435555346	5337	Economy	14400.00
0005434343817	5337	Economy	14400.00
0005432133048	5337	Economy	14400.00
0005435612371	5337	Economy	14400.00
0005435612385	5337	Economy	14400.00
0005434573189	5337	Economy	14400.00
0005435612425	5337	Economy	14400.00
0005432133035	5337	Economy	14400.00
0005432166864	10926	Business	43100.00
0005435423998	10926	Business	43100.00
0005434244644	10926	Business	43100.00
0005434244647	10926	Business	43100.00
0005435424003	10926	Business	43100.00
0005435319476	10926	Business	43100.00
0005435424028	10926	Business	43100.00
0005435424034	10926	Business	43100.00
0005432363382	10926	Business	43100.00
0005434244655	10926	Business	43100.00
0005435380241	10926	Business	43100.00
0005432164954	10926	Business	43100.00
0005433719102	10926	Business	43100.00
0005435424014	10926	Comfort	24400.00
0005434244649	10926	Comfort	24400.00
0005435424067	10926	Comfort	24400.00
0005435380244	10926	Comfort	24400.00
0005434244640	10926	Comfort	24400.00
0005435424016	10926	Comfort	24400.00
0005435424002	10926	Comfort	24400.00
0005434244646	10926	Comfort	24400.00
0005434244663	10926	Comfort	24400.00
0005435424051	10926	Comfort	24400.00
0005434244662	10926	Comfort	24400.00
0005432363377	10926	Comfort	24400.00
0005435424058	10926	Comfort	24400.00
0005434244661	10926	Comfort	24400.00
0005435424022	10926	Economy	14400.00
0005435380246	10926	Economy	14400.00
0005433719103	10926	Economy	14400.00
0005434244660	10926	Economy	14400.00
0005435424032	10926	Economy	14400.00
0005435424033	10926	Economy	14400.00
0005432164955	10926	Economy	14400.00
0005435380240	10926	Economy	14400.00
0005435424062	10926	Economy	14400.00
0005435424001	10926	Economy	14400.00
0005435424063	10926	Economy	14400.00
0005435319473	10926	Economy	14400.00
0005434244656	10926	Economy	14400.00
0005435319475	10926	Economy	14400.00
0005435424040	10926	Economy	14400.00
0005432840989	10926	Economy	14400.00
0005434244664	10926	Economy	14400.00
0005435424054	10926	Economy	14400.00
0005432164951	10926	Economy	14400.00
0005435424068	10926	Economy	14400.00
0005434656533	10926	Economy	14400.00
0005432363380	10926	Economy	15800.00
0005435424049	10926	Economy	15800.00
0005432164953	10926	Economy	14400.00
0005435319469	10926	Economy	15800.00
0005435424048	10926	Economy	15800.00
0005435424044	10926	Economy	14400.00
0005435319471	10926	Economy	14400.00
0005433719101	10926	Economy	14400.00
0005434244659	10926	Economy	14400.00
0005435424064	10926	Economy	14400.00
0005435424007	10926	Economy	14400.00
0005434244658	10926	Economy	14400.00
0005435424018	10926	Economy	14400.00
0005435424020	10926	Economy	14400.00
0005432164950	10926	Economy	14400.00
0005435424008	10926	Economy	14400.00
0005435424023	10926	Economy	14400.00
0005434244651	10926	Economy	14400.00
0005434244635	10926	Economy	14400.00
0005434244654	10926	Economy	14400.00
0005434244645	10926	Economy	14400.00
0005435424065	10926	Economy	14400.00
0005432164949	10926	Economy	14400.00
0005435424061	10926	Economy	14400.00
0005435424017	10926	Economy	14400.00
0005434244634	10926	Economy	14400.00
0005432166863	10926	Economy	14400.00
0005435424042	10926	Economy	14400.00
0005435424000	10926	Economy	14400.00
0005435424006	10926	Economy	14400.00
0005435424005	10926	Economy	14400.00
0005435424012	10926	Economy	14400.00
0005432840990	10926	Economy	14400.00
0005435424013	10926	Economy	14400.00
0005435424015	10926	Economy	14400.00
0005435424030	10926	Economy	14400.00
0005435423999	10926	Economy	14400.00
0005435424025	10926	Economy	14400.00
0005434244652	10926	Economy	14400.00
0005435424043	10926	Economy	14400.00
0005435319468	10926	Economy	14400.00
0005435319474	10926	Economy	14400.00
0005435424024	10926	Economy	14400.00
0005435319477	10926	Economy	14400.00
0005435424036	10926	Economy	14400.00
0005434244639	10926	Economy	14400.00
0005435424050	10926	Economy	14400.00
0005435424004	10926	Economy	14400.00
0005434244642	10926	Economy	15800.00
0005435424052	10926	Economy	15800.00
0005434656532	10926	Economy	15800.00
0005435424047	10926	Economy	15800.00
0005434244637	10926	Economy	14400.00
0005435380245	10926	Economy	14400.00
0005435424031	10926	Economy	14400.00
0005432363379	10926	Economy	14400.00
0005435424019	10926	Economy	14400.00
0005435424037	10926	Economy	14400.00
0005435380242	10926	Economy	14400.00
0005435424057	10926	Economy	14400.00
0005435424041	10926	Economy	14400.00
0005432166865	10926	Economy	14400.00
0005435424046	10926	Economy	14400.00
0005432363378	10926	Economy	14400.00
0005435424026	10926	Economy	14400.00
0005432166866	10926	Economy	14400.00
0005435319470	10926	Economy	14400.00
0005434244636	10926	Economy	14400.00
0005435319472	10926	Economy	14400.00
0005434244653	10926	Economy	14400.00
0005433719104	10926	Economy	14400.00
0005435424011	10926	Economy	14400.00
0005434244648	10926	Economy	14400.00
0005435424029	10926	Economy	14400.00
0005432164952	10926	Economy	14400.00
0005435424066	10926	Economy	14400.00
0005435042831	10926	Economy	14400.00
0005434244657	10926	Economy	14400.00
0005434244650	10926	Economy	14400.00
0005435424055	10926	Economy	14400.00
0005435424059	10926	Economy	14400.00
0005434244641	10926	Economy	14400.00
0005435424010	10926	Economy	14400.00
0005435424045	10926	Economy	14400.00
0005434244638	10926	Economy	14400.00
0005435424056	10926	Economy	14400.00
0005435424060	10926	Economy	14400.00
0005435424021	10926	Economy	14400.00
0005434244643	10926	Economy	14400.00
0005435424053	10926	Economy	14400.00
0005435424035	10926	Economy	14400.00
0005435380243	10926	Economy	14400.00
0005435424009	10926	Economy	14400.00
0005435424038	10926	Economy	14400.00
0005432363381	10926	Economy	14400.00
0005435424027	10926	Economy	14400.00
0005435424039	10926	Economy	14400.00
0005435042832	10926	Economy	14400.00
0005433633427	3320	Business	18800.00
0005433633455	3320	Business	18800.00
0005432181475	3320	Business	18800.00
0005433506963	3320	Business	18800.00
0005432181456	3320	Business	18800.00
0005432181463	3320	Business	18800.00
0005432181466	3320	Business	18800.00
0005432181464	3320	Business	18800.00
0005433633445	3320	Business	18800.00
0005433633446	3320	Business	18800.00
0005433506980	3320	Business	18800.00
0005432181461	3320	Business	18800.00
0005433633433	3320	Business	18800.00
0005433506978	3320	Business	18800.00
0005432458956	3320	Business	18800.00
0005433804993	3320	Business	18800.00
0005433506969	3320	Business	18800.00
0005433633449	3320	Business	18800.00
0005433804988	3320	Business	18800.00
0005433805001	3320	Business	18800.00
0005433506973	3320	Business	18800.00
0005433633429	3320	Economy	6900.00
0005433805000	3320	Economy	6900.00
0005433804985	3320	Economy	6900.00
0005433506977	3320	Economy	6300.00
0005432181470	3320	Economy	6300.00
0005433633443	3320	Economy	6300.00
0005433804969	3320	Economy	6300.00
0005433804970	3320	Economy	6300.00
0005433506961	3320	Economy	6300.00
0005433633431	3320	Economy	6300.00
0005433804973	3320	Economy	6300.00
0005433506965	3320	Economy	6300.00
0005433804986	3320	Economy	6300.00
0005432181471	3320	Economy	6300.00
0005433633450	3320	Economy	6300.00
0005433633452	3320	Economy	6300.00
0005433804978	3320	Economy	6300.00
0005433804975	3320	Economy	6300.00
0005433506960	3320	Economy	6300.00
0005433804968	3320	Economy	6300.00
0005432181468	3320	Economy	6300.00
0005433633448	3320	Economy	6300.00
0005433506976	3320	Economy	6300.00
0005433633425	3320	Economy	6300.00
0005433633437	3320	Economy	6300.00
0005433633447	3320	Economy	6300.00
0005433633423	3320	Economy	6300.00
0005433804981	3320	Economy	6300.00
0005432459007	3320	Economy	6300.00
0005433633426	3320	Economy	6300.00
0005433804992	3320	Economy	6300.00
0005433804972	3320	Economy	6300.00
0005432181477	3320	Economy	6300.00
0005433804989	3320	Economy	6300.00
0005433633434	3320	Economy	6300.00
0005432181459	3320	Economy	6300.00
0005433804979	3320	Economy	6300.00
0005433506967	3320	Economy	6300.00
0005433633428	3320	Economy	6300.00
0005433506981	3320	Economy	6300.00
0005433633430	3320	Economy	6300.00
0005433633436	3320	Economy	6300.00
0005433506975	3320	Economy	6300.00
0005432181476	3320	Economy	6300.00
0005433506966	3320	Economy	6300.00
0005433506974	3320	Economy	6300.00
0005433633453	3320	Economy	6300.00
0005433506959	3320	Economy	6900.00
0005433804996	3320	Economy	6900.00
0005432459031	3320	Economy	6900.00
0005433804999	3320	Economy	6300.00
0005433633441	3320	Economy	6300.00
0005432181458	3320	Economy	6300.00
0005432181462	3320	Economy	6300.00
0005433633454	3320	Economy	6900.00
0005433804991	3320	Economy	6300.00
0005433633451	3320	Economy	6300.00
0005432181455	3320	Economy	6300.00
0005433633442	3320	Economy	6300.00
0005433633439	3320	Economy	6300.00
0005433804977	3320	Economy	6300.00
0005433506962	3320	Economy	6300.00
0005433804982	3320	Economy	6300.00
0005433804998	3320	Economy	6300.00
0005433633422	3320	Economy	6300.00
0005432181472	3320	Economy	6300.00
0005433633440	3320	Economy	6300.00
0005433633438	3320	Economy	6300.00
0005432181478	3320	Economy	6300.00
0005432459008	3320	Economy	6300.00
0005433805002	3320	Economy	6300.00
0005433805003	3320	Economy	6300.00
0005433804984	3320	Economy	6300.00
0005433804980	3320	Economy	6300.00
0005433506971	3320	Economy	6300.00
0005432181457	3320	Economy	6300.00
0005433804994	3320	Economy	6300.00
0005432181473	3320	Economy	6300.00
0005433633424	3320	Economy	6300.00
0005433633456	3320	Economy	6300.00
0005433804976	3320	Economy	6300.00
0005433506968	3320	Economy	6300.00
0005433633435	3320	Economy	6300.00
0005433804997	3320	Economy	6300.00
0005433506979	3320	Economy	6300.00
0005433506964	3320	Economy	6300.00
0005433633444	3320	Economy	6300.00
0005433804995	3320	Economy	6300.00
0005432181474	3320	Economy	6300.00
0005433633432	3320	Economy	6300.00
0005433506972	3320	Economy	6300.00
0005432181467	3320	Economy	6300.00
0005433804990	3320	Economy	6300.00
0005432181469	3320	Economy	6300.00
0005433804983	3320	Economy	6300.00
0005433804974	3320	Economy	6300.00
0005433506970	3320	Economy	6300.00
0005432181465	3320	Economy	6300.00
0005433804987	3320	Economy	6300.00
0005432181460	3320	Economy	6300.00
0005433804971	3320	Economy	6300.00
0005432458980	3320	Economy	6300.00
0005435884403	3321	Business	18800.00
0005435884377	3321	Business	18800.00
0005435884426	3321	Business	18800.00
0005435884444	3321	Business	18800.00
0005435884384	3321	Economy	6300.00
0005435884376	3321	Economy	6300.00
0005435884394	3321	Economy	6300.00
0005435884574	3321	Economy	6300.00
0005435884519	3321	Economy	6300.00
0005435884554	3321	Economy	6300.00
0005435884423	3321	Economy	6300.00
0005435884518	3321	Economy	6300.00
0005435884378	3321	Economy	6300.00
0005435884566	3321	Economy	6300.00
0005435884520	3321	Economy	6300.00
0005435884457	3321	Economy	6300.00
0005435884395	3321	Economy	6300.00
0005435884565	3321	Economy	6300.00
0005435884559	3321	Economy	6300.00
0005435884710	8170	Business	18800.00
0005432459325	8170	Business	18800.00
0005435884676	8170	Business	18800.00
0005435884684	8170	Business	18800.00
0005432459329	8170	Business	18800.00
0005432459309	8170	Business	18800.00
0005432459326	8170	Business	18800.00
0005432459323	8170	Business	18800.00
0005435884706	8170	Business	18800.00
0005432042560	8170	Business	18800.00
0005432459290	8170	Business	18800.00
0005435884681	8170	Business	18800.00
0005435884704	8170	Business	18800.00
0005432042555	8170	Business	18800.00
0005435884720	8170	Business	18800.00
0005435884713	8170	Business	18800.00
0005433506863	8170	Business	18800.00
0005432459287	8170	Economy	6900.00
0005435884702	8170	Economy	6900.00
0005432042553	8170	Economy	6900.00
0005435884678	8170	Economy	6900.00
0005435884715	8170	Economy	6900.00
0005432459300	8170	Economy	6900.00
0005435884701	8170	Economy	6300.00
0005432459296	8170	Economy	6300.00
0005435884699	8170	Economy	6300.00
0005432459327	8170	Economy	6300.00
0005432042556	8170	Economy	6300.00
0005432459319	8170	Economy	6300.00
0005432042558	8170	Economy	6300.00
0005435884682	8170	Economy	6300.00
0005432459292	8170	Economy	6300.00
0005435884721	8170	Economy	6300.00
0005435884695	8170	Economy	6300.00
0005432042563	8170	Economy	6300.00
0005432459285	8170	Economy	6300.00
0005432459310	8170	Economy	6300.00
0005435884716	8170	Economy	6300.00
0005432459317	8170	Economy	6300.00
0005432459298	8170	Economy	6300.00
0005435884693	8170	Economy	6300.00
0005435884677	8170	Economy	6300.00
0005432459320	8170	Economy	6300.00
0005432459289	8170	Economy	6300.00
0005432459308	8170	Economy	6300.00
0005435884700	8170	Economy	6300.00
0005432042562	8170	Economy	6300.00
0005435884705	8170	Economy	6300.00
0005432459306	8170	Economy	6300.00
0005432459291	8170	Economy	6300.00
0005435884696	8170	Economy	6300.00
0005432042559	8170	Economy	6300.00
0005435884714	8170	Economy	6300.00
0005435884685	8170	Economy	6300.00
0005432459297	8170	Economy	6300.00
0005435884712	8170	Economy	6300.00
0005432459278	8170	Economy	6300.00
0005434312296	8170	Economy	6300.00
0005432042554	8170	Economy	6300.00
0005434312297	8170	Economy	6300.00
0005432459328	8170	Economy	6300.00
0005432459324	8170	Economy	6300.00
0005432459315	8170	Economy	6300.00
0005432042564	8170	Economy	6900.00
0005432459284	8170	Economy	6900.00
0005435884718	8170	Economy	6900.00
0005435884711	8170	Economy	6900.00
0005432459303	8170	Economy	6300.00
0005432459288	8170	Economy	6300.00
0005435884687	8170	Economy	6300.00
0005435884708	8170	Economy	6900.00
0005435884692	8170	Economy	6300.00
0005435884683	8170	Economy	6300.00
0005432459318	8170	Economy	6300.00
0005435884680	8170	Economy	6300.00
0005435884689	8170	Economy	6300.00
0005435884709	8170	Economy	6300.00
0005432459295	8170	Economy	6300.00
0005435884697	8170	Economy	6300.00
0005435884679	8170	Economy	6300.00
0005432459281	8170	Economy	6300.00
0005432459307	8170	Economy	6300.00
0005435884694	8170	Economy	6300.00
0005435884686	8170	Economy	6300.00
0005435884719	8170	Economy	6300.00
0005432459302	8170	Economy	6300.00
0005432459283	8170	Economy	6300.00
0005432459301	8170	Economy	6300.00
0005435884703	8170	Economy	6300.00
0005432042557	8170	Economy	6300.00
0005432459294	8170	Economy	6300.00
0005432042565	8170	Economy	6300.00
0005432042561	8170	Economy	6300.00
0005432459313	8170	Economy	6300.00
0005433506886	8170	Economy	6300.00
0005432459322	8170	Economy	6300.00
0005432459314	8170	Economy	6300.00
0005435884707	8170	Economy	6300.00
0005435884717	8170	Economy	6300.00
0005435884688	8170	Economy	6300.00
0005433506869	8170	Economy	6300.00
0005432459316	8170	Economy	6300.00
0005432459279	8170	Economy	6300.00
0005435884690	8170	Economy	6300.00
0005432459304	8170	Economy	6300.00
0005432459305	8170	Economy	6300.00
0005432459312	8170	Economy	6300.00
0005435884698	8170	Economy	6300.00
0005435884691	8170	Economy	6300.00
0005432459299	8170	Economy	6300.00
0005432459280	8170	Economy	6300.00
0005432459286	8170	Economy	6300.00
0005432459293	8170	Economy	6300.00
0005432459321	8170	Economy	6300.00
0005432459311	8170	Economy	6300.00
0005432459282	8170	Economy	6300.00
0005432042566	8170	Economy	6300.00
0005432459277	8170	Economy	6300.00
0005433633215	8174	Business	18800.00
0005433633233	8174	Business	18800.00
0005433633246	8174	Business	18800.00
0005433804806	8174	Economy	6300.00
0005433804841	8174	Economy	6300.00
0005433633214	8174	Economy	6300.00
0005433633213	8174	Economy	6300.00
0005433633232	8174	Economy	6300.00
0005433804790	8174	Economy	6300.00
0005433804842	8174	Economy	6300.00
0005434183543	8176	Business	18800.00
0005433722145	4625	Business	9900.00
0005433722147	4625	Business	9900.00
0005432382735	4625	Business	9900.00
0005432382763	4625	Business	9900.00
0005432382766	4625	Business	9900.00
0005432382733	4625	Business	9900.00
0005432727797	4625	Business	9900.00
0005432382739	4625	Business	9900.00
0005433453742	4625	Business	9900.00
0005432382753	4625	Economy	3300.00
0005432382747	4625	Economy	3300.00
0005432727799	4625	Economy	3300.00
0005432382765	4625	Economy	3300.00
0005433722144	4625	Economy	3300.00
0005433722143	4625	Economy	3300.00
0005432382738	4625	Economy	3300.00
0005432382743	4625	Economy	3600.00
0005432727792	4625	Economy	3600.00
0005433722142	4625	Economy	3600.00
0005432382751	4625	Economy	3300.00
0005432727795	4625	Economy	3300.00
0005432382727	4625	Economy	3300.00
0005432727793	4625	Economy	3300.00
0005432382730	4625	Economy	3300.00
0005433722146	4625	Economy	3300.00
0005432382758	4625	Economy	3300.00
0005433453741	4625	Economy	3300.00
0005432382731	4625	Economy	3300.00
0005432382760	4625	Economy	3300.00
0005432382761	4625	Economy	3300.00
0005432382752	4625	Economy	3300.00
0005433454851	4625	Economy	3300.00
0005432382749	4625	Economy	3300.00
0005432727803	4625	Economy	3300.00
0005433722148	4625	Economy	3300.00
0005433722150	4625	Economy	3300.00
0005432382764	4625	Economy	3300.00
0005432382734	4625	Economy	3300.00
0005432382748	4625	Economy	3300.00
0005432382742	4625	Economy	3300.00
0005433722141	4625	Economy	3300.00
0005432382762	4625	Economy	3300.00
0005432382757	4625	Economy	3300.00
0005433722154	4625	Economy	3300.00
0005432382754	4625	Economy	3300.00
0005432382755	4625	Economy	3300.00
0005432382756	4625	Economy	3300.00
0005432382736	4625	Economy	3300.00
0005433722151	4625	Economy	3300.00
0005432727801	4625	Economy	3300.00
0005432382750	4625	Economy	3300.00
0005432382741	4625	Economy	3300.00
0005433453740	4625	Economy	3300.00
0005432382728	4625	Economy	3300.00
0005432382740	4625	Economy	3300.00
0005432727798	4625	Economy	3300.00
0005433722152	4625	Economy	3300.00
0005432382744	4625	Economy	3300.00
0005432382759	4625	Economy	3300.00
0005432727804	4625	Economy	3300.00
0005432382746	4625	Economy	3300.00
0005433722149	4625	Economy	3300.00
0005433722153	4625	Economy	3300.00
0005432727796	4625	Economy	3300.00
0005432727802	4625	Economy	3300.00
0005432382737	4625	Economy	3300.00
0005432382745	4625	Economy	3300.00
0005432382729	4625	Economy	3300.00
0005432727794	4625	Economy	3300.00
0005432382732	4625	Economy	3300.00
0005432727800	4625	Economy	3300.00
0005432727751	30217	Economy	3300.00
0005432727724	30217	Economy	3300.00
0005435529011	1769	Business	57200.00
0005435529020	1769	Business	57200.00
0005433516782	1769	Business	57200.00
0005435540762	1769	Business	57200.00
0005435529018	1769	Business	57200.00
0005435540765	1769	Business	57200.00
0005435529014	1769	Economy	19100.00
0005435529012	1769	Economy	19100.00
0005435540769	1769	Economy	19100.00
0005432294461	1769	Economy	19100.00
0005435529019	1769	Economy	21000.00
0005435529022	1769	Economy	21000.00
0005435540764	1769	Economy	21000.00
0005435540768	1769	Economy	19100.00
0005435529030	1769	Economy	19100.00
0005435529029	1769	Economy	19100.00
0005435540771	1769	Economy	19100.00
0005435540763	1769	Economy	19100.00
0005435529024	1769	Economy	19100.00
0005433516781	1769	Economy	19100.00
0005435529025	1769	Economy	19100.00
0005435540760	1769	Economy	19100.00
0005435529023	1769	Economy	19100.00
0005433516785	1769	Economy	19100.00
0005435529016	1769	Economy	19100.00
0005435540773	1769	Economy	19100.00
0005435540774	1769	Economy	19100.00
0005435529032	1769	Economy	19100.00
0005435540776	1769	Economy	19100.00
0005435529017	1769	Economy	19100.00
0005435529031	1769	Economy	19100.00
0005435529028	1769	Economy	19100.00
0005435540767	1769	Economy	19100.00
0005435540777	1769	Economy	19100.00
0005435540758	1769	Economy	19100.00
0005433516779	1769	Economy	19100.00
0005432294460	1769	Economy	19100.00
0005435540775	1769	Economy	19100.00
0005435540757	1769	Economy	19100.00
0005435529021	1769	Economy	19100.00
0005435529033	1769	Economy	19100.00
0005435540761	1769	Economy	19100.00
0005435529027	1769	Economy	19100.00
0005433516783	1769	Economy	19100.00
0005435540759	1769	Economy	19100.00
0005433516784	1769	Economy	19100.00
0005433516780	1769	Economy	19100.00
0005433516786	1769	Economy	19100.00
0005435529026	1769	Economy	19100.00
0005433516778	1769	Economy	19100.00
0005435540756	1769	Economy	19100.00
0005435540770	1769	Economy	19100.00
0005435529013	1769	Economy	19100.00
0005435540766	1769	Economy	19100.00
0005435529015	1769	Economy	19100.00
0005435540772	1769	Economy	19100.00
0005433516747	21970	Business	57200.00
0005432924985	21970	Business	57200.00
0005433516724	21970	Business	57200.00
0005433516722	21970	Economy	19100.00
0005432924982	21970	Economy	19100.00
0005435517606	21970	Economy	19100.00
0005432924984	21970	Economy	19100.00
0005433516723	21970	Economy	19100.00
0005435517605	21970	Economy	19100.00
0005432924983	21970	Economy	19100.00
0005435540666	21970	Economy	19100.00
0005435540665	21970	Economy	19100.00
0005432838687	7382	Business	18500.00
0005432838672	7382	Business	18500.00
0005432073350	7382	Business	18500.00
0005434458563	7382	Business	18500.00
0005435252413	7382	Business	18500.00
0005432838700	7382	Business	18500.00
0005432838674	7382	Business	18500.00
0005434458570	7382	Business	18500.00
0005434458580	7382	Business	18500.00
0005434458575	7382	Business	18500.00
0005432838701	7382	Business	18500.00
0005434458578	7382	Economy	6200.00
0005432838692	7382	Economy	6200.00
0005435252390	7382	Economy	6200.00
0005432838686	7382	Economy	6200.00
0005432838696	7382	Economy	6200.00
0005432840988	7382	Economy	6200.00
0005432838699	7382	Economy	6800.00
0005432838678	7382	Economy	6800.00
0005434458574	7382	Economy	6800.00
0005432073351	7382	Economy	6200.00
0005432838683	7382	Economy	6200.00
0005434458581	7382	Economy	6200.00
0005432838691	7382	Economy	6200.00
0005432838702	7382	Economy	6200.00
0005432838689	7382	Economy	6200.00
0005432838679	7382	Economy	6200.00
0005435252414	7382	Economy	6200.00
0005432838693	7382	Economy	6200.00
0005432838685	7382	Economy	6200.00
0005435252403	7382	Economy	6200.00
0005434458569	7382	Economy	6200.00
0005434458571	7382	Economy	6200.00
0005432838688	7382	Economy	6200.00
0005432838681	7382	Economy	6200.00
0005434458573	7382	Economy	6200.00
0005434458564	7382	Economy	6200.00
0005434458562	7382	Economy	6200.00
0005434458579	7382	Economy	6200.00
0005432838695	7382	Economy	6200.00
0005432838675	7382	Economy	6200.00
0005432073353	7382	Economy	6200.00
0005432823426	7382	Economy	6200.00
0005432838690	7382	Economy	6200.00
0005432838680	7382	Economy	6200.00
0005432838673	7382	Economy	6200.00
0005432838697	7382	Economy	6200.00
0005434458561	7382	Economy	6200.00
0005432838677	7382	Economy	6200.00
0005432840987	7382	Economy	6200.00
0005432823425	7382	Economy	6200.00
0005434458577	7382	Economy	6200.00
0005432073352	7382	Economy	6200.00
0005435252399	7382	Economy	6200.00
0005434458572	7382	Economy	6200.00
0005434458568	7382	Economy	6200.00
0005434458565	7382	Economy	6200.00
0005432838694	7382	Economy	6200.00
0005432838676	7382	Economy	6200.00
0005432838698	7382	Economy	6200.00
0005434458576	7382	Economy	6200.00
0005432838682	7382	Economy	6200.00
0005434458582	7382	Economy	6200.00
0005435252389	7382	Economy	6200.00
0005434458566	7382	Economy	6200.00
0005434458567	7382	Economy	6200.00
0005432838684	7382	Economy	6200.00
0005435252391	7382	Economy	6200.00
0005435252499	28895	Business	18500.00
0005435252507	28895	Business	18500.00
0005435252506	28895	Business	18500.00
0005435252502	28895	Business	18500.00
0005435252492	28895	Business	18500.00
0005435252504	28895	Business	18500.00
0005435252495	28895	Economy	6200.00
0005435252505	28895	Economy	6200.00
0005432838526	28895	Economy	6200.00
0005435491417	28895	Economy	6200.00
0005435252503	28895	Economy	6200.00
0005435491418	28895	Economy	6200.00
0005435252508	28895	Economy	6800.00
0005435252497	28895	Economy	6200.00
0005435252491	28895	Economy	6200.00
0005434458438	28895	Economy	6200.00
0005432838507	28895	Economy	6200.00
0005432838520	28895	Economy	6200.00
0005434458439	28895	Economy	6200.00
0005432001001	28895	Economy	6200.00
0005432001000	28895	Economy	6200.00
0005434664934	28895	Economy	6200.00
0005432840976	28895	Economy	6200.00
0005432001002	28895	Economy	6200.00
0005434664935	28895	Economy	6200.00
0005435252501	28895	Economy	6200.00
0005432838528	28895	Economy	6200.00
0005435491419	28895	Economy	6200.00
0005435252493	28895	Economy	6200.00
0005434458490	28895	Economy	6200.00
0005434458471	28895	Economy	6200.00
0005435252498	28895	Economy	6200.00
0005435252494	28895	Economy	6200.00
0005432838627	28895	Economy	6200.00
0005435252496	28895	Economy	6200.00
0005432838527	28895	Economy	6200.00
0005434664933	28895	Economy	6200.00
0005434458453	28895	Economy	6200.00
0005435252500	28895	Economy	6200.00
0005432838481	28895	Economy	6200.00
0005435990543	8793	Business	145300.00
0005434275949	8793	Economy	48400.00
0005435990546	8793	Economy	53300.00
0005435990541	8793	Economy	48400.00
0005435990547	8793	Economy	48400.00
0005435990545	8793	Economy	48400.00
0005435990544	8793	Economy	48400.00
0005435990540	8793	Economy	48400.00
0005435990542	8793	Economy	48400.00
0005434275939	8793	Economy	48400.00
0005434275948	8793	Economy	48400.00
0005434275963	15726	Business	145300.00
0005435990508	15726	Economy	48400.00
0005434275959	15726	Economy	48400.00
0005434275960	15726	Economy	48400.00
0005434275964	15726	Economy	48400.00
0005434275961	15726	Economy	48400.00
0005434275962	15726	Economy	48400.00
0005433476855	20627	Economy	14500.00
0005432427118	20627	Economy	14500.00
0005433476858	20627	Economy	14500.00
0005432427117	20627	Economy	14500.00
0005432427115	20627	Economy	14500.00
0005432427116	20627	Economy	14500.00
0005432427119	20627	Economy	14500.00
0005433476869	30856	Economy	14500.00
0005432427109	30856	Economy	14500.00
0005433476867	30856	Economy	14500.00
0005433476866	30856	Economy	14500.00
0005433476868	30856	Economy	14500.00
0005432427108	30856	Economy	14500.00
0005432909224	23852	Economy	13300.00
0005432909218	23852	Economy	12100.00
0005432909221	23852	Economy	12100.00
0005432909222	23852	Economy	12100.00
0005432909226	23852	Economy	12100.00
0005432909220	23852	Economy	12100.00
0005432909227	23852	Economy	12100.00
0005432909217	23852	Economy	12100.00
0005433468186	23852	Economy	12100.00
0005432909225	23852	Economy	12100.00
0005432909219	23852	Economy	12100.00
0005432909223	23852	Economy	12100.00
0005432359823	6372	Business	36600.00
0005432359843	6372	Business	36600.00
0005432335902	6372	Business	36600.00
0005432363382	6372	Business	36600.00
0005435176638	6372	Business	36600.00
0005432359806	6372	Business	36600.00
0005432359842	6372	Economy	12200.00
0005432335895	6372	Economy	12200.00
0005432359848	6372	Economy	12200.00
0005432363380	6372	Economy	12200.00
0005432335900	6372	Economy	12200.00
0005432359815	6372	Economy	12200.00
0005432359824	6372	Economy	12200.00
0005435176642	6372	Economy	12200.00
0005432359829	6372	Economy	12200.00
0005432359808	6372	Economy	12200.00
0005432062167	6372	Economy	12200.00
0005435176594	6372	Economy	12200.00
0005432359850	6372	Economy	12200.00
0005432359839	6372	Economy	12200.00
0005432359818	6372	Economy	12200.00
0005432062169	6372	Economy	12200.00
0005432359803	6372	Economy	12200.00
0005432062166	6372	Economy	12200.00
0005432359819	6372	Economy	12200.00
0005432359845	6372	Economy	12200.00
0005432359822	6372	Economy	12200.00
0005432359821	6372	Economy	12200.00
0005435176688	6372	Economy	12200.00
0005432359840	6372	Economy	12200.00
0005432363379	6372	Economy	12200.00
0005432359836	6372	Economy	12200.00
0005432359837	6372	Economy	12200.00
0005432335903	6372	Economy	12200.00
0005432359831	6372	Economy	12200.00
0005432359833	6372	Economy	13400.00
0005432359849	6372	Economy	13400.00
0005432359807	6372	Economy	13400.00
0005432359832	6372	Economy	13400.00
0005432359835	6372	Economy	13400.00
0005432359802	6372	Economy	12200.00
0005432359827	6372	Economy	12200.00
0005432359801	6372	Economy	12200.00
0005434149529	6372	Economy	12200.00
0005435176654	6372	Economy	12200.00
0005432335905	6372	Economy	12200.00
0005432359813	6372	Economy	12200.00
0005435176602	6372	Economy	12200.00
0005432359820	6372	Economy	12200.00
0005435176593	6372	Economy	12200.00
0005432359812	6372	Economy	12200.00
0005432359811	6372	Economy	12200.00
0005432359826	6372	Economy	12200.00
0005432359828	6372	Economy	12200.00
0005432359825	6372	Economy	12200.00
0005432359830	6372	Economy	12200.00
0005432359809	6372	Economy	12200.00
0005435176633	6372	Economy	12200.00
0005432359847	6372	Economy	12200.00
0005432335896	6372	Economy	12200.00
0005432359805	6372	Economy	12200.00
0005432335904	6372	Economy	12200.00
0005432062171	6372	Economy	12200.00
0005432363381	6372	Economy	12200.00
0005432335899	6372	Economy	12200.00
0005432359844	6372	Economy	12200.00
0005432359817	6372	Economy	12200.00
0005432062168	6372	Economy	12200.00
0005435176610	6372	Economy	12200.00
0005432363377	6372	Economy	12200.00
0005432359834	6372	Economy	12200.00
0005432062170	6372	Economy	12200.00
0005432359810	6372	Economy	12200.00
0005432359814	6372	Economy	12200.00
0005432359846	6372	Economy	12200.00
0005432359838	6372	Economy	12200.00
0005432335901	6372	Economy	12200.00
0005432335906	6372	Economy	12200.00
0005432359816	6372	Economy	12200.00
0005432335897	6372	Economy	12200.00
0005432359841	6372	Economy	12200.00
0005432359804	6372	Economy	12200.00
0005432335898	6372	Economy	12200.00
0005432363378	6372	Economy	12200.00
0005435723023	20999	Business	36600.00
0005434149603	20999	Business	36600.00
0005435176756	20999	Business	36600.00
0005432052710	20999	Business	36600.00
0005435490190	20999	Business	36600.00
0005435176770	20999	Business	36600.00
0005435490188	20999	Business	36600.00
0005435176773	20999	Business	36600.00
0005432359645	20999	Economy	12200.00
0005432052711	20999	Economy	12200.00
0005435176772	20999	Economy	12200.00
0005435176777	20999	Economy	12200.00
0005435176757	20999	Economy	12200.00
0005435176776	20999	Economy	12200.00
0005435176764	20999	Economy	12200.00
0005434149596	20999	Economy	12200.00
0005432363362	20999	Economy	12200.00
0005434149601	20999	Economy	12200.00
0005434149598	20999	Economy	12200.00
0005435490189	20999	Economy	12200.00
0005434149593	20999	Economy	12200.00
0005434149594	20999	Economy	12200.00
0005435176768	20999	Economy	12200.00
0005435176769	20999	Economy	12200.00
0005435176759	20999	Economy	13400.00
0005434149599	20999	Economy	13400.00
0005435176771	20999	Economy	12200.00
0005435176782	20999	Economy	12200.00
0005435176766	20999	Economy	12200.00
0005434149600	20999	Economy	12200.00
0005435176775	20999	Economy	12200.00
0005432359542	20999	Economy	12200.00
0005432359644	20999	Economy	12200.00
0005435176780	20999	Economy	12200.00
0005432359510	20999	Economy	12200.00
0005435176760	20999	Economy	12200.00
0005434149595	20999	Economy	12200.00
0005435176781	20999	Economy	12200.00
0005435176761	20999	Economy	12200.00
0005434149597	20999	Economy	12200.00
0005435723024	20999	Economy	12200.00
0005435176779	20999	Economy	12200.00
0005432052712	20999	Economy	12200.00
0005435176765	20999	Economy	12200.00
0005435176767	20999	Economy	12200.00
0005435490191	20999	Economy	12200.00
0005435176774	20999	Economy	12200.00
0005435176763	20999	Economy	12200.00
0005432359630	20999	Economy	12200.00
0005434149602	20999	Economy	12200.00
0005435176758	20999	Economy	12200.00
0005435176778	20999	Economy	12200.00
0005432359522	20999	Economy	12200.00
0005435176762	20999	Economy	12200.00
0005434458463	17719	Economy	3400.00
0005434458476	17719	Economy	3100.00
0005434458517	17719	Economy	3100.00
0005434458518	17719	Economy	3100.00
0005434448253	17719	Economy	3100.00
0005434458475	17719	Economy	3100.00
0005434463892	17719	Economy	3100.00
0005434186167	17719	Economy	3100.00
0005434186165	17719	Economy	3100.00
0005434458449	17719	Economy	3100.00
0005434186166	17719	Economy	3100.00
0005434458448	17719	Economy	3100.00
0005434458462	17719	Economy	3100.00
0005434463891	17719	Economy	3100.00
0005434458581	29075	Economy	3400.00
0005434463903	29075	Economy	3400.00
0005434458576	29075	Economy	3400.00
0005434458569	29075	Economy	3100.00
0005434458570	29075	Economy	3100.00
0005434458568	29075	Economy	3100.00
0005434448272	29075	Economy	3100.00
0005434458575	29075	Economy	3100.00
0005434458567	29075	Economy	3100.00
0005434448274	29075	Economy	3100.00
0005434458565	29075	Economy	3100.00
0005434462764	29075	Economy	3100.00
0005434458571	29075	Economy	3100.00
0005434458579	29075	Economy	3100.00
0005434448273	29075	Economy	3100.00
0005434458566	29075	Economy	3100.00
0005434458577	29075	Economy	3100.00
0005434458582	29075	Economy	3100.00
0005434458578	29075	Economy	3100.00
0005434448271	29075	Economy	3100.00
0005434458574	29075	Economy	3100.00
0005434458580	29075	Economy	3100.00
0005434458561	29075	Economy	3100.00
0005434458563	29075	Economy	3100.00
0005434458572	29075	Economy	3100.00
0005434458564	29075	Economy	3100.00
0005434458562	29075	Economy	3100.00
0005434458573	29075	Economy	3100.00
0005432664117	6492	Business	185300.00
0005432661912	6492	Business	185300.00
0005432664127	6492	Business	185300.00
0005432663018	6492	Business	185300.00
0005432663014	6492	Business	185300.00
0005432663019	6492	Economy	61800.00
0005432661911	6492	Economy	61800.00
0005432663024	6492	Economy	61800.00
0005432663022	6492	Economy	61800.00
0005432661902	6492	Economy	61800.00
0005432663017	6492	Economy	61800.00
0005432661904	6492	Economy	61800.00
0005432664119	6492	Economy	61800.00
0005432661901	6492	Economy	67900.00
0005432663013	6492	Economy	67900.00
0005432664121	6492	Economy	61800.00
0005432664125	6492	Economy	61800.00
0005432664123	6492	Economy	61800.00
0005432663023	6492	Economy	61800.00
0005432664126	6492	Economy	61800.00
0005432661905	6492	Economy	61800.00
0005432664120	6492	Economy	61800.00
0005432661898	6492	Economy	61800.00
0005432664116	6492	Economy	61800.00
0005432661903	6492	Economy	61800.00
0005432661908	6492	Economy	61800.00
0005432664122	6492	Economy	61800.00
0005432664114	6492	Economy	61800.00
0005432661906	6492	Economy	61800.00
0005432663025	6492	Economy	61800.00
0005432663012	6492	Economy	61800.00
0005432664115	6492	Economy	61800.00
0005432661909	6492	Economy	61800.00
0005432664124	6492	Economy	61800.00
0005432663020	6492	Economy	61800.00
0005432661910	6492	Economy	61800.00
0005432663016	6492	Economy	61800.00
0005432663015	6492	Economy	61800.00
0005432663021	6492	Economy	61800.00
0005432664113	6492	Economy	61800.00
0005432661900	6492	Economy	61800.00
0005432661899	6492	Economy	61800.00
0005432661907	6492	Economy	61800.00
0005432664118	6492	Economy	61800.00
0005432663026	6492	Economy	61800.00
0005432603858	21429	Economy	7300.00
0005432603874	21429	Economy	7300.00
0005432603845	21429	Economy	7300.00
0005432603860	21429	Economy	7300.00
0005432603844	21429	Economy	6600.00
0005432603851	21429	Economy	6600.00
0005432603867	21429	Economy	6600.00
0005432603875	21429	Economy	6600.00
0005432603857	21429	Economy	6600.00
0005432603866	21429	Economy	6600.00
0005432603846	21429	Economy	6600.00
0005432603881	21429	Economy	6600.00
0005432603847	21429	Economy	6600.00
0005432603865	21429	Economy	6600.00
0005432603869	21429	Economy	6600.00
0005432603853	21429	Economy	6600.00
0005432603854	21429	Economy	6600.00
0005432603882	21429	Economy	6600.00
0005432603856	21429	Economy	6600.00
0005432603876	21429	Economy	6600.00
0005432603868	21429	Economy	6600.00
0005432603862	21429	Economy	6600.00
0005432603880	21429	Economy	6600.00
0005432603870	21429	Economy	6600.00
0005432603879	21429	Economy	6600.00
0005432603877	21429	Economy	6600.00
0005432603863	21429	Economy	6600.00
0005432603850	21429	Economy	6600.00
0005432603855	21429	Economy	6600.00
0005432603852	21429	Economy	6600.00
0005432603873	21429	Economy	6600.00
0005432603859	21429	Economy	6600.00
0005432603849	21429	Economy	6600.00
0005432603848	21429	Economy	6600.00
0005432603864	21429	Economy	6600.00
0005432603883	21429	Economy	6600.00
0005432603884	21429	Economy	6600.00
0005432603871	21429	Economy	6600.00
0005432603861	21429	Economy	6600.00
0005432603872	21429	Economy	6600.00
0005432603878	21429	Economy	6600.00
0005432603715	31690	Economy	6600.00
0005435221045	31690	Economy	6600.00
0005435221044	31690	Economy	6600.00
0005435221505	31690	Economy	6600.00
0005435221504	31690	Economy	6600.00
0005432603668	31690	Economy	6600.00
0005435154589	12303	Economy	19500.00
0005435154590	12303	Economy	17800.00
0005435154587	12303	Economy	17800.00
0005435154588	12303	Economy	17800.00
0005435154586	12303	Economy	17800.00
0005433473107	23894	Economy	12700.00
0005433473108	23894	Economy	12700.00
0005435257176	23894	Economy	12700.00
0005435257172	23894	Economy	12700.00
0005435257179	23894	Economy	12700.00
0005435257173	23894	Economy	12700.00
0005435257180	23894	Economy	12700.00
0005435257178	23894	Economy	12700.00
0005435257171	23894	Economy	12700.00
0005435257174	23894	Economy	12700.00
0005435257177	23894	Economy	12700.00
0005435257181	23894	Economy	12700.00
0005435257175	23894	Economy	12700.00
0005434604855	22346	Economy	6600.00
0005434604854	22346	Economy	6600.00
0005434604856	22346	Economy	6600.00
0005434606782	22346	Economy	6600.00
0005434606784	22346	Economy	6600.00
0005434604857	22346	Economy	6600.00
0005434604858	22346	Economy	6600.00
0005434606783	22346	Economy	6600.00
0005434522400	3849	Economy	24900.00
0005434522401	3849	Economy	22600.00
0005434522399	3849	Economy	22600.00
0005434522396	3849	Economy	22600.00
0005434522403	3849	Economy	22600.00
0005434522397	3849	Economy	22600.00
0005434522398	3849	Economy	22600.00
0005434522402	3849	Economy	22600.00
0005435904379	19044	Economy	22600.00
0005435904381	19044	Economy	22600.00
0005434522383	19044	Economy	22600.00
0005434522384	19044	Economy	22600.00
0005435904380	19044	Economy	22600.00
0005435904382	19044	Economy	22600.00
0005434522380	19044	Economy	22600.00
0005435904378	19044	Economy	22600.00
0005432753259	404	Business	44500.00
0005432747122	404	Business	44500.00
0005432747103	404	Business	44500.00
0005432219954	404	Business	44500.00
0005432751487	404	Business	44500.00
0005432747114	404	Business	44500.00
0005432747112	404	Economy	14800.00
0005432747115	404	Economy	14800.00
0005432747113	404	Economy	14800.00
0005432890684	404	Economy	14800.00
0005432747127	404	Economy	14800.00
0005432747130	404	Economy	16300.00
0005432747118	404	Economy	16300.00
0005432747129	404	Economy	16300.00
0005432747121	404	Economy	14800.00
0005432747138	404	Economy	14800.00
0005432747117	404	Economy	14800.00
0005432747136	404	Economy	14800.00
0005432749757	404	Economy	14800.00
0005432747126	404	Economy	14800.00
0005432747131	404	Economy	14800.00
0005432751485	404	Economy	14800.00
0005432747134	404	Economy	14800.00
0005432747105	404	Economy	14800.00
0005432747101	404	Economy	14800.00
0005432753260	404	Economy	14800.00
0005432747102	404	Economy	14800.00
0005432747111	404	Economy	14800.00
0005432747116	404	Economy	14800.00
0005432747106	404	Economy	14800.00
0005432219955	404	Economy	14800.00
0005432747104	404	Economy	14800.00
0005432890697	404	Economy	14800.00
0005432749759	404	Economy	14800.00
0005432747109	404	Economy	14800.00
0005432753261	404	Economy	14800.00
0005432747123	404	Economy	14800.00
0005432219952	404	Economy	14800.00
0005432747133	404	Economy	14800.00
0005432747108	404	Economy	14800.00
0005432751484	404	Economy	14800.00
0005432747120	404	Economy	14800.00
0005432747107	404	Economy	14800.00
0005432747139	404	Economy	14800.00
0005432747110	404	Economy	14800.00
0005432747119	404	Economy	14800.00
0005432747132	404	Economy	14800.00
0005432747124	404	Economy	14800.00
0005432749758	404	Economy	14800.00
0005432751486	404	Economy	14800.00
0005432219953	404	Economy	14800.00
0005432747137	404	Economy	14800.00
0005432747125	404	Economy	14800.00
0005432747135	404	Economy	14800.00
0005432747128	404	Economy	14800.00
0005432890791	12072	Business	44500.00
0005432746870	12072	Business	44500.00
0005432746871	12072	Business	44500.00
0005432890799	12072	Business	44500.00
0005432746973	12072	Business	44500.00
0005432890800	12072	Economy	14800.00
0005432214778	12072	Economy	14800.00
0005432890801	12072	Economy	14800.00
0005432746916	12072	Economy	14800.00
0005432746895	12072	Economy	14800.00
0005432890793	12072	Economy	14800.00
0005432890803	12072	Economy	16300.00
0005432890789	12072	Economy	14800.00
0005432890807	12072	Economy	14800.00
0005432890790	12072	Economy	14800.00
0005432746926	12072	Economy	14800.00
0005432746918	12072	Economy	14800.00
0005432746917	12072	Economy	14800.00
0005434153521	12072	Economy	14800.00
0005432890795	12072	Economy	14800.00
0005432890798	12072	Economy	14800.00
0005432890805	12072	Economy	14800.00
0005432890796	12072	Economy	14800.00
0005432890794	12072	Economy	14800.00
0005432890802	12072	Economy	14800.00
0005432890797	12072	Economy	14800.00
0005432890808	12072	Economy	14800.00
0005432746891	12072	Economy	14800.00
0005432747023	12072	Economy	14800.00
0005434153523	12072	Economy	14800.00
0005432746925	12072	Economy	14800.00
0005432890804	12072	Economy	14800.00
0005432214779	12072	Economy	14800.00
0005432746972	12072	Economy	14800.00
0005432746896	12072	Economy	14800.00
0005432890806	12072	Economy	14800.00
0005432890792	12072	Economy	14800.00
0005432746938	12072	Economy	14800.00
0005432747017	12072	Economy	14800.00
0005432746937	12072	Economy	14800.00
0005434153522	12072	Economy	14800.00
0005433524908	18973	Economy	28200.00
0005433524904	18973	Economy	25700.00
0005433524911	18973	Economy	25700.00
0005433524903	18973	Economy	25700.00
0005433533260	18973	Economy	25700.00
0005433533261	18973	Economy	25700.00
0005433524909	18973	Economy	25700.00
0005433524906	18973	Economy	25700.00
0005433533262	18973	Economy	25700.00
0005433524910	18973	Economy	25700.00
0005433531245	18973	Economy	25700.00
0005433524902	18973	Economy	25700.00
0005433524901	18973	Economy	25700.00
0005433531246	18973	Economy	25700.00
0005433531248	18973	Economy	25700.00
0005433531247	18973	Economy	25700.00
0005433524907	18973	Economy	25700.00
0005433524905	18973	Economy	25700.00
0005433527209	32511	Economy	28200.00
0005433527210	32511	Economy	28200.00
0005433524852	32511	Economy	25700.00
0005433527208	32511	Economy	25700.00
0005433531229	32511	Economy	25700.00
0005432927921	32511	Economy	25700.00
0005433527207	32511	Economy	25700.00
0005432927924	32511	Economy	25700.00
0005432927922	32511	Economy	25700.00
0005432927923	32511	Economy	25700.00
0005434558187	5297	Business	84000.00
0005435372187	5297	Business	84000.00
0005434822193	5297	Business	84000.00
0005434822217	5297	Business	84000.00
0005435372136	5297	Business	84000.00
0005434822123	5297	Business	84000.00
0005434822110	5297	Business	84000.00
0005432396199	5297	Business	84000.00
0005434831094	5297	Business	84000.00
0005434822106	5297	Business	84000.00
0005434822107	5297	Business	84000.00
0005435372099	5297	Business	84000.00
0005434822186	5297	Business	84000.00
0005432121179	5297	Business	84000.00
0005434822154	5297	Business	84000.00
0005434822194	5297	Business	84000.00
0005434822152	5297	Comfort	47600.00
0005434822091	5297	Comfort	47600.00
0005432121176	5297	Comfort	47600.00
0005434822156	5297	Comfort	47600.00
0005434822120	5297	Comfort	47600.00
0005435372151	5297	Comfort	47600.00
0005434822115	5297	Comfort	47600.00
0005434822170	5297	Comfort	47600.00
0005434558190	5297	Comfort	47600.00
0005432121175	5297	Comfort	47600.00
0005432396197	5297	Comfort	47600.00
0005432121178	5297	Comfort	47600.00
0005434822134	5297	Comfort	47600.00
0005434822197	5297	Comfort	47600.00
0005435149883	5297	Comfort	47600.00
0005434822114	5297	Comfort	47600.00
0005434822096	5297	Comfort	47600.00
0005435386461	5297	Comfort	47600.00
0005435372154	5297	Comfort	47600.00
0005434822113	5297	Economy	28000.00
0005435372110	5297	Economy	28000.00
0005434822163	5297	Economy	28000.00
0005434822168	5297	Economy	28000.00
0005434822141	5297	Economy	28000.00
0005432121177	5297	Economy	28000.00
0005434822173	5297	Economy	28000.00
0005434822105	5297	Economy	28000.00
0005432394059	5297	Economy	28000.00
0005434822196	5297	Economy	28000.00
0005432121172	5297	Economy	28000.00
0005435372178	5297	Economy	28000.00
0005435372114	5297	Economy	28000.00
0005434664932	5297	Economy	28000.00
0005434822122	5297	Economy	28000.00
0005432121170	5297	Economy	28000.00
0005434822177	5297	Economy	28000.00
0005434822166	5297	Economy	28000.00
0005435299699	5297	Economy	28000.00
0005435149873	5297	Economy	28000.00
0005434822190	5297	Economy	28000.00
0005432121174	5297	Economy	28000.00
0005434822139	5297	Economy	28000.00
0005434831092	5297	Economy	28000.00
0005434822206	5297	Economy	28000.00
0005434822169	5297	Economy	28000.00
0005435372179	5297	Economy	28000.00
0005434822131	5297	Economy	28000.00
0005435372214	5297	Economy	28000.00
0005434822215	5297	Economy	28000.00
0005434822214	5297	Economy	28000.00
0005434822171	5297	Economy	28000.00
0005432394057	5297	Economy	28000.00
0005432823415	5297	Economy	28000.00
0005432121171	5297	Economy	28000.00
0005435149874	5297	Economy	28000.00
0005434822136	5297	Economy	28000.00
0005435149871	5297	Economy	28000.00
0005434822094	5297	Economy	30800.00
0005434822201	5297	Economy	30800.00
0005434822209	5297	Economy	28000.00
0005434558189	5297	Economy	28000.00
0005434822129	5297	Economy	28000.00
0005434822119	5297	Economy	30800.00
0005434558188	5297	Economy	28000.00
0005434822174	5297	Economy	28000.00
0005434822140	5297	Economy	28000.00
0005434822212	5297	Economy	28000.00
0005432396196	5297	Economy	28000.00
0005434822130	5297	Economy	28000.00
0005434822172	5297	Economy	28000.00
0005434822157	5297	Economy	28000.00
0005434822203	5297	Economy	28000.00
0005434822200	5297	Economy	28000.00
0005435386462	5297	Economy	28000.00
0005434822185	5297	Economy	28000.00
0005434822099	5297	Economy	28000.00
0005434822192	5297	Economy	28000.00
0005434831090	5297	Economy	28000.00
0005435372188	5297	Economy	28000.00
0005434822158	5297	Economy	28000.00
0005434822125	5297	Economy	28000.00
0005432396198	5297	Economy	28000.00
0005435149882	5297	Economy	28000.00
0005432394060	5297	Economy	28000.00
0005434822153	5297	Economy	28000.00
0005432121181	5297	Economy	28000.00
0005434822208	5297	Economy	28000.00
0005434822097	5297	Economy	28000.00
0005435149872	5297	Economy	28000.00
0005434822112	5297	Economy	28000.00
0005434822101	5297	Economy	28000.00
0005434822142	5297	Economy	28000.00
0005434822103	5297	Economy	28000.00
0005434822162	5297	Economy	28000.00
0005435149875	5297	Economy	28000.00
0005434822179	5297	Economy	28000.00
0005434822128	5297	Economy	28000.00
0005434558191	5297	Economy	28000.00
0005434822126	5297	Economy	28000.00
0005434822175	5297	Economy	28000.00
0005432121169	5297	Economy	28000.00
0005434822145	5297	Economy	28000.00
0005434828664	5297	Economy	28000.00
0005434558181	5297	Economy	28000.00
0005434822135	5297	Economy	28000.00
0005434822109	5297	Economy	28000.00
0005434558180	5297	Economy	28000.00
0005434558184	5297	Economy	28000.00
0005434822149	5297	Economy	28000.00
0005434558183	5297	Economy	28000.00
0005435149879	5297	Economy	28000.00
0005432396200	5297	Economy	28000.00
0005434822218	5297	Economy	28000.00
0005434822127	5297	Economy	28000.00
0005435372325	5297	Economy	28000.00
0005434822161	5297	Economy	28000.00
0005434558182	5297	Economy	28000.00
0005434822147	5297	Economy	28000.00
0005435372180	5297	Economy	28000.00
0005435149870	5297	Economy	28000.00
0005434822155	5297	Economy	28000.00
0005434822100	5297	Economy	28000.00
0005434822182	5297	Economy	28000.00
0005434831091	5297	Economy	28000.00
0005435149878	5297	Economy	28000.00
0005434822183	5297	Economy	28000.00
0005435372203	5297	Economy	28000.00
0005434822202	5297	Economy	28000.00
0005432394058	5297	Economy	28000.00
0005434822180	5297	Economy	28000.00
0005434822210	5297	Economy	28000.00
0005434828662	5297	Economy	28000.00
0005434822164	5297	Economy	28000.00
0005434822151	5297	Economy	28000.00
0005435372127	5297	Economy	28000.00
0005435372097	5297	Economy	28000.00
0005435372160	5297	Economy	28000.00
0005434831093	5297	Economy	28000.00
0005434822092	5297	Economy	28000.00
0005434822117	5297	Economy	28000.00
0005434822198	5297	Economy	28000.00
0005432121173	5297	Economy	28000.00
0005435149876	5297	Economy	30800.00
0005434822167	5297	Economy	30800.00
0005434822124	5297	Economy	28000.00
0005434822118	5297	Economy	28000.00
0005435372096	5297	Economy	28000.00
0005435149877	5297	Economy	28000.00
0005434822189	5297	Economy	28000.00
0005434822098	5297	Economy	28000.00
0005434822108	5297	Economy	28000.00
0005434822102	5297	Economy	28000.00
0005434822178	5297	Economy	28000.00
0005435372153	5297	Economy	28000.00
0005434822146	5297	Economy	28000.00
0005435372105	5297	Economy	28000.00
0005434822121	5297	Economy	28000.00
0005434822148	5297	Economy	28000.00
0005434822181	5297	Economy	28000.00
0005434822188	5297	Economy	28000.00
0005434822207	5297	Economy	28000.00
0005434822219	5297	Economy	28000.00
0005434822187	5297	Economy	28000.00
0005434822195	5297	Economy	28000.00
0005434822211	5297	Economy	28000.00
0005435372173	5297	Economy	28000.00
0005434822150	5297	Economy	28000.00
0005434822159	5297	Economy	28000.00
0005435372204	5297	Economy	28000.00
0005434822095	5297	Economy	28000.00
0005434822199	5297	Economy	28000.00
0005434822137	5297	Economy	28000.00
0005434822132	5297	Economy	28000.00
0005434822138	5297	Economy	28000.00
0005434828663	5297	Economy	28000.00
0005432121180	5297	Economy	28000.00
0005434822104	5297	Economy	28000.00
0005434822191	5297	Economy	28000.00
0005434558186	5297	Economy	28000.00
0005434822205	5297	Economy	28000.00
0005434822160	5297	Economy	28000.00
0005434822116	5297	Economy	28000.00
0005435149881	5297	Economy	28000.00
0005435149884	5297	Economy	28000.00
0005434822144	5297	Economy	28000.00
0005434822111	5297	Economy	28000.00
0005434822213	5297	Economy	28000.00
0005434822184	5297	Economy	28000.00
0005435372142	5297	Economy	28000.00
0005432121182	5297	Economy	28000.00
0005434822143	5297	Economy	28000.00
0005434822204	5297	Economy	28000.00
0005435149880	5297	Economy	28000.00
0005434558185	5297	Economy	28000.00
0005434822165	5297	Economy	28000.00
0005434558192	5297	Economy	28000.00
0005434822133	5297	Economy	28000.00
0005434822093	5297	Economy	28000.00
0005434822176	5297	Economy	28000.00
0005434822216	5297	Economy	28000.00
0005435372529	9880	Business	84000.00
0005434821518	9880	Business	84000.00
0005435299722	9880	Business	84000.00
0005435372533	9880	Business	84000.00
0005432202981	9880	Business	84000.00
0005432823428	9880	Business	84000.00
0005435372524	9880	Business	84000.00
0005435372509	9880	Comfort	47600.00
0005435372553	9880	Comfort	47600.00
0005435372520	9880	Comfort	47600.00
0005435372556	9880	Comfort	47600.00
0005434821422	9880	Comfort	47600.00
0005435735086	9880	Comfort	47600.00
0005435302146	9880	Comfort	47600.00
0005435735087	9880	Comfort	47600.00
0005435372501	9880	Comfort	47600.00
0005435661897	9880	Comfort	47600.00
0005435372519	9880	Comfort	47600.00
0005434821406	9880	Comfort	47600.00
0005435302148	9880	Comfort	47600.00
0005432202983	9880	Comfort	47600.00
0005434821354	9880	Comfort	47600.00
0005435372542	9880	Comfort	47600.00
0005435735089	9880	Comfort	47600.00
0005434821364	9880	Comfort	47600.00
0005434821397	9880	Comfort	47600.00
0005435372512	9880	Economy	28000.00
0005435372527	9880	Economy	28000.00
0005435149825	9880	Economy	28000.00
0005435372523	9880	Economy	28000.00
0005432202985	9880	Economy	28000.00
0005435372500	9880	Economy	28000.00
0005435372540	9880	Economy	28000.00
0005435179387	9880	Economy	28000.00
0005432823427	9880	Economy	28000.00
0005435299723	9880	Economy	28000.00
0005435372555	9880	Economy	28000.00
0005435372546	9880	Economy	28000.00
0005435372547	9880	Economy	28000.00
0005434821447	9880	Economy	28000.00
0005434821311	9880	Economy	28000.00
0005435302144	9880	Economy	28000.00
0005435372513	9880	Economy	28000.00
0005435372543	9880	Economy	28000.00
0005435372496	9880	Economy	30800.00
0005435386499	9880	Economy	28000.00
0005435299720	9880	Economy	30800.00
0005435372499	9880	Economy	30800.00
0005432202982	9880	Economy	30800.00
0005435372535	9880	Economy	28000.00
0005435372550	9880	Economy	28000.00
0005435735088	9880	Economy	28000.00
0005435179388	9880	Economy	28000.00
0005435372508	9880	Economy	28000.00
0005435386500	9880	Economy	28000.00
0005435661899	9880	Economy	28000.00
0005435372548	9880	Economy	28000.00
0005434821423	9880	Economy	28000.00
0005435302145	9880	Economy	28000.00
0005435299721	9880	Economy	28000.00
0005435372531	9880	Economy	28000.00
0005435372518	9880	Economy	28000.00
0005432202979	9880	Economy	28000.00
0005435372502	9880	Economy	28000.00
0005435372521	9880	Economy	28000.00
0005435372545	9880	Economy	28000.00
0005435386498	9880	Economy	28000.00
0005434821312	9880	Economy	28000.00
0005435386501	9880	Economy	28000.00
0005435372525	9880	Economy	28000.00
0005435372530	9880	Economy	28000.00
0005435372534	9880	Economy	28000.00
0005435302147	9880	Economy	28000.00
0005435372557	9880	Economy	28000.00
0005434821405	9880	Economy	28000.00
0005435372515	9880	Economy	28000.00
0005435299724	9880	Economy	28000.00
0005435372554	9880	Economy	28000.00
0005434821315	9880	Economy	28000.00
0005434821316	9880	Economy	28000.00
0005435372504	9880	Economy	28000.00
0005434821453	9880	Economy	28000.00
0005432202980	9880	Economy	28000.00
0005434821616	9880	Economy	28000.00
0005434821365	9880	Economy	28000.00
0005434821549	9880	Economy	28000.00
0005435372522	9880	Economy	28000.00
0005435372507	9880	Economy	28000.00
0005435372539	9880	Economy	28000.00
0005435661898	9880	Economy	28000.00
0005435372559	9880	Economy	28000.00
0005435372536	9880	Economy	28000.00
0005435372552	9880	Economy	30800.00
0005435372514	9880	Economy	28000.00
0005435372498	9880	Economy	28000.00
0005435372537	9880	Economy	28000.00
0005435372549	9880	Economy	28000.00
0005435386503	9880	Economy	28000.00
0005435372551	9880	Economy	28000.00
0005434821347	9880	Economy	28000.00
0005435372526	9880	Economy	28000.00
0005434821528	9880	Economy	28000.00
0005435372558	9880	Economy	28000.00
0005435372528	9880	Economy	28000.00
0005434821335	9880	Economy	28000.00
0005435372541	9880	Economy	28000.00
0005434821493	9880	Economy	28000.00
0005434821403	9880	Economy	28000.00
0005435372516	9880	Economy	28000.00
0005435372538	9880	Economy	28000.00
0005435372503	9880	Economy	28000.00
0005435372497	9880	Economy	28000.00
0005434821326	9880	Economy	28000.00
0005435372506	9880	Economy	28000.00
0005435372494	9880	Economy	28000.00
0005435372517	9880	Economy	28000.00
0005435372510	9880	Economy	28000.00
0005434821358	9880	Economy	28000.00
0005435372505	9880	Economy	28000.00
0005435386502	9880	Economy	28000.00
0005435372511	9880	Economy	28000.00
0005432202984	9880	Economy	28000.00
0005434821402	9880	Economy	28000.00
0005435372532	9880	Economy	28000.00
0005435372495	9880	Economy	28000.00
0005435372544	9880	Economy	28000.00
0005435790273	6968	Economy	8200.00
0005435082702	6968	Economy	7400.00
0005435082698	6968	Economy	7400.00
0005435082695	6968	Economy	7400.00
0005435082696	6968	Economy	7400.00
0005435790272	6968	Economy	7400.00
0005435082697	6968	Economy	7400.00
0005435790274	6968	Economy	7400.00
0005435082701	6968	Economy	7400.00
0005435082699	6968	Economy	7400.00
0005435082700	6968	Economy	7400.00
0005435790275	6968	Economy	7400.00
0005435082703	6968	Economy	7400.00
0005435790259	25987	Economy	7400.00
0005435790258	25987	Economy	7400.00
0005434213701	9556	Business	32800.00
0005434755999	9556	Business	32800.00
0005434755969	9556	Business	32800.00
0005434755962	9556	Business	32800.00
0005434213732	9556	Business	32800.00
0005434755998	9556	Business	32800.00
0005434755988	9556	Business	32800.00
0005434213791	9556	Business	32800.00
0005434755982	9556	Business	32800.00
0005434755996	9556	Economy	10900.00
0005434755964	9556	Economy	10900.00
0005434755987	9556	Economy	10900.00
0005434755977	9556	Economy	10900.00
0005434755965	9556	Economy	12000.00
0005434755978	9556	Economy	12000.00
0005434213740	9556	Economy	10900.00
0005434756003	9556	Economy	10900.00
0005434755975	9556	Economy	10900.00
0005434755968	9556	Economy	10900.00
0005434756007	9556	Economy	10900.00
0005434755993	9556	Economy	10900.00
0005434755983	9556	Economy	10900.00
0005434756004	9556	Economy	10900.00
0005434755995	9556	Economy	10900.00
0005434213750	9556	Economy	10900.00
0005434755986	9556	Economy	10900.00
0005434755989	9556	Economy	10900.00
0005434755966	9556	Economy	10900.00
0005434755963	9556	Economy	10900.00
0005434755974	9556	Economy	10900.00
0005434755970	9556	Economy	10900.00
0005434755991	9556	Economy	10900.00
0005434755972	9556	Economy	10900.00
0005434756002	9556	Economy	10900.00
0005434755971	9556	Economy	10900.00
0005434755981	9556	Economy	10900.00
0005434755994	9556	Economy	10900.00
0005434756001	9556	Economy	10900.00
0005434755980	9556	Economy	10900.00
0005434755984	9556	Economy	10900.00
0005434213749	9556	Economy	10900.00
0005434755961	9556	Economy	10900.00
0005434756000	9556	Economy	10900.00
0005434755990	9556	Economy	10900.00
0005434755985	9556	Economy	10900.00
0005434755973	9556	Economy	10900.00
0005434755967	9556	Economy	10900.00
0005434755976	9556	Economy	10900.00
0005434756006	9556	Economy	10900.00
0005434755979	9556	Economy	10900.00
0005434755992	9556	Economy	10900.00
0005434756005	9556	Economy	10900.00
0005434755997	9556	Economy	10900.00
0005434213978	28591	Business	32800.00
0005434213960	28591	Business	32800.00
0005434213968	28591	Business	32800.00
0005434213942	28591	Business	32800.00
0005434213951	28591	Business	32800.00
0005434213947	28591	Business	32800.00
0005434213974	28591	Business	32800.00
0005434213969	28591	Economy	10900.00
0005434213937	28591	Economy	10900.00
0005434213958	28591	Economy	10900.00
0005434213961	28591	Economy	10900.00
0005434213963	28591	Economy	10900.00
0005434213955	28591	Economy	12000.00
0005434213975	28591	Economy	12000.00
0005434213973	28591	Economy	10900.00
0005434213945	28591	Economy	10900.00
0005434213981	28591	Economy	10900.00
0005434213972	28591	Economy	10900.00
0005434213979	28591	Economy	10900.00
0005434213971	28591	Economy	10900.00
0005434213959	28591	Economy	10900.00
0005434213944	28591	Economy	10900.00
0005434213982	28591	Economy	10900.00
0005434213970	28591	Economy	10900.00
0005434213976	28591	Economy	10900.00
0005434213953	28591	Economy	10900.00
0005434213939	28591	Economy	10900.00
0005434213946	28591	Economy	10900.00
0005434213964	28591	Economy	10900.00
0005434213940	28591	Economy	10900.00
0005434213965	28591	Economy	10900.00
0005434213943	28591	Economy	10900.00
0005434213938	28591	Economy	10900.00
0005434213967	28591	Economy	10900.00
0005434213954	28591	Economy	10900.00
0005434213962	28591	Economy	10900.00
0005434213950	28591	Economy	10900.00
0005434213936	28591	Economy	10900.00
0005434213977	28591	Economy	10900.00
0005434213956	28591	Economy	10900.00
0005434213949	28591	Economy	10900.00
0005434213957	28591	Economy	10900.00
0005434213980	28591	Economy	10900.00
0005434213983	28591	Economy	10900.00
0005434213952	28591	Economy	10900.00
0005434213941	28591	Economy	10900.00
0005434213966	28591	Economy	10900.00
0005434213948	28591	Economy	10900.00
0005435100089	10837	Economy	8900.00
0005435100087	10837	Economy	8900.00
0005435100088	10837	Economy	8900.00
0005434760168	31807	Economy	8900.00
0005434760169	31807	Economy	8900.00
0005434760170	31807	Economy	8900.00
0005434639039	1957	Economy	20900.00
0005434639035	1957	Economy	20900.00
0005434639022	1957	Economy	20900.00
0005434639020	1957	Economy	19000.00
0005435948314	1957	Economy	19000.00
0005432290599	1957	Economy	19000.00
0005434639029	1957	Economy	19000.00
0005434639025	1957	Economy	19000.00
0005434639040	1957	Economy	19000.00
0005434639021	1957	Economy	19000.00
0005434639031	1957	Economy	19000.00
0005434639036	1957	Economy	19000.00
0005434639034	1957	Economy	19000.00
0005434639026	1957	Economy	19000.00
0005435948312	1957	Economy	19000.00
0005434639042	1957	Economy	19000.00
0005434639018	1957	Economy	19000.00
0005432290598	1957	Economy	19000.00
0005434639041	1957	Economy	19000.00
0005434639030	1957	Economy	19000.00
0005434639015	1957	Economy	19000.00
0005434639027	1957	Economy	19000.00
0005435948313	1957	Economy	19000.00
0005434639043	1957	Economy	19000.00
0005434639028	1957	Economy	19000.00
0005434639017	1957	Economy	19000.00
0005434639019	1957	Economy	19000.00
0005434639014	1957	Economy	19000.00
0005434639013	1957	Economy	19000.00
0005432290600	1957	Economy	19000.00
0005434639038	1957	Economy	19000.00
0005434639033	1957	Economy	19000.00
0005434639037	1957	Economy	19000.00
0005434639016	1957	Economy	19000.00
0005434639032	1957	Economy	19000.00
0005434639023	1957	Economy	19000.00
0005434639024	1957	Economy	19000.00
0005433202180	23264	Economy	20900.00
0005433202187	23264	Economy	20900.00
0005434638878	23264	Economy	19000.00
0005433202189	23264	Economy	19000.00
0005433202179	23264	Economy	19000.00
0005433202191	23264	Economy	19000.00
0005434638847	23264	Economy	19000.00
0005433202177	23264	Economy	19000.00
0005433202184	23264	Economy	19000.00
0005433202190	23264	Economy	19000.00
0005433202183	23264	Economy	19000.00
0005433202181	23264	Economy	19000.00
0005435948309	23264	Economy	19000.00
0005433202182	23264	Economy	19000.00
0005434638905	23264	Economy	19000.00
0005433202185	23264	Economy	19000.00
0005433202186	23264	Economy	19000.00
0005433202188	23264	Economy	19000.00
0005435948308	23264	Economy	19000.00
0005433202178	23264	Economy	19000.00
0005434638846	23264	Economy	19000.00
0005432111245	6085	Business	69700.00
0005433533264	6085	Business	69700.00
0005433533266	6085	Business	69700.00
0005434600514	6085	Business	69700.00
0005434600510	6085	Business	69700.00
0005434600503	6085	Business	69700.00
0005434600519	6085	Economy	23200.00
0005433533267	6085	Economy	23200.00
0005434600507	6085	Economy	23200.00
0005434600498	6085	Economy	23200.00
0005434600509	6085	Economy	23200.00
0005434600494	6085	Economy	25600.00
0005434600513	6085	Economy	25600.00
0005434600495	6085	Economy	23200.00
0005434600497	6085	Economy	23200.00
0005434600511	6085	Economy	23200.00
0005434600501	6085	Economy	23200.00
0005434600508	6085	Economy	23200.00
0005432111247	6085	Economy	23200.00
0005433533263	6085	Economy	23200.00
0005434600518	6085	Economy	23200.00
0005432111246	6085	Economy	23200.00
0005434600515	6085	Economy	23200.00
0005434600516	6085	Economy	23200.00
0005434600499	6085	Economy	23200.00
0005433531250	6085	Economy	23200.00
0005434600504	6085	Economy	23200.00
0005435326503	6085	Economy	23200.00
0005433531251	6085	Economy	23200.00
0005433533265	6085	Economy	23200.00
0005434600500	6085	Economy	23200.00
0005434600496	6085	Economy	23200.00
0005434600506	6085	Economy	23200.00
0005435326504	6085	Economy	23200.00
0005433531249	6085	Economy	23200.00
0005434600505	6085	Economy	23200.00
0005434600502	6085	Economy	23200.00
0005434600517	6085	Economy	23200.00
0005435326521	6085	Economy	23200.00
0005434600520	6085	Economy	23200.00
0005435326508	6085	Economy	23200.00
0005434600512	6085	Economy	23200.00
0005434600407	18599	Business	69700.00
0005435326583	18599	Business	69700.00
0005435326590	18599	Economy	25600.00
0005435326589	18599	Economy	23200.00
0005435326596	18599	Economy	23200.00
0005435326584	18599	Economy	23200.00
0005435326597	18599	Economy	23200.00
0005434600388	18599	Economy	23200.00
0005434600409	18599	Economy	23200.00
0005434600367	18599	Economy	23200.00
0005435326595	18599	Economy	23200.00
0005435326588	18599	Economy	23200.00
0005434600395	18599	Economy	23200.00
0005435326582	18599	Economy	23200.00
0005434600408	18599	Economy	23200.00
0005435326594	18599	Economy	23200.00
0005435326586	18599	Economy	23200.00
0005435326591	18599	Economy	23200.00
0005435326587	18599	Economy	23200.00
0005434600387	18599	Economy	23200.00
0005434600394	18599	Economy	23200.00
0005435326585	18599	Economy	23200.00
0005435326592	18599	Economy	23200.00
0005435326593	18599	Economy	23200.00
0005434550587	10592	Business	9100.00
0005434558171	10592	Business	9100.00
0005434550576	10592	Business	9100.00
0005434550590	10592	Business	9100.00
0005434550565	10592	Business	9100.00
0005434550573	10592	Business	9100.00
0005434550571	10592	Business	9100.00
0005434550555	10592	Business	9100.00
0005434550568	10592	Economy	3000.00
0005434550553	10592	Economy	3000.00
0005434550579	10592	Economy	3000.00
0005434550552	10592	Economy	3000.00
0005434550589	10592	Economy	3000.00
0005434550567	10592	Economy	3000.00
0005434550543	10592	Economy	3000.00
0005434550549	10592	Economy	3000.00
0005434550578	10592	Economy	3300.00
0005434550569	10592	Economy	3300.00
0005434550563	10592	Economy	3000.00
0005434550560	10592	Economy	3000.00
0005434550588	10592	Economy	3000.00
0005434550572	10592	Economy	3000.00
0005434550538	10592	Economy	3000.00
0005434550577	10592	Economy	3000.00
0005434550585	10592	Economy	3000.00
0005434558175	10592	Economy	3000.00
0005434550580	10592	Economy	3000.00
0005434550570	10592	Economy	3000.00
0005434550548	10592	Economy	3000.00
0005434550544	10592	Economy	3000.00
0005434550557	10592	Economy	3000.00
0005434558172	10592	Economy	3000.00
0005434550542	10592	Economy	3000.00
0005434550559	10592	Economy	3000.00
0005434550545	10592	Economy	3000.00
0005434550556	10592	Economy	3000.00
0005434550550	10592	Economy	3000.00
0005434550541	10592	Economy	3000.00
0005434558177	10592	Economy	3000.00
0005434550537	10592	Economy	3000.00
0005434550540	10592	Economy	3000.00
0005434550581	10592	Economy	3000.00
0005434550561	10592	Economy	3000.00
0005434550562	10592	Economy	3000.00
0005434550564	10592	Economy	3000.00
0005434550582	10592	Economy	3000.00
0005434550592	10592	Economy	3000.00
0005434550566	10592	Economy	3000.00
0005434550584	10592	Economy	3000.00
0005434558176	10592	Economy	3000.00
0005434550546	10592	Economy	3000.00
0005434550591	10592	Economy	3000.00
0005434558173	10592	Economy	3000.00
0005434550586	10592	Economy	3000.00
0005434550575	10592	Economy	3000.00
0005434550554	10592	Economy	3000.00
0005434554038	10592	Economy	3000.00
0005434558174	10592	Economy	3000.00
0005434550551	10592	Economy	3000.00
0005434558179	10592	Economy	3000.00
0005433180660	10592	Economy	3000.00
0005434550547	10592	Economy	3000.00
0005434550574	10592	Economy	3000.00
0005434550583	10592	Economy	3000.00
0005434558178	10592	Economy	3000.00
0005434550558	10592	Economy	3000.00
0005434550539	10592	Economy	3000.00
0005433180819	27770	Business	9100.00
0005433180818	27770	Business	9100.00
0005433180807	27770	Business	9100.00
0005433180813	27770	Economy	3000.00
0005433180809	27770	Economy	3000.00
0005433180821	27770	Economy	3300.00
0005433180827	27770	Economy	3000.00
0005433180823	27770	Economy	3000.00
0005433180817	27770	Economy	3000.00
0005433180804	27770	Economy	3000.00
0005433180812	27770	Economy	3000.00
0005433180816	27770	Economy	3000.00
0005433180825	27770	Economy	3000.00
0005433180822	27770	Economy	3000.00
0005433180808	27770	Economy	3000.00
0005433180826	27770	Economy	3000.00
0005433180815	27770	Economy	3000.00
0005433180824	27770	Economy	3000.00
0005433180810	27770	Economy	3000.00
0005433180828	27770	Economy	3000.00
0005433180814	27770	Economy	3000.00
0005433180806	27770	Economy	3000.00
0005433180811	27770	Economy	3000.00
0005433180803	27770	Economy	3000.00
0005433180820	27770	Economy	3000.00
0005433180805	27770	Economy	3000.00
0005434554024	27771	Economy	3000.00
0005434550391	27771	Economy	3300.00
0005434550397	27771	Economy	3000.00
0005434550292	27771	Economy	3000.00
0005434550390	27771	Economy	3000.00
0005433459172	6127	Economy	11700.00
0005433459169	6127	Economy	11700.00
0005433459171	6127	Economy	11700.00
0005433459170	6127	Economy	11700.00
0005433459154	19347	Economy	11700.00
0005433459155	19347	Economy	11700.00
0005435254446	19347	Economy	11700.00
0005435254445	19347	Economy	11700.00
0005435437622	6711	Business	51100.00
0005435437562	6711	Business	51100.00
0005435661896	6711	Business	51100.00
0005435681665	6711	Business	51100.00
0005435681646	6711	Business	51100.00
0005435681663	6711	Economy	17000.00
0005432136110	6711	Economy	17000.00
0005435681659	6711	Economy	17000.00
0005435681669	6711	Economy	17000.00
0005435681655	6711	Economy	17000.00
0005435681657	6711	Economy	17000.00
0005435681675	6711	Economy	17000.00
0005435681662	6711	Economy	17000.00
0005435681666	6711	Economy	17000.00
0005435630929	6711	Economy	18700.00
0005435681650	6711	Economy	18700.00
0005435681647	6711	Economy	18700.00
0005435681653	6711	Economy	18700.00
0005435661894	6711	Economy	17000.00
0005435681643	6711	Economy	17000.00
0005435437621	6711	Economy	17000.00
0005435681645	6711	Economy	17000.00
0005435681652	6711	Economy	17000.00
0005435681649	6711	Economy	17000.00
0005435681683	6711	Economy	17000.00
0005435720125	6711	Economy	17000.00
0005435681644	6711	Economy	17000.00
0005435681658	6711	Economy	17000.00
0005432136113	6711	Economy	17000.00
0005435681667	6711	Economy	17000.00
0005435681673	6711	Economy	17000.00
0005435681680	6711	Economy	17000.00
0005435681678	6711	Economy	17000.00
0005432136112	6711	Economy	17000.00
0005435437569	6711	Economy	17000.00
0005435681684	6711	Economy	17000.00
0005435437553	6711	Economy	17000.00
0005435681671	6711	Economy	17000.00
0005435681685	6711	Economy	17000.00
0005435437563	6711	Economy	17000.00
0005435630932	6711	Economy	17000.00
0005435437576	6711	Economy	17000.00
0005435681672	6711	Economy	17000.00
0005435681660	6711	Economy	17000.00
0005435630931	6711	Economy	17000.00
0005435661895	6711	Economy	17000.00
0005435681670	6711	Economy	17000.00
0005435681677	6711	Economy	17000.00
0005435437605	6711	Economy	17000.00
0005435681681	6711	Economy	17000.00
0005435681651	6711	Economy	17000.00
0005435681682	6711	Economy	17000.00
0005435681676	6711	Economy	17000.00
0005435681656	6711	Economy	17000.00
0005435681668	6711	Economy	17000.00
0005435681654	6711	Economy	17000.00
0005435719556	6711	Economy	17000.00
0005435681674	6711	Economy	17000.00
0005435681679	6711	Economy	17000.00
0005435630930	6711	Economy	17000.00
0005435720126	6711	Economy	17000.00
0005435681661	6711	Economy	17000.00
0005435681648	6711	Economy	17000.00
0005435719557	6711	Economy	17000.00
0005432136111	6711	Economy	17000.00
0005435681664	6711	Economy	17000.00
0005432136109	6711	Economy	17000.00
0005435720800	24615	Business	51100.00
0005435437699	24615	Business	51100.00
0005435720799	24615	Business	51100.00
0005435681404	24615	Business	51100.00
0005435437702	24615	Business	51100.00
0005435681529	24615	Business	51100.00
0005435437692	24615	Business	51100.00
0005432533259	24615	Economy	17000.00
0005435437707	24615	Economy	17000.00
0005435437693	24615	Economy	17000.00
0005435437704	24615	Economy	17000.00
0005435437690	24615	Economy	17000.00
0005432533258	24615	Economy	17000.00
0005435437708	24615	Economy	17000.00
0005435437691	24615	Economy	17000.00
0005435437705	24615	Economy	17000.00
0005435437689	24615	Economy	17000.00
0005435437703	24615	Economy	17000.00
0005435437706	24615	Economy	17000.00
0005435437694	24615	Economy	17000.00
0005435437710	24615	Economy	17000.00
0005435681398	24615	Economy	17000.00
0005435681395	24615	Economy	17000.00
0005435437700	24615	Economy	17000.00
0005434828666	24615	Economy	17000.00
0005435681400	24615	Economy	17000.00
0005432305720	24615	Economy	17000.00
0005432305721	24615	Economy	17000.00
0005432533260	24615	Economy	17000.00
0005435437695	24615	Economy	17000.00
0005435437688	24615	Economy	17000.00
0005435681402	24615	Economy	17000.00
0005434828667	24615	Economy	17000.00
0005435720798	24615	Economy	17000.00
0005435437709	24615	Economy	17000.00
0005435437701	24615	Economy	17000.00
0005434828665	24615	Economy	17000.00
0005435437697	24615	Economy	17000.00
0005435437696	24615	Economy	17000.00
0005435437698	24615	Economy	17000.00
0005435125881	11551	Business	26400.00
0005435125869	11551	Business	26400.00
0005435125863	11551	Business	26400.00
0005435125890	11551	Economy	8800.00
0005435125875	11551	Economy	8800.00
0005435125857	11551	Economy	8800.00
0005435125891	11551	Economy	8800.00
0005435125868	11551	Economy	8800.00
0005435125889	11551	Economy	8800.00
0005435125856	11551	Economy	9700.00
0005435125883	11551	Economy	8800.00
0005435125865	11551	Economy	8800.00
0005435125859	11551	Economy	8800.00
0005435125862	11551	Economy	8800.00
0005435125896	11551	Economy	8800.00
0005435125866	11551	Economy	8800.00
0005435125861	11551	Economy	8800.00
0005435125895	11551	Economy	8800.00
0005435125867	11551	Economy	8800.00
0005435125888	11551	Economy	8800.00
0005435125887	11551	Economy	8800.00
0005435125892	11551	Economy	8800.00
0005435125872	11551	Economy	8800.00
0005435125882	11551	Economy	8800.00
0005435125886	11551	Economy	8800.00
0005435125871	11551	Economy	8800.00
0005435125864	11551	Economy	8800.00
0005435125884	11551	Economy	8800.00
0005435125858	11551	Economy	8800.00
0005435125894	11551	Economy	8800.00
0005435125876	11551	Economy	8800.00
0005435125893	11551	Economy	8800.00
0005435125878	11551	Economy	8800.00
0005435105944	11551	Economy	8800.00
0005435125873	11551	Economy	8800.00
0005435125885	11551	Economy	8800.00
0005435125860	11551	Economy	8800.00
0005435125877	11551	Economy	8800.00
0005435125870	11551	Economy	8800.00
0005435125874	11551	Economy	8800.00
0005435125880	11551	Economy	8800.00
0005435125879	11551	Economy	8800.00
0005435125673	31900	Business	26400.00
0005435125685	31900	Business	26400.00
0005435125716	31900	Economy	8800.00
0005435558057	31900	Economy	8800.00
0005435125743	31900	Economy	8800.00
0005435125679	31900	Economy	8800.00
0005435125744	31900	Economy	8800.00
0005435558056	31900	Economy	8800.00
0005435105927	31900	Economy	8800.00
0005435558058	31900	Economy	8800.00
0005435125717	31900	Economy	8800.00
0005435125672	31900	Economy	8800.00
0005433397518	13546	Business	36600.00
0005433397496	13546	Business	36600.00
0005433397479	13546	Business	36600.00
0005433397523	13546	Business	36600.00
0005435732136	13546	Business	36600.00
0005433397498	13546	Business	36600.00
0005433397494	13546	Business	36600.00
0005433397509	13546	Economy	12200.00
0005433397506	13546	Economy	12200.00
0005433397525	13546	Economy	12200.00
0005433397508	13546	Economy	12200.00
0005433397507	13546	Economy	12200.00
0005433397495	13546	Economy	12200.00
0005433397505	13546	Economy	12200.00
0005433397477	13546	Economy	13400.00
0005433397480	13546	Economy	13400.00
0005433397484	13546	Economy	12200.00
0005433397522	13546	Economy	12200.00
0005433397485	13546	Economy	12200.00
0005433397499	13546	Economy	12200.00
0005433397492	13546	Economy	12200.00
0005433397524	13546	Economy	12200.00
0005433397510	13546	Economy	12200.00
0005433397478	13546	Economy	12200.00
0005433397481	13546	Economy	12200.00
0005433397487	13546	Economy	12200.00
0005433397489	13546	Economy	12200.00
0005433397501	13546	Economy	12200.00
0005433397512	13546	Economy	12200.00
0005433397521	13546	Economy	12200.00
0005433397493	13546	Economy	12200.00
0005433397500	13546	Economy	12200.00
0005433397511	13546	Economy	12200.00
0005433397502	13546	Economy	12200.00
0005433397519	13546	Economy	12200.00
0005433397515	13546	Economy	12200.00
0005433397513	13546	Economy	12200.00
0005433397520	13546	Economy	12200.00
0005433397482	13546	Economy	12200.00
0005433397486	13546	Economy	12200.00
0005433397517	13546	Economy	12200.00
0005433397483	13546	Economy	12200.00
0005433397503	13546	Economy	12200.00
0005433397516	13546	Economy	12200.00
0005433397514	13546	Economy	12200.00
0005433397490	13546	Economy	12200.00
0005433397491	13546	Economy	12200.00
0005433397504	13546	Economy	12200.00
0005433397488	13546	Economy	12200.00
0005433397497	13546	Economy	12200.00
0005435732184	19416	Economy	12200.00
0005435732181	19416	Economy	12200.00
0005433397377	19416	Economy	13400.00
0005432297248	19416	Economy	12200.00
0005435732182	19416	Economy	12200.00
0005433397327	19416	Economy	12200.00
0005433397206	19416	Economy	12200.00
0005435732180	19416	Economy	12200.00
0005432297250	19416	Economy	12200.00
0005435732187	19416	Economy	12200.00
0005435732185	19416	Economy	12200.00
0005435732189	19416	Economy	12200.00
0005433397376	19416	Economy	12200.00
0005433397234	19416	Economy	12200.00
0005435732193	19416	Economy	12200.00
0005432297246	19416	Economy	12200.00
0005435732192	19416	Economy	12200.00
0005435732190	19416	Economy	12200.00
0005432297249	19416	Economy	12200.00
0005435732191	19416	Economy	12200.00
0005433397308	19416	Economy	12200.00
0005433397293	19416	Economy	12200.00
0005433397205	19416	Economy	12200.00
0005435732188	19416	Economy	12200.00
0005435732183	19416	Economy	12200.00
0005435732186	19416	Economy	12200.00
0005433397378	19416	Economy	12200.00
0005432297247	19416	Economy	12200.00
0005435925140	13175	Business	11300.00
0005435068161	13175	Business	11300.00
0005435925142	13175	Business	11300.00
0005435925131	13175	Business	11300.00
0005435925137	13175	Business	11300.00
0005435068260	13175	Business	11300.00
0005435925130	13175	Business	11300.00
0005435925138	13175	Economy	3800.00
0005435925147	13175	Economy	3800.00
0005435925135	13175	Economy	4100.00
0005435925146	13175	Economy	3800.00
0005435925133	13175	Economy	3800.00
0005435925129	13175	Economy	3800.00
0005435068236	13175	Economy	3800.00
0005435925134	13175	Economy	3800.00
0005435925143	13175	Economy	3800.00
0005435925141	13175	Economy	3800.00
0005435925144	13175	Economy	3800.00
0005435925145	13175	Economy	3800.00
0005435925136	13175	Economy	3800.00
0005435068181	13175	Economy	3800.00
0005435925139	13175	Economy	3800.00
0005435068162	13175	Economy	3800.00
0005435068208	13175	Economy	3800.00
0005435068211	13175	Economy	3800.00
0005435925132	13175	Economy	3800.00
0005435068238	13175	Economy	3800.00
0005435068452	15506	Business	11300.00
0005435068436	15506	Business	11300.00
0005435068468	15506	Business	11300.00
0005435068447	15506	Business	11300.00
0005435068442	15506	Business	11300.00
0005435068462	15506	Business	11300.00
0005435068443	15506	Business	11300.00
0005435068473	15506	Business	11300.00
0005435068475	15506	Business	11300.00
0005435068432	15506	Economy	3800.00
0005435068440	15506	Economy	3800.00
0005435068430	15506	Economy	3800.00
0005435068426	15506	Economy	3800.00
0005435068424	15506	Economy	3800.00
0005435068441	15506	Economy	4100.00
0005435068464	15506	Economy	4100.00
0005435068449	15506	Economy	4100.00
0005435068472	15506	Economy	3800.00
0005435068450	15506	Economy	3800.00
0005435068470	15506	Economy	3800.00
0005435068474	15506	Economy	3800.00
0005435068425	15506	Economy	3800.00
0005435068467	15506	Economy	3800.00
0005435068445	15506	Economy	3800.00
0005435068433	15506	Economy	3800.00
0005435068471	15506	Economy	3800.00
0005435068453	15506	Economy	3800.00
0005435068457	15506	Economy	3800.00
0005435068465	15506	Economy	3800.00
0005435068423	15506	Economy	3800.00
0005435068469	15506	Economy	3800.00
0005435068427	15506	Economy	3800.00
0005435068439	15506	Economy	3800.00
0005435068458	15506	Economy	3800.00
0005435068454	15506	Economy	3800.00
0005435068438	15506	Economy	3800.00
0005435068456	15506	Economy	3800.00
0005435068431	15506	Economy	3800.00
0005435068460	15506	Economy	3800.00
0005435068429	15506	Economy	3800.00
0005435068434	15506	Economy	3800.00
0005435068428	15506	Economy	3800.00
0005435068455	15506	Economy	3800.00
0005435068437	15506	Economy	3800.00
0005435068459	15506	Economy	3800.00
0005435068461	15506	Economy	3800.00
0005435068463	15506	Economy	3800.00
0005435068451	15506	Economy	3800.00
0005435068446	15506	Economy	3800.00
0005435068444	15506	Economy	3800.00
0005435068435	15506	Economy	3800.00
0005435068466	15506	Economy	3800.00
0005435068448	15506	Economy	3800.00
0005435808102	23178	Economy	27100.00
0005435808089	23178	Economy	27100.00
0005435808092	23178	Economy	27100.00
0005435808090	23178	Economy	24700.00
0005435808106	23178	Economy	24700.00
0005435808094	23178	Economy	24700.00
0005435808096	23178	Economy	24700.00
0005435808084	23178	Economy	24700.00
0005435808083	23178	Economy	24700.00
0005435808093	23178	Economy	24700.00
0005435808081	23178	Economy	24700.00
0005435808104	23178	Economy	24700.00
0005435808091	23178	Economy	24700.00
0005435808100	23178	Economy	24700.00
0005435808098	23178	Economy	24700.00
0005435808101	23178	Economy	24700.00
0005435808110	23178	Economy	24700.00
0005435808082	23178	Economy	24700.00
0005435808097	23178	Economy	24700.00
0005435808112	23178	Economy	24700.00
0005435808087	23178	Economy	24700.00
0005435808111	23178	Economy	24700.00
0005435808103	23178	Economy	24700.00
0005435808088	23178	Economy	24700.00
0005435808099	23178	Economy	24700.00
0005435808109	23178	Economy	24700.00
0005435808108	23178	Economy	24700.00
0005435808085	23178	Economy	24700.00
0005435808107	23178	Economy	24700.00
0005435808095	23178	Economy	24700.00
0005435808086	23178	Economy	24700.00
0005435808105	23178	Economy	24700.00
0005434755728	10739	Business	61300.00
0005434214008	10739	Business	61300.00
0005434214024	10739	Business	61300.00
0005434214015	10739	Business	61300.00
0005434214005	10739	Business	61300.00
0005434214003	10739	Business	61300.00
0005434213989	10739	Economy	20400.00
0005434214011	10739	Economy	20400.00
0005434214019	10739	Economy	20400.00
0005434214030	10739	Economy	22500.00
0005434214021	10739	Economy	22500.00
0005434213998	10739	Economy	22500.00
0005434213994	10739	Economy	20400.00
0005434213985	10739	Economy	20400.00
0005434213997	10739	Economy	20400.00
0005434214010	10739	Economy	20400.00
0005434214009	10739	Economy	20400.00
0005434214014	10739	Economy	20400.00
0005434214029	10739	Economy	20400.00
0005434213984	10739	Economy	20400.00
0005434214026	10739	Economy	20400.00
0005434214000	10739	Economy	20400.00
0005434213995	10739	Economy	20400.00
0005434214027	10739	Economy	20400.00
0005434214023	10739	Economy	20400.00
0005434214007	10739	Economy	20400.00
0005434213990	10739	Economy	20400.00
0005434213988	10739	Economy	20400.00
0005434214022	10739	Economy	20400.00
0005434213993	10739	Economy	20400.00
0005434213986	10739	Economy	20400.00
0005434214028	10739	Economy	20400.00
0005434213987	10739	Economy	20400.00
0005434214018	10739	Economy	20400.00
0005434213999	10739	Economy	20400.00
0005434214017	10739	Economy	20400.00
0005434214004	10739	Economy	20400.00
0005434214001	10739	Economy	20400.00
0005434214012	10739	Economy	20400.00
0005434214013	10739	Economy	20400.00
0005434214016	10739	Economy	20400.00
0005434213996	10739	Economy	20400.00
0005434214006	10739	Economy	20400.00
0005434213992	10739	Economy	20400.00
0005434214020	10739	Economy	20400.00
0005434214002	10739	Economy	20400.00
0005434213991	10739	Economy	20400.00
0005434214025	10739	Economy	20400.00
0005434755948	28703	Business	61300.00
0005434755960	28703	Business	61300.00
0005434755924	28703	Business	61300.00
0005434755929	28703	Business	61300.00
0005434755947	28703	Business	61300.00
0005434755954	28703	Business	61300.00
0005434213706	28703	Economy	20400.00
0005434755943	28703	Economy	20400.00
0005434755940	28703	Economy	20400.00
0005434755949	28703	Economy	20400.00
0005434755932	28703	Economy	20400.00
0005434755946	28703	Economy	22500.00
0005434755923	28703	Economy	20400.00
0005434755953	28703	Economy	20400.00
0005434755942	28703	Economy	20400.00
0005434755931	28703	Economy	20400.00
0005434755933	28703	Economy	20400.00
0005434213712	28703	Economy	20400.00
0005434755944	28703	Economy	20400.00
0005434755950	28703	Economy	20400.00
0005434213705	28703	Economy	20400.00
0005434755939	28703	Economy	20400.00
0005434755935	28703	Economy	20400.00
0005434755951	28703	Economy	20400.00
0005434755925	28703	Economy	20400.00
0005434755927	28703	Economy	20400.00
0005434755937	28703	Economy	20400.00
0005434755955	28703	Economy	20400.00
0005434755945	28703	Economy	20400.00
0005434755952	28703	Economy	20400.00
0005434755936	28703	Economy	20400.00
0005434755922	28703	Economy	20400.00
0005434755941	28703	Economy	20400.00
0005434755956	28703	Economy	20400.00
0005434755930	28703	Economy	20400.00
0005434755938	28703	Economy	20400.00
0005434755957	28703	Economy	20400.00
0005434755926	28703	Economy	20400.00
0005434755934	28703	Economy	20400.00
0005434755958	28703	Economy	20400.00
0005434755928	28703	Economy	20400.00
0005434755959	28703	Economy	20400.00
0005434229074	5436	Business	29500.00
0005435038996	5436	Business	29500.00
0005435039035	5436	Business	29500.00
0005435006759	5436	Business	29500.00
0005435006757	5436	Business	29500.00
0005435039030	5436	Business	29500.00
0005435039012	5436	Business	29500.00
0005435039052	5436	Business	29500.00
0005435039018	5436	Business	29500.00
0005435039045	5436	Business	29500.00
0005435042832	5436	Economy	9800.00
0005435039034	5436	Economy	9800.00
0005435039037	5436	Economy	9800.00
0005435006760	5436	Economy	9800.00
0005435006750	5436	Economy	9800.00
0005435042831	5436	Economy	9800.00
0005435039023	5436	Economy	9800.00
0005435039033	5436	Economy	9800.00
0005435039003	5436	Economy	9800.00
0005435039017	5436	Economy	9800.00
0005435038992	5436	Economy	9800.00
0005435039051	5436	Economy	9800.00
0005435039021	5436	Economy	9800.00
0005435039046	5436	Economy	9800.00
0005435039000	5436	Economy	9800.00
0005435039004	5436	Economy	9800.00
0005435039014	5436	Economy	9800.00
0005435039026	5436	Economy	9800.00
0005435039031	5436	Economy	9800.00
0005435006752	5436	Economy	9800.00
0005435006761	5436	Economy	9800.00
0005435039056	5436	Economy	9800.00
0005435039039	5436	Economy	9800.00
0005435006764	5436	Economy	9800.00
0005432125368	5436	Economy	9800.00
0005435039028	5436	Economy	9800.00
0005435039022	5436	Economy	9800.00
0005435006765	5436	Economy	9800.00
0005435039050	5436	Economy	9800.00
0005435038990	5436	Economy	9800.00
0005435039043	5436	Economy	10800.00
0005432125367	5436	Economy	10800.00
0005435039049	5436	Economy	10800.00
0005435039010	5436	Economy	10800.00
0005435039015	5436	Economy	10800.00
0005435006749	5436	Economy	10800.00
0005435039048	5436	Economy	9800.00
0005435039006	5436	Economy	9800.00
0005432125369	5436	Economy	9800.00
0005435006755	5436	Economy	9800.00
0005435039044	5436	Economy	9800.00
0005435039005	5436	Economy	9800.00
0005435006756	5436	Economy	9800.00
0005435039041	5436	Economy	9800.00
0005435039042	5436	Economy	9800.00
0005435006762	5436	Economy	9800.00
0005435039025	5436	Economy	9800.00
0005435039013	5436	Economy	9800.00
0005434228992	5436	Economy	9800.00
0005435006758	5436	Economy	9800.00
0005435006746	5436	Economy	9800.00
0005435039001	5436	Economy	9800.00
0005435039020	5436	Economy	9800.00
0005435006747	5436	Economy	9800.00
0005435006751	5436	Economy	9800.00
0005435038998	5436	Economy	9800.00
0005434229016	5436	Economy	9800.00
0005435039008	5436	Economy	9800.00
0005435038994	5436	Economy	9800.00
0005435006748	5436	Economy	9800.00
0005435039040	5436	Economy	9800.00
0005435039032	5436	Economy	9800.00
0005435038997	5436	Economy	9800.00
0005435039007	5436	Economy	9800.00
0005435039027	5436	Economy	9800.00
0005435039016	5436	Economy	9800.00
0005432125366	5436	Economy	9800.00
0005435006763	5436	Economy	9800.00
0005435039054	5436	Economy	9800.00
0005435039019	5436	Economy	9800.00
0005435039057	5436	Economy	9800.00
0005435039047	5436	Economy	9800.00
0005435039038	5436	Economy	9800.00
0005435039011	5436	Economy	9800.00
0005435038993	5436	Economy	9800.00
0005435039029	5436	Economy	9800.00
0005435039024	5436	Economy	9800.00
0005435038999	5436	Economy	9800.00
0005432125365	5436	Economy	9800.00
0005435038991	5436	Economy	9800.00
0005435006753	5436	Economy	9800.00
0005435039002	5436	Economy	9800.00
0005435039036	5436	Economy	9800.00
0005432125370	5436	Economy	9800.00
0005435006754	5436	Economy	9800.00
0005435039009	5436	Economy	9800.00
0005435038995	5436	Economy	9800.00
0005435039055	5436	Economy	9800.00
0005435039053	5436	Economy	9800.00
0005434229112	12989	Business	29500.00
0005434229107	12989	Business	29500.00
0005434229121	12989	Business	29500.00
0005435038675	12989	Business	29500.00
0005434229108	12989	Economy	9800.00
0005432304356	12989	Economy	9800.00
0005434229106	12989	Economy	9800.00
0005434229125	12989	Economy	9800.00
0005434229110	12989	Economy	9800.00
0005435038706	12989	Economy	9800.00
0005434229117	12989	Economy	9800.00
0005434229126	12989	Economy	9800.00
0005435006611	12989	Economy	9800.00
0005435038715	12989	Economy	9800.00
0005434229109	12989	Economy	9800.00
0005432304353	12989	Economy	9800.00
0005434229127	12989	Economy	9800.00
0005435038772	12989	Economy	9800.00
0005434229120	12989	Economy	9800.00
0005434229122	12989	Economy	9800.00
0005435038625	12989	Economy	9800.00
0005434229104	12989	Economy	10800.00
0005432304352	12989	Economy	10800.00
0005435038707	12989	Economy	9800.00
0005435038680	12989	Economy	9800.00
0005434229116	12989	Economy	9800.00
0005435038847	12989	Economy	9800.00
0005434229115	12989	Economy	9800.00
0005434229118	12989	Economy	9800.00
0005435038773	12989	Economy	9800.00
0005434229123	12989	Economy	9800.00
0005435038711	12989	Economy	9800.00
0005435038654	12989	Economy	9800.00
0005434229124	12989	Economy	9800.00
0005434229119	12989	Economy	9800.00
0005432304355	12989	Economy	9800.00
0005434229114	12989	Economy	9800.00
0005435006612	12989	Economy	9800.00
0005434229105	12989	Economy	9800.00
0005434229113	12989	Economy	9800.00
0005435038753	12989	Economy	9800.00
0005435006618	12989	Economy	9800.00
0005435038669	12989	Economy	9800.00
0005435006606	12989	Economy	9800.00
0005435006671	12989	Economy	9800.00
0005432304354	12989	Economy	9800.00
0005435038752	12989	Economy	9800.00
0005435006670	12989	Economy	9800.00
0005434229111	12989	Economy	9800.00
0005435038636	12989	Economy	9800.00
0005434426237	14866	Business	52900.00
0005435902393	14866	Business	52900.00
0005434426261	14866	Business	52900.00
0005434426255	14866	Business	52900.00
0005434426241	14866	Business	52900.00
0005434426245	14866	Business	52900.00
0005432188567	14866	Economy	17600.00
0005434426249	14866	Economy	17600.00
0005434426256	14866	Economy	17600.00
0005434411725	14866	Economy	17600.00
0005434426252	14866	Economy	17600.00
0005434426246	14866	Economy	17600.00
0005432188568	14866	Economy	17600.00
0005434426238	14866	Economy	17600.00
0005434426236	14866	Economy	17600.00
0005434426250	14866	Economy	17600.00
0005434426260	14866	Economy	17600.00
0005434426264	14866	Economy	17600.00
0005434426242	14866	Economy	17600.00
0005432188566	14866	Economy	17600.00
0005434411727	14866	Economy	17600.00
0005434426239	14866	Economy	17600.00
0005434426248	14866	Economy	17600.00
0005434426244	14866	Economy	17600.00
0005434426247	14866	Economy	17600.00
0005434426254	14866	Economy	17600.00
0005434426263	14866	Economy	17600.00
0005434426257	14866	Economy	17600.00
0005434426240	14866	Economy	17600.00
0005434426258	14866	Economy	17600.00
0005434426253	14866	Economy	17600.00
0005434411724	14866	Economy	17600.00
0005434426262	14866	Economy	17600.00
0005434426259	14866	Economy	17600.00
0005434411726	14866	Economy	17600.00
0005434426243	14866	Economy	17600.00
0005434426251	14866	Economy	17600.00
0005435902506	20186	Business	52900.00
0005435902509	20186	Business	52900.00
0005435554135	20186	Business	52900.00
0005435902493	20186	Business	52900.00
0005434426085	20186	Economy	17600.00
0005432059483	20186	Economy	17600.00
0005435554134	20186	Economy	17600.00
0005435902510	20186	Economy	17600.00
0005435902505	20186	Economy	19400.00
0005435902502	20186	Economy	19400.00
0005435902495	20186	Economy	19400.00
0005435554137	20186	Economy	17600.00
0005434426111	20186	Economy	17600.00
0005435902494	20186	Economy	17600.00
0005435554133	20186	Economy	17600.00
0005435902496	20186	Economy	17600.00
0005434426086	20186	Economy	17600.00
0005435554136	20186	Economy	17600.00
0005434426113	20186	Economy	17600.00
0005435902499	20186	Economy	17600.00
0005434426094	20186	Economy	17600.00
0005435902501	20186	Economy	17600.00
0005434426120	20186	Economy	17600.00
0005435902511	20186	Economy	17600.00
0005435902497	20186	Economy	17600.00
0005435902507	20186	Economy	17600.00
0005432059482	20186	Economy	17600.00
0005435902504	20186	Economy	17600.00
0005435902500	20186	Economy	17600.00
0005434426110	20186	Economy	17600.00
0005435902508	20186	Economy	17600.00
0005435902503	20186	Economy	17600.00
0005435902498	20186	Economy	17600.00
0005434426169	20186	Economy	17600.00
0005432462491	28013	Economy	35600.00
0005432462487	28013	Economy	35600.00
0005432462490	28013	Economy	35600.00
0005432462485	28013	Economy	35600.00
0005432462489	28013	Economy	35600.00
0005432462488	28013	Economy	35600.00
0005432462486	28013	Economy	35600.00
0005434559086	30886	Business	106800.00
0005434559084	30886	Business	106800.00
0005434559082	30886	Economy	35600.00
0005434559087	30886	Economy	35600.00
0005434559083	30886	Economy	35600.00
0005434523741	30886	Economy	39200.00
0005434523742	30886	Economy	35600.00
0005434523746	30886	Economy	35600.00
0005434523743	30886	Economy	35600.00
0005434523744	30886	Economy	35600.00
0005434523745	30886	Economy	35600.00
0005434559085	30886	Economy	35600.00
0005433726063	30867	Business	91700.00
0005433726064	30867	Business	91700.00
0005433726069	30867	Business	91700.00
0005433726066	30867	Economy	30600.00
0005433726071	30867	Economy	30600.00
0005433726074	30867	Economy	30600.00
0005433726073	30867	Economy	30600.00
0005433726072	30867	Economy	30600.00
0005433726070	30867	Economy	30600.00
0005433726075	30867	Economy	30600.00
0005433726065	30867	Economy	30600.00
0005433726068	30867	Economy	30600.00
0005433726067	30867	Economy	30600.00
0005435981766	26500	Business	18500.00
0005435981773	26500	Business	18500.00
0005435981759	26500	Business	18500.00
0005435981764	26500	Business	18500.00
0005435981777	26500	Business	18500.00
0005435981776	26500	Business	18500.00
0005435981769	26500	Business	18500.00
0005435981753	26500	Business	18500.00
0005435981748	26500	Business	18500.00
0005435981737	26500	Business	18500.00
0005435981756	26500	Economy	6200.00
0005433434183	26500	Economy	6200.00
0005435981761	26500	Economy	6200.00
0005432300192	26500	Economy	6200.00
0005435981782	26500	Economy	6800.00
0005432300193	26500	Economy	6800.00
0005435981745	26500	Economy	6200.00
0005435981735	26500	Economy	6200.00
0005435981780	26500	Economy	6200.00
0005435981755	26500	Economy	6200.00
0005432300195	26500	Economy	6200.00
0005435981749	26500	Economy	6200.00
0005435981740	26500	Economy	6200.00
0005435981747	26500	Economy	6200.00
0005435981774	26500	Economy	6200.00
0005435981785	26500	Economy	6200.00
0005435981771	26500	Economy	6200.00
0005435981744	26500	Economy	6200.00
0005435981736	26500	Economy	6200.00
0005435981762	26500	Economy	6200.00
0005435981746	26500	Economy	6200.00
0005435981784	26500	Economy	6200.00
0005435981775	26500	Economy	6200.00
0005435981768	26500	Economy	6200.00
0005435981752	26500	Economy	6200.00
0005435981781	26500	Economy	6200.00
0005435981765	26500	Economy	6200.00
0005435981760	26500	Economy	6200.00
0005435981778	26500	Economy	6200.00
0005435981754	26500	Economy	6200.00
0005435981758	26500	Economy	6200.00
0005435981779	26500	Economy	6200.00
0005435981739	26500	Economy	6200.00
0005433434198	26500	Economy	6200.00
0005435981751	26500	Economy	6200.00
0005435981750	26500	Economy	6200.00
0005435981783	26500	Economy	6200.00
0005435981742	26500	Economy	6200.00
0005435981741	26500	Economy	6200.00
0005433434197	26500	Economy	6200.00
0005435981757	26500	Economy	6200.00
0005435981770	26500	Economy	6200.00
0005432300194	26500	Economy	6200.00
0005435981772	26500	Economy	6200.00
0005435981767	26500	Economy	6200.00
0005435981786	26500	Economy	6200.00
0005433434182	26500	Economy	6200.00
0005433434221	26500	Economy	6200.00
0005435981788	26500	Economy	6200.00
0005435981738	26500	Economy	6200.00
0005435981763	26500	Economy	6200.00
0005435981787	26500	Economy	6200.00
0005435981743	26500	Economy	6200.00
0005435981565	26737	Business	18500.00
0005433434379	26737	Business	18500.00
0005432051094	26737	Business	18500.00
0005433434368	26737	Business	18500.00
0005433434357	26737	Business	18500.00
0005433434360	26737	Economy	6200.00
0005433434378	26737	Economy	6200.00
0005433434371	26737	Economy	6200.00
0005433434370	26737	Economy	6200.00
0005434270183	26737	Economy	6200.00
0005433434364	26737	Economy	6200.00
0005434271289	26737	Economy	6800.00
0005433434361	26737	Economy	6800.00
0005433434375	26737	Economy	6200.00
0005434270182	26737	Economy	6200.00
0005433434359	26737	Economy	6200.00
0005433434369	26737	Economy	6200.00
0005433434356	26737	Economy	6200.00
0005433434380	26737	Economy	6200.00
0005433434355	26737	Economy	6200.00
0005433434366	26737	Economy	6200.00
0005433434373	26737	Economy	6200.00
0005432051093	26737	Economy	6200.00
0005434271288	26737	Economy	6200.00
0005433434377	26737	Economy	6200.00
0005433434363	26737	Economy	6200.00
0005432051092	26737	Economy	6200.00
0005433434372	26737	Economy	6200.00
0005433434365	26737	Economy	6200.00
0005433434362	26737	Economy	6200.00
0005433434354	26737	Economy	6200.00
0005433434358	26737	Economy	6200.00
0005435981533	26737	Economy	6200.00
0005433434376	26737	Economy	6200.00
0005433434374	26737	Economy	6200.00
0005434269080	26737	Economy	6200.00
0005433434367	26737	Economy	6200.00
0005433689875	29258	Economy	19100.00
0005432583742	3144	Economy	11100.00
0005432583738	3144	Economy	11100.00
0005432583741	3144	Economy	11100.00
0005432583743	3144	Economy	10100.00
0005432583751	3144	Economy	10100.00
0005432583750	3144	Economy	10100.00
0005432583757	3144	Economy	10100.00
0005432583754	3144	Economy	10100.00
0005432583759	3144	Economy	10100.00
0005432583747	3144	Economy	10100.00
0005432583760	3144	Economy	10100.00
0005432583736	3144	Economy	10100.00
0005432583755	3144	Economy	10100.00
0005432583753	3144	Economy	10100.00
0005432583746	3144	Economy	10100.00
0005432216239	3144	Economy	10100.00
0005432216241	3144	Economy	10100.00
0005432583761	3144	Economy	10100.00
0005432583752	3144	Economy	10100.00
0005432583739	3144	Economy	10100.00
0005432216242	3144	Economy	10100.00
0005432857858	3144	Economy	10100.00
0005432583749	3144	Economy	10100.00
0005432583737	3144	Economy	10100.00
0005432583756	3144	Economy	10100.00
0005432583758	3144	Economy	10100.00
0005432583740	3144	Economy	10100.00
0005432583745	3144	Economy	10100.00
0005432216240	3144	Economy	10100.00
0005432583744	3144	Economy	10100.00
0005432583748	3144	Economy	10100.00
0005432857924	31472	Economy	11100.00
0005432857932	31472	Economy	11100.00
0005432857931	31472	Economy	11100.00
0005432857934	31472	Economy	10100.00
0005432857933	31472	Economy	10100.00
0005432583621	31472	Economy	10100.00
0005432857935	31472	Economy	10100.00
0005432857926	31472	Economy	10100.00
0005432857927	31472	Economy	10100.00
0005432583595	31472	Economy	10100.00
0005432583620	31472	Economy	10100.00
0005432857925	31472	Economy	10100.00
0005432583603	31472	Economy	10100.00
0005432857928	31472	Economy	10100.00
0005432583604	31472	Economy	10100.00
0005432857930	31472	Economy	10100.00
0005432857929	31472	Economy	10100.00
0005434943242	895	Economy	7500.00
0005433255028	895	Economy	7500.00
0005434943246	895	Economy	7500.00
0005434943247	895	Economy	7500.00
0005434943244	895	Economy	7500.00
0005434943245	895	Economy	7500.00
0005434943249	895	Economy	7500.00
0005434943243	895	Economy	7500.00
0005434943250	895	Economy	7500.00
0005434943248	895	Economy	7500.00
0005434943190	16197	Economy	8300.00
0005434943230	16197	Economy	7500.00
0005433255058	16197	Economy	7500.00
0005434943214	16197	Economy	7500.00
0005433255059	16197	Economy	7500.00
0005433255054	16197	Economy	7500.00
0005433255056	16197	Economy	7500.00
0005434943197	16197	Economy	7500.00
0005433255057	16197	Economy	7500.00
0005434943187	16197	Economy	7500.00
0005433255055	16197	Economy	7500.00
0005434943198	16197	Economy	7500.00
0005435858513	27611	Business	90500.00
0005435858510	27611	Economy	30200.00
0005435858509	27611	Economy	30200.00
0005433654649	27611	Economy	30200.00
0005435858508	27611	Economy	30200.00
0005435858500	27611	Economy	30200.00
0005435858504	27611	Economy	30200.00
0005435858507	27611	Economy	30200.00
0005435858502	27611	Economy	30200.00
0005435858511	27611	Economy	30200.00
0005435858505	27611	Economy	30200.00
0005435858501	27611	Economy	30200.00
0005435858503	27611	Economy	30200.00
0005435858512	27611	Economy	30200.00
0005435858506	27611	Economy	30200.00
0005435652526	21774	Business	9800.00
0005433367241	21774	Business	9800.00
0005435652514	21774	Business	9800.00
0005435652515	21774	Economy	3300.00
0005435652496	21774	Economy	3300.00
0005435652506	21774	Economy	3300.00
0005435652498	21774	Economy	3300.00
0005435652516	21774	Economy	3600.00
0005435652513	21774	Economy	3600.00
0005435652522	21774	Economy	3600.00
0005435652510	21774	Economy	3300.00
0005435652497	21774	Economy	3300.00
0005435652507	21774	Economy	3300.00
0005435652499	21774	Economy	3300.00
0005435652489	21774	Economy	3300.00
0005435652492	21774	Economy	3300.00
0005433367234	21774	Economy	3300.00
0005435652500	21774	Economy	3300.00
0005435652511	21774	Economy	3300.00
0005435652519	21774	Economy	3300.00
0005435652521	21774	Economy	3300.00
0005435652505	21774	Economy	3300.00
0005435652520	21774	Economy	3300.00
0005435652493	21774	Economy	3300.00
0005435652523	21774	Economy	3300.00
0005435652518	21774	Economy	3300.00
0005435652509	21774	Economy	3300.00
0005435652524	21774	Economy	3300.00
0005435652504	21774	Economy	3300.00
0005435652502	21774	Economy	3300.00
0005435652494	21774	Economy	3300.00
0005435652495	21774	Economy	3300.00
0005435652501	21774	Economy	3300.00
0005435652503	21774	Economy	3300.00
0005435652491	21774	Economy	3300.00
0005435652490	21774	Economy	3300.00
0005435652525	21774	Economy	3300.00
0005435652517	21774	Economy	3300.00
0005435652508	21774	Economy	3300.00
0005433367223	21774	Economy	3300.00
0005435652512	21774	Economy	3300.00
0005433763046	9364	Business	186200.00
0005433763039	9364	Business	186200.00
0005433784540	9364	Business	186200.00
0005433763045	9364	Business	186200.00
0005433804996	9364	Business	186200.00
0005433804974	9364	Business	186200.00
0005433784532	9364	Business	186200.00
0005433763038	9364	Business	186200.00
0005433763037	9364	Business	186200.00
0005433784528	9364	Business	186200.00
0005432665251	9364	Business	186200.00
0005433804979	9364	Business	186200.00
0005432666363	9364	Business	186200.00
0005433804970	9364	Business	186200.00
0005433784550	9364	Business	186200.00
0005433784520	9364	Business	186200.00
0005433763041	9364	Business	186200.00
0005433804976	9364	Business	186200.00
0005433804982	9364	Economy	68300.00
0005433784548	9364	Economy	68300.00
0005433804985	9364	Economy	68300.00
0005433804977	9364	Economy	62100.00
0005433784546	9364	Economy	62100.00
0005433784524	9364	Economy	62100.00
0005433804993	9364	Economy	62100.00
0005433784543	9364	Economy	62100.00
0005433804981	9364	Economy	62100.00
0005434170831	9364	Economy	62100.00
0005433784537	9364	Economy	62100.00
0005433804995	9364	Economy	62100.00
0005433804969	9364	Economy	62100.00
0005433763035	9364	Economy	62100.00
0005433784538	9364	Economy	62100.00
0005433804972	9364	Economy	62100.00
0005433805002	9364	Economy	62100.00
0005433784529	9364	Economy	62100.00
0005433784522	9364	Economy	62100.00
0005433784531	9364	Economy	62100.00
0005433804990	9364	Economy	62100.00
0005433804989	9364	Economy	62100.00
0005433784536	9364	Economy	62100.00
0005432667429	9364	Economy	62100.00
0005433804991	9364	Economy	62100.00
0005433804997	9364	Economy	62100.00
0005433804999	9364	Economy	62100.00
0005433784525	9364	Economy	62100.00
0005433763040	9364	Economy	62100.00
0005433763042	9364	Economy	62100.00
0005433784530	9364	Economy	62100.00
0005433784523	9364	Economy	62100.00
0005433784535	9364	Economy	62100.00
0005433805001	9364	Economy	62100.00
0005433784534	9364	Economy	62100.00
0005433784521	9364	Economy	62100.00
0005433804973	9364	Economy	62100.00
0005433804986	9364	Economy	62100.00
0005433784545	9364	Economy	62100.00
0005433804987	9364	Economy	68300.00
0005434170830	9364	Economy	62100.00
0005434170805	9364	Economy	62100.00
0005432667431	9364	Economy	68300.00
0005433784526	9364	Economy	62100.00
0005433784519	9364	Economy	62100.00
0005433804968	9364	Economy	62100.00
0005433784544	9364	Economy	62100.00
0005433804992	9364	Economy	62100.00
0005433784542	9364	Economy	62100.00
0005433784541	9364	Economy	62100.00
0005433804994	9364	Economy	62100.00
0005433804984	9364	Economy	62100.00
0005433804975	9364	Economy	62100.00
0005432667430	9364	Economy	62100.00
0005433805000	9364	Economy	62100.00
0005432666365	9364	Economy	62100.00
0005433763034	9364	Economy	62100.00
0005432665250	9364	Economy	62100.00
0005433805003	9364	Economy	62100.00
0005433763036	9364	Economy	62100.00
0005433804980	9364	Economy	62100.00
0005433804988	9364	Economy	62100.00
0005432657414	9364	Economy	62100.00
0005433784527	9364	Economy	62100.00
0005433784551	9364	Economy	62100.00
0005432666364	9364	Economy	62100.00
0005433784533	9364	Economy	62100.00
0005433763033	9364	Economy	62100.00
0005433763044	9364	Economy	62100.00
0005433784547	9364	Economy	62100.00
0005433784549	9364	Economy	62100.00
0005433804983	9364	Economy	62100.00
0005433784552	9364	Economy	62100.00
0005433784518	9364	Economy	62100.00
0005433804971	9364	Economy	62100.00
0005433804978	9364	Economy	62100.00
0005434170829	9364	Economy	62100.00
0005433804998	9364	Economy	62100.00
0005433763043	9364	Economy	62100.00
0005433784539	9364	Economy	62100.00
0005434170895	26278	Business	186200.00
0005433784413	26278	Business	186200.00
0005433804806	26278	Business	186200.00
0005433804790	26278	Business	186200.00
0005433784378	26278	Business	186200.00
0005434269078	26278	Business	186200.00
0005433784366	26278	Business	186200.00
0005434170887	26278	Business	186200.00
0005433784326	26278	Economy	68300.00
0005434269079	26278	Economy	62100.00
0005433762981	26278	Economy	62100.00
0005433784332	26278	Economy	62100.00
0005433784341	26278	Economy	62100.00
0005433784331	26278	Economy	62100.00
0005433804842	26278	Economy	62100.00
0005434269077	26278	Economy	62100.00
0005434170885	26278	Economy	62100.00
0005434270180	26278	Economy	62100.00
0005434151671	26278	Economy	62100.00
0005434170897	26278	Economy	62100.00
0005433784305	26278	Economy	62100.00
0005434271287	26278	Economy	62100.00
0005432657394	26278	Economy	62100.00
0005434170888	26278	Economy	62100.00
0005434270181	26278	Economy	62100.00
0005434170898	26278	Economy	62100.00
0005433784306	26278	Economy	62100.00
0005434271286	26278	Economy	62100.00
0005433804841	26278	Economy	62100.00
0005434151670	26278	Economy	62100.00
0005433784303	26278	Economy	62100.00
0005434170886	26278	Economy	62100.00
0005434170892	26278	Economy	62100.00
0005434170889	26278	Economy	62100.00
0005433784304	26278	Economy	62100.00
0005433762980	26278	Economy	62100.00
0005434170890	26278	Economy	62100.00
0005434170891	26278	Economy	62100.00
0005433784330	26278	Economy	62100.00
0005434170894	26278	Economy	62100.00
0005434170893	26278	Economy	62100.00
0005434170896	26278	Economy	62100.00
0005433762947	26278	Economy	62100.00
0005433762983	26278	Economy	62100.00
0005433784379	26278	Economy	62100.00
0005435135612	4882	Economy	5900.00
0005435135613	4882	Economy	5300.00
0005435135614	4882	Economy	5300.00
0005435135611	4882	Economy	5300.00
0005435135616	4882	Economy	5300.00
0005435135615	4882	Economy	5300.00
0005435135583	33025	Economy	5900.00
0005435929612	33025	Economy	5300.00
0005435929613	33025	Economy	5300.00
0005435135582	33025	Economy	5300.00
0005434983226	9511	Economy	19700.00
0005434983230	9511	Economy	17900.00
0005434983225	9511	Economy	17900.00
0005434983227	9511	Economy	17900.00
0005434983228	9511	Economy	17900.00
0005434983229	9511	Economy	17900.00
0005434217922	27387	Economy	19700.00
0005434217919	27387	Economy	17900.00
0005434217924	27387	Economy	17900.00
0005434217923	27387	Economy	17900.00
0005434217921	27387	Economy	17900.00
0005434217920	27387	Economy	17900.00
0005433985150	24291	Economy	12100.00
0005433985126	24291	Economy	12100.00
0005433985134	24291	Economy	12100.00
0005433985371	25925	Business	36400.00
0005433985374	25925	Business	36400.00
0005433960155	25925	Business	36400.00
0005433985392	25925	Business	36400.00
0005433960147	25925	Business	36400.00
0005433960183	25925	Business	36400.00
0005433985394	25925	Business	36400.00
0005433985360	25925	Business	36400.00
0005433960185	25925	Business	36400.00
0005433985390	25925	Economy	13400.00
0005433960188	25925	Economy	12100.00
0005433960193	25925	Economy	12100.00
0005433960204	25925	Economy	12100.00
0005433960174	25925	Economy	12100.00
0005433960151	25925	Economy	12100.00
0005433960142	25925	Economy	12100.00
0005433985358	25925	Economy	12100.00
0005433960156	25925	Economy	12100.00
0005433985396	25925	Economy	12100.00
0005433960161	25925	Economy	12100.00
0005433960205	25925	Economy	12100.00
0005433960158	25925	Economy	12100.00
0005433985383	25925	Economy	12100.00
0005433985401	25925	Economy	12100.00
0005433960165	25925	Economy	12100.00
0005433985359	25925	Economy	12100.00
0005433985400	25925	Economy	12100.00
0005433960162	25925	Economy	12100.00
0005433985388	25925	Economy	12100.00
0005433985405	25925	Economy	12100.00
0005433960169	25925	Economy	12100.00
0005433960186	25925	Economy	12100.00
0005433960201	25925	Economy	12100.00
0005433960178	25925	Economy	12100.00
0005433985389	25925	Economy	12100.00
0005433960172	25925	Economy	12100.00
0005433985373	25925	Economy	12100.00
0005433960181	25925	Economy	12100.00
0005433960184	25925	Economy	12100.00
0005433960197	25925	Economy	12100.00
0005433985375	25925	Economy	12100.00
0005433985377	25925	Economy	12100.00
0005433960146	25925	Economy	12100.00
0005433960167	25925	Economy	12100.00
0005433960200	25925	Economy	12100.00
0005433985393	25925	Economy	12100.00
0005433960179	25925	Economy	12100.00
0005433985406	25925	Economy	12100.00
0005433985367	25925	Economy	12100.00
0005433960189	25925	Economy	12100.00
0005433960171	25925	Economy	12100.00
0005433960198	25925	Economy	12100.00
0005433985376	25925	Economy	12100.00
0005433960153	25925	Economy	12100.00
0005433985370	25925	Economy	12100.00
0005433985366	25925	Economy	12100.00
0005433985402	25925	Economy	12100.00
0005433960207	25925	Economy	12100.00
0005433985381	25925	Economy	12100.00
0005433960166	25925	Economy	12100.00
0005433960190	25925	Economy	12100.00
0005433960180	25925	Economy	12100.00
0005433985403	25925	Economy	12100.00
0005433985407	25925	Economy	12100.00
0005433985361	25925	Economy	12100.00
0005433960176	25925	Economy	12100.00
0005433985362	25925	Economy	12100.00
0005433985369	25925	Economy	13400.00
0005433960187	25925	Economy	12100.00
0005433960168	25925	Economy	12100.00
0005433960194	25925	Economy	13400.00
0005433960175	25925	Economy	12100.00
0005433985372	25925	Economy	12100.00
0005433960206	25925	Economy	12100.00
0005433985385	25925	Economy	12100.00
0005433985378	25925	Economy	12100.00
0005433960182	25925	Economy	12100.00
0005433960203	25925	Economy	12100.00
0005433960154	25925	Economy	12100.00
0005433985364	25925	Economy	12100.00
0005433960170	25925	Economy	12100.00
0005433960191	25925	Economy	12100.00
0005433960192	25925	Economy	12100.00
0005433985404	25925	Economy	12100.00
0005433985387	25925	Economy	12100.00
0005433985397	25925	Economy	12100.00
0005433985399	25925	Economy	12100.00
0005433960152	25925	Economy	12100.00
0005433985395	25925	Economy	12100.00
0005433960164	25925	Economy	12100.00
0005433960143	25925	Economy	12100.00
0005433960163	25925	Economy	12100.00
0005433985386	25925	Economy	12100.00
0005433985363	25925	Economy	12100.00
0005433960145	25925	Economy	12100.00
0005433960144	25925	Economy	12100.00
0005433985380	25925	Economy	12100.00
0005433960148	25925	Economy	12100.00
0005433985365	25925	Economy	12100.00
0005433985379	25925	Economy	12100.00
0005433960173	25925	Economy	12100.00
0005433960196	25925	Economy	12100.00
0005433960159	25925	Economy	12100.00
0005433960202	25925	Economy	12100.00
0005433960208	25925	Economy	12100.00
0005433960150	25925	Economy	12100.00
0005433960195	25925	Economy	12100.00
0005433985398	25925	Economy	12100.00
0005433985391	25925	Economy	12100.00
0005433985382	25925	Economy	12100.00
0005433960199	25925	Economy	12100.00
0005433960157	25925	Economy	12100.00
0005433985384	25925	Economy	12100.00
0005433960160	25925	Economy	12100.00
0005433960149	25925	Economy	12100.00
0005433985368	25925	Economy	12100.00
0005433960177	25925	Economy	12100.00
0005434480049	930	Economy	25400.00
0005434480042	930	Economy	25400.00
0005434480032	930	Economy	25400.00
0005434480039	930	Economy	25400.00
0005433165682	930	Economy	23100.00
0005434480043	930	Economy	23100.00
0005433165681	930	Economy	23100.00
0005434480036	930	Economy	23100.00
0005433165671	930	Economy	23100.00
0005434480034	930	Economy	23100.00
0005434480053	930	Economy	23100.00
0005434480046	930	Economy	23100.00
0005432269463	930	Economy	23100.00
0005433165672	930	Economy	23100.00
0005433165670	930	Economy	23100.00
0005434480044	930	Economy	23100.00
0005434480052	930	Economy	23100.00
0005434480054	930	Economy	23100.00
0005433165691	930	Economy	23100.00
0005434480037	930	Economy	23100.00
0005433165694	930	Economy	23100.00
0005434480055	930	Economy	23100.00
0005434480045	930	Economy	23100.00
0005434480033	930	Economy	23100.00
0005433165683	930	Economy	23100.00
0005434480041	930	Economy	23100.00
0005434480047	930	Economy	23100.00
0005432269464	930	Economy	23100.00
0005434480050	930	Economy	23100.00
0005434480048	930	Economy	23100.00
0005434480035	930	Economy	23100.00
0005434480040	930	Economy	23100.00
0005434480031	930	Economy	23100.00
0005434480038	930	Economy	23100.00
0005434480051	930	Economy	23100.00
0005434479889	16556	Economy	25400.00
0005433165752	16556	Economy	25400.00
0005433165759	16556	Economy	23100.00
0005434479888	16556	Economy	23100.00
0005433165757	16556	Economy	23100.00
0005433165761	16556	Economy	23100.00
0005433165754	16556	Economy	23100.00
0005433165753	16556	Economy	23100.00
0005433165750	16556	Economy	23100.00
0005434479897	16556	Economy	23100.00
0005434479894	16556	Economy	23100.00
0005433165755	16556	Economy	23100.00
0005434479902	16556	Economy	23100.00
0005433165751	16556	Economy	23100.00
0005433165758	16556	Economy	23100.00
0005433165756	16556	Economy	23100.00
0005433165760	16556	Economy	23100.00
0005434479895	16556	Economy	23100.00
0005433165762	16556	Economy	23100.00
0005435149866	10333	Economy	17000.00
0005435149864	10333	Economy	15400.00
0005435142412	10333	Economy	15400.00
0005435142410	10333	Economy	15400.00
0005435142409	10333	Economy	15400.00
0005435142416	10333	Economy	15400.00
0005435149863	10333	Economy	15400.00
0005435142408	10333	Economy	15400.00
0005435149856	10333	Economy	15400.00
0005435149868	10333	Economy	15400.00
0005435149861	10333	Economy	15400.00
0005435149857	10333	Economy	15400.00
0005435149860	10333	Economy	15400.00
0005435142413	10333	Economy	15400.00
0005435142406	10333	Economy	15400.00
0005435149859	10333	Economy	15400.00
0005435142417	10333	Economy	15400.00
0005435149867	10333	Economy	15400.00
0005435149858	10333	Economy	15400.00
0005435142405	10333	Economy	15400.00
0005435142415	10333	Economy	15400.00
0005435149865	10333	Economy	15400.00
0005435149862	10333	Economy	15400.00
0005435142411	10333	Economy	15400.00
0005435149869	10333	Economy	15400.00
0005435142414	10333	Economy	15400.00
0005435142407	10333	Economy	15400.00
0005433289774	21913	Economy	17000.00
0005433289769	21913	Economy	15400.00
0005433289772	21913	Economy	15400.00
0005435386503	21913	Economy	15400.00
0005435386500	21913	Economy	15400.00
0005435386501	21913	Economy	15400.00
0005435386502	21913	Economy	15400.00
0005435149825	21913	Economy	15400.00
0005433289768	21913	Economy	15400.00
0005435386498	21913	Economy	15400.00
0005433289770	21913	Economy	15400.00
0005433289775	21913	Economy	15400.00
0005433289773	21913	Economy	15400.00
0005433289771	21913	Economy	15400.00
0005435386499	21913	Economy	15400.00
0005434573173	11192	Business	57200.00
0005434573183	11192	Business	57200.00
0005434573187	11192	Business	57200.00
0005435319425	11192	Business	57200.00
0005434573179	11192	Economy	19100.00
0005435501941	11192	Economy	19100.00
0005435501943	11192	Economy	19100.00
0005434573174	11192	Economy	21000.00
0005435528921	11192	Economy	19100.00
0005434573181	11192	Economy	19100.00
0005435501949	11192	Economy	19100.00
0005434573178	11192	Economy	19100.00
0005434573186	11192	Economy	19100.00
0005435319424	11192	Economy	19100.00
0005434573184	11192	Economy	19100.00
0005435501942	11192	Economy	19100.00
0005434573177	11192	Economy	19100.00
0005434573185	11192	Economy	19100.00
0005434573175	11192	Economy	19100.00
0005434573176	11192	Economy	19100.00
0005434573182	11192	Economy	19100.00
0005434573180	11192	Economy	19100.00
0005435517698	20916	Business	57200.00
0005435319486	20916	Business	57200.00
0005435502043	20916	Business	57200.00
0005435319479	20916	Business	57200.00
0005435502062	20916	Business	57200.00
0005435517690	20916	Economy	19100.00
0005435517697	20916	Economy	19100.00
0005435319481	20916	Economy	19100.00
0005432291901	20916	Economy	19100.00
0005435502052	20916	Economy	19100.00
0005435508222	20916	Economy	19100.00
0005435502042	20916	Economy	19100.00
0005435508225	20916	Economy	21000.00
0005435502045	20916	Economy	21000.00
0005435502051	20916	Economy	21000.00
0005435517694	20916	Economy	21000.00
0005435502049	20916	Economy	19100.00
0005435319482	20916	Economy	19100.00
0005435517701	20916	Economy	19100.00
0005435517707	20916	Economy	19100.00
0005435517689	20916	Economy	19100.00
0005435508224	20916	Economy	19100.00
0005435502053	20916	Economy	19100.00
0005435517700	20916	Economy	19100.00
0005435502054	20916	Economy	19100.00
0005435502059	20916	Economy	19100.00
0005435502055	20916	Economy	19100.00
0005435319483	20916	Economy	19100.00
0005435517708	20916	Economy	19100.00
0005435517692	20916	Economy	19100.00
0005435502056	20916	Economy	19100.00
0005435319478	20916	Economy	19100.00
0005435502047	20916	Economy	19100.00
0005435502046	20916	Economy	19100.00
0005435502050	20916	Economy	19100.00
0005435517705	20916	Economy	19100.00
0005435517699	20916	Economy	19100.00
0005435319480	20916	Economy	19100.00
0005435517709	20916	Economy	19100.00
0005435508226	20916	Economy	19100.00
0005432291900	20916	Economy	19100.00
0005435502058	20916	Economy	19100.00
0005435517703	20916	Economy	19100.00
0005435517704	20916	Economy	19100.00
0005435502060	20916	Economy	19100.00
0005435517706	20916	Economy	19100.00
0005435508223	20916	Economy	19100.00
0005435517710	20916	Economy	19100.00
0005435517695	20916	Economy	19100.00
0005435502044	20916	Economy	19100.00
0005432291902	20916	Economy	19100.00
0005435319485	20916	Economy	19100.00
0005435508227	20916	Economy	19100.00
0005435517693	20916	Economy	19100.00
0005435502048	20916	Economy	19100.00
0005435502063	20916	Economy	19100.00
0005435517696	20916	Economy	19100.00
0005435319484	20916	Economy	19100.00
0005435517691	20916	Economy	19100.00
0005435502057	20916	Economy	19100.00
0005435517702	20916	Economy	19100.00
0005435502061	20916	Economy	19100.00
0005435508228	20916	Economy	19100.00
0005432692552	2990	Economy	3400.00
0005432692551	2990	Economy	3400.00
0005432706466	2989	Business	10300.00
0005432217742	2989	Business	10300.00
0005432706470	2989	Business	10300.00
0005432880572	2989	Business	10300.00
0005433123580	2989	Business	10300.00
0005432706485	2989	Business	10300.00
0005432706469	2989	Economy	3400.00
0005432706473	2989	Economy	3400.00
0005432706483	2989	Economy	3400.00
0005432880557	2989	Economy	3400.00
0005433123586	2989	Economy	3400.00
0005432706489	2989	Economy	3800.00
0005432706468	2989	Economy	3800.00
0005432706472	2989	Economy	3400.00
0005432706465	2989	Economy	3400.00
0005432706476	2989	Economy	3400.00
0005432706475	2989	Economy	3400.00
0005432706488	2989	Economy	3400.00
0005432706479	2989	Economy	3400.00
0005433123571	2989	Economy	3400.00
0005432880554	2989	Economy	3400.00
0005432706477	2989	Economy	3400.00
0005432706482	2989	Economy	3400.00
0005432217743	2989	Economy	3400.00
0005432706486	2989	Economy	3400.00
0005432706480	2989	Economy	3400.00
0005432217744	2989	Economy	3400.00
0005433123581	2989	Economy	3400.00
0005432706471	2989	Economy	3400.00
0005432706467	2989	Economy	3400.00
0005432706484	2989	Economy	3400.00
0005433123587	2989	Economy	3400.00
0005433123593	2989	Economy	3400.00
0005432706487	2989	Economy	3400.00
0005432706474	2989	Economy	3400.00
0005432706478	2989	Economy	3400.00
0005433123609	2989	Economy	3400.00
0005432706481	2989	Economy	3400.00
0005432692734	29944	Business	10300.00
0005432692719	29944	Business	10300.00
0005432706317	29944	Business	10300.00
0005433123679	29944	Business	10300.00
0005432692725	29944	Business	10300.00
0005432692743	29944	Business	10300.00
0005432692747	29944	Business	10300.00
0005432706374	29944	Economy	3400.00
0005433123697	29944	Economy	3400.00
0005432692720	29944	Economy	3400.00
0005432706400	29944	Economy	3400.00
0005432692729	29944	Economy	3400.00
0005433123686	29944	Economy	3400.00
0005433123685	29944	Economy	3400.00
0005433123682	29944	Economy	3400.00
0005432692730	29944	Economy	3400.00
0005432880647	29944	Economy	3800.00
0005432692737	29944	Economy	3800.00
0005432706401	29944	Economy	3800.00
0005432880649	29944	Economy	3800.00
0005433123692	29944	Economy	3400.00
0005432692733	29944	Economy	3400.00
0005433123681	29944	Economy	3400.00
0005432880648	29944	Economy	3400.00
0005433123680	29944	Economy	3400.00
0005432692741	29944	Economy	3400.00
0005433123691	29944	Economy	3400.00
0005432880651	29944	Economy	3400.00
0005433123688	29944	Economy	3400.00
0005432706311	29944	Economy	3400.00
0005432692731	29944	Economy	3400.00
0005433123689	29944	Economy	3400.00
0005432692726	29944	Economy	3400.00
0005432692724	29944	Economy	3400.00
0005432880644	29944	Economy	3400.00
0005432692732	29944	Economy	3400.00
0005432880643	29944	Economy	3400.00
0005432706312	29944	Economy	3400.00
0005432880645	29944	Economy	3400.00
0005432880650	29944	Economy	3400.00
0005432692742	29944	Economy	3400.00
0005432692740	29944	Economy	3400.00
0005432692727	29944	Economy	3400.00
0005432692736	29944	Economy	3400.00
0005432692721	29944	Economy	3400.00
0005432880653	29944	Economy	3400.00
0005433123695	29944	Economy	3400.00
0005432692722	29944	Economy	3400.00
0005433123683	29944	Economy	3400.00
0005432692739	29944	Economy	3400.00
0005433123687	29944	Economy	3400.00
0005432880646	29944	Economy	3400.00
0005433123694	29944	Economy	3400.00
0005432692745	29944	Economy	3400.00
0005432880655	29944	Economy	3400.00
0005432692718	29944	Economy	3400.00
0005432692746	29944	Economy	3400.00
0005432692728	29944	Economy	3400.00
0005433123698	29944	Economy	3400.00
0005432880642	29944	Economy	3400.00
0005432880654	29944	Economy	3400.00
0005432706373	29944	Economy	3400.00
0005433123693	29944	Economy	3400.00
0005432692735	29944	Economy	3400.00
0005432880641	29944	Economy	3400.00
0005432692744	29944	Economy	3400.00
0005432880652	29944	Economy	3400.00
0005432692738	29944	Economy	3400.00
0005432692723	29944	Economy	3400.00
0005432692717	29944	Economy	3400.00
0005433123696	29944	Economy	3400.00
0005433123690	29944	Economy	3400.00
0005433123684	29944	Economy	3400.00
0005434979430	23686	Economy	4000.00
0005434979409	23686	Economy	4000.00
0005434979435	23686	Economy	4000.00
0005434988607	23686	Economy	4000.00
0005434979436	23686	Economy	3600.00
0005434979434	23686	Economy	3600.00
0005434988604	23686	Economy	3600.00
0005434979425	23686	Economy	3600.00
0005434979428	23686	Economy	3600.00
0005434979433	23686	Economy	3600.00
0005434979419	23686	Economy	3600.00
0005434988602	23686	Economy	3600.00
0005434979416	23686	Economy	3600.00
0005434979424	23686	Economy	3600.00
0005434979418	23686	Economy	3600.00
0005434979415	23686	Economy	3600.00
0005434979407	23686	Economy	3600.00
0005434979432	23686	Economy	3600.00
0005434979431	23686	Economy	3600.00
0005434979421	23686	Economy	3600.00
0005434988600	23686	Economy	3600.00
0005434988603	23686	Economy	3600.00
0005434979410	23686	Economy	3600.00
0005434979411	23686	Economy	3600.00
0005434979414	23686	Economy	3600.00
0005434979426	23686	Economy	3600.00
0005434979429	23686	Economy	3600.00
0005434979412	23686	Economy	3600.00
0005434988606	23686	Economy	3600.00
0005434979417	23686	Economy	3600.00
0005434979413	23686	Economy	3600.00
0005434979422	23686	Economy	3600.00
0005434979423	23686	Economy	3600.00
0005434979420	23686	Economy	3600.00
0005434988599	23686	Economy	3600.00
0005434979427	23686	Economy	3600.00
0005434988605	23686	Economy	3600.00
0005434979408	23686	Economy	3600.00
0005434988601	23686	Economy	3600.00
0005434302405	10282	Economy	19700.00
0005434302407	10282	Economy	19700.00
0005434302404	10282	Economy	19700.00
0005434302406	10282	Economy	19700.00
0005434302382	19616	Economy	19700.00
0005433113509	19616	Economy	19700.00
0005433113510	19616	Economy	19700.00
0005435068514	3546	Business	26900.00
0005435068526	3546	Business	26900.00
0005435068515	3546	Business	26900.00
0005435068513	3546	Business	26900.00
0005435068479	3546	Business	26900.00
0005435068511	3546	Business	26900.00
0005435068505	3546	Business	26900.00
0005435718876	3546	Business	26900.00
0005435068486	3546	Business	26900.00
0005435068487	3546	Economy	9000.00
0005435068528	3546	Economy	9000.00
0005435068521	3546	Economy	9000.00
0005435068506	3546	Economy	9000.00
0005435068482	3546	Economy	9000.00
0005435068523	3546	Economy	9900.00
0005435068488	3546	Economy	9900.00
0005435068490	3546	Economy	9000.00
0005435068519	3546	Economy	9000.00
0005435068499	3546	Economy	9000.00
0005435068495	3546	Economy	9000.00
0005435068525	3546	Economy	9000.00
0005435068517	3546	Economy	9000.00
0005435068507	3546	Economy	9000.00
0005435068492	3546	Economy	9000.00
0005435718877	3546	Economy	9000.00
0005435718878	3546	Economy	9000.00
0005435068501	3546	Economy	9000.00
0005435718875	3546	Economy	9000.00
0005435068498	3546	Economy	9000.00
0005435068481	3546	Economy	9000.00
0005435068520	3546	Economy	9000.00
0005435068518	3546	Economy	9000.00
0005435068496	3546	Economy	9000.00
0005435068478	3546	Economy	9000.00
0005435068491	3546	Economy	9000.00
0005435068509	3546	Economy	9000.00
0005435718872	3546	Economy	9000.00
0005435068512	3546	Economy	9000.00
0005435068508	3546	Economy	9000.00
0005435068502	3546	Economy	9000.00
0005435068480	3546	Economy	9000.00
0005435068527	3546	Economy	9000.00
0005435068489	3546	Economy	9000.00
0005435068503	3546	Economy	9000.00
0005435068493	3546	Economy	9000.00
0005435068477	3546	Economy	9000.00
0005435068484	3546	Economy	9000.00
0005435068494	3546	Economy	9000.00
0005435718871	3546	Economy	9000.00
0005435718874	3546	Economy	9000.00
0005435068500	3546	Economy	9000.00
0005435068522	3546	Economy	9000.00
0005435068524	3546	Economy	9000.00
0005435068497	3546	Economy	9000.00
0005435068476	3546	Economy	9000.00
0005435068483	3546	Economy	9000.00
0005435068504	3546	Economy	9000.00
0005435068516	3546	Economy	9000.00
0005435718873	3546	Economy	9000.00
0005435068510	3546	Economy	9000.00
0005435068485	3546	Economy	9000.00
0005435925142	15296	Business	26900.00
0005435925135	15296	Business	26900.00
0005435925133	15296	Economy	9000.00
0005435925134	15296	Economy	9000.00
0005435925143	15296	Economy	9000.00
0005435925137	15296	Economy	9900.00
0005435925138	15296	Economy	9000.00
0005435068238	15296	Economy	9000.00
0005435925130	15296	Economy	9000.00
0005435925144	15296	Economy	9000.00
0005435068181	15296	Economy	9000.00
0005435068208	15296	Economy	9000.00
0005435925146	15296	Economy	9000.00
0005435925145	15296	Economy	9000.00
0005435068161	15296	Economy	9000.00
0005435925139	15296	Economy	9000.00
0005435925136	15296	Economy	9000.00
0005435925129	15296	Economy	9000.00
0005435925132	15296	Economy	9000.00
0005435939863	15296	Economy	9000.00
0005435068236	15296	Economy	9000.00
0005435925147	15296	Economy	9000.00
0005435925131	15296	Economy	9000.00
0005435925141	15296	Economy	9000.00
0005435925140	15296	Economy	9000.00
0005435068162	15296	Economy	9000.00
0005435068211	15296	Economy	9000.00
0005435068260	15296	Economy	9000.00
0005432660793	18173	Economy	5900.00
0005432658567	18173	Economy	5900.00
0005432659683	18173	Economy	5900.00
0005432660794	18173	Economy	5900.00
0005432659682	18173	Economy	5900.00
0005432901324	184	Business	20000.00
0005432901307	184	Business	20000.00
0005432901320	184	Economy	7300.00
0005432919520	184	Economy	6700.00
0005432901299	184	Economy	6700.00
0005432901339	184	Economy	6700.00
0005432901310	184	Economy	6700.00
0005432901327	184	Economy	6700.00
0005432157469	184	Economy	7300.00
0005432157470	184	Economy	6700.00
0005432901294	184	Economy	6700.00
0005432919519	184	Economy	6700.00
0005432901321	184	Economy	6700.00
0005432919541	184	Economy	6700.00
0005432901311	184	Economy	6700.00
0005432901340	184	Economy	6700.00
0005432261401	182	Business	20000.00
0005432261381	182	Business	20000.00
0005432817137	182	Business	20000.00
0005432261383	182	Business	20000.00
0005432817121	182	Business	20000.00
0005432817146	182	Business	20000.00
0005432817135	182	Business	20000.00
0005432261409	182	Business	20000.00
0005432817128	182	Business	20000.00
0005432817133	182	Business	20000.00
0005432817119	182	Business	20000.00
0005432261405	182	Economy	7300.00
0005432261389	182	Economy	6700.00
0005432288948	182	Economy	6700.00
0005432261411	182	Economy	6700.00
0005432288949	182	Economy	6700.00
0005432261384	182	Economy	6700.00
0005432817132	182	Economy	6700.00
0005432261395	182	Economy	6700.00
0005432817124	182	Economy	6700.00
0005432261372	182	Economy	6700.00
0005432261375	182	Economy	6700.00
0005432817148	182	Economy	6700.00
0005432207629	182	Economy	6700.00
0005432261376	182	Economy	6700.00
0005432261374	182	Economy	6700.00
0005432817145	182	Economy	6700.00
0005432817127	182	Economy	6700.00
0005432207630	182	Economy	6700.00
0005432261379	182	Economy	6700.00
0005432261388	182	Economy	6700.00
0005432261378	182	Economy	6700.00
0005433690893	182	Economy	6700.00
0005432261398	182	Economy	6700.00
0005432817122	182	Economy	6700.00
0005432817142	182	Economy	6700.00
0005432261408	182	Economy	6700.00
0005432261390	182	Economy	6700.00
0005432261400	182	Economy	6700.00
0005432817144	182	Economy	6700.00
0005432261410	182	Economy	6700.00
0005432817140	182	Economy	6700.00
0005432817134	182	Economy	6700.00
0005432817126	182	Economy	6700.00
0005432261406	182	Economy	7300.00
0005432261382	182	Economy	7300.00
0005432261404	182	Economy	7300.00
0005432261387	182	Economy	6700.00
0005432207631	182	Economy	7300.00
0005432261396	182	Economy	6700.00
0005432261391	182	Economy	6700.00
0005432261393	182	Economy	6700.00
0005432817141	182	Economy	6700.00
0005432261412	182	Economy	6700.00
0005432817131	182	Economy	6700.00
0005432817123	182	Economy	6700.00
0005432261370	182	Economy	6700.00
0005432261394	182	Economy	6700.00
0005432261402	182	Economy	6700.00
0005432261397	182	Economy	6700.00
0005432261386	182	Economy	6700.00
0005432261399	182	Economy	6700.00
0005432817130	182	Economy	6700.00
0005432261392	182	Economy	6700.00
0005432261403	182	Economy	6700.00
0005432288950	182	Economy	6700.00
0005432261407	182	Economy	6700.00
0005432288947	182	Economy	6700.00
0005432817147	182	Economy	6700.00
0005432261413	182	Economy	6700.00
0005432261414	182	Economy	6700.00
0005432817139	182	Economy	6700.00
0005432261385	182	Economy	6700.00
0005432817149	182	Economy	6700.00
0005432261371	182	Economy	6700.00
0005432817143	182	Economy	6700.00
0005432261368	182	Economy	6700.00
0005432261380	182	Economy	6700.00
0005434153520	182	Economy	6700.00
0005432817136	182	Economy	6700.00
0005432261373	182	Economy	6700.00
0005432817120	182	Economy	6700.00
0005432261377	182	Economy	6700.00
0005432817129	182	Economy	6700.00
0005434153519	182	Economy	6700.00
0005432817138	182	Economy	6700.00
0005432817125	182	Economy	6700.00
0005433690890	182	Economy	6700.00
0005432261369	182	Economy	6700.00
0005432019954	8018	Business	20000.00
0005433101530	8018	Business	20000.00
0005432019956	8018	Business	20000.00
0005432677531	8018	Business	20000.00
0005433101518	8018	Business	20000.00
0005432919615	8018	Business	20000.00
0005432919624	8018	Business	20000.00
0005433101558	8018	Business	20000.00
0005433101581	8018	Business	20000.00
0005432019948	8018	Business	20000.00
0005433101576	8018	Business	20000.00
0005432019955	8018	Business	20000.00
0005433101579	8018	Business	20000.00
0005432019953	8018	Business	20000.00
0005432019960	8018	Business	20000.00
0005432019959	8018	Business	20000.00
0005432919614	8018	Business	20000.00
0005433101560	8018	Business	20000.00
0005432677530	8018	Business	20000.00
0005433101569	8018	Business	20000.00
0005432753262	8018	Economy	7300.00
0005433101524	8018	Economy	7300.00
0005432019951	8018	Economy	7300.00
0005432045592	8018	Economy	7300.00
0005433101575	8018	Economy	6700.00
0005433101547	8018	Economy	6700.00
0005432019950	8018	Economy	6700.00
0005433101572	8018	Economy	6700.00
0005433101566	8018	Economy	6700.00
0005433101543	8018	Economy	6700.00
0005432919625	8018	Economy	6700.00
0005433101520	8018	Economy	6700.00
0005432019969	8018	Economy	6700.00
0005432044493	8018	Economy	6700.00
0005433101551	8018	Economy	6700.00
0005432677529	8018	Economy	6700.00
0005433101563	8018	Economy	6700.00
0005432019944	8018	Economy	6700.00
0005432919619	8018	Economy	6700.00
0005432919627	8018	Economy	6700.00
0005433101571	8018	Economy	6700.00
0005433101587	8018	Economy	6700.00
0005433101554	8018	Economy	6700.00
0005433101529	8018	Economy	6700.00
0005433101542	8018	Economy	6700.00
0005433101582	8018	Economy	6700.00
0005433101533	8018	Economy	6700.00
0005433101523	8018	Economy	6700.00
0005432919623	8018	Economy	6700.00
0005433101548	8018	Economy	6700.00
0005432919612	8018	Economy	6700.00
0005432751488	8018	Economy	6700.00
0005432019945	8018	Economy	6700.00
0005432019967	8018	Economy	6700.00
0005433101540	8018	Economy	6700.00
0005432019964	8018	Economy	6700.00
0005433101517	8018	Economy	6700.00
0005432919626	8018	Economy	6700.00
0005432019966	8018	Economy	6700.00
0005432019946	8018	Economy	6700.00
0005433101549	8018	Economy	6700.00
0005432391966	8018	Economy	6700.00
0005433101568	8018	Economy	6700.00
0005432919611	8018	Economy	6700.00
0005433101537	8018	Economy	6700.00
0005432753263	8018	Economy	6700.00
0005432019957	8018	Economy	6700.00
0005432391965	8018	Economy	6700.00
0005432919617	8018	Economy	6700.00
0005432919621	8018	Economy	6700.00
0005433101552	8018	Economy	6700.00
0005432019947	8018	Economy	6700.00
0005432751489	8018	Economy	6700.00
0005433101521	8018	Economy	6700.00
0005433101535	8018	Economy	7300.00
0005433101584	8018	Economy	7300.00
0005432919620	8018	Economy	7300.00
0005432044492	8018	Economy	6700.00
0005433101556	8018	Economy	7300.00
0005432019970	8018	Economy	6700.00
0005433101580	8018	Economy	6700.00
0005433101545	8018	Economy	6700.00
0005432019958	8018	Economy	6700.00
0005432919618	8018	Economy	7300.00
0005433101526	8018	Economy	6700.00
0005433101534	8018	Economy	6700.00
0005433101527	8018	Economy	6700.00
0005433101546	8018	Economy	6700.00
0005433101559	8018	Economy	6700.00
0005433101531	8018	Economy	6700.00
0005433101561	8018	Economy	6700.00
0005432677528	8018	Economy	6700.00
0005432753265	8018	Economy	6700.00
0005432019965	8018	Economy	6700.00
0005433101583	8018	Economy	6700.00
0005432677532	8018	Economy	6700.00
0005433101532	8018	Economy	6700.00
0005432019962	8018	Economy	6700.00
0005433101522	8018	Economy	6700.00
0005433101578	8018	Economy	6700.00
0005432919630	8018	Economy	6700.00
0005433101550	8018	Economy	6700.00
0005432044494	8018	Economy	6700.00
0005433101570	8018	Economy	6700.00
0005433101586	8018	Economy	6700.00
0005433101555	8018	Economy	6700.00
0005433101528	8018	Economy	6700.00
0005432919628	8018	Economy	6700.00
0005432919622	8018	Economy	6700.00
0005433101557	8018	Economy	6700.00
0005432751490	8018	Economy	6700.00
0005432019968	8018	Economy	6700.00
0005433101577	8018	Economy	6700.00
0005433101525	8018	Economy	6700.00
0005432919613	8018	Economy	6700.00
0005432019949	8018	Economy	6700.00
0005433101565	8018	Economy	6700.00
0005432753264	8018	Economy	6700.00
0005432919616	8018	Economy	6700.00
0005433101567	8018	Economy	6700.00
0005432919610	8018	Economy	6700.00
0005433101588	8018	Economy	6700.00
0005433101544	8018	Economy	6700.00
0005433101538	8018	Economy	6700.00
0005433101564	8018	Economy	6700.00
0005433101536	8018	Economy	6700.00
0005432751491	8018	Economy	6700.00
0005433101519	8018	Economy	6700.00
0005433101574	8018	Economy	6700.00
0005433101541	8018	Economy	6700.00
0005432019963	8018	Economy	6700.00
0005433101562	8018	Economy	6700.00
0005432919629	8018	Economy	6700.00
0005433101585	8018	Economy	6700.00
0005433101553	8018	Economy	6700.00
0005433101539	8018	Economy	6700.00
0005433101573	8018	Economy	6700.00
0005432019961	8018	Economy	6700.00
0005432019952	8018	Economy	6700.00
0005432816963	8019	Business	20000.00
0005432901409	8019	Economy	7300.00
0005432002052	8019	Economy	7300.00
0005432901416	8019	Economy	6700.00
0005432901410	8019	Economy	6700.00
0005432901407	8019	Economy	6700.00
0005432901402	8019	Economy	6700.00
0005432002053	8019	Economy	6700.00
0005432901404	8019	Economy	6700.00
0005432901406	8019	Economy	6700.00
0005432901405	8019	Economy	6700.00
0005432901414	8019	Economy	6700.00
0005432901415	8019	Economy	6700.00
0005432901408	8019	Economy	6700.00
0005432901412	8019	Economy	6700.00
0005432002054	8019	Economy	6700.00
0005432901418	8019	Economy	6700.00
0005432901403	8019	Economy	6700.00
0005432901417	8019	Economy	6700.00
0005432901411	8019	Economy	6700.00
0005432901413	8019	Economy	6700.00
0005433870705	9658	Economy	6900.00
0005433870706	9658	Economy	6900.00
0005433870695	32342	Economy	6900.00
0005434175707	32342	Economy	6900.00
0005434175705	32342	Economy	6900.00
0005434175703	32342	Economy	6900.00
0005434175702	32342	Economy	6900.00
0005434175706	32342	Economy	6900.00
0005434175704	32342	Economy	6900.00
0005434426286	3511	Business	35000.00
0005435125926	3511	Business	35000.00
0005434937932	3511	Business	35000.00
0005435125928	3511	Business	35000.00
0005434877181	3511	Business	35000.00
0005434426271	3511	Business	35000.00
0005434937930	3511	Business	35000.00
0005432611665	3511	Business	35000.00
0005434877167	3511	Business	35000.00
0005432799138	3511	Business	35000.00
0005432799133	3511	Business	35000.00
0005432611664	3511	Business	35000.00
0005432799147	3511	Business	35000.00
0005434877201	3511	Business	35000.00
0005434877141	3511	Comfort	19900.00
0005434877194	3511	Comfort	19900.00
0005435125918	3511	Comfort	19900.00
0005434877143	3511	Comfort	19900.00
0005434877206	3511	Comfort	19900.00
0005434426293	3511	Comfort	19900.00
0005435125912	3511	Comfort	19900.00
0005434877199	3511	Comfort	19900.00
0005434877234	3511	Comfort	19900.00
0005435625973	3511	Comfort	19900.00
0005434877219	3511	Comfort	19900.00
0005434877203	3511	Comfort	19900.00
0005435125922	3511	Comfort	19900.00
0005434877164	3511	Comfort	19900.00
0005435125911	3511	Comfort	19900.00
0005434877177	3511	Comfort	19900.00
0005435125909	3511	Comfort	19900.00
0005434426273	3511	Comfort	19900.00
0005434877148	3511	Comfort	19900.00
0005432611666	3511	Comfort	19900.00
0005434937924	3511	Comfort	19900.00
0005432613814	3511	Comfort	19900.00
0005434426269	3511	Comfort	19900.00
0005434877179	3511	Comfort	19900.00
0005435125901	3511	Comfort	19900.00
0005434877202	3511	Comfort	19900.00
0005432799151	3511	Comfort	19900.00
0005435625971	3511	Comfort	19900.00
0005434877151	3511	Comfort	19900.00
0005434877197	3511	Comfort	19900.00
0005434877173	3511	Comfort	19900.00
0005435625983	3511	Economy	11700.00
0005434877190	3511	Economy	11700.00
0005434877175	3511	Economy	11700.00
0005435125897	3511	Economy	11700.00
0005434877139	3511	Economy	11700.00
0005434937917	3511	Economy	11700.00
0005434426290	3511	Economy	11700.00
0005435625981	3511	Economy	11700.00
0005434877196	3511	Economy	11700.00
0005435902399	3511	Economy	11700.00
0005435625977	3511	Economy	11700.00
0005434426282	3511	Economy	11700.00
0005432799135	3511	Economy	11700.00
0005434426279	3511	Economy	11700.00
0005434877163	3511	Economy	11700.00
0005435625972	3511	Economy	11700.00
0005432799137	3511	Economy	11700.00
0005434877214	3511	Economy	11700.00
0005434877176	3511	Economy	11700.00
0005435125902	3511	Economy	11700.00
0005434877217	3511	Economy	11700.00
0005432613817	3511	Economy	11700.00
0005434426277	3511	Economy	11700.00
0005434877224	3511	Economy	11700.00
0005434426289	3511	Economy	11700.00
0005434937913	3511	Economy	11700.00
0005432799136	3511	Economy	11700.00
0005435125927	3511	Economy	11700.00
0005432799139	3511	Economy	11700.00
0005435125907	3511	Economy	11700.00
0005432799130	3511	Economy	11700.00
0005434877188	3511	Economy	11700.00
0005432188572	3511	Economy	11700.00
0005432799129	3511	Economy	11700.00
0005434877147	3511	Economy	11700.00
0005434877170	3511	Economy	11700.00
0005432188570	3511	Economy	11700.00
0005432799149	3511	Economy	11700.00
0005432613813	3511	Economy	11700.00
0005434877218	3511	Economy	11700.00
0005435125919	3511	Economy	11700.00
0005434877189	3511	Economy	11700.00
0005434877168	3511	Economy	11700.00
0005434937922	3511	Economy	11700.00
0005435125932	3511	Economy	12800.00
0005432799152	3511	Economy	12800.00
0005434877210	3511	Economy	11700.00
0005432799143	3511	Economy	12800.00
0005434426294	3511	Economy	11700.00
0005432799140	3511	Economy	11700.00
0005434937912	3511	Economy	11700.00
0005432611663	3511	Economy	11700.00
0005434937919	3511	Economy	11700.00
0005434877193	3511	Economy	11700.00
0005432613818	3511	Economy	11700.00
0005435125915	3511	Economy	11700.00
0005432183442	3511	Economy	11700.00
0005434877174	3511	Economy	11700.00
0005434426278	3511	Economy	11700.00
0005435625975	3511	Economy	11700.00
0005435125923	3511	Economy	11700.00
0005434426284	3511	Economy	11700.00
0005435125924	3511	Economy	11700.00
0005434877208	3511	Economy	11700.00
0005434937927	3511	Economy	11700.00
0005434877165	3511	Economy	11700.00
0005432799131	3511	Economy	11700.00
0005432799142	3511	Economy	11700.00
0005435125937	3511	Economy	11700.00
0005432799127	3511	Economy	11700.00
0005432188569	3511	Economy	11700.00
0005435625978	3511	Economy	11700.00
0005435125921	3511	Economy	11700.00
0005434877192	3511	Economy	11700.00
0005435125917	3511	Economy	11700.00
0005434877146	3511	Economy	11700.00
0005432799126	3511	Economy	11700.00
0005434937925	3511	Economy	11700.00
0005434877162	3511	Economy	11700.00
0005435125916	3511	Economy	11700.00
0005434877230	3511	Economy	11700.00
0005434877213	3511	Economy	11700.00
0005434877158	3511	Economy	11700.00
0005434877233	3511	Economy	11700.00
0005435125900	3511	Economy	11700.00
0005435625982	3511	Economy	11700.00
0005434877159	3511	Economy	11700.00
0005435125899	3511	Economy	11700.00
0005432799144	3511	Economy	11700.00
0005434877155	3511	Economy	11700.00
0005435125908	3511	Economy	11700.00
0005434877180	3511	Economy	11700.00
0005434877185	3511	Economy	11700.00
0005435902398	3511	Economy	11700.00
0005434877154	3511	Economy	11700.00
0005432799132	3511	Economy	11700.00
0005434937923	3511	Economy	11700.00
0005434426291	3511	Economy	11700.00
0005434877142	3511	Economy	11700.00
0005434877153	3511	Economy	11700.00
0005435125913	3511	Economy	11700.00
0005434426281	3511	Economy	11700.00
0005434877200	3511	Economy	11700.00
0005434877183	3511	Economy	11700.00
0005434426268	3511	Economy	11700.00
0005434877184	3511	Economy	11700.00
0005435125904	3511	Economy	11700.00
0005434937914	3511	Economy	11700.00
0005432799153	3511	Economy	11700.00
0005435125903	3511	Economy	11700.00
0005434426270	3511	Economy	11700.00
0005435125925	3511	Economy	11700.00
0005434877178	3511	Economy	11700.00
0005434937928	3511	Economy	11700.00
0005434426266	3511	Economy	11700.00
0005434877160	3511	Economy	11700.00
0005435625979	3511	Economy	11700.00
0005435125914	3511	Economy	11700.00
0005435125934	3511	Economy	11700.00
0005434877152	3511	Economy	11700.00
0005435125905	3511	Economy	11700.00
0005434877227	3511	Economy	11700.00
0005434877157	3511	Economy	11700.00
0005432799150	3511	Economy	11700.00
0005434877187	3511	Economy	11700.00
0005434877216	3511	Economy	11700.00
0005434937931	3511	Economy	12800.00
0005434877171	3511	Economy	12800.00
0005434877207	3511	Economy	12800.00
0005434877225	3511	Economy	12800.00
0005434877140	3511	Economy	12800.00
0005432183441	3511	Economy	11700.00
0005434877209	3511	Economy	11700.00
0005434426287	3511	Economy	11700.00
0005434937920	3511	Economy	11700.00
0005434877204	3511	Economy	11700.00
0005434937929	3511	Economy	11700.00
0005434937926	3511	Economy	11700.00
0005434877169	3511	Economy	11700.00
0005435625976	3511	Economy	11700.00
0005435125936	3511	Economy	11700.00
0005434426283	3511	Economy	11700.00
0005435125920	3511	Economy	11700.00
0005435125906	3511	Economy	11700.00
0005434877149	3511	Economy	11700.00
0005434937915	3511	Economy	11700.00
0005434426267	3511	Economy	11700.00
0005434426265	3511	Economy	11700.00
0005434877186	3511	Economy	11700.00
0005434877138	3511	Economy	11700.00
0005434877172	3511	Economy	11700.00
0005434426288	3511	Economy	11700.00
0005432799148	3511	Economy	11700.00
0005434877166	3511	Economy	11700.00
0005434877232	3511	Economy	11700.00
0005434877191	3511	Economy	11700.00
0005432188571	3511	Economy	11700.00
0005432799145	3511	Economy	11700.00
0005434877145	3511	Economy	11700.00
0005434877195	3511	Economy	11700.00
0005434937918	3511	Economy	11700.00
0005434877198	3511	Economy	11700.00
0005434877150	3511	Economy	11700.00
0005434426272	3511	Economy	11700.00
0005435125929	3511	Economy	11700.00
0005432611667	3511	Economy	11700.00
0005434937916	3511	Economy	11700.00
0005432799128	3511	Economy	11700.00
0005432613815	3511	Economy	11700.00
0005432613816	3511	Economy	11700.00
0005434877156	3511	Economy	11700.00
0005434877144	3511	Economy	11700.00
0005434877231	3511	Economy	11700.00
0005434426274	3511	Economy	11700.00
0005434877215	3511	Economy	11700.00
0005432799146	3511	Economy	11700.00
0005432799141	3511	Economy	11700.00
0005434426280	3511	Economy	11700.00
0005435125898	3511	Economy	11700.00
0005434877226	3511	Economy	11700.00
0005434877161	3511	Economy	11700.00
0005434426285	3511	Economy	11700.00
0005434426292	3511	Economy	11700.00
0005434426276	3511	Economy	11700.00
0005435625980	3511	Economy	11700.00
0005434877212	3511	Economy	11700.00
0005434877211	3511	Economy	11700.00
0005432799134	3511	Economy	11700.00
0005435125933	3511	Economy	11700.00
0005434877220	3511	Economy	11700.00
0005435125910	3511	Economy	11700.00
0005434877182	3511	Economy	11700.00
0005434426275	3511	Economy	11700.00
0005434877221	3511	Economy	11700.00
0005434877229	3511	Economy	11700.00
0005435125931	3511	Economy	11700.00
0005435125935	3511	Economy	11700.00
0005435125930	3511	Economy	11700.00
0005434877223	3511	Economy	11700.00
0005432799154	3511	Economy	11700.00
0005434877222	3511	Economy	11700.00
0005434877228	3511	Economy	11700.00
0005434937921	3511	Economy	11700.00
0005435625974	3511	Economy	11700.00
0005434877205	3511	Economy	11700.00
0005434426295	3511	Economy	11700.00
0005434876574	14576	Business	35000.00
0005434876782	14576	Business	35000.00
0005434426113	14576	Business	35000.00
0005435125668	14576	Business	35000.00
0005434426111	14576	Business	35000.00
0005435902496	14576	Comfort	19900.00
0005434876630	14576	Business	35000.00
0005435902503	14576	Comfort	19900.00
0005434876571	14576	Comfort	19900.00
0005435902502	14576	Comfort	19900.00
0005435902510	14576	Comfort	19900.00
0005434876784	14576	Comfort	19900.00
0005432798957	14576	Comfort	19900.00
0005435913891	14576	Comfort	19900.00
0005434876611	14576	Economy	11700.00
0005432059482	14576	Economy	11700.00
0005435125649	14576	Economy	11700.00
0005434937877	14576	Economy	11700.00
0005432799008	14576	Economy	11700.00
0005435125684	14576	Economy	11700.00
0005434937831	14576	Economy	11700.00
0005434876575	14576	Economy	11700.00
0005434426094	14576	Economy	11700.00
0005434426120	14576	Economy	11700.00
0005435842320	14576	Economy	11700.00
0005435902511	14576	Economy	11700.00
0005435902494	14576	Economy	11700.00
0005434426086	14576	Economy	11700.00
0005435902498	14576	Economy	11700.00
0005435842319	14576	Economy	12800.00
0005434937829	14576	Economy	11700.00
0005434937802	14576	Economy	11700.00
0005435842321	14576	Economy	12800.00
0005434937813	14576	Economy	11700.00
0005435902504	14576	Economy	11700.00
0005435842322	14576	Economy	11700.00
0005434876576	14576	Economy	11700.00
0005435902505	14576	Economy	11700.00
0005434876686	14576	Economy	11700.00
0005434876582	14576	Economy	11700.00
0005434937806	14576	Economy	11700.00
0005435125669	14576	Economy	11700.00
0005435902501	14576	Economy	11700.00
0005435913892	14576	Economy	11700.00
0005435902497	14576	Economy	11700.00
0005434876783	14576	Economy	11700.00
0005432059483	14576	Economy	11700.00
0005434937828	14576	Economy	11700.00
0005434876626	14576	Economy	11700.00
0005434876581	14576	Economy	11700.00
0005435902495	14576	Economy	11700.00
0005435902493	14576	Economy	11700.00
0005434876586	14576	Economy	11700.00
0005435902507	14576	Economy	11700.00
0005434876606	14576	Economy	12800.00
0005434876556	14576	Economy	11700.00
0005435841813	14576	Economy	11700.00
0005435902509	14576	Economy	11700.00
0005434876632	14576	Economy	11700.00
0005434876717	14576	Economy	11700.00
0005432611653	14576	Economy	11700.00
0005435902499	14576	Economy	11700.00
0005435913889	14576	Economy	11700.00
0005434876588	14576	Economy	11700.00
0005434937799	14576	Economy	11700.00
0005434876617	14576	Economy	11700.00
0005435902500	14576	Economy	11700.00
0005434876650	14576	Economy	11700.00
0005434876555	14576	Economy	11700.00
0005435913890	14576	Economy	11700.00
0005434937832	14576	Economy	11700.00
0005435902506	14576	Economy	11700.00
0005434426085	14576	Economy	11700.00
0005435125657	14576	Economy	11700.00
0005434937827	14576	Economy	11700.00
0005434876625	14576	Economy	11700.00
0005435902508	14576	Economy	11700.00
0005432798958	14576	Economy	11700.00
0005434426169	14576	Economy	11700.00
0005434937876	14576	Economy	11700.00
0005434426110	14576	Economy	11700.00
0005432799007	14576	Economy	11700.00
0005435889796	3614	Economy	16300.00
0005434312294	3614	Economy	14800.00
0005434325517	3614	Economy	14800.00
0005434325514	3614	Economy	14800.00
0005434325520	3614	Economy	14800.00
0005434325515	3614	Economy	14800.00
0005434325521	3614	Economy	14800.00
0005435889797	3614	Economy	14800.00
0005434325518	3614	Economy	14800.00
0005434325523	3614	Economy	14800.00
0005434325524	3614	Economy	14800.00
0005434312295	3614	Economy	14800.00
0005434325516	3614	Economy	14800.00
0005434325525	3614	Economy	14800.00
0005434325519	3614	Economy	14800.00
0005434325522	3614	Economy	14800.00
0005434325459	15630	Economy	16300.00
0005435889827	15630	Economy	16300.00
0005435889828	15630	Economy	16300.00
0005434325474	15630	Economy	14800.00
0005434325443	15630	Economy	14800.00
0005434325478	15630	Economy	14800.00
0005435889831	15630	Economy	14800.00
0005434325462	15630	Economy	14800.00
0005435889825	15630	Economy	14800.00
0005435889826	15630	Economy	14800.00
0005434325469	15630	Economy	14800.00
0005434325446	15630	Economy	14800.00
0005434325472	15630	Economy	14800.00
0005435889830	15630	Economy	14800.00
0005434325463	15630	Economy	14800.00
0005435889829	15630	Economy	14800.00
0005434325473	15630	Economy	14800.00
0005435957530	658	Economy	4500.00
0005435957540	658	Economy	4100.00
0005435957541	658	Economy	4100.00
0005433420266	658	Economy	4100.00
0005435957538	658	Economy	4100.00
0005435957537	658	Economy	4100.00
0005435957543	658	Economy	4100.00
0005435957536	658	Economy	4100.00
0005435957539	658	Economy	4100.00
0005435957533	658	Economy	4100.00
0005435957542	658	Economy	4100.00
0005435957532	658	Economy	4100.00
0005435957535	658	Economy	4100.00
0005435957534	658	Economy	4100.00
0005435957531	658	Economy	4100.00
0005435957529	658	Economy	4100.00
0005433420306	15176	Economy	4500.00
0005435957480	15176	Economy	4500.00
0005433420303	15176	Economy	4100.00
0005433420301	15176	Economy	4100.00
0005433420304	15176	Economy	4100.00
0005433420305	15176	Economy	4100.00
0005435957441	15176	Economy	4100.00
0005433420302	15176	Economy	4100.00
0005433420309	15176	Economy	4100.00
0005433420307	15176	Economy	4100.00
0005435957453	15176	Economy	4100.00
0005433420308	15176	Economy	4100.00
0005434247118	16034	Economy	10400.00
0005434247119	16034	Economy	10400.00
0005434247117	16034	Economy	10400.00
0005434096720	20174	Economy	13400.00
0005434096715	20174	Economy	13400.00
0005434096716	20174	Economy	13400.00
0005434096714	20174	Economy	13400.00
0005434096719	20174	Economy	13400.00
0005434096718	20174	Economy	13400.00
0005434096717	20174	Economy	13400.00
0005435229352	25115	Business	87700.00
0005435229341	25115	Business	87700.00
0005435229343	25115	Economy	29200.00
0005435229333	25115	Economy	32200.00
0005435229336	25115	Economy	32200.00
0005432645769	25115	Economy	29200.00
0005435229345	25115	Economy	29200.00
0005435229342	25115	Economy	29200.00
0005435229338	25115	Economy	29200.00
0005435229344	25115	Economy	29200.00
0005435229331	25115	Economy	29200.00
0005435229346	25115	Economy	29200.00
0005435229349	25115	Economy	29200.00
0005435229348	25115	Economy	29200.00
0005435229350	25115	Economy	29200.00
0005435229332	25115	Economy	29200.00
0005435229339	25115	Economy	29200.00
0005435229334	25115	Economy	29200.00
0005435229337	25115	Economy	29200.00
0005435229347	25115	Economy	29200.00
0005435229340	25115	Economy	29200.00
0005435229335	25115	Economy	29200.00
0005432645771	25115	Economy	29200.00
0005435229351	25115	Economy	29200.00
0005435797313	2834	Business	12600.00
0005435797311	2834	Business	12600.00
0005435797320	2834	Economy	4200.00
0005435797309	2834	Economy	4200.00
0005435797322	2834	Economy	4200.00
0005435797310	2834	Economy	4200.00
0005435797316	2834	Economy	4200.00
0005435797314	2834	Economy	4200.00
0005435797318	2834	Economy	4200.00
0005435797312	2834	Economy	4200.00
0005435797315	2834	Economy	4200.00
0005435797319	2834	Economy	4200.00
0005435797317	2834	Economy	4200.00
0005435797321	2834	Economy	4200.00
0005435797280	29301	Economy	4200.00
0005435797273	29301	Economy	4200.00
0005435797235	29301	Economy	4200.00
0005433404725	29301	Economy	4200.00
0005433404722	29301	Economy	4200.00
0005433404728	29301	Economy	4200.00
0005433404723	29301	Economy	4200.00
0005435797236	29301	Economy	4200.00
0005435797291	29301	Economy	4200.00
0005433404726	29301	Economy	4200.00
0005433404727	29301	Economy	4200.00
0005433404724	29301	Economy	4200.00
0005435797281	29301	Economy	4200.00
0005434947922	5837	Economy	6800.00
0005434947927	5837	Economy	6800.00
0005434947928	5837	Economy	6800.00
0005434947924	5837	Economy	6800.00
0005434947929	5837	Economy	6800.00
0005434947923	5837	Economy	6800.00
0005434947926	5837	Economy	6800.00
0005434947925	5837	Economy	6800.00
0005434947930	5837	Economy	6800.00
0005433960238	6868	Business	21400.00
0005433960219	6868	Business	21400.00
0005433960264	6868	Business	21400.00
0005433960253	6868	Business	21400.00
0005433960220	6868	Business	21400.00
0005433960227	6868	Business	21400.00
0005433960226	6868	Business	21400.00
0005433960212	6868	Business	21400.00
0005433960256	6868	Economy	7100.00
0005433960244	6868	Economy	7100.00
0005433960241	6868	Economy	7100.00
0005433960240	6868	Economy	7100.00
0005433960265	6868	Economy	7100.00
0005433960262	6868	Economy	7800.00
0005433960247	6868	Economy	7800.00
0005433960224	6868	Economy	7800.00
0005433960246	6868	Economy	7800.00
0005433960222	6868	Economy	7100.00
0005433960210	6868	Economy	7100.00
0005433960211	6868	Economy	7100.00
0005433960255	6868	Economy	7100.00
0005433960214	6868	Economy	7100.00
0005433960221	6868	Economy	7100.00
0005433960248	6868	Economy	7100.00
0005433960261	6868	Economy	7100.00
0005433960254	6868	Economy	7100.00
0005433960216	6868	Economy	7100.00
0005433960233	6868	Economy	7100.00
0005433960260	6868	Economy	7100.00
0005433960252	6868	Economy	7100.00
0005433960231	6868	Economy	7100.00
0005433960239	6868	Economy	7100.00
0005433960266	6868	Economy	7100.00
0005433960245	6868	Economy	7100.00
0005433960251	6868	Economy	7100.00
0005433960232	6868	Economy	7100.00
0005433960243	6868	Economy	7100.00
0005433960258	6868	Economy	7100.00
0005433960249	6868	Economy	7100.00
0005433960213	6868	Economy	7100.00
0005433960223	6868	Economy	7100.00
0005433960225	6868	Economy	7100.00
0005433960228	6868	Economy	7100.00
0005433960229	6868	Economy	7100.00
0005433960237	6868	Economy	7100.00
0005433960235	6868	Economy	7100.00
0005433960230	6868	Economy	7100.00
0005433960236	6868	Economy	7100.00
0005433960234	6868	Economy	7100.00
0005433960215	6868	Economy	7100.00
0005433960209	6868	Economy	7100.00
0005433960217	6868	Economy	7100.00
0005433960257	6868	Economy	7100.00
0005433960259	6868	Economy	7100.00
0005433960267	6868	Economy	7100.00
0005433960263	6868	Economy	7100.00
0005433960218	6868	Economy	7100.00
0005433960250	6868	Economy	7100.00
0005433960242	6868	Economy	7100.00
0005435082689	26127	Economy	3900.00
0005435082686	26127	Economy	3900.00
0005435082694	26127	Economy	3900.00
0005435082685	26127	Economy	3900.00
0005435082684	26127	Economy	3900.00
0005435082690	26127	Economy	3900.00
0005435082688	26127	Economy	3900.00
0005435082693	26127	Economy	3900.00
0005435082687	26127	Economy	3900.00
0005435082692	26127	Economy	3900.00
0005435082691	26127	Economy	3900.00
0005434244664	5180	Business	18000.00
0005432166863	5180	Business	18000.00
0005434244661	5180	Business	18000.00
0005434244640	5180	Business	18000.00
0005434244636	5180	Business	18000.00
0005434244637	5180	Business	18000.00
0005434244663	5180	Business	18000.00
0005434244642	5180	Economy	6600.00
0005434244650	5180	Economy	6000.00
0005432166864	5180	Economy	6000.00
0005434244653	5180	Economy	6000.00
0005434244649	5180	Economy	6000.00
0005434244647	5180	Economy	6000.00
0005434244659	5180	Economy	6000.00
0005434244655	5180	Economy	6000.00
0005434244645	5180	Economy	6000.00
0005434244654	5180	Economy	6000.00
0005434244646	5180	Economy	6000.00
0005434244635	5180	Economy	6000.00
0005434244660	5180	Economy	6600.00
0005434244638	5180	Economy	6000.00
0005434244639	5180	Economy	6600.00
0005434244652	5180	Economy	6000.00
0005432166866	5180	Economy	6000.00
0005434244651	5180	Economy	6000.00
0005434244634	5180	Economy	6000.00
0005434244643	5180	Economy	6000.00
0005434244657	5180	Economy	6000.00
0005432166865	5180	Economy	6000.00
0005434244656	5180	Economy	6000.00
0005434244644	5180	Economy	6000.00
0005434244648	5180	Economy	6000.00
0005434244641	5180	Economy	6000.00
0005434244662	5180	Economy	6000.00
0005434244658	5180	Economy	6000.00
0005433784521	5177	Business	18000.00
0005433613886	5177	Business	18000.00
0005433784550	5177	Business	18000.00
0005433613905	5177	Business	18000.00
0005433784525	5177	Business	18000.00
0005432105033	5177	Business	18000.00
0005432105008	5177	Business	18000.00
0005433784519	5177	Business	18000.00
0005433613901	5177	Business	18000.00
0005433613862	5177	Business	18000.00
0005432105042	5177	Business	18000.00
0005432105025	5177	Business	18000.00
0005432666365	5177	Business	18000.00
0005432105032	5177	Business	18000.00
0005432667429	5177	Business	18000.00
0005432105038	5177	Business	18000.00
0005433613852	5177	Business	18000.00
0005433784529	5177	Business	18000.00
0005433784534	5177	Business	18000.00
0005433613896	5177	Business	18000.00
0005433613900	5177	Business	18000.00
0005433784530	5177	Business	18000.00
0005432665250	5177	Business	18000.00
0005433613871	5177	Business	18000.00
0005432105012	5177	Business	18000.00
0005432105043	5177	Business	18000.00
0005433613840	5177	Business	18000.00
0005432667430	5177	Economy	6600.00
0005433613857	5177	Business	18000.00
0005433613856	5177	Economy	6600.00
0005433613908	5177	Economy	6600.00
0005432105029	5177	Economy	6600.00
0005433784537	5177	Economy	6600.00
0005433613839	5177	Economy	6600.00
0005432105017	5177	Economy	6000.00
0005433613872	5177	Economy	6000.00
0005433784526	5177	Economy	6000.00
0005433613867	5177	Economy	6000.00
0005433613864	5177	Economy	6000.00
0005432105027	5177	Economy	6000.00
0005433784518	5177	Economy	6000.00
0005433613838	5177	Economy	6000.00
0005432105047	5177	Economy	6000.00
0005433784522	5177	Economy	6000.00
0005433613846	5177	Economy	6000.00
0005433613850	5177	Economy	6000.00
0005433613882	5177	Economy	6000.00
0005432105036	5177	Economy	6000.00
0005433613859	5177	Economy	6000.00
0005433613892	5177	Economy	6000.00
0005432105024	5177	Economy	6000.00
0005432105050	5177	Economy	6000.00
0005433613874	5177	Economy	6000.00
0005433613844	5177	Economy	6000.00
0005433613836	5177	Economy	6000.00
0005433613903	5177	Economy	6000.00
0005433613877	5177	Economy	6000.00
0005432105035	5177	Economy	6000.00
0005432105019	5177	Economy	6000.00
0005433613894	5177	Economy	6000.00
0005433784538	5177	Economy	6000.00
0005433784546	5177	Economy	6000.00
0005433613909	5177	Economy	6000.00
0005432105010	5177	Economy	6000.00
0005433784539	5177	Economy	6000.00
0005433613873	5177	Economy	6000.00
0005432105023	5177	Economy	6000.00
0005433613880	5177	Economy	6000.00
0005432105006	5177	Economy	6000.00
0005432105040	5177	Economy	6000.00
0005433613837	5177	Economy	6000.00
0005433784531	5177	Economy	6000.00
0005433613855	5177	Economy	6000.00
0005433784549	5177	Economy	6000.00
0005432666364	5177	Economy	6000.00
0005432105011	5177	Economy	6000.00
0005432105030	5177	Economy	6000.00
0005433613841	5177	Economy	6000.00
0005433784551	5177	Economy	6000.00
0005433613890	5177	Economy	6000.00
0005433784523	5177	Economy	6000.00
0005432666363	5177	Economy	6000.00
0005432145089	5177	Economy	6000.00
0005433613851	5177	Economy	6000.00
0005432105016	5177	Economy	6000.00
0005433613904	5177	Economy	6000.00
0005432105020	5177	Economy	6000.00
0005432105026	5177	Economy	6000.00
0005433784540	5177	Economy	6000.00
0005433613875	5177	Economy	6000.00
0005433613854	5177	Economy	6000.00
0005433613888	5177	Economy	6000.00
0005433613868	5177	Economy	6000.00
0005432105045	5177	Economy	6000.00
0005432105007	5177	Economy	6600.00
0005433613870	5177	Economy	6600.00
0005432105039	5177	Economy	6600.00
0005433613893	5177	Economy	6600.00
0005433784536	5177	Economy	6600.00
0005433784543	5177	Economy	6000.00
0005432105031	5177	Economy	6000.00
0005433613878	5177	Economy	6000.00
0005432105013	5177	Economy	6000.00
0005432105037	5177	Economy	6600.00
0005433784535	5177	Economy	6000.00
0005432105022	5177	Economy	6000.00
0005433613899	5177	Economy	6000.00
0005432105034	5177	Economy	6000.00
0005433784532	5177	Economy	6000.00
0005433613863	5177	Economy	6000.00
0005433613884	5177	Economy	6000.00
0005433613881	5177	Economy	6000.00
0005433784547	5177	Economy	6000.00
0005433613902	5177	Economy	6000.00
0005432105044	5177	Economy	6000.00
0005432105015	5177	Economy	6000.00
0005433613858	5177	Economy	6000.00
0005433613898	5177	Economy	6000.00
0005432145088	5177	Economy	6000.00
0005433613848	5177	Economy	6000.00
0005432145090	5177	Economy	6000.00
0005432105014	5177	Economy	6000.00
0005432665251	5177	Economy	6000.00
0005433784544	5177	Economy	6000.00
0005432105048	5177	Economy	6000.00
0005433613887	5177	Economy	6000.00
0005432105018	5177	Economy	6000.00
0005433784541	5177	Economy	6000.00
0005433613897	5177	Economy	6000.00
0005433613895	5177	Economy	6000.00
0005432105049	5177	Economy	6000.00
0005432105052	5177	Economy	6000.00
0005433613861	5177	Economy	6000.00
0005433784552	5177	Economy	6000.00
0005433613889	5177	Economy	6000.00
0005433613853	5177	Economy	6000.00
0005433613883	5177	Economy	6000.00
0005433613879	5177	Economy	6000.00
0005432105041	5177	Economy	6000.00
0005433613865	5177	Economy	6000.00
0005433613906	5177	Economy	6000.00
0005433613843	5177	Economy	6000.00
0005433784527	5177	Economy	6000.00
0005433613885	5177	Economy	6000.00
0005433613869	5177	Economy	6000.00
0005433784520	5177	Economy	6000.00
0005433784545	5177	Economy	6000.00
0005433613907	5177	Economy	6000.00
0005432105046	5177	Economy	6000.00
0005433613845	5177	Economy	6000.00
0005432105053	5177	Economy	6000.00
0005432105005	5177	Economy	6000.00
0005433613860	5177	Economy	6000.00
0005433784542	5177	Economy	6000.00
0005433613866	5177	Economy	6000.00
0005432667431	5177	Economy	6000.00
0005432105028	5177	Economy	6000.00
0005433784528	5177	Economy	6000.00
0005432105021	5177	Economy	6000.00
0005433784524	5177	Economy	6000.00
0005433613835	5177	Economy	6000.00
0005433613842	5177	Economy	6000.00
0005433613849	5177	Economy	6000.00
0005433613891	5177	Economy	6000.00
0005432105009	5177	Economy	6000.00
0005433613847	5177	Economy	6000.00
0005433784533	5177	Economy	6000.00
0005433613876	5177	Economy	6000.00
0005433784548	5177	Economy	6000.00
0005432105051	5177	Economy	6000.00
0005434229120	5175	Business	18000.00
0005434264853	5175	Business	18000.00
0005434229118	5175	Business	18000.00
0005434229111	5175	Business	18000.00
0005434312286	5175	Business	18000.00
0005434264845	5175	Business	18000.00
0005434264858	5175	Business	18000.00
0005433815302	5175	Business	18000.00
0005434149596	5175	Business	18000.00
0005435006612	5175	Business	18000.00
0005434264854	5175	Business	18000.00
0005434149599	5175	Economy	6600.00
0005434264837	5175	Economy	6600.00
0005434229115	5175	Economy	6000.00
0005435006618	5175	Economy	6000.00
0005434229119	5175	Economy	6000.00
0005434264851	5175	Economy	6000.00
0005434264857	5175	Economy	6000.00
0005434312285	5175	Economy	6000.00
0005434264849	5175	Economy	6000.00
0005433815308	5175	Economy	6000.00
0005434229122	5175	Economy	6000.00
0005434149594	5175	Economy	6000.00
0005434264855	5175	Economy	6000.00
0005434264836	5175	Economy	6000.00
0005434229117	5175	Economy	6000.00
0005434264843	5175	Economy	6000.00
0005434149597	5175	Economy	6000.00
0005434229126	5175	Economy	6000.00
0005434229104	5175	Economy	6000.00
0005435006606	5175	Economy	6000.00
0005434149602	5175	Economy	6000.00
0005434264850	5175	Economy	6000.00
0005434264838	5175	Economy	6000.00
0005434229110	5175	Economy	6000.00
0005434229121	5175	Economy	6000.00
0005434264842	5175	Economy	6000.00
0005434229108	5175	Economy	6000.00
0005434229114	5175	Economy	6000.00
0005434264859	5175	Economy	6000.00
0005434173476	5175	Economy	6000.00
0005434229116	5175	Economy	6000.00
0005434229123	5175	Economy	6600.00
0005434149598	5175	Economy	6600.00
0005434149601	5175	Economy	6000.00
0005434264852	5175	Economy	6000.00
0005434264839	5175	Economy	6000.00
0005434229109	5175	Economy	6600.00
0005434229112	5175	Economy	6000.00
0005434149603	5175	Economy	6000.00
0005434173474	5175	Economy	6000.00
0005433815301	5175	Economy	6000.00
0005434149593	5175	Economy	6000.00
0005434173473	5175	Economy	6000.00
0005434149595	5175	Economy	6000.00
0005434264856	5175	Economy	6000.00
0005434264847	5175	Economy	6000.00
0005434229106	5175	Economy	6000.00
0005435006670	5175	Economy	6000.00
0005435006671	5175	Economy	6000.00
0005434264848	5175	Economy	6000.00
0005434264844	5175	Economy	6000.00
0005434264840	5175	Economy	6000.00
0005434229127	5175	Economy	6000.00
0005434229124	5175	Economy	6000.00
0005435006611	5175	Economy	6000.00
0005434264860	5175	Economy	6000.00
0005434264841	5175	Economy	6000.00
0005434229125	5175	Economy	6000.00
0005434229113	5175	Economy	6000.00
0005434173475	5175	Economy	6000.00
0005434229107	5175	Economy	6000.00
0005434264835	5175	Economy	6000.00
0005434149600	5175	Economy	6000.00
0005434264846	5175	Economy	6000.00
0005434229105	5175	Economy	6000.00
0005434173477	5175	Economy	6000.00
0005433784341	8457	Business	18000.00
0005434244556	8457	Economy	6600.00
0005433784331	8457	Economy	6000.00
0005434244488	8457	Economy	6000.00
0005434244453	8457	Economy	6000.00
0005434244454	8457	Economy	6000.00
0005433784304	8457	Economy	6000.00
0005433784413	8457	Economy	6000.00
0005433784326	8457	Economy	6000.00
0005434244489	8457	Economy	6000.00
0005433784332	8457	Economy	6600.00
0005433784378	8457	Economy	6000.00
0005433784306	8457	Economy	6000.00
0005433784305	8457	Economy	6000.00
0005434244481	8457	Economy	6000.00
0005433784303	8457	Economy	6000.00
0005433784379	8457	Economy	6000.00
0005433784366	8457	Economy	6000.00
0005433784330	8457	Economy	6000.00
0005433613439	8456	Business	18000.00
0005433613459	8456	Business	18000.00
0005433613424	8456	Economy	6000.00
0005433613520	8456	Economy	6000.00
0005433613398	8456	Economy	6000.00
0005433613490	8456	Economy	6000.00
0005433613397	8456	Economy	6000.00
0005433613452	8456	Economy	6000.00
0005433613451	8456	Economy	6000.00
0005432034620	8455	Business	18000.00
0005432335905	8455	Business	18000.00
0005433688786	8455	Business	18000.00
0005432047507	8455	Business	18000.00
0005434264707	8455	Business	18000.00
0005432034642	8455	Business	18000.00
0005433534473	8455	Business	18000.00
0005435006748	8455	Business	18000.00
0005435006762	8455	Business	18000.00
0005434149529	8455	Business	18000.00
0005432034638	8455	Business	18000.00
0005434311194	8455	Business	18000.00
0005435006755	8455	Business	18000.00
0005432034629	8455	Business	18000.00
0005433689888	8455	Economy	6600.00
0005434311195	8455	Economy	6600.00
0005432034630	8455	Economy	6000.00
0005435006754	8455	Economy	6000.00
0005435006761	8455	Economy	6000.00
0005432047508	8455	Economy	6000.00
0005432335902	8455	Economy	6000.00
0005435006756	8455	Economy	6000.00
0005435006752	8455	Economy	6000.00
0005433815334	8455	Economy	6000.00
0005433690904	8455	Economy	6000.00
0005432034646	8455	Economy	6000.00
0005433688785	8455	Economy	6000.00
0005433534474	8455	Economy	6000.00
0005435006747	8455	Economy	6000.00
0005434264682	8455	Economy	6000.00
0005432034641	8455	Economy	6000.00
0005432034636	8455	Economy	6000.00
0005432034637	8455	Economy	6000.00
0005432034633	8455	Economy	6000.00
0005432034635	8455	Economy	6000.00
0005434264718	8455	Economy	6000.00
0005432034627	8455	Economy	6000.00
0005435006753	8455	Economy	6000.00
0005432034628	8455	Economy	6000.00
0005432034624	8455	Economy	6000.00
0005435006746	8455	Economy	6000.00
0005432034625	8455	Economy	6000.00
0005432335900	8455	Economy	6000.00
0005432034645	8455	Economy	6000.00
0005434228992	8455	Economy	6000.00
0005435006749	8455	Economy	6000.00
0005435006751	8455	Economy	6000.00
0005433815335	8455	Economy	6000.00
0005432034639	8455	Economy	6000.00
0005432335898	8455	Economy	6600.00
0005432034632	8455	Economy	6600.00
0005432335895	8455	Economy	6600.00
0005432034622	8455	Economy	6600.00
0005434264706	8455	Economy	6000.00
0005432335896	8455	Economy	6000.00
0005433815330	8455	Economy	6000.00
0005435006765	8455	Economy	6000.00
0005435006757	8455	Economy	6000.00
0005434264675	8455	Economy	6000.00
0005432047506	8455	Economy	6000.00
0005432335906	8455	Economy	6000.00
0005435006758	8455	Economy	6000.00
0005432034643	8455	Economy	6000.00
0005433689887	8455	Economy	6000.00
0005432335897	8455	Economy	6000.00
0005432047509	8455	Economy	6000.00
0005432034623	8455	Economy	6000.00
0005432034626	8455	Economy	6000.00
0005433815331	8455	Economy	6000.00
0005432034621	8455	Economy	6000.00
0005433815332	8455	Economy	6000.00
0005432335901	8455	Economy	6000.00
0005432335903	8455	Economy	6000.00
0005433690903	8455	Economy	6000.00
0005432034647	8455	Economy	6000.00
0005435006760	8455	Economy	6000.00
0005435006750	8455	Economy	6000.00
0005434264695	8455	Economy	6000.00
0005432034640	8455	Economy	6000.00
0005432335904	8455	Economy	6000.00
0005435006763	8455	Economy	6000.00
0005432335899	8455	Economy	6000.00
0005435006764	8455	Economy	6000.00
0005432034644	8455	Economy	6000.00
0005434229016	8455	Economy	6000.00
0005432034648	8455	Economy	6000.00
0005435006759	8455	Economy	6000.00
0005434311196	8455	Economy	6000.00
0005432034634	8455	Economy	6000.00
0005434229074	8455	Economy	6000.00
0005432034631	8455	Economy	6000.00
0005433815333	8455	Economy	6000.00
0005433202201	12584	Economy	16200.00
0005434638927	12584	Economy	16200.00
0005433202194	12584	Economy	14800.00
0005434638871	12584	Economy	14800.00
0005433202202	12584	Economy	14800.00
0005433202205	12584	Economy	14800.00
0005433202195	12584	Economy	14800.00
0005433202198	12584	Economy	14800.00
0005433202206	12584	Economy	14800.00
0005433202207	12584	Economy	14800.00
0005433202199	12584	Economy	14800.00
0005434638862	12584	Economy	14800.00
0005433202193	12584	Economy	14800.00
0005434638870	12584	Economy	14800.00
0005433202203	12584	Economy	14800.00
0005433202204	12584	Economy	14800.00
0005433202197	12584	Economy	14800.00
0005433202192	12584	Economy	14800.00
0005433202200	12584	Economy	14800.00
0005433202196	12584	Economy	14800.00
0005434638993	23362	Economy	16200.00
0005434639007	23362	Economy	16200.00
0005434638995	23362	Economy	16200.00
0005434638996	23362	Economy	14800.00
0005434639010	23362	Economy	14800.00
0005432290595	23362	Economy	14800.00
0005434638997	23362	Economy	14800.00
0005434639006	23362	Economy	14800.00
0005434638989	23362	Economy	14800.00
0005434638992	23362	Economy	14800.00
0005434639011	23362	Economy	14800.00
0005434638987	23362	Economy	14800.00
0005434639012	23362	Economy	14800.00
0005434638986	23362	Economy	14800.00
0005434639002	23362	Economy	14800.00
0005434639004	23362	Economy	14800.00
0005432290597	23362	Economy	14800.00
0005434639003	23362	Economy	14800.00
0005434638985	23362	Economy	14800.00
0005434638990	23362	Economy	14800.00
0005434639000	23362	Economy	14800.00
0005434638988	23362	Economy	14800.00
0005434638998	23362	Economy	14800.00
0005434639005	23362	Economy	14800.00
0005432290594	23362	Economy	14800.00
0005434638999	23362	Economy	14800.00
0005434639009	23362	Economy	14800.00
0005434638991	23362	Economy	14800.00
0005434638994	23362	Economy	14800.00
0005434639008	23362	Economy	14800.00
0005432290596	23362	Economy	14800.00
0005434639001	23362	Economy	14800.00
0005432054272	21061	Business	18900.00
0005432054271	21061	Economy	6300.00
0005432054270	21061	Economy	6300.00
0005432327989	21061	Economy	6300.00
0005432327945	21061	Economy	6300.00
0005432382704	31253	Business	18900.00
0005432328137	31253	Business	18900.00
0005432328160	31253	Business	18900.00
0005432328155	31253	Business	18900.00
0005432382700	31253	Business	18900.00
0005432287128	31253	Business	18900.00
0005432382718	31253	Business	18900.00
0005432328150	31253	Business	18900.00
0005432328128	31253	Business	18900.00
0005432382705	31253	Business	18900.00
0005432328167	31253	Business	18900.00
0005432328144	31253	Economy	6300.00
0005432328139	31253	Economy	6300.00
0005432328145	31253	Economy	6300.00
0005432328157	31253	Economy	6300.00
0005432382706	31253	Economy	6300.00
0005432382722	31253	Economy	6300.00
0005432328134	31253	Economy	6300.00
0005432328148	31253	Economy	6300.00
0005432328151	31253	Economy	6300.00
0005432382691	31253	Economy	6300.00
0005432287126	31253	Economy	6900.00
0005432328130	31253	Economy	6900.00
0005432382707	31253	Economy	6900.00
0005432382725	31253	Economy	6900.00
0005432382726	31253	Economy	6900.00
0005432382708	31253	Economy	6300.00
0005432328172	31253	Economy	6300.00
0005432382720	31253	Economy	6300.00
0005432382697	31253	Economy	6300.00
0005432328126	31253	Economy	6300.00
0005432328154	31253	Economy	6300.00
0005432382694	31253	Economy	6300.00
0005432382692	31253	Economy	6300.00
0005432382714	31253	Economy	6300.00
0005432382713	31253	Economy	6300.00
0005432328129	31253	Economy	6300.00
0005432328141	31253	Economy	6300.00
0005432328161	31253	Economy	6300.00
0005432328163	31253	Economy	6300.00
0005432382716	31253	Economy	6300.00
0005432382724	31253	Economy	6300.00
0005432382721	31253	Economy	6300.00
0005432287131	31253	Economy	6300.00
0005432328168	31253	Economy	6300.00
0005432382719	31253	Economy	6300.00
0005432328170	31253	Economy	6300.00
0005432328135	31253	Economy	6300.00
0005432328171	31253	Economy	6300.00
0005432287129	31253	Economy	6300.00
0005432328162	31253	Economy	6300.00
0005432382695	31253	Economy	6300.00
0005432328159	31253	Economy	6300.00
0005432328165	31253	Economy	6300.00
0005432382698	31253	Economy	6300.00
0005432328133	31253	Economy	6300.00
0005432328158	31253	Economy	6300.00
0005432328146	31253	Economy	6300.00
0005432328136	31253	Economy	6300.00
0005432382696	31253	Economy	6300.00
0005432287127	31253	Economy	6300.00
0005432328164	31253	Economy	6300.00
0005432382702	31253	Economy	6300.00
0005432328138	31253	Economy	6300.00
0005432382711	31253	Economy	6300.00
0005432382701	31253	Economy	6300.00
0005432382723	31253	Economy	6300.00
0005432328166	31253	Economy	6300.00
0005432382715	31253	Economy	6300.00
0005432382699	31253	Economy	6300.00
0005432382709	31253	Economy	6300.00
0005432328156	31253	Economy	6300.00
0005432328169	31253	Economy	6300.00
0005432328142	31253	Economy	6300.00
0005432328140	31253	Economy	6300.00
0005432328152	31253	Economy	6300.00
0005432287130	31253	Economy	6300.00
0005432328153	31253	Economy	6300.00
0005432328132	31253	Economy	6300.00
0005432328127	31253	Economy	6300.00
0005432382703	31253	Economy	6300.00
0005432328143	31253	Economy	6300.00
0005432382693	31253	Economy	6300.00
0005432382717	31253	Economy	6300.00
0005432328131	31253	Economy	6300.00
0005432328125	31253	Economy	6300.00
0005432382710	31253	Economy	6300.00
0005432382712	31253	Economy	6300.00
0005432328149	31253	Economy	6300.00
0005432287125	31253	Economy	6300.00
0005432328147	31253	Economy	6300.00
0005433642106	27597	Business	89600.00
0005432953840	27597	Business	89600.00
0005432953843	27597	Business	89600.00
0005433642080	27597	Economy	29900.00
0005432953842	27597	Economy	32800.00
0005432953830	27597	Economy	29900.00
0005432953831	27597	Economy	29900.00
0005432953837	27597	Economy	29900.00
0005432953838	27597	Economy	29900.00
0005433642094	27597	Economy	29900.00
0005432953833	27597	Economy	29900.00
0005432953841	27597	Economy	29900.00
0005432953835	27597	Economy	29900.00
0005433642092	27597	Economy	29900.00
0005432953832	27597	Economy	29900.00
0005432953834	27597	Economy	29900.00
0005433642102	27597	Economy	29900.00
0005433642087	27597	Economy	29900.00
0005432953845	27597	Economy	29900.00
0005432953844	27597	Economy	29900.00
0005432953836	27597	Economy	29900.00
0005432953839	27597	Economy	29900.00
0005432423877	13320	Business	12700.00
0005432423884	13320	Business	12700.00
0005432423909	13320	Business	12700.00
0005432423900	13320	Business	12700.00
0005432423861	13320	Business	12700.00
0005432423865	13320	Business	12700.00
0005432423898	13320	Business	12700.00
0005432423901	13320	Business	12700.00
0005432423888	13320	Economy	4200.00
0005432423894	13320	Economy	4200.00
0005432423876	13320	Economy	4200.00
0005432423893	13320	Economy	4200.00
0005432423895	13320	Economy	4200.00
0005432423863	13320	Economy	4200.00
0005432423862	13320	Economy	4200.00
0005432423899	13320	Economy	4200.00
0005432423864	13320	Economy	4200.00
0005432423870	13320	Economy	4200.00
0005432423892	13320	Economy	4200.00
0005432423905	13320	Economy	4200.00
0005432423897	13320	Economy	4200.00
0005432423868	13320	Economy	4200.00
0005432423886	13320	Economy	4200.00
0005432423867	13320	Economy	4200.00
0005432423879	13320	Economy	4200.00
0005432423903	13320	Economy	4200.00
0005432423904	13320	Economy	4200.00
0005432423891	13320	Economy	4200.00
0005432423902	13320	Economy	4200.00
0005432423907	13320	Economy	4200.00
0005432423871	13320	Economy	4200.00
0005432423875	13320	Economy	4200.00
0005432423880	13320	Economy	4200.00
0005432423882	13320	Economy	4200.00
0005432423908	13320	Economy	4200.00
0005432423890	13320	Economy	4200.00
0005432423881	13320	Economy	4200.00
0005432423889	13320	Economy	4200.00
0005432423874	13320	Economy	4200.00
0005432423860	13320	Economy	4200.00
0005432423883	13320	Economy	4200.00
0005432423896	13320	Economy	4200.00
0005432423885	13320	Economy	4200.00
0005432423887	13320	Economy	4200.00
0005432423878	13320	Economy	4200.00
0005432423866	13320	Economy	4200.00
0005432423872	13320	Economy	4200.00
0005432423906	13320	Economy	4200.00
0005432423873	13320	Economy	4200.00
0005432423869	13320	Economy	4200.00
0005432822117	9601	Business	32600.00
0005432817137	9601	Business	32600.00
0005432901312	9601	Business	32600.00
0005432817128	9601	Business	32600.00
0005432817136	9601	Business	32600.00
0005432817122	9601	Business	32600.00
0005432817124	9601	Business	32600.00
0005434157360	9601	Economy	10900.00
0005432817121	9601	Economy	10900.00
0005432901335	9601	Economy	10900.00
0005432822118	9601	Economy	10900.00
0005434448277	9601	Economy	10900.00
0005432817127	9601	Economy	10900.00
0005432817134	9601	Economy	11900.00
0005432822114	9601	Economy	11900.00
0005434448275	9601	Economy	10900.00
0005432817142	9601	Economy	10900.00
0005432817148	9601	Economy	10900.00
0005432817129	9601	Economy	10900.00
0005432817132	9601	Economy	10900.00
0005432288947	9601	Economy	10900.00
0005432817145	9601	Economy	10900.00
0005432817126	9601	Economy	10900.00
0005432817144	9601	Economy	10900.00
0005432901300	9601	Economy	10900.00
0005432817139	9601	Economy	10900.00
0005432817138	9601	Economy	10900.00
0005432817125	9601	Economy	10900.00
0005432817133	9601	Economy	10900.00
0005434157341	9601	Economy	10900.00
0005432822113	9601	Economy	10900.00
0005432817123	9601	Economy	10900.00
0005432822115	9601	Economy	10900.00
0005432288950	9601	Economy	10900.00
0005432817131	9601	Economy	10900.00
0005432817149	9601	Economy	10900.00
0005432288948	9601	Economy	10900.00
0005432817135	9601	Economy	10900.00
0005432817143	9601	Economy	10900.00
0005432817140	9601	Economy	10900.00
0005432817120	9601	Economy	10900.00
0005432817130	9601	Economy	10900.00
0005432817147	9601	Economy	10900.00
0005432817119	9601	Economy	10900.00
0005434157342	9601	Economy	10900.00
0005434448276	9601	Economy	10900.00
0005432817146	9601	Economy	10900.00
0005432817141	9601	Economy	10900.00
0005432288949	9601	Economy	10900.00
0005432822116	9601	Economy	10900.00
0005432901416	28984	Business	32600.00
0005432901402	28984	Business	32600.00
0005432901412	28984	Economy	10900.00
0005432901411	28984	Economy	10900.00
0005434157387	28984	Economy	11900.00
0005434186163	28984	Economy	11900.00
0005432002054	28984	Economy	11900.00
0005432901415	28984	Economy	10900.00
0005432901409	28984	Economy	10900.00
0005434157392	28984	Economy	10900.00
0005432901418	28984	Economy	10900.00
0005434448260	28984	Economy	10900.00
0005432002052	28984	Economy	10900.00
0005432901417	28984	Economy	10900.00
0005432901408	28984	Economy	10900.00
0005434157388	28984	Economy	10900.00
0005432901404	28984	Economy	10900.00
0005432901413	28984	Economy	10900.00
0005434157394	28984	Economy	10900.00
0005432901405	28984	Economy	10900.00
0005432822071	28984	Economy	10900.00
0005432901406	28984	Economy	10900.00
0005432901407	28984	Economy	10900.00
0005434157391	28984	Economy	10900.00
0005434157393	28984	Economy	10900.00
0005434448259	28984	Economy	10900.00
0005432901410	28984	Economy	10900.00
0005432816963	28984	Economy	10900.00
0005434186164	28984	Economy	10900.00
0005432822072	28984	Economy	10900.00
0005434157389	28984	Economy	10900.00
0005434157390	28984	Economy	10900.00
0005432002053	28984	Economy	10900.00
0005432901403	28984	Economy	10900.00
0005432901414	28984	Economy	10900.00
0005432613816	15131	Economy	11000.00
0005432611664	15131	Economy	11000.00
0005432611667	15131	Economy	11000.00
0005432613817	15131	Economy	11000.00
0005432611665	15131	Economy	11000.00
0005432611666	15131	Economy	11000.00
0005432611663	15131	Economy	11000.00
0005432613814	15131	Economy	11000.00
0005432613815	15131	Economy	11000.00
0005432613818	15131	Economy	11000.00
0005432613813	15131	Economy	11000.00
0005435842320	31583	Economy	11000.00
0005435842322	31583	Economy	11000.00
0005435841813	31583	Economy	11000.00
0005435842321	31583	Economy	11000.00
0005435842319	31583	Economy	11000.00
0005432611653	31583	Economy	11000.00
0005433568340	11836	Business	105900.00
0005433568350	11836	Business	105900.00
0005433568344	11836	Business	105900.00
0005433568369	11836	Business	105900.00
0005433568371	11836	Business	105900.00
0005433568373	11836	Business	105900.00
0005433568354	11836	Business	105900.00
0005433568326	11836	Economy	35300.00
0005433568313	11836	Economy	35300.00
0005433568367	11836	Economy	35300.00
0005433568314	11836	Economy	35300.00
0005432947787	11836	Economy	35300.00
0005433568333	11836	Economy	35300.00
0005433568322	11836	Economy	35300.00
0005433568352	11836	Economy	35300.00
0005433568343	11836	Economy	35300.00
0005433568332	11836	Economy	35300.00
0005433568320	11836	Economy	38800.00
0005433568334	11836	Economy	38800.00
0005433568342	11836	Economy	38800.00
0005433568338	11836	Economy	35300.00
0005433568311	11836	Economy	35300.00
0005433568310	11836	Economy	35300.00
0005433568328	11836	Economy	35300.00
0005433568308	11836	Economy	35300.00
0005433568351	11836	Economy	35300.00
0005433568365	11836	Economy	35300.00
0005433568327	11836	Economy	35300.00
0005433568345	11836	Economy	35300.00
0005433568336	11836	Economy	35300.00
0005433568335	11836	Economy	35300.00
0005433568323	11836	Economy	35300.00
0005433568370	11836	Economy	35300.00
0005433568356	11836	Economy	35300.00
0005433568372	11836	Economy	35300.00
0005433568331	11836	Economy	35300.00
0005433568360	11836	Economy	35300.00
0005433568348	11836	Economy	35300.00
0005433568357	11836	Economy	35300.00
0005432947772	11836	Economy	35300.00
0005433568321	11836	Economy	35300.00
0005433568366	11836	Economy	35300.00
0005433568316	11836	Economy	35300.00
0005433568359	11836	Economy	35300.00
0005433568346	11836	Economy	35300.00
0005433568363	11836	Economy	35300.00
0005433568358	11836	Economy	35300.00
0005433568324	11836	Economy	35300.00
0005433568355	11836	Economy	35300.00
0005433568337	11836	Economy	35300.00
0005433568361	11836	Economy	35300.00
0005433568353	11836	Economy	35300.00
0005433568364	11836	Economy	35300.00
0005433568362	11836	Economy	35300.00
0005433568349	11836	Economy	35300.00
0005433568368	11836	Economy	35300.00
0005433568317	11836	Economy	35300.00
0005433568347	11836	Economy	35300.00
0005433568329	11836	Economy	35300.00
0005433568315	11836	Economy	35300.00
0005433568312	11836	Economy	35300.00
0005433568341	11836	Economy	35300.00
0005432947786	11836	Economy	35300.00
0005433568309	11836	Economy	35300.00
0005433568330	11836	Economy	35300.00
0005433568318	11836	Economy	35300.00
0005433568319	11836	Economy	35300.00
0005433568325	11836	Economy	35300.00
0005433568339	11836	Economy	35300.00
0005432948017	25285	Business	105900.00
0005432948030	25285	Business	105900.00
0005432948040	25285	Business	105900.00
0005432948026	25285	Business	105900.00
0005432948049	25285	Business	105900.00
0005432948031	25285	Business	105900.00
0005432948052	25285	Economy	35300.00
0005432948046	25285	Economy	35300.00
0005432948025	25285	Economy	35300.00
0005432948039	25285	Economy	35300.00
0005432948050	25285	Economy	38800.00
0005432948036	25285	Economy	35300.00
0005432948044	25285	Economy	35300.00
0005432948053	25285	Economy	35300.00
0005432948043	25285	Economy	35300.00
0005432948019	25285	Economy	35300.00
0005432948021	25285	Economy	35300.00
0005432948020	25285	Economy	35300.00
0005432948013	25285	Economy	35300.00
0005432948048	25285	Economy	35300.00
0005432948015	25285	Economy	35300.00
0005432948038	25285	Economy	35300.00
0005432948041	25285	Economy	35300.00
0005432948047	25285	Economy	35300.00
0005432948018	25285	Economy	35300.00
0005432948042	25285	Economy	35300.00
0005432948054	25285	Economy	35300.00
0005432948016	25285	Economy	35300.00
0005432948014	25285	Economy	35300.00
0005432948034	25285	Economy	35300.00
0005432948028	25285	Economy	35300.00
0005432948037	25285	Economy	35300.00
0005432948033	25285	Economy	35300.00
0005432948027	25285	Economy	35300.00
0005432948051	25285	Economy	35300.00
0005432948045	25285	Economy	35300.00
0005432948035	25285	Economy	35300.00
0005432948023	25285	Economy	35300.00
0005432948032	25285	Economy	35300.00
0005432948029	25285	Economy	35300.00
0005432948024	25285	Economy	35300.00
0005432948022	25285	Economy	35300.00
0005434654341	5388	Business	67200.00
0005434656533	5388	Business	67200.00
0005434654349	5388	Business	67200.00
0005434654358	5388	Business	67200.00
0005434654368	5388	Economy	22400.00
0005434654350	5388	Economy	22400.00
0005434654352	5388	Economy	22400.00
0005434654353	5388	Economy	22400.00
0005432114166	5388	Economy	24600.00
0005434654351	5388	Economy	24600.00
0005434654357	5388	Economy	22400.00
0005432114165	5388	Economy	22400.00
0005434654347	5388	Economy	22400.00
0005434654361	5388	Economy	22400.00
0005434654344	5388	Economy	22400.00
0005434654360	5388	Economy	22400.00
0005434654367	5388	Economy	22400.00
0005434654346	5388	Economy	22400.00
0005434654362	5388	Economy	22400.00
0005434654339	5388	Economy	22400.00
0005434654343	5388	Economy	22400.00
0005434654365	5388	Economy	22400.00
0005434654366	5388	Economy	22400.00
0005432114167	5388	Economy	22400.00
0005434654342	5388	Economy	22400.00
0005434654356	5388	Economy	22400.00
0005434654359	5388	Economy	22400.00
0005434654348	5388	Economy	22400.00
0005434656532	5388	Economy	22400.00
0005434654363	5388	Economy	22400.00
0005434654354	5388	Economy	22400.00
0005434654345	5388	Economy	22400.00
0005434654340	5388	Economy	22400.00
0005434654364	5388	Economy	22400.00
0005434654355	5388	Economy	22400.00
0005435340091	12504	Business	67200.00
0005434654184	12504	Business	67200.00
0005434654237	12504	Business	67200.00
0005435340094	12504	Business	67200.00
0005434654205	12504	Business	67200.00
0005435340096	12504	Economy	22400.00
0005435340083	12504	Economy	22400.00
0005434654183	12504	Economy	22400.00
0005434654244	12504	Economy	22400.00
0005435340092	12504	Economy	24600.00
0005435340082	12504	Economy	22400.00
0005434654243	12504	Economy	22400.00
0005435340086	12504	Economy	22400.00
0005435340088	12504	Economy	22400.00
0005435340085	12504	Economy	22400.00
0005434654204	12504	Economy	22400.00
0005434654245	12504	Economy	22400.00
0005435340084	12504	Economy	22400.00
0005434654206	12504	Economy	22400.00
0005435340095	12504	Economy	22400.00
0005434654246	12504	Economy	22400.00
0005435340090	12504	Economy	22400.00
0005434654236	12504	Economy	22400.00
0005435340093	12504	Economy	22400.00
0005435340087	12504	Economy	22400.00
0005435340089	12504	Economy	22400.00
0005434654188	12504	Economy	22400.00
0005433656632	7464	Business	32000.00
0005432078045	7464	Business	32000.00
0005433715397	7464	Business	32000.00
0005433722135	7464	Business	32000.00
0005433722132	7464	Business	32000.00
0005433656631	7464	Business	32000.00
0005433690900	7464	Business	32000.00
0005433715412	7464	Economy	10700.00
0005432078046	7464	Economy	10700.00
0005433715389	7464	Economy	10700.00
0005433715380	7464	Economy	10700.00
0005433715422	7464	Economy	10700.00
0005433715407	7464	Economy	10700.00
0005433715413	7464	Economy	10700.00
0005433715411	7464	Economy	10700.00
0005433715391	7464	Economy	10700.00
0005433722134	7464	Economy	10700.00
0005433715409	7464	Economy	10700.00
0005433715416	7464	Economy	10700.00
0005433715418	7464	Economy	10700.00
0005433715415	7464	Economy	10700.00
0005433722140	7464	Economy	10700.00
0005433715398	7464	Economy	10700.00
0005433715382	7464	Economy	10700.00
0005433715404	7464	Economy	10700.00
0005433715381	7464	Economy	10700.00
0005433690902	7464	Economy	10700.00
0005433715393	7464	Economy	10700.00
0005433656629	7464	Economy	10700.00
0005433715392	7464	Economy	10700.00
0005433715420	7464	Economy	11700.00
0005433722136	7464	Economy	11700.00
0005433715421	7464	Economy	11700.00
0005432078042	7464	Economy	10700.00
0005433690901	7464	Economy	10700.00
0005433719098	7464	Economy	10700.00
0005433715376	7464	Economy	10700.00
0005433715388	7464	Economy	10700.00
0005433715417	7464	Economy	10700.00
0005433656630	7464	Economy	10700.00
0005433722133	7464	Economy	10700.00
0005433722139	7464	Economy	10700.00
0005433689886	7464	Economy	10700.00
0005433715414	7464	Economy	10700.00
0005433715395	7464	Economy	10700.00
0005432078047	7464	Economy	10700.00
0005433715400	7464	Economy	10700.00
0005433715408	7464	Economy	10700.00
0005433722138	7464	Economy	10700.00
0005433715402	7464	Economy	10700.00
0005433688784	7464	Economy	10700.00
0005433715387	7464	Economy	10700.00
0005433715374	7464	Economy	10700.00
0005433715384	7464	Economy	10700.00
0005433719100	7464	Economy	10700.00
0005433715399	7464	Economy	10700.00
0005433715405	7464	Economy	10700.00
0005433715396	7464	Economy	10700.00
0005433715386	7464	Economy	10700.00
0005432078044	7464	Economy	10700.00
0005433715375	7464	Economy	10700.00
0005433715419	7464	Economy	10700.00
0005433715379	7464	Economy	10700.00
0005433715377	7464	Economy	10700.00
0005433715385	7464	Economy	10700.00
0005433715401	7464	Economy	10700.00
0005433656628	7464	Economy	10700.00
0005433715383	7464	Economy	10700.00
0005433715378	7464	Economy	10700.00
0005433715394	7464	Economy	10700.00
0005433689885	7464	Economy	10700.00
0005433715373	7464	Economy	10700.00
0005433715403	7464	Economy	10700.00
0005433715410	7464	Economy	10700.00
0005433715406	7464	Economy	10700.00
0005433722137	7464	Economy	10700.00
0005433715423	7464	Economy	10700.00
0005433715390	7464	Economy	10700.00
0005432078043	7464	Economy	10700.00
0005433719099	7464	Economy	10700.00
0005432006726	29246	Business	32000.00
0005435266092	29246	Business	32000.00
0005435266100	29246	Economy	10700.00
0005432428891	29246	Economy	10700.00
0005433715132	29246	Economy	10700.00
0005432006728	29246	Economy	10700.00
0005435266095	29246	Economy	10700.00
0005435266099	29246	Economy	10700.00
0005432006727	29246	Economy	10700.00
0005433715242	29246	Economy	10700.00
0005433715147	29246	Economy	10700.00
0005432428890	29246	Economy	11700.00
0005433715148	29246	Economy	10700.00
0005433715191	29246	Economy	10700.00
0005435266093	29246	Economy	10700.00
0005435266101	29246	Economy	10700.00
0005432428889	29246	Economy	10700.00
0005433715149	29246	Economy	10700.00
0005435266102	29246	Economy	10700.00
0005435266097	29246	Economy	10700.00
0005433715192	29246	Economy	10700.00
0005435266096	29246	Economy	10700.00
0005433715193	29246	Economy	10700.00
0005433715112	29246	Economy	10700.00
0005435266098	29246	Economy	10700.00
0005435266094	29246	Economy	10700.00
0005432428888	29246	Economy	10700.00
0005434181976	8688	Business	36500.00
0005434182005	8688	Economy	12200.00
0005434181960	8688	Economy	12200.00
0005434095110	8688	Economy	13400.00
0005434095113	8688	Economy	12200.00
0005434095116	8688	Economy	12200.00
0005434095105	8688	Economy	12200.00
0005434095106	8688	Economy	12200.00
0005434095107	8688	Economy	12200.00
0005434095109	8688	Economy	12200.00
0005434095115	8688	Economy	12200.00
0005434095112	8688	Economy	12200.00
0005434181968	8688	Economy	12200.00
0005434095118	8688	Economy	12200.00
0005434181967	8688	Economy	12200.00
0005434181957	8688	Economy	12200.00
0005434095104	8688	Economy	12200.00
0005434095117	8688	Economy	12200.00
0005434095114	8688	Economy	12200.00
0005434181961	8688	Economy	12200.00
0005434095111	8688	Economy	12200.00
0005434095108	8688	Economy	12200.00
0005434095035	11660	Business	36500.00
0005434183555	11660	Business	36500.00
0005434095018	11660	Business	36500.00
0005434095036	11660	Economy	12200.00
0005434182038	11660	Economy	13400.00
0005434182036	11660	Economy	13400.00
0005434182040	11660	Economy	12200.00
0005434182037	11660	Economy	12200.00
0005434182046	11660	Economy	12200.00
0005434184640	11660	Economy	12200.00
0005434182043	11660	Economy	12200.00
0005434182042	11660	Economy	12200.00
0005434182041	11660	Economy	12200.00
0005434095017	11660	Economy	12200.00
0005434182039	11660	Economy	12200.00
0005434182045	11660	Economy	12200.00
0005434182044	11660	Economy	12200.00
0005434095039	11660	Economy	12200.00
0005434182035	11660	Economy	12200.00
0005435732192	1454	Business	33000.00
0005433397308	1454	Business	33000.00
0005433456921	1454	Economy	11000.00
0005433397376	1454	Economy	11000.00
0005435732183	1454	Economy	11000.00
0005432297246	1454	Economy	11000.00
0005433397293	1454	Economy	12100.00
0005432297248	1454	Economy	12100.00
0005432297249	1454	Economy	12100.00
0005435732191	1454	Economy	12100.00
0005432297247	1454	Economy	12100.00
0005433397377	1454	Economy	11000.00
0005435732184	1454	Economy	11000.00
0005435732185	1454	Economy	11000.00
0005432297250	1454	Economy	11000.00
0005433456922	1454	Economy	11000.00
0005433397327	1454	Economy	11000.00
0005435732190	1454	Economy	11000.00
0005435732187	1454	Economy	11000.00
0005435732186	1454	Economy	11000.00
0005435732181	1454	Economy	11000.00
0005433397206	1454	Economy	11000.00
0005435732189	1454	Economy	11000.00
0005435732193	1454	Economy	11000.00
0005433456923	1454	Economy	11000.00
0005435732182	1454	Economy	11000.00
0005433397205	1454	Economy	11000.00
0005435732188	1454	Economy	11000.00
0005433397234	1454	Economy	11000.00
0005433397378	1454	Economy	11000.00
0005433456924	1454	Economy	11000.00
0005435732180	1454	Economy	11000.00
0005433456925	1454	Economy	11000.00
0005433397502	19283	Business	33000.00
0005433397507	19283	Business	33000.00
0005433397524	19283	Business	33000.00
0005432906508	19283	Business	33000.00
0005433397521	19283	Business	33000.00
0005433397508	19283	Business	33000.00
0005433397511	19283	Business	33000.00
0005433397490	19283	Business	33000.00
0005433397492	19283	Business	33000.00
0005433397498	19283	Business	33000.00
0005433397516	19283	Business	33000.00
0005433397512	19283	Economy	11000.00
0005433397525	19283	Economy	11000.00
0005433397500	19283	Economy	11000.00
0005433397519	19283	Economy	12100.00
0005433397481	19283	Economy	12100.00
0005433397513	19283	Economy	12100.00
0005433397522	19283	Economy	11000.00
0005433397501	19283	Economy	11000.00
0005433397515	19283	Economy	11000.00
0005433397510	19283	Economy	11000.00
0005433397485	19283	Economy	11000.00
0005433397478	19283	Economy	11000.00
0005433397482	19283	Economy	11000.00
0005433397479	19283	Economy	11000.00
0005433397493	19283	Economy	11000.00
0005433397491	19283	Economy	11000.00
0005433397489	19283	Economy	11000.00
0005433397496	19283	Economy	11000.00
0005433397504	19283	Economy	11000.00
0005433397494	19283	Economy	11000.00
0005433397517	19283	Economy	11000.00
0005433397484	19283	Economy	11000.00
0005433397518	19283	Economy	11000.00
0005433397486	19283	Economy	11000.00
0005433397497	19283	Economy	11000.00
0005433397499	19283	Economy	11000.00
0005433397505	19283	Economy	11000.00
0005433397523	19283	Economy	11000.00
0005433397477	19283	Economy	11000.00
0005432906507	19283	Economy	11000.00
0005433397480	19283	Economy	11000.00
0005433397483	19283	Economy	11000.00
0005433397503	19283	Economy	11000.00
0005433397520	19283	Economy	11000.00
0005435732136	19283	Economy	11000.00
0005433397488	19283	Economy	11000.00
0005433397514	19283	Economy	11000.00
0005433397506	19283	Economy	11000.00
0005433397487	19283	Economy	11000.00
0005433397495	19283	Economy	11000.00
0005433397509	19283	Economy	11000.00
0005434443509	20563	Economy	15600.00
0005434443514	20563	Economy	15600.00
0005434443507	20563	Economy	15600.00
0005434443519	20563	Economy	15600.00
0005434443508	20563	Economy	14100.00
0005434443520	20563	Economy	14100.00
0005434443518	20563	Economy	14100.00
0005434443511	20563	Economy	14100.00
0005434443517	20563	Economy	14100.00
0005434443512	20563	Economy	14100.00
0005434443516	20563	Economy	14100.00
0005434443521	20563	Economy	14100.00
0005434443513	20563	Economy	14100.00
0005434443515	20563	Economy	14100.00
0005434443510	20563	Economy	14100.00
0005434954563	7272	Economy	5800.00
0005434954564	7272	Economy	5800.00
0005434954562	7272	Economy	5800.00
0005434954565	7272	Economy	5800.00
0005434954543	28330	Economy	5800.00
0005435377552	28330	Economy	5800.00
0005435377551	28330	Economy	5800.00
0005435893539	4456	Economy	15400.00
0005435893537	4456	Economy	14000.00
0005434351548	4456	Economy	14000.00
0005434351553	4456	Economy	14000.00
0005434351554	4456	Economy	14000.00
0005434351547	4456	Economy	14000.00
0005434351546	4456	Economy	14000.00
0005434351542	4456	Economy	14000.00
0005434351545	4456	Economy	14000.00
0005435893538	4456	Economy	14000.00
0005434351549	4456	Economy	14000.00
0005434351543	4456	Economy	14000.00
0005434351551	4456	Economy	14000.00
0005435893512	4456	Economy	14000.00
0005434351555	4456	Economy	14000.00
0005434351552	4456	Economy	14000.00
0005434351544	4456	Economy	14000.00
0005434351550	4456	Economy	14000.00
0005435893550	29656	Economy	15400.00
0005435893552	29656	Economy	15400.00
0005435893549	29656	Economy	14000.00
0005435893551	29656	Economy	14000.00
0005435893546	29656	Economy	14000.00
0005435893547	29656	Economy	14000.00
0005434351473	29656	Economy	14000.00
0005435893548	29656	Economy	14000.00
0005434351469	29656	Economy	14000.00
0005435893553	29656	Economy	14000.00
0005435091957	1046	Business	30600.00
0005435091954	1046	Business	30600.00
0005433341549	1046	Business	30600.00
0005433341405	1046	Business	30600.00
0005433341406	1046	Economy	10200.00
0005433269624	1046	Economy	10200.00
0005435091960	1046	Economy	10200.00
0005434445221	1046	Economy	10200.00
0005433463876	1046	Economy	10200.00
0005435091961	1046	Economy	10200.00
0005434446492	1046	Economy	10200.00
0005435091958	1046	Economy	10200.00
0005435091964	1046	Economy	10200.00
0005433341670	1046	Economy	10200.00
0005433341465	1046	Economy	10200.00
0005435091955	1046	Economy	10200.00
0005434446493	1046	Economy	10200.00
0005433463875	1046	Economy	10200.00
0005432293179	1046	Economy	10200.00
0005434446494	1046	Economy	10200.00
0005435091959	1046	Economy	10200.00
0005434445222	1046	Economy	10200.00
0005433341466	1046	Economy	10200.00
0005433462722	1046	Economy	10200.00
0005435091963	1046	Economy	10200.00
0005435091956	1046	Economy	10200.00
0005432293180	1046	Economy	10200.00
0005433341525	1046	Economy	10200.00
0005435091962	1046	Economy	10200.00
0005433269653	17047	Business	30600.00
0005433159286	17047	Business	30600.00
0005433341890	17047	Business	30600.00
0005433341985	17047	Business	30600.00
0005433341950	17047	Business	30600.00
0005433341933	17047	Business	30600.00
0005433341959	17047	Business	30600.00
0005433341917	17047	Business	30600.00
0005433341958	17047	Business	30600.00
0005433341955	17047	Business	30600.00
0005433341912	17047	Business	30600.00
0005433341929	17047	Business	30600.00
0005433341899	17047	Business	30600.00
0005433341948	17047	Business	30600.00
0005433341982	17047	Business	30600.00
0005435091908	17047	Business	30600.00
0005433341903	17047	Business	30600.00
0005433341914	17047	Economy	11200.00
0005433269659	17047	Economy	11200.00
0005433341977	17047	Economy	11200.00
0005433341963	17047	Economy	11200.00
0005433341949	17047	Economy	10200.00
0005433341911	17047	Economy	10200.00
0005433341932	17047	Economy	10200.00
0005433341973	17047	Economy	10200.00
0005433341891	17047	Economy	10200.00
0005433341919	17047	Economy	10200.00
0005433269654	17047	Economy	10200.00
0005433341945	17047	Economy	10200.00
0005433341978	17047	Economy	10200.00
0005433341961	17047	Economy	10200.00
0005433341918	17047	Economy	10200.00
0005433341927	17047	Economy	10200.00
0005433341964	17047	Economy	10200.00
0005433341935	17047	Economy	10200.00
0005433341951	17047	Economy	10200.00
0005433341984	17047	Economy	10200.00
0005433341957	17047	Economy	10200.00
0005433341926	17047	Economy	10200.00
0005433341923	17047	Economy	10200.00
0005433341965	17047	Economy	10200.00
0005433269657	17047	Economy	10200.00
0005433341941	17047	Economy	10200.00
0005433341954	17047	Economy	10200.00
0005433341940	17047	Economy	10200.00
0005433341967	17047	Economy	10200.00
0005433341931	17047	Economy	10200.00
0005433341928	17047	Economy	10200.00
0005433341974	17047	Economy	10200.00
0005435091909	17047	Economy	10200.00
0005435091906	17047	Economy	10200.00
0005433269658	17047	Economy	10200.00
0005433341898	17047	Economy	10200.00
0005433341921	17047	Economy	10200.00
0005435091903	17047	Economy	10200.00
0005433341893	17047	Economy	10200.00
0005433341956	17047	Economy	10200.00
0005433341905	17047	Economy	10200.00
0005433341915	17047	Economy	10200.00
0005433341971	17047	Economy	10200.00
0005433341944	17047	Economy	10200.00
0005433341907	17047	Economy	10200.00
0005433341894	17047	Economy	10200.00
0005433341904	17047	Economy	10200.00
0005433341897	17047	Economy	10200.00
0005433341934	17047	Economy	10200.00
0005433341916	17047	Economy	10200.00
0005435091902	17047	Economy	10200.00
0005433159288	17047	Economy	10200.00
0005433341936	17047	Economy	10200.00
0005433341966	17047	Economy	10200.00
0005433341938	17047	Economy	10200.00
0005433341980	17047	Economy	10200.00
0005433341902	17047	Economy	10200.00
0005433341889	17047	Economy	10200.00
0005433341972	17047	Economy	10200.00
0005433341920	17047	Economy	10200.00
0005433341888	17047	Economy	10200.00
0005433341901	17047	Economy	10200.00
0005433341952	17047	Economy	10200.00
0005433269656	17047	Economy	10200.00
0005433341942	17047	Economy	10200.00
0005433341896	17047	Economy	10200.00
0005433341970	17047	Economy	10200.00
0005433341968	17047	Economy	10200.00
0005433341981	17047	Economy	10200.00
0005433341922	17047	Economy	10200.00
0005433341906	17047	Economy	10200.00
0005435091900	17047	Economy	10200.00
0005433341953	17047	Economy	10200.00
0005433341943	17047	Economy	10200.00
0005433341939	17047	Economy	10200.00
0005433341987	17047	Economy	10200.00
0005433341895	17047	Economy	10200.00
0005433341960	17047	Economy	10200.00
0005433341937	17047	Economy	10200.00
0005433341913	17047	Economy	10200.00
0005433341969	17047	Economy	10200.00
0005433341925	17047	Economy	10200.00
0005435091907	17047	Economy	10200.00
0005433341946	17047	Economy	10200.00
0005433159287	17047	Economy	10200.00
0005433341924	17047	Economy	10200.00
0005433341892	17047	Economy	10200.00
0005433341962	17047	Economy	10200.00
0005433341975	17047	Economy	10200.00
0005433341910	17047	Economy	10200.00
0005433341976	17047	Economy	10200.00
0005433269655	17047	Economy	10200.00
0005433341983	17047	Economy	10200.00
0005433341900	17047	Economy	10200.00
0005433341908	17047	Economy	10200.00
0005433269660	17047	Economy	10200.00
0005433341947	17047	Economy	10200.00
0005433341909	17047	Economy	10200.00
0005435091897	17047	Economy	10200.00
0005433341930	17047	Economy	10200.00
0005433341979	17047	Economy	10200.00
0005433341986	17047	Economy	10200.00
0005432391958	1345	Business	101000.00
0005432389984	1345	Business	101000.00
0005432391959	1345	Business	101000.00
0005432389985	1345	Business	101000.00
0005432389998	1345	Business	101000.00
0005432390011	1345	Business	101000.00
0005432391961	1345	Business	101000.00
0005432389988	1345	Business	101000.00
0005432390009	1345	Business	101000.00
0005432390013	1345	Business	101000.00
0005432389971	1345	Business	101000.00
0005432389995	1345	Business	101000.00
0005432389997	1345	Business	101000.00
0005432389994	1345	Economy	33700.00
0005432389990	1345	Economy	33700.00
0005432389973	1345	Economy	33700.00
0005432389996	1345	Economy	33700.00
0005432389968	1345	Economy	33700.00
0005432389975	1345	Economy	33700.00
0005432389987	1345	Economy	33700.00
0005432389992	1345	Economy	33700.00
0005432851819	1345	Economy	37000.00
0005432391953	1345	Economy	33700.00
0005432389982	1345	Economy	33700.00
0005432389969	1345	Economy	33700.00
0005432390001	1345	Economy	33700.00
0005432390006	1345	Economy	33700.00
0005432391955	1345	Economy	33700.00
0005432389976	1345	Economy	33700.00
0005432391963	1345	Economy	33700.00
0005432390004	1345	Economy	33700.00
0005432390003	1345	Economy	33700.00
0005432389977	1345	Economy	33700.00
0005432389979	1345	Economy	33700.00
0005432391956	1345	Economy	33700.00
0005432389986	1345	Economy	33700.00
0005432390005	1345	Economy	33700.00
0005432391952	1345	Economy	33700.00
0005432389993	1345	Economy	33700.00
0005432389970	1345	Economy	33700.00
0005432390002	1345	Economy	33700.00
0005432391957	1345	Economy	33700.00
0005432391962	1345	Economy	33700.00
0005432389981	1345	Economy	33700.00
0005432389972	1345	Economy	33700.00
0005432390007	1345	Economy	33700.00
0005432389991	1345	Economy	33700.00
0005432389983	1345	Economy	33700.00
0005432389989	1345	Economy	33700.00
0005432390000	1345	Economy	33700.00
0005432389978	1345	Economy	33700.00
0005432389980	1345	Economy	33700.00
0005432391964	1345	Economy	33700.00
0005432391960	1345	Economy	33700.00
0005432390014	1345	Economy	33700.00
0005432389974	1345	Economy	33700.00
0005432390012	1345	Economy	33700.00
0005432390010	1345	Economy	33700.00
0005432390015	1345	Economy	33700.00
0005432389999	1345	Economy	33700.00
0005432390008	1345	Economy	33700.00
0005432391954	1345	Economy	33700.00
0005434066350	12805	Business	40300.00
0005434066384	12805	Business	40300.00
0005432433619	12805	Business	40300.00
0005434066351	12805	Economy	13400.00
0005432161125	12805	Economy	13400.00
0005434066304	12805	Economy	13400.00
0005434066331	12805	Economy	13400.00
0005433812873	12805	Economy	13400.00
0005432433616	12805	Economy	13400.00
0005432161127	12805	Economy	13400.00
0005434066510	12805	Economy	13400.00
0005432433618	12805	Economy	13400.00
0005432161124	12805	Economy	13400.00
0005433812872	12805	Economy	13400.00
0005432159803	12805	Economy	13400.00
0005432161126	12805	Economy	13400.00
0005432159806	12805	Economy	13400.00
0005432159805	12805	Economy	13400.00
0005434066305	12805	Economy	13400.00
0005432433617	12805	Economy	13400.00
0005432433615	12805	Economy	13400.00
0005432159804	12805	Economy	13400.00
0005434081620	30669	Business	40300.00
0005434066687	30669	Business	40300.00
0005434081625	30669	Business	40300.00
0005434066685	30669	Business	40300.00
0005434066712	30669	Business	40300.00
0005434066726	30669	Business	40300.00
0005434066667	30669	Business	40300.00
0005434066674	30669	Business	40300.00
0005434081624	30669	Business	40300.00
0005434066691	30669	Business	40300.00
0005432186824	30669	Business	40300.00
0005434066695	30669	Business	40300.00
0005432186826	30669	Economy	13400.00
0005434066714	30669	Economy	13400.00
0005434081605	30669	Economy	13400.00
0005434066683	30669	Economy	13400.00
0005432150095	30669	Economy	13400.00
0005434066690	30669	Economy	13400.00
0005434081613	30669	Economy	13400.00
0005434066715	30669	Economy	13400.00
0005434066702	30669	Economy	13400.00
0005434066722	30669	Economy	13400.00
0005432150099	30669	Economy	13400.00
0005434066699	30669	Economy	13400.00
0005434081603	30669	Economy	13400.00
0005434081609	30669	Economy	13400.00
0005434066676	30669	Economy	13400.00
0005434081616	30669	Economy	13400.00
0005434066720	30669	Economy	13400.00
0005433989714	30669	Economy	13400.00
0005434081621	30669	Economy	13400.00
0005432433586	30669	Economy	13400.00
0005434066666	30669	Economy	13400.00
0005434066672	30669	Economy	13400.00
0005434066697	30669	Economy	13400.00
0005433989711	30669	Economy	13400.00
0005434066661	30669	Economy	13400.00
0005434066717	30669	Economy	13400.00
0005434081618	30669	Economy	13400.00
0005434066710	30669	Economy	13400.00
0005434081610	30669	Economy	13400.00
0005434066664	30669	Economy	13400.00
0005434081614	30669	Economy	13400.00
0005432150101	30669	Economy	13400.00
0005434081600	30669	Economy	13400.00
0005434066668	30669	Economy	13400.00
0005434066719	30669	Economy	13400.00
0005434066677	30669	Economy	13400.00
0005434066700	30669	Economy	13400.00
0005434066659	30669	Economy	13400.00
0005432150102	30669	Economy	13400.00
0005434066688	30669	Economy	14800.00
0005434081599	30669	Economy	14800.00
0005434066675	30669	Economy	14800.00
0005432150096	30669	Economy	14800.00
0005434081612	30669	Economy	14800.00
0005434066707	30669	Economy	13400.00
0005434066716	30669	Economy	13400.00
0005434066684	30669	Economy	13400.00
0005434081617	30669	Economy	13400.00
0005434066658	30669	Economy	13400.00
0005434081602	30669	Economy	13400.00
0005432433594	30669	Economy	13400.00
0005434066686	30669	Economy	13400.00
0005434066705	30669	Economy	13400.00
0005434081606	30669	Economy	13400.00
0005434081604	30669	Economy	13400.00
0005434081623	30669	Economy	13400.00
0005434066729	30669	Economy	13400.00
0005433989710	30669	Economy	13400.00
0005434081619	30669	Economy	13400.00
0005432433585	30669	Economy	13400.00
0005434066718	30669	Economy	13400.00
0005434066689	30669	Economy	13400.00
0005434066727	30669	Economy	13400.00
0005434066682	30669	Economy	13400.00
0005434066694	30669	Economy	13400.00
0005434081611	30669	Economy	13400.00
0005434066681	30669	Economy	13400.00
0005432433582	30669	Economy	13400.00
0005434066723	30669	Economy	13400.00
0005434066721	30669	Economy	13400.00
0005434081608	30669	Economy	13400.00
0005434066708	30669	Economy	13400.00
0005432150098	30669	Economy	13400.00
0005432150100	30669	Economy	13400.00
0005434066679	30669	Economy	13400.00
0005434066678	30669	Economy	13400.00
0005434066663	30669	Economy	13400.00
0005434066701	30669	Economy	13400.00
0005434066660	30669	Economy	13400.00
0005434081607	30669	Economy	13400.00
0005432150097	30669	Economy	13400.00
0005434081598	30669	Economy	13400.00
0005434066698	30669	Economy	13400.00
0005432186825	30669	Economy	13400.00
0005434066724	30669	Economy	13400.00
0005432186823	30669	Economy	13400.00
0005434081615	30669	Economy	13400.00
0005434081601	30669	Economy	13400.00
0005434066680	30669	Economy	13400.00
0005434066706	30669	Economy	13400.00
0005434066669	30669	Economy	13400.00
0005434066704	30669	Economy	13400.00
0005434066728	30669	Economy	13400.00
0005434066671	30669	Economy	13400.00
0005432433596	30669	Economy	13400.00
0005434066725	30669	Economy	13400.00
0005434066670	30669	Economy	13400.00
0005434081622	30669	Economy	13400.00
0005434066693	30669	Economy	13400.00
0005434066692	30669	Economy	13400.00
0005434066713	30669	Economy	13400.00
0005434066662	30669	Economy	13400.00
0005434066673	30669	Economy	13400.00
0005434066696	30669	Economy	13400.00
0005433989712	30669	Economy	13400.00
0005434066703	30669	Economy	13400.00
0005434066711	30669	Economy	13400.00
0005433989713	30669	Economy	13400.00
0005432150094	30669	Economy	13400.00
0005434066709	30669	Economy	13400.00
0005434066665	30669	Economy	13400.00
0005433687688	9037	Economy	17600.00
0005433686612	9037	Economy	17600.00
0005433685505	9037	Economy	17600.00
0005433685501	9037	Economy	17600.00
0005433686616	9037	Economy	17600.00
0005433687683	9037	Economy	17600.00
0005433687682	9037	Economy	17600.00
0005433686615	9037	Economy	17600.00
0005433687686	9037	Economy	17600.00
0005433685504	9037	Economy	17600.00
0005433686611	9037	Economy	17600.00
0005433687685	9037	Economy	17600.00
0005433685502	9037	Economy	17600.00
0005433685506	9037	Economy	17600.00
0005433685503	9037	Economy	17600.00
0005433686610	9037	Economy	17600.00
0005433686614	9037	Economy	17600.00
0005433687687	9037	Economy	17600.00
0005433685500	9037	Economy	17600.00
0005433686613	9037	Economy	17600.00
0005433687684	9037	Economy	17600.00
0005432140353	5517	Business	35300.00
0005435765483	5517	Business	35300.00
0005435765496	5517	Business	35300.00
0005435765516	5517	Business	35300.00
0005435765504	5517	Business	35300.00
0005435765518	5517	Business	35300.00
0005435765503	5517	Business	35300.00
0005435722028	5517	Business	35300.00
0005435765512	5517	Business	35300.00
0005435765510	5517	Business	35300.00
0005434264696	5517	Business	35300.00
0005435723022	5517	Business	35300.00
0005435765492	5517	Business	35300.00
0005435765540	5517	Business	35300.00
0005435461777	5517	Business	35300.00
0005435765543	5517	Economy	12900.00
0005435765542	5517	Economy	12900.00
0005435765498	5517	Economy	12900.00
0005435735083	5517	Economy	11800.00
0005435765499	5517	Economy	11800.00
0005435725539	5517	Economy	11800.00
0005435765487	5517	Economy	11800.00
0005435765534	5517	Economy	11800.00
0005435765519	5517	Economy	11800.00
0005435765538	5517	Economy	11800.00
0005435765525	5517	Economy	11800.00
0005433529235	5517	Economy	11800.00
0005435723020	5517	Economy	11800.00
0005435765517	5517	Economy	11800.00
0005435765500	5517	Economy	11800.00
0005435765521	5517	Economy	11800.00
0005433527224	5517	Economy	11800.00
0005435765482	5517	Economy	11800.00
0005435765545	5517	Economy	11800.00
0005435725538	5517	Economy	11800.00
0005435723021	5517	Economy	11800.00
0005432140352	5517	Economy	11800.00
0005435765529	5517	Economy	11800.00
0005432140356	5517	Economy	11800.00
0005435765522	5517	Economy	11800.00
0005435461842	5517	Economy	11800.00
0005433527223	5517	Economy	11800.00
0005435765480	5517	Economy	11800.00
0005435765530	5517	Economy	11800.00
0005435725537	5517	Economy	11800.00
0005435765531	5517	Economy	11800.00
0005435765532	5517	Economy	11800.00
0005435461823	5517	Economy	11800.00
0005435765533	5517	Economy	11800.00
0005435765515	5517	Economy	11800.00
0005435765481	5517	Economy	11800.00
0005435765535	5517	Economy	11800.00
0005435765524	5517	Economy	11800.00
0005435722027	5517	Economy	11800.00
0005435765495	5517	Economy	11800.00
0005435765511	5517	Economy	11800.00
0005435765501	5517	Economy	11800.00
0005435765478	5517	Economy	11800.00
0005435765509	5517	Economy	11800.00
0005435765494	5517	Economy	11800.00
0005432140349	5517	Economy	11800.00
0005433527225	5517	Economy	11800.00
0005435720811	5517	Economy	11800.00
0005435765486	5517	Economy	11800.00
0005435725541	5517	Economy	11800.00
0005435765514	5517	Economy	11800.00
0005432140351	5517	Economy	11800.00
0005435722026	5517	Economy	11800.00
0005435765520	5517	Economy	11800.00
0005435765485	5517	Economy	11800.00
0005435735082	5517	Economy	12900.00
0005435765505	5517	Economy	12900.00
0005435461779	5517	Economy	11800.00
0005435765493	5517	Economy	11800.00
0005435461843	5517	Economy	11800.00
0005435765537	5517	Economy	12900.00
0005435765508	5517	Economy	12900.00
0005435765477	5517	Economy	11800.00
0005435765527	5517	Economy	11800.00
0005435725540	5517	Economy	11800.00
0005433529236	5517	Economy	11800.00
0005435765523	5517	Economy	11800.00
0005433527222	5517	Economy	11800.00
0005435735081	5517	Economy	11800.00
0005435765541	5517	Economy	11800.00
0005432140350	5517	Economy	11800.00
0005435765490	5517	Economy	11800.00
0005435765546	5517	Economy	11800.00
0005434264697	5517	Economy	11800.00
0005435765502	5517	Economy	11800.00
0005435765497	5517	Economy	11800.00
0005435735085	5517	Economy	11800.00
0005435765536	5517	Economy	11800.00
0005432140355	5517	Economy	11800.00
0005435765513	5517	Economy	11800.00
0005435765507	5517	Economy	11800.00
0005432140354	5517	Economy	11800.00
0005435735084	5517	Economy	11800.00
0005435765539	5517	Economy	11800.00
0005435765479	5517	Economy	11800.00
0005435765506	5517	Economy	11800.00
0005435720812	5517	Economy	11800.00
0005435765544	5517	Economy	11800.00
0005435765488	5517	Economy	11800.00
0005435765484	5517	Economy	11800.00
0005435765491	5517	Economy	11800.00
0005435765528	5517	Economy	11800.00
0005435461778	5517	Economy	11800.00
0005435765489	5517	Economy	11800.00
0005435765547	5517	Economy	11800.00
0005435765526	5517	Economy	11800.00
0005432535777	13482	Business	35300.00
0005435461988	13482	Business	35300.00
0005435461993	13482	Business	35300.00
0005435765140	13482	Business	35300.00
0005435461997	13482	Business	35300.00
0005434264841	13482	Business	35300.00
0005435765123	13482	Business	35300.00
0005434264842	13482	Business	35300.00
0005434831098	13482	Business	35300.00
0005434264843	13482	Economy	12900.00
0005435462002	13482	Economy	12900.00
0005435461998	13482	Economy	12900.00
0005434264838	13482	Economy	11800.00
0005435765205	13482	Economy	11800.00
0005434264849	13482	Economy	11800.00
0005435765190	13482	Economy	11800.00
0005434831095	13482	Economy	11800.00
0005435765206	13482	Economy	11800.00
0005434264858	13482	Economy	11800.00
0005435462018	13482	Economy	11800.00
0005435462022	13482	Economy	11800.00
0005435765183	13482	Economy	11800.00
0005434264857	13482	Economy	11800.00
0005435461991	13482	Economy	11800.00
0005434264840	13482	Economy	11800.00
0005435765104	13482	Economy	11800.00
0005434264860	13482	Economy	11800.00
0005435462009	13482	Economy	11800.00
0005435462012	13482	Economy	11800.00
0005435461996	13482	Economy	11800.00
0005435461990	13482	Economy	11800.00
0005435462013	13482	Economy	11800.00
0005435462004	13482	Economy	11800.00
0005435462001	13482	Economy	11800.00
0005435462024	13482	Economy	11800.00
0005432535780	13482	Economy	11800.00
0005435462021	13482	Economy	11800.00
0005432194462	13482	Economy	11800.00
0005435462011	13482	Economy	11800.00
0005434264853	13482	Economy	11800.00
0005434264851	13482	Economy	11800.00
0005434264856	13482	Economy	11800.00
0005434264844	13482	Economy	11800.00
0005434264859	13482	Economy	11800.00
0005432194463	13482	Economy	11800.00
0005435765103	13482	Economy	11800.00
0005435462017	13482	Economy	11800.00
0005435461992	13482	Economy	11800.00
0005434264839	13482	Economy	11800.00
0005435461995	13482	Economy	11800.00
0005435462005	13482	Economy	11800.00
0005435765141	13482	Economy	11800.00
0005435462008	13482	Economy	11800.00
0005435461994	13482	Economy	11800.00
0005435735059	13482	Economy	11800.00
0005435462000	13482	Economy	11800.00
0005434264850	13482	Economy	11800.00
0005435462016	13482	Economy	11800.00
0005434264836	13482	Economy	11800.00
0005434264848	13482	Economy	12900.00
0005435765240	13482	Economy	11800.00
0005435462019	13482	Economy	11800.00
0005432194461	13482	Economy	12900.00
0005435462003	13482	Economy	11800.00
0005435462014	13482	Economy	11800.00
0005434831097	13482	Economy	11800.00
0005432535779	13482	Economy	11800.00
0005435462015	13482	Economy	11800.00
0005432535776	13482	Economy	11800.00
0005434264846	13482	Economy	11800.00
0005435765160	13482	Economy	11800.00
0005434831096	13482	Economy	11800.00
0005435462010	13482	Economy	11800.00
0005435461999	13482	Economy	11800.00
0005435462026	13482	Economy	11800.00
0005434264845	13482	Economy	11800.00
0005435462023	13482	Economy	11800.00
0005434831099	13482	Economy	11800.00
0005435765120	13482	Economy	11800.00
0005434264837	13482	Economy	11800.00
0005434264854	13482	Economy	11800.00
0005435461989	13482	Economy	11800.00
0005432535775	13482	Economy	11800.00
0005434264855	13482	Economy	11800.00
0005435765102	13482	Economy	11800.00
0005435462007	13482	Economy	11800.00
0005434264835	13482	Economy	11800.00
0005432535778	13482	Economy	11800.00
0005434264852	13482	Economy	11800.00
0005435462020	13482	Economy	11800.00
0005434264847	13482	Economy	11800.00
0005435462025	13482	Economy	11800.00
0005432194464	13482	Economy	11800.00
0005435462006	13482	Economy	11800.00
0005434602864	18705	Economy	3300.00
0005434514936	18704	Economy	3300.00
0005434513547	18704	Economy	3300.00
0005434514935	18704	Economy	3300.00
0005434513548	18704	Economy	3300.00
0005434514934	18704	Economy	3300.00
0005434514925	19144	Economy	3300.00
0005434514924	19144	Economy	3300.00
0005432632663	4125	Business	88300.00
0005435846188	4125	Business	88300.00
0005432632661	4125	Economy	29400.00
0005432649333	4125	Economy	29400.00
0005435846190	4125	Economy	29400.00
0005432632658	4125	Economy	29400.00
0005432649337	4125	Economy	32400.00
0005432649335	4125	Economy	32400.00
0005432632660	4125	Economy	29400.00
0005432632668	4125	Economy	29400.00
0005432632664	4125	Economy	29400.00
0005432632665	4125	Economy	29400.00
0005432632659	4125	Economy	29400.00
0005432632662	4125	Economy	29400.00
0005432632657	4125	Economy	29400.00
0005432649336	4125	Economy	29400.00
0005432632669	4125	Economy	29400.00
0005432649338	4125	Economy	29400.00
0005432649331	4125	Economy	29400.00
0005432649334	4125	Economy	29400.00
0005432632656	4125	Economy	29400.00
0005435846194	4125	Economy	29400.00
0005432649329	4125	Economy	29400.00
0005432649327	4125	Economy	29400.00
0005432632655	4125	Economy	29400.00
0005432632666	4125	Economy	29400.00
0005432649332	4125	Economy	29400.00
0005432649330	4125	Economy	29400.00
0005432649328	4125	Economy	29400.00
0005432632667	4125	Economy	29400.00
0005433007853	1804	Business	48700.00
0005433810508	1804	Business	48700.00
0005433007825	1804	Business	48700.00
0005433007873	1804	Business	48700.00
0005432295848	1804	Economy	16200.00
0005433284783	1804	Economy	16200.00
0005433007855	1804	Economy	16200.00
0005433007856	1804	Economy	17900.00
0005433007874	1804	Economy	17900.00
0005433284805	1804	Economy	16200.00
0005433007918	1804	Economy	16200.00
0005432295850	1804	Economy	16200.00
0005433007950	1804	Economy	16200.00
0005432295849	1804	Economy	16200.00
0005433007823	1804	Economy	16200.00
0005433284823	1804	Economy	16200.00
0005433007919	1804	Economy	16200.00
0005433284824	1804	Economy	16200.00
0005433284782	1804	Economy	16200.00
0005433810509	1804	Economy	16200.00
0005433008083	22512	Business	48700.00
0005433284928	22512	Business	48700.00
0005433284930	22512	Business	48700.00
0005433284927	22512	Business	48700.00
0005433008070	22512	Business	48700.00
0005433284941	22512	Business	48700.00
0005433008064	22512	Business	48700.00
0005433284923	22512	Economy	16200.00
0005433284911	22512	Economy	16200.00
0005433284934	22512	Economy	16200.00
0005433284942	22512	Economy	16200.00
0005433284919	22512	Economy	16200.00
0005433008086	22512	Economy	16200.00
0005433008097	22512	Economy	16200.00
0005433284933	22512	Economy	16200.00
0005433008076	22512	Economy	16200.00
0005433284926	22512	Economy	17900.00
0005433008068	22512	Economy	17900.00
0005433284918	22512	Economy	17900.00
0005433284921	22512	Economy	17900.00
0005433008084	22512	Economy	16200.00
0005433284922	22512	Economy	16200.00
0005433008096	22512	Economy	16200.00
0005433284940	22512	Economy	16200.00
0005433008059	22512	Economy	16200.00
0005433008081	22512	Economy	16200.00
0005433284938	22512	Economy	16200.00
0005433008072	22512	Economy	16200.00
0005433008074	22512	Economy	16200.00
0005433008088	22512	Economy	16200.00
0005433008080	22512	Economy	16200.00
0005433284920	22512	Economy	16200.00
0005433008077	22512	Economy	16200.00
0005433008069	22512	Economy	16200.00
0005433008087	22512	Economy	16200.00
0005433284929	22512	Economy	16200.00
0005433284924	22512	Economy	16200.00
0005433008071	22512	Economy	16200.00
0005433008066	22512	Economy	16200.00
0005433284912	22512	Economy	16200.00
0005433284931	22512	Economy	16200.00
0005433008099	22512	Economy	16200.00
0005433284917	22512	Economy	16200.00
0005433008065	22512	Economy	16200.00
0005433008057	22512	Economy	16200.00
0005433008067	22512	Economy	16200.00
0005433008090	22512	Economy	16200.00
0005433008091	22512	Economy	16200.00
0005433008061	22512	Economy	16200.00
0005433284939	22512	Economy	16200.00
0005433008085	22512	Economy	16200.00
0005433008095	22512	Economy	16200.00
0005433008075	22512	Economy	16200.00
0005433008073	22512	Economy	16200.00
0005433284935	22512	Economy	16200.00
0005433008092	22512	Economy	16200.00
0005433284932	22512	Economy	16200.00
0005433008063	22512	Economy	16200.00
0005433008082	22512	Economy	16200.00
0005433008078	22512	Economy	16200.00
0005433008055	22512	Economy	16200.00
0005433284936	22512	Economy	16200.00
0005433008093	22512	Economy	16200.00
0005433008094	22512	Economy	16200.00
0005433008060	22512	Economy	16200.00
0005433008098	22512	Economy	16200.00
0005433284937	22512	Economy	16200.00
0005433284915	22512	Economy	16200.00
0005433284914	22512	Economy	16200.00
0005433284913	22512	Economy	16200.00
0005433284925	22512	Economy	16200.00
0005433008058	22512	Economy	16200.00
0005433008079	22512	Economy	16200.00
0005433008062	22512	Economy	16200.00
0005433008089	22512	Economy	16200.00
0005433008056	22512	Economy	16200.00
0005433284916	22512	Economy	16200.00
0005434152771	12293	Business	83800.00
0005434152764	12293	Business	83800.00
0005434152762	12293	Business	83800.00
0005432755018	12293	Business	83800.00
0005434152760	12293	Economy	30700.00
0005434152770	12293	Economy	27900.00
0005434152765	12293	Economy	27900.00
0005434152769	12293	Economy	27900.00
0005434152768	12293	Economy	27900.00
0005432755019	12293	Economy	27900.00
0005434152761	12293	Economy	27900.00
0005434152763	12293	Economy	27900.00
0005434152767	12293	Economy	27900.00
0005434152766	12293	Economy	27900.00
0005433846036	5559	Business	99800.00
0005433815326	5559	Business	99800.00
0005433846074	5559	Business	99800.00
0005433846032	5559	Business	99800.00
0005433815325	5559	Business	99800.00
0005433846037	5559	Business	99800.00
0005433815329	5559	Business	99800.00
0005432081440	5559	Business	99800.00
0005432081435	5559	Business	99800.00
0005433815328	5559	Business	99800.00
0005433846055	5559	Business	99800.00
0005433846029	5559	Business	99800.00
0005433846024	5559	Business	99800.00
0005433846078	5559	Business	99800.00
0005433846048	5559	Economy	33300.00
0005433846064	5559	Economy	33300.00
0005433846051	5559	Economy	33300.00
0005433846057	5559	Economy	33300.00
0005433846058	5559	Economy	33300.00
0005433846049	5559	Economy	33300.00
0005433846059	5559	Economy	33300.00
0005433846079	5559	Economy	33300.00
0005433846047	5559	Economy	36600.00
0005433846062	5559	Economy	36600.00
0005433846040	5559	Economy	33300.00
0005433846025	5559	Economy	36600.00
0005433846075	5559	Economy	33300.00
0005433846081	5559	Economy	33300.00
0005433846052	5559	Economy	33300.00
0005433846044	5559	Economy	33300.00
0005433846056	5559	Economy	33300.00
0005433815327	5559	Economy	33300.00
0005433846076	5559	Economy	33300.00
0005432081441	5559	Economy	33300.00
0005433846030	5559	Economy	33300.00
0005433846033	5559	Economy	33300.00
0005433846072	5559	Economy	33300.00
0005432081437	5559	Economy	33300.00
0005432081439	5559	Economy	33300.00
0005433846060	5559	Economy	33300.00
0005433846043	5559	Economy	33300.00
0005433846069	5559	Economy	33300.00
0005433846070	5559	Economy	33300.00
0005433846035	5559	Economy	33300.00
0005433846042	5559	Economy	33300.00
0005433846034	5559	Economy	33300.00
0005433846023	5559	Economy	33300.00
0005433846061	5559	Economy	33300.00
0005433846028	5559	Economy	33300.00
0005432081434	5559	Economy	33300.00
0005433846067	5559	Economy	33300.00
0005433846073	5559	Economy	33300.00
0005433846045	5559	Economy	33300.00
0005433846039	5559	Economy	33300.00
0005433846046	5559	Economy	33300.00
0005432081436	5559	Economy	33300.00
0005433846026	5559	Economy	33300.00
0005433846065	5559	Economy	33300.00
0005432081438	5559	Economy	33300.00
0005433846080	5559	Economy	33300.00
0005433846077	5559	Economy	33300.00
0005433846038	5559	Economy	33300.00
0005433846054	5559	Economy	33300.00
0005433846053	5559	Economy	33300.00
0005433846063	5559	Economy	33300.00
0005433846022	5559	Economy	33300.00
0005433846068	5559	Economy	33300.00
0005433846041	5559	Economy	33300.00
0005433846027	5559	Economy	33300.00
0005433846031	5559	Economy	33300.00
0005433846050	5559	Economy	33300.00
0005432081433	5559	Economy	33300.00
0005433846071	5559	Economy	33300.00
0005433846066	5559	Economy	33300.00
0005434173477	13863	Business	99800.00
0005435282208	13863	Business	99800.00
0005433845749	13863	Business	99800.00
0005435282225	13863	Business	99800.00
0005434173476	13863	Business	99800.00
0005435282217	13863	Business	99800.00
0005435282222	13863	Business	99800.00
0005433845750	13863	Business	99800.00
0005435282209	13863	Business	99800.00
0005434173475	13863	Economy	33300.00
0005433845816	13863	Economy	33300.00
0005432003665	13863	Economy	33300.00
0005434173474	13863	Economy	33300.00
0005435282229	13863	Economy	36600.00
0005433845766	13863	Economy	36600.00
0005435282213	13863	Economy	36600.00
0005433815308	13863	Economy	33300.00
0005433845792	13863	Economy	33300.00
0005432003664	13863	Economy	33300.00
0005435282220	13863	Economy	33300.00
0005435282223	13863	Economy	33300.00
0005433845674	13863	Economy	33300.00
0005435282230	13863	Economy	33300.00
0005435282221	13863	Economy	33300.00
0005435282216	13863	Economy	33300.00
0005433845720	13863	Economy	33300.00
0005435282219	13863	Economy	33300.00
0005435282226	13863	Economy	33300.00
0005435282228	13863	Economy	33300.00
0005433815302	13863	Economy	33300.00
0005433845775	13863	Economy	33300.00
0005435282224	13863	Economy	33300.00
0005435282214	13863	Economy	33300.00
0005432003666	13863	Economy	33300.00
0005434173473	13863	Economy	33300.00
0005433845783	13863	Economy	33300.00
0005435282218	13863	Economy	33300.00
0005433845791	13863	Economy	33300.00
0005433845840	13863	Economy	33300.00
0005435282227	13863	Economy	33300.00
0005433815301	13863	Economy	33300.00
0005433845767	13863	Economy	33300.00
0005433845839	13863	Economy	33300.00
0005435282211	13863	Economy	33300.00
0005433845721	13863	Economy	33300.00
0005432003667	13863	Economy	33300.00
0005435282215	13863	Economy	33300.00
0005435282212	13863	Economy	33300.00
0005435282231	13863	Economy	33300.00
0005435282210	13863	Economy	33300.00
0005434620368	7844	Economy	16600.00
0005434620365	7844	Economy	15100.00
0005434620361	7844	Economy	15100.00
0005435332159	7844	Economy	15100.00
0005434620359	7844	Economy	15100.00
0005434620360	7844	Economy	15100.00
0005434620363	7844	Economy	15100.00
0005432112491	7844	Economy	15100.00
0005434620354	7844	Economy	15100.00
0005434620350	7844	Economy	15100.00
0005434620351	7844	Economy	15100.00
0005434620358	7844	Economy	15100.00
0005434620369	7844	Economy	15100.00
0005434620353	7844	Economy	15100.00
0005434620357	7844	Economy	15100.00
0005434620362	7844	Economy	15100.00
0005434620348	7844	Economy	15100.00
0005434620356	7844	Economy	15100.00
0005434620366	7844	Economy	15100.00
0005434620349	7844	Economy	15100.00
0005434620355	7844	Economy	15100.00
0005434620352	7844	Economy	15100.00
0005432112490	7844	Economy	15100.00
0005432112489	7844	Economy	15100.00
0005434620364	7844	Economy	15100.00
0005434620367	7844	Economy	15100.00
0005435332187	7844	Economy	15100.00
0005435332217	32994	Economy	15100.00
0005435332214	32994	Economy	15100.00
0005435332218	32994	Economy	15100.00
0005435332212	32994	Economy	15100.00
0005435332219	32994	Economy	15100.00
0005435332210	32994	Economy	15100.00
0005434620235	32994	Economy	15100.00
0005434620293	32994	Economy	15100.00
0005435332220	32994	Economy	15100.00
0005434620291	32994	Economy	15100.00
0005435332215	32994	Economy	15100.00
0005435332216	32994	Economy	15100.00
0005435332213	32994	Economy	15100.00
0005434620274	32994	Economy	15100.00
0005434620294	32994	Economy	15100.00
0005434620241	32994	Economy	15100.00
0005435332211	32994	Economy	15100.00
0005432190586	4287	Business	38000.00
0005435784947	4287	Business	38000.00
0005432190584	4287	Business	38000.00
0005435784965	4287	Business	38000.00
0005435784950	4287	Business	38000.00
0005435784960	4287	Business	38000.00
0005435784943	4287	Business	38000.00
0005435784963	4287	Economy	12700.00
0005435784961	4287	Economy	12700.00
0005435784946	4287	Economy	12700.00
0005434993910	4287	Economy	12700.00
0005435784955	4287	Economy	12700.00
0005435784953	4287	Economy	12700.00
0005435784969	4287	Economy	12700.00
0005435784957	4287	Economy	13900.00
0005435784945	4287	Economy	13900.00
0005435784944	4287	Economy	13900.00
0005435784939	4287	Economy	12700.00
0005435784966	4287	Economy	12700.00
0005435784959	4287	Economy	12700.00
0005435784940	4287	Economy	12700.00
0005435784951	4287	Economy	12700.00
0005435784949	4287	Economy	12700.00
0005434993911	4287	Economy	12700.00
0005434993913	4287	Economy	12700.00
0005434993909	4287	Economy	12700.00
0005434993906	4287	Economy	12700.00
0005435784956	4287	Economy	12700.00
0005435784952	4287	Economy	12700.00
0005435784962	4287	Economy	12700.00
0005435787329	4287	Economy	12700.00
0005432190583	4287	Economy	12700.00
0005435784973	4287	Economy	12700.00
0005435784970	4287	Economy	12700.00
0005435784974	4287	Economy	12700.00
0005435784967	4287	Economy	12700.00
0005434993914	4287	Economy	12700.00
0005435784942	4287	Economy	12700.00
0005432190585	4287	Economy	12700.00
0005435784948	4287	Economy	12700.00
0005434993907	4287	Economy	12700.00
0005435784968	4287	Economy	12700.00
0005435787328	4287	Economy	12700.00
0005434993912	4287	Economy	12700.00
0005435784971	4287	Economy	12700.00
0005435784972	4287	Economy	12700.00
0005435918584	4287	Economy	12700.00
0005435784976	4287	Economy	12700.00
0005435784941	4287	Economy	12700.00
0005435784954	4287	Economy	12700.00
0005435784975	4287	Economy	12700.00
0005435784958	4287	Economy	12700.00
0005434993908	4287	Economy	12700.00
0005435784964	4287	Economy	12700.00
0005432195667	27303	Economy	12700.00
0005434993846	27303	Economy	12700.00
0005435918600	27303	Economy	12700.00
0005435918602	27303	Economy	12700.00
0005435918601	27303	Economy	12700.00
0005434993859	27303	Economy	12700.00
0005435918599	27303	Economy	12700.00
0005434993872	27303	Economy	12700.00
0005435918598	27303	Economy	12700.00
0005434993860	27303	Economy	12700.00
0005435784781	27303	Economy	12700.00
0005432146175	19901	Economy	12800.00
0005432459263	4720	Business	40900.00
0005434081633	4720	Business	40900.00
0005434081646	4720	Business	40900.00
0005434081648	4720	Business	40900.00
0005432170306	4720	Business	40900.00
0005432459272	4720	Business	40900.00
0005432566909	4720	Business	40900.00
0005432566904	4720	Business	40900.00
0005432566956	4720	Business	40900.00
0005434081638	4720	Business	40900.00
0005432459261	4720	Business	40900.00
0005432459251	4720	Business	40900.00
0005432566930	4720	Business	40900.00
0005434081626	4720	Business	40900.00
0005432566949	4720	Business	40900.00
0005432459276	4720	Business	40900.00
0005432459259	4720	Business	40900.00
0005432459235	4720	Business	40900.00
0005432459227	4720	Business	40900.00
0005434081647	4720	Business	40900.00
0005432459240	4720	Business	40900.00
0005432566959	4720	Business	40900.00
0005432566963	4720	Business	40900.00
0005432566913	4720	Business	40900.00
0005432459233	4720	Economy	15000.00
0005432459266	4720	Economy	15000.00
0005434081641	4720	Economy	15000.00
0005432566908	4720	Economy	15000.00
0005432459226	4720	Economy	13600.00
0005432566916	4720	Economy	13600.00
0005432459242	4720	Economy	13600.00
0005432459269	4720	Economy	13600.00
0005432170307	4720	Economy	13600.00
0005432566920	4720	Economy	13600.00
0005432566950	4720	Economy	13600.00
0005432566960	4720	Economy	13600.00
0005432459268	4720	Economy	13600.00
0005432459265	4720	Economy	13600.00
0005432566957	4720	Economy	13600.00
0005432566901	4720	Economy	13600.00
0005432566902	4720	Economy	13600.00
0005432459274	4720	Economy	13600.00
0005433452714	4720	Economy	13600.00
0005432566926	4720	Economy	13600.00
0005432459267	4720	Economy	13600.00
0005432566958	4720	Economy	13600.00
0005432571278	4720	Economy	13600.00
0005432566928	4720	Economy	13600.00
0005434081628	4720	Economy	13600.00
0005434081645	4720	Economy	13600.00
0005432170309	4720	Economy	13600.00
0005432566962	4720	Economy	13600.00
0005432459262	4720	Economy	13600.00
0005432459237	4720	Economy	13600.00
0005432459256	4720	Economy	13600.00
0005432566942	4720	Economy	13600.00
0005434081649	4720	Economy	13600.00
0005432566927	4720	Economy	13600.00
0005432186827	4720	Economy	13600.00
0005432459270	4720	Economy	13600.00
0005433726076	4720	Economy	13600.00
0005432566931	4720	Economy	13600.00
0005432566938	4720	Economy	13600.00
0005432459252	4720	Economy	13600.00
0005432170311	4720	Economy	13600.00
0005432566937	4720	Economy	13600.00
0005432459250	4720	Economy	13600.00
0005432459234	4720	Economy	13600.00
0005432566945	4720	Economy	13600.00
0005432571279	4720	Economy	13600.00
0005432566934	4720	Economy	13600.00
0005432566955	4720	Economy	13600.00
0005434081639	4720	Economy	13600.00
0005434081643	4720	Economy	13600.00
0005432566943	4720	Economy	13600.00
0005432566954	4720	Economy	13600.00
0005432459243	4720	Economy	13600.00
0005432571276	4720	Economy	13600.00
0005432459231	4720	Economy	13600.00
0005432566933	4720	Economy	13600.00
0005432186830	4720	Economy	13600.00
0005432566944	4720	Economy	13600.00
0005434081640	4720	Economy	13600.00
0005432566911	4720	Economy	13600.00
0005432459232	4720	Economy	13600.00
0005432566936	4720	Economy	13600.00
0005432459230	4720	Economy	13600.00
0005432459275	4720	Economy	13600.00
0005432459253	4720	Economy	13600.00
0005434081630	4720	Economy	13600.00
0005432459255	4720	Economy	13600.00
0005432566915	4720	Economy	13600.00
0005432459260	4720	Economy	13600.00
0005432566919	4720	Economy	13600.00
0005432566935	4720	Economy	13600.00
0005432566953	4720	Economy	13600.00
0005432459244	4720	Economy	13600.00
0005432566932	4720	Economy	13600.00
0005432170308	4720	Economy	13600.00
0005432571277	4720	Economy	13600.00
0005432459229	4720	Economy	15000.00
0005432459271	4720	Economy	13600.00
0005432566952	4720	Economy	15000.00
0005432459241	4720	Economy	13600.00
0005432459258	4720	Economy	13600.00
0005432566961	4720	Economy	15000.00
0005432459246	4720	Economy	13600.00
0005434081650	4720	Economy	15000.00
0005432566923	4720	Economy	13600.00
0005432566903	4720	Economy	13600.00
0005432459247	4720	Economy	13600.00
0005434081634	4720	Economy	13600.00
0005432566907	4720	Economy	13600.00
0005432459249	4720	Economy	13600.00
0005433452715	4720	Economy	13600.00
0005432170310	4720	Economy	13600.00
0005432566925	4720	Economy	13600.00
0005432566910	4720	Economy	13600.00
0005432459239	4720	Economy	13600.00
0005432566939	4720	Economy	13600.00
0005432186829	4720	Economy	13600.00
0005432170312	4720	Economy	13600.00
0005432566905	4720	Economy	13600.00
0005432566941	4720	Economy	13600.00
0005432566912	4720	Economy	13600.00
0005434081632	4720	Economy	13600.00
0005432566940	4720	Economy	13600.00
0005432459223	4720	Economy	13600.00
0005434081644	4720	Economy	13600.00
0005434081636	4720	Economy	13600.00
0005433726077	4720	Economy	13600.00
0005432566921	4720	Economy	13600.00
0005432459225	4720	Economy	13600.00
0005432186828	4720	Economy	13600.00
0005434081627	4720	Economy	13600.00
0005432566924	4720	Economy	13600.00
0005432459264	4720	Economy	13600.00
0005432459238	4720	Economy	13600.00
0005434081629	4720	Economy	13600.00
0005432566918	4720	Economy	13600.00
0005434081651	4720	Economy	13600.00
0005432566951	4720	Economy	13600.00
0005432566914	4720	Economy	13600.00
0005432459254	4720	Economy	13600.00
0005432566929	4720	Economy	13600.00
0005434081652	4720	Economy	13600.00
0005432566948	4720	Economy	13600.00
0005432459245	4720	Economy	13600.00
0005432566946	4720	Economy	13600.00
0005432566922	4720	Economy	13600.00
0005432459273	4720	Economy	13600.00
0005434081631	4720	Economy	13600.00
0005434081642	4720	Economy	13600.00
0005432566917	4720	Economy	13600.00
0005432566906	4720	Economy	13600.00
0005432459257	4720	Economy	13600.00
0005434081637	4720	Economy	13600.00
0005432566947	4720	Economy	13600.00
0005432459236	4720	Economy	13600.00
0005432459224	4720	Economy	13600.00
0005432459228	4720	Economy	13600.00
0005433726078	4720	Economy	13600.00
0005432459248	4720	Economy	13600.00
0005434081635	4720	Economy	13600.00
0005432566574	30519	Business	40900.00
0005432458985	30519	Business	40900.00
0005432566529	30519	Business	40900.00
0005432161127	30519	Business	40900.00
0005432459049	30519	Business	40900.00
0005432458988	30519	Business	40900.00
0005432458986	30519	Economy	15000.00
0005432458957	30519	Economy	13600.00
0005432459041	30519	Economy	13600.00
0005433454840	30519	Economy	13600.00
0005432566580	30519	Economy	13600.00
0005432161124	30519	Economy	13600.00
0005432566657	30519	Economy	13600.00
0005432458984	30519	Economy	13600.00
0005432566546	30519	Economy	13600.00
0005432213564	30519	Economy	13600.00
0005432566762	30519	Economy	13600.00
0005432566549	30519	Economy	13600.00
0005432459050	30519	Economy	13600.00
0005432458958	30519	Economy	13600.00
0005433454839	30519	Economy	13600.00
0005432458959	30519	Economy	13600.00
0005432213562	30519	Economy	13600.00
0005432213563	30519	Economy	13600.00
0005432566649	30519	Economy	13600.00
0005432161125	30519	Economy	15000.00
0005432459042	30519	Economy	13600.00
0005432566650	30519	Economy	13600.00
0005432566573	30519	Economy	13600.00
0005432566656	30519	Economy	13600.00
0005432566601	30519	Economy	13600.00
0005432213561	30519	Economy	13600.00
0005432566667	30519	Economy	13600.00
0005432566602	30519	Economy	13600.00
0005432161126	30519	Economy	13600.00
0005432566668	30519	Economy	13600.00
0005432566636	30519	Economy	13600.00
0005432213565	30519	Economy	13600.00
0005435722028	13612	Economy	9900.00
0005435722026	13612	Economy	9900.00
0005435720812	13612	Economy	9900.00
0005435720811	13612	Economy	9900.00
0005435722027	13612	Economy	9900.00
0005432295850	22781	Economy	8800.00
0005432295849	22781	Economy	8800.00
0005432295848	22781	Economy	8800.00
0005433342079	11108	Business	23600.00
0005433341992	11108	Business	23600.00
0005433342024	11108	Business	23600.00
0005433342042	11108	Business	23600.00
0005433341993	11108	Business	23600.00
0005433342082	11108	Business	23600.00
0005433342019	11108	Business	23600.00
0005433342032	11108	Business	23600.00
0005433342071	11108	Business	23600.00
0005435097096	11108	Economy	7900.00
0005433342064	11108	Economy	7900.00
0005433342047	11108	Economy	7900.00
0005433342048	11108	Economy	7900.00
0005433342027	11108	Economy	7900.00
0005433341999	11108	Economy	7900.00
0005433342067	11108	Economy	7900.00
0005433342066	11108	Economy	7900.00
0005433342000	11108	Economy	7900.00
0005433342010	11108	Economy	7900.00
0005433342087	11108	Economy	7900.00
0005433342062	11108	Economy	7900.00
0005433342056	11108	Economy	7900.00
0005433341997	11108	Economy	7900.00
0005433342072	11108	Economy	7900.00
0005433342059	11108	Economy	7900.00
0005433342008	11108	Economy	7900.00
0005433342077	11108	Economy	7900.00
0005433342006	11108	Economy	7900.00
0005433342080	11108	Economy	7900.00
0005433342033	11108	Economy	7900.00
0005433342051	11108	Economy	7900.00
0005433342075	11108	Economy	7900.00
0005433342045	11108	Economy	7900.00
0005433342068	11108	Economy	7900.00
0005433341996	11108	Economy	7900.00
0005433342007	11108	Economy	7900.00
0005435097095	11108	Economy	7900.00
0005435097092	11108	Economy	7900.00
0005433342011	11108	Economy	7900.00
0005433342016	11108	Economy	7900.00
0005433342069	11108	Economy	7900.00
0005433342081	11108	Economy	7900.00
0005435097090	11108	Economy	7900.00
0005433342073	11108	Economy	7900.00
0005433342020	11108	Economy	8600.00
0005433342030	11108	Economy	8600.00
0005433342004	11108	Economy	8600.00
0005433342054	11108	Economy	8600.00
0005433342035	11108	Economy	8600.00
0005433342022	11108	Economy	8600.00
0005435097094	11108	Economy	7900.00
0005433342063	11108	Economy	7900.00
0005433342057	11108	Economy	7900.00
0005433341995	11108	Economy	7900.00
0005433342049	11108	Economy	7900.00
0005433342039	11108	Economy	7900.00
0005433342046	11108	Economy	7900.00
0005433342058	11108	Economy	7900.00
0005433341998	11108	Economy	7900.00
0005435097091	11108	Economy	7900.00
0005435097098	11108	Economy	7900.00
0005433342044	11108	Economy	7900.00
0005433342083	11108	Economy	7900.00
0005433342060	11108	Economy	7900.00
0005433342015	11108	Economy	7900.00
0005433342040	11108	Economy	7900.00
0005433342021	11108	Economy	7900.00
0005433342013	11108	Economy	7900.00
0005433342014	11108	Economy	7900.00
0005433342037	11108	Economy	7900.00
0005433342026	11108	Economy	7900.00
0005433341989	11108	Economy	7900.00
0005433342070	11108	Economy	7900.00
0005435097088	11108	Economy	7900.00
0005435097093	11108	Economy	7900.00
0005433342085	11108	Economy	7900.00
0005433342038	11108	Economy	7900.00
0005433342002	11108	Economy	7900.00
0005433342025	11108	Economy	7900.00
0005433342055	11108	Economy	7900.00
0005433342052	11108	Economy	7900.00
0005433342074	11108	Economy	7900.00
0005433342003	11108	Economy	7900.00
0005433342009	11108	Economy	7900.00
0005433342034	11108	Economy	7900.00
0005433342005	11108	Economy	7900.00
0005433342076	11108	Economy	7900.00
0005433342012	11108	Economy	7900.00
0005433342050	11108	Economy	7900.00
0005433342041	11108	Economy	7900.00
0005433342028	11108	Economy	7900.00
0005433342043	11108	Economy	7900.00
0005433342053	11108	Economy	7900.00
0005435097089	11108	Economy	7900.00
0005433342001	11108	Economy	7900.00
0005433342088	11108	Economy	7900.00
0005433342031	11108	Economy	7900.00
0005433342078	11108	Economy	7900.00
0005433342065	11108	Economy	7900.00
0005433342018	11108	Economy	7900.00
0005433342084	11108	Economy	7900.00
0005433342029	11108	Economy	7900.00
0005435097097	11108	Economy	7900.00
0005433341990	11108	Economy	7900.00
0005433342061	11108	Economy	7900.00
0005433342017	11108	Economy	7900.00
0005433341991	11108	Economy	7900.00
0005433341988	11108	Economy	7900.00
0005433342036	11108	Economy	7900.00
0005433342023	11108	Economy	7900.00
0005433341994	11108	Economy	7900.00
0005433342086	11108	Economy	7900.00
0005433341670	17136	Business	23600.00
0005433341406	17136	Economy	7900.00
0005433341466	17136	Economy	7900.00
0005433341525	17136	Economy	8600.00
0005433341405	17136	Economy	7900.00
0005432293180	17136	Economy	7900.00
0005432293179	17136	Economy	7900.00
0005433341465	17136	Economy	7900.00
0005433341549	17136	Economy	7900.00
0005433506981	9066	Business	26600.00
0005433506965	9066	Economy	8900.00
0005433506975	9066	Economy	8900.00
0005433506977	9066	Economy	8900.00
0005433506972	9066	Economy	8900.00
0005433506970	9066	Economy	9800.00
0005433506962	9066	Economy	8900.00
0005433506974	9066	Economy	8900.00
0005433506966	9066	Economy	8900.00
0005433506968	9066	Economy	8900.00
0005433506980	9066	Economy	8900.00
0005433481078	9066	Economy	8900.00
0005433506978	9066	Economy	8900.00
0005433506976	9066	Economy	8900.00
0005433481082	9066	Economy	8900.00
0005433506961	9066	Economy	8900.00
0005433481079	9066	Economy	8900.00
0005433506960	9066	Economy	8900.00
0005433481077	9066	Economy	8900.00
0005433481081	9066	Economy	8900.00
0005433481076	9066	Economy	8900.00
0005434158943	9066	Economy	8900.00
0005433506967	9066	Economy	8900.00
0005433506973	9066	Economy	8900.00
0005433506959	9066	Economy	8900.00
0005433481080	9066	Economy	8900.00
0005433506979	9066	Economy	8900.00
0005433506964	9066	Economy	8900.00
0005433506963	9066	Economy	8900.00
0005433506969	9066	Economy	8900.00
0005433506971	9066	Economy	8900.00
0005432919645	20445	Business	26600.00
0005433506871	20445	Business	26600.00
0005433506872	20445	Business	26600.00
0005432919637	20445	Business	26600.00
0005432919632	20445	Economy	8900.00
0005432919638	20445	Economy	8900.00
0005432919639	20445	Economy	8900.00
0005432919640	20445	Economy	8900.00
0005432919643	20445	Economy	8900.00
0005432919641	20445	Economy	8900.00
0005432919647	20445	Economy	8900.00
0005432919635	20445	Economy	8900.00
0005433506856	20445	Economy	8900.00
0005433481041	20445	Economy	8900.00
0005432919650	20445	Economy	8900.00
0005433481039	20445	Economy	8900.00
0005432919653	20445	Economy	8900.00
0005432919651	20445	Economy	8900.00
0005432919633	20445	Economy	8900.00
0005432919644	20445	Economy	8900.00
0005432919642	20445	Economy	8900.00
0005432919648	20445	Economy	8900.00
0005432919646	20445	Economy	8900.00
0005432919636	20445	Economy	8900.00
0005432919634	20445	Economy	8900.00
0005432919649	20445	Economy	8900.00
0005433506855	20445	Economy	8900.00
0005432919652	20445	Economy	8900.00
0005433481043	20445	Economy	8900.00
0005432919631	20445	Economy	8900.00
0005433506873	20445	Economy	8900.00
0005433481042	20445	Economy	8900.00
0005432396193	10139	Economy	5800.00
0005432394055	10139	Economy	5800.00
0005432396192	10139	Economy	5800.00
0005432396194	10139	Economy	5800.00
0005432394052	10139	Economy	5800.00
0005432394053	10139	Economy	5800.00
0005432394056	10139	Economy	5800.00
0005432394054	10139	Economy	5800.00
0005432396195	10139	Economy	5800.00
0005435179388	18284	Economy	5800.00
0005435179387	18284	Economy	5800.00
0005435125684	11055	Business	9500.00
0005434928267	11055	Business	9500.00
0005434411728	11055	Business	9500.00
0005434411730	11055	Economy	3500.00
0005434928266	11055	Economy	3500.00
0005435125669	11055	Economy	3200.00
0005435125668	11055	Economy	3200.00
0005434411729	11055	Economy	3200.00
0005435125649	11055	Economy	3200.00
0005434411731	11055	Economy	3200.00
0005434928268	11055	Economy	3200.00
0005435554105	11055	Economy	3200.00
0005435125657	11055	Economy	3200.00
0005435125912	14705	Business	9500.00
0005435125900	14705	Business	9500.00
0005435625981	14705	Business	9500.00
0005435125935	14705	Business	9500.00
0005435556661	14705	Business	9500.00
0005435125904	14705	Business	9500.00
0005435125931	14705	Business	9500.00
0005435125914	14705	Business	9500.00
0005435556662	14705	Business	9500.00
0005434928260	14705	Business	9500.00
0005434928259	14705	Business	9500.00
0005435625971	14705	Economy	3200.00
0005435125897	14705	Economy	3200.00
0005435625978	14705	Economy	3200.00
0005435125908	14705	Economy	3200.00
0005435125919	14705	Economy	3200.00
0005435125899	14705	Economy	3200.00
0005435125917	14705	Economy	3200.00
0005435125927	14705	Economy	3500.00
0005435125909	14705	Economy	3500.00
0005435125906	14705	Economy	3500.00
0005435625972	14705	Economy	3200.00
0005435125926	14705	Economy	3200.00
0005435125905	14705	Economy	3200.00
0005435625982	14705	Economy	3200.00
0005435125910	14705	Economy	3200.00
0005435625983	14705	Economy	3200.00
0005435125916	14705	Economy	3200.00
0005435556663	14705	Economy	3200.00
0005435125933	14705	Economy	3200.00
0005435625973	14705	Economy	3200.00
0005435625979	14705	Economy	3200.00
0005435125925	14705	Economy	3200.00
0005435125901	14705	Economy	3200.00
0005435125920	14705	Economy	3200.00
0005435125918	14705	Economy	3200.00
0005435125930	14705	Economy	3200.00
0005435125921	14705	Economy	3200.00
0005435554129	14705	Economy	3200.00
0005435554130	14705	Economy	3200.00
0005435125913	14705	Economy	3200.00
0005435125898	14705	Economy	3200.00
0005435625974	14705	Economy	3200.00
0005435625977	14705	Economy	3200.00
0005435125928	14705	Economy	3200.00
0005435556664	14705	Economy	3200.00
0005435554131	14705	Economy	3200.00
0005435125915	14705	Economy	3200.00
0005435625980	14705	Economy	3200.00
0005435125922	14705	Economy	3200.00
0005435556665	14705	Economy	3200.00
0005435125902	14705	Economy	3200.00
0005435554132	14705	Economy	3200.00
0005435625975	14705	Economy	3200.00
0005435625976	14705	Economy	3200.00
0005435125932	14705	Economy	3200.00
0005435125934	14705	Economy	3200.00
0005435125903	14705	Economy	3200.00
0005435125907	14705	Economy	3200.00
0005435125936	14705	Economy	3200.00
0005435125923	14705	Economy	3200.00
0005435125911	14705	Economy	3200.00
0005435125937	14705	Economy	3200.00
0005435125929	14705	Economy	3200.00
0005435125924	14705	Economy	3200.00
0005435443151	7104	Business	86900.00
0005435715272	7104	Business	86900.00
0005435715275	7104	Business	86900.00
0005435715280	7104	Business	86900.00
0005432400084	7104	Business	86900.00
0005435715269	7104	Business	86900.00
0005435715268	7104	Business	86900.00
0005435715278	7104	Economy	29000.00
0005432400085	7104	Economy	29000.00
0005435715264	7104	Economy	31900.00
0005435715276	7104	Economy	29000.00
0005435715270	7104	Economy	29000.00
0005432398155	7104	Economy	29000.00
0005435715271	7104	Economy	29000.00
0005432400083	7104	Economy	29000.00
0005435715266	7104	Economy	29000.00
0005432398154	7104	Economy	29000.00
0005432398156	7104	Economy	29000.00
0005435221035	7104	Economy	29000.00
0005435715267	7104	Economy	29000.00
0005435715281	7104	Economy	29000.00
0005435715279	7104	Economy	29000.00
0005432400082	7104	Economy	29000.00
0005435715274	7104	Economy	29000.00
0005435715277	7104	Economy	29000.00
0005435715273	7104	Economy	29000.00
0005435715265	7104	Economy	29000.00
0005432398152	7104	Economy	29000.00
0005432398153	7104	Economy	29000.00
0005435178477	27088	Business	86900.00
0005435178982	27088	Economy	29000.00
0005435178476	27088	Economy	31900.00
0005435443202	27088	Economy	29000.00
0005435443203	27088	Economy	29000.00
0005435443204	27088	Economy	29000.00
0005435715206	27088	Economy	29000.00
0005435443208	27088	Economy	29000.00
0005435443210	27088	Economy	29000.00
0005435178981	27088	Economy	29000.00
0005435443207	27088	Economy	29000.00
0005435443205	27088	Economy	29000.00
0005435443209	27088	Economy	29000.00
0005435443206	27088	Economy	29000.00
0005434084881	2754	Economy	7700.00
0005434084880	2754	Economy	7700.00
0005434084877	2754	Economy	7700.00
0005434084876	2754	Economy	7700.00
0005434084878	2754	Economy	7700.00
0005434084879	2754	Economy	7700.00
0005434084875	2754	Economy	7700.00
0005433060382	28502	Economy	7700.00
0005433060381	28502	Economy	7700.00
0005433060383	28502	Economy	7700.00
0005432632642	25190	Economy	29000.00
0005432632648	25190	Economy	29000.00
0005432632643	25190	Economy	26400.00
0005432632649	25190	Economy	26400.00
0005432632645	25190	Economy	26400.00
0005432632654	25190	Economy	26400.00
0005432632638	25190	Economy	26400.00
0005432632652	25190	Economy	26400.00
0005432632636	25190	Economy	26400.00
0005432632653	25190	Economy	26400.00
0005432632641	25190	Economy	26400.00
0005432632651	25190	Economy	26400.00
0005432632639	25190	Economy	26400.00
0005432632644	25190	Economy	26400.00
0005432632646	25190	Economy	26400.00
0005432632635	25190	Economy	26400.00
0005432632647	25190	Economy	26400.00
0005432632637	25190	Economy	26400.00
0005432632640	25190	Economy	26400.00
0005432632650	25190	Economy	26400.00
0005435844276	28176	Economy	29000.00
0005435844272	28176	Economy	29000.00
0005435844274	28176	Economy	26400.00
0005435844281	28176	Economy	26400.00
0005435844275	28176	Economy	26400.00
0005432632627	28176	Economy	26400.00
0005435844279	28176	Economy	26400.00
0005435844277	28176	Economy	26400.00
0005435844278	28176	Economy	26400.00
0005435844273	28176	Economy	26400.00
0005435844271	28176	Economy	26400.00
0005435844280	28176	Economy	26400.00
0005435844282	28176	Economy	26400.00
0005435517618	11363	Business	20200.00
0005435540647	11363	Economy	7400.00
0005435517587	11363	Economy	6700.00
0005435517616	11363	Economy	6700.00
0005435517586	11363	Economy	6700.00
0005435517627	11363	Economy	6700.00
0005435540626	11363	Economy	6700.00
0005435540630	11363	Economy	6700.00
0005435540740	22242	Business	20200.00
0005435529005	22242	Business	20200.00
0005435528990	22242	Business	20200.00
0005435540742	22242	Business	20200.00
0005435540736	22242	Business	20200.00
0005435528992	22242	Business	20200.00
0005435528994	22242	Business	20200.00
0005435540753	22242	Economy	6700.00
0005435540734	22242	Economy	6700.00
0005435528993	22242	Economy	6700.00
0005435528997	22242	Economy	6700.00
0005435540749	22242	Economy	6700.00
0005435529010	22242	Economy	6700.00
0005435540751	22242	Economy	6700.00
0005435529008	22242	Economy	7400.00
0005435540744	22242	Economy	7400.00
0005435540748	22242	Economy	7400.00
0005435529001	22242	Economy	7400.00
0005435528999	22242	Economy	6700.00
0005435528989	22242	Economy	6700.00
0005435528998	22242	Economy	6700.00
0005435529002	22242	Economy	6700.00
0005435540754	22242	Economy	6700.00
0005432294457	22242	Economy	6700.00
0005432294459	22242	Economy	6700.00
0005435529006	22242	Economy	6700.00
0005435540755	22242	Economy	6700.00
0005435540743	22242	Economy	6700.00
0005435529009	22242	Economy	6700.00
0005435528991	22242	Economy	6700.00
0005435540747	22242	Economy	6700.00
0005435540737	22242	Economy	6700.00
0005435540735	22242	Economy	6700.00
0005432294458	22242	Economy	6700.00
0005435540746	22242	Economy	6700.00
0005435529003	22242	Economy	6700.00
0005435529007	22242	Economy	6700.00
0005435540752	22242	Economy	6700.00
0005435528995	22242	Economy	6700.00
0005435540741	22242	Economy	6700.00
0005435529004	22242	Economy	6700.00
0005435540739	22242	Economy	6700.00
0005435540738	22242	Economy	6700.00
0005435540750	22242	Economy	6700.00
0005435528996	22242	Economy	6700.00
0005435540745	22242	Economy	6700.00
0005435529000	22242	Economy	6700.00
0005434906744	2306	Business	20200.00
0005433250997	2306	Business	20200.00
0005433250950	2306	Business	20200.00
0005433250963	2306	Business	20200.00
0005433250989	2306	Business	20200.00
0005434906694	2306	Business	20200.00
0005434906714	2306	Business	20200.00
0005434906747	2306	Business	20200.00
0005434906724	2306	Business	20200.00
0005434906703	2306	Economy	6700.00
0005434906727	2306	Economy	6700.00
0005434906731	2306	Economy	6700.00
0005433250938	2306	Economy	6700.00
0005434906707	2306	Economy	6700.00
0005434906739	2306	Economy	6700.00
0005434906729	2306	Economy	6700.00
0005434906717	2306	Economy	6700.00
0005434906710	2306	Economy	7400.00
0005434906728	2306	Economy	7400.00
0005434906742	2306	Economy	6700.00
0005434906713	2306	Economy	6700.00
0005434906721	2306	Economy	6700.00
0005434906702	2306	Economy	6700.00
0005433251002	2306	Economy	6700.00
0005433251003	2306	Economy	6700.00
0005434906701	2306	Economy	6700.00
0005434906743	2306	Economy	6700.00
0005434906730	2306	Economy	6700.00
0005434906711	2306	Economy	6700.00
0005434906700	2306	Economy	6700.00
0005433250928	2306	Economy	6700.00
0005434906734	2306	Economy	6700.00
0005434906708	2306	Economy	6700.00
0005434906695	2306	Economy	6700.00
0005434906720	2306	Economy	6700.00
0005434906719	2306	Economy	6700.00
0005434906749	2306	Economy	6700.00
0005434906722	2306	Economy	6700.00
0005434906716	2306	Economy	6700.00
0005434906725	2306	Economy	6700.00
0005434906696	2306	Economy	6700.00
0005433250986	2306	Economy	6700.00
0005433250943	2306	Economy	6700.00
0005434906712	2306	Economy	6700.00
0005433250939	2306	Economy	6700.00
0005433250957	2306	Economy	6700.00
0005434906698	2306	Economy	6700.00
0005434906738	2306	Economy	6700.00
0005434906709	2306	Economy	6700.00
0005434906726	2306	Economy	6700.00
0005434906699	2306	Economy	6700.00
0005434906715	2306	Economy	6700.00
0005434906732	2306	Economy	6700.00
0005433250964	2306	Economy	6700.00
0005433250927	2306	Economy	6700.00
0005434906704	2306	Economy	6700.00
0005434906740	2306	Economy	6700.00
0005434906746	2306	Economy	6700.00
0005434906736	2306	Economy	6700.00
0005434906735	2306	Economy	6700.00
0005434906741	2306	Economy	6700.00
0005434906706	2306	Economy	6700.00
0005434906697	2306	Economy	6700.00
0005434906737	2306	Economy	6700.00
0005434906718	2306	Economy	6700.00
0005433250949	2306	Economy	6700.00
0005434906705	2306	Economy	6700.00
0005434906748	2306	Economy	6700.00
0005434906723	2306	Economy	6700.00
0005433251004	2306	Economy	6700.00
0005434906693	2306	Economy	6700.00
0005434906745	2306	Economy	6700.00
0005434906733	2306	Economy	6700.00
0005433251005	2306	Economy	6700.00
0005433251125	25581	Business	20200.00
0005433251145	25581	Business	20200.00
0005433251124	25581	Business	20200.00
0005433251134	25581	Business	20200.00
0005433251127	25581	Business	20200.00
0005433251137	25581	Economy	6700.00
0005433251118	25581	Economy	6700.00
0005433251126	25581	Economy	7400.00
0005433251128	25581	Economy	6700.00
0005433251146	25581	Economy	6700.00
0005433251132	25581	Economy	6700.00
0005433400950	25581	Economy	6700.00
0005433251129	25581	Economy	6700.00
0005433251131	25581	Economy	6700.00
0005433251147	25581	Economy	6700.00
0005433251148	25581	Economy	6700.00
0005433251123	25581	Economy	6700.00
0005433251138	25581	Economy	6700.00
0005433251130	25581	Economy	6700.00
0005433251121	25581	Economy	6700.00
0005433251140	25581	Economy	6700.00
0005433251122	25581	Economy	6700.00
0005433251120	25581	Economy	6700.00
0005433251133	25581	Economy	6700.00
0005433400949	25581	Economy	6700.00
0005433251144	25581	Economy	6700.00
0005433400948	25581	Economy	6700.00
0005433251139	25581	Economy	6700.00
0005433251143	25581	Economy	6700.00
0005433251141	25581	Economy	6700.00
0005433251142	25581	Economy	6700.00
0005433251119	25581	Economy	6700.00
0005433251135	25581	Economy	6700.00
0005433251136	25581	Economy	6700.00
0005432620880	2509	Economy	12400.00
0005432620887	2509	Economy	12400.00
0005432620875	2509	Economy	12400.00
0005432620885	2509	Economy	12400.00
0005432620874	2509	Economy	12400.00
0005432620881	2509	Economy	12400.00
0005432620879	2509	Economy	12400.00
0005432862162	2509	Economy	12400.00
0005432620883	2509	Economy	12400.00
0005432620886	2509	Economy	12400.00
0005432620878	2509	Economy	12400.00
0005432620882	2509	Economy	12400.00
0005432620877	2509	Economy	12400.00
0005432620884	2509	Economy	12400.00
0005432620876	2509	Economy	12400.00
0005432620873	2509	Economy	12400.00
0005432862211	28088	Economy	13600.00
0005432862217	28088	Economy	12400.00
0005432862216	28088	Economy	12400.00
0005432862212	28088	Economy	12400.00
0005432620811	28088	Economy	12400.00
0005432620809	28088	Economy	12400.00
0005432862210	28088	Economy	12400.00
0005432862214	28088	Economy	12400.00
0005432862215	28088	Economy	12400.00
0005432862213	28088	Economy	12400.00
0005432620810	28088	Economy	12400.00
0005434097460	13096	Economy	11300.00
0005434097459	13096	Economy	11300.00
0005434191252	28028	Economy	29900.00
0005434191258	28028	Economy	29900.00
0005434191254	28028	Economy	29900.00
0005434191261	28028	Economy	29900.00
0005434191253	28028	Economy	29900.00
0005434191259	28028	Economy	29900.00
0005434191256	28028	Economy	29900.00
0005434191257	28028	Economy	29900.00
0005434191260	28028	Economy	29900.00
0005434191251	28028	Economy	29900.00
0005434191255	28028	Economy	29900.00
0005433452715	31076	Economy	8400.00
0005433452714	31076	Economy	8400.00
0005433454840	31428	Economy	8400.00
0005433454839	31428	Economy	8400.00
0005433134057	12007	Economy	6600.00
0005434142561	29869	Economy	7200.00
0005433134087	29869	Economy	7200.00
0005433134085	29869	Economy	6600.00
0005434142563	29869	Economy	6600.00
0005434184641	29869	Economy	6600.00
0005433134086	29869	Economy	6600.00
0005433131655	29869	Economy	6600.00
0005433134088	29869	Economy	6600.00
0005433131659	29869	Economy	6600.00
0005433131654	29869	Economy	6600.00
0005434142564	29869	Economy	6600.00
0005434183557	29869	Economy	6600.00
0005434183556	29869	Economy	6600.00
0005434142562	29869	Economy	6600.00
0005433131658	29869	Economy	6600.00
0005433131656	29869	Economy	6600.00
0005434184642	29869	Economy	6600.00
0005433131657	29869	Economy	6600.00
0005433134084	29869	Economy	6600.00
0005435697008	16468	Economy	19900.00
0005435696998	16468	Economy	19900.00
0005435696992	16468	Economy	19900.00
0005435696991	16468	Economy	18100.00
0005435697009	16468	Economy	18100.00
0005435696993	16468	Economy	18100.00
0005435697005	16468	Economy	18100.00
0005435697004	16468	Economy	18100.00
0005435697001	16468	Economy	18100.00
0005435696989	16468	Economy	18100.00
0005435697011	16468	Economy	18100.00
0005435935001	16468	Economy	18100.00
0005435696999	16468	Economy	18100.00
0005435696996	16468	Economy	18100.00
0005435697007	16468	Economy	18100.00
0005435696995	16468	Economy	18100.00
0005435696997	16468	Economy	18100.00
0005435696990	16468	Economy	18100.00
0005435697013	16468	Economy	18100.00
0005435935002	16468	Economy	18100.00
0005435697006	16468	Economy	18100.00
0005435696988	16468	Economy	18100.00
0005435697014	16468	Economy	18100.00
0005435696994	16468	Economy	18100.00
0005435697000	16468	Economy	18100.00
0005435697012	16468	Economy	18100.00
0005435696987	16468	Economy	18100.00
0005435697010	16468	Economy	18100.00
0005435697003	16468	Economy	18100.00
0005435696986	16468	Economy	18100.00
0005435697002	16468	Economy	18100.00
0005435696891	24710	Economy	19900.00
0005435935013	24710	Economy	18100.00
0005435696909	24710	Economy	18100.00
0005435696880	24710	Economy	18100.00
0005435696845	24710	Economy	18100.00
0005435696872	24710	Economy	18100.00
0005435696848	24710	Economy	18100.00
0005435696849	24710	Economy	18100.00
0005435935012	24710	Economy	18100.00
0005433724751	18812	Economy	4400.00
0005433724752	18812	Economy	4400.00
0005433724748	18812	Economy	4400.00
0005433724749	18812	Economy	4400.00
0005433724750	18812	Economy	4400.00
0005432968815	21601	Economy	4400.00
0005432968817	21601	Economy	4400.00
0005432968816	21601	Economy	4400.00
0005433724739	21601	Economy	4400.00
0005434137226	7346	Business	23100.00
0005434137206	7346	Business	23100.00
0005434137219	7346	Business	23100.00
0005434137189	7346	Business	23100.00
0005434137243	7346	Business	23100.00
0005434137265	7346	Business	23100.00
0005434087459	7346	Business	23100.00
0005434137198	7346	Business	23100.00
0005434137181	7346	Business	23100.00
0005434137253	7346	Business	23100.00
0005434137205	7346	Business	23100.00
0005434137215	7346	Business	23100.00
0005434137263	7346	Economy	7700.00
0005434137224	7346	Economy	7700.00
0005434137194	7346	Economy	7700.00
0005434137259	7346	Economy	7700.00
0005434137229	7346	Economy	7700.00
0005434137177	7346	Economy	7700.00
0005434137257	7346	Economy	7700.00
0005434137264	7346	Economy	7700.00
0005434137185	7346	Economy	7700.00
0005434137213	7346	Economy	7700.00
0005434137240	7346	Economy	8500.00
0005434137218	7346	Economy	8500.00
0005434137208	7346	Economy	8500.00
0005434137241	7346	Economy	8500.00
0005434137212	7346	Economy	8500.00
0005434137242	7346	Economy	7700.00
0005434137222	7346	Economy	7700.00
0005434137236	7346	Economy	7700.00
0005434137232	7346	Economy	7700.00
0005434137238	7346	Economy	7700.00
0005434137200	7346	Economy	7700.00
0005434137190	7346	Economy	7700.00
0005434137244	7346	Economy	7700.00
0005434137220	7346	Economy	7700.00
0005434137192	7346	Economy	7700.00
0005434137201	7346	Economy	7700.00
0005434137247	7346	Economy	7700.00
0005434137209	7346	Economy	7700.00
0005434137250	7346	Economy	7700.00
0005434137196	7346	Economy	7700.00
0005434137221	7346	Economy	7700.00
0005434137186	7346	Economy	7700.00
0005434137210	7346	Economy	7700.00
0005434137228	7346	Economy	7700.00
0005434137256	7346	Economy	7700.00
0005434137262	7346	Economy	7700.00
0005434137266	7346	Economy	7700.00
0005434137255	7346	Economy	7700.00
0005434137251	7346	Economy	7700.00
0005434087460	7346	Economy	7700.00
0005434137207	7346	Economy	7700.00
0005434137178	7346	Economy	7700.00
0005434137197	7346	Economy	7700.00
0005434137246	7346	Economy	7700.00
0005434137203	7346	Economy	7700.00
0005434137233	7346	Economy	7700.00
0005434087458	7346	Economy	7700.00
0005434137230	7346	Economy	7700.00
0005434137234	7346	Economy	7700.00
0005434137176	7346	Economy	7700.00
0005434137258	7346	Economy	7700.00
0005434137245	7346	Economy	7700.00
0005434137183	7346	Economy	7700.00
0005434137249	7346	Economy	7700.00
0005434137179	7346	Economy	7700.00
0005434137223	7346	Economy	7700.00
0005434137239	7346	Economy	7700.00
0005434137252	7346	Economy	7700.00
0005434137182	7346	Economy	7700.00
0005434137235	7346	Economy	7700.00
0005434137254	7346	Economy	7700.00
0005434137261	7346	Economy	7700.00
0005434137227	7346	Economy	7700.00
0005434137211	7346	Economy	7700.00
0005434137187	7346	Economy	7700.00
0005434137180	7346	Economy	7700.00
0005434137260	7346	Economy	7700.00
0005434137237	7346	Economy	7700.00
0005434137267	7346	Economy	7700.00
0005434137225	7346	Economy	7700.00
0005434137184	7346	Economy	7700.00
0005434137199	7346	Economy	7700.00
0005434137217	7346	Economy	7700.00
0005434137248	7346	Economy	7700.00
0005434137193	7346	Economy	7700.00
0005434137214	7346	Economy	7700.00
0005434137191	7346	Economy	7700.00
0005434137231	7346	Economy	7700.00
0005434137204	7346	Economy	7700.00
0005434137216	7346	Economy	7700.00
0005434137202	7346	Economy	7700.00
0005434137188	7346	Economy	7700.00
0005434137195	7346	Economy	7700.00
0005434087430	28572	Economy	7700.00
0005434087433	28572	Economy	7700.00
0005435808115	1903	Economy	23900.00
0005433407480	1903	Economy	23900.00
0005435808114	1903	Economy	23900.00
0005435808123	1903	Economy	21700.00
0005434610188	1903	Economy	21700.00
0005435808118	1903	Economy	21700.00
0005435808120	1903	Economy	21700.00
0005435808117	1903	Economy	21700.00
0005435808121	1903	Economy	21700.00
0005435808119	1903	Economy	21700.00
0005435808122	1903	Economy	21700.00
0005435808116	1903	Economy	21700.00
0005435808113	1903	Economy	21700.00
0005434610189	1903	Economy	21700.00
0005434503461	16676	Economy	6900.00
0005434503495	16676	Economy	6900.00
0005434503462	16676	Economy	6900.00
0005434503528	16676	Economy	6900.00
0005434503686	22914	Economy	7600.00
0005434503684	22914	Economy	7600.00
0005434503692	22914	Economy	6900.00
0005434503667	22914	Economy	6900.00
0005434503665	22914	Economy	6900.00
0005434503681	22914	Economy	6900.00
0005434503683	22914	Economy	6900.00
0005434503690	22914	Economy	6900.00
0005434503695	22914	Economy	6900.00
0005434503671	22914	Economy	6900.00
0005434503662	22914	Economy	6900.00
0005434503687	22914	Economy	6900.00
0005434503672	22914	Economy	6900.00
0005434503694	22914	Economy	6900.00
0005434503679	22914	Economy	6900.00
0005434503664	22914	Economy	6900.00
0005434503668	22914	Economy	6900.00
0005434503689	22914	Economy	6900.00
0005434503676	22914	Economy	6900.00
0005434503663	22914	Economy	6900.00
0005434503697	22914	Economy	6900.00
0005434503673	22914	Economy	6900.00
0005434503691	22914	Economy	6900.00
0005434503682	22914	Economy	6900.00
0005434503696	22914	Economy	6900.00
0005434503660	22914	Economy	6900.00
0005434503674	22914	Economy	6900.00
0005434503661	22914	Economy	6900.00
0005434503678	22914	Economy	6900.00
0005434503693	22914	Economy	6900.00
0005434503688	22914	Economy	6900.00
0005434503666	22914	Economy	6900.00
0005434503669	22914	Economy	6900.00
0005434503680	22914	Economy	6900.00
0005434503675	22914	Economy	6900.00
0005434503698	22914	Economy	6900.00
0005434503685	22914	Economy	6900.00
0005434503670	22914	Economy	6900.00
0005434503699	22914	Economy	6900.00
0005434503677	22914	Economy	6900.00
0005435078167	2186	Economy	7700.00
0005435078168	2186	Economy	7000.00
0005435078162	2186	Economy	7000.00
0005435078173	2186	Economy	7000.00
0005435078161	2186	Economy	7000.00
0005435078172	2186	Economy	7000.00
0005435078166	2186	Economy	7000.00
0005435078169	2186	Economy	7000.00
0005435078171	2186	Economy	7000.00
0005435078163	2186	Economy	7000.00
0005435078159	2186	Economy	7000.00
0005435078165	2186	Economy	7000.00
0005435078160	2186	Economy	7000.00
0005435078170	2186	Economy	7000.00
0005435078164	2186	Economy	7000.00
0005435078174	2186	Economy	7000.00
0005435078101	24347	Economy	7700.00
0005433266614	24347	Economy	7000.00
0005433266619	24347	Economy	7000.00
0005433266620	24347	Economy	7000.00
0005433266616	24347	Economy	7000.00
0005433266623	24347	Economy	7000.00
0005433266617	24347	Economy	7000.00
0005433266622	24347	Economy	7000.00
0005435078108	24347	Economy	7000.00
0005433266618	24347	Economy	7000.00
0005433266615	24347	Economy	7000.00
0005435078106	24347	Economy	7000.00
0005433266621	24347	Economy	7000.00
0005434988612	6629	Economy	10800.00
0005434988620	6629	Economy	10800.00
0005434988614	6629	Economy	9800.00
0005434988609	6629	Economy	9800.00
0005434988610	6629	Economy	9800.00
0005434988611	6629	Economy	9800.00
0005434988621	6629	Economy	9800.00
0005435803230	6629	Economy	9800.00
0005435464473	6629	Economy	9800.00
0005434988616	6629	Economy	9800.00
0005434988615	6629	Economy	9800.00
0005435803229	6629	Economy	9800.00
0005434988617	6629	Economy	9800.00
0005434988613	6629	Economy	9800.00
0005434988619	6629	Economy	9800.00
0005435464472	6629	Economy	9800.00
0005434988618	6629	Economy	9800.00
0005434988608	6629	Economy	9800.00
0005435803228	6629	Economy	9800.00
0005435464484	23612	Economy	9800.00
0005435464486	23612	Economy	9800.00
0005435464485	23612	Economy	9800.00
0005433449726	30466	Business	9900.00
0005433449724	30466	Business	9900.00
0005432382733	30466	Business	9900.00
0005432382753	30466	Business	9900.00
0005433449719	30466	Business	9900.00
0005433449736	30466	Business	9900.00
0005432382764	30466	Business	9900.00
0005432382758	30466	Economy	3300.00
0005433449718	30466	Economy	3300.00
0005432382763	30466	Economy	3300.00
0005432382738	30466	Economy	3300.00
0005433453742	30466	Economy	3300.00
0005433453741	30466	Economy	3300.00
0005433453740	30466	Economy	3300.00
0005433449738	30466	Economy	3300.00
0005432382750	30466	Economy	3600.00
0005433449733	30466	Economy	3600.00
0005432382727	30466	Economy	3600.00
0005432382730	30466	Economy	3300.00
0005433449717	30466	Economy	3300.00
0005432382761	30466	Economy	3300.00
0005433449723	30466	Economy	3300.00
0005432382736	30466	Economy	3300.00
0005433454851	30466	Economy	3300.00
0005432382749	30466	Economy	3300.00
0005432382743	30466	Economy	3300.00
0005432382741	30466	Economy	3300.00
0005433449731	30466	Economy	3300.00
0005432382729	30466	Economy	3300.00
0005432382735	30466	Economy	3300.00
0005432382766	30466	Economy	3300.00
0005433449735	30466	Economy	3300.00
0005432382737	30466	Economy	3300.00
0005433449737	30466	Economy	3300.00
0005433449722	30466	Economy	3300.00
0005432382754	30466	Economy	3300.00
0005433449725	30466	Economy	3300.00
0005433449728	30466	Economy	3300.00
0005432382757	30466	Economy	3300.00
0005432382752	30466	Economy	3300.00
0005432382756	30466	Economy	3300.00
0005432382734	30466	Economy	3300.00
0005432382745	30466	Economy	3300.00
0005432382762	30466	Economy	3300.00
0005432382732	30466	Economy	3300.00
0005432382739	30466	Economy	3300.00
0005432382751	30466	Economy	3300.00
0005433449730	30466	Economy	3300.00
0005432382742	30466	Economy	3300.00
0005433449721	30466	Economy	3300.00
0005432382755	30466	Economy	3300.00
0005432382765	30466	Economy	3300.00
0005433449732	30466	Economy	3300.00
0005432382746	30466	Economy	3300.00
0005432382760	30466	Economy	3300.00
0005432382747	30466	Economy	3300.00
0005433449720	30466	Economy	3300.00
0005432382728	30466	Economy	3300.00
0005432382740	30466	Economy	3300.00
0005432382731	30466	Economy	3300.00
0005433449727	30466	Economy	3300.00
0005433449734	30466	Economy	3300.00
0005432382748	30466	Economy	3300.00
0005432382744	30466	Economy	3300.00
0005433449729	30466	Economy	3300.00
0005432382759	30466	Economy	3300.00
0005433449602	31308	Economy	3600.00
0005433449603	31308	Economy	3600.00
0005433449591	31308	Economy	3300.00
0005433449649	31308	Economy	3300.00
0005433449648	31308	Economy	3300.00
0005432382492	31308	Economy	3300.00
0005433449664	31308	Economy	3300.00
0005432382491	31308	Economy	3300.00
0005435548440	26466	Economy	23800.00
0005435548446	26466	Economy	23800.00
0005435548444	26466	Economy	23800.00
0005435548442	26466	Economy	23800.00
0005435548447	26466	Economy	23800.00
0005435548441	26466	Economy	23800.00
0005435548449	26466	Economy	23800.00
0005435548448	26466	Economy	23800.00
0005435548443	26466	Economy	23800.00
0005435548445	26466	Economy	23800.00
0005435304098	10796	Economy	15600.00
0005435302152	29707	Economy	17100.00
0005433126796	29707	Economy	17100.00
0005433129227	29707	Economy	15600.00
0005435302151	29707	Economy	15600.00
0005433126798	29707	Economy	15600.00
0005433129231	29707	Economy	15600.00
0005435302149	29707	Economy	15600.00
0005435299728	29707	Economy	15600.00
0005433126797	29707	Economy	15600.00
0005433129228	29707	Economy	15600.00
0005433126799	29707	Economy	15600.00
0005435299726	29707	Economy	15600.00
0005433126795	29707	Economy	15600.00
0005433129226	29707	Economy	15600.00
0005433129229	29707	Economy	15600.00
0005435299725	29707	Economy	15600.00
0005435302150	29707	Economy	15600.00
0005435299727	29707	Economy	15600.00
0005433129230	29707	Economy	15600.00
0005434287045	2382	Economy	17200.00
0005434287034	2382	Economy	17200.00
0005434287048	2382	Economy	17200.00
0005434287047	2382	Economy	17200.00
0005434287044	2382	Economy	15700.00
0005434287030	2382	Economy	15700.00
0005433109875	2382	Economy	15700.00
0005434287040	2382	Economy	15700.00
0005432264447	2382	Economy	15700.00
0005433109837	2382	Economy	15700.00
0005434287035	2382	Economy	15700.00
0005434287039	2382	Economy	15700.00
0005434287033	2382	Economy	15700.00
0005434287036	2382	Economy	15700.00
0005433109839	2382	Economy	15700.00
0005432264446	2382	Economy	15700.00
0005434287037	2382	Economy	15700.00
0005434287049	2382	Economy	15700.00
0005433109850	2382	Economy	15700.00
0005434287029	2382	Economy	15700.00
0005434287031	2382	Economy	15700.00
0005433109848	2382	Economy	15700.00
0005432264450	2382	Economy	15700.00
0005434287042	2382	Economy	15700.00
0005434287050	2382	Economy	15700.00
0005434287041	2382	Economy	15700.00
0005432264448	2382	Economy	15700.00
0005434287046	2382	Economy	15700.00
0005433109874	2382	Economy	15700.00
0005434287043	2382	Economy	15700.00
0005433109838	2382	Economy	15700.00
0005434287038	2382	Economy	15700.00
0005433109843	2382	Economy	15700.00
0005433109873	2382	Economy	15700.00
0005432264449	2382	Economy	15700.00
0005433109847	2382	Economy	15700.00
0005434287032	2382	Economy	15700.00
0005433109851	2382	Economy	15700.00
0005433109917	26824	Economy	15700.00
0005434286934	26824	Economy	15700.00
0005434286933	26824	Economy	15700.00
0005433109921	26824	Economy	15700.00
0005433109913	26824	Economy	15700.00
0005433109916	26824	Economy	15700.00
0005434286911	26824	Economy	15700.00
0005433109918	26824	Economy	15700.00
0005434286912	26824	Economy	15700.00
0005433109915	26824	Economy	15700.00
0005433109914	26824	Economy	15700.00
0005434286910	26824	Economy	15700.00
0005434286908	26824	Economy	15700.00
0005433109923	26824	Economy	15700.00
0005433109922	26824	Economy	15700.00
0005434286943	26824	Economy	15700.00
0005434286915	26824	Economy	15700.00
0005433109920	26824	Economy	15700.00
0005433109919	26824	Economy	15700.00
0005433109912	26824	Economy	15700.00
0005435856159	25468	Economy	22800.00
0005435856157	25468	Economy	22800.00
0005435856156	25468	Economy	22800.00
0005435856155	25468	Economy	22800.00
0005435856158	25468	Economy	22800.00
0005434520176	6098	Economy	24600.00
0005434520166	6098	Economy	24600.00
0005434520182	6098	Economy	24600.00
0005434520184	6098	Economy	22300.00
0005434520153	6098	Economy	22300.00
0005434520178	6098	Economy	22300.00
0005434520169	6098	Economy	22300.00
0005434520183	6098	Economy	22300.00
0005434520159	6098	Economy	22300.00
0005434520158	6098	Economy	22300.00
0005434520156	6098	Economy	22300.00
0005434520161	6098	Economy	22300.00
0005434520170	6098	Economy	22300.00
0005434520175	6098	Economy	22300.00
0005434520173	6098	Economy	22300.00
0005434520165	6098	Economy	22300.00
0005434520179	6098	Economy	22300.00
0005434520164	6098	Economy	22300.00
0005434520167	6098	Economy	22300.00
0005434520160	6098	Economy	22300.00
0005434520168	6098	Economy	22300.00
0005434520172	6098	Economy	22300.00
0005434520174	6098	Economy	22300.00
0005434520162	6098	Economy	22300.00
0005434520181	6098	Economy	22300.00
0005434520163	6098	Economy	22300.00
0005434520180	6098	Economy	22300.00
0005434520155	6098	Economy	22300.00
0005434520154	6098	Economy	22300.00
0005434520171	6098	Economy	22300.00
0005434520185	6098	Economy	22300.00
0005434520157	6098	Economy	22300.00
0005434520177	6098	Economy	22300.00
0005434520152	6098	Economy	22300.00
0005435263511	27629	Business	89800.00
0005435263525	27629	Business	89800.00
0005435263531	27629	Business	89800.00
0005435263524	27629	Business	89800.00
0005435263514	27629	Business	89800.00
0005435263512	27629	Economy	29900.00
0005435263517	27629	Economy	29900.00
0005435263515	27629	Economy	29900.00
0005435263530	27629	Economy	29900.00
0005435263519	27629	Economy	32900.00
0005433650395	27629	Economy	32900.00
0005435263526	27629	Economy	32900.00
0005435263528	27629	Economy	32900.00
0005435263534	27629	Economy	29900.00
0005435263509	27629	Economy	29900.00
0005433650366	27629	Economy	29900.00
0005435263510	27629	Economy	29900.00
0005435263506	27629	Economy	29900.00
0005435263505	27629	Economy	29900.00
0005435263532	27629	Economy	29900.00
0005435263535	27629	Economy	29900.00
0005435263523	27629	Economy	29900.00
0005435263503	27629	Economy	29900.00
0005435263520	27629	Economy	29900.00
0005435263518	27629	Economy	29900.00
0005435263508	27629	Economy	29900.00
0005435263533	27629	Economy	29900.00
0005435263516	27629	Economy	29900.00
0005435263522	27629	Economy	29900.00
0005433650396	27629	Economy	29900.00
0005435263507	27629	Economy	29900.00
0005435263529	27629	Economy	29900.00
0005435263513	27629	Economy	29900.00
0005435263504	27629	Economy	29900.00
0005435263521	27629	Economy	29900.00
0005435263527	27629	Economy	29900.00
0005433868006	4759	Economy	19400.00
0005433867983	4759	Economy	19400.00
0005433867987	4759	Economy	19400.00
0005433867999	4759	Economy	17600.00
0005433868002	4759	Economy	17600.00
0005433868009	4759	Economy	17600.00
0005433867980	4759	Economy	17600.00
0005433867978	4759	Economy	17600.00
0005433868003	4759	Economy	17600.00
0005433867996	4759	Economy	17600.00
0005433867971	4759	Economy	17600.00
0005433867993	4759	Economy	17600.00
0005433867992	4759	Economy	17600.00
0005433867975	4759	Economy	17600.00
0005433867991	4759	Economy	17600.00
0005433867979	4759	Economy	17600.00
0005433867984	4759	Economy	17600.00
0005433868004	4759	Economy	17600.00
0005433867976	4759	Economy	17600.00
0005433868011	4759	Economy	17600.00
0005433868005	4759	Economy	17600.00
0005433868001	4759	Economy	17600.00
0005433867982	4759	Economy	17600.00
0005433867970	4759	Economy	17600.00
0005433868008	4759	Economy	17600.00
0005433867972	4759	Economy	17600.00
0005433867988	4759	Economy	17600.00
0005433867985	4759	Economy	17600.00
0005433867995	4759	Economy	17600.00
0005433867973	4759	Economy	17600.00
0005433867977	4759	Economy	17600.00
0005433867989	4759	Economy	17600.00
0005433867974	4759	Economy	17600.00
0005433868010	4759	Economy	17600.00
0005433867981	4759	Economy	17600.00
0005433867994	4759	Economy	17600.00
0005433868007	4759	Economy	17600.00
0005433867990	4759	Economy	17600.00
0005433867998	4759	Economy	17600.00
0005433868000	4759	Economy	17600.00
0005433867997	4759	Economy	17600.00
0005433867986	4759	Economy	17600.00
0005435860449	32582	Economy	17600.00
0005433867798	32582	Economy	17600.00
0005435860448	32582	Economy	17600.00
0005433867819	32582	Economy	17600.00
0005434663254	3403	Economy	24800.00
0005434663251	3403	Economy	22600.00
0005434663249	3403	Economy	22600.00
0005434460482	3403	Economy	22600.00
0005434663262	3403	Economy	22600.00
0005434460480	3403	Economy	22600.00
0005434663255	3403	Economy	22600.00
0005434461622	3403	Economy	22600.00
0005434663260	3403	Economy	22600.00
0005434663256	3403	Economy	22600.00
0005434663261	3403	Economy	22600.00
0005434663257	3403	Economy	22600.00
0005434460481	3403	Economy	22600.00
0005434663252	3403	Economy	22600.00
0005434460483	3403	Economy	22600.00
0005434461621	3403	Economy	22600.00
0005434663250	3403	Economy	22600.00
0005434663253	3403	Economy	22600.00
0005434461623	3403	Economy	22600.00
0005434663259	3403	Economy	22600.00
0005434663258	3403	Economy	22600.00
0005435911369	12498	Economy	22600.00
0005435911366	12498	Economy	22600.00
0005434663180	12498	Economy	22600.00
0005435911365	12498	Economy	22600.00
0005435911364	12498	Economy	22600.00
0005435911367	12498	Economy	22600.00
0005434663181	12498	Economy	22600.00
0005435911368	12498	Economy	22600.00
0005435860449	14486	Economy	18500.00
0005433867798	14486	Economy	16800.00
0005433867819	14486	Economy	16800.00
0005435860448	14486	Economy	16800.00
0005433867949	32700	Economy	18500.00
0005433867935	32700	Economy	18500.00
0005433867940	32700	Economy	18500.00
0005433867958	32700	Economy	16800.00
0005433867951	32700	Economy	16800.00
0005433867942	32700	Economy	16800.00
0005433867937	32700	Economy	16800.00
0005433867931	32700	Economy	16800.00
0005433867952	32700	Economy	16800.00
0005433867941	32700	Economy	16800.00
0005433867934	32700	Economy	16800.00
0005433867950	32700	Economy	16800.00
0005433867967	32700	Economy	16800.00
0005433867961	32700	Economy	16800.00
0005433867944	32700	Economy	16800.00
0005433867965	32700	Economy	16800.00
0005433867943	32700	Economy	16800.00
0005433867964	32700	Economy	16800.00
0005433867968	32700	Economy	16800.00
0005433867963	32700	Economy	16800.00
0005433867938	32700	Economy	16800.00
0005433867962	32700	Economy	16800.00
0005433867959	32700	Economy	16800.00
0005433867969	32700	Economy	16800.00
0005433867936	32700	Economy	16800.00
0005433867960	32700	Economy	16800.00
0005433867966	32700	Economy	16800.00
0005433867945	32700	Economy	16800.00
0005433867957	32700	Economy	16800.00
0005433867948	32700	Economy	16800.00
0005433867947	32700	Economy	16800.00
0005433867953	32700	Economy	16800.00
0005433867932	32700	Economy	16800.00
0005433867956	32700	Economy	16800.00
0005433867954	32700	Economy	16800.00
0005433867955	32700	Economy	16800.00
0005433867933	32700	Economy	16800.00
0005433867939	32700	Economy	16800.00
0005433867946	32700	Economy	16800.00
0005432798957	12098	Economy	4400.00
0005432799007	12098	Economy	4400.00
0005432799008	12098	Economy	4400.00
0005432798958	12098	Economy	4400.00
0005432799101	14778	Economy	4900.00
0005432799122	14778	Economy	4900.00
0005432799107	14778	Economy	4900.00
0005432799113	14778	Economy	4900.00
0005432799102	14778	Economy	4400.00
0005432799111	14778	Economy	4400.00
0005432799104	14778	Economy	4400.00
0005432799124	14778	Economy	4400.00
0005432799098	14778	Economy	4400.00
0005432799106	14778	Economy	4400.00
0005432799116	14778	Economy	4400.00
0005432799100	14778	Economy	4400.00
0005432799099	14778	Economy	4400.00
0005432799108	14778	Economy	4400.00
0005432799125	14778	Economy	4400.00
0005432799105	14778	Economy	4400.00
0005432799103	14778	Economy	4400.00
0005432799114	14778	Economy	4400.00
0005432799115	14778	Economy	4400.00
0005432799118	14778	Economy	4400.00
0005432799121	14778	Economy	4400.00
0005432799123	14778	Economy	4400.00
0005432799110	14778	Economy	4400.00
0005432799109	14778	Economy	4400.00
0005432799120	14778	Economy	4400.00
0005432799112	14778	Economy	4400.00
0005432799117	14778	Economy	4400.00
0005432799119	14778	Economy	4400.00
0005434407048	7029	Business	49100.00
0005434407059	7029	Business	49100.00
0005434299298	7029	Business	49100.00
0005434407033	7029	Business	49100.00
0005434407060	7029	Business	49100.00
0005434407027	7029	Business	49100.00
0005434299313	7029	Business	49100.00
0005434299305	7029	Business	49100.00
0005434407032	7029	Economy	16400.00
0005432153856	7029	Economy	16400.00
0005434407053	7029	Economy	16400.00
0005432153863	7029	Economy	16400.00
0005434407025	7029	Economy	16400.00
0005434407042	7029	Economy	16400.00
0005434407086	7029	Economy	16400.00
0005434299308	7029	Economy	16400.00
0005432153859	7029	Economy	16400.00
0005434407073	7029	Economy	16400.00
0005432108222	7029	Economy	16400.00
0005434299295	7029	Economy	16400.00
0005432153860	7029	Economy	16400.00
0005434407077	7029	Economy	16400.00
0005434407028	7029	Economy	16400.00
0005434407026	7029	Economy	16400.00
0005434299311	7029	Economy	16400.00
0005434299314	7029	Economy	16400.00
0005434407074	7029	Economy	16400.00
0005435293054	7029	Economy	16400.00
0005434407036	7029	Economy	16400.00
0005434407041	7029	Economy	16400.00
0005434407057	7029	Economy	16400.00
0005434407072	7029	Economy	16400.00
0005434299301	7029	Economy	16400.00
0005434407069	7029	Economy	16400.00
0005435293055	7029	Economy	16400.00
0005432153862	7029	Economy	16400.00
0005434299289	7029	Economy	16400.00
0005434407040	7029	Economy	16400.00
0005434407081	7029	Economy	16400.00
0005434407070	7029	Economy	16400.00
0005434407068	7029	Economy	16400.00
0005434407037	7029	Economy	16400.00
0005434407031	7029	Economy	18000.00
0005434407052	7029	Economy	18000.00
0005434407063	7029	Economy	18000.00
0005434299299	7029	Economy	18000.00
0005434299310	7029	Economy	16400.00
0005434299312	7029	Economy	16400.00
0005434299290	7029	Economy	16400.00
0005434299309	7029	Economy	16400.00
0005434299291	7029	Economy	16400.00
0005434407035	7029	Economy	16400.00
0005435293050	7029	Economy	16400.00
0005434299297	7029	Economy	16400.00
0005434407084	7029	Economy	16400.00
0005434299302	7029	Economy	16400.00
0005434407062	7029	Economy	16400.00
0005434407024	7029	Economy	16400.00
0005434407051	7029	Economy	16400.00
0005434407030	7029	Economy	16400.00
0005434299303	7029	Economy	16400.00
0005434407034	7029	Economy	16400.00
0005434407044	7029	Economy	16400.00
0005434407078	7029	Economy	16400.00
0005434407050	7029	Economy	16400.00
0005434299304	7029	Economy	16400.00
0005434299294	7029	Economy	16400.00
0005432108221	7029	Economy	16400.00
0005434407065	7029	Economy	16400.00
0005435293049	7029	Economy	16400.00
0005434299296	7029	Economy	16400.00
0005434299300	7029	Economy	16400.00
0005434407075	7029	Economy	16400.00
0005434407067	7029	Economy	16400.00
0005434407079	7029	Economy	16400.00
0005434407056	7029	Economy	16400.00
0005434407082	7029	Economy	16400.00
0005434407029	7029	Economy	16400.00
0005434407066	7029	Economy	16400.00
0005434407038	7029	Economy	16400.00
0005434299292	7029	Economy	16400.00
0005434407058	7029	Economy	16400.00
0005434299306	7029	Economy	16400.00
0005434407043	7029	Economy	16400.00
0005434407047	7029	Economy	16400.00
0005432108220	7029	Economy	16400.00
0005434407046	7029	Economy	16400.00
0005432153861	7029	Economy	16400.00
0005434407049	7029	Economy	16400.00
0005434407085	7029	Economy	16400.00
0005434407071	7029	Economy	16400.00
0005435293056	7029	Economy	16400.00
0005434407087	7029	Economy	16400.00
0005434299307	7029	Economy	16400.00
0005434407083	7029	Economy	16400.00
0005434407080	7029	Economy	16400.00
0005434407054	7029	Economy	16400.00
0005434407061	7029	Economy	16400.00
0005434407045	7029	Economy	16400.00
0005432153858	7029	Economy	16400.00
0005432153857	7029	Economy	16400.00
0005434407076	7029	Economy	16400.00
0005434407064	7029	Economy	16400.00
0005435293063	7029	Economy	16400.00
0005434407039	7029	Economy	16400.00
0005434407055	7029	Economy	16400.00
0005434299293	7029	Economy	16400.00
0005432058336	26927	Business	49100.00
0005432058334	26927	Business	49100.00
0005434299170	26927	Business	49100.00
0005434299171	26927	Economy	16400.00
0005434299148	26927	Economy	16400.00
0005434299163	26927	Economy	16400.00
0005434299173	26927	Economy	16400.00
0005434299157	26927	Economy	18000.00
0005434299167	26927	Economy	16400.00
0005432058333	26927	Economy	16400.00
0005434299164	26927	Economy	16400.00
0005434299182	26927	Economy	16400.00
0005432058332	26927	Economy	16400.00
0005434299258	26927	Economy	16400.00
0005434299187	26927	Economy	16400.00
0005432058335	26927	Economy	16400.00
0005432603888	6433	Economy	16500.00
0005432603900	6433	Economy	16500.00
0005432603886	6433	Economy	16500.00
0005432603905	6433	Economy	16500.00
0005434512057	6433	Economy	15000.00
0005432603907	6433	Economy	15000.00
0005432603891	6433	Economy	15000.00
0005432603890	6433	Economy	15000.00
0005434512056	6433	Economy	15000.00
0005434512053	6433	Economy	15000.00
0005432603889	6433	Economy	15000.00
0005434512058	6433	Economy	15000.00
0005432603908	6433	Economy	15000.00
0005434512055	6433	Economy	15000.00
0005432603904	6433	Economy	15000.00
0005432603916	6433	Economy	15000.00
0005432603917	6433	Economy	15000.00
0005432603924	6433	Economy	15000.00
0005434512054	6433	Economy	15000.00
0005432603885	6433	Economy	15000.00
0005432603895	6433	Economy	15000.00
0005432603892	6433	Economy	15000.00
0005432603925	6433	Economy	15000.00
0005432603922	6433	Economy	15000.00
0005432603913	6433	Economy	15000.00
0005434512052	6433	Economy	15000.00
0005432603914	6433	Economy	15000.00
0005432603906	6433	Economy	15000.00
0005432603894	6433	Economy	15000.00
0005432603899	6433	Economy	15000.00
0005432603910	6433	Economy	15000.00
0005432603923	6433	Economy	15000.00
0005432603898	6433	Economy	15000.00
0005432603919	6433	Economy	15000.00
0005432603911	6433	Economy	15000.00
0005432603915	6433	Economy	15000.00
0005432603909	6433	Economy	15000.00
0005432603901	6433	Economy	15000.00
0005432603903	6433	Economy	15000.00
0005432603912	6433	Economy	15000.00
0005432603887	6433	Economy	15000.00
0005432603918	6433	Economy	15000.00
0005432603897	6433	Economy	15000.00
0005432603896	6433	Economy	15000.00
0005432603902	6433	Economy	15000.00
0005434512059	6433	Economy	15000.00
0005432603893	6433	Economy	15000.00
0005432603920	6433	Economy	15000.00
0005432603921	6433	Economy	15000.00
0005434512026	21364	Economy	16500.00
0005432603715	21364	Economy	15000.00
0005434512015	21364	Economy	15000.00
0005435221045	21364	Economy	15000.00
0005432603668	21364	Economy	15000.00
0005434512024	21364	Economy	15000.00
0005434512016	21364	Economy	15000.00
0005435221505	21364	Economy	15000.00
0005435221044	21364	Economy	15000.00
0005435221504	21364	Economy	15000.00
0005434512025	21364	Economy	15000.00
0005433251124	14989	Business	18900.00
0005433251138	14989	Business	18900.00
0005433251119	14989	Economy	6300.00
0005433251130	14989	Economy	6300.00
0005433251146	14989	Economy	6300.00
0005433251143	14989	Economy	6300.00
0005433251125	14989	Economy	6300.00
0005433251134	14989	Economy	6300.00
0005433251132	14989	Economy	6300.00
0005433251147	14989	Economy	6300.00
0005433251123	14989	Economy	6300.00
0005433251136	14989	Economy	6300.00
0005433251120	14989	Economy	6300.00
0005433251139	14989	Economy	6300.00
0005433251144	14989	Economy	6300.00
0005433251127	14989	Economy	6300.00
0005433251121	14989	Economy	6300.00
0005433251142	14989	Economy	6300.00
0005433251137	14989	Economy	6300.00
0005433251145	14989	Economy	6300.00
0005433251133	14989	Economy	6300.00
0005433251129	14989	Economy	6300.00
0005433251148	14989	Economy	6300.00
0005433251128	14989	Economy	6300.00
0005433251126	14989	Economy	6300.00
0005433251118	14989	Economy	6300.00
0005433251140	14989	Economy	6300.00
0005433251131	14989	Economy	6300.00
0005433251135	14989	Economy	6300.00
0005433251122	14989	Economy	6300.00
0005433251141	14989	Economy	6300.00
0005434906642	25841	Business	18900.00
0005433250934	25841	Business	18900.00
0005434906686	25841	Business	18900.00
0005434906670	25841	Business	18900.00
0005434906692	25841	Business	18900.00
0005434906641	25841	Business	18900.00
0005434906664	25841	Business	18900.00
0005434906691	25841	Business	18900.00
0005434906678	25841	Business	18900.00
0005434906676	25841	Economy	6300.00
0005434906683	25841	Economy	6300.00
0005434906663	25841	Economy	6300.00
0005434906648	25841	Economy	6300.00
0005434906668	25841	Economy	6300.00
0005433250942	25841	Economy	6300.00
0005434906667	25841	Economy	6300.00
0005434906655	25841	Economy	6300.00
0005434906681	25841	Economy	6900.00
0005434906688	25841	Economy	6900.00
0005434906671	25841	Economy	6900.00
0005434906643	25841	Economy	6300.00
0005434906674	25841	Economy	6300.00
0005434906677	25841	Economy	6300.00
0005434906687	25841	Economy	6300.00
0005434906673	25841	Economy	6300.00
0005434906666	25841	Economy	6300.00
0005434906654	25841	Economy	6300.00
0005434906682	25841	Economy	6300.00
0005434906637	25841	Economy	6300.00
0005434906638	25841	Economy	6300.00
0005434906636	25841	Economy	6300.00
0005434906650	25841	Economy	6300.00
0005434906679	25841	Economy	6300.00
0005434906649	25841	Economy	6300.00
0005434906661	25841	Economy	6300.00
0005434906672	25841	Economy	6300.00
0005434906684	25841	Economy	6300.00
0005434906680	25841	Economy	6300.00
0005433250951	25841	Economy	6300.00
0005434906656	25841	Economy	6300.00
0005434906658	25841	Economy	6300.00
0005434906669	25841	Economy	6300.00
0005434906675	25841	Economy	6300.00
0005434906657	25841	Economy	6300.00
0005434906652	25841	Economy	6300.00
0005434906639	25841	Economy	6300.00
0005433250937	25841	Economy	6300.00
0005434906689	25841	Economy	6300.00
0005434906690	25841	Economy	6300.00
0005434906645	25841	Economy	6300.00
0005434906653	25841	Economy	6300.00
0005434906646	25841	Economy	6300.00
0005433250966	25841	Economy	6300.00
0005434906660	25841	Economy	6300.00
0005434906662	25841	Economy	6300.00
0005434906685	25841	Economy	6300.00
0005434906640	25841	Economy	6300.00
0005434906651	25841	Economy	6300.00
0005434906647	25841	Economy	6300.00
0005434906635	25841	Economy	6300.00
0005434906634	25841	Economy	6300.00
0005433250933	25841	Economy	6300.00
0005434906659	25841	Economy	6300.00
0005434906644	25841	Economy	6300.00
0005434906665	25841	Economy	6300.00
0005433008143	14185	Business	52300.00
0005433008105	14185	Business	52300.00
0005433008111	14185	Business	52300.00
0005433008112	14185	Business	52300.00
0005433008115	14185	Business	52300.00
0005433008116	14185	Business	52300.00
0005433008118	14185	Economy	17400.00
0005433008144	14185	Economy	17400.00
0005433008104	14185	Economy	17400.00
0005433008102	14185	Economy	17400.00
0005433008128	14185	Economy	19200.00
0005433008136	14185	Economy	17400.00
0005433008114	14185	Economy	17400.00
0005433008133	14185	Economy	17400.00
0005433008108	14185	Economy	17400.00
0005433008101	14185	Economy	17400.00
0005433008140	14185	Economy	17400.00
0005433008106	14185	Economy	17400.00
0005433008141	14185	Economy	17400.00
0005433008129	14185	Economy	17400.00
0005433008120	14185	Economy	17400.00
0005433008119	14185	Economy	17400.00
0005433008117	14185	Economy	17400.00
0005433008134	14185	Economy	17400.00
0005433008146	14185	Economy	17400.00
0005433008137	14185	Economy	17400.00
0005433008135	14185	Economy	17400.00
0005433008107	14185	Economy	17400.00
0005433008132	14185	Economy	17400.00
0005433008100	14185	Economy	17400.00
0005433008121	14185	Economy	17400.00
0005433008124	14185	Economy	17400.00
0005433008126	14185	Economy	17400.00
0005433008130	14185	Economy	17400.00
0005433008138	14185	Economy	17400.00
0005433008142	14185	Economy	17400.00
0005433008103	14185	Economy	17400.00
0005433008139	14185	Economy	17400.00
0005433008113	14185	Economy	17400.00
0005433008123	14185	Economy	17400.00
0005433008122	14185	Economy	17400.00
0005433008110	14185	Economy	17400.00
0005433008125	14185	Economy	17400.00
0005433008145	14185	Economy	17400.00
0005433008127	14185	Economy	17400.00
0005433008109	14185	Economy	17400.00
0005433008131	14185	Economy	17400.00
0005433007840	22819	Business	52300.00
0005433007842	22819	Economy	17400.00
0005433007909	22819	Economy	17400.00
0005433810506	22819	Economy	19200.00
0005433007851	22819	Economy	17400.00
0005433810507	22819	Economy	17400.00
0005433007885	22819	Economy	17400.00
0005433007857	22819	Economy	17400.00
0005434925397	20510	Business	22900.00
0005434925430	20510	Business	22900.00
0005434925401	20510	Business	22900.00
0005434925416	20510	Business	22900.00
0005434925414	20510	Business	22900.00
0005434925405	20510	Business	22900.00
0005434925399	20510	Business	22900.00
0005434925412	20510	Business	22900.00
0005434925423	20510	Economy	7600.00
0005434925402	20510	Economy	7600.00
0005434925427	20510	Economy	7600.00
0005434925429	20510	Economy	7600.00
0005434925417	20510	Economy	7600.00
0005434925409	20510	Economy	7600.00
0005434925432	20510	Economy	7600.00
0005434925413	20510	Economy	7600.00
0005434925420	20510	Economy	7600.00
0005434925424	20510	Economy	7600.00
0005434925406	20510	Economy	7600.00
0005434925403	20510	Economy	7600.00
0005434925400	20510	Economy	7600.00
0005434925398	20510	Economy	7600.00
0005434925419	20510	Economy	7600.00
0005434925411	20510	Economy	7600.00
0005434925422	20510	Economy	7600.00
0005434925410	20510	Economy	7600.00
0005434925428	20510	Economy	7600.00
0005434925415	20510	Economy	7600.00
0005434925431	20510	Economy	7600.00
0005434925418	20510	Economy	7600.00
0005434925408	20510	Economy	7600.00
0005434925421	20510	Economy	7600.00
0005434925425	20510	Economy	7600.00
0005434925407	20510	Economy	7600.00
0005434925404	20510	Economy	7600.00
0005434925426	20510	Economy	7600.00
0005435487595	15806	Economy	8900.00
0005435487593	15806	Economy	8100.00
0005435487600	15806	Economy	8100.00
0005435487589	15806	Economy	8100.00
0005435487597	15806	Economy	8100.00
0005435487602	15806	Economy	8100.00
0005435487596	15806	Economy	8100.00
0005435487599	15806	Economy	8100.00
0005435487603	15806	Economy	8100.00
0005435487607	15806	Economy	8100.00
0005435487591	15806	Economy	8100.00
0005435487606	15806	Economy	8100.00
0005435487594	15806	Economy	8100.00
0005435487588	15806	Economy	8100.00
0005435487601	15806	Economy	8100.00
0005435487586	15806	Economy	8100.00
0005435487605	15806	Economy	8100.00
0005435487590	15806	Economy	8100.00
0005435487598	15806	Economy	8100.00
0005435487604	15806	Economy	8100.00
0005435487608	15806	Economy	8100.00
0005435487587	15806	Economy	8100.00
0005435487592	15806	Economy	8100.00
0005435999041	19696	Economy	8900.00
0005435999035	19696	Economy	8100.00
0005435999044	19696	Economy	8100.00
0005435999037	19696	Economy	8100.00
0005435999043	19696	Economy	8100.00
0005435999045	19696	Economy	8100.00
0005435999039	19696	Economy	8100.00
0005435999042	19696	Economy	8100.00
0005435999036	19696	Economy	8100.00
0005435999038	19696	Economy	8100.00
0005435999040	19696	Economy	8100.00
0005435999046	19696	Economy	8100.00
0005432658570	6004	Business	199300.00
0005435839136	6004	Business	199300.00
0005435839145	6004	Business	199300.00
0005432658568	6004	Business	199300.00
0005435839154	6004	Business	199300.00
0005432142219	6004	Business	199300.00
0005432658569	6004	Business	199300.00
0005435839139	6004	Business	199300.00
0005435839132	6004	Economy	66400.00
0005435839148	6004	Economy	66400.00
0005435839138	6004	Economy	66400.00
0005435839147	6004	Economy	66400.00
0005435839158	6004	Economy	73100.00
0005435839141	6004	Economy	66400.00
0005435839150	6004	Economy	66400.00
0005432142218	6004	Economy	66400.00
0005435839134	6004	Economy	66400.00
0005435839144	6004	Economy	66400.00
0005435839142	6004	Economy	66400.00
0005435839140	6004	Economy	66400.00
0005432660796	6004	Economy	66400.00
0005435839151	6004	Economy	66400.00
0005435839152	6004	Economy	66400.00
0005435839156	6004	Economy	66400.00
0005432658571	6004	Economy	66400.00
0005432659685	6004	Economy	66400.00
0005435839143	6004	Economy	66400.00
0005432660795	6004	Economy	66400.00
0005435839131	6004	Economy	66400.00
0005435839157	6004	Economy	66400.00
0005435839146	6004	Economy	66400.00
0005435839153	6004	Economy	66400.00
0005432659684	6004	Economy	66400.00
0005435839135	6004	Economy	66400.00
0005432142217	6004	Economy	66400.00
0005435839155	6004	Economy	66400.00
0005435839149	6004	Economy	66400.00
0005435839137	6004	Economy	66400.00
0005432142216	6004	Economy	66400.00
0005435839133	6004	Economy	66400.00
0005435472625	18053	Business	199300.00
0005435838965	18053	Business	199300.00
0005435472614	18053	Business	199300.00
0005435472621	18053	Business	199300.00
0005435472624	18053	Economy	66400.00
0005435839026	18053	Economy	66400.00
0005435472626	18053	Economy	66400.00
0005435839025	18053	Economy	73100.00
0005435472615	18053	Economy	66400.00
0005435838980	18053	Economy	66400.00
0005435472629	18053	Economy	66400.00
0005435472613	18053	Economy	66400.00
0005435472628	18053	Economy	66400.00
0005435838960	18053	Economy	66400.00
0005435838994	18053	Economy	66400.00
0005435472616	18053	Economy	66400.00
0005435472620	18053	Economy	66400.00
0005435472627	18053	Economy	66400.00
0005435472623	18053	Economy	66400.00
0005435838959	18053	Economy	66400.00
0005435472619	18053	Economy	66400.00
0005435472622	18053	Economy	66400.00
0005435472617	18053	Economy	66400.00
0005435472618	18053	Economy	66400.00
0005435838979	18053	Economy	66400.00
0005435839027	18053	Economy	66400.00
0005433284824	23013	Business	15700.00
0005435103848	23013	Economy	5200.00
0005435103842	23013	Economy	5200.00
0005433284805	23013	Economy	5200.00
0005435103847	23013	Economy	5200.00
0005435103846	23013	Economy	5200.00
0005435103839	23013	Economy	5700.00
0005435103845	23013	Economy	5200.00
0005433284782	23013	Economy	5200.00
0005435103849	23013	Economy	5200.00
0005435103840	23013	Economy	5200.00
0005435103844	23013	Economy	5200.00
0005435103843	23013	Economy	5200.00
0005435103838	23013	Economy	5200.00
0005435103841	23013	Economy	5200.00
0005433284783	23013	Economy	5200.00
0005433284823	23013	Economy	5200.00
0005433284967	32093	Business	15700.00
0005433284961	32093	Economy	5200.00
0005433284959	32093	Economy	5200.00
0005433284957	32093	Economy	5200.00
0005433284956	32093	Economy	5200.00
0005433284972	32093	Economy	5200.00
0005433284962	32093	Economy	5200.00
0005433284949	32093	Economy	5200.00
0005433284951	32093	Economy	5200.00
0005433284952	32093	Economy	5700.00
0005433284953	32093	Economy	5200.00
0005433284964	32093	Economy	5200.00
0005433284963	32093	Economy	5200.00
0005433284974	32093	Economy	5200.00
0005433284948	32093	Economy	5200.00
0005433284968	32093	Economy	5200.00
0005433284971	32093	Economy	5200.00
0005433284947	32093	Economy	5200.00
0005433284950	32093	Economy	5200.00
0005433284973	32093	Economy	5200.00
0005433284954	32093	Economy	5200.00
0005433284944	32093	Economy	5200.00
0005433284966	32093	Economy	5200.00
0005433284970	32093	Economy	5200.00
0005433284960	32093	Economy	5200.00
0005433284943	32093	Economy	5200.00
0005433284958	32093	Economy	5200.00
0005433284965	32093	Economy	5200.00
0005433284955	32093	Economy	5200.00
0005433284945	32093	Economy	5200.00
0005433284946	32093	Economy	5200.00
0005433284969	32093	Economy	5200.00
0005435212852	30602	Business	42100.00
0005435212840	30602	Business	42100.00
0005434066306	30602	Business	42100.00
0005435212849	30602	Business	42100.00
0005432525871	30602	Business	42100.00
0005435212875	30602	Business	42100.00
0005435212829	30602	Business	42100.00
0005435212816	30602	Business	42100.00
0005432211420	30602	Business	42100.00
0005432526554	30602	Business	42100.00
0005432525718	30602	Business	42100.00
0005435212825	30602	Business	42100.00
0005435212874	30602	Business	42100.00
0005435630937	30602	Business	42100.00
0005434066327	30602	Business	42100.00
0005434066440	30602	Business	42100.00
0005432525744	30602	Comfort	23900.00
0005432525674	30602	Comfort	23900.00
0005435212838	30602	Comfort	23900.00
0005435725552	30602	Comfort	23900.00
0005435212877	30602	Comfort	23900.00
0005435212860	30602	Comfort	23900.00
0005432159811	30602	Comfort	23900.00
0005432526555	30602	Comfort	23900.00
0005434066433	30602	Comfort	23900.00
0005432525669	30602	Comfort	23900.00
0005435212845	30602	Comfort	23900.00
0005435212867	30602	Comfort	23900.00
0005434066441	30602	Comfort	23900.00
0005435212841	30602	Comfort	23900.00
0005432535748	30602	Comfort	23900.00
0005432525653	30602	Comfort	23900.00
0005432525743	30602	Comfort	23900.00
0005435212882	30602	Comfort	23900.00
0005435725551	30602	Comfort	23900.00
0005435212859	30602	Comfort	23900.00
0005432159810	30602	Comfort	23900.00
0005432535747	30602	Comfort	23900.00
0005434066299	30602	Economy	14000.00
0005435212820	30602	Economy	14000.00
0005435630936	30602	Economy	14000.00
0005432525972	30602	Economy	14000.00
0005435212837	30602	Economy	14000.00
0005434066348	30602	Economy	14000.00
0005435212856	30602	Economy	14000.00
0005435212844	30602	Economy	14000.00
0005432526022	30602	Economy	14000.00
0005435212868	30602	Economy	14000.00
0005435212879	30602	Economy	14000.00
0005435212826	30602	Economy	14000.00
0005432526026	30602	Economy	14000.00
0005435212876	30602	Economy	14000.00
0005432525707	30602	Economy	14000.00
0005433656635	30602	Economy	14000.00
0005432525673	30602	Economy	14000.00
0005435630935	30602	Economy	14000.00
0005435212847	30602	Economy	14000.00
0005435212850	30602	Economy	14000.00
0005435212862	30602	Economy	14000.00
0005432428870	30602	Economy	14000.00
0005435212861	30602	Economy	14000.00
0005435725549	30602	Economy	14000.00
0005434066311	30602	Economy	14000.00
0005435212858	30602	Economy	14000.00
0005435212855	30602	Economy	15400.00
0005432211421	30602	Economy	14000.00
0005435725547	30602	Economy	14000.00
0005432211419	30602	Economy	14000.00
0005435212823	30602	Economy	14000.00
0005435212842	30602	Economy	14000.00
0005432526109	30602	Economy	14000.00
0005435725548	30602	Economy	14000.00
0005432525859	30602	Economy	14000.00
0005432525963	30602	Economy	14000.00
0005432211423	30602	Economy	14000.00
0005435212846	30602	Economy	14000.00
0005435212827	30602	Economy	14000.00
0005435212848	30602	Economy	14000.00
0005432525702	30602	Economy	14000.00
0005432525962	30602	Economy	14000.00
0005434066298	30602	Economy	14000.00
0005432525831	30602	Economy	14000.00
0005432525640	30602	Economy	14000.00
0005432525820	30602	Economy	14000.00
0005435212871	30602	Economy	14000.00
0005435212824	30602	Economy	14000.00
0005435212822	30602	Economy	14000.00
0005435212835	30602	Economy	14000.00
0005435212869	30602	Economy	14000.00
0005435212854	30602	Economy	14000.00
0005433656637	30602	Economy	14000.00
0005435212818	30602	Economy	14000.00
0005435212853	30602	Economy	14000.00
0005435212819	30602	Economy	14000.00
0005432211425	30602	Economy	14000.00
0005435212832	30602	Economy	14000.00
0005435725550	30602	Economy	14000.00
0005435212828	30602	Economy	14000.00
0005435212821	30602	Economy	14000.00
0005435212814	30602	Economy	14000.00
0005434066434	30602	Economy	14000.00
0005434066422	30602	Economy	14000.00
0005435212873	30602	Economy	14000.00
0005432525677	30602	Economy	15400.00
0005434066328	30602	Economy	15400.00
0005432525840	30602	Economy	15400.00
0005435212836	30602	Economy	14000.00
0005435212878	30602	Economy	14000.00
0005432211422	30602	Economy	14000.00
0005435212881	30602	Economy	14000.00
0005434066313	30602	Economy	14000.00
0005435212851	30602	Economy	14000.00
0005435212839	30602	Economy	14000.00
0005432526021	30602	Economy	14000.00
0005432525670	30602	Economy	14000.00
0005435212872	30602	Economy	14000.00
0005432525706	30602	Economy	14000.00
0005432525701	30602	Economy	14000.00
0005434066394	30602	Economy	14000.00
0005435212831	30602	Economy	14000.00
0005435212870	30602	Economy	14000.00
0005432211426	30602	Economy	14000.00
0005433656636	30602	Economy	14000.00
0005435212883	30602	Economy	14000.00
0005435212864	30602	Economy	14000.00
0005435212833	30602	Economy	14000.00
0005435212830	30602	Economy	14000.00
0005435212815	30602	Economy	14000.00
0005432525652	30602	Economy	14000.00
0005435212817	30602	Economy	14000.00
0005435212857	30602	Economy	14000.00
0005434066442	30602	Economy	14000.00
0005432525675	30602	Economy	14000.00
0005432525832	30602	Economy	14000.00
0005435212866	30602	Economy	14000.00
0005435212880	30602	Economy	14000.00
0005435212865	30602	Economy	14000.00
0005435212863	30602	Economy	14000.00
0005434066297	30602	Economy	14000.00
0005434066300	30602	Economy	14000.00
0005432525659	30602	Economy	14000.00
0005432159809	30602	Economy	14000.00
0005432525655	30602	Economy	14000.00
0005432525860	30602	Economy	14000.00
0005432525858	30602	Economy	14000.00
0005432525798	30602	Economy	14000.00
0005432159807	30602	Economy	14000.00
0005435212843	30602	Economy	14000.00
0005435212834	30602	Economy	14000.00
0005432525753	30602	Economy	14000.00
0005432428871	30602	Economy	14000.00
0005432211424	30602	Economy	14000.00
0005432525742	30602	Economy	14000.00
0005432525654	30602	Economy	14000.00
0005432159808	30602	Economy	14000.00
0005432525872	30602	Economy	14000.00
0005433367520	24835	Business	9800.00
0005433367501	24835	Business	9800.00
0005433367510	24835	Business	9800.00
0005433367500	24835	Business	9800.00
0005433367512	24835	Business	9800.00
0005433367487	24835	Business	9800.00
0005433367518	24835	Business	9800.00
0005433367499	24835	Business	9800.00
0005433367517	24835	Economy	3300.00
0005433367524	24835	Economy	3300.00
0005433367490	24835	Economy	3300.00
0005433367502	24835	Economy	3300.00
0005433367513	24835	Economy	3300.00
0005433367515	24835	Economy	3600.00
0005433367492	24835	Economy	3600.00
0005433367508	24835	Economy	3300.00
0005433367489	24835	Economy	3300.00
0005433367506	24835	Economy	3300.00
0005433367511	24835	Economy	3300.00
0005433367509	24835	Economy	3300.00
0005433367516	24835	Economy	3300.00
0005433367521	24835	Economy	3300.00
0005433367523	24835	Economy	3300.00
0005433367491	24835	Economy	3300.00
0005433367503	24835	Economy	3300.00
0005433367493	24835	Economy	3300.00
0005433367496	24835	Economy	3300.00
0005433367488	24835	Economy	3300.00
0005433367514	24835	Economy	3300.00
0005433367522	24835	Economy	3300.00
0005433367494	24835	Economy	3300.00
0005433367507	24835	Economy	3300.00
0005433367519	24835	Economy	3300.00
0005433367505	24835	Economy	3300.00
0005433367504	24835	Economy	3300.00
0005433367498	24835	Economy	3300.00
0005433367495	24835	Economy	3300.00
0005433367497	24835	Economy	3300.00
0005435801665	2062	Economy	10500.00
0005434979483	2062	Economy	10500.00
0005434979497	2062	Economy	10500.00
0005435801666	2062	Economy	9500.00
0005434979485	2062	Economy	9500.00
0005434979476	2062	Economy	9500.00
0005434979482	2062	Economy	9500.00
0005434979495	2062	Economy	9500.00
0005434979486	2062	Economy	9500.00
0005434979467	2062	Economy	9500.00
0005434979493	2062	Economy	9500.00
0005434979488	2062	Economy	9500.00
0005434979494	2062	Economy	9500.00
0005434979487	2062	Economy	9500.00
0005434979492	2062	Economy	9500.00
0005434979496	2062	Economy	9500.00
0005434979471	2062	Economy	9500.00
0005434979468	2062	Economy	9500.00
0005434979469	2062	Economy	9500.00
0005434979481	2062	Economy	9500.00
0005434979470	2062	Economy	9500.00
0005434979489	2062	Economy	9500.00
0005434979484	2062	Economy	9500.00
0005434979490	2062	Economy	9500.00
0005434979479	2062	Economy	9500.00
0005434979478	2062	Economy	9500.00
0005434979472	2062	Economy	9500.00
0005435801664	2062	Economy	9500.00
0005434979475	2062	Economy	9500.00
0005434979480	2062	Economy	9500.00
0005434979491	2062	Economy	9500.00
0005434979474	2062	Economy	9500.00
0005434979473	2062	Economy	9500.00
0005434979477	2062	Economy	9500.00
0005435801655	23534	Economy	10500.00
0005435801642	23534	Economy	9500.00
0005434952493	2656	Economy	5300.00
0005434952492	2656	Economy	5300.00
0005434952494	2656	Economy	5300.00
0005433256383	2655	Economy	5300.00
0005433256381	2655	Economy	5300.00
0005433256384	2655	Economy	5300.00
0005433256382	2655	Economy	5300.00
0005433256399	28241	Economy	5300.00
0005433256400	28241	Economy	5300.00
0005433111484	19814	Economy	8700.00
0005433111483	19814	Economy	8700.00
0005434136717	11967	Business	9700.00
0005434136832	11967	Business	9700.00
0005434136849	11967	Business	9700.00
0005434136686	11967	Business	9700.00
0005434136760	11967	Business	9700.00
0005434136726	11967	Economy	3200.00
0005434136920	11967	Economy	3200.00
0005434136733	11967	Economy	3200.00
0005434136677	11967	Economy	3200.00
0005434136687	11967	Economy	3200.00
0005434136848	11967	Economy	3200.00
0005434136753	11967	Economy	3200.00
0005434136688	11967	Economy	3200.00
0005434136831	11967	Economy	3200.00
0005434136678	11967	Economy	3200.00
0005434136748	11967	Economy	3200.00
0005434136806	11967	Economy	3200.00
0005434136718	11967	Economy	3200.00
0005434136761	11967	Economy	3200.00
0005434136699	11967	Economy	3200.00
0005434137246	28721	Business	9700.00
0005434137260	28721	Business	9700.00
0005434137194	28721	Business	9700.00
0005434137200	28721	Business	9700.00
0005434137212	28721	Business	9700.00
0005434137258	28721	Business	9700.00
0005434137205	28721	Business	9700.00
0005434137192	28721	Business	9700.00
0005434137204	28721	Business	9700.00
0005434137176	28721	Business	9700.00
0005434137221	28721	Business	9700.00
0005434137206	28721	Economy	3200.00
0005434137230	28721	Economy	3200.00
0005434137190	28721	Economy	3200.00
0005434137232	28721	Economy	3200.00
0005434137180	28721	Economy	3200.00
0005434137257	28721	Economy	3200.00
0005434137181	28721	Economy	3200.00
0005434137199	28721	Economy	3200.00
0005434137202	28721	Economy	3200.00
0005434137256	28721	Economy	3500.00
0005434137191	28721	Economy	3500.00
0005434137201	28721	Economy	3500.00
0005434137193	28721	Economy	3500.00
0005434137255	28721	Economy	3500.00
0005434137217	28721	Economy	3200.00
0005434137242	28721	Economy	3200.00
0005434137207	28721	Economy	3200.00
0005434137265	28721	Economy	3200.00
0005434137238	28721	Economy	3200.00
0005434137247	28721	Economy	3200.00
0005434137209	28721	Economy	3200.00
0005434137244	28721	Economy	3200.00
0005434137220	28721	Economy	3200.00
0005434137196	28721	Economy	3200.00
0005434137245	28721	Economy	3200.00
0005434137252	28721	Economy	3200.00
0005434137241	28721	Economy	3200.00
0005434137235	28721	Economy	3200.00
0005434137197	28721	Economy	3200.00
0005434137248	28721	Economy	3200.00
0005434137231	28721	Economy	3200.00
0005434137223	28721	Economy	3200.00
0005434137182	28721	Economy	3200.00
0005434137198	28721	Economy	3200.00
0005434137253	28721	Economy	3200.00
0005434137188	28721	Economy	3200.00
0005434137184	28721	Economy	3200.00
0005434137213	28721	Economy	3200.00
0005434137186	28721	Economy	3200.00
0005434137226	28721	Economy	3200.00
0005434137237	28721	Economy	3200.00
0005434137261	28721	Economy	3200.00
0005434137224	28721	Economy	3200.00
0005434137189	28721	Economy	3200.00
0005434137195	28721	Economy	3200.00
0005434137236	28721	Economy	3200.00
0005434137228	28721	Economy	3200.00
0005434137177	28721	Economy	3200.00
0005434137208	28721	Economy	3200.00
0005434137216	28721	Economy	3200.00
0005434137179	28721	Economy	3200.00
0005434137183	28721	Economy	3200.00
0005434137262	28721	Economy	3200.00
0005434137254	28721	Economy	3200.00
0005434137267	28721	Economy	3200.00
0005434137185	28721	Economy	3200.00
0005434137218	28721	Economy	3200.00
0005434137251	28721	Economy	3200.00
0005434137263	28721	Economy	3200.00
0005434137250	28721	Economy	3200.00
0005434137178	28721	Economy	3200.00
0005434137219	28721	Economy	3200.00
0005434137211	28721	Economy	3200.00
0005434137239	28721	Economy	3200.00
0005434137243	28721	Economy	3200.00
0005434137229	28721	Economy	3200.00
0005434137249	28721	Economy	3200.00
0005434137187	28721	Economy	3200.00
0005434137214	28721	Economy	3200.00
0005434137210	28721	Economy	3200.00
0005434137233	28721	Economy	3200.00
0005434137227	28721	Economy	3200.00
0005434137215	28721	Economy	3200.00
0005434137203	28721	Economy	3200.00
0005434137222	28721	Economy	3200.00
0005434137264	28721	Economy	3200.00
0005434137225	28721	Economy	3200.00
0005434137259	28721	Economy	3200.00
0005434137240	28721	Economy	3200.00
0005434137266	28721	Economy	3200.00
0005434137234	28721	Economy	3200.00
0005434513534	19101	Economy	26000.00
0005434513535	19101	Economy	23600.00
0005434190379	19101	Economy	23600.00
0005434190380	19101	Economy	23600.00
0005434190384	19101	Economy	23600.00
0005434190383	19101	Economy	23600.00
0005434190381	19101	Economy	23600.00
0005434513533	19101	Economy	23600.00
0005434190382	19101	Economy	23600.00
0005434513536	19101	Economy	23600.00
0005433534476	6769	Economy	10900.00
0005435259687	6769	Economy	10900.00
0005433538785	6769	Economy	10900.00
0005433538783	6769	Economy	9900.00
0005433538778	6769	Economy	9900.00
0005433538782	6769	Economy	9900.00
0005433538780	6769	Economy	9900.00
0005433534475	6769	Economy	9900.00
0005433538781	6769	Economy	9900.00
0005433538779	6769	Economy	9900.00
0005433538784	6769	Economy	9900.00
0005433534477	6769	Economy	9900.00
0005435259686	6769	Economy	9900.00
0005435259685	6769	Economy	9900.00
0005433534461	25003	Economy	10900.00
0005433538728	25003	Economy	9900.00
0005433538726	25003	Economy	9900.00
0005433538732	25003	Economy	9900.00
0005433538727	25003	Economy	9900.00
0005433538724	25003	Economy	9900.00
0005433538733	25003	Economy	9900.00
0005433538725	25003	Economy	9900.00
0005435259710	25003	Economy	9900.00
0005433534463	25003	Economy	9900.00
0005435259712	25003	Economy	9900.00
0005435259711	25003	Economy	9900.00
0005433534462	25003	Economy	9900.00
0005435259713	25003	Economy	9900.00
0005435259709	25003	Economy	9900.00
0005433511863	828	Economy	16100.00
0005433511861	828	Economy	16100.00
0005433511866	828	Economy	14600.00
0005433511862	828	Economy	14600.00
0005433511867	828	Economy	14600.00
0005433511869	828	Economy	14600.00
0005433511865	828	Economy	14600.00
0005433511868	828	Economy	14600.00
0005433511864	828	Economy	14600.00
0005432922455	828	Economy	14600.00
0005433511834	16168	Economy	16100.00
0005433511835	16168	Economy	14600.00
0005433511805	16168	Economy	14600.00
0005432922485	16168	Economy	14600.00
0005433511806	16168	Economy	14600.00
0005432922481	16168	Economy	14600.00
0005432922484	16168	Economy	14600.00
0005432922482	16168	Economy	14600.00
0005432922483	16168	Economy	14600.00
0005433511817	16168	Economy	14600.00
0005433511807	16168	Economy	14600.00
0005435852526	4024	Economy	13500.00
0005433475664	4024	Economy	13500.00
0005433475662	4024	Economy	12300.00
0005433475658	4024	Economy	12300.00
0005433475657	4024	Economy	12300.00
0005433475663	4024	Economy	12300.00
0005433475661	4024	Economy	12300.00
0005435852533	4024	Economy	12300.00
0005433475665	4024	Economy	12300.00
0005435852532	4024	Economy	12300.00
0005433475660	4024	Economy	12300.00
0005433475659	4024	Economy	12300.00
0005435697057	3704	Economy	7900.00
0005435697068	3704	Economy	7900.00
0005435697051	3704	Economy	7200.00
0005435697065	3704	Economy	7200.00
0005435697056	3704	Economy	7200.00
0005435697048	3704	Economy	7200.00
0005435697062	3704	Economy	7200.00
0005435697061	3704	Economy	7200.00
0005435697046	3704	Economy	7200.00
0005435697064	3704	Economy	7200.00
0005435697049	3704	Economy	7200.00
0005435697054	3704	Economy	7200.00
0005435697045	3704	Economy	7200.00
0005435697066	3704	Economy	7200.00
0005435697063	3704	Economy	7200.00
0005435697050	3704	Economy	7200.00
0005435697055	3704	Economy	7200.00
0005434950484	3704	Economy	7200.00
0005435697067	3704	Economy	7200.00
0005435697044	3704	Economy	7200.00
0005434950483	3704	Economy	7200.00
0005435697069	3704	Economy	7200.00
0005435697058	3704	Economy	7200.00
0005435697060	3704	Economy	7200.00
0005435697053	3704	Economy	7200.00
0005435697047	3704	Economy	7200.00
0005435697071	3704	Economy	7200.00
0005434950482	3704	Economy	7200.00
0005435697059	3704	Economy	7200.00
0005434950481	3704	Economy	7200.00
0005434950485	3704	Economy	7200.00
0005435697070	3704	Economy	7200.00
0005435697072	3704	Economy	7200.00
0005435697052	3704	Economy	7200.00
0005435696891	16283	Economy	7200.00
0005435916140	16283	Economy	7200.00
0005435696909	16283	Economy	7200.00
0005435696849	16283	Economy	7200.00
0005435696872	16283	Economy	7200.00
0005434950470	16283	Economy	7200.00
0005435935013	16283	Economy	7200.00
0005435696848	16283	Economy	7200.00
0005435696845	16283	Economy	7200.00
0005434950453	16283	Economy	7200.00
0005434950454	16283	Economy	7200.00
0005435935012	16283	Economy	7200.00
0005435916139	16283	Economy	7200.00
0005435696880	16283	Economy	7200.00
0005435916138	16283	Economy	7200.00
0005434604864	3982	Economy	21300.00
0005433519410	3982	Economy	21300.00
0005432607523	3982	Economy	21300.00
0005432607525	3982	Economy	19300.00
0005434606793	3982	Economy	19300.00
0005433519411	3982	Economy	19300.00
0005432609689	3982	Economy	19300.00
0005432607524	3982	Economy	19300.00
0005434606790	3982	Economy	19300.00
0005432607527	3982	Economy	19300.00
0005432607526	3982	Economy	19300.00
0005433519412	3982	Economy	19300.00
0005434604863	3982	Economy	19300.00
0005434606792	3982	Economy	19300.00
0005432609690	3982	Economy	19300.00
0005434606791	3982	Economy	19300.00
0005433519409	3982	Economy	19300.00
0005433519413	3982	Economy	19300.00
0005434606789	3982	Economy	19300.00
0005432609691	3982	Economy	19300.00
0005435853591	22033	Economy	21300.00
0005435853593	22033	Economy	19300.00
0005435853592	22033	Economy	19300.00
0005433519379	22033	Economy	19300.00
0005435628692	754	Economy	3700.00
0005433348888	754	Economy	3700.00
0005435628695	754	Economy	3700.00
0005433348887	754	Economy	3700.00
0005433348902	754	Economy	3700.00
0005435628694	754	Economy	3700.00
0005435628693	754	Economy	3700.00
0005433348929	15948	Economy	3700.00
0005435628674	15948	Economy	3700.00
0005433348930	15948	Economy	3700.00
0005433348931	15948	Economy	3700.00
0005433348928	15948	Economy	3700.00
0005433348932	15948	Economy	3700.00
0005433348933	15948	Economy	3700.00
0005434445221	17252	Economy	7100.00
0005434445222	17252	Economy	7100.00
0005434446493	17252	Economy	7100.00
0005434446492	17252	Economy	7100.00
0005434446494	17252	Economy	7100.00
0005434445209	17658	Economy	7100.00
0005434445208	17658	Economy	7100.00
0005433159291	17658	Economy	7100.00
0005433159290	17658	Economy	7100.00
0005435132777	7867	Economy	5400.00
0005435132780	7867	Economy	5400.00
0005435132775	7867	Economy	5400.00
0005435132770	7867	Economy	5400.00
0005435132773	7867	Economy	5400.00
0005435132772	7867	Economy	5400.00
0005435132776	7867	Economy	5400.00
0005435132774	7867	Economy	5400.00
0005435132779	7867	Economy	5400.00
0005435132771	7867	Economy	5400.00
0005435132778	7867	Economy	5400.00
0005435132706	33100	Economy	5400.00
0005435383094	33100	Economy	5400.00
0005435383097	33100	Economy	5400.00
0005435383098	33100	Economy	5400.00
0005435132719	33100	Economy	5400.00
0005435132715	33100	Economy	5400.00
0005435383096	33100	Economy	5400.00
0005435383093	33100	Economy	5400.00
0005435383095	33100	Economy	5400.00
0005435132701	33100	Economy	5400.00
0005435160184	7514	Economy	13800.00
0005435390119	7514	Economy	13800.00
0005435160185	7514	Economy	12500.00
0005435160186	7514	Economy	12500.00
0005435160183	7514	Economy	12500.00
0005435160187	7514	Economy	12500.00
0005435390121	7514	Economy	12500.00
0005435390117	7514	Economy	12500.00
0005435390120	7514	Economy	12500.00
0005435160190	7514	Economy	12500.00
0005435160188	7514	Economy	12500.00
0005435160191	7514	Economy	12500.00
0005435160192	7514	Economy	12500.00
0005435160193	7514	Economy	12500.00
0005435160189	7514	Economy	12500.00
0005435390123	7514	Economy	12500.00
0005435160194	7514	Economy	12500.00
0005435390171	29577	Economy	13800.00
0005435390167	29577	Economy	12500.00
0005435390170	29577	Economy	12500.00
0005435160137	29577	Economy	12500.00
0005435160123	29577	Economy	12500.00
0005435390172	29577	Economy	12500.00
0005435160121	29577	Economy	12500.00
0005435390169	29577	Economy	12500.00
0005435390168	29577	Economy	12500.00
0005435160122	29577	Economy	12500.00
0005435178479	18461	Economy	4900.00
0005435178478	18461	Economy	4900.00
0005435178984	18461	Economy	4900.00
0005435178983	18461	Economy	4900.00
0005432400084	27174	Economy	4900.00
0005432398154	27174	Economy	4900.00
0005432398153	27174	Economy	4900.00
0005432400085	27174	Economy	4900.00
0005432398155	27174	Economy	4900.00
0005432398152	27174	Economy	4900.00
0005432400083	27174	Economy	4900.00
0005432400082	27174	Economy	4900.00
0005432398156	27174	Economy	4900.00
0005434503772	6526	Business	48400.00
0005434503754	6526	Business	48400.00
0005434503778	6526	Business	48400.00
0005434503779	6526	Business	48400.00
0005434503743	6526	Business	48400.00
0005434503747	6526	Business	48400.00
0005434503782	6526	Business	48400.00
0005434503774	6526	Economy	16100.00
0005435103856	6526	Economy	16100.00
0005434503777	6526	Economy	17800.00
0005434503759	6526	Economy	17800.00
0005434503741	6526	Economy	17800.00
0005434503745	6526	Economy	17800.00
0005434503748	6526	Economy	16100.00
0005434503780	6526	Economy	16100.00
0005434503781	6526	Economy	16100.00
0005434503753	6526	Economy	16100.00
0005434503765	6526	Economy	16100.00
0005434503761	6526	Economy	16100.00
0005435103854	6526	Economy	16100.00
0005435103857	6526	Economy	16100.00
0005434503757	6526	Economy	16100.00
0005434503771	6526	Economy	16100.00
0005434503760	6526	Economy	16100.00
0005434503755	6526	Economy	16100.00
0005435103855	6526	Economy	16100.00
0005434503768	6526	Economy	16100.00
0005434503758	6526	Economy	16100.00
0005434503742	6526	Economy	16100.00
0005435103861	6526	Economy	16100.00
0005434503749	6526	Economy	16100.00
0005435103859	6526	Economy	16100.00
0005434503770	6526	Economy	16100.00
0005434503766	6526	Economy	16100.00
0005434503773	6526	Economy	16100.00
0005435103853	6526	Economy	16100.00
0005434503751	6526	Economy	16100.00
0005434503750	6526	Economy	16100.00
0005434503762	6526	Economy	16100.00
0005435103860	6526	Economy	16100.00
0005434503763	6526	Economy	16100.00
0005434503776	6526	Economy	16100.00
0005434503775	6526	Economy	16100.00
0005434503744	6526	Economy	16100.00
0005434503764	6526	Economy	16100.00
0005434503752	6526	Economy	16100.00
0005434503769	6526	Economy	16100.00
0005434503746	6526	Economy	16100.00
0005434503767	6526	Economy	16100.00
0005435103858	6526	Economy	16100.00
0005434503756	6526	Economy	16100.00
0005434503528	22681	Economy	16100.00
0005434503461	22681	Economy	16100.00
0005434503462	22681	Economy	16100.00
0005434503495	22681	Economy	16100.00
0005433367232	1698	Business	50000.00
0005435652566	1698	Business	50000.00
0005435652608	1698	Business	50000.00
0005435652614	1698	Business	50000.00
0005435652599	1698	Business	50000.00
0005435652596	1698	Business	50000.00
0005433367397	1698	Business	50000.00
0005435652611	1698	Business	50000.00
0005435652581	1698	Business	50000.00
0005435652578	1698	Business	50000.00
0005435652607	1698	Business	50000.00
0005433367251	1698	Economy	16700.00
0005435652580	1698	Economy	16700.00
0005435652564	1698	Economy	16700.00
0005435652571	1698	Economy	16700.00
0005433367258	1698	Economy	16700.00
0005435652610	1698	Economy	16700.00
0005435652589	1698	Economy	16700.00
0005435652601	1698	Economy	18300.00
0005435652583	1698	Economy	18300.00
0005435652582	1698	Economy	18300.00
0005433367233	1698	Economy	18300.00
0005433367256	1698	Economy	18300.00
0005433367277	1698	Economy	16700.00
0005435652576	1698	Economy	16700.00
0005435652587	1698	Economy	16700.00
0005433367242	1698	Economy	16700.00
0005435652572	1698	Economy	16700.00
0005433367280	1698	Economy	16700.00
0005435652579	1698	Economy	16700.00
0005435652613	1698	Economy	16700.00
0005435652562	1698	Economy	16700.00
0005435652616	1698	Economy	16700.00
0005435652597	1698	Economy	16700.00
0005435652568	1698	Economy	16700.00
0005435652567	1698	Economy	16700.00
0005435652603	1698	Economy	16700.00
0005435652615	1698	Economy	16700.00
0005435652604	1698	Economy	16700.00
0005435652593	1698	Economy	16700.00
0005435652609	1698	Economy	16700.00
0005435652591	1698	Economy	16700.00
0005433367257	1698	Economy	16700.00
0005435652569	1698	Economy	16700.00
0005435652563	1698	Economy	16700.00
0005435652577	1698	Economy	16700.00
0005433367284	1698	Economy	16700.00
0005435652584	1698	Economy	16700.00
0005435652605	1698	Economy	16700.00
0005435652598	1698	Economy	16700.00
0005435652561	1698	Economy	16700.00
0005435652586	1698	Economy	16700.00
0005435652574	1698	Economy	16700.00
0005435652585	1698	Economy	16700.00
0005435652618	1698	Economy	16700.00
0005435652617	1698	Economy	16700.00
0005435652602	1698	Economy	16700.00
0005435652575	1698	Economy	16700.00
0005435652590	1698	Economy	16700.00
0005435652619	1698	Economy	16700.00
0005433367229	1698	Economy	16700.00
0005435652588	1698	Economy	16700.00
0005435652592	1698	Economy	16700.00
0005435652620	1698	Economy	16700.00
0005435652565	1698	Economy	16700.00
0005435652595	1698	Economy	16700.00
0005435652612	1698	Economy	16700.00
0005435652573	1698	Economy	16700.00
0005435652600	1698	Economy	16700.00
0005435652570	1698	Economy	16700.00
0005435652594	1698	Economy	16700.00
0005435652606	1698	Economy	16700.00
0005433367503	21704	Business	50000.00
0005433367497	21704	Business	50000.00
0005433367523	21704	Business	50000.00
0005433367520	21704	Business	50000.00
0005433367514	21704	Business	50000.00
0005433367488	21704	Business	50000.00
0005433367498	21704	Business	50000.00
0005433367521	21704	Economy	16700.00
0005433367496	21704	Economy	16700.00
0005433367506	21704	Economy	18300.00
0005433367492	21704	Economy	18300.00
0005433367489	21704	Economy	16700.00
0005433367499	21704	Economy	16700.00
0005433367517	21704	Economy	16700.00
0005433367490	21704	Economy	16700.00
0005433367502	21704	Economy	16700.00
0005433367487	21704	Economy	16700.00
0005433367513	21704	Economy	16700.00
0005433367522	21704	Economy	16700.00
0005433367500	21704	Economy	16700.00
0005433367501	21704	Economy	16700.00
0005433367494	21704	Economy	16700.00
0005433367518	21704	Economy	16700.00
0005433367519	21704	Economy	16700.00
0005433367505	21704	Economy	16700.00
0005433367515	21704	Economy	16700.00
0005433367507	21704	Economy	16700.00
0005433367495	21704	Economy	16700.00
0005433367510	21704	Economy	16700.00
0005433367491	21704	Economy	16700.00
0005433367512	21704	Economy	16700.00
0005433367516	21704	Economy	16700.00
0005433367508	21704	Economy	16700.00
0005433367524	21704	Economy	16700.00
0005433367493	21704	Economy	16700.00
0005433367504	21704	Economy	16700.00
0005433367511	21704	Economy	16700.00
0005433367509	21704	Economy	16700.00
0005433985516	4179	Business	21500.00
0005435788745	4179	Business	21500.00
0005433985506	4179	Business	21500.00
0005433985485	4179	Business	21500.00
0005433985500	4179	Business	21500.00
0005433985508	4179	Business	21500.00
0005433985465	4179	Business	21500.00
0005433985464	4179	Business	21500.00
0005433985493	4179	Business	21500.00
0005433985501	4179	Economy	7200.00
0005433985477	4179	Economy	7200.00
0005433985514	4179	Economy	7200.00
0005433985471	4179	Economy	7900.00
0005433985494	4179	Economy	7900.00
0005433985483	4179	Economy	7900.00
0005433985470	4179	Economy	7900.00
0005433985507	4179	Economy	7900.00
0005433985497	4179	Economy	7200.00
0005433985486	4179	Economy	7200.00
0005433985472	4179	Economy	7200.00
0005433985515	4179	Economy	7200.00
0005433985513	4179	Economy	7200.00
0005433985502	4179	Economy	7200.00
0005433985504	4179	Economy	7200.00
0005433985466	4179	Economy	7200.00
0005433985473	4179	Economy	7200.00
0005433985505	4179	Economy	7200.00
0005433985509	4179	Economy	7200.00
0005433985491	4179	Economy	7200.00
0005433985487	4179	Economy	7200.00
0005433985478	4179	Economy	7200.00
0005433985484	4179	Economy	7200.00
0005433985469	4179	Economy	7200.00
0005433985468	4179	Economy	7200.00
0005433985510	4179	Economy	7200.00
0005435788746	4179	Economy	7200.00
0005433985503	4179	Economy	7200.00
0005433985479	4179	Economy	7200.00
0005433985492	4179	Economy	7200.00
0005433985511	4179	Economy	7200.00
0005433985512	4179	Economy	7200.00
0005433985476	4179	Economy	7200.00
0005433985480	4179	Economy	7200.00
0005433985499	4179	Economy	7200.00
0005433985498	4179	Economy	7200.00
0005433985489	4179	Economy	7200.00
0005433985481	4179	Economy	7200.00
0005433985496	4179	Economy	7200.00
0005433985495	4179	Economy	7200.00
0005435788747	4179	Economy	7200.00
0005433985488	4179	Economy	7200.00
0005433985474	4179	Economy	7200.00
0005435788744	4179	Economy	7200.00
0005433985490	4179	Economy	7200.00
0005433985475	4179	Economy	7200.00
0005433985467	4179	Economy	7200.00
0005433985482	4179	Economy	7200.00
0005433460400	20243	Business	201300.00
0005433460411	20243	Business	201300.00
0005433460403	20243	Business	201300.00
0005433461560	20243	Business	201300.00
0005433460401	20243	Economy	73800.00
0005433460409	20243	Economy	67100.00
0005433461562	20243	Economy	67100.00
0005433461564	20243	Economy	67100.00
0005433460407	20243	Economy	67100.00
0005433460406	20243	Economy	67100.00
0005433460405	20243	Economy	67100.00
0005433461559	20243	Economy	67100.00
0005433461554	20243	Economy	67100.00
0005433461558	20243	Economy	67100.00
0005433460412	20243	Economy	67100.00
0005433461550	20243	Economy	67100.00
0005433460408	20243	Economy	67100.00
0005433461561	20243	Economy	67100.00
0005433460398	20243	Economy	67100.00
0005433461557	20243	Economy	67100.00
0005433461556	20243	Economy	67100.00
0005433460410	20243	Economy	67100.00
0005433461553	20243	Economy	67100.00
0005433460399	20243	Economy	67100.00
0005433461563	20243	Economy	67100.00
0005433460404	20243	Economy	67100.00
0005433461552	20243	Economy	67100.00
0005433460402	20243	Economy	67100.00
0005433461551	20243	Economy	67100.00
0005433461555	20243	Economy	67100.00
0005435720125	24763	Economy	10400.00
0005435720126	24763	Economy	9400.00
0005435719556	24763	Economy	9400.00
0005435719557	24763	Economy	9400.00
0005433168331	21329	Economy	17000.00
0005433168330	21329	Economy	15500.00
0005434509029	21329	Economy	15500.00
0005433168328	21329	Economy	15500.00
0005433168329	21329	Economy	15500.00
0005434509015	21329	Economy	15500.00
0005433168327	21329	Economy	15500.00
0005433168332	21329	Economy	15500.00
0005433168325	21329	Economy	15500.00
0005434509016	21329	Economy	15500.00
0005433168326	21329	Economy	15500.00
0005434509030	21329	Economy	15500.00
0005432655340	17851	Business	18000.00
0005432655341	17851	Economy	6000.00
0005434151675	17851	Economy	6000.00
0005432666360	17851	Economy	6000.00
0005432657393	17851	Economy	6000.00
0005432869463	17851	Economy	6000.00
0005432869464	17851	Economy	6000.00
0005432869462	17851	Economy	6000.00
0005432658555	17851	Economy	6000.00
0005432666359	17851	Economy	6000.00
0005434151677	17851	Economy	6000.00
0005432869461	17851	Economy	6000.00
0005434151676	17851	Economy	6000.00
0005432658556	17851	Economy	6000.00
0005432665237	17851	Economy	6000.00
0005432869460	17851	Economy	6000.00
0005432869459	17851	Economy	6000.00
0005432655390	26307	Business	18000.00
0005432660794	26307	Business	18000.00
0005432655395	26307	Business	18000.00
0005432655392	26307	Business	18000.00
0005432655397	26307	Business	18000.00
0005432655398	26307	Business	18000.00
0005432666363	26307	Business	18000.00
0005432667431	26307	Economy	6000.00
0005432665250	26307	Economy	6000.00
0005432655389	26307	Economy	6600.00
0005432659682	26307	Economy	6600.00
0005432665251	26307	Economy	6000.00
0005432659683	26307	Economy	6000.00
0005432655399	26307	Economy	6000.00
0005432655387	26307	Economy	6000.00
0005432655396	26307	Economy	6000.00
0005432666365	26307	Economy	6000.00
0005432655388	26307	Economy	6000.00
0005432667430	26307	Economy	6000.00
0005432655391	26307	Economy	6000.00
0005432660793	26307	Economy	6000.00
0005432666364	26307	Economy	6000.00
0005432658567	26307	Economy	6000.00
0005432655394	26307	Economy	6000.00
0005432667429	26307	Economy	6000.00
0005432657414	26307	Economy	6000.00
0005432655393	26307	Economy	6000.00
0005432328265	3079	Business	16100.00
0005432328232	3079	Business	16100.00
0005432328243	3079	Business	16100.00
0005432328262	3079	Business	16100.00
0005432328249	3079	Business	16100.00
0005432328234	3079	Business	16100.00
0005432287139	3079	Business	16100.00
0005432328252	3079	Business	16100.00
0005432328239	3079	Economy	5400.00
0005432328240	3079	Economy	5400.00
0005432905041	3079	Economy	5400.00
0005432287137	3079	Economy	5400.00
0005432328242	3079	Economy	5900.00
0005432328229	3079	Economy	5900.00
0005432287140	3079	Economy	5900.00
0005432328228	3079	Economy	5400.00
0005432328251	3079	Economy	5400.00
0005432328258	3079	Economy	5400.00
0005432328221	3079	Economy	5400.00
0005432328220	3079	Economy	5400.00
0005432328255	3079	Economy	5400.00
0005432328245	3079	Economy	5400.00
0005432328259	3079	Economy	5400.00
0005432328260	3079	Economy	5400.00
0005432328223	3079	Economy	5400.00
0005432328236	3079	Economy	5400.00
0005432328235	3079	Economy	5400.00
0005432328238	3079	Economy	5400.00
0005432328233	3079	Economy	5400.00
0005432287136	3079	Economy	5400.00
0005432905028	3079	Economy	5400.00
0005432328222	3079	Economy	5400.00
0005432328263	3079	Economy	5400.00
0005432328225	3079	Economy	5400.00
0005432328261	3079	Economy	5400.00
0005432905031	3079	Economy	5400.00
0005432328226	3079	Economy	5400.00
0005432328237	3079	Economy	5400.00
0005432905027	3079	Economy	5400.00
0005432328256	3079	Economy	5400.00
0005432328254	3079	Economy	5400.00
0005432328257	3079	Economy	5400.00
0005432328247	3079	Economy	5400.00
0005432328231	3079	Economy	5400.00
0005432328219	3079	Economy	5400.00
0005432328253	3079	Economy	5400.00
0005433438813	3079	Economy	5400.00
0005432328224	3079	Economy	5400.00
0005432328244	3079	Economy	5400.00
0005432328241	3079	Economy	5400.00
0005432328248	3079	Economy	5400.00
0005433438812	3079	Economy	5400.00
0005432328246	3079	Economy	5400.00
0005432328230	3079	Economy	5400.00
0005432328227	3079	Economy	5400.00
0005432328264	3079	Economy	5400.00
0005432328250	3079	Economy	5400.00
0005432287138	3079	Economy	5400.00
0005432905064	31131	Business	16100.00
0005432327930	31131	Business	16100.00
0005432054273	31131	Business	16100.00
0005432328033	31131	Economy	5400.00
0005432328034	31131	Economy	5900.00
0005432327905	31131	Economy	5400.00
0005432905066	31131	Economy	5400.00
0005432905069	31131	Economy	5400.00
0005432327931	31131	Economy	5400.00
0005432327901	31131	Economy	5400.00
0005432905067	31131	Economy	5400.00
0005432054275	31131	Economy	5400.00
0005432328004	31131	Economy	5400.00
0005432905065	31131	Economy	5400.00
0005432327919	31131	Economy	5400.00
0005432327902	31131	Economy	5400.00
0005432327906	31131	Economy	5400.00
0005432905068	31131	Economy	5400.00
0005432905063	31131	Economy	5400.00
0005432328006	31131	Economy	5400.00
0005432328005	31131	Economy	5400.00
0005432054274	31131	Economy	5400.00
0005435999090	6209	Business	124600.00
0005435999087	6209	Business	124600.00
0005435999086	6209	Business	124600.00
0005435296957	6209	Business	124600.00
0005434309602	6209	Economy	41500.00
0005435999083	6209	Economy	41500.00
0005435487468	6209	Economy	41500.00
0005435999069	6209	Economy	41500.00
0005435999080	6209	Economy	41500.00
0005434309607	6209	Economy	41500.00
0005435999078	6209	Economy	41500.00
0005435999081	6209	Economy	41500.00
0005434309600	6209	Economy	41500.00
0005435999085	6209	Economy	41500.00
0005435999073	6209	Economy	41500.00
0005432146179	6209	Economy	41500.00
0005435999079	6209	Economy	41500.00
0005435999075	6209	Economy	41500.00
0005435999074	6209	Economy	41500.00
0005434309606	6209	Economy	41500.00
0005435999076	6209	Economy	45700.00
0005434309604	6209	Economy	45700.00
0005434309599	6209	Economy	41500.00
0005435999093	6209	Economy	41500.00
0005435999088	6209	Economy	41500.00
0005435999077	6209	Economy	41500.00
0005435999071	6209	Economy	41500.00
0005434309603	6209	Economy	41500.00
0005434309601	6209	Economy	41500.00
0005435999072	6209	Economy	41500.00
0005435999084	6209	Economy	41500.00
0005435296953	6209	Economy	41500.00
0005434309608	6209	Economy	41500.00
0005435999091	6209	Economy	41500.00
0005435999089	6209	Economy	41500.00
0005432146178	6209	Economy	41500.00
0005435999070	6209	Economy	41500.00
0005435999092	6209	Economy	41500.00
0005434309611	6209	Economy	41500.00
0005434309598	6209	Economy	41500.00
0005435487461	6209	Economy	41500.00
0005434309609	6209	Economy	41500.00
0005434309605	6209	Economy	41500.00
0005435999082	6209	Economy	41500.00
0005434309610	6209	Economy	41500.00
0005434309531	19580	Business	124600.00
0005435487596	19580	Business	124600.00
0005435487594	19580	Business	124600.00
0005435487589	19580	Economy	41500.00
0005435296991	19580	Economy	41500.00
0005435487587	19580	Economy	41500.00
0005435487592	19580	Economy	41500.00
0005435487603	19580	Economy	41500.00
0005434309505	19580	Economy	41500.00
0005434309521	19580	Economy	41500.00
0005435487607	19580	Economy	41500.00
0005434309532	19580	Economy	41500.00
0005435487586	19580	Economy	41500.00
0005434309533	19580	Economy	41500.00
0005435487608	19580	Economy	41500.00
0005435487601	19580	Economy	41500.00
0005435296992	19580	Economy	41500.00
0005434309509	19580	Economy	45700.00
0005435296990	19580	Economy	45700.00
0005435487595	19580	Economy	41500.00
0005435487590	19580	Economy	41500.00
0005435487604	19580	Economy	41500.00
0005434309542	19580	Economy	41500.00
0005435296987	19580	Economy	41500.00
0005435487598	19580	Economy	41500.00
0005434309508	19580	Economy	41500.00
0005435487605	19580	Economy	41500.00
0005434309541	19580	Economy	41500.00
0005435487602	19580	Economy	41500.00
0005435296988	19580	Economy	41500.00
0005435487600	19580	Economy	41500.00
0005435487588	19580	Economy	41500.00
0005435487599	19580	Economy	41500.00
0005435296989	19580	Economy	41500.00
0005435487606	19580	Economy	41500.00
0005435487597	19580	Economy	41500.00
0005435487593	19580	Economy	41500.00
0005435487591	19580	Economy	41500.00
0005433158104	17552	Economy	13600.00
0005433158111	17552	Economy	12300.00
0005433158106	17552	Economy	12300.00
0005433158105	17552	Economy	12300.00
0005433158109	17552	Economy	12300.00
0005433158110	17552	Economy	12300.00
0005433158107	17552	Economy	12300.00
0005433158108	17552	Economy	12300.00
0005435508240	1575	Business	86000.00
0005435508244	1575	Business	86000.00
0005435517741	1575	Business	86000.00
0005435502105	1575	Business	86000.00
0005435517742	1575	Business	86000.00
0005434565784	1575	Business	86000.00
0005435508248	1575	Business	86000.00
0005435502100	1575	Business	86000.00
0005432291906	1575	Business	86000.00
0005435502101	1575	Economy	28700.00
0005435517739	1575	Economy	28700.00
0005435502106	1575	Economy	28700.00
0005435517747	1575	Economy	28700.00
0005435502102	1575	Economy	28700.00
0005435517738	1575	Economy	31500.00
0005434565780	1575	Economy	31500.00
0005434565775	1575	Economy	31500.00
0005434565783	1575	Economy	31500.00
0005434565781	1575	Economy	28700.00
0005435502107	1575	Economy	28700.00
0005435508239	1575	Economy	28700.00
0005432291907	1575	Economy	28700.00
0005435517737	1575	Economy	28700.00
0005432291905	1575	Economy	28700.00
0005435502086	1575	Economy	28700.00
0005435517735	1575	Economy	28700.00
0005433185981	1575	Economy	28700.00
0005435502093	1575	Economy	28700.00
0005435502099	1575	Economy	28700.00
0005434565786	1575	Economy	28700.00
0005435502087	1575	Economy	28700.00
0005434565779	1575	Economy	28700.00
0005435502090	1575	Economy	28700.00
0005435508246	1575	Economy	28700.00
0005435508241	1575	Economy	28700.00
0005435517736	1575	Economy	28700.00
0005434565777	1575	Economy	28700.00
0005435517748	1575	Economy	28700.00
0005435502089	1575	Economy	28700.00
0005435508249	1575	Economy	28700.00
0005435502095	1575	Economy	28700.00
0005435502088	1575	Economy	28700.00
0005435502098	1575	Economy	28700.00
0005435517743	1575	Economy	28700.00
0005435508242	1575	Economy	28700.00
0005434565778	1575	Economy	28700.00
0005433185980	1575	Economy	28700.00
0005435502104	1575	Economy	28700.00
0005433185971	1575	Economy	28700.00
0005435508235	1575	Economy	28700.00
0005435517745	1575	Economy	28700.00
0005434565787	1575	Economy	28700.00
0005435517740	1575	Economy	28700.00
0005435502103	1575	Economy	28700.00
0005435508236	1575	Economy	28700.00
0005435502094	1575	Economy	28700.00
0005435508238	1575	Economy	28700.00
0005434565785	1575	Economy	28700.00
0005435517746	1575	Economy	28700.00
0005435508237	1575	Economy	28700.00
0005435502091	1575	Economy	28700.00
0005435508245	1575	Economy	28700.00
0005435517744	1575	Economy	28700.00
0005435508247	1575	Economy	28700.00
0005435517733	1575	Economy	28700.00
0005435502092	1575	Economy	28700.00
0005434565782	1575	Economy	28700.00
0005434565776	1575	Economy	28700.00
0005435502096	1575	Economy	28700.00
0005435517732	1575	Economy	28700.00
0005435517734	1575	Economy	28700.00
0005435502097	1575	Economy	28700.00
0005435508243	1575	Economy	28700.00
0005433186030	20859	Business	86000.00
0005434565691	20859	Business	86000.00
0005434565689	20859	Business	86000.00
0005433186035	20859	Business	86000.00
0005433186033	20859	Economy	28700.00
0005433186038	20859	Economy	28700.00
0005435501942	20859	Economy	28700.00
0005434565699	20859	Economy	28700.00
0005434565706	20859	Economy	28700.00
0005433186034	20859	Economy	28700.00
0005433186031	20859	Economy	28700.00
0005434565693	20859	Economy	28700.00
0005435501949	20859	Economy	28700.00
0005434565690	20859	Economy	28700.00
0005433186037	20859	Economy	28700.00
0005433186036	20859	Economy	28700.00
0005435501943	20859	Economy	28700.00
0005433186032	20859	Economy	28700.00
0005435501941	20859	Economy	28700.00
0005435528921	20859	Economy	28700.00
0005435931537	3898	Economy	19700.00
0005435931542	3898	Economy	19700.00
0005435153676	3898	Economy	19700.00
0005435931538	3898	Economy	19700.00
0005435153674	3898	Economy	19700.00
0005435153678	3898	Economy	19700.00
0005435153675	3898	Economy	19700.00
0005435153679	3898	Economy	19700.00
0005435153677	3898	Economy	19700.00
0005435931564	21855	Economy	21600.00
0005435153629	21855	Economy	21600.00
0005435931565	21855	Economy	21600.00
0005435153630	21855	Economy	19700.00
0005435931563	21855	Economy	19700.00
0005432628693	7228	Economy	14300.00
0005432628699	7228	Economy	13000.00
0005432628700	7228	Economy	13000.00
0005432628705	7228	Economy	13000.00
0005432628697	7228	Economy	13000.00
0005432628691	7228	Economy	13000.00
0005432628692	7228	Economy	13000.00
0005432628704	7228	Economy	13000.00
0005432628702	7228	Economy	13000.00
0005432628701	7228	Economy	13000.00
0005432628694	7228	Economy	13000.00
0005432628696	7228	Economy	13000.00
0005432628698	7228	Economy	13000.00
0005432628703	7228	Economy	13000.00
0005435225443	7228	Economy	13000.00
0005432628695	7228	Economy	13000.00
0005432628610	28144	Economy	14300.00
0005432628617	28144	Economy	13000.00
0005435225506	28144	Economy	13000.00
0005432628614	28144	Economy	13000.00
0005435225503	28144	Economy	13000.00
0005435225501	28144	Economy	13000.00
0005435225508	28144	Economy	13000.00
0005432628605	28144	Economy	13000.00
0005435225510	28144	Economy	13000.00
0005432628616	28144	Economy	13000.00
0005435225504	28144	Economy	13000.00
0005432628615	28144	Economy	13000.00
0005432628609	28144	Economy	13000.00
0005435225509	28144	Economy	13000.00
0005435225507	28144	Economy	13000.00
0005435225505	28144	Economy	13000.00
0005435225502	28144	Economy	13000.00
0005432628618	28144	Economy	13000.00
0005432628604	28144	Economy	13000.00
0005435225500	28144	Economy	13000.00
0005432628602	28144	Economy	13000.00
0005432628603	28144	Economy	13000.00
0005435960012	8748	Economy	10500.00
0005435960013	8748	Economy	10500.00
0005435960011	8748	Economy	10500.00
0005434267890	8748	Economy	10500.00
0005435960010	8748	Economy	10500.00
0005435960014	8748	Economy	10500.00
0005435960015	8748	Economy	10500.00
0005434267912	15254	Economy	11500.00
0005434267911	15254	Economy	10500.00
0005435959986	15254	Economy	10500.00
0005434267913	15254	Economy	10500.00
0005432692725	1183	Business	115000.00
0005432692729	1183	Business	115000.00
0005432674975	1183	Business	115000.00
0005432674977	1183	Business	115000.00
0005432692741	1183	Business	115000.00
0005432674981	1183	Business	115000.00
0005432692728	1183	Business	115000.00
0005432873166	1183	Business	115000.00
0005432692747	1183	Business	115000.00
0005432692727	1183	Business	115000.00
0005432692744	1183	Economy	38300.00
0005432674974	1183	Economy	38300.00
0005432692739	1183	Economy	38300.00
0005432692738	1183	Economy	38300.00
0005432692742	1183	Economy	38300.00
0005432692723	1183	Economy	38300.00
0005432692730	1183	Economy	38300.00
0005432692724	1183	Economy	42200.00
0005432692732	1183	Economy	42200.00
0005432692737	1183	Economy	38300.00
0005432674985	1183	Economy	38300.00
0005432692720	1183	Economy	38300.00
0005432674984	1183	Economy	38300.00
0005432873179	1183	Economy	38300.00
0005432692745	1183	Economy	38300.00
0005432692731	1183	Economy	38300.00
0005432677529	1183	Economy	38300.00
0005432692736	1183	Economy	38300.00
0005432692735	1183	Economy	38300.00
0005432692722	1183	Economy	38300.00
0005432692717	1183	Economy	38300.00
0005432692721	1183	Economy	38300.00
0005432674978	1183	Economy	38300.00
0005432692718	1183	Economy	38300.00
0005432674972	1183	Economy	38300.00
0005432677531	1183	Economy	38300.00
0005432677530	1183	Economy	38300.00
0005432873189	1183	Economy	38300.00
0005432674980	1183	Economy	38300.00
0005432674973	1183	Economy	38300.00
0005432677528	1183	Economy	38300.00
0005432873165	1183	Economy	38300.00
0005432674979	1183	Economy	38300.00
0005432692740	1183	Economy	38300.00
0005432692733	1183	Economy	38300.00
0005432677532	1183	Economy	38300.00
0005432692719	1183	Economy	38300.00
0005432692746	1183	Economy	38300.00
0005432674983	1183	Economy	38300.00
0005432692734	1183	Economy	38300.00
0005432674971	1183	Economy	38300.00
0005432674986	1183	Economy	38300.00
0005432674982	1183	Economy	38300.00
0005432692726	1183	Economy	38300.00
0005432674976	1183	Economy	38300.00
0005432692743	1183	Economy	38300.00
0005432873222	17512	Economy	38300.00
0005432677508	17512	Economy	42200.00
0005432873217	17512	Economy	42200.00
0005432692536	17512	Economy	38300.00
0005432873223	17512	Economy	38300.00
0005432873219	17512	Economy	38300.00
0005432677509	17512	Economy	38300.00
0005432692563	17512	Economy	38300.00
0005432873220	17512	Economy	38300.00
0005432692581	17512	Economy	38300.00
0005432873221	17512	Economy	38300.00
0005432692541	17512	Economy	38300.00
0005432692542	17512	Economy	38300.00
0005432674889	17512	Economy	38300.00
0005432677510	17512	Economy	38300.00
0005432674868	17512	Economy	38300.00
0005432873218	17512	Economy	38300.00
0005434435033	1138	Economy	13900.00
0005434435020	1138	Economy	13900.00
0005434435023	1138	Economy	13900.00
0005434435030	1138	Economy	13900.00
0005434435026	1138	Economy	13900.00
0005433156614	1138	Economy	13900.00
0005434435027	1138	Economy	13900.00
0005434435032	1138	Economy	13900.00
0005434435029	1138	Economy	13900.00
0005434435024	1138	Economy	13900.00
0005434435025	1138	Economy	13900.00
0005434435028	1138	Economy	13900.00
0005434435022	1138	Economy	13900.00
0005434435021	1138	Economy	13900.00
0005434435031	1138	Economy	13900.00
0005434434921	17330	Economy	13900.00
0005433156661	17330	Economy	13900.00
0005433156662	17330	Economy	13900.00
0005433156665	17330	Economy	13900.00
0005434434948	17330	Economy	13900.00
0005434434911	17330	Economy	13900.00
0005433156658	17330	Economy	13900.00
0005433156666	17330	Economy	13900.00
0005434434959	17330	Economy	13900.00
0005434434910	17330	Economy	13900.00
0005434434922	17330	Economy	13900.00
0005433156663	17330	Economy	13900.00
0005433156659	17330	Economy	13900.00
0005434434929	17330	Economy	13900.00
0005433156660	17330	Economy	13900.00
0005434434947	17330	Economy	13900.00
0005433156664	17330	Economy	13900.00
0005434434967	17330	Economy	13900.00
0005434434968	17330	Economy	13900.00
0005435086761	4060	Economy	7500.00
0005435086760	4060	Economy	7500.00
0005435086759	4060	Economy	7500.00
0005435086755	4060	Economy	7500.00
0005435086757	4060	Economy	7500.00
0005435086756	4060	Economy	7500.00
0005435086758	4060	Economy	7500.00
0005435928093	24437	Economy	7500.00
0005435928096	24437	Economy	7500.00
0005435928095	24437	Economy	7500.00
0005435928094	24437	Economy	7500.00
0005435086716	24437	Economy	7500.00
0005435928097	24437	Economy	7500.00
0005435086702	24437	Economy	7500.00
0005435928092	24437	Economy	7500.00
0005435098533	17004	Business	144300.00
0005435098534	17004	Business	144300.00
0005435098537	17004	Business	144300.00
0005435551524	17004	Business	144300.00
0005435551528	17004	Business	144300.00
0005435551516	17004	Business	144300.00
0005435551523	17004	Business	144300.00
0005435098529	17004	Business	144300.00
0005435551531	17004	Business	144300.00
0005435551526	17004	Economy	48100.00
0005435551532	17004	Economy	48100.00
0005435551522	17004	Economy	48100.00
0005435551535	17004	Economy	48100.00
0005435551527	17004	Economy	48100.00
0005435098530	17004	Economy	48100.00
0005435551514	17004	Economy	48100.00
0005435551533	17004	Economy	48100.00
0005435551519	17004	Economy	48100.00
0005435098535	17004	Economy	48100.00
0005435551525	17004	Economy	48100.00
0005435551536	17004	Economy	48100.00
0005435098532	17004	Economy	48100.00
0005435551534	17004	Economy	48100.00
0005435551529	17004	Economy	48100.00
0005435098531	17004	Economy	48100.00
0005435551517	17004	Economy	48100.00
0005435551518	17004	Economy	48100.00
0005435551520	17004	Economy	48100.00
0005435551513	17004	Economy	48100.00
0005435551530	17004	Economy	48100.00
0005435551515	17004	Economy	48100.00
0005435551521	17004	Economy	48100.00
0005435098536	17004	Economy	48100.00
0005434625866	4840	Business	44200.00
0005434625867	4840	Business	44200.00
0005434625865	4840	Business	44200.00
0005434625870	4840	Economy	14700.00
0005434625869	4840	Economy	14700.00
0005434625868	4840	Economy	14700.00
0005435907418	4840	Economy	14700.00
0005434625864	4840	Economy	14700.00
0005435907419	4840	Economy	14700.00
0005435907457	32882	Business	44200.00
0005433194828	32882	Business	44200.00
0005435907454	32882	Economy	14700.00
0005434625798	32882	Economy	16200.00
0005435907453	32882	Economy	14700.00
0005433194833	32882	Economy	14700.00
0005433194831	32882	Economy	14700.00
0005433194832	32882	Economy	14700.00
0005435907455	32882	Economy	14700.00
0005434625797	32882	Economy	14700.00
0005434625821	32882	Economy	14700.00
0005434625822	32882	Economy	14700.00
0005435907456	32882	Economy	14700.00
0005433194829	32882	Economy	14700.00
0005433194830	32882	Economy	14700.00
0005432195671	13800	Economy	3400.00
0005435784727	13800	Economy	3100.00
0005435784811	13800	Economy	3100.00
0005435784740	13800	Economy	3100.00
0005435784782	13800	Economy	3100.00
0005435784743	13800	Economy	3100.00
0005435784733	13800	Economy	3100.00
0005432195672	13800	Economy	3100.00
0005435784728	13800	Economy	3100.00
0005435784734	13800	Economy	3100.00
0005435784950	27416	Economy	3400.00
0005435784961	27416	Economy	3400.00
0005435784965	27416	Economy	3400.00
0005435784946	27416	Economy	3400.00
0005432190586	27416	Economy	3100.00
0005432190584	27416	Economy	3100.00
0005435784960	27416	Economy	3100.00
0005435784945	27416	Economy	3100.00
0005435784968	27416	Economy	3100.00
0005435784976	27416	Economy	3100.00
0005435784955	27416	Economy	3100.00
0005435787329	27416	Economy	3100.00
0005432190583	27416	Economy	3100.00
0005435784975	27416	Economy	3100.00
0005435784956	27416	Economy	3100.00
0005435784969	27416	Economy	3100.00
0005435784963	27416	Economy	3100.00
0005435784940	27416	Economy	3100.00
0005435784964	27416	Economy	3100.00
0005435784967	27416	Economy	3100.00
0005432190585	27416	Economy	3100.00
0005435784972	27416	Economy	3100.00
0005435784958	27416	Economy	3100.00
0005435787328	27416	Economy	3100.00
0005435784954	27416	Economy	3100.00
0005435784949	27416	Economy	3100.00
0005435784953	27416	Economy	3100.00
0005435784970	27416	Economy	3100.00
0005435784948	27416	Economy	3100.00
0005435784973	27416	Economy	3100.00
0005435784942	27416	Economy	3100.00
0005435784952	27416	Economy	3100.00
0005435784939	27416	Economy	3100.00
0005435784944	27416	Economy	3100.00
0005435784962	27416	Economy	3100.00
0005435784951	27416	Economy	3100.00
0005435784947	27416	Economy	3100.00
0005435784941	27416	Economy	3100.00
0005435784971	27416	Economy	3100.00
0005435784943	27416	Economy	3100.00
0005435784959	27416	Economy	3100.00
0005435784974	27416	Economy	3100.00
0005435784966	27416	Economy	3100.00
0005435784957	27416	Economy	3100.00
0005434406663	20265	Business	12000.00
0005434406751	20265	Economy	4000.00
0005432058343	20265	Economy	4000.00
0005434406810	20265	Economy	4400.00
0005434406834	20265	Economy	4400.00
0005434406821	20265	Economy	4000.00
0005434406800	20265	Economy	4000.00
0005434406743	20265	Economy	4000.00
0005434406784	20265	Economy	4000.00
0005435310946	20265	Economy	4000.00
0005432058341	20265	Economy	4000.00
0005432058340	20265	Economy	4000.00
0005435310945	20265	Economy	4000.00
0005434406729	20265	Economy	4000.00
0005434406770	20265	Economy	4000.00
0005434406783	20265	Economy	4000.00
0005434406662	20265	Economy	4000.00
0005435310942	20265	Economy	4000.00
0005434406730	20265	Economy	4000.00
0005434406674	20265	Economy	4000.00
0005434406917	20265	Economy	4000.00
0005435310948	20265	Economy	4000.00
0005434406742	20265	Economy	4000.00
0005435310943	20265	Economy	4000.00
0005435310947	20265	Economy	4000.00
0005435310944	20265	Economy	4000.00
0005434406660	20265	Economy	4000.00
0005432058342	20265	Economy	4000.00
0005434406713	20265	Economy	4000.00
0005434406862	20265	Economy	4000.00
0005434407109	27015	Business	12000.00
0005434407089	27015	Business	12000.00
0005434407121	27015	Business	12000.00
0005434407147	27015	Business	12000.00
0005434407090	27015	Business	12000.00
0005434407103	27015	Business	12000.00
0005434407149	27015	Business	12000.00
0005434407129	27015	Business	12000.00
0005434407130	27015	Business	12000.00
0005434407092	27015	Business	12000.00
0005434407088	27015	Economy	4000.00
0005434407119	27015	Economy	4000.00
0005434407117	27015	Economy	4000.00
0005434407123	27015	Economy	4000.00
0005434407133	27015	Economy	4000.00
0005434407143	27015	Economy	4000.00
0005434407136	27015	Economy	4000.00
0005434407138	27015	Economy	4400.00
0005434407126	27015	Economy	4400.00
0005434407106	27015	Economy	4400.00
0005432153866	27015	Economy	4400.00
0005432153864	27015	Economy	4000.00
0005434407120	27015	Economy	4000.00
0005434407097	27015	Economy	4000.00
0005434407099	27015	Economy	4000.00
0005434407116	27015	Economy	4000.00
0005434407111	27015	Economy	4000.00
0005434407095	27015	Economy	4000.00
0005432153868	27015	Economy	4000.00
0005434407101	27015	Economy	4000.00
0005434407114	27015	Economy	4000.00
0005434407094	27015	Economy	4000.00
0005434407107	27015	Economy	4000.00
0005434407100	27015	Economy	4000.00
0005434407140	27015	Economy	4000.00
0005434407137	27015	Economy	4000.00
0005434407152	27015	Economy	4000.00
0005434407093	27015	Economy	4000.00
0005434407144	27015	Economy	4000.00
0005434407142	27015	Economy	4000.00
0005434407113	27015	Economy	4000.00
0005434407091	27015	Economy	4000.00
0005434407146	27015	Economy	4000.00
0005434407145	27015	Economy	4000.00
0005434407105	27015	Economy	4000.00
0005434407128	27015	Economy	4000.00
0005434407102	27015	Economy	4000.00
0005434407115	27015	Economy	4000.00
0005434407153	27015	Economy	4000.00
0005434407118	27015	Economy	4000.00
0005434407150	27015	Economy	4000.00
0005434407104	27015	Economy	4000.00
0005434407148	27015	Economy	4000.00
0005434407134	27015	Economy	4000.00
0005434407096	27015	Economy	4000.00
0005434407124	27015	Economy	4000.00
0005432153865	27015	Economy	4000.00
0005434407098	27015	Economy	4000.00
0005434407127	27015	Economy	4000.00
0005434407131	27015	Economy	4000.00
0005434407139	27015	Economy	4000.00
0005432153867	27015	Economy	4000.00
0005432153869	27015	Economy	4000.00
0005434407135	27015	Economy	4000.00
0005434407112	27015	Economy	4000.00
0005434407108	27015	Economy	4000.00
0005434407110	27015	Economy	4000.00
0005434407132	27015	Economy	4000.00
0005434407125	27015	Economy	4000.00
0005434407151	27015	Economy	4000.00
0005434407141	27015	Economy	4000.00
0005434407154	27015	Economy	4000.00
0005434407122	27015	Economy	4000.00
0005434319243	5684	Business	43300.00
0005433123584	5684	Business	43300.00
0005433123572	5684	Business	43300.00
0005434319248	5684	Business	43300.00
0005433123578	5684	Economy	14400.00
0005434311197	5684	Economy	14400.00
0005433123579	5684	Economy	14400.00
0005433123569	5684	Economy	14400.00
0005433123583	5684	Economy	14400.00
0005434319241	5684	Economy	14400.00
0005434319246	5684	Economy	14400.00
0005434319247	5684	Economy	14400.00
0005434319244	5684	Economy	14400.00
0005434311200	5684	Economy	14400.00
0005433123585	5684	Economy	14400.00
0005434311198	5684	Economy	14400.00
0005434311199	5684	Economy	14400.00
0005432109676	5684	Economy	14400.00
0005433123568	5684	Economy	14400.00
0005434319242	5684	Economy	14400.00
0005432109675	5684	Economy	14400.00
0005434319245	5684	Economy	14400.00
0005433123610	5684	Economy	14400.00
0005433123714	15649	Business	43300.00
0005433123719	15649	Business	43300.00
0005433123732	15649	Business	43300.00
0005434311182	15649	Economy	14400.00
0005433123723	15649	Economy	14400.00
0005433123730	15649	Economy	14400.00
0005433123735	15649	Economy	14400.00
0005433123716	15649	Economy	15900.00
0005433123727	15649	Economy	14400.00
0005433123734	15649	Economy	14400.00
0005434312287	15649	Economy	14400.00
0005433123725	15649	Economy	14400.00
0005434311185	15649	Economy	14400.00
0005433123720	15649	Economy	14400.00
0005433123721	15649	Economy	14400.00
0005433123722	15649	Economy	14400.00
0005433123729	15649	Economy	14400.00
0005433123715	15649	Economy	14400.00
0005434319142	15649	Economy	14400.00
0005433123736	15649	Economy	14400.00
0005434312283	15649	Economy	14400.00
0005433123724	15649	Economy	14400.00
0005433123718	15649	Economy	14400.00
0005433123726	15649	Economy	14400.00
0005433123728	15649	Economy	14400.00
0005433123717	15649	Economy	14400.00
0005434319141	15649	Economy	14400.00
0005433123733	15649	Economy	14400.00
0005433123731	15649	Economy	14400.00
0005434312288	15649	Economy	14400.00
0005435220295	31754	Economy	17100.00
0005435219179	31754	Economy	15500.00
0005435220299	31754	Economy	15500.00
0005435219175	31754	Economy	15500.00
0005435219178	31754	Economy	15500.00
0005435220296	31754	Economy	15500.00
0005435219176	31754	Economy	15500.00
0005435220298	31754	Economy	15500.00
0005435220297	31754	Economy	15500.00
0005435219180	31754	Economy	15500.00
0005435219177	31754	Economy	15500.00
0005434484281	9014	Economy	24900.00
0005434484283	9014	Economy	24900.00
0005434484278	9014	Economy	24900.00
0005434484280	9014	Economy	24900.00
0005434484279	9014	Economy	24900.00
0005434189076	9014	Economy	24900.00
0005434484282	9014	Economy	24900.00
0005434484284	9014	Economy	24900.00
0005434189120	16647	Economy	24900.00
0005434189119	16647	Economy	24900.00
0005434189117	16647	Economy	24900.00
0005434189122	16647	Economy	24900.00
0005434189121	16647	Economy	24900.00
0005434484247	16647	Economy	24900.00
0005434189118	16647	Economy	24900.00
0005433123720	7653	Business	11100.00
0005433123717	7653	Business	11100.00
0005433123736	7653	Business	11100.00
0005433123714	7653	Business	11100.00
0005433123733	7653	Business	11100.00
0005433123719	7653	Economy	3700.00
0005433123730	7653	Economy	4100.00
0005433123718	7653	Economy	3700.00
0005433123726	7653	Economy	3700.00
0005433123722	7653	Economy	3700.00
0005433123729	7653	Economy	3700.00
0005433123727	7653	Economy	3700.00
0005433123723	7653	Economy	3700.00
0005433123734	7653	Economy	3700.00
0005433123735	7653	Economy	3700.00
0005433123731	7653	Economy	3700.00
0005433123728	7653	Economy	3700.00
0005433123732	7653	Economy	3700.00
0005433123724	7653	Economy	3700.00
0005433123716	7653	Economy	3700.00
0005433123715	7653	Economy	3700.00
0005433123721	7653	Economy	3700.00
0005433123725	7653	Economy	3700.00
0005433449757	7586	Business	11100.00
0005432720642	7586	Business	11100.00
0005433449756	7586	Business	11100.00
0005432692779	7586	Business	11100.00
0005433449741	7586	Business	11100.00
0005432720648	7586	Business	11100.00
0005432692770	7586	Business	11100.00
0005432720627	7586	Business	11100.00
0005433449754	7586	Business	11100.00
0005432720630	7586	Business	11100.00
0005432692755	7586	Business	11100.00
0005433449740	7586	Economy	3700.00
0005432692769	7586	Economy	3700.00
0005432692758	7586	Economy	3700.00
0005432720632	7586	Economy	3700.00
0005432692752	7586	Economy	3700.00
0005433449752	7586	Economy	3700.00
0005432692765	7586	Economy	3700.00
0005433449743	7586	Economy	3700.00
0005432720643	7586	Economy	3700.00
0005432720637	7586	Economy	3700.00
0005432692768	7586	Economy	4100.00
0005432720623	7586	Economy	4100.00
0005432720634	7586	Economy	4100.00
0005433449744	7586	Economy	4100.00
0005432720645	7586	Economy	4100.00
0005433449759	7586	Economy	3700.00
0005432692756	7586	Economy	3700.00
0005432720620	7586	Economy	3700.00
0005432720628	7586	Economy	3700.00
0005432692773	7586	Economy	3700.00
0005432720631	7586	Economy	3700.00
0005432720629	7586	Economy	3700.00
0005433449758	7586	Economy	3700.00
0005433449760	7586	Economy	3700.00
0005432720646	7586	Economy	3700.00
0005433449755	7586	Economy	3700.00
0005432720622	7586	Economy	3700.00
0005432692777	7586	Economy	3700.00
0005432692767	7586	Economy	3700.00
0005432071544	7586	Economy	3700.00
0005433449747	7586	Economy	3700.00
0005432692772	7586	Economy	3700.00
0005432692764	7586	Economy	3700.00
0005432692748	7586	Economy	3700.00
0005432692763	7586	Economy	3700.00
0005432720624	7586	Economy	3700.00
0005432692761	7586	Economy	3700.00
0005432692762	7586	Economy	3700.00
0005433449748	7586	Economy	3700.00
0005432692766	7586	Economy	3700.00
0005432692750	7586	Economy	3700.00
0005432692751	7586	Economy	3700.00
0005432720640	7586	Economy	3700.00
0005432692771	7586	Economy	3700.00
0005432692778	7586	Economy	3700.00
0005432692757	7586	Economy	3700.00
0005432720621	7586	Economy	3700.00
0005432071545	7586	Economy	3700.00
0005432692754	7586	Economy	3700.00
0005433449746	7586	Economy	3700.00
0005432692776	7586	Economy	3700.00
0005432720635	7586	Economy	3700.00
0005433449750	7586	Economy	3700.00
0005433449749	7586	Economy	3700.00
0005433449745	7586	Economy	3700.00
0005432720644	7586	Economy	3700.00
0005432720626	7586	Economy	3700.00
0005432720641	7586	Economy	3700.00
0005432720647	7586	Economy	3700.00
0005432720639	7586	Economy	3700.00
0005432692760	7586	Economy	3700.00
0005432692759	7586	Economy	3700.00
0005433449753	7586	Economy	3700.00
0005432071543	7586	Economy	3700.00
0005432692753	7586	Economy	3700.00
0005432720636	7586	Economy	3700.00
0005433449751	7586	Economy	3700.00
0005432071542	7586	Economy	3700.00
0005433449761	7586	Economy	3700.00
0005432692749	7586	Economy	3700.00
0005432720633	7586	Economy	3700.00
0005432692775	7586	Economy	3700.00
0005432720638	7586	Economy	3700.00
0005433449739	7586	Economy	3700.00
0005432692774	7586	Economy	3700.00
0005433449742	7586	Economy	3700.00
0005432720625	7586	Economy	3700.00
0005433449661	30392	Economy	3700.00
0005432692536	30392	Economy	3700.00
0005432692542	30392	Economy	3700.00
0005432692581	30392	Economy	3700.00
0005432692563	30392	Economy	3700.00
0005432692541	30392	Economy	3700.00
0005433449623	30392	Economy	3700.00
0005433449646	30392	Economy	3700.00
0005433449622	30392	Economy	3700.00
0005433449610	30392	Economy	3700.00
0005433123585	30391	Business	11100.00
0005433722155	30391	Business	11100.00
0005432720434	30391	Economy	3700.00
0005433123579	30391	Economy	3700.00
0005432720476	30391	Economy	3700.00
0005433123578	30391	Economy	4100.00
0005432720432	30391	Economy	3700.00
0005433722156	30391	Economy	3700.00
0005433123572	30391	Economy	3700.00
0005432720433	30391	Economy	3700.00
0005433123610	30391	Economy	3700.00
0005433722157	30391	Economy	3700.00
0005433123583	30391	Economy	3700.00
0005433123568	30391	Economy	3700.00
0005432720481	30391	Economy	3700.00
0005432720505	30391	Economy	3700.00
0005432720440	30391	Economy	3700.00
0005433123569	30391	Economy	3700.00
0005433123584	30391	Economy	3700.00
0005432720441	30391	Economy	3700.00
0005432927895	1396	Business	70400.00
0005434586348	1396	Business	70400.00
0005434586362	1396	Business	70400.00
0005433192838	1396	Business	70400.00
0005434586345	1396	Business	70400.00
0005433524929	1396	Business	70400.00
0005433192839	1396	Business	70400.00
0005433524933	1396	Business	70400.00
0005434586366	1396	Business	70400.00
0005433192843	1396	Economy	23500.00
0005433524930	1396	Economy	23500.00
0005433524934	1396	Economy	23500.00
0005434586367	1396	Economy	23500.00
0005434586346	1396	Economy	23500.00
0005433724761	1396	Economy	23500.00
0005434586349	1396	Economy	25800.00
0005434513552	1396	Economy	25800.00
0005433524932	1396	Economy	25800.00
0005434514941	1396	Economy	23500.00
0005433524935	1396	Economy	23500.00
0005432927892	1396	Economy	23500.00
0005432927896	1396	Economy	23500.00
0005433724759	1396	Economy	23500.00
0005433192818	1396	Economy	23500.00
0005433524931	1396	Economy	23500.00
0005434586354	1396	Economy	23500.00
0005433724760	1396	Economy	23500.00
0005434586352	1396	Economy	23500.00
0005432927891	1396	Economy	23500.00
0005434513551	1396	Economy	23500.00
0005434586344	1396	Economy	23500.00
0005434586357	1396	Economy	23500.00
0005434586350	1396	Economy	23500.00
0005433524927	1396	Economy	23500.00
0005433524923	1396	Economy	23500.00
0005434586353	1396	Economy	23500.00
0005434586363	1396	Economy	23500.00
0005434586365	1396	Economy	23500.00
0005434586347	1396	Economy	23500.00
0005434514940	1396	Economy	23500.00
0005434586358	1396	Economy	23500.00
0005434586359	1396	Economy	23500.00
0005434513553	1396	Economy	23500.00
0005433524926	1396	Economy	23500.00
0005432927887	1396	Economy	23500.00
0005434586356	1396	Economy	23500.00
0005434586361	1396	Economy	23500.00
0005434586364	1396	Economy	23500.00
0005434586360	1396	Economy	23500.00
0005434586342	1396	Economy	23500.00
0005432270975	1396	Economy	23500.00
0005434586351	1396	Economy	23500.00
0005433724762	1396	Economy	23500.00
0005433524928	1396	Economy	23500.00
0005433524924	1396	Economy	23500.00
0005432270974	1396	Economy	23500.00
0005432927897	1396	Economy	23500.00
0005432270976	1396	Economy	23500.00
0005433524925	1396	Economy	23500.00
0005434586343	1396	Economy	23500.00
0005434586355	1396	Economy	23500.00
0005433192914	18545	Business	70400.00
0005434586162	18545	Business	70400.00
0005432968815	18545	Business	70400.00
0005433192904	18545	Business	70400.00
0005433192909	18545	Business	70400.00
0005433192919	18545	Business	70400.00
0005434514924	18545	Economy	23500.00
0005433192913	18545	Economy	23500.00
0005432927922	18545	Economy	23500.00
0005434514925	18545	Economy	23500.00
0005433192915	18545	Economy	25800.00
0005434586223	18545	Economy	25800.00
0005433192912	18545	Economy	23500.00
0005433192917	18545	Economy	23500.00
0005433192906	18545	Economy	23500.00
0005433192908	18545	Economy	23500.00
0005433192911	18545	Economy	23500.00
0005433192910	18545	Economy	23500.00
0005432927921	18545	Economy	23500.00
0005434586237	18545	Economy	23500.00
0005433192905	18545	Economy	23500.00
0005432927923	18545	Economy	23500.00
0005432927924	18545	Economy	23500.00
0005434586180	18545	Economy	23500.00
0005433192916	18545	Economy	23500.00
0005433524852	18545	Economy	23500.00
0005434586236	18545	Economy	23500.00
0005434586190	18545	Economy	23500.00
0005433724739	18545	Economy	23500.00
0005434586222	18545	Economy	23500.00
0005434586161	18545	Economy	23500.00
0005433192918	18545	Economy	23500.00
0005432968816	18545	Economy	23500.00
0005432968817	18545	Economy	23500.00
0005433192907	18545	Economy	23500.00
0005434343816	11455	Economy	4300.00
0005434343799	11455	Economy	4300.00
0005434343808	11455	Economy	4300.00
0005434142572	11455	Economy	4300.00
0005435302119	11455	Economy	4000.00
0005434343817	11455	Economy	4000.00
0005434343836	11455	Economy	4000.00
0005434343802	11455	Economy	4000.00
0005434343834	11455	Economy	4000.00
0005434343835	11455	Economy	4000.00
0005434343837	11455	Economy	4000.00
0005434343809	11455	Economy	4000.00
0005434343821	11455	Economy	4000.00
0005434142570	11455	Economy	4000.00
0005434343806	11455	Economy	4000.00
0005434343825	11455	Economy	4000.00
0005434142573	11455	Economy	4000.00
0005434343800	11455	Economy	4000.00
0005434343818	11455	Economy	4000.00
0005434343820	11455	Economy	4000.00
0005434343832	11455	Economy	4000.00
0005434343827	11455	Economy	4000.00
0005434343804	11455	Economy	4000.00
0005434343826	11455	Economy	4000.00
0005434142569	11455	Economy	4000.00
0005434343801	11455	Economy	4000.00
0005434343831	11455	Economy	4000.00
0005434343805	11455	Economy	4000.00
0005434343833	11455	Economy	4000.00
0005434343823	11455	Economy	4000.00
0005434343812	11455	Economy	4000.00
0005434343803	11455	Economy	4000.00
0005434343830	11455	Economy	4000.00
0005434343815	11455	Economy	4000.00
0005434343811	11455	Economy	4000.00
0005434343814	11455	Economy	4000.00
0005434343822	11455	Economy	4000.00
0005434343829	11455	Economy	4000.00
0005434142571	11455	Economy	4000.00
0005434343828	11455	Economy	4000.00
0005434343824	11455	Economy	4000.00
0005434343807	11455	Economy	4000.00
0005434343810	11455	Economy	4000.00
0005434343819	11455	Economy	4000.00
0005434343813	11455	Economy	4000.00
0005434343584	29750	Economy	4000.00
0005435824349	1249	Business	199800.00
0005435824351	1249	Business	199800.00
0005433415407	1249	Business	199800.00
0005435824343	1249	Business	199800.00
0005435824344	1249	Business	199800.00
0005435824358	1249	Business	199800.00
0005435824362	1249	Economy	66600.00
0005433415429	1249	Economy	66600.00
0005432284530	1249	Economy	66600.00
0005435824356	1249	Economy	66600.00
0005432284527	1249	Economy	66600.00
0005435824355	1249	Economy	73200.00
0005435824348	1249	Economy	66600.00
0005435824352	1249	Economy	66600.00
0005435824365	1249	Economy	66600.00
0005433415430	1249	Economy	66600.00
0005435824370	1249	Economy	66600.00
0005432284528	1249	Economy	66600.00
0005433415389	1249	Economy	66600.00
0005433415420	1249	Economy	66600.00
0005435824367	1249	Economy	66600.00
0005435824354	1249	Economy	66600.00
0005435824366	1249	Economy	66600.00
0005435824363	1249	Economy	66600.00
0005433415419	1249	Economy	66600.00
0005435824345	1249	Economy	66600.00
0005435824347	1249	Economy	66600.00
0005435824359	1249	Economy	66600.00
0005435824360	1249	Economy	66600.00
0005435824368	1249	Economy	66600.00
0005435824369	1249	Economy	66600.00
0005435824350	1249	Economy	66600.00
0005432284529	1249	Economy	66600.00
0005433415390	1249	Economy	66600.00
0005435824346	1249	Economy	66600.00
0005435824357	1249	Economy	66600.00
0005433415400	1249	Economy	66600.00
0005435824364	1249	Economy	66600.00
0005435824361	1249	Economy	66600.00
0005435824353	1249	Economy	66600.00
0005433415391	1249	Economy	66600.00
0005433415418	1249	Economy	66600.00
0005435824185	17977	Business	199800.00
0005435824170	17977	Business	199800.00
0005433415493	17977	Business	199800.00
0005433415499	17977	Economy	66600.00
0005435824171	17977	Economy	73200.00
0005433415495	17977	Economy	73200.00
0005435824183	17977	Economy	66600.00
0005433415492	17977	Economy	66600.00
0005433415497	17977	Economy	66600.00
0005433415496	17977	Economy	66600.00
0005435824259	17977	Economy	66600.00
0005433415502	17977	Economy	66600.00
0005433415494	17977	Economy	66600.00
0005433415503	17977	Economy	66600.00
0005433415507	17977	Economy	66600.00
0005435824168	17977	Economy	66600.00
0005433415504	17977	Economy	66600.00
0005435824184	17977	Economy	66600.00
0005435824169	17977	Economy	66600.00
0005433415506	17977	Economy	66600.00
0005435824167	17977	Economy	66600.00
0005433415498	17977	Economy	66600.00
0005433415505	17977	Economy	66600.00
0005433415501	17977	Economy	66600.00
0005433415508	17977	Economy	66600.00
0005433415500	17977	Economy	66600.00
0005432783246	5617	Business	27800.00
0005432143954	5617	Business	27800.00
0005432783230	5617	Business	27800.00
0005435476646	5617	Business	27800.00
0005432783244	5617	Business	27800.00
0005432783238	5617	Business	27800.00
0005432783234	5617	Business	27800.00
0005432783250	5617	Economy	9300.00
0005432783248	5617	Economy	9300.00
0005435476648	5617	Economy	9300.00
0005432783232	5617	Economy	9300.00
0005432783271	5617	Economy	9300.00
0005432783249	5617	Economy	9300.00
0005435476645	5617	Economy	9300.00
0005432783226	5617	Economy	10200.00
0005432783273	5617	Economy	10200.00
0005432783243	5617	Economy	10200.00
0005432783275	5617	Economy	10200.00
0005432783263	5617	Economy	9300.00
0005432783276	5617	Economy	9300.00
0005432783237	5617	Economy	9300.00
0005435242441	5617	Economy	9300.00
0005432783269	5617	Economy	9300.00
0005432783252	5617	Economy	9300.00
0005432143955	5617	Economy	9300.00
0005432783265	5617	Economy	9300.00
0005432783239	5617	Economy	9300.00
0005435476636	5617	Economy	9300.00
0005432783259	5617	Economy	9300.00
0005432783264	5617	Economy	9300.00
0005432783231	5617	Economy	9300.00
0005432783236	5617	Economy	9300.00
0005432783268	5617	Economy	9300.00
0005432783258	5617	Economy	9300.00
0005435242387	5617	Economy	9300.00
0005432783267	5617	Economy	9300.00
0005432783240	5617	Economy	9300.00
0005432783254	5617	Economy	9300.00
0005435242414	5617	Economy	9300.00
0005432783257	5617	Economy	9300.00
0005432783229	5617	Economy	9300.00
0005432783227	5617	Economy	9300.00
0005432783241	5617	Economy	9300.00
0005432783235	5617	Economy	9300.00
0005432783274	5617	Economy	9300.00
0005432783251	5617	Economy	9300.00
0005432783233	5617	Economy	9300.00
0005432783266	5617	Economy	9300.00
0005435242415	5617	Economy	9300.00
0005432783277	5617	Economy	9300.00
0005432783255	5617	Economy	9300.00
0005435242442	5617	Economy	9300.00
0005432783272	5617	Economy	9300.00
0005432783245	5617	Economy	9300.00
0005432783261	5617	Economy	9300.00
0005432783260	5617	Economy	9300.00
0005432783262	5617	Economy	9300.00
0005432783225	5617	Economy	9300.00
0005432783278	5617	Economy	9300.00
0005432783256	5617	Economy	9300.00
0005432783253	5617	Economy	9300.00
0005432783228	5617	Economy	9300.00
0005435242413	5617	Economy	9300.00
0005432783270	5617	Economy	9300.00
0005432783242	5617	Economy	9300.00
0005432783247	5617	Economy	9300.00
0005435242557	15389	Business	27800.00
0005435242565	15389	Business	27800.00
0005435242562	15389	Business	27800.00
0005435242579	15389	Business	27800.00
0005435476694	15389	Business	27800.00
0005435242572	15389	Business	27800.00
0005435476693	15389	Business	27800.00
0005435242558	15389	Business	27800.00
0005435242575	15389	Economy	9300.00
0005432782879	15389	Economy	9300.00
0005432782904	15389	Economy	9300.00
0005435242559	15389	Economy	9300.00
0005435476697	15389	Economy	9300.00
0005435242566	15389	Economy	9300.00
0005435476690	15389	Economy	10200.00
0005432782955	15389	Economy	9300.00
0005435242573	15389	Economy	9300.00
0005435242568	15389	Economy	9300.00
0005435242580	15389	Economy	9300.00
0005435242563	15389	Economy	9300.00
0005435242578	15389	Economy	9300.00
0005432782848	15389	Economy	9300.00
0005435476692	15389	Economy	9300.00
0005435476689	15389	Economy	9300.00
0005435476696	15389	Economy	9300.00
0005435242564	15389	Economy	9300.00
0005435476698	15389	Economy	9300.00
0005435476695	15389	Economy	9300.00
0005432782880	15389	Economy	9300.00
0005435242577	15389	Economy	9300.00
0005435242574	15389	Economy	9300.00
0005435242570	15389	Economy	9300.00
0005432782902	15389	Economy	9300.00
0005435242581	15389	Economy	9300.00
0005435242554	15389	Economy	9300.00
0005435476691	15389	Economy	9300.00
0005432782849	15389	Economy	9300.00
0005435242556	15389	Economy	9300.00
0005435242555	15389	Economy	9300.00
0005435242561	15389	Economy	9300.00
0005435476699	15389	Economy	9300.00
0005432782885	15389	Economy	9300.00
0005432782868	15389	Economy	9300.00
0005432782911	15389	Economy	9300.00
0005432782899	15389	Economy	9300.00
0005435242569	15389	Economy	9300.00
0005435476700	15389	Economy	9300.00
0005435242576	15389	Economy	9300.00
0005435242560	15389	Economy	9300.00
0005435242567	15389	Economy	9300.00
0005435242571	15389	Economy	9300.00
0005435850761	4361	Economy	7000.00
0005434463906	4361	Economy	7000.00
0005432848168	4361	Economy	6300.00
0005432848172	4361	Economy	6300.00
0005432848160	4361	Economy	6300.00
0005435850802	4361	Economy	6300.00
0005432848173	4361	Economy	6300.00
0005432848164	4361	Economy	6300.00
0005432848163	4361	Economy	6300.00
0005432848167	4361	Economy	6300.00
0005432848162	4361	Economy	6300.00
0005432848161	4361	Economy	6300.00
0005432848174	4361	Economy	6300.00
0005432848159	4361	Economy	6300.00
0005432848171	4361	Economy	6300.00
0005432848170	4361	Economy	6300.00
0005432848166	4361	Economy	6300.00
0005432848165	4361	Economy	6300.00
0005435850770	4361	Economy	6300.00
0005434462769	4361	Economy	6300.00
0005434462767	4361	Economy	6300.00
0005434463907	4361	Economy	6300.00
0005434462768	4361	Economy	6300.00
0005432848169	4361	Economy	6300.00
0005434463908	4361	Economy	6300.00
0005435850817	28858	Economy	6300.00
0005435850822	28858	Economy	6300.00
0005435850823	28858	Economy	6300.00
0005435850820	28858	Economy	6300.00
0005435850818	28858	Economy	6300.00
0005432848055	28858	Economy	6300.00
0005434463891	28858	Economy	6300.00
0005435850815	28858	Economy	6300.00
0005432848057	28858	Economy	6300.00
0005435850816	28858	Economy	6300.00
0005435850819	28858	Economy	6300.00
0005434463892	28858	Economy	6300.00
0005432848056	28858	Economy	6300.00
0005435850814	28858	Economy	6300.00
0005435850821	28858	Economy	6300.00
0005433496667	6320	Business	11900.00
0005434443551	6320	Business	11900.00
0005433496665	6320	Business	11900.00
0005434925491	6320	Business	11900.00
0005434443553	6320	Business	11900.00
0005434925478	6320	Business	11900.00
0005433496674	6320	Business	11900.00
0005434925476	6320	Business	11900.00
0005433496655	6320	Business	11900.00
0005434925487	6320	Economy	4000.00
0005433496661	6320	Business	11900.00
0005434925501	6320	Economy	4000.00
0005434443544	6320	Economy	4000.00
0005434443555	6320	Economy	4000.00
0005434443539	6320	Economy	4000.00
0005434443548	6320	Economy	4000.00
0005434443554	6320	Economy	4000.00
0005433496653	6320	Economy	4000.00
0005434925483	6320	Economy	4000.00
0005434925490	6320	Economy	4400.00
0005433496658	6320	Economy	4400.00
0005433496673	6320	Economy	4400.00
0005434925495	6320	Economy	4400.00
0005434443550	6320	Economy	4000.00
0005434925474	6320	Economy	4000.00
0005434925481	6320	Economy	4000.00
0005433496671	6320	Economy	4000.00
0005432075196	6320	Economy	4000.00
0005434925488	6320	Economy	4000.00
0005434443540	6320	Economy	4000.00
0005434925500	6320	Economy	4000.00
0005433496657	6320	Economy	4000.00
0005433496650	6320	Economy	4000.00
0005434443541	6320	Economy	4000.00
0005434443547	6320	Economy	4000.00
0005433496649	6320	Economy	4000.00
0005434925475	6320	Economy	4000.00
0005433496672	6320	Economy	4000.00
0005433496648	6320	Economy	4000.00
0005434925486	6320	Economy	4000.00
0005433496644	6320	Economy	4000.00
0005434443546	6320	Economy	4000.00
0005434925480	6320	Economy	4000.00
0005433496659	6320	Economy	4000.00
0005434925489	6320	Economy	4000.00
0005433496642	6320	Economy	4000.00
0005433496662	6320	Economy	4000.00
0005432075195	6320	Economy	4000.00
0005433496651	6320	Economy	4000.00
0005433496652	6320	Economy	4000.00
0005433496654	6320	Economy	4000.00
0005434925482	6320	Economy	4000.00
0005434443549	6320	Economy	4000.00
0005433496669	6320	Economy	4000.00
0005434925494	6320	Economy	4000.00
0005433496660	6320	Economy	4000.00
0005434925498	6320	Economy	4000.00
0005433496664	6320	Economy	4000.00
0005434925479	6320	Economy	4000.00
0005433496666	6320	Economy	4000.00
0005434443552	6320	Economy	4000.00
0005433496645	6320	Economy	4000.00
0005433496643	6320	Economy	4000.00
0005433496656	6320	Economy	4000.00
0005433496668	6320	Economy	4000.00
0005432075194	6320	Economy	4000.00
0005434925493	6320	Economy	4000.00
0005433496646	6320	Economy	4000.00
0005434925485	6320	Economy	4000.00
0005434443542	6320	Economy	4000.00
0005434925492	6320	Economy	4000.00
0005434925496	6320	Economy	4000.00
0005434925477	6320	Economy	4000.00
0005433496670	6320	Economy	4000.00
0005433496663	6320	Economy	4000.00
0005433496647	6320	Economy	4000.00
0005434443545	6320	Economy	4000.00
0005434925497	6320	Economy	4000.00
0005434925484	6320	Economy	4000.00
0005434925502	6320	Economy	4000.00
0005434443543	6320	Economy	4000.00
0005434925499	6320	Economy	4000.00
0005434443447	20365	Business	11900.00
0005433496456	20365	Business	11900.00
0005433496461	20365	Economy	4400.00
0005433496526	20365	Economy	4400.00
0005433496428	20365	Economy	4400.00
0005433496567	20365	Economy	4400.00
0005433496427	20365	Economy	4000.00
0005433496513	20365	Economy	4000.00
0005433496502	20365	Economy	4000.00
0005433496435	20365	Economy	4000.00
0005433496430	20365	Economy	4000.00
0005433496462	20365	Economy	4000.00
0005433496431	20365	Economy	4000.00
0005433496460	20365	Economy	4000.00
0005433496459	20365	Economy	4000.00
0005435242601	12193	Business	41200.00
0005432782992	12193	Business	41200.00
0005432782843	12193	Business	41200.00
0005435242609	12193	Business	41200.00
0005435242600	12193	Business	41200.00
0005432783044	12193	Economy	13700.00
0005435242603	12193	Economy	13700.00
0005432782942	12193	Economy	13700.00
0005432782871	12193	Economy	13700.00
0005435242604	12193	Economy	15100.00
0005435242586	12193	Economy	15100.00
0005435242592	12193	Economy	15100.00
0005432782901	12193	Economy	13700.00
0005435242582	12193	Economy	13700.00
0005432782883	12193	Economy	13700.00
0005432782919	12193	Economy	13700.00
0005435242589	12193	Economy	13700.00
0005432783090	12193	Economy	13700.00
0005432783011	12193	Economy	13700.00
0005435242584	12193	Economy	13700.00
0005435242605	12193	Economy	13700.00
0005435242594	12193	Economy	13700.00
0005435242596	12193	Economy	13700.00
0005432782900	12193	Economy	13700.00
0005432783091	12193	Economy	13700.00
0005432783010	12193	Economy	13700.00
0005435242590	12193	Economy	13700.00
0005432783009	12193	Economy	13700.00
0005435242610	12193	Economy	13700.00
0005432782938	12193	Economy	13700.00
0005435242607	12193	Economy	13700.00
0005435242593	12193	Economy	13700.00
0005432782898	12193	Economy	13700.00
0005435242585	12193	Economy	13700.00
0005435242598	12193	Economy	13700.00
0005432782990	12193	Economy	13700.00
0005435242606	12193	Economy	13700.00
0005435242588	12193	Economy	13700.00
0005435242599	12193	Economy	13700.00
0005435242583	12193	Economy	13700.00
0005432782991	12193	Economy	13700.00
0005432782968	12193	Economy	13700.00
0005435242595	12193	Economy	13700.00
0005435242602	12193	Economy	13700.00
0005432782905	12193	Economy	13700.00
0005435242608	12193	Economy	13700.00
0005435242597	12193	Economy	13700.00
0005432782845	12193	Economy	13700.00
0005432783045	12193	Economy	13700.00
0005432782874	12193	Economy	13700.00
0005435242591	12193	Economy	13700.00
0005432783092	12193	Economy	13700.00
0005432782840	12193	Economy	13700.00
0005432782967	12193	Economy	13700.00
0005435242587	12193	Economy	13700.00
0005432783201	15407	Business	41200.00
0005432783212	15407	Business	41200.00
0005432783189	15407	Business	41200.00
0005432783172	15407	Business	41200.00
0005432783176	15407	Business	41200.00
0005432783199	15407	Business	41200.00
0005432783182	15407	Business	41200.00
0005432783180	15407	Business	41200.00
0005432783179	15407	Economy	13700.00
0005432783222	15407	Economy	13700.00
0005432783183	15407	Economy	13700.00
0005432783211	15407	Economy	13700.00
0005432783181	15407	Economy	13700.00
0005432783213	15407	Economy	15100.00
0005432783208	15407	Economy	15100.00
0005432783198	15407	Economy	15100.00
0005432783173	15407	Economy	13700.00
0005432783174	15407	Economy	13700.00
0005432783217	15407	Economy	13700.00
0005432783197	15407	Economy	13700.00
0005432783223	15407	Economy	13700.00
0005432783178	15407	Economy	13700.00
0005432783203	15407	Economy	13700.00
0005432783186	15407	Economy	13700.00
0005432783188	15407	Economy	13700.00
0005432783206	15407	Economy	13700.00
0005432783196	15407	Economy	13700.00
0005432783200	15407	Economy	13700.00
0005432783218	15407	Economy	13700.00
0005432783210	15407	Economy	13700.00
0005432783219	15407	Economy	13700.00
0005432783216	15407	Economy	13700.00
0005432783177	15407	Economy	13700.00
0005432783184	15407	Economy	13700.00
0005432783214	15407	Economy	13700.00
0005432783224	15407	Economy	13700.00
0005432783195	15407	Economy	13700.00
0005432783175	15407	Economy	13700.00
0005432783194	15407	Economy	13700.00
0005432783193	15407	Economy	13700.00
0005432783204	15407	Economy	13700.00
0005432783215	15407	Economy	13700.00
0005432783190	15407	Economy	13700.00
0005432783170	15407	Economy	13700.00
0005432783169	15407	Economy	13700.00
0005432783187	15407	Economy	13700.00
0005432783192	15407	Economy	13700.00
0005432783221	15407	Economy	13700.00
0005432783191	15407	Economy	13700.00
0005432783207	15407	Economy	13700.00
0005432783209	15407	Economy	13700.00
0005432783171	15407	Economy	13700.00
0005432783205	15407	Economy	13700.00
0005432783220	15407	Economy	13700.00
0005432783202	15407	Economy	13700.00
0005432783185	15407	Economy	13700.00
0005435913899	10099	Business	49700.00
0005434876616	10099	Business	49700.00
0005434876936	10099	Business	49700.00
0005434876667	10099	Business	49700.00
0005434876612	10099	Business	49700.00
0005435913894	10099	Business	49700.00
0005434876759	10099	Business	49700.00
0005434876825	10099	Economy	16600.00
0005434876817	10099	Economy	16600.00
0005434876668	10099	Economy	16600.00
0005434876826	10099	Economy	16600.00
0005434876761	10099	Economy	16600.00
0005434876760	10099	Economy	18200.00
0005434876669	10099	Economy	18200.00
0005435913895	10099	Economy	16600.00
0005434876722	10099	Economy	16600.00
0005434876563	10099	Economy	16600.00
0005434876564	10099	Economy	16600.00
0005434876670	10099	Economy	16600.00
0005435913896	10099	Economy	16600.00
0005434910086	10099	Economy	16600.00
0005435913900	10099	Economy	16600.00
0005434876614	10099	Economy	16600.00
0005434876688	10099	Economy	16600.00
0005434876572	10099	Economy	16600.00
0005434876621	10099	Economy	16600.00
0005434876675	10099	Economy	16600.00
0005434876615	10099	Economy	16600.00
0005434876671	10099	Economy	16600.00
0005434876645	10099	Economy	16600.00
0005434910084	10099	Economy	16600.00
0005434876820	10099	Economy	16600.00
0005435913898	10099	Economy	16600.00
0005434876674	10099	Economy	16600.00
0005434876583	10099	Economy	16600.00
0005434910085	10099	Economy	16600.00
0005434910087	10099	Economy	16600.00
0005434876672	10099	Economy	16600.00
0005434876704	10099	Economy	16600.00
0005434876607	10099	Economy	16600.00
0005434876656	10099	Economy	16600.00
0005434876703	10099	Economy	16600.00
0005434876646	10099	Economy	16600.00
0005434876673	10099	Economy	16600.00
0005434876752	10099	Economy	16600.00
0005435913893	10099	Economy	16600.00
0005435913897	10099	Economy	16600.00
0005434876620	10099	Economy	16600.00
0005434876819	10099	Economy	16600.00
0005434876909	10099	Economy	16600.00
0005434876585	10099	Economy	16600.00
0005434877301	14640	Business	49700.00
0005434877323	14640	Business	49700.00
0005434877305	14640	Business	49700.00
0005434758868	14640	Business	49700.00
0005434877256	14640	Business	49700.00
0005434877282	14640	Business	49700.00
0005434877279	14640	Business	49700.00
0005434877239	14640	Business	49700.00
0005434877311	14640	Business	49700.00
0005434877250	14640	Business	49700.00
0005434877308	14640	Business	49700.00
0005434877278	14640	Business	49700.00
0005434877288	14640	Business	49700.00
0005434877266	14640	Business	49700.00
0005434877307	14640	Business	49700.00
0005434877254	14640	Business	49700.00
0005434877300	14640	Economy	16600.00
0005434877317	14640	Economy	16600.00
0005434877289	14640	Economy	16600.00
0005434877303	14640	Economy	16600.00
0005434877235	14640	Economy	16600.00
0005434877294	14640	Economy	16600.00
0005434877242	14640	Economy	16600.00
0005434877281	14640	Economy	16600.00
0005434877314	14640	Economy	16600.00
0005434877260	14640	Economy	16600.00
0005434877268	14640	Economy	16600.00
0005434877269	14640	Economy	16600.00
0005434877290	14640	Economy	18200.00
0005434758870	14640	Economy	18200.00
0005434877247	14640	Economy	18200.00
0005434877262	14640	Economy	16600.00
0005434877284	14640	Economy	16600.00
0005434877241	14640	Economy	16600.00
0005434758871	14640	Economy	16600.00
0005434877275	14640	Economy	16600.00
0005434877330	14640	Economy	16600.00
0005434877295	14640	Economy	16600.00
0005434877291	14640	Economy	16600.00
0005434877249	14640	Economy	16600.00
0005434877309	14640	Economy	16600.00
0005434877306	14640	Economy	16600.00
0005434877313	14640	Economy	16600.00
0005434877302	14640	Economy	16600.00
0005434877245	14640	Economy	16600.00
0005434877299	14640	Economy	16600.00
0005434877324	14640	Economy	16600.00
0005434877236	14640	Economy	16600.00
0005434877271	14640	Economy	16600.00
0005434877321	14640	Economy	16600.00
0005434758869	14640	Economy	16600.00
0005434877312	14640	Economy	16600.00
0005434877327	14640	Economy	16600.00
0005434877258	14640	Economy	16600.00
0005434877246	14640	Economy	16600.00
0005434877320	14640	Economy	16600.00
0005434877259	14640	Economy	16600.00
0005434877273	14640	Economy	16600.00
0005434877255	14640	Economy	16600.00
0005434877257	14640	Economy	16600.00
0005434877276	14640	Economy	16600.00
0005434877293	14640	Economy	16600.00
0005434877310	14640	Economy	16600.00
0005434877244	14640	Economy	16600.00
0005434877316	14640	Economy	16600.00
0005434877243	14640	Economy	16600.00
0005434877270	14640	Economy	16600.00
0005434877252	14640	Economy	16600.00
0005434877265	14640	Economy	16600.00
0005434877315	14640	Economy	16600.00
0005434877277	14640	Economy	16600.00
0005434877283	14640	Economy	16600.00
0005434877274	14640	Economy	16600.00
0005434877292	14640	Economy	16600.00
0005434877263	14640	Economy	16600.00
0005434877264	14640	Economy	16600.00
0005434877272	14640	Economy	16600.00
0005434877326	14640	Economy	16600.00
0005434877286	14640	Economy	16600.00
0005434877318	14640	Economy	16600.00
0005434877237	14640	Economy	16600.00
0005434877253	14640	Economy	16600.00
0005434877248	14640	Economy	16600.00
0005434877238	14640	Economy	16600.00
0005434877285	14640	Economy	16600.00
0005434877328	14640	Economy	16600.00
0005434877329	14640	Economy	16600.00
0005434877261	14640	Economy	16600.00
0005434877298	14640	Economy	16600.00
0005434877296	14640	Economy	16600.00
0005434877280	14640	Economy	16600.00
0005434877267	14640	Economy	16600.00
0005434877251	14640	Economy	16600.00
0005434877287	14640	Economy	16600.00
0005434877322	14640	Economy	16600.00
0005434877297	14640	Economy	16600.00
0005434877304	14640	Economy	16600.00
0005434877325	14640	Economy	16600.00
0005434877240	14640	Economy	16600.00
0005434877319	14640	Economy	16600.00
0005435660026	9218	Economy	22400.00
0005435660022	9218	Economy	20300.00
0005434251803	9218	Economy	20300.00
0005434251802	9218	Economy	20300.00
0005435660023	9218	Economy	20300.00
0005435660021	9218	Economy	20300.00
0005435660027	9218	Economy	20300.00
0005435660019	9218	Economy	20300.00
0005435660028	9218	Economy	20300.00
0005435660020	9218	Economy	20300.00
0005435660025	9218	Economy	20300.00
0005435660024	9218	Economy	20300.00
0005435660017	9218	Economy	20300.00
0005435660018	9218	Economy	20300.00
0005435659947	24637	Economy	22400.00
0005435659938	24637	Economy	20300.00
0005434251864	24637	Economy	20300.00
0005434251866	24637	Economy	20300.00
0005434251865	24637	Economy	20300.00
0005434251872	24637	Economy	20300.00
0005435659939	24637	Economy	20300.00
0005435659952	24637	Economy	20300.00
0005435659940	24637	Economy	20300.00
0005434251868	24637	Economy	20300.00
0005435659955	24637	Economy	20300.00
0005435659937	24637	Economy	20300.00
0005435659953	24637	Economy	20300.00
0005434251870	24637	Economy	20300.00
0005434251863	24637	Economy	20300.00
0005434251871	24637	Economy	20300.00
0005434251869	24637	Economy	20300.00
0005435659948	24637	Economy	20300.00
0005435659956	24637	Economy	20300.00
0005434251867	24637	Economy	20300.00
0005433680081	2785	Business	33000.00
0005432966502	2785	Business	33000.00
0005433680075	2785	Business	33000.00
0005433680079	2785	Business	33000.00
0005433680062	2785	Business	33000.00
0005433680072	2785	Business	33000.00
0005432222727	2785	Business	33000.00
0005432966479	2785	Economy	11000.00
0005433680068	2785	Economy	11000.00
0005433684397	2785	Economy	11000.00
0005432966522	2785	Economy	11000.00
0005432966523	2785	Economy	11000.00
0005433680069	2785	Economy	12100.00
0005433680067	2785	Economy	12100.00
0005432222726	2785	Economy	12100.00
0005433680093	2785	Economy	11000.00
0005433680089	2785	Economy	11000.00
0005433680092	2785	Economy	11000.00
0005432966514	2785	Economy	11000.00
0005432966576	2785	Economy	11000.00
0005433680096	2785	Economy	11000.00
0005432222728	2785	Economy	11000.00
0005433680074	2785	Economy	11000.00
0005433680078	2785	Economy	11000.00
0005433680087	2785	Economy	11000.00
0005432966621	2785	Economy	11000.00
0005433680086	2785	Economy	11000.00
0005433680099	2785	Economy	11000.00
0005433680073	2785	Economy	11000.00
0005433680080	2785	Economy	11000.00
0005432966551	2785	Economy	11000.00
0005433680088	2785	Economy	11000.00
0005433680053	2785	Economy	11000.00
0005433680071	2785	Economy	11000.00
0005433680083	2785	Economy	11000.00
0005432966491	2785	Economy	11000.00
0005433680061	2785	Economy	11000.00
0005433680064	2785	Economy	11000.00
0005433680055	2785	Economy	11000.00
0005433680070	2785	Economy	11000.00
0005432966499	2785	Economy	11000.00
0005433680082	2785	Economy	11000.00
0005433684398	2785	Economy	11000.00
0005433680084	2785	Economy	11000.00
0005433680077	2785	Economy	11000.00
0005433680052	2785	Economy	11000.00
0005433680066	2785	Economy	11000.00
0005432966620	2785	Economy	11000.00
0005433680097	2785	Economy	11000.00
0005433680054	2785	Economy	11000.00
0005432222730	2785	Economy	11000.00
0005433680060	2785	Economy	11000.00
0005433680085	2785	Economy	11000.00
0005433680091	2785	Economy	11000.00
0005432966515	2785	Economy	11000.00
0005433680095	2785	Economy	11000.00
0005433680076	2785	Economy	11000.00
0005433680056	2785	Economy	11000.00
0005432222729	2785	Economy	11000.00
0005433680065	2785	Economy	11000.00
0005433680057	2785	Economy	11000.00
0005433680059	2785	Economy	11000.00
0005433680098	2785	Economy	11000.00
0005433680058	2785	Economy	11000.00
0005433680063	2785	Economy	11000.00
0005433680090	2785	Economy	11000.00
0005433680094	2785	Economy	11000.00
0005433679883	29193	Business	33000.00
0005432966677	29193	Business	33000.00
0005432966685	29193	Business	33000.00
0005433679912	29193	Business	33000.00
0005432966672	29193	Business	33000.00
0005432005184	29193	Economy	11000.00
0005432966681	29193	Economy	11000.00
0005433679717	29193	Economy	11000.00
0005432966665	29193	Economy	11000.00
0005433684384	29193	Economy	11000.00
0005432966663	29193	Economy	12100.00
0005432966686	29193	Economy	12100.00
0005432966675	29193	Economy	12100.00
0005433679727	29193	Economy	11000.00
0005433679932	29193	Economy	11000.00
0005433679891	29193	Economy	11000.00
0005433679808	29193	Economy	11000.00
0005433679807	29193	Economy	11000.00
0005432966668	29193	Economy	11000.00
0005432966680	29193	Economy	11000.00
0005432966682	29193	Economy	11000.00
0005432966684	29193	Economy	11000.00
0005433679830	29193	Economy	11000.00
0005432966664	29193	Economy	11000.00
0005432966667	29193	Economy	11000.00
0005433684385	29193	Economy	11000.00
0005432966683	29193	Economy	11000.00
0005432966673	29193	Economy	11000.00
0005433679743	29193	Economy	11000.00
0005432966676	29193	Economy	11000.00
0005432966666	29193	Economy	11000.00
0005432966669	29193	Economy	11000.00
0005432005185	29193	Economy	11000.00
0005432966671	29193	Economy	11000.00
0005433679742	29193	Economy	11000.00
0005432966679	29193	Economy	11000.00
0005432966687	29193	Economy	11000.00
0005432966678	29193	Economy	11000.00
0005432966670	29193	Economy	11000.00
0005432966674	29193	Economy	11000.00
0005433679906	29193	Economy	11000.00
0005433679913	29193	Economy	11000.00
0005433679739	29193	Economy	11000.00
0005433633456	9308	Business	132900.00
0005433633448	9308	Business	132900.00
0005433633428	9308	Business	132900.00
0005433613857	9308	Business	132900.00
0005433613881	9308	Business	132900.00
0005433633450	9308	Business	132900.00
0005433613891	9308	Business	132900.00
0005433613887	9308	Business	132900.00
0005433613842	9308	Business	132900.00
0005433633454	9308	Business	132900.00
0005433577666	9308	Business	132900.00
0005433633436	9308	Business	132900.00
0005433613885	9308	Business	132900.00
0005433613856	9308	Business	132900.00
0005433613906	9308	Business	132900.00
0005433633440	9308	Business	132900.00
0005433613876	9308	Business	132900.00
0005433613848	9308	Business	132900.00
0005433633444	9308	Business	132900.00
0005433613902	9308	Business	132900.00
0005433613908	9308	Business	132900.00
0005433613869	9308	Business	132900.00
0005433613864	9308	Economy	48700.00
0005433613866	9308	Economy	48700.00
0005432756811	9308	Economy	48700.00
0005433613843	9308	Economy	48700.00
0005433613845	9308	Economy	48700.00
0005433613898	9308	Economy	48700.00
0005433633449	9308	Economy	44300.00
0005433613840	9308	Economy	44300.00
0005433633441	9308	Economy	44300.00
0005433613903	9308	Economy	44300.00
0005433633445	9308	Economy	44300.00
0005433613850	9308	Economy	44300.00
0005433613880	9308	Economy	44300.00
0005433613846	9308	Economy	44300.00
0005433613836	9308	Economy	44300.00
0005433633434	9308	Economy	44300.00
0005433577661	9308	Economy	44300.00
0005432145089	9308	Economy	44300.00
0005433613872	9308	Economy	44300.00
0005433633427	9308	Economy	44300.00
0005433633452	9308	Economy	44300.00
0005433577662	9308	Economy	44300.00
0005433613847	9308	Economy	44300.00
0005433633435	9308	Economy	44300.00
0005433633424	9308	Economy	44300.00
0005433633430	9308	Economy	44300.00
0005434163485	9308	Economy	44300.00
0005433613901	9308	Economy	44300.00
0005433633455	9308	Economy	44300.00
0005433613841	9308	Economy	44300.00
0005432145090	9308	Economy	44300.00
0005432145088	9308	Economy	44300.00
0005433613894	9308	Economy	44300.00
0005433613888	9308	Economy	44300.00
0005433613882	9308	Economy	44300.00
0005433633425	9308	Economy	44300.00
0005433613859	9308	Economy	44300.00
0005432756812	9308	Economy	44300.00
0005433613904	9308	Economy	44300.00
0005433613851	9308	Economy	44300.00
0005433613895	9308	Economy	44300.00
0005433613889	9308	Economy	44300.00
0005433613907	9308	Economy	44300.00
0005433633433	9308	Economy	44300.00
0005433613844	9308	Economy	44300.00
0005432756813	9308	Economy	44300.00
0005433633453	9308	Economy	44300.00
0005433613837	9308	Economy	44300.00
0005433577659	9308	Economy	44300.00
0005434163492	9308	Economy	44300.00
0005433613865	9308	Economy	44300.00
0005433613868	9308	Economy	44300.00
0005433613905	9308	Economy	44300.00
0005433613899	9308	Economy	44300.00
0005432755041	9308	Economy	44300.00
0005433633443	9308	Economy	44300.00
0005433577660	9308	Economy	44300.00
0005434163493	9308	Economy	48700.00
0005433633429	9308	Economy	48700.00
0005433633437	9308	Economy	48700.00
0005433613863	9308	Economy	44300.00
0005433577667	9308	Economy	44300.00
0005433613854	9308	Economy	44300.00
0005433613884	9308	Economy	44300.00
0005432755042	9308	Economy	48700.00
0005433613893	9308	Economy	44300.00
0005433577665	9308	Economy	44300.00
0005433633432	9308	Economy	44300.00
0005433577670	9308	Economy	44300.00
0005433613849	9308	Economy	44300.00
0005433613870	9308	Economy	44300.00
0005433633422	9308	Economy	44300.00
0005433613838	9308	Economy	44300.00
0005433613897	9308	Economy	44300.00
0005433613877	9308	Economy	44300.00
0005433613875	9308	Economy	44300.00
0005433613860	9308	Economy	44300.00
0005433633442	9308	Economy	44300.00
0005433613900	9308	Economy	44300.00
0005433613874	9308	Economy	44300.00
0005433633439	9308	Economy	44300.00
0005433613883	9308	Economy	44300.00
0005433613852	9308	Economy	44300.00
0005432756814	9308	Economy	44300.00
0005433613858	9308	Economy	44300.00
0005433577663	9308	Economy	44300.00
0005433613890	9308	Economy	44300.00
0005433577668	9308	Economy	44300.00
0005432755039	9308	Economy	44300.00
0005433613861	9308	Economy	44300.00
0005433613892	9308	Economy	44300.00
0005433613855	9308	Economy	44300.00
0005433613853	9308	Economy	44300.00
0005433613886	9308	Economy	44300.00
0005434272167	9308	Economy	44300.00
0005433633447	9308	Economy	44300.00
0005433577669	9308	Economy	44300.00
0005432755040	9308	Economy	44300.00
0005433633426	9308	Economy	44300.00
0005433613896	9308	Economy	44300.00
0005433577664	9308	Economy	44300.00
0005433613878	9308	Economy	44300.00
0005433633431	9308	Economy	44300.00
0005433613879	9308	Economy	44300.00
0005433613867	9308	Economy	44300.00
0005433633423	9308	Economy	44300.00
0005433613871	9308	Economy	44300.00
0005433613862	9308	Economy	44300.00
0005433613835	9308	Economy	44300.00
0005433633438	9308	Economy	44300.00
0005433613839	9308	Economy	44300.00
0005433613873	9308	Economy	44300.00
0005433633451	9308	Economy	44300.00
0005433613909	9308	Economy	44300.00
0005433633446	9308	Economy	44300.00
0005433613477	25263	Business	132900.00
0005433633289	25263	Business	132900.00
0005434152767	25263	Business	132900.00
0005433633272	25263	Business	132900.00
0005434152770	25263	Business	132900.00
0005433577630	25263	Business	132900.00
0005433613418	25263	Economy	48700.00
0005434152762	25263	Economy	44300.00
0005434152761	25263	Economy	44300.00
0005433613703	25263	Economy	44300.00
0005432755018	25263	Economy	44300.00
0005433633296	25263	Economy	44300.00
0005433613423	25263	Economy	44300.00
0005433613426	25263	Economy	44300.00
0005434152768	25263	Economy	44300.00
0005433633314	25263	Economy	44300.00
0005433577574	25263	Economy	44300.00
0005433613427	25263	Economy	44300.00
0005434152769	25263	Economy	44300.00
0005434163525	25263	Economy	44300.00
0005433577632	25263	Economy	44300.00
0005434152771	25263	Economy	44300.00
0005433577631	25263	Economy	48700.00
0005433633315	25263	Economy	48700.00
0005433613386	25263	Economy	48700.00
0005434152764	25263	Economy	44300.00
0005433577561	25263	Economy	44300.00
0005434152760	25263	Economy	44300.00
0005432755019	25263	Economy	44300.00
0005433577576	25263	Economy	44300.00
0005433577575	25263	Economy	44300.00
0005433633295	25263	Economy	44300.00
0005434152765	25263	Economy	44300.00
0005434152763	25263	Economy	44300.00
0005434152766	25263	Economy	44300.00
0005433613387	25263	Economy	44300.00
0005432184921	4238	Business	193100.00
0005435986694	4238	Business	193100.00
0005435947010	4238	Business	193100.00
0005435986703	4238	Economy	64400.00
0005435986701	4238	Economy	64400.00
0005435986700	4238	Economy	64400.00
0005435947033	4238	Economy	64400.00
0005435986702	4238	Economy	64400.00
0005435986699	4238	Economy	64400.00
0005435986696	4238	Economy	64400.00
0005435947041	4238	Economy	64400.00
0005435947039	4238	Economy	64400.00
0005435947040	4238	Economy	64400.00
0005435856143	4238	Economy	70800.00
0005435947015	4238	Economy	64400.00
0005435947042	4238	Economy	64400.00
0005435986695	4238	Economy	64400.00
0005435986698	4238	Economy	64400.00
0005432184922	4238	Economy	64400.00
0005435986697	4238	Economy	64400.00
0005435947011	4238	Economy	64400.00
0005435947109	26585	Business	193100.00
0005435947108	26585	Business	193100.00
0005435787332	26585	Business	193100.00
0005435856162	26585	Business	193100.00
0005435947104	26585	Economy	70800.00
0005435856161	26585	Economy	64400.00
0005435947114	26585	Economy	64400.00
0005435856165	26585	Economy	64400.00
0005435856160	26585	Economy	64400.00
0005435947102	26585	Economy	64400.00
0005435856163	26585	Economy	64400.00
0005432571287	26585	Economy	64400.00
0005435787333	26585	Economy	64400.00
0005432571285	26585	Economy	64400.00
0005435947112	26585	Economy	64400.00
0005435947103	26585	Economy	70800.00
0005435947110	26585	Economy	70800.00
0005435986651	26585	Economy	64400.00
0005435947106	26585	Economy	64400.00
0005435947113	26585	Economy	64400.00
0005435856164	26585	Economy	64400.00
0005435986652	26585	Economy	64400.00
0005435947107	26585	Economy	64400.00
0005432571284	26585	Economy	64400.00
0005435947105	26585	Economy	64400.00
0005435947111	26585	Economy	64400.00
0005432571286	26585	Economy	64400.00
0005435986658	26585	Economy	64400.00
0005433568426	326	Business	21500.00
0005433568451	326	Business	21500.00
0005433568442	326	Business	21500.00
0005433074266	326	Business	21500.00
0005433568463	326	Business	21500.00
0005433568436	326	Business	21500.00
0005433568457	326	Business	21500.00
0005433074229	326	Business	21500.00
0005433568448	326	Business	21500.00
0005433568469	326	Business	21500.00
0005433074250	326	Business	21500.00
0005432238875	326	Economy	7900.00
0005433568435	326	Economy	7900.00
0005433568445	326	Economy	7200.00
0005433568475	326	Economy	7200.00
0005432238872	326	Economy	7200.00
0005432238874	326	Economy	7200.00
0005433568473	326	Economy	7200.00
0005432947776	326	Economy	7200.00
0005433568471	326	Economy	7200.00
0005433568459	326	Economy	7200.00
0005433568431	326	Economy	7200.00
0005433568432	326	Economy	7200.00
0005432238871	326	Economy	7200.00
0005432238873	326	Economy	7200.00
0005432947796	326	Economy	7200.00
0005432947775	326	Economy	7200.00
0005433568428	326	Economy	7200.00
0005433568444	326	Economy	7200.00
0005433568441	326	Economy	7200.00
0005433074267	326	Economy	7200.00
0005433134065	326	Economy	7200.00
0005433568447	326	Economy	7200.00
0005433568455	326	Economy	7200.00
0005432238876	326	Economy	7200.00
0005432947764	326	Economy	7200.00
0005433568437	326	Economy	7200.00
0005433568430	326	Economy	7200.00
0005433568450	326	Economy	7200.00
0005433568440	326	Economy	7200.00
0005433568476	326	Economy	7200.00
0005433568446	326	Economy	7200.00
0005433568467	326	Economy	7900.00
0005433568456	326	Economy	7200.00
0005433568461	326	Economy	7900.00
0005433568462	326	Economy	7200.00
0005433568439	326	Economy	7200.00
0005433568472	326	Economy	7200.00
0005433568449	326	Economy	7200.00
0005433568434	326	Economy	7200.00
0005433568424	326	Economy	7200.00
0005433568427	326	Economy	7200.00
0005433568468	326	Economy	7200.00
0005433568464	326	Economy	7200.00
0005433568477	326	Economy	7200.00
0005433568443	326	Economy	7200.00
0005432947797	326	Economy	7200.00
0005433568425	326	Economy	7200.00
0005433074249	326	Economy	7200.00
0005433568429	326	Economy	7200.00
0005433568454	326	Economy	7200.00
0005433568433	326	Economy	7200.00
0005433568465	326	Economy	7200.00
0005433568460	326	Economy	7200.00
0005433568470	326	Economy	7200.00
0005433568466	326	Economy	7200.00
0005433568452	326	Economy	7200.00
0005433074330	326	Economy	7200.00
0005433568423	326	Economy	7200.00
0005433568438	326	Economy	7200.00
0005433074248	326	Economy	7200.00
0005433568458	326	Economy	7200.00
0005433074263	326	Economy	7200.00
0005433568453	326	Economy	7200.00
0005433568474	326	Economy	7200.00
0005432948039	11581	Business	21500.00
0005432192286	11581	Business	21500.00
0005433074425	11581	Business	21500.00
0005432948053	11581	Business	21500.00
0005432948020	11581	Business	21500.00
0005432948025	11581	Business	21500.00
0005433134092	11581	Business	21500.00
0005433131660	11581	Business	21500.00
0005432948036	11581	Business	21500.00
0005432948042	11581	Business	21500.00
0005432948033	11581	Business	21500.00
0005432948052	11581	Business	21500.00
0005432948051	11581	Business	21500.00
0005432192288	11581	Business	21500.00
0005432948017	11581	Business	21500.00
0005432948028	11581	Business	21500.00
0005433074404	11581	Business	21500.00
0005432948024	11581	Business	21500.00
0005432948015	11581	Economy	7900.00
0005433134091	11581	Economy	7200.00
0005432948021	11581	Economy	7200.00
0005433134093	11581	Economy	7200.00
0005432948044	11581	Economy	7200.00
0005432948019	11581	Economy	7200.00
0005433134094	11581	Economy	7200.00
0005433074423	11581	Economy	7200.00
0005433074430	11581	Economy	7200.00
0005433134090	11581	Economy	7200.00
0005433074429	11581	Economy	7200.00
0005432948047	11581	Economy	7200.00
0005433074411	11581	Economy	7200.00
0005433074418	11581	Economy	7200.00
0005433074408	11581	Economy	7200.00
0005432948054	11581	Economy	7200.00
0005432948034	11581	Economy	7200.00
0005432948041	11581	Economy	7200.00
0005432948022	11581	Economy	7200.00
0005432948050	11581	Economy	7200.00
0005433074407	11581	Economy	7200.00
0005432948030	11581	Economy	7200.00
0005433074417	11581	Economy	7200.00
0005433074401	11581	Economy	7200.00
0005432948016	11581	Economy	7200.00
0005433074409	11581	Economy	7200.00
0005433074412	11581	Economy	7900.00
0005432948049	11581	Economy	7200.00
0005433131662	11581	Economy	7200.00
0005432948043	11581	Economy	7200.00
0005432948035	11581	Economy	7200.00
0005432948037	11581	Economy	7200.00
0005433074415	11581	Economy	7200.00
0005432948018	11581	Economy	7200.00
0005433074414	11581	Economy	7200.00
0005433074421	11581	Economy	7200.00
0005433074410	11581	Economy	7200.00
0005432192287	11581	Economy	7200.00
0005433074427	11581	Economy	7200.00
0005432948026	11581	Economy	7200.00
0005433074403	11581	Economy	7200.00
0005432192289	11581	Economy	7200.00
0005432948046	11581	Economy	7200.00
0005432948045	11581	Economy	7200.00
0005433131661	11581	Economy	7200.00
0005433134089	11581	Economy	7200.00
0005432948031	11581	Economy	7200.00
0005432948048	11581	Economy	7200.00
0005433074419	11581	Economy	7200.00
0005433074402	11581	Economy	7200.00
0005432948013	11581	Economy	7200.00
0005433074405	11581	Economy	7200.00
0005433074422	11581	Economy	7200.00
0005432948027	11581	Economy	7200.00
0005432948032	11581	Economy	7200.00
0005432948040	11581	Economy	7200.00
0005433074420	11581	Economy	7200.00
0005433074426	11581	Economy	7200.00
0005432948014	11581	Economy	7200.00
0005433074413	11581	Economy	7200.00
0005433074424	11581	Economy	7200.00
0005432948023	11581	Economy	7200.00
0005433074406	11581	Economy	7200.00
0005433074428	11581	Economy	7200.00
0005432948029	11581	Economy	7200.00
0005432948038	11581	Economy	7200.00
0005433074416	11581	Economy	7200.00
0005434732918	9949	Economy	6300.00
0005433817432	9949	Economy	6300.00
0005433817434	9949	Economy	6300.00
0005433817431	9949	Economy	6300.00
0005434732919	9949	Economy	6300.00
0005434732920	9949	Economy	6300.00
0005433817433	9949	Economy	6300.00
0005434732946	13995	Economy	6300.00
0005434732945	13995	Economy	6300.00
0005433817418	13995	Economy	6300.00
0005433753681	2362	Business	184500.00
0005433434194	2362	Business	184500.00
0005435981877	2362	Business	184500.00
0005433434184	2362	Business	184500.00
0005433766600	2362	Business	184500.00
0005433753674	2362	Business	184500.00
0005435981875	2362	Business	184500.00
0005435981884	2362	Business	184500.00
0005433753648	2362	Business	184500.00
0005432300205	2362	Business	184500.00
0005435981885	2362	Business	184500.00
0005432655419	2362	Business	184500.00
0005433434209	2362	Business	184500.00
0005435981858	2362	Business	184500.00
0005435981865	2362	Business	184500.00
0005433753624	2362	Business	184500.00
0005433753654	2362	Business	184500.00
0005435981862	2362	Business	184500.00
0005433753658	2362	Business	184500.00
0005433434252	2362	Business	184500.00
0005432225995	2362	Business	184500.00
0005433434196	2362	Business	184500.00
0005432655416	2362	Business	184500.00
0005432225991	2362	Business	184500.00
0005433753675	2362	Economy	67700.00
0005435981874	2362	Economy	67700.00
0005432984514	2362	Economy	67700.00
0005433766602	2362	Economy	61500.00
0005435981871	2362	Economy	61500.00
0005433753641	2362	Economy	61500.00
0005435981850	2362	Economy	61500.00
0005433764659	2362	Economy	61500.00
0005433753656	2362	Economy	61500.00
0005433434210	2362	Economy	61500.00
0005433434180	2362	Economy	61500.00
0005435981846	2362	Economy	61500.00
0005433753667	2362	Economy	61500.00
0005435981845	2362	Economy	61500.00
0005435981872	2362	Economy	61500.00
0005433753670	2362	Economy	61500.00
0005433753652	2362	Economy	61500.00
0005432655414	2362	Economy	61500.00
0005435981879	2362	Economy	61500.00
0005435981873	2362	Economy	61500.00
0005435981843	2362	Economy	61500.00
0005433434203	2362	Economy	61500.00
0005432984518	2362	Economy	61500.00
0005433434191	2362	Economy	61500.00
0005432984576	2362	Economy	61500.00
0005433434181	2362	Economy	61500.00
0005432655418	2362	Economy	61500.00
0005435981867	2362	Economy	61500.00
0005435981870	2362	Economy	61500.00
0005433753651	2362	Economy	61500.00
0005432300204	2362	Economy	61500.00
0005432984513	2362	Economy	61500.00
0005433753636	2362	Economy	61500.00
0005433753645	2362	Economy	61500.00
0005435981888	2362	Economy	61500.00
0005435981880	2362	Economy	61500.00
0005435981878	2362	Economy	61500.00
0005433753628	2362	Economy	61500.00
0005435981876	2362	Economy	61500.00
0005433753637	2362	Economy	61500.00
0005433753649	2362	Economy	61500.00
0005433434186	2362	Economy	61500.00
0005433753671	2362	Economy	61500.00
0005433753631	2362	Economy	61500.00
0005435981854	2362	Economy	61500.00
0005435981857	2362	Economy	61500.00
0005433753632	2362	Economy	61500.00
0005433753638	2362	Economy	61500.00
0005433753669	2362	Economy	61500.00
0005435981844	2362	Economy	61500.00
0005433753664	2362	Economy	61500.00
0005433753672	2362	Economy	61500.00
0005432655420	2362	Economy	61500.00
0005433753646	2362	Economy	61500.00
0005433434185	2362	Economy	61500.00
0005432984578	2362	Economy	61500.00
0005435981856	2362	Economy	61500.00
0005432655412	2362	Economy	61500.00
0005433753660	2362	Economy	61500.00
0005432984549	2362	Economy	61500.00
0005432984599	2362	Economy	61500.00
0005433753673	2362	Economy	61500.00
0005433753642	2362	Economy	61500.00
0005435981859	2362	Economy	61500.00
0005433753680	2362	Economy	61500.00
0005433434202	2362	Economy	61500.00
0005432225996	2362	Economy	61500.00
0005435981868	2362	Economy	61500.00
0005435981886	2362	Economy	61500.00
0005432300203	2362	Economy	61500.00
0005432225994	2362	Economy	61500.00
0005435981864	2362	Economy	61500.00
0005433753662	2362	Economy	61500.00
0005433753639	2362	Economy	61500.00
0005432655415	2362	Economy	61500.00
0005435981881	2362	Economy	61500.00
0005433434195	2362	Economy	67700.00
0005433753625	2362	Economy	67700.00
0005433753661	2362	Economy	61500.00
0005435981855	2362	Economy	61500.00
0005433434187	2362	Economy	61500.00
0005433753663	2362	Economy	61500.00
0005435981866	2362	Economy	61500.00
0005432655417	2362	Economy	61500.00
0005433753640	2362	Economy	61500.00
0005433753655	2362	Economy	61500.00
0005435981887	2362	Economy	61500.00
0005433766601	2362	Economy	61500.00
0005435981851	2362	Economy	61500.00
0005433753633	2362	Economy	61500.00
0005435981847	2362	Economy	61500.00
0005433753668	2362	Economy	61500.00
0005435981852	2362	Economy	61500.00
0005432225993	2362	Economy	61500.00
0005433753657	2362	Economy	61500.00
0005433764658	2362	Economy	61500.00
0005433753650	2362	Economy	61500.00
0005433753666	2362	Economy	61500.00
0005433753634	2362	Economy	61500.00
0005435981849	2362	Economy	61500.00
0005433434190	2362	Economy	61500.00
0005432984543	2362	Economy	61500.00
0005432984542	2362	Economy	61500.00
0005432655421	2362	Economy	61500.00
0005435981848	2362	Economy	61500.00
0005433753626	2362	Economy	61500.00
0005433753677	2362	Economy	61500.00
0005433753647	2362	Economy	61500.00
0005432655422	2362	Economy	61500.00
0005432984577	2362	Economy	61500.00
0005433753676	2362	Economy	61500.00
0005435981882	2362	Economy	61500.00
0005432655413	2362	Economy	61500.00
0005432300207	2362	Economy	61500.00
0005435981883	2362	Economy	61500.00
0005433753644	2362	Economy	61500.00
0005435981863	2362	Economy	61500.00
0005435981853	2362	Economy	61500.00
0005435981860	2362	Economy	61500.00
0005433753679	2362	Economy	61500.00
0005433753678	2362	Economy	61500.00
0005433753630	2362	Economy	61500.00
0005432655411	2362	Economy	61500.00
0005435981861	2362	Economy	61500.00
0005435981869	2362	Economy	61500.00
0005433753643	2362	Economy	61500.00
0005433753629	2362	Economy	61500.00
0005432225992	2362	Economy	61500.00
0005433753635	2362	Economy	61500.00
0005432300206	2362	Economy	61500.00
0005433753653	2362	Economy	61500.00
0005435981842	2362	Economy	61500.00
0005433753659	2362	Economy	61500.00
0005433753665	2362	Economy	61500.00
0005432984564	2362	Economy	61500.00
0005433766599	2362	Economy	61500.00
0005433753627	2362	Economy	61500.00
0005432984759	26207	Business	184500.00
0005432984733	26207	Business	184500.00
0005432984761	26207	Business	184500.00
0005433753254	26207	Business	184500.00
0005432869454	26207	Business	184500.00
0005433434399	26207	Business	184500.00
0005432984740	26207	Business	184500.00
0005433434396	26207	Business	184500.00
0005433753308	26207	Business	184500.00
0005433434393	26207	Business	184500.00
0005434731127	26207	Business	184500.00
0005432984760	26207	Business	184500.00
0005432984737	26207	Business	184500.00
0005432869453	26207	Business	184500.00
0005435981534	26207	Business	184500.00
0005435981517	26207	Economy	67700.00
0005433753300	26207	Economy	67700.00
0005432984747	26207	Economy	61500.00
0005433753272	26207	Economy	61500.00
0005433434390	26207	Economy	61500.00
0005434731126	26207	Economy	61500.00
0005432984749	26207	Economy	61500.00
0005433434384	26207	Economy	61500.00
0005433753340	26207	Economy	61500.00
0005432984735	26207	Economy	61500.00
0005433753269	26207	Economy	61500.00
0005432984763	26207	Economy	61500.00
0005435981510	26207	Economy	61500.00
0005433753229	26207	Economy	61500.00
0005432984742	26207	Economy	61500.00
0005432984754	26207	Economy	61500.00
0005433753270	26207	Economy	61500.00
0005433434385	26207	Economy	61500.00
0005433434395	26207	Economy	61500.00
0005433434405	26207	Economy	61500.00
0005432984762	26207	Economy	61500.00
0005433434409	26207	Economy	61500.00
0005435981605	26207	Economy	61500.00
0005432869458	26207	Economy	61500.00
0005433434401	26207	Economy	61500.00
0005432984765	26207	Economy	61500.00
0005433753372	26207	Economy	61500.00
0005434731129	26207	Economy	61500.00
0005433434382	26207	Economy	61500.00
0005432869452	26207	Economy	61500.00
0005433434400	26207	Economy	61500.00
0005433434387	26207	Economy	61500.00
0005433434397	26207	Economy	61500.00
0005435981604	26207	Economy	61500.00
0005435981513	26207	Economy	61500.00
0005433434389	26207	Economy	61500.00
0005433753315	26207	Economy	61500.00
0005432984744	26207	Economy	61500.00
0005435981536	26207	Economy	61500.00
0005433764646	26207	Economy	61500.00
0005433434386	26207	Economy	61500.00
0005433434383	26207	Economy	61500.00
0005433753255	26207	Economy	61500.00
0005432984758	26207	Economy	61500.00
0005432984738	26207	Economy	61500.00
0005433434406	26207	Economy	61500.00
0005432984732	26207	Economy	61500.00
0005433434398	26207	Economy	61500.00
0005432984748	26207	Economy	61500.00
0005432984753	26207	Economy	61500.00
0005432984750	26207	Economy	61500.00
0005433434408	26207	Economy	61500.00
0005432984743	26207	Economy	61500.00
0005432984757	26207	Economy	61500.00
0005432049426	26207	Economy	61500.00
0005432051095	26207	Economy	61500.00
0005433753228	26207	Economy	67700.00
0005432984741	26207	Economy	61500.00
0005435981545	26207	Economy	67700.00
0005432984739	26207	Economy	61500.00
0005433434402	26207	Economy	67700.00
0005432984736	26207	Economy	61500.00
0005433753271	26207	Economy	67700.00
0005433434381	26207	Economy	61500.00
0005435981511	26207	Economy	61500.00
0005432051097	26207	Economy	61500.00
0005433434404	26207	Economy	61500.00
0005433753273	26207	Economy	61500.00
0005435981691	26207	Economy	61500.00
0005432984752	26207	Economy	61500.00
0005433434388	26207	Economy	61500.00
0005433753256	26207	Economy	61500.00
0005432984764	26207	Economy	61500.00
0005432984751	26207	Economy	61500.00
0005432051096	26207	Economy	61500.00
0005432984734	26207	Economy	61500.00
0005432869451	26207	Economy	61500.00
0005433753223	26207	Economy	61500.00
0005433764645	26207	Economy	61500.00
0005433753309	26207	Economy	61500.00
0005433753268	26207	Economy	61500.00
0005433753454	26207	Economy	61500.00
0005432869457	26207	Economy	61500.00
0005434731128	26207	Economy	61500.00
0005432049427	26207	Economy	61500.00
0005433434403	26207	Economy	61500.00
0005432049429	26207	Economy	61500.00
0005432984745	26207	Economy	61500.00
0005432049428	26207	Economy	61500.00
0005435981586	26207	Economy	61500.00
0005433434394	26207	Economy	61500.00
0005432869455	26207	Economy	61500.00
0005432984746	26207	Economy	61500.00
0005432984756	26207	Economy	61500.00
0005433434392	26207	Economy	61500.00
0005433753453	26207	Economy	61500.00
0005432984755	26207	Economy	61500.00
0005432869456	26207	Economy	61500.00
0005433434407	26207	Economy	61500.00
0005433434391	26207	Economy	61500.00
0005434374194	1518	Business	38900.00
0005433150861	1518	Business	38900.00
0005433461565	1518	Business	38900.00
0005434374163	1518	Business	38900.00
0005433150860	1518	Business	38900.00
0005433150815	1518	Business	38900.00
0005434374164	1518	Economy	13000.00
0005434374182	1518	Economy	13000.00
0005434374179	1518	Economy	13000.00
0005434374169	1518	Economy	13000.00
0005432267826	1518	Economy	13000.00
0005433150854	1518	Economy	13000.00
0005433150801	1518	Economy	13000.00
0005433150828	1518	Economy	13000.00
0005434374195	1518	Economy	13000.00
0005434374167	1518	Economy	13000.00
0005434374178	1518	Economy	13000.00
0005434374196	1518	Economy	13000.00
0005433150963	1518	Economy	13000.00
0005434374189	1518	Economy	13000.00
0005434374191	1518	Economy	13000.00
0005434374185	1518	Economy	13000.00
0005433150802	1518	Economy	13000.00
0005433461566	1518	Economy	13000.00
0005433150964	1518	Economy	13000.00
0005432267830	1518	Economy	13000.00
0005433150809	1518	Economy	13000.00
0005434374193	1518	Economy	13000.00
0005433150837	1518	Economy	13000.00
0005434374183	1518	Economy	13000.00
0005434374168	1518	Economy	14300.00
0005434374165	1518	Economy	14300.00
0005433150864	1518	Economy	14300.00
0005434374181	1518	Economy	13000.00
0005434374180	1518	Economy	13000.00
0005433150865	1518	Economy	13000.00
0005434374162	1518	Economy	13000.00
0005433150914	1518	Economy	13000.00
0005433150866	1518	Economy	13000.00
0005434374173	1518	Economy	13000.00
0005434374171	1518	Economy	13000.00
0005433150867	1518	Economy	13000.00
0005434374172	1518	Economy	13000.00
0005433150859	1518	Economy	13000.00
0005434374184	1518	Economy	13000.00
0005432267827	1518	Economy	13000.00
0005434374170	1518	Economy	13000.00
0005433460413	1518	Economy	13000.00
0005434374175	1518	Economy	13000.00
0005433150869	1518	Economy	13000.00
0005434374187	1518	Economy	13000.00
0005433460414	1518	Economy	13000.00
0005433150888	1518	Economy	13000.00
0005432267825	1518	Economy	13000.00
0005433150887	1518	Economy	13000.00
0005433461567	1518	Economy	13000.00
0005434374160	1518	Economy	13000.00
0005434374192	1518	Economy	13000.00
0005434374174	1518	Economy	13000.00
0005434374177	1518	Economy	13000.00
0005433150836	1518	Economy	13000.00
0005434374161	1518	Economy	13000.00
0005433931417	1518	Economy	13000.00
0005434374176	1518	Economy	13000.00
0005434374158	1518	Economy	13000.00
0005432267829	1518	Economy	13000.00
0005434374190	1518	Economy	13000.00
0005434374188	1518	Economy	13000.00
0005433150808	1518	Economy	13000.00
0005434374159	1518	Economy	13000.00
0005433150794	1518	Economy	13000.00
0005432267828	1518	Economy	13000.00
0005433150822	1518	Economy	13000.00
0005434374166	1518	Economy	13000.00
0005434374186	1518	Economy	13000.00
0005433150821	1518	Economy	13000.00
0005433151070	20135	Business	38900.00
0005433151071	20135	Business	38900.00
0005434373855	20135	Business	38900.00
0005433151043	20135	Business	38900.00
0005433931433	20135	Business	38900.00
0005433151066	20135	Business	38900.00
0005433931435	20135	Economy	13000.00
0005434373978	20135	Economy	13000.00
0005433151067	20135	Economy	13000.00
0005433151058	20135	Economy	13000.00
0005433151042	20135	Economy	13000.00
0005433151064	20135	Economy	13000.00
0005433151054	20135	Economy	13000.00
0005433151044	20135	Economy	13000.00
0005433764659	20135	Economy	13000.00
0005432056261	20135	Economy	13000.00
0005433151059	20135	Economy	13000.00
0005433151051	20135	Economy	13000.00
0005433151060	20135	Economy	13000.00
0005433151057	20135	Economy	13000.00
0005433151063	20135	Economy	13000.00
0005433151053	20135	Economy	14300.00
0005433151052	20135	Economy	14300.00
0005433151045	20135	Economy	14300.00
0005434029632	20135	Economy	13000.00
0005433151041	20135	Economy	13000.00
0005434373858	20135	Economy	13000.00
0005434029630	20135	Economy	13000.00
0005433151050	20135	Economy	13000.00
0005432056259	20135	Economy	13000.00
0005434029631	20135	Economy	13000.00
0005433151049	20135	Economy	13000.00
0005433151055	20135	Economy	13000.00
0005434373979	20135	Economy	13000.00
0005433151069	20135	Economy	13000.00
0005434373937	20135	Economy	13000.00
0005434373924	20135	Economy	13000.00
0005433151068	20135	Economy	13000.00
0005433151065	20135	Economy	13000.00
0005433151074	20135	Economy	13000.00
0005433151061	20135	Economy	13000.00
0005433151062	20135	Economy	13000.00
0005434373892	20135	Economy	13000.00
0005434373938	20135	Economy	13000.00
0005433151039	20135	Economy	13000.00
0005433151072	20135	Economy	13000.00
0005433151073	20135	Economy	13000.00
0005433151056	20135	Economy	13000.00
0005434373893	20135	Economy	13000.00
0005434373884	20135	Economy	13000.00
0005433151040	20135	Economy	13000.00
0005433931434	20135	Economy	13000.00
0005433151046	20135	Economy	13000.00
0005433151048	20135	Economy	13000.00
0005434373857	20135	Economy	13000.00
0005434373848	20135	Economy	13000.00
0005433764658	20135	Economy	13000.00
0005434373923	20135	Economy	13000.00
0005434373849	20135	Economy	13000.00
0005432056260	20135	Economy	13000.00
0005432056258	20135	Economy	13000.00
0005433151047	20135	Economy	13000.00
0005432423995	560	Business	27500.00
0005432423983	560	Business	27500.00
0005432423986	560	Business	27500.00
0005432423965	560	Business	27500.00
0005432423956	560	Business	27500.00
0005432423978	560	Business	27500.00
0005432423999	560	Business	27500.00
0005432423961	560	Business	27500.00
0005432282790	560	Business	27500.00
0005432282792	560	Business	27500.00
0005432423982	560	Economy	10100.00
0005432423994	560	Economy	10100.00
0005432282795	560	Economy	10100.00
0005432282794	560	Economy	9200.00
0005432423990	560	Economy	9200.00
0005432423977	560	Economy	9200.00
0005432282793	560	Economy	9200.00
0005432423997	560	Economy	9200.00
0005432423980	560	Economy	9200.00
0005432423963	560	Economy	9200.00
0005432423970	560	Economy	9200.00
0005432423973	560	Economy	9200.00
0005432423991	560	Economy	9200.00
0005432423957	560	Economy	9200.00
0005432423998	560	Economy	9200.00
0005432423975	560	Economy	9200.00
0005432423964	560	Economy	9200.00
0005432423987	560	Economy	9200.00
0005432423958	560	Economy	9200.00
0005432423976	560	Economy	9200.00
0005432423996	560	Economy	9200.00
0005432423972	560	Economy	10100.00
0005432423992	560	Economy	10100.00
0005432282791	560	Economy	9200.00
0005432423966	560	Economy	9200.00
0005432423959	560	Economy	9200.00
0005432423969	560	Economy	9200.00
0005432423979	560	Economy	9200.00
0005432423984	560	Economy	9200.00
0005432423967	560	Economy	9200.00
0005432423989	560	Economy	9200.00
0005432423981	560	Economy	9200.00
0005432423988	560	Economy	9200.00
0005432423968	560	Economy	9200.00
0005432423962	560	Economy	9200.00
0005432423993	560	Economy	9200.00
0005432423960	560	Economy	9200.00
0005432282789	560	Economy	9200.00
0005432423985	560	Economy	9200.00
0005432423974	560	Economy	9200.00
0005432423971	560	Economy	9200.00
0005433158108	12852	Business	27500.00
0005432302295	12852	Business	27500.00
0005433158109	12852	Business	27500.00
0005432302291	12852	Economy	9200.00
0005433158105	12852	Economy	9200.00
0005432302294	12852	Economy	9200.00
0005433158107	12852	Economy	9200.00
0005433158106	12852	Economy	9200.00
0005433158111	12852	Economy	9200.00
0005432302292	12852	Economy	9200.00
0005433158110	12852	Economy	9200.00
0005432302293	12852	Economy	9200.00
0005433158104	12852	Economy	9200.00
0005434023040	471	Business	24500.00
0005434023019	471	Business	24500.00
0005433057257	471	Business	24500.00
0005432235560	471	Business	24500.00
0005434023027	471	Business	24500.00
0005434023054	471	Business	24500.00
0005433057236	471	Business	24500.00
0005434022989	471	Business	24500.00
0005434023013	471	Business	24500.00
0005434031975	471	Business	24500.00
0005434023012	471	Business	24500.00
0005433057234	471	Business	24500.00
0005434735606	471	Business	24500.00
0005433057276	471	Business	24500.00
0005433057248	471	Business	24500.00
0005434023046	471	Business	24500.00
0005434735600	471	Business	24500.00
0005434023036	471	Business	24500.00
0005434023034	471	Business	24500.00
0005433057277	471	Business	24500.00
0005432235566	471	Business	24500.00
0005434023020	471	Economy	9000.00
0005434023023	471	Economy	9000.00
0005434023028	471	Economy	8200.00
0005434022993	471	Economy	8200.00
0005434028264	471	Economy	8200.00
0005434023018	471	Economy	8200.00
0005434023037	471	Economy	8200.00
0005434023029	471	Economy	8200.00
0005433684389	471	Economy	8200.00
0005434022991	471	Economy	8200.00
0005433057289	471	Economy	8200.00
0005434029628	471	Economy	8200.00
0005434031973	471	Economy	8200.00
0005434022994	471	Economy	8200.00
0005433929546	471	Economy	8200.00
0005434023025	471	Economy	8200.00
0005434023009	471	Economy	8200.00
0005432045592	471	Economy	8200.00
0005434023033	471	Economy	8200.00
0005433057219	471	Economy	8200.00
0005434023021	471	Economy	8200.00
0005434023038	471	Economy	8200.00
0005434023014	471	Economy	8200.00
0005434023003	471	Economy	8200.00
0005434023043	471	Economy	8200.00
0005432235563	471	Economy	8200.00
0005434022997	471	Economy	8200.00
0005434022995	471	Economy	8200.00
0005434023004	471	Economy	8200.00
0005434023050	471	Economy	8200.00
0005434023030	471	Economy	8200.00
0005433057183	471	Economy	8200.00
0005434028263	471	Economy	8200.00
0005434023041	471	Economy	8200.00
0005433057218	471	Economy	8200.00
0005434023010	471	Economy	8200.00
0005434023051	471	Economy	8200.00
0005434023017	471	Economy	8200.00
0005433057243	471	Economy	8200.00
0005433057203	471	Economy	8200.00
0005434023001	471	Economy	8200.00
0005434023015	471	Economy	8200.00
0005434028266	471	Economy	8200.00
0005432235565	471	Economy	8200.00
0005434023007	471	Economy	8200.00
0005434023052	471	Economy	8200.00
0005434029627	471	Economy	8200.00
0005433057224	471	Economy	8200.00
0005434023011	471	Economy	8200.00
0005434023005	471	Economy	8200.00
0005434023039	471	Economy	9000.00
0005433057233	471	Economy	9000.00
0005434023049	471	Economy	9000.00
0005433057231	471	Economy	8200.00
0005434022988	471	Economy	8200.00
0005432235559	471	Economy	8200.00
0005432235561	471	Economy	8200.00
0005434023016	471	Economy	8200.00
0005434029629	471	Economy	8200.00
0005432235564	471	Economy	8200.00
0005434022990	471	Economy	8200.00
0005434022999	471	Economy	8200.00
0005434023008	471	Economy	8200.00
0005434022992	471	Economy	8200.00
0005434023026	471	Economy	8200.00
0005434735601	471	Economy	8200.00
0005434023000	471	Economy	8200.00
0005434023035	471	Economy	8200.00
0005434023024	471	Economy	8200.00
0005434023053	471	Economy	8200.00
0005434031972	471	Economy	8200.00
0005434031974	471	Economy	8200.00
0005434022987	471	Economy	8200.00
0005434023006	471	Economy	8200.00
0005434023031	471	Economy	8200.00
0005434022996	471	Economy	8200.00
0005434023044	471	Economy	8200.00
0005434023002	471	Economy	8200.00
0005434023048	471	Economy	8200.00
0005433057244	471	Economy	8200.00
0005433057313	471	Economy	8200.00
0005434023022	471	Economy	8200.00
0005434022986	471	Economy	8200.00
0005434023042	471	Economy	8200.00
0005434023032	471	Economy	8200.00
0005433057245	471	Economy	8200.00
0005434023047	471	Economy	8200.00
0005434022998	471	Economy	8200.00
0005432235558	471	Economy	8200.00
0005432235562	471	Economy	8200.00
0005434028265	471	Economy	8200.00
0005434023045	471	Economy	8200.00
0005433057330	471	Economy	8200.00
0005433057492	12645	Business	24500.00
0005434022612	12645	Business	24500.00
0005433057483	12645	Business	24500.00
0005434022569	12645	Business	24500.00
0005433057474	12645	Business	24500.00
0005433057461	12645	Business	24500.00
0005433057496	12645	Business	24500.00
0005433057456	12645	Business	24500.00
0005433057468	12645	Business	24500.00
0005433057493	12645	Business	24500.00
0005433057486	12645	Business	24500.00
0005433057467	12645	Business	24500.00
0005433057471	12645	Business	24500.00
0005433057494	12645	Economy	9000.00
0005434022516	12645	Economy	9000.00
0005433057473	12645	Economy	9000.00
0005433057458	12645	Economy	8200.00
0005434022732	12645	Economy	8200.00
0005432156322	12645	Economy	8200.00
0005433684399	12645	Economy	8200.00
0005433057482	12645	Economy	8200.00
0005433057478	12645	Economy	8200.00
0005433057487	12645	Economy	8200.00
0005433057470	12645	Economy	8200.00
0005434022558	12645	Economy	8200.00
0005434022613	12645	Economy	8200.00
0005432157471	12645	Economy	8200.00
0005433057460	12645	Economy	8200.00
0005434022515	12645	Economy	8200.00
0005432156318	12645	Economy	8200.00
0005433057457	12645	Economy	8200.00
0005433057469	12645	Economy	8200.00
0005434022507	12645	Economy	8200.00
0005433057490	12645	Economy	8200.00
0005434735640	12645	Economy	8200.00
0005433057491	12645	Economy	8200.00
0005433929571	12645	Economy	8200.00
0005434735639	12645	Economy	8200.00
0005433057489	12645	Economy	8200.00
0005434022579	12645	Economy	8200.00
0005434735637	12645	Economy	8200.00
0005432156320	12645	Economy	8200.00
0005433057459	12645	Economy	8200.00
0005434022632	12645	Economy	8200.00
0005432156321	12645	Economy	8200.00
0005432156323	12645	Economy	8200.00
0005433929569	12645	Economy	8200.00
0005434022527	12645	Economy	8200.00
0005433057462	12645	Economy	8200.00
0005433929570	12645	Economy	8200.00
0005433057480	12645	Economy	8200.00
0005434022670	12645	Economy	8200.00
0005432156319	12645	Economy	8200.00
0005434022580	12645	Economy	9000.00
0005434022525	12645	Economy	8200.00
0005434735638	12645	Economy	9000.00
0005434022554	12645	Economy	8200.00
0005433929572	12645	Economy	8200.00
0005433684400	12645	Economy	8200.00
0005433057476	12645	Economy	8200.00
0005434022526	12645	Economy	8200.00
0005434022690	12645	Economy	8200.00
0005433057485	12645	Economy	8200.00
0005433057495	12645	Economy	8200.00
0005434022551	12645	Economy	8200.00
0005433057484	12645	Economy	8200.00
0005433057481	12645	Economy	8200.00
0005433057466	12645	Economy	8200.00
0005433057463	12645	Economy	8200.00
0005432157472	12645	Economy	8200.00
0005433057464	12645	Economy	8200.00
0005434022547	12645	Economy	8200.00
0005433057477	12645	Economy	8200.00
0005434022553	12645	Economy	8200.00
0005433057475	12645	Economy	8200.00
0005434022713	12645	Economy	8200.00
0005433057479	12645	Economy	8200.00
0005433057472	12645	Economy	8200.00
0005434735636	12645	Economy	8200.00
0005434022552	12645	Economy	8200.00
0005433057488	12645	Economy	8200.00
0005433057465	12645	Economy	8200.00
0005434022508	12645	Economy	8200.00
0005434022631	12645	Economy	8200.00
0005433527225	13819	Business	111600.00
0005433529234	13819	Business	111600.00
0005433527215	13819	Business	111600.00
0005433529226	13819	Business	111600.00
0005433529224	13819	Economy	37200.00
0005433529229	13819	Economy	37200.00
0005433527216	13819	Economy	37200.00
0005433529227	13819	Economy	37200.00
0005433527213	13819	Economy	37200.00
0005433529228	13819	Economy	37200.00
0005433527217	13819	Economy	37200.00
0005433527212	13819	Economy	37200.00
0005433527221	13819	Economy	37200.00
0005433527222	13819	Economy	37200.00
0005433529225	13819	Economy	37200.00
0005433529222	13819	Economy	37200.00
0005433527218	13819	Economy	37200.00
0005433527223	13819	Economy	37200.00
0005433527224	13819	Economy	37200.00
0005433529232	13819	Economy	37200.00
0005433529236	13819	Economy	37200.00
0005433529233	13819	Economy	37200.00
0005433527214	13819	Economy	37200.00
0005433527219	13819	Economy	37200.00
0005433529231	13819	Economy	37200.00
0005433529230	13819	Economy	37200.00
0005433529223	13819	Economy	37200.00
0005433527211	13819	Economy	37200.00
0005433529235	13819	Economy	37200.00
0005433527220	13819	Economy	37200.00
0005433529210	32451	Business	111600.00
0005433922338	2112	Business	34700.00
0005432231454	2112	Business	34700.00
0005433922290	2112	Business	34700.00
0005433922345	2112	Business	34700.00
0005433922301	2112	Business	34700.00
0005433922339	2112	Business	34700.00
0005433922296	2112	Business	34700.00
0005433922359	2112	Business	34700.00
0005433035390	2112	Business	34700.00
0005433922324	2112	Business	34700.00
0005433922292	2112	Business	34700.00
0005433922276	2112	Business	34700.00
0005433922293	2112	Business	34700.00
0005433035378	2112	Business	34700.00
0005433035454	2112	Business	34700.00
0005433035400	2112	Business	34700.00
0005433035393	2112	Business	34700.00
0005433922308	2112	Business	34700.00
0005433035437	2112	Business	34700.00
0005433922370	2112	Business	34700.00
0005433922285	2112	Economy	12700.00
0005433922313	2112	Economy	12700.00
0005432231453	2112	Economy	12700.00
0005433922341	2112	Economy	11600.00
0005433922307	2112	Economy	11600.00
0005433922321	2112	Economy	11600.00
0005433922363	2112	Economy	11600.00
0005433922289	2112	Economy	11600.00
0005433922294	2112	Economy	11600.00
0005433922284	2112	Economy	11600.00
0005433922320	2112	Economy	11600.00
0005433922286	2112	Economy	11600.00
0005433922365	2112	Economy	11600.00
0005433922357	2112	Economy	11600.00
0005433922331	2112	Economy	11600.00
0005433922291	2112	Economy	11600.00
0005433922299	2112	Economy	11600.00
0005433922319	2112	Economy	11600.00
0005433922349	2112	Economy	11600.00
0005433922335	2112	Economy	11600.00
0005433931435	2112	Economy	11600.00
0005433035389	2112	Economy	11600.00
0005432231456	2112	Economy	11600.00
0005433922300	2112	Economy	11600.00
0005432044497	2112	Economy	11600.00
0005433035426	2112	Economy	11600.00
0005433922325	2112	Economy	11600.00
0005433035442	2112	Economy	11600.00
0005433922371	2112	Economy	11600.00
0005432044496	2112	Economy	11600.00
0005433035478	2112	Economy	11600.00
0005433929571	2112	Economy	11600.00
0005433922368	2112	Economy	11600.00
0005433922280	2112	Economy	11600.00
0005433922305	2112	Economy	11600.00
0005433922330	2112	Economy	11600.00
0005433035405	2112	Economy	11600.00
0005433035391	2112	Economy	11600.00
0005432231452	2112	Economy	11600.00
0005433922369	2112	Economy	11600.00
0005433922302	2112	Economy	11600.00
0005433922275	2112	Economy	11600.00
0005433922288	2112	Economy	11600.00
0005433035451	2112	Economy	11600.00
0005432231461	2112	Economy	11600.00
0005433922323	2112	Economy	11600.00
0005433922352	2112	Economy	11600.00
0005432231459	2112	Economy	11600.00
0005433922344	2112	Economy	11600.00
0005433922322	2112	Economy	11600.00
0005433922333	2112	Economy	11600.00
0005433922343	2112	Economy	11600.00
0005433922334	2112	Economy	11600.00
0005433922342	2112	Economy	11600.00
0005433922287	2112	Economy	11600.00
0005433922328	2112	Economy	11600.00
0005433922312	2112	Economy	11600.00
0005433922337	2112	Economy	11600.00
0005433035441	2112	Economy	11600.00
0005432044495	2112	Economy	11600.00
0005433922283	2112	Economy	11600.00
0005433035427	2112	Economy	11600.00
0005433929570	2112	Economy	11600.00
0005433931434	2112	Economy	11600.00
0005433922314	2112	Economy	11600.00
0005433922361	2112	Economy	11600.00
0005433922353	2112	Economy	11600.00
0005433929569	2112	Economy	11600.00
0005433922317	2112	Economy	11600.00
0005433922310	2112	Economy	11600.00
0005432231450	2112	Economy	11600.00
0005433922298	2112	Economy	11600.00
0005433922362	2112	Economy	11600.00
0005433922303	2112	Economy	11600.00
0005433922348	2112	Economy	11600.00
0005433922295	2112	Economy	11600.00
0005433922316	2112	Economy	11600.00
0005433922336	2112	Economy	11600.00
0005433922326	2112	Economy	11600.00
0005433922350	2112	Economy	11600.00
0005433922332	2112	Economy	11600.00
0005433922360	2112	Economy	11600.00
0005433931433	2112	Economy	11600.00
0005433035401	2112	Economy	11600.00
0005432231460	2112	Economy	11600.00
0005433922329	2112	Economy	11600.00
0005433922372	2112	Economy	11600.00
0005433922327	2112	Economy	11600.00
0005433035394	2112	Economy	11600.00
0005433922311	2112	Economy	11600.00
0005433922367	2112	Economy	11600.00
0005433922279	2112	Economy	11600.00
0005433922277	2112	Economy	11600.00
0005433929572	2112	Economy	11600.00
0005433922306	2112	Economy	11600.00
0005432231458	2112	Economy	11600.00
0005433922347	2112	Economy	11600.00
0005433922297	2112	Economy	11600.00
0005433922366	2112	Economy	11600.00
0005433922318	2112	Economy	11600.00
0005433922358	2112	Economy	11600.00
0005433922340	2112	Economy	11600.00
0005433035438	2112	Economy	11600.00
0005433922351	2112	Economy	11600.00
0005433922304	2112	Economy	11600.00
0005433922354	2112	Economy	11600.00
0005433922355	2112	Economy	11600.00
0005433922315	2112	Economy	11600.00
0005433922356	2112	Economy	11600.00
0005432231451	2112	Economy	11600.00
0005433922373	2112	Economy	11600.00
0005433922278	2112	Economy	11600.00
0005433922281	2112	Economy	11600.00
0005432231457	2112	Economy	11600.00
0005433922364	2112	Economy	11600.00
0005433922282	2112	Economy	11600.00
0005433922346	2112	Economy	11600.00
0005432231455	2112	Economy	11600.00
0005433035531	2112	Economy	11600.00
0005433922309	2112	Economy	11600.00
0005434028267	24143	Business	34700.00
0005433921753	24143	Business	34700.00
0005433035771	24143	Business	34700.00
0005433931422	24143	Business	34700.00
0005433921610	24143	Business	34700.00
0005433035770	24143	Business	34700.00
0005433035763	24143	Business	34700.00
0005433035743	24143	Business	34700.00
0005434028270	24143	Business	34700.00
0005434028269	24143	Business	34700.00
0005433035773	24143	Business	34700.00
0005432207636	24143	Business	34700.00
0005434028268	24143	Economy	12700.00
0005433035769	24143	Economy	12700.00
0005433921752	24143	Economy	12700.00
0005433921609	24143	Economy	12700.00
0005433035755	24143	Economy	11600.00
0005433035787	24143	Economy	11600.00
0005433035752	24143	Economy	11600.00
0005433035739	24143	Economy	11600.00
0005433035761	24143	Economy	11600.00
0005433035750	24143	Economy	11600.00
0005433921645	24143	Economy	11600.00
0005433921595	24143	Economy	11600.00
0005432207635	24143	Economy	11600.00
0005433035748	24143	Economy	11600.00
0005433035756	24143	Economy	11600.00
0005432207634	24143	Economy	11600.00
0005433035762	24143	Economy	11600.00
0005433035767	24143	Economy	11600.00
0005433921647	24143	Economy	11600.00
0005433035742	24143	Economy	11600.00
0005433921818	24143	Economy	11600.00
0005433035746	24143	Economy	11600.00
0005433035781	24143	Economy	11600.00
0005433035754	24143	Economy	11600.00
0005433035778	24143	Economy	11600.00
0005433035776	24143	Economy	11600.00
0005432749762	24143	Economy	11600.00
0005433035784	24143	Economy	11600.00
0005432206137	24143	Economy	11600.00
0005433035745	24143	Economy	11600.00
0005433035783	24143	Economy	11600.00
0005432206133	24143	Economy	11600.00
0005433921611	24143	Economy	11600.00
0005432206136	24143	Economy	11600.00
0005433921670	24143	Economy	11600.00
0005433921589	24143	Economy	11600.00
0005433921661	24143	Economy	11600.00
0005433035785	24143	Economy	11600.00
0005433035777	24143	Economy	11600.00
0005433035764	24143	Economy	11600.00
0005433921615	24143	Economy	11600.00
0005433035757	24143	Economy	11600.00
0005433921616	24143	Economy	11600.00
0005433922048	24143	Economy	11600.00
0005433875356	24143	Economy	11600.00
0005433035775	24143	Economy	11600.00
0005433035766	24143	Economy	11600.00
0005433875355	24143	Economy	11600.00
0005433035765	24143	Economy	11600.00
0005432206134	24143	Economy	11600.00
0005432206138	24143	Economy	11600.00
0005433035749	24143	Economy	11600.00
0005433035747	24143	Economy	11600.00
0005433035744	24143	Economy	12700.00
0005433035768	24143	Economy	12700.00
0005433921866	24143	Economy	11600.00
0005433921588	24143	Economy	11600.00
0005433921807	24143	Economy	12700.00
0005433921671	24143	Economy	12700.00
0005433922050	24143	Economy	11600.00
0005433921587	24143	Economy	11600.00
0005433035774	24143	Economy	11600.00
0005433035740	24143	Economy	11600.00
0005433035779	24143	Economy	11600.00
0005432749763	24143	Economy	11600.00
0005432206139	24143	Economy	11600.00
0005433035738	24143	Economy	11600.00
0005433035751	24143	Economy	11600.00
0005433035782	24143	Economy	11600.00
0005433921859	24143	Economy	11600.00
0005433921646	24143	Economy	11600.00
0005433035735	24143	Economy	11600.00
0005433921662	24143	Economy	11600.00
0005433035759	24143	Economy	11600.00
0005432206135	24143	Economy	11600.00
0005433035786	24143	Economy	11600.00
0005433035780	24143	Economy	11600.00
0005433922049	24143	Economy	11600.00
0005433035753	24143	Economy	11600.00
0005433035772	24143	Economy	11600.00
0005433035760	24143	Economy	11600.00
0005433035758	24143	Economy	11600.00
0005433035741	24143	Economy	11600.00
0005433921617	24143	Economy	11600.00
0005433035736	24143	Economy	11600.00
0005433921836	24143	Economy	11600.00
0005433035737	24143	Economy	11600.00
0005433921599	24143	Economy	11600.00
0005433931421	24143	Economy	11600.00
0005434724205	258	Business	83700.00
0005434550690	258	Business	83700.00
0005434550668	258	Business	83700.00
0005433180658	258	Business	83700.00
0005434724222	258	Business	83700.00
0005433233210	258	Business	83700.00
0005433233158	258	Business	83700.00
0005434550703	258	Business	83700.00
0005433233273	258	Business	83700.00
0005433233199	258	Business	83700.00
0005434550688	258	Business	83700.00
0005434724264	258	Business	83700.00
0005435142433	258	Business	83700.00
0005434724263	258	Business	83700.00
0005434724188	258	Business	83700.00
0005434550685	258	Business	83700.00
0005435142445	258	Business	83700.00
0005434724245	258	Business	83700.00
0005434724209	258	Business	83700.00
0005432277670	258	Comfort	47400.00
0005434724219	258	Comfort	47400.00
0005435142443	258	Comfort	47400.00
0005435142435	258	Comfort	47400.00
0005433233092	258	Comfort	47400.00
0005435142440	258	Comfort	47400.00
0005434724185	258	Comfort	47400.00
0005434724273	258	Comfort	47400.00
0005434550657	258	Comfort	47400.00
0005434735633	258	Comfort	47400.00
0005434724178	258	Comfort	47400.00
0005434724214	258	Comfort	47400.00
0005434724271	258	Comfort	47400.00
0005434724238	258	Comfort	47400.00
0005434724202	258	Comfort	47400.00
0005434550679	258	Comfort	47400.00
0005433233155	258	Comfort	47400.00
0005434724293	258	Comfort	47400.00
0005434724255	258	Comfort	47400.00
0005433233230	258	Comfort	47400.00
0005434724192	258	Comfort	47400.00
0005434550654	258	Comfort	47400.00
0005432277673	258	Comfort	47400.00
0005434724180	258	Comfort	47400.00
0005435142442	258	Comfort	47400.00
0005433126770	258	Comfort	47400.00
0005434724206	258	Comfort	47400.00
0005434724277	258	Comfort	47400.00
0005434550655	258	Comfort	47400.00
0005434550696	258	Comfort	47400.00
0005434724215	258	Comfort	47400.00
0005434724201	258	Comfort	47400.00
0005434724226	258	Comfort	47400.00
0005434724224	258	Comfort	47400.00
0005434550683	258	Comfort	47400.00
0005434550676	258	Comfort	47400.00
0005434550656	258	Comfort	47400.00
0005434724294	258	Comfort	47400.00
0005433180679	258	Economy	27900.00
0005434724239	258	Economy	27900.00
0005434550674	258	Economy	27900.00
0005434724179	258	Economy	27900.00
0005434724248	258	Economy	27900.00
0005434724250	258	Economy	27900.00
0005434724266	258	Economy	27900.00
0005434724259	258	Economy	27900.00
0005434550684	258	Economy	27900.00
0005434724234	258	Economy	27900.00
0005434724300	258	Economy	27900.00
0005434724246	258	Economy	27900.00
0005434724235	258	Economy	27900.00
0005434550669	258	Economy	27900.00
0005434724272	258	Economy	27900.00
0005434735630	258	Economy	27900.00
0005434724299	258	Economy	27900.00
0005434724213	258	Economy	27900.00
0005434724290	258	Economy	27900.00
0005434724286	258	Economy	27900.00
0005433180666	258	Economy	27900.00
0005432277677	258	Economy	27900.00
0005434550680	258	Economy	27900.00
0005434724189	258	Economy	27900.00
0005434724281	258	Economy	27900.00
0005434550673	258	Economy	27900.00
0005434724267	258	Economy	27900.00
0005433131627	258	Economy	27900.00
0005434550662	258	Economy	27900.00
0005434724244	258	Economy	27900.00
0005434724241	258	Economy	27900.00
0005434550681	258	Economy	27900.00
0005434724225	258	Economy	27900.00
0005434724233	258	Economy	27900.00
0005434550660	258	Economy	27900.00
0005434724218	258	Economy	27900.00
0005434550697	258	Economy	27900.00
0005434724278	258	Economy	27900.00
0005433233157	258	Economy	27900.00
0005434724196	258	Economy	27900.00
0005435142446	258	Economy	27900.00
0005434724197	258	Economy	27900.00
0005434302417	258	Economy	27900.00
0005433180742	258	Economy	27900.00
0005432277667	258	Economy	27900.00
0005434724203	258	Economy	27900.00
0005434724251	258	Economy	30700.00
0005434550682	258	Economy	30700.00
0005434550665	258	Economy	27900.00
0005434724237	258	Economy	27900.00
0005434724252	258	Economy	30700.00
0005434735629	258	Economy	27900.00
0005434724275	258	Economy	30700.00
0005433233147	258	Economy	30700.00
0005434550667	258	Economy	27900.00
0005434550702	258	Economy	27900.00
0005434724269	258	Economy	27900.00
0005434550664	258	Economy	27900.00
0005434724276	258	Economy	27900.00
0005434550687	258	Economy	27900.00
0005434550651	258	Economy	27900.00
0005434724186	258	Economy	27900.00
0005435142439	258	Economy	27900.00
0005433233290	258	Economy	27900.00
0005434724282	258	Economy	27900.00
0005434724221	258	Economy	27900.00
0005433111471	258	Economy	27900.00
0005433180672	258	Economy	27900.00
0005434724231	258	Economy	27900.00
0005434724184	258	Economy	27900.00
0005434550691	258	Economy	27900.00
0005434724212	258	Economy	27900.00
0005434724268	258	Economy	27900.00
0005433233108	258	Economy	27900.00
0005434724262	258	Economy	27900.00
0005434550666	258	Economy	27900.00
0005433233160	258	Economy	27900.00
0005434724260	258	Economy	27900.00
0005434550670	258	Economy	27900.00
0005434724297	258	Economy	27900.00
0005433180654	258	Economy	27900.00
0005434735632	258	Economy	27900.00
0005434550677	258	Economy	27900.00
0005434724254	258	Economy	27900.00
0005434724236	258	Economy	27900.00
0005434550675	258	Economy	27900.00
0005434550699	258	Economy	27900.00
0005434724292	258	Economy	27900.00
0005433233138	258	Economy	27900.00
0005434724204	258	Economy	27900.00
0005435142436	258	Economy	27900.00
0005434550671	258	Economy	27900.00
0005434724242	258	Economy	27900.00
0005434724198	258	Economy	27900.00
0005434724229	258	Economy	27900.00
0005433180675	258	Economy	27900.00
0005434724295	258	Economy	27900.00
0005432277676	258	Economy	27900.00
0005432277669	258	Economy	27900.00
0005434550700	258	Economy	27900.00
0005434550704	258	Economy	27900.00
0005434735635	258	Economy	27900.00
0005435142432	258	Economy	27900.00
0005434550686	258	Economy	27900.00
0005432277672	258	Economy	27900.00
0005433233201	258	Economy	27900.00
0005434731122	258	Economy	27900.00
0005434735631	258	Economy	27900.00
0005434724280	258	Economy	27900.00
0005434031944	258	Economy	27900.00
0005434724265	258	Economy	27900.00
0005434724211	258	Economy	27900.00
0005434724182	258	Economy	27900.00
0005433233231	258	Economy	27900.00
0005433233090	258	Economy	27900.00
0005434724257	258	Economy	27900.00
0005434724288	258	Economy	27900.00
0005435142437	258	Economy	27900.00
0005434724270	258	Economy	27900.00
0005434724183	258	Economy	27900.00
0005435142438	258	Economy	27900.00
0005434731124	258	Economy	27900.00
0005434724261	258	Economy	27900.00
0005434724287	258	Economy	27900.00
0005434724207	258	Economy	27900.00
0005434550661	258	Economy	27900.00
0005434302415	258	Economy	27900.00
0005434724210	258	Economy	27900.00
0005434724217	258	Economy	27900.00
0005433113496	258	Economy	27900.00
0005432277675	258	Economy	27900.00
0005433233137	258	Economy	30700.00
0005434724296	258	Economy	27900.00
0005434724181	258	Economy	30700.00
0005433233315	258	Economy	27900.00
0005434724190	258	Economy	30700.00
0005434724191	258	Economy	27900.00
0005432277668	258	Economy	27900.00
0005433180683	258	Economy	27900.00
0005434550693	258	Economy	27900.00
0005433180709	258	Economy	27900.00
0005434724193	258	Economy	27900.00
0005434724187	258	Economy	27900.00
0005434550652	258	Economy	27900.00
0005434724223	258	Economy	27900.00
0005433233102	258	Economy	27900.00
0005433233101	258	Economy	27900.00
0005434550694	258	Economy	27900.00
0005432277666	258	Economy	27900.00
0005434724195	258	Economy	27900.00
0005434724247	258	Economy	27900.00
0005434724256	258	Economy	27900.00
0005434302413	258	Economy	27900.00
0005434302416	258	Economy	27900.00
0005433131626	258	Economy	27900.00
0005435142434	258	Economy	27900.00
0005433111469	258	Economy	27900.00
0005434731125	258	Economy	27900.00
0005434724253	258	Economy	27900.00
0005434724298	258	Economy	27900.00
0005434731123	258	Economy	27900.00
0005434550698	258	Economy	27900.00
0005433180711	258	Economy	27900.00
0005434031952	258	Economy	27900.00
0005434550689	258	Economy	27900.00
0005433233146	258	Economy	27900.00
0005434724289	258	Economy	27900.00
0005434550653	258	Economy	27900.00
0005434724258	258	Economy	27900.00
0005434724291	258	Economy	27900.00
0005432277665	258	Economy	27900.00
0005434302414	258	Economy	27900.00
0005434735634	258	Economy	27900.00
0005433233177	258	Economy	27900.00
0005434724216	258	Economy	27900.00
0005433180676	258	Economy	27900.00
0005434724227	258	Economy	27900.00
0005433233154	258	Economy	27900.00
0005435142441	258	Economy	27900.00
0005432277671	258	Economy	27900.00
0005433233159	258	Economy	27900.00
0005433180678	258	Economy	27900.00
0005434724240	258	Economy	27900.00
0005434550701	258	Economy	27900.00
0005434550658	258	Economy	27900.00
0005434550692	258	Economy	27900.00
0005434550672	258	Economy	27900.00
0005434550678	258	Economy	27900.00
0005434724243	258	Economy	27900.00
0005434724232	258	Economy	27900.00
0005434724279	258	Economy	27900.00
0005433180653	258	Economy	27900.00
0005434724274	258	Economy	27900.00
0005433111468	258	Economy	27900.00
0005434724208	258	Economy	27900.00
0005433180671	258	Economy	27900.00
0005434724283	258	Economy	27900.00
0005434724230	258	Economy	27900.00
0005434724200	258	Economy	27900.00
0005432277678	258	Economy	27900.00
0005434550695	258	Economy	27900.00
0005434724220	258	Economy	27900.00
0005434550663	258	Economy	27900.00
0005433126771	258	Economy	27900.00
0005434724285	258	Economy	27900.00
0005432277674	258	Economy	27900.00
0005433233109	258	Economy	27900.00
0005434550705	258	Economy	27900.00
0005434724249	258	Economy	27900.00
0005434724228	258	Economy	27900.00
0005434724199	258	Economy	27900.00
0005434724194	258	Economy	27900.00
0005434724284	258	Economy	27900.00
0005435142444	258	Economy	27900.00
0005433131629	258	Economy	27900.00
0005434550659	258	Economy	27900.00
0005433180831	9846	Business	83700.00
0005434723318	9846	Business	83700.00
0005433233570	9846	Business	83700.00
0005433233591	9846	Business	83700.00
0005433126795	9846	Business	83700.00
0005432199174	9846	Business	83700.00
0005434723466	9846	Business	83700.00
0005433233564	9846	Business	83700.00
0005433233584	9846	Business	83700.00
0005434723534	9846	Business	83700.00
0005434031979	9846	Business	83700.00
0005433180846	9846	Comfort	47400.00
0005433233586	9846	Business	83700.00
0005433180845	9846	Comfort	47400.00
0005433233558	9846	Comfort	47400.00
0005433233581	9846	Comfort	47400.00
0005433233561	9846	Comfort	47400.00
0005434723706	9846	Comfort	47400.00
0005433233594	9846	Comfort	47400.00
0005433233534	9846	Comfort	47400.00
0005433233590	9846	Comfort	47400.00
0005433233535	9846	Comfort	47400.00
0005433180843	9846	Comfort	47400.00
0005433126798	9846	Comfort	47400.00
0005434723719	9846	Comfort	47400.00
0005433180835	9846	Comfort	47400.00
0005434724036	9846	Comfort	47400.00
0005433289768	9846	Comfort	47400.00
0005433129228	9846	Comfort	47400.00
0005434723389	9846	Comfort	47400.00
0005434302390	9846	Comfort	47400.00
0005434723629	9846	Economy	27900.00
0005433233552	9846	Economy	27900.00
0005433233573	9846	Economy	27900.00
0005433233560	9846	Economy	27900.00
0005433233539	9846	Economy	27900.00
0005434550390	9846	Economy	27900.00
0005433180830	9846	Economy	27900.00
0005433233550	9846	Economy	27900.00
0005434723325	9846	Economy	27900.00
0005433126797	9846	Economy	27900.00
0005433113511	9846	Economy	27900.00
0005433180848	9846	Economy	27900.00
0005433233543	9846	Economy	27900.00
0005433233592	9846	Economy	27900.00
0005434723656	9846	Economy	27900.00
0005433129226	9846	Economy	27900.00
0005434723586	9846	Economy	27900.00
0005433180850	9846	Economy	27900.00
0005434723398	9846	Economy	27900.00
0005434031978	9846	Economy	27900.00
0005434302385	9846	Economy	27900.00
0005432199176	9846	Economy	27900.00
0005433233566	9846	Economy	27900.00
0005434723467	9846	Economy	27900.00
0005433233562	9846	Economy	27900.00
0005434723718	9846	Economy	27900.00
0005433289773	9846	Economy	27900.00
0005434723317	9846	Economy	27900.00
0005433129227	9846	Economy	27900.00
0005433233540	9846	Economy	27900.00
0005433233536	9846	Economy	27900.00
0005433180834	9846	Economy	27900.00
0005433233556	9846	Economy	27900.00
0005433233549	9846	Economy	27900.00
0005434302389	9846	Economy	27900.00
0005433180839	9846	Economy	27900.00
0005434550292	9846	Economy	27900.00
0005434723613	9846	Economy	27900.00
0005434723513	9846	Economy	27900.00
0005433180854	9846	Economy	27900.00
0005433233580	9846	Economy	27900.00
0005433180840	9846	Economy	27900.00
0005433233545	9846	Economy	27900.00
0005433289775	9846	Economy	27900.00
0005434723391	9846	Economy	27900.00
0005433180847	9846	Economy	27900.00
0005434723374	9846	Economy	27900.00
0005433289774	9846	Economy	27900.00
0005434031980	9846	Economy	27900.00
0005433233579	9846	Economy	27900.00
0005433233565	9846	Economy	27900.00
0005433766601	9846	Economy	27900.00
0005433233551	9846	Economy	27900.00
0005434723419	9846	Economy	27900.00
0005434735597	9846	Economy	27900.00
0005433233546	9846	Economy	27900.00
0005433233577	9846	Economy	27900.00
0005433233571	9846	Economy	27900.00
0005433233567	9846	Economy	27900.00
0005434031976	9846	Economy	27900.00
0005434723418	9846	Economy	27900.00
0005433180833	9846	Economy	27900.00
0005434723542	9846	Economy	27900.00
0005433126796	9846	Economy	27900.00
0005432199179	9846	Economy	27900.00
0005433233574	9846	Economy	27900.00
0005433233533	9846	Economy	27900.00
0005434550391	9846	Economy	27900.00
0005433129230	9846	Economy	27900.00
0005433233557	9846	Economy	27900.00
0005433289770	9846	Economy	27900.00
0005434723554	9846	Economy	27900.00
0005433180836	9846	Economy	27900.00
0005434724034	9846	Economy	27900.00
0005434723694	9846	Economy	27900.00
0005434723816	9846	Economy	27900.00
0005433180849	9846	Economy	27900.00
0005433233553	9846	Economy	27900.00
0005433126799	9846	Economy	27900.00
0005432199178	9846	Economy	27900.00
0005433233532	9846	Economy	27900.00
0005433233544	9846	Economy	27900.00
0005433233568	9846	Economy	27900.00
0005433233587	9846	Economy	27900.00
0005433233576	9846	Economy	27900.00
0005433233575	9846	Economy	27900.00
0005433233548	9846	Economy	27900.00
0005433233554	9846	Economy	27900.00
0005434723472	9846	Economy	27900.00
0005433180841	9846	Economy	27900.00
0005433766602	9846	Economy	27900.00
0005434723533	9846	Economy	27900.00
0005433289771	9846	Economy	27900.00
0005433180852	9846	Economy	30700.00
0005433233589	9846	Economy	30700.00
0005433766600	9846	Economy	27900.00
0005433233583	9846	Economy	27900.00
0005433233593	9846	Economy	27900.00
0005434723379	9846	Economy	27900.00
0005433233538	9846	Economy	27900.00
0005433233559	9846	Economy	27900.00
0005434723514	9846	Economy	27900.00
0005434723388	9846	Economy	27900.00
0005433766599	9846	Economy	27900.00
0005433180837	9846	Economy	27900.00
0005433180838	9846	Economy	27900.00
0005434724035	9846	Economy	27900.00
0005434723350	9846	Economy	27900.00
0005432199175	9846	Economy	27900.00
0005433233588	9846	Economy	27900.00
0005433180829	9846	Economy	27900.00
0005433180853	9846	Economy	27900.00
0005434031977	9846	Economy	27900.00
0005434723372	9846	Economy	27900.00
0005433289772	9846	Economy	27900.00
0005433180851	9846	Economy	27900.00
0005432199177	9846	Economy	27900.00
0005433129229	9846	Economy	27900.00
0005433233569	9846	Economy	27900.00
0005433233537	9846	Economy	27900.00
0005433233542	9846	Economy	27900.00
0005434723458	9846	Economy	27900.00
0005434723610	9846	Economy	27900.00
0005433233547	9846	Economy	27900.00
0005433113512	9846	Economy	27900.00
0005433233555	9846	Economy	27900.00
0005433233563	9846	Economy	27900.00
0005433180842	9846	Economy	27900.00
0005433180844	9846	Economy	27900.00
0005434723357	9846	Economy	27900.00
0005433289769	9846	Economy	27900.00
0005433233585	9846	Economy	27900.00
0005434723541	9846	Economy	27900.00
0005433233541	9846	Economy	27900.00
0005433233572	9846	Economy	27900.00
0005433129231	9846	Economy	27900.00
0005432199173	9846	Economy	27900.00
0005433233582	9846	Economy	27900.00
0005434723417	9846	Economy	27900.00
0005434550397	9846	Economy	27900.00
0005433180832	9846	Economy	27900.00
0005434723693	9846	Economy	27900.00
0005433233578	9846	Economy	27900.00
0005432428892	7732	Business	42100.00
0005435212369	7732	Business	42100.00
0005432150115	7732	Business	42100.00
0005432526649	7732	Business	42100.00
0005432526627	7732	Business	42100.00
0005434066864	7732	Business	42100.00
0005432526699	7732	Business	42100.00
0005432526597	7732	Business	42100.00
0005434066808	7732	Business	42100.00
0005434066824	7732	Business	42100.00
0005432526600	7732	Business	42100.00
0005432069508	7732	Business	42100.00
0005435212479	7732	Business	42100.00
0005432526658	7732	Business	42100.00
0005434066859	7732	Business	42100.00
0005434066818	7732	Business	42100.00
0005432526611	7732	Business	42100.00
0005432526624	7732	Business	42100.00
0005432526599	7732	Comfort	23900.00
0005434066851	7732	Business	42100.00
0005432526706	7732	Comfort	23900.00
0005432526686	7732	Comfort	23900.00
0005432526625	7732	Comfort	23900.00
0005432526605	7732	Comfort	23900.00
0005432526618	7732	Comfort	23900.00
0005432526586	7732	Comfort	23900.00
0005435212334	7732	Comfort	23900.00
0005434066861	7732	Comfort	23900.00
0005432526684	7732	Comfort	23900.00
0005435212457	7732	Comfort	23900.00
0005432526685	7732	Comfort	23900.00
0005432526667	7732	Comfort	23900.00
0005434066872	7732	Comfort	23900.00
0005432069506	7732	Comfort	23900.00
0005432526637	7732	Comfort	23900.00
0005432526640	7732	Comfort	23900.00
0005432150114	7732	Comfort	23900.00
0005432526687	7732	Comfort	23900.00
0005432526580	7732	Comfort	23900.00
0005434066830	7732	Comfort	23900.00
0005434066827	7732	Comfort	23900.00
0005432526631	7732	Comfort	23900.00
0005434066862	7732	Comfort	23900.00
0005432526678	7732	Comfort	23900.00
0005432069498	7732	Comfort	23900.00
0005432526578	7732	Comfort	23900.00
0005432526598	7732	Comfort	23900.00
0005434066850	7732	Comfort	23900.00
0005434066847	7732	Comfort	23900.00
0005434066817	7732	Comfort	23900.00
0005432526633	7732	Comfort	23900.00
0005432526622	7732	Comfort	23900.00
0005432526579	7732	Comfort	23900.00
0005432535785	7732	Comfort	23900.00
0005432526615	7732	Economy	14000.00
0005434066855	7732	Comfort	23900.00
0005432526666	7732	Economy	14000.00
0005434066828	7732	Economy	14000.00
0005434066873	7732	Economy	14000.00
0005434066812	7732	Economy	14000.00
0005435212364	7732	Economy	14000.00
0005434066856	7732	Economy	14000.00
0005432535781	7732	Economy	14000.00
0005432533263	7732	Economy	14000.00
0005432526674	7732	Economy	14000.00
0005435212440	7732	Economy	14000.00
0005432535782	7732	Economy	14000.00
0005432526590	7732	Economy	14000.00
0005434066857	7732	Economy	14000.00
0005432526660	7732	Economy	14000.00
0005432526689	7732	Economy	14000.00
0005434066837	7732	Economy	14000.00
0005434066867	7732	Economy	14000.00
0005432526635	7732	Economy	14000.00
0005432526647	7732	Economy	14000.00
0005432526690	7732	Economy	14000.00
0005432526588	7732	Economy	14000.00
0005432150110	7732	Economy	14000.00
0005434066823	7732	Economy	14000.00
0005434066836	7732	Economy	14000.00
0005432533262	7732	Economy	14000.00
0005434066822	7732	Economy	14000.00
0005434066826	7732	Economy	14000.00
0005432526621	7732	Economy	14000.00
0005432526654	7732	Economy	14000.00
0005432533261	7732	Economy	14000.00
0005432526582	7732	Economy	14000.00
0005435212487	7732	Economy	14000.00
0005432526642	7732	Economy	14000.00
0005432526614	7732	Economy	14000.00
0005435212527	7732	Economy	14000.00
0005434066854	7732	Economy	14000.00
0005434066868	7732	Economy	14000.00
0005432526693	7732	Economy	14000.00
0005432526616	7732	Economy	14000.00
0005435212513	7732	Economy	14000.00
0005435212441	7732	Economy	14000.00
0005434066813	7732	Economy	14000.00
0005432526651	7732	Economy	14000.00
0005432526652	7732	Economy	14000.00
0005434066821	7732	Economy	14000.00
0005432428894	7732	Economy	14000.00
0005434066844	7732	Economy	14000.00
0005432150111	7732	Economy	15400.00
0005432526575	7732	Economy	14000.00
0005434066804	7732	Economy	15400.00
0005434066805	7732	Economy	14000.00
0005432535784	7732	Economy	15400.00
0005432526589	7732	Economy	15400.00
0005432526656	7732	Economy	14000.00
0005432526681	7732	Economy	14000.00
0005434066842	7732	Economy	14000.00
0005432526596	7732	Economy	14000.00
0005432526591	7732	Economy	14000.00
0005432526587	7732	Economy	14000.00
0005432069511	7732	Economy	14000.00
0005432526677	7732	Economy	14000.00
0005435212443	7732	Economy	14000.00
0005434066829	7732	Economy	14000.00
0005432526643	7732	Economy	14000.00
0005432526671	7732	Economy	14000.00
0005435212478	7732	Economy	14000.00
0005434066835	7732	Economy	14000.00
0005432526626	7732	Economy	14000.00
0005432526617	7732	Economy	14000.00
0005434066806	7732	Economy	14000.00
0005432150116	7732	Economy	14000.00
0005433656619	7732	Economy	14000.00
0005432069507	7732	Economy	14000.00
0005434066833	7732	Economy	14000.00
0005432069509	7732	Economy	14000.00
0005434066825	7732	Economy	14000.00
0005434066866	7732	Economy	14000.00
0005432526691	7732	Economy	14000.00
0005434066831	7732	Economy	14000.00
0005432069503	7732	Economy	14000.00
0005434066816	7732	Economy	14000.00
0005432526623	7732	Economy	14000.00
0005432526632	7732	Economy	14000.00
0005432150117	7732	Economy	14000.00
0005434066848	7732	Economy	14000.00
0005432526628	7732	Economy	14000.00
0005432526703	7732	Economy	14000.00
0005432526612	7732	Economy	14000.00
0005434066860	7732	Economy	14000.00
0005432526694	7732	Economy	14000.00
0005434066810	7732	Economy	14000.00
0005435212345	7732	Economy	14000.00
0005434066841	7732	Economy	14000.00
0005432526670	7732	Economy	14000.00
0005432526604	7732	Economy	14000.00
0005432526584	7732	Economy	14000.00
0005432069500	7732	Economy	14000.00
0005434066819	7732	Economy	14000.00
0005432150112	7732	Economy	14000.00
0005432526606	7732	Economy	14000.00
0005432526676	7732	Economy	14000.00
0005432526595	7732	Economy	14000.00
0005435212370	7732	Economy	14000.00
0005432526705	7732	Economy	14000.00
0005435212363	7732	Economy	14000.00
0005432526636	7732	Economy	14000.00
0005435212411	7732	Economy	14000.00
0005432526692	7732	Economy	14000.00
0005432526700	7732	Economy	14000.00
0005432526581	7732	Economy	14000.00
0005432069505	7732	Economy	14000.00
0005432526697	7732	Economy	14000.00
0005434066832	7732	Economy	14000.00
0005432535783	7732	Economy	14000.00
0005432526661	7732	Economy	14000.00
0005432526646	7732	Economy	14000.00
0005434066809	7732	Economy	14000.00
0005432526603	7732	Economy	14000.00
0005432526608	7732	Economy	14000.00
0005435212333	7732	Economy	14000.00
0005432526673	7732	Economy	14000.00
0005432526641	7732	Economy	14000.00
0005434066871	7732	Economy	14000.00
0005432526659	7732	Economy	14000.00
0005435212429	7732	Economy	14000.00
0005432526644	7732	Economy	14000.00
0005432526613	7732	Economy	14000.00
0005432526650	7732	Economy	14000.00
0005432069502	7732	Economy	14000.00
0005432069512	7732	Economy	14000.00
0005435212335	7732	Economy	14000.00
0005432526610	7732	Economy	14000.00
0005432526696	7732	Economy	14000.00
0005435212378	7732	Economy	14000.00
0005432526672	7732	Economy	15400.00
0005432526695	7732	Economy	15400.00
0005432526655	7732	Economy	15400.00
0005432150113	7732	Economy	15400.00
0005432526668	7732	Economy	15400.00
0005432526665	7732	Economy	14000.00
0005432526620	7732	Economy	14000.00
0005434066869	7732	Economy	14000.00
0005432526669	7732	Economy	14000.00
0005432526593	7732	Economy	14000.00
0005432069501	7732	Economy	14000.00
0005432526664	7732	Economy	14000.00
0005432526594	7732	Economy	14000.00
0005432526663	7732	Economy	14000.00
0005432526701	7732	Economy	14000.00
0005434066838	7732	Economy	14000.00
0005434066807	7732	Economy	14000.00
0005434066820	7732	Economy	14000.00
0005434066849	7732	Economy	14000.00
0005432069504	7732	Economy	14000.00
0005434066874	7732	Economy	14000.00
0005434066852	7732	Economy	14000.00
0005432526609	7732	Economy	14000.00
0005432526619	7732	Economy	14000.00
0005435212375	7732	Economy	14000.00
0005434066814	7732	Economy	14000.00
0005432526607	7732	Economy	14000.00
0005432428893	7732	Economy	14000.00
0005432526688	7732	Economy	14000.00
0005432526679	7732	Economy	14000.00
0005435212371	7732	Economy	14000.00
0005432526638	7732	Economy	14000.00
0005432526583	7732	Economy	14000.00
0005432526602	7732	Economy	14000.00
0005432526682	7732	Economy	14000.00
0005432526601	7732	Economy	14000.00
0005432526585	7732	Economy	14000.00
0005432069510	7732	Economy	14000.00
0005434066858	7732	Economy	14000.00
0005434066843	7732	Economy	14000.00
0005432526592	7732	Economy	14000.00
0005432069499	7732	Economy	14000.00
0005434066845	7732	Economy	14000.00
0005434066840	7732	Economy	14000.00
0005432526702	7732	Economy	14000.00
0005432526630	7732	Economy	14000.00
0005434066834	7732	Economy	14000.00
0005434066815	7732	Economy	14000.00
0005434066839	7732	Economy	14000.00
0005434066853	7732	Economy	14000.00
0005432526662	7732	Economy	14000.00
0005432526576	7732	Economy	14000.00
0005432526577	7732	Economy	14000.00
0005434066870	7732	Economy	14000.00
0005432526683	7732	Economy	14000.00
0005432526653	7732	Economy	14000.00
0005435212379	7732	Economy	14000.00
0005432526645	7732	Economy	14000.00
0005435212444	7732	Economy	14000.00
0005434066875	7732	Economy	14000.00
0005432526634	7732	Economy	14000.00
0005434066846	7732	Economy	14000.00
0005432526657	7732	Economy	14000.00
0005434066865	7732	Economy	14000.00
0005432526648	7732	Economy	14000.00
0005432526704	7732	Economy	14000.00
0005435212372	7732	Economy	14000.00
0005432526639	7732	Economy	14000.00
0005434066811	7732	Economy	14000.00
0005435212512	7732	Economy	14000.00
0005432526698	7732	Economy	14000.00
0005434066863	7732	Economy	14000.00
0005432526680	7732	Economy	14000.00
0005435212347	7732	Economy	14000.00
0005432526629	7732	Economy	14000.00
0005432526675	7732	Economy	14000.00
0005435423621	5316	Business	43100.00
0005435423664	5316	Business	43100.00
0005435423722	5316	Business	43100.00
0005434573216	5316	Business	43100.00
0005435423710	5316	Business	43100.00
0005435612589	5316	Business	43100.00
0005435612561	5316	Business	43100.00
0005435423674	5316	Business	43100.00
0005435612577	5316	Business	43100.00
0005435612562	5316	Business	43100.00
0005435491418	5316	Business	43100.00
0005435423778	5316	Business	43100.00
0005432133055	5316	Business	43100.00
0005434573205	5316	Business	43100.00
0005435612510	5316	Business	43100.00
0005435423851	5316	Business	43100.00
0005435319428	5316	Business	43100.00
0005435612500	5316	Business	43100.00
0005434343863	5316	Business	43100.00
0005435097112	5316	Business	43100.00
0005434343848	5316	Comfort	24400.00
0005434573210	5316	Business	43100.00
0005435423892	5316	Comfort	24400.00
0005435097113	5316	Comfort	24400.00
0005435612518	5316	Comfort	24400.00
0005435612604	5316	Comfort	24400.00
0005435612542	5316	Comfort	24400.00
0005435423634	5316	Comfort	24400.00
0005432047512	5316	Comfort	24400.00
0005435490189	5316	Comfort	24400.00
0005434343870	5316	Comfort	24400.00
0005435491417	5316	Comfort	24400.00
0005432133050	5316	Comfort	24400.00
0005432133058	5316	Comfort	24400.00
0005435612514	5316	Comfort	24400.00
0005434343873	5316	Comfort	24400.00
0005435612541	5316	Comfort	24400.00
0005435423805	5316	Comfort	24400.00
0005435612507	5316	Comfort	24400.00
0005435612547	5316	Comfort	24400.00
0005434343844	5316	Comfort	24400.00
0005435612599	5316	Comfort	24400.00
0005435612578	5316	Comfort	24400.00
0005432133059	5316	Comfort	24400.00
0005434573214	5316	Comfort	24400.00
0005434343867	5316	Comfort	24400.00
0005434343840	5316	Comfort	24400.00
0005435612508	5316	Comfort	24400.00
0005435423612	5316	Comfort	24400.00
0005435423726	5316	Comfort	24400.00
0005435423891	5316	Comfort	24400.00
0005435097116	5316	Comfort	24400.00
0005434573203	5316	Comfort	24400.00
0005432840976	5316	Comfort	24400.00
0005435423703	5316	Economy	14400.00
0005435612536	5316	Economy	14400.00
0005435612605	5316	Economy	14400.00
0005432047513	5316	Economy	14400.00
0005435612593	5316	Economy	14400.00
0005435612565	5316	Economy	14400.00
0005435612509	5316	Economy	14400.00
0005435612520	5316	Economy	14400.00
0005435612521	5316	Economy	14400.00
0005434343862	5316	Economy	14400.00
0005435612511	5316	Economy	14400.00
0005435612594	5316	Economy	14400.00
0005435612582	5316	Economy	14400.00
0005435423751	5316	Economy	14400.00
0005435612558	5316	Economy	14400.00
0005434343842	5316	Economy	14400.00
0005435423610	5316	Economy	14400.00
0005434343859	5316	Economy	14400.00
0005434343864	5316	Economy	14400.00
0005434573207	5316	Economy	14400.00
0005434343852	5316	Economy	14400.00
0005435612584	5316	Economy	14400.00
0005435423721	5316	Economy	14400.00
0005435612595	5316	Economy	14400.00
0005435612546	5316	Economy	14400.00
0005434343869	5316	Economy	14400.00
0005435612486	5316	Economy	14400.00
0005434573209	5316	Economy	14400.00
0005435612533	5316	Economy	14400.00
0005432047510	5316	Economy	14400.00
0005435612545	5316	Economy	14400.00
0005435423658	5316	Economy	14400.00
0005432133052	5316	Economy	14400.00
0005435612549	5316	Economy	14400.00
0005435612531	5316	Economy	14400.00
0005435612498	5316	Economy	14400.00
0005435423614	5316	Economy	14400.00
0005435097111	5316	Economy	14400.00
0005435612540	5316	Economy	14400.00
0005435612525	5316	Economy	14400.00
0005434343841	5316	Economy	14400.00
0005435612526	5316	Economy	14400.00
0005435612555	5316	Economy	14400.00
0005435612501	5316	Economy	14400.00
0005435612574	5316	Economy	15800.00
0005435612524	5316	Economy	15800.00
0005435612492	5316	Economy	15800.00
0005435612537	5316	Economy	14400.00
0005434343856	5316	Economy	14400.00
0005435491419	5316	Economy	14400.00
0005435423657	5316	Economy	15800.00
0005435097115	5316	Economy	14400.00
0005434343855	5316	Economy	14400.00
0005434244481	5316	Economy	14400.00
0005435612493	5316	Economy	14400.00
0005435612569	5316	Economy	14400.00
0005435612497	5316	Economy	14400.00
0005435423624	5316	Economy	14400.00
0005435612538	5316	Economy	14400.00
0005432133053	5316	Economy	14400.00
0005434244488	5316	Economy	14400.00
0005432133054	5316	Economy	14400.00
0005435612544	5316	Economy	14400.00
0005432133051	5316	Economy	14400.00
0005435097114	5316	Economy	14400.00
0005434343850	5316	Economy	14400.00
0005435423779	5316	Economy	14400.00
0005434343865	5316	Economy	14400.00
0005435612606	5316	Economy	14400.00
0005435612515	5316	Economy	14400.00
0005435423750	5316	Economy	14400.00
0005435612487	5316	Economy	14400.00
0005435612505	5316	Economy	14400.00
0005435612581	5316	Economy	14400.00
0005434573213	5316	Economy	14400.00
0005435423782	5316	Economy	14400.00
0005435612600	5316	Economy	14400.00
0005432133056	5316	Economy	14400.00
0005434244453	5316	Economy	14400.00
0005435612576	5316	Economy	14400.00
0005434244556	5316	Economy	14400.00
0005435423689	5316	Economy	14400.00
0005435612575	5316	Economy	14400.00
0005435612553	5316	Economy	14400.00
0005435612592	5316	Economy	14400.00
0005435612490	5316	Economy	14400.00
0005435097117	5316	Economy	14400.00
0005432133063	5316	Economy	14400.00
0005432363362	5316	Economy	14400.00
0005435423711	5316	Economy	14400.00
0005435612495	5316	Economy	14400.00
0005432133057	5316	Economy	14400.00
0005435612484	5316	Economy	14400.00
0005435304993	5316	Economy	14400.00
0005435612494	5316	Economy	14400.00
0005435423850	5316	Economy	14400.00
0005435423586	5316	Economy	14400.00
0005435423849	5316	Economy	14400.00
0005435612608	5316	Economy	14400.00
0005435612550	5316	Economy	14400.00
0005435612543	5316	Economy	14400.00
0005435097110	5316	Economy	14400.00
0005435612610	5316	Economy	14400.00
0005435612580	5316	Economy	14400.00
0005435612602	5316	Economy	14400.00
0005434343854	5316	Economy	14400.00
0005435612598	5316	Economy	14400.00
0005435612532	5316	Economy	14400.00
0005435612597	5316	Economy	14400.00
0005434573211	5316	Economy	14400.00
0005435612496	5316	Economy	14400.00
0005434343857	5316	Economy	14400.00
0005434343866	5316	Economy	14400.00
0005435612579	5316	Economy	14400.00
0005435423611	5316	Economy	14400.00
0005435612591	5316	Economy	14400.00
0005434573204	5316	Economy	14400.00
0005434573215	5316	Economy	14400.00
0005434343860	5316	Economy	14400.00
0005435612585	5316	Economy	14400.00
0005435612522	5316	Economy	14400.00
0005435304994	5316	Economy	14400.00
0005434343851	5316	Economy	14400.00
0005435612554	5316	Economy	14400.00
0005435612588	5316	Economy	14400.00
0005435612485	5316	Economy	14400.00
0005435612527	5316	Economy	14400.00
0005435612503	5316	Economy	14400.00
0005432133061	5316	Economy	14400.00
0005435490188	5316	Economy	14400.00
0005435612528	5316	Economy	14400.00
0005435612568	5316	Economy	14400.00
0005435423632	5316	Economy	14400.00
0005435612601	5316	Economy	14400.00
0005435612502	5316	Economy	14400.00
0005432047514	5316	Economy	14400.00
0005435423682	5316	Economy	14400.00
0005435612530	5316	Economy	15800.00
0005435612571	5316	Economy	15800.00
0005435612567	5316	Economy	15800.00
0005434343843	5316	Economy	15800.00
0005435612563	5316	Economy	14400.00
0005435612586	5316	Economy	14400.00
0005434573206	5316	Economy	14400.00
0005435612499	5316	Economy	14400.00
0005435423688	5316	Economy	14400.00
0005435612548	5316	Economy	14400.00
0005435612603	5316	Economy	14400.00
0005435612513	5316	Economy	14400.00
0005435612551	5316	Economy	14400.00
0005434573208	5316	Economy	14400.00
0005435423665	5316	Economy	14400.00
0005434244454	5316	Economy	14400.00
0005435423718	5316	Economy	14400.00
0005435612517	5316	Economy	14400.00
0005435612516	5316	Economy	14400.00
0005434343849	5316	Economy	14400.00
0005435423605	5316	Economy	14400.00
0005435612583	5316	Economy	14400.00
0005435612559	5316	Economy	14400.00
0005435612573	5316	Economy	14400.00
0005435612539	5316	Economy	14400.00
0005434244489	5316	Economy	14400.00
0005435612611	5316	Economy	14400.00
0005435612552	5316	Economy	14400.00
0005435612504	5316	Economy	14400.00
0005435612488	5316	Economy	14400.00
0005435612491	5316	Economy	14400.00
0005434343871	5316	Economy	14400.00
0005435612489	5316	Economy	14400.00
0005432047511	5316	Economy	14400.00
0005435097118	5316	Economy	14400.00
0005435423677	5316	Economy	14400.00
0005435423633	5316	Economy	14400.00
0005435612557	5316	Economy	14400.00
0005434343847	5316	Economy	14400.00
0005432133064	5316	Economy	14400.00
0005435612572	5316	Economy	14400.00
0005434573212	5316	Economy	14400.00
0005435612590	5316	Economy	14400.00
0005432133062	5316	Economy	14400.00
0005434343846	5316	Economy	14400.00
0005435423604	5316	Economy	14400.00
0005434343872	5316	Economy	14400.00
0005435612596	5316	Economy	14400.00
0005435423712	5316	Economy	14400.00
0005435612512	5316	Economy	14400.00
0005435612587	5316	Economy	14400.00
0005434343845	5316	Economy	14400.00
0005432133060	5316	Economy	14400.00
0005435612523	5316	Economy	14400.00
0005434343858	5316	Economy	14400.00
0005435612564	5316	Economy	14400.00
0005435423736	5316	Economy	14400.00
0005435612534	5316	Economy	14400.00
0005435612609	5316	Economy	14400.00
0005435612566	5316	Economy	14400.00
0005432133049	5316	Economy	14400.00
0005435612529	5316	Economy	14400.00
0005435612570	5316	Economy	14400.00
0005435612607	5316	Economy	14400.00
0005435612535	5316	Economy	14400.00
0005435612506	5316	Economy	14400.00
0005435612556	5316	Economy	14400.00
0005435490190	5316	Economy	14400.00
0005435423918	5316	Economy	14400.00
0005435423673	5316	Economy	14400.00
0005434343868	5316	Economy	14400.00
0005434343839	5316	Economy	14400.00
0005435612519	5316	Economy	14400.00
0005435423619	5316	Economy	14400.00
0005435490191	5316	Economy	14400.00
0005434343838	5316	Economy	14400.00
0005435319429	5316	Economy	14400.00
0005435612560	5316	Economy	14400.00
0005434343861	5316	Economy	14400.00
0005434343853	5316	Economy	14400.00
0005435424073	10911	Business	43100.00
0005435611750	10911	Business	43100.00
0005435612100	10911	Business	43100.00
0005435424136	10911	Business	43100.00
0005434244673	10911	Business	43100.00
0005435319480	10911	Business	43100.00
0005435424072	10911	Business	43100.00
0005435424100	10911	Business	43100.00
0005435611852	10911	Business	43100.00
0005435424128	10911	Business	43100.00
0005435424120	10911	Business	43100.00
0005435304115	10911	Business	43100.00
0005435424111	10911	Business	43100.00
0005435424108	10911	Business	43100.00
0005432164961	10911	Business	43100.00
0005435304117	10911	Business	43100.00
0005435319479	10911	Business	43100.00
0005434244666	10911	Comfort	24400.00
0005432164959	10911	Comfort	24400.00
0005435424083	10911	Comfort	24400.00
0005432164963	10911	Comfort	24400.00
0005435424084	10911	Comfort	24400.00
0005435424107	10911	Comfort	24400.00
0005434656534	10911	Comfort	24400.00
0005435424077	10911	Comfort	24400.00
0005435611871	10911	Comfort	24400.00
0005434244682	10911	Comfort	24400.00
0005434244688	10911	Comfort	24400.00
0005435611745	10911	Comfort	24400.00
0005435424088	10911	Comfort	24400.00
0005435042833	10911	Comfort	24400.00
0005435424116	10911	Comfort	24400.00
0005435319478	10911	Comfort	24400.00
0005434343653	10911	Economy	14400.00
0005435424076	10911	Economy	14400.00
0005435612101	10911	Economy	14400.00
0005435611846	10911	Economy	14400.00
0005434656535	10911	Economy	14400.00
0005435612064	10911	Economy	14400.00
0005435424078	10911	Economy	14400.00
0005435424096	10911	Economy	14400.00
0005434244665	10911	Economy	14400.00
0005435424093	10911	Economy	14400.00
0005434244679	10911	Economy	14400.00
0005435424138	10911	Economy	14400.00
0005434244690	10911	Economy	14400.00
0005433719106	10911	Economy	14400.00
0005435424135	10911	Economy	14400.00
0005435424121	10911	Economy	14400.00
0005435424069	10911	Economy	14400.00
0005434244687	10911	Economy	14400.00
0005435611785	10911	Economy	14400.00
0005435424105	10911	Economy	14400.00
0005435424095	10911	Economy	14400.00
0005435611834	10911	Economy	14400.00
0005434244668	10911	Economy	14400.00
0005435611970	10911	Economy	14400.00
0005435424119	10911	Economy	14400.00
0005432166870	10911	Economy	15800.00
0005435319484	10911	Economy	14400.00
0005435424127	10911	Economy	15800.00
0005435424129	10911	Economy	14400.00
0005434656537	10911	Economy	15800.00
0005435042834	10911	Economy	15800.00
0005434244692	10911	Economy	14400.00
0005435424130	10911	Economy	14400.00
0005435611965	10911	Economy	14400.00
0005434244669	10911	Economy	14400.00
0005435611845	10911	Economy	14400.00
0005435612042	10911	Economy	14400.00
0005434244681	10911	Economy	14400.00
0005434656536	10911	Economy	14400.00
0005435424079	10911	Economy	14400.00
0005435424134	10911	Economy	14400.00
0005435424102	10911	Economy	14400.00
0005434244693	10911	Economy	14400.00
0005435319485	10911	Economy	14400.00
0005435611884	10911	Economy	14400.00
0005435424097	10911	Economy	14400.00
0005432363383	10911	Economy	14400.00
0005434244691	10911	Economy	14400.00
0005434244686	10911	Economy	14400.00
0005435319486	10911	Economy	14400.00
0005432164960	10911	Economy	14400.00
0005435424125	10911	Economy	14400.00
0005435424074	10911	Economy	14400.00
0005432164957	10911	Economy	14400.00
0005435424131	10911	Economy	14400.00
0005432840992	10911	Economy	14400.00
0005433719107	10911	Economy	14400.00
0005434244683	10911	Economy	14400.00
0005435304116	10911	Economy	14400.00
0005435424071	10911	Economy	14400.00
0005435424133	10911	Economy	14400.00
0005435424080	10911	Economy	14400.00
0005432166868	10911	Economy	14400.00
0005434244689	10911	Economy	14400.00
0005435611914	10911	Economy	14400.00
0005435424091	10911	Economy	14400.00
0005434244678	10911	Economy	14400.00
0005432164956	10911	Economy	14400.00
0005435424118	10911	Economy	14400.00
0005433719105	10911	Economy	14400.00
0005434244675	10911	Economy	14400.00
0005432166869	10911	Economy	14400.00
0005435424113	10911	Economy	14400.00
0005434244676	10911	Economy	14400.00
0005434244677	10911	Economy	14400.00
0005435424117	10911	Economy	14400.00
0005435424082	10911	Economy	14400.00
0005435424132	10911	Economy	14400.00
0005434244684	10911	Economy	14400.00
0005434244685	10911	Economy	14400.00
0005435424124	10911	Economy	14400.00
0005435611833	10911	Economy	14400.00
0005435424109	10911	Economy	14400.00
0005435611825	10911	Economy	15800.00
0005435424115	10911	Economy	14400.00
0005434244672	10911	Economy	14400.00
0005435424110	10911	Economy	14400.00
0005435424075	10911	Economy	14400.00
0005435611744	10911	Economy	14400.00
0005432166867	10911	Economy	14400.00
0005435611823	10911	Economy	14400.00
0005435611821	10911	Economy	14400.00
0005434244667	10911	Economy	14400.00
0005432164962	10911	Economy	14400.00
0005435424094	10911	Economy	14400.00
0005434343676	10911	Economy	14400.00
0005435424114	10911	Economy	14400.00
0005435424101	10911	Economy	14400.00
0005432164958	10911	Economy	14400.00
0005435424081	10911	Economy	14400.00
0005435424092	10911	Economy	14400.00
0005435424126	10911	Economy	14400.00
0005435424086	10911	Economy	14400.00
0005435424070	10911	Economy	14400.00
0005435424122	10911	Economy	14400.00
0005434244671	10911	Economy	14400.00
0005435611784	10911	Economy	14400.00
0005435424106	10911	Economy	14400.00
0005435424112	10911	Economy	14400.00
0005435424104	10911	Economy	14400.00
0005435611714	10911	Economy	14400.00
0005435611824	10911	Economy	14400.00
0005435424123	10911	Economy	14400.00
0005435319482	10911	Economy	14400.00
0005435319483	10911	Economy	14400.00
0005435424089	10911	Economy	14400.00
0005435424137	10911	Economy	14400.00
0005434244670	10911	Economy	14400.00
0005435491407	10911	Economy	14400.00
0005435319481	10911	Economy	14400.00
0005435611793	10911	Economy	14400.00
0005435424087	10911	Economy	14400.00
0005434244674	10911	Economy	14400.00
0005435611853	10911	Economy	14400.00
0005434244680	10911	Economy	14400.00
0005432840991	10911	Economy	14400.00
0005435424103	10911	Economy	14400.00
0005435424098	10911	Economy	14400.00
0005435424085	10911	Economy	14400.00
0005435424099	10911	Economy	14400.00
0005435611822	10911	Economy	14400.00
0005435611847	10911	Economy	14400.00
0005434343654	10911	Economy	14400.00
0005434343594	10911	Economy	14400.00
0005435424090	10911	Economy	14400.00
0005435611872	10911	Economy	14400.00
0005433805020	3341	Business	18800.00
0005433633472	3341	Business	18800.00
0005433633491	3341	Business	18800.00
0005432181479	3341	Business	18800.00
0005432459042	3341	Business	18800.00
0005433805029	3341	Business	18800.00
0005433633464	3341	Business	18800.00
0005433633473	3341	Business	18800.00
0005433805014	3341	Business	18800.00
0005433805015	3341	Business	18800.00
0005432181497	3341	Business	18800.00
0005433506983	3341	Business	18800.00
0005433633488	3341	Business	18800.00
0005432181481	3341	Business	18800.00
0005432181490	3341	Business	18800.00
0005433633482	3341	Business	18800.00
0005433633485	3341	Business	18800.00
0005433633469	3341	Business	18800.00
0005433805010	3341	Business	18800.00
0005433633458	3341	Business	18800.00
0005433506991	3341	Business	18800.00
0005433805034	3341	Business	18800.00
0005433805044	3341	Economy	6900.00
0005433633487	3341	Economy	6900.00
0005433805043	3341	Economy	6900.00
0005433805035	3341	Economy	6900.00
0005433633471	3341	Economy	6900.00
0005432181496	3341	Economy	6300.00
0005433805036	3341	Economy	6300.00
0005432181489	3341	Economy	6300.00
0005433633463	3341	Economy	6300.00
0005433805013	3341	Economy	6300.00
0005432181488	3341	Economy	6300.00
0005433805040	3341	Economy	6300.00
0005432181499	3341	Economy	6300.00
0005433805021	3341	Economy	6300.00
0005433805023	3341	Economy	6300.00
0005432459049	3341	Economy	6300.00
0005433805028	3341	Economy	6300.00
0005433507000	3341	Economy	6300.00
0005433633474	3341	Economy	6300.00
0005433633475	3341	Economy	6300.00
0005433633466	3341	Economy	6300.00
0005433506986	3341	Economy	6300.00
0005433633461	3341	Economy	6300.00
0005433805004	3341	Economy	6300.00
0005432181494	3341	Economy	6300.00
0005433633490	3341	Economy	6300.00
0005432181495	3341	Economy	6300.00
0005432181491	3341	Economy	6300.00
0005433805007	3341	Economy	6300.00
0005433805006	3341	Economy	6300.00
0005433633457	3341	Economy	6300.00
0005433633489	3341	Economy	6300.00
0005433506984	3341	Economy	6300.00
0005432458988	3341	Economy	6300.00
0005433805024	3341	Economy	6300.00
0005432459050	3341	Economy	6300.00
0005432458984	3341	Economy	6300.00
0005433506993	3341	Economy	6300.00
0005432181502	3341	Economy	6300.00
0005433805033	3341	Economy	6300.00
0005433633483	3341	Economy	6300.00
0005433805046	3341	Economy	6300.00
0005433633478	3341	Economy	6300.00
0005432458985	3341	Economy	6300.00
0005433805030	3341	Economy	6300.00
0005433633470	3341	Economy	6300.00
0005433633462	3341	Economy	6300.00
0005433506989	3341	Economy	6300.00
0005433506987	3341	Economy	6300.00
0005432458958	3341	Economy	6300.00
0005432458957	3341	Economy	6900.00
0005432181492	3341	Economy	6900.00
0005432181498	3341	Economy	6900.00
0005433633468	3341	Economy	6300.00
0005433805016	3341	Economy	6900.00
0005433805041	3341	Economy	6300.00
0005433506997	3341	Economy	6300.00
0005433633459	3341	Economy	6300.00
0005432181486	3341	Economy	6900.00
0005433805019	3341	Economy	6300.00
0005432181484	3341	Economy	6300.00
0005433805031	3341	Economy	6300.00
0005432181482	3341	Economy	6300.00
0005433805042	3341	Economy	6300.00
0005432181483	3341	Economy	6300.00
0005432181501	3341	Economy	6300.00
0005433506994	3341	Economy	6300.00
0005433805022	3341	Economy	6300.00
0005433506992	3341	Economy	6300.00
0005433805039	3341	Economy	6300.00
0005432181487	3341	Economy	6300.00
0005432181485	3341	Economy	6300.00
0005433805008	3341	Economy	6300.00
0005433633481	3341	Economy	6300.00
0005433805038	3341	Economy	6300.00
0005433805017	3341	Economy	6300.00
0005433506996	3341	Economy	6300.00
0005433506998	3341	Economy	6300.00
0005433805018	3341	Economy	6300.00
0005433506988	3341	Economy	6300.00
0005433633479	3341	Economy	6300.00
0005433507001	3341	Economy	6300.00
0005433805005	3341	Economy	6300.00
0005433805012	3341	Economy	6300.00
0005433506999	3341	Economy	6300.00
0005433805032	3341	Economy	6300.00
0005433805045	3341	Economy	6300.00
0005432458986	3341	Economy	6300.00
0005432459041	3341	Economy	6300.00
0005433506990	3341	Economy	6300.00
0005433506995	3341	Economy	6300.00
0005433633467	3341	Economy	6300.00
0005432181480	3341	Economy	6300.00
0005433805025	3341	Economy	6300.00
0005433805037	3341	Economy	6300.00
0005433805026	3341	Economy	6300.00
0005433805027	3341	Economy	6300.00
0005433633476	3341	Economy	6300.00
0005432181493	3341	Economy	6300.00
0005433633484	3341	Economy	6300.00
0005433805011	3341	Economy	6300.00
0005432458959	3341	Economy	6300.00
0005432181500	3341	Economy	6300.00
0005433506982	3341	Economy	6300.00
0005433633486	3341	Economy	6300.00
0005433633465	3341	Economy	6300.00
0005433506985	3341	Economy	6300.00
0005433805009	3341	Economy	6300.00
0005433633460	3341	Economy	6300.00
0005433633477	3341	Economy	6300.00
0005433633480	3341	Economy	6300.00
0005435884497	3342	Business	18800.00
0005435884516	3342	Business	18800.00
0005435884422	3342	Business	18800.00
0005435884390	3342	Business	18800.00
0005435884404	3342	Economy	6300.00
0005435884515	3342	Economy	6300.00
0005435884480	3342	Economy	6300.00
0005435884511	3342	Economy	6300.00
0005435884449	3342	Economy	6300.00
0005435884533	3342	Economy	6300.00
0005435884407	3342	Economy	6300.00
0005435884663	3342	Economy	6300.00
0005435884411	3342	Economy	6300.00
0005435884448	3342	Economy	6300.00
0005435884441	3342	Economy	6300.00
0005435884510	3342	Economy	6300.00
0005435884664	3342	Economy	6300.00
0005435884537	3342	Economy	6300.00
0005435884512	3342	Economy	6300.00
0005435884503	3342	Economy	6300.00
0005435884405	3342	Economy	6300.00
0005435884532	3342	Economy	6300.00
0005435884406	3342	Economy	6300.00
0005435884504	3342	Economy	6300.00
0005435884421	3342	Economy	6300.00
0005435884573	3342	Economy	6300.00
0005432042573	8210	Business	18800.00
0005432042574	8210	Business	18800.00
0005435884747	8210	Business	18800.00
0005432459339	8210	Business	18800.00
0005432459363	8210	Business	18800.00
0005432042568	8210	Business	18800.00
0005435884755	8210	Business	18800.00
0005435884749	8210	Business	18800.00
0005433506855	8210	Business	18800.00
0005432459364	8210	Business	18800.00
0005432042571	8210	Business	18800.00
0005433506856	8210	Business	18800.00
0005432459354	8210	Business	18800.00
0005435884738	8210	Business	18800.00
0005435884767	8210	Business	18800.00
0005432459347	8210	Business	18800.00
0005432459371	8210	Business	18800.00
0005432459357	8210	Business	18800.00
0005432459348	8210	Business	18800.00
0005432042567	8210	Business	18800.00
0005432459370	8210	Economy	6900.00
0005432042577	8210	Economy	6900.00
0005435884753	8210	Economy	6900.00
0005432459355	8210	Economy	6900.00
0005432459376	8210	Economy	6900.00
0005435884731	8210	Economy	6300.00
0005435884739	8210	Economy	6300.00
0005432042572	8210	Economy	6300.00
0005432459383	8210	Economy	6300.00
0005435884722	8210	Economy	6300.00
0005434312298	8210	Economy	6300.00
0005435884724	8210	Economy	6300.00
0005435884758	8210	Economy	6300.00
0005432459368	8210	Economy	6300.00
0005432459378	8210	Economy	6300.00
0005435884757	8210	Economy	6300.00
0005435884726	8210	Economy	6300.00
0005435884759	8210	Economy	6300.00
0005432459342	8210	Economy	6300.00
0005435884760	8210	Economy	6300.00
0005432459337	8210	Economy	6300.00
0005435884742	8210	Economy	6300.00
0005432042569	8210	Economy	6300.00
0005432459334	8210	Economy	6300.00
0005432459332	8210	Economy	6300.00
0005432459333	8210	Economy	6300.00
0005435884729	8210	Economy	6300.00
0005432459377	8210	Economy	6300.00
0005432459341	8210	Economy	6300.00
0005435884741	8210	Economy	6300.00
0005435884756	8210	Economy	6300.00
0005435884765	8210	Economy	6300.00
0005435884723	8210	Economy	6300.00
0005435884762	8210	Economy	6300.00
0005435884736	8210	Economy	6300.00
0005432459350	8210	Economy	6300.00
0005435884732	8210	Economy	6300.00
0005432459335	8210	Economy	6300.00
0005435884733	8210	Economy	6300.00
0005434312299	8210	Economy	6300.00
0005432459349	8210	Economy	6300.00
0005432459360	8210	Economy	6300.00
0005435884745	8210	Economy	6300.00
0005432459359	8210	Economy	6300.00
0005435884764	8210	Economy	6300.00
0005435884751	8210	Economy	6300.00
0005432459366	8210	Economy	6300.00
0005432459343	8210	Economy	6300.00
0005432459361	8210	Economy	6300.00
0005432459382	8210	Economy	6300.00
0005432459379	8210	Economy	6300.00
0005432042576	8210	Economy	6900.00
0005432459330	8210	Economy	6900.00
0005435884750	8210	Economy	6900.00
0005435884725	8210	Economy	6900.00
0005435884743	8210	Economy	6900.00
0005435884754	8210	Economy	6300.00
0005433506871	8210	Economy	6300.00
0005432042570	8210	Economy	6300.00
0005432459356	8210	Economy	6300.00
0005432459344	8210	Economy	6900.00
0005432459352	8210	Economy	6300.00
0005432042580	8210	Economy	6300.00
0005435884746	8210	Economy	6300.00
0005435884734	8210	Economy	6300.00
0005432459381	8210	Economy	6300.00
0005432459369	8210	Economy	6300.00
0005435884727	8210	Economy	6300.00
0005435884748	8210	Economy	6300.00
0005432459372	8210	Economy	6300.00
0005435884768	8210	Economy	6300.00
0005435884740	8210	Economy	6300.00
0005432459346	8210	Economy	6300.00
0005435884728	8210	Economy	6300.00
0005435884744	8210	Economy	6300.00
0005432459340	8210	Economy	6300.00
0005432459345	8210	Economy	6300.00
0005435884752	8210	Economy	6300.00
0005432459331	8210	Economy	6300.00
0005432459351	8210	Economy	6300.00
0005432042578	8210	Economy	6300.00
0005433506873	8210	Economy	6300.00
0005432042575	8210	Economy	6300.00
0005432459365	8210	Economy	6300.00
0005432459362	8210	Economy	6300.00
0005435884730	8210	Economy	6300.00
0005432459338	8210	Economy	6300.00
0005435884761	8210	Economy	6300.00
0005432042579	8210	Economy	6300.00
0005435884735	8210	Economy	6300.00
0005432459374	8210	Economy	6300.00
0005432459380	8210	Economy	6300.00
0005432459336	8210	Economy	6300.00
0005432459353	8210	Economy	6300.00
0005432459373	8210	Economy	6300.00
0005432459358	8210	Economy	6300.00
0005433506872	8210	Economy	6300.00
0005432459367	8210	Economy	6300.00
0005435884766	8210	Economy	6300.00
0005432459375	8210	Economy	6300.00
0005435884737	8210	Economy	6300.00
0005435884763	8210	Economy	6300.00
0005433804843	8223	Business	18800.00
0005433804784	8223	Business	18800.00
0005433633289	8223	Economy	6900.00
0005433804795	8223	Economy	6300.00
0005433804786	8223	Economy	6300.00
0005433633315	8223	Economy	6300.00
0005433633272	8223	Economy	6300.00
0005433804864	8223	Economy	6300.00
0005433804815	8223	Economy	6300.00
0005433804823	8223	Economy	6300.00
0005434271276	8223	Economy	6300.00
0005433804785	8223	Economy	6900.00
0005433804812	8223	Economy	6300.00
0005433804802	8223	Economy	6300.00
0005433804855	8223	Economy	6300.00
0005433633296	8223	Economy	6300.00
0005433633314	8223	Economy	6300.00
0005433804854	8223	Economy	6300.00
0005433633295	8223	Economy	6300.00
0005433804791	8223	Economy	6300.00
0005433804794	8223	Economy	6300.00
0005434183549	8247	Economy	6300.00
0005434183548	8247	Economy	6300.00
0005432727809	4510	Business	9900.00
0005432382778	4510	Business	9900.00
0005433722155	4510	Business	9900.00
0005432382799	4510	Business	9900.00
0005432382797	4510	Business	9900.00
0005432382792	4510	Business	9900.00
0005432382781	4510	Business	9900.00
0005433722156	4510	Economy	3300.00
0005432382773	4510	Economy	3300.00
0005432382791	4510	Economy	3300.00
0005432382793	4510	Economy	3300.00
0005432382801	4510	Economy	3600.00
0005432727815	4510	Economy	3600.00
0005432382782	4510	Economy	3600.00
0005432382798	4510	Economy	3300.00
0005432382803	4510	Economy	3300.00
0005432382769	4510	Economy	3300.00
0005432727807	4510	Economy	3300.00
0005432382771	4510	Economy	3300.00
0005432382780	4510	Economy	3300.00
0005433454853	4510	Economy	3300.00
0005432382784	4510	Economy	3300.00
0005432382767	4510	Economy	3300.00
0005432382774	4510	Economy	3300.00
0005432382779	4510	Economy	3300.00
0005432727817	4510	Economy	3300.00
0005432727814	4510	Economy	3300.00
0005432382787	4510	Economy	3300.00
0005432382790	4510	Economy	3300.00
0005432727816	4510	Economy	3300.00
0005433722157	4510	Economy	3300.00
0005432382768	4510	Economy	3300.00
0005433454852	4510	Economy	3300.00
0005432382794	4510	Economy	3300.00
0005432727806	4510	Economy	3300.00
0005432727810	4510	Economy	3300.00
0005432382796	4510	Economy	3300.00
0005432382795	4510	Economy	3300.00
0005432382788	4510	Economy	3300.00
0005432727805	4510	Economy	3300.00
0005432382783	4510	Economy	3300.00
0005432382789	4510	Economy	3300.00
0005432727811	4510	Economy	3300.00
0005432382786	4510	Economy	3300.00
0005432382800	4510	Economy	3300.00
0005432382772	4510	Economy	3300.00
0005432382776	4510	Economy	3300.00
0005432727812	4510	Economy	3300.00
0005432382777	4510	Economy	3300.00
0005432727808	4510	Economy	3300.00
0005432382770	4510	Economy	3300.00
0005432382785	4510	Economy	3300.00
0005432382802	4510	Economy	3300.00
0005432727813	4510	Economy	3300.00
0005432382775	4510	Economy	3300.00
0005432382491	30261	Business	9900.00
0005432382492	30261	Economy	3300.00
0005432727725	30261	Economy	3300.00
0005432727750	30261	Economy	3300.00
0005432727716	30261	Economy	3300.00
0005435540784	1709	Business	57200.00
0005435540794	1709	Business	57200.00
0005435529041	1709	Business	57200.00
0005435540779	1709	Business	57200.00
0005435540796	1709	Business	57200.00
0005435540793	1709	Business	57200.00
0005433516795	1709	Business	57200.00
0005435529040	1709	Economy	19100.00
0005435529049	1709	Economy	19100.00
0005432924957	1709	Economy	19100.00
0005435529034	1709	Economy	19100.00
0005433516793	1709	Economy	19100.00
0005432294464	1709	Economy	19100.00
0005435540783	1709	Economy	21000.00
0005435540778	1709	Economy	21000.00
0005435540780	1709	Economy	21000.00
0005435540792	1709	Economy	21000.00
0005435529042	1709	Economy	19100.00
0005433516789	1709	Economy	19100.00
0005435540788	1709	Economy	19100.00
0005435529053	1709	Economy	19100.00
0005435540797	1709	Economy	19100.00
0005435529035	1709	Economy	19100.00
0005432294463	1709	Economy	19100.00
0005435529051	1709	Economy	19100.00
0005435540791	1709	Economy	19100.00
0005435529043	1709	Economy	19100.00
0005435540785	1709	Economy	19100.00
0005433516788	1709	Economy	19100.00
0005435540781	1709	Economy	19100.00
0005435529045	1709	Economy	19100.00
0005435529047	1709	Economy	19100.00
0005435529052	1709	Economy	19100.00
0005435540782	1709	Economy	19100.00
0005435540786	1709	Economy	19100.00
0005433516796	1709	Economy	19100.00
0005435540789	1709	Economy	19100.00
0005433516790	1709	Economy	19100.00
0005435529046	1709	Economy	19100.00
0005435540795	1709	Economy	19100.00
0005435540799	1709	Economy	19100.00
0005435529044	1709	Economy	19100.00
0005433516787	1709	Economy	19100.00
0005433516794	1709	Economy	19100.00
0005435540787	1709	Economy	19100.00
0005435529048	1709	Economy	19100.00
0005435540798	1709	Economy	19100.00
0005435529038	1709	Economy	19100.00
0005435529036	1709	Economy	19100.00
0005432294462	1709	Economy	19100.00
0005435529054	1709	Economy	19100.00
0005433516791	1709	Economy	19100.00
0005435529037	1709	Economy	19100.00
0005433516792	1709	Economy	19100.00
0005435529039	1709	Economy	19100.00
0005435529050	1709	Economy	19100.00
0005435540790	1709	Economy	19100.00
0005432924989	21995	Business	57200.00
0005432924986	21995	Business	57200.00
0005435540626	21995	Economy	19100.00
0005435540647	21995	Economy	21000.00
0005432924987	21995	Economy	21000.00
0005435517616	21995	Economy	19100.00
0005435517618	21995	Economy	19100.00
0005432924988	21995	Economy	19100.00
0005435517587	21995	Economy	19100.00
0005435517627	21995	Economy	19100.00
0005432924990	21995	Economy	19100.00
0005435517586	21995	Economy	19100.00
0005435540630	21995	Economy	19100.00
0005433516726	21995	Economy	19100.00
0005432073355	7398	Business	18500.00
0005432838711	7398	Business	18500.00
0005432838731	7398	Business	18500.00
0005432838703	7398	Business	18500.00
0005435252417	7398	Business	18500.00
0005434458596	7398	Business	18500.00
0005434458583	7398	Business	18500.00
0005435252416	7398	Economy	6200.00
0005432838730	7398	Economy	6200.00
0005432838710	7398	Economy	6200.00
0005434458598	7398	Economy	6200.00
0005432838704	7398	Economy	6200.00
0005435252409	7398	Economy	6200.00
0005432838727	7398	Economy	6200.00
0005434458597	7398	Economy	6200.00
0005435252415	7398	Economy	6200.00
0005434458599	7398	Economy	6800.00
0005432840990	7398	Economy	6800.00
0005434458589	7398	Economy	6800.00
0005432838720	7398	Economy	6800.00
0005434458593	7398	Economy	6800.00
0005432838717	7398	Economy	6200.00
0005432838725	7398	Economy	6200.00
0005432838728	7398	Economy	6200.00
0005432838722	7398	Economy	6200.00
0005434458600	7398	Economy	6200.00
0005432823428	7398	Economy	6200.00
0005432073354	7398	Economy	6200.00
0005432838719	7398	Economy	6200.00
0005434458584	7398	Economy	6200.00
0005432838721	7398	Economy	6200.00
0005434458602	7398	Economy	6200.00
0005432838714	7398	Economy	6200.00
0005434458603	7398	Economy	6200.00
0005434458588	7398	Economy	6200.00
0005432838718	7398	Economy	6200.00
0005432838726	7398	Economy	6200.00
0005435252388	7398	Economy	6200.00
0005432838706	7398	Economy	6200.00
0005432840989	7398	Economy	6200.00
0005432838723	7398	Economy	6200.00
0005432838713	7398	Economy	6200.00
0005432838724	7398	Economy	6200.00
0005432838707	7398	Economy	6200.00
0005432838734	7398	Economy	6200.00
0005434458591	7398	Economy	6200.00
0005435252382	7398	Economy	6200.00
0005435252379	7398	Economy	6200.00
0005432838729	7398	Economy	6200.00
0005432838709	7398	Economy	6200.00
0005432838705	7398	Economy	6200.00
0005434458586	7398	Economy	6200.00
0005432838733	7398	Economy	6200.00
0005432838715	7398	Economy	6200.00
0005432838716	7398	Economy	6200.00
0005434458601	7398	Economy	6200.00
0005432838732	7398	Economy	6200.00
0005432838712	7398	Economy	6200.00
0005432838708	7398	Economy	6200.00
0005434458594	7398	Economy	6200.00
0005432073356	7398	Economy	6200.00
0005434458585	7398	Economy	6200.00
0005435252418	7398	Economy	6200.00
0005434458592	7398	Economy	6200.00
0005434458590	7398	Economy	6200.00
0005432823427	7398	Economy	6200.00
0005434458595	7398	Economy	6200.00
0005434458587	7398	Economy	6200.00
0005435252512	28948	Business	18500.00
0005432838508	28948	Business	18500.00
0005432001003	28948	Business	18500.00
0005435491422	28948	Business	18500.00
0005434458448	28948	Business	18500.00
0005435252514	28948	Business	18500.00
0005434664936	28948	Business	18500.00
0005435252515	28948	Economy	6200.00
0005435252526	28948	Economy	6200.00
0005435252517	28948	Economy	6200.00
0005432838499	28948	Economy	6200.00
0005434458449	28948	Economy	6200.00
0005435252519	28948	Economy	6200.00
0005432838560	28948	Economy	6800.00
0005432001004	28948	Economy	6800.00
0005434458476	28948	Economy	6200.00
0005432838529	28948	Economy	6200.00
0005434664937	28948	Economy	6200.00
0005432838637	28948	Economy	6200.00
0005432823418	28948	Economy	6200.00
0005432838554	28948	Economy	6200.00
0005435252525	28948	Economy	6200.00
0005432838535	28948	Economy	6200.00
0005434458463	28948	Economy	6200.00
0005432838500	28948	Economy	6200.00
0005435252527	28948	Economy	6200.00
0005432838544	28948	Economy	6200.00
0005435252509	28948	Economy	6200.00
0005435252510	28948	Economy	6200.00
0005434458518	28948	Economy	6200.00
0005435252511	28948	Economy	6200.00
0005432840977	28948	Economy	6200.00
0005435252528	28948	Economy	6200.00
0005432838559	28948	Economy	6200.00
0005432838543	28948	Economy	6200.00
0005434458517	28948	Economy	6200.00
0005432838530	28948	Economy	6200.00
0005432838495	28948	Economy	6200.00
0005432838494	28948	Economy	6200.00
0005435252513	28948	Economy	6200.00
0005435491420	28948	Economy	6200.00
0005435252522	28948	Economy	6200.00
0005432838493	28948	Economy	6200.00
0005435491421	28948	Economy	6200.00
0005434458462	28948	Economy	6200.00
0005435252523	28948	Economy	6200.00
0005434458475	28948	Economy	6200.00
0005435252524	28948	Economy	6200.00
0005432840978	28948	Economy	6200.00
0005435252520	28948	Economy	6200.00
0005435252516	28948	Economy	6200.00
0005432838587	28948	Economy	6200.00
0005435252518	28948	Economy	6200.00
0005435252521	28948	Economy	6200.00
0005434664938	28948	Economy	6200.00
0005432838488	28948	Economy	6200.00
0005435990549	8784	Business	145300.00
0005434275945	8784	Economy	48400.00
0005435990552	8784	Economy	48400.00
0005435990550	8784	Economy	48400.00
0005435990553	8784	Economy	48400.00
0005435990551	8784	Economy	48400.00
0005435990554	8784	Economy	48400.00
0005434275933	8784	Economy	48400.00
0005434275944	8784	Economy	48400.00
0005435990548	8784	Economy	48400.00
0005435990516	15741	Business	145300.00
0005434275970	15741	Economy	53300.00
0005434275966	15741	Economy	48400.00
0005434275969	15741	Economy	48400.00
0005434275967	15741	Economy	48400.00
0005434275968	15741	Economy	48400.00
0005434275965	15741	Economy	48400.00
0005435990503	15741	Economy	48400.00
0005433468245	2075	Economy	13300.00
0005433468238	2075	Economy	13300.00
0005433468237	2075	Economy	12100.00
0005433468248	2075	Economy	12100.00
0005433468247	2075	Economy	12100.00
0005433468251	2075	Economy	12100.00
0005433468249	2075	Economy	12100.00
0005433468246	2075	Economy	12100.00
0005433468235	2075	Economy	12100.00
0005433468236	2075	Economy	12100.00
0005433468243	2075	Economy	12100.00
0005433468244	2075	Economy	12100.00
0005433468250	2075	Economy	12100.00
0005433468234	2075	Economy	12100.00
0005433468241	2075	Economy	12100.00
0005433468252	2075	Economy	12100.00
0005433468253	2075	Economy	12100.00
0005433468240	2075	Economy	12100.00
0005433468242	2075	Economy	12100.00
0005433468239	2075	Economy	12100.00
0005432359852	6378	Business	36600.00
0005432359894	6378	Business	36600.00
0005432335914	6378	Business	36600.00
0005432359857	6378	Business	36600.00
0005432359856	6378	Business	36600.00
0005432359873	6378	Business	36600.00
0005432359853	6378	Business	36600.00
0005432359879	6378	Business	36600.00
0005435176631	6378	Business	36600.00
0005432359889	6378	Economy	12200.00
0005432359868	6378	Economy	12200.00
0005435176589	6378	Economy	12200.00
0005432359882	6378	Economy	12200.00
0005435176632	6378	Economy	12200.00
0005432359851	6378	Economy	12200.00
0005435176617	6378	Economy	12200.00
0005432335910	6378	Economy	12200.00
0005435176641	6378	Economy	12200.00
0005432359858	6378	Economy	12200.00
0005435176681	6378	Economy	12200.00
0005432359874	6378	Economy	12200.00
0005434149541	6378	Economy	12200.00
0005435176628	6378	Economy	12200.00
0005432335913	6378	Economy	12200.00
0005432359895	6378	Economy	12200.00
0005432359899	6378	Economy	12200.00
0005432359871	6378	Economy	12200.00
0005432359870	6378	Economy	12200.00
0005432335912	6378	Economy	12200.00
0005435176588	6378	Economy	12200.00
0005432359881	6378	Economy	12200.00
0005432335908	6378	Economy	13400.00
0005432359878	6378	Economy	13400.00
0005432335918	6378	Economy	13400.00
0005432359890	6378	Economy	13400.00
0005432359898	6378	Economy	13400.00
0005432359893	6378	Economy	12200.00
0005434149562	6378	Economy	12200.00
0005432359867	6378	Economy	12200.00
0005432359862	6378	Economy	12200.00
0005432359875	6378	Economy	12200.00
0005432062175	6378	Economy	12200.00
0005432359861	6378	Economy	12200.00
0005432359892	6378	Economy	12200.00
0005432359864	6378	Economy	12200.00
0005432359886	6378	Economy	12200.00
0005432062176	6378	Economy	12200.00
0005432359887	6378	Economy	12200.00
0005432335917	6378	Economy	12200.00
0005432359880	6378	Economy	12200.00
0005432359888	6378	Economy	12200.00
0005435176639	6378	Economy	12200.00
0005432359891	6378	Economy	12200.00
0005432335909	6378	Economy	12200.00
0005432359855	6378	Economy	12200.00
0005432062174	6378	Economy	12200.00
0005435176624	6378	Economy	12200.00
0005432359877	6378	Economy	12200.00
0005432359865	6378	Economy	12200.00
0005432359860	6378	Economy	12200.00
0005435176662	6378	Economy	12200.00
0005432359869	6378	Economy	12200.00
0005432335907	6378	Economy	12200.00
0005432062172	6378	Economy	12200.00
0005435176640	6378	Economy	12200.00
0005432335915	6378	Economy	12200.00
0005435176660	6378	Economy	12200.00
0005435176743	6378	Economy	12200.00
0005432359896	6378	Economy	12200.00
0005432062173	6378	Economy	12200.00
0005432359872	6378	Economy	12200.00
0005435176661	6378	Economy	12200.00
0005432335916	6378	Economy	12200.00
0005435176655	6378	Economy	12200.00
0005432359885	6378	Economy	12200.00
0005432359884	6378	Economy	12200.00
0005432359863	6378	Economy	12200.00
0005435176625	6378	Economy	12200.00
0005432359883	6378	Economy	12200.00
0005432359876	6378	Economy	12200.00
0005432359859	6378	Economy	12200.00
0005432359866	6378	Economy	12200.00
0005434149559	6378	Economy	12200.00
0005432335911	6378	Economy	12200.00
0005432359897	6378	Economy	12200.00
0005432363383	6378	Economy	12200.00
0005432359854	6378	Economy	12200.00
0005432335825	21039	Business	36600.00
0005432052716	21039	Business	36600.00
0005432359599	21039	Business	36600.00
0005432359696	21039	Business	36600.00
0005432359549	21039	Economy	12200.00
0005435176799	21039	Economy	12200.00
0005432335827	21039	Economy	12200.00
0005435176806	21039	Economy	12200.00
0005434149614	21039	Economy	12200.00
0005434149612	21039	Economy	12200.00
0005435176810	21039	Economy	12200.00
0005434149604	21039	Economy	12200.00
0005432359512	21039	Economy	12200.00
0005434149610	21039	Economy	12200.00
0005435176804	21039	Economy	12200.00
0005432359728	21039	Economy	12200.00
0005435176803	21039	Economy	12200.00
0005435176783	21039	Economy	12200.00
0005435176792	21039	Economy	12200.00
0005435176790	21039	Economy	12200.00
0005435176789	21039	Economy	12200.00
0005432359742	21039	Economy	12200.00
0005435176788	21039	Economy	12200.00
0005435490192	21039	Economy	12200.00
0005432359543	21039	Economy	12200.00
0005435176798	21039	Economy	13400.00
0005432363364	21039	Economy	13400.00
0005432335826	21039	Economy	13400.00
0005435176787	21039	Economy	12200.00
0005434149611	21039	Economy	12200.00
0005435176807	21039	Economy	12200.00
0005435176785	21039	Economy	12200.00
0005435176800	21039	Economy	12200.00
0005432359629	21039	Economy	12200.00
0005435176805	21039	Economy	12200.00
0005432359602	21039	Economy	12200.00
0005434149605	21039	Economy	12200.00
0005434149608	21039	Economy	12200.00
0005432359727	21039	Economy	12200.00
0005435176794	21039	Economy	12200.00
0005435176791	21039	Economy	12200.00
0005432359548	21039	Economy	12200.00
0005432359513	21039	Economy	12200.00
0005432052715	21039	Economy	12200.00
0005432052714	21039	Economy	12200.00
0005432335828	21039	Economy	12200.00
0005435176808	21039	Economy	12200.00
0005435176797	21039	Economy	12200.00
0005435490194	21039	Economy	12200.00
0005435490193	21039	Economy	12200.00
0005432359527	21039	Economy	12200.00
0005432359606	21039	Economy	12200.00
0005432359607	21039	Economy	12200.00
0005432052713	21039	Economy	12200.00
0005432363363	21039	Economy	12200.00
0005435176809	21039	Economy	12200.00
0005435723025	21039	Economy	12200.00
0005435176795	21039	Economy	12200.00
0005432335823	21039	Economy	12200.00
0005435176801	21039	Economy	12200.00
0005435176786	21039	Economy	12200.00
0005435176796	21039	Economy	12200.00
0005432359641	21039	Economy	12200.00
0005434149613	21039	Economy	12200.00
0005434149615	21039	Economy	12200.00
0005432359550	21039	Economy	12200.00
0005432335833	21039	Economy	12200.00
0005432359519	21039	Economy	12200.00
0005432359598	21039	Economy	12200.00
0005435723026	21039	Economy	12200.00
0005434149609	21039	Economy	12200.00
0005435176793	21039	Economy	12200.00
0005435176802	21039	Economy	12200.00
0005434149606	21039	Economy	12200.00
0005435176784	21039	Economy	12200.00
0005434149607	21039	Economy	12200.00
0005434458441	17721	Economy	3100.00
0005434458527	17721	Economy	3100.00
0005434458525	17721	Economy	3100.00
0005434458491	17721	Economy	3100.00
0005434458440	17721	Economy	3100.00
0005434458474	17721	Economy	3100.00
0005434186169	17721	Economy	3100.00
0005434186168	17721	Economy	3100.00
0005434458523	17721	Economy	3100.00
0005434186170	17721	Economy	3100.00
0005434458526	17721	Economy	3100.00
0005434458461	17721	Economy	3100.00
0005434458434	17721	Economy	3100.00
0005434186171	17721	Economy	3100.00
0005434458602	29087	Economy	3400.00
0005434458583	29087	Economy	3100.00
0005434458585	29087	Economy	3100.00
0005434462766	29087	Economy	3100.00
0005434458601	29087	Economy	3100.00
0005434458595	29087	Economy	3100.00
0005434458587	29087	Economy	3100.00
0005434458597	29087	Economy	3100.00
0005434458586	29087	Economy	3100.00
0005434458589	29087	Economy	3100.00
0005434448276	29087	Economy	3100.00
0005434458593	29087	Economy	3100.00
0005434458591	29087	Economy	3100.00
0005434458596	29087	Economy	3100.00
0005434462765	29087	Economy	3100.00
0005434458590	29087	Economy	3100.00
0005434448275	29087	Economy	3100.00
0005434458588	29087	Economy	3100.00
0005434458600	29087	Economy	3100.00
0005434448277	29087	Economy	3100.00
0005434458594	29087	Economy	3100.00
0005434463905	29087	Economy	3100.00
0005434458592	29087	Economy	3100.00
0005434463904	29087	Economy	3100.00
0005434458584	29087	Economy	3100.00
0005434458598	29087	Economy	3100.00
0005434458599	29087	Economy	3100.00
0005434458603	29087	Economy	3100.00
0005432603925	21459	Economy	7300.00
0005432603906	21459	Economy	7300.00
0005432603918	21459	Economy	7300.00
0005432603893	21459	Economy	7300.00
0005432603899	21459	Economy	6600.00
0005432603885	21459	Economy	6600.00
0005432603894	21459	Economy	6600.00
0005432603924	21459	Economy	6600.00
0005432603903	21459	Economy	6600.00
0005432603896	21459	Economy	6600.00
0005432603909	21459	Economy	6600.00
0005432603915	21459	Economy	6600.00
0005432603921	21459	Economy	6600.00
0005432603891	21459	Economy	6600.00
0005432603916	21459	Economy	6600.00
0005432603907	21459	Economy	6600.00
0005432603886	21459	Economy	6600.00
0005432603892	21459	Economy	6600.00
0005432603900	21459	Economy	6600.00
0005432603905	21459	Economy	6600.00
0005432603920	21459	Economy	6600.00
0005432603910	21459	Economy	6600.00
0005432603902	21459	Economy	6600.00
0005432603913	21459	Economy	6600.00
0005432603911	21459	Economy	6600.00
0005432603890	21459	Economy	6600.00
0005432603895	21459	Economy	6600.00
0005432603888	21459	Economy	6600.00
0005432603887	21459	Economy	6600.00
0005432603889	21459	Economy	6600.00
0005432603914	21459	Economy	6600.00
0005432603904	21459	Economy	6600.00
0005432603908	21459	Economy	6600.00
0005432603901	21459	Economy	6600.00
0005432603898	21459	Economy	6600.00
0005432603912	21459	Economy	6600.00
0005432603923	21459	Economy	6600.00
0005432603919	21459	Economy	6600.00
0005432603917	21459	Economy	6600.00
0005432603922	21459	Economy	6600.00
0005432603897	21459	Economy	6600.00
0005432603680	31688	Economy	7300.00
0005432603685	31688	Economy	6600.00
0005432603665	31688	Economy	6600.00
0005432603679	31688	Economy	6600.00
0005432603647	31688	Economy	6600.00
0005432603734	31688	Economy	6600.00
0005432603648	31688	Economy	6600.00
0005432603705	31688	Economy	6600.00
0005432603674	31688	Economy	6600.00
0005432603673	31688	Economy	6600.00
0005433293186	29612	Economy	19500.00
0005433293183	29612	Economy	17800.00
0005433293189	29612	Economy	17800.00
0005433293184	29612	Economy	17800.00
0005433293178	29612	Economy	17800.00
0005433293195	29612	Economy	17800.00
0005433293181	29612	Economy	17800.00
0005433293192	29612	Economy	17800.00
0005433293197	29612	Economy	17800.00
0005433293190	29612	Economy	17800.00
0005433293193	29612	Economy	17800.00
0005433293191	29612	Economy	17800.00
0005433293187	29612	Economy	17800.00
0005433293179	29612	Economy	17800.00
0005433293188	29612	Economy	17800.00
0005433293185	29612	Economy	17800.00
0005433293196	29612	Economy	17800.00
0005433293194	29612	Economy	17800.00
0005433293180	29612	Economy	17800.00
0005433293182	29612	Economy	17800.00
0005433473168	6675	Economy	14000.00
0005435257149	6675	Economy	14000.00
0005433473157	6675	Economy	14000.00
0005433473161	6675	Economy	12700.00
0005433473150	6675	Economy	12700.00
0005433473155	6675	Economy	12700.00
0005433473172	6675	Economy	12700.00
0005433473162	6675	Economy	12700.00
0005433473166	6675	Economy	12700.00
0005433473148	6675	Economy	12700.00
0005433473159	6675	Economy	12700.00
0005433473151	6675	Economy	12700.00
0005433473165	6675	Economy	12700.00
0005433473152	6675	Economy	12700.00
0005433473153	6675	Economy	12700.00
0005433473149	6675	Economy	12700.00
0005433473170	6675	Economy	12700.00
0005433473167	6675	Economy	12700.00
0005433473156	6675	Economy	12700.00
0005433473158	6675	Economy	12700.00
0005433473154	6675	Economy	12700.00
0005435257151	6675	Economy	12700.00
0005433473163	6675	Economy	12700.00
0005433473164	6675	Economy	12700.00
0005433473171	6675	Economy	12700.00
0005433473169	6675	Economy	12700.00
0005433473174	6675	Economy	12700.00
0005433473160	6675	Economy	12700.00
0005433473173	6675	Economy	12700.00
0005434606786	22284	Economy	6600.00
0005434606788	22284	Economy	6600.00
0005434606785	22284	Economy	6600.00
0005434604860	22284	Economy	6600.00
0005434604859	22284	Economy	6600.00
0005434604862	22284	Economy	6600.00
0005434604861	22284	Economy	6600.00
0005434606787	22284	Economy	6600.00
0005432747140	411	Business	44500.00
0005432747149	411	Business	44500.00
0005432747162	411	Business	44500.00
0005432890688	411	Business	44500.00
0005432747151	411	Business	44500.00
0005432753263	411	Business	44500.00
0005432747171	411	Business	44500.00
0005432747157	411	Business	44500.00
0005432747174	411	Business	44500.00
0005432747180	411	Business	44500.00
0005432890704	411	Business	44500.00
0005432890747	411	Economy	14800.00
0005432747175	411	Economy	14800.00
0005432747160	411	Economy	14800.00
0005432749760	411	Economy	14800.00
0005432747150	411	Economy	14800.00
0005432751491	411	Economy	14800.00
0005432753265	411	Economy	14800.00
0005432747179	411	Economy	14800.00
0005432747146	411	Economy	16300.00
0005432751490	411	Economy	16300.00
0005432747167	411	Economy	14800.00
0005432747147	411	Economy	14800.00
0005432747163	411	Economy	14800.00
0005432747158	411	Economy	14800.00
0005432747144	411	Economy	14800.00
0005432753262	411	Economy	14800.00
0005432747176	411	Economy	14800.00
0005432747166	411	Economy	14800.00
0005432749761	411	Economy	14800.00
0005432747143	411	Economy	14800.00
0005432219959	411	Economy	14800.00
0005432890675	411	Economy	14800.00
0005432747168	411	Economy	14800.00
0005432890669	411	Economy	14800.00
0005432747164	411	Economy	14800.00
0005432219956	411	Economy	14800.00
0005432747145	411	Economy	14800.00
0005432747155	411	Economy	14800.00
0005432747172	411	Economy	14800.00
0005432747177	411	Economy	14800.00
0005432890701	411	Economy	14800.00
0005432747152	411	Economy	14800.00
0005432747141	411	Economy	14800.00
0005432747173	411	Economy	14800.00
0005432747153	411	Economy	14800.00
0005432747159	411	Economy	14800.00
0005432890689	411	Economy	14800.00
0005432219960	411	Economy	14800.00
0005432747170	411	Economy	14800.00
0005432747156	411	Economy	14800.00
0005432751489	411	Economy	14800.00
0005432747165	411	Economy	14800.00
0005432747148	411	Economy	14800.00
0005432890674	411	Economy	14800.00
0005432747142	411	Economy	14800.00
0005432747154	411	Economy	14800.00
0005432219958	411	Economy	14800.00
0005432747161	411	Economy	14800.00
0005432753264	411	Economy	14800.00
0005432747178	411	Economy	14800.00
0005432219957	411	Economy	14800.00
0005432751488	411	Economy	14800.00
0005432747169	411	Economy	14800.00
0005432890812	12061	Business	44500.00
0005432749748	12061	Business	44500.00
0005432890820	12061	Business	44500.00
0005432890827	12061	Business	44500.00
0005432746866	12061	Business	44500.00
0005432890828	12061	Business	44500.00
0005432746974	12061	Business	44500.00
0005432890817	12061	Business	44500.00
0005432890824	12061	Business	44500.00
0005432890814	12061	Economy	14800.00
0005432746940	12061	Economy	14800.00
0005432746868	12061	Economy	14800.00
0005432746867	12061	Economy	16300.00
0005432746941	12061	Economy	16300.00
0005432214781	12061	Economy	14800.00
0005432749747	12061	Economy	14800.00
0005432746883	12061	Economy	14800.00
0005432747021	12061	Economy	14800.00
0005432746919	12061	Economy	14800.00
0005432746884	12061	Economy	14800.00
0005432890819	12061	Economy	14800.00
0005432747044	12061	Economy	14800.00
0005432746928	12061	Economy	14800.00
0005432890818	12061	Economy	14800.00
0005432747002	12061	Economy	14800.00
0005432890823	12061	Economy	14800.00
0005432890822	12061	Economy	14800.00
0005432746969	12061	Economy	14800.00
0005432756796	12061	Economy	14800.00
0005432747019	12061	Economy	14800.00
0005432747020	12061	Economy	14800.00
0005432214780	12061	Economy	14800.00
0005432890825	12061	Economy	14800.00
0005432747008	12061	Economy	14800.00
0005432890816	12061	Economy	14800.00
0005432890813	12061	Economy	14800.00
0005432746910	12061	Economy	14800.00
0005432890809	12061	Economy	14800.00
0005432747043	12061	Economy	14800.00
0005432746880	12061	Economy	14800.00
0005432890826	12061	Economy	14800.00
0005433875364	12061	Economy	14800.00
0005432746968	12061	Economy	14800.00
0005432746881	12061	Economy	14800.00
0005432890810	12061	Economy	14800.00
0005432890821	12061	Economy	14800.00
0005432890811	12061	Economy	14800.00
0005432890815	12061	Economy	14800.00
0005433533263	18987	Economy	28200.00
0005433524917	18987	Economy	28200.00
0005433524918	18987	Economy	25700.00
0005433531249	18987	Economy	25700.00
0005433533267	18987	Economy	25700.00
0005433524921	18987	Economy	25700.00
0005433524916	18987	Economy	25700.00
0005433533264	18987	Economy	25700.00
0005433524922	18987	Economy	25700.00
0005433524915	18987	Economy	25700.00
0005433531251	18987	Economy	25700.00
0005433524914	18987	Economy	25700.00
0005433524920	18987	Economy	25700.00
0005433533265	18987	Economy	25700.00
0005433524913	18987	Economy	25700.00
0005433524912	18987	Economy	25700.00
0005433524919	18987	Economy	25700.00
0005433533266	18987	Economy	25700.00
0005433531250	18987	Economy	25700.00
0005432927930	32494	Economy	25700.00
0005432927927	32494	Economy	25700.00
0005433524846	32494	Economy	25700.00
0005432927928	32494	Economy	25700.00
0005432927929	32494	Economy	25700.00
0005432927926	32494	Economy	25700.00
0005432927925	32494	Economy	25700.00
0005435372358	5247	Business	84000.00
0005434822238	5247	Business	84000.00
0005435304093	5247	Business	84000.00
0005434822252	5247	Business	84000.00
0005434558196	5247	Business	84000.00
0005434822329	5247	Business	84000.00
0005432121188	5247	Business	84000.00
0005434822232	5247	Business	84000.00
0005434822313	5247	Business	84000.00
0005434558197	5247	Business	84000.00
0005434831095	5247	Business	84000.00
0005434822349	5247	Business	84000.00
0005434822323	5247	Business	84000.00
0005434822282	5247	Business	84000.00
0005434822319	5247	Comfort	47600.00
0005434822262	5247	Comfort	47600.00
0005434822263	5247	Comfort	47600.00
0005434822346	5247	Comfort	47600.00
0005434822317	5247	Comfort	47600.00
0005434822338	5247	Comfort	47600.00
0005434822327	5247	Comfort	47600.00
0005434822243	5247	Comfort	47600.00
0005434822314	5247	Comfort	47600.00
0005434822342	5247	Comfort	47600.00
0005435149896	5247	Comfort	47600.00
0005432396201	5247	Comfort	47600.00
0005434822274	5247	Comfort	47600.00
0005434822246	5247	Comfort	47600.00
0005434822270	5247	Comfort	47600.00
0005432396202	5247	Comfort	47600.00
0005434664934	5247	Comfort	47600.00
0005435149888	5247	Comfort	47600.00
0005434822284	5247	Comfort	47600.00
0005434822234	5247	Comfort	47600.00
0005434822269	5247	Comfort	47600.00
0005434822326	5247	Comfort	47600.00
0005434822322	5247	Comfort	47600.00
0005434822289	5247	Comfort	47600.00
0005434822265	5247	Comfort	47600.00
0005434822290	5247	Comfort	47600.00
0005434822271	5247	Comfort	47600.00
0005435372207	5247	Comfort	47600.00
0005434822251	5247	Comfort	47600.00
0005435372118	5247	Comfort	47600.00
0005434822315	5247	Comfort	47600.00
0005435372208	5247	Economy	28000.00
0005435372119	5247	Economy	28000.00
0005432121183	5247	Economy	28000.00
0005434822291	5247	Economy	28000.00
0005434822320	5247	Economy	28000.00
0005434822277	5247	Economy	28000.00
0005434822301	5247	Economy	28000.00
0005435372117	5247	Economy	28000.00
0005434822302	5247	Economy	28000.00
0005434822335	5247	Economy	28000.00
0005434822278	5247	Economy	28000.00
0005434822261	5247	Economy	28000.00
0005434822311	5247	Economy	28000.00
0005434822255	5247	Economy	28000.00
0005434822233	5247	Economy	28000.00
0005434822344	5247	Economy	28000.00
0005434822304	5247	Economy	28000.00
0005434822236	5247	Economy	28000.00
0005432121185	5247	Economy	28000.00
0005435149892	5247	Economy	28000.00
0005434822305	5247	Economy	28000.00
0005434822307	5247	Economy	28000.00
0005435149887	5247	Economy	28000.00
0005434822249	5247	Economy	28000.00
0005434664935	5247	Economy	28000.00
0005435149893	5247	Economy	28000.00
0005432394061	5247	Economy	28000.00
0005435299697	5247	Economy	28000.00
0005434822285	5247	Economy	28000.00
0005434822332	5247	Economy	28000.00
0005435372364	5247	Economy	28000.00
0005434822337	5247	Economy	28000.00
0005434822321	5247	Economy	28000.00
0005434828667	5247	Economy	28000.00
0005435149891	5247	Economy	28000.00
0005435372103	5247	Economy	28000.00
0005434822331	5247	Economy	28000.00
0005434822224	5247	Economy	28000.00
0005434822241	5247	Economy	28000.00
0005435149885	5247	Economy	28000.00
0005434822299	5247	Economy	28000.00
0005435372102	5247	Economy	28000.00
0005434822328	5247	Economy	30800.00
0005434822288	5247	Economy	28000.00
0005434822266	5247	Economy	30800.00
0005432121189	5247	Economy	28000.00
0005434822245	5247	Economy	30800.00
0005434822294	5247	Economy	28000.00
0005434822268	5247	Economy	28000.00
0005434822287	5247	Economy	28000.00
0005432396203	5247	Economy	28000.00
0005434822279	5247	Economy	28000.00
0005434822324	5247	Economy	28000.00
0005434822339	5247	Economy	28000.00
0005434822280	5247	Economy	28000.00
0005434822248	5247	Economy	28000.00
0005434822230	5247	Economy	28000.00
0005434822334	5247	Economy	28000.00
0005434822267	5247	Economy	28000.00
0005434822264	5247	Economy	28000.00
0005434822250	5247	Economy	28000.00
0005434822303	5247	Economy	28000.00
0005434822240	5247	Economy	28000.00
0005434822333	5247	Economy	28000.00
0005432121193	5247	Economy	28000.00
0005435372210	5247	Economy	28000.00
0005435149890	5247	Economy	28000.00
0005434822225	5247	Economy	28000.00
0005434822312	5247	Economy	28000.00
0005434822297	5247	Economy	28000.00
0005435149886	5247	Economy	28000.00
0005434822350	5247	Economy	28000.00
0005434822242	5247	Economy	28000.00
0005434822221	5247	Economy	28000.00
0005434822229	5247	Economy	28000.00
0005434822223	5247	Economy	28000.00
0005434822228	5247	Economy	28000.00
0005434822257	5247	Economy	28000.00
0005434664933	5247	Economy	28000.00
0005434822235	5247	Economy	28000.00
0005434822318	5247	Economy	28000.00
0005434822239	5247	Economy	28000.00
0005434822286	5247	Economy	28000.00
0005432394064	5247	Economy	28000.00
0005434558193	5247	Economy	28000.00
0005435372121	5247	Economy	28000.00
0005434558194	5247	Economy	28000.00
0005434822345	5247	Economy	28000.00
0005434822340	5247	Economy	28000.00
0005434822259	5247	Economy	28000.00
0005434831099	5247	Economy	28000.00
0005432394063	5247	Economy	28000.00
0005434822298	5247	Economy	28000.00
0005434822227	5247	Economy	28000.00
0005434822300	5247	Economy	28000.00
0005434822296	5247	Economy	28000.00
0005434822283	5247	Economy	28000.00
0005434831097	5247	Economy	30800.00
0005435372148	5247	Economy	28000.00
0005435304094	5247	Economy	30800.00
0005435372197	5247	Economy	30800.00
0005432121195	5247	Economy	28000.00
0005432121196	5247	Economy	28000.00
0005435372115	5247	Economy	28000.00
0005434822247	5247	Economy	28000.00
0005434822281	5247	Economy	28000.00
0005434822306	5247	Economy	28000.00
0005434822244	5247	Economy	28000.00
0005435372158	5247	Economy	28000.00
0005434822222	5247	Economy	28000.00
0005434822309	5247	Economy	28000.00
0005432121187	5247	Economy	28000.00
0005434822253	5247	Economy	28000.00
0005434822276	5247	Economy	28000.00
0005434828665	5247	Economy	28000.00
0005434822316	5247	Economy	28000.00
0005434822310	5247	Economy	28000.00
0005434822348	5247	Economy	28000.00
0005432121186	5247	Economy	28000.00
0005434822295	5247	Economy	28000.00
0005434822258	5247	Economy	28000.00
0005434822347	5247	Economy	28000.00
0005435372120	5247	Economy	28000.00
0005434822237	5247	Economy	28000.00
0005432121194	5247	Economy	28000.00
0005434822220	5247	Economy	28000.00
0005434831098	5247	Economy	28000.00
0005435149898	5247	Economy	28000.00
0005434822325	5247	Economy	28000.00
0005435149895	5247	Economy	28000.00
0005435149889	5247	Economy	28000.00
0005432121191	5247	Economy	28000.00
0005435372149	5247	Economy	28000.00
0005434822336	5247	Economy	28000.00
0005432394062	5247	Economy	28000.00
0005432121192	5247	Economy	28000.00
0005434822341	5247	Economy	28000.00
0005434828666	5247	Economy	28000.00
0005434558195	5247	Economy	28000.00
0005434822273	5247	Economy	28000.00
0005435735059	5247	Economy	28000.00
0005434822275	5247	Economy	28000.00
0005434831096	5247	Economy	28000.00
0005434822292	5247	Economy	28000.00
0005435372116	5247	Economy	28000.00
0005435149897	5247	Economy	28000.00
0005434822343	5247	Economy	28000.00
0005434822308	5247	Economy	28000.00
0005434822226	5247	Economy	28000.00
0005434822272	5247	Economy	28000.00
0005434822256	5247	Economy	28000.00
0005435372112	5247	Economy	28000.00
0005432121190	5247	Economy	28000.00
0005434822231	5247	Economy	28000.00
0005434822254	5247	Economy	28000.00
0005432121184	5247	Economy	28000.00
0005435372104	5247	Economy	28000.00
0005434822293	5247	Economy	28000.00
0005435149894	5247	Economy	28000.00
0005434822260	5247	Economy	28000.00
0005434822330	5247	Economy	28000.00
0005435661901	9906	Business	84000.00
0005435372590	9906	Business	84000.00
0005434821642	9906	Business	84000.00
0005435386507	9906	Business	84000.00
0005435386505	9906	Business	84000.00
0005434821502	9906	Business	84000.00
0005435372619	9906	Business	84000.00
0005434821606	9906	Business	84000.00
0005434821605	9906	Business	84000.00
0005435661900	9906	Comfort	47600.00
0005435735093	9906	Comfort	47600.00
0005435299725	9906	Comfort	47600.00
0005434821475	9906	Comfort	47600.00
0005432202986	9906	Comfort	47600.00
0005434821380	9906	Comfort	47600.00
0005435372596	9906	Comfort	47600.00
0005435372612	9906	Comfort	47600.00
0005434821419	9906	Comfort	47600.00
0005435299727	9906	Comfort	47600.00
0005434821791	9906	Economy	28000.00
0005435302150	9906	Economy	28000.00
0005434821647	9906	Economy	28000.00
0005435372593	9906	Economy	28000.00
0005434821373	9906	Economy	28000.00
0005435372599	9906	Economy	28000.00
0005434821491	9906	Economy	28000.00
0005434821396	9906	Economy	28000.00
0005435372567	9906	Economy	28000.00
0005432202988	9906	Economy	28000.00
0005434831069	9906	Economy	28000.00
0005435302151	9906	Economy	28000.00
0005432400057	9906	Economy	28000.00
0005435372616	9906	Economy	28000.00
0005432202987	9906	Economy	28000.00
0005432400058	9906	Economy	28000.00
0005435372620	9906	Economy	28000.00
0005435372586	9906	Economy	28000.00
0005435372618	9906	Economy	28000.00
0005435372580	9906	Economy	28000.00
0005435372601	9906	Economy	28000.00
0005435372583	9906	Economy	28000.00
0005435372569	9906	Economy	28000.00
0005434821343	9906	Economy	28000.00
0005434821496	9906	Economy	28000.00
0005435372581	9906	Economy	28000.00
0005434821390	9906	Economy	28000.00
0005434821554	9906	Economy	28000.00
0005435372617	9906	Economy	28000.00
0005432202990	9906	Economy	28000.00
0005435386510	9906	Economy	28000.00
0005434821417	9906	Economy	28000.00
0005435372571	9906	Economy	30800.00
0005435372574	9906	Economy	28000.00
0005435372598	9906	Economy	28000.00
0005435372564	9906	Economy	30800.00
0005434821725	9906	Economy	28000.00
0005435372594	9906	Economy	30800.00
0005434821418	9906	Economy	28000.00
0005435372614	9906	Economy	28000.00
0005434821627	9906	Economy	28000.00
0005435372592	9906	Economy	28000.00
0005435372582	9906	Economy	28000.00
0005435372624	9906	Economy	28000.00
0005435372561	9906	Economy	28000.00
0005435372610	9906	Economy	28000.00
0005434821607	9906	Economy	28000.00
0005435372597	9906	Economy	28000.00
0005435735090	9906	Economy	28000.00
0005434821433	9906	Economy	28000.00
0005432400063	9906	Economy	28000.00
0005434821391	9906	Economy	28000.00
0005434821590	9906	Economy	28000.00
0005432202992	9906	Economy	28000.00
0005435372562	9906	Economy	28000.00
0005435372607	9906	Economy	28000.00
0005435372613	9906	Economy	28000.00
0005435372605	9906	Economy	28000.00
0005434821526	9906	Economy	28000.00
0005434821477	9906	Economy	28000.00
0005435372585	9906	Economy	28000.00
0005434821420	9906	Economy	28000.00
0005432823430	9906	Economy	28000.00
0005435386506	9906	Economy	28000.00
0005435372563	9906	Economy	28000.00
0005435372615	9906	Economy	28000.00
0005434821724	9906	Economy	28000.00
0005435372575	9906	Economy	28000.00
0005435372566	9906	Economy	28000.00
0005435735095	9906	Economy	28000.00
0005435372611	9906	Economy	28000.00
0005432823429	9906	Economy	28000.00
0005434821501	9906	Economy	28000.00
0005435372626	9906	Economy	28000.00
0005435386508	9906	Economy	28000.00
0005435372608	9906	Economy	28000.00
0005435372565	9906	Economy	28000.00
0005435386504	9906	Economy	28000.00
0005435299728	9906	Economy	28000.00
0005435372579	9906	Economy	28000.00
0005435372603	9906	Economy	28000.00
0005435372625	9906	Economy	28000.00
0005435302149	9906	Economy	28000.00
0005435735094	9906	Economy	28000.00
0005435372609	9906	Economy	28000.00
0005432202989	9906	Economy	28000.00
0005435372584	9906	Economy	28000.00
0005434821319	9906	Economy	30800.00
0005432400059	9906	Economy	28000.00
0005435372588	9906	Economy	28000.00
0005435372589	9906	Economy	28000.00
0005435386509	9906	Economy	28000.00
0005435372602	9906	Economy	28000.00
0005435372572	9906	Economy	28000.00
0005435372570	9906	Economy	28000.00
0005435372622	9906	Economy	28000.00
0005435372600	9906	Economy	28000.00
0005434821434	9906	Economy	28000.00
0005435302152	9906	Economy	28000.00
0005435372587	9906	Economy	28000.00
0005435372577	9906	Economy	28000.00
0005434821356	9906	Economy	28000.00
0005432202991	9906	Economy	28000.00
0005435372623	9906	Economy	28000.00
0005435372621	9906	Economy	28000.00
0005434821560	9906	Economy	28000.00
0005434821348	9906	Economy	28000.00
0005435372595	9906	Economy	28000.00
0005434821792	9906	Economy	28000.00
0005432400061	9906	Economy	28000.00
0005435372606	9906	Economy	28000.00
0005435372604	9906	Economy	28000.00
0005432400056	9906	Economy	28000.00
0005435661902	9906	Economy	28000.00
0005435372560	9906	Economy	28000.00
0005434821322	9906	Economy	28000.00
0005435735092	9906	Economy	28000.00
0005435735091	9906	Economy	28000.00
0005434821559	9906	Economy	28000.00
0005435372591	9906	Economy	28000.00
0005434821349	9906	Economy	28000.00
0005435299726	9906	Economy	28000.00
0005434821556	9906	Economy	28000.00
0005434664919	9906	Economy	28000.00
0005434821375	9906	Economy	28000.00
0005435372573	9906	Economy	28000.00
0005435372578	9906	Economy	28000.00
0005435372568	9906	Economy	28000.00
0005435372576	9906	Economy	28000.00
0005434821374	9906	Economy	28000.00
0005434821379	9906	Economy	28000.00
0005435790277	6986	Economy	8200.00
0005435790276	6986	Economy	7400.00
0005435082705	6986	Economy	7400.00
0005435082707	6986	Economy	7400.00
0005435082706	6986	Economy	7400.00
0005435082709	6986	Economy	7400.00
0005435082710	6986	Economy	7400.00
0005435082704	6986	Economy	7400.00
0005435082708	6986	Economy	7400.00
0005435790264	26025	Economy	8200.00
0005435790260	26025	Economy	7400.00
0005435790261	26025	Economy	7400.00
0005434756008	9522	Business	32800.00
0005434213810	9522	Business	32800.00
0005434756029	9522	Business	32800.00
0005434756027	9522	Business	32800.00
0005434756019	9522	Business	32800.00
0005434756012	9522	Business	32800.00
0005434756045	9522	Economy	10900.00
0005434756009	9522	Economy	10900.00
0005434756047	9522	Economy	10900.00
0005434756041	9522	Economy	12000.00
0005434756033	9522	Economy	10900.00
0005434756039	9522	Economy	10900.00
0005434213811	9522	Economy	10900.00
0005434756046	9522	Economy	10900.00
0005434756035	9522	Economy	10900.00
0005434756044	9522	Economy	10900.00
0005434756026	9522	Economy	10900.00
0005434756034	9522	Economy	10900.00
0005434213770	9522	Economy	10900.00
0005434756011	9522	Economy	10900.00
0005434756016	9522	Economy	10900.00
0005434756038	9522	Economy	10900.00
0005434756042	9522	Economy	10900.00
0005434756015	9522	Economy	10900.00
0005434756024	9522	Economy	10900.00
0005434756017	9522	Economy	10900.00
0005434756037	9522	Economy	10900.00
0005434756031	9522	Economy	10900.00
0005434756020	9522	Economy	10900.00
0005434756028	9522	Economy	10900.00
0005434756040	9522	Economy	10900.00
0005434756021	9522	Economy	10900.00
0005434213734	9522	Economy	10900.00
0005434756043	9522	Economy	10900.00
0005434756014	9522	Economy	10900.00
0005434756032	9522	Economy	10900.00
0005434756025	9522	Economy	10900.00
0005434756030	9522	Economy	10900.00
0005434756036	9522	Economy	10900.00
0005434756010	9522	Economy	10900.00
0005434756048	9522	Economy	10900.00
0005434756018	9522	Economy	10900.00
0005434756013	9522	Economy	10900.00
0005434756022	9522	Economy	10900.00
0005434756023	9522	Economy	10900.00
0005434214023	28594	Business	32800.00
0005434214019	28594	Business	32800.00
0005434213984	28594	Business	32800.00
0005434213992	28594	Business	32800.00
0005434214005	28594	Business	32800.00
0005434213993	28594	Business	32800.00
0005434214016	28594	Economy	10900.00
0005434213997	28594	Economy	10900.00
0005434214013	28594	Economy	10900.00
0005434214025	28594	Economy	10900.00
0005434214027	28594	Economy	12000.00
0005434214022	28594	Economy	10900.00
0005434214012	28594	Economy	10900.00
0005434214002	28594	Economy	10900.00
0005434214009	28594	Economy	10900.00
0005434214017	28594	Economy	10900.00
0005434213998	28594	Economy	10900.00
0005434214001	28594	Economy	10900.00
0005434213986	28594	Economy	10900.00
0005434214024	28594	Economy	10900.00
0005434214010	28594	Economy	10900.00
0005434213996	28594	Economy	10900.00
0005434755728	28594	Economy	10900.00
0005434214008	28594	Economy	10900.00
0005434214015	28594	Economy	10900.00
0005434214030	28594	Economy	10900.00
0005434214006	28594	Economy	10900.00
0005434214028	28594	Economy	10900.00
0005434213995	28594	Economy	10900.00
0005434213994	28594	Economy	10900.00
0005434214018	28594	Economy	10900.00
0005434213988	28594	Economy	10900.00
0005434214014	28594	Economy	10900.00
0005434213987	28594	Economy	10900.00
0005434214011	28594	Economy	10900.00
0005434214000	28594	Economy	10900.00
0005434213985	28594	Economy	10900.00
0005434213999	28594	Economy	10900.00
0005434214020	28594	Economy	10900.00
0005434214029	28594	Economy	10900.00
0005434214004	28594	Economy	10900.00
0005434213989	28594	Economy	10900.00
0005434214007	28594	Economy	10900.00
0005434214021	28594	Economy	10900.00
0005434213990	28594	Economy	10900.00
0005434214003	28594	Economy	10900.00
0005434214026	28594	Economy	10900.00
0005434213991	28594	Economy	10900.00
0005435100094	10836	Economy	9800.00
0005435100091	10836	Economy	9800.00
0005434760159	10836	Economy	8900.00
0005435100093	10836	Economy	8900.00
0005435100092	10836	Economy	8900.00
0005435100090	10836	Economy	8900.00
0005434760171	31818	Economy	8900.00
0005434760172	31818	Economy	8900.00
0005434639068	1996	Economy	20900.00
0005432290603	1996	Economy	20900.00
0005434639052	1996	Economy	19000.00
0005434639045	1996	Economy	19000.00
0005434639047	1996	Economy	19000.00
0005434639063	1996	Economy	19000.00
0005434639057	1996	Economy	19000.00
0005434639059	1996	Economy	19000.00
0005433202114	1996	Economy	19000.00
0005434639051	1996	Economy	19000.00
0005434639055	1996	Economy	19000.00
0005433202109	1996	Economy	19000.00
0005434639061	1996	Economy	19000.00
0005433202119	1996	Economy	19000.00
0005434639050	1996	Economy	19000.00
0005434639062	1996	Economy	19000.00
0005434639053	1996	Economy	19000.00
0005433202116	1996	Economy	19000.00
0005432290601	1996	Economy	19000.00
0005434639044	1996	Economy	19000.00
0005434639046	1996	Economy	19000.00
0005434639065	1996	Economy	19000.00
0005434639056	1996	Economy	19000.00
0005435948316	1996	Economy	19000.00
0005434639067	1996	Economy	19000.00
0005434639048	1996	Economy	19000.00
0005434639049	1996	Economy	19000.00
0005432290602	1996	Economy	19000.00
0005432290604	1996	Economy	19000.00
0005434639069	1996	Economy	19000.00
0005434639058	1996	Economy	19000.00
0005435948315	1996	Economy	19000.00
0005434639064	1996	Economy	19000.00
0005434639054	1996	Economy	19000.00
0005434639060	1996	Economy	19000.00
0005434639066	1996	Economy	19000.00
0005433202207	23302	Economy	20900.00
0005433202205	23302	Economy	20900.00
0005433202199	23302	Economy	20900.00
0005433202192	23302	Economy	19000.00
0005433202201	23302	Economy	19000.00
0005433202203	23302	Economy	19000.00
0005433202198	23302	Economy	19000.00
0005433202197	23302	Economy	19000.00
0005433202202	23302	Economy	19000.00
0005433202193	23302	Economy	19000.00
0005433202194	23302	Economy	19000.00
0005433202200	23302	Economy	19000.00
0005433202196	23302	Economy	19000.00
0005434638862	23302	Economy	19000.00
0005433202195	23302	Economy	19000.00
0005433202204	23302	Economy	19000.00
0005434638871	23302	Economy	19000.00
0005433202206	23302	Economy	19000.00
0005434638927	23302	Economy	19000.00
0005434638870	23302	Economy	19000.00
0005433533269	6055	Business	69700.00
0005434600524	6055	Business	69700.00
0005434600539	6055	Business	69700.00
0005434600538	6055	Business	69700.00
0005434600523	6055	Business	69700.00
0005434600533	6055	Business	69700.00
0005434600532	6055	Economy	23200.00
0005434600522	6055	Economy	23200.00
0005434600547	6055	Economy	25600.00
0005432111249	6055	Economy	25600.00
0005432111248	6055	Economy	25600.00
0005433531253	6055	Economy	23200.00
0005433531254	6055	Economy	23200.00
0005434600527	6055	Economy	23200.00
0005434600545	6055	Economy	23200.00
0005433533270	6055	Economy	23200.00
0005434600543	6055	Economy	23200.00
0005434600535	6055	Economy	23200.00
0005434600534	6055	Economy	23200.00
0005434600542	6055	Economy	23200.00
0005434600537	6055	Economy	23200.00
0005435326502	6055	Economy	23200.00
0005433531255	6055	Economy	23200.00
0005434600540	6055	Economy	23200.00
0005433531252	6055	Economy	23200.00
0005434600544	6055	Economy	23200.00
0005435326520	6055	Economy	23200.00
0005434600536	6055	Economy	23200.00
0005434600525	6055	Economy	23200.00
0005434600531	6055	Economy	23200.00
0005434600541	6055	Economy	23200.00
0005434600521	6055	Economy	23200.00
0005433533268	6055	Economy	23200.00
0005435326519	6055	Economy	23200.00
0005435326500	6055	Economy	23200.00
0005435326501	6055	Economy	23200.00
0005435326509	6055	Economy	23200.00
0005435326532	6055	Economy	23200.00
0005434600526	6055	Economy	23200.00
0005433531256	6055	Economy	23200.00
0005434600530	6055	Economy	23200.00
0005434600528	6055	Economy	23200.00
0005434600546	6055	Economy	23200.00
0005434600529	6055	Economy	23200.00
0005433531229	18606	Business	69700.00
0005433527207	18606	Business	69700.00
0005434600401	18606	Economy	23200.00
0005435326602	18606	Economy	23200.00
0005435326601	18606	Economy	23200.00
0005434600330	18606	Economy	25600.00
0005433527210	18606	Economy	23200.00
0005435326608	18606	Economy	23200.00
0005435326606	18606	Economy	23200.00
0005435326599	18606	Economy	23200.00
0005434600334	18606	Economy	23200.00
0005435326609	18606	Economy	23200.00
0005434600384	18606	Economy	23200.00
0005434600385	18606	Economy	23200.00
0005435326605	18606	Economy	23200.00
0005433527208	18606	Economy	23200.00
0005435326598	18606	Economy	23200.00
0005435326603	18606	Economy	23200.00
0005435326600	18606	Economy	23200.00
0005434600333	18606	Economy	23200.00
0005435326607	18606	Economy	23200.00
0005434600353	18606	Economy	23200.00
0005433527209	18606	Economy	23200.00
0005435326604	18606	Economy	23200.00
0005433180692	10560	Business	9100.00
0005434554040	10560	Business	9100.00
0005434550629	10560	Business	9100.00
0005434550642	10560	Business	9100.00
0005434550606	10560	Business	9100.00
0005434558189	10560	Business	9100.00
0005434558192	10560	Business	9100.00
0005434558184	10560	Business	9100.00
0005434550601	10560	Business	9100.00
0005434558185	10560	Business	9100.00
0005434558187	10560	Economy	3000.00
0005434550598	10560	Economy	3000.00
0005434550628	10560	Economy	3000.00
0005434550648	10560	Economy	3000.00
0005434558180	10560	Economy	3000.00
0005434550602	10560	Economy	3000.00
0005434550619	10560	Economy	3000.00
0005434550635	10560	Economy	3000.00
0005434550646	10560	Economy	3000.00
0005434550604	10560	Economy	3000.00
0005434550640	10560	Economy	3300.00
0005434558186	10560	Economy	3300.00
0005434550632	10560	Economy	3300.00
0005434550647	10560	Economy	3300.00
0005434550638	10560	Economy	3000.00
0005434550615	10560	Economy	3000.00
0005434550603	10560	Economy	3000.00
0005434550625	10560	Economy	3000.00
0005434550613	10560	Economy	3000.00
0005434550594	10560	Economy	3000.00
0005434558183	10560	Economy	3000.00
0005434558188	10560	Economy	3000.00
0005434550611	10560	Economy	3000.00
0005434550622	10560	Economy	3000.00
0005434550645	10560	Economy	3000.00
0005434550605	10560	Economy	3000.00
0005434550616	10560	Economy	3000.00
0005434550610	10560	Economy	3000.00
0005434550630	10560	Economy	3000.00
0005433180721	10560	Economy	3000.00
0005434550631	10560	Economy	3000.00
0005434550607	10560	Economy	3000.00
0005434550644	10560	Economy	3000.00
0005434550639	10560	Economy	3000.00
0005434550620	10560	Economy	3000.00
0005434550618	10560	Economy	3000.00
0005433180691	10560	Economy	3000.00
0005434550627	10560	Economy	3000.00
0005434550649	10560	Economy	3000.00
0005434550643	10560	Economy	3000.00
0005434550593	10560	Economy	3000.00
0005434558191	10560	Economy	3000.00
0005434550609	10560	Economy	3000.00
0005433180720	10560	Economy	3000.00
0005434558182	10560	Economy	3000.00
0005434550637	10560	Economy	3000.00
0005434550623	10560	Economy	3000.00
0005434550596	10560	Economy	3000.00
0005434550612	10560	Economy	3000.00
0005434558181	10560	Economy	3000.00
0005434550633	10560	Economy	3000.00
0005434554041	10560	Economy	3000.00
0005434550599	10560	Economy	3000.00
0005434550634	10560	Economy	3000.00
0005433180669	10560	Economy	3000.00
0005434550597	10560	Economy	3000.00
0005434554039	10560	Economy	3000.00
0005433180649	10560	Economy	3000.00
0005434550641	10560	Economy	3000.00
0005433180648	10560	Economy	3000.00
0005434550626	10560	Economy	3000.00
0005434550650	10560	Economy	3000.00
0005434550608	10560	Economy	3000.00
0005433180670	10560	Economy	3000.00
0005434550614	10560	Economy	3000.00
0005434550600	10560	Economy	3000.00
0005434558190	10560	Economy	3000.00
0005434550636	10560	Economy	3000.00
0005434550595	10560	Economy	3000.00
0005434550624	10560	Economy	3000.00
0005433180652	10560	Economy	3000.00
0005434550621	10560	Economy	3000.00
0005434550617	10560	Economy	3000.00
0005433180835	27780	Business	9100.00
0005433180851	27780	Business	9100.00
0005433180849	27780	Business	9100.00
0005433180847	27780	Business	9100.00
0005433180829	27780	Economy	3000.00
0005433180846	27780	Economy	3000.00
0005433180843	27780	Economy	3000.00
0005433180833	27780	Economy	3000.00
0005433180831	27780	Economy	3300.00
0005433180850	27780	Economy	3000.00
0005433180840	27780	Economy	3000.00
0005433180841	27780	Economy	3000.00
0005433180838	27780	Economy	3000.00
0005433180839	27780	Economy	3000.00
0005433180852	27780	Economy	3000.00
0005433180830	27780	Economy	3000.00
0005433180836	27780	Economy	3000.00
0005433180842	27780	Economy	3000.00
0005433180848	27780	Economy	3000.00
0005433180854	27780	Economy	3000.00
0005433180834	27780	Economy	3000.00
0005433180844	27780	Economy	3000.00
0005433180837	27780	Economy	3000.00
0005433180853	27780	Economy	3000.00
0005433180832	27780	Economy	3000.00
0005433180845	27780	Economy	3000.00
0005434550313	27779	Business	9100.00
0005434550276	27779	Business	9100.00
0005434550327	27779	Business	9100.00
0005434550266	27779	Business	9100.00
0005434550362	27779	Business	9100.00
0005434550270	27779	Economy	3000.00
0005434550363	27779	Economy	3000.00
0005434550515	27779	Economy	3000.00
0005434550273	27779	Economy	3300.00
0005434550265	27779	Economy	3000.00
0005434550275	27779	Economy	3000.00
0005434550498	27779	Economy	3000.00
0005434550516	27779	Economy	3000.00
0005434550288	27779	Economy	3000.00
0005434550285	27779	Economy	3000.00
0005434550319	27779	Economy	3000.00
0005434550297	27779	Economy	3000.00
0005434550348	27779	Economy	3000.00
0005434550381	27779	Economy	3000.00
0005434550457	27779	Economy	3000.00
0005434550274	27779	Economy	3000.00
0005434550312	27779	Economy	3000.00
0005434550263	27779	Economy	3000.00
0005434550458	27779	Economy	3000.00
0005433459176	6166	Economy	11700.00
0005433459175	6166	Economy	11700.00
0005433459173	6166	Economy	11700.00
0005433459177	6166	Economy	11700.00
0005433459174	6166	Economy	11700.00
0005435254449	19307	Economy	11700.00
0005435254447	19307	Economy	11700.00
0005435254448	19307	Economy	11700.00
0005435681695	6707	Business	51100.00
0005435681707	6707	Business	51100.00
0005435681727	6707	Business	51100.00
0005435681687	6707	Business	51100.00
0005435681693	6707	Business	51100.00
0005432136117	6707	Business	51100.00
0005435437577	6707	Business	51100.00
0005435681705	6707	Business	51100.00
0005435681697	6707	Economy	17000.00
0005435437600	6707	Economy	17000.00
0005435681729	6707	Economy	17000.00
0005435681702	6707	Economy	17000.00
0005435681724	6707	Economy	17000.00
0005435681708	6707	Economy	17000.00
0005435681720	6707	Economy	18700.00
0005435681721	6707	Economy	18700.00
0005435437601	6707	Economy	18700.00
0005435681701	6707	Economy	18700.00
0005435681722	6707	Economy	17000.00
0005435681706	6707	Economy	17000.00
0005435437578	6707	Economy	17000.00
0005435681719	6707	Economy	17000.00
0005435681688	6707	Economy	17000.00
0005432136114	6707	Economy	17000.00
0005435437589	6707	Economy	17000.00
0005435681699	6707	Economy	17000.00
0005435681700	6707	Economy	17000.00
0005435681698	6707	Economy	17000.00
0005435681690	6707	Economy	17000.00
0005435437618	6707	Economy	17000.00
0005435661898	6707	Economy	17000.00
0005435681711	6707	Economy	17000.00
0005435681692	6707	Economy	17000.00
0005435681689	6707	Economy	17000.00
0005435681715	6707	Economy	17000.00
0005432136118	6707	Economy	17000.00
0005435681717	6707	Economy	17000.00
0005435681716	6707	Economy	17000.00
0005435681723	6707	Economy	17000.00
0005435681691	6707	Economy	17000.00
0005435630933	6707	Economy	17000.00
0005435661899	6707	Economy	17000.00
0005435681696	6707	Economy	17000.00
0005435437588	6707	Economy	17000.00
0005435681710	6707	Economy	17000.00
0005435437580	6707	Economy	17000.00
0005435681694	6707	Economy	17000.00
0005435437564	6707	Economy	17000.00
0005435681712	6707	Economy	17000.00
0005435681703	6707	Economy	17000.00
0005435681704	6707	Economy	17000.00
0005432136116	6707	Economy	17000.00
0005435437619	6707	Economy	17000.00
0005435661897	6707	Economy	17000.00
0005435681718	6707	Economy	17000.00
0005435681714	6707	Economy	17000.00
0005435681725	6707	Economy	17000.00
0005435681713	6707	Economy	17000.00
0005432136115	6707	Economy	17000.00
0005435630934	6707	Economy	17000.00
0005435681728	6707	Economy	17000.00
0005435681726	6707	Economy	17000.00
0005435681709	6707	Economy	17000.00
0005435681686	6707	Economy	17000.00
0005435220283	6707	Economy	17000.00
0005435437730	24583	Business	51100.00
0005432533261	24583	Economy	17000.00
0005435437724	24583	Economy	17000.00
0005435681465	24583	Economy	17000.00
0005435437719	24583	Economy	17000.00
0005435681391	24583	Economy	17000.00
0005435437721	24583	Economy	17000.00
0005435437717	24583	Economy	18700.00
0005435437715	24583	Economy	18700.00
0005435437718	24583	Economy	17000.00
0005435681464	24583	Economy	17000.00
0005432305723	24583	Economy	17000.00
0005435437720	24583	Economy	17000.00
0005435437713	24583	Economy	17000.00
0005432533263	24583	Economy	17000.00
0005435681490	24583	Economy	17000.00
0005435681444	24583	Economy	17000.00
0005435437726	24583	Economy	17000.00
0005435681392	24583	Economy	17000.00
0005435437722	24583	Economy	17000.00
0005435681472	24583	Economy	17000.00
0005435437714	24583	Economy	17000.00
0005435437723	24583	Economy	17000.00
0005434828668	24583	Economy	17000.00
0005435681511	24583	Economy	17000.00
0005432305724	24583	Economy	17000.00
0005435681504	24583	Economy	17000.00
0005435681512	24583	Economy	17000.00
0005435681390	24583	Economy	17000.00
0005435681587	24583	Economy	17000.00
0005435681399	24583	Economy	17000.00
0005435681488	24583	Economy	17000.00
0005435437732	24583	Economy	17000.00
0005434828669	24583	Economy	17000.00
0005435437712	24583	Economy	17000.00
0005435437711	24583	Economy	17000.00
0005435437729	24583	Economy	17000.00
0005432305722	24583	Economy	17000.00
0005435681425	24583	Economy	17000.00
0005435681489	24583	Economy	17000.00
0005435437725	24583	Economy	17000.00
0005435681494	24583	Economy	17000.00
0005435437716	24583	Economy	17000.00
0005435437731	24583	Economy	17000.00
0005432533262	24583	Economy	17000.00
0005435437727	24583	Economy	17000.00
0005435681424	24583	Economy	17000.00
0005435681412	24583	Economy	17000.00
0005435437728	24583	Economy	17000.00
0005435681493	24583	Economy	17000.00
0005435125905	11508	Business	26400.00
0005435125916	11508	Business	26400.00
0005435125918	11508	Business	26400.00
0005435125901	11508	Business	26400.00
0005435125926	11508	Business	26400.00
0005435125898	11508	Economy	8800.00
0005435125929	11508	Economy	8800.00
0005435125906	11508	Economy	8800.00
0005435125919	11508	Economy	8800.00
0005435125907	11508	Economy	8800.00
0005435125924	11508	Economy	8800.00
0005435125910	11508	Economy	9700.00
0005435125932	11508	Economy	9700.00
0005435125922	11508	Economy	8800.00
0005435125911	11508	Economy	8800.00
0005435125925	11508	Economy	8800.00
0005435125933	11508	Economy	8800.00
0005435125917	11508	Economy	8800.00
0005435125937	11508	Economy	8800.00
0005435125928	11508	Economy	8800.00
0005435125909	11508	Economy	8800.00
0005435125920	11508	Economy	8800.00
0005435125900	11508	Economy	8800.00
0005435125913	11508	Economy	8800.00
0005435125935	11508	Economy	8800.00
0005435125899	11508	Economy	8800.00
0005435125908	11508	Economy	8800.00
0005435125927	11508	Economy	8800.00
0005435125936	11508	Economy	8800.00
0005435105946	11508	Economy	8800.00
0005435105945	11508	Economy	8800.00
0005435125902	11508	Economy	8800.00
0005435105947	11508	Economy	8800.00
0005435125915	11508	Economy	8800.00
0005435125897	11508	Economy	8800.00
0005435125904	11508	Economy	8800.00
0005435125903	11508	Economy	8800.00
0005435125912	11508	Economy	8800.00
0005435125934	11508	Economy	8800.00
0005435105948	11508	Economy	8800.00
0005435125923	11508	Economy	8800.00
0005435125921	11508	Economy	8800.00
0005435125914	11508	Economy	8800.00
0005435125931	11508	Economy	8800.00
0005435125930	11508	Economy	8800.00
0005435558059	31881	Business	26400.00
0005435558060	31881	Economy	8800.00
0005435125698	31881	Economy	8800.00
0005435125695	31881	Economy	8800.00
0005435125729	31881	Economy	8800.00
0005435125696	31881	Economy	8800.00
0005435125697	31881	Economy	8800.00
0005433397573	13523	Business	36600.00
0005435732127	13523	Business	36600.00
0005433397543	13523	Business	36600.00
0005433397542	13523	Business	36600.00
0005433397574	13523	Business	36600.00
0005433397536	13523	Business	36600.00
0005433397529	13523	Economy	12200.00
0005433397576	13523	Economy	12200.00
0005433397534	13523	Economy	12200.00
0005433397528	13523	Economy	12200.00
0005435732118	13523	Economy	12200.00
0005433397551	13523	Economy	12200.00
0005433397540	13523	Economy	13400.00
0005433397559	13523	Economy	13400.00
0005433397558	13523	Economy	13400.00
0005433397557	13523	Economy	13400.00
0005433397570	13523	Economy	12200.00
0005435732148	13523	Economy	12200.00
0005433397539	13523	Economy	12200.00
0005433397535	13523	Economy	12200.00
0005433397532	13523	Economy	12200.00
0005433397530	13523	Economy	12200.00
0005433397541	13523	Economy	12200.00
0005433397545	13523	Economy	12200.00
0005433397526	13523	Economy	12200.00
0005433397560	13523	Economy	12200.00
0005433397547	13523	Economy	12200.00
0005433397552	13523	Economy	12200.00
0005433397553	13523	Economy	12200.00
0005435732128	13523	Economy	12200.00
0005435732112	13523	Economy	12200.00
0005433397548	13523	Economy	12200.00
0005433397546	13523	Economy	12200.00
0005433397531	13523	Economy	12200.00
0005433397538	13523	Economy	12200.00
0005433397555	13523	Economy	12200.00
0005433397544	13523	Economy	12200.00
0005435732124	13523	Economy	12200.00
0005433397554	13523	Economy	12200.00
0005435732116	13523	Economy	12200.00
0005433397575	13523	Economy	12200.00
0005433397567	13523	Economy	12200.00
0005433397527	13523	Economy	12200.00
0005433397562	13523	Economy	12200.00
0005433397565	13523	Economy	12200.00
0005433397549	13523	Economy	12200.00
0005433397563	13523	Economy	12200.00
0005435732123	13523	Economy	12200.00
0005433397537	13523	Economy	12200.00
0005433397566	13523	Economy	12200.00
0005433397564	13523	Economy	12200.00
0005433397572	13523	Economy	12200.00
0005433397568	13523	Economy	12200.00
0005433397550	13523	Economy	12200.00
0005433397556	13523	Economy	12200.00
0005433397571	13523	Economy	12200.00
0005433397561	13523	Economy	12200.00
0005435732117	13523	Economy	12200.00
0005435732149	13523	Economy	12200.00
0005433397569	13523	Economy	12200.00
0005433397533	13523	Economy	12200.00
0005435732199	19408	Business	36600.00
0005433397201	19408	Business	36600.00
0005433397209	19408	Business	36600.00
0005435732210	19408	Business	36600.00
0005435732203	19408	Business	36600.00
0005435732202	19408	Economy	12200.00
0005435732196	19408	Economy	12200.00
0005433397323	19408	Economy	12200.00
0005432297251	19408	Economy	13400.00
0005433397258	19408	Economy	12200.00
0005433397194	19408	Economy	12200.00
0005435732205	19408	Economy	12200.00
0005435732211	19408	Economy	12200.00
0005433397191	19408	Economy	12200.00
0005433397183	19408	Economy	12200.00
0005435732198	19408	Economy	12200.00
0005435732209	19408	Economy	12200.00
0005435732213	19408	Economy	12200.00
0005435732194	19408	Economy	12200.00
0005435732207	19408	Economy	12200.00
0005435732195	19408	Economy	12200.00
0005435732206	19408	Economy	12200.00
0005435732200	19408	Economy	12200.00
0005433397190	19408	Economy	12200.00
0005435732212	19408	Economy	12200.00
0005433397202	19408	Economy	12200.00
0005435732197	19408	Economy	12200.00
0005435732204	19408	Economy	12200.00
0005435732201	19408	Economy	12200.00
0005435732208	19408	Economy	12200.00
0005433397229	19408	Economy	12200.00
0005435925154	13163	Business	11300.00
0005435925148	13163	Business	11300.00
0005435068218	13163	Economy	3800.00
0005435925149	13163	Economy	3800.00
0005435068192	13163	Economy	3800.00
0005435068172	13163	Economy	3800.00
0005435068256	13163	Economy	3800.00
0005435068267	13163	Economy	3800.00
0005435925150	13163	Economy	3800.00
0005435068266	13163	Economy	3800.00
0005435068275	13163	Economy	3800.00
0005435925151	13163	Economy	3800.00
0005435925152	13163	Economy	3800.00
0005435068217	13163	Economy	3800.00
0005435068193	13163	Economy	3800.00
0005435925153	13163	Economy	3800.00
0005435068286	13163	Economy	3800.00
0005435068489	15486	Business	11300.00
0005435068480	15486	Business	11300.00
0005435068518	15486	Business	11300.00
0005435068495	15486	Economy	3800.00
0005435068511	15486	Economy	3800.00
0005435068488	15486	Economy	3800.00
0005435068493	15486	Economy	3800.00
0005435068510	15486	Economy	3800.00
0005435068499	15486	Economy	3800.00
0005435068476	15486	Economy	3800.00
0005435068505	15486	Economy	3800.00
0005435068522	15486	Economy	4100.00
0005435068502	15486	Economy	4100.00
0005435068482	15486	Economy	4100.00
0005435068485	15486	Economy	3800.00
0005435068490	15486	Economy	3800.00
0005435068515	15486	Economy	3800.00
0005435068520	15486	Economy	3800.00
0005435068487	15486	Economy	3800.00
0005435068496	15486	Economy	3800.00
0005435068492	15486	Economy	3800.00
0005435068508	15486	Economy	3800.00
0005435068479	15486	Economy	3800.00
0005435068478	15486	Economy	3800.00
0005435068512	15486	Economy	3800.00
0005435068506	15486	Economy	3800.00
0005435068524	15486	Economy	3800.00
0005435068497	15486	Economy	3800.00
0005435068500	15486	Economy	3800.00
0005435068501	15486	Economy	3800.00
0005435068523	15486	Economy	3800.00
0005435068521	15486	Economy	3800.00
0005435068481	15486	Economy	3800.00
0005435068504	15486	Economy	3800.00
0005435068491	15486	Economy	3800.00
0005435068486	15486	Economy	3800.00
0005435068527	15486	Economy	3800.00
0005435068519	15486	Economy	3800.00
0005435068498	15486	Economy	3800.00
0005435068507	15486	Economy	3800.00
0005435068517	15486	Economy	3800.00
0005435068526	15486	Economy	3800.00
0005435068509	15486	Economy	3800.00
0005435068484	15486	Economy	3800.00
0005435068525	15486	Economy	3800.00
0005435068494	15486	Economy	3800.00
0005435068503	15486	Economy	3800.00
0005435068513	15486	Economy	3800.00
0005435068516	15486	Economy	3800.00
0005435068477	15486	Economy	3800.00
0005435068483	15486	Economy	3800.00
0005435068528	15486	Economy	3800.00
0005435068514	15486	Economy	3800.00
0005433407517	29490	Economy	27100.00
0005433407505	29490	Economy	24700.00
0005435808051	29490	Economy	24700.00
0005433407508	29490	Economy	24700.00
0005433407504	29490	Economy	24700.00
0005433407510	29490	Economy	24700.00
0005433407506	29490	Economy	24700.00
0005435808050	29490	Economy	24700.00
0005435808052	29490	Economy	24700.00
0005433407511	29490	Economy	24700.00
0005433407514	29490	Economy	24700.00
0005433407512	29490	Economy	24700.00
0005433407516	29490	Economy	24700.00
0005433407515	29490	Economy	24700.00
0005433407507	29490	Economy	24700.00
0005433407513	29490	Economy	24700.00
0005433407509	29490	Economy	24700.00
0005433407503	29490	Economy	24700.00
0005434214036	10741	Business	61300.00
0005434214055	10741	Business	61300.00
0005434214074	10741	Business	61300.00
0005434214052	10741	Business	61300.00
0005434214032	10741	Business	61300.00
0005434214051	10741	Economy	20400.00
0005434214071	10741	Economy	20400.00
0005434214057	10741	Economy	20400.00
0005434214065	10741	Economy	20400.00
0005434214067	10741	Economy	20400.00
0005434214060	10741	Economy	20400.00
0005434214075	10741	Economy	20400.00
0005434214042	10741	Economy	20400.00
0005434214048	10741	Economy	22500.00
0005434214066	10741	Economy	22500.00
0005434214077	10741	Economy	20400.00
0005434214033	10741	Economy	20400.00
0005434214064	10741	Economy	20400.00
0005434214041	10741	Economy	20400.00
0005434214045	10741	Economy	20400.00
0005434214069	10741	Economy	20400.00
0005434214043	10741	Economy	20400.00
0005434214062	10741	Economy	20400.00
0005434214058	10741	Economy	20400.00
0005434214039	10741	Economy	20400.00
0005434214063	10741	Economy	20400.00
0005434214031	10741	Economy	20400.00
0005434214078	10741	Economy	20400.00
0005434214049	10741	Economy	20400.00
0005434214056	10741	Economy	20400.00
0005434214044	10741	Economy	20400.00
0005434214061	10741	Economy	20400.00
0005434214059	10741	Economy	20400.00
0005434214053	10741	Economy	20400.00
0005434214035	10741	Economy	20400.00
0005434214050	10741	Economy	20400.00
0005434214037	10741	Economy	20400.00
0005434214038	10741	Economy	20400.00
0005434214046	10741	Economy	20400.00
0005434214068	10741	Economy	20400.00
0005434214054	10741	Economy	20400.00
0005434214070	10741	Economy	20400.00
0005434214073	10741	Economy	20400.00
0005434214072	10741	Economy	20400.00
0005434214040	10741	Economy	20400.00
0005434214047	10741	Economy	20400.00
0005434214076	10741	Economy	20400.00
0005434214034	10741	Economy	20400.00
0005434756007	28685	Business	61300.00
0005434755978	28685	Business	61300.00
0005434755994	28685	Business	61300.00
0005434755996	28685	Business	61300.00
0005434755998	28685	Business	61300.00
0005434756001	28685	Business	61300.00
0005434755988	28685	Business	61300.00
0005434213750	28685	Economy	20400.00
0005434755971	28685	Economy	20400.00
0005434755992	28685	Economy	20400.00
0005434755990	28685	Economy	20400.00
0005434755969	28685	Economy	20400.00
0005434755967	28685	Economy	22500.00
0005434755970	28685	Economy	20400.00
0005434755986	28685	Economy	20400.00
0005434213791	28685	Economy	20400.00
0005434756006	28685	Economy	20400.00
0005434213749	28685	Economy	20400.00
0005434755963	28685	Economy	20400.00
0005434755984	28685	Economy	20400.00
0005434756004	28685	Economy	20400.00
0005434755977	28685	Economy	20400.00
0005434755975	28685	Economy	20400.00
0005434755968	28685	Economy	20400.00
0005434755974	28685	Economy	20400.00
0005434755973	28685	Economy	20400.00
0005434755989	28685	Economy	20400.00
0005434756003	28685	Economy	20400.00
0005434755961	28685	Economy	20400.00
0005434755981	28685	Economy	20400.00
0005434755995	28685	Economy	20400.00
0005434213732	28685	Economy	20400.00
0005434755964	28685	Economy	20400.00
0005434755985	28685	Economy	20400.00
0005434755966	28685	Economy	20400.00
0005434755987	28685	Economy	20400.00
0005434755983	28685	Economy	20400.00
0005434755979	28685	Economy	20400.00
0005434755993	28685	Economy	20400.00
0005434755991	28685	Economy	20400.00
0005434755999	28685	Economy	20400.00
0005434755972	28685	Economy	20400.00
0005434756002	28685	Economy	20400.00
0005434755980	28685	Economy	20400.00
0005434756000	28685	Economy	20400.00
0005434755976	28685	Economy	20400.00
0005434755997	28685	Economy	20400.00
0005434755965	28685	Economy	20400.00
0005434213740	28685	Economy	20400.00
0005434755962	28685	Economy	20400.00
0005434213701	28685	Economy	20400.00
0005434755982	28685	Economy	20400.00
0005434756005	28685	Economy	20400.00
0005432125379	5483	Business	29500.00
0005435039086	5483	Business	29500.00
0005435006775	5483	Business	29500.00
0005435039120	5483	Business	29500.00
0005435042834	5483	Business	29500.00
0005435039113	5483	Business	29500.00
0005435039105	5483	Business	29500.00
0005435006791	5483	Business	29500.00
0005435006769	5483	Business	29500.00
0005435039073	5483	Business	29500.00
0005435006790	5483	Business	29500.00
0005435039083	5483	Economy	9800.00
0005435039076	5483	Economy	9800.00
0005435039064	5483	Economy	9800.00
0005435039095	5483	Economy	9800.00
0005435039082	5483	Economy	9800.00
0005435006787	5483	Economy	9800.00
0005435006767	5483	Economy	9800.00
0005435039091	5483	Economy	9800.00
0005432125372	5483	Economy	9800.00
0005435006780	5483	Economy	9800.00
0005434229029	5483	Economy	9800.00
0005435039084	5483	Economy	9800.00
0005435039104	5483	Economy	9800.00
0005435006770	5483	Economy	9800.00
0005435039068	5483	Economy	9800.00
0005435006771	5483	Economy	9800.00
0005435006784	5483	Economy	9800.00
0005432125377	5483	Economy	9800.00
0005435039103	5483	Economy	9800.00
0005435006766	5483	Economy	9800.00
0005435039100	5483	Economy	9800.00
0005435039088	5483	Economy	9800.00
0005432125373	5483	Economy	9800.00
0005434229007	5483	Economy	9800.00
0005435039074	5483	Economy	9800.00
0005435039093	5483	Economy	9800.00
0005435006776	5483	Economy	9800.00
0005435006779	5483	Economy	9800.00
0005435039106	5483	Economy	9800.00
0005434228983	5483	Economy	9800.00
0005434229008	5483	Economy	9800.00
0005435039087	5483	Economy	9800.00
0005435006789	5483	Economy	9800.00
0005435039079	5483	Economy	9800.00
0005435039060	5483	Economy	10800.00
0005435039117	5483	Economy	10800.00
0005435039099	5483	Economy	10800.00
0005435039116	5483	Economy	10800.00
0005435039107	5483	Economy	10800.00
0005435006782	5483	Economy	9800.00
0005435039124	5483	Economy	9800.00
0005435039121	5483	Economy	9800.00
0005435039101	5483	Economy	9800.00
0005435006774	5483	Economy	9800.00
0005435039069	5483	Economy	9800.00
0005435039108	5483	Economy	9800.00
0005435039118	5483	Economy	9800.00
0005434229002	5483	Economy	9800.00
0005435006783	5483	Economy	9800.00
0005435039070	5483	Economy	9800.00
0005435006788	5483	Economy	9800.00
0005434228972	5483	Economy	9800.00
0005435039119	5483	Economy	9800.00
0005435039059	5483	Economy	9800.00
0005435039114	5483	Economy	9800.00
0005432125375	5483	Economy	9800.00
0005435039109	5483	Economy	9800.00
0005435039092	5483	Economy	9800.00
0005435006773	5483	Economy	9800.00
0005435039071	5483	Economy	9800.00
0005435039065	5483	Economy	9800.00
0005435039097	5483	Economy	9800.00
0005435039102	5483	Economy	9800.00
0005435039096	5483	Economy	9800.00
0005432125371	5483	Economy	9800.00
0005435039094	5483	Economy	9800.00
0005435039072	5483	Economy	9800.00
0005435006786	5483	Economy	9800.00
0005435039077	5483	Economy	9800.00
0005435039067	5483	Economy	9800.00
0005435039122	5483	Economy	9800.00
0005435006781	5483	Economy	9800.00
0005435039098	5483	Economy	9800.00
0005435039115	5483	Economy	9800.00
0005435039111	5483	Economy	9800.00
0005435039110	5483	Economy	9800.00
0005435006768	5483	Economy	9800.00
0005435039058	5483	Economy	9800.00
0005435039090	5483	Economy	9800.00
0005435039112	5483	Economy	9800.00
0005435039066	5483	Economy	9800.00
0005432125378	5483	Economy	9800.00
0005435039089	5483	Economy	9800.00
0005434228978	5483	Economy	9800.00
0005435039123	5483	Economy	9800.00
0005432125374	5483	Economy	9800.00
0005435039081	5483	Economy	9800.00
0005434229006	5483	Economy	9800.00
0005435039063	5483	Economy	9800.00
0005435006778	5483	Economy	9800.00
0005435006785	5483	Economy	9800.00
0005435039062	5483	Economy	9800.00
0005435039075	5483	Economy	9800.00
0005435042833	5483	Economy	9800.00
0005435039080	5483	Economy	9800.00
0005435039078	5483	Economy	9800.00
0005435006772	5483	Economy	9800.00
0005432125376	5483	Economy	9800.00
0005435039085	5483	Economy	9800.00
0005435006777	5483	Economy	9800.00
0005435039061	5483	Economy	9800.00
0005434229147	13003	Business	29500.00
0005434229134	13003	Business	29500.00
0005435038866	13003	Business	29500.00
0005434229138	13003	Business	29500.00
0005435006630	13003	Business	29500.00
0005435006635	13003	Business	29500.00
0005435038751	13003	Business	29500.00
0005435006610	13003	Economy	9800.00
0005435006620	13003	Economy	9800.00
0005432304359	13003	Economy	9800.00
0005435038635	13003	Economy	9800.00
0005434229133	13003	Economy	9800.00
0005435038649	13003	Economy	9800.00
0005435038733	13003	Economy	9800.00
0005435038757	13003	Economy	9800.00
0005435038698	13003	Economy	9800.00
0005435038728	13003	Economy	9800.00
0005435038759	13003	Economy	9800.00
0005434229145	13003	Economy	9800.00
0005435006662	13003	Economy	9800.00
0005434229129	13003	Economy	9800.00
0005435038648	13003	Economy	9800.00
0005435006719	13003	Economy	9800.00
0005434229132	13003	Economy	9800.00
0005434229143	13003	Economy	9800.00
0005435038865	13003	Economy	9800.00
0005434229149	13003	Economy	9800.00
0005435006661	13003	Economy	9800.00
0005435006609	13003	Economy	9800.00
0005434229140	13003	Economy	9800.00
0005435038796	13003	Economy	9800.00
0005435038722	13003	Economy	9800.00
0005435038683	13003	Economy	9800.00
0005432304358	13003	Economy	9800.00
0005434229150	13003	Economy	9800.00
0005434229131	13003	Economy	9800.00
0005434229142	13003	Economy	9800.00
0005434229144	13003	Economy	9800.00
0005435006643	13003	Economy	9800.00
0005435038634	13003	Economy	9800.00
0005434229136	13003	Economy	9800.00
0005434229137	13003	Economy	9800.00
0005435038697	13003	Economy	9800.00
0005435038761	13003	Economy	9800.00
0005435038738	13003	Economy	9800.00
0005434229141	13003	Economy	9800.00
0005435038633	13003	Economy	9800.00
0005435006631	13003	Economy	9800.00
0005434229128	13003	Economy	9800.00
0005434229135	13003	Economy	9800.00
0005434229148	13003	Economy	9800.00
0005435038626	13003	Economy	9800.00
0005435006642	13003	Economy	9800.00
0005432304360	13003	Economy	9800.00
0005432304357	13003	Economy	9800.00
0005435006619	13003	Economy	9800.00
0005434229139	13003	Economy	9800.00
0005435038755	13003	Economy	9800.00
0005434229146	13003	Economy	9800.00
0005435006615	13003	Economy	9800.00
0005434229130	13003	Economy	9800.00
0005435006614	13003	Economy	9800.00
0005435038793	13003	Economy	9800.00
0005435038756	13003	Economy	9800.00
0005434426291	14888	Business	52900.00
0005434426282	14888	Business	52900.00
0005434426270	14888	Business	52900.00
0005434426283	14888	Business	52900.00
0005434426269	14888	Business	52900.00
0005434426279	14888	Business	52900.00
0005434411729	14888	Business	52900.00
0005434426281	14888	Business	52900.00
0005434426277	14888	Economy	17600.00
0005435902398	14888	Economy	17600.00
0005434411730	14888	Economy	17600.00
0005434426280	14888	Economy	17600.00
0005434426293	14888	Economy	19400.00
0005435902399	14888	Economy	19400.00
0005434426295	14888	Economy	17600.00
0005434411728	14888	Economy	17600.00
0005434426278	14888	Economy	17600.00
0005434426284	14888	Economy	17600.00
0005434426285	14888	Economy	17600.00
0005434426289	14888	Economy	17600.00
0005434426268	14888	Economy	17600.00
0005434426273	14888	Economy	17600.00
0005432188569	14888	Economy	17600.00
0005432188570	14888	Economy	17600.00
0005434426265	14888	Economy	17600.00
0005434426290	14888	Economy	17600.00
0005434426271	14888	Economy	17600.00
0005432188571	14888	Economy	17600.00
0005434426287	14888	Economy	17600.00
0005434411731	14888	Economy	17600.00
0005434426266	14888	Economy	17600.00
0005434426294	14888	Economy	17600.00
0005434426288	14888	Economy	17600.00
0005434426267	14888	Economy	17600.00
0005434426274	14888	Economy	17600.00
0005434426272	14888	Economy	17600.00
0005434426276	14888	Economy	17600.00
0005434426275	14888	Economy	17600.00
0005434426292	14888	Economy	17600.00
0005434426286	14888	Economy	17600.00
0005432188572	14888	Economy	17600.00
0005435554105	14888	Economy	17600.00
0005435902516	20223	Business	52900.00
0005435554143	20223	Business	52900.00
0005434426161	20223	Business	52900.00
0005434426091	20223	Business	52900.00
0005435902513	20223	Economy	17600.00
0005435554142	20223	Economy	19400.00
0005435554139	20223	Economy	19400.00
0005435902529	20223	Economy	17600.00
0005434426108	20223	Economy	17600.00
0005435554140	20223	Economy	17600.00
0005435902519	20223	Economy	17600.00
0005434411702	20223	Economy	17600.00
0005435902514	20223	Economy	17600.00
0005435902524	20223	Economy	17600.00
0005434426100	20223	Economy	17600.00
0005434426164	20223	Economy	17600.00
0005432059484	20223	Economy	17600.00
0005435902518	20223	Economy	17600.00
0005435554141	20223	Economy	17600.00
0005435902527	20223	Economy	17600.00
0005435902517	20223	Economy	17600.00
0005435902522	20223	Economy	17600.00
0005435902520	20223	Economy	17600.00
0005434426160	20223	Economy	17600.00
0005435902525	20223	Economy	17600.00
0005435554138	20223	Economy	17600.00
0005435902523	20223	Economy	17600.00
0005435902512	20223	Economy	17600.00
0005435902526	20223	Economy	17600.00
0005435902515	20223	Economy	17600.00
0005435902528	20223	Economy	17600.00
0005435902521	20223	Economy	17600.00
0005435981803	26542	Business	18500.00
0005435981791	26542	Business	18500.00
0005435981802	26542	Business	18500.00
0005435981841	26542	Business	18500.00
0005435981804	26542	Business	18500.00
0005432300197	26542	Business	18500.00
0005432300201	26542	Business	18500.00
0005435981836	26542	Economy	6200.00
0005435981796	26542	Economy	6200.00
0005435981815	26542	Economy	6200.00
0005435981827	26542	Economy	6200.00
0005435981807	26542	Economy	6200.00
0005433434193	26542	Economy	6200.00
0005435981794	26542	Economy	6200.00
0005435981800	26542	Economy	6800.00
0005435981825	26542	Economy	6800.00
0005435981811	26542	Economy	6800.00
0005435981837	26542	Economy	6800.00
0005435981805	26542	Economy	6200.00
0005435981809	26542	Economy	6200.00
0005435981789	26542	Economy	6200.00
0005435981797	26542	Economy	6200.00
0005435981834	26542	Economy	6200.00
0005435981820	26542	Economy	6200.00
0005435981818	26542	Economy	6200.00
0005435981833	26542	Economy	6200.00
0005435981823	26542	Economy	6200.00
0005435981824	26542	Economy	6200.00
0005435981835	26542	Economy	6200.00
0005432300200	26542	Economy	6200.00
0005435981812	26542	Economy	6200.00
0005435981832	26542	Economy	6200.00
0005435981830	26542	Economy	6200.00
0005435981795	26542	Economy	6200.00
0005435981817	26542	Economy	6200.00
0005435981822	26542	Economy	6200.00
0005432300199	26542	Economy	6200.00
0005435981814	26542	Economy	6200.00
0005432300202	26542	Economy	6200.00
0005435981798	26542	Economy	6200.00
0005435981810	26542	Economy	6200.00
0005435981828	26542	Economy	6200.00
0005435981839	26542	Economy	6200.00
0005435981806	26542	Economy	6200.00
0005435981790	26542	Economy	6200.00
0005435981826	26542	Economy	6200.00
0005435981819	26542	Economy	6200.00
0005435981813	26542	Economy	6200.00
0005435981793	26542	Economy	6200.00
0005435981838	26542	Economy	6200.00
0005435981816	26542	Economy	6200.00
0005435981792	26542	Economy	6200.00
0005435981829	26542	Economy	6200.00
0005435981840	26542	Economy	6200.00
0005432300196	26542	Economy	6200.00
0005435981799	26542	Economy	6200.00
0005432300198	26542	Economy	6200.00
0005435981831	26542	Economy	6200.00
0005435981821	26542	Economy	6200.00
0005435981808	26542	Economy	6200.00
0005435981801	26542	Economy	6200.00
0005435981511	26732	Business	18500.00
0005433434390	26732	Business	18500.00
0005435981517	26732	Business	18500.00
0005434271290	26732	Business	18500.00
0005435981604	26732	Business	18500.00
0005435981545	26732	Business	18500.00
0005435981510	26732	Economy	6200.00
0005433434406	26732	Economy	6200.00
0005434269082	26732	Economy	6200.00
0005434270184	26732	Economy	6200.00
0005433434402	26732	Economy	6200.00
0005433434381	26732	Economy	6800.00
0005433434405	26732	Economy	6800.00
0005433434397	26732	Economy	6200.00
0005435981691	26732	Economy	6200.00
0005433434400	26732	Economy	6200.00
0005433434398	26732	Economy	6200.00
0005433434384	26732	Economy	6200.00
0005433434383	26732	Economy	6200.00
0005432051097	26732	Economy	6200.00
0005433434385	26732	Economy	6200.00
0005433434391	26732	Economy	6200.00
0005433434407	26732	Economy	6200.00
0005433434404	26732	Economy	6200.00
0005433434401	26732	Economy	6200.00
0005433434409	26732	Economy	6200.00
0005433434386	26732	Economy	6200.00
0005435981605	26732	Economy	6200.00
0005435981586	26732	Economy	6200.00
0005433434403	26732	Economy	6200.00
0005435981513	26732	Economy	6200.00
0005433434393	26732	Economy	6200.00
0005433434408	26732	Economy	6200.00
0005435981534	26732	Economy	6200.00
0005432051096	26732	Economy	6200.00
0005434271291	26732	Economy	6200.00
0005434269081	26732	Economy	6200.00
0005432051095	26732	Economy	6200.00
0005433434392	26732	Economy	6200.00
0005433434399	26732	Economy	6200.00
0005435981536	26732	Economy	6200.00
0005434270185	26732	Economy	6200.00
0005433434382	26732	Economy	6200.00
0005433434388	26732	Economy	6200.00
0005433434394	26732	Economy	6200.00
0005433434387	26732	Economy	6200.00
0005433434389	26732	Economy	6200.00
0005433434396	26732	Economy	6200.00
0005433434395	26732	Economy	6200.00
0005433687681	19522	Economy	21000.00
0005433686608	19522	Economy	21000.00
0005433685493	19522	Economy	21000.00
0005433686606	19522	Economy	21000.00
0005433686609	19522	Economy	19100.00
0005433685503	19522	Economy	19100.00
0005433686613	19522	Economy	19100.00
0005433685497	19522	Economy	19100.00
0005433687679	19522	Economy	19100.00
0005433686610	19522	Economy	19100.00
0005433686616	19522	Economy	19100.00
0005433685501	19522	Economy	19100.00
0005433685506	19522	Economy	19100.00
0005433685502	19522	Economy	19100.00
0005433686603	19522	Economy	19100.00
0005433686607	19522	Economy	19100.00
0005433685498	19522	Economy	19100.00
0005433685500	19522	Economy	19100.00
0005433687685	19522	Economy	19100.00
0005433687688	19522	Economy	19100.00
0005433687683	19522	Economy	19100.00
0005433685505	19522	Economy	19100.00
0005433686605	19522	Economy	19100.00
0005433687680	19522	Economy	19100.00
0005433687682	19522	Economy	19100.00
0005433686611	19522	Economy	19100.00
0005433685496	19522	Economy	19100.00
0005433687686	19522	Economy	19100.00
0005433686602	19522	Economy	19100.00
0005433686615	19522	Economy	19100.00
0005433687684	19522	Economy	19100.00
0005433687678	19522	Economy	19100.00
0005433685499	19522	Economy	19100.00
0005433685495	19522	Economy	19100.00
0005433686614	19522	Economy	19100.00
0005433687677	19522	Economy	19100.00
0005433685491	19522	Economy	19100.00
0005433685492	19522	Economy	19100.00
0005433687675	19522	Economy	19100.00
0005433687687	19522	Economy	19100.00
0005433686612	19522	Economy	19100.00
0005433685494	19522	Economy	19100.00
0005433686604	19522	Economy	19100.00
0005433687676	19522	Economy	19100.00
0005433685504	19522	Economy	19100.00
0005432583778	3183	Economy	11100.00
0005432583774	3183	Economy	11100.00
0005432583779	3183	Economy	10100.00
0005432583764	3183	Economy	10100.00
0005432583780	3183	Economy	10100.00
0005432857867	3183	Economy	10100.00
0005432583787	3183	Economy	10100.00
0005432583777	3183	Economy	10100.00
0005432583769	3183	Economy	10100.00
0005432583784	3183	Economy	10100.00
0005432583782	3183	Economy	10100.00
0005432583786	3183	Economy	10100.00
0005432216243	3183	Economy	10100.00
0005432583766	3183	Economy	10100.00
0005432583781	3183	Economy	10100.00
0005432583773	3183	Economy	10100.00
0005432583763	3183	Economy	10100.00
0005432857855	3183	Economy	10100.00
0005432583762	3183	Economy	10100.00
0005432857872	3183	Economy	10100.00
0005432857873	3183	Economy	10100.00
0005432583767	3183	Economy	10100.00
0005432216244	3183	Economy	10100.00
0005432583783	3183	Economy	10100.00
0005432583770	3183	Economy	10100.00
0005432583772	3183	Economy	10100.00
0005432583771	3183	Economy	10100.00
0005432583768	3183	Economy	10100.00
0005432857863	3183	Economy	10100.00
0005432583775	3183	Economy	10100.00
0005432857876	3183	Economy	10100.00
0005432583765	3183	Economy	10100.00
0005432583785	3183	Economy	10100.00
0005432583776	3183	Economy	10100.00
0005432857939	31469	Economy	11100.00
0005432583587	31469	Economy	11100.00
0005432583602	31469	Economy	10100.00
0005432583633	31469	Economy	10100.00
0005432857937	31469	Economy	10100.00
0005432583661	31469	Economy	10100.00
0005432583632	31469	Economy	10100.00
0005432583582	31469	Economy	10100.00
0005432857942	31469	Economy	10100.00
0005432857946	31469	Economy	10100.00
0005432857943	31469	Economy	10100.00
0005432857938	31469	Economy	10100.00
0005432857948	31469	Economy	10100.00
0005432857936	31469	Economy	10100.00
0005432583634	31469	Economy	10100.00
0005432857940	31469	Economy	10100.00
0005432857944	31469	Economy	10100.00
0005432857947	31469	Economy	10100.00
0005432583670	31469	Economy	10100.00
0005432857945	31469	Economy	10100.00
0005432583656	31469	Economy	10100.00
0005432583625	31469	Economy	10100.00
0005432583655	31469	Economy	10100.00
0005432583654	31469	Economy	10100.00
0005432857941	31469	Economy	10100.00
0005432583608	31469	Economy	10100.00
0005432583626	31469	Economy	10100.00
0005432583583	31469	Economy	10100.00
0005432583669	31469	Economy	10100.00
0005432583724	31469	Economy	10100.00
0005434943252	894	Economy	8300.00
0005434943258	894	Economy	7500.00
0005434943260	894	Economy	7500.00
0005434943255	894	Economy	7500.00
0005434943254	894	Economy	7500.00
0005434943259	894	Economy	7500.00
0005434943256	894	Economy	7500.00
0005434943257	894	Economy	7500.00
0005434943253	894	Economy	7500.00
0005433255035	894	Economy	7500.00
0005434943251	894	Economy	7500.00
0005433255064	16211	Economy	8300.00
0005433255065	16211	Economy	8300.00
0005434943212	16211	Economy	7500.00
0005433255062	16211	Economy	7500.00
0005433255063	16211	Economy	7500.00
0005433255061	16211	Economy	7500.00
0005433255060	16211	Economy	7500.00
0005433654700	4331	Business	90500.00
0005433654690	4331	Business	90500.00
0005433654685	4331	Business	90500.00
0005433654705	4331	Business	90500.00
0005433654697	4331	Economy	30200.00
0005433654691	4331	Economy	30200.00
0005433654695	4331	Economy	30200.00
0005433654693	4331	Economy	30200.00
0005433654702	4331	Economy	30200.00
0005433654687	4331	Economy	30200.00
0005433654701	4331	Economy	30200.00
0005433654688	4331	Economy	30200.00
0005433654692	4331	Economy	30200.00
0005433654696	4331	Economy	30200.00
0005433654689	4331	Economy	30200.00
0005433654686	4331	Economy	30200.00
0005433654706	4331	Economy	30200.00
0005433654703	4331	Economy	30200.00
0005433654704	4331	Economy	30200.00
0005433654699	4331	Economy	30200.00
0005433654698	4331	Economy	30200.00
0005433654707	4331	Economy	30200.00
0005433654694	4331	Economy	30200.00
0005433811612	27836	Economy	4400.00
0005433811611	27836	Economy	4400.00
0005433811616	27836	Economy	4400.00
0005433811617	27836	Economy	4400.00
0005433811610	27836	Economy	4400.00
0005433811613	27836	Economy	4400.00
0005433811619	27836	Economy	4400.00
0005433811618	27836	Economy	4400.00
0005433811614	27836	Economy	4400.00
0005433811615	27836	Economy	4400.00
0005433811620	27836	Economy	4400.00
0005435652538	21746	Business	9800.00
0005435652548	21746	Business	9800.00
0005433367220	21746	Business	9800.00
0005435652527	21746	Business	9800.00
0005435652535	21746	Business	9800.00
0005435652546	21746	Economy	3300.00
0005435652533	21746	Economy	3300.00
0005433367248	21746	Economy	3600.00
0005435652556	21746	Economy	3600.00
0005435652553	21746	Economy	3600.00
0005435652544	21746	Economy	3600.00
0005435652542	21746	Economy	3300.00
0005435652529	21746	Economy	3300.00
0005435652537	21746	Economy	3300.00
0005435652540	21746	Economy	3300.00
0005435652558	21746	Economy	3300.00
0005435652543	21746	Economy	3300.00
0005435652547	21746	Economy	3300.00
0005435652534	21746	Economy	3300.00
0005435652559	21746	Economy	3300.00
0005435652532	21746	Economy	3300.00
0005435652550	21746	Economy	3300.00
0005433367235	21746	Economy	3300.00
0005435652531	21746	Economy	3300.00
0005433367282	21746	Economy	3300.00
0005435652551	21746	Economy	3300.00
0005435652530	21746	Economy	3300.00
0005435652539	21746	Economy	3300.00
0005433367247	21746	Economy	3300.00
0005435652528	21746	Economy	3300.00
0005435652555	21746	Economy	3300.00
0005435652554	21746	Economy	3300.00
0005433367291	21746	Economy	3300.00
0005433367313	21746	Economy	3300.00
0005435652536	21746	Economy	3300.00
0005435652545	21746	Economy	3300.00
0005435652541	21746	Economy	3300.00
0005435652560	21746	Economy	3300.00
0005435652549	21746	Economy	3300.00
0005435652552	21746	Economy	3300.00
0005433367236	21746	Economy	3300.00
0005435652557	21746	Economy	3300.00
0005433784559	9381	Business	186200.00
0005434273052	9381	Business	186200.00
0005433805045	9381	Business	186200.00
0005433805004	9381	Business	186200.00
0005433805011	9381	Business	186200.00
0005433784555	9381	Business	186200.00
0005433784570	9381	Business	186200.00
0005433805030	9381	Business	186200.00
0005432667432	9381	Business	186200.00
0005432657416	9381	Business	186200.00
0005433805016	9381	Business	186200.00
0005433784564	9381	Business	186200.00
0005433784584	9381	Economy	68300.00
0005433805026	9381	Economy	68300.00
0005433805013	9381	Economy	62100.00
0005433805031	9381	Economy	62100.00
0005433805005	9381	Economy	62100.00
0005433763052	9381	Economy	62100.00
0005433805007	9381	Economy	62100.00
0005433784562	9381	Economy	62100.00
0005432667433	9381	Economy	62100.00
0005433784576	9381	Economy	62100.00
0005433784583	9381	Economy	62100.00
0005433805021	9381	Economy	62100.00
0005433805041	9381	Economy	62100.00
0005433784573	9381	Economy	62100.00
0005433805010	9381	Economy	62100.00
0005433805008	9381	Economy	62100.00
0005433805009	9381	Economy	62100.00
0005433784565	9381	Economy	62100.00
0005433805020	9381	Economy	62100.00
0005434170838	9381	Economy	62100.00
0005433784567	9381	Economy	62100.00
0005433784571	9381	Economy	62100.00
0005433805028	9381	Economy	62100.00
0005433805018	9381	Economy	62100.00
0005433805039	9381	Economy	62100.00
0005433805014	9381	Economy	62100.00
0005434270170	9381	Economy	62100.00
0005433784582	9381	Economy	62100.00
0005433763051	9381	Economy	62100.00
0005433784553	9381	Economy	62100.00
0005433805029	9381	Economy	62100.00
0005433763050	9381	Economy	62100.00
0005433784569	9381	Economy	62100.00
0005434170817	9381	Economy	62100.00
0005433805040	9381	Economy	62100.00
0005432666367	9381	Economy	62100.00
0005433784563	9381	Economy	62100.00
0005433763055	9381	Economy	62100.00
0005433784575	9381	Economy	62100.00
0005433763060	9381	Economy	62100.00
0005434170834	9381	Economy	62100.00
0005433784581	9381	Economy	62100.00
0005433805034	9381	Economy	62100.00
0005433805023	9381	Economy	62100.00
0005433763056	9381	Economy	62100.00
0005433784554	9381	Economy	62100.00
0005432665252	9381	Economy	62100.00
0005434151657	9381	Economy	62100.00
0005433805017	9381	Economy	62100.00
0005432666366	9381	Economy	68300.00
0005433763054	9381	Economy	68300.00
0005433763058	9381	Economy	62100.00
0005433763049	9381	Economy	62100.00
0005433784577	9381	Economy	68300.00
0005432666368	9381	Economy	62100.00
0005434170826	9381	Economy	62100.00
0005433784557	9381	Economy	62100.00
0005433784586	9381	Economy	62100.00
0005433805012	9381	Economy	62100.00
0005434170837	9381	Economy	62100.00
0005433763057	9381	Economy	62100.00
0005433805024	9381	Economy	62100.00
0005433784580	9381	Economy	62100.00
0005433763062	9381	Economy	62100.00
0005432665253	9381	Economy	62100.00
0005433763047	9381	Economy	62100.00
0005433784578	9381	Economy	62100.00
0005433763061	9381	Economy	62100.00
0005433805046	9381	Economy	62100.00
0005433805044	9381	Economy	62100.00
0005432657415	9381	Economy	62100.00
0005433763053	9381	Economy	62100.00
0005433805019	9381	Economy	62100.00
0005433805036	9381	Economy	62100.00
0005433784560	9381	Economy	62100.00
0005433805033	9381	Economy	62100.00
0005433784558	9381	Economy	62100.00
0005433784556	9381	Economy	62100.00
0005433805006	9381	Economy	62100.00
0005433805015	9381	Economy	62100.00
0005433805027	9381	Economy	62100.00
0005433784561	9381	Economy	62100.00
0005433763059	9381	Economy	62100.00
0005433805043	9381	Economy	62100.00
0005434170847	9381	Economy	62100.00
0005433805032	9381	Economy	62100.00
0005434151654	9381	Economy	62100.00
0005432666369	9381	Economy	62100.00
0005433805025	9381	Economy	62100.00
0005433805042	9381	Economy	62100.00
0005433805022	9381	Economy	62100.00
0005433763048	9381	Economy	62100.00
0005433784579	9381	Economy	62100.00
0005433784572	9381	Economy	62100.00
0005433784566	9381	Economy	62100.00
0005433805035	9381	Economy	62100.00
0005433784574	9381	Economy	62100.00
0005433784568	9381	Economy	62100.00
0005432657417	9381	Economy	62100.00
0005433805038	9381	Economy	62100.00
0005433784585	9381	Economy	62100.00
0005433805037	9381	Economy	62100.00
0005433804785	26238	Business	186200.00
0005434170907	26238	Business	186200.00
0005433804795	26238	Business	186200.00
0005434269080	26238	Business	186200.00
0005434170913	26238	Economy	68300.00
0005434170912	26238	Economy	62100.00
0005433804864	26238	Economy	62100.00
0005434170910	26238	Economy	62100.00
0005432666351	26238	Economy	62100.00
0005433784433	26238	Economy	62100.00
0005433804812	26238	Economy	62100.00
0005433762971	26238	Economy	62100.00
0005433804855	26238	Economy	62100.00
0005434170914	26238	Economy	62100.00
0005433804802	26238	Economy	62100.00
0005433804784	26238	Economy	62100.00
0005433804786	26238	Economy	62100.00
0005433762972	26238	Economy	62100.00
0005434270183	26238	Economy	62100.00
0005434170902	26238	Economy	62100.00
0005433804843	26238	Economy	62100.00
0005434271288	26238	Economy	62100.00
0005434151674	26238	Economy	62100.00
0005435269673	26238	Economy	62100.00
0005433784298	26238	Economy	62100.00
0005433804815	26238	Economy	62100.00
0005434170911	26238	Economy	62100.00
0005433784432	26238	Economy	62100.00
0005434170908	26238	Economy	62100.00
0005433762949	26238	Economy	62100.00
0005433784297	26238	Economy	62100.00
0005434151673	26238	Economy	62100.00
0005434170899	26238	Economy	68300.00
0005434170906	26238	Economy	62100.00
0005433784301	26238	Economy	62100.00
0005434170904	26238	Economy	62100.00
0005435269672	26238	Economy	62100.00
0005434151672	26238	Economy	62100.00
0005433762979	26238	Economy	62100.00
0005434170900	26238	Economy	62100.00
0005434170905	26238	Economy	62100.00
0005433762956	26238	Economy	62100.00
0005433804854	26238	Economy	62100.00
0005433804823	26238	Economy	62100.00
0005433762950	26238	Economy	62100.00
0005434270182	26238	Economy	62100.00
0005433804791	26238	Economy	62100.00
0005433804794	26238	Economy	62100.00
0005433784354	26238	Economy	62100.00
0005435269674	26238	Economy	62100.00
0005434170909	26238	Economy	62100.00
0005433784356	26238	Economy	62100.00
0005434170903	26238	Economy	62100.00
0005434170901	26238	Economy	62100.00
0005434271289	26238	Economy	62100.00
0005435135617	4905	Economy	5300.00
0005435929602	4905	Economy	5300.00
0005435135618	4905	Economy	5300.00
0005435135619	4905	Economy	5300.00
0005435135620	4905	Economy	5300.00
0005435135621	4905	Economy	5300.00
0005435929601	4905	Economy	5300.00
0005435929616	33006	Economy	5900.00
0005435929615	33006	Economy	5300.00
0005435135595	33006	Economy	5300.00
0005435135588	33006	Economy	5300.00
0005435929614	33006	Economy	5300.00
0005435135587	33006	Economy	5300.00
0005434217907	9469	Economy	19700.00
0005434983235	9469	Economy	17900.00
0005434217897	9469	Economy	17900.00
0005434983234	9469	Economy	17900.00
0005434983232	9469	Economy	17900.00
0005434983233	9469	Economy	17900.00
0005434983231	9469	Economy	17900.00
0005434217898	9469	Economy	17900.00
0005434217906	9469	Economy	17900.00
0005434217905	9469	Economy	17900.00
0005434983207	27355	Economy	19700.00
0005434217925	27355	Economy	17900.00
0005434983206	27355	Economy	17900.00
0005434217926	27355	Economy	17900.00
0005434217927	27355	Economy	17900.00
0005434983202	27355	Economy	17900.00
0005434983203	27355	Economy	17900.00
0005433960218	25929	Business	36400.00
0005433960267	25929	Business	36400.00
0005433985447	25929	Business	36400.00
0005433985418	25929	Business	36400.00
0005433985459	25929	Business	36400.00
0005433960230	25929	Business	36400.00
0005433960219	25929	Business	36400.00
0005433985428	25929	Business	36400.00
0005433985438	25929	Business	36400.00
0005433985442	25929	Business	36400.00
0005433985446	25929	Business	36400.00
0005433985417	25929	Business	36400.00
0005433960248	25929	Business	36400.00
0005433960226	25929	Business	36400.00
0005433960255	25929	Business	36400.00
0005433960225	25929	Business	36400.00
0005433960220	25929	Economy	13400.00
0005433960247	25929	Economy	13400.00
0005433960234	25929	Economy	13400.00
0005433960261	25929	Economy	12100.00
0005433960214	25929	Economy	12100.00
0005433985458	25929	Economy	12100.00
0005433960253	25929	Economy	12100.00
0005433960244	25929	Economy	12100.00
0005433985461	25929	Economy	12100.00
0005433960240	25929	Economy	12100.00
0005433960243	25929	Economy	12100.00
0005433985454	25929	Economy	12100.00
0005433960242	25929	Economy	12100.00
0005433960233	25929	Economy	12100.00
0005433960212	25929	Economy	12100.00
0005433985415	25929	Economy	12100.00
0005433985411	25929	Economy	12100.00
0005433960251	25929	Economy	12100.00
0005433960213	25929	Economy	12100.00
0005433960231	25929	Economy	12100.00
0005433985410	25929	Economy	12100.00
0005433960236	25929	Economy	12100.00
0005433985433	25929	Economy	12100.00
0005433985427	25929	Economy	12100.00
0005433960209	25929	Economy	12100.00
0005433985413	25929	Economy	12100.00
0005433960235	25929	Economy	12100.00
0005433985432	25929	Economy	12100.00
0005433985420	25929	Economy	12100.00
0005433985441	25929	Economy	12100.00
0005433960263	25929	Economy	12100.00
0005433960215	25929	Economy	12100.00
0005433960227	25929	Economy	12100.00
0005433985416	25929	Economy	12100.00
0005433960250	25929	Economy	12100.00
0005433985414	25929	Economy	12100.00
0005433960254	25929	Economy	12100.00
0005433985436	25929	Economy	12100.00
0005433985457	25929	Economy	12100.00
0005433985445	25929	Economy	12100.00
0005433960249	25929	Economy	12100.00
0005433960260	25929	Economy	12100.00
0005433960262	25929	Economy	12100.00
0005433960258	25929	Economy	12100.00
0005433960265	25929	Economy	12100.00
0005433985409	25929	Economy	12100.00
0005433985453	25929	Economy	12100.00
0005433985440	25929	Economy	12100.00
0005433960223	25929	Economy	12100.00
0005433960221	25929	Economy	12100.00
0005433960257	25929	Economy	12100.00
0005433960217	25929	Economy	12100.00
0005433960241	25929	Economy	12100.00
0005433960239	25929	Economy	12100.00
0005433985422	25929	Economy	12100.00
0005433985439	25929	Economy	12100.00
0005433985462	25929	Economy	12100.00
0005433985448	25929	Economy	12100.00
0005433960256	25929	Economy	12100.00
0005433985426	25929	Economy	13400.00
0005433985451	25929	Economy	12100.00
0005433960224	25929	Economy	12100.00
0005433985443	25929	Economy	12100.00
0005433960222	25929	Economy	12100.00
0005433985435	25929	Economy	12100.00
0005433985429	25929	Economy	12100.00
0005433985419	25929	Economy	12100.00
0005433960264	25929	Economy	12100.00
0005433960238	25929	Economy	12100.00
0005433960259	25929	Economy	12100.00
0005433985412	25929	Economy	12100.00
0005433985425	25929	Economy	12100.00
0005433960211	25929	Economy	12100.00
0005433960245	25929	Economy	12100.00
0005433960216	25929	Economy	12100.00
0005433985449	25929	Economy	12100.00
0005433985444	25929	Economy	12100.00
0005433960229	25929	Economy	12100.00
0005433985408	25929	Economy	12100.00
0005433960246	25929	Economy	12100.00
0005433985423	25929	Economy	12100.00
0005433960210	25929	Economy	12100.00
0005433985431	25929	Economy	12100.00
0005433985430	25929	Economy	12100.00
0005433960237	25929	Economy	12100.00
0005433985463	25929	Economy	12100.00
0005433985424	25929	Economy	12100.00
0005433960232	25929	Economy	12100.00
0005433985456	25929	Economy	12100.00
0005433960266	25929	Economy	12100.00
0005433985434	25929	Economy	12100.00
0005433985460	25929	Economy	12100.00
0005433985437	25929	Economy	12100.00
0005433960252	25929	Economy	12100.00
0005433985421	25929	Economy	12100.00
0005433985450	25929	Economy	12100.00
0005433985452	25929	Economy	12100.00
0005433985455	25929	Economy	12100.00
0005433960228	25929	Economy	12100.00
0005434480077	938	Economy	25400.00
0005434480081	938	Economy	25400.00
0005434480062	938	Economy	25400.00
0005434480063	938	Economy	25400.00
0005434480061	938	Economy	23100.00
0005434480078	938	Economy	23100.00
0005434480070	938	Economy	23100.00
0005434480072	938	Economy	23100.00
0005434480069	938	Economy	23100.00
0005434480076	938	Economy	23100.00
0005434480075	938	Economy	23100.00
0005434480057	938	Economy	23100.00
0005432269465	938	Economy	23100.00
0005434480056	938	Economy	23100.00
0005434480060	938	Economy	23100.00
0005434480065	938	Economy	23100.00
0005434480064	938	Economy	23100.00
0005434480074	938	Economy	23100.00
0005433165676	938	Economy	23100.00
0005434480059	938	Economy	23100.00
0005434480058	938	Economy	23100.00
0005432269466	938	Economy	23100.00
0005432269467	938	Economy	23100.00
0005434480071	938	Economy	23100.00
0005433165700	938	Economy	23100.00
0005434480079	938	Economy	23100.00
0005434480067	938	Economy	23100.00
0005434480068	938	Economy	23100.00
0005433165686	938	Economy	23100.00
0005433165675	938	Economy	23100.00
0005433165680	938	Economy	23100.00
0005434480080	938	Economy	23100.00
0005433165679	938	Economy	23100.00
0005433165701	938	Economy	23100.00
0005433165687	938	Economy	23100.00
0005434480073	938	Economy	23100.00
0005434480066	938	Economy	23100.00
0005434479905	16553	Economy	25400.00
0005434479878	16553	Economy	25400.00
0005433165765	16553	Economy	23100.00
0005433165769	16553	Economy	23100.00
0005433165766	16553	Economy	23100.00
0005434479903	16553	Economy	23100.00
0005433165771	16553	Economy	23100.00
0005434479926	16553	Economy	23100.00
0005433165767	16553	Economy	23100.00
0005433165774	16553	Economy	23100.00
0005433165773	16553	Economy	23100.00
0005433165768	16553	Economy	23100.00
0005434479896	16553	Economy	23100.00
0005433165772	16553	Economy	23100.00
0005433165770	16553	Economy	23100.00
0005433165775	16553	Economy	23100.00
0005433165764	16553	Economy	23100.00
0005434479892	16553	Economy	23100.00
0005433165763	16553	Economy	23100.00
0005434479879	16553	Economy	23100.00
0005434479901	16553	Economy	23100.00
0005434479904	16553	Economy	23100.00
0005434479880	16553	Economy	23100.00
0005433872447	3198	Economy	17200.00
0005433872452	3198	Economy	17200.00
0005433872448	3198	Economy	17200.00
0005433872444	3198	Economy	17200.00
0005433872446	3198	Economy	17200.00
0005433872449	3198	Economy	17200.00
0005433872451	3198	Economy	17200.00
0005433872443	3198	Economy	17200.00
0005433872450	3198	Economy	17200.00
0005433872445	3198	Economy	17200.00
0005433872453	3198	Economy	17200.00
0005433872427	32536	Economy	17200.00
0005433872426	32536	Economy	17200.00
0005433872439	32536	Economy	17200.00
0005435142431	10374	Economy	17000.00
0005435149874	10374	Economy	17000.00
0005435149876	10374	Economy	15400.00
0005435149872	10374	Economy	15400.00
0005435386461	10374	Economy	15400.00
0005435142425	10374	Economy	15400.00
0005435149877	10374	Economy	15400.00
0005435142424	10374	Economy	15400.00
0005435149870	10374	Economy	15400.00
0005435149881	10374	Economy	15400.00
0005435149880	10374	Economy	15400.00
0005435142428	10374	Economy	15400.00
0005435149884	10374	Economy	15400.00
0005435386462	10374	Economy	15400.00
0005435149875	10374	Economy	15400.00
0005435149878	10374	Economy	15400.00
0005435142427	10374	Economy	15400.00
0005435142418	10374	Economy	15400.00
0005435142420	10374	Economy	15400.00
0005435149879	10374	Economy	15400.00
0005435142422	10374	Economy	15400.00
0005435142423	10374	Economy	15400.00
0005435149882	10374	Economy	15400.00
0005435149883	10374	Economy	15400.00
0005435142421	10374	Economy	15400.00
0005435149871	10374	Economy	15400.00
0005435142419	10374	Economy	15400.00
0005435149873	10374	Economy	15400.00
0005435142429	10374	Economy	15400.00
0005435142430	10374	Economy	15400.00
0005435142426	10374	Economy	15400.00
0005435142335	21910	Economy	17000.00
0005433289780	21910	Economy	15400.00
0005433289784	21910	Economy	15400.00
0005435386504	21910	Economy	15400.00
0005435386506	21910	Economy	15400.00
0005435386509	21910	Economy	15400.00
0005433289782	21910	Economy	15400.00
0005433289779	21910	Economy	15400.00
0005435386508	21910	Economy	15400.00
0005435386507	21910	Economy	15400.00
0005433289777	21910	Economy	15400.00
0005435142342	21910	Economy	15400.00
0005435386510	21910	Economy	15400.00
0005433289785	21910	Economy	15400.00
0005433289781	21910	Economy	15400.00
0005433289776	21910	Economy	15400.00
0005435386505	21910	Economy	15400.00
0005435142362	21910	Economy	15400.00
0005433289778	21910	Economy	15400.00
0005433289783	21910	Economy	15400.00
0005434573196	11224	Business	57200.00
0005434573202	11224	Economy	19100.00
0005434573188	11224	Economy	19100.00
0005434573197	11224	Economy	19100.00
0005434573195	11224	Economy	21000.00
0005435501991	11224	Economy	19100.00
0005435501951	11224	Economy	19100.00
0005435319423	11224	Economy	19100.00
0005434573190	11224	Economy	19100.00
0005434573200	11224	Economy	19100.00
0005435528893	11224	Economy	19100.00
0005435501945	11224	Economy	19100.00
0005434573191	11224	Economy	19100.00
0005435501970	11224	Economy	19100.00
0005435528882	11224	Economy	19100.00
0005434573198	11224	Economy	19100.00
0005434573199	11224	Economy	19100.00
0005435528900	11224	Economy	19100.00
0005434573189	11224	Economy	19100.00
0005435528899	11224	Economy	19100.00
0005434573192	11224	Economy	19100.00
0005435501985	11224	Economy	19100.00
0005435501971	11224	Economy	19100.00
0005434573201	11224	Economy	19100.00
0005434573194	11224	Economy	19100.00
0005434573193	11224	Economy	19100.00
0005435528908	11224	Economy	19100.00
0005435502072	20913	Business	57200.00
0005435517716	20913	Business	57200.00
0005435517729	20913	Business	57200.00
0005434573129	20913	Business	57200.00
0005435502085	20913	Business	57200.00
0005435502067	20913	Business	57200.00
0005435502068	20913	Business	57200.00
0005435517721	20913	Business	57200.00
0005435319496	20913	Business	57200.00
0005435517719	20913	Economy	19100.00
0005434573127	20913	Economy	19100.00
0005435517712	20913	Economy	19100.00
0005435517727	20913	Economy	19100.00
0005435319490	20913	Economy	19100.00
0005435517720	20913	Economy	19100.00
0005435508232	20913	Economy	19100.00
0005435508233	20913	Economy	19100.00
0005435517723	20913	Economy	19100.00
0005435517718	20913	Economy	19100.00
0005435502080	20913	Economy	21000.00
0005434573109	20913	Economy	21000.00
0005435502083	20913	Economy	21000.00
0005435502076	20913	Economy	21000.00
0005435508234	20913	Economy	19100.00
0005435517724	20913	Economy	19100.00
0005435508231	20913	Economy	19100.00
0005435319493	20913	Economy	19100.00
0005435502082	20913	Economy	19100.00
0005435502065	20913	Economy	19100.00
0005435502084	20913	Economy	19100.00
0005435502081	20913	Economy	19100.00
0005435508229	20913	Economy	19100.00
0005435508230	20913	Economy	19100.00
0005435502078	20913	Economy	19100.00
0005435517717	20913	Economy	19100.00
0005434573126	20913	Economy	19100.00
0005435517711	20913	Economy	19100.00
0005435319491	20913	Economy	19100.00
0005435319487	20913	Economy	19100.00
0005435502066	20913	Economy	19100.00
0005434573110	20913	Economy	19100.00
0005435502071	20913	Economy	19100.00
0005432291904	20913	Economy	19100.00
0005435502077	20913	Economy	19100.00
0005435517715	20913	Economy	19100.00
0005435502074	20913	Economy	19100.00
0005434573128	20913	Economy	19100.00
0005435319492	20913	Economy	19100.00
0005435517722	20913	Economy	19100.00
0005435502079	20913	Economy	19100.00
0005435502069	20913	Economy	19100.00
0005435502070	20913	Economy	19100.00
0005435517714	20913	Economy	19100.00
0005435319489	20913	Economy	19100.00
0005434573124	20913	Economy	19100.00
0005435517725	20913	Economy	19100.00
0005435517713	20913	Economy	19100.00
0005435502064	20913	Economy	19100.00
0005434573125	20913	Economy	19100.00
0005435502075	20913	Economy	19100.00
0005435319494	20913	Economy	19100.00
0005435319495	20913	Economy	19100.00
0005435517730	20913	Economy	19100.00
0005432291903	20913	Economy	19100.00
0005435517731	20913	Economy	19100.00
0005435517726	20913	Economy	19100.00
0005435517728	20913	Economy	19100.00
0005435502073	20913	Economy	19100.00
0005434573119	20913	Economy	19100.00
0005435319488	20913	Economy	19100.00
0005433927396	24308	Economy	18800.00
0005433683309	24308	Economy	17100.00
0005433683310	24308	Economy	17100.00
0005433683302	24308	Economy	17100.00
0005433683301	24308	Economy	17100.00
0005433927395	24308	Economy	17100.00
0005433683307	24308	Economy	17100.00
0005433683308	24308	Economy	17100.00
0005433683311	24308	Economy	17100.00
0005433683305	24308	Economy	17100.00
0005433927397	24308	Economy	17100.00
0005433683303	24308	Economy	17100.00
0005433683304	24308	Economy	17100.00
0005433683306	24308	Economy	17100.00
0005433927406	29283	Economy	17100.00
0005433927411	29283	Economy	17100.00
0005433927409	29283	Economy	17100.00
0005433927416	29283	Economy	17100.00
0005433683292	29283	Economy	17100.00
0005433927413	29283	Economy	17100.00
0005433683291	29283	Economy	17100.00
0005433927415	29283	Economy	17100.00
0005433927407	29283	Economy	17100.00
0005433683293	29283	Economy	17100.00
0005433927412	29283	Economy	17100.00
0005433927408	29283	Economy	17100.00
0005433683290	29283	Economy	17100.00
0005433927410	29283	Economy	17100.00
0005433927414	29283	Economy	17100.00
0005432692541	3003	Business	10300.00
0005432692581	3003	Economy	3400.00
0005432692536	3003	Economy	3800.00
0005432692563	3003	Economy	3400.00
0005432692542	3003	Economy	3400.00
0005432706514	3004	Business	10300.00
0005432706497	3004	Business	10300.00
0005433123579	3004	Business	10300.00
0005432706503	3004	Business	10300.00
0005432706508	3004	Economy	3400.00
0005432217746	3004	Economy	3400.00
0005432706494	3004	Economy	3400.00
0005432706504	3004	Economy	3400.00
0005433123578	3004	Economy	3800.00
0005432706515	3004	Economy	3800.00
0005432706498	3004	Economy	3800.00
0005432217747	3004	Economy	3400.00
0005433123583	3004	Economy	3400.00
0005433123585	3004	Economy	3400.00
0005433194817	3004	Economy	3400.00
0005432217745	3004	Economy	3400.00
0005432706495	3004	Economy	3400.00
0005432706490	3004	Economy	3400.00
0005432706502	3004	Economy	3400.00
0005432706513	3004	Economy	3400.00
0005432706507	3004	Economy	3400.00
0005432706491	3004	Economy	3400.00
0005432706500	3004	Economy	3400.00
0005433123568	3004	Economy	3400.00
0005432706496	3004	Economy	3400.00
0005432706511	3004	Economy	3400.00
0005433123584	3004	Economy	3400.00
0005432706505	3004	Economy	3400.00
0005432706492	3004	Economy	3400.00
0005432706499	3004	Economy	3400.00
0005432706510	3004	Economy	3400.00
0005432706516	3004	Economy	3400.00
0005433123572	3004	Economy	3400.00
0005432706501	3004	Economy	3400.00
0005432706493	3004	Economy	3400.00
0005432706512	3004	Economy	3400.00
0005432706517	3004	Economy	3400.00
0005432706506	3004	Economy	3400.00
0005432706509	3004	Economy	3400.00
0005433123610	3004	Economy	3400.00
0005433123569	3004	Economy	3400.00
0005433123706	30013	Business	10300.00
0005432880660	30013	Business	10300.00
0005432706396	30013	Business	10300.00
0005433123703	30013	Business	10300.00
0005432692777	30013	Business	10300.00
0005432706326	30013	Business	10300.00
0005432880658	30013	Business	10300.00
0005432692767	30013	Business	10300.00
0005432706340	30013	Business	10300.00
0005432692773	30013	Business	10300.00
0005432706354	30013	Economy	3400.00
0005432706332	30013	Economy	3400.00
0005432692758	30013	Economy	3400.00
0005432880669	30013	Economy	3400.00
0005432880667	30013	Economy	3400.00
0005432692766	30013	Economy	3400.00
0005433123702	30013	Economy	3400.00
0005432692763	30013	Economy	3400.00
0005432692775	30013	Economy	3800.00
0005432880656	30013	Economy	3800.00
0005432692762	30013	Economy	3800.00
0005432692749	30013	Economy	3400.00
0005432706338	30013	Economy	3400.00
0005432692778	30013	Economy	3400.00
0005432706331	30013	Economy	3400.00
0005432692771	30013	Economy	3400.00
0005432692755	30013	Economy	3400.00
0005432692764	30013	Economy	3400.00
0005432706359	30013	Economy	3400.00
0005432692752	30013	Economy	3400.00
0005432880670	30013	Economy	3400.00
0005432692765	30013	Economy	3400.00
0005432706380	30013	Economy	3400.00
0005432692759	30013	Economy	3400.00
0005432880663	30013	Economy	3400.00
0005432880668	30013	Economy	3400.00
0005433123704	30013	Economy	3400.00
0005432880657	30013	Economy	3400.00
0005432706382	30013	Economy	3400.00
0005433123709	30013	Economy	3400.00
0005432706339	30013	Economy	3400.00
0005432692770	30013	Economy	3400.00
0005432692772	30013	Economy	3400.00
0005433123701	30013	Economy	3400.00
0005432692760	30013	Economy	3400.00
0005433123710	30013	Economy	3400.00
0005433123712	30013	Economy	3400.00
0005432692779	30013	Economy	3400.00
0005433123705	30013	Economy	3400.00
0005432880664	30013	Economy	3400.00
0005432692748	30013	Economy	3400.00
0005432880665	30013	Economy	3400.00
0005432692774	30013	Economy	3400.00
0005432692776	30013	Economy	3400.00
0005433123707	30013	Economy	3400.00
0005432880661	30013	Economy	3400.00
0005432880659	30013	Economy	3400.00
0005432692768	30013	Economy	3400.00
0005432880666	30013	Economy	3400.00
0005432692754	30013	Economy	3400.00
0005432692750	30013	Economy	3400.00
0005432706362	30013	Economy	3400.00
0005432692769	30013	Economy	3400.00
0005432706383	30013	Economy	3400.00
0005432692751	30013	Economy	3400.00
0005432692761	30013	Economy	3400.00
0005432706358	30013	Economy	3400.00
0005433123711	30013	Economy	3400.00
0005433123708	30013	Economy	3400.00
0005433123699	30013	Economy	3400.00
0005432692757	30013	Economy	3400.00
0005432706355	30013	Economy	3400.00
0005432692753	30013	Economy	3400.00
0005432880662	30013	Economy	3400.00
0005432706363	30013	Economy	3400.00
0005433123700	30013	Economy	3400.00
0005432692756	30013	Economy	3400.00
0005432706381	30013	Economy	3400.00
0005433123713	30013	Economy	3400.00
0005434988610	23655	Economy	4000.00
0005434988616	23655	Economy	4000.00
0005434979450	23655	Economy	4000.00
0005434979461	23655	Economy	3600.00
0005434979443	23655	Economy	3600.00
0005434988611	23655	Economy	3600.00
0005434979454	23655	Economy	3600.00
0005434979462	23655	Economy	3600.00
0005434979466	23655	Economy	3600.00
0005434988619	23655	Economy	3600.00
0005434979464	23655	Economy	3600.00
0005434979441	23655	Economy	3600.00
0005434988608	23655	Economy	3600.00
0005434988620	23655	Economy	3600.00
0005434979446	23655	Economy	3600.00
0005434979445	23655	Economy	3600.00
0005434979439	23655	Economy	3600.00
0005434979452	23655	Economy	3600.00
0005434979459	23655	Economy	3600.00
0005434988612	23655	Economy	3600.00
0005434979458	23655	Economy	3600.00
0005434979460	23655	Economy	3600.00
0005434979447	23655	Economy	3600.00
0005434979465	23655	Economy	3600.00
0005434988617	23655	Economy	3600.00
0005434988613	23655	Economy	3600.00
0005434988609	23655	Economy	3600.00
0005434979442	23655	Economy	3600.00
0005434979437	23655	Economy	3600.00
0005434979444	23655	Economy	3600.00
0005434979455	23655	Economy	3600.00
0005434979438	23655	Economy	3600.00
0005434979448	23655	Economy	3600.00
0005434988621	23655	Economy	3600.00
0005434979456	23655	Economy	3600.00
0005434979449	23655	Economy	3600.00
0005434979457	23655	Economy	3600.00
0005434988618	23655	Economy	3600.00
0005434979440	23655	Economy	3600.00
0005434988614	23655	Economy	3600.00
0005434979451	23655	Economy	3600.00
0005434988615	23655	Economy	3600.00
0005434979463	23655	Economy	3600.00
0005434979453	23655	Economy	3600.00
0005434979253	27558	Economy	3600.00
0005434979363	27558	Economy	3600.00
0005434979299	27558	Economy	3600.00
0005434979331	27558	Economy	3600.00
0005434979254	27558	Economy	3600.00
0005434979362	27558	Economy	3600.00
0005434979260	27558	Economy	3600.00
0005434979283	27558	Economy	3600.00
0005434979337	27558	Economy	3600.00
0005434302412	10246	Economy	19700.00
0005434302409	10246	Economy	19700.00
0005434302410	10246	Economy	19700.00
0005434302408	10246	Economy	19700.00
0005434302411	10246	Economy	19700.00
0005434302390	19635	Economy	19700.00
0005433113511	19635	Economy	19700.00
0005434302389	19635	Economy	19700.00
0005434302385	19635	Economy	19700.00
0005433113512	19635	Economy	19700.00
0005435068545	3579	Business	26900.00
0005435068559	3579	Business	26900.00
0005435068549	3579	Business	26900.00
0005435068570	3579	Business	26900.00
0005435068565	3579	Business	26900.00
0005435718884	3579	Business	26900.00
0005435718881	3579	Business	26900.00
0005435068560	3579	Economy	9000.00
0005435068563	3579	Economy	9000.00
0005435068555	3579	Economy	9000.00
0005435068542	3579	Economy	9000.00
0005435068574	3579	Economy	9000.00
0005435068558	3579	Economy	9900.00
0005435068553	3579	Economy	9900.00
0005435068539	3579	Economy	9900.00
0005435068530	3579	Economy	9900.00
0005435068534	3579	Economy	9000.00
0005435718883	3579	Economy	9000.00
0005435068564	3579	Economy	9000.00
0005435068547	3579	Economy	9000.00
0005435718882	3579	Economy	9000.00
0005435068552	3579	Economy	9000.00
0005435718879	3579	Economy	9000.00
0005435068538	3579	Economy	9000.00
0005435068531	3579	Economy	9000.00
0005435068568	3579	Economy	9000.00
0005435068579	3579	Economy	9000.00
0005435068576	3579	Economy	9000.00
0005435068544	3579	Economy	9000.00
0005435068537	3579	Economy	9000.00
0005435068577	3579	Economy	9000.00
0005435068567	3579	Economy	9000.00
0005435068533	3579	Economy	9000.00
0005435068581	3579	Economy	9000.00
0005435068548	3579	Economy	9000.00
0005435718880	3579	Economy	9000.00
0005435068529	3579	Economy	9000.00
0005435068543	3579	Economy	9000.00
0005435068554	3579	Economy	9000.00
0005435068572	3579	Economy	9000.00
0005435068573	3579	Economy	9000.00
0005435068536	3579	Economy	9000.00
0005435068569	3579	Economy	9000.00
0005435068561	3579	Economy	9000.00
0005435068546	3579	Economy	9000.00
0005435068541	3579	Economy	9000.00
0005435068571	3579	Economy	9000.00
0005435068540	3579	Economy	9000.00
0005435068551	3579	Economy	9000.00
0005435068575	3579	Economy	9000.00
0005435068566	3579	Economy	9000.00
0005435068550	3579	Economy	9000.00
0005435068562	3579	Economy	9000.00
0005435068532	3579	Economy	9000.00
0005435068557	3579	Economy	9000.00
0005435068535	3579	Economy	9000.00
0005435068580	3579	Economy	9000.00
0005435068556	3579	Economy	9000.00
0005435068578	3579	Economy	9000.00
0005435068217	15289	Business	26900.00
0005435068266	15289	Business	26900.00
0005435068267	15289	Business	26900.00
0005435925148	15289	Economy	9000.00
0005435068172	15289	Economy	9900.00
0005435925151	15289	Economy	9000.00
0005435925149	15289	Economy	9000.00
0005435939864	15289	Economy	9000.00
0005435068286	15289	Economy	9000.00
0005435925152	15289	Economy	9000.00
0005435925150	15289	Economy	9000.00
0005435068192	15289	Economy	9000.00
0005435068275	15289	Economy	9000.00
0005435068193	15289	Economy	9000.00
0005435068256	15289	Economy	9000.00
0005435925153	15289	Economy	9000.00
0005435925154	15289	Economy	9000.00
0005435068218	15289	Economy	9000.00
0005432660796	18149	Economy	5900.00
0005432660795	18149	Economy	5900.00
0005432658571	18149	Economy	5900.00
0005432659685	18149	Economy	5900.00
0005432658570	18149	Economy	5900.00
0005432658568	18149	Economy	5900.00
0005432659684	18149	Economy	5900.00
0005432658569	18149	Economy	5900.00
0005432157471	153	Business	20000.00
0005432901369	153	Business	20000.00
0005432677509	153	Business	20000.00
0005433101170	153	Business	20000.00
0005432157472	153	Business	20000.00
0005432919535	153	Business	20000.00
0005433101152	153	Economy	7300.00
0005432919528	153	Economy	6700.00
0005433101159	153	Economy	6700.00
0005432919527	153	Economy	6700.00
0005432901295	153	Economy	6700.00
0005432901346	153	Economy	6700.00
0005432901302	153	Economy	6700.00
0005432901317	153	Economy	6700.00
0005432901306	153	Economy	6700.00
0005433101158	153	Economy	6700.00
0005432901305	153	Economy	6700.00
0005432901381	153	Economy	6700.00
0005432391947	153	Economy	6700.00
0005432901361	153	Economy	6700.00
0005432901319	153	Economy	6700.00
0005432677508	153	Economy	7300.00
0005432901301	153	Economy	7300.00
0005432919529	153	Economy	6700.00
0005432901316	153	Economy	6700.00
0005432391946	153	Economy	6700.00
0005432919562	153	Economy	6700.00
0005433101160	153	Economy	6700.00
0005432901356	153	Economy	6700.00
0005432901370	153	Economy	6700.00
0005432901380	153	Economy	6700.00
0005433101153	153	Economy	6700.00
0005432901293	153	Economy	6700.00
0005432677510	153	Economy	6700.00
0005433101155	153	Economy	6700.00
0005432817169	152	Business	20000.00
0005432817162	152	Business	20000.00
0005432817168	152	Business	20000.00
0005432817171	152	Business	20000.00
0005432817165	152	Business	20000.00
0005432261428	152	Business	20000.00
0005432261425	152	Business	20000.00
0005432817178	152	Business	20000.00
0005432261421	152	Business	20000.00
0005432261446	152	Business	20000.00
0005432261437	152	Business	20000.00
0005432817160	152	Business	20000.00
0005432817175	152	Business	20000.00
0005432261435	152	Business	20000.00
0005432261441	152	Economy	7300.00
0005432261433	152	Economy	7300.00
0005432817177	152	Economy	7300.00
0005432261415	152	Economy	6700.00
0005432261452	152	Economy	6700.00
0005432817176	152	Economy	6700.00
0005432261416	152	Economy	6700.00
0005432261423	152	Economy	6700.00
0005432817151	152	Economy	6700.00
0005432817153	152	Economy	6700.00
0005432261454	152	Economy	6700.00
0005432817152	152	Economy	6700.00
0005432261432	152	Economy	6700.00
0005432261427	152	Economy	6700.00
0005432261419	152	Economy	6700.00
0005432288953	152	Economy	6700.00
0005432207633	152	Economy	6700.00
0005432261451	152	Economy	6700.00
0005432261429	152	Economy	6700.00
0005432261447	152	Economy	6700.00
0005432261438	152	Economy	6700.00
0005432261444	152	Economy	6700.00
0005432817150	152	Economy	6700.00
0005432261443	152	Economy	6700.00
0005432261453	152	Economy	6700.00
0005432261436	152	Economy	6700.00
0005432817170	152	Economy	6700.00
0005432261422	152	Economy	6700.00
0005432261455	152	Economy	6700.00
0005432817155	152	Economy	6700.00
0005434153522	152	Economy	6700.00
0005432817154	152	Economy	6700.00
0005432817161	152	Economy	6700.00
0005432261426	152	Economy	6700.00
0005432261439	152	Economy	6700.00
0005432288952	152	Economy	6700.00
0005432261440	152	Economy	7300.00
0005432261418	152	Economy	7300.00
0005432817164	152	Economy	7300.00
0005432261457	152	Economy	6700.00
0005432817156	152	Economy	6700.00
0005432261459	152	Economy	6700.00
0005434153521	152	Economy	6700.00
0005432817173	152	Economy	6700.00
0005432817167	152	Economy	6700.00
0005432261449	152	Economy	6700.00
0005432261460	152	Economy	6700.00
0005432207632	152	Economy	6700.00
0005432288951	152	Economy	6700.00
0005432261431	152	Economy	6700.00
0005432817163	152	Economy	6700.00
0005432261442	152	Economy	6700.00
0005434153523	152	Economy	6700.00
0005432261434	152	Economy	6700.00
0005432261445	152	Economy	6700.00
0005432261456	152	Economy	6700.00
0005432817172	152	Economy	6700.00
0005432261424	152	Economy	6700.00
0005432261450	152	Economy	6700.00
0005432261458	152	Economy	6700.00
0005432817159	152	Economy	6700.00
0005432261420	152	Economy	6700.00
0005432817179	152	Economy	6700.00
0005432261448	152	Economy	6700.00
0005432817158	152	Economy	6700.00
0005432817166	152	Economy	6700.00
0005432817174	152	Economy	6700.00
0005432817157	152	Economy	6700.00
0005432261430	152	Economy	6700.00
0005432261417	152	Economy	6700.00
0005432919643	7968	Business	20000.00
0005433101615	7968	Business	20000.00
0005432919645	7968	Business	20000.00
0005432919647	7968	Business	20000.00
0005432677534	7968	Business	20000.00
0005432019989	7968	Business	20000.00
0005432019977	7968	Business	20000.00
0005432019985	7968	Business	20000.00
0005432919652	7968	Business	20000.00
0005432919648	7968	Business	20000.00
0005433101598	7968	Business	20000.00
0005433101602	7968	Business	20000.00
0005433101614	7968	Business	20000.00
0005433101592	7968	Business	20000.00
0005432019976	7968	Business	20000.00
0005432019987	7968	Business	20000.00
0005432919636	7968	Business	20000.00
0005432019988	7968	Business	20000.00
0005432919650	7968	Economy	7300.00
0005432919641	7968	Economy	7300.00
0005432919631	7968	Economy	7300.00
0005432019974	7968	Economy	7300.00
0005433101616	7968	Economy	6700.00
0005433101600	7968	Economy	6700.00
0005432019998	7968	Economy	6700.00
0005432391969	7968	Economy	6700.00
0005432751493	7968	Economy	6700.00
0005432919653	7968	Economy	6700.00
0005432919635	7968	Economy	6700.00
0005432919646	7968	Economy	6700.00
0005433101594	7968	Economy	6700.00
0005432919634	7968	Economy	6700.00
0005432391968	7968	Economy	6700.00
0005432019993	7968	Economy	6700.00
0005433101610	7968	Economy	6700.00
0005432677533	7968	Economy	6700.00
0005432677535	7968	Economy	6700.00
0005433101596	7968	Economy	6700.00
0005432751492	7968	Economy	6700.00
0005432019990	7968	Economy	6700.00
0005433101608	7968	Economy	6700.00
0005432019994	7968	Economy	6700.00
0005433101590	7968	Economy	6700.00
0005432019973	7968	Economy	6700.00
0005433101595	7968	Economy	6700.00
0005432753266	7968	Economy	6700.00
0005432019992	7968	Economy	6700.00
0005432919640	7968	Economy	6700.00
0005432919638	7968	Economy	6700.00
0005432391967	7968	Economy	6700.00
0005432019978	7968	Economy	6700.00
0005433101589	7968	Economy	6700.00
0005432919633	7968	Economy	6700.00
0005432044497	7968	Economy	6700.00
0005432045595	7968	Economy	6700.00
0005432677536	7968	Economy	6700.00
0005432753268	7968	Economy	6700.00
0005432019972	7968	Economy	6700.00
0005433101606	7968	Economy	6700.00
0005432919642	7968	Economy	7300.00
0005433101593	7968	Economy	7300.00
0005432019995	7968	Economy	6700.00
0005433101604	7968	Economy	6700.00
0005432919649	7968	Economy	6700.00
0005433101601	7968	Economy	6700.00
0005432919639	7968	Economy	6700.00
0005433101591	7968	Economy	6700.00
0005432753267	7968	Economy	6700.00
0005432019984	7968	Economy	6700.00
0005432919644	7968	Economy	6700.00
0005433101609	7968	Economy	6700.00
0005432019983	7968	Economy	6700.00
0005432919632	7968	Economy	6700.00
0005433101603	7968	Economy	6700.00
0005433101617	7968	Economy	6700.00
0005433101611	7968	Economy	6700.00
0005432019980	7968	Economy	6700.00
0005432045593	7968	Economy	6700.00
0005433101618	7968	Economy	6700.00
0005433101613	7968	Economy	6700.00
0005432019975	7968	Economy	6700.00
0005433101619	7968	Economy	6700.00
0005433101605	7968	Economy	6700.00
0005432019971	7968	Economy	6700.00
0005433101597	7968	Economy	6700.00
0005432019986	7968	Economy	6700.00
0005432044496	7968	Economy	6700.00
0005433101607	7968	Economy	6700.00
0005433101599	7968	Economy	6700.00
0005432019982	7968	Economy	6700.00
0005432019997	7968	Economy	6700.00
0005432045594	7968	Economy	6700.00
0005432019991	7968	Economy	6700.00
0005432019996	7968	Economy	6700.00
0005432919651	7968	Economy	6700.00
0005433101612	7968	Economy	6700.00
0005432919637	7968	Economy	6700.00
0005432019981	7968	Economy	6700.00
0005432019979	7968	Economy	6700.00
0005432044495	7968	Economy	6700.00
0005432817061	8021	Business	20000.00
0005432901425	8021	Business	20000.00
0005432901423	8021	Business	20000.00
0005434513536	8021	Economy	7300.00
0005432816964	8021	Economy	6700.00
0005432901434	8021	Economy	6700.00
0005434513533	8021	Economy	6700.00
0005432901429	8021	Economy	6700.00
0005432816944	8021	Economy	6700.00
0005432901435	8021	Economy	6700.00
0005432817042	8021	Economy	6700.00
0005432901427	8021	Economy	6700.00
0005432816954	8021	Economy	6700.00
0005432901433	8021	Economy	6700.00
0005432816952	8021	Economy	6700.00
0005432901424	8021	Economy	6700.00
0005434513534	8021	Economy	7300.00
0005432816953	8021	Economy	6700.00
0005432901422	8021	Economy	6700.00
0005432002055	8021	Economy	6700.00
0005432901420	8021	Economy	6700.00
0005432901426	8021	Economy	6700.00
0005432901430	8021	Economy	6700.00
0005432901421	8021	Economy	6700.00
0005432817041	8021	Economy	6700.00
0005432816955	8021	Economy	6700.00
0005434513535	8021	Economy	6700.00
0005432901419	8021	Economy	6700.00
0005432901431	8021	Economy	6700.00
0005432901432	8021	Economy	6700.00
0005432817000	8021	Economy	6700.00
0005432817067	8021	Economy	6700.00
0005432901436	8021	Economy	6700.00
0005432901428	8021	Economy	6700.00
0005432816943	8021	Economy	6700.00
0005434175686	9654	Economy	6900.00
0005433870708	9654	Economy	6900.00
0005433870707	9654	Economy	6900.00
0005434175708	32377	Economy	6900.00
0005434175710	32377	Economy	6900.00
0005434175709	32377	Economy	6900.00
0005434877245	3491	Business	35000.00
0005434877248	3491	Business	35000.00
0005435125949	3491	Business	35000.00
0005434877314	3491	Business	35000.00
0005434937937	3491	Business	35000.00
0005434877297	3491	Business	35000.00
0005434426315	3491	Business	35000.00
0005434877310	3491	Business	35000.00
0005434877239	3491	Business	35000.00
0005435625998	3491	Business	35000.00
0005434426319	3491	Business	35000.00
0005435625987	3491	Business	35000.00
0005434877318	3491	Business	35000.00
0005435125942	3491	Business	35000.00
0005434877267	3491	Business	35000.00
0005434426300	3491	Business	35000.00
0005435125973	3491	Business	35000.00
0005435625999	3491	Business	35000.00
0005435125968	3491	Business	35000.00
0005434877320	3491	Business	35000.00
0005435902414	3491	Business	35000.00
0005434426323	3491	Comfort	19900.00
0005432188574	3491	Comfort	19900.00
0005434937947	3491	Comfort	19900.00
0005435125969	3491	Comfort	19900.00
0005435125939	3491	Comfort	19900.00
0005434877253	3491	Comfort	19900.00
0005434877294	3491	Comfort	19900.00
0005434877246	3491	Comfort	19900.00
0005434877317	3491	Comfort	19900.00
0005434877324	3491	Comfort	19900.00
0005432611669	3491	Comfort	19900.00
0005434877325	3491	Comfort	19900.00
0005435125966	3491	Comfort	19900.00
0005432799159	3491	Comfort	19900.00
0005432799180	3491	Comfort	19900.00
0005434426316	3491	Comfort	19900.00
0005435125944	3491	Comfort	19900.00
0005434877256	3491	Comfort	19900.00
0005434426303	3491	Comfort	19900.00
0005434877254	3491	Comfort	19900.00
0005434877309	3491	Comfort	19900.00
0005434877281	3491	Comfort	19900.00
0005435125976	3491	Comfort	19900.00
0005434877315	3491	Comfort	19900.00
0005434877306	3491	Comfort	19900.00
0005434426307	3491	Comfort	19900.00
0005432799158	3491	Comfort	19900.00
0005434426311	3491	Economy	11700.00
0005434937935	3491	Economy	11700.00
0005434877262	3491	Economy	11700.00
0005434877286	3491	Economy	11700.00
0005432799164	3491	Economy	11700.00
0005434877258	3491	Economy	11700.00
0005432799171	3491	Economy	11700.00
0005434877295	3491	Economy	11700.00
0005434426304	3491	Economy	11700.00
0005434877264	3491	Economy	11700.00
0005434937945	3491	Economy	11700.00
0005435125943	3491	Economy	11700.00
0005432799161	3491	Economy	11700.00
0005432183445	3491	Economy	11700.00
0005434877271	3491	Economy	11700.00
0005434877304	3491	Economy	11700.00
0005434877251	3491	Economy	11700.00
0005434877269	3491	Economy	11700.00
0005434877311	3491	Economy	11700.00
0005434877243	3491	Economy	11700.00
0005434426312	3491	Economy	11700.00
0005432799157	3491	Economy	11700.00
0005432799170	3491	Economy	11700.00
0005435625997	3491	Economy	11700.00
0005434877293	3491	Economy	11700.00
0005435125958	3491	Economy	11700.00
0005434877321	3491	Economy	11700.00
0005435125962	3491	Economy	11700.00
0005434877301	3491	Economy	11700.00
0005434937942	3491	Economy	11700.00
0005434877240	3491	Economy	11700.00
0005435125938	3491	Economy	11700.00
0005432799163	3491	Economy	11700.00
0005434426314	3491	Economy	11700.00
0005434426299	3491	Economy	11700.00
0005432183444	3491	Economy	11700.00
0005435625984	3491	Economy	11700.00
0005435625990	3491	Economy	11700.00
0005432188575	3491	Economy	11700.00
0005435625996	3491	Economy	12800.00
0005435625988	3491	Economy	11700.00
0005434877302	3491	Economy	11700.00
0005435125979	3491	Economy	11700.00
0005434877323	3491	Economy	11700.00
0005434937943	3491	Economy	11700.00
0005434877257	3491	Economy	11700.00
0005435625993	3491	Economy	11700.00
0005434426322	3491	Economy	11700.00
0005435125954	3491	Economy	11700.00
0005434877326	3491	Economy	11700.00
0005435125974	3491	Economy	11700.00
0005434426313	3491	Economy	11700.00
0005435902413	3491	Economy	11700.00
0005432799172	3491	Economy	11700.00
0005435125948	3491	Economy	11700.00
0005432799169	3491	Economy	11700.00
0005435625994	3491	Economy	11700.00
0005434937938	3491	Economy	11700.00
0005435125940	3491	Economy	11700.00
0005434426321	3491	Economy	11700.00
0005434426301	3491	Economy	11700.00
0005434877283	3491	Economy	11700.00
0005434877278	3491	Economy	11700.00
0005434877276	3491	Economy	11700.00
0005434877329	3491	Economy	11700.00
0005434877303	3491	Economy	11700.00
0005435125955	3491	Economy	11700.00
0005434877249	3491	Economy	11700.00
0005434877236	3491	Economy	11700.00
0005434877238	3491	Economy	11700.00
0005434426320	3491	Economy	11700.00
0005434877255	3491	Economy	11700.00
0005434937941	3491	Economy	11700.00
0005435902412	3491	Economy	11700.00
0005435125978	3491	Economy	11700.00
0005434877327	3491	Economy	11700.00
0005432799168	3491	Economy	11700.00
0005434877272	3491	Economy	11700.00
0005432799179	3491	Economy	11700.00
0005432799165	3491	Economy	11700.00
0005434877237	3491	Economy	11700.00
0005435125965	3491	Economy	11700.00
0005435902394	3491	Economy	11700.00
0005432188573	3491	Economy	11700.00
0005432611671	3491	Economy	11700.00
0005435625992	3491	Economy	11700.00
0005434877279	3491	Economy	11700.00
0005434877285	3491	Economy	11700.00
0005434877277	3491	Economy	11700.00
0005435125956	3491	Economy	11700.00
0005434877296	3491	Economy	11700.00
0005434877312	3491	Economy	11700.00
0005434937940	3491	Economy	11700.00
0005434877250	3491	Economy	11700.00
0005434426302	3491	Economy	11700.00
0005434877260	3491	Economy	11700.00
0005434426309	3491	Economy	11700.00
0005432799178	3491	Economy	11700.00
0005434877259	3491	Economy	11700.00
0005435125961	3491	Economy	11700.00
0005434426306	3491	Economy	11700.00
0005434937949	3491	Economy	11700.00
0005434877290	3491	Economy	11700.00
0005432613819	3491	Economy	11700.00
0005434937950	3491	Economy	11700.00
0005435125972	3491	Economy	11700.00
0005434937939	3491	Economy	11700.00
0005435125971	3491	Economy	11700.00
0005432799166	3491	Economy	11700.00
0005432799173	3491	Economy	11700.00
0005435125970	3491	Economy	11700.00
0005434877299	3491	Economy	11700.00
0005434877288	3491	Economy	11700.00
0005435625985	3491	Economy	11700.00
0005434426310	3491	Economy	11700.00
0005432611670	3491	Economy	11700.00
0005432799174	3491	Economy	11700.00
0005435125960	3491	Economy	12800.00
0005434877307	3491	Economy	12800.00
0005434937934	3491	Economy	11700.00
0005434877308	3491	Economy	11700.00
0005434877284	3491	Economy	11700.00
0005434877287	3491	Economy	11700.00
0005434937944	3491	Economy	11700.00
0005434877291	3491	Economy	11700.00
0005434877265	3491	Economy	11700.00
0005435125951	3491	Economy	11700.00
0005434877289	3491	Economy	11700.00
0005435125941	3491	Economy	11700.00
0005435125959	3491	Economy	11700.00
0005432799181	3491	Economy	11700.00
0005434877270	3491	Economy	11700.00
0005434937948	3491	Economy	11700.00
0005435125957	3491	Economy	11700.00
0005432799183	3491	Economy	11700.00
0005434426324	3491	Economy	11700.00
0005435125946	3491	Economy	11700.00
0005434937936	3491	Economy	11700.00
0005432799156	3491	Economy	11700.00
0005434877292	3491	Economy	11700.00
0005434877266	3491	Economy	11700.00
0005435125967	3491	Economy	11700.00
0005434877305	3491	Economy	11700.00
0005432799177	3491	Economy	11700.00
0005434877328	3491	Economy	11700.00
0005432183443	3491	Economy	11700.00
0005432799160	3491	Economy	11700.00
0005434877316	3491	Economy	11700.00
0005434426318	3491	Economy	11700.00
0005435125950	3491	Economy	11700.00
0005435125964	3491	Economy	11700.00
0005434937933	3491	Economy	11700.00
0005435625986	3491	Economy	11700.00
0005432613820	3491	Economy	11700.00
0005432799182	3491	Economy	11700.00
0005434877275	3491	Economy	11700.00
0005435125963	3491	Economy	11700.00
0005434877280	3491	Economy	11700.00
0005435625991	3491	Economy	11700.00
0005434877235	3491	Economy	11700.00
0005432799167	3491	Economy	11700.00
0005434426305	3491	Economy	11700.00
0005434877273	3491	Economy	11700.00
0005435125977	3491	Economy	11700.00
0005434877268	3491	Economy	11700.00
0005432613821	3491	Economy	11700.00
0005432799162	3491	Economy	11700.00
0005434877261	3491	Economy	11700.00
0005434877319	3491	Economy	11700.00
0005434877244	3491	Economy	11700.00
0005434877313	3491	Economy	11700.00
0005435125947	3491	Economy	11700.00
0005435125953	3491	Economy	11700.00
0005435125975	3491	Economy	11700.00
0005434426296	3491	Economy	11700.00
0005435625989	3491	Economy	11700.00
0005434937951	3491	Economy	11700.00
0005432799175	3491	Economy	11700.00
0005434877263	3491	Economy	11700.00
0005434426308	3491	Economy	11700.00
0005435625995	3491	Economy	11700.00
0005434426317	3491	Economy	11700.00
0005434877274	3491	Economy	11700.00
0005432799176	3491	Economy	11700.00
0005434877298	3491	Economy	11700.00
0005434877241	3491	Economy	11700.00
0005434877282	3491	Economy	11700.00
0005434877322	3491	Economy	11700.00
0005434877330	3491	Economy	11700.00
0005434937946	3491	Economy	11700.00
0005435125945	3491	Economy	11700.00
0005434877242	3491	Economy	11700.00
0005434426325	3491	Economy	11700.00
0005432799155	3491	Economy	11700.00
0005435125952	3491	Economy	11700.00
0005434877252	3491	Economy	11700.00
0005432611668	3491	Economy	11700.00
0005434426298	3491	Economy	11700.00
0005434426297	3491	Economy	11700.00
0005434877247	3491	Economy	11700.00
0005434877300	3491	Economy	11700.00
0005435902519	14553	Business	35000.00
0005435902527	14553	Business	35000.00
0005435913898	14553	Business	35000.00
0005434876621	14553	Business	35000.00
0005434876620	14553	Business	35000.00
0005434876645	14553	Business	35000.00
0005434876703	14553	Business	35000.00
0005434937810	14553	Comfort	19900.00
0005434937837	14553	Comfort	19900.00
0005435902528	14553	Comfort	19900.00
0005435125679	14553	Comfort	19900.00
0005434876671	14553	Comfort	19900.00
0005434426108	14553	Comfort	19900.00
0005434937818	14553	Comfort	19900.00
0005435902521	14553	Comfort	19900.00
0005434876670	14553	Comfort	19900.00
0005434937809	14553	Comfort	19900.00
0005435902516	14553	Comfort	19900.00
0005435902525	14553	Comfort	19900.00
0005434426161	14553	Comfort	19900.00
0005434876674	14553	Economy	11700.00
0005435902526	14553	Economy	11700.00
0005434876669	14553	Economy	11700.00
0005434876572	14553	Economy	11700.00
0005434876909	14553	Economy	11700.00
0005432798991	14553	Economy	11700.00
0005432799043	14553	Economy	11700.00
0005435902517	14553	Economy	11700.00
0005435914688	14553	Economy	11700.00
0005434876612	14553	Economy	11700.00
0005434937851	14553	Economy	11700.00
0005434876760	14553	Economy	11700.00
0005434876563	14553	Economy	11700.00
0005432798966	14553	Economy	11700.00
0005435913893	14553	Economy	11700.00
0005435913899	14553	Economy	11700.00
0005435902518	14553	Economy	11700.00
0005435125672	14553	Economy	12800.00
0005434876820	14553	Economy	12800.00
0005432059484	14553	Economy	11700.00
0005434426100	14553	Economy	11700.00
0005434876583	14553	Economy	11700.00
0005434426160	14553	Economy	11700.00
0005434876668	14553	Economy	11700.00
0005435913894	14553	Economy	11700.00
0005434426091	14553	Economy	11700.00
0005435902529	14553	Economy	11700.00
0005435913897	14553	Economy	11700.00
0005434876759	14553	Economy	11700.00
0005434876825	14553	Economy	11700.00
0005434937890	14553	Economy	11700.00
0005434876585	14553	Economy	11700.00
0005432798993	14553	Economy	11700.00
0005434937830	14553	Economy	11700.00
0005435125743	14553	Economy	11700.00
0005434876826	14553	Economy	11700.00
0005435902515	14553	Economy	11700.00
0005434937808	14553	Economy	11700.00
0005435125685	14553	Economy	11700.00
0005434876673	14553	Economy	11700.00
0005435902513	14553	Economy	11700.00
0005434876752	14553	Economy	11700.00
0005435125717	14553	Economy	11700.00
0005434937836	14553	Economy	11700.00
0005435913896	14553	Economy	11700.00
0005434937891	14553	Economy	11700.00
0005434876614	14553	Economy	11700.00
0005432611648	14553	Economy	12800.00
0005434876616	14553	Economy	12800.00
0005432798992	14553	Economy	11700.00
0005434876607	14553	Economy	11700.00
0005432799000	14553	Economy	11700.00
0005434876672	14553	Economy	11700.00
0005435902512	14553	Economy	11700.00
0005434876675	14553	Economy	11700.00
0005432798964	14553	Economy	11700.00
0005434876722	14553	Economy	11700.00
0005434426164	14553	Economy	11700.00
0005434876761	14553	Economy	11700.00
0005434876615	14553	Economy	11700.00
0005434876819	14553	Economy	11700.00
0005435902524	14553	Economy	11700.00
0005434937803	14553	Economy	11700.00
0005434876688	14553	Economy	11700.00
0005435913895	14553	Economy	11700.00
0005434876564	14553	Economy	11700.00
0005435902514	14553	Economy	11700.00
0005435902523	14553	Economy	11700.00
0005435902520	14553	Economy	11700.00
0005434876646	14553	Economy	11700.00
0005435902522	14553	Economy	11700.00
0005434876936	14553	Economy	11700.00
0005434876817	14553	Economy	11700.00
0005434876704	14553	Economy	11700.00
0005435125744	14553	Economy	11700.00
0005434876656	14553	Economy	11700.00
0005435913900	14553	Economy	11700.00
0005432799044	14553	Economy	11700.00
0005432798970	14553	Economy	11700.00
0005435125673	14553	Economy	11700.00
0005434876667	14553	Economy	11700.00
0005435125716	14553	Economy	11700.00
0005432799010	14553	Economy	11700.00
0005432798965	14553	Economy	11700.00
0005434325530	3643	Economy	16300.00
0005434325529	3643	Economy	14800.00
0005434325536	3643	Economy	14800.00
0005434325526	3643	Economy	14800.00
0005435889812	3643	Economy	14800.00
0005435889813	3643	Economy	14800.00
0005434325532	3643	Economy	14800.00
0005434312297	3643	Economy	14800.00
0005435889811	3643	Economy	14800.00
0005434325527	3643	Economy	14800.00
0005434325531	3643	Economy	14800.00
0005434325533	3643	Economy	14800.00
0005434325528	3643	Economy	14800.00
0005434325534	3643	Economy	14800.00
0005434325535	3643	Economy	14800.00
0005435889792	3643	Economy	14800.00
0005434312296	3643	Economy	14800.00
0005435889837	15636	Economy	16300.00
0005434325450	15636	Economy	16300.00
0005434325458	15636	Economy	14800.00
0005434325461	15636	Economy	14800.00
0005434325449	15636	Economy	14800.00
0005434325454	15636	Economy	14800.00
0005434325447	15636	Economy	14800.00
0005434325457	15636	Economy	14800.00
0005434325455	15636	Economy	14800.00
0005435889838	15636	Economy	14800.00
0005434325451	15636	Economy	14800.00
0005435889836	15636	Economy	14800.00
0005435889832	15636	Economy	14800.00
0005434325448	15636	Economy	14800.00
0005435889833	15636	Economy	14800.00
0005434325453	15636	Economy	14800.00
0005435889834	15636	Economy	14800.00
0005435889835	15636	Economy	14800.00
0005435957558	630	Economy	4500.00
0005435957544	630	Economy	4500.00
0005435957552	630	Economy	4500.00
0005435957556	630	Economy	4100.00
0005435957551	630	Economy	4100.00
0005435957549	630	Economy	4100.00
0005435957547	630	Economy	4100.00
0005435957554	630	Economy	4100.00
0005433420273	630	Economy	4100.00
0005435957545	630	Economy	4100.00
0005433420275	630	Economy	4100.00
0005433420274	630	Economy	4100.00
0005433420268	630	Economy	4100.00
0005433420272	630	Economy	4100.00
0005433420249	630	Economy	4100.00
0005435957553	630	Economy	4100.00
0005435957557	630	Economy	4100.00
0005435957548	630	Economy	4100.00
0005435957546	630	Economy	4100.00
0005435957550	630	Economy	4100.00
0005435957555	630	Economy	4100.00
0005433420314	15157	Economy	4100.00
0005433420311	15157	Economy	4100.00
0005433420316	15157	Economy	4100.00
0005435957447	15157	Economy	4100.00
0005433420312	15157	Economy	4100.00
0005433420315	15157	Economy	4100.00
0005435957444	15157	Economy	4100.00
0005433420310	15157	Economy	4100.00
0005433420317	15157	Economy	4100.00
0005433420318	15157	Economy	4100.00
0005433420313	15157	Economy	4100.00
0005435957465	15157	Economy	4100.00
0005433420319	15157	Economy	4100.00
0005435221035	27265	Economy	25500.00
0005435218106	31775	Economy	28100.00
0005435217688	31775	Economy	25500.00
0005435218105	31775	Economy	25500.00
0005435216567	31775	Economy	25500.00
0005435217687	31775	Economy	25500.00
0005435216568	31775	Economy	25500.00
0005435216564	31775	Economy	25500.00
0005435217692	31775	Economy	25500.00
0005435216566	31775	Economy	25500.00
0005435216561	31775	Economy	25500.00
0005435217685	31775	Economy	25500.00
0005435217693	31775	Economy	25500.00
0005435217690	31775	Economy	25500.00
0005435216565	31775	Economy	25500.00
0005435216569	31775	Economy	25500.00
0005435217686	31775	Economy	25500.00
0005435217691	31775	Economy	25500.00
0005435217694	31775	Economy	25500.00
0005435217689	31775	Economy	25500.00
0005435218107	31775	Economy	25500.00
0005435216563	31775	Economy	25500.00
0005435216562	31775	Economy	25500.00
0005435218108	31775	Economy	25500.00
0005435629392	8836	Economy	10400.00
0005435629391	8836	Economy	10400.00
0005434247121	16026	Economy	10400.00
0005435629383	16026	Economy	10400.00
0005434247120	16026	Economy	10400.00
0005434247122	16026	Economy	10400.00
0005434467739	4008	Economy	21200.00
0005434467740	4008	Economy	21200.00
0005434467735	4008	Economy	21200.00
0005434467732	4008	Economy	21200.00
0005434467737	4008	Economy	21200.00
0005434467734	4008	Economy	21200.00
0005434467736	4008	Economy	21200.00
0005434467741	4008	Economy	21200.00
0005434467738	4008	Economy	21200.00
0005434467733	4008	Economy	21200.00
0005434467724	23209	Economy	21200.00
0005434467723	23209	Economy	21200.00
0005435163169	4433	Economy	13400.00
0005435163170	4433	Economy	13400.00
0005435163172	4433	Economy	12200.00
0005435163175	4433	Economy	12200.00
0005435163174	4433	Economy	12200.00
0005435163173	4433	Economy	12200.00
0005435163166	4433	Economy	12200.00
0005435163179	4433	Economy	12200.00
0005435163180	4433	Economy	12200.00
0005435933403	4433	Economy	12200.00
0005435163171	4433	Economy	12200.00
0005435933401	4433	Economy	12200.00
0005435933402	4433	Economy	12200.00
0005435163178	4433	Economy	12200.00
0005435163181	4433	Economy	12200.00
0005435163167	4433	Economy	12200.00
0005435163177	4433	Economy	12200.00
0005435163176	4433	Economy	12200.00
0005435163168	4433	Economy	12200.00
0005435933417	29507	Economy	13400.00
0005435163144	29507	Economy	12200.00
0005435933414	29507	Economy	12200.00
0005435163142	29507	Economy	12200.00
0005435933415	29507	Economy	12200.00
0005435163143	29507	Economy	12200.00
0005435933416	29507	Economy	12200.00
0005435933420	29507	Economy	12200.00
0005435933418	29507	Economy	12200.00
0005435933419	29507	Economy	12200.00
0005432645817	6828	Business	87700.00
0005432645865	6828	Business	87700.00
0005432645837	6828	Business	87700.00
0005432645827	6828	Business	87700.00
0005432645815	6828	Business	87700.00
0005432645852	6828	Business	87700.00
0005432645847	6828	Economy	29200.00
0005432645821	6828	Economy	29200.00
0005432645846	6828	Economy	29200.00
0005435229324	6828	Economy	29200.00
0005432645836	6828	Economy	29200.00
0005432645844	6828	Economy	32200.00
0005432645831	6828	Economy	32200.00
0005432645824	6828	Economy	32200.00
0005432645851	6828	Economy	29200.00
0005432645857	6828	Economy	29200.00
0005432645826	6828	Economy	29200.00
0005432645818	6828	Economy	29200.00
0005432645863	6828	Economy	29200.00
0005432645856	6828	Economy	29200.00
0005432645819	6828	Economy	29200.00
0005432645840	6828	Economy	29200.00
0005432645820	6828	Economy	29200.00
0005432645838	6828	Economy	29200.00
0005432645843	6828	Economy	29200.00
0005432645823	6828	Economy	29200.00
0005432645830	6828	Economy	29200.00
0005432645842	6828	Economy	29200.00
0005432645864	6828	Economy	29200.00
0005432645853	6828	Economy	29200.00
0005432645834	6828	Economy	29200.00
0005432645814	6828	Economy	29200.00
0005432645832	6828	Economy	29200.00
0005432645825	6828	Economy	29200.00
0005432645862	6828	Economy	29200.00
0005432645860	6828	Economy	29200.00
0005432645861	6828	Economy	29200.00
0005432645835	6828	Economy	29200.00
0005432645813	6828	Economy	29200.00
0005432645822	6828	Economy	29200.00
0005432645841	6828	Economy	29200.00
0005432645859	6828	Economy	29200.00
0005432645829	6828	Economy	29200.00
0005432645848	6828	Economy	29200.00
0005432645855	6828	Economy	29200.00
0005432645816	6828	Economy	29200.00
0005432645854	6828	Economy	29200.00
0005432645828	6828	Economy	29200.00
0005432645833	6828	Economy	29200.00
0005432645850	6828	Economy	29200.00
0005432645845	6828	Economy	29200.00
0005432645858	6828	Economy	29200.00
0005432645849	6828	Economy	29200.00
0005432645839	6828	Economy	29200.00
0005433404706	2846	Business	12600.00
0005435797332	2846	Business	12600.00
0005435797336	2846	Economy	4200.00
0005435797333	2846	Economy	4200.00
0005435797330	2846	Economy	4200.00
0005435797326	2846	Economy	4200.00
0005435797335	2846	Economy	4200.00
0005435797329	2846	Economy	4200.00
0005435797338	2846	Economy	4200.00
0005435797334	2846	Economy	4200.00
0005433404707	2846	Economy	4200.00
0005435797328	2846	Economy	4200.00
0005435797323	2846	Economy	4200.00
0005435797331	2846	Economy	4200.00
0005435797325	2846	Economy	4200.00
0005435797324	2846	Economy	4200.00
0005435797327	2846	Economy	4200.00
0005435797337	2846	Economy	4200.00
0005433404730	29293	Business	12600.00
0005433404732	29293	Business	12600.00
0005433404735	29293	Economy	4200.00
0005433404733	29293	Economy	4200.00
0005435797246	29293	Economy	4200.00
0005435797231	29293	Economy	4200.00
0005435797290	29293	Economy	4200.00
0005435797232	29293	Economy	4200.00
0005435797230	29293	Economy	4200.00
0005435797245	29293	Economy	4200.00
0005433404736	29293	Economy	4200.00
0005433404731	29293	Economy	4200.00
0005433404737	29293	Economy	4200.00
0005433404729	29293	Economy	4200.00
0005435797275	29293	Economy	4200.00
0005433404734	29293	Economy	4200.00
0005435376316	5795	Economy	6800.00
0005435376315	5795	Economy	6800.00
0005435376318	5795	Economy	6800.00
0005435376317	5795	Economy	6800.00
0005434947933	5833	Economy	6800.00
0005434947936	5833	Economy	6800.00
0005434947938	5833	Economy	6800.00
0005434947934	5833	Economy	6800.00
0005434947931	5833	Economy	6800.00
0005434947935	5833	Economy	6800.00
0005434947937	5833	Economy	6800.00
0005434947939	5833	Economy	6800.00
0005434947932	5833	Economy	6800.00
0005434947877	16401	Economy	6800.00
0005434947878	16401	Economy	6800.00
0005435376329	16401	Economy	6800.00
0005435376328	16401	Economy	6800.00
0005435376326	16401	Economy	6800.00
0005434947876	16401	Economy	6800.00
0005435376327	16401	Economy	6800.00
0005434947879	16401	Economy	6800.00
0005434947873	16401	Economy	6800.00
0005433960292	6849	Business	21400.00
0005433960332	6849	Business	21400.00
0005433960333	6849	Business	21400.00
0005433960310	6849	Business	21400.00
0005433960331	6849	Business	21400.00
0005433960283	6849	Business	21400.00
0005433960322	6849	Business	21400.00
0005433960288	6849	Business	21400.00
0005433960304	6849	Business	21400.00
0005433960272	6849	Business	21400.00
0005433960314	6849	Economy	7100.00
0005433960285	6849	Economy	7100.00
0005433960302	6849	Economy	7100.00
0005433960311	6849	Economy	7800.00
0005433960318	6849	Economy	7800.00
0005433960300	6849	Economy	7800.00
0005433960268	6849	Economy	7100.00
0005433960287	6849	Economy	7100.00
0005433960313	6849	Economy	7100.00
0005433960309	6849	Economy	7100.00
0005433960294	6849	Economy	7100.00
0005433960312	6849	Economy	7100.00
0005433960326	6849	Economy	7100.00
0005433960290	6849	Economy	7100.00
0005433960329	6849	Economy	7100.00
0005433960282	6849	Economy	7100.00
0005433960296	6849	Economy	7100.00
0005433960273	6849	Economy	7100.00
0005433960284	6849	Economy	7100.00
0005433960297	6849	Economy	7100.00
0005433960276	6849	Economy	7100.00
0005433960327	6849	Economy	7100.00
0005433960277	6849	Economy	7100.00
0005433960289	6849	Economy	7100.00
0005433960325	6849	Economy	7100.00
0005433960279	6849	Economy	7100.00
0005433960336	6849	Economy	7100.00
0005433960317	6849	Economy	7100.00
0005433960307	6849	Economy	7100.00
0005433960330	6849	Economy	7100.00
0005433960293	6849	Economy	7100.00
0005433960291	6849	Economy	7100.00
0005433960270	6849	Economy	7100.00
0005433960335	6849	Economy	7100.00
0005433960316	6849	Economy	7100.00
0005433960271	6849	Economy	7100.00
0005433960274	6849	Economy	7100.00
0005433960323	6849	Economy	7100.00
0005433960281	6849	Economy	7100.00
0005433960299	6849	Economy	7100.00
0005433960320	6849	Economy	7100.00
0005433960286	6849	Economy	7100.00
0005433960298	6849	Economy	7100.00
0005433960306	6849	Economy	7100.00
0005433960280	6849	Economy	7100.00
0005433960305	6849	Economy	7100.00
0005433960328	6849	Economy	7100.00
0005433960321	6849	Economy	7100.00
0005433960269	6849	Economy	7100.00
0005433960308	6849	Economy	7100.00
0005433960315	6849	Economy	7100.00
0005433960303	6849	Economy	7100.00
0005433960275	6849	Economy	7100.00
0005433960319	6849	Economy	7100.00
0005433960324	6849	Economy	7100.00
0005433960334	6849	Economy	7100.00
0005433960295	6849	Economy	7100.00
0005433960278	6849	Economy	7100.00
0005433960301	6849	Economy	7100.00
0005435082695	26071	Economy	3900.00
0005435082700	26071	Economy	3900.00
0005435082703	26071	Economy	3900.00
0005435082701	26071	Economy	3900.00
0005435082699	26071	Economy	3900.00
0005435082696	26071	Economy	3900.00
0005435082697	26071	Economy	3900.00
0005435082702	26071	Economy	3900.00
0005435082698	26071	Economy	3900.00
0005434244678	5017	Business	18000.00
0005434244684	5017	Business	18000.00
0005434244686	5017	Business	18000.00
0005434244666	5017	Business	18000.00
0005432166869	5017	Business	18000.00
0005434244674	5017	Economy	6000.00
0005434244683	5017	Economy	6000.00
0005434244676	5017	Economy	6000.00
0005433534463	5017	Economy	6000.00
0005433534461	5017	Economy	6000.00
0005434244679	5017	Economy	6000.00
0005434244681	5017	Economy	6000.00
0005434244680	5017	Economy	6000.00
0005434244690	5017	Economy	6000.00
0005434244665	5017	Economy	6000.00
0005432166867	5017	Economy	6000.00
0005434244688	5017	Economy	6000.00
0005434244687	5017	Economy	6600.00
0005434244667	5017	Economy	6000.00
0005434244693	5017	Economy	6000.00
0005434244668	5017	Economy	6600.00
0005434244677	5017	Economy	6000.00
0005434244682	5017	Economy	6000.00
0005434244670	5017	Economy	6000.00
0005434244685	5017	Economy	6000.00
0005434244689	5017	Economy	6000.00
0005434244673	5017	Economy	6000.00
0005434244691	5017	Economy	6000.00
0005434244675	5017	Economy	6000.00
0005434244671	5017	Economy	6000.00
0005434244692	5017	Economy	6000.00
0005433534462	5017	Economy	6000.00
0005432166870	5017	Economy	6000.00
0005434244669	5017	Economy	6000.00
0005432166868	5017	Economy	6000.00
0005434244672	5017	Economy	6000.00
0005432666366	5016	Business	18000.00
0005433784580	5016	Business	18000.00
0005433613962	5016	Business	18000.00
0005432105090	5016	Business	18000.00
0005433784566	5016	Business	18000.00
0005433613911	5016	Business	18000.00
0005433784567	5016	Business	18000.00
0005433613922	5016	Business	18000.00
0005433784565	5016	Business	18000.00
0005432105103	5016	Business	18000.00
0005433784555	5016	Business	18000.00
0005433613910	5016	Business	18000.00
0005433613961	5016	Business	18000.00
0005432667432	5016	Business	18000.00
0005433613963	5016	Business	18000.00
0005432105073	5016	Business	18000.00
0005433613982	5016	Business	18000.00
0005433613936	5016	Business	18000.00
0005433784581	5016	Business	18000.00
0005433613913	5016	Business	18000.00
0005433613926	5016	Business	18000.00
0005433613941	5016	Business	18000.00
0005433613966	5016	Business	18000.00
0005432105098	5016	Business	18000.00
0005432105076	5016	Business	18000.00
0005433613939	5016	Business	18000.00
0005432665253	5016	Business	18000.00
0005433613947	5016	Business	18000.00
0005432105064	5016	Economy	6600.00
0005433784576	5016	Economy	6600.00
0005432667433	5016	Economy	6600.00
0005433613944	5016	Economy	6600.00
0005433784559	5016	Economy	6600.00
0005432105093	5016	Economy	6600.00
0005433613954	5016	Economy	6000.00
0005433613980	5016	Economy	6000.00
0005433613929	5016	Economy	6000.00
0005432105054	5016	Economy	6000.00
0005433613956	5016	Economy	6000.00
0005432105084	5016	Economy	6000.00
0005432145091	5016	Economy	6000.00
0005433613959	5016	Economy	6000.00
0005433613983	5016	Economy	6000.00
0005433613919	5016	Economy	6000.00
0005433613965	5016	Economy	6000.00
0005433784584	5016	Economy	6000.00
0005433613952	5016	Economy	6000.00
0005433784582	5016	Economy	6000.00
0005433613974	5016	Economy	6000.00
0005433784558	5016	Economy	6000.00
0005432105094	5016	Economy	6000.00
0005433613981	5016	Economy	6000.00
0005432666369	5016	Economy	6000.00
0005433613968	5016	Economy	6000.00
0005432105066	5016	Economy	6000.00
0005432105070	5016	Economy	6000.00
0005433613979	5016	Economy	6000.00
0005433784560	5016	Economy	6000.00
0005433613969	5016	Economy	6000.00
0005433784586	5016	Economy	6000.00
0005432105100	5016	Economy	6000.00
0005432105085	5016	Economy	6000.00
0005432105062	5016	Economy	6000.00
0005432105087	5016	Economy	6000.00
0005433613977	5016	Economy	6000.00
0005433784577	5016	Economy	6000.00
0005433613912	5016	Economy	6000.00
0005433784557	5016	Economy	6000.00
0005433613973	5016	Economy	6000.00
0005432105088	5016	Economy	6000.00
0005432105102	5016	Economy	6000.00
0005433784572	5016	Economy	6000.00
0005432666368	5016	Economy	6000.00
0005432105075	5016	Economy	6000.00
0005433613945	5016	Economy	6000.00
0005433784571	5016	Economy	6000.00
0005433613975	5016	Economy	6000.00
0005433784578	5016	Economy	6000.00
0005432105077	5016	Economy	6000.00
0005433784585	5016	Economy	6000.00
0005433613931	5016	Economy	6000.00
0005432105069	5016	Economy	6000.00
0005433784570	5016	Economy	6000.00
0005433784569	5016	Economy	6000.00
0005433613921	5016	Economy	6000.00
0005432105071	5016	Economy	6000.00
0005432105099	5016	Economy	6000.00
0005433784575	5016	Economy	6000.00
0005433784583	5016	Economy	6000.00
0005433613978	5016	Economy	6000.00
0005433784561	5016	Economy	6000.00
0005432105074	5016	Economy	6000.00
0005433613934	5016	Economy	6000.00
0005432105096	5016	Economy	6600.00
0005433784568	5016	Economy	6600.00
0005432105055	5016	Economy	6600.00
0005433613924	5016	Economy	6600.00
0005433613971	5016	Economy	6600.00
0005432105058	5016	Economy	6000.00
0005433613930	5016	Economy	6000.00
0005433613976	5016	Economy	6000.00
0005432105057	5016	Economy	6000.00
0005433784574	5016	Economy	6600.00
0005433784554	5016	Economy	6000.00
0005433613938	5016	Economy	6000.00
0005433613942	5016	Economy	6000.00
0005432105065	5016	Economy	6000.00
0005433613917	5016	Economy	6000.00
0005432105078	5016	Economy	6000.00
0005433784563	5016	Economy	6000.00
0005432105059	5016	Economy	6000.00
0005432105061	5016	Economy	6000.00
0005433613970	5016	Economy	6000.00
0005432105068	5016	Economy	6000.00
0005432105092	5016	Economy	6000.00
0005433613958	5016	Economy	6000.00
0005433613984	5016	Economy	6000.00
0005433784573	5016	Economy	6000.00
0005433613972	5016	Economy	6000.00
0005433613925	5016	Economy	6000.00
0005433613914	5016	Economy	6000.00
0005432105095	5016	Economy	6000.00
0005432105079	5016	Economy	6000.00
0005433613955	5016	Economy	6000.00
0005433613933	5016	Economy	6000.00
0005433613943	5016	Economy	6000.00
0005432105056	5016	Economy	6000.00
0005433613950	5016	Economy	6000.00
0005433784579	5016	Economy	6000.00
0005433613935	5016	Economy	6000.00
0005433613915	5016	Economy	6000.00
0005433784553	5016	Economy	6000.00
0005433613967	5016	Economy	6000.00
0005432105067	5016	Economy	6000.00
0005433613951	5016	Economy	6000.00
0005432105091	5016	Economy	6000.00
0005433613920	5016	Economy	6000.00
0005433784564	5016	Economy	6000.00
0005432105082	5016	Economy	6000.00
0005433613928	5016	Economy	6000.00
0005432105072	5016	Economy	6000.00
0005432665252	5016	Economy	6000.00
0005433784556	5016	Economy	6000.00
0005432105097	5016	Economy	6000.00
0005433613940	5016	Economy	6000.00
0005432105080	5016	Economy	6000.00
0005433784562	5016	Economy	6000.00
0005433613960	5016	Economy	6000.00
0005433613957	5016	Economy	6000.00
0005433613937	5016	Economy	6000.00
0005433613918	5016	Economy	6000.00
0005433613946	5016	Economy	6000.00
0005432105083	5016	Economy	6000.00
0005433613916	5016	Economy	6000.00
0005432105060	5016	Economy	6000.00
0005432105063	5016	Economy	6000.00
0005432666367	5016	Economy	6000.00
0005432105101	5016	Economy	6000.00
0005433613949	5016	Economy	6000.00
0005433613953	5016	Economy	6000.00
0005433613948	5016	Economy	6000.00
0005432105086	5016	Economy	6000.00
0005433613932	5016	Economy	6000.00
0005433613923	5016	Economy	6000.00
0005433613964	5016	Economy	6000.00
0005433613927	5016	Economy	6000.00
0005432105089	5016	Economy	6000.00
0005432145092	5016	Economy	6000.00
0005432105081	5016	Economy	6000.00
0005434264881	5014	Business	18000.00
0005434229138	5014	Business	18000.00
0005434264873	5014	Business	18000.00
0005434264868	5014	Business	18000.00
0005435006630	5014	Business	18000.00
0005435006610	5014	Business	18000.00
0005435006614	5014	Business	18000.00
0005434229132	5014	Business	18000.00
0005434229133	5014	Business	18000.00
0005434229141	5014	Business	18000.00
0005432335828	5014	Business	18000.00
0005434229149	5014	Business	18000.00
0005434264862	5014	Business	18000.00
0005435006609	5014	Business	18000.00
0005434229136	5014	Business	18000.00
0005432335827	5014	Business	18000.00
0005434311185	5014	Business	18000.00
0005434229140	5014	Business	18000.00
0005434264869	5014	Economy	6600.00
0005434173479	5014	Economy	6600.00
0005434229143	5014	Economy	6600.00
0005434264884	5014	Economy	6000.00
0005434264865	5014	Economy	6000.00
0005434149611	5014	Economy	6000.00
0005434264874	5014	Economy	6000.00
0005434229139	5014	Economy	6000.00
0005434149608	5014	Economy	6000.00
0005434264883	5014	Economy	6000.00
0005434149609	5014	Economy	6000.00
0005434173480	5014	Economy	6000.00
0005434149615	5014	Economy	6000.00
0005434264866	5014	Economy	6000.00
0005434229145	5014	Economy	6000.00
0005434229128	5014	Economy	6000.00
0005432335823	5014	Economy	6000.00
0005435006662	5014	Economy	6000.00
0005434264877	5014	Economy	6000.00
0005434173478	5014	Economy	6000.00
0005434312283	5014	Economy	6000.00
0005434149614	5014	Economy	6000.00
0005434264867	5014	Economy	6000.00
0005435006661	5014	Economy	6000.00
0005434264861	5014	Economy	6000.00
0005434264885	5014	Economy	6000.00
0005435006615	5014	Economy	6000.00
0005434149606	5014	Economy	6000.00
0005434264864	5014	Economy	6000.00
0005434311182	5014	Economy	6000.00
0005434229150	5014	Economy	6000.00
0005434229142	5014	Economy	6000.00
0005434149612	5014	Economy	6000.00
0005435006642	5014	Economy	6000.00
0005434149604	5014	Economy	6600.00
0005434229130	5014	Economy	6600.00
0005434312287	5014	Economy	6600.00
0005435006619	5014	Economy	6000.00
0005434229135	5014	Economy	6000.00
0005434264870	5014	Economy	6000.00
0005434229131	5014	Economy	6000.00
0005434264876	5014	Economy	6000.00
0005434229144	5014	Economy	6000.00
0005434264886	5014	Economy	6000.00
0005432335826	5014	Economy	6000.00
0005434229129	5014	Economy	6000.00
0005434264875	5014	Economy	6000.00
0005434264872	5014	Economy	6000.00
0005434312288	5014	Economy	6000.00
0005432335825	5014	Economy	6000.00
0005434229146	5014	Economy	6000.00
0005434149607	5014	Economy	6000.00
0005434264878	5014	Economy	6000.00
0005434229137	5014	Economy	6000.00
0005434264880	5014	Economy	6000.00
0005433815300	5014	Economy	6000.00
0005435006635	5014	Economy	6000.00
0005434229148	5014	Economy	6000.00
0005434229147	5014	Economy	6000.00
0005434149605	5014	Economy	6000.00
0005432335833	5014	Economy	6000.00
0005435006719	5014	Economy	6000.00
0005435006631	5014	Economy	6000.00
0005434264879	5014	Economy	6000.00
0005435006643	5014	Economy	6000.00
0005434229134	5014	Economy	6000.00
0005434149613	5014	Economy	6000.00
0005434264871	5014	Economy	6000.00
0005434264863	5014	Economy	6000.00
0005434149610	5014	Economy	6000.00
0005434264882	5014	Economy	6000.00
0005435006620	5014	Economy	6000.00
0005433784354	8422	Business	18000.00
0005433784297	8422	Business	18000.00
0005435269673	8422	Business	18000.00
0005434244459	8422	Business	18000.00
0005434244464	8422	Economy	6600.00
0005434244475	8422	Economy	6600.00
0005434244462	8422	Economy	6600.00
0005434244492	8422	Economy	6000.00
0005434244549	8422	Economy	6000.00
0005434244502	8422	Economy	6000.00
0005434244495	8422	Economy	6000.00
0005434244607	8422	Economy	6000.00
0005434244463	8422	Economy	6000.00
0005433784298	8422	Economy	6000.00
0005434244514	8422	Economy	6000.00
0005433784432	8422	Economy	6600.00
0005433784356	8422	Economy	6600.00
0005434244545	8422	Economy	6600.00
0005434244513	8422	Economy	6000.00
0005434244525	8422	Economy	6600.00
0005434244455	8422	Economy	6000.00
0005434244512	8422	Economy	6000.00
0005434244476	8422	Economy	6000.00
0005434244491	8422	Economy	6000.00
0005434244478	8422	Economy	6000.00
0005434244544	8422	Economy	6000.00
0005433784433	8422	Economy	6000.00
0005434244474	8422	Economy	6000.00
0005435269674	8422	Economy	6000.00
0005433784301	8422	Economy	6000.00
0005435269672	8422	Economy	6000.00
0005434244539	8422	Economy	6000.00
0005432666351	8422	Economy	6000.00
0005434244550	8422	Economy	6000.00
0005434244583	8422	Economy	6000.00
0005433613703	8421	Business	18000.00
0005433613426	8421	Economy	6000.00
0005433613418	8421	Economy	6000.00
0005433613427	8421	Economy	6000.00
0005433613423	8421	Economy	6000.00
0005433613477	8421	Economy	6600.00
0005433613386	8421	Economy	6000.00
0005433613387	8421	Economy	6000.00
0005434264694	8420	Business	18000.00
0005433534477	8420	Business	18000.00
0005434228972	8420	Business	18000.00
0005435006780	8420	Business	18000.00
0005432034654	8420	Business	18000.00
0005434264753	8420	Business	18000.00
0005435006771	8420	Business	18000.00
0005432034674	8420	Business	18000.00
0005433690905	8420	Business	18000.00
0005434264679	8420	Business	18000.00
0005432034668	8420	Business	18000.00
0005432335913	8420	Business	18000.00
0005435006775	8420	Business	18000.00
0005435006776	8420	Business	18000.00
0005432034665	8420	Business	18000.00
0005434264686	8420	Business	18000.00
0005432335912	8420	Business	18000.00
0005435006788	8420	Business	18000.00
0005435006790	8420	Business	18000.00
0005432034669	8420	Economy	6600.00
0005435006772	8420	Economy	6600.00
0005435006789	8420	Economy	6600.00
0005434229007	8420	Economy	6600.00
0005432034664	8420	Economy	6000.00
0005435006779	8420	Economy	6000.00
0005432034666	8420	Economy	6000.00
0005432034675	8420	Economy	6000.00
0005432335907	8420	Economy	6000.00
0005435006770	8420	Economy	6000.00
0005435006785	8420	Economy	6000.00
0005434311199	8420	Economy	6000.00
0005432034655	8420	Economy	6000.00
0005434264724	8420	Economy	6000.00
0005433815338	8420	Economy	6000.00
0005434311197	8420	Economy	6000.00
0005434173452	8420	Economy	6000.00
0005434311198	8420	Economy	6000.00
0005433534475	8420	Economy	6000.00
0005434264715	8420	Economy	6000.00
0005435006784	8420	Economy	6000.00
0005432034649	8420	Economy	6000.00
0005434264720	8420	Economy	6000.00
0005432034672	8420	Economy	6000.00
0005433815336	8420	Economy	6000.00
0005432034659	8420	Economy	6000.00
0005434149541	8420	Economy	6000.00
0005432034657	8420	Economy	6000.00
0005432034673	8420	Economy	6000.00
0005434264768	8420	Economy	6000.00
0005435006766	8420	Economy	6000.00
0005432047511	8420	Economy	6000.00
0005432034652	8420	Economy	6000.00
0005434173456	8420	Economy	6000.00
0005435006778	8420	Economy	6000.00
0005434229008	8420	Economy	6000.00
0005433689889	8420	Economy	6000.00
0005433689890	8420	Economy	6000.00
0005432335918	8420	Economy	6000.00
0005432335914	8420	Economy	6000.00
0005432034662	8420	Economy	6000.00
0005435006774	8420	Economy	6000.00
0005432335911	8420	Economy	6000.00
0005435006777	8420	Economy	6000.00
0005435006768	8420	Economy	6600.00
0005434149559	8420	Economy	6600.00
0005434311200	8420	Economy	6600.00
0005434264767	8420	Economy	6600.00
0005432047514	8420	Economy	6000.00
0005434264678	8420	Economy	6000.00
0005435006773	8420	Economy	6000.00
0005433690906	8420	Economy	6000.00
0005432335908	8420	Economy	6000.00
0005435286564	8420	Economy	6000.00
0005432034650	8420	Economy	6000.00
0005435286563	8420	Economy	6000.00
0005435006787	8420	Economy	6000.00
0005434228983	8420	Economy	6000.00
0005432034658	8420	Economy	6000.00
0005432034663	8420	Economy	6000.00
0005434173453	8420	Economy	6000.00
0005432034667	8420	Economy	6000.00
0005434264693	8420	Economy	6000.00
0005434229002	8420	Economy	6000.00
0005432034653	8420	Economy	6000.00
0005432335917	8420	Economy	6000.00
0005432034671	8420	Economy	6000.00
0005432034660	8420	Economy	6000.00
0005433688789	8420	Economy	6000.00
0005432047512	8420	Economy	6000.00
0005434149562	8420	Economy	6000.00
0005435006782	8420	Economy	6000.00
0005433688787	8420	Economy	6000.00
0005435006786	8420	Economy	6000.00
0005433534476	8420	Economy	6000.00
0005435006769	8420	Economy	6000.00
0005432047510	8420	Economy	6000.00
0005432335909	8420	Economy	6000.00
0005432335916	8420	Economy	6000.00
0005434229029	8420	Economy	6000.00
0005432034651	8420	Economy	6000.00
0005432047513	8420	Economy	6000.00
0005433815339	8420	Economy	6000.00
0005433688788	8420	Economy	6000.00
0005435006767	8420	Economy	6000.00
0005435006791	8420	Economy	6000.00
0005434264733	8420	Economy	6000.00
0005432335910	8420	Economy	6000.00
0005432335915	8420	Economy	6000.00
0005435286565	8420	Economy	6000.00
0005434173450	8420	Economy	6000.00
0005432034670	8420	Economy	6000.00
0005435006783	8420	Economy	6000.00
0005434264723	8420	Economy	6000.00
0005432034676	8420	Economy	6000.00
0005432034661	8420	Economy	6000.00
0005432034656	8420	Economy	6000.00
0005434229006	8420	Economy	6000.00
0005434228978	8420	Economy	6000.00
0005433815337	8420	Economy	6000.00
0005435006781	8420	Economy	6000.00
0005434264713	8420	Economy	6000.00
0005434638913	12599	Economy	16200.00
0005433202216	12599	Economy	16200.00
0005434638882	12599	Economy	14800.00
0005434638855	12599	Economy	14800.00
0005433202211	12599	Economy	14800.00
0005434638851	12599	Economy	14800.00
0005434638915	12599	Economy	14800.00
0005433202219	12599	Economy	14800.00
0005434638881	12599	Economy	14800.00
0005433202209	12599	Economy	14800.00
0005433202212	12599	Economy	14800.00
0005434638859	12599	Economy	14800.00
0005433202220	12599	Economy	14800.00
0005434638852	12599	Economy	14800.00
0005434638861	12599	Economy	14800.00
0005433202208	12599	Economy	14800.00
0005433202213	12599	Economy	14800.00
0005433202214	12599	Economy	14800.00
0005433202215	12599	Economy	14800.00
0005433202210	12599	Economy	14800.00
0005434638914	12599	Economy	14800.00
0005433202221	12599	Economy	14800.00
0005433202222	12599	Economy	14800.00
0005433202218	12599	Economy	14800.00
0005433202217	12599	Economy	14800.00
0005434638853	12599	Economy	14800.00
0005434639033	23369	Economy	16200.00
0005434639035	23369	Economy	16200.00
0005434639022	23369	Economy	16200.00
0005434639041	23369	Economy	14800.00
0005434639042	23369	Economy	14800.00
0005434639015	23369	Economy	14800.00
0005434639020	23369	Economy	14800.00
0005434639030	23369	Economy	14800.00
0005432290598	23369	Economy	14800.00
0005434639017	23369	Economy	14800.00
0005434639029	23369	Economy	14800.00
0005434639028	23369	Economy	14800.00
0005434639021	23369	Economy	14800.00
0005434639039	23369	Economy	14800.00
0005434639043	23369	Economy	14800.00
0005434639013	23369	Economy	14800.00
0005434639014	23369	Economy	14800.00
0005434639038	23369	Economy	14800.00
0005432290599	23369	Economy	14800.00
0005434639016	23369	Economy	14800.00
0005434639037	23369	Economy	14800.00
0005434639027	23369	Economy	14800.00
0005434639024	23369	Economy	14800.00
0005434639032	23369	Economy	14800.00
0005434639018	23369	Economy	14800.00
0005434639025	23369	Economy	14800.00
0005434639026	23369	Economy	14800.00
0005432290600	23369	Economy	14800.00
0005434639023	23369	Economy	14800.00
0005434639036	23369	Economy	14800.00
0005434639034	23369	Economy	14800.00
0005434639031	23369	Economy	14800.00
0005434639019	23369	Economy	14800.00
0005434639040	23369	Economy	14800.00
0005432328005	21081	Business	18900.00
0005432327919	21081	Business	18900.00
0005432054275	21081	Economy	6300.00
0005432327906	21081	Economy	6300.00
0005432328033	21081	Economy	6900.00
0005432328034	21081	Economy	6300.00
0005432327905	21081	Economy	6300.00
0005432382511	21081	Economy	6300.00
0005432382520	21081	Economy	6300.00
0005432054274	21081	Economy	6300.00
0005432382532	21081	Economy	6300.00
0005432327930	21081	Economy	6300.00
0005432382531	21081	Economy	6300.00
0005432327901	21081	Economy	6300.00
0005432382541	21081	Economy	6300.00
0005432382586	21081	Economy	6300.00
0005432382556	21081	Economy	6300.00
0005432054273	21081	Economy	6300.00
0005432328004	21081	Economy	6300.00
0005432328006	21081	Economy	6300.00
0005432327902	21081	Economy	6300.00
0005432382533	21081	Economy	6300.00
0005432382555	21081	Economy	6300.00
0005432327931	21081	Economy	6300.00
0005432382746	31248	Business	18900.00
0005432382728	31248	Business	18900.00
0005432328193	31248	Business	18900.00
0005432287132	31248	Business	18900.00
0005432382760	31248	Business	18900.00
0005432328210	31248	Business	18900.00
0005432328206	31248	Business	18900.00
0005432328197	31248	Business	18900.00
0005432328188	31248	Business	18900.00
0005432328174	31248	Business	18900.00
0005432328184	31248	Business	18900.00
0005432382747	31248	Economy	6300.00
0005432328199	31248	Economy	6300.00
0005432328198	31248	Economy	6300.00
0005432328192	31248	Economy	6300.00
0005432328216	31248	Economy	6300.00
0005432382736	31248	Economy	6300.00
0005432328203	31248	Economy	6300.00
0005432382729	31248	Economy	6300.00
0005432382763	31248	Economy	6900.00
0005432328194	31248	Economy	6900.00
0005432328179	31248	Economy	6900.00
0005432382734	31248	Economy	6900.00
0005432328195	31248	Economy	6900.00
0005432328208	31248	Economy	6300.00
0005432382740	31248	Economy	6300.00
0005432382738	31248	Economy	6300.00
0005432328181	31248	Economy	6300.00
0005432328190	31248	Economy	6300.00
0005432382727	31248	Economy	6300.00
0005432382756	31248	Economy	6300.00
0005432328201	31248	Economy	6300.00
0005432382753	31248	Economy	6300.00
0005432328183	31248	Economy	6300.00
0005432382743	31248	Economy	6300.00
0005432382765	31248	Economy	6300.00
0005432328217	31248	Economy	6300.00
0005432382732	31248	Economy	6300.00
0005432382750	31248	Economy	6300.00
0005432382737	31248	Economy	6300.00
0005432382730	31248	Economy	6300.00
0005432328176	31248	Economy	6300.00
0005432382742	31248	Economy	6300.00
0005432328196	31248	Economy	6300.00
0005432382762	31248	Economy	6300.00
0005432382751	31248	Economy	6300.00
0005432328182	31248	Economy	6300.00
0005432382758	31248	Economy	6300.00
0005432382755	31248	Economy	6300.00
0005432328200	31248	Economy	6300.00
0005432382731	31248	Economy	6300.00
0005432328178	31248	Economy	6300.00
0005432382764	31248	Economy	6300.00
0005432382741	31248	Economy	6300.00
0005432287135	31248	Economy	6300.00
0005432382745	31248	Economy	6300.00
0005432328187	31248	Economy	6300.00
0005432382754	31248	Economy	6300.00
0005432328173	31248	Economy	6300.00
0005432328180	31248	Economy	6300.00
0005432328185	31248	Economy	6300.00
0005432328218	31248	Economy	6300.00
0005432382744	31248	Economy	6300.00
0005432328214	31248	Economy	6300.00
0005432382752	31248	Economy	6300.00
0005432328175	31248	Economy	6300.00
0005432382739	31248	Economy	6300.00
0005432328189	31248	Economy	6300.00
0005432328202	31248	Economy	6300.00
0005432328213	31248	Economy	6300.00
0005432382759	31248	Economy	6300.00
0005432328212	31248	Economy	6300.00
0005432328191	31248	Economy	6300.00
0005432328186	31248	Economy	6300.00
0005432382757	31248	Economy	6300.00
0005432382766	31248	Economy	6300.00
0005432382761	31248	Economy	6300.00
0005432382735	31248	Economy	6300.00
0005432328215	31248	Economy	6300.00
0005432382733	31248	Economy	6300.00
0005432328211	31248	Economy	6300.00
0005432287134	31248	Economy	6300.00
0005432382748	31248	Economy	6300.00
0005432382749	31248	Economy	6300.00
0005432328204	31248	Economy	6300.00
0005432287133	31248	Economy	6300.00
0005432328209	31248	Economy	6300.00
0005432328177	31248	Economy	6300.00
0005432328207	31248	Economy	6300.00
0005432328205	31248	Economy	6300.00
0005433642173	2478	Business	89600.00
0005433642191	2478	Business	89600.00
0005433642161	2478	Business	89600.00
0005433642183	2478	Business	89600.00
0005433642153	2478	Business	89600.00
0005433642172	2478	Business	89600.00
0005433642179	2478	Economy	29900.00
0005433642155	2478	Economy	29900.00
0005433642182	2478	Economy	29900.00
0005433642175	2478	Economy	29900.00
0005433642192	2478	Economy	29900.00
0005433642194	2478	Economy	29900.00
0005433642151	2478	Economy	29900.00
0005433642164	2478	Economy	32800.00
0005433642189	2478	Economy	32800.00
0005433642187	2478	Economy	32800.00
0005433642168	2478	Economy	29900.00
0005433642185	2478	Economy	29900.00
0005433642156	2478	Economy	29900.00
0005433642170	2478	Economy	29900.00
0005433642162	2478	Economy	29900.00
0005433642169	2478	Economy	29900.00
0005433642184	2478	Economy	29900.00
0005433642186	2478	Economy	29900.00
0005433642158	2478	Economy	29900.00
0005433642174	2478	Economy	29900.00
0005433642163	2478	Economy	29900.00
0005433642159	2478	Economy	29900.00
0005432953785	2478	Economy	29900.00
0005433642176	2478	Economy	29900.00
0005433642180	2478	Economy	29900.00
0005433642171	2478	Economy	29900.00
0005433642165	2478	Economy	29900.00
0005433642181	2478	Economy	29900.00
0005433642150	2478	Economy	29900.00
0005433642160	2478	Economy	29900.00
0005433642154	2478	Economy	29900.00
0005433642166	2478	Economy	29900.00
0005433642193	2478	Economy	29900.00
0005433642195	2478	Economy	29900.00
0005433642178	2478	Economy	29900.00
0005433642188	2478	Economy	29900.00
0005433642167	2478	Economy	29900.00
0005433642177	2478	Economy	29900.00
0005433642190	2478	Economy	29900.00
0005433642157	2478	Economy	29900.00
0005433642152	2478	Economy	29900.00
0005432423947	13353	Business	12700.00
0005432423939	13353	Business	12700.00
0005432423925	13353	Business	12700.00
0005432423931	13353	Business	12700.00
0005432423936	13353	Economy	4200.00
0005432423948	13353	Economy	4200.00
0005432423914	13353	Economy	4200.00
0005432423952	13353	Economy	4200.00
0005432423910	13353	Economy	4200.00
0005432423927	13353	Economy	4200.00
0005432423923	13353	Economy	4700.00
0005432423934	13353	Economy	4700.00
0005432423911	13353	Economy	4700.00
0005432423928	13353	Economy	4200.00
0005432423929	13353	Economy	4200.00
0005432423912	13353	Economy	4200.00
0005432423945	13353	Economy	4200.00
0005432423953	13353	Economy	4200.00
0005432423913	13353	Economy	4200.00
0005432423954	13353	Economy	4200.00
0005432423951	13353	Economy	4200.00
0005432423920	13353	Economy	4200.00
0005432423935	13353	Economy	4200.00
0005432423933	13353	Economy	4200.00
0005432423926	13353	Economy	4200.00
0005432423916	13353	Economy	4200.00
0005432423941	13353	Economy	4200.00
0005432423940	13353	Economy	4200.00
0005432423930	13353	Economy	4200.00
0005432423949	13353	Economy	4200.00
0005432423924	13353	Economy	4200.00
0005432423942	13353	Economy	4200.00
0005432423921	13353	Economy	4200.00
0005432423955	13353	Economy	4200.00
0005432423922	13353	Economy	4200.00
0005432423946	13353	Economy	4200.00
0005432423918	13353	Economy	4200.00
0005432423932	13353	Economy	4200.00
0005432423950	13353	Economy	4200.00
0005432423937	13353	Economy	4200.00
0005432423917	13353	Economy	4200.00
0005432423919	13353	Economy	4200.00
0005432423943	13353	Economy	4200.00
0005432423944	13353	Economy	4200.00
0005432423938	13353	Economy	4200.00
0005432423915	13353	Economy	4200.00
0005432817169	9626	Business	32600.00
0005432901324	9626	Business	32600.00
0005432817164	9626	Business	32600.00
0005432288952	9626	Business	32600.00
0005434448278	9626	Business	32600.00
0005432901327	9626	Business	32600.00
0005432822123	9626	Business	32600.00
0005432817150	9626	Business	32600.00
0005432822125	9626	Economy	10900.00
0005432822119	9626	Economy	10900.00
0005432817166	9626	Economy	10900.00
0005432817170	9626	Economy	10900.00
0005434157344	9626	Economy	10900.00
0005432901294	9626	Economy	10900.00
0005432817154	9626	Economy	11900.00
0005432817158	9626	Economy	11900.00
0005432822120	9626	Economy	10900.00
0005432901339	9626	Economy	10900.00
0005432817155	9626	Economy	10900.00
0005432817172	9626	Economy	10900.00
0005434186150	9626	Economy	10900.00
0005434186152	9626	Economy	10900.00
0005432817178	9626	Economy	10900.00
0005432817160	9626	Economy	10900.00
0005434186151	9626	Economy	10900.00
0005432901320	9626	Economy	10900.00
0005432822126	9626	Economy	10900.00
0005432817176	9626	Economy	10900.00
0005434157351	9626	Economy	10900.00
0005432817157	9626	Economy	10900.00
0005434448279	9626	Economy	10900.00
0005432817168	9626	Economy	10900.00
0005432817179	9626	Economy	10900.00
0005432901310	9626	Economy	10900.00
0005432817173	9626	Economy	10900.00
0005432817162	9626	Economy	10900.00
0005432288953	9626	Economy	10900.00
0005434157345	9626	Economy	10900.00
0005432817159	9626	Economy	10900.00
0005432817153	9626	Economy	10900.00
0005432817161	9626	Economy	10900.00
0005432822121	9626	Economy	10900.00
0005432817174	9626	Economy	10900.00
0005432817171	9626	Economy	10900.00
0005434448281	9626	Economy	10900.00
0005432817177	9626	Economy	10900.00
0005432817165	9626	Economy	10900.00
0005432822122	9626	Economy	10900.00
0005432901307	9626	Economy	10900.00
0005432817163	9626	Economy	10900.00
0005432901299	9626	Economy	10900.00
0005432901321	9626	Economy	10900.00
0005432817175	9626	Economy	10900.00
0005432901311	9626	Economy	10900.00
0005432822124	9626	Economy	10900.00
0005432817167	9626	Economy	10900.00
0005434448280	9626	Economy	10900.00
0005432817151	9626	Economy	10900.00
0005432901340	9626	Economy	10900.00
0005432817152	9626	Economy	10900.00
0005432288951	9626	Economy	10900.00
0005432817156	9626	Economy	10900.00
0005434157395	28982	Business	32600.00
0005432901421	28982	Business	32600.00
0005432002055	28982	Business	32600.00
0005432901432	28982	Business	32600.00
0005432901419	28982	Business	32600.00
0005434448253	28982	Economy	10900.00
0005432901434	28982	Economy	10900.00
0005432816964	28982	Economy	10900.00
0005434157396	28982	Economy	10900.00
0005432901420	28982	Economy	10900.00
0005432901425	28982	Economy	10900.00
0005434186165	28982	Economy	11900.00
0005432901423	28982	Economy	10900.00
0005432817042	28982	Economy	10900.00
0005432816944	28982	Economy	10900.00
0005432901427	28982	Economy	10900.00
0005432901430	28982	Economy	10900.00
0005432816943	28982	Economy	10900.00
0005434157401	28982	Economy	10900.00
0005434157399	28982	Economy	10900.00
0005434157402	28982	Economy	10900.00
0005432901426	28982	Economy	10900.00
0005432817067	28982	Economy	10900.00
0005432817000	28982	Economy	10900.00
0005432816952	28982	Economy	10900.00
0005432816953	28982	Economy	10900.00
0005434186166	28982	Economy	10900.00
0005432817061	28982	Economy	10900.00
0005432901422	28982	Economy	10900.00
0005432816954	28982	Economy	10900.00
0005434157398	28982	Economy	10900.00
0005432901436	28982	Economy	10900.00
0005432901433	28982	Economy	10900.00
0005432901424	28982	Economy	10900.00
0005434157403	28982	Economy	10900.00
0005434157397	28982	Economy	10900.00
0005434186167	28982	Economy	10900.00
0005432816955	28982	Economy	10900.00
0005432901429	28982	Economy	10900.00
0005432901435	28982	Economy	10900.00
0005432817041	28982	Economy	10900.00
0005434157400	28982	Economy	10900.00
0005432901428	28982	Economy	10900.00
0005432901431	28982	Economy	10900.00
0005432611670	15071	Economy	11000.00
0005432613821	15071	Economy	11000.00
0005432611671	15071	Economy	11000.00
0005432613819	15071	Economy	11000.00
0005432613820	15071	Economy	11000.00
0005432611668	15071	Economy	11000.00
0005432611669	15071	Economy	11000.00
0005432611648	31544	Economy	11000.00
0005433568402	11855	Business	105900.00
0005433568390	11855	Business	105900.00
0005433568417	11855	Business	105900.00
0005433568412	11855	Business	105900.00
0005433568400	11855	Business	105900.00
0005433568420	11855	Business	105900.00
0005433568385	11855	Business	105900.00
0005433568403	11855	Business	105900.00
0005433568394	11855	Business	105900.00
0005433568382	11855	Business	105900.00
0005433568398	11855	Business	105900.00
0005432947798	11855	Economy	35300.00
0005433568378	11855	Economy	35300.00
0005433568381	11855	Economy	35300.00
0005433568397	11855	Economy	35300.00
0005433568406	11855	Economy	35300.00
0005433568389	11855	Economy	35300.00
0005433568386	11855	Economy	38800.00
0005433568408	11855	Economy	35300.00
0005433568395	11855	Economy	35300.00
0005433568409	11855	Economy	35300.00
0005433568405	11855	Economy	35300.00
0005433568392	11855	Economy	35300.00
0005433568401	11855	Economy	35300.00
0005433568419	11855	Economy	35300.00
0005433568377	11855	Economy	35300.00
0005433568404	11855	Economy	35300.00
0005433568414	11855	Economy	35300.00
0005433568383	11855	Economy	35300.00
0005432947773	11855	Economy	35300.00
0005433568415	11855	Economy	35300.00
0005433568413	11855	Economy	35300.00
0005433568380	11855	Economy	35300.00
0005433568399	11855	Economy	35300.00
0005432947826	11855	Economy	35300.00
0005433568396	11855	Economy	35300.00
0005432947774	11855	Economy	35300.00
0005433568416	11855	Economy	35300.00
0005433568421	11855	Economy	35300.00
0005433568418	11855	Economy	35300.00
0005433568379	11855	Economy	35300.00
0005433568391	11855	Economy	35300.00
0005433568411	11855	Economy	35300.00
0005433568407	11855	Economy	35300.00
0005433568387	11855	Economy	35300.00
0005433568422	11855	Economy	35300.00
0005433568376	11855	Economy	35300.00
0005433568410	11855	Economy	35300.00
0005433568388	11855	Economy	35300.00
0005432947812	11855	Economy	35300.00
0005433568375	11855	Economy	35300.00
0005433568374	11855	Economy	35300.00
0005432947830	11855	Economy	35300.00
0005433568384	11855	Economy	35300.00
0005433568393	11855	Economy	35300.00
0005432948060	25272	Business	105900.00
0005432948079	25272	Business	105900.00
0005433568054	25272	Business	105900.00
0005432948071	25272	Business	105900.00
0005432948084	25272	Business	105900.00
0005432948058	25272	Business	105900.00
0005432948059	25272	Business	105900.00
0005432948085	25272	Economy	35300.00
0005432948083	25272	Economy	35300.00
0005432948066	25272	Economy	35300.00
0005432948064	25272	Economy	35300.00
0005432948089	25272	Economy	35300.00
0005432948076	25272	Economy	35300.00
0005432948095	25272	Economy	38800.00
0005432948086	25272	Economy	38800.00
0005432948055	25272	Economy	35300.00
0005432948096	25272	Economy	35300.00
0005432948072	25272	Economy	35300.00
0005432948082	25272	Economy	35300.00
0005432948074	25272	Economy	35300.00
0005432948080	25272	Economy	35300.00
0005432948070	25272	Economy	35300.00
0005432948092	25272	Economy	35300.00
0005432948090	25272	Economy	35300.00
0005432948075	25272	Economy	35300.00
0005432948061	25272	Economy	35300.00
0005432948056	25272	Economy	35300.00
0005432948063	25272	Economy	35300.00
0005432948091	25272	Economy	35300.00
0005432948065	25272	Economy	35300.00
0005432948081	25272	Economy	35300.00
0005432948062	25272	Economy	35300.00
0005432948067	25272	Economy	35300.00
0005432948073	25272	Economy	35300.00
0005432948068	25272	Economy	35300.00
0005432948078	25272	Economy	35300.00
0005432948057	25272	Economy	35300.00
0005432948077	25272	Economy	35300.00
0005433568051	25272	Economy	35300.00
0005432948093	25272	Economy	35300.00
0005432948088	25272	Economy	35300.00
0005432948069	25272	Economy	35300.00
0005432948087	25272	Economy	35300.00
0005433568037	25272	Economy	35300.00
0005432948094	25272	Economy	35300.00
0005433568055	25272	Economy	35300.00
0005433808305	14466	Business	117400.00
0005432430819	14466	Business	117400.00
0005434026682	14466	Business	117400.00
0005432430829	14466	Business	117400.00
0005432430824	14466	Business	117400.00
0005434026685	14466	Economy	39100.00
0005434026684	14466	Economy	39100.00
0005432430821	14466	Economy	39100.00
0005433808304	14466	Economy	39100.00
0005432430820	14466	Economy	39100.00
0005433812861	14466	Economy	39100.00
0005434026686	14466	Economy	39100.00
0005432430822	14466	Economy	39100.00
0005432430826	14466	Economy	39100.00
0005434026681	14466	Economy	39100.00
0005432430828	14466	Economy	39100.00
0005432430823	14466	Economy	39100.00
0005432430827	14466	Economy	39100.00
0005432430825	14466	Economy	39100.00
0005434026683	14466	Economy	39100.00
0005433812870	30828	Business	117400.00
0005433808331	30828	Business	117400.00
0005433808330	30828	Business	117400.00
0005433808328	30828	Business	117400.00
0005433808325	30828	Business	117400.00
0005433808335	30828	Business	117400.00
0005433812864	30828	Business	117400.00
0005433808324	30828	Economy	39100.00
0005433808326	30828	Economy	39100.00
0005433812872	30828	Economy	39100.00
0005433812871	30828	Economy	39100.00
0005433812866	30828	Economy	39100.00
0005433812868	30828	Economy	39100.00
0005433808327	30828	Economy	39100.00
0005433808321	30828	Economy	39100.00
0005433812873	30828	Economy	39100.00
0005433808334	30828	Economy	39100.00
0005433808322	30828	Economy	39100.00
0005433808333	30828	Economy	39100.00
0005433808332	30828	Economy	39100.00
0005433812867	30828	Economy	39100.00
0005433812865	30828	Economy	39100.00
0005433808323	30828	Economy	39100.00
0005433808320	30828	Economy	39100.00
0005433808329	30828	Economy	39100.00
0005433812869	30828	Economy	39100.00
0005434654388	5393	Business	67200.00
0005435340028	5393	Business	67200.00
0005434654390	5393	Business	67200.00
0005432114168	5393	Business	67200.00
0005434654386	5393	Business	67200.00
0005435340023	5393	Economy	22400.00
0005434654396	5393	Economy	22400.00
0005434656534	5393	Economy	22400.00
0005434654374	5393	Economy	24600.00
0005434654376	5393	Economy	22400.00
0005434654370	5393	Economy	22400.00
0005434654385	5393	Economy	22400.00
0005432114169	5393	Economy	22400.00
0005434654375	5393	Economy	22400.00
0005434654377	5393	Economy	22400.00
0005434654382	5393	Economy	22400.00
0005434654389	5393	Economy	22400.00
0005434654398	5393	Economy	22400.00
0005434654397	5393	Economy	22400.00
0005434654393	5393	Economy	22400.00
0005435339993	5393	Economy	22400.00
0005432114170	5393	Economy	22400.00
0005434654391	5393	Economy	22400.00
0005434654384	5393	Economy	22400.00
0005434654379	5393	Economy	22400.00
0005434654378	5393	Economy	22400.00
0005434654383	5393	Economy	22400.00
0005434654387	5393	Economy	22400.00
0005435339999	5393	Economy	22400.00
0005434656537	5393	Economy	22400.00
0005434654369	5393	Economy	22400.00
0005435339998	5393	Economy	22400.00
0005434654373	5393	Economy	22400.00
0005434656535	5393	Economy	22400.00
0005434654395	5393	Economy	22400.00
0005434654394	5393	Economy	22400.00
0005434654392	5393	Economy	22400.00
0005434654372	5393	Economy	22400.00
0005434654371	5393	Economy	22400.00
0005434654380	5393	Economy	22400.00
0005434654381	5393	Economy	22400.00
0005434656536	5393	Economy	22400.00
0005435339994	5393	Economy	22400.00
0005434654226	12528	Business	67200.00
0005434656521	12528	Business	67200.00
0005434654175	12528	Business	67200.00
0005435340099	12528	Business	67200.00
0005435340112	12528	Business	67200.00
0005435340100	12528	Economy	22400.00
0005434654194	12528	Economy	22400.00
0005435340111	12528	Economy	24600.00
0005435340101	12528	Economy	24600.00
0005435340108	12528	Economy	24600.00
0005434654202	12528	Economy	24600.00
0005435555348	12528	Economy	22400.00
0005434654185	12528	Economy	22400.00
0005435340106	12528	Economy	22400.00
0005435340097	12528	Economy	22400.00
0005434654161	12528	Economy	22400.00
0005435340102	12528	Economy	22400.00
0005434656520	12528	Economy	22400.00
0005435340109	12528	Economy	22400.00
0005434654208	12528	Economy	22400.00
0005435340098	12528	Economy	22400.00
0005435340107	12528	Economy	22400.00
0005434654267	12528	Economy	22400.00
0005434654160	12528	Economy	22400.00
0005435555349	12528	Economy	22400.00
0005434654176	12528	Economy	22400.00
0005435340103	12528	Economy	22400.00
0005435555350	12528	Economy	22400.00
0005435340110	12528	Economy	22400.00
0005435340104	12528	Economy	22400.00
0005435340105	12528	Economy	22400.00
0005433715468	7436	Business	32000.00
0005433715429	7436	Business	32000.00
0005433715474	7436	Business	32000.00
0005433715453	7436	Business	32000.00
0005433722153	7436	Business	32000.00
0005433715448	7436	Business	32000.00
0005433715431	7436	Business	32000.00
0005433715466	7436	Business	32000.00
0005433722149	7436	Business	32000.00
0005433715472	7436	Economy	10700.00
0005433722142	7436	Economy	10700.00
0005433715458	7436	Economy	10700.00
0005433715442	7436	Economy	10700.00
0005432078051	7436	Economy	10700.00
0005433719104	7436	Economy	10700.00
0005433715471	7436	Economy	10700.00
0005433715428	7436	Economy	10700.00
0005433715433	7436	Economy	10700.00
0005433715435	7436	Economy	10700.00
0005432078049	7436	Economy	10700.00
0005433715449	7436	Economy	10700.00
0005433715457	7436	Economy	10700.00
0005433715470	7436	Economy	10700.00
0005433688786	7436	Economy	10700.00
0005433715464	7436	Economy	10700.00
0005433715446	7436	Economy	10700.00
0005433715462	7436	Economy	10700.00
0005433715461	7436	Economy	10700.00
0005433656634	7436	Economy	10700.00
0005433719101	7436	Economy	10700.00
0005433715438	7436	Economy	10700.00
0005433722150	7436	Economy	11700.00
0005433715424	7436	Economy	11700.00
0005433715459	7436	Economy	11700.00
0005433715437	7436	Economy	11700.00
0005433689887	7436	Economy	10700.00
0005433715445	7436	Economy	10700.00
0005433722154	7436	Economy	10700.00
0005433715427	7436	Economy	10700.00
0005433722152	7436	Economy	10700.00
0005433715447	7436	Economy	10700.00
0005433715456	7436	Economy	10700.00
0005433715467	7436	Economy	10700.00
0005433715439	7436	Economy	10700.00
0005432078048	7436	Economy	10700.00
0005433715451	7436	Economy	10700.00
0005433715434	7436	Economy	10700.00
0005433715452	7436	Economy	10700.00
0005433715455	7436	Economy	10700.00
0005433722148	7436	Economy	10700.00
0005433715450	7436	Economy	10700.00
0005433715460	7436	Economy	10700.00
0005433722144	7436	Economy	10700.00
0005433715473	7436	Economy	10700.00
0005433715469	7436	Economy	10700.00
0005433715430	7436	Economy	10700.00
0005433715425	7436	Economy	10700.00
0005433722141	7436	Economy	10700.00
0005433715440	7436	Economy	10700.00
0005433722147	7436	Economy	10700.00
0005433689888	7436	Economy	10700.00
0005432078050	7436	Economy	10700.00
0005433719103	7436	Economy	10700.00
0005433722146	7436	Economy	10700.00
0005433715465	7436	Economy	10700.00
0005433690904	7436	Economy	10700.00
0005433688785	7436	Economy	10700.00
0005433715444	7436	Economy	10700.00
0005433715454	7436	Economy	10700.00
0005433722143	7436	Economy	10700.00
0005433690903	7436	Economy	10700.00
0005433656633	7436	Economy	10700.00
0005433715436	7436	Economy	10700.00
0005433715463	7436	Economy	10700.00
0005433722145	7436	Economy	10700.00
0005432078052	7436	Economy	10700.00
0005433715432	7436	Economy	10700.00
0005433715426	7436	Economy	10700.00
0005433715443	7436	Economy	10700.00
0005433719102	7436	Economy	10700.00
0005432078053	7436	Economy	10700.00
0005433722151	7436	Economy	10700.00
0005433715441	7436	Economy	10700.00
0005433715211	29232	Business	32000.00
0005433715219	29232	Business	32000.00
0005433715107	29232	Business	32000.00
0005433715078	29232	Business	32000.00
0005433719087	29232	Business	32000.00
0005432006730	29232	Economy	10700.00
0005435266109	29232	Economy	10700.00
0005435266103	29232	Economy	10700.00
0005433715097	29232	Economy	10700.00
0005433715156	29232	Economy	10700.00
0005433715130	29232	Economy	10700.00
0005435266108	29232	Economy	10700.00
0005433715068	29232	Economy	10700.00
0005432006731	29232	Economy	10700.00
0005433715139	29232	Economy	10700.00
0005433715106	29232	Economy	10700.00
0005432428892	29232	Economy	10700.00
0005435266107	29232	Economy	10700.00
0005432428893	29232	Economy	10700.00
0005433715212	29232	Economy	10700.00
0005433715213	29232	Economy	11700.00
0005432428894	29232	Economy	10700.00
0005433715138	29232	Economy	10700.00
0005433715142	29232	Economy	10700.00
0005435266105	29232	Economy	10700.00
0005433715235	29232	Economy	10700.00
0005435266106	29232	Economy	10700.00
0005433656619	29232	Economy	10700.00
0005433719086	29232	Economy	10700.00
0005433715080	29232	Economy	10700.00
0005433715099	29232	Economy	10700.00
0005433715131	29232	Economy	10700.00
0005433715214	29232	Economy	10700.00
0005433715128	29232	Economy	10700.00
0005432006729	29232	Economy	10700.00
0005433715218	29232	Economy	10700.00
0005435266104	29232	Economy	10700.00
0005434095119	8709	Business	36500.00
0005434184633	8709	Business	36500.00
0005434095120	8709	Business	36500.00
0005434181990	8709	Business	36500.00
0005434181974	8709	Economy	12200.00
0005434181994	8709	Economy	12200.00
0005434095126	8709	Economy	13400.00
0005434181978	8709	Economy	12200.00
0005434095128	8709	Economy	12200.00
0005434181988	8709	Economy	12200.00
0005434095125	8709	Economy	12200.00
0005434095121	8709	Economy	12200.00
0005434095124	8709	Economy	12200.00
0005434095127	8709	Economy	12200.00
0005434095132	8709	Economy	12200.00
0005434095130	8709	Economy	12200.00
0005434095131	8709	Economy	12200.00
0005434181989	8709	Economy	12200.00
0005434095122	8709	Economy	12200.00
0005434095129	8709	Economy	12200.00
0005434095123	8709	Economy	12200.00
0005434181991	8709	Economy	12200.00
0005434181984	8709	Economy	12200.00
0005434184641	11625	Business	36500.00
0005434182059	11625	Business	36500.00
0005434095025	11625	Business	36500.00
0005434182055	11625	Business	36500.00
0005434182056	11625	Economy	12200.00
0005434182057	11625	Economy	12200.00
0005434182054	11625	Economy	12200.00
0005434182048	11625	Economy	13400.00
0005434184642	11625	Economy	12200.00
0005434095024	11625	Economy	12200.00
0005434095050	11625	Economy	12200.00
0005434182058	11625	Economy	12200.00
0005434182053	11625	Economy	12200.00
0005434095028	11625	Economy	12200.00
0005434095051	11625	Economy	12200.00
0005434182047	11625	Economy	12200.00
0005434182049	11625	Economy	12200.00
0005434183556	11625	Economy	12200.00
0005434183557	11625	Economy	12200.00
0005434095048	11625	Economy	12200.00
0005434182052	11625	Economy	12200.00
0005434182051	11625	Economy	12200.00
0005434095043	11625	Economy	12200.00
0005434182050	11625	Economy	12200.00
0005433397191	1420	Business	33000.00
0005435732205	1420	Business	33000.00
0005435732209	1420	Business	33000.00
0005435732213	1420	Business	33000.00
0005435732199	1420	Economy	11000.00
0005435732212	1420	Economy	12100.00
0005433397209	1420	Economy	12100.00
0005433397201	1420	Economy	11000.00
0005435732211	1420	Economy	11000.00
0005435732210	1420	Economy	11000.00
0005435732198	1420	Economy	11000.00
0005433397190	1420	Economy	11000.00
0005435732206	1420	Economy	11000.00
0005435732207	1420	Economy	11000.00
0005432906492	1420	Economy	11000.00
0005433397323	1420	Economy	11000.00
0005435732204	1420	Economy	11000.00
0005433456927	1420	Economy	11000.00
0005433397194	1420	Economy	11000.00
0005433397183	1420	Economy	11000.00
0005435732208	1420	Economy	11000.00
0005432297251	1420	Economy	11000.00
0005435732203	1420	Economy	11000.00
0005432906491	1420	Economy	11000.00
0005435732200	1420	Economy	11000.00
0005435732197	1420	Economy	11000.00
0005433456928	1420	Economy	11000.00
0005433456926	1420	Economy	11000.00
0005433397229	1420	Economy	11000.00
0005435732202	1420	Economy	11000.00
0005433397258	1420	Economy	11000.00
0005435732201	1420	Economy	11000.00
0005435732194	1420	Economy	11000.00
0005435732196	1420	Economy	11000.00
0005435732195	1420	Economy	11000.00
0005433397202	1420	Economy	11000.00
0005433397555	19278	Business	33000.00
0005433397541	19278	Business	33000.00
0005435732123	19278	Business	33000.00
0005435732149	19278	Business	33000.00
0005435732124	19278	Business	33000.00
0005433397554	19278	Business	33000.00
0005433397546	19278	Business	33000.00
0005433397552	19278	Business	33000.00
0005433397542	19278	Economy	11000.00
0005433397563	19278	Economy	11000.00
0005432906509	19278	Economy	11000.00
0005435732118	19278	Economy	11000.00
0005435732128	19278	Economy	11000.00
0005435732112	19278	Economy	12100.00
0005433397537	19278	Economy	12100.00
0005433397540	19278	Economy	12100.00
0005433397550	19278	Economy	11000.00
0005433397569	19278	Economy	11000.00
0005433397553	19278	Economy	11000.00
0005433397573	19278	Economy	11000.00
0005433397571	19278	Economy	11000.00
0005433397561	19278	Economy	11000.00
0005433397556	19278	Economy	11000.00
0005433397530	19278	Economy	11000.00
0005433397538	19278	Economy	11000.00
0005435732148	19278	Economy	11000.00
0005433456906	19278	Economy	11000.00
0005433397567	19278	Economy	11000.00
0005433397535	19278	Economy	11000.00
0005433397527	19278	Economy	11000.00
0005433397565	19278	Economy	11000.00
0005433397576	19278	Economy	11000.00
0005433397560	19278	Economy	11000.00
0005433397551	19278	Economy	11000.00
0005433397539	19278	Economy	11000.00
0005433397572	19278	Economy	11000.00
0005433397547	19278	Economy	11000.00
0005433397526	19278	Economy	11000.00
0005433397574	19278	Economy	11000.00
0005433397528	19278	Economy	11000.00
0005435732127	19278	Economy	11000.00
0005433397559	19278	Economy	11000.00
0005433397531	19278	Economy	11000.00
0005433397548	19278	Economy	11000.00
0005435732117	19278	Economy	11000.00
0005433397562	19278	Economy	11000.00
0005432906510	19278	Economy	11000.00
0005433397536	19278	Economy	11000.00
0005433397570	19278	Economy	11000.00
0005435732116	19278	Economy	11000.00
0005433397534	19278	Economy	11000.00
0005433397544	19278	Economy	11000.00
0005433397532	19278	Economy	11000.00
0005433397543	19278	Economy	11000.00
0005433397549	19278	Economy	11000.00
0005433397564	19278	Economy	11000.00
0005433397566	19278	Economy	11000.00
0005433397568	19278	Economy	11000.00
0005433397557	19278	Economy	11000.00
0005433397533	19278	Economy	11000.00
0005433397545	19278	Economy	11000.00
0005433397529	19278	Economy	11000.00
0005433397558	19278	Economy	11000.00
0005433397575	19278	Economy	11000.00
0005434443447	17391	Economy	14100.00
0005434443538	20573	Economy	15600.00
0005434443531	20573	Economy	15600.00
0005434443529	20573	Economy	14100.00
0005434443530	20573	Economy	14100.00
0005434443532	20573	Economy	14100.00
0005434443525	20573	Economy	14100.00
0005434443533	20573	Economy	14100.00
0005434443527	20573	Economy	14100.00
0005434443536	20573	Economy	14100.00
0005434443534	20573	Economy	14100.00
0005434443528	20573	Economy	14100.00
0005434443523	20573	Economy	14100.00
0005434443535	20573	Economy	14100.00
0005434443522	20573	Economy	14100.00
0005434443537	20573	Economy	14100.00
0005434443526	20573	Economy	14100.00
0005434443524	20573	Economy	14100.00
0005434954566	7233	Economy	5800.00
0005434954568	7233	Economy	5800.00
0005434954567	7233	Economy	5800.00
0005434954570	7233	Economy	5800.00
0005434954569	7233	Economy	5800.00
0005434954547	28301	Economy	5800.00
0005434954548	28301	Economy	5800.00
0005434954540	28301	Economy	5800.00
0005435377555	28301	Economy	5800.00
0005435377554	28301	Economy	5800.00
0005435377553	28301	Economy	5800.00
0005435893506	4470	Economy	14000.00
0005434351564	4470	Economy	14000.00
0005434351566	4470	Economy	14000.00
0005434183543	4470	Economy	14000.00
0005434351557	4470	Economy	14000.00
0005435893505	4470	Economy	14000.00
0005434351562	4470	Economy	14000.00
0005435893507	4470	Economy	14000.00
0005434351560	4470	Economy	14000.00
0005434351559	4470	Economy	14000.00
0005435893520	4470	Economy	14000.00
0005434351567	4470	Economy	14000.00
0005434351563	4470	Economy	14000.00
0005434351558	4470	Economy	14000.00
0005434351561	4470	Economy	14000.00
0005434351565	4470	Economy	14000.00
0005434351556	4470	Economy	14000.00
0005435893555	29669	Economy	14000.00
0005434351465	29669	Economy	14000.00
0005434351506	29669	Economy	14000.00
0005435893560	29669	Economy	14000.00
0005434351468	29669	Economy	14000.00
0005435893558	29669	Economy	14000.00
0005434351475	29669	Economy	14000.00
0005434351482	29669	Economy	14000.00
0005435893554	29669	Economy	14000.00
0005435893557	29669	Economy	14000.00
0005435893559	29669	Economy	14000.00
0005435893556	29669	Economy	14000.00
0005433341387	1047	Business	30600.00
0005432293181	1047	Business	30600.00
0005432293182	1047	Business	30600.00
0005433462724	1047	Business	30600.00
0005433341574	1047	Business	30600.00
0005433462723	1047	Business	30600.00
0005433341538	1047	Business	30600.00
0005435091968	1047	Business	30600.00
0005433463877	1047	Business	30600.00
0005435091965	1047	Business	30600.00
0005434446495	1047	Economy	11200.00
0005433341408	1047	Economy	10200.00
0005433269633	1047	Economy	10200.00
0005433341502	1047	Economy	10200.00
0005434446497	1047	Economy	10200.00
0005433341501	1047	Economy	10200.00
0005433463878	1047	Economy	10200.00
0005435091969	1047	Economy	10200.00
0005433341384	1047	Economy	10200.00
0005435091967	1047	Economy	10200.00
0005435545644	1047	Economy	10200.00
0005433341409	1047	Economy	10200.00
0005435545647	1047	Economy	10200.00
0005433269626	1047	Economy	10200.00
0005433341475	1047	Economy	10200.00
0005435545645	1047	Economy	10200.00
0005435545649	1047	Economy	10200.00
0005433269631	1047	Economy	10200.00
0005433341474	1047	Economy	10200.00
0005433341442	1047	Economy	10200.00
0005433269622	1047	Economy	10200.00
0005435545648	1047	Economy	10200.00
0005433341396	1047	Economy	10200.00
0005435091966	1047	Economy	10200.00
0005435091971	1047	Economy	10200.00
0005433341431	1047	Economy	11200.00
0005435091973	1047	Economy	10200.00
0005433269621	1047	Economy	10200.00
0005434445223	1047	Economy	10200.00
0005435545643	1047	Economy	10200.00
0005435091970	1047	Economy	10200.00
0005433341568	1047	Economy	10200.00
0005435545646	1047	Economy	10200.00
0005433269619	1047	Economy	10200.00
0005432293184	1047	Economy	10200.00
0005432293183	1047	Economy	10200.00
0005433341386	1047	Economy	10200.00
0005435091972	1047	Economy	10200.00
0005433341410	1047	Economy	10200.00
0005433341560	1047	Economy	10200.00
0005433269634	1047	Economy	10200.00
0005434446496	1047	Economy	10200.00
0005433341567	1047	Economy	10200.00
0005433342015	17019	Business	30600.00
0005433342016	17019	Business	30600.00
0005433342064	17019	Business	30600.00
0005435091924	17019	Business	30600.00
0005433342084	17019	Business	30600.00
0005433342056	17019	Business	30600.00
0005433342077	17019	Business	30600.00
0005433342018	17019	Business	30600.00
0005433269661	17019	Business	30600.00
0005435091927	17019	Business	30600.00
0005433341990	17019	Business	30600.00
0005433342029	17019	Business	30600.00
0005433342026	17019	Business	30600.00
0005433342001	17019	Business	30600.00
0005433342088	17019	Business	30600.00
0005433341995	17019	Business	30600.00
0005433342012	17019	Economy	11200.00
0005433342047	17019	Business	30600.00
0005433342058	17019	Economy	11200.00
0005433269663	17019	Economy	11200.00
0005433342024	17019	Economy	10200.00
0005433342053	17019	Economy	10200.00
0005433342030	17019	Economy	10200.00
0005433342081	17019	Economy	10200.00
0005433342022	17019	Economy	10200.00
0005433342075	17019	Economy	10200.00
0005433342051	17019	Economy	10200.00
0005433342055	17019	Economy	10200.00
0005433159289	17019	Economy	10200.00
0005433342062	17019	Economy	10200.00
0005433342066	17019	Economy	10200.00
0005433342072	17019	Economy	10200.00
0005433342010	17019	Economy	10200.00
0005433341994	17019	Economy	10200.00
0005433342013	17019	Economy	10200.00
0005433342060	17019	Economy	10200.00
0005433342011	17019	Economy	10200.00
0005433342008	17019	Economy	10200.00
0005433342038	17019	Economy	10200.00
0005433341996	17019	Economy	10200.00
0005433341989	17019	Economy	10200.00
0005433342043	17019	Economy	10200.00
0005433342042	17019	Economy	10200.00
0005433342074	17019	Economy	10200.00
0005433342005	17019	Economy	10200.00
0005433341992	17019	Economy	10200.00
0005433342033	17019	Economy	10200.00
0005433342063	17019	Economy	10200.00
0005433342050	17019	Economy	10200.00
0005433341993	17019	Economy	10200.00
0005433342020	17019	Economy	10200.00
0005433342027	17019	Economy	10200.00
0005433342039	17019	Economy	10200.00
0005435091917	17019	Economy	10200.00
0005433342025	17019	Economy	10200.00
0005433342028	17019	Economy	10200.00
0005433341999	17019	Economy	10200.00
0005435091914	17019	Economy	10200.00
0005433342037	17019	Economy	10200.00
0005435091920	17019	Economy	10200.00
0005433342006	17019	Economy	10200.00
0005433342086	17019	Economy	10200.00
0005433342023	17019	Economy	10200.00
0005433342041	17019	Economy	10200.00
0005433342068	17019	Economy	10200.00
0005433342036	17019	Economy	10200.00
0005433342031	17019	Economy	10200.00
0005433342009	17019	Economy	10200.00
0005433342054	17019	Economy	10200.00
0005433342082	17019	Economy	10200.00
0005433342052	17019	Economy	10200.00
0005433342067	17019	Economy	10200.00
0005433342071	17019	Economy	11200.00
0005433342048	17019	Economy	11200.00
0005433342002	17019	Economy	10200.00
0005433342040	17019	Economy	10200.00
0005433342000	17019	Economy	10200.00
0005433342049	17019	Economy	10200.00
0005433342044	17019	Economy	10200.00
0005433342070	17019	Economy	10200.00
0005433342032	17019	Economy	10200.00
0005433342076	17019	Economy	10200.00
0005433342019	17019	Economy	10200.00
0005433342014	17019	Economy	10200.00
0005433342065	17019	Economy	10200.00
0005433342078	17019	Economy	10200.00
0005435091915	17019	Economy	10200.00
0005433342061	17019	Economy	10200.00
0005433342004	17019	Economy	10200.00
0005433342057	17019	Economy	10200.00
0005433342079	17019	Economy	10200.00
0005433341998	17019	Economy	10200.00
0005434445210	17019	Economy	10200.00
0005433341991	17019	Economy	10200.00
0005433342046	17019	Economy	10200.00
0005433342007	17019	Economy	10200.00
0005433342059	17019	Economy	10200.00
0005433341988	17019	Economy	10200.00
0005433342021	17019	Economy	10200.00
0005435091925	17019	Economy	10200.00
0005433342034	17019	Economy	10200.00
0005435091932	17019	Economy	10200.00
0005435091926	17019	Economy	10200.00
0005433342017	17019	Economy	10200.00
0005433341997	17019	Economy	10200.00
0005433342073	17019	Economy	10200.00
0005433342069	17019	Economy	10200.00
0005433342035	17019	Economy	10200.00
0005433342087	17019	Economy	10200.00
0005433269662	17019	Economy	10200.00
0005433342003	17019	Economy	10200.00
0005433342045	17019	Economy	10200.00
0005433342080	17019	Economy	10200.00
0005433342083	17019	Economy	10200.00
0005433342085	17019	Economy	10200.00
0005435091901	17019	Economy	10200.00
0005432851856	18272	Business	101000.00
0005432851854	18272	Business	101000.00
0005432851863	18272	Business	101000.00
0005432851844	18272	Business	101000.00
0005432851845	18272	Business	101000.00
0005432851858	18272	Economy	33700.00
0005432851851	18272	Economy	33700.00
0005432851861	18272	Economy	33700.00
0005432851852	18272	Economy	33700.00
0005432851842	18272	Economy	33700.00
0005432851850	18272	Economy	33700.00
0005432391946	18272	Economy	33700.00
0005432851847	18272	Economy	33700.00
0005432389947	18272	Economy	33700.00
0005432389952	18272	Economy	33700.00
0005432851855	18272	Economy	33700.00
0005432389946	18272	Economy	33700.00
0005432851846	18272	Economy	33700.00
0005432851841	18272	Economy	33700.00
0005432391947	18272	Economy	33700.00
0005432851853	18272	Economy	33700.00
0005432851857	18272	Economy	33700.00
0005432851859	18272	Economy	33700.00
0005432851862	18272	Economy	33700.00
0005432851849	18272	Economy	33700.00
0005432851843	18272	Economy	33700.00
0005432851860	18272	Economy	33700.00
0005432851848	18272	Economy	33700.00
0005432389951	18272	Economy	33700.00
0005432433621	12812	Business	40300.00
0005434066440	12812	Business	40300.00
0005434066433	12812	Business	40300.00
0005434066313	12812	Business	40300.00
0005434066328	12812	Business	40300.00
0005434066299	12812	Economy	13400.00
0005434066311	12812	Economy	13400.00
0005432433624	12812	Economy	13400.00
0005432159808	12812	Economy	13400.00
0005434081558	12812	Economy	13400.00
0005434066327	12812	Economy	13400.00
0005433812875	12812	Economy	13400.00
0005434066434	12812	Economy	14800.00
0005432159811	12812	Economy	13400.00
0005434066394	12812	Economy	13400.00
0005434066297	12812	Economy	13400.00
0005432161128	12812	Economy	13400.00
0005434081474	12812	Economy	13400.00
0005432433623	12812	Economy	13400.00
0005433812874	12812	Economy	13400.00
0005432159810	12812	Economy	13400.00
0005434066298	12812	Economy	13400.00
0005434066300	12812	Economy	13400.00
0005434081510	12812	Economy	13400.00
0005434066442	12812	Economy	13400.00
0005432433620	12812	Economy	13400.00
0005432159809	12812	Economy	13400.00
0005432159807	12812	Economy	13400.00
0005434066306	12812	Economy	13400.00
0005432433622	12812	Economy	13400.00
0005434066348	12812	Economy	13400.00
0005434081557	12812	Economy	13400.00
0005433989688	12812	Economy	13400.00
0005432433625	12812	Economy	13400.00
0005434081485	12812	Economy	13400.00
0005434066441	12812	Economy	13400.00
0005434066422	12812	Economy	13400.00
0005434066746	30691	Business	40300.00
0005434066795	30691	Business	40300.00
0005434081636	30691	Business	40300.00
0005434066751	30691	Business	40300.00
0005434081637	30691	Business	40300.00
0005434066761	30691	Business	40300.00
0005432186829	30691	Business	40300.00
0005434066756	30691	Business	40300.00
0005434066755	30691	Business	40300.00
0005434066794	30691	Business	40300.00
0005434066736	30691	Business	40300.00
0005434066803	30691	Business	40300.00
0005434081638	30691	Economy	13400.00
0005434066764	30691	Economy	13400.00
0005434081650	30691	Economy	13400.00
0005433989715	30691	Economy	13400.00
0005434066798	30691	Economy	13400.00
0005434081630	30691	Economy	13400.00
0005434066743	30691	Economy	13400.00
0005434081652	30691	Economy	13400.00
0005434066797	30691	Economy	13400.00
0005434066779	30691	Economy	13400.00
0005434066758	30691	Economy	13400.00
0005434066789	30691	Economy	13400.00
0005434066791	30691	Economy	13400.00
0005434081647	30691	Economy	13400.00
0005432186830	30691	Economy	13400.00
0005432150107	30691	Economy	13400.00
0005434066777	30691	Economy	13400.00
0005433989717	30691	Economy	13400.00
0005434081646	30691	Economy	13400.00
0005434066787	30691	Economy	13400.00
0005434066802	30691	Economy	13400.00
0005434081632	30691	Economy	13400.00
0005433989719	30691	Economy	13400.00
0005434066766	30691	Economy	13400.00
0005434066741	30691	Economy	13400.00
0005434066765	30691	Economy	13400.00
0005432186828	30691	Economy	13400.00
0005432150104	30691	Economy	13400.00
0005433989718	30691	Economy	13400.00
0005434066769	30691	Economy	13400.00
0005434066784	30691	Economy	13400.00
0005434081629	30691	Economy	13400.00
0005434066781	30691	Economy	13400.00
0005434066778	30691	Economy	13400.00
0005434066760	30691	Economy	13400.00
0005434066740	30691	Economy	13400.00
0005434066732	30691	Economy	13400.00
0005434066783	30691	Economy	14800.00
0005434081645	30691	Economy	14800.00
0005432150103	30691	Economy	14800.00
0005432150109	30691	Economy	14800.00
0005434066745	30691	Economy	14800.00
0005434081639	30691	Economy	13400.00
0005434066800	30691	Economy	13400.00
0005432150108	30691	Economy	13400.00
0005434066786	30691	Economy	13400.00
0005434066759	30691	Economy	13400.00
0005434066776	30691	Economy	13400.00
0005434066788	30691	Economy	13400.00
0005432186827	30691	Economy	13400.00
0005434081648	30691	Economy	13400.00
0005432433599	30691	Economy	13400.00
0005434066744	30691	Economy	13400.00
0005434066731	30691	Economy	13400.00
0005434066742	30691	Economy	13400.00
0005432150105	30691	Economy	13400.00
0005434066773	30691	Economy	13400.00
0005434081649	30691	Economy	13400.00
0005433989716	30691	Economy	13400.00
0005434066770	30691	Economy	13400.00
0005434066754	30691	Economy	13400.00
0005434066738	30691	Economy	13400.00
0005434081644	30691	Economy	13400.00
0005434066775	30691	Economy	13400.00
0005434066792	30691	Economy	13400.00
0005434066750	30691	Economy	13400.00
0005434066790	30691	Economy	13400.00
0005434066763	30691	Economy	13400.00
0005434066767	30691	Economy	13400.00
0005434066733	30691	Economy	13400.00
0005434066785	30691	Economy	13400.00
0005434066772	30691	Economy	13400.00
0005434066771	30691	Economy	13400.00
0005434081643	30691	Economy	13400.00
0005434081640	30691	Economy	13400.00
0005434066730	30691	Economy	13400.00
0005434081635	30691	Economy	13400.00
0005434066753	30691	Economy	13400.00
0005434066748	30691	Economy	13400.00
0005434081642	30691	Economy	13400.00
0005432150106	30691	Economy	13400.00
0005434066734	30691	Economy	13400.00
0005434066774	30691	Economy	13400.00
0005434066793	30691	Economy	13400.00
0005434081631	30691	Economy	13400.00
0005434066752	30691	Economy	13400.00
0005434066762	30691	Economy	13400.00
0005434066747	30691	Economy	13400.00
0005434081633	30691	Economy	13400.00
0005434066757	30691	Economy	13400.00
0005434081651	30691	Economy	13400.00
0005434081626	30691	Economy	13400.00
0005434066782	30691	Economy	13400.00
0005434066801	30691	Economy	13400.00
0005434066735	30691	Economy	13400.00
0005434081628	30691	Economy	13400.00
0005432433600	30691	Economy	13400.00
0005434066796	30691	Economy	13400.00
0005434066739	30691	Economy	13400.00
0005434066768	30691	Economy	13400.00
0005434066749	30691	Economy	13400.00
0005434081627	30691	Economy	13400.00
0005434066780	30691	Economy	13400.00
0005434081641	30691	Economy	13400.00
0005434066737	30691	Economy	13400.00
0005434066799	30691	Economy	13400.00
0005434081634	30691	Economy	13400.00
0005433689875	19355	Economy	17600.00
0005435461817	5545	Business	35300.00
0005435735087	5545	Business	35300.00
0005435725542	5545	Business	35300.00
0005435461917	5545	Business	35300.00
0005435765585	5545	Business	35300.00
0005435725546	5545	Business	35300.00
0005435765568	5545	Business	35300.00
0005435735088	5545	Business	35300.00
0005435722030	5545	Business	35300.00
0005435461792	5545	Business	35300.00
0005435461763	5545	Business	35300.00
0005435765605	5545	Business	35300.00
0005435765593	5545	Business	35300.00
0005435765587	5545	Business	35300.00
0005435765578	5545	Business	35300.00
0005435765592	5545	Business	35300.00
0005435765588	5545	Economy	12900.00
0005435765596	5545	Economy	12900.00
0005435765559	5545	Economy	12900.00
0005435765604	5545	Economy	11800.00
0005435765580	5545	Economy	11800.00
0005435765583	5545	Economy	11800.00
0005435765548	5545	Economy	11800.00
0005435765551	5545	Economy	11800.00
0005435765575	5545	Economy	11800.00
0005432140359	5545	Economy	11800.00
0005435765601	5545	Economy	11800.00
0005435765594	5545	Economy	11800.00
0005435765556	5545	Economy	11800.00
0005435765600	5545	Economy	11800.00
0005435765597	5545	Economy	11800.00
0005435765589	5545	Economy	11800.00
0005435765598	5545	Economy	11800.00
0005435725544	5545	Economy	11800.00
0005435765595	5545	Economy	11800.00
0005433527229	5545	Economy	11800.00
0005433529240	5545	Economy	11800.00
0005435765569	5545	Economy	11800.00
0005435765576	5545	Economy	11800.00
0005435765571	5545	Economy	11800.00
0005432140365	5545	Economy	11800.00
0005435461772	5545	Economy	11800.00
0005435765562	5545	Economy	11800.00
0005435765574	5545	Economy	11800.00
0005435765584	5545	Economy	11800.00
0005432140360	5545	Economy	11800.00
0005434264682	5545	Economy	11800.00
0005432140363	5545	Economy	11800.00
0005435765573	5545	Economy	11800.00
0005435765581	5545	Economy	11800.00
0005433527226	5545	Economy	11800.00
0005435461825	5545	Economy	11800.00
0005435765554	5545	Economy	11800.00
0005435765599	5545	Economy	11800.00
0005435720813	5545	Economy	11800.00
0005435735086	5545	Economy	11800.00
0005435461818	5545	Economy	11800.00
0005433527230	5545	Economy	11800.00
0005435765608	5545	Economy	11800.00
0005435765566	5545	Economy	11800.00
0005435735089	5545	Economy	11800.00
0005435765590	5545	Economy	11800.00
0005435765579	5545	Economy	11800.00
0005435722029	5545	Economy	11800.00
0005434264675	5545	Economy	11800.00
0005435765567	5545	Economy	11800.00
0005435461766	5545	Economy	11800.00
0005435765586	5545	Economy	11800.00
0005435765606	5545	Economy	11800.00
0005435765607	5545	Economy	11800.00
0005435765558	5545	Economy	12900.00
0005435725543	5545	Economy	12900.00
0005435765550	5545	Economy	11800.00
0005435765603	5545	Economy	12900.00
0005435765582	5545	Economy	12900.00
0005435765557	5545	Economy	11800.00
0005435765563	5545	Economy	11800.00
0005432140362	5545	Economy	11800.00
0005435461824	5545	Economy	11800.00
0005435765572	5545	Economy	11800.00
0005434264706	5545	Economy	11800.00
0005435765561	5545	Economy	11800.00
0005435461765	5545	Economy	11800.00
0005435461769	5545	Economy	11800.00
0005433529239	5545	Economy	11800.00
0005434264695	5545	Economy	11800.00
0005435720814	5545	Economy	11800.00
0005435723023	5545	Economy	11800.00
0005435765565	5545	Economy	11800.00
0005435765549	5545	Economy	11800.00
0005432140364	5545	Economy	11800.00
0005435461916	5545	Economy	11800.00
0005434264707	5545	Economy	11800.00
0005433527228	5545	Economy	11800.00
0005435725545	5545	Economy	11800.00
0005433529238	5545	Economy	11800.00
0005435765564	5545	Economy	11800.00
0005435765602	5545	Economy	11800.00
0005435765560	5545	Economy	11800.00
0005435765555	5545	Economy	11800.00
0005433529237	5545	Economy	11800.00
0005435765570	5545	Economy	11800.00
0005434264718	5545	Economy	11800.00
0005435461773	5545	Economy	11800.00
0005435461762	5545	Economy	11800.00
0005433529241	5545	Economy	11800.00
0005435765552	5545	Economy	11800.00
0005435723024	5545	Economy	11800.00
0005432140357	5545	Economy	11800.00
0005432140361	5545	Economy	11800.00
0005435765577	5545	Economy	11800.00
0005435765591	5545	Economy	11800.00
0005433527227	5545	Economy	11800.00
0005435461786	5545	Economy	11800.00
0005432140358	5545	Economy	11800.00
0005435765553	5545	Economy	11800.00
0005434264875	13461	Business	35300.00
0005435462049	13461	Business	35300.00
0005434831101	13461	Business	35300.00
0005435462061	13461	Business	35300.00
0005435765161	13461	Business	35300.00
0005435462044	13461	Business	35300.00
0005434264865	13461	Business	35300.00
0005435462063	13461	Business	35300.00
0005434264867	13461	Business	35300.00
0005434264878	13461	Business	35300.00
0005432194469	13461	Business	35300.00
0005435462056	13461	Business	35300.00
0005434264868	13461	Economy	12900.00
0005435462040	13461	Economy	11800.00
0005435462032	13461	Economy	11800.00
0005435462033	13461	Economy	11800.00
0005432535785	13461	Economy	11800.00
0005435765128	13461	Economy	11800.00
0005435765189	13461	Economy	11800.00
0005435462048	13461	Economy	11800.00
0005435765171	13461	Economy	11800.00
0005435462047	13461	Economy	11800.00
0005435765241	13461	Economy	11800.00
0005435462065	13461	Economy	11800.00
0005435462029	13461	Economy	11800.00
0005435765335	13461	Economy	11800.00
0005435462036	13461	Economy	11800.00
0005434264864	13461	Economy	11800.00
0005435462028	13461	Economy	11800.00
0005435765124	13461	Economy	11800.00
0005435462038	13461	Economy	11800.00
0005435765314	13461	Economy	11800.00
0005434264881	13461	Economy	11800.00
0005435765271	13461	Economy	11800.00
0005435765152	13461	Economy	11800.00
0005435462045	13461	Economy	11800.00
0005435765333	13461	Economy	11800.00
0005435462042	13461	Economy	11800.00
0005432535783	13461	Economy	11800.00
0005434264872	13461	Economy	11800.00
0005435462052	13461	Economy	11800.00
0005435765153	13461	Economy	11800.00
0005432194467	13461	Economy	11800.00
0005435765138	13461	Economy	11800.00
0005435765168	13461	Economy	11800.00
0005434264879	13461	Economy	11800.00
0005435462035	13461	Economy	11800.00
0005435462039	13461	Economy	11800.00
0005435462043	13461	Economy	11800.00
0005434264863	13461	Economy	11800.00
0005435765336	13461	Economy	11800.00
0005435765315	13461	Economy	11800.00
0005434264882	13461	Economy	11800.00
0005434264861	13461	Economy	11800.00
0005435765188	13461	Economy	11800.00
0005434831104	13461	Economy	11800.00
0005435462057	13461	Economy	11800.00
0005434264886	13461	Economy	11800.00
0005435462027	13461	Economy	11800.00
0005434264876	13461	Economy	11800.00
0005434264884	13461	Economy	12900.00
0005435765170	13461	Economy	11800.00
0005432535784	13461	Economy	11800.00
0005435462051	13461	Economy	11800.00
0005435462054	13461	Economy	11800.00
0005434831102	13461	Economy	11800.00
0005435462046	13461	Economy	11800.00
0005432535781	13461	Economy	11800.00
0005435462059	13461	Economy	11800.00
0005434264873	13461	Economy	11800.00
0005434264862	13461	Economy	11800.00
0005435765214	13461	Economy	11800.00
0005435462037	13461	Economy	11800.00
0005434264883	13461	Economy	11800.00
0005435462050	13461	Economy	11800.00
0005434831100	13461	Economy	11800.00
0005434264871	13461	Economy	11800.00
0005434264877	13461	Economy	11800.00
0005435765334	13461	Economy	11800.00
0005435462053	13461	Economy	11800.00
0005435462062	13461	Economy	11800.00
0005435462034	13461	Economy	11800.00
0005435765167	13461	Economy	11800.00
0005435462041	13461	Economy	11800.00
0005435462060	13461	Economy	11800.00
0005432194465	13461	Economy	11800.00
0005435462064	13461	Economy	11800.00
0005435462055	13461	Economy	11800.00
0005435462031	13461	Economy	11800.00
0005434264866	13461	Economy	11800.00
0005432535782	13461	Economy	11800.00
0005434831105	13461	Economy	11800.00
0005435765220	13461	Economy	11800.00
0005435462058	13461	Economy	11800.00
0005435462030	13461	Economy	11800.00
0005434831103	13461	Economy	11800.00
0005434264869	13461	Economy	11800.00
0005434264880	13461	Economy	11800.00
0005434264885	13461	Economy	11800.00
0005434264874	13461	Economy	11800.00
0005435765305	13461	Economy	11800.00
0005435765127	13461	Economy	11800.00
0005435765281	13461	Economy	11800.00
0005435765282	13461	Economy	11800.00
0005434264870	13461	Economy	11800.00
0005432194468	13461	Economy	11800.00
0005432194466	13461	Economy	11800.00
0005434514937	18746	Economy	3300.00
0005434513550	18746	Economy	3300.00
0005434514939	18746	Economy	3300.00
0005434514938	18746	Economy	3300.00
0005434513549	18746	Economy	3300.00
0005434514923	19184	Economy	3300.00
0005434514928	19184	Economy	3300.00
0005434514927	19184	Economy	3300.00
0005434514922	19184	Economy	3300.00
0005435844282	25089	Business	88300.00
0005432632627	25089	Business	88300.00
0005435844276	25089	Economy	29400.00
0005435844271	25089	Economy	29400.00
0005435846214	25089	Economy	32400.00
0005432649303	25089	Economy	32400.00
0005435844279	25089	Economy	29400.00
0005435846216	25089	Economy	29400.00
0005435846210	25089	Economy	29400.00
0005435844274	25089	Economy	29400.00
0005435844281	25089	Economy	29400.00
0005435844273	25089	Economy	29400.00
0005435844275	25089	Economy	29400.00
0005432649296	25089	Economy	29400.00
0005435844280	25089	Economy	29400.00
0005435846213	25089	Economy	29400.00
0005435846211	25089	Economy	29400.00
0005435846215	25089	Economy	29400.00
0005435844277	25089	Economy	29400.00
0005435846212	25089	Economy	29400.00
0005432649307	25089	Economy	29400.00
0005432649302	25089	Economy	29400.00
0005435844272	25089	Economy	29400.00
0005435844278	25089	Economy	29400.00
0005435846217	25089	Economy	29400.00
0005432649297	25089	Economy	29400.00
0005433007987	1852	Business	48700.00
0005433007848	1852	Economy	16200.00
0005433007986	1852	Economy	16200.00
0005433007929	1852	Economy	17900.00
0005432295852	1852	Economy	17900.00
0005433008006	1852	Economy	16200.00
0005433007899	1852	Economy	16200.00
0005433007822	1852	Economy	16200.00
0005433284772	1852	Economy	16200.00
0005433007847	1852	Economy	16200.00
0005432295851	1852	Economy	16200.00
0005432295854	1852	Economy	16200.00
0005433284771	1852	Economy	16200.00
0005433007868	1852	Economy	16200.00
0005433007860	1852	Economy	16200.00
0005433007910	1852	Economy	16200.00
0005433007911	1852	Economy	16200.00
0005433007876	1852	Economy	16200.00
0005433007834	1852	Economy	16200.00
0005433007875	1852	Economy	16200.00
0005433284769	1852	Economy	16200.00
0005432295853	1852	Economy	16200.00
0005433007877	1852	Economy	16200.00
0005433007985	1852	Economy	16200.00
0005433008142	22628	Business	48700.00
0005433284948	22628	Business	48700.00
0005433008115	22628	Business	48700.00
0005433284955	22628	Business	48700.00
0005433284946	22628	Business	48700.00
0005433008120	22628	Business	48700.00
0005433284963	22628	Business	48700.00
0005433284949	22628	Business	48700.00
0005433008108	22628	Business	48700.00
0005433008101	22628	Business	48700.00
0005433284960	22628	Economy	16200.00
0005433008137	22628	Economy	16200.00
0005433008145	22628	Economy	16200.00
0005433008131	22628	Economy	16200.00
0005433284970	22628	Economy	16200.00
0005433008146	22628	Economy	16200.00
0005433008144	22628	Economy	16200.00
0005433008111	22628	Economy	16200.00
0005433008139	22628	Economy	16200.00
0005433284961	22628	Economy	17900.00
0005433008124	22628	Economy	17900.00
0005433008104	22628	Economy	17900.00
0005433008130	22628	Economy	17900.00
0005433284971	22628	Economy	17900.00
0005433008117	22628	Economy	16200.00
0005433284952	22628	Economy	16200.00
0005433284967	22628	Economy	16200.00
0005433008140	22628	Economy	16200.00
0005433284964	22628	Economy	16200.00
0005433008135	22628	Economy	16200.00
0005433284953	22628	Economy	16200.00
0005433008126	22628	Economy	16200.00
0005433284965	22628	Economy	16200.00
0005433284945	22628	Economy	16200.00
0005433008136	22628	Economy	16200.00
0005433008119	22628	Economy	16200.00
0005433008102	22628	Economy	16200.00
0005433008141	22628	Economy	16200.00
0005433008107	22628	Economy	16200.00
0005433008129	22628	Economy	16200.00
0005433284958	22628	Economy	16200.00
0005433284973	22628	Economy	16200.00
0005433284969	22628	Economy	16200.00
0005433284947	22628	Economy	16200.00
0005433284951	22628	Economy	16200.00
0005433008132	22628	Economy	16200.00
0005433008138	22628	Economy	16200.00
0005433284956	22628	Economy	16200.00
0005433008123	22628	Economy	16200.00
0005433008118	22628	Economy	16200.00
0005433284966	22628	Economy	16200.00
0005433284943	22628	Economy	16200.00
0005433284944	22628	Economy	16200.00
0005433008105	22628	Economy	16200.00
0005433008103	22628	Economy	16200.00
0005433284968	22628	Economy	16200.00
0005433008114	22628	Economy	16200.00
0005433008125	22628	Economy	16200.00
0005433008143	22628	Economy	16200.00
0005433008106	22628	Economy	16200.00
0005433008110	22628	Economy	16200.00
0005433284957	22628	Economy	16200.00
0005433008128	22628	Economy	16200.00
0005433008112	22628	Economy	16200.00
0005433008122	22628	Economy	16200.00
0005433284954	22628	Economy	16200.00
0005433284962	22628	Economy	16200.00
0005433008109	22628	Economy	16200.00
0005433008100	22628	Economy	16200.00
0005433008134	22628	Economy	16200.00
0005433284974	22628	Economy	16200.00
0005433284950	22628	Economy	16200.00
0005433008133	22628	Economy	16200.00
0005433008116	22628	Economy	16200.00
0005433008127	22628	Economy	16200.00
0005433008121	22628	Economy	16200.00
0005433284959	22628	Economy	16200.00
0005433284972	22628	Economy	16200.00
0005433008113	22628	Economy	16200.00
0005432755032	25331	Business	83800.00
0005432756803	25331	Business	83800.00
0005432755027	25331	Business	83800.00
0005432755031	25331	Business	83800.00
0005432755038	25331	Business	83800.00
0005432756801	25331	Economy	27900.00
0005432756804	25331	Economy	27900.00
0005432756808	25331	Economy	27900.00
0005432755029	25331	Economy	30700.00
0005432755034	25331	Economy	30700.00
0005432755035	25331	Economy	27900.00
0005432756807	25331	Economy	27900.00
0005432755030	25331	Economy	27900.00
0005432756797	25331	Economy	27900.00
0005432755037	25331	Economy	27900.00
0005432756798	25331	Economy	27900.00
0005432755036	25331	Economy	27900.00
0005432756802	25331	Economy	27900.00
0005432756809	25331	Economy	27900.00
0005432756800	25331	Economy	27900.00
0005432755026	25331	Economy	27900.00
0005432756805	25331	Economy	27900.00
0005432755028	25331	Economy	27900.00
0005432756806	25331	Economy	27900.00
0005432756810	25331	Economy	27900.00
0005432755033	25331	Economy	27900.00
0005432756799	25331	Economy	27900.00
0005433846115	5555	Business	99800.00
0005435282077	5555	Business	99800.00
0005435282059	5555	Business	99800.00
0005433846098	5555	Business	99800.00
0005432081442	5555	Business	99800.00
0005435282097	5555	Business	99800.00
0005432081443	5555	Business	99800.00
0005435282128	5555	Business	99800.00
0005433846103	5555	Business	99800.00
0005433846099	5555	Business	99800.00
0005433846132	5555	Business	99800.00
0005433846119	5555	Business	99800.00
0005433846092	5555	Business	99800.00
0005433846085	5555	Business	99800.00
0005433846116	5555	Business	99800.00
0005433846105	5555	Economy	33300.00
0005433846123	5555	Business	99800.00
0005433846131	5555	Economy	33300.00
0005432081444	5555	Economy	33300.00
0005433846107	5555	Economy	33300.00
0005433815335	5555	Economy	33300.00
0005433846125	5555	Economy	33300.00
0005433846101	5555	Economy	33300.00
0005433846129	5555	Economy	33300.00
0005433846113	5555	Economy	33300.00
0005433846118	5555	Economy	33300.00
0005435282076	5555	Economy	33300.00
0005433846090	5555	Economy	33300.00
0005433846088	5555	Economy	33300.00
0005433846120	5555	Economy	33300.00
0005433846106	5555	Economy	33300.00
0005433846126	5555	Economy	33300.00
0005433846130	5555	Economy	33300.00
0005433846100	5555	Economy	33300.00
0005433846089	5555	Economy	33300.00
0005433846128	5555	Economy	33300.00
0005433846086	5555	Economy	33300.00
0005433846087	5555	Economy	33300.00
0005433815332	5555	Economy	33300.00
0005433846134	5555	Economy	33300.00
0005433846135	5555	Economy	33300.00
0005433846127	5555	Economy	33300.00
0005435282061	5555	Economy	33300.00
0005433846137	5555	Economy	33300.00
0005433815331	5555	Economy	33300.00
0005433815330	5555	Economy	33300.00
0005433846114	5555	Economy	33300.00
0005433846138	5555	Economy	33300.00
0005435282129	5555	Economy	33300.00
0005433846111	5555	Economy	33300.00
0005433846112	5555	Economy	33300.00
0005433846122	5555	Economy	33300.00
0005435282079	5555	Economy	33300.00
0005435282060	5555	Economy	33300.00
0005433846104	5555	Economy	33300.00
0005433846082	5555	Economy	33300.00
0005433846117	5555	Economy	33300.00
0005435282062	5555	Economy	33300.00
0005435282049	5555	Economy	33300.00
0005433846097	5555	Economy	33300.00
0005433846110	5555	Economy	33300.00
0005433846121	5555	Economy	33300.00
0005433846139	5555	Economy	33300.00
0005435282075	5555	Economy	33300.00
0005433846108	5555	Economy	33300.00
0005433846140	5555	Economy	33300.00
0005433846083	5555	Economy	33300.00
0005433846093	5555	Economy	33300.00
0005433846109	5555	Economy	33300.00
0005433846136	5555	Economy	33300.00
0005433846096	5555	Economy	33300.00
0005433846095	5555	Economy	33300.00
0005433846084	5555	Economy	33300.00
0005433815333	5555	Economy	33300.00
0005433846094	5555	Economy	33300.00
0005433846124	5555	Economy	33300.00
0005433815334	5555	Economy	33300.00
0005435282063	5555	Economy	33300.00
0005433846091	5555	Economy	33300.00
0005433846102	5555	Economy	33300.00
0005435282069	5555	Economy	33300.00
0005433846133	5555	Economy	33300.00
0005432081445	5555	Economy	33300.00
0005433845665	13882	Business	99800.00
0005435282242	13882	Business	99800.00
0005435282235	13882	Business	99800.00
0005433845762	13882	Business	99800.00
0005432003670	13882	Business	99800.00
0005433845810	13882	Business	99800.00
0005433845806	13882	Business	99800.00
0005432003668	13882	Business	99800.00
0005435282249	13882	Business	99800.00
0005435282259	13882	Business	99800.00
0005435282244	13882	Economy	33300.00
0005435282260	13882	Economy	33300.00
0005434173478	13882	Economy	33300.00
0005435282256	13882	Economy	33300.00
0005433845669	13882	Economy	33300.00
0005433845664	13882	Economy	33300.00
0005433845853	13882	Economy	33300.00
0005433845666	13882	Economy	33300.00
0005434173480	13882	Economy	33300.00
0005433845808	13882	Economy	33300.00
0005435282238	13882	Economy	33300.00
0005433845842	13882	Economy	33300.00
0005433845668	13882	Economy	33300.00
0005433845771	13882	Economy	33300.00
0005435282253	13882	Economy	33300.00
0005435282248	13882	Economy	33300.00
0005435282232	13882	Economy	33300.00
0005435282234	13882	Economy	33300.00
0005433845739	13882	Economy	33300.00
0005433845824	13882	Economy	33300.00
0005435282239	13882	Economy	33300.00
0005433845812	13882	Economy	33300.00
0005435282233	13882	Economy	33300.00
0005435282241	13882	Economy	33300.00
0005433845813	13882	Economy	33300.00
0005435282237	13882	Economy	33300.00
0005433845854	13882	Economy	33300.00
0005435282250	13882	Economy	33300.00
0005435282236	13882	Economy	33300.00
0005435282254	13882	Economy	33300.00
0005435282252	13882	Economy	33300.00
0005432003669	13882	Economy	33300.00
0005435282247	13882	Economy	33300.00
0005435282255	13882	Economy	33300.00
0005433815300	13882	Economy	33300.00
0005434173479	13882	Economy	33300.00
0005435282257	13882	Economy	33300.00
0005435282243	13882	Economy	33300.00
0005433845772	13882	Economy	33300.00
0005433845663	13882	Economy	33300.00
0005435282258	13882	Economy	33300.00
0005433845738	13882	Economy	33300.00
0005433845761	13882	Economy	33300.00
0005433845857	13882	Economy	33300.00
0005433845805	13882	Economy	33300.00
0005435282240	13882	Economy	33300.00
0005433845811	13882	Economy	33300.00
0005435282251	13882	Economy	33300.00
0005435282245	13882	Economy	33300.00
0005435282246	13882	Economy	33300.00
0005434620376	7846	Economy	16600.00
0005434620383	7846	Economy	16600.00
0005434620385	7846	Economy	15100.00
0005432112492	7846	Economy	15100.00
0005435332150	7846	Economy	15100.00
0005435332172	7846	Economy	15100.00
0005434620378	7846	Economy	15100.00
0005434620389	7846	Economy	15100.00
0005434620384	7846	Economy	15100.00
0005434620375	7846	Economy	15100.00
0005434620381	7846	Economy	15100.00
0005434620388	7846	Economy	15100.00
0005435332151	7846	Economy	15100.00
0005434620373	7846	Economy	15100.00
0005435332173	7846	Economy	15100.00
0005435332171	7846	Economy	15100.00
0005434620387	7846	Economy	15100.00
0005435332152	7846	Economy	15100.00
0005435332170	7846	Economy	15100.00
0005434620377	7846	Economy	15100.00
0005434620379	7846	Economy	15100.00
0005434620370	7846	Economy	15100.00
0005434620372	7846	Economy	15100.00
0005434620371	7846	Economy	15100.00
0005434620380	7846	Economy	15100.00
0005434620386	7846	Economy	15100.00
0005434620382	7846	Economy	15100.00
0005434620374	7846	Economy	15100.00
0005435332230	32947	Economy	16600.00
0005435332227	32947	Economy	16600.00
0005435332222	32947	Economy	15100.00
0005434620259	32947	Economy	15100.00
0005435332224	32947	Economy	15100.00
0005435332221	32947	Economy	15100.00
0005434620222	32947	Economy	15100.00
0005435332225	32947	Economy	15100.00
0005434620255	32947	Economy	15100.00
0005435332228	32947	Economy	15100.00
0005434620277	32947	Economy	15100.00
0005434620230	32947	Economy	15100.00
0005434620229	32947	Economy	15100.00
0005435332223	32947	Economy	15100.00
0005434620260	32947	Economy	15100.00
0005435332226	32947	Economy	15100.00
0005434620258	32947	Economy	15100.00
0005435332229	32947	Economy	15100.00
0005435784993	4293	Business	38000.00
0005435784999	4293	Business	38000.00
0005435784981	4293	Business	38000.00
0005435784997	4293	Business	38000.00
0005435784996	4293	Business	38000.00
0005432190590	4293	Economy	12700.00
0005435785003	4293	Economy	12700.00
0005435785005	4293	Economy	12700.00
0005435784986	4293	Economy	12700.00
0005434993922	4293	Economy	12700.00
0005435785010	4293	Economy	13900.00
0005435785004	4293	Economy	13900.00
0005434993924	4293	Economy	13900.00
0005435784998	4293	Economy	13900.00
0005435785006	4293	Economy	13900.00
0005435785002	4293	Economy	12700.00
0005435784983	4293	Economy	12700.00
0005435785001	4293	Economy	12700.00
0005434993919	4293	Economy	12700.00
0005434993915	4293	Economy	12700.00
0005432190589	4293	Economy	12700.00
0005434993917	4293	Economy	12700.00
0005434993918	4293	Economy	12700.00
0005435784979	4293	Economy	12700.00
0005435785008	4293	Economy	12700.00
0005435918569	4293	Economy	12700.00
0005435784977	4293	Economy	12700.00
0005432190588	4293	Economy	12700.00
0005434993921	4293	Economy	12700.00
0005435918590	4293	Economy	12700.00
0005435784990	4293	Economy	12700.00
0005432190587	4293	Economy	12700.00
0005435785000	4293	Economy	12700.00
0005435784992	4293	Economy	12700.00
0005435785007	4293	Economy	12700.00
0005435784987	4293	Economy	12700.00
0005435787331	4293	Economy	12700.00
0005435918576	4293	Economy	12700.00
0005435784995	4293	Economy	12700.00
0005435784984	4293	Economy	12700.00
0005435784978	4293	Economy	12700.00
0005435784988	4293	Economy	12700.00
0005434993920	4293	Economy	12700.00
0005435784982	4293	Economy	12700.00
0005435787330	4293	Economy	12700.00
0005435784980	4293	Economy	12700.00
0005434993916	4293	Economy	12700.00
0005435784985	4293	Economy	12700.00
0005435785009	4293	Economy	12700.00
0005435918574	4293	Economy	12700.00
0005434993923	4293	Economy	12700.00
0005435918591	4293	Economy	12700.00
0005435784991	4293	Economy	12700.00
0005435784989	4293	Economy	12700.00
0005435918570	4293	Economy	12700.00
0005435784994	4293	Economy	12700.00
0005435918575	4293	Economy	12700.00
0005435918605	27280	Business	38000.00
0005432195669	27280	Business	38000.00
0005435918606	27280	Business	38000.00
0005435918603	27280	Economy	12700.00
0005435937333	27280	Economy	12700.00
0005435784817	27280	Economy	12700.00
0005435937332	27280	Economy	12700.00
0005435937329	27280	Economy	12700.00
0005435918604	27280	Economy	12700.00
0005435937331	27280	Economy	12700.00
0005435784735	27280	Economy	12700.00
0005435784790	27280	Economy	12700.00
0005432195670	27280	Economy	12700.00
0005432195668	27280	Economy	12700.00
0005435937330	27280	Economy	12700.00
0005432146177	19849	Economy	12800.00
0005432146176	19849	Economy	12800.00
0005432566995	4717	Business	40900.00
0005434081663	4717	Business	40900.00
0005432459283	4717	Business	40900.00
0005432459298	4717	Business	40900.00
0005432566971	4717	Business	40900.00
0005434081654	4717	Business	40900.00
0005432571282	4717	Business	40900.00
0005432170318	4717	Business	40900.00
0005432459282	4717	Business	40900.00
0005432566997	4717	Business	40900.00
0005432571283	4717	Business	40900.00
0005432566981	4717	Business	40900.00
0005432459301	4717	Business	40900.00
0005432170317	4717	Business	40900.00
0005434081657	4717	Business	40900.00
0005432566966	4717	Business	40900.00
0005432566990	4717	Business	40900.00
0005432459315	4717	Business	40900.00
0005432459325	4717	Business	40900.00
0005433726079	4717	Business	40900.00
0005432567024	4717	Business	40900.00
0005434081670	4717	Business	40900.00
0005432566970	4717	Business	40900.00
0005432567019	4717	Business	40900.00
0005432566975	4717	Business	40900.00
0005432459297	4717	Economy	15000.00
0005432459300	4717	Economy	15000.00
0005434081667	4717	Economy	13600.00
0005432459280	4717	Economy	13600.00
0005432459304	4717	Economy	13600.00
0005432566979	4717	Economy	13600.00
0005432567018	4717	Economy	13600.00
0005432566974	4717	Economy	13600.00
0005432567020	4717	Economy	13600.00
0005432459310	4717	Economy	13600.00
0005432459281	4717	Economy	13600.00
0005432567022	4717	Economy	13600.00
0005432170320	4717	Economy	13600.00
0005432567007	4717	Economy	13600.00
0005433452716	4717	Economy	13600.00
0005432566982	4717	Economy	13600.00
0005434081672	4717	Economy	13600.00
0005432567000	4717	Economy	13600.00
0005432566989	4717	Economy	13600.00
0005432567017	4717	Economy	13600.00
0005434081655	4717	Economy	13600.00
0005434081660	4717	Economy	13600.00
0005432459311	4717	Economy	13600.00
0005432459326	4717	Economy	13600.00
0005434081653	4717	Economy	13600.00
0005432459296	4717	Economy	13600.00
0005432566984	4717	Economy	13600.00
0005432459313	4717	Economy	13600.00
0005432170315	4717	Economy	13600.00
0005433726080	4717	Economy	13600.00
0005432566980	4717	Economy	13600.00
0005432566977	4717	Economy	13600.00
0005432459314	4717	Economy	13600.00
0005432567004	4717	Economy	13600.00
0005432567008	4717	Economy	13600.00
0005432566987	4717	Economy	13600.00
0005432571280	4717	Economy	13600.00
0005432459288	4717	Economy	13600.00
0005432459307	4717	Economy	13600.00
0005432459286	4717	Economy	13600.00
0005432566999	4717	Economy	13600.00
0005432567002	4717	Economy	13600.00
0005432567012	4717	Economy	13600.00
0005432566983	4717	Economy	13600.00
0005432459328	4717	Economy	13600.00
0005434081668	4717	Economy	13600.00
0005434081656	4717	Economy	13600.00
0005432459329	4717	Economy	13600.00
0005433452718	4717	Economy	13600.00
0005432567011	4717	Economy	13600.00
0005434081664	4717	Economy	13600.00
0005432459277	4717	Economy	13600.00
0005432170316	4717	Economy	13600.00
0005432459306	4717	Economy	13600.00
0005432567015	4717	Economy	13600.00
0005434081673	4717	Economy	13600.00
0005434081659	4717	Economy	13600.00
0005433451598	4717	Economy	13600.00
0005433451597	4717	Economy	13600.00
0005434081671	4717	Economy	13600.00
0005432567010	4717	Economy	13600.00
0005432459319	4717	Economy	13600.00
0005432566968	4717	Economy	13600.00
0005432566972	4717	Economy	13600.00
0005432566964	4717	Economy	13600.00
0005434081662	4717	Economy	13600.00
0005432566985	4717	Economy	13600.00
0005432567023	4717	Economy	13600.00
0005432459322	4717	Economy	13600.00
0005432459317	4717	Economy	13600.00
0005432566992	4717	Economy	13600.00
0005432566976	4717	Economy	13600.00
0005432567016	4717	Economy	13600.00
0005432459324	4717	Economy	13600.00
0005432459321	4717	Economy	13600.00
0005432567009	4717	Economy	13600.00
0005432459291	4717	Economy	15000.00
0005432459318	4717	Economy	15000.00
0005432459316	4717	Economy	13600.00
0005432566973	4717	Economy	13600.00
0005432459279	4717	Economy	15000.00
0005432566991	4717	Economy	13600.00
0005434081666	4717	Economy	13600.00
0005432186831	4717	Economy	13600.00
0005432459294	4717	Economy	13600.00
0005432566986	4717	Economy	13600.00
0005432459293	4717	Economy	13600.00
0005432571281	4717	Economy	13600.00
0005432566965	4717	Economy	13600.00
0005432459299	4717	Economy	13600.00
0005432459278	4717	Economy	13600.00
0005432459323	4717	Economy	13600.00
0005432459289	4717	Economy	13600.00
0005432566993	4717	Economy	13600.00
0005432459303	4717	Economy	13600.00
0005432459287	4717	Economy	13600.00
0005432459320	4717	Economy	13600.00
0005434081669	4717	Economy	13600.00
0005432459305	4717	Economy	13600.00
0005432567014	4717	Economy	13600.00
0005432170314	4717	Economy	13600.00
0005432170319	4717	Economy	13600.00
0005432459290	4717	Economy	13600.00
0005432567003	4717	Economy	13600.00
0005432170313	4717	Economy	13600.00
0005432567013	4717	Economy	13600.00
0005432566996	4717	Economy	13600.00
0005432186833	4717	Economy	13600.00
0005432566978	4717	Economy	13600.00
0005432459295	4717	Economy	13600.00
0005432186832	4717	Economy	13600.00
0005433726081	4717	Economy	13600.00
0005433451599	4717	Economy	13600.00
0005432566988	4717	Economy	13600.00
0005432567005	4717	Economy	13600.00
0005432567006	4717	Economy	13600.00
0005432566998	4717	Economy	13600.00
0005432459308	4717	Economy	13600.00
0005432459302	4717	Economy	13600.00
0005432459285	4717	Economy	13600.00
0005432459309	4717	Economy	13600.00
0005432459284	4717	Economy	13600.00
0005432567021	4717	Economy	13600.00
0005432566967	4717	Economy	13600.00
0005432459327	4717	Economy	13600.00
0005433452717	4717	Economy	13600.00
0005434081665	4717	Economy	13600.00
0005432566969	4717	Economy	13600.00
0005432567025	4717	Economy	13600.00
0005432459292	4717	Economy	13600.00
0005434081658	4717	Economy	13600.00
0005434081661	4717	Economy	13600.00
0005432459312	4717	Economy	13600.00
0005432566994	4717	Economy	13600.00
0005432567001	4717	Economy	13600.00
0005432566547	30530	Business	40900.00
0005432459038	30530	Business	40900.00
0005432566734	30530	Business	40900.00
0005432566542	30530	Business	40900.00
0005432459100	30530	Business	40900.00
0005432566554	30530	Business	40900.00
0005432566701	30530	Business	40900.00
0005432459096	30530	Business	40900.00
0005432571259	30530	Business	40900.00
0005432566759	30530	Economy	13600.00
0005432459025	30530	Economy	13600.00
0005432566686	30530	Economy	13600.00
0005432459121	30530	Economy	13600.00
0005432566596	30530	Economy	13600.00
0005432459103	30530	Economy	13600.00
0005434081485	30530	Economy	13600.00
0005432161128	30530	Economy	13600.00
0005432566625	30530	Economy	13600.00
0005432566543	30530	Economy	13600.00
0005432566698	30530	Economy	13600.00
0005432459217	30530	Economy	13600.00
0005432458968	30530	Economy	13600.00
0005432213568	30530	Economy	13600.00
0005432566528	30530	Economy	13600.00
0005432566595	30530	Economy	13600.00
0005432213566	30530	Economy	13600.00
0005432213567	30530	Economy	13600.00
0005432566576	30530	Economy	13600.00
0005432459227	30530	Economy	13600.00
0005432566700	30530	Economy	13600.00
0005432459061	30530	Economy	13600.00
0005434081474	30530	Economy	13600.00
0005432459060	30530	Economy	13600.00
0005432458965	30530	Economy	13600.00
0005432566645	30530	Economy	13600.00
0005432459101	30530	Economy	13600.00
0005432566577	30530	Economy	13600.00
0005432566699	30530	Economy	13600.00
0005432459037	30530	Economy	13600.00
0005432458978	30530	Economy	13600.00
0005432566726	30530	Economy	15000.00
0005434081510	30530	Economy	15000.00
0005432458967	30530	Economy	13600.00
0005432459077	30530	Economy	13600.00
0005432566674	30530	Economy	13600.00
0005434081557	30530	Economy	13600.00
0005432458973	30530	Economy	13600.00
0005432566624	30530	Economy	13600.00
0005434081558	30530	Economy	13600.00
0005432458960	30530	Economy	13600.00
0005432459205	30530	Economy	13600.00
0005432566673	30530	Economy	13600.00
0005432459097	30530	Economy	13600.00
0005432459036	30530	Economy	13600.00
0005432566711	30530	Economy	13600.00
0005432566721	30530	Economy	13600.00
0005432566555	30530	Economy	13600.00
0005432566758	30530	Economy	13600.00
0005432566666	30530	Economy	13600.00
0005432459226	30530	Economy	13600.00
0005432566556	30530	Economy	13600.00
0005432566575	30530	Economy	13600.00
0005432566558	30530	Economy	13600.00
0005432566665	30530	Economy	13600.00
0005435722030	13601	Economy	9900.00
0005435720814	13601	Economy	9900.00
0005435720813	13601	Economy	9900.00
0005435722029	13601	Economy	9900.00
0005432295851	22765	Economy	8800.00
0005432295853	22765	Economy	8800.00
0005432295852	22765	Economy	8800.00
0005432295854	22765	Economy	8800.00
0005433342157	11096	Business	23600.00
0005433342171	11096	Business	23600.00
0005433342108	11096	Business	23600.00
0005433342103	11096	Business	23600.00
0005433342142	11096	Business	23600.00
0005433342137	11096	Business	23600.00
0005433342151	11096	Business	23600.00
0005433342136	11096	Business	23600.00
0005433342134	11096	Business	23600.00
0005433342139	11096	Business	23600.00
0005433342117	11096	Business	23600.00
0005433342168	11096	Business	23600.00
0005433342182	11096	Economy	7900.00
0005433342121	11096	Economy	7900.00
0005433342156	11096	Economy	7900.00
0005433342190	11096	Economy	7900.00
0005433342175	11096	Economy	7900.00
0005433342153	11096	Economy	7900.00
0005433342160	11096	Economy	7900.00
0005433342140	11096	Economy	7900.00
0005433342183	11096	Economy	7900.00
0005433342141	11096	Economy	7900.00
0005433342162	11096	Economy	7900.00
0005435097101	11096	Economy	7900.00
0005433342154	11096	Economy	7900.00
0005433342116	11096	Economy	7900.00
0005433342135	11096	Economy	7900.00
0005433342165	11096	Economy	7900.00
0005433342089	11096	Economy	7900.00
0005433342110	11096	Economy	7900.00
0005433342100	11096	Economy	7900.00
0005433342176	11096	Economy	7900.00
0005433342131	11096	Economy	7900.00
0005433342119	11096	Economy	7900.00
0005433342112	11096	Economy	7900.00
0005435097104	11096	Economy	7900.00
0005433342150	11096	Economy	7900.00
0005433342106	11096	Economy	7900.00
0005433342186	11096	Economy	7900.00
0005433342169	11096	Economy	7900.00
0005433342148	11096	Economy	7900.00
0005433342109	11096	Economy	7900.00
0005433342152	11096	Economy	7900.00
0005433342174	11096	Economy	7900.00
0005433342163	11096	Economy	8600.00
0005433342126	11096	Economy	8600.00
0005433342127	11096	Economy	8600.00
0005435097105	11096	Economy	8600.00
0005433342091	11096	Economy	8600.00
0005433342164	11096	Economy	8600.00
0005433342125	11096	Economy	7900.00
0005433342090	11096	Economy	7900.00
0005433342138	11096	Economy	7900.00
0005433342128	11096	Economy	7900.00
0005435097109	11096	Economy	7900.00
0005433342094	11096	Economy	7900.00
0005433342120	11096	Economy	7900.00
0005433342096	11096	Economy	7900.00
0005433342158	11096	Economy	7900.00
0005435097107	11096	Economy	7900.00
0005433342167	11096	Economy	7900.00
0005433342095	11096	Economy	7900.00
0005433342104	11096	Economy	7900.00
0005433342184	11096	Economy	7900.00
0005433342105	11096	Economy	7900.00
0005433342166	11096	Economy	7900.00
0005433342113	11096	Economy	7900.00
0005433342172	11096	Economy	7900.00
0005433342093	11096	Economy	7900.00
0005433342170	11096	Economy	7900.00
0005433342181	11096	Economy	7900.00
0005435097106	11096	Economy	7900.00
0005433342143	11096	Economy	7900.00
0005435097099	11096	Economy	7900.00
0005433342102	11096	Economy	7900.00
0005433342107	11096	Economy	7900.00
0005433342177	11096	Economy	7900.00
0005433342114	11096	Economy	7900.00
0005433342144	11096	Economy	7900.00
0005433342111	11096	Economy	7900.00
0005433342179	11096	Economy	7900.00
0005433342124	11096	Economy	7900.00
0005433342147	11096	Economy	7900.00
0005433342191	11096	Economy	7900.00
0005433342159	11096	Economy	7900.00
0005433342132	11096	Economy	7900.00
0005433342123	11096	Economy	7900.00
0005433342188	11096	Economy	7900.00
0005433342178	11096	Economy	7900.00
0005433342173	11096	Economy	7900.00
0005433342101	11096	Economy	7900.00
0005433342161	11096	Economy	7900.00
0005433342149	11096	Economy	7900.00
0005433342185	11096	Economy	7900.00
0005433342097	11096	Economy	7900.00
0005433342118	11096	Economy	7900.00
0005433342145	11096	Economy	7900.00
0005433342092	11096	Economy	7900.00
0005435097100	11096	Economy	7900.00
0005433342189	11096	Economy	7900.00
0005433342133	11096	Economy	7900.00
0005433342098	11096	Economy	7900.00
0005433342122	11096	Economy	7900.00
0005433342180	11096	Economy	7900.00
0005433342130	11096	Economy	7900.00
0005435097108	11096	Economy	7900.00
0005435097103	11096	Economy	7900.00
0005433342129	11096	Economy	7900.00
0005435097102	11096	Economy	7900.00
0005433342146	11096	Economy	7900.00
0005433342099	11096	Economy	7900.00
0005433342115	11096	Economy	7900.00
0005433342155	11096	Economy	7900.00
0005433342187	11096	Economy	7900.00
0005433341410	17106	Business	23600.00
0005433341442	17106	Business	23600.00
0005432293183	17106	Business	23600.00
0005433341501	17106	Business	23600.00
0005435380251	17106	Economy	7900.00
0005433341567	17106	Economy	7900.00
0005435380250	17106	Economy	7900.00
0005433341409	17106	Economy	7900.00
0005433341474	17106	Economy	7900.00
0005435380249	17106	Economy	7900.00
0005435380248	17106	Economy	7900.00
0005435545643	17106	Economy	7900.00
0005433341396	17106	Economy	7900.00
0005433341574	17106	Economy	8600.00
0005435545649	17106	Economy	8600.00
0005433341538	17106	Economy	7900.00
0005435545647	17106	Economy	7900.00
0005433341431	17106	Economy	7900.00
0005432293184	17106	Economy	7900.00
0005432293182	17106	Economy	7900.00
0005435545645	17106	Economy	7900.00
0005435545646	17106	Economy	7900.00
0005433341560	17106	Economy	7900.00
0005433341384	17106	Economy	7900.00
0005433341475	17106	Economy	7900.00
0005435380247	17106	Economy	7900.00
0005433341386	17106	Economy	7900.00
0005433341502	17106	Economy	7900.00
0005432293181	17106	Economy	7900.00
0005433341408	17106	Economy	7900.00
0005435545644	17106	Economy	7900.00
0005433341387	17106	Economy	7900.00
0005433341568	17106	Economy	7900.00
0005435545648	17106	Economy	7900.00
0005433481086	9106	Business	26600.00
0005433506988	9106	Business	26600.00
0005432919541	9106	Business	26600.00
0005433506992	9106	Business	26600.00
0005432919519	9106	Economy	8900.00
0005433481090	9106	Economy	8900.00
0005433506990	9106	Economy	8900.00
0005433506998	9106	Economy	9800.00
0005433481083	9106	Economy	9800.00
0005432919520	9106	Economy	8900.00
0005433506986	9106	Economy	8900.00
0005433481085	9106	Economy	8900.00
0005433506991	9106	Economy	8900.00
0005433506984	9106	Economy	8900.00
0005433506982	9106	Economy	8900.00
0005433506996	9106	Economy	8900.00
0005433506997	9106	Economy	8900.00
0005433481088	9106	Economy	8900.00
0005433507000	9106	Economy	8900.00
0005433506989	9106	Economy	8900.00
0005433506999	9106	Economy	8900.00
0005433506993	9106	Economy	8900.00
0005433506987	9106	Economy	8900.00
0005433506994	9106	Economy	8900.00
0005433506983	9106	Economy	8900.00
0005433506995	9106	Economy	8900.00
0005433507001	9106	Economy	8900.00
0005433481084	9106	Economy	8900.00
0005433481089	9106	Economy	8900.00
0005433506985	9106	Economy	8900.00
0005433481087	9106	Economy	8900.00
0005434158956	20440	Business	26600.00
0005432919673	20440	Business	26600.00
0005432919659	20440	Business	26600.00
0005433506857	20440	Business	26600.00
0005432919663	20440	Business	26600.00
0005432919660	20440	Economy	8900.00
0005433506911	20440	Economy	8900.00
0005432919665	20440	Economy	8900.00
0005434158955	20440	Economy	8900.00
0005433506874	20440	Economy	8900.00
0005432919657	20440	Economy	8900.00
0005434158954	20440	Economy	9800.00
0005432919674	20440	Economy	9800.00
0005433506853	20440	Economy	9800.00
0005432919656	20440	Economy	8900.00
0005432919667	20440	Economy	8900.00
0005433506910	20440	Economy	8900.00
0005432919671	20440	Economy	8900.00
0005434158957	20440	Economy	8900.00
0005432919670	20440	Economy	8900.00
0005433506897	20440	Economy	8900.00
0005433481051	20440	Economy	8900.00
0005432919672	20440	Economy	8900.00
0005432919669	20440	Economy	8900.00
0005432919654	20440	Economy	8900.00
0005433506868	20440	Economy	8900.00
0005432919662	20440	Economy	8900.00
0005432919661	20440	Economy	8900.00
0005433506858	20440	Economy	8900.00
0005432919658	20440	Economy	8900.00
0005432919655	20440	Economy	8900.00
0005432919666	20440	Economy	8900.00
0005432919668	20440	Economy	8900.00
0005433506895	20440	Economy	8900.00
0005434158958	20440	Economy	8900.00
0005432919664	20440	Economy	8900.00
0005432396200	10134	Economy	5800.00
0005432394058	10134	Economy	5800.00
0005432396199	10134	Economy	5800.00
0005432396197	10134	Economy	5800.00
0005432396196	10134	Economy	5800.00
0005432394059	10134	Economy	5800.00
0005432394060	10134	Economy	5800.00
0005432394057	10134	Economy	5800.00
0005432396198	10134	Economy	5800.00
0005432400059	18330	Economy	5800.00
0005432400056	18330	Economy	5800.00
0005432400057	18330	Economy	5800.00
0005432400063	18330	Economy	5800.00
0005432400058	18330	Economy	5800.00
0005432400061	18330	Economy	5800.00
0005435554109	11047	Business	9500.00
0005434411733	11047	Business	9500.00
0005435125672	11047	Economy	3200.00
0005434411734	11047	Economy	3200.00
0005435125717	11047	Economy	3200.00
0005434411736	11047	Economy	3500.00
0005435125716	11047	Economy	3200.00
0005435125673	11047	Economy	3200.00
0005434411732	11047	Economy	3200.00
0005434928269	11047	Economy	3200.00
0005434928271	11047	Economy	3200.00
0005435125685	11047	Economy	3200.00
0005435125744	11047	Economy	3200.00
0005435125743	11047	Economy	3200.00
0005435125679	11047	Economy	3200.00
0005434411735	11047	Economy	3200.00
0005434928270	11047	Economy	3200.00
0005435554118	11047	Economy	3200.00
0005435125964	14691	Business	9500.00
0005435625989	14691	Business	9500.00
0005435125938	14691	Business	9500.00
0005435554136	14691	Business	9500.00
0005435625997	14691	Business	9500.00
0005434928248	14691	Business	9500.00
0005435125966	14691	Business	9500.00
0005435125976	14691	Business	9500.00
0005435125967	14691	Business	9500.00
0005435125954	14691	Business	9500.00
0005435125979	14691	Economy	3200.00
0005435125960	14691	Economy	3200.00
0005435554133	14691	Economy	3200.00
0005435625992	14691	Economy	3200.00
0005435125977	14691	Economy	3200.00
0005435625994	14691	Economy	3200.00
0005435625998	14691	Economy	3200.00
0005435125943	14691	Economy	3200.00
0005435125972	14691	Economy	3500.00
0005435554134	14691	Economy	3500.00
0005435625988	14691	Economy	3500.00
0005435125940	14691	Economy	3500.00
0005435125959	14691	Economy	3200.00
0005435125962	14691	Economy	3200.00
0005435125951	14691	Economy	3200.00
0005435554137	14691	Economy	3200.00
0005435125942	14691	Economy	3200.00
0005435125978	14691	Economy	3200.00
0005435125956	14691	Economy	3200.00
0005435125973	14691	Economy	3200.00
0005435125941	14691	Economy	3200.00
0005435125945	14691	Economy	3200.00
0005435125969	14691	Economy	3200.00
0005435125939	14691	Economy	3200.00
0005435125974	14691	Economy	3200.00
0005435625991	14691	Economy	3200.00
0005435554135	14691	Economy	3200.00
0005435125944	14691	Economy	3200.00
0005435125949	14691	Economy	3200.00
0005435125961	14691	Economy	3200.00
0005435625984	14691	Economy	3200.00
0005435625987	14691	Economy	3200.00
0005435125950	14691	Economy	3200.00
0005435625993	14691	Economy	3200.00
0005435125957	14691	Economy	3200.00
0005435625990	14691	Economy	3200.00
0005435125953	14691	Economy	3200.00
0005435125948	14691	Economy	3200.00
0005435125946	14691	Economy	3200.00
0005435625985	14691	Economy	3200.00
0005434928249	14691	Economy	3200.00
0005435125963	14691	Economy	3200.00
0005435125958	14691	Economy	3200.00
0005435556666	14691	Economy	3200.00
0005435125947	14691	Economy	3200.00
0005435625999	14691	Economy	3200.00
0005435556667	14691	Economy	3200.00
0005435625996	14691	Economy	3200.00
0005435125955	14691	Economy	3200.00
0005435125970	14691	Economy	3200.00
0005435125971	14691	Economy	3200.00
0005435125975	14691	Economy	3200.00
0005435125952	14691	Economy	3200.00
0005435625986	14691	Economy	3200.00
0005435125968	14691	Economy	3200.00
0005435625995	14691	Economy	3200.00
0005435125965	14691	Economy	3200.00
0005435715286	7139	Business	86900.00
0005432400090	7139	Economy	29000.00
0005435443145	7139	Economy	29000.00
0005435715290	7139	Economy	31900.00
0005432398160	7139	Economy	29000.00
0005435715292	7139	Economy	29000.00
0005432398161	7139	Economy	29000.00
0005435178471	7139	Economy	29000.00
0005435715291	7139	Economy	29000.00
0005435443167	7139	Economy	29000.00
0005432400089	7139	Economy	29000.00
0005432400086	7139	Economy	29000.00
0005435715295	7139	Economy	29000.00
0005435715297	7139	Economy	29000.00
0005432400088	7139	Economy	29000.00
0005435715298	7139	Economy	29000.00
0005432398158	7139	Economy	29000.00
0005435715293	7139	Economy	29000.00
0005435715294	7139	Economy	29000.00
0005435715282	7139	Economy	29000.00
0005435715283	7139	Economy	29000.00
0005432400087	7139	Economy	29000.00
0005435443146	7139	Economy	29000.00
0005435715287	7139	Economy	29000.00
0005432398157	7139	Economy	29000.00
0005435715284	7139	Economy	29000.00
0005435715288	7139	Economy	29000.00
0005435715299	7139	Economy	29000.00
0005435715289	7139	Economy	29000.00
0005435715285	7139	Economy	29000.00
0005432398159	7139	Economy	29000.00
0005435715296	7139	Economy	29000.00
0005435443211	27077	Business	86900.00
0005435443215	27077	Economy	29000.00
0005432394035	27077	Economy	29000.00
0005435443216	27077	Economy	29000.00
0005435443214	27077	Economy	29000.00
0005432394036	27077	Economy	29000.00
0005435715166	27077	Economy	29000.00
0005435715180	27077	Economy	29000.00
0005435443212	27077	Economy	29000.00
0005435443217	27077	Economy	29000.00
0005435443213	27077	Economy	29000.00
0005435443220	27077	Economy	29000.00
0005435443219	27077	Economy	29000.00
0005435443218	27077	Economy	29000.00
0005435715165	27077	Economy	29000.00
0005434084883	2739	Economy	7700.00
0005434084884	2739	Economy	7700.00
0005434084882	2739	Economy	7700.00
0005433060384	28476	Economy	7700.00
0005434084853	28476	Economy	7700.00
0005433060385	28476	Economy	7700.00
0005433060386	28476	Economy	7700.00
0005434084854	28476	Economy	7700.00
0005435517610	11364	Economy	6700.00
0005435517643	11364	Economy	6700.00
0005435540658	11364	Economy	6700.00
0005435540657	11364	Economy	6700.00
0005435517589	11364	Economy	6700.00
0005435540698	11364	Economy	6700.00
0005435540659	11364	Economy	6700.00
0005435540643	11364	Economy	6700.00
0005435517642	11364	Economy	6700.00
0005435517590	11364	Economy	6700.00
0005435517609	11364	Economy	6700.00
0005435517595	11364	Economy	6700.00
0005435540759	22225	Business	20200.00
0005435529013	22225	Business	20200.00
0005435540768	22225	Business	20200.00
0005435540758	22225	Business	20200.00
0005435529019	22225	Business	20200.00
0005435529011	22225	Business	20200.00
0005435540774	22225	Economy	6700.00
0005435529028	22225	Economy	6700.00
0005432294461	22225	Economy	6700.00
0005435529024	22225	Economy	6700.00
0005435540766	22225	Economy	6700.00
0005435540760	22225	Economy	6700.00
0005435540765	22225	Economy	6700.00
0005435529026	22225	Economy	7400.00
0005435540767	22225	Economy	7400.00
0005435529022	22225	Economy	7400.00
0005435529023	22225	Economy	7400.00
0005435529029	22225	Economy	6700.00
0005435540757	22225	Economy	6700.00
0005435540763	22225	Economy	6700.00
0005432294460	22225	Economy	6700.00
0005435529014	22225	Economy	6700.00
0005435529016	22225	Economy	6700.00
0005435529033	22225	Economy	6700.00
0005435529017	22225	Economy	6700.00
0005435540762	22225	Economy	6700.00
0005435540773	22225	Economy	6700.00
0005435540761	22225	Economy	6700.00
0005435540769	22225	Economy	6700.00
0005435529015	22225	Economy	6700.00
0005435540756	22225	Economy	6700.00
0005435540775	22225	Economy	6700.00
0005435529032	22225	Economy	6700.00
0005435529020	22225	Economy	6700.00
0005435540764	22225	Economy	6700.00
0005435529031	22225	Economy	6700.00
0005435529018	22225	Economy	6700.00
0005435540777	22225	Economy	6700.00
0005435529030	22225	Economy	6700.00
0005435529012	22225	Economy	6700.00
0005435529021	22225	Economy	6700.00
0005435540776	22225	Economy	6700.00
0005435540770	22225	Economy	6700.00
0005435540772	22225	Economy	6700.00
0005435540771	22225	Economy	6700.00
0005435529027	22225	Economy	6700.00
0005435529025	22225	Economy	6700.00
0005434906809	2318	Business	20200.00
0005434906791	2318	Business	20200.00
0005433250969	2318	Business	20200.00
0005434906756	2318	Business	20200.00
0005434906772	2318	Business	20200.00
0005434906785	2318	Business	20200.00
0005434906804	2318	Business	20200.00
0005433250929	2318	Business	20200.00
0005434906768	2318	Business	20200.00
0005433250932	2318	Economy	6700.00
0005434906753	2318	Economy	6700.00
0005433251009	2318	Economy	6700.00
0005434906810	2318	Economy	6700.00
0005434906789	2318	Economy	6700.00
0005434906788	2318	Economy	6700.00
0005434906782	2318	Economy	6700.00
0005434906755	2318	Economy	6700.00
0005434906764	2318	Economy	6700.00
0005433250930	2318	Economy	6700.00
0005433251068	2318	Economy	7400.00
0005434906798	2318	Economy	7400.00
0005434906776	2318	Economy	7400.00
0005434906794	2318	Economy	7400.00
0005434906761	2318	Economy	6700.00
0005434906802	2318	Economy	6700.00
0005434906778	2318	Economy	6700.00
0005433250996	2318	Economy	6700.00
0005433251074	2318	Economy	6700.00
0005434906807	2318	Economy	6700.00
0005434906796	2318	Economy	6700.00
0005434906763	2318	Economy	6700.00
0005434906783	2318	Economy	6700.00
0005434906770	2318	Economy	6700.00
0005434906784	2318	Economy	6700.00
0005434906805	2318	Economy	6700.00
0005434906767	2318	Economy	6700.00
0005433251093	2318	Economy	6700.00
0005433250970	2318	Economy	6700.00
0005434906790	2318	Economy	6700.00
0005434906801	2318	Economy	6700.00
0005433250931	2318	Economy	6700.00
0005433251067	2318	Economy	6700.00
0005433250935	2318	Economy	6700.00
0005434906769	2318	Economy	6700.00
0005434906812	2318	Economy	6700.00
0005434906795	2318	Economy	6700.00
0005434906781	2318	Economy	6700.00
0005434906777	2318	Economy	6700.00
0005434906773	2318	Economy	6700.00
0005434906808	2318	Economy	6700.00
0005434906754	2318	Economy	6700.00
0005434906803	2318	Economy	6700.00
0005434906762	2318	Economy	6700.00
0005434906758	2318	Economy	6700.00
0005433251018	2318	Economy	6700.00
0005434906765	2318	Economy	6700.00
0005433400932	2318	Economy	6700.00
0005434906797	2318	Economy	6700.00
0005434906780	2318	Economy	6700.00
0005434906771	2318	Economy	6700.00
0005434906760	2318	Economy	6700.00
0005434906759	2318	Economy	6700.00
0005433400931	2318	Economy	6700.00
0005434906813	2318	Economy	6700.00
0005434906779	2318	Economy	6700.00
0005434906800	2318	Economy	6700.00
0005434906786	2318	Economy	6700.00
0005434906793	2318	Economy	6700.00
0005434906750	2318	Economy	6700.00
0005434906787	2318	Economy	6700.00
0005434906766	2318	Economy	6700.00
0005434906811	2318	Economy	6700.00
0005433251010	2318	Economy	6700.00
0005434906799	2318	Economy	6700.00
0005434906792	2318	Economy	6700.00
0005434906752	2318	Economy	6700.00
0005434906806	2318	Economy	6700.00
0005434906751	2318	Economy	6700.00
0005434906774	2318	Economy	6700.00
0005434906775	2318	Economy	6700.00
0005433250995	2318	Economy	6700.00
0005434906757	2318	Economy	6700.00
0005433251178	25609	Business	20200.00
0005433251152	25609	Business	20200.00
0005433400953	25609	Business	20200.00
0005433251153	25609	Business	20200.00
0005433251160	25609	Economy	6700.00
0005433251171	25609	Economy	6700.00
0005433251158	25609	Economy	7400.00
0005433251150	25609	Economy	7400.00
0005433251177	25609	Economy	6700.00
0005433251156	25609	Economy	6700.00
0005433251173	25609	Economy	6700.00
0005433251170	25609	Economy	6700.00
0005433251172	25609	Economy	6700.00
0005433251174	25609	Economy	6700.00
0005433251164	25609	Economy	6700.00
0005433251163	25609	Economy	6700.00
0005433251162	25609	Economy	6700.00
0005433251161	25609	Economy	6700.00
0005433251167	25609	Economy	6700.00
0005433251176	25609	Economy	6700.00
0005433251169	25609	Economy	6700.00
0005433251166	25609	Economy	6700.00
0005433400951	25609	Economy	6700.00
0005433251168	25609	Economy	6700.00
0005433251179	25609	Economy	6700.00
0005433251149	25609	Economy	6700.00
0005433251159	25609	Economy	6700.00
0005433400952	25609	Economy	6700.00
0005433251154	25609	Economy	6700.00
0005433251165	25609	Economy	6700.00
0005433251151	25609	Economy	6700.00
0005433251157	25609	Economy	6700.00
0005433251155	25609	Economy	6700.00
0005433251175	25609	Economy	6700.00
0005432620893	2521	Economy	13600.00
0005432862192	2521	Economy	12400.00
0005432620889	2521	Economy	12400.00
0005432620892	2521	Economy	12400.00
0005432620902	2521	Economy	12400.00
0005432620898	2521	Economy	12400.00
0005432620896	2521	Economy	12400.00
0005432620901	2521	Economy	12400.00
0005432862191	2521	Economy	12400.00
0005432620888	2521	Economy	12400.00
0005432620891	2521	Economy	12400.00
0005432620895	2521	Economy	12400.00
0005432620900	2521	Economy	12400.00
0005432620894	2521	Economy	12400.00
0005432862168	2521	Economy	12400.00
0005432862169	2521	Economy	12400.00
0005432862189	2521	Economy	12400.00
0005432620890	2521	Economy	12400.00
0005432862188	2521	Economy	12400.00
0005432620899	2521	Economy	12400.00
0005432620897	2521	Economy	12400.00
0005432862223	28044	Economy	12400.00
0005432862226	28044	Economy	12400.00
0005432862221	28044	Economy	12400.00
0005432862222	28044	Economy	12400.00
0005432620823	28044	Economy	12400.00
0005432620822	28044	Economy	12400.00
0005432862218	28044	Economy	12400.00
0005432862219	28044	Economy	12400.00
0005432862220	28044	Economy	12400.00
0005432862224	28044	Economy	12400.00
0005432862225	28044	Economy	12400.00
0005434097462	13112	Economy	11300.00
0005434097463	13112	Economy	11300.00
0005434097461	13112	Economy	11300.00
0005433451599	31095	Economy	8400.00
0005433452716	31095	Economy	8400.00
0005433451597	31095	Economy	8400.00
0005433451598	31095	Economy	8400.00
0005433452717	31095	Economy	8400.00
0005433452718	31095	Economy	8400.00
0005433134065	12015	Economy	6600.00
0005434142550	12015	Economy	6600.00
0005434142543	12015	Economy	6600.00
0005433131661	29848	Economy	7200.00
0005433134093	29848	Economy	6600.00
0005433134090	29848	Economy	6600.00
0005433134089	29848	Economy	6600.00
0005434142568	29848	Economy	6600.00
0005434142566	29848	Economy	6600.00
0005434183559	29848	Economy	6600.00
0005434142565	29848	Economy	6600.00
0005433134092	29848	Economy	6600.00
0005433134091	29848	Economy	6600.00
0005434183558	29848	Economy	6600.00
0005433131660	29848	Economy	6600.00
0005434184643	29848	Economy	6600.00
0005433131662	29848	Economy	6600.00
0005434142567	29848	Economy	6600.00
0005434184644	29848	Economy	6600.00
0005433134094	29848	Economy	6600.00
0005435798926	1608	Economy	17200.00
0005435798925	1608	Economy	17200.00
0005435798929	1608	Economy	15700.00
0005435798924	1608	Economy	15700.00
0005435798927	1608	Economy	15700.00
0005435798930	1608	Economy	15700.00
0005435798920	1608	Economy	15700.00
0005435798916	1608	Economy	15700.00
0005435798917	1608	Economy	15700.00
0005435798918	1608	Economy	15700.00
0005435798928	1608	Economy	15700.00
0005435798923	1608	Economy	15700.00
0005435798922	1608	Economy	15700.00
0005435798921	1608	Economy	15700.00
0005435798919	1608	Economy	15700.00
0005435697038	16495	Economy	19900.00
0005435697041	16495	Economy	19900.00
0005435934997	16495	Economy	19900.00
0005435697033	16495	Economy	18100.00
0005435697023	16495	Economy	18100.00
0005435697025	16495	Economy	18100.00
0005435697015	16495	Economy	18100.00
0005435697017	16495	Economy	18100.00
0005435697026	16495	Economy	18100.00
0005435697034	16495	Economy	18100.00
0005435697043	16495	Economy	18100.00
0005435697031	16495	Economy	18100.00
0005435697039	16495	Economy	18100.00
0005435697040	16495	Economy	18100.00
0005435697019	16495	Economy	18100.00
0005435697018	16495	Economy	18100.00
0005435697020	16495	Economy	18100.00
0005435697037	16495	Economy	18100.00
0005435697021	16495	Economy	18100.00
0005435697016	16495	Economy	18100.00
0005435697035	16495	Economy	18100.00
0005435697042	16495	Economy	18100.00
0005435697024	16495	Economy	18100.00
0005435697028	16495	Economy	18100.00
0005435697027	16495	Economy	18100.00
0005435697036	16495	Economy	18100.00
0005435697030	16495	Economy	18100.00
0005435697029	16495	Economy	18100.00
0005435697032	16495	Economy	18100.00
0005435697022	16495	Economy	18100.00
0005435696904	24712	Economy	19900.00
0005435935015	24712	Economy	18100.00
0005435696977	24712	Economy	18100.00
0005435696856	24712	Economy	18100.00
0005435696905	24712	Economy	18100.00
0005435696846	24712	Economy	18100.00
0005435696978	24712	Economy	18100.00
0005435696874	24712	Economy	18100.00
0005435696934	24712	Economy	18100.00
0005435696924	24712	Economy	18100.00
0005435935014	24712	Economy	18100.00
0005435696875	24712	Economy	18100.00
0005433724753	18783	Economy	4400.00
0005433724755	18783	Economy	4400.00
0005433724754	18783	Economy	4400.00
0005433724756	18783	Economy	4400.00
0005433724757	18783	Economy	4400.00
0005433724758	18783	Economy	4400.00
0005432968819	21607	Economy	4400.00
0005433724725	21607	Economy	4400.00
0005432968818	21607	Economy	4400.00
0005434137289	7342	Business	23100.00
0005434137296	7342	Business	23100.00
0005434137268	7342	Business	23100.00
0005434137302	7342	Business	23100.00
0005434137295	7342	Business	23100.00
0005434137327	7342	Business	23100.00
0005434137352	7342	Business	23100.00
0005434137324	7342	Business	23100.00
0005434137301	7342	Business	23100.00
0005434137317	7342	Business	23100.00
0005434137353	7342	Business	23100.00
0005434137308	7342	Economy	7700.00
0005434137290	7342	Economy	7700.00
0005434137333	7342	Economy	7700.00
0005434137271	7342	Economy	7700.00
0005434137349	7342	Economy	7700.00
0005434087464	7342	Economy	7700.00
0005434087465	7342	Economy	7700.00
0005434137284	7342	Economy	7700.00
0005434137319	7342	Economy	7700.00
0005434137346	7342	Economy	7700.00
0005434137339	7342	Economy	8500.00
0005434137325	7342	Economy	8500.00
0005434137334	7342	Economy	8500.00
0005434137354	7342	Economy	8500.00
0005434137312	7342	Economy	8500.00
0005434137311	7342	Economy	7700.00
0005434137314	7342	Economy	7700.00
0005434137273	7342	Economy	7700.00
0005434137340	7342	Economy	7700.00
0005434137279	7342	Economy	7700.00
0005434137286	7342	Economy	7700.00
0005434137287	7342	Economy	7700.00
0005434137310	7342	Economy	7700.00
0005434137285	7342	Economy	7700.00
0005434137274	7342	Economy	7700.00
0005434137320	7342	Economy	7700.00
0005434137356	7342	Economy	7700.00
0005434137281	7342	Economy	7700.00
0005434137299	7342	Economy	7700.00
0005434137318	7342	Economy	7700.00
0005434137291	7342	Economy	7700.00
0005434137277	7342	Economy	7700.00
0005434137288	7342	Economy	7700.00
0005434137343	7342	Economy	7700.00
0005434137276	7342	Economy	7700.00
0005434137309	7342	Economy	7700.00
0005434137294	7342	Economy	7700.00
0005434137269	7342	Economy	7700.00
0005434137321	7342	Economy	7700.00
0005434137335	7342	Economy	7700.00
0005434137316	7342	Economy	7700.00
0005434137345	7342	Economy	7700.00
0005434137323	7342	Economy	7700.00
0005434137350	7342	Economy	7700.00
0005434137355	7342	Economy	7700.00
0005434137344	7342	Economy	7700.00
0005434137292	7342	Economy	7700.00
0005434137347	7342	Economy	7700.00
0005434137337	7342	Economy	7700.00
0005434137341	7342	Economy	7700.00
0005434137351	7342	Economy	7700.00
0005434137305	7342	Economy	7700.00
0005434137280	7342	Economy	7700.00
0005434137330	7342	Economy	7700.00
0005434137275	7342	Economy	7700.00
0005434137272	7342	Economy	7700.00
0005434087462	7342	Economy	7700.00
0005434087461	7342	Economy	7700.00
0005434137326	7342	Economy	7700.00
0005434137331	7342	Economy	7700.00
0005434137329	7342	Economy	7700.00
0005434137282	7342	Economy	7700.00
0005434137304	7342	Economy	7700.00
0005434137332	7342	Economy	7700.00
0005434137300	7342	Economy	7700.00
0005434137283	7342	Economy	7700.00
0005434137293	7342	Economy	7700.00
0005434137338	7342	Economy	7700.00
0005434087463	7342	Economy	7700.00
0005434137306	7342	Economy	7700.00
0005434137336	7342	Economy	7700.00
0005434137315	7342	Economy	7700.00
0005434137298	7342	Economy	7700.00
0005434137342	7342	Economy	7700.00
0005434137307	7342	Economy	7700.00
0005434137270	7342	Economy	7700.00
0005434087466	7342	Economy	7700.00
0005434137348	7342	Economy	7700.00
0005434137278	7342	Economy	7700.00
0005434137328	7342	Economy	7700.00
0005434137297	7342	Economy	7700.00
0005434137303	7342	Economy	7700.00
0005434137313	7342	Economy	7700.00
0005434137322	7342	Economy	7700.00
0005434136738	28578	Business	23100.00
0005434136739	28578	Economy	7700.00
0005434087437	28578	Economy	7700.00
0005434136680	28578	Economy	7700.00
0005434087431	28578	Economy	7700.00
0005434136722	28578	Economy	7700.00
0005434136719	28578	Economy	7700.00
0005435808126	1929	Economy	23900.00
0005435808133	1929	Economy	23900.00
0005435808130	1929	Economy	23900.00
0005435808134	1929	Economy	21700.00
0005434610193	1929	Economy	21700.00
0005434610192	1929	Economy	21700.00
0005435808128	1929	Economy	21700.00
0005435808132	1929	Economy	21700.00
0005434610190	1929	Economy	21700.00
0005435808124	1929	Economy	21700.00
0005434610191	1929	Economy	21700.00
0005435808131	1929	Economy	21700.00
0005435808127	1929	Economy	21700.00
0005435808125	1929	Economy	21700.00
0005435808135	1929	Economy	21700.00
0005435808129	1929	Economy	21700.00
0005434503477	16685	Economy	6900.00
0005434503613	16685	Economy	6900.00
0005434503478	16685	Economy	6900.00
0005434503463	16685	Economy	6900.00
0005434503571	16685	Economy	6900.00
0005434503469	16685	Economy	6900.00
0005434503614	16685	Economy	6900.00
0005434503572	16685	Economy	6900.00
0005434503464	16685	Economy	6900.00
0005434503731	22921	Economy	7600.00
0005434503738	22921	Economy	7600.00
0005434503705	22921	Economy	7600.00
0005434503720	22921	Economy	7600.00
0005434503725	22921	Economy	6900.00
0005434503737	22921	Economy	6900.00
0005434503740	22921	Economy	6900.00
0005434503723	22921	Economy	6900.00
0005434503736	22921	Economy	6900.00
0005434503706	22921	Economy	6900.00
0005434503732	22921	Economy	6900.00
0005434503727	22921	Economy	6900.00
0005434503729	22921	Economy	6900.00
0005434503703	22921	Economy	6900.00
0005434503730	22921	Economy	6900.00
0005434503722	22921	Economy	6900.00
0005434503717	22921	Economy	6900.00
0005434503712	22921	Economy	6900.00
0005434503713	22921	Economy	6900.00
0005434503711	22921	Economy	6900.00
0005434503719	22921	Economy	6900.00
0005434503728	22921	Economy	6900.00
0005434503733	22921	Economy	6900.00
0005434503704	22921	Economy	6900.00
0005434503716	22921	Economy	6900.00
0005434503735	22921	Economy	6900.00
0005434503709	22921	Economy	6900.00
0005434503715	22921	Economy	6900.00
0005434503701	22921	Economy	6900.00
0005434503718	22921	Economy	6900.00
0005434503721	22921	Economy	6900.00
0005434503739	22921	Economy	6900.00
0005434503714	22921	Economy	6900.00
0005434503734	22921	Economy	6900.00
0005434503710	22921	Economy	6900.00
0005434503707	22921	Economy	6900.00
0005434503700	22921	Economy	6900.00
0005434503702	22921	Economy	6900.00
0005434503724	22921	Economy	6900.00
0005434503726	22921	Economy	6900.00
0005434503708	22921	Economy	6900.00
0005434608278	6504	Economy	19100.00
0005434608293	6504	Economy	17300.00
0005434608280	6504	Economy	17300.00
0005434608294	6504	Economy	17300.00
0005434608289	6504	Economy	17300.00
0005434608279	6504	Economy	17300.00
0005434608296	6504	Economy	17300.00
0005434608285	6504	Economy	17300.00
0005434608284	6504	Economy	17300.00
0005434608286	6504	Economy	17300.00
0005434608288	6504	Economy	17300.00
0005434608283	6504	Economy	17300.00
0005434608281	6504	Economy	17300.00
0005434608298	6504	Economy	17300.00
0005434608282	6504	Economy	17300.00
0005434608292	6504	Economy	17300.00
0005434608297	6504	Economy	17300.00
0005434608287	6504	Economy	17300.00
0005434608290	6504	Economy	17300.00
0005434608295	6504	Economy	17300.00
0005434608291	6504	Economy	17300.00
0005433266571	2177	Economy	7700.00
0005435078180	2177	Economy	7000.00
0005433266564	2177	Economy	7000.00
0005433266563	2177	Economy	7000.00
0005435078177	2177	Economy	7000.00
0005433266561	2177	Economy	7000.00
0005433266562	2177	Economy	7000.00
0005435078175	2177	Economy	7000.00
0005435078178	2177	Economy	7000.00
0005435078189	2177	Economy	7000.00
0005435078185	2177	Economy	7000.00
0005435078187	2177	Economy	7000.00
0005435078181	2177	Economy	7000.00
0005435078183	2177	Economy	7000.00
0005435078190	2177	Economy	7000.00
0005435078176	2177	Economy	7000.00
0005435078184	2177	Economy	7000.00
0005435078188	2177	Economy	7000.00
0005435078186	2177	Economy	7000.00
0005433266558	2177	Economy	7000.00
0005435078179	2177	Economy	7000.00
0005435078182	2177	Economy	7000.00
0005433266631	24319	Economy	7000.00
0005435078086	24319	Economy	7000.00
0005435078146	24319	Economy	7000.00
0005433266632	24319	Economy	7000.00
0005433266625	24319	Economy	7000.00
0005435078065	24319	Economy	7000.00
0005435078081	24319	Economy	7000.00
0005435078071	24319	Economy	7000.00
0005435078095	24319	Economy	7000.00
0005435078084	24319	Economy	7000.00
0005433266629	24319	Economy	7000.00
0005433266626	24319	Economy	7000.00
0005435078094	24319	Economy	7000.00
0005433266627	24319	Economy	7000.00
0005433266630	24319	Economy	7000.00
0005433266628	24319	Economy	7000.00
0005435078085	24319	Economy	7000.00
0005433266624	24319	Economy	7000.00
0005434988629	6666	Economy	10800.00
0005434988625	6666	Economy	10800.00
0005434988628	6666	Economy	9800.00
0005435803233	6666	Economy	9800.00
0005434988632	6666	Economy	9800.00
0005435803232	6666	Economy	9800.00
0005434988631	6666	Economy	9800.00
0005434988627	6666	Economy	9800.00
0005434988626	6666	Economy	9800.00
0005434988624	6666	Economy	9800.00
0005435803231	6666	Economy	9800.00
0005435803234	6666	Economy	9800.00
0005434988622	6666	Economy	9800.00
0005434988630	6666	Economy	9800.00
0005434988623	6666	Economy	9800.00
0005435464475	6666	Economy	9800.00
0005435464476	6666	Economy	9800.00
0005435464488	23639	Economy	9800.00
0005435464487	23639	Economy	9800.00
0005432382801	30453	Business	9900.00
0005432382781	30453	Business	9900.00
0005432382803	30453	Business	9900.00
0005433449754	30453	Business	9900.00
0005433449759	30453	Business	9900.00
0005432382784	30453	Business	9900.00
0005432382773	30453	Business	9900.00
0005432382780	30453	Economy	3300.00
0005433449747	30453	Economy	3300.00
0005432382796	30453	Economy	3300.00
0005432382772	30453	Economy	3300.00
0005433449743	30453	Economy	3300.00
0005433449741	30453	Economy	3300.00
0005433449745	30453	Economy	3600.00
0005432382777	30453	Economy	3600.00
0005432382779	30453	Economy	3600.00
0005432382769	30453	Economy	3600.00
0005433449744	30453	Economy	3600.00
0005432382799	30453	Economy	3300.00
0005432382797	30453	Economy	3300.00
0005433449752	30453	Economy	3300.00
0005433449740	30453	Economy	3300.00
0005432382802	30453	Economy	3300.00
0005432382798	30453	Economy	3300.00
0005433454853	30453	Economy	3300.00
0005433449739	30453	Economy	3300.00
0005433449758	30453	Economy	3300.00
0005433449757	30453	Economy	3300.00
0005432382794	30453	Economy	3300.00
0005432382790	30453	Economy	3300.00
0005432382791	30453	Economy	3300.00
0005432382785	30453	Economy	3300.00
0005433449760	30453	Economy	3300.00
0005433449751	30453	Economy	3300.00
0005432382788	30453	Economy	3300.00
0005432382789	30453	Economy	3300.00
0005432382776	30453	Economy	3300.00
0005433449742	30453	Economy	3300.00
0005432382783	30453	Economy	3300.00
0005432382793	30453	Economy	3300.00
0005432382800	30453	Economy	3300.00
0005433449756	30453	Economy	3300.00
0005433449748	30453	Economy	3300.00
0005432382795	30453	Economy	3300.00
0005432382770	30453	Economy	3300.00
0005433449750	30453	Economy	3300.00
0005432382775	30453	Economy	3300.00
0005433454852	30453	Economy	3300.00
0005432382792	30453	Economy	3300.00
0005433449753	30453	Economy	3300.00
0005432382786	30453	Economy	3300.00
0005432382774	30453	Economy	3300.00
0005432382768	30453	Economy	3300.00
0005432382778	30453	Economy	3300.00
0005433449749	30453	Economy	3300.00
0005433449755	30453	Economy	3300.00
0005432382767	30453	Economy	3300.00
0005432382771	30453	Economy	3300.00
0005432382782	30453	Economy	3300.00
0005433449761	30453	Economy	3300.00
0005432382787	30453	Economy	3300.00
0005433449746	30453	Economy	3300.00
0005433449623	31311	Economy	3300.00
0005433449661	31311	Economy	3300.00
0005433449646	31311	Economy	3300.00
0005433449622	31311	Economy	3300.00
0005433449610	31311	Economy	3300.00
0005433788151	20831	Economy	26200.00
0005433788160	20831	Economy	23800.00
0005433788150	20831	Economy	23800.00
0005433788158	20831	Economy	23800.00
0005433788156	20831	Economy	23800.00
0005433788153	20831	Economy	23800.00
0005433788154	20831	Economy	23800.00
0005433788152	20831	Economy	23800.00
0005433788157	20831	Economy	23800.00
0005433788149	20831	Economy	23800.00
0005433788159	20831	Economy	23800.00
0005433788155	20831	Economy	23800.00
0005433131630	10802	Economy	15600.00
0005435299699	10802	Economy	15600.00
0005435299732	29725	Economy	17100.00
0005433129235	29725	Economy	15600.00
0005435299730	29725	Economy	15600.00
0005435299733	29725	Economy	15600.00
0005435299731	29725	Economy	15600.00
0005435299729	29725	Economy	15600.00
0005435302156	29725	Economy	15600.00
0005435302155	29725	Economy	15600.00
0005433129233	29725	Economy	15600.00
0005433126802	29725	Economy	15600.00
0005435302153	29725	Economy	15600.00
0005433126803	29725	Economy	15600.00
0005433126801	29725	Economy	15600.00
0005435302157	29725	Economy	15600.00
0005435302154	29725	Economy	15600.00
0005433129234	29725	Economy	15600.00
0005433129232	29725	Economy	15600.00
0005433126800	29725	Economy	15600.00
0005433109895	2416	Economy	17200.00
0005433109866	2416	Economy	17200.00
0005434287052	2416	Economy	17200.00
0005433109878	2416	Economy	17200.00
0005434287071	2416	Economy	15700.00
0005433109896	2416	Economy	15700.00
0005434287068	2416	Economy	15700.00
0005434287065	2416	Economy	15700.00
0005434287053	2416	Economy	15700.00
0005434287069	2416	Economy	15700.00
0005434287062	2416	Economy	15700.00
0005434287059	2416	Economy	15700.00
0005433109859	2416	Economy	15700.00
0005433109893	2416	Economy	15700.00
0005433109858	2416	Economy	15700.00
0005434287063	2416	Economy	15700.00
0005433109867	2416	Economy	15700.00
0005434287060	2416	Economy	15700.00
0005434287055	2416	Economy	15700.00
0005434287073	2416	Economy	15700.00
0005434287064	2416	Economy	15700.00
0005434287072	2416	Economy	15700.00
0005434287066	2416	Economy	15700.00
0005433109842	2416	Economy	15700.00
0005433109857	2416	Economy	15700.00
0005434287051	2416	Economy	15700.00
0005433109877	2416	Economy	15700.00
0005434287054	2416	Economy	15700.00
0005434287058	2416	Economy	15700.00
0005434287070	2416	Economy	15700.00
0005433109894	2416	Economy	15700.00
0005434287067	2416	Economy	15700.00
0005434287057	2416	Economy	15700.00
0005434287056	2416	Economy	15700.00
0005434287061	2416	Economy	15700.00
0005433109876	2416	Economy	15700.00
0005433109925	26862	Economy	15700.00
0005434286964	26862	Economy	15700.00
0005433109932	26862	Economy	15700.00
0005433109926	26862	Economy	15700.00
0005433109930	26862	Economy	15700.00
0005434286905	26862	Economy	15700.00
0005433109924	26862	Economy	15700.00
0005434286898	26862	Economy	15700.00
0005434286899	26862	Economy	15700.00
0005433109931	26862	Economy	15700.00
0005433109935	26862	Economy	15700.00
0005433109933	26862	Economy	15700.00
0005433109927	26862	Economy	15700.00
0005433109929	26862	Economy	15700.00
0005433109934	26862	Economy	15700.00
0005433109928	26862	Economy	15700.00
0005434286919	26862	Economy	15700.00
0005435856163	25492	Economy	25000.00
0005435856161	25492	Economy	22800.00
0005435856164	25492	Economy	22800.00
0005435856162	25492	Economy	22800.00
0005435856160	25492	Economy	22800.00
0005435856165	25492	Economy	22800.00
0005434273060	26667	Economy	25000.00
0005434273059	26667	Economy	22800.00
0005434272175	26667	Economy	22800.00
0005434273061	26667	Economy	22800.00
0005434272174	26667	Economy	22800.00
0005435314797	19083	Economy	24600.00
0005434520131	19083	Economy	22300.00
0005435314788	19083	Economy	22300.00
0005435314796	19083	Economy	22300.00
0005435314792	19083	Economy	22300.00
0005435314794	19083	Economy	22300.00
0005435314798	19083	Economy	22300.00
0005435314793	19083	Economy	22300.00
0005435314800	19083	Economy	22300.00
0005435314799	19083	Economy	22300.00
0005435314801	19083	Economy	22300.00
0005434520136	19083	Economy	22300.00
0005435314791	19083	Economy	22300.00
0005435314789	19083	Economy	22300.00
0005435314790	19083	Economy	22300.00
0005435314795	19083	Economy	22300.00
0005433874315	7780	Economy	19200.00
0005433874316	7780	Economy	17400.00
0005433874310	7780	Economy	17400.00
0005433874318	7780	Economy	17400.00
0005433874312	7780	Economy	17400.00
0005433874313	7780	Economy	17400.00
0005433874311	7780	Economy	17400.00
0005433874319	7780	Economy	17400.00
0005433874309	7780	Economy	17400.00
0005433874314	7780	Economy	17400.00
0005433874317	7780	Economy	17400.00
0005433874308	7780	Economy	17400.00
0005433874303	32636	Economy	17400.00
0005433874293	32636	Economy	17400.00
0005433868027	4772	Economy	19400.00
0005433868047	4772	Economy	19400.00
0005433868029	4772	Economy	19400.00
0005433868014	4772	Economy	19400.00
0005433868048	4772	Economy	17600.00
0005433868050	4772	Economy	17600.00
0005433868045	4772	Economy	17600.00
0005433868024	4772	Economy	17600.00
0005433868042	4772	Economy	17600.00
0005433868043	4772	Economy	17600.00
0005433868051	4772	Economy	17600.00
0005433868046	4772	Economy	17600.00
0005433868016	4772	Economy	17600.00
0005433868052	4772	Economy	17600.00
0005433868018	4772	Economy	17600.00
0005433868053	4772	Economy	17600.00
0005433868034	4772	Economy	17600.00
0005433868039	4772	Economy	17600.00
0005433868020	4772	Economy	17600.00
0005433868040	4772	Economy	17600.00
0005433868049	4772	Economy	17600.00
0005433868035	4772	Economy	17600.00
0005433868012	4772	Economy	17600.00
0005433868013	4772	Economy	17600.00
0005433868026	4772	Economy	17600.00
0005433868017	4772	Economy	17600.00
0005433868044	4772	Economy	17600.00
0005433868028	4772	Economy	17600.00
0005433868032	4772	Economy	17600.00
0005433868037	4772	Economy	17600.00
0005433868019	4772	Economy	17600.00
0005433868021	4772	Economy	17600.00
0005433868023	4772	Economy	17600.00
0005433868025	4772	Economy	17600.00
0005433868033	4772	Economy	17600.00
0005433868041	4772	Economy	17600.00
0005433868015	4772	Economy	17600.00
0005433868036	4772	Economy	17600.00
0005433868038	4772	Economy	17600.00
0005433868030	4772	Economy	17600.00
0005433868031	4772	Economy	17600.00
0005433868022	4772	Economy	17600.00
0005435860450	32567	Economy	19400.00
0005433867730	32567	Economy	17600.00
0005433867794	32567	Economy	17600.00
0005435860452	32567	Economy	17600.00
0005433867731	32567	Economy	17600.00
0005433867736	32567	Economy	17600.00
0005435860451	32567	Economy	17600.00
0005435860453	32567	Economy	17600.00
0005433867765	32567	Economy	17600.00
0005433867772	32567	Economy	17600.00
0005433867735	32567	Economy	17600.00
0005433867729	32567	Economy	17600.00
0005433867826	32567	Economy	17600.00
0005433867754	32567	Economy	17600.00
0005433867771	32567	Economy	17600.00
0005434663268	3408	Economy	24800.00
0005434663277	3408	Economy	24800.00
0005434663266	3408	Economy	22600.00
0005434663265	3408	Economy	22600.00
0005434461625	3408	Economy	22600.00
0005434461624	3408	Economy	22600.00
0005434461626	3408	Economy	22600.00
0005434663264	3408	Economy	22600.00
0005434663273	3408	Economy	22600.00
0005434461627	3408	Economy	22600.00
0005434663267	3408	Economy	22600.00
0005434663275	3408	Economy	22600.00
0005434663263	3408	Economy	22600.00
0005434663276	3408	Economy	22600.00
0005434663274	3408	Economy	22600.00
0005434663269	3408	Economy	22600.00
0005434663270	3408	Economy	22600.00
0005434663272	3408	Economy	22600.00
0005434663271	3408	Economy	22600.00
0005435911373	12494	Economy	24800.00
0005434663185	12494	Economy	22600.00
0005435911371	12494	Economy	22600.00
0005434663175	12494	Economy	22600.00
0005435911375	12494	Economy	22600.00
0005435911376	12494	Economy	22600.00
0005434460467	12494	Economy	22600.00
0005434663195	12494	Economy	22600.00
0005434663196	12494	Economy	22600.00
0005435911374	12494	Economy	22600.00
0005435911372	12494	Economy	22600.00
0005434663176	12494	Economy	22600.00
0005434663169	12494	Economy	22600.00
0005434663197	12494	Economy	22600.00
0005434663178	12494	Economy	22600.00
0005434663170	12494	Economy	22600.00
0005434663186	12494	Economy	22600.00
0005435911377	12494	Economy	22600.00
0005434663171	12494	Economy	22600.00
0005435911370	12494	Economy	22600.00
0005435860453	14530	Economy	18500.00
0005433867771	14530	Economy	16800.00
0005433867729	14530	Economy	16800.00
0005435860450	14530	Economy	16800.00
0005435860452	14530	Economy	16800.00
0005433867826	14530	Economy	16800.00
0005433867765	14530	Economy	16800.00
0005433867731	14530	Economy	16800.00
0005433867736	14530	Economy	16800.00
0005433867772	14530	Economy	16800.00
0005433867735	14530	Economy	16800.00
0005433867754	14530	Economy	16800.00
0005435860451	14530	Economy	16800.00
0005433867794	14530	Economy	16800.00
0005433867730	14530	Economy	16800.00
0005433867994	32680	Economy	18500.00
0005433867982	32680	Economy	18500.00
0005433868010	32680	Economy	18500.00
0005433867998	32680	Economy	18500.00
0005433867976	32680	Economy	16800.00
0005433867983	32680	Economy	16800.00
0005433867974	32680	Economy	16800.00
0005433867990	32680	Economy	16800.00
0005433867986	32680	Economy	16800.00
0005433867989	32680	Economy	16800.00
0005433867970	32680	Economy	16800.00
0005433867996	32680	Economy	16800.00
0005433867999	32680	Economy	16800.00
0005433867992	32680	Economy	16800.00
0005433867978	32680	Economy	16800.00
0005433868003	32680	Economy	16800.00
0005433868005	32680	Economy	16800.00
0005433867985	32680	Economy	16800.00
0005433868004	32680	Economy	16800.00
0005433867993	32680	Economy	16800.00
0005433868011	32680	Economy	16800.00
0005433867979	32680	Economy	16800.00
0005433867977	32680	Economy	16800.00
0005433868001	32680	Economy	16800.00
0005433868000	32680	Economy	16800.00
0005433867991	32680	Economy	16800.00
0005433867975	32680	Economy	16800.00
0005433868006	32680	Economy	16800.00
0005433867973	32680	Economy	16800.00
0005433868002	32680	Economy	16800.00
0005433867984	32680	Economy	16800.00
0005433867988	32680	Economy	16800.00
0005433868009	32680	Economy	16800.00
0005433867972	32680	Economy	16800.00
0005433867980	32680	Economy	16800.00
0005433867987	32680	Economy	16800.00
0005433867997	32680	Economy	16800.00
0005433867995	32680	Economy	16800.00
0005433868007	32680	Economy	16800.00
0005433868008	32680	Economy	16800.00
0005433867981	32680	Economy	16800.00
0005433867971	32680	Economy	16800.00
0005432798993	12113	Economy	4900.00
0005432798970	12113	Economy	4400.00
0005432799000	12113	Economy	4400.00
0005432798964	12113	Economy	4400.00
0005432798992	12113	Economy	4400.00
0005432798965	12113	Economy	4400.00
0005432798966	12113	Economy	4400.00
0005432799043	12113	Economy	4400.00
0005432798991	12113	Economy	4400.00
0005432799010	12113	Economy	4400.00
0005432799044	12113	Economy	4400.00
0005432799146	14834	Economy	4900.00
0005432799148	14834	Economy	4900.00
0005432799143	14834	Economy	4900.00
0005432799142	14834	Economy	4900.00
0005432799127	14834	Economy	4400.00
0005432799134	14834	Economy	4400.00
0005432799147	14834	Economy	4400.00
0005432799153	14834	Economy	4400.00
0005432799136	14834	Economy	4400.00
0005432799135	14834	Economy	4400.00
0005432799151	14834	Economy	4400.00
0005432799149	14834	Economy	4400.00
0005432799141	14834	Economy	4400.00
0005432799126	14834	Economy	4400.00
0005432799133	14834	Economy	4400.00
0005432799137	14834	Economy	4400.00
0005432799128	14834	Economy	4400.00
0005432799129	14834	Economy	4400.00
0005432799139	14834	Economy	4400.00
0005432799131	14834	Economy	4400.00
0005432799138	14834	Economy	4400.00
0005432799144	14834	Economy	4400.00
0005432799150	14834	Economy	4400.00
0005432799145	14834	Economy	4400.00
0005432799132	14834	Economy	4400.00
0005432799152	14834	Economy	4400.00
0005432799130	14834	Economy	4400.00
0005432799140	14834	Economy	4400.00
0005432799154	14834	Economy	4400.00
0005434407143	7070	Business	49100.00
0005434407091	7070	Business	49100.00
0005434407103	7070	Business	49100.00
0005434407099	7070	Business	49100.00
0005434407112	7070	Business	49100.00
0005434407088	7070	Business	49100.00
0005434407145	7070	Business	49100.00
0005434407120	7070	Economy	16400.00
0005432153864	7070	Economy	16400.00
0005434299332	7070	Economy	16400.00
0005434299334	7070	Economy	16400.00
0005434407130	7070	Economy	16400.00
0005434407123	7070	Economy	16400.00
0005434407125	7070	Economy	16400.00
0005434299324	7070	Economy	16400.00
0005434407094	7070	Economy	16400.00
0005434407122	7070	Economy	16400.00
0005434407154	7070	Economy	16400.00
0005434407129	7070	Economy	16400.00
0005434407126	7070	Economy	16400.00
0005434407117	7070	Economy	16400.00
0005432153869	7070	Economy	16400.00
0005434407137	7070	Economy	16400.00
0005434407153	7070	Economy	16400.00
0005434407113	7070	Economy	16400.00
0005434407142	7070	Economy	16400.00
0005434407136	7070	Economy	16400.00
0005432153865	7070	Economy	16400.00
0005434407128	7070	Economy	16400.00
0005434407116	7070	Economy	16400.00
0005434407114	7070	Economy	16400.00
0005434407098	7070	Economy	16400.00
0005434407108	7070	Economy	16400.00
0005432108223	7070	Economy	16400.00
0005434299333	7070	Economy	16400.00
0005432153867	7070	Economy	16400.00
0005434407132	7070	Economy	16400.00
0005434407146	7070	Economy	16400.00
0005434299335	7070	Economy	18000.00
0005434407110	7070	Economy	18000.00
0005434407135	7070	Economy	18000.00
0005434299315	7070	Economy	18000.00
0005434407148	7070	Economy	18000.00
0005434407093	7070	Economy	18000.00
0005434299319	7070	Economy	16400.00
0005434299328	7070	Economy	16400.00
0005434299320	7070	Economy	16400.00
0005434407092	7070	Economy	16400.00
0005434407102	7070	Economy	16400.00
0005434407139	7070	Economy	16400.00
0005434407119	7070	Economy	16400.00
0005434299321	7070	Economy	16400.00
0005434407107	7070	Economy	16400.00
0005434407118	7070	Economy	16400.00
0005434407111	7070	Economy	16400.00
0005434407105	7070	Economy	16400.00
0005434407141	7070	Economy	16400.00
0005434407138	7070	Economy	16400.00
0005434299326	7070	Economy	16400.00
0005434407149	7070	Economy	16400.00
0005432153868	7070	Economy	16400.00
0005434299317	7070	Economy	16400.00
0005434407106	7070	Economy	16400.00
0005434407121	7070	Economy	16400.00
0005434299322	7070	Economy	16400.00
0005434407115	7070	Economy	16400.00
0005432108224	7070	Economy	16400.00
0005434299331	7070	Economy	16400.00
0005434407100	7070	Economy	16400.00
0005434299323	7070	Economy	16400.00
0005434407090	7070	Economy	16400.00
0005434407147	7070	Economy	16400.00
0005434407089	7070	Economy	16400.00
0005434299316	7070	Economy	16400.00
0005434407152	7070	Economy	16400.00
0005434407109	7070	Economy	16400.00
0005434407144	7070	Economy	16400.00
0005434407133	7070	Economy	16400.00
0005434299329	7070	Economy	16400.00
0005434299330	7070	Economy	16400.00
0005434407104	7070	Economy	16400.00
0005434407150	7070	Economy	16400.00
0005434407151	7070	Economy	16400.00
0005434407095	7070	Economy	16400.00
0005434299327	7070	Economy	16400.00
0005434407101	7070	Economy	16400.00
0005434299325	7070	Economy	16400.00
0005434407096	7070	Economy	16400.00
0005434407131	7070	Economy	16400.00
0005434407124	7070	Economy	16400.00
0005434407097	7070	Economy	16400.00
0005432153866	7070	Economy	16400.00
0005434407127	7070	Economy	16400.00
0005434407134	7070	Economy	16400.00
0005434407140	7070	Economy	16400.00
0005434299318	7070	Economy	16400.00
0005435293121	26895	Business	49100.00
0005434299188	26895	Business	49100.00
0005434299166	26895	Business	49100.00
0005435310934	26895	Business	49100.00
0005432058339	26895	Business	49100.00
0005435310935	26895	Economy	16400.00
0005432058338	26895	Economy	16400.00
0005435293130	26895	Economy	16400.00
0005434299216	26895	Economy	16400.00
0005434299231	26895	Economy	16400.00
0005435293129	26895	Economy	16400.00
0005435310932	26895	Economy	16400.00
0005435310931	26895	Economy	16400.00
0005434406661	26895	Economy	16400.00
0005435293127	26895	Economy	16400.00
0005434299176	26895	Economy	16400.00
0005434406693	26895	Economy	16400.00
0005434406722	26895	Economy	16400.00
0005434299214	26895	Economy	16400.00
0005434299240	26895	Economy	16400.00
0005434299165	26895	Economy	16400.00
0005435293125	26895	Economy	18000.00
0005434406675	26895	Economy	16400.00
0005434299232	26895	Economy	16400.00
0005434406747	26895	Economy	16400.00
0005435310938	26895	Economy	16400.00
0005435310939	26895	Economy	16400.00
0005434406733	26895	Economy	16400.00
0005435293128	26895	Economy	16400.00
0005434299207	26895	Economy	16400.00
0005434406716	26895	Economy	16400.00
0005434406666	26895	Economy	16400.00
0005435293126	26895	Economy	16400.00
0005435310937	26895	Economy	16400.00
0005435293122	26895	Economy	16400.00
0005435310936	26895	Economy	16400.00
0005435293124	26895	Economy	16400.00
0005434299252	26895	Economy	16400.00
0005434299215	26895	Economy	16400.00
0005435310933	26895	Economy	16400.00
0005432058337	26895	Economy	16400.00
0005435293123	26895	Economy	16400.00
0005435310930	26895	Economy	16400.00
0005435310941	26895	Economy	16400.00
0005434299189	26895	Economy	16400.00
0005435310940	26895	Economy	16400.00
0005434299213	26895	Economy	16400.00
0005432603931	6449	Economy	16500.00
0005432603950	6449	Economy	16500.00
0005432603959	6449	Economy	16500.00
0005432603938	6449	Economy	16500.00
0005432603942	6449	Economy	15000.00
0005432603956	6449	Economy	15000.00
0005432603954	6449	Economy	15000.00
0005432603955	6449	Economy	15000.00
0005432603962	6449	Economy	15000.00
0005432603949	6449	Economy	15000.00
0005434512061	6449	Economy	15000.00
0005432603945	6449	Economy	15000.00
0005432603933	6449	Economy	15000.00
0005432603940	6449	Economy	15000.00
0005432603957	6449	Economy	15000.00
0005434512066	6449	Economy	15000.00
0005434512063	6449	Economy	15000.00
0005434512065	6449	Economy	15000.00
0005432603948	6449	Economy	15000.00
0005432603927	6449	Economy	15000.00
0005432603958	6449	Economy	15000.00
0005432603953	6449	Economy	15000.00
0005432603964	6449	Economy	15000.00
0005432603941	6449	Economy	15000.00
0005432603939	6449	Economy	15000.00
0005432603952	6449	Economy	15000.00
0005434512060	6449	Economy	15000.00
0005434512064	6449	Economy	15000.00
0005432603965	6449	Economy	15000.00
0005432603944	6449	Economy	15000.00
0005432603937	6449	Economy	15000.00
0005432603932	6449	Economy	15000.00
0005432603943	6449	Economy	15000.00
0005432603946	6449	Economy	15000.00
0005432603930	6449	Economy	15000.00
0005432603951	6449	Economy	15000.00
0005432603935	6449	Economy	15000.00
0005432603929	6449	Economy	15000.00
0005434512062	6449	Economy	15000.00
0005432603934	6449	Economy	15000.00
0005432603960	6449	Economy	15000.00
0005432603963	6449	Economy	15000.00
0005432603961	6449	Economy	15000.00
0005432603926	6449	Economy	15000.00
0005432603936	6449	Economy	15000.00
0005432603947	6449	Economy	15000.00
0005432603928	6449	Economy	15000.00
0005434512022	21371	Economy	16500.00
0005432603648	21371	Economy	15000.00
0005432603685	21371	Economy	15000.00
0005432603679	21371	Economy	15000.00
0005434512023	21371	Economy	15000.00
0005432603665	21371	Economy	15000.00
0005432603674	21371	Economy	15000.00
0005432603680	21371	Economy	15000.00
0005432603647	21371	Economy	15000.00
0005432603734	21371	Economy	15000.00
0005432603673	21371	Economy	15000.00
0005432603705	21371	Economy	15000.00
0005433251154	15005	Business	18900.00
0005433251162	15005	Business	18900.00
0005433251176	15005	Economy	6300.00
0005433251171	15005	Economy	6300.00
0005433251174	15005	Economy	6900.00
0005433251173	15005	Economy	6900.00
0005433251172	15005	Economy	6300.00
0005433251169	15005	Economy	6300.00
0005433251175	15005	Economy	6300.00
0005433251155	15005	Economy	6300.00
0005433251159	15005	Economy	6300.00
0005433251149	15005	Economy	6300.00
0005433251152	15005	Economy	6300.00
0005433251160	15005	Economy	6300.00
0005433251163	15005	Economy	6300.00
0005433251165	15005	Economy	6300.00
0005433251156	15005	Economy	6300.00
0005433251158	15005	Economy	6300.00
0005433251150	15005	Economy	6300.00
0005433251168	15005	Economy	6300.00
0005433251151	15005	Economy	6300.00
0005433251177	15005	Economy	6300.00
0005433251153	15005	Economy	6300.00
0005433251164	15005	Economy	6300.00
0005433251161	15005	Economy	6300.00
0005433251157	15005	Economy	6300.00
0005433251179	15005	Economy	6300.00
0005433251170	15005	Economy	6300.00
0005433251167	15005	Economy	6300.00
0005433251178	15005	Economy	6300.00
0005433251166	15005	Economy	6300.00
0005433250950	25876	Business	18900.00
0005434906698	25876	Business	18900.00
0005433250964	25876	Business	18900.00
0005433251005	25876	Business	18900.00
0005434906730	25876	Business	18900.00
0005433250963	25876	Business	18900.00
0005434906707	25876	Business	18900.00
0005434906746	25876	Business	18900.00
0005434906695	25876	Business	18900.00
0005433250997	25876	Business	18900.00
0005434906722	25876	Economy	6300.00
0005433251004	25876	Economy	6300.00
0005434906742	25876	Economy	6300.00
0005434906699	25876	Economy	6300.00
0005434906739	25876	Economy	6300.00
0005434906724	25876	Economy	6300.00
0005434906712	25876	Economy	6300.00
0005434906697	25876	Economy	6900.00
0005434906693	25876	Economy	6900.00
0005433250957	25876	Economy	6900.00
0005433251003	25876	Economy	6900.00
0005434906731	25876	Economy	6300.00
0005434906740	25876	Economy	6300.00
0005434906727	25876	Economy	6300.00
0005434906704	25876	Economy	6300.00
0005434906735	25876	Economy	6300.00
0005434906709	25876	Economy	6300.00
0005433250949	25876	Economy	6300.00
0005434906733	25876	Economy	6300.00
0005434906711	25876	Economy	6300.00
0005434906748	25876	Economy	6300.00
0005434906728	25876	Economy	6300.00
0005434906703	25876	Economy	6300.00
0005434906732	25876	Economy	6300.00
0005433250939	25876	Economy	6300.00
0005434906738	25876	Economy	6300.00
0005434906718	25876	Economy	6300.00
0005434906721	25876	Economy	6300.00
0005434906723	25876	Economy	6300.00
0005434906701	25876	Economy	6300.00
0005434906743	25876	Economy	6300.00
0005434906706	25876	Economy	6300.00
0005434906717	25876	Economy	6300.00
0005433250928	25876	Economy	6300.00
0005434906702	25876	Economy	6300.00
0005434906749	25876	Economy	6300.00
0005434906705	25876	Economy	6300.00
0005434906720	25876	Economy	6300.00
0005434906745	25876	Economy	6300.00
0005433250986	25876	Economy	6300.00
0005434906736	25876	Economy	6300.00
0005433250989	25876	Economy	6300.00
0005434906710	25876	Economy	6300.00
0005434906744	25876	Economy	6300.00
0005434906719	25876	Economy	6300.00
0005434906737	25876	Economy	6300.00
0005434906696	25876	Economy	6300.00
0005434906708	25876	Economy	6300.00
0005433250943	25876	Economy	6300.00
0005434906694	25876	Economy	6300.00
0005434906714	25876	Economy	6300.00
0005434906747	25876	Economy	6300.00
0005434906715	25876	Economy	6300.00
0005434906734	25876	Economy	6300.00
0005434906741	25876	Economy	6300.00
0005433250938	25876	Economy	6300.00
0005434906700	25876	Economy	6300.00
0005434906725	25876	Economy	6300.00
0005434906726	25876	Economy	6300.00
0005434906716	25876	Economy	6300.00
0005434906729	25876	Economy	6300.00
0005434906713	25876	Economy	6300.00
0005433251002	25876	Economy	6300.00
0005433250927	25876	Economy	6300.00
0005432609684	22481	Economy	16400.00
0005432607506	22481	Economy	16400.00
0005432607518	22481	Economy	16400.00
0005432609679	22481	Economy	14900.00
0005432607508	22481	Economy	14900.00
0005432607522	22481	Economy	14900.00
0005432609683	22481	Economy	14900.00
0005432607513	22481	Economy	14900.00
0005432607510	22481	Economy	14900.00
0005432607512	22481	Economy	14900.00
0005432609681	22481	Economy	14900.00
0005432609688	22481	Economy	14900.00
0005432609686	22481	Economy	14900.00
0005432607519	22481	Economy	14900.00
0005432609674	22481	Economy	14900.00
0005432609685	22481	Economy	14900.00
0005432609675	22481	Economy	14900.00
0005432609678	22481	Economy	14900.00
0005432607517	22481	Economy	14900.00
0005432609687	22481	Economy	14900.00
0005432609673	22481	Economy	14900.00
0005432607521	22481	Economy	14900.00
0005432607516	22481	Economy	14900.00
0005435842312	22481	Economy	14900.00
0005432607515	22481	Economy	14900.00
0005432609677	22481	Economy	14900.00
0005432609676	22481	Economy	14900.00
0005432607514	22481	Economy	14900.00
0005432609680	22481	Economy	14900.00
0005432607509	22481	Economy	14900.00
0005432607511	22481	Economy	14900.00
0005432607520	22481	Economy	14900.00
0005432609682	22481	Economy	14900.00
0005432607507	22481	Economy	14900.00
0005432609672	22481	Economy	14900.00
0005435842313	22481	Economy	14900.00
0005432609663	31718	Economy	14900.00
0005432609662	31718	Economy	14900.00
0005432613799	31718	Economy	14900.00
0005432609667	31718	Economy	14900.00
0005433008162	14208	Business	52300.00
0005433008154	14208	Business	52300.00
0005433008177	14208	Business	52300.00
0005433008151	14208	Business	52300.00
0005433008159	14208	Business	52300.00
0005433008148	14208	Economy	17400.00
0005433008183	14208	Economy	17400.00
0005433008182	14208	Economy	17400.00
0005433008187	14208	Economy	17400.00
0005433008178	14208	Economy	17400.00
0005433008149	14208	Economy	19200.00
0005433008169	14208	Economy	17400.00
0005433008147	14208	Economy	17400.00
0005433008168	14208	Economy	17400.00
0005433008171	14208	Economy	17400.00
0005433008193	14208	Economy	17400.00
0005433008180	14208	Economy	17400.00
0005433008158	14208	Economy	17400.00
0005433008170	14208	Economy	17400.00
0005433008161	14208	Economy	17400.00
0005433008175	14208	Economy	17400.00
0005433008156	14208	Economy	17400.00
0005433008160	14208	Economy	17400.00
0005433008191	14208	Economy	17400.00
0005433008185	14208	Economy	17400.00
0005433008163	14208	Economy	17400.00
0005433008165	14208	Economy	17400.00
0005433008155	14208	Economy	17400.00
0005433008172	14208	Economy	17400.00
0005433008166	14208	Economy	17400.00
0005433008192	14208	Economy	17400.00
0005433008150	14208	Economy	17400.00
0005433008152	14208	Economy	17400.00
0005433008188	14208	Economy	17400.00
0005433008181	14208	Economy	17400.00
0005433008157	14208	Economy	17400.00
0005433008186	14208	Economy	17400.00
0005433008174	14208	Economy	17400.00
0005433008176	14208	Economy	17400.00
0005433008179	14208	Economy	17400.00
0005433008189	14208	Economy	17400.00
0005433008173	14208	Economy	17400.00
0005433008190	14208	Economy	17400.00
0005433008184	14208	Economy	17400.00
0005433008164	14208	Economy	17400.00
0005433008167	14208	Economy	17400.00
0005433008153	14208	Economy	17400.00
0005433007856	22873	Business	52300.00
0005433007874	22873	Economy	19200.00
0005433007823	22873	Economy	17400.00
0005433007873	22873	Economy	17400.00
0005433810508	22873	Economy	17400.00
0005433007918	22873	Economy	17400.00
0005433810509	22873	Economy	17400.00
0005433007855	22873	Economy	17400.00
0005433007825	22873	Economy	17400.00
0005433007853	22873	Economy	17400.00
0005433007919	22873	Economy	17400.00
0005433007950	22873	Economy	17400.00
0005434925466	20514	Business	22900.00
0005434925468	20514	Business	22900.00
0005434925455	20514	Business	22900.00
0005434925461	20514	Business	22900.00
0005434925440	20514	Economy	7600.00
0005434925462	20514	Economy	7600.00
0005434925458	20514	Economy	7600.00
0005434925446	20514	Economy	8400.00
0005434925439	20514	Economy	8400.00
0005434925433	20514	Economy	8400.00
0005434925445	20514	Economy	8400.00
0005434925470	20514	Economy	7600.00
0005434925435	20514	Economy	7600.00
0005434925444	20514	Economy	7600.00
0005434925441	20514	Economy	7600.00
0005434925438	20514	Economy	7600.00
0005434925448	20514	Economy	7600.00
0005434925452	20514	Economy	7600.00
0005434925443	20514	Economy	7600.00
0005434925472	20514	Economy	7600.00
0005434925436	20514	Economy	7600.00
0005434925449	20514	Economy	7600.00
0005434925467	20514	Economy	7600.00
0005434925473	20514	Economy	7600.00
0005434925460	20514	Economy	7600.00
0005434925469	20514	Economy	7600.00
0005434925450	20514	Economy	7600.00
0005434925465	20514	Economy	7600.00
0005434925464	20514	Economy	7600.00
0005434925447	20514	Economy	7600.00
0005434925454	20514	Economy	7600.00
0005434925442	20514	Economy	7600.00
0005434925434	20514	Economy	7600.00
0005434925456	20514	Economy	7600.00
0005434925437	20514	Economy	7600.00
0005434925451	20514	Economy	7600.00
0005434925463	20514	Economy	7600.00
0005434925453	20514	Economy	7600.00
0005434925457	20514	Economy	7600.00
0005434925459	20514	Economy	7600.00
0005434925471	20514	Economy	7600.00
0005435487611	15811	Economy	8900.00
0005435487610	15811	Economy	8900.00
0005435487627	15811	Economy	8900.00
0005435487624	15811	Economy	8100.00
0005435487619	15811	Economy	8100.00
0005435487626	15811	Economy	8100.00
0005435487616	15811	Economy	8100.00
0005435487623	15811	Economy	8100.00
0005435487615	15811	Economy	8100.00
0005435487609	15811	Economy	8100.00
0005435487618	15811	Economy	8100.00
0005435487617	15811	Economy	8100.00
0005435487620	15811	Economy	8100.00
0005435487628	15811	Economy	8100.00
0005435487612	15811	Economy	8100.00
0005435487625	15811	Economy	8100.00
0005435487630	15811	Economy	8100.00
0005435487613	15811	Economy	8100.00
0005435487621	15811	Economy	8100.00
0005435487614	15811	Economy	8100.00
0005435487622	15811	Economy	8100.00
0005435487629	15811	Economy	8100.00
0005435999068	19697	Economy	8900.00
0005435999048	19697	Economy	8900.00
0005435999063	19697	Economy	8900.00
0005435999060	19697	Economy	8100.00
0005435999047	19697	Economy	8100.00
0005435999053	19697	Economy	8100.00
0005435999051	19697	Economy	8100.00
0005435999057	19697	Economy	8100.00
0005435999062	19697	Economy	8100.00
0005435999052	19697	Economy	8100.00
0005435999050	19697	Economy	8100.00
0005435999049	19697	Economy	8100.00
0005435999058	19697	Economy	8100.00
0005435999056	19697	Economy	8100.00
0005435999059	19697	Economy	8100.00
0005435999066	19697	Economy	8100.00
0005435999061	19697	Economy	8100.00
0005435999065	19697	Economy	8100.00
0005435999064	19697	Economy	8100.00
0005435999055	19697	Economy	8100.00
0005435999054	19697	Economy	8100.00
0005435999067	19697	Economy	8100.00
0005435472580	6019	Business	199300.00
0005435839163	6019	Business	199300.00
0005435839162	6019	Business	199300.00
0005432659686	6019	Business	199300.00
0005435839165	6019	Business	199300.00
0005435839177	6019	Business	199300.00
0005435839170	6019	Business	199300.00
0005435839169	6019	Economy	66400.00
0005435472519	6019	Economy	66400.00
0005435472524	6019	Economy	66400.00
0005435839160	6019	Economy	66400.00
0005435839183	6019	Economy	66400.00
0005435839164	6019	Economy	73100.00
0005435839174	6019	Economy	73100.00
0005432660797	6019	Economy	66400.00
0005435839178	6019	Economy	66400.00
0005435472541	6019	Economy	66400.00
0005435839166	6019	Economy	66400.00
0005435839172	6019	Economy	66400.00
0005435839176	6019	Economy	66400.00
0005435839181	6019	Economy	66400.00
0005435839185	6019	Economy	66400.00
0005432659688	6019	Economy	66400.00
0005435839175	6019	Economy	66400.00
0005435472525	6019	Economy	66400.00
0005432660798	6019	Economy	66400.00
0005435839171	6019	Economy	66400.00
0005432142220	6019	Economy	66400.00
0005435839168	6019	Economy	66400.00
0005435839184	6019	Economy	66400.00
0005432659687	6019	Economy	66400.00
0005435472514	6019	Economy	66400.00
0005435472523	6019	Economy	66400.00
0005435839167	6019	Economy	66400.00
0005432142221	6019	Economy	66400.00
0005435839187	6019	Economy	66400.00
0005435839182	6019	Economy	66400.00
0005435839179	6019	Economy	66400.00
0005435472540	6019	Economy	66400.00
0005435839180	6019	Economy	66400.00
0005435839186	6019	Economy	66400.00
0005435839159	6019	Economy	66400.00
0005435839173	6019	Economy	66400.00
0005435839161	6019	Economy	66400.00
0005432537038	18079	Business	199300.00
0005435472641	18079	Business	199300.00
0005435838971	18079	Business	199300.00
0005435472631	18079	Economy	66400.00
0005432537037	18079	Economy	66400.00
0005435838978	18079	Economy	66400.00
0005435838970	18079	Economy	73100.00
0005435472642	18079	Economy	73100.00
0005435472632	18079	Economy	66400.00
0005435472638	18079	Economy	66400.00
0005435839042	18079	Economy	66400.00
0005432537036	18079	Economy	66400.00
0005435472635	18079	Economy	66400.00
0005435839014	18079	Economy	66400.00
0005435472643	18079	Economy	66400.00
0005435472645	18079	Economy	66400.00
0005435472637	18079	Economy	66400.00
0005435839013	18079	Economy	66400.00
0005435838964	18079	Economy	66400.00
0005435472640	18079	Economy	66400.00
0005435472630	18079	Economy	66400.00
0005435472644	18079	Economy	66400.00
0005435472634	18079	Economy	66400.00
0005435472636	18079	Economy	66400.00
0005435839006	18079	Economy	66400.00
0005435472633	18079	Economy	66400.00
0005435838983	18079	Economy	66400.00
0005435472639	18079	Economy	66400.00
0005433463869	17269	Business	146400.00
0005433462722	17269	Business	146400.00
0005433463867	17269	Business	146400.00
0005433462715	17269	Business	146400.00
0005433463872	17269	Business	146400.00
0005433463877	17269	Business	146400.00
0005433463876	17269	Economy	48800.00
0005433462711	17269	Economy	48800.00
0005433462723	17269	Economy	48800.00
0005433463870	17269	Economy	48800.00
0005433462714	17269	Economy	48800.00
0005433463865	17269	Economy	48800.00
0005433462713	17269	Economy	48800.00
0005433462710	17269	Economy	48800.00
0005433462718	17269	Economy	48800.00
0005433463864	17269	Economy	48800.00
0005433462719	17269	Economy	48800.00
0005433462717	17269	Economy	48800.00
0005433463873	17269	Economy	48800.00
0005433462712	17269	Economy	48800.00
0005433462724	17269	Economy	48800.00
0005433462720	17269	Economy	48800.00
0005433463871	17269	Economy	48800.00
0005433463875	17269	Economy	48800.00
0005433463866	17269	Economy	48800.00
0005433462721	17269	Economy	48800.00
0005433463868	17269	Economy	48800.00
0005433463878	17269	Economy	48800.00
0005433462716	17269	Economy	48800.00
0005433463874	17269	Economy	48800.00
0005433284772	23019	Business	15700.00
0005435103851	23019	Economy	5200.00
0005433284769	23019	Economy	5200.00
0005435103850	23019	Economy	5200.00
0005435103852	23019	Economy	5200.00
0005433284771	23019	Economy	5200.00
0005433284990	32098	Business	15700.00
0005433284978	32098	Business	15700.00
0005433284998	32098	Business	15700.00
0005433284988	32098	Business	15700.00
0005433285002	32098	Economy	5200.00
0005433285000	32098	Economy	5200.00
0005433284983	32098	Economy	5200.00
0005433284984	32098	Economy	5200.00
0005433284976	32098	Economy	5200.00
0005433284991	32098	Economy	5200.00
0005433284980	32098	Economy	5200.00
0005433285004	32098	Economy	5200.00
0005433284997	32098	Economy	5200.00
0005433284996	32098	Economy	5700.00
0005433284994	32098	Economy	5200.00
0005433284993	32098	Economy	5200.00
0005433285006	32098	Economy	5200.00
0005433284999	32098	Economy	5200.00
0005433284981	32098	Economy	5200.00
0005433284986	32098	Economy	5200.00
0005433284985	32098	Economy	5200.00
0005433284975	32098	Economy	5200.00
0005433284995	32098	Economy	5200.00
0005433284977	32098	Economy	5200.00
0005433285005	32098	Economy	5200.00
0005433284987	32098	Economy	5200.00
0005433285001	32098	Economy	5200.00
0005433285003	32098	Economy	5200.00
0005433284979	32098	Economy	5200.00
0005433284992	32098	Economy	5200.00
0005433284982	32098	Economy	5200.00
0005433284989	32098	Economy	5200.00
0005432159817	30606	Business	42100.00
0005434066321	30606	Business	42100.00
0005434066378	30606	Business	42100.00
0005435212949	30606	Business	42100.00
0005432525886	30606	Business	42100.00
0005432533242	30606	Business	42100.00
0005435212893	30606	Business	42100.00
0005434066376	30606	Business	42100.00
0005432525980	30606	Comfort	23900.00
0005435212904	30606	Comfort	23900.00
0005435212907	30606	Comfort	23900.00
0005432526132	30606	Comfort	23900.00
0005435212945	30606	Comfort	23900.00
0005435212939	30606	Comfort	23900.00
0005432526110	30606	Comfort	23900.00
0005435212914	30606	Comfort	23900.00
0005432525905	30606	Comfort	23900.00
0005434066362	30606	Comfort	23900.00
0005435212936	30606	Comfort	23900.00
0005435212895	30606	Comfort	23900.00
0005435212933	30606	Comfort	23900.00
0005432211435	30606	Comfort	23900.00
0005435212924	30606	Comfort	23900.00
0005432526011	30606	Comfort	23900.00
0005432525941	30606	Comfort	23900.00
0005435212912	30606	Comfort	23900.00
0005435212902	30606	Comfort	23900.00
0005432525989	30606	Comfort	23900.00
0005435212930	30606	Comfort	23900.00
0005435212897	30606	Comfort	23900.00
0005433656641	30606	Comfort	23900.00
0005434066308	30606	Comfort	23900.00
0005432525663	30606	Comfort	23900.00
0005435212889	30606	Comfort	23900.00
0005432525988	30606	Comfort	23900.00
0005432535752	30606	Comfort	23900.00
0005434066316	30606	Economy	14000.00
0005435212931	30606	Economy	14000.00
0005432526402	30606	Economy	14000.00
0005432211432	30606	Economy	14000.00
0005434066360	30606	Economy	14000.00
0005434066495	30606	Economy	14000.00
0005432525856	30606	Economy	14000.00
0005432526222	30606	Economy	14000.00
0005432525904	30606	Economy	14000.00
0005432525799	30606	Economy	14000.00
0005432533241	30606	Economy	14000.00
0005435212948	30606	Economy	14000.00
0005432525775	30606	Economy	14000.00
0005432159812	30606	Economy	14000.00
0005432159815	30606	Economy	14000.00
0005435212940	30606	Economy	14000.00
0005435212942	30606	Economy	14000.00
0005434066365	30606	Economy	14000.00
0005432525857	30606	Economy	14000.00
0005432525854	30606	Economy	14000.00
0005435212919	30606	Economy	14000.00
0005435212920	30606	Economy	14000.00
0005435212927	30606	Economy	14000.00
0005434066324	30606	Economy	14000.00
0005432211429	30606	Economy	14000.00
0005435212901	30606	Economy	14000.00
0005432525956	30606	Economy	14000.00
0005432525887	30606	Economy	14000.00
0005434066496	30606	Economy	14000.00
0005432211433	30606	Economy	14000.00
0005435725555	30606	Economy	14000.00
0005432526221	30606	Economy	14000.00
0005433656640	30606	Economy	15400.00
0005432533256	30606	Economy	14000.00
0005432526096	30606	Economy	14000.00
0005432525651	30606	Economy	14000.00
0005434066466	30606	Economy	14000.00
0005435212885	30606	Economy	14000.00
0005435212913	30606	Economy	14000.00
0005435212934	30606	Economy	14000.00
0005434066494	30606	Economy	14000.00
0005432211434	30606	Economy	14000.00
0005435212922	30606	Economy	14000.00
0005435212946	30606	Economy	14000.00
0005432526097	30606	Economy	14000.00
0005434066336	30606	Economy	14000.00
0005435630938	30606	Economy	14000.00
0005435212910	30606	Economy	14000.00
0005432525671	30606	Economy	14000.00
0005435212935	30606	Economy	14000.00
0005432525800	30606	Economy	14000.00
0005432526032	30606	Economy	14000.00
0005432211430	30606	Economy	14000.00
0005432525776	30606	Economy	14000.00
0005434066359	30606	Economy	14000.00
0005435212888	30606	Economy	14000.00
0005435212903	30606	Economy	14000.00
0005435212916	30606	Economy	14000.00
0005435212951	30606	Economy	14000.00
0005435212941	30606	Economy	14000.00
0005432525711	30606	Economy	14000.00
0005432211431	30606	Economy	14000.00
0005435725554	30606	Economy	14000.00
0005432525779	30606	Economy	14000.00
0005435212906	30606	Economy	14000.00
0005434066312	30606	Economy	14000.00
0005434066385	30606	Economy	14000.00
0005435212944	30606	Economy	14000.00
0005432526151	30606	Economy	14000.00
0005432211428	30606	Economy	14000.00
0005432525656	30606	Economy	14000.00
0005434066400	30606	Economy	14000.00
0005435212900	30606	Economy	14000.00
0005435212947	30606	Economy	14000.00
0005435212925	30606	Economy	14000.00
0005434066337	30606	Economy	14000.00
0005434066427	30606	Economy	14000.00
0005432526012	30606	Economy	14000.00
0005432525885	30606	Economy	14000.00
0005435212890	30606	Economy	14000.00
0005432525889	30606	Economy	14000.00
0005432535746	30606	Economy	14000.00
0005432428868	30606	Economy	14000.00
0005434066386	30606	Economy	14000.00
0005432525688	30606	Economy	14000.00
0005432159814	30606	Economy	14000.00
0005432525763	30606	Economy	14000.00
0005432525761	30606	Economy	14000.00
0005435212887	30606	Economy	14000.00
0005432525703	30606	Economy	14000.00
0005432525639	30606	Economy	15400.00
0005432525650	30606	Economy	14000.00
0005435212937	30606	Economy	15400.00
0005435212894	30606	Economy	15400.00
0005434066487	30606	Economy	14000.00
0005434066424	30606	Economy	14000.00
0005435212917	30606	Economy	14000.00
0005432525974	30606	Economy	14000.00
0005435212884	30606	Economy	14000.00
0005432211427	30606	Economy	14000.00
0005435212892	30606	Economy	14000.00
0005432525780	30606	Economy	14000.00
0005432535751	30606	Economy	14000.00
0005433656638	30606	Economy	14000.00
0005432159816	30606	Economy	14000.00
0005432525638	30606	Economy	14000.00
0005432525864	30606	Economy	14000.00
0005432525977	30606	Economy	14000.00
0005434066379	30606	Economy	14000.00
0005432526313	30606	Economy	14000.00
0005434066374	30606	Economy	14000.00
0005435212896	30606	Economy	14000.00
0005432525851	30606	Economy	14000.00
0005432525940	30606	Economy	14000.00
0005435212923	30606	Economy	14000.00
0005435212891	30606	Economy	14000.00
0005432525721	30606	Economy	14000.00
0005432525843	30606	Economy	14000.00
0005432525698	30606	Economy	14000.00
0005432537022	30606	Economy	14000.00
0005435212909	30606	Economy	14000.00
0005435212926	30606	Economy	14000.00
0005432526289	30606	Economy	14000.00
0005432525979	30606	Economy	14000.00
0005435212928	30606	Economy	14000.00
0005435212938	30606	Economy	14000.00
0005435725553	30606	Economy	14000.00
0005435212915	30606	Economy	14000.00
0005435212899	30606	Economy	14000.00
0005435212943	30606	Economy	14000.00
0005435212898	30606	Economy	14000.00
0005435212918	30606	Economy	14000.00
0005432526044	30606	Economy	14000.00
0005435212905	30606	Economy	14000.00
0005435212932	30606	Economy	14000.00
0005432159813	30606	Economy	14000.00
0005434066353	30606	Economy	14000.00
0005435212929	30606	Economy	14000.00
0005435630940	30606	Economy	14000.00
0005432526401	30606	Economy	14000.00
0005434066380	30606	Economy	14000.00
0005432525995	30606	Economy	14000.00
0005432428873	30606	Economy	14000.00
0005434066486	30606	Economy	14000.00
0005432428872	30606	Economy	14000.00
0005432526150	30606	Economy	14000.00
0005432525760	30606	Economy	14000.00
0005432533257	30606	Economy	14000.00
0005432525771	30606	Economy	14000.00
0005432525808	30606	Economy	14000.00
0005432525689	30606	Economy	14000.00
0005435212921	30606	Economy	14000.00
0005435212911	30606	Economy	14000.00
0005435212908	30606	Economy	14000.00
0005435212950	30606	Economy	14000.00
0005435212886	30606	Economy	14000.00
0005435725556	30606	Economy	14000.00
0005434066375	30606	Economy	14000.00
0005432525682	30606	Economy	14000.00
0005432525839	30606	Economy	14000.00
0005432526054	30606	Economy	14000.00
0005432525741	30606	Economy	14000.00
0005435630939	30606	Economy	14000.00
0005433656639	30606	Economy	14000.00
0005435652315	24872	Business	9800.00
0005433367534	24872	Business	9800.00
0005435652311	24872	Business	9800.00
0005433367537	24872	Business	9800.00
0005433367563	24872	Business	9800.00
0005435652310	24872	Economy	3300.00
0005435652286	24872	Economy	3300.00
0005433367551	24872	Economy	3300.00
0005435652293	24872	Economy	3300.00
0005433367527	24872	Economy	3300.00
0005433367543	24872	Economy	3300.00
0005433367546	24872	Economy	3300.00
0005433367526	24872	Economy	3600.00
0005435652314	24872	Economy	3600.00
0005433367561	24872	Economy	3300.00
0005433367528	24872	Economy	3300.00
0005433367559	24872	Economy	3300.00
0005435652266	24872	Economy	3300.00
0005435652281	24872	Economy	3300.00
0005433367525	24872	Economy	3300.00
0005433367541	24872	Economy	3300.00
0005435652285	24872	Economy	3300.00
0005433367556	24872	Economy	3300.00
0005433367532	24872	Economy	3300.00
0005433367536	24872	Economy	3300.00
0005433367535	24872	Economy	3300.00
0005435652309	24872	Economy	3300.00
0005435652312	24872	Economy	3300.00
0005435652265	24872	Economy	3300.00
0005433367553	24872	Economy	3300.00
0005433367558	24872	Economy	3300.00
0005433367555	24872	Economy	3300.00
0005433367562	24872	Economy	3300.00
0005433367554	24872	Economy	3300.00
0005433367557	24872	Economy	3300.00
0005433367550	24872	Economy	3300.00
0005433367544	24872	Economy	3300.00
0005435652291	24872	Economy	3300.00
0005435652308	24872	Economy	3300.00
0005433367548	24872	Economy	3300.00
0005433367542	24872	Economy	3300.00
0005435652296	24872	Economy	3300.00
0005433367552	24872	Economy	3300.00
0005433367539	24872	Economy	3300.00
0005433367547	24872	Economy	3300.00
0005433367545	24872	Economy	3300.00
0005433367533	24872	Economy	3300.00
0005433367531	24872	Economy	3300.00
0005433367538	24872	Economy	3300.00
0005433367540	24872	Economy	3300.00
0005435652287	24872	Economy	3300.00
0005433367529	24872	Economy	3300.00
0005433367560	24872	Economy	3300.00
0005433367549	24872	Economy	3300.00
0005433367530	24872	Economy	3300.00
0005435652294	24872	Economy	3300.00
0005434979523	2065	Economy	10500.00
0005434979499	2065	Economy	10500.00
0005434979507	2065	Economy	10500.00
0005434979501	2065	Economy	10500.00
0005434979500	2065	Economy	9500.00
0005434979508	2065	Economy	9500.00
0005434979509	2065	Economy	9500.00
0005434979522	2065	Economy	9500.00
0005434979524	2065	Economy	9500.00
0005434979510	2065	Economy	9500.00
0005434979503	2065	Economy	9500.00
0005434979525	2065	Economy	9500.00
0005434979505	2065	Economy	9500.00
0005434979515	2065	Economy	9500.00
0005435801668	2065	Economy	9500.00
0005434979528	2065	Economy	9500.00
0005434979527	2065	Economy	9500.00
0005434979498	2065	Economy	9500.00
0005434979519	2065	Economy	9500.00
0005434979504	2065	Economy	9500.00
0005434979512	2065	Economy	9500.00
0005434979502	2065	Economy	9500.00
0005434979517	2065	Economy	9500.00
0005434979506	2065	Economy	9500.00
0005435801667	2065	Economy	9500.00
0005434979516	2065	Economy	9500.00
0005434979526	2065	Economy	9500.00
0005434979518	2065	Economy	9500.00
0005434979520	2065	Economy	9500.00
0005434979521	2065	Economy	9500.00
0005434979513	2065	Economy	9500.00
0005434979514	2065	Economy	9500.00
0005434979511	2065	Economy	9500.00
0005434979299	23578	Economy	9500.00
0005434979363	23578	Economy	9500.00
0005434979253	23578	Economy	9500.00
0005434979254	23578	Economy	9500.00
0005434979331	23578	Economy	9500.00
0005434979337	23578	Economy	9500.00
0005435801648	23578	Economy	9500.00
0005434979283	23578	Economy	9500.00
0005434979362	23578	Economy	9500.00
0005434979260	23578	Economy	9500.00
0005434952495	2628	Economy	5300.00
0005434952497	2628	Economy	5300.00
0005434952496	2628	Economy	5300.00
0005434952498	2628	Economy	5300.00
0005433256388	2629	Economy	5300.00
0005433256385	2629	Economy	5300.00
0005433256401	28239	Economy	5300.00
0005434952470	28239	Economy	5300.00
0005434952474	28239	Economy	5300.00
0005433111486	19806	Economy	8700.00
0005433111487	19806	Economy	8700.00
0005433111485	19806	Economy	8700.00
0005433111488	19806	Economy	8700.00
0005434136933	11928	Business	9700.00
0005434136850	11928	Business	9700.00
0005434136907	11928	Business	9700.00
0005434136934	11928	Economy	3200.00
0005434136853	11928	Economy	3200.00
0005434136798	11928	Economy	3200.00
0005434136900	11928	Economy	3200.00
0005434136780	11928	Economy	3500.00
0005434136679	11928	Economy	3500.00
0005434136884	11928	Economy	3200.00
0005434136736	11928	Economy	3200.00
0005434136829	11928	Economy	3200.00
0005434136852	11928	Economy	3200.00
0005434136967	11928	Economy	3200.00
0005434136958	11928	Economy	3200.00
0005434136982	11928	Economy	3200.00
0005434136928	11928	Economy	3200.00
0005434136865	11928	Economy	3200.00
0005434136749	11928	Economy	3200.00
0005434136683	11928	Economy	3200.00
0005434136709	11928	Economy	3200.00
0005434136779	11928	Economy	3200.00
0005434136828	11928	Economy	3200.00
0005434137037	11928	Economy	3200.00
0005434136803	11928	Economy	3200.00
0005434136684	11928	Economy	3200.00
0005434136844	11928	Economy	3200.00
0005434136800	11928	Economy	3200.00
0005434136823	11928	Economy	3200.00
0005434136893	11928	Economy	3200.00
0005434136802	11928	Economy	3200.00
0005434136758	11928	Economy	3200.00
0005434136701	11928	Economy	3200.00
0005434136807	11928	Economy	3200.00
0005434136767	11928	Economy	3200.00
0005434136773	11928	Economy	3200.00
0005434136827	11928	Economy	3200.00
0005434136938	11928	Economy	3200.00
0005434136698	11928	Economy	3200.00
0005434136801	11928	Economy	3200.00
0005434136871	11928	Economy	3200.00
0005434136856	11928	Economy	3200.00
0005434136700	11928	Economy	3200.00
0005434136998	11928	Economy	3200.00
0005434136721	11928	Economy	3200.00
0005434136737	11928	Economy	3200.00
0005434136851	11928	Economy	3200.00
0005434136898	11928	Economy	3200.00
0005434136899	11928	Economy	3200.00
0005434136781	11928	Economy	3200.00
0005434137278	28751	Business	9700.00
0005434137327	28751	Business	9700.00
0005434137318	28751	Business	9700.00
0005434137272	28751	Business	9700.00
0005434137341	28751	Business	9700.00
0005434137346	28751	Business	9700.00
0005434137290	28751	Business	9700.00
0005434137280	28751	Business	9700.00
0005434137356	28751	Business	9700.00
0005434137310	28751	Business	9700.00
0005434137355	28751	Business	9700.00
0005434137321	28751	Economy	3200.00
0005434137284	28751	Economy	3200.00
0005434137332	28751	Economy	3200.00
0005434137287	28751	Economy	3200.00
0005434137297	28751	Economy	3200.00
0005434137298	28751	Economy	3200.00
0005434137315	28751	Economy	3200.00
0005434137271	28751	Economy	3200.00
0005434137289	28751	Economy	3200.00
0005434137301	28751	Economy	3200.00
0005434137320	28751	Economy	3500.00
0005434137348	28751	Economy	3500.00
0005434137274	28751	Economy	3500.00
0005434137329	28751	Economy	3500.00
0005434137347	28751	Economy	3500.00
0005434137293	28751	Economy	3200.00
0005434137352	28751	Economy	3200.00
0005434137349	28751	Economy	3200.00
0005434137312	28751	Economy	3200.00
0005434137305	28751	Economy	3200.00
0005434137325	28751	Economy	3200.00
0005434137326	28751	Economy	3200.00
0005434137353	28751	Economy	3200.00
0005434137299	28751	Economy	3200.00
0005434137309	28751	Economy	3200.00
0005434137317	28751	Economy	3200.00
0005434137350	28751	Economy	3200.00
0005434137330	28751	Economy	3200.00
0005434137337	28751	Economy	3200.00
0005434137294	28751	Economy	3200.00
0005434137316	28751	Economy	3200.00
0005434137269	28751	Economy	3200.00
0005434137268	28751	Economy	3200.00
0005434137291	28751	Economy	3200.00
0005434137351	28751	Economy	3200.00
0005434137288	28751	Economy	3200.00
0005434137323	28751	Economy	3200.00
0005434137285	28751	Economy	3200.00
0005434137322	28751	Economy	3200.00
0005434137342	28751	Economy	3200.00
0005434137279	28751	Economy	3200.00
0005434137277	28751	Economy	3200.00
0005434137286	28751	Economy	3200.00
0005434137270	28751	Economy	3200.00
0005434137319	28751	Economy	3200.00
0005434137339	28751	Economy	3200.00
0005434137333	28751	Economy	3200.00
0005434137313	28751	Economy	3200.00
0005434137281	28751	Economy	3200.00
0005434137295	28751	Economy	3200.00
0005434137283	28751	Economy	3200.00
0005434137344	28751	Economy	3200.00
0005434137282	28751	Economy	3200.00
0005434137338	28751	Economy	3200.00
0005434137292	28751	Economy	3200.00
0005434137302	28751	Economy	3200.00
0005434137343	28751	Economy	3200.00
0005434137306	28751	Economy	3200.00
0005434137354	28751	Economy	3200.00
0005434137300	28751	Economy	3200.00
0005434137273	28751	Economy	3200.00
0005434137307	28751	Economy	3200.00
0005434137336	28751	Economy	3200.00
0005434137340	28751	Economy	3200.00
0005434137304	28751	Economy	3200.00
0005434137308	28751	Economy	3200.00
0005434137345	28751	Economy	3200.00
0005434137311	28751	Economy	3200.00
0005434137314	28751	Economy	3200.00
0005434137335	28751	Economy	3200.00
0005434137324	28751	Economy	3200.00
0005434137296	28751	Economy	3200.00
0005434137331	28751	Economy	3200.00
0005434137303	28751	Economy	3200.00
0005434137334	28751	Economy	3200.00
0005434137276	28751	Economy	3200.00
0005434137275	28751	Economy	3200.00
0005434137328	28751	Economy	3200.00
0005435259695	6790	Economy	10900.00
0005433534480	6790	Economy	9900.00
0005435259684	6790	Economy	9900.00
0005433538793	6790	Economy	9900.00
0005435259678	6790	Economy	9900.00
0005433538789	6790	Economy	9900.00
0005433538790	6790	Economy	9900.00
0005433538786	6790	Economy	9900.00
0005433538787	6790	Economy	9900.00
0005435259696	6790	Economy	9900.00
0005433538788	6790	Economy	9900.00
0005433534479	6790	Economy	9900.00
0005433538791	6790	Economy	9900.00
0005433534478	6790	Economy	9900.00
0005433538794	6790	Economy	9900.00
0005433538792	6790	Economy	9900.00
0005433538746	25035	Economy	9900.00
0005433538747	25035	Economy	9900.00
0005435259715	25035	Economy	9900.00
0005435259717	25035	Economy	9900.00
0005435259714	25035	Economy	9900.00
0005435259716	25035	Economy	9900.00
0005433511874	821	Economy	16100.00
0005433511877	821	Economy	14600.00
0005433511875	821	Economy	14600.00
0005433511871	821	Economy	14600.00
0005433511872	821	Economy	14600.00
0005432922467	821	Economy	14600.00
0005433511876	821	Economy	14600.00
0005433511870	821	Economy	14600.00
0005433511873	821	Economy	14600.00
0005432922486	16151	Economy	14600.00
0005433511818	16151	Economy	14600.00
0005433511814	16151	Economy	14600.00
0005432922488	16151	Economy	14600.00
0005432922487	16151	Economy	14600.00
0005433511813	16151	Economy	14600.00
0005433511819	16151	Economy	14600.00
0005433511839	16151	Economy	14600.00
0005432922489	16151	Economy	14600.00
0005435916121	3702	Economy	7900.00
0005435697073	3702	Economy	7900.00
0005435697077	3702	Economy	7900.00
0005435697082	3702	Economy	7900.00
0005435697094	3702	Economy	7200.00
0005435697085	3702	Economy	7200.00
0005435697100	3702	Economy	7200.00
0005435697091	3702	Economy	7200.00
0005435697092	3702	Economy	7200.00
0005434950488	3702	Economy	7200.00
0005435697087	3702	Economy	7200.00
0005435916123	3702	Economy	7200.00
0005435697097	3702	Economy	7200.00
0005435697081	3702	Economy	7200.00
0005435697101	3702	Economy	7200.00
0005435697088	3702	Economy	7200.00
0005435697083	3702	Economy	7200.00
0005435697093	3702	Economy	7200.00
0005435697099	3702	Economy	7200.00
0005435697096	3702	Economy	7200.00
0005435697076	3702	Economy	7200.00
0005435697084	3702	Economy	7200.00
0005435697078	3702	Economy	7200.00
0005434950489	3702	Economy	7200.00
0005435697074	3702	Economy	7200.00
0005435697090	3702	Economy	7200.00
0005435697086	3702	Economy	7200.00
0005435916124	3702	Economy	7200.00
0005435916120	3702	Economy	7200.00
0005435697095	3702	Economy	7200.00
0005435697080	3702	Economy	7200.00
0005435934993	3702	Economy	7200.00
0005434950487	3702	Economy	7200.00
0005435697098	3702	Economy	7200.00
0005435697079	3702	Economy	7200.00
0005435697089	3702	Economy	7200.00
0005435697075	3702	Economy	7200.00
0005434950486	3702	Economy	7200.00
0005435916141	16290	Economy	7900.00
0005434950452	16290	Economy	7200.00
0005435696905	16290	Economy	7200.00
0005435696846	16290	Economy	7200.00
0005435696856	16290	Economy	7200.00
0005435935014	16290	Economy	7200.00
0005435696875	16290	Economy	7200.00
0005435916142	16290	Economy	7200.00
0005435696904	16290	Economy	7200.00
0005435696924	16290	Economy	7200.00
0005434950456	16290	Economy	7200.00
0005435935015	16290	Economy	7200.00
0005435696934	16290	Economy	7200.00
0005435696874	16290	Economy	7200.00
0005435696978	16290	Economy	7200.00
0005435696977	16290	Economy	7200.00
0005434606794	3975	Economy	21300.00
0005434604868	3975	Economy	21300.00
0005434606797	3975	Economy	21300.00
0005432607528	3975	Economy	19300.00
0005433519415	3975	Economy	19300.00
0005432609696	3975	Economy	19300.00
0005433519418	3975	Economy	19300.00
0005433519414	3975	Economy	19300.00
0005432609695	3975	Economy	19300.00
0005435842315	3975	Economy	19300.00
0005433519417	3975	Economy	19300.00
0005432607529	3975	Economy	19300.00
0005432609694	3975	Economy	19300.00
0005432607530	3975	Economy	19300.00
0005434604867	3975	Economy	19300.00
0005433519416	3975	Economy	19300.00
0005434604866	3975	Economy	19300.00
0005434606795	3975	Economy	19300.00
0005434604865	3975	Economy	19300.00
0005435842316	3975	Economy	19300.00
0005434606796	3975	Economy	19300.00
0005432609692	3975	Economy	19300.00
0005432609693	3975	Economy	19300.00
0005433519382	22089	Economy	21300.00
0005432609662	22089	Economy	19300.00
0005432613799	22089	Economy	19300.00
0005432609667	22089	Economy	19300.00
0005433519383	22089	Economy	19300.00
0005433519378	22089	Economy	19300.00
0005432609663	22089	Economy	19300.00
0005435628696	697	Economy	3700.00
0005435628697	697	Economy	3700.00
0005435628698	697	Economy	3700.00
0005435628699	697	Economy	3700.00
0005433348894	697	Economy	3700.00
0005433348939	15904	Economy	3700.00
0005433348938	15904	Economy	3700.00
0005433348937	15904	Economy	3700.00
0005433348936	15904	Economy	3700.00
0005433348941	15904	Economy	3700.00
0005433348940	15904	Economy	3700.00
0005433348935	15904	Economy	3700.00
0005433348934	15904	Economy	3700.00
0005434445223	17191	Economy	7100.00
0005434446496	17191	Economy	7100.00
0005434446497	17191	Economy	7100.00
0005434446495	17191	Economy	7100.00
0005433159295	17591	Economy	7100.00
0005433159292	17591	Economy	7100.00
0005433159293	17591	Economy	7100.00
0005433159294	17591	Economy	7100.00
0005435132782	7884	Economy	5900.00
0005435132789	7884	Economy	5900.00
0005435132787	7884	Economy	5400.00
0005435132783	7884	Economy	5400.00
0005435132781	7884	Economy	5400.00
0005435132786	7884	Economy	5400.00
0005435132788	7884	Economy	5400.00
0005435132785	7884	Economy	5400.00
0005435132791	7884	Economy	5400.00
0005435132784	7884	Economy	5400.00
0005435132790	7884	Economy	5400.00
0005435383101	33071	Economy	5900.00
0005435132709	33071	Economy	5400.00
0005435383100	33071	Economy	5400.00
0005435132710	33071	Economy	5400.00
0005435383103	33071	Economy	5400.00
0005435383102	33071	Economy	5400.00
0005435383099	33071	Economy	5400.00
0005435132758	33071	Economy	5400.00
0005435132708	33071	Economy	5400.00
0005435132698	33071	Economy	5400.00
0005435811030	4420	Business	133200.00
0005435811024	4420	Economy	44400.00
0005435938843	4420	Economy	44400.00
0005435811031	4420	Economy	44400.00
0005435811027	4420	Economy	44400.00
0005435811025	4420	Economy	44400.00
0005435811022	4420	Economy	44400.00
0005435811026	4420	Economy	44400.00
0005435811028	4420	Economy	44400.00
0005435811029	4420	Economy	44400.00
0005435811023	4420	Economy	44400.00
0005435938862	29448	Business	133200.00
0005435938861	29448	Economy	48800.00
0005435810989	29448	Economy	44400.00
0005435938860	29448	Economy	44400.00
0005435938863	29448	Economy	44400.00
0005435938864	29448	Economy	44400.00
0005435810985	29448	Economy	44400.00
0005435810986	29448	Economy	44400.00
0005435160200	7518	Economy	13800.00
0005435160204	7518	Economy	13800.00
0005435390116	7518	Economy	13800.00
0005435160196	7518	Economy	13800.00
0005435160198	7518	Economy	12500.00
0005435390133	7518	Economy	12500.00
0005435390135	7518	Economy	12500.00
0005435390118	7518	Economy	12500.00
0005435390136	7518	Economy	12500.00
0005435160199	7518	Economy	12500.00
0005435160202	7518	Economy	12500.00
0005435160203	7518	Economy	12500.00
0005435160195	7518	Economy	12500.00
0005435160205	7518	Economy	12500.00
0005435390122	7518	Economy	12500.00
0005435160201	7518	Economy	12500.00
0005435160197	7518	Economy	12500.00
0005435160111	29581	Economy	13800.00
0005435160116	29581	Economy	13800.00
0005435160126	29581	Economy	13800.00
0005435390181	29581	Economy	13800.00
0005435390173	29581	Economy	12500.00
0005435390178	29581	Economy	12500.00
0005435390179	29581	Economy	12500.00
0005435160141	29581	Economy	12500.00
0005435390177	29581	Economy	12500.00
0005435160119	29581	Economy	12500.00
0005435160120	29581	Economy	12500.00
0005435390180	29581	Economy	12500.00
0005435160136	29581	Economy	12500.00
0005435160127	29581	Economy	12500.00
0005435160110	29581	Economy	12500.00
0005435390174	29581	Economy	12500.00
0005435160128	29581	Economy	12500.00
0005435390176	29581	Economy	12500.00
0005435390175	29581	Economy	12500.00
0005432398132	18456	Economy	4900.00
0005435178481	18456	Economy	4900.00
0005432398149	18456	Economy	4900.00
0005432394033	18456	Economy	4900.00
0005432394039	18456	Economy	4900.00
0005435178480	18456	Economy	4900.00
0005432400088	27172	Economy	4900.00
0005432400090	27172	Economy	4900.00
0005432398157	27172	Economy	4900.00
0005432400086	27172	Economy	4900.00
0005432400089	27172	Economy	4900.00
0005432400087	27172	Economy	4900.00
0005435178471	27172	Economy	4900.00
0005432398159	27172	Economy	4900.00
0005432398161	27172	Economy	4900.00
0005432398158	27172	Economy	4900.00
0005432398160	27172	Economy	4900.00
0005434503786	6541	Business	48400.00
0005434503810	6541	Business	48400.00
0005434503798	6541	Business	48400.00
0005434503821	6541	Business	48400.00
0005434503807	6541	Business	48400.00
0005434503812	6541	Economy	16100.00
0005434503814	6541	Economy	16100.00
0005434503785	6541	Economy	16100.00
0005434503805	6541	Economy	16100.00
0005435103864	6541	Economy	16100.00
0005434503790	6541	Economy	16100.00
0005434503817	6541	Economy	17800.00
0005434503794	6541	Economy	17800.00
0005434503801	6541	Economy	16100.00
0005434503788	6541	Economy	16100.00
0005434503804	6541	Economy	16100.00
0005434503815	6541	Economy	16100.00
0005434503787	6541	Economy	16100.00
0005434503792	6541	Economy	16100.00
0005434503811	6541	Economy	16100.00
0005434503795	6541	Economy	16100.00
0005434503808	6541	Economy	16100.00
0005434503796	6541	Economy	16100.00
0005434503793	6541	Economy	16100.00
0005435103866	6541	Economy	16100.00
0005435103863	6541	Economy	16100.00
0005434503802	6541	Economy	16100.00
0005434503789	6541	Economy	16100.00
0005434503818	6541	Economy	16100.00
0005434503797	6541	Economy	16100.00
0005434503822	6541	Economy	16100.00
0005435103862	6541	Economy	16100.00
0005434503813	6541	Economy	16100.00
0005434503783	6541	Economy	16100.00
0005434503784	6541	Economy	16100.00
0005434503806	6541	Economy	16100.00
0005434503819	6541	Economy	16100.00
0005434503803	6541	Economy	16100.00
0005434503791	6541	Economy	16100.00
0005434503816	6541	Economy	16100.00
0005434503809	6541	Economy	16100.00
0005434503820	6541	Economy	16100.00
0005434503799	6541	Economy	16100.00
0005435103865	6541	Economy	16100.00
0005434503800	6541	Economy	16100.00
0005434503478	22638	Business	48400.00
0005434503571	22638	Business	48400.00
0005434503477	22638	Business	48400.00
0005434503614	22638	Economy	16100.00
0005434503572	22638	Economy	16100.00
0005434503613	22638	Economy	16100.00
0005434503469	22638	Economy	16100.00
0005434503463	22638	Economy	16100.00
0005434503464	22638	Economy	16100.00
0005435800077	21307	Economy	16800.00
0005435800078	21307	Economy	15300.00
0005435800081	21307	Economy	15300.00
0005435652621	1646	Business	50000.00
0005433367302	1646	Business	50000.00
0005435652642	1646	Business	50000.00
0005435652647	1646	Business	50000.00
0005433367281	1646	Business	50000.00
0005435652659	1646	Business	50000.00
0005433367330	1646	Business	50000.00
0005435652651	1646	Business	50000.00
0005435652650	1646	Economy	16700.00
0005435652655	1646	Economy	16700.00
0005433367300	1646	Economy	16700.00
0005435652622	1646	Economy	16700.00
0005435652644	1646	Economy	16700.00
0005433367287	1646	Economy	16700.00
0005435652635	1646	Economy	16700.00
0005435652648	1646	Economy	18300.00
0005433367262	1646	Economy	18300.00
0005433367253	1646	Economy	18300.00
0005435652634	1646	Economy	16700.00
0005435652661	1646	Economy	16700.00
0005435652641	1646	Economy	16700.00
0005435652665	1646	Economy	16700.00
0005435652645	1646	Economy	16700.00
0005433367272	1646	Economy	16700.00
0005435652662	1646	Economy	16700.00
0005435652654	1646	Economy	16700.00
0005433367273	1646	Economy	16700.00
0005433367362	1646	Economy	16700.00
0005433367316	1646	Economy	16700.00
0005435652658	1646	Economy	16700.00
0005433367274	1646	Economy	16700.00
0005433367301	1646	Economy	16700.00
0005433367391	1646	Economy	16700.00
0005435652629	1646	Economy	16700.00
0005433367267	1646	Economy	16700.00
0005433367288	1646	Economy	16700.00
0005435652652	1646	Economy	16700.00
0005435652643	1646	Economy	16700.00
0005433367245	1646	Economy	16700.00
0005435652668	1646	Economy	16700.00
0005435652663	1646	Economy	16700.00
0005435652632	1646	Economy	16700.00
0005433367230	1646	Economy	16700.00
0005433367225	1646	Economy	16700.00
0005433367361	1646	Economy	16700.00
0005435652626	1646	Economy	16700.00
0005435652640	1646	Economy	16700.00
0005433367393	1646	Economy	16700.00
0005435652657	1646	Economy	16700.00
0005435652664	1646	Economy	16700.00
0005433367231	1646	Economy	16700.00
0005435652631	1646	Economy	16700.00
0005433367240	1646	Economy	16700.00
0005435652628	1646	Economy	16700.00
0005435652625	1646	Economy	16700.00
0005435652656	1646	Economy	16700.00
0005435652639	1646	Economy	16700.00
0005435652667	1646	Economy	16700.00
0005435652660	1646	Economy	16700.00
0005435652636	1646	Economy	16700.00
0005435652666	1646	Economy	16700.00
0005433367331	1646	Economy	16700.00
0005433367226	1646	Economy	16700.00
0005433367392	1646	Economy	16700.00
0005435652638	1646	Economy	16700.00
0005435652623	1646	Economy	16700.00
0005435652630	1646	Economy	16700.00
0005435652649	1646	Economy	16700.00
0005435652624	1646	Economy	16700.00
0005435652627	1646	Economy	16700.00
0005435652669	1646	Economy	16700.00
0005435652633	1646	Economy	16700.00
0005435652646	1646	Economy	16700.00
0005435652653	1646	Economy	16700.00
0005435652637	1646	Economy	16700.00
0005433367547	21709	Business	50000.00
0005435652285	21709	Business	50000.00
0005435652310	21709	Business	50000.00
0005433367554	21709	Business	50000.00
0005433367563	21709	Economy	16700.00
0005433367544	21709	Economy	16700.00
0005433367550	21709	Economy	16700.00
0005433367533	21709	Economy	16700.00
0005435652293	21709	Economy	16700.00
0005433367548	21709	Economy	16700.00
0005435652286	21709	Economy	16700.00
0005433367549	21709	Economy	18300.00
0005435652265	21709	Economy	18300.00
0005433367538	21709	Economy	18300.00
0005435652294	21709	Economy	16700.00
0005433367532	21709	Economy	16700.00
0005433367534	21709	Economy	16700.00
0005433367559	21709	Economy	16700.00
0005435652312	21709	Economy	16700.00
0005435652315	21709	Economy	16700.00
0005435652291	21709	Economy	16700.00
0005433367541	21709	Economy	16700.00
0005435652287	21709	Economy	16700.00
0005433367562	21709	Economy	16700.00
0005433367552	21709	Economy	16700.00
0005435652311	21709	Economy	16700.00
0005433367543	21709	Economy	16700.00
0005433367545	21709	Economy	16700.00
0005433367556	21709	Economy	16700.00
0005433367542	21709	Economy	16700.00
0005433367540	21709	Economy	16700.00
0005433367526	21709	Economy	16700.00
0005433367558	21709	Economy	16700.00
0005433367530	21709	Economy	16700.00
0005433367546	21709	Economy	16700.00
0005433367537	21709	Economy	16700.00
0005433367527	21709	Economy	16700.00
0005433367539	21709	Economy	16700.00
0005433367560	21709	Economy	16700.00
0005433367528	21709	Economy	16700.00
0005435652309	21709	Economy	16700.00
0005433367536	21709	Economy	16700.00
0005435652314	21709	Economy	16700.00
0005433367553	21709	Economy	16700.00
0005435652266	21709	Economy	16700.00
0005433367535	21709	Economy	16700.00
0005433367531	21709	Economy	16700.00
0005433367561	21709	Economy	16700.00
0005433367525	21709	Economy	16700.00
0005433367551	21709	Economy	16700.00
0005435652296	21709	Economy	16700.00
0005435652308	21709	Economy	16700.00
0005435652281	21709	Economy	16700.00
0005433367555	21709	Economy	16700.00
0005433367557	21709	Economy	16700.00
0005433367529	21709	Economy	16700.00
0005433985543	4168	Business	21500.00
0005433985530	4168	Business	21500.00
0005433985533	4168	Business	21500.00
0005433985531	4168	Business	21500.00
0005433985534	4168	Business	21500.00
0005433985527	4168	Business	21500.00
0005433985537	4168	Economy	7200.00
0005433985525	4168	Economy	7200.00
0005433985529	4168	Economy	7200.00
0005433985518	4168	Economy	7200.00
0005433985550	4168	Economy	7200.00
0005433985523	4168	Economy	7900.00
0005433985545	4168	Economy	7900.00
0005433985556	4168	Economy	7200.00
0005433985517	4168	Economy	7200.00
0005433985526	4168	Economy	7200.00
0005433985521	4168	Economy	7200.00
0005433985520	4168	Economy	7200.00
0005433985548	4168	Economy	7200.00
0005433985558	4168	Economy	7200.00
0005433985554	4168	Economy	7200.00
0005433985540	4168	Economy	7200.00
0005433985553	4168	Economy	7200.00
0005433985535	4168	Economy	7200.00
0005433985552	4168	Economy	7200.00
0005433985542	4168	Economy	7200.00
0005433985528	4168	Economy	7200.00
0005433985532	4168	Economy	7200.00
0005433985539	4168	Economy	7200.00
0005433985557	4168	Economy	7200.00
0005433985555	4168	Economy	7200.00
0005433985544	4168	Economy	7200.00
0005433985541	4168	Economy	7200.00
0005433985546	4168	Economy	7200.00
0005433985524	4168	Economy	7200.00
0005435788748	4168	Economy	7200.00
0005433985549	4168	Economy	7200.00
0005433985522	4168	Economy	7200.00
0005433985538	4168	Economy	7200.00
0005433985547	4168	Economy	7200.00
0005433985551	4168	Economy	7200.00
0005433985536	4168	Economy	7200.00
0005433985519	4168	Economy	7200.00
0005435788736	25683	Business	21500.00
0005433985288	25683	Business	21500.00
0005433985203	25683	Economy	7200.00
0005433985190	25683	Economy	7200.00
0005433985128	25683	Economy	7200.00
0005433985124	25683	Economy	7900.00
0005433985136	25683	Economy	7900.00
0005433985125	25683	Economy	7200.00
0005433985130	25683	Economy	7200.00
0005433985248	25683	Economy	7200.00
0005433985133	25683	Economy	7200.00
0005433985177	25683	Economy	7200.00
0005433985204	25683	Economy	7200.00
0005433985270	25683	Economy	7200.00
0005433985129	25683	Economy	7200.00
0005433985247	25683	Economy	7200.00
0005433985175	25683	Economy	7200.00
0005433985224	25683	Economy	7200.00
0005433985174	25683	Economy	7200.00
0005433985230	25683	Economy	7200.00
0005433985287	25683	Economy	7200.00
0005433985229	25683	Economy	7200.00
0005435720805	21289	Economy	10400.00
0005435720806	21289	Economy	9400.00
0005434509075	1615	Economy	15500.00
0005434509079	1615	Economy	15500.00
0005433168310	1615	Economy	15500.00
0005434509080	1615	Economy	15500.00
0005434509074	1615	Economy	15500.00
0005434509077	1615	Economy	15500.00
0005434509081	1615	Economy	15500.00
0005434509078	1615	Economy	15500.00
0005434509082	1615	Economy	15500.00
0005434509083	1615	Economy	15500.00
0005434509070	1615	Economy	15500.00
0005434509076	1615	Economy	15500.00
0005434509071	1615	Economy	15500.00
0005434509084	1615	Economy	15500.00
0005434509069	1615	Economy	15500.00
0005434509073	1615	Economy	15500.00
0005434509072	1615	Economy	15500.00
0005433168299	1615	Economy	15500.00
0005432869467	17825	Business	18000.00
0005432655337	17825	Economy	6000.00
0005432665238	17825	Economy	6000.00
0005432655336	17825	Economy	6600.00
0005434151679	17825	Economy	6000.00
0005432869472	17825	Economy	6000.00
0005432869468	17825	Economy	6000.00
0005434151678	17825	Economy	6000.00
0005432666354	17825	Economy	6000.00
0005432659674	17825	Economy	6000.00
0005432869469	17825	Economy	6000.00
0005432657398	17825	Economy	6000.00
0005432869466	17825	Economy	6000.00
0005432869471	17825	Economy	6000.00
0005432869465	17825	Economy	6000.00
0005432657399	17825	Economy	6000.00
0005434151680	17825	Economy	6000.00
0005432869470	17825	Economy	6000.00
0005432655335	17825	Economy	6000.00
0005432666358	17825	Economy	6000.00
0005432655400	26336	Business	18000.00
0005432666366	26336	Business	18000.00
0005432657415	26336	Business	18000.00
0005432665252	26336	Business	18000.00
0005432660795	26336	Business	18000.00
0005432655404	26336	Economy	6000.00
0005432655407	26336	Economy	6000.00
0005432658570	26336	Economy	6000.00
0005434151657	26336	Economy	6600.00
0005432655403	26336	Economy	6000.00
0005432655405	26336	Economy	6000.00
0005432660796	26336	Economy	6000.00
0005432655408	26336	Economy	6000.00
0005432655406	26336	Economy	6000.00
0005432667433	26336	Economy	6000.00
0005432869431	26336	Economy	6000.00
0005432655401	26336	Economy	6000.00
0005432666368	26336	Economy	6000.00
0005432655402	26336	Economy	6000.00
0005432659685	26336	Economy	6000.00
0005434151654	26336	Economy	6000.00
0005432658571	26336	Economy	6000.00
0005432869416	26336	Economy	6000.00
0005432666367	26336	Economy	6000.00
0005432658568	26336	Economy	6000.00
0005432666369	26336	Economy	6000.00
0005432657416	26336	Economy	6000.00
0005432655410	26336	Economy	6000.00
0005432655409	26336	Economy	6000.00
0005432659684	26336	Economy	6000.00
0005432657417	26336	Economy	6000.00
0005432658569	26336	Economy	6000.00
0005432869415	26336	Economy	6000.00
0005432665253	26336	Economy	6000.00
0005432667432	26336	Economy	6000.00
0005432865955	25068	Business	87300.00
0005432865949	25068	Business	87300.00
0005432638935	25068	Business	87300.00
0005432638916	25068	Business	87300.00
0005432865950	25068	Economy	29100.00
0005432638934	25068	Economy	29100.00
0005432638936	25068	Economy	32000.00
0005432865948	25068	Economy	32000.00
0005432638938	25068	Economy	29100.00
0005432865956	25068	Economy	29100.00
0005432638918	25068	Economy	29100.00
0005432638949	25068	Economy	29100.00
0005432638942	25068	Economy	29100.00
0005432865954	25068	Economy	29100.00
0005432638941	25068	Economy	29100.00
0005432638917	25068	Economy	29100.00
0005432865953	25068	Economy	29100.00
0005432865945	25068	Economy	29100.00
0005432865946	25068	Economy	29100.00
0005432865957	25068	Economy	29100.00
0005432865944	25068	Economy	29100.00
0005432865951	25068	Economy	29100.00
0005432865952	25068	Economy	29100.00
0005432865947	25068	Economy	29100.00
0005433438819	3088	Business	16100.00
0005432905021	3088	Business	16100.00
0005432328284	3088	Business	16100.00
0005432328291	3088	Business	16100.00
0005432328281	3088	Business	16100.00
0005432328310	3088	Business	16100.00
0005432328271	3088	Business	16100.00
0005432328298	3088	Economy	5400.00
0005433438815	3088	Economy	5400.00
0005432287142	3088	Economy	5400.00
0005432328302	3088	Economy	5400.00
0005432328282	3088	Economy	5400.00
0005433438817	3088	Economy	5400.00
0005432328283	3088	Economy	5900.00
0005432328308	3088	Economy	5400.00
0005432328276	3088	Economy	5400.00
0005432328269	3088	Economy	5400.00
0005432328273	3088	Economy	5400.00
0005432328267	3088	Economy	5400.00
0005432328274	3088	Economy	5400.00
0005432328286	3088	Economy	5400.00
0005432328297	3088	Economy	5400.00
0005433438814	3088	Economy	5400.00
0005432328293	3088	Economy	5400.00
0005432328279	3088	Economy	5400.00
0005432328290	3088	Economy	5400.00
0005432287144	3088	Economy	5400.00
0005432328305	3088	Economy	5400.00
0005432328268	3088	Economy	5400.00
0005432328280	3088	Economy	5400.00
0005433438820	3088	Economy	5400.00
0005432328292	3088	Economy	5400.00
0005432328301	3088	Economy	5400.00
0005432287141	3088	Economy	5400.00
0005433438821	3088	Economy	5400.00
0005432328307	3088	Economy	5400.00
0005432328296	3088	Economy	5400.00
0005432905022	3088	Economy	5400.00
0005432328270	3088	Economy	5400.00
0005432905036	3088	Economy	5400.00
0005433438822	3088	Economy	5400.00
0005432328294	3088	Economy	5400.00
0005432328309	3088	Economy	5400.00
0005432328299	3088	Economy	5400.00
0005432287143	3088	Economy	5400.00
0005432328277	3088	Economy	5400.00
0005432328303	3088	Economy	5400.00
0005432328285	3088	Economy	5400.00
0005432328278	3088	Economy	5400.00
0005432328287	3088	Economy	5400.00
0005432328272	3088	Economy	5400.00
0005432328312	3088	Economy	5400.00
0005432328311	3088	Economy	5400.00
0005433438818	3088	Economy	5400.00
0005432328300	3088	Economy	5400.00
0005433438816	3088	Economy	5400.00
0005432328275	3088	Economy	5400.00
0005432328306	3088	Economy	5400.00
0005432328288	3088	Economy	5400.00
0005432328295	3088	Economy	5400.00
0005432328289	3088	Economy	5400.00
0005432328266	3088	Economy	5400.00
0005432287145	3088	Economy	5400.00
0005432328304	3088	Economy	5400.00
0005433438766	31136	Business	16100.00
0005432327938	31136	Business	16100.00
0005433438765	31136	Business	16100.00
0005432905073	31136	Economy	5400.00
0005432054278	31136	Economy	5400.00
0005433438783	31136	Economy	5400.00
0005432327983	31136	Economy	5900.00
0005432327984	31136	Economy	5900.00
0005432327897	31136	Economy	5400.00
0005433438780	31136	Economy	5400.00
0005433438767	31136	Economy	5400.00
0005433438782	31136	Economy	5400.00
0005432327928	31136	Economy	5400.00
0005433438771	31136	Economy	5400.00
0005432327937	31136	Economy	5400.00
0005432327936	31136	Economy	5400.00
0005433438784	31136	Economy	5400.00
0005432054277	31136	Economy	5400.00
0005432905070	31136	Economy	5400.00
0005432905075	31136	Economy	5400.00
0005432327929	31136	Economy	5400.00
0005432905074	31136	Economy	5400.00
0005432327895	31136	Economy	5400.00
0005432905072	31136	Economy	5400.00
0005433438781	31136	Economy	5400.00
0005432905071	31136	Economy	5400.00
0005432054276	31136	Economy	5400.00
0005432327948	31136	Economy	5400.00
0005434309614	6200	Business	124600.00
0005434309623	6200	Business	124600.00
0005434309625	6200	Business	124600.00
0005435999098	6200	Business	124600.00
0005434309616	6200	Business	124600.00
0005435999102	6200	Economy	41500.00
0005435999104	6200	Economy	41500.00
0005435999108	6200	Economy	41500.00
0005435999100	6200	Economy	41500.00
0005434309624	6200	Economy	41500.00
0005434309612	6200	Economy	41500.00
0005435999105	6200	Economy	41500.00
0005435999099	6200	Economy	41500.00
0005435999106	6200	Economy	41500.00
0005435487477	6200	Economy	41500.00
0005435999110	6200	Economy	41500.00
0005432146180	6200	Economy	41500.00
0005435487512	6200	Economy	41500.00
0005434309618	6200	Economy	41500.00
0005435999103	6200	Economy	41500.00
0005435487513	6200	Economy	45700.00
0005435999111	6200	Economy	45700.00
0005434309615	6200	Economy	41500.00
0005434309621	6200	Economy	41500.00
0005434309622	6200	Economy	41500.00
0005434309617	6200	Economy	41500.00
0005434309620	6200	Economy	41500.00
0005435487478	6200	Economy	41500.00
0005434309619	6200	Economy	41500.00
0005435999101	6200	Economy	41500.00
0005435999096	6200	Economy	41500.00
0005435487514	6200	Economy	41500.00
0005434309626	6200	Economy	41500.00
0005435487496	6200	Economy	41500.00
0005435999094	6200	Economy	41500.00
0005435487497	6200	Economy	41500.00
0005435999097	6200	Economy	41500.00
0005435999095	6200	Economy	41500.00
0005435999109	6200	Economy	41500.00
0005435487472	6200	Economy	41500.00
0005434309613	6200	Economy	41500.00
0005432146181	6200	Economy	41500.00
0005435999107	6200	Economy	41500.00
0005435296999	19563	Business	124600.00
0005435487623	19563	Business	124600.00
0005434309538	19563	Business	124600.00
0005434309520	19563	Business	124600.00
0005435296996	19563	Business	124600.00
0005435487617	19563	Economy	41500.00
0005435487613	19563	Economy	41500.00
0005435487610	19563	Economy	41500.00
0005434309528	19563	Economy	41500.00
0005434309522	19563	Economy	41500.00
0005434309526	19563	Economy	41500.00
0005435487628	19563	Economy	41500.00
0005435487620	19563	Economy	41500.00
0005435487624	19563	Economy	45700.00
0005434309527	19563	Economy	45700.00
0005435487609	19563	Economy	45700.00
0005435296995	19563	Economy	41500.00
0005434309529	19563	Economy	41500.00
0005435487626	19563	Economy	41500.00
0005435487627	19563	Economy	41500.00
0005435296993	19563	Economy	41500.00
0005435487616	19563	Economy	41500.00
0005435296998	19563	Economy	41500.00
0005435296994	19563	Economy	41500.00
0005435487621	19563	Economy	41500.00
0005435487622	19563	Economy	41500.00
0005435487618	19563	Economy	41500.00
0005435487629	19563	Economy	41500.00
0005435487614	19563	Economy	41500.00
0005435487630	19563	Economy	41500.00
0005435487611	19563	Economy	41500.00
0005435487615	19563	Economy	41500.00
0005435487612	19563	Economy	41500.00
0005434309563	19563	Economy	41500.00
0005435487625	19563	Economy	41500.00
0005435296997	19563	Economy	41500.00
0005435487619	19563	Economy	41500.00
0005435517758	1554	Business	86000.00
0005435502117	1554	Business	86000.00
0005435502123	1554	Business	86000.00
0005434565789	1554	Business	86000.00
0005435508265	1554	Business	86000.00
0005433185970	1554	Business	86000.00
0005433186003	1554	Business	86000.00
0005435502125	1554	Business	86000.00
0005435502120	1554	Business	86000.00
0005435508258	1554	Business	86000.00
0005435517762	1554	Economy	28700.00
0005435517755	1554	Economy	28700.00
0005435502116	1554	Economy	28700.00
0005434565795	1554	Economy	28700.00
0005435508257	1554	Economy	28700.00
0005435502114	1554	Economy	28700.00
0005435517749	1554	Economy	28700.00
0005435517753	1554	Economy	28700.00
0005434565790	1554	Economy	28700.00
0005435508264	1554	Economy	31500.00
0005435502110	1554	Economy	31500.00
0005435502119	1554	Economy	31500.00
0005433186002	1554	Economy	31500.00
0005435517752	1554	Economy	28700.00
0005435517754	1554	Economy	28700.00
0005435517759	1554	Economy	28700.00
0005433186001	1554	Economy	28700.00
0005435508259	1554	Economy	28700.00
0005435517764	1554	Economy	28700.00
0005435502108	1554	Economy	28700.00
0005435508250	1554	Economy	28700.00
0005435502109	1554	Economy	28700.00
0005435502131	1554	Economy	28700.00
0005434565798	1554	Economy	28700.00
0005435502111	1554	Economy	28700.00
0005435502112	1554	Economy	28700.00
0005435508253	1554	Economy	28700.00
0005435508252	1554	Economy	28700.00
0005435502115	1554	Economy	28700.00
0005434565797	1554	Economy	28700.00
0005435517763	1554	Economy	28700.00
0005435502122	1554	Economy	28700.00
0005434565794	1554	Economy	28700.00
0005435508262	1554	Economy	28700.00
0005435502124	1554	Economy	28700.00
0005434565791	1554	Economy	28700.00
0005435502127	1554	Economy	28700.00
0005434565788	1554	Economy	28700.00
0005434565800	1554	Economy	28700.00
0005433185991	1554	Economy	28700.00
0005435517756	1554	Economy	28700.00
0005435502130	1554	Economy	28700.00
0005435517761	1554	Economy	28700.00
0005434565793	1554	Economy	28700.00
0005434565799	1554	Economy	28700.00
0005435502128	1554	Economy	28700.00
0005434565796	1554	Economy	28700.00
0005435508251	1554	Economy	28700.00
0005435508255	1554	Economy	28700.00
0005435502129	1554	Economy	28700.00
0005432291908	1554	Economy	28700.00
0005435517760	1554	Economy	28700.00
0005435508263	1554	Economy	28700.00
0005435517757	1554	Economy	28700.00
0005435508260	1554	Economy	28700.00
0005434565792	1554	Economy	28700.00
0005433185976	1554	Economy	28700.00
0005435502118	1554	Economy	28700.00
0005435517750	1554	Economy	28700.00
0005435517751	1554	Economy	28700.00
0005435502126	1554	Economy	28700.00
0005435508261	1554	Economy	28700.00
0005432291909	1554	Economy	28700.00
0005435502121	1554	Economy	28700.00
0005435502113	1554	Economy	28700.00
0005435508256	1554	Economy	28700.00
0005435517765	1554	Economy	28700.00
0005435508254	1554	Economy	28700.00
0005435528900	20893	Business	86000.00
0005435501970	20893	Economy	28700.00
0005433186042	20893	Economy	31500.00
0005435501985	20893	Economy	28700.00
0005435501971	20893	Economy	28700.00
0005433186041	20893	Economy	28700.00
0005435528893	20893	Economy	28700.00
0005434565741	20893	Economy	28700.00
0005435501991	20893	Economy	28700.00
0005435528882	20893	Economy	28700.00
0005433186045	20893	Economy	28700.00
0005435501951	20893	Economy	28700.00
0005433186043	20893	Economy	28700.00
0005435501945	20893	Economy	28700.00
0005433186040	20893	Economy	28700.00
0005435528908	20893	Economy	28700.00
0005433186039	20893	Economy	28700.00
0005435528899	20893	Economy	28700.00
0005434565696	20893	Economy	28700.00
0005433186046	20893	Economy	28700.00
0005434565740	20893	Economy	28700.00
0005433186044	20893	Economy	28700.00
0005435153682	3931	Economy	19700.00
0005435153681	3931	Economy	19700.00
0005435153680	3931	Economy	19700.00
0005435931549	3931	Economy	19700.00
0005435153684	3931	Economy	19700.00
0005435931550	3931	Economy	19700.00
0005435931548	3931	Economy	19700.00
0005435931536	3931	Economy	19700.00
0005435153685	3931	Economy	19700.00
0005435153683	3931	Economy	19700.00
0005435931551	3931	Economy	19700.00
0005435931569	21856	Economy	21600.00
0005435153652	21856	Economy	19700.00
0005435931568	21856	Economy	19700.00
0005435931571	21856	Economy	19700.00
0005435153628	21856	Economy	19700.00
0005435153627	21856	Economy	19700.00
0005435153626	21856	Economy	19700.00
0005435931570	21856	Economy	19700.00
0005435153635	21856	Economy	19700.00
0005435931567	21856	Economy	19700.00
0005435153651	21856	Economy	19700.00
0005435153650	21856	Economy	19700.00
0005435931566	21856	Economy	19700.00
0005435153636	21856	Economy	19700.00
0005435153637	21856	Economy	19700.00
0005432628714	7214	Economy	13000.00
0005432628715	7214	Economy	13000.00
0005435225445	7214	Economy	13000.00
0005435225466	7214	Economy	13000.00
0005432628711	7214	Economy	13000.00
0005435225450	7214	Economy	13000.00
0005432628707	7214	Economy	13000.00
0005432628713	7214	Economy	13000.00
0005432628717	7214	Economy	13000.00
0005435225457	7214	Economy	13000.00
0005435225464	7214	Economy	13000.00
0005435225459	7214	Economy	13000.00
0005435225451	7214	Economy	13000.00
0005432628712	7214	Economy	13000.00
0005432628710	7214	Economy	13000.00
0005432628706	7214	Economy	13000.00
0005432628716	7214	Economy	13000.00
0005432628721	7214	Economy	13000.00
0005432628720	7214	Economy	13000.00
0005432628708	7214	Economy	13000.00
0005432628709	7214	Economy	13000.00
0005432628719	7214	Economy	13000.00
0005432628718	7214	Economy	13000.00
0005435225512	28117	Economy	13000.00
0005432628598	28117	Economy	13000.00
0005432628634	28117	Economy	13000.00
0005435225514	28117	Economy	13000.00
0005432628625	28117	Economy	13000.00
0005432628626	28117	Economy	13000.00
0005432628633	28117	Economy	13000.00
0005432628597	28117	Economy	13000.00
0005435225515	28117	Economy	13000.00
0005435225513	28117	Economy	13000.00
0005432628636	28117	Economy	13000.00
0005432628599	28117	Economy	13000.00
0005432628635	28117	Economy	13000.00
0005435225511	28117	Economy	13000.00
0005432628621	28117	Economy	13000.00
0005434267888	8745	Economy	10500.00
0005435960016	8745	Economy	10500.00
0005435960017	8745	Economy	10500.00
0005434267914	15268	Economy	10500.00
0005434267916	15268	Economy	10500.00
0005435959987	15268	Economy	10500.00
0005434267915	15268	Economy	10500.00
0005435959989	15268	Economy	10500.00
0005435959988	15268	Economy	10500.00
0005434267917	15268	Economy	10500.00
0005432692754	1212	Business	115000.00
0005432674998	1212	Business	115000.00
0005432692756	1212	Business	115000.00
0005432675000	1212	Business	115000.00
0005432674995	1212	Business	115000.00
0005432692777	1212	Business	115000.00
0005432692769	1212	Business	115000.00
0005432674989	1212	Business	115000.00
0005432692759	1212	Economy	38300.00
0005432692751	1212	Economy	38300.00
0005432674991	1212	Economy	38300.00
0005432674997	1212	Economy	38300.00
0005432677534	1212	Economy	38300.00
0005432692775	1212	Economy	38300.00
0005432692772	1212	Economy	38300.00
0005432692749	1212	Economy	38300.00
0005432692768	1212	Economy	38300.00
0005432692771	1212	Economy	38300.00
0005432692758	1212	Economy	38300.00
0005432692763	1212	Economy	38300.00
0005432692762	1212	Economy	38300.00
0005432674987	1212	Economy	38300.00
0005432692757	1212	Economy	38300.00
0005432674999	1212	Economy	38300.00
0005432677536	1212	Economy	38300.00
0005432692779	1212	Economy	38300.00
0005432873174	1212	Economy	38300.00
0005432692764	1212	Economy	38300.00
0005432692770	1212	Economy	38300.00
0005432675001	1212	Economy	38300.00
0005432674996	1212	Economy	38300.00
0005432674990	1212	Economy	38300.00
0005432692761	1212	Economy	38300.00
0005432692765	1212	Economy	38300.00
0005432677533	1212	Economy	38300.00
0005432692778	1212	Economy	38300.00
0005432692774	1212	Economy	38300.00
0005432674988	1212	Economy	38300.00
0005432692750	1212	Economy	38300.00
0005432692767	1212	Economy	38300.00
0005432677535	1212	Economy	38300.00
0005432692755	1212	Economy	38300.00
0005432692752	1212	Economy	38300.00
0005432692748	1212	Economy	38300.00
0005432692753	1212	Economy	38300.00
0005432692773	1212	Economy	38300.00
0005432692766	1212	Economy	38300.00
0005432674994	1212	Economy	38300.00
0005432674993	1212	Economy	38300.00
0005432674992	1212	Economy	38300.00
0005432692776	1212	Economy	38300.00
0005432692760	1212	Economy	38300.00
0005432677504	17496	Business	115000.00
0005432674917	17496	Business	115000.00
0005432692635	17496	Business	115000.00
0005432873224	17496	Business	115000.00
0005432674882	17496	Business	115000.00
0005432674895	17496	Business	115000.00
0005432692532	17496	Economy	38300.00
0005432674871	17496	Economy	38300.00
0005432692573	17496	Economy	38300.00
0005432674875	17496	Economy	42200.00
0005432692622	17496	Economy	38300.00
0005432873228	17496	Economy	38300.00
0005432873230	17496	Economy	38300.00
0005432873225	17496	Economy	38300.00
0005432674881	17496	Economy	38300.00
0005432873227	17496	Economy	38300.00
0005432873226	17496	Economy	38300.00
0005432677506	17496	Economy	38300.00
0005432677505	17496	Economy	38300.00
0005432692531	17496	Economy	38300.00
0005432677503	17496	Economy	38300.00
0005432674890	17496	Economy	38300.00
0005432873229	17496	Economy	38300.00
0005432674938	17496	Economy	38300.00
0005434435044	1106	Economy	15200.00
0005433156606	1106	Economy	15200.00
0005434435048	1106	Economy	13900.00
0005434435042	1106	Economy	13900.00
0005434435046	1106	Economy	13900.00
0005434435037	1106	Economy	13900.00
0005434435035	1106	Economy	13900.00
0005434435038	1106	Economy	13900.00
0005434435049	1106	Economy	13900.00
0005434435039	1106	Economy	13900.00
0005433156629	1106	Economy	13900.00
0005433156607	1106	Economy	13900.00
0005434435045	1106	Economy	13900.00
0005434435034	1106	Economy	13900.00
0005433156630	1106	Economy	13900.00
0005434435036	1106	Economy	13900.00
0005434435041	1106	Economy	13900.00
0005434435047	1106	Economy	13900.00
0005434435050	1106	Economy	13900.00
0005434435043	1106	Economy	13900.00
0005434435040	1106	Economy	13900.00
0005433156669	17285	Economy	15200.00
0005434434913	17285	Economy	13900.00
0005434434960	17285	Economy	13900.00
0005433156668	17285	Economy	13900.00
0005434434934	17285	Economy	13900.00
0005433156675	17285	Economy	13900.00
0005433156670	17285	Economy	13900.00
0005433156674	17285	Economy	13900.00
0005434434917	17285	Economy	13900.00
0005433156672	17285	Economy	13900.00
0005433156671	17285	Economy	13900.00
0005434434983	17285	Economy	13900.00
0005434434984	17285	Economy	13900.00
0005433156673	17285	Economy	13900.00
0005434434935	17285	Economy	13900.00
0005433156667	17285	Economy	13900.00
0005434434920	17285	Economy	13900.00
0005435928060	4072	Economy	8200.00
0005435086766	4072	Economy	7500.00
0005435086763	4072	Economy	7500.00
0005435086765	4072	Economy	7500.00
0005435086762	4072	Economy	7500.00
0005435086768	4072	Economy	7500.00
0005435086769	4072	Economy	7500.00
0005435086764	4072	Economy	7500.00
0005435086767	4072	Economy	7500.00
0005435086721	24389	Economy	7500.00
0005435086705	24389	Economy	7500.00
0005435928099	24389	Economy	7500.00
0005435928101	24389	Economy	7500.00
0005435086704	24389	Economy	7500.00
0005435928100	24389	Economy	7500.00
0005435086720	24389	Economy	7500.00
0005435928098	24389	Economy	7500.00
0005434964067	1332	Business	203300.00
0005434964056	1332	Business	203300.00
0005433261390	1332	Business	203300.00
0005434964057	1332	Business	203300.00
0005434964066	1332	Business	203300.00
0005434964046	1332	Business	203300.00
0005434964033	1332	Business	203300.00
0005434964069	1332	Business	203300.00
0005434964035	1332	Business	203300.00
0005434964040	1332	Business	203300.00
0005434964032	1332	Economy	74500.00
0005434964039	1332	Economy	67800.00
0005434964063	1332	Economy	67800.00
0005433261399	1332	Economy	67800.00
0005433261391	1332	Economy	67800.00
0005433261406	1332	Economy	67800.00
0005432279252	1332	Economy	67800.00
0005434964044	1332	Economy	67800.00
0005434964038	1332	Economy	67800.00
0005434964041	1332	Economy	67800.00
0005434964061	1332	Economy	67800.00
0005434964055	1332	Economy	67800.00
0005434964037	1332	Economy	67800.00
0005434964036	1332	Economy	67800.00
0005434964045	1332	Economy	67800.00
0005434964047	1332	Economy	67800.00
0005433261405	1332	Economy	67800.00
0005434964070	1332	Economy	67800.00
0005434964058	1332	Economy	67800.00
0005434964043	1332	Economy	67800.00
0005434964048	1332	Economy	67800.00
0005434964049	1332	Economy	67800.00
0005434964064	1332	Economy	67800.00
0005434964051	1332	Economy	67800.00
0005434964052	1332	Economy	67800.00
0005434964053	1332	Economy	67800.00
0005432279251	1332	Economy	67800.00
0005434964054	1332	Economy	67800.00
0005434964059	1332	Economy	67800.00
0005434964068	1332	Economy	67800.00
0005434964034	1332	Economy	67800.00
0005434964050	1332	Economy	67800.00
0005433261394	1332	Economy	67800.00
0005434964031	1332	Economy	67800.00
0005434964042	1332	Economy	67800.00
0005433261407	1332	Economy	67800.00
0005434964060	1332	Economy	67800.00
0005432279253	1332	Economy	67800.00
0005434964062	1332	Economy	67800.00
0005433261398	1332	Economy	67800.00
0005434964065	1332	Economy	67800.00
0005432279250	1332	Economy	67800.00
0005434963923	18235	Business	203300.00
0005433261470	18235	Business	203300.00
0005433261471	18235	Business	203300.00
0005434963968	18235	Economy	74500.00
0005434963912	18235	Economy	67800.00
0005434963911	18235	Economy	67800.00
0005433261478	18235	Economy	67800.00
0005433261474	18235	Economy	67800.00
0005433261467	18235	Economy	67800.00
0005433261473	18235	Economy	67800.00
0005433261465	18235	Economy	67800.00
0005434963966	18235	Economy	67800.00
0005433261463	18235	Economy	67800.00
0005433261469	18235	Economy	67800.00
0005433261466	18235	Economy	67800.00
0005434963913	18235	Economy	67800.00
0005433261468	18235	Economy	67800.00
0005434963967	18235	Economy	67800.00
0005434963900	18235	Economy	67800.00
0005433261464	18235	Economy	67800.00
0005434963919	18235	Economy	67800.00
0005433261475	18235	Economy	67800.00
0005433261477	18235	Economy	67800.00
0005434963921	18235	Economy	67800.00
0005433261476	18235	Economy	67800.00
0005433261462	18235	Economy	67800.00
0005434963920	18235	Economy	67800.00
0005434963901	18235	Economy	67800.00
0005434963914	18235	Economy	67800.00
0005433261472	18235	Economy	67800.00
0005433261479	18235	Economy	67800.00
0005433261481	18235	Economy	67800.00
0005434963984	18235	Economy	67800.00
0005433261480	18235	Economy	67800.00
0005434625879	4817	Business	44200.00
0005435907422	4817	Economy	14700.00
0005435907449	4817	Economy	14700.00
0005434625872	4817	Economy	14700.00
0005434625876	4817	Economy	14700.00
0005434625877	4817	Economy	14700.00
0005434625874	4817	Economy	14700.00
0005435907448	4817	Economy	14700.00
0005434625871	4817	Economy	14700.00
0005433194817	4817	Economy	14700.00
0005435907421	4817	Economy	14700.00
0005434625878	4817	Economy	14700.00
0005435907444	4817	Economy	14700.00
0005434625880	4817	Economy	14700.00
0005434625875	4817	Economy	14700.00
0005434625873	4817	Economy	14700.00
0005435907436	4817	Economy	14700.00
0005435907437	4817	Economy	14700.00
0005434625815	32879	Business	44200.00
0005434625808	32879	Business	44200.00
0005434625800	32879	Economy	14700.00
0005435907461	32879	Economy	14700.00
0005435907464	32879	Economy	16200.00
0005435907462	32879	Economy	14700.00
0005435907460	32879	Economy	14700.00
0005434625814	32879	Economy	14700.00
0005434625844	32879	Economy	14700.00
0005435907463	32879	Economy	14700.00
0005434625807	32879	Economy	14700.00
0005435907459	32879	Economy	14700.00
0005435907458	32879	Economy	14700.00
0005434625796	32879	Economy	14700.00
0005434625799	32879	Economy	14700.00
0005434625805	32879	Economy	14700.00
0005434625813	32879	Economy	14700.00
0005435937337	13796	Economy	3100.00
0005435784750	13796	Economy	3100.00
0005432195675	13796	Economy	3100.00
0005435937336	13796	Economy	3100.00
0005435937341	13796	Economy	3100.00
0005432195674	13796	Economy	3100.00
0005435937342	13796	Economy	3100.00
0005435937343	13796	Economy	3100.00
0005435784810	13796	Economy	3100.00
0005435784748	13796	Economy	3100.00
0005435937339	13796	Economy	3100.00
0005435784749	13796	Economy	3100.00
0005435937335	13796	Economy	3100.00
0005435937334	13796	Economy	3100.00
0005435787320	13796	Economy	3100.00
0005432195673	13796	Economy	3100.00
0005435937338	13796	Economy	3100.00
0005435784747	13796	Economy	3100.00
0005435937340	13796	Economy	3100.00
0005435784991	27446	Economy	3400.00
0005435784981	27446	Economy	3400.00
0005435784985	27446	Economy	3400.00
0005435785005	27446	Economy	3400.00
0005435784977	27446	Economy	3100.00
0005435784984	27446	Economy	3100.00
0005435785007	27446	Economy	3100.00
0005435784978	27446	Economy	3100.00
0005435785008	27446	Economy	3100.00
0005435785003	27446	Economy	3100.00
0005435785001	27446	Economy	3100.00
0005435784998	27446	Economy	3100.00
0005435787331	27446	Economy	3100.00
0005435785002	27446	Economy	3100.00
0005435784979	27446	Economy	3100.00
0005435784982	27446	Economy	3100.00
0005435785009	27446	Economy	3100.00
0005435784989	27446	Economy	3100.00
0005435784993	27446	Economy	3100.00
0005432190588	27446	Economy	3100.00
0005435784996	27446	Economy	3100.00
0005435784997	27446	Economy	3100.00
0005435784983	27446	Economy	3100.00
0005435784995	27446	Economy	3100.00
0005435784986	27446	Economy	3100.00
0005435784992	27446	Economy	3100.00
0005435784987	27446	Economy	3100.00
0005435784988	27446	Economy	3100.00
0005435785000	27446	Economy	3100.00
0005435787330	27446	Economy	3100.00
0005432190590	27446	Economy	3100.00
0005435784994	27446	Economy	3100.00
0005435784999	27446	Economy	3100.00
0005435785004	27446	Economy	3100.00
0005435784980	27446	Economy	3100.00
0005435784990	27446	Economy	3100.00
0005432190587	27446	Economy	3100.00
0005432190589	27446	Economy	3100.00
0005435785010	27446	Economy	3100.00
0005435785006	27446	Economy	3100.00
0005434406892	20282	Business	12000.00
0005434406680	20282	Business	12000.00
0005434406822	20282	Business	12000.00
0005434406723	20282	Business	12000.00
0005434406724	20282	Business	12000.00
0005434406701	20282	Business	12000.00
0005434406809	20282	Business	12000.00
0005435310965	20282	Business	12000.00
0005434406664	20282	Business	12000.00
0005435310968	20282	Economy	4000.00
0005434406748	20282	Economy	4000.00
0005434406704	20282	Economy	4000.00
0005434406686	20282	Economy	4000.00
0005434406989	20282	Economy	4000.00
0005434406669	20282	Economy	4000.00
0005435310967	20282	Economy	4400.00
0005434406687	20282	Economy	4400.00
0005434406681	20282	Economy	4000.00
0005435310957	20282	Economy	4000.00
0005435310966	20282	Economy	4000.00
0005435310958	20282	Economy	4000.00
0005435310951	20282	Economy	4000.00
0005434406823	20282	Economy	4000.00
0005435310960	20282	Economy	4000.00
0005434406668	20282	Economy	4000.00
0005434406647	20282	Economy	4000.00
0005434406646	20282	Economy	4000.00
0005434406824	20282	Economy	4000.00
0005435310955	20282	Economy	4000.00
0005435310964	20282	Economy	4000.00
0005434406639	20282	Economy	4000.00
0005435310954	20282	Economy	4000.00
0005434406665	20282	Economy	4000.00
0005435310950	20282	Economy	4000.00
0005435310952	20282	Economy	4000.00
0005435310962	20282	Economy	4000.00
0005435310949	20282	Economy	4000.00
0005432058346	20282	Economy	4000.00
0005434406667	20282	Economy	4000.00
0005435310961	20282	Economy	4000.00
0005432058344	20282	Economy	4000.00
0005435310963	20282	Economy	4000.00
0005432058347	20282	Economy	4000.00
0005435310953	20282	Economy	4000.00
0005434406825	20282	Economy	4000.00
0005434406776	20282	Economy	4000.00
0005435310956	20282	Economy	4000.00
0005434406777	20282	Economy	4000.00
0005435310959	20282	Economy	4000.00
0005434406727	20282	Economy	4000.00
0005434406728	20282	Economy	4000.00
0005434406778	20282	Economy	4000.00
0005434406682	20282	Economy	4000.00
0005434406670	20282	Economy	4000.00
0005434406645	20282	Economy	4000.00
0005434406717	20282	Economy	4000.00
0005434406694	20282	Economy	4000.00
0005434406855	20282	Economy	4000.00
0005432058345	20282	Economy	4000.00
0005434406683	20282	Economy	4000.00
0005432153874	26987	Business	12000.00
0005434407173	26987	Business	12000.00
0005434407194	26987	Business	12000.00
0005434407169	26987	Business	12000.00
0005432153873	26987	Business	12000.00
0005434407162	26987	Business	12000.00
0005435310838	26987	Business	12000.00
0005434407181	26987	Business	12000.00
0005434407156	26987	Economy	4000.00
0005434407178	26987	Economy	4000.00
0005434407190	26987	Economy	4000.00
0005434407205	26987	Economy	4000.00
0005435310850	26987	Economy	4000.00
0005434407188	26987	Economy	4000.00
0005434407203	26987	Economy	4000.00
0005434407172	26987	Economy	4000.00
0005434407155	26987	Economy	4400.00
0005434407187	26987	Economy	4400.00
0005434407167	26987	Economy	4400.00
0005432153875	26987	Economy	4400.00
0005434407170	26987	Economy	4400.00
0005434407177	26987	Economy	4000.00
0005434407207	26987	Economy	4000.00
0005434407198	26987	Economy	4000.00
0005432153877	26987	Economy	4000.00
0005434407201	26987	Economy	4000.00
0005434407206	26987	Economy	4000.00
0005434407174	26987	Economy	4000.00
0005434407158	26987	Economy	4000.00
0005434407176	26987	Economy	4000.00
0005434407171	26987	Economy	4000.00
0005435310852	26987	Economy	4000.00
0005434407217	26987	Economy	4000.00
0005432153872	26987	Economy	4000.00
0005432153870	26987	Economy	4000.00
0005434407214	26987	Economy	4000.00
0005434407184	26987	Economy	4000.00
0005434407164	26987	Economy	4000.00
0005434407196	26987	Economy	4000.00
0005434407211	26987	Economy	4000.00
0005434407163	26987	Economy	4000.00
0005434407192	26987	Economy	4000.00
0005434407166	26987	Economy	4000.00
0005434407185	26987	Economy	4000.00
0005434407159	26987	Economy	4000.00
0005434407175	26987	Economy	4000.00
0005434407189	26987	Economy	4000.00
0005435310841	26987	Economy	4000.00
0005434407197	26987	Economy	4000.00
0005434407186	26987	Economy	4000.00
0005434407161	26987	Economy	4000.00
0005434407199	26987	Economy	4000.00
0005434407179	26987	Economy	4000.00
0005434407216	26987	Economy	4000.00
0005434407210	26987	Economy	4000.00
0005435310846	26987	Economy	4000.00
0005434407193	26987	Economy	4000.00
0005434407183	26987	Economy	4000.00
0005434407204	26987	Economy	4000.00
0005434407213	26987	Economy	4000.00
0005434407168	26987	Economy	4000.00
0005434407195	26987	Economy	4000.00
0005435310851	26987	Economy	4000.00
0005434407202	26987	Economy	4000.00
0005432153871	26987	Economy	4000.00
0005435310845	26987	Economy	4000.00
0005434407208	26987	Economy	4000.00
0005434407157	26987	Economy	4000.00
0005434407200	26987	Economy	4000.00
0005434407180	26987	Economy	4000.00
0005434407160	26987	Economy	4000.00
0005434407212	26987	Economy	4000.00
0005434407209	26987	Economy	4000.00
0005435310842	26987	Economy	4000.00
0005434407165	26987	Economy	4000.00
0005432153876	26987	Economy	4000.00
0005434407182	26987	Economy	4000.00
0005434407215	26987	Economy	4000.00
0005434407191	26987	Economy	4000.00
0005432109678	5688	Business	43300.00
0005434319250	5688	Business	43300.00
0005434319259	5688	Business	43300.00
0005434319263	5688	Business	43300.00
0005433123604	5688	Business	43300.00
0005433123640	5688	Business	43300.00
0005434319254	5688	Economy	14400.00
0005434319261	5688	Economy	14400.00
0005433123573	5688	Economy	14400.00
0005433123576	5688	Economy	15900.00
0005434319251	5688	Economy	14400.00
0005434319262	5688	Economy	14400.00
0005433123657	5688	Economy	14400.00
0005434319253	5688	Economy	14400.00
0005433123632	5688	Economy	14400.00
0005434319260	5688	Economy	14400.00
0005432109679	5688	Economy	14400.00
0005434319257	5688	Economy	14400.00
0005434319249	5688	Economy	14400.00
0005432109677	5688	Economy	14400.00
0005434319252	5688	Economy	14400.00
0005434319258	5688	Economy	14400.00
0005433123574	5688	Economy	14400.00
0005433123567	5688	Economy	14400.00
0005434319255	5688	Economy	14400.00
0005433123641	5688	Economy	14400.00
0005433123566	5688	Economy	14400.00
0005434319256	5688	Economy	14400.00
0005433123749	15689	Business	43300.00
0005433123744	15689	Economy	14400.00
0005433123757	15689	Economy	14400.00
0005433123738	15689	Economy	14400.00
0005433123741	15689	Economy	15900.00
0005433123740	15689	Economy	15900.00
0005433123739	15689	Economy	15900.00
0005433123743	15689	Economy	15900.00
0005434319154	15689	Economy	14400.00
0005433123755	15689	Economy	14400.00
0005433123751	15689	Economy	14400.00
0005433123746	15689	Economy	14400.00
0005433123748	15689	Economy	14400.00
0005433123745	15689	Economy	14400.00
0005434319149	15689	Economy	14400.00
0005434319148	15689	Economy	14400.00
0005433123758	15689	Economy	14400.00
0005433123754	15689	Economy	14400.00
0005433123737	15689	Economy	14400.00
0005433123742	15689	Economy	14400.00
0005433123747	15689	Economy	14400.00
0005433123759	15689	Economy	14400.00
0005433123753	15689	Economy	14400.00
0005433123752	15689	Economy	14400.00
0005433123750	15689	Economy	14400.00
0005433123756	15689	Economy	14400.00
0005435220283	24971	Economy	15500.00
0005434484286	8965	Economy	24900.00
0005434484285	8965	Economy	24900.00
0005434484288	8965	Economy	24900.00
0005434189085	8965	Economy	24900.00
0005434484291	8965	Economy	24900.00
0005434484290	8965	Economy	24900.00
0005434189084	8965	Economy	24900.00
0005434484287	8965	Economy	24900.00
0005434189079	8965	Economy	24900.00
0005434484289	8965	Economy	24900.00
0005434189078	8965	Economy	24900.00
0005434189128	16639	Economy	24900.00
0005434189127	16639	Economy	24900.00
0005434189123	16639	Economy	24900.00
0005434484238	16639	Economy	24900.00
0005434484237	16639	Economy	24900.00
0005434189124	16639	Economy	24900.00
0005434189125	16639	Economy	24900.00
0005434484239	16639	Economy	24900.00
0005434189126	16639	Economy	24900.00
0005433123739	7536	Business	11100.00
0005433123745	7536	Business	11100.00
0005433123740	7536	Business	11100.00
0005433123753	7536	Business	11100.00
0005433123743	7536	Business	11100.00
0005433123756	7536	Economy	3700.00
0005433123742	7536	Economy	4100.00
0005433123754	7536	Economy	3700.00
0005433123758	7536	Economy	3700.00
0005433123759	7536	Economy	3700.00
0005433123752	7536	Economy	3700.00
0005433123757	7536	Economy	3700.00
0005433123737	7536	Economy	3700.00
0005433123749	7536	Economy	3700.00
0005433123744	7536	Economy	3700.00
0005433123741	7536	Economy	3700.00
0005433123751	7536	Economy	3700.00
0005433123755	7536	Economy	3700.00
0005433123750	7536	Economy	3700.00
0005433123746	7536	Economy	3700.00
0005433123738	7536	Economy	3700.00
0005433123748	7536	Economy	3700.00
0005433123747	7536	Economy	3700.00
0005433449784	7534	Business	11100.00
0005433449763	7534	Business	11100.00
0005432692783	7534	Business	11100.00
0005432692799	7534	Business	11100.00
0005432692809	7534	Business	11100.00
0005432692781	7534	Business	11100.00
0005432692794	7534	Business	11100.00
0005432720656	7534	Business	11100.00
0005432692791	7534	Business	11100.00
0005433449779	7534	Business	11100.00
0005432720655	7534	Business	11100.00
0005433449765	7534	Economy	3700.00
0005433449772	7534	Economy	3700.00
0005433449764	7534	Economy	3700.00
0005432692795	7534	Economy	3700.00
0005432720662	7534	Economy	3700.00
0005432692796	7534	Economy	3700.00
0005433449766	7534	Economy	3700.00
0005432720670	7534	Economy	3700.00
0005432720672	7534	Economy	3700.00
0005433449768	7534	Economy	4100.00
0005432720660	7534	Economy	4100.00
0005432720668	7534	Economy	4100.00
0005433449780	7534	Economy	3700.00
0005432692803	7534	Economy	3700.00
0005432720650	7534	Economy	3700.00
0005432692802	7534	Economy	3700.00
0005432692798	7534	Economy	3700.00
0005432720661	7534	Economy	3700.00
0005432692785	7534	Economy	3700.00
0005432692787	7534	Economy	3700.00
0005432720671	7534	Economy	3700.00
0005432692784	7534	Economy	3700.00
0005432692792	7534	Economy	3700.00
0005433449773	7534	Economy	3700.00
0005432720667	7534	Economy	3700.00
0005432720649	7534	Economy	3700.00
0005432720664	7534	Economy	3700.00
0005433449777	7534	Economy	3700.00
0005432692806	7534	Economy	3700.00
0005433449762	7534	Economy	3700.00
0005432692786	7534	Economy	3700.00
0005432692780	7534	Economy	3700.00
0005432720653	7534	Economy	3700.00
0005433449782	7534	Economy	3700.00
0005432720652	7534	Economy	3700.00
0005432720665	7534	Economy	3700.00
0005432692800	7534	Economy	3700.00
0005432692790	7534	Economy	3700.00
0005432720675	7534	Economy	3700.00
0005432720666	7534	Economy	3700.00
0005433449771	7534	Economy	3700.00
0005432692808	7534	Economy	3700.00
0005432692797	7534	Economy	3700.00
0005433449783	7534	Economy	3700.00
0005432692805	7534	Economy	3700.00
0005432692782	7534	Economy	3700.00
0005433449778	7534	Economy	3700.00
0005432071546	7534	Economy	3700.00
0005432692810	7534	Economy	3700.00
0005432720669	7534	Economy	3700.00
0005432720651	7534	Economy	3700.00
0005433449770	7534	Economy	3700.00
0005433449776	7534	Economy	3700.00
0005433449774	7534	Economy	3700.00
0005432692807	7534	Economy	3700.00
0005432720673	7534	Economy	3700.00
0005433449781	7534	Economy	3700.00
0005433449769	7534	Economy	3700.00
0005432720657	7534	Economy	3700.00
0005432692789	7534	Economy	3700.00
0005432692793	7534	Economy	3700.00
0005432071547	7534	Economy	3700.00
0005433449775	7534	Economy	3700.00
0005432720658	7534	Economy	3700.00
0005432720654	7534	Economy	3700.00
0005432720659	7534	Economy	3700.00
0005432720663	7534	Economy	3700.00
0005432692788	7534	Economy	3700.00
0005432692801	7534	Economy	3700.00
0005432692804	7534	Economy	3700.00
0005432720674	7534	Economy	3700.00
0005433449767	7534	Economy	3700.00
0005433449632	30382	Business	11100.00
0005433449586	30382	Business	11100.00
0005433449594	30382	Economy	3700.00
0005432692531	30382	Economy	3700.00
0005432692532	30382	Economy	3700.00
0005433449596	30382	Economy	4100.00
0005433449597	30382	Economy	3700.00
0005432692573	30382	Economy	3700.00
0005433449642	30382	Economy	3700.00
0005433449606	30382	Economy	3700.00
0005432692622	30382	Economy	3700.00
0005433449585	30382	Economy	3700.00
0005433449693	30382	Economy	3700.00
0005432692635	30382	Economy	3700.00
0005433449633	30382	Economy	3700.00
0005433123566	30381	Business	11100.00
0005432720448	30381	Business	11100.00
0005433123573	30381	Business	11100.00
0005433123604	30381	Business	11100.00
0005432720531	30381	Business	11100.00
0005433123640	30381	Economy	3700.00
0005432720547	30381	Economy	3700.00
0005432720569	30381	Economy	3700.00
0005432720449	30381	Economy	4100.00
0005433722165	30381	Economy	4100.00
0005432720447	30381	Economy	3700.00
0005432720482	30381	Economy	3700.00
0005432720511	30381	Economy	3700.00
0005432720497	30381	Economy	3700.00
0005432720575	30381	Economy	3700.00
0005432720483	30381	Economy	3700.00
0005433722160	30381	Economy	3700.00
0005433722162	30381	Economy	3700.00
0005433722164	30381	Economy	3700.00
0005433722158	30381	Economy	3700.00
0005432720485	30381	Economy	3700.00
0005433722166	30381	Economy	3700.00
0005432720512	30381	Economy	3700.00
0005433123641	30381	Economy	3700.00
0005432720437	30381	Economy	3700.00
0005433722163	30381	Economy	3700.00
0005433123632	30381	Economy	3700.00
0005433123567	30381	Economy	3700.00
0005433123576	30381	Economy	3700.00
0005432720484	30381	Economy	3700.00
0005433722161	30381	Economy	3700.00
0005433722159	30381	Economy	3700.00
0005433123657	30381	Economy	3700.00
0005433123574	30381	Economy	3700.00
0005433192867	1384	Business	70400.00
0005433524945	1384	Business	70400.00
0005432270977	1384	Business	70400.00
0005434586368	1384	Business	70400.00
0005434513554	1384	Business	70400.00
0005433192811	1384	Economy	23500.00
0005434586369	1384	Economy	23500.00
0005433524943	1384	Economy	23500.00
0005434586388	1384	Economy	23500.00
0005432270978	1384	Economy	23500.00
0005433524942	1384	Economy	23500.00
0005434586381	1384	Economy	25800.00
0005434586376	1384	Economy	25800.00
0005434586392	1384	Economy	25800.00
0005434514944	1384	Economy	23500.00
0005432270979	1384	Economy	23500.00
0005434586390	1384	Economy	23500.00
0005434586373	1384	Economy	23500.00
0005433524941	1384	Economy	23500.00
0005434586383	1384	Economy	23500.00
0005434586384	1384	Economy	23500.00
0005434586371	1384	Economy	23500.00
0005434586389	1384	Economy	23500.00
0005433724765	1384	Economy	23500.00
0005433724763	1384	Economy	23500.00
0005433524939	1384	Economy	23500.00
0005434586375	1384	Economy	23500.00
0005434586391	1384	Economy	23500.00
0005433524940	1384	Economy	23500.00
0005434586386	1384	Economy	23500.00
0005434586372	1384	Economy	23500.00
0005434514942	1384	Economy	23500.00
0005432270980	1384	Economy	23500.00
0005434513556	1384	Economy	23500.00
0005433724764	1384	Economy	23500.00
0005434586387	1384	Economy	23500.00
0005433524944	1384	Economy	23500.00
0005433524938	1384	Economy	23500.00
0005434514943	1384	Economy	23500.00
0005434586377	1384	Economy	23500.00
0005433192868	1384	Economy	23500.00
0005433524936	1384	Economy	23500.00
0005434586382	1384	Economy	23500.00
0005434586385	1384	Economy	23500.00
0005434586393	1384	Economy	23500.00
0005434586374	1384	Economy	23500.00
0005434586379	1384	Economy	23500.00
0005434586370	1384	Economy	23500.00
0005434586380	1384	Economy	23500.00
0005434513555	1384	Economy	23500.00
0005433724766	1384	Economy	23500.00
0005434586378	1384	Economy	23500.00
0005433524937	1384	Economy	23500.00
0005433192928	18504	Business	70400.00
0005434586184	18504	Business	70400.00
0005434586261	18504	Business	70400.00
0005434514922	18504	Business	70400.00
0005434586166	18504	Business	70400.00
0005432927929	18504	Business	70400.00
0005434514927	18504	Economy	23500.00
0005433192927	18504	Economy	25800.00
0005434586185	18504	Economy	25800.00
0005434586167	18504	Economy	23500.00
0005433724725	18504	Economy	23500.00
0005432927926	18504	Economy	23500.00
0005434514928	18504	Economy	23500.00
0005432968818	18504	Economy	23500.00
0005432927930	18504	Economy	23500.00
0005434586171	18504	Economy	23500.00
0005434514923	18504	Economy	23500.00
0005433192920	18504	Economy	23500.00
0005432968819	18504	Economy	23500.00
0005433192929	18504	Economy	23500.00
0005432927928	18504	Economy	23500.00
0005432927927	18504	Economy	23500.00
0005433524846	18504	Economy	23500.00
0005434586172	18504	Economy	23500.00
0005433192923	18504	Economy	23500.00
0005433192925	18504	Economy	23500.00
0005434586183	18504	Economy	23500.00
0005434586173	18504	Economy	23500.00
0005434586186	18504	Economy	23500.00
0005432927925	18504	Economy	23500.00
0005433192931	18504	Economy	23500.00
0005434586163	18504	Economy	23500.00
0005433192924	18504	Economy	23500.00
0005433192926	18504	Economy	23500.00
0005433192922	18504	Economy	23500.00
0005433192921	18504	Economy	23500.00
0005433192930	18504	Economy	23500.00
0005434343865	11481	Economy	4300.00
0005434343867	11481	Economy	4300.00
0005434343871	11481	Economy	4300.00
0005434343852	11481	Economy	4300.00
0005434343854	11481	Economy	4000.00
0005434343872	11481	Economy	4000.00
0005434343857	11481	Economy	4000.00
0005434343862	11481	Economy	4000.00
0005434343843	11481	Economy	4000.00
0005434343861	11481	Economy	4000.00
0005435304993	11481	Economy	4000.00
0005434343849	11481	Economy	4000.00
0005434343873	11481	Economy	4000.00
0005434343868	11481	Economy	4000.00
0005434142574	11481	Economy	4000.00
0005434343860	11481	Economy	4000.00
0005434343869	11481	Economy	4000.00
0005434343870	11481	Economy	4000.00
0005434343863	11481	Economy	4000.00
0005434343842	11481	Economy	4000.00
0005434343858	11481	Economy	4000.00
0005434343850	11481	Economy	4000.00
0005434343838	11481	Economy	4000.00
0005434343859	11481	Economy	4000.00
0005434142576	11481	Economy	4000.00
0005434343853	11481	Economy	4000.00
0005434343845	11481	Economy	4000.00
0005434343840	11481	Economy	4000.00
0005434343846	11481	Economy	4000.00
0005434343847	11481	Economy	4000.00
0005434343839	11481	Economy	4000.00
0005434343844	11481	Economy	4000.00
0005434343864	11481	Economy	4000.00
0005434343866	11481	Economy	4000.00
0005434343851	11481	Economy	4000.00
0005435304994	11481	Economy	4000.00
0005434142575	11481	Economy	4000.00
0005434343841	11481	Economy	4000.00
0005434343856	11481	Economy	4000.00
0005434343848	11481	Economy	4000.00
0005434343855	11481	Economy	4000.00
0005435305000	29777	Economy	4300.00
0005434343619	29777	Economy	4000.00
0005435304119	29777	Economy	4000.00
0005434343657	29777	Economy	4000.00
0005434343658	29777	Economy	4000.00
0005434343591	29777	Economy	4000.00
0005434343592	29777	Economy	4000.00
0005434142550	29777	Economy	4000.00
0005434343642	29777	Economy	4000.00
0005435304120	29777	Economy	4000.00
0005434142543	29777	Economy	4000.00
0005434343600	29777	Economy	4000.00
0005434343607	29777	Economy	4000.00
0005435304118	29777	Economy	4000.00
0005435304121	29777	Economy	4000.00
0005435824375	1294	Business	199800.00
0005435824381	1294	Business	199800.00
0005435824395	1294	Business	199800.00
0005433415439	1294	Business	199800.00
0005435824387	1294	Business	199800.00
0005433415433	1294	Economy	66600.00
0005433415410	1294	Economy	66600.00
0005433415388	1294	Economy	73200.00
0005435824393	1294	Economy	66600.00
0005435824398	1294	Economy	66600.00
0005435824373	1294	Economy	66600.00
0005435824376	1294	Economy	66600.00
0005435824380	1294	Economy	66600.00
0005433415425	1294	Economy	66600.00
0005435824391	1294	Economy	66600.00
0005435824388	1294	Economy	66600.00
0005435824394	1294	Economy	66600.00
0005435824384	1294	Economy	66600.00
0005433415440	1294	Economy	66600.00
0005435824378	1294	Economy	66600.00
0005433415401	1294	Economy	66600.00
0005435824385	1294	Economy	66600.00
0005433415378	1294	Economy	66600.00
0005435824374	1294	Economy	66600.00
0005435824392	1294	Economy	66600.00
0005435824389	1294	Economy	66600.00
0005435824397	1294	Economy	66600.00
0005433415424	1294	Economy	66600.00
0005435824390	1294	Economy	66600.00
0005435824382	1294	Economy	66600.00
0005432284531	1294	Economy	66600.00
0005435824399	1294	Economy	66600.00
0005432284532	1294	Economy	66600.00
0005435824379	1294	Economy	66600.00
0005433415379	1294	Economy	66600.00
0005435824386	1294	Economy	66600.00
0005435824377	1294	Economy	66600.00
0005435824372	1294	Economy	66600.00
0005435824396	1294	Economy	66600.00
0005435824371	1294	Economy	66600.00
0005435824383	1294	Economy	66600.00
0005433415518	18005	Business	199800.00
0005433415522	18005	Business	199800.00
0005433415514	18005	Business	199800.00
0005435824180	18005	Business	199800.00
0005433415524	18005	Business	199800.00
0005433415523	18005	Business	199800.00
0005433415512	18005	Economy	66600.00
0005435824219	18005	Economy	66600.00
0005435824210	18005	Economy	73200.00
0005433415510	18005	Economy	73200.00
0005433415511	18005	Economy	66600.00
0005435824198	18005	Economy	66600.00
0005433415509	18005	Economy	66600.00
0005433415517	18005	Economy	66600.00
0005433415515	18005	Economy	66600.00
0005435824155	18005	Economy	66600.00
0005433415521	18005	Economy	66600.00
0005433415520	18005	Economy	66600.00
0005433415516	18005	Economy	66600.00
0005433415513	18005	Economy	66600.00
0005435824156	18005	Economy	66600.00
0005435824223	18005	Economy	66600.00
0005435824220	18005	Economy	66600.00
0005435824158	18005	Economy	66600.00
0005435824222	18005	Economy	66600.00
0005433415519	18005	Economy	66600.00
0005435824211	18005	Economy	66600.00
0005434461621	12571	Economy	14800.00
0005434461623	12571	Economy	14800.00
0005434460481	12571	Economy	13500.00
0005434461627	12571	Economy	13500.00
0005434461626	12571	Economy	13500.00
0005434461625	12571	Economy	13500.00
0005434460480	12571	Economy	13500.00
0005434461622	12571	Economy	13500.00
0005434460483	12571	Economy	13500.00
0005434460478	12571	Economy	13500.00
0005434460477	12571	Economy	13500.00
0005434460482	12571	Economy	13500.00
0005434461624	12571	Economy	13500.00
0005434460479	12571	Economy	13500.00
0005432143960	5612	Business	27800.00
0005432783287	5612	Business	27800.00
0005432783330	5612	Business	27800.00
0005432783309	5612	Business	27800.00
0005432783299	5612	Business	27800.00
0005432783327	5612	Business	27800.00
0005432783298	5612	Business	27800.00
0005435242458	5612	Business	27800.00
0005432783329	5612	Economy	9300.00
0005432783305	5612	Economy	9300.00
0005432783279	5612	Economy	9300.00
0005432783297	5612	Economy	9300.00
0005432783322	5612	Economy	9300.00
0005432783334	5612	Economy	9300.00
0005432783315	5612	Economy	9300.00
0005432783331	5612	Economy	9300.00
0005432783290	5612	Economy	10200.00
0005435242416	5612	Economy	10200.00
0005432143957	5612	Economy	10200.00
0005432783320	5612	Economy	10200.00
0005432783310	5612	Economy	10200.00
0005432783321	5612	Economy	9300.00
0005432783301	5612	Economy	9300.00
0005432783300	5612	Economy	9300.00
0005432783291	5612	Economy	9300.00
0005432783323	5612	Economy	9300.00
0005432783294	5612	Economy	9300.00
0005435242409	5612	Economy	9300.00
0005432783313	5612	Economy	9300.00
0005435242391	5612	Economy	9300.00
0005432783302	5612	Economy	9300.00
0005432783307	5612	Economy	9300.00
0005432783288	5612	Economy	9300.00
0005435242468	5612	Economy	9300.00
0005432783333	5612	Economy	9300.00
0005432783311	5612	Economy	9300.00
0005435242392	5612	Economy	9300.00
0005435242408	5612	Economy	9300.00
0005432783281	5612	Economy	9300.00
0005432783318	5612	Economy	9300.00
0005432783306	5612	Economy	9300.00
0005432783312	5612	Economy	9300.00
0005432783304	5612	Economy	9300.00
0005432143956	5612	Economy	9300.00
0005432143959	5612	Economy	9300.00
0005432783295	5612	Economy	9300.00
0005432783289	5612	Economy	9300.00
0005432783326	5612	Economy	9300.00
0005432783325	5612	Economy	9300.00
0005432783303	5612	Economy	9300.00
0005432143961	5612	Economy	9300.00
0005432783332	5612	Economy	9300.00
0005432783283	5612	Economy	9300.00
0005435242424	5612	Economy	9300.00
0005432783319	5612	Economy	9300.00
0005432143958	5612	Economy	9300.00
0005432783314	5612	Economy	9300.00
0005432783317	5612	Economy	9300.00
0005432783308	5612	Economy	9300.00
0005432783292	5612	Economy	9300.00
0005432783280	5612	Economy	9300.00
0005435242388	5612	Economy	9300.00
0005432783284	5612	Economy	9300.00
0005435242425	5612	Economy	9300.00
0005432783316	5612	Economy	9300.00
0005432783296	5612	Economy	9300.00
0005432783285	5612	Economy	9300.00
0005432783286	5612	Economy	9300.00
0005432783282	5612	Economy	9300.00
0005435242410	5612	Economy	9300.00
0005432783328	5612	Economy	9300.00
0005432783324	5612	Economy	9300.00
0005432783293	5612	Economy	9300.00
0005432782871	15377	Business	27800.00
0005435242587	15377	Business	27800.00
0005432782845	15377	Business	27800.00
0005435242597	15377	Business	27800.00
0005432783092	15377	Business	27800.00
0005432782874	15377	Business	27800.00
0005435242589	15377	Business	27800.00
0005435242610	15377	Business	27800.00
0005435242603	15377	Economy	9300.00
0005435242596	15377	Economy	9300.00
0005432782901	15377	Economy	9300.00
0005435242582	15377	Economy	9300.00
0005432782992	15377	Economy	9300.00
0005435242593	15377	Economy	9300.00
0005435242598	15377	Economy	9300.00
0005432782840	15377	Economy	10200.00
0005435242583	15377	Economy	10200.00
0005435242591	15377	Economy	9300.00
0005432782900	15377	Economy	9300.00
0005435242606	15377	Economy	9300.00
0005432782898	15377	Economy	9300.00
0005432782942	15377	Economy	9300.00
0005435242602	15377	Economy	9300.00
0005435242595	15377	Economy	9300.00
0005432783010	15377	Economy	9300.00
0005432783045	15377	Economy	9300.00
0005435476704	15377	Economy	9300.00
0005432782967	15377	Economy	9300.00
0005435242600	15377	Economy	9300.00
0005432782968	15377	Economy	9300.00
0005435242594	15377	Economy	9300.00
0005432783090	15377	Economy	9300.00
0005432783009	15377	Economy	9300.00
0005435476703	15377	Economy	9300.00
0005432783044	15377	Economy	9300.00
0005435242586	15377	Economy	9300.00
0005435242585	15377	Economy	9300.00
0005435242590	15377	Economy	9300.00
0005435242607	15377	Economy	9300.00
0005435242592	15377	Economy	9300.00
0005435242599	15377	Economy	9300.00
0005432782905	15377	Economy	9300.00
0005435242608	15377	Economy	9300.00
0005432782919	15377	Economy	9300.00
0005435242609	15377	Economy	9300.00
0005432782991	15377	Economy	9300.00
0005432783091	15377	Economy	9300.00
0005435242588	15377	Economy	9300.00
0005435242605	15377	Economy	9300.00
0005432782990	15377	Economy	9300.00
0005432782883	15377	Economy	9300.00
0005435242584	15377	Economy	9300.00
0005432782938	15377	Economy	9300.00
0005435476702	15377	Economy	9300.00
0005432783011	15377	Economy	9300.00
0005432782843	15377	Economy	9300.00
0005435242604	15377	Economy	9300.00
0005435242601	15377	Economy	9300.00
0005435476701	15377	Economy	9300.00
0005432848176	4377	Economy	7000.00
0005435850781	4377	Economy	6300.00
0005435850786	4377	Economy	6300.00
0005432848179	4377	Economy	6300.00
0005432848188	4377	Economy	6300.00
0005434462770	4377	Economy	6300.00
0005434463910	4377	Economy	6300.00
0005432848182	4377	Economy	6300.00
0005432848187	4377	Economy	6300.00
0005432848186	4377	Economy	6300.00
0005432848175	4377	Economy	6300.00
0005432848184	4377	Economy	6300.00
0005432848181	4377	Economy	6300.00
0005432848185	4377	Economy	6300.00
0005432848177	4377	Economy	6300.00
0005432848180	4377	Economy	6300.00
0005432848183	4377	Economy	6300.00
0005434463909	4377	Economy	6300.00
0005435850756	4377	Economy	6300.00
0005435850785	4377	Economy	6300.00
0005432848178	4377	Economy	6300.00
0005434462771	4377	Economy	6300.00
0005435850782	4377	Economy	6300.00
0005435850826	28864	Economy	7000.00
0005435850828	28864	Economy	6300.00
0005435850831	28864	Economy	6300.00
0005432848065	28864	Economy	6300.00
0005432848093	28864	Economy	6300.00
0005435850827	28864	Economy	6300.00
0005432848096	28864	Economy	6300.00
0005432848064	28864	Economy	6300.00
0005435850824	28864	Economy	6300.00
0005435850829	28864	Economy	6300.00
0005435850825	28864	Economy	6300.00
0005435850830	28864	Economy	6300.00
0005432848063	28864	Economy	6300.00
0005434925513	6241	Business	11900.00
0005434925515	6241	Business	11900.00
0005433496687	6241	Business	11900.00
0005433496699	6241	Business	11900.00
0005434925518	6241	Business	11900.00
0005432075199	6241	Business	11900.00
0005434925505	6241	Business	11900.00
0005434925517	6241	Business	11900.00
0005434443566	6241	Business	11900.00
0005434443559	6241	Business	11900.00
0005434925528	6241	Business	11900.00
0005434925531	6241	Economy	4000.00
0005434443570	6241	Economy	4000.00
0005433496678	6241	Economy	4000.00
0005434443556	6241	Economy	4000.00
0005433496683	6241	Economy	4000.00
0005433496677	6241	Economy	4000.00
0005434443569	6241	Economy	4000.00
0005434443558	6241	Economy	4000.00
0005434925522	6241	Economy	4000.00
0005433496690	6241	Economy	4400.00
0005434443571	6241	Economy	4400.00
0005432075198	6241	Economy	4400.00
0005433496691	6241	Economy	4400.00
0005433496684	6241	Economy	4400.00
0005433496702	6241	Economy	4000.00
0005433496685	6241	Economy	4000.00
0005433496695	6241	Economy	4000.00
0005433496703	6241	Economy	4000.00
0005434443562	6241	Economy	4000.00
0005434925512	6241	Economy	4000.00
0005434925511	6241	Economy	4000.00
0005434925521	6241	Economy	4000.00
0005433496686	6241	Economy	4000.00
0005434443567	6241	Economy	4000.00
0005434925524	6241	Economy	4000.00
0005433496692	6241	Economy	4000.00
0005434925509	6241	Economy	4000.00
0005433496701	6241	Economy	4000.00
0005434925503	6241	Economy	4000.00
0005434925504	6241	Economy	4000.00
0005432075200	6241	Economy	4000.00
0005434925516	6241	Economy	4000.00
0005434925520	6241	Economy	4000.00
0005434443557	6241	Economy	4000.00
0005434925526	6241	Economy	4000.00
0005433496680	6241	Economy	4000.00
0005434443563	6241	Economy	4000.00
0005433496681	6241	Economy	4000.00
0005434443561	6241	Economy	4000.00
0005434925514	6241	Economy	4000.00
0005433496693	6241	Economy	4000.00
0005434925525	6241	Economy	4000.00
0005434443560	6241	Economy	4000.00
0005432075197	6241	Economy	4000.00
0005433496689	6241	Economy	4000.00
0005434443564	6241	Economy	4000.00
0005434443565	6241	Economy	4000.00
0005434925508	6241	Economy	4000.00
0005434925530	6241	Economy	4000.00
0005434443568	6241	Economy	4000.00
0005434925506	6241	Economy	4000.00
0005433496675	6241	Economy	4000.00
0005433496697	6241	Economy	4000.00
0005434925510	6241	Economy	4000.00
0005434925532	6241	Economy	4000.00
0005433496679	6241	Economy	4000.00
0005434925527	6241	Economy	4000.00
0005433496682	6241	Economy	4000.00
0005433496694	6241	Economy	4000.00
0005433496696	6241	Economy	4000.00
0005434925507	6241	Economy	4000.00
0005433496676	6241	Economy	4000.00
0005434925529	6241	Economy	4000.00
0005433496706	6241	Economy	4000.00
0005433496698	6241	Economy	4000.00
0005433496704	6241	Economy	4000.00
0005433496700	6241	Economy	4000.00
0005433496705	6241	Economy	4000.00
0005433496688	6241	Economy	4000.00
0005434925519	6241	Economy	4000.00
0005434925523	6241	Economy	4000.00
0005433496475	20426	Business	11900.00
0005433496504	20426	Business	11900.00
0005433496466	20426	Business	11900.00
0005433496483	20426	Business	11900.00
0005433496499	20426	Business	11900.00
0005434443470	20426	Economy	4000.00
0005433496442	20426	Economy	4000.00
0005433496424	20426	Economy	4000.00
0005433496484	20426	Economy	4000.00
0005434443453	20426	Economy	4000.00
0005433496524	20426	Economy	4400.00
0005433496421	20426	Economy	4000.00
0005433496465	20426	Economy	4000.00
0005433496441	20426	Economy	4000.00
0005434443434	20426	Economy	4000.00
0005433496425	20426	Economy	4000.00
0005434443512	20426	Economy	4000.00
0005434443467	20426	Economy	4000.00
0005433496426	20426	Economy	4000.00
0005433496540	20426	Economy	4000.00
0005433496506	20426	Economy	4000.00
0005433496525	20426	Economy	4000.00
0005433496473	20426	Economy	4000.00
0005434443469	20426	Economy	4000.00
0005433496554	20426	Economy	4000.00
0005433496498	20426	Economy	4000.00
0005433496557	20426	Economy	4000.00
0005434443463	20426	Economy	4000.00
0005434443511	20426	Economy	4000.00
0005433496589	20426	Economy	4000.00
0005433496447	20426	Economy	4000.00
0005433496541	20426	Economy	4000.00
0005434443428	20426	Economy	4000.00
0005434443433	20426	Economy	4000.00
0005433496467	20426	Economy	4000.00
0005433496474	20426	Economy	4000.00
0005433496558	20426	Economy	4000.00
0005432782838	12184	Business	41200.00
0005435242629	12184	Business	41200.00
0005432783237	12184	Business	41200.00
0005435242635	12184	Business	41200.00
0005435242618	12184	Business	41200.00
0005432782881	12184	Business	41200.00
0005435242623	12184	Business	41200.00
0005435242622	12184	Economy	13700.00
0005435242616	12184	Economy	13700.00
0005432782946	12184	Economy	13700.00
0005432782850	12184	Economy	15100.00
0005435242631	12184	Economy	15100.00
0005432782886	12184	Economy	15100.00
0005435242636	12184	Economy	13700.00
0005435242633	12184	Economy	13700.00
0005435242617	12184	Economy	13700.00
0005435242626	12184	Economy	13700.00
0005432782931	12184	Economy	13700.00
0005432782864	12184	Economy	13700.00
0005432782962	12184	Economy	13700.00
0005435242613	12184	Economy	13700.00
0005435242625	12184	Economy	13700.00
0005435242615	12184	Economy	13700.00
0005435242611	12184	Economy	13700.00
0005432782851	12184	Economy	13700.00
0005435242612	12184	Economy	13700.00
0005435242627	12184	Economy	13700.00
0005432782889	12184	Economy	13700.00
0005432783015	12184	Economy	13700.00
0005432782877	12184	Economy	13700.00
0005435242619	12184	Economy	13700.00
0005432782930	12184	Economy	13700.00
0005432782908	12184	Economy	13700.00
0005432782918	12184	Economy	13700.00
0005432783024	12184	Economy	13700.00
0005432782964	12184	Economy	13700.00
0005432782888	12184	Economy	13700.00
0005432783014	12184	Economy	13700.00
0005432782865	12184	Economy	13700.00
0005435242630	12184	Economy	13700.00
0005432783238	12184	Economy	13700.00
0005432782947	12184	Economy	13700.00
0005432782906	12184	Economy	13700.00
0005435242624	12184	Economy	13700.00
0005435242614	12184	Economy	13700.00
0005435242634	12184	Economy	13700.00
0005432782873	12184	Economy	13700.00
0005435242621	12184	Economy	13700.00
0005435242632	12184	Economy	13700.00
0005432782916	12184	Economy	13700.00
0005432782929	12184	Economy	13700.00
0005432782882	12184	Economy	13700.00
0005435242620	12184	Economy	13700.00
0005435242628	12184	Economy	13700.00
0005432782857	12184	Economy	13700.00
0005432782948	12184	Economy	13700.00
0005432783246	15409	Business	41200.00
0005432783226	15409	Business	41200.00
0005432783268	15409	Business	41200.00
0005432783245	15409	Business	41200.00
0005432783242	15409	Business	41200.00
0005432783275	15409	Business	41200.00
0005432783276	15409	Business	41200.00
0005432783252	15409	Business	41200.00
0005432783266	15409	Business	41200.00
0005432783260	15409	Economy	13700.00
0005432783261	15409	Economy	13700.00
0005432783272	15409	Economy	13700.00
0005432783247	15409	Economy	13700.00
0005432783263	15409	Economy	13700.00
0005432783256	15409	Economy	13700.00
0005432783238	15409	Economy	15100.00
0005432783227	15409	Economy	15100.00
0005432783231	15409	Economy	15100.00
0005432783233	15409	Economy	13700.00
0005432783259	15409	Economy	13700.00
0005432783244	15409	Economy	13700.00
0005432783254	15409	Economy	13700.00
0005432783236	15409	Economy	13700.00
0005432783234	15409	Economy	13700.00
0005435242441	15409	Economy	13700.00
0005435242387	15409	Economy	13700.00
0005432783265	15409	Economy	13700.00
0005432783241	15409	Economy	13700.00
0005432783277	15409	Economy	13700.00
0005432783269	15409	Economy	13700.00
0005432783229	15409	Economy	13700.00
0005435242414	15409	Economy	13700.00
0005432783225	15409	Economy	13700.00
0005432783274	15409	Economy	13700.00
0005432783271	15409	Economy	13700.00
0005432783278	15409	Economy	13700.00
0005432783232	15409	Economy	13700.00
0005432783257	15409	Economy	13700.00
0005435242413	15409	Economy	13700.00
0005432783262	15409	Economy	13700.00
0005432783264	15409	Economy	13700.00
0005435242442	15409	Economy	13700.00
0005432783258	15409	Economy	13700.00
0005435242415	15409	Economy	13700.00
0005432783255	15409	Economy	13700.00
0005432783267	15409	Economy	13700.00
0005432783273	15409	Economy	13700.00
0005432783250	15409	Economy	13700.00
0005432783235	15409	Economy	13700.00
0005432783237	15409	Economy	13700.00
0005432783240	15409	Economy	13700.00
0005432783239	15409	Economy	13700.00
0005432783253	15409	Economy	13700.00
0005432783251	15409	Economy	13700.00
0005432783228	15409	Economy	13700.00
0005432783270	15409	Economy	13700.00
0005432783230	15409	Economy	13700.00
0005432783243	15409	Economy	13700.00
0005432783249	15409	Economy	13700.00
0005432783248	15409	Economy	13700.00
0005434877017	10114	Business	49700.00
0005434876643	10114	Business	49700.00
0005434758856	10114	Business	49700.00
0005434910089	10114	Business	49700.00
0005434877016	10114	Business	49700.00
0005434876602	10114	Business	49700.00
0005434876809	10114	Business	49700.00
0005434876875	10114	Economy	16600.00
0005434910088	10114	Economy	16600.00
0005434876723	10114	Economy	16600.00
0005434876892	10114	Economy	18200.00
0005434876813	10114	Economy	18200.00
0005434876716	10114	Economy	18200.00
0005434876693	10114	Economy	16600.00
0005434876737	10114	Economy	18200.00
0005434876804	10114	Economy	16600.00
0005434876806	10114	Economy	16600.00
0005434876893	10114	Economy	16600.00
0005434876680	10114	Economy	16600.00
0005434876578	10114	Economy	16600.00
0005434876676	10114	Economy	16600.00
0005434876682	10114	Economy	16600.00
0005434876810	10114	Economy	16600.00
0005434876739	10114	Economy	16600.00
0005434876923	10114	Economy	16600.00
0005434876641	10114	Economy	16600.00
0005434876561	10114	Economy	16600.00
0005434876624	10114	Economy	16600.00
0005434876557	10114	Economy	16600.00
0005434876876	10114	Economy	16600.00
0005434758855	10114	Economy	16600.00
0005434876627	10114	Economy	16600.00
0005434876603	10114	Economy	16600.00
0005434876592	10114	Economy	16600.00
0005434876649	10114	Economy	16600.00
0005434876835	10114	Economy	16600.00
0005434876648	10114	Economy	16600.00
0005434877015	10114	Economy	16600.00
0005434876640	10114	Economy	16600.00
0005434876647	10114	Economy	16600.00
0005434876679	10114	Economy	16600.00
0005435913901	10114	Economy	16600.00
0005434876918	10114	Economy	16600.00
0005434876628	10114	Economy	16600.00
0005434876562	10114	Economy	16600.00
0005435913902	10114	Economy	16600.00
0005434876800	10114	Economy	16600.00
0005434876794	10114	Economy	16600.00
0005434876613	10114	Economy	16600.00
0005434876738	10114	Economy	16600.00
0005434876560	10114	Economy	16600.00
0005434877003	10114	Economy	16600.00
0005434877370	14645	Business	49700.00
0005434877405	14645	Business	49700.00
0005434877378	14645	Business	49700.00
0005434877350	14645	Business	49700.00
0005434877332	14645	Business	49700.00
0005434877403	14645	Business	49700.00
0005434877360	14645	Business	49700.00
0005434877415	14645	Business	49700.00
0005434877409	14645	Business	49700.00
0005434877411	14645	Business	49700.00
0005434877381	14645	Business	49700.00
0005434877372	14645	Business	49700.00
0005434877345	14645	Business	49700.00
0005434877382	14645	Business	49700.00
0005434877358	14645	Business	49700.00
0005434877400	14645	Economy	16600.00
0005434877331	14645	Economy	16600.00
0005434877375	14645	Economy	16600.00
0005434877356	14645	Economy	16600.00
0005434877374	14645	Economy	16600.00
0005434877348	14645	Economy	16600.00
0005434877362	14645	Economy	16600.00
0005434877339	14645	Economy	16600.00
0005434877418	14645	Economy	16600.00
0005434877412	14645	Economy	16600.00
0005434877335	14645	Economy	16600.00
0005434877410	14645	Economy	16600.00
0005434877427	14645	Economy	16600.00
0005434877426	14645	Economy	18200.00
0005434877385	14645	Economy	18200.00
0005434877387	14645	Economy	18200.00
0005434877421	14645	Economy	16600.00
0005434877393	14645	Economy	16600.00
0005434877398	14645	Economy	16600.00
0005434877422	14645	Economy	16600.00
0005434877371	14645	Economy	16600.00
0005434877424	14645	Economy	16600.00
0005434877420	14645	Economy	16600.00
0005434877399	14645	Economy	16600.00
0005434877425	14645	Economy	16600.00
0005434877354	14645	Economy	16600.00
0005434877379	14645	Economy	16600.00
0005434877416	14645	Economy	16600.00
0005434877423	14645	Economy	16600.00
0005434877357	14645	Economy	16600.00
0005434877407	14645	Economy	16600.00
0005434877342	14645	Economy	16600.00
0005434877395	14645	Economy	16600.00
0005434877333	14645	Economy	16600.00
0005434877384	14645	Economy	16600.00
0005434877340	14645	Economy	16600.00
0005434877344	14645	Economy	16600.00
0005434877355	14645	Economy	16600.00
0005434877391	14645	Economy	16600.00
0005434877341	14645	Economy	16600.00
0005434877336	14645	Economy	16600.00
0005434877408	14645	Economy	16600.00
0005434877353	14645	Economy	16600.00
0005434877419	14645	Economy	16600.00
0005434877369	14645	Economy	16600.00
0005434877394	14645	Economy	16600.00
0005434877337	14645	Economy	16600.00
0005434877368	14645	Economy	16600.00
0005434877401	14645	Economy	16600.00
0005434877361	14645	Economy	16600.00
0005434877389	14645	Economy	16600.00
0005434877351	14645	Economy	16600.00
0005434877397	14645	Economy	16600.00
0005434877377	14645	Economy	16600.00
0005434877388	14645	Economy	16600.00
0005434877390	14645	Economy	16600.00
0005434877413	14645	Economy	16600.00
0005434910071	14645	Economy	16600.00
0005434877365	14645	Economy	16600.00
0005434877392	14645	Economy	16600.00
0005434877347	14645	Economy	16600.00
0005434877364	14645	Economy	16600.00
0005434877376	14645	Economy	16600.00
0005434877386	14645	Economy	16600.00
0005434877346	14645	Economy	16600.00
0005434877380	14645	Economy	16600.00
0005434877363	14645	Economy	16600.00
0005434877396	14645	Economy	16600.00
0005434877359	14645	Economy	16600.00
0005434877417	14645	Economy	16600.00
0005434877352	14645	Economy	16600.00
0005434877366	14645	Economy	16600.00
0005434877349	14645	Economy	16600.00
0005434877383	14645	Economy	16600.00
0005434877343	14645	Economy	16600.00
0005434877402	14645	Economy	16600.00
0005434877367	14645	Economy	16600.00
0005434877334	14645	Economy	16600.00
0005434877414	14645	Economy	16600.00
0005434877404	14645	Economy	16600.00
0005434877373	14645	Economy	16600.00
0005434877338	14645	Economy	16600.00
0005434758872	14645	Economy	16600.00
0005434877406	14645	Economy	16600.00
0005435660037	9268	Economy	22400.00
0005435660031	9268	Economy	22400.00
0005434251799	9268	Economy	22400.00
0005434251804	9268	Economy	22400.00
0005435660029	9268	Economy	20300.00
0005435660030	9268	Economy	20300.00
0005435660033	9268	Economy	20300.00
0005435660035	9268	Economy	20300.00
0005434251844	9268	Economy	20300.00
0005435660032	9268	Economy	20300.00
0005435660038	9268	Economy	20300.00
0005435660039	9268	Economy	20300.00
0005434251808	9268	Economy	20300.00
0005435660034	9268	Economy	20300.00
0005435660036	9268	Economy	20300.00
0005434251877	24647	Economy	22400.00
0005434251881	24647	Economy	22400.00
0005435659946	24647	Economy	20300.00
0005435659951	24647	Economy	20300.00
0005434251880	24647	Economy	20300.00
0005434251883	24647	Economy	20300.00
0005434251875	24647	Economy	20300.00
0005434251882	24647	Economy	20300.00
0005435659971	24647	Economy	20300.00
0005434251873	24647	Economy	20300.00
0005434251874	24647	Economy	20300.00
0005434251878	24647	Economy	20300.00
0005434251879	24647	Economy	20300.00
0005435659965	24647	Economy	20300.00
0005435659961	24647	Economy	20300.00
0005434251876	24647	Economy	20300.00
0005435659960	24647	Economy	20300.00
0005433680105	2808	Business	33000.00
0005433680117	2808	Business	33000.00
0005432966550	2808	Business	33000.00
0005433680116	2808	Business	33000.00
0005433680146	2808	Business	33000.00
0005433680141	2808	Business	33000.00
0005432222735	2808	Economy	11000.00
0005433680127	2808	Economy	11000.00
0005433680139	2808	Economy	11000.00
0005433680113	2808	Economy	11000.00
0005432966531	2808	Economy	12100.00
0005433680128	2808	Economy	12100.00
0005432222732	2808	Economy	12100.00
0005432222733	2808	Economy	11000.00
0005433680102	2808	Economy	11000.00
0005433680132	2808	Economy	11000.00
0005433680107	2808	Economy	11000.00
0005432222734	2808	Economy	11000.00
0005432966521	2808	Economy	11000.00
0005432966524	2808	Economy	11000.00
0005433680114	2808	Economy	11000.00
0005432966562	2808	Economy	11000.00
0005433680144	2808	Economy	11000.00
0005432966590	2808	Economy	11000.00
0005433680126	2808	Economy	11000.00
0005432966589	2808	Economy	11000.00
0005433684400	2808	Economy	11000.00
0005433680119	2808	Economy	11000.00
0005432222731	2808	Economy	11000.00
0005433680142	2808	Economy	11000.00
0005433680115	2808	Economy	11000.00
0005433680108	2808	Economy	11000.00
0005433680138	2808	Economy	11000.00
0005433680147	2808	Economy	11000.00
0005433680145	2808	Economy	11000.00
0005433680103	2808	Economy	11000.00
0005432966563	2808	Economy	11000.00
0005433680134	2808	Economy	11000.00
0005433680133	2808	Economy	11000.00
0005432966600	2808	Economy	11000.00
0005433680111	2808	Economy	11000.00
0005432966481	2808	Economy	11000.00
0005433680135	2808	Economy	11000.00
0005433680120	2808	Economy	11000.00
0005433680104	2808	Economy	11000.00
0005433680112	2808	Economy	11000.00
0005433680101	2808	Economy	11000.00
0005433680137	2808	Economy	11000.00
0005433680140	2808	Economy	11000.00
0005433680118	2808	Economy	11000.00
0005432966549	2808	Economy	11000.00
0005433680109	2808	Economy	11000.00
0005433680123	2808	Economy	11000.00
0005433680148	2808	Economy	11000.00
0005433680122	2808	Economy	11000.00
0005433680130	2808	Economy	11000.00
0005432966599	2808	Economy	11000.00
0005433684399	2808	Economy	11000.00
0005433680106	2808	Economy	11000.00
0005433680136	2808	Economy	11000.00
0005433680124	2808	Economy	11000.00
0005432966480	2808	Economy	11000.00
0005433680110	2808	Economy	11000.00
0005433680100	2808	Economy	11000.00
0005433680121	2808	Economy	11000.00
0005433680131	2808	Economy	11000.00
0005433680129	2808	Economy	11000.00
0005433680125	2808	Economy	11000.00
0005433680143	2808	Economy	11000.00
0005433679790	29138	Business	33000.00
0005433679774	29138	Business	33000.00
0005433679770	29138	Business	33000.00
0005433679911	29138	Business	33000.00
0005433679777	29138	Business	33000.00
0005433679785	29138	Business	33000.00
0005432966705	29138	Business	33000.00
0005433690895	29138	Business	33000.00
0005433679715	29138	Business	33000.00
0005432966694	29138	Economy	11000.00
0005432966701	29138	Economy	11000.00
0005432966698	29138	Economy	11000.00
0005433679802	29138	Economy	11000.00
0005433679721	29138	Economy	11000.00
0005433684386	29138	Economy	11000.00
0005432966710	29138	Economy	11000.00
0005432005186	29138	Economy	11000.00
0005433679833	29138	Economy	11000.00
0005433679886	29138	Economy	12100.00
0005432966713	29138	Economy	12100.00
0005433679806	29138	Economy	12100.00
0005433679714	29138	Economy	12100.00
0005433679970	29138	Economy	11000.00
0005432966691	29138	Economy	11000.00
0005432966715	29138	Economy	11000.00
0005433679805	29138	Economy	11000.00
0005432966707	29138	Economy	11000.00
0005433679750	29138	Economy	11000.00
0005433679957	29138	Economy	11000.00
0005433690891	29138	Economy	11000.00
0005433684388	29138	Economy	11000.00
0005433679720	29138	Economy	11000.00
0005433680001	29138	Economy	11000.00
0005432966714	29138	Economy	11000.00
0005432966692	29138	Economy	11000.00
0005432966709	29138	Economy	11000.00
0005433679773	29138	Economy	11000.00
0005432966702	29138	Economy	11000.00
0005433684387	29138	Economy	11000.00
0005432966712	29138	Economy	11000.00
0005432966693	29138	Economy	11000.00
0005432966704	29138	Economy	11000.00
0005432966703	29138	Economy	11000.00
0005433679940	29138	Economy	11000.00
0005433679784	29138	Economy	11000.00
0005432966706	29138	Economy	11000.00
0005432966689	29138	Economy	11000.00
0005433679788	29138	Economy	11000.00
0005433679832	29138	Economy	11000.00
0005433679978	29138	Economy	11000.00
0005432966697	29138	Economy	11000.00
0005433679938	29138	Economy	11000.00
0005433690892	29138	Economy	11000.00
0005432005188	29138	Economy	11000.00
0005432966696	29138	Economy	11000.00
0005432966690	29138	Economy	11000.00
0005433679796	29138	Economy	11000.00
0005432966695	29138	Economy	11000.00
0005432966700	29138	Economy	11000.00
0005432966708	29138	Economy	11000.00
0005433679941	29138	Economy	11000.00
0005433679958	29138	Economy	11000.00
0005433680002	29138	Economy	11000.00
0005433679775	29138	Economy	11000.00
0005432005187	29138	Economy	11000.00
0005433690896	29138	Economy	11000.00
0005433679816	29138	Economy	11000.00
0005432966688	29138	Economy	11000.00
0005433679898	29138	Economy	11000.00
0005433679850	29138	Economy	11000.00
0005432966699	29138	Economy	11000.00
0005433679751	29138	Economy	11000.00
0005433679786	29138	Economy	11000.00
0005433679787	29138	Economy	11000.00
0005432966711	29138	Economy	11000.00
0005433633459	9311	Business	132900.00
0005433633463	9311	Business	132900.00
0005433613952	9311	Business	132900.00
0005433633478	9311	Business	132900.00
0005433613963	9311	Business	132900.00
0005433633464	9311	Business	132900.00
0005434269070	9311	Business	132900.00
0005433613947	9311	Business	132900.00
0005433613941	9311	Business	132900.00
0005432145092	9311	Business	132900.00
0005433613975	9311	Business	132900.00
0005433633479	9311	Business	132900.00
0005433577682	9311	Business	132900.00
0005433577671	9311	Business	132900.00
0005433577679	9311	Business	132900.00
0005433613936	9311	Business	132900.00
0005433633473	9311	Business	132900.00
0005433613979	9311	Business	132900.00
0005433613942	9311	Business	132900.00
0005433633476	9311	Business	132900.00
0005433633491	9311	Business	132900.00
0005433613935	9311	Business	132900.00
0005433613954	9311	Business	132900.00
0005433613973	9311	Business	132900.00
0005433633485	9311	Economy	48700.00
0005433577672	9311	Economy	48700.00
0005433577676	9311	Economy	48700.00
0005432755044	9311	Economy	48700.00
0005433577681	9311	Economy	48700.00
0005433613970	9311	Economy	44300.00
0005433613940	9311	Economy	44300.00
0005433613924	9311	Economy	44300.00
0005433613916	9311	Economy	44300.00
0005433613949	9311	Economy	44300.00
0005433613910	9311	Economy	44300.00
0005433613965	9311	Economy	44300.00
0005433613911	9311	Economy	44300.00
0005433613950	9311	Economy	44300.00
0005433613960	9311	Economy	44300.00
0005433613915	9311	Economy	44300.00
0005433613938	9311	Economy	44300.00
0005433633486	9311	Economy	44300.00
0005433577674	9311	Economy	44300.00
0005433577675	9311	Economy	44300.00
0005433633461	9311	Economy	44300.00
0005433613930	9311	Economy	44300.00
0005433633474	9311	Economy	44300.00
0005433613920	9311	Economy	44300.00
0005434163462	9311	Economy	44300.00
0005433633489	9311	Economy	44300.00
0005433613919	9311	Economy	44300.00
0005433613934	9311	Economy	44300.00
0005433633462	9311	Economy	44300.00
0005432755043	9311	Economy	44300.00
0005433613982	9311	Economy	44300.00
0005433577678	9311	Economy	44300.00
0005432756816	9311	Economy	44300.00
0005433613951	9311	Economy	44300.00
0005433613932	9311	Economy	44300.00
0005433577680	9311	Economy	44300.00
0005433633487	9311	Economy	44300.00
0005433633488	9311	Economy	44300.00
0005433613969	9311	Economy	44300.00
0005433577683	9311	Economy	44300.00
0005433613917	9311	Economy	44300.00
0005432756815	9311	Economy	44300.00
0005433613957	9311	Economy	44300.00
0005433613978	9311	Economy	44300.00
0005433633470	9311	Economy	44300.00
0005433633475	9311	Economy	44300.00
0005433613914	9311	Economy	44300.00
0005433633467	9311	Economy	44300.00
0005433613922	9311	Economy	44300.00
0005433633465	9311	Economy	44300.00
0005433613980	9311	Economy	44300.00
0005433613967	9311	Economy	48700.00
0005433613929	9311	Economy	48700.00
0005433613925	9311	Economy	48700.00
0005433613972	9311	Economy	44300.00
0005433613984	9311	Economy	44300.00
0005434163461	9311	Economy	44300.00
0005433633484	9311	Economy	44300.00
0005433613964	9311	Economy	44300.00
0005433613928	9311	Economy	44300.00
0005433613977	9311	Economy	44300.00
0005433613946	9311	Economy	44300.00
0005433613961	9311	Economy	44300.00
0005433613971	9311	Economy	44300.00
0005433633481	9311	Economy	44300.00
0005434163463	9311	Economy	44300.00
0005433633483	9311	Economy	44300.00
0005433613931	9311	Economy	44300.00
0005433613955	9311	Economy	44300.00
0005433613981	9311	Economy	44300.00
0005434163465	9311	Economy	44300.00
0005433633460	9311	Economy	44300.00
0005433613918	9311	Economy	44300.00
0005433577684	9311	Economy	44300.00
0005433613912	9311	Economy	44300.00
0005433577673	9311	Economy	44300.00
0005433633477	9311	Economy	44300.00
0005433613933	9311	Economy	44300.00
0005433613976	9311	Economy	44300.00
0005433613939	9311	Economy	44300.00
0005433613948	9311	Economy	44300.00
0005433613926	9311	Economy	44300.00
0005433613937	9311	Economy	44300.00
0005433613913	9311	Economy	44300.00
0005433577677	9311	Economy	44300.00
0005433633458	9311	Economy	44300.00
0005433613921	9311	Economy	44300.00
0005433613974	9311	Economy	44300.00
0005432145091	9311	Economy	44300.00
0005433613944	9311	Economy	44300.00
0005433633472	9311	Economy	44300.00
0005433613983	9311	Economy	44300.00
0005433613959	9311	Economy	44300.00
0005433613953	9311	Economy	44300.00
0005433633490	9311	Economy	44300.00
0005433633469	9311	Economy	44300.00
0005433613923	9311	Economy	44300.00
0005433613956	9311	Economy	44300.00
0005433633457	9311	Economy	44300.00
0005433613943	9311	Economy	44300.00
0005433613966	9311	Economy	44300.00
0005433633471	9311	Economy	44300.00
0005433633482	9311	Economy	44300.00
0005433613962	9311	Economy	44300.00
0005433613968	9311	Economy	44300.00
0005433613958	9311	Economy	44300.00
0005433633480	9311	Economy	44300.00
0005433633466	9311	Economy	44300.00
0005433613927	9311	Economy	44300.00
0005433633468	9311	Economy	44300.00
0005432756817	9311	Economy	44300.00
0005433613945	9311	Economy	44300.00
0005434163531	25213	Business	132900.00
0005433613431	25213	Business	132900.00
0005434163535	25213	Business	132900.00
0005434163534	25213	Business	132900.00
0005434163533	25213	Business	132900.00
0005433613495	25213	Business	132900.00
0005434163530	25213	Business	132900.00
0005433613678	25213	Business	132900.00
0005433633277	25213	Business	132900.00
0005433613569	25213	Business	132900.00
0005433613493	25213	Economy	48700.00
0005433613502	25213	Economy	48700.00
0005433613438	25213	Economy	44300.00
0005433633220	25213	Economy	44300.00
0005433613649	25213	Economy	44300.00
0005433613480	25213	Economy	44300.00
0005434273060	25213	Economy	44300.00
0005433613464	25213	Economy	44300.00
0005433633255	25213	Economy	44300.00
0005433613568	25213	Economy	44300.00
0005434272174	25213	Economy	44300.00
0005433633278	25213	Economy	44300.00
0005433577621	25213	Economy	44300.00
0005433577586	25213	Economy	44300.00
0005434163526	25213	Economy	44300.00
0005433613388	25213	Economy	44300.00
0005433613650	25213	Economy	44300.00
0005433613389	25213	Economy	44300.00
0005434163529	25213	Economy	44300.00
0005433613487	25213	Economy	44300.00
0005433577587	25213	Economy	44300.00
0005433613399	25213	Economy	44300.00
0005433613430	25213	Economy	44300.00
0005433613624	25213	Economy	44300.00
0005433613456	25213	Economy	44300.00
0005433613510	25213	Economy	48700.00
0005433633322	25213	Economy	48700.00
0005433633411	25213	Economy	44300.00
0005434163536	25213	Economy	44300.00
0005434163532	25213	Economy	44300.00
0005433613648	25213	Economy	44300.00
0005433577582	25213	Economy	44300.00
0005434163528	25213	Economy	44300.00
0005433613504	25213	Economy	44300.00
0005433633249	25213	Economy	44300.00
0005434272175	25213	Economy	44300.00
0005433613453	25213	Economy	44300.00
0005433577562	25213	Economy	44300.00
0005433577590	25213	Economy	44300.00
0005433613625	25213	Economy	44300.00
0005433613415	25213	Economy	44300.00
0005433613548	25213	Economy	44300.00
0005433633412	25213	Economy	44300.00
0005434273059	25213	Economy	44300.00
0005433633321	25213	Economy	44300.00
0005434273061	25213	Economy	44300.00
0005434163527	25213	Economy	44300.00
0005433613472	25213	Economy	44300.00
0005433613429	25213	Economy	44300.00
0005433613494	25213	Economy	44300.00
0005433633226	25213	Economy	44300.00
0005435856134	4234	Business	193100.00
0005435856144	4234	Business	193100.00
0005435986704	4234	Economy	64400.00
0005432184927	4234	Economy	64400.00
0005435856145	4234	Economy	64400.00
0005435947004	4234	Economy	64400.00
0005432184926	4234	Economy	64400.00
0005435947078	4234	Economy	64400.00
0005435986706	4234	Economy	64400.00
0005435986705	4234	Economy	64400.00
0005432184925	4234	Economy	64400.00
0005434271276	4234	Economy	64400.00
0005432571259	4234	Economy	64400.00
0005432184924	4234	Economy	64400.00
0005432184923	4234	Economy	64400.00
0005435947019	4234	Economy	64400.00
0005435947025	4234	Economy	64400.00
0005435947006	4234	Economy	64400.00
0005435787337	26595	Business	193100.00
0005435947117	26595	Business	193100.00
0005435947124	26595	Business	193100.00
0005432571290	26595	Economy	70800.00
0005435947115	26595	Economy	64400.00
0005435947128	26595	Economy	64400.00
0005435947129	26595	Economy	64400.00
0005435947120	26595	Economy	64400.00
0005435947122	26595	Economy	64400.00
0005435856166	26595	Economy	64400.00
0005435947126	26595	Economy	64400.00
0005432571291	26595	Economy	64400.00
0005435787334	26595	Economy	64400.00
0005435947121	26595	Economy	64400.00
0005435787336	26595	Economy	64400.00
0005435947123	26595	Economy	64400.00
0005432571289	26595	Economy	64400.00
0005435947118	26595	Economy	64400.00
0005435947130	26595	Economy	64400.00
0005435856167	26595	Economy	64400.00
0005432571288	26595	Economy	70800.00
0005435787335	26595	Economy	64400.00
0005435986656	26595	Economy	64400.00
0005435947131	26595	Economy	64400.00
0005435947127	26595	Economy	64400.00
0005435986650	26595	Economy	64400.00
0005435947119	26595	Economy	64400.00
0005435947125	26595	Economy	64400.00
0005435947116	26595	Economy	64400.00
0005433129206	320	Business	21500.00
0005433568479	320	Business	21500.00
0005433568530	320	Business	21500.00
0005433568516	320	Business	21500.00
0005433568534	320	Business	21500.00
0005433568526	320	Business	21500.00
0005433074284	320	Business	21500.00
0005433568481	320	Business	21500.00
0005433074282	320	Business	21500.00
0005433568506	320	Business	21500.00
0005433568478	320	Business	21500.00
0005432238883	320	Business	21500.00
0005433568489	320	Business	21500.00
0005433134059	320	Business	21500.00
0005432238881	320	Business	21500.00
0005432238878	320	Economy	7900.00
0005432238882	320	Economy	7900.00
0005432947793	320	Economy	7200.00
0005433568495	320	Economy	7200.00
0005433568486	320	Economy	7200.00
0005433568505	320	Economy	7200.00
0005433568480	320	Economy	7200.00
0005433568494	320	Economy	7200.00
0005433568509	320	Economy	7200.00
0005433568488	320	Economy	7200.00
0005433568499	320	Economy	7200.00
0005433568519	320	Economy	7200.00
0005433568496	320	Economy	7200.00
0005433568518	320	Economy	7200.00
0005433568487	320	Economy	7200.00
0005433568533	320	Economy	7200.00
0005433568537	320	Economy	7200.00
0005433568513	320	Economy	7200.00
0005433568539	320	Economy	7200.00
0005433568484	320	Economy	7200.00
0005433568501	320	Economy	7200.00
0005433568483	320	Economy	7200.00
0005433568482	320	Economy	7200.00
0005433568522	320	Economy	7200.00
0005433568536	320	Economy	7200.00
0005433568543	320	Economy	7200.00
0005433074285	320	Economy	7200.00
0005432947769	320	Economy	7200.00
0005433568529	320	Economy	7200.00
0005433568511	320	Economy	7200.00
0005433129211	320	Economy	7200.00
0005433568524	320	Economy	7200.00
0005433568525	320	Economy	7200.00
0005432947865	320	Economy	7200.00
0005433074289	320	Economy	7200.00
0005433568510	320	Economy	7200.00
0005433074283	320	Economy	7200.00
0005432238877	320	Economy	7200.00
0005433568517	320	Economy	7200.00
0005433074246	320	Economy	7200.00
0005432947794	320	Economy	7200.00
0005433568492	320	Economy	7200.00
0005433568512	320	Economy	7900.00
0005433568528	320	Economy	7900.00
0005433568497	320	Economy	7900.00
0005433568498	320	Economy	7200.00
0005433568538	320	Economy	7200.00
0005433568535	320	Economy	7900.00
0005433568541	320	Economy	7200.00
0005434087918	320	Economy	7200.00
0005433568500	320	Economy	7200.00
0005433568485	320	Economy	7200.00
0005433568508	320	Economy	7200.00
0005433568504	320	Economy	7200.00
0005433074198	320	Economy	7200.00
0005433074224	320	Economy	7200.00
0005432947784	320	Economy	7200.00
0005433568542	320	Economy	7200.00
0005433568540	320	Economy	7200.00
0005433568520	320	Economy	7200.00
0005433568527	320	Economy	7200.00
0005433568514	320	Economy	7200.00
0005433074278	320	Economy	7200.00
0005432947783	320	Economy	7200.00
0005432238880	320	Economy	7200.00
0005433134061	320	Economy	7200.00
0005433134072	320	Economy	7200.00
0005433568532	320	Economy	7200.00
0005433568493	320	Economy	7200.00
0005433074220	320	Economy	7200.00
0005433074242	320	Economy	7200.00
0005432238879	320	Economy	7200.00
0005433134071	320	Economy	7200.00
0005433568521	320	Economy	7200.00
0005432947840	320	Economy	7200.00
0005433568507	320	Economy	7200.00
0005433568490	320	Economy	7200.00
0005433568503	320	Economy	7200.00
0005433568502	320	Economy	7200.00
0005433568515	320	Economy	7200.00
0005433568523	320	Economy	7200.00
0005433568491	320	Economy	7200.00
0005433074219	320	Economy	7200.00
0005433568531	320	Economy	7200.00
0005432947864	320	Economy	7200.00
0005432948083	11586	Business	21500.00
0005433074442	11586	Business	21500.00
0005432948073	11586	Business	21500.00
0005433074445	11586	Business	21500.00
0005433074440	11586	Business	21500.00
0005433074454	11586	Business	21500.00
0005432948077	11586	Business	21500.00
0005432948071	11586	Business	21500.00
0005432948095	11586	Business	21500.00
0005432948057	11586	Business	21500.00
0005433074458	11586	Business	21500.00
0005432948068	11586	Business	21500.00
0005432948093	11586	Business	21500.00
0005433074449	11586	Business	21500.00
0005432192291	11586	Business	21500.00
0005433134095	11586	Business	21500.00
0005432948067	11586	Economy	7900.00
0005433568055	11586	Economy	7900.00
0005432948076	11586	Economy	7200.00
0005432948074	11586	Economy	7200.00
0005433074450	11586	Economy	7200.00
0005432948082	11586	Economy	7200.00
0005432948061	11586	Economy	7200.00
0005432948096	11586	Economy	7200.00
0005432948058	11586	Economy	7200.00
0005433074452	11586	Economy	7200.00
0005433568037	11586	Economy	7200.00
0005433074438	11586	Economy	7200.00
0005433131667	11586	Economy	7200.00
0005433074432	11586	Economy	7200.00
0005433131665	11586	Economy	7200.00
0005432948069	11586	Economy	7200.00
0005432948078	11586	Economy	7200.00
0005433074455	11586	Economy	7200.00
0005432948092	11586	Economy	7200.00
0005432948064	11586	Economy	7200.00
0005433074446	11586	Economy	7200.00
0005432948065	11586	Economy	7200.00
0005432948056	11586	Economy	7200.00
0005433134097	11586	Economy	7200.00
0005432948072	11586	Economy	7200.00
0005433131663	11586	Economy	7200.00
0005433074443	11586	Economy	7200.00
0005432948088	11586	Economy	7200.00
0005433074453	11586	Economy	7200.00
0005432948086	11586	Economy	7200.00
0005433074444	11586	Economy	7900.00
0005433074433	11586	Economy	7900.00
0005432948081	11586	Economy	7900.00
0005432948063	11586	Economy	7200.00
0005432948062	11586	Economy	7200.00
0005433074439	11586	Economy	7200.00
0005432948075	11586	Economy	7200.00
0005432192290	11586	Economy	7900.00
0005432948087	11586	Economy	7200.00
0005432948080	11586	Economy	7200.00
0005433074434	11586	Economy	7200.00
0005433074437	11586	Economy	7200.00
0005433074456	11586	Economy	7200.00
0005433074435	11586	Economy	7200.00
0005432948079	11586	Economy	7200.00
0005433131666	11586	Economy	7200.00
0005433568054	11586	Economy	7200.00
0005432948055	11586	Economy	7200.00
0005433074448	11586	Economy	7200.00
0005433131664	11586	Economy	7200.00
0005433568051	11586	Economy	7200.00
0005433074457	11586	Economy	7200.00
0005432948091	11586	Economy	7200.00
0005433074441	11586	Economy	7200.00
0005432948084	11586	Economy	7200.00
0005433134096	11586	Economy	7200.00
0005432948085	11586	Economy	7200.00
0005433074431	11586	Economy	7200.00
0005432948070	11586	Economy	7200.00
0005432948089	11586	Economy	7200.00
0005432948094	11586	Economy	7200.00
0005432948060	11586	Economy	7200.00
0005433074451	11586	Economy	7200.00
0005433074447	11586	Economy	7200.00
0005432948059	11586	Economy	7200.00
0005432948090	11586	Economy	7200.00
0005432948066	11586	Economy	7200.00
0005433074436	11586	Economy	7200.00
0005433817436	9979	Economy	6300.00
0005433817435	9979	Economy	6300.00
0005434732924	9979	Economy	6300.00
0005434732925	9979	Economy	6300.00
0005433817437	9979	Economy	6300.00
0005434732923	9979	Economy	6300.00
0005434732948	13997	Economy	6300.00
0005434732949	13997	Economy	6300.00
0005434732950	13997	Economy	6300.00
0005434732947	13997	Economy	6300.00
0005433753690	2365	Business	184500.00
0005432655427	2365	Business	184500.00
0005433753712	2365	Business	184500.00
0005433753697	2365	Business	184500.00
0005435981890	2365	Business	184500.00
0005433753724	2365	Business	184500.00
0005433764661	2365	Business	184500.00
0005435981893	2365	Business	184500.00
0005433753689	2365	Business	184500.00
0005435981909	2365	Business	184500.00
0005433753720	2365	Business	184500.00
0005432225999	2365	Business	184500.00
0005433753686	2365	Business	184500.00
0005432300210	2365	Business	184500.00
0005432984570	2365	Business	184500.00
0005432984615	2365	Business	184500.00
0005433766604	2365	Business	184500.00
0005433753699	2365	Business	184500.00
0005435981912	2365	Business	184500.00
0005433753738	2365	Business	184500.00
0005432655430	2365	Business	184500.00
0005433753719	2365	Business	184500.00
0005432226001	2365	Business	184500.00
0005432984561	2365	Business	184500.00
0005432300209	2365	Business	184500.00
0005435981916	2365	Economy	67700.00
0005435981908	2365	Economy	67700.00
0005435981913	2365	Economy	67700.00
0005435981907	2365	Economy	61500.00
0005432655431	2365	Economy	61500.00
0005435981900	2365	Economy	61500.00
0005433753692	2365	Economy	61500.00
0005433753726	2365	Economy	61500.00
0005432300213	2365	Economy	61500.00
0005433753732	2365	Economy	61500.00
0005432869412	2365	Economy	61500.00
0005433434204	2365	Economy	61500.00
0005435981898	2365	Economy	61500.00
0005433753721	2365	Economy	61500.00
0005432984625	2365	Economy	61500.00
0005435981921	2365	Economy	61500.00
0005432869421	2365	Economy	61500.00
0005432225997	2365	Economy	61500.00
0005432984524	2365	Economy	61500.00
0005433434245	2365	Economy	61500.00
0005433753702	2365	Economy	61500.00
0005432984520	2365	Economy	61500.00
0005432984606	2365	Economy	61500.00
0005432300208	2365	Economy	61500.00
0005432984566	2365	Economy	61500.00
0005433434243	2365	Economy	61500.00
0005435981891	2365	Economy	61500.00
0005435981923	2365	Economy	61500.00
0005432984557	2365	Economy	61500.00
0005433766603	2365	Economy	61500.00
0005435981914	2365	Economy	61500.00
0005433434224	2365	Economy	61500.00
0005433766607	2365	Economy	61500.00
0005432655432	2365	Economy	61500.00
0005433766605	2365	Economy	61500.00
0005433753698	2365	Economy	61500.00
0005433434199	2365	Economy	61500.00
0005433434207	2365	Economy	61500.00
0005435981892	2365	Economy	61500.00
0005435981896	2365	Economy	61500.00
0005433434220	2365	Economy	61500.00
0005434731104	2365	Economy	61500.00
0005432655428	2365	Economy	61500.00
0005432655426	2365	Economy	61500.00
0005433753708	2365	Economy	61500.00
0005435981920	2365	Economy	61500.00
0005432869430	2365	Economy	61500.00
0005432984626	2365	Economy	61500.00
0005435981911	2365	Economy	61500.00
0005435981899	2365	Economy	61500.00
0005435981889	2365	Economy	61500.00
0005433434214	2365	Economy	61500.00
0005433753737	2365	Economy	61500.00
0005433753729	2365	Economy	61500.00
0005432984569	2365	Economy	61500.00
0005432984544	2365	Economy	61500.00
0005435981922	2365	Economy	61500.00
0005432300212	2365	Economy	61500.00
0005432984575	2365	Economy	61500.00
0005433753688	2365	Economy	61500.00
0005433434238	2365	Economy	61500.00
0005432655429	2365	Economy	61500.00
0005435981897	2365	Economy	61500.00
0005432655425	2365	Economy	61500.00
0005433753711	2365	Economy	61500.00
0005433753714	2365	Economy	61500.00
0005432984616	2365	Economy	61500.00
0005433753709	2365	Economy	61500.00
0005433753735	2365	Economy	61500.00
0005432984503	2365	Economy	61500.00
0005433753722	2365	Economy	61500.00
0005433434282	2365	Economy	61500.00
0005433753685	2365	Economy	61500.00
0005435981905	2365	Economy	61500.00
0005435981918	2365	Economy	61500.00
0005433753683	2365	Economy	61500.00
0005433753707	2365	Economy	61500.00
0005432984605	2365	Economy	61500.00
0005432655423	2365	Economy	61500.00
0005433753723	2365	Economy	67700.00
0005435981917	2365	Economy	61500.00
0005433753682	2365	Economy	61500.00
0005433434213	2365	Economy	61500.00
0005435981894	2365	Economy	67700.00
0005433753684	2365	Economy	67700.00
0005432984614	2365	Economy	61500.00
0005432655433	2365	Economy	61500.00
0005433753696	2365	Economy	61500.00
0005433753728	2365	Economy	61500.00
0005433753715	2365	Economy	61500.00
0005435981904	2365	Economy	61500.00
0005433753730	2365	Economy	61500.00
0005433753705	2365	Economy	61500.00
0005433434232	2365	Economy	61500.00
0005435981902	2365	Economy	61500.00
0005435981915	2365	Economy	61500.00
0005433753693	2365	Economy	61500.00
0005432655435	2365	Economy	61500.00
0005432984567	2365	Economy	61500.00
0005433766606	2365	Economy	61500.00
0005435981906	2365	Economy	61500.00
0005432225998	2365	Economy	61500.00
0005433753717	2365	Economy	61500.00
0005432984522	2365	Economy	61500.00
0005433434244	2365	Economy	61500.00
0005432655424	2365	Economy	61500.00
0005432984521	2365	Economy	61500.00
0005433434272	2365	Economy	61500.00
0005433764660	2365	Economy	61500.00
0005432869424	2365	Economy	61500.00
0005432984624	2365	Economy	61500.00
0005432655434	2365	Economy	61500.00
0005432984540	2365	Economy	61500.00
0005433434237	2365	Economy	61500.00
0005435981903	2365	Economy	61500.00
0005432869425	2365	Economy	61500.00
0005432869427	2365	Economy	61500.00
0005433753731	2365	Economy	61500.00
0005432300211	2365	Economy	61500.00
0005435981910	2365	Economy	61500.00
0005433753727	2365	Economy	61500.00
0005433434283	2365	Economy	61500.00
0005433753695	2365	Economy	61500.00
0005433753716	2365	Economy	61500.00
0005433753734	2365	Economy	61500.00
0005435981895	2365	Economy	61500.00
0005432984508	2365	Economy	61500.00
0005432226002	2365	Economy	61500.00
0005433753713	2365	Economy	61500.00
0005433753691	2365	Economy	61500.00
0005432984525	2365	Economy	61500.00
0005433753706	2365	Economy	61500.00
0005435981901	2365	Economy	61500.00
0005435981919	2365	Economy	61500.00
0005433753733	2365	Economy	61500.00
0005433434205	2365	Economy	61500.00
0005433753704	2365	Economy	61500.00
0005433753700	2365	Economy	61500.00
0005433434206	2365	Economy	61500.00
0005433434225	2365	Economy	61500.00
0005433753710	2365	Economy	61500.00
0005432226000	2365	Economy	61500.00
0005433753718	2365	Economy	61500.00
0005433434192	2365	Economy	61500.00
0005433753694	2365	Economy	61500.00
0005433753687	2365	Economy	61500.00
0005433753701	2365	Economy	61500.00
0005433753703	2365	Economy	61500.00
0005432984537	2365	Economy	61500.00
0005433753725	2365	Economy	61500.00
0005433753736	2365	Economy	61500.00
0005433753252	26192	Business	184500.00
0005432049430	26192	Business	184500.00
0005435981629	26192	Business	184500.00
0005432984785	26192	Business	184500.00
0005433753329	26192	Business	184500.00
0005433434437	26192	Business	184500.00
0005433434411	26192	Business	184500.00
0005435981514	26192	Business	184500.00
0005433766583	26192	Business	184500.00
0005433434429	26192	Business	184500.00
0005433753470	26192	Business	184500.00
0005432984796	26192	Business	184500.00
0005432869462	26192	Business	184500.00
0005434731130	26192	Business	184500.00
0005433753383	26192	Business	184500.00
0005433434419	26192	Business	184500.00
0005432869463	26192	Economy	67700.00
0005433434412	26192	Economy	67700.00
0005433434415	26192	Economy	67700.00
0005433764651	26192	Economy	61500.00
0005434731131	26192	Economy	61500.00
0005432984773	26192	Economy	61500.00
0005432984793	26192	Economy	61500.00
0005432984775	26192	Economy	61500.00
0005433753253	26192	Economy	61500.00
0005432984774	26192	Economy	61500.00
0005432984794	26192	Economy	61500.00
0005432984770	26192	Economy	61500.00
0005432049432	26192	Economy	61500.00
0005432869460	26192	Economy	61500.00
0005433753232	26192	Economy	61500.00
0005433434434	26192	Economy	61500.00
0005433753354	26192	Economy	61500.00
0005433753251	26192	Economy	61500.00
0005433753345	26192	Economy	61500.00
0005434731134	26192	Economy	61500.00
0005432984768	26192	Economy	61500.00
0005435981641	26192	Economy	61500.00
0005432869459	26192	Economy	61500.00
0005432984786	26192	Economy	61500.00
0005433434438	26192	Economy	61500.00
0005433766573	26192	Economy	61500.00
0005432655340	26192	Economy	61500.00
0005433753370	26192	Economy	61500.00
0005433753385	26192	Economy	61500.00
0005435981509	26192	Economy	61500.00
0005432984769	26192	Economy	61500.00
0005433434433	26192	Economy	61500.00
0005433434435	26192	Economy	61500.00
0005432984782	26192	Economy	61500.00
0005433753328	26192	Economy	61500.00
0005432984788	26192	Economy	61500.00
0005432984776	26192	Economy	61500.00
0005432655341	26192	Economy	61500.00
0005432051100	26192	Economy	61500.00
0005435981518	26192	Economy	61500.00
0005432984790	26192	Economy	61500.00
0005433753379	26192	Economy	61500.00
0005433434416	26192	Economy	61500.00
0005432984792	26192	Economy	61500.00
0005432984781	26192	Economy	61500.00
0005433753406	26192	Economy	61500.00
0005433753267	26192	Economy	61500.00
0005434731133	26192	Economy	61500.00
0005433753284	26192	Economy	61500.00
0005433766575	26192	Economy	61500.00
0005433434421	26192	Economy	61500.00
0005432984795	26192	Economy	61500.00
0005432051098	26192	Economy	61500.00
0005432984772	26192	Economy	61500.00
0005432984780	26192	Economy	61500.00
0005432984798	26192	Economy	61500.00
0005433434427	26192	Economy	61500.00
0005433434417	26192	Economy	61500.00
0005433434428	26192	Economy	61500.00
0005433434420	26192	Economy	61500.00
0005433753231	26192	Economy	61500.00
0005434731132	26192	Economy	67700.00
0005433434423	26192	Economy	61500.00
0005432984791	26192	Economy	67700.00
0005432984766	26192	Economy	61500.00
0005433434418	26192	Economy	61500.00
0005433434436	26192	Economy	61500.00
0005433753384	26192	Economy	61500.00
0005432984771	26192	Economy	61500.00
0005432869464	26192	Economy	61500.00
0005432984777	26192	Economy	61500.00
0005432984778	26192	Economy	61500.00
0005432869461	26192	Economy	61500.00
0005432984784	26192	Economy	61500.00
0005433434431	26192	Economy	61500.00
0005432984797	26192	Economy	61500.00
0005433753418	26192	Economy	61500.00
0005432984783	26192	Economy	61500.00
0005433434410	26192	Economy	61500.00
0005433753266	26192	Economy	61500.00
0005432984787	26192	Economy	61500.00
0005433434425	26192	Economy	61500.00
0005433434432	26192	Economy	61500.00
0005433753233	26192	Economy	61500.00
0005433766584	26192	Economy	61500.00
0005432051099	26192	Economy	61500.00
0005433434414	26192	Economy	61500.00
0005432984779	26192	Economy	61500.00
0005432049431	26192	Economy	61500.00
0005433434413	26192	Economy	61500.00
0005432984789	26192	Economy	61500.00
0005435981559	26192	Economy	61500.00
0005435981564	26192	Economy	61500.00
0005433753442	26192	Economy	61500.00
0005433766574	26192	Economy	61500.00
0005433434424	26192	Economy	61500.00
0005433753378	26192	Economy	61500.00
0005432984767	26192	Economy	61500.00
0005433434422	26192	Economy	61500.00
0005433753277	26192	Economy	61500.00
0005435981563	26192	Economy	61500.00
0005433434426	26192	Economy	61500.00
0005433434430	26192	Economy	61500.00
0005435981527	26192	Economy	61500.00
0005433150924	1530	Business	38900.00
0005434374218	1530	Business	38900.00
0005434374233	1530	Business	38900.00
0005434374220	1530	Business	38900.00
0005433460416	1530	Business	38900.00
0005434374236	1530	Business	38900.00
0005434374203	1530	Business	38900.00
0005434374215	1530	Business	38900.00
0005433460418	1530	Business	38900.00
0005434374213	1530	Business	38900.00
0005433764646	1530	Business	38900.00
0005434374230	1530	Economy	13000.00
0005432267832	1530	Economy	13000.00
0005433150925	1530	Economy	13000.00
0005434374209	1530	Economy	13000.00
0005433150901	1530	Economy	13000.00
0005434374210	1530	Economy	13000.00
0005434374238	1530	Economy	13000.00
0005433150847	1530	Economy	13000.00
0005433150797	1530	Economy	13000.00
0005432267833	1530	Economy	13000.00
0005433460417	1530	Economy	13000.00
0005434374227	1530	Economy	13000.00
0005434374199	1530	Economy	13000.00
0005433460415	1530	Economy	13000.00
0005434374248	1530	Economy	13000.00
0005434374251	1530	Economy	13000.00
0005434374232	1530	Economy	13000.00
0005433150839	1530	Economy	13000.00
0005434374247	1530	Economy	13000.00
0005434374226	1530	Economy	13000.00
0005433150862	1530	Economy	13000.00
0005432267836	1530	Economy	13000.00
0005434374243	1530	Economy	13000.00
0005432267835	1530	Economy	14300.00
0005433150880	1530	Economy	14300.00
0005434374249	1530	Economy	14300.00
0005434374214	1530	Economy	14300.00
0005433461569	1530	Economy	13000.00
0005434374237	1530	Economy	13000.00
0005433461568	1530	Economy	13000.00
0005434374223	1530	Economy	13000.00
0005433150886	1530	Economy	13000.00
0005432267834	1530	Economy	13000.00
0005434374242	1530	Economy	13000.00
0005433150900	1530	Economy	13000.00
0005434374224	1530	Economy	13000.00
0005433150846	1530	Economy	13000.00
0005434374234	1530	Economy	13000.00
0005434374204	1530	Economy	13000.00
0005433931421	1530	Economy	13000.00
0005434374208	1530	Economy	13000.00
0005434374217	1530	Economy	13000.00
0005434374216	1530	Economy	13000.00
0005433150956	1530	Economy	13000.00
0005434374212	1530	Economy	13000.00
0005434374211	1530	Economy	13000.00
0005434374246	1530	Economy	13000.00
0005434374231	1530	Economy	13000.00
0005433150863	1530	Economy	13000.00
0005434374198	1530	Economy	13000.00
0005434374200	1530	Economy	13000.00
0005433150879	1530	Economy	13000.00
0005434374207	1530	Economy	13000.00
0005434374202	1530	Economy	13000.00
0005434374239	1530	Economy	13000.00
0005434374225	1530	Economy	13000.00
0005433150976	1530	Economy	13000.00
0005434374235	1530	Economy	13000.00
0005433150845	1530	Economy	13000.00
0005434374205	1530	Economy	13000.00
0005433764645	1530	Economy	13000.00
0005433150935	1530	Economy	13000.00
0005434374240	1530	Economy	13000.00
0005434374222	1530	Economy	13000.00
0005434374221	1530	Economy	13000.00
0005434374244	1530	Economy	13000.00
0005434374245	1530	Economy	13000.00
0005434374228	1530	Economy	13000.00
0005434374229	1530	Economy	13000.00
0005433150878	1530	Economy	13000.00
0005432267837	1530	Economy	13000.00
0005434374206	1530	Economy	13000.00
0005433150955	1530	Economy	13000.00
0005433931422	1530	Economy	13000.00
0005434374219	1530	Economy	13000.00
0005432267831	1530	Economy	13000.00
0005434374241	1530	Economy	13000.00
0005434374250	1530	Economy	13000.00
0005434374201	1530	Economy	13000.00
0005434374197	1530	Economy	13000.00
0005433151106	20111	Business	38900.00
0005433764661	20111	Business	38900.00
0005433151083	20111	Business	38900.00
0005433151088	20111	Business	38900.00
0005433151089	20111	Business	38900.00
0005433151096	20111	Business	38900.00
0005434029634	20111	Economy	13000.00
0005433151078	20111	Economy	13000.00
0005434373980	20111	Economy	13000.00
0005434373912	20111	Economy	13000.00
0005434373861	20111	Economy	13000.00
0005433151077	20111	Economy	13000.00
0005434373919	20111	Economy	13000.00
0005433151098	20111	Economy	13000.00
0005434374033	20111	Economy	13000.00
0005433151093	20111	Economy	13000.00
0005433151082	20111	Economy	13000.00
0005433151100	20111	Economy	13000.00
0005433151090	20111	Economy	13000.00
0005433151099	20111	Economy	13000.00
0005434374038	20111	Economy	13000.00
0005434373851	20111	Economy	13000.00
0005434373850	20111	Economy	13000.00
0005433931436	20111	Economy	13000.00
0005434374006	20111	Economy	13000.00
0005433151079	20111	Economy	13000.00
0005433151094	20111	Economy	13000.00
0005433151076	20111	Economy	13000.00
0005432056265	20111	Economy	13000.00
0005434373913	20111	Economy	13000.00
0005434374046	20111	Economy	13000.00
0005433151084	20111	Economy	13000.00
0005433151081	20111	Economy	14300.00
0005433151102	20111	Economy	14300.00
0005433151087	20111	Economy	14300.00
0005434373984	20111	Economy	13000.00
0005433151101	20111	Economy	13000.00
0005433151075	20111	Economy	13000.00
0005433151095	20111	Economy	13000.00
0005433931439	20111	Economy	13000.00
0005433151080	20111	Economy	13000.00
0005433151092	20111	Economy	13000.00
0005433931438	20111	Economy	13000.00
0005434373856	20111	Economy	13000.00
0005433151108	20111	Economy	13000.00
0005433151103	20111	Economy	13000.00
0005433151104	20111	Economy	13000.00
0005433151109	20111	Economy	13000.00
0005433931437	20111	Economy	13000.00
0005434373911	20111	Economy	13000.00
0005433151085	20111	Economy	13000.00
0005434374037	20111	Economy	13000.00
0005434373936	20111	Economy	13000.00
0005433151091	20111	Economy	13000.00
0005434373977	20111	Economy	13000.00
0005434374024	20111	Economy	13000.00
0005433151086	20111	Economy	13000.00
0005432056262	20111	Economy	13000.00
0005434373898	20111	Economy	13000.00
0005433764660	20111	Economy	13000.00
0005434373891	20111	Economy	13000.00
0005434029633	20111	Economy	13000.00
0005434373918	20111	Economy	13000.00
0005432056264	20111	Economy	13000.00
0005433151097	20111	Economy	13000.00
0005434373954	20111	Economy	13000.00
0005434373853	20111	Economy	13000.00
0005433151105	20111	Economy	13000.00
0005433151107	20111	Economy	13000.00
0005432056263	20111	Economy	13000.00
0005432424026	518	Business	27500.00
0005432424029	518	Business	27500.00
0005432424003	518	Business	27500.00
0005432424034	518	Business	27500.00
0005432424053	518	Business	27500.00
0005432282798	518	Business	27500.00
0005432424039	518	Business	27500.00
0005432424035	518	Business	27500.00
0005432424046	518	Business	27500.00
0005432424027	518	Business	27500.00
0005432424050	518	Business	27500.00
0005432424001	518	Business	27500.00
0005432424047	518	Economy	10100.00
0005432424004	518	Economy	9200.00
0005432424015	518	Economy	9200.00
0005432424009	518	Economy	9200.00
0005432424018	518	Economy	9200.00
0005432424022	518	Economy	9200.00
0005432424044	518	Economy	9200.00
0005432424051	518	Economy	9200.00
0005432424010	518	Economy	9200.00
0005432424041	518	Economy	9200.00
0005432424005	518	Economy	9200.00
0005432424055	518	Economy	9200.00
0005432424040	518	Economy	9200.00
0005432424054	518	Economy	9200.00
0005432424052	518	Economy	9200.00
0005432424030	518	Economy	9200.00
0005432424038	518	Economy	9200.00
0005432424011	518	Economy	9200.00
0005432424014	518	Economy	9200.00
0005432424021	518	Economy	9200.00
0005432424025	518	Economy	9200.00
0005432424057	518	Economy	9200.00
0005432282796	518	Economy	10100.00
0005432424037	518	Economy	9200.00
0005432424033	518	Economy	10100.00
0005432424024	518	Economy	9200.00
0005432424036	518	Economy	9200.00
0005432282802	518	Economy	9200.00
0005432424000	518	Economy	9200.00
0005432424002	518	Economy	9200.00
0005432282801	518	Economy	9200.00
0005432424042	518	Economy	9200.00
0005432424007	518	Economy	9200.00
0005432424020	518	Economy	9200.00
0005432424028	518	Economy	9200.00
0005432424043	518	Economy	9200.00
0005432424032	518	Economy	9200.00
0005432424017	518	Economy	9200.00
0005432424049	518	Economy	9200.00
0005432424019	518	Economy	9200.00
0005432424006	518	Economy	9200.00
0005432424016	518	Economy	9200.00
0005432424012	518	Economy	9200.00
0005432424045	518	Economy	9200.00
0005432424048	518	Economy	9200.00
0005432282797	518	Economy	9200.00
0005432424008	518	Economy	9200.00
0005432424031	518	Economy	9200.00
0005432282799	518	Economy	9200.00
0005432424013	518	Economy	9200.00
0005432424056	518	Economy	9200.00
0005432424023	518	Economy	9200.00
0005432282800	518	Economy	9200.00
0005432302296	12941	Economy	9200.00
0005432302297	12941	Economy	9200.00
0005434023075	438	Business	24500.00
0005433684384	438	Business	24500.00
0005434023121	438	Business	24500.00
0005432235568	438	Business	24500.00
0005434023065	438	Business	24500.00
0005434023069	438	Business	24500.00
0005434023091	438	Business	24500.00
0005434023082	438	Business	24500.00
0005432045593	438	Business	24500.00
0005434023096	438	Business	24500.00
0005434023105	438	Business	24500.00
0005434031976	438	Business	24500.00
0005432235572	438	Economy	9000.00
0005434023085	438	Economy	8200.00
0005434023057	438	Economy	8200.00
0005434031980	438	Economy	8200.00
0005434023062	438	Economy	8200.00
0005434023104	438	Economy	8200.00
0005434023083	438	Economy	8200.00
0005434023125	438	Economy	8200.00
0005434023124	438	Economy	8200.00
0005434023059	438	Economy	8200.00
0005434023063	438	Economy	8200.00
0005434023093	438	Economy	8200.00
0005434023078	438	Economy	8200.00
0005433057253	438	Economy	8200.00
0005434023074	438	Economy	8200.00
0005434029632	438	Economy	8200.00
0005434023092	438	Economy	8200.00
0005434023084	438	Economy	8200.00
0005434029630	438	Economy	8200.00
0005434023072	438	Economy	8200.00
0005434023106	438	Economy	8200.00
0005434023070	438	Economy	8200.00
0005434023079	438	Economy	8200.00
0005434023097	438	Economy	8200.00
0005434023086	438	Economy	8200.00
0005434023071	438	Economy	8200.00
0005434023073	438	Economy	8200.00
0005433057278	438	Economy	8200.00
0005434735597	438	Economy	8200.00
0005434023102	438	Economy	8200.00
0005434023088	438	Economy	8200.00
0005434023064	438	Economy	8200.00
0005432045594	438	Economy	8200.00
0005434023099	438	Economy	8200.00
0005434023101	438	Economy	8200.00
0005433057266	438	Economy	8200.00
0005434023111	438	Economy	8200.00
0005433057201	438	Economy	8200.00
0005434023108	438	Economy	8200.00
0005434031977	438	Economy	8200.00
0005434028267	438	Economy	8200.00
0005434023094	438	Economy	8200.00
0005434023087	438	Economy	8200.00
0005434028270	438	Economy	8200.00
0005434023118	438	Economy	8200.00
0005434023114	438	Economy	8200.00
0005434023123	438	Economy	8200.00
0005434031978	438	Economy	8200.00
0005433057299	438	Economy	8200.00
0005434023066	438	Economy	8200.00
0005434023103	438	Economy	8200.00
0005434023098	438	Economy	8200.00
0005433057269	438	Economy	8200.00
0005434023100	438	Economy	8200.00
0005434023076	438	Economy	8200.00
0005434023122	438	Economy	9000.00
0005434023119	438	Economy	8200.00
0005432235569	438	Economy	9000.00
0005434023117	438	Economy	8200.00
0005434023120	438	Economy	8200.00
0005434023107	438	Economy	8200.00
0005434023112	438	Economy	8200.00
0005434023060	438	Economy	8200.00
0005433057285	438	Economy	8200.00
0005433057300	438	Economy	8200.00
0005433057225	438	Economy	8200.00
0005434023055	438	Economy	8200.00
0005433057284	438	Economy	8200.00
0005433057171	438	Economy	8200.00
0005434023056	438	Economy	8200.00
0005434023061	438	Economy	8200.00
0005434023115	438	Economy	8200.00
0005432235570	438	Economy	8200.00
0005432045595	438	Economy	8200.00
0005434031979	438	Economy	8200.00
0005434028268	438	Economy	8200.00
0005434023090	438	Economy	8200.00
0005434023095	438	Economy	8200.00
0005434023067	438	Economy	8200.00
0005433057270	438	Economy	8200.00
0005434023110	438	Economy	8200.00
0005434023113	438	Economy	8200.00
0005433057226	438	Economy	8200.00
0005434023068	438	Economy	8200.00
0005433684385	438	Economy	8200.00
0005434023077	438	Economy	8200.00
0005434023058	438	Economy	8200.00
0005432235571	438	Economy	8200.00
0005433057186	438	Economy	8200.00
0005432235567	438	Economy	8200.00
0005433057346	438	Economy	8200.00
0005433057279	438	Economy	8200.00
0005434028269	438	Economy	8200.00
0005433057230	438	Economy	8200.00
0005434023109	438	Economy	8200.00
0005433057366	438	Economy	8200.00
0005434023116	438	Economy	8200.00
0005434023080	438	Economy	8200.00
0005434029631	438	Economy	8200.00
0005434023089	438	Economy	8200.00
0005434023081	438	Economy	8200.00
0005434022633	12690	Business	24500.00
0005432156324	12690	Business	24500.00
0005434022626	12690	Business	24500.00
0005433057500	12690	Business	24500.00
0005433929577	12690	Business	24500.00
0005434022676	12690	Business	24500.00
0005434022635	12690	Business	24500.00
0005433057530	12690	Business	24500.00
0005433057511	12690	Business	24500.00
0005434022529	12690	Business	24500.00
0005434022521	12690	Business	24500.00
0005433057527	12690	Business	24500.00
0005433057522	12690	Business	24500.00
0005433057510	12690	Business	24500.00
0005433057534	12690	Economy	9000.00
0005433057531	12690	Economy	8200.00
0005434022867	12690	Economy	9000.00
0005434022556	12690	Economy	8200.00
0005434022657	12690	Economy	8200.00
0005434022513	12690	Economy	8200.00
0005433057521	12690	Economy	8200.00
0005433057505	12690	Economy	8200.00
0005434022590	12690	Economy	8200.00
0005433057506	12690	Economy	8200.00
0005432156325	12690	Economy	8200.00
0005434022518	12690	Economy	8200.00
0005433057501	12690	Economy	8200.00
0005433057535	12690	Economy	8200.00
0005434022576	12690	Economy	8200.00
0005434022555	12690	Economy	8200.00
0005434022504	12690	Economy	8200.00
0005434022568	12690	Economy	8200.00
0005433057503	12690	Economy	8200.00
0005434022575	12690	Economy	8200.00
0005433057529	12690	Economy	8200.00
0005433057499	12690	Economy	8200.00
0005434022730	12690	Economy	8200.00
0005433057497	12690	Economy	8200.00
0005434031953	12690	Economy	8200.00
0005433057532	12690	Economy	8200.00
0005434022637	12690	Economy	8200.00
0005433929575	12690	Economy	8200.00
0005433057523	12690	Economy	8200.00
0005434022643	12690	Economy	8200.00
0005433057518	12690	Economy	8200.00
0005434735643	12690	Economy	8200.00
0005432157473	12690	Economy	8200.00
0005433057536	12690	Economy	8200.00
0005432157474	12690	Economy	8200.00
0005434022524	12690	Economy	8200.00
0005433057513	12690	Economy	8200.00
0005434022534	12690	Economy	8200.00
0005433929576	12690	Economy	8200.00
0005433684402	12690	Economy	8200.00
0005433057525	12690	Economy	8200.00
0005434022522	12690	Economy	8200.00
0005434022567	12690	Economy	8200.00
0005433057512	12690	Economy	8200.00
0005434022595	12690	Economy	8200.00
0005433057507	12690	Economy	8200.00
0005434022731	12690	Economy	8200.00
0005434022519	12690	Economy	8200.00
0005433929573	12690	Economy	8200.00
0005434022629	12690	Economy	8200.00
0005433057520	12690	Economy	8200.00
0005434022528	12690	Economy	9000.00
0005434022584	12690	Economy	8200.00
0005433057515	12690	Economy	9000.00
0005433057519	12690	Economy	8200.00
0005433057533	12690	Economy	8200.00
0005433057508	12690	Economy	8200.00
0005433057517	12690	Economy	8200.00
0005433057502	12690	Economy	8200.00
0005434022585	12690	Economy	8200.00
0005434022550	12690	Economy	8200.00
0005434022728	12690	Economy	8200.00
0005434022589	12690	Economy	8200.00
0005434022597	12690	Economy	8200.00
0005434022630	12690	Economy	8200.00
0005433057514	12690	Economy	8200.00
0005434022523	12690	Economy	8200.00
0005434735644	12690	Economy	8200.00
0005434022680	12690	Economy	8200.00
0005434031945	12690	Economy	8200.00
0005433057504	12690	Economy	8200.00
0005433057498	12690	Economy	8200.00
0005434022634	12690	Economy	8200.00
0005434022709	12690	Economy	8200.00
0005433057537	12690	Economy	8200.00
0005433057528	12690	Economy	8200.00
0005433684401	12690	Economy	8200.00
0005434735641	12690	Economy	8200.00
0005432156326	12690	Economy	8200.00
0005433057509	12690	Economy	8200.00
0005434735642	12690	Economy	8200.00
0005434022624	12690	Economy	8200.00
0005433057526	12690	Economy	8200.00
0005434022544	12690	Economy	8200.00
0005433929574	12690	Economy	8200.00
0005434022503	12690	Economy	8200.00
0005434022868	12690	Economy	8200.00
0005433057516	12690	Economy	8200.00
0005434022729	12690	Economy	8200.00
0005434022594	12690	Economy	8200.00
0005433057524	12690	Economy	8200.00
0005433922442	2116	Business	34700.00
0005432231463	2116	Business	34700.00
0005433922376	2116	Business	34700.00
0005433922448	2116	Business	34700.00
0005433931436	2116	Business	34700.00
0005433035365	2116	Business	34700.00
0005433922402	2116	Business	34700.00
0005433922453	2116	Business	34700.00
0005433922455	2116	Business	34700.00
0005433922421	2116	Business	34700.00
0005432231464	2116	Business	34700.00
0005433922397	2116	Business	34700.00
0005432749747	2116	Business	34700.00
0005432231467	2116	Economy	12700.00
0005433035463	2116	Economy	12700.00
0005433922461	2116	Economy	12700.00
0005433035602	2116	Economy	12700.00
0005433922404	2116	Economy	11600.00
0005433922435	2116	Economy	11600.00
0005433922465	2116	Economy	11600.00
0005433931437	2116	Economy	11600.00
0005433922425	2116	Economy	11600.00
0005433922375	2116	Economy	11600.00
0005432231471	2116	Economy	11600.00
0005433922440	2116	Economy	11600.00
0005433922406	2116	Economy	11600.00
0005433922392	2116	Economy	11600.00
0005433875364	2116	Economy	11600.00
0005433035392	2116	Economy	11600.00
0005433922382	2116	Economy	11600.00
0005433035461	2116	Economy	11600.00
0005432231470	2116	Economy	11600.00
0005433922464	2116	Economy	11600.00
0005433929574	2116	Economy	11600.00
0005433929575	2116	Economy	11600.00
0005433922420	2116	Economy	11600.00
0005433922378	2116	Economy	11600.00
0005433922419	2116	Economy	11600.00
0005432044499	2116	Economy	11600.00
0005433035473	2116	Economy	11600.00
0005433922437	2116	Economy	11600.00
0005433922429	2116	Economy	11600.00
0005433035363	2116	Economy	11600.00
0005433922393	2116	Economy	11600.00
0005433922388	2116	Economy	11600.00
0005433922417	2116	Economy	11600.00
0005433922463	2116	Economy	11600.00
0005433922396	2116	Economy	11600.00
0005433922468	2116	Economy	11600.00
0005433922434	2116	Economy	11600.00
0005433922452	2116	Economy	11600.00
0005433922407	2116	Economy	11600.00
0005433035375	2116	Economy	11600.00
0005433922428	2116	Economy	11600.00
0005433922431	2116	Economy	11600.00
0005433922449	2116	Economy	11600.00
0005433922390	2116	Economy	11600.00
0005433922447	2116	Economy	11600.00
0005433922451	2116	Economy	11600.00
0005433922408	2116	Economy	11600.00
0005433922385	2116	Economy	11600.00
0005433922460	2116	Economy	11600.00
0005433922426	2116	Economy	11600.00
0005433922400	2116	Economy	11600.00
0005433922424	2116	Economy	11600.00
0005433922456	2116	Economy	11600.00
0005433922381	2116	Economy	11600.00
0005433922446	2116	Economy	11600.00
0005433929577	2116	Economy	11600.00
0005433035440	2116	Economy	11600.00
0005432231462	2116	Economy	11600.00
0005433922395	2116	Economy	11600.00
0005433922416	2116	Economy	11600.00
0005433922414	2116	Economy	11600.00
0005433922433	2116	Economy	11600.00
0005433922383	2116	Economy	11600.00
0005433922430	2116	Economy	11600.00
0005433035356	2116	Economy	11600.00
0005433922418	2116	Economy	11600.00
0005433922457	2116	Economy	11600.00
0005432231468	2116	Economy	11600.00
0005433035474	2116	Economy	11600.00
0005432044498	2116	Economy	12700.00
0005433922458	2116	Economy	12700.00
0005433922469	2116	Economy	11600.00
0005433922403	2116	Economy	12700.00
0005433035519	2116	Economy	12700.00
0005433035424	2116	Economy	11600.00
0005433922439	2116	Economy	11600.00
0005433922427	2116	Economy	11600.00
0005433035528	2116	Economy	11600.00
0005433922405	2116	Economy	11600.00
0005432231465	2116	Economy	11600.00
0005433922409	2116	Economy	11600.00
0005433922422	2116	Economy	11600.00
0005433035357	2116	Economy	11600.00
0005433035366	2116	Economy	11600.00
0005433922377	2116	Economy	11600.00
0005433922379	2116	Economy	11600.00
0005433922401	2116	Economy	11600.00
0005433922387	2116	Economy	11600.00
0005433035368	2116	Economy	11600.00
0005433922445	2116	Economy	11600.00
0005433035513	2116	Economy	11600.00
0005432749748	2116	Economy	11600.00
0005433929573	2116	Economy	11600.00
0005433922384	2116	Economy	11600.00
0005433035576	2116	Economy	11600.00
0005433929576	2116	Economy	11600.00
0005433922391	2116	Economy	11600.00
0005433922374	2116	Economy	11600.00
0005433035567	2116	Economy	11600.00
0005433035408	2116	Economy	11600.00
0005433922466	2116	Economy	11600.00
0005433922389	2116	Economy	11600.00
0005433922411	2116	Economy	11600.00
0005433922459	2116	Economy	11600.00
0005433035557	2116	Economy	11600.00
0005433922413	2116	Economy	11600.00
0005433035460	2116	Economy	11600.00
0005433922410	2116	Economy	11600.00
0005433922441	2116	Economy	11600.00
0005433035385	2116	Economy	11600.00
0005433922398	2116	Economy	11600.00
0005433922399	2116	Economy	11600.00
0005433922450	2116	Economy	11600.00
0005433922462	2116	Economy	11600.00
0005432231469	2116	Economy	11600.00
0005433035462	2116	Economy	11600.00
0005433922432	2116	Economy	11600.00
0005433922443	2116	Economy	11600.00
0005433931439	2116	Economy	11600.00
0005433922467	2116	Economy	11600.00
0005432231466	2116	Economy	11600.00
0005433922386	2116	Economy	11600.00
0005433922436	2116	Economy	11600.00
0005433922412	2116	Economy	11600.00
0005433922380	2116	Economy	11600.00
0005433922415	2116	Economy	11600.00
0005433922454	2116	Economy	11600.00
0005433922394	2116	Economy	11600.00
0005433922444	2116	Economy	11600.00
0005433931438	2116	Economy	11600.00
0005433922438	2116	Economy	11600.00
0005432044500	2116	Economy	11600.00
0005433922423	2116	Economy	11600.00
0005433035833	24091	Business	34700.00
0005433921921	24091	Business	34700.00
0005433921931	24091	Business	34700.00
0005433035823	24091	Business	34700.00
0005434028272	24091	Business	34700.00
0005433921648	24091	Business	34700.00
0005433921908	24091	Business	34700.00
0005433921810	24091	Business	34700.00
0005433035800	24091	Business	34700.00
0005433921751	24091	Business	34700.00
0005433921867	24091	Business	34700.00
0005433921619	24091	Business	34700.00
0005433035807	24091	Business	34700.00
0005433921916	24091	Business	34700.00
0005433035817	24091	Business	34700.00
0005433035813	24091	Economy	12700.00
0005433035838	24091	Economy	11600.00
0005433035792	24091	Economy	11600.00
0005432749764	24091	Economy	11600.00
0005433921628	24091	Economy	11600.00
0005433035788	24091	Economy	11600.00
0005433921705	24091	Economy	11600.00
0005434028271	24091	Economy	11600.00
0005433035822	24091	Economy	11600.00
0005433035808	24091	Economy	11600.00
0005432206144	24091	Economy	11600.00
0005432206142	24091	Economy	11600.00
0005433035795	24091	Economy	11600.00
0005433922088	24091	Economy	11600.00
0005433921869	24091	Economy	11600.00
0005433922108	24091	Economy	11600.00
0005433035829	24091	Economy	11600.00
0005433035802	24091	Economy	11600.00
0005433921622	24091	Economy	11600.00
0005433035820	24091	Economy	11600.00
0005432749765	24091	Economy	11600.00
0005432749766	24091	Economy	11600.00
0005433921657	24091	Economy	11600.00
0005433921844	24091	Economy	11600.00
0005433921782	24091	Economy	11600.00
0005433035835	24091	Economy	11600.00
0005433035793	24091	Economy	11600.00
0005432207640	24091	Economy	11600.00
0005433929549	24091	Economy	11600.00
0005433921737	24091	Economy	11600.00
0005432206143	24091	Economy	11600.00
0005433035840	24091	Economy	11600.00
0005433035806	24091	Economy	11600.00
0005433921833	24091	Economy	11600.00
0005433921847	24091	Economy	11600.00
0005433921848	24091	Economy	11600.00
0005433921608	24091	Economy	11600.00
0005433035804	24091	Economy	11600.00
0005432207639	24091	Economy	11600.00
0005433921868	24091	Economy	11600.00
0005433921849	24091	Economy	11600.00
0005433921884	24091	Economy	11600.00
0005434028273	24091	Economy	11600.00
0005433921750	24091	Economy	11600.00
0005433921593	24091	Economy	11600.00
0005433035828	24091	Economy	11600.00
0005433035801	24091	Economy	11600.00
0005433035821	24091	Economy	11600.00
0005433035818	24091	Economy	11600.00
0005433921885	24091	Economy	11600.00
0005434028274	24091	Economy	11600.00
0005433921909	24091	Economy	11600.00
0005433035824	24091	Economy	11600.00
0005433035811	24091	Economy	11600.00
0005433921594	24091	Economy	11600.00
0005433921636	24091	Economy	11600.00
0005433921656	24091	Economy	11600.00
0005433035803	24091	Economy	11600.00
0005433922087	24091	Economy	11600.00
0005433931431	24091	Economy	11600.00
0005433035794	24091	Economy	11600.00
0005433921832	24091	Economy	12700.00
0005433921639	24091	Economy	12700.00
0005433035825	24091	Economy	11600.00
0005433035837	24091	Economy	11600.00
0005433035810	24091	Economy	11600.00
0005433035789	24091	Economy	11600.00
0005433921601	24091	Economy	11600.00
0005433035799	24091	Economy	11600.00
0005433035832	24091	Economy	11600.00
0005433035816	24091	Economy	11600.00
0005433035791	24091	Economy	11600.00
0005433035827	24091	Economy	11600.00
0005433035831	24091	Economy	11600.00
0005433035797	24091	Economy	11600.00
0005432207638	24091	Economy	11600.00
0005433035812	24091	Economy	11600.00
0005433035798	24091	Economy	11600.00
0005432207637	24091	Economy	11600.00
0005433035814	24091	Economy	11600.00
0005433921893	24091	Economy	11600.00
0005433035839	24091	Economy	11600.00
0005433035836	24091	Economy	11600.00
0005433035841	24091	Economy	11600.00
0005433035805	24091	Economy	11600.00
0005433921644	24091	Economy	11600.00
0005432206140	24091	Economy	11600.00
0005433921892	24091	Economy	11600.00
0005433035826	24091	Economy	11600.00
0005432206141	24091	Economy	11600.00
0005433921714	24091	Economy	11600.00
0005433921774	24091	Economy	11600.00
0005433035796	24091	Economy	11600.00
0005433921739	24091	Economy	11600.00
0005433035830	24091	Economy	11600.00
0005433921602	24091	Economy	11600.00
0005433035809	24091	Economy	11600.00
0005433921738	24091	Economy	11600.00
0005433921845	24091	Economy	11600.00
0005433035819	24091	Economy	11600.00
0005433035790	24091	Economy	11600.00
0005433035815	24091	Economy	11600.00
0005433035834	24091	Economy	11600.00
0005433180729	279	Business	83700.00
0005434724324	279	Business	83700.00
0005434724391	279	Business	83700.00
0005434724342	279	Business	83700.00
0005434724381	279	Business	83700.00
0005434735636	279	Business	83700.00
0005434724407	279	Business	83700.00
0005434550759	279	Business	83700.00
0005433233141	279	Business	83700.00
0005434550718	279	Business	83700.00
0005434724377	279	Business	83700.00
0005434724335	279	Business	83700.00
0005432277681	279	Business	83700.00
0005434724388	279	Business	83700.00
0005433180690	279	Business	83700.00
0005432277682	279	Business	83700.00
0005434550706	279	Business	83700.00
0005434550720	279	Business	83700.00
0005434724319	279	Comfort	47400.00
0005432277690	279	Comfort	47400.00
0005434724417	279	Comfort	47400.00
0005434550732	279	Comfort	47400.00
0005434724389	279	Comfort	47400.00
0005434302420	279	Comfort	47400.00
0005434724343	279	Comfort	47400.00
0005434724376	279	Comfort	47400.00
0005434724327	279	Comfort	47400.00
0005434550748	279	Comfort	47400.00
0005434550708	279	Comfort	47400.00
0005434550745	279	Comfort	47400.00
0005434550726	279	Comfort	47400.00
0005433233152	279	Comfort	47400.00
0005434550719	279	Comfort	47400.00
0005434550761	279	Comfort	47400.00
0005435142454	279	Comfort	47400.00
0005434735638	279	Comfort	47400.00
0005434724334	279	Comfort	47400.00
0005434550749	279	Comfort	47400.00
0005434724375	279	Comfort	47400.00
0005433233308	279	Comfort	47400.00
0005433233089	279	Comfort	47400.00
0005434724314	279	Comfort	47400.00
0005434724367	279	Comfort	47400.00
0005435142447	279	Comfort	47400.00
0005432277679	279	Comfort	47400.00
0005434550723	279	Comfort	47400.00
0005433126774	279	Comfort	47400.00
0005434550711	279	Comfort	47400.00
0005434724310	279	Comfort	47400.00
0005433180680	279	Economy	27900.00
0005434724419	279	Economy	27900.00
0005434724387	279	Economy	27900.00
0005434724333	279	Economy	27900.00
0005434724332	279	Economy	27900.00
0005434550752	279	Economy	27900.00
0005435142449	279	Economy	27900.00
0005434735640	279	Economy	27900.00
0005434550747	279	Economy	27900.00
0005434724406	279	Economy	27900.00
0005434550713	279	Economy	27900.00
0005434550721	279	Economy	27900.00
0005434302418	279	Economy	27900.00
0005434724401	279	Economy	27900.00
0005434724356	279	Economy	27900.00
0005434724330	279	Economy	27900.00
0005434724374	279	Economy	27900.00
0005434724395	279	Economy	27900.00
0005434724312	279	Economy	27900.00
0005433180734	279	Economy	27900.00
0005434724390	279	Economy	27900.00
0005433233441	279	Economy	27900.00
0005434735637	279	Economy	27900.00
0005434550735	279	Economy	27900.00
0005434724422	279	Economy	27900.00
0005434550740	279	Economy	27900.00
0005434724412	279	Economy	27900.00
0005432277689	279	Economy	27900.00
0005434724328	279	Economy	27900.00
0005433111467	279	Economy	27900.00
0005434724416	279	Economy	27900.00
0005434550731	279	Economy	27900.00
0005434550736	279	Economy	27900.00
0005435142448	279	Economy	27900.00
0005432277686	279	Economy	27900.00
0005434724399	279	Economy	27900.00
0005433289728	279	Economy	27900.00
0005434724366	279	Economy	27900.00
0005434550734	279	Economy	27900.00
0005434724347	279	Economy	27900.00
0005435142456	279	Economy	27900.00
0005435142452	279	Economy	27900.00
0005435142457	279	Economy	27900.00
0005434724346	279	Economy	27900.00
0005434724370	279	Economy	27900.00
0005434724413	279	Economy	30700.00
0005432277687	279	Economy	27900.00
0005434724371	279	Economy	27900.00
0005434550737	279	Economy	27900.00
0005434724340	279	Economy	27900.00
0005434724415	279	Economy	30700.00
0005434731128	279	Economy	27900.00
0005433233096	279	Economy	27900.00
0005434724360	279	Economy	27900.00
0005434724380	279	Economy	27900.00
0005434724364	279	Economy	27900.00
0005434550756	279	Economy	27900.00
0005434724397	279	Economy	27900.00
0005434550722	279	Economy	27900.00
0005433180728	279	Economy	27900.00
0005434724368	279	Economy	27900.00
0005435142450	279	Economy	27900.00
0005434735639	279	Economy	27900.00
0005434550739	279	Economy	27900.00
0005433131632	279	Economy	27900.00
0005434724386	279	Economy	27900.00
0005433233310	279	Economy	27900.00
0005434724350	279	Economy	27900.00
0005434724349	279	Economy	27900.00
0005433233176	279	Economy	27900.00
0005434724421	279	Economy	27900.00
0005434550727	279	Economy	27900.00
0005433233293	279	Economy	27900.00
0005434724382	279	Economy	27900.00
0005434550709	279	Economy	27900.00
0005434724383	279	Economy	27900.00
0005434724423	279	Economy	27900.00
0005434724369	279	Economy	27900.00
0005433289729	279	Economy	27900.00
0005434724302	279	Economy	27900.00
0005434550733	279	Economy	27900.00
0005432277685	279	Economy	27900.00
0005434724400	279	Economy	27900.00
0005434724301	279	Economy	27900.00
0005434550755	279	Economy	27900.00
0005434550753	279	Economy	27900.00
0005434724361	279	Economy	27900.00
0005434724384	279	Economy	27900.00
0005434724352	279	Economy	27900.00
0005433126775	279	Economy	27900.00
0005434724398	279	Economy	27900.00
0005434302419	279	Economy	27900.00
0005434550707	279	Economy	27900.00
0005434724344	279	Economy	27900.00
0005434731126	279	Economy	27900.00
0005433233178	279	Economy	27900.00
0005434550729	279	Economy	27900.00
0005433233135	279	Economy	27900.00
0005433126776	279	Economy	27900.00
0005434724420	279	Economy	27900.00
0005434724408	279	Economy	27900.00
0005434724307	279	Economy	27900.00
0005434724365	279	Economy	27900.00
0005434724378	279	Economy	27900.00
0005434550762	279	Economy	27900.00
0005434724405	279	Economy	27900.00
0005433233087	279	Economy	27900.00
0005433233082	279	Economy	27900.00
0005434550754	279	Economy	27900.00
0005434550712	279	Economy	27900.00
0005434724362	279	Economy	27900.00
0005434724379	279	Economy	27900.00
0005434550742	279	Economy	27900.00
0005434550746	279	Economy	27900.00
0005432277691	279	Economy	27900.00
0005434724323	279	Economy	27900.00
0005434724414	279	Economy	27900.00
0005434724359	279	Economy	27900.00
0005434550714	279	Economy	27900.00
0005434724410	279	Economy	27900.00
0005434724358	279	Economy	27900.00
0005434724326	279	Economy	27900.00
0005434724318	279	Economy	27900.00
0005433113495	279	Economy	27900.00
0005434550725	279	Economy	27900.00
0005434724331	279	Economy	27900.00
0005434724311	279	Economy	27900.00
0005433233083	279	Economy	27900.00
0005434550724	279	Economy	27900.00
0005434550730	279	Economy	27900.00
0005434724325	279	Economy	27900.00
0005434724315	279	Economy	27900.00
0005433233088	279	Economy	27900.00
0005435142451	279	Economy	27900.00
0005434724393	279	Economy	27900.00
0005434724404	279	Economy	27900.00
0005434724305	279	Economy	30700.00
0005433233311	279	Economy	30700.00
0005434724411	279	Economy	30700.00
0005434724317	279	Economy	27900.00
0005434550738	279	Economy	27900.00
0005433233395	279	Economy	27900.00
0005434724321	279	Economy	27900.00
0005434724372	279	Economy	27900.00
0005434724308	279	Economy	27900.00
0005434724354	279	Economy	27900.00
0005434724355	279	Economy	27900.00
0005435142453	279	Economy	27900.00
0005433233332	279	Economy	27900.00
0005435142459	279	Economy	27900.00
0005434724357	279	Economy	27900.00
0005434724418	279	Economy	27900.00
0005434724409	279	Economy	27900.00
0005433233165	279	Economy	27900.00
0005435142455	279	Economy	27900.00
0005434724353	279	Economy	27900.00
0005434724348	279	Economy	27900.00
0005434724402	279	Economy	27900.00
0005433233161	279	Economy	27900.00
0005434550744	279	Economy	27900.00
0005434550715	279	Economy	27900.00
0005434724329	279	Economy	27900.00
0005434550717	279	Economy	27900.00
0005434550743	279	Economy	27900.00
0005434724385	279	Economy	27900.00
0005434550760	279	Economy	27900.00
0005434724394	279	Economy	27900.00
0005434550750	279	Economy	27900.00
0005433233171	279	Economy	27900.00
0005432277688	279	Economy	27900.00
0005434731127	279	Economy	27900.00
0005434550741	279	Economy	27900.00
0005433233153	279	Economy	27900.00
0005433233164	279	Economy	27900.00
0005435142458	279	Economy	27900.00
0005434724313	279	Economy	27900.00
0005434724351	279	Economy	27900.00
0005434550757	279	Economy	27900.00
0005434724320	279	Economy	27900.00
0005434724424	279	Economy	27900.00
0005434724309	279	Economy	27900.00
0005432277683	279	Economy	27900.00
0005434724303	279	Economy	27900.00
0005432277684	279	Economy	27900.00
0005433289730	279	Economy	27900.00
0005434724316	279	Economy	27900.00
0005434724392	279	Economy	27900.00
0005433233191	279	Economy	27900.00
0005434724322	279	Economy	27900.00
0005433180668	279	Economy	27900.00
0005433233116	279	Economy	27900.00
0005434550710	279	Economy	27900.00
0005434724341	279	Economy	27900.00
0005434724336	279	Economy	27900.00
0005434724403	279	Economy	27900.00
0005434724425	279	Economy	27900.00
0005434550728	279	Economy	27900.00
0005434724338	279	Economy	27900.00
0005434724396	279	Economy	27900.00
0005433180743	279	Economy	27900.00
0005434731129	279	Economy	27900.00
0005433233140	279	Economy	27900.00
0005434724363	279	Economy	27900.00
0005434724339	279	Economy	27900.00
0005434550716	279	Economy	27900.00
0005434724304	279	Economy	27900.00
0005434724337	279	Economy	27900.00
0005433131633	279	Economy	27900.00
0005434724306	279	Economy	27900.00
0005434550758	279	Economy	27900.00
0005434724373	279	Economy	27900.00
0005434724345	279	Economy	27900.00
0005432277680	279	Economy	27900.00
0005433233179	279	Economy	27900.00
0005433233312	279	Economy	27900.00
0005434550751	279	Economy	27900.00
0005433766606	9870	Business	83700.00
0005433233600	9870	Business	83700.00
0005433180880	9870	Business	83700.00
0005434723813	9870	Business	83700.00
0005434723515	9870	Business	83700.00
0005433126800	9870	Business	83700.00
0005432199180	9870	Business	83700.00
0005434723627	9870	Business	83700.00
0005433233613	9870	Business	83700.00
0005434723557	9870	Business	83700.00
0005434723378	9870	Business	83700.00
0005433289783	9870	Business	83700.00
0005434723468	9870	Business	83700.00
0005433180873	9870	Business	83700.00
0005433233626	9870	Business	83700.00
0005433180860	9870	Business	83700.00
0005434031984	9870	Business	83700.00
0005433233647	9870	Business	83700.00
0005434723758	9870	Business	83700.00
0005434723558	9870	Business	83700.00
0005434723481	9870	Comfort	47400.00
0005434723855	9870	Comfort	47400.00
0005433233639	9870	Comfort	47400.00
0005432199185	9870	Comfort	47400.00
0005434723644	9870	Comfort	47400.00
0005433233630	9870	Comfort	47400.00
0005433233651	9870	Comfort	47400.00
0005433233615	9870	Comfort	47400.00
0005433113515	9870	Comfort	47400.00
0005432199182	9870	Comfort	47400.00
0005435142342	9870	Comfort	47400.00
0005434550458	9870	Comfort	47400.00
0005434723338	9870	Comfort	47400.00
0005433233597	9870	Comfort	47400.00
0005433233607	9870	Comfort	47400.00
0005434723320	9870	Comfort	47400.00
0005434731104	9870	Comfort	47400.00
0005433233595	9870	Comfort	47400.00
0005433129232	9870	Comfort	47400.00
0005433233610	9870	Comfort	47400.00
0005434550363	9870	Comfort	47400.00
0005433233643	9870	Comfort	47400.00
0005434723528	9870	Comfort	47400.00
0005433233648	9870	Comfort	47400.00
0005433233609	9870	Comfort	47400.00
0005434723469	9870	Economy	27900.00
0005434550327	9870	Economy	27900.00
0005433233646	9870	Economy	27900.00
0005433233601	9870	Economy	27900.00
0005433233653	9870	Economy	27900.00
0005433180876	9870	Economy	27900.00
0005433233633	9870	Economy	27900.00
0005433180879	9870	Economy	27900.00
0005433233596	9870	Economy	27900.00
0005433289784	9870	Economy	27900.00
0005432199183	9870	Economy	27900.00
0005433289776	9870	Economy	27900.00
0005434550381	9870	Economy	27900.00
0005434723851	9870	Economy	27900.00
0005434723871	9870	Economy	27900.00
0005434723802	9870	Economy	27900.00
0005433233632	9870	Economy	27900.00
0005433766607	9870	Economy	27900.00
0005434723966	9870	Economy	27900.00
0005434723608	9870	Economy	27900.00
0005433180869	9870	Economy	27900.00
0005433233656	9870	Economy	27900.00
0005434723411	9870	Economy	27900.00
0005433233606	9870	Economy	27900.00
0005432199186	9870	Economy	27900.00
0005433233640	9870	Economy	27900.00
0005433233605	9870	Economy	27900.00
0005434723814	9870	Economy	27900.00
0005434723912	9870	Economy	27900.00
0005432199181	9870	Economy	27900.00
0005433233657	9870	Economy	27900.00
0005434723351	9870	Economy	27900.00
0005434723410	9870	Economy	27900.00
0005434723497	9870	Economy	27900.00
0005433180859	9870	Economy	27900.00
0005434550516	9870	Economy	27900.00
0005434550498	9870	Economy	27900.00
0005434550362	9870	Economy	27900.00
0005434550276	9870	Economy	27900.00
0005433126803	9870	Economy	27900.00
0005433233612	9870	Economy	27900.00
0005433233617	9870	Economy	27900.00
0005433233619	9870	Economy	27900.00
0005433180878	9870	Economy	27900.00
0005434723358	9870	Economy	30700.00
0005434723498	9870	Economy	27900.00
0005433289782	9870	Economy	30700.00
0005433233645	9870	Economy	27900.00
0005433113513	9870	Economy	27900.00
0005434723516	9870	Economy	27900.00
0005433180874	9870	Economy	27900.00
0005434723314	9870	Economy	27900.00
0005433113514	9870	Economy	27900.00
0005434723647	9870	Economy	27900.00
0005434723823	9870	Economy	27900.00
0005433233621	9870	Economy	27900.00
0005434031981	9870	Economy	27900.00
0005434723354	9870	Economy	27900.00
0005433113516	9870	Economy	27900.00
0005433126801	9870	Economy	27900.00
0005434550275	9870	Economy	27900.00
0005434723657	9870	Economy	27900.00
0005434550319	9870	Economy	27900.00
0005434723500	9870	Economy	27900.00
0005433129234	9870	Economy	27900.00
0005434723329	9870	Economy	27900.00
0005434550285	9870	Economy	27900.00
0005433180858	9870	Economy	27900.00
0005433180861	9870	Economy	27900.00
0005433180877	9870	Economy	27900.00
0005434723431	9870	Economy	27900.00
0005434723439	9870	Economy	27900.00
0005434031983	9870	Economy	27900.00
0005433233642	9870	Economy	27900.00
0005434550266	9870	Economy	27900.00
0005433126802	9870	Economy	27900.00
0005434550313	9870	Economy	27900.00
0005433233622	9870	Economy	27900.00
0005434723850	9870	Economy	27900.00
0005433233604	9870	Economy	27900.00
0005434723643	9870	Economy	27900.00
0005434723445	9870	Economy	27900.00
0005434723337	9870	Economy	27900.00
0005433233637	9870	Economy	27900.00
0005433233627	9870	Economy	27900.00
0005434723473	9870	Economy	27900.00
0005434723630	9870	Economy	27900.00
0005433180864	9870	Economy	27900.00
0005433180866	9870	Economy	27900.00
0005433233658	9870	Economy	27900.00
0005433233598	9870	Economy	27900.00
0005433289778	9870	Economy	27900.00
0005433233629	9870	Economy	27900.00
0005434723453	9870	Economy	27900.00
0005434723319	9870	Economy	27900.00
0005434723822	9870	Economy	27900.00
0005433233623	9870	Economy	27900.00
0005434031982	9870	Economy	27900.00
0005434723757	9870	Economy	27900.00
0005433233649	9870	Economy	27900.00
0005433233641	9870	Economy	27900.00
0005433180870	9870	Economy	27900.00
0005434723522	9870	Economy	27900.00
0005434723471	9870	Economy	27900.00
0005434723315	9870	Economy	27900.00
0005434550273	9870	Economy	27900.00
0005433129235	9870	Economy	27900.00
0005432199188	9870	Economy	27900.00
0005434723631	9870	Economy	27900.00
0005433129233	9870	Economy	27900.00
0005433233628	9870	Economy	27900.00
0005434723330	9870	Economy	27900.00
0005435142335	9870	Economy	27900.00
0005433766604	9870	Economy	27900.00
0005433180856	9870	Economy	27900.00
0005433233603	9870	Economy	27900.00
0005434723321	9870	Economy	27900.00
0005433289781	9870	Economy	30700.00
0005433180872	9870	Economy	30700.00
0005434723735	9870	Economy	30700.00
0005433289785	9870	Economy	27900.00
0005433233636	9870	Economy	27900.00
0005434550274	9870	Economy	27900.00
0005433233655	9870	Economy	27900.00
0005433233634	9870	Economy	27900.00
0005434723424	9870	Economy	27900.00
0005433233625	9870	Economy	27900.00
0005433233652	9870	Economy	27900.00
0005433233654	9870	Economy	27900.00
0005434550312	9870	Economy	27900.00
0005433233624	9870	Economy	27900.00
0005434550457	9870	Economy	27900.00
0005434550515	9870	Economy	27900.00
0005434723480	9870	Economy	27900.00
0005434723847	9870	Economy	27900.00
0005434723607	9870	Economy	27900.00
0005435142362	9870	Economy	27900.00
0005433233635	9870	Economy	27900.00
0005434735614	9870	Economy	27900.00
0005433180862	9870	Economy	27900.00
0005433233631	9870	Economy	27900.00
0005434723535	9870	Economy	27900.00
0005434723590	9870	Economy	27900.00
0005433233620	9870	Economy	27900.00
0005434723852	9870	Economy	27900.00
0005434723451	9870	Economy	27900.00
0005433289780	9870	Economy	27900.00
0005434550297	9870	Economy	27900.00
0005433289779	9870	Economy	27900.00
0005433233659	9870	Economy	27900.00
0005433233614	9870	Economy	27900.00
0005434550348	9870	Economy	27900.00
0005433180867	9870	Economy	27900.00
0005433180863	9870	Economy	27900.00
0005433766603	9870	Economy	27900.00
0005434723646	9870	Economy	27900.00
0005433233616	9870	Economy	27900.00
0005433233618	9870	Economy	27900.00
0005433180855	9870	Economy	27900.00
0005434723432	9870	Economy	27900.00
0005433233599	9870	Economy	27900.00
0005433180875	9870	Economy	27900.00
0005434031985	9870	Economy	27900.00
0005434723433	9870	Economy	27900.00
0005434723313	9870	Economy	27900.00
0005433289777	9870	Economy	27900.00
0005433180857	9870	Economy	27900.00
0005434550288	9870	Economy	27900.00
0005434550265	9870	Economy	27900.00
0005433233650	9870	Economy	27900.00
0005434723409	9870	Economy	27900.00
0005433766605	9870	Economy	27900.00
0005433180865	9870	Economy	27900.00
0005434550263	9870	Economy	27900.00
0005433233608	9870	Economy	27900.00
0005433233644	9870	Economy	27900.00
0005432199184	9870	Economy	27900.00
0005433233638	9870	Economy	27900.00
0005434723732	9870	Economy	27900.00
0005433180871	9870	Economy	27900.00
0005433180868	9870	Economy	27900.00
0005434723470	9870	Economy	27900.00
0005433233611	9870	Economy	27900.00
0005433233602	9870	Economy	27900.00
0005432199187	9870	Economy	27900.00
0005434723448	9870	Economy	27900.00
0005434550270	9870	Economy	27900.00
0005432526781	7775	Business	42100.00
0005432526733	7775	Business	42100.00
0005435212401	7775	Business	42100.00
0005432069521	7775	Business	42100.00
0005432069520	7775	Business	42100.00
0005434066877	7775	Business	42100.00
0005433656615	7775	Business	42100.00
0005435725520	7775	Business	42100.00
0005432526758	7775	Business	42100.00
0005435212530	7775	Business	42100.00
0005432526759	7775	Business	42100.00
0005434066926	7775	Business	42100.00
0005432069525	7775	Business	42100.00
0005432526833	7775	Business	42100.00
0005434066888	7775	Business	42100.00
0005432069528	7775	Business	42100.00
0005435212337	7775	Business	42100.00
0005435212448	7775	Comfort	23900.00
0005434066897	7775	Comfort	23900.00
0005432526795	7775	Comfort	23900.00
0005432526716	7775	Comfort	23900.00
0005432526772	7775	Comfort	23900.00
0005432526798	7775	Comfort	23900.00
0005434066887	7775	Comfort	23900.00
0005434066885	7775	Comfort	23900.00
0005432526745	7775	Comfort	23900.00
0005432526780	7775	Comfort	23900.00
0005435212373	7775	Comfort	23900.00
0005435725528	7775	Comfort	23900.00
0005432526836	7775	Comfort	23900.00
0005432526815	7775	Comfort	23900.00
0005432526736	7775	Comfort	23900.00
0005432526752	7775	Comfort	23900.00
0005432526787	7775	Comfort	23900.00
0005432526750	7775	Comfort	23900.00
0005434066916	7775	Comfort	23900.00
0005432526791	7775	Comfort	23900.00
0005434066919	7775	Comfort	23900.00
0005432526784	7775	Comfort	23900.00
0005432526755	7775	Comfort	23900.00
0005432069522	7775	Comfort	23900.00
0005435212412	7775	Comfort	23900.00
0005432069519	7775	Comfort	23900.00
0005432526763	7775	Comfort	23900.00
0005434066918	7775	Comfort	23900.00
0005432526831	7775	Comfort	23900.00
0005434066914	7775	Comfort	23900.00
0005432526819	7775	Comfort	23900.00
0005432526838	7775	Comfort	23900.00
0005432526777	7775	Economy	14000.00
0005432526811	7775	Economy	14000.00
0005432150121	7775	Economy	14000.00
0005435212374	7775	Economy	14000.00
0005432526807	7775	Economy	14000.00
0005434066909	7775	Economy	14000.00
0005432526809	7775	Economy	14000.00
0005432526711	7775	Economy	14000.00
0005434066930	7775	Economy	14000.00
0005432526710	7775	Economy	14000.00
0005432526751	7775	Economy	14000.00
0005434066945	7775	Economy	14000.00
0005434066901	7775	Economy	14000.00
0005432535788	7775	Economy	14000.00
0005432526740	7775	Economy	14000.00
0005432526778	7775	Economy	14000.00
0005434066895	7775	Economy	14000.00
0005432533264	7775	Economy	14000.00
0005432069517	7775	Economy	14000.00
0005435212381	7775	Economy	14000.00
0005435630914	7775	Economy	14000.00
0005432526767	7775	Economy	14000.00
0005434066886	7775	Economy	14000.00
0005432526834	7775	Economy	14000.00
0005432069516	7775	Economy	14000.00
0005432526729	7775	Economy	14000.00
0005434066898	7775	Economy	14000.00
0005432526722	7775	Economy	14000.00
0005432526732	7775	Economy	14000.00
0005434066917	7775	Economy	14000.00
0005434066908	7775	Economy	14000.00
0005432526837	7775	Economy	14000.00
0005432526822	7775	Economy	14000.00
0005432526718	7775	Economy	14000.00
0005435212446	7775	Economy	14000.00
0005434066927	7775	Economy	14000.00
0005434066905	7775	Economy	14000.00
0005432526810	7775	Economy	14000.00
0005432526816	7775	Economy	14000.00
0005434066920	7775	Economy	14000.00
0005434066881	7775	Economy	14000.00
0005435212340	7775	Economy	14000.00
0005432526792	7775	Economy	14000.00
0005434066934	7775	Economy	14000.00
0005435212422	7775	Economy	14000.00
0005432526743	7775	Economy	14000.00
0005432526790	7775	Economy	14000.00
0005432526827	7775	Economy	14000.00
0005432526720	7775	Economy	14000.00
0005435212640	7775	Economy	14000.00
0005434066913	7775	Economy	14000.00
0005434066933	7775	Economy	15400.00
0005432526782	7775	Economy	15400.00
0005432069524	7775	Economy	14000.00
0005432526764	7775	Economy	14000.00
0005432526754	7775	Economy	15400.00
0005432526756	7775	Economy	15400.00
0005432526735	7775	Economy	14000.00
0005434066944	7775	Economy	15400.00
0005432526741	7775	Economy	14000.00
0005432526805	7775	Economy	14000.00
0005432526802	7775	Economy	14000.00
0005432526824	7775	Economy	14000.00
0005435212344	7775	Economy	14000.00
0005434066878	7775	Economy	14000.00
0005432526761	7775	Economy	14000.00
0005432526818	7775	Economy	14000.00
0005432526793	7775	Economy	14000.00
0005434066935	7775	Economy	14000.00
0005432069526	7775	Economy	14000.00
0005432533265	7775	Economy	14000.00
0005432526713	7775	Economy	14000.00
0005434066882	7775	Economy	14000.00
0005432526747	7775	Economy	14000.00
0005432526820	7775	Economy	14000.00
0005434066900	7775	Economy	14000.00
0005432069527	7775	Economy	14000.00
0005432526749	7775	Economy	14000.00
0005434066946	7775	Economy	14000.00
0005434066876	7775	Economy	14000.00
0005434066911	7775	Economy	14000.00
0005435212380	7775	Economy	14000.00
0005435212593	7775	Economy	14000.00
0005432526774	7775	Economy	14000.00
0005432526823	7775	Economy	14000.00
0005432069513	7775	Economy	14000.00
0005432526783	7775	Economy	14000.00
0005434066929	7775	Economy	14000.00
0005432526804	7775	Economy	14000.00
0005432069518	7775	Economy	14000.00
0005434066880	7775	Economy	14000.00
0005435212359	7775	Economy	14000.00
0005432428898	7775	Economy	14000.00
0005434066938	7775	Economy	14000.00
0005434066932	7775	Economy	14000.00
0005432526768	7775	Economy	14000.00
0005434066884	7775	Economy	14000.00
0005432526730	7775	Economy	14000.00
0005432526832	7775	Economy	14000.00
0005435212342	7775	Economy	14000.00
0005432526794	7775	Economy	14000.00
0005432526788	7775	Economy	14000.00
0005432526766	7775	Economy	14000.00
0005432526796	7775	Economy	14000.00
0005432535790	7775	Economy	14000.00
0005434066879	7775	Economy	14000.00
0005434066903	7775	Economy	14000.00
0005432150119	7775	Economy	14000.00
0005432526771	7775	Economy	14000.00
0005432526719	7775	Economy	14000.00
0005434066893	7775	Economy	14000.00
0005432535786	7775	Economy	14000.00
0005434066912	7775	Economy	14000.00
0005432526708	7775	Economy	14000.00
0005432526724	7775	Economy	14000.00
0005432069523	7775	Economy	14000.00
0005435212397	7775	Economy	14000.00
0005432428897	7775	Economy	14000.00
0005435212360	7775	Economy	14000.00
0005432069515	7775	Economy	14000.00
0005432526817	7775	Economy	14000.00
0005432150125	7775	Economy	14000.00
0005434066921	7775	Economy	14000.00
0005434066941	7775	Economy	14000.00
0005432150122	7775	Economy	14000.00
0005432526739	7775	Economy	14000.00
0005435212400	7775	Economy	14000.00
0005434066915	7775	Economy	14000.00
0005435212423	7775	Economy	14000.00
0005432526821	7775	Economy	14000.00
0005432526765	7775	Economy	14000.00
0005434066943	7775	Economy	14000.00
0005432526748	7775	Economy	14000.00
0005432526814	7775	Economy	14000.00
0005434066904	7775	Economy	14000.00
0005434066889	7775	Economy	14000.00
0005432150123	7775	Economy	14000.00
0005434066923	7775	Economy	14000.00
0005434066940	7775	Economy	14000.00
0005432526738	7775	Economy	14000.00
0005435212639	7775	Economy	14000.00
0005432526829	7775	Economy	14000.00
0005432526773	7775	Economy	14000.00
0005432526728	7775	Economy	15400.00
0005432526714	7775	Economy	15400.00
0005432526712	7775	Economy	15400.00
0005432526826	7775	Economy	14000.00
0005432526785	7775	Economy	14000.00
0005434066906	7775	Economy	14000.00
0005434066910	7775	Economy	14000.00
0005432526746	7775	Economy	14000.00
0005432526770	7775	Economy	14000.00
0005432526744	7775	Economy	14000.00
0005435212584	7775	Economy	14000.00
0005432526799	7775	Economy	14000.00
0005435212498	7775	Economy	14000.00
0005432526742	7775	Economy	14000.00
0005432150118	7775	Economy	14000.00
0005432526840	7775	Economy	14000.00
0005434066907	7775	Economy	14000.00
0005435212413	7775	Economy	14000.00
0005435212368	7775	Economy	14000.00
0005432526707	7775	Economy	14000.00
0005432526801	7775	Economy	14000.00
0005432526769	7775	Economy	14000.00
0005432537038	7775	Economy	14000.00
0005435212414	7775	Economy	14000.00
0005434066924	7775	Economy	14000.00
0005432526828	7775	Economy	14000.00
0005434066896	7775	Economy	14000.00
0005432526808	7775	Economy	14000.00
0005432526715	7775	Economy	14000.00
0005432526803	7775	Economy	14000.00
0005435725511	7775	Economy	14000.00
0005434066939	7775	Economy	14000.00
0005432526789	7775	Economy	14000.00
0005434066890	7775	Economy	14000.00
0005432526753	7775	Economy	14000.00
0005435212341	7775	Economy	14000.00
0005432428895	7775	Economy	14000.00
0005434066947	7775	Economy	14000.00
0005432537037	7775	Economy	14000.00
0005432526737	7775	Economy	14000.00
0005434066942	7775	Economy	14000.00
0005432526757	7775	Economy	14000.00
0005432526760	7775	Economy	14000.00
0005435212531	7775	Economy	14000.00
0005432150124	7775	Economy	14000.00
0005434066883	7775	Economy	14000.00
0005432526825	7775	Economy	14000.00
0005432526723	7775	Economy	14000.00
0005432535789	7775	Economy	14000.00
0005432526725	7775	Economy	14000.00
0005432069514	7775	Economy	14000.00
0005432526731	7775	Economy	14000.00
0005434066899	7775	Economy	14000.00
0005434066902	7775	Economy	14000.00
0005435212338	7775	Economy	14000.00
0005432428896	7775	Economy	14000.00
0005434066891	7775	Economy	14000.00
0005432526806	7775	Economy	14000.00
0005434066928	7775	Economy	14000.00
0005432526779	7775	Economy	14000.00
0005432526734	7775	Economy	14000.00
0005432526813	7775	Economy	14000.00
0005432526726	7775	Economy	14000.00
0005432526800	7775	Economy	14000.00
0005434066937	7775	Economy	14000.00
0005432526717	7775	Economy	14000.00
0005434066892	7775	Economy	14000.00
0005432526709	7775	Economy	14000.00
0005434066925	7775	Economy	14000.00
0005434066936	7775	Economy	14000.00
0005432526775	7775	Economy	14000.00
0005432535787	7775	Economy	14000.00
0005432526776	7775	Economy	14000.00
0005432150120	7775	Economy	14000.00
0005432526797	7775	Economy	14000.00
0005432526839	7775	Economy	14000.00
0005432526786	7775	Economy	14000.00
0005432526830	7775	Economy	14000.00
0005432526835	7775	Economy	14000.00
0005435212407	7775	Economy	14000.00
0005434066922	7775	Economy	14000.00
0005434066931	7775	Economy	14000.00
0005432537036	7775	Economy	14000.00
0005434066894	7775	Economy	14000.00
0005432526721	7775	Economy	14000.00
0005432526727	7775	Economy	14000.00
0005432526812	7775	Economy	14000.00
0005432526762	7775	Economy	14000.00
0005435612648	5359	Business	43100.00
0005434343888	5359	Business	43100.00
0005435423647	5359	Business	43100.00
0005435423759	5359	Business	43100.00
0005435612620	5359	Business	43100.00
0005435423618	5359	Business	43100.00
0005435423819	5359	Business	43100.00
0005435612677	5359	Business	43100.00
0005435612621	5359	Business	43100.00
0005434343896	5359	Business	43100.00
0005435490192	5359	Business	43100.00
0005435612615	5359	Business	43100.00
0005435612646	5359	Business	43100.00
0005435423838	5359	Business	43100.00
0005434343875	5359	Business	43100.00
0005435612652	5359	Business	43100.00
0005434244550	5359	Business	43100.00
0005435612682	5359	Business	43100.00
0005435423729	5359	Business	43100.00
0005434244583	5359	Business	43100.00
0005434343877	5359	Business	43100.00
0005435319453	5359	Business	43100.00
0005434343892	5359	Business	43100.00
0005435304990	5359	Comfort	24400.00
0005434343900	5359	Comfort	24400.00
0005435612635	5359	Comfort	24400.00
0005435423833	5359	Comfort	24400.00
0005435612640	5359	Comfort	24400.00
0005432047516	5359	Comfort	24400.00
0005435097127	5359	Comfort	24400.00
0005434343876	5359	Comfort	24400.00
0005434244455	5359	Comfort	24400.00
0005434343881	5359	Comfort	24400.00
0005435612636	5359	Comfort	24400.00
0005434244462	5359	Comfort	24400.00
0005435423793	5359	Comfort	24400.00
0005435304991	5359	Comfort	24400.00
0005435612619	5359	Comfort	24400.00
0005435097120	5359	Comfort	24400.00
0005435423926	5359	Comfort	24400.00
0005434343891	5359	Comfort	24400.00
0005434244463	5359	Comfort	24400.00
0005435612617	5359	Comfort	24400.00
0005435423577	5359	Comfort	24400.00
0005435612679	5359	Comfort	24400.00
0005435097124	5359	Comfort	24400.00
0005435612667	5359	Comfort	24400.00
0005435423754	5359	Comfort	24400.00
0005434573217	5359	Comfort	24400.00
0005435423679	5359	Comfort	24400.00
0005434343899	5359	Comfort	24400.00
0005434573229	5359	Comfort	24400.00
0005434343910	5359	Comfort	24400.00
0005434573223	5359	Comfort	24400.00
0005435423617	5359	Comfort	24400.00
0005434343908	5359	Comfort	24400.00
0005435490193	5359	Comfort	24400.00
0005435612632	5359	Economy	14400.00
0005434244514	5359	Economy	14400.00
0005435097129	5359	Economy	14400.00
0005434573222	5359	Economy	14400.00
0005432133073	5359	Economy	14400.00
0005435612645	5359	Economy	14400.00
0005434343903	5359	Economy	14400.00
0005432133074	5359	Economy	14400.00
0005435612681	5359	Economy	14400.00
0005433719086	5359	Economy	14400.00
0005435423813	5359	Economy	14400.00
0005432133080	5359	Economy	14400.00
0005434343874	5359	Economy	14400.00
0005435612639	5359	Economy	14400.00
0005434343890	5359	Economy	14400.00
0005434573226	5359	Economy	14400.00
0005434244492	5359	Economy	14400.00
0005432133068	5359	Economy	14400.00
0005435612613	5359	Economy	14400.00
0005435423706	5359	Economy	14400.00
0005434244502	5359	Economy	14400.00
0005435319445	5359	Economy	14400.00
0005435612637	5359	Economy	14400.00
0005435491422	5359	Economy	14400.00
0005435612655	5359	Economy	14400.00
0005435612680	5359	Economy	14400.00
0005435423583	5359	Economy	14400.00
0005434343893	5359	Economy	14400.00
0005434244525	5359	Economy	14400.00
0005434244476	5359	Economy	14400.00
0005435380224	5359	Economy	14400.00
0005432363364	5359	Economy	14400.00
0005434656521	5359	Economy	14400.00
0005434573219	5359	Economy	14400.00
0005435423666	5359	Economy	14400.00
0005434573231	5359	Economy	14400.00
0005434573230	5359	Economy	14400.00
0005432133065	5359	Economy	14400.00
0005435612633	5359	Economy	14400.00
0005435097123	5359	Economy	14400.00
0005435097121	5359	Economy	14400.00
0005434343887	5359	Economy	14400.00
0005434573224	5359	Economy	14400.00
0005435612616	5359	Economy	14400.00
0005435423775	5359	Economy	14400.00
0005435423790	5359	Economy	14400.00
0005434343907	5359	Economy	14400.00
0005434244544	5359	Economy	14400.00
0005435612647	5359	Economy	14400.00
0005435097119	5359	Economy	14400.00
0005434573227	5359	Economy	14400.00
0005435319432	5359	Economy	14400.00
0005434573225	5359	Economy	14400.00
0005435612661	5359	Economy	14400.00
0005434343883	5359	Economy	14400.00
0005434343879	5359	Economy	14400.00
0005432047515	5359	Economy	14400.00
0005435612638	5359	Economy	14400.00
0005435423709	5359	Economy	14400.00
0005435424012	5359	Economy	14400.00
0005435612641	5359	Economy	14400.00
0005434343884	5359	Economy	14400.00
0005434343882	5359	Economy	14400.00
0005435612612	5359	Economy	14400.00
0005435423922	5359	Economy	14400.00
0005435612650	5359	Economy	14400.00
0005434573220	5359	Economy	14400.00
0005435423731	5359	Economy	14400.00
0005435423700	5359	Economy	14400.00
0005434244513	5359	Economy	14400.00
0005435423728	5359	Economy	14400.00
0005434343902	5359	Economy	14400.00
0005432840977	5359	Economy	14400.00
0005435612670	5359	Economy	14400.00
0005435555348	5359	Economy	14400.00
0005435612664	5359	Economy	14400.00
0005435612658	5359	Economy	14400.00
0005435612623	5359	Economy	14400.00
0005432133071	5359	Economy	14400.00
0005435612666	5359	Economy	14400.00
0005435612630	5359	Economy	14400.00
0005432133078	5359	Economy	14400.00
0005432133067	5359	Economy	14400.00
0005435423791	5359	Economy	14400.00
0005435380225	5359	Economy	14400.00
0005434573218	5359	Economy	14400.00
0005432133075	5359	Economy	14400.00
0005434244512	5359	Economy	14400.00
0005435612676	5359	Economy	14400.00
0005435097122	5359	Economy	14400.00
0005433719087	5359	Economy	14400.00
0005432133077	5359	Economy	14400.00
0005432133066	5359	Economy	14400.00
0005434244464	5359	Economy	14400.00
0005435612624	5359	Economy	14400.00
0005435097126	5359	Economy	14400.00
0005435612659	5359	Economy	14400.00
0005435612629	5359	Economy	14400.00
0005435612663	5359	Economy	14400.00
0005434244474	5359	Economy	14400.00
0005435612649	5359	Economy	14400.00
0005435612657	5359	Economy	14400.00
0005435302120	5359	Economy	14400.00
0005434343901	5359	Economy	14400.00
0005435612634	5359	Economy	14400.00
0005435423799	5359	Economy	14400.00
0005434244549	5359	Economy	14400.00
0005435612626	5359	Economy	14400.00
0005434343889	5359	Economy	14400.00
0005435612625	5359	Economy	14400.00
0005434244491	5359	Economy	14400.00
0005435423753	5359	Economy	14400.00
0005434343878	5359	Economy	14400.00
0005435612675	5359	Economy	14400.00
0005432133069	5359	Economy	14400.00
0005435319446	5359	Economy	14400.00
0005435423714	5359	Economy	14400.00
0005434343897	5359	Economy	14400.00
0005435423812	5359	Economy	14400.00
0005435612660	5359	Economy	14400.00
0005435423834	5359	Economy	14400.00
0005434343904	5359	Economy	14400.00
0005435612643	5359	Economy	14400.00
0005432133076	5359	Economy	14400.00
0005434244478	5359	Economy	14400.00
0005435319427	5359	Economy	14400.00
0005435424011	5359	Economy	14400.00
0005435423629	5359	Economy	14400.00
0005435612631	5359	Economy	14400.00
0005434244475	5359	Economy	14400.00
0005435423880	5359	Economy	15800.00
0005435423713	5359	Economy	15800.00
0005435423752	5359	Economy	15800.00
0005435612642	5359	Economy	14400.00
0005434343886	5359	Economy	14400.00
0005434343880	5359	Economy	14400.00
0005435423708	5359	Economy	14400.00
0005435612614	5359	Economy	14400.00
0005432133072	5359	Economy	14400.00
0005435097125	5359	Economy	14400.00
0005435555349	5359	Economy	14400.00
0005435423907	5359	Economy	14400.00
0005435491420	5359	Economy	14400.00
0005435423625	5359	Economy	14400.00
0005434343885	5359	Economy	14400.00
0005435612627	5359	Economy	14400.00
0005435612644	5359	Economy	14400.00
0005434343909	5359	Economy	14400.00
0005435491421	5359	Economy	14400.00
0005434343894	5359	Economy	14400.00
0005435612671	5359	Economy	14400.00
0005434656520	5359	Economy	14400.00
0005435423818	5359	Economy	14400.00
0005434244545	5359	Economy	14400.00
0005435612651	5359	Economy	14400.00
0005432133070	5359	Economy	14400.00
0005435423774	5359	Economy	14400.00
0005435612653	5359	Economy	14400.00
0005434343906	5359	Economy	14400.00
0005432840978	5359	Economy	14400.00
0005435612662	5359	Economy	14400.00
0005434244459	5359	Economy	14400.00
0005432133079	5359	Economy	14400.00
0005435490194	5359	Economy	14400.00
0005432363363	5359	Economy	14400.00
0005434244495	5359	Economy	14400.00
0005435555350	5359	Economy	14400.00
0005434343905	5359	Economy	14400.00
0005435612668	5359	Economy	14400.00
0005435612618	5359	Economy	14400.00
0005435423817	5359	Economy	14400.00
0005435612622	5359	Economy	14400.00
0005435423681	5359	Economy	14400.00
0005435423923	5359	Economy	14400.00
0005434573228	5359	Economy	14400.00
0005435612656	5359	Economy	14400.00
0005435423690	5359	Economy	14400.00
0005435423816	5359	Economy	14400.00
0005435423663	5359	Economy	14400.00
0005435612628	5359	Economy	14400.00
0005435097128	5359	Economy	14400.00
0005435612672	5359	Economy	14400.00
0005434244539	5359	Economy	14400.00
0005435612654	5359	Economy	14400.00
0005435423896	5359	Economy	14400.00
0005434573221	5359	Economy	14400.00
0005435612678	5359	Economy	14400.00
0005434343895	5359	Economy	14400.00
0005435423794	5359	Economy	14400.00
0005435423623	5359	Economy	14400.00
0005435423732	5359	Economy	14400.00
0005435612674	5359	Economy	14400.00
0005435612665	5359	Economy	14400.00
0005435612669	5359	Economy	14400.00
0005434343898	5359	Economy	14400.00
0005434244607	5359	Economy	14400.00
0005435612673	5359	Economy	14400.00
0005435423695	5359	Economy	14400.00
0005435423597	5359	Economy	14400.00
0005435611758	10930	Business	43100.00
0005435611709	10930	Business	43100.00
0005435424201	10930	Business	43100.00
0005435424177	10930	Business	43100.00
0005435424156	10930	Business	43100.00
0005435424203	10930	Business	43100.00
0005435424161	10930	Business	43100.00
0005434244709	10930	Business	43100.00
0005435424143	10930	Business	43100.00
0005434573129	10930	Business	43100.00
0005434573126	10930	Business	43100.00
0005435424184	10930	Business	43100.00
0005434573125	10930	Business	43100.00
0005434244699	10930	Comfort	24400.00
0005434244715	10930	Comfort	24400.00
0005435611760	10930	Comfort	24400.00
0005435611799	10930	Comfort	24400.00
0005432164966	10930	Comfort	24400.00
0005433719108	10930	Comfort	24400.00
0005434244701	10930	Comfort	24400.00
0005435490172	10930	Comfort	24400.00
0005434244707	10930	Comfort	24400.00
0005435424178	10930	Comfort	24400.00
0005435611837	10930	Comfort	24400.00
0005432164967	10930	Comfort	24400.00
0005435424204	10930	Comfort	24400.00
0005435424206	10930	Comfort	24400.00
0005434244712	10930	Comfort	24400.00
0005435424183	10930	Comfort	24400.00
0005435424205	10930	Comfort	24400.00
0005435491406	10930	Comfort	24400.00
0005435319494	10930	Comfort	24400.00
0005435424196	10930	Comfort	24400.00
0005435611740	10930	Comfort	24400.00
0005432363385	10930	Economy	14400.00
0005435424146	10930	Economy	14400.00
0005435424166	10930	Economy	14400.00
0005435424145	10930	Economy	14400.00
0005435424167	10930	Economy	14400.00
0005435424192	10930	Economy	14400.00
0005435424173	10930	Economy	14400.00
0005435424148	10930	Economy	14400.00
0005435424189	10930	Economy	14400.00
0005434244723	10930	Economy	14400.00
0005435319488	10930	Economy	14400.00
0005435424195	10930	Economy	14400.00
0005435490171	10930	Economy	14400.00
0005434244721	10930	Economy	14400.00
0005435319490	10930	Economy	14400.00
0005434244718	10930	Economy	14400.00
0005435424152	10930	Economy	14400.00
0005434244716	10930	Economy	14400.00
0005432363384	10930	Economy	14400.00
0005434573124	10930	Economy	14400.00
0005435611798	10930	Economy	14400.00
0005435611700	10930	Economy	14400.00
0005435611860	10930	Economy	14400.00
0005435424191	10930	Economy	14400.00
0005434244700	10930	Economy	14400.00
0005434244705	10930	Economy	14400.00
0005433719111	10930	Economy	14400.00
0005435424199	10930	Economy	14400.00
0005435424202	10930	Economy	14400.00
0005433719110	10930	Economy	14400.00
0005435319491	10930	Economy	14400.00
0005435319489	10930	Economy	15800.00
0005434244719	10930	Economy	15800.00
0005434244696	10930	Economy	14400.00
0005435380248	10930	Economy	14400.00
0005434244724	10930	Economy	14400.00
0005435424163	10930	Economy	14400.00
0005434244714	10930	Economy	14400.00
0005435424174	10930	Economy	14400.00
0005435424169	10930	Economy	14400.00
0005435424171	10930	Economy	14400.00
0005435424157	10930	Economy	14400.00
0005432363386	10930	Economy	14400.00
0005435611840	10930	Economy	14400.00
0005434244703	10930	Economy	14400.00
0005432166871	10930	Economy	14400.00
0005432840994	10930	Economy	14400.00
0005435424149	10930	Economy	14400.00
0005435424208	10930	Economy	14400.00
0005435611702	10930	Economy	14400.00
0005435611727	10930	Economy	14400.00
0005435611736	10930	Economy	14400.00
0005435490173	10930	Economy	14400.00
0005435424197	10930	Economy	14400.00
0005434244698	10930	Economy	14400.00
0005435424141	10930	Economy	14400.00
0005435424158	10930	Economy	14400.00
0005435424200	10930	Economy	14400.00
0005435424187	10930	Economy	14400.00
0005434244720	10930	Economy	14400.00
0005434573119	10930	Economy	14400.00
0005435424142	10930	Economy	14400.00
0005434244713	10930	Economy	14400.00
0005434244722	10930	Economy	14400.00
0005435424144	10930	Economy	14400.00
0005434573127	10930	Economy	14400.00
0005435611708	10930	Economy	14400.00
0005435424160	10930	Economy	14400.00
0005435319496	10930	Economy	14400.00
0005434573128	10930	Economy	14400.00
0005435611734	10930	Economy	14400.00
0005435380249	10930	Economy	14400.00
0005434244710	10930	Economy	14400.00
0005435611728	10930	Economy	14400.00
0005435490169	10930	Economy	14400.00
0005435611738	10930	Economy	14400.00
0005435380250	10930	Economy	14400.00
0005435611769	10930	Economy	14400.00
0005432164965	10930	Economy	14400.00
0005433719112	10930	Economy	14400.00
0005435424198	10930	Economy	14400.00
0005435611732	10930	Economy	14400.00
0005435611861	10930	Economy	14400.00
0005432164970	10930	Economy	14400.00
0005435611835	10930	Economy	14400.00
0005435611801	10930	Economy	14400.00
0005435424151	10930	Economy	14400.00
0005435424209	10930	Economy	14400.00
0005435611735	10930	Economy	14400.00
0005435319492	10930	Economy	14400.00
0005435611739	10930	Economy	14400.00
0005435424194	10930	Economy	14400.00
0005434573109	10930	Economy	14400.00
0005435380247	10930	Economy	14400.00
0005435424182	10930	Economy	14400.00
0005435424172	10930	Economy	14400.00
0005435611864	10930	Economy	14400.00
0005433719109	10930	Economy	14400.00
0005435424139	10930	Economy	14400.00
0005434244704	10930	Economy	14400.00
0005434244702	10930	Economy	14400.00
0005435319495	10930	Economy	14400.00
0005435319493	10930	Economy	14400.00
0005435424168	10930	Economy	14400.00
0005435424170	10930	Economy	14400.00
0005435424188	10930	Economy	14400.00
0005435611752	10930	Economy	14400.00
0005435424181	10930	Economy	14400.00
0005434573110	10930	Economy	14400.00
0005435424147	10930	Economy	14400.00
0005435611836	10930	Economy	14400.00
0005434244708	10930	Economy	14400.00
0005434343584	10930	Economy	14400.00
0005435424193	10930	Economy	14400.00
0005435424165	10930	Economy	14400.00
0005435611759	10930	Economy	14400.00
0005432164964	10930	Economy	14400.00
0005435611707	10930	Economy	14400.00
0005432164969	10930	Economy	14400.00
0005434244695	10930	Economy	14400.00
0005435611706	10930	Economy	14400.00
0005435611841	10930	Economy	14400.00
0005435611757	10930	Economy	14400.00
0005435611698	10930	Economy	14400.00
0005434244697	10930	Economy	14400.00
0005435319487	10930	Economy	14400.00
0005432363388	10930	Economy	14400.00
0005432164968	10930	Economy	14400.00
0005435424180	10930	Economy	14400.00
0005435611701	10930	Economy	14400.00
0005435424190	10930	Economy	14400.00
0005435042836	10930	Economy	14400.00
0005434244706	10930	Economy	14400.00
0005435611800	10930	Economy	14400.00
0005435424207	10930	Economy	14400.00
0005432840993	10930	Economy	14400.00
0005435380251	10930	Economy	14400.00
0005435424179	10930	Economy	14400.00
0005435424155	10930	Economy	14400.00
0005435424150	10930	Economy	14400.00
0005435424176	10930	Economy	14400.00
0005432363387	10930	Economy	14400.00
0005435424164	10930	Economy	14400.00
0005435424186	10930	Economy	14400.00
0005434244717	10930	Economy	14400.00
0005435424185	10930	Economy	14400.00
0005435424175	10930	Economy	14400.00
0005435611747	10930	Economy	14400.00
0005435424159	10930	Economy	14400.00
0005435424153	10930	Economy	14400.00
0005435611699	10930	Economy	14400.00
0005435424140	10930	Economy	14400.00
0005434244694	10930	Economy	14400.00
0005435042835	10930	Economy	14400.00
0005435424162	10930	Economy	14400.00
0005432166872	10930	Economy	14400.00
0005434244711	10930	Economy	14400.00
0005435424154	10930	Economy	14400.00
0005435611868	10930	Economy	14400.00
0005432181523	3359	Business	18800.00
0005432181511	3359	Business	18800.00
0005433507012	3359	Business	18800.00
0005432459077	3359	Business	18800.00
0005432459205	3359	Business	18800.00
0005433507018	3359	Business	18800.00
0005432181520	3359	Business	18800.00
0005432181506	3359	Business	18800.00
0005433805067	3359	Business	18800.00
0005433633499	3359	Business	18800.00
0005433507010	3359	Business	18800.00
0005432181517	3359	Business	18800.00
0005433633524	3359	Business	18800.00
0005433633501	3359	Business	18800.00
0005433633497	3359	Business	18800.00
0005433633522	3359	Business	18800.00
0005433805074	3359	Business	18800.00
0005432459096	3359	Business	18800.00
0005433633517	3359	Business	18800.00
0005432459217	3359	Business	18800.00
0005433633502	3359	Business	18800.00
0005433805076	3359	Business	18800.00
0005433805064	3359	Business	18800.00
0005432458960	3359	Economy	6900.00
0005432458965	3359	Economy	6900.00
0005432181508	3359	Economy	6900.00
0005433507007	3359	Economy	6900.00
0005433633519	3359	Economy	6300.00
0005433633494	3359	Economy	6300.00
0005432459038	3359	Economy	6300.00
0005433507002	3359	Economy	6300.00
0005433507013	3359	Economy	6300.00
0005432181504	3359	Economy	6300.00
0005433805075	3359	Economy	6300.00
0005433805055	3359	Economy	6300.00
0005433507003	3359	Economy	6300.00
0005433633525	3359	Economy	6300.00
0005433507020	3359	Economy	6300.00
0005433633496	3359	Economy	6300.00
0005433805054	3359	Economy	6300.00
0005433633509	3359	Economy	6300.00
0005432181505	3359	Economy	6300.00
0005433805070	3359	Economy	6300.00
0005433633506	3359	Economy	6300.00
0005433633518	3359	Economy	6300.00
0005432459121	3359	Economy	6300.00
0005432459227	3359	Economy	6300.00
0005432459103	3359	Economy	6300.00
0005432181516	3359	Economy	6300.00
0005433507014	3359	Economy	6300.00
0005433633504	3359	Economy	6300.00
0005433507019	3359	Economy	6300.00
0005432181522	3359	Economy	6300.00
0005433633516	3359	Economy	6300.00
0005433507022	3359	Economy	6300.00
0005432181509	3359	Economy	6300.00
0005433507008	3359	Economy	6300.00
0005433633492	3359	Economy	6300.00
0005433805059	3359	Economy	6300.00
0005433805056	3359	Economy	6300.00
0005433507004	3359	Economy	6300.00
0005432459025	3359	Economy	6300.00
0005433633520	3359	Economy	6300.00
0005433633495	3359	Economy	6300.00
0005433805072	3359	Economy	6300.00
0005433507023	3359	Economy	6300.00
0005432458967	3359	Economy	6300.00
0005432458978	3359	Economy	6300.00
0005433633523	3359	Economy	6300.00
0005433633513	3359	Economy	6300.00
0005432459061	3359	Economy	6300.00
0005432181503	3359	Economy	6900.00
0005433805062	3359	Economy	6900.00
0005433507021	3359	Economy	6900.00
0005433507006	3359	Economy	6300.00
0005433633498	3359	Economy	6300.00
0005433805051	3359	Economy	6300.00
0005433633512	3359	Economy	6900.00
0005432459037	3359	Economy	6300.00
0005432458973	3359	Economy	6300.00
0005433507005	3359	Economy	6300.00
0005432181510	3359	Economy	6300.00
0005433805060	3359	Economy	6300.00
0005433805047	3359	Economy	6300.00
0005432459060	3359	Economy	6300.00
0005433805061	3359	Economy	6300.00
0005433633503	3359	Economy	6300.00
0005433507009	3359	Economy	6300.00
0005433805071	3359	Economy	6300.00
0005433633510	3359	Economy	6300.00
0005433805069	3359	Economy	6300.00
0005433633493	3359	Economy	6300.00
0005433507015	3359	Economy	6300.00
0005432181521	3359	Economy	6300.00
0005433805068	3359	Economy	6300.00
0005433633508	3359	Economy	6300.00
0005433805048	3359	Economy	6300.00
0005432459036	3359	Economy	6300.00
0005432459100	3359	Economy	6300.00
0005433633511	3359	Economy	6300.00
0005432181513	3359	Economy	6300.00
0005432181515	3359	Economy	6300.00
0005433805066	3359	Economy	6300.00
0005433805073	3359	Economy	6300.00
0005432181512	3359	Economy	6300.00
0005433633500	3359	Economy	6300.00
0005432181507	3359	Economy	6300.00
0005432181519	3359	Economy	6300.00
0005433633514	3359	Economy	6300.00
0005432181514	3359	Economy	6300.00
0005433805065	3359	Economy	6300.00
0005433805050	3359	Economy	6300.00
0005433805057	3359	Economy	6300.00
0005433507016	3359	Economy	6300.00
0005433805049	3359	Economy	6300.00
0005432459097	3359	Economy	6300.00
0005432459101	3359	Economy	6300.00
0005433805052	3359	Economy	6300.00
0005432459226	3359	Economy	6300.00
0005433633526	3359	Economy	6300.00
0005433805063	3359	Economy	6300.00
0005433805058	3359	Economy	6300.00
0005433633507	3359	Economy	6300.00
0005432458968	3359	Economy	6300.00
0005433805053	3359	Economy	6300.00
0005433633521	3359	Economy	6300.00
0005432181518	3359	Economy	6300.00
0005433507011	3359	Economy	6300.00
0005433633505	3359	Economy	6300.00
0005433507017	3359	Economy	6300.00
0005433633515	3359	Economy	6300.00
0005435884555	3360	Business	18800.00
0005435884433	3360	Business	18800.00
0005435884575	3360	Business	18800.00
0005435884466	3360	Economy	6900.00
0005435884472	3360	Economy	6300.00
0005435884556	3360	Economy	6300.00
0005435884412	3360	Economy	6300.00
0005435884606	3360	Economy	6300.00
0005435884447	3360	Economy	6300.00
0005435884493	3360	Economy	6300.00
0005435884452	3360	Economy	6300.00
0005435884471	3360	Economy	6300.00
0005435884437	3360	Economy	6300.00
0005435884487	3360	Economy	6300.00
0005435884414	3360	Economy	6300.00
0005435884413	3360	Economy	6300.00
0005435884371	3360	Economy	6300.00
0005435884644	3360	Economy	6300.00
0005435884486	3360	Economy	6300.00
0005435884557	3360	Economy	6300.00
0005435884563	3360	Economy	6300.00
0005435884432	3360	Economy	6900.00
0005435884446	3360	Economy	6300.00
0005435884438	3360	Economy	6300.00
0005435884485	3360	Economy	6300.00
0005435884379	3360	Economy	6300.00
0005435884370	3360	Economy	6300.00
0005435884434	3360	Economy	6300.00
0005435884415	3360	Economy	6300.00
0005435884401	3360	Economy	6300.00
0005435884396	3360	Economy	6300.00
0005435884425	3360	Economy	6300.00
0005435884424	3360	Economy	6300.00
0005435884451	3360	Economy	6300.00
0005435884498	3360	Economy	6300.00
0005435884459	3360	Economy	6300.00
0005435884576	3360	Economy	6300.00
0005435884467	3360	Economy	6300.00
0005435884468	3360	Economy	6300.00
0005435884564	3360	Economy	6300.00
0005432459408	8221	Business	18800.00
0005432459426	8221	Business	18800.00
0005435884795	8221	Business	18800.00
0005432042588	8221	Business	18800.00
0005432459421	8221	Business	18800.00
0005435884773	8221	Business	18800.00
0005435884822	8221	Business	18800.00
0005435884821	8221	Business	18800.00
0005435884819	8221	Business	18800.00
0005432459398	8221	Business	18800.00
0005432459389	8221	Business	18800.00
0005432042589	8221	Business	18800.00
0005435884825	8221	Business	18800.00
0005435884809	8221	Business	18800.00
0005432459424	8221	Business	18800.00
0005432459436	8221	Business	18800.00
0005432459405	8221	Business	18800.00
0005435884797	8221	Business	18800.00
0005432459392	8221	Business	18800.00
0005432459431	8221	Business	18800.00
0005435884802	8221	Business	18800.00
0005433506910	8221	Business	18800.00
0005432042590	8221	Business	18800.00
0005432459384	8221	Business	18800.00
0005432459409	8221	Business	18800.00
0005435884784	8221	Business	18800.00
0005432459413	8221	Economy	6900.00
0005432459429	8221	Economy	6900.00
0005432459393	8221	Economy	6900.00
0005432459419	8221	Economy	6900.00
0005435884775	8221	Economy	6900.00
0005432459397	8221	Economy	6900.00
0005435884827	8221	Economy	6300.00
0005435884811	8221	Economy	6300.00
0005432459432	8221	Economy	6300.00
0005432459406	8221	Economy	6300.00
0005434326264	8221	Economy	6300.00
0005432459402	8221	Economy	6300.00
0005435884798	8221	Economy	6300.00
0005432459407	8221	Economy	6300.00
0005432459414	8221	Economy	6300.00
0005432459415	8221	Economy	6300.00
0005434312300	8221	Economy	6300.00
0005435884782	8221	Economy	6300.00
0005432042591	8221	Economy	6300.00
0005432459401	8221	Economy	6300.00
0005435884794	8221	Economy	6300.00
0005435884779	8221	Economy	6300.00
0005435884771	8221	Economy	6300.00
0005432042581	8221	Economy	6300.00
0005435884801	8221	Economy	6300.00
0005432042585	8221	Economy	6300.00
0005435884816	8221	Economy	6300.00
0005432459428	8221	Economy	6300.00
0005435884799	8221	Economy	6300.00
0005435884796	8221	Economy	6300.00
0005435884823	8221	Economy	6300.00
0005435884791	8221	Economy	6300.00
0005432459396	8221	Economy	6300.00
0005435884817	8221	Economy	6300.00
0005432459386	8221	Economy	6300.00
0005432459388	8221	Economy	6300.00
0005435884770	8221	Economy	6300.00
0005435884781	8221	Economy	6300.00
0005435884820	8221	Economy	6300.00
0005432459434	8221	Economy	6300.00
0005432459390	8221	Economy	6300.00
0005435884790	8221	Economy	6300.00
0005432459418	8221	Economy	6300.00
0005435884805	8221	Economy	6300.00
0005435884826	8221	Economy	6300.00
0005435884815	8221	Economy	6300.00
0005435884788	8221	Economy	6300.00
0005432459412	8221	Economy	6300.00
0005432459430	8221	Economy	6300.00
0005432459435	8221	Economy	6300.00
0005432042583	8221	Economy	6300.00
0005435884789	8221	Economy	6300.00
0005435884814	8221	Economy	6900.00
0005432459423	8221	Economy	6900.00
0005432459387	8221	Economy	6300.00
0005433506853	8221	Economy	6300.00
0005433506868	8221	Economy	6300.00
0005433506897	8221	Economy	6300.00
0005434312302	8221	Economy	6900.00
0005435884803	8221	Economy	6300.00
0005432459416	8221	Economy	6300.00
0005432042587	8221	Economy	6300.00
0005432042593	8221	Economy	6300.00
0005432459417	8221	Economy	6300.00
0005435884785	8221	Economy	6300.00
0005432459411	8221	Economy	6300.00
0005435884824	8221	Economy	6300.00
0005435884793	8221	Economy	6300.00
0005435884777	8221	Economy	6300.00
0005435884806	8221	Economy	6300.00
0005432042594	8221	Economy	6300.00
0005432459420	8221	Economy	6300.00
0005432459403	8221	Economy	6300.00
0005432459425	8221	Economy	6300.00
0005435884774	8221	Economy	6300.00
0005435884807	8221	Economy	6300.00
0005434312301	8221	Economy	6300.00
0005432042586	8221	Economy	6300.00
0005435884804	8221	Economy	6300.00
0005433506895	8221	Economy	6300.00
0005432459410	8221	Economy	6300.00
0005433506911	8221	Economy	6300.00
0005432459385	8221	Economy	6300.00
0005435884776	8221	Economy	6300.00
0005435884808	8221	Economy	6300.00
0005435884818	8221	Economy	6300.00
0005433506857	8221	Economy	6300.00
0005435884800	8221	Economy	6300.00
0005435884810	8221	Economy	6300.00
0005432042582	8221	Economy	6300.00
0005435884783	8221	Economy	6300.00
0005435884813	8221	Economy	6300.00
0005433506858	8221	Economy	6300.00
0005435884787	8221	Economy	6300.00
0005435884792	8221	Economy	6300.00
0005432459394	8221	Economy	6300.00
0005435884769	8221	Economy	6300.00
0005435884772	8221	Economy	6300.00
0005432459433	8221	Economy	6300.00
0005435884786	8221	Economy	6300.00
0005432042592	8221	Economy	6300.00
0005432459400	8221	Economy	6300.00
0005432459399	8221	Economy	6300.00
0005434326265	8221	Economy	6300.00
0005432042584	8221	Economy	6300.00
0005432459395	8221	Economy	6300.00
0005432459422	8221	Economy	6300.00
0005432459404	8221	Economy	6300.00
0005435884812	8221	Economy	6300.00
0005433506874	8221	Economy	6300.00
0005432459427	8221	Economy	6300.00
0005435884778	8221	Economy	6300.00
0005435884780	8221	Economy	6300.00
0005432459391	8221	Economy	6300.00
0005433804836	8219	Business	18800.00
0005433804938	8219	Business	18800.00
0005433804888	8219	Business	18800.00
0005433804889	8219	Business	18800.00
0005433804787	8219	Business	18800.00
0005433804922	8219	Business	18800.00
0005433804805	8219	Business	18800.00
0005433804788	8219	Economy	6900.00
0005433633249	8219	Economy	6900.00
0005433804807	8219	Economy	6300.00
0005433804799	8219	Economy	6300.00
0005433633255	8219	Economy	6300.00
0005433633412	8219	Economy	6300.00
0005434271281	8219	Economy	6300.00
0005433804777	8219	Economy	6300.00
0005433633321	8219	Economy	6300.00
0005433633322	8219	Economy	6300.00
0005433633277	8219	Economy	6300.00
0005433804781	8219	Economy	6300.00
0005433633278	8219	Economy	6300.00
0005433633411	8219	Economy	6300.00
0005433804800	8219	Economy	6300.00
0005433633220	8219	Economy	6300.00
0005433804830	8219	Economy	6300.00
0005433804868	8219	Economy	6300.00
0005433633226	8219	Economy	6300.00
0005433804829	8219	Economy	6300.00
0005433804778	8219	Economy	6300.00
0005433804847	8219	Economy	6300.00
0005432727826	4602	Business	9900.00
0005432382826	4602	Business	9900.00
0005433453746	4602	Business	9900.00
0005432382821	4602	Business	9900.00
0005432382816	4602	Business	9900.00
0005433453743	4602	Business	9900.00
0005432382838	4602	Business	9900.00
0005432382809	4602	Business	9900.00
0005432727827	4602	Business	9900.00
0005432382834	4602	Economy	3300.00
0005432382828	4602	Economy	3300.00
0005433194832	4602	Economy	3300.00
0005432382804	4602	Economy	3300.00
0005432382818	4602	Economy	3300.00
0005432382808	4602	Economy	3300.00
0005432382812	4602	Economy	3300.00
0005433722163	4602	Economy	3600.00
0005432382824	4602	Economy	3600.00
0005432382832	4602	Economy	3600.00
0005432382806	4602	Economy	3300.00
0005433722159	4602	Economy	3300.00
0005432727823	4602	Economy	3300.00
0005432382811	4602	Economy	3300.00
0005432727824	4602	Economy	3300.00
0005432382805	4602	Economy	3300.00
0005432727820	4602	Economy	3300.00
0005433194831	4602	Economy	3300.00
0005432382813	4602	Economy	3300.00
0005432382836	4602	Economy	3300.00
0005432382815	4602	Economy	3300.00
0005433722160	4602	Economy	3300.00
0005432382810	4602	Economy	3300.00
0005432382837	4602	Economy	3300.00
0005432382841	4602	Economy	3300.00
0005432382817	4602	Economy	3300.00
0005432382819	4602	Economy	3300.00
0005432727818	4602	Economy	3300.00
0005433194833	4602	Economy	3300.00
0005432382835	4602	Economy	3300.00
0005433454854	4602	Economy	3300.00
0005432727819	4602	Economy	3300.00
0005432382839	4602	Economy	3300.00
0005432382830	4602	Economy	3300.00
0005432382814	4602	Economy	3300.00
0005432382820	4602	Economy	3300.00
0005432382822	4602	Economy	3300.00
0005432382829	4602	Economy	3300.00
0005432727821	4602	Economy	3300.00
0005432382825	4602	Economy	3300.00
0005432382827	4602	Economy	3300.00
0005433194828	4602	Economy	3300.00
0005432382840	4602	Economy	3300.00
0005432382842	4602	Economy	3300.00
0005433454855	4602	Economy	3300.00
0005432727828	4602	Economy	3300.00
0005433722158	4602	Economy	3300.00
0005432382833	4602	Economy	3300.00
0005432727830	4602	Economy	3300.00
0005433722164	4602	Economy	3300.00
0005433722165	4602	Economy	3300.00
0005432382843	4602	Economy	3300.00
0005433194829	4602	Economy	3300.00
0005432727829	4602	Economy	3300.00
0005432382807	4602	Economy	3300.00
0005432382823	4602	Economy	3300.00
0005433722161	4602	Economy	3300.00
0005433722166	4602	Economy	3300.00
0005433453745	4602	Economy	3300.00
0005432382831	4602	Economy	3300.00
0005433194830	4602	Economy	3300.00
0005432727825	4602	Economy	3300.00
0005433722162	4602	Economy	3300.00
0005433453744	4602	Economy	3300.00
0005432727822	4602	Economy	3300.00
0005433194817	30167	Economy	3300.00
0005432727727	30167	Economy	3300.00
0005432727765	30167	Economy	3300.00
0005432727766	30167	Economy	3300.00
0005432727726	30167	Economy	3300.00
0005435529074	1739	Business	57200.00
0005435540819	1739	Business	57200.00
0005432924961	1739	Business	57200.00
0005435540802	1739	Business	57200.00
0005435529071	1739	Business	57200.00
0005435540808	1739	Economy	19100.00
0005433516804	1739	Economy	19100.00
0005435540813	1739	Economy	19100.00
0005433516802	1739	Economy	19100.00
0005435540821	1739	Economy	19100.00
0005433516799	1739	Economy	19100.00
0005435540816	1739	Economy	19100.00
0005435540804	1739	Economy	21000.00
0005435540815	1739	Economy	21000.00
0005435540810	1739	Economy	21000.00
0005435529062	1739	Economy	19100.00
0005435529063	1739	Economy	19100.00
0005433516797	1739	Economy	19100.00
0005435529073	1739	Economy	19100.00
0005432924954	1739	Economy	19100.00
0005435529075	1739	Economy	19100.00
0005435540806	1739	Economy	19100.00
0005435540822	1739	Economy	19100.00
0005435540814	1739	Economy	19100.00
0005435540818	1739	Economy	19100.00
0005435529061	1739	Economy	19100.00
0005435529057	1739	Economy	19100.00
0005435540807	1739	Economy	19100.00
0005435529064	1739	Economy	19100.00
0005435529076	1739	Economy	19100.00
0005435540803	1739	Economy	19100.00
0005435540817	1739	Economy	19100.00
0005435529060	1739	Economy	19100.00
0005435529059	1739	Economy	19100.00
0005433516801	1739	Economy	19100.00
0005435529066	1739	Economy	19100.00
0005435529072	1739	Economy	19100.00
0005435540805	1739	Economy	19100.00
0005433516798	1739	Economy	19100.00
0005435529069	1739	Economy	19100.00
0005435529056	1739	Economy	19100.00
0005435529067	1739	Economy	19100.00
0005435529070	1739	Economy	19100.00
0005435529055	1739	Economy	19100.00
0005435529065	1739	Economy	19100.00
0005433516805	1739	Economy	19100.00
0005432294465	1739	Economy	19100.00
0005435529077	1739	Economy	19100.00
0005435540809	1739	Economy	19100.00
0005435540820	1739	Economy	19100.00
0005432294466	1739	Economy	19100.00
0005435529058	1739	Economy	19100.00
0005433516803	1739	Economy	19100.00
0005435529068	1739	Economy	19100.00
0005435540800	1739	Economy	19100.00
0005435540801	1739	Economy	19100.00
0005433516800	1739	Economy	19100.00
0005435540812	1739	Economy	19100.00
0005435540811	1739	Economy	19100.00
0005433516764	22021	Business	57200.00
0005435517642	22021	Business	57200.00
0005435517643	22021	Economy	19100.00
0005435517610	22021	Economy	19100.00
0005433516728	22021	Economy	19100.00
0005435540643	22021	Economy	19100.00
0005433516739	22021	Economy	21000.00
0005433516729	22021	Economy	21000.00
0005433516732	22021	Economy	19100.00
0005433516733	22021	Economy	19100.00
0005432924993	22021	Economy	19100.00
0005435540658	22021	Economy	19100.00
0005435517590	22021	Economy	19100.00
0005435517589	22021	Economy	19100.00
0005435540657	22021	Economy	19100.00
0005432924992	22021	Economy	19100.00
0005432924991	22021	Economy	19100.00
0005433516738	22021	Economy	19100.00
0005435540698	22021	Economy	19100.00
0005435540659	22021	Economy	19100.00
0005435517595	22021	Economy	19100.00
0005432924994	22021	Economy	19100.00
0005435517609	22021	Economy	19100.00
0005432838745	7352	Business	18500.00
0005432838748	7352	Business	18500.00
0005432073357	7352	Business	18500.00
0005432838766	7352	Business	18500.00
0005432838742	7352	Business	18500.00
0005434664919	7352	Business	18500.00
0005434458614	7352	Business	18500.00
0005434458624	7352	Business	18500.00
0005432838737	7352	Business	18500.00
0005432838735	7352	Business	18500.00
0005434458617	7352	Business	18500.00
0005435252433	7352	Business	18500.00
0005434458621	7352	Economy	6200.00
0005435252387	7352	Economy	6200.00
0005434458620	7352	Economy	6200.00
0005432838739	7352	Economy	6200.00
0005432838757	7352	Economy	6200.00
0005434458616	7352	Economy	6200.00
0005432838758	7352	Economy	6200.00
0005434458610	7352	Economy	6200.00
0005434458611	7352	Economy	6200.00
0005432073358	7352	Economy	6800.00
0005432838756	7352	Economy	6800.00
0005435252467	7352	Economy	6800.00
0005432838753	7352	Economy	6800.00
0005432838764	7352	Economy	6200.00
0005435252402	7352	Economy	6200.00
0005432073360	7352	Economy	6200.00
0005432838743	7352	Economy	6200.00
0005435252385	7352	Economy	6200.00
0005432838740	7352	Economy	6200.00
0005432073359	7352	Economy	6200.00
0005432838736	7352	Economy	6200.00
0005432838754	7352	Economy	6200.00
0005432838741	7352	Economy	6200.00
0005434458618	7352	Economy	6200.00
0005434458606	7352	Economy	6200.00
0005434458613	7352	Economy	6200.00
0005432838752	7352	Economy	6200.00
0005432838761	7352	Economy	6200.00
0005434458609	7352	Economy	6200.00
0005434458619	7352	Economy	6200.00
0005434458615	7352	Economy	6200.00
0005432838765	7352	Economy	6200.00
0005432823430	7352	Economy	6200.00
0005432838738	7352	Economy	6200.00
0005432838746	7352	Economy	6200.00
0005434458604	7352	Economy	6200.00
0005432823429	7352	Economy	6200.00
0005432838760	7352	Economy	6200.00
0005435252434	7352	Economy	6200.00
0005434458605	7352	Economy	6200.00
0005432838759	7352	Economy	6200.00
0005432838751	7352	Economy	6200.00
0005435491407	7352	Economy	6200.00
0005434458623	7352	Economy	6200.00
0005432840992	7352	Economy	6200.00
0005434458608	7352	Economy	6200.00
0005435252386	7352	Economy	6200.00
0005432838763	7352	Economy	6200.00
0005432838755	7352	Economy	6200.00
0005434458607	7352	Economy	6200.00
0005432838762	7352	Economy	6200.00
0005432840991	7352	Economy	6200.00
0005432838747	7352	Economy	6200.00
0005432838750	7352	Economy	6200.00
0005432838744	7352	Economy	6200.00
0005434458622	7352	Economy	6200.00
0005432838749	7352	Economy	6200.00
0005434458612	7352	Economy	6200.00
0005432838542	28942	Business	18500.00
0005435252540	28942	Business	18500.00
0005432838502	28942	Business	18500.00
0005435252542	28942	Business	18500.00
0005432838522	28942	Business	18500.00
0005432838519	28942	Business	18500.00
0005435491423	28942	Economy	6200.00
0005435252545	28942	Economy	6200.00
0005435252536	28942	Economy	6200.00
0005432838580	28942	Economy	6200.00
0005432838523	28942	Economy	6800.00
0005432838524	28942	Economy	6800.00
0005432838518	28942	Economy	6800.00
0005434458523	28942	Economy	6800.00
0005432838555	28942	Economy	6800.00
0005435252531	28942	Economy	6200.00
0005434458527	28942	Economy	6200.00
0005435491424	28942	Economy	6200.00
0005435252533	28942	Economy	6200.00
0005435252541	28942	Economy	6200.00
0005434458525	28942	Economy	6200.00
0005435252538	28942	Economy	6200.00
0005434458434	28942	Economy	6200.00
0005432838531	28942	Economy	6200.00
0005432838503	28942	Economy	6200.00
0005434458441	28942	Economy	6200.00
0005435252532	28942	Economy	6200.00
0005435252534	28942	Economy	6200.00
0005434458461	28942	Economy	6200.00
0005435252535	28942	Economy	6200.00
0005432838496	28942	Economy	6200.00
0005435252544	28942	Economy	6200.00
0005432838510	28942	Economy	6200.00
0005434664939	28942	Economy	6200.00
0005432838534	28942	Economy	6200.00
0005435252529	28942	Economy	6200.00
0005435252537	28942	Economy	6200.00
0005432838582	28942	Economy	6200.00
0005432838549	28942	Economy	6200.00
0005435491425	28942	Economy	6200.00
0005435252530	28942	Economy	6200.00
0005432001005	28942	Economy	6200.00
0005434458474	28942	Economy	6200.00
0005432838511	28942	Economy	6200.00
0005432838576	28942	Economy	6200.00
0005434458491	28942	Economy	6200.00
0005434458440	28942	Economy	6200.00
0005432838497	28942	Economy	6200.00
0005434458526	28942	Economy	6200.00
0005435252543	28942	Economy	6200.00
0005432838556	28942	Economy	6200.00
0005432838501	28942	Economy	6200.00
0005435252539	28942	Economy	6200.00
0005435990558	8821	Business	145300.00
0005435990561	8821	Economy	53300.00
0005435990562	8821	Economy	48400.00
0005434275927	8821	Economy	48400.00
0005435990556	8821	Economy	48400.00
0005435990557	8821	Economy	48400.00
0005435990559	8821	Economy	48400.00
0005435990560	8821	Economy	48400.00
0005434275926	8821	Economy	48400.00
0005435990555	8821	Economy	48400.00
0005434275975	15757	Business	145300.00
0005434275971	15757	Economy	48400.00
0005434275972	15757	Economy	48400.00
0005434275976	15757	Economy	48400.00
0005434275974	15757	Economy	48400.00
0005434275973	15757	Economy	48400.00
0005435990505	15757	Economy	48400.00
0005432427123	20617	Economy	15900.00
0005433476857	20617	Economy	14500.00
0005432427120	20617	Economy	14500.00
0005432427124	20617	Economy	14500.00
0005432427122	20617	Economy	14500.00
0005432427121	20617	Economy	14500.00
0005433476864	20617	Economy	14500.00
0005433476865	20617	Economy	14500.00
0005432427111	30843	Economy	14500.00
0005433476873	30843	Economy	14500.00
0005433476871	30843	Economy	14500.00
0005432427112	30843	Economy	14500.00
0005433476872	30843	Economy	14500.00
0005432427106	30843	Economy	14500.00
0005433476870	30843	Economy	14500.00
0005432427107	30843	Economy	14500.00
0005432359912	6386	Business	36600.00
0005435176643	6386	Business	36600.00
0005432363384	6386	Business	36600.00
0005432359941	6386	Business	36600.00
0005432359927	6386	Business	36600.00
0005432335922	6386	Business	36600.00
0005432359903	6386	Business	36600.00
0005432359902	6386	Business	36600.00
0005434149539	6386	Business	36600.00
0005435176683	6386	Business	36600.00
0005435490169	6386	Economy	12200.00
0005432335927	6386	Economy	12200.00
0005432359945	6386	Economy	12200.00
0005432359919	6386	Economy	12200.00
0005435176605	6386	Economy	12200.00
0005435176636	6386	Economy	12200.00
0005432062183	6386	Economy	12200.00
0005432359943	6386	Economy	12200.00
0005435176635	6386	Economy	12200.00
0005432359915	6386	Economy	12200.00
0005432359911	6386	Economy	12200.00
0005432359922	6386	Economy	12200.00
0005432359935	6386	Economy	12200.00
0005432359929	6386	Economy	12200.00
0005432359924	6386	Economy	12200.00
0005432359921	6386	Economy	12200.00
0005432359910	6386	Economy	12200.00
0005434149540	6386	Economy	12200.00
0005432359933	6386	Economy	12200.00
0005435176609	6386	Economy	12200.00
0005435176684	6386	Economy	12200.00
0005435490172	6386	Economy	12200.00
0005432363386	6386	Economy	12200.00
0005435176634	6386	Economy	12200.00
0005432359948	6386	Economy	12200.00
0005435723012	6386	Economy	12200.00
0005432359930	6386	Economy	12200.00
0005432359901	6386	Economy	12200.00
0005434149572	6386	Economy	12200.00
0005432363387	6386	Economy	12200.00
0005432335924	6386	Economy	13400.00
0005432363385	6386	Economy	13400.00
0005432359900	6386	Economy	13400.00
0005432359914	6386	Economy	13400.00
0005432359940	6386	Economy	12200.00
0005432359917	6386	Economy	12200.00
0005432359932	6386	Economy	12200.00
0005432359939	6386	Economy	12200.00
0005432359920	6386	Economy	12200.00
0005432062180	6386	Economy	12200.00
0005432359938	6386	Economy	12200.00
0005432359926	6386	Economy	12200.00
0005432335920	6386	Economy	12200.00
0005432359923	6386	Economy	12200.00
0005432359925	6386	Economy	12200.00
0005432062177	6386	Economy	12200.00
0005432359918	6386	Economy	12200.00
0005432359931	6386	Economy	12200.00
0005435490173	6386	Economy	12200.00
0005432359936	6386	Economy	12200.00
0005432363388	6386	Economy	12200.00
0005432359907	6386	Economy	12200.00
0005432062182	6386	Economy	12200.00
0005432359934	6386	Economy	12200.00
0005432335925	6386	Economy	12200.00
0005435723009	6386	Economy	12200.00
0005432359944	6386	Economy	12200.00
0005432359906	6386	Economy	12200.00
0005435176615	6386	Economy	12200.00
0005432335919	6386	Economy	12200.00
0005432335928	6386	Economy	12200.00
0005432335923	6386	Economy	12200.00
0005435176711	6386	Economy	12200.00
0005432359942	6386	Economy	12200.00
0005435176608	6386	Economy	12200.00
0005432062179	6386	Economy	12200.00
0005432359908	6386	Economy	12200.00
0005432359916	6386	Economy	12200.00
0005434149571	6386	Economy	12200.00
0005432359937	6386	Economy	12200.00
0005432335921	6386	Economy	12200.00
0005432359946	6386	Economy	12200.00
0005432359909	6386	Economy	12200.00
0005435490171	6386	Economy	12200.00
0005432062181	6386	Economy	12200.00
0005434149538	6386	Economy	12200.00
0005432335929	6386	Economy	12200.00
0005432335926	6386	Economy	12200.00
0005432359905	6386	Economy	12200.00
0005432359947	6386	Economy	12200.00
0005432359913	6386	Economy	12200.00
0005435176601	6386	Economy	12200.00
0005432359904	6386	Economy	12200.00
0005432062178	6386	Economy	12200.00
0005432359928	6386	Economy	12200.00
0005435490198	21006	Business	36600.00
0005435176812	21006	Business	36600.00
0005435176822	21006	Business	36600.00
0005435490197	21006	Business	36600.00
0005434149621	21006	Business	36600.00
0005432359586	21006	Business	36600.00
0005435176829	21006	Economy	12200.00
0005432359609	21006	Economy	12200.00
0005435176817	21006	Economy	12200.00
0005432335830	21006	Economy	12200.00
0005435176825	21006	Economy	12200.00
0005432359624	21006	Economy	12200.00
0005432359633	21006	Economy	12200.00
0005435490195	21006	Economy	12200.00
0005435176811	21006	Economy	12200.00
0005434149622	21006	Economy	12200.00
0005435176826	21006	Economy	12200.00
0005435176828	21006	Economy	12200.00
0005435176836	21006	Economy	12200.00
0005435176834	21006	Economy	12200.00
0005432052718	21006	Economy	12200.00
0005435176821	21006	Economy	12200.00
0005435176838	21006	Economy	12200.00
0005432363360	21006	Economy	12200.00
0005435723028	21006	Economy	12200.00
0005435490196	21006	Economy	12200.00
0005435176823	21006	Economy	12200.00
0005435176837	21006	Economy	12200.00
0005432359585	21006	Economy	12200.00
0005432359553	21006	Economy	12200.00
0005432359530	21006	Economy	12200.00
0005435723027	21006	Economy	13400.00
0005435176818	21006	Economy	13400.00
0005432359611	21006	Economy	12200.00
0005432359604	21006	Economy	12200.00
0005432335869	21006	Economy	12200.00
0005432363359	21006	Economy	12200.00
0005432359625	21006	Economy	12200.00
0005435176833	21006	Economy	12200.00
0005435176815	21006	Economy	12200.00
0005434149623	21006	Economy	12200.00
0005434149620	21006	Economy	12200.00
0005434149627	21006	Economy	12200.00
0005432359605	21006	Economy	12200.00
0005432359655	21006	Economy	12200.00
0005435176830	21006	Economy	12200.00
0005432359752	21006	Economy	12200.00
0005432363365	21006	Economy	12200.00
0005434149616	21006	Economy	12200.00
0005432335860	21006	Economy	12200.00
0005435176814	21006	Economy	12200.00
0005435176816	21006	Economy	12200.00
0005435176827	21006	Economy	12200.00
0005435176820	21006	Economy	12200.00
0005434149626	21006	Economy	12200.00
0005432359653	21006	Economy	12200.00
0005432335831	21006	Economy	12200.00
0005435723029	21006	Economy	12200.00
0005435176835	21006	Economy	12200.00
0005432359635	21006	Economy	12200.00
0005432359515	21006	Economy	12200.00
0005432052717	21006	Economy	12200.00
0005434149624	21006	Economy	12200.00
0005435176813	21006	Economy	12200.00
0005435176819	21006	Economy	12200.00
0005432359751	21006	Economy	12200.00
0005435176824	21006	Economy	12200.00
0005432359567	21006	Economy	12200.00
0005432359560	21006	Economy	12200.00
0005435176831	21006	Economy	12200.00
0005432052719	21006	Economy	12200.00
0005435176832	21006	Economy	12200.00
0005434149619	21006	Economy	12200.00
0005432363372	21006	Economy	12200.00
0005434149625	21006	Economy	12200.00
0005434149617	21006	Economy	12200.00
0005432359511	21006	Economy	12200.00
0005432359634	21006	Economy	12200.00
0005432363366	21006	Economy	12200.00
0005432359552	21006	Economy	12200.00
0005432359610	21006	Economy	12200.00
0005434149618	21006	Economy	12200.00
0005434458507	17688	Economy	3400.00
0005434458481	17688	Economy	3100.00
0005434458513	17688	Economy	3100.00
0005434458450	17688	Economy	3100.00
0005434458480	17688	Economy	3100.00
0005434186172	17688	Economy	3100.00
0005434458452	17688	Economy	3100.00
0005434186173	17688	Economy	3100.00
0005434461610	17688	Economy	3100.00
0005434448263	17688	Economy	3100.00
0005434461609	17688	Economy	3100.00
0005434458451	17688	Economy	3100.00
0005434448262	17688	Economy	3100.00
0005434186174	17688	Economy	3100.00
0005434458515	17688	Economy	3100.00
0005434458466	17688	Economy	3100.00
0005434448258	17688	Economy	3100.00
0005434448264	17688	Economy	3100.00
0005434458611	29114	Economy	3400.00
0005434186151	29114	Economy	3400.00
0005434458616	29114	Economy	3100.00
0005434458612	29114	Economy	3100.00
0005434448279	29114	Economy	3100.00
0005434458619	29114	Economy	3100.00
0005434458610	29114	Economy	3100.00
0005434458624	29114	Economy	3100.00
0005434458605	29114	Economy	3100.00
0005434458621	29114	Economy	3100.00
0005434448280	29114	Economy	3100.00
0005434463907	29114	Economy	3100.00
0005434462769	29114	Economy	3100.00
0005434458623	29114	Economy	3100.00
0005434458614	29114	Economy	3100.00
0005434458622	29114	Economy	3100.00
0005434186152	29114	Economy	3100.00
0005434186150	29114	Economy	3100.00
0005434448281	29114	Economy	3100.00
0005434448278	29114	Economy	3100.00
0005434462768	29114	Economy	3100.00
0005434458607	29114	Economy	3100.00
0005434458604	29114	Economy	3100.00
0005434458613	29114	Economy	3100.00
0005434463908	29114	Economy	3100.00
0005434463906	29114	Economy	3100.00
0005434458609	29114	Economy	3100.00
0005434458615	29114	Economy	3100.00
0005434458618	29114	Economy	3100.00
0005434462767	29114	Economy	3100.00
0005434458617	29114	Economy	3100.00
0005434458606	29114	Economy	3100.00
0005434458608	29114	Economy	3100.00
0005434458620	29114	Economy	3100.00
0005432603959	21442	Economy	7300.00
0005432603936	21442	Economy	7300.00
0005432603948	21442	Economy	7300.00
0005432603941	21442	Economy	7300.00
0005432603950	21442	Economy	6600.00
0005432603949	21442	Economy	6600.00
0005432603944	21442	Economy	6600.00
0005432603955	21442	Economy	6600.00
0005432603953	21442	Economy	6600.00
0005432603930	21442	Economy	6600.00
0005432603957	21442	Economy	6600.00
0005432603964	21442	Economy	6600.00
0005432603932	21442	Economy	6600.00
0005432603958	21442	Economy	6600.00
0005432603937	21442	Economy	6600.00
0005432603954	21442	Economy	6600.00
0005432603934	21442	Economy	6600.00
0005432603965	21442	Economy	6600.00
0005432603929	21442	Economy	6600.00
0005432603946	21442	Economy	6600.00
0005432603956	21442	Economy	6600.00
0005432603931	21442	Economy	6600.00
0005432603928	21442	Economy	6600.00
0005432603938	21442	Economy	6600.00
0005432603963	21442	Economy	6600.00
0005432603952	21442	Economy	6600.00
0005432603927	21442	Economy	6600.00
0005432603943	21442	Economy	6600.00
0005432603962	21442	Economy	6600.00
0005432603933	21442	Economy	6600.00
0005432603940	21442	Economy	6600.00
0005432603942	21442	Economy	6600.00
0005432603935	21442	Economy	6600.00
0005432603945	21442	Economy	6600.00
0005432603947	21442	Economy	6600.00
0005432603961	21442	Economy	6600.00
0005432603939	21442	Economy	6600.00
0005432603926	21442	Economy	6600.00
0005432603951	21442	Economy	6600.00
0005432603960	21442	Economy	6600.00
0005432603642	31682	Economy	7300.00
0005432603666	31682	Economy	7300.00
0005432603691	31682	Economy	7300.00
0005435221047	31682	Economy	6600.00
0005432603655	31682	Economy	6600.00
0005432603714	31682	Economy	6600.00
0005432603712	31682	Economy	6600.00
0005432603663	31682	Economy	6600.00
0005432603695	31682	Economy	6600.00
0005432603667	31682	Economy	6600.00
0005435221506	31682	Economy	6600.00
0005432603692	31682	Economy	6600.00
0005432603719	31682	Economy	6600.00
0005432603694	31682	Economy	6600.00
0005435221046	31682	Economy	6600.00
0005435221507	31682	Economy	6600.00
0005432603763	31682	Economy	6600.00
0005432603713	31682	Economy	6600.00
0005432603661	31682	Economy	6600.00
0005432603736	31682	Economy	6600.00
0005432603684	31682	Economy	6600.00
0005435221508	31682	Economy	6600.00
0005435904890	18846	Economy	6600.00
0005434606760	18846	Economy	6600.00
0005434606759	18846	Economy	6600.00
0005435904891	18846	Economy	6600.00
0005434606791	22316	Economy	6600.00
0005434604863	22316	Economy	6600.00
0005434606792	22316	Economy	6600.00
0005434606789	22316	Economy	6600.00
0005434606790	22316	Economy	6600.00
0005434606793	22316	Economy	6600.00
0005434604864	22316	Economy	6600.00
0005432747181	416	Business	44500.00
0005432747216	416	Business	44500.00
0005432890720	416	Business	44500.00
0005432890702	416	Business	44500.00
0005432749762	416	Business	44500.00
0005432747210	416	Business	44500.00
0005432747195	416	Business	44500.00
0005432747192	416	Business	44500.00
0005432890722	416	Business	44500.00
0005432747211	416	Business	44500.00
0005432747205	416	Economy	14800.00
0005432747183	416	Economy	14800.00
0005432747196	416	Economy	14800.00
0005432747190	416	Economy	14800.00
0005433875356	416	Economy	14800.00
0005432219961	416	Economy	16300.00
0005432747217	416	Economy	16300.00
0005432890679	416	Economy	16300.00
0005432749763	416	Economy	14800.00
0005432751493	416	Economy	14800.00
0005432747199	416	Economy	14800.00
0005432747201	416	Economy	14800.00
0005432747206	416	Economy	14800.00
0005432747185	416	Economy	14800.00
0005432890670	416	Economy	14800.00
0005432747204	416	Economy	14800.00
0005432747209	416	Economy	14800.00
0005432751492	416	Economy	14800.00
0005432219963	416	Economy	14800.00
0005432747203	416	Economy	14800.00
0005432747200	416	Economy	14800.00
0005432747208	416	Economy	14800.00
0005432747189	416	Economy	14800.00
0005432890682	416	Economy	14800.00
0005432753267	416	Economy	14800.00
0005432747212	416	Economy	14800.00
0005433875355	416	Economy	14800.00
0005432753268	416	Economy	14800.00
0005432219962	416	Economy	14800.00
0005432747197	416	Economy	14800.00
0005432890687	416	Economy	14800.00
0005432747213	416	Economy	14800.00
0005432890680	416	Economy	14800.00
0005432747215	416	Economy	14800.00
0005432747198	416	Economy	14800.00
0005432747207	416	Economy	14800.00
0005432747188	416	Economy	14800.00
0005432747186	416	Economy	14800.00
0005433293143	416	Economy	14800.00
0005432219964	416	Economy	14800.00
0005432753266	416	Economy	14800.00
0005432747182	416	Economy	14800.00
0005432747187	416	Economy	14800.00
0005432747193	416	Economy	14800.00
0005432747191	416	Economy	14800.00
0005432890683	416	Economy	14800.00
0005432747184	416	Economy	14800.00
0005432890719	416	Economy	14800.00
0005432890721	416	Economy	14800.00
0005432747202	416	Economy	14800.00
0005432890671	416	Economy	14800.00
0005432747214	416	Economy	14800.00
0005432747218	416	Economy	14800.00
0005432747194	416	Economy	14800.00
0005433293189	12062	Business	44500.00
0005434153524	12062	Business	44500.00
0005432890847	12062	Business	44500.00
0005433293181	12062	Business	44500.00
0005433293194	12062	Business	44500.00
0005432890846	12062	Business	44500.00
0005432746949	12062	Business	44500.00
0005432746877	12062	Business	44500.00
0005432890830	12062	Business	44500.00
0005432746879	12062	Business	44500.00
0005432746939	12062	Business	44500.00
0005432746954	12062	Economy	14800.00
0005432746962	12062	Economy	14800.00
0005432890835	12062	Economy	14800.00
0005433293180	12062	Economy	14800.00
0005432746935	12062	Economy	16300.00
0005432746894	12062	Economy	16300.00
0005433293185	12062	Economy	14800.00
0005432749749	12062	Economy	14800.00
0005432890836	12062	Economy	14800.00
0005433293182	12062	Economy	14800.00
0005433293190	12062	Economy	14800.00
0005433293193	12062	Economy	14800.00
0005432890841	12062	Economy	14800.00
0005433293195	12062	Economy	14800.00
0005432746978	12062	Economy	14800.00
0005432890845	12062	Economy	14800.00
0005433875365	12062	Economy	14800.00
0005432890831	12062	Economy	14800.00
0005433293196	12062	Economy	14800.00
0005432890834	12062	Economy	14800.00
0005432890833	12062	Economy	14800.00
0005433293197	12062	Economy	14800.00
0005432746931	12062	Economy	14800.00
0005433293179	12062	Economy	14800.00
0005432747049	12062	Economy	14800.00
0005432214782	12062	Economy	14800.00
0005433293192	12062	Economy	14800.00
0005432214783	12062	Economy	14800.00
0005432890829	12062	Economy	14800.00
0005432890839	12062	Economy	14800.00
0005433293178	12062	Economy	14800.00
0005432746878	12062	Economy	14800.00
0005433293183	12062	Economy	14800.00
0005432747000	12062	Economy	14800.00
0005432747097	12062	Economy	14800.00
0005432890844	12062	Economy	14800.00
0005432746936	12062	Economy	14800.00
0005432890837	12062	Economy	14800.00
0005432747047	12062	Economy	14800.00
0005432753243	12062	Economy	14800.00
0005432890832	12062	Economy	14800.00
0005432890838	12062	Economy	14800.00
0005432890843	12062	Economy	14800.00
0005433293188	12062	Economy	14800.00
0005432747048	12062	Economy	14800.00
0005432890842	12062	Economy	14800.00
0005432890848	12062	Economy	14800.00
0005433293186	12062	Economy	14800.00
0005432214784	12062	Economy	14800.00
0005432747052	12062	Economy	14800.00
0005432747001	12062	Economy	14800.00
0005432746886	12062	Economy	14800.00
0005433293187	12062	Economy	14800.00
0005432746888	12062	Economy	14800.00
0005432749750	12062	Economy	14800.00
0005432890840	12062	Economy	14800.00
0005432746904	12062	Economy	14800.00
0005433293191	12062	Economy	14800.00
0005433293184	12062	Economy	14800.00
0005432753242	12062	Economy	14800.00
0005433524926	18995	Economy	28200.00
0005433531253	18995	Economy	25700.00
0005433524927	18995	Economy	25700.00
0005433524928	18995	Economy	25700.00
0005433524924	18995	Economy	25700.00
0005433531256	18995	Economy	25700.00
0005432927887	18995	Economy	25700.00
0005433531252	18995	Economy	25700.00
0005433524923	18995	Economy	25700.00
0005433533269	18995	Economy	25700.00
0005432927896	18995	Economy	25700.00
0005433531254	18995	Economy	25700.00
0005433524929	18995	Economy	25700.00
0005433524925	18995	Economy	25700.00
0005432927891	18995	Economy	25700.00
0005433524933	18995	Economy	25700.00
0005433533270	18995	Economy	25700.00
0005433524934	18995	Economy	25700.00
0005433531255	18995	Economy	25700.00
0005433524932	18995	Economy	25700.00
0005432927892	18995	Economy	25700.00
0005433533268	18995	Economy	25700.00
0005433524931	18995	Economy	25700.00
0005432927895	18995	Economy	25700.00
0005433524930	18995	Economy	25700.00
0005432927897	18995	Economy	25700.00
0005433524935	18995	Economy	25700.00
0005432927935	32480	Economy	28200.00
0005432927933	32480	Economy	25700.00
0005433524863	32480	Economy	25700.00
0005433524850	32480	Economy	25700.00
0005432927932	32480	Economy	25700.00
0005433524858	32480	Economy	25700.00
0005433524872	32480	Economy	25700.00
0005433524849	32480	Economy	25700.00
0005432927931	32480	Economy	25700.00
0005433527204	32480	Economy	25700.00
0005433524873	32480	Economy	25700.00
0005433524857	32480	Economy	25700.00
0005432927934	32480	Economy	25700.00
0005433524862	32480	Economy	25700.00
0005433524859	32480	Economy	25700.00
0005434558200	5265	Business	84000.00
0005434822478	5265	Business	84000.00
0005434822447	5265	Business	84000.00
0005434822423	5265	Business	84000.00
0005434822384	5265	Business	84000.00
0005434558203	5265	Business	84000.00
0005434822379	5265	Business	84000.00
0005434822476	5265	Business	84000.00
0005434822431	5265	Business	84000.00
0005434822434	5265	Business	84000.00
0005434822424	5265	Business	84000.00
0005432823418	5265	Business	84000.00
0005434822474	5265	Business	84000.00
0005434828669	5265	Business	84000.00
0005435149907	5265	Business	84000.00
0005434822460	5265	Comfort	47600.00
0005434822441	5265	Comfort	47600.00
0005435372225	5265	Comfort	47600.00
0005434822426	5265	Comfort	47600.00
0005435149902	5265	Comfort	47600.00
0005434822356	5265	Comfort	47600.00
0005435372407	5265	Comfort	47600.00
0005435372350	5265	Comfort	47600.00
0005434822361	5265	Comfort	47600.00
0005434831104	5265	Comfort	47600.00
0005435372357	5265	Comfort	47600.00
0005434822407	5265	Comfort	47600.00
0005434822468	5265	Comfort	47600.00
0005434822369	5265	Comfort	47600.00
0005434558204	5265	Comfort	47600.00
0005432121198	5265	Comfort	47600.00
0005434822410	5265	Comfort	47600.00
0005434822401	5265	Comfort	47600.00
0005434822417	5265	Comfort	47600.00
0005435372246	5265	Comfort	47600.00
0005434822405	5265	Comfort	47600.00
0005435386487	5265	Comfort	47600.00
0005434822442	5265	Comfort	47600.00
0005434822358	5265	Comfort	47600.00
0005434822464	5265	Comfort	47600.00
0005434822398	5265	Comfort	47600.00
0005434822479	5265	Comfort	47600.00
0005434822413	5265	Comfort	47600.00
0005434822360	5265	Economy	28000.00
0005435149899	5265	Economy	28000.00
0005434822430	5265	Economy	28000.00
0005434822370	5265	Economy	28000.00
0005435372258	5265	Economy	28000.00
0005434822433	5265	Economy	28000.00
0005434822357	5265	Economy	28000.00
0005435304102	5265	Economy	28000.00
0005432396207	5265	Economy	28000.00
0005435372094	5265	Economy	28000.00
0005434822432	5265	Economy	28000.00
0005432121201	5265	Economy	28000.00
0005434822392	5265	Economy	28000.00
0005434822446	5265	Economy	28000.00
0005434822437	5265	Economy	28000.00
0005434822381	5265	Economy	28000.00
0005434822450	5265	Economy	28000.00
0005434822403	5265	Economy	28000.00
0005434822368	5265	Economy	28000.00
0005434822475	5265	Economy	28000.00
0005434822466	5265	Economy	28000.00
0005434822453	5265	Economy	28000.00
0005434822402	5265	Economy	28000.00
0005434822387	5265	Economy	28000.00
0005434822429	5265	Economy	28000.00
0005435372273	5265	Economy	28000.00
0005434822473	5265	Economy	28000.00
0005434831102	5265	Economy	28000.00
0005432121207	5265	Economy	28000.00
0005434822389	5265	Economy	28000.00
0005434828668	5265	Economy	28000.00
0005432121205	5265	Economy	28000.00
0005434822420	5265	Economy	28000.00
0005435372215	5265	Economy	28000.00
0005434822451	5265	Economy	28000.00
0005434558199	5265	Economy	28000.00
0005432121210	5265	Economy	28000.00
0005435149912	5265	Economy	30800.00
0005434822422	5265	Economy	30800.00
0005434831105	5265	Economy	30800.00
0005435299698	5265	Economy	28000.00
0005434822383	5265	Economy	28000.00
0005434822385	5265	Economy	30800.00
0005434822399	5265	Economy	30800.00
0005434822418	5265	Economy	28000.00
0005434822448	5265	Economy	28000.00
0005435372125	5265	Economy	28000.00
0005434822365	5265	Economy	28000.00
0005432121199	5265	Economy	28000.00
0005434822461	5265	Economy	28000.00
0005434822421	5265	Economy	28000.00
0005434822439	5265	Economy	28000.00
0005434831101	5265	Economy	28000.00
0005434822386	5265	Economy	28000.00
0005432121200	5265	Economy	28000.00
0005435372162	5265	Economy	28000.00
0005434822364	5265	Economy	28000.00
0005434822404	5265	Economy	28000.00
0005432396205	5265	Economy	28000.00
0005434822366	5265	Economy	28000.00
0005434822465	5265	Economy	28000.00
0005434822409	5265	Economy	28000.00
0005434822416	5265	Economy	28000.00
0005434822436	5265	Economy	28000.00
0005434831103	5265	Economy	28000.00
0005435372126	5265	Economy	28000.00
0005435372290	5265	Economy	28000.00
0005434822372	5265	Economy	28000.00
0005434822458	5265	Economy	28000.00
0005432121211	5265	Economy	28000.00
0005434822382	5265	Economy	28000.00
0005435149903	5265	Economy	28000.00
0005432394067	5265	Economy	28000.00
0005434822354	5265	Economy	28000.00
0005434822443	5265	Economy	28000.00
0005435372182	5265	Economy	28000.00
0005434822467	5265	Economy	28000.00
0005435149904	5265	Economy	28000.00
0005434822396	5265	Economy	28000.00
0005435372144	5265	Economy	28000.00
0005435149911	5265	Economy	28000.00
0005434822438	5265	Economy	28000.00
0005432121208	5265	Economy	28000.00
0005434822359	5265	Economy	28000.00
0005434822352	5265	Economy	28000.00
0005434822455	5265	Economy	28000.00
0005434822427	5265	Economy	28000.00
0005435149908	5265	Economy	28000.00
0005435149901	5265	Economy	28000.00
0005435372143	5265	Economy	28000.00
0005434822391	5265	Economy	28000.00
0005434822449	5265	Economy	28000.00
0005432121206	5265	Economy	28000.00
0005434822415	5265	Economy	28000.00
0005434822353	5265	Economy	28000.00
0005434822462	5265	Economy	28000.00
0005434822477	5265	Economy	28000.00
0005435149905	5265	Economy	28000.00
0005434822400	5265	Economy	28000.00
0005432121197	5265	Economy	28000.00
0005434822452	5265	Economy	28000.00
0005434822373	5265	Economy	28000.00
0005434822463	5265	Economy	28000.00
0005434822454	5265	Economy	28000.00
0005434822408	5265	Economy	30800.00
0005434822351	5265	Economy	30800.00
0005434822390	5265	Economy	30800.00
0005434822388	5265	Economy	28000.00
0005434822471	5265	Economy	28000.00
0005434664936	5265	Economy	28000.00
0005435149910	5265	Economy	28000.00
0005435386464	5265	Economy	28000.00
0005434822378	5265	Economy	28000.00
0005434822414	5265	Economy	28000.00
0005434822355	5265	Economy	28000.00
0005434822377	5265	Economy	28000.00
0005435304101	5265	Economy	28000.00
0005435372253	5265	Economy	28000.00
0005434822444	5265	Economy	28000.00
0005434822411	5265	Economy	28000.00
0005435372274	5265	Economy	28000.00
0005434822425	5265	Economy	28000.00
0005434822419	5265	Economy	28000.00
0005435299705	5265	Economy	28000.00
0005434822435	5265	Economy	28000.00
0005434822470	5265	Economy	28000.00
0005434822412	5265	Economy	28000.00
0005434822374	5265	Economy	28000.00
0005432396204	5265	Economy	28000.00
0005434822395	5265	Economy	28000.00
0005434822380	5265	Economy	28000.00
0005434822456	5265	Economy	28000.00
0005434822367	5265	Economy	28000.00
0005432396206	5265	Economy	28000.00
0005432394068	5265	Economy	28000.00
0005432121202	5265	Economy	28000.00
0005432121204	5265	Economy	28000.00
0005434822362	5265	Economy	28000.00
0005434822472	5265	Economy	28000.00
0005434822445	5265	Economy	28000.00
0005434558201	5265	Economy	28000.00
0005435372356	5265	Economy	28000.00
0005434822457	5265	Economy	28000.00
0005432394066	5265	Economy	28000.00
0005434558198	5265	Economy	28000.00
0005434664938	5265	Economy	28000.00
0005434822440	5265	Economy	28000.00
0005435372406	5265	Economy	28000.00
0005434822371	5265	Economy	28000.00
0005435149909	5265	Economy	28000.00
0005434822397	5265	Economy	28000.00
0005434558202	5265	Economy	28000.00
0005434664937	5265	Economy	28000.00
0005435149906	5265	Economy	28000.00
0005434822375	5265	Economy	28000.00
0005434822394	5265	Economy	28000.00
0005432121209	5265	Economy	28000.00
0005435149900	5265	Economy	28000.00
0005435372134	5265	Economy	28000.00
0005435372257	5265	Economy	28000.00
0005434822459	5265	Economy	28000.00
0005434831100	5265	Economy	28000.00
0005435372209	5265	Economy	28000.00
0005434822428	5265	Economy	28000.00
0005434822469	5265	Economy	28000.00
0005435372251	5265	Economy	28000.00
0005435372133	5265	Economy	28000.00
0005434822393	5265	Economy	28000.00
0005435372216	5265	Economy	28000.00
0005432394065	5265	Economy	28000.00
0005434822406	5265	Economy	28000.00
0005435149913	5265	Economy	28000.00
0005434822376	5265	Economy	28000.00
0005432121203	5265	Economy	28000.00
0005434822363	5265	Economy	28000.00
0005435372689	9914	Business	84000.00
0005435386517	9914	Business	84000.00
0005435372630	9914	Business	84000.00
0005435372633	9914	Business	84000.00
0005435372680	9914	Business	84000.00
0005435372674	9914	Business	84000.00
0005434821883	9914	Business	84000.00
0005434821399	9914	Business	84000.00
0005434821388	9914	Business	84000.00
0005434821457	9914	Business	84000.00
0005435735096	9914	Business	84000.00
0005434821760	9914	Business	84000.00
0005435372628	9914	Comfort	47600.00
0005434821625	9914	Comfort	47600.00
0005435372642	9914	Comfort	47600.00
0005435372687	9914	Comfort	47600.00
0005435372657	9914	Comfort	47600.00
0005434821823	9914	Comfort	47600.00
0005435735097	9914	Comfort	47600.00
0005434821674	9914	Comfort	47600.00
0005432396177	9914	Comfort	47600.00
0005435386513	9914	Comfort	47600.00
0005435372635	9914	Comfort	47600.00
0005434821774	9914	Comfort	47600.00
0005435372676	9914	Comfort	47600.00
0005435372665	9914	Comfort	47600.00
0005435372634	9914	Comfort	47600.00
0005434821371	9914	Comfort	47600.00
0005435372673	9914	Comfort	47600.00
0005434821515	9914	Comfort	47600.00
0005434821824	9914	Comfort	47600.00
0005435386512	9914	Comfort	47600.00
0005434821332	9914	Comfort	47600.00
0005435372650	9914	Comfort	47600.00
0005434821367	9914	Comfort	47600.00
0005434821429	9914	Comfort	47600.00
0005435386511	9914	Comfort	47600.00
0005432823432	9914	Economy	28000.00
0005434821338	9914	Economy	28000.00
0005434821551	9914	Economy	28000.00
0005434831074	9914	Economy	28000.00
0005435661905	9914	Economy	28000.00
0005434821430	9914	Economy	28000.00
0005435372647	9914	Economy	28000.00
0005434821324	9914	Economy	28000.00
0005435372651	9914	Economy	28000.00
0005435372654	9914	Economy	28000.00
0005434821323	9914	Economy	28000.00
0005435372649	9914	Economy	28000.00
0005435372670	9914	Economy	28000.00
0005435735099	9914	Economy	28000.00
0005435372640	9914	Economy	28000.00
0005434821541	9914	Economy	28000.00
0005434821425	9914	Economy	28000.00
0005435302156	9914	Economy	28000.00
0005435372631	9914	Economy	28000.00
0005434821521	9914	Economy	28000.00
0005435386516	9914	Economy	28000.00
0005434821942	9914	Economy	28000.00
0005435372677	9914	Economy	28000.00
0005434821366	9914	Economy	28000.00
0005432202995	9914	Economy	28000.00
0005435372691	9914	Economy	28000.00
0005435661904	9914	Economy	28000.00
0005434821773	9914	Economy	28000.00
0005435372639	9914	Economy	28000.00
0005434821431	9914	Economy	28000.00
0005435372663	9914	Economy	28000.00
0005435372652	9914	Economy	28000.00
0005435372662	9914	Economy	30800.00
0005434822083	9914	Economy	28000.00
0005435372643	9914	Economy	28000.00
0005435372629	9914	Economy	28000.00
0005434821382	9914	Economy	28000.00
0005434821707	9914	Economy	28000.00
0005435372661	9914	Economy	28000.00
0005434821565	9914	Economy	28000.00
0005435299729	9914	Economy	28000.00
0005432396178	9914	Economy	28000.00
0005435372672	9914	Economy	28000.00
0005434821497	9914	Economy	28000.00
0005434821689	9914	Economy	28000.00
0005434822011	9914	Economy	28000.00
0005435372641	9914	Economy	28000.00
0005435302153	9914	Economy	28000.00
0005435372686	9914	Economy	28000.00
0005435372664	9914	Economy	28000.00
0005434821383	9914	Economy	28000.00
0005434821659	9914	Economy	28000.00
0005435372690	9914	Economy	28000.00
0005435386515	9914	Economy	28000.00
0005434821489	9914	Economy	28000.00
0005435372638	9914	Economy	28000.00
0005435372682	9914	Economy	28000.00
0005435372648	9914	Economy	28000.00
0005435149793	9914	Economy	28000.00
0005434821372	9914	Economy	28000.00
0005434831072	9914	Economy	28000.00
0005434821758	9914	Economy	28000.00
0005434821672	9914	Economy	28000.00
0005434821711	9914	Economy	28000.00
0005432202996	9914	Economy	28000.00
0005434821545	9914	Economy	28000.00
0005435372667	9914	Economy	28000.00
0005435372655	9914	Economy	28000.00
0005434821351	9914	Economy	28000.00
0005434821678	9914	Economy	28000.00
0005434821487	9914	Economy	28000.00
0005432202997	9914	Economy	28000.00
0005434821432	9914	Economy	28000.00
0005434821346	9914	Economy	28000.00
0005435302154	9914	Economy	28000.00
0005435372636	9914	Economy	28000.00
0005434821458	9914	Economy	28000.00
0005435372675	9914	Economy	28000.00
0005434821861	9914	Economy	28000.00
0005435372678	9914	Economy	28000.00
0005434821424	9914	Economy	28000.00
0005434821673	9914	Economy	28000.00
0005435735098	9914	Economy	28000.00
0005435372688	9914	Economy	28000.00
0005435372632	9914	Economy	28000.00
0005435372627	9914	Economy	28000.00
0005435372681	9914	Economy	30800.00
0005435372659	9914	Economy	30800.00
0005435372671	9914	Economy	30800.00
0005434821532	9914	Economy	28000.00
0005434821334	9914	Economy	28000.00
0005434821563	9914	Economy	28000.00
0005434821597	9914	Economy	28000.00
0005434821386	9914	Economy	28000.00
0005435299731	9914	Economy	28000.00
0005435302155	9914	Economy	28000.00
0005432400060	9914	Economy	28000.00
0005434821333	9914	Economy	28000.00
0005434821516	9914	Economy	28000.00
0005435372653	9914	Economy	28000.00
0005434821398	9914	Economy	28000.00
0005435372693	9914	Economy	28000.00
0005434821389	9914	Economy	28000.00
0005434821345	9914	Economy	28000.00
0005432202998	9914	Economy	28000.00
0005435149794	9914	Economy	28000.00
0005434821362	9914	Economy	28000.00
0005435372683	9914	Economy	28000.00
0005435372646	9914	Economy	28000.00
0005435299730	9914	Economy	28000.00
0005435299732	9914	Economy	28000.00
0005434821552	9914	Economy	28000.00
0005434821524	9914	Economy	28000.00
0005435299733	9914	Economy	28000.00
0005434821355	9914	Economy	28000.00
0005434821368	9914	Economy	28000.00
0005434821488	9914	Economy	28000.00
0005434821439	9914	Economy	28000.00
0005435661903	9914	Economy	28000.00
0005434821566	9914	Economy	28000.00
0005435372658	9914	Economy	28000.00
0005435372684	9914	Economy	28000.00
0005432202999	9914	Economy	28000.00
0005435372685	9914	Economy	28000.00
0005434821522	9914	Economy	28000.00
0005432202994	9914	Economy	28000.00
0005434822084	9914	Economy	28000.00
0005435372645	9914	Economy	28000.00
0005435372656	9914	Economy	28000.00
0005432823431	9914	Economy	28000.00
0005435386514	9914	Economy	28000.00
0005434821525	9914	Economy	28000.00
0005435302157	9914	Economy	28000.00
0005435372666	9914	Economy	28000.00
0005435372644	9914	Economy	28000.00
0005434821759	9914	Economy	28000.00
0005434821337	9914	Economy	28000.00
0005435372679	9914	Economy	28000.00
0005435179389	9914	Economy	28000.00
0005434821772	9914	Economy	28000.00
0005434821822	9914	Economy	28000.00
0005435372668	9914	Economy	28000.00
0005434821655	9914	Economy	28000.00
0005434821681	9914	Economy	28000.00
0005432400062	9914	Economy	28000.00
0005432202993	9914	Economy	28000.00
0005435372692	9914	Economy	28000.00
0005435372660	9914	Economy	28000.00
0005435372637	9914	Economy	28000.00
0005434821705	9914	Economy	28000.00
0005435372669	9914	Economy	28000.00
0005434821682	9914	Economy	28000.00
0005435790279	7010	Economy	7400.00
0005435790278	7010	Economy	7400.00
0005435790280	7010	Economy	7400.00
0005435082711	7010	Economy	7400.00
0005435082712	7010	Economy	7400.00
0005435082716	7010	Economy	7400.00
0005435082714	7010	Economy	7400.00
0005435082715	7010	Economy	7400.00
0005435082713	7010	Economy	7400.00
0005435790265	26010	Economy	7400.00
0005435790263	26010	Economy	7400.00
0005435790262	26010	Economy	7400.00
0005435790256	26010	Economy	7400.00
0005435790255	26010	Economy	7400.00
0005434756064	9538	Business	32800.00
0005434756077	9538	Business	32800.00
0005434756068	9538	Business	32800.00
0005434213741	9538	Business	32800.00
0005434756052	9538	Business	32800.00
0005434756062	9538	Economy	10900.00
0005434756055	9538	Economy	10900.00
0005434756088	9538	Economy	10900.00
0005434756079	9538	Economy	10900.00
0005434756086	9538	Economy	10900.00
0005434756060	9538	Economy	12000.00
0005434756063	9538	Economy	12000.00
0005434756083	9538	Economy	12000.00
0005434756076	9538	Economy	12000.00
0005434213743	9538	Economy	12000.00
0005434756087	9538	Economy	10900.00
0005434756053	9538	Economy	10900.00
0005434213776	9538	Economy	10900.00
0005434756054	9538	Economy	10900.00
0005434756059	9538	Economy	10900.00
0005434213869	9538	Economy	10900.00
0005434756049	9538	Economy	10900.00
0005434756081	9538	Economy	10900.00
0005434213769	9538	Economy	10900.00
0005434756065	9538	Economy	10900.00
0005434756085	9538	Economy	10900.00
0005434213772	9538	Economy	10900.00
0005434756089	9538	Economy	10900.00
0005434756071	9538	Economy	10900.00
0005434756056	9538	Economy	10900.00
0005434213715	9538	Economy	10900.00
0005434756073	9538	Economy	10900.00
0005434213768	9538	Economy	10900.00
0005434213784	9538	Economy	10900.00
0005434756072	9538	Economy	10900.00
0005434756066	9538	Economy	10900.00
0005434756051	9538	Economy	10900.00
0005434213778	9538	Economy	10900.00
0005434756058	9538	Economy	10900.00
0005434213880	9538	Economy	10900.00
0005434756075	9538	Economy	10900.00
0005434756067	9538	Economy	10900.00
0005434213879	9538	Economy	10900.00
0005434756070	9538	Economy	10900.00
0005434756061	9538	Economy	10900.00
0005434213742	9538	Economy	10900.00
0005434756074	9538	Economy	10900.00
0005434213771	9538	Economy	10900.00
0005434756057	9538	Economy	10900.00
0005434213777	9538	Economy	10900.00
0005434756082	9538	Economy	10900.00
0005434756078	9538	Economy	10900.00
0005434213716	9538	Economy	10900.00
0005434756069	9538	Economy	10900.00
0005434756084	9538	Economy	10900.00
0005434756050	9538	Economy	10900.00
0005434756080	9538	Economy	10900.00
0005434214051	28615	Business	32800.00
0005434214069	28615	Business	32800.00
0005434214037	28615	Business	32800.00
0005434214032	28615	Business	32800.00
0005434214065	28615	Business	32800.00
0005434214061	28615	Business	32800.00
0005434214043	28615	Economy	10900.00
0005434214050	28615	Economy	10900.00
0005434214035	28615	Economy	10900.00
0005434214052	28615	Economy	10900.00
0005434214071	28615	Economy	10900.00
0005434214046	28615	Economy	12000.00
0005434214067	28615	Economy	10900.00
0005434214066	28615	Economy	10900.00
0005434214053	28615	Economy	10900.00
0005434214070	28615	Economy	10900.00
0005434214039	28615	Economy	10900.00
0005434214031	28615	Economy	10900.00
0005434214058	28615	Economy	10900.00
0005434214077	28615	Economy	10900.00
0005434214057	28615	Economy	10900.00
0005434214078	28615	Economy	10900.00
0005434214049	28615	Economy	10900.00
0005434214064	28615	Economy	10900.00
0005434214068	28615	Economy	10900.00
0005434214047	28615	Economy	10900.00
0005434214045	28615	Economy	10900.00
0005434214056	28615	Economy	10900.00
0005434214072	28615	Economy	10900.00
0005434214074	28615	Economy	10900.00
0005434214075	28615	Economy	10900.00
0005434214076	28615	Economy	10900.00
0005434214042	28615	Economy	10900.00
0005434214036	28615	Economy	10900.00
0005434214038	28615	Economy	10900.00
0005434214044	28615	Economy	10900.00
0005434214040	28615	Economy	10900.00
0005434214060	28615	Economy	10900.00
0005434214073	28615	Economy	10900.00
0005434214055	28615	Economy	10900.00
0005434214048	28615	Economy	10900.00
0005434214054	28615	Economy	10900.00
0005434214033	28615	Economy	10900.00
0005434214063	28615	Economy	10900.00
0005434214062	28615	Economy	10900.00
0005434214041	28615	Economy	10900.00
0005434214059	28615	Economy	10900.00
0005434214034	28615	Economy	10900.00
0005435100096	10811	Economy	8900.00
0005435100095	10811	Economy	8900.00
0005435100069	31804	Economy	9800.00
0005435100075	31804	Economy	8900.00
0005434760174	31804	Economy	8900.00
0005434760175	31804	Economy	8900.00
0005434760173	31804	Economy	8900.00
0005435100070	31804	Economy	8900.00
0005434639079	1955	Economy	20900.00
0005434639084	1955	Economy	20900.00
0005434639093	1955	Economy	19000.00
0005433202111	1955	Economy	19000.00
0005433202102	1955	Economy	19000.00
0005434639091	1955	Economy	19000.00
0005434639088	1955	Economy	19000.00
0005432290606	1955	Economy	19000.00
0005434639086	1955	Economy	19000.00
0005434639077	1955	Economy	19000.00
0005434639085	1955	Economy	19000.00
0005434639074	1955	Economy	19000.00
0005434639092	1955	Economy	19000.00
0005434639095	1955	Economy	19000.00
0005434639082	1955	Economy	19000.00
0005434639080	1955	Economy	19000.00
0005434639094	1955	Economy	19000.00
0005434639089	1955	Economy	19000.00
0005434639087	1955	Economy	19000.00
0005434639072	1955	Economy	19000.00
0005434639076	1955	Economy	19000.00
0005434639081	1955	Economy	19000.00
0005433202140	1955	Economy	19000.00
0005434639073	1955	Economy	19000.00
0005434639078	1955	Economy	19000.00
0005434639075	1955	Economy	19000.00
0005434639071	1955	Economy	19000.00
0005433202113	1955	Economy	19000.00
0005434639083	1955	Economy	19000.00
0005434639096	1955	Economy	19000.00
0005434639090	1955	Economy	19000.00
0005433202139	1955	Economy	19000.00
0005434639097	1955	Economy	19000.00
0005434639098	1955	Economy	19000.00
0005432290605	1955	Economy	19000.00
0005433202110	1955	Economy	19000.00
0005434639070	1955	Economy	19000.00
0005434638859	23288	Economy	20900.00
0005433202219	23288	Economy	20900.00
0005433202212	23288	Economy	19000.00
0005433202210	23288	Economy	19000.00
0005433202215	23288	Economy	19000.00
0005433202211	23288	Economy	19000.00
0005433202213	23288	Economy	19000.00
0005433202208	23288	Economy	19000.00
0005433202217	23288	Economy	19000.00
0005433202222	23288	Economy	19000.00
0005434638881	23288	Economy	19000.00
0005434638915	23288	Economy	19000.00
0005433202216	23288	Economy	19000.00
0005434638852	23288	Economy	19000.00
0005433202220	23288	Economy	19000.00
0005434638861	23288	Economy	19000.00
0005433202209	23288	Economy	19000.00
0005434638914	23288	Economy	19000.00
0005434638851	23288	Economy	19000.00
0005433202221	23288	Economy	19000.00
0005433202218	23288	Economy	19000.00
0005434638855	23288	Economy	19000.00
0005434638853	23288	Economy	19000.00
0005433202214	23288	Economy	19000.00
0005434638913	23288	Economy	19000.00
0005434638882	23288	Economy	19000.00
0005432111252	6071	Business	69700.00
0005434600559	6071	Business	69700.00
0005435326512	6071	Business	69700.00
0005433531258	6071	Business	69700.00
0005433533275	6071	Business	69700.00
0005432111250	6071	Business	69700.00
0005434600550	6071	Business	69700.00
0005434600551	6071	Economy	23200.00
0005434600549	6071	Economy	23200.00
0005433533274	6071	Economy	23200.00
0005434600561	6071	Economy	23200.00
0005433531260	6071	Economy	23200.00
0005434600548	6071	Economy	25600.00
0005433533271	6071	Economy	25600.00
0005435326515	6071	Economy	25600.00
0005433533272	6071	Economy	23200.00
0005434600569	6071	Economy	23200.00
0005434600556	6071	Economy	23200.00
0005434600571	6071	Economy	23200.00
0005433531259	6071	Economy	23200.00
0005434600565	6071	Economy	23200.00
0005434600572	6071	Economy	23200.00
0005434600552	6071	Economy	23200.00
0005434600560	6071	Economy	23200.00
0005434600564	6071	Economy	23200.00
0005435326545	6071	Economy	23200.00
0005433533273	6071	Economy	23200.00
0005434600553	6071	Economy	23200.00
0005432111253	6071	Economy	23200.00
0005434600555	6071	Economy	23200.00
0005434600563	6071	Economy	23200.00
0005434600566	6071	Economy	23200.00
0005434600570	6071	Economy	23200.00
0005434600558	6071	Economy	23200.00
0005435326546	6071	Economy	23200.00
0005434600554	6071	Economy	23200.00
0005434600574	6071	Economy	23200.00
0005433531257	6071	Economy	23200.00
0005435326516	6071	Economy	23200.00
0005432111251	6071	Economy	23200.00
0005434600567	6071	Economy	23200.00
0005434600573	6071	Economy	23200.00
0005434600568	6071	Economy	23200.00
0005434600557	6071	Economy	23200.00
0005434600562	6071	Economy	23200.00
0005435326517	6071	Economy	23200.00
0005435326623	18612	Business	69700.00
0005435326613	18612	Business	69700.00
0005434600366	18612	Business	69700.00
0005434600373	18612	Economy	23200.00
0005434600372	18612	Economy	23200.00
0005435326614	18612	Economy	23200.00
0005435326611	18612	Economy	23200.00
0005434600339	18612	Economy	23200.00
0005435326618	18612	Economy	23200.00
0005434600423	18612	Economy	23200.00
0005434600413	18612	Economy	25600.00
0005435326617	18612	Economy	23200.00
0005435326616	18612	Economy	23200.00
0005435326610	18612	Economy	23200.00
0005434600352	18612	Economy	23200.00
0005435326615	18612	Economy	23200.00
0005435326624	18612	Economy	23200.00
0005434600393	18612	Economy	23200.00
0005435326619	18612	Economy	23200.00
0005435326622	18612	Economy	23200.00
0005435326620	18612	Economy	23200.00
0005434600329	18612	Economy	23200.00
0005434600370	18612	Economy	23200.00
0005434600400	18612	Economy	23200.00
0005434600338	18612	Economy	23200.00
0005434600420	18612	Economy	23200.00
0005435326621	18612	Economy	23200.00
0005435326612	18612	Economy	23200.00
0005434550699	10678	Business	9100.00
0005434550651	10678	Business	9100.00
0005434550690	10678	Business	9100.00
0005434550666	10678	Business	9100.00
0005434550704	10678	Business	9100.00
0005434550695	10678	Business	9100.00
0005433180678	10678	Business	9100.00
0005434554042	10678	Business	9100.00
0005434550672	10678	Business	9100.00
0005434550653	10678	Economy	3000.00
0005434550662	10678	Economy	3000.00
0005434558195	10678	Economy	3000.00
0005434550691	10678	Economy	3000.00
0005434550671	10678	Economy	3000.00
0005434558196	10678	Economy	3000.00
0005433180676	10678	Economy	3300.00
0005434550698	10678	Economy	3300.00
0005433180658	10678	Economy	3300.00
0005434550655	10678	Economy	3000.00
0005433180675	10678	Economy	3000.00
0005434550664	10678	Economy	3000.00
0005434550654	10678	Economy	3000.00
0005434550673	10678	Economy	3000.00
0005434550667	10678	Economy	3000.00
0005434550703	10678	Economy	3000.00
0005434550705	10678	Economy	3000.00
0005434550681	10678	Economy	3000.00
0005433180711	10678	Economy	3000.00
0005434550677	10678	Economy	3000.00
0005434550656	10678	Economy	3000.00
0005434550658	10678	Economy	3000.00
0005434550684	10678	Economy	3000.00
0005434550689	10678	Economy	3000.00
0005434550657	10678	Economy	3000.00
0005434550680	10678	Economy	3000.00
0005434550700	10678	Economy	3000.00
0005434550688	10678	Economy	3000.00
0005434550659	10678	Economy	3000.00
0005434550701	10678	Economy	3000.00
0005434550652	10678	Economy	3000.00
0005434550670	10678	Economy	3000.00
0005433180672	10678	Economy	3000.00
0005434550692	10678	Economy	3000.00
0005434550661	10678	Economy	3000.00
0005434558197	10678	Economy	3000.00
0005433180679	10678	Economy	3000.00
0005434550687	10678	Economy	3000.00
0005434550685	10678	Economy	3000.00
0005433180666	10678	Economy	3000.00
0005433180654	10678	Economy	3000.00
0005434550676	10678	Economy	3000.00
0005434558194	10678	Economy	3000.00
0005434550665	10678	Economy	3000.00
0005434550682	10678	Economy	3000.00
0005434550675	10678	Economy	3000.00
0005434550694	10678	Economy	3000.00
0005434550683	10678	Economy	3000.00
0005434550697	10678	Economy	3000.00
0005434550674	10678	Economy	3000.00
0005433180683	10678	Economy	3000.00
0005434550663	10678	Economy	3000.00
0005434550696	10678	Economy	3000.00
0005434550668	10678	Economy	3000.00
0005434554043	10678	Economy	3000.00
0005434550686	10678	Economy	3000.00
0005433180742	10678	Economy	3000.00
0005434550702	10678	Economy	3000.00
0005434550678	10678	Economy	3000.00
0005434550693	10678	Economy	3000.00
0005433180709	10678	Economy	3000.00
0005434550679	10678	Economy	3000.00
0005433180653	10678	Economy	3000.00
0005434550660	10678	Economy	3000.00
0005433180671	10678	Economy	3000.00
0005434558193	10678	Economy	3000.00
0005434550669	10678	Economy	3000.00
0005433180875	27738	Business	9100.00
0005433180876	27738	Business	9100.00
0005433180878	27738	Economy	3000.00
0005433180872	27738	Economy	3000.00
0005433180859	27738	Economy	3300.00
0005433180880	27738	Economy	3000.00
0005433180867	27738	Economy	3000.00
0005433180877	27738	Economy	3000.00
0005433180879	27738	Economy	3000.00
0005433180864	27738	Economy	3000.00
0005433180857	27738	Economy	3000.00
0005433180863	27738	Economy	3000.00
0005433180856	27738	Economy	3000.00
0005433180862	27738	Economy	3000.00
0005433180861	27738	Economy	3000.00
0005433180858	27738	Economy	3000.00
0005433180869	27738	Economy	3000.00
0005433180873	27738	Economy	3000.00
0005433180874	27738	Economy	3000.00
0005433180855	27738	Economy	3000.00
0005433180860	27738	Economy	3000.00
0005433180870	27738	Economy	3000.00
0005433180871	27738	Economy	3000.00
0005433180866	27738	Economy	3000.00
0005433180868	27738	Economy	3000.00
0005433180865	27738	Economy	3000.00
0005434550335	27736	Business	9100.00
0005434550296	27736	Business	9100.00
0005434554025	27736	Economy	3000.00
0005434550407	27736	Economy	3300.00
0005434550279	27736	Economy	3300.00
0005434550409	27736	Economy	3300.00
0005434550295	27736	Economy	3000.00
0005434550392	27736	Economy	3000.00
0005434550347	27736	Economy	3000.00
0005434550310	27736	Economy	3000.00
0005434550278	27736	Economy	3000.00
0005434550408	27736	Economy	3000.00
0005434550405	27736	Economy	3000.00
0005434550340	27736	Economy	3000.00
0005434550271	27736	Economy	3000.00
0005434550406	27736	Economy	3000.00
0005434550349	27736	Economy	3000.00
0005434550304	27736	Economy	3000.00
0005434550355	27736	Economy	3000.00
0005434550343	27736	Economy	3000.00
0005434550307	27736	Economy	3000.00
0005434550311	27736	Economy	3000.00
0005434550423	27736	Economy	3000.00
0005434550337	27736	Economy	3000.00
0005434550289	27736	Economy	3000.00
0005434550350	27736	Economy	3000.00
0005434550473	27736	Economy	3000.00
0005434550272	27736	Economy	3000.00
0005434550370	27736	Economy	3000.00
0005433459180	6119	Economy	11700.00
0005433459178	6119	Economy	11700.00
0005433459181	6119	Economy	11700.00
0005435254437	6119	Economy	11700.00
0005433459179	6119	Economy	11700.00
0005435254433	6119	Economy	11700.00
0005435254450	19335	Economy	11700.00
0005433459164	19335	Economy	11700.00
0005435254451	19335	Economy	11700.00
0005433459148	19335	Economy	11700.00
0005433459163	19335	Economy	11700.00
0005433459149	19335	Economy	11700.00
0005435254452	19335	Economy	11700.00
0005433459145	19335	Economy	11700.00
0005433459147	19335	Economy	11700.00
0005433459162	19335	Economy	11700.00
0005435681730	6765	Business	51100.00
0005435681747	6765	Business	51100.00
0005435681757	6765	Business	51100.00
0005432136121	6765	Business	51100.00
0005435437582	6765	Business	51100.00
0005435681731	6765	Business	51100.00
0005435437581	6765	Business	51100.00
0005435681732	6765	Economy	17000.00
0005435630936	6765	Economy	17000.00
0005435630937	6765	Economy	17000.00
0005435437603	6765	Economy	17000.00
0005435681753	6765	Economy	17000.00
0005435681755	6765	Economy	17000.00
0005435661900	6765	Economy	18700.00
0005435681743	6765	Economy	18700.00
0005435681760	6765	Economy	18700.00
0005435437608	6765	Economy	18700.00
0005435681744	6765	Economy	17000.00
0005435681746	6765	Economy	17000.00
0005435661902	6765	Economy	17000.00
0005435437554	6765	Economy	17000.00
0005435437648	6765	Economy	17000.00
0005435437617	6765	Economy	17000.00
0005435719558	6765	Economy	17000.00
0005435681764	6765	Economy	17000.00
0005435681754	6765	Economy	17000.00
0005435437560	6765	Economy	17000.00
0005435437565	6765	Economy	17000.00
0005435681752	6765	Economy	17000.00
0005432136122	6765	Economy	17000.00
0005435681745	6765	Economy	17000.00
0005432136119	6765	Economy	17000.00
0005435681765	6765	Economy	17000.00
0005435681761	6765	Economy	17000.00
0005435681736	6765	Economy	17000.00
0005435681749	6765	Economy	17000.00
0005435681756	6765	Economy	17000.00
0005435681735	6765	Economy	17000.00
0005435681750	6765	Economy	17000.00
0005435437583	6765	Economy	17000.00
0005435681738	6765	Economy	17000.00
0005435681766	6765	Economy	17000.00
0005432136123	6765	Economy	17000.00
0005435437552	6765	Economy	17000.00
0005435681739	6765	Economy	17000.00
0005435681758	6765	Economy	17000.00
0005435681742	6765	Economy	17000.00
0005435681767	6765	Economy	17000.00
0005435437566	6765	Economy	17000.00
0005435630935	6765	Economy	17000.00
0005435681737	6765	Economy	17000.00
0005435681741	6765	Economy	17000.00
0005435661901	6765	Economy	17000.00
0005435681759	6765	Economy	17000.00
0005435681733	6765	Economy	17000.00
0005432136120	6765	Economy	17000.00
0005435681740	6765	Economy	17000.00
0005435681748	6765	Economy	17000.00
0005435681763	6765	Economy	17000.00
0005435681762	6765	Economy	17000.00
0005435681734	6765	Economy	17000.00
0005435217676	6765	Economy	17000.00
0005435681751	6765	Economy	17000.00
0005435437733	24604	Business	51100.00
0005435437739	24604	Business	51100.00
0005435219177	24604	Business	51100.00
0005435437734	24604	Business	51100.00
0005435661887	24604	Business	51100.00
0005435219176	24604	Economy	17000.00
0005435437754	24604	Economy	17000.00
0005432305725	24604	Economy	18700.00
0005435437755	24604	Economy	18700.00
0005435681405	24604	Economy	18700.00
0005435220295	24604	Economy	17000.00
0005435220299	24604	Economy	17000.00
0005435437737	24604	Economy	17000.00
0005432305726	24604	Economy	17000.00
0005435437744	24604	Economy	17000.00
0005434828672	24604	Economy	17000.00
0005435437756	24604	Economy	17000.00
0005435219175	24604	Economy	17000.00
0005434828671	24604	Economy	17000.00
0005435437750	24604	Economy	17000.00
0005435437736	24604	Economy	17000.00
0005435437740	24604	Economy	17000.00
0005435437753	24604	Economy	17000.00
0005435437749	24604	Economy	17000.00
0005435437745	24604	Economy	17000.00
0005435220298	24604	Economy	17000.00
0005435219179	24604	Economy	17000.00
0005435681393	24604	Economy	17000.00
0005435437743	24604	Economy	17000.00
0005435437735	24604	Economy	17000.00
0005434828673	24604	Economy	17000.00
0005435437752	24604	Economy	17000.00
0005435681396	24604	Economy	17000.00
0005435661889	24604	Economy	17000.00
0005435437742	24604	Economy	17000.00
0005435437748	24604	Economy	17000.00
0005435437751	24604	Economy	17000.00
0005432533265	24604	Economy	17000.00
0005434828670	24604	Economy	17000.00
0005435437746	24604	Economy	17000.00
0005435220296	24604	Economy	17000.00
0005435220297	24604	Economy	17000.00
0005435681388	24604	Economy	17000.00
0005435437741	24604	Economy	17000.00
0005435661888	24604	Economy	17000.00
0005435219180	24604	Economy	17000.00
0005435219178	24604	Economy	17000.00
0005435681394	24604	Economy	17000.00
0005435437747	24604	Economy	17000.00
0005435437738	24604	Economy	17000.00
0005435681406	24604	Economy	17000.00
0005435661886	24604	Economy	17000.00
0005432533264	24604	Economy	17000.00
0005435630914	24604	Economy	17000.00
0005435098534	11531	Business	26400.00
0005435098537	11531	Business	26400.00
0005435125971	11531	Business	26400.00
0005435125947	11531	Business	26400.00
0005435125968	11531	Economy	8800.00
0005435125963	11531	Economy	8800.00
0005435098532	11531	Economy	8800.00
0005435125954	11531	Economy	8800.00
0005435125958	11531	Economy	8800.00
0005435125967	11531	Economy	9700.00
0005435125977	11531	Economy	9700.00
0005435125976	11531	Economy	8800.00
0005435125970	11531	Economy	8800.00
0005435125948	11531	Economy	8800.00
0005435125955	11531	Economy	8800.00
0005435125943	11531	Economy	8800.00
0005435558046	11531	Economy	8800.00
0005435125962	11531	Economy	8800.00
0005435098536	11531	Economy	8800.00
0005435125944	11531	Economy	8800.00
0005435125966	11531	Economy	8800.00
0005435105950	11531	Economy	8800.00
0005435125946	11531	Economy	8800.00
0005435098533	11531	Economy	8800.00
0005435125974	11531	Economy	8800.00
0005435125940	11531	Economy	8800.00
0005435125951	11531	Economy	8800.00
0005435105949	11531	Economy	8800.00
0005435125956	11531	Economy	8800.00
0005435125949	11531	Economy	8800.00
0005435105951	11531	Economy	8800.00
0005435125941	11531	Economy	8800.00
0005435098530	11531	Economy	8800.00
0005435105952	11531	Economy	8800.00
0005435125964	11531	Economy	8800.00
0005435125979	11531	Economy	8800.00
0005435125978	11531	Economy	8800.00
0005435125969	11531	Economy	8800.00
0005435125961	11531	Economy	8800.00
0005435125939	11531	Economy	8800.00
0005435098529	11531	Economy	8800.00
0005435125942	11531	Economy	8800.00
0005435098535	11531	Economy	8800.00
0005435125975	11531	Economy	8800.00
0005435125960	11531	Economy	8800.00
0005435125950	11531	Economy	8800.00
0005435125965	11531	Economy	8800.00
0005435558045	11531	Economy	8800.00
0005435125959	11531	Economy	8800.00
0005435125973	11531	Economy	8800.00
0005435125938	11531	Economy	8800.00
0005435558044	11531	Economy	8800.00
0005435125972	11531	Economy	8800.00
0005435125953	11531	Economy	8800.00
0005435125952	11531	Economy	8800.00
0005435125957	11531	Economy	8800.00
0005435098531	11531	Economy	8800.00
0005435125945	11531	Economy	8800.00
0005435105926	31907	Business	26400.00
0005435125735	31907	Business	26400.00
0005435125671	31907	Business	26400.00
0005435125734	31907	Business	26400.00
0005435125674	31907	Business	26400.00
0005435125782	31907	Economy	8800.00
0005435125801	31907	Economy	8800.00
0005435125658	31907	Economy	8800.00
0005435125784	31907	Economy	8800.00
0005435125701	31907	Economy	8800.00
0005435125687	31907	Economy	9700.00
0005435125733	31907	Economy	9700.00
0005435125676	31907	Economy	8800.00
0005435125783	31907	Economy	8800.00
0005435125675	31907	Economy	8800.00
0005435125694	31907	Economy	8800.00
0005435125661	31907	Economy	8800.00
0005435558064	31907	Economy	8800.00
0005435125662	31907	Economy	8800.00
0005435125767	31907	Economy	8800.00
0005435125656	31907	Economy	8800.00
0005435125768	31907	Economy	8800.00
0005435558061	31907	Economy	8800.00
0005435125659	31907	Economy	8800.00
0005435125754	31907	Economy	8800.00
0005435558063	31907	Economy	8800.00
0005435105940	31907	Economy	8800.00
0005435105934	31907	Economy	8800.00
0005435558062	31907	Economy	8800.00
0005435125660	31907	Economy	8800.00
0005435125753	31907	Economy	8800.00
0005435125688	31907	Economy	8800.00
0005435125709	31907	Economy	8800.00
0005435732131	13562	Business	36600.00
0005433397616	13562	Business	36600.00
0005433397593	13562	Business	36600.00
0005433397601	13562	Business	36600.00
0005433397592	13562	Business	36600.00
0005433397581	13562	Business	36600.00
0005433397594	13562	Economy	12200.00
0005435732160	13562	Economy	12200.00
0005433397626	13562	Economy	12200.00
0005433397611	13562	Economy	12200.00
0005433397618	13562	Economy	12200.00
0005433397596	13562	Economy	13400.00
0005435732130	13562	Economy	13400.00
0005433397599	13562	Economy	13400.00
0005433397614	13562	Economy	13400.00
0005433397612	13562	Economy	12200.00
0005433397624	13562	Economy	12200.00
0005435732137	13562	Economy	12200.00
0005433397591	13562	Economy	12200.00
0005433397586	13562	Economy	12200.00
0005433397597	13562	Economy	12200.00
0005433397600	13562	Economy	12200.00
0005435732138	13562	Economy	12200.00
0005433397625	13562	Economy	12200.00
0005433397577	13562	Economy	12200.00
0005433397584	13562	Economy	12200.00
0005433397580	13562	Economy	12200.00
0005433397589	13562	Economy	12200.00
0005433397602	13562	Economy	12200.00
0005433397603	13562	Economy	12200.00
0005433397595	13562	Economy	12200.00
0005433397604	13562	Economy	12200.00
0005433397579	13562	Economy	12200.00
0005433397615	13562	Economy	12200.00
0005433397621	13562	Economy	12200.00
0005433397588	13562	Economy	12200.00
0005433397583	13562	Economy	12200.00
0005433397585	13562	Economy	12200.00
0005433397578	13562	Economy	12200.00
0005433397613	13562	Economy	12200.00
0005433397623	13562	Economy	12200.00
0005433397609	13562	Economy	12200.00
0005433397622	13562	Economy	12200.00
0005433397582	13562	Economy	12200.00
0005433397587	13562	Economy	12200.00
0005433397608	13562	Economy	12200.00
0005433397605	13562	Economy	12200.00
0005433397610	13562	Economy	12200.00
0005433397607	13562	Economy	12200.00
0005435732159	13562	Economy	12200.00
0005433397619	13562	Economy	12200.00
0005433397598	13562	Economy	12200.00
0005433397606	13562	Economy	12200.00
0005433397617	13562	Economy	12200.00
0005433397590	13562	Economy	12200.00
0005433397620	13562	Economy	12200.00
0005433397188	19380	Business	36600.00
0005433397245	19380	Business	36600.00
0005433397259	19380	Business	36600.00
0005433397254	19380	Business	36600.00
0005433397252	19380	Business	36600.00
0005435732223	19380	Business	36600.00
0005432297253	19380	Business	36600.00
0005435732220	19380	Economy	12200.00
0005433397250	19380	Economy	12200.00
0005435732216	19380	Economy	12200.00
0005433397222	19380	Economy	13400.00
0005435732217	19380	Economy	13400.00
0005433397297	19380	Economy	12200.00
0005433397300	19380	Economy	12200.00
0005433397217	19380	Economy	12200.00
0005433397260	19380	Economy	12200.00
0005433397257	19380	Economy	12200.00
0005432297252	19380	Economy	12200.00
0005433397290	19380	Economy	12200.00
0005433397251	19380	Economy	12200.00
0005433397347	19380	Economy	12200.00
0005433397348	19380	Economy	12200.00
0005433397226	19380	Economy	12200.00
0005433397187	19380	Economy	12200.00
0005435732225	19380	Economy	12200.00
0005433397410	19380	Economy	12200.00
0005433397230	19380	Economy	12200.00
0005433397273	19380	Economy	12200.00
0005435732224	19380	Economy	12200.00
0005433397296	19380	Economy	12200.00
0005435732218	19380	Economy	12200.00
0005435732214	19380	Economy	12200.00
0005433397221	19380	Economy	12200.00
0005433397301	19380	Economy	12200.00
0005433397203	19380	Economy	12200.00
0005435732215	19380	Economy	12200.00
0005435732219	19380	Economy	12200.00
0005433397200	19380	Economy	12200.00
0005435732221	19380	Economy	12200.00
0005433397225	19380	Economy	12200.00
0005433397220	19380	Economy	12200.00
0005435732222	19380	Economy	12200.00
0005433397330	19380	Economy	12200.00
0005435925167	13186	Business	11300.00
0005435925160	13186	Business	11300.00
0005435925165	13186	Business	11300.00
0005435925175	13186	Business	11300.00
0005435925158	13186	Business	11300.00
0005435925155	13186	Business	11300.00
0005435925166	13186	Economy	3800.00
0005435068230	13186	Economy	3800.00
0005435925157	13186	Economy	4100.00
0005435925159	13186	Economy	3800.00
0005435068165	13186	Economy	3800.00
0005435925162	13186	Economy	3800.00
0005435068186	13186	Economy	3800.00
0005435068160	13186	Economy	3800.00
0005435925174	13186	Economy	3800.00
0005435068159	13186	Economy	3800.00
0005435068185	13186	Economy	3800.00
0005435925176	13186	Economy	3800.00
0005435925161	13186	Economy	3800.00
0005435925156	13186	Economy	3800.00
0005435925173	13186	Economy	3800.00
0005435068187	13186	Economy	3800.00
0005435925172	13186	Economy	3800.00
0005435925170	13186	Economy	3800.00
0005435068194	13186	Economy	3800.00
0005435925169	13186	Economy	3800.00
0005435068322	13186	Economy	3800.00
0005435925168	13186	Economy	3800.00
0005435925171	13186	Economy	3800.00
0005435925164	13186	Economy	3800.00
0005435068184	13186	Economy	3800.00
0005435925163	13186	Economy	3800.00
0005435068231	13186	Economy	3800.00
0005435068158	13186	Economy	3800.00
0005435068568	15474	Business	11300.00
0005435068555	15474	Business	11300.00
0005435068575	15474	Business	11300.00
0005435068535	15474	Business	11300.00
0005435068549	15474	Business	11300.00
0005435068547	15474	Business	11300.00
0005435068541	15474	Business	11300.00
0005435068572	15474	Business	11300.00
0005435068552	15474	Economy	3800.00
0005435068566	15474	Economy	3800.00
0005435068531	15474	Economy	3800.00
0005435068569	15474	Economy	3800.00
0005435068560	15474	Economy	4100.00
0005435068545	15474	Economy	4100.00
0005435068578	15474	Economy	4100.00
0005435068567	15474	Economy	3800.00
0005435068532	15474	Economy	3800.00
0005435068558	15474	Economy	3800.00
0005435068537	15474	Economy	3800.00
0005435068533	15474	Economy	3800.00
0005435068563	15474	Economy	3800.00
0005435068564	15474	Economy	3800.00
0005435068559	15474	Economy	3800.00
0005435068530	15474	Economy	3800.00
0005435068540	15474	Economy	3800.00
0005435068580	15474	Economy	3800.00
0005435068565	15474	Economy	3800.00
0005435068550	15474	Economy	3800.00
0005435068577	15474	Economy	3800.00
0005435068536	15474	Economy	3800.00
0005435068554	15474	Economy	3800.00
0005435068571	15474	Economy	3800.00
0005435068543	15474	Economy	3800.00
0005435068542	15474	Economy	3800.00
0005435068562	15474	Economy	3800.00
0005435068579	15474	Economy	3800.00
0005435068538	15474	Economy	3800.00
0005435068546	15474	Economy	3800.00
0005435068539	15474	Economy	3800.00
0005435068529	15474	Economy	3800.00
0005435068553	15474	Economy	3800.00
0005435068573	15474	Economy	3800.00
0005435068561	15474	Economy	3800.00
0005435068548	15474	Economy	3800.00
0005435068557	15474	Economy	3800.00
0005435068574	15474	Economy	3800.00
0005435068551	15474	Economy	3800.00
0005435068570	15474	Economy	3800.00
0005435068534	15474	Economy	3800.00
0005435068576	15474	Economy	3800.00
0005435068544	15474	Economy	3800.00
0005435068581	15474	Economy	3800.00
0005435068556	15474	Economy	3800.00
0005435808123	23179	Economy	27100.00
0005435808126	23179	Economy	27100.00
0005435808130	23179	Economy	24700.00
0005435808120	23179	Economy	24700.00
0005433407480	23179	Economy	24700.00
0005435808128	23179	Economy	24700.00
0005435808117	23179	Economy	24700.00
0005435808127	23179	Economy	24700.00
0005435808124	23179	Economy	24700.00
0005435808119	23179	Economy	24700.00
0005435808114	23179	Economy	24700.00
0005435808132	23179	Economy	24700.00
0005435808113	23179	Economy	24700.00
0005435808129	23179	Economy	24700.00
0005435808118	23179	Economy	24700.00
0005435808115	23179	Economy	24700.00
0005435808135	23179	Economy	24700.00
0005435808134	23179	Economy	24700.00
0005435808121	23179	Economy	24700.00
0005435808122	23179	Economy	24700.00
0005435808133	23179	Economy	24700.00
0005435808131	23179	Economy	24700.00
0005435808125	23179	Economy	24700.00
0005435808116	23179	Economy	24700.00
0005434214103	10698	Business	61300.00
0005434214117	10698	Business	61300.00
0005434214104	10698	Business	61300.00
0005434214121	10698	Business	61300.00
0005434214113	10698	Business	61300.00
0005434214100	10698	Business	61300.00
0005434214091	10698	Business	61300.00
0005434214087	10698	Economy	20400.00
0005434214096	10698	Economy	20400.00
0005434214099	10698	Economy	20400.00
0005434214112	10698	Economy	20400.00
0005434214119	10698	Economy	20400.00
0005434214079	10698	Economy	20400.00
0005434755741	10698	Economy	20400.00
0005434214124	10698	Economy	20400.00
0005434214092	10698	Economy	22500.00
0005434214123	10698	Economy	22500.00
0005434214089	10698	Economy	22500.00
0005434214098	10698	Economy	20400.00
0005434214115	10698	Economy	20400.00
0005434755725	10698	Economy	20400.00
0005434214101	10698	Economy	20400.00
0005434214085	10698	Economy	20400.00
0005434214102	10698	Economy	20400.00
0005434214125	10698	Economy	20400.00
0005434214111	10698	Economy	20400.00
0005434214116	10698	Economy	20400.00
0005434755792	10698	Economy	20400.00
0005434214090	10698	Economy	20400.00
0005434214110	10698	Economy	20400.00
0005434214084	10698	Economy	20400.00
0005434214088	10698	Economy	20400.00
0005434214094	10698	Economy	20400.00
0005434755787	10698	Economy	20400.00
0005434755758	10698	Economy	20400.00
0005434214120	10698	Economy	20400.00
0005434214126	10698	Economy	20400.00
0005434214086	10698	Economy	20400.00
0005434755740	10698	Economy	20400.00
0005434214083	10698	Economy	20400.00
0005434214107	10698	Economy	20400.00
0005434214080	10698	Economy	20400.00
0005434214081	10698	Economy	20400.00
0005434214082	10698	Economy	20400.00
0005434214114	10698	Economy	20400.00
0005434755717	10698	Economy	20400.00
0005434214106	10698	Economy	20400.00
0005434214097	10698	Economy	20400.00
0005434214108	10698	Economy	20400.00
0005434214095	10698	Economy	20400.00
0005434214109	10698	Economy	20400.00
0005434214105	10698	Economy	20400.00
0005434214122	10698	Economy	20400.00
0005434214118	10698	Economy	20400.00
0005434214093	10698	Economy	20400.00
0005434756044	28697	Business	61300.00
0005434756012	28697	Business	61300.00
0005434756017	28697	Business	61300.00
0005434756020	28697	Business	61300.00
0005434756019	28697	Business	61300.00
0005434213770	28697	Economy	20400.00
0005434756011	28697	Economy	20400.00
0005434756010	28697	Economy	20400.00
0005434756022	28697	Economy	20400.00
0005434756014	28697	Economy	22500.00
0005434756041	28697	Economy	22500.00
0005434213811	28697	Economy	20400.00
0005434756028	28697	Economy	20400.00
0005434756025	28697	Economy	20400.00
0005434756037	28697	Economy	20400.00
0005434756008	28697	Economy	20400.00
0005434756036	28697	Economy	20400.00
0005434756029	28697	Economy	20400.00
0005434756047	28697	Economy	20400.00
0005434756027	28697	Economy	20400.00
0005434756016	28697	Economy	20400.00
0005434756039	28697	Economy	20400.00
0005434756035	28697	Economy	20400.00
0005434756042	28697	Economy	20400.00
0005434756045	28697	Economy	20400.00
0005434756046	28697	Economy	20400.00
0005434213734	28697	Economy	20400.00
0005434756026	28697	Economy	20400.00
0005434756034	28697	Economy	20400.00
0005434756018	28697	Economy	20400.00
0005434756033	28697	Economy	20400.00
0005434756030	28697	Economy	20400.00
0005434756038	28697	Economy	20400.00
0005434756021	28697	Economy	20400.00
0005434756009	28697	Economy	20400.00
0005434756040	28697	Economy	20400.00
0005434756043	28697	Economy	20400.00
0005434756024	28697	Economy	20400.00
0005434756023	28697	Economy	20400.00
0005434756015	28697	Economy	20400.00
0005434213810	28697	Economy	20400.00
0005434756032	28697	Economy	20400.00
0005434756031	28697	Economy	20400.00
0005434756048	28697	Economy	20400.00
0005434756013	28697	Economy	20400.00
0005432125381	5464	Business	29500.00
0005435039155	5464	Business	29500.00
0005435039188	5464	Business	29500.00
0005435039133	5464	Business	29500.00
0005435043276	5464	Business	29500.00
0005435039127	5464	Business	29500.00
0005435039177	5464	Business	29500.00
0005435039180	5464	Business	29500.00
0005435039179	5464	Business	29500.00
0005435039169	5464	Business	29500.00
0005435039163	5464	Business	29500.00
0005435006792	5464	Business	29500.00
0005435039165	5464	Economy	9800.00
0005434229025	5464	Economy	9800.00
0005435039182	5464	Economy	9800.00
0005435006805	5464	Economy	9800.00
0005435039186	5464	Economy	9800.00
0005435006797	5464	Economy	9800.00
0005434228973	5464	Economy	9800.00
0005435006806	5464	Economy	9800.00
0005435006814	5464	Economy	9800.00
0005435039132	5464	Economy	9800.00
0005435039181	5464	Economy	9800.00
0005435039126	5464	Economy	9800.00
0005435039178	5464	Economy	9800.00
0005435042835	5464	Economy	9800.00
0005435039174	5464	Economy	9800.00
0005435006809	5464	Economy	9800.00
0005434228976	5464	Economy	9800.00
0005435039146	5464	Economy	9800.00
0005435006803	5464	Economy	9800.00
0005435006810	5464	Economy	9800.00
0005435039190	5464	Economy	9800.00
0005435006811	5464	Economy	9800.00
0005435039183	5464	Economy	9800.00
0005435006799	5464	Economy	9800.00
0005435039129	5464	Economy	9800.00
0005434229003	5464	Economy	9800.00
0005435039136	5464	Economy	9800.00
0005435006802	5464	Economy	9800.00
0005435039149	5464	Economy	9800.00
0005435006815	5464	Economy	9800.00
0005435039135	5464	Economy	9800.00
0005432125382	5464	Economy	9800.00
0005435006808	5464	Economy	9800.00
0005435039171	5464	Economy	9800.00
0005434228987	5464	Economy	9800.00
0005435039191	5464	Economy	9800.00
0005435039185	5464	Economy	9800.00
0005435039159	5464	Economy	10800.00
0005434228975	5464	Economy	10800.00
0005435006816	5464	Economy	10800.00
0005435039162	5464	Economy	10800.00
0005434228989	5464	Economy	9800.00
0005435039175	5464	Economy	10800.00
0005435039141	5464	Economy	9800.00
0005435039150	5464	Economy	9800.00
0005435039134	5464	Economy	9800.00
0005435039158	5464	Economy	9800.00
0005435039140	5464	Economy	9800.00
0005432125380	5464	Economy	9800.00
0005435039172	5464	Economy	9800.00
0005435006795	5464	Economy	9800.00
0005435039189	5464	Economy	9800.00
0005435039131	5464	Economy	9800.00
0005435039168	5464	Economy	9800.00
0005435039137	5464	Economy	9800.00
0005435039154	5464	Economy	9800.00
0005432125384	5464	Economy	9800.00
0005435039170	5464	Economy	9800.00
0005435006804	5464	Economy	9800.00
0005435006794	5464	Economy	9800.00
0005434229053	5464	Economy	9800.00
0005435039152	5464	Economy	9800.00
0005432125385	5464	Economy	9800.00
0005434229055	5464	Economy	9800.00
0005435039157	5464	Economy	9800.00
0005435039164	5464	Economy	9800.00
0005435006807	5464	Economy	9800.00
0005434229013	5464	Economy	9800.00
0005435042836	5464	Economy	9800.00
0005435006800	5464	Economy	9800.00
0005432125383	5464	Economy	9800.00
0005435039145	5464	Economy	9800.00
0005435039192	5464	Economy	9800.00
0005435006801	5464	Economy	9800.00
0005435039130	5464	Economy	9800.00
0005435039128	5464	Economy	9800.00
0005435039166	5464	Economy	9800.00
0005435039138	5464	Economy	9800.00
0005435039160	5464	Economy	9800.00
0005434229026	5464	Economy	9800.00
0005435039139	5464	Economy	9800.00
0005435039153	5464	Economy	9800.00
0005435039148	5464	Economy	9800.00
0005435039187	5464	Economy	9800.00
0005435039161	5464	Economy	9800.00
0005435006812	5464	Economy	9800.00
0005435039143	5464	Economy	9800.00
0005435039184	5464	Economy	9800.00
0005434228988	5464	Economy	9800.00
0005435039144	5464	Economy	9800.00
0005435039156	5464	Economy	9800.00
0005434229001	5464	Economy	9800.00
0005435039151	5464	Economy	9800.00
0005435006796	5464	Economy	9800.00
0005435006813	5464	Economy	9800.00
0005435039125	5464	Economy	9800.00
0005435006793	5464	Economy	9800.00
0005435039147	5464	Economy	9800.00
0005435006798	5464	Economy	9800.00
0005435039176	5464	Economy	9800.00
0005434229054	5464	Economy	9800.00
0005435039173	5464	Economy	9800.00
0005434228986	5464	Economy	9800.00
0005435039142	5464	Economy	9800.00
0005435039167	5464	Economy	9800.00
0005435038774	12950	Business	29500.00
0005435038647	12950	Business	29500.00
0005434229154	12950	Business	29500.00
0005435038775	12950	Business	29500.00
0005434229170	12950	Business	29500.00
0005435038643	12950	Business	29500.00
0005432304362	12950	Business	29500.00
0005435038880	12950	Business	29500.00
0005435038744	12950	Business	29500.00
0005434229157	12950	Economy	9800.00
0005435038717	12950	Economy	9800.00
0005434229156	12950	Economy	9800.00
0005434229151	12950	Economy	9800.00
0005435006696	12950	Economy	9800.00
0005434229173	12950	Economy	9800.00
0005435038740	12950	Economy	9800.00
0005435038665	12950	Economy	9800.00
0005435038684	12950	Economy	9800.00
0005434229152	12950	Economy	9800.00
0005435038829	12950	Economy	9800.00
0005434229167	12950	Economy	9800.00
0005435038638	12950	Economy	9800.00
0005435038637	12950	Economy	9800.00
0005435038642	12950	Economy	9800.00
0005434229155	12950	Economy	9800.00
0005435038639	12950	Economy	9800.00
0005434229158	12950	Economy	9800.00
0005435006660	12950	Economy	9800.00
0005435038780	12950	Economy	9800.00
0005435038621	12950	Economy	9800.00
0005435038622	12950	Economy	9800.00
0005435006622	12950	Economy	9800.00
0005435038716	12950	Economy	9800.00
0005435038685	12950	Economy	9800.00
0005435038803	12950	Economy	10800.00
0005435038731	12950	Economy	10800.00
0005435038826	12950	Economy	9800.00
0005435006697	12950	Economy	9800.00
0005434229161	12950	Economy	9800.00
0005435038664	12950	Economy	9800.00
0005434229162	12950	Economy	9800.00
0005434229164	12950	Economy	9800.00
0005435006695	12950	Economy	9800.00
0005435006667	12950	Economy	9800.00
0005435038843	12950	Economy	9800.00
0005435038795	12950	Economy	9800.00
0005435038672	12950	Economy	9800.00
0005435006659	12950	Economy	9800.00
0005434229160	12950	Economy	9800.00
0005434229166	12950	Economy	9800.00
0005434229163	12950	Economy	9800.00
0005435038746	12950	Economy	9800.00
0005435038881	12950	Economy	9800.00
0005435006693	12950	Economy	9800.00
0005435038844	12950	Economy	9800.00
0005435038644	12950	Economy	9800.00
0005435038741	12950	Economy	9800.00
0005435006628	12950	Economy	9800.00
0005435038630	12950	Economy	9800.00
0005434229168	12950	Economy	9800.00
0005435038747	12950	Economy	9800.00
0005434229165	12950	Economy	9800.00
0005434229172	12950	Economy	9800.00
0005434229153	12950	Economy	9800.00
0005435038663	12950	Economy	9800.00
0005434229159	12950	Economy	9800.00
0005432304363	12950	Economy	9800.00
0005435038745	12950	Economy	9800.00
0005435038679	12950	Economy	9800.00
0005434229171	12950	Economy	9800.00
0005435038651	12950	Economy	9800.00
0005432304361	12950	Economy	9800.00
0005435038682	12950	Economy	9800.00
0005435038650	12950	Economy	9800.00
0005434229169	12950	Economy	9800.00
0005435038666	12950	Economy	9800.00
0005432188575	14859	Business	52900.00
0005434426311	14859	Business	52900.00
0005434426324	14859	Business	52900.00
0005434426305	14859	Economy	17600.00
0005434426304	14859	Economy	17600.00
0005434426319	14859	Economy	17600.00
0005434426301	14859	Economy	17600.00
0005434426296	14859	Economy	17600.00
0005435554109	14859	Economy	19400.00
0005434411735	14859	Economy	19400.00
0005434426300	14859	Economy	19400.00
0005434426322	14859	Economy	19400.00
0005434426306	14859	Economy	17600.00
0005434426297	14859	Economy	17600.00
0005434426321	14859	Economy	17600.00
0005432188573	14859	Economy	17600.00
0005434426318	14859	Economy	17600.00
0005434426313	14859	Economy	17600.00
0005434426308	14859	Economy	17600.00
0005434426302	14859	Economy	17600.00
0005434426323	14859	Economy	17600.00
0005434426310	14859	Economy	17600.00
0005434426317	14859	Economy	17600.00
0005434426303	14859	Economy	17600.00
0005434411734	14859	Economy	17600.00
0005434411733	14859	Economy	17600.00
0005432188574	14859	Economy	17600.00
0005434411732	14859	Economy	17600.00
0005435902414	14859	Economy	17600.00
0005434426316	14859	Economy	17600.00
0005434411736	14859	Economy	17600.00
0005434426298	14859	Economy	17600.00
0005434426314	14859	Economy	17600.00
0005434426309	14859	Economy	17600.00
0005434426299	14859	Economy	17600.00
0005434426312	14859	Economy	17600.00
0005434426307	14859	Economy	17600.00
0005435554118	14859	Economy	17600.00
0005435902413	14859	Economy	17600.00
0005435902412	14859	Economy	17600.00
0005434426315	14859	Economy	17600.00
0005434426325	14859	Economy	17600.00
0005435902394	14859	Economy	17600.00
0005434426320	14859	Economy	17600.00
0005432059485	20235	Business	52900.00
0005434426137	20235	Business	52900.00
0005434426233	20235	Business	52900.00
0005435902536	20235	Business	52900.00
0005435902534	20235	Business	52900.00
0005434426188	20235	Business	52900.00
0005435902548	20235	Business	52900.00
0005435902547	20235	Business	52900.00
0005434426185	20235	Business	52900.00
0005434426127	20235	Economy	17600.00
0005435902540	20235	Economy	19400.00
0005434426187	20235	Economy	17600.00
0005435902545	20235	Economy	17600.00
0005435902538	20235	Economy	17600.00
0005435902537	20235	Economy	17600.00
0005435554148	20235	Economy	17600.00
0005435902544	20235	Economy	17600.00
0005434426184	20235	Economy	17600.00
0005435902531	20235	Economy	17600.00
0005434426104	20235	Economy	17600.00
0005435554146	20235	Economy	17600.00
0005435902533	20235	Economy	17600.00
0005435902546	20235	Economy	17600.00
0005435902532	20235	Economy	17600.00
0005434426115	20235	Economy	17600.00
0005435902542	20235	Economy	17600.00
0005435554147	20235	Economy	17600.00
0005434411704	20235	Economy	17600.00
0005434426146	20235	Economy	17600.00
0005435902539	20235	Economy	17600.00
0005434426087	20235	Economy	17600.00
0005434426102	20235	Economy	17600.00
0005434426109	20235	Economy	17600.00
0005435554144	20235	Economy	17600.00
0005434411709	20235	Economy	17600.00
0005434426231	20235	Economy	17600.00
0005435554145	20235	Economy	17600.00
0005435902530	20235	Economy	17600.00
0005434426106	20235	Economy	17600.00
0005435902541	20235	Economy	17600.00
0005434426105	20235	Economy	17600.00
0005435902543	20235	Economy	17600.00
0005435902535	20235	Economy	17600.00
0005434426114	20235	Economy	17600.00
0005432059486	20235	Economy	17600.00
0005433434202	26538	Business	18500.00
0005435981870	26538	Business	18500.00
0005435981872	26538	Business	18500.00
0005435981849	26538	Business	18500.00
0005433434190	26538	Business	18500.00
0005435981867	26538	Business	18500.00
0005435981846	26538	Business	18500.00
0005435981886	26538	Business	18500.00
0005435981871	26538	Business	18500.00
0005435981848	26538	Business	18500.00
0005433434203	26538	Economy	6200.00
0005435981874	26538	Economy	6200.00
0005435981850	26538	Economy	6200.00
0005435981843	26538	Economy	6200.00
0005435981877	26538	Economy	6200.00
0005433434210	26538	Economy	6200.00
0005435981887	26538	Economy	6800.00
0005435981884	26538	Economy	6800.00
0005435981845	26538	Economy	6200.00
0005435981863	26538	Economy	6200.00
0005432300203	26538	Economy	6200.00
0005433434194	26538	Economy	6200.00
0005435981879	26538	Economy	6200.00
0005433434252	26538	Economy	6200.00
0005433434196	26538	Economy	6200.00
0005435981878	26538	Economy	6200.00
0005435981873	26538	Economy	6200.00
0005435981862	26538	Economy	6200.00
0005435981856	26538	Economy	6200.00
0005435981842	26538	Economy	6200.00
0005435981864	26538	Economy	6200.00
0005435981880	26538	Economy	6200.00
0005435981853	26538	Economy	6200.00
0005433434181	26538	Economy	6200.00
0005433434195	26538	Economy	6200.00
0005433434187	26538	Economy	6200.00
0005435981857	26538	Economy	6200.00
0005435981865	26538	Economy	6200.00
0005435981881	26538	Economy	6200.00
0005434270170	26538	Economy	6200.00
0005435981859	26538	Economy	6200.00
0005435981868	26538	Economy	6200.00
0005435981858	26538	Economy	6200.00
0005435981875	26538	Economy	6200.00
0005433434191	26538	Economy	6200.00
0005433434185	26538	Economy	6200.00
0005433434186	26538	Economy	6200.00
0005432300207	26538	Economy	6200.00
0005433434184	26538	Economy	6200.00
0005435981854	26538	Economy	6200.00
0005435981866	26538	Economy	6200.00
0005433434180	26538	Economy	6200.00
0005435981869	26538	Economy	6200.00
0005435981847	26538	Economy	6200.00
0005432300206	26538	Economy	6200.00
0005432300205	26538	Economy	6200.00
0005435981888	26538	Economy	6200.00
0005435981860	26538	Economy	6200.00
0005432300204	26538	Economy	6200.00
0005435981844	26538	Economy	6200.00
0005435981883	26538	Economy	6200.00
0005435981852	26538	Economy	6200.00
0005435981882	26538	Economy	6200.00
0005435981876	26538	Economy	6200.00
0005435981885	26538	Economy	6200.00
0005435981851	26538	Economy	6200.00
0005434273052	26538	Economy	6200.00
0005433434209	26538	Economy	6200.00
0005435981861	26538	Economy	6200.00
0005435981855	26538	Economy	6200.00
0005433434416	26705	Business	18500.00
0005433434430	26705	Business	18500.00
0005433434418	26705	Business	18500.00
0005433434423	26705	Business	18500.00
0005434271293	26705	Business	18500.00
0005433434432	26705	Business	18500.00
0005435981559	26705	Business	18500.00
0005433434434	26705	Business	18500.00
0005435981641	26705	Business	18500.00
0005433434417	26705	Economy	6200.00
0005435981563	26705	Economy	6200.00
0005433434426	26705	Economy	6200.00
0005435981514	26705	Economy	6200.00
0005435981564	26705	Economy	6800.00
0005434270188	26705	Economy	6800.00
0005433434420	26705	Economy	6800.00
0005433434435	26705	Economy	6800.00
0005433434436	26705	Economy	6200.00
0005433434410	26705	Economy	6200.00
0005433434421	26705	Economy	6200.00
0005433434437	26705	Economy	6200.00
0005433434438	26705	Economy	6200.00
0005433434425	26705	Economy	6200.00
0005434269083	26705	Economy	6200.00
0005434270187	26705	Economy	6200.00
0005433434412	26705	Economy	6200.00
0005432051099	26705	Economy	6200.00
0005433434414	26705	Economy	6200.00
0005434271294	26705	Economy	6200.00
0005435981629	26705	Economy	6200.00
0005434271292	26705	Economy	6200.00
0005435981518	26705	Economy	6200.00
0005435981509	26705	Economy	6200.00
0005434270186	26705	Economy	6200.00
0005433434419	26705	Economy	6200.00
0005432051100	26705	Economy	6200.00
0005433434433	26705	Economy	6200.00
0005433434422	26705	Economy	6200.00
0005433434428	26705	Economy	6200.00
0005433434429	26705	Economy	6200.00
0005433434415	26705	Economy	6200.00
0005433434431	26705	Economy	6200.00
0005433434424	26705	Economy	6200.00
0005435981527	26705	Economy	6200.00
0005433434411	26705	Economy	6200.00
0005434269084	26705	Economy	6200.00
0005432051098	26705	Economy	6200.00
0005433434413	26705	Economy	6200.00
0005433434427	26705	Economy	6200.00
0005432583791	3186	Economy	11100.00
0005432583812	3186	Economy	11100.00
0005432583802	3186	Economy	11100.00
0005432583809	3186	Economy	10100.00
0005432583805	3186	Economy	10100.00
0005432583792	3186	Economy	10100.00
0005432583806	3186	Economy	10100.00
0005432583793	3186	Economy	10100.00
0005432583813	3186	Economy	10100.00
0005432583790	3186	Economy	10100.00
0005432216246	3186	Economy	10100.00
0005432583800	3186	Economy	10100.00
0005432583794	3186	Economy	10100.00
0005432857898	3186	Economy	10100.00
0005432583796	3186	Economy	10100.00
0005432583795	3186	Economy	10100.00
0005432583798	3186	Economy	10100.00
0005432583788	3186	Economy	10100.00
0005432583797	3186	Economy	10100.00
0005432583799	3186	Economy	10100.00
0005432216248	3186	Economy	10100.00
0005432583807	3186	Economy	10100.00
0005432583804	3186	Economy	10100.00
0005432857881	3186	Economy	10100.00
0005432583811	3186	Economy	10100.00
0005432583810	3186	Economy	10100.00
0005432216245	3186	Economy	10100.00
0005432216247	3186	Economy	10100.00
0005432857852	3186	Economy	10100.00
0005432583803	3186	Economy	10100.00
0005432583801	3186	Economy	10100.00
0005432583789	3186	Economy	10100.00
0005432583808	3186	Economy	10100.00
0005432583638	31497	Economy	11100.00
0005432583723	31497	Economy	11100.00
0005432583696	31497	Economy	11100.00
0005432583639	31497	Economy	10100.00
0005432583722	31497	Economy	10100.00
0005432857950	31497	Economy	10100.00
0005432857954	31497	Economy	10100.00
0005432583679	31497	Economy	10100.00
0005432583629	31497	Economy	10100.00
0005432857957	31497	Economy	10100.00
0005432583628	31497	Economy	10100.00
0005432583689	31497	Economy	10100.00
0005432857951	31497	Economy	10100.00
0005432857953	31497	Economy	10100.00
0005432857956	31497	Economy	10100.00
0005432857960	31497	Economy	10100.00
0005432583627	31497	Economy	10100.00
0005432583692	31497	Economy	10100.00
0005432583607	31497	Economy	10100.00
0005432583623	31497	Economy	10100.00
0005432583702	31497	Economy	10100.00
0005432583646	31497	Economy	10100.00
0005432583652	31497	Economy	10100.00
0005432583618	31497	Economy	10100.00
0005432857949	31497	Economy	10100.00
0005432583678	31497	Economy	10100.00
0005432857952	31497	Economy	10100.00
0005432857955	31497	Economy	10100.00
0005432857958	31497	Economy	10100.00
0005432857959	31497	Economy	10100.00
0005432583697	31497	Economy	10100.00
0005432583680	31497	Economy	10100.00
0005434943268	914	Economy	8300.00
0005434943263	914	Economy	8300.00
0005434943264	914	Economy	7500.00
0005434943265	914	Economy	7500.00
0005434943262	914	Economy	7500.00
0005433255047	914	Economy	7500.00
0005433255040	914	Economy	7500.00
0005433255039	914	Economy	7500.00
0005433255021	914	Economy	7500.00
0005434943266	914	Economy	7500.00
0005433255036	914	Economy	7500.00
0005434943269	914	Economy	7500.00
0005434943261	914	Economy	7500.00
0005434943267	914	Economy	7500.00
0005434943237	16227	Economy	8300.00
0005434943211	16227	Economy	7500.00
0005433255069	16227	Economy	7500.00
0005434943206	16227	Economy	7500.00
0005433255070	16227	Economy	7500.00
0005434943209	16227	Economy	7500.00
0005433255068	16227	Economy	7500.00
0005433255066	16227	Economy	7500.00
0005434943184	16227	Economy	7500.00
0005433255071	16227	Economy	7500.00
0005434943210	16227	Economy	7500.00
0005433255067	16227	Economy	7500.00
0005435652605	21736	Business	9800.00
0005435652593	21736	Business	9800.00
0005435652573	21736	Business	9800.00
0005435652608	21736	Business	9800.00
0005435652619	21736	Business	9800.00
0005435652591	21736	Business	9800.00
0005435652562	21736	Business	9800.00
0005435652580	21736	Business	9800.00
0005435652590	21736	Business	9800.00
0005433367257	21736	Business	9800.00
0005433367284	21736	Business	9800.00
0005435652567	21736	Economy	3300.00
0005433367229	21736	Economy	3300.00
0005435652613	21736	Economy	3300.00
0005435652594	21736	Economy	3300.00
0005435652584	21736	Economy	3300.00
0005435652565	21736	Economy	3300.00
0005435652582	21736	Economy	3300.00
0005435652611	21736	Economy	3300.00
0005435652577	21736	Economy	3600.00
0005435652596	21736	Economy	3600.00
0005435652620	21736	Economy	3600.00
0005435652561	21736	Economy	3300.00
0005435652571	21736	Economy	3300.00
0005433367233	21736	Economy	3300.00
0005435652601	21736	Economy	3300.00
0005435652583	21736	Economy	3300.00
0005435652576	21736	Economy	3300.00
0005435652617	21736	Economy	3300.00
0005435652599	21736	Economy	3300.00
0005433367242	21736	Economy	3300.00
0005435652578	21736	Economy	3300.00
0005435652604	21736	Economy	3300.00
0005435652568	21736	Economy	3300.00
0005435652595	21736	Economy	3300.00
0005435652610	21736	Economy	3300.00
0005435652612	21736	Economy	3300.00
0005435652607	21736	Economy	3300.00
0005435652598	21736	Economy	3300.00
0005435652588	21736	Economy	3300.00
0005433367256	21736	Economy	3300.00
0005435652563	21736	Economy	3300.00
0005435652570	21736	Economy	3300.00
0005433367277	21736	Economy	3300.00
0005433367280	21736	Economy	3300.00
0005435652564	21736	Economy	3300.00
0005435652603	21736	Economy	3300.00
0005433367251	21736	Economy	3300.00
0005435652587	21736	Economy	3300.00
0005435652618	21736	Economy	3300.00
0005435652602	21736	Economy	3300.00
0005435652585	21736	Economy	3300.00
0005435652569	21736	Economy	3300.00
0005435652579	21736	Economy	3300.00
0005435652581	21736	Economy	3300.00
0005435652575	21736	Economy	3300.00
0005435652616	21736	Economy	3300.00
0005433367232	21736	Economy	3300.00
0005435652615	21736	Economy	3300.00
0005435652566	21736	Economy	3300.00
0005435652600	21736	Economy	3300.00
0005435652606	21736	Economy	3300.00
0005435652597	21736	Economy	3300.00
0005435652586	21736	Economy	3300.00
0005433367397	21736	Economy	3300.00
0005435652589	21736	Economy	3300.00
0005435652609	21736	Economy	3300.00
0005435652572	21736	Economy	3300.00
0005435652592	21736	Economy	3300.00
0005435652574	21736	Economy	3300.00
0005433367258	21736	Economy	3300.00
0005435652614	21736	Economy	3300.00
0005433784620	9385	Business	186200.00
0005434270176	9385	Business	186200.00
0005433805056	9385	Business	186200.00
0005433784601	9385	Business	186200.00
0005433784605	9385	Business	186200.00
0005433784621	9385	Business	186200.00
0005433763073	9385	Business	186200.00
0005433784610	9385	Business	186200.00
0005433763076	9385	Business	186200.00
0005434270174	9385	Business	186200.00
0005432665254	9385	Business	186200.00
0005433805055	9385	Business	186200.00
0005433805072	9385	Economy	68300.00
0005433784587	9385	Economy	68300.00
0005433805062	9385	Economy	62100.00
0005434170842	9385	Economy	62100.00
0005433805067	9385	Economy	62100.00
0005434170869	9385	Economy	62100.00
0005433805061	9385	Economy	62100.00
0005433784619	9385	Economy	62100.00
0005433784614	9385	Economy	62100.00
0005434270173	9385	Economy	62100.00
0005432665256	9385	Economy	62100.00
0005432667434	9385	Economy	62100.00
0005433784599	9385	Economy	62100.00
0005433784623	9385	Economy	62100.00
0005433805065	9385	Economy	62100.00
0005434170799	9385	Economy	62100.00
0005433784617	9385	Economy	62100.00
0005433763072	9385	Economy	62100.00
0005433805064	9385	Economy	62100.00
0005433784589	9385	Economy	62100.00
0005433784602	9385	Economy	62100.00
0005432657420	9385	Economy	62100.00
0005433784597	9385	Economy	62100.00
0005433784615	9385	Economy	62100.00
0005433805052	9385	Economy	62100.00
0005433784595	9385	Economy	62100.00
0005432667435	9385	Economy	62100.00
0005433784596	9385	Economy	62100.00
0005434273046	9385	Economy	62100.00
0005433763069	9385	Economy	62100.00
0005433784591	9385	Economy	62100.00
0005433805070	9385	Economy	62100.00
0005433784608	9385	Economy	62100.00
0005433805073	9385	Economy	62100.00
0005433763070	9385	Economy	62100.00
0005433805050	9385	Economy	62100.00
0005433763063	9385	Economy	62100.00
0005434170823	9385	Economy	62100.00
0005433784613	9385	Economy	62100.00
0005433784607	9385	Economy	62100.00
0005432665257	9385	Economy	62100.00
0005433784604	9385	Economy	62100.00
0005433763075	9385	Economy	62100.00
0005433784611	9385	Economy	62100.00
0005433805057	9385	Economy	62100.00
0005434170804	9385	Economy	62100.00
0005433805058	9385	Economy	62100.00
0005434270175	9385	Economy	62100.00
0005433805059	9385	Economy	62100.00
0005433784593	9385	Economy	62100.00
0005433784588	9385	Economy	62100.00
0005433805049	9385	Economy	62100.00
0005433805071	9385	Economy	62100.00
0005433805066	9385	Economy	68300.00
0005434170818	9385	Economy	62100.00
0005433763067	9385	Economy	62100.00
0005434170855	9385	Economy	62100.00
0005433784609	9385	Economy	62100.00
0005433805063	9385	Economy	62100.00
0005433805054	9385	Economy	62100.00
0005433763064	9385	Economy	62100.00
0005433805051	9385	Economy	62100.00
0005433784598	9385	Economy	62100.00
0005434151655	9385	Economy	62100.00
0005433784603	9385	Economy	62100.00
0005433784612	9385	Economy	62100.00
0005433805048	9385	Economy	62100.00
0005434170810	9385	Economy	62100.00
0005433784622	9385	Economy	62100.00
0005432657418	9385	Economy	62100.00
0005433784600	9385	Economy	62100.00
0005433805047	9385	Economy	62100.00
0005433763065	9385	Economy	62100.00
0005432657419	9385	Economy	62100.00
0005433805053	9385	Economy	62100.00
0005433784592	9385	Economy	62100.00
0005433784594	9385	Economy	62100.00
0005433784590	9385	Economy	62100.00
0005433805076	9385	Economy	62100.00
0005433805074	9385	Economy	62100.00
0005432665255	9385	Economy	62100.00
0005433784616	9385	Economy	62100.00
0005433805060	9385	Economy	62100.00
0005434270172	9385	Economy	62100.00
0005433763071	9385	Economy	62100.00
0005433763074	9385	Economy	62100.00
0005433805069	9385	Economy	62100.00
0005433763066	9385	Economy	62100.00
0005433805068	9385	Economy	62100.00
0005433805075	9385	Economy	62100.00
0005432667436	9385	Economy	62100.00
0005433784618	9385	Economy	62100.00
0005434170798	9385	Economy	62100.00
0005433763068	9385	Economy	62100.00
0005433784606	9385	Economy	62100.00
0005434170812	9385	Economy	62100.00
0005433804888	26242	Business	186200.00
0005433784402	26242	Business	186200.00
0005432666360	26242	Business	186200.00
0005434170927	26242	Business	186200.00
0005433762955	26242	Business	186200.00
0005433784328	26242	Business	186200.00
0005435269684	26242	Business	186200.00
0005434170917	26242	Business	186200.00
0005434269081	26242	Economy	68300.00
0005433804889	26242	Economy	62100.00
0005435269679	26242	Economy	62100.00
0005432666359	26242	Economy	62100.00
0005434170919	26242	Economy	62100.00
0005434151676	26242	Economy	62100.00
0005434170923	26242	Economy	62100.00
0005433784415	26242	Economy	62100.00
0005434170918	26242	Economy	62100.00
0005434271290	26242	Economy	62100.00
0005433804836	26242	Economy	62100.00
0005434170925	26242	Economy	62100.00
0005433784430	26242	Economy	62100.00
0005433804787	26242	Economy	62100.00
0005433784404	26242	Economy	62100.00
0005435269678	26242	Economy	62100.00
0005433804807	26242	Economy	62100.00
0005434270185	26242	Economy	62100.00
0005433804781	26242	Economy	62100.00
0005433804938	26242	Economy	62100.00
0005433804800	26242	Economy	62100.00
0005434170924	26242	Economy	62100.00
0005433784309	26242	Economy	62100.00
0005434170916	26242	Economy	62100.00
0005435269677	26242	Economy	62100.00
0005434170926	26242	Economy	62100.00
0005433784294	26242	Economy	62100.00
0005433804778	26242	Economy	62100.00
0005433784339	26242	Economy	62100.00
0005433784416	26242	Economy	62100.00
0005435269683	26242	Economy	62100.00
0005435269675	26242	Economy	62100.00
0005433804847	26242	Economy	62100.00
0005434170922	26242	Economy	62100.00
0005433762945	26242	Economy	62100.00
0005435269682	26242	Economy	62100.00
0005435269680	26242	Economy	62100.00
0005433804799	26242	Economy	62100.00
0005433784311	26242	Economy	62100.00
0005434271291	26242	Economy	62100.00
0005433762987	26242	Economy	62100.00
0005433804805	26242	Economy	62100.00
0005434170915	26242	Economy	68300.00
0005433762954	26242	Economy	68300.00
0005433784293	26242	Economy	62100.00
0005434170920	26242	Economy	62100.00
0005433804788	26242	Economy	62100.00
0005433804868	26242	Economy	62100.00
0005434151677	26242	Economy	62100.00
0005434151675	26242	Economy	62100.00
0005433804829	26242	Economy	62100.00
0005433762946	26242	Economy	62100.00
0005434170921	26242	Economy	62100.00
0005433784310	26242	Economy	62100.00
0005432657393	26242	Economy	62100.00
0005433784312	26242	Economy	62100.00
0005433784403	26242	Economy	62100.00
0005434270184	26242	Economy	62100.00
0005433784292	26242	Economy	62100.00
0005435269676	26242	Economy	62100.00
0005435269681	26242	Economy	62100.00
0005434269082	26242	Economy	62100.00
0005434170928	26242	Economy	62100.00
0005433804922	26242	Economy	62100.00
0005433804777	26242	Economy	62100.00
0005433784295	26242	Economy	62100.00
0005433804830	26242	Economy	62100.00
0005435135624	4931	Economy	5300.00
0005435135622	4931	Economy	5300.00
0005435135625	4931	Economy	5300.00
0005435135623	4931	Economy	5300.00
0005435929599	4931	Economy	5300.00
0005435929598	4931	Economy	5300.00
0005435929595	4931	Economy	5300.00
0005435929617	33045	Economy	5300.00
0005435929619	33045	Economy	5300.00
0005435929618	33045	Economy	5300.00
0005434983238	9452	Economy	19700.00
0005434983236	9452	Economy	17900.00
0005434217901	9452	Economy	17900.00
0005434983241	9452	Economy	17900.00
0005434983240	9452	Economy	17900.00
0005434983239	9452	Economy	17900.00
0005434983237	9452	Economy	17900.00
0005434983220	27345	Economy	17900.00
0005434983193	27345	Economy	17900.00
0005434217928	27345	Economy	17900.00
0005434983194	27345	Economy	17900.00
0005434217930	27345	Economy	17900.00
0005434217931	27345	Economy	17900.00
0005434983208	27345	Economy	17900.00
0005434983219	27345	Economy	17900.00
0005434217929	27345	Economy	17900.00
0005434983200	27345	Economy	17900.00
0005433959865	24249	Business	36400.00
0005433985175	24249	Business	36400.00
0005433985130	24249	Economy	13400.00
0005433985128	24249	Economy	13400.00
0005433959868	24249	Economy	12100.00
0005433985133	24249	Economy	12100.00
0005433985247	24249	Economy	12100.00
0005433985174	24249	Economy	12100.00
0005433985190	24249	Economy	12100.00
0005433985287	24249	Economy	12100.00
0005433985129	24249	Economy	12100.00
0005433985203	24249	Economy	12100.00
0005433985248	24249	Economy	12100.00
0005433985229	24249	Economy	12100.00
0005433985177	24249	Economy	12100.00
0005433985204	24249	Economy	12100.00
0005433985136	24249	Economy	12100.00
0005433985230	24249	Economy	12100.00
0005433985124	24249	Economy	12100.00
0005433985224	24249	Economy	12100.00
0005433985288	24249	Economy	12100.00
0005433985125	24249	Economy	12100.00
0005433959861	24249	Economy	12100.00
0005433985270	24249	Economy	12100.00
0005433960330	25926	Business	36400.00
0005433985504	25926	Business	36400.00
0005433960285	25926	Business	36400.00
0005433960328	25926	Business	36400.00
0005433960289	25926	Business	36400.00
0005433985470	25926	Business	36400.00
0005433960321	25926	Business	36400.00
0005433985491	25926	Business	36400.00
0005433985485	25926	Business	36400.00
0005433960326	25926	Business	36400.00
0005433960291	25926	Business	36400.00
0005433985476	25926	Business	36400.00
0005433960333	25926	Business	36400.00
0005433960290	25926	Business	36400.00
0005433960316	25926	Business	36400.00
0005433985486	25926	Business	36400.00
0005433960286	25926	Business	36400.00
0005433985478	25926	Business	36400.00
0005433985497	25926	Business	36400.00
0005433960335	25926	Business	36400.00
0005433960308	25926	Business	36400.00
0005433985508	25926	Economy	13400.00
0005433960274	25926	Economy	13400.00
0005433985503	25926	Economy	12100.00
0005433960287	25926	Economy	12100.00
0005433960292	25926	Economy	12100.00
0005433985484	25926	Economy	12100.00
0005433960278	25926	Economy	12100.00
0005433960336	25926	Economy	12100.00
0005433985516	25926	Economy	12100.00
0005433960322	25926	Economy	12100.00
0005433960283	25926	Economy	12100.00
0005433985481	25926	Economy	12100.00
0005433960270	25926	Economy	12100.00
0005433960309	25926	Economy	12100.00
0005433960272	25926	Economy	12100.00
0005433985515	25926	Economy	12100.00
0005433985474	25926	Economy	12100.00
0005433960276	25926	Economy	12100.00
0005433960317	25926	Economy	12100.00
0005433985490	25926	Economy	12100.00
0005433960307	25926	Economy	12100.00
0005433960319	25926	Economy	12100.00
0005433960298	25926	Economy	12100.00
0005433985496	25926	Economy	12100.00
0005433960281	25926	Economy	12100.00
0005433985509	25926	Economy	12100.00
0005433985510	25926	Economy	12100.00
0005433960294	25926	Economy	12100.00
0005433985480	25926	Economy	12100.00
0005433985512	25926	Economy	12100.00
0005433960323	25926	Economy	12100.00
0005433960314	25926	Economy	12100.00
0005433985483	25926	Economy	12100.00
0005433985511	25926	Economy	12100.00
0005433985472	25926	Economy	12100.00
0005433985501	25926	Economy	12100.00
0005433985505	25926	Economy	12100.00
0005433960300	25926	Economy	12100.00
0005433960268	25926	Economy	12100.00
0005433960296	25926	Economy	12100.00
0005433985477	25926	Economy	12100.00
0005433960302	25926	Economy	12100.00
0005433960331	25926	Economy	12100.00
0005433960304	25926	Economy	12100.00
0005433985471	25926	Economy	12100.00
0005433985500	25926	Economy	12100.00
0005433985502	25926	Economy	12100.00
0005433960293	25926	Economy	12100.00
0005433960277	25926	Economy	12100.00
0005433960271	25926	Economy	12100.00
0005433985468	25926	Economy	13400.00
0005433960282	25926	Economy	12100.00
0005433985467	25926	Economy	12100.00
0005433960325	25926	Economy	13400.00
0005433985492	25926	Economy	12100.00
0005433960318	25926	Economy	12100.00
0005433985488	25926	Economy	12100.00
0005433985482	25926	Economy	12100.00
0005433985469	25926	Economy	12100.00
0005433960295	25926	Economy	12100.00
0005433960303	25926	Economy	12100.00
0005433960305	25926	Economy	12100.00
0005433960310	25926	Economy	12100.00
0005433960297	25926	Economy	12100.00
0005433985507	25926	Economy	12100.00
0005433960284	25926	Economy	12100.00
0005433960324	25926	Economy	12100.00
0005433960280	25926	Economy	12100.00
0005433985479	25926	Economy	12100.00
0005433960320	25926	Economy	12100.00
0005433985493	25926	Economy	12100.00
0005433985487	25926	Economy	12100.00
0005433985494	25926	Economy	12100.00
0005433960311	25926	Economy	12100.00
0005433985473	25926	Economy	12100.00
0005433960275	25926	Economy	12100.00
0005433960306	25926	Economy	12100.00
0005433960315	25926	Economy	12100.00
0005433960279	25926	Economy	12100.00
0005433960269	25926	Economy	12100.00
0005433960312	25926	Economy	12100.00
0005433960329	25926	Economy	12100.00
0005433960299	25926	Economy	12100.00
0005433985513	25926	Economy	12100.00
0005433985495	25926	Economy	12100.00
0005433985465	25926	Economy	12100.00
0005433960273	25926	Economy	12100.00
0005433985475	25926	Economy	12100.00
0005433960288	25926	Economy	12100.00
0005433960313	25926	Economy	12100.00
0005433960334	25926	Economy	12100.00
0005433960301	25926	Economy	12100.00
0005433985489	25926	Economy	12100.00
0005433985464	25926	Economy	12100.00
0005433985514	25926	Economy	12100.00
0005433985466	25926	Economy	12100.00
0005433985499	25926	Economy	12100.00
0005433985506	25926	Economy	12100.00
0005433960327	25926	Economy	12100.00
0005433985498	25926	Economy	12100.00
0005433960332	25926	Economy	12100.00
0005433165762	953	Economy	25400.00
0005434480083	953	Economy	25400.00
0005434480092	953	Economy	25400.00
0005434480099	953	Economy	25400.00
0005434480087	953	Economy	23100.00
0005434480106	953	Economy	23100.00
0005434480105	953	Economy	23100.00
0005434480088	953	Economy	23100.00
0005432269468	953	Economy	23100.00
0005432269470	953	Economy	23100.00
0005434480102	953	Economy	23100.00
0005433165706	953	Economy	23100.00
0005433165726	953	Economy	23100.00
0005434480107	953	Economy	23100.00
0005432269469	953	Economy	23100.00
0005434480100	953	Economy	23100.00
0005434480096	953	Economy	23100.00
0005433165678	953	Economy	23100.00
0005434480103	953	Economy	23100.00
0005434480082	953	Economy	23100.00
0005434480085	953	Economy	23100.00
0005433165718	953	Economy	23100.00
0005434480104	953	Economy	23100.00
0005434480097	953	Economy	23100.00
0005434480086	953	Economy	23100.00
0005433165677	953	Economy	23100.00
0005433165699	953	Economy	23100.00
0005434480093	953	Economy	23100.00
0005434480084	953	Economy	23100.00
0005434480091	953	Economy	23100.00
0005434480094	953	Economy	23100.00
0005433165761	953	Economy	23100.00
0005434480090	953	Economy	23100.00
0005434480089	953	Economy	23100.00
0005434480101	953	Economy	23100.00
0005434480095	953	Economy	23100.00
0005434480098	953	Economy	23100.00
0005434479929	16574	Economy	25400.00
0005433165783	16574	Economy	23100.00
0005433165790	16574	Economy	23100.00
0005433165781	16574	Economy	23100.00
0005433165776	16574	Economy	23100.00
0005434479920	16574	Economy	23100.00
0005434479919	16574	Economy	23100.00
0005434480003	16574	Economy	23100.00
0005433165789	16574	Economy	23100.00
0005433165777	16574	Economy	23100.00
0005433165786	16574	Economy	23100.00
0005433165785	16574	Economy	23100.00
0005434479917	16574	Economy	23100.00
0005433165778	16574	Economy	23100.00
0005434479908	16574	Economy	23100.00
0005433165788	16574	Economy	23100.00
0005434479893	16574	Economy	23100.00
0005433165782	16574	Economy	23100.00
0005433165779	16574	Economy	23100.00
0005433165787	16574	Economy	23100.00
0005434479891	16574	Economy	23100.00
0005434479944	16574	Economy	23100.00
0005434479909	16574	Economy	23100.00
0005434479890	16574	Economy	23100.00
0005434479928	16574	Economy	23100.00
0005433165784	16574	Economy	23100.00
0005433165780	16574	Economy	23100.00
0005435149889	10344	Economy	17000.00
0005435149896	10344	Economy	17000.00
0005435149893	10344	Economy	17000.00
0005435149895	10344	Economy	15400.00
0005435142443	10344	Economy	15400.00
0005435142435	10344	Economy	15400.00
0005435142444	10344	Economy	15400.00
0005435149892	10344	Economy	15400.00
0005435149886	10344	Economy	15400.00
0005435142436	10344	Economy	15400.00
0005435149887	10344	Economy	15400.00
0005435149898	10344	Economy	15400.00
0005435149894	10344	Economy	15400.00
0005435142441	10344	Economy	15400.00
0005435142442	10344	Economy	15400.00
0005435142434	10344	Economy	15400.00
0005435142437	10344	Economy	15400.00
0005435149888	10344	Economy	15400.00
0005435142446	10344	Economy	15400.00
0005435142433	10344	Economy	15400.00
0005435142440	10344	Economy	15400.00
0005435142445	10344	Economy	15400.00
0005435142439	10344	Economy	15400.00
0005435149891	10344	Economy	15400.00
0005435149885	10344	Economy	15400.00
0005435142432	10344	Economy	15400.00
0005435149890	10344	Economy	15400.00
0005435149897	10344	Economy	15400.00
0005435142438	10344	Economy	15400.00
0005435142346	21968	Economy	17000.00
0005435149794	21968	Economy	17000.00
0005433289786	21968	Economy	15400.00
0005435386513	21968	Economy	15400.00
0005433289788	21968	Economy	15400.00
0005435386516	21968	Economy	15400.00
0005435386515	21968	Economy	15400.00
0005435142345	21968	Economy	15400.00
0005435149793	21968	Economy	15400.00
0005433289790	21968	Economy	15400.00
0005433289787	21968	Economy	15400.00
0005435386511	21968	Economy	15400.00
0005435386517	21968	Economy	15400.00
0005435142358	21968	Economy	15400.00
0005433289789	21968	Economy	15400.00
0005435142347	21968	Economy	15400.00
0005435386514	21968	Economy	15400.00
0005435142339	21968	Economy	15400.00
0005435386512	21968	Economy	15400.00
0005435528897	11179	Business	57200.00
0005434573207	11179	Business	57200.00
0005435501936	11179	Business	57200.00
0005434573209	11179	Business	57200.00
0005435528920	11179	Economy	19100.00
0005434573214	11179	Economy	19100.00
0005435528887	11179	Economy	19100.00
0005435501964	11179	Economy	19100.00
0005434573215	11179	Economy	21000.00
0005435528884	11179	Economy	21000.00
0005434573211	11179	Economy	19100.00
0005435528886	11179	Economy	19100.00
0005435319428	11179	Economy	19100.00
0005435528939	11179	Economy	19100.00
0005434573208	11179	Economy	19100.00
0005435501976	11179	Economy	19100.00
0005435528896	11179	Economy	19100.00
0005434573213	11179	Economy	19100.00
0005434573204	11179	Economy	19100.00
0005435501948	11179	Economy	19100.00
0005435528885	11179	Economy	19100.00
0005435501967	11179	Economy	19100.00
0005435319429	11179	Economy	19100.00
0005434573206	11179	Economy	19100.00
0005435501965	11179	Economy	19100.00
0005435528938	11179	Economy	19100.00
0005435501937	11179	Economy	19100.00
0005435501947	11179	Economy	19100.00
0005434573205	11179	Economy	19100.00
0005434573210	11179	Economy	19100.00
0005434573212	11179	Economy	19100.00
0005434573203	11179	Economy	19100.00
0005435501931	11179	Economy	19100.00
0005435501935	11179	Economy	19100.00
0005434573216	11179	Economy	19100.00
0005435319502	20942	Business	57200.00
0005435508236	20942	Business	57200.00
0005434573108	20942	Business	57200.00
0005435502100	20942	Business	57200.00
0005435517734	20942	Business	57200.00
0005435502090	20942	Business	57200.00
0005435517744	20942	Business	57200.00
0005435517746	20942	Business	57200.00
0005435319501	20942	Economy	19100.00
0005435502089	20942	Economy	19100.00
0005435502096	20942	Economy	19100.00
0005435517741	20942	Economy	19100.00
0005435517733	20942	Economy	19100.00
0005432291905	20942	Economy	19100.00
0005435508247	20942	Economy	19100.00
0005435502103	20942	Economy	21000.00
0005435517738	20942	Economy	21000.00
0005435508242	20942	Economy	21000.00
0005435502086	20942	Economy	19100.00
0005435319504	20942	Economy	19100.00
0005435517735	20942	Economy	19100.00
0005435502095	20942	Economy	19100.00
0005435508235	20942	Economy	19100.00
0005435502091	20942	Economy	19100.00
0005435517740	20942	Economy	19100.00
0005435517739	20942	Economy	19100.00
0005435502101	20942	Economy	19100.00
0005435508241	20942	Economy	19100.00
0005435502107	20942	Economy	19100.00
0005435502092	20942	Economy	19100.00
0005435508245	20942	Economy	19100.00
0005435517743	20942	Economy	19100.00
0005435508240	20942	Economy	19100.00
0005435517737	20942	Economy	19100.00
0005435502104	20942	Economy	19100.00
0005435517732	20942	Economy	19100.00
0005432291907	20942	Economy	19100.00
0005435319505	20942	Economy	19100.00
0005435502088	20942	Economy	19100.00
0005435319497	20942	Economy	19100.00
0005432291906	20942	Economy	19100.00
0005435502099	20942	Economy	19100.00
0005435508243	20942	Economy	19100.00
0005435319503	20942	Economy	19100.00
0005435502106	20942	Economy	19100.00
0005435502087	20942	Economy	19100.00
0005435502105	20942	Economy	19100.00
0005435319498	20942	Economy	19100.00
0005435517747	20942	Economy	19100.00
0005435319499	20942	Economy	19100.00
0005435502093	20942	Economy	19100.00
0005435517748	20942	Economy	19100.00
0005435508237	20942	Economy	19100.00
0005435502097	20942	Economy	19100.00
0005435502098	20942	Economy	19100.00
0005435517742	20942	Economy	19100.00
0005435319500	20942	Economy	19100.00
0005435502102	20942	Economy	19100.00
0005435508246	20942	Economy	19100.00
0005435508239	20942	Economy	19100.00
0005435508249	20942	Economy	19100.00
0005435517745	20942	Economy	19100.00
0005435502094	20942	Economy	19100.00
0005435517736	20942	Economy	19100.00
0005435508248	20942	Economy	19100.00
0005435508238	20942	Economy	19100.00
0005435508244	20942	Economy	19100.00
0005432692622	3022	Economy	3400.00
0005432692573	3022	Economy	3400.00
0005432692635	3022	Economy	3400.00
0005432692531	3022	Economy	3400.00
0005432692532	3022	Economy	3400.00
0005432880573	3021	Business	10300.00
0005432880597	3021	Business	10300.00
0005432706538	3021	Business	10300.00
0005433123576	3021	Business	10300.00
0005433123574	3021	Economy	3400.00
0005432706535	3021	Economy	3400.00
0005432706518	3021	Economy	3400.00
0005433123657	3021	Economy	3400.00
0005433123641	3021	Economy	3400.00
0005432706527	3021	Economy	3400.00
0005433123573	3021	Economy	3400.00
0005432706540	3021	Economy	3800.00
0005432706533	3021	Economy	3800.00
0005432706528	3021	Economy	3800.00
0005432880580	3021	Economy	3800.00
0005432706520	3021	Economy	3400.00
0005432217749	3021	Economy	3400.00
0005433123632	3021	Economy	3400.00
0005432880564	3021	Economy	3400.00
0005433123640	3021	Economy	3400.00
0005432706542	3021	Economy	3400.00
0005432706531	3021	Economy	3400.00
0005432880575	3021	Economy	3400.00
0005432706537	3021	Economy	3400.00
0005432706522	3021	Economy	3400.00
0005432706524	3021	Economy	3400.00
0005432706526	3021	Economy	3400.00
0005432217748	3021	Economy	3400.00
0005433123566	3021	Economy	3400.00
0005432706534	3021	Economy	3400.00
0005432880579	3021	Economy	3400.00
0005432706529	3021	Economy	3400.00
0005432706541	3021	Economy	3400.00
0005432880552	3021	Economy	3400.00
0005432706519	3021	Economy	3400.00
0005432706523	3021	Economy	3400.00
0005432880551	3021	Economy	3400.00
0005432706539	3021	Economy	3400.00
0005432706530	3021	Economy	3400.00
0005433123567	3021	Economy	3400.00
0005432706525	3021	Economy	3400.00
0005432217750	3021	Economy	3400.00
0005432706536	3021	Economy	3400.00
0005432880565	3021	Economy	3400.00
0005433123604	3021	Economy	3400.00
0005432706532	3021	Economy	3400.00
0005432706521	3021	Economy	3400.00
0005432706319	29939	Business	10300.00
0005432706417	29939	Business	10300.00
0005433123735	29939	Business	10300.00
0005433123726	29939	Business	10300.00
0005432692781	29939	Business	10300.00
0005432692809	29939	Business	10300.00
0005432692792	29939	Business	10300.00
0005432692782	29939	Business	10300.00
0005432692802	29939	Business	10300.00
0005432692801	29939	Business	10300.00
0005432706346	29939	Economy	3400.00
0005432692780	29939	Economy	3400.00
0005432880677	29939	Economy	3400.00
0005433123729	29939	Economy	3400.00
0005433123721	29939	Economy	3400.00
0005432880678	29939	Economy	3400.00
0005432692783	29939	Economy	3400.00
0005433123714	29939	Economy	3400.00
0005433194832	29939	Economy	3400.00
0005432692794	29939	Economy	3400.00
0005432880679	29939	Economy	3800.00
0005432880680	29939	Economy	3800.00
0005433123734	29939	Economy	3800.00
0005432692786	29939	Economy	3800.00
0005432692796	29939	Economy	3400.00
0005432692804	29939	Economy	3400.00
0005432692791	29939	Economy	3400.00
0005432692793	29939	Economy	3400.00
0005433194829	29939	Economy	3400.00
0005432692785	29939	Economy	3400.00
0005433194830	29939	Economy	3400.00
0005432692789	29939	Economy	3400.00
0005432692810	29939	Economy	3400.00
0005432692807	29939	Economy	3400.00
0005432880672	29939	Economy	3400.00
0005432880673	29939	Economy	3400.00
0005433194828	29939	Economy	3400.00
0005433123718	29939	Economy	3400.00
0005432880671	29939	Economy	3400.00
0005433194831	29939	Economy	3400.00
0005432880682	29939	Economy	3400.00
0005432706335	29939	Economy	3400.00
0005432692806	29939	Economy	3400.00
0005433123719	29939	Economy	3400.00
0005433123730	29939	Economy	3400.00
0005432880684	29939	Economy	3400.00
0005432880683	29939	Economy	3400.00
0005433123716	29939	Economy	3400.00
0005433123728	29939	Economy	3400.00
0005432706352	29939	Economy	3400.00
0005432706361	29939	Economy	3400.00
0005432706318	29939	Economy	3400.00
0005433123722	29939	Economy	3400.00
0005433123725	29939	Economy	3400.00
0005433123736	29939	Economy	3400.00
0005433123733	29939	Economy	3400.00
0005432706459	29939	Economy	3400.00
0005432880674	29939	Economy	3400.00
0005432880685	29939	Economy	3400.00
0005432880675	29939	Economy	3400.00
0005432706418	29939	Economy	3400.00
0005432706397	29939	Economy	3400.00
0005432692805	29939	Economy	3400.00
0005432692808	29939	Economy	3400.00
0005432706341	29939	Economy	3400.00
0005432692800	29939	Economy	3400.00
0005432692797	29939	Economy	3400.00
0005432706395	29939	Economy	3400.00
0005432880681	29939	Economy	3400.00
0005432692787	29939	Economy	3400.00
0005432706309	29939	Economy	3400.00
0005432880676	29939	Economy	3400.00
0005432692798	29939	Economy	3400.00
0005433194833	29939	Economy	3400.00
0005433123727	29939	Economy	3400.00
0005433123720	29939	Economy	3400.00
0005433123732	29939	Economy	3400.00
0005433123715	29939	Economy	3400.00
0005433123724	29939	Economy	3400.00
0005432692799	29939	Economy	3400.00
0005433123717	29939	Economy	3400.00
0005432692784	29939	Economy	3400.00
0005432692803	29939	Economy	3400.00
0005432692795	29939	Economy	3400.00
0005432692790	29939	Economy	3400.00
0005433123731	29939	Economy	3400.00
0005433123723	29939	Economy	3400.00
0005432692788	29939	Economy	3400.00
0005434988627	23697	Economy	4000.00
0005434979486	23697	Economy	4000.00
0005434979469	23697	Economy	4000.00
0005434979489	23697	Economy	4000.00
0005434979471	23697	Economy	3600.00
0005434979497	23697	Economy	3600.00
0005434979490	23697	Economy	3600.00
0005434979487	23697	Economy	3600.00
0005434979473	23697	Economy	3600.00
0005434979474	23697	Economy	3600.00
0005434988628	23697	Economy	3600.00
0005434979468	23697	Economy	3600.00
0005434979481	23697	Economy	3600.00
0005434979482	23697	Economy	3600.00
0005434988626	23697	Economy	3600.00
0005434979477	23697	Economy	3600.00
0005434979493	23697	Economy	3600.00
0005434979483	23697	Economy	3600.00
0005434979475	23697	Economy	3600.00
0005434979478	23697	Economy	3600.00
0005434988622	23697	Economy	3600.00
0005434979492	23697	Economy	3600.00
0005434979495	23697	Economy	3600.00
0005434979479	23697	Economy	3600.00
0005434988623	23697	Economy	3600.00
0005434979491	23697	Economy	3600.00
0005434979476	23697	Economy	3600.00
0005434979485	23697	Economy	3600.00
0005434979472	23697	Economy	3600.00
0005434979470	23697	Economy	3600.00
0005434988624	23697	Economy	3600.00
0005434979494	23697	Economy	3600.00
0005434988625	23697	Economy	3600.00
0005434979484	23697	Economy	3600.00
0005434988631	23697	Economy	3600.00
0005434979496	23697	Economy	3600.00
0005434979480	23697	Economy	3600.00
0005434979467	23697	Economy	3600.00
0005434979488	23697	Economy	3600.00
0005434988630	23697	Economy	3600.00
0005434988632	23697	Economy	3600.00
0005434988629	23697	Economy	3600.00
0005434979325	27567	Economy	4000.00
0005434979296	27567	Economy	3600.00
0005434979396	27567	Economy	3600.00
0005434979301	27567	Economy	3600.00
0005434979300	27567	Economy	3600.00
0005434979298	27567	Economy	3600.00
0005434979297	27567	Economy	3600.00
0005434979313	27567	Economy	3600.00
0005433111469	10256	Economy	19700.00
0005433111471	10256	Economy	19700.00
0005434302414	10256	Economy	19700.00
0005434302417	10256	Economy	19700.00
0005433113496	10256	Economy	19700.00
0005434302415	10256	Economy	19700.00
0005434302416	10256	Economy	19700.00
0005433111468	10256	Economy	19700.00
0005434302413	10256	Economy	19700.00
0005433113516	19628	Economy	19700.00
0005433113515	19628	Economy	19700.00
0005433113514	19628	Economy	19700.00
0005433113513	19628	Economy	19700.00
0005435068632	3573	Business	26900.00
0005435925055	3573	Business	26900.00
0005435925060	3573	Business	26900.00
0005435068589	3573	Business	26900.00
0005435068606	3573	Business	26900.00
0005435068607	3573	Business	26900.00
0005435068614	3573	Business	26900.00
0005435068625	3573	Business	26900.00
0005435068624	3573	Business	26900.00
0005435068588	3573	Business	26900.00
0005435068584	3573	Economy	9000.00
0005435068618	3573	Economy	9000.00
0005435068629	3573	Economy	9000.00
0005435718892	3573	Economy	9000.00
0005435068628	3573	Economy	9000.00
0005435068595	3573	Economy	9000.00
0005435925081	3573	Economy	9900.00
0005435718886	3573	Economy	9900.00
0005435068630	3573	Economy	9900.00
0005435925082	3573	Economy	9900.00
0005435068633	3573	Economy	9000.00
0005435718889	3573	Economy	9000.00
0005435068626	3573	Economy	9000.00
0005435068582	3573	Economy	9000.00
0005435068620	3573	Economy	9000.00
0005435068605	3573	Economy	9000.00
0005435068592	3573	Economy	9000.00
0005435068593	3573	Economy	9000.00
0005435925059	3573	Economy	9000.00
0005435068609	3573	Economy	9000.00
0005435068587	3573	Economy	9000.00
0005435068627	3573	Economy	9000.00
0005435068599	3573	Economy	9000.00
0005435068623	3573	Economy	9000.00
0005435068590	3573	Economy	9000.00
0005435718890	3573	Economy	9000.00
0005435068613	3573	Economy	9000.00
0005435068610	3573	Economy	9000.00
0005435068616	3573	Economy	9000.00
0005435068596	3573	Economy	9000.00
0005435068608	3573	Economy	9000.00
0005435068585	3573	Economy	9000.00
0005435068631	3573	Economy	9000.00
0005435068622	3573	Economy	9000.00
0005435068621	3573	Economy	9000.00
0005435925086	3573	Economy	9000.00
0005435068612	3573	Economy	9000.00
0005435068594	3573	Economy	9000.00
0005435925064	3573	Economy	9000.00
0005435925056	3573	Economy	9000.00
0005435068586	3573	Economy	9000.00
0005435068583	3573	Economy	9000.00
0005435068602	3573	Economy	9000.00
0005435068619	3573	Economy	9000.00
0005435925094	3573	Economy	9000.00
0005435068634	3573	Economy	9000.00
0005435068617	3573	Economy	9000.00
0005435925063	3573	Economy	9000.00
0005435068601	3573	Economy	9000.00
0005435939857	3573	Economy	9000.00
0005435068597	3573	Economy	9000.00
0005435068598	3573	Economy	9000.00
0005435718891	3573	Economy	9000.00
0005435068600	3573	Economy	9000.00
0005435068603	3573	Economy	9000.00
0005435718887	3573	Economy	9000.00
0005435925066	3573	Economy	9000.00
0005435718885	3573	Economy	9000.00
0005435068611	3573	Economy	9000.00
0005435068604	3573	Economy	9000.00
0005435718888	3573	Economy	9000.00
0005435068591	3573	Economy	9000.00
0005435068615	3573	Economy	9000.00
0005435925167	15297	Business	26900.00
0005435925171	15297	Business	26900.00
0005435068322	15297	Business	26900.00
0005435925161	15297	Economy	9000.00
0005435068230	15297	Economy	9000.00
0005435925155	15297	Economy	9000.00
0005435925166	15297	Economy	9000.00
0005435925175	15297	Economy	9900.00
0005435925159	15297	Economy	9000.00
0005435068158	15297	Economy	9000.00
0005435925172	15297	Economy	9000.00
0005435068187	15297	Economy	9000.00
0005435068184	15297	Economy	9000.00
0005435925156	15297	Economy	9000.00
0005435925158	15297	Economy	9000.00
0005435068159	15297	Economy	9000.00
0005435925162	15297	Economy	9000.00
0005435068194	15297	Economy	9000.00
0005435925169	15297	Economy	9000.00
0005435068165	15297	Economy	9000.00
0005435925174	15297	Economy	9000.00
0005435925173	15297	Economy	9000.00
0005435925160	15297	Economy	9000.00
0005435925168	15297	Economy	9000.00
0005435068231	15297	Economy	9000.00
0005435068186	15297	Economy	9000.00
0005435925163	15297	Economy	9000.00
0005435068185	15297	Economy	9000.00
0005435925165	15297	Economy	9000.00
0005435068160	15297	Economy	9000.00
0005435925176	15297	Economy	9000.00
0005435925164	15297	Economy	9000.00
0005435925170	15297	Economy	9000.00
0005435925157	15297	Economy	9000.00
0005432659688	18144	Economy	5900.00
0005432659687	18144	Economy	5900.00
0005432660797	18144	Economy	5900.00
0005432660798	18144	Economy	5900.00
0005432659686	18144	Economy	5900.00
0005433101271	130	Business	20000.00
0005432901326	130	Business	20000.00
0005432919565	130	Business	20000.00
0005432919524	130	Business	20000.00
0005432157474	130	Business	20000.00
0005433101280	130	Business	20000.00
0005433101281	130	Economy	6700.00
0005433101267	130	Economy	6700.00
0005432677506	130	Economy	6700.00
0005433101194	130	Economy	6700.00
0005433101290	130	Economy	6700.00
0005432919523	130	Economy	6700.00
0005432919536	130	Economy	6700.00
0005432919516	130	Economy	6700.00
0005433101211	130	Economy	6700.00
0005433101186	130	Economy	6700.00
0005432677505	130	Economy	6700.00
0005433101212	130	Economy	6700.00
0005432919566	130	Economy	6700.00
0005433101207	130	Economy	6700.00
0005433101157	130	Economy	6700.00
0005432919506	130	Economy	6700.00
0005432901318	130	Economy	6700.00
0005432901378	130	Economy	6700.00
0005433101229	130	Economy	6700.00
0005432901336	130	Economy	6700.00
0005433101196	130	Economy	6700.00
0005433101285	130	Economy	7300.00
0005433101189	130	Economy	7300.00
0005432677504	130	Economy	6700.00
0005433101266	130	Economy	6700.00
0005433101244	130	Economy	6700.00
0005433101249	130	Economy	6700.00
0005433101270	130	Economy	6700.00
0005433101209	130	Economy	6700.00
0005433101191	130	Economy	6700.00
0005432901329	130	Economy	6700.00
0005432901345	130	Economy	6700.00
0005433101243	130	Economy	6700.00
0005432677503	130	Economy	6700.00
0005432901304	130	Economy	6700.00
0005433101163	130	Economy	6700.00
0005432919540	130	Economy	6700.00
0005433101210	130	Economy	6700.00
0005432901297	130	Economy	6700.00
0005432157473	130	Economy	6700.00
0005433101173	130	Economy	6700.00
0005433101188	130	Economy	6700.00
0005432901427	130	Economy	6700.00
0005432901428	130	Economy	6700.00
0005433101276	130	Economy	6700.00
0005432901354	130	Economy	6700.00
0005432901303	130	Economy	6700.00
0005433101230	130	Economy	6700.00
0005432261468	129	Business	20000.00
0005432756796	129	Business	20000.00
0005432261469	129	Business	20000.00
0005432817192	129	Business	20000.00
0005432261463	129	Business	20000.00
0005432817198	129	Business	20000.00
0005432817184	129	Business	20000.00
0005432261497	129	Business	20000.00
0005432288957	129	Business	20000.00
0005432207636	129	Business	20000.00
0005432261491	129	Business	20000.00
0005432207635	129	Business	20000.00
0005432261472	129	Business	20000.00
0005432817185	129	Economy	7300.00
0005432261500	129	Economy	7300.00
0005432261482	129	Economy	7300.00
0005432261499	129	Economy	7300.00
0005432817190	129	Economy	6700.00
0005432261461	129	Economy	6700.00
0005432261479	129	Economy	6700.00
0005432817210	129	Economy	6700.00
0005432288955	129	Economy	6700.00
0005432817183	129	Economy	6700.00
0005432817207	129	Economy	6700.00
0005432817195	129	Economy	6700.00
0005432817180	129	Economy	6700.00
0005432261494	129	Economy	6700.00
0005432817199	129	Economy	6700.00
0005432261484	129	Economy	6700.00
0005432261501	129	Economy	6700.00
0005432261493	129	Economy	6700.00
0005432261495	129	Economy	6700.00
0005432261480	129	Economy	6700.00
0005432261467	129	Economy	6700.00
0005432817189	129	Economy	6700.00
0005432261485	129	Economy	6700.00
0005432261498	129	Economy	6700.00
0005432817188	129	Economy	6700.00
0005432817187	129	Economy	6700.00
0005432261464	129	Economy	6700.00
0005432817206	129	Economy	6700.00
0005432261503	129	Economy	6700.00
0005432288958	129	Economy	6700.00
0005432261486	129	Economy	6700.00
0005432207634	129	Economy	6700.00
0005432261481	129	Economy	6700.00
0005432817201	129	Economy	6700.00
0005432817208	129	Economy	7300.00
0005432261466	129	Economy	7300.00
0005432261477	129	Economy	7300.00
0005432261505	129	Economy	6700.00
0005432261474	129	Economy	6700.00
0005432261507	129	Economy	6700.00
0005432261478	129	Economy	6700.00
0005432261506	129	Economy	6700.00
0005432817202	129	Economy	6700.00
0005432261462	129	Economy	6700.00
0005432261483	129	Economy	6700.00
0005432261504	129	Economy	6700.00
0005432261488	129	Economy	6700.00
0005432817186	129	Economy	6700.00
0005432817191	129	Economy	6700.00
0005432261489	129	Economy	6700.00
0005432817211	129	Economy	6700.00
0005432261475	129	Economy	6700.00
0005432817182	129	Economy	6700.00
0005432261502	129	Economy	6700.00
0005432817200	129	Economy	6700.00
0005432817204	129	Economy	6700.00
0005432817209	129	Economy	6700.00
0005432261476	129	Economy	6700.00
0005432817203	129	Economy	6700.00
0005432817197	129	Economy	6700.00
0005432261471	129	Economy	6700.00
0005432288954	129	Economy	6700.00
0005432261487	129	Economy	6700.00
0005432261496	129	Economy	6700.00
0005432817193	129	Economy	6700.00
0005432288956	129	Economy	6700.00
0005432817181	129	Economy	6700.00
0005432261473	129	Economy	6700.00
0005432261465	129	Economy	6700.00
0005432261492	129	Economy	6700.00
0005432817194	129	Economy	6700.00
0005432261490	129	Economy	6700.00
0005432817196	129	Economy	6700.00
0005432817205	129	Economy	6700.00
0005432261470	129	Economy	6700.00
0005433101653	8055	Business	20000.00
0005432677538	8055	Business	20000.00
0005433101650	8055	Business	20000.00
0005432919662	8055	Business	20000.00
0005433101670	8055	Business	20000.00
0005433101635	8055	Business	20000.00
0005433101652	8055	Business	20000.00
0005433101629	8055	Business	20000.00
0005433101668	8055	Business	20000.00
0005432919670	8055	Business	20000.00
0005432919657	8055	Business	20000.00
0005433101676	8055	Business	20000.00
0005433101628	8055	Business	20000.00
0005432020002	8055	Business	20000.00
0005432919655	8055	Business	20000.00
0005432753270	8055	Business	20000.00
0005432020010	8055	Business	20000.00
0005432045597	8055	Business	20000.00
0005433101651	8055	Business	20000.00
0005433101640	8055	Business	20000.00
0005432753271	8055	Business	20000.00
0005432020023	8055	Economy	7300.00
0005433101642	8055	Economy	7300.00
0005433101639	8055	Economy	7300.00
0005432919673	8055	Economy	7300.00
0005433101665	8055	Economy	6700.00
0005432020007	8055	Economy	6700.00
0005432020000	8055	Economy	6700.00
0005432020014	8055	Economy	6700.00
0005433101631	8055	Economy	6700.00
0005432020020	8055	Economy	6700.00
0005432919661	8055	Economy	6700.00
0005432391971	8055	Economy	6700.00
0005433101626	8055	Economy	6700.00
0005432919660	8055	Economy	6700.00
0005433101647	8055	Economy	6700.00
0005432019999	8055	Economy	6700.00
0005432020005	8055	Economy	6700.00
0005433101645	8055	Economy	6700.00
0005433101636	8055	Economy	6700.00
0005433101646	8055	Economy	6700.00
0005432753269	8055	Economy	6700.00
0005432391970	8055	Economy	6700.00
0005432919654	8055	Economy	6700.00
0005433101633	8055	Economy	6700.00
0005432751494	8055	Economy	6700.00
0005433101655	8055	Economy	6700.00
0005432020025	8055	Economy	6700.00
0005433101623	8055	Economy	6700.00
0005432919659	8055	Economy	6700.00
0005432020013	8055	Economy	6700.00
0005432020021	8055	Economy	6700.00
0005433101674	8055	Economy	6700.00
0005433101654	8055	Economy	6700.00
0005432020019	8055	Economy	6700.00
0005432919667	8055	Economy	6700.00
0005433101661	8055	Economy	6700.00
0005432020017	8055	Economy	6700.00
0005432919672	8055	Economy	6700.00
0005432677539	8055	Economy	6700.00
0005432020016	8055	Economy	6700.00
0005433101666	8055	Economy	6700.00
0005433101675	8055	Economy	6700.00
0005432020009	8055	Economy	6700.00
0005432020024	8055	Economy	6700.00
0005432677537	8055	Economy	6700.00
0005433101643	8055	Economy	7300.00
0005433101641	8055	Economy	7300.00
0005433101672	8055	Economy	7300.00
0005432020003	8055	Economy	7300.00
0005432044498	8055	Economy	6700.00
0005433101671	8055	Economy	6700.00
0005433101621	8055	Economy	6700.00
0005433101663	8055	Economy	7300.00
0005432919669	8055	Economy	6700.00
0005433101625	8055	Economy	6700.00
0005432391972	8055	Economy	6700.00
0005432919665	8055	Economy	6700.00
0005433101659	8055	Economy	6700.00
0005433101657	8055	Economy	6700.00
0005433101620	8055	Economy	6700.00
0005433101638	8055	Economy	6700.00
0005432919674	8055	Economy	6700.00
0005433101656	8055	Economy	6700.00
0005433101662	8055	Economy	6700.00
0005433101637	8055	Economy	6700.00
0005433101658	8055	Economy	6700.00
0005433101630	8055	Economy	6700.00
0005433101667	8055	Economy	6700.00
0005432020004	8055	Economy	6700.00
0005432751496	8055	Economy	6700.00
0005433101669	8055	Economy	6700.00
0005432020006	8055	Economy	6700.00
0005432919666	8055	Economy	6700.00
0005432919671	8055	Economy	6700.00
0005432020011	8055	Economy	6700.00
0005433101660	8055	Economy	6700.00
0005433101634	8055	Economy	6700.00
0005432919663	8055	Economy	6700.00
0005433101632	8055	Economy	6700.00
0005432753272	8055	Economy	6700.00
0005433101622	8055	Economy	6700.00
0005432020001	8055	Economy	6700.00
0005432919664	8055	Economy	6700.00
0005433101673	8055	Economy	6700.00
0005432020018	8055	Economy	6700.00
0005432919656	8055	Economy	6700.00
0005433101648	8055	Economy	6700.00
0005432751495	8055	Economy	6700.00
0005433101678	8055	Economy	6700.00
0005432020022	8055	Economy	6700.00
0005433101664	8055	Economy	6700.00
0005433101649	8055	Economy	6700.00
0005432020015	8055	Economy	6700.00
0005432919658	8055	Economy	6700.00
0005432919668	8055	Economy	6700.00
0005432044500	8055	Economy	6700.00
0005433101624	8055	Economy	6700.00
0005432044499	8055	Economy	6700.00
0005433101627	8055	Economy	6700.00
0005432020012	8055	Economy	6700.00
0005432020008	8055	Economy	6700.00
0005433101677	8055	Economy	6700.00
0005432751497	8055	Economy	6700.00
0005432045596	8055	Economy	6700.00
0005433101644	8055	Economy	6700.00
0005432901442	8056	Business	20000.00
0005432816995	8056	Business	20000.00
0005432901441	8056	Business	20000.00
0005432901445	8056	Business	20000.00
0005432816993	8056	Business	20000.00
0005432817022	8056	Business	20000.00
0005432816940	8056	Economy	7300.00
0005432901449	8056	Economy	6700.00
0005432816975	8056	Economy	6700.00
0005432901448	8056	Economy	6700.00
0005432816948	8056	Economy	6700.00
0005432901438	8056	Economy	6700.00
0005432901447	8056	Economy	6700.00
0005432816960	8056	Economy	6700.00
0005432816968	8056	Economy	6700.00
0005432901439	8056	Economy	6700.00
0005432817009	8056	Economy	6700.00
0005432816976	8056	Economy	6700.00
0005432816981	8056	Economy	6700.00
0005432817050	8056	Economy	6700.00
0005432901440	8056	Economy	6700.00
0005432901453	8056	Economy	6700.00
0005432901443	8056	Economy	6700.00
0005432816961	8056	Economy	6700.00
0005432901437	8056	Economy	6700.00
0005432901454	8056	Economy	6700.00
0005432816994	8056	Economy	6700.00
0005432817051	8056	Economy	6700.00
0005432901451	8056	Economy	6700.00
0005432002057	8056	Economy	6700.00
0005432901450	8056	Economy	6700.00
0005432901444	8056	Economy	6700.00
0005432901446	8056	Economy	6700.00
0005432816991	8056	Economy	6700.00
0005432816969	8056	Economy	6700.00
0005432816992	8056	Economy	6700.00
0005432901452	8056	Economy	6700.00
0005432002056	8056	Economy	6700.00
0005432816939	8056	Economy	6700.00
0005433870711	9637	Economy	6900.00
0005433870712	9637	Economy	6900.00
0005434175684	9637	Economy	6900.00
0005434175679	9637	Economy	6900.00
0005433870709	9637	Economy	6900.00
0005434175683	9637	Economy	6900.00
0005434175678	9637	Economy	6900.00
0005434175685	9637	Economy	6900.00
0005433870710	9637	Economy	6900.00
0005434175712	32354	Economy	6900.00
0005434175711	32354	Economy	6900.00
0005434175714	32354	Economy	6900.00
0005434175713	32354	Economy	6900.00
0005435126011	3499	Business	35000.00
0005435125980	3499	Business	35000.00
0005434877420	3499	Business	35000.00
0005435626013	3499	Business	35000.00
0005434877413	3499	Business	35000.00
0005434877405	3499	Business	35000.00
0005434877375	3499	Business	35000.00
0005435902403	3499	Business	35000.00
0005434937964	3499	Business	35000.00
0005432799198	3499	Business	35000.00
0005435125993	3499	Business	35000.00
0005434877402	3499	Business	35000.00
0005435626019	3499	Business	35000.00
0005434426341	3499	Business	35000.00
0005434877376	3499	Business	35000.00
0005434426340	3499	Business	35000.00
0005435626022	3499	Business	35000.00
0005435626001	3499	Business	35000.00
0005435125998	3499	Business	35000.00
0005434877408	3499	Business	35000.00
0005434877382	3499	Business	35000.00
0005434877337	3499	Comfort	19900.00
0005434877343	3499	Business	35000.00
0005435626008	3499	Comfort	19900.00
0005435902463	3499	Comfort	19900.00
0005434877333	3499	Comfort	19900.00
0005434877345	3499	Comfort	19900.00
0005434426334	3499	Comfort	19900.00
0005432799189	3499	Comfort	19900.00
0005434877427	3499	Comfort	19900.00
0005435126019	3499	Comfort	19900.00
0005434877400	3499	Comfort	19900.00
0005434877340	3499	Comfort	19900.00
0005432799207	3499	Comfort	19900.00
0005435626011	3499	Comfort	19900.00
0005434426355	3499	Comfort	19900.00
0005434426339	3499	Comfort	19900.00
0005434877393	3499	Comfort	19900.00
0005435902402	3499	Comfort	19900.00
0005435626010	3499	Comfort	19900.00
0005435902400	3499	Comfort	19900.00
0005435626012	3499	Comfort	19900.00
0005434877414	3499	Comfort	19900.00
0005434426353	3499	Comfort	19900.00
0005434937961	3499	Comfort	19900.00
0005434877381	3499	Comfort	19900.00
0005432799193	3499	Comfort	19900.00
0005435126010	3499	Comfort	19900.00
0005432799195	3499	Comfort	19900.00
0005435125985	3499	Comfort	19900.00
0005432799211	3499	Comfort	19900.00
0005434877358	3499	Comfort	19900.00
0005435126021	3499	Economy	11700.00
0005432183446	3499	Economy	11700.00
0005434937962	3499	Economy	11700.00
0005434426350	3499	Economy	11700.00
0005434877380	3499	Economy	11700.00
0005432799201	3499	Economy	11700.00
0005432188579	3499	Economy	11700.00
0005435626006	3499	Economy	11700.00
0005432613825	3499	Economy	11700.00
0005434877348	3499	Economy	11700.00
0005434877416	3499	Economy	11700.00
0005434877404	3499	Economy	11700.00
0005435126000	3499	Economy	11700.00
0005435626002	3499	Economy	11700.00
0005434426331	3499	Economy	11700.00
0005434877371	3499	Economy	11700.00
0005434877369	3499	Economy	11700.00
0005435126013	3499	Economy	11700.00
0005432613824	3499	Economy	11700.00
0005434937959	3499	Economy	11700.00
0005434877407	3499	Economy	11700.00
0005432799200	3499	Economy	11700.00
0005432799208	3499	Economy	11700.00
0005434426327	3499	Economy	11700.00
0005435126008	3499	Economy	11700.00
0005434426347	3499	Economy	11700.00
0005432799199	3499	Economy	11700.00
0005432611675	3499	Economy	11700.00
0005434877391	3499	Economy	11700.00
0005434937971	3499	Economy	11700.00
0005432799210	3499	Economy	11700.00
0005434877353	3499	Economy	11700.00
0005434426354	3499	Economy	11700.00
0005434877399	3499	Economy	11700.00
0005435126016	3499	Economy	11700.00
0005434877388	3499	Economy	11700.00
0005435125995	3499	Economy	11700.00
0005434877339	3499	Economy	11700.00
0005435125984	3499	Economy	11700.00
0005434877352	3499	Economy	11700.00
0005434426329	3499	Economy	12800.00
0005432799206	3499	Economy	11700.00
0005434426348	3499	Economy	12800.00
0005434426328	3499	Economy	11700.00
0005435626016	3499	Economy	12800.00
0005434877383	3499	Economy	12800.00
0005434937955	3499	Economy	12800.00
0005434426333	3499	Economy	11700.00
0005435126020	3499	Economy	11700.00
0005434877331	3499	Economy	11700.00
0005434877415	3499	Economy	11700.00
0005435626020	3499	Economy	11700.00
0005432799190	3499	Economy	11700.00
0005435626004	3499	Economy	11700.00
0005434937970	3499	Economy	11700.00
0005434426345	3499	Economy	11700.00
0005435125981	3499	Economy	11700.00
0005434877397	3499	Economy	11700.00
0005434426335	3499	Economy	11700.00
0005434877395	3499	Economy	11700.00
0005434877374	3499	Economy	11700.00
0005435126004	3499	Economy	11700.00
0005434877346	3499	Economy	11700.00
0005432799186	3499	Economy	11700.00
0005434877362	3499	Economy	11700.00
0005432188577	3499	Economy	11700.00
0005432611673	3499	Economy	11700.00
0005434426338	3499	Economy	11700.00
0005435126005	3499	Economy	11700.00
0005432799209	3499	Economy	11700.00
0005434877359	3499	Economy	11700.00
0005432799192	3499	Economy	11700.00
0005435126006	3499	Economy	11700.00
0005434426342	3499	Economy	11700.00
0005434877401	3499	Economy	11700.00
0005434877368	3499	Economy	11700.00
0005434877334	3499	Economy	11700.00
0005434937954	3499	Economy	11700.00
0005434877354	3499	Economy	11700.00
0005435626014	3499	Economy	11700.00
0005434877418	3499	Economy	11700.00
0005435125997	3499	Economy	11700.00
0005435126001	3499	Economy	11700.00
0005434426346	3499	Economy	11700.00
0005434877378	3499	Economy	11700.00
0005432188578	3499	Economy	11700.00
0005435126002	3499	Economy	11700.00
0005432799191	3499	Economy	11700.00
0005432799202	3499	Economy	11700.00
0005432799205	3499	Economy	11700.00
0005434877347	3499	Economy	11700.00
0005434937965	3499	Economy	11700.00
0005434877412	3499	Economy	11700.00
0005434937957	3499	Economy	11700.00
0005435126009	3499	Economy	11700.00
0005434877357	3499	Economy	11700.00
0005434877342	3499	Economy	11700.00
0005434426332	3499	Economy	11700.00
0005435125987	3499	Economy	11700.00
0005432799196	3499	Economy	11700.00
0005434877372	3499	Economy	11700.00
0005434877384	3499	Economy	11700.00
0005434877364	3499	Economy	11700.00
0005434877356	3499	Economy	11700.00
0005434937967	3499	Economy	11700.00
0005432799185	3499	Economy	11700.00
0005432611674	3499	Economy	11700.00
0005434426344	3499	Economy	11700.00
0005434877379	3499	Economy	11700.00
0005434877389	3499	Economy	11700.00
0005434877406	3499	Economy	11700.00
0005432799184	3499	Economy	11700.00
0005434877398	3499	Economy	11700.00
0005435126015	3499	Economy	11700.00
0005435125992	3499	Economy	11700.00
0005434877361	3499	Economy	11700.00
0005434877336	3499	Economy	11700.00
0005435125994	3499	Economy	11700.00
0005434877373	3499	Economy	11700.00
0005434426326	3499	Economy	11700.00
0005435626007	3499	Economy	11700.00
0005434877370	3499	Economy	11700.00
0005434877360	3499	Economy	11700.00
0005434877338	3499	Economy	11700.00
0005434877335	3499	Economy	11700.00
0005434426349	3499	Economy	11700.00
0005435126007	3499	Economy	12800.00
0005434877341	3499	Economy	12800.00
0005435126003	3499	Economy	12800.00
0005434426336	3499	Economy	12800.00
0005434877349	3499	Economy	11700.00
0005434877419	3499	Economy	11700.00
0005432799212	3499	Economy	11700.00
0005432183449	3499	Economy	11700.00
0005434426330	3499	Economy	11700.00
0005434426337	3499	Economy	11700.00
0005435626005	3499	Economy	11700.00
0005434877403	3499	Economy	11700.00
0005434877350	3499	Economy	11700.00
0005435626018	3499	Economy	11700.00
0005432613823	3499	Economy	11700.00
0005434877367	3499	Economy	11700.00
0005435902401	3499	Economy	11700.00
0005434937969	3499	Economy	11700.00
0005432613826	3499	Economy	11700.00
0005434877344	3499	Economy	11700.00
0005434877423	3499	Economy	11700.00
0005434877424	3499	Economy	11700.00
0005435626009	3499	Economy	11700.00
0005434877332	3499	Economy	11700.00
0005435125990	3499	Economy	11700.00
0005435626017	3499	Economy	11700.00
0005434937966	3499	Economy	11700.00
0005435125988	3499	Economy	11700.00
0005432183448	3499	Economy	11700.00
0005434877392	3499	Economy	11700.00
0005432799188	3499	Economy	11700.00
0005434877387	3499	Economy	11700.00
0005434877351	3499	Economy	11700.00
0005432611672	3499	Economy	11700.00
0005434937968	3499	Economy	11700.00
0005434877410	3499	Economy	11700.00
0005435626015	3499	Economy	11700.00
0005432183447	3499	Economy	11700.00
0005435126018	3499	Economy	11700.00
0005434877366	3499	Economy	11700.00
0005432613822	3499	Economy	11700.00
0005434877426	3499	Economy	11700.00
0005434937952	3499	Economy	11700.00
0005434937958	3499	Economy	11700.00
0005434937960	3499	Economy	11700.00
0005434937953	3499	Economy	11700.00
0005435125983	3499	Economy	11700.00
0005434877409	3499	Economy	11700.00
0005434426343	3499	Economy	11700.00
0005435126012	3499	Economy	11700.00
0005432799203	3499	Economy	11700.00
0005434877390	3499	Economy	11700.00
0005434877421	3499	Economy	11700.00
0005435125986	3499	Economy	11700.00
0005435626021	3499	Economy	11700.00
0005432799194	3499	Economy	11700.00
0005434877422	3499	Economy	11700.00
0005435126017	3499	Economy	11700.00
0005435125999	3499	Economy	11700.00
0005435125996	3499	Economy	11700.00
0005434877377	3499	Economy	11700.00
0005434877365	3499	Economy	11700.00
0005432799204	3499	Economy	11700.00
0005434426352	3499	Economy	11700.00
0005435902411	3499	Economy	11700.00
0005432799187	3499	Economy	11700.00
0005434937963	3499	Economy	11700.00
0005434426351	3499	Economy	11700.00
0005434877396	3499	Economy	11700.00
0005435126014	3499	Economy	11700.00
0005434937956	3499	Economy	11700.00
0005432799197	3499	Economy	11700.00
0005432188576	3499	Economy	11700.00
0005435626000	3499	Economy	11700.00
0005434877394	3499	Economy	11700.00
0005435125982	3499	Economy	11700.00
0005434877425	3499	Economy	11700.00
0005434877385	3499	Economy	11700.00
0005434877355	3499	Economy	11700.00
0005434877386	3499	Economy	11700.00
0005435125991	3499	Economy	11700.00
0005434877411	3499	Economy	11700.00
0005435125989	3499	Economy	11700.00
0005434877417	3499	Economy	11700.00
0005435626003	3499	Economy	11700.00
0005434877363	3499	Economy	11700.00
0005434876800	14586	Business	35000.00
0005434876716	14586	Business	35000.00
0005434876809	14586	Business	35000.00
0005435125697	14586	Business	35000.00
0005432798981	14586	Business	35000.00
0005434876810	14586	Business	35000.00
0005434876875	14586	Business	35000.00
0005434876628	14586	Comfort	19900.00
0005435902546	14586	Business	35000.00
0005434876561	14586	Comfort	19900.00
0005435125696	14586	Comfort	19900.00
0005432059485	14586	Comfort	19900.00
0005434876649	14586	Comfort	19900.00
0005435625863	14586	Comfort	19900.00
0005434876560	14586	Comfort	19900.00
0005434426109	14586	Comfort	19900.00
0005432799022	14586	Comfort	19900.00
0005434876804	14586	Comfort	19900.00
0005435625864	14586	Comfort	19900.00
0005434426146	14586	Comfort	19900.00
0005434876592	14586	Comfort	19900.00
0005434876602	14586	Comfort	19900.00
0005435902540	14586	Comfort	19900.00
0005434876679	14586	Comfort	19900.00
0005435625859	14586	Comfort	19900.00
0005435902532	14586	Comfort	19900.00
0005432607494	14586	Economy	11700.00
0005434426233	14586	Economy	11700.00
0005434876643	14586	Economy	11700.00
0005435125698	14586	Economy	11700.00
0005434876737	14586	Economy	11700.00
0005432799023	14586	Economy	11700.00
0005435125729	14586	Economy	11700.00
0005434426231	14586	Economy	11700.00
0005435125695	14586	Economy	11700.00
0005434937854	14586	Economy	11700.00
0005432799086	14586	Economy	11700.00
0005435902544	14586	Economy	11700.00
0005434877016	14586	Economy	11700.00
0005434877015	14586	Economy	11700.00
0005434877003	14586	Economy	11700.00
0005434876918	14586	Economy	11700.00
0005435902530	14586	Economy	11700.00
0005434876680	14586	Economy	11700.00
0005432059486	14586	Economy	11700.00
0005434876892	14586	Economy	11700.00
0005434937883	14586	Economy	11700.00
0005435902531	14586	Economy	11700.00
0005434937882	14586	Economy	11700.00
0005432799014	14586	Economy	11700.00
0005434937858	14586	Economy	11700.00
0005435913902	14586	Economy	11700.00
0005434876557	14586	Economy	11700.00
0005434876794	14586	Economy	12800.00
0005434876923	14586	Economy	11700.00
0005434876562	14586	Economy	11700.00
0005432798982	14586	Economy	11700.00
0005432798977	14586	Economy	11700.00
0005432799028	14586	Economy	11700.00
0005434426137	14586	Economy	11700.00
0005434876676	14586	Economy	11700.00
0005434937871	14586	Economy	11700.00
0005434426106	14586	Economy	11700.00
0005435902543	14586	Economy	11700.00
0005435902545	14586	Economy	11700.00
0005434876876	14586	Economy	11700.00
0005434876813	14586	Economy	11700.00
0005434426188	14586	Economy	11700.00
0005434876603	14586	Economy	11700.00
0005435902535	14586	Economy	11700.00
0005434426187	14586	Economy	11700.00
0005434937849	14586	Economy	11700.00
0005432799005	14586	Economy	11700.00
0005434876613	14586	Economy	11700.00
0005434426127	14586	Economy	11700.00
0005434426087	14586	Economy	11700.00
0005434937853	14586	Economy	11700.00
0005432798978	14586	Economy	11700.00
0005434876578	14586	Economy	11700.00
0005435902534	14586	Economy	11700.00
0005435902548	14586	Economy	11700.00
0005434937852	14586	Economy	11700.00
0005434426105	14586	Economy	11700.00
0005432607505	14586	Economy	11700.00
0005434876806	14586	Economy	11700.00
0005434877017	14586	Economy	11700.00
0005435902536	14586	Economy	11700.00
0005432799040	14586	Economy	11700.00
0005434937850	14586	Economy	11700.00
0005434937859	14586	Economy	11700.00
0005434876640	14586	Economy	12800.00
0005434426102	14586	Economy	11700.00
0005435902541	14586	Economy	11700.00
0005434426185	14586	Economy	11700.00
0005432798969	14586	Economy	11700.00
0005434876641	14586	Economy	11700.00
0005435902547	14586	Economy	11700.00
0005434937796	14586	Economy	11700.00
0005434426115	14586	Economy	11700.00
0005434876723	14586	Economy	11700.00
0005434876738	14586	Economy	11700.00
0005435902539	14586	Economy	11700.00
0005435902537	14586	Economy	11700.00
0005434426114	14586	Economy	11700.00
0005434876682	14586	Economy	11700.00
0005435902533	14586	Economy	11700.00
0005435902538	14586	Economy	11700.00
0005434876693	14586	Economy	11700.00
0005432799049	14586	Economy	11700.00
0005434876627	14586	Economy	11700.00
0005434876739	14586	Economy	11700.00
0005434876624	14586	Economy	11700.00
0005432799090	14586	Economy	11700.00
0005432799029	14586	Economy	11700.00
0005434876835	14586	Economy	11700.00
0005434937820	14586	Economy	11700.00
0005434876647	14586	Economy	11700.00
0005435913901	14586	Economy	11700.00
0005434426104	14586	Economy	11700.00
0005434426184	14586	Economy	11700.00
0005434876893	14586	Economy	11700.00
0005435902542	14586	Economy	11700.00
0005434876648	14586	Economy	11700.00
0005432798971	14586	Economy	11700.00
0005435625865	14586	Economy	11700.00
0005434325542	3605	Economy	16300.00
0005434325537	3605	Economy	14800.00
0005434312299	3605	Economy	14800.00
0005434325544	3605	Economy	14800.00
0005434325539	3605	Economy	14800.00
0005434325546	3605	Economy	14800.00
0005434325538	3605	Economy	14800.00
0005435889793	3605	Economy	14800.00
0005434325545	3605	Economy	14800.00
0005434325543	3605	Economy	14800.00
0005434325547	3605	Economy	14800.00
0005434312298	3605	Economy	14800.00
0005434325540	3605	Economy	14800.00
0005434325548	3605	Economy	14800.00
0005434325541	3605	Economy	14800.00
0005435889841	15643	Economy	14800.00
0005435889840	15643	Economy	14800.00
0005435889842	15643	Economy	14800.00
0005434325521	15643	Economy	14800.00
0005434325482	15643	Economy	14800.00
0005434325471	15643	Economy	14800.00
0005435889843	15643	Economy	14800.00
0005434325489	15643	Economy	14800.00
0005434325445	15643	Economy	14800.00
0005435889839	15643	Economy	14800.00
0005434325490	15643	Economy	14800.00
0005434325452	15643	Economy	14800.00
0005435957566	642	Economy	4100.00
0005435957560	642	Economy	4100.00
0005435957571	642	Economy	4100.00
0005435957565	642	Economy	4100.00
0005435957568	642	Economy	4100.00
0005435957563	642	Economy	4100.00
0005435957567	642	Economy	4100.00
0005435957573	642	Economy	4100.00
0005433420269	642	Economy	4100.00
0005435957572	642	Economy	4100.00
0005435957564	642	Economy	4100.00
0005435957561	642	Economy	4100.00
0005435957570	642	Economy	4100.00
0005435957562	642	Economy	4100.00
0005435957559	642	Economy	4100.00
0005435957569	642	Economy	4100.00
0005433420327	15209	Economy	4500.00
0005435957457	15209	Economy	4100.00
0005435957458	15209	Economy	4100.00
0005433420322	15209	Economy	4100.00
0005433420321	15209	Economy	4100.00
0005435957454	15209	Economy	4100.00
0005433420324	15209	Economy	4100.00
0005433420323	15209	Economy	4100.00
0005433420320	15209	Economy	4100.00
0005433420325	15209	Economy	4100.00
0005433420326	15209	Economy	4100.00
0005435629393	8941	Economy	10400.00
0005435629394	8941	Economy	10400.00
0005434247123	16013	Economy	10400.00
0005434247125	16013	Economy	10400.00
0005434247124	16013	Economy	10400.00
0005435629388	16013	Economy	10400.00
0005435797347	2883	Business	12600.00
0005435797351	2883	Economy	4200.00
0005435797348	2883	Economy	4200.00
0005435797342	2883	Economy	4600.00
0005433404686	2883	Economy	4200.00
0005433404685	2883	Economy	4200.00
0005435797340	2883	Economy	4200.00
0005435797339	2883	Economy	4200.00
0005435797346	2883	Economy	4200.00
0005435797344	2883	Economy	4200.00
0005435797343	2883	Economy	4200.00
0005435797350	2883	Economy	4200.00
0005435797341	2883	Economy	4200.00
0005435797349	2883	Economy	4200.00
0005433404699	2883	Economy	4200.00
0005435797345	2883	Economy	4200.00
0005433404739	29347	Business	12600.00
0005435797223	29347	Economy	4200.00
0005433404741	29347	Economy	4200.00
0005433404742	29347	Economy	4200.00
0005435797261	29347	Economy	4200.00
0005433404743	29347	Economy	4200.00
0005433404745	29347	Economy	4200.00
0005433404740	29347	Economy	4200.00
0005435797259	29347	Economy	4200.00
0005435797264	29347	Economy	4200.00
0005435797251	29347	Economy	4200.00
0005435797222	29347	Economy	4200.00
0005433404744	29347	Economy	4200.00
0005433404738	29347	Economy	4200.00
0005435797250	29347	Economy	4200.00
0005435797260	29347	Economy	4200.00
0005435797243	29347	Economy	4200.00
0005434947945	5766	Economy	6800.00
0005434947943	5766	Economy	6800.00
0005434947941	5766	Economy	6800.00
0005434947940	5766	Economy	6800.00
0005434947947	5766	Economy	6800.00
0005434947946	5766	Economy	6800.00
0005434947942	5766	Economy	6800.00
0005434947944	5766	Economy	6800.00
0005434947948	5766	Economy	6800.00
0005434947889	16399	Economy	6800.00
0005434947886	16399	Economy	6800.00
0005434947871	16399	Economy	6800.00
0005434947887	16399	Economy	6800.00
0005434947904	16399	Economy	6800.00
0005435376330	16399	Economy	6800.00
0005434947939	16399	Economy	6800.00
0005434947870	16399	Economy	6800.00
0005434947872	16399	Economy	6800.00
0005434947890	16399	Economy	6800.00
0005433960349	6952	Business	21400.00
0005433960375	6952	Business	21400.00
0005433960357	6952	Business	21400.00
0005433960342	6952	Business	21400.00
0005433960368	6952	Business	21400.00
0005433960379	6952	Business	21400.00
0005433960351	6952	Business	21400.00
0005433960389	6952	Economy	7100.00
0005433960340	6952	Economy	7100.00
0005433960367	6952	Economy	7100.00
0005433960345	6952	Economy	7100.00
0005433960359	6952	Economy	7100.00
0005433960370	6952	Economy	7100.00
0005433960387	6952	Economy	7800.00
0005433960343	6952	Economy	7800.00
0005433960364	6952	Economy	7800.00
0005433960344	6952	Economy	7100.00
0005433960378	6952	Economy	7100.00
0005433960338	6952	Economy	7100.00
0005433960372	6952	Economy	7100.00
0005433960361	6952	Economy	7100.00
0005433960388	6952	Economy	7100.00
0005433960384	6952	Economy	7100.00
0005433960376	6952	Economy	7100.00
0005433960355	6952	Economy	7100.00
0005433960380	6952	Economy	7100.00
0005433960346	6952	Economy	7100.00
0005433960341	6952	Economy	7100.00
0005433960365	6952	Economy	7100.00
0005433960373	6952	Economy	7100.00
0005433960337	6952	Economy	7100.00
0005433960339	6952	Economy	7100.00
0005433960360	6952	Economy	7100.00
0005433960385	6952	Economy	7100.00
0005433960386	6952	Economy	7100.00
0005433960352	6952	Economy	7100.00
0005433960371	6952	Economy	7100.00
0005433960363	6952	Economy	7100.00
0005433960348	6952	Economy	7100.00
0005433960354	6952	Economy	7100.00
0005433960377	6952	Economy	7100.00
0005433960362	6952	Economy	7100.00
0005433960347	6952	Economy	7100.00
0005433960353	6952	Economy	7100.00
0005433960374	6952	Economy	7100.00
0005433960356	6952	Economy	7100.00
0005433960382	6952	Economy	7100.00
0005433960350	6952	Economy	7100.00
0005433960383	6952	Economy	7100.00
0005433960369	6952	Economy	7100.00
0005433960366	6952	Economy	7100.00
0005433960358	6952	Economy	7100.00
0005433960381	6952	Economy	7100.00
0005435082704	26131	Economy	3900.00
0005435082705	26131	Economy	3900.00
0005435082708	26131	Economy	3900.00
0005435082710	26131	Economy	3900.00
0005435082709	26131	Economy	3900.00
0005435082706	26131	Economy	3900.00
0005435082707	26131	Economy	3900.00
0005432166871	5003	Business	18000.00
0005434244708	5003	Business	18000.00
0005435286544	5003	Business	18000.00
0005434244703	5003	Business	18000.00
0005434244695	5003	Business	18000.00
0005434244707	5003	Economy	6600.00
0005434244706	5003	Economy	6000.00
0005435286540	5003	Economy	6000.00
0005434244715	5003	Economy	6000.00
0005432166872	5003	Economy	6000.00
0005434244702	5003	Economy	6000.00
0005434244699	5003	Economy	6000.00
0005434244714	5003	Economy	6000.00
0005435286541	5003	Economy	6000.00
0005434244713	5003	Economy	6000.00
0005434244696	5003	Economy	6000.00
0005434244697	5003	Economy	6000.00
0005434244709	5003	Economy	6000.00
0005434244704	5003	Economy	6000.00
0005434244717	5003	Economy	6000.00
0005434244712	5003	Economy	6000.00
0005434244719	5003	Economy	6000.00
0005434244694	5003	Economy	6000.00
0005434244724	5003	Economy	6000.00
0005434244711	5003	Economy	6000.00
0005434244710	5003	Economy	6000.00
0005434244701	5003	Economy	6000.00
0005434244698	5003	Economy	6000.00
0005434244720	5003	Economy	6000.00
0005434244718	5003	Economy	6000.00
0005434244705	5003	Economy	6000.00
0005434244716	5003	Economy	6000.00
0005434244723	5003	Economy	6000.00
0005434244700	5003	Economy	6000.00
0005434244722	5003	Economy	6000.00
0005435286538	5003	Economy	6000.00
0005434244721	5003	Economy	6000.00
0005433614016	5004	Business	18000.00
0005433614058	5004	Business	18000.00
0005433784595	5004	Business	18000.00
0005432105109	5004	Business	18000.00
0005433613998	5004	Business	18000.00
0005433613988	5004	Business	18000.00
0005433614036	5004	Business	18000.00
0005432105130	5004	Business	18000.00
0005432105131	5004	Business	18000.00
0005433614023	5004	Business	18000.00
0005433614040	5004	Business	18000.00
0005432105147	5004	Business	18000.00
0005433614001	5004	Business	18000.00
0005433614039	5004	Business	18000.00
0005433613996	5004	Business	18000.00
0005433614006	5004	Business	18000.00
0005433614015	5004	Business	18000.00
0005433784613	5004	Business	18000.00
0005433614002	5004	Business	18000.00
0005433613993	5004	Business	18000.00
0005433613992	5004	Business	18000.00
0005433614043	5004	Business	18000.00
0005432105129	5004	Business	18000.00
0005432105115	5004	Business	18000.00
0005432665256	5004	Business	18000.00
0005433784610	5004	Business	18000.00
0005433784620	5004	Business	18000.00
0005432105141	5004	Business	18000.00
0005432105107	5004	Economy	6600.00
0005432105116	5004	Economy	6600.00
0005433614018	5004	Economy	6600.00
0005432105136	5004	Economy	6600.00
0005433784612	5004	Economy	6600.00
0005433614020	5004	Economy	6600.00
0005433784599	5004	Economy	6000.00
0005432105150	5004	Economy	6000.00
0005432105140	5004	Economy	6000.00
0005432105127	5004	Economy	6000.00
0005433614051	5004	Economy	6000.00
0005433784596	5004	Economy	6000.00
0005433614042	5004	Economy	6000.00
0005433614021	5004	Economy	6000.00
0005433614005	5004	Economy	6000.00
0005432105149	5004	Economy	6000.00
0005432105118	5004	Economy	6000.00
0005432667436	5004	Economy	6000.00
0005433614038	5004	Economy	6000.00
0005433613999	5004	Economy	6000.00
0005433614045	5004	Economy	6000.00
0005433614046	5004	Economy	6000.00
0005433614028	5004	Economy	6000.00
0005433614014	5004	Economy	6000.00
0005433614034	5004	Economy	6000.00
0005432105132	5004	Economy	6000.00
0005432105146	5004	Economy	6000.00
0005433784617	5004	Economy	6000.00
0005433784607	5004	Economy	6000.00
0005432105142	5004	Economy	6000.00
0005433784592	5004	Economy	6000.00
0005432105122	5004	Economy	6000.00
0005432105113	5004	Economy	6000.00
0005432105111	5004	Economy	6000.00
0005433613997	5004	Economy	6000.00
0005433614032	5004	Economy	6000.00
0005432667435	5004	Economy	6000.00
0005433784606	5004	Economy	6000.00
0005433614027	5004	Economy	6000.00
0005432105152	5004	Economy	6000.00
0005433613989	5004	Economy	6000.00
0005432105138	5004	Economy	6000.00
0005433784621	5004	Economy	6000.00
0005433614010	5004	Economy	6000.00
0005432105110	5004	Economy	6000.00
0005432665257	5004	Economy	6000.00
0005433614009	5004	Economy	6000.00
0005432105117	5004	Economy	6000.00
0005433614024	5004	Economy	6000.00
0005432105139	5004	Economy	6000.00
0005433614056	5004	Economy	6000.00
0005433614059	5004	Economy	6000.00
0005433784591	5004	Economy	6000.00
0005433784597	5004	Economy	6000.00
0005433784623	5004	Economy	6000.00
0005433784587	5004	Economy	6000.00
0005432105123	5004	Economy	6000.00
0005433613987	5004	Economy	6000.00
0005433784619	5004	Economy	6000.00
0005433614037	5004	Economy	6000.00
0005433784588	5004	Economy	6000.00
0005433614031	5004	Economy	6000.00
0005433614007	5004	Economy	6000.00
0005432105121	5004	Economy	6000.00
0005433784611	5004	Economy	6000.00
0005433614013	5004	Economy	6000.00
0005432105104	5004	Economy	6600.00
0005433614000	5004	Economy	6600.00
0005433784589	5004	Economy	6600.00
0005433614025	5004	Economy	6600.00
0005433784594	5004	Economy	6600.00
0005432105124	5004	Economy	6000.00
0005432105114	5004	Economy	6000.00
0005433784600	5004	Economy	6000.00
0005433784605	5004	Economy	6000.00
0005433784616	5004	Economy	6600.00
0005433614033	5004	Economy	6000.00
0005432665254	5004	Economy	6000.00
0005433614029	5004	Economy	6000.00
0005433614044	5004	Economy	6000.00
0005433613986	5004	Economy	6000.00
0005433614057	5004	Economy	6000.00
0005433614053	5004	Economy	6000.00
0005433784593	5004	Economy	6000.00
0005433613985	5004	Economy	6000.00
0005433613990	5004	Economy	6000.00
0005433614026	5004	Economy	6000.00
0005432665255	5004	Economy	6000.00
0005432105106	5004	Economy	6000.00
0005433614048	5004	Economy	6000.00
0005432105135	5004	Economy	6000.00
0005433614052	5004	Economy	6000.00
0005432105119	5004	Economy	6000.00
0005433614050	5004	Economy	6000.00
0005433784618	5004	Economy	6000.00
0005433614003	5004	Economy	6000.00
0005433784614	5004	Economy	6000.00
0005432105128	5004	Economy	6000.00
0005432105112	5004	Economy	6000.00
0005433614011	5004	Economy	6000.00
0005432105151	5004	Economy	6000.00
0005433614012	5004	Economy	6000.00
0005432105126	5004	Economy	6000.00
0005433614030	5004	Economy	6000.00
0005433784608	5004	Economy	6000.00
0005433614041	5004	Economy	6000.00
0005432667434	5004	Economy	6000.00
0005433614055	5004	Economy	6000.00
0005433613995	5004	Economy	6000.00
0005433784609	5004	Economy	6000.00
0005433614054	5004	Economy	6000.00
0005432105137	5004	Economy	6000.00
0005433784603	5004	Economy	6000.00
0005432145093	5004	Economy	6000.00
0005433613991	5004	Economy	6000.00
0005432105105	5004	Economy	6000.00
0005433784590	5004	Economy	6000.00
0005432105148	5004	Economy	6000.00
0005433614035	5004	Economy	6000.00
0005432105125	5004	Economy	6000.00
0005433784601	5004	Economy	6000.00
0005432105120	5004	Economy	6000.00
0005433614004	5004	Economy	6000.00
0005432105144	5004	Economy	6000.00
0005433614019	5004	Economy	6000.00
0005432105143	5004	Economy	6000.00
0005433784615	5004	Economy	6000.00
0005433614022	5004	Economy	6000.00
0005432105145	5004	Economy	6000.00
0005433784598	5004	Economy	6000.00
0005433784604	5004	Economy	6000.00
0005432105133	5004	Economy	6000.00
0005433614008	5004	Economy	6000.00
0005432105134	5004	Economy	6000.00
0005433613994	5004	Economy	6000.00
0005433784622	5004	Economy	6000.00
0005433784602	5004	Economy	6000.00
0005433614049	5004	Economy	6000.00
0005433614017	5004	Economy	6000.00
0005433614047	5004	Economy	6000.00
0005432105108	5004	Economy	6000.00
0005433688773	5006	Business	18000.00
0005434149618	5006	Business	18000.00
0005434229152	5006	Business	18000.00
0005434229156	5006	Business	18000.00
0005434229160	5006	Business	18000.00
0005433815303	5006	Business	18000.00
0005434229165	5006	Business	18000.00
0005434264908	5006	Business	18000.00
0005434264912	5006	Business	18000.00
0005434149622	5006	Business	18000.00
0005434264909	5006	Business	18000.00
0005435269643	5006	Business	18000.00
0005434264906	5006	Business	18000.00
0005435006697	5006	Business	18000.00
0005434173481	5006	Business	18000.00
0005435006667	5006	Business	18000.00
0005434229157	5006	Economy	6600.00
0005434229163	5006	Economy	6600.00
0005434264893	5006	Economy	6600.00
0005432335860	5006	Economy	6000.00
0005434229172	5006	Economy	6000.00
0005434173484	5006	Economy	6000.00
0005434264889	5006	Economy	6000.00
0005434264891	5006	Economy	6000.00
0005434229167	5006	Economy	6000.00
0005435269638	5006	Economy	6000.00
0005434229151	5006	Economy	6000.00
0005435006695	5006	Economy	6000.00
0005434149620	5006	Economy	6000.00
0005434264896	5006	Economy	6000.00
0005434264902	5006	Economy	6000.00
0005435006696	5006	Economy	6000.00
0005434264894	5006	Economy	6000.00
0005435006693	5006	Economy	6000.00
0005434264905	5006	Economy	6000.00
0005434229171	5006	Economy	6000.00
0005434149623	5006	Economy	6000.00
0005434229169	5006	Economy	6000.00
0005434229154	5006	Economy	6000.00
0005435006628	5006	Economy	6000.00
0005434149621	5006	Economy	6000.00
0005434149627	5006	Economy	6000.00
0005434264898	5006	Economy	6000.00
0005434149616	5006	Economy	6000.00
0005434229161	5006	Economy	6000.00
0005434229162	5006	Economy	6000.00
0005434229153	5006	Economy	6000.00
0005434264888	5006	Economy	6000.00
0005434149624	5006	Economy	6600.00
0005434229158	5006	Economy	6600.00
0005435269622	5006	Economy	6600.00
0005434264901	5006	Economy	6000.00
0005435006659	5006	Economy	6000.00
0005435269633	5006	Economy	6000.00
0005434264887	5006	Economy	6000.00
0005434149617	5006	Economy	6600.00
0005434264892	5006	Economy	6000.00
0005435006622	5006	Economy	6000.00
0005435006660	5006	Economy	6000.00
0005432335830	5006	Economy	6000.00
0005434264907	5006	Economy	6000.00
0005434264910	5006	Economy	6000.00
0005434264895	5006	Economy	6000.00
0005435269637	5006	Economy	6000.00
0005433688784	5006	Economy	6000.00
0005434229155	5006	Economy	6000.00
0005434229164	5006	Economy	6000.00
0005434149625	5006	Economy	6000.00
0005432335869	5006	Economy	6000.00
0005434173483	5006	Economy	6000.00
0005434229166	5006	Economy	6000.00
0005434229168	5006	Economy	6000.00
0005434264913	5006	Economy	6000.00
0005434149626	5006	Economy	6000.00
0005434264897	5006	Economy	6000.00
0005434149619	5006	Economy	6000.00
0005434264911	5006	Economy	6000.00
0005434264903	5006	Economy	6000.00
0005434264900	5006	Economy	6000.00
0005434229170	5006	Economy	6000.00
0005434264890	5006	Economy	6000.00
0005434264904	5006	Economy	6000.00
0005432335831	5006	Economy	6000.00
0005434229173	5006	Economy	6000.00
0005434173482	5006	Economy	6000.00
0005434264899	5006	Economy	6000.00
0005435269640	5006	Economy	6000.00
0005434229159	5006	Economy	6000.00
0005434244510	8387	Business	18000.00
0005433784309	8387	Business	18000.00
0005432666359	8387	Business	18000.00
0005433784294	8387	Business	18000.00
0005434244528	8387	Business	18000.00
0005433784292	8387	Business	18000.00
0005435269677	8387	Business	18000.00
0005434244490	8387	Business	18000.00
0005434244535	8387	Business	18000.00
0005433784404	8387	Business	18000.00
0005434244537	8387	Business	18000.00
0005434244589	8387	Economy	6600.00
0005434244485	8387	Economy	6600.00
0005435269684	8387	Economy	6000.00
0005433784416	8387	Economy	6000.00
0005434244536	8387	Economy	6000.00
0005434244511	8387	Economy	6000.00
0005435269675	8387	Economy	6000.00
0005435269683	8387	Economy	6000.00
0005433784311	8387	Economy	6000.00
0005435269676	8387	Economy	6000.00
0005435269681	8387	Economy	6000.00
0005435269679	8387	Economy	6000.00
0005435269680	8387	Economy	6000.00
0005433784293	8387	Economy	6000.00
0005433784403	8387	Economy	6000.00
0005434244534	8387	Economy	6000.00
0005432666360	8387	Economy	6000.00
0005434244465	8387	Economy	6600.00
0005434244467	8387	Economy	6600.00
0005435269678	8387	Economy	6000.00
0005434244494	8387	Economy	6000.00
0005435269682	8387	Economy	6000.00
0005433784295	8387	Economy	6000.00
0005433784402	8387	Economy	6000.00
0005434244571	8387	Economy	6000.00
0005434244522	8387	Economy	6000.00
0005434244569	8387	Economy	6000.00
0005433784312	8387	Economy	6000.00
0005433784430	8387	Economy	6000.00
0005434244468	8387	Economy	6000.00
0005433784328	8387	Economy	6000.00
0005434244466	8387	Economy	6000.00
0005433784310	8387	Economy	6000.00
0005433784415	8387	Economy	6000.00
0005434244486	8387	Economy	6000.00
0005433784339	8387	Economy	6000.00
0005433613389	8386	Business	18000.00
0005433613504	8386	Business	18000.00
0005433613510	8386	Business	18000.00
0005433613399	8386	Business	18000.00
0005433613438	8386	Economy	6600.00
0005433613456	8386	Economy	6000.00
0005433613649	8386	Economy	6000.00
0005433613487	8386	Economy	6000.00
0005433613472	8386	Economy	6000.00
0005433613650	8386	Economy	6000.00
0005433613388	8386	Economy	6000.00
0005433613495	8386	Economy	6000.00
0005433613624	8386	Economy	6000.00
0005433613464	8386	Economy	6000.00
0005433613678	8386	Economy	6000.00
0005433613648	8386	Economy	6000.00
0005433613415	8386	Economy	6600.00
0005433613548	8386	Economy	6000.00
0005433613493	8386	Economy	6000.00
0005433613494	8386	Economy	6000.00
0005433613502	8386	Economy	6000.00
0005433613453	8386	Economy	6000.00
0005433613429	8386	Economy	6000.00
0005433613569	8386	Economy	6000.00
0005433613431	8386	Economy	6000.00
0005433613480	8386	Economy	6000.00
0005433613625	8386	Economy	6000.00
0005433613430	8386	Economy	6000.00
0005433613568	8386	Economy	6000.00
0005432034690	8385	Business	18000.00
0005435006803	8385	Business	18000.00
0005434264726	8385	Business	18000.00
0005432335927	8385	Business	18000.00
0005435286568	8385	Business	18000.00
0005434264687	8385	Business	18000.00
0005434229055	8385	Business	18000.00
0005434228989	8385	Business	18000.00
0005434264735	8385	Business	18000.00
0005432034685	8385	Business	18000.00
0005432034691	8385	Business	18000.00
0005433534480	8385	Business	18000.00
0005432335926	8385	Business	18000.00
0005432034683	8385	Business	18000.00
0005434264759	8385	Business	18000.00
0005435006816	8385	Business	18000.00
0005433689892	8385	Business	18000.00
0005432034704	8385	Business	18000.00
0005434229026	8385	Business	18000.00
0005432335922	8385	Business	18000.00
0005432034702	8385	Business	18000.00
0005434264760	8385	Business	18000.00
0005432034692	8385	Economy	6600.00
0005435006804	8385	Economy	6600.00
0005432034695	8385	Economy	6600.00
0005435006801	8385	Economy	6600.00
0005434264766	8385	Economy	6600.00
0005432047515	8385	Economy	6000.00
0005435006799	8385	Economy	6000.00
0005434228973	8385	Economy	6000.00
0005435006814	8385	Economy	6000.00
0005434228975	8385	Economy	6000.00
0005434229053	8385	Economy	6000.00
0005432335923	8385	Economy	6000.00
0005435006812	8385	Economy	6000.00
0005434228988	8385	Economy	6000.00
0005433688791	8385	Economy	6000.00
0005432335929	8385	Economy	6000.00
0005433534479	8385	Economy	6000.00
0005434264736	8385	Economy	6000.00
0005434229025	8385	Economy	6000.00
0005434228976	8385	Economy	6000.00
0005435286569	8385	Economy	6000.00
0005433815343	8385	Economy	6000.00
0005432034694	8385	Economy	6000.00
0005435006809	8385	Economy	6000.00
0005433815342	8385	Economy	6000.00
0005432034689	8385	Economy	6000.00
0005434264734	8385	Economy	6000.00
0005433690907	8385	Economy	6000.00
0005434149538	8385	Economy	6000.00
0005432335928	8385	Economy	6000.00
0005435006800	8385	Economy	6000.00
0005432335919	8385	Economy	6000.00
0005434149540	8385	Economy	6000.00
0005434264779	8385	Economy	6000.00
0005432034677	8385	Economy	6000.00
0005433690908	8385	Economy	6000.00
0005435006813	8385	Economy	6000.00
0005434264719	8385	Economy	6000.00
0005435006793	8385	Economy	6000.00
0005432034687	8385	Economy	6000.00
0005435006805	8385	Economy	6000.00
0005432034681	8385	Economy	6000.00
0005435286567	8385	Economy	6000.00
0005435006798	8385	Economy	6000.00
0005432034701	8385	Economy	6000.00
0005432047516	8385	Economy	6600.00
0005432034698	8385	Economy	6600.00
0005432034686	8385	Economy	6600.00
0005435006806	8385	Economy	6600.00
0005435006796	8385	Economy	6600.00
0005434264716	8385	Economy	6000.00
0005432034697	8385	Economy	6000.00
0005433688790	8385	Economy	6000.00
0005434149571	8385	Economy	6000.00
0005433689891	8385	Economy	6000.00
0005432034688	8385	Economy	6000.00
0005434264717	8385	Economy	6000.00
0005432034682	8385	Economy	6000.00
0005435006807	8385	Economy	6000.00
0005434228986	8385	Economy	6000.00
0005432034699	8385	Economy	6000.00
0005434264699	8385	Economy	6000.00
0005432034679	8385	Economy	6000.00
0005432335921	8385	Economy	6000.00
0005432034703	8385	Economy	6000.00
0005434229013	8385	Economy	6000.00
0005435006795	8385	Economy	6000.00
0005432335925	8385	Economy	6000.00
0005432034684	8385	Economy	6000.00
0005435006810	8385	Economy	6000.00
0005434229001	8385	Economy	6000.00
0005434229003	8385	Economy	6000.00
0005433815344	8385	Economy	6000.00
0005435286566	8385	Economy	6000.00
0005434228987	8385	Economy	6000.00
0005434264691	8385	Economy	6000.00
0005432335924	8385	Economy	6000.00
0005433815340	8385	Economy	6000.00
0005433534478	8385	Economy	6000.00
0005435006811	8385	Economy	6000.00
0005435006808	8385	Economy	6000.00
0005434149572	8385	Economy	6000.00
0005433815341	8385	Economy	6000.00
0005432335920	8385	Economy	6000.00
0005435006815	8385	Economy	6000.00
0005435006802	8385	Economy	6000.00
0005435006794	8385	Economy	6000.00
0005434264780	8385	Economy	6000.00
0005432034700	8385	Economy	6000.00
0005434229054	8385	Economy	6000.00
0005435006797	8385	Economy	6000.00
0005432034696	8385	Economy	6000.00
0005435006792	8385	Economy	6000.00
0005432034678	8385	Economy	6000.00
0005434149539	8385	Economy	6000.00
0005432034693	8385	Economy	6000.00
0005432034680	8385	Economy	6000.00
0005433202224	12633	Economy	16200.00
0005434638992	12633	Economy	16200.00
0005433202231	12633	Economy	16200.00
0005433202223	12633	Economy	16200.00
0005434638917	12633	Economy	14800.00
0005434638903	12633	Economy	14800.00
0005433202225	12633	Economy	14800.00
0005434638893	12633	Economy	14800.00
0005433202234	12633	Economy	14800.00
0005434638854	12633	Economy	14800.00
0005434638991	12633	Economy	14800.00
0005434638916	12633	Economy	14800.00
0005434638864	12633	Economy	14800.00
0005433202236	12633	Economy	14800.00
0005433202233	12633	Economy	14800.00
0005434638886	12633	Economy	14800.00
0005434638900	12633	Economy	14800.00
0005434638885	12633	Economy	14800.00
0005433202237	12633	Economy	14800.00
0005433202226	12633	Economy	14800.00
0005434638879	12633	Economy	14800.00
0005433202238	12633	Economy	14800.00
0005434638904	12633	Economy	14800.00
0005434638894	12633	Economy	14800.00
0005434638887	12633	Economy	14800.00
0005433202235	12633	Economy	14800.00
0005433202228	12633	Economy	14800.00
0005434638924	12633	Economy	14800.00
0005434638899	12633	Economy	14800.00
0005433202229	12633	Economy	14800.00
0005433202230	12633	Economy	14800.00
0005433202232	12633	Economy	14800.00
0005434638850	12633	Economy	14800.00
0005433202227	12633	Economy	14800.00
0005434639064	23375	Economy	16200.00
0005432290602	23375	Economy	16200.00
0005434639050	23375	Economy	14800.00
0005434639045	23375	Economy	14800.00
0005432290603	23375	Economy	14800.00
0005432290604	23375	Economy	14800.00
0005434639060	23375	Economy	14800.00
0005434639053	23375	Economy	14800.00
0005434639056	23375	Economy	14800.00
0005434639066	23375	Economy	14800.00
0005433202109	23375	Economy	14800.00
0005434639054	23375	Economy	14800.00
0005434639069	23375	Economy	14800.00
0005433202114	23375	Economy	14800.00
0005434639065	23375	Economy	14800.00
0005434639061	23375	Economy	14800.00
0005434639068	23375	Economy	14800.00
0005434639057	23375	Economy	14800.00
0005434639044	23375	Economy	14800.00
0005432290601	23375	Economy	14800.00
0005433202119	23375	Economy	14800.00
0005434639047	23375	Economy	14800.00
0005434639063	23375	Economy	14800.00
0005434639049	23375	Economy	14800.00
0005434639046	23375	Economy	14800.00
0005434639051	23375	Economy	14800.00
0005434639062	23375	Economy	14800.00
0005433202116	23375	Economy	14800.00
0005434639055	23375	Economy	14800.00
0005434639067	23375	Economy	14800.00
0005434639059	23375	Economy	14800.00
0005434639052	23375	Economy	14800.00
0005434639058	23375	Economy	14800.00
0005434639048	23375	Economy	14800.00
0005432327948	21108	Business	18900.00
0005432382484	21108	Business	18900.00
0005432327937	21108	Business	18900.00
0005432054277	21108	Economy	6300.00
0005432382544	21108	Economy	6300.00
0005432382510	21108	Economy	6300.00
0005432382559	21108	Economy	6300.00
0005432054276	21108	Economy	6300.00
0005432327936	21108	Economy	6300.00
0005432382490	21108	Economy	6300.00
0005432382536	21108	Economy	6300.00
0005432382545	21108	Economy	6300.00
0005432382507	21108	Economy	6300.00
0005432382508	21108	Economy	6300.00
0005432327983	21108	Economy	6300.00
0005432327938	21108	Economy	6300.00
0005432382521	21108	Economy	6300.00
0005432382509	21108	Economy	6300.00
0005432382519	21108	Economy	6300.00
0005432382572	21108	Economy	6300.00
0005432382501	21108	Economy	6300.00
0005432327897	21108	Economy	6300.00
0005432382503	21108	Economy	6300.00
0005432054278	21108	Economy	6300.00
0005432327984	21108	Economy	6300.00
0005432382487	21108	Economy	6300.00
0005432382518	21108	Economy	6300.00
0005432327895	21108	Economy	6300.00
0005432327929	21108	Economy	6300.00
0005432327928	21108	Economy	6300.00
0005432328261	31227	Business	18900.00
0005432328264	31227	Business	18900.00
0005432287137	31227	Business	18900.00
0005432328247	31227	Business	18900.00
0005432328260	31227	Business	18900.00
0005432382783	31227	Business	18900.00
0005432382796	31227	Business	18900.00
0005432328245	31227	Business	18900.00
0005432328233	31227	Business	18900.00
0005432328246	31227	Business	18900.00
0005432328225	31227	Business	18900.00
0005432382772	31227	Economy	6300.00
0005432382769	31227	Economy	6300.00
0005432382776	31227	Economy	6300.00
0005432382781	31227	Economy	6300.00
0005432382787	31227	Economy	6300.00
0005432328231	31227	Economy	6300.00
0005432328265	31227	Economy	6300.00
0005432328256	31227	Economy	6300.00
0005432328229	31227	Economy	6300.00
0005432328220	31227	Economy	6900.00
0005432328219	31227	Economy	6900.00
0005432382771	31227	Economy	6900.00
0005432328257	31227	Economy	6900.00
0005432287138	31227	Economy	6900.00
0005432287136	31227	Economy	6300.00
0005432328251	31227	Economy	6300.00
0005432328242	31227	Economy	6300.00
0005432328230	31227	Economy	6300.00
0005432328254	31227	Economy	6300.00
0005432328221	31227	Economy	6300.00
0005432328255	31227	Economy	6300.00
0005432328234	31227	Economy	6300.00
0005432382795	31227	Economy	6300.00
0005432382784	31227	Economy	6300.00
0005432382798	31227	Economy	6300.00
0005432328244	31227	Economy	6300.00
0005432328236	31227	Economy	6300.00
0005432328228	31227	Economy	6300.00
0005432328222	31227	Economy	6300.00
0005432287139	31227	Economy	6300.00
0005432382790	31227	Economy	6300.00
0005432382773	31227	Economy	6300.00
0005432382788	31227	Economy	6300.00
0005432382791	31227	Economy	6300.00
0005432328252	31227	Economy	6300.00
0005432382785	31227	Economy	6300.00
0005432382775	31227	Economy	6300.00
0005432328248	31227	Economy	6300.00
0005432382779	31227	Economy	6300.00
0005432328223	31227	Economy	6300.00
0005432382799	31227	Economy	6300.00
0005432382789	31227	Economy	6300.00
0005432382793	31227	Economy	6300.00
0005432328227	31227	Economy	6300.00
0005432382777	31227	Economy	6300.00
0005432382803	31227	Economy	6300.00
0005432328253	31227	Economy	6300.00
0005432328232	31227	Economy	6300.00
0005432328237	31227	Economy	6300.00
0005432382786	31227	Economy	6300.00
0005432382770	31227	Economy	6300.00
0005432328226	31227	Economy	6300.00
0005432382797	31227	Economy	6300.00
0005432328263	31227	Economy	6300.00
0005432328249	31227	Economy	6300.00
0005432382774	31227	Economy	6300.00
0005432382802	31227	Economy	6300.00
0005432328240	31227	Economy	6300.00
0005432382768	31227	Economy	6300.00
0005432328262	31227	Economy	6300.00
0005432287140	31227	Economy	6300.00
0005432328239	31227	Economy	6300.00
0005432382792	31227	Economy	6300.00
0005432328241	31227	Economy	6300.00
0005432382778	31227	Economy	6300.00
0005432382782	31227	Economy	6300.00
0005432328250	31227	Economy	6300.00
0005432328224	31227	Economy	6300.00
0005432382800	31227	Economy	6300.00
0005432382794	31227	Economy	6300.00
0005432382767	31227	Economy	6300.00
0005432328258	31227	Economy	6300.00
0005432328243	31227	Economy	6300.00
0005432382801	31227	Economy	6300.00
0005432328259	31227	Economy	6300.00
0005432328235	31227	Economy	6300.00
0005432382780	31227	Economy	6300.00
0005432328238	31227	Economy	6300.00
0005432423974	13325	Business	12700.00
0005432423996	13325	Business	12700.00
0005432423965	13325	Business	12700.00
0005432423982	13325	Business	12700.00
0005432423960	13325	Business	12700.00
0005432423958	13325	Economy	4200.00
0005432423968	13325	Economy	4200.00
0005432423986	13325	Economy	4200.00
0005432423992	13325	Economy	4200.00
0005432423976	13325	Economy	4700.00
0005432423973	13325	Economy	4200.00
0005432423980	13325	Economy	4200.00
0005432423990	13325	Economy	4200.00
0005432423983	13325	Economy	4200.00
0005432423957	13325	Economy	4200.00
0005432423989	13325	Economy	4200.00
0005432423994	13325	Economy	4200.00
0005432423981	13325	Economy	4200.00
0005432423964	13325	Economy	4200.00
0005432423956	13325	Economy	4200.00
0005432423971	13325	Economy	4200.00
0005432423963	13325	Economy	4200.00
0005432423997	13325	Economy	4200.00
0005432423995	13325	Economy	4200.00
0005432423977	13325	Economy	4200.00
0005432423979	13325	Economy	4200.00
0005432423991	13325	Economy	4200.00
0005432423972	13325	Economy	4200.00
0005432423999	13325	Economy	4200.00
0005432423998	13325	Economy	4200.00
0005432423978	13325	Economy	4200.00
0005432423969	13325	Economy	4200.00
0005432423975	13325	Economy	4200.00
0005432423962	13325	Economy	4200.00
0005432423984	13325	Economy	4200.00
0005432423988	13325	Economy	4200.00
0005432423993	13325	Economy	4200.00
0005432423987	13325	Economy	4200.00
0005432423961	13325	Economy	4200.00
0005432423985	13325	Economy	4200.00
0005432423959	13325	Economy	4200.00
0005432423966	13325	Economy	4200.00
0005432423967	13325	Economy	4200.00
0005432423970	13325	Economy	4200.00
0005434186157	9589	Business	32600.00
0005434448284	9589	Business	32600.00
0005432817195	9589	Business	32600.00
0005432817196	9589	Business	32600.00
0005432817207	9589	Business	32600.00
0005432817202	9589	Business	32600.00
0005432817206	9589	Economy	10900.00
0005432817210	9589	Economy	10900.00
0005432817187	9589	Economy	10900.00
0005434448282	9589	Economy	10900.00
0005432901306	9589	Economy	10900.00
0005434157355	9589	Economy	10900.00
0005432822130	9589	Economy	10900.00
0005432817181	9589	Economy	10900.00
0005432817180	9589	Economy	11900.00
0005432817208	9589	Economy	11900.00
0005432288957	9589	Economy	11900.00
0005432817209	9589	Economy	11900.00
0005432817183	9589	Economy	10900.00
0005432288954	9589	Economy	10900.00
0005432817182	9589	Economy	10900.00
0005434157354	9589	Economy	10900.00
0005432817199	9589	Economy	10900.00
0005432901302	9589	Economy	10900.00
0005434186159	9589	Economy	10900.00
0005432901346	9589	Economy	10900.00
0005432901295	9589	Economy	10900.00
0005432901369	9589	Economy	10900.00
0005432288955	9589	Economy	10900.00
0005432822134	9589	Economy	10900.00
0005432822133	9589	Economy	10900.00
0005432822129	9589	Economy	10900.00
0005432817192	9589	Economy	10900.00
0005432817204	9589	Economy	10900.00
0005432817200	9589	Economy	10900.00
0005432817189	9589	Economy	10900.00
0005432901380	9589	Economy	10900.00
0005432817186	9589	Economy	10900.00
0005432901370	9589	Economy	10900.00
0005432817185	9589	Economy	10900.00
0005432901301	9589	Economy	10900.00
0005432817191	9589	Economy	10900.00
0005432901356	9589	Economy	10900.00
0005432901317	9589	Economy	10900.00
0005432288956	9589	Economy	10900.00
0005432817211	9589	Economy	10900.00
0005432901319	9589	Economy	10900.00
0005432817203	9589	Economy	10900.00
0005432288958	9589	Economy	10900.00
0005432817198	9589	Economy	10900.00
0005432901361	9589	Economy	10900.00
0005432817201	9589	Economy	10900.00
0005432901305	9589	Economy	10900.00
0005432817194	9589	Economy	10900.00
0005432817193	9589	Economy	10900.00
0005432817205	9589	Economy	10900.00
0005434186158	9589	Economy	10900.00
0005434448283	9589	Economy	10900.00
0005432817197	9589	Economy	10900.00
0005432817188	9589	Economy	10900.00
0005434157358	9589	Economy	10900.00
0005432901293	9589	Economy	10900.00
0005432901316	9589	Economy	10900.00
0005432817184	9589	Economy	10900.00
0005432822127	9589	Economy	10900.00
0005432822128	9589	Economy	10900.00
0005434186154	9589	Economy	10900.00
0005432817190	9589	Economy	10900.00
0005432901381	9589	Economy	10900.00
0005432822131	9589	Economy	10900.00
0005432822132	9589	Economy	10900.00
0005432816948	29007	Business	32600.00
0005432817022	29007	Business	32600.00
0005432816976	29007	Business	32600.00
0005432822081	29007	Business	32600.00
0005432901447	29007	Business	32600.00
0005432901439	29007	Business	32600.00
0005432817009	29007	Business	32600.00
0005432817050	29007	Business	32600.00
0005432816992	29007	Economy	10900.00
0005432816995	29007	Economy	10900.00
0005432816969	29007	Economy	10900.00
0005432901448	29007	Economy	10900.00
0005434157407	29007	Economy	10900.00
0005432901445	29007	Economy	10900.00
0005432002057	29007	Economy	11900.00
0005434157408	29007	Economy	11900.00
0005432901451	29007	Economy	11900.00
0005432901444	29007	Economy	10900.00
0005432901450	29007	Economy	10900.00
0005434157411	29007	Economy	10900.00
0005432816939	29007	Economy	10900.00
0005432816960	29007	Economy	10900.00
0005432901452	29007	Economy	10900.00
0005434157404	29007	Economy	10900.00
0005432901446	29007	Economy	10900.00
0005432901453	29007	Economy	10900.00
0005432822073	29007	Economy	10900.00
0005432901437	29007	Economy	10900.00
0005434186169	29007	Economy	10900.00
0005432816994	29007	Economy	10900.00
0005432901454	29007	Economy	10900.00
0005432816991	29007	Economy	10900.00
0005432816993	29007	Economy	10900.00
0005432901443	29007	Economy	10900.00
0005432901442	29007	Economy	10900.00
0005432901440	29007	Economy	10900.00
0005432901441	29007	Economy	10900.00
0005434157405	29007	Economy	10900.00
0005434186170	29007	Economy	10900.00
0005434157406	29007	Economy	10900.00
0005434157410	29007	Economy	10900.00
0005432901449	29007	Economy	10900.00
0005432817051	29007	Economy	10900.00
0005432816940	29007	Economy	10900.00
0005434157409	29007	Economy	10900.00
0005432901438	29007	Economy	10900.00
0005432816981	29007	Economy	10900.00
0005434186168	29007	Economy	10900.00
0005432002056	29007	Economy	10900.00
0005432816975	29007	Economy	10900.00
0005432816961	29007	Economy	10900.00
0005432816968	29007	Economy	10900.00
0005434186171	29007	Economy	10900.00
0005432613822	15036	Economy	11000.00
0005432611672	15036	Economy	11000.00
0005432611675	15036	Economy	11000.00
0005432613825	15036	Economy	11000.00
0005432611673	15036	Economy	11000.00
0005432611674	15036	Economy	11000.00
0005432613823	15036	Economy	11000.00
0005432613826	15036	Economy	11000.00
0005432613824	15036	Economy	11000.00
0005432607494	31570	Economy	11000.00
0005432607505	31570	Economy	11000.00
0005433568440	11843	Business	105900.00
0005433568435	11843	Business	105900.00
0005433568427	11843	Business	105900.00
0005433568430	11843	Business	105900.00
0005433568463	11843	Business	105900.00
0005433568425	11843	Business	105900.00
0005433568433	11843	Business	105900.00
0005433568477	11843	Business	105900.00
0005432947797	11843	Business	105900.00
0005433568454	11843	Business	105900.00
0005433568434	11843	Business	105900.00
0005433568447	11843	Economy	35300.00
0005433568438	11843	Economy	35300.00
0005433568450	11843	Economy	35300.00
0005433568476	11843	Economy	35300.00
0005433568442	11843	Economy	35300.00
0005433568432	11843	Economy	35300.00
0005433568452	11843	Economy	35300.00
0005433568461	11843	Economy	35300.00
0005433568444	11843	Economy	35300.00
0005432947776	11843	Economy	35300.00
0005433568424	11843	Economy	35300.00
0005433568443	11843	Economy	35300.00
0005433568441	11843	Economy	35300.00
0005433568449	11843	Economy	35300.00
0005433568423	11843	Economy	35300.00
0005433568437	11843	Economy	35300.00
0005433568474	11843	Economy	35300.00
0005432947796	11843	Economy	35300.00
0005433568465	11843	Economy	35300.00
0005433568472	11843	Economy	35300.00
0005433568473	11843	Economy	35300.00
0005433568460	11843	Economy	35300.00
0005433568455	11843	Economy	35300.00
0005433568436	11843	Economy	35300.00
0005433568471	11843	Economy	35300.00
0005433568462	11843	Economy	35300.00
0005433568428	11843	Economy	35300.00
0005433568458	11843	Economy	35300.00
0005433568445	11843	Economy	35300.00
0005432947764	11843	Economy	35300.00
0005433568431	11843	Economy	35300.00
0005433568464	11843	Economy	35300.00
0005433568457	11843	Economy	35300.00
0005433568468	11843	Economy	35300.00
0005433568429	11843	Economy	35300.00
0005433568459	11843	Economy	35300.00
0005433568469	11843	Economy	35300.00
0005433568467	11843	Economy	35300.00
0005433568451	11843	Economy	35300.00
0005433568448	11843	Economy	35300.00
0005433568466	11843	Economy	35300.00
0005433568456	11843	Economy	35300.00
0005433568446	11843	Economy	35300.00
0005433568475	11843	Economy	35300.00
0005433568453	11843	Economy	35300.00
0005433568426	11843	Economy	35300.00
0005432947775	11843	Economy	35300.00
0005433568439	11843	Economy	35300.00
0005433568470	11843	Economy	35300.00
0005432948127	25271	Business	105900.00
0005433568071	25271	Business	105900.00
0005432948104	25271	Business	105900.00
0005433568073	25271	Business	105900.00
0005433568033	25271	Business	105900.00
0005432948129	25271	Business	105900.00
0005432948097	25271	Business	105900.00
0005432948102	25271	Business	105900.00
0005432948138	25271	Business	105900.00
0005432948132	25271	Business	105900.00
0005432948134	25271	Economy	35300.00
0005432948109	25271	Economy	35300.00
0005432948098	25271	Economy	35300.00
0005432948136	25271	Economy	35300.00
0005433568027	25271	Economy	38800.00
0005432948118	25271	Economy	38800.00
0005432948121	25271	Economy	35300.00
0005432948100	25271	Economy	35300.00
0005433568076	25271	Economy	35300.00
0005433568023	25271	Economy	35300.00
0005432948107	25271	Economy	35300.00
0005432948120	25271	Economy	35300.00
0005432948117	25271	Economy	35300.00
0005432948105	25271	Economy	35300.00
0005432948115	25271	Economy	35300.00
0005432948131	25271	Economy	35300.00
0005433568072	25271	Economy	35300.00
0005432948123	25271	Economy	35300.00
0005432948130	25271	Economy	35300.00
0005432948128	25271	Economy	35300.00
0005432948111	25271	Economy	35300.00
0005432948126	25271	Economy	35300.00
0005432948133	25271	Economy	35300.00
0005432948110	25271	Economy	35300.00
0005432948137	25271	Economy	35300.00
0005433568070	25271	Economy	35300.00
0005432948106	25271	Economy	35300.00
0005432948122	25271	Economy	35300.00
0005432948114	25271	Economy	35300.00
0005432948116	25271	Economy	35300.00
0005432948108	25271	Economy	35300.00
0005432948112	25271	Economy	35300.00
0005432948119	25271	Economy	35300.00
0005433568082	25271	Economy	35300.00
0005432948101	25271	Economy	35300.00
0005432948125	25271	Economy	35300.00
0005432948113	25271	Economy	35300.00
0005432948135	25271	Economy	35300.00
0005432948099	25271	Economy	35300.00
0005432948103	25271	Economy	35300.00
0005432948124	25271	Economy	35300.00
0005434654425	5398	Business	67200.00
0005434654401	5398	Business	67200.00
0005434654421	5398	Business	67200.00
0005432114173	5398	Business	67200.00
0005435340050	5398	Economy	22400.00
0005435340048	5398	Economy	22400.00
0005435340009	5398	Economy	22400.00
0005434654403	5398	Economy	24600.00
0005434654402	5398	Economy	24600.00
0005432114172	5398	Economy	24600.00
0005434654417	5398	Economy	22400.00
0005434654422	5398	Economy	22400.00
0005435340039	5398	Economy	22400.00
0005434654405	5398	Economy	22400.00
0005434654427	5398	Economy	22400.00
0005434654424	5398	Economy	22400.00
0005434654416	5398	Economy	22400.00
0005434654404	5398	Economy	22400.00
0005435340012	5398	Economy	22400.00
0005435340038	5398	Economy	22400.00
0005435340010	5398	Economy	22400.00
0005434654423	5398	Economy	22400.00
0005435340027	5398	Economy	22400.00
0005434654412	5398	Economy	22400.00
0005434654406	5398	Economy	22400.00
0005434654426	5398	Economy	22400.00
0005434654428	5398	Economy	22400.00
0005434654413	5398	Economy	22400.00
0005434654411	5398	Economy	22400.00
0005435340020	5398	Economy	22400.00
0005434654400	5398	Economy	22400.00
0005435340011	5398	Economy	22400.00
0005434654408	5398	Economy	22400.00
0005434654415	5398	Economy	22400.00
0005435339995	5398	Economy	22400.00
0005434654407	5398	Economy	22400.00
0005434654410	5398	Economy	22400.00
0005434654399	5398	Economy	22400.00
0005434654414	5398	Economy	22400.00
0005434654420	5398	Economy	22400.00
0005432114174	5398	Economy	22400.00
0005435340049	5398	Economy	22400.00
0005434654418	5398	Economy	22400.00
0005434654409	5398	Economy	22400.00
0005432114171	5398	Economy	22400.00
0005434654419	5398	Economy	22400.00
0005434654198	12555	Business	67200.00
0005435555351	12555	Business	67200.00
0005434654187	12555	Business	67200.00
0005434654174	12555	Business	67200.00
0005434654186	12555	Business	67200.00
0005435340113	12555	Economy	22400.00
0005434656523	12555	Economy	22400.00
0005435340125	12555	Economy	22400.00
0005435340120	12555	Economy	22400.00
0005435340124	12555	Economy	22400.00
0005435340116	12555	Economy	22400.00
0005434654305	12555	Economy	22400.00
0005435340122	12555	Economy	22400.00
0005435340127	12555	Economy	22400.00
0005435340119	12555	Economy	22400.00
0005435340114	12555	Economy	22400.00
0005434654216	12555	Economy	22400.00
0005435340126	12555	Economy	22400.00
0005435340121	12555	Economy	22400.00
0005435555352	12555	Economy	22400.00
0005435340123	12555	Economy	22400.00
0005434654217	12555	Economy	22400.00
0005434654301	12555	Economy	22400.00
0005435340115	12555	Economy	22400.00
0005434654200	12555	Economy	22400.00
0005435340128	12555	Economy	22400.00
0005435340118	12555	Economy	22400.00
0005434654225	12555	Economy	22400.00
0005435555353	12555	Economy	22400.00
0005435340117	12555	Economy	22400.00
0005433715492	7458	Business	32000.00
0005433715520	7458	Business	32000.00
0005433656637	7458	Business	32000.00
0005433715521	7458	Business	32000.00
0005433715504	7458	Business	32000.00
0005433689889	7458	Business	32000.00
0005433715516	7458	Business	32000.00
0005432428871	7458	Economy	10700.00
0005433715524	7458	Economy	10700.00
0005433715517	7458	Economy	10700.00
0005433715478	7458	Economy	10700.00
0005433715514	7458	Economy	10700.00
0005433715484	7458	Economy	10700.00
0005433722155	7458	Economy	10700.00
0005433715526	7458	Economy	10700.00
0005433715501	7458	Economy	10700.00
0005433656635	7458	Economy	10700.00
0005432078058	7458	Economy	10700.00
0005433715490	7458	Economy	10700.00
0005433719105	7458	Economy	10700.00
0005433688788	7458	Economy	10700.00
0005433715494	7458	Economy	10700.00
0005433690906	7458	Economy	10700.00
0005433715525	7458	Economy	10700.00
0005433715502	7458	Economy	10700.00
0005433688789	7458	Economy	10700.00
0005433715509	7458	Economy	10700.00
0005433715506	7458	Economy	10700.00
0005433715523	7458	Economy	10700.00
0005433715489	7458	Economy	10700.00
0005433715477	7458	Economy	10700.00
0005433715499	7458	Economy	10700.00
0005433715479	7458	Economy	11700.00
0005433688787	7458	Economy	11700.00
0005433715512	7458	Economy	10700.00
0005433715480	7458	Economy	10700.00
0005433715498	7458	Economy	10700.00
0005433715500	7458	Economy	10700.00
0005433715513	7458	Economy	10700.00
0005433715485	7458	Economy	10700.00
0005432078057	7458	Economy	10700.00
0005433715487	7458	Economy	10700.00
0005433656636	7458	Economy	10700.00
0005433715491	7458	Economy	10700.00
0005432078054	7458	Economy	10700.00
0005433719107	7458	Economy	10700.00
0005433715511	7458	Economy	10700.00
0005433715515	7458	Economy	10700.00
0005433715518	7458	Economy	10700.00
0005432078056	7458	Economy	10700.00
0005433715475	7458	Economy	10700.00
0005433715508	7458	Economy	10700.00
0005433689890	7458	Economy	10700.00
0005433715495	7458	Economy	10700.00
0005433715519	7458	Economy	10700.00
0005433715483	7458	Economy	10700.00
0005433715507	7458	Economy	10700.00
0005433715496	7458	Economy	10700.00
0005433690905	7458	Economy	10700.00
0005433722156	7458	Economy	10700.00
0005433715493	7458	Economy	10700.00
0005432078055	7458	Economy	10700.00
0005433715482	7458	Economy	10700.00
0005433715522	7458	Economy	10700.00
0005433715505	7458	Economy	10700.00
0005433715510	7458	Economy	10700.00
0005433715488	7458	Economy	10700.00
0005433715503	7458	Economy	10700.00
0005432428870	7458	Economy	10700.00
0005433715497	7458	Economy	10700.00
0005433715481	7458	Economy	10700.00
0005433715476	7458	Economy	10700.00
0005433719106	7458	Economy	10700.00
0005433722157	7458	Economy	10700.00
0005433715486	7458	Economy	10700.00
0005433715169	29215	Business	32000.00
0005433715094	29215	Business	32000.00
0005432006733	29215	Business	32000.00
0005433656615	29215	Business	32000.00
0005433715087	29215	Business	32000.00
0005433715069	29215	Economy	10700.00
0005433715091	29215	Economy	10700.00
0005433715116	29215	Economy	10700.00
0005433715324	29215	Economy	10700.00
0005433715081	29215	Economy	10700.00
0005433715122	29215	Economy	10700.00
0005432428897	29215	Economy	10700.00
0005433688773	29215	Economy	10700.00
0005435266115	29215	Economy	10700.00
0005433688784	29215	Economy	10700.00
0005433715093	29215	Economy	10700.00
0005435266114	29215	Economy	10700.00
0005433715255	29215	Economy	10700.00
0005432006736	29215	Economy	10700.00
0005433715082	29215	Economy	10700.00
0005432428896	29215	Economy	10700.00
0005433715185	29215	Economy	11700.00
0005433715095	29215	Economy	11700.00
0005433715098	29215	Economy	11700.00
0005433715090	29215	Economy	11700.00
0005433715121	29215	Economy	11700.00
0005433715200	29215	Economy	10700.00
0005433715083	29215	Economy	10700.00
0005433715120	29215	Economy	10700.00
0005435266113	29215	Economy	10700.00
0005432428898	29215	Economy	10700.00
0005435266116	29215	Economy	10700.00
0005432006735	29215	Economy	10700.00
0005433715187	29215	Economy	10700.00
0005435266112	29215	Economy	10700.00
0005433715155	29215	Economy	10700.00
0005433715118	29215	Economy	10700.00
0005435266111	29215	Economy	10700.00
0005433715254	29215	Economy	10700.00
0005432006732	29215	Economy	10700.00
0005433715140	29215	Economy	10700.00
0005433715167	29215	Economy	10700.00
0005432006734	29215	Economy	10700.00
0005432428895	29215	Economy	10700.00
0005433715325	29215	Economy	10700.00
0005433715170	29215	Economy	10700.00
0005433715186	29215	Economy	10700.00
0005433715141	29215	Economy	10700.00
0005433715166	29215	Economy	10700.00
0005435266110	29215	Economy	10700.00
0005434184629	8667	Business	36500.00
0005434182034	8667	Business	36500.00
0005434095142	8667	Business	36500.00
0005434095133	8667	Economy	12200.00
0005434182033	8667	Economy	13400.00
0005434181985	8667	Economy	12200.00
0005434326085	8667	Economy	12200.00
0005434095137	8667	Economy	12200.00
0005434095138	8667	Economy	12200.00
0005434095144	8667	Economy	12200.00
0005434095136	8667	Economy	12200.00
0005434095134	8667	Economy	12200.00
0005434095145	8667	Economy	12200.00
0005434095140	8667	Economy	12200.00
0005434095135	8667	Economy	12200.00
0005434095141	8667	Economy	12200.00
0005434095147	8667	Economy	12200.00
0005434095139	8667	Economy	12200.00
0005434181959	8667	Economy	12200.00
0005434184630	8667	Economy	12200.00
0005434095146	8667	Economy	12200.00
0005434095143	8667	Economy	12200.00
0005434182063	11665	Business	36500.00
0005434182067	11665	Business	36500.00
0005434184644	11665	Business	36500.00
0005434182071	11665	Economy	12200.00
0005434182060	11665	Economy	12200.00
0005434182061	11665	Economy	12200.00
0005434182066	11665	Economy	13400.00
0005434183559	11665	Economy	12200.00
0005434183558	11665	Economy	12200.00
0005434182069	11665	Economy	12200.00
0005434182065	11665	Economy	12200.00
0005434182068	11665	Economy	12200.00
0005434095033	11665	Economy	12200.00
0005434182062	11665	Economy	12200.00
0005434095034	11665	Economy	12200.00
0005434182064	11665	Economy	12200.00
0005434182070	11665	Economy	12200.00
0005434184643	11665	Economy	12200.00
0005433397260	1458	Business	33000.00
0005435732224	1458	Business	33000.00
0005433397226	1458	Business	33000.00
0005433397254	1458	Business	33000.00
0005433397330	1458	Business	33000.00
0005433456930	1458	Business	33000.00
0005435732217	1458	Business	33000.00
0005433397222	1458	Economy	11000.00
0005433397347	1458	Economy	11000.00
0005433397252	1458	Economy	11000.00
0005435732221	1458	Economy	11000.00
0005433456932	1458	Economy	11000.00
0005433397200	1458	Economy	11000.00
0005433397220	1458	Economy	12100.00
0005433397250	1458	Economy	12100.00
0005433397410	1458	Economy	12100.00
0005435732216	1458	Economy	11000.00
0005433397348	1458	Economy	11000.00
0005433397251	1458	Economy	11000.00
0005435732218	1458	Economy	11000.00
0005435732225	1458	Economy	11000.00
0005432297253	1458	Economy	11000.00
0005435732220	1458	Economy	11000.00
0005433397297	1458	Economy	11000.00
0005433397301	1458	Economy	11000.00
0005435732222	1458	Economy	11000.00
0005435732223	1458	Economy	11000.00
0005433397273	1458	Economy	11000.00
0005435732214	1458	Economy	11000.00
0005433397225	1458	Economy	11000.00
0005433397300	1458	Economy	11000.00
0005433397221	1458	Economy	11000.00
0005433456931	1458	Economy	11000.00
0005433397217	1458	Economy	11000.00
0005432297252	1458	Economy	11000.00
0005433397296	1458	Economy	11000.00
0005435732219	1458	Economy	11000.00
0005433397187	1458	Economy	11000.00
0005435732215	1458	Economy	11000.00
0005433397259	1458	Economy	11000.00
0005433397245	1458	Economy	11000.00
0005433397188	1458	Economy	11000.00
0005433397290	1458	Economy	11000.00
0005433397203	1458	Economy	11000.00
0005433397230	1458	Economy	11000.00
0005433397257	1458	Economy	11000.00
0005433456929	1458	Economy	11000.00
0005433397625	19273	Business	33000.00
0005432906514	19273	Business	33000.00
0005433397620	19273	Business	33000.00
0005433397591	19273	Business	33000.00
0005433397600	19273	Business	33000.00
0005435732137	19273	Business	33000.00
0005433397598	19273	Business	33000.00
0005433397614	19273	Business	33000.00
0005433397607	19273	Business	33000.00
0005433397608	19273	Business	33000.00
0005433397621	19273	Economy	11000.00
0005433397616	19273	Economy	11000.00
0005433397609	19273	Economy	11000.00
0005432906513	19273	Economy	11000.00
0005433397579	19273	Economy	11000.00
0005433397618	19273	Economy	11000.00
0005433397589	19273	Economy	12100.00
0005433397626	19273	Economy	12100.00
0005433397597	19273	Economy	12100.00
0005433397578	19273	Economy	11000.00
0005432906511	19273	Economy	11000.00
0005435732160	19273	Economy	11000.00
0005433397599	19273	Economy	11000.00
0005433397593	19273	Economy	11000.00
0005433456899	19273	Economy	11000.00
0005433397624	19273	Economy	11000.00
0005433397588	19273	Economy	11000.00
0005433397606	19273	Economy	11000.00
0005433397580	19273	Economy	11000.00
0005432906515	19273	Economy	11000.00
0005435732138	19273	Economy	11000.00
0005433397612	19273	Economy	11000.00
0005433397604	19273	Economy	11000.00
0005435732130	19273	Economy	11000.00
0005433397594	19273	Economy	11000.00
0005433397581	19273	Economy	11000.00
0005433397583	19273	Economy	11000.00
0005433397617	19273	Economy	11000.00
0005433397601	19273	Economy	11000.00
0005433397592	19273	Economy	11000.00
0005433397577	19273	Economy	11000.00
0005433397611	19273	Economy	11000.00
0005433397582	19273	Economy	11000.00
0005435732159	19273	Economy	11000.00
0005433397595	19273	Economy	11000.00
0005433397623	19273	Economy	11000.00
0005433397605	19273	Economy	11000.00
0005435732131	19273	Economy	11000.00
0005433397584	19273	Economy	11000.00
0005433456904	19273	Economy	11000.00
0005432906512	19273	Economy	11000.00
0005433397585	19273	Economy	11000.00
0005433397596	19273	Economy	11000.00
0005433397603	19273	Economy	11000.00
0005433397613	19273	Economy	11000.00
0005433397587	19273	Economy	11000.00
0005433397622	19273	Economy	11000.00
0005433456900	19273	Economy	11000.00
0005433397610	19273	Economy	11000.00
0005433456903	19273	Economy	11000.00
0005433397586	19273	Economy	11000.00
0005433397615	19273	Economy	11000.00
0005433397619	19273	Economy	11000.00
0005433397590	19273	Economy	11000.00
0005433397602	19273	Economy	11000.00
0005434443433	17387	Economy	15600.00
0005434443434	17387	Economy	14100.00
0005434443463	17387	Economy	14100.00
0005434443512	17387	Economy	14100.00
0005434443511	17387	Economy	14100.00
0005434443453	17387	Economy	14100.00
0005434443470	17387	Economy	14100.00
0005434443469	17387	Economy	14100.00
0005434443467	17387	Economy	14100.00
0005434443428	17387	Economy	14100.00
0005434443552	20570	Economy	15600.00
0005434443542	20570	Economy	15600.00
0005434443546	20570	Economy	14100.00
0005434443539	20570	Economy	14100.00
0005434443553	20570	Economy	14100.00
0005434443550	20570	Economy	14100.00
0005434443554	20570	Economy	14100.00
0005434443548	20570	Economy	14100.00
0005434443555	20570	Economy	14100.00
0005434443545	20570	Economy	14100.00
0005434443544	20570	Economy	14100.00
0005434443543	20570	Economy	14100.00
0005434443551	20570	Economy	14100.00
0005434443540	20570	Economy	14100.00
0005434443541	20570	Economy	14100.00
0005434443549	20570	Economy	14100.00
0005434443547	20570	Economy	14100.00
0005434954571	7231	Economy	5800.00
0005434954573	7231	Economy	5800.00
0005435377542	7231	Economy	5800.00
0005435377541	7231	Economy	5800.00
0005434954572	7231	Economy	5800.00
0005435377560	28322	Economy	5800.00
0005435377558	28322	Economy	5800.00
0005435377557	28322	Economy	5800.00
0005435377559	28322	Economy	5800.00
0005435377556	28322	Economy	5800.00
0005434351568	4483	Economy	15400.00
0005434351569	4483	Economy	15400.00
0005434351573	4483	Economy	15400.00
0005434351570	4483	Economy	14000.00
0005434351577	4483	Economy	14000.00
0005434351571	4483	Economy	14000.00
0005434183549	4483	Economy	14000.00
0005434351572	4483	Economy	14000.00
0005434326265	4483	Economy	14000.00
0005435893521	4483	Economy	14000.00
0005434351580	4483	Economy	14000.00
0005434351574	4483	Economy	14000.00
0005434351579	4483	Economy	14000.00
0005434183548	4483	Economy	14000.00
0005434351575	4483	Economy	14000.00
0005434351576	4483	Economy	14000.00
0005434326264	4483	Economy	14000.00
0005434351581	4483	Economy	14000.00
0005435893504	4483	Economy	14000.00
0005434351578	4483	Economy	14000.00
0005435893565	29665	Economy	15400.00
0005434351464	29665	Economy	14000.00
0005434351472	29665	Economy	14000.00
0005434351470	29665	Economy	14000.00
0005435893562	29665	Economy	14000.00
0005435893563	29665	Economy	14000.00
0005434351474	29665	Economy	14000.00
0005434351471	29665	Economy	14000.00
0005435893561	29665	Economy	14000.00
0005434351466	29665	Economy	14000.00
0005435893567	29665	Economy	14000.00
0005435893568	29665	Economy	14000.00
0005435893564	29665	Economy	14000.00
0005435893566	29665	Economy	14000.00
0005434351476	29665	Economy	14000.00
0005434351512	29665	Economy	14000.00
0005433463879	1083	Business	30600.00
0005433341684	1083	Business	30600.00
0005435091981	1083	Business	30600.00
0005433341443	1083	Business	30600.00
0005435091976	1083	Business	30600.00
0005434445224	1083	Business	30600.00
0005435091978	1083	Economy	11200.00
0005434446500	1083	Economy	11200.00
0005433341575	1083	Economy	10200.00
0005433341533	1083	Economy	10200.00
0005433341421	1083	Economy	10200.00
0005435091979	1083	Economy	10200.00
0005433341777	1083	Economy	10200.00
0005433341433	1083	Economy	10200.00
0005433462725	1083	Economy	10200.00
0005433341941	1083	Economy	10200.00
0005433158099	1083	Economy	10200.00
0005433341453	1083	Economy	10200.00
0005435545654	1083	Economy	10200.00
0005435545652	1083	Economy	10200.00
0005433341423	1083	Economy	10200.00
0005433341411	1083	Economy	10200.00
0005435091977	1083	Economy	10200.00
0005433341782	1083	Economy	10200.00
0005434445225	1083	Economy	10200.00
0005432293185	1083	Economy	10200.00
0005433341452	1083	Economy	10200.00
0005433341696	1083	Economy	10200.00
0005435091983	1083	Economy	10200.00
0005433341653	1083	Economy	10200.00
0005433269636	1083	Economy	10200.00
0005433341434	1083	Economy	10200.00
0005433341596	1083	Economy	10200.00
0005433462726	1083	Economy	10200.00
0005435545650	1083	Economy	10200.00
0005435091974	1083	Economy	10200.00
0005435545651	1083	Economy	10200.00
0005433341422	1083	Economy	10200.00
0005434446498	1083	Economy	11200.00
0005435091982	1083	Economy	10200.00
0005433341636	1083	Economy	10200.00
0005435091975	1083	Economy	10200.00
0005433341942	1083	Economy	10200.00
0005433341576	1083	Economy	10200.00
0005433341440	1083	Economy	10200.00
0005433341637	1083	Economy	10200.00
0005433463880	1083	Economy	10200.00
0005433341395	1083	Economy	10200.00
0005433341430	1083	Economy	10200.00
0005433462727	1083	Economy	10200.00
0005433269629	1083	Economy	10200.00
0005433341407	1083	Economy	10200.00
0005433341648	1083	Economy	10200.00
0005433341473	1083	Economy	10200.00
0005434446499	1083	Economy	10200.00
0005435545653	1083	Economy	10200.00
0005433341697	1083	Economy	10200.00
0005433341441	1083	Economy	10200.00
0005433341764	1083	Economy	10200.00
0005433341404	1083	Economy	10200.00
0005435091980	1083	Economy	10200.00
0005433159274	1083	Economy	10200.00
0005433342148	17038	Business	30600.00
0005433269664	17038	Business	30600.00
0005433342121	17038	Business	30600.00
0005433342122	17038	Business	30600.00
0005435091918	17038	Business	30600.00
0005433342185	17038	Business	30600.00
0005433342096	17038	Business	30600.00
0005433342179	17038	Business	30600.00
0005434445209	17038	Business	30600.00
0005433342109	17038	Business	30600.00
0005433342158	17038	Business	30600.00
0005433342110	17038	Business	30600.00
0005434445208	17038	Business	30600.00
0005433342165	17038	Business	30600.00
0005433342175	17038	Business	30600.00
0005433342172	17038	Business	30600.00
0005433342170	17038	Business	30600.00
0005433342162	17038	Business	30600.00
0005433342119	17038	Economy	11200.00
0005433342180	17038	Economy	11200.00
0005433342104	17038	Economy	11200.00
0005433342143	17038	Economy	10200.00
0005433342138	17038	Economy	10200.00
0005433342191	17038	Economy	10200.00
0005433342126	17038	Economy	10200.00
0005433342135	17038	Economy	10200.00
0005433342189	17038	Economy	10200.00
0005433342171	17038	Economy	10200.00
0005433342098	17038	Economy	10200.00
0005433342131	17038	Economy	10200.00
0005433342153	17038	Economy	10200.00
0005433342140	17038	Economy	10200.00
0005433342103	17038	Economy	10200.00
0005433342090	17038	Economy	10200.00
0005433269665	17038	Economy	10200.00
0005433159290	17038	Economy	10200.00
0005433342101	17038	Economy	10200.00
0005433342176	17038	Economy	10200.00
0005433342151	17038	Economy	10200.00
0005433342190	17038	Economy	10200.00
0005433342129	17038	Economy	10200.00
0005433269668	17038	Economy	10200.00
0005433342188	17038	Economy	10200.00
0005433342141	17038	Economy	10200.00
0005433342169	17038	Economy	10200.00
0005433342167	17038	Economy	10200.00
0005435091938	17038	Economy	10200.00
0005433342095	17038	Economy	10200.00
0005433342116	17038	Economy	10200.00
0005433342137	17038	Economy	10200.00
0005433269666	17038	Economy	10200.00
0005433269669	17038	Economy	10200.00
0005433342106	17038	Economy	10200.00
0005433342092	17038	Economy	10200.00
0005433342139	17038	Economy	10200.00
0005433342144	17038	Economy	10200.00
0005433342159	17038	Economy	10200.00
0005433342117	17038	Economy	10200.00
0005433342183	17038	Economy	10200.00
0005433342156	17038	Economy	10200.00
0005433159291	17038	Economy	10200.00
0005433342147	17038	Economy	10200.00
0005433342134	17038	Economy	10200.00
0005435091898	17038	Economy	10200.00
0005433342164	17038	Economy	10200.00
0005433342160	17038	Economy	10200.00
0005433342186	17038	Economy	10200.00
0005433342146	17038	Economy	10200.00
0005433342094	17038	Economy	10200.00
0005433342132	17038	Economy	10200.00
0005433269670	17038	Economy	11200.00
0005433342114	17038	Economy	10200.00
0005433342149	17038	Economy	10200.00
0005433342111	17038	Economy	11200.00
0005433342168	17038	Economy	10200.00
0005433342124	17038	Economy	10200.00
0005433342112	17038	Economy	10200.00
0005433342089	17038	Economy	10200.00
0005433342115	17038	Economy	10200.00
0005433342181	17038	Economy	10200.00
0005433342187	17038	Economy	10200.00
0005433342128	17038	Economy	10200.00
0005433342142	17038	Economy	10200.00
0005433342093	17038	Economy	10200.00
0005433342157	17038	Economy	10200.00
0005433342105	17038	Economy	10200.00
0005433342174	17038	Economy	10200.00
0005433269667	17038	Economy	10200.00
0005433342177	17038	Economy	10200.00
0005435091899	17038	Economy	10200.00
0005433342118	17038	Economy	10200.00
0005433342125	17038	Economy	10200.00
0005433342133	17038	Economy	10200.00
0005433342097	17038	Economy	10200.00
0005433342123	17038	Economy	10200.00
0005433342150	17038	Economy	10200.00
0005433342154	17038	Economy	10200.00
0005433342182	17038	Economy	10200.00
0005433342155	17038	Economy	10200.00
0005433342166	17038	Economy	10200.00
0005433342113	17038	Economy	10200.00
0005433342152	17038	Economy	10200.00
0005433342108	17038	Economy	10200.00
0005433342163	17038	Economy	10200.00
0005433342100	17038	Economy	10200.00
0005433342178	17038	Economy	10200.00
0005433342127	17038	Economy	10200.00
0005433342161	17038	Economy	10200.00
0005433342107	17038	Economy	10200.00
0005433342184	17038	Economy	10200.00
0005435091921	17038	Economy	10200.00
0005433342091	17038	Economy	10200.00
0005433342120	17038	Economy	10200.00
0005433342130	17038	Economy	10200.00
0005433342099	17038	Economy	10200.00
0005433342145	17038	Economy	10200.00
0005433342173	17038	Economy	10200.00
0005433342102	17038	Economy	10200.00
0005433342136	17038	Economy	10200.00
0005434066495	12809	Business	40300.00
0005434081517	12809	Business	40300.00
0005434066486	12809	Business	40300.00
0005434081545	12809	Business	40300.00
0005434066466	12809	Business	40300.00
0005433812880	12809	Business	40300.00
0005434066496	12809	Business	40300.00
0005432159816	12809	Economy	13400.00
0005432159813	12809	Economy	13400.00
0005434066359	12809	Economy	13400.00
0005433812876	12809	Economy	13400.00
0005434066386	12809	Economy	13400.00
0005432433627	12809	Economy	13400.00
0005434066376	12809	Economy	13400.00
0005434066336	12809	Economy	13400.00
0005434066427	12809	Economy	13400.00
0005434081529	12809	Economy	13400.00
0005434081482	12809	Economy	13400.00
0005433989690	12809	Economy	13400.00
0005434026669	12809	Economy	13400.00
0005432433631	12809	Economy	13400.00
0005434066379	12809	Economy	13400.00
0005432159814	12809	Economy	13400.00
0005432433630	12809	Economy	13400.00
0005434066362	12809	Economy	13400.00
0005434066337	12809	Economy	13400.00
0005433989684	12809	Economy	14800.00
0005432433629	12809	Economy	14800.00
0005432433626	12809	Economy	14800.00
0005434026670	12809	Economy	14800.00
0005434026671	12809	Economy	13400.00
0005433812878	12809	Economy	14800.00
0005434081501	12809	Economy	13400.00
0005434081495	12809	Economy	13400.00
0005432159817	12809	Economy	13400.00
0005434066374	12809	Economy	13400.00
0005434066308	12809	Economy	13400.00
0005434081539	12809	Economy	13400.00
0005432159812	12809	Economy	13400.00
0005434081490	12809	Economy	13400.00
0005434081491	12809	Economy	13400.00
0005433812877	12809	Economy	13400.00
0005434066487	12809	Economy	13400.00
0005434066378	12809	Economy	13400.00
0005434066375	12809	Economy	13400.00
0005434066353	12809	Economy	13400.00
0005434066324	12809	Economy	13400.00
0005434081541	12809	Economy	13400.00
0005434081500	12809	Economy	13400.00
0005434066385	12809	Economy	13400.00
0005434066380	12809	Economy	13400.00
0005434066321	12809	Economy	13400.00
0005432161129	12809	Economy	13400.00
0005434066365	12809	Economy	13400.00
0005433989683	12809	Economy	13400.00
0005432161130	12809	Economy	13400.00
0005432161131	12809	Economy	13400.00
0005432159815	12809	Economy	13400.00
0005434066316	12809	Economy	13400.00
0005432433628	12809	Economy	13400.00
0005433812879	12809	Economy	13400.00
0005434066400	12809	Economy	13400.00
0005434066494	12809	Economy	13400.00
0005434081489	12809	Economy	13400.00
0005434066360	12809	Economy	13400.00
0005434066424	12809	Economy	13400.00
0005433989691	12809	Economy	13400.00
0005434066312	12809	Economy	13400.00
0005434066841	30675	Business	40300.00
0005434081666	30675	Business	40300.00
0005434066839	30675	Business	40300.00
0005434066808	30675	Business	40300.00
0005434066852	30675	Business	40300.00
0005434066806	30675	Business	40300.00
0005434066843	30675	Business	40300.00
0005434066869	30675	Business	40300.00
0005434066848	30675	Business	40300.00
0005434066844	30675	Business	40300.00
0005432433608	30675	Business	40300.00
0005434066826	30675	Economy	13400.00
0005432186833	30675	Economy	13400.00
0005434081654	30675	Economy	13400.00
0005434066827	30675	Economy	13400.00
0005434081671	30675	Economy	13400.00
0005434066809	30675	Economy	13400.00
0005434081664	30675	Economy	13400.00
0005434066854	30675	Economy	13400.00
0005434066849	30675	Economy	13400.00
0005434081669	30675	Economy	13400.00
0005434066828	30675	Economy	13400.00
0005434081665	30675	Economy	13400.00
0005432186831	30675	Economy	13400.00
0005434066847	30675	Economy	13400.00
0005434066816	30675	Economy	13400.00
0005434066857	30675	Economy	13400.00
0005433989721	30675	Economy	13400.00
0005434066864	30675	Economy	13400.00
0005434081670	30675	Economy	13400.00
0005434066810	30675	Economy	13400.00
0005434066811	30675	Economy	13400.00
0005434066868	30675	Economy	13400.00
0005434066862	30675	Economy	13400.00
0005434066820	30675	Economy	13400.00
0005434081661	30675	Economy	13400.00
0005434066815	30675	Economy	13400.00
0005434081653	30675	Economy	13400.00
0005434081656	30675	Economy	13400.00
0005434066867	30675	Economy	13400.00
0005434081667	30675	Economy	13400.00
0005433989723	30675	Economy	13400.00
0005434026686	30675	Economy	13400.00
0005434066873	30675	Economy	13400.00
0005434081673	30675	Economy	13400.00
0005434081663	30675	Economy	13400.00
0005434066865	30675	Economy	13400.00
0005432150115	30675	Economy	13400.00
0005434081672	30675	Economy	13400.00
0005434066874	30675	Economy	14800.00
0005432150112	30675	Economy	14800.00
0005434026684	30675	Economy	14800.00
0005434066871	30675	Economy	14800.00
0005434066846	30675	Economy	13400.00
0005434066872	30675	Economy	13400.00
0005432150111	30675	Economy	13400.00
0005434081668	30675	Economy	13400.00
0005434066823	30675	Economy	13400.00
0005434066850	30675	Economy	13400.00
0005434066861	30675	Economy	13400.00
0005434081657	30675	Economy	13400.00
0005434066822	30675	Economy	13400.00
0005434066866	30675	Economy	13400.00
0005432150116	30675	Economy	13400.00
0005434066824	30675	Economy	13400.00
0005432186832	30675	Economy	13400.00
0005434066819	30675	Economy	13400.00
0005434066825	30675	Economy	13400.00
0005434066818	30675	Economy	13400.00
0005434081662	30675	Economy	13400.00
0005434026685	30675	Economy	13400.00
0005434066840	30675	Economy	13400.00
0005434066829	30675	Economy	13400.00
0005434026681	30675	Economy	13400.00
0005434066863	30675	Economy	13400.00
0005434066842	30675	Economy	13400.00
0005434066821	30675	Economy	13400.00
0005434026682	30675	Economy	13400.00
0005434066836	30675	Economy	13400.00
0005433989720	30675	Economy	13400.00
0005434066832	30675	Economy	13400.00
0005434066858	30675	Economy	13400.00
0005434066804	30675	Economy	13400.00
0005434066807	30675	Economy	13400.00
0005434066813	30675	Economy	13400.00
0005434066855	30675	Economy	13400.00
0005433989724	30675	Economy	13400.00
0005434066845	30675	Economy	13400.00
0005434081660	30675	Economy	13400.00
0005434066875	30675	Economy	13400.00
0005434081659	30675	Economy	13400.00
0005432150110	30675	Economy	13400.00
0005434066837	30675	Economy	13400.00
0005434026683	30675	Economy	13400.00
0005434066833	30675	Economy	13400.00
0005434081655	30675	Economy	13400.00
0005434066856	30675	Economy	13400.00
0005432150117	30675	Economy	13400.00
0005434066870	30675	Economy	13400.00
0005434066859	30675	Economy	13400.00
0005434066805	30675	Economy	13400.00
0005434066838	30675	Economy	13400.00
0005434066814	30675	Economy	13400.00
0005434066817	30675	Economy	13400.00
0005433989722	30675	Economy	13400.00
0005433812861	30675	Economy	13400.00
0005434066812	30675	Economy	13400.00
0005434066830	30675	Economy	13400.00
0005434066853	30675	Economy	13400.00
0005434081658	30675	Economy	13400.00
0005434066835	30675	Economy	13400.00
0005434066860	30675	Economy	13400.00
0005432150113	30675	Economy	13400.00
0005432433597	30675	Economy	13400.00
0005434066851	30675	Economy	13400.00
0005434066834	30675	Economy	13400.00
0005434066831	30675	Economy	13400.00
0005432150114	30675	Economy	13400.00
0005435765649	5542	Business	35300.00
0005435765647	5542	Business	35300.00
0005434264724	5542	Business	35300.00
0005435765618	5542	Business	35300.00
0005435461793	5542	Business	35300.00
0005435765620	5542	Business	35300.00
0005435765638	5542	Business	35300.00
0005435765659	5542	Business	35300.00
0005435765637	5542	Business	35300.00
0005432140366	5542	Business	35300.00
0005435725547	5542	Business	35300.00
0005435725551	5542	Business	35300.00
0005435765612	5542	Business	35300.00
0005435765639	5542	Business	35300.00
0005435765645	5542	Business	35300.00
0005434264733	5542	Business	35300.00
0005435461865	5542	Business	35300.00
0005432140368	5542	Business	35300.00
0005435765624	5542	Business	35300.00
0005433529243	5542	Business	35300.00
0005435765643	5542	Business	35300.00
0005435765615	5542	Economy	12900.00
0005435461770	5542	Economy	11800.00
0005434264715	5542	Economy	11800.00
0005435765635	5542	Economy	11800.00
0005435765632	5542	Economy	11800.00
0005435461794	5542	Economy	11800.00
0005435765644	5542	Economy	11800.00
0005435765628	5542	Economy	11800.00
0005435725549	5542	Economy	11800.00
0005435735095	5542	Economy	11800.00
0005435735093	5542	Economy	11800.00
0005435765657	5542	Economy	11800.00
0005435765633	5542	Economy	11800.00
0005435722031	5542	Economy	11800.00
0005435765667	5542	Economy	11800.00
0005432535748	5542	Economy	11800.00
0005435461821	5542	Economy	11800.00
0005435461809	5542	Economy	11800.00
0005435765663	5542	Economy	11800.00
0005435765646	5542	Economy	11800.00
0005435765668	5542	Economy	11800.00
0005435765621	5542	Economy	11800.00
0005435461811	5542	Economy	11800.00
0005435765651	5542	Economy	11800.00
0005435765642	5542	Economy	11800.00
0005435765660	5542	Economy	11800.00
0005435765656	5542	Economy	11800.00
0005435765669	5542	Economy	11800.00
0005434264679	5542	Economy	11800.00
0005435765617	5542	Economy	11800.00
0005435765609	5542	Economy	11800.00
0005435765622	5542	Economy	11800.00
0005435461800	5542	Economy	11800.00
0005435765672	5542	Economy	11800.00
0005435765670	5542	Economy	11800.00
0005435461810	5542	Economy	11800.00
0005435765655	5542	Economy	11800.00
0005434264694	5542	Economy	11800.00
0005433529242	5542	Economy	11800.00
0005433527231	5542	Economy	11800.00
0005434264693	5542	Economy	11800.00
0005435461790	5542	Economy	11800.00
0005435735091	5542	Economy	11800.00
0005435723026	5542	Economy	11800.00
0005433527233	5542	Economy	11800.00
0005435765634	5542	Economy	11800.00
0005432140369	5542	Economy	11800.00
0005435765631	5542	Economy	11800.00
0005435461791	5542	Economy	11800.00
0005435461863	5542	Economy	11800.00
0005435765653	5542	Economy	11800.00
0005434264723	5542	Economy	11800.00
0005435765650	5542	Economy	11800.00
0005432140372	5542	Economy	11800.00
0005432140367	5542	Economy	11800.00
0005434264678	5542	Economy	11800.00
0005434264753	5542	Economy	11800.00
0005435765648	5542	Economy	11800.00
0005435765623	5542	Economy	11800.00
0005434264768	5542	Economy	11800.00
0005435765666	5542	Economy	11800.00
0005434264767	5542	Economy	11800.00
0005435461799	5542	Economy	12900.00
0005435461771	5542	Economy	12900.00
0005435765662	5542	Economy	11800.00
0005435735094	5542	Economy	12900.00
0005435461787	5542	Economy	11800.00
0005435765652	5542	Economy	11800.00
0005435765654	5542	Economy	11800.00
0005435725548	5542	Economy	11800.00
0005435723025	5542	Economy	11800.00
0005435765610	5542	Economy	11800.00
0005435735090	5542	Economy	11800.00
0005435765658	5542	Economy	11800.00
0005432140370	5542	Economy	11800.00
0005435765671	5542	Economy	11800.00
0005433529244	5542	Economy	11800.00
0005432140373	5542	Economy	11800.00
0005435765641	5542	Economy	11800.00
0005434264686	5542	Economy	11800.00
0005435765611	5542	Economy	11800.00
0005435765661	5542	Economy	11800.00
0005433527232	5542	Economy	11800.00
0005432140371	5542	Economy	11800.00
0005435765629	5542	Economy	11800.00
0005434264713	5542	Economy	11800.00
0005435765630	5542	Economy	11800.00
0005434831069	5542	Economy	11800.00
0005435461798	5542	Economy	11800.00
0005434264720	5542	Economy	11800.00
0005435765627	5542	Economy	11800.00
0005435765614	5542	Economy	11800.00
0005435765626	5542	Economy	11800.00
0005435765636	5542	Economy	11800.00
0005435765664	5542	Economy	11800.00
0005435722033	5542	Economy	11800.00
0005435461781	5542	Economy	11800.00
0005435461888	5542	Economy	11800.00
0005435765665	5542	Economy	11800.00
0005435461788	5542	Economy	11800.00
0005435765625	5542	Economy	11800.00
0005435461782	5542	Economy	11800.00
0005432535747	5542	Economy	11800.00
0005435725550	5542	Economy	11800.00
0005435765619	5542	Economy	11800.00
0005435765616	5542	Economy	11800.00
0005435765640	5542	Economy	11800.00
0005435725552	5542	Economy	11800.00
0005435735092	5542	Economy	11800.00
0005435765613	5542	Economy	11800.00
0005435722032	5542	Economy	11800.00
0005435462080	13450	Business	35300.00
0005434264912	13450	Business	35300.00
0005434264908	13450	Business	35300.00
0005435462103	13450	Business	35300.00
0005435462092	13450	Business	35300.00
0005435462081	13450	Business	35300.00
0005435462066	13450	Business	35300.00
0005435462067	13450	Business	35300.00
0005435765142	13450	Business	35300.00
0005435462101	13450	Business	35300.00
0005435462073	13450	Business	35300.00
0005435462083	13450	Business	35300.00
0005434264895	13450	Business	35300.00
0005434264906	13450	Business	35300.00
0005434831106	13450	Business	35300.00
0005434264889	13450	Economy	12900.00
0005435765148	13450	Economy	11800.00
0005434264911	13450	Economy	11800.00
0005435462072	13450	Economy	11800.00
0005434831107	13450	Economy	11800.00
0005435462084	13450	Economy	11800.00
0005434264909	13450	Economy	11800.00
0005435735056	13450	Economy	11800.00
0005434264905	13450	Economy	11800.00
0005434264893	13450	Economy	11800.00
0005435462069	13450	Economy	11800.00
0005432194473	13450	Economy	11800.00
0005435765145	13450	Economy	11800.00
0005434264900	13450	Economy	11800.00
0005434264903	13450	Economy	11800.00
0005435462075	13450	Economy	11800.00
0005435462096	13450	Economy	11800.00
0005435462071	13450	Economy	11800.00
0005434264898	13450	Economy	11800.00
0005435735057	13450	Economy	11800.00
0005435462100	13450	Economy	11800.00
0005435725528	13450	Economy	11800.00
0005435043276	13450	Economy	11800.00
0005435462097	13450	Economy	11800.00
0005434264901	13450	Economy	11800.00
0005435765146	13450	Economy	11800.00
0005435462077	13450	Economy	11800.00
0005434264892	13450	Economy	11800.00
0005432535789	13450	Economy	11800.00
0005435462094	13450	Economy	11800.00
0005435723012	13450	Economy	11800.00
0005434264894	13450	Economy	11800.00
0005432194470	13450	Economy	11800.00
0005434264902	13450	Economy	11800.00
0005434831109	13450	Economy	11800.00
0005435725520	13450	Economy	11800.00
0005434264891	13450	Economy	11800.00
0005435765143	13450	Economy	11800.00
0005434264899	13450	Economy	11800.00
0005435462091	13450	Economy	11800.00
0005435462086	13450	Economy	11800.00
0005435723009	13450	Economy	11800.00
0005435462074	13450	Economy	11800.00
0005432535790	13450	Economy	11800.00
0005435725511	13450	Economy	11800.00
0005435462078	13450	Economy	11800.00
0005432535788	13450	Economy	12900.00
0005434264896	13450	Economy	12900.00
0005435462082	13450	Economy	11800.00
0005435462079	13450	Economy	11800.00
0005432535787	13450	Economy	11800.00
0005435765108	13450	Economy	11800.00
0005432194471	13450	Economy	11800.00
0005435462095	13450	Economy	11800.00
0005434264913	13450	Economy	11800.00
0005433529210	13450	Economy	11800.00
0005435765117	13450	Economy	11800.00
0005434264904	13450	Economy	11800.00
0005434831108	13450	Economy	11800.00
0005435462093	13450	Economy	11800.00
0005435462099	13450	Economy	11800.00
0005435765116	13450	Economy	11800.00
0005435462098	13450	Economy	11800.00
0005435462070	13450	Economy	11800.00
0005435765126	13450	Economy	11800.00
0005435765115	13450	Economy	11800.00
0005435462102	13450	Economy	11800.00
0005434264890	13450	Economy	11800.00
0005434264888	13450	Economy	11800.00
0005435462089	13450	Economy	11800.00
0005434264887	13450	Economy	11800.00
0005435462076	13450	Economy	11800.00
0005434264910	13450	Economy	11800.00
0005435462087	13450	Economy	11800.00
0005435462088	13450	Economy	11800.00
0005435462085	13450	Economy	11800.00
0005434264897	13450	Economy	11800.00
0005435462090	13450	Economy	11800.00
0005432194472	13450	Economy	11800.00
0005435765111	13450	Economy	11800.00
0005435462068	13450	Economy	11800.00
0005432535786	13450	Economy	11800.00
0005435735065	13450	Economy	11800.00
0005434264907	13450	Economy	11800.00
0005434602865	18712	Economy	3300.00
0005434513553	18707	Economy	3300.00
0005434604840	18707	Economy	3300.00
0005434513552	18707	Economy	3300.00
0005434514940	18707	Economy	3300.00
0005434604839	18707	Economy	3300.00
0005434514941	18707	Economy	3300.00
0005434513551	18707	Economy	3300.00
0005434604838	18707	Economy	3300.00
0005434514921	19131	Economy	3300.00
0005432649347	4130	Business	88300.00
0005432632673	4130	Business	88300.00
0005432649344	4130	Business	88300.00
0005432632674	4130	Business	88300.00
0005432649342	4130	Business	88300.00
0005432649340	4130	Economy	32400.00
0005432649350	4130	Economy	32400.00
0005432632675	4130	Economy	32400.00
0005432632678	4130	Economy	29400.00
0005432649345	4130	Economy	29400.00
0005432632680	4130	Economy	29400.00
0005432632672	4130	Economy	29400.00
0005432632681	4130	Economy	29400.00
0005432632671	4130	Economy	29400.00
0005432632682	4130	Economy	29400.00
0005432649349	4130	Economy	29400.00
0005432632683	4130	Economy	29400.00
0005432632676	4130	Economy	29400.00
0005432649343	4130	Economy	29400.00
0005432632670	4130	Economy	29400.00
0005432649346	4130	Economy	29400.00
0005432649341	4130	Economy	29400.00
0005432632679	4130	Economy	29400.00
0005432649351	4130	Economy	29400.00
0005432632677	4130	Economy	29400.00
0005432649339	4130	Economy	29400.00
0005432649348	4130	Economy	29400.00
0005433007895	1821	Business	48700.00
0005433007900	1821	Business	48700.00
0005433284775	1821	Business	48700.00
0005433284816	1821	Business	48700.00
0005433007912	1821	Business	48700.00
0005433007829	1821	Economy	16200.00
0005433007849	1821	Economy	16200.00
0005433007839	1821	Economy	16200.00
0005433008035	1821	Economy	16200.00
0005433007832	1821	Economy	16200.00
0005433284856	1821	Economy	16200.00
0005433007887	1821	Economy	17900.00
0005433007836	1821	Economy	17900.00
0005433284774	1821	Economy	17900.00
0005433007936	1821	Economy	17900.00
0005433007886	1821	Economy	17900.00
0005433007989	1821	Economy	16200.00
0005433007889	1821	Economy	16200.00
0005433008036	1821	Economy	16200.00
0005432295856	1821	Economy	16200.00
0005433284817	1821	Economy	16200.00
0005433007976	1821	Economy	16200.00
0005433007991	1821	Economy	16200.00
0005433284865	1821	Economy	16200.00
0005433284859	1821	Economy	16200.00
0005433008071	1821	Economy	16200.00
0005433284808	1821	Economy	16200.00
0005433284829	1821	Economy	16200.00
0005433007914	1821	Economy	16200.00
0005433007882	1821	Economy	16200.00
0005433007892	1821	Economy	16200.00
0005433007935	1821	Economy	16200.00
0005433810510	1821	Economy	16200.00
0005433284792	1821	Economy	16200.00
0005433007881	1821	Economy	16200.00
0005433284878	1821	Economy	16200.00
0005433810511	1821	Economy	16200.00
0005433810513	1821	Economy	16200.00
0005433810514	1821	Economy	16200.00
0005433007859	1821	Economy	16200.00
0005433008037	1821	Economy	16200.00
0005433007901	1821	Economy	16200.00
0005433284788	1821	Economy	16200.00
0005433007861	1821	Economy	16200.00
0005433284877	1821	Economy	16200.00
0005433284807	1821	Economy	16200.00
0005433007828	1821	Economy	16200.00
0005433284785	1821	Economy	16200.00
0005433007990	1821	Economy	16200.00
0005433284948	1821	Economy	16200.00
0005432295855	1821	Economy	16200.00
0005433007870	1821	Economy	16200.00
0005433007977	1821	Economy	16200.00
0005433007869	1821	Economy	16200.00
0005433810512	1821	Economy	16200.00
0005433007988	1821	Economy	16200.00
0005433284855	1821	Economy	16200.00
0005433008072	1821	Economy	16200.00
0005433284984	22618	Business	48700.00
0005433008176	22618	Business	48700.00
0005433284997	22618	Business	48700.00
0005433285001	22618	Business	48700.00
0005433008163	22618	Business	48700.00
0005433284983	22618	Business	48700.00
0005433008171	22618	Business	48700.00
0005433008175	22618	Business	48700.00
0005433284977	22618	Business	48700.00
0005433008161	22618	Business	48700.00
0005433284996	22618	Business	48700.00
0005433008154	22618	Economy	16200.00
0005433008184	22618	Economy	16200.00
0005433008180	22618	Economy	16200.00
0005433008192	22618	Economy	16200.00
0005433008167	22618	Economy	16200.00
0005433008182	22618	Economy	16200.00
0005433284985	22618	Economy	16200.00
0005433008160	22618	Economy	17900.00
0005433008187	22618	Economy	17900.00
0005433284994	22618	Economy	17900.00
0005433285002	22618	Economy	16200.00
0005433284978	22618	Economy	16200.00
0005433008178	22618	Economy	16200.00
0005433008166	22618	Economy	16200.00
0005433008189	22618	Economy	16200.00
0005433008177	22618	Economy	16200.00
0005433008148	22618	Economy	16200.00
0005433008153	22618	Economy	16200.00
0005433008162	22618	Economy	16200.00
0005433008170	22618	Economy	16200.00
0005433008185	22618	Economy	16200.00
0005433284979	22618	Economy	16200.00
0005433008158	22618	Economy	16200.00
0005433008169	22618	Economy	16200.00
0005433008173	22618	Economy	16200.00
0005433284982	22618	Economy	16200.00
0005433008149	22618	Economy	16200.00
0005433008157	22618	Economy	16200.00
0005433008155	22618	Economy	16200.00
0005433008151	22618	Economy	16200.00
0005433285005	22618	Economy	16200.00
0005433285004	22618	Economy	16200.00
0005433284987	22618	Economy	16200.00
0005433284995	22618	Economy	16200.00
0005433008193	22618	Economy	16200.00
0005433284989	22618	Economy	16200.00
0005433008168	22618	Economy	16200.00
0005433008147	22618	Economy	16200.00
0005433285006	22618	Economy	16200.00
0005433284980	22618	Economy	16200.00
0005433008186	22618	Economy	16200.00
0005433008152	22618	Economy	16200.00
0005433284975	22618	Economy	16200.00
0005433008159	22618	Economy	16200.00
0005433008156	22618	Economy	16200.00
0005433284999	22618	Economy	16200.00
0005433008190	22618	Economy	16200.00
0005433008174	22618	Economy	16200.00
0005433008179	22618	Economy	16200.00
0005433285003	22618	Economy	16200.00
0005433284993	22618	Economy	16200.00
0005433284976	22618	Economy	16200.00
0005433008150	22618	Economy	16200.00
0005433284991	22618	Economy	16200.00
0005433284992	22618	Economy	16200.00
0005433284986	22618	Economy	16200.00
0005433008191	22618	Economy	16200.00
0005433284998	22618	Economy	16200.00
0005433284981	22618	Economy	16200.00
0005433008183	22618	Economy	16200.00
0005433008188	22618	Economy	16200.00
0005433008172	22618	Economy	16200.00
0005433008165	22618	Economy	16200.00
0005433284988	22618	Economy	16200.00
0005433008164	22618	Economy	16200.00
0005433285000	22618	Economy	16200.00
0005433008181	22618	Economy	16200.00
0005433284990	22618	Economy	16200.00
0005433815336	5548	Business	99800.00
0005435282080	5548	Business	99800.00
0005433846190	5548	Business	99800.00
0005433846179	5548	Business	99800.00
0005435282081	5548	Business	99800.00
0005433846195	5548	Business	99800.00
0005433846166	5548	Business	99800.00
0005435282093	5548	Business	99800.00
0005433846185	5548	Business	99800.00
0005433846143	5548	Business	99800.00
0005433815338	5548	Business	99800.00
0005433846162	5548	Business	99800.00
0005433846170	5548	Economy	33300.00
0005433846183	5548	Economy	33300.00
0005433846193	5548	Economy	33300.00
0005433815339	5548	Economy	33300.00
0005433846181	5548	Economy	33300.00
0005433846172	5548	Economy	33300.00
0005433846163	5548	Economy	33300.00
0005433846160	5548	Economy	33300.00
0005433846189	5548	Economy	33300.00
0005432081447	5548	Economy	33300.00
0005433846157	5548	Economy	33300.00
0005433846178	5548	Economy	36600.00
0005433846152	5548	Economy	36600.00
0005433846151	5548	Economy	36600.00
0005433846196	5548	Economy	33300.00
0005433846180	5548	Economy	33300.00
0005432081446	5548	Economy	33300.00
0005433846168	5548	Economy	33300.00
0005433846161	5548	Economy	33300.00
0005435282052	5548	Economy	33300.00
0005433846198	5548	Economy	33300.00
0005433846173	5548	Economy	33300.00
0005433846142	5548	Economy	33300.00
0005433846164	5548	Economy	33300.00
0005432081449	5548	Economy	33300.00
0005434173450	5548	Economy	33300.00
0005433846188	5548	Economy	33300.00
0005433846197	5548	Economy	33300.00
0005435282058	5548	Economy	33300.00
0005435282197	5548	Economy	33300.00
0005435282050	5548	Economy	33300.00
0005433846187	5548	Economy	33300.00
0005433846177	5548	Economy	33300.00
0005435282196	5548	Economy	33300.00
0005433846146	5548	Economy	33300.00
0005433846191	5548	Economy	33300.00
0005433846192	5548	Economy	33300.00
0005432081451	5548	Economy	33300.00
0005435282064	5548	Economy	33300.00
0005433846169	5548	Economy	33300.00
0005433846182	5548	Economy	33300.00
0005433846174	5548	Economy	33300.00
0005433846167	5548	Economy	33300.00
0005432081452	5548	Economy	33300.00
0005433846147	5548	Economy	33300.00
0005433846148	5548	Economy	33300.00
0005433815337	5548	Economy	33300.00
0005434173456	5548	Economy	33300.00
0005433846186	5548	Economy	33300.00
0005433846154	5548	Economy	33300.00
0005433846145	5548	Economy	33300.00
0005433846175	5548	Economy	33300.00
0005433846150	5548	Economy	33300.00
0005433846199	5548	Economy	33300.00
0005433846149	5548	Economy	33300.00
0005433846141	5548	Economy	33300.00
0005433846155	5548	Economy	33300.00
0005433846144	5548	Economy	33300.00
0005433846194	5548	Economy	33300.00
0005435282057	5548	Economy	33300.00
0005435282124	5548	Economy	33300.00
0005433846159	5548	Economy	33300.00
0005433846200	5548	Economy	33300.00
0005433846184	5548	Economy	33300.00
0005433846156	5548	Economy	33300.00
0005433846158	5548	Economy	33300.00
0005433846165	5548	Economy	33300.00
0005434173453	5548	Economy	33300.00
0005434173452	5548	Economy	33300.00
0005435282115	5548	Economy	33300.00
0005433846153	5548	Economy	33300.00
0005432081448	5548	Economy	33300.00
0005432081450	5548	Economy	33300.00
0005433846171	5548	Economy	33300.00
0005433846176	5548	Economy	33300.00
0005433845675	13867	Business	99800.00
0005435282261	13867	Business	99800.00
0005433845760	13867	Business	99800.00
0005435282273	13867	Business	99800.00
0005432003673	13867	Economy	33300.00
0005435282272	13867	Economy	33300.00
0005435282263	13867	Economy	33300.00
0005435282267	13867	Economy	33300.00
0005435282282	13867	Economy	33300.00
0005435282275	13867	Economy	36600.00
0005435282271	13867	Economy	33300.00
0005435282280	13867	Economy	33300.00
0005435282283	13867	Economy	33300.00
0005435282274	13867	Economy	33300.00
0005434173484	13867	Economy	33300.00
0005435282276	13867	Economy	33300.00
0005435282278	13867	Economy	33300.00
0005433845834	13867	Economy	33300.00
0005435282284	13867	Economy	33300.00
0005433845833	13867	Economy	33300.00
0005433845768	13867	Economy	33300.00
0005433845826	13867	Economy	33300.00
0005435282270	13867	Economy	33300.00
0005434173483	13867	Economy	33300.00
0005433845686	13867	Economy	33300.00
0005433845825	13867	Economy	33300.00
0005432003672	13867	Economy	33300.00
0005433845835	13867	Economy	33300.00
0005435282268	13867	Economy	33300.00
0005435282279	13867	Economy	33300.00
0005435282262	13867	Economy	33300.00
0005435282269	13867	Economy	33300.00
0005434173481	13867	Economy	33300.00
0005433845895	13867	Economy	33300.00
0005435282265	13867	Economy	33300.00
0005433845821	13867	Economy	33300.00
0005433845896	13867	Economy	33300.00
0005435282277	13867	Economy	33300.00
0005434173482	13867	Economy	33300.00
0005435282281	13867	Economy	33300.00
0005435282266	13867	Economy	33300.00
0005433845709	13867	Economy	33300.00
0005433845897	13867	Economy	33300.00
0005433845755	13867	Economy	33300.00
0005432003671	13867	Economy	33300.00
0005433845855	13867	Economy	33300.00
0005433845759	13867	Economy	33300.00
0005433815303	13867	Economy	33300.00
0005435282264	13867	Economy	33300.00
0005434620392	7798	Economy	16600.00
0005432112493	7798	Economy	16600.00
0005434620399	7798	Economy	16600.00
0005434620405	7798	Economy	15100.00
0005434620410	7798	Economy	15100.00
0005434620398	7798	Economy	15100.00
0005435332180	7798	Economy	15100.00
0005435332146	7798	Economy	15100.00
0005434620390	7798	Economy	15100.00
0005435332179	7798	Economy	15100.00
0005434620394	7798	Economy	15100.00
0005435332166	7798	Economy	15100.00
0005435332156	7798	Economy	15100.00
0005434620401	7798	Economy	15100.00
0005435332167	7798	Economy	15100.00
0005432112495	7798	Economy	15100.00
0005434620391	7798	Economy	15100.00
0005434620409	7798	Economy	15100.00
0005434620400	7798	Economy	15100.00
0005434620408	7798	Economy	15100.00
0005434620393	7798	Economy	15100.00
0005435332153	7798	Economy	15100.00
0005435332157	7798	Economy	15100.00
0005435332155	7798	Economy	15100.00
0005434620402	7798	Economy	15100.00
0005432112494	7798	Economy	15100.00
0005434620407	7798	Economy	15100.00
0005434620396	7798	Economy	15100.00
0005434620397	7798	Economy	15100.00
0005435332158	7798	Economy	15100.00
0005434620404	7798	Economy	15100.00
0005434620395	7798	Economy	15100.00
0005434620406	7798	Economy	15100.00
0005434620403	7798	Economy	15100.00
0005434620234	32977	Economy	16600.00
0005434620280	32977	Economy	15100.00
0005434620252	32977	Economy	15100.00
0005434620281	32977	Economy	15100.00
0005435332239	32977	Economy	15100.00
0005434620253	32977	Economy	15100.00
0005434620268	32977	Economy	15100.00
0005434620321	32977	Economy	15100.00
0005434620227	32977	Economy	15100.00
0005434620273	32977	Economy	15100.00
0005434620269	32977	Economy	15100.00
0005435332234	32977	Economy	15100.00
0005435332237	32977	Economy	15100.00
0005434620267	32977	Economy	15100.00
0005434620266	32977	Economy	15100.00
0005434620251	32977	Economy	15100.00
0005435332241	32977	Economy	15100.00
0005435332235	32977	Economy	15100.00
0005435332231	32977	Economy	15100.00
0005435332232	32977	Economy	15100.00
0005435332236	32977	Economy	15100.00
0005435332240	32977	Economy	15100.00
0005435332233	32977	Economy	15100.00
0005434620320	32977	Economy	15100.00
0005434620228	32977	Economy	15100.00
0005435332238	32977	Economy	15100.00
0005432190595	4290	Business	38000.00
0005434993930	4290	Business	38000.00
0005435785044	4290	Business	38000.00
0005434993927	4290	Business	38000.00
0005435785015	4290	Business	38000.00
0005434993928	4290	Business	38000.00
0005435785032	4290	Economy	12700.00
0005435785028	4290	Economy	12700.00
0005435918571	4290	Economy	12700.00
0005435785017	4290	Economy	12700.00
0005435785011	4290	Economy	12700.00
0005432190591	4290	Economy	12700.00
0005435785018	4290	Economy	12700.00
0005435785016	4290	Economy	13900.00
0005432190592	4290	Economy	13900.00
0005435785043	4290	Economy	13900.00
0005435785045	4290	Economy	13900.00
0005435787332	4290	Economy	12700.00
0005435785039	4290	Economy	12700.00
0005435785035	4290	Economy	12700.00
0005435785038	4290	Economy	12700.00
0005435785030	4290	Economy	12700.00
0005435785034	4290	Economy	12700.00
0005435785013	4290	Economy	12700.00
0005435785020	4290	Economy	12700.00
0005435937305	4290	Economy	12700.00
0005435785042	4290	Economy	12700.00
0005435785029	4290	Economy	12700.00
0005434993933	4290	Economy	12700.00
0005432190594	4290	Economy	12700.00
0005434993932	4290	Economy	12700.00
0005435918579	4290	Economy	12700.00
0005435785037	4290	Economy	12700.00
0005435918586	4290	Economy	12700.00
0005435785022	4290	Economy	12700.00
0005434993925	4290	Economy	12700.00
0005434993934	4290	Economy	12700.00
0005435785041	4290	Economy	12700.00
0005434993929	4290	Economy	12700.00
0005435785026	4290	Economy	12700.00
0005435787333	4290	Economy	12700.00
0005435785019	4290	Economy	12700.00
0005435785021	4290	Economy	12700.00
0005432190593	4290	Economy	12700.00
0005435785036	4290	Economy	12700.00
0005435785023	4290	Economy	12700.00
0005435785040	4290	Economy	12700.00
0005435918583	4290	Economy	12700.00
0005435918593	4290	Economy	12700.00
0005435785025	4290	Economy	12700.00
0005435785031	4290	Economy	12700.00
0005435918572	4290	Economy	12700.00
0005435937306	4290	Economy	12700.00
0005434993926	4290	Economy	12700.00
0005435785014	4290	Economy	12700.00
0005435785012	4290	Economy	12700.00
0005435785027	4290	Economy	12700.00
0005435785024	4290	Economy	12700.00
0005435918582	4290	Economy	12700.00
0005435785033	4290	Economy	12700.00
0005434993931	4290	Economy	12700.00
0005435918585	4290	Economy	12700.00
0005434993861	27296	Business	38000.00
0005435784734	27296	Economy	12700.00
0005435918609	27296	Economy	12700.00
0005435784782	27296	Economy	12700.00
0005435918607	27296	Economy	12700.00
0005434993886	27296	Economy	12700.00
0005435784740	27296	Economy	12700.00
0005434993878	27296	Economy	12700.00
0005434993877	27296	Economy	12700.00
0005432195671	27296	Economy	12700.00
0005434993879	27296	Economy	12700.00
0005435918610	27296	Economy	12700.00
0005435784743	27296	Economy	12700.00
0005435918611	27296	Economy	12700.00
0005435784728	27296	Economy	12700.00
0005432195672	27296	Economy	12700.00
0005434993885	27296	Economy	12700.00
0005435784811	27296	Economy	12700.00
0005435784733	27296	Economy	12700.00
0005435918608	27296	Economy	12700.00
0005435784727	27296	Economy	12700.00
0005434993884	27296	Economy	12700.00
0005432146179	19859	Economy	12800.00
0005432146178	19859	Economy	12800.00
0005432567078	4710	Business	40900.00
0005432567051	4710	Business	40900.00
0005432567058	4710	Business	40900.00
0005432459336	4710	Business	40900.00
0005432459332	4710	Business	40900.00
0005432567081	4710	Business	40900.00
0005432459339	4710	Business	40900.00
0005432571285	4710	Business	40900.00
0005432567027	4710	Business	40900.00
0005432459381	4710	Business	40900.00
0005432567031	4710	Business	40900.00
0005434081679	4710	Business	40900.00
0005432567079	4710	Business	40900.00
0005432459343	4710	Business	40900.00
0005433452719	4710	Business	40900.00
0005432567062	4710	Business	40900.00
0005432459340	4710	Business	40900.00
0005432567064	4710	Business	40900.00
0005432567035	4710	Business	40900.00
0005434081691	4710	Business	40900.00
0005432459351	4710	Business	40900.00
0005432567036	4710	Business	40900.00
0005432567033	4710	Economy	15000.00
0005432170325	4710	Economy	15000.00
0005432567056	4710	Economy	15000.00
0005432170326	4710	Economy	15000.00
0005432567059	4710	Economy	13600.00
0005432459352	4710	Economy	13600.00
0005432459341	4710	Economy	13600.00
0005433726082	4710	Economy	13600.00
0005432567040	4710	Economy	13600.00
0005432459374	4710	Economy	13600.00
0005432459364	4710	Economy	13600.00
0005432459360	4710	Economy	13600.00
0005432459330	4710	Economy	13600.00
0005432567034	4710	Economy	13600.00
0005432567071	4710	Economy	13600.00
0005434081689	4710	Economy	13600.00
0005432459346	4710	Economy	13600.00
0005432571284	4710	Economy	13600.00
0005434081680	4710	Economy	13600.00
0005432567063	4710	Economy	13600.00
0005434081687	4710	Economy	13600.00
0005433726083	4710	Economy	13600.00
0005432567046	4710	Economy	13600.00
0005432459334	4710	Economy	13600.00
0005432567052	4710	Economy	13600.00
0005432459342	4710	Economy	13600.00
0005432567080	4710	Economy	13600.00
0005432567055	4710	Economy	13600.00
0005432459356	4710	Economy	13600.00
0005432567074	4710	Economy	13600.00
0005432459376	4710	Economy	13600.00
0005432459338	4710	Economy	13600.00
0005433451601	4710	Economy	13600.00
0005434081678	4710	Economy	13600.00
0005432459348	4710	Economy	13600.00
0005432459355	4710	Economy	13600.00
0005432567042	4710	Economy	13600.00
0005432459379	4710	Economy	13600.00
0005432567076	4710	Economy	13600.00
0005432567041	4710	Economy	13600.00
0005432567026	4710	Economy	13600.00
0005432459382	4710	Economy	13600.00
0005434081693	4710	Economy	13600.00
0005432567039	4710	Economy	13600.00
0005432170321	4710	Economy	13600.00
0005432567049	4710	Economy	13600.00
0005432567065	4710	Economy	13600.00
0005433452720	4710	Economy	13600.00
0005432459362	4710	Economy	13600.00
0005434081697	4710	Economy	13600.00
0005434081674	4710	Economy	13600.00
0005432567060	4710	Economy	13600.00
0005432459370	4710	Economy	13600.00
0005432459350	4710	Economy	13600.00
0005432459383	4710	Economy	13600.00
0005434081688	4710	Economy	13600.00
0005432459380	4710	Economy	13600.00
0005432459361	4710	Economy	13600.00
0005432567053	4710	Economy	13600.00
0005432567084	4710	Economy	13600.00
0005432459363	4710	Economy	13600.00
0005432459345	4710	Economy	13600.00
0005432567050	4710	Economy	13600.00
0005432567086	4710	Economy	13600.00
0005432567045	4710	Economy	13600.00
0005432459359	4710	Economy	13600.00
0005432459349	4710	Economy	13600.00
0005432567083	4710	Economy	13600.00
0005432186835	4710	Economy	13600.00
0005434081681	4710	Economy	13600.00
0005434081677	4710	Economy	13600.00
0005432459335	4710	Economy	13600.00
0005432567054	4710	Economy	13600.00
0005432567077	4710	Economy	13600.00
0005432459367	4710	Economy	13600.00
0005432170327	4710	Economy	13600.00
0005434081686	4710	Economy	13600.00
0005434081682	4710	Economy	13600.00
0005432567032	4710	Economy	15000.00
0005434081676	4710	Economy	13600.00
0005433451600	4710	Economy	15000.00
0005432567068	4710	Economy	13600.00
0005432567070	4710	Economy	13600.00
0005432170322	4710	Economy	13600.00
0005432459337	4710	Economy	13600.00
0005432459347	4710	Economy	13600.00
0005432459344	4710	Economy	13600.00
0005432186836	4710	Economy	13600.00
0005432459372	4710	Economy	13600.00
0005432459354	4710	Economy	13600.00
0005432567075	4710	Economy	13600.00
0005432567087	4710	Economy	13600.00
0005432459331	4710	Economy	13600.00
0005432459375	4710	Economy	13600.00
0005432459366	4710	Economy	13600.00
0005432170323	4710	Economy	13600.00
0005434081695	4710	Economy	13600.00
0005432567067	4710	Economy	13600.00
0005432186834	4710	Economy	13600.00
0005434081675	4710	Economy	13600.00
0005432567057	4710	Economy	13600.00
0005432567047	4710	Economy	13600.00
0005432567037	4710	Economy	13600.00
0005432459365	4710	Economy	13600.00
0005432567038	4710	Economy	13600.00
0005432571287	4710	Economy	13600.00
0005434081692	4710	Economy	13600.00
0005432459358	4710	Economy	13600.00
0005432567028	4710	Economy	13600.00
0005432567043	4710	Economy	13600.00
0005432459333	4710	Economy	13600.00
0005432567061	4710	Economy	13600.00
0005432567082	4710	Economy	13600.00
0005434081683	4710	Economy	13600.00
0005432567073	4710	Economy	13600.00
0005434081690	4710	Economy	13600.00
0005432170324	4710	Economy	13600.00
0005434081684	4710	Economy	13600.00
0005434081694	4710	Economy	13600.00
0005432567069	4710	Economy	13600.00
0005432459369	4710	Economy	13600.00
0005432459357	4710	Economy	13600.00
0005432459377	4710	Economy	13600.00
0005432571286	4710	Economy	13600.00
0005434081696	4710	Economy	13600.00
0005432459371	4710	Economy	13600.00
0005432567029	4710	Economy	13600.00
0005432459378	4710	Economy	13600.00
0005432567044	4710	Economy	13600.00
0005432567085	4710	Economy	13600.00
0005432459368	4710	Economy	13600.00
0005432459373	4710	Economy	13600.00
0005434081685	4710	Economy	13600.00
0005432459353	4710	Economy	13600.00
0005432567048	4710	Economy	13600.00
0005432567030	4710	Economy	13600.00
0005432567072	4710	Economy	13600.00
0005432567066	4710	Economy	13600.00
0005432459223	30524	Business	40900.00
0005434081529	30524	Business	40900.00
0005433454849	30524	Business	40900.00
0005432459005	30524	Business	40900.00
0005432459084	30524	Business	40900.00
0005432566603	30524	Business	40900.00
0005432566604	30524	Business	40900.00
0005432566774	30524	Business	40900.00
0005434081491	30524	Economy	15000.00
0005432566551	30524	Economy	13600.00
0005432459002	30524	Economy	13600.00
0005432459018	30524	Economy	13600.00
0005434081490	30524	Economy	13600.00
0005432566564	30524	Economy	13600.00
0005433454850	30524	Economy	13600.00
0005432566885	30524	Economy	13600.00
0005432566663	30524	Economy	13600.00
0005434081495	30524	Economy	13600.00
0005432566937	30524	Economy	13600.00
0005432566545	30524	Economy	13600.00
0005432459000	30524	Economy	13600.00
0005432459003	30524	Economy	13600.00
0005432566536	30524	Economy	13600.00
0005432566756	30524	Economy	13600.00
0005434081545	30524	Economy	13600.00
0005432566763	30524	Economy	13600.00
0005432161131	30524	Economy	13600.00
0005432566884	30524	Economy	13600.00
0005432566571	30524	Economy	13600.00
0005432566591	30524	Economy	13600.00
0005432213571	30524	Economy	13600.00
0005432459085	30524	Economy	13600.00
0005432459224	30524	Economy	13600.00
0005432566565	30524	Economy	13600.00
0005432566631	30524	Economy	13600.00
0005432161130	30524	Economy	13600.00
0005432566635	30524	Economy	13600.00
0005432566533	30524	Economy	13600.00
0005434081482	30524	Economy	13600.00
0005432566613	30524	Economy	13600.00
0005435840358	30524	Economy	13600.00
0005432459001	30524	Economy	13600.00
0005432459130	30524	Economy	13600.00
0005434081489	30524	Economy	13600.00
0005432566808	30524	Economy	13600.00
0005432161129	30524	Economy	13600.00
0005432459140	30524	Economy	13600.00
0005434081541	30524	Economy	13600.00
0005432566532	30524	Economy	13600.00
0005432571258	30524	Economy	13600.00
0005432566582	30524	Economy	13600.00
0005432566820	30524	Economy	13600.00
0005432213569	30524	Economy	13600.00
0005434081500	30524	Economy	13600.00
0005432566592	30524	Economy	13600.00
0005432566622	30524	Economy	13600.00
0005432566566	30524	Economy	13600.00
0005432459129	30524	Economy	13600.00
0005432459088	30524	Economy	13600.00
0005432566539	30524	Economy	13600.00
0005432566648	30524	Economy	13600.00
0005432459004	30524	Economy	13600.00
0005434081539	30524	Economy	13600.00
0005434081501	30524	Economy	13600.00
0005434081517	30524	Economy	13600.00
0005432458987	30524	Economy	13600.00
0005432566609	30524	Economy	13600.00
0005432213570	30524	Economy	13600.00
0005432566611	30524	Economy	13600.00
0005432213572	30524	Economy	13600.00
0005432566538	30524	Economy	13600.00
0005432458981	30524	Economy	13600.00
0005432459098	30524	Economy	13600.00
0005432566583	30524	Economy	13600.00
0005432566719	30524	Economy	13600.00
0005432566610	30524	Economy	13600.00
0005432566647	30524	Economy	13600.00
0005435722031	13581	Economy	9900.00
0005435722033	13581	Economy	9900.00
0005435722032	13581	Economy	9900.00
0005435722015	21113	Economy	9900.00
0005432295856	22772	Economy	8800.00
0005432295855	22772	Economy	8800.00
0005433342224	11095	Business	23600.00
0005433342284	11095	Business	23600.00
0005433342214	11095	Business	23600.00
0005433342194	11095	Business	23600.00
0005433342259	11095	Business	23600.00
0005433342211	11095	Business	23600.00
0005435097112	11095	Business	23600.00
0005433342219	11095	Business	23600.00
0005433342196	11095	Business	23600.00
0005433342222	11095	Business	23600.00
0005435097115	11095	Business	23600.00
0005433342199	11095	Economy	7900.00
0005433342202	11095	Economy	7900.00
0005433342212	11095	Economy	7900.00
0005433342255	11095	Economy	7900.00
0005433342192	11095	Economy	7900.00
0005433342213	11095	Economy	7900.00
0005433342207	11095	Economy	7900.00
0005433342193	11095	Economy	7900.00
0005433342226	11095	Economy	7900.00
0005433342293	11095	Economy	7900.00
0005433342253	11095	Economy	7900.00
0005433342270	11095	Economy	7900.00
0005433342263	11095	Economy	7900.00
0005435508174	11095	Economy	7900.00
0005433342217	11095	Economy	7900.00
0005433342233	11095	Economy	7900.00
0005433342272	11095	Economy	7900.00
0005433342279	11095	Economy	7900.00
0005433342282	11095	Economy	7900.00
0005433342243	11095	Economy	7900.00
0005433342200	11095	Economy	7900.00
0005433342265	11095	Economy	7900.00
0005433342209	11095	Economy	7900.00
0005433342291	11095	Economy	7900.00
0005433342247	11095	Economy	7900.00
0005433342244	11095	Economy	7900.00
0005433342267	11095	Economy	7900.00
0005433342290	11095	Economy	7900.00
0005433342269	11095	Economy	7900.00
0005433342286	11095	Economy	7900.00
0005433342241	11095	Economy	7900.00
0005435508173	11095	Economy	7900.00
0005433342216	11095	Economy	7900.00
0005433342289	11095	Economy	7900.00
0005433342228	11095	Economy	7900.00
0005433342204	11095	Economy	7900.00
0005433342285	11095	Economy	7900.00
0005435508167	11095	Economy	8600.00
0005433342203	11095	Economy	8600.00
0005433342225	11095	Economy	8600.00
0005435097117	11095	Economy	8600.00
0005433342250	11095	Economy	8600.00
0005433342271	11095	Economy	8600.00
0005435097110	11095	Economy	7900.00
0005433342264	11095	Economy	7900.00
0005435508165	11095	Economy	7900.00
0005433342229	11095	Economy	7900.00
0005433342292	11095	Economy	7900.00
0005433342287	11095	Economy	7900.00
0005433342234	11095	Economy	7900.00
0005433342205	11095	Economy	7900.00
0005433342278	11095	Economy	7900.00
0005433342268	11095	Economy	7900.00
0005435097116	11095	Economy	7900.00
0005433342230	11095	Economy	7900.00
0005435097118	11095	Economy	7900.00
0005433342245	11095	Economy	7900.00
0005433342277	11095	Economy	7900.00
0005433342237	11095	Economy	7900.00
0005433342266	11095	Economy	7900.00
0005433342280	11095	Economy	7900.00
0005433342257	11095	Economy	7900.00
0005433342218	11095	Economy	7900.00
0005433342239	11095	Economy	7900.00
0005433342246	11095	Economy	7900.00
0005433342197	11095	Economy	7900.00
0005433342206	11095	Economy	7900.00
0005435097114	11095	Economy	7900.00
0005433342221	11095	Economy	7900.00
0005433342201	11095	Economy	7900.00
0005433342283	11095	Economy	7900.00
0005433342223	11095	Economy	7900.00
0005433342275	11095	Economy	7900.00
0005433342261	11095	Economy	7900.00
0005433342258	11095	Economy	7900.00
0005433342274	11095	Economy	7900.00
0005433342276	11095	Economy	7900.00
0005433342249	11095	Economy	7900.00
0005433342238	11095	Economy	7900.00
0005433342235	11095	Economy	7900.00
0005433342251	11095	Economy	7900.00
0005433342281	11095	Economy	7900.00
0005433342208	11095	Economy	7900.00
0005433342240	11095	Economy	7900.00
0005433342210	11095	Economy	7900.00
0005433342273	11095	Economy	7900.00
0005433342262	11095	Economy	7900.00
0005433342256	11095	Economy	7900.00
0005433342232	11095	Economy	7900.00
0005433342248	11095	Economy	7900.00
0005433342260	11095	Economy	7900.00
0005433342288	11095	Economy	7900.00
0005433342198	11095	Economy	7900.00
0005433342231	11095	Economy	7900.00
0005433342227	11095	Economy	7900.00
0005433342236	11095	Economy	7900.00
0005435097113	11095	Economy	7900.00
0005433342242	11095	Economy	7900.00
0005435508171	11095	Economy	7900.00
0005433342195	11095	Economy	7900.00
0005435508170	11095	Economy	7900.00
0005433342220	11095	Economy	7900.00
0005433342215	11095	Economy	7900.00
0005435097111	11095	Economy	7900.00
0005433342254	11095	Economy	7900.00
0005433342252	11095	Economy	7900.00
0005433341473	17084	Business	23600.00
0005433341452	17084	Business	23600.00
0005433341684	17084	Economy	7900.00
0005435380255	17084	Economy	7900.00
0005433341942	17084	Economy	7900.00
0005433341648	17084	Economy	7900.00
0005435545651	17084	Economy	7900.00
0005433341423	17084	Economy	7900.00
0005435380252	17084	Economy	7900.00
0005432293185	17084	Economy	7900.00
0005433341411	17084	Economy	7900.00
0005433341404	17084	Economy	7900.00
0005435380256	17084	Economy	7900.00
0005435380259	17084	Economy	7900.00
0005433341453	17084	Economy	7900.00
0005433341941	17084	Economy	7900.00
0005433341421	17084	Economy	7900.00
0005433341441	17084	Economy	8600.00
0005433341764	17084	Economy	8600.00
0005433341434	17084	Economy	7900.00
0005433341440	17084	Economy	7900.00
0005433341575	17084	Economy	7900.00
0005433341422	17084	Economy	7900.00
0005433341637	17084	Economy	7900.00
0005435380254	17084	Economy	7900.00
0005435380258	17084	Economy	7900.00
0005433341782	17084	Economy	7900.00
0005433341395	17084	Economy	7900.00
0005433341443	17084	Economy	7900.00
0005433341653	17084	Economy	7900.00
0005435545653	17084	Economy	7900.00
0005433341533	17084	Economy	7900.00
0005433341777	17084	Economy	7900.00
0005435545652	17084	Economy	7900.00
0005433341576	17084	Economy	7900.00
0005433341636	17084	Economy	7900.00
0005433341407	17084	Economy	7900.00
0005435380257	17084	Economy	7900.00
0005433341430	17084	Economy	7900.00
0005435380253	17084	Economy	7900.00
0005433341596	17084	Economy	7900.00
0005435545650	17084	Economy	7900.00
0005433341696	17084	Economy	7900.00
0005435097055	17084	Economy	7900.00
0005435545654	17084	Economy	7900.00
0005433341433	17084	Economy	7900.00
0005433341697	17084	Economy	7900.00
0005433507010	9087	Business	26600.00
0005433507023	9087	Business	26600.00
0005433507016	9087	Business	26600.00
0005433507021	9087	Economy	8900.00
0005433507009	9087	Economy	8900.00
0005433507019	9087	Economy	8900.00
0005433507011	9087	Economy	9800.00
0005434158944	9087	Economy	9800.00
0005433481093	9087	Economy	9800.00
0005433507017	9087	Economy	8900.00
0005433507003	9087	Economy	8900.00
0005434158949	9087	Economy	8900.00
0005432919527	9087	Economy	8900.00
0005433481095	9087	Economy	8900.00
0005433507006	9087	Economy	8900.00
0005433507007	9087	Economy	8900.00
0005433507008	9087	Economy	8900.00
0005433507020	9087	Economy	8900.00
0005433507012	9087	Economy	8900.00
0005433481098	9087	Economy	8900.00
0005432919562	9087	Economy	8900.00
0005433507005	9087	Economy	8900.00
0005433507015	9087	Economy	8900.00
0005433481096	9087	Economy	8900.00
0005433481092	9087	Economy	8900.00
0005433507018	9087	Economy	8900.00
0005433507014	9087	Economy	8900.00
0005433507022	9087	Economy	8900.00
0005433507013	9087	Economy	8900.00
0005432919535	9087	Economy	8900.00
0005433507004	9087	Economy	8900.00
0005432919528	9087	Economy	8900.00
0005433481091	9087	Economy	8900.00
0005433481097	9087	Economy	8900.00
0005433507002	9087	Economy	8900.00
0005432919529	9087	Economy	8900.00
0005433481094	9087	Economy	8900.00
0005432919692	20432	Business	26600.00
0005432919683	20432	Business	26600.00
0005434158959	20432	Economy	8900.00
0005432919686	20432	Economy	8900.00
0005432919681	20432	Economy	8900.00
0005433506890	20432	Economy	8900.00
0005433481058	20432	Economy	8900.00
0005433481071	20432	Economy	9800.00
0005433506930	20432	Economy	9800.00
0005432919679	20432	Economy	8900.00
0005432919687	20432	Economy	8900.00
0005434158960	20432	Economy	8900.00
0005432919693	20432	Economy	8900.00
0005433506864	20432	Economy	8900.00
0005432919677	20432	Economy	8900.00
0005433481033	20432	Economy	8900.00
0005433506880	20432	Economy	8900.00
0005432919675	20432	Economy	8900.00
0005432919676	20432	Economy	8900.00
0005432919690	20432	Economy	8900.00
0005432919678	20432	Economy	8900.00
0005432919685	20432	Economy	8900.00
0005432919689	20432	Economy	8900.00
0005432919688	20432	Economy	8900.00
0005433481055	20432	Economy	8900.00
0005433506893	20432	Economy	8900.00
0005433481059	20432	Economy	8900.00
0005433506903	20432	Economy	8900.00
0005432919684	20432	Economy	8900.00
0005432919691	20432	Economy	8900.00
0005432919680	20432	Economy	8900.00
0005433506876	20432	Economy	8900.00
0005433506902	20432	Economy	8900.00
0005433506881	20432	Economy	8900.00
0005432919682	20432	Economy	8900.00
0005433506861	20432	Economy	8900.00
0005433506942	20432	Economy	8900.00
0005433506859	20432	Economy	8900.00
0005433481034	20432	Economy	8900.00
0005433506887	20432	Economy	8900.00
0005432919694	20432	Economy	8900.00
0005432394063	10177	Economy	5800.00
0005432396203	10177	Economy	5800.00
0005432396201	10177	Economy	5800.00
0005432394061	10177	Economy	5800.00
0005432396202	10177	Economy	5800.00
0005432394062	10177	Economy	5800.00
0005432394064	10177	Economy	5800.00
0005432400060	18390	Economy	5800.00
0005432396177	18390	Economy	5800.00
0005432396178	18390	Economy	5800.00
0005432400062	18390	Economy	5800.00
0005435179389	18390	Economy	5800.00
0005435625863	11039	Business	9500.00
0005434411740	11039	Business	9500.00
0005435625859	11039	Economy	3200.00
0005435125696	11039	Economy	3200.00
0005434928274	11039	Economy	3200.00
0005434411739	11039	Economy	3500.00
0005435125697	11039	Economy	3200.00
0005435625864	11039	Economy	3200.00
0005434928273	11039	Economy	3200.00
0005434411738	11039	Economy	3200.00
0005434928275	11039	Economy	3200.00
0005435125729	11039	Economy	3200.00
0005435625865	11039	Economy	3200.00
0005435554111	11039	Economy	3200.00
0005434411737	11039	Economy	3200.00
0005435125695	11039	Economy	3200.00
0005435125698	11039	Economy	3200.00
0005434928272	11039	Economy	3200.00
0005435125983	14772	Business	9500.00
0005435125987	14772	Business	9500.00
0005435554140	14772	Business	9500.00
0005435626018	14772	Business	9500.00
0005434928251	14772	Business	9500.00
0005435626015	14772	Business	9500.00
0005435126016	14772	Business	9500.00
0005435126006	14772	Business	9500.00
0005435554143	14772	Business	9500.00
0005435126001	14772	Business	9500.00
0005435125986	14772	Economy	3200.00
0005435554138	14772	Economy	3200.00
0005435125980	14772	Economy	3200.00
0005435125985	14772	Economy	3200.00
0005435126013	14772	Economy	3200.00
0005435126015	14772	Economy	3200.00
0005435126005	14772	Economy	3500.00
0005435626016	14772	Economy	3500.00
0005435125996	14772	Economy	3500.00
0005435126014	14772	Economy	3500.00
0005435126021	14772	Economy	3200.00
0005435626020	14772	Economy	3200.00
0005435556668	14772	Economy	3200.00
0005435626003	14772	Economy	3200.00
0005435126012	14772	Economy	3200.00
0005435626001	14772	Economy	3200.00
0005435126018	14772	Economy	3200.00
0005434928250	14772	Economy	3200.00
0005435626008	14772	Economy	3200.00
0005435126000	14772	Economy	3200.00
0005435626010	14772	Economy	3200.00
0005435126007	14772	Economy	3200.00
0005435125998	14772	Economy	3200.00
0005435126002	14772	Economy	3200.00
0005435626021	14772	Economy	3200.00
0005435126019	14772	Economy	3200.00
0005435554141	14772	Economy	3200.00
0005435125989	14772	Economy	3200.00
0005435126004	14772	Economy	3200.00
0005435125984	14772	Economy	3200.00
0005435626005	14772	Economy	3200.00
0005435125997	14772	Economy	3200.00
0005435125982	14772	Economy	3200.00
0005435554142	14772	Economy	3200.00
0005435626019	14772	Economy	3200.00
0005435626006	14772	Economy	3200.00
0005435125981	14772	Economy	3200.00
0005435626012	14772	Economy	3200.00
0005435126008	14772	Economy	3200.00
0005435126003	14772	Economy	3200.00
0005435125993	14772	Economy	3200.00
0005435126009	14772	Economy	3200.00
0005435125991	14772	Economy	3200.00
0005435626007	14772	Economy	3200.00
0005435125994	14772	Economy	3200.00
0005435554139	14772	Economy	3200.00
0005435626000	14772	Economy	3200.00
0005435125999	14772	Economy	3200.00
0005435626017	14772	Economy	3200.00
0005435126010	14772	Economy	3200.00
0005435626004	14772	Economy	3200.00
0005435125992	14772	Economy	3200.00
0005434411702	14772	Economy	3200.00
0005435126020	14772	Economy	3200.00
0005435125995	14772	Economy	3200.00
0005435626009	14772	Economy	3200.00
0005435626011	14772	Economy	3200.00
0005435126011	14772	Economy	3200.00
0005435626014	14772	Economy	3200.00
0005435126017	14772	Economy	3200.00
0005435626022	14772	Economy	3200.00
0005435626013	14772	Economy	3200.00
0005435125990	14772	Economy	3200.00
0005434928253	14772	Economy	3200.00
0005435626002	14772	Economy	3200.00
0005435125988	14772	Economy	3200.00
0005435715302	7124	Business	86900.00
0005435715309	7124	Business	86900.00
0005435443148	7124	Business	86900.00
0005435715310	7124	Business	86900.00
0005435715307	7124	Business	86900.00
0005432400094	7124	Economy	29000.00
0005435443175	7124	Economy	29000.00
0005435443147	7124	Economy	29000.00
0005432400092	7124	Economy	29000.00
0005435443187	7124	Economy	31900.00
0005435221036	7124	Economy	31900.00
0005435443159	7124	Economy	29000.00
0005435715303	7124	Economy	29000.00
0005432400093	7124	Economy	29000.00
0005435443160	7124	Economy	29000.00
0005435715312	7124	Economy	29000.00
0005435715305	7124	Economy	29000.00
0005435443181	7124	Economy	29000.00
0005435715308	7124	Economy	29000.00
0005435715311	7124	Economy	29000.00
0005435715313	7124	Economy	29000.00
0005432400091	7124	Economy	29000.00
0005435715316	7124	Economy	29000.00
0005435715315	7124	Economy	29000.00
0005432398162	7124	Economy	29000.00
0005435715301	7124	Economy	29000.00
0005435715304	7124	Economy	29000.00
0005435178469	7124	Economy	29000.00
0005435715314	7124	Economy	29000.00
0005432398164	7124	Economy	29000.00
0005435715306	7124	Economy	29000.00
0005432398163	7124	Economy	29000.00
0005435443158	7124	Economy	29000.00
0005432400095	7124	Economy	29000.00
0005435715300	7124	Economy	29000.00
0005435443180	7124	Economy	29000.00
0005435217692	27105	Business	86900.00
0005435443229	27105	Business	86900.00
0005435216562	27105	Business	86900.00
0005435218106	27105	Business	86900.00
0005435217685	27105	Business	86900.00
0005435216564	27105	Business	86900.00
0005435715169	27105	Economy	29000.00
0005435178983	27105	Economy	29000.00
0005435217694	27105	Economy	29000.00
0005435715207	27105	Economy	29000.00
0005435715177	27105	Economy	31900.00
0005435715204	27105	Economy	31900.00
0005435443222	27105	Economy	29000.00
0005435217686	27105	Economy	29000.00
0005435443221	27105	Economy	29000.00
0005435216566	27105	Economy	29000.00
0005435443228	27105	Economy	29000.00
0005435443227	27105	Economy	29000.00
0005435216567	27105	Economy	29000.00
0005435178479	27105	Economy	29000.00
0005435178478	27105	Economy	29000.00
0005435217693	27105	Economy	29000.00
0005435216561	27105	Economy	29000.00
0005435217689	27105	Economy	29000.00
0005435715193	27105	Economy	29000.00
0005435443226	27105	Economy	29000.00
0005435443223	27105	Economy	29000.00
0005435715170	27105	Economy	29000.00
0005435216568	27105	Economy	29000.00
0005435218108	27105	Economy	29000.00
0005435218107	27105	Economy	29000.00
0005435216563	27105	Economy	29000.00
0005435715208	27105	Economy	29000.00
0005435217688	27105	Economy	29000.00
0005435217687	27105	Economy	29000.00
0005435443225	27105	Economy	29000.00
0005435218105	27105	Economy	29000.00
0005435216565	27105	Economy	29000.00
0005435217691	27105	Economy	29000.00
0005435216569	27105	Economy	29000.00
0005435715174	27105	Economy	29000.00
0005435443230	27105	Economy	29000.00
0005435178984	27105	Economy	29000.00
0005435217690	27105	Economy	29000.00
0005435443224	27105	Economy	29000.00
0005433060373	2747	Economy	7700.00
0005434084885	2747	Economy	7700.00
0005434084886	2747	Economy	7700.00
0005433060374	2747	Economy	7700.00
0005433060366	2747	Economy	7700.00
0005433060372	2747	Economy	7700.00
0005433060367	2747	Economy	7700.00
0005434084888	2747	Economy	7700.00
0005433060370	2747	Economy	7700.00
0005434084887	2747	Economy	7700.00
0005434084858	28505	Economy	7700.00
0005434084859	28505	Economy	7700.00
0005433060387	28505	Economy	7700.00
0005433060389	28505	Economy	7700.00
0005434084850	28505	Economy	7700.00
0005433060388	28505	Economy	7700.00
0005434084849	28505	Economy	7700.00
0005433788174	11171	Economy	27100.00
0005433788161	11171	Economy	27100.00
0005433788164	11171	Economy	24600.00
0005433788168	11171	Economy	24600.00
0005433788162	11171	Economy	24600.00
0005433788163	11171	Economy	24600.00
0005433788171	11171	Economy	24600.00
0005433788173	11171	Economy	24600.00
0005433788166	11171	Economy	24600.00
0005433788167	11171	Economy	24600.00
0005433788177	11171	Economy	24600.00
0005433788170	11171	Economy	24600.00
0005433788165	11171	Economy	24600.00
0005433788172	11171	Economy	24600.00
0005433788176	11171	Economy	24600.00
0005433788175	11171	Economy	24600.00
0005433788169	11171	Economy	24600.00
0005435548441	20678	Economy	27100.00
0005435548448	20678	Economy	24600.00
0005435548447	20678	Economy	24600.00
0005435548446	20678	Economy	24600.00
0005435548449	20678	Economy	24600.00
0005435548444	20678	Economy	24600.00
0005435548442	20678	Economy	24600.00
0005435548440	20678	Economy	24600.00
0005435548443	20678	Economy	24600.00
0005435548445	20678	Economy	24600.00
0005435540747	11386	Business	20200.00
0005435540638	11386	Business	20200.00
0005435540721	11386	Business	20200.00
0005435540636	11386	Business	20200.00
0005435540693	11386	Business	20200.00
0005435540662	11386	Economy	6700.00
0005435517600	11386	Economy	6700.00
0005435540722	11386	Economy	6700.00
0005435517593	11386	Economy	6700.00
0005435517592	11386	Economy	6700.00
0005435540723	11386	Economy	7400.00
0005435517599	11386	Economy	7400.00
0005435517613	11386	Economy	7400.00
0005435540645	11386	Economy	6700.00
0005435540644	11386	Economy	6700.00
0005435517639	11386	Economy	6700.00
0005435517638	11386	Economy	6700.00
0005435517614	11386	Economy	6700.00
0005435540669	11386	Economy	6700.00
0005435540681	11386	Economy	6700.00
0005435540680	11386	Economy	6700.00
0005435517615	11386	Economy	6700.00
0005435517668	11386	Economy	6700.00
0005435517612	11386	Economy	6700.00
0005435540641	11386	Economy	6700.00
0005435540637	11386	Economy	6700.00
0005435517591	11386	Economy	6700.00
0005435517601	11386	Economy	6700.00
0005432294463	22229	Business	20200.00
0005435529039	22229	Business	20200.00
0005435529045	22229	Business	20200.00
0005435529046	22229	Business	20200.00
0005435540789	22229	Business	20200.00
0005435540781	22229	Business	20200.00
0005435540790	22229	Business	20200.00
0005435529054	22229	Economy	6700.00
0005435540780	22229	Economy	6700.00
0005435529038	22229	Economy	6700.00
0005435540797	22229	Economy	7400.00
0005435540782	22229	Economy	7400.00
0005435529035	22229	Economy	7400.00
0005435529044	22229	Economy	6700.00
0005435529037	22229	Economy	6700.00
0005435540788	22229	Economy	6700.00
0005435540794	22229	Economy	6700.00
0005432294462	22229	Economy	6700.00
0005435529052	22229	Economy	6700.00
0005435540791	22229	Economy	6700.00
0005435529050	22229	Economy	6700.00
0005435540784	22229	Economy	6700.00
0005435529051	22229	Economy	6700.00
0005435529041	22229	Economy	6700.00
0005435540792	22229	Economy	6700.00
0005435540783	22229	Economy	6700.00
0005435540778	22229	Economy	6700.00
0005435540798	22229	Economy	6700.00
0005435529040	22229	Economy	6700.00
0005435529036	22229	Economy	6700.00
0005435540779	22229	Economy	6700.00
0005435529042	22229	Economy	6700.00
0005435529048	22229	Economy	6700.00
0005435529043	22229	Economy	6700.00
0005432294464	22229	Economy	6700.00
0005435540799	22229	Economy	6700.00
0005435540785	22229	Economy	6700.00
0005435529053	22229	Economy	6700.00
0005435540796	22229	Economy	6700.00
0005435540787	22229	Economy	6700.00
0005435529047	22229	Economy	6700.00
0005435540793	22229	Economy	6700.00
0005435529034	22229	Economy	6700.00
0005435529049	22229	Economy	6700.00
0005435540786	22229	Economy	6700.00
0005435540795	22229	Economy	6700.00
0005433250953	2277	Business	20200.00
0005434906850	2277	Business	20200.00
0005434906841	2277	Business	20200.00
0005433251031	2277	Business	20200.00
0005434906821	2277	Business	20200.00
0005434906856	2277	Business	20200.00
0005434906828	2277	Business	20200.00
0005434906852	2277	Business	20200.00
0005433251012	2277	Economy	6700.00
0005434906837	2277	Economy	6700.00
0005434906818	2277	Economy	6700.00
0005434906848	2277	Economy	6700.00
0005433250941	2277	Economy	6700.00
0005433251019	2277	Economy	6700.00
0005434906849	2277	Economy	6700.00
0005434906822	2277	Economy	6700.00
0005433250936	2277	Economy	6700.00
0005433251096	2277	Economy	6700.00
0005434906842	2277	Economy	7400.00
0005434906815	2277	Economy	7400.00
0005434906851	2277	Economy	7400.00
0005434906835	2277	Economy	7400.00
0005434906824	2277	Economy	6700.00
0005434906838	2277	Economy	6700.00
0005433250954	2277	Economy	6700.00
0005434906840	2277	Economy	6700.00
0005433250958	2277	Economy	6700.00
0005434906827	2277	Economy	6700.00
0005434906825	2277	Economy	6700.00
0005434906839	2277	Economy	6700.00
0005434906819	2277	Economy	6700.00
0005434906845	2277	Economy	6700.00
0005434906833	2277	Economy	6700.00
0005434906858	2277	Economy	6700.00
0005433251066	2277	Economy	6700.00
0005434906830	2277	Economy	6700.00
0005434906826	2277	Economy	6700.00
0005433250973	2277	Economy	6700.00
0005433251058	2277	Economy	6700.00
0005434906816	2277	Economy	6700.00
0005433250983	2277	Economy	6700.00
0005434906832	2277	Economy	6700.00
0005434906823	2277	Economy	6700.00
0005433251033	2277	Economy	6700.00
0005434906814	2277	Economy	6700.00
0005434906843	2277	Economy	6700.00
0005434906847	2277	Economy	6700.00
0005433251065	2277	Economy	6700.00
0005433251095	2277	Economy	6700.00
0005433251013	2277	Economy	6700.00
0005434906846	2277	Economy	6700.00
0005434906855	2277	Economy	6700.00
0005434906817	2277	Economy	6700.00
0005434906857	2277	Economy	6700.00
0005434906853	2277	Economy	6700.00
0005433251011	2277	Economy	6700.00
0005434906836	2277	Economy	6700.00
0005434906844	2277	Economy	6700.00
0005433250967	2277	Economy	6700.00
0005433250952	2277	Economy	6700.00
0005434906854	2277	Economy	6700.00
0005433250974	2277	Economy	6700.00
0005434906829	2277	Economy	6700.00
0005433251098	2277	Economy	6700.00
0005434906831	2277	Economy	6700.00
0005434906820	2277	Economy	6700.00
0005434906834	2277	Economy	6700.00
0005433250962	2277	Economy	6700.00
0005433250979	2277	Economy	6700.00
0005434906524	25611	Business	20200.00
0005434906410	25611	Business	20200.00
0005433251199	25611	Business	20200.00
0005434906421	25611	Business	20200.00
0005434906428	25611	Business	20200.00
0005433251180	25611	Business	20200.00
0005434906560	25611	Business	20200.00
0005433400955	25611	Economy	6700.00
0005433400956	25611	Economy	6700.00
0005434906559	25611	Economy	6700.00
0005434906381	25611	Economy	6700.00
0005433251205	25611	Economy	6700.00
0005433251184	25611	Economy	6700.00
0005433251195	25611	Economy	7400.00
0005434906422	25611	Economy	7400.00
0005434906397	25611	Economy	7400.00
0005433251208	25611	Economy	6700.00
0005433251198	25611	Economy	6700.00
0005434906400	25611	Economy	6700.00
0005433251190	25611	Economy	6700.00
0005433251194	25611	Economy	6700.00
0005433251193	25611	Economy	6700.00
0005434906525	25611	Economy	6700.00
0005433251196	25611	Economy	6700.00
0005434906376	25611	Economy	6700.00
0005433251185	25611	Economy	6700.00
0005433251206	25611	Economy	6700.00
0005434906433	25611	Economy	6700.00
0005434906558	25611	Economy	6700.00
0005433251183	25611	Economy	6700.00
0005434906375	25611	Economy	6700.00
0005433400954	25611	Economy	6700.00
0005434906374	25611	Economy	6700.00
0005434906423	25611	Economy	6700.00
0005434906526	25611	Economy	6700.00
0005434906373	25611	Economy	6700.00
0005434906403	25611	Economy	6700.00
0005433251181	25611	Economy	6700.00
0005433251197	25611	Economy	6700.00
0005433251192	25611	Economy	6700.00
0005433251207	25611	Economy	6700.00
0005433251202	25611	Economy	6700.00
0005434906444	25611	Economy	6700.00
0005433251209	25611	Economy	6700.00
0005433251186	25611	Economy	6700.00
0005433251188	25611	Economy	6700.00
0005433251200	25611	Economy	6700.00
0005433251189	25611	Economy	6700.00
0005433251182	25611	Economy	6700.00
0005433251203	25611	Economy	6700.00
0005433251187	25611	Economy	6700.00
0005434906427	25611	Economy	6700.00
0005433251211	25611	Economy	6700.00
0005434906490	25611	Economy	6700.00
0005433251204	25611	Economy	6700.00
0005434906366	25611	Economy	6700.00
0005433251210	25611	Economy	6700.00
0005433251201	25611	Economy	6700.00
0005433251191	25611	Economy	6700.00
0005432620909	2494	Economy	12400.00
0005432620904	2494	Economy	12400.00
0005432620914	2494	Economy	12400.00
0005432620908	2494	Economy	12400.00
0005432620912	2494	Economy	12400.00
0005432620903	2494	Economy	12400.00
0005432620906	2494	Economy	12400.00
0005432620910	2494	Economy	12400.00
0005432620905	2494	Economy	12400.00
0005432862167	2494	Economy	12400.00
0005432620907	2494	Economy	12400.00
0005432862209	2494	Economy	12400.00
0005432862163	2494	Economy	12400.00
0005432620911	2494	Economy	12400.00
0005432620915	2494	Economy	12400.00
0005432620913	2494	Economy	12400.00
0005432620833	28068	Economy	13600.00
0005432620798	28068	Economy	13600.00
0005432620799	28068	Economy	12400.00
0005432620821	28068	Economy	12400.00
0005432620796	28068	Economy	12400.00
0005432862229	28068	Economy	12400.00
0005432862231	28068	Economy	12400.00
0005432862228	28068	Economy	12400.00
0005432620795	28068	Economy	12400.00
0005432620800	28068	Economy	12400.00
0005432862230	28068	Economy	12400.00
0005432862227	28068	Economy	12400.00
0005432862232	28068	Economy	12400.00
0005432862233	28068	Economy	12400.00
0005432620797	28068	Economy	12400.00
0005432620834	28068	Economy	12400.00
0005433452719	30985	Economy	8400.00
0005433452720	30985	Economy	8400.00
0005433451600	30985	Economy	8400.00
0005433451601	30985	Economy	8400.00
0005433454849	31398	Economy	8400.00
0005433454850	31398	Economy	8400.00
0005434142540	11997	Economy	7200.00
0005433134072	11997	Economy	6600.00
0005433129206	11997	Economy	6600.00
0005434142544	11997	Economy	6600.00
0005433134071	11997	Economy	6600.00
0005433129211	11997	Economy	6600.00
0005433134059	11997	Economy	6600.00
0005434184633	11997	Economy	6600.00
0005433134061	11997	Economy	6600.00
0005434142573	29823	Economy	7200.00
0005434183561	29823	Economy	7200.00
0005433131667	29823	Economy	6600.00
0005434142569	29823	Economy	6600.00
0005434183562	29823	Economy	6600.00
0005434184645	29823	Economy	6600.00
0005434142570	29823	Economy	6600.00
0005434142572	29823	Economy	6600.00
0005434184646	29823	Economy	6600.00
0005433131665	29823	Economy	6600.00
0005433131664	29823	Economy	6600.00
0005433134096	29823	Economy	6600.00
0005433131666	29823	Economy	6600.00
0005433134097	29823	Economy	6600.00
0005434142571	29823	Economy	6600.00
0005433131663	29823	Economy	6600.00
0005433134095	29823	Economy	6600.00
0005434183560	29823	Economy	6600.00
0005435798915	21297	Economy	15700.00
0005435697072	16461	Economy	19900.00
0005435697071	16461	Economy	19900.00
0005435697053	16461	Economy	19900.00
0005435697050	16461	Economy	18100.00
0005435697045	16461	Economy	18100.00
0005435697065	16461	Economy	18100.00
0005435697048	16461	Economy	18100.00
0005435697062	16461	Economy	18100.00
0005435697069	16461	Economy	18100.00
0005435697063	16461	Economy	18100.00
0005435697047	16461	Economy	18100.00
0005435697068	16461	Economy	18100.00
0005435697056	16461	Economy	18100.00
0005435697070	16461	Economy	18100.00
0005435697055	16461	Economy	18100.00
0005435697067	16461	Economy	18100.00
0005435697057	16461	Economy	18100.00
0005435697052	16461	Economy	18100.00
0005435697060	16461	Economy	18100.00
0005435697051	16461	Economy	18100.00
0005435697064	16461	Economy	18100.00
0005435697059	16461	Economy	18100.00
0005435697061	16461	Economy	18100.00
0005435697044	16461	Economy	18100.00
0005435697066	16461	Economy	18100.00
0005435697046	16461	Economy	18100.00
0005435697049	16461	Economy	18100.00
0005435697058	16461	Economy	18100.00
0005435697054	16461	Economy	18100.00
0005435696855	24727	Economy	19900.00
0005435696877	24727	Economy	18100.00
0005435696940	24727	Economy	18100.00
0005435696896	24727	Economy	18100.00
0005435696882	24727	Economy	18100.00
0005435696894	24727	Economy	18100.00
0005435696864	24727	Economy	18100.00
0005435696870	24727	Economy	18100.00
0005435696876	24727	Economy	18100.00
0005435935016	24727	Economy	18100.00
0005435696854	24727	Economy	18100.00
0005435696883	24727	Economy	18100.00
0005435696859	24727	Economy	18100.00
0005435696897	24727	Economy	18100.00
0005435696853	24727	Economy	18100.00
0005435697058	24727	Economy	18100.00
0005435935017	24727	Economy	18100.00
0005435696881	24727	Economy	18100.00
0005435696857	24727	Economy	18100.00
0005435696871	24727	Economy	18100.00
0005435696898	24727	Economy	18100.00
0005435696889	24727	Economy	18100.00
0005435696865	24727	Economy	18100.00
0005435696858	24727	Economy	18100.00
0005433724759	18797	Economy	4400.00
0005433724761	18797	Economy	4400.00
0005433724760	18797	Economy	4400.00
0005433724762	18797	Economy	4400.00
0005433724726	21647	Economy	4400.00
0005433724734	21647	Economy	4400.00
0005432968822	21647	Economy	4400.00
0005432968820	21647	Economy	4400.00
0005432968821	21647	Economy	4400.00
0005433724727	21647	Economy	4400.00
0005434137441	7326	Business	23100.00
0005434137394	7326	Business	23100.00
0005434137383	7326	Business	23100.00
0005434087469	7326	Business	23100.00
0005434137375	7326	Business	23100.00
0005434137401	7326	Business	23100.00
0005434137386	7326	Business	23100.00
0005434137381	7326	Business	23100.00
0005434137361	7326	Business	23100.00
0005434137360	7326	Business	23100.00
0005434137405	7326	Business	23100.00
0005434137396	7326	Business	23100.00
0005434137400	7326	Economy	7700.00
0005434137399	7326	Economy	7700.00
0005434137374	7326	Economy	7700.00
0005434137391	7326	Economy	7700.00
0005434087467	7326	Economy	7700.00
0005434137427	7326	Economy	7700.00
0005434137358	7326	Economy	7700.00
0005434137368	7326	Economy	7700.00
0005434137367	7326	Economy	7700.00
0005434137420	7326	Economy	7700.00
0005434137380	7326	Economy	8500.00
0005434087470	7326	Economy	8500.00
0005434137432	7326	Economy	8500.00
0005434137385	7326	Economy	8500.00
0005434137390	7326	Economy	8500.00
0005434137389	7326	Economy	7700.00
0005434137370	7326	Economy	7700.00
0005434137377	7326	Economy	7700.00
0005434137376	7326	Economy	7700.00
0005434137364	7326	Economy	7700.00
0005434137411	7326	Economy	7700.00
0005434137365	7326	Economy	7700.00
0005434137363	7326	Economy	7700.00
0005434137359	7326	Economy	7700.00
0005434137398	7326	Economy	7700.00
0005434137382	7326	Economy	7700.00
0005434137412	7326	Economy	7700.00
0005434087471	7326	Economy	7700.00
0005434137372	7326	Economy	7700.00
0005434137437	7326	Economy	7700.00
0005434137418	7326	Economy	7700.00
0005434137384	7326	Economy	7700.00
0005434137362	7326	Economy	7700.00
0005434137421	7326	Economy	7700.00
0005434137357	7326	Economy	7700.00
0005434137416	7326	Economy	7700.00
0005434137425	7326	Economy	7700.00
0005434137403	7326	Economy	7700.00
0005434137378	7326	Economy	7700.00
0005434137366	7326	Economy	7700.00
0005434137392	7326	Economy	7700.00
0005434137424	7326	Economy	7700.00
0005434137438	7326	Economy	7700.00
0005434137423	7326	Economy	7700.00
0005434137419	7326	Economy	7700.00
0005434137388	7326	Economy	7700.00
0005434137439	7326	Economy	7700.00
0005434137408	7326	Economy	7700.00
0005434137431	7326	Economy	7700.00
0005434137417	7326	Economy	7700.00
0005434137406	7326	Economy	7700.00
0005434137442	7326	Economy	7700.00
0005434137422	7326	Economy	7700.00
0005434137426	7326	Economy	7700.00
0005434137369	7326	Economy	7700.00
0005434137397	7326	Economy	7700.00
0005434137410	7326	Economy	7700.00
0005434137445	7326	Economy	7700.00
0005434137435	7326	Economy	7700.00
0005434137402	7326	Economy	7700.00
0005434137443	7326	Economy	7700.00
0005434137413	7326	Economy	7700.00
0005434137434	7326	Economy	7700.00
0005434137407	7326	Economy	7700.00
0005434137387	7326	Economy	7700.00
0005434137373	7326	Economy	7700.00
0005434137371	7326	Economy	7700.00
0005434137395	7326	Economy	7700.00
0005434137436	7326	Economy	7700.00
0005434137404	7326	Economy	7700.00
0005434137430	7326	Economy	7700.00
0005434137428	7326	Economy	7700.00
0005434137415	7326	Economy	7700.00
0005434137409	7326	Economy	7700.00
0005434137444	7326	Economy	7700.00
0005434137433	7326	Economy	7700.00
0005434087468	7326	Economy	7700.00
0005434137414	7326	Economy	7700.00
0005434137429	7326	Economy	7700.00
0005434137379	7326	Economy	7700.00
0005434137440	7326	Economy	7700.00
0005434137393	7326	Economy	7700.00
0005434087435	28584	Business	23100.00
0005434136761	28584	Business	23100.00
0005434136832	28584	Business	23100.00
0005434087429	28584	Business	23100.00
0005434136678	28584	Economy	7700.00
0005434136717	28584	Economy	7700.00
0005434136748	28584	Economy	7700.00
0005434136677	28584	Economy	8500.00
0005434136687	28584	Economy	7700.00
0005434136688	28584	Economy	7700.00
0005434136733	28584	Economy	7700.00
0005434136718	28584	Economy	7700.00
0005434136848	28584	Economy	7700.00
0005434136849	28584	Economy	7700.00
0005434136699	28584	Economy	7700.00
0005434087440	28584	Economy	7700.00
0005434136686	28584	Economy	7700.00
0005434136831	28584	Economy	7700.00
0005434136760	28584	Economy	7700.00
0005434136726	28584	Economy	7700.00
0005434087434	28584	Economy	7700.00
0005434136806	28584	Economy	7700.00
0005434136920	28584	Economy	7700.00
0005434136753	28584	Economy	7700.00
0005435808137	1895	Economy	23900.00
0005435808140	1895	Economy	21700.00
0005435808144	1895	Economy	21700.00
0005434610197	1895	Economy	21700.00
0005433407485	1895	Economy	21700.00
0005433407477	1895	Economy	21700.00
0005434610194	1895	Economy	21700.00
0005434610195	1895	Economy	21700.00
0005435808141	1895	Economy	21700.00
0005433407484	1895	Economy	21700.00
0005435808138	1895	Economy	21700.00
0005435808139	1895	Economy	21700.00
0005435808136	1895	Economy	21700.00
0005434610196	1895	Economy	21700.00
0005435808143	1895	Economy	21700.00
0005435808142	1895	Economy	21700.00
0005435808050	23069	Economy	23900.00
0005435808051	23069	Economy	23900.00
0005433407506	23069	Economy	21700.00
0005433407504	23069	Economy	21700.00
0005435808052	23069	Economy	21700.00
0005433407511	23069	Economy	21700.00
0005433407517	23069	Economy	21700.00
0005433407512	23069	Economy	21700.00
0005433407510	23069	Economy	21700.00
0005433407513	23069	Economy	21700.00
0005433407515	23069	Economy	21700.00
0005433407503	23069	Economy	21700.00
0005433407505	23069	Economy	21700.00
0005433407516	23069	Economy	21700.00
0005433407514	23069	Economy	21700.00
0005433407508	23069	Economy	21700.00
0005433407507	23069	Economy	21700.00
0005433407509	23069	Economy	21700.00
0005434503526	16704	Economy	7600.00
0005434503530	16704	Economy	6900.00
0005434503575	16704	Economy	6900.00
0005434503496	16704	Economy	6900.00
0005434503654	16704	Economy	6900.00
0005434503529	16704	Economy	6900.00
0005434503745	22917	Economy	7600.00
0005434503761	22917	Economy	7600.00
0005434503782	22917	Economy	6900.00
0005434503771	22917	Economy	6900.00
0005434503743	22917	Economy	6900.00
0005434503755	22917	Economy	6900.00
0005434503777	22917	Economy	6900.00
0005434503770	22917	Economy	6900.00
0005434503754	22917	Economy	6900.00
0005434503774	22917	Economy	6900.00
0005434503758	22917	Economy	6900.00
0005434503776	22917	Economy	6900.00
0005434503744	22917	Economy	6900.00
0005434503779	22917	Economy	6900.00
0005434503746	22917	Economy	6900.00
0005434503756	22917	Economy	6900.00
0005434503767	22917	Economy	6900.00
0005434503757	22917	Economy	6900.00
0005434503768	22917	Economy	6900.00
0005434503764	22917	Economy	6900.00
0005434503760	22917	Economy	6900.00
0005434503766	22917	Economy	6900.00
0005434503763	22917	Economy	6900.00
0005434503750	22917	Economy	6900.00
0005434503762	22917	Economy	6900.00
0005434503773	22917	Economy	6900.00
0005434503781	22917	Economy	6900.00
0005434503772	22917	Economy	6900.00
0005434503780	22917	Economy	6900.00
0005434503749	22917	Economy	6900.00
0005434503775	22917	Economy	6900.00
0005434503748	22917	Economy	6900.00
0005434503741	22917	Economy	6900.00
0005434503747	22917	Economy	6900.00
0005434503753	22917	Economy	6900.00
0005434503769	22917	Economy	6900.00
0005434503778	22917	Economy	6900.00
0005434503751	22917	Economy	6900.00
0005434503765	22917	Economy	6900.00
0005434503742	22917	Economy	6900.00
0005434503752	22917	Economy	6900.00
0005434503759	22917	Economy	6900.00
0005433266584	2209	Economy	7700.00
0005435078198	2209	Economy	7700.00
0005435078193	2209	Economy	7000.00
0005435078206	2209	Economy	7000.00
0005435078195	2209	Economy	7000.00
0005435078204	2209	Economy	7000.00
0005435078194	2209	Economy	7000.00
0005435078205	2209	Economy	7000.00
0005435078202	2209	Economy	7000.00
0005433266585	2209	Economy	7000.00
0005433266575	2209	Economy	7000.00
0005435078203	2209	Economy	7000.00
0005435078197	2209	Economy	7000.00
0005435078192	2209	Economy	7000.00
0005435078200	2209	Economy	7000.00
0005433266598	2209	Economy	7000.00
0005433266557	2209	Economy	7000.00
0005435078201	2209	Economy	7000.00
0005435078196	2209	Economy	7000.00
0005435078199	2209	Economy	7000.00
0005435078191	2209	Economy	7000.00
0005433266576	2209	Economy	7000.00
0005433266638	24323	Economy	7700.00
0005435078063	24323	Economy	7700.00
0005433266639	24323	Economy	7000.00
0005435078142	24323	Economy	7000.00
0005435078092	24323	Economy	7000.00
0005433266637	24323	Economy	7000.00
0005435078102	24323	Economy	7000.00
0005433266640	24323	Economy	7000.00
0005433266636	24323	Economy	7000.00
0005433266634	24323	Economy	7000.00
0005433266641	24323	Economy	7000.00
0005435078132	24323	Economy	7000.00
0005435078070	24323	Economy	7000.00
0005433266633	24323	Economy	7000.00
0005435078103	24323	Economy	7000.00
0005433266635	24323	Economy	7000.00
0005435803235	6667	Economy	9800.00
0005435803237	6667	Economy	9800.00
0005435803236	6667	Economy	9800.00
0005434988636	6667	Economy	9800.00
0005434988637	6667	Economy	9800.00
0005434988634	6667	Economy	9800.00
0005434988633	6667	Economy	9800.00
0005435464474	6667	Economy	9800.00
0005434988635	6667	Economy	9800.00
0005435464489	23608	Economy	9800.00
0005435803214	23608	Economy	9800.00
0005435803217	23608	Economy	9800.00
0005435803215	23608	Economy	9800.00
0005435803216	23608	Economy	9800.00
0005432382821	30499	Business	9900.00
0005432382806	30499	Business	9900.00
0005432382812	30499	Business	9900.00
0005432382835	30499	Business	9900.00
0005432382814	30499	Business	9900.00
0005432382830	30499	Business	9900.00
0005433453744	30499	Business	9900.00
0005432382823	30499	Business	9900.00
0005433449777	30499	Business	9900.00
0005432382832	30499	Economy	3300.00
0005433449768	30499	Economy	3300.00
0005432382815	30499	Economy	3300.00
0005432382805	30499	Economy	3300.00
0005433449782	30499	Economy	3300.00
0005432382807	30499	Economy	3300.00
0005432382828	30499	Economy	3300.00
0005432382833	30499	Economy	3600.00
0005433449774	30499	Economy	3600.00
0005432382810	30499	Economy	3600.00
0005432382819	30499	Economy	3600.00
0005433454855	30499	Economy	3300.00
0005432382818	30499	Economy	3300.00
0005433449783	30499	Economy	3300.00
0005433449767	30499	Economy	3300.00
0005433449781	30499	Economy	3300.00
0005433453743	30499	Economy	3300.00
0005432382817	30499	Economy	3300.00
0005433449776	30499	Economy	3300.00
0005432382843	30499	Economy	3300.00
0005432382839	30499	Economy	3300.00
0005432382808	30499	Economy	3300.00
0005432382824	30499	Economy	3300.00
0005432382831	30499	Economy	3300.00
0005432382811	30499	Economy	3300.00
0005433453745	30499	Economy	3300.00
0005433449763	30499	Economy	3300.00
0005432382837	30499	Economy	3300.00
0005432382842	30499	Economy	3300.00
0005432382822	30499	Economy	3300.00
0005432382826	30499	Economy	3300.00
0005432382816	30499	Economy	3300.00
0005433449769	30499	Economy	3300.00
0005433449772	30499	Economy	3300.00
0005433449780	30499	Economy	3300.00
0005432382820	30499	Economy	3300.00
0005432382841	30499	Economy	3300.00
0005433449773	30499	Economy	3300.00
0005433449771	30499	Economy	3300.00
0005433449779	30499	Economy	3300.00
0005432382813	30499	Economy	3300.00
0005432382838	30499	Economy	3300.00
0005433449775	30499	Economy	3300.00
0005433449766	30499	Economy	3300.00
0005433449762	30499	Economy	3300.00
0005433449784	30499	Economy	3300.00
0005433453746	30499	Economy	3300.00
0005432382827	30499	Economy	3300.00
0005433449764	30499	Economy	3300.00
0005433449778	30499	Economy	3300.00
0005433449770	30499	Economy	3300.00
0005432382809	30499	Economy	3300.00
0005432382825	30499	Economy	3300.00
0005433454854	30499	Economy	3300.00
0005433449765	30499	Economy	3300.00
0005432382829	30499	Economy	3300.00
0005432382804	30499	Economy	3300.00
0005432382834	30499	Economy	3300.00
0005432382836	30499	Economy	3300.00
0005432382840	30499	Economy	3300.00
0005433449633	31322	Business	9900.00
0005432382520	31322	Business	9900.00
0005432382531	31322	Business	9900.00
0005432382511	31322	Economy	3600.00
0005433449642	31322	Economy	3600.00
0005432382533	31322	Economy	3300.00
0005432382556	31322	Economy	3300.00
0005433451583	31322	Economy	3300.00
0005433449594	31322	Economy	3300.00
0005433449596	31322	Economy	3300.00
0005433449606	31322	Economy	3300.00
0005432382555	31322	Economy	3300.00
0005433449632	31322	Economy	3300.00
0005432382532	31322	Economy	3300.00
0005433449585	31322	Economy	3300.00
0005432382541	31322	Economy	3300.00
0005433449586	31322	Economy	3300.00
0005433449597	31322	Economy	3300.00
0005433449693	31322	Economy	3300.00
0005432382586	31322	Economy	3300.00
0005433453728	31322	Economy	3300.00
0005435299697	10755	Economy	17100.00
0005433131626	10755	Economy	15600.00
0005433131627	10755	Economy	15600.00
0005433126771	10755	Economy	15600.00
0005433126770	10755	Economy	15600.00
0005435304094	10755	Economy	15600.00
0005433131629	10755	Economy	15600.00
0005435304093	10755	Economy	15600.00
0005433126806	29736	Economy	17100.00
0005433129237	29736	Economy	17100.00
0005433129239	29736	Economy	15600.00
0005433129240	29736	Economy	15600.00
0005435299735	29736	Economy	15600.00
0005433126807	29736	Economy	15600.00
0005435302159	29736	Economy	15600.00
0005433126805	29736	Economy	15600.00
0005435299738	29736	Economy	15600.00
0005433126808	29736	Economy	15600.00
0005435299737	29736	Economy	15600.00
0005435299736	29736	Economy	15600.00
0005433126804	29736	Economy	15600.00
0005435299734	29736	Economy	15600.00
0005435302163	29736	Economy	15600.00
0005433129238	29736	Economy	15600.00
0005435302162	29736	Economy	15600.00
0005435302161	29736	Economy	15600.00
0005435302160	29736	Economy	15600.00
0005435302158	29736	Economy	15600.00
0005433129236	29736	Economy	15600.00
0005433109904	2428	Economy	17200.00
0005434287084	2428	Economy	17200.00
0005434287088	2428	Economy	15700.00
0005434287092	2428	Economy	15700.00
0005433109849	2428	Economy	15700.00
0005433109862	2428	Economy	15700.00
0005434287082	2428	Economy	15700.00
0005434287086	2428	Economy	15700.00
0005434287087	2428	Economy	15700.00
0005434287096	2428	Economy	15700.00
0005434287079	2428	Economy	15700.00
0005434287094	2428	Economy	15700.00
0005434287090	2428	Economy	15700.00
0005434287080	2428	Economy	15700.00
0005432264454	2428	Economy	15700.00
0005432264453	2428	Economy	15700.00
0005432264452	2428	Economy	15700.00
0005434287089	2428	Economy	15700.00
0005434287083	2428	Economy	15700.00
0005434287095	2428	Economy	15700.00
0005434287093	2428	Economy	15700.00
0005434287077	2428	Economy	15700.00
0005434287081	2428	Economy	15700.00
0005434287091	2428	Economy	15700.00
0005434287078	2428	Economy	15700.00
0005434287085	2428	Economy	15700.00
0005434287076	2428	Economy	15700.00
0005432264451	2428	Economy	15700.00
0005434287075	2428	Economy	15700.00
0005433109901	2428	Economy	15700.00
0005433109852	2428	Economy	15700.00
0005434287074	2428	Economy	15700.00
0005434286916	26847	Economy	17200.00
0005433109942	26847	Economy	17200.00
0005434286932	26847	Economy	15700.00
0005433109939	26847	Economy	15700.00
0005434286949	26847	Economy	15700.00
0005434286901	26847	Economy	15700.00
0005434286893	26847	Economy	15700.00
0005433109943	26847	Economy	15700.00
0005434286902	26847	Economy	15700.00
0005434286928	26847	Economy	15700.00
0005434286896	26847	Economy	15700.00
0005433109937	26847	Economy	15700.00
0005433109938	26847	Economy	15700.00
0005434286994	26847	Economy	15700.00
0005434286938	26847	Economy	15700.00
0005434286897	26847	Economy	15700.00
0005433109941	26847	Economy	15700.00
0005433109944	26847	Economy	15700.00
0005434286950	26847	Economy	15700.00
0005433109936	26847	Economy	15700.00
0005433109945	26847	Economy	15700.00
0005433109948	26847	Economy	15700.00
0005434286965	26847	Economy	15700.00
0005433109946	26847	Economy	15700.00
0005434286907	26847	Economy	15700.00
0005433109947	26847	Economy	15700.00
0005434286954	26847	Economy	15700.00
0005433109940	26847	Economy	15700.00
0005434272167	25464	Economy	22800.00
0005435856166	25464	Economy	22800.00
0005435856167	25464	Economy	22800.00
0005434272176	26660	Economy	22800.00
0005434272177	26660	Economy	22800.00
0005434273062	26660	Economy	22800.00
0005433868058	4803	Economy	19400.00
0005433868079	4803	Economy	19400.00
0005433868093	4803	Economy	17600.00
0005433868055	4803	Economy	17600.00
0005433868085	4803	Economy	17600.00
0005433868073	4803	Economy	17600.00
0005433868090	4803	Economy	17600.00
0005433868076	4803	Economy	17600.00
0005433868074	4803	Economy	17600.00
0005433868092	4803	Economy	17600.00
0005433868068	4803	Economy	17600.00
0005433868083	4803	Economy	17600.00
0005433868057	4803	Economy	17600.00
0005433868082	4803	Economy	17600.00
0005433868078	4803	Economy	17600.00
0005433868061	4803	Economy	17600.00
0005433868086	4803	Economy	17600.00
0005433868067	4803	Economy	17600.00
0005433868089	4803	Economy	17600.00
0005433868069	4803	Economy	17600.00
0005433868064	4803	Economy	17600.00
0005433868084	4803	Economy	17600.00
0005433868077	4803	Economy	17600.00
0005433868062	4803	Economy	17600.00
0005433868060	4803	Economy	17600.00
0005433868088	4803	Economy	17600.00
0005433868065	4803	Economy	17600.00
0005433868075	4803	Economy	17600.00
0005433868063	4803	Economy	17600.00
0005433868059	4803	Economy	17600.00
0005433868072	4803	Economy	17600.00
0005433868081	4803	Economy	17600.00
0005433868070	4803	Economy	17600.00
0005433868056	4803	Economy	17600.00
0005433868087	4803	Economy	17600.00
0005433868054	4803	Economy	17600.00
0005433868094	4803	Economy	17600.00
0005433868071	4803	Economy	17600.00
0005433868066	4803	Economy	17600.00
0005433868091	4803	Economy	17600.00
0005433868080	4803	Economy	17600.00
0005435860456	32588	Economy	19400.00
0005433867746	32588	Economy	19400.00
0005435860461	32588	Economy	17600.00
0005433867763	32588	Economy	17600.00
0005435860454	32588	Economy	17600.00
0005433867885	32588	Economy	17600.00
0005433867728	32588	Economy	17600.00
0005433867762	32588	Economy	17600.00
0005433867792	32588	Economy	17600.00
0005433867800	32588	Economy	17600.00
0005435860460	32588	Economy	17600.00
0005435860459	32588	Economy	17600.00
0005435860457	32588	Economy	17600.00
0005433867799	32588	Economy	17600.00
0005433867801	32588	Economy	17600.00
0005433867773	32588	Economy	17600.00
0005435860455	32588	Economy	17600.00
0005433867761	32588	Economy	17600.00
0005433867734	32588	Economy	17600.00
0005435860458	32588	Economy	17600.00
0005435911322	3414	Economy	24800.00
0005435911326	3414	Economy	24800.00
0005434663282	3414	Economy	24800.00
0005435911328	3414	Economy	24800.00
0005434460485	3414	Economy	22600.00
0005434663288	3414	Economy	22600.00
0005434663284	3414	Economy	22600.00
0005434663291	3414	Economy	22600.00
0005434663285	3414	Economy	22600.00
0005434663283	3414	Economy	22600.00
0005434460484	3414	Economy	22600.00
0005434663290	3414	Economy	22600.00
0005434460486	3414	Economy	22600.00
0005434663286	3414	Economy	22600.00
0005434663289	3414	Economy	22600.00
0005434663280	3414	Economy	22600.00
0005434663279	3414	Economy	22600.00
0005434663278	3414	Economy	22600.00
0005435911317	3414	Economy	22600.00
0005434663287	3414	Economy	22600.00
0005434663281	3414	Economy	22600.00
0005434663168	12473	Economy	24800.00
0005435911381	12473	Economy	22600.00
0005435911379	12473	Economy	22600.00
0005434663198	12473	Economy	22600.00
0005435911378	12473	Economy	22600.00
0005435911380	12473	Economy	22600.00
0005434663174	12473	Economy	22600.00
0005434663177	12473	Economy	22600.00
0005435911385	12473	Economy	22600.00
0005435911382	12473	Economy	22600.00
0005435911383	12473	Economy	22600.00
0005435911384	12473	Economy	22600.00
0005434663167	12473	Economy	22600.00
0005433867746	14496	Economy	18500.00
0005433867885	14496	Economy	18500.00
0005433867792	14496	Economy	18500.00
0005435860460	14496	Economy	16800.00
0005435860461	14496	Economy	16800.00
0005433867801	14496	Economy	16800.00
0005433867800	14496	Economy	16800.00
0005435860458	14496	Economy	16800.00
0005433867773	14496	Economy	16800.00
0005435860454	14496	Economy	16800.00
0005433867734	14496	Economy	16800.00
0005433867762	14496	Economy	16800.00
0005435860459	14496	Economy	16800.00
0005433867799	14496	Economy	16800.00
0005433867728	14496	Economy	16800.00
0005435860455	14496	Economy	16800.00
0005433867761	14496	Economy	16800.00
0005433867763	14496	Economy	16800.00
0005435860457	14496	Economy	16800.00
0005435860456	14496	Economy	16800.00
0005433868034	32664	Economy	18500.00
0005433868049	32664	Economy	18500.00
0005433868041	32664	Economy	18500.00
0005433868053	32664	Economy	18500.00
0005433868022	32664	Economy	16800.00
0005433868030	32664	Economy	16800.00
0005433868032	32664	Economy	16800.00
0005433868031	32664	Economy	16800.00
0005433868035	32664	Economy	16800.00
0005433868047	32664	Economy	16800.00
0005433868026	32664	Economy	16800.00
0005433868033	32664	Economy	16800.00
0005433868029	32664	Economy	16800.00
0005433868021	32664	Economy	16800.00
0005433868023	32664	Economy	16800.00
0005433868052	32664	Economy	16800.00
0005433868014	32664	Economy	16800.00
0005433868037	32664	Economy	16800.00
0005433868042	32664	Economy	16800.00
0005433868051	32664	Economy	16800.00
0005433868038	32664	Economy	16800.00
0005433868017	32664	Economy	16800.00
0005433868039	32664	Economy	16800.00
0005433868036	32664	Economy	16800.00
0005433868027	32664	Economy	16800.00
0005433868016	32664	Economy	16800.00
0005433868013	32664	Economy	16800.00
0005433868025	32664	Economy	16800.00
0005433868050	32664	Economy	16800.00
0005433868018	32664	Economy	16800.00
0005433868024	32664	Economy	16800.00
0005433868048	32664	Economy	16800.00
0005433868020	32664	Economy	16800.00
0005433868019	32664	Economy	16800.00
0005433868046	32664	Economy	16800.00
0005433868044	32664	Economy	16800.00
0005433868045	32664	Economy	16800.00
0005433868028	32664	Economy	16800.00
0005433868012	32664	Economy	16800.00
0005433868040	32664	Economy	16800.00
0005433868043	32664	Economy	16800.00
0005433868015	32664	Economy	16800.00
0005432798971	12107	Economy	4400.00
0005432799028	12107	Economy	4400.00
0005432798982	12107	Economy	4400.00
0005432799022	12107	Economy	4400.00
0005432799086	12107	Economy	4400.00
0005432798981	12107	Economy	4400.00
0005432799049	12107	Economy	4400.00
0005432799029	12107	Economy	4400.00
0005432798969	12107	Economy	4400.00
0005432798978	12107	Economy	4400.00
0005432799005	12107	Economy	4400.00
0005432799040	12107	Economy	4400.00
0005432798977	12107	Economy	4400.00
0005432799090	12107	Economy	4400.00
0005432799023	12107	Economy	4400.00
0005432799014	12107	Economy	4400.00
0005432799181	14793	Economy	4900.00
0005432799183	14793	Economy	4400.00
0005432799182	14793	Economy	4400.00
0005432799164	14793	Economy	4400.00
0005432799169	14793	Economy	4400.00
0005432799177	14793	Economy	4400.00
0005432799165	14793	Economy	4400.00
0005432799166	14793	Economy	4400.00
0005432799179	14793	Economy	4400.00
0005432799155	14793	Economy	4400.00
0005432799158	14793	Economy	4400.00
0005432799172	14793	Economy	4400.00
0005432799174	14793	Economy	4400.00
0005432799180	14793	Economy	4400.00
0005432799157	14793	Economy	4400.00
0005432799176	14793	Economy	4400.00
0005432799178	14793	Economy	4400.00
0005432799175	14793	Economy	4400.00
0005432799170	14793	Economy	4400.00
0005432799173	14793	Economy	4400.00
0005432799156	14793	Economy	4400.00
0005432799168	14793	Economy	4400.00
0005432799167	14793	Economy	4400.00
0005432799163	14793	Economy	4400.00
0005432799171	14793	Economy	4400.00
0005432799162	14793	Economy	4400.00
0005432799159	14793	Economy	4400.00
0005432799161	14793	Economy	4400.00
0005432799160	14793	Economy	4400.00
0005434299349	7064	Business	49100.00
0005434299351	7064	Business	49100.00
0005434407200	7064	Business	49100.00
0005434407169	7064	Business	49100.00
0005434407197	7064	Business	49100.00
0005434407172	7064	Business	49100.00
0005434299346	7064	Business	49100.00
0005434407166	7064	Business	49100.00
0005434407160	7064	Business	49100.00
0005434299356	7064	Business	49100.00
0005434407163	7064	Business	49100.00
0005434407185	7064	Business	49100.00
0005434407164	7064	Economy	16400.00
0005434299338	7064	Economy	16400.00
0005434407208	7064	Economy	16400.00
0005432153877	7064	Economy	16400.00
0005434407168	7064	Economy	16400.00
0005434407187	7064	Economy	16400.00
0005434407192	7064	Economy	16400.00
0005434299341	7064	Economy	16400.00
0005434407177	7064	Economy	16400.00
0005435310841	7064	Economy	16400.00
0005434407171	7064	Economy	16400.00
0005434299342	7064	Economy	16400.00
0005434407186	7064	Economy	16400.00
0005434407182	7064	Economy	16400.00
0005432153876	7064	Economy	16400.00
0005434299359	7064	Economy	16400.00
0005435310851	7064	Economy	16400.00
0005434407179	7064	Economy	16400.00
0005432153870	7064	Economy	16400.00
0005435310852	7064	Economy	16400.00
0005434407165	7064	Economy	16400.00
0005434407195	7064	Economy	16400.00
0005434407194	7064	Economy	16400.00
0005435310845	7064	Economy	16400.00
0005435310838	7064	Economy	16400.00
0005434299360	7064	Economy	16400.00
0005432153875	7064	Economy	16400.00
0005434299353	7064	Economy	16400.00
0005434407213	7064	Economy	16400.00
0005434299352	7064	Economy	16400.00
0005434299348	7064	Economy	16400.00
0005434407206	7064	Economy	16400.00
0005434299339	7064	Economy	16400.00
0005434407196	7064	Economy	16400.00
0005435310842	7064	Economy	16400.00
0005435310850	7064	Economy	18000.00
0005432153874	7064	Economy	16400.00
0005434407167	7064	Economy	18000.00
0005434407204	7064	Economy	18000.00
0005434407198	7064	Economy	18000.00
0005434407199	7064	Economy	16400.00
0005434407159	7064	Economy	16400.00
0005435310846	7064	Economy	16400.00
0005434407170	7064	Economy	16400.00
0005434407205	7064	Economy	16400.00
0005434407158	7064	Economy	16400.00
0005435293073	7064	Economy	16400.00
0005434407191	7064	Economy	16400.00
0005434299357	7064	Economy	16400.00
0005435293068	7064	Economy	16400.00
0005434407175	7064	Economy	16400.00
0005434407173	7064	Economy	16400.00
0005434407183	7064	Economy	16400.00
0005434407215	7064	Economy	16400.00
0005434407210	7064	Economy	16400.00
0005432153873	7064	Economy	16400.00
0005434299340	7064	Economy	16400.00
0005434407201	7064	Economy	16400.00
0005434407216	7064	Economy	16400.00
0005434299355	7064	Economy	16400.00
0005434407188	7064	Economy	16400.00
0005434299350	7064	Economy	16400.00
0005434407176	7064	Economy	16400.00
0005434299354	7064	Economy	16400.00
0005434407162	7064	Economy	16400.00
0005434407184	7064	Economy	16400.00
0005432108225	7064	Economy	16400.00
0005434407189	7064	Economy	16400.00
0005434407190	7064	Economy	16400.00
0005434407155	7064	Economy	16400.00
0005434407180	7064	Economy	16400.00
0005434407157	7064	Economy	16400.00
0005434407207	7064	Economy	16400.00
0005432153871	7064	Economy	16400.00
0005432153872	7064	Economy	16400.00
0005434299345	7064	Economy	16400.00
0005434407202	7064	Economy	16400.00
0005434407217	7064	Economy	16400.00
0005434299343	7064	Economy	16400.00
0005434407181	7064	Economy	16400.00
0005434407212	7064	Economy	16400.00
0005434299336	7064	Economy	16400.00
0005434299344	7064	Economy	16400.00
0005432108226	7064	Economy	16400.00
0005434299358	7064	Economy	16400.00
0005434407203	7064	Economy	16400.00
0005434299337	7064	Economy	16400.00
0005434407211	7064	Economy	16400.00
0005434407174	7064	Economy	16400.00
0005434407209	7064	Economy	16400.00
0005434299347	7064	Economy	16400.00
0005434407178	7064	Economy	16400.00
0005434407214	7064	Economy	16400.00
0005434407193	7064	Economy	16400.00
0005434407161	7064	Economy	16400.00
0005432108227	7064	Economy	16400.00
0005434407156	7064	Economy	16400.00
0005434406784	26881	Business	49100.00
0005435310943	26881	Business	49100.00
0005434299192	26881	Business	49100.00
0005434406663	26881	Business	49100.00
0005434406783	26881	Business	49100.00
0005434406713	26881	Economy	16400.00
0005434299179	26881	Economy	16400.00
0005435293138	26881	Economy	16400.00
0005435310945	26881	Economy	16400.00
0005434299205	26881	Economy	16400.00
0005435293132	26881	Economy	16400.00
0005434406662	26881	Economy	16400.00
0005435293139	26881	Economy	16400.00
0005435293136	26881	Economy	16400.00
0005434406917	26881	Economy	16400.00
0005435293143	26881	Economy	16400.00
0005434299196	26881	Economy	16400.00
0005434299158	26881	Economy	16400.00
0005435310947	26881	Economy	16400.00
0005434299156	26881	Economy	16400.00
0005434406862	26881	Economy	16400.00
0005434406674	26881	Economy	18000.00
0005434299193	26881	Economy	18000.00
0005435293135	26881	Economy	18000.00
0005434406770	26881	Economy	18000.00
0005435293134	26881	Economy	16400.00
0005434299269	26881	Economy	16400.00
0005434406743	26881	Economy	16400.00
0005434299225	26881	Economy	16400.00
0005434299210	26881	Economy	16400.00
0005435310942	26881	Economy	16400.00
0005432058342	26881	Economy	16400.00
0005434406821	26881	Economy	16400.00
0005435293142	26881	Economy	16400.00
0005434299268	26881	Economy	16400.00
0005434299224	26881	Economy	16400.00
0005434406834	26881	Economy	16400.00
0005435310948	26881	Economy	16400.00
0005435293137	26881	Economy	16400.00
0005434406810	26881	Economy	16400.00
0005435310944	26881	Economy	16400.00
0005434406800	26881	Economy	16400.00
0005434406729	26881	Economy	16400.00
0005435293140	26881	Economy	16400.00
0005432058340	26881	Economy	16400.00
0005434299206	26881	Economy	16400.00
0005435293141	26881	Economy	16400.00
0005435293133	26881	Economy	16400.00
0005432058341	26881	Economy	16400.00
0005432058343	26881	Economy	16400.00
0005434406742	26881	Economy	16400.00
0005434406660	26881	Economy	16400.00
0005434299162	26881	Economy	16400.00
0005435310946	26881	Economy	16400.00
0005435293131	26881	Economy	16400.00
0005434406730	26881	Economy	16400.00
0005434299150	26881	Economy	16400.00
0005434406751	26881	Economy	16400.00
0005432603980	6456	Economy	16500.00
0005432603985	6456	Economy	16500.00
0005435218104	6456	Economy	16500.00
0005432603986	6456	Economy	16500.00
0005432603977	6456	Economy	15000.00
0005432603994	6456	Economy	15000.00
0005434512067	6456	Economy	15000.00
0005432604001	6456	Economy	15000.00
0005432603979	6456	Economy	15000.00
0005434512069	6456	Economy	15000.00
0005432603988	6456	Economy	15000.00
0005432603975	6456	Economy	15000.00
0005432603971	6456	Economy	15000.00
0005432603973	6456	Economy	15000.00
0005432604000	6456	Economy	15000.00
0005432603968	6456	Economy	15000.00
0005432603990	6456	Economy	15000.00
0005432603966	6456	Economy	15000.00
0005432603996	6456	Economy	15000.00
0005434512071	6456	Economy	15000.00
0005432603978	6456	Economy	15000.00
0005432603981	6456	Economy	15000.00
0005432603995	6456	Economy	15000.00
0005432603967	6456	Economy	15000.00
0005434512070	6456	Economy	15000.00
0005432603998	6456	Economy	15000.00
0005432603976	6456	Economy	15000.00
0005434512068	6456	Economy	15000.00
0005432603991	6456	Economy	15000.00
0005432603974	6456	Economy	15000.00
0005432603970	6456	Economy	15000.00
0005432603982	6456	Economy	15000.00
0005432603969	6456	Economy	15000.00
0005432604002	6456	Economy	15000.00
0005432603989	6456	Economy	15000.00
0005432604004	6456	Economy	15000.00
0005432604005	6456	Economy	15000.00
0005432603984	6456	Economy	15000.00
0005432603992	6456	Economy	15000.00
0005432603997	6456	Economy	15000.00
0005434512072	6456	Economy	15000.00
0005432603993	6456	Economy	15000.00
0005432603987	6456	Economy	15000.00
0005432603999	6456	Economy	15000.00
0005432603983	6456	Economy	15000.00
0005432603972	6456	Economy	15000.00
0005432604003	6456	Economy	15000.00
0005432603713	21349	Economy	16500.00
0005432603684	21349	Economy	16500.00
0005432603642	21349	Economy	15000.00
0005434512037	21349	Economy	15000.00
0005434512040	21349	Economy	15000.00
0005432603661	21349	Economy	15000.00
0005432603695	21349	Economy	15000.00
0005432603692	21349	Economy	15000.00
0005435221046	21349	Economy	15000.00
0005435221506	21349	Economy	15000.00
0005432603655	21349	Economy	15000.00
0005434512032	21349	Economy	15000.00
0005432603719	21349	Economy	15000.00
0005432603663	21349	Economy	15000.00
0005432603763	21349	Economy	15000.00
0005432603694	21349	Economy	15000.00
0005432603666	21349	Economy	15000.00
0005432603712	21349	Economy	15000.00
0005432603736	21349	Economy	15000.00
0005435221047	21349	Economy	15000.00
0005435221508	21349	Economy	15000.00
0005434512033	21349	Economy	15000.00
0005432603691	21349	Economy	15000.00
0005434512021	21349	Economy	15000.00
0005435221507	21349	Economy	15000.00
0005432603714	21349	Economy	15000.00
0005434512030	21349	Economy	15000.00
0005434512017	21349	Economy	15000.00
0005434512041	21349	Economy	15000.00
0005432603667	21349	Economy	15000.00
0005433251183	14977	Business	18900.00
0005434906490	14977	Business	18900.00
0005433251182	14977	Business	18900.00
0005434906410	14977	Business	18900.00
0005434906422	14977	Business	18900.00
0005433251205	14977	Business	18900.00
0005433251186	14977	Business	18900.00
0005433251188	14977	Business	18900.00
0005433251206	14977	Economy	6300.00
0005433251209	14977	Economy	6300.00
0005433251201	14977	Economy	6300.00
0005433251210	14977	Economy	6300.00
0005433251194	14977	Economy	6300.00
0005433251184	14977	Economy	6300.00
0005433251196	14977	Economy	6300.00
0005434906397	14977	Economy	6900.00
0005433251187	14977	Economy	6900.00
0005433251185	14977	Economy	6900.00
0005433251189	14977	Economy	6300.00
0005433251211	14977	Economy	6300.00
0005434906403	14977	Economy	6300.00
0005433251202	14977	Economy	6300.00
0005434906526	14977	Economy	6300.00
0005433251193	14977	Economy	6300.00
0005434906444	14977	Economy	6300.00
0005434906525	14977	Economy	6300.00
0005434906559	14977	Economy	6300.00
0005433251192	14977	Economy	6300.00
0005434906376	14977	Economy	6300.00
0005433251190	14977	Economy	6300.00
0005433251197	14977	Economy	6300.00
0005434906400	14977	Economy	6300.00
0005434906560	14977	Economy	6300.00
0005433251200	14977	Economy	6300.00
0005434906433	14977	Economy	6300.00
0005434906524	14977	Economy	6300.00
0005434906373	14977	Economy	6300.00
0005433251198	14977	Economy	6300.00
0005433251203	14977	Economy	6300.00
0005434906381	14977	Economy	6300.00
0005433251199	14977	Economy	6300.00
0005433251195	14977	Economy	6300.00
0005433251204	14977	Economy	6300.00
0005434906428	14977	Economy	6300.00
0005434906374	14977	Economy	6300.00
0005434906366	14977	Economy	6300.00
0005433251191	14977	Economy	6300.00
0005433251181	14977	Economy	6300.00
0005433251207	14977	Economy	6300.00
0005434906421	14977	Economy	6300.00
0005434906423	14977	Economy	6300.00
0005434906375	14977	Economy	6300.00
0005433251208	14977	Economy	6300.00
0005433251180	14977	Economy	6300.00
0005434906558	14977	Economy	6300.00
0005434906427	14977	Economy	6300.00
0005434906793	25873	Business	18900.00
0005434906811	25873	Business	18900.00
0005434906798	25873	Business	18900.00
0005434906801	25873	Business	18900.00
0005434906807	25873	Business	18900.00
0005434906796	25873	Business	18900.00
0005434906782	25873	Business	18900.00
0005434906771	25873	Business	18900.00
0005434906759	25873	Business	18900.00
0005434906775	25873	Business	18900.00
0005434906757	25873	Economy	6300.00
0005434906809	25873	Economy	6300.00
0005433251074	25873	Economy	6300.00
0005434906768	25873	Economy	6300.00
0005434906758	25873	Economy	6300.00
0005434906774	25873	Economy	6300.00
0005434906756	25873	Economy	6300.00
0005434906778	25873	Economy	6300.00
0005434906770	25873	Economy	6300.00
0005434906803	25873	Economy	6300.00
0005434906794	25873	Economy	6900.00
0005434906779	25873	Economy	6900.00
0005434906813	25873	Economy	6900.00
0005433250995	25873	Economy	6900.00
0005433250932	25873	Economy	6900.00
0005433251018	25873	Economy	6300.00
0005433251068	25873	Economy	6300.00
0005434906750	25873	Economy	6300.00
0005434906755	25873	Economy	6300.00
0005434906804	25873	Economy	6300.00
0005434906772	25873	Economy	6300.00
0005434906783	25873	Economy	6300.00
0005434906764	25873	Economy	6300.00
0005434906792	25873	Economy	6300.00
0005434906806	25873	Economy	6300.00
0005434906788	25873	Economy	6300.00
0005434906773	25873	Economy	6300.00
0005434906797	25873	Economy	6300.00
0005434906800	25873	Economy	6300.00
0005434906787	25873	Economy	6300.00
0005433251093	25873	Economy	6300.00
0005434906751	25873	Economy	6300.00
0005433250931	25873	Economy	6300.00
0005434906761	25873	Economy	6300.00
0005434906791	25873	Economy	6300.00
0005434906776	25873	Economy	6300.00
0005434906766	25873	Economy	6300.00
0005433250969	25873	Economy	6300.00
0005434906790	25873	Economy	6300.00
0005434906760	25873	Economy	6300.00
0005434906767	25873	Economy	6300.00
0005434906810	25873	Economy	6300.00
0005434906780	25873	Economy	6300.00
0005433250929	25873	Economy	6300.00
0005434906769	25873	Economy	6300.00
0005434906777	25873	Economy	6300.00
0005434906753	25873	Economy	6300.00
0005434906786	25873	Economy	6300.00
0005433250935	25873	Economy	6300.00
0005434906795	25873	Economy	6300.00
0005433251009	25873	Economy	6300.00
0005433250996	25873	Economy	6300.00
0005434906762	25873	Economy	6300.00
0005434906802	25873	Economy	6300.00
0005434906789	25873	Economy	6300.00
0005434906781	25873	Economy	6300.00
0005434906799	25873	Economy	6300.00
0005434906784	25873	Economy	6300.00
0005433251067	25873	Economy	6300.00
0005434906763	25873	Economy	6300.00
0005433250930	25873	Economy	6300.00
0005434906805	25873	Economy	6300.00
0005433251010	25873	Economy	6300.00
0005434906808	25873	Economy	6300.00
0005434906812	25873	Economy	6300.00
0005434906765	25873	Economy	6300.00
0005434906785	25873	Economy	6300.00
0005433250970	25873	Economy	6300.00
0005434906752	25873	Economy	6300.00
0005434906754	25873	Economy	6300.00
0005433008198	14166	Business	52300.00
0005433008197	14166	Business	52300.00
0005433008231	14166	Business	52300.00
0005433008232	14166	Business	52300.00
0005433008208	14166	Business	52300.00
0005433008235	14166	Business	52300.00
0005433008228	14166	Business	52300.00
0005433008205	14166	Economy	17400.00
0005433008215	14166	Economy	17400.00
0005433008201	14166	Economy	17400.00
0005433008203	14166	Economy	17400.00
0005433008220	14166	Economy	19200.00
0005433008200	14166	Economy	19200.00
0005433008225	14166	Economy	19200.00
0005433008236	14166	Economy	17400.00
0005433008210	14166	Economy	17400.00
0005433008227	14166	Economy	17400.00
0005433008233	14166	Economy	17400.00
0005433008226	14166	Economy	17400.00
0005433008219	14166	Economy	17400.00
0005433008214	14166	Economy	17400.00
0005433008238	14166	Economy	17400.00
0005433008221	14166	Economy	17400.00
0005433008218	14166	Economy	17400.00
0005433008194	14166	Economy	17400.00
0005433008199	14166	Economy	17400.00
0005433008213	14166	Economy	17400.00
0005433008212	14166	Economy	17400.00
0005433008211	14166	Economy	17400.00
0005433008217	14166	Economy	17400.00
0005433008216	14166	Economy	17400.00
0005433008206	14166	Economy	17400.00
0005433008195	14166	Economy	17400.00
0005433008237	14166	Economy	17400.00
0005433008202	14166	Economy	17400.00
0005433008209	14166	Economy	17400.00
0005433008239	14166	Economy	17400.00
0005433008224	14166	Economy	17400.00
0005433008223	14166	Economy	17400.00
0005433008229	14166	Economy	17400.00
0005433008230	14166	Economy	17400.00
0005433008207	14166	Economy	17400.00
0005433008196	14166	Economy	17400.00
0005433008204	14166	Economy	17400.00
0005433008222	14166	Economy	17400.00
0005433008234	14166	Economy	17400.00
0005433007899	22835	Business	52300.00
0005433007929	22835	Economy	17400.00
0005433007987	22835	Economy	17400.00
0005433007834	22835	Economy	19200.00
0005433007848	22835	Economy	17400.00
0005433007876	22835	Economy	17400.00
0005433007847	22835	Economy	17400.00
0005433007875	22835	Economy	17400.00
0005433007910	22835	Economy	17400.00
0005433007860	22835	Economy	17400.00
0005433007911	22835	Economy	17400.00
0005433007868	22835	Economy	17400.00
0005433007822	22835	Economy	17400.00
0005433008006	22835	Economy	17400.00
0005433007877	22835	Economy	17400.00
0005433007985	22835	Economy	17400.00
0005433007986	22835	Economy	17400.00
0005435718864	15518	Business	85200.00
0005435718871	15518	Business	85200.00
0005435718870	15518	Business	85200.00
0005435718836	15518	Business	85200.00
0005435718868	15518	Business	85200.00
0005435718879	15518	Business	85200.00
0005435718847	15518	Business	85200.00
0005435718859	15518	Economy	28400.00
0005435718865	15518	Economy	28400.00
0005435718866	15518	Economy	28400.00
0005435718858	15518	Economy	28400.00
0005435718845	15518	Economy	28400.00
0005435718882	15518	Economy	31200.00
0005435718842	15518	Economy	31200.00
0005435718881	15518	Economy	28400.00
0005435718832	15518	Economy	28400.00
0005435718872	15518	Economy	28400.00
0005435718862	15518	Economy	28400.00
0005435718837	15518	Economy	28400.00
0005435718873	15518	Economy	28400.00
0005435718840	15518	Economy	28400.00
0005435718851	15518	Economy	28400.00
0005435718850	15518	Economy	28400.00
0005435718846	15518	Economy	28400.00
0005435718833	15518	Economy	28400.00
0005435718878	15518	Economy	28400.00
0005435718841	15518	Economy	28400.00
0005435718875	15518	Economy	28400.00
0005435718839	15518	Economy	28400.00
0005435718838	15518	Economy	28400.00
0005435718852	15518	Economy	28400.00
0005435718877	15518	Economy	28400.00
0005435718835	15518	Economy	28400.00
0005435718861	15518	Economy	28400.00
0005435718863	15518	Economy	28400.00
0005435718880	15518	Economy	28400.00
0005435718874	15518	Economy	28400.00
0005435718876	15518	Economy	28400.00
0005435718848	15518	Economy	28400.00
0005435718884	15518	Economy	28400.00
0005435718844	15518	Economy	28400.00
0005435718883	15518	Economy	28400.00
0005435718857	15518	Economy	28400.00
0005435718860	15518	Economy	28400.00
0005435718853	15518	Economy	28400.00
0005435718869	15518	Economy	28400.00
0005435718849	15518	Economy	28400.00
0005435718834	15518	Economy	28400.00
0005435718855	15518	Economy	28400.00
0005435718854	15518	Economy	28400.00
0005435718856	15518	Economy	28400.00
0005435718843	15518	Economy	28400.00
0005435718867	15518	Economy	28400.00
0005434925502	20527	Business	22900.00
0005434925489	20527	Business	22900.00
0005434925478	20527	Business	22900.00
0005434925476	20527	Business	22900.00
0005434925487	20527	Business	22900.00
0005434925493	20527	Business	22900.00
0005434925485	20527	Business	22900.00
0005434925482	20527	Economy	7600.00
0005434925486	20527	Economy	7600.00
0005434925498	20527	Economy	8400.00
0005434925495	20527	Economy	8400.00
0005434925483	20527	Economy	7600.00
0005434925492	20527	Economy	7600.00
0005434925475	20527	Economy	7600.00
0005434925481	20527	Economy	7600.00
0005434925479	20527	Economy	7600.00
0005434925490	20527	Economy	7600.00
0005434925484	20527	Economy	7600.00
0005434925488	20527	Economy	7600.00
0005434925499	20527	Economy	7600.00
0005434925500	20527	Economy	7600.00
0005434925501	20527	Economy	7600.00
0005434925494	20527	Economy	7600.00
0005434925497	20527	Economy	7600.00
0005434925474	20527	Economy	7600.00
0005434925491	20527	Economy	7600.00
0005434925480	20527	Economy	7600.00
0005434925477	20527	Economy	7600.00
0005434925496	20527	Economy	7600.00
0005435487645	15812	Economy	8900.00
0005435998966	15812	Economy	8100.00
0005435998962	15812	Economy	8100.00
0005435487646	15812	Economy	8100.00
0005435487651	15812	Economy	8100.00
0005435487635	15812	Economy	8100.00
0005435487650	15812	Economy	8100.00
0005435487637	15812	Economy	8100.00
0005435487642	15812	Economy	8100.00
0005435998967	15812	Economy	8100.00
0005435487633	15812	Economy	8100.00
0005435998976	15812	Economy	8100.00
0005435487641	15812	Economy	8100.00
0005435487648	15812	Economy	8100.00
0005435487638	15812	Economy	8100.00
0005435487649	15812	Economy	8100.00
0005435487639	15812	Economy	8100.00
0005435487644	15812	Economy	8100.00
0005435487640	15812	Economy	8100.00
0005435487634	15812	Economy	8100.00
0005435487631	15812	Economy	8100.00
0005435487652	15812	Economy	8100.00
0005435487632	15812	Economy	8100.00
0005435998969	15812	Economy	8100.00
0005435487643	15812	Economy	8100.00
0005435487636	15812	Economy	8100.00
0005435487647	15812	Economy	8100.00
0005435999069	19678	Economy	8900.00
0005435999084	19678	Economy	8900.00
0005435999075	19678	Economy	8900.00
0005435999091	19678	Economy	8900.00
0005435999083	19678	Economy	8100.00
0005435999081	19678	Economy	8100.00
0005435999093	19678	Economy	8100.00
0005435999080	19678	Economy	8100.00
0005435999085	19678	Economy	8100.00
0005435999090	19678	Economy	8100.00
0005435487461	19678	Economy	8100.00
0005435999071	19678	Economy	8100.00
0005435487468	19678	Economy	8100.00
0005435999086	19678	Economy	8100.00
0005435999078	19678	Economy	8100.00
0005435999077	19678	Economy	8100.00
0005435999082	19678	Economy	8100.00
0005435999092	19678	Economy	8100.00
0005435999070	19678	Economy	8100.00
0005435999076	19678	Economy	8100.00
0005435999087	19678	Economy	8100.00
0005435999073	19678	Economy	8100.00
0005435999072	19678	Economy	8100.00
0005435999079	19678	Economy	8100.00
0005435999074	19678	Economy	8100.00
0005435999088	19678	Economy	8100.00
0005435999089	19678	Economy	8100.00
0005435839215	6012	Business	199300.00
0005435839211	6012	Business	199300.00
0005435839189	6012	Business	199300.00
0005435839201	6012	Business	199300.00
0005435839206	6012	Business	199300.00
0005435839203	6012	Business	199300.00
0005435472582	6012	Business	199300.00
0005432660800	6012	Economy	66400.00
0005435472527	6012	Economy	66400.00
0005435839200	6012	Economy	66400.00
0005432142224	6012	Economy	66400.00
0005435839208	6012	Economy	73100.00
0005432659689	6012	Economy	66400.00
0005432660799	6012	Economy	66400.00
0005435839205	6012	Economy	66400.00
0005435839197	6012	Economy	66400.00
0005435839194	6012	Economy	66400.00
0005432658574	6012	Economy	66400.00
0005435839202	6012	Economy	66400.00
0005435839217	6012	Economy	66400.00
0005435839193	6012	Economy	66400.00
0005435839204	6012	Economy	66400.00
0005435839190	6012	Economy	66400.00
0005435839199	6012	Economy	66400.00
0005435839216	6012	Economy	66400.00
0005432142222	6012	Economy	66400.00
0005435839209	6012	Economy	66400.00
0005435839212	6012	Economy	66400.00
0005435472534	6012	Economy	66400.00
0005435472528	6012	Economy	66400.00
0005435839198	6012	Economy	66400.00
0005432658573	6012	Economy	66400.00
0005435839214	6012	Economy	66400.00
0005432142226	6012	Economy	66400.00
0005432142223	6012	Economy	66400.00
0005432658575	6012	Economy	66400.00
0005435839213	6012	Economy	66400.00
0005435839196	6012	Economy	66400.00
0005435839192	6012	Economy	66400.00
0005435839207	6012	Economy	66400.00
0005435839188	6012	Economy	66400.00
0005432660801	6012	Economy	66400.00
0005432658572	6012	Economy	66400.00
0005435839210	6012	Economy	66400.00
0005435839191	6012	Economy	66400.00
0005435839195	6012	Economy	66400.00
0005432142225	6012	Economy	66400.00
0005432537041	18058	Business	199300.00
0005435472655	18058	Business	199300.00
0005435472652	18058	Business	199300.00
0005435839111	18058	Business	199300.00
0005435472654	18058	Business	199300.00
0005435838975	18058	Business	199300.00
0005435472659	18058	Economy	66400.00
0005435838976	18058	Economy	66400.00
0005435838998	18058	Economy	66400.00
0005435838963	18058	Economy	66400.00
0005435472661	18058	Economy	66400.00
0005435472656	18058	Economy	73100.00
0005435472657	18058	Economy	73100.00
0005435472662	18058	Economy	73100.00
0005435472646	18058	Economy	66400.00
0005435839023	18058	Economy	66400.00
0005435472651	18058	Economy	66400.00
0005432537039	18058	Economy	66400.00
0005435839022	18058	Economy	66400.00
0005435472660	18058	Economy	66400.00
0005435838999	18058	Economy	66400.00
0005435472648	18058	Economy	66400.00
0005435472649	18058	Economy	66400.00
0005435839067	18058	Economy	66400.00
0005435838988	18058	Economy	66400.00
0005432537040	18058	Economy	66400.00
0005435838989	18058	Economy	66400.00
0005435839069	18058	Economy	66400.00
0005435472650	18058	Economy	66400.00
0005435839068	18058	Economy	66400.00
0005435472647	18058	Economy	66400.00
0005435839001	18058	Economy	66400.00
0005435839033	18058	Economy	66400.00
0005435472653	18058	Economy	66400.00
0005435472658	18058	Economy	66400.00
0005433284775	23041	Business	15700.00
0005433284816	23041	Business	15700.00
0005435103857	23041	Business	15700.00
0005433284948	23041	Economy	5200.00
0005433284856	23041	Economy	5200.00
0005435103858	23041	Economy	5200.00
0005435103853	23041	Economy	5200.00
0005433284829	23041	Economy	5200.00
0005433284774	23041	Economy	5200.00
0005435103861	23041	Economy	5200.00
0005435103860	23041	Economy	5200.00
0005433284855	23041	Economy	5200.00
0005433284788	23041	Economy	5200.00
0005433284792	23041	Economy	5700.00
0005435103854	23041	Economy	5200.00
0005433284859	23041	Economy	5200.00
0005435103855	23041	Economy	5200.00
0005435103856	23041	Economy	5200.00
0005433284865	23041	Economy	5200.00
0005433284785	23041	Economy	5200.00
0005433284807	23041	Economy	5200.00
0005433284817	23041	Economy	5200.00
0005433284878	23041	Economy	5200.00
0005433284877	23041	Economy	5200.00
0005433284808	23041	Economy	5200.00
0005435103859	23041	Economy	5200.00
0005433285020	32057	Business	15700.00
0005433285028	32057	Business	15700.00
0005433285022	32057	Business	15700.00
0005433285036	32057	Economy	5200.00
0005433285025	32057	Economy	5200.00
0005433285024	32057	Economy	5200.00
0005433285029	32057	Economy	5200.00
0005433285012	32057	Economy	5200.00
0005433285013	32057	Economy	5200.00
0005433285030	32057	Economy	5200.00
0005433285019	32057	Economy	5200.00
0005433285031	32057	Economy	5200.00
0005433285017	32057	Economy	5700.00
0005433285034	32057	Economy	5700.00
0005433285032	32057	Economy	5200.00
0005433285016	32057	Economy	5200.00
0005433285014	32057	Economy	5200.00
0005433285038	32057	Economy	5200.00
0005433285027	32057	Economy	5200.00
0005433285011	32057	Economy	5200.00
0005433285015	32057	Economy	5200.00
0005433285035	32057	Economy	5200.00
0005433285008	32057	Economy	5200.00
0005433285023	32057	Economy	5200.00
0005433285009	32057	Economy	5200.00
0005433285033	32057	Economy	5200.00
0005433285018	32057	Economy	5200.00
0005433285007	32057	Economy	5200.00
0005433285021	32057	Economy	5200.00
0005433285026	32057	Economy	5200.00
0005433285037	32057	Economy	5200.00
0005433285010	32057	Economy	5200.00
0005432802456	1479	Business	150400.00
0005432802449	1479	Business	150400.00
0005432802454	1479	Business	150400.00
0005432802457	1479	Business	150400.00
0005432802464	1479	Business	150400.00
0005432802465	1479	Business	150400.00
0005432892719	1479	Economy	50100.00
0005432802438	1479	Economy	50100.00
0005432802461	1479	Economy	50100.00
0005432802460	1479	Economy	50100.00
0005432802443	1479	Economy	50100.00
0005432802462	1479	Economy	50100.00
0005432802466	1479	Economy	50100.00
0005432802437	1479	Economy	50100.00
0005432802450	1479	Economy	50100.00
0005432802448	1479	Economy	50100.00
0005432802446	1479	Economy	50100.00
0005432802447	1479	Economy	50100.00
0005432802453	1479	Economy	50100.00
0005432802439	1479	Economy	50100.00
0005432802445	1479	Economy	50100.00
0005432802455	1479	Economy	50100.00
0005432802440	1479	Economy	50100.00
0005432802458	1479	Economy	50100.00
0005432802459	1479	Economy	50100.00
0005432802436	1479	Economy	50100.00
0005432802442	1479	Economy	50100.00
0005432802467	1479	Economy	50100.00
0005432802452	1479	Economy	50100.00
0005432802441	1479	Economy	50100.00
0005432802444	1479	Economy	50100.00
0005432802463	1479	Economy	50100.00
0005432802451	1479	Economy	50100.00
0005435852545	23867	Economy	12300.00
0005433475636	23867	Economy	12300.00
0005435852551	23867	Economy	12300.00
0005435852547	23867	Economy	12300.00
0005433475632	23867	Economy	12300.00
0005435852552	23867	Economy	12300.00
0005435852544	23867	Economy	12300.00
0005433475633	23867	Economy	12300.00
0005435852548	23867	Economy	12300.00
0005435852549	23867	Economy	12300.00
0005435852546	23867	Economy	12300.00
0005435852550	23867	Economy	12300.00
0005432525686	30598	Business	42100.00
0005435212970	30598	Business	42100.00
0005432525807	30598	Business	42100.00
0005432525926	30598	Business	42100.00
0005435725558	30598	Business	42100.00
0005432525762	30598	Business	42100.00
0005435212969	30598	Business	42100.00
0005432526039	30598	Business	42100.00
0005432526276	30598	Business	42100.00
0005434066432	30598	Business	42100.00
0005435212958	30598	Business	42100.00
0005435212964	30598	Business	42100.00
0005435213005	30598	Business	42100.00
0005432525975	30598	Business	42100.00
0005432526838	30598	Business	42100.00
0005432525991	30598	Business	42100.00
0005432525900	30598	Business	42100.00
0005432525822	30598	Business	42100.00
0005435212977	30598	Comfort	23900.00
0005432535763	30598	Business	42100.00
0005432526297	30598	Comfort	23900.00
0005434066438	30598	Comfort	23900.00
0005432525918	30598	Comfort	23900.00
0005432525806	30598	Comfort	23900.00
0005435212985	30598	Comfort	23900.00
0005432526162	30598	Comfort	23900.00
0005435212994	30598	Comfort	23900.00
0005432159820	30598	Comfort	23900.00
0005434066369	30598	Comfort	23900.00
0005432525821	30598	Comfort	23900.00
0005432525880	30598	Comfort	23900.00
0005435213004	30598	Comfort	23900.00
0005432525964	30598	Comfort	23900.00
0005432526003	30598	Comfort	23900.00
0005435213002	30598	Comfort	23900.00
0005435213003	30598	Comfort	23900.00
0005432525925	30598	Comfort	23900.00
0005432525878	30598	Comfort	23900.00
0005432525647	30598	Comfort	23900.00
0005432525764	30598	Comfort	23900.00
0005435630943	30598	Comfort	23900.00
0005432525737	30598	Comfort	23900.00
0005435212992	30598	Comfort	23900.00
0005435212989	30598	Comfort	23900.00
0005434066320	30598	Comfort	23900.00
0005432525768	30598	Comfort	23900.00
0005432526165	30598	Comfort	23900.00
0005432525852	30598	Comfort	23900.00
0005432525999	30598	Comfort	23900.00
0005432525790	30598	Comfort	23900.00
0005434066346	30598	Comfort	23900.00
0005435213019	30598	Comfort	23900.00
0005432526224	30598	Comfort	23900.00
0005435213015	30598	Economy	14000.00
0005432211437	30598	Economy	14000.00
0005435212965	30598	Economy	14000.00
0005434066352	30598	Economy	14000.00
0005435212981	30598	Economy	14000.00
0005432525733	30598	Economy	14000.00
0005432526208	30598	Economy	14000.00
0005432525879	30598	Economy	14000.00
0005432526013	30598	Economy	14000.00
0005435213008	30598	Economy	14000.00
0005435213007	30598	Economy	14000.00
0005434066491	30598	Economy	14000.00
0005432525919	30598	Economy	14000.00
0005432525815	30598	Economy	14000.00
0005435212962	30598	Economy	14000.00
0005435212973	30598	Economy	14000.00
0005435212995	30598	Economy	14000.00
0005432525789	30598	Economy	14000.00
0005432526199	30598	Economy	14000.00
0005435213010	30598	Economy	14000.00
0005432211441	30598	Economy	14000.00
0005435212999	30598	Economy	14000.00
0005432525715	30598	Economy	14000.00
0005435212986	30598	Economy	14000.00
0005435212974	30598	Economy	14000.00
0005432525973	30598	Economy	14000.00
0005432526146	30598	Economy	14000.00
0005432525966	30598	Economy	14000.00
0005432526079	30598	Economy	14000.00
0005433656643	30598	Economy	14000.00
0005432525986	30598	Economy	14000.00
0005434066468	30598	Economy	14000.00
0005432211440	30598	Economy	14000.00
0005432525931	30598	Economy	14000.00
0005433656644	30598	Economy	14000.00
0005432525913	30598	Economy	14000.00
0005434066387	30598	Economy	14000.00
0005435213012	30598	Economy	14000.00
0005435212956	30598	Economy	14000.00
0005432526083	30598	Economy	14000.00
0005435212963	30598	Economy	14000.00
0005435213000	30598	Economy	14000.00
0005434066449	30598	Economy	14000.00
0005435212959	30598	Economy	14000.00
0005432525805	30598	Economy	15400.00
0005432525873	30598	Economy	14000.00
0005435212990	30598	Economy	15400.00
0005432525965	30598	Economy	14000.00
0005432526145	30598	Economy	14000.00
0005432526000	30598	Economy	15400.00
0005432525892	30598	Economy	14000.00
0005435212967	30598	Economy	14000.00
0005432535765	30598	Economy	14000.00
0005432535749	30598	Economy	14000.00
0005435213017	30598	Economy	14000.00
0005432525717	30598	Economy	14000.00
0005435212984	30598	Economy	14000.00
0005432525985	30598	Economy	14000.00
0005432525984	30598	Economy	14000.00
0005432526557	30598	Economy	14000.00
0005432211438	30598	Economy	14000.00
0005434066309	30598	Economy	14000.00
0005432525666	30598	Economy	14000.00
0005435212979	30598	Economy	14000.00
0005432526839	30598	Economy	14000.00
0005432526257	30598	Economy	14000.00
0005432525710	30598	Economy	14000.00
0005435725560	30598	Economy	14000.00
0005432525667	30598	Economy	14000.00
0005435212982	30598	Economy	14000.00
0005432525700	30598	Economy	14000.00
0005434066410	30598	Economy	14000.00
0005432526084	30598	Economy	14000.00
0005432525714	30598	Economy	14000.00
0005432525868	30598	Economy	14000.00
0005432525699	30598	Economy	14000.00
0005432211439	30598	Economy	14000.00
0005432525869	30598	Economy	14000.00
0005435212998	30598	Economy	14000.00
0005432525908	30598	Economy	14000.00
0005434066504	30598	Economy	14000.00
0005434066388	30598	Economy	14000.00
0005435213016	30598	Economy	14000.00
0005435213006	30598	Economy	14000.00
0005434066303	30598	Economy	14000.00
0005432525765	30598	Economy	14000.00
0005432525824	30598	Economy	14000.00
0005435213013	30598	Economy	14000.00
0005435212954	30598	Economy	14000.00
0005432525838	30598	Economy	14000.00
0005432526014	30598	Economy	14000.00
0005435213011	30598	Economy	14000.00
0005434066413	30598	Economy	14000.00
0005434066548	30598	Economy	14000.00
0005432526288	30598	Economy	14000.00
0005435212955	30598	Economy	14000.00
0005435213001	30598	Economy	14000.00
0005432525788	30598	Economy	14000.00
0005435212960	30598	Economy	14000.00
0005432533240	30598	Economy	14000.00
0005434066653	30598	Economy	14000.00
0005432526428	30598	Economy	14000.00
0005435212957	30598	Economy	14000.00
0005435725561	30598	Economy	14000.00
0005435212971	30598	Economy	14000.00
0005432526005	30598	Economy	14000.00
0005432525907	30598	Economy	14000.00
0005435212997	30598	Economy	14000.00
0005434066295	30598	Economy	14000.00
0005432525950	30598	Economy	14000.00
0005432526075	30598	Economy	14000.00
0005435213020	30598	Economy	14000.00
0005432535750	30598	Economy	14000.00
0005432526002	30598	Economy	14000.00
0005432525848	30598	Economy	14000.00
0005435212988	30598	Economy	14000.00
0005434066345	30598	Economy	14000.00
0005432525755	30598	Economy	14000.00
0005434066368	30598	Economy	14000.00
0005435212983	30598	Economy	14000.00
0005434066430	30598	Economy	14000.00
0005434066342	30598	Economy	15400.00
0005432211436	30598	Economy	15400.00
0005434066318	30598	Economy	15400.00
0005432525836	30598	Economy	15400.00
0005432535762	30598	Economy	14000.00
0005435212991	30598	Economy	14000.00
0005432525819	30598	Economy	14000.00
0005432525948	30598	Economy	14000.00
0005432525976	30598	Economy	14000.00
0005432526004	30598	Economy	14000.00
0005435213014	30598	Economy	14000.00
0005432526023	30598	Economy	14000.00
0005432525736	30598	Economy	14000.00
0005432159818	30598	Economy	14000.00
0005432525917	30598	Economy	14000.00
0005432526001	30598	Economy	14000.00
0005435212993	30598	Economy	14000.00
0005432526213	30598	Economy	14000.00
0005435630942	30598	Economy	14000.00
0005432525990	30598	Economy	14000.00
0005435725559	30598	Economy	14000.00
0005432535757	30598	Economy	14000.00
0005432525750	30598	Economy	14000.00
0005432525853	30598	Economy	14000.00
0005435213018	30598	Economy	14000.00
0005432525751	30598	Economy	14000.00
0005434066317	30598	Economy	14000.00
0005434066412	30598	Economy	14000.00
0005432525932	30598	Economy	14000.00
0005432525818	30598	Economy	14000.00
0005432525837	30598	Economy	14000.00
0005434066341	30598	Economy	14000.00
0005434066439	30598	Economy	14000.00
0005432526563	30598	Economy	14000.00
0005432526030	30598	Economy	14000.00
0005432526368	30598	Economy	14000.00
0005432526315	30598	Economy	14000.00
0005434066761	30598	Economy	14000.00
0005432525756	30598	Economy	14000.00
0005435630941	30598	Economy	14000.00
0005435212953	30598	Economy	14000.00
0005435212978	30598	Economy	14000.00
0005434066296	30598	Economy	14000.00
0005435212987	30598	Economy	14000.00
0005432525646	30598	Economy	14000.00
0005432525899	30598	Economy	14000.00
0005432525884	30598	Economy	14000.00
0005435213009	30598	Economy	14000.00
0005435212996	30598	Economy	14000.00
0005432535764	30598	Economy	14000.00
0005432525816	30598	Economy	14000.00
0005434066450	30598	Economy	14000.00
0005435725557	30598	Economy	14000.00
0005435212966	30598	Economy	14000.00
0005435212976	30598	Economy	14000.00
0005433656642	30598	Economy	14000.00
0005432525823	30598	Economy	14000.00
0005432535756	30598	Economy	14000.00
0005432525683	30598	Economy	14000.00
0005434066319	30598	Economy	14000.00
0005432526427	30598	Economy	14000.00
0005432526031	30598	Economy	14000.00
0005435212980	30598	Economy	14000.00
0005432159819	30598	Economy	14000.00
0005435212961	30598	Economy	14000.00
0005435212972	30598	Economy	14000.00
0005432525888	30598	Economy	14000.00
0005432526131	30598	Economy	14000.00
0005432525943	30598	Economy	14000.00
0005434066579	30598	Economy	14000.00
0005432526009	30598	Economy	14000.00
0005432525749	30598	Economy	14000.00
0005432525947	30598	Economy	14000.00
0005434066340	30598	Economy	14000.00
0005434066411	30598	Economy	14000.00
0005435212968	30598	Economy	14000.00
0005435212975	30598	Economy	14000.00
0005432525914	30598	Economy	14000.00
0005432525716	30598	Economy	14000.00
0005434066503	30598	Economy	14000.00
0005435212952	30598	Economy	14000.00
0005433367575	24858	Business	9800.00
0005435652328	24858	Business	9800.00
0005433367580	24858	Business	9800.00
0005433367579	24858	Business	9800.00
0005435652327	24858	Business	9800.00
0005435652289	24858	Business	9800.00
0005435652262	24858	Business	9800.00
0005433367590	24858	Business	9800.00
0005435652263	24858	Business	9800.00
0005433367568	24858	Economy	3300.00
0005433367594	24858	Economy	3300.00
0005433367587	24858	Economy	3300.00
0005433367601	24858	Economy	3300.00
0005435652356	24858	Economy	3300.00
0005433367577	24858	Economy	3300.00
0005435652290	24858	Economy	3600.00
0005433367566	24858	Economy	3600.00
0005435652374	24858	Economy	3600.00
0005433367586	24858	Economy	3300.00
0005435652345	24858	Economy	3300.00
0005433367581	24858	Economy	3300.00
0005433367578	24858	Economy	3300.00
0005433367596	24858	Economy	3300.00
0005433367569	24858	Economy	3300.00
0005433367600	24858	Economy	3300.00
0005433367570	24858	Economy	3300.00
0005435652271	24858	Economy	3300.00
0005435652279	24858	Economy	3300.00
0005435652295	24858	Economy	3300.00
0005435652254	24858	Economy	3300.00
0005435652323	24858	Economy	3300.00
0005435652355	24858	Economy	3300.00
0005435652273	24858	Economy	3300.00
0005433367565	24858	Economy	3300.00
0005435652373	24858	Economy	3300.00
0005433367582	24858	Economy	3300.00
0005435652272	24858	Economy	3300.00
0005435652354	24858	Economy	3300.00
0005435652274	24858	Economy	3300.00
0005433367584	24858	Economy	3300.00
0005433367593	24858	Economy	3300.00
0005433367591	24858	Economy	3300.00
0005433367567	24858	Economy	3300.00
0005433367598	24858	Economy	3300.00
0005433367585	24858	Economy	3300.00
0005433367564	24858	Economy	3300.00
0005433367592	24858	Economy	3300.00
0005433367573	24858	Economy	3300.00
0005433367574	24858	Economy	3300.00
0005433367589	24858	Economy	3300.00
0005433367588	24858	Economy	3300.00
0005433367576	24858	Economy	3300.00
0005433367571	24858	Economy	3300.00
0005433367599	24858	Economy	3300.00
0005433367583	24858	Economy	3300.00
0005433367572	24858	Economy	3300.00
0005433367597	24858	Economy	3300.00
0005435652280	24858	Economy	3300.00
0005433367595	24858	Economy	3300.00
0005434979546	2034	Economy	10500.00
0005434979555	2034	Economy	10500.00
0005434979557	2034	Economy	10500.00
0005434979539	2034	Economy	10500.00
0005435801671	2034	Economy	9500.00
0005434979556	2034	Economy	9500.00
0005435801669	2034	Economy	9500.00
0005434979530	2034	Economy	9500.00
0005434979542	2034	Economy	9500.00
0005434979554	2034	Economy	9500.00
0005434979529	2034	Economy	9500.00
0005434979549	2034	Economy	9500.00
0005434979548	2034	Economy	9500.00
0005434979538	2034	Economy	9500.00
0005434979536	2034	Economy	9500.00
0005434979550	2034	Economy	9500.00
0005434979553	2034	Economy	9500.00
0005434979537	2034	Economy	9500.00
0005434979543	2034	Economy	9500.00
0005434979532	2034	Economy	9500.00
0005434979551	2034	Economy	9500.00
0005434979558	2034	Economy	9500.00
0005434979552	2034	Economy	9500.00
0005434979547	2034	Economy	9500.00
0005434979544	2034	Economy	9500.00
0005434979531	2034	Economy	9500.00
0005434979533	2034	Economy	9500.00
0005434979535	2034	Economy	9500.00
0005434979545	2034	Economy	9500.00
0005434979559	2034	Economy	9500.00
0005434979541	2034	Economy	9500.00
0005435801670	2034	Economy	9500.00
0005434979534	2034	Economy	9500.00
0005434979540	2034	Economy	9500.00
0005434979313	23561	Economy	10500.00
0005435801646	23561	Economy	10500.00
0005434979301	23561	Economy	9500.00
0005434979325	23561	Economy	9500.00
0005434979300	23561	Economy	9500.00
0005434979298	23561	Economy	9500.00
0005434979396	23561	Economy	9500.00
0005434979296	23561	Economy	9500.00
0005435801643	23561	Economy	9500.00
0005434979297	23561	Economy	9500.00
0005434952499	2560	Economy	5300.00
0005434952501	2560	Economy	5300.00
0005434952500	2560	Economy	5300.00
0005433256403	28297	Economy	5300.00
0005433256404	28297	Economy	5300.00
0005434952471	28297	Economy	5300.00
0005433256402	28297	Economy	5300.00
0005434952472	28297	Economy	5300.00
0005433111489	19802	Economy	8700.00
0005433112362	19802	Economy	8700.00
0005434136732	11945	Business	9700.00
0005434136708	11945	Business	9700.00
0005434136693	11945	Business	9700.00
0005434136707	11945	Business	9700.00
0005434136763	11945	Business	9700.00
0005434136830	11945	Business	9700.00
0005434136792	11945	Business	9700.00
0005434136879	11945	Economy	3200.00
0005434136714	11945	Economy	3200.00
0005434136710	11945	Economy	3200.00
0005434136799	11945	Economy	3200.00
0005434136924	11945	Economy	3200.00
0005434136930	11945	Economy	3200.00
0005434136771	11945	Economy	3200.00
0005434136704	11945	Economy	3500.00
0005434136867	11945	Economy	3500.00
0005434136703	11945	Economy	3500.00
0005434136797	11945	Economy	3500.00
0005434136711	11945	Economy	3200.00
0005434136756	11945	Economy	3200.00
0005434136731	11945	Economy	3200.00
0005434136712	11945	Economy	3200.00
0005434136815	11945	Economy	3200.00
0005434136841	11945	Economy	3200.00
0005434136745	11945	Economy	3200.00
0005434136916	11945	Economy	3200.00
0005434136866	11945	Economy	3200.00
0005434136835	11945	Economy	3200.00
0005434136691	11945	Economy	3200.00
0005434136681	11945	Economy	3200.00
0005434136746	11945	Economy	3200.00
0005434136915	11945	Economy	3200.00
0005434136692	11945	Economy	3200.00
0005434136791	11945	Economy	3200.00
0005434136834	11945	Economy	3200.00
0005434136747	11945	Economy	3200.00
0005434136878	11945	Economy	3200.00
0005434136929	11945	Economy	3200.00
0005434136786	11945	Economy	3200.00
0005434136925	11945	Economy	3200.00
0005434136785	11945	Economy	3200.00
0005434136839	11945	Economy	3200.00
0005434136880	11945	Economy	3200.00
0005434136752	11945	Economy	3200.00
0005434136905	11945	Economy	3200.00
0005434136735	11945	Economy	3200.00
0005434136904	11945	Economy	3200.00
0005434136702	11945	Economy	3200.00
0005434136816	11945	Economy	3200.00
0005434136744	11945	Economy	3200.00
0005434136793	11945	Economy	3200.00
0005434136919	11945	Economy	3200.00
0005434136727	11945	Economy	3200.00
0005434136734	11945	Economy	3200.00
0005434136906	11945	Economy	3200.00
0005434136885	11945	Economy	3200.00
0005434136713	11945	Economy	3200.00
0005434136819	11945	Economy	3200.00
0005434137431	28746	Business	9700.00
0005434137445	28746	Business	9700.00
0005434137393	28746	Business	9700.00
0005434137416	28746	Business	9700.00
0005434137376	28746	Business	9700.00
0005434137365	28746	Business	9700.00
0005434137444	28746	Business	9700.00
0005434137396	28746	Business	9700.00
0005434137424	28746	Business	9700.00
0005434137357	28746	Business	9700.00
0005434137437	28746	Business	9700.00
0005434137388	28746	Business	9700.00
0005434137411	28746	Economy	3200.00
0005434137441	28746	Economy	3200.00
0005434137443	28746	Economy	3200.00
0005434137363	28746	Economy	3200.00
0005434137403	28746	Economy	3200.00
0005434137362	28746	Economy	3200.00
0005434137422	28746	Economy	3200.00
0005434137375	28746	Economy	3200.00
0005434137386	28746	Economy	3500.00
0005434137420	28746	Economy	3200.00
0005434137436	28746	Economy	3500.00
0005434137428	28746	Economy	3500.00
0005434137370	28746	Economy	3500.00
0005434137369	28746	Economy	3500.00
0005434137359	28746	Economy	3200.00
0005434137373	28746	Economy	3200.00
0005434137361	28746	Economy	3200.00
0005434137380	28746	Economy	3200.00
0005434137387	28746	Economy	3200.00
0005434137413	28746	Economy	3200.00
0005434137425	28746	Economy	3200.00
0005434137417	28746	Economy	3200.00
0005434137430	28746	Economy	3200.00
0005434137368	28746	Economy	3200.00
0005434137405	28746	Economy	3200.00
0005434137397	28746	Economy	3200.00
0005434137383	28746	Economy	3200.00
0005434137377	28746	Economy	3200.00
0005434137390	28746	Economy	3200.00
0005434137366	28746	Economy	3200.00
0005434137433	28746	Economy	3200.00
0005434137395	28746	Economy	3200.00
0005434137371	28746	Economy	3200.00
0005434137414	28746	Economy	3200.00
0005434137398	28746	Economy	3200.00
0005434137429	28746	Economy	3200.00
0005434137381	28746	Economy	3200.00
0005434137435	28746	Economy	3200.00
0005434137372	28746	Economy	3200.00
0005434137360	28746	Economy	3200.00
0005434137434	28746	Economy	3200.00
0005434137440	28746	Economy	3200.00
0005434137358	28746	Economy	3200.00
0005434137401	28746	Economy	3200.00
0005434137404	28746	Economy	3200.00
0005434137432	28746	Economy	3200.00
0005434137402	28746	Economy	3200.00
0005434137415	28746	Economy	3200.00
0005434137439	28746	Economy	3200.00
0005434137408	28746	Economy	3200.00
0005434137438	28746	Economy	3200.00
0005434137400	28746	Economy	3200.00
0005434137410	28746	Economy	3200.00
0005434137378	28746	Economy	3200.00
0005434137412	28746	Economy	3200.00
0005434137394	28746	Economy	3200.00
0005434137391	28746	Economy	3200.00
0005434137418	28746	Economy	3200.00
0005434137385	28746	Economy	3200.00
0005434137379	28746	Economy	3200.00
0005434137442	28746	Economy	3200.00
0005434137399	28746	Economy	3200.00
0005434137409	28746	Economy	3200.00
0005434137382	28746	Economy	3200.00
0005434137426	28746	Economy	3200.00
0005434137384	28746	Economy	3200.00
0005434137367	28746	Economy	3200.00
0005434137407	28746	Economy	3200.00
0005434137392	28746	Economy	3200.00
0005434137423	28746	Economy	3200.00
0005434137364	28746	Economy	3200.00
0005434137419	28746	Economy	3200.00
0005434137374	28746	Economy	3200.00
0005434137421	28746	Economy	3200.00
0005434137406	28746	Economy	3200.00
0005434137427	28746	Economy	3200.00
0005434137389	28746	Economy	3200.00
0005434466425	6566	Economy	23000.00
0005434466423	6566	Economy	20900.00
0005434466422	6566	Economy	20900.00
0005434466416	6566	Economy	20900.00
0005434466411	6566	Economy	20900.00
0005435312765	6566	Economy	20900.00
0005434466420	6566	Economy	20900.00
0005434466409	6566	Economy	20900.00
0005434466419	6566	Economy	20900.00
0005434466413	6566	Economy	20900.00
0005434466414	6566	Economy	20900.00
0005434466410	6566	Economy	20900.00
0005434466417	6566	Economy	20900.00
0005434466415	6566	Economy	20900.00
0005435312766	6566	Economy	20900.00
0005434466424	6566	Economy	20900.00
0005434466412	6566	Economy	20900.00
0005434466421	6566	Economy	20900.00
0005435312769	6566	Economy	20900.00
0005434466418	6566	Economy	20900.00
0005433534481	6823	Economy	9900.00
0005433538800	6823	Economy	9900.00
0005433538798	6823	Economy	9900.00
0005433538799	6823	Economy	9900.00
0005435259680	6823	Economy	9900.00
0005433538796	6823	Economy	9900.00
0005433538803	6823	Economy	9900.00
0005433538797	6823	Economy	9900.00
0005433538801	6823	Economy	9900.00
0005433538795	6823	Economy	9900.00
0005433538802	6823	Economy	9900.00
0005435259679	6823	Economy	9900.00
0005433538720	25034	Economy	10900.00
0005435259720	25034	Economy	10900.00
0005435259718	25034	Economy	9900.00
0005435259722	25034	Economy	9900.00
0005433538721	25034	Economy	9900.00
0005433534465	25034	Economy	9900.00
0005435259723	25034	Economy	9900.00
0005433534464	25034	Economy	9900.00
0005433538739	25034	Economy	9900.00
0005433538740	25034	Economy	9900.00
0005433534468	25034	Economy	9900.00
0005435259719	25034	Economy	9900.00
0005435259721	25034	Economy	9900.00
0005433538735	25034	Economy	9900.00
0005433534466	25034	Economy	9900.00
0005433538734	25034	Economy	9900.00
0005433538738	25034	Economy	9900.00
0005433534467	25034	Economy	9900.00
0005433538736	25034	Economy	9900.00
0005433511883	838	Economy	14600.00
0005432922459	838	Economy	14600.00
0005433511884	838	Economy	14600.00
0005433511878	838	Economy	14600.00
0005433511885	838	Economy	14600.00
0005432922457	838	Economy	14600.00
0005432922458	838	Economy	14600.00
0005433511886	838	Economy	14600.00
0005433511879	838	Economy	14600.00
0005433511882	838	Economy	14600.00
0005433511881	838	Economy	14600.00
0005433511880	838	Economy	14600.00
0005432922491	16131	Economy	16100.00
0005433511837	16131	Economy	16100.00
0005433511802	16131	Economy	14600.00
0005433511803	16131	Economy	14600.00
0005433511809	16131	Economy	14600.00
0005433511838	16131	Economy	14600.00
0005433511808	16131	Economy	14600.00
0005432922490	16131	Economy	14600.00
0005433511840	16131	Economy	14600.00
0005432922492	16131	Economy	14600.00
0005433511804	16131	Economy	14600.00
0005433511828	16131	Economy	14600.00
0005432922493	16131	Economy	14600.00
0005433511836	16131	Economy	14600.00
0005433511824	16131	Economy	14600.00
0005433511825	16131	Economy	14600.00
0005433475672	4038	Economy	13500.00
0005433475670	4038	Economy	13500.00
0005433475668	4038	Economy	12300.00
0005433475669	4038	Economy	12300.00
0005433475666	4038	Economy	12300.00
0005433475667	4038	Economy	12300.00
0005435852525	4038	Economy	12300.00
0005433475671	4038	Economy	12300.00
0005435852530	4038	Economy	12300.00
0005435852528	4038	Economy	12300.00
0005433475673	4038	Economy	12300.00
0005435697115	3674	Economy	7900.00
0005434950491	3674	Economy	7900.00
0005435934995	3674	Economy	7200.00
0005435697111	3674	Economy	7200.00
0005435697119	3674	Economy	7200.00
0005435697103	3674	Economy	7200.00
0005435697110	3674	Economy	7200.00
0005435697120	3674	Economy	7200.00
0005435697106	3674	Economy	7200.00
0005435697122	3674	Economy	7200.00
0005435697126	3674	Economy	7200.00
0005434950492	3674	Economy	7200.00
0005435697116	3674	Economy	7200.00
0005435697109	3674	Economy	7200.00
0005435697112	3674	Economy	7200.00
0005435697117	3674	Economy	7200.00
0005435934994	3674	Economy	7200.00
0005435697118	3674	Economy	7200.00
0005435697104	3674	Economy	7200.00
0005435697107	3674	Economy	7200.00
0005435697102	3674	Economy	7200.00
0005435697114	3674	Economy	7200.00
0005435934996	3674	Economy	7200.00
0005435697125	3674	Economy	7200.00
0005435697121	3674	Economy	7200.00
0005435697124	3674	Economy	7200.00
0005435697128	3674	Economy	7200.00
0005435697123	3674	Economy	7200.00
0005434950494	3674	Economy	7200.00
0005435697108	3674	Economy	7200.00
0005435697130	3674	Economy	7200.00
0005434950493	3674	Economy	7200.00
0005434950490	3674	Economy	7200.00
0005435697129	3674	Economy	7200.00
0005435697113	3674	Economy	7200.00
0005435697127	3674	Economy	7200.00
0005435697105	3674	Economy	7200.00
0005435916144	16284	Economy	7900.00
0005435696896	16284	Economy	7200.00
0005435696898	16284	Economy	7200.00
0005435696940	16284	Economy	7200.00
0005435696897	16284	Economy	7200.00
0005435696883	16284	Economy	7200.00
0005435696854	16284	Economy	7200.00
0005435696882	16284	Economy	7200.00
0005435696870	16284	Economy	7200.00
0005435696864	16284	Economy	7200.00
0005435916145	16284	Economy	7200.00
0005435935016	16284	Economy	7200.00
0005435696857	16284	Economy	7200.00
0005435935017	16284	Economy	7200.00
0005435696877	16284	Economy	7200.00
0005435696889	16284	Economy	7200.00
0005435696876	16284	Economy	7200.00
0005435697058	16284	Economy	7200.00
0005435696894	16284	Economy	7200.00
0005434950469	16284	Economy	7200.00
0005435696865	16284	Economy	7200.00
0005435696881	16284	Economy	7200.00
0005435696858	16284	Economy	7200.00
0005435696855	16284	Economy	7200.00
0005435916143	16284	Economy	7200.00
0005435696859	16284	Economy	7200.00
0005435696871	16284	Economy	7200.00
0005435696853	16284	Economy	7200.00
0005434606800	3963	Economy	21300.00
0005434604869	3963	Economy	21300.00
0005433519421	3963	Economy	19300.00
0005434604870	3963	Economy	19300.00
0005432609698	3963	Economy	19300.00
0005433519422	3963	Economy	19300.00
0005432609700	3963	Economy	19300.00
0005435853584	3963	Economy	19300.00
0005432609699	3963	Economy	19300.00
0005432607532	3963	Economy	19300.00
0005435853580	3963	Economy	19300.00
0005435853583	3963	Economy	19300.00
0005432609697	3963	Economy	19300.00
0005433519419	3963	Economy	19300.00
0005435841462	3963	Economy	19300.00
0005432607533	3963	Economy	19300.00
0005432607534	3963	Economy	19300.00
0005435853579	3963	Economy	19300.00
0005433519420	3963	Economy	19300.00
0005434606799	3963	Economy	19300.00
0005435842311	3963	Economy	19300.00
0005434606798	3963	Economy	19300.00
0005432609701	3963	Economy	19300.00
0005434606801	3963	Economy	19300.00
0005432607531	3963	Economy	19300.00
0005433519399	22045	Economy	21300.00
0005435853597	22045	Economy	19300.00
0005433519385	22045	Economy	19300.00
0005435853596	22045	Economy	19300.00
0005433519380	22045	Economy	19300.00
0005433519391	22045	Economy	19300.00
0005435853594	22045	Economy	19300.00
0005433519397	22045	Economy	19300.00
0005434606760	22045	Economy	19300.00
0005433519398	22045	Economy	19300.00
0005435904890	22045	Economy	19300.00
0005434606759	22045	Economy	19300.00
0005435904891	22045	Economy	19300.00
0005433519384	22045	Economy	19300.00
0005435853595	22045	Economy	19300.00
0005435628703	774	Economy	3700.00
0005433348892	774	Economy	3700.00
0005433348912	774	Economy	3700.00
0005433348904	774	Economy	3700.00
0005433348905	774	Economy	3700.00
0005435628701	774	Economy	3700.00
0005433348897	774	Economy	3700.00
0005435628702	774	Economy	3700.00
0005435628700	774	Economy	3700.00
0005433348946	15961	Economy	3700.00
0005433348943	15961	Economy	3700.00
0005433348942	15961	Economy	3700.00
0005433348945	15961	Economy	3700.00
0005433348944	15961	Economy	3700.00
0005434446500	17147	Economy	7100.00
0005434446499	17147	Economy	7100.00
0005433158099	17147	Economy	7100.00
0005433159274	17147	Economy	7100.00
0005434446498	17147	Economy	7100.00
0005434445225	17147	Economy	7100.00
0005434445224	17147	Economy	7100.00
0005434445211	17599	Economy	7100.00
0005433159296	17599	Economy	7100.00
0005433159297	17599	Economy	7100.00
0005434445212	17599	Economy	7100.00
0005435132794	7870	Economy	5900.00
0005435383073	7870	Economy	5900.00
0005435132796	7870	Economy	5400.00
0005435132797	7870	Economy	5400.00
0005435383069	7870	Economy	5400.00
0005435132799	7870	Economy	5400.00
0005435132798	7870	Economy	5400.00
0005435383067	7870	Economy	5400.00
0005435132800	7870	Economy	5400.00
0005435132795	7870	Economy	5400.00
0005435132793	7870	Economy	5400.00
0005435132801	7870	Economy	5400.00
0005435383068	7870	Economy	5400.00
0005435383070	7870	Economy	5400.00
0005435132792	7870	Economy	5400.00
0005435383105	33064	Economy	5900.00
0005435132755	33064	Economy	5400.00
0005435383109	33064	Economy	5400.00
0005435132711	33064	Economy	5400.00
0005435383104	33064	Economy	5400.00
0005435132712	33064	Economy	5400.00
0005435132697	33064	Economy	5400.00
0005435383107	33064	Economy	5400.00
0005435383108	33064	Economy	5400.00
0005435132718	33064	Economy	5400.00
0005435383106	33064	Economy	5400.00
0005435132717	33064	Economy	5400.00
0005435132725	33064	Economy	5400.00
0005435132696	33064	Economy	5400.00
0005435132721	33064	Economy	5400.00
0005435390132	7485	Economy	12500.00
0005435160213	7485	Economy	12500.00
0005435160206	7485	Economy	12500.00
0005435160211	7485	Economy	12500.00
0005435160210	7485	Economy	12500.00
0005435160209	7485	Economy	12500.00
0005435160215	7485	Economy	12500.00
0005435160214	7485	Economy	12500.00
0005435160216	7485	Economy	12500.00
0005435160207	7485	Economy	12500.00
0005435390145	7485	Economy	12500.00
0005435160212	7485	Economy	12500.00
0005435160208	7485	Economy	12500.00
0005435160217	7485	Economy	12500.00
0005435390186	29538	Economy	12500.00
0005435160157	29538	Economy	12500.00
0005435160125	29538	Economy	12500.00
0005435160114	29538	Economy	12500.00
0005435160181	29538	Economy	12500.00
0005435160108	29538	Economy	12500.00
0005435390182	29538	Economy	12500.00
0005435390188	29538	Economy	12500.00
0005435160106	29538	Economy	12500.00
0005435160112	29538	Economy	12500.00
0005435390187	29538	Economy	12500.00
0005435390185	29538	Economy	12500.00
0005435160107	29538	Economy	12500.00
0005435390184	29538	Economy	12500.00
0005435160132	29538	Economy	12500.00
0005435390183	29538	Economy	12500.00
0005435178483	18436	Economy	4900.00
0005432394034	18436	Economy	4900.00
0005435178482	18436	Economy	4900.00
0005432398135	18436	Economy	4900.00
0005432394045	18436	Economy	4900.00
0005432394041	18436	Economy	4900.00
0005432398131	18436	Economy	4900.00
0005432398142	18436	Economy	4900.00
0005432394042	18436	Economy	4900.00
0005432394046	18436	Economy	4900.00
0005432394044	18436	Economy	4900.00
0005432400095	27171	Economy	4900.00
0005432398164	27171	Economy	4900.00
0005432400093	27171	Economy	4900.00
0005435178469	27171	Economy	4900.00
0005432398162	27171	Economy	4900.00
0005432398163	27171	Economy	4900.00
0005432400094	27171	Economy	4900.00
0005432400092	27171	Economy	4900.00
0005432400091	27171	Economy	4900.00
0005432639039	2239	Business	87300.00
0005432865906	2239	Business	87300.00
0005432639033	2239	Business	87300.00
0005432639019	2239	Economy	29100.00
0005432639036	2239	Economy	29100.00
0005432639038	2239	Economy	29100.00
0005432865896	2239	Economy	32000.00
0005432639035	2239	Economy	32000.00
0005432639016	2239	Economy	32000.00
0005432865905	2239	Economy	29100.00
0005432639015	2239	Economy	29100.00
0005432639022	2239	Economy	29100.00
0005432865895	2239	Economy	29100.00
0005432639037	2239	Economy	29100.00
0005432639018	2239	Economy	29100.00
0005432639023	2239	Economy	29100.00
0005432639009	2239	Economy	29100.00
0005432639010	2239	Economy	29100.00
0005432639014	2239	Economy	29100.00
0005432639032	2239	Economy	29100.00
0005432639012	2239	Economy	29100.00
0005432639005	2239	Economy	29100.00
0005432639041	2239	Economy	29100.00
0005432639021	2239	Economy	29100.00
0005432639008	2239	Economy	29100.00
0005432639024	2239	Economy	29100.00
0005432639029	2239	Economy	29100.00
0005432639026	2239	Economy	29100.00
0005432639006	2239	Economy	29100.00
0005432639034	2239	Economy	29100.00
0005432639017	2239	Economy	29100.00
0005432639013	2239	Economy	29100.00
0005432639027	2239	Economy	29100.00
0005432639025	2239	Economy	29100.00
0005432865897	2239	Economy	29100.00
0005432639028	2239	Economy	29100.00
0005432639030	2239	Economy	29100.00
0005432639007	2239	Economy	29100.00
0005432639031	2239	Economy	29100.00
0005432639040	2239	Economy	29100.00
0005432639020	2239	Economy	29100.00
0005432639011	2239	Economy	29100.00
0005434503829	6550	Business	48400.00
0005434503824	6550	Business	48400.00
0005434503839	6550	Business	48400.00
0005434503852	6550	Business	48400.00
0005434503832	6550	Business	48400.00
0005435103873	6550	Business	48400.00
0005435103874	6550	Business	48400.00
0005434503857	6550	Economy	16100.00
0005434503836	6550	Economy	16100.00
0005435103868	6550	Economy	16100.00
0005434503837	6550	Economy	16100.00
0005434503828	6550	Economy	16100.00
0005434503858	6550	Economy	16100.00
0005434503851	6550	Economy	16100.00
0005435103875	6550	Economy	16100.00
0005435103869	6550	Economy	16100.00
0005434503843	6550	Economy	17800.00
0005435103877	6550	Economy	17800.00
0005434503860	6550	Economy	17800.00
0005435103871	6550	Economy	16100.00
0005434503854	6550	Economy	16100.00
0005434503842	6550	Economy	16100.00
0005434503856	6550	Economy	16100.00
0005434503826	6550	Economy	16100.00
0005434503841	6550	Economy	16100.00
0005434503859	6550	Economy	16100.00
0005434503834	6550	Economy	16100.00
0005434503840	6550	Economy	16100.00
0005434503846	6550	Economy	16100.00
0005434503849	6550	Economy	16100.00
0005434503830	6550	Economy	16100.00
0005434503853	6550	Economy	16100.00
0005434503825	6550	Economy	16100.00
0005434503838	6550	Economy	16100.00
0005434503844	6550	Economy	16100.00
0005434503827	6550	Economy	16100.00
0005434503847	6550	Economy	16100.00
0005435103876	6550	Economy	16100.00
0005435103867	6550	Economy	16100.00
0005435103872	6550	Economy	16100.00
0005434503861	6550	Economy	16100.00
0005434503823	6550	Economy	16100.00
0005434503850	6550	Economy	16100.00
0005434503835	6550	Economy	16100.00
0005434503831	6550	Economy	16100.00
0005434503862	6550	Economy	16100.00
0005434503833	6550	Economy	16100.00
0005435103870	6550	Economy	16100.00
0005434503855	6550	Economy	16100.00
0005434503848	6550	Economy	16100.00
0005434503845	6550	Economy	16100.00
0005434503530	22690	Business	48400.00
0005434503526	22690	Economy	16100.00
0005434503496	22690	Economy	17800.00
0005434503529	22690	Economy	16100.00
0005434503654	22690	Economy	16100.00
0005434503575	22690	Economy	16100.00
0005435800087	6424	Economy	16800.00
0005435800085	6424	Economy	16800.00
0005435800095	6424	Economy	15300.00
0005435800092	6424	Economy	15300.00
0005435800084	6424	Economy	15300.00
0005435800090	6424	Economy	15300.00
0005435800091	6424	Economy	15300.00
0005435800096	6424	Economy	15300.00
0005435800093	6424	Economy	15300.00
0005435800088	6424	Economy	15300.00
0005435800089	6424	Economy	15300.00
0005435800086	6424	Economy	15300.00
0005435800097	6424	Economy	15300.00
0005435800083	6424	Economy	15300.00
0005435800082	6424	Economy	15300.00
0005435800094	6424	Economy	15300.00
0005435652703	1687	Business	50000.00
0005433367266	1687	Business	50000.00
0005435652695	1687	Business	50000.00
0005435652682	1687	Business	50000.00
0005435652681	1687	Business	50000.00
0005433367264	1687	Business	50000.00
0005433367471	1687	Business	50000.00
0005435652701	1687	Business	50000.00
0005435652674	1687	Business	50000.00
0005435652676	1687	Business	50000.00
0005435652671	1687	Economy	16700.00
0005435652692	1687	Economy	16700.00
0005435652680	1687	Economy	16700.00
0005433367297	1687	Economy	16700.00
0005435652690	1687	Economy	16700.00
0005435652730	1687	Economy	16700.00
0005435652673	1687	Economy	16700.00
0005435652729	1687	Economy	16700.00
0005435652697	1687	Economy	18300.00
0005435652718	1687	Economy	18300.00
0005435652678	1687	Economy	18300.00
0005435652710	1687	Economy	18300.00
0005433367370	1687	Economy	18300.00
0005435652677	1687	Economy	16700.00
0005435652711	1687	Economy	16700.00
0005433367286	1687	Economy	16700.00
0005435652721	1687	Economy	16700.00
0005435652704	1687	Economy	16700.00
0005433367243	1687	Economy	16700.00
0005435652688	1687	Economy	16700.00
0005435652714	1687	Economy	16700.00
0005433367371	1687	Economy	16700.00
0005435652709	1687	Economy	16700.00
0005433367337	1687	Economy	16700.00
0005433367406	1687	Economy	16700.00
0005433367377	1687	Economy	16700.00
0005435652700	1687	Economy	16700.00
0005435652706	1687	Economy	16700.00
0005433367298	1687	Economy	16700.00
0005433367227	1687	Economy	16700.00
0005435652696	1687	Economy	16700.00
0005435652725	1687	Economy	16700.00
0005435652724	1687	Economy	16700.00
0005435652689	1687	Economy	16700.00
0005435652693	1687	Economy	16700.00
0005435652719	1687	Economy	16700.00
0005435652705	1687	Economy	16700.00
0005433367354	1687	Economy	16700.00
0005435652675	1687	Economy	16700.00
0005433367472	1687	Economy	16700.00
0005435652683	1687	Economy	16700.00
0005435652702	1687	Economy	16700.00
0005435652722	1687	Economy	16700.00
0005433367378	1687	Economy	16700.00
0005435652670	1687	Economy	16700.00
0005433367385	1687	Economy	16700.00
0005435652712	1687	Economy	16700.00
0005435652679	1687	Economy	16700.00
0005435652686	1687	Economy	16700.00
0005433367285	1687	Economy	16700.00
0005435652687	1687	Economy	16700.00
0005435652708	1687	Economy	16700.00
0005433367323	1687	Economy	16700.00
0005435652699	1687	Economy	16700.00
0005435652684	1687	Economy	16700.00
0005433367357	1687	Economy	16700.00
0005435652685	1687	Economy	16700.00
0005435652715	1687	Economy	16700.00
0005433367260	1687	Economy	16700.00
0005433367317	1687	Economy	16700.00
0005435652691	1687	Economy	16700.00
0005435652727	1687	Economy	16700.00
0005433367299	1687	Economy	16700.00
0005435652694	1687	Economy	16700.00
0005435652717	1687	Economy	16700.00
0005435652726	1687	Economy	16700.00
0005435652728	1687	Economy	16700.00
0005435652723	1687	Economy	16700.00
0005435652713	1687	Economy	16700.00
0005435652672	1687	Economy	16700.00
0005435652698	1687	Economy	16700.00
0005435652716	1687	Economy	16700.00
0005435652720	1687	Economy	16700.00
0005433367355	1687	Economy	16700.00
0005433367261	1687	Economy	16700.00
0005435652707	1687	Economy	16700.00
0005435652345	21705	Business	50000.00
0005433367576	21705	Business	50000.00
0005433367578	21705	Business	50000.00
0005433367594	21705	Business	50000.00
0005433367581	21705	Business	50000.00
0005433367600	21705	Business	50000.00
0005433367598	21705	Business	50000.00
0005435652254	21705	Business	50000.00
0005435652354	21705	Business	50000.00
0005435652323	21705	Economy	16700.00
0005433367568	21705	Economy	16700.00
0005435652328	21705	Economy	16700.00
0005433367572	21705	Economy	16700.00
0005435652279	21705	Economy	16700.00
0005433367592	21705	Economy	16700.00
0005433367596	21705	Economy	18300.00
0005435652295	21705	Economy	18300.00
0005435652262	21705	Economy	18300.00
0005433367597	21705	Economy	16700.00
0005433367586	21705	Economy	16700.00
0005435652356	21705	Economy	16700.00
0005433367590	21705	Economy	16700.00
0005435652274	21705	Economy	16700.00
0005433367575	21705	Economy	16700.00
0005433367580	21705	Economy	16700.00
0005433367587	21705	Economy	16700.00
0005433367585	21705	Economy	16700.00
0005435652374	21705	Economy	16700.00
0005433367577	21705	Economy	16700.00
0005433367582	21705	Economy	16700.00
0005435652271	21705	Economy	16700.00
0005433367599	21705	Economy	16700.00
0005433367565	21705	Economy	16700.00
0005433367571	21705	Economy	16700.00
0005435652355	21705	Economy	16700.00
0005433367589	21705	Economy	16700.00
0005433367583	21705	Economy	16700.00
0005435652273	21705	Economy	16700.00
0005435652373	21705	Economy	16700.00
0005435652272	21705	Economy	16700.00
0005433367593	21705	Economy	16700.00
0005433367569	21705	Economy	16700.00
0005435652290	21705	Economy	16700.00
0005433367601	21705	Economy	16700.00
0005433367566	21705	Economy	16700.00
0005435652289	21705	Economy	16700.00
0005433367574	21705	Economy	16700.00
0005433367584	21705	Economy	16700.00
0005433367588	21705	Economy	16700.00
0005435652280	21705	Economy	16700.00
0005433367579	21705	Economy	16700.00
0005433367567	21705	Economy	16700.00
0005433367573	21705	Economy	16700.00
0005435652327	21705	Economy	16700.00
0005433367591	21705	Economy	16700.00
0005433367570	21705	Economy	16700.00
0005433367595	21705	Economy	16700.00
0005433367564	21705	Economy	16700.00
0005435652263	21705	Economy	16700.00
0005434466392	23239	Economy	23000.00
0005434466374	23239	Economy	23000.00
0005434466377	23239	Economy	20900.00
0005434466375	23239	Economy	20900.00
0005435312785	23239	Economy	20900.00
0005435312784	23239	Economy	20900.00
0005434466391	23239	Economy	20900.00
0005434466378	23239	Economy	20900.00
0005435312780	23239	Economy	20900.00
0005434466381	23239	Economy	20900.00
0005435312787	23239	Economy	20900.00
0005434466385	23239	Economy	20900.00
0005434466373	23239	Economy	20900.00
0005434466387	23239	Economy	20900.00
0005434466386	23239	Economy	20900.00
0005435312782	23239	Economy	20900.00
0005435312786	23239	Economy	20900.00
0005435312781	23239	Economy	20900.00
0005435312783	23239	Economy	20900.00
0005433985573	4175	Business	21500.00
0005433985581	4175	Business	21500.00
0005433985599	4175	Business	21500.00
0005433985604	4175	Business	21500.00
0005433985588	4175	Business	21500.00
0005433985572	4175	Business	21500.00
0005433985564	4175	Business	21500.00
0005433985578	4175	Economy	7200.00
0005433985563	4175	Economy	7200.00
0005435788751	4175	Economy	7200.00
0005433985567	4175	Economy	7900.00
0005433985597	4175	Economy	7900.00
0005433985562	4175	Economy	7900.00
0005433985590	4175	Economy	7200.00
0005433985571	4175	Economy	7200.00
0005435788749	4175	Economy	7200.00
0005433985559	4175	Economy	7200.00
0005433985587	4175	Economy	7200.00
0005433985602	4175	Economy	7200.00
0005433985594	4175	Economy	7200.00
0005435788750	4175	Economy	7200.00
0005433985605	4175	Economy	7200.00
0005433985580	4175	Economy	7200.00
0005433985596	4175	Economy	7200.00
0005433985600	4175	Economy	7200.00
0005433985582	4175	Economy	7200.00
0005433985569	4175	Economy	7200.00
0005433985595	4175	Economy	7200.00
0005433985598	4175	Economy	7200.00
0005433985576	4175	Economy	7200.00
0005433985565	4175	Economy	7200.00
0005433985591	4175	Economy	7200.00
0005433985561	4175	Economy	7200.00
0005433985601	4175	Economy	7200.00
0005433985570	4175	Economy	7200.00
0005433985566	4175	Economy	7200.00
0005433985575	4175	Economy	7200.00
0005433985592	4175	Economy	7200.00
0005433985574	4175	Economy	7200.00
0005433985589	4175	Economy	7200.00
0005433985586	4175	Economy	7200.00
0005433985560	4175	Economy	7200.00
0005433985584	4175	Economy	7200.00
0005433985585	4175	Economy	7200.00
0005433985583	4175	Economy	7200.00
0005433985593	4175	Economy	7200.00
0005433985568	4175	Economy	7200.00
0005433985579	4175	Economy	7200.00
0005433985577	4175	Economy	7200.00
0005433985603	4175	Economy	7200.00
0005435788729	25651	Business	21500.00
0005435788728	25651	Economy	7200.00
0005435788727	25651	Economy	7200.00
0005435788726	25651	Economy	7200.00
0005435788725	25651	Economy	7200.00
0005435720801	21271	Economy	9400.00
0005435719558	24761	Economy	9400.00
0005434509014	21313	Economy	15500.00
0005434509028	21313	Economy	15500.00
0005434509034	21313	Economy	15500.00
0005433168340	21313	Economy	15500.00
0005433168337	21313	Economy	15500.00
0005434509036	21313	Economy	15500.00
0005433168335	21313	Economy	15500.00
0005433168336	21313	Economy	15500.00
0005433168338	21313	Economy	15500.00
0005433168334	21313	Economy	15500.00
0005434509027	21313	Economy	15500.00
0005434509035	21313	Economy	15500.00
0005433168333	21313	Economy	15500.00
0005433168341	21313	Economy	15500.00
0005433168339	21313	Economy	15500.00
0005434151682	17816	Business	18000.00
0005432666352	17816	Business	18000.00
0005432666353	17816	Economy	6000.00
0005432869476	17816	Economy	6600.00
0005432869477	17816	Economy	6600.00
0005434151681	17816	Economy	6600.00
0005434151683	17816	Economy	6000.00
0005432869475	17816	Economy	6000.00
0005432869474	17816	Economy	6000.00
0005432655353	17816	Economy	6000.00
0005432665239	17816	Economy	6000.00
0005432657401	17816	Economy	6000.00
0005432655326	17816	Economy	6000.00
0005432655327	17816	Economy	6000.00
0005432659672	17816	Economy	6000.00
0005432869478	17816	Economy	6000.00
0005432655328	17816	Economy	6000.00
0005432655351	17816	Economy	6000.00
0005432667420	17816	Economy	6000.00
0005432666357	17816	Economy	6000.00
0005432869473	17816	Economy	6000.00
0005432665244	17816	Economy	6000.00
0005432665240	17816	Economy	6000.00
0005432666356	17816	Economy	6000.00
0005432655331	17816	Economy	6000.00
0005432665245	17816	Economy	6000.00
0005432660798	26316	Business	18000.00
0005432667435	26316	Business	18000.00
0005432655421	26316	Business	18000.00
0005432655420	26316	Economy	6000.00
0005432655417	26316	Economy	6000.00
0005432655415	26316	Economy	6000.00
0005432665254	26316	Economy	6000.00
0005432655419	26316	Economy	6600.00
0005432665256	26316	Economy	6000.00
0005432659688	26316	Economy	6000.00
0005432655412	26316	Economy	6000.00
0005432655413	26316	Economy	6000.00
0005432667436	26316	Economy	6000.00
0005432655416	26316	Economy	6000.00
0005432655418	26316	Economy	6000.00
0005432657418	26316	Economy	6000.00
0005432665255	26316	Economy	6000.00
0005432659686	26316	Economy	6000.00
0005432657419	26316	Economy	6000.00
0005432667434	26316	Economy	6000.00
0005432660797	26316	Economy	6000.00
0005432665257	26316	Economy	6000.00
0005432655411	26316	Economy	6000.00
0005432655414	26316	Economy	6000.00
0005432659687	26316	Economy	6000.00
0005432657420	26316	Economy	6000.00
0005434151655	26316	Economy	6000.00
0005432655422	26316	Economy	6000.00
0005432328317	3115	Business	16100.00
0005432328329	3115	Business	16100.00
0005432328332	3115	Business	16100.00
0005432328324	3115	Business	16100.00
0005432287148	3115	Business	16100.00
0005432328350	3115	Business	16100.00
0005432328326	3115	Business	16100.00
0005432328337	3115	Business	16100.00
0005432328325	3115	Business	16100.00
0005432328345	3115	Economy	5400.00
0005432328343	3115	Economy	5400.00
0005432328340	3115	Economy	5400.00
0005432905029	3115	Economy	5400.00
0005432328344	3115	Economy	5400.00
0005432905056	3115	Economy	5400.00
0005432328333	3115	Economy	5400.00
0005432328316	3115	Economy	5400.00
0005432328346	3115	Economy	5900.00
0005433438825	3115	Economy	5900.00
0005432328354	3115	Economy	5900.00
0005433438826	3115	Economy	5900.00
0005432905030	3115	Economy	5900.00
0005433438824	3115	Economy	5400.00
0005433438823	3115	Economy	5400.00
0005432328352	3115	Economy	5400.00
0005432328323	3115	Economy	5400.00
0005432328356	3115	Economy	5400.00
0005432328351	3115	Economy	5400.00
0005432328321	3115	Economy	5400.00
0005433438829	3115	Economy	5400.00
0005432328349	3115	Economy	5400.00
0005432328327	3115	Economy	5400.00
0005432328348	3115	Economy	5400.00
0005433438827	3115	Economy	5400.00
0005432328315	3115	Economy	5400.00
0005432328347	3115	Economy	5400.00
0005432328341	3115	Economy	5400.00
0005432328357	3115	Economy	5400.00
0005432328319	3115	Economy	5400.00
0005433438828	3115	Economy	5400.00
0005432905043	3115	Economy	5400.00
0005432328318	3115	Economy	5400.00
0005432328353	3115	Economy	5400.00
0005432328342	3115	Economy	5400.00
0005432328358	3115	Economy	5400.00
0005432328330	3115	Economy	5400.00
0005432328320	3115	Economy	5400.00
0005432287147	3115	Economy	5400.00
0005432905057	3115	Economy	5400.00
0005433438830	3115	Economy	5400.00
0005432328313	3115	Economy	5400.00
0005432328322	3115	Economy	5400.00
0005432287146	3115	Economy	5400.00
0005432328355	3115	Economy	5400.00
0005432328331	3115	Economy	5400.00
0005432328336	3115	Economy	5400.00
0005432328334	3115	Economy	5400.00
0005432905033	3115	Economy	5400.00
0005432287149	3115	Economy	5400.00
0005432328314	3115	Economy	5400.00
0005432328359	3115	Economy	5400.00
0005432287150	3115	Economy	5400.00
0005432328338	3115	Economy	5400.00
0005432328328	3115	Economy	5400.00
0005432328339	3115	Economy	5400.00
0005432328335	3115	Economy	5400.00
0005432328133	31114	Business	16100.00
0005433438775	31114	Business	16100.00
0005432054279	31114	Business	16100.00
0005432327954	31114	Business	16100.00
0005432054281	31114	Economy	5400.00
0005432327903	31114	Economy	5400.00
0005432327912	31114	Economy	5400.00
0005432327892	31114	Economy	5900.00
0005432327946	31114	Economy	5400.00
0005432327910	31114	Economy	5400.00
0005433438770	31114	Economy	5400.00
0005432327893	31114	Economy	5400.00
0005432327980	31114	Economy	5400.00
0005432905081	31114	Economy	5400.00
0005432905079	31114	Economy	5400.00
0005432327913	31114	Economy	5400.00
0005432327981	31114	Economy	5400.00
0005432328028	31114	Economy	5400.00
0005432327982	31114	Economy	5400.00
0005432327949	31114	Economy	5400.00
0005432905077	31114	Economy	5400.00
0005432328079	31114	Economy	5400.00
0005432327894	31114	Economy	5400.00
0005432905080	31114	Economy	5400.00
0005432328109	31114	Economy	5400.00
0005432905076	31114	Economy	5400.00
0005432327891	31114	Economy	5400.00
0005432905078	31114	Economy	5400.00
0005432054280	31114	Economy	5400.00
0005432327955	31114	Economy	5400.00
0005432328027	31114	Economy	5400.00
0005434309641	6187	Business	124600.00
0005435999118	6187	Business	124600.00
0005434309636	6187	Business	124600.00
0005435296967	6187	Economy	41500.00
0005435999128	6187	Economy	41500.00
0005435487508	6187	Economy	41500.00
0005435999113	6187	Economy	41500.00
0005434309634	6187	Economy	41500.00
0005434309629	6187	Economy	41500.00
0005435487464	6187	Economy	41500.00
0005434309630	6187	Economy	41500.00
0005435999117	6187	Economy	41500.00
0005435999122	6187	Economy	41500.00
0005434309633	6187	Economy	41500.00
0005432146182	6187	Economy	41500.00
0005435999119	6187	Economy	41500.00
0005435296951	6187	Economy	41500.00
0005435487479	6187	Economy	41500.00
0005435296945	6187	Economy	41500.00
0005434309632	6187	Economy	41500.00
0005434309631	6187	Economy	41500.00
0005435487463	6187	Economy	41500.00
0005435487458	6187	Economy	41500.00
0005435487466	6187	Economy	41500.00
0005434309635	6187	Economy	41500.00
0005434309637	6187	Economy	41500.00
0005435296968	6187	Economy	41500.00
0005432146183	6187	Economy	41500.00
0005434309628	6187	Economy	41500.00
0005435487465	6187	Economy	41500.00
0005435999121	6187	Economy	41500.00
0005435487456	6187	Economy	41500.00
0005435487467	6187	Economy	41500.00
0005435999120	6187	Economy	41500.00
0005434309638	6187	Economy	41500.00
0005435999115	6187	Economy	41500.00
0005435487480	6187	Economy	41500.00
0005435487459	6187	Economy	41500.00
0005435999112	6187	Economy	41500.00
0005435999126	6187	Economy	41500.00
0005434309639	6187	Economy	41500.00
0005435999124	6187	Economy	41500.00
0005435487489	6187	Economy	41500.00
0005435999116	6187	Economy	41500.00
0005435999125	6187	Economy	41500.00
0005435999127	6187	Economy	41500.00
0005435999123	6187	Economy	41500.00
0005434309640	6187	Economy	41500.00
0005435296969	6187	Economy	41500.00
0005435487457	6187	Economy	41500.00
0005435487475	6187	Economy	41500.00
0005434309627	6187	Economy	41500.00
0005435999114	6187	Economy	41500.00
0005434309500	19553	Business	124600.00
0005434309501	19553	Business	124600.00
0005435487634	19553	Business	124600.00
0005435487637	19553	Economy	41500.00
0005435487645	19553	Economy	41500.00
0005434309510	19553	Economy	41500.00
0005435487631	19553	Economy	41500.00
0005435487642	19553	Economy	41500.00
0005434309511	19553	Economy	41500.00
0005435487639	19553	Economy	41500.00
0005434309565	19553	Economy	41500.00
0005435297007	19553	Economy	41500.00
0005435487650	19553	Economy	41500.00
0005434309512	19553	Economy	41500.00
0005435998967	19553	Economy	41500.00
0005434309507	19553	Economy	41500.00
0005435487648	19553	Economy	41500.00
0005435487646	19553	Economy	41500.00
0005435998962	19553	Economy	41500.00
0005435487632	19553	Economy	41500.00
0005435998966	19553	Economy	41500.00
0005435998976	19553	Economy	45700.00
0005434309570	19553	Economy	41500.00
0005434309518	19553	Economy	41500.00
0005435487644	19553	Economy	41500.00
0005434309513	19553	Economy	41500.00
0005435297000	19553	Economy	41500.00
0005435297006	19553	Economy	41500.00
0005435487651	19553	Economy	41500.00
0005435487649	19553	Economy	41500.00
0005435487641	19553	Economy	41500.00
0005434309548	19553	Economy	41500.00
0005435487635	19553	Economy	41500.00
0005435487643	19553	Economy	41500.00
0005434309566	19553	Economy	41500.00
0005435487640	19553	Economy	41500.00
0005435487652	19553	Economy	41500.00
0005435297003	19553	Economy	41500.00
0005434309519	19553	Economy	41500.00
0005435297002	19553	Economy	41500.00
0005435297001	19553	Economy	41500.00
0005435297004	19553	Economy	41500.00
0005435487647	19553	Economy	41500.00
0005434309504	19553	Economy	41500.00
0005435487638	19553	Economy	41500.00
0005434309517	19553	Economy	41500.00
0005435487633	19553	Economy	41500.00
0005435297005	19553	Economy	41500.00
0005435487636	19553	Economy	41500.00
0005435998969	19553	Economy	41500.00
0005433158115	17542	Economy	12300.00
0005434446482	17542	Economy	12300.00
0005433158112	17542	Economy	12300.00
0005433158114	17542	Economy	12300.00
0005434446483	17542	Economy	12300.00
0005433158113	17542	Economy	12300.00
0005435517771	1549	Business	86000.00
0005432291910	1549	Business	86000.00
0005435502149	1549	Business	86000.00
0005434565805	1549	Business	86000.00
0005435508268	1549	Business	86000.00
0005435508272	1549	Business	86000.00
0005435502135	1549	Business	86000.00
0005435502151	1549	Business	86000.00
0005433185974	1549	Business	86000.00
0005433185988	1549	Economy	28700.00
0005435508273	1549	Economy	28700.00
0005435502152	1549	Economy	28700.00
0005435502133	1549	Economy	28700.00
0005433185975	1549	Economy	28700.00
0005434565811	1549	Economy	28700.00
0005435508270	1549	Economy	28700.00
0005433185973	1549	Economy	28700.00
0005435508269	1549	Economy	28700.00
0005433185977	1549	Economy	31500.00
0005434565810	1549	Economy	31500.00
0005435517770	1549	Economy	31500.00
0005435517769	1549	Economy	28700.00
0005435517766	1549	Economy	28700.00
0005435502142	1549	Economy	28700.00
0005435508274	1549	Economy	28700.00
0005434565814	1549	Economy	28700.00
0005435517774	1549	Economy	28700.00
0005434565809	1549	Economy	28700.00
0005434565803	1549	Economy	28700.00
0005433185969	1549	Economy	28700.00
0005435502138	1549	Economy	28700.00
0005435502141	1549	Economy	28700.00
0005435502132	1549	Economy	28700.00
0005435502150	1549	Economy	28700.00
0005435502144	1549	Economy	28700.00
0005435502146	1549	Economy	28700.00
0005433185982	1549	Economy	28700.00
0005435508267	1549	Economy	28700.00
0005434565812	1549	Economy	28700.00
0005435517772	1549	Economy	28700.00
0005435502143	1549	Economy	28700.00
0005433185987	1549	Economy	28700.00
0005435502148	1549	Economy	28700.00
0005434565801	1549	Economy	28700.00
0005435502137	1549	Economy	28700.00
0005434565802	1549	Economy	28700.00
0005435502139	1549	Economy	28700.00
0005435502140	1549	Economy	28700.00
0005434565804	1549	Economy	28700.00
0005435517777	1549	Economy	28700.00
0005433185983	1549	Economy	28700.00
0005435508266	1549	Economy	28700.00
0005434565807	1549	Economy	28700.00
0005434565808	1549	Economy	28700.00
0005435502136	1549	Economy	28700.00
0005435502147	1549	Economy	28700.00
0005433185979	1549	Economy	28700.00
0005435502145	1549	Economy	28700.00
0005435517775	1549	Economy	28700.00
0005433186005	1549	Economy	28700.00
0005435502134	1549	Economy	28700.00
0005433185972	1549	Economy	28700.00
0005435517767	1549	Economy	28700.00
0005434565806	1549	Economy	28700.00
0005433185984	1549	Economy	28700.00
0005435508271	1549	Economy	28700.00
0005434565813	1549	Economy	28700.00
0005435508275	1549	Economy	28700.00
0005435517768	1549	Economy	28700.00
0005435517773	1549	Economy	28700.00
0005432291911	1549	Economy	28700.00
0005435517776	1549	Economy	28700.00
0005433185978	1549	Economy	28700.00
0005435501937	20864	Business	86000.00
0005435528897	20864	Business	86000.00
0005435528939	20864	Business	86000.00
0005435501935	20864	Business	86000.00
0005433186050	20864	Business	86000.00
0005434565723	20864	Business	86000.00
0005435501947	20864	Economy	28700.00
0005435528885	20864	Economy	28700.00
0005434565710	20864	Economy	28700.00
0005435501948	20864	Economy	28700.00
0005433186049	20864	Economy	28700.00
0005435528886	20864	Economy	28700.00
0005435528938	20864	Economy	28700.00
0005435501965	20864	Economy	28700.00
0005433186048	20864	Economy	28700.00
0005435501967	20864	Economy	28700.00
0005435501931	20864	Economy	28700.00
0005435501976	20864	Economy	28700.00
0005433186054	20864	Economy	28700.00
0005435501936	20864	Economy	28700.00
0005433186053	20864	Economy	28700.00
0005435528920	20864	Economy	28700.00
0005435528896	20864	Economy	28700.00
0005434565711	20864	Economy	28700.00
0005433186047	20864	Economy	28700.00
0005433186052	20864	Economy	28700.00
0005435528884	20864	Economy	28700.00
0005435501964	20864	Economy	28700.00
0005435528887	20864	Economy	28700.00
0005433186051	20864	Economy	28700.00
0005435153689	3905	Economy	21600.00
0005435153690	3905	Economy	21600.00
0005435931547	3905	Economy	21600.00
0005435153687	3905	Economy	19700.00
0005435153692	3905	Economy	19700.00
0005435153686	3905	Economy	19700.00
0005435153691	3905	Economy	19700.00
0005435153688	3905	Economy	19700.00
0005435153693	3905	Economy	19700.00
0005435931541	3905	Economy	19700.00
0005435153638	21857	Economy	19700.00
0005435931572	21857	Economy	19700.00
0005435153642	21857	Economy	19700.00
0005435153653	21857	Economy	19700.00
0005435153641	21857	Economy	19700.00
0005435153643	21857	Economy	19700.00
0005435153639	21857	Economy	19700.00
0005435153646	21857	Economy	19700.00
0005435153647	21857	Economy	19700.00
0005435225460	7194	Economy	14300.00
0005432628722	7194	Economy	13000.00
0005432628733	7194	Economy	13000.00
0005432628728	7194	Economy	13000.00
0005432628731	7194	Economy	13000.00
0005432628735	7194	Economy	13000.00
0005432628729	7194	Economy	13000.00
0005435225479	7194	Economy	13000.00
0005432628724	7194	Economy	13000.00
0005432628726	7194	Economy	13000.00
0005432628734	7194	Economy	13000.00
0005432628727	7194	Economy	13000.00
0005432628730	7194	Economy	13000.00
0005432628732	7194	Economy	13000.00
0005432628736	7194	Economy	13000.00
0005432628725	7194	Economy	13000.00
0005435225461	7194	Economy	13000.00
0005432628723	7194	Economy	13000.00
0005432628592	28097	Economy	14300.00
0005435225516	28097	Economy	13000.00
0005435225520	28097	Economy	13000.00
0005432628651	28097	Economy	13000.00
0005435225519	28097	Economy	13000.00
0005432628628	28097	Economy	13000.00
0005432628619	28097	Economy	13000.00
0005432628593	28097	Economy	13000.00
0005435225524	28097	Economy	13000.00
0005435225523	28097	Economy	13000.00
0005435225518	28097	Economy	13000.00
0005435225521	28097	Economy	13000.00
0005435225517	28097	Economy	13000.00
0005435225522	28097	Economy	13000.00
0005432628629	28097	Economy	13000.00
0005432628669	28097	Economy	13000.00
0005432628591	28097	Economy	13000.00
0005432628630	28097	Economy	13000.00
0005434267884	8726	Economy	10500.00
0005435960021	8726	Economy	10500.00
0005435960019	8726	Economy	10500.00
0005435960018	8726	Economy	10500.00
0005435960020	8726	Economy	10500.00
0005435959994	15266	Economy	11500.00
0005435959998	15266	Economy	11500.00
0005434267920	15266	Economy	10500.00
0005434267919	15266	Economy	10500.00
0005435959999	15266	Economy	10500.00
0005434267921	15266	Economy	10500.00
0005435960007	15266	Economy	10500.00
0005434267918	15266	Economy	10500.00
0005435959982	15266	Economy	10500.00
0005435959995	15266	Economy	10500.00
0005432692789	1199	Business	115000.00
0005432675011	1199	Business	115000.00
0005432692797	1199	Business	115000.00
0005432675005	1199	Business	115000.00
0005432692800	1199	Business	115000.00
0005432692810	1199	Business	115000.00
0005432692792	1199	Business	115000.00
0005432692787	1199	Business	115000.00
0005432692801	1199	Economy	38300.00
0005432692806	1199	Economy	38300.00
0005432692794	1199	Economy	38300.00
0005432692788	1199	Economy	38300.00
0005432692802	1199	Economy	42200.00
0005432692781	1199	Economy	42200.00
0005432675004	1199	Economy	42200.00
0005432675014	1199	Economy	38300.00
0005432692785	1199	Economy	38300.00
0005432692809	1199	Economy	38300.00
0005432692784	1199	Economy	38300.00
0005432692786	1199	Economy	38300.00
0005432692803	1199	Economy	38300.00
0005432675016	1199	Economy	38300.00
0005432692798	1199	Economy	38300.00
0005432873184	1199	Economy	38300.00
0005432692796	1199	Economy	38300.00
0005432675007	1199	Economy	38300.00
0005432677537	1199	Economy	38300.00
0005432675013	1199	Economy	38300.00
0005432692793	1199	Economy	38300.00
0005432692805	1199	Economy	38300.00
0005432692808	1199	Economy	38300.00
0005432692783	1199	Economy	38300.00
0005432675003	1199	Economy	38300.00
0005432675009	1199	Economy	38300.00
0005432675010	1199	Economy	38300.00
0005432692807	1199	Economy	38300.00
0005432675012	1199	Economy	38300.00
0005432675015	1199	Economy	38300.00
0005432692791	1199	Economy	38300.00
0005432675006	1199	Economy	38300.00
0005432692780	1199	Economy	38300.00
0005432692804	1199	Economy	38300.00
0005432692782	1199	Economy	38300.00
0005432677538	1199	Economy	38300.00
0005432675002	1199	Economy	38300.00
0005432692795	1199	Economy	38300.00
0005432677539	1199	Economy	38300.00
0005432692799	1199	Economy	38300.00
0005432692790	1199	Economy	38300.00
0005432675008	1199	Economy	38300.00
0005432674897	17479	Business	115000.00
0005432674863	17479	Business	115000.00
0005432692567	17479	Economy	38300.00
0005432674870	17479	Economy	38300.00
0005432873233	17479	Economy	38300.00
0005432674965	17479	Economy	38300.00
0005432692572	17479	Economy	38300.00
0005432692579	17479	Economy	42200.00
0005432873232	17479	Economy	42200.00
0005432674903	17479	Economy	38300.00
0005432692553	17479	Economy	38300.00
0005432674896	17479	Economy	38300.00
0005432692554	17479	Economy	38300.00
0005432674884	17479	Economy	38300.00
0005432674899	17479	Economy	38300.00
0005432692555	17479	Economy	38300.00
0005432873234	17479	Economy	38300.00
0005432674888	17479	Economy	38300.00
0005432873231	17479	Economy	38300.00
0005432692644	17479	Economy	38300.00
0005432674883	17479	Economy	38300.00
0005432692562	17479	Economy	38300.00
0005432692547	17479	Economy	38300.00
0005432692566	17479	Economy	38300.00
0005432873235	17479	Economy	38300.00
0005432873236	17479	Economy	38300.00
0005432873237	17479	Economy	38300.00
0005432692528	17479	Economy	38300.00
0005432674900	17479	Economy	38300.00
0005432692561	17479	Economy	38300.00
0005432674864	17479	Economy	38300.00
0005432674924	17479	Economy	38300.00
0005432674935	17479	Economy	38300.00
0005432692580	17479	Economy	38300.00
0005432692535	17479	Economy	38300.00
0005434435053	1123	Economy	15200.00
0005434435065	1123	Economy	13900.00
0005434435060	1123	Economy	13900.00
0005434435054	1123	Economy	13900.00
0005434435058	1123	Economy	13900.00
0005433156601	1123	Economy	13900.00
0005434435057	1123	Economy	13900.00
0005433156602	1123	Economy	13900.00
0005433156631	1123	Economy	13900.00
0005433156600	1123	Economy	13900.00
0005434435051	1123	Economy	13900.00
0005433156603	1123	Economy	13900.00
0005434435056	1123	Economy	13900.00
0005434435059	1123	Economy	13900.00
0005434435064	1123	Economy	13900.00
0005434435062	1123	Economy	13900.00
0005434435052	1123	Economy	13900.00
0005434435055	1123	Economy	13900.00
0005433156644	1123	Economy	13900.00
0005433156621	1123	Economy	13900.00
0005434435061	1123	Economy	13900.00
0005434435063	1123	Economy	13900.00
0005434434938	17299	Economy	15200.00
0005434434957	17299	Economy	13900.00
0005434434931	17299	Economy	13900.00
0005434434937	17299	Economy	13900.00
0005433156677	17299	Economy	13900.00
0005434434956	17299	Economy	13900.00
0005434434930	17299	Economy	13900.00
0005433156684	17299	Economy	13900.00
0005434434915	17299	Economy	13900.00
0005433156678	17299	Economy	13900.00
0005434434969	17299	Economy	13900.00
0005433156679	17299	Economy	13900.00
0005433156680	17299	Economy	13900.00
0005434434962	17299	Economy	13900.00
0005434434909	17299	Economy	13900.00
0005434434933	17299	Economy	13900.00
0005434434970	17299	Economy	13900.00
0005434434925	17299	Economy	13900.00
0005434434926	17299	Economy	13900.00
0005433156683	17299	Economy	13900.00
0005434434961	17299	Economy	13900.00
0005433156682	17299	Economy	13900.00
0005434434927	17299	Economy	13900.00
0005434434916	17299	Economy	13900.00
0005433156676	17299	Economy	13900.00
0005434434928	17299	Economy	13900.00
0005433156681	17299	Economy	13900.00
0005435086771	4064	Economy	7500.00
0005435086777	4064	Economy	7500.00
0005435086770	4064	Economy	7500.00
0005435086772	4064	Economy	7500.00
0005435928083	4064	Economy	7500.00
0005435086776	4064	Economy	7500.00
0005435086774	4064	Economy	7500.00
0005435086775	4064	Economy	7500.00
0005435086773	4064	Economy	7500.00
0005435928103	24422	Economy	7500.00
0005435086709	24422	Economy	7500.00
0005435086703	24422	Economy	7500.00
0005435086718	24422	Economy	7500.00
0005435928102	24422	Economy	7500.00
0005435928105	24422	Economy	7500.00
0005435928106	24422	Economy	7500.00
0005435086728	24422	Economy	7500.00
0005435928104	24422	Economy	7500.00
0005435086727	24422	Economy	7500.00
0005435706215	2447	Business	86800.00
0005435706250	2447	Business	86800.00
0005435706251	2447	Business	86800.00
0005435706236	2447	Business	86800.00
0005435706260	2447	Business	86800.00
0005435706253	2447	Business	86800.00
0005435706221	2447	Business	86800.00
0005435706229	2447	Economy	28900.00
0005435706214	2447	Economy	28900.00
0005435706225	2447	Economy	28900.00
0005435706220	2447	Economy	28900.00
0005433373384	2447	Economy	28900.00
0005435706262	2447	Economy	31800.00
0005435706257	2447	Economy	31800.00
0005435706217	2447	Economy	31800.00
0005435706261	2447	Economy	28900.00
0005435706258	2447	Economy	28900.00
0005435706223	2447	Economy	28900.00
0005435706252	2447	Economy	28900.00
0005435706259	2447	Economy	28900.00
0005435706249	2447	Economy	28900.00
0005435706230	2447	Economy	28900.00
0005435706233	2447	Economy	28900.00
0005435706224	2447	Economy	28900.00
0005435706219	2447	Economy	28900.00
0005435706238	2447	Economy	28900.00
0005435706242	2447	Economy	28900.00
0005435706232	2447	Economy	28900.00
0005435706226	2447	Economy	28900.00
0005435706228	2447	Economy	28900.00
0005435706247	2447	Economy	28900.00
0005435706235	2447	Economy	28900.00
0005435706216	2447	Economy	28900.00
0005435706218	2447	Economy	28900.00
0005433373383	2447	Economy	28900.00
0005433373397	2447	Economy	28900.00
0005435706237	2447	Economy	28900.00
0005435706248	2447	Economy	28900.00
0005435706222	2447	Economy	28900.00
0005433373418	2447	Economy	28900.00
0005435706241	2447	Economy	28900.00
0005435706239	2447	Economy	28900.00
0005435706213	2447	Economy	28900.00
0005433373412	2447	Economy	28900.00
0005433373393	2447	Economy	28900.00
0005435706244	2447	Economy	28900.00
0005433373396	2447	Economy	28900.00
0005435706245	2447	Economy	28900.00
0005433373407	2447	Economy	28900.00
0005433373395	2447	Economy	28900.00
0005435706234	2447	Economy	28900.00
0005433373408	2447	Economy	28900.00
0005435706246	2447	Economy	28900.00
0005433373394	2447	Economy	28900.00
0005435706254	2447	Economy	28900.00
0005435706227	2447	Economy	28900.00
0005435706255	2447	Economy	28900.00
0005435706243	2447	Economy	28900.00
0005435706240	2447	Economy	28900.00
0005435706256	2447	Economy	28900.00
0005435706231	2447	Economy	28900.00
0005433373454	27039	Business	86800.00
0005435706097	27039	Business	86800.00
0005433373461	27039	Business	86800.00
0005433373455	27039	Business	86800.00
0005433373458	27039	Business	86800.00
0005433373464	27039	Business	86800.00
0005435706096	27039	Business	86800.00
0005435706119	27039	Economy	28900.00
0005433373443	27039	Economy	28900.00
0005435706109	27039	Economy	28900.00
0005433373446	27039	Economy	28900.00
0005433373467	27039	Economy	28900.00
0005433373444	27039	Economy	28900.00
0005433373452	27039	Economy	31800.00
0005433373450	27039	Economy	28900.00
0005435706108	27039	Economy	28900.00
0005433373453	27039	Economy	28900.00
0005435706111	27039	Economy	28900.00
0005433373442	27039	Economy	28900.00
0005433373439	27039	Economy	28900.00
0005433373465	27039	Economy	28900.00
0005435706132	27039	Economy	28900.00
0005435706107	27039	Economy	28900.00
0005433373448	27039	Economy	28900.00
0005433373459	27039	Economy	28900.00
0005433373441	27039	Economy	28900.00
0005433373457	27039	Economy	28900.00
0005435706172	27039	Economy	28900.00
0005433373440	27039	Economy	28900.00
0005433373445	27039	Economy	28900.00
0005435706122	27039	Economy	28900.00
0005435706135	27039	Economy	28900.00
0005435706112	27039	Economy	28900.00
0005433373460	27039	Economy	28900.00
0005433373463	27039	Economy	28900.00
0005435706104	27039	Economy	28900.00
0005435706156	27039	Economy	28900.00
0005435706137	27039	Economy	28900.00
0005433373451	27039	Economy	28900.00
0005433373466	27039	Economy	28900.00
0005433373462	27039	Economy	28900.00
0005435706129	27039	Economy	28900.00
0005435706143	27039	Economy	28900.00
0005433373449	27039	Economy	28900.00
0005433373456	27039	Economy	28900.00
0005435706136	27039	Economy	28900.00
0005433373447	27039	Economy	28900.00
0005435706155	27039	Economy	28900.00
0005435907417	4858	Business	44200.00
0005435907445	4858	Business	44200.00
0005435907432	4858	Business	44200.00
0005434625886	4858	Economy	14700.00
0005434625887	4858	Economy	14700.00
0005434625890	4858	Economy	14700.00
0005434625884	4858	Economy	16200.00
0005434625889	4858	Economy	16200.00
0005435907420	4858	Economy	14700.00
0005435907423	4858	Economy	14700.00
0005435907433	4858	Economy	14700.00
0005434625882	4858	Economy	14700.00
0005435907431	4858	Economy	14700.00
0005434625888	4858	Economy	14700.00
0005434625885	4858	Economy	14700.00
0005434625883	4858	Economy	14700.00
0005434625881	4858	Economy	14700.00
0005435907466	32907	Business	44200.00
0005434625839	32907	Business	44200.00
0005434625826	32907	Economy	14700.00
0005435907468	32907	Economy	14700.00
0005434625819	32907	Economy	14700.00
0005434625803	32907	Economy	14700.00
0005434625794	32907	Economy	14700.00
0005434625836	32907	Economy	14700.00
0005434625837	32907	Economy	14700.00
0005434625809	32907	Economy	14700.00
0005434625793	32907	Economy	14700.00
0005435907467	32907	Economy	14700.00
0005434625820	32907	Economy	14700.00
0005435907465	32907	Economy	14700.00
0005435937347	13793	Economy	3400.00
0005435784856	13793	Economy	3400.00
0005435784877	13793	Economy	3100.00
0005435937346	13793	Economy	3100.00
0005435784758	13793	Economy	3100.00
0005435937345	13793	Economy	3100.00
0005435787322	13793	Economy	3100.00
0005435784759	13793	Economy	3100.00
0005435787321	13793	Economy	3100.00
0005435784756	13793	Economy	3100.00
0005432195676	13793	Economy	3100.00
0005435784798	13793	Economy	3100.00
0005435784902	13793	Economy	3100.00
0005435784874	13793	Economy	3100.00
0005435784736	13793	Economy	3100.00
0005435784885	13793	Economy	3100.00
0005435784757	13793	Economy	3100.00
0005435937348	13793	Economy	3100.00
0005435784799	13793	Economy	3100.00
0005435784797	13793	Economy	3100.00
0005435784737	13793	Economy	3100.00
0005432195677	13793	Economy	3100.00
0005435787323	13793	Economy	3100.00
0005435937344	13793	Economy	3100.00
0005435785026	27450	Economy	3400.00
0005435785012	27450	Economy	3400.00
0005435785027	27450	Economy	3400.00
0005435785041	27450	Economy	3100.00
0005435937306	27450	Economy	3100.00
0005435785011	27450	Economy	3100.00
0005435785033	27450	Economy	3100.00
0005435785038	27450	Economy	3100.00
0005435785029	27450	Economy	3100.00
0005435785021	27450	Economy	3100.00
0005435937305	27450	Economy	3100.00
0005432190594	27450	Economy	3100.00
0005435785016	27450	Economy	3100.00
0005435785015	27450	Economy	3100.00
0005435785036	27450	Economy	3100.00
0005435787332	27450	Economy	3100.00
0005435785013	27450	Economy	3100.00
0005435785031	27450	Economy	3100.00
0005435785014	27450	Economy	3100.00
0005435785028	27450	Economy	3100.00
0005435785034	27450	Economy	3100.00
0005435787333	27450	Economy	3100.00
0005435785039	27450	Economy	3100.00
0005435785023	27450	Economy	3100.00
0005435785042	27450	Economy	3100.00
0005432190595	27450	Economy	3100.00
0005435785020	27450	Economy	3100.00
0005435785017	27450	Economy	3100.00
0005435785044	27450	Economy	3100.00
0005432190593	27450	Economy	3100.00
0005432190592	27450	Economy	3100.00
0005432190591	27450	Economy	3100.00
0005435785032	27450	Economy	3100.00
0005435785035	27450	Economy	3100.00
0005435785024	27450	Economy	3100.00
0005435785030	27450	Economy	3100.00
0005435785045	27450	Economy	3100.00
0005435785018	27450	Economy	3100.00
0005435785022	27450	Economy	3100.00
0005435785019	27450	Economy	3100.00
0005435785037	27450	Economy	3100.00
0005435785040	27450	Economy	3100.00
0005435785043	27450	Economy	3100.00
0005435785025	27450	Economy	3100.00
0005434406744	20261	Business	12000.00
0005434406707	20261	Business	12000.00
0005435310976	20261	Business	12000.00
0005434406773	20261	Business	12000.00
0005435310971	20261	Business	12000.00
0005434406986	20261	Business	12000.00
0005434406779	20261	Business	12000.00
0005434406695	20261	Economy	4000.00
0005432058350	20261	Economy	4000.00
0005434406761	20261	Economy	4000.00
0005434406696	20261	Economy	4000.00
0005435310975	20261	Economy	4000.00
0005434406640	20261	Economy	4000.00
0005434406984	20261	Economy	4000.00
0005434406762	20261	Economy	4000.00
0005434406654	20261	Economy	4400.00
0005434406891	20261	Economy	4000.00
0005434406794	20261	Economy	4000.00
0005434406709	20261	Economy	4000.00
0005434406745	20261	Economy	4000.00
0005434406994	20261	Economy	4000.00
0005434406679	20261	Economy	4000.00
0005434406853	20261	Economy	4000.00
0005435310969	20261	Economy	4000.00
0005435310973	20261	Economy	4000.00
0005434406959	20261	Economy	4000.00
0005435310970	20261	Economy	4000.00
0005434406746	20261	Economy	4000.00
0005435310972	20261	Economy	4000.00
0005434406708	20261	Economy	4000.00
0005434406649	20261	Economy	4000.00
0005434406656	20261	Economy	4000.00
0005435310977	20261	Economy	4000.00
0005434406859	20261	Economy	4000.00
0005434406797	20261	Economy	4000.00
0005434406655	20261	Economy	4000.00
0005435310974	20261	Economy	4000.00
0005434406993	20261	Economy	4000.00
0005434406860	20261	Economy	4000.00
0005434406985	20261	Economy	4000.00
0005434407071	20261	Economy	4000.00
0005434406750	20261	Economy	4000.00
0005434406883	20261	Economy	4000.00
0005434406650	20261	Economy	4000.00
0005432058351	20261	Economy	4000.00
0005432058348	20261	Economy	4000.00
0005432058349	20261	Economy	4000.00
0005434406732	20261	Economy	4000.00
0005434406890	20261	Economy	4000.00
0005434406808	20261	Economy	4000.00
0005434407248	26981	Business	12000.00
0005434407225	26981	Business	12000.00
0005434407272	26981	Business	12000.00
0005434407264	26981	Business	12000.00
0005434407271	26981	Business	12000.00
0005434407244	26981	Business	12000.00
0005434407249	26981	Business	12000.00
0005434407276	26981	Business	12000.00
0005434407238	26981	Business	12000.00
0005435310856	26981	Economy	4000.00
0005434407223	26981	Economy	4000.00
0005434407274	26981	Economy	4000.00
0005434407241	26981	Economy	4000.00
0005435310867	26981	Economy	4000.00
0005432153880	26981	Economy	4000.00
0005432153883	26981	Economy	4000.00
0005434407229	26981	Economy	4000.00
0005434407260	26981	Economy	4400.00
0005434407253	26981	Economy	4400.00
0005434407277	26981	Economy	4400.00
0005432153878	26981	Economy	4400.00
0005434407279	26981	Economy	4400.00
0005432153882	26981	Economy	4000.00
0005435310855	26981	Economy	4000.00
0005434407243	26981	Economy	4000.00
0005434407247	26981	Economy	4000.00
0005434407254	26981	Economy	4000.00
0005434407218	26981	Economy	4000.00
0005434407270	26981	Economy	4000.00
0005434407265	26981	Economy	4000.00
0005434407234	26981	Economy	4000.00
0005434407262	26981	Economy	4000.00
0005434407235	26981	Economy	4000.00
0005434407278	26981	Economy	4000.00
0005434407267	26981	Economy	4000.00
0005434407252	26981	Economy	4000.00
0005434407281	26981	Economy	4000.00
0005434407257	26981	Economy	4000.00
0005434407232	26981	Economy	4000.00
0005432153884	26981	Economy	4000.00
0005434407224	26981	Economy	4000.00
0005434407236	26981	Economy	4000.00
0005434407275	26981	Economy	4000.00
0005435310873	26981	Economy	4000.00
0005434407227	26981	Economy	4000.00
0005434407221	26981	Economy	4000.00
0005434407245	26981	Economy	4000.00
0005432153879	26981	Economy	4000.00
0005435310872	26981	Economy	4000.00
0005434407251	26981	Economy	4000.00
0005434407230	26981	Economy	4000.00
0005434407259	26981	Economy	4000.00
0005434407219	26981	Economy	4000.00
0005434407256	26981	Economy	4000.00
0005434407258	26981	Economy	4000.00
0005434407220	26981	Economy	4000.00
0005432153881	26981	Economy	4000.00
0005434407237	26981	Economy	4000.00
0005434407222	26981	Economy	4000.00
0005434407250	26981	Economy	4000.00
0005434407228	26981	Economy	4000.00
0005435310858	26981	Economy	4000.00
0005434407268	26981	Economy	4000.00
0005435310840	26981	Economy	4000.00
0005434407226	26981	Economy	4000.00
0005434407263	26981	Economy	4000.00
0005434407231	26981	Economy	4000.00
0005434407273	26981	Economy	4000.00
0005434407240	26981	Economy	4000.00
0005435310857	26981	Economy	4000.00
0005434407266	26981	Economy	4000.00
0005434407255	26981	Economy	4000.00
0005434407261	26981	Economy	4000.00
0005434407242	26981	Economy	4000.00
0005434407239	26981	Economy	4000.00
0005434407246	26981	Economy	4000.00
0005434407233	26981	Economy	4000.00
0005434407269	26981	Economy	4000.00
0005434407280	26981	Economy	4000.00
0005434319276	5689	Business	43300.00
0005434319286	5689	Business	43300.00
0005434319279	5689	Business	43300.00
0005434319266	5689	Business	43300.00
0005434319264	5689	Business	43300.00
0005434319274	5689	Economy	14400.00
0005434319277	5689	Economy	14400.00
0005434319265	5689	Economy	14400.00
0005434319278	5689	Economy	14400.00
0005434319280	5689	Economy	14400.00
0005433123613	5689	Economy	14400.00
0005434319283	5689	Economy	14400.00
0005432109682	5689	Economy	14400.00
0005432109681	5689	Economy	14400.00
0005433123589	5689	Economy	14400.00
0005433123651	5689	Economy	14400.00
0005434311202	5689	Economy	14400.00
0005434319272	5689	Economy	14400.00
0005434319281	5689	Economy	14400.00
0005434319273	5689	Economy	14400.00
0005434319267	5689	Economy	14400.00
0005434319271	5689	Economy	14400.00
0005433123642	5689	Economy	14400.00
0005434319269	5689	Economy	14400.00
0005432109680	5689	Economy	14400.00
0005433123612	5689	Economy	14400.00
0005434319285	5689	Economy	14400.00
0005434311203	5689	Economy	14400.00
0005434319275	5689	Economy	14400.00
0005434319270	5689	Economy	14400.00
0005434311201	5689	Economy	14400.00
0005434319282	5689	Economy	14400.00
0005434319268	5689	Economy	14400.00
0005434319284	5689	Economy	14400.00
0005433123776	15693	Business	43300.00
0005434319205	15693	Business	43300.00
0005433123771	15693	Business	43300.00
0005433123762	15693	Economy	14400.00
0005433123778	15693	Economy	14400.00
0005433123760	15693	Economy	15900.00
0005433123773	15693	Economy	15900.00
0005433123774	15693	Economy	15900.00
0005434319190	15693	Economy	14400.00
0005434319152	15693	Economy	14400.00
0005433123764	15693	Economy	14400.00
0005433123775	15693	Economy	14400.00
0005433123765	15693	Economy	14400.00
0005433123780	15693	Economy	14400.00
0005433123772	15693	Economy	14400.00
0005433123769	15693	Economy	14400.00
0005434319192	15693	Economy	14400.00
0005433123767	15693	Economy	14400.00
0005433123768	15693	Economy	14400.00
0005433123770	15693	Economy	14400.00
0005434319227	15693	Economy	14400.00
0005434319191	15693	Economy	14400.00
0005433123777	15693	Economy	14400.00
0005434319206	15693	Economy	14400.00
0005434319178	15693	Economy	14400.00
0005433123766	15693	Economy	14400.00
0005433123779	15693	Economy	14400.00
0005433123761	15693	Economy	14400.00
0005434319207	15693	Economy	14400.00
0005434319153	15693	Economy	14400.00
0005434319208	15693	Economy	14400.00
0005433123763	15693	Economy	14400.00
0005435219183	31759	Economy	17100.00
0005435219185	31759	Economy	17100.00
0005435220300	31759	Economy	15500.00
0005435220303	31759	Economy	15500.00
0005435219182	31759	Economy	15500.00
0005435220304	31759	Economy	15500.00
0005435219186	31759	Economy	15500.00
0005435220302	31759	Economy	15500.00
0005435219184	31759	Economy	15500.00
0005435219181	31759	Economy	15500.00
0005435220301	31759	Economy	15500.00
0005434484296	9003	Economy	24900.00
0005434189083	9003	Economy	24900.00
0005434484294	9003	Economy	24900.00
0005434484293	9003	Economy	24900.00
0005434189096	9003	Economy	24900.00
0005434189086	9003	Economy	24900.00
0005434189082	9003	Economy	24900.00
0005434189075	9003	Economy	24900.00
0005434484292	9003	Economy	24900.00
0005434189080	9003	Economy	24900.00
0005434484297	9003	Economy	24900.00
0005434189103	9003	Economy	24900.00
0005434484295	9003	Economy	24900.00
0005434189130	16655	Economy	27400.00
0005434189133	16655	Economy	27400.00
0005434484234	16655	Economy	24900.00
0005434189132	16655	Economy	24900.00
0005434189134	16655	Economy	24900.00
0005434484235	16655	Economy	24900.00
0005434189131	16655	Economy	24900.00
0005434189129	16655	Economy	24900.00
0005434484266	16655	Economy	24900.00
0005433123775	7611	Business	11100.00
0005433123779	7611	Economy	3700.00
0005433123760	7611	Economy	4100.00
0005433123762	7611	Economy	3700.00
0005433123773	7611	Economy	3700.00
0005433123765	7611	Economy	3700.00
0005433123778	7611	Economy	3700.00
0005433123769	7611	Economy	3700.00
0005433123774	7611	Economy	3700.00
0005433123761	7611	Economy	3700.00
0005433123776	7611	Economy	3700.00
0005433123767	7611	Economy	3700.00
0005433123764	7611	Economy	3700.00
0005433123763	7611	Economy	3700.00
0005433123770	7611	Economy	3700.00
0005433123780	7611	Economy	3700.00
0005433123771	7611	Economy	3700.00
0005433123766	7611	Economy	3700.00
0005433123777	7611	Economy	3700.00
0005433123772	7611	Economy	3700.00
0005433123768	7611	Economy	3700.00
0005433449790	7612	Business	11100.00
0005432692819	7612	Business	11100.00
0005432720686	7612	Business	11100.00
0005432720696	7612	Business	11100.00
0005433449800	7612	Business	11100.00
0005432071548	7612	Business	11100.00
0005432720689	7612	Business	11100.00
0005432692832	7612	Business	11100.00
0005432720695	7612	Business	11100.00
0005433449795	7612	Business	11100.00
0005432720700	7612	Business	11100.00
0005433449793	7612	Economy	3700.00
0005433449803	7612	Economy	3700.00
0005432692841	7612	Economy	3700.00
0005432720694	7612	Economy	3700.00
0005432692816	7612	Economy	3700.00
0005433449797	7612	Economy	3700.00
0005432692835	7612	Economy	4100.00
0005432720692	7612	Economy	4100.00
0005432720681	7612	Economy	4100.00
0005432692839	7612	Economy	4100.00
0005432692830	7612	Economy	3700.00
0005433449788	7612	Economy	3700.00
0005433449798	7612	Economy	3700.00
0005432692837	7612	Economy	3700.00
0005433449794	7612	Economy	3700.00
0005432692833	7612	Economy	3700.00
0005432692834	7612	Economy	3700.00
0005433449799	7612	Economy	3700.00
0005432720685	7612	Economy	3700.00
0005433449787	7612	Economy	3700.00
0005432720697	7612	Economy	3700.00
0005432720682	7612	Economy	3700.00
0005432692840	7612	Economy	3700.00
0005433449805	7612	Economy	3700.00
0005432720678	7612	Economy	3700.00
0005432692812	7612	Economy	3700.00
0005432720693	7612	Economy	3700.00
0005432720690	7612	Economy	3700.00
0005433449786	7612	Economy	3700.00
0005432692825	7612	Economy	3700.00
0005432720688	7612	Economy	3700.00
0005433449789	7612	Economy	3700.00
0005433449791	7612	Economy	3700.00
0005433449785	7612	Economy	3700.00
0005432071550	7612	Economy	3700.00
0005433449801	7612	Economy	3700.00
0005432720679	7612	Economy	3700.00
0005432720698	7612	Economy	3700.00
0005433449796	7612	Economy	3700.00
0005432692817	7612	Economy	3700.00
0005432692813	7612	Economy	3700.00
0005433449802	7612	Economy	3700.00
0005432720684	7612	Economy	3700.00
0005432720676	7612	Economy	3700.00
0005432720683	7612	Economy	3700.00
0005432071549	7612	Economy	3700.00
0005432692842	7612	Economy	3700.00
0005432692827	7612	Economy	3700.00
0005432692824	7612	Economy	3700.00
0005432692811	7612	Economy	3700.00
0005432692815	7612	Economy	3700.00
0005432692836	7612	Economy	3700.00
0005432692828	7612	Economy	3700.00
0005432720699	7612	Economy	3700.00
0005432720677	7612	Economy	3700.00
0005432692822	7612	Economy	3700.00
0005432720701	7612	Economy	3700.00
0005432692826	7612	Economy	3700.00
0005432692831	7612	Economy	3700.00
0005432692823	7612	Economy	3700.00
0005432720687	7612	Economy	3700.00
0005432692818	7612	Economy	3700.00
0005432692821	7612	Economy	3700.00
0005432692820	7612	Economy	3700.00
0005432692814	7612	Economy	3700.00
0005433449804	7612	Economy	3700.00
0005432720691	7612	Economy	3700.00
0005433449792	7612	Economy	3700.00
0005432720680	7612	Economy	3700.00
0005432720702	7612	Economy	3700.00
0005432692838	7612	Economy	3700.00
0005432692829	7612	Economy	3700.00
0005432692547	30373	Business	11100.00
0005432692579	30373	Business	11100.00
0005432692566	30373	Business	11100.00
0005433449599	30373	Business	11100.00
0005433449584	30373	Business	11100.00
0005433449628	30373	Business	11100.00
0005433449615	30373	Economy	3700.00
0005433449583	30373	Economy	3700.00
0005433449590	30373	Economy	4100.00
0005433449598	30373	Economy	3700.00
0005432692553	30373	Economy	3700.00
0005433449659	30373	Economy	3700.00
0005432692572	30373	Economy	3700.00
0005433449593	30373	Economy	3700.00
0005433449660	30373	Economy	3700.00
0005432692580	30373	Economy	3700.00
0005432692554	30373	Economy	3700.00
0005432692567	30373	Economy	3700.00
0005432692562	30373	Economy	3700.00
0005433449639	30373	Economy	3700.00
0005432692561	30373	Economy	3700.00
0005432692528	30373	Economy	3700.00
0005433449653	30373	Economy	3700.00
0005432692535	30373	Economy	3700.00
0005432692644	30373	Economy	3700.00
0005432692555	30373	Economy	3700.00
0005432720507	30372	Business	11100.00
0005432720514	30372	Business	11100.00
0005432720463	30372	Business	11100.00
0005432720438	30372	Economy	3700.00
0005433123651	30372	Economy	3700.00
0005432720618	30372	Economy	3700.00
0005433722168	30372	Economy	4100.00
0005432720480	30372	Economy	3700.00
0005432720546	30372	Economy	3700.00
0005432720674	30372	Economy	3700.00
0005432720675	30372	Economy	3700.00
0005432720504	30372	Economy	3700.00
0005432720431	30372	Economy	3700.00
0005433123642	30372	Economy	3700.00
0005433123613	30372	Economy	3700.00
0005433722169	30372	Economy	3700.00
0005432720436	30372	Economy	3700.00
0005432720474	30372	Economy	3700.00
0005432720619	30372	Economy	3700.00
0005433123612	30372	Economy	3700.00
0005432720508	30372	Economy	3700.00
0005432720579	30372	Economy	3700.00
0005432720439	30372	Economy	3700.00
0005432720526	30372	Economy	3700.00
0005433722167	30372	Economy	3700.00
0005432720473	30372	Economy	3700.00
0005433123589	30372	Economy	3700.00
0005432720478	30372	Economy	3700.00
0005432720442	30372	Economy	3700.00
0005432720430	30372	Economy	3700.00
0005432720435	30372	Economy	3700.00
0005433192824	1398	Business	70400.00
0005434586404	1398	Business	70400.00
0005432927900	1398	Business	70400.00
0005432927910	1398	Business	70400.00
0005434586408	1398	Business	70400.00
0005433524956	1398	Business	70400.00
0005432927912	1398	Business	70400.00
0005433192833	1398	Business	70400.00
0005434586395	1398	Business	70400.00
0005433192832	1398	Business	70400.00
0005434586398	1398	Business	70400.00
0005433192850	1398	Economy	23500.00
0005434586403	1398	Economy	23500.00
0005433192837	1398	Economy	23500.00
0005434586397	1398	Economy	23500.00
0005432968801	1398	Economy	23500.00
0005434586411	1398	Economy	23500.00
0005434586400	1398	Economy	23500.00
0005434586396	1398	Economy	23500.00
0005433524954	1398	Economy	23500.00
0005434586399	1398	Economy	23500.00
0005433724767	1398	Economy	25800.00
0005433192842	1398	Economy	25800.00
0005432927899	1398	Economy	25800.00
0005434586412	1398	Economy	25800.00
0005433192874	1398	Economy	23500.00
0005434586418	1398	Economy	23500.00
0005432270981	1398	Economy	23500.00
0005433192875	1398	Economy	23500.00
0005433192835	1398	Economy	23500.00
0005434586405	1398	Economy	23500.00
0005432927890	1398	Economy	23500.00
0005433524948	1398	Economy	23500.00
0005432927906	1398	Economy	23500.00
0005434586402	1398	Economy	23500.00
0005434586409	1398	Economy	23500.00
0005433524946	1398	Economy	23500.00
0005433524951	1398	Economy	23500.00
0005432927885	1398	Economy	23500.00
0005434586394	1398	Economy	23500.00
0005433192836	1398	Economy	23500.00
0005434586420	1398	Economy	23500.00
0005432270982	1398	Economy	23500.00
0005433192827	1398	Economy	23500.00
0005433524955	1398	Economy	23500.00
0005434513559	1398	Economy	23500.00
0005433524949	1398	Economy	23500.00
0005433724770	1398	Economy	23500.00
0005434586406	1398	Economy	23500.00
0005433192852	1398	Economy	23500.00
0005433524950	1398	Economy	23500.00
0005433724771	1398	Economy	23500.00
0005434586417	1398	Economy	23500.00
0005432927913	1398	Economy	23500.00
0005434586410	1398	Economy	23500.00
0005434586415	1398	Economy	23500.00
0005434513558	1398	Economy	23500.00
0005433192831	1398	Economy	23500.00
0005433192859	1398	Economy	23500.00
0005433192823	1398	Economy	23500.00
0005434586407	1398	Economy	23500.00
0005434586416	1398	Economy	23500.00
0005433724768	1398	Economy	23500.00
0005433192853	1398	Economy	23500.00
0005434586413	1398	Economy	23500.00
0005433192860	1398	Economy	23500.00
0005434514945	1398	Economy	23500.00
0005434586401	1398	Economy	23500.00
0005432927893	1398	Economy	23500.00
0005434513557	1398	Economy	23500.00
0005434514946	1398	Economy	23500.00
0005433524953	1398	Economy	23500.00
0005433524952	1398	Economy	23500.00
0005434513560	1398	Economy	23500.00
0005434514947	1398	Economy	23500.00
0005433724769	1398	Economy	23500.00
0005433192834	1398	Economy	23500.00
0005434586414	1398	Economy	23500.00
0005434586419	1398	Economy	23500.00
0005433524947	1398	Economy	23500.00
0005433192858	1398	Economy	23500.00
0005433192932	18544	Business	70400.00
0005434586196	18544	Business	70400.00
0005434586250	18544	Business	70400.00
0005433192940	18544	Business	70400.00
0005432927934	18544	Business	70400.00
0005433192941	18544	Economy	23500.00
0005433524862	18544	Economy	23500.00
0005432927935	18544	Economy	23500.00
0005433192943	18544	Economy	23500.00
0005433524859	18544	Economy	23500.00
0005433724727	18544	Economy	23500.00
0005433192944	18544	Economy	23500.00
0005433724726	18544	Economy	23500.00
0005433192936	18544	Economy	25800.00
0005434586206	18544	Economy	23500.00
0005433524857	18544	Economy	23500.00
0005434586224	18544	Economy	23500.00
0005433524850	18544	Economy	23500.00
0005434586242	18544	Economy	23500.00
0005434586248	18544	Economy	23500.00
0005434586225	18544	Economy	23500.00
0005432927932	18544	Economy	23500.00
0005434586245	18544	Economy	23500.00
0005433192938	18544	Economy	23500.00
0005434586226	18544	Economy	23500.00
0005433192939	18544	Economy	23500.00
0005433524872	18544	Economy	23500.00
0005433524863	18544	Economy	23500.00
0005433192935	18544	Economy	23500.00
0005432927933	18544	Economy	23500.00
0005434586251	18544	Economy	23500.00
0005432968820	18544	Economy	23500.00
0005434586249	18544	Economy	23500.00
0005432968822	18544	Economy	23500.00
0005433192933	18544	Economy	23500.00
0005434586227	18544	Economy	23500.00
0005433192934	18544	Economy	23500.00
0005434586181	18544	Economy	23500.00
0005433524873	18544	Economy	23500.00
0005434514921	18544	Economy	23500.00
0005432927931	18544	Economy	23500.00
0005433192937	18544	Economy	23500.00
0005433524858	18544	Economy	23500.00
0005433724734	18544	Economy	23500.00
0005433524849	18544	Economy	23500.00
0005433192942	18544	Economy	23500.00
0005432968821	18544	Economy	23500.00
0005434343882	11448	Economy	4300.00
0005434343895	11448	Economy	4300.00
0005434343874	11448	Economy	4300.00
0005434142578	11448	Economy	4300.00
0005434343879	11448	Economy	4000.00
0005434142577	11448	Economy	4000.00
0005434343901	11448	Economy	4000.00
0005434343880	11448	Economy	4000.00
0005434343878	11448	Economy	4000.00
0005434343886	11448	Economy	4000.00
0005434343910	11448	Economy	4000.00
0005435302120	11448	Economy	4000.00
0005434343899	11448	Economy	4000.00
0005434142581	11448	Economy	4000.00
0005434343890	11448	Economy	4000.00
0005434343885	11448	Economy	4000.00
0005434343889	11448	Economy	4000.00
0005434343904	11448	Economy	4000.00
0005434343891	11448	Economy	4000.00
0005434343894	11448	Economy	4000.00
0005434343896	11448	Economy	4000.00
0005435304990	11448	Economy	4000.00
0005434343909	11448	Economy	4000.00
0005434343902	11448	Economy	4000.00
0005434343897	11448	Economy	4000.00
0005434343908	11448	Economy	4000.00
0005434142580	11448	Economy	4000.00
0005434343898	11448	Economy	4000.00
0005434343888	11448	Economy	4000.00
0005435304991	11448	Economy	4000.00
0005434343907	11448	Economy	4000.00
0005434343875	11448	Economy	4000.00
0005434343877	11448	Economy	4000.00
0005434343892	11448	Economy	4000.00
0005434343903	11448	Economy	4000.00
0005434343881	11448	Economy	4000.00
0005434343906	11448	Economy	4000.00
0005434343876	11448	Economy	4000.00
0005434343893	11448	Economy	4000.00
0005434343883	11448	Economy	4000.00
0005434343905	11448	Economy	4000.00
0005434343884	11448	Economy	4000.00
0005434142579	11448	Economy	4000.00
0005434343887	11448	Economy	4000.00
0005434343900	11448	Economy	4000.00
0005434343621	29748	Economy	4300.00
0005434343663	29748	Economy	4300.00
0005434343709	29748	Economy	4300.00
0005434343672	29748	Economy	4300.00
0005434343599	29748	Economy	4000.00
0005434343648	29748	Economy	4000.00
0005434343583	29748	Economy	4000.00
0005434343664	29748	Economy	4000.00
0005434343597	29748	Economy	4000.00
0005434343609	29748	Economy	4000.00
0005434343587	29748	Economy	4000.00
0005434343598	29748	Economy	4000.00
0005434343703	29748	Economy	4000.00
0005434343710	29748	Economy	4000.00
0005434343605	29748	Economy	4000.00
0005435304125	29748	Economy	4000.00
0005434343649	29748	Economy	4000.00
0005434142540	29748	Economy	4000.00
0005434343589	29748	Economy	4000.00
0005434343628	29748	Economy	4000.00
0005435304122	29748	Economy	4000.00
0005435304126	29748	Economy	4000.00
0005434343606	29748	Economy	4000.00
0005434343699	29748	Economy	4000.00
0005434343611	29748	Economy	4000.00
0005434343631	29748	Economy	4000.00
0005435304123	29748	Economy	4000.00
0005434343673	29748	Economy	4000.00
0005434343684	29748	Economy	4000.00
0005434343630	29748	Economy	4000.00
0005434343645	29748	Economy	4000.00
0005434343610	29748	Economy	4000.00
0005435304124	29748	Economy	4000.00
0005434142544	29748	Economy	4000.00
0005434343588	29748	Economy	4000.00
0005435824412	1306	Business	199800.00
0005433415463	1306	Business	199800.00
0005435824420	1306	Business	199800.00
0005433415396	1306	Business	199800.00
0005433415412	1306	Business	199800.00
0005432284533	1306	Business	199800.00
0005433415411	1306	Business	199800.00
0005435824424	1306	Business	199800.00
0005435824418	1306	Business	199800.00
0005435824411	1306	Economy	66600.00
0005432284534	1306	Economy	66600.00
0005433415458	1306	Economy	66600.00
0005433415432	1306	Economy	66600.00
0005435824413	1306	Economy	66600.00
0005435824400	1306	Economy	66600.00
0005435824421	1306	Economy	73200.00
0005435824422	1306	Economy	73200.00
0005435824414	1306	Economy	66600.00
0005435824416	1306	Economy	66600.00
0005435824401	1306	Economy	66600.00
0005433415484	1306	Economy	66600.00
0005433415435	1306	Economy	66600.00
0005433415386	1306	Economy	66600.00
0005435824425	1306	Economy	66600.00
0005435824406	1306	Economy	66600.00
0005435824417	1306	Economy	66600.00
0005433415423	1306	Economy	66600.00
0005435824403	1306	Economy	66600.00
0005433415408	1306	Economy	66600.00
0005435824423	1306	Economy	66600.00
0005435824404	1306	Economy	66600.00
0005435824409	1306	Economy	66600.00
0005435824410	1306	Economy	66600.00
0005433415409	1306	Economy	66600.00
0005435824407	1306	Economy	66600.00
0005433415436	1306	Economy	66600.00
0005432284535	1306	Economy	66600.00
0005435824405	1306	Economy	66600.00
0005433415464	1306	Economy	66600.00
0005433415431	1306	Economy	66600.00
0005435824419	1306	Economy	66600.00
0005433415406	1306	Economy	66600.00
0005435824408	1306	Economy	66600.00
0005433415456	1306	Economy	66600.00
0005433415395	1306	Economy	66600.00
0005435824415	1306	Economy	66600.00
0005435824402	1306	Economy	66600.00
0005433415531	18020	Business	199800.00
0005435824261	18020	Business	199800.00
0005435824260	18020	Business	199800.00
0005435824224	18020	Business	199800.00
0005435824187	18020	Economy	66600.00
0005433415534	18020	Economy	66600.00
0005433415525	18020	Economy	66600.00
0005435824209	18020	Economy	66600.00
0005435824157	18020	Economy	66600.00
0005433415528	18020	Economy	66600.00
0005435824217	18020	Economy	66600.00
0005433415539	18020	Economy	66600.00
0005433415536	18020	Economy	66600.00
0005433415540	18020	Economy	66600.00
0005435824218	18020	Economy	66600.00
0005435824195	18020	Economy	66600.00
0005435824186	18020	Economy	66600.00
0005433415535	18020	Economy	66600.00
0005433415530	18020	Economy	66600.00
0005435824207	18020	Economy	66600.00
0005433415526	18020	Economy	66600.00
0005433415538	18020	Economy	66600.00
0005435824208	18020	Economy	66600.00
0005435824152	18020	Economy	66600.00
0005433415532	18020	Economy	66600.00
0005433415529	18020	Economy	66600.00
0005435824190	18020	Economy	66600.00
0005435824196	18020	Economy	66600.00
0005433415527	18020	Economy	66600.00
0005433415537	18020	Economy	66600.00
0005433415533	18020	Economy	66600.00
0005435242432	5655	Business	27800.00
0005432783376	5655	Business	27800.00
0005432783340	5655	Business	27800.00
0005432783339	5655	Business	27800.00
0005432783361	5655	Business	27800.00
0005435242475	5655	Business	27800.00
0005432783386	5655	Business	27800.00
0005432783345	5655	Business	27800.00
0005432783388	5655	Business	27800.00
0005432783373	5655	Business	27800.00
0005432783351	5655	Economy	9300.00
0005432783337	5655	Economy	9300.00
0005432783370	5655	Economy	9300.00
0005432783343	5655	Economy	9300.00
0005432783367	5655	Economy	9300.00
0005432783389	5655	Economy	9300.00
0005435242396	5655	Economy	9300.00
0005432783355	5655	Economy	9300.00
0005435242437	5655	Economy	10200.00
0005435242430	5655	Economy	10200.00
0005432783366	5655	Economy	10200.00
0005432783365	5655	Economy	10200.00
0005435242398	5655	Economy	10200.00
0005432783354	5655	Economy	9300.00
0005432783357	5655	Economy	9300.00
0005432783384	5655	Economy	9300.00
0005435242397	5655	Economy	9300.00
0005432783364	5655	Economy	9300.00
0005435242452	5655	Economy	9300.00
0005432783372	5655	Economy	9300.00
0005435476644	5655	Economy	9300.00
0005435242450	5655	Economy	9300.00
0005432783377	5655	Economy	9300.00
0005432783341	5655	Economy	9300.00
0005432783380	5655	Economy	9300.00
0005435476637	5655	Economy	9300.00
0005432783353	5655	Economy	9300.00
0005435242453	5655	Economy	9300.00
0005435242513	5655	Economy	9300.00
0005432783335	5655	Economy	9300.00
0005432783356	5655	Economy	9300.00
0005432783371	5655	Economy	9300.00
0005432783382	5655	Economy	9300.00
0005432783383	5655	Economy	9300.00
0005432783363	5655	Economy	9300.00
0005435242476	5655	Economy	9300.00
0005432783346	5655	Economy	9300.00
0005432783379	5655	Economy	9300.00
0005432783369	5655	Economy	9300.00
0005435476640	5655	Economy	9300.00
0005435242405	5655	Economy	9300.00
0005432783342	5655	Economy	9300.00
0005432783375	5655	Economy	9300.00
0005432783390	5655	Economy	9300.00
0005432783349	5655	Economy	9300.00
0005432783348	5655	Economy	9300.00
0005432783385	5655	Economy	9300.00
0005432783338	5655	Economy	9300.00
0005435242429	5655	Economy	9300.00
0005435242431	5655	Economy	9300.00
0005432783358	5655	Economy	9300.00
0005435476643	5655	Economy	9300.00
0005432783347	5655	Economy	9300.00
0005432783360	5655	Economy	9300.00
0005432783336	5655	Economy	9300.00
0005432783387	5655	Economy	9300.00
0005432783378	5655	Economy	9300.00
0005432783374	5655	Economy	9300.00
0005432783350	5655	Economy	9300.00
0005432783368	5655	Economy	9300.00
0005432143962	5655	Economy	9300.00
0005435242402	5655	Economy	9300.00
0005432783352	5655	Economy	9300.00
0005432783344	5655	Economy	9300.00
0005432783362	5655	Economy	9300.00
0005432783359	5655	Economy	9300.00
0005435242446	5655	Economy	9300.00
0005432783381	5655	Economy	9300.00
0005435242624	15390	Business	27800.00
0005432783237	15390	Business	27800.00
0005432782962	15390	Business	27800.00
0005432782838	15390	Business	27800.00
0005432782908	15390	Business	27800.00
0005432782877	15390	Business	27800.00
0005432782865	15390	Business	27800.00
0005435476708	15390	Business	27800.00
0005432782889	15390	Business	27800.00
0005435242634	15390	Economy	9300.00
0005432782864	15390	Economy	9300.00
0005435242616	15390	Economy	9300.00
0005432782873	15390	Economy	9300.00
0005432782888	15390	Economy	9300.00
0005432782947	15390	Economy	10200.00
0005432782857	15390	Economy	10200.00
0005432782918	15390	Economy	10200.00
0005435242618	15390	Economy	9300.00
0005435242628	15390	Economy	9300.00
0005435242615	15390	Economy	9300.00
0005435242623	15390	Economy	9300.00
0005435242621	15390	Economy	9300.00
0005432782882	15390	Economy	9300.00
0005432782881	15390	Economy	9300.00
0005432782916	15390	Economy	9300.00
0005435242619	15390	Economy	9300.00
0005435476707	15390	Economy	9300.00
0005435242617	15390	Economy	9300.00
0005432782946	15390	Economy	9300.00
0005435242613	15390	Economy	9300.00
0005435242631	15390	Economy	9300.00
0005435242630	15390	Economy	9300.00
0005432782851	15390	Economy	9300.00
0005435242611	15390	Economy	9300.00
0005435242627	15390	Economy	9300.00
0005435242612	15390	Economy	9300.00
0005435476706	15390	Economy	9300.00
0005432782964	15390	Economy	9300.00
0005435242635	15390	Economy	9300.00
0005432782931	15390	Economy	9300.00
0005435242629	15390	Economy	9300.00
0005432782930	15390	Economy	9300.00
0005435476705	15390	Economy	9300.00
0005435242626	15390	Economy	9300.00
0005432782948	15390	Economy	9300.00
0005432782929	15390	Economy	9300.00
0005435242622	15390	Economy	9300.00
0005435242636	15390	Economy	9300.00
0005435242625	15390	Economy	9300.00
0005432783024	15390	Economy	9300.00
0005432782886	15390	Economy	9300.00
0005432783015	15390	Economy	9300.00
0005435242632	15390	Economy	9300.00
0005435242614	15390	Economy	9300.00
0005435242620	15390	Economy	9300.00
0005432782850	15390	Economy	9300.00
0005432782906	15390	Economy	9300.00
0005435242633	15390	Economy	9300.00
0005432783238	15390	Economy	9300.00
0005432783014	15390	Economy	9300.00
0005435850752	4359	Economy	7000.00
0005432848193	4359	Economy	7000.00
0005435850765	4359	Economy	7000.00
0005435850753	4359	Economy	7000.00
0005432848191	4359	Economy	6300.00
0005435850804	4359	Economy	6300.00
0005432848201	4359	Economy	6300.00
0005434463912	4359	Economy	6300.00
0005435850788	4359	Economy	6300.00
0005435850766	4359	Economy	6300.00
0005435850789	4359	Economy	6300.00
0005432848196	4359	Economy	6300.00
0005432848202	4359	Economy	6300.00
0005432848203	4359	Economy	6300.00
0005434462772	4359	Economy	6300.00
0005432848194	4359	Economy	6300.00
0005432848199	4359	Economy	6300.00
0005435850779	4359	Economy	6300.00
0005435850773	4359	Economy	6300.00
0005435850771	4359	Economy	6300.00
0005435850778	4359	Economy	6300.00
0005434462773	4359	Economy	6300.00
0005432848198	4359	Economy	6300.00
0005434463911	4359	Economy	6300.00
0005435850803	4359	Economy	6300.00
0005435850809	4359	Economy	6300.00
0005435850780	4359	Economy	6300.00
0005432848192	4359	Economy	6300.00
0005435850776	4359	Economy	6300.00
0005432848200	4359	Economy	6300.00
0005434463913	4359	Economy	6300.00
0005432848197	4359	Economy	6300.00
0005432848189	4359	Economy	6300.00
0005432848195	4359	Economy	6300.00
0005432848190	4359	Economy	6300.00
0005435850769	4359	Economy	6300.00
0005435850787	4359	Economy	6300.00
0005432848107	28855	Economy	7000.00
0005435850839	28855	Economy	6300.00
0005435850841	28855	Economy	6300.00
0005432848109	28855	Economy	6300.00
0005435850832	28855	Economy	6300.00
0005434461610	28855	Economy	6300.00
0005432848112	28855	Economy	6300.00
0005432848108	28855	Economy	6300.00
0005435850833	28855	Economy	6300.00
0005432848111	28855	Economy	6300.00
0005435850840	28855	Economy	6300.00
0005434461609	28855	Economy	6300.00
0005435850835	28855	Economy	6300.00
0005432848078	28855	Economy	6300.00
0005435850837	28855	Economy	6300.00
0005435850836	28855	Economy	6300.00
0005435850834	28855	Economy	6300.00
0005435850838	28855	Economy	6300.00
0005432075203	6238	Business	11900.00
0005434925560	6238	Business	11900.00
0005434443578	6238	Business	11900.00
0005434443584	6238	Business	11900.00
0005433496710	6238	Business	11900.00
0005433496718	6238	Business	11900.00
0005433496737	6238	Business	11900.00
0005432075202	6238	Business	11900.00
0005433496722	6238	Business	11900.00
0005434925535	6238	Business	11900.00
0005434925534	6238	Business	11900.00
0005434925554	6238	Business	11900.00
0005434925540	6238	Economy	4000.00
0005434925561	6238	Economy	4000.00
0005434925547	6238	Economy	4000.00
0005433496715	6238	Economy	4000.00
0005433496734	6238	Economy	4000.00
0005434925557	6238	Economy	4000.00
0005433496720	6238	Economy	4000.00
0005432075201	6238	Economy	4000.00
0005434925559	6238	Economy	4000.00
0005434925566	6238	Economy	4000.00
0005433496708	6238	Economy	4400.00
0005434443574	6238	Economy	4400.00
0005433496725	6238	Economy	4400.00
0005434925562	6238	Economy	4400.00
0005434925548	6238	Economy	4000.00
0005434443589	6238	Economy	4000.00
0005433496736	6238	Economy	4000.00
0005434925569	6238	Economy	4000.00
0005434925550	6238	Economy	4000.00
0005434925571	6238	Economy	4000.00
0005434925538	6238	Economy	4000.00
0005433496726	6238	Economy	4000.00
0005434925565	6238	Economy	4000.00
0005434925564	6238	Economy	4000.00
0005434925543	6238	Economy	4000.00
0005433496713	6238	Economy	4000.00
0005434443588	6238	Economy	4000.00
0005434925546	6238	Economy	4000.00
0005434925570	6238	Economy	4000.00
0005433496712	6238	Economy	4000.00
0005433496730	6238	Economy	4000.00
0005433496724	6238	Economy	4000.00
0005434443583	6238	Economy	4000.00
0005434925556	6238	Economy	4000.00
0005433496735	6238	Economy	4000.00
0005433496711	6238	Economy	4000.00
0005434925542	6238	Economy	4000.00
0005434443581	6238	Economy	4000.00
0005434443572	6238	Economy	4000.00
0005434443580	6238	Economy	4000.00
0005434443579	6238	Economy	4000.00
0005434925553	6238	Economy	4000.00
0005434443576	6238	Economy	4000.00
0005434925544	6238	Economy	4000.00
0005434443573	6238	Economy	4000.00
0005433496716	6238	Economy	4000.00
0005433496723	6238	Economy	4000.00
0005433496733	6238	Economy	4000.00
0005433496729	6238	Economy	4000.00
0005434925536	6238	Economy	4000.00
0005434925549	6238	Economy	4000.00
0005434925537	6238	Economy	4000.00
0005433496732	6238	Economy	4000.00
0005434443575	6238	Economy	4000.00
0005433496727	6238	Economy	4000.00
0005433496717	6238	Economy	4000.00
0005434443587	6238	Economy	4000.00
0005434443585	6238	Economy	4000.00
0005433496719	6238	Economy	4000.00
0005434925555	6238	Economy	4000.00
0005434925545	6238	Economy	4000.00
0005433496728	6238	Economy	4000.00
0005433496721	6238	Economy	4000.00
0005434925567	6238	Economy	4000.00
0005433496731	6238	Economy	4000.00
0005433496714	6238	Economy	4000.00
0005434925551	6238	Economy	4000.00
0005434925533	6238	Economy	4000.00
0005434925563	6238	Economy	4000.00
0005434925552	6238	Economy	4000.00
0005434925558	6238	Economy	4000.00
0005434925568	6238	Economy	4000.00
0005434925539	6238	Economy	4000.00
0005434443582	6238	Economy	4000.00
0005434443577	6238	Economy	4000.00
0005433496707	6238	Economy	4000.00
0005434925541	6238	Economy	4000.00
0005433496709	6238	Economy	4000.00
0005434443586	6238	Economy	4000.00
0005434925249	20411	Business	11900.00
0005433496552	20411	Business	11900.00
0005433496488	20411	Business	11900.00
0005434925271	20411	Business	11900.00
0005433496470	20411	Business	11900.00
0005434443497	20411	Business	11900.00
0005433496550	20411	Economy	4000.00
0005434443425	20411	Economy	4000.00
0005433496521	20411	Economy	4000.00
0005433496446	20411	Economy	4000.00
0005434925310	20411	Economy	4000.00
0005434443479	20411	Economy	4400.00
0005433496509	20411	Economy	4400.00
0005434443446	20411	Economy	4400.00
0005434443460	20411	Economy	4400.00
0005433496487	20411	Economy	4000.00
0005433496598	20411	Economy	4000.00
0005433496574	20411	Economy	4000.00
0005433496458	20411	Economy	4000.00
0005433496522	20411	Economy	4000.00
0005434925252	20411	Economy	4000.00
0005434925272	20411	Economy	4000.00
0005433496489	20411	Economy	4000.00
0005434443478	20411	Economy	4000.00
0005433496508	20411	Economy	4000.00
0005433496618	20411	Economy	4000.00
0005433496597	20411	Economy	4000.00
0005433496463	20411	Economy	4000.00
0005434443459	20411	Economy	4000.00
0005434925250	20411	Economy	4000.00
0005433496573	20411	Economy	4000.00
0005433496507	20411	Economy	4000.00
0005434925291	20411	Economy	4000.00
0005434443504	20411	Economy	4000.00
0005433496551	20411	Economy	4000.00
0005434925279	20411	Economy	4000.00
0005434925247	20411	Economy	4000.00
0005434443438	20411	Economy	4000.00
0005434925270	20411	Economy	4000.00
0005434925292	20411	Economy	4000.00
0005434443452	20411	Economy	4000.00
0005434925261	20411	Economy	4000.00
0005433496457	20411	Economy	4000.00
0005433496566	20411	Economy	4000.00
0005433496565	20411	Economy	4000.00
0005433496641	20411	Economy	4000.00
0005435242654	12159	Business	41200.00
0005432782876	12159	Business	41200.00
0005432782924	12159	Business	41200.00
0005432783042	12159	Business	41200.00
0005435242659	12159	Business	41200.00
0005432782866	12159	Business	41200.00
0005432782854	12159	Economy	13700.00
0005435242660	12159	Economy	13700.00
0005432783089	12159	Economy	13700.00
0005435242658	12159	Economy	13700.00
0005432782923	12159	Economy	13700.00
0005435242655	12159	Economy	13700.00
0005435242637	12159	Economy	13700.00
0005435242645	12159	Economy	13700.00
0005432782894	12159	Economy	15100.00
0005432783057	12159	Economy	15100.00
0005432782956	12159	Economy	13700.00
0005432782943	12159	Economy	13700.00
0005432782961	12159	Economy	13700.00
0005432783112	12159	Economy	13700.00
0005435242647	12159	Economy	13700.00
0005435242641	12159	Economy	13700.00
0005432783193	12159	Economy	13700.00
0005432782909	12159	Economy	13700.00
0005435242662	12159	Economy	13700.00
0005432782853	12159	Economy	13700.00
0005435242657	12159	Economy	13700.00
0005432782922	12159	Economy	13700.00
0005435242648	12159	Economy	13700.00
0005435242640	12159	Economy	13700.00
0005432782987	12159	Economy	13700.00
0005432782846	12159	Economy	13700.00
0005432782875	12159	Economy	13700.00
0005435242643	12159	Economy	13700.00
0005435242649	12159	Economy	13700.00
0005435242639	12159	Economy	13700.00
0005435242651	12159	Economy	13700.00
0005432782988	12159	Economy	13700.00
0005432782856	12159	Economy	13700.00
0005435242638	12159	Economy	13700.00
0005435242653	12159	Economy	13700.00
0005432782944	12159	Economy	13700.00
0005432782983	12159	Economy	13700.00
0005435242663	12159	Economy	13700.00
0005435242650	12159	Economy	13700.00
0005432782855	12159	Economy	13700.00
0005432782960	12159	Economy	13700.00
0005432782841	12159	Economy	13700.00
0005432782939	12159	Economy	13700.00
0005435242646	12159	Economy	13700.00
0005432782895	12159	Economy	13700.00
0005432783192	12159	Economy	13700.00
0005435242656	12159	Economy	13700.00
0005432782936	12159	Economy	13700.00
0005435242642	12159	Economy	13700.00
0005432782993	12159	Economy	13700.00
0005435242644	12159	Economy	13700.00
0005435242652	12159	Economy	13700.00
0005432782867	12159	Economy	13700.00
0005435242661	12159	Economy	13700.00
0005432783316	15410	Business	41200.00
0005432783312	15410	Business	41200.00
0005432783297	15410	Business	41200.00
0005432783296	15410	Business	41200.00
0005432783283	15410	Business	41200.00
0005432783332	15410	Business	41200.00
0005435242392	15410	Business	41200.00
0005432783290	15410	Business	41200.00
0005432783315	15410	Business	41200.00
0005432783317	15410	Business	41200.00
0005432783307	15410	Economy	13700.00
0005435242416	15410	Economy	13700.00
0005432783326	15410	Economy	13700.00
0005432783304	15410	Economy	13700.00
0005432783303	15410	Economy	13700.00
0005432783325	15410	Economy	13700.00
0005432783308	15410	Economy	15100.00
0005435242424	15410	Economy	15100.00
0005435242458	15410	Economy	13700.00
0005432783331	15410	Economy	13700.00
0005432783300	15410	Economy	13700.00
0005432783319	15410	Economy	13700.00
0005432783294	15410	Economy	13700.00
0005435242468	15410	Economy	13700.00
0005432783285	15410	Economy	13700.00
0005432783322	15410	Economy	13700.00
0005432783301	15410	Economy	13700.00
0005432783314	15410	Economy	13700.00
0005432783279	15410	Economy	13700.00
0005432783327	15410	Economy	13700.00
0005432783289	15410	Economy	13700.00
0005435242409	15410	Economy	13700.00
0005435242425	15410	Economy	13700.00
0005432783298	15410	Economy	13700.00
0005432783328	15410	Economy	13700.00
0005432783333	15410	Economy	13700.00
0005432783288	15410	Economy	13700.00
0005432783329	15410	Economy	13700.00
0005432783324	15410	Economy	13700.00
0005432783284	15410	Economy	13700.00
0005432783334	15410	Economy	13700.00
0005432783318	15410	Economy	13700.00
0005432783287	15410	Economy	13700.00
0005432783302	15410	Economy	13700.00
0005432783305	15410	Economy	13700.00
0005432783313	15410	Economy	13700.00
0005432783286	15410	Economy	13700.00
0005435242410	15410	Economy	13700.00
0005432783282	15410	Economy	13700.00
0005432783306	15410	Economy	13700.00
0005432783310	15410	Economy	13700.00
0005432783280	15410	Economy	13700.00
0005432783281	15410	Economy	13700.00
0005432783291	15410	Economy	13700.00
0005432783309	15410	Economy	13700.00
0005432783293	15410	Economy	13700.00
0005432783321	15410	Economy	13700.00
0005432783330	15410	Economy	13700.00
0005432783311	15410	Economy	13700.00
0005435242391	15410	Economy	13700.00
0005432783323	15410	Economy	13700.00
0005435242408	15410	Economy	13700.00
0005432783295	15410	Economy	13700.00
0005432783299	15410	Economy	13700.00
0005435242388	15410	Economy	13700.00
0005432783320	15410	Economy	13700.00
0005432783292	15410	Economy	13700.00
0005434876908	10069	Business	49700.00
0005434876728	10069	Business	49700.00
0005434876629	10069	Business	49700.00
0005434877053	10069	Business	49700.00
0005434876900	10069	Business	49700.00
0005434910091	10069	Business	49700.00
0005435913907	10069	Business	49700.00
0005434876594	10069	Business	49700.00
0005434876778	10069	Business	49700.00
0005434876633	10069	Business	49700.00
0005434876895	10069	Business	49700.00
0005434876772	10069	Business	49700.00
0005434876894	10069	Business	49700.00
0005434876734	10069	Business	49700.00
0005434876644	10069	Business	49700.00
0005434758861	10069	Economy	16600.00
0005434876823	10069	Economy	16600.00
0005434876636	10069	Economy	16600.00
0005434876791	10069	Economy	16600.00
0005434876570	10069	Economy	16600.00
0005434876799	10069	Economy	16600.00
0005434877136	10069	Economy	16600.00
0005434876803	10069	Economy	16600.00
0005434876715	10069	Economy	18200.00
0005434876684	10069	Economy	18200.00
0005434876692	10069	Economy	18200.00
0005434876843	10069	Economy	18200.00
0005434876730	10069	Economy	16600.00
0005434876709	10069	Economy	16600.00
0005435913903	10069	Economy	16600.00
0005434876866	10069	Economy	16600.00
0005434876824	10069	Economy	16600.00
0005434876595	10069	Economy	16600.00
0005434876708	10069	Economy	16600.00
0005434876695	10069	Economy	16600.00
0005434758859	10069	Economy	16600.00
0005434876994	10069	Economy	16600.00
0005434876790	10069	Economy	16600.00
0005434877029	10069	Economy	16600.00
0005434876732	10069	Economy	16600.00
0005434876579	10069	Economy	16600.00
0005434876705	10069	Economy	16600.00
0005434876665	10069	Economy	16600.00
0005434876822	10069	Economy	16600.00
0005434758860	10069	Economy	16600.00
0005435913905	10069	Economy	16600.00
0005434876731	10069	Economy	16600.00
0005434876753	10069	Economy	16600.00
0005434876846	10069	Economy	16600.00
0005434877028	10069	Economy	16600.00
0005434876857	10069	Economy	16600.00
0005435913908	10069	Economy	16600.00
0005434876844	10069	Economy	16600.00
0005435913906	10069	Economy	16600.00
0005434876727	10069	Economy	16600.00
0005434876839	10069	Economy	16600.00
0005434877052	10069	Economy	16600.00
0005434876733	10069	Economy	16600.00
0005434876712	10069	Economy	16600.00
0005434876751	10069	Economy	16600.00
0005434876580	10069	Economy	16600.00
0005434876698	10069	Economy	16600.00
0005434876699	10069	Economy	16600.00
0005434876637	10069	Economy	16600.00
0005434876638	10069	Economy	16600.00
0005434876593	10069	Economy	16600.00
0005434876729	10069	Economy	16600.00
0005434876981	10069	Economy	16600.00
0005434876845	10069	Economy	16600.00
0005435913904	10069	Economy	16600.00
0005434910090	10069	Economy	16600.00
0005434876681	10069	Economy	16600.00
0005434877137	10069	Economy	16600.00
0005434876639	10069	Economy	16600.00
0005434876573	10069	Economy	16600.00
0005434877454	14628	Business	49700.00
0005434877446	14628	Business	49700.00
0005434877466	14628	Business	49700.00
0005434877499	14628	Business	49700.00
0005434877487	14628	Business	49700.00
0005434877508	14628	Business	49700.00
0005434877432	14628	Business	49700.00
0005434877493	14628	Business	49700.00
0005434877512	14628	Business	49700.00
0005434877484	14628	Business	49700.00
0005434877519	14628	Business	49700.00
0005434877491	14628	Business	49700.00
0005434877520	14628	Business	49700.00
0005434877428	14628	Business	49700.00
0005434877485	14628	Business	49700.00
0005434877482	14628	Business	49700.00
0005434877473	14628	Business	49700.00
0005434877510	14628	Economy	16600.00
0005434877504	14628	Economy	16600.00
0005434877436	14628	Economy	16600.00
0005434877516	14628	Economy	16600.00
0005434877501	14628	Economy	16600.00
0005434877502	14628	Economy	16600.00
0005434877461	14628	Economy	16600.00
0005434877513	14628	Economy	16600.00
0005434877481	14628	Economy	16600.00
0005434877445	14628	Economy	16600.00
0005434877460	14628	Economy	18200.00
0005434877435	14628	Economy	18200.00
0005434877438	14628	Economy	18200.00
0005434877439	14628	Economy	16600.00
0005434877474	14628	Economy	16600.00
0005434877440	14628	Economy	16600.00
0005434877470	14628	Economy	16600.00
0005434877457	14628	Economy	16600.00
0005434877472	14628	Economy	16600.00
0005434877496	14628	Economy	16600.00
0005434877521	14628	Economy	16600.00
0005434877434	14628	Economy	16600.00
0005434877518	14628	Economy	16600.00
0005434877500	14628	Economy	16600.00
0005434877433	14628	Economy	16600.00
0005434877522	14628	Economy	16600.00
0005434877465	14628	Economy	16600.00
0005434877468	14628	Economy	16600.00
0005434877448	14628	Economy	16600.00
0005434877451	14628	Economy	16600.00
0005434877514	14628	Economy	16600.00
0005434877447	14628	Economy	16600.00
0005434877458	14628	Economy	16600.00
0005434877515	14628	Economy	16600.00
0005434877509	14628	Economy	16600.00
0005434877430	14628	Economy	16600.00
0005434877455	14628	Economy	16600.00
0005434877477	14628	Economy	16600.00
0005434877494	14628	Economy	16600.00
0005434877444	14628	Economy	16600.00
0005434877503	14628	Economy	16600.00
0005434877490	14628	Economy	16600.00
0005434877495	14628	Economy	16600.00
0005434877507	14628	Economy	16600.00
0005434877486	14628	Economy	16600.00
0005434877456	14628	Economy	16600.00
0005434877497	14628	Economy	16600.00
0005434758873	14628	Economy	16600.00
0005434877462	14628	Economy	16600.00
0005434877450	14628	Economy	16600.00
0005434877517	14628	Economy	16600.00
0005434877492	14628	Economy	16600.00
0005434877429	14628	Economy	16600.00
0005434877464	14628	Economy	16600.00
0005434877475	14628	Economy	16600.00
0005434877511	14628	Economy	16600.00
0005434877506	14628	Economy	16600.00
0005434877469	14628	Economy	16600.00
0005434758874	14628	Economy	16600.00
0005434877441	14628	Economy	16600.00
0005434877437	14628	Economy	16600.00
0005434758876	14628	Economy	16600.00
0005434877463	14628	Economy	16600.00
0005434877471	14628	Economy	16600.00
0005435913849	14628	Economy	16600.00
0005434877479	14628	Economy	16600.00
0005434877483	14628	Economy	16600.00
0005434877467	14628	Economy	16600.00
0005434877498	14628	Economy	16600.00
0005434877452	14628	Economy	16600.00
0005434877459	14628	Economy	16600.00
0005434877443	14628	Economy	16600.00
0005434877453	14628	Economy	16600.00
0005434758875	14628	Economy	16600.00
0005434877431	14628	Economy	16600.00
0005434877505	14628	Economy	16600.00
0005434877488	14628	Economy	16600.00
0005434877449	14628	Economy	16600.00
0005434877476	14628	Economy	16600.00
0005434877478	14628	Economy	16600.00
0005434877442	14628	Economy	16600.00
0005434877489	14628	Economy	16600.00
0005434877480	14628	Economy	16600.00
0005435660046	9209	Economy	22400.00
0005434251831	9209	Economy	22400.00
0005435660043	9209	Economy	20300.00
0005435660051	9209	Economy	20300.00
0005434251825	9209	Economy	20300.00
0005435660047	9209	Economy	20300.00
0005435660042	9209	Economy	20300.00
0005435660048	9209	Economy	20300.00
0005435660049	9209	Economy	20300.00
0005434251830	9209	Economy	20300.00
0005435660050	9209	Economy	20300.00
0005435660041	9209	Economy	20300.00
0005435660040	9209	Economy	20300.00
0005435660045	9209	Economy	20300.00
0005435660044	9209	Economy	20300.00
0005434251887	24624	Economy	20300.00
0005434251890	24624	Economy	20300.00
0005435659968	24624	Economy	20300.00
0005434251884	24624	Economy	20300.00
0005434251885	24624	Economy	20300.00
0005434251886	24624	Economy	20300.00
0005435659969	24624	Economy	20300.00
0005434251889	24624	Economy	20300.00
0005435659945	24624	Economy	20300.00
0005434251891	24624	Economy	20300.00
0005435660003	24624	Economy	20300.00
0005434251888	24624	Economy	20300.00
0005435659975	24624	Economy	20300.00
0005435659944	24624	Economy	20300.00
0005434251892	24624	Economy	20300.00
0005433680168	2769	Business	33000.00
0005433680193	2769	Business	33000.00
0005433680156	2769	Business	33000.00
0005432966527	2769	Business	33000.00
0005433680157	2769	Business	33000.00
0005432222741	2769	Business	33000.00
0005433680152	2769	Business	33000.00
0005433680185	2769	Business	33000.00
0005433680175	2769	Business	33000.00
0005433680177	2769	Economy	11000.00
0005432222737	2769	Economy	11000.00
0005433680194	2769	Economy	11000.00
0005432222736	2769	Economy	11000.00
0005433680189	2769	Economy	11000.00
0005433680178	2769	Economy	11000.00
0005433680160	2769	Economy	11000.00
0005433680171	2769	Economy	12100.00
0005432222738	2769	Economy	12100.00
0005433680180	2769	Economy	12100.00
0005433680153	2769	Economy	11000.00
0005433680172	2769	Economy	11000.00
0005432966555	2769	Economy	11000.00
0005433680165	2769	Economy	11000.00
0005432966516	2769	Economy	11000.00
0005433680179	2769	Economy	11000.00
0005432966545	2769	Economy	11000.00
0005433684402	2769	Economy	11000.00
0005432222739	2769	Economy	11000.00
0005433680162	2769	Economy	11000.00
0005432966528	2769	Economy	11000.00
0005432966537	2769	Economy	11000.00
0005433680182	2769	Economy	11000.00
0005433680187	2769	Economy	11000.00
0005433680174	2769	Economy	11000.00
0005432222740	2769	Economy	11000.00
0005433680167	2769	Economy	11000.00
0005433680150	2769	Economy	11000.00
0005433680192	2769	Economy	11000.00
0005433680173	2769	Economy	11000.00
0005433680149	2769	Economy	11000.00
0005433680195	2769	Economy	11000.00
0005433680170	2769	Economy	11000.00
0005433680186	2769	Economy	11000.00
0005433680151	2769	Economy	11000.00
0005433680166	2769	Economy	11000.00
0005433680158	2769	Economy	11000.00
0005433680196	2769	Economy	11000.00
0005433680176	2769	Economy	11000.00
0005432966532	2769	Economy	11000.00
0005433680155	2769	Economy	11000.00
0005433680181	2769	Economy	11000.00
0005433680164	2769	Economy	11000.00
0005433680184	2769	Economy	11000.00
0005433680190	2769	Economy	11000.00
0005433680161	2769	Economy	11000.00
0005432966556	2769	Economy	11000.00
0005432966597	2769	Economy	11000.00
0005433680169	2769	Economy	11000.00
0005433680183	2769	Economy	11000.00
0005432966596	2769	Economy	11000.00
0005433680159	2769	Economy	11000.00
0005433680191	2769	Economy	11000.00
0005433684401	2769	Economy	11000.00
0005432966535	2769	Economy	11000.00
0005433680163	2769	Economy	11000.00
0005433680154	2769	Economy	11000.00
0005433680188	2769	Economy	11000.00
0005433690894	29182	Business	33000.00
0005433679804	29182	Business	33000.00
0005432005190	29182	Business	33000.00
0005432966726	29182	Business	33000.00
0005432966721	29182	Business	33000.00
0005432966729	29182	Business	33000.00
0005433679760	29182	Business	33000.00
0005433679759	29182	Business	33000.00
0005433679709	29182	Business	33000.00
0005432966737	29182	Business	33000.00
0005432966731	29182	Business	33000.00
0005433679782	29182	Business	33000.00
0005432966724	29182	Economy	11000.00
0005432966719	29182	Economy	11000.00
0005433679779	29182	Economy	11000.00
0005433679778	29182	Economy	11000.00
0005433679983	29182	Economy	11000.00
0005433679851	29182	Economy	11000.00
0005432005192	29182	Economy	11000.00
0005432966727	29182	Economy	12100.00
0005433679922	29182	Economy	12100.00
0005433679920	29182	Economy	12100.00
0005432005189	29182	Economy	12100.00
0005432966725	29182	Economy	11000.00
0005432966732	29182	Economy	11000.00
0005432966735	29182	Economy	11000.00
0005433679801	29182	Economy	11000.00
0005432966738	29182	Economy	11000.00
0005433679931	29182	Economy	11000.00
0005432966730	29182	Economy	11000.00
0005433679813	29182	Economy	11000.00
0005432966733	29182	Economy	11000.00
0005433684390	29182	Economy	11000.00
0005433679953	29182	Economy	11000.00
0005433679811	29182	Economy	11000.00
0005432966740	29182	Economy	11000.00
0005433679789	29182	Economy	11000.00
0005433679899	29182	Economy	11000.00
0005433679841	29182	Economy	11000.00
0005433679825	29182	Economy	11000.00
0005433679863	29182	Economy	11000.00
0005432966717	29182	Economy	11000.00
0005433679919	29182	Economy	11000.00
0005433679860	29182	Economy	11000.00
0005432966728	29182	Economy	11000.00
0005433679900	29182	Economy	11000.00
0005433679952	29182	Economy	11000.00
0005432966722	29182	Economy	11000.00
0005433679861	29182	Economy	11000.00
0005433679719	29182	Economy	11000.00
0005433684392	29182	Economy	11000.00
0005432966723	29182	Economy	11000.00
0005432966718	29182	Economy	11000.00
0005433679862	29182	Economy	11000.00
0005432966739	29182	Economy	11000.00
0005433679872	29182	Economy	11000.00
0005433679857	29182	Economy	11000.00
0005432966736	29182	Economy	11000.00
0005432005191	29182	Economy	11000.00
0005433679907	29182	Economy	11000.00
0005433690899	29182	Economy	11000.00
0005433679814	29182	Economy	11000.00
0005432966720	29182	Economy	11000.00
0005433679923	29182	Economy	11000.00
0005433679944	29182	Economy	11000.00
0005433679873	29182	Economy	11000.00
0005433679800	29182	Economy	11000.00
0005433679917	29182	Economy	11000.00
0005432966734	29182	Economy	11000.00
0005433679824	29182	Economy	11000.00
0005432966716	29182	Economy	11000.00
0005433679718	29182	Economy	11000.00
0005433679712	29182	Economy	11000.00
0005433679738	29182	Economy	11000.00
0005433679783	29182	Economy	11000.00
0005433633505	9281	Business	132900.00
0005433614005	9281	Business	132900.00
0005433614052	9281	Business	132900.00
0005433577695	9281	Business	132900.00
0005433614032	9281	Business	132900.00
0005433613997	9281	Business	132900.00
0005433614014	9281	Business	132900.00
0005432145093	9281	Business	132900.00
0005433614036	9281	Business	132900.00
0005433577696	9281	Business	132900.00
0005433613986	9281	Business	132900.00
0005433614001	9281	Business	132900.00
0005433614015	9281	Business	132900.00
0005433614044	9281	Business	132900.00
0005433614004	9281	Business	132900.00
0005433633492	9281	Business	132900.00
0005433633501	9281	Business	132900.00
0005433614040	9281	Business	132900.00
0005433633513	9281	Business	132900.00
0005433633519	9281	Business	132900.00
0005433633514	9281	Business	132900.00
0005433633509	9281	Business	132900.00
0005433577686	9281	Business	132900.00
0005433577693	9281	Business	132900.00
0005433614025	9281	Business	132900.00
0005432756819	9281	Economy	48700.00
0005433614043	9281	Economy	48700.00
0005433614006	9281	Economy	48700.00
0005433614057	9281	Economy	48700.00
0005433633495	9281	Economy	48700.00
0005433614022	9281	Economy	44300.00
0005433614026	9281	Economy	44300.00
0005433614021	9281	Economy	44300.00
0005433577687	9281	Economy	44300.00
0005433633517	9281	Economy	44300.00
0005433614046	9281	Economy	44300.00
0005433633521	9281	Economy	44300.00
0005433614042	9281	Economy	44300.00
0005432756820	9281	Economy	44300.00
0005433633506	9281	Economy	44300.00
0005433577697	9281	Economy	44300.00
0005433614039	9281	Economy	44300.00
0005433577694	9281	Economy	44300.00
0005432755045	9281	Economy	44300.00
0005433614010	9281	Economy	44300.00
0005433577689	9281	Economy	44300.00
0005433614028	9281	Economy	44300.00
0005433614055	9281	Economy	44300.00
0005433613991	9281	Economy	44300.00
0005433633498	9281	Economy	44300.00
0005433614003	9281	Economy	44300.00
0005433613992	9281	Economy	44300.00
0005433614041	9281	Economy	44300.00
0005432756818	9281	Economy	44300.00
0005433633504	9281	Economy	44300.00
0005433633520	9281	Economy	44300.00
0005434163480	9281	Economy	44300.00
0005433633524	9281	Economy	44300.00
0005433633500	9281	Economy	44300.00
0005433613994	9281	Economy	44300.00
0005434163506	9281	Economy	44300.00
0005433633499	9281	Economy	44300.00
0005434152755	9281	Economy	44300.00
0005433633512	9281	Economy	44300.00
0005432755046	9281	Economy	44300.00
0005433614017	9281	Economy	44300.00
0005432755047	9281	Economy	44300.00
0005433613990	9281	Economy	44300.00
0005434163482	9281	Economy	44300.00
0005433614038	9281	Economy	44300.00
0005433633496	9281	Economy	44300.00
0005433633497	9281	Economy	44300.00
0005433614007	9281	Economy	44300.00
0005434272170	9281	Economy	44300.00
0005434163468	9281	Economy	44300.00
0005433614024	9281	Economy	44300.00
0005433613995	9281	Economy	44300.00
0005433614054	9281	Economy	44300.00
0005433614019	9281	Economy	44300.00
0005433633494	9281	Economy	44300.00
0005434163478	9281	Economy	44300.00
0005433633493	9281	Economy	44300.00
0005433577685	9281	Economy	44300.00
0005433614023	9281	Economy	48700.00
0005433577691	9281	Economy	48700.00
0005433633515	9281	Economy	48700.00
0005433633525	9281	Economy	48700.00
0005433614030	9281	Economy	48700.00
0005433614034	9281	Economy	44300.00
0005433614047	9281	Economy	44300.00
0005433614049	9281	Economy	44300.00
0005433613993	9281	Economy	48700.00
0005433633502	9281	Economy	44300.00
0005433633511	9281	Economy	44300.00
0005433614009	9281	Economy	44300.00
0005433614027	9281	Economy	44300.00
0005433614012	9281	Economy	44300.00
0005433614048	9281	Economy	44300.00
0005433613985	9281	Economy	44300.00
0005433614011	9281	Economy	44300.00
0005434272169	9281	Economy	44300.00
0005433613987	9281	Economy	44300.00
0005433633526	9281	Economy	44300.00
0005433633523	9281	Economy	44300.00
0005433577690	9281	Economy	44300.00
0005433614051	9281	Economy	44300.00
0005433613988	9281	Economy	44300.00
0005433613989	9281	Economy	44300.00
0005433577692	9281	Economy	44300.00
0005433614002	9281	Economy	44300.00
0005433633508	9281	Economy	44300.00
0005433614053	9281	Economy	44300.00
0005434163481	9281	Economy	44300.00
0005433633516	9281	Economy	44300.00
0005433633522	9281	Economy	44300.00
0005433614008	9281	Economy	44300.00
0005433614031	9281	Economy	44300.00
0005432755048	9281	Economy	44300.00
0005434163469	9281	Economy	44300.00
0005433633518	9281	Economy	44300.00
0005433614059	9281	Economy	44300.00
0005433613999	9281	Economy	44300.00
0005433614037	9281	Economy	44300.00
0005433614016	9281	Economy	44300.00
0005433633510	9281	Economy	44300.00
0005433614033	9281	Economy	44300.00
0005433614013	9281	Economy	44300.00
0005433577698	9281	Economy	44300.00
0005433613998	9281	Economy	44300.00
0005433613996	9281	Economy	44300.00
0005433614029	9281	Economy	44300.00
0005433633503	9281	Economy	44300.00
0005433614035	9281	Economy	44300.00
0005433614000	9281	Economy	44300.00
0005433614018	9281	Economy	44300.00
0005434163479	9281	Economy	44300.00
0005434163466	9281	Economy	44300.00
0005433614050	9281	Economy	44300.00
0005433577688	9281	Economy	44300.00
0005433633507	9281	Economy	44300.00
0005433614058	9281	Economy	44300.00
0005433614045	9281	Economy	44300.00
0005433614056	9281	Economy	44300.00
0005433614020	9281	Economy	44300.00
0005433613447	25264	Business	132900.00
0005433577563	25264	Business	132900.00
0005434272176	25264	Business	132900.00
0005433633336	25264	Business	132900.00
0005434273062	25264	Business	132900.00
0005433613561	25264	Business	132900.00
0005433633248	25264	Business	132900.00
0005433633227	25264	Business	132900.00
0005433613546	25264	Business	132900.00
0005434163537	25264	Economy	48700.00
0005434163547	25264	Economy	48700.00
0005433613460	25264	Economy	44300.00
0005433577581	25264	Economy	44300.00
0005433613710	25264	Economy	44300.00
0005433613562	25264	Economy	44300.00
0005433633284	25264	Economy	44300.00
0005433633279	25264	Economy	44300.00
0005433613652	25264	Economy	44300.00
0005433613545	25264	Economy	44300.00
0005433577612	25264	Economy	44300.00
0005433613633	25264	Economy	44300.00
0005434163541	25264	Economy	44300.00
0005433613392	25264	Economy	44300.00
0005434163539	25264	Economy	44300.00
0005434272177	25264	Economy	44300.00
0005433613395	25264	Economy	44300.00
0005433613437	25264	Economy	44300.00
0005433613454	25264	Economy	44300.00
0005433633251	25264	Economy	44300.00
0005433613535	25264	Economy	44300.00
0005434163540	25264	Economy	44300.00
0005435854045	25264	Economy	44300.00
0005433633363	25264	Economy	44300.00
0005433613653	25264	Economy	44300.00
0005434163543	25264	Economy	44300.00
0005433577580	25264	Economy	44300.00
0005433613523	25264	Economy	44300.00
0005433633250	25264	Economy	44300.00
0005434163544	25264	Economy	44300.00
0005434163546	25264	Economy	44300.00
0005433613518	25264	Economy	44300.00
0005434163542	25264	Economy	48700.00
0005433613413	25264	Economy	48700.00
0005433613566	25264	Economy	48700.00
0005433613663	25264	Economy	48700.00
0005433613522	25264	Economy	44300.00
0005433613448	25264	Economy	44300.00
0005434163548	25264	Economy	44300.00
0005434163545	25264	Economy	44300.00
0005433613393	25264	Economy	44300.00
0005433577611	25264	Economy	44300.00
0005433613662	25264	Economy	44300.00
0005433633290	25264	Economy	44300.00
0005433577614	25264	Economy	44300.00
0005433613455	25264	Economy	44300.00
0005433613405	25264	Economy	44300.00
0005433613503	25264	Economy	44300.00
0005433613412	25264	Economy	44300.00
0005433613664	25264	Economy	44300.00
0005435854046	25264	Economy	44300.00
0005433613406	25264	Economy	44300.00
0005433613567	25264	Economy	44300.00
0005434163538	25264	Economy	44300.00
0005433633254	25264	Economy	44300.00
0005433633283	25264	Economy	44300.00
0005433577595	25264	Economy	44300.00
0005433613505	25264	Economy	44300.00
0005433613519	25264	Economy	44300.00
0005433613394	25264	Economy	44300.00
0005433613660	25264	Economy	44300.00
0005433633285	25264	Economy	44300.00
0005433633297	25264	Economy	44300.00
0005433633271	25264	Economy	44300.00
0005435854047	25264	Economy	44300.00
0005435947038	4233	Business	193100.00
0005435986710	4233	Economy	64400.00
0005435986709	4233	Economy	64400.00
0005435947016	4233	Economy	64400.00
0005435986714	4233	Economy	64400.00
0005435787320	4233	Economy	64400.00
0005435947028	4233	Economy	64400.00
0005434271281	4233	Economy	64400.00
0005435947036	4233	Economy	64400.00
0005435947037	4233	Economy	64400.00
0005435986707	4233	Economy	64400.00
0005435986713	4233	Economy	64400.00
0005435947003	4233	Economy	64400.00
0005435986711	4233	Economy	70800.00
0005435986708	4233	Economy	64400.00
0005435947030	4233	Economy	64400.00
0005435986715	4233	Economy	64400.00
0005432184928	4233	Economy	64400.00
0005435986712	4233	Economy	64400.00
0005432571258	4233	Economy	64400.00
0005435856133	4233	Economy	64400.00
0005435947031	4233	Economy	64400.00
0005432571292	26607	Business	193100.00
0005435856169	26607	Business	193100.00
0005435947135	26607	Business	193100.00
0005435947145	26607	Business	193100.00
0005435856168	26607	Economy	64400.00
0005435787338	26607	Economy	64400.00
0005435947144	26607	Economy	64400.00
0005435856170	26607	Economy	64400.00
0005432571293	26607	Economy	64400.00
0005435947143	26607	Economy	64400.00
0005435947136	26607	Economy	64400.00
0005435856171	26607	Economy	64400.00
0005435787340	26607	Economy	64400.00
0005435947133	26607	Economy	64400.00
0005435787339	26607	Economy	64400.00
0005435947139	26607	Economy	64400.00
0005435947138	26607	Economy	64400.00
0005435947140	26607	Economy	64400.00
0005432571294	26607	Economy	64400.00
0005435947134	26607	Economy	64400.00
0005435947142	26607	Economy	64400.00
0005435947132	26607	Economy	64400.00
0005435947141	26607	Economy	64400.00
0005435856172	26607	Economy	64400.00
0005435947137	26607	Economy	64400.00
0005433074241	315	Business	21500.00
0005432947955	315	Business	21500.00
0005432947824	315	Business	21500.00
0005433568567	315	Business	21500.00
0005432947779	315	Business	21500.00
0005433568550	315	Business	21500.00
0005433074216	315	Business	21500.00
0005433568587	315	Business	21500.00
0005433568592	315	Business	21500.00
0005433568595	315	Business	21500.00
0005433568597	315	Business	21500.00
0005433129201	315	Business	21500.00
0005433568559	315	Business	21500.00
0005433568600	315	Business	21500.00
0005432947823	315	Business	21500.00
0005433074217	315	Business	21500.00
0005432238889	315	Business	21500.00
0005433074280	315	Business	21500.00
0005433568575	315	Economy	7900.00
0005433568588	315	Economy	7900.00
0005433568590	315	Economy	7900.00
0005433074215	315	Economy	7900.00
0005432947899	315	Economy	7900.00
0005433568593	315	Economy	7200.00
0005432947915	315	Economy	7200.00
0005433568558	315	Economy	7200.00
0005433568544	315	Economy	7200.00
0005433568605	315	Economy	7200.00
0005433568548	315	Economy	7200.00
0005432947954	315	Economy	7200.00
0005433568594	315	Economy	7200.00
0005432947881	315	Economy	7200.00
0005433074251	315	Economy	7200.00
0005433568546	315	Economy	7200.00
0005433568585	315	Economy	7200.00
0005432947916	315	Economy	7200.00
0005433568564	315	Economy	7200.00
0005432238884	315	Economy	7200.00
0005433074300	315	Economy	7200.00
0005433568549	315	Economy	7200.00
0005433074296	315	Economy	7200.00
0005433568547	315	Economy	7200.00
0005433074256	315	Economy	7200.00
0005433568562	315	Economy	7200.00
0005433568573	315	Economy	7200.00
0005433568561	315	Economy	7200.00
0005433568563	315	Economy	7200.00
0005432238887	315	Economy	7200.00
0005432947825	315	Economy	7200.00
0005433134058	315	Economy	7200.00
0005433568582	315	Economy	7200.00
0005432238886	315	Economy	7200.00
0005432238885	315	Economy	7200.00
0005433568602	315	Economy	7200.00
0005433074214	315	Economy	7200.00
0005433568599	315	Economy	7200.00
0005433568579	315	Economy	7200.00
0005432947917	315	Economy	7200.00
0005433568552	315	Economy	7200.00
0005432947803	315	Economy	7200.00
0005433568591	315	Economy	7200.00
0005433074297	315	Economy	7200.00
0005433568572	315	Economy	7200.00
0005433568569	315	Economy	7200.00
0005433568598	315	Economy	7200.00
0005433568571	315	Economy	7200.00
0005433074211	315	Economy	7900.00
0005433074328	315	Economy	7900.00
0005433568556	315	Economy	7900.00
0005432947882	315	Economy	7900.00
0005433074225	315	Economy	7200.00
0005433568578	315	Economy	7200.00
0005433568554	315	Economy	7200.00
0005433568601	315	Economy	7200.00
0005433568551	315	Economy	7900.00
0005433074212	315	Economy	7200.00
0005433074213	315	Economy	7200.00
0005433568584	315	Economy	7200.00
0005433074363	315	Economy	7200.00
0005432947956	315	Economy	7200.00
0005433074255	315	Economy	7200.00
0005433568580	315	Economy	7200.00
0005433568570	315	Economy	7200.00
0005433568545	315	Economy	7200.00
0005433568555	315	Economy	7200.00
0005433074275	315	Economy	7200.00
0005433074334	315	Economy	7200.00
0005433568553	315	Economy	7200.00
0005433568576	315	Economy	7200.00
0005433568586	315	Economy	7200.00
0005433074299	315	Economy	7200.00
0005432947953	315	Economy	7200.00
0005433568604	315	Economy	7200.00
0005433074252	315	Economy	7200.00
0005433568583	315	Economy	7200.00
0005432947931	315	Economy	7200.00
0005433568565	315	Economy	7200.00
0005433074281	315	Economy	7200.00
0005433074230	315	Economy	7200.00
0005433129200	315	Economy	7200.00
0005433074257	315	Economy	7200.00
0005433568574	315	Economy	7200.00
0005433568577	315	Economy	7200.00
0005433568581	315	Economy	7200.00
0005433074231	315	Economy	7200.00
0005433074333	315	Economy	7200.00
0005433074277	315	Economy	7200.00
0005433568568	315	Economy	7200.00
0005433568589	315	Economy	7200.00
0005432238888	315	Economy	7200.00
0005432947857	315	Economy	7200.00
0005433568603	315	Economy	7200.00
0005433568596	315	Economy	7200.00
0005433568560	315	Economy	7200.00
0005433568557	315	Economy	7200.00
0005433568566	315	Economy	7200.00
0005432947932	315	Economy	7200.00
0005433074470	11597	Business	21500.00
0005432948117	11597	Business	21500.00
0005432948114	11597	Business	21500.00
0005432948126	11597	Business	21500.00
0005433074461	11597	Business	21500.00
0005432948129	11597	Business	21500.00
0005432948125	11597	Business	21500.00
0005433074486	11597	Business	21500.00
0005433074469	11597	Business	21500.00
0005433134098	11597	Business	21500.00
0005432948121	11597	Business	21500.00
0005432948109	11597	Business	21500.00
0005432192295	11597	Business	21500.00
0005432948134	11597	Business	21500.00
0005433074464	11597	Economy	7900.00
0005433074484	11597	Economy	7900.00
0005432948135	11597	Economy	7900.00
0005432192292	11597	Economy	7200.00
0005433074460	11597	Economy	7200.00
0005433074468	11597	Economy	7200.00
0005433131673	11597	Economy	7200.00
0005433074462	11597	Economy	7200.00
0005432948136	11597	Economy	7200.00
0005433568082	11597	Economy	7200.00
0005432948111	11597	Economy	7200.00
0005433568076	11597	Economy	7200.00
0005433074472	11597	Economy	7200.00
0005432948107	11597	Economy	7200.00
0005432948115	11597	Economy	7200.00
0005433074466	11597	Economy	7200.00
0005433568073	11597	Economy	7200.00
0005433131671	11597	Economy	7200.00
0005433568071	11597	Economy	7200.00
0005433074482	11597	Economy	7200.00
0005433568070	11597	Economy	7200.00
0005433134102	11597	Economy	7200.00
0005432948120	11597	Economy	7200.00
0005433074467	11597	Economy	7200.00
0005432948124	11597	Economy	7200.00
0005433134099	11597	Economy	7200.00
0005432192293	11597	Economy	7200.00
0005432948108	11597	Economy	7200.00
0005433074478	11597	Economy	7200.00
0005433131672	11597	Economy	7200.00
0005432948105	11597	Economy	7200.00
0005432948131	11597	Economy	7200.00
0005433074459	11597	Economy	7200.00
0005433568027	11597	Economy	7200.00
0005433568033	11597	Economy	7200.00
0005433074480	11597	Economy	7900.00
0005432948110	11597	Economy	7900.00
0005433568023	11597	Economy	7900.00
0005433568072	11597	Economy	7900.00
0005433074476	11597	Economy	7200.00
0005432948132	11597	Economy	7200.00
0005433074481	11597	Economy	7200.00
0005432948097	11597	Economy	7200.00
0005432948138	11597	Economy	7200.00
0005432948099	11597	Economy	7200.00
0005432948116	11597	Economy	7200.00
0005433074487	11597	Economy	7200.00
0005432948127	11597	Economy	7200.00
0005433074485	11597	Economy	7200.00
0005432948137	11597	Economy	7200.00
0005433134101	11597	Economy	7200.00
0005432948130	11597	Economy	7200.00
0005433074477	11597	Economy	7200.00
0005433074475	11597	Economy	7200.00
0005433131669	11597	Economy	7200.00
0005432948123	11597	Economy	7200.00
0005433074474	11597	Economy	7200.00
0005432948102	11597	Economy	7200.00
0005432948106	11597	Economy	7200.00
0005432948112	11597	Economy	7200.00
0005432192294	11597	Economy	7200.00
0005432948104	11597	Economy	7200.00
0005432948119	11597	Economy	7200.00
0005433074471	11597	Economy	7200.00
0005433131670	11597	Economy	7200.00
0005432948101	11597	Economy	7200.00
0005433074473	11597	Economy	7200.00
0005432948118	11597	Economy	7200.00
0005432948098	11597	Economy	7200.00
0005433074483	11597	Economy	7200.00
0005433074463	11597	Economy	7200.00
0005432948133	11597	Economy	7200.00
0005433131668	11597	Economy	7200.00
0005433074479	11597	Economy	7200.00
0005432948100	11597	Economy	7200.00
0005433074465	11597	Economy	7200.00
0005432948128	11597	Economy	7200.00
0005432948113	11597	Economy	7200.00
0005432948122	11597	Economy	7200.00
0005432948103	11597	Economy	7200.00
0005433134100	11597	Economy	7200.00
0005433817439	9984	Economy	6300.00
0005434732933	9984	Economy	6300.00
0005433817438	9984	Economy	6300.00
0005433817440	9984	Economy	6300.00
0005433817441	9984	Economy	6300.00
0005434732926	9984	Economy	6300.00
0005434732927	9984	Economy	6300.00
0005434732928	9984	Economy	6300.00
0005434732953	14002	Economy	6300.00
0005433817427	14002	Economy	6300.00
0005434732951	14002	Economy	6300.00
0005434732952	14002	Economy	6300.00
0005434732954	14002	Economy	6300.00
0005432984553	2350	Business	184500.00
0005435981947	2350	Business	184500.00
0005435981927	2350	Business	184500.00
0005432984600	2350	Business	184500.00
0005432984583	2350	Business	184500.00
0005435981937	2350	Business	184500.00
0005435981960	2350	Business	184500.00
0005432869420	2350	Business	184500.00
0005433753766	2350	Business	184500.00
0005433753794	2350	Business	184500.00
0005433434218	2350	Business	184500.00
0005433753754	2350	Business	184500.00
0005433753782	2350	Business	184500.00
0005432984555	2350	Business	184500.00
0005435981953	2350	Business	184500.00
0005433434259	2350	Business	184500.00
0005432226009	2350	Business	184500.00
0005432984581	2350	Business	184500.00
0005435981936	2350	Business	184500.00
0005433753772	2350	Business	184500.00
0005432984539	2350	Business	184500.00
0005432984562	2350	Business	184500.00
0005433753758	2350	Business	184500.00
0005435981938	2350	Business	184500.00
0005432300214	2350	Economy	67700.00
0005435981958	2350	Economy	61500.00
0005433753748	2350	Economy	61500.00
0005433753759	2350	Economy	61500.00
0005432984559	2350	Economy	61500.00
0005433753784	2350	Economy	61500.00
0005433753762	2350	Economy	61500.00
0005432226007	2350	Economy	61500.00
0005433753780	2350	Economy	61500.00
0005434731098	2350	Economy	61500.00
0005433753745	2350	Economy	61500.00
0005433753761	2350	Economy	61500.00
0005433753760	2350	Economy	61500.00
0005433753769	2350	Economy	61500.00
0005435981928	2350	Economy	61500.00
0005432655444	2350	Economy	61500.00
0005433764663	2350	Economy	61500.00
0005432655436	2350	Economy	61500.00
0005432655441	2350	Economy	61500.00
0005432226008	2350	Economy	61500.00
0005433753795	2350	Economy	61500.00
0005432984603	2350	Economy	61500.00
0005433753793	2350	Economy	61500.00
0005435981959	2350	Economy	61500.00
0005433766609	2350	Economy	61500.00
0005432226005	2350	Economy	61500.00
0005433434235	2350	Economy	61500.00
0005433753749	2350	Economy	61500.00
0005433434260	2350	Economy	61500.00
0005433434261	2350	Economy	61500.00
0005435981925	2350	Economy	61500.00
0005432984627	2350	Economy	61500.00
0005433753757	2350	Economy	61500.00
0005432655438	2350	Economy	61500.00
0005432984588	2350	Economy	61500.00
0005433753781	2350	Economy	61500.00
0005435981946	2350	Economy	61500.00
0005433766608	2350	Economy	61500.00
0005435981950	2350	Economy	61500.00
0005435981934	2350	Economy	61500.00
0005435981945	2350	Economy	61500.00
0005435981952	2350	Economy	61500.00
0005432300218	2350	Economy	61500.00
0005433753776	2350	Economy	61500.00
0005435981949	2350	Economy	61500.00
0005433753742	2350	Economy	61500.00
0005433753783	2350	Economy	61500.00
0005433753790	2350	Economy	61500.00
0005435981951	2350	Economy	61500.00
0005433753775	2350	Economy	61500.00
0005432984636	2350	Economy	61500.00
0005433753755	2350	Economy	61500.00
0005432300216	2350	Economy	61500.00
0005432655442	2350	Economy	61500.00
0005432984584	2350	Economy	61500.00
0005433753739	2350	Economy	61500.00
0005433753791	2350	Economy	61500.00
0005433753764	2350	Economy	61500.00
0005433753768	2350	Economy	61500.00
0005432984612	2350	Economy	61500.00
0005433753752	2350	Economy	61500.00
0005433753774	2350	Economy	61500.00
0005435981926	2350	Economy	61500.00
0005433753786	2350	Economy	61500.00
0005432984633	2350	Economy	61500.00
0005432300215	2350	Economy	61500.00
0005432655440	2350	Economy	61500.00
0005433434234	2350	Economy	61500.00
0005433753777	2350	Economy	61500.00
0005432300217	2350	Economy	61500.00
0005432226004	2350	Economy	61500.00
0005432300220	2350	Economy	61500.00
0005435981935	2350	Economy	61500.00
0005435981942	2350	Economy	61500.00
0005432655447	2350	Economy	61500.00
0005433753787	2350	Economy	67700.00
0005433753773	2350	Economy	67700.00
0005433753765	2350	Economy	61500.00
0005433434270	2350	Economy	61500.00
0005433753751	2350	Economy	67700.00
0005433753750	2350	Economy	61500.00
0005432655448	2350	Economy	61500.00
0005433753779	2350	Economy	61500.00
0005432655446	2350	Economy	61500.00
0005433753778	2350	Economy	61500.00
0005432300219	2350	Economy	61500.00
0005433753770	2350	Economy	61500.00
0005433753744	2350	Economy	61500.00
0005432984533	2350	Economy	61500.00
0005435981944	2350	Economy	61500.00
0005435981961	2350	Economy	61500.00
0005432984727	2350	Economy	61500.00
0005432984579	2350	Economy	61500.00
0005435981930	2350	Economy	61500.00
0005433753756	2350	Economy	61500.00
0005433764662	2350	Economy	61500.00
0005433434258	2350	Economy	61500.00
0005432984556	2350	Economy	61500.00
0005433753789	2350	Economy	61500.00
0005432655439	2350	Economy	61500.00
0005432655437	2350	Economy	61500.00
0005435981929	2350	Economy	61500.00
0005433434257	2350	Economy	61500.00
0005435981932	2350	Economy	61500.00
0005433753747	2350	Economy	61500.00
0005432655443	2350	Economy	61500.00
0005433434223	2350	Economy	61500.00
0005433434236	2350	Economy	61500.00
0005435981954	2350	Economy	61500.00
0005432869419	2350	Economy	61500.00
0005435981940	2350	Economy	61500.00
0005432984632	2350	Economy	61500.00
0005435981957	2350	Economy	61500.00
0005432984580	2350	Economy	61500.00
0005433753792	2350	Economy	61500.00
0005434731106	2350	Economy	61500.00
0005433753746	2350	Economy	61500.00
0005433753740	2350	Economy	61500.00
0005435981955	2350	Economy	61500.00
0005433753796	2350	Economy	61500.00
0005435981933	2350	Economy	61500.00
0005435981931	2350	Economy	61500.00
0005432226003	2350	Economy	61500.00
0005433753741	2350	Economy	61500.00
0005433434284	2350	Economy	61500.00
0005433753743	2350	Economy	61500.00
0005435981943	2350	Economy	61500.00
0005432984552	2350	Economy	61500.00
0005433434256	2350	Economy	61500.00
0005432655445	2350	Economy	61500.00
0005432984618	2350	Economy	61500.00
0005433753767	2350	Economy	61500.00
0005432984587	2350	Economy	61500.00
0005433753785	2350	Economy	61500.00
0005433434219	2350	Economy	61500.00
0005435981941	2350	Economy	61500.00
0005433753763	2350	Economy	61500.00
0005435981948	2350	Economy	61500.00
0005433434255	2350	Economy	61500.00
0005433434347	2350	Economy	61500.00
0005433753771	2350	Economy	61500.00
0005433434222	2350	Economy	61500.00
0005435981956	2350	Economy	61500.00
0005435981924	2350	Economy	61500.00
0005433753753	2350	Economy	61500.00
0005433766610	2350	Economy	61500.00
0005432226006	2350	Economy	61500.00
0005435981939	2350	Economy	61500.00
0005432984601	2350	Economy	61500.00
0005433753788	2350	Economy	61500.00
0005433434269	2350	Economy	61500.00
0005432984822	26188	Business	184500.00
0005433753224	26188	Business	184500.00
0005433753281	26188	Business	184500.00
0005435981522	26188	Business	184500.00
0005432984812	26188	Business	184500.00
0005433434452	26188	Business	184500.00
0005432984808	26188	Business	184500.00
0005433434461	26188	Business	184500.00
0005433753473	26188	Business	184500.00
0005433753369	26188	Business	184500.00
0005433753325	26188	Business	184500.00
0005432984810	26188	Business	184500.00
0005432051104	26188	Business	184500.00
0005433753222	26188	Business	184500.00
0005433434456	26188	Business	184500.00
0005432869468	26188	Business	184500.00
0005432984816	26188	Business	184500.00
0005432984815	26188	Business	184500.00
0005432984811	26188	Business	184500.00
0005435981546	26188	Business	184500.00
0005435981606	26188	Economy	67700.00
0005433766578	26188	Economy	61500.00
0005433434466	26188	Economy	61500.00
0005433753294	26188	Economy	61500.00
0005433434446	26188	Economy	61500.00
0005433753349	26188	Economy	61500.00
0005433753437	26188	Economy	61500.00
0005433434451	26188	Economy	61500.00
0005432049435	26188	Economy	61500.00
0005432655337	26188	Economy	61500.00
0005432869472	26188	Economy	61500.00
0005433753324	26188	Economy	61500.00
0005432051103	26188	Economy	61500.00
0005433753389	26188	Economy	61500.00
0005433434460	26188	Economy	61500.00
0005433434444	26188	Economy	61500.00
0005435981547	26188	Economy	61500.00
0005432984799	26188	Economy	61500.00
0005433434465	26188	Economy	61500.00
0005434731138	26188	Economy	61500.00
0005433753460	26188	Economy	61500.00
0005432984801	26188	Economy	61500.00
0005433753472	26188	Economy	61500.00
0005433434445	26188	Economy	61500.00
0005435981587	26188	Economy	61500.00
0005432984819	26188	Economy	61500.00
0005433753348	26188	Economy	61500.00
0005433434443	26188	Economy	61500.00
0005432984806	26188	Economy	61500.00
0005433753531	26188	Economy	61500.00
0005432655335	26188	Economy	61500.00
0005435981583	26188	Economy	61500.00
0005432869466	26188	Economy	61500.00
0005432051102	26188	Economy	61500.00
0005433753221	26188	Economy	61500.00
0005433434467	26188	Economy	61500.00
0005433753368	26188	Economy	61500.00
0005432049434	26188	Economy	61500.00
0005433753415	26188	Economy	61500.00
0005435981554	26188	Economy	61500.00
0005433753408	26188	Economy	61500.00
0005432984803	26188	Economy	61500.00
0005433766577	26188	Economy	61500.00
0005433434442	26188	Economy	61500.00
0005433753282	26188	Economy	61500.00
0005433753478	26188	Economy	61500.00
0005435981553	26188	Economy	61500.00
0005433753261	26188	Economy	61500.00
0005435981550	26188	Economy	61500.00
0005435981524	26188	Economy	61500.00
0005433753293	26188	Economy	61500.00
0005433434462	26188	Economy	61500.00
0005433434454	26188	Economy	61500.00
0005433753225	26188	Economy	61500.00
0005432869470	26188	Economy	61500.00
0005433434447	26188	Economy	61500.00
0005433434453	26188	Economy	61500.00
0005435981582	26188	Economy	61500.00
0005432984827	26188	Economy	61500.00
0005433434449	26188	Economy	61500.00
0005432984800	26188	Economy	61500.00
0005435981520	26188	Economy	61500.00
0005432984814	26188	Economy	61500.00
0005432049433	26188	Economy	61500.00
0005433753226	26188	Economy	61500.00
0005432869471	26188	Economy	61500.00
0005433753420	26188	Economy	61500.00
0005433753530	26188	Economy	61500.00
0005433753367	26188	Economy	61500.00
0005433434455	26188	Economy	67700.00
0005432984813	26188	Economy	67700.00
0005432984807	26188	Economy	61500.00
0005432984820	26188	Economy	67700.00
0005432984828	26188	Economy	61500.00
0005432984804	26188	Economy	61500.00
0005433753421	26188	Economy	61500.00
0005432869465	26188	Economy	61500.00
0005435981585	26188	Economy	61500.00
0005433434458	26188	Economy	61500.00
0005432984809	26188	Economy	61500.00
0005435981627	26188	Economy	61500.00
0005432051101	26188	Economy	61500.00
0005432984825	26188	Economy	61500.00
0005433434450	26188	Economy	61500.00
0005433434464	26188	Economy	61500.00
0005432984818	26188	Economy	61500.00
0005433766587	26188	Economy	61500.00
0005432984824	26188	Economy	61500.00
0005433753386	26188	Economy	61500.00
0005432984823	26188	Economy	61500.00
0005432984829	26188	Economy	61500.00
0005433434439	26188	Economy	61500.00
0005432869467	26188	Economy	61500.00
0005433753407	26188	Economy	61500.00
0005432984826	26188	Economy	61500.00
0005435981552	26188	Economy	61500.00
0005434731136	26188	Economy	61500.00
0005434731135	26188	Economy	61500.00
0005435981648	26188	Economy	61500.00
0005435981638	26188	Economy	61500.00
0005433434448	26188	Economy	61500.00
0005434731137	26188	Economy	61500.00
0005433753443	26188	Economy	61500.00
0005432984830	26188	Economy	61500.00
0005433753283	26188	Economy	61500.00
0005432984817	26188	Economy	61500.00
0005432984831	26188	Economy	61500.00
0005433753409	26188	Economy	61500.00
0005433753297	26188	Economy	61500.00
0005435981523	26188	Economy	61500.00
0005432984805	26188	Economy	61500.00
0005433434463	26188	Economy	61500.00
0005433753326	26188	Economy	61500.00
0005432655336	26188	Economy	61500.00
0005433434459	26188	Economy	61500.00
0005435981647	26188	Economy	61500.00
0005433753250	26188	Economy	61500.00
0005433764643	26188	Economy	61500.00
0005433434441	26188	Economy	61500.00
0005433434457	26188	Economy	61500.00
0005433753479	26188	Economy	61500.00
0005432984821	26188	Economy	61500.00
0005433753279	26188	Economy	61500.00
0005433434468	26188	Economy	61500.00
0005432984802	26188	Economy	61500.00
0005432869469	26188	Economy	61500.00
0005433434440	26188	Economy	61500.00
0005434374257	1495	Business	38900.00
0005434374277	1495	Business	38900.00
0005433461570	1495	Business	38900.00
0005434374291	1495	Business	38900.00
0005433150852	1495	Business	38900.00
0005434374270	1495	Business	38900.00
0005434374302	1495	Business	38900.00
0005434374305	1495	Business	38900.00
0005434029613	1495	Economy	13000.00
0005433150980	1495	Economy	13000.00
0005433150800	1495	Economy	13000.00
0005434374264	1495	Economy	13000.00
0005434374256	1495	Economy	13000.00
0005434374273	1495	Economy	13000.00
0005433150875	1495	Economy	13000.00
0005433150817	1495	Economy	13000.00
0005432267838	1495	Economy	13000.00
0005434374280	1495	Economy	13000.00
0005434374298	1495	Economy	13000.00
0005434374293	1495	Economy	13000.00
0005432267841	1495	Economy	13000.00
0005434374294	1495	Economy	13000.00
0005434374309	1495	Economy	13000.00
0005434374269	1495	Economy	13000.00
0005434374292	1495	Economy	13000.00
0005434374253	1495	Economy	13000.00
0005433764651	1495	Economy	13000.00
0005434374255	1495	Economy	13000.00
0005434374254	1495	Economy	13000.00
0005433460419	1495	Economy	13000.00
0005433150930	1495	Economy	13000.00
0005434374285	1495	Economy	13000.00
0005434374265	1495	Economy	13000.00
0005433150840	1495	Economy	13000.00
0005432267844	1495	Economy	13000.00
0005434374283	1495	Economy	13000.00
0005434374258	1495	Economy	14300.00
0005433150960	1495	Economy	14300.00
0005433150943	1495	Economy	14300.00
0005434374266	1495	Economy	14300.00
0005433150981	1495	Economy	13000.00
0005433150965	1495	Economy	13000.00
0005432267842	1495	Economy	13000.00
0005433150951	1495	Economy	13000.00
0005434374261	1495	Economy	13000.00
0005433150952	1495	Economy	13000.00
0005433150870	1495	Economy	13000.00
0005433150843	1495	Economy	13000.00
0005434374286	1495	Economy	13000.00
0005434374274	1495	Economy	13000.00
0005433150841	1495	Economy	13000.00
0005433150957	1495	Economy	13000.00
0005433150922	1495	Economy	13000.00
0005433461571	1495	Economy	13000.00
0005434374271	1495	Economy	13000.00
0005434374301	1495	Economy	13000.00
0005433150876	1495	Economy	13000.00
0005433150872	1495	Economy	13000.00
0005434374300	1495	Economy	13000.00
0005434374260	1495	Economy	13000.00
0005433150893	1495	Economy	13000.00
0005434374252	1495	Economy	13000.00
0005434374272	1495	Economy	13000.00
0005434374295	1495	Economy	13000.00
0005433150871	1495	Economy	13000.00
0005434374304	1495	Economy	13000.00
0005434374290	1495	Economy	13000.00
0005433150950	1495	Economy	13000.00
0005434374281	1495	Economy	13000.00
0005434374306	1495	Economy	13000.00
0005434374289	1495	Economy	13000.00
0005434374308	1495	Economy	13000.00
0005434374259	1495	Economy	13000.00
0005434374287	1495	Economy	13000.00
0005432267840	1495	Economy	13000.00
0005434374284	1495	Economy	13000.00
0005434374262	1495	Economy	13000.00
0005434374303	1495	Economy	13000.00
0005434374267	1495	Economy	13000.00
0005433931431	1495	Economy	13000.00
0005434374268	1495	Economy	13000.00
0005432267839	1495	Economy	13000.00
0005433150874	1495	Economy	13000.00
0005434374307	1495	Economy	13000.00
0005434374296	1495	Economy	13000.00
0005434374288	1495	Economy	13000.00
0005434374299	1495	Economy	13000.00
0005434374297	1495	Economy	13000.00
0005434374263	1495	Economy	13000.00
0005434374282	1495	Economy	13000.00
0005433150842	1495	Economy	13000.00
0005433150961	1495	Economy	13000.00
0005433150990	1495	Economy	13000.00
0005434374278	1495	Economy	13000.00
0005433150944	1495	Economy	13000.00
0005434374276	1495	Economy	13000.00
0005432267843	1495	Economy	13000.00
0005434374279	1495	Economy	13000.00
0005434374275	1495	Economy	13000.00
0005433150818	1495	Economy	13000.00
0005434373895	20110	Business	38900.00
0005433151134	20110	Business	38900.00
0005433151132	20110	Business	38900.00
0005432056266	20110	Business	38900.00
0005432056267	20110	Business	38900.00
0005433151122	20110	Business	38900.00
0005434373866	20110	Business	38900.00
0005434373948	20110	Business	38900.00
0005433151124	20110	Economy	13000.00
0005434373939	20110	Economy	13000.00
0005434374020	20110	Economy	13000.00
0005433151121	20110	Economy	13000.00
0005434374022	20110	Economy	13000.00
0005434373875	20110	Economy	13000.00
0005434374011	20110	Economy	13000.00
0005434374021	20110	Economy	13000.00
0005434373947	20110	Economy	13000.00
0005434373940	20110	Economy	13000.00
0005433931441	20110	Economy	13000.00
0005434373982	20110	Economy	13000.00
0005434373944	20110	Economy	13000.00
0005433764662	20110	Economy	13000.00
0005433151136	20110	Economy	13000.00
0005433151126	20110	Economy	13000.00
0005433151143	20110	Economy	13000.00
0005433151127	20110	Economy	13000.00
0005433151137	20110	Economy	13000.00
0005434373897	20110	Economy	13000.00
0005434373917	20110	Economy	13000.00
0005433151112	20110	Economy	13000.00
0005434374019	20110	Economy	13000.00
0005434373949	20110	Economy	13000.00
0005433151111	20110	Economy	13000.00
0005434373991	20110	Economy	14300.00
0005433151117	20110	Economy	14300.00
0005432056269	20110	Economy	14300.00
0005432056270	20110	Economy	13000.00
0005434373880	20110	Economy	13000.00
0005433151123	20110	Economy	13000.00
0005434373983	20110	Economy	13000.00
0005433151118	20110	Economy	13000.00
0005434373946	20110	Economy	13000.00
0005433151131	20110	Economy	13000.00
0005433151116	20110	Economy	13000.00
0005434029635	20110	Economy	13000.00
0005434373950	20110	Economy	13000.00
0005434029637	20110	Economy	13000.00
0005433764663	20110	Economy	13000.00
0005433151144	20110	Economy	13000.00
0005433151125	20110	Economy	13000.00
0005434373997	20110	Economy	13000.00
0005433151113	20110	Economy	13000.00
0005434373972	20110	Economy	13000.00
0005433151141	20110	Economy	13000.00
0005433151139	20110	Economy	13000.00
0005434373894	20110	Economy	13000.00
0005433931440	20110	Economy	13000.00
0005433151119	20110	Economy	13000.00
0005434373951	20110	Economy	13000.00
0005433151135	20110	Economy	13000.00
0005434374012	20110	Economy	13000.00
0005433151142	20110	Economy	13000.00
0005433151110	20110	Economy	13000.00
0005433151138	20110	Economy	13000.00
0005433151114	20110	Economy	13000.00
0005433151128	20110	Economy	13000.00
0005433151140	20110	Economy	13000.00
0005433151120	20110	Economy	13000.00
0005434373879	20110	Economy	13000.00
0005433151115	20110	Economy	13000.00
0005433151130	20110	Economy	13000.00
0005434373896	20110	Economy	13000.00
0005434029636	20110	Economy	13000.00
0005434374007	20110	Economy	13000.00
0005433151129	20110	Economy	13000.00
0005432056268	20110	Economy	13000.00
0005433151133	20110	Economy	13000.00
0005434373990	20110	Economy	13000.00
0005432424059	599	Business	27500.00
0005432424075	599	Business	27500.00
0005432282808	599	Business	27500.00
0005432282806	599	Business	27500.00
0005432424068	599	Business	27500.00
0005432424095	599	Business	27500.00
0005432424071	599	Business	27500.00
0005432424087	599	Business	27500.00
0005432424094	599	Business	27500.00
0005432424069	599	Economy	10100.00
0005432424061	599	Economy	10100.00
0005432424092	599	Economy	10100.00
0005432424096	599	Economy	10100.00
0005432282804	599	Economy	10100.00
0005432424080	599	Economy	10100.00
0005432282809	599	Economy	9200.00
0005432424081	599	Economy	9200.00
0005432424090	599	Economy	9200.00
0005432282807	599	Economy	9200.00
0005432424079	599	Economy	9200.00
0005432424082	599	Economy	9200.00
0005432424088	599	Economy	9200.00
0005432424076	599	Economy	9200.00
0005432424084	599	Economy	9200.00
0005432424083	599	Economy	9200.00
0005432424093	599	Economy	9200.00
0005432424063	599	Economy	9200.00
0005432424086	599	Economy	9200.00
0005432424073	599	Economy	9200.00
0005432424097	599	Economy	9200.00
0005432424074	599	Economy	9200.00
0005432424066	599	Economy	9200.00
0005432424067	599	Economy	10100.00
0005432424091	599	Economy	9200.00
0005432424070	599	Economy	9200.00
0005432424072	599	Economy	9200.00
0005432282810	599	Economy	9200.00
0005432282805	599	Economy	9200.00
0005432424064	599	Economy	9200.00
0005432424085	599	Economy	9200.00
0005432424077	599	Economy	9200.00
0005432424058	599	Economy	9200.00
0005432424062	599	Economy	9200.00
0005432282803	599	Economy	9200.00
0005432424065	599	Economy	9200.00
0005432424089	599	Economy	9200.00
0005432424060	599	Economy	9200.00
0005432424078	599	Economy	9200.00
0005433158114	12829	Business	27500.00
0005432302298	12829	Business	27500.00
0005432302302	12829	Economy	10100.00
0005432302300	12829	Economy	9200.00
0005433158115	12829	Economy	9200.00
0005432302301	12829	Economy	9200.00
0005432302299	12829	Economy	9200.00
0005433158112	12829	Economy	9200.00
0005434446483	12829	Economy	9200.00
0005434446482	12829	Economy	9200.00
0005433158113	12829	Economy	9200.00
0005432423616	12926	Business	27500.00
0005432423635	12926	Economy	9200.00
0005432423654	12926	Economy	9200.00
0005432423665	12926	Economy	9200.00
0005432423664	12926	Economy	9200.00
0005432423644	12926	Economy	9200.00
0005432423615	12926	Economy	9200.00
0005432423606	12926	Economy	10100.00
0005432423640	12926	Economy	9200.00
0005432423645	12926	Economy	9200.00
0005432423620	12926	Economy	9200.00
0005432423646	12926	Economy	9200.00
0005432423619	12926	Economy	9200.00
0005432423604	12926	Economy	9200.00
0005433057209	461	Business	24500.00
0005433684386	461	Business	24500.00
0005434023133	461	Business	24500.00
0005434023157	461	Business	24500.00
0005434023179	461	Business	24500.00
0005433057319	461	Business	24500.00
0005433057200	461	Business	24500.00
0005434023166	461	Business	24500.00
0005433057178	461	Business	24500.00
0005434023135	461	Business	24500.00
0005434023152	461	Business	24500.00
0005434028273	461	Business	24500.00
0005434028272	461	Business	24500.00
0005432235576	461	Business	24500.00
0005433057441	461	Business	24500.00
0005434023164	461	Business	24500.00
0005432235575	461	Business	24500.00
0005434023191	461	Economy	9000.00
0005433057389	461	Economy	8200.00
0005434023181	461	Economy	8200.00
0005434023171	461	Economy	8200.00
0005434023194	461	Economy	8200.00
0005433057206	461	Economy	8200.00
0005433057220	461	Economy	8200.00
0005434023176	461	Economy	8200.00
0005434023131	461	Economy	8200.00
0005432235578	461	Economy	8200.00
0005434031985	461	Economy	8200.00
0005434023168	461	Economy	8200.00
0005434031983	461	Economy	8200.00
0005433057238	461	Economy	8200.00
0005433057325	461	Economy	8200.00
0005432235573	461	Economy	8200.00
0005434023142	461	Economy	8200.00
0005434023180	461	Economy	8200.00
0005434023175	461	Economy	8200.00
0005434023187	461	Economy	8200.00
0005434023192	461	Economy	8200.00
0005434023160	461	Economy	8200.00
0005434023145	461	Economy	8200.00
0005434023128	461	Economy	8200.00
0005433057227	461	Economy	8200.00
0005433057326	461	Economy	8200.00
0005433057281	461	Economy	8200.00
0005434023165	461	Economy	8200.00
0005434023185	461	Economy	8200.00
0005432045597	461	Economy	8200.00
0005434023150	461	Economy	8200.00
0005434023158	461	Economy	8200.00
0005434023184	461	Economy	8200.00
0005434023146	461	Economy	8200.00
0005434023134	461	Economy	8200.00
0005432235577	461	Economy	8200.00
0005433057198	461	Economy	8200.00
0005434023156	461	Economy	8200.00
0005434023169	461	Economy	8200.00
0005434023163	461	Economy	8200.00
0005434023174	461	Economy	8200.00
0005434023183	461	Economy	8200.00
0005434023130	461	Economy	8200.00
0005434028274	461	Economy	8200.00
0005432235579	461	Economy	8200.00
0005434031982	461	Economy	8200.00
0005434023167	461	Economy	8200.00
0005434023139	461	Economy	8200.00
0005434023189	461	Economy	8200.00
0005433684388	461	Economy	8200.00
0005434023126	461	Economy	8200.00
0005434023143	461	Economy	8200.00
0005434023154	461	Economy	8200.00
0005434023144	461	Economy	8200.00
0005434023127	461	Economy	8200.00
0005434023153	461	Economy	8200.00
0005434023173	461	Economy	8200.00
0005434023147	461	Economy	9000.00
0005434023149	461	Economy	9000.00
0005433057317	461	Economy	8200.00
0005434023182	461	Economy	8200.00
0005432045596	461	Economy	8200.00
0005434023141	461	Economy	8200.00
0005434023162	461	Economy	8200.00
0005434023170	461	Economy	8200.00
0005433057316	461	Economy	8200.00
0005434031981	461	Economy	8200.00
0005433057199	461	Economy	8200.00
0005433057318	461	Economy	8200.00
0005434023136	461	Economy	8200.00
0005434023129	461	Economy	8200.00
0005434023188	461	Economy	8200.00
0005433929549	461	Economy	8200.00
0005434028271	461	Economy	8200.00
0005434023148	461	Economy	8200.00
0005434029634	461	Economy	8200.00
0005434023151	461	Economy	8200.00
0005433057235	461	Economy	8200.00
0005432235580	461	Economy	8200.00
0005433057207	461	Economy	8200.00
0005434023193	461	Economy	8200.00
0005434023172	461	Economy	8200.00
0005434023138	461	Economy	8200.00
0005434023161	461	Economy	8200.00
0005434023155	461	Economy	8200.00
0005434023186	461	Economy	8200.00
0005433057280	461	Economy	8200.00
0005434023137	461	Economy	8200.00
0005434029633	461	Economy	8200.00
0005432235574	461	Economy	8200.00
0005434023190	461	Economy	8200.00
0005434023159	461	Economy	8200.00
0005433057182	461	Economy	8200.00
0005434023178	461	Economy	8200.00
0005434023132	461	Economy	8200.00
0005434023177	461	Economy	8200.00
0005434031984	461	Economy	8200.00
0005434735614	461	Economy	8200.00
0005433684387	461	Economy	8200.00
0005434023140	461	Economy	8200.00
0005433057545	12665	Business	24500.00
0005434022663	12665	Business	24500.00
0005434022833	12665	Business	24500.00
0005434022533	12665	Business	24500.00
0005434022607	12665	Business	24500.00
0005434022804	12665	Business	24500.00
0005434022904	12665	Business	24500.00
0005434022588	12665	Business	24500.00
0005433684405	12665	Business	24500.00
0005434022832	12665	Business	24500.00
0005433057538	12665	Business	24500.00
0005433057540	12665	Economy	9000.00
0005434022636	12665	Economy	9000.00
0005434022587	12665	Economy	8200.00
0005433057566	12665	Economy	8200.00
0005434022530	12665	Economy	8200.00
0005433929578	12665	Economy	8200.00
0005434022605	12665	Economy	8200.00
0005433057551	12665	Economy	8200.00
0005433057570	12665	Economy	8200.00
0005433057565	12665	Economy	8200.00
0005434022642	12665	Economy	8200.00
0005433057550	12665	Economy	8200.00
0005433057559	12665	Economy	8200.00
0005433057556	12665	Economy	8200.00
0005434022761	12665	Economy	8200.00
0005433057554	12665	Economy	8200.00
0005434022653	12665	Economy	8200.00
0005434022748	12665	Economy	8200.00
0005432156331	12665	Economy	8200.00
0005434022646	12665	Economy	8200.00
0005434029613	12665	Economy	8200.00
0005433057578	12665	Economy	8200.00
0005433057542	12665	Economy	8200.00
0005434022573	12665	Economy	8200.00
0005434022578	12665	Economy	8200.00
0005433057555	12665	Economy	8200.00
0005434028252	12665	Economy	8200.00
0005433929579	12665	Economy	8200.00
0005434022686	12665	Economy	8200.00
0005433057553	12665	Economy	8200.00
0005433057547	12665	Economy	8200.00
0005433057541	12665	Economy	8200.00
0005434022903	12665	Economy	8200.00
0005433057549	12665	Economy	8200.00
0005434022563	12665	Economy	8200.00
0005433057574	12665	Economy	8200.00
0005434022712	12665	Economy	8200.00
0005434022535	12665	Economy	8200.00
0005433057560	12665	Economy	8200.00
0005434735648	12665	Economy	8200.00
0005433057562	12665	Economy	8200.00
0005433929580	12665	Economy	8200.00
0005434022606	12665	Economy	8200.00
0005434028246	12665	Economy	8200.00
0005434022614	12665	Economy	8200.00
0005433057544	12665	Economy	8200.00
0005433057569	12665	Economy	8200.00
0005432157476	12665	Economy	8200.00
0005434022622	12665	Economy	8200.00
0005433057571	12665	Economy	8200.00
0005434028248	12665	Economy	8200.00
0005433057543	12665	Economy	8200.00
0005433057561	12665	Economy	8200.00
0005434022834	12665	Economy	8200.00
0005433057539	12665	Economy	8200.00
0005434022620	12665	Economy	8200.00
0005434735645	12665	Economy	8200.00
0005432156332	12665	Economy	9000.00
0005433057573	12665	Economy	8200.00
0005434022685	12665	Economy	9000.00
0005434735646	12665	Economy	9000.00
0005434022608	12665	Economy	8200.00
0005434022841	12665	Economy	8200.00
0005432156327	12665	Economy	8200.00
0005434022623	12665	Economy	8200.00
0005434022647	12665	Economy	8200.00
0005433057563	12665	Economy	8200.00
0005434028253	12665	Economy	8200.00
0005434735649	12665	Economy	8200.00
0005434022619	12665	Economy	8200.00
0005434022902	12665	Economy	8200.00
0005433057572	12665	Economy	8200.00
0005433057575	12665	Economy	8200.00
0005432156328	12665	Economy	8200.00
0005433057579	12665	Economy	8200.00
0005434022714	12665	Economy	8200.00
0005432156329	12665	Economy	8200.00
0005433684404	12665	Economy	8200.00
0005433057568	12665	Economy	8200.00
0005434031946	12665	Economy	8200.00
0005432156330	12665	Economy	8200.00
0005433057576	12665	Economy	8200.00
0005433057558	12665	Economy	8200.00
0005434022641	12665	Economy	8200.00
0005434022666	12665	Economy	8200.00
0005433057567	12665	Economy	8200.00
0005432157475	12665	Economy	8200.00
0005434022540	12665	Economy	8200.00
0005434022711	12665	Economy	8200.00
0005434022742	12665	Economy	8200.00
0005434022715	12665	Economy	8200.00
0005432157477	12665	Economy	8200.00
0005434022739	12665	Economy	8200.00
0005433057557	12665	Economy	8200.00
0005434022922	12665	Economy	8200.00
0005433057548	12665	Economy	8200.00
0005434022609	12665	Economy	8200.00
0005434735647	12665	Economy	8200.00
0005434022536	12665	Economy	8200.00
0005434022703	12665	Economy	8200.00
0005433057546	12665	Economy	8200.00
0005433057577	12665	Economy	8200.00
0005434022727	12665	Economy	8200.00
0005433684403	12665	Economy	8200.00
0005433057552	12665	Economy	8200.00
0005433057564	12665	Economy	8200.00
0005434022662	12665	Economy	8200.00
0005434022710	12665	Economy	8200.00
0005434022611	12665	Economy	8200.00
0005434022601	12665	Economy	8200.00
0005433922567	2161	Business	34700.00
0005433922540	2161	Business	34700.00
0005433035589	2161	Business	34700.00
0005433922496	2161	Business	34700.00
0005433922547	2161	Business	34700.00
0005432231482	2161	Business	34700.00
0005433922549	2161	Business	34700.00
0005433922524	2161	Business	34700.00
0005433922546	2161	Business	34700.00
0005432749750	2161	Business	34700.00
0005433922528	2161	Business	34700.00
0005433922523	2161	Business	34700.00
0005433922501	2161	Business	34700.00
0005433922556	2161	Business	34700.00
0005433922568	2161	Business	34700.00
0005433922519	2161	Business	34700.00
0005433922481	2161	Business	34700.00
0005433931440	2161	Business	34700.00
0005433922525	2161	Business	34700.00
0005433922482	2161	Business	34700.00
0005433922495	2161	Economy	12700.00
0005433922542	2161	Business	34700.00
0005433035383	2161	Economy	12700.00
0005433922530	2161	Economy	12700.00
0005433922503	2161	Economy	11600.00
0005432231481	2161	Economy	11600.00
0005433922517	2161	Economy	11600.00
0005433035607	2161	Economy	11600.00
0005433922508	2161	Economy	11600.00
0005433035415	2161	Economy	11600.00
0005433922513	2161	Economy	11600.00
0005433922473	2161	Economy	11600.00
0005433922491	2161	Economy	11600.00
0005433035455	2161	Economy	11600.00
0005433035372	2161	Economy	11600.00
0005433922471	2161	Economy	11600.00
0005433922536	2161	Economy	11600.00
0005433922551	2161	Economy	11600.00
0005433922534	2161	Economy	11600.00
0005433922543	2161	Economy	11600.00
0005433922537	2161	Economy	11600.00
0005433035416	2161	Economy	11600.00
0005433922506	2161	Economy	11600.00
0005433922512	2161	Economy	11600.00
0005433922545	2161	Economy	11600.00
0005433922531	2161	Economy	11600.00
0005433922527	2161	Economy	11600.00
0005433922541	2161	Economy	11600.00
0005434028252	2161	Economy	11600.00
0005432231477	2161	Economy	11600.00
0005433922569	2161	Economy	11600.00
0005432044501	2161	Economy	11600.00
0005433922539	2161	Economy	11600.00
0005433922555	2161	Economy	11600.00
0005433922561	2161	Economy	11600.00
0005433035422	2161	Economy	11600.00
0005433922518	2161	Economy	11600.00
0005433922474	2161	Economy	11600.00
0005433035542	2161	Economy	11600.00
0005433922552	2161	Economy	11600.00
0005432231478	2161	Economy	11600.00
0005433035587	2161	Economy	11600.00
0005432231474	2161	Economy	11600.00
0005432231472	2161	Economy	11600.00
0005433922475	2161	Economy	11600.00
0005433922490	2161	Economy	11600.00
0005433922499	2161	Economy	11600.00
0005432231479	2161	Economy	11600.00
0005433922554	2161	Economy	11600.00
0005433922520	2161	Economy	11600.00
0005433922472	2161	Economy	11600.00
0005432749749	2161	Economy	11600.00
0005433035377	2161	Economy	11600.00
0005433922529	2161	Economy	11600.00
0005433035606	2161	Economy	11600.00
0005433922484	2161	Economy	11600.00
0005433922498	2161	Economy	11600.00
0005433922477	2161	Economy	11600.00
0005433922487	2161	Economy	11600.00
0005432044502	2161	Economy	11600.00
0005433922538	2161	Economy	11600.00
0005433922558	2161	Economy	11600.00
0005433922522	2161	Economy	11600.00
0005432231476	2161	Economy	11600.00
0005433922564	2161	Economy	11600.00
0005433929578	2161	Economy	11600.00
0005433922500	2161	Economy	11600.00
0005434028246	2161	Economy	11600.00
0005433922478	2161	Economy	11600.00
0005433922535	2161	Economy	11600.00
0005433035433	2161	Economy	11600.00
0005432231475	2161	Economy	11600.00
0005432231473	2161	Economy	11600.00
0005433922557	2161	Economy	11600.00
0005433922565	2161	Economy	11600.00
0005433035526	2161	Economy	12700.00
0005433922560	2161	Economy	12700.00
0005433922533	2161	Economy	11600.00
0005433922521	2161	Economy	11600.00
0005433922562	2161	Economy	11600.00
0005433922566	2161	Economy	11600.00
0005433035419	2161	Economy	11600.00
0005433931441	2161	Economy	11600.00
0005433922514	2161	Economy	11600.00
0005433922497	2161	Economy	11600.00
0005433922526	2161	Economy	11600.00
0005433922515	2161	Economy	11600.00
0005433035404	2161	Economy	11600.00
0005433035417	2161	Economy	11600.00
0005434028253	2161	Economy	11600.00
0005433035421	2161	Economy	11600.00
0005433035588	2161	Economy	11600.00
0005433922553	2161	Economy	11600.00
0005433922504	2161	Economy	11600.00
0005433922509	2161	Economy	11600.00
0005432044503	2161	Economy	11600.00
0005433922505	2161	Economy	11600.00
0005434028248	2161	Economy	11600.00
0005433922494	2161	Economy	11600.00
0005433035571	2161	Economy	11600.00
0005433875365	2161	Economy	11600.00
0005433922510	2161	Economy	11600.00
0005433922502	2161	Economy	11600.00
0005433922470	2161	Economy	11600.00
0005433922532	2161	Economy	11600.00
0005433035516	2161	Economy	11600.00
0005433922511	2161	Economy	11600.00
0005433922492	2161	Economy	11600.00
0005433922486	2161	Economy	11600.00
0005432231480	2161	Economy	11600.00
0005433035376	2161	Economy	11600.00
0005433922488	2161	Economy	11600.00
0005433035551	2161	Economy	11600.00
0005433922516	2161	Economy	11600.00
0005433922483	2161	Economy	11600.00
0005433922476	2161	Economy	11600.00
0005433929580	2161	Economy	11600.00
0005433922559	2161	Economy	11600.00
0005433922479	2161	Economy	11600.00
0005433922493	2161	Economy	11600.00
0005433922563	2161	Economy	11600.00
0005433922507	2161	Economy	11600.00
0005433922548	2161	Economy	11600.00
0005433922544	2161	Economy	11600.00
0005433929579	2161	Economy	11600.00
0005433035434	2161	Economy	11600.00
0005433035432	2161	Economy	11600.00
0005433035525	2161	Economy	11600.00
0005433922550	2161	Economy	11600.00
0005433922480	2161	Economy	11600.00
0005433922489	2161	Economy	11600.00
0005433922485	2161	Economy	11600.00
0005433921918	24132	Business	34700.00
0005433921852	24132	Business	34700.00
0005433921850	24132	Business	34700.00
0005433035856	24132	Business	34700.00
0005433035862	24132	Business	34700.00
0005433921748	24132	Business	34700.00
0005433921756	24132	Business	34700.00
0005433921642	24132	Business	34700.00
0005433035891	24132	Business	34700.00
0005433035885	24132	Business	34700.00
0005433035881	24132	Business	34700.00
0005433921862	24132	Business	34700.00
0005433921606	24132	Business	34700.00
0005433921905	24132	Business	34700.00
0005433035895	24132	Business	34700.00
0005433922070	24132	Business	34700.00
0005433921623	24132	Economy	12700.00
0005433035883	24132	Economy	12700.00
0005433929556	24132	Economy	12700.00
0005433921962	24132	Economy	12700.00
0005433921972	24132	Economy	11600.00
0005433035875	24132	Economy	11600.00
0005433035887	24132	Economy	11600.00
0005433921712	24132	Economy	11600.00
0005433035852	24132	Economy	11600.00
0005433035851	24132	Economy	11600.00
0005433921699	24132	Economy	11600.00
0005433922103	24132	Economy	11600.00
0005433921920	24132	Economy	11600.00
0005432207641	24132	Economy	11600.00
0005432206149	24132	Economy	11600.00
0005433921855	24132	Economy	11600.00
0005433035845	24132	Economy	11600.00
0005433921917	24132	Economy	11600.00
0005433921757	24132	Economy	11600.00
0005433035866	24132	Economy	11600.00
0005433929557	24132	Economy	11600.00
0005432206145	24132	Economy	11600.00
0005433921779	24132	Economy	11600.00
0005433035871	24132	Economy	11600.00
0005433035849	24132	Economy	11600.00
0005433035893	24132	Economy	11600.00
0005433921969	24132	Economy	11600.00
0005433035865	24132	Economy	11600.00
0005433035863	24132	Economy	11600.00
0005433931414	24132	Economy	11600.00
0005433035878	24132	Economy	11600.00
0005433035859	24132	Economy	11600.00
0005433921652	24132	Economy	11600.00
0005433035843	24132	Economy	11600.00
0005433035850	24132	Economy	11600.00
0005433922116	24132	Economy	11600.00
0005433035847	24132	Economy	11600.00
0005433035894	24132	Economy	11600.00
0005432206147	24132	Economy	11600.00
0005433035886	24132	Economy	11600.00
0005433921853	24132	Economy	11600.00
0005433035848	24132	Economy	11600.00
0005433035868	24132	Economy	11600.00
0005433921942	24132	Economy	11600.00
0005433921771	24132	Economy	11600.00
0005433921709	24132	Economy	11600.00
0005433035842	24132	Economy	11600.00
0005433035889	24132	Economy	11600.00
0005433035876	24132	Economy	11600.00
0005433921906	24132	Economy	11600.00
0005433035844	24132	Economy	11600.00
0005433921710	24132	Economy	11600.00
0005433921666	24132	Economy	11600.00
0005432749768	24132	Economy	11600.00
0005433921981	24132	Economy	11600.00
0005432206150	24132	Economy	11600.00
0005433035858	24132	Economy	11600.00
0005434028276	24132	Economy	11600.00
0005433035888	24132	Economy	11600.00
0005433035890	24132	Economy	11600.00
0005433921676	24132	Economy	11600.00
0005433035864	24132	Economy	11600.00
0005432206148	24132	Economy	11600.00
0005433921703	24132	Economy	11600.00
0005433921735	24132	Economy	11600.00
0005433921761	24132	Economy	11600.00
0005433931424	24132	Economy	11600.00
0005433921673	24132	Economy	11600.00
0005433921776	24132	Economy	11600.00
0005433921629	24132	Economy	11600.00
0005433929558	24132	Economy	11600.00
0005433035874	24132	Economy	11600.00
0005433921672	24132	Economy	12700.00
0005433035882	24132	Economy	11600.00
0005433035880	24132	Economy	11600.00
0005433921653	24132	Economy	12700.00
0005433921746	24132	Economy	11600.00
0005433921894	24132	Economy	12700.00
0005433035896	24132	Economy	11600.00
0005433921768	24132	Economy	11600.00
0005433035857	24132	Economy	11600.00
0005432749767	24132	Economy	11600.00
0005433921863	24132	Economy	11600.00
0005433921895	24132	Economy	11600.00
0005433921654	24132	Economy	11600.00
0005433035854	24132	Economy	11600.00
0005433921898	24132	Economy	11600.00
0005433929559	24132	Economy	11600.00
0005433921736	24132	Economy	11600.00
0005433921791	24132	Economy	11600.00
0005433921702	24132	Economy	11600.00
0005433921723	24132	Economy	11600.00
0005433921745	24132	Economy	11600.00
0005433035892	24132	Economy	11600.00
0005433921919	24132	Economy	11600.00
0005433035884	24132	Economy	11600.00
0005433035855	24132	Economy	11600.00
0005433035872	24132	Economy	11600.00
0005433921607	24132	Economy	11600.00
0005433931427	24132	Economy	11600.00
0005433921980	24132	Economy	11600.00
0005433921600	24132	Economy	11600.00
0005433921769	24132	Economy	11600.00
0005432206146	24132	Economy	11600.00
0005433035861	24132	Economy	11600.00
0005434028275	24132	Economy	11600.00
0005433035877	24132	Economy	11600.00
0005433921777	24132	Economy	11600.00
0005433921590	24132	Economy	11600.00
0005433035879	24132	Economy	11600.00
0005433035867	24132	Economy	11600.00
0005433931413	24132	Economy	11600.00
0005433921700	24132	Economy	11600.00
0005433035873	24132	Economy	11600.00
0005433035869	24132	Economy	11600.00
0005433921912	24132	Economy	11600.00
0005433922117	24132	Economy	11600.00
0005433035870	24132	Economy	11600.00
0005433921744	24132	Economy	11600.00
0005433035846	24132	Economy	11600.00
0005433929539	24132	Economy	11600.00
0005433922022	24132	Economy	11600.00
0005433035853	24132	Economy	11600.00
0005433921722	24132	Economy	11600.00
0005433921713	24132	Economy	11600.00
0005433922073	24132	Economy	11600.00
0005433931420	24132	Economy	11600.00
0005433035860	24132	Economy	11600.00
0005433922259	24132	Economy	11600.00
0005433921747	24132	Economy	11600.00
0005433921858	24132	Economy	11600.00
0005433766575	295	Business	83700.00
0005432277695	295	Business	83700.00
0005433233259	295	Business	83700.00
0005434724443	295	Business	83700.00
0005435142461	295	Business	83700.00
0005434724472	295	Business	83700.00
0005433233106	295	Business	83700.00
0005433233382	295	Business	83700.00
0005433180712	295	Business	83700.00
0005434724481	295	Business	83700.00
0005434735644	295	Business	83700.00
0005434724501	295	Business	83700.00
0005435142465	295	Business	83700.00
0005434724545	295	Business	83700.00
0005434724542	295	Business	83700.00
0005434724485	295	Business	83700.00
0005434724504	295	Business	83700.00
0005434724479	295	Business	83700.00
0005434724495	295	Business	83700.00
0005434550816	295	Business	83700.00
0005433233383	295	Business	83700.00
0005434550774	295	Comfort	47400.00
0005434724533	295	Comfort	47400.00
0005434550792	295	Comfort	47400.00
0005434302425	295	Comfort	47400.00
0005434550818	295	Comfort	47400.00
0005433180662	295	Comfort	47400.00
0005434550798	295	Comfort	47400.00
0005434724475	295	Comfort	47400.00
0005435142469	295	Comfort	47400.00
0005434724427	295	Comfort	47400.00
0005433766573	295	Comfort	47400.00
0005434550786	295	Comfort	47400.00
0005434724509	295	Comfort	47400.00
0005434724487	295	Comfort	47400.00
0005434724470	295	Comfort	47400.00
0005434724440	295	Comfort	47400.00
0005434724520	295	Comfort	47400.00
0005433233166	295	Comfort	47400.00
0005434724465	295	Comfort	47400.00
0005434724518	295	Comfort	47400.00
0005433233123	295	Comfort	47400.00
0005434724506	295	Comfort	47400.00
0005434724461	295	Comfort	47400.00
0005434724474	295	Comfort	47400.00
0005434724539	295	Comfort	47400.00
0005433180650	295	Comfort	47400.00
0005435142462	295	Comfort	47400.00
0005434724449	295	Comfort	47400.00
0005434302422	295	Comfort	47400.00
0005434724514	295	Comfort	47400.00
0005434550788	295	Comfort	47400.00
0005434724471	295	Comfort	47400.00
0005434724453	295	Comfort	47400.00
0005435142460	295	Comfort	47400.00
0005434724498	295	Comfort	47400.00
0005434724452	295	Comfort	47400.00
0005435142473	295	Comfort	47400.00
0005435142463	295	Comfort	47400.00
0005434724446	295	Comfort	47400.00
0005433233575	295	Comfort	47400.00
0005434550781	295	Economy	27900.00
0005433233193	295	Economy	27900.00
0005433233190	295	Economy	27900.00
0005434724437	295	Economy	27900.00
0005434550799	295	Economy	27900.00
0005434724477	295	Economy	27900.00
0005434724536	295	Economy	27900.00
0005434724431	295	Economy	27900.00
0005432277692	295	Economy	27900.00
0005434724503	295	Economy	27900.00
0005432277696	295	Economy	27900.00
0005433131634	295	Economy	27900.00
0005434724483	295	Economy	27900.00
0005434550779	295	Economy	27900.00
0005434550794	295	Economy	27900.00
0005434735641	295	Economy	27900.00
0005434550804	295	Economy	27900.00
0005434724468	295	Economy	27900.00
0005434550810	295	Economy	27900.00
0005433233233	295	Economy	27900.00
0005434550766	295	Economy	27900.00
0005433233183	295	Economy	27900.00
0005433233274	295	Economy	27900.00
0005434731131	295	Economy	27900.00
0005434724460	295	Economy	27900.00
0005434724447	295	Economy	27900.00
0005434724548	295	Economy	27900.00
0005432277706	295	Economy	27900.00
0005434302423	295	Economy	27900.00
0005434550815	295	Economy	27900.00
0005434724490	295	Economy	27900.00
0005434731134	295	Economy	27900.00
0005434550782	295	Economy	27900.00
0005433766584	295	Economy	27900.00
0005434724458	295	Economy	27900.00
0005434550796	295	Economy	27900.00
0005434724529	295	Economy	27900.00
0005433233192	295	Economy	27900.00
0005433233167	295	Economy	27900.00
0005434724507	295	Economy	27900.00
0005433233124	295	Economy	27900.00
0005433131636	295	Economy	27900.00
0005434724531	295	Economy	27900.00
0005434550765	295	Economy	27900.00
0005433233264	295	Economy	27900.00
0005434724543	295	Economy	27900.00
0005433180727	295	Economy	27900.00
0005434724523	295	Economy	30700.00
0005434724535	295	Economy	27900.00
0005434724429	295	Economy	30700.00
0005433126768	295	Economy	27900.00
0005434550809	295	Economy	27900.00
0005434724521	295	Economy	30700.00
0005434724426	295	Economy	27900.00
0005434735643	295	Economy	27900.00
0005432277697	295	Economy	30700.00
0005433766583	295	Economy	27900.00
0005435142472	295	Economy	27900.00
0005433180665	295	Economy	27900.00
0005434550768	295	Economy	27900.00
0005434550789	295	Economy	27900.00
0005433180651	295	Economy	27900.00
0005434724525	295	Economy	27900.00
0005434550803	295	Economy	27900.00
0005434724544	295	Economy	27900.00
0005434724448	295	Economy	27900.00
0005434550772	295	Economy	27900.00
0005434724510	295	Economy	27900.00
0005434550793	295	Economy	27900.00
0005434550787	295	Economy	27900.00
0005434302426	295	Economy	27900.00
0005434724445	295	Economy	27900.00
0005434724442	295	Economy	27900.00
0005434724513	295	Economy	27900.00
0005433180674	295	Economy	27900.00
0005434550769	295	Economy	27900.00
0005434724541	295	Economy	27900.00
0005434724527	295	Economy	27900.00
0005432277694	295	Economy	27900.00
0005432277700	295	Economy	27900.00
0005433233181	295	Economy	27900.00
0005434550784	295	Economy	27900.00
0005434724489	295	Economy	27900.00
0005434550776	295	Economy	27900.00
0005434724500	295	Economy	27900.00
0005433233125	295	Economy	27900.00
0005435142464	295	Economy	27900.00
0005434550777	295	Economy	27900.00
0005433233313	295	Economy	27900.00
0005434550778	295	Economy	27900.00
0005434724439	295	Economy	27900.00
0005434724488	295	Economy	27900.00
0005434724515	295	Economy	27900.00
0005433233247	295	Economy	27900.00
0005433131644	295	Economy	27900.00
0005434724486	295	Economy	27900.00
0005433289731	295	Economy	27900.00
0005433233126	295	Economy	27900.00
0005434550801	295	Economy	27900.00
0005434724476	295	Economy	27900.00
0005434550790	295	Economy	27900.00
0005434724546	295	Economy	27900.00
0005434724434	295	Economy	27900.00
0005433180726	295	Economy	27900.00
0005434550808	295	Economy	27900.00
0005433233234	295	Economy	27900.00
0005434724480	295	Economy	27900.00
0005434724516	295	Economy	27900.00
0005434724519	295	Economy	27900.00
0005432277701	295	Economy	27900.00
0005433766574	295	Economy	27900.00
0005434724435	295	Economy	27900.00
0005434724530	295	Economy	27900.00
0005434724441	295	Economy	27900.00
0005433180684	295	Economy	27900.00
0005434731133	295	Economy	27900.00
0005433180663	295	Economy	27900.00
0005434724432	295	Economy	27900.00
0005432277702	295	Economy	27900.00
0005433233091	295	Economy	27900.00
0005433233103	295	Economy	27900.00
0005433233576	295	Economy	27900.00
0005434724496	295	Economy	27900.00
0005433180673	295	Economy	27900.00
0005434724454	295	Economy	27900.00
0005435142471	295	Economy	27900.00
0005434724499	295	Economy	27900.00
0005433233105	295	Economy	27900.00
0005434550770	295	Economy	27900.00
0005433233184	295	Economy	27900.00
0005434724538	295	Economy	27900.00
0005432277699	295	Economy	27900.00
0005434724494	295	Economy	27900.00
0005434550783	295	Economy	27900.00
0005434724526	295	Economy	27900.00
0005433180713	295	Economy	27900.00
0005434724457	295	Economy	27900.00
0005434724512	295	Economy	27900.00
0005433180685	295	Economy	27900.00
0005433289739	295	Economy	27900.00
0005434550771	295	Economy	27900.00
0005434724524	295	Economy	27900.00
0005434724463	295	Economy	27900.00
0005434302424	295	Economy	30700.00
0005435142467	295	Economy	27900.00
0005434724450	295	Economy	30700.00
0005434550811	295	Economy	30700.00
0005433233381	295	Economy	30700.00
0005434724547	295	Economy	27900.00
0005433180769	295	Economy	30700.00
0005433180661	295	Economy	27900.00
0005434724493	295	Economy	27900.00
0005434550805	295	Economy	27900.00
0005434724428	295	Economy	27900.00
0005434724502	295	Economy	27900.00
0005434550763	295	Economy	27900.00
0005433233185	295	Economy	27900.00
0005433233336	295	Economy	27900.00
0005434724537	295	Economy	27900.00
0005434724517	295	Economy	27900.00
0005434724444	295	Economy	27900.00
0005434550764	295	Economy	27900.00
0005434724505	295	Economy	27900.00
0005432277698	295	Economy	27900.00
0005433180664	295	Economy	27900.00
0005434735642	295	Economy	27900.00
0005434724464	295	Economy	27900.00
0005434550814	295	Economy	27900.00
0005434550797	295	Economy	27900.00
0005434550813	295	Economy	27900.00
0005434724456	295	Economy	27900.00
0005433233104	295	Economy	27900.00
0005434550795	295	Economy	27900.00
0005433233242	295	Economy	27900.00
0005434550775	295	Economy	27900.00
0005434724451	295	Economy	27900.00
0005434724528	295	Economy	27900.00
0005432277693	295	Economy	27900.00
0005434031945	295	Economy	27900.00
0005434724522	295	Economy	27900.00
0005434724469	295	Economy	27900.00
0005433180686	295	Economy	27900.00
0005433233182	295	Economy	27900.00
0005434724467	295	Economy	27900.00
0005434550785	295	Economy	27900.00
0005435142468	295	Economy	27900.00
0005434550780	295	Economy	27900.00
0005434550802	295	Economy	27900.00
0005432277703	295	Economy	27900.00
0005434550767	295	Economy	27900.00
0005434550773	295	Economy	27900.00
0005434550817	295	Economy	27900.00
0005434550807	295	Economy	27900.00
0005434724433	295	Economy	27900.00
0005434031953	295	Economy	27900.00
0005434724455	295	Economy	27900.00
0005434302421	295	Economy	27900.00
0005434724484	295	Economy	27900.00
0005434724462	295	Economy	27900.00
0005432277705	295	Economy	27900.00
0005433289732	295	Economy	27900.00
0005435142466	295	Economy	27900.00
0005434550806	295	Economy	27900.00
0005434724430	295	Economy	27900.00
0005434724478	295	Economy	27900.00
0005433233335	295	Economy	27900.00
0005434731130	295	Economy	27900.00
0005434724473	295	Economy	27900.00
0005434724534	295	Economy	27900.00
0005434550791	295	Economy	27900.00
0005434724466	295	Economy	27900.00
0005434724540	295	Economy	27900.00
0005434724492	295	Economy	27900.00
0005434724482	295	Economy	27900.00
0005433126769	295	Economy	27900.00
0005434724459	295	Economy	27900.00
0005434724508	295	Economy	27900.00
0005434302854	295	Economy	27900.00
0005434724511	295	Economy	27900.00
0005434724491	295	Economy	27900.00
0005434724438	295	Economy	27900.00
0005435142470	295	Economy	27900.00
0005433233156	295	Economy	27900.00
0005434550800	295	Economy	27900.00
0005432277704	295	Economy	27900.00
0005434550812	295	Economy	27900.00
0005434731132	295	Economy	27900.00
0005434724436	295	Economy	27900.00
0005434724497	295	Economy	27900.00
0005434724532	295	Economy	27900.00
0005433233314	295	Economy	27900.00
0005433233692	9875	Business	83700.00
0005434723640	9875	Business	83700.00
0005434723373	9875	Business	83700.00
0005433233685	9875	Business	83700.00
0005433180883	9875	Business	83700.00
0005433233670	9875	Business	83700.00
0005433126804	9875	Business	83700.00
0005433233672	9875	Business	83700.00
0005433180902	9875	Business	83700.00
0005434723573	9875	Business	83700.00
0005434550392	9875	Business	83700.00
0005434723760	9875	Business	83700.00
0005434723744	9875	Business	83700.00
0005434723592	9875	Business	83700.00
0005434723414	9875	Business	83700.00
0005434735605	9875	Business	83700.00
0005432199194	9875	Comfort	47400.00
0005434723560	9875	Comfort	47400.00
0005433233714	9875	Comfort	47400.00
0005434723743	9875	Comfort	47400.00
0005434550307	9875	Comfort	47400.00
0005434550423	9875	Comfort	47400.00
0005433233698	9875	Comfort	47400.00
0005434735604	9875	Comfort	47400.00
0005434031988	9875	Comfort	47400.00
0005434723632	9875	Comfort	47400.00
0005433233695	9875	Comfort	47400.00
0005434550355	9875	Comfort	47400.00
0005433233699	9875	Comfort	47400.00
0005433180887	9875	Comfort	47400.00
0005434723478	9875	Comfort	47400.00
0005433289787	9875	Comfort	47400.00
0005434723420	9875	Comfort	47400.00
0005434550311	9875	Comfort	47400.00
0005433233703	9875	Comfort	47400.00
0005434550278	9875	Comfort	47400.00
0005434723349	9875	Comfort	47400.00
0005434724009	9875	Comfort	47400.00
0005433233690	9875	Comfort	47400.00
0005433233697	9875	Comfort	47400.00
0005433129240	9875	Comfort	47400.00
0005434723452	9875	Comfort	47400.00
0005433233665	9875	Comfort	47400.00
0005433233688	9875	Comfort	47400.00
0005434723634	9875	Economy	27900.00
0005433233713	9875	Economy	27900.00
0005433233661	9875	Economy	27900.00
0005434723748	9875	Economy	27900.00
0005434723443	9875	Economy	27900.00
0005433180884	9875	Economy	27900.00
0005434724105	9875	Economy	27900.00
0005434723396	9875	Economy	27900.00
0005434723574	9875	Economy	27900.00
0005434723334	9875	Economy	27900.00
0005434723429	9875	Economy	27900.00
0005433129238	9875	Economy	27900.00
0005434723602	9875	Economy	27900.00
0005434723434	9875	Economy	27900.00
0005433233705	9875	Economy	27900.00
0005434723559	9875	Economy	27900.00
0005434550279	9875	Economy	27900.00
0005434031987	9875	Economy	27900.00
0005434550349	9875	Economy	27900.00
0005434723421	9875	Economy	27900.00
0005433233663	9875	Economy	27900.00
0005433180904	9875	Economy	27900.00
0005434723369	9875	Economy	27900.00
0005433233687	9875	Economy	27900.00
0005433180896	9875	Economy	27900.00
0005432199190	9875	Economy	27900.00
0005434723489	9875	Economy	27900.00
0005434723564	9875	Economy	27900.00
0005434723518	9875	Economy	27900.00
0005433289789	9875	Economy	27900.00
0005433289788	9875	Economy	27900.00
0005433180886	9875	Economy	27900.00
0005433233668	9875	Economy	27900.00
0005434723791	9875	Economy	27900.00
0005433126808	9875	Economy	27900.00
0005433233701	9875	Economy	27900.00
0005433180900	9875	Economy	27900.00
0005433113518	9875	Economy	27900.00
0005434723585	9875	Economy	27900.00
0005434723437	9875	Economy	27900.00
0005434550408	9875	Economy	27900.00
0005434723928	9875	Economy	27900.00
0005434723615	9875	Economy	27900.00
0005433233681	9875	Economy	27900.00
0005434302393	9875	Economy	27900.00
0005434731098	9875	Economy	27900.00
0005434723645	9875	Economy	27900.00
0005433233673	9875	Economy	30700.00
0005433233671	9875	Economy	27900.00
0005434723444	9875	Economy	27900.00
0005434723423	9875	Economy	27900.00
0005434550271	9875	Economy	27900.00
0005433113517	9875	Economy	30700.00
0005434723622	9875	Economy	30700.00
0005433289790	9875	Economy	30700.00
0005434550296	9875	Economy	27900.00
0005433233723	9875	Economy	27900.00
0005433233667	9875	Economy	27900.00
0005433233675	9875	Economy	27900.00
0005433233693	9875	Economy	27900.00
0005434723635	9875	Economy	27900.00
0005434550409	9875	Economy	27900.00
0005434723333	9875	Economy	27900.00
0005434723371	9875	Economy	27900.00
0005433129239	9875	Economy	27900.00
0005434550337	9875	Economy	27900.00
0005433289786	9875	Economy	27900.00
0005434550473	9875	Economy	27900.00
0005433766610	9875	Economy	27900.00
0005434550304	9875	Economy	27900.00
0005434723866	9875	Economy	27900.00
0005434550310	9875	Economy	27900.00
0005433180890	9875	Economy	27900.00
0005434723914	9875	Economy	27900.00
0005434723792	9875	Economy	27900.00
0005434723576	9875	Economy	27900.00
0005434723633	9875	Economy	27900.00
0005434723775	9875	Economy	27900.00
0005434723565	9875	Economy	27900.00
0005434723345	9875	Economy	27900.00
0005434723440	9875	Economy	27900.00
0005433180892	9875	Economy	27900.00
0005434723495	9875	Economy	27900.00
0005434723539	9875	Economy	27900.00
0005434302388	9875	Economy	27900.00
0005433233717	9875	Economy	27900.00
0005434723344	9875	Economy	27900.00
0005433233709	9875	Economy	27900.00
0005434302392	9875	Economy	27900.00
0005434723672	9875	Economy	27900.00
0005433233678	9875	Economy	27900.00
0005435142358	9875	Economy	27900.00
0005433233689	9875	Economy	27900.00
0005433233677	9875	Economy	27900.00
0005433233682	9875	Economy	27900.00
0005434723575	9875	Economy	27900.00
0005433180882	9875	Economy	27900.00
0005434731106	9875	Economy	27900.00
0005433233702	9875	Economy	27900.00
0005433180888	9875	Economy	27900.00
0005433233706	9875	Economy	27900.00
0005433233669	9875	Economy	27900.00
0005432199193	9875	Economy	27900.00
0005433180898	9875	Economy	27900.00
0005433233674	9875	Economy	27900.00
0005433233696	9875	Economy	27900.00
0005433180881	9875	Economy	27900.00
0005433180895	9875	Economy	27900.00
0005434723479	9875	Economy	27900.00
0005433233676	9875	Economy	27900.00
0005433233707	9875	Economy	27900.00
0005434723488	9875	Economy	27900.00
0005434723370	9875	Economy	27900.00
0005432199189	9875	Economy	27900.00
0005433233694	9875	Economy	27900.00
0005433233712	9875	Economy	27900.00
0005433126807	9875	Economy	27900.00
0005433233684	9875	Economy	27900.00
0005435142345	9875	Economy	27900.00
0005433233704	9875	Economy	27900.00
0005434550407	9875	Economy	27900.00
0005434723747	9875	Economy	27900.00
0005434550405	9875	Economy	27900.00
0005434550343	9875	Economy	30700.00
0005434550370	9875	Economy	30700.00
0005433126805	9875	Economy	30700.00
0005434723724	9875	Economy	27900.00
0005434723761	9875	Economy	27900.00
0005434550406	9875	Economy	27900.00
0005435142346	9875	Economy	27900.00
0005433233715	9875	Economy	27900.00
0005434550295	9875	Economy	27900.00
0005434723649	9875	Economy	27900.00
0005434723708	9875	Economy	27900.00
0005434550335	9875	Economy	27900.00
0005433233721	9875	Economy	27900.00
0005434723894	9875	Economy	27900.00
0005433766609	9875	Economy	27900.00
0005434723584	9875	Economy	27900.00
0005433233680	9875	Economy	27900.00
0005434723665	9875	Economy	27900.00
0005434723929	9875	Economy	27900.00
0005433233664	9875	Economy	27900.00
0005433180897	9875	Economy	27900.00
0005434031989	9875	Economy	27900.00
0005433129236	9875	Economy	27900.00
0005434723413	9875	Economy	27900.00
0005434550289	9875	Economy	27900.00
0005433129237	9875	Economy	27900.00
0005433233708	9875	Economy	27900.00
0005434723428	9875	Economy	27900.00
0005435142347	9875	Economy	27900.00
0005433233686	9875	Economy	27900.00
0005433233711	9875	Economy	27900.00
0005434723730	9875	Economy	27900.00
0005434302391	9875	Economy	27900.00
0005433233662	9875	Economy	27900.00
0005434723606	9875	Economy	27900.00
0005433233700	9875	Economy	27900.00
0005434723336	9875	Economy	27900.00
0005433180894	9875	Economy	27900.00
0005433233719	9875	Economy	27900.00
0005433233666	9875	Economy	27900.00
0005434550272	9875	Economy	27900.00
0005434723422	9875	Economy	27900.00
0005434723725	9875	Economy	27900.00
0005433233716	9875	Economy	27900.00
0005434031986	9875	Economy	27900.00
0005433233718	9875	Economy	27900.00
0005434723780	9875	Economy	27900.00
0005432199192	9875	Economy	27900.00
0005433180899	9875	Economy	27900.00
0005433233720	9875	Economy	27900.00
0005433233660	9875	Economy	27900.00
0005433233722	9875	Economy	27900.00
0005434723746	9875	Economy	27900.00
0005434550347	9875	Economy	27900.00
0005434723965	9875	Economy	27900.00
0005433180905	9875	Economy	27900.00
0005433233679	9875	Economy	27900.00
0005434723601	9875	Economy	27900.00
0005432199191	9875	Economy	27900.00
0005433233683	9875	Economy	27900.00
0005433180889	9875	Economy	27900.00
0005433180893	9875	Economy	27900.00
0005433233691	9875	Economy	27900.00
0005433126806	9875	Economy	27900.00
0005434550350	9875	Economy	27900.00
0005433233710	9875	Economy	27900.00
0005434723412	9875	Economy	27900.00
0005434550340	9875	Economy	27900.00
0005434723650	9875	Economy	27900.00
0005435142339	9875	Economy	27900.00
0005433180891	9875	Economy	27900.00
0005434723427	9875	Economy	27900.00
0005434723519	9875	Economy	27900.00
0005433180903	9875	Economy	27900.00
0005433766608	9875	Economy	27900.00
0005433180885	9875	Economy	27900.00
0005433180901	9875	Economy	27900.00
0005432526923	7744	Business	42100.00
0005432526892	7744	Business	42100.00
0005432526883	7744	Business	42100.00
0005435212351	7744	Business	42100.00
0005434067012	7744	Business	42100.00
0005435212410	7744	Business	42100.00
0005432069540	7744	Business	42100.00
0005432533267	7744	Business	42100.00
0005435212477	7744	Business	42100.00
0005432526938	7744	Business	42100.00
0005432526935	7744	Business	42100.00
0005432535795	7744	Business	42100.00
0005432526969	7744	Business	42100.00
0005432526953	7744	Business	42100.00
0005432526954	7744	Business	42100.00
0005432526841	7744	Business	42100.00
0005432526968	7744	Business	42100.00
0005434066995	7744	Business	42100.00
0005434066973	7744	Comfort	23900.00
0005435212713	7744	Comfort	23900.00
0005432526893	7744	Comfort	23900.00
0005434066992	7744	Comfort	23900.00
0005432150133	7744	Comfort	23900.00
0005432069539	7744	Comfort	23900.00
0005434066962	7744	Comfort	23900.00
0005434066954	7744	Comfort	23900.00
0005432526886	7744	Comfort	23900.00
0005434066993	7744	Comfort	23900.00
0005432526903	7744	Comfort	23900.00
0005432526872	7744	Comfort	23900.00
0005432069531	7744	Comfort	23900.00
0005432069542	7744	Comfort	23900.00
0005432526974	7744	Comfort	23900.00
0005434066960	7744	Comfort	23900.00
0005434066998	7744	Comfort	23900.00
0005432526944	7744	Comfort	23900.00
0005434067018	7744	Comfort	23900.00
0005432526901	7744	Comfort	23900.00
0005432526857	7744	Comfort	23900.00
0005432526947	7744	Comfort	23900.00
0005432526956	7744	Comfort	23900.00
0005432526865	7744	Comfort	23900.00
0005432526920	7744	Comfort	23900.00
0005432537039	7744	Comfort	23900.00
0005434066988	7744	Comfort	23900.00
0005432533268	7744	Comfort	23900.00
0005435212456	7744	Comfort	23900.00
0005432526958	7744	Comfort	23900.00
0005432526843	7744	Comfort	23900.00
0005432526848	7744	Comfort	23900.00
0005432526880	7744	Comfort	23900.00
0005434067017	7744	Comfort	23900.00
0005434067010	7744	Comfort	23900.00
0005432533266	7744	Comfort	23900.00
0005434066952	7744	Comfort	23900.00
0005432526870	7744	Comfort	23900.00
0005432526975	7744	Comfort	23900.00
0005435212515	7744	Comfort	23900.00
0005432526908	7744	Comfort	23900.00
0005435212503	7744	Economy	14000.00
0005434067002	7744	Economy	14000.00
0005432526902	7744	Economy	14000.00
0005434067015	7744	Economy	14000.00
0005432526868	7744	Economy	14000.00
0005432069534	7744	Economy	14000.00
0005432526963	7744	Economy	14000.00
0005432526916	7744	Economy	14000.00
0005434066984	7744	Economy	14000.00
0005434066955	7744	Economy	14000.00
0005434066975	7744	Economy	14000.00
0005434066977	7744	Economy	14000.00
0005435212698	7744	Economy	14000.00
0005434066968	7744	Economy	14000.00
0005435212502	7744	Economy	14000.00
0005434067000	7744	Economy	14000.00
0005435212483	7744	Economy	14000.00
0005434066994	7744	Economy	14000.00
0005432069536	7744	Economy	14000.00
0005432526856	7744	Economy	14000.00
0005432526910	7744	Economy	14000.00
0005434067003	7744	Economy	14000.00
0005434066971	7744	Economy	14000.00
0005434066985	7744	Economy	14000.00
0005432526973	7744	Economy	14000.00
0005432526849	7744	Economy	14000.00
0005435212480	7744	Economy	14000.00
0005434067011	7744	Economy	14000.00
0005434066989	7744	Economy	14000.00
0005432526971	7744	Economy	14000.00
0005435212336	7744	Economy	14000.00
0005432526913	7744	Economy	14000.00
0005432526858	7744	Economy	14000.00
0005432526866	7744	Economy	14000.00
0005432526931	7744	Economy	14000.00
0005432526966	7744	Economy	14000.00
0005432526889	7744	Economy	14000.00
0005435212476	7744	Economy	14000.00
0005432526946	7744	Economy	14000.00
0005435212550	7744	Economy	14000.00
0005432428900	7744	Economy	14000.00
0005432526891	7744	Economy	14000.00
0005432526928	7744	Economy	14000.00
0005434067008	7744	Economy	14000.00
0005435212630	7744	Economy	14000.00
0005432526961	7744	Economy	14000.00
0005432069532	7744	Economy	14000.00
0005432526861	7744	Economy	14000.00
0005432526847	7744	Economy	14000.00
0005432526929	7744	Economy	14000.00
0005432526941	7744	Economy	14000.00
0005432526942	7744	Economy	14000.00
0005434066951	7744	Economy	14000.00
0005432526952	7744	Economy	14000.00
0005434066983	7744	Economy	14000.00
0005435212597	7744	Economy	14000.00
0005432526922	7744	Economy	14000.00
0005435212516	7744	Economy	15400.00
0005432526917	7744	Economy	14000.00
0005432526884	7744	Economy	15400.00
0005432526948	7744	Economy	15400.00
0005434066967	7744	Economy	14000.00
0005435212352	7744	Economy	14000.00
0005432526862	7744	Economy	14000.00
0005432526970	7744	Economy	14000.00
0005434066980	7744	Economy	15400.00
0005434067013	7744	Economy	15400.00
0005434066966	7744	Economy	14000.00
0005432526936	7744	Economy	14000.00
0005434066972	7744	Economy	14000.00
0005432526890	7744	Economy	14000.00
0005432526894	7744	Economy	14000.00
0005432069533	7744	Economy	14000.00
0005435212481	7744	Economy	14000.00
0005435212529	7744	Economy	14000.00
0005432526873	7744	Economy	14000.00
0005432526879	7744	Economy	14000.00
0005435212349	7744	Economy	14000.00
0005432526897	7744	Economy	14000.00
0005432069537	7744	Economy	14000.00
0005435212482	7744	Economy	14000.00
0005432526904	7744	Economy	14000.00
0005432526937	7744	Economy	14000.00
0005434066974	7744	Economy	14000.00
0005432069535	7744	Economy	14000.00
0005434067006	7744	Economy	14000.00
0005432526853	7744	Economy	14000.00
0005432526972	7744	Economy	14000.00
0005432526850	7744	Economy	14000.00
0005432526909	7744	Economy	14000.00
0005432526895	7744	Economy	14000.00
0005432526882	7744	Economy	14000.00
0005432526885	7744	Economy	14000.00
0005432526845	7744	Economy	14000.00
0005435212362	7744	Economy	14000.00
0005435212617	7744	Economy	14000.00
0005435630916	7744	Economy	14000.00
0005432526949	7744	Economy	14000.00
0005432526959	7744	Economy	14000.00
0005432526955	7744	Economy	14000.00
0005432526915	7744	Economy	14000.00
0005432526962	7744	Economy	14000.00
0005434066965	7744	Economy	14000.00
0005434067016	7744	Economy	14000.00
0005432526854	7744	Economy	14000.00
0005434066982	7744	Economy	14000.00
0005435212427	7744	Economy	14000.00
0005432526876	7744	Economy	14000.00
0005434066959	7744	Economy	14000.00
0005432526925	7744	Economy	14000.00
0005432526950	7744	Economy	14000.00
0005432535791	7744	Economy	14000.00
0005432526852	7744	Economy	14000.00
0005435212387	7744	Economy	14000.00
0005435212547	7744	Economy	14000.00
0005434066961	7744	Economy	14000.00
0005432526860	7744	Economy	14000.00
0005434066978	7744	Economy	14000.00
0005432526844	7744	Economy	14000.00
0005432526896	7744	Economy	14000.00
0005434067001	7744	Economy	14000.00
0005434066990	7744	Economy	14000.00
0005432526864	7744	Economy	14000.00
0005432526867	7744	Economy	14000.00
0005432526957	7744	Economy	14000.00
0005432526869	7744	Economy	14000.00
0005434066976	7744	Economy	14000.00
0005434066970	7744	Economy	14000.00
0005432526898	7744	Economy	14000.00
0005434067009	7744	Economy	14000.00
0005434067014	7744	Economy	14000.00
0005432069538	7744	Economy	14000.00
0005432150130	7744	Economy	14000.00
0005434066969	7744	Economy	14000.00
0005434067007	7744	Economy	14000.00
0005432526932	7744	Economy	14000.00
0005435212712	7744	Economy	14000.00
0005435212628	7744	Economy	14000.00
0005435212377	7744	Economy	14000.00
0005432526933	7744	Economy	14000.00
0005432535793	7744	Economy	14000.00
0005434066949	7744	Economy	14000.00
0005432526878	7744	Economy	14000.00
0005432150131	7744	Economy	14000.00
0005432428901	7744	Economy	14000.00
0005432526945	7744	Economy	14000.00
0005432150128	7744	Economy	14000.00
0005434067004	7744	Economy	14000.00
0005432526911	7744	Economy	15400.00
0005432526934	7744	Economy	15400.00
0005435630915	7744	Economy	15400.00
0005435212596	7744	Economy	15400.00
0005432526967	7744	Economy	15400.00
0005432526960	7744	Economy	15400.00
0005434066981	7744	Economy	14000.00
0005432526943	7744	Economy	14000.00
0005432069529	7744	Economy	14000.00
0005432526906	7744	Economy	14000.00
0005434066986	7744	Economy	14000.00
0005432526951	7744	Economy	14000.00
0005432526842	7744	Economy	14000.00
0005432526926	7744	Economy	14000.00
0005434066958	7744	Economy	14000.00
0005432535794	7744	Economy	14000.00
0005432526881	7744	Economy	14000.00
0005432526874	7744	Economy	14000.00
0005432526927	7744	Economy	14000.00
0005432526964	7744	Economy	14000.00
0005435212406	7744	Economy	14000.00
0005432150126	7744	Economy	14000.00
0005432526888	7744	Economy	14000.00
0005432526940	7744	Economy	14000.00
0005432150132	7744	Economy	14000.00
0005432526921	7744	Economy	14000.00
0005432526912	7744	Economy	14000.00
0005432537041	7744	Economy	14000.00
0005434067005	7744	Economy	14000.00
0005432526914	7744	Economy	14000.00
0005432526918	7744	Economy	14000.00
0005435212390	7744	Economy	14000.00
0005432150127	7744	Economy	14000.00
0005432526899	7744	Economy	14000.00
0005434066997	7744	Economy	14000.00
0005434066957	7744	Economy	14000.00
0005432526905	7744	Economy	14000.00
0005432526877	7744	Economy	14000.00
0005432526875	7744	Economy	14000.00
0005434066999	7744	Economy	14000.00
0005435725513	7744	Economy	14000.00
0005432428899	7744	Economy	14000.00
0005434066987	7744	Economy	14000.00
0005432069541	7744	Economy	14000.00
0005434066948	7744	Economy	14000.00
0005432069530	7744	Economy	14000.00
0005435212561	7744	Economy	14000.00
0005432526851	7744	Economy	14000.00
0005435725514	7744	Economy	14000.00
0005432526846	7744	Economy	14000.00
0005432526871	7744	Economy	14000.00
0005432526859	7744	Economy	14000.00
0005434066963	7744	Economy	14000.00
0005435212350	7744	Economy	14000.00
0005434066964	7744	Economy	14000.00
0005432535792	7744	Economy	14000.00
0005434066979	7744	Economy	14000.00
0005432526919	7744	Economy	14000.00
0005434066956	7744	Economy	14000.00
0005435212491	7744	Economy	14000.00
0005432526855	7744	Economy	14000.00
0005432526965	7744	Economy	14000.00
0005434066991	7744	Economy	14000.00
0005435212388	7744	Economy	14000.00
0005432526863	7744	Economy	14000.00
0005435212492	7744	Economy	14000.00
0005432526887	7744	Economy	14000.00
0005432526939	7744	Economy	14000.00
0005434067020	7744	Economy	14000.00
0005432537040	7744	Economy	14000.00
0005434066953	7744	Economy	14000.00
0005432150129	7744	Economy	14000.00
0005432526924	7744	Economy	14000.00
0005434067019	7744	Economy	14000.00
0005435212490	7744	Economy	14000.00
0005435212711	7744	Economy	14000.00
0005435212629	7744	Economy	14000.00
0005432526930	7744	Economy	14000.00
0005435212416	7744	Economy	14000.00
0005432526900	7744	Economy	14000.00
0005434066996	7744	Economy	14000.00
0005432526907	7744	Economy	14000.00
0005434066950	7744	Economy	14000.00
0005435612694	5331	Business	43100.00
0005435491423	5331	Business	43100.00
0005435423968	5331	Business	43100.00
0005432133089	5331	Business	43100.00
0005435612750	5331	Business	43100.00
0005435612714	5331	Business	43100.00
0005434343936	5331	Business	43100.00
0005435612726	5331	Business	43100.00
0005435423840	5331	Business	43100.00
0005432133082	5331	Business	43100.00
0005434573243	5331	Business	43100.00
0005435612707	5331	Business	43100.00
0005435612744	5331	Business	43100.00
0005435612688	5331	Business	43100.00
0005435612774	5331	Business	43100.00
0005435423807	5331	Business	43100.00
0005434343917	5331	Business	43100.00
0005435319435	5331	Business	43100.00
0005435612700	5331	Business	43100.00
0005434244534	5331	Business	43100.00
0005435423967	5331	Business	43100.00
0005435612775	5331	Business	43100.00
0005434573240	5331	Business	43100.00
0005435423737	5331	Business	43100.00
0005434573244	5331	Comfort	24400.00
0005432047517	5331	Comfort	24400.00
0005435555352	5331	Comfort	24400.00
0005435612772	5331	Comfort	24400.00
0005435423925	5331	Comfort	24400.00
0005435612745	5331	Comfort	24400.00
0005435380228	5331	Comfort	24400.00
0005435423776	5331	Comfort	24400.00
0005435612790	5331	Comfort	24400.00
0005434244466	5331	Comfort	24400.00
0005435423884	5331	Comfort	24400.00
0005434244522	5331	Comfort	24400.00
0005435612754	5331	Comfort	24400.00
0005435612731	5331	Comfort	24400.00
0005434343929	5331	Comfort	24400.00
0005434343934	5331	Comfort	24400.00
0005435423808	5331	Comfort	24400.00
0005435423648	5331	Comfort	24400.00
0005435612741	5331	Comfort	24400.00
0005435424006	5331	Comfort	24400.00
0005432133090	5331	Comfort	24400.00
0005434343940	5331	Comfort	24400.00
0005434343937	5331	Comfort	24400.00
0005435612787	5331	Comfort	24400.00
0005435423786	5331	Comfort	24400.00
0005435423821	5331	Comfort	24400.00
0005435612749	5331	Comfort	24400.00
0005435612743	5331	Comfort	24400.00
0005435612785	5331	Comfort	24400.00
0005435423883	5331	Comfort	24400.00
0005435423801	5331	Comfort	24400.00
0005435423742	5331	Comfort	24400.00
0005435490195	5331	Comfort	24400.00
0005435490198	5331	Comfort	24400.00
0005435423638	5331	Comfort	24400.00
0005434573233	5331	Comfort	24400.00
0005435612753	5331	Economy	14400.00
0005435380229	5331	Economy	14400.00
0005435612706	5331	Economy	14400.00
0005435423895	5331	Economy	14400.00
0005434244537	5331	Economy	14400.00
0005435612703	5331	Economy	14400.00
0005434244468	5331	Economy	14400.00
0005434244535	5331	Economy	14400.00
0005432133093	5331	Economy	14400.00
0005435423771	5331	Economy	14400.00
0005435612757	5331	Economy	14400.00
0005434573239	5331	Economy	14400.00
0005435612733	5331	Economy	14400.00
0005435423694	5331	Economy	14400.00
0005435423680	5331	Economy	14400.00
0005435612786	5331	Economy	14400.00
0005435612713	5331	Economy	14400.00
0005434244589	5331	Economy	14400.00
0005435612722	5331	Economy	14400.00
0005434244485	5331	Economy	14400.00
0005434343946	5331	Economy	14400.00
0005435423609	5331	Economy	14400.00
0005434343948	5331	Economy	14400.00
0005435612759	5331	Economy	14400.00
0005435612789	5331	Economy	14400.00
0005435612758	5331	Economy	14400.00
0005435319459	5331	Economy	14400.00
0005435612738	5331	Economy	14400.00
0005435612724	5331	Economy	14400.00
0005434573234	5331	Economy	14400.00
0005435612788	5331	Economy	14400.00
0005435491424	5331	Economy	14400.00
0005434573235	5331	Economy	14400.00
0005435612792	5331	Economy	14400.00
0005434244465	5331	Economy	14400.00
0005435423768	5331	Economy	14400.00
0005435423656	5331	Economy	14400.00
0005435423581	5331	Economy	14400.00
0005435612695	5331	Economy	14400.00
0005435612725	5331	Economy	14400.00
0005435612720	5331	Economy	14400.00
0005435612778	5331	Economy	14400.00
0005435612701	5331	Economy	14400.00
0005434244494	5331	Economy	14400.00
0005432133083	5331	Economy	14400.00
0005435612689	5331	Economy	14400.00
0005435423785	5331	Economy	14400.00
0005432133086	5331	Economy	14400.00
0005435423879	5331	Economy	14400.00
0005435612710	5331	Economy	14400.00
0005435423669	5331	Economy	15800.00
0005434343911	5331	Economy	14400.00
0005434343924	5331	Economy	15800.00
0005435097138	5331	Economy	14400.00
0005435423651	5331	Economy	14400.00
0005435612793	5331	Economy	14400.00
0005432047519	5331	Economy	14400.00
0005435423668	5331	Economy	15800.00
0005435612755	5331	Economy	15800.00
0005435612705	5331	Economy	14400.00
0005435423637	5331	Economy	15800.00
0005434343916	5331	Economy	14400.00
0005434343947	5331	Economy	14400.00
0005435612764	5331	Economy	14400.00
0005435612699	5331	Economy	14400.00
0005435612780	5331	Economy	14400.00
0005435302131	5331	Economy	14400.00
0005432363359	5331	Economy	14400.00
0005434343942	5331	Economy	14400.00
0005435423734	5331	Economy	14400.00
0005435423662	5331	Economy	14400.00
0005432363372	5331	Economy	14400.00
0005432133091	5331	Economy	14400.00
0005435423743	5331	Economy	14400.00
0005434343928	5331	Economy	14400.00
0005434343926	5331	Economy	14400.00
0005435612702	5331	Economy	14400.00
0005435612783	5331	Economy	14400.00
0005435612711	5331	Economy	14400.00
0005432133087	5331	Economy	14400.00
0005435612779	5331	Economy	14400.00
0005434573245	5331	Economy	14400.00
0005435097133	5331	Economy	14400.00
0005435612716	5331	Economy	14400.00
0005435612735	5331	Economy	14400.00
0005435612751	5331	Economy	14400.00
0005435423697	5331	Economy	14400.00
0005435612727	5331	Economy	14400.00
0005434244510	5331	Economy	14400.00
0005435612762	5331	Economy	14400.00
0005435097132	5331	Economy	14400.00
0005435612698	5331	Economy	14400.00
0005435424087	5331	Economy	14400.00
0005434573232	5331	Economy	14400.00
0005435612718	5331	Economy	14400.00
0005435612734	5331	Economy	14400.00
0005435612708	5331	Economy	14400.00
0005435319458	5331	Economy	14400.00
0005435380245	5331	Economy	14400.00
0005434343941	5331	Economy	14400.00
0005435490196	5331	Economy	14400.00
0005435612761	5331	Economy	14400.00
0005434343922	5331	Economy	14400.00
0005432133081	5331	Economy	14400.00
0005435612696	5331	Economy	14400.00
0005435612717	5331	Economy	14400.00
0005435612719	5331	Economy	14400.00
0005435612765	5331	Economy	14400.00
0005434343931	5331	Economy	14400.00
0005435097137	5331	Economy	14400.00
0005434343913	5331	Economy	14400.00
0005435612795	5331	Economy	14400.00
0005435380246	5331	Economy	14400.00
0005435612729	5331	Economy	14400.00
0005435423995	5331	Economy	14400.00
0005435424007	5331	Economy	14400.00
0005434573242	5331	Economy	14400.00
0005435423912	5331	Economy	14400.00
0005435612768	5331	Economy	14400.00
0005434244528	5331	Economy	14400.00
0005434244536	5331	Economy	14400.00
0005434343945	5331	Economy	14400.00
0005434343914	5331	Economy	14400.00
0005434343932	5331	Economy	14400.00
0005434573236	5331	Economy	14400.00
0005434244571	5331	Economy	14400.00
0005434343930	5331	Economy	14400.00
0005435612690	5331	Economy	14400.00
0005435612684	5331	Economy	14400.00
0005435612799	5331	Economy	14400.00
0005434244511	5331	Economy	14400.00
0005434656523	5331	Economy	14400.00
0005434343925	5331	Economy	14400.00
0005434573241	5331	Economy	14400.00
0005435423608	5331	Economy	14400.00
0005435612742	5331	Economy	14400.00
0005435612697	5331	Economy	14400.00
0005434244486	5331	Economy	14400.00
0005434343927	5331	Economy	14400.00
0005435423820	5331	Economy	14400.00
0005435423643	5331	Economy	14400.00
0005435612769	5331	Economy	14400.00
0005435612767	5331	Economy	14400.00
0005435423839	5331	Economy	14400.00
0005435612692	5331	Economy	14400.00
0005435612704	5331	Economy	14400.00
0005435612723	5331	Economy	14400.00
0005435097136	5331	Economy	14400.00
0005432133088	5331	Economy	14400.00
0005435612796	5331	Economy	14400.00
0005435612712	5331	Economy	14400.00
0005432133084	5331	Economy	14400.00
0005435612776	5331	Economy	14400.00
0005435555351	5331	Economy	14400.00
0005435423772	5331	Economy	14400.00
0005435423652	5331	Economy	14400.00
0005435097134	5331	Economy	14400.00
0005434343935	5331	Economy	14400.00
0005435423806	5331	Economy	15800.00
0005435612728	5331	Economy	15800.00
0005434343943	5331	Economy	15800.00
0005435612784	5331	Economy	15800.00
0005434244569	5331	Economy	14400.00
0005435423894	5331	Economy	14400.00
0005435490197	5331	Economy	14400.00
0005435555353	5331	Economy	14400.00
0005435612732	5331	Economy	14400.00
0005435612740	5331	Economy	14400.00
0005435423767	5331	Economy	14400.00
0005434343915	5331	Economy	14400.00
0005435097131	5331	Economy	14400.00
0005435380227	5331	Economy	14400.00
0005435612781	5331	Economy	14400.00
0005435612736	5331	Economy	14400.00
0005435612752	5331	Economy	14400.00
0005435423667	5331	Economy	14400.00
0005435612709	5331	Economy	14400.00
0005435423649	5331	Economy	14400.00
0005432363360	5331	Economy	14400.00
0005434343944	5331	Economy	14400.00
0005435612791	5331	Economy	14400.00
0005432363366	5331	Economy	14400.00
0005432047520	5331	Economy	14400.00
0005435423769	5331	Economy	14400.00
0005435423929	5331	Economy	14400.00
0005435097139	5331	Economy	14400.00
0005435612773	5331	Economy	14400.00
0005435612798	5331	Economy	14400.00
0005435423802	5331	Economy	14400.00
0005435612691	5331	Economy	14400.00
0005435612794	5331	Economy	14400.00
0005435491425	5331	Economy	14400.00
0005435612721	5331	Economy	14400.00
0005435612685	5331	Economy	14400.00
0005435423809	5331	Economy	14400.00
0005434244490	5331	Economy	14400.00
0005435423740	5331	Economy	14400.00
0005435612763	5331	Economy	14400.00
0005434343921	5331	Economy	14400.00
0005435612770	5331	Economy	14400.00
0005434343918	5331	Economy	14400.00
0005432133094	5331	Economy	14400.00
0005435423671	5331	Economy	14400.00
0005435612747	5331	Economy	14400.00
0005434573238	5331	Economy	14400.00
0005435612739	5331	Economy	14400.00
0005435423877	5331	Economy	14400.00
0005435612683	5331	Economy	14400.00
0005435612686	5331	Economy	14400.00
0005435612782	5331	Economy	14400.00
0005434573237	5331	Economy	14400.00
0005434244467	5331	Economy	14400.00
0005435423715	5331	Economy	14400.00
0005432047518	5331	Economy	14400.00
0005435612715	5331	Economy	14400.00
0005435612737	5331	Economy	14400.00
0005435612748	5331	Economy	14400.00
0005432133085	5331	Economy	14400.00
0005435097130	5331	Economy	14400.00
0005435423760	5331	Economy	14400.00
0005435612797	5331	Economy	14400.00
0005432133092	5331	Economy	14400.00
0005434343938	5331	Economy	14400.00
0005435612760	5331	Economy	14400.00
0005432363365	5331	Economy	14400.00
0005435612771	5331	Economy	14400.00
0005434343919	5331	Economy	14400.00
0005435097140	5331	Economy	14400.00
0005435302132	5331	Economy	14400.00
0005435612687	5331	Economy	14400.00
0005435612756	5331	Economy	14400.00
0005435423966	5331	Economy	14400.00
0005435612693	5331	Economy	14400.00
0005435612730	5331	Economy	14400.00
0005434343939	5331	Economy	14400.00
0005435423590	5331	Economy	14400.00
0005435423642	5331	Economy	14400.00
0005435612766	5331	Economy	14400.00
0005434343920	5331	Economy	14400.00
0005434343923	5331	Economy	14400.00
0005434343912	5331	Economy	14400.00
0005434343933	5331	Economy	14400.00
0005435423924	5331	Economy	14400.00
0005435612746	5331	Economy	14400.00
0005435423735	5331	Economy	14400.00
0005435423789	5331	Economy	14400.00
0005435097135	5331	Economy	14400.00
0005435612777	5331	Economy	14400.00
0005435424267	10881	Business	43100.00
0005435424241	10881	Business	43100.00
0005435424269	10881	Business	43100.00
0005435612106	10881	Business	43100.00
0005435490177	10881	Business	43100.00
0005435424266	10881	Business	43100.00
0005435612031	10881	Business	43100.00
0005435611865	10881	Business	43100.00
0005435612032	10881	Business	43100.00
0005435319504	10881	Business	43100.00
0005435490182	10881	Business	43100.00
0005434244734	10881	Business	43100.00
0005432164977	10881	Business	43100.00
0005435611815	10881	Business	43100.00
0005434343592	10881	Business	43100.00
0005435380257	10881	Business	43100.00
0005435611893	10881	Business	43100.00
0005435424236	10881	Comfort	24400.00
0005435380259	10881	Comfort	24400.00
0005432164974	10881	Comfort	24400.00
0005435424233	10881	Comfort	24400.00
0005435424277	10881	Comfort	24400.00
0005432164973	10881	Comfort	24400.00
0005435304121	10881	Comfort	24400.00
0005435424237	10881	Comfort	24400.00
0005434244737	10881	Comfort	24400.00
0005435319505	10881	Comfort	24400.00
0005435611787	10881	Comfort	24400.00
0005435611755	10881	Comfort	24400.00
0005435319498	10881	Comfort	24400.00
0005435611849	10881	Comfort	24400.00
0005435424230	10881	Comfort	24400.00
0005435424234	10881	Comfort	24400.00
0005435424224	10881	Comfort	24400.00
0005435611896	10881	Comfort	24400.00
0005435424216	10881	Comfort	24400.00
0005435611898	10881	Comfort	24400.00
0005435424223	10881	Comfort	24400.00
0005435611830	10881	Comfort	24400.00
0005432166874	10881	Comfort	24400.00
0005435611817	10881	Comfort	24400.00
0005435380253	10881	Comfort	24400.00
0005435097055	10881	Comfort	24400.00
0005434244745	10881	Comfort	24400.00
0005435424261	10881	Economy	14400.00
0005435424262	10881	Economy	14400.00
0005435612018	10881	Economy	14400.00
0005435612339	10881	Economy	14400.00
0005435611831	10881	Economy	14400.00
0005435424271	10881	Economy	14400.00
0005435611876	10881	Economy	14400.00
0005435424257	10881	Economy	14400.00
0005435612254	10881	Economy	14400.00
0005432166875	10881	Economy	14400.00
0005435424225	10881	Economy	14400.00
0005432164972	10881	Economy	14400.00
0005434343607	10881	Economy	14400.00
0005435612238	10881	Economy	14400.00
0005435424253	10881	Economy	14400.00
0005435424239	10881	Economy	14400.00
0005435611790	10881	Economy	14400.00
0005435424268	10881	Economy	14400.00
0005435611859	10881	Economy	14400.00
0005435612060	10881	Economy	14400.00
0005434244728	10881	Economy	14400.00
0005435424259	10881	Economy	14400.00
0005435612017	10881	Economy	14400.00
0005435611874	10881	Economy	14400.00
0005435611863	10881	Economy	14400.00
0005435424278	10881	Economy	14400.00
0005435380254	10881	Economy	14400.00
0005435424232	10881	Economy	14400.00
0005435424247	10881	Economy	14400.00
0005435611810	10881	Economy	14400.00
0005435305000	10881	Economy	14400.00
0005434244741	10881	Economy	14400.00
0005435611866	10881	Economy	14400.00
0005435424219	10881	Economy	14400.00
0005435612228	10881	Economy	14400.00
0005434244747	10881	Economy	14400.00
0005435612340	10881	Economy	14400.00
0005434343619	10881	Economy	14400.00
0005434244733	10881	Economy	14400.00
0005435612235	10881	Economy	14400.00
0005435611791	10881	Economy	14400.00
0005435424227	10881	Economy	14400.00
0005435424274	10881	Economy	15800.00
0005435304118	10881	Economy	14400.00
0005434656538	10881	Economy	14400.00
0005435612193	10881	Economy	14400.00
0005435611721	10881	Economy	15800.00
0005434244751	10881	Economy	14400.00
0005435611756	10881	Economy	14400.00
0005435612411	10881	Economy	14400.00
0005435611886	10881	Economy	14400.00
0005434343600	10881	Economy	14400.00
0005435612040	10881	Economy	14400.00
0005435424265	10881	Economy	14400.00
0005433719113	10881	Economy	14400.00
0005434244740	10881	Economy	14400.00
0005432164975	10881	Economy	14400.00
0005435611766	10881	Economy	14400.00
0005435424249	10881	Economy	14400.00
0005434244743	10881	Economy	14400.00
0005435424254	10881	Economy	14400.00
0005435424222	10881	Economy	14400.00
0005434656540	10881	Economy	14400.00
0005434244730	10881	Economy	14400.00
0005435612270	10881	Economy	14400.00
0005435424256	10881	Economy	14400.00
0005434244748	10881	Economy	14400.00
0005435612148	10881	Economy	14400.00
0005435424260	10881	Economy	14400.00
0005434244738	10881	Economy	14400.00
0005432166873	10881	Economy	14400.00
0005435611737	10881	Economy	14400.00
0005432840995	10881	Economy	14400.00
0005435612278	10881	Economy	14400.00
0005435424248	10881	Economy	14400.00
0005435380255	10881	Economy	14400.00
0005435380258	10881	Economy	14400.00
0005435611802	10881	Economy	14400.00
0005435555337	10881	Economy	14400.00
0005434573108	10881	Economy	14400.00
0005435611862	10881	Economy	14400.00
0005434244725	10881	Economy	14400.00
0005435424245	10881	Economy	14400.00
0005435612076	10881	Economy	14400.00
0005434656539	10881	Economy	14400.00
0005435612239	10881	Economy	14400.00
0005435611928	10881	Economy	14400.00
0005435424275	10881	Economy	14400.00
0005434244736	10881	Economy	14400.00
0005435424211	10881	Economy	14400.00
0005435424235	10881	Economy	14400.00
0005435611887	10881	Economy	14400.00
0005435611726	10881	Economy	14400.00
0005435319497	10881	Economy	14400.00
0005435380256	10881	Economy	14400.00
0005434244746	10881	Economy	14400.00
0005435424251	10881	Economy	14400.00
0005435424263	10881	Economy	14400.00
0005435424226	10881	Economy	14400.00
0005435612014	10881	Economy	14400.00
0005435424244	10881	Economy	14400.00
0005435611754	10881	Economy	14400.00
0005435319501	10881	Economy	14400.00
0005433719114	10881	Economy	14400.00
0005435424212	10881	Economy	14400.00
0005435611803	10881	Economy	14400.00
0005435424215	10881	Economy	14400.00
0005435424279	10881	Economy	14400.00
0005435611829	10881	Economy	14400.00
0005434244752	10881	Economy	14400.00
0005435424264	10881	Economy	14400.00
0005435424229	10881	Economy	14400.00
0005435424250	10881	Economy	14400.00
0005435424214	10881	Economy	14400.00
0005432164976	10881	Economy	14400.00
0005434244749	10881	Economy	15800.00
0005435424238	10881	Economy	15800.00
0005435611731	10881	Economy	15800.00
0005435424213	10881	Economy	15800.00
0005435611786	10881	Economy	15800.00
0005435380252	10881	Economy	15800.00
0005434244742	10881	Economy	14400.00
0005435424252	10881	Economy	14400.00
0005435611897	10881	Economy	14400.00
0005432164971	10881	Economy	14400.00
0005432164978	10881	Economy	14400.00
0005435319503	10881	Economy	14400.00
0005435424221	10881	Economy	14400.00
0005435319502	10881	Economy	14400.00
0005435555336	10881	Economy	14400.00
0005435319500	10881	Economy	14400.00
0005435424240	10881	Economy	14400.00
0005435304119	10881	Economy	14400.00
0005435611984	10881	Economy	14400.00
0005435424210	10881	Economy	14400.00
0005435424273	10881	Economy	14400.00
0005435611743	10881	Economy	14400.00
0005435612094	10881	Economy	14400.00
0005435611844	10881	Economy	14400.00
0005434343658	10881	Economy	14400.00
0005434343642	10881	Economy	14400.00
0005435304120	10881	Economy	14400.00
0005435424270	10881	Economy	14400.00
0005435424258	10881	Economy	14400.00
0005435424242	10881	Economy	14400.00
0005434244753	10881	Economy	14400.00
0005434244744	10881	Economy	14400.00
0005435612131	10881	Economy	14400.00
0005435319499	10881	Economy	14400.00
0005432363389	10881	Economy	14400.00
0005435424255	10881	Economy	14400.00
0005434244732	10881	Economy	14400.00
0005435611816	10881	Economy	14400.00
0005435611873	10881	Economy	14400.00
0005435611916	10881	Economy	14400.00
0005435424276	10881	Economy	14400.00
0005435424228	10881	Economy	14400.00
0005435612013	10881	Economy	14400.00
0005434244739	10881	Economy	14400.00
0005435611776	10881	Economy	14400.00
0005432840996	10881	Economy	14400.00
0005435424218	10881	Economy	14400.00
0005435611917	10881	Economy	14400.00
0005434343591	10881	Economy	14400.00
0005435424217	10881	Economy	14400.00
0005434244735	10881	Economy	14400.00
0005435424243	10881	Economy	14400.00
0005435424246	10881	Economy	14400.00
0005434244750	10881	Economy	14400.00
0005435611950	10881	Economy	14400.00
0005435611838	10881	Economy	14400.00
0005435424231	10881	Economy	14400.00
0005435611975	10881	Economy	14400.00
0005434244731	10881	Economy	14400.00
0005435611877	10881	Economy	14400.00
0005435424220	10881	Economy	14400.00
0005434244726	10881	Economy	14400.00
0005432363390	10881	Economy	14400.00
0005435611753	10881	Economy	14400.00
0005435424272	10881	Economy	14400.00
0005435612265	10881	Economy	14400.00
0005435612237	10881	Economy	14400.00
0005435612279	10881	Economy	14400.00
0005434244729	10881	Economy	14400.00
0005434244727	10881	Economy	14400.00
0005435611765	10881	Economy	14400.00
0005435612229	10881	Economy	14400.00
0005434343657	10881	Economy	14400.00
0005434143710	3377	Business	18800.00
0005433805077	3377	Business	18800.00
0005432181524	3377	Business	18800.00
0005432459223	3377	Business	18800.00
0005432181540	3377	Business	18800.00
0005433507039	3377	Business	18800.00
0005433805110	3377	Business	18800.00
0005433507038	3377	Business	18800.00
0005433507027	3377	Business	18800.00
0005433507024	3377	Business	18800.00
0005433805083	3377	Business	18800.00
0005433633558	3377	Business	18800.00
0005433805090	3377	Business	18800.00
0005432459085	3377	Business	18800.00
0005434143707	3377	Business	18800.00
0005433805094	3377	Business	18800.00
0005433633553	3377	Business	18800.00
0005432459084	3377	Business	18800.00
0005433633559	3377	Business	18800.00
0005432181543	3377	Business	18800.00
0005432181528	3377	Business	18800.00
0005433805106	3377	Business	18800.00
0005434143708	3377	Business	18800.00
0005432459224	3377	Business	18800.00
0005433805089	3377	Economy	6900.00
0005433805109	3377	Business	18800.00
0005433633554	3377	Economy	6900.00
0005433805117	3377	Economy	6900.00
0005433633556	3377	Economy	6900.00
0005433633561	3377	Economy	6900.00
0005432458981	3377	Economy	6900.00
0005433633529	3377	Economy	6300.00
0005433805086	3377	Economy	6300.00
0005433805099	3377	Economy	6300.00
0005432181539	3377	Economy	6300.00
0005433633555	3377	Economy	6300.00
0005433805118	3377	Economy	6300.00
0005433805081	3377	Economy	6300.00
0005433805105	3377	Economy	6300.00
0005433507042	3377	Economy	6300.00
0005433633542	3377	Economy	6300.00
0005433507037	3377	Economy	6300.00
0005433633552	3377	Economy	6300.00
0005433633548	3377	Economy	6300.00
0005432459140	3377	Economy	6300.00
0005432459018	3377	Economy	6300.00
0005433805093	3377	Economy	6300.00
0005433633560	3377	Economy	6300.00
0005433805103	3377	Economy	6300.00
0005433805084	3377	Economy	6300.00
0005433805113	3377	Economy	6300.00
0005433507034	3377	Economy	6300.00
0005433805079	3377	Economy	6300.00
0005432459130	3377	Economy	6300.00
0005432181541	3377	Economy	6300.00
0005432181536	3377	Economy	6300.00
0005433805091	3377	Economy	6300.00
0005434143712	3377	Economy	6300.00
0005433507026	3377	Economy	6300.00
0005433805096	3377	Economy	6300.00
0005433805104	3377	Economy	6300.00
0005432181532	3377	Economy	6300.00
0005432181542	3377	Economy	6300.00
0005433633545	3377	Economy	6300.00
0005434143713	3377	Economy	6300.00
0005434143711	3377	Economy	6300.00
0005433633550	3377	Economy	6300.00
0005433633531	3377	Economy	6300.00
0005433633530	3377	Economy	6300.00
0005433633528	3377	Economy	6300.00
0005433805100	3377	Economy	6300.00
0005433633539	3377	Economy	6300.00
0005432459098	3377	Economy	6300.00
0005434143714	3377	Economy	6300.00
0005433805097	3377	Economy	6300.00
0005433633551	3377	Economy	6300.00
0005433633544	3377	Economy	6300.00
0005433507029	3377	Economy	6300.00
0005433633533	3377	Economy	6300.00
0005432181525	3377	Economy	6300.00
0005433805101	3377	Economy	6300.00
0005432459129	3377	Economy	6300.00
0005433805087	3377	Economy	6300.00
0005433507030	3377	Economy	6300.00
0005433633543	3377	Economy	6300.00
0005433633540	3377	Economy	6900.00
0005432459003	3377	Economy	6900.00
0005434143706	3377	Economy	6900.00
0005433633534	3377	Economy	6900.00
0005433805098	3377	Economy	6300.00
0005433805085	3377	Economy	6300.00
0005433805108	3377	Economy	6300.00
0005432181546	3377	Economy	6300.00
0005433507025	3377	Economy	6900.00
0005432181545	3377	Economy	6300.00
0005433633557	3377	Economy	6300.00
0005433805092	3377	Economy	6300.00
0005433633547	3377	Economy	6300.00
0005433805107	3377	Economy	6300.00
0005433507033	3377	Economy	6300.00
0005432181526	3377	Economy	6300.00
0005432459002	3377	Economy	6300.00
0005433805078	3377	Economy	6300.00
0005432459005	3377	Economy	6300.00
0005433805114	3377	Economy	6300.00
0005432181531	3377	Economy	6300.00
0005433805095	3377	Economy	6300.00
0005433507031	3377	Economy	6300.00
0005433507041	3377	Economy	6300.00
0005433507036	3377	Economy	6300.00
0005433633537	3377	Economy	6300.00
0005432181538	3377	Economy	6300.00
0005433633541	3377	Economy	6300.00
0005433805082	3377	Economy	6300.00
0005433507028	3377	Economy	6300.00
0005433805088	3377	Economy	6300.00
0005433805102	3377	Economy	6300.00
0005432181533	3377	Economy	6300.00
0005432459001	3377	Economy	6300.00
0005432181534	3377	Economy	6300.00
0005434143709	3377	Economy	6300.00
0005433633546	3377	Economy	6300.00
0005433633549	3377	Economy	6300.00
0005433507040	3377	Economy	6300.00
0005433805080	3377	Economy	6300.00
0005433805116	3377	Economy	6300.00
0005433633536	3377	Economy	6300.00
0005432181527	3377	Economy	6300.00
0005432181529	3377	Economy	6300.00
0005432458987	3377	Economy	6300.00
0005433507035	3377	Economy	6300.00
0005432459004	3377	Economy	6300.00
0005432459000	3377	Economy	6300.00
0005432181537	3377	Economy	6300.00
0005433633532	3377	Economy	6300.00
0005432181530	3377	Economy	6300.00
0005433633535	3377	Economy	6300.00
0005433507032	3377	Economy	6300.00
0005433633527	3377	Economy	6300.00
0005433805115	3377	Economy	6300.00
0005433633538	3377	Economy	6300.00
0005432181535	3377	Economy	6300.00
0005433805112	3377	Economy	6300.00
0005432181544	3377	Economy	6300.00
0005432459088	3377	Economy	6300.00
0005433805111	3377	Economy	6300.00
0005435884610	3378	Business	18800.00
0005435884456	3378	Business	18800.00
0005435884508	3378	Business	18800.00
0005435884397	3378	Business	18800.00
0005435884522	3378	Economy	6900.00
0005435884523	3378	Economy	6300.00
0005435884380	3378	Economy	6300.00
0005435884419	3378	Economy	6300.00
0005435884428	3378	Economy	6300.00
0005435884514	3378	Economy	6300.00
0005435884381	3378	Economy	6300.00
0005435884416	3378	Economy	6300.00
0005435884398	3378	Economy	6300.00
0005435884496	3378	Economy	6300.00
0005435884430	3378	Economy	6300.00
0005435884382	3378	Economy	6300.00
0005435884539	3378	Economy	6300.00
0005435884643	3378	Economy	6300.00
0005435884541	3378	Economy	6300.00
0005435884418	3378	Economy	6300.00
0005435884501	3378	Economy	6300.00
0005435884647	3378	Economy	6300.00
0005435884540	3378	Economy	6300.00
0005435884621	3378	Economy	6300.00
0005435884499	3378	Economy	6300.00
0005435884445	3378	Economy	6300.00
0005435884651	3378	Economy	6300.00
0005435884517	3378	Economy	6300.00
0005435884500	3378	Economy	6300.00
0005435884620	3378	Economy	6300.00
0005435884553	3378	Economy	6300.00
0005435884385	3378	Economy	6300.00
0005432459468	8248	Business	18800.00
0005432459448	8248	Business	18800.00
0005435884847	8248	Business	18800.00
0005433506861	8248	Business	18800.00
0005432042599	8248	Business	18800.00
0005435884862	8248	Business	18800.00
0005435884857	8248	Business	18800.00
0005432459458	8248	Business	18800.00
0005432042602	8248	Business	18800.00
0005432459470	8248	Business	18800.00
0005432459449	8248	Business	18800.00
0005432459462	8248	Business	18800.00
0005435884830	8248	Business	18800.00
0005435884861	8248	Business	18800.00
0005432459473	8248	Business	18800.00
0005435884836	8248	Business	18800.00
0005432459489	8248	Business	18800.00
0005432459441	8248	Business	18800.00
0005432459457	8248	Business	18800.00
0005435884828	8248	Business	18800.00
0005435884845	8248	Economy	6900.00
0005432459467	8248	Economy	6900.00
0005432042608	8248	Economy	6900.00
0005432459480	8248	Economy	6900.00
0005435884842	8248	Economy	6300.00
0005433506890	8248	Economy	6300.00
0005432459455	8248	Economy	6300.00
0005432459439	8248	Economy	6300.00
0005433506859	8248	Economy	6300.00
0005433506887	8248	Economy	6300.00
0005435884835	8248	Economy	6300.00
0005432459487	8248	Economy	6300.00
0005432459474	8248	Economy	6300.00
0005432459447	8248	Economy	6300.00
0005432459469	8248	Economy	6300.00
0005435884840	8248	Economy	6300.00
0005435884863	8248	Economy	6300.00
0005435884838	8248	Economy	6300.00
0005432459438	8248	Economy	6300.00
0005435884843	8248	Economy	6300.00
0005432459456	8248	Economy	6300.00
0005433506864	8248	Economy	6300.00
0005432459440	8248	Economy	6300.00
0005433506930	8248	Economy	6300.00
0005435884860	8248	Economy	6300.00
0005432459478	8248	Economy	6300.00
0005432459486	8248	Economy	6300.00
0005432459451	8248	Economy	6300.00
0005435884844	8248	Economy	6300.00
0005432459477	8248	Economy	6300.00
0005435884837	8248	Economy	6300.00
0005432459485	8248	Economy	6300.00
0005432042598	8248	Economy	6300.00
0005432459482	8248	Economy	6300.00
0005432459488	8248	Economy	6300.00
0005432459471	8248	Economy	6300.00
0005432459465	8248	Economy	6300.00
0005432459464	8248	Economy	6300.00
0005435884834	8248	Economy	6300.00
0005432042604	8248	Economy	6300.00
0005432459452	8248	Economy	6300.00
0005433506903	8248	Economy	6300.00
0005435884852	8248	Economy	6300.00
0005432459450	8248	Economy	6300.00
0005432042601	8248	Economy	6300.00
0005432459479	8248	Economy	6300.00
0005435884859	8248	Economy	6300.00
0005432459445	8248	Economy	6300.00
0005435884853	8248	Economy	6900.00
0005432459483	8248	Economy	6900.00
0005432459466	8248	Economy	6900.00
0005432042606	8248	Economy	6900.00
0005433506876	8248	Economy	6300.00
0005433506880	8248	Economy	6300.00
0005432459461	8248	Economy	6300.00
0005432459459	8248	Economy	6300.00
0005435884841	8248	Economy	6300.00
0005435884858	8248	Economy	6300.00
0005432042596	8248	Economy	6300.00
0005433506902	8248	Economy	6300.00
0005432459444	8248	Economy	6300.00
0005435884832	8248	Economy	6300.00
0005434312304	8248	Economy	6300.00
0005432042605	8248	Economy	6300.00
0005434312303	8248	Economy	6300.00
0005432459463	8248	Economy	6300.00
0005435884849	8248	Economy	6300.00
0005435884856	8248	Economy	6300.00
0005432459446	8248	Economy	6300.00
0005432042600	8248	Economy	6300.00
0005432459442	8248	Economy	6300.00
0005435884831	8248	Economy	6300.00
0005432459481	8248	Economy	6300.00
0005435884839	8248	Economy	6300.00
0005435884850	8248	Economy	6300.00
0005432459437	8248	Economy	6300.00
0005432459460	8248	Economy	6300.00
0005433506942	8248	Economy	6300.00
0005432459476	8248	Economy	6300.00
0005435884848	8248	Economy	6300.00
0005432459472	8248	Economy	6300.00
0005432459475	8248	Economy	6300.00
0005433506881	8248	Economy	6300.00
0005433506893	8248	Economy	6300.00
0005435884829	8248	Economy	6300.00
0005432459484	8248	Economy	6300.00
0005432042607	8248	Economy	6300.00
0005435884833	8248	Economy	6300.00
0005435884846	8248	Economy	6300.00
0005435884855	8248	Economy	6300.00
0005432459454	8248	Economy	6300.00
0005432042595	8248	Economy	6300.00
0005435884851	8248	Economy	6300.00
0005435884854	8248	Economy	6300.00
0005432042603	8248	Economy	6300.00
0005432459443	8248	Economy	6300.00
0005432459453	8248	Economy	6300.00
0005432042597	8248	Economy	6300.00
0005433633271	8245	Business	18800.00
0005433633250	8245	Business	18800.00
0005433804857	8245	Business	18800.00
0005435854045	8245	Business	18800.00
0005433804891	8245	Business	18800.00
0005433804828	8245	Business	18800.00
0005433633248	8245	Business	18800.00
0005433633290	8245	Business	18800.00
0005433633336	8245	Economy	6900.00
0005433633254	8245	Economy	6300.00
0005433804892	8245	Economy	6300.00
0005433633251	8245	Economy	6300.00
0005433804798	8245	Economy	6300.00
0005433804840	8245	Economy	6300.00
0005433804849	8245	Economy	6300.00
0005435854047	8245	Economy	6300.00
0005433633227	8245	Economy	6300.00
0005434271277	8245	Economy	6300.00
0005433804932	8245	Economy	6900.00
0005433633279	8245	Economy	6900.00
0005433804818	8245	Economy	6300.00
0005435854046	8245	Economy	6300.00
0005433804837	8245	Economy	6300.00
0005433804827	8245	Economy	6300.00
0005433804783	8245	Economy	6300.00
0005433633285	8245	Economy	6300.00
0005434271278	8245	Economy	6300.00
0005433804979	8245	Economy	6300.00
0005433804782	8245	Economy	6300.00
0005433804801	8245	Economy	6300.00
0005433804803	8245	Economy	6300.00
0005434271279	8245	Economy	6300.00
0005433633297	8245	Economy	6300.00
0005433633363	8245	Economy	6300.00
0005433633284	8245	Economy	6300.00
0005433804793	8245	Economy	6300.00
0005434271280	8245	Economy	6300.00
0005434271287	8245	Economy	6300.00
0005433633283	8245	Economy	6300.00
0005434183547	8244	Business	18800.00
0005432727834	4673	Business	9900.00
0005432382869	4673	Business	9900.00
0005433722167	4673	Business	9900.00
0005432382876	4673	Business	9900.00
0005432382884	4673	Business	9900.00
0005432382848	4673	Business	9900.00
0005432727839	4673	Economy	3300.00
0005433453747	4673	Economy	3300.00
0005432382849	4673	Economy	3300.00
0005432382868	4673	Economy	3300.00
0005432382855	4673	Economy	3300.00
0005433453748	4673	Economy	3300.00
0005432382870	4673	Economy	3600.00
0005433722168	4673	Economy	3600.00
0005432382856	4673	Economy	3300.00
0005432382864	4673	Economy	3300.00
0005432382845	4673	Economy	3300.00
0005432382857	4673	Economy	3300.00
0005432382874	4673	Economy	3300.00
0005432382859	4673	Economy	3300.00
0005433454857	4673	Economy	3300.00
0005432382853	4673	Economy	3300.00
0005432727843	4673	Economy	3300.00
0005432382852	4673	Economy	3300.00
0005432727835	4673	Economy	3300.00
0005432727831	4673	Economy	3300.00
0005432382880	4673	Economy	3300.00
0005432382850	4673	Economy	3300.00
0005432382862	4673	Economy	3300.00
0005432382882	4673	Economy	3300.00
0005432382866	4673	Economy	3300.00
0005432382875	4673	Economy	3300.00
0005432727840	4673	Economy	3300.00
0005432382878	4673	Economy	3300.00
0005432382865	4673	Economy	3300.00
0005432382883	4673	Economy	3300.00
0005432382881	4673	Economy	3300.00
0005433454858	4673	Economy	3300.00
0005432382863	4673	Economy	3300.00
0005432382846	4673	Economy	3300.00
0005432382877	4673	Economy	3300.00
0005432727841	4673	Economy	3300.00
0005432382872	4673	Economy	3300.00
0005432382867	4673	Economy	3300.00
0005432382847	4673	Economy	3300.00
0005432382885	4673	Economy	3300.00
0005432727838	4673	Economy	3300.00
0005432382858	4673	Economy	3300.00
0005432382873	4673	Economy	3300.00
0005433454856	4673	Economy	3300.00
0005432382871	4673	Economy	3300.00
0005432727832	4673	Economy	3300.00
0005433722169	4673	Economy	3300.00
0005432727836	4673	Economy	3300.00
0005432727837	4673	Economy	3300.00
0005432382861	4673	Economy	3300.00
0005432382844	4673	Economy	3300.00
0005432382854	4673	Economy	3300.00
0005432382860	4673	Economy	3300.00
0005432382879	4673	Economy	3300.00
0005432727842	4673	Economy	3300.00
0005432382851	4673	Economy	3300.00
0005432727833	4673	Economy	3300.00
0005433453728	30255	Economy	3300.00
0005432382533	30255	Economy	3300.00
0005432727743	30255	Economy	3300.00
0005432727789	30255	Economy	3300.00
0005432382520	30255	Economy	3300.00
0005432382555	30255	Economy	3300.00
0005432727742	30255	Economy	3300.00
0005432382511	30255	Economy	3300.00
0005432382586	30255	Economy	3300.00
0005432727722	30255	Economy	3300.00
0005432382531	30255	Economy	3300.00
0005432727746	30255	Economy	3300.00
0005432382532	30255	Economy	3300.00
0005432727747	30255	Economy	3300.00
0005432727790	30255	Economy	3300.00
0005432382556	30255	Economy	3300.00
0005433451583	30255	Economy	3300.00
0005432382541	30255	Economy	3300.00
0005432727721	30255	Economy	3300.00
0005435540832	1726	Business	57200.00
0005433516815	1726	Business	57200.00
0005433516810	1726	Business	57200.00
0005435529090	1726	Business	57200.00
0005435540842	1726	Business	57200.00
0005433516807	1726	Business	57200.00
0005435540833	1726	Business	57200.00
0005435529088	1726	Business	57200.00
0005435529086	1726	Business	57200.00
0005435540835	1726	Economy	19100.00
0005433516809	1726	Economy	19100.00
0005435529087	1726	Economy	19100.00
0005435529096	1726	Economy	19100.00
0005432924964	1726	Economy	19100.00
0005435540831	1726	Economy	19100.00
0005432294469	1726	Economy	19100.00
0005435540837	1726	Economy	21000.00
0005435529079	1726	Economy	21000.00
0005435540841	1726	Economy	21000.00
0005435529092	1726	Economy	19100.00
0005435529089	1726	Economy	19100.00
0005433516814	1726	Economy	19100.00
0005435529080	1726	Economy	19100.00
0005435540843	1726	Economy	19100.00
0005435540834	1726	Economy	19100.00
0005435529085	1726	Economy	19100.00
0005433516812	1726	Economy	19100.00
0005435540840	1726	Economy	19100.00
0005435529081	1726	Economy	19100.00
0005435529098	1726	Economy	19100.00
0005433516816	1726	Economy	19100.00
0005435529093	1726	Economy	19100.00
0005432294468	1726	Economy	19100.00
0005435540828	1726	Economy	19100.00
0005432294467	1726	Economy	19100.00
0005435540825	1726	Economy	19100.00
0005435529097	1726	Economy	19100.00
0005435540830	1726	Economy	19100.00
0005435540829	1726	Economy	19100.00
0005435529078	1726	Economy	19100.00
0005435529083	1726	Economy	19100.00
0005435529094	1726	Economy	19100.00
0005435540836	1726	Economy	19100.00
0005435529084	1726	Economy	19100.00
0005432924966	1726	Economy	19100.00
0005433516811	1726	Economy	19100.00
0005435540826	1726	Economy	19100.00
0005435540823	1726	Economy	19100.00
0005432924965	1726	Economy	19100.00
0005433516806	1726	Economy	19100.00
0005435540827	1726	Economy	19100.00
0005435529082	1726	Economy	19100.00
0005435529095	1726	Economy	19100.00
0005435540838	1726	Economy	19100.00
0005435540824	1726	Economy	19100.00
0005433516808	1726	Economy	19100.00
0005435540839	1726	Economy	19100.00
0005435529091	1726	Economy	19100.00
0005435529099	1726	Economy	19100.00
0005432924955	1726	Economy	19100.00
0005433516813	1726	Economy	19100.00
0005435540638	21985	Business	57200.00
0005435540637	21985	Business	57200.00
0005432924995	21985	Business	57200.00
0005435517614	21985	Business	57200.00
0005435540722	21985	Business	57200.00
0005435540681	21985	Business	57200.00
0005435540645	21985	Business	57200.00
0005435517591	21985	Economy	19100.00
0005433516740	21985	Economy	19100.00
0005435517668	21985	Economy	19100.00
0005435540669	21985	Economy	19100.00
0005435517638	21985	Economy	19100.00
0005435540662	21985	Economy	19100.00
0005432924996	21985	Economy	19100.00
0005435517593	21985	Economy	19100.00
0005435517601	21985	Economy	19100.00
0005435540723	21985	Economy	19100.00
0005432924999	21985	Economy	19100.00
0005435540641	21985	Economy	19100.00
0005435540747	21985	Economy	19100.00
0005435517599	21985	Economy	19100.00
0005435517612	21985	Economy	19100.00
0005435517592	21985	Economy	19100.00
0005435540721	21985	Economy	19100.00
0005435540693	21985	Economy	19100.00
0005435517615	21985	Economy	19100.00
0005433516725	21985	Economy	19100.00
0005433516773	21985	Economy	19100.00
0005435540636	21985	Economy	19100.00
0005432924998	21985	Economy	19100.00
0005432924997	21985	Economy	19100.00
0005435517600	21985	Economy	19100.00
0005435517639	21985	Economy	19100.00
0005433516772	21985	Economy	19100.00
0005433516734	21985	Economy	19100.00
0005435540644	21985	Economy	19100.00
0005435540680	21985	Economy	19100.00
0005435517613	21985	Economy	19100.00
0005434458638	7357	Business	18500.00
0005434458641	7357	Business	18500.00
0005432838770	7357	Business	18500.00
0005432838784	7357	Business	18500.00
0005432838776	7357	Business	18500.00
0005432823432	7357	Business	18500.00
0005432073362	7357	Business	18500.00
0005435252457	7357	Business	18500.00
0005435252407	7357	Business	18500.00
0005432838797	7357	Economy	6200.00
0005432838769	7357	Economy	6200.00
0005432838775	7357	Economy	6200.00
0005434458640	7357	Economy	6200.00
0005435252396	7357	Economy	6200.00
0005432838771	7357	Economy	6200.00
0005432838788	7357	Economy	6200.00
0005435252392	7357	Economy	6200.00
0005432838774	7357	Economy	6800.00
0005432838778	7357	Economy	6800.00
0005432073363	7357	Economy	6800.00
0005434458630	7357	Economy	6800.00
0005434458642	7357	Economy	6200.00
0005434458644	7357	Economy	6200.00
0005435252405	7357	Economy	6200.00
0005432838773	7357	Economy	6200.00
0005432838781	7357	Economy	6200.00
0005434458645	7357	Economy	6200.00
0005435252395	7357	Economy	6200.00
0005432838791	7357	Economy	6200.00
0005434458633	7357	Economy	6200.00
0005434458646	7357	Economy	6200.00
0005434458636	7357	Economy	6200.00
0005434458637	7357	Economy	6200.00
0005432838783	7357	Economy	6200.00
0005432838777	7357	Economy	6200.00
0005432838790	7357	Economy	6200.00
0005434458643	7357	Economy	6200.00
0005434458639	7357	Economy	6200.00
0005432823431	7357	Economy	6200.00
0005432838793	7357	Economy	6200.00
0005434458625	7357	Economy	6200.00
0005432838782	7357	Economy	6200.00
0005434458634	7357	Economy	6200.00
0005434458632	7357	Economy	6200.00
0005434458627	7357	Economy	6200.00
0005432838789	7357	Economy	6200.00
0005435252404	7357	Economy	6200.00
0005434458635	7357	Economy	6200.00
0005432073361	7357	Economy	6200.00
0005435252394	7357	Economy	6200.00
0005435252406	7357	Economy	6200.00
0005432838794	7357	Economy	6200.00
0005432838772	7357	Economy	6200.00
0005432838792	7357	Economy	6200.00
0005432838779	7357	Economy	6200.00
0005434458631	7357	Economy	6200.00
0005435252393	7357	Economy	6200.00
0005434458628	7357	Economy	6200.00
0005434458626	7357	Economy	6200.00
0005432838787	7357	Economy	6200.00
0005432838795	7357	Economy	6200.00
0005432838767	7357	Economy	6200.00
0005432840993	7357	Economy	6200.00
0005432838785	7357	Economy	6200.00
0005432838780	7357	Economy	6200.00
0005435491406	7357	Economy	6200.00
0005432840994	7357	Economy	6200.00
0005432838796	7357	Economy	6200.00
0005432838768	7357	Economy	6200.00
0005434458629	7357	Economy	6200.00
0005432838786	7357	Economy	6200.00
0005435252559	28915	Business	18500.00
0005435252561	28915	Business	18500.00
0005432838573	28915	Business	18500.00
0005432838509	28915	Business	18500.00
0005432838548	28915	Business	18500.00
0005432838545	28915	Business	18500.00
0005435252556	28915	Business	18500.00
0005434458466	28915	Business	18500.00
0005432838533	28915	Business	18500.00
0005435252547	28915	Economy	6200.00
0005432838612	28915	Economy	6200.00
0005434458507	28915	Economy	6200.00
0005434458513	28915	Economy	6200.00
0005434664941	28915	Economy	6200.00
0005435252560	28915	Economy	6200.00
0005435252562	28915	Economy	6200.00
0005432838546	28915	Economy	6800.00
0005435252546	28915	Economy	6800.00
0005434664942	28915	Economy	6800.00
0005432838620	28915	Economy	6800.00
0005432838484	28915	Economy	6800.00
0005435252564	28915	Economy	6200.00
0005435491427	28915	Economy	6200.00
0005435252555	28915	Economy	6200.00
0005432001007	28915	Economy	6200.00
0005434458452	28915	Economy	6200.00
0005432838492	28915	Economy	6200.00
0005432838491	28915	Economy	6200.00
0005435252563	28915	Economy	6200.00
0005435252550	28915	Economy	6200.00
0005435252558	28915	Economy	6200.00
0005432838532	28915	Economy	6200.00
0005435252557	28915	Economy	6200.00
0005435252554	28915	Economy	6200.00
0005435252553	28915	Economy	6200.00
0005432838486	28915	Economy	6200.00
0005432823427	28915	Economy	6200.00
0005435491426	28915	Economy	6200.00
0005432838563	28915	Economy	6200.00
0005435252549	28915	Economy	6200.00
0005432001006	28915	Economy	6200.00
0005434458451	28915	Economy	6200.00
0005432838487	28915	Economy	6200.00
0005434664940	28915	Economy	6200.00
0005432838619	28915	Economy	6200.00
0005432838483	28915	Economy	6200.00
0005432838550	28915	Economy	6200.00
0005434458481	28915	Economy	6200.00
0005432838521	28915	Economy	6200.00
0005434458515	28915	Economy	6200.00
0005434458450	28915	Economy	6200.00
0005435252548	28915	Economy	6200.00
0005434458480	28915	Economy	6200.00
0005435252552	28915	Economy	6200.00
0005435252551	28915	Economy	6200.00
0005432838547	28915	Economy	6200.00
0005435990564	8831	Business	145300.00
0005435990563	8831	Economy	48400.00
0005435990566	8831	Economy	48400.00
0005434275942	8831	Economy	53300.00
0005434275930	8831	Economy	48400.00
0005434275957	8831	Economy	48400.00
0005434275943	8831	Economy	48400.00
0005435990568	8831	Economy	48400.00
0005434275946	8831	Economy	48400.00
0005434275940	8831	Economy	48400.00
0005434275938	8831	Economy	48400.00
0005434275931	8831	Economy	48400.00
0005434275932	8831	Economy	48400.00
0005435990565	8831	Economy	48400.00
0005434275952	8831	Economy	48400.00
0005434275941	8831	Economy	48400.00
0005435990567	8831	Economy	48400.00
0005434275982	15734	Economy	48400.00
0005435990501	15734	Economy	48400.00
0005435990499	15734	Economy	48400.00
0005434275979	15734	Economy	53300.00
0005434275977	15734	Economy	48400.00
0005434275978	15734	Economy	48400.00
0005435990514	15734	Economy	48400.00
0005434275980	15734	Economy	48400.00
0005435990527	15734	Economy	48400.00
0005435990500	15734	Economy	48400.00
0005435990502	15734	Economy	48400.00
0005435990524	15734	Economy	48400.00
0005434275981	15734	Economy	48400.00
0005433468267	2099	Economy	13300.00
0005433468259	2099	Economy	12100.00
0005433468269	2099	Economy	12100.00
0005433468264	2099	Economy	12100.00
0005433468256	2099	Economy	12100.00
0005433468261	2099	Economy	12100.00
0005433468260	2099	Economy	12100.00
0005433468263	2099	Economy	12100.00
0005433468266	2099	Economy	12100.00
0005433468265	2099	Economy	12100.00
0005433468254	2099	Economy	12100.00
0005433468257	2099	Economy	12100.00
0005432909197	2099	Economy	12100.00
0005432909192	2099	Economy	12100.00
0005433468268	2099	Economy	12100.00
0005432909206	2099	Economy	12100.00
0005432909199	2099	Economy	12100.00
0005433468270	2099	Economy	12100.00
0005433468255	2099	Economy	12100.00
0005433468258	2099	Economy	12100.00
0005432909198	2099	Economy	12100.00
0005433468262	2099	Economy	12100.00
0005432909205	2099	Economy	12100.00
0005432909200	2099	Economy	12100.00
0005432909236	23841	Economy	13300.00
0005433468206	23841	Economy	13300.00
0005432909230	23841	Economy	13300.00
0005432909235	23841	Economy	12100.00
0005433468188	23841	Economy	12100.00
0005433468203	23841	Economy	12100.00
0005432909240	23841	Economy	12100.00
0005432909232	23841	Economy	12100.00
0005432909239	23841	Economy	12100.00
0005432909242	23841	Economy	12100.00
0005432909228	23841	Economy	12100.00
0005432909241	23841	Economy	12100.00
0005432909231	23841	Economy	12100.00
0005433468187	23841	Economy	12100.00
0005432909233	23841	Economy	12100.00
0005432909238	23841	Economy	12100.00
0005433468184	23841	Economy	12100.00
0005432909234	23841	Economy	12100.00
0005432909243	23841	Economy	12100.00
0005432909237	23841	Economy	12100.00
0005433468181	23841	Economy	12100.00
0005432909229	23841	Economy	12100.00
0005432359997	6403	Business	36600.00
0005432359987	6403	Business	36600.00
0005432359994	6403	Business	36600.00
0005432359990	6403	Business	36600.00
0005432359991	6403	Business	36600.00
0005432335936	6403	Business	36600.00
0005432359984	6403	Business	36600.00
0005435176663	6403	Business	36600.00
0005435176627	6403	Business	36600.00
0005432359976	6403	Business	36600.00
0005432359949	6403	Economy	12200.00
0005432359992	6403	Business	36600.00
0005435176689	6403	Economy	12200.00
0005432359975	6403	Economy	12200.00
0005435176704	6403	Economy	12200.00
0005432359989	6403	Economy	12200.00
0005435176668	6403	Economy	12200.00
0005435490177	6403	Economy	12200.00
0005435176716	6403	Economy	12200.00
0005432359988	6403	Economy	12200.00
0005434149536	6403	Economy	12200.00
0005435176665	6403	Economy	12200.00
0005432335934	6403	Economy	12200.00
0005432335930	6403	Economy	12200.00
0005435176751	6403	Economy	12200.00
0005432335939	6403	Economy	12200.00
0005432359969	6403	Economy	12200.00
0005432359980	6403	Economy	12200.00
0005432359971	6403	Economy	12200.00
0005432359953	6403	Economy	12200.00
0005435176616	6403	Economy	12200.00
0005432062186	6403	Economy	12200.00
0005432363389	6403	Economy	12200.00
0005435176690	6403	Economy	12200.00
0005432359993	6403	Economy	12200.00
0005435176585	6403	Economy	12200.00
0005435176623	6403	Economy	12200.00
0005435176666	6403	Economy	12200.00
0005432335931	6403	Economy	12200.00
0005435176699	6403	Economy	12200.00
0005435723015	6403	Economy	12200.00
0005432359977	6403	Economy	12200.00
0005435176667	6403	Economy	12200.00
0005435723011	6403	Economy	13400.00
0005432335933	6403	Economy	13400.00
0005435176651	6403	Economy	13400.00
0005435176644	6403	Economy	13400.00
0005432335935	6403	Economy	13400.00
0005432359986	6403	Economy	12200.00
0005432359985	6403	Economy	12200.00
0005432359995	6403	Economy	12200.00
0005435176622	6403	Economy	12200.00
0005432335932	6403	Economy	12200.00
0005432062185	6403	Economy	12200.00
0005435176717	6403	Economy	12200.00
0005432359972	6403	Economy	12200.00
0005432359996	6403	Economy	12200.00
0005435176713	6403	Economy	12200.00
0005432363390	6403	Economy	12200.00
0005435176721	6403	Economy	12200.00
0005432359963	6403	Economy	12200.00
0005432359978	6403	Economy	12200.00
0005432359982	6403	Economy	12200.00
0005432359961	6403	Economy	12200.00
0005432359951	6403	Economy	12200.00
0005432359962	6403	Economy	12200.00
0005432359979	6403	Economy	12200.00
0005432359957	6403	Economy	12200.00
0005432335938	6403	Economy	12200.00
0005432359958	6403	Economy	12200.00
0005432062184	6403	Economy	12200.00
0005432335940	6403	Economy	12200.00
0005432335941	6403	Economy	12200.00
0005435176590	6403	Economy	12200.00
0005432359965	6403	Economy	12200.00
0005435490182	6403	Economy	12200.00
0005432359956	6403	Economy	12200.00
0005432359955	6403	Economy	12200.00
0005434149531	6403	Economy	12200.00
0005432359983	6403	Economy	12200.00
0005434149530	6403	Economy	12200.00
0005432359952	6403	Economy	12200.00
0005432062187	6403	Economy	12200.00
0005435176722	6403	Economy	12200.00
0005432359959	6403	Economy	12200.00
0005435176682	6403	Economy	12200.00
0005432359973	6403	Economy	12200.00
0005435176669	6403	Economy	12200.00
0005432359966	6403	Economy	12200.00
0005434149537	6403	Economy	12200.00
0005432359960	6403	Economy	12200.00
0005432359954	6403	Economy	12200.00
0005435176709	6403	Economy	12200.00
0005432359974	6403	Economy	12200.00
0005435176700	6403	Economy	12200.00
0005432335942	6403	Economy	12200.00
0005432359981	6403	Economy	12200.00
0005435176720	6403	Economy	12200.00
0005432359950	6403	Economy	12200.00
0005432359967	6403	Economy	12200.00
0005435176741	6403	Economy	12200.00
0005432359970	6403	Economy	12200.00
0005432359968	6403	Economy	12200.00
0005432359964	6403	Economy	12200.00
0005432335937	6403	Economy	12200.00
0005432359581	20986	Business	36600.00
0005435176848	20986	Business	36600.00
0005432359573	20986	Business	36600.00
0005432359618	20986	Business	36600.00
0005432359603	20986	Business	36600.00
0005435176849	20986	Business	36600.00
0005432359524	20986	Business	36600.00
0005434149630	20986	Business	36600.00
0005435176847	20986	Business	36600.00
0005432359572	20986	Economy	12200.00
0005432335885	20986	Economy	12200.00
0005432052722	20986	Economy	12200.00
0005435176865	20986	Economy	12200.00
0005435176851	20986	Economy	12200.00
0005435176841	20986	Economy	12200.00
0005432363371	20986	Economy	12200.00
0005435176863	20986	Economy	12200.00
0005432359649	20986	Economy	12200.00
0005435490201	20986	Economy	12200.00
0005432359536	20986	Economy	12200.00
0005435176866	20986	Economy	12200.00
0005434149634	20986	Economy	12200.00
0005434149639	20986	Economy	12200.00
0005435490199	20986	Economy	12200.00
0005435176858	20986	Economy	12200.00
0005435176855	20986	Economy	12200.00
0005432359534	20986	Economy	12200.00
0005432359810	20986	Economy	12200.00
0005435176857	20986	Economy	12200.00
0005432359621	20986	Economy	12200.00
0005432335853	20986	Economy	12200.00
0005432052723	20986	Economy	12200.00
0005432359575	20986	Economy	12200.00
0005432335854	20986	Economy	12200.00
0005434149635	20986	Economy	12200.00
0005432359648	20986	Economy	12200.00
0005432335821	20986	Economy	12200.00
0005432335850	20986	Economy	12200.00
0005435176850	20986	Economy	12200.00
0005432335839	20986	Economy	12200.00
0005432359509	20986	Economy	12200.00
0005435176861	20986	Economy	13400.00
0005434149632	20986	Economy	13400.00
0005432359523	20986	Economy	13400.00
0005435176852	20986	Economy	13400.00
0005432359506	20986	Economy	13400.00
0005435176844	20986	Economy	13400.00
0005435176842	20986	Economy	12200.00
0005432359713	20986	Economy	12200.00
0005432359589	20986	Economy	12200.00
0005432363368	20986	Economy	12200.00
0005435176840	20986	Economy	12200.00
0005432363369	20986	Economy	12200.00
0005435176853	20986	Economy	12200.00
0005432363370	20986	Economy	12200.00
0005434149636	20986	Economy	12200.00
0005432335820	20986	Economy	12200.00
0005432359619	20986	Economy	12200.00
0005432359516	20986	Economy	12200.00
0005434149638	20986	Economy	12200.00
0005432359712	20986	Economy	12200.00
0005435176846	20986	Economy	12200.00
0005435176843	20986	Economy	12200.00
0005432359590	20986	Economy	12200.00
0005432335832	20986	Economy	12200.00
0005432359580	20986	Economy	12200.00
0005432335840	20986	Economy	12200.00
0005432359531	20986	Economy	12200.00
0005435176845	20986	Economy	12200.00
0005432359576	20986	Economy	12200.00
0005435176854	20986	Economy	12200.00
0005432052721	20986	Economy	12200.00
0005435176862	20986	Economy	12200.00
0005435176856	20986	Economy	12200.00
0005434149631	20986	Economy	12200.00
0005432052720	20986	Economy	12200.00
0005434149629	20986	Economy	12200.00
0005432359579	20986	Economy	12200.00
0005432335866	20986	Economy	12200.00
0005435490202	20986	Economy	12200.00
0005435490200	20986	Economy	12200.00
0005432359720	20986	Economy	12200.00
0005432359620	20986	Economy	12200.00
0005432335865	20986	Economy	12200.00
0005435176864	20986	Economy	12200.00
0005434149633	20986	Economy	12200.00
0005432359517	20986	Economy	12200.00
0005435176839	20986	Economy	12200.00
0005435723030	20986	Economy	12200.00
0005432359671	20986	Economy	12200.00
0005434149628	20986	Economy	12200.00
0005435176859	20986	Economy	12200.00
0005432359608	20986	Economy	12200.00
0005435176860	20986	Economy	12200.00
0005434149637	20986	Economy	12200.00
0005434186177	17703	Economy	3400.00
0005434458505	17703	Economy	3400.00
0005434458468	17703	Economy	3100.00
0005434458456	17703	Economy	3100.00
0005434458436	17703	Economy	3100.00
0005434458516	17703	Economy	3100.00
0005434458508	17703	Economy	3100.00
0005434458455	17703	Economy	3100.00
0005434458437	17703	Economy	3100.00
0005434461617	17703	Economy	3100.00
0005434458435	17703	Economy	3100.00
0005434458433	17703	Economy	3100.00
0005434458457	17703	Economy	3100.00
0005434458531	17703	Economy	3100.00
0005434458479	17703	Economy	3100.00
0005434458467	17703	Economy	3100.00
0005434458487	17703	Economy	3100.00
0005434461616	17703	Economy	3100.00
0005434448257	17703	Economy	3100.00
0005434186176	17703	Economy	3100.00
0005434458509	17703	Economy	3100.00
0005434458506	17703	Economy	3100.00
0005434186175	17703	Economy	3100.00
0005434458470	17703	Economy	3100.00
0005434458532	17703	Economy	3100.00
0005434458638	29093	Economy	3400.00
0005434458626	29093	Economy	3400.00
0005434458633	29093	Economy	3400.00
0005434463910	29093	Economy	3100.00
0005434458625	29093	Economy	3100.00
0005434458642	29093	Economy	3100.00
0005434463909	29093	Economy	3100.00
0005434458627	29093	Economy	3100.00
0005434458635	29093	Economy	3100.00
0005434186159	29093	Economy	3100.00
0005434458644	29093	Economy	3100.00
0005434458640	29093	Economy	3100.00
0005434458634	29093	Economy	3100.00
0005434186154	29093	Economy	3100.00
0005434458632	29093	Economy	3100.00
0005434458645	29093	Economy	3100.00
0005434448283	29093	Economy	3100.00
0005434186158	29093	Economy	3100.00
0005434458639	29093	Economy	3100.00
0005434458630	29093	Economy	3100.00
0005434448282	29093	Economy	3100.00
0005434458643	29093	Economy	3100.00
0005434458641	29093	Economy	3100.00
0005434458636	29093	Economy	3100.00
0005434186157	29093	Economy	3100.00
0005434448284	29093	Economy	3100.00
0005434458637	29093	Economy	3100.00
0005434458646	29093	Economy	3100.00
0005434462770	29093	Economy	3100.00
0005434458629	29093	Economy	3100.00
0005434458631	29093	Economy	3100.00
0005434458628	29093	Economy	3100.00
0005434462771	29093	Economy	3100.00
0005435218104	21461	Economy	7300.00
0005432603968	21461	Economy	7300.00
0005432603993	21461	Economy	7300.00
0005432603977	21461	Economy	7300.00
0005432603970	21461	Economy	6600.00
0005432603995	21461	Economy	6600.00
0005432603988	21461	Economy	6600.00
0005432603994	21461	Economy	6600.00
0005432603985	21461	Economy	6600.00
0005432603982	21461	Economy	6600.00
0005432603986	21461	Economy	6600.00
0005432603999	21461	Economy	6600.00
0005432604003	21461	Economy	6600.00
0005432603989	21461	Economy	6600.00
0005432603976	21461	Economy	6600.00
0005432603979	21461	Economy	6600.00
0005432603992	21461	Economy	6600.00
0005432603998	21461	Economy	6600.00
0005432603978	21461	Economy	6600.00
0005432604000	21461	Economy	6600.00
0005432603974	21461	Economy	6600.00
0005432603996	21461	Economy	6600.00
0005432604002	21461	Economy	6600.00
0005432603966	21461	Economy	6600.00
0005432603990	21461	Economy	6600.00
0005432603980	21461	Economy	6600.00
0005432603997	21461	Economy	6600.00
0005432603987	21461	Economy	6600.00
0005432603969	21461	Economy	6600.00
0005432603983	21461	Economy	6600.00
0005432603984	21461	Economy	6600.00
0005432603991	21461	Economy	6600.00
0005432603967	21461	Economy	6600.00
0005432603975	21461	Economy	6600.00
0005432604004	21461	Economy	6600.00
0005432603972	21461	Economy	6600.00
0005432604001	21461	Economy	6600.00
0005432603981	21461	Economy	6600.00
0005432603973	21461	Economy	6600.00
0005432604005	21461	Economy	6600.00
0005432603971	21461	Economy	6600.00
0005432603645	31657	Economy	7300.00
0005432603651	31657	Economy	7300.00
0005432603701	31657	Economy	6600.00
0005432603658	31657	Economy	6600.00
0005432603643	31657	Economy	6600.00
0005432603737	31657	Economy	6600.00
0005432603672	31657	Economy	6600.00
0005432603644	31657	Economy	6600.00
0005432603653	31657	Economy	6600.00
0005432603659	31657	Economy	6600.00
0005432603738	31657	Economy	6600.00
0005432603682	31657	Economy	6600.00
0005432603783	31657	Economy	6600.00
0005432603652	31657	Economy	6600.00
0005432603739	31657	Economy	6600.00
0005432603671	31657	Economy	6600.00
0005432603699	31657	Economy	6600.00
0005432603654	31657	Economy	6600.00
0005432603660	31657	Economy	6600.00
0005432603650	31657	Economy	6600.00
0005432603649	31657	Economy	6600.00
0005432603702	31657	Economy	6600.00
0005432603797	31657	Economy	6600.00
0005432603740	31657	Economy	6600.00
0005433293199	29607	Economy	17800.00
0005433293200	29607	Economy	17800.00
0005433293203	29607	Economy	17800.00
0005433293209	29607	Economy	17800.00
0005433293198	29607	Economy	17800.00
0005433293205	29607	Economy	17800.00
0005433293202	29607	Economy	17800.00
0005433293206	29607	Economy	17800.00
0005433293208	29607	Economy	17800.00
0005433293204	29607	Economy	17800.00
0005433293201	29607	Economy	17800.00
0005433293207	29607	Economy	17800.00
0005433473180	6687	Economy	14000.00
0005435257166	6687	Economy	14000.00
0005433473189	6687	Economy	12700.00
0005433473181	6687	Economy	12700.00
0005433473179	6687	Economy	12700.00
0005435257167	6687	Economy	12700.00
0005433473182	6687	Economy	12700.00
0005433473176	6687	Economy	12700.00
0005433473185	6687	Economy	12700.00
0005433473193	6687	Economy	12700.00
0005433473190	6687	Economy	12700.00
0005433473177	6687	Economy	12700.00
0005433473178	6687	Economy	12700.00
0005433473183	6687	Economy	12700.00
0005433473192	6687	Economy	12700.00
0005433473188	6687	Economy	12700.00
0005433473187	6687	Economy	12700.00
0005433473186	6687	Economy	12700.00
0005433473175	6687	Economy	12700.00
0005435257162	6687	Economy	12700.00
0005433473184	6687	Economy	12700.00
0005433473191	6687	Economy	12700.00
0005435257163	6687	Economy	12700.00
0005435257195	23901	Economy	14000.00
0005435257194	23901	Economy	14000.00
0005433473115	23901	Economy	14000.00
0005435257187	23901	Economy	14000.00
0005435257184	23901	Economy	12700.00
0005435257198	23901	Economy	12700.00
0005433473122	23901	Economy	12700.00
0005435257186	23901	Economy	12700.00
0005433473105	23901	Economy	12700.00
0005435257182	23901	Economy	12700.00
0005433473128	23901	Economy	12700.00
0005433473101	23901	Economy	12700.00
0005433473102	23901	Economy	12700.00
0005433473121	23901	Economy	12700.00
0005433473118	23901	Economy	12700.00
0005435257190	23901	Economy	12700.00
0005435257197	23901	Economy	12700.00
0005435257188	23901	Economy	12700.00
0005435257196	23901	Economy	12700.00
0005433473120	23901	Economy	12700.00
0005435257191	23901	Economy	12700.00
0005435257183	23901	Economy	12700.00
0005435257193	23901	Economy	12700.00
0005433473119	23901	Economy	12700.00
0005435257189	23901	Economy	12700.00
0005435257185	23901	Economy	12700.00
0005435257192	23901	Economy	12700.00
0005435904892	18900	Economy	6600.00
0005434606796	22332	Economy	6600.00
0005434606794	22332	Economy	6600.00
0005434606797	22332	Economy	6600.00
0005434606795	22332	Economy	6600.00
0005434604868	22332	Economy	6600.00
0005434604866	22332	Economy	6600.00
0005434604865	22332	Economy	6600.00
0005434604867	22332	Economy	6600.00
0005434522407	3860	Economy	24900.00
0005434522414	3860	Economy	22600.00
0005434522406	3860	Economy	22600.00
0005434602875	3860	Economy	22600.00
0005434602877	3860	Economy	22600.00
0005434522405	3860	Economy	22600.00
0005434522412	3860	Economy	22600.00
0005434522408	3860	Economy	22600.00
0005434522413	3860	Economy	22600.00
0005434522404	3860	Economy	22600.00
0005434602876	3860	Economy	22600.00
0005434602879	3860	Economy	22600.00
0005434522409	3860	Economy	22600.00
0005434522410	3860	Economy	22600.00
0005434602878	3860	Economy	22600.00
0005434522411	3860	Economy	22600.00
0005434522415	3860	Economy	22600.00
0005434522416	3860	Economy	22600.00
0005435904367	3860	Economy	22600.00
0005435904383	19047	Economy	24900.00
0005434602864	19047	Economy	22600.00
0005434604838	19047	Economy	22600.00
0005434604840	19047	Economy	22600.00
0005435904389	19047	Economy	22600.00
0005434602865	19047	Economy	22600.00
0005434604837	19047	Economy	22600.00
0005434522378	19047	Economy	22600.00
0005434522385	19047	Economy	22600.00
0005435904388	19047	Economy	22600.00
0005435904385	19047	Economy	22600.00
0005435904390	19047	Economy	22600.00
0005435904384	19047	Economy	22600.00
0005435904386	19047	Economy	22600.00
0005434522386	19047	Economy	22600.00
0005435904387	19047	Economy	22600.00
0005434522376	19047	Economy	22600.00
0005434604839	19047	Economy	22600.00
0005432747234	423	Business	44500.00
0005432747221	423	Business	44500.00
0005432890724	423	Business	44500.00
0005432747242	423	Business	44500.00
0005432747227	423	Business	44500.00
0005432890681	423	Business	44500.00
0005432747252	423	Business	44500.00
0005432747249	423	Business	44500.00
0005432747228	423	Business	44500.00
0005432749766	423	Economy	14800.00
0005432890703	423	Economy	14800.00
0005432753269	423	Economy	14800.00
0005432890758	423	Economy	14800.00
0005432890786	423	Economy	14800.00
0005432890715	423	Economy	14800.00
0005432749764	423	Economy	14800.00
0005432747254	423	Economy	14800.00
0005432890685	423	Economy	14800.00
0005432751495	423	Economy	16300.00
0005432747235	423	Economy	16300.00
0005432747256	423	Economy	14800.00
0005432753270	423	Economy	14800.00
0005432219966	423	Economy	14800.00
0005432747220	423	Economy	14800.00
0005432747241	423	Economy	14800.00
0005432747226	423	Economy	14800.00
0005432747237	423	Economy	14800.00
0005432747230	423	Economy	14800.00
0005432747246	423	Economy	14800.00
0005432747251	423	Economy	14800.00
0005432219968	423	Economy	14800.00
0005432747219	423	Economy	14800.00
0005432747244	423	Economy	14800.00
0005432890723	423	Economy	14800.00
0005432890733	423	Economy	14800.00
0005432747223	423	Economy	14800.00
0005432747233	423	Economy	14800.00
0005432747255	423	Economy	14800.00
0005432747225	423	Economy	14800.00
0005432747245	423	Economy	14800.00
0005432751496	423	Economy	14800.00
0005432751497	423	Economy	14800.00
0005432747229	423	Economy	14800.00
0005432890770	423	Economy	14800.00
0005432747240	423	Economy	14800.00
0005432747248	423	Economy	14800.00
0005432751494	423	Economy	14800.00
0005432890732	423	Economy	14800.00
0005432890757	423	Economy	14800.00
0005432219965	423	Economy	14800.00
0005432747258	423	Economy	14800.00
0005432747224	423	Economy	14800.00
0005432747257	423	Economy	14800.00
0005432747250	423	Economy	14800.00
0005432747243	423	Economy	14800.00
0005432890707	423	Economy	14800.00
0005432747238	423	Economy	14800.00
0005432749765	423	Economy	14800.00
0005432747222	423	Economy	14800.00
0005432753271	423	Economy	14800.00
0005432753272	423	Economy	14800.00
0005432747232	423	Economy	14800.00
0005432747231	423	Economy	14800.00
0005432747239	423	Economy	14800.00
0005432219967	423	Economy	14800.00
0005432747236	423	Economy	14800.00
0005435627113	423	Economy	14800.00
0005432747253	423	Economy	14800.00
0005432747247	423	Economy	14800.00
0005432746911	12083	Business	44500.00
0005432890869	12083	Business	44500.00
0005432890862	12083	Business	44500.00
0005432890860	12083	Business	44500.00
0005432890852	12083	Business	44500.00
0005432746980	12083	Business	44500.00
0005432747084	12083	Business	44500.00
0005432747082	12083	Business	44500.00
0005432746907	12083	Business	44500.00
0005432890857	12083	Economy	14800.00
0005432746991	12083	Economy	14800.00
0005432747129	12083	Economy	14800.00
0005432890864	12083	Economy	14800.00
0005432746921	12083	Economy	14800.00
0005432890856	12083	Economy	14800.00
0005432746872	12083	Economy	14800.00
0005432890851	12083	Economy	16300.00
0005432747116	12083	Economy	16300.00
0005432890859	12083	Economy	16300.00
0005432890858	12083	Economy	16300.00
0005432746999	12083	Economy	16300.00
0005432747046	12083	Economy	14800.00
0005434153526	12083	Economy	14800.00
0005432746897	12083	Economy	14800.00
0005432890853	12083	Economy	14800.00
0005432890866	12083	Economy	14800.00
0005432890849	12083	Economy	14800.00
0005432890850	12083	Economy	14800.00
0005432746898	12083	Economy	14800.00
0005432890868	12083	Economy	14800.00
0005432746900	12083	Economy	14800.00
0005432746922	12083	Economy	14800.00
0005432753258	12083	Economy	14800.00
0005432756795	12083	Economy	14800.00
0005432890855	12083	Economy	14800.00
0005432747117	12083	Economy	14800.00
0005432747038	12083	Economy	14800.00
0005432746893	12083	Economy	14800.00
0005432890867	12083	Economy	14800.00
0005432746903	12083	Economy	14800.00
0005432747056	12083	Economy	14800.00
0005432747039	12083	Economy	14800.00
0005432890863	12083	Economy	14800.00
0005434153525	12083	Economy	14800.00
0005432746979	12083	Economy	14800.00
0005432746905	12083	Economy	14800.00
0005432746959	12083	Economy	14800.00
0005432890861	12083	Economy	14800.00
0005432753245	12083	Economy	14800.00
0005432746912	12083	Economy	14800.00
0005432890865	12083	Economy	14800.00
0005432746924	12083	Economy	14800.00
0005432747130	12083	Economy	14800.00
0005432214786	12083	Economy	14800.00
0005432214785	12083	Economy	14800.00
0005432747088	12083	Economy	14800.00
0005432746906	12083	Economy	14800.00
0005432747089	12083	Economy	14800.00
0005432747055	12083	Economy	14800.00
0005432747083	12083	Economy	14800.00
0005432890854	12083	Economy	14800.00
0005433875366	12083	Economy	14800.00
0005432746873	12083	Economy	14800.00
0005432756794	12083	Economy	14800.00
0005432746960	12083	Economy	14800.00
0005432746882	12083	Economy	14800.00
0005433531258	18999	Economy	28200.00
0005433524937	18999	Economy	28200.00
0005433533274	18999	Economy	28200.00
0005433531259	18999	Economy	25700.00
0005433524941	18999	Economy	25700.00
0005433533272	18999	Economy	25700.00
0005433524936	18999	Economy	25700.00
0005433524944	18999	Economy	25700.00
0005433531257	18999	Economy	25700.00
0005433524942	18999	Economy	25700.00
0005433524945	18999	Economy	25700.00
0005433524939	18999	Economy	25700.00
0005433531260	18999	Economy	25700.00
0005433533275	18999	Economy	25700.00
0005433524943	18999	Economy	25700.00
0005433533273	18999	Economy	25700.00
0005433533271	18999	Economy	25700.00
0005433524940	18999	Economy	25700.00
0005433524938	18999	Economy	25700.00
0005433524902	32465	Economy	28200.00
0005433524896	32465	Economy	28200.00
0005432927936	32465	Economy	25700.00
0005433531248	32465	Economy	25700.00
0005433524881	32465	Economy	25700.00
0005433531240	32465	Economy	25700.00
0005433531235	32465	Economy	25700.00
0005432927939	32465	Economy	25700.00
0005433524853	32465	Economy	25700.00
0005432927940	32465	Economy	25700.00
0005433524874	32465	Economy	25700.00
0005433524886	32465	Economy	25700.00
0005433524870	32465	Economy	25700.00
0005433524885	32465	Economy	25700.00
0005433531247	32465	Economy	25700.00
0005433531236	32465	Economy	25700.00
0005433524875	32465	Economy	25700.00
0005432927938	32465	Economy	25700.00
0005432927941	32465	Economy	25700.00
0005433524860	32465	Economy	25700.00
0005433524861	32465	Economy	25700.00
0005432927937	32465	Economy	25700.00
0005433524901	32465	Economy	25700.00
0005435386478	5249	Business	84000.00
0005434558207	5249	Business	84000.00
0005432394070	5249	Business	84000.00
0005435372248	5249	Business	84000.00
0005434822553	5249	Business	84000.00
0005435372128	5249	Business	84000.00
0005434822545	5249	Business	84000.00
0005434822571	5249	Business	84000.00
0005434822522	5249	Business	84000.00
0005434664939	5249	Business	84000.00
0005435372174	5249	Business	84000.00
0005435372314	5249	Business	84000.00
0005432121219	5249	Business	84000.00
0005435149921	5249	Business	84000.00
0005434822599	5249	Business	84000.00
0005435149925	5249	Business	84000.00
0005434822527	5249	Business	84000.00
0005434822606	5249	Business	84000.00
0005435304099	5249	Comfort	47600.00
0005434822481	5249	Comfort	47600.00
0005434822488	5249	Comfort	47600.00
0005434822568	5249	Comfort	47600.00
0005432121213	5249	Comfort	47600.00
0005434822559	5249	Comfort	47600.00
0005435304092	5249	Comfort	47600.00
0005434822580	5249	Comfort	47600.00
0005434558208	5249	Comfort	47600.00
0005434822607	5249	Comfort	47600.00
0005434822560	5249	Comfort	47600.00
0005434822587	5249	Comfort	47600.00
0005434822511	5249	Comfort	47600.00
0005434822500	5249	Comfort	47600.00
0005435299706	5249	Comfort	47600.00
0005434822582	5249	Comfort	47600.00
0005435372218	5249	Comfort	47600.00
0005434822498	5249	Comfort	47600.00
0005435372294	5249	Comfort	47600.00
0005434822480	5249	Comfort	47600.00
0005435661888	5249	Comfort	47600.00
0005434822557	5249	Comfort	47600.00
0005435299700	5249	Comfort	47600.00
0005434822552	5249	Comfort	47600.00
0005434822512	5249	Comfort	47600.00
0005434822584	5249	Comfort	47600.00
0005435661889	5249	Comfort	47600.00
0005435735057	5249	Economy	28000.00
0005432394072	5249	Economy	28000.00
0005435149915	5249	Economy	28000.00
0005434822499	5249	Economy	28000.00
0005434822490	5249	Economy	28000.00
0005435372164	5249	Economy	28000.00
0005435372315	5249	Economy	28000.00
0005434822536	5249	Economy	28000.00
0005434822593	5249	Economy	28000.00
0005434822547	5249	Economy	28000.00
0005434822528	5249	Economy	28000.00
0005434822492	5249	Economy	28000.00
0005434822523	5249	Economy	28000.00
0005434831107	5249	Economy	28000.00
0005434822595	5249	Economy	28000.00
0005432121215	5249	Economy	28000.00
0005434828672	5249	Economy	28000.00
0005434822491	5249	Economy	28000.00
0005434822533	5249	Economy	28000.00
0005435372194	5249	Economy	28000.00
0005435372163	5249	Economy	28000.00
0005434822573	5249	Economy	28000.00
0005434822600	5249	Economy	28000.00
0005435149916	5249	Economy	28000.00
0005434822529	5249	Economy	28000.00
0005434822555	5249	Economy	28000.00
0005434822503	5249	Economy	28000.00
0005434822525	5249	Economy	28000.00
0005435372313	5249	Economy	28000.00
0005432121216	5249	Economy	28000.00
0005435372342	5249	Economy	28000.00
0005434822484	5249	Economy	28000.00
0005434822514	5249	Economy	28000.00
0005434558210	5249	Economy	28000.00
0005434822589	5249	Economy	28000.00
0005434822585	5249	Economy	28000.00
0005434822608	5249	Economy	28000.00
0005434822513	5249	Economy	28000.00
0005435372491	5249	Economy	28000.00
0005432121224	5249	Economy	30800.00
0005435372303	5249	Economy	28000.00
0005434822581	5249	Economy	30800.00
0005434822530	5249	Economy	28000.00
0005435149926	5249	Economy	28000.00
0005434822574	5249	Economy	28000.00
0005435372200	5249	Economy	30800.00
0005434558209	5249	Economy	30800.00
0005434822520	5249	Economy	30800.00
0005434822577	5249	Economy	28000.00
0005434822493	5249	Economy	28000.00
0005434822497	5249	Economy	28000.00
0005434822602	5249	Economy	28000.00
0005435372192	5249	Economy	28000.00
0005435372319	5249	Economy	28000.00
0005435372284	5249	Economy	28000.00
0005434822505	5249	Economy	28000.00
0005434828671	5249	Economy	28000.00
0005434822605	5249	Economy	28000.00
0005434822532	5249	Economy	28000.00
0005432121220	5249	Economy	28000.00
0005434822575	5249	Economy	28000.00
0005435149923	5249	Economy	28000.00
0005434822546	5249	Economy	28000.00
0005435372382	5249	Economy	28000.00
0005432121214	5249	Economy	28000.00
0005434822544	5249	Economy	28000.00
0005435735065	5249	Economy	28000.00
0005434822537	5249	Economy	28000.00
0005434822566	5249	Economy	28000.00
0005434822506	5249	Economy	28000.00
0005434822569	5249	Economy	28000.00
0005435372234	5249	Economy	28000.00
0005434558206	5249	Economy	28000.00
0005434822563	5249	Economy	28000.00
0005434822508	5249	Economy	28000.00
0005434822561	5249	Economy	28000.00
0005434831106	5249	Economy	28000.00
0005434822539	5249	Economy	28000.00
0005435149918	5249	Economy	28000.00
0005434822485	5249	Economy	28000.00
0005434822502	5249	Economy	28000.00
0005435304100	5249	Economy	28000.00
0005435372175	5249	Economy	28000.00
0005434822483	5249	Economy	28000.00
0005435149922	5249	Economy	28000.00
0005432396209	5249	Economy	28000.00
0005432121221	5249	Economy	28000.00
0005434822548	5249	Economy	28000.00
0005434822596	5249	Economy	28000.00
0005435661887	5249	Economy	28000.00
0005435372241	5249	Economy	28000.00
0005434831109	5249	Economy	28000.00
0005435372172	5249	Economy	28000.00
0005432121222	5249	Economy	28000.00
0005434822554	5249	Economy	28000.00
0005435372461	5249	Economy	28000.00
0005435372199	5249	Economy	28000.00
0005434822487	5249	Economy	28000.00
0005435149914	5249	Economy	28000.00
0005434822564	5249	Economy	28000.00
0005432121212	5249	Economy	28000.00
0005435372292	5249	Economy	28000.00
0005435386468	5249	Economy	28000.00
0005435372211	5249	Economy	28000.00
0005435372170	5249	Economy	28000.00
0005432121225	5249	Economy	28000.00
0005435179687	5249	Economy	28000.00
0005434822576	5249	Economy	28000.00
0005435179686	5249	Economy	28000.00
0005434822516	5249	Economy	28000.00
0005434822482	5249	Economy	28000.00
0005434822598	5249	Economy	28000.00
0005435372140	5249	Economy	28000.00
0005435372418	5249	Economy	28000.00
0005434822583	5249	Economy	28000.00
0005434822604	5249	Economy	28000.00
0005434822590	5249	Economy	28000.00
0005435372109	5249	Economy	28000.00
0005434822486	5249	Economy	28000.00
0005435304107	5249	Economy	28000.00
0005434558205	5249	Economy	28000.00
0005434822489	5249	Economy	28000.00
0005434822509	5249	Economy	28000.00
0005434822562	5249	Economy	28000.00
0005434822494	5249	Economy	28000.00
0005434822526	5249	Economy	28000.00
0005435372272	5249	Economy	28000.00
0005434822496	5249	Economy	30800.00
0005434822601	5249	Economy	30800.00
0005434822534	5249	Economy	30800.00
0005434822565	5249	Economy	28000.00
0005432121217	5249	Economy	28000.00
0005435372108	5249	Economy	28000.00
0005434822521	5249	Economy	28000.00
0005434822541	5249	Economy	28000.00
0005435372181	5249	Economy	28000.00
0005435149919	5249	Economy	28000.00
0005434822524	5249	Economy	28000.00
0005432121223	5249	Economy	28000.00
0005434822519	5249	Economy	28000.00
0005435149920	5249	Economy	28000.00
0005434822603	5249	Economy	28000.00
0005434822588	5249	Economy	28000.00
0005435149924	5249	Economy	28000.00
0005434822551	5249	Economy	28000.00
0005434822510	5249	Economy	28000.00
0005434822556	5249	Economy	28000.00
0005432394071	5249	Economy	28000.00
0005434822540	5249	Economy	28000.00
0005435299701	5249	Economy	28000.00
0005434822558	5249	Economy	28000.00
0005434822579	5249	Economy	28000.00
0005435372198	5249	Economy	28000.00
0005434822592	5249	Economy	28000.00
0005434828673	5249	Economy	28000.00
0005434822501	5249	Economy	28000.00
0005434822570	5249	Economy	28000.00
0005434831108	5249	Economy	28000.00
0005432396208	5249	Economy	28000.00
0005434822542	5249	Economy	28000.00
0005434822549	5249	Economy	28000.00
0005435735056	5249	Economy	28000.00
0005434822507	5249	Economy	28000.00
0005435372334	5249	Economy	28000.00
0005435372193	5249	Economy	28000.00
0005434822495	5249	Economy	28000.00
0005434822518	5249	Economy	28000.00
0005432121218	5249	Economy	28000.00
0005432396211	5249	Economy	28000.00
0005434822567	5249	Economy	28000.00
0005434822550	5249	Economy	28000.00
0005435372217	5249	Economy	28000.00
0005434822531	5249	Economy	28000.00
0005434822535	5249	Economy	28000.00
0005432396210	5249	Economy	28000.00
0005434822538	5249	Economy	28000.00
0005435372171	5249	Economy	28000.00
0005434828670	5249	Economy	28000.00
0005434822572	5249	Economy	28000.00
0005435372189	5249	Economy	28000.00
0005435372191	5249	Economy	28000.00
0005434822597	5249	Economy	28000.00
0005432394069	5249	Economy	28000.00
0005434822586	5249	Economy	28000.00
0005434822517	5249	Economy	28000.00
0005435372271	5249	Economy	28000.00
0005435372235	5249	Economy	28000.00
0005435149917	5249	Economy	28000.00
0005435372462	5249	Economy	28000.00
0005435372268	5249	Economy	28000.00
0005435372374	5249	Economy	28000.00
0005434822515	5249	Economy	28000.00
0005435661886	5249	Economy	28000.00
0005435372343	5249	Economy	28000.00
0005435372293	5249	Economy	28000.00
0005434822594	5249	Economy	28000.00
0005435372320	5249	Economy	28000.00
0005435372417	5249	Economy	28000.00
0005435304097	5249	Economy	28000.00
0005434822591	5249	Economy	28000.00
0005434822578	5249	Economy	28000.00
0005435372212	5249	Economy	28000.00
0005434822543	5249	Economy	28000.00
0005434822504	5249	Economy	28000.00
0005435372697	9893	Business	84000.00
0005434821644	9893	Business	84000.00
0005432396176	9893	Business	84000.00
0005435661907	9893	Business	84000.00
0005435372739	9893	Business	84000.00
0005435372727	9893	Business	84000.00
0005435372744	9893	Business	84000.00
0005435372725	9893	Business	84000.00
0005435372759	9893	Business	84000.00
0005434821401	9893	Business	84000.00
0005434822052	9893	Business	84000.00
0005435372751	9893	Business	84000.00
0005434821916	9893	Business	84000.00
0005434822047	9893	Business	84000.00
0005435372711	9893	Comfort	47600.00
0005435372719	9893	Business	84000.00
0005434822006	9893	Comfort	47600.00
0005435735100	9893	Comfort	47600.00
0005435302160	9893	Comfort	47600.00
0005434821753	9893	Comfort	47600.00
0005432203005	9893	Comfort	47600.00
0005434821444	9893	Comfort	47600.00
0005435661906	9893	Comfort	47600.00
0005435372736	9893	Comfort	47600.00
0005434831067	9893	Comfort	47600.00
0005434822010	9893	Comfort	47600.00
0005434821478	9893	Comfort	47600.00
0005434821622	9893	Comfort	47600.00
0005435149840	9893	Comfort	47600.00
0005434821600	9893	Comfort	47600.00
0005435149802	9893	Comfort	47600.00
0005435372732	9893	Comfort	47600.00
0005435372729	9893	Comfort	47600.00
0005432396184	9893	Comfort	47600.00
0005435386520	9893	Comfort	47600.00
0005435372756	9893	Comfort	47600.00
0005435372714	9893	Comfort	47600.00
0005432203006	9893	Comfort	47600.00
0005435149839	9893	Comfort	47600.00
0005435299736	9893	Comfort	47600.00
0005435299735	9893	Comfort	47600.00
0005435372748	9893	Comfort	47600.00
0005435372738	9893	Comfort	47600.00
0005434821413	9893	Comfort	47600.00
0005434821535	9893	Economy	28000.00
0005434821470	9893	Economy	28000.00
0005434821776	9893	Economy	28000.00
0005434821445	9893	Economy	28000.00
0005435302159	9893	Economy	28000.00
0005435372743	9893	Economy	28000.00
0005435386524	9893	Economy	28000.00
0005435372757	9893	Economy	28000.00
0005434821813	9893	Economy	28000.00
0005435372752	9893	Economy	28000.00
0005435386521	9893	Economy	28000.00
0005434821503	9893	Economy	28000.00
0005434821533	9893	Economy	28000.00
0005434821580	9893	Economy	28000.00
0005435735104	9893	Economy	28000.00
0005435372694	9893	Economy	28000.00
0005434821529	9893	Economy	28000.00
0005434821797	9893	Economy	28000.00
0005435372741	9893	Economy	28000.00
0005434821798	9893	Economy	28000.00
0005435372749	9893	Economy	28000.00
0005435372731	9893	Economy	28000.00
0005434831068	9893	Economy	28000.00
0005434821604	9893	Economy	28000.00
0005434821775	9893	Economy	28000.00
0005435372712	9893	Economy	28000.00
0005434821589	9893	Economy	28000.00
0005434821339	9893	Economy	28000.00
0005435386519	9893	Economy	28000.00
0005434821706	9893	Economy	28000.00
0005435302162	9893	Economy	28000.00
0005434821313	9893	Economy	28000.00
0005434821661	9893	Economy	28000.00
0005435372742	9893	Economy	28000.00
0005435149824	9893	Economy	28000.00
0005434821534	9893	Economy	28000.00
0005435372737	9893	Economy	28000.00
0005435149810	9893	Economy	28000.00
0005435372755	9893	Economy	28000.00
0005435372723	9893	Economy	28000.00
0005432203003	9893	Economy	28000.00
0005434821325	9893	Economy	28000.00
0005434821645	9893	Economy	30800.00
0005434821567	9893	Economy	28000.00
0005434821748	9893	Economy	30800.00
0005435372745	9893	Economy	28000.00
0005434821471	9893	Economy	28000.00
0005432396174	9893	Economy	28000.00
0005432203001	9893	Economy	28000.00
0005434821320	9893	Economy	28000.00
0005434821795	9893	Economy	28000.00
0005434822056	9893	Economy	28000.00
0005435372702	9893	Economy	28000.00
0005435372747	9893	Economy	28000.00
0005435299738	9893	Economy	28000.00
0005434821757	9893	Economy	28000.00
0005434821626	9893	Economy	28000.00
0005434821761	9893	Economy	28000.00
0005434821648	9893	Economy	28000.00
0005435372730	9893	Economy	28000.00
0005434821699	9893	Economy	28000.00
0005434664921	9893	Economy	28000.00
0005435372750	9893	Economy	28000.00
0005435386522	9893	Economy	28000.00
0005434821479	9893	Economy	28000.00
0005434822057	9893	Economy	28000.00
0005435386523	9893	Economy	28000.00
0005434821569	9893	Economy	28000.00
0005435372700	9893	Economy	28000.00
0005434821927	9893	Economy	28000.00
0005435372707	9893	Economy	28000.00
0005434821452	9893	Economy	28000.00
0005434821880	9893	Economy	28000.00
0005434821793	9893	Economy	28000.00
0005434821443	9893	Economy	28000.00
0005435149851	9893	Economy	28000.00
0005434821352	9893	Economy	28000.00
0005435372713	9893	Economy	28000.00
0005434821495	9893	Economy	28000.00
0005435372718	9893	Economy	28000.00
0005435372734	9893	Economy	28000.00
0005435372708	9893	Economy	28000.00
0005432203007	9893	Economy	28000.00
0005435302161	9893	Economy	28000.00
0005434822009	9893	Economy	28000.00
0005434822048	9893	Economy	28000.00
0005434821578	9893	Economy	28000.00
0005434821360	9893	Economy	28000.00
0005434821472	9893	Economy	28000.00
0005434821387	9893	Economy	28000.00
0005432823433	9893	Economy	28000.00
0005434821877	9893	Economy	28000.00
0005435372728	9893	Economy	28000.00
0005432823434	9893	Economy	28000.00
0005434821794	9893	Economy	28000.00
0005434821631	9893	Economy	28000.00
0005435372753	9893	Economy	28000.00
0005435302163	9893	Economy	28000.00
0005435372704	9893	Economy	28000.00
0005435372758	9893	Economy	28000.00
0005435149823	9893	Economy	28000.00
0005435372706	9893	Economy	28000.00
0005434821577	9893	Economy	28000.00
0005435386518	9893	Economy	28000.00
0005432400071	9893	Economy	28000.00
0005434831073	9893	Economy	28000.00
0005434821531	9893	Economy	28000.00
0005435372721	9893	Economy	28000.00
0005434821568	9893	Economy	28000.00
0005434821438	9893	Economy	28000.00
0005435372733	9893	Economy	28000.00
0005434821692	9893	Economy	30800.00
0005435372699	9893	Economy	30800.00
0005434821850	9893	Economy	30800.00
0005432400070	9893	Economy	30800.00
0005432203002	9893	Economy	28000.00
0005434821684	9893	Economy	28000.00
0005434821663	9893	Economy	28000.00
0005434821321	9893	Economy	28000.00
0005435372698	9893	Economy	28000.00
0005434831078	9893	Economy	28000.00
0005434821530	9893	Economy	28000.00
0005435372703	9893	Economy	28000.00
0005434821527	9893	Economy	28000.00
0005432396175	9893	Economy	28000.00
0005435299737	9893	Economy	28000.00
0005432203004	9893	Economy	28000.00
0005434821361	9893	Economy	28000.00
0005435372710	9893	Economy	28000.00
0005435299734	9893	Economy	28000.00
0005435372740	9893	Economy	28000.00
0005435149852	9893	Economy	28000.00
0005435661909	9893	Economy	28000.00
0005434821700	9893	Economy	28000.00
0005435372705	9893	Economy	28000.00
0005434821404	9893	Economy	28000.00
0005434821881	9893	Economy	28000.00
0005434821603	9893	Economy	28000.00
0005435661908	9893	Economy	28000.00
0005435372724	9893	Economy	28000.00
0005434821664	9893	Economy	28000.00
0005434821400	9893	Economy	28000.00
0005434822055	9893	Economy	28000.00
0005435735103	9893	Economy	28000.00
0005434821693	9893	Economy	28000.00
0005435372709	9893	Economy	28000.00
0005435372701	9893	Economy	28000.00
0005435149809	9893	Economy	28000.00
0005435372720	9893	Economy	28000.00
0005435302158	9893	Economy	28000.00
0005434821473	9893	Economy	28000.00
0005434821570	9893	Economy	28000.00
0005435372735	9893	Economy	28000.00
0005432203000	9893	Economy	28000.00
0005435372746	9893	Economy	28000.00
0005435372715	9893	Economy	28000.00
0005435735102	9893	Economy	28000.00
0005434821662	9893	Economy	28000.00
0005435149801	9893	Economy	28000.00
0005435372726	9893	Economy	28000.00
0005435372722	9893	Economy	28000.00
0005434821341	9893	Economy	28000.00
0005434821591	9893	Economy	28000.00
0005434821715	9893	Economy	28000.00
0005435372696	9893	Economy	28000.00
0005432203008	9893	Economy	28000.00
0005435372716	9893	Economy	28000.00
0005435372754	9893	Economy	28000.00
0005434821461	9893	Economy	28000.00
0005434821359	9893	Economy	28000.00
0005434821617	9893	Economy	28000.00
0005434821903	9893	Economy	28000.00
0005434821508	9893	Economy	28000.00
0005434821557	9893	Economy	28000.00
0005434821923	9893	Economy	28000.00
0005434821904	9893	Economy	28000.00
0005435735101	9893	Economy	28000.00
0005435372695	9893	Economy	28000.00
0005432400064	9893	Economy	28000.00
0005434821544	9893	Economy	28000.00
0005434821749	9893	Economy	28000.00
0005435372717	9893	Economy	28000.00
0005435082726	7001	Economy	8200.00
0005435082719	7001	Economy	7400.00
0005435082727	7001	Economy	7400.00
0005435790282	7001	Economy	7400.00
0005435082721	7001	Economy	7400.00
0005435082717	7001	Economy	7400.00
0005435082718	7001	Economy	7400.00
0005435082720	7001	Economy	7400.00
0005435790281	7001	Economy	7400.00
0005435082723	7001	Economy	7400.00
0005435082722	7001	Economy	7400.00
0005435082725	7001	Economy	7400.00
0005435790283	7001	Economy	7400.00
0005435082724	7001	Economy	7400.00
0005435082680	25986	Economy	7400.00
0005435082667	25986	Economy	7400.00
0005435082647	25986	Economy	7400.00
0005435082661	25986	Economy	7400.00
0005435082644	25986	Economy	7400.00
0005435790269	25986	Economy	7400.00
0005435790268	25986	Economy	7400.00
0005435082660	25986	Economy	7400.00
0005435082646	25986	Economy	7400.00
0005435082645	25986	Economy	7400.00
0005434756099	9531	Business	32800.00
0005434756112	9531	Business	32800.00
0005434213841	9531	Business	32800.00
0005434213792	9531	Business	32800.00
0005434213757	9531	Business	32800.00
0005434213745	9531	Economy	10900.00
0005434213731	9531	Economy	10900.00
0005434756113	9531	Economy	10900.00
0005434756114	9531	Economy	10900.00
0005434756102	9531	Economy	10900.00
0005434756091	9531	Economy	10900.00
0005434213738	9531	Economy	12000.00
0005434213699	9531	Economy	12000.00
0005434756116	9531	Economy	12000.00
0005434213854	9531	Economy	12000.00
0005434213707	9531	Economy	12000.00
0005434213767	9531	Economy	10900.00
0005434213815	9531	Economy	10900.00
0005434756097	9531	Economy	10900.00
0005434213814	9531	Economy	10900.00
0005434213700	9531	Economy	10900.00
0005434213717	9531	Economy	10900.00
0005434213813	9531	Economy	10900.00
0005434213793	9531	Economy	10900.00
0005434756098	9531	Economy	10900.00
0005434756103	9531	Economy	10900.00
0005434756096	9531	Economy	10900.00
0005434213752	9531	Economy	10900.00
0005434756090	9531	Economy	10900.00
0005434756100	9531	Economy	10900.00
0005434756092	9531	Economy	10900.00
0005434213783	9531	Economy	10900.00
0005434756095	9531	Economy	10900.00
0005434756094	9531	Economy	10900.00
0005434213698	9531	Economy	10900.00
0005434756106	9531	Economy	10900.00
0005434213829	9531	Economy	10900.00
0005434756111	9531	Economy	10900.00
0005434213718	9531	Economy	10900.00
0005434213756	9531	Economy	10900.00
0005434756105	9531	Economy	10900.00
0005434213863	9531	Economy	10900.00
0005434756101	9531	Economy	10900.00
0005434213766	9531	Economy	10900.00
0005434756104	9531	Economy	10900.00
0005434756108	9531	Economy	10900.00
0005434756117	9531	Economy	10900.00
0005434756118	9531	Economy	10900.00
0005434756110	9531	Economy	10900.00
0005434756115	9531	Economy	10900.00
0005434756093	9531	Economy	10900.00
0005434756109	9531	Economy	10900.00
0005434213786	9531	Economy	10900.00
0005434756107	9531	Economy	10900.00
0005434213755	9531	Economy	10900.00
0005434213754	9531	Economy	10900.00
0005434214118	28610	Business	32800.00
0005434214091	28610	Business	32800.00
0005434214103	28610	Business	32800.00
0005434214081	28610	Business	32800.00
0005434214080	28610	Business	32800.00
0005434214115	28610	Economy	10900.00
0005434214086	28610	Economy	10900.00
0005434214125	28610	Economy	10900.00
0005434214110	28610	Economy	10900.00
0005434214113	28610	Economy	10900.00
0005434214096	28610	Economy	10900.00
0005434214098	28610	Economy	10900.00
0005434755725	28610	Economy	10900.00
0005434214102	28610	Economy	12000.00
0005434214087	28610	Economy	12000.00
0005434214088	28610	Economy	12000.00
0005434214079	28610	Economy	10900.00
0005434214119	28610	Economy	10900.00
0005434214117	28610	Economy	10900.00
0005434214124	28610	Economy	10900.00
0005434214100	28610	Economy	10900.00
0005434214092	28610	Economy	10900.00
0005434214084	28610	Economy	10900.00
0005434755792	28610	Economy	10900.00
0005434214107	28610	Economy	10900.00
0005434214122	28610	Economy	10900.00
0005434214126	28610	Economy	10900.00
0005434214104	28610	Economy	10900.00
0005434214108	28610	Economy	10900.00
0005434214085	28610	Economy	10900.00
0005434214093	28610	Economy	10900.00
0005434214090	28610	Economy	10900.00
0005434214121	28610	Economy	10900.00
0005434214123	28610	Economy	10900.00
0005434755717	28610	Economy	10900.00
0005434214105	28610	Economy	10900.00
0005434755787	28610	Economy	10900.00
0005434214082	28610	Economy	10900.00
0005434214101	28610	Economy	10900.00
0005434214120	28610	Economy	10900.00
0005434214112	28610	Economy	10900.00
0005434214097	28610	Economy	10900.00
0005434755740	28610	Economy	10900.00
0005434755758	28610	Economy	10900.00
0005434214116	28610	Economy	10900.00
0005434214083	28610	Economy	10900.00
0005434214089	28610	Economy	10900.00
0005434214114	28610	Economy	10900.00
0005434755741	28610	Economy	10900.00
0005434214094	28610	Economy	10900.00
0005434214099	28610	Economy	10900.00
0005434214106	28610	Economy	10900.00
0005434214111	28610	Economy	10900.00
0005434214109	28610	Economy	10900.00
0005434214095	28610	Economy	10900.00
0005435100097	10833	Economy	9800.00
0005435100099	10833	Economy	8900.00
0005435100098	10833	Economy	8900.00
0005434760157	10833	Economy	8900.00
0005434760168	10833	Economy	8900.00
0005435100084	31791	Economy	8900.00
0005435100071	31791	Economy	8900.00
0005434760179	31791	Economy	8900.00
0005435100083	31791	Economy	8900.00
0005435100077	31791	Economy	8900.00
0005434760178	31791	Economy	8900.00
0005434760176	31791	Economy	8900.00
0005434760177	31791	Economy	8900.00
0005434639111	2003	Economy	20900.00
0005434639101	2003	Economy	20900.00
0005434639114	2003	Economy	20900.00
0005434639110	2003	Economy	20900.00
0005433202126	2003	Economy	19000.00
0005434639108	2003	Economy	19000.00
0005434639125	2003	Economy	19000.00
0005433202129	2003	Economy	19000.00
0005434639113	2003	Economy	19000.00
0005433202125	2003	Economy	19000.00
0005434639115	2003	Economy	19000.00
0005433202115	2003	Economy	19000.00
0005434639121	2003	Economy	19000.00
0005434639122	2003	Economy	19000.00
0005434639117	2003	Economy	19000.00
0005434639119	2003	Economy	19000.00
0005434639103	2003	Economy	19000.00
0005434639118	2003	Economy	19000.00
0005432290608	2003	Economy	19000.00
0005434639112	2003	Economy	19000.00
0005433202107	2003	Economy	19000.00
0005433202106	2003	Economy	19000.00
0005434639105	2003	Economy	19000.00
0005433202172	2003	Economy	19000.00
0005434639124	2003	Economy	19000.00
0005433202120	2003	Economy	19000.00
0005434639102	2003	Economy	19000.00
0005432290607	2003	Economy	19000.00
0005434639104	2003	Economy	19000.00
0005434639100	2003	Economy	19000.00
0005434639120	2003	Economy	19000.00
0005434639116	2003	Economy	19000.00
0005434639123	2003	Economy	19000.00
0005434639099	2003	Economy	19000.00
0005432290609	2003	Economy	19000.00
0005434639106	2003	Economy	19000.00
0005433202121	2003	Economy	19000.00
0005434639109	2003	Economy	19000.00
0005433202146	2003	Economy	19000.00
0005434639107	2003	Economy	19000.00
0005434638903	23280	Economy	20900.00
0005433202229	23280	Economy	20900.00
0005434638917	23280	Economy	20900.00
0005434638991	23280	Economy	20900.00
0005433202235	23280	Economy	19000.00
0005434638893	23280	Economy	19000.00
0005433202231	23280	Economy	19000.00
0005434638850	23280	Economy	19000.00
0005434638916	23280	Economy	19000.00
0005434638864	23280	Economy	19000.00
0005433202223	23280	Economy	19000.00
0005433202224	23280	Economy	19000.00
0005434638879	23280	Economy	19000.00
0005434638900	23280	Economy	19000.00
0005433202226	23280	Economy	19000.00
0005434638899	23280	Economy	19000.00
0005434638894	23280	Economy	19000.00
0005433202230	23280	Economy	19000.00
0005434638887	23280	Economy	19000.00
0005434638924	23280	Economy	19000.00
0005433202228	23280	Economy	19000.00
0005434638992	23280	Economy	19000.00
0005434638886	23280	Economy	19000.00
0005433202236	23280	Economy	19000.00
0005433202225	23280	Economy	19000.00
0005433202233	23280	Economy	19000.00
0005433202237	23280	Economy	19000.00
0005433202232	23280	Economy	19000.00
0005433202227	23280	Economy	19000.00
0005434638885	23280	Economy	19000.00
0005434638854	23280	Economy	19000.00
0005433202238	23280	Economy	19000.00
0005434638904	23280	Economy	19000.00
0005433202234	23280	Economy	19000.00
0005434600577	6068	Business	69700.00
0005432111255	6068	Business	69700.00
0005435326527	6068	Business	69700.00
0005434600597	6068	Business	69700.00
0005433533276	6068	Economy	23200.00
0005435326498	6068	Economy	23200.00
0005432111256	6068	Economy	23200.00
0005434600598	6068	Economy	23200.00
0005434600601	6068	Economy	23200.00
0005433531264	6068	Economy	23200.00
0005435326510	6068	Economy	23200.00
0005434600602	6068	Economy	25600.00
0005433533277	6068	Economy	25600.00
0005434600578	6068	Economy	23200.00
0005433531262	6068	Economy	23200.00
0005433533278	6068	Economy	23200.00
0005434600585	6068	Economy	23200.00
0005434600599	6068	Economy	23200.00
0005434600587	6068	Economy	23200.00
0005434600590	6068	Economy	23200.00
0005433531261	6068	Economy	23200.00
0005434600584	6068	Economy	23200.00
0005433531263	6068	Economy	23200.00
0005434600583	6068	Economy	23200.00
0005434600596	6068	Economy	23200.00
0005434600600	6068	Economy	23200.00
0005434600592	6068	Economy	23200.00
0005432111254	6068	Economy	23200.00
0005434600582	6068	Economy	23200.00
0005434600595	6068	Economy	23200.00
0005434600576	6068	Economy	23200.00
0005434600586	6068	Economy	23200.00
0005434600579	6068	Economy	23200.00
0005434600594	6068	Economy	23200.00
0005435326524	6068	Economy	23200.00
0005434600593	6068	Economy	23200.00
0005434600575	6068	Economy	23200.00
0005434600591	6068	Economy	23200.00
0005435326511	6068	Economy	23200.00
0005434600589	6068	Economy	23200.00
0005434600581	6068	Economy	23200.00
0005434600588	6068	Economy	23200.00
0005435326523	6068	Economy	23200.00
0005434600580	6068	Economy	23200.00
0005434600358	18614	Business	69700.00
0005434600443	18614	Business	69700.00
0005434600391	18614	Business	69700.00
0005435326632	18614	Business	69700.00
0005434600446	18614	Business	69700.00
0005434600441	18614	Business	69700.00
0005434600380	18614	Business	69700.00
0005435326633	18614	Economy	23200.00
0005434600345	18614	Economy	23200.00
0005434600383	18614	Economy	23200.00
0005435326626	18614	Economy	23200.00
0005435326628	18614	Economy	23200.00
0005435326630	18614	Economy	25600.00
0005433527204	18614	Economy	23200.00
0005435326627	18614	Economy	23200.00
0005434600355	18614	Economy	23200.00
0005434600390	18614	Economy	23200.00
0005434600371	18614	Economy	23200.00
0005435326635	18614	Economy	23200.00
0005434600374	18614	Economy	23200.00
0005434600347	18614	Economy	23200.00
0005435326629	18614	Economy	23200.00
0005434600440	18614	Economy	23200.00
0005434600350	18614	Economy	23200.00
0005435326636	18614	Economy	23200.00
0005434600414	18614	Economy	23200.00
0005435326638	18614	Economy	23200.00
0005435326639	18614	Economy	23200.00
0005434600435	18614	Economy	23200.00
0005434600471	18614	Economy	23200.00
0005435326625	18614	Economy	23200.00
0005434600359	18614	Economy	23200.00
0005434600498	18614	Economy	23200.00
0005435326637	18614	Economy	23200.00
0005434600341	18614	Economy	23200.00
0005434600340	18614	Economy	23200.00
0005434600382	18614	Economy	23200.00
0005435326631	18614	Economy	23200.00
0005434600434	18614	Economy	23200.00
0005434600402	18614	Economy	23200.00
0005434600346	18614	Economy	23200.00
0005434600397	18614	Economy	23200.00
0005434600360	18614	Economy	23200.00
0005435326634	18614	Economy	23200.00
0005434600442	18614	Economy	23200.00
0005434550718	10655	Business	9100.00
0005434550747	10655	Business	9100.00
0005434550732	10655	Business	9100.00
0005434550740	10655	Business	9100.00
0005434550733	10655	Business	9100.00
0005434550727	10655	Business	9100.00
0005434550712	10655	Business	9100.00
0005433180729	10655	Business	9100.00
0005434550746	10655	Business	9100.00
0005434558202	10655	Business	9100.00
0005434550762	10655	Business	9100.00
0005434550719	10655	Economy	3000.00
0005434550739	10655	Economy	3000.00
0005433180668	10655	Economy	3000.00
0005434558203	10655	Economy	3000.00
0005434550744	10655	Economy	3000.00
0005434550755	10655	Economy	3000.00
0005434550726	10655	Economy	3000.00
0005433180734	10655	Economy	3300.00
0005434550715	10655	Economy	3300.00
0005434550756	10655	Economy	3300.00
0005434550724	10655	Economy	3300.00
0005434550742	10655	Economy	3300.00
0005434550738	10655	Economy	3000.00
0005434550749	10655	Economy	3000.00
0005434554044	10655	Economy	3000.00
0005434550714	10655	Economy	3000.00
0005434550741	10655	Economy	3000.00
0005434550751	10655	Economy	3000.00
0005434558199	10655	Economy	3000.00
0005434550753	10655	Economy	3000.00
0005434558198	10655	Economy	3000.00
0005434550736	10655	Economy	3000.00
0005434550717	10655	Economy	3000.00
0005434550710	10655	Economy	3000.00
0005433180690	10655	Economy	3000.00
0005433180680	10655	Economy	3000.00
0005434550722	10655	Economy	3000.00
0005434550737	10655	Economy	3000.00
0005434550743	10655	Economy	3000.00
0005433180743	10655	Economy	3000.00
0005434550760	10655	Economy	3000.00
0005434554045	10655	Economy	3000.00
0005434550721	10655	Economy	3000.00
0005434550758	10655	Economy	3000.00
0005434550711	10655	Economy	3000.00
0005434558201	10655	Economy	3000.00
0005434554046	10655	Economy	3000.00
0005434550708	10655	Economy	3000.00
0005434550729	10655	Economy	3000.00
0005434550757	10655	Economy	3000.00
0005433180728	10655	Economy	3000.00
0005434550728	10655	Economy	3000.00
0005434550752	10655	Economy	3000.00
0005434558200	10655	Economy	3000.00
0005434550725	10655	Economy	3000.00
0005434550759	10655	Economy	3000.00
0005434550713	10655	Economy	3000.00
0005434550716	10655	Economy	3000.00
0005434550748	10655	Economy	3000.00
0005434550754	10655	Economy	3000.00
0005434550761	10655	Economy	3000.00
0005434550709	10655	Economy	3000.00
0005434550731	10655	Economy	3000.00
0005434550730	10655	Economy	3000.00
0005434550707	10655	Economy	3000.00
0005434558204	10655	Economy	3000.00
0005434550750	10655	Economy	3000.00
0005434550720	10655	Economy	3000.00
0005434550734	10655	Economy	3000.00
0005434550723	10655	Economy	3000.00
0005434550745	10655	Economy	3000.00
0005434550735	10655	Economy	3000.00
0005434550706	10655	Economy	3000.00
0005433180895	27766	Business	9100.00
0005433180899	27766	Business	9100.00
0005433180903	27766	Business	9100.00
0005433180897	27766	Economy	3000.00
0005433180905	27766	Economy	3000.00
0005433180885	27766	Economy	3000.00
0005433180893	27766	Economy	3000.00
0005433180902	27766	Economy	3000.00
0005433180892	27766	Economy	3000.00
0005433180900	27766	Economy	3000.00
0005433180883	27766	Economy	3000.00
0005433180886	27766	Economy	3000.00
0005433180884	27766	Economy	3000.00
0005433180894	27766	Economy	3000.00
0005433180901	27766	Economy	3000.00
0005433180898	27766	Economy	3000.00
0005433180887	27766	Economy	3000.00
0005433180891	27766	Economy	3000.00
0005433180881	27766	Economy	3000.00
0005433180904	27766	Economy	3000.00
0005433180889	27766	Economy	3000.00
0005433180890	27766	Economy	3000.00
0005433180896	27766	Economy	3000.00
0005433180882	27766	Economy	3000.00
0005433180888	27766	Economy	3000.00
0005434558144	27765	Business	9100.00
0005434550324	27765	Business	9100.00
0005434550323	27765	Business	9100.00
0005434550303	27765	Business	9100.00
0005434550378	27765	Business	9100.00
0005434550369	27765	Business	9100.00
0005434550493	27765	Business	9100.00
0005434550477	27765	Business	9100.00
0005434558142	27765	Economy	3000.00
0005434558140	27765	Economy	3000.00
0005434550606	27765	Economy	3000.00
0005434550268	27765	Economy	3000.00
0005434550532	27765	Economy	3000.00
0005434550318	27765	Economy	3300.00
0005434550528	27765	Economy	3000.00
0005434550395	27765	Economy	3000.00
0005434550379	27765	Economy	3000.00
0005434550396	27765	Economy	3000.00
0005434550372	27765	Economy	3000.00
0005434550332	27765	Economy	3000.00
0005434550492	27765	Economy	3000.00
0005434550424	27765	Economy	3000.00
0005434550507	27765	Economy	3000.00
0005434550267	27765	Economy	3000.00
0005434550543	27765	Economy	3000.00
0005434550506	27765	Economy	3000.00
0005434550478	27765	Economy	3000.00
0005434550364	27765	Economy	3000.00
0005434550261	27765	Economy	3000.00
0005434550346	27765	Economy	3000.00
0005434550450	27765	Economy	3000.00
0005434550354	27765	Economy	3000.00
0005434550305	27765	Economy	3000.00
0005434550360	27765	Economy	3000.00
0005434550394	27765	Economy	3000.00
0005434550605	27765	Economy	3000.00
0005434550361	27765	Economy	3000.00
0005434550294	27765	Economy	3000.00
0005434550353	27765	Economy	3000.00
0005434550302	27765	Economy	3000.00
0005434558143	27765	Economy	3000.00
0005434550491	27765	Economy	3000.00
0005434550373	27765	Economy	3000.00
0005434550328	27765	Economy	3000.00
0005434550293	27765	Economy	3000.00
0005433459184	6115	Economy	11700.00
0005433459183	6115	Economy	11700.00
0005433459186	6115	Economy	11700.00
0005433459185	6115	Economy	11700.00
0005433459182	6115	Economy	11700.00
0005433459143	19289	Economy	11700.00
0005433459146	19289	Economy	11700.00
0005433459144	19289	Economy	11700.00
0005435254454	19289	Economy	11700.00
0005435254453	19289	Economy	11700.00
0005435681798	6763	Business	51100.00
0005435437640	6763	Business	51100.00
0005435437716	6763	Business	51100.00
0005435681768	6763	Business	51100.00
0005435681770	6763	Business	51100.00
0005432533242	6763	Business	51100.00
0005435681801	6763	Business	51100.00
0005435681791	6763	Business	51100.00
0005435681797	6763	Business	51100.00
0005435437598	6763	Business	51100.00
0005435720127	6763	Economy	17000.00
0005435681803	6763	Economy	17000.00
0005435681795	6763	Economy	17000.00
0005435221499	6763	Economy	17000.00
0005435437699	6763	Economy	17000.00
0005435681809	6763	Economy	17000.00
0005435681782	6763	Economy	17000.00
0005435681780	6763	Economy	17000.00
0005435681796	6763	Economy	17000.00
0005435681784	6763	Economy	17000.00
0005435681800	6763	Economy	18700.00
0005435681805	6763	Economy	18700.00
0005435630939	6763	Economy	18700.00
0005435681786	6763	Economy	18700.00
0005435681804	6763	Economy	17000.00
0005435681789	6763	Economy	17000.00
0005435681793	6763	Economy	17000.00
0005435681781	6763	Economy	17000.00
0005435221500	6763	Economy	17000.00
0005435681779	6763	Economy	17000.00
0005435437551	6763	Economy	17000.00
0005435661903	6763	Economy	17000.00
0005435719559	6763	Economy	17000.00
0005435437555	6763	Economy	17000.00
0005435221498	6763	Economy	17000.00
0005435681769	6763	Economy	17000.00
0005435437613	6763	Economy	17000.00
0005435681777	6763	Economy	17000.00
0005432533256	6763	Economy	17000.00
0005435681792	6763	Economy	17000.00
0005435681785	6763	Economy	17000.00
0005432533241	6763	Economy	17000.00
0005435681773	6763	Economy	17000.00
0005435681794	6763	Economy	17000.00
0005435437629	6763	Economy	17000.00
0005435630938	6763	Economy	17000.00
0005435681799	6763	Economy	17000.00
0005435681771	6763	Economy	17000.00
0005435681788	6763	Economy	17000.00
0005435437558	6763	Economy	17000.00
0005435661904	6763	Economy	17000.00
0005435437602	6763	Economy	17000.00
0005435681807	6763	Economy	17000.00
0005435719560	6763	Economy	17000.00
0005432136128	6763	Economy	17000.00
0005432136129	6763	Economy	17000.00
0005435437570	6763	Economy	17000.00
0005435217682	6763	Economy	17000.00
0005432136124	6763	Economy	17000.00
0005435681776	6763	Economy	17000.00
0005432136125	6763	Economy	17000.00
0005435681787	6763	Economy	17000.00
0005435681778	6763	Economy	17000.00
0005435437557	6763	Economy	17000.00
0005435437612	6763	Economy	17000.00
0005432136127	6763	Economy	17000.00
0005435437556	6763	Economy	17000.00
0005435681808	6763	Economy	17000.00
0005432136126	6763	Economy	17000.00
0005435437649	6763	Economy	17000.00
0005435437590	6763	Economy	17000.00
0005435661905	6763	Economy	17000.00
0005435681775	6763	Economy	17000.00
0005435630940	6763	Economy	17000.00
0005435681790	6763	Economy	17000.00
0005435681802	6763	Economy	17000.00
0005435437594	6763	Economy	17000.00
0005435681806	6763	Economy	17000.00
0005432533257	6763	Economy	17000.00
0005435681783	6763	Economy	17000.00
0005435681772	6763	Economy	17000.00
0005435437639	6763	Economy	17000.00
0005435681774	6763	Economy	17000.00
0005435437775	24589	Business	51100.00
0005435681461	24589	Business	51100.00
0005435437778	24589	Business	51100.00
0005435437764	24589	Business	51100.00
0005435437759	24589	Business	51100.00
0005432533267	24589	Business	51100.00
0005435681534	24589	Business	51100.00
0005435437771	24589	Business	51100.00
0005435681455	24589	Business	51100.00
0005435437765	24589	Economy	17000.00
0005435681481	24589	Economy	17000.00
0005435681415	24589	Economy	17000.00
0005435437757	24589	Economy	17000.00
0005435437761	24589	Economy	17000.00
0005435681451	24589	Economy	17000.00
0005432305728	24589	Economy	17000.00
0005435681522	24589	Economy	18700.00
0005435681440	24589	Economy	18700.00
0005432305730	24589	Economy	17000.00
0005435681521	24589	Economy	17000.00
0005435437766	24589	Economy	17000.00
0005435681430	24589	Economy	17000.00
0005435681663	24589	Economy	17000.00
0005432305727	24589	Economy	17000.00
0005435681546	24589	Economy	17000.00
0005435437777	24589	Economy	17000.00
0005434828675	24589	Economy	17000.00
0005432533268	24589	Economy	17000.00
0005435681431	24589	Economy	17000.00
0005435437758	24589	Economy	17000.00
0005435681408	24589	Economy	17000.00
0005432533266	24589	Economy	17000.00
0005435681470	24589	Economy	17000.00
0005435437768	24589	Economy	17000.00
0005435681416	24589	Economy	17000.00
0005435681453	24589	Economy	17000.00
0005435681533	24589	Economy	17000.00
0005435437769	24589	Economy	17000.00
0005435681403	24589	Economy	17000.00
0005434828674	24589	Economy	17000.00
0005435681439	24589	Economy	17000.00
0005435437763	24589	Economy	17000.00
0005435681409	24589	Economy	17000.00
0005435437760	24589	Economy	17000.00
0005435437772	24589	Economy	17000.00
0005435681448	24589	Economy	17000.00
0005435681438	24589	Economy	17000.00
0005435437770	24589	Economy	17000.00
0005435681389	24589	Economy	17000.00
0005435681509	24589	Economy	17000.00
0005435437776	24589	Economy	17000.00
0005435720805	24589	Economy	17000.00
0005435437767	24589	Economy	17000.00
0005435437773	24589	Economy	17000.00
0005435681454	24589	Economy	17000.00
0005435437762	24589	Economy	17000.00
0005435720806	24589	Economy	17000.00
0005435681433	24589	Economy	17000.00
0005435681462	24589	Economy	17000.00
0005435681502	24589	Economy	17000.00
0005435437774	24589	Economy	17000.00
0005435681463	24589	Economy	17000.00
0005435630915	24589	Economy	17000.00
0005435630916	24589	Economy	17000.00
0005432305729	24589	Economy	17000.00
0005435681501	24589	Economy	17000.00
0005435125981	11505	Business	26400.00
0005435558040	11505	Business	26400.00
0005435126012	11505	Business	26400.00
0005435125995	11505	Business	26400.00
0005435126021	11505	Business	26400.00
0005435125989	11505	Business	26400.00
0005435125999	11505	Business	26400.00
0005435558047	11505	Economy	8800.00
0005435558049	11505	Economy	8800.00
0005435126005	11505	Economy	8800.00
0005435126007	11505	Economy	8800.00
0005435126000	11505	Economy	9700.00
0005435125998	11505	Economy	9700.00
0005435125988	11505	Economy	9700.00
0005435126002	11505	Economy	8800.00
0005435125997	11505	Economy	8800.00
0005435558041	11505	Economy	8800.00
0005435126017	11505	Economy	8800.00
0005435125994	11505	Economy	8800.00
0005435126015	11505	Economy	8800.00
0005435125985	11505	Economy	8800.00
0005435125996	11505	Economy	8800.00
0005435125992	11505	Economy	8800.00
0005435126014	11505	Economy	8800.00
0005435126003	11505	Economy	8800.00
0005435126004	11505	Economy	8800.00
0005435105953	11505	Economy	8800.00
0005435125980	11505	Economy	8800.00
0005435126010	11505	Economy	8800.00
0005435126016	11505	Economy	8800.00
0005435126001	11505	Economy	8800.00
0005435126018	11505	Economy	8800.00
0005435125993	11505	Economy	8800.00
0005435105954	11505	Economy	8800.00
0005435125982	11505	Economy	8800.00
0005435126019	11505	Economy	8800.00
0005435558050	11505	Economy	8800.00
0005435126013	11505	Economy	8800.00
0005435126020	11505	Economy	8800.00
0005435125991	11505	Economy	8800.00
0005435126011	11505	Economy	8800.00
0005435126006	11505	Economy	8800.00
0005435125990	11505	Economy	8800.00
0005435126009	11505	Economy	8800.00
0005435125984	11505	Economy	8800.00
0005435125987	11505	Economy	8800.00
0005435558039	11505	Economy	8800.00
0005435126008	11505	Economy	8800.00
0005435125986	11505	Economy	8800.00
0005435125983	11505	Economy	8800.00
0005435125722	31860	Business	26400.00
0005435558066	31860	Business	26400.00
0005435105932	31860	Business	26400.00
0005435125825	31860	Business	26400.00
0005435125693	31860	Business	26400.00
0005435558065	31860	Business	26400.00
0005435125708	31860	Business	26400.00
0005435125712	31860	Economy	8800.00
0005435125718	31860	Economy	8800.00
0005435125725	31860	Economy	8800.00
0005435125705	31860	Economy	8800.00
0005435125691	31860	Economy	8800.00
0005435125648	31860	Economy	9700.00
0005435125680	31860	Economy	9700.00
0005435125727	31860	Economy	8800.00
0005435125690	31860	Economy	8800.00
0005435125711	31860	Economy	8800.00
0005435125682	31860	Economy	8800.00
0005435125781	31860	Economy	8800.00
0005435125883	31860	Economy	8800.00
0005435125882	31860	Economy	8800.00
0005435125655	31860	Economy	8800.00
0005435105923	31860	Economy	8800.00
0005435125762	31860	Economy	8800.00
0005435125692	31860	Economy	8800.00
0005435125647	31860	Economy	8800.00
0005435125746	31860	Economy	8800.00
0005435125677	31860	Economy	8800.00
0005435125707	31860	Economy	8800.00
0005435125678	31860	Economy	8800.00
0005435125726	31860	Economy	8800.00
0005435105925	31860	Economy	8800.00
0005435125922	31860	Economy	8800.00
0005435105939	31860	Economy	8800.00
0005435125836	31860	Economy	8800.00
0005435125689	31860	Economy	8800.00
0005435125721	31860	Economy	8800.00
0005435105924	31860	Economy	8800.00
0005435098521	31860	Economy	8800.00
0005433397640	13542	Business	36600.00
0005433397670	13542	Business	36600.00
0005433397663	13542	Business	36600.00
0005435732150	13542	Business	36600.00
0005433397628	13542	Business	36600.00
0005433397651	13542	Business	36600.00
0005433397641	13542	Economy	12200.00
0005433397665	13542	Economy	12200.00
0005435732142	13542	Economy	12200.00
0005433397655	13542	Economy	12200.00
0005433397650	13542	Economy	12200.00
0005433397639	13542	Economy	12200.00
0005433397662	13542	Economy	13400.00
0005433397658	13542	Economy	13400.00
0005433397652	13542	Economy	13400.00
0005433397627	13542	Economy	12200.00
0005433397673	13542	Economy	12200.00
0005435732141	13542	Economy	12200.00
0005435732122	13542	Economy	12200.00
0005433397637	13542	Economy	12200.00
0005433397657	13542	Economy	12200.00
0005433397666	13542	Economy	12200.00
0005433397644	13542	Economy	12200.00
0005433397653	13542	Economy	12200.00
0005433397669	13542	Economy	12200.00
0005433397661	13542	Economy	12200.00
0005433397636	13542	Economy	12200.00
0005433397671	13542	Economy	12200.00
0005433397634	13542	Economy	12200.00
0005433397646	13542	Economy	12200.00
0005433397632	13542	Economy	12200.00
0005433397642	13542	Economy	12200.00
0005433397635	13542	Economy	12200.00
0005435732151	13542	Economy	12200.00
0005433397667	13542	Economy	12200.00
0005433397638	13542	Economy	12200.00
0005433397629	13542	Economy	12200.00
0005433397675	13542	Economy	12200.00
0005433397672	13542	Economy	12200.00
0005433397668	13542	Economy	12200.00
0005433397647	13542	Economy	12200.00
0005433397643	13542	Economy	12200.00
0005435732126	13542	Economy	12200.00
0005433397660	13542	Economy	12200.00
0005433397649	13542	Economy	12200.00
0005433397645	13542	Economy	12200.00
0005433397656	13542	Economy	12200.00
0005433397659	13542	Economy	12200.00
0005433397633	13542	Economy	12200.00
0005433397674	13542	Economy	12200.00
0005433397631	13542	Economy	12200.00
0005433397654	13542	Economy	12200.00
0005433397648	13542	Economy	12200.00
0005435732121	13542	Economy	12200.00
0005435732120	13542	Economy	12200.00
0005433397664	13542	Economy	12200.00
0005433397630	13542	Economy	12200.00
0005433397275	19423	Business	36600.00
0005433397318	19423	Business	36600.00
0005433397313	19423	Business	36600.00
0005435732232	19423	Economy	12200.00
0005433397306	19423	Economy	12200.00
0005433397361	19423	Economy	13400.00
0005435732229	19423	Economy	13400.00
0005433397396	19423	Economy	13400.00
0005433397274	19423	Economy	12200.00
0005435732227	19423	Economy	12200.00
0005433397270	19423	Economy	12200.00
0005433397304	19423	Economy	12200.00
0005433397456	19423	Economy	12200.00
0005433397307	19423	Economy	12200.00
0005433397298	19423	Economy	12200.00
0005433397269	19423	Economy	12200.00
0005433397276	19423	Economy	12200.00
0005432297254	19423	Economy	12200.00
0005433397299	19423	Economy	12200.00
0005432297255	19423	Economy	12200.00
0005433397215	19423	Economy	12200.00
0005435732231	19423	Economy	12200.00
0005433397266	19423	Economy	12200.00
0005433397265	19423	Economy	12200.00
0005433397204	19423	Economy	12200.00
0005433397317	19423	Economy	12200.00
0005433397337	19423	Economy	12200.00
0005433397244	19423	Economy	12200.00
0005432297256	19423	Economy	12200.00
0005433397366	19423	Economy	12200.00
0005435732230	19423	Economy	12200.00
0005433397214	19423	Economy	12200.00
0005433397264	19423	Economy	12200.00
0005433397262	19423	Economy	12200.00
0005435732228	19423	Economy	12200.00
0005433397263	19423	Economy	12200.00
0005433397443	19423	Economy	12200.00
0005435732226	19423	Economy	12200.00
0005433397213	19423	Economy	12200.00
0005433397305	19423	Economy	12200.00
0005433397248	19423	Economy	12200.00
0005433397397	19423	Economy	12200.00
0005435068349	13131	Business	11300.00
0005435925188	13131	Business	11300.00
0005435068339	13131	Business	11300.00
0005435925182	13131	Business	11300.00
0005435925178	13131	Business	11300.00
0005435068219	13131	Business	11300.00
0005435068213	13131	Business	11300.00
0005435925190	13131	Economy	3800.00
0005435925185	13131	Economy	3800.00
0005435068179	13131	Economy	3800.00
0005435925186	13131	Economy	3800.00
0005435925180	13131	Economy	4100.00
0005435068202	13131	Economy	4100.00
0005435068235	13131	Economy	3800.00
0005435068234	13131	Economy	3800.00
0005435925177	13131	Economy	3800.00
0005435925183	13131	Economy	3800.00
0005435068366	13131	Economy	3800.00
0005435068285	13131	Economy	3800.00
0005435068257	13131	Economy	3800.00
0005435925191	13131	Economy	3800.00
0005435925184	13131	Economy	3800.00
0005435068258	13131	Economy	3800.00
0005435068306	13131	Economy	3800.00
0005435068407	13131	Economy	3800.00
0005435068259	13131	Economy	3800.00
0005435068188	13131	Economy	3800.00
0005435068210	13131	Economy	3800.00
0005435068338	13131	Economy	3800.00
0005435068240	13131	Economy	3800.00
0005435925181	13131	Economy	3800.00
0005435068348	13131	Economy	3800.00
0005435925179	13131	Economy	3800.00
0005435068241	13131	Economy	3800.00
0005435068312	13131	Economy	3800.00
0005435068180	13131	Economy	3800.00
0005435068225	13131	Economy	3800.00
0005435068307	13131	Economy	3800.00
0005435068189	13131	Economy	3800.00
0005435068220	13131	Economy	3800.00
0005435925187	13131	Economy	3800.00
0005435068226	13131	Economy	3800.00
0005435925189	13131	Economy	3800.00
0005435068367	13131	Economy	3800.00
0005435068209	13131	Economy	3800.00
0005435925059	15499	Business	11300.00
0005435925064	15499	Business	11300.00
0005435068629	15499	Business	11300.00
0005435068598	15499	Business	11300.00
0005435925082	15499	Business	11300.00
0005435068605	15499	Business	11300.00
0005435925056	15499	Business	11300.00
0005435925063	15499	Business	11300.00
0005435925055	15499	Business	11300.00
0005435068611	15499	Economy	3800.00
0005435068625	15499	Economy	3800.00
0005435068631	15499	Economy	3800.00
0005435068623	15499	Economy	3800.00
0005435068590	15499	Economy	3800.00
0005435068624	15499	Economy	3800.00
0005435925060	15499	Economy	3800.00
0005435068591	15499	Economy	4100.00
0005435068627	15499	Economy	4100.00
0005435925081	15499	Economy	4100.00
0005435068603	15499	Economy	4100.00
0005435068608	15499	Economy	3800.00
0005435068599	15499	Economy	3800.00
0005435068613	15499	Economy	3800.00
0005435068626	15499	Economy	3800.00
0005435068630	15499	Economy	3800.00
0005435068610	15499	Economy	3800.00
0005435068582	15499	Economy	3800.00
0005435068596	15499	Economy	3800.00
0005435068601	15499	Economy	3800.00
0005435068588	15499	Economy	3800.00
0005435925086	15499	Economy	3800.00
0005435068620	15499	Economy	3800.00
0005435068587	15499	Economy	3800.00
0005435068600	15499	Economy	3800.00
0005435068584	15499	Economy	3800.00
0005435068606	15499	Economy	3800.00
0005435068633	15499	Economy	3800.00
0005435068595	15499	Economy	3800.00
0005435068622	15499	Economy	3800.00
0005435068586	15499	Economy	3800.00
0005435068621	15499	Economy	3800.00
0005435068615	15499	Economy	3800.00
0005435068593	15499	Economy	3800.00
0005435068604	15499	Economy	3800.00
0005435068594	15499	Economy	3800.00
0005435068628	15499	Economy	3800.00
0005435068616	15499	Economy	3800.00
0005435068592	15499	Economy	3800.00
0005435068609	15499	Economy	3800.00
0005435068583	15499	Economy	3800.00
0005435068585	15499	Economy	3800.00
0005435068618	15499	Economy	3800.00
0005435068617	15499	Economy	3800.00
0005435068607	15499	Economy	3800.00
0005435068597	15499	Economy	3800.00
0005435068614	15499	Economy	3800.00
0005435068602	15499	Economy	3800.00
0005435068634	15499	Economy	3800.00
0005435925094	15499	Economy	3800.00
0005435068632	15499	Economy	3800.00
0005435068589	15499	Economy	3800.00
0005435068612	15499	Economy	3800.00
0005435068619	15499	Economy	3800.00
0005435925066	15499	Economy	3800.00
0005435808059	29501	Economy	27100.00
0005435808065	29501	Economy	27100.00
0005435808073	29501	Economy	24700.00
0005435808069	29501	Economy	24700.00
0005433407527	29501	Economy	24700.00
0005435808054	29501	Economy	24700.00
0005433407525	29501	Economy	24700.00
0005433407522	29501	Economy	24700.00
0005435808055	29501	Economy	24700.00
0005433407526	29501	Economy	24700.00
0005435808070	29501	Economy	24700.00
0005433407521	29501	Economy	24700.00
0005435808064	29501	Economy	24700.00
0005435808061	29501	Economy	24700.00
0005435808062	29501	Economy	24700.00
0005433407528	29501	Economy	24700.00
0005433407520	29501	Economy	24700.00
0005433407529	29501	Economy	24700.00
0005435808060	29501	Economy	24700.00
0005435808067	29501	Economy	24700.00
0005433407524	29501	Economy	24700.00
0005435808066	29501	Economy	24700.00
0005433407523	29501	Economy	24700.00
0005433407519	29501	Economy	24700.00
0005433407518	29501	Economy	24700.00
0005435808058	29501	Economy	24700.00
0005434214172	10704	Business	61300.00
0005434214147	10704	Business	61300.00
0005434214140	10704	Business	61300.00
0005434214161	10704	Business	61300.00
0005434755706	10704	Business	61300.00
0005434214138	10704	Business	61300.00
0005434214159	10704	Business	61300.00
0005434755762	10704	Business	61300.00
0005434214158	10704	Economy	20400.00
0005434214137	10704	Economy	20400.00
0005434214151	10704	Economy	20400.00
0005434755766	10704	Economy	20400.00
0005434214136	10704	Economy	20400.00
0005434214169	10704	Economy	20400.00
0005434755770	10704	Economy	20400.00
0005434214148	10704	Economy	22500.00
0005434214133	10704	Economy	22500.00
0005434755763	10704	Economy	22500.00
0005434214135	10704	Economy	20400.00
0005434214149	10704	Economy	20400.00
0005434755771	10704	Economy	20400.00
0005434755707	10704	Economy	20400.00
0005434214173	10704	Economy	20400.00
0005434214165	10704	Economy	20400.00
0005434755756	10704	Economy	20400.00
0005434755705	10704	Economy	20400.00
0005434214129	10704	Economy	20400.00
0005434755738	10704	Economy	20400.00
0005434214152	10704	Economy	20400.00
0005434214139	10704	Economy	20400.00
0005434755757	10704	Economy	20400.00
0005434755726	10704	Economy	20400.00
0005434214153	10704	Economy	20400.00
0005434755727	10704	Economy	20400.00
0005434214146	10704	Economy	20400.00
0005434214134	10704	Economy	20400.00
0005434214131	10704	Economy	20400.00
0005434214164	10704	Economy	20400.00
0005434214170	10704	Economy	20400.00
0005434214155	10704	Economy	20400.00
0005434214128	10704	Economy	20400.00
0005434755742	10704	Economy	20400.00
0005434755711	10704	Economy	20400.00
0005434755712	10704	Economy	20400.00
0005434214154	10704	Economy	20400.00
0005434214141	10704	Economy	20400.00
0005434214160	10704	Economy	20400.00
0005434214156	10704	Economy	20400.00
0005434214132	10704	Economy	20400.00
0005434214127	10704	Economy	20400.00
0005434214168	10704	Economy	20400.00
0005434214150	10704	Economy	20400.00
0005434214145	10704	Economy	20400.00
0005434214157	10704	Economy	20400.00
0005434755759	10704	Economy	20400.00
0005434755750	10704	Economy	20400.00
0005434214162	10704	Economy	20400.00
0005434214166	10704	Economy	20400.00
0005434214142	10704	Economy	20400.00
0005434214130	10704	Economy	20400.00
0005434214144	10704	Economy	20400.00
0005434755769	10704	Economy	20400.00
0005434214167	10704	Economy	20400.00
0005434214143	10704	Economy	20400.00
0005434755772	10704	Economy	20400.00
0005434214171	10704	Economy	20400.00
0005434755748	10704	Economy	20400.00
0005434755760	10704	Economy	20400.00
0005434214163	10704	Economy	20400.00
0005434213716	28671	Business	61300.00
0005434756084	28671	Business	61300.00
0005434213784	28671	Business	61300.00
0005434213772	28671	Business	61300.00
0005434756057	28671	Business	61300.00
0005434756089	28671	Business	61300.00
0005434756051	28671	Business	61300.00
0005434213743	28671	Economy	20400.00
0005434756049	28671	Economy	20400.00
0005434213778	28671	Economy	20400.00
0005434213715	28671	Economy	20400.00
0005434756068	28671	Economy	20400.00
0005434756079	28671	Economy	20400.00
0005434756053	28671	Economy	20400.00
0005434756087	28671	Economy	22500.00
0005434756061	28671	Economy	22500.00
0005434756054	28671	Economy	22500.00
0005434756066	28671	Economy	22500.00
0005434756080	28671	Economy	20400.00
0005434213771	28671	Economy	20400.00
0005434756055	28671	Economy	20400.00
0005434756085	28671	Economy	20400.00
0005434756086	28671	Economy	20400.00
0005434756056	28671	Economy	20400.00
0005434756075	28671	Economy	20400.00
0005434756088	28671	Economy	20400.00
0005434756071	28671	Economy	20400.00
0005434756083	28671	Economy	20400.00
0005434756073	28671	Economy	20400.00
0005434213777	28671	Economy	20400.00
0005434756076	28671	Economy	20400.00
0005434213869	28671	Economy	20400.00
0005434756058	28671	Economy	20400.00
0005434756074	28671	Economy	20400.00
0005434213880	28671	Economy	20400.00
0005434756081	28671	Economy	20400.00
0005434756064	28671	Economy	20400.00
0005434756060	28671	Economy	20400.00
0005434213769	28671	Economy	20400.00
0005434756050	28671	Economy	20400.00
0005434756067	28671	Economy	20400.00
0005434213776	28671	Economy	20400.00
0005434756077	28671	Economy	20400.00
0005434756082	28671	Economy	20400.00
0005434213741	28671	Economy	20400.00
0005434756072	28671	Economy	20400.00
0005434756063	28671	Economy	20400.00
0005434756059	28671	Economy	20400.00
0005434213879	28671	Economy	20400.00
0005434213768	28671	Economy	20400.00
0005434756069	28671	Economy	20400.00
0005434756065	28671	Economy	20400.00
0005434756062	28671	Economy	20400.00
0005434756078	28671	Economy	20400.00
0005434213742	28671	Economy	20400.00
0005434756070	28671	Economy	20400.00
0005434756052	28671	Economy	20400.00
0005435039246	5465	Business	29500.00
0005435006830	5465	Business	29500.00
0005435039216	5465	Business	29500.00
0005435039225	5465	Business	29500.00
0005435039211	5465	Business	29500.00
0005435039227	5465	Business	29500.00
0005435039212	5465	Business	29500.00
0005434228980	5465	Business	29500.00
0005435039262	5465	Business	29500.00
0005435039226	5465	Business	29500.00
0005435006817	5465	Business	29500.00
0005435006832	5465	Economy	9800.00
0005435039241	5465	Economy	9800.00
0005435039204	5465	Economy	9800.00
0005435006820	5465	Economy	9800.00
0005435039221	5465	Economy	9800.00
0005435039198	5465	Economy	9800.00
0005434228969	5465	Economy	9800.00
0005432125389	5465	Economy	9800.00
0005432125387	5465	Economy	9800.00
0005435039253	5465	Economy	9800.00
0005434228970	5465	Economy	9800.00
0005435039249	5465	Economy	9800.00
0005435039209	5465	Economy	9800.00
0005435039194	5465	Economy	9800.00
0005435039223	5465	Economy	9800.00
0005435039201	5465	Economy	9800.00
0005434228981	5465	Economy	9800.00
0005432125388	5465	Economy	9800.00
0005434228998	5465	Economy	9800.00
0005434229004	5465	Economy	9800.00
0005434228996	5465	Economy	9800.00
0005434229035	5465	Economy	9800.00
0005435039213	5465	Economy	9800.00
0005435039254	5465	Economy	9800.00
0005435039234	5465	Economy	9800.00
0005435039255	5465	Economy	9800.00
0005435039237	5465	Economy	9800.00
0005435039193	5465	Economy	9800.00
0005435039250	5465	Economy	9800.00
0005435039238	5465	Economy	9800.00
0005435039205	5465	Economy	9800.00
0005435039240	5465	Economy	9800.00
0005435039195	5465	Economy	9800.00
0005435039200	5465	Economy	9800.00
0005435006836	5465	Economy	9800.00
0005435006829	5465	Economy	9800.00
0005434229027	5465	Economy	10800.00
0005432125391	5465	Economy	10800.00
0005435006841	5465	Economy	10800.00
0005435039256	5465	Economy	10800.00
0005434229048	5465	Economy	10800.00
0005435006837	5465	Economy	9800.00
0005435039228	5465	Economy	9800.00
0005435006821	5465	Economy	9800.00
0005435039230	5465	Economy	9800.00
0005435039260	5465	Economy	9800.00
0005435039235	5465	Economy	9800.00
0005434229020	5465	Economy	9800.00
0005435006839	5465	Economy	9800.00
0005435039215	5465	Economy	9800.00
0005435039257	5465	Economy	9800.00
0005435039236	5465	Economy	9800.00
0005435006822	5465	Economy	9800.00
0005435039202	5465	Economy	9800.00
0005435039251	5465	Economy	9800.00
0005434228997	5465	Economy	9800.00
0005435039220	5465	Economy	9800.00
0005432125393	5465	Economy	9800.00
0005435006819	5465	Economy	9800.00
0005435039207	5465	Economy	9800.00
0005435039197	5465	Economy	9800.00
0005434229028	5465	Economy	9800.00
0005435039229	5465	Economy	9800.00
0005435039243	5465	Economy	9800.00
0005435039196	5465	Economy	9800.00
0005435006823	5465	Economy	9800.00
0005435039210	5465	Economy	9800.00
0005434229021	5465	Economy	9800.00
0005435039239	5465	Economy	9800.00
0005434228971	5465	Economy	9800.00
0005435039199	5465	Economy	9800.00
0005434229047	5465	Economy	9800.00
0005435006828	5465	Economy	9800.00
0005435039219	5465	Economy	9800.00
0005435039218	5465	Economy	9800.00
0005435039206	5465	Economy	9800.00
0005435039258	5465	Economy	9800.00
0005435006838	5465	Economy	9800.00
0005435039214	5465	Economy	9800.00
0005435039252	5465	Economy	9800.00
0005435006834	5465	Economy	9800.00
0005434228985	5465	Economy	9800.00
0005432125386	5465	Economy	9800.00
0005432125392	5465	Economy	9800.00
0005435039208	5465	Economy	9800.00
0005434229005	5465	Economy	9800.00
0005435006833	5465	Economy	9800.00
0005435039244	5465	Economy	9800.00
0005435039231	5465	Economy	9800.00
0005435006825	5465	Economy	9800.00
0005435039222	5465	Economy	9800.00
0005435039247	5465	Economy	9800.00
0005435006818	5465	Economy	9800.00
0005435006840	5465	Economy	9800.00
0005435039242	5465	Economy	9800.00
0005435039259	5465	Economy	9800.00
0005432125390	5465	Economy	9800.00
0005435039248	5465	Economy	9800.00
0005435039232	5465	Economy	9800.00
0005435039224	5465	Economy	9800.00
0005435039245	5465	Economy	9800.00
0005435039217	5465	Economy	9800.00
0005435039261	5465	Economy	9800.00
0005434228984	5465	Economy	9800.00
0005435006827	5465	Economy	9800.00
0005435006831	5465	Economy	9800.00
0005435006835	5465	Economy	9800.00
0005435006826	5465	Economy	9800.00
0005435039233	5465	Economy	9800.00
0005435039203	5465	Economy	9800.00
0005435006824	5465	Economy	9800.00
0005435038718	12980	Business	29500.00
0005434229180	12980	Business	29500.00
0005434229176	12980	Business	29500.00
0005434229195	12980	Business	29500.00
0005435038659	12980	Business	29500.00
0005435038629	12980	Business	29500.00
0005434229183	12980	Business	29500.00
0005435038695	12980	Business	29500.00
0005435038611	12980	Business	29500.00
0005435038763	12980	Economy	9800.00
0005435006648	12980	Economy	9800.00
0005435006728	12980	Economy	9800.00
0005435038628	12980	Economy	9800.00
0005435038656	12980	Economy	9800.00
0005435006684	12980	Economy	9800.00
0005434229185	12980	Economy	9800.00
0005435038688	12980	Economy	9800.00
0005435006720	12980	Economy	9800.00
0005435006626	12980	Economy	9800.00
0005434229182	12980	Economy	9800.00
0005435038839	12980	Economy	9800.00
0005434229194	12980	Economy	9800.00
0005435038727	12980	Economy	9800.00
0005435038613	12980	Economy	9800.00
0005434229177	12980	Economy	9800.00
0005435038888	12980	Economy	9800.00
0005435006679	12980	Economy	9800.00
0005434229189	12980	Economy	9800.00
0005435038750	12980	Economy	9800.00
0005435038804	12980	Economy	9800.00
0005434229192	12980	Economy	9800.00
0005434229186	12980	Economy	9800.00
0005435038719	12980	Economy	9800.00
0005434229184	12980	Economy	9800.00
0005435038660	12980	Economy	9800.00
0005435038704	12980	Economy	10800.00
0005435006621	12980	Economy	9800.00
0005435038835	12980	Economy	10800.00
0005435038764	12980	Economy	10800.00
0005432304365	12980	Economy	10800.00
0005434229175	12980	Economy	10800.00
0005435006680	12980	Economy	10800.00
0005435038618	12980	Economy	9800.00
0005435038798	12980	Economy	9800.00
0005432304366	12980	Economy	9800.00
0005435038900	12980	Economy	9800.00
0005434229179	12980	Economy	9800.00
0005435038702	12980	Economy	9800.00
0005435038712	12980	Economy	9800.00
0005435038687	12980	Economy	9800.00
0005435038692	12980	Economy	9800.00
0005434229193	12980	Economy	9800.00
0005435038739	12980	Economy	9800.00
0005434229196	12980	Economy	9800.00
0005432304364	12980	Economy	9800.00
0005435038610	12980	Economy	9800.00
0005435006681	12980	Economy	9800.00
0005434229178	12980	Economy	9800.00
0005435038667	12980	Economy	9800.00
0005435038612	12980	Economy	9800.00
0005435038794	12980	Economy	9800.00
0005434229174	12980	Economy	9800.00
0005435038725	12980	Economy	9800.00
0005435038681	12980	Economy	9800.00
0005435038617	12980	Economy	9800.00
0005435038616	12980	Economy	9800.00
0005435006647	12980	Economy	9800.00
0005435006638	12980	Economy	9800.00
0005435038620	12980	Economy	9800.00
0005434229181	12980	Economy	9800.00
0005435038693	12980	Economy	9800.00
0005434229187	12980	Economy	9800.00
0005434229190	12980	Economy	9800.00
0005434229191	12980	Economy	9800.00
0005434229188	12980	Economy	9800.00
0005435038691	12980	Economy	9800.00
0005435038784	12980	Economy	9800.00
0005435038658	12980	Economy	9800.00
0005435006721	12980	Economy	9800.00
0005435038887	12980	Economy	9800.00
0005435038668	12980	Economy	9800.00
0005435006700	12980	Economy	9800.00
0005432304367	12980	Economy	9800.00
0005435006682	12980	Economy	9800.00
0005435006627	12980	Economy	9800.00
0005435038762	12980	Economy	9800.00
0005435038696	12980	Economy	9800.00
0005435038754	12980	Economy	9800.00
0005435038655	12980	Economy	9800.00
0005434229197	12980	Economy	9800.00
0005435038619	12980	Economy	9800.00
0005435902400	14881	Business	52900.00
0005434426332	14881	Business	52900.00
0005434426342	14881	Business	52900.00
0005434411737	14881	Business	52900.00
0005434426349	14881	Business	52900.00
0005434426348	14881	Economy	17600.00
0005434426344	14881	Economy	17600.00
0005435554111	14881	Economy	17600.00
0005434426328	14881	Economy	17600.00
0005435902411	14881	Economy	19400.00
0005434426335	14881	Economy	19400.00
0005434426343	14881	Economy	19400.00
0005434426347	14881	Economy	19400.00
0005434426330	14881	Economy	17600.00
0005434411739	14881	Economy	17600.00
0005434426355	14881	Economy	17600.00
0005435902401	14881	Economy	17600.00
0005434426350	14881	Economy	17600.00
0005432188576	14881	Economy	17600.00
0005434426331	14881	Economy	17600.00
0005434426340	14881	Economy	17600.00
0005434426354	14881	Economy	17600.00
0005434426338	14881	Economy	17600.00
0005432188579	14881	Economy	17600.00
0005434426337	14881	Economy	17600.00
0005435902403	14881	Economy	17600.00
0005434426329	14881	Economy	17600.00
0005434426346	14881	Economy	17600.00
0005434426336	14881	Economy	17600.00
0005435902463	14881	Economy	17600.00
0005434426341	14881	Economy	17600.00
0005434426327	14881	Economy	17600.00
0005435902402	14881	Economy	17600.00
0005434426334	14881	Economy	17600.00
0005434426352	14881	Economy	17600.00
0005434426345	14881	Economy	17600.00
0005434411738	14881	Economy	17600.00
0005434426339	14881	Economy	17600.00
0005434426353	14881	Economy	17600.00
0005432188577	14881	Economy	17600.00
0005434426333	14881	Economy	17600.00
0005434426326	14881	Economy	17600.00
0005432188578	14881	Economy	17600.00
0005434411740	14881	Economy	17600.00
0005434426351	14881	Economy	17600.00
0005434426103	20238	Business	52900.00
0005434426107	20238	Business	52900.00
0005434426170	20238	Business	52900.00
0005435902556	20238	Business	52900.00
0005434426139	20238	Business	52900.00
0005434426099	20238	Business	52900.00
0005435554152	20238	Business	52900.00
0005434426238	20238	Economy	17600.00
0005432059488	20238	Economy	17600.00
0005434426214	20238	Economy	17600.00
0005434426173	20238	Economy	19400.00
0005434426141	20238	Economy	19400.00
0005435902559	20238	Economy	19400.00
0005434426175	20238	Economy	17600.00
0005435554151	20238	Economy	17600.00
0005435902564	20238	Economy	17600.00
0005435902555	20238	Economy	17600.00
0005432059487	20238	Economy	17600.00
0005434411708	20238	Economy	17600.00
0005435902565	20238	Economy	17600.00
0005435902553	20238	Economy	17600.00
0005435902549	20238	Economy	17600.00
0005434426142	20238	Economy	17600.00
0005435902551	20238	Economy	17600.00
0005434426172	20238	Economy	17600.00
0005435902561	20238	Economy	17600.00
0005434426118	20238	Economy	17600.00
0005434426186	20238	Economy	17600.00
0005435902560	20238	Economy	17600.00
0005435902558	20238	Economy	17600.00
0005435554149	20238	Economy	17600.00
0005435902552	20238	Economy	17600.00
0005435902554	20238	Economy	17600.00
0005434411701	20238	Economy	17600.00
0005434426237	20238	Economy	17600.00
0005434426156	20238	Economy	17600.00
0005435902557	20238	Economy	17600.00
0005434426119	20238	Economy	17600.00
0005434426171	20238	Economy	17600.00
0005435902562	20238	Economy	17600.00
0005435554150	20238	Economy	17600.00
0005435902550	20238	Economy	17600.00
0005435902563	20238	Economy	17600.00
0005434426140	20238	Economy	17600.00
0005432462492	28019	Business	106800.00
0005432462496	28019	Economy	35600.00
0005432462493	28019	Economy	35600.00
0005434523737	28019	Economy	35600.00
0005432462495	28019	Economy	39200.00
0005432462497	28019	Economy	35600.00
0005432462494	28019	Economy	35600.00
0005432462498	28019	Economy	35600.00
0005434523733	28019	Economy	35600.00
0005434523736	28019	Economy	35600.00
0005432462499	28019	Economy	35600.00
0005435981908	26518	Business	18500.00
0005435981918	26518	Business	18500.00
0005435981895	26518	Business	18500.00
0005435981902	26518	Business	18500.00
0005432300208	26518	Business	18500.00
0005433434199	26518	Business	18500.00
0005433434272	26518	Business	18500.00
0005435981923	26518	Business	18500.00
0005433434220	26518	Business	18500.00
0005434270175	26518	Economy	6200.00
0005434270174	26518	Economy	6200.00
0005435981898	26518	Economy	6200.00
0005435981891	26518	Economy	6200.00
0005433434205	26518	Economy	6200.00
0005433434243	26518	Economy	6200.00
0005435981896	26518	Economy	6200.00
0005435981921	26518	Economy	6800.00
0005435981889	26518	Economy	6800.00
0005432300210	26518	Economy	6800.00
0005435981893	26518	Economy	6800.00
0005435981892	26518	Economy	6800.00
0005435981905	26518	Economy	6200.00
0005435981920	26518	Economy	6200.00
0005435981910	26518	Economy	6200.00
0005435981916	26518	Economy	6200.00
0005435981899	26518	Economy	6200.00
0005433434213	26518	Economy	6200.00
0005432300213	26518	Economy	6200.00
0005435981897	26518	Economy	6200.00
0005433434204	26518	Economy	6200.00
0005435981900	26518	Economy	6200.00
0005433434237	26518	Economy	6200.00
0005434273046	26518	Economy	6200.00
0005434270176	26518	Economy	6200.00
0005435981914	26518	Economy	6200.00
0005432300211	26518	Economy	6200.00
0005435981894	26518	Economy	6200.00
0005433434232	26518	Economy	6200.00
0005433434206	26518	Economy	6200.00
0005433434283	26518	Economy	6200.00
0005435981913	26518	Economy	6200.00
0005435981890	26518	Economy	6200.00
0005435981901	26518	Economy	6200.00
0005435981917	26518	Economy	6200.00
0005434270172	26518	Economy	6200.00
0005434270173	26518	Economy	6200.00
0005433434238	26518	Economy	6200.00
0005435981912	26518	Economy	6200.00
0005433434192	26518	Economy	6200.00
0005435981907	26518	Economy	6200.00
0005435981915	26518	Economy	6200.00
0005433434225	26518	Economy	6200.00
0005435981903	26518	Economy	6200.00
0005432300209	26518	Economy	6200.00
0005433434244	26518	Economy	6200.00
0005433434224	26518	Economy	6200.00
0005435981911	26518	Economy	6200.00
0005435981919	26518	Economy	6200.00
0005432300212	26518	Economy	6200.00
0005435981906	26518	Economy	6200.00
0005433434214	26518	Economy	6200.00
0005433434207	26518	Economy	6200.00
0005435981922	26518	Economy	6200.00
0005433434245	26518	Economy	6200.00
0005433434282	26518	Economy	6200.00
0005435981904	26518	Economy	6200.00
0005435981909	26518	Economy	6200.00
0005435981648	26694	Business	18500.00
0005433434467	26694	Business	18500.00
0005433434462	26694	Business	18500.00
0005435981585	26694	Business	18500.00
0005434270189	26694	Economy	6200.00
0005435981550	26694	Economy	6200.00
0005433434445	26694	Economy	6200.00
0005433434450	26694	Economy	6200.00
0005433434452	26694	Economy	6200.00
0005433434444	26694	Economy	6200.00
0005433434459	26694	Economy	6200.00
0005434269085	26694	Economy	6200.00
0005435981554	26694	Economy	6200.00
0005433434451	26694	Economy	6800.00
0005435981582	26694	Economy	6800.00
0005432051103	26694	Economy	6800.00
0005433434455	26694	Economy	6200.00
0005435981547	26694	Economy	6200.00
0005433434456	26694	Economy	6200.00
0005433434447	26694	Economy	6200.00
0005433434457	26694	Economy	6200.00
0005433434443	26694	Economy	6200.00
0005435981638	26694	Economy	6200.00
0005433434468	26694	Economy	6200.00
0005433434449	26694	Economy	6200.00
0005433434442	26694	Economy	6200.00
0005435981606	26694	Economy	6200.00
0005435981627	26694	Economy	6200.00
0005433434460	26694	Economy	6200.00
0005432051101	26694	Economy	6200.00
0005433434454	26694	Economy	6200.00
0005434271295	26694	Economy	6200.00
0005433434441	26694	Economy	6200.00
0005435981553	26694	Economy	6200.00
0005435981583	26694	Economy	6200.00
0005435981522	26694	Economy	6200.00
0005433434458	26694	Economy	6200.00
0005432051104	26694	Economy	6200.00
0005435981523	26694	Economy	6200.00
0005433434446	26694	Economy	6200.00
0005433434463	26694	Economy	6200.00
0005435981546	26694	Economy	6200.00
0005433434466	26694	Economy	6200.00
0005433434440	26694	Economy	6200.00
0005435981552	26694	Economy	6200.00
0005434270190	26694	Economy	6200.00
0005434269086	26694	Economy	6200.00
0005435981524	26694	Economy	6200.00
0005433434453	26694	Economy	6200.00
0005435981587	26694	Economy	6200.00
0005435981520	26694	Economy	6200.00
0005434269087	26694	Economy	6200.00
0005435981647	26694	Economy	6200.00
0005433434461	26694	Economy	6200.00
0005433434448	26694	Economy	6200.00
0005433434465	26694	Economy	6200.00
0005432051102	26694	Economy	6200.00
0005433434439	26694	Economy	6200.00
0005433434464	26694	Economy	6200.00
0005433689883	29263	Economy	19100.00
0005433689874	29263	Economy	19100.00
0005433689884	29263	Economy	19100.00
0005433689881	29263	Economy	19100.00
0005433689882	29263	Economy	19100.00
0005433689878	29263	Economy	19100.00
0005433689880	29263	Economy	19100.00
0005433689879	29263	Economy	19100.00
0005433689877	29263	Economy	19100.00
0005432857884	3177	Economy	11100.00
0005432857894	3177	Economy	11100.00
0005432583831	3177	Economy	11100.00
0005432583829	3177	Economy	11100.00
0005432857895	3177	Economy	10100.00
0005432583821	3177	Economy	10100.00
0005432583836	3177	Economy	10100.00
0005432583815	3177	Economy	10100.00
0005432583839	3177	Economy	10100.00
0005432583838	3177	Economy	10100.00
0005432583837	3177	Economy	10100.00
0005432583814	3177	Economy	10100.00
0005432857853	3177	Economy	10100.00
0005432216251	3177	Economy	10100.00
0005432583827	3177	Economy	10100.00
0005432583830	3177	Economy	10100.00
0005432583819	3177	Economy	10100.00
0005432857864	3177	Economy	10100.00
0005432857947	3177	Economy	10100.00
0005432857865	3177	Economy	10100.00
0005432216250	3177	Economy	10100.00
0005432583833	3177	Economy	10100.00
0005432583818	3177	Economy	10100.00
0005432583817	3177	Economy	10100.00
0005432583834	3177	Economy	10100.00
0005432583828	3177	Economy	10100.00
0005432216249	3177	Economy	10100.00
0005432857896	3177	Economy	10100.00
0005432583826	3177	Economy	10100.00
0005432857866	3177	Economy	10100.00
0005432583816	3177	Economy	10100.00
0005432857886	3177	Economy	10100.00
0005432583820	3177	Economy	10100.00
0005432583822	3177	Economy	10100.00
0005432583825	3177	Economy	10100.00
0005432583832	3177	Economy	10100.00
0005432857854	3177	Economy	10100.00
0005432583835	3177	Economy	10100.00
0005432583823	3177	Economy	10100.00
0005432583824	3177	Economy	10100.00
0005432583664	31500	Economy	11100.00
0005432583709	31500	Economy	11100.00
0005432583591	31500	Economy	10100.00
0005432583643	31500	Economy	10100.00
0005432583631	31500	Economy	10100.00
0005432583609	31500	Economy	10100.00
0005432583630	31500	Economy	10100.00
0005432857973	31500	Economy	10100.00
0005432583645	31500	Economy	10100.00
0005432583668	31500	Economy	10100.00
0005432583599	31500	Economy	10100.00
0005432857965	31500	Economy	10100.00
0005432857967	31500	Economy	10100.00
0005432583598	31500	Economy	10100.00
0005432583648	31500	Economy	10100.00
0005432583597	31500	Economy	10100.00
0005432583624	31500	Economy	10100.00
0005432857962	31500	Economy	10100.00
0005432583708	31500	Economy	10100.00
0005432857970	31500	Economy	10100.00
0005432583647	31500	Economy	10100.00
0005432583610	31500	Economy	10100.00
0005432583705	31500	Economy	10100.00
0005432583637	31500	Economy	10100.00
0005432857971	31500	Economy	10100.00
0005432857968	31500	Economy	10100.00
0005432583616	31500	Economy	10100.00
0005432857966	31500	Economy	10100.00
0005432857963	31500	Economy	10100.00
0005432857964	31500	Economy	10100.00
0005432583636	31500	Economy	10100.00
0005432857972	31500	Economy	10100.00
0005432583611	31500	Economy	10100.00
0005432583644	31500	Economy	10100.00
0005432857969	31500	Economy	10100.00
0005432583617	31500	Economy	10100.00
0005432857961	31500	Economy	10100.00
0005432583736	31500	Economy	10100.00
0005434943270	903	Economy	7500.00
0005433255051	903	Economy	7500.00
0005434943276	903	Economy	7500.00
0005434943274	903	Economy	7500.00
0005434943271	903	Economy	7500.00
0005434943273	903	Economy	7500.00
0005434943277	903	Economy	7500.00
0005434943278	903	Economy	7500.00
0005434943272	903	Economy	7500.00
0005434943275	903	Economy	7500.00
0005433255074	16233	Economy	7500.00
0005433255073	16233	Economy	7500.00
0005434943238	16233	Economy	7500.00
0005434943205	16233	Economy	7500.00
0005433255076	16233	Economy	7500.00
0005434943235	16233	Economy	7500.00
0005433255075	16233	Economy	7500.00
0005434943202	16233	Economy	7500.00
0005434943231	16233	Economy	7500.00
0005434943203	16233	Economy	7500.00
0005433255072	16233	Economy	7500.00
0005434943196	16233	Economy	7500.00
0005435652638	21726	Business	9800.00
0005435652627	21726	Business	9800.00
0005435652645	21726	Business	9800.00
0005433367267	21726	Business	9800.00
0005435652642	21726	Business	9800.00
0005433367272	21726	Business	9800.00
0005435652621	21726	Business	9800.00
0005433367302	21726	Business	9800.00
0005433367331	21726	Business	9800.00
0005435652653	21726	Business	9800.00
0005435652632	21726	Business	9800.00
0005435652650	21726	Economy	3300.00
0005435652651	21726	Economy	3300.00
0005433367240	21726	Economy	3300.00
0005435652663	21726	Economy	3300.00
0005435652643	21726	Economy	3300.00
0005435652669	21726	Economy	3300.00
0005435652628	21726	Economy	3300.00
0005435652625	21726	Economy	3300.00
0005435652630	21726	Economy	3300.00
0005435652631	21726	Economy	3600.00
0005435652637	21726	Economy	3600.00
0005433367225	21726	Economy	3600.00
0005435652646	21726	Economy	3600.00
0005435652666	21726	Economy	3600.00
0005433367287	21726	Economy	3300.00
0005433367274	21726	Economy	3300.00
0005435652635	21726	Economy	3300.00
0005435652657	21726	Economy	3300.00
0005435652667	21726	Economy	3300.00
0005435652640	21726	Economy	3300.00
0005433367301	21726	Economy	3300.00
0005433367273	21726	Economy	3300.00
0005435652623	21726	Economy	3300.00
0005435652658	21726	Economy	3300.00
0005435652659	21726	Economy	3300.00
0005433367362	21726	Economy	3300.00
0005433367253	21726	Economy	3300.00
0005435652662	21726	Economy	3300.00
0005435652661	21726	Economy	3300.00
0005433367300	21726	Economy	3300.00
0005435652649	21726	Economy	3300.00
0005435652660	21726	Economy	3300.00
0005433367245	21726	Economy	3300.00
0005435652624	21726	Economy	3300.00
0005433367288	21726	Economy	3300.00
0005433367226	21726	Economy	3300.00
0005433367330	21726	Economy	3300.00
0005433367393	21726	Economy	3300.00
0005435652648	21726	Economy	3300.00
0005433367231	21726	Economy	3300.00
0005435652626	21726	Economy	3300.00
0005433367392	21726	Economy	3300.00
0005435652654	21726	Economy	3300.00
0005435652636	21726	Economy	3300.00
0005433367316	21726	Economy	3300.00
0005435652629	21726	Economy	3300.00
0005433367230	21726	Economy	3300.00
0005433367281	21726	Economy	3300.00
0005435652655	21726	Economy	3300.00
0005435652668	21726	Economy	3300.00
0005435652644	21726	Economy	3300.00
0005435652664	21726	Economy	3300.00
0005435652665	21726	Economy	3300.00
0005435652634	21726	Economy	3300.00
0005433367262	21726	Economy	3300.00
0005435652622	21726	Economy	3300.00
0005435652639	21726	Economy	3300.00
0005435652641	21726	Economy	3300.00
0005435652656	21726	Economy	3300.00
0005435652652	21726	Economy	3300.00
0005435652633	21726	Economy	3300.00
0005433367391	21726	Economy	3300.00
0005433367361	21726	Economy	3300.00
0005435652647	21726	Economy	3300.00
0005433805081	9378	Business	186200.00
0005433763090	9378	Business	186200.00
0005433805106	9378	Business	186200.00
0005433784661	9378	Business	186200.00
0005433805091	9378	Business	186200.00
0005433784651	9378	Business	186200.00
0005433805094	9378	Business	186200.00
0005433763082	9378	Business	186200.00
0005433805113	9378	Business	186200.00
0005433805095	9378	Business	186200.00
0005433784658	9378	Business	186200.00
0005432657425	9378	Business	186200.00
0005433805105	9378	Business	186200.00
0005432657423	9378	Business	186200.00
0005433784625	9378	Business	186200.00
0005433805117	9378	Business	186200.00
0005433784653	9378	Business	186200.00
0005433784635	9378	Business	186200.00
0005433763083	9378	Economy	68300.00
0005433784652	9378	Economy	68300.00
0005432667438	9378	Economy	62100.00
0005434170878	9378	Economy	62100.00
0005433763084	9378	Economy	62100.00
0005433784645	9378	Economy	62100.00
0005434170816	9378	Economy	62100.00
0005433784648	9378	Economy	62100.00
0005433784631	9378	Economy	62100.00
0005433805080	9378	Economy	62100.00
0005433784644	9378	Economy	62100.00
0005433805099	9378	Economy	62100.00
0005433784649	9378	Economy	62100.00
0005433805089	9378	Economy	62100.00
0005433784636	9378	Economy	62100.00
0005433784662	9378	Economy	62100.00
0005433805079	9378	Economy	62100.00
0005433784626	9378	Economy	62100.00
0005433805109	9378	Economy	62100.00
0005432657424	9378	Economy	62100.00
0005433763086	9378	Economy	62100.00
0005434170801	9378	Economy	62100.00
0005434170820	9378	Economy	62100.00
0005433784642	9378	Economy	62100.00
0005434170853	9378	Economy	62100.00
0005433784641	9378	Economy	62100.00
0005435269643	9378	Economy	62100.00
0005433784643	9378	Economy	62100.00
0005433805111	9378	Economy	62100.00
0005433805103	9378	Economy	62100.00
0005433805118	9378	Economy	62100.00
0005433805101	9378	Economy	62100.00
0005433784650	9378	Economy	62100.00
0005433784633	9378	Economy	62100.00
0005432666370	9378	Economy	62100.00
0005433805082	9378	Economy	62100.00
0005433784639	9378	Economy	62100.00
0005433784656	9378	Economy	62100.00
0005432666372	9378	Economy	62100.00
0005434170811	9378	Economy	62100.00
0005433805085	9378	Economy	62100.00
0005433784624	9378	Economy	62100.00
0005433784632	9378	Economy	62100.00
0005433805084	9378	Economy	62100.00
0005433805086	9378	Economy	62100.00
0005434170846	9378	Economy	62100.00
0005433805096	9378	Economy	62100.00
0005433805087	9378	Economy	62100.00
0005432657421	9378	Economy	62100.00
0005434151656	9378	Economy	62100.00
0005433805115	9378	Economy	62100.00
0005433784659	9378	Economy	62100.00
0005433763087	9378	Economy	62100.00
0005432666371	9378	Economy	62100.00
0005433805100	9378	Economy	62100.00
0005433784654	9378	Economy	62100.00
0005433784629	9378	Economy	62100.00
0005433784640	9378	Economy	62100.00
0005433805097	9378	Economy	62100.00
0005433784637	9378	Economy	62100.00
0005433805110	9378	Economy	62100.00
0005435269622	9378	Economy	62100.00
0005433784646	9378	Economy	62100.00
0005433805107	9378	Economy	62100.00
0005433805112	9378	Economy	62100.00
0005433805093	9378	Economy	62100.00
0005435269640	9378	Economy	62100.00
0005433763089	9378	Economy	62100.00
0005433763077	9378	Economy	62100.00
0005433805102	9378	Economy	62100.00
0005433763081	9378	Economy	62100.00
0005433805116	9378	Economy	62100.00
0005432667437	9378	Economy	62100.00
0005433763078	9378	Economy	62100.00
0005435269633	9378	Economy	62100.00
0005433805078	9378	Economy	62100.00
0005433784655	9378	Economy	62100.00
0005433805092	9378	Economy	62100.00
0005435269637	9378	Economy	62100.00
0005433805077	9378	Economy	62100.00
0005434170819	9378	Economy	62100.00
0005433763088	9378	Economy	62100.00
0005433805088	9378	Economy	62100.00
0005435269638	9378	Economy	62100.00
0005433805090	9378	Economy	62100.00
0005433805114	9378	Economy	62100.00
0005434170827	9378	Economy	62100.00
0005433805083	9378	Economy	62100.00
0005433784630	9378	Economy	62100.00
0005433784628	9378	Economy	62100.00
0005432657422	9378	Economy	62100.00
0005433784647	9378	Economy	62100.00
0005433763091	9378	Economy	62100.00
0005434170821	9378	Economy	62100.00
0005433805098	9378	Economy	62100.00
0005433763080	9378	Economy	62100.00
0005433784657	9378	Economy	62100.00
0005434170815	9378	Economy	62100.00
0005433784634	9378	Economy	62100.00
0005433784660	9378	Economy	62100.00
0005433763085	9378	Economy	62100.00
0005433805104	9378	Economy	62100.00
0005433763079	9378	Economy	62100.00
0005433784638	9378	Economy	62100.00
0005433784627	9378	Economy	62100.00
0005433805108	9378	Economy	62100.00
0005434170938	26258	Business	186200.00
0005433762948	26258	Business	186200.00
0005433804828	26258	Business	186200.00
0005435269689	26258	Business	186200.00
0005435269686	26258	Business	186200.00
0005433804793	26258	Business	186200.00
0005433784437	26258	Business	186200.00
0005433784302	26258	Business	186200.00
0005432666358	26258	Business	186200.00
0005434269083	26258	Economy	68300.00
0005433784409	26258	Economy	62100.00
0005433804891	26258	Economy	62100.00
0005433762978	26258	Economy	62100.00
0005433784440	26258	Economy	62100.00
0005433784320	26258	Economy	62100.00
0005433804783	26258	Economy	62100.00
0005434151678	26258	Economy	62100.00
0005433784387	26258	Economy	62100.00
0005434271294	26258	Economy	62100.00
0005433784321	26258	Economy	62100.00
0005433804801	26258	Economy	62100.00
0005433784319	26258	Economy	62100.00
0005433784483	26258	Economy	62100.00
0005434170935	26258	Economy	62100.00
0005433804892	26258	Economy	62100.00
0005433784351	26258	Economy	62100.00
0005434170934	26258	Economy	62100.00
0005434170932	26258	Economy	62100.00
0005434170942	26258	Economy	62100.00
0005433804857	26258	Economy	62100.00
0005434170937	26258	Economy	62100.00
0005435269685	26258	Economy	62100.00
0005433804818	26258	Economy	62100.00
0005433784368	26258	Economy	62100.00
0005435269690	26258	Economy	62100.00
0005433804782	26258	Economy	62100.00
0005434270186	26258	Economy	62100.00
0005433804849	26258	Economy	62100.00
0005433804837	26258	Economy	62100.00
0005433784401	26258	Economy	62100.00
0005434271293	26258	Economy	62100.00
0005433804979	26258	Economy	62100.00
0005433784405	26258	Economy	62100.00
0005434170931	26258	Economy	62100.00
0005433784374	26258	Economy	62100.00
0005435269687	26258	Economy	62100.00
0005434269084	26258	Economy	62100.00
0005433784334	26258	Economy	68300.00
0005434170936	26258	Economy	68300.00
0005434271292	26258	Economy	62100.00
0005434151679	26258	Economy	62100.00
0005435269688	26258	Economy	62100.00
0005433784316	26258	Economy	62100.00
0005433784419	26258	Economy	62100.00
0005434170933	26258	Economy	62100.00
0005433784435	26258	Economy	62100.00
0005432657398	26258	Economy	62100.00
0005433784367	26258	Economy	62100.00
0005434170929	26258	Economy	62100.00
0005434170941	26258	Economy	62100.00
0005433784322	26258	Economy	62100.00
0005434270187	26258	Economy	62100.00
0005433804827	26258	Economy	62100.00
0005432659674	26258	Economy	62100.00
0005433784482	26258	Economy	62100.00
0005433804803	26258	Economy	62100.00
0005435269692	26258	Economy	62100.00
0005434170939	26258	Economy	62100.00
0005433784436	26258	Economy	62100.00
0005434151680	26258	Economy	62100.00
0005433762953	26258	Economy	62100.00
0005433804798	26258	Economy	62100.00
0005435269691	26258	Economy	62100.00
0005432666354	26258	Economy	62100.00
0005433762967	26258	Economy	62100.00
0005433804840	26258	Economy	62100.00
0005433804932	26258	Economy	62100.00
0005434170930	26258	Economy	62100.00
0005434170940	26258	Economy	62100.00
0005433762951	26258	Economy	62100.00
0005432657399	26258	Economy	62100.00
0005434270188	26258	Economy	62100.00
0005435135629	4891	Economy	5900.00
0005435135630	4891	Economy	5300.00
0005435929604	4891	Economy	5300.00
0005435929597	4891	Economy	5300.00
0005435135628	4891	Economy	5300.00
0005435135626	4891	Economy	5300.00
0005435135627	4891	Economy	5300.00
0005435929620	33038	Economy	5300.00
0005435135584	33038	Economy	5300.00
0005435929621	33038	Economy	5300.00
0005435929622	33038	Economy	5300.00
0005435135585	33038	Economy	5300.00
0005434983245	9496	Economy	19700.00
0005434983246	9496	Economy	19700.00
0005434217900	9496	Economy	17900.00
0005434217923	9496	Economy	17900.00
0005434983242	9496	Economy	17900.00
0005434983244	9496	Economy	17900.00
0005434983243	9496	Economy	17900.00
0005434217899	9496	Economy	17900.00
0005434217924	9496	Economy	17900.00
0005434983198	27383	Economy	19700.00
0005434217932	27383	Economy	17900.00
0005434983197	27383	Economy	17900.00
0005434217934	27383	Economy	17900.00
0005434983214	27383	Economy	17900.00
0005434217933	27383	Economy	17900.00
0005434983213	27383	Economy	17900.00
0005434983224	27383	Economy	17900.00
0005434217935	27383	Economy	17900.00
0005433960352	25956	Business	36400.00
0005433985545	25956	Business	36400.00
0005433985554	25956	Business	36400.00
0005433960361	25956	Business	36400.00
0005433960359	25956	Business	36400.00
0005433985541	25956	Business	36400.00
0005433985543	25956	Business	36400.00
0005433985523	25956	Business	36400.00
0005433985551	25956	Business	36400.00
0005433960384	25956	Business	36400.00
0005433985520	25956	Business	36400.00
0005433960358	25956	Business	36400.00
0005433985556	25956	Business	36400.00
0005433960351	25956	Business	36400.00
0005433960348	25956	Business	36400.00
0005433985552	25956	Economy	13400.00
0005433985548	25956	Economy	12100.00
0005433960337	25956	Economy	12100.00
0005433985553	25956	Economy	12100.00
0005433985555	25956	Economy	12100.00
0005433985530	25956	Economy	12100.00
0005433960371	25956	Economy	12100.00
0005433985542	25956	Economy	12100.00
0005433960377	25956	Economy	12100.00
0005433960354	25956	Economy	12100.00
0005433960374	25956	Economy	12100.00
0005433985546	25956	Economy	12100.00
0005433960376	25956	Economy	12100.00
0005433960382	25956	Economy	12100.00
0005433985526	25956	Economy	12100.00
0005433985558	25956	Economy	12100.00
0005433985525	25956	Economy	12100.00
0005433960360	25956	Economy	12100.00
0005433985518	25956	Economy	12100.00
0005433960350	25956	Economy	12100.00
0005433960345	25956	Economy	12100.00
0005433960356	25956	Economy	12100.00
0005433960385	25956	Economy	12100.00
0005433960338	25956	Economy	12100.00
0005433960387	25956	Economy	12100.00
0005433985532	25956	Economy	12100.00
0005433960381	25956	Economy	12100.00
0005433985557	25956	Economy	12100.00
0005433985528	25956	Economy	12100.00
0005433985547	25956	Economy	12100.00
0005433960355	25956	Economy	12100.00
0005433960388	25956	Economy	12100.00
0005433960372	25956	Economy	12100.00
0005433960357	25956	Economy	12100.00
0005433960339	25956	Economy	12100.00
0005433960346	25956	Economy	12100.00
0005433985549	25956	Economy	12100.00
0005433960386	25956	Economy	12100.00
0005433960379	25956	Economy	12100.00
0005433985524	25956	Economy	12100.00
0005433960365	25956	Economy	12100.00
0005433985517	25956	Economy	12100.00
0005433985537	25956	Economy	12100.00
0005433985539	25956	Economy	12100.00
0005433960373	25956	Economy	12100.00
0005433960383	25956	Economy	12100.00
0005433960340	25956	Economy	12100.00
0005433985527	25956	Economy	12100.00
0005433960342	25956	Economy	13400.00
0005433985535	25956	Economy	12100.00
0005433960366	25956	Economy	12100.00
0005433960341	25956	Economy	12100.00
0005433985531	25956	Economy	12100.00
0005433960368	25956	Economy	12100.00
0005433960370	25956	Economy	12100.00
0005433985522	25956	Economy	12100.00
0005433985529	25956	Economy	12100.00
0005433985550	25956	Economy	12100.00
0005433960362	25956	Economy	12100.00
0005433985544	25956	Economy	12100.00
0005433960375	25956	Economy	12100.00
0005433960369	25956	Economy	12100.00
0005433960380	25956	Economy	12100.00
0005433960353	25956	Economy	12100.00
0005433960343	25956	Economy	12100.00
0005433985533	25956	Economy	12100.00
0005433960367	25956	Economy	12100.00
0005433985536	25956	Economy	12100.00
0005433985534	25956	Economy	12100.00
0005433960349	25956	Economy	12100.00
0005433960347	25956	Economy	12100.00
0005433960389	25956	Economy	12100.00
0005433985540	25956	Economy	12100.00
0005433985538	25956	Economy	12100.00
0005433960344	25956	Economy	12100.00
0005433985521	25956	Economy	12100.00
0005433960364	25956	Economy	12100.00
0005433960378	25956	Economy	12100.00
0005433960363	25956	Economy	12100.00
0005433985519	25956	Economy	12100.00
0005434480108	950	Economy	25400.00
0005433165710	950	Economy	25400.00
0005434480122	950	Economy	23100.00
0005434480129	950	Economy	23100.00
0005434480126	950	Economy	23100.00
0005434480125	950	Economy	23100.00
0005434480124	950	Economy	23100.00
0005434480110	950	Economy	23100.00
0005434480111	950	Economy	23100.00
0005434480131	950	Economy	23100.00
0005433165688	950	Economy	23100.00
0005434480119	950	Economy	23100.00
0005434480117	950	Economy	23100.00
0005432269472	950	Economy	23100.00
0005434480112	950	Economy	23100.00
0005434480130	950	Economy	23100.00
0005434480109	950	Economy	23100.00
0005434480113	950	Economy	23100.00
0005434480128	950	Economy	23100.00
0005434480118	950	Economy	23100.00
0005434480116	950	Economy	23100.00
0005434480133	950	Economy	23100.00
0005432269473	950	Economy	23100.00
0005434480132	950	Economy	23100.00
0005434480127	950	Economy	23100.00
0005434480115	950	Economy	23100.00
0005434480121	950	Economy	23100.00
0005434480120	950	Economy	23100.00
0005434480114	950	Economy	23100.00
0005432269471	950	Economy	23100.00
0005434480123	950	Economy	23100.00
0005434479912	16595	Economy	25400.00
0005433165802	16595	Economy	25400.00
0005433165796	16595	Economy	23100.00
0005433165801	16595	Economy	23100.00
0005434480011	16595	Economy	23100.00
0005434479930	16595	Economy	23100.00
0005434479953	16595	Economy	23100.00
0005433165794	16595	Economy	23100.00
0005434479937	16595	Economy	23100.00
0005434479970	16595	Economy	23100.00
0005434479933	16595	Economy	23100.00
0005434480012	16595	Economy	23100.00
0005433165798	16595	Economy	23100.00
0005433165792	16595	Economy	23100.00
0005433165797	16595	Economy	23100.00
0005434479931	16595	Economy	23100.00
0005433165795	16595	Economy	23100.00
0005434479887	16595	Economy	23100.00
0005434479932	16595	Economy	23100.00
0005433165799	16595	Economy	23100.00
0005434479881	16595	Economy	23100.00
0005433165791	16595	Economy	23100.00
0005433165793	16595	Economy	23100.00
0005433165800	16595	Economy	23100.00
0005434479984	16595	Economy	23100.00
0005434479952	16595	Economy	23100.00
0005433872454	3195	Economy	17200.00
0005433872459	3195	Economy	17200.00
0005433872458	3195	Economy	17200.00
0005433872455	3195	Economy	17200.00
0005433872457	3195	Economy	17200.00
0005433872456	3195	Economy	17200.00
0005433872431	32555	Economy	17200.00
0005433872430	32555	Economy	17200.00
0005433872435	32555	Economy	17200.00
0005435386487	10373	Economy	17000.00
0005435149910	10373	Economy	17000.00
0005435142457	10373	Economy	17000.00
0005435142455	10373	Economy	17000.00
0005435149909	10373	Economy	15400.00
0005435142447	10373	Economy	15400.00
0005435142456	10373	Economy	15400.00
0005435149908	10373	Economy	15400.00
0005435142452	10373	Economy	15400.00
0005435142454	10373	Economy	15400.00
0005435142458	10373	Economy	15400.00
0005435149913	10373	Economy	15400.00
0005433289730	10373	Economy	15400.00
0005433289729	10373	Economy	15400.00
0005435149904	10373	Economy	15400.00
0005435149903	10373	Economy	15400.00
0005435149907	10373	Economy	15400.00
0005435149901	10373	Economy	15400.00
0005435149899	10373	Economy	15400.00
0005435149911	10373	Economy	15400.00
0005435149912	10373	Economy	15400.00
0005435142448	10373	Economy	15400.00
0005435142459	10373	Economy	15400.00
0005435149905	10373	Economy	15400.00
0005435149906	10373	Economy	15400.00
0005435142450	10373	Economy	15400.00
0005433289728	10373	Economy	15400.00
0005435386464	10373	Economy	15400.00
0005435149902	10373	Economy	15400.00
0005435142453	10373	Economy	15400.00
0005435142451	10373	Economy	15400.00
0005435149900	10373	Economy	15400.00
0005435142449	10373	Economy	15400.00
0005435149840	21963	Economy	17000.00
0005433289796	21963	Economy	17000.00
0005435386522	21963	Economy	17000.00
0005435142336	21963	Economy	15400.00
0005435149852	21963	Economy	15400.00
0005435386521	21963	Economy	15400.00
0005435149809	21963	Economy	15400.00
0005435386518	21963	Economy	15400.00
0005435386519	21963	Economy	15400.00
0005433289791	21963	Economy	15400.00
0005433289795	21963	Economy	15400.00
0005435386520	21963	Economy	15400.00
0005433289797	21963	Economy	15400.00
0005435142416	21963	Economy	15400.00
0005435149801	21963	Economy	15400.00
0005435149824	21963	Economy	15400.00
0005433289792	21963	Economy	15400.00
0005435149810	21963	Economy	15400.00
0005435142366	21963	Economy	15400.00
0005435142354	21963	Economy	15400.00
0005435142343	21963	Economy	15400.00
0005435386524	21963	Economy	15400.00
0005435386523	21963	Economy	15400.00
0005435149839	21963	Economy	15400.00
0005433289793	21963	Economy	15400.00
0005435142365	21963	Economy	15400.00
0005433289794	21963	Economy	15400.00
0005435149802	21963	Economy	15400.00
0005435149851	21963	Economy	15400.00
0005435149823	21963	Economy	15400.00
0005434573218	11212	Business	57200.00
0005435502003	11212	Business	57200.00
0005435528929	11212	Business	57200.00
0005435528918	11212	Business	57200.00
0005435501997	11212	Business	57200.00
0005435528954	11212	Business	57200.00
0005435319432	11212	Economy	19100.00
0005435501969	11212	Economy	19100.00
0005434573231	11212	Economy	19100.00
0005435501963	11212	Economy	19100.00
0005435502035	11212	Economy	19100.00
0005435501946	11212	Economy	19100.00
0005434573222	11212	Economy	19100.00
0005435528930	11212	Economy	21000.00
0005434573228	11212	Economy	19100.00
0005434573224	11212	Economy	19100.00
0005434573223	11212	Economy	19100.00
0005435528928	11212	Economy	19100.00
0005435528931	11212	Economy	19100.00
0005435319445	11212	Economy	19100.00
0005435545618	11212	Economy	19100.00
0005435501995	11212	Economy	19100.00
0005435319446	11212	Economy	19100.00
0005434573227	11212	Economy	19100.00
0005435545619	11212	Economy	19100.00
0005435502012	11212	Economy	19100.00
0005435528919	11212	Economy	19100.00
0005435501968	11212	Economy	19100.00
0005434573226	11212	Economy	19100.00
0005435528913	11212	Economy	19100.00
0005435528909	11212	Economy	19100.00
0005435528894	11212	Economy	19100.00
0005434573230	11212	Economy	19100.00
0005435501989	11212	Economy	19100.00
0005434573219	11212	Economy	19100.00
0005435502002	11212	Economy	19100.00
0005434573221	11212	Economy	19100.00
0005435528898	11212	Economy	19100.00
0005435501939	11212	Economy	19100.00
0005435501934	11212	Economy	19100.00
0005435501977	11212	Economy	19100.00
0005434573225	11212	Economy	19100.00
0005434573217	11212	Economy	19100.00
0005435319427	11212	Economy	19100.00
0005435501978	11212	Economy	19100.00
0005434573220	11212	Economy	19100.00
0005435501940	11212	Economy	19100.00
0005435319453	11212	Economy	19100.00
0005435501996	11212	Economy	19100.00
0005435502001	11212	Economy	19100.00
0005435502009	11212	Economy	19100.00
0005434573229	11212	Economy	19100.00
0005435502117	20951	Business	57200.00
0005435502115	20951	Business	57200.00
0005435502124	20951	Business	57200.00
0005435502120	20951	Business	57200.00
0005435517759	20951	Business	57200.00
0005435502126	20951	Business	57200.00
0005435502127	20951	Business	57200.00
0005435319510	20951	Business	57200.00
0005435508254	20951	Business	57200.00
0005435319511	20951	Business	57200.00
0005435517763	20951	Economy	19100.00
0005435319512	20951	Economy	19100.00
0005435319513	20951	Economy	19100.00
0005435502121	20951	Economy	19100.00
0005435502119	20951	Economy	19100.00
0005435517752	20951	Economy	19100.00
0005435502122	20951	Economy	19100.00
0005435508263	20951	Economy	19100.00
0005435508258	20951	Economy	19100.00
0005434573141	20951	Economy	21000.00
0005435517751	20951	Economy	21000.00
0005435517756	20951	Economy	21000.00
0005435502112	20951	Economy	21000.00
0005435502113	20951	Economy	19100.00
0005435502116	20951	Economy	19100.00
0005435508251	20951	Economy	19100.00
0005435502130	20951	Economy	19100.00
0005435508264	20951	Economy	19100.00
0005435508250	20951	Economy	19100.00
0005435517762	20951	Economy	19100.00
0005432291908	20951	Economy	19100.00
0005435517764	20951	Economy	19100.00
0005435517758	20951	Economy	19100.00
0005435508252	20951	Economy	19100.00
0005432291909	20951	Economy	19100.00
0005435319507	20951	Economy	19100.00
0005435502125	20951	Economy	19100.00
0005434573168	20951	Economy	19100.00
0005435508253	20951	Economy	19100.00
0005435517754	20951	Economy	19100.00
0005435502118	20951	Economy	19100.00
0005435502129	20951	Economy	19100.00
0005435508265	20951	Economy	19100.00
0005434573164	20951	Economy	19100.00
0005435502123	20951	Economy	19100.00
0005434573130	20951	Economy	19100.00
0005435517760	20951	Economy	19100.00
0005435502108	20951	Economy	19100.00
0005435502111	20951	Economy	19100.00
0005435517757	20951	Economy	19100.00
0005435319509	20951	Economy	19100.00
0005435319506	20951	Economy	19100.00
0005434573183	20951	Economy	19100.00
0005435508261	20951	Economy	19100.00
0005435517753	20951	Economy	19100.00
0005435508260	20951	Economy	19100.00
0005435517749	20951	Economy	19100.00
0005435517755	20951	Economy	19100.00
0005435502109	20951	Economy	19100.00
0005435502110	20951	Economy	19100.00
0005434573175	20951	Economy	19100.00
0005435517765	20951	Economy	19100.00
0005435319508	20951	Economy	19100.00
0005435502131	20951	Economy	19100.00
0005435517750	20951	Economy	19100.00
0005435508262	20951	Economy	19100.00
0005434573116	20951	Economy	19100.00
0005435508257	20951	Economy	19100.00
0005435502128	20951	Economy	19100.00
0005435502114	20951	Economy	19100.00
0005435517761	20951	Economy	19100.00
0005435508255	20951	Economy	19100.00
0005435508259	20951	Economy	19100.00
0005434573163	20951	Economy	19100.00
0005435508256	20951	Economy	19100.00
0005432692562	2962	Business	10300.00
0005432692547	2962	Business	10300.00
0005432692553	2962	Business	10300.00
0005432692579	2962	Economy	3800.00
0005432692528	2962	Economy	3400.00
0005432692561	2962	Economy	3400.00
0005432692572	2962	Economy	3400.00
0005432692566	2962	Economy	3400.00
0005432692555	2962	Economy	3400.00
0005432692567	2962	Economy	3400.00
0005432692554	2962	Economy	3400.00
0005432692535	2962	Economy	3400.00
0005432692580	2962	Economy	3400.00
0005432692644	2962	Economy	3400.00
0005432706552	2961	Business	10300.00
0005433194820	2961	Business	10300.00
0005432880566	2961	Business	10300.00
0005432880595	2961	Business	10300.00
0005432706555	2961	Business	10300.00
0005432706548	2961	Business	10300.00
0005432706544	2961	Business	10300.00
0005432880588	2961	Business	10300.00
0005432880567	2961	Business	10300.00
0005432706561	2961	Economy	3400.00
0005432706566	2961	Economy	3400.00
0005432706545	2961	Economy	3400.00
0005432880590	2961	Economy	3400.00
0005432880599	2961	Economy	3400.00
0005432706567	2961	Economy	3400.00
0005432706558	2961	Economy	3800.00
0005433123589	2961	Economy	3800.00
0005432880587	2961	Economy	3400.00
0005432706568	2961	Economy	3400.00
0005432706553	2961	Economy	3400.00
0005433123651	2961	Economy	3400.00
0005433123613	2961	Economy	3400.00
0005432880576	2961	Economy	3400.00
0005433123612	2961	Economy	3400.00
0005432217752	2961	Economy	3400.00
0005433123642	2961	Economy	3400.00
0005432706549	2961	Economy	3400.00
0005432880563	2961	Economy	3400.00
0005432706562	2961	Economy	3400.00
0005432706564	2961	Economy	3400.00
0005432880560	2961	Economy	3400.00
0005432880561	2961	Economy	3400.00
0005433194819	2961	Economy	3400.00
0005432706546	2961	Economy	3400.00
0005432706551	2961	Economy	3400.00
0005432706560	2961	Economy	3400.00
0005432706554	2961	Economy	3400.00
0005432880562	2961	Economy	3400.00
0005432706559	2961	Economy	3400.00
0005432706547	2961	Economy	3400.00
0005432217751	2961	Economy	3400.00
0005432706556	2961	Economy	3400.00
0005432706563	2961	Economy	3400.00
0005432706543	2961	Economy	3400.00
0005432706550	2961	Economy	3400.00
0005432880589	2961	Economy	3400.00
0005433194818	2961	Economy	3400.00
0005433194825	2961	Economy	3400.00
0005432217753	2961	Economy	3400.00
0005432880598	2961	Economy	3400.00
0005432706565	2961	Economy	3400.00
0005432706557	2961	Economy	3400.00
0005432880692	29950	Business	10300.00
0005432692825	29950	Business	10300.00
0005433123748	29950	Business	10300.00
0005432692835	29950	Business	10300.00
0005433123753	29950	Business	10300.00
0005432880688	29950	Business	10300.00
0005432706432	29950	Business	10300.00
0005433123752	29950	Business	10300.00
0005432706367	29950	Business	10300.00
0005433123750	29950	Business	10300.00
0005433123742	29950	Business	10300.00
0005432706413	29950	Business	10300.00
0005432692837	29950	Economy	3400.00
0005433123739	29950	Economy	3400.00
0005432706388	29950	Economy	3400.00
0005432706368	29950	Economy	3400.00
0005432706393	29950	Economy	3400.00
0005432706351	29950	Economy	3400.00
0005432706308	29950	Economy	3400.00
0005432706324	29950	Economy	3400.00
0005432692823	29950	Economy	3400.00
0005432706365	29950	Economy	3800.00
0005432706357	29950	Economy	3800.00
0005433123743	29950	Economy	3800.00
0005433123759	29950	Economy	3800.00
0005432880687	29950	Economy	3800.00
0005432692842	29950	Economy	3400.00
0005433123757	29950	Economy	3400.00
0005433123747	29950	Economy	3400.00
0005432880698	29950	Economy	3400.00
0005432692812	29950	Economy	3400.00
0005432706447	29950	Economy	3400.00
0005432692836	29950	Economy	3400.00
0005432692838	29950	Economy	3400.00
0005433123744	29950	Economy	3400.00
0005433123755	29950	Economy	3400.00
0005432880689	29950	Economy	3400.00
0005433123751	29950	Economy	3400.00
0005432692822	29950	Economy	3400.00
0005432880690	29950	Economy	3400.00
0005433123758	29950	Economy	3400.00
0005433123738	29950	Economy	3400.00
0005432692831	29950	Economy	3400.00
0005432880700	29950	Economy	3400.00
0005433123741	29950	Economy	3400.00
0005432692816	29950	Economy	3400.00
0005432706430	29950	Economy	3400.00
0005433123746	29950	Economy	3400.00
0005432880699	29950	Economy	3400.00
0005432692820	29950	Economy	3400.00
0005432706342	29950	Economy	3400.00
0005433123740	29950	Economy	3400.00
0005432880696	29950	Economy	3400.00
0005432692815	29950	Economy	3400.00
0005432706386	29950	Economy	3400.00
0005432692827	29950	Economy	3400.00
0005432692818	29950	Economy	3400.00
0005432880695	29950	Economy	3400.00
0005432706437	29950	Economy	3400.00
0005432706353	29950	Economy	3400.00
0005432692828	29950	Economy	3400.00
0005432692826	29950	Economy	3400.00
0005432692833	29950	Economy	3400.00
0005432706448	29950	Economy	3400.00
0005432692841	29950	Economy	3400.00
0005433123749	29950	Economy	3400.00
0005432692819	29950	Economy	3400.00
0005432692821	29950	Economy	3400.00
0005432706325	29950	Economy	3400.00
0005432692824	29950	Economy	3400.00
0005433123754	29950	Economy	3400.00
0005433123737	29950	Economy	3400.00
0005432692839	29950	Economy	3400.00
0005433123756	29950	Economy	3400.00
0005432880693	29950	Economy	3400.00
0005432880697	29950	Economy	3400.00
0005432706345	29950	Economy	3400.00
0005432692840	29950	Economy	3400.00
0005432706431	29950	Economy	3400.00
0005432880691	29950	Economy	3400.00
0005432692811	29950	Economy	3400.00
0005432706343	29950	Economy	3400.00
0005432692830	29950	Economy	3400.00
0005432692829	29950	Economy	3400.00
0005432692832	29950	Economy	3400.00
0005432692814	29950	Economy	3400.00
0005432692813	29950	Economy	3400.00
0005432880686	29950	Economy	3400.00
0005433123745	29950	Economy	3400.00
0005432692834	29950	Economy	3400.00
0005432706372	29950	Economy	3400.00
0005432692817	29950	Economy	3400.00
0005432880694	29950	Economy	3400.00
0005432706310	29950	Economy	3400.00
0005434979516	23699	Economy	4000.00
0005434979514	23699	Economy	4000.00
0005434988633	23699	Economy	3600.00
0005434979520	23699	Economy	3600.00
0005434979500	23699	Economy	3600.00
0005434979517	23699	Economy	3600.00
0005434979525	23699	Economy	3600.00
0005434979510	23699	Economy	3600.00
0005434979519	23699	Economy	3600.00
0005434979501	23699	Economy	3600.00
0005434979526	23699	Economy	3600.00
0005434979506	23699	Economy	3600.00
0005434979511	23699	Economy	3600.00
0005434979522	23699	Economy	3600.00
0005434979513	23699	Economy	3600.00
0005434988637	23699	Economy	3600.00
0005434979503	23699	Economy	3600.00
0005434979528	23699	Economy	3600.00
0005434979524	23699	Economy	3600.00
0005434979515	23699	Economy	3600.00
0005434979521	23699	Economy	3600.00
0005434979499	23699	Economy	3600.00
0005434979505	23699	Economy	3600.00
0005434979502	23699	Economy	3600.00
0005434979504	23699	Economy	3600.00
0005434988634	23699	Economy	3600.00
0005434988636	23699	Economy	3600.00
0005434979498	23699	Economy	3600.00
0005434979509	23699	Economy	3600.00
0005434979512	23699	Economy	3600.00
0005434988635	23699	Economy	3600.00
0005434979523	23699	Economy	3600.00
0005434979518	23699	Economy	3600.00
0005434979527	23699	Economy	3600.00
0005434979508	23699	Economy	3600.00
0005434979507	23699	Economy	3600.00
0005434979320	27562	Economy	4000.00
0005434988564	27562	Economy	3600.00
0005434979322	27562	Economy	3600.00
0005434979280	27562	Economy	3600.00
0005434988560	27562	Economy	3600.00
0005434979302	27562	Economy	3600.00
0005434979338	27562	Economy	3600.00
0005434979265	27562	Economy	3600.00
0005434979341	27562	Economy	3600.00
0005434988561	27562	Economy	3600.00
0005434979367	27562	Economy	3600.00
0005434979282	27562	Economy	3600.00
0005434979278	27562	Economy	3600.00
0005434979252	27562	Economy	3600.00
0005434979295	27562	Economy	3600.00
0005434979321	27562	Economy	3600.00
0005433111467	10265	Economy	19700.00
0005434302419	10265	Economy	19700.00
0005434302418	10265	Economy	19700.00
0005433113495	10265	Economy	19700.00
0005434302420	10265	Economy	19700.00
0005434302393	19641	Economy	19700.00
0005433113517	19641	Economy	19700.00
0005434302391	19641	Economy	19700.00
0005434302392	19641	Economy	19700.00
0005434302388	19641	Economy	19700.00
0005433113518	19641	Economy	19700.00
0005435068679	3557	Business	26900.00
0005435068663	3557	Business	26900.00
0005435068645	3557	Business	26900.00
0005435718895	3557	Business	26900.00
0005435068654	3557	Business	26900.00
0005435068681	3557	Business	26900.00
0005435068666	3557	Business	26900.00
0005435925053	3557	Business	26900.00
0005435068685	3557	Business	26900.00
0005435925047	3557	Business	26900.00
0005435068659	3557	Economy	9000.00
0005435068642	3557	Economy	9000.00
0005435925050	3557	Economy	9000.00
0005435718897	3557	Economy	9000.00
0005435068656	3557	Economy	9000.00
0005435068670	3557	Economy	9000.00
0005435068661	3557	Economy	9000.00
0005435925054	3557	Economy	9900.00
0005435068652	3557	Economy	9900.00
0005435718898	3557	Economy	9000.00
0005435068651	3557	Economy	9000.00
0005435068639	3557	Economy	9000.00
0005435068683	3557	Economy	9000.00
0005435068653	3557	Economy	9000.00
0005435068680	3557	Economy	9000.00
0005435718901	3557	Economy	9000.00
0005435718900	3557	Economy	9000.00
0005435068668	3557	Economy	9000.00
0005435068658	3557	Economy	9000.00
0005435068637	3557	Economy	9000.00
0005435068667	3557	Economy	9000.00
0005435718896	3557	Economy	9000.00
0005435068669	3557	Economy	9000.00
0005435068675	3557	Economy	9000.00
0005435068647	3557	Economy	9000.00
0005435068657	3557	Economy	9000.00
0005435925071	3557	Economy	9000.00
0005435068664	3557	Economy	9000.00
0005435068660	3557	Economy	9000.00
0005435068650	3557	Economy	9000.00
0005435068638	3557	Economy	9000.00
0005435068686	3557	Economy	9000.00
0005435068649	3557	Economy	9000.00
0005435068674	3557	Economy	9000.00
0005435068662	3557	Economy	9000.00
0005435068684	3557	Economy	9000.00
0005435068640	3557	Economy	9000.00
0005435925049	3557	Economy	9000.00
0005435068635	3557	Economy	9000.00
0005435068678	3557	Economy	9000.00
0005435068673	3557	Economy	9000.00
0005435068641	3557	Economy	9000.00
0005435068676	3557	Economy	9000.00
0005435068687	3557	Economy	9000.00
0005435068671	3557	Economy	9000.00
0005435068644	3557	Economy	9000.00
0005435068655	3557	Economy	9000.00
0005435068636	3557	Economy	9000.00
0005435068643	3557	Economy	9000.00
0005435718893	3557	Economy	9000.00
0005435939856	3557	Economy	9000.00
0005435068648	3557	Economy	9000.00
0005435068672	3557	Economy	9000.00
0005435068682	3557	Economy	9000.00
0005435925048	3557	Economy	9000.00
0005435925068	3557	Economy	9000.00
0005435068677	3557	Economy	9000.00
0005435718894	3557	Economy	9000.00
0005435068646	3557	Economy	9000.00
0005435925067	3557	Economy	9000.00
0005435718899	3557	Economy	9000.00
0005435068665	3557	Economy	9000.00
0005435068367	15280	Business	26900.00
0005435925180	15280	Business	26900.00
0005435068188	15280	Business	26900.00
0005435925183	15280	Business	26900.00
0005435068209	15280	Business	26900.00
0005435925182	15280	Business	26900.00
0005435068179	15280	Economy	9000.00
0005435068202	15280	Economy	9000.00
0005435925181	15280	Economy	9000.00
0005435068180	15280	Economy	9000.00
0005435068306	15280	Economy	9000.00
0005435068349	15280	Economy	9000.00
0005435925190	15280	Economy	9000.00
0005435068189	15280	Economy	9000.00
0005435068338	15280	Economy	9900.00
0005435925185	15280	Economy	9900.00
0005435068241	15280	Economy	9000.00
0005435068234	15280	Economy	9000.00
0005435925184	15280	Economy	9000.00
0005435068219	15280	Economy	9000.00
0005435925178	15280	Economy	9000.00
0005435068225	15280	Economy	9000.00
0005435925191	15280	Economy	9000.00
0005435068366	15280	Economy	9000.00
0005435925189	15280	Economy	9000.00
0005435068220	15280	Economy	9000.00
0005435925188	15280	Economy	9000.00
0005435068240	15280	Economy	9000.00
0005435068307	15280	Economy	9000.00
0005435939865	15280	Economy	9000.00
0005435068348	15280	Economy	9000.00
0005435068235	15280	Economy	9000.00
0005435068210	15280	Economy	9000.00
0005435068226	15280	Economy	9000.00
0005435068407	15280	Economy	9000.00
0005435068285	15280	Economy	9000.00
0005435925177	15280	Economy	9000.00
0005435925186	15280	Economy	9000.00
0005435925179	15280	Economy	9000.00
0005435068339	15280	Economy	9000.00
0005435925187	15280	Economy	9000.00
0005435068312	15280	Economy	9000.00
0005435068213	15280	Economy	9000.00
0005435068258	15280	Economy	9000.00
0005435068257	15280	Economy	9000.00
0005435068259	15280	Economy	9000.00
0005432659689	18112	Economy	5900.00
0005432660799	18112	Economy	5900.00
0005432658573	18112	Economy	5900.00
0005432658575	18112	Economy	5900.00
0005432660800	18112	Economy	5900.00
0005432658574	18112	Economy	5900.00
0005432660801	18112	Economy	5900.00
0005432658572	18112	Economy	5900.00
0005433101269	214	Business	20000.00
0005433101251	214	Business	20000.00
0005432901344	214	Business	20000.00
0005433101187	214	Business	20000.00
0005432919547	214	Business	20000.00
0005433101287	214	Business	20000.00
0005432901388	214	Business	20000.00
0005433101182	214	Business	20000.00
0005433101154	214	Business	20000.00
0005433101180	214	Business	20000.00
0005433101274	214	Business	20000.00
0005433101282	214	Economy	7300.00
0005432157476	214	Economy	7300.00
0005432919503	214	Economy	7300.00
0005433101233	214	Economy	6700.00
0005433101217	214	Economy	6700.00
0005433101219	214	Economy	6700.00
0005433101224	214	Economy	6700.00
0005432157477	214	Economy	6700.00
0005433101179	214	Economy	6700.00
0005433101225	214	Economy	6700.00
0005432157475	214	Economy	6700.00
0005433101261	214	Economy	6700.00
0005433101275	214	Economy	6700.00
0005433101248	214	Economy	6700.00
0005433101247	214	Economy	6700.00
0005433101239	214	Economy	6700.00
0005433101183	214	Economy	6700.00
0005433101151	214	Economy	6700.00
0005432901296	214	Economy	6700.00
0005432901362	214	Economy	6700.00
0005432919551	214	Economy	6700.00
0005433101277	214	Economy	6700.00
0005433101178	214	Economy	6700.00
0005432901337	214	Economy	6700.00
0005433101232	214	Economy	7300.00
0005432901360	214	Economy	6700.00
0005433101263	214	Economy	6700.00
0005433101208	214	Economy	6700.00
0005433101176	214	Economy	7300.00
0005432901343	214	Economy	6700.00
0005433101240	214	Economy	6700.00
0005433101175	214	Economy	6700.00
0005433101259	214	Economy	6700.00
0005433101148	214	Economy	6700.00
0005433101215	214	Economy	6700.00
0005433101278	214	Economy	6700.00
0005432919543	214	Economy	6700.00
0005432901359	214	Economy	6700.00
0005433101252	214	Economy	6700.00
0005432919522	214	Economy	6700.00
0005433101258	214	Economy	6700.00
0005433101181	214	Economy	6700.00
0005433101262	214	Economy	6700.00
0005432901328	214	Economy	6700.00
0005433101241	214	Economy	6700.00
0005433101214	214	Economy	6700.00
0005433101190	214	Economy	6700.00
0005432901355	214	Economy	6700.00
0005432901322	214	Economy	6700.00
0005433101165	214	Economy	6700.00
0005432901323	214	Economy	6700.00
0005432919521	214	Economy	6700.00
0005432817212	209	Business	20000.00
0005432207638	209	Business	20000.00
0005432261521	209	Business	20000.00
0005432261540	209	Business	20000.00
0005432261550	209	Business	20000.00
0005432261532	209	Business	20000.00
0005432817240	209	Business	20000.00
0005432261525	209	Business	20000.00
0005432817238	209	Business	20000.00
0005432817236	209	Business	20000.00
0005432261549	209	Economy	7300.00
0005432817230	209	Economy	7300.00
0005432261524	209	Economy	7300.00
0005432817226	209	Economy	7300.00
0005432817219	209	Economy	7300.00
0005432261511	209	Economy	6700.00
0005432817225	209	Economy	6700.00
0005432261543	209	Economy	6700.00
0005432261513	209	Economy	6700.00
0005432817223	209	Economy	6700.00
0005432261539	209	Economy	6700.00
0005432817228	209	Economy	6700.00
0005432817216	209	Economy	6700.00
0005432817222	209	Economy	6700.00
0005434153524	209	Economy	6700.00
0005432261544	209	Economy	6700.00
0005432261527	209	Economy	6700.00
0005432261554	209	Economy	6700.00
0005432817220	209	Economy	6700.00
0005432817218	209	Economy	6700.00
0005432817213	209	Economy	6700.00
0005432288959	209	Economy	6700.00
0005432261541	209	Economy	6700.00
0005432261526	209	Economy	6700.00
0005432817235	209	Economy	6700.00
0005433690892	209	Economy	6700.00
0005433690895	209	Economy	6700.00
0005432261520	209	Economy	6700.00
0005432261508	209	Economy	6700.00
0005432261516	209	Economy	6700.00
0005432261509	209	Economy	6700.00
0005432261545	209	Economy	6700.00
0005432817214	209	Economy	6700.00
0005432261538	209	Economy	6700.00
0005432261514	209	Economy	6700.00
0005432261530	209	Economy	6700.00
0005432261518	209	Economy	6700.00
0005432817224	209	Economy	6700.00
0005432817233	209	Economy	6700.00
0005432261536	209	Economy	7300.00
0005432261533	209	Economy	7300.00
0005432261522	209	Economy	7300.00
0005432207639	209	Economy	6700.00
0005432817215	209	Economy	6700.00
0005432261537	209	Economy	6700.00
0005432261534	209	Economy	6700.00
0005432817231	209	Economy	6700.00
0005433690891	209	Economy	6700.00
0005432817217	209	Economy	6700.00
0005432817227	209	Economy	6700.00
0005432261512	209	Economy	6700.00
0005432261510	209	Economy	6700.00
0005432261519	209	Economy	6700.00
0005432817221	209	Economy	6700.00
0005432261553	209	Economy	6700.00
0005432261529	209	Economy	6700.00
0005432817232	209	Economy	6700.00
0005432753243	209	Economy	6700.00
0005432261515	209	Economy	6700.00
0005432261546	209	Economy	6700.00
0005432288960	209	Economy	6700.00
0005432207640	209	Economy	6700.00
0005432817234	209	Economy	6700.00
0005432753242	209	Economy	6700.00
0005432261517	209	Economy	6700.00
0005432817237	209	Economy	6700.00
0005432261547	209	Economy	6700.00
0005432207637	209	Economy	6700.00
0005432261552	209	Economy	6700.00
0005432817229	209	Economy	6700.00
0005432261551	209	Economy	6700.00
0005432261548	209	Economy	6700.00
0005432261535	209	Economy	6700.00
0005432817239	209	Economy	6700.00
0005432261528	209	Economy	6700.00
0005432261531	209	Economy	6700.00
0005432261523	209	Economy	6700.00
0005433690896	209	Economy	6700.00
0005432261542	209	Economy	6700.00
0005433101722	7960	Business	20000.00
0005433101728	7960	Business	20000.00
0005432020049	7960	Business	20000.00
0005433101689	7960	Business	20000.00
0005433101687	7960	Business	20000.00
0005433101718	7960	Business	20000.00
0005432020037	7960	Business	20000.00
0005433101725	7960	Business	20000.00
0005432020030	7960	Business	20000.00
0005432919689	7960	Business	20000.00
0005433101692	7960	Business	20000.00
0005433101703	7960	Business	20000.00
0005432020044	7960	Business	20000.00
0005433101724	7960	Business	20000.00
0005433101704	7960	Business	20000.00
0005432020043	7960	Business	20000.00
0005432391973	7960	Business	20000.00
0005433101719	7960	Business	20000.00
0005433101709	7960	Business	20000.00
0005433101700	7960	Business	20000.00
0005433101682	7960	Business	20000.00
0005433101705	7960	Business	20000.00
0005432919684	7960	Economy	7300.00
0005433101726	7960	Economy	7300.00
0005432020040	7960	Economy	7300.00
0005432753275	7960	Economy	6700.00
0005432919682	7960	Economy	6700.00
0005433101710	7960	Economy	6700.00
0005432753274	7960	Economy	6700.00
0005432044502	7960	Economy	6700.00
0005433101708	7960	Economy	6700.00
0005432751500	7960	Economy	6700.00
0005433101680	7960	Economy	6700.00
0005432919680	7960	Economy	6700.00
0005433101706	7960	Economy	6700.00
0005433101712	7960	Economy	6700.00
0005432391975	7960	Economy	6700.00
0005432919683	7960	Economy	6700.00
0005433101732	7960	Economy	6700.00
0005433101685	7960	Economy	6700.00
0005433101684	7960	Economy	6700.00
0005433101720	7960	Economy	6700.00
0005432020029	7960	Economy	6700.00
0005433101733	7960	Economy	6700.00
0005432020033	7960	Economy	6700.00
0005433101699	7960	Economy	6700.00
0005432391974	7960	Economy	6700.00
0005432020045	7960	Economy	6700.00
0005432677542	7960	Economy	6700.00
0005433101688	7960	Economy	6700.00
0005432020028	7960	Economy	6700.00
0005433101695	7960	Economy	6700.00
0005432919677	7960	Economy	6700.00
0005432919691	7960	Economy	6700.00
0005432919685	7960	Economy	6700.00
0005433101711	7960	Economy	6700.00
0005432677540	7960	Economy	6700.00
0005433101730	7960	Economy	6700.00
0005432045598	7960	Economy	6700.00
0005433101727	7960	Economy	6700.00
0005432020050	7960	Economy	6700.00
0005432677543	7960	Economy	6700.00
0005433101686	7960	Economy	7300.00
0005432020034	7960	Economy	6700.00
0005433101702	7960	Economy	7300.00
0005433101697	7960	Economy	7300.00
0005432919687	7960	Economy	6700.00
0005433101683	7960	Economy	6700.00
0005432020027	7960	Economy	6700.00
0005432020047	7960	Economy	7300.00
0005432677541	7960	Economy	6700.00
0005432020038	7960	Economy	6700.00
0005433101681	7960	Economy	6700.00
0005432020039	7960	Economy	6700.00
0005433101713	7960	Economy	6700.00
0005433101693	7960	Economy	6700.00
0005432751499	7960	Economy	6700.00
0005432044503	7960	Economy	6700.00
0005432751501	7960	Economy	6700.00
0005432020042	7960	Economy	6700.00
0005433101679	7960	Economy	6700.00
0005432919686	7960	Economy	6700.00
0005432919690	7960	Economy	6700.00
0005432020026	7960	Economy	6700.00
0005432919693	7960	Economy	6700.00
0005432020032	7960	Economy	6700.00
0005433101729	7960	Economy	6700.00
0005433101707	7960	Economy	6700.00
0005432020041	7960	Economy	6700.00
0005433101690	7960	Economy	6700.00
0005433101691	7960	Economy	6700.00
0005433101717	7960	Economy	6700.00
0005432919688	7960	Economy	6700.00
0005432919675	7960	Economy	6700.00
0005432020046	7960	Economy	6700.00
0005433101734	7960	Economy	6700.00
0005433101715	7960	Economy	6700.00
0005433101731	7960	Economy	6700.00
0005432020031	7960	Economy	6700.00
0005433101696	7960	Economy	6700.00
0005432919678	7960	Economy	6700.00
0005432919681	7960	Economy	6700.00
0005433101716	7960	Economy	6700.00
0005432919692	7960	Economy	6700.00
0005432020051	7960	Economy	6700.00
0005432751498	7960	Economy	6700.00
0005433101723	7960	Economy	6700.00
0005433101694	7960	Economy	6700.00
0005432020052	7960	Economy	6700.00
0005432919679	7960	Economy	6700.00
0005433101698	7960	Economy	6700.00
0005432020035	7960	Economy	6700.00
0005432020036	7960	Economy	6700.00
0005432020048	7960	Economy	6700.00
0005432753273	7960	Economy	6700.00
0005433101714	7960	Economy	6700.00
0005432919694	7960	Economy	6700.00
0005432044501	7960	Economy	6700.00
0005433101701	7960	Economy	6700.00
0005432919676	7960	Economy	6700.00
0005433101721	7960	Economy	6700.00
0005432817021	7958	Business	20000.00
0005432816990	7958	Business	20000.00
0005432816988	7958	Business	20000.00
0005432816987	7958	Economy	7300.00
0005432817048	7958	Economy	6700.00
0005432901457	7958	Economy	6700.00
0005432901468	7958	Economy	6700.00
0005432901464	7958	Economy	6700.00
0005432817020	7958	Economy	6700.00
0005432901465	7958	Economy	6700.00
0005432901461	7958	Economy	6700.00
0005432901458	7958	Economy	6700.00
0005432817052	7958	Economy	6700.00
0005432901459	7958	Economy	6700.00
0005432817008	7958	Economy	6700.00
0005432816945	7958	Economy	6700.00
0005432901456	7958	Economy	6700.00
0005432817015	7958	Economy	6700.00
0005432901471	7958	Economy	6700.00
0005432817043	7958	Economy	6700.00
0005432901455	7958	Economy	7300.00
0005432901469	7958	Economy	6700.00
0005432816966	7958	Economy	6700.00
0005432816980	7958	Economy	6700.00
0005432901466	7958	Economy	6700.00
0005432901470	7958	Economy	6700.00
0005432901462	7958	Economy	6700.00
0005432901467	7958	Economy	6700.00
0005432901472	7958	Economy	6700.00
0005432816977	7958	Economy	6700.00
0005432002059	7958	Economy	6700.00
0005432901463	7958	Economy	6700.00
0005432817010	7958	Economy	6700.00
0005432817014	7958	Economy	6700.00
0005432816989	7958	Economy	6700.00
0005432002058	7958	Economy	6700.00
0005432817049	7958	Economy	6700.00
0005432901460	7958	Economy	6700.00
0005432002060	7958	Economy	6700.00
0005434175682	9641	Economy	6900.00
0005434175681	9641	Economy	6900.00
0005434175692	9641	Economy	6900.00
0005434175691	9641	Economy	6900.00
0005434175693	9641	Economy	6900.00
0005434175687	9641	Economy	6900.00
0005433870713	9641	Economy	6900.00
0005433870693	32346	Economy	6900.00
0005434175716	32346	Economy	6900.00
0005434175715	32346	Economy	6900.00
0005433870694	32346	Economy	6900.00
0005434175719	32346	Economy	6900.00
0005434175717	32346	Economy	6900.00
0005434175718	32346	Economy	6900.00
0005435126056	3485	Business	35000.00
0005434426375	3485	Business	35000.00
0005432799237	3485	Business	35000.00
0005434877463	3485	Business	35000.00
0005434426385	3485	Business	35000.00
0005434877521	3485	Business	35000.00
0005434937976	3485	Business	35000.00
0005434877488	3485	Business	35000.00
0005432613827	3485	Business	35000.00
0005434877466	3485	Business	35000.00
0005434937982	3485	Business	35000.00
0005434877455	3485	Business	35000.00
0005434937984	3485	Business	35000.00
0005434877467	3485	Business	35000.00
0005434426358	3485	Business	35000.00
0005432613830	3485	Business	35000.00
0005434937990	3485	Business	35000.00
0005435126040	3485	Business	35000.00
0005434877513	3485	Business	35000.00
0005434937977	3485	Business	35000.00
0005434426377	3485	Business	35000.00
0005434877445	3485	Comfort	19900.00
0005435626028	3485	Business	35000.00
0005434937986	3485	Comfort	19900.00
0005435902420	3485	Comfort	19900.00
0005434877434	3485	Comfort	19900.00
0005435126026	3485	Comfort	19900.00
0005434877447	3485	Comfort	19900.00
0005432799238	3485	Comfort	19900.00
0005432799235	3485	Comfort	19900.00
0005435626037	3485	Comfort	19900.00
0005435126041	3485	Comfort	19900.00
0005434877476	3485	Comfort	19900.00
0005435626026	3485	Comfort	19900.00
0005435626038	3485	Comfort	19900.00
0005434877435	3485	Comfort	19900.00
0005432799214	3485	Comfort	19900.00
0005435626034	3485	Comfort	19900.00
0005435126022	3485	Comfort	19900.00
0005435126029	3485	Comfort	19900.00
0005432799236	3485	Comfort	19900.00
0005435126042	3485	Comfort	19900.00
0005434426360	3485	Comfort	19900.00
0005432799226	3485	Comfort	19900.00
0005434877472	3485	Comfort	19900.00
0005434426381	3485	Comfort	19900.00
0005434426368	3485	Comfort	19900.00
0005434877503	3485	Comfort	19900.00
0005434877479	3485	Comfort	19900.00
0005434877462	3485	Comfort	19900.00
0005434426380	3485	Comfort	19900.00
0005432799241	3485	Economy	11700.00
0005434877436	3485	Economy	11700.00
0005434877504	3485	Economy	11700.00
0005434426384	3485	Economy	11700.00
0005434426378	3485	Economy	11700.00
0005434877461	3485	Economy	11700.00
0005434877510	3485	Economy	11700.00
0005434937972	3485	Economy	11700.00
0005434877442	3485	Economy	11700.00
0005432611676	3485	Economy	11700.00
0005434937989	3485	Economy	11700.00
0005434877508	3485	Economy	11700.00
0005435126045	3485	Economy	11700.00
0005432799228	3485	Economy	11700.00
0005435126033	3485	Economy	11700.00
0005432799242	3485	Economy	11700.00
0005434426366	3485	Economy	11700.00
0005434426365	3485	Economy	11700.00
0005434877450	3485	Economy	11700.00
0005432799221	3485	Economy	11700.00
0005435126039	3485	Economy	11700.00
0005434877481	3485	Economy	11700.00
0005435126057	3485	Economy	11700.00
0005434877433	3485	Economy	11700.00
0005434877498	3485	Economy	11700.00
0005434877457	3485	Economy	11700.00
0005434877501	3485	Economy	11700.00
0005434877452	3485	Economy	11700.00
0005435126053	3485	Economy	11700.00
0005435626032	3485	Economy	11700.00
0005435126032	3485	Economy	11700.00
0005435126037	3485	Economy	11700.00
0005434877458	3485	Economy	11700.00
0005434877465	3485	Economy	11700.00
0005435902433	3485	Economy	11700.00
0005434937978	3485	Economy	11700.00
0005435626039	3485	Economy	11700.00
0005435913849	3485	Economy	11700.00
0005432799213	3485	Economy	11700.00
0005434877456	3485	Economy	11700.00
0005434877459	3485	Economy	11700.00
0005432611677	3485	Economy	11700.00
0005432799215	3485	Economy	11700.00
0005434877490	3485	Economy	11700.00
0005434937979	3485	Economy	11700.00
0005435126035	3485	Economy	11700.00
0005434426371	3485	Economy	11700.00
0005435126063	3485	Economy	11700.00
0005435126047	3485	Economy	11700.00
0005434877429	3485	Economy	11700.00
0005435902443	3485	Economy	11700.00
0005434877437	3485	Economy	11700.00
0005434426383	3485	Economy	11700.00
0005434877499	3485	Economy	11700.00
0005435126031	3485	Economy	11700.00
0005434877438	3485	Economy	11700.00
0005435626029	3485	Economy	11700.00
0005434877471	3485	Economy	12800.00
0005435126052	3485	Economy	11700.00
0005434877446	3485	Economy	11700.00
0005435126025	3485	Economy	12800.00
0005435126023	3485	Economy	12800.00
0005434877486	3485	Economy	11700.00
0005434877432	3485	Economy	11700.00
0005435126054	3485	Economy	11700.00
0005434877514	3485	Economy	11700.00
0005435626023	3485	Economy	11700.00
0005435902390	3485	Economy	11700.00
0005432613828	3485	Economy	11700.00
0005435126034	3485	Economy	11700.00
0005432799220	3485	Economy	11700.00
0005434877441	3485	Economy	11700.00
0005434877475	3485	Economy	11700.00
0005434937985	3485	Economy	11700.00
0005434426362	3485	Economy	11700.00
0005435126038	3485	Economy	11700.00
0005435626031	3485	Economy	11700.00
0005435626035	3485	Economy	11700.00
0005435126059	3485	Economy	11700.00
0005434877502	3485	Economy	11700.00
0005434877460	3485	Economy	11700.00
0005434877487	3485	Economy	11700.00
0005434877477	3485	Economy	11700.00
0005435902469	3485	Economy	11700.00
0005434426379	3485	Economy	11700.00
0005434426372	3485	Economy	11700.00
0005435126055	3485	Economy	11700.00
0005434937987	3485	Economy	11700.00
0005432799230	3485	Economy	11700.00
0005434877469	3485	Economy	11700.00
0005435902442	3485	Economy	11700.00
0005434877443	3485	Economy	11700.00
0005434877430	3485	Economy	11700.00
0005434937983	3485	Economy	11700.00
0005435126060	3485	Economy	11700.00
0005434877495	3485	Economy	11700.00
0005432611679	3485	Economy	11700.00
0005434877497	3485	Economy	11700.00
0005434877505	3485	Economy	11700.00
0005435126050	3485	Economy	11700.00
0005434877494	3485	Economy	11700.00
0005434877454	3485	Economy	11700.00
0005434426359	3485	Economy	11700.00
0005434877439	3485	Economy	11700.00
0005435626033	3485	Economy	11700.00
0005432799223	3485	Economy	11700.00
0005434877451	3485	Economy	11700.00
0005432799227	3485	Economy	11700.00
0005435126049	3485	Economy	11700.00
0005435626024	3485	Economy	11700.00
0005434877468	3485	Economy	11700.00
0005434877509	3485	Economy	11700.00
0005434937974	3485	Economy	11700.00
0005434426367	3485	Economy	11700.00
0005434937981	3485	Economy	11700.00
0005432188581	3485	Economy	11700.00
0005435126036	3485	Economy	11700.00
0005434877511	3485	Economy	11700.00
0005435626030	3485	Economy	11700.00
0005432188582	3485	Economy	11700.00
0005432799233	3485	Economy	11700.00
0005435126030	3485	Economy	11700.00
0005435902444	3485	Economy	11700.00
0005434877489	3485	Economy	11700.00
0005434877480	3485	Economy	11700.00
0005435902419	3485	Economy	11700.00
0005432188580	3485	Economy	11700.00
0005434937975	3485	Economy	11700.00
0005434877449	3485	Economy	11700.00
0005435126028	3485	Economy	11700.00
0005434877493	3485	Economy	11700.00
0005434877482	3485	Economy	11700.00
0005435126027	3485	Economy	12800.00
0005432799224	3485	Economy	12800.00
0005434877470	3485	Economy	12800.00
0005432799222	3485	Economy	12800.00
0005434937973	3485	Economy	11700.00
0005432799217	3485	Economy	11700.00
0005435126061	3485	Economy	11700.00
0005434877491	3485	Economy	11700.00
0005434877506	3485	Economy	11700.00
0005435126046	3485	Economy	11700.00
0005432799232	3485	Economy	11700.00
0005434937991	3485	Economy	11700.00
0005432611678	3485	Economy	11700.00
0005432799240	3485	Economy	11700.00
0005434426357	3485	Economy	11700.00
0005435626025	3485	Economy	11700.00
0005432799231	3485	Economy	11700.00
0005435126062	3485	Economy	11700.00
0005434877428	3485	Economy	11700.00
0005435902432	3485	Economy	11700.00
0005432799229	3485	Economy	11700.00
0005432799216	3485	Economy	11700.00
0005434877440	3485	Economy	11700.00
0005434426374	3485	Economy	11700.00
0005434877500	3485	Economy	11700.00
0005434877431	3485	Economy	11700.00
0005434877484	3485	Economy	11700.00
0005434877520	3485	Economy	11700.00
0005435902434	3485	Economy	11700.00
0005434877517	3485	Economy	11700.00
0005434877496	3485	Economy	11700.00
0005434877507	3485	Economy	11700.00
0005435626027	3485	Economy	11700.00
0005435126044	3485	Economy	11700.00
0005435126024	3485	Economy	11700.00
0005434877519	3485	Economy	11700.00
0005434877453	3485	Economy	11700.00
0005435126048	3485	Economy	11700.00
0005434877483	3485	Economy	11700.00
0005434937988	3485	Economy	11700.00
0005434877444	3485	Economy	11700.00
0005435126051	3485	Economy	11700.00
0005434877474	3485	Economy	11700.00
0005434426369	3485	Economy	11700.00
0005432799225	3485	Economy	11700.00
0005434877522	3485	Economy	11700.00
0005434426363	3485	Economy	11700.00
0005432799239	3485	Economy	11700.00
0005434426364	3485	Economy	11700.00
0005434937980	3485	Economy	11700.00
0005434426361	3485	Economy	11700.00
0005432613829	3485	Economy	11700.00
0005434877512	3485	Economy	11700.00
0005434426370	3485	Economy	11700.00
0005432799219	3485	Economy	11700.00
0005435126043	3485	Economy	11700.00
0005434877464	3485	Economy	11700.00
0005434877448	3485	Economy	11700.00
0005434426376	3485	Economy	11700.00
0005434426373	3485	Economy	11700.00
0005434426356	3485	Economy	11700.00
0005434877492	3485	Economy	11700.00
0005434877515	3485	Economy	11700.00
0005432799234	3485	Economy	11700.00
0005434426382	3485	Economy	11700.00
0005434877485	3485	Economy	11700.00
0005432799218	3485	Economy	11700.00
0005434877473	3485	Economy	11700.00
0005434877518	3485	Economy	11700.00
0005434877516	3485	Economy	11700.00
0005434877478	3485	Economy	11700.00
0005435626036	3485	Economy	11700.00
0005435126058	3485	Economy	11700.00
0005434937911	14585	Business	35000.00
0005435902553	14585	Business	35000.00
0005432798960	14585	Business	35000.00
0005434876981	14585	Business	35000.00
0005435913908	14585	Business	35000.00
0005435125767	14585	Business	35000.00
0005434876799	14585	Business	35000.00
0005434876665	14585	Business	35000.00
0005435125701	14585	Business	35000.00
0005432799039	14585	Business	35000.00
0005432799068	14585	Business	35000.00
0005435625870	14585	Business	35000.00
0005432798955	14585	Business	35000.00
0005435125734	14585	Comfort	19900.00
0005434876727	14585	Comfort	19900.00
0005434426140	14585	Comfort	19900.00
0005434426099	14585	Comfort	19900.00
0005434876790	14585	Comfort	19900.00
0005434937856	14585	Comfort	19900.00
0005432799006	14585	Comfort	19900.00
0005434937860	14585	Comfort	19900.00
0005434876705	14585	Comfort	19900.00
0005434876692	14585	Comfort	19900.00
0005435125688	14585	Comfort	19900.00
0005434876712	14585	Comfort	19900.00
0005434426142	14585	Comfort	19900.00
0005435125768	14585	Comfort	19900.00
0005434876728	14585	Comfort	19900.00
0005432798963	14585	Comfort	19900.00
0005435125694	14585	Comfort	19900.00
0005434937857	14585	Comfort	19900.00
0005432798954	14585	Comfort	19900.00
0005435902562	14585	Comfort	19900.00
0005435902563	14585	Comfort	19900.00
0005434876778	14585	Comfort	19900.00
0005434877029	14585	Comfort	19900.00
0005435125784	14585	Economy	11700.00
0005434426175	14585	Economy	11700.00
0005434876791	14585	Economy	11700.00
0005435125733	14585	Economy	11700.00
0005434426214	14585	Economy	11700.00
0005435902555	14585	Economy	11700.00
0005434876843	14585	Economy	11700.00
0005434937865	14585	Economy	11700.00
0005432607497	14585	Economy	11700.00
0005432799016	14585	Economy	11700.00
0005434877053	14585	Economy	11700.00
0005435125801	14585	Economy	11700.00
0005432799094	14585	Economy	11700.00
0005434876636	14585	Economy	11700.00
0005434937833	14585	Economy	11700.00
0005434426107	14585	Economy	11700.00
0005434876695	14585	Economy	11700.00
0005434876731	14585	Economy	11700.00
0005435902556	14585	Economy	11700.00
0005434876994	14585	Economy	11700.00
0005435625874	14585	Economy	11700.00
0005434876751	14585	Economy	11700.00
0005434876644	14585	Economy	11700.00
0005434876895	14585	Economy	11700.00
0005434426186	14585	Economy	11700.00
0005434876570	14585	Economy	11700.00
0005435625871	14585	Economy	11700.00
0005435125674	14585	Economy	11700.00
0005434876844	14585	Economy	11700.00
0005434876639	14585	Economy	11700.00
0005434876734	14585	Economy	11700.00
0005435902552	14585	Economy	11700.00
0005435125687	14585	Economy	11700.00
0005432799097	14585	Economy	11700.00
0005434426156	14585	Economy	11700.00
0005434426170	14585	Economy	11700.00
0005435902549	14585	Economy	11700.00
0005434876772	14585	Economy	11700.00
0005434877136	14585	Economy	11700.00
0005434876715	14585	Economy	11700.00
0005434876846	14585	Economy	11700.00
0005434876753	14585	Economy	11700.00
0005434876900	14585	Economy	11700.00
0005435125662	14585	Economy	11700.00
0005432607498	14585	Economy	11700.00
0005434876822	14585	Economy	11700.00
0005434426103	14585	Economy	11700.00
0005434876633	14585	Economy	11700.00
0005434877028	14585	Economy	11700.00
0005435902558	14585	Economy	11700.00
0005432799027	14585	Economy	11700.00
0005432799035	14585	Economy	11700.00
0005432611651	14585	Economy	11700.00
0005435902565	14585	Economy	11700.00
0005434876698	14585	Economy	11700.00
0005432799001	14585	Economy	11700.00
0005435902560	14585	Economy	11700.00
0005435125658	14585	Economy	11700.00
0005432799098	14585	Economy	11700.00
0005434876866	14585	Economy	11700.00
0005434426139	14585	Economy	11700.00
0005435902551	14585	Economy	11700.00
0005432798967	14585	Economy	11700.00
0005435902559	14585	Economy	11700.00
0005435902561	14585	Economy	11700.00
0005435913905	14585	Economy	11700.00
0005432059488	14585	Economy	11700.00
0005435913903	14585	Economy	11700.00
0005434876894	14585	Economy	11700.00
0005434937838	14585	Economy	11700.00
0005432798983	14585	Economy	11700.00
0005432611646	14585	Economy	11700.00
0005435914690	14585	Economy	11700.00
0005432611649	14585	Economy	11700.00
0005432799037	14585	Economy	11700.00
0005434876823	14585	Economy	11700.00
0005434876684	14585	Economy	11700.00
0005434426171	14585	Economy	11700.00
0005435902554	14585	Economy	11700.00
0005434426172	14585	Economy	11700.00
0005432059487	14585	Economy	11700.00
0005432798968	14585	Economy	11700.00
0005434876730	14585	Economy	11700.00
0005435125659	14585	Economy	11700.00
0005435913907	14585	Economy	11700.00
0005432611644	14585	Economy	11700.00
0005432798959	14585	Economy	11700.00
0005432798956	14585	Economy	11700.00
0005434876803	14585	Economy	11700.00
0005432799034	14585	Economy	11700.00
0005434876579	14585	Economy	11700.00
0005435625873	14585	Economy	11700.00
0005434426238	14585	Economy	11700.00
0005434426118	14585	Economy	11700.00
0005434937875	14585	Economy	12800.00
0005435625872	14585	Economy	12800.00
0005434876593	14585	Economy	12800.00
0005434876580	14585	Economy	12800.00
0005432798953	14585	Economy	11700.00
0005434876729	14585	Economy	11700.00
0005434876681	14585	Economy	11700.00
0005435914689	14585	Economy	11700.00
0005435902557	14585	Economy	11700.00
0005434937822	14585	Economy	11700.00
0005434876733	14585	Economy	11700.00
0005434876857	14585	Economy	11700.00
0005432798976	14585	Economy	11700.00
0005434876732	14585	Economy	11700.00
0005434877052	14585	Economy	11700.00
0005434876573	14585	Economy	11700.00
0005434426141	14585	Economy	11700.00
0005435125782	14585	Economy	11700.00
0005435125754	14585	Economy	11700.00
0005435125709	14585	Economy	11700.00
0005432799002	14585	Economy	11700.00
0005434876845	14585	Economy	11700.00
0005434877137	14585	Economy	11700.00
0005435625866	14585	Economy	11700.00
0005434876637	14585	Economy	11700.00
0005434876708	14585	Economy	11700.00
0005435625862	14585	Economy	11700.00
0005435125676	14585	Economy	11700.00
0005435125753	14585	Economy	11700.00
0005435625867	14585	Economy	11700.00
0005434426119	14585	Economy	11700.00
0005432799041	14585	Economy	11700.00
0005434426173	14585	Economy	11700.00
0005434937846	14585	Economy	11700.00
0005434876699	14585	Economy	11700.00
0005434876595	14585	Economy	11700.00
0005434876638	14585	Economy	11700.00
0005435125675	14585	Economy	11700.00
0005434876824	14585	Economy	11700.00
0005435913906	14585	Economy	11700.00
0005435125661	14585	Economy	11700.00
0005432798961	14585	Economy	11700.00
0005432798995	14585	Economy	11700.00
0005432799021	14585	Economy	11700.00
0005435125735	14585	Economy	11700.00
0005435125660	14585	Economy	11700.00
0005434426237	14585	Economy	11700.00
0005434876594	14585	Economy	11700.00
0005435902550	14585	Economy	11700.00
0005435913904	14585	Economy	11700.00
0005434937855	14585	Economy	11700.00
0005434876839	14585	Economy	11700.00
0005435125671	14585	Economy	11700.00
0005435902564	14585	Economy	11700.00
0005435125656	14585	Economy	11700.00
0005434876908	14585	Economy	11700.00
0005434937910	14585	Economy	11700.00
0005434876709	14585	Economy	11700.00
0005434876629	14585	Economy	11700.00
0005435125783	14585	Economy	11700.00
0005434325560	3599	Economy	16300.00
0005434312301	3599	Economy	16300.00
0005435889798	3599	Economy	14800.00
0005435889801	3599	Economy	14800.00
0005434325554	3599	Economy	14800.00
0005435889805	3599	Economy	14800.00
0005434312300	3599	Economy	14800.00
0005434325558	3599	Economy	14800.00
0005434325550	3599	Economy	14800.00
0005434325556	3599	Economy	14800.00
0005434325552	3599	Economy	14800.00
0005434312302	3599	Economy	14800.00
0005435889802	3599	Economy	14800.00
0005435889804	3599	Economy	14800.00
0005434325551	3599	Economy	14800.00
0005435889794	3599	Economy	14800.00
0005434325555	3599	Economy	14800.00
0005434325553	3599	Economy	14800.00
0005434325549	3599	Economy	14800.00
0005434325559	3599	Economy	14800.00
0005434325557	3599	Economy	14800.00
0005435889848	15589	Economy	16300.00
0005434325507	15589	Economy	16300.00
0005434325500	15589	Economy	16300.00
0005435889849	15589	Economy	14800.00
0005434325487	15589	Economy	14800.00
0005434325480	15589	Economy	14800.00
0005434325499	15589	Economy	14800.00
0005434325488	15589	Economy	14800.00
0005435889847	15589	Economy	14800.00
0005435889846	15589	Economy	14800.00
0005434325506	15589	Economy	14800.00
0005435889844	15589	Economy	14800.00
0005434325476	15589	Economy	14800.00
0005434325498	15589	Economy	14800.00
0005435889845	15589	Economy	14800.00
0005434325479	15589	Economy	14800.00
0005435957574	620	Economy	4500.00
0005435957582	620	Economy	4100.00
0005435957579	620	Economy	4100.00
0005435957583	620	Economy	4100.00
0005435957575	620	Economy	4100.00
0005435957580	620	Economy	4100.00
0005433420257	620	Economy	4100.00
0005435957581	620	Economy	4100.00
0005435957587	620	Economy	4100.00
0005433420265	620	Economy	4100.00
0005435957578	620	Economy	4100.00
0005435957585	620	Economy	4100.00
0005435957577	620	Economy	4100.00
0005435957586	620	Economy	4100.00
0005435957588	620	Economy	4100.00
0005435957576	620	Economy	4100.00
0005435957584	620	Economy	4100.00
0005435957443	15169	Economy	4500.00
0005433420330	15169	Economy	4100.00
0005435957455	15169	Economy	4100.00
0005435957471	15169	Economy	4100.00
0005435957459	15169	Economy	4100.00
0005433420334	15169	Economy	4100.00
0005433420333	15169	Economy	4100.00
0005435957508	15169	Economy	4100.00
0005433420328	15169	Economy	4100.00
0005435957450	15169	Economy	4100.00
0005433420329	15169	Economy	4100.00
0005433420332	15169	Economy	4100.00
0005435957449	15169	Economy	4100.00
0005435957469	15169	Economy	4100.00
0005433420336	15169	Economy	4100.00
0005433420335	15169	Economy	4100.00
0005435957442	15169	Economy	4100.00
0005435957448	15169	Economy	4100.00
0005433420331	15169	Economy	4100.00
0005435957513	15169	Economy	4100.00
0005435957460	15169	Economy	4100.00
0005434247107	8833	Economy	10400.00
0005434247102	8833	Economy	10400.00
0005434247100	8833	Economy	10400.00
0005434247108	8833	Economy	10400.00
0005434247110	8833	Economy	10400.00
0005434247105	8833	Economy	10400.00
0005434247109	8833	Economy	10400.00
0005434247101	8833	Economy	10400.00
0005434247126	16119	Economy	10400.00
0005435629386	16119	Economy	10400.00
0005435629387	16119	Economy	10400.00
0005435163193	4440	Economy	13400.00
0005435933394	4440	Economy	13400.00
0005435163192	4440	Economy	13400.00
0005435163189	4440	Economy	12200.00
0005435163182	4440	Economy	12200.00
0005435163191	4440	Economy	12200.00
0005435163188	4440	Economy	12200.00
0005435933399	4440	Economy	12200.00
0005435933400	4440	Economy	12200.00
0005435933410	4440	Economy	12200.00
0005435163187	4440	Economy	12200.00
0005435163183	4440	Economy	12200.00
0005435163186	4440	Economy	12200.00
0005435163190	4440	Economy	12200.00
0005435163185	4440	Economy	12200.00
0005435933398	4440	Economy	12200.00
0005435163184	4440	Economy	12200.00
0005435163155	29504	Economy	13400.00
0005435163146	29504	Economy	12200.00
0005435163140	29504	Economy	12200.00
0005435933421	29504	Economy	12200.00
0005435933423	29504	Economy	12200.00
0005435933427	29504	Economy	12200.00
0005435933425	29504	Economy	12200.00
0005435933422	29504	Economy	12200.00
0005435933428	29504	Economy	12200.00
0005435163145	29504	Economy	12200.00
0005435163141	29504	Economy	12200.00
0005435933426	29504	Economy	12200.00
0005435933424	29504	Economy	12200.00
0005435797361	2867	Business	12600.00
0005435797358	2867	Economy	4200.00
0005433404702	2867	Economy	4200.00
0005435797359	2867	Economy	4200.00
0005435797357	2867	Economy	4200.00
0005435797365	2867	Economy	4200.00
0005435797355	2867	Economy	4200.00
0005435797353	2867	Economy	4200.00
0005433404701	2867	Economy	4200.00
0005435797360	2867	Economy	4200.00
0005435797354	2867	Economy	4200.00
0005435797352	2867	Economy	4200.00
0005435797356	2867	Economy	4200.00
0005435797362	2867	Economy	4200.00
0005435797363	2867	Economy	4200.00
0005433404684	2867	Economy	4200.00
0005433404681	2867	Economy	4200.00
0005435797366	2867	Economy	4200.00
0005435797364	2867	Economy	4200.00
0005435797277	29323	Business	12600.00
0005435797234	29323	Business	12600.00
0005435797228	29323	Economy	4200.00
0005433404747	29323	Economy	4200.00
0005435797233	29323	Economy	4200.00
0005435797265	29323	Economy	4200.00
0005433404746	29323	Economy	4200.00
0005435797268	29323	Economy	4200.00
0005433404750	29323	Economy	4200.00
0005435797267	29323	Economy	4200.00
0005435797229	29323	Economy	4200.00
0005433404752	29323	Economy	4200.00
0005435797247	29323	Economy	4200.00
0005433404749	29323	Economy	4200.00
0005433404748	29323	Economy	4200.00
0005433404751	29323	Economy	4200.00
0005435797266	29323	Economy	4200.00
0005435376312	5748	Economy	6800.00
0005434947952	5741	Economy	6800.00
0005434947953	5741	Economy	6800.00
0005434947954	5741	Economy	6800.00
0005434947955	5741	Economy	6800.00
0005434947949	5741	Economy	6800.00
0005434947956	5741	Economy	6800.00
0005434947950	5741	Economy	6800.00
0005434947951	5741	Economy	6800.00
0005434947880	16393	Economy	6800.00
0005434947897	16393	Economy	6800.00
0005435376333	16393	Economy	6800.00
0005435376332	16393	Economy	6800.00
0005434947899	16393	Economy	6800.00
0005435376331	16393	Economy	6800.00
0005434947874	16393	Economy	6800.00
0005434947901	16393	Economy	6800.00
0005434947900	16393	Economy	6800.00
0005435376334	16393	Economy	6800.00
0005433960400	6910	Business	21400.00
0005433960411	6910	Business	21400.00
0005433960440	6910	Business	21400.00
0005433960393	6910	Business	21400.00
0005433960433	6910	Business	21400.00
0005433960424	6910	Business	21400.00
0005433960429	6910	Business	21400.00
0005433960422	6910	Business	21400.00
0005433960435	6910	Economy	7100.00
0005433960406	6910	Economy	7100.00
0005433960405	6910	Economy	7100.00
0005433960436	6910	Economy	7800.00
0005433960430	6910	Economy	7100.00
0005433960416	6910	Economy	7100.00
0005433960391	6910	Economy	7100.00
0005433960441	6910	Economy	7100.00
0005433960423	6910	Economy	7100.00
0005433960414	6910	Economy	7100.00
0005433960396	6910	Economy	7100.00
0005433960439	6910	Economy	7100.00
0005433960401	6910	Economy	7100.00
0005433960407	6910	Economy	7100.00
0005433960427	6910	Economy	7100.00
0005433960425	6910	Economy	7100.00
0005433960438	6910	Economy	7100.00
0005433960442	6910	Economy	7100.00
0005433960390	6910	Economy	7100.00
0005433960403	6910	Economy	7100.00
0005433960428	6910	Economy	7100.00
0005433960432	6910	Economy	7100.00
0005433960418	6910	Economy	7100.00
0005433960412	6910	Economy	7100.00
0005433960408	6910	Economy	7100.00
0005433960434	6910	Economy	7100.00
0005433960413	6910	Economy	7100.00
0005433960421	6910	Economy	7100.00
0005433960397	6910	Economy	7100.00
0005433960420	6910	Economy	7100.00
0005433960410	6910	Economy	7100.00
0005433960437	6910	Economy	7100.00
0005433960419	6910	Economy	7100.00
0005433960404	6910	Economy	7100.00
0005433960431	6910	Economy	7100.00
0005433960415	6910	Economy	7100.00
0005433960399	6910	Economy	7100.00
0005433960417	6910	Economy	7100.00
0005433960395	6910	Economy	7100.00
0005433960409	6910	Economy	7100.00
0005433960426	6910	Economy	7100.00
0005433960394	6910	Economy	7100.00
0005433960402	6910	Economy	7100.00
0005433960392	6910	Economy	7100.00
0005433960398	6910	Economy	7100.00
0005433959868	25808	Business	21400.00
0005433959865	25808	Business	21400.00
0005433959861	25808	Economy	7100.00
0005435082661	24487	Economy	3900.00
0005435082645	24487	Economy	3900.00
0005435082644	24487	Economy	3900.00
0005435082660	24487	Economy	3900.00
0005435082646	24487	Economy	3900.00
0005435082667	24487	Economy	3900.00
0005435082680	24487	Economy	3900.00
0005435082647	24487	Economy	3900.00
0005435082714	26062	Economy	3900.00
0005435082716	26062	Economy	3900.00
0005435082713	26062	Economy	3900.00
0005435082711	26062	Economy	3900.00
0005435082715	26062	Economy	3900.00
0005435082712	26062	Economy	3900.00
0005434244753	5129	Business	18000.00
0005434244726	5129	Business	18000.00
0005434244730	5129	Business	18000.00
0005434244729	5129	Business	18000.00
0005434244737	5129	Business	18000.00
0005433534464	5129	Business	18000.00
0005434244749	5129	Business	18000.00
0005432166875	5129	Economy	6600.00
0005434244732	5129	Economy	6600.00
0005434244743	5129	Economy	6000.00
0005433534468	5129	Economy	6000.00
0005434244747	5129	Economy	6000.00
0005434244738	5129	Economy	6000.00
0005434244735	5129	Economy	6000.00
0005435286549	5129	Economy	6000.00
0005434244748	5129	Economy	6000.00
0005434244733	5129	Economy	6000.00
0005433534465	5129	Economy	6000.00
0005434244752	5129	Economy	6000.00
0005434244739	5129	Economy	6000.00
0005434244741	5129	Economy	6000.00
0005434244744	5129	Economy	6000.00
0005434244728	5129	Economy	6000.00
0005434244751	5129	Economy	6000.00
0005434244740	5129	Economy	6000.00
0005434244746	5129	Economy	6000.00
0005434244734	5129	Economy	6000.00
0005432166874	5129	Economy	6000.00
0005434244745	5129	Economy	6000.00
0005433534466	5129	Economy	6000.00
0005434244742	5129	Economy	6000.00
0005433534467	5129	Economy	6000.00
0005434244736	5129	Economy	6000.00
0005435286550	5129	Economy	6000.00
0005432166873	5129	Economy	6000.00
0005434244731	5129	Economy	6000.00
0005434244750	5129	Economy	6000.00
0005434244727	5129	Economy	6000.00
0005434244725	5129	Economy	6000.00
0005433784658	5130	Business	18000.00
0005433614105	5130	Business	18000.00
0005433784629	5130	Business	18000.00
0005432105200	5130	Business	18000.00
0005432105196	5130	Business	18000.00
0005433614075	5130	Business	18000.00
0005433784648	5130	Business	18000.00
0005432105172	5130	Business	18000.00
0005433614065	5130	Business	18000.00
0005432105163	5130	Business	18000.00
0005433784624	5130	Business	18000.00
0005433784645	5130	Business	18000.00
0005433614134	5130	Business	18000.00
0005433784634	5130	Business	18000.00
0005433614112	5130	Business	18000.00
0005433614132	5130	Business	18000.00
0005433784653	5130	Business	18000.00
0005433784642	5130	Business	18000.00
0005433784655	5130	Business	18000.00
0005433784643	5130	Business	18000.00
0005433784636	5130	Business	18000.00
0005432145094	5130	Business	18000.00
0005432105165	5130	Business	18000.00
0005433784661	5130	Business	18000.00
0005433614083	5130	Business	18000.00
0005433784638	5130	Business	18000.00
0005433784646	5130	Business	18000.00
0005432105168	5130	Economy	6600.00
0005433614068	5130	Economy	6600.00
0005433614102	5130	Economy	6600.00
0005432105194	5130	Economy	6600.00
0005433614109	5130	Economy	6600.00
0005433784650	5130	Economy	6600.00
0005433614078	5130	Economy	6000.00
0005432105190	5130	Economy	6000.00
0005432666372	5130	Economy	6000.00
0005433784641	5130	Economy	6000.00
0005433784630	5130	Economy	6000.00
0005432105167	5130	Economy	6000.00
0005433784662	5130	Economy	6000.00
0005432105174	5130	Economy	6000.00
0005433784647	5130	Economy	6000.00
0005433784659	5130	Economy	6000.00
0005433614098	5130	Economy	6000.00
0005432105153	5130	Economy	6000.00
0005433614099	5130	Economy	6000.00
0005433614107	5130	Economy	6000.00
0005433784632	5130	Economy	6000.00
0005433614129	5130	Economy	6000.00
0005433784631	5130	Economy	6000.00
0005433614091	5130	Economy	6000.00
0005433614067	5130	Economy	6000.00
0005433784651	5130	Economy	6000.00
0005433614093	5130	Economy	6000.00
0005433614073	5130	Economy	6000.00
0005433784637	5130	Economy	6000.00
0005432105191	5130	Economy	6000.00
0005433614119	5130	Economy	6000.00
0005433614114	5130	Economy	6000.00
0005433614115	5130	Economy	6000.00
0005433614111	5130	Economy	6000.00
0005433614061	5130	Economy	6000.00
0005433614066	5130	Economy	6000.00
0005432105187	5130	Economy	6000.00
0005432667437	5130	Economy	6000.00
0005432105186	5130	Economy	6000.00
0005433614104	5130	Economy	6000.00
0005432105175	5130	Economy	6000.00
0005433614079	5130	Economy	6000.00
0005433614103	5130	Economy	6000.00
0005433784625	5130	Economy	6000.00
0005432105171	5130	Economy	6000.00
0005433614092	5130	Economy	6000.00
0005432105158	5130	Economy	6000.00
0005433614100	5130	Economy	6000.00
0005432105156	5130	Economy	6000.00
0005433784626	5130	Economy	6000.00
0005432667438	5130	Economy	6000.00
0005433784639	5130	Economy	6000.00
0005433614121	5130	Economy	6000.00
0005433614116	5130	Economy	6000.00
0005432105185	5130	Economy	6000.00
0005433614128	5130	Economy	6000.00
0005433784635	5130	Economy	6000.00
0005432105193	5130	Economy	6000.00
0005433614133	5130	Economy	6000.00
0005432105183	5130	Economy	6000.00
0005432105180	5130	Economy	6000.00
0005432105157	5130	Economy	6000.00
0005433614071	5130	Economy	6000.00
0005433614117	5130	Economy	6000.00
0005432105197	5130	Economy	6000.00
0005433614097	5130	Economy	6000.00
0005432105169	5130	Economy	6600.00
0005433614122	5130	Economy	6600.00
0005433614125	5130	Economy	6600.00
0005433614072	5130	Economy	6600.00
0005433784656	5130	Economy	6000.00
0005433614062	5130	Economy	6600.00
0005433614069	5130	Economy	6000.00
0005433614081	5130	Economy	6000.00
0005432105184	5130	Economy	6000.00
0005433614085	5130	Economy	6600.00
0005432105154	5130	Economy	6000.00
0005433614094	5130	Economy	6000.00
0005433614084	5130	Economy	6000.00
0005433614113	5130	Economy	6000.00
0005433614126	5130	Economy	6000.00
0005433614088	5130	Economy	6000.00
0005432145095	5130	Economy	6000.00
0005432105170	5130	Economy	6000.00
0005433614101	5130	Economy	6000.00
0005433784627	5130	Economy	6000.00
0005433614108	5130	Economy	6000.00
0005433614087	5130	Economy	6000.00
0005433784640	5130	Economy	6000.00
0005433784649	5130	Economy	6000.00
0005432105195	5130	Economy	6000.00
0005433614130	5130	Economy	6000.00
0005433614080	5130	Economy	6000.00
0005433614070	5130	Economy	6000.00
0005432105181	5130	Economy	6000.00
0005432666370	5130	Economy	6000.00
0005433614064	5130	Economy	6000.00
0005433614076	5130	Economy	6000.00
0005432105160	5130	Economy	6000.00
0005432105192	5130	Economy	6000.00
0005433784628	5130	Economy	6000.00
0005433614063	5130	Economy	6000.00
0005433614089	5130	Economy	6000.00
0005432105159	5130	Economy	6000.00
0005432105162	5130	Economy	6000.00
0005433614095	5130	Economy	6000.00
0005433614077	5130	Economy	6000.00
0005433614086	5130	Economy	6000.00
0005433614118	5130	Economy	6000.00
0005433784657	5130	Economy	6000.00
0005432666371	5130	Economy	6000.00
0005432105199	5130	Economy	6000.00
0005432105189	5130	Economy	6000.00
0005432105179	5130	Economy	6000.00
0005432105188	5130	Economy	6000.00
0005433784644	5130	Economy	6000.00
0005432105177	5130	Economy	6000.00
0005433614131	5130	Economy	6000.00
0005433614124	5130	Economy	6000.00
0005433784652	5130	Economy	6000.00
0005433784633	5130	Economy	6000.00
0005433614127	5130	Economy	6000.00
0005433784660	5130	Economy	6000.00
0005432105176	5130	Economy	6000.00
0005433614074	5130	Economy	6000.00
0005432105173	5130	Economy	6000.00
0005432105182	5130	Economy	6000.00
0005432105178	5130	Economy	6000.00
0005433614106	5130	Economy	6000.00
0005433614123	5130	Economy	6000.00
0005433614096	5130	Economy	6000.00
0005432105155	5130	Economy	6000.00
0005432105166	5130	Economy	6000.00
0005433614060	5130	Economy	6000.00
0005432105161	5130	Economy	6000.00
0005433614082	5130	Economy	6000.00
0005432105164	5130	Economy	6000.00
0005432105198	5130	Economy	6000.00
0005433784654	5130	Economy	6000.00
0005433614120	5130	Economy	6000.00
0005433614090	5130	Economy	6000.00
0005433614110	5130	Economy	6000.00
0005432335865	5132	Business	18000.00
0005434173487	5132	Business	18000.00
0005432335840	5132	Business	18000.00
0005432335866	5132	Business	18000.00
0005434149636	5132	Business	18000.00
0005434229195	5132	Business	18000.00
0005434264930	5132	Business	18000.00
0005434264914	5132	Business	18000.00
0005434229192	5132	Business	18000.00
0005435006680	5132	Business	18000.00
0005432335885	5132	Business	18000.00
0005434264937	5132	Business	18000.00
0005434264934	5132	Business	18000.00
0005434229196	5132	Business	18000.00
0005434229193	5132	Business	18000.00
0005434229177	5132	Business	18000.00
0005435006681	5132	Business	18000.00
0005435006626	5132	Economy	6600.00
0005434149631	5132	Economy	6600.00
0005433815317	5132	Economy	6600.00
0005434264925	5132	Economy	6000.00
0005435006721	5132	Economy	6600.00
0005434264921	5132	Economy	6000.00
0005434229176	5132	Economy	6000.00
0005434229197	5132	Economy	6000.00
0005434264923	5132	Economy	6000.00
0005434229194	5132	Economy	6000.00
0005434229181	5132	Economy	6000.00
0005435006684	5132	Economy	6000.00
0005434264927	5132	Economy	6000.00
0005433815319	5132	Economy	6000.00
0005435006648	5132	Economy	6000.00
0005434149629	5132	Economy	6000.00
0005434229182	5132	Economy	6000.00
0005434264922	5132	Economy	6000.00
0005434229186	5132	Economy	6000.00
0005434149630	5132	Economy	6000.00
0005434264926	5132	Economy	6000.00
0005434264940	5132	Economy	6000.00
0005434264924	5132	Economy	6000.00
0005434229175	5132	Economy	6000.00
0005434149634	5132	Economy	6000.00
0005432335853	5132	Economy	6000.00
0005434173488	5132	Economy	6000.00
0005433688776	5132	Economy	6000.00
0005432335820	5132	Economy	6000.00
0005435006679	5132	Economy	6000.00
0005434264918	5132	Economy	6000.00
0005434229178	5132	Economy	6000.00
0005434229174	5132	Economy	6000.00
0005432335832	5132	Economy	6000.00
0005432335839	5132	Economy	6000.00
0005434264936	5132	Economy	6000.00
0005434264919	5132	Economy	6600.00
0005434149633	5132	Economy	6000.00
0005434229191	5132	Economy	6000.00
0005435006720	5132	Economy	6000.00
0005435006621	5132	Economy	6000.00
0005433815307	5132	Economy	6000.00
0005434229187	5132	Economy	6000.00
0005434264939	5132	Economy	6000.00
0005434229189	5132	Economy	6000.00
0005435006627	5132	Economy	6000.00
0005434149639	5132	Economy	6000.00
0005435006647	5132	Economy	6000.00
0005434149637	5132	Economy	6000.00
0005435006700	5132	Economy	6000.00
0005433815318	5132	Economy	6000.00
0005434229185	5132	Economy	6000.00
0005434149632	5132	Economy	6000.00
0005435006682	5132	Economy	6000.00
0005434264928	5132	Economy	6000.00
0005434264929	5132	Economy	6000.00
0005432335850	5132	Economy	6000.00
0005434264933	5132	Economy	6000.00
0005432335854	5132	Economy	6000.00
0005434229184	5132	Economy	6000.00
0005434149638	5132	Economy	6000.00
0005434264938	5132	Economy	6000.00
0005434264920	5132	Economy	6000.00
0005434149628	5132	Economy	6000.00
0005434264917	5132	Economy	6000.00
0005432335821	5132	Economy	6000.00
0005434229188	5132	Economy	6000.00
0005434173486	5132	Economy	6000.00
0005434264932	5132	Economy	6000.00
0005433815306	5132	Economy	6000.00
0005434264916	5132	Economy	6000.00
0005434264931	5132	Economy	6000.00
0005435006728	5132	Economy	6000.00
0005434264935	5132	Economy	6000.00
0005434229179	5132	Economy	6000.00
0005434149635	5132	Economy	6000.00
0005434173485	5132	Economy	6000.00
0005434229180	5132	Economy	6000.00
0005435006638	5132	Economy	6000.00
0005434229190	5132	Economy	6000.00
0005434229183	5132	Economy	6000.00
0005434264915	5132	Economy	6000.00
0005433784322	8372	Business	18000.00
0005434244554	8372	Business	18000.00
0005434244470	8372	Business	18000.00
0005435269685	8372	Business	18000.00
0005433784316	8372	Business	18000.00
0005433784321	8372	Business	18000.00
0005433784483	8372	Business	18000.00
0005432666354	8372	Economy	6000.00
0005434244603	8372	Economy	6000.00
0005433784437	8372	Economy	6000.00
0005435269687	8372	Economy	6000.00
0005433784405	8372	Economy	6000.00
0005434244508	8372	Economy	6000.00
0005435269686	8372	Economy	6000.00
0005433784419	8372	Economy	6000.00
0005435269691	8372	Economy	6000.00
0005433784440	8372	Economy	6000.00
0005434244500	8372	Economy	6000.00
0005434244471	8372	Economy	6000.00
0005434244501	8372	Economy	6000.00
0005433784401	8372	Economy	6000.00
0005434244564	8372	Economy	6000.00
0005435269690	8372	Economy	6000.00
0005433784435	8372	Economy	6000.00
0005434244601	8372	Economy	6000.00
0005433784319	8372	Economy	6000.00
0005434244472	8372	Economy	6000.00
0005433784367	8372	Economy	6000.00
0005434244597	8372	Economy	6000.00
0005435269692	8372	Economy	6000.00
0005433784482	8372	Economy	6000.00
0005433784436	8372	Economy	6600.00
0005433784374	8372	Economy	6000.00
0005434244509	8372	Economy	6000.00
0005434244543	8372	Economy	6000.00
0005434244493	8372	Economy	6000.00
0005434244487	8372	Economy	6000.00
0005434244542	8372	Economy	6000.00
0005433784302	8372	Economy	6000.00
0005434244574	8372	Economy	6000.00
0005433784409	8372	Economy	6000.00
0005435269689	8372	Economy	6000.00
0005434244643	8372	Economy	6000.00
0005432666358	8372	Economy	6000.00
0005434244577	8372	Economy	6000.00
0005433784368	8372	Economy	6000.00
0005432659674	8372	Economy	6000.00
0005434244497	8372	Economy	6000.00
0005434244602	8372	Economy	6000.00
0005433784351	8372	Economy	6000.00
0005433784320	8372	Economy	6000.00
0005433784334	8372	Economy	6000.00
0005433784387	8372	Economy	6000.00
0005434244469	8372	Economy	6000.00
0005434244575	8372	Economy	6000.00
0005434244576	8372	Economy	6000.00
0005435269688	8372	Economy	6000.00
0005433613392	8371	Business	18000.00
0005433613663	8371	Business	18000.00
0005433613652	8371	Business	18000.00
0005433613519	8371	Economy	6600.00
0005433613660	8371	Economy	6000.00
0005433613505	8371	Economy	6000.00
0005433613437	8371	Economy	6000.00
0005433613567	8371	Economy	6000.00
0005433613523	8371	Economy	6000.00
0005433613664	8371	Economy	6000.00
0005433613562	8371	Economy	6000.00
0005433613460	8371	Economy	6000.00
0005433613454	8371	Economy	6000.00
0005433613395	8371	Economy	6000.00
0005433613546	8371	Economy	6000.00
0005433613522	8371	Economy	6000.00
0005433613405	8371	Economy	6000.00
0005433613566	8371	Economy	6000.00
0005433613448	8371	Economy	6600.00
0005433613633	8371	Economy	6000.00
0005433613518	8371	Economy	6000.00
0005433613561	8371	Economy	6000.00
0005433613653	8371	Economy	6000.00
0005433613503	8371	Economy	6000.00
0005433613412	8371	Economy	6000.00
0005433613393	8371	Economy	6000.00
0005433613447	8371	Economy	6000.00
0005433613413	8371	Economy	6000.00
0005433613455	8371	Economy	6000.00
0005433613394	8371	Economy	6000.00
0005433613662	8371	Economy	6000.00
0005433613545	8371	Economy	6000.00
0005433613710	8371	Economy	6000.00
0005433613406	8371	Economy	6000.00
0005433613535	8371	Economy	6000.00
0005434264794	8370	Business	18000.00
0005432034718	8370	Business	18000.00
0005435286573	8370	Business	18000.00
0005435286570	8370	Business	18000.00
0005432034708	8370	Business	18000.00
0005434264741	8370	Business	18000.00
0005432335933	8370	Business	18000.00
0005432034729	8370	Business	18000.00
0005432335931	8370	Business	18000.00
0005434229035	8370	Business	18000.00
0005432034722	8370	Business	18000.00
0005432335934	8370	Business	18000.00
0005433688794	8370	Business	18000.00
0005435286574	8370	Business	18000.00
0005432335940	8370	Business	18000.00
0005432034707	8370	Business	18000.00
0005434149537	8370	Business	18000.00
0005434229020	8370	Business	18000.00
0005432034730	8370	Business	18000.00
0005434311202	8370	Business	18000.00
0005435006825	8370	Business	18000.00
0005433815350	8370	Business	18000.00
0005435006829	8370	Economy	6600.00
0005434229028	8370	Economy	6600.00
0005434264709	8370	Economy	6000.00
0005434264756	8370	Economy	6000.00
0005432335936	8370	Economy	6000.00
0005434264793	8370	Economy	6000.00
0005432034716	8370	Economy	6000.00
0005432034727	8370	Economy	6000.00
0005432335939	8370	Economy	6000.00
0005432034724	8370	Economy	6000.00
0005432034717	8370	Economy	6000.00
0005434228969	8370	Economy	6000.00
0005434228981	8370	Economy	6000.00
0005435006821	8370	Economy	6000.00
0005435006837	8370	Economy	6000.00
0005435006841	8370	Economy	6000.00
0005435006831	8370	Economy	6000.00
0005432034705	8370	Economy	6000.00
0005433689894	8370	Economy	6000.00
0005435006830	8370	Economy	6000.00
0005432034709	8370	Economy	6000.00
0005434264752	8370	Economy	6000.00
0005434264708	8370	Economy	6000.00
0005434228996	8370	Economy	6000.00
0005434229005	8370	Economy	6000.00
0005435286576	8370	Economy	6000.00
0005434228997	8370	Economy	6000.00
0005432047519	8370	Economy	6000.00
0005434264746	8370	Economy	6000.00
0005433688793	8370	Economy	6000.00
0005435006823	8370	Economy	6000.00
0005435006832	8370	Economy	6000.00
0005432335942	8370	Economy	6000.00
0005432034731	8370	Economy	6000.00
0005432034721	8370	Economy	6000.00
0005434149530	8370	Economy	6000.00
0005432034720	8370	Economy	6000.00
0005433815347	8370	Economy	6000.00
0005435006828	8370	Economy	6000.00
0005434228971	8370	Economy	6000.00
0005432047520	8370	Economy	6000.00
0005435286578	8370	Economy	6000.00
0005435286571	8370	Economy	6000.00
0005435006819	8370	Economy	6000.00
0005434228985	8370	Economy	6000.00
0005434264750	8370	Economy	6000.00
0005432034732	8370	Economy	6000.00
0005433688792	8370	Economy	6000.00
0005434149531	8370	Economy	6000.00
0005434228970	8370	Economy	6000.00
0005435006818	8370	Economy	6000.00
0005435286572	8370	Economy	6600.00
0005432335938	8370	Economy	6600.00
0005432335941	8370	Economy	6600.00
0005432034723	8370	Economy	6600.00
0005432034711	8370	Economy	6600.00
0005432034715	8370	Economy	6000.00
0005433690909	8370	Economy	6000.00
0005434311203	8370	Economy	6000.00
0005433815348	8370	Economy	6000.00
0005433815346	8370	Economy	6600.00
0005434264749	8370	Economy	6000.00
0005435006838	8370	Economy	6000.00
0005434228998	8370	Economy	6000.00
0005432034726	8370	Economy	6000.00
0005434264683	8370	Economy	6000.00
0005435006826	8370	Economy	6000.00
0005435006822	8370	Economy	6000.00
0005434228980	8370	Economy	6000.00
0005432047518	8370	Economy	6000.00
0005434264728	8370	Economy	6000.00
0005433815349	8370	Economy	6000.00
0005432034712	8370	Economy	6000.00
0005432335937	8370	Economy	6000.00
0005432034706	8370	Economy	6000.00
0005432034734	8370	Economy	6000.00
0005434228984	8370	Economy	6000.00
0005432034728	8370	Economy	6000.00
0005435006834	8370	Economy	6000.00
0005432335932	8370	Economy	6000.00
0005432034713	8370	Economy	6000.00
0005434311201	8370	Economy	6000.00
0005434229004	8370	Economy	6000.00
0005432034719	8370	Economy	6000.00
0005435006839	8370	Economy	6000.00
0005435006820	8370	Economy	6000.00
0005432034714	8370	Economy	6000.00
0005432335935	8370	Economy	6000.00
0005435006827	8370	Economy	6000.00
0005433690911	8370	Economy	6000.00
0005435006836	8370	Economy	6000.00
0005433815345	8370	Economy	6000.00
0005435286575	8370	Economy	6000.00
0005434173451	8370	Economy	6000.00
0005434264751	8370	Economy	6000.00
0005432034733	8370	Economy	6000.00
0005435006833	8370	Economy	6000.00
0005433689893	8370	Economy	6000.00
0005435006840	8370	Economy	6000.00
0005434149536	8370	Economy	6000.00
0005435006824	8370	Economy	6000.00
0005433690910	8370	Economy	6000.00
0005435006817	8370	Economy	6000.00
0005434264744	8370	Economy	6000.00
0005432335930	8370	Economy	6000.00
0005435006835	8370	Economy	6000.00
0005434229021	8370	Economy	6000.00
0005434229027	8370	Economy	6000.00
0005434229048	8370	Economy	6000.00
0005434264684	8370	Economy	6000.00
0005432034710	8370	Economy	6000.00
0005433534481	8370	Economy	6000.00
0005432047517	8370	Economy	6000.00
0005432034725	8370	Economy	6000.00
0005434229047	8370	Economy	6000.00
0005435286577	8370	Economy	6000.00
0005434638892	12630	Economy	16200.00
0005433202252	12630	Economy	16200.00
0005433202243	12630	Economy	16200.00
0005433202242	12630	Economy	14800.00
0005434638849	12630	Economy	14800.00
0005433202241	12630	Economy	14800.00
0005433202239	12630	Economy	14800.00
0005434638875	12630	Economy	14800.00
0005433202250	12630	Economy	14800.00
0005434638874	12630	Economy	14800.00
0005433202245	12630	Economy	14800.00
0005433202251	12630	Economy	14800.00
0005434638856	12630	Economy	14800.00
0005433202247	12630	Economy	14800.00
0005433202240	12630	Economy	14800.00
0005433202249	12630	Economy	14800.00
0005434638872	12630	Economy	14800.00
0005434638934	12630	Economy	14800.00
0005433202248	12630	Economy	14800.00
0005434638935	12630	Economy	14800.00
0005434638873	12630	Economy	14800.00
0005434638868	12630	Economy	14800.00
0005433202244	12630	Economy	14800.00
0005434638891	12630	Economy	14800.00
0005434638932	12630	Economy	14800.00
0005434638867	12630	Economy	14800.00
0005434638869	12630	Economy	14800.00
0005433202246	12630	Economy	14800.00
0005434638976	12630	Economy	14800.00
0005434639070	23383	Economy	16200.00
0005433202113	23383	Economy	16200.00
0005434639078	23383	Economy	16200.00
0005434639073	23383	Economy	16200.00
0005433202111	23383	Economy	14800.00
0005434639089	23383	Economy	14800.00
0005434639075	23383	Economy	14800.00
0005434639080	23383	Economy	14800.00
0005434639090	23383	Economy	14800.00
0005433202102	23383	Economy	14800.00
0005434639097	23383	Economy	14800.00
0005434639081	23383	Economy	14800.00
0005434639093	23383	Economy	14800.00
0005434639079	23383	Economy	14800.00
0005434639096	23383	Economy	14800.00
0005434639098	23383	Economy	14800.00
0005434639083	23383	Economy	14800.00
0005434639087	23383	Economy	14800.00
0005434639077	23383	Economy	14800.00
0005432290606	23383	Economy	14800.00
0005432290605	23383	Economy	14800.00
0005434639095	23383	Economy	14800.00
0005433202110	23383	Economy	14800.00
0005434639092	23383	Economy	14800.00
0005434639071	23383	Economy	14800.00
0005434639086	23383	Economy	14800.00
0005434639088	23383	Economy	14800.00
0005433202139	23383	Economy	14800.00
0005434639084	23383	Economy	14800.00
0005434639072	23383	Economy	14800.00
0005434639074	23383	Economy	14800.00
0005434639082	23383	Economy	14800.00
0005434639094	23383	Economy	14800.00
0005434639091	23383	Economy	14800.00
0005434639085	23383	Economy	14800.00
0005433202140	23383	Economy	14800.00
0005434639076	23383	Economy	14800.00
0005432382550	21109	Business	18900.00
0005432382765	21109	Business	18900.00
0005432327949	21109	Business	18900.00
0005432327892	21109	Business	18900.00
0005432054279	21109	Business	18900.00
0005432327954	21109	Business	18900.00
0005432328027	21109	Business	18900.00
0005432328028	21109	Economy	6300.00
0005432328133	21109	Economy	6300.00
0005432054281	21109	Economy	6300.00
0005432327982	21109	Economy	6300.00
0005432382667	21109	Economy	6900.00
0005432327910	21109	Economy	6900.00
0005432382530	21109	Economy	6900.00
0005432382599	21109	Economy	6300.00
0005432382612	21109	Economy	6300.00
0005432327894	21109	Economy	6300.00
0005432382764	21109	Economy	6300.00
0005432327955	21109	Economy	6300.00
0005432382485	21109	Economy	6300.00
0005432382585	21109	Economy	6300.00
0005432327891	21109	Economy	6300.00
0005432327913	21109	Economy	6300.00
0005432327981	21109	Economy	6300.00
0005432382539	21109	Economy	6300.00
0005432382766	21109	Economy	6300.00
0005432328079	21109	Economy	6300.00
0005432382551	21109	Economy	6300.00
0005432328109	21109	Economy	6300.00
0005432382486	21109	Economy	6300.00
0005432382537	21109	Economy	6300.00
0005432382567	21109	Economy	6300.00
0005432382560	21109	Economy	6300.00
0005432382522	21109	Economy	6300.00
0005432327946	21109	Economy	6300.00
0005432327912	21109	Economy	6300.00
0005432382538	21109	Economy	6300.00
0005432382549	21109	Economy	6300.00
0005432382593	21109	Economy	6300.00
0005432382529	21109	Economy	6300.00
0005432327903	21109	Economy	6300.00
0005432327980	21109	Economy	6300.00
0005432382668	21109	Economy	6300.00
0005432327893	21109	Economy	6300.00
0005432382594	21109	Economy	6300.00
0005432054280	21109	Economy	6300.00
0005432328308	31232	Business	18900.00
0005432328275	31232	Business	18900.00
0005432328284	31232	Business	18900.00
0005432382822	31232	Business	18900.00
0005432382843	31232	Business	18900.00
0005432382838	31232	Business	18900.00
0005432328266	31232	Business	18900.00
0005432328303	31232	Business	18900.00
0005432382813	31232	Business	18900.00
0005432382815	31232	Business	18900.00
0005432328287	31232	Business	18900.00
0005432328307	31232	Business	18900.00
0005432382827	31232	Economy	6300.00
0005432382828	31232	Economy	6300.00
0005432328298	31232	Economy	6300.00
0005432382807	31232	Economy	6300.00
0005432382821	31232	Economy	6300.00
0005432328310	31232	Economy	6300.00
0005432382818	31232	Economy	6300.00
0005432382831	31232	Economy	6300.00
0005432328292	31232	Economy	6300.00
0005432287145	31232	Economy	6900.00
0005432328274	31232	Economy	6900.00
0005432287144	31232	Economy	6900.00
0005432328268	31232	Economy	6900.00
0005432382808	31232	Economy	6900.00
0005432328277	31232	Economy	6300.00
0005432382834	31232	Economy	6300.00
0005432328270	31232	Economy	6300.00
0005432382811	31232	Economy	6300.00
0005432382820	31232	Economy	6300.00
0005432328285	31232	Economy	6300.00
0005432287143	31232	Economy	6300.00
0005432382805	31232	Economy	6300.00
0005432328290	31232	Economy	6300.00
0005432328282	31232	Economy	6300.00
0005432382830	31232	Economy	6300.00
0005432328279	31232	Economy	6300.00
0005432287142	31232	Economy	6300.00
0005432328267	31232	Economy	6300.00
0005432382812	31232	Economy	6300.00
0005432328300	31232	Economy	6300.00
0005432382841	31232	Economy	6300.00
0005432382810	31232	Economy	6300.00
0005432382817	31232	Economy	6300.00
0005432328297	31232	Economy	6300.00
0005432328286	31232	Economy	6300.00
0005432382836	31232	Economy	6300.00
0005432382804	31232	Economy	6300.00
0005432328278	31232	Economy	6300.00
0005432328291	31232	Economy	6300.00
0005432328302	31232	Economy	6300.00
0005432328280	31232	Economy	6300.00
0005432382837	31232	Economy	6300.00
0005432328293	31232	Economy	6300.00
0005432328276	31232	Economy	6300.00
0005432382823	31232	Economy	6300.00
0005432328304	31232	Economy	6300.00
0005432382840	31232	Economy	6300.00
0005432328272	31232	Economy	6300.00
0005432382806	31232	Economy	6300.00
0005432328273	31232	Economy	6300.00
0005432382814	31232	Economy	6300.00
0005432382839	31232	Economy	6300.00
0005432328269	31232	Economy	6300.00
0005432328295	31232	Economy	6300.00
0005432328299	31232	Economy	6300.00
0005432382809	31232	Economy	6300.00
0005432328271	31232	Economy	6300.00
0005432328306	31232	Economy	6300.00
0005432382819	31232	Economy	6300.00
0005432382833	31232	Economy	6300.00
0005432328294	31232	Economy	6300.00
0005432328312	31232	Economy	6300.00
0005432382842	31232	Economy	6300.00
0005432382832	31232	Economy	6300.00
0005432382829	31232	Economy	6300.00
0005432328296	31232	Economy	6300.00
0005432328305	31232	Economy	6300.00
0005432382835	31232	Economy	6300.00
0005432328311	31232	Economy	6300.00
0005432328288	31232	Economy	6300.00
0005432328281	31232	Economy	6300.00
0005432328283	31232	Economy	6300.00
0005432328289	31232	Economy	6300.00
0005432382826	31232	Economy	6300.00
0005432287141	31232	Economy	6300.00
0005432328309	31232	Economy	6300.00
0005432382824	31232	Economy	6300.00
0005432382825	31232	Economy	6300.00
0005432382816	31232	Economy	6300.00
0005432328301	31232	Economy	6300.00
0005433642224	2487	Business	89600.00
0005433642216	2487	Business	89600.00
0005433642215	2487	Economy	29900.00
0005433642214	2487	Economy	29900.00
0005433642228	2487	Economy	29900.00
0005433642209	2487	Economy	29900.00
0005432953790	2487	Economy	32800.00
0005433642199	2487	Economy	32800.00
0005433642207	2487	Economy	32800.00
0005433642202	2487	Economy	29900.00
0005433642208	2487	Economy	29900.00
0005433642203	2487	Economy	29900.00
0005433642220	2487	Economy	29900.00
0005433642204	2487	Economy	29900.00
0005433642198	2487	Economy	29900.00
0005432953805	2487	Economy	29900.00
0005433642211	2487	Economy	29900.00
0005432953803	2487	Economy	29900.00
0005433642210	2487	Economy	29900.00
0005433642222	2487	Economy	29900.00
0005433642227	2487	Economy	29900.00
0005433642200	2487	Economy	29900.00
0005433642205	2487	Economy	29900.00
0005433642223	2487	Economy	29900.00
0005433642226	2487	Economy	29900.00
0005433642196	2487	Economy	29900.00
0005433642197	2487	Economy	29900.00
0005433642225	2487	Economy	29900.00
0005433642206	2487	Economy	29900.00
0005433642212	2487	Economy	29900.00
0005433642213	2487	Economy	29900.00
0005433642221	2487	Economy	29900.00
0005433642217	2487	Economy	29900.00
0005432953804	2487	Economy	29900.00
0005432953786	2487	Economy	29900.00
0005433642218	2487	Economy	29900.00
0005433642219	2487	Economy	29900.00
0005433642201	2487	Economy	29900.00
0005432953797	2487	Economy	29900.00
0005432953848	27584	Business	89600.00
0005432953870	27584	Business	89600.00
0005433642097	27584	Business	89600.00
0005432953857	27584	Business	89600.00
0005433642081	27584	Business	89600.00
0005433642129	27584	Economy	29900.00
0005432953867	27584	Economy	29900.00
0005432953850	27584	Economy	29900.00
0005433642130	27584	Economy	32800.00
0005433642125	27584	Economy	32800.00
0005432953866	27584	Economy	29900.00
0005432953858	27584	Economy	29900.00
0005433642085	27584	Economy	29900.00
0005432953864	27584	Economy	29900.00
0005432953854	27584	Economy	29900.00
0005432953849	27584	Economy	29900.00
0005432953852	27584	Economy	29900.00
0005432953846	27584	Economy	29900.00
0005433642073	27584	Economy	29900.00
0005432953871	27584	Economy	29900.00
0005433642114	27584	Economy	29900.00
0005432953855	27584	Economy	29900.00
0005432953860	27584	Economy	29900.00
0005433642105	27584	Economy	29900.00
0005432953861	27584	Economy	29900.00
0005433642115	27584	Economy	29900.00
0005432953859	27584	Economy	29900.00
0005433642098	27584	Economy	29900.00
0005432953869	27584	Economy	29900.00
0005432953872	27584	Economy	29900.00
0005433642077	27584	Economy	29900.00
0005432953862	27584	Economy	29900.00
0005432953856	27584	Economy	29900.00
0005433642112	27584	Economy	29900.00
0005433642076	27584	Economy	29900.00
0005433642086	27584	Economy	29900.00
0005432953865	27584	Economy	29900.00
0005432953853	27584	Economy	29900.00
0005432953851	27584	Economy	29900.00
0005432953863	27584	Economy	29900.00
0005432953847	27584	Economy	29900.00
0005432953868	27584	Economy	29900.00
0005433642113	27584	Economy	29900.00
0005433642111	27584	Economy	29900.00
0005432424025	13365	Business	12700.00
0005432424024	13365	Business	12700.00
0005432424001	13365	Business	12700.00
0005432424044	13365	Business	12700.00
0005432424052	13365	Business	12700.00
0005432424048	13365	Business	12700.00
0005432424050	13365	Business	12700.00
0005432424000	13365	Business	12700.00
0005432424006	13365	Business	12700.00
0005432424034	13365	Business	12700.00
0005432424005	13365	Economy	4200.00
0005432424011	13365	Economy	4200.00
0005432424043	13365	Economy	4200.00
0005432424054	13365	Economy	4200.00
0005432424016	13365	Economy	4200.00
0005432424038	13365	Economy	4700.00
0005432424009	13365	Economy	4700.00
0005432424046	13365	Economy	4700.00
0005432424055	13365	Economy	4200.00
0005432424027	13365	Economy	4200.00
0005432424049	13365	Economy	4200.00
0005432424031	13365	Economy	4200.00
0005432424035	13365	Economy	4200.00
0005432424017	13365	Economy	4200.00
0005432424022	13365	Economy	4200.00
0005432424002	13365	Economy	4200.00
0005432424013	13365	Economy	4200.00
0005432424014	13365	Economy	4200.00
0005432424003	13365	Economy	4200.00
0005432424045	13365	Economy	4200.00
0005432424018	13365	Economy	4200.00
0005432424041	13365	Economy	4200.00
0005432424023	13365	Economy	4200.00
0005432424037	13365	Economy	4200.00
0005432424019	13365	Economy	4200.00
0005432424030	13365	Economy	4200.00
0005432424039	13365	Economy	4200.00
0005432424056	13365	Economy	4200.00
0005432424032	13365	Economy	4200.00
0005432424008	13365	Economy	4200.00
0005432424012	13365	Economy	4200.00
0005432424036	13365	Economy	4200.00
0005432424020	13365	Economy	4200.00
0005432424021	13365	Economy	4200.00
0005432424004	13365	Economy	4200.00
0005432424026	13365	Economy	4200.00
0005432424015	13365	Economy	4200.00
0005432424057	13365	Economy	4200.00
0005432424007	13365	Economy	4200.00
0005432424033	13365	Economy	4200.00
0005432424028	13365	Economy	4200.00
0005432424040	13365	Economy	4200.00
0005432424042	13365	Economy	4200.00
0005432424029	13365	Economy	4200.00
0005432424010	13365	Economy	4200.00
0005432424047	13365	Economy	4200.00
0005432424053	13365	Economy	4200.00
0005432424051	13365	Economy	4200.00
0005432423615	30804	Business	12700.00
0005432423664	30804	Economy	4200.00
0005432423620	30804	Economy	4200.00
0005432423665	30804	Economy	4200.00
0005432423645	30804	Economy	4200.00
0005432423646	30804	Economy	4200.00
0005432423604	30804	Economy	4200.00
0005432423635	30804	Economy	4200.00
0005432423606	30804	Economy	4200.00
0005432423640	30804	Economy	4200.00
0005432423616	30804	Economy	4200.00
0005432423654	30804	Economy	4200.00
0005432423644	30804	Economy	4200.00
0005432423619	30804	Economy	4200.00
0005434157349	9609	Business	32600.00
0005432817232	9609	Business	32600.00
0005434157348	9609	Business	32600.00
0005432817213	9609	Business	32600.00
0005434448288	9609	Business	32600.00
0005432901336	9609	Business	32600.00
0005434448289	9609	Economy	10900.00
0005432817226	9609	Economy	10900.00
0005432822139	9609	Economy	10900.00
0005432817233	9609	Economy	10900.00
0005432817235	9609	Economy	10900.00
0005432822137	9609	Economy	10900.00
0005432822138	9609	Economy	10900.00
0005432901428	9609	Economy	11900.00
0005432822142	9609	Economy	11900.00
0005434157359	9609	Economy	11900.00
0005432817225	9609	Economy	11900.00
0005432822136	9609	Economy	10900.00
0005432901345	9609	Economy	10900.00
0005432817239	9609	Economy	10900.00
0005434448287	9609	Economy	10900.00
0005432901329	9609	Economy	10900.00
0005434157356	9609	Economy	10900.00
0005432901318	9609	Economy	10900.00
0005432901427	9609	Economy	10900.00
0005432822140	9609	Economy	10900.00
0005432817228	9609	Economy	10900.00
0005432817231	9609	Economy	10900.00
0005432817224	9609	Economy	10900.00
0005432288960	9609	Economy	10900.00
0005432817222	9609	Economy	10900.00
0005432817212	9609	Economy	10900.00
0005432817237	9609	Economy	10900.00
0005434157350	9609	Economy	10900.00
0005434157368	9609	Economy	10900.00
0005432817217	9609	Economy	10900.00
0005432901326	9609	Economy	10900.00
0005432288959	9609	Economy	10900.00
0005432817240	9609	Economy	10900.00
0005434157386	9609	Economy	10900.00
0005432817215	9609	Economy	10900.00
0005432817236	9609	Economy	10900.00
0005432901378	9609	Economy	10900.00
0005432817227	9609	Economy	10900.00
0005432822135	9609	Economy	10900.00
0005432817214	9609	Economy	10900.00
0005432817219	9609	Economy	10900.00
0005432817220	9609	Economy	10900.00
0005432901354	9609	Economy	10900.00
0005432817223	9609	Economy	10900.00
0005432817218	9609	Economy	10900.00
0005432822141	9609	Economy	10900.00
0005432901297	9609	Economy	10900.00
0005432817229	9609	Economy	10900.00
0005432901303	9609	Economy	10900.00
0005432817216	9609	Economy	10900.00
0005432817230	9609	Economy	10900.00
0005432817234	9609	Economy	10900.00
0005434448285	9609	Economy	10900.00
0005432817238	9609	Economy	10900.00
0005432901304	9609	Economy	10900.00
0005434448286	9609	Economy	10900.00
0005432817221	9609	Economy	10900.00
0005432901471	29010	Business	32600.00
0005432817020	29010	Business	32600.00
0005432816988	29010	Business	32600.00
0005432816966	29010	Business	32600.00
0005432002060	29010	Business	32600.00
0005432002058	29010	Business	32600.00
0005432901467	29010	Business	32600.00
0005432901469	29010	Business	32600.00
0005432817049	29010	Economy	10900.00
0005434448258	29010	Economy	10900.00
0005432817008	29010	Economy	10900.00
0005432817048	29010	Economy	10900.00
0005432901459	29010	Economy	10900.00
0005432816987	29010	Economy	10900.00
0005432816945	29010	Economy	10900.00
0005434157415	29010	Economy	11900.00
0005432817021	29010	Economy	11900.00
0005432901455	29010	Economy	10900.00
0005434157417	29010	Economy	10900.00
0005432901460	29010	Economy	10900.00
0005434157412	29010	Economy	10900.00
0005432002059	29010	Economy	10900.00
0005432901472	29010	Economy	10900.00
0005432817010	29010	Economy	10900.00
0005434448262	29010	Economy	10900.00
0005434186172	29010	Economy	10900.00
0005432816989	29010	Economy	10900.00
0005432817043	29010	Economy	10900.00
0005432901464	29010	Economy	10900.00
0005432816990	29010	Economy	10900.00
0005432817014	29010	Economy	10900.00
0005432817052	29010	Economy	10900.00
0005434448264	29010	Economy	10900.00
0005432901462	29010	Economy	10900.00
0005434448263	29010	Economy	10900.00
0005432822070	29010	Economy	10900.00
0005432901466	29010	Economy	10900.00
0005432901470	29010	Economy	10900.00
0005432901456	29010	Economy	10900.00
0005432901468	29010	Economy	10900.00
0005432901463	29010	Economy	10900.00
0005432901457	29010	Economy	10900.00
0005432816980	29010	Economy	10900.00
0005432901458	29010	Economy	10900.00
0005432901461	29010	Economy	10900.00
0005432901465	29010	Economy	10900.00
0005432816977	29010	Economy	10900.00
0005434186174	29010	Economy	10900.00
0005432817015	29010	Economy	10900.00
0005434157414	29010	Economy	10900.00
0005434157413	29010	Economy	10900.00
0005434157416	29010	Economy	10900.00
0005434157418	29010	Economy	10900.00
0005434186173	29010	Economy	10900.00
0005432611679	15133	Economy	11000.00
0005432611678	15133	Economy	11000.00
0005432611677	15133	Economy	11000.00
0005432611676	15133	Economy	11000.00
0005432613828	15133	Economy	11000.00
0005432613829	15133	Economy	11000.00
0005432613827	15133	Economy	11000.00
0005432613830	15133	Economy	11000.00
0005432611646	31630	Economy	11000.00
0005432611651	31630	Economy	11000.00
0005432611644	31630	Economy	11000.00
0005432607497	31630	Economy	11000.00
0005432611649	31630	Economy	11000.00
0005432607498	31630	Economy	11000.00
0005433568511	11879	Business	105900.00
0005432947783	11879	Business	105900.00
0005433568533	11879	Business	105900.00
0005433568538	11879	Business	105900.00
0005433568493	11879	Business	105900.00
0005433568504	11879	Business	105900.00
0005432947840	11879	Business	105900.00
0005433568534	11879	Business	105900.00
0005432947793	11879	Business	105900.00
0005433568491	11879	Business	105900.00
0005433568529	11879	Business	105900.00
0005433568535	11879	Business	105900.00
0005433568516	11879	Business	105900.00
0005433568536	11879	Economy	35300.00
0005433568507	11879	Economy	35300.00
0005433568539	11879	Economy	35300.00
0005433568505	11879	Economy	35300.00
0005433568495	11879	Economy	35300.00
0005433568515	11879	Economy	35300.00
0005433568503	11879	Economy	35300.00
0005433568524	11879	Economy	35300.00
0005433568520	11879	Economy	38800.00
0005433568523	11879	Economy	38800.00
0005433568518	11879	Economy	38800.00
0005433568506	11879	Economy	35300.00
0005433568519	11879	Economy	35300.00
0005432947864	11879	Economy	35300.00
0005433568492	11879	Economy	35300.00
0005433568489	11879	Economy	35300.00
0005433568541	11879	Economy	35300.00
0005433568531	11879	Economy	35300.00
0005433568484	11879	Economy	35300.00
0005433568490	11879	Economy	35300.00
0005432947784	11879	Economy	35300.00
0005433568514	11879	Economy	35300.00
0005433568509	11879	Economy	35300.00
0005433568478	11879	Economy	35300.00
0005433568502	11879	Economy	35300.00
0005433568521	11879	Economy	35300.00
0005433568522	11879	Economy	35300.00
0005433568494	11879	Economy	35300.00
0005433568517	11879	Economy	35300.00
0005433568513	11879	Economy	35300.00
0005433568526	11879	Economy	35300.00
0005433568540	11879	Economy	35300.00
0005433568480	11879	Economy	35300.00
0005432947769	11879	Economy	35300.00
0005433568486	11879	Economy	35300.00
0005433568537	11879	Economy	35300.00
0005433568527	11879	Economy	35300.00
0005433568496	11879	Economy	35300.00
0005433568479	11879	Economy	35300.00
0005433568510	11879	Economy	35300.00
0005433568497	11879	Economy	35300.00
0005433568543	11879	Economy	35300.00
0005433568500	11879	Economy	35300.00
0005433568528	11879	Economy	35300.00
0005433568532	11879	Economy	35300.00
0005433568512	11879	Economy	35300.00
0005432947794	11879	Economy	35300.00
0005433568508	11879	Economy	35300.00
0005432947865	11879	Economy	35300.00
0005433568481	11879	Economy	35300.00
0005433568498	11879	Economy	35300.00
0005433568499	11879	Economy	35300.00
0005433568530	11879	Economy	35300.00
0005433568525	11879	Economy	35300.00
0005433568501	11879	Economy	35300.00
0005433568483	11879	Economy	35300.00
0005433568482	11879	Economy	35300.00
0005433568542	11879	Economy	35300.00
0005433568485	11879	Economy	35300.00
0005433568487	11879	Economy	35300.00
0005433568488	11879	Economy	35300.00
0005432948176	25305	Business	105900.00
0005432948180	25305	Business	105900.00
0005432948155	25305	Business	105900.00
0005432948179	25305	Business	105900.00
0005432948170	25305	Business	105900.00
0005432948140	25305	Business	105900.00
0005433568022	25305	Business	105900.00
0005432948167	25305	Economy	35300.00
0005433568119	25305	Business	105900.00
0005433568084	25305	Economy	35300.00
0005433568064	25305	Economy	35300.00
0005432948160	25305	Economy	35300.00
0005433568050	25305	Economy	35300.00
0005433568024	25305	Economy	38800.00
0005432948173	25305	Economy	38800.00
0005433568042	25305	Economy	38800.00
0005432948163	25305	Economy	38800.00
0005432948172	25305	Economy	35300.00
0005433568025	25305	Economy	35300.00
0005433568113	25305	Economy	35300.00
0005433568118	25305	Economy	35300.00
0005432948147	25305	Economy	35300.00
0005432948157	25305	Economy	35300.00
0005432948143	25305	Economy	35300.00
0005432948154	25305	Economy	35300.00
0005432948149	25305	Economy	35300.00
0005433568112	25305	Economy	35300.00
0005432948177	25305	Economy	35300.00
0005432948146	25305	Economy	35300.00
0005433568038	25305	Economy	35300.00
0005432948178	25305	Economy	35300.00
0005433568021	25305	Economy	35300.00
0005432948175	25305	Economy	35300.00
0005432948169	25305	Economy	35300.00
0005432948161	25305	Economy	35300.00
0005432948142	25305	Economy	35300.00
0005432948153	25305	Economy	35300.00
0005432948158	25305	Economy	35300.00
0005432948164	25305	Economy	35300.00
0005433568052	25305	Economy	35300.00
0005433568086	25305	Economy	35300.00
0005432948165	25305	Economy	35300.00
0005433568039	25305	Economy	35300.00
0005432948168	25305	Economy	35300.00
0005432948141	25305	Economy	35300.00
0005433568017	25305	Economy	35300.00
0005432948145	25305	Economy	35300.00
0005432948156	25305	Economy	35300.00
0005432948139	25305	Economy	35300.00
0005432948144	25305	Economy	35300.00
0005432948152	25305	Economy	35300.00
0005432948150	25305	Economy	35300.00
0005432948159	25305	Economy	35300.00
0005433568102	25305	Economy	35300.00
0005432948162	25305	Economy	35300.00
0005432948148	25305	Economy	35300.00
0005433568069	25305	Economy	35300.00
0005432948171	25305	Economy	35300.00
0005432948166	25305	Economy	35300.00
0005433568026	25305	Economy	35300.00
0005433568049	25305	Economy	35300.00
0005432948151	25305	Economy	35300.00
0005432948174	25305	Economy	35300.00
0005435339989	5371	Business	67200.00
0005435340019	5371	Business	67200.00
0005434656538	5371	Business	67200.00
0005434654455	5371	Business	67200.00
0005434654451	5371	Business	67200.00
0005435339991	5371	Business	67200.00
0005434654447	5371	Business	67200.00
0005434656540	5371	Business	67200.00
0005435340003	5371	Economy	22400.00
0005434654439	5371	Economy	22400.00
0005435340005	5371	Economy	22400.00
0005434654442	5371	Economy	22400.00
0005434654449	5371	Economy	22400.00
0005434654436	5371	Economy	24600.00
0005435340024	5371	Economy	24600.00
0005435340006	5371	Economy	24600.00
0005434654453	5371	Economy	24600.00
0005434654430	5371	Economy	22400.00
0005435339990	5371	Economy	22400.00
0005435339996	5371	Economy	22400.00
0005435555336	5371	Economy	22400.00
0005434654438	5371	Economy	22400.00
0005435340001	5371	Economy	22400.00
0005434654445	5371	Economy	22400.00
0005434656539	5371	Economy	22400.00
0005432114176	5371	Economy	22400.00
0005434654452	5371	Economy	22400.00
0005435340018	5371	Economy	22400.00
0005434654441	5371	Economy	22400.00
0005434654454	5371	Economy	22400.00
0005434654434	5371	Economy	22400.00
0005434654444	5371	Economy	22400.00
0005434654459	5371	Economy	22400.00
0005434654450	5371	Economy	22400.00
0005432114175	5371	Economy	22400.00
0005434654433	5371	Economy	22400.00
0005432114177	5371	Economy	22400.00
0005434654443	5371	Economy	22400.00
0005434654458	5371	Economy	22400.00
0005434654460	5371	Economy	22400.00
0005434654435	5371	Economy	22400.00
0005434654429	5371	Economy	22400.00
0005435339997	5371	Economy	22400.00
0005434654446	5371	Economy	22400.00
0005434654432	5371	Economy	22400.00
0005435555337	5371	Economy	22400.00
0005434654431	5371	Economy	22400.00
0005434654437	5371	Economy	22400.00
0005434654457	5371	Economy	22400.00
0005434654448	5371	Economy	22400.00
0005435339992	5371	Economy	22400.00
0005434654456	5371	Economy	22400.00
0005434654440	5371	Economy	22400.00
0005435340002	5371	Economy	22400.00
0005434654220	12542	Business	67200.00
0005434654215	12542	Business	67200.00
0005435340141	12542	Business	67200.00
0005434654169	12542	Business	67200.00
0005434656522	12542	Economy	22400.00
0005434654238	12542	Economy	22400.00
0005434654190	12542	Economy	22400.00
0005435340135	12542	Economy	24600.00
0005435340130	12542	Economy	24600.00
0005435340132	12542	Economy	22400.00
0005434654219	12542	Economy	22400.00
0005434654196	12542	Economy	22400.00
0005434654265	12542	Economy	22400.00
0005434654195	12542	Economy	22400.00
0005434654362	12542	Economy	22400.00
0005434654182	12542	Economy	22400.00
0005434654229	12542	Economy	22400.00
0005434654201	12542	Economy	22400.00
0005434654281	12542	Economy	22400.00
0005435340133	12542	Economy	22400.00
0005434654264	12542	Economy	22400.00
0005435340131	12542	Economy	22400.00
0005435340140	12542	Economy	22400.00
0005434654170	12542	Economy	22400.00
0005434654261	12542	Economy	22400.00
0005434654166	12542	Economy	22400.00
0005435340139	12542	Economy	22400.00
0005435340134	12542	Economy	22400.00
0005434654235	12542	Economy	22400.00
0005434654263	12542	Economy	22400.00
0005434654363	12542	Economy	22400.00
0005435340129	12542	Economy	22400.00
0005435340143	12542	Economy	22400.00
0005434654233	12542	Economy	22400.00
0005434656525	12542	Economy	22400.00
0005435340136	12542	Economy	22400.00
0005434656529	12542	Economy	22400.00
0005434654171	12542	Economy	22400.00
0005435340137	12542	Economy	22400.00
0005435340138	12542	Economy	22400.00
0005435555355	12542	Economy	22400.00
0005434654262	12542	Economy	22400.00
0005435340142	12542	Economy	22400.00
0005435555354	12542	Economy	22400.00
0005434654276	12542	Economy	22400.00
0005433722163	7468	Business	32000.00
0005433719112	7468	Business	32000.00
0005433715542	7468	Business	32000.00
0005433715556	7468	Business	32000.00
0005433715574	7468	Business	32000.00
0005433715555	7468	Business	32000.00
0005433715567	7468	Business	32000.00
0005433715573	7468	Economy	10700.00
0005433656641	7468	Economy	10700.00
0005433715575	7468	Economy	10700.00
0005433715537	7468	Economy	10700.00
0005433722165	7468	Economy	10700.00
0005433715562	7468	Economy	10700.00
0005432428872	7468	Economy	10700.00
0005433715548	7468	Economy	10700.00
0005433722162	7468	Economy	10700.00
0005433722160	7468	Economy	10700.00
0005433715534	7468	Economy	10700.00
0005433715531	7468	Economy	10700.00
0005433715533	7468	Economy	10700.00
0005433715564	7468	Economy	10700.00
0005433715572	7468	Economy	10700.00
0005433719108	7468	Economy	10700.00
0005433715551	7468	Economy	10700.00
0005433690907	7468	Economy	10700.00
0005433722158	7468	Economy	10700.00
0005432428868	7468	Economy	10700.00
0005433715563	7468	Economy	10700.00
0005433715571	7468	Economy	10700.00
0005433689892	7468	Economy	10700.00
0005433719111	7468	Economy	10700.00
0005433715535	7468	Economy	10700.00
0005433715549	7468	Economy	10700.00
0005433656638	7468	Economy	10700.00
0005433715527	7468	Economy	11700.00
0005433715530	7468	Economy	11700.00
0005433689891	7468	Economy	11700.00
0005433715532	7468	Economy	10700.00
0005433719110	7468	Economy	10700.00
0005433715529	7468	Economy	10700.00
0005432078060	7468	Economy	10700.00
0005433688790	7468	Economy	10700.00
0005433715553	7468	Economy	10700.00
0005433715543	7468	Economy	10700.00
0005433715545	7468	Economy	10700.00
0005432078059	7468	Economy	10700.00
0005433656640	7468	Economy	10700.00
0005433715559	7468	Economy	10700.00
0005433715539	7468	Economy	10700.00
0005433722159	7468	Economy	10700.00
0005433656639	7468	Economy	10700.00
0005433715568	7468	Economy	10700.00
0005433715557	7468	Economy	10700.00
0005433715552	7468	Economy	10700.00
0005433715570	7468	Economy	10700.00
0005433690908	7468	Economy	10700.00
0005433715569	7468	Economy	10700.00
0005433715544	7468	Economy	10700.00
0005433722164	7468	Economy	10700.00
0005433715561	7468	Economy	10700.00
0005432078062	7468	Economy	10700.00
0005433715565	7468	Economy	10700.00
0005432078061	7468	Economy	10700.00
0005433688791	7468	Economy	10700.00
0005433715536	7468	Economy	10700.00
0005433715560	7468	Economy	10700.00
0005433715566	7468	Economy	10700.00
0005433715540	7468	Economy	10700.00
0005433715546	7468	Economy	10700.00
0005433715576	7468	Economy	10700.00
0005433722166	7468	Economy	10700.00
0005433715558	7468	Economy	10700.00
0005433722161	7468	Economy	10700.00
0005433715550	7468	Economy	10700.00
0005432078064	7468	Economy	10700.00
0005433719109	7468	Economy	10700.00
0005432428873	7468	Economy	10700.00
0005433715554	7468	Economy	10700.00
0005433715541	7468	Economy	10700.00
0005432078063	7468	Economy	10700.00
0005433715528	7468	Economy	10700.00
0005433715547	7468	Economy	10700.00
0005433715538	7468	Economy	10700.00
0005433715164	29203	Business	32000.00
0005433719080	29203	Business	32000.00
0005433715123	29203	Business	32000.00
0005433715270	29203	Business	32000.00
0005433715336	29203	Economy	10700.00
0005433715113	29203	Economy	10700.00
0005435266117	29203	Economy	10700.00
0005433715217	29203	Economy	10700.00
0005433715171	29203	Economy	10700.00
0005433719083	29203	Economy	10700.00
0005433715079	29203	Economy	10700.00
0005433715189	29203	Economy	10700.00
0005433715153	29203	Economy	10700.00
0005432428900	29203	Economy	10700.00
0005433719081	29203	Economy	10700.00
0005433715269	29203	Economy	10700.00
0005433715197	29203	Economy	10700.00
0005433715111	29203	Economy	10700.00
0005433715181	29203	Economy	10700.00
0005433715158	29203	Economy	11700.00
0005432428901	29203	Economy	11700.00
0005433715154	29203	Economy	10700.00
0005433688776	29203	Economy	10700.00
0005433715227	29203	Economy	10700.00
0005433715204	29203	Economy	10700.00
0005433715240	29203	Economy	10700.00
0005432428899	29203	Economy	10700.00
0005433715092	29203	Economy	10700.00
0005433715114	29203	Economy	10700.00
0005433715133	29203	Economy	10700.00
0005433715190	29203	Economy	10700.00
0005432006737	29203	Economy	10700.00
0005433715335	29203	Economy	10700.00
0005433715271	29203	Economy	10700.00
0005433715163	29203	Economy	10700.00
0005433715124	29203	Economy	10700.00
0005433715160	29203	Economy	10700.00
0005433715196	29203	Economy	10700.00
0005433715086	29203	Economy	10700.00
0005433715182	29203	Economy	10700.00
0005433715152	29203	Economy	10700.00
0005433715183	29203	Economy	10700.00
0005433715084	29203	Economy	10700.00
0005433715172	29203	Economy	10700.00
0005432006738	29203	Economy	10700.00
0005433715203	29203	Economy	10700.00
0005433715115	29203	Economy	10700.00
0005434095148	8663	Business	36500.00
0005434182037	8663	Economy	12200.00
0005434182011	8663	Economy	12200.00
0005434095153	8663	Economy	12200.00
0005434095157	8663	Economy	12200.00
0005434095160	8663	Economy	12200.00
0005434182002	8663	Economy	12200.00
0005434181977	8663	Economy	13400.00
0005434095150	8663	Economy	13400.00
0005434095158	8663	Economy	13400.00
0005434095159	8663	Economy	12200.00
0005434143712	8663	Economy	12200.00
0005434143714	8663	Economy	12200.00
0005434143708	8663	Economy	12200.00
0005434095152	8663	Economy	12200.00
0005434182000	8663	Economy	12200.00
0005434143711	8663	Economy	12200.00
0005434181980	8663	Economy	12200.00
0005434143713	8663	Economy	12200.00
0005434095155	8663	Economy	12200.00
0005434095149	8663	Economy	12200.00
0005434182029	8663	Economy	12200.00
0005434181979	8663	Economy	12200.00
0005434095151	8663	Economy	12200.00
0005434182006	8663	Economy	12200.00
0005434143706	8663	Economy	12200.00
0005434095162	8663	Economy	12200.00
0005434095156	8663	Economy	12200.00
0005434095161	8663	Economy	12200.00
0005434095154	8663	Economy	12200.00
0005434181992	8663	Economy	12200.00
0005434143709	8663	Economy	12200.00
0005434143707	8663	Economy	12200.00
0005434143710	8663	Economy	12200.00
0005434181993	8663	Economy	12200.00
0005434095098	11681	Business	36500.00
0005434182073	11681	Business	36500.00
0005434095062	11681	Business	36500.00
0005434182077	11681	Business	36500.00
0005434184646	11681	Economy	12200.00
0005434095016	11681	Economy	12200.00
0005434095061	11681	Economy	12200.00
0005434182083	11681	Economy	12200.00
0005434095019	11681	Economy	13400.00
0005434182079	11681	Economy	12200.00
0005434095029	11681	Economy	12200.00
0005434095015	11681	Economy	12200.00
0005434182075	11681	Economy	12200.00
0005434182084	11681	Economy	12200.00
0005434182081	11681	Economy	12200.00
0005434182074	11681	Economy	12200.00
0005434095022	11681	Economy	12200.00
0005434183562	11681	Economy	12200.00
0005434183561	11681	Economy	12200.00
0005434095068	11681	Economy	12200.00
0005434182078	11681	Economy	12200.00
0005434095069	11681	Economy	12200.00
0005434095077	11681	Economy	12200.00
0005434182072	11681	Economy	12200.00
0005434184645	11681	Economy	12200.00
0005434095063	11681	Economy	12200.00
0005434182076	11681	Economy	12200.00
0005434095078	11681	Economy	12200.00
0005434182082	11681	Economy	12200.00
0005434183560	11681	Economy	12200.00
0005434182080	11681	Economy	12200.00
0005434095021	11681	Economy	12200.00
0005433397269	1435	Business	33000.00
0005433397244	1435	Business	33000.00
0005433397366	1435	Business	33000.00
0005432906495	1435	Business	33000.00
0005433397317	1435	Business	33000.00
0005433397318	1435	Economy	11000.00
0005433397397	1435	Economy	11000.00
0005433397443	1435	Economy	11000.00
0005435732227	1435	Economy	11000.00
0005433397262	1435	Economy	11000.00
0005433456936	1435	Economy	11000.00
0005433397276	1435	Economy	12100.00
0005433456933	1435	Economy	11000.00
0005433397299	1435	Economy	11000.00
0005433397266	1435	Economy	11000.00
0005433397263	1435	Economy	11000.00
0005435732231	1435	Economy	11000.00
0005433397265	1435	Economy	11000.00
0005432297255	1435	Economy	11000.00
0005433456934	1435	Economy	11000.00
0005435732229	1435	Economy	11000.00
0005433397307	1435	Economy	11000.00
0005435732232	1435	Economy	11000.00
0005435732230	1435	Economy	11000.00
0005433397204	1435	Economy	11000.00
0005433397248	1435	Economy	11000.00
0005435732228	1435	Economy	11000.00
0005433397264	1435	Economy	11000.00
0005433397298	1435	Economy	11000.00
0005433397396	1435	Economy	11000.00
0005433397214	1435	Economy	11000.00
0005433397270	1435	Economy	11000.00
0005433397275	1435	Economy	11000.00
0005433397337	1435	Economy	11000.00
0005432297256	1435	Economy	11000.00
0005433397361	1435	Economy	11000.00
0005433456935	1435	Economy	11000.00
0005435732226	1435	Economy	11000.00
0005432297254	1435	Economy	11000.00
0005433397304	1435	Economy	11000.00
0005433397274	1435	Economy	11000.00
0005433397305	1435	Economy	11000.00
0005433397306	1435	Economy	11000.00
0005433397313	1435	Economy	11000.00
0005433397215	1435	Economy	11000.00
0005433397456	1435	Economy	11000.00
0005433397213	1435	Economy	11000.00
0005433397648	19239	Business	33000.00
0005433456913	19239	Business	33000.00
0005433397662	19239	Business	33000.00
0005433397647	19239	Business	33000.00
0005433397641	19239	Business	33000.00
0005433397674	19239	Business	33000.00
0005433397634	19239	Business	33000.00
0005433397669	19239	Economy	11000.00
0005435732141	19239	Economy	11000.00
0005433397671	19239	Economy	11000.00
0005433456912	19239	Economy	11000.00
0005433397628	19239	Economy	11000.00
0005435732150	19239	Economy	12100.00
0005433397627	19239	Economy	12100.00
0005433397666	19239	Economy	11000.00
0005433397640	19239	Economy	11000.00
0005433397643	19239	Economy	11000.00
0005433397668	19239	Economy	11000.00
0005433397644	19239	Economy	11000.00
0005433397659	19239	Economy	11000.00
0005433397664	19239	Economy	11000.00
0005435732151	19239	Economy	11000.00
0005433397663	19239	Economy	11000.00
0005433397675	19239	Economy	11000.00
0005433397661	19239	Economy	11000.00
0005435732121	19239	Economy	11000.00
0005433397649	19239	Economy	11000.00
0005433397651	19239	Economy	11000.00
0005433397657	19239	Economy	11000.00
0005433397636	19239	Economy	11000.00
0005433397639	19239	Economy	11000.00
0005433397630	19239	Economy	11000.00
0005433397650	19239	Economy	11000.00
0005433397632	19239	Economy	11000.00
0005433397667	19239	Economy	11000.00
0005433397656	19239	Economy	11000.00
0005433397654	19239	Economy	11000.00
0005433397670	19239	Economy	11000.00
0005435732126	19239	Economy	11000.00
0005433397637	19239	Economy	11000.00
0005433397655	19239	Economy	11000.00
0005433397633	19239	Economy	11000.00
0005433397635	19239	Economy	11000.00
0005433397629	19239	Economy	11000.00
0005435732120	19239	Economy	11000.00
0005433397672	19239	Economy	11000.00
0005433397638	19239	Economy	11000.00
0005435732122	19239	Economy	11000.00
0005433397646	19239	Economy	11000.00
0005435732142	19239	Economy	11000.00
0005433397645	19239	Economy	11000.00
0005433397653	19239	Economy	11000.00
0005433397660	19239	Economy	11000.00
0005433397631	19239	Economy	11000.00
0005433397642	19239	Economy	11000.00
0005433397673	19239	Economy	11000.00
0005433397658	19239	Economy	11000.00
0005433397665	19239	Economy	11000.00
0005433397652	19239	Economy	11000.00
0005434443460	17389	Economy	14100.00
0005434443425	17389	Economy	14100.00
0005434443446	17389	Economy	14100.00
0005434443497	17389	Economy	14100.00
0005434443452	17389	Economy	14100.00
0005434443504	17389	Economy	14100.00
0005434443479	17389	Economy	14100.00
0005434443459	17389	Economy	14100.00
0005434443438	17389	Economy	14100.00
0005434443478	17389	Economy	14100.00
0005434443566	20580	Economy	14100.00
0005434443565	20580	Economy	14100.00
0005434443562	20580	Economy	14100.00
0005434443567	20580	Economy	14100.00
0005434443556	20580	Economy	14100.00
0005434443561	20580	Economy	14100.00
0005434443559	20580	Economy	14100.00
0005434443557	20580	Economy	14100.00
0005434443558	20580	Economy	14100.00
0005434443570	20580	Economy	14100.00
0005434443568	20580	Economy	14100.00
0005434443564	20580	Economy	14100.00
0005434443560	20580	Economy	14100.00
0005434443571	20580	Economy	14100.00
0005434443569	20580	Economy	14100.00
0005434443563	20580	Economy	14100.00
0005434954575	7280	Economy	5800.00
0005435377546	7280	Economy	5800.00
0005434954577	7280	Economy	5800.00
0005434954574	7280	Economy	5800.00
0005434954576	7280	Economy	5800.00
0005434954539	28341	Economy	5800.00
0005434954541	28341	Economy	5800.00
0005434954538	28341	Economy	5800.00
0005434954537	28341	Economy	5800.00
0005434954566	28341	Economy	5800.00
0005434351590	4496	Economy	15400.00
0005434351585	4496	Economy	14000.00
0005434351587	4496	Economy	14000.00
0005434351582	4496	Economy	14000.00
0005435893531	4496	Economy	14000.00
0005434351591	4496	Economy	14000.00
0005435893532	4496	Economy	14000.00
0005434351583	4496	Economy	14000.00
0005435893511	4496	Economy	14000.00
0005435893547	4496	Economy	14000.00
0005434351584	4496	Economy	14000.00
0005434351592	4496	Economy	14000.00
0005434351588	4496	Economy	14000.00
0005435893530	4496	Economy	14000.00
0005434351594	4496	Economy	14000.00
0005434351589	4496	Economy	14000.00
0005434351586	4496	Economy	14000.00
0005434351593	4496	Economy	14000.00
0005434351463	29633	Economy	15400.00
0005435893572	29633	Economy	15400.00
0005434351495	29633	Economy	14000.00
0005434351505	29633	Economy	14000.00
0005435893574	29633	Economy	14000.00
0005434351491	29633	Economy	14000.00
0005434351481	29633	Economy	14000.00
0005434351487	29633	Economy	14000.00
0005434351467	29633	Economy	14000.00
0005434351493	29633	Economy	14000.00
0005434351504	29633	Economy	14000.00
0005435893571	29633	Economy	14000.00
0005435893570	29633	Economy	14000.00
0005435893569	29633	Economy	14000.00
0005434351486	29633	Economy	14000.00
0005435893573	29633	Economy	14000.00
0005435545664	1066	Business	30600.00
0005435091994	1066	Business	30600.00
0005433341532	1066	Business	30600.00
0005435545661	1066	Business	30600.00
0005433341703	1066	Business	30600.00
0005432293188	1066	Business	30600.00
0005433463882	1066	Business	30600.00
0005433341704	1066	Business	30600.00
0005435091984	1066	Business	30600.00
0005434445229	1066	Business	30600.00
0005433269632	1066	Business	30600.00
0005435545668	1066	Business	30600.00
0005433341415	1066	Business	30600.00
0005433341854	1066	Business	30600.00
0005435091993	1066	Business	30600.00
0005433341425	1066	Business	30600.00
0005433341635	1066	Economy	11200.00
0005433341400	1066	Economy	11200.00
0005433341477	1066	Economy	11200.00
0005434445227	1066	Economy	10200.00
0005432293186	1066	Economy	10200.00
0005435091991	1066	Economy	10200.00
0005434446502	1066	Economy	10200.00
0005435545665	1066	Economy	10200.00
0005433269647	1066	Economy	10200.00
0005435545659	1066	Economy	10200.00
0005433341429	1066	Economy	10200.00
0005433341500	1066	Economy	10200.00
0005435545656	1066	Economy	10200.00
0005435545657	1066	Economy	10200.00
0005435091987	1066	Economy	10200.00
0005435545662	1066	Economy	10200.00
0005433341620	1066	Economy	10200.00
0005433341853	1066	Economy	10200.00
0005435545669	1066	Economy	10200.00
0005433463881	1066	Economy	10200.00
0005433341607	1066	Economy	10200.00
0005433341461	1066	Economy	10200.00
0005433341836	1066	Economy	10200.00
0005433341734	1066	Economy	10200.00
0005433341428	1066	Economy	10200.00
0005434445226	1066	Economy	10200.00
0005435545658	1066	Economy	10200.00
0005434446503	1066	Economy	10200.00
0005435091986	1066	Economy	10200.00
0005433341671	1066	Economy	10200.00
0005435091992	1066	Economy	10200.00
0005433462729	1066	Economy	10200.00
0005433341488	1066	Economy	10200.00
0005435091995	1066	Economy	10200.00
0005433341382	1066	Economy	10200.00
0005435091989	1066	Economy	10200.00
0005433463883	1066	Economy	10200.00
0005433341402	1066	Economy	10200.00
0005433341486	1066	Economy	10200.00
0005434445228	1066	Economy	10200.00
0005435545660	1066	Economy	10200.00
0005433341449	1066	Economy	10200.00
0005435091985	1066	Economy	11200.00
0005433341815	1066	Economy	10200.00
0005433341835	1066	Economy	10200.00
0005433341641	1066	Economy	11200.00
0005433341595	1066	Economy	10200.00
0005433159282	1066	Economy	10200.00
0005433462728	1066	Economy	10200.00
0005434446501	1066	Economy	10200.00
0005435545670	1066	Economy	10200.00
0005433341669	1066	Economy	10200.00
0005432293187	1066	Economy	10200.00
0005433341667	1066	Economy	10200.00
0005433341412	1066	Economy	10200.00
0005435545666	1066	Economy	10200.00
0005433269635	1066	Economy	10200.00
0005435545663	1066	Economy	10200.00
0005433341417	1066	Economy	10200.00
0005435545655	1066	Economy	10200.00
0005433341649	1066	Economy	10200.00
0005433341603	1066	Economy	10200.00
0005433341738	1066	Economy	10200.00
0005433341561	1066	Economy	10200.00
0005435091988	1066	Economy	10200.00
0005435545667	1066	Economy	10200.00
0005433341650	1066	Economy	10200.00
0005433341683	1066	Economy	10200.00
0005435091990	1066	Economy	10200.00
0005433341586	1066	Economy	10200.00
0005433341383	1066	Economy	10200.00
0005433341424	1066	Economy	10200.00
0005433341601	1066	Economy	10200.00
0005435545671	1066	Economy	10200.00
0005433341448	1066	Economy	10200.00
0005433341505	1066	Economy	10200.00
0005433341587	1066	Economy	10200.00
0005433341462	1066	Economy	10200.00
0005433341391	1066	Economy	10200.00
0005433342271	17053	Business	30600.00
0005433342281	17053	Business	30600.00
0005433342259	17053	Business	30600.00
0005433159294	17053	Business	30600.00
0005433342251	17053	Business	30600.00
0005433342220	17053	Business	30600.00
0005433342248	17053	Business	30600.00
0005433342290	17053	Business	30600.00
0005433159293	17053	Business	30600.00
0005433342213	17053	Business	30600.00
0005433342215	17053	Business	30600.00
0005433342232	17053	Business	30600.00
0005433342247	17053	Business	30600.00
0005433342252	17053	Business	30600.00
0005433342235	17053	Business	30600.00
0005433269674	17053	Economy	11200.00
0005433342211	17053	Economy	11200.00
0005433342287	17053	Economy	10200.00
0005433342258	17053	Economy	10200.00
0005433342280	17053	Economy	10200.00
0005435508171	17053	Economy	10200.00
0005433342192	17053	Economy	10200.00
0005433342218	17053	Economy	10200.00
0005433342240	17053	Economy	10200.00
0005433342286	17053	Economy	10200.00
0005433342243	17053	Economy	10200.00
0005433342223	17053	Economy	10200.00
0005433342279	17053	Economy	10200.00
0005433342198	17053	Economy	10200.00
0005433342264	17053	Economy	10200.00
0005433342250	17053	Economy	10200.00
0005433342217	17053	Economy	10200.00
0005433159295	17053	Economy	10200.00
0005433342245	17053	Economy	10200.00
0005433342269	17053	Economy	10200.00
0005433342212	17053	Economy	10200.00
0005433342292	17053	Economy	10200.00
0005435091935	17053	Economy	10200.00
0005433342200	17053	Economy	10200.00
0005433342277	17053	Economy	10200.00
0005433342261	17053	Economy	10200.00
0005433342209	17053	Economy	10200.00
0005433342262	17053	Economy	10200.00
0005433342273	17053	Economy	10200.00
0005433342204	17053	Economy	10200.00
0005433342256	17053	Economy	10200.00
0005433342266	17053	Economy	10200.00
0005433342268	17053	Economy	10200.00
0005433342195	17053	Economy	10200.00
0005433342205	17053	Economy	10200.00
0005433342278	17053	Economy	10200.00
0005433342203	17053	Economy	10200.00
0005433342265	17053	Economy	10200.00
0005433342234	17053	Economy	10200.00
0005433342257	17053	Economy	10200.00
0005433342249	17053	Economy	10200.00
0005435508173	17053	Economy	10200.00
0005433159292	17053	Economy	10200.00
0005433342202	17053	Economy	10200.00
0005435091929	17053	Economy	10200.00
0005433342210	17053	Economy	10200.00
0005433342197	17053	Economy	10200.00
0005433342272	17053	Economy	10200.00
0005433342199	17053	Economy	10200.00
0005433342233	17053	Economy	10200.00
0005433342242	17053	Economy	10200.00
0005433342283	17053	Economy	10200.00
0005433269672	17053	Economy	10200.00
0005433342288	17053	Economy	10200.00
0005433342208	17053	Economy	10200.00
0005433342246	17053	Economy	10200.00
0005433342228	17053	Economy	10200.00
0005433342291	17053	Economy	10200.00
0005433342206	17053	Economy	10200.00
0005433342230	17053	Economy	10200.00
0005433342253	17053	Economy	10200.00
0005433342225	17053	Economy	11200.00
0005433342229	17053	Economy	10200.00
0005435508167	17053	Economy	10200.00
0005435091946	17053	Economy	10200.00
0005433342270	17053	Economy	10200.00
0005433342274	17053	Economy	10200.00
0005433269671	17053	Economy	10200.00
0005433342236	17053	Economy	10200.00
0005433342221	17053	Economy	10200.00
0005433342293	17053	Economy	10200.00
0005433342239	17053	Economy	10200.00
0005433342244	17053	Economy	10200.00
0005433342193	17053	Economy	10200.00
0005433342207	17053	Economy	10200.00
0005433342284	17053	Economy	10200.00
0005433342241	17053	Economy	10200.00
0005433342214	17053	Economy	10200.00
0005433342267	17053	Economy	10200.00
0005433342219	17053	Economy	10200.00
0005433342238	17053	Economy	10200.00
0005435508174	17053	Economy	10200.00
0005433342237	17053	Economy	10200.00
0005433342276	17053	Economy	10200.00
0005435091905	17053	Economy	10200.00
0005433342226	17053	Economy	10200.00
0005433342260	17053	Economy	10200.00
0005433342231	17053	Economy	10200.00
0005433342222	17053	Economy	10200.00
0005433342263	17053	Economy	10200.00
0005435508165	17053	Economy	10200.00
0005433342275	17053	Economy	10200.00
0005433342285	17053	Economy	10200.00
0005433342194	17053	Economy	10200.00
0005433342224	17053	Economy	10200.00
0005433342227	17053	Economy	10200.00
0005433342216	17053	Economy	10200.00
0005435508170	17053	Economy	10200.00
0005433342196	17053	Economy	10200.00
0005433269673	17053	Economy	10200.00
0005435091945	17053	Economy	10200.00
0005433342282	17053	Economy	10200.00
0005433342289	17053	Economy	10200.00
0005433342201	17053	Economy	10200.00
0005433342254	17053	Economy	10200.00
0005435091936	17053	Economy	10200.00
0005433342255	17053	Economy	10200.00
0005432851830	1344	Business	101000.00
0005432390036	1344	Business	101000.00
0005432390051	1344	Business	101000.00
0005432390032	1344	Business	101000.00
0005432390038	1344	Business	101000.00
0005432851833	1344	Business	101000.00
0005432390022	1344	Business	101000.00
0005432390030	1344	Business	101000.00
0005432851831	1344	Economy	33700.00
0005432391965	1344	Economy	33700.00
0005432391968	1344	Economy	33700.00
0005432390048	1344	Economy	33700.00
0005432391969	1344	Economy	33700.00
0005432390027	1344	Economy	33700.00
0005432390039	1344	Economy	33700.00
0005432851832	1344	Economy	33700.00
0005432391966	1344	Economy	33700.00
0005432390050	1344	Economy	33700.00
0005432390044	1344	Economy	37000.00
0005432851817	1344	Economy	37000.00
0005432390031	1344	Economy	33700.00
0005432390026	1344	Economy	33700.00
0005432390016	1344	Economy	33700.00
0005432390049	1344	Economy	33700.00
0005432390021	1344	Economy	33700.00
0005432390025	1344	Economy	33700.00
0005432390034	1344	Economy	33700.00
0005432390024	1344	Economy	33700.00
0005432390017	1344	Economy	33700.00
0005432390037	1344	Economy	33700.00
0005432390018	1344	Economy	33700.00
0005432390040	1344	Economy	33700.00
0005432391967	1344	Economy	33700.00
0005432851818	1344	Economy	33700.00
0005432390020	1344	Economy	33700.00
0005432391971	1344	Economy	33700.00
0005432391970	1344	Economy	33700.00
0005432390046	1344	Economy	33700.00
0005432851834	1344	Economy	33700.00
0005432390047	1344	Economy	33700.00
0005432390033	1344	Economy	33700.00
0005432390028	1344	Economy	33700.00
0005432390023	1344	Economy	33700.00
0005432390042	1344	Economy	33700.00
0005432391972	1344	Economy	33700.00
0005432390019	1344	Economy	33700.00
0005432851815	1344	Economy	33700.00
0005432390041	1344	Economy	33700.00
0005432390043	1344	Economy	33700.00
0005432390035	1344	Economy	33700.00
0005432390045	1344	Economy	33700.00
0005432390029	1344	Economy	33700.00
0005434081481	12820	Business	40300.00
0005434066295	12820	Business	40300.00
0005432433635	12820	Business	40300.00
0005434066468	12820	Business	40300.00
0005434081503	12820	Business	40300.00
0005433989689	12820	Business	40300.00
0005434066340	12820	Economy	13400.00
0005434081494	12820	Economy	13400.00
0005434066504	12820	Economy	13400.00
0005434066491	12820	Economy	13400.00
0005434066368	12820	Economy	13400.00
0005434081473	12820	Economy	13400.00
0005434066303	12820	Economy	13400.00
0005432161132	12820	Economy	13400.00
0005434081513	12820	Economy	13400.00
0005434066413	12820	Economy	13400.00
0005434081514	12820	Economy	13400.00
0005432159818	12820	Economy	13400.00
0005434066579	12820	Economy	13400.00
0005434066309	12820	Economy	13400.00
0005434066450	12820	Economy	13400.00
0005432433632	12820	Economy	13400.00
0005434081507	12820	Economy	13400.00
0005434066341	12820	Economy	13400.00
0005432159819	12820	Economy	13400.00
0005434066449	12820	Economy	13400.00
0005434066430	12820	Economy	13400.00
0005434066388	12820	Economy	13400.00
0005434066387	12820	Economy	13400.00
0005434081493	12820	Economy	13400.00
0005434081535	12820	Economy	14800.00
0005434081506	12820	Economy	14800.00
0005434081472	12820	Economy	14800.00
0005434081521	12820	Economy	14800.00
0005434066410	12820	Economy	13400.00
0005434066438	12820	Economy	13400.00
0005434066369	12820	Economy	13400.00
0005434081492	12820	Economy	13400.00
0005432433636	12820	Economy	13400.00
0005432161133	12820	Economy	13400.00
0005434081478	12820	Economy	13400.00
0005434066653	12820	Economy	13400.00
0005433989709	12820	Economy	13400.00
0005434081483	12820	Economy	13400.00
0005434066411	12820	Economy	13400.00
0005432433633	12820	Economy	13400.00
0005434066320	12820	Economy	13400.00
0005434066761	12820	Economy	13400.00
0005434066503	12820	Economy	13400.00
0005434066432	12820	Economy	13400.00
0005434081479	12820	Economy	13400.00
0005434066342	12820	Economy	13400.00
0005434066352	12820	Economy	13400.00
0005434081505	12820	Economy	13400.00
0005433989702	12820	Economy	13400.00
0005434066317	12820	Economy	13400.00
0005434066439	12820	Economy	13400.00
0005434066318	12820	Economy	13400.00
0005434066346	12820	Economy	13400.00
0005432433634	12820	Economy	13400.00
0005434066548	12820	Economy	13400.00
0005434066345	12820	Economy	13400.00
0005434081475	12820	Economy	13400.00
0005434081498	12820	Economy	13400.00
0005434081536	12820	Economy	13400.00
0005434066319	12820	Economy	13400.00
0005433989703	12820	Economy	13400.00
0005434066412	12820	Economy	13400.00
0005432159820	12820	Economy	13400.00
0005434081480	12820	Economy	13400.00
0005434081497	12820	Economy	13400.00
0005434066296	12820	Economy	13400.00
0005434066876	30645	Business	40300.00
0005434081677	30645	Business	40300.00
0005434081688	30645	Business	40300.00
0005432433612	30645	Business	40300.00
0005434066931	30645	Business	40300.00
0005434066892	30645	Business	40300.00
0005432433611	30645	Business	40300.00
0005434066878	30645	Business	40300.00
0005432150125	30645	Business	40300.00
0005434066947	30645	Economy	13400.00
0005434066893	30645	Economy	13400.00
0005434066912	30645	Economy	13400.00
0005434081676	30645	Economy	13400.00
0005434066883	30645	Economy	13400.00
0005434081681	30645	Economy	13400.00
0005434081679	30645	Economy	13400.00
0005434066933	30645	Economy	13400.00
0005434066946	30645	Economy	13400.00
0005434066894	30645	Economy	13400.00
0005434066880	30645	Economy	13400.00
0005434066882	30645	Economy	13400.00
0005432150123	30645	Economy	13400.00
0005432433605	30645	Economy	13400.00
0005434066895	30645	Economy	13400.00
0005434066908	30645	Economy	13400.00
0005434081693	30645	Economy	13400.00
0005434066942	30645	Economy	13400.00
0005434066896	30645	Economy	13400.00
0005433989727	30645	Economy	13400.00
0005433989725	30645	Economy	13400.00
0005434081694	30645	Economy	13400.00
0005432186835	30645	Economy	13400.00
0005434066920	30645	Economy	13400.00
0005434066929	30645	Economy	13400.00
0005432186836	30645	Economy	13400.00
0005434066939	30645	Economy	13400.00
0005433989728	30645	Economy	13400.00
0005434066927	30645	Economy	13400.00
0005434066898	30645	Economy	13400.00
0005434066886	30645	Economy	13400.00
0005434081684	30645	Economy	13400.00
0005432433588	30645	Economy	13400.00
0005434066909	30645	Economy	13400.00
0005434081695	30645	Economy	13400.00
0005434066905	30645	Economy	13400.00
0005432186834	30645	Economy	13400.00
0005434066943	30645	Economy	13400.00
0005434066900	30645	Economy	14800.00
0005434066901	30645	Economy	14800.00
0005434066921	30645	Economy	14800.00
0005434066928	30645	Economy	14800.00
0005434066941	30645	Economy	14800.00
0005434066936	30645	Economy	14800.00
0005432150120	30645	Economy	13400.00
0005434066918	30645	Economy	13400.00
0005434066917	30645	Economy	13400.00
0005432433607	30645	Economy	13400.00
0005432150121	30645	Economy	13400.00
0005434066904	30645	Economy	13400.00
0005434066930	30645	Economy	13400.00
0005434081675	30645	Economy	13400.00
0005432150119	30645	Economy	13400.00
0005434066890	30645	Economy	13400.00
0005434081680	30645	Economy	13400.00
0005434066911	30645	Economy	13400.00
0005434081692	30645	Economy	13400.00
0005434081690	30645	Economy	13400.00
0005434066885	30645	Economy	13400.00
0005434081686	30645	Economy	13400.00
0005434066902	30645	Economy	13400.00
0005434066937	30645	Economy	13400.00
0005434066914	30645	Economy	13400.00
0005434066919	30645	Economy	13400.00
0005434081691	30645	Economy	13400.00
0005432150124	30645	Economy	13400.00
0005434066897	30645	Economy	13400.00
0005434066884	30645	Economy	13400.00
0005434081689	30645	Economy	13400.00
0005434066932	30645	Economy	13400.00
0005434081674	30645	Economy	13400.00
0005434066922	30645	Economy	13400.00
0005434081696	30645	Economy	13400.00
0005434066923	30645	Economy	13400.00
0005434081682	30645	Economy	13400.00
0005434066889	30645	Economy	13400.00
0005434066906	30645	Economy	13400.00
0005434066881	30645	Economy	13400.00
0005434066940	30645	Economy	13400.00
0005434066915	30645	Economy	13400.00
0005434066888	30645	Economy	13400.00
0005433989729	30645	Economy	13400.00
0005434066935	30645	Economy	13400.00
0005434066926	30645	Economy	13400.00
0005432433587	30645	Economy	13400.00
0005434066907	30645	Economy	13400.00
0005434081678	30645	Economy	13400.00
0005434066913	30645	Economy	13400.00
0005434081683	30645	Economy	13400.00
0005434066877	30645	Economy	13400.00
0005434066924	30645	Economy	13400.00
0005432150122	30645	Economy	13400.00
0005434081697	30645	Economy	13400.00
0005433989726	30645	Economy	13400.00
0005434066934	30645	Economy	13400.00
0005434066916	30645	Economy	13400.00
0005432433606	30645	Economy	13400.00
0005434066938	30645	Economy	13400.00
0005434066944	30645	Economy	13400.00
0005434066903	30645	Economy	13400.00
0005432150118	30645	Economy	13400.00
0005434066945	30645	Economy	13400.00
0005434066910	30645	Economy	13400.00
0005434066925	30645	Economy	13400.00
0005434081687	30645	Economy	13400.00
0005434066891	30645	Economy	13400.00
0005434066899	30645	Economy	13400.00
0005434081685	30645	Economy	13400.00
0005434066879	30645	Economy	13400.00
0005434066887	30645	Economy	13400.00
0005434264734	5497	Business	35300.00
0005435461856	5497	Business	35300.00
0005435765733	5497	Business	35300.00
0005435720816	5497	Business	35300.00
0005435461885	5497	Business	35300.00
0005435765703	5497	Business	35300.00
0005435461881	5497	Business	35300.00
0005432140375	5497	Business	35300.00
0005435765720	5497	Business	35300.00
0005434264759	5497	Business	35300.00
0005435765734	5497	Business	35300.00
0005435765735	5497	Business	35300.00
0005435461927	5497	Business	35300.00
0005435765709	5497	Business	35300.00
0005435765731	5497	Business	35300.00
0005433529247	5497	Business	35300.00
0005435765711	5497	Economy	12900.00
0005432140377	5497	Economy	11800.00
0005435461852	5497	Economy	11800.00
0005435765738	5497	Economy	11800.00
0005435765691	5497	Economy	11800.00
0005434264735	5497	Economy	11800.00
0005434264736	5497	Economy	11800.00
0005434264716	5497	Economy	11800.00
0005435765717	5497	Economy	11800.00
0005432140380	5497	Economy	11800.00
0005435461918	5497	Economy	11800.00
0005433529246	5497	Economy	11800.00
0005434264717	5497	Economy	11800.00
0005435735096	5497	Economy	11800.00
0005433527237	5497	Economy	11800.00
0005434264780	5497	Economy	11800.00
0005435461760	5497	Economy	11800.00
0005432535746	5497	Economy	11800.00
0005435765718	5497	Economy	11800.00
0005435725553	5497	Economy	11800.00
0005435722035	5497	Economy	11800.00
0005435765699	5497	Economy	11800.00
0005432140374	5497	Economy	11800.00
0005435765729	5497	Economy	11800.00
0005435765707	5497	Economy	11800.00
0005435723027	5497	Economy	11800.00
0005435735097	5497	Economy	11800.00
0005435720815	5497	Economy	11800.00
0005435765706	5497	Economy	11800.00
0005435765677	5497	Economy	11800.00
0005435765675	5497	Economy	11800.00
0005435765710	5497	Economy	11800.00
0005435765692	5497	Economy	11800.00
0005435765722	5497	Economy	11800.00
0005435765732	5497	Economy	11800.00
0005435765737	5497	Economy	11800.00
0005435765697	5497	Economy	11800.00
0005432140376	5497	Economy	11800.00
0005435765713	5497	Economy	11800.00
0005435765690	5497	Economy	11800.00
0005434264687	5497	Economy	11800.00
0005435735099	5497	Economy	11800.00
0005435461764	5497	Economy	11800.00
0005432140378	5497	Economy	11800.00
0005435461839	5497	Economy	11800.00
0005435461841	5497	Economy	11800.00
0005435723028	5497	Economy	11800.00
0005435765723	5497	Economy	11800.00
0005435765725	5497	Economy	11800.00
0005435461956	5497	Economy	11800.00
0005435461884	5497	Economy	11800.00
0005433527234	5497	Economy	11800.00
0005435765684	5497	Economy	11800.00
0005433527235	5497	Economy	11800.00
0005434264719	5497	Economy	11800.00
0005435765740	5497	Economy	11800.00
0005435461804	5497	Economy	11800.00
0005435765724	5497	Economy	11800.00
0005435765704	5497	Economy	11800.00
0005435461867	5497	Economy	11800.00
0005435765728	5497	Economy	11800.00
0005432140379	5497	Economy	11800.00
0005435765678	5497	Economy	11800.00
0005435765730	5497	Economy	11800.00
0005435765719	5497	Economy	11800.00
0005435765681	5497	Economy	11800.00
0005432535751	5497	Economy	11800.00
0005435765700	5497	Economy	11800.00
0005435461840	5497	Economy	11800.00
0005435765716	5497	Economy	11800.00
0005435765673	5497	Economy	11800.00
0005435765682	5497	Economy	11800.00
0005432140381	5497	Economy	11800.00
0005435725556	5497	Economy	12900.00
0005435765693	5497	Economy	12900.00
0005435765705	5497	Economy	11800.00
0005435765727	5497	Economy	11800.00
0005435765695	5497	Economy	11800.00
0005434264760	5497	Economy	11800.00
0005435765698	5497	Economy	12900.00
0005435765679	5497	Economy	11800.00
0005435765714	5497	Economy	11800.00
0005435725555	5497	Economy	11800.00
0005434264726	5497	Economy	11800.00
0005435725554	5497	Economy	11800.00
0005435461789	5497	Economy	11800.00
0005434264779	5497	Economy	11800.00
0005435765721	5497	Economy	11800.00
0005435461796	5497	Economy	11800.00
0005435765687	5497	Economy	11800.00
0005435765702	5497	Economy	11800.00
0005435765680	5497	Economy	11800.00
0005435765683	5497	Economy	11800.00
0005434831072	5497	Economy	11800.00
0005435765701	5497	Economy	11800.00
0005433529245	5497	Economy	11800.00
0005435461919	5497	Economy	11800.00
0005435765694	5497	Economy	11800.00
0005435765674	5497	Economy	11800.00
0005434831074	5497	Economy	11800.00
0005435723029	5497	Economy	11800.00
0005435765736	5497	Economy	11800.00
0005434264766	5497	Economy	11800.00
0005433527236	5497	Economy	11800.00
0005435461880	5497	Economy	11800.00
0005435765689	5497	Economy	11800.00
0005435461935	5497	Economy	11800.00
0005435461837	5497	Economy	11800.00
0005435722034	5497	Economy	11800.00
0005433527238	5497	Economy	11800.00
0005432535752	5497	Economy	11800.00
0005434264691	5497	Economy	11800.00
0005435765676	5497	Economy	11800.00
0005435765686	5497	Economy	11800.00
0005435461826	5497	Economy	11800.00
0005435765685	5497	Economy	11800.00
0005435461838	5497	Economy	11800.00
0005435765688	5497	Economy	11800.00
0005435765715	5497	Economy	11800.00
0005435765708	5497	Economy	11800.00
0005435461866	5497	Economy	11800.00
0005434264699	5497	Economy	11800.00
0005435765696	5497	Economy	11800.00
0005435765712	5497	Economy	11800.00
0005435461915	5497	Economy	11800.00
0005435461785	5497	Economy	11800.00
0005435461806	5497	Economy	11800.00
0005435765726	5497	Economy	11800.00
0005435765739	5497	Economy	11800.00
0005435735098	5497	Economy	11800.00
0005433529248	5497	Economy	11800.00
0005435765250	13472	Business	35300.00
0005435765396	13472	Business	35300.00
0005435765273	13472	Business	35300.00
0005435765191	13472	Business	35300.00
0005435462118	13472	Business	35300.00
0005435765175	13472	Business	35300.00
0005435765502	13472	Business	35300.00
0005435462116	13472	Business	35300.00
0005435462133	13472	Business	35300.00
0005434264933	13472	Business	35300.00
0005435765245	13472	Business	35300.00
0005435765312	13472	Business	35300.00
0005434264924	13472	Business	35300.00
0005435765253	13472	Business	35300.00
0005435765174	13472	Business	35300.00
0005435462132	13472	Economy	12900.00
0005435462123	13472	Economy	12900.00
0005435765165	13472	Economy	12900.00
0005435765163	13472	Economy	11800.00
0005435765318	13472	Economy	11800.00
0005435723011	13472	Economy	11800.00
0005435462119	13472	Economy	11800.00
0005435765181	13472	Economy	11800.00
0005434264927	13472	Economy	11800.00
0005434264937	13472	Economy	11800.00
0005435765202	13472	Economy	11800.00
0005435765311	13472	Economy	11800.00
0005434264926	13472	Economy	11800.00
0005435462135	13472	Economy	11800.00
0005434264936	13472	Economy	11800.00
0005435462117	13472	Economy	11800.00
0005435765162	13472	Economy	11800.00
0005432535794	13472	Economy	11800.00
0005435765252	13472	Economy	11800.00
0005435765321	13472	Economy	11800.00
0005435462120	13472	Economy	11800.00
0005434264922	13472	Economy	11800.00
0005435765254	13472	Economy	11800.00
0005435735062	13472	Economy	11800.00
0005435462125	13472	Economy	11800.00
0005435765204	13472	Economy	11800.00
0005435462139	13472	Economy	11800.00
0005435765399	13472	Economy	11800.00
0005435765285	13472	Economy	11800.00
0005435462105	13472	Economy	11800.00
0005435735063	13472	Economy	11800.00
0005435765248	13472	Economy	11800.00
0005434264915	13472	Economy	11800.00
0005432194477	13472	Economy	11800.00
0005435765149	13472	Economy	11800.00
0005434264929	13472	Economy	11800.00
0005435462137	13472	Economy	11800.00
0005435462108	13472	Economy	11800.00
0005435765172	13472	Economy	11800.00
0005435723015	13472	Economy	11800.00
0005435462122	13472	Economy	11800.00
0005435462131	13472	Economy	11800.00
0005435462134	13472	Economy	11800.00
0005434264935	13472	Economy	11800.00
0005435462111	13472	Economy	11800.00
0005435462106	13472	Economy	11800.00
0005435735066	13472	Economy	11800.00
0005434264919	13472	Economy	11800.00
0005432194474	13472	Economy	11800.00
0005434831111	13472	Economy	11800.00
0005435765316	13472	Economy	11800.00
0005435462104	13472	Economy	11800.00
0005434264938	13472	Economy	11800.00
0005434264934	13472	Economy	11800.00
0005435765317	13472	Economy	11800.00
0005434264917	13472	Economy	11800.00
0005432194475	13472	Economy	11800.00
0005435462121	13472	Economy	11800.00
0005434264921	13472	Economy	11800.00
0005435765310	13472	Economy	11800.00
0005435765323	13472	Economy	11800.00
0005435765304	13472	Economy	11800.00
0005435462107	13472	Economy	11800.00
0005435462130	13472	Economy	11800.00
0005434264925	13472	Economy	11800.00
0005432535792	13472	Economy	11800.00
0005435765110	13472	Economy	11800.00
0005435725514	13472	Economy	11800.00
0005434264918	13472	Economy	11800.00
0005435462141	13472	Economy	12900.00
0005434831110	13472	Economy	11800.00
0005435765303	13472	Economy	12900.00
0005435462113	13472	Economy	11800.00
0005432535791	13472	Economy	12900.00
0005435462138	13472	Economy	11800.00
0005435462112	13472	Economy	11800.00
0005435462142	13472	Economy	11800.00
0005434264920	13472	Economy	11800.00
0005434264931	13472	Economy	11800.00
0005435765203	13472	Economy	11800.00
0005435765247	13472	Economy	11800.00
0005435462124	13472	Economy	11800.00
0005435765164	13472	Economy	11800.00
0005435462126	13472	Economy	11800.00
0005434831113	13472	Economy	11800.00
0005434264928	13472	Economy	11800.00
0005432194476	13472	Economy	11800.00
0005435462115	13472	Economy	11800.00
0005435735061	13472	Economy	11800.00
0005434831114	13472	Economy	11800.00
0005435462110	13472	Economy	11800.00
0005435765329	13472	Economy	11800.00
0005434831112	13472	Economy	11800.00
0005432535793	13472	Economy	11800.00
0005435765166	13472	Economy	11800.00
0005435765542	13472	Economy	11800.00
0005435765554	13472	Economy	11800.00
0005435462109	13472	Economy	11800.00
0005434264932	13472	Economy	11800.00
0005435765341	13472	Economy	11800.00
0005434264914	13472	Economy	11800.00
0005435462127	13472	Economy	11800.00
0005434264923	13472	Economy	11800.00
0005435765249	13472	Economy	11800.00
0005435765261	13472	Economy	11800.00
0005435462140	13472	Economy	11800.00
0005435765211	13472	Economy	11800.00
0005432194478	13472	Economy	11800.00
0005435462129	13472	Economy	11800.00
0005435462136	13472	Economy	11800.00
0005432535795	13472	Economy	11800.00
0005434264916	13472	Economy	11800.00
0005435765121	13472	Economy	11800.00
0005435765182	13472	Economy	11800.00
0005435765308	13472	Economy	11800.00
0005435725513	13472	Economy	11800.00
0005435735055	13472	Economy	11800.00
0005434264940	13472	Economy	11800.00
0005435765173	13472	Economy	11800.00
0005435722015	13472	Economy	11800.00
0005435462128	13472	Economy	11800.00
0005435462114	13472	Economy	11800.00
0005434264930	13472	Economy	11800.00
0005434264939	13472	Economy	11800.00
0005434602873	18663	Economy	3300.00
0005434602874	18663	Economy	3300.00
0005434602860	18663	Economy	3300.00
0005434513554	18659	Economy	3300.00
0005434514942	18659	Economy	3300.00
0005434513555	18659	Economy	3300.00
0005434604837	18659	Economy	3300.00
0005434513556	18659	Economy	3300.00
0005434514943	18659	Economy	3300.00
0005434514944	18659	Economy	3300.00
0005434514931	19223	Economy	3300.00
0005435846219	25082	Economy	29400.00
0005435846220	25082	Economy	29400.00
0005435846223	25082	Economy	29400.00
0005435846218	25082	Economy	29400.00
0005432649298	25082	Economy	29400.00
0005435846224	25082	Economy	29400.00
0005435846222	25082	Economy	29400.00
0005435846221	25082	Economy	29400.00
0005432649301	25082	Economy	29400.00
0005433007938	1826	Business	48700.00
0005433007928	1826	Business	48700.00
0005433007939	1826	Business	48700.00
0005433007844	1826	Business	48700.00
0005433008114	1826	Business	48700.00
0005433284786	1826	Business	48700.00
0005433007975	1826	Business	48700.00
0005433007827	1826	Business	48700.00
0005433007862	1826	Business	48700.00
0005433008013	1826	Economy	16200.00
0005433284890	1826	Economy	16200.00
0005433007954	1826	Economy	16200.00
0005433284815	1826	Economy	16200.00
0005433284891	1826	Economy	16200.00
0005433007891	1826	Economy	17900.00
0005433284840	1826	Economy	17900.00
0005433008113	1826	Economy	16200.00
0005433284828	1826	Economy	16200.00
0005433284818	1826	Economy	16200.00
0005433008129	1826	Economy	16200.00
0005433007863	1826	Economy	16200.00
0005433284798	1826	Economy	16200.00
0005433008001	1826	Economy	16200.00
0005432295857	1826	Economy	16200.00
0005433008130	1826	Economy	16200.00
0005433008050	1826	Economy	16200.00
0005433284795	1826	Economy	16200.00
0005433284892	1826	Economy	16200.00
0005433008049	1826	Economy	16200.00
0005433284841	1826	Economy	16200.00
0005433284842	1826	Economy	16200.00
0005432295858	1826	Economy	16200.00
0005433008042	1826	Economy	16200.00
0005433810517	1826	Economy	16200.00
0005433284796	1826	Economy	16200.00
0005433284873	1826	Economy	16200.00
0005433008045	1826	Economy	16200.00
0005433007826	1826	Economy	16200.00
0005433284819	1826	Economy	16200.00
0005433008022	1826	Economy	16200.00
0005433007872	1826	Economy	16200.00
0005433007830	1826	Economy	16200.00
0005433810516	1826	Economy	16200.00
0005433810515	1826	Economy	16200.00
0005433284787	1826	Economy	16200.00
0005433284845	1826	Economy	16200.00
0005433284876	1826	Economy	16200.00
0005433008000	1826	Economy	16200.00
0005433007974	1826	Economy	16200.00
0005433008043	1826	Economy	16200.00
0005433284825	1826	Economy	16200.00
0005433284773	1826	Economy	16200.00
0005433007913	1826	Economy	16200.00
0005433284872	1826	Economy	16200.00
0005433008023	1826	Economy	16200.00
0005433007831	1826	Economy	16200.00
0005433007968	1826	Economy	16200.00
0005433008239	22614	Business	48700.00
0005433008226	22614	Business	48700.00
0005433008200	22614	Business	48700.00
0005433008222	22614	Business	48700.00
0005433008232	22614	Business	48700.00
0005433285031	22614	Business	48700.00
0005433008208	22614	Business	48700.00
0005433285008	22614	Business	48700.00
0005433285036	22614	Business	48700.00
0005433008229	22614	Business	48700.00
0005433008194	22614	Economy	16200.00
0005433285010	22614	Economy	16200.00
0005433008224	22614	Economy	16200.00
0005433008197	22614	Economy	16200.00
0005433008235	22614	Economy	16200.00
0005433285028	22614	Economy	16200.00
0005433008231	22614	Economy	16200.00
0005433285024	22614	Economy	16200.00
0005433008219	22614	Economy	17900.00
0005433008230	22614	Economy	17900.00
0005433285007	22614	Economy	17900.00
0005433008206	22614	Economy	16200.00
0005433008213	22614	Economy	16200.00
0005433285033	22614	Economy	16200.00
0005433285016	22614	Economy	16200.00
0005433008234	22614	Economy	16200.00
0005433008198	22614	Economy	16200.00
0005433285018	22614	Economy	16200.00
0005433008212	22614	Economy	16200.00
0005433008204	22614	Economy	16200.00
0005433285014	22614	Economy	16200.00
0005433285019	22614	Economy	16200.00
0005433008209	22614	Economy	16200.00
0005433008214	22614	Economy	16200.00
0005433008203	22614	Economy	16200.00
0005433285030	22614	Economy	16200.00
0005433008202	22614	Economy	16200.00
0005433285015	22614	Economy	16200.00
0005433285020	22614	Economy	16200.00
0005433008233	22614	Economy	16200.00
0005433008227	22614	Economy	16200.00
0005433008225	22614	Economy	16200.00
0005433008199	22614	Economy	16200.00
0005433008215	22614	Economy	16200.00
0005433008195	22614	Economy	16200.00
0005433008238	22614	Economy	16200.00
0005433285032	22614	Economy	16200.00
0005433285009	22614	Economy	16200.00
0005433285012	22614	Economy	16200.00
0005433285026	22614	Economy	16200.00
0005433008220	22614	Economy	16200.00
0005433285021	22614	Economy	16200.00
0005433008196	22614	Economy	16200.00
0005433285029	22614	Economy	16200.00
0005433285037	22614	Economy	16200.00
0005433285025	22614	Economy	16200.00
0005433008221	22614	Economy	16200.00
0005433008237	22614	Economy	16200.00
0005433008217	22614	Economy	16200.00
0005433285038	22614	Economy	16200.00
0005433008218	22614	Economy	16200.00
0005433008201	22614	Economy	16200.00
0005433285022	22614	Economy	16200.00
0005433008223	22614	Economy	16200.00
0005433008211	22614	Economy	16200.00
0005433008216	22614	Economy	16200.00
0005433008205	22614	Economy	16200.00
0005433285034	22614	Economy	16200.00
0005433008207	22614	Economy	16200.00
0005433008210	22614	Economy	16200.00
0005433285027	22614	Economy	16200.00
0005433285011	22614	Economy	16200.00
0005433285013	22614	Economy	16200.00
0005433008236	22614	Economy	16200.00
0005433285023	22614	Economy	16200.00
0005433285017	22614	Economy	16200.00
0005433008228	22614	Economy	16200.00
0005433285035	22614	Economy	16200.00
0005432755021	12283	Business	83800.00
0005434152777	12283	Economy	30700.00
0005432751469	12283	Economy	27900.00
0005434152779	12283	Economy	27900.00
0005434152780	12283	Economy	27900.00
0005432755022	12283	Economy	27900.00
0005434152772	12283	Economy	27900.00
0005434152773	12283	Economy	27900.00
0005432755015	12283	Economy	27900.00
0005432751468	12283	Economy	27900.00
0005434152774	12283	Economy	27900.00
0005434152775	12283	Economy	27900.00
0005434152776	12283	Economy	27900.00
0005434152778	12283	Economy	27900.00
0005433846241	5576	Business	99800.00
0005435282152	5576	Business	99800.00
0005433815340	5576	Business	99800.00
0005433846252	5576	Business	99800.00
0005435282090	5576	Business	99800.00
0005433846203	5576	Business	99800.00
0005433846245	5576	Business	99800.00
0005433846248	5576	Business	99800.00
0005433846244	5576	Business	99800.00
0005433815341	5576	Business	99800.00
0005433846215	5576	Business	99800.00
0005433846247	5576	Business	99800.00
0005435282130	5576	Business	99800.00
0005433815343	5576	Economy	33300.00
0005433846261	5576	Economy	33300.00
0005433846260	5576	Economy	33300.00
0005433846254	5576	Economy	33300.00
0005435282104	5576	Economy	33300.00
0005433846237	5576	Economy	33300.00
0005433846259	5576	Economy	33300.00
0005433815342	5576	Economy	33300.00
0005433846232	5576	Economy	33300.00
0005433846221	5576	Economy	33300.00
0005435282134	5576	Economy	36600.00
0005433846239	5576	Economy	36600.00
0005435282131	5576	Economy	36600.00
0005433846214	5576	Economy	33300.00
0005433846255	5576	Economy	33300.00
0005433846258	5576	Economy	33300.00
0005432081459	5576	Economy	33300.00
0005433846220	5576	Economy	33300.00
0005433846240	5576	Economy	33300.00
0005433846246	5576	Economy	33300.00
0005433846228	5576	Economy	33300.00
0005433846223	5576	Economy	33300.00
0005433846257	5576	Economy	33300.00
0005433846236	5576	Economy	33300.00
0005433846217	5576	Economy	33300.00
0005433846209	5576	Economy	33300.00
0005433846242	5576	Economy	33300.00
0005435282084	5576	Economy	33300.00
0005433846213	5576	Economy	33300.00
0005433846205	5576	Economy	33300.00
0005432081458	5576	Economy	33300.00
0005433846218	5576	Economy	33300.00
0005433846256	5576	Economy	33300.00
0005432081453	5576	Economy	33300.00
0005433846253	5576	Economy	33300.00
0005432081455	5576	Economy	33300.00
0005433846231	5576	Economy	33300.00
0005433846212	5576	Economy	33300.00
0005435282116	5576	Economy	33300.00
0005433846230	5576	Economy	33300.00
0005433846229	5576	Economy	33300.00
0005433846216	5576	Economy	33300.00
0005435282070	5576	Economy	33300.00
0005433846227	5576	Economy	33300.00
0005432081457	5576	Economy	33300.00
0005432081456	5576	Economy	33300.00
0005435282085	5576	Economy	33300.00
0005433846211	5576	Economy	33300.00
0005433846249	5576	Economy	33300.00
0005433846206	5576	Economy	33300.00
0005433846250	5576	Economy	33300.00
0005432081454	5576	Economy	33300.00
0005433846225	5576	Economy	33300.00
0005433846238	5576	Economy	33300.00
0005433815344	5576	Economy	33300.00
0005433846226	5576	Economy	33300.00
0005433846224	5576	Economy	33300.00
0005433846234	5576	Economy	33300.00
0005433846222	5576	Economy	33300.00
0005433846207	5576	Economy	33300.00
0005435282133	5576	Economy	33300.00
0005433846243	5576	Economy	33300.00
0005433846235	5576	Economy	33300.00
0005433846251	5576	Economy	33300.00
0005433846202	5576	Economy	33300.00
0005435282107	5576	Economy	33300.00
0005433846201	5576	Economy	33300.00
0005433846210	5576	Economy	33300.00
0005435282119	5576	Economy	33300.00
0005433846208	5576	Economy	33300.00
0005433846204	5576	Economy	33300.00
0005433846219	5576	Economy	33300.00
0005433846233	5576	Economy	33300.00
0005433815307	13854	Business	99800.00
0005432003675	13854	Business	99800.00
0005432003676	13854	Business	99800.00
0005433845802	13854	Business	99800.00
0005435282292	13854	Business	99800.00
0005433845784	13854	Business	99800.00
0005435282287	13854	Business	99800.00
0005435282306	13854	Business	99800.00
0005435282301	13854	Business	99800.00
0005433845751	13854	Business	99800.00
0005433845910	13854	Business	99800.00
0005433845901	13854	Business	99800.00
0005433815319	13854	Economy	33300.00
0005435282303	13854	Economy	33300.00
0005435282300	13854	Economy	33300.00
0005434173488	13854	Economy	33300.00
0005433845790	13854	Economy	33300.00
0005434173486	13854	Economy	33300.00
0005433845778	13854	Economy	33300.00
0005433845735	13854	Economy	33300.00
0005435282302	13854	Economy	33300.00
0005435282298	13854	Economy	36600.00
0005434173485	13854	Economy	36600.00
0005433845725	13854	Economy	36600.00
0005435282308	13854	Economy	33300.00
0005433845726	13854	Economy	33300.00
0005435282299	13854	Economy	33300.00
0005433845841	13854	Economy	33300.00
0005432003674	13854	Economy	33300.00
0005435282293	13854	Economy	33300.00
0005433815318	13854	Economy	33300.00
0005433845707	13854	Economy	33300.00
0005433845777	13854	Economy	33300.00
0005433845830	13854	Economy	33300.00
0005435282295	13854	Economy	33300.00
0005433845979	13854	Economy	33300.00
0005433845748	13854	Economy	33300.00
0005435282305	13854	Economy	33300.00
0005433845708	13854	Economy	33300.00
0005434173487	13854	Economy	33300.00
0005433845706	13854	Economy	33300.00
0005435282304	13854	Economy	33300.00
0005435282309	13854	Economy	33300.00
0005433815317	13854	Economy	33300.00
0005433845872	13854	Economy	33300.00
0005433845744	13854	Economy	33300.00
0005435282294	13854	Economy	33300.00
0005435282296	13854	Economy	33300.00
0005433845902	13854	Economy	33300.00
0005435282288	13854	Economy	33300.00
0005433845730	13854	Economy	33300.00
0005433815306	13854	Economy	33300.00
0005433845893	13854	Economy	33300.00
0005435282285	13854	Economy	33300.00
0005433845769	13854	Economy	33300.00
0005433845879	13854	Economy	33300.00
0005435282307	13854	Economy	33300.00
0005433845700	13854	Economy	33300.00
0005433845776	13854	Economy	33300.00
0005435282289	13854	Economy	33300.00
0005433845734	13854	Economy	33300.00
0005433845978	13854	Economy	33300.00
0005433845878	13854	Economy	33300.00
0005435282297	13854	Economy	33300.00
0005433845974	13854	Economy	33300.00
0005435282286	13854	Economy	33300.00
0005433845722	13854	Economy	33300.00
0005435282290	13854	Economy	33300.00
0005435282291	13854	Economy	33300.00
0005434620424	7829	Economy	16600.00
0005434620427	7829	Economy	16600.00
0005434620430	7829	Economy	16600.00
0005434620418	7829	Economy	16600.00
0005434620422	7829	Economy	15100.00
0005435332154	7829	Economy	15100.00
0005435332174	7829	Economy	15100.00
0005434620428	7829	Economy	15100.00
0005434620431	7829	Economy	15100.00
0005434620415	7829	Economy	15100.00
0005434620419	7829	Economy	15100.00
0005435332162	7829	Economy	15100.00
0005435332209	7829	Economy	15100.00
0005434620411	7829	Economy	15100.00
0005434620425	7829	Economy	15100.00
0005432112497	7829	Economy	15100.00
0005434620429	7829	Economy	15100.00
0005434620414	7829	Economy	15100.00
0005434620416	7829	Economy	15100.00
0005435332175	7829	Economy	15100.00
0005434620413	7829	Economy	15100.00
0005434620412	7829	Economy	15100.00
0005434620420	7829	Economy	15100.00
0005435332161	7829	Economy	15100.00
0005434620421	7829	Economy	15100.00
0005435332163	7829	Economy	15100.00
0005434620423	7829	Economy	15100.00
0005434620417	7829	Economy	15100.00
0005435332191	7829	Economy	15100.00
0005435332199	7829	Economy	15100.00
0005432112496	7829	Economy	15100.00
0005434620432	7829	Economy	15100.00
0005435332169	7829	Economy	15100.00
0005434620426	7829	Economy	15100.00
0005434620326	32957	Economy	16600.00
0005434620225	32957	Economy	16600.00
0005434620313	32957	Economy	15100.00
0005435332248	32957	Economy	15100.00
0005435332250	32957	Economy	15100.00
0005435332245	32957	Economy	15100.00
0005434620296	32957	Economy	15100.00
0005434620262	32957	Economy	15100.00
0005434620245	32957	Economy	15100.00
0005434620226	32957	Economy	15100.00
0005434620297	32957	Economy	15100.00
0005435332246	32957	Economy	15100.00
0005435332244	32957	Economy	15100.00
0005435332252	32957	Economy	15100.00
0005435332242	32957	Economy	15100.00
0005434620244	32957	Economy	15100.00
0005435332253	32957	Economy	15100.00
0005435332251	32957	Economy	15100.00
0005434620249	32957	Economy	15100.00
0005435332243	32957	Economy	15100.00
0005434620246	32957	Economy	15100.00
0005434620261	32957	Economy	15100.00
0005435332247	32957	Economy	15100.00
0005435332249	32957	Economy	15100.00
0005434620243	32957	Economy	15100.00
0005435785056	4282	Business	38000.00
0005434993938	4282	Business	38000.00
0005435785067	4282	Business	38000.00
0005435785049	4282	Business	38000.00
0005435785070	4282	Business	38000.00
0005435785064	4282	Business	38000.00
0005434993941	4282	Business	38000.00
0005434993937	4282	Economy	12700.00
0005434993942	4282	Economy	12700.00
0005435787334	4282	Economy	12700.00
0005435785074	4282	Economy	12700.00
0005435785060	4282	Economy	12700.00
0005434993939	4282	Economy	13900.00
0005434993936	4282	Economy	13900.00
0005435785057	4282	Economy	13900.00
0005435787336	4282	Economy	13900.00
0005435785068	4282	Economy	12700.00
0005435785047	4282	Economy	12700.00
0005435785078	4282	Economy	12700.00
0005432190597	4282	Economy	12700.00
0005435785063	4282	Economy	12700.00
0005435785071	4282	Economy	12700.00
0005432190596	4282	Economy	12700.00
0005435918597	4282	Economy	12700.00
0005435937317	4282	Economy	12700.00
0005435785072	4282	Economy	12700.00
0005435785052	4282	Economy	12700.00
0005435785061	4282	Economy	12700.00
0005432190598	4282	Economy	12700.00
0005435785080	4282	Economy	12700.00
0005435785055	4282	Economy	12700.00
0005435785054	4282	Economy	12700.00
0005434993944	4282	Economy	12700.00
0005434993935	4282	Economy	12700.00
0005435785076	4282	Economy	12700.00
0005435785048	4282	Economy	12700.00
0005434993940	4282	Economy	12700.00
0005434993945	4282	Economy	12700.00
0005435785075	4282	Economy	12700.00
0005435785069	4282	Economy	12700.00
0005435785077	4282	Economy	12700.00
0005434993943	4282	Economy	12700.00
0005435937310	4282	Economy	12700.00
0005435785058	4282	Economy	12700.00
0005435787335	4282	Economy	12700.00
0005435785079	4282	Economy	12700.00
0005435937316	4282	Economy	12700.00
0005435937311	4282	Economy	12700.00
0005435785065	4282	Economy	12700.00
0005435785059	4282	Economy	12700.00
0005435785062	4282	Economy	12700.00
0005435785051	4282	Economy	12700.00
0005435787337	4282	Economy	12700.00
0005435918581	4282	Economy	12700.00
0005435785066	4282	Economy	12700.00
0005435785046	4282	Economy	12700.00
0005435785050	4282	Economy	12700.00
0005435785073	4282	Economy	12700.00
0005435785053	4282	Economy	12700.00
0005435937341	27312	Business	38000.00
0005435918615	27312	Business	38000.00
0005435937337	27312	Business	38000.00
0005435937342	27312	Economy	12700.00
0005435784750	27312	Economy	12700.00
0005435784748	27312	Economy	12700.00
0005435937339	27312	Economy	12700.00
0005435784747	27312	Economy	12700.00
0005432195674	27312	Economy	12700.00
0005435784749	27312	Economy	12700.00
0005434993871	27312	Economy	12700.00
0005432195675	27312	Economy	12700.00
0005435787320	27312	Economy	12700.00
0005435937334	27312	Economy	12700.00
0005434993853	27312	Economy	12700.00
0005434993870	27312	Economy	12700.00
0005435937340	27312	Economy	12700.00
0005435937338	27312	Economy	12700.00
0005435784810	27312	Economy	12700.00
0005435937343	27312	Economy	12700.00
0005434993857	27312	Economy	12700.00
0005434993854	27312	Economy	12700.00
0005434993856	27312	Economy	12700.00
0005434993867	27312	Economy	12700.00
0005435918613	27312	Economy	12700.00
0005435937335	27312	Economy	12700.00
0005434993887	27312	Economy	12700.00
0005435937336	27312	Economy	12700.00
0005435918614	27312	Economy	12700.00
0005435918616	27312	Economy	12700.00
0005435918612	27312	Economy	12700.00
0005432195673	27312	Economy	12700.00
0005432146180	19894	Economy	12800.00
0005432146181	19894	Economy	12800.00
0005434081717	4746	Business	40900.00
0005432459407	4746	Business	40900.00
0005432567095	4746	Business	40900.00
0005432459416	4746	Business	40900.00
0005434081708	4746	Business	40900.00
0005432459414	4746	Business	40900.00
0005432567096	4746	Business	40900.00
0005433451603	4746	Business	40900.00
0005432567088	4746	Business	40900.00
0005432459408	4746	Business	40900.00
0005432459436	4746	Business	40900.00
0005432170333	4746	Business	40900.00
0005432459405	4746	Business	40900.00
0005432567115	4746	Business	40900.00
0005432567117	4746	Business	40900.00
0005432459392	4746	Business	40900.00
0005433726085	4746	Business	40900.00
0005432567143	4746	Business	40900.00
0005432571290	4746	Business	40900.00
0005432459423	4746	Business	40900.00
0005432567147	4746	Business	40900.00
0005432459420	4746	Business	40900.00
0005434081721	4746	Business	40900.00
0005432459395	4746	Economy	15000.00
0005433451602	4746	Economy	13600.00
0005432459389	4746	Economy	13600.00
0005432567108	4746	Economy	13600.00
0005432459426	4746	Economy	13600.00
0005432567129	4746	Economy	13600.00
0005432459402	4746	Economy	13600.00
0005432567133	4746	Economy	13600.00
0005432567132	4746	Economy	13600.00
0005434081715	4746	Economy	13600.00
0005432567094	4746	Economy	13600.00
0005432567100	4746	Economy	13600.00
0005432567128	4746	Economy	13600.00
0005432459399	4746	Economy	13600.00
0005434081698	4746	Economy	13600.00
0005432567136	4746	Economy	13600.00
0005432567116	4746	Economy	13600.00
0005432170328	4746	Economy	13600.00
0005432459396	4746	Economy	13600.00
0005432567092	4746	Economy	13600.00
0005432567126	4746	Economy	13600.00
0005432567109	4746	Economy	13600.00
0005432567141	4746	Economy	13600.00
0005434081723	4746	Economy	13600.00
0005432567152	4746	Economy	13600.00
0005432459387	4746	Economy	13600.00
0005432459421	4746	Economy	13600.00
0005432170334	4746	Economy	13600.00
0005434081727	4746	Economy	13600.00
0005433452722	4746	Economy	13600.00
0005432459429	4746	Economy	13600.00
0005432459428	4746	Economy	13600.00
0005432567142	4746	Economy	13600.00
0005432567137	4746	Economy	13600.00
0005432170332	4746	Economy	13600.00
0005432459400	4746	Economy	13600.00
0005432186840	4746	Economy	13600.00
0005432567127	4746	Economy	13600.00
0005432567099	4746	Economy	13600.00
0005432459401	4746	Economy	13600.00
0005432170329	4746	Economy	13600.00
0005434081700	4746	Economy	13600.00
0005432459403	4746	Economy	13600.00
0005434081713	4746	Economy	13600.00
0005432567151	4746	Economy	13600.00
0005432459431	4746	Economy	13600.00
0005434081699	4746	Economy	13600.00
0005432571291	4746	Economy	13600.00
0005432567120	4746	Economy	13600.00
0005434081702	4746	Economy	13600.00
0005432567150	4746	Economy	13600.00
0005432459409	4746	Economy	13600.00
0005432571288	4746	Economy	13600.00
0005432459384	4746	Economy	13600.00
0005432567146	4746	Economy	13600.00
0005432567102	4746	Economy	13600.00
0005432567113	4746	Economy	13600.00
0005434081712	4746	Economy	13600.00
0005432186839	4746	Economy	13600.00
0005434081707	4746	Economy	13600.00
0005432170331	4746	Economy	13600.00
0005432459418	4746	Economy	13600.00
0005434081709	4746	Economy	13600.00
0005434081726	4746	Economy	13600.00
0005434081725	4746	Economy	13600.00
0005432459425	4746	Economy	13600.00
0005432567097	4746	Economy	13600.00
0005434081724	4746	Economy	13600.00
0005432459430	4746	Economy	13600.00
0005432459404	4746	Economy	13600.00
0005432459398	4746	Economy	13600.00
0005433726084	4746	Economy	13600.00
0005432567123	4746	Economy	13600.00
0005432567098	4746	Economy	13600.00
0005432186838	4746	Economy	13600.00
0005432459391	4746	Economy	13600.00
0005432459433	4746	Economy	13600.00
0005432567134	4746	Economy	15000.00
0005432459394	4746	Economy	13600.00
0005434081705	4746	Economy	13600.00
0005432459427	4746	Economy	15000.00
0005432459390	4746	Economy	15000.00
0005432567107	4746	Economy	13600.00
0005432459435	4746	Economy	13600.00
0005432170330	4746	Economy	13600.00
0005432459413	4746	Economy	13600.00
0005434081716	4746	Economy	13600.00
0005432459406	4746	Economy	13600.00
0005432186837	4746	Economy	13600.00
0005434081703	4746	Economy	13600.00
0005433452721	4746	Economy	13600.00
0005432459434	4746	Economy	13600.00
0005432459385	4746	Economy	13600.00
0005432459419	4746	Economy	13600.00
0005432567138	4746	Economy	13600.00
0005432459432	4746	Economy	13600.00
0005432567125	4746	Economy	13600.00
0005432567106	4746	Economy	13600.00
0005434081719	4746	Economy	13600.00
0005432567130	4746	Economy	13600.00
0005432567131	4746	Economy	13600.00
0005434081711	4746	Economy	13600.00
0005432567093	4746	Economy	13600.00
0005434081720	4746	Economy	13600.00
0005432571289	4746	Economy	13600.00
0005432567090	4746	Economy	13600.00
0005434081714	4746	Economy	13600.00
0005432567089	4746	Economy	13600.00
0005432567121	4746	Economy	13600.00
0005432567110	4746	Economy	13600.00
0005432567145	4746	Economy	13600.00
0005432567105	4746	Economy	13600.00
0005432567148	4746	Economy	13600.00
0005432567114	4746	Economy	13600.00
0005432567118	4746	Economy	13600.00
0005434081706	4746	Economy	13600.00
0005432567122	4746	Economy	13600.00
0005432567091	4746	Economy	13600.00
0005432459424	4746	Economy	13600.00
0005432567103	4746	Economy	13600.00
0005432567101	4746	Economy	13600.00
0005434081701	4746	Economy	13600.00
0005432567144	4746	Economy	13600.00
0005432567104	4746	Economy	13600.00
0005432567139	4746	Economy	13600.00
0005434081718	4746	Economy	13600.00
0005432459411	4746	Economy	13600.00
0005434081722	4746	Economy	13600.00
0005432459393	4746	Economy	13600.00
0005432567140	4746	Economy	13600.00
0005434081704	4746	Economy	13600.00
0005432459422	4746	Economy	13600.00
0005432567149	4746	Economy	13600.00
0005432567119	4746	Economy	13600.00
0005432459410	4746	Economy	13600.00
0005432567111	4746	Economy	13600.00
0005432459397	4746	Economy	13600.00
0005432459417	4746	Economy	13600.00
0005432567124	4746	Economy	13600.00
0005432459415	4746	Economy	13600.00
0005432459388	4746	Economy	13600.00
0005432459386	4746	Economy	13600.00
0005432567112	4746	Economy	13600.00
0005432459412	4746	Economy	13600.00
0005434081710	4746	Economy	13600.00
0005432567135	4746	Economy	13600.00
0005432566713	30544	Business	40900.00
0005432566660	30544	Business	40900.00
0005432566858	30544	Business	40900.00
0005432458974	30544	Business	40900.00
0005432459055	30544	Business	40900.00
0005433452707	30544	Business	40900.00
0005432459110	30544	Business	40900.00
0005432459093	30544	Business	40900.00
0005432571260	30544	Business	40900.00
0005432459156	30544	Business	40900.00
0005432566722	30544	Business	40900.00
0005432459069	30544	Business	40900.00
0005432571264	30544	Business	40900.00
0005432161133	30544	Business	40900.00
0005432566847	30544	Business	40900.00
0005432571262	30544	Business	40900.00
0005432566901	30544	Business	40900.00
0005432459271	30544	Business	40900.00
0005432459108	30544	Business	40900.00
0005434081521	30544	Business	40900.00
0005432459150	30544	Business	40900.00
0005432459058	30544	Business	40900.00
0005432458994	30544	Business	40900.00
0005434081472	30544	Business	40900.00
0005434081513	30544	Business	40900.00
0005434081478	30544	Economy	15000.00
0005432213575	30544	Economy	15000.00
0005432459054	30544	Economy	13600.00
0005432459045	30544	Economy	13600.00
0005432459147	30544	Economy	13600.00
0005432459095	30544	Economy	13600.00
0005433454843	30544	Economy	13600.00
0005432459157	30544	Economy	13600.00
0005432459270	30544	Economy	13600.00
0005432161132	30544	Economy	13600.00
0005432213574	30544	Economy	13600.00
0005432566727	30544	Economy	13600.00
0005432566834	30544	Economy	13600.00
0005432566664	30544	Economy	13600.00
0005432566844	30544	Economy	13600.00
0005432571263	30544	Economy	13600.00
0005432459044	30544	Economy	13600.00
0005432459106	30544	Economy	13600.00
0005432566630	30544	Economy	13600.00
0005432459053	30544	Economy	13600.00
0005434081479	30544	Economy	13600.00
0005432459073	30544	Economy	13600.00
0005434081492	30544	Economy	13600.00
0005432566736	30544	Economy	13600.00
0005432566619	30544	Economy	13600.00
0005434081498	30544	Economy	13600.00
0005434081480	30544	Economy	13600.00
0005434081481	30544	Economy	13600.00
0005432459169	30544	Economy	13600.00
0005432459017	30544	Economy	13600.00
0005434081506	30544	Economy	13600.00
0005432566659	30544	Economy	13600.00
0005432566725	30544	Economy	13600.00
0005434081497	30544	Economy	13600.00
0005432566689	30544	Economy	13600.00
0005432566643	30544	Economy	13600.00
0005432566955	30544	Economy	13600.00
0005432566681	30544	Economy	13600.00
0005433454838	30544	Economy	13600.00
0005432458966	30544	Economy	13600.00
0005432566690	30544	Economy	13600.00
0005432459146	30544	Economy	13600.00
0005432566569	30544	Economy	13600.00
0005434081507	30544	Economy	13600.00
0005432566641	30544	Economy	13600.00
0005432458963	30544	Economy	13600.00
0005434081483	30544	Economy	13600.00
0005432459113	30544	Economy	13600.00
0005432566712	30544	Economy	13600.00
0005432459135	30544	Economy	13600.00
0005432459071	30544	Economy	13600.00
0005432566838	30544	Economy	13600.00
0005432566760	30544	Economy	13600.00
0005432566692	30544	Economy	13600.00
0005432459166	30544	Economy	13600.00
0005433454837	30544	Economy	13600.00
0005432566903	30544	Economy	13600.00
0005432458962	30544	Economy	13600.00
0005432458977	30544	Economy	13600.00
0005432566675	30544	Economy	13600.00
0005432459086	30544	Economy	13600.00
0005432566669	30544	Economy	13600.00
0005432459034	30544	Economy	13600.00
0005432459109	30544	Economy	13600.00
0005432566684	30544	Economy	13600.00
0005432459074	30544	Economy	13600.00
0005434081475	30544	Economy	13600.00
0005432459059	30544	Economy	13600.00
0005432571265	30544	Economy	13600.00
0005434081536	30544	Economy	13600.00
0005432459099	30544	Economy	13600.00
0005432459046	30544	Economy	13600.00
0005433452713	30544	Economy	13600.00
0005432566845	30544	Economy	13600.00
0005432459114	30544	Economy	13600.00
0005432566568	30544	Economy	13600.00
0005432459165	30544	Economy	13600.00
0005432566646	30544	Economy	13600.00
0005432566972	30544	Economy	15000.00
0005432566570	30544	Economy	15000.00
0005432566638	30544	Economy	13600.00
0005432459379	30544	Economy	13600.00
0005434081505	30544	Economy	15000.00
0005432459155	30544	Economy	13600.00
0005432566640	30544	Economy	13600.00
0005432458976	30544	Economy	13600.00
0005432566651	30544	Economy	13600.00
0005432566642	30544	Economy	13600.00
0005432459107	30544	Economy	13600.00
0005432459193	30544	Economy	13600.00
0005432566821	30544	Economy	13600.00
0005432459131	30544	Economy	13600.00
0005432459010	30544	Economy	13600.00
0005432566691	30544	Economy	13600.00
0005432459163	30544	Economy	13600.00
0005434081494	30544	Economy	13600.00
0005432459138	30544	Economy	13600.00
0005432459151	30544	Economy	13600.00
0005434081503	30544	Economy	13600.00
0005432566661	30544	Economy	13600.00
0005432566550	30544	Economy	13600.00
0005433452712	30544	Economy	13600.00
0005432459164	30544	Economy	13600.00
0005432458993	30544	Economy	13600.00
0005432566594	30544	Economy	13600.00
0005432566561	30544	Economy	13600.00
0005432459194	30544	Economy	13600.00
0005432459170	30544	Economy	13600.00
0005432566628	30544	Economy	13600.00
0005432566714	30544	Economy	13600.00
0005432458983	30544	Economy	13600.00
0005434081473	30544	Economy	13600.00
0005432566902	30544	Economy	13600.00
0005432566833	30544	Economy	13600.00
0005432459011	30544	Economy	13600.00
0005432459006	30544	Economy	13600.00
0005434081535	30544	Economy	13600.00
0005432459111	30544	Economy	13600.00
0005432566682	30544	Economy	13600.00
0005434081493	30544	Economy	13600.00
0005432566544	30544	Economy	13600.00
0005432459094	30544	Economy	13600.00
0005432459152	30544	Economy	13600.00
0005432566629	30544	Economy	13600.00
0005432566637	30544	Economy	13600.00
0005432566846	30544	Economy	13600.00
0005432566761	30544	Economy	13600.00
0005432213576	30544	Economy	13600.00
0005432213573	30544	Economy	13600.00
0005432571261	30544	Economy	13600.00
0005432459047	30544	Economy	13600.00
0005434081514	30544	Economy	13600.00
0005432566683	30544	Economy	13600.00
0005432566527	30544	Economy	13600.00
0005432566676	30544	Economy	13600.00
0005435720816	13658	Economy	9900.00
0005435722035	13658	Economy	9900.00
0005435720815	13658	Economy	9900.00
0005435722034	13658	Economy	9900.00
0005432295858	22791	Economy	8800.00
0005432295857	22791	Economy	8800.00
0005435097129	11091	Business	23600.00
0005435097124	11091	Business	23600.00
0005433342301	11091	Business	23600.00
0005433342298	11091	Business	23600.00
0005433342329	11091	Business	23600.00
0005433342379	11091	Business	23600.00
0005433342367	11091	Business	23600.00
0005433342318	11091	Business	23600.00
0005433342384	11091	Business	23600.00
0005433342361	11091	Business	23600.00
0005433342304	11091	Economy	7900.00
0005433342328	11091	Economy	7900.00
0005433342352	11091	Economy	7900.00
0005433342378	11091	Economy	7900.00
0005433342357	11091	Economy	7900.00
0005433342307	11091	Economy	7900.00
0005433342317	11091	Economy	7900.00
0005433342386	11091	Economy	7900.00
0005433342339	11091	Economy	7900.00
0005433342333	11091	Economy	7900.00
0005433342322	11091	Economy	7900.00
0005433342354	11091	Economy	7900.00
0005433342337	11091	Economy	7900.00
0005435097122	11091	Economy	7900.00
0005433342359	11091	Economy	7900.00
0005433342306	11091	Economy	7900.00
0005433342346	11091	Economy	7900.00
0005433342366	11091	Economy	7900.00
0005433342342	11091	Economy	7900.00
0005435097121	11091	Economy	7900.00
0005433342341	11091	Economy	7900.00
0005435508164	11091	Economy	7900.00
0005433342294	11091	Economy	7900.00
0005433342356	11091	Economy	7900.00
0005433342381	11091	Economy	7900.00
0005433342348	11091	Economy	7900.00
0005433342311	11091	Economy	7900.00
0005433342309	11091	Economy	7900.00
0005433342364	11091	Economy	7900.00
0005433342391	11091	Economy	7900.00
0005433342389	11091	Economy	7900.00
0005433342332	11091	Economy	7900.00
0005433342380	11091	Economy	7900.00
0005433342320	11091	Economy	7900.00
0005433342325	11091	Economy	7900.00
0005433342305	11091	Economy	7900.00
0005433342350	11091	Economy	8600.00
0005433342335	11091	Economy	8600.00
0005433342326	11091	Economy	8600.00
0005433342312	11091	Economy	8600.00
0005433342371	11091	Economy	8600.00
0005433342363	11091	Economy	8600.00
0005433342393	11091	Economy	7900.00
0005433342331	11091	Economy	7900.00
0005433342336	11091	Economy	7900.00
0005433342330	11091	Economy	7900.00
0005435097123	11091	Economy	7900.00
0005433342368	11091	Economy	7900.00
0005433342343	11091	Economy	7900.00
0005433342390	11091	Economy	7900.00
0005433342362	11091	Economy	7900.00
0005435097125	11091	Economy	7900.00
0005433342382	11091	Economy	7900.00
0005433342392	11091	Economy	7900.00
0005433342308	11091	Economy	7900.00
0005433342376	11091	Economy	7900.00
0005433342327	11091	Economy	7900.00
0005433342372	11091	Economy	7900.00
0005433342313	11091	Economy	7900.00
0005433342345	11091	Economy	7900.00
0005435097128	11091	Economy	7900.00
0005433342369	11091	Economy	7900.00
0005433342370	11091	Economy	7900.00
0005433342302	11091	Economy	7900.00
0005433342349	11091	Economy	7900.00
0005433342297	11091	Economy	7900.00
0005433342385	11091	Economy	7900.00
0005435380224	11091	Economy	7900.00
0005433342355	11091	Economy	7900.00
0005435097120	11091	Economy	7900.00
0005433342324	11091	Economy	7900.00
0005433342314	11091	Economy	7900.00
0005433342296	11091	Economy	7900.00
0005435097119	11091	Economy	7900.00
0005433342365	11091	Economy	7900.00
0005433342388	11091	Economy	7900.00
0005433342377	11091	Economy	7900.00
0005433342374	11091	Economy	7900.00
0005433342310	11091	Economy	7900.00
0005433342358	11091	Economy	7900.00
0005433342340	11091	Economy	7900.00
0005433342316	11091	Economy	7900.00
0005433342387	11091	Economy	7900.00
0005433342323	11091	Economy	7900.00
0005433342303	11091	Economy	7900.00
0005433342375	11091	Economy	7900.00
0005435097126	11091	Economy	7900.00
0005433342319	11091	Economy	7900.00
0005433342321	11091	Economy	7900.00
0005433342300	11091	Economy	7900.00
0005435380225	11091	Economy	7900.00
0005433342295	11091	Economy	7900.00
0005433342338	11091	Economy	7900.00
0005433342299	11091	Economy	7900.00
0005433342351	11091	Economy	7900.00
0005433342383	11091	Economy	7900.00
0005433342394	11091	Economy	7900.00
0005433342315	11091	Economy	7900.00
0005433342347	11091	Economy	7900.00
0005433342353	11091	Economy	7900.00
0005433342373	11091	Economy	7900.00
0005433342360	11091	Economy	7900.00
0005433342334	11091	Economy	7900.00
0005433342344	11091	Economy	7900.00
0005435097127	11091	Economy	7900.00
0005433341488	17090	Business	23600.00
0005433341667	17090	Business	23600.00
0005433341412	17090	Business	23600.00
0005433341641	17090	Business	23600.00
0005433341448	17090	Business	23600.00
0005433341669	17090	Economy	7900.00
0005435545662	17090	Economy	7900.00
0005435097062	17090	Economy	7900.00
0005433341424	17090	Economy	7900.00
0005433341500	17090	Economy	7900.00
0005435380263	17090	Economy	7900.00
0005433341486	17090	Economy	7900.00
0005433341429	17090	Economy	7900.00
0005435545663	17090	Economy	7900.00
0005433341704	17090	Economy	7900.00
0005433341382	17090	Economy	7900.00
0005433341853	17090	Economy	7900.00
0005433341836	17090	Economy	7900.00
0005433341586	17090	Economy	7900.00
0005435545668	17090	Economy	7900.00
0005433341815	17090	Economy	7900.00
0005433341835	17090	Economy	7900.00
0005433341532	17090	Economy	7900.00
0005435545659	17090	Economy	7900.00
0005435545657	17090	Economy	7900.00
0005433341477	17090	Economy	7900.00
0005433341425	17090	Economy	8600.00
0005433341462	17090	Economy	8600.00
0005433341461	17090	Economy	8600.00
0005432293188	17090	Economy	8600.00
0005433341428	17090	Economy	8600.00
0005435545660	17090	Economy	7900.00
0005433341449	17090	Economy	7900.00
0005435545658	17090	Economy	7900.00
0005435545656	17090	Economy	7900.00
0005433341400	17090	Economy	7900.00
0005433341417	17090	Economy	7900.00
0005435097044	17090	Economy	7900.00
0005433341601	17090	Economy	7900.00
0005433341734	17090	Economy	7900.00
0005435545655	17090	Economy	7900.00
0005433341561	17090	Economy	7900.00
0005433341603	17090	Economy	7900.00
0005435545661	17090	Economy	7900.00
0005433341402	17090	Economy	7900.00
0005435545665	17090	Economy	7900.00
0005433341391	17090	Economy	7900.00
0005435380260	17090	Economy	7900.00
0005433341607	17090	Economy	7900.00
0005433341587	17090	Economy	7900.00
0005433341650	17090	Economy	7900.00
0005433341683	17090	Economy	7900.00
0005433341595	17090	Economy	7900.00
0005435545671	17090	Economy	7900.00
0005433341738	17090	Economy	7900.00
0005433341620	17090	Economy	7900.00
0005432293186	17090	Economy	7900.00
0005435545669	17090	Economy	7900.00
0005435545664	17090	Economy	7900.00
0005435545666	17090	Economy	7900.00
0005435545667	17090	Economy	7900.00
0005433341854	17090	Economy	7900.00
0005435097063	17090	Economy	7900.00
0005433341703	17090	Economy	7900.00
0005435380262	17090	Economy	7900.00
0005433341649	17090	Economy	7900.00
0005433341671	17090	Economy	7900.00
0005435380261	17090	Economy	7900.00
0005432293187	17090	Economy	7900.00
0005433341635	17090	Economy	7900.00
0005435545670	17090	Economy	7900.00
0005435097089	17090	Economy	7900.00
0005435097045	17090	Economy	7900.00
0005433341415	17090	Economy	7900.00
0005433341383	17090	Economy	7900.00
0005433341505	17090	Economy	7900.00
0005432919524	9104	Business	26600.00
0005433507040	9104	Business	26600.00
0005433507042	9104	Business	26600.00
0005433507025	9104	Economy	8900.00
0005433507036	9104	Economy	8900.00
0005433507029	9104	Economy	8900.00
0005433481106	9104	Economy	8900.00
0005434158947	9104	Economy	8900.00
0005433481102	9104	Economy	9800.00
0005432919516	9104	Economy	9800.00
0005434158948	9104	Economy	8900.00
0005433507032	9104	Economy	8900.00
0005433507038	9104	Economy	8900.00
0005432919506	9104	Economy	8900.00
0005433507034	9104	Economy	8900.00
0005433507028	9104	Economy	8900.00
0005433507027	9104	Economy	8900.00
0005432919523	9104	Economy	8900.00
0005433481105	9104	Economy	8900.00
0005432919540	9104	Economy	8900.00
0005433507026	9104	Economy	8900.00
0005433507035	9104	Economy	8900.00
0005433507030	9104	Economy	8900.00
0005433507039	9104	Economy	8900.00
0005433507024	9104	Economy	8900.00
0005434158945	9104	Economy	8900.00
0005432919565	9104	Economy	8900.00
0005433507041	9104	Economy	8900.00
0005434158950	9104	Economy	8900.00
0005432919566	9104	Economy	8900.00
0005433481099	9104	Economy	8900.00
0005433481101	9104	Economy	8900.00
0005433481100	9104	Economy	8900.00
0005433507037	9104	Economy	8900.00
0005433507033	9104	Economy	8900.00
0005433481104	9104	Economy	8900.00
0005432919536	9104	Economy	8900.00
0005433507031	9104	Economy	8900.00
0005433481103	9104	Economy	8900.00
0005433506862	20433	Business	26600.00
0005433506908	20433	Business	26600.00
0005433481035	20433	Business	26600.00
0005432919705	20433	Business	26600.00
0005432919708	20433	Economy	8900.00
0005432919701	20433	Economy	8900.00
0005432919695	20433	Economy	8900.00
0005433506928	20433	Economy	8900.00
0005432919704	20433	Economy	9800.00
0005432919700	20433	Economy	9800.00
0005432919702	20433	Economy	9800.00
0005433506904	20433	Economy	8900.00
0005432919712	20433	Economy	8900.00
0005433481032	20433	Economy	8900.00
0005433481062	20433	Economy	8900.00
0005433506866	20433	Economy	8900.00
0005432919696	20433	Economy	8900.00
0005433506892	20433	Economy	8900.00
0005433506879	20433	Economy	8900.00
0005433506912	20433	Economy	8900.00
0005433506882	20433	Economy	8900.00
0005432919710	20433	Economy	8900.00
0005433506896	20433	Economy	8900.00
0005432919703	20433	Economy	8900.00
0005432919697	20433	Economy	8900.00
0005433506865	20433	Economy	8900.00
0005432919706	20433	Economy	8900.00
0005432919707	20433	Economy	8900.00
0005432919716	20433	Economy	8900.00
0005432919699	20433	Economy	8900.00
0005432919713	20433	Economy	8900.00
0005433481031	20433	Economy	8900.00
0005432919714	20433	Economy	8900.00
0005433481063	20433	Economy	8900.00
0005432919711	20433	Economy	8900.00
0005432919698	20433	Economy	8900.00
0005432919715	20433	Economy	8900.00
0005432919709	20433	Economy	8900.00
0005432396206	10170	Economy	5800.00
0005432394068	10170	Economy	5800.00
0005432396204	10170	Economy	5800.00
0005432394067	10170	Economy	5800.00
0005432396205	10170	Economy	5800.00
0005432394065	10170	Economy	5800.00
0005432396207	10170	Economy	5800.00
0005432394066	10170	Economy	5800.00
0005432400071	18392	Economy	5800.00
0005432396175	18392	Economy	5800.00
0005432400070	18392	Economy	5800.00
0005432396176	18392	Economy	5800.00
0005432396184	18392	Economy	5800.00
0005432396174	18392	Economy	5800.00
0005432400064	18392	Economy	5800.00
0005435625862	11002	Business	9500.00
0005434411743	11002	Business	9500.00
0005435554103	11002	Business	9500.00
0005435625867	11002	Business	9500.00
0005435125662	11002	Business	9500.00
0005435125676	11002	Economy	3200.00
0005435125688	11002	Economy	3200.00
0005434411742	11002	Economy	3200.00
0005435556646	11002	Economy	3200.00
0005435125735	11002	Economy	3500.00
0005435125753	11002	Economy	3500.00
0005435125687	11002	Economy	3200.00
0005435125656	11002	Economy	3200.00
0005434928276	11002	Economy	3200.00
0005435125694	11002	Economy	3200.00
0005435125754	11002	Economy	3200.00
0005434411741	11002	Economy	3200.00
0005434928277	11002	Economy	3200.00
0005435125671	11002	Economy	3200.00
0005435625870	11002	Economy	3200.00
0005435125659	11002	Economy	3200.00
0005435125661	11002	Economy	3200.00
0005435554115	11002	Economy	3200.00
0005435125768	11002	Economy	3200.00
0005435125658	11002	Economy	3200.00
0005435625866	11002	Economy	3200.00
0005435125783	11002	Economy	3200.00
0005435125675	11002	Economy	3200.00
0005435625874	11002	Economy	3200.00
0005434411744	11002	Economy	3200.00
0005435625873	11002	Economy	3200.00
0005435125701	11002	Economy	3200.00
0005435625871	11002	Economy	3200.00
0005435125734	11002	Economy	3200.00
0005435125709	11002	Economy	3200.00
0005435125733	11002	Economy	3200.00
0005435125782	11002	Economy	3200.00
0005435625872	11002	Economy	3200.00
0005435125784	11002	Economy	3200.00
0005435125660	11002	Economy	3200.00
0005435125801	11002	Economy	3200.00
0005435125674	11002	Economy	3200.00
0005435554104	11002	Economy	3200.00
0005435556653	11002	Economy	3200.00
0005435125767	11002	Economy	3200.00
0005435126032	14675	Business	9500.00
0005435126061	14675	Business	9500.00
0005435126034	14675	Business	9500.00
0005435126059	14675	Business	9500.00
0005435126023	14675	Business	9500.00
0005435126045	14675	Business	9500.00
0005434928254	14675	Business	9500.00
0005435126051	14675	Economy	3200.00
0005435626028	14675	Economy	3200.00
0005435126062	14675	Economy	3200.00
0005435626029	14675	Economy	3200.00
0005435126057	14675	Economy	3200.00
0005435554147	14675	Economy	3200.00
0005435626027	14675	Economy	3200.00
0005435626033	14675	Economy	3500.00
0005435554145	14675	Economy	3500.00
0005435126036	14675	Economy	3500.00
0005435626025	14675	Economy	3200.00
0005435626030	14675	Economy	3200.00
0005435626035	14675	Economy	3200.00
0005435126029	14675	Economy	3200.00
0005435126054	14675	Economy	3200.00
0005435126040	14675	Economy	3200.00
0005435126031	14675	Economy	3200.00
0005435126046	14675	Economy	3200.00
0005435126041	14675	Economy	3200.00
0005435126025	14675	Economy	3200.00
0005435556669	14675	Economy	3200.00
0005435126049	14675	Economy	3200.00
0005435554146	14675	Economy	3200.00
0005435126052	14675	Economy	3200.00
0005435126056	14675	Economy	3200.00
0005435126055	14675	Economy	3200.00
0005434411709	14675	Economy	3200.00
0005435126058	14675	Economy	3200.00
0005435626039	14675	Economy	3200.00
0005435126035	14675	Economy	3200.00
0005435556671	14675	Economy	3200.00
0005435626036	14675	Economy	3200.00
0005435126048	14675	Economy	3200.00
0005435626031	14675	Economy	3200.00
0005435126026	14675	Economy	3200.00
0005434411704	14675	Economy	3200.00
0005435126039	14675	Economy	3200.00
0005435126063	14675	Economy	3200.00
0005435556670	14675	Economy	3200.00
0005435126033	14675	Economy	3200.00
0005435126027	14675	Economy	3200.00
0005435554144	14675	Economy	3200.00
0005435126043	14675	Economy	3200.00
0005435626024	14675	Economy	3200.00
0005435126038	14675	Economy	3200.00
0005435626034	14675	Economy	3200.00
0005435126030	14675	Economy	3200.00
0005435126050	14675	Economy	3200.00
0005435554148	14675	Economy	3200.00
0005435126060	14675	Economy	3200.00
0005435126053	14675	Economy	3200.00
0005435126037	14675	Economy	3200.00
0005435126022	14675	Economy	3200.00
0005435126024	14675	Economy	3200.00
0005435626037	14675	Economy	3200.00
0005435626038	14675	Economy	3200.00
0005435626026	14675	Economy	3200.00
0005435626032	14675	Economy	3200.00
0005435126047	14675	Economy	3200.00
0005435126028	14675	Economy	3200.00
0005435626023	14675	Economy	3200.00
0005435126044	14675	Economy	3200.00
0005435126042	14675	Economy	3200.00
0005435443155	7093	Business	86900.00
0005435715329	7093	Business	86900.00
0005432400096	7093	Business	86900.00
0005432398165	7093	Business	86900.00
0005435715328	7093	Business	86900.00
0005435715330	7093	Business	86900.00
0005435715327	7093	Economy	29000.00
0005435443165	7093	Economy	29000.00
0005435443154	7093	Economy	29000.00
0005435219173	7093	Economy	29000.00
0005435715319	7093	Economy	29000.00
0005435715320	7093	Economy	29000.00
0005435715322	7093	Economy	31900.00
0005435443164	7093	Economy	29000.00
0005435443163	7093	Economy	29000.00
0005435715324	7093	Economy	29000.00
0005435443152	7093	Economy	29000.00
0005435715318	7093	Economy	29000.00
0005432398167	7093	Economy	29000.00
0005435219168	7093	Economy	29000.00
0005435178473	7093	Economy	29000.00
0005435715323	7093	Economy	29000.00
0005435715332	7093	Economy	29000.00
0005435715333	7093	Economy	29000.00
0005435715317	7093	Economy	29000.00
0005435443144	7093	Economy	29000.00
0005435715331	7093	Economy	29000.00
0005435715321	7093	Economy	29000.00
0005435715326	7093	Economy	29000.00
0005435715325	7093	Economy	29000.00
0005435178476	7093	Economy	29000.00
0005435715334	7093	Economy	29000.00
0005432398166	7093	Economy	29000.00
0005435178480	27053	Business	86900.00
0005435443231	27053	Business	86900.00
0005435715176	27053	Business	86900.00
0005432398132	27053	Economy	29000.00
0005435715167	27053	Economy	29000.00
0005435443235	27053	Economy	29000.00
0005432398149	27053	Economy	29000.00
0005435443237	27053	Economy	31900.00
0005435443234	27053	Economy	29000.00
0005435443241	27053	Economy	29000.00
0005435715164	27053	Economy	29000.00
0005435443233	27053	Economy	29000.00
0005435715245	27053	Economy	29000.00
0005435715197	27053	Economy	29000.00
0005435178481	27053	Economy	29000.00
0005435715213	27053	Economy	29000.00
0005435715216	27053	Economy	29000.00
0005432394039	27053	Economy	29000.00
0005435715168	27053	Economy	29000.00
0005435715194	27053	Economy	29000.00
0005435443239	27053	Economy	29000.00
0005435443232	27053	Economy	29000.00
0005435443240	27053	Economy	29000.00
0005435715175	27053	Economy	29000.00
0005432394033	27053	Economy	29000.00
0005435443238	27053	Economy	29000.00
0005435443236	27053	Economy	29000.00
0005434084893	2752	Economy	7700.00
0005434084890	2752	Economy	7700.00
0005434084895	2752	Economy	7700.00
0005434084892	2752	Economy	7700.00
0005434084894	2752	Economy	7700.00
0005433060368	2752	Economy	7700.00
0005434084891	2752	Economy	7700.00
0005434084889	2752	Economy	7700.00
0005433060390	28521	Economy	7700.00
0005434084862	28521	Economy	7700.00
0005434084852	28521	Economy	7700.00
0005433060391	28521	Economy	7700.00
0005434084856	28521	Economy	7700.00
0005434084857	28521	Economy	7700.00
0005434084855	28521	Economy	7700.00
0005433060392	28521	Economy	7700.00
0005434084868	28521	Economy	7700.00
0005434084848	28521	Economy	7700.00
0005435540674	11408	Business	20200.00
0005435540728	11408	Business	20200.00
0005435517626	11408	Business	20200.00
0005435540631	11408	Business	20200.00
0005435540695	11408	Economy	6700.00
0005435540654	11408	Economy	6700.00
0005435517644	11408	Economy	6700.00
0005435517628	11408	Economy	6700.00
0005435540697	11408	Economy	6700.00
0005435540632	11408	Economy	7400.00
0005435517621	11408	Economy	7400.00
0005435517707	11408	Economy	7400.00
0005435540685	11408	Economy	7400.00
0005435517679	11408	Economy	6700.00
0005435517607	11408	Economy	6700.00
0005435517611	11408	Economy	6700.00
0005435517687	11408	Economy	6700.00
0005435540684	11408	Economy	6700.00
0005435540672	11408	Economy	6700.00
0005435540686	11408	Economy	6700.00
0005435540671	11408	Economy	6700.00
0005435517608	11408	Economy	6700.00
0005435540622	11408	Economy	6700.00
0005435540629	11408	Economy	6700.00
0005435540663	11408	Economy	6700.00
0005435517661	11408	Economy	6700.00
0005435517660	11408	Economy	6700.00
0005435540664	11408	Economy	6700.00
0005435540656	11408	Economy	6700.00
0005435540623	11408	Economy	6700.00
0005435540702	11408	Economy	6700.00
0005435540655	11408	Economy	6700.00
0005435517604	11408	Economy	6700.00
0005435540729	11408	Economy	6700.00
0005435540642	11408	Economy	6700.00
0005435517645	11408	Economy	6700.00
0005435517680	11408	Economy	6700.00
0005435540814	22264	Business	20200.00
0005435529067	22264	Business	20200.00
0005435529060	22264	Business	20200.00
0005435529069	22264	Business	20200.00
0005435529071	22264	Business	20200.00
0005435540809	22264	Business	20200.00
0005432294465	22264	Economy	6700.00
0005435540807	22264	Economy	6700.00
0005435529074	22264	Economy	6700.00
0005435540801	22264	Economy	6700.00
0005435540817	22264	Economy	6700.00
0005435540803	22264	Economy	7400.00
0005435529075	22264	Economy	6700.00
0005435540815	22264	Economy	6700.00
0005435540818	22264	Economy	6700.00
0005435529070	22264	Economy	6700.00
0005435529072	22264	Economy	6700.00
0005435529066	22264	Economy	6700.00
0005432294466	22264	Economy	6700.00
0005435540820	22264	Economy	6700.00
0005435529064	22264	Economy	6700.00
0005435529057	22264	Economy	6700.00
0005435529055	22264	Economy	6700.00
0005435540812	22264	Economy	6700.00
0005435529077	22264	Economy	6700.00
0005435540816	22264	Economy	6700.00
0005435540811	22264	Economy	6700.00
0005435540819	22264	Economy	6700.00
0005435540821	22264	Economy	6700.00
0005435529056	22264	Economy	6700.00
0005435540805	22264	Economy	6700.00
0005435540800	22264	Economy	6700.00
0005435529073	22264	Economy	6700.00
0005435529068	22264	Economy	6700.00
0005435540808	22264	Economy	6700.00
0005435529058	22264	Economy	6700.00
0005435529062	22264	Economy	6700.00
0005435540810	22264	Economy	6700.00
0005435540806	22264	Economy	6700.00
0005435529076	22264	Economy	6700.00
0005435540804	22264	Economy	6700.00
0005435529063	22264	Economy	6700.00
0005435540813	22264	Economy	6700.00
0005435540802	22264	Economy	6700.00
0005435540822	22264	Economy	6700.00
0005435529059	22264	Economy	6700.00
0005435529065	22264	Economy	6700.00
0005435529061	22264	Economy	6700.00
0005434906875	2308	Business	20200.00
0005433251064	2308	Business	20200.00
0005433251071	2308	Business	20200.00
0005434906896	2308	Business	20200.00
0005433251059	2308	Business	20200.00
0005434906862	2308	Business	20200.00
0005434906888	2308	Business	20200.00
0005433251117	2308	Business	20200.00
0005434906894	2308	Economy	6700.00
0005434906864	2308	Economy	6700.00
0005434906871	2308	Economy	6700.00
0005433251069	2308	Economy	6700.00
0005433250988	2308	Economy	6700.00
0005434906863	2308	Economy	6700.00
0005434906865	2308	Economy	6700.00
0005434906877	2308	Economy	6700.00
0005434906899	2308	Economy	7400.00
0005434906880	2308	Economy	7400.00
0005433251038	2308	Economy	7400.00
0005434906874	2308	Economy	6700.00
0005433251116	2308	Economy	6700.00
0005434906867	2308	Economy	6700.00
0005434906869	2308	Economy	6700.00
0005434906879	2308	Economy	6700.00
0005434906860	2308	Economy	6700.00
0005434906902	2308	Economy	6700.00
0005433250984	2308	Economy	6700.00
0005434906901	2308	Economy	6700.00
0005433250985	2308	Economy	6700.00
0005434906900	2308	Economy	6700.00
0005433250955	2308	Economy	6700.00
0005433250993	2308	Economy	6700.00
0005433250959	2308	Economy	6700.00
0005434906903	2308	Economy	6700.00
0005434906898	2308	Economy	6700.00
0005434906891	2308	Economy	6700.00
0005434906904	2308	Economy	6700.00
0005434906861	2308	Economy	6700.00
0005434906885	2308	Economy	6700.00
0005434906883	2308	Economy	6700.00
0005434906886	2308	Economy	6700.00
0005434906873	2308	Economy	6700.00
0005434906887	2308	Economy	6700.00
0005433250956	2308	Economy	6700.00
0005434906876	2308	Economy	6700.00
0005433251070	2308	Economy	6700.00
0005434906870	2308	Economy	6700.00
0005434906890	2308	Economy	6700.00
0005433251016	2308	Economy	6700.00
0005433251015	2308	Economy	6700.00
0005434906895	2308	Economy	6700.00
0005434906878	2308	Economy	6700.00
0005434906868	2308	Economy	6700.00
0005434906893	2308	Economy	6700.00
0005434906884	2308	Economy	6700.00
0005434906859	2308	Economy	6700.00
0005434906881	2308	Economy	6700.00
0005434906889	2308	Economy	6700.00
0005434906882	2308	Economy	6700.00
0005434906872	2308	Economy	6700.00
0005433400937	2308	Economy	6700.00
0005434906866	2308	Economy	6700.00
0005434906892	2308	Economy	6700.00
0005434906897	2308	Economy	6700.00
0005434906447	25582	Business	20200.00
0005434906360	25582	Business	20200.00
0005434906438	25582	Business	20200.00
0005433251242	25582	Business	20200.00
0005434906420	25582	Business	20200.00
0005433251218	25582	Business	20200.00
0005433251233	25582	Business	20200.00
0005434906436	25582	Economy	6700.00
0005433251239	25582	Economy	6700.00
0005433251234	25582	Economy	6700.00
0005433251216	25582	Economy	6700.00
0005433251231	25582	Economy	6700.00
0005433400959	25582	Economy	6700.00
0005433400957	25582	Economy	6700.00
0005433251230	25582	Economy	7400.00
0005433251213	25582	Economy	7400.00
0005433251236	25582	Economy	6700.00
0005434906437	25582	Economy	6700.00
0005433251219	25582	Economy	6700.00
0005433251226	25582	Economy	6700.00
0005434906368	25582	Economy	6700.00
0005434906415	25582	Economy	6700.00
0005433251224	25582	Economy	6700.00
0005433251215	25582	Economy	6700.00
0005433251214	25582	Economy	6700.00
0005433251241	25582	Economy	6700.00
0005433251240	25582	Economy	6700.00
0005433251238	25582	Economy	6700.00
0005433251225	25582	Economy	6700.00
0005433251228	25582	Economy	6700.00
0005434906367	25582	Economy	6700.00
0005433251237	25582	Economy	6700.00
0005434906390	25582	Economy	6700.00
0005433251227	25582	Economy	6700.00
0005434906401	25582	Economy	6700.00
0005433251221	25582	Economy	6700.00
0005434906389	25582	Economy	6700.00
0005433251235	25582	Economy	6700.00
0005433251223	25582	Economy	6700.00
0005434906441	25582	Economy	6700.00
0005433400958	25582	Economy	6700.00
0005434906395	25582	Economy	6700.00
0005434906391	25582	Economy	6700.00
0005433251232	25582	Economy	6700.00
0005433251217	25582	Economy	6700.00
0005434906445	25582	Economy	6700.00
0005434906442	25582	Economy	6700.00
0005433251229	25582	Economy	6700.00
0005433251220	25582	Economy	6700.00
0005433251212	25582	Economy	6700.00
0005433251222	25582	Economy	6700.00
0005434906370	25582	Economy	6700.00
0005434906409	25582	Economy	6700.00
0005434906446	25582	Economy	6700.00
0005434906407	25582	Economy	6700.00
0005434906431	25582	Economy	6700.00
0005432620919	2542	Economy	12400.00
0005432862171	2542	Economy	12400.00
0005432620925	2542	Economy	12400.00
0005432620929	2542	Economy	12400.00
0005432620930	2542	Economy	12400.00
0005432620926	2542	Economy	12400.00
0005432620920	2542	Economy	12400.00
0005432620922	2542	Economy	12400.00
0005432862170	2542	Economy	12400.00
0005432620916	2542	Economy	12400.00
0005432862181	2542	Economy	12400.00
0005432620918	2542	Economy	12400.00
0005432620924	2542	Economy	12400.00
0005432620931	2542	Economy	12400.00
0005432862165	2542	Economy	12400.00
0005432620928	2542	Economy	12400.00
0005432620921	2542	Economy	12400.00
0005432620927	2542	Economy	12400.00
0005432620923	2542	Economy	12400.00
0005432620917	2542	Economy	12400.00
0005432620932	2542	Economy	12400.00
0005432620824	28083	Economy	12400.00
0005432862235	28083	Economy	12400.00
0005432862241	28083	Economy	12400.00
0005432620814	28083	Economy	12400.00
0005432862238	28083	Economy	12400.00
0005432862240	28083	Economy	12400.00
0005432862239	28083	Economy	12400.00
0005432620812	28083	Economy	12400.00
0005432620827	28083	Economy	12400.00
0005432620825	28083	Economy	12400.00
0005432862234	28083	Economy	12400.00
0005432620826	28083	Economy	12400.00
0005432620790	28083	Economy	12400.00
0005432862237	28083	Economy	12400.00
0005432620817	28083	Economy	12400.00
0005432620828	28083	Economy	12400.00
0005432862236	28083	Economy	12400.00
0005432620818	28083	Economy	12400.00
0005434097455	11787	Economy	11300.00
0005434097454	11787	Economy	11300.00
0005434097464	13080	Economy	11300.00
0005434097465	13080	Economy	11300.00
0005433451603	31009	Economy	8400.00
0005433452721	31009	Economy	8400.00
0005433452722	31009	Economy	8400.00
0005433451602	31009	Economy	8400.00
0005433454843	31355	Economy	8400.00
0005433454838	31355	Economy	8400.00
0005433452713	31355	Economy	8400.00
0005433452707	31355	Economy	8400.00
0005433452712	31355	Economy	8400.00
0005433454837	31355	Economy	8400.00
0005433129201	12008	Economy	6600.00
0005434184629	12008	Economy	6600.00
0005434184630	12008	Economy	6600.00
0005433134058	12008	Economy	6600.00
0005434326085	12008	Economy	6600.00
0005433129200	12008	Economy	6600.00
0005433134102	29867	Economy	7200.00
0005434142576	29867	Economy	7200.00
0005434184647	29867	Economy	7200.00
0005433134099	29867	Economy	6600.00
0005433131670	29867	Economy	6600.00
0005434142575	29867	Economy	6600.00
0005434184648	29867	Economy	6600.00
0005434326259	29867	Economy	6600.00
0005433134100	29867	Economy	6600.00
0005433131669	29867	Economy	6600.00
0005434326260	29867	Economy	6600.00
0005433131671	29867	Economy	6600.00
0005433134098	29867	Economy	6600.00
0005433134101	29867	Economy	6600.00
0005433131672	29867	Economy	6600.00
0005433131673	29867	Economy	6600.00
0005434183563	29867	Economy	6600.00
0005433131668	29867	Economy	6600.00
0005434184649	29867	Economy	6600.00
0005434142574	29867	Economy	6600.00
0005435697099	16502	Economy	19900.00
0005435697082	16502	Economy	18100.00
0005435697097	16502	Economy	18100.00
0005435697090	16502	Economy	18100.00
0005435934993	16502	Economy	18100.00
0005435697077	16502	Economy	18100.00
0005435697096	16502	Economy	18100.00
0005435697089	16502	Economy	18100.00
0005435697098	16502	Economy	18100.00
0005435697083	16502	Economy	18100.00
0005435697092	16502	Economy	18100.00
0005435697074	16502	Economy	18100.00
0005435697088	16502	Economy	18100.00
0005435697091	16502	Economy	18100.00
0005435697101	16502	Economy	18100.00
0005435697078	16502	Economy	18100.00
0005435697079	16502	Economy	18100.00
0005435697081	16502	Economy	18100.00
0005435697087	16502	Economy	18100.00
0005435697073	16502	Economy	18100.00
0005435697093	16502	Economy	18100.00
0005435697084	16502	Economy	18100.00
0005435697094	16502	Economy	18100.00
0005435697076	16502	Economy	18100.00
0005435697100	16502	Economy	18100.00
0005435697085	16502	Economy	18100.00
0005435697075	16502	Economy	18100.00
0005435697086	16502	Economy	18100.00
0005435697095	16502	Economy	18100.00
0005435697080	16502	Economy	18100.00
0005435696907	24717	Economy	19900.00
0005435696906	24717	Economy	19900.00
0005435697007	24717	Economy	18100.00
0005435696975	24717	Economy	18100.00
0005435696962	24717	Economy	18100.00
0005435697008	24717	Economy	18100.00
0005435696915	24717	Economy	18100.00
0005435935019	24717	Economy	18100.00
0005435935018	24717	Economy	18100.00
0005435696916	24717	Economy	18100.00
0005435696948	24717	Economy	18100.00
0005435696949	24717	Economy	18100.00
0005435696852	24717	Economy	18100.00
0005435696843	24717	Economy	18100.00
0005435696922	24717	Economy	18100.00
0005435696869	24717	Economy	18100.00
0005435696895	24717	Economy	18100.00
0005435696908	24717	Economy	18100.00
0005435696844	24717	Economy	18100.00
0005435696941	24717	Economy	18100.00
0005435696851	24717	Economy	18100.00
0005433724766	18808	Economy	4400.00
0005433724763	18808	Economy	4400.00
0005433724764	18808	Economy	4400.00
0005433724765	18808	Economy	4400.00
0005432968824	21598	Economy	4400.00
0005433724730	21598	Economy	4400.00
0005433724737	21598	Economy	4400.00
0005432968823	21598	Economy	4400.00
0005433724738	21598	Economy	4400.00
0005434137518	7339	Business	23100.00
0005434137452	7339	Business	23100.00
0005434137480	7339	Business	23100.00
0005434137483	7339	Business	23100.00
0005434137448	7339	Business	23100.00
0005434137460	7339	Business	23100.00
0005434137490	7339	Business	23100.00
0005434137454	7339	Business	23100.00
0005434137496	7339	Business	23100.00
0005434137450	7339	Business	23100.00
0005434137477	7339	Business	23100.00
0005434137506	7339	Business	23100.00
0005434137464	7339	Economy	7700.00
0005434137503	7339	Economy	7700.00
0005434137473	7339	Economy	7700.00
0005434137500	7339	Economy	7700.00
0005434137531	7339	Economy	7700.00
0005434137512	7339	Economy	7700.00
0005434137517	7339	Economy	7700.00
0005434137535	7339	Economy	7700.00
0005434137526	7339	Economy	7700.00
0005434137537	7339	Economy	7700.00
0005434137498	7339	Economy	8500.00
0005434137489	7339	Economy	8500.00
0005434137478	7339	Economy	8500.00
0005434137494	7339	Economy	8500.00
0005434137523	7339	Economy	8500.00
0005434137527	7339	Economy	7700.00
0005434137469	7339	Economy	7700.00
0005434137475	7339	Economy	7700.00
0005434137513	7339	Economy	7700.00
0005434137491	7339	Economy	7700.00
0005434137461	7339	Economy	7700.00
0005434137462	7339	Economy	7700.00
0005434137521	7339	Economy	7700.00
0005434137502	7339	Economy	7700.00
0005434137481	7339	Economy	7700.00
0005434137530	7339	Economy	7700.00
0005434137455	7339	Economy	7700.00
0005434087476	7339	Economy	7700.00
0005434137507	7339	Economy	7700.00
0005434137466	7339	Economy	7700.00
0005434137467	7339	Economy	7700.00
0005434137459	7339	Economy	7700.00
0005434137501	7339	Economy	7700.00
0005434137486	7339	Economy	7700.00
0005434137493	7339	Economy	7700.00
0005434137476	7339	Economy	7700.00
0005434137529	7339	Economy	7700.00
0005434137453	7339	Economy	7700.00
0005434137451	7339	Economy	7700.00
0005434137457	7339	Economy	7700.00
0005434137516	7339	Economy	7700.00
0005434137446	7339	Economy	7700.00
0005434137519	7339	Economy	7700.00
0005434137495	7339	Economy	7700.00
0005434137479	7339	Economy	7700.00
0005434137505	7339	Economy	7700.00
0005434137447	7339	Economy	7700.00
0005434087474	7339	Economy	7700.00
0005434137456	7339	Economy	7700.00
0005434137470	7339	Economy	7700.00
0005434137525	7339	Economy	7700.00
0005434137536	7339	Economy	7700.00
0005434137468	7339	Economy	7700.00
0005434137482	7339	Economy	7700.00
0005434137509	7339	Economy	7700.00
0005434137514	7339	Economy	7700.00
0005434137472	7339	Economy	7700.00
0005434137492	7339	Economy	7700.00
0005434137515	7339	Economy	7700.00
0005434137511	7339	Economy	7700.00
0005434137522	7339	Economy	7700.00
0005434087475	7339	Economy	7700.00
0005434137520	7339	Economy	7700.00
0005434137465	7339	Economy	7700.00
0005434137524	7339	Economy	7700.00
0005434137534	7339	Economy	7700.00
0005434087473	7339	Economy	7700.00
0005434137499	7339	Economy	7700.00
0005434137533	7339	Economy	7700.00
0005434137487	7339	Economy	7700.00
0005434137532	7339	Economy	7700.00
0005434137508	7339	Economy	7700.00
0005434137449	7339	Economy	7700.00
0005434137474	7339	Economy	7700.00
0005434137458	7339	Economy	7700.00
0005434137471	7339	Economy	7700.00
0005434137510	7339	Economy	7700.00
0005434137504	7339	Economy	7700.00
0005434137528	7339	Economy	7700.00
0005434137485	7339	Economy	7700.00
0005434137463	7339	Economy	7700.00
0005434137488	7339	Economy	7700.00
0005434137497	7339	Economy	7700.00
0005434087472	7339	Economy	7700.00
0005434137484	7339	Economy	7700.00
0005434136829	28529	Business	23100.00
0005434136700	28529	Business	23100.00
0005434136844	28529	Business	23100.00
0005434136958	28529	Business	23100.00
0005434136856	28529	Business	23100.00
0005434087445	28529	Business	23100.00
0005434136827	28529	Business	23100.00
0005434136884	28529	Business	23100.00
0005434136701	28529	Economy	7700.00
0005434136698	28529	Economy	7700.00
0005434136679	28529	Economy	7700.00
0005434136684	28529	Economy	7700.00
0005434136800	28529	Economy	7700.00
0005434136852	28529	Economy	7700.00
0005434136749	28529	Economy	8500.00
0005434087444	28529	Economy	8500.00
0005434136898	28529	Economy	8500.00
0005434136938	28529	Economy	7700.00
0005434136899	28529	Economy	7700.00
0005434136998	28529	Economy	7700.00
0005434136871	28529	Economy	7700.00
0005434136982	28529	Economy	7700.00
0005434136767	28529	Economy	7700.00
0005434136853	28529	Economy	7700.00
0005434136893	28529	Economy	7700.00
0005434136801	28529	Economy	7700.00
0005434137037	28529	Economy	7700.00
0005434136850	28529	Economy	7700.00
0005434087447	28529	Economy	7700.00
0005434136907	28529	Economy	7700.00
0005434136780	28529	Economy	7700.00
0005434136758	28529	Economy	7700.00
0005434136721	28529	Economy	7700.00
0005434136709	28529	Economy	7700.00
0005434136779	28529	Economy	7700.00
0005434136933	28529	Economy	7700.00
0005434136900	28529	Economy	7700.00
0005434136802	28529	Economy	7700.00
0005434136934	28529	Economy	7700.00
0005434136823	28529	Economy	7700.00
0005434136781	28529	Economy	7700.00
0005434136865	28529	Economy	7700.00
0005434136773	28529	Economy	7700.00
0005434136828	28529	Economy	7700.00
0005434136967	28529	Economy	7700.00
0005434087446	28529	Economy	7700.00
0005434136803	28529	Economy	7700.00
0005434136683	28529	Economy	7700.00
0005434136851	28529	Economy	7700.00
0005434136737	28529	Economy	7700.00
0005434136807	28529	Economy	7700.00
0005434136928	28529	Economy	7700.00
0005434136736	28529	Economy	7700.00
0005434136798	28529	Economy	7700.00
0005435808148	1909	Economy	23900.00
0005435808153	1909	Economy	21700.00
0005435808146	1909	Economy	21700.00
0005434610199	1909	Economy	21700.00
0005435808145	1909	Economy	21700.00
0005434610198	1909	Economy	21700.00
0005435808155	1909	Economy	21700.00
0005435808149	1909	Economy	21700.00
0005435808154	1909	Economy	21700.00
0005433407483	1909	Economy	21700.00
0005434610200	1909	Economy	21700.00
0005435808150	1909	Economy	21700.00
0005435808147	1909	Economy	21700.00
0005435808151	1909	Economy	21700.00
0005435808152	1909	Economy	21700.00
0005434610176	23096	Economy	21700.00
0005434503568	16690	Economy	7600.00
0005434503569	16690	Economy	7600.00
0005434503494	16690	Economy	6900.00
0005434503623	16690	Economy	6900.00
0005434503542	16690	Economy	6900.00
0005434503525	16690	Economy	6900.00
0005434503483	16690	Economy	6900.00
0005434503564	16690	Economy	6900.00
0005434503541	16690	Economy	6900.00
0005434503540	16690	Economy	6900.00
0005434503616	16690	Economy	6900.00
0005434503547	16690	Economy	6900.00
0005434503617	16690	Economy	6900.00
0005434503658	16690	Economy	6900.00
0005434503493	16690	Economy	6900.00
0005434503492	16690	Economy	6900.00
0005434503488	16690	Economy	6900.00
0005434503591	16690	Economy	6900.00
0005434503570	16690	Economy	6900.00
0005434503563	16690	Economy	6900.00
0005434503499	16690	Economy	6900.00
0005434503789	22910	Economy	7600.00
0005434503807	22910	Economy	7600.00
0005434503786	22910	Economy	7600.00
0005434503813	22910	Economy	6900.00
0005434503799	22910	Economy	6900.00
0005434503805	22910	Economy	6900.00
0005434503792	22910	Economy	6900.00
0005434503788	22910	Economy	6900.00
0005434503796	22910	Economy	6900.00
0005434503806	22910	Economy	6900.00
0005434503783	22910	Economy	6900.00
0005434503815	22910	Economy	6900.00
0005434503787	22910	Economy	6900.00
0005434503812	22910	Economy	6900.00
0005434503803	22910	Economy	6900.00
0005434503808	22910	Economy	6900.00
0005434503814	22910	Economy	6900.00
0005434503794	22910	Economy	6900.00
0005434503811	22910	Economy	6900.00
0005434503820	22910	Economy	6900.00
0005434503798	22910	Economy	6900.00
0005434503821	22910	Economy	6900.00
0005434503804	22910	Economy	6900.00
0005434503810	22910	Economy	6900.00
0005434503790	22910	Economy	6900.00
0005434503816	22910	Economy	6900.00
0005434503801	22910	Economy	6900.00
0005434503784	22910	Economy	6900.00
0005434503818	22910	Economy	6900.00
0005434503797	22910	Economy	6900.00
0005434503822	22910	Economy	6900.00
0005434503809	22910	Economy	6900.00
0005434503791	22910	Economy	6900.00
0005434503819	22910	Economy	6900.00
0005434503785	22910	Economy	6900.00
0005434503795	22910	Economy	6900.00
0005434503793	22910	Economy	6900.00
0005434503802	22910	Economy	6900.00
0005434503817	22910	Economy	6900.00
0005434503800	22910	Economy	6900.00
0005435078216	2185	Economy	7700.00
0005435078221	2185	Economy	7000.00
0005435078208	2185	Economy	7000.00
0005435078209	2185	Economy	7000.00
0005435078218	2185	Economy	7000.00
0005435078213	2185	Economy	7000.00
0005435078207	2185	Economy	7000.00
0005435078210	2185	Economy	7000.00
0005435078219	2185	Economy	7000.00
0005433266578	2185	Economy	7000.00
0005435078212	2185	Economy	7000.00
0005433266596	2185	Economy	7000.00
0005435078211	2185	Economy	7000.00
0005433266588	2185	Economy	7000.00
0005435078215	2185	Economy	7000.00
0005435078214	2185	Economy	7000.00
0005435078222	2185	Economy	7000.00
0005433266586	2185	Economy	7000.00
0005435078220	2185	Economy	7000.00
0005435078217	2185	Economy	7000.00
0005435078138	24326	Economy	7700.00
0005435078105	24326	Economy	7700.00
0005433266646	24326	Economy	7700.00
0005435078169	24326	Economy	7000.00
0005433266649	24326	Economy	7000.00
0005435078150	24326	Economy	7000.00
0005435078083	24326	Economy	7000.00
0005435078168	24326	Economy	7000.00
0005433266642	24326	Economy	7000.00
0005435078126	24326	Economy	7000.00
0005433266645	24326	Economy	7000.00
0005433266647	24326	Economy	7000.00
0005435078147	24326	Economy	7000.00
0005433266644	24326	Economy	7000.00
0005433266648	24326	Economy	7000.00
0005433266652	24326	Economy	7000.00
0005435078082	24326	Economy	7000.00
0005433266651	24326	Economy	7000.00
0005433266650	24326	Economy	7000.00
0005435078127	24326	Economy	7000.00
0005433266643	24326	Economy	7000.00
0005434988651	6644	Economy	10800.00
0005435803238	6644	Economy	9800.00
0005434988645	6644	Economy	9800.00
0005434988647	6644	Economy	9800.00
0005434988649	6644	Economy	9800.00
0005434988642	6644	Economy	9800.00
0005435803240	6644	Economy	9800.00
0005434988646	6644	Economy	9800.00
0005434988652	6644	Economy	9800.00
0005434988650	6644	Economy	9800.00
0005434988640	6644	Economy	9800.00
0005434988643	6644	Economy	9800.00
0005434988638	6644	Economy	9800.00
0005434988648	6644	Economy	9800.00
0005434988644	6644	Economy	9800.00
0005434988639	6644	Economy	9800.00
0005434988641	6644	Economy	9800.00
0005435803239	6644	Economy	9800.00
0005434988653	6644	Economy	9800.00
0005435464490	23622	Economy	10800.00
0005435464491	23622	Economy	9800.00
0005432382865	30488	Business	9900.00
0005433453747	30488	Business	9900.00
0005432382871	30488	Business	9900.00
0005432382864	30488	Business	9900.00
0005432382853	30488	Business	9900.00
0005432382856	30488	Business	9900.00
0005433449801	30488	Business	9900.00
0005433453748	30488	Business	9900.00
0005433449799	30488	Business	9900.00
0005432382850	30488	Business	9900.00
0005433449802	30488	Economy	3300.00
0005432382875	30488	Economy	3300.00
0005432382869	30488	Economy	3300.00
0005433454856	30488	Economy	3300.00
0005433449786	30488	Economy	3300.00
0005432382867	30488	Economy	3300.00
0005433449785	30488	Economy	3300.00
0005433449794	30488	Economy	3300.00
0005433449787	30488	Economy	3600.00
0005432382868	30488	Economy	3300.00
0005432382866	30488	Economy	3300.00
0005432382847	30488	Economy	3300.00
0005432382881	30488	Economy	3300.00
0005433449791	30488	Economy	3300.00
0005432382848	30488	Economy	3300.00
0005433449792	30488	Economy	3300.00
0005432382846	30488	Economy	3300.00
0005432382852	30488	Economy	3300.00
0005432382872	30488	Economy	3300.00
0005433454858	30488	Economy	3300.00
0005432382870	30488	Economy	3300.00
0005432382844	30488	Economy	3300.00
0005433454857	30488	Economy	3300.00
0005432382862	30488	Economy	3300.00
0005433449795	30488	Economy	3300.00
0005433449803	30488	Economy	3300.00
0005432382859	30488	Economy	3300.00
0005433449797	30488	Economy	3300.00
0005432382874	30488	Economy	3300.00
0005433449804	30488	Economy	3300.00
0005432382883	30488	Economy	3300.00
0005432382860	30488	Economy	3300.00
0005432382878	30488	Economy	3300.00
0005432382863	30488	Economy	3300.00
0005433449805	30488	Economy	3300.00
0005432382885	30488	Economy	3300.00
0005432382880	30488	Economy	3300.00
0005432382851	30488	Economy	3300.00
0005433449790	30488	Economy	3300.00
0005432382861	30488	Economy	3300.00
0005433449800	30488	Economy	3300.00
0005433449796	30488	Economy	3300.00
0005432382854	30488	Economy	3300.00
0005433449789	30488	Economy	3300.00
0005432382858	30488	Economy	3300.00
0005432382884	30488	Economy	3300.00
0005432382845	30488	Economy	3300.00
0005432382882	30488	Economy	3300.00
0005432382877	30488	Economy	3300.00
0005432382876	30488	Economy	3300.00
0005432382855	30488	Economy	3300.00
0005432382849	30488	Economy	3300.00
0005432382873	30488	Economy	3300.00
0005432382857	30488	Economy	3300.00
0005433449798	30488	Economy	3300.00
0005433449793	30488	Economy	3300.00
0005433449788	30488	Economy	3300.00
0005432382879	30488	Economy	3300.00
0005433453729	31329	Business	9900.00
0005432382510	31329	Business	9900.00
0005433449653	31329	Business	9900.00
0005432382545	31329	Economy	3300.00
0005433449590	31329	Economy	3300.00
0005433449583	31329	Economy	3300.00
0005432382484	31329	Economy	3600.00
0005433451582	31329	Economy	3300.00
0005432382490	31329	Economy	3300.00
0005432382507	31329	Economy	3300.00
0005433449628	31329	Economy	3300.00
0005433449615	31329	Economy	3300.00
0005433449599	31329	Economy	3300.00
0005433449659	31329	Economy	3300.00
0005432382501	31329	Economy	3300.00
0005433449660	31329	Economy	3300.00
0005432382572	31329	Economy	3300.00
0005432382559	31329	Economy	3300.00
0005433451591	31329	Economy	3300.00
0005433451592	31329	Economy	3300.00
0005432382536	31329	Economy	3300.00
0005433451586	31329	Economy	3300.00
0005432382518	31329	Economy	3300.00
0005433451593	31329	Economy	3300.00
0005433449593	31329	Economy	3300.00
0005432382509	31329	Economy	3300.00
0005433449598	31329	Economy	3300.00
0005432382544	31329	Economy	3300.00
0005432382519	31329	Economy	3300.00
0005432382508	31329	Economy	3300.00
0005432382503	31329	Economy	3300.00
0005432382487	31329	Economy	3300.00
0005432382521	31329	Economy	3300.00
0005433449584	31329	Economy	3300.00
0005433449639	31329	Economy	3300.00
0005433788172	20833	Economy	26200.00
0005433788167	20833	Economy	23800.00
0005433788166	20833	Economy	23800.00
0005433788174	20833	Economy	23800.00
0005433788168	20833	Economy	23800.00
0005433788171	20833	Economy	23800.00
0005433788176	20833	Economy	23800.00
0005433788165	20833	Economy	23800.00
0005433788177	20833	Economy	23800.00
0005433788163	20833	Economy	23800.00
0005433788173	20833	Economy	23800.00
0005433788162	20833	Economy	23800.00
0005433788161	20833	Economy	23800.00
0005433788169	20833	Economy	23800.00
0005433788170	20833	Economy	23800.00
0005433788164	20833	Economy	23800.00
0005433788175	20833	Economy	23800.00
0005435548451	26470	Economy	23800.00
0005435548452	26470	Economy	23800.00
0005435548460	26470	Economy	23800.00
0005433788142	26470	Economy	23800.00
0005433788144	26470	Economy	23800.00
0005435548456	26470	Economy	23800.00
0005433788141	26470	Economy	23800.00
0005435548453	26470	Economy	23800.00
0005435548461	26470	Economy	23800.00
0005435548450	26470	Economy	23800.00
0005435548455	26470	Economy	23800.00
0005435548457	26470	Economy	23800.00
0005435548462	26470	Economy	23800.00
0005435548458	26470	Economy	23800.00
0005435548454	26470	Economy	23800.00
0005435548459	26470	Economy	23800.00
0005433788148	26470	Economy	23800.00
0005435299698	10764	Economy	17100.00
0005433126775	10764	Economy	15600.00
0005433126776	10764	Economy	15600.00
0005433126774	10764	Economy	15600.00
0005435304102	10764	Economy	15600.00
0005435304101	10764	Economy	15600.00
0005435299705	10764	Economy	15600.00
0005433131633	10764	Economy	15600.00
0005433131632	10764	Economy	15600.00
0005435302164	29698	Economy	17100.00
0005433129245	29698	Economy	15600.00
0005433129243	29698	Economy	15600.00
0005433126809	29698	Economy	15600.00
0005433126813	29698	Economy	15600.00
0005435302167	29698	Economy	15600.00
0005433129244	29698	Economy	15600.00
0005435299741	29698	Economy	15600.00
0005435302165	29698	Economy	15600.00
0005433126812	29698	Economy	15600.00
0005433126811	29698	Economy	15600.00
0005433126810	29698	Economy	15600.00
0005435299743	29698	Economy	15600.00
0005433129242	29698	Economy	15600.00
0005433129241	29698	Economy	15600.00
0005435302166	29698	Economy	15600.00
0005435299740	29698	Economy	15600.00
0005435299742	29698	Economy	15600.00
0005435299739	29698	Economy	15600.00
0005434287108	2381	Economy	17200.00
0005434287113	2381	Economy	15700.00
0005434287119	2381	Economy	15700.00
0005434287111	2381	Economy	15700.00
0005434287106	2381	Economy	15700.00
0005434287099	2381	Economy	15700.00
0005434287118	2381	Economy	15700.00
0005434287104	2381	Economy	15700.00
0005432264456	2381	Economy	15700.00
0005433109856	2381	Economy	15700.00
0005433109892	2381	Economy	15700.00
0005434287110	2381	Economy	15700.00
0005434287105	2381	Economy	15700.00
0005434287109	2381	Economy	15700.00
0005434287114	2381	Economy	15700.00
0005434287098	2381	Economy	15700.00
0005434287116	2381	Economy	15700.00
0005434287097	2381	Economy	15700.00
0005434287103	2381	Economy	15700.00
0005433109865	2381	Economy	15700.00
0005434287120	2381	Economy	15700.00
0005432264455	2381	Economy	15700.00
0005434287107	2381	Economy	15700.00
0005434287112	2381	Economy	15700.00
0005434287100	2381	Economy	15700.00
0005434287117	2381	Economy	15700.00
0005434287101	2381	Economy	15700.00
0005434287115	2381	Economy	15700.00
0005434287102	2381	Economy	15700.00
0005434286963	26875	Economy	17200.00
0005434286922	26875	Economy	17200.00
0005434286972	26875	Economy	15700.00
0005434287002	26875	Economy	15700.00
0005433109949	26875	Economy	15700.00
0005433109950	26875	Economy	15700.00
0005433109951	26875	Economy	15700.00
0005434286904	26875	Economy	15700.00
0005434286924	26875	Economy	15700.00
0005434287001	26875	Economy	15700.00
0005433109958	26875	Economy	15700.00
0005434286956	26875	Economy	15700.00
0005434286903	26875	Economy	15700.00
0005433109956	26875	Economy	15700.00
0005434286923	26875	Economy	15700.00
0005433109957	26875	Economy	15700.00
0005434286955	26875	Economy	15700.00
0005434286937	26875	Economy	15700.00
0005433109952	26875	Economy	15700.00
0005434286948	26875	Economy	15700.00
0005433109955	26875	Economy	15700.00
0005433109960	26875	Economy	15700.00
0005433109953	26875	Economy	15700.00
0005434286925	26875	Economy	15700.00
0005433109959	26875	Economy	15700.00
0005433109954	26875	Economy	15700.00
0005433109961	26875	Economy	15700.00
0005434286917	26875	Economy	15700.00
0005434286947	26875	Economy	15700.00
0005435856172	25478	Economy	25000.00
0005434269070	25478	Economy	22800.00
0005435856168	25478	Economy	22800.00
0005435856171	25478	Economy	22800.00
0005435856169	25478	Economy	22800.00
0005435856170	25478	Economy	22800.00
0005434273063	26654	Economy	25000.00
0005434272179	26654	Economy	22800.00
0005434272178	26654	Economy	22800.00
0005434273064	26654	Economy	22800.00
0005435856143	26654	Economy	22800.00
0005434520191	6101	Economy	24600.00
0005434520187	6101	Economy	24600.00
0005434520193	6101	Economy	24600.00
0005434520203	6101	Economy	24600.00
0005434520210	6101	Economy	22300.00
0005434520196	6101	Economy	22300.00
0005434520199	6101	Economy	22300.00
0005434520190	6101	Economy	22300.00
0005434520194	6101	Economy	22300.00
0005434520204	6101	Economy	22300.00
0005434520192	6101	Economy	22300.00
0005434520200	6101	Economy	22300.00
0005435314784	6101	Economy	22300.00
0005434520197	6101	Economy	22300.00
0005435314776	6101	Economy	22300.00
0005434520205	6101	Economy	22300.00
0005434520188	6101	Economy	22300.00
0005434520189	6101	Economy	22300.00
0005434520195	6101	Economy	22300.00
0005434520208	6101	Economy	22300.00
0005435314775	6101	Economy	22300.00
0005434520202	6101	Economy	22300.00
0005434520201	6101	Economy	22300.00
0005434520207	6101	Economy	22300.00
0005434520206	6101	Economy	22300.00
0005434520209	6101	Economy	22300.00
0005435314770	6101	Economy	22300.00
0005434520198	6101	Economy	22300.00
0005434520186	6101	Economy	22300.00
0005435314769	6101	Economy	22300.00
0005435314782	6101	Economy	22300.00
0005433650478	7165	Business	89800.00
0005433650505	7165	Business	89800.00
0005433650509	7165	Business	89800.00
0005433650474	7165	Business	89800.00
0005433650471	7165	Business	89800.00
0005433650525	7165	Business	89800.00
0005435263479	7165	Business	89800.00
0005435263491	7165	Business	89800.00
0005433650473	7165	Business	89800.00
0005433650519	7165	Business	89800.00
0005433650494	7165	Business	89800.00
0005433650502	7165	Economy	29900.00
0005435263485	7165	Economy	29900.00
0005433650492	7165	Economy	29900.00
0005433650490	7165	Economy	29900.00
0005433650483	7165	Economy	29900.00
0005433650503	7165	Economy	29900.00
0005433650475	7165	Economy	29900.00
0005433650498	7165	Economy	29900.00
0005433650467	7165	Economy	32900.00
0005433650526	7165	Economy	32900.00
0005435263490	7165	Economy	32900.00
0005433650497	7165	Economy	32900.00
0005433650472	7165	Economy	32900.00
0005435263489	7165	Economy	29900.00
0005433650521	7165	Economy	29900.00
0005433650514	7165	Economy	29900.00
0005433650470	7165	Economy	29900.00
0005433650506	7165	Economy	29900.00
0005433650518	7165	Economy	29900.00
0005433650524	7165	Economy	29900.00
0005433650504	7165	Economy	29900.00
0005433650507	7165	Economy	29900.00
0005433650463	7165	Economy	29900.00
0005433650466	7165	Economy	29900.00
0005435263497	7165	Economy	29900.00
0005433650501	7165	Economy	29900.00
0005433650496	7165	Economy	29900.00
0005433650477	7165	Economy	29900.00
0005433650522	7165	Economy	29900.00
0005433650469	7165	Economy	29900.00
0005433650486	7165	Economy	29900.00
0005435263487	7165	Economy	29900.00
0005433650493	7165	Economy	29900.00
0005433650499	7165	Economy	29900.00
0005433650479	7165	Economy	29900.00
0005433650488	7165	Economy	29900.00
0005433650481	7165	Economy	29900.00
0005433650476	7165	Economy	29900.00
0005435263484	7165	Economy	29900.00
0005433650491	7165	Economy	29900.00
0005433650523	7165	Economy	29900.00
0005435263486	7165	Economy	29900.00
0005433650508	7165	Economy	29900.00
0005433650464	7165	Economy	29900.00
0005433650468	7165	Economy	29900.00
0005435263480	7165	Economy	29900.00
0005433650489	7165	Economy	29900.00
0005433650512	7165	Economy	29900.00
0005433650480	7165	Economy	29900.00
0005433650482	7165	Economy	29900.00
0005433650487	7165	Economy	29900.00
0005435263481	7165	Economy	29900.00
0005433650511	7165	Economy	29900.00
0005433650500	7165	Economy	29900.00
0005433650495	7165	Economy	29900.00
0005433650517	7165	Economy	29900.00
0005433650516	7165	Economy	29900.00
0005433650465	7165	Economy	29900.00
0005435263488	7165	Economy	29900.00
0005435263482	7165	Economy	29900.00
0005433650484	7165	Economy	29900.00
0005433650485	7165	Economy	29900.00
0005433650510	7165	Economy	29900.00
0005433650515	7165	Economy	29900.00
0005433650520	7165	Economy	29900.00
0005433650513	7165	Economy	29900.00
0005433650401	27625	Business	89800.00
0005435263553	27625	Business	89800.00
0005433650448	27625	Business	89800.00
0005433650381	27625	Business	89800.00
0005435263546	27625	Business	89800.00
0005435263541	27625	Business	89800.00
0005435263562	27625	Business	89800.00
0005435263544	27625	Business	89800.00
0005435263561	27625	Business	89800.00
0005433650419	27625	Economy	29900.00
0005435263537	27625	Economy	29900.00
0005433650391	27625	Economy	29900.00
0005433650400	27625	Economy	29900.00
0005433650384	27625	Economy	29900.00
0005435263560	27625	Economy	29900.00
0005435263563	27625	Economy	29900.00
0005433650454	27625	Economy	29900.00
0005435263555	27625	Economy	32900.00
0005433650369	27625	Economy	32900.00
0005433650449	27625	Economy	32900.00
0005433650386	27625	Economy	29900.00
0005433650374	27625	Economy	29900.00
0005433650387	27625	Economy	29900.00
0005433650411	27625	Economy	29900.00
0005433650385	27625	Economy	29900.00
0005435263545	27625	Economy	29900.00
0005435263539	27625	Economy	29900.00
0005433650408	27625	Economy	29900.00
0005435263559	27625	Economy	29900.00
0005433650375	27625	Economy	29900.00
0005435263557	27625	Economy	29900.00
0005433650392	27625	Economy	29900.00
0005435263551	27625	Economy	29900.00
0005433650376	27625	Economy	29900.00
0005435263549	27625	Economy	29900.00
0005433650412	27625	Economy	29900.00
0005435263556	27625	Economy	29900.00
0005433650420	27625	Economy	29900.00
0005435263536	27625	Economy	29900.00
0005433650367	27625	Economy	29900.00
0005435263543	27625	Economy	29900.00
0005435263552	27625	Economy	29900.00
0005435263540	27625	Economy	29900.00
0005435263542	27625	Economy	29900.00
0005435263547	27625	Economy	29900.00
0005435263558	27625	Economy	29900.00
0005433650388	27625	Economy	29900.00
0005433650370	27625	Economy	29900.00
0005435263554	27625	Economy	29900.00
0005435263550	27625	Economy	29900.00
0005435263548	27625	Economy	29900.00
0005435263538	27625	Economy	29900.00
0005433868110	4788	Economy	19400.00
0005433868130	4788	Economy	19400.00
0005433868097	4788	Economy	19400.00
0005433868105	4788	Economy	19400.00
0005433868115	4788	Economy	17600.00
0005433868123	4788	Economy	17600.00
0005433868136	4788	Economy	17600.00
0005433868134	4788	Economy	17600.00
0005433868106	4788	Economy	17600.00
0005433868101	4788	Economy	17600.00
0005433868117	4788	Economy	17600.00
0005433868118	4788	Economy	17600.00
0005433868100	4788	Economy	17600.00
0005433868116	4788	Economy	17600.00
0005433868133	4788	Economy	17600.00
0005433868121	4788	Economy	17600.00
0005433868128	4788	Economy	17600.00
0005433868109	4788	Economy	17600.00
0005433868124	4788	Economy	17600.00
0005433868119	4788	Economy	17600.00
0005433868095	4788	Economy	17600.00
0005433868096	4788	Economy	17600.00
0005433868131	4788	Economy	17600.00
0005433868129	4788	Economy	17600.00
0005433868107	4788	Economy	17600.00
0005433868125	4788	Economy	17600.00
0005433868103	4788	Economy	17600.00
0005433868102	4788	Economy	17600.00
0005433868120	4788	Economy	17600.00
0005433868132	4788	Economy	17600.00
0005433868135	4788	Economy	17600.00
0005433868098	4788	Economy	17600.00
0005433868113	4788	Economy	17600.00
0005433868104	4788	Economy	17600.00
0005433868127	4788	Economy	17600.00
0005433868099	4788	Economy	17600.00
0005433868114	4788	Economy	17600.00
0005433868112	4788	Economy	17600.00
0005433868122	4788	Economy	17600.00
0005433868108	4788	Economy	17600.00
0005433868111	4788	Economy	17600.00
0005433868126	4788	Economy	17600.00
0005433867764	32591	Economy	19400.00
0005433867751	32591	Economy	19400.00
0005433867850	32591	Economy	19400.00
0005435860462	32591	Economy	17600.00
0005433867849	32591	Economy	17600.00
0005435860466	32591	Economy	17600.00
0005433867872	32591	Economy	17600.00
0005433867802	32591	Economy	17600.00
0005433867732	32591	Economy	17600.00
0005433867776	32591	Economy	17600.00
0005433867966	32591	Economy	17600.00
0005433867820	32591	Economy	17600.00
0005433867755	32591	Economy	17600.00
0005433867780	32591	Economy	17600.00
0005435860464	32591	Economy	17600.00
0005435860463	32591	Economy	17600.00
0005433867873	32591	Economy	17600.00
0005433867766	32591	Economy	17600.00
0005433867733	32591	Economy	17600.00
0005433867810	32591	Economy	17600.00
0005435860465	32591	Economy	17600.00
0005433867752	32591	Economy	17600.00
0005434663302	3436	Economy	22600.00
0005434663306	3436	Economy	22600.00
0005434663296	3436	Economy	22600.00
0005435911318	3436	Economy	22600.00
0005434663305	3436	Economy	22600.00
0005434663298	3436	Economy	22600.00
0005434663304	3436	Economy	22600.00
0005434460489	3436	Economy	22600.00
0005434663301	3436	Economy	22600.00
0005434663300	3436	Economy	22600.00
0005434663299	3436	Economy	22600.00
0005435911335	3436	Economy	22600.00
0005434460490	3436	Economy	22600.00
0005434461630	3436	Economy	22600.00
0005434663295	3436	Economy	22600.00
0005435911316	3436	Economy	22600.00
0005434663303	3436	Economy	22600.00
0005434460488	3436	Economy	22600.00
0005435911319	3436	Economy	22600.00
0005434461628	3436	Economy	22600.00
0005434663294	3436	Economy	22600.00
0005434663297	3436	Economy	22600.00
0005434663292	3436	Economy	22600.00
0005435911315	3436	Economy	22600.00
0005434663293	3436	Economy	22600.00
0005434461629	3436	Economy	22600.00
0005435911320	3436	Economy	22600.00
0005434460487	3436	Economy	22600.00
0005435911387	12489	Economy	22600.00
0005435911393	12489	Economy	22600.00
0005435911386	12489	Economy	22600.00
0005435911390	12489	Economy	22600.00
0005435911392	12489	Economy	22600.00
0005434663218	12489	Economy	22600.00
0005434663187	12489	Economy	22600.00
0005434663216	12489	Economy	22600.00
0005434663172	12489	Economy	22600.00
0005435911389	12489	Economy	22600.00
0005434663192	12489	Economy	22600.00
0005435911391	12489	Economy	22600.00
0005434663217	12489	Economy	22600.00
0005435911388	12489	Economy	22600.00
0005433867872	14523	Economy	18500.00
0005433867966	14523	Economy	16800.00
0005433867820	14523	Economy	16800.00
0005433867751	14523	Economy	16800.00
0005435860464	14523	Economy	16800.00
0005433867802	14523	Economy	16800.00
0005433867780	14523	Economy	16800.00
0005433867755	14523	Economy	16800.00
0005433867776	14523	Economy	16800.00
0005433867873	14523	Economy	16800.00
0005433867732	14523	Economy	16800.00
0005435860465	14523	Economy	16800.00
0005435860463	14523	Economy	16800.00
0005433867733	14523	Economy	16800.00
0005435860462	14523	Economy	16800.00
0005433867752	14523	Economy	16800.00
0005433867766	14523	Economy	16800.00
0005433867850	14523	Economy	16800.00
0005433867849	14523	Economy	16800.00
0005433867810	14523	Economy	16800.00
0005435860466	14523	Economy	16800.00
0005433867764	14523	Economy	16800.00
0005433868061	32657	Economy	18500.00
0005433868081	32657	Economy	18500.00
0005433868091	32657	Economy	18500.00
0005433868094	32657	Economy	16800.00
0005433868065	32657	Economy	16800.00
0005433868077	32657	Economy	16800.00
0005433868078	32657	Economy	16800.00
0005433868082	32657	Economy	16800.00
0005433868083	32657	Economy	16800.00
0005433868069	32657	Economy	16800.00
0005433868059	32657	Economy	16800.00
0005433868066	32657	Economy	16800.00
0005433868088	32657	Economy	16800.00
0005433868064	32657	Economy	16800.00
0005433868079	32657	Economy	16800.00
0005433868084	32657	Economy	16800.00
0005433868062	32657	Economy	16800.00
0005433868055	32657	Economy	16800.00
0005433868074	32657	Economy	16800.00
0005433868085	32657	Economy	16800.00
0005433868070	32657	Economy	16800.00
0005433868080	32657	Economy	16800.00
0005433868068	32657	Economy	16800.00
0005433868056	32657	Economy	16800.00
0005433868075	32657	Economy	16800.00
0005433868092	32657	Economy	16800.00
0005433868073	32657	Economy	16800.00
0005433868087	32657	Economy	16800.00
0005433868063	32657	Economy	16800.00
0005433868093	32657	Economy	16800.00
0005433868089	32657	Economy	16800.00
0005433868072	32657	Economy	16800.00
0005433868054	32657	Economy	16800.00
0005433868057	32657	Economy	16800.00
0005433868086	32657	Economy	16800.00
0005433868060	32657	Economy	16800.00
0005433868067	32657	Economy	16800.00
0005433868090	32657	Economy	16800.00
0005433868071	32657	Economy	16800.00
0005433868058	32657	Economy	16800.00
0005433868076	32657	Economy	16800.00
0005432798961	12116	Economy	4900.00
0005432799027	12116	Economy	4900.00
0005432799016	12116	Economy	4900.00
0005432799037	12116	Economy	4400.00
0005432798967	12116	Economy	4400.00
0005432798960	12116	Economy	4400.00
0005432799068	12116	Economy	4400.00
0005432798956	12116	Economy	4400.00
0005432799034	12116	Economy	4400.00
0005432798976	12116	Economy	4400.00
0005432798955	12116	Economy	4400.00
0005432799001	12116	Economy	4400.00
0005432799021	12116	Economy	4400.00
0005432798963	12116	Economy	4400.00
0005432799097	12116	Economy	4400.00
0005432799006	12116	Economy	4400.00
0005432798995	12116	Economy	4400.00
0005432799035	12116	Economy	4400.00
0005432799002	12116	Economy	4400.00
0005432798954	12116	Economy	4400.00
0005432799041	12116	Economy	4400.00
0005432798968	12116	Economy	4400.00
0005432798953	12116	Economy	4400.00
0005432798959	12116	Economy	4400.00
0005432799039	12116	Economy	4400.00
0005432799098	12116	Economy	4400.00
0005432798983	12116	Economy	4400.00
0005432799094	12116	Economy	4400.00
0005432799211	14796	Economy	4900.00
0005432799200	14796	Economy	4900.00
0005432799209	14796	Economy	4400.00
0005432799189	14796	Economy	4400.00
0005432799190	14796	Economy	4400.00
0005432799206	14796	Economy	4400.00
0005432799196	14796	Economy	4400.00
0005432799194	14796	Economy	4400.00
0005432799201	14796	Economy	4400.00
0005432799193	14796	Economy	4400.00
0005432799187	14796	Economy	4400.00
0005432799204	14796	Economy	4400.00
0005432799203	14796	Economy	4400.00
0005432799210	14796	Economy	4400.00
0005432799207	14796	Economy	4400.00
0005432799205	14796	Economy	4400.00
0005432799185	14796	Economy	4400.00
0005432799188	14796	Economy	4400.00
0005432799186	14796	Economy	4400.00
0005432799197	14796	Economy	4400.00
0005432799192	14796	Economy	4400.00
0005432799195	14796	Economy	4400.00
0005432799202	14796	Economy	4400.00
0005432799198	14796	Economy	4400.00
0005432799199	14796	Economy	4400.00
0005432799184	14796	Economy	4400.00
0005432799191	14796	Economy	4400.00
0005432799208	14796	Economy	4400.00
0005432799212	14796	Economy	4400.00
0005434299365	7066	Business	49100.00
0005434407276	7066	Business	49100.00
0005434299372	7066	Business	49100.00
0005434299370	7066	Business	49100.00
0005434407255	7066	Business	49100.00
0005434407258	7066	Business	49100.00
0005434299379	7066	Business	49100.00
0005432153882	7066	Business	49100.00
0005434299361	7066	Economy	16400.00
0005435310873	7066	Economy	16400.00
0005434407251	7066	Economy	16400.00
0005434299368	7066	Economy	16400.00
0005434407256	7066	Economy	16400.00
0005434299374	7066	Economy	16400.00
0005434407233	7066	Economy	16400.00
0005434407263	7066	Economy	16400.00
0005434407230	7066	Economy	16400.00
0005434407279	7066	Economy	16400.00
0005434407274	7066	Economy	16400.00
0005434407245	7066	Economy	16400.00
0005434299380	7066	Economy	16400.00
0005434407246	7066	Economy	16400.00
0005434299381	7066	Economy	16400.00
0005434407262	7066	Economy	16400.00
0005434407265	7066	Economy	16400.00
0005434407261	7066	Economy	16400.00
0005434407232	7066	Economy	16400.00
0005434407223	7066	Economy	16400.00
0005434407278	7066	Economy	16400.00
0005434407257	7066	Economy	16400.00
0005434407268	7066	Economy	16400.00
0005434299367	7066	Economy	16400.00
0005434407236	7066	Economy	16400.00
0005434407252	7066	Economy	16400.00
0005432153881	7066	Economy	16400.00
0005434299378	7066	Economy	16400.00
0005434407239	7066	Economy	16400.00
0005435310840	7066	Economy	16400.00
0005434407224	7066	Economy	16400.00
0005434407281	7066	Economy	16400.00
0005434407237	7066	Economy	16400.00
0005434299382	7066	Economy	16400.00
0005434407247	7066	Economy	16400.00
0005434407241	7066	Economy	16400.00
0005435310872	7066	Economy	16400.00
0005434407253	7066	Economy	18000.00
0005432153884	7066	Economy	18000.00
0005432108229	7066	Economy	18000.00
0005435293045	7066	Economy	16400.00
0005434299376	7066	Economy	16400.00
0005434407269	7066	Economy	16400.00
0005435293075	7066	Economy	16400.00
0005434407234	7066	Economy	16400.00
0005434407219	7066	Economy	16400.00
0005434407267	7066	Economy	16400.00
0005435310856	7066	Economy	16400.00
0005434299366	7066	Economy	16400.00
0005434299364	7066	Economy	16400.00
0005435310858	7066	Economy	16400.00
0005434407271	7066	Economy	16400.00
0005434299375	7066	Economy	16400.00
0005434299383	7066	Economy	16400.00
0005432153878	7066	Economy	16400.00
0005434407226	7066	Economy	16400.00
0005432153883	7066	Economy	16400.00
0005434407221	7066	Economy	16400.00
0005434407280	7066	Economy	16400.00
0005434407259	7066	Economy	16400.00
0005434407218	7066	Economy	16400.00
0005434407244	7066	Economy	16400.00
0005434299369	7066	Economy	16400.00
0005434407248	7066	Economy	16400.00
0005435293061	7066	Economy	16400.00
0005435293076	7066	Economy	16400.00
0005434299371	7066	Economy	16400.00
0005434407272	7066	Economy	16400.00
0005435293062	7066	Economy	16400.00
0005434407225	7066	Economy	16400.00
0005435310867	7066	Economy	16400.00
0005432153879	7066	Economy	16400.00
0005434407277	7066	Economy	16400.00
0005434407227	7066	Economy	16400.00
0005434299362	7066	Economy	16400.00
0005435293074	7066	Economy	16400.00
0005434407249	7066	Economy	16400.00
0005434407260	7066	Economy	16400.00
0005434407240	7066	Economy	16400.00
0005434407275	7066	Economy	16400.00
0005434407273	7066	Economy	16400.00
0005434407229	7066	Economy	16400.00
0005434407242	7066	Economy	16400.00
0005434407235	7066	Economy	16400.00
0005434407243	7066	Economy	16400.00
0005434407228	7066	Economy	16400.00
0005434407266	7066	Economy	16400.00
0005435310857	7066	Economy	16400.00
0005434407231	7066	Economy	16400.00
0005434407250	7066	Economy	16400.00
0005434299363	7066	Economy	16400.00
0005434407270	7066	Economy	16400.00
0005434407238	7066	Economy	16400.00
0005432153880	7066	Economy	16400.00
0005435293096	7066	Economy	16400.00
0005434407254	7066	Economy	16400.00
0005435310855	7066	Economy	16400.00
0005434407222	7066	Economy	16400.00
0005432108228	7066	Economy	16400.00
0005434299373	7066	Economy	16400.00
0005434407220	7066	Economy	16400.00
0005434407264	7066	Economy	16400.00
0005434299377	7066	Economy	16400.00
0005434406727	26921	Business	49100.00
0005434406824	26921	Business	49100.00
0005434406825	26921	Business	49100.00
0005435310958	26921	Business	49100.00
0005435310960	26921	Business	49100.00
0005434299260	26921	Business	49100.00
0005434299161	26921	Economy	16400.00
0005435293145	26921	Economy	16400.00
0005434406778	26921	Economy	16400.00
0005434406728	26921	Economy	16400.00
0005434406717	26921	Economy	16400.00
0005434406748	26921	Economy	16400.00
0005434299160	26921	Economy	16400.00
0005435293148	26921	Economy	16400.00
0005434406777	26921	Economy	16400.00
0005434406647	26921	Economy	16400.00
0005434299285	26921	Economy	16400.00
0005434299244	26921	Economy	16400.00
0005434406701	26921	Economy	16400.00
0005435310967	26921	Economy	16400.00
0005435310965	26921	Economy	16400.00
0005434406667	26921	Economy	16400.00
0005434406686	26921	Economy	16400.00
0005435310964	26921	Economy	16400.00
0005435293147	26921	Economy	16400.00
0005435293155	26921	Economy	16400.00
0005435293151	26921	Economy	16400.00
0005435310950	26921	Economy	16400.00
0005434406989	26921	Economy	16400.00
0005434299236	26921	Economy	16400.00
0005434406704	26921	Economy	16400.00
0005434299279	26921	Economy	16400.00
0005435310951	26921	Economy	16400.00
0005432058346	26921	Economy	16400.00
0005435310953	26921	Economy	16400.00
0005434299227	26921	Economy	16400.00
0005434299204	26921	Economy	18000.00
0005434406646	26921	Economy	18000.00
0005435293150	26921	Economy	16400.00
0005435310954	26921	Economy	16400.00
0005434406680	26921	Economy	16400.00
0005435293152	26921	Economy	16400.00
0005434406809	26921	Economy	16400.00
0005435310952	26921	Economy	16400.00
0005435310966	26921	Economy	16400.00
0005434299217	26921	Economy	16400.00
0005434299219	26921	Economy	16400.00
0005435310961	26921	Economy	16400.00
0005435293146	26921	Economy	16400.00
0005434406670	26921	Economy	16400.00
0005434406823	26921	Economy	16400.00
0005434406668	26921	Economy	16400.00
0005434406723	26921	Economy	16400.00
0005435310968	26921	Economy	16400.00
0005434406669	26921	Economy	16400.00
0005434406681	26921	Economy	16400.00
0005435293154	26921	Economy	16400.00
0005434406639	26921	Economy	16400.00
0005434299220	26921	Economy	16400.00
0005435310963	26921	Economy	16400.00
0005434299218	26921	Economy	16400.00
0005432058347	26921	Economy	16400.00
0005435310956	26921	Economy	16400.00
0005435310949	26921	Economy	16400.00
0005434299261	26921	Economy	16400.00
0005435310955	26921	Economy	16400.00
0005434299221	26921	Economy	16400.00
0005435310959	26921	Economy	16400.00
0005434406855	26921	Economy	16400.00
0005434299209	26921	Economy	16400.00
0005435293156	26921	Economy	16400.00
0005432058344	26921	Economy	16400.00
0005434406664	26921	Economy	16400.00
0005434406665	26921	Economy	16400.00
0005435293149	26921	Economy	16400.00
0005434406776	26921	Economy	16400.00
0005434406683	26921	Economy	16400.00
0005434406645	26921	Economy	16400.00
0005434299284	26921	Economy	16400.00
0005435310962	26921	Economy	16400.00
0005434406892	26921	Economy	16400.00
0005435293153	26921	Economy	16400.00
0005435310957	26921	Economy	16400.00
0005434406682	26921	Economy	16400.00
0005434406724	26921	Economy	16400.00
0005432058345	26921	Economy	16400.00
0005434299262	26921	Economy	16400.00
0005434406687	26921	Economy	16400.00
0005434406694	26921	Economy	16400.00
0005435293144	26921	Economy	16400.00
0005434406822	26921	Economy	16400.00
0005432604028	6452	Economy	16500.00
0005432604032	6452	Economy	16500.00
0005432604026	6452	Economy	16500.00
0005432604027	6452	Economy	16500.00
0005432604030	6452	Economy	15000.00
0005432604010	6452	Economy	15000.00
0005432604037	6452	Economy	15000.00
0005432604035	6452	Economy	15000.00
0005434512076	6452	Economy	15000.00
0005432604016	6452	Economy	15000.00
0005432604018	6452	Economy	15000.00
0005432604043	6452	Economy	15000.00
0005432604029	6452	Economy	15000.00
0005432604031	6452	Economy	15000.00
0005432604021	6452	Economy	15000.00
0005434512073	6452	Economy	15000.00
0005432604044	6452	Economy	15000.00
0005432604019	6452	Economy	15000.00
0005432604034	6452	Economy	15000.00
0005432604041	6452	Economy	15000.00
0005434512079	6452	Economy	15000.00
0005432604046	6452	Economy	15000.00
0005432604022	6452	Economy	15000.00
0005432604017	6452	Economy	15000.00
0005432604012	6452	Economy	15000.00
0005432604013	6452	Economy	15000.00
0005432604040	6452	Economy	15000.00
0005432604023	6452	Economy	15000.00
0005432604007	6452	Economy	15000.00
0005432604024	6452	Economy	15000.00
0005432604014	6452	Economy	15000.00
0005432604025	6452	Economy	15000.00
0005432604009	6452	Economy	15000.00
0005432604045	6452	Economy	15000.00
0005432604036	6452	Economy	15000.00
0005432604039	6452	Economy	15000.00
0005434512078	6452	Economy	15000.00
0005432604006	6452	Economy	15000.00
0005432604020	6452	Economy	15000.00
0005432604042	6452	Economy	15000.00
0005434512080	6452	Economy	15000.00
0005432604008	6452	Economy	15000.00
0005434512075	6452	Economy	15000.00
0005432604015	6452	Economy	15000.00
0005432604011	6452	Economy	15000.00
0005434512077	6452	Economy	15000.00
0005432604038	6452	Economy	15000.00
0005432604033	6452	Economy	15000.00
0005434512074	6452	Economy	15000.00
0005432603643	21389	Economy	16500.00
0005432603737	21389	Economy	15000.00
0005432603739	21389	Economy	15000.00
0005432603645	21389	Economy	15000.00
0005432603797	21389	Economy	15000.00
0005432603659	21389	Economy	15000.00
0005432603671	21389	Economy	15000.00
0005432603672	21389	Economy	15000.00
0005432603738	21389	Economy	15000.00
0005432603682	21389	Economy	15000.00
0005432603652	21389	Economy	15000.00
0005432603651	21389	Economy	15000.00
0005432603701	21389	Economy	15000.00
0005432603658	21389	Economy	15000.00
0005432603649	21389	Economy	15000.00
0005432603660	21389	Economy	15000.00
0005432603654	21389	Economy	15000.00
0005432603740	21389	Economy	15000.00
0005432603650	21389	Economy	15000.00
0005432603644	21389	Economy	15000.00
0005432603699	21389	Economy	15000.00
0005432603653	21389	Economy	15000.00
0005432603783	21389	Economy	15000.00
0005432603702	21389	Economy	15000.00
0005434906401	15020	Business	18900.00
0005434906447	15020	Business	18900.00
0005433251237	15020	Business	18900.00
0005433251233	15020	Business	18900.00
0005433251222	15020	Business	18900.00
0005433251221	15020	Business	18900.00
0005433251234	15020	Business	18900.00
0005434906420	15020	Business	18900.00
0005434906389	15020	Economy	6300.00
0005433251240	15020	Economy	6300.00
0005433251235	15020	Economy	6300.00
0005433251228	15020	Economy	6300.00
0005433251223	15020	Economy	6900.00
0005433251230	15020	Economy	6900.00
0005433251229	15020	Economy	6900.00
0005433251225	15020	Economy	6900.00
0005433251242	15020	Economy	6300.00
0005434906446	15020	Economy	6300.00
0005433251232	15020	Economy	6300.00
0005434906407	15020	Economy	6300.00
0005433251216	15020	Economy	6300.00
0005433251212	15020	Economy	6300.00
0005433251220	15020	Economy	6300.00
0005434906431	15020	Economy	6300.00
0005434906391	15020	Economy	6300.00
0005433251238	15020	Economy	6300.00
0005434906415	15020	Economy	6300.00
0005433251214	15020	Economy	6300.00
0005433251213	15020	Economy	6300.00
0005433251236	15020	Economy	6300.00
0005434906442	15020	Economy	6300.00
0005434906367	15020	Economy	6300.00
0005433251219	15020	Economy	6300.00
0005434906445	15020	Economy	6300.00
0005434906437	15020	Economy	6300.00
0005433251224	15020	Economy	6300.00
0005434906368	15020	Economy	6300.00
0005433251231	15020	Economy	6300.00
0005434906438	15020	Economy	6300.00
0005433251226	15020	Economy	6300.00
0005434906360	15020	Economy	6300.00
0005434906436	15020	Economy	6300.00
0005434906395	15020	Economy	6300.00
0005433251218	15020	Economy	6300.00
0005433251227	15020	Economy	6300.00
0005434906409	15020	Economy	6300.00
0005434906390	15020	Economy	6300.00
0005433251241	15020	Economy	6300.00
0005434906441	15020	Economy	6300.00
0005433251215	15020	Economy	6300.00
0005433251239	15020	Economy	6300.00
0005433251217	15020	Economy	6300.00
0005434906370	15020	Economy	6300.00
0005433250967	25870	Business	18900.00
0005433251096	25870	Business	18900.00
0005433251012	25870	Business	18900.00
0005434906818	25870	Business	18900.00
0005433250958	25870	Business	18900.00
0005434906848	25870	Business	18900.00
0005434906852	25870	Business	18900.00
0005433251019	25870	Business	18900.00
0005434906857	25870	Business	18900.00
0005433251098	25870	Business	18900.00
0005434906826	25870	Economy	6300.00
0005434906817	25870	Economy	6300.00
0005434906816	25870	Economy	6300.00
0005433250941	25870	Economy	6300.00
0005433250953	25870	Economy	6300.00
0005434906823	25870	Economy	6300.00
0005434906839	25870	Economy	6300.00
0005434906844	25870	Economy	6300.00
0005434906834	25870	Economy	6900.00
0005434906855	25870	Economy	6900.00
0005433251095	25870	Economy	6900.00
0005433251013	25870	Economy	6900.00
0005433251033	25870	Economy	6300.00
0005434906845	25870	Economy	6300.00
0005434906830	25870	Economy	6300.00
0005434906814	25870	Economy	6300.00
0005433250973	25870	Economy	6300.00
0005434906835	25870	Economy	6300.00
0005433250952	25870	Economy	6300.00
0005434906821	25870	Economy	6300.00
0005433251011	25870	Economy	6300.00
0005434906853	25870	Economy	6300.00
0005433251031	25870	Economy	6300.00
0005434906820	25870	Economy	6300.00
0005434906824	25870	Economy	6300.00
0005434906847	25870	Economy	6300.00
0005434906838	25870	Economy	6300.00
0005434906825	25870	Economy	6300.00
0005434906842	25870	Economy	6300.00
0005434906850	25870	Economy	6300.00
0005434906836	25870	Economy	6300.00
0005434906815	25870	Economy	6300.00
0005433250954	25870	Economy	6300.00
0005434906829	25870	Economy	6300.00
0005434906843	25870	Economy	6300.00
0005434906856	25870	Economy	6300.00
0005434906822	25870	Economy	6300.00
0005434906854	25870	Economy	6300.00
0005434906832	25870	Economy	6300.00
0005434906827	25870	Economy	6300.00
0005434906819	25870	Economy	6300.00
0005434906858	25870	Economy	6300.00
0005433250983	25870	Economy	6300.00
0005433251066	25870	Economy	6300.00
0005433250936	25870	Economy	6300.00
0005434906828	25870	Economy	6300.00
0005434906851	25870	Economy	6300.00
0005433251058	25870	Economy	6300.00
0005433251065	25870	Economy	6300.00
0005434906833	25870	Economy	6300.00
0005433250962	25870	Economy	6300.00
0005434906837	25870	Economy	6300.00
0005433250979	25870	Economy	6300.00
0005434906846	25870	Economy	6300.00
0005434906849	25870	Economy	6300.00
0005434906840	25870	Economy	6300.00
0005434906841	25870	Economy	6300.00
0005433250974	25870	Economy	6300.00
0005434906831	25870	Economy	6300.00
0005433008278	14194	Business	52300.00
0005433008272	14194	Business	52300.00
0005433008258	14194	Business	52300.00
0005433008264	14194	Economy	17400.00
0005433008254	14194	Economy	17400.00
0005433008241	14194	Economy	17400.00
0005433008253	14194	Economy	17400.00
0005433008261	14194	Economy	17400.00
0005433008275	14194	Economy	19200.00
0005433008259	14194	Economy	17400.00
0005433008285	14194	Economy	17400.00
0005433008270	14194	Economy	17400.00
0005433008263	14194	Economy	17400.00
0005433008277	14194	Economy	17400.00
0005433008255	14194	Economy	17400.00
0005433008282	14194	Economy	17400.00
0005433008252	14194	Economy	17400.00
0005433008262	14194	Economy	17400.00
0005433008273	14194	Economy	17400.00
0005433008281	14194	Economy	17400.00
0005433008284	14194	Economy	17400.00
0005433008260	14194	Economy	17400.00
0005433008280	14194	Economy	17400.00
0005433008247	14194	Economy	17400.00
0005433008256	14194	Economy	17400.00
0005433008240	14194	Economy	17400.00
0005433008276	14194	Economy	17400.00
0005433008257	14194	Economy	17400.00
0005433008245	14194	Economy	17400.00
0005433008246	14194	Economy	17400.00
0005433008251	14194	Economy	17400.00
0005433008242	14194	Economy	17400.00
0005433008267	14194	Economy	17400.00
0005433008271	14194	Economy	17400.00
0005433008265	14194	Economy	17400.00
0005433008266	14194	Economy	17400.00
0005433008268	14194	Economy	17400.00
0005433008248	14194	Economy	17400.00
0005433008274	14194	Economy	17400.00
0005433008244	14194	Economy	17400.00
0005433008243	14194	Economy	17400.00
0005433008283	14194	Economy	17400.00
0005433008249	14194	Economy	17400.00
0005433008279	14194	Economy	17400.00
0005433008269	14194	Economy	17400.00
0005433008250	14194	Economy	17400.00
0005433007989	22845	Business	52300.00
0005433007870	22845	Business	52300.00
0005433008072	22845	Business	52300.00
0005433007895	22845	Business	52300.00
0005433007839	22845	Business	52300.00
0005433007836	22845	Business	52300.00
0005433007892	22845	Business	52300.00
0005433810512	22845	Economy	17400.00
0005433007828	22845	Economy	17400.00
0005433007859	22845	Economy	17400.00
0005433007976	22845	Economy	17400.00
0005433007936	22845	Economy	17400.00
0005433007881	22845	Economy	17400.00
0005433007901	22845	Economy	19200.00
0005433007849	22845	Economy	17400.00
0005433007861	22845	Economy	17400.00
0005433007990	22845	Economy	17400.00
0005433007869	22845	Economy	17400.00
0005433007832	22845	Economy	17400.00
0005433007882	22845	Economy	17400.00
0005433810511	22845	Economy	17400.00
0005433007977	22845	Economy	17400.00
0005433007887	22845	Economy	17400.00
0005433008035	22845	Economy	17400.00
0005433007829	22845	Economy	17400.00
0005433007991	22845	Economy	17400.00
0005433007886	22845	Economy	17400.00
0005433008071	22845	Economy	17400.00
0005433007988	22845	Economy	17400.00
0005433007900	22845	Economy	17400.00
0005433007914	22845	Economy	17400.00
0005433008037	22845	Economy	17400.00
0005433810513	22845	Economy	17400.00
0005433008036	22845	Economy	17400.00
0005433810514	22845	Economy	17400.00
0005433007889	22845	Economy	17400.00
0005433810510	22845	Economy	17400.00
0005433007912	22845	Economy	17400.00
0005433007935	22845	Economy	17400.00
0005434925247	14930	Business	22900.00
0005434925252	14930	Business	22900.00
0005434925250	14930	Business	22900.00
0005434925272	14930	Economy	8400.00
0005434925279	14930	Economy	7600.00
0005434925310	14930	Economy	7600.00
0005434925261	14930	Economy	7600.00
0005434925291	14930	Economy	7600.00
0005434925292	14930	Economy	7600.00
0005434925249	14930	Economy	7600.00
0005434925271	14930	Economy	7600.00
0005434925270	14930	Economy	7600.00
0005434925513	20525	Business	22900.00
0005434925510	20525	Business	22900.00
0005434925519	20525	Business	22900.00
0005434925505	20525	Business	22900.00
0005434925527	20525	Economy	7600.00
0005434925511	20525	Economy	8400.00
0005434925530	20525	Economy	7600.00
0005434925526	20525	Economy	7600.00
0005434925515	20525	Economy	7600.00
0005434925522	20525	Economy	7600.00
0005434925518	20525	Economy	7600.00
0005434925516	20525	Economy	7600.00
0005434925523	20525	Economy	7600.00
0005434925532	20525	Economy	7600.00
0005434925503	20525	Economy	7600.00
0005434925529	20525	Economy	7600.00
0005434925531	20525	Economy	7600.00
0005434925514	20525	Economy	7600.00
0005434925524	20525	Economy	7600.00
0005434925507	20525	Economy	7600.00
0005434925525	20525	Economy	7600.00
0005434925506	20525	Economy	7600.00
0005434925520	20525	Economy	7600.00
0005434925509	20525	Economy	7600.00
0005434925521	20525	Economy	7600.00
0005434925508	20525	Economy	7600.00
0005434925504	20525	Economy	7600.00
0005434925517	20525	Economy	7600.00
0005434925528	20525	Economy	7600.00
0005434925512	20525	Economy	7600.00
0005435487664	15815	Economy	8900.00
0005435487663	15815	Economy	8100.00
0005435487672	15815	Economy	8100.00
0005435487655	15815	Economy	8100.00
0005435487658	15815	Economy	8100.00
0005435487660	15815	Economy	8100.00
0005435487673	15815	Economy	8100.00
0005435487656	15815	Economy	8100.00
0005435487667	15815	Economy	8100.00
0005435487668	15815	Economy	8100.00
0005435487662	15815	Economy	8100.00
0005435487669	15815	Economy	8100.00
0005435487666	15815	Economy	8100.00
0005435487661	15815	Economy	8100.00
0005435487671	15815	Economy	8100.00
0005435998957	15815	Economy	8100.00
0005435487659	15815	Economy	8100.00
0005435487654	15815	Economy	8100.00
0005435487675	15815	Economy	8100.00
0005435487674	15815	Economy	8100.00
0005435487665	15815	Economy	8100.00
0005435487653	15815	Economy	8100.00
0005435487657	15815	Economy	8100.00
0005435487670	15815	Economy	8100.00
0005435999103	19712	Economy	8900.00
0005435999098	19712	Economy	8900.00
0005435999096	19712	Economy	8100.00
0005435999101	19712	Economy	8100.00
0005435999095	19712	Economy	8100.00
0005435999108	19712	Economy	8100.00
0005435999097	19712	Economy	8100.00
0005435487497	19712	Economy	8100.00
0005435999100	19712	Economy	8100.00
0005435487513	19712	Economy	8100.00
0005435487512	19712	Economy	8100.00
0005435999106	19712	Economy	8100.00
0005435999099	19712	Economy	8100.00
0005435487496	19712	Economy	8100.00
0005435487472	19712	Economy	8100.00
0005435999104	19712	Economy	8100.00
0005435487477	19712	Economy	8100.00
0005435999102	19712	Economy	8100.00
0005435999107	19712	Economy	8100.00
0005435999105	19712	Economy	8100.00
0005435999094	19712	Economy	8100.00
0005435999110	19712	Economy	8100.00
0005435999109	19712	Economy	8100.00
0005435487514	19712	Economy	8100.00
0005435999111	19712	Economy	8100.00
0005435487478	19712	Economy	8100.00
0005435839228	6018	Business	199300.00
0005435839241	6018	Business	199300.00
0005435472549	6018	Business	199300.00
0005435839236	6018	Business	199300.00
0005435472520	6018	Business	199300.00
0005435472548	6018	Business	199300.00
0005435472533	6018	Business	199300.00
0005435839235	6018	Business	199300.00
0005435472532	6018	Business	199300.00
0005435839226	6018	Business	199300.00
0005435472537	6018	Economy	66400.00
0005435472573	6018	Economy	66400.00
0005435839230	6018	Economy	66400.00
0005435839233	6018	Economy	73100.00
0005435839225	6018	Economy	73100.00
0005432660803	6018	Economy	66400.00
0005435839227	6018	Economy	66400.00
0005435839222	6018	Economy	66400.00
0005435839220	6018	Economy	66400.00
0005435839246	6018	Economy	66400.00
0005435839223	6018	Economy	66400.00
0005432660802	6018	Economy	66400.00
0005435839219	6018	Economy	66400.00
0005435839242	6018	Economy	66400.00
0005435472536	6018	Economy	66400.00
0005435839229	6018	Economy	66400.00
0005435839224	6018	Economy	66400.00
0005435839243	6018	Economy	66400.00
0005435472511	6018	Economy	66400.00
0005432537022	6018	Economy	66400.00
0005432659691	6018	Economy	66400.00
0005432658577	6018	Economy	66400.00
0005435472558	6018	Economy	66400.00
0005435839238	6018	Economy	66400.00
0005435839234	6018	Economy	66400.00
0005432659690	6018	Economy	66400.00
0005435472512	6018	Economy	66400.00
0005435472538	6018	Economy	66400.00
0005435839218	6018	Economy	66400.00
0005432142228	6018	Economy	66400.00
0005435839221	6018	Economy	66400.00
0005435839240	6018	Economy	66400.00
0005435472539	6018	Economy	66400.00
0005435472572	6018	Economy	66400.00
0005432658576	6018	Economy	66400.00
0005435839231	6018	Economy	66400.00
0005435839244	6018	Economy	66400.00
0005435839239	6018	Economy	66400.00
0005432142227	6018	Economy	66400.00
0005435839237	6018	Economy	66400.00
0005435839232	6018	Economy	66400.00
0005435839245	6018	Economy	66400.00
0005435472670	18078	Business	199300.00
0005435838973	18078	Business	199300.00
0005435838987	18078	Business	199300.00
0005435838984	18078	Business	199300.00
0005435472665	18078	Business	199300.00
0005435839060	18078	Business	199300.00
0005435472676	18078	Business	199300.00
0005435839101	18078	Business	199300.00
0005435472679	18078	Business	199300.00
0005435838967	18078	Economy	66400.00
0005435838982	18078	Economy	66400.00
0005435472678	18078	Economy	73100.00
0005435838969	18078	Economy	73100.00
0005435839091	18078	Economy	66400.00
0005435472677	18078	Economy	66400.00
0005435472673	18078	Economy	66400.00
0005435472663	18078	Economy	66400.00
0005435472675	18078	Economy	66400.00
0005435472667	18078	Economy	66400.00
0005432537043	18078	Economy	66400.00
0005435839000	18078	Economy	66400.00
0005435839073	18078	Economy	66400.00
0005435472664	18078	Economy	66400.00
0005435839019	18078	Economy	66400.00
0005435472672	18078	Economy	66400.00
0005435472680	18078	Economy	66400.00
0005435839092	18078	Economy	66400.00
0005435472674	18078	Economy	66400.00
0005435472669	18078	Economy	66400.00
0005435472666	18078	Economy	66400.00
0005435838986	18078	Economy	66400.00
0005435838968	18078	Economy	66400.00
0005432537042	18078	Economy	66400.00
0005435839002	18078	Economy	66400.00
0005435472671	18078	Economy	66400.00
0005435472668	18078	Economy	66400.00
0005433462708	19909	Economy	48800.00
0005435103865	23029	Business	15700.00
0005433284873	23029	Business	15700.00
0005433284773	23029	Economy	5200.00
0005433284828	23029	Economy	5200.00
0005433284840	23029	Economy	5200.00
0005433284795	23029	Economy	5200.00
0005433284796	23029	Economy	5200.00
0005433284845	23029	Economy	5200.00
0005435103864	23029	Economy	5200.00
0005435103862	23029	Economy	5200.00
0005433284891	23029	Economy	5200.00
0005435103866	23029	Economy	5700.00
0005433284818	23029	Economy	5700.00
0005433284842	23029	Economy	5200.00
0005433284815	23029	Economy	5200.00
0005433284876	23029	Economy	5200.00
0005433284787	23029	Economy	5200.00
0005433284825	23029	Economy	5200.00
0005433284841	23029	Economy	5200.00
0005433284872	23029	Economy	5200.00
0005433284819	23029	Economy	5200.00
0005433284890	23029	Economy	5200.00
0005433284786	23029	Economy	5200.00
0005433284798	23029	Economy	5200.00
0005435103863	23029	Economy	5200.00
0005433284892	23029	Economy	5200.00
0005433285061	32067	Business	15700.00
0005433285041	32067	Business	15700.00
0005433285046	32067	Business	15700.00
0005433285054	32067	Economy	5200.00
0005433285065	32067	Economy	5200.00
0005433285057	32067	Economy	5200.00
0005433285059	32067	Economy	5200.00
0005433285040	32067	Economy	5200.00
0005433285062	32067	Economy	5200.00
0005433285069	32067	Economy	5200.00
0005433285048	32067	Economy	5200.00
0005433285053	32067	Economy	5200.00
0005433285043	32067	Economy	5200.00
0005433285045	32067	Economy	5200.00
0005433285047	32067	Economy	5700.00
0005433285056	32067	Economy	5700.00
0005433285044	32067	Economy	5200.00
0005433285050	32067	Economy	5200.00
0005433285055	32067	Economy	5200.00
0005433285064	32067	Economy	5200.00
0005433285068	32067	Economy	5200.00
0005433285039	32067	Economy	5200.00
0005433285051	32067	Economy	5200.00
0005433285067	32067	Economy	5200.00
0005433285070	32067	Economy	5200.00
0005433285042	32067	Economy	5200.00
0005433285058	32067	Economy	5200.00
0005433285063	32067	Economy	5200.00
0005433285052	32067	Economy	5200.00
0005433285066	32067	Economy	5200.00
0005433285049	32067	Economy	5200.00
0005433285060	32067	Economy	5200.00
0005433111476	19947	Business	150400.00
0005433112357	19947	Business	150400.00
0005432892742	19947	Business	150400.00
0005432892729	19947	Business	150400.00
0005433111481	19947	Business	150400.00
0005432892736	19947	Business	150400.00
0005433111485	19947	Economy	50100.00
0005432802429	19947	Economy	50100.00
0005432892726	19947	Economy	50100.00
0005432892731	19947	Economy	50100.00
0005432892735	19947	Economy	50100.00
0005433111479	19947	Economy	50100.00
0005432892727	19947	Economy	55200.00
0005432892739	19947	Economy	55200.00
0005433111483	19947	Economy	50100.00
0005432802435	19947	Economy	50100.00
0005433112359	19947	Economy	50100.00
0005433112360	19947	Economy	50100.00
0005432892738	19947	Economy	50100.00
0005432892741	19947	Economy	50100.00
0005433111484	19947	Economy	50100.00
0005433112356	19947	Economy	50100.00
0005432802430	19947	Economy	50100.00
0005432892734	19947	Economy	50100.00
0005432892730	19947	Economy	50100.00
0005433111482	19947	Economy	50100.00
0005433112358	19947	Economy	50100.00
0005433111474	19947	Economy	50100.00
0005432892732	19947	Economy	50100.00
0005433111472	19947	Economy	50100.00
0005433112353	19947	Economy	50100.00
0005432892737	19947	Economy	50100.00
0005433111480	19947	Economy	50100.00
0005433111487	19947	Economy	50100.00
0005432892728	19947	Economy	50100.00
0005433111477	19947	Economy	50100.00
0005433112351	19947	Economy	50100.00
0005433111473	19947	Economy	50100.00
0005432892740	19947	Economy	50100.00
0005432802431	19947	Economy	50100.00
0005433111486	19947	Economy	50100.00
0005432892743	19947	Economy	50100.00
0005433112354	19947	Economy	50100.00
0005433112361	19947	Economy	50100.00
0005433111478	19947	Economy	50100.00
0005432802432	19947	Economy	50100.00
0005432802433	19947	Economy	50100.00
0005432892733	19947	Economy	50100.00
0005433111488	19947	Economy	50100.00
0005433112355	19947	Economy	50100.00
0005433111475	19947	Economy	50100.00
0005433112352	19947	Economy	50100.00
0005435630945	30629	Business	42100.00
0005434066414	30629	Business	42100.00
0005432525953	30629	Business	42100.00
0005435213065	30629	Business	42100.00
0005432526168	30629	Business	42100.00
0005432526291	30629	Business	42100.00
0005435213035	30629	Business	42100.00
0005435213080	30629	Business	42100.00
0005435213074	30629	Business	42100.00
0005434066302	30629	Business	42100.00
0005435213043	30629	Business	42100.00
0005432525781	30629	Business	42100.00
0005432525712	30629	Comfort	23900.00
0005434066517	30629	Business	42100.00
0005432159822	30629	Comfort	23900.00
0005432525690	30629	Comfort	23900.00
0005432526582	30629	Comfort	23900.00
0005432525777	30629	Comfort	23900.00
0005432525794	30629	Comfort	23900.00
0005432526010	30629	Comfort	23900.00
0005434066420	30629	Comfort	23900.00
0005432525992	30629	Comfort	23900.00
0005435213036	30629	Comfort	23900.00
0005432525726	30629	Comfort	23900.00
0005432526143	30629	Comfort	23900.00
0005432525784	30629	Comfort	23900.00
0005435213023	30629	Comfort	23900.00
0005435213024	30629	Comfort	23900.00
0005432525657	30629	Comfort	23900.00
0005433656648	30629	Comfort	23900.00
0005435213083	30629	Comfort	23900.00
0005435213087	30629	Comfort	23900.00
0005432526241	30629	Comfort	23900.00
0005432526385	30629	Comfort	23900.00
0005432526230	30629	Comfort	23900.00
0005435213044	30629	Comfort	23900.00
0005435213079	30629	Comfort	23900.00
0005435213042	30629	Comfort	23900.00
0005434066425	30629	Comfort	23900.00
0005432525923	30629	Comfort	23900.00
0005432526433	30629	Economy	14000.00
0005434066507	30629	Economy	14000.00
0005432525691	30629	Economy	14000.00
0005434066343	30629	Economy	14000.00
0005432525855	30629	Economy	14000.00
0005434066436	30629	Economy	14000.00
0005432211448	30629	Economy	14000.00
0005434066357	30629	Economy	14000.00
0005432211442	30629	Economy	14000.00
0005434066435	30629	Economy	14000.00
0005432526195	30629	Economy	14000.00
0005435213086	30629	Economy	14000.00
0005432526058	30629	Economy	14000.00
0005432525692	30629	Economy	14000.00
0005435213025	30629	Economy	14000.00
0005432525861	30629	Economy	14000.00
0005432526038	30629	Economy	14000.00
0005435213068	30629	Economy	14000.00
0005432525660	30629	Economy	14000.00
0005432525719	30629	Economy	14000.00
0005432211445	30629	Economy	14000.00
0005435213051	30629	Economy	14000.00
0005432526057	30629	Economy	14000.00
0005435213062	30629	Economy	14000.00
0005432525959	30629	Economy	14000.00
0005434066399	30629	Economy	14000.00
0005435213090	30629	Economy	14000.00
0005435213076	30629	Economy	14000.00
0005432211449	30629	Economy	14000.00
0005432526411	30629	Economy	14000.00
0005432159823	30629	Economy	14000.00
0005434066419	30629	Economy	14000.00
0005432526128	30629	Economy	14000.00
0005432526384	30629	Economy	14000.00
0005433656645	30629	Economy	14000.00
0005432159821	30629	Economy	14000.00
0005433656647	30629	Economy	14000.00
0005432525720	30629	Economy	14000.00
0005435630946	30629	Economy	14000.00
0005434066622	30629	Economy	14000.00
0005432526467	30629	Economy	14000.00
0005432525928	30629	Economy	14000.00
0005435213039	30629	Economy	14000.00
0005435725564	30629	Economy	14000.00
0005435213085	30629	Economy	14000.00
0005432211444	30629	Economy	15400.00
0005434066728	30629	Economy	15400.00
0005435213053	30629	Economy	14000.00
0005434066391	30629	Economy	14000.00
0005432525927	30629	Economy	15400.00
0005434066443	30629	Economy	14000.00
0005432525738	30629	Economy	15400.00
0005432526190	30629	Economy	15400.00
0005432525954	30629	Economy	14000.00
0005435213082	30629	Economy	14000.00
0005434066429	30629	Economy	14000.00
0005435213049	30629	Economy	14000.00
0005432525955	30629	Economy	14000.00
0005432525746	30629	Economy	14000.00
0005434066571	30629	Economy	14000.00
0005432526081	30629	Economy	14000.00
0005434066465	30629	Economy	14000.00
0005434066423	30629	Economy	14000.00
0005435213026	30629	Economy	14000.00
0005435213059	30629	Economy	14000.00
0005435725565	30629	Economy	14000.00
0005435213058	30629	Economy	14000.00
0005435213060	30629	Economy	14000.00
0005432526104	30629	Economy	14000.00
0005432525924	30629	Economy	14000.00
0005435213028	30629	Economy	14000.00
0005432525685	30629	Economy	14000.00
0005434066621	30629	Economy	14000.00
0005434066408	30629	Economy	14000.00
0005435213046	30629	Economy	14000.00
0005432525662	30629	Economy	14000.00
0005433656646	30629	Economy	14000.00
0005432159825	30629	Economy	14000.00
0005432525641	30629	Economy	14000.00
0005434066509	30629	Economy	14000.00
0005434066605	30629	Economy	14000.00
0005432525828	30629	Economy	14000.00
0005434066301	30629	Economy	14000.00
0005434066358	30629	Economy	14000.00
0005432525745	30629	Economy	14000.00
0005435213081	30629	Economy	14000.00
0005432526036	30629	Economy	14000.00
0005435213040	30629	Economy	14000.00
0005432525661	30629	Economy	14000.00
0005434066418	30629	Economy	14000.00
0005432533250	30629	Economy	14000.00
0005435213037	30629	Economy	14000.00
0005432526232	30629	Economy	14000.00
0005432526060	30629	Economy	14000.00
0005432525929	30629	Economy	14000.00
0005435213041	30629	Economy	14000.00
0005432428879	30629	Economy	14000.00
0005432525727	30629	Economy	14000.00
0005435213031	30629	Economy	14000.00
0005432525648	30629	Economy	14000.00
0005432159824	30629	Economy	14000.00
0005435213066	30629	Economy	14000.00
0005435213027	30629	Economy	14000.00
0005432526025	30629	Economy	14000.00
0005432525684	30629	Economy	14000.00
0005432526037	30629	Economy	14000.00
0005435213047	30629	Economy	14000.00
0005432525782	30629	Economy	14000.00
0005435213064	30629	Economy	14000.00
0005435213045	30629	Economy	14000.00
0005435630944	30629	Economy	14000.00
0005432526142	30629	Economy	14000.00
0005432526024	30629	Economy	14000.00
0005432526179	30629	Economy	14000.00
0005434066363	30629	Economy	14000.00
0005432525877	30629	Economy	14000.00
0005435213033	30629	Economy	14000.00
0005435213073	30629	Economy	14000.00
0005432525883	30629	Economy	14000.00
0005435213063	30629	Economy	14000.00
0005432525728	30629	Economy	14000.00
0005432526171	30629	Economy	14000.00
0005432526059	30629	Economy	14000.00
0005435213055	30629	Economy	15400.00
0005432525709	30629	Economy	15400.00
0005432526215	30629	Economy	15400.00
0005434066508	30629	Economy	15400.00
0005435213057	30629	Economy	14000.00
0005432526294	30629	Economy	14000.00
0005435630947	30629	Economy	14000.00
0005434066417	30629	Economy	14000.00
0005435725562	30629	Economy	14000.00
0005432525758	30629	Economy	14000.00
0005432526251	30629	Economy	14000.00
0005435213067	30629	Economy	14000.00
0005434066444	30629	Economy	14000.00
0005435213069	30629	Economy	14000.00
0005432525946	30629	Economy	14000.00
0005432525902	30629	Economy	14000.00
0005435213048	30629	Economy	14000.00
0005432525796	30629	Economy	14000.00
0005435213070	30629	Economy	14000.00
0005432211443	30629	Economy	14000.00
0005432526008	30629	Economy	14000.00
0005432526141	30629	Economy	14000.00
0005435213089	30629	Economy	14000.00
0005432525729	30629	Economy	14000.00
0005432526239	30629	Economy	14000.00
0005435213022	30629	Economy	14000.00
0005435213075	30629	Economy	14000.00
0005432525930	30629	Economy	14000.00
0005434066415	30629	Economy	14000.00
0005435725563	30629	Economy	14000.00
0005432533254	30629	Economy	14000.00
0005432526432	30629	Economy	14000.00
0005435213034	30629	Economy	14000.00
0005435213088	30629	Economy	14000.00
0005434066469	30629	Economy	14000.00
0005432526196	30629	Economy	14000.00
0005435213061	30629	Economy	14000.00
0005432211446	30629	Economy	14000.00
0005432526129	30629	Economy	14000.00
0005432525994	30629	Economy	14000.00
0005432526434	30629	Economy	14000.00
0005434066447	30629	Economy	14000.00
0005435213056	30629	Economy	14000.00
0005432526016	30629	Economy	14000.00
0005435213084	30629	Economy	14000.00
0005432526394	30629	Economy	14000.00
0005432526238	30629	Economy	14000.00
0005432526007	30629	Economy	14000.00
0005432526240	30629	Economy	14000.00
0005435213054	30629	Economy	14000.00
0005435213077	30629	Economy	14000.00
0005432526538	30629	Economy	14000.00
0005432525903	30629	Economy	14000.00
0005432526229	30629	Economy	14000.00
0005435213050	30629	Economy	14000.00
0005434066506	30629	Economy	14000.00
0005432525867	30629	Economy	14000.00
0005435213038	30629	Economy	14000.00
0005435213032	30629	Economy	14000.00
0005432525901	30629	Economy	14000.00
0005435213071	30629	Economy	14000.00
0005432525774	30629	Economy	14000.00
0005435213052	30629	Economy	14000.00
0005434066729	30629	Economy	14000.00
0005435725566	30629	Economy	14000.00
0005435213021	30629	Economy	14000.00
0005432526395	30629	Economy	14000.00
0005432525952	30629	Economy	14000.00
0005435213029	30629	Economy	14000.00
0005432525778	30629	Economy	14000.00
0005432525693	30629	Economy	14000.00
0005432211447	30629	Economy	14000.00
0005435213072	30629	Economy	14000.00
0005435213030	30629	Economy	14000.00
0005432525658	30629	Economy	14000.00
0005434066310	30629	Economy	14000.00
0005432525834	30629	Economy	14000.00
0005432526147	30629	Economy	14000.00
0005432526130	30629	Economy	14000.00
0005435213078	30629	Economy	14000.00
0005433367640	24827	Business	9800.00
0005433367620	24827	Business	9800.00
0005433367622	24827	Business	9800.00
0005433367611	24827	Business	9800.00
0005435652336	24827	Business	9800.00
0005435652334	24827	Business	9800.00
0005435652267	24827	Business	9800.00
0005435652270	24827	Business	9800.00
0005435652303	24827	Business	9800.00
0005435652251	24827	Business	9800.00
0005435652372	24827	Business	9800.00
0005435652346	24827	Economy	3300.00
0005433367621	24827	Economy	3300.00
0005435652283	24827	Economy	3300.00
0005433367635	24827	Economy	3300.00
0005433367619	24827	Economy	3300.00
0005433367630	24827	Economy	3300.00
0005433367633	24827	Economy	3300.00
0005433367627	24827	Economy	3600.00
0005435652369	24827	Economy	3600.00
0005435652352	24827	Economy	3600.00
0005433367602	24827	Economy	3600.00
0005433367634	24827	Economy	3300.00
0005433367636	24827	Economy	3300.00
0005433367604	24827	Economy	3300.00
0005433367632	24827	Economy	3300.00
0005433367617	24827	Economy	3300.00
0005433367614	24827	Economy	3300.00
0005435652269	24827	Economy	3300.00
0005433367639	24827	Economy	3300.00
0005435652252	24827	Economy	3300.00
0005435652250	24827	Economy	3300.00
0005435652268	24827	Economy	3300.00
0005433367610	24827	Economy	3300.00
0005433367631	24827	Economy	3300.00
0005435652277	24827	Economy	3300.00
0005435652284	24827	Economy	3300.00
0005433367609	24827	Economy	3300.00
0005433367618	24827	Economy	3300.00
0005433367613	24827	Economy	3300.00
0005435652313	24827	Economy	3300.00
0005435652302	24827	Economy	3300.00
0005435652351	24827	Economy	3300.00
0005435652322	24827	Economy	3300.00
0005433367605	24827	Economy	3300.00
0005435652282	24827	Economy	3300.00
0005435652377	24827	Economy	3300.00
0005435652253	24827	Economy	3300.00
0005433367624	24827	Economy	3300.00
0005433367637	24827	Economy	3300.00
0005435652358	24827	Economy	3300.00
0005435652297	24827	Economy	3300.00
0005435652298	24827	Economy	3300.00
0005435652350	24827	Economy	3300.00
0005433367607	24827	Economy	3300.00
0005433367623	24827	Economy	3300.00
0005433367603	24827	Economy	3300.00
0005433367606	24827	Economy	3300.00
0005433367628	24827	Economy	3300.00
0005435652276	24827	Economy	3300.00
0005433367629	24827	Economy	3300.00
0005435652378	24827	Economy	3300.00
0005433367615	24827	Economy	3300.00
0005433367638	24827	Economy	3300.00
0005435652261	24827	Economy	3300.00
0005435652347	24827	Economy	3300.00
0005433367612	24827	Economy	3300.00
0005433367626	24827	Economy	3300.00
0005433367616	24827	Economy	3300.00
0005433367625	24827	Economy	3300.00
0005433367608	24827	Economy	3300.00
0005435652335	24827	Economy	3300.00
0005435949764	6600	Economy	20600.00
0005435949754	6600	Economy	20600.00
0005435949758	6600	Economy	18700.00
0005435949753	6600	Economy	18700.00
0005435949759	6600	Economy	18700.00
0005435949757	6600	Economy	18700.00
0005435949755	6600	Economy	18700.00
0005435949763	6600	Economy	18700.00
0005435949756	6600	Economy	18700.00
0005435949752	6600	Economy	18700.00
0005435949762	6600	Economy	18700.00
0005435949760	6600	Economy	18700.00
0005435949761	6600	Economy	18700.00
0005434979591	2059	Economy	10500.00
0005434979565	2059	Economy	10500.00
0005434979567	2059	Economy	9500.00
0005434979568	2059	Economy	9500.00
0005434979586	2059	Economy	9500.00
0005434979569	2059	Economy	9500.00
0005434979571	2059	Economy	9500.00
0005434979587	2059	Economy	9500.00
0005434979566	2059	Economy	9500.00
0005434979562	2059	Economy	9500.00
0005434979573	2059	Economy	9500.00
0005434979582	2059	Economy	9500.00
0005434979580	2059	Economy	9500.00
0005434979590	2059	Economy	9500.00
0005435801674	2059	Economy	9500.00
0005434979570	2059	Economy	9500.00
0005434979574	2059	Economy	9500.00
0005435801673	2059	Economy	9500.00
0005434979564	2059	Economy	9500.00
0005434979584	2059	Economy	9500.00
0005434979578	2059	Economy	9500.00
0005434979589	2059	Economy	9500.00
0005434979561	2059	Economy	9500.00
0005434979572	2059	Economy	9500.00
0005434979575	2059	Economy	9500.00
0005434979560	2059	Economy	9500.00
0005434979583	2059	Economy	9500.00
0005434979576	2059	Economy	9500.00
0005435801672	2059	Economy	9500.00
0005435801675	2059	Economy	9500.00
0005434979581	2059	Economy	9500.00
0005434979577	2059	Economy	9500.00
0005434979588	2059	Economy	9500.00
0005434979579	2059	Economy	9500.00
0005434979585	2059	Economy	9500.00
0005434979563	2059	Economy	9500.00
0005434979321	23569	Economy	10500.00
0005435801644	23569	Economy	9500.00
0005434979265	23569	Economy	9500.00
0005434979280	23569	Economy	9500.00
0005434979282	23569	Economy	9500.00
0005434979295	23569	Economy	9500.00
0005434979341	23569	Economy	9500.00
0005434979322	23569	Economy	9500.00
0005435801652	23569	Economy	9500.00
0005434979302	23569	Economy	9500.00
0005434979320	23569	Economy	9500.00
0005434979278	23569	Economy	9500.00
0005434979367	23569	Economy	9500.00
0005434979338	23569	Economy	9500.00
0005434979252	23569	Economy	9500.00
0005434952503	2658	Economy	5300.00
0005434952504	2658	Economy	5300.00
0005434952505	2658	Economy	5300.00
0005434952502	2658	Economy	5300.00
0005433256392	2648	Economy	5300.00
0005434952467	28257	Economy	5300.00
0005434952477	28257	Economy	5300.00
0005433256406	28257	Economy	5300.00
0005434952465	28257	Economy	5300.00
0005434952464	28257	Economy	5300.00
0005434952482	28257	Economy	5300.00
0005434952481	28257	Economy	5300.00
0005433256407	28257	Economy	5300.00
0005433256405	28257	Economy	5300.00
0005434952483	28257	Economy	5300.00
0005434952466	28257	Economy	5300.00
0005433111490	19796	Economy	8700.00
0005433111491	19796	Economy	8700.00
0005434136811	11946	Business	9700.00
0005434136917	11946	Business	9700.00
0005434136805	11946	Business	9700.00
0005434136914	11946	Business	9700.00
0005434137008	11946	Business	9700.00
0005434136887	11946	Business	9700.00
0005434136842	11946	Business	9700.00
0005434137056	11946	Business	9700.00
0005434136959	11946	Business	9700.00
0005434136975	11946	Business	9700.00
0005434136729	11946	Business	9700.00
0005434136913	11946	Economy	3200.00
0005434136776	11946	Economy	3200.00
0005434136992	11946	Economy	3200.00
0005434136817	11946	Economy	3200.00
0005434136846	11946	Economy	3200.00
0005434136974	11946	Economy	3200.00
0005434136948	11946	Economy	3200.00
0005434136921	11946	Economy	3200.00
0005434136772	11946	Economy	3500.00
0005434137021	11946	Economy	3500.00
0005434136863	11946	Economy	3500.00
0005434136716	11946	Economy	3500.00
0005434136690	11946	Economy	3500.00
0005434136810	11946	Economy	3200.00
0005434136742	11946	Economy	3200.00
0005434137070	11946	Economy	3200.00
0005434136897	11946	Economy	3200.00
0005434137064	11946	Economy	3200.00
0005434136911	11946	Economy	3200.00
0005434136912	11946	Economy	3200.00
0005434136796	11946	Economy	3200.00
0005434136843	11946	Economy	3200.00
0005434136862	11946	Economy	3200.00
0005434137023	11946	Economy	3200.00
0005434136743	11946	Economy	3200.00
0005434136755	11946	Economy	3200.00
0005434136984	11946	Economy	3200.00
0005434136918	11946	Economy	3200.00
0005434136730	11946	Economy	3200.00
0005434136762	11946	Economy	3200.00
0005434136720	11946	Economy	3200.00
0005434136804	11946	Economy	3200.00
0005434137045	11946	Economy	3200.00
0005434136881	11946	Economy	3200.00
0005434136965	11946	Economy	3200.00
0005434137034	11946	Economy	3200.00
0005434136993	11946	Economy	3200.00
0005434136888	11946	Economy	3200.00
0005434137097	11946	Economy	3200.00
0005434136861	11946	Economy	3200.00
0005434136909	11946	Economy	3200.00
0005434137002	11946	Economy	3200.00
0005434136750	11946	Economy	3200.00
0005434136922	11946	Economy	3200.00
0005434136715	11946	Economy	3200.00
0005434136949	11946	Economy	3200.00
0005434136960	11946	Economy	3200.00
0005434137061	11946	Economy	3200.00
0005434136751	11946	Economy	3200.00
0005434136910	11946	Economy	3200.00
0005434136983	11946	Economy	3200.00
0005434136966	11946	Economy	3200.00
0005434137096	11946	Economy	3200.00
0005434137101	11946	Economy	3200.00
0005434136886	11946	Economy	3200.00
0005434137069	11946	Economy	3200.00
0005434136908	11946	Economy	3200.00
0005434137046	11946	Economy	3200.00
0005434136809	11946	Economy	3200.00
0005434136864	11946	Economy	3200.00
0005434136808	11946	Economy	3200.00
0005434136877	11946	Economy	3200.00
0005434137035	11946	Economy	3200.00
0005434136894	11946	Economy	3200.00
0005434137060	11946	Economy	3200.00
0005434136728	11946	Economy	3200.00
0005434136857	11946	Economy	3200.00
0005434137457	28765	Business	9700.00
0005434137494	28765	Business	9700.00
0005434137518	28765	Business	9700.00
0005434137519	28765	Business	9700.00
0005434137523	28765	Business	9700.00
0005434137447	28765	Business	9700.00
0005434137461	28765	Business	9700.00
0005434137490	28765	Business	9700.00
0005434137504	28765	Business	9700.00
0005434137506	28765	Business	9700.00
0005434137448	28765	Economy	3200.00
0005434137477	28765	Economy	3200.00
0005434137508	28765	Economy	3200.00
0005434137525	28765	Economy	3200.00
0005434137524	28765	Economy	3200.00
0005434137510	28765	Economy	3200.00
0005434137459	28765	Economy	3200.00
0005434137527	28765	Economy	3200.00
0005434137500	28765	Economy	3200.00
0005434137532	28765	Economy	3200.00
0005434137465	28765	Economy	3500.00
0005434137496	28765	Economy	3500.00
0005434137488	28765	Economy	3500.00
0005434137522	28765	Economy	3200.00
0005434137531	28765	Economy	3200.00
0005434137516	28765	Economy	3200.00
0005434137480	28765	Economy	3200.00
0005434137450	28765	Economy	3200.00
0005434137528	28765	Economy	3200.00
0005434137456	28765	Economy	3200.00
0005434137530	28765	Economy	3200.00
0005434137464	28765	Economy	3200.00
0005434137446	28765	Economy	3200.00
0005434137536	28765	Economy	3200.00
0005434137520	28765	Economy	3200.00
0005434137475	28765	Economy	3200.00
0005434137505	28765	Economy	3200.00
0005434137481	28765	Economy	3200.00
0005434137455	28765	Economy	3200.00
0005434137482	28765	Economy	3200.00
0005434137470	28765	Economy	3200.00
0005434137460	28765	Economy	3200.00
0005434137452	28765	Economy	3200.00
0005434137493	28765	Economy	3200.00
0005434137484	28765	Economy	3200.00
0005434137453	28765	Economy	3200.00
0005434137513	28765	Economy	3200.00
0005434137463	28765	Economy	3200.00
0005434137476	28765	Economy	3200.00
0005434137485	28765	Economy	3200.00
0005434137474	28765	Economy	3200.00
0005434137534	28765	Economy	3200.00
0005434137514	28765	Economy	3200.00
0005434137473	28765	Economy	3200.00
0005434137468	28765	Economy	3200.00
0005434137499	28765	Economy	3200.00
0005434137471	28765	Economy	3200.00
0005434137535	28765	Economy	3200.00
0005434137489	28765	Economy	3200.00
0005434137509	28765	Economy	3200.00
0005434137458	28765	Economy	3200.00
0005434137497	28765	Economy	3200.00
0005434137492	28765	Economy	3200.00
0005434137503	28765	Economy	3200.00
0005434137487	28765	Economy	3200.00
0005434137469	28765	Economy	3200.00
0005434137511	28765	Economy	3200.00
0005434137507	28765	Economy	3200.00
0005434137533	28765	Economy	3200.00
0005434137512	28765	Economy	3200.00
0005434137486	28765	Economy	3200.00
0005434137515	28765	Economy	3200.00
0005434137521	28765	Economy	3200.00
0005434137502	28765	Economy	3200.00
0005434137498	28765	Economy	3200.00
0005434137526	28765	Economy	3200.00
0005434137529	28765	Economy	3200.00
0005434137479	28765	Economy	3200.00
0005434137501	28765	Economy	3200.00
0005434137454	28765	Economy	3200.00
0005434137495	28765	Economy	3200.00
0005434137451	28765	Economy	3200.00
0005434137491	28765	Economy	3200.00
0005434137483	28765	Economy	3200.00
0005434137537	28765	Economy	3200.00
0005434137478	28765	Economy	3200.00
0005434137472	28765	Economy	3200.00
0005434137462	28765	Economy	3200.00
0005434137517	28765	Economy	3200.00
0005434137449	28765	Economy	3200.00
0005434137466	28765	Economy	3200.00
0005434137467	28765	Economy	3200.00
0005433538806	6809	Economy	10900.00
0005435259697	6809	Economy	10900.00
0005435259682	6809	Economy	10900.00
0005433534482	6809	Economy	9900.00
0005433538805	6809	Economy	9900.00
0005433538807	6809	Economy	9900.00
0005433538809	6809	Economy	9900.00
0005433538810	6809	Economy	9900.00
0005433534483	6809	Economy	9900.00
0005433538808	6809	Economy	9900.00
0005433538804	6809	Economy	9900.00
0005433538811	6809	Economy	9900.00
0005433538812	6809	Economy	9900.00
0005435259727	25026	Economy	9900.00
0005435259724	25026	Economy	9900.00
0005435259726	25026	Economy	9900.00
0005435259725	25026	Economy	9900.00
0005433538749	25026	Economy	9900.00
0005433538750	25026	Economy	9900.00
0005433538787	25026	Economy	9900.00
0005433511893	816	Economy	16100.00
0005432922476	816	Economy	14600.00
0005433511888	816	Economy	14600.00
0005433511890	816	Economy	14600.00
0005433511895	816	Economy	14600.00
0005433511892	816	Economy	14600.00
0005433511887	816	Economy	14600.00
0005433511889	816	Economy	14600.00
0005433511896	816	Economy	14600.00
0005432922475	816	Economy	14600.00
0005433511894	816	Economy	14600.00
0005433511891	816	Economy	14600.00
0005433511847	16126	Economy	14600.00
0005432922496	16126	Economy	14600.00
0005432922494	16126	Economy	14600.00
0005432922497	16126	Economy	14600.00
0005433511845	16126	Economy	14600.00
0005432922495	16126	Economy	14600.00
0005433511841	16126	Economy	14600.00
0005433511857	16126	Economy	14600.00
0005433511848	16126	Economy	14600.00
0005433511858	16126	Economy	14600.00
0005433511823	16126	Economy	14600.00
0005435697131	3648	Economy	7900.00
0005435697148	3648	Economy	7900.00
0005434950497	3648	Economy	7900.00
0005435697136	3648	Economy	7900.00
0005435935008	3648	Economy	7200.00
0005434950496	3648	Economy	7200.00
0005435697137	3648	Economy	7200.00
0005435697143	3648	Economy	7200.00
0005435697149	3648	Economy	7200.00
0005435697145	3648	Economy	7200.00
0005435697151	3648	Economy	7200.00
0005435697158	3648	Economy	7200.00
0005435916128	3648	Economy	7200.00
0005435697142	3648	Economy	7200.00
0005435697132	3648	Economy	7200.00
0005435697144	3648	Economy	7200.00
0005435935009	3648	Economy	7200.00
0005435697154	3648	Economy	7200.00
0005435697157	3648	Economy	7200.00
0005435697139	3648	Economy	7200.00
0005435697152	3648	Economy	7200.00
0005435697147	3648	Economy	7200.00
0005435697134	3648	Economy	7200.00
0005435697156	3648	Economy	7200.00
0005435697140	3648	Economy	7200.00
0005434950499	3648	Economy	7200.00
0005435934999	3648	Economy	7200.00
0005435934992	3648	Economy	7200.00
0005435697146	3648	Economy	7200.00
0005435697133	3648	Economy	7200.00
0005435697150	3648	Economy	7200.00
0005435697153	3648	Economy	7200.00
0005434950495	3648	Economy	7200.00
0005435916127	3648	Economy	7200.00
0005435697155	3648	Economy	7200.00
0005435697138	3648	Economy	7200.00
0005435697141	3648	Economy	7200.00
0005435697135	3648	Economy	7200.00
0005434950498	3648	Economy	7200.00
0005435916137	3648	Economy	7200.00
0005435696922	16255	Economy	7900.00
0005435696895	16255	Economy	7900.00
0005435696916	16255	Economy	7200.00
0005435696949	16255	Economy	7200.00
0005435935018	16255	Economy	7200.00
0005435696948	16255	Economy	7200.00
0005435696975	16255	Economy	7200.00
0005435916147	16255	Economy	7200.00
0005435696962	16255	Economy	7200.00
0005435916146	16255	Economy	7200.00
0005435696844	16255	Economy	7200.00
0005435696915	16255	Economy	7200.00
0005435696906	16255	Economy	7200.00
0005435696908	16255	Economy	7200.00
0005435696869	16255	Economy	7200.00
0005435935019	16255	Economy	7200.00
0005435697008	16255	Economy	7200.00
0005435696851	16255	Economy	7200.00
0005435696907	16255	Economy	7200.00
0005435696852	16255	Economy	7200.00
0005435916148	16255	Economy	7200.00
0005435696941	16255	Economy	7200.00
0005435697007	16255	Economy	7200.00
0005435696843	16255	Economy	7200.00
0005434604872	3969	Economy	19300.00
0005434604874	3969	Economy	19300.00
0005434604873	3969	Economy	19300.00
0005434606802	3969	Economy	19300.00
0005432607535	3969	Economy	19300.00
0005432607536	3969	Economy	19300.00
0005433519424	3969	Economy	19300.00
0005433519426	3969	Economy	19300.00
0005433519425	3969	Economy	19300.00
0005432607537	3969	Economy	19300.00
0005432609703	3969	Economy	19300.00
0005432607538	3969	Economy	19300.00
0005435853587	3969	Economy	19300.00
0005432609702	3969	Economy	19300.00
0005434606804	3969	Economy	19300.00
0005433519427	3969	Economy	19300.00
0005434606805	3969	Economy	19300.00
0005434606803	3969	Economy	19300.00
0005433519423	3969	Economy	19300.00
0005434604871	3969	Economy	19300.00
0005435904892	22039	Economy	21300.00
0005433519377	22039	Economy	19300.00
0005435853598	22039	Economy	19300.00
0005433348895	685	Economy	3700.00
0005433348889	685	Economy	3700.00
0005433348908	685	Economy	3700.00
0005435628706	685	Economy	3700.00
0005435628705	685	Economy	3700.00
0005435628704	685	Economy	3700.00
0005433348899	685	Economy	3700.00
0005435628675	15953	Economy	3700.00
0005433348950	15953	Economy	3700.00
0005433348949	15953	Economy	3700.00
0005435628669	15953	Economy	3700.00
0005435628671	15953	Economy	3700.00
0005435628670	15953	Economy	3700.00
0005433348948	15953	Economy	3700.00
0005435628672	15953	Economy	3700.00
0005433348951	15953	Economy	3700.00
0005435628673	15953	Economy	3700.00
0005433348947	15953	Economy	3700.00
0005434445229	17170	Economy	7100.00
0005434446502	17170	Economy	7100.00
0005434446501	17170	Economy	7100.00
0005434446503	17170	Economy	7100.00
0005434445228	17170	Economy	7100.00
0005434445227	17170	Economy	7100.00
0005434445226	17170	Economy	7100.00
0005433159282	17170	Economy	7100.00
0005433159298	17621	Economy	7100.00
0005434445207	17621	Economy	7100.00
0005435132806	7905	Economy	5400.00
0005435383056	7905	Economy	5400.00
0005435132811	7905	Economy	5400.00
0005435132810	7905	Economy	5400.00
0005435383057	7905	Economy	5400.00
0005435132809	7905	Economy	5400.00
0005435132807	7905	Economy	5400.00
0005435132805	7905	Economy	5400.00
0005435383055	7905	Economy	5400.00
0005435132804	7905	Economy	5400.00
0005435132803	7905	Economy	5400.00
0005435132802	7905	Economy	5400.00
0005435383065	7905	Economy	5400.00
0005435132808	7905	Economy	5400.00
0005435383064	7905	Economy	5400.00
0005435132812	7905	Economy	5400.00
0005435383066	7905	Economy	5400.00
0005435383112	33065	Economy	5900.00
0005435132768	33065	Economy	5900.00
0005435132769	33065	Economy	5900.00
0005435383110	33065	Economy	5400.00
0005435132720	33065	Economy	5400.00
0005435132707	33065	Economy	5400.00
0005435383111	33065	Economy	5400.00
0005435132723	33065	Economy	5400.00
0005435132705	33065	Economy	5400.00
0005435132750	33065	Economy	5400.00
0005435132738	33065	Economy	5400.00
0005435132731	33065	Economy	5400.00
0005435383113	33065	Economy	5400.00
0005435132695	33065	Economy	5400.00
0005435132766	33065	Economy	5400.00
0005435132722	33065	Economy	5400.00
0005435132732	33065	Economy	5400.00
0005435132767	33065	Economy	5400.00
0005435132694	33065	Economy	5400.00
0005435132733	33065	Economy	5400.00
0005435132749	33065	Economy	5400.00
0005435132713	33065	Economy	5400.00
0005435132724	33065	Economy	5400.00
0005435383114	33065	Economy	5400.00
0005435132741	33065	Economy	5400.00
0005435160218	7520	Economy	13800.00
0005435160222	7520	Economy	13800.00
0005435390131	7520	Economy	12500.00
0005435160223	7520	Economy	12500.00
0005435160224	7520	Economy	12500.00
0005435160225	7520	Economy	12500.00
0005435160228	7520	Economy	12500.00
0005435160226	7520	Economy	12500.00
0005435160220	7520	Economy	12500.00
0005435160221	7520	Economy	12500.00
0005435160227	7520	Economy	12500.00
0005435160219	7520	Economy	12500.00
0005435390144	7520	Economy	12500.00
0005435160118	29567	Economy	13800.00
0005435160117	29567	Economy	13800.00
0005435160135	29567	Economy	12500.00
0005435390191	29567	Economy	12500.00
0005435390193	29567	Economy	12500.00
0005435390192	29567	Economy	12500.00
0005435390189	29567	Economy	12500.00
0005435390190	29567	Economy	12500.00
0005435160105	29567	Economy	12500.00
0005435390195	29567	Economy	12500.00
0005435160182	29567	Economy	12500.00
0005435390194	29567	Economy	12500.00
0005432398145	18441	Economy	4900.00
0005435178486	18441	Economy	4900.00
0005435178985	18441	Economy	4900.00
0005435178988	18441	Economy	4900.00
0005435178987	18441	Economy	4900.00
0005432398144	18441	Economy	4900.00
0005432398143	18441	Economy	4900.00
0005435178484	18441	Economy	4900.00
0005435178986	18441	Economy	4900.00
0005435178485	18441	Economy	4900.00
0005435178473	27169	Economy	4900.00
0005432398166	27169	Economy	4900.00
0005432398165	27169	Economy	4900.00
0005432400096	27169	Economy	4900.00
0005432398167	27169	Economy	4900.00
0005435178476	27169	Economy	4900.00
0005432661912	21841	Business	92200.00
0005432661909	21841	Business	92200.00
0005432664113	21841	Business	92200.00
0005432664114	21841	Business	92200.00
0005432661900	21841	Business	92200.00
0005432664126	21841	Business	92200.00
0005432663012	21841	Economy	30700.00
0005432663020	21841	Economy	30700.00
0005432664119	21841	Economy	30700.00
0005432663021	21841	Economy	30700.00
0005432663019	21841	Economy	33800.00
0005432663025	21841	Economy	30700.00
0005432664116	21841	Economy	33800.00
0005432661903	21841	Economy	30700.00
0005432664124	21841	Economy	30700.00
0005432664120	21841	Economy	30700.00
0005432664117	21841	Economy	30700.00
0005432663015	21841	Economy	30700.00
0005432661908	21841	Economy	30700.00
0005432664118	21841	Economy	30700.00
0005432661904	21841	Economy	30700.00
0005432664122	21841	Economy	30700.00
0005432663017	21841	Economy	30700.00
0005432661905	21841	Economy	30700.00
0005432663026	21841	Economy	30700.00
0005432664127	21841	Economy	30700.00
0005432664121	21841	Economy	30700.00
0005432661901	21841	Economy	30700.00
0005432661907	21841	Economy	30700.00
0005432663013	21841	Economy	30700.00
0005432661898	21841	Economy	30700.00
0005432663022	21841	Economy	30700.00
0005432661910	21841	Economy	30700.00
0005432663016	21841	Economy	30700.00
0005432661902	21841	Economy	30700.00
0005432663024	21841	Economy	30700.00
0005432661906	21841	Economy	30700.00
0005432661899	21841	Economy	30700.00
0005432664125	21841	Economy	30700.00
0005432663014	21841	Economy	30700.00
0005432663023	21841	Economy	30700.00
0005432661911	21841	Economy	30700.00
0005432664123	21841	Economy	30700.00
0005432663018	21841	Economy	30700.00
0005432664115	21841	Economy	30700.00
0005434503887	6514	Business	48400.00
0005434503883	6514	Business	48400.00
0005434503896	6514	Business	48400.00
0005434503891	6514	Business	48400.00
0005434503879	6514	Economy	16100.00
0005434503884	6514	Economy	16100.00
0005434503878	6514	Economy	16100.00
0005434503870	6514	Economy	16100.00
0005434503882	6514	Economy	16100.00
0005434503888	6514	Economy	16100.00
0005434503889	6514	Economy	17800.00
0005434503876	6514	Economy	17800.00
0005434503872	6514	Economy	16100.00
0005434503885	6514	Economy	16100.00
0005434503863	6514	Economy	16100.00
0005434503897	6514	Economy	16100.00
0005434503874	6514	Economy	16100.00
0005434503865	6514	Economy	16100.00
0005434503886	6514	Economy	16100.00
0005434503890	6514	Economy	16100.00
0005434503880	6514	Economy	16100.00
0005434503869	6514	Economy	16100.00
0005434503900	6514	Economy	16100.00
0005434503895	6514	Economy	16100.00
0005434503877	6514	Economy	16100.00
0005434503894	6514	Economy	16100.00
0005434503867	6514	Economy	16100.00
0005434503868	6514	Economy	16100.00
0005434503866	6514	Economy	16100.00
0005434503864	6514	Economy	16100.00
0005434503899	6514	Economy	16100.00
0005434503881	6514	Economy	16100.00
0005434503893	6514	Economy	16100.00
0005434503898	6514	Economy	16100.00
0005434503875	6514	Economy	16100.00
0005434503871	6514	Economy	16100.00
0005434503892	6514	Economy	16100.00
0005434503873	6514	Economy	16100.00
0005434503569	22650	Business	48400.00
0005434503568	22650	Business	48400.00
0005434503623	22650	Economy	16100.00
0005434503616	22650	Economy	16100.00
0005434503483	22650	Economy	17800.00
0005434503563	22650	Economy	16100.00
0005434503493	22650	Economy	16100.00
0005434503570	22650	Economy	16100.00
0005434503488	22650	Economy	16100.00
0005434503499	22650	Economy	16100.00
0005434503494	22650	Economy	16100.00
0005434503617	22650	Economy	16100.00
0005434503591	22650	Economy	16100.00
0005434503541	22650	Economy	16100.00
0005434503542	22650	Economy	16100.00
0005434503658	22650	Economy	16100.00
0005434503492	22650	Economy	16100.00
0005434503525	22650	Economy	16100.00
0005434503564	22650	Economy	16100.00
0005434503540	22650	Economy	16100.00
0005434503547	22650	Economy	16100.00
0005433367424	1672	Business	50000.00
0005435652771	1672	Business	50000.00
0005433367320	1672	Business	50000.00
0005435652769	1672	Business	50000.00
0005435652762	1672	Business	50000.00
0005435652768	1672	Business	50000.00
0005435652765	1672	Business	50000.00
0005433367221	1672	Business	50000.00
0005435652770	1672	Business	50000.00
0005435652777	1672	Business	50000.00
0005433367271	1672	Business	50000.00
0005435652784	1672	Economy	16700.00
0005435652763	1672	Economy	16700.00
0005435652733	1672	Economy	16700.00
0005435652745	1672	Economy	16700.00
0005433367246	1672	Economy	16700.00
0005435652783	1672	Economy	16700.00
0005435652752	1672	Economy	16700.00
0005435652779	1672	Economy	18300.00
0005435652761	1672	Economy	18300.00
0005435652732	1672	Economy	18300.00
0005435652753	1672	Economy	18300.00
0005435652742	1672	Economy	16700.00
0005435652744	1672	Economy	16700.00
0005433367314	1672	Economy	16700.00
0005433367321	1672	Economy	16700.00
0005435652766	1672	Economy	16700.00
0005435652755	1672	Economy	16700.00
0005435652780	1672	Economy	16700.00
0005435652735	1672	Economy	16700.00
0005435652739	1672	Economy	16700.00
0005435652764	1672	Economy	16700.00
0005435652746	1672	Economy	16700.00
0005435652748	1672	Economy	16700.00
0005435652756	1672	Economy	16700.00
0005435652737	1672	Economy	16700.00
0005433367252	1672	Economy	16700.00
0005435652754	1672	Economy	16700.00
0005435652738	1672	Economy	16700.00
0005433367293	1672	Economy	16700.00
0005433367310	1672	Economy	16700.00
0005435652759	1672	Economy	16700.00
0005435652782	1672	Economy	16700.00
0005435652749	1672	Economy	16700.00
0005433367350	1672	Economy	16700.00
0005435652751	1672	Economy	16700.00
0005435652747	1672	Economy	16700.00
0005435652775	1672	Economy	16700.00
0005435652731	1672	Economy	16700.00
0005433367423	1672	Economy	16700.00
0005433367389	1672	Economy	16700.00
0005433367319	1672	Economy	16700.00
0005433367292	1672	Economy	16700.00
0005433367315	1672	Economy	16700.00
0005435652772	1672	Economy	16700.00
0005433367294	1672	Economy	16700.00
0005433367456	1672	Economy	16700.00
0005435652750	1672	Economy	16700.00
0005435652767	1672	Economy	16700.00
0005435652781	1672	Economy	16700.00
0005435652740	1672	Economy	16700.00
0005435652743	1672	Economy	16700.00
0005433367324	1672	Economy	16700.00
0005435652773	1672	Economy	16700.00
0005435652776	1672	Economy	16700.00
0005435652758	1672	Economy	16700.00
0005435652785	1672	Economy	16700.00
0005433367255	1672	Economy	16700.00
0005435652778	1672	Economy	16700.00
0005435652760	1672	Economy	16700.00
0005435652734	1672	Economy	16700.00
0005435652757	1672	Economy	16700.00
0005433367434	1672	Economy	16700.00
0005435652774	1672	Economy	16700.00
0005433367254	1672	Economy	16700.00
0005433367322	1672	Economy	16700.00
0005435652741	1672	Economy	16700.00
0005435652736	1672	Economy	16700.00
0005435652347	21663	Business	50000.00
0005433367635	21663	Business	50000.00
0005435652369	21663	Business	50000.00
0005433367606	21663	Business	50000.00
0005435652322	21663	Business	50000.00
0005433367605	21663	Business	50000.00
0005433367621	21663	Business	50000.00
0005433367614	21663	Business	50000.00
0005433367609	21663	Business	50000.00
0005433367634	21663	Business	50000.00
0005433367611	21663	Business	50000.00
0005435652377	21663	Economy	16700.00
0005435652336	21663	Economy	16700.00
0005435652358	21663	Economy	16700.00
0005435652283	21663	Economy	16700.00
0005435652251	21663	Economy	16700.00
0005433367627	21663	Economy	16700.00
0005433367612	21663	Economy	16700.00
0005433367602	21663	Economy	16700.00
0005433367630	21663	Economy	16700.00
0005435652267	21663	Economy	18300.00
0005435652334	21663	Economy	18300.00
0005433367633	21663	Economy	18300.00
0005433367604	21663	Economy	18300.00
0005435652346	21663	Economy	16700.00
0005433367619	21663	Economy	16700.00
0005433367632	21663	Economy	16700.00
0005433367629	21663	Economy	16700.00
0005433367617	21663	Economy	16700.00
0005435652298	21663	Economy	16700.00
0005435652269	21663	Economy	16700.00
0005435652252	21663	Economy	16700.00
0005433367615	21663	Economy	16700.00
0005435652297	21663	Economy	16700.00
0005435652335	21663	Economy	16700.00
0005433367636	21663	Economy	16700.00
0005433367640	21663	Economy	16700.00
0005435652351	21663	Economy	16700.00
0005435652270	21663	Economy	16700.00
0005435652276	21663	Economy	16700.00
0005433367603	21663	Economy	16700.00
0005433367610	21663	Economy	16700.00
0005433367613	21663	Economy	16700.00
0005435652253	21663	Economy	16700.00
0005435652277	21663	Economy	16700.00
0005433367631	21663	Economy	16700.00
0005435652284	21663	Economy	16700.00
0005435652378	21663	Economy	16700.00
0005433367638	21663	Economy	16700.00
0005433367608	21663	Economy	16700.00
0005433367624	21663	Economy	16700.00
0005435652261	21663	Economy	16700.00
0005433367625	21663	Economy	16700.00
0005433367620	21663	Economy	16700.00
0005435652282	21663	Economy	16700.00
0005433367626	21663	Economy	16700.00
0005433367607	21663	Economy	16700.00
0005435652302	21663	Economy	16700.00
0005433367616	21663	Economy	16700.00
0005435652350	21663	Economy	16700.00
0005433367639	21663	Economy	16700.00
0005433367622	21663	Economy	16700.00
0005433367623	21663	Economy	16700.00
0005435652303	21663	Economy	16700.00
0005435652268	21663	Economy	16700.00
0005433367628	21663	Economy	16700.00
0005433367618	21663	Economy	16700.00
0005433367637	21663	Economy	16700.00
0005435652250	21663	Economy	16700.00
0005435652313	21663	Economy	16700.00
0005435652372	21663	Economy	16700.00
0005435652352	21663	Economy	16700.00
0005435627113	12250	Economy	11200.00
0005433985637	4191	Business	21500.00
0005433985628	4191	Business	21500.00
0005433985633	4191	Business	21500.00
0005433985634	4191	Business	21500.00
0005433985614	4191	Business	21500.00
0005433985615	4191	Economy	7200.00
0005433985606	4191	Economy	7200.00
0005433985622	4191	Economy	7200.00
0005433985642	4191	Economy	7900.00
0005433985639	4191	Economy	7900.00
0005433985620	4191	Economy	7900.00
0005433985636	4191	Economy	7200.00
0005433985612	4191	Economy	7200.00
0005433985632	4191	Economy	7200.00
0005433985623	4191	Economy	7200.00
0005433985644	4191	Economy	7200.00
0005433985635	4191	Economy	7200.00
0005433985629	4191	Economy	7200.00
0005433985616	4191	Economy	7200.00
0005433985640	4191	Economy	7200.00
0005433985647	4191	Economy	7200.00
0005433985643	4191	Economy	7200.00
0005433985618	4191	Economy	7200.00
0005433985610	4191	Economy	7200.00
0005433985646	4191	Economy	7200.00
0005433985619	4191	Economy	7200.00
0005433985611	4191	Economy	7200.00
0005433985631	4191	Economy	7200.00
0005435788753	4191	Economy	7200.00
0005433985621	4191	Economy	7200.00
0005433985641	4191	Economy	7200.00
0005433985627	4191	Economy	7200.00
0005433985645	4191	Economy	7200.00
0005433985625	4191	Economy	7200.00
0005433985607	4191	Economy	7200.00
0005433985608	4191	Economy	7200.00
0005433985630	4191	Economy	7200.00
0005433985624	4191	Economy	7200.00
0005435788752	4191	Economy	7200.00
0005433985613	4191	Economy	7200.00
0005433985609	4191	Economy	7200.00
0005433985626	4191	Economy	7200.00
0005433985617	4191	Economy	7200.00
0005433985638	4191	Economy	7200.00
0005433985292	25658	Business	21500.00
0005433985373	25658	Business	21500.00
0005435788731	25658	Business	21500.00
0005433985374	25658	Business	21500.00
0005433985344	25658	Economy	7200.00
0005433985160	25658	Economy	7200.00
0005433985406	25658	Economy	7200.00
0005435788733	25658	Economy	7200.00
0005433985271	25658	Economy	7900.00
0005433985135	25658	Economy	7900.00
0005433985233	25658	Economy	7900.00
0005433985199	25658	Economy	7900.00
0005433985221	25658	Economy	7200.00
0005433985201	25658	Economy	7200.00
0005433985197	25658	Economy	7200.00
0005435788732	25658	Economy	7200.00
0005433985215	25658	Economy	7200.00
0005433985127	25658	Economy	7200.00
0005433985165	25658	Economy	7200.00
0005435788738	25658	Economy	7200.00
0005433985163	25658	Economy	7200.00
0005433985220	25658	Economy	7200.00
0005433985138	25658	Economy	7200.00
0005433985143	25658	Economy	7200.00
0005433985273	25658	Economy	7200.00
0005433985140	25658	Economy	7200.00
0005433985144	25658	Economy	7200.00
0005433985303	25658	Economy	7200.00
0005433985243	25658	Economy	7200.00
0005433985141	25658	Economy	7200.00
0005433985142	25658	Economy	7200.00
0005433985274	25658	Economy	7200.00
0005433985147	25658	Economy	7200.00
0005433985272	25658	Economy	7200.00
0005433985162	25658	Economy	7200.00
0005433985216	25658	Economy	7200.00
0005433985157	25658	Economy	7200.00
0005433985278	25658	Economy	7200.00
0005433985148	25658	Economy	7200.00
0005433985202	25658	Economy	7200.00
0005433985198	25658	Economy	7200.00
0005433985200	25658	Economy	7200.00
0005433985293	25658	Economy	7200.00
0005433985170	25658	Economy	7200.00
0005433985164	25658	Economy	7200.00
0005433985139	25658	Economy	7200.00
0005433985304	25658	Economy	7200.00
0005433985285	25658	Economy	7200.00
0005435788734	25658	Economy	7200.00
0005435720804	21269	Economy	10400.00
0005435720803	21269	Economy	9400.00
0005435720809	21269	Economy	9400.00
0005435720810	21269	Economy	9400.00
0005435720807	21269	Economy	9400.00
0005435719552	21269	Economy	9400.00
0005435720802	21269	Economy	9400.00
0005435719560	24786	Economy	9400.00
0005435719559	24786	Economy	9400.00
0005435720127	24786	Economy	9400.00
0005434516065	9019	Economy	26000.00
0005434190368	9019	Economy	26000.00
0005434516059	9019	Economy	23600.00
0005434516058	9019	Economy	23600.00
0005434190372	9019	Economy	23600.00
0005434190374	9019	Economy	23600.00
0005434516064	9019	Economy	23600.00
0005434190367	9019	Economy	23600.00
0005434516066	9019	Economy	23600.00
0005434190375	9019	Economy	23600.00
0005434516062	9019	Economy	23600.00
0005434516063	9019	Economy	23600.00
0005434516061	9019	Economy	23600.00
0005434516060	9019	Economy	23600.00
0005432667419	17824	Business	18000.00
0005432657396	17824	Business	18000.00
0005432665243	17824	Business	18000.00
0005432655367	17824	Business	18000.00
0005432666364	17824	Business	18000.00
0005432655373	17824	Economy	6000.00
0005434151685	17824	Economy	6000.00
0005432657397	17824	Economy	6000.00
0005432869481	17824	Economy	6000.00
0005432665242	17824	Economy	6000.00
0005432658566	17824	Economy	6600.00
0005432655363	17824	Economy	6000.00
0005432660786	17824	Economy	6000.00
0005432657400	17824	Economy	6000.00
0005432666355	17824	Economy	6000.00
0005432869485	17824	Economy	6000.00
0005434151688	17824	Economy	6000.00
0005432665241	17824	Economy	6000.00
0005432660787	17824	Economy	6000.00
0005432655364	17824	Economy	6000.00
0005432655369	17824	Economy	6000.00
0005432655368	17824	Economy	6000.00
0005432655366	17824	Economy	6000.00
0005434151684	17824	Economy	6000.00
0005432666363	17824	Economy	6000.00
0005432869479	17824	Economy	6000.00
0005432655372	17824	Economy	6000.00
0005432658561	17824	Economy	6000.00
0005432869482	17824	Economy	6000.00
0005432658565	17824	Economy	6000.00
0005432869484	17824	Economy	6000.00
0005434151687	17824	Economy	6000.00
0005434151686	17824	Economy	6000.00
0005432869483	17824	Economy	6000.00
0005432869480	17824	Economy	6000.00
0005432666370	26280	Business	18000.00
0005432869430	26280	Business	18000.00
0005432657423	26280	Business	18000.00
0005432869421	26280	Economy	6000.00
0005432655423	26280	Economy	6000.00
0005432655433	26280	Economy	6000.00
0005432657421	26280	Economy	6600.00
0005432869424	26280	Economy	6000.00
0005432658574	26280	Economy	6000.00
0005432869425	26280	Economy	6000.00
0005432655429	26280	Economy	6000.00
0005432655424	26280	Economy	6000.00
0005432655425	26280	Economy	6000.00
0005432658573	26280	Economy	6000.00
0005432655427	26280	Economy	6000.00
0005432667438	26280	Economy	6000.00
0005432655434	26280	Economy	6000.00
0005432655435	26280	Economy	6000.00
0005432869427	26280	Economy	6000.00
0005432660801	26280	Economy	6000.00
0005432655430	26280	Economy	6000.00
0005432660800	26280	Economy	6000.00
0005432657424	26280	Economy	6000.00
0005432655432	26280	Economy	6000.00
0005432655426	26280	Economy	6000.00
0005432666371	26280	Economy	6000.00
0005432657425	26280	Economy	6000.00
0005432655431	26280	Economy	6000.00
0005432869412	26280	Economy	6000.00
0005432659689	26280	Economy	6000.00
0005432655428	26280	Economy	6000.00
0005432658575	26280	Economy	6000.00
0005434151656	26280	Economy	6000.00
0005432657422	26280	Economy	6000.00
0005432666372	26280	Economy	6000.00
0005432658572	26280	Economy	6000.00
0005432667437	26280	Economy	6000.00
0005432660799	26280	Economy	6000.00
0005432328385	3094	Business	16100.00
0005432328379	3094	Business	16100.00
0005432287152	3094	Business	16100.00
0005432328387	3094	Business	16100.00
0005432905024	3094	Business	16100.00
0005432328369	3094	Business	16100.00
0005432287154	3094	Business	16100.00
0005432287151	3094	Business	16100.00
0005433438836	3094	Business	16100.00
0005432328400	3094	Business	16100.00
0005432328367	3094	Economy	5400.00
0005432328391	3094	Economy	5400.00
0005432328372	3094	Economy	5400.00
0005432328386	3094	Economy	5400.00
0005432287157	3094	Economy	5900.00
0005432328378	3094	Economy	5900.00
0005432328403	3094	Economy	5900.00
0005432328366	3094	Economy	5900.00
0005432328377	3094	Economy	5400.00
0005432328395	3094	Economy	5400.00
0005432328368	3094	Economy	5400.00
0005432287156	3094	Economy	5400.00
0005432328365	3094	Economy	5400.00
0005432328361	3094	Economy	5400.00
0005432328390	3094	Economy	5400.00
0005433438833	3094	Economy	5400.00
0005432287153	3094	Economy	5400.00
0005432328402	3094	Economy	5400.00
0005432328360	3094	Economy	5400.00
0005432905062	3094	Economy	5400.00
0005432328394	3094	Economy	5400.00
0005432905025	3094	Economy	5400.00
0005432328380	3094	Economy	5400.00
0005432328375	3094	Economy	5400.00
0005432328373	3094	Economy	5400.00
0005432328374	3094	Economy	5400.00
0005432328381	3094	Economy	5400.00
0005433438834	3094	Economy	5400.00
0005433438832	3094	Economy	5400.00
0005432328405	3094	Economy	5400.00
0005432328388	3094	Economy	5400.00
0005432328404	3094	Economy	5400.00
0005432328364	3094	Economy	5400.00
0005432328376	3094	Economy	5400.00
0005432905061	3094	Economy	5400.00
0005432328371	3094	Economy	5400.00
0005432328401	3094	Economy	5400.00
0005432328362	3094	Economy	5400.00
0005432328398	3094	Economy	5400.00
0005432328370	3094	Economy	5400.00
0005432328389	3094	Economy	5400.00
0005432328397	3094	Economy	5400.00
0005432287155	3094	Economy	5400.00
0005432328383	3094	Economy	5400.00
0005433438831	3094	Economy	5400.00
0005433438837	3094	Economy	5400.00
0005433438835	3094	Economy	5400.00
0005432328392	3094	Economy	5400.00
0005432328382	3094	Economy	5400.00
0005432328393	3094	Economy	5400.00
0005432328406	3094	Economy	5400.00
0005432328363	3094	Economy	5400.00
0005432328399	3094	Economy	5400.00
0005432328396	3094	Economy	5400.00
0005432328384	3094	Economy	5400.00
0005432327973	31156	Business	16100.00
0005433438794	31156	Business	16100.00
0005432328053	31156	Business	16100.00
0005432327972	31156	Business	16100.00
0005432905088	31156	Economy	5400.00
0005432327970	31156	Economy	5400.00
0005432054283	31156	Economy	5400.00
0005432328051	31156	Economy	5400.00
0005432327911	31156	Economy	5400.00
0005433438801	31156	Economy	5400.00
0005433438800	31156	Economy	5900.00
0005432905084	31156	Economy	5900.00
0005432328055	31156	Economy	5400.00
0005432328024	31156	Economy	5400.00
0005432905086	31156	Economy	5400.00
0005432328072	31156	Economy	5400.00
0005432905089	31156	Economy	5400.00
0005432905087	31156	Economy	5400.00
0005433438790	31156	Economy	5400.00
0005432328011	31156	Economy	5400.00
0005432328013	31156	Economy	5400.00
0005433438789	31156	Economy	5400.00
0005432328025	31156	Economy	5400.00
0005432328110	31156	Economy	5400.00
0005432328066	31156	Economy	5400.00
0005432905090	31156	Economy	5400.00
0005432328061	31156	Economy	5400.00
0005432054284	31156	Economy	5400.00
0005432327925	31156	Economy	5400.00
0005432054282	31156	Economy	5400.00
0005432328056	31156	Economy	5400.00
0005433438791	31156	Economy	5400.00
0005432327898	31156	Economy	5400.00
0005433438769	31156	Economy	5400.00
0005432327896	31156	Economy	5400.00
0005432328026	31156	Economy	5400.00
0005432327968	31156	Economy	5400.00
0005432905083	31156	Economy	5400.00
0005432905085	31156	Economy	5400.00
0005432327934	31156	Economy	5400.00
0005432328014	31156	Economy	5400.00
0005432054285	31156	Economy	5400.00
0005432327969	31156	Economy	5400.00
0005432328054	31156	Economy	5400.00
0005432328060	31156	Economy	5400.00
0005432328057	31156	Economy	5400.00
0005432905082	31156	Economy	5400.00
0005432327935	31156	Economy	5400.00
0005432328134	31156	Economy	5400.00
0005433438795	31156	Economy	5400.00
0005435999140	6214	Business	124600.00
0005435999142	6214	Business	124600.00
0005435487493	6214	Business	124600.00
0005435999134	6214	Business	124600.00
0005434309644	6214	Business	124600.00
0005435487525	6214	Economy	41500.00
0005435296956	6214	Economy	41500.00
0005435999135	6214	Economy	41500.00
0005435999133	6214	Economy	41500.00
0005434309642	6214	Economy	41500.00
0005434309653	6214	Economy	41500.00
0005435999139	6214	Economy	41500.00
0005435487536	6214	Economy	41500.00
0005435296952	6214	Economy	41500.00
0005434309649	6214	Economy	41500.00
0005435487537	6214	Economy	41500.00
0005432146185	6214	Economy	41500.00
0005435999143	6214	Economy	41500.00
0005435487545	6214	Economy	41500.00
0005434309643	6214	Economy	41500.00
0005435487453	6214	Economy	41500.00
0005435999130	6214	Economy	41500.00
0005435487524	6214	Economy	41500.00
0005434309654	6214	Economy	41500.00
0005435487454	6214	Economy	41500.00
0005435487623	6214	Economy	45700.00
0005435999138	6214	Economy	41500.00
0005435296950	6214	Economy	41500.00
0005434309646	6214	Economy	41500.00
0005435487546	6214	Economy	41500.00
0005435999141	6214	Economy	41500.00
0005432146184	6214	Economy	41500.00
0005435999129	6214	Economy	41500.00
0005435487483	6214	Economy	41500.00
0005434309647	6214	Economy	41500.00
0005434309651	6214	Economy	41500.00
0005435296941	6214	Economy	41500.00
0005434309652	6214	Economy	41500.00
0005435487455	6214	Economy	41500.00
0005435296955	6214	Economy	41500.00
0005435999136	6214	Economy	41500.00
0005434309648	6214	Economy	41500.00
0005435999131	6214	Economy	41500.00
0005435296949	6214	Economy	41500.00
0005434309650	6214	Economy	41500.00
0005435487471	6214	Economy	41500.00
0005435487460	6214	Economy	41500.00
0005434309645	6214	Economy	41500.00
0005435999137	6214	Economy	41500.00
0005435487488	6214	Economy	41500.00
0005435487487	6214	Economy	41500.00
0005435487535	6214	Economy	41500.00
0005435999132	6214	Economy	41500.00
0005435487462	6214	Economy	41500.00
0005435297010	19561	Business	124600.00
0005435487662	19561	Business	124600.00
0005435297012	19561	Business	124600.00
0005434309503	19561	Economy	41500.00
0005434309574	19561	Economy	41500.00
0005435487669	19561	Economy	41500.00
0005435297014	19561	Economy	41500.00
0005435297008	19561	Economy	41500.00
0005434309535	19561	Economy	41500.00
0005434309502	19561	Economy	41500.00
0005435487668	19561	Economy	41500.00
0005435487653	19561	Economy	41500.00
0005435487657	19561	Economy	41500.00
0005435998957	19561	Economy	41500.00
0005434309543	19561	Economy	41500.00
0005435487665	19561	Economy	41500.00
0005435487661	19561	Economy	41500.00
0005435487655	19561	Economy	41500.00
0005435487670	19561	Economy	41500.00
0005435487654	19561	Economy	41500.00
0005435487667	19561	Economy	41500.00
0005435297016	19561	Economy	41500.00
0005435487673	19561	Economy	41500.00
0005435487658	19561	Economy	41500.00
0005434309553	19561	Economy	41500.00
0005435487666	19561	Economy	41500.00
0005434309584	19561	Economy	41500.00
0005435487659	19561	Economy	41500.00
0005435487671	19561	Economy	41500.00
0005435297015	19561	Economy	41500.00
0005435297011	19561	Economy	41500.00
0005435297013	19561	Economy	41500.00
0005435487674	19561	Economy	41500.00
0005435487675	19561	Economy	41500.00
0005434309506	19561	Economy	41500.00
0005435487664	19561	Economy	41500.00
0005435487672	19561	Economy	41500.00
0005435487660	19561	Economy	41500.00
0005435487663	19561	Economy	41500.00
0005435297009	19561	Economy	41500.00
0005435487656	19561	Economy	41500.00
0005435502155	1579	Business	86000.00
0005434565817	1579	Business	86000.00
0005433185989	1579	Business	86000.00
0005435502154	1579	Business	86000.00
0005435502157	1579	Business	86000.00
0005434565819	1579	Business	86000.00
0005434565826	1579	Business	86000.00
0005433185990	1579	Business	86000.00
0005435517783	1579	Business	86000.00
0005435502160	1579	Economy	28700.00
0005435502164	1579	Economy	28700.00
0005435502162	1579	Economy	28700.00
0005435517793	1579	Economy	28700.00
0005435502158	1579	Economy	28700.00
0005435508284	1579	Economy	28700.00
0005434565818	1579	Economy	28700.00
0005434565824	1579	Economy	28700.00
0005435502172	1579	Economy	28700.00
0005434565828	1579	Economy	28700.00
0005435502159	1579	Economy	31500.00
0005435508283	1579	Economy	31500.00
0005435502153	1579	Economy	31500.00
0005435517797	1579	Economy	31500.00
0005434565825	1579	Economy	31500.00
0005432291914	1579	Economy	28700.00
0005435517796	1579	Economy	28700.00
0005435508278	1579	Economy	28700.00
0005434565815	1579	Economy	28700.00
0005435517778	1579	Economy	28700.00
0005435508281	1579	Economy	28700.00
0005435502167	1579	Economy	28700.00
0005435517799	1579	Economy	28700.00
0005435517790	1579	Economy	28700.00
0005435502163	1579	Economy	28700.00
0005435517795	1579	Economy	28700.00
0005435517794	1579	Economy	28700.00
0005435508276	1579	Economy	28700.00
0005432291913	1579	Economy	28700.00
0005435502169	1579	Economy	28700.00
0005435502171	1579	Economy	28700.00
0005435517788	1579	Economy	28700.00
0005435517791	1579	Economy	28700.00
0005435517798	1579	Economy	28700.00
0005435517787	1579	Economy	28700.00
0005435502174	1579	Economy	28700.00
0005435508279	1579	Economy	28700.00
0005435508282	1579	Economy	28700.00
0005435502165	1579	Economy	28700.00
0005435502161	1579	Economy	28700.00
0005435502173	1579	Economy	28700.00
0005434565816	1579	Economy	28700.00
0005435517789	1579	Economy	28700.00
0005435508285	1579	Economy	28700.00
0005435508277	1579	Economy	28700.00
0005435502166	1579	Economy	28700.00
0005434565827	1579	Economy	28700.00
0005435517786	1579	Economy	28700.00
0005435502170	1579	Economy	28700.00
0005435502168	1579	Economy	28700.00
0005434565822	1579	Economy	28700.00
0005435517782	1579	Economy	28700.00
0005435508280	1579	Economy	28700.00
0005435517781	1579	Economy	28700.00
0005434565820	1579	Economy	28700.00
0005435517785	1579	Economy	28700.00
0005435517780	1579	Economy	28700.00
0005435517784	1579	Economy	28700.00
0005435517779	1579	Economy	28700.00
0005435502156	1579	Economy	28700.00
0005434565821	1579	Economy	28700.00
0005435517792	1579	Economy	28700.00
0005434565823	1579	Economy	28700.00
0005432291912	1579	Economy	28700.00
0005434565713	20900	Business	86000.00
0005435545618	20900	Business	86000.00
0005435528918	20900	Business	86000.00
0005434565683	20900	Business	86000.00
0005435528930	20900	Business	86000.00
0005434565761	20900	Business	86000.00
0005435528898	20900	Business	86000.00
0005433186061	20900	Business	86000.00
0005435501939	20900	Economy	28700.00
0005434565678	20900	Economy	28700.00
0005435528954	20900	Economy	28700.00
0005434565685	20900	Economy	28700.00
0005435502003	20900	Economy	28700.00
0005435502002	20900	Economy	31500.00
0005435528909	20900	Economy	31500.00
0005435502035	20900	Economy	31500.00
0005435528894	20900	Economy	28700.00
0005435528929	20900	Economy	28700.00
0005433186062	20900	Economy	28700.00
0005435501995	20900	Economy	28700.00
0005435528928	20900	Economy	28700.00
0005433186055	20900	Economy	28700.00
0005435501963	20900	Economy	28700.00
0005434565712	20900	Economy	28700.00
0005435502001	20900	Economy	28700.00
0005434565688	20900	Economy	28700.00
0005434565697	20900	Economy	28700.00
0005435501997	20900	Economy	28700.00
0005434565737	20900	Economy	28700.00
0005433186056	20900	Economy	28700.00
0005435501989	20900	Economy	28700.00
0005435528931	20900	Economy	28700.00
0005435528919	20900	Economy	28700.00
0005433186058	20900	Economy	28700.00
0005435501969	20900	Economy	28700.00
0005434565714	20900	Economy	28700.00
0005435501968	20900	Economy	28700.00
0005433186057	20900	Economy	28700.00
0005434565726	20900	Economy	28700.00
0005435501946	20900	Economy	28700.00
0005433186060	20900	Economy	28700.00
0005434565687	20900	Economy	28700.00
0005433186063	20900	Economy	28700.00
0005434565684	20900	Economy	28700.00
0005435501977	20900	Economy	28700.00
0005435501934	20900	Economy	28700.00
0005434565720	20900	Economy	28700.00
0005435545619	20900	Economy	28700.00
0005435501978	20900	Economy	28700.00
0005434565727	20900	Economy	28700.00
0005433186064	20900	Economy	28700.00
0005435528913	20900	Economy	28700.00
0005435502009	20900	Economy	28700.00
0005433186059	20900	Economy	28700.00
0005435502012	20900	Economy	28700.00
0005434565679	20900	Economy	28700.00
0005434565698	20900	Economy	28700.00
0005435501996	20900	Economy	28700.00
0005435501940	20900	Economy	28700.00
0005434565692	20900	Economy	28700.00
0005435153698	3877	Economy	21600.00
0005435153694	3877	Economy	19700.00
0005435153695	3877	Economy	19700.00
0005435153696	3877	Economy	19700.00
0005435153699	3877	Economy	19700.00
0005435153700	3877	Economy	19700.00
0005435153697	3877	Economy	19700.00
0005435153634	21858	Economy	21600.00
0005435931574	21858	Economy	19700.00
0005435931577	21858	Economy	19700.00
0005435153664	21858	Economy	19700.00
0005435931575	21858	Economy	19700.00
0005435153631	21858	Economy	19700.00
0005435931573	21858	Economy	19700.00
0005435931576	21858	Economy	19700.00
0005435153649	21858	Economy	19700.00
0005432628747	7176	Economy	14300.00
0005435225462	7176	Economy	14300.00
0005432628743	7176	Economy	14300.00
0005432628751	7176	Economy	13000.00
0005432628741	7176	Economy	13000.00
0005435225477	7176	Economy	13000.00
0005432628748	7176	Economy	13000.00
0005432628749	7176	Economy	13000.00
0005432628737	7176	Economy	13000.00
0005432628738	7176	Economy	13000.00
0005435225448	7176	Economy	13000.00
0005432628740	7176	Economy	13000.00
0005432628742	7176	Economy	13000.00
0005432628750	7176	Economy	13000.00
0005432628744	7176	Economy	13000.00
0005435225444	7176	Economy	13000.00
0005432628745	7176	Economy	13000.00
0005432628746	7176	Economy	13000.00
0005432628739	7176	Economy	13000.00
0005432628637	28150	Economy	14300.00
0005432628586	28150	Economy	13000.00
0005435225525	28150	Economy	13000.00
0005432628624	28150	Economy	13000.00
0005432628590	28150	Economy	13000.00
0005435225527	28150	Economy	13000.00
0005432628671	28150	Economy	13000.00
0005432628640	28150	Economy	13000.00
0005432628649	28150	Economy	13000.00
0005432628622	28150	Economy	13000.00
0005435225528	28150	Economy	13000.00
0005435225530	28150	Economy	13000.00
0005432628650	28150	Economy	13000.00
0005432628607	28150	Economy	13000.00
0005432628608	28150	Economy	13000.00
0005432628680	28150	Economy	13000.00
0005432628690	28150	Economy	13000.00
0005435225532	28150	Economy	13000.00
0005435225526	28150	Economy	13000.00
0005435225533	28150	Economy	13000.00
0005435225534	28150	Economy	13000.00
0005432628589	28150	Economy	13000.00
0005435225531	28150	Economy	13000.00
0005435225529	28150	Economy	13000.00
0005434267885	8767	Economy	11500.00
0005434267891	8767	Economy	11500.00
0005435960022	8767	Economy	10500.00
0005435960023	8767	Economy	10500.00
0005435960025	8767	Economy	10500.00
0005435960024	8767	Economy	10500.00
0005435960015	15251	Economy	10500.00
0005434267923	15251	Economy	10500.00
0005435960013	15251	Economy	10500.00
0005434267924	15251	Economy	10500.00
0005435960014	15251	Economy	10500.00
0005434267922	15251	Economy	10500.00
0005432675028	1170	Business	115000.00
0005432692815	1170	Business	115000.00
0005432873185	1170	Business	115000.00
0005432692834	1170	Business	115000.00
0005432675019	1170	Business	115000.00
0005432677542	1170	Business	115000.00
0005432692818	1170	Business	115000.00
0005432675032	1170	Business	115000.00
0005432675024	1170	Business	115000.00
0005432692822	1170	Business	115000.00
0005432692811	1170	Business	115000.00
0005432675022	1170	Business	115000.00
0005432873170	1170	Business	115000.00
0005432692827	1170	Economy	38300.00
0005432675018	1170	Economy	38300.00
0005432675029	1170	Economy	38300.00
0005432692820	1170	Economy	42200.00
0005432692838	1170	Economy	42200.00
0005432692832	1170	Economy	42200.00
0005432692829	1170	Economy	42200.00
0005432873190	1170	Economy	38300.00
0005432675026	1170	Economy	38300.00
0005432692814	1170	Economy	38300.00
0005432692813	1170	Economy	38300.00
0005432692816	1170	Economy	38300.00
0005432692821	1170	Economy	38300.00
0005432692823	1170	Economy	38300.00
0005432692826	1170	Economy	38300.00
0005432692837	1170	Economy	38300.00
0005432692831	1170	Economy	38300.00
0005432677543	1170	Economy	38300.00
0005432873167	1170	Economy	38300.00
0005432692839	1170	Economy	38300.00
0005432675027	1170	Economy	38300.00
0005432873168	1170	Economy	38300.00
0005432873169	1170	Economy	38300.00
0005432692840	1170	Economy	38300.00
0005432677540	1170	Economy	38300.00
0005432675020	1170	Economy	38300.00
0005432692830	1170	Economy	38300.00
0005432692825	1170	Economy	38300.00
0005432692812	1170	Economy	38300.00
0005432675021	1170	Economy	38300.00
0005432675025	1170	Economy	38300.00
0005432675030	1170	Economy	38300.00
0005432692836	1170	Economy	38300.00
0005432675023	1170	Economy	38300.00
0005432692828	1170	Economy	38300.00
0005432692841	1170	Economy	38300.00
0005432677541	1170	Economy	38300.00
0005432675017	1170	Economy	38300.00
0005432692824	1170	Economy	38300.00
0005432692819	1170	Economy	38300.00
0005432692817	1170	Economy	38300.00
0005432692835	1170	Economy	38300.00
0005432692833	1170	Economy	38300.00
0005432692842	1170	Economy	38300.00
0005432675031	1170	Economy	38300.00
0005432692597	17456	Business	115000.00
0005432692529	17456	Business	115000.00
0005432674873	17456	Business	115000.00
0005432873244	17456	Business	115000.00
0005432692546	17456	Business	115000.00
0005432873242	17456	Business	115000.00
0005432692538	17456	Economy	38300.00
0005432692539	17456	Economy	38300.00
0005432674955	17456	Economy	38300.00
0005432692615	17456	Economy	42200.00
0005432692634	17456	Economy	42200.00
0005432674867	17456	Economy	38300.00
0005432677514	17456	Economy	38300.00
0005432692591	17456	Economy	38300.00
0005432677507	17456	Economy	38300.00
0005432692556	17456	Economy	38300.00
0005432873245	17456	Economy	38300.00
0005432692699	17456	Economy	38300.00
0005432674894	17456	Economy	38300.00
0005432674891	17456	Economy	38300.00
0005432692596	17456	Economy	38300.00
0005432677521	17456	Economy	38300.00
0005432873239	17456	Economy	38300.00
0005432692595	17456	Economy	38300.00
0005432873238	17456	Economy	38300.00
0005432674874	17456	Economy	38300.00
0005432692700	17456	Economy	38300.00
0005432677522	17456	Economy	38300.00
0005432674865	17456	Economy	38300.00
0005432692560	17456	Economy	38300.00
0005432677513	17456	Economy	38300.00
0005432873243	17456	Economy	38300.00
0005432873241	17456	Economy	38300.00
0005432692545	17456	Economy	38300.00
0005432692533	17456	Economy	38300.00
0005432674898	17456	Economy	38300.00
0005432692544	17456	Economy	38300.00
0005432692530	17456	Economy	38300.00
0005432674931	17456	Economy	38300.00
0005432674866	17456	Economy	38300.00
0005432692604	17456	Economy	38300.00
0005432692559	17456	Economy	38300.00
0005432692618	17456	Economy	38300.00
0005432674954	17456	Economy	38300.00
0005432674892	17456	Economy	38300.00
0005432674922	17456	Economy	38300.00
0005432692594	17456	Economy	38300.00
0005432873240	17456	Economy	38300.00
0005432692564	17456	Economy	38300.00
0005434435077	1149	Economy	15200.00
0005433156626	1149	Economy	15200.00
0005433156639	1149	Economy	15200.00
0005434435070	1149	Economy	13900.00
0005434435078	1149	Economy	13900.00
0005434435069	1149	Economy	13900.00
0005434435072	1149	Economy	13900.00
0005433156640	1149	Economy	13900.00
0005434435076	1149	Economy	13900.00
0005434435068	1149	Economy	13900.00
0005434435073	1149	Economy	13900.00
0005434435066	1149	Economy	13900.00
0005434435081	1149	Economy	13900.00
0005434435080	1149	Economy	13900.00
0005433156641	1149	Economy	13900.00
0005433156617	1149	Economy	13900.00
0005434435071	1149	Economy	13900.00
0005434435074	1149	Economy	13900.00
0005434435079	1149	Economy	13900.00
0005434435067	1149	Economy	13900.00
0005434435075	1149	Economy	13900.00
0005433156692	17282	Economy	15200.00
0005433156688	17282	Economy	15200.00
0005434434939	17282	Economy	13900.00
0005434434919	17282	Economy	13900.00
0005433156687	17282	Economy	13900.00
0005433156686	17282	Economy	13900.00
0005433156691	17282	Economy	13900.00
0005434434940	17282	Economy	13900.00
0005434434980	17282	Economy	13900.00
0005434434981	17282	Economy	13900.00
0005434435009	17282	Economy	13900.00
0005433156685	17282	Economy	13900.00
0005433156689	17282	Economy	13900.00
0005433156690	17282	Economy	13900.00
0005435086780	4083	Economy	7500.00
0005435928069	4083	Economy	7500.00
0005435086778	4083	Economy	7500.00
0005435086781	4083	Economy	7500.00
0005435086783	4083	Economy	7500.00
0005435086782	4083	Economy	7500.00
0005435086779	4083	Economy	7500.00
0005435086784	4083	Economy	7500.00
0005435086733	24398	Economy	7500.00
0005435928108	24398	Economy	7500.00
0005435086719	24398	Economy	7500.00
0005435086708	24398	Economy	7500.00
0005435928110	24398	Economy	7500.00
0005435086738	24398	Economy	7500.00
0005435086707	24398	Economy	7500.00
0005435086734	24398	Economy	7500.00
0005435928107	24398	Economy	7500.00
0005435928109	24398	Economy	7500.00
0005435551508	11062	Economy	48100.00
0005435551509	11062	Economy	48100.00
0005435551504	11062	Economy	48100.00
0005435551491	11062	Economy	48100.00
0005435551507	11062	Economy	48100.00
0005435551502	11062	Economy	48100.00
0005435551527	11062	Economy	48100.00
0005435098521	11062	Economy	48100.00
0005435551526	11062	Economy	48100.00
0005435551503	11062	Economy	48100.00
0005435551493	11062	Economy	48100.00
0005435551510	11062	Economy	48100.00
0005435551552	17005	Business	144300.00
0005435098542	17005	Business	144300.00
0005435098540	17005	Economy	48100.00
0005435098539	17005	Economy	48100.00
0005435551544	17005	Economy	48100.00
0005435551554	17005	Economy	48100.00
0005435551537	17005	Economy	48100.00
0005435551551	17005	Economy	48100.00
0005435551538	17005	Economy	48100.00
0005435551543	17005	Economy	48100.00
0005435551549	17005	Economy	48100.00
0005435551542	17005	Economy	48100.00
0005435551546	17005	Economy	48100.00
0005435551547	17005	Economy	48100.00
0005435551553	17005	Economy	48100.00
0005435551550	17005	Economy	48100.00
0005435551541	17005	Economy	48100.00
0005435551540	17005	Economy	48100.00
0005435098538	17005	Economy	48100.00
0005435098541	17005	Economy	48100.00
0005435551545	17005	Economy	48100.00
0005435551539	17005	Economy	48100.00
0005435551548	17005	Economy	48100.00
0005435098543	17005	Economy	48100.00
0005435551555	17005	Economy	48100.00
0005433261495	18245	Business	203300.00
0005433261492	18245	Business	203300.00
0005433261493	18245	Business	203300.00
0005434963931	18245	Business	203300.00
0005434963927	18245	Business	203300.00
0005434963933	18245	Business	203300.00
0005434963899	18245	Business	203300.00
0005433261498	18245	Economy	67800.00
0005434964006	18245	Economy	74500.00
0005434963961	18245	Economy	67800.00
0005433261490	18245	Economy	67800.00
0005434963926	18245	Economy	67800.00
0005433261501	18245	Economy	67800.00
0005433261487	18245	Economy	67800.00
0005434963945	18245	Economy	67800.00
0005433261483	18245	Economy	67800.00
0005434963992	18245	Economy	67800.00
0005434963936	18245	Economy	67800.00
0005433261482	18245	Economy	67800.00
0005433261503	18245	Economy	67800.00
0005433261502	18245	Economy	67800.00
0005434963949	18245	Economy	67800.00
0005433261496	18245	Economy	67800.00
0005434963944	18245	Economy	67800.00
0005434963954	18245	Economy	67800.00
0005434963897	18245	Economy	67800.00
0005433261500	18245	Economy	67800.00
0005434963955	18245	Economy	67800.00
0005433261494	18245	Economy	67800.00
0005433261486	18245	Economy	67800.00
0005434963924	18245	Economy	67800.00
0005434963963	18245	Economy	74500.00
0005433261489	18245	Economy	67800.00
0005434964000	18245	Economy	67800.00
0005434963898	18245	Economy	67800.00
0005434963928	18245	Economy	67800.00
0005433261484	18245	Economy	67800.00
0005434963999	18245	Economy	67800.00
0005434963998	18245	Economy	67800.00
0005433261491	18245	Economy	67800.00
0005434963964	18245	Economy	67800.00
0005433261485	18245	Economy	67800.00
0005434963950	18245	Economy	67800.00
0005433261497	18245	Economy	67800.00
0005434963925	18245	Economy	67800.00
0005433261488	18245	Economy	67800.00
0005434963948	18245	Economy	67800.00
0005433261499	18245	Economy	67800.00
0005434625892	4848	Business	44200.00
0005434625896	4848	Economy	14700.00
0005433194819	4848	Economy	14700.00
0005434625897	4848	Economy	14700.00
0005433194825	4848	Economy	14700.00
0005435907430	4848	Economy	16200.00
0005434625898	4848	Economy	16200.00
0005435907424	4848	Economy	14700.00
0005434625893	4848	Economy	14700.00
0005434625901	4848	Economy	14700.00
0005434625891	4848	Economy	14700.00
0005435907429	4848	Economy	14700.00
0005433194820	4848	Economy	14700.00
0005434625899	4848	Economy	14700.00
0005435907425	4848	Economy	14700.00
0005434625894	4848	Economy	14700.00
0005433194818	4848	Economy	14700.00
0005434625895	4848	Economy	14700.00
0005434625900	4848	Economy	14700.00
0005433194840	32923	Business	44200.00
0005435907472	32923	Business	44200.00
0005433194837	32923	Business	44200.00
0005434625854	32923	Business	44200.00
0005433194838	32923	Business	44200.00
0005433194836	32923	Economy	14700.00
0005435907471	32923	Economy	14700.00
0005435907470	32923	Economy	14700.00
0005433194835	32923	Economy	14700.00
0005433194839	32923	Economy	14700.00
0005435907473	32923	Economy	14700.00
0005434625827	32923	Economy	14700.00
0005435907469	32923	Economy	14700.00
0005434625852	32923	Economy	14700.00
0005433194842	32923	Economy	14700.00
0005434625806	32923	Economy	14700.00
0005433194834	32923	Economy	14700.00
0005434625849	32923	Economy	14700.00
0005434625832	32923	Economy	14700.00
0005434625856	32923	Economy	14700.00
0005433194841	32923	Economy	14700.00
0005434625850	32923	Economy	14700.00
0005434625831	32923	Economy	14700.00
0005434625851	32923	Economy	14700.00
0005434625838	32923	Economy	14700.00
0005435784775	13768	Economy	3400.00
0005435784825	13768	Economy	3400.00
0005435937356	13768	Economy	3100.00
0005435784833	13768	Economy	3100.00
0005435784789	13768	Economy	3100.00
0005435937349	13768	Economy	3100.00
0005435784904	13768	Economy	3100.00
0005435784903	13768	Economy	3100.00
0005435784768	13768	Economy	3100.00
0005432195678	13768	Economy	3100.00
0005435784807	13768	Economy	3100.00
0005435784873	13768	Economy	3100.00
0005435784858	13768	Economy	3100.00
0005435937352	13768	Economy	3100.00
0005435784770	13768	Economy	3100.00
0005435784826	13768	Economy	3100.00
0005435784738	13768	Economy	3100.00
0005435937350	13768	Economy	3100.00
0005435784774	13768	Economy	3100.00
0005435784844	13768	Economy	3100.00
0005435784808	13768	Economy	3100.00
0005435937351	13768	Economy	3100.00
0005435784812	13768	Economy	3100.00
0005435937357	13768	Economy	3100.00
0005435784830	13768	Economy	3100.00
0005435784776	13768	Economy	3100.00
0005435784739	13768	Economy	3100.00
0005435784792	13768	Economy	3100.00
0005435784780	13768	Economy	3100.00
0005435784742	13768	Economy	3100.00
0005435784853	13768	Economy	3100.00
0005435937353	13768	Economy	3100.00
0005435937354	13768	Economy	3100.00
0005435784793	13768	Economy	3100.00
0005435937355	13768	Economy	3100.00
0005435784755	13768	Economy	3100.00
0005435785047	27448	Economy	3400.00
0005435785063	27448	Economy	3400.00
0005435785066	27448	Economy	3400.00
0005435787334	27448	Economy	3400.00
0005435785059	27448	Economy	3100.00
0005435785065	27448	Economy	3100.00
0005435787335	27448	Economy	3100.00
0005435785060	27448	Economy	3100.00
0005435785079	27448	Economy	3100.00
0005435937311	27448	Economy	3100.00
0005435785055	27448	Economy	3100.00
0005435785071	27448	Economy	3100.00
0005435785062	27448	Economy	3100.00
0005435785058	27448	Economy	3100.00
0005435785080	27448	Economy	3100.00
0005435787336	27448	Economy	3100.00
0005432190596	27448	Economy	3100.00
0005435785067	27448	Economy	3100.00
0005435785074	27448	Economy	3100.00
0005435785048	27448	Economy	3100.00
0005435785078	27448	Economy	3100.00
0005435785077	27448	Economy	3100.00
0005435785072	27448	Economy	3100.00
0005432190597	27448	Economy	3100.00
0005435937317	27448	Economy	3100.00
0005435785049	27448	Economy	3100.00
0005435785056	27448	Economy	3100.00
0005435785076	27448	Economy	3100.00
0005435937310	27448	Economy	3100.00
0005435785064	27448	Economy	3100.00
0005435785068	27448	Economy	3100.00
0005435785046	27448	Economy	3100.00
0005435785053	27448	Economy	3100.00
0005435785052	27448	Economy	3100.00
0005435785070	27448	Economy	3100.00
0005435785054	27448	Economy	3100.00
0005435785069	27448	Economy	3100.00
0005435785057	27448	Economy	3100.00
0005435785050	27448	Economy	3100.00
0005435785061	27448	Economy	3100.00
0005435787337	27448	Economy	3100.00
0005432190598	27448	Economy	3100.00
0005435785073	27448	Economy	3100.00
0005435785051	27448	Economy	3100.00
0005435785075	27448	Economy	3100.00
0005435937316	27448	Economy	3100.00
0005434406659	20277	Business	12000.00
0005434406698	20277	Business	12000.00
0005434406843	20277	Business	12000.00
0005434406893	20277	Business	12000.00
0005434406781	20277	Business	12000.00
0005434406658	20277	Business	12000.00
0005434406844	20277	Business	12000.00
0005434406684	20277	Economy	4000.00
0005435310987	20277	Economy	4000.00
0005434406689	20277	Economy	4000.00
0005435310979	20277	Economy	4000.00
0005434406702	20277	Economy	4000.00
0005435310983	20277	Economy	4000.00
0005435310990	20277	Economy	4000.00
0005434406774	20277	Economy	4000.00
0005434406936	20277	Economy	4000.00
0005434406880	20277	Economy	4400.00
0005432058356	20277	Economy	4400.00
0005435310988	20277	Economy	4400.00
0005434406882	20277	Economy	4400.00
0005432058353	20277	Economy	4000.00
0005434406901	20277	Economy	4000.00
0005434406718	20277	Economy	4000.00
0005434407033	20277	Economy	4000.00
0005434406676	20277	Economy	4000.00
0005435310980	20277	Economy	4000.00
0005435310991	20277	Economy	4000.00
0005434406657	20277	Economy	4000.00
0005434406977	20277	Economy	4000.00
0005434406894	20277	Economy	4000.00
0005434406725	20277	Economy	4000.00
0005434406842	20277	Economy	4000.00
0005434406699	20277	Economy	4000.00
0005435310978	20277	Economy	4000.00
0005435310992	20277	Economy	4000.00
0005434406881	20277	Economy	4000.00
0005434407048	20277	Economy	4000.00
0005434406752	20277	Economy	4000.00
0005432058352	20277	Economy	4000.00
0005434406967	20277	Economy	4000.00
0005435310994	20277	Economy	4000.00
0005434406738	20277	Economy	4000.00
0005435310985	20277	Economy	4000.00
0005434406760	20277	Economy	4000.00
0005434406754	20277	Economy	4000.00
0005434406895	20277	Economy	4000.00
0005434406943	20277	Economy	4000.00
0005434406845	20277	Economy	4000.00
0005434406671	20277	Economy	4000.00
0005434406739	20277	Economy	4000.00
0005434406648	20277	Economy	4000.00
0005435310995	20277	Economy	4000.00
0005434407087	20277	Economy	4000.00
0005435310981	20277	Economy	4000.00
0005434406697	20277	Economy	4000.00
0005434406672	20277	Economy	4000.00
0005434406780	20277	Economy	4000.00
0005434406688	20277	Economy	4000.00
0005435310989	20277	Economy	4000.00
0005434406753	20277	Economy	4000.00
0005435310982	20277	Economy	4000.00
0005435310986	20277	Economy	4000.00
0005434406812	20277	Economy	4000.00
0005434406731	20277	Economy	4000.00
0005432058354	20277	Economy	4000.00
0005435310993	20277	Economy	4000.00
0005434406811	20277	Economy	4000.00
0005434406678	20277	Economy	4000.00
0005434406641	20277	Economy	4000.00
0005434406703	20277	Economy	4000.00
0005435310984	20277	Economy	4000.00
0005434406978	20277	Economy	4000.00
0005434406677	20277	Economy	4000.00
0005432058355	20277	Economy	4000.00
0005434406807	20277	Economy	4000.00
0005434406814	20277	Economy	4000.00
0005434407341	26975	Business	12000.00
0005434407302	26975	Business	12000.00
0005434407316	26975	Business	12000.00
0005434407293	26975	Business	12000.00
0005434407323	26975	Business	12000.00
0005434407343	26975	Business	12000.00
0005434407315	26975	Business	12000.00
0005434407325	26975	Business	12000.00
0005434407298	26975	Economy	4000.00
0005434407317	26975	Economy	4000.00
0005434407344	26975	Economy	4000.00
0005434407310	26975	Economy	4000.00
0005434407337	26975	Economy	4000.00
0005434407303	26975	Economy	4000.00
0005434407300	26975	Economy	4400.00
0005434407340	26975	Economy	4400.00
0005432153890	26975	Economy	4400.00
0005434407296	26975	Economy	4400.00
0005434407299	26975	Economy	4400.00
0005434407333	26975	Economy	4000.00
0005434407328	26975	Economy	4000.00
0005434407335	26975	Economy	4000.00
0005432153891	26975	Economy	4000.00
0005434407331	26975	Economy	4000.00
0005432153888	26975	Economy	4000.00
0005434407287	26975	Economy	4000.00
0005434407284	26975	Economy	4000.00
0005434407311	26975	Economy	4000.00
0005434407282	26975	Economy	4000.00
0005434407286	26975	Economy	4000.00
0005434407306	26975	Economy	4000.00
0005432153885	26975	Economy	4000.00
0005432153889	26975	Economy	4000.00
0005434407312	26975	Economy	4000.00
0005434407336	26975	Economy	4000.00
0005434407345	26975	Economy	4000.00
0005434407327	26975	Economy	4000.00
0005434407329	26975	Economy	4000.00
0005434407313	26975	Economy	4000.00
0005434407309	26975	Economy	4000.00
0005434407330	26975	Economy	4000.00
0005434407295	26975	Economy	4000.00
0005434407324	26975	Economy	4000.00
0005434407346	26975	Economy	4000.00
0005434407326	26975	Economy	4000.00
0005434407314	26975	Economy	4000.00
0005434407288	26975	Economy	4000.00
0005434407291	26975	Economy	4000.00
0005434407294	26975	Economy	4000.00
0005434407301	26975	Economy	4000.00
0005434407283	26975	Economy	4000.00
0005434407307	26975	Economy	4000.00
0005434407308	26975	Economy	4000.00
0005434407297	26975	Economy	4000.00
0005434407339	26975	Economy	4000.00
0005434407320	26975	Economy	4000.00
0005434407334	26975	Economy	4000.00
0005434407305	26975	Economy	4000.00
0005432153886	26975	Economy	4000.00
0005432153887	26975	Economy	4000.00
0005434407318	26975	Economy	4000.00
0005434407290	26975	Economy	4000.00
0005434407321	26975	Economy	4000.00
0005434407304	26975	Economy	4000.00
0005434407292	26975	Economy	4000.00
0005434407285	26975	Economy	4000.00
0005434407332	26975	Economy	4000.00
0005434407319	26975	Economy	4000.00
0005434407289	26975	Economy	4000.00
0005434407338	26975	Economy	4000.00
0005434407342	26975	Economy	4000.00
0005434407322	26975	Economy	4000.00
0005434311205	5692	Business	43300.00
0005434319291	5692	Business	43300.00
0005434311204	5692	Business	43300.00
0005433123595	5692	Business	43300.00
0005433123644	5692	Business	43300.00
0005433123600	5692	Economy	14400.00
0005433123606	5692	Economy	15900.00
0005433123594	5692	Economy	15900.00
0005433123622	5692	Economy	15900.00
0005433123565	5692	Economy	14400.00
0005433123614	5692	Economy	14400.00
0005433123607	5692	Economy	14400.00
0005433123649	5692	Economy	14400.00
0005433123599	5692	Economy	14400.00
0005434319290	5692	Economy	14400.00
0005434319287	5692	Economy	14400.00
0005432109683	5692	Economy	14400.00
0005433123598	5692	Economy	14400.00
0005432109684	5692	Economy	14400.00
0005433123608	5692	Economy	14400.00
0005433123643	5692	Economy	14400.00
0005433123617	5692	Economy	14400.00
0005433123648	5692	Economy	14400.00
0005433123570	5692	Economy	14400.00
0005433123592	5692	Economy	14400.00
0005434319288	5692	Economy	14400.00
0005434319289	5692	Economy	14400.00
0005434319292	5692	Economy	14400.00
0005434319293	5692	Economy	14400.00
0005434319294	5692	Economy	14400.00
0005433123597	5692	Economy	14400.00
0005433123647	5692	Economy	14400.00
0005434319197	15652	Business	43300.00
0005433123794	15652	Business	43300.00
0005434319204	15652	Business	43300.00
0005433123793	15652	Business	43300.00
0005434311192	15652	Business	43300.00
0005433123786	15652	Business	43300.00
0005433123781	15652	Economy	14400.00
0005434319157	15652	Economy	14400.00
0005434311193	15652	Economy	14400.00
0005434311197	15652	Economy	14400.00
0005434319182	15652	Economy	14400.00
0005434319143	15652	Economy	14400.00
0005433123798	15652	Economy	15900.00
0005434319146	15652	Economy	15900.00
0005434319150	15652	Economy	14400.00
0005434319202	15652	Economy	14400.00
0005433123788	15652	Economy	14400.00
0005433123803	15652	Economy	14400.00
0005433123790	15652	Economy	14400.00
0005434311200	15652	Economy	14400.00
0005434319144	15652	Economy	14400.00
0005434311199	15652	Economy	14400.00
0005433123797	15652	Economy	14400.00
0005433123787	15652	Economy	14400.00
0005433123800	15652	Economy	14400.00
0005433123792	15652	Economy	14400.00
0005433123802	15652	Economy	14400.00
0005433123796	15652	Economy	14400.00
0005433123785	15652	Economy	14400.00
0005434319195	15652	Economy	14400.00
0005433123782	15652	Economy	14400.00
0005433123789	15652	Economy	14400.00
0005434311198	15652	Economy	14400.00
0005434319184	15652	Economy	14400.00
0005434319163	15652	Economy	14400.00
0005433123784	15652	Economy	14400.00
0005433123791	15652	Economy	14400.00
0005434319183	15652	Economy	14400.00
0005434319196	15652	Economy	14400.00
0005434319198	15652	Economy	14400.00
0005434319203	15652	Economy	14400.00
0005433123799	15652	Economy	14400.00
0005433123783	15652	Economy	14400.00
0005433123801	15652	Economy	14400.00
0005434319165	15652	Economy	14400.00
0005434319147	15652	Economy	14400.00
0005433123795	15652	Economy	14400.00
0005434319194	15652	Economy	14400.00
0005435221499	24986	Economy	17100.00
0005435217676	24986	Economy	15500.00
0005435217682	24986	Economy	15500.00
0005435221500	24986	Economy	15500.00
0005435221498	24986	Economy	15500.00
0005434189081	8958	Economy	24900.00
0005434189115	8958	Economy	24900.00
0005434484306	8958	Economy	24900.00
0005434189097	8958	Economy	24900.00
0005434189098	8958	Economy	24900.00
0005434484299	8958	Economy	24900.00
0005434484298	8958	Economy	24900.00
0005434189114	8958	Economy	24900.00
0005434484303	8958	Economy	24900.00
0005434189116	8958	Economy	24900.00
0005434484301	8958	Economy	24900.00
0005434484304	8958	Economy	24900.00
0005434484305	8958	Economy	24900.00
0005434484302	8958	Economy	24900.00
0005434484300	8958	Economy	24900.00
0005434484256	16628	Economy	27400.00
0005434484233	16628	Economy	27400.00
0005434484259	16628	Economy	24900.00
0005434484244	16628	Economy	24900.00
0005434189137	16628	Economy	24900.00
0005434484249	16628	Economy	24900.00
0005434189140	16628	Economy	24900.00
0005434189136	16628	Economy	24900.00
0005434484257	16628	Economy	24900.00
0005434189139	16628	Economy	24900.00
0005434189135	16628	Economy	24900.00
0005434484252	16628	Economy	24900.00
0005434484243	16628	Economy	24900.00
0005434484246	16628	Economy	24900.00
0005434189138	16628	Economy	24900.00
0005434484245	16628	Economy	24900.00
0005434484255	16628	Economy	24900.00
0005433722115	7613	Business	11100.00
0005433123793	7613	Business	11100.00
0005433123790	7613	Economy	3700.00
0005433123803	7613	Economy	3700.00
0005433722106	7613	Economy	3700.00
0005433123800	7613	Economy	4100.00
0005433123792	7613	Economy	4100.00
0005433123797	7613	Economy	3700.00
0005433123785	7613	Economy	3700.00
0005433123786	7613	Economy	3700.00
0005433123787	7613	Economy	3700.00
0005433123781	7613	Economy	3700.00
0005433123782	7613	Economy	3700.00
0005433123798	7613	Economy	3700.00
0005433123791	7613	Economy	3700.00
0005433123801	7613	Economy	3700.00
0005433722103	7613	Economy	3700.00
0005433123783	7613	Economy	3700.00
0005433123789	7613	Economy	3700.00
0005433123796	7613	Economy	3700.00
0005433123794	7613	Economy	3700.00
0005433123799	7613	Economy	3700.00
0005433123795	7613	Economy	3700.00
0005433123784	7613	Economy	3700.00
0005433123802	7613	Economy	3700.00
0005433123788	7613	Economy	3700.00
0005432720724	7610	Business	11100.00
0005433449808	7610	Business	11100.00
0005432692861	7610	Business	11100.00
0005433449824	7610	Business	11100.00
0005432692863	7610	Business	11100.00
0005432720715	7610	Business	11100.00
0005432720717	7610	Business	11100.00
0005433449814	7610	Business	11100.00
0005432692846	7610	Business	11100.00
0005432692870	7610	Business	11100.00
0005432720722	7610	Business	11100.00
0005433449811	7610	Economy	3700.00
0005433449809	7610	Economy	3700.00
0005432692848	7610	Economy	3700.00
0005432720711	7610	Economy	3700.00
0005432720707	7610	Economy	3700.00
0005432692858	7610	Economy	3700.00
0005433449817	7610	Economy	3700.00
0005433449823	7610	Economy	3700.00
0005432720713	7610	Economy	3700.00
0005432692844	7610	Economy	4100.00
0005432720704	7610	Economy	4100.00
0005432692855	7610	Economy	4100.00
0005432692868	7610	Economy	4100.00
0005432720720	7610	Economy	3700.00
0005432692856	7610	Economy	3700.00
0005432692849	7610	Economy	3700.00
0005432720718	7610	Economy	3700.00
0005432720710	7610	Economy	3700.00
0005432720726	7610	Economy	3700.00
0005433449812	7610	Economy	3700.00
0005432692845	7610	Economy	3700.00
0005432720725	7610	Economy	3700.00
0005432071551	7610	Economy	3700.00
0005432720706	7610	Economy	3700.00
0005432720714	7610	Economy	3700.00
0005433449822	7610	Economy	3700.00
0005432692872	7610	Economy	3700.00
0005432692852	7610	Economy	3700.00
0005433449821	7610	Economy	3700.00
0005432692857	7610	Economy	3700.00
0005432692865	7610	Economy	3700.00
0005432720705	7610	Economy	3700.00
0005432692862	7610	Economy	3700.00
0005433449815	7610	Economy	3700.00
0005432720723	7610	Economy	3700.00
0005432720716	7610	Economy	3700.00
0005433449818	7610	Economy	3700.00
0005432720708	7610	Economy	3700.00
0005432720709	7610	Economy	3700.00
0005433449807	7610	Economy	3700.00
0005432692843	7610	Economy	3700.00
0005432720727	7610	Economy	3700.00
0005432692869	7610	Economy	3700.00
0005432071553	7610	Economy	3700.00
0005432720729	7610	Economy	3700.00
0005433449819	7610	Economy	3700.00
0005433449820	7610	Economy	3700.00
0005433449825	7610	Economy	3700.00
0005432692873	7610	Economy	3700.00
0005432692860	7610	Economy	3700.00
0005432692854	7610	Economy	3700.00
0005433449806	7610	Economy	3700.00
0005433449816	7610	Economy	3700.00
0005432720728	7610	Economy	3700.00
0005432720712	7610	Economy	3700.00
0005432071554	7610	Economy	3700.00
0005432720721	7610	Economy	3700.00
0005432692859	7610	Economy	3700.00
0005432720719	7610	Economy	3700.00
0005432692866	7610	Economy	3700.00
0005432692850	7610	Economy	3700.00
0005432692847	7610	Economy	3700.00
0005432720703	7610	Economy	3700.00
0005433449827	7610	Economy	3700.00
0005433449826	7610	Economy	3700.00
0005432692867	7610	Economy	3700.00
0005432692864	7610	Economy	3700.00
0005433449813	7610	Economy	3700.00
0005432071552	7610	Economy	3700.00
0005433449810	7610	Economy	3700.00
0005432692871	7610	Economy	3700.00
0005432692853	7610	Economy	3700.00
0005432692851	7610	Economy	3700.00
0005432692529	30367	Business	11100.00
0005432692538	30367	Business	11100.00
0005432692530	30367	Business	11100.00
0005432692556	30367	Business	11100.00
0005433449620	30367	Economy	3700.00
0005432692539	30367	Economy	3700.00
0005432692559	30367	Economy	3700.00
0005433449601	30367	Economy	3700.00
0005432692597	30367	Economy	3700.00
0005432692533	30367	Economy	3700.00
0005433449592	30367	Economy	4100.00
0005433449667	30367	Economy	3700.00
0005433449673	30367	Economy	3700.00
0005433449657	30367	Economy	3700.00
0005433449678	30367	Economy	3700.00
0005432692595	30367	Economy	3700.00
0005432692544	30367	Economy	3700.00
0005432692564	30367	Economy	3700.00
0005432692596	30367	Economy	3700.00
0005433449708	30367	Economy	3700.00
0005433449694	30367	Economy	3700.00
0005433449756	30367	Economy	3700.00
0005433449669	30367	Economy	3700.00
0005432692591	30367	Economy	3700.00
0005433449755	30367	Economy	3700.00
0005432692699	30367	Economy	3700.00
0005433449672	30367	Economy	3700.00
0005432692618	30367	Economy	3700.00
0005433449587	30367	Economy	3700.00
0005433449645	30367	Economy	3700.00
0005432692560	30367	Economy	3700.00
0005432692700	30367	Economy	3700.00
0005432692604	30367	Economy	3700.00
0005433449611	30367	Economy	3700.00
0005432692546	30367	Economy	3700.00
0005432692634	30367	Economy	3700.00
0005432692615	30367	Economy	3700.00
0005432692594	30367	Economy	3700.00
0005432692545	30367	Economy	3700.00
0005433449607	30367	Economy	3700.00
0005433449600	30367	Economy	3700.00
0005433123606	30366	Business	11100.00
0005433123595	30366	Business	11100.00
0005433123565	30366	Business	11100.00
0005432720587	30366	Business	11100.00
0005433123570	30366	Business	11100.00
0005433123608	30366	Business	11100.00
0005432720524	30366	Economy	3700.00
0005433123649	30366	Economy	3700.00
0005433123617	30366	Economy	3700.00
0005432720541	30366	Economy	3700.00
0005433123594	30366	Economy	4100.00
0005432720630	30366	Economy	4100.00
0005432720486	30366	Economy	3700.00
0005432720586	30366	Economy	3700.00
0005432720595	30366	Economy	3700.00
0005432720469	30366	Economy	3700.00
0005432720568	30366	Economy	3700.00
0005433123607	30366	Economy	3700.00
0005433722171	30366	Economy	3700.00
0005433123648	30366	Economy	3700.00
0005432720588	30366	Economy	3700.00
0005432720536	30366	Economy	3700.00
0005433722172	30366	Economy	3700.00
0005432720457	30366	Economy	3700.00
0005433123622	30366	Economy	3700.00
0005432720537	30366	Economy	3700.00
0005433722175	30366	Economy	3700.00
0005432720468	30366	Economy	3700.00
0005433722173	30366	Economy	3700.00
0005433123598	30366	Economy	3700.00
0005433722178	30366	Economy	3700.00
0005433722174	30366	Economy	3700.00
0005433722170	30366	Economy	3700.00
0005433123592	30366	Economy	3700.00
0005433123597	30366	Economy	3700.00
0005433123644	30366	Economy	3700.00
0005433722176	30366	Economy	3700.00
0005433722177	30366	Economy	3700.00
0005432720662	30366	Economy	3700.00
0005433123643	30366	Economy	3700.00
0005432720471	30366	Economy	3700.00
0005432720576	30366	Economy	3700.00
0005433123614	30366	Economy	3700.00
0005432720533	30366	Economy	3700.00
0005433123600	30366	Economy	3700.00
0005432720663	30366	Economy	3700.00
0005433123647	30366	Economy	3700.00
0005432720525	30366	Economy	3700.00
0005433123599	30366	Economy	3700.00
0005432720567	30366	Economy	3700.00
0005434586429	1381	Business	70400.00
0005433524959	1381	Business	70400.00
0005432927886	1381	Business	70400.00
0005433192822	1381	Business	70400.00
0005433192821	1381	Business	70400.00
0005434586430	1381	Business	70400.00
0005433724776	1381	Business	70400.00
0005434586424	1381	Business	70400.00
0005432968802	1381	Business	70400.00
0005433524962	1381	Economy	23500.00
0005433192895	1381	Economy	23500.00
0005434586444	1381	Economy	23500.00
0005433192877	1381	Economy	23500.00
0005433192819	1381	Economy	23500.00
0005434586422	1381	Economy	23500.00
0005433524957	1381	Economy	23500.00
0005434514948	1381	Economy	23500.00
0005434586441	1381	Economy	23500.00
0005434586421	1381	Economy	25800.00
0005434514949	1381	Economy	25800.00
0005434586434	1381	Economy	23500.00
0005433724772	1381	Economy	23500.00
0005433192854	1381	Economy	23500.00
0005434586428	1381	Economy	23500.00
0005433524958	1381	Economy	23500.00
0005432968803	1381	Economy	23500.00
0005434586437	1381	Economy	23500.00
0005434586442	1381	Economy	23500.00
0005433724773	1381	Economy	23500.00
0005433192880	1381	Economy	23500.00
0005433524963	1381	Economy	23500.00
0005433524961	1381	Economy	23500.00
0005433192812	1381	Economy	23500.00
0005433724774	1381	Economy	23500.00
0005432270983	1381	Economy	23500.00
0005434586438	1381	Economy	23500.00
0005434586427	1381	Economy	23500.00
0005434513561	1381	Economy	23500.00
0005434586433	1381	Economy	23500.00
0005434586425	1381	Economy	23500.00
0005433192845	1381	Economy	23500.00
0005434586445	1381	Economy	23500.00
0005433524965	1381	Economy	23500.00
0005433192846	1381	Economy	23500.00
0005432927889	1381	Economy	23500.00
0005434586426	1381	Economy	23500.00
0005434513564	1381	Economy	23500.00
0005434586423	1381	Economy	23500.00
0005433524964	1381	Economy	23500.00
0005434586443	1381	Economy	23500.00
0005433192863	1381	Economy	23500.00
0005433192896	1381	Economy	23500.00
0005434586436	1381	Economy	23500.00
0005432270984	1381	Economy	23500.00
0005434586446	1381	Economy	23500.00
0005433192897	1381	Economy	23500.00
0005433192862	1381	Economy	23500.00
0005434586432	1381	Economy	23500.00
0005432968811	1381	Economy	23500.00
0005433524967	1381	Economy	23500.00
0005434586439	1381	Economy	23500.00
0005434513562	1381	Economy	23500.00
0005433192865	1381	Economy	23500.00
0005432270985	1381	Economy	23500.00
0005434586431	1381	Economy	23500.00
0005434586435	1381	Economy	23500.00
0005434586440	1381	Economy	23500.00
0005434513563	1381	Economy	23500.00
0005432927901	1381	Economy	23500.00
0005433524966	1381	Economy	23500.00
0005433524960	1381	Economy	23500.00
0005432927902	1381	Economy	23500.00
0005433724775	1381	Economy	23500.00
0005432927939	18551	Business	70400.00
0005434586187	18551	Business	70400.00
0005434586191	18551	Business	70400.00
0005433192952	18551	Business	70400.00
0005433192954	18551	Business	70400.00
0005433192958	18551	Business	70400.00
0005433524885	18551	Business	70400.00
0005432927941	18551	Business	70400.00
0005433192956	18551	Business	70400.00
0005434586201	18551	Business	70400.00
0005434586246	18551	Economy	23500.00
0005432927938	18551	Economy	23500.00
0005434586189	18551	Economy	23500.00
0005434586221	18551	Economy	23500.00
0005434586307	18551	Economy	25800.00
0005432927940	18551	Economy	25800.00
0005434586200	18551	Economy	25800.00
0005434514931	18551	Economy	23500.00
0005434586282	18551	Economy	23500.00
0005433524874	18551	Economy	23500.00
0005433524853	18551	Economy	23500.00
0005432968823	18551	Economy	23500.00
0005434586195	18551	Economy	23500.00
0005433524901	18551	Economy	23500.00
0005433192951	18551	Economy	23500.00
0005434586266	18551	Economy	23500.00
0005433192955	18551	Economy	23500.00
0005434586265	18551	Economy	23500.00
0005433524875	18551	Economy	23500.00
0005434586176	18551	Economy	23500.00
0005434586218	18551	Economy	23500.00
0005434586278	18551	Economy	23500.00
0005434586198	18551	Economy	23500.00
0005432968824	18551	Economy	23500.00
0005433192950	18551	Economy	23500.00
0005434586235	18551	Economy	23500.00
0005433524886	18551	Economy	23500.00
0005433524896	18551	Economy	23500.00
0005433192949	18551	Economy	23500.00
0005433192953	18551	Economy	23500.00
0005434586264	18551	Economy	23500.00
0005432927936	18551	Economy	23500.00
0005433192957	18551	Economy	23500.00
0005433192947	18551	Economy	23500.00
0005433192948	18551	Economy	23500.00
0005433524902	18551	Economy	23500.00
0005434586247	18551	Economy	23500.00
0005434586193	18551	Economy	23500.00
0005434586188	18551	Economy	23500.00
0005434586174	18551	Economy	23500.00
0005433724730	18551	Economy	23500.00
0005434586254	18551	Economy	23500.00
0005433524860	18551	Economy	23500.00
0005432927937	18551	Economy	23500.00
0005433524861	18551	Economy	23500.00
0005434586212	18551	Economy	23500.00
0005433524881	18551	Economy	23500.00
0005434586194	18551	Economy	23500.00
0005434586199	18551	Economy	23500.00
0005433524870	18551	Economy	23500.00
0005434586217	18551	Economy	23500.00
0005434586220	18551	Economy	23500.00
0005433192945	18551	Economy	23500.00
0005433724738	18551	Economy	23500.00
0005433192946	18551	Economy	23500.00
0005433724737	18551	Economy	23500.00
0005434586175	18551	Economy	23500.00
0005434343948	11474	Economy	4300.00
0005434343927	11474	Economy	4300.00
0005434343929	11474	Economy	4300.00
0005434343928	11474	Economy	4000.00
0005434343938	11474	Economy	4300.00
0005434343930	11474	Economy	4000.00
0005434343921	11474	Economy	4000.00
0005434343918	11474	Economy	4000.00
0005435302131	11474	Economy	4000.00
0005434343916	11474	Economy	4000.00
0005434343946	11474	Economy	4000.00
0005435302132	11474	Economy	4000.00
0005434343943	11474	Economy	4000.00
0005434142582	11474	Economy	4000.00
0005434343912	11474	Economy	4000.00
0005434343939	11474	Economy	4000.00
0005434343932	11474	Economy	4000.00
0005434343915	11474	Economy	4000.00
0005434343936	11474	Economy	4000.00
0005434343923	11474	Economy	4000.00
0005434343911	11474	Economy	4000.00
0005434343940	11474	Economy	4000.00
0005434343913	11474	Economy	4000.00
0005434343933	11474	Economy	4000.00
0005434142583	11474	Economy	4000.00
0005434343941	11474	Economy	4000.00
0005434343942	11474	Economy	4000.00
0005434343944	11474	Economy	4000.00
0005434343914	11474	Economy	4000.00
0005434343935	11474	Economy	4000.00
0005434343937	11474	Economy	4000.00
0005434343920	11474	Economy	4000.00
0005434343947	11474	Economy	4000.00
0005434142584	11474	Economy	4000.00
0005434343922	11474	Economy	4000.00
0005434343945	11474	Economy	4000.00
0005434343924	11474	Economy	4000.00
0005434343925	11474	Economy	4000.00
0005434343926	11474	Economy	4000.00
0005434343931	11474	Economy	4000.00
0005434343934	11474	Economy	4000.00
0005434343919	11474	Economy	4000.00
0005434343917	11474	Economy	4000.00
0005434343736	29775	Economy	4300.00
0005434343632	29775	Economy	4300.00
0005435304128	29775	Economy	4300.00
0005434343705	29775	Economy	4300.00
0005435304129	29775	Economy	4000.00
0005435305003	29775	Economy	4000.00
0005434343670	29775	Economy	4000.00
0005435304130	29775	Economy	4000.00
0005434343681	29775	Economy	4000.00
0005435304127	29775	Economy	4000.00
0005434343745	29775	Economy	4000.00
0005434343678	29775	Economy	4000.00
0005434343622	29775	Economy	4000.00
0005434343582	29775	Economy	4000.00
0005434343740	29775	Economy	4000.00
0005434343706	29775	Economy	4000.00
0005434343593	29775	Economy	4000.00
0005434343602	29775	Economy	4000.00
0005434343615	29775	Economy	4000.00
0005434343744	29775	Economy	4000.00
0005434343616	29775	Economy	4000.00
0005434343671	29775	Economy	4000.00
0005434343679	29775	Economy	4000.00
0005434343771	29775	Economy	4000.00
0005435305004	29775	Economy	4000.00
0005435304131	29775	Economy	4000.00
0005434343603	29775	Economy	4000.00
0005434343641	29775	Economy	4000.00
0005435305002	29775	Economy	4000.00
0005435305001	29775	Economy	4000.00
0005434343650	29775	Economy	4000.00
0005434343640	29775	Economy	4000.00
0005433415465	1290	Business	199800.00
0005435824443	1290	Business	199800.00
0005432284537	1290	Business	199800.00
0005435824452	1290	Business	199800.00
0005435824426	1290	Business	199800.00
0005435824432	1290	Business	199800.00
0005435824447	1290	Business	199800.00
0005435824433	1290	Business	199800.00
0005435824441	1290	Business	199800.00
0005435824442	1290	Economy	66600.00
0005435824431	1290	Economy	73200.00
0005435824439	1290	Economy	73200.00
0005435824434	1290	Economy	66600.00
0005435824445	1290	Economy	66600.00
0005432284538	1290	Economy	66600.00
0005435824427	1290	Economy	66600.00
0005435824428	1290	Economy	66600.00
0005435824449	1290	Economy	66600.00
0005435824436	1290	Economy	66600.00
0005435824430	1290	Economy	66600.00
0005435824446	1290	Economy	66600.00
0005435824440	1290	Economy	66600.00
0005433415414	1290	Economy	66600.00
0005433415394	1290	Economy	66600.00
0005435824438	1290	Economy	66600.00
0005435824444	1290	Economy	66600.00
0005433415416	1290	Economy	66600.00
0005432284536	1290	Economy	66600.00
0005433415417	1290	Economy	66600.00
0005435824450	1290	Economy	66600.00
0005433415398	1290	Economy	66600.00
0005435824435	1290	Economy	66600.00
0005435824448	1290	Economy	66600.00
0005435824451	1290	Economy	66600.00
0005433415441	1290	Economy	66600.00
0005433415415	1290	Economy	66600.00
0005435824437	1290	Economy	66600.00
0005435824429	1290	Economy	66600.00
0005433415557	17983	Business	199800.00
0005433415551	17983	Business	199800.00
0005433415543	17983	Business	199800.00
0005435824313	17983	Business	199800.00
0005435824228	17983	Business	199800.00
0005435824314	17983	Business	199800.00
0005433415548	17983	Economy	66600.00
0005435824182	17983	Economy	66600.00
0005435824297	17983	Economy	66600.00
0005435824316	17983	Economy	66600.00
0005435824172	17983	Economy	66600.00
0005435824315	17983	Economy	66600.00
0005435824227	17983	Economy	73200.00
0005435824272	17983	Economy	73200.00
0005433415552	17983	Economy	73200.00
0005435824237	17983	Economy	66600.00
0005435824229	17983	Economy	66600.00
0005433415541	17983	Economy	66600.00
0005435824197	17983	Economy	66600.00
0005435824174	17983	Economy	66600.00
0005433415544	17983	Economy	66600.00
0005433415547	17983	Economy	66600.00
0005433415542	17983	Economy	66600.00
0005433415549	17983	Economy	66600.00
0005435824362	17983	Economy	66600.00
0005435824151	17983	Economy	66600.00
0005433415550	17983	Economy	66600.00
0005433415556	17983	Economy	66600.00
0005433415554	17983	Economy	66600.00
0005435824256	17983	Economy	66600.00
0005435824165	17983	Economy	66600.00
0005433415553	17983	Economy	66600.00
0005435824214	17983	Economy	66600.00
0005433415545	17983	Economy	66600.00
0005435824253	17983	Economy	66600.00
0005433415546	17983	Economy	66600.00
0005435824255	17983	Economy	66600.00
0005433415555	17983	Economy	66600.00
0005435824226	17983	Economy	66600.00
0005435824300	17983	Economy	66600.00
0005435824173	17983	Economy	66600.00
0005435824290	17983	Economy	66600.00
0005434460466	17532	Economy	14800.00
0005434460473	17532	Economy	13500.00
0005434460468	17532	Economy	13500.00
0005434462752	17532	Economy	13500.00
0005434462757	17532	Economy	13500.00
0005434460476	17532	Economy	13500.00
0005435242428	5620	Business	27800.00
0005435476634	5620	Business	27800.00
0005435242412	5620	Business	27800.00
0005432783409	5620	Business	27800.00
0005432143964	5620	Business	27800.00
0005432783401	5620	Business	27800.00
0005432783440	5620	Business	27800.00
0005432783405	5620	Economy	9300.00
0005432783432	5620	Economy	9300.00
0005435242481	5620	Economy	9300.00
0005432783434	5620	Economy	9300.00
0005432783392	5620	Economy	9300.00
0005432783397	5620	Economy	9300.00
0005432143963	5620	Economy	9300.00
0005435242403	5620	Economy	9300.00
0005432783428	5620	Economy	10200.00
0005432783437	5620	Economy	10200.00
0005432783398	5620	Economy	10200.00
0005432783435	5620	Economy	10200.00
0005432783418	5620	Economy	10200.00
0005435242512	5620	Economy	9300.00
0005432783415	5620	Economy	9300.00
0005432783417	5620	Economy	9300.00
0005432783426	5620	Economy	9300.00
0005432783431	5620	Economy	9300.00
0005432783425	5620	Economy	9300.00
0005435242390	5620	Economy	9300.00
0005432783441	5620	Economy	9300.00
0005432783410	5620	Economy	9300.00
0005432783436	5620	Economy	9300.00
0005432783391	5620	Economy	9300.00
0005432783413	5620	Economy	9300.00
0005432783394	5620	Economy	9300.00
0005435242553	5620	Economy	9300.00
0005432783412	5620	Economy	9300.00
0005432783416	5620	Economy	9300.00
0005432783396	5620	Economy	9300.00
0005432783399	5620	Economy	9300.00
0005432783400	5620	Economy	9300.00
0005432783442	5620	Economy	9300.00
0005432783395	5620	Economy	9300.00
0005432783422	5620	Economy	9300.00
0005432783423	5620	Economy	9300.00
0005432783429	5620	Economy	9300.00
0005435242418	5620	Economy	9300.00
0005432143965	5620	Economy	9300.00
0005435476647	5620	Economy	9300.00
0005435242457	5620	Economy	9300.00
0005432783402	5620	Economy	9300.00
0005435476659	5620	Economy	9300.00
0005432783411	5620	Economy	9300.00
0005432783427	5620	Economy	9300.00
0005435242389	5620	Economy	9300.00
0005432783439	5620	Economy	9300.00
0005435242480	5620	Economy	9300.00
0005432783424	5620	Economy	9300.00
0005432783430	5620	Economy	9300.00
0005432783433	5620	Economy	9300.00
0005432783403	5620	Economy	9300.00
0005432783438	5620	Economy	9300.00
0005432783421	5620	Economy	9300.00
0005432783407	5620	Economy	9300.00
0005432783420	5620	Economy	9300.00
0005435476655	5620	Economy	9300.00
0005435242448	5620	Economy	9300.00
0005435476654	5620	Economy	9300.00
0005432783404	5620	Economy	9300.00
0005432783393	5620	Economy	9300.00
0005432783408	5620	Economy	9300.00
0005432783443	5620	Economy	9300.00
0005432783414	5620	Economy	9300.00
0005435242456	5620	Economy	9300.00
0005435242552	5620	Economy	9300.00
0005432783419	5620	Economy	9300.00
0005432783406	5620	Economy	9300.00
0005432783089	15391	Business	27800.00
0005432782909	15391	Business	27800.00
0005435242642	15391	Business	27800.00
0005432782867	15391	Business	27800.00
0005435242637	15391	Business	27800.00
0005435242638	15391	Business	27800.00
0005435242657	15391	Business	27800.00
0005435476715	15391	Business	27800.00
0005432782876	15391	Economy	9300.00
0005432782866	15391	Economy	9300.00
0005432782853	15391	Economy	9300.00
0005432783042	15391	Economy	9300.00
0005435242646	15391	Economy	9300.00
0005432782936	15391	Economy	9300.00
0005435476711	15391	Economy	9300.00
0005432782846	15391	Economy	9300.00
0005435242643	15391	Economy	9300.00
0005432782894	15391	Economy	10200.00
0005435242639	15391	Economy	10200.00
0005432782983	15391	Economy	10200.00
0005432782943	15391	Economy	9300.00
0005432782987	15391	Economy	9300.00
0005435476712	15391	Economy	9300.00
0005432782856	15391	Economy	9300.00
0005432782855	15391	Economy	9300.00
0005435242649	15391	Economy	9300.00
0005435242661	15391	Economy	9300.00
0005432782988	15391	Economy	9300.00
0005432782841	15391	Economy	9300.00
0005432783193	15391	Economy	9300.00
0005432782875	15391	Economy	9300.00
0005435242641	15391	Economy	9300.00
0005435242640	15391	Economy	9300.00
0005435242655	15391	Economy	9300.00
0005435242660	15391	Economy	9300.00
0005435242654	15391	Economy	9300.00
0005432782961	15391	Economy	9300.00
0005432783057	15391	Economy	9300.00
0005435242647	15391	Economy	9300.00
0005432782956	15391	Economy	9300.00
0005432782854	15391	Economy	9300.00
0005432782923	15391	Economy	9300.00
0005435242644	15391	Economy	9300.00
0005432782922	15391	Economy	9300.00
0005432782939	15391	Economy	9300.00
0005435242662	15391	Economy	9300.00
0005435476710	15391	Economy	9300.00
0005435476709	15391	Economy	9300.00
0005432782993	15391	Economy	9300.00
0005435242650	15391	Economy	9300.00
0005435242653	15391	Economy	9300.00
0005432782895	15391	Economy	9300.00
0005435242651	15391	Economy	9300.00
0005435242663	15391	Economy	9300.00
0005435242648	15391	Economy	9300.00
0005432783112	15391	Economy	9300.00
0005432782960	15391	Economy	9300.00
0005435242656	15391	Economy	9300.00
0005435476714	15391	Economy	9300.00
0005432782944	15391	Economy	9300.00
0005435476716	15391	Economy	9300.00
0005435476713	15391	Economy	9300.00
0005432783192	15391	Economy	9300.00
0005435242652	15391	Economy	9300.00
0005432782924	15391	Economy	9300.00
0005435242658	15391	Economy	9300.00
0005435242659	15391	Economy	9300.00
0005435242645	15391	Economy	9300.00
0005435850764	4346	Economy	7000.00
0005432848216	4346	Economy	7000.00
0005432848205	4346	Economy	7000.00
0005432848204	4346	Economy	6300.00
0005435850784	4346	Economy	6300.00
0005435850816	4346	Economy	6300.00
0005435850758	4346	Economy	6300.00
0005432848208	4346	Economy	6300.00
0005435850812	4346	Economy	6300.00
0005435850793	4346	Economy	6300.00
0005434463914	4346	Economy	6300.00
0005432848210	4346	Economy	6300.00
0005435850762	4346	Economy	6300.00
0005432848207	4346	Economy	6300.00
0005434462775	4346	Economy	6300.00
0005432848211	4346	Economy	6300.00
0005432848217	4346	Economy	6300.00
0005432848213	4346	Economy	6300.00
0005432848209	4346	Economy	6300.00
0005432848215	4346	Economy	6300.00
0005432848212	4346	Economy	6300.00
0005432848214	4346	Economy	6300.00
0005432848206	4346	Economy	6300.00
0005435850763	4346	Economy	6300.00
0005434462774	4346	Economy	6300.00
0005432848090	28873	Economy	7000.00
0005434461616	28873	Economy	7000.00
0005435850845	28873	Economy	6300.00
0005434461617	28873	Economy	6300.00
0005432848070	28873	Economy	6300.00
0005435850850	28873	Economy	6300.00
0005432848083	28873	Economy	6300.00
0005432848125	28873	Economy	6300.00
0005435850849	28873	Economy	6300.00
0005432848082	28873	Economy	6300.00
0005432848072	28873	Economy	6300.00
0005432848061	28873	Economy	6300.00
0005432848080	28873	Economy	6300.00
0005432848081	28873	Economy	6300.00
0005435850843	28873	Economy	6300.00
0005432848085	28873	Economy	6300.00
0005435850844	28873	Economy	6300.00
0005432848084	28873	Economy	6300.00
0005435850846	28873	Economy	6300.00
0005432848069	28873	Economy	6300.00
0005432848086	28873	Economy	6300.00
0005432848089	28873	Economy	6300.00
0005432848101	28873	Economy	6300.00
0005435850842	28873	Economy	6300.00
0005435850847	28873	Economy	6300.00
0005432848066	28873	Economy	6300.00
0005432848062	28873	Economy	6300.00
0005432848071	28873	Economy	6300.00
0005435850848	28873	Economy	6300.00
0005433496752	6273	Business	11900.00
0005433496761	6273	Business	11900.00
0005434443599	6273	Business	11900.00
0005434925573	6273	Business	11900.00
0005434443597	6273	Business	11900.00
0005433496767	6273	Business	11900.00
0005434925581	6273	Business	11900.00
0005434925597	6273	Business	11900.00
0005434925603	6273	Business	11900.00
0005434925594	6273	Business	11900.00
0005433496741	6273	Economy	4000.00
0005433496763	6273	Economy	4000.00
0005434925572	6273	Economy	4000.00
0005434925580	6273	Economy	4000.00
0005434925595	6273	Economy	4000.00
0005434443594	6273	Economy	4000.00
0005434925601	6273	Economy	4000.00
0005434925599	6273	Economy	4000.00
0005433496768	6273	Economy	4000.00
0005434925584	6273	Economy	4000.00
0005434443598	6273	Economy	4400.00
0005434925579	6273	Economy	4400.00
0005434925576	6273	Economy	4400.00
0005433496738	6273	Economy	4400.00
0005434925575	6273	Economy	4000.00
0005433496746	6273	Economy	4000.00
0005434925606	6273	Economy	4000.00
0005432075206	6273	Economy	4000.00
0005434925583	6273	Economy	4000.00
0005433496742	6273	Economy	4000.00
0005434925582	6273	Economy	4000.00
0005434925602	6273	Economy	4000.00
0005434925588	6273	Economy	4000.00
0005434925578	6273	Economy	4000.00
0005434443602	6273	Economy	4000.00
0005432075205	6273	Economy	4000.00
0005433496771	6273	Economy	4000.00
0005434925585	6273	Economy	4000.00
0005433496739	6273	Economy	4000.00
0005434443595	6273	Economy	4000.00
0005434443591	6273	Economy	4000.00
0005433496769	6273	Economy	4000.00
0005434443593	6273	Economy	4000.00
0005434925604	6273	Economy	4000.00
0005433496744	6273	Economy	4000.00
0005434443603	6273	Economy	4000.00
0005434443604	6273	Economy	4000.00
0005432075208	6273	Economy	4000.00
0005434443601	6273	Economy	4000.00
0005434443592	6273	Economy	4000.00
0005433496757	6273	Economy	4000.00
0005433496750	6273	Economy	4000.00
0005433496755	6273	Economy	4000.00
0005434925605	6273	Economy	4000.00
0005434925591	6273	Economy	4000.00
0005433496760	6273	Economy	4000.00
0005434925592	6273	Economy	4000.00
0005433496766	6273	Economy	4000.00
0005433496770	6273	Economy	4000.00
0005433496759	6273	Economy	4000.00
0005434925593	6273	Economy	4000.00
0005433496740	6273	Economy	4000.00
0005433496743	6273	Economy	4000.00
0005434925587	6273	Economy	4000.00
0005434443600	6273	Economy	4000.00
0005434443590	6273	Economy	4000.00
0005433496756	6273	Economy	4000.00
0005434925574	6273	Economy	4000.00
0005432075207	6273	Economy	4000.00
0005434925586	6273	Economy	4000.00
0005433496749	6273	Economy	4000.00
0005433496747	6273	Economy	4000.00
0005433496764	6273	Economy	4000.00
0005433496762	6273	Economy	4000.00
0005434925600	6273	Economy	4000.00
0005433496751	6273	Economy	4000.00
0005432075204	6273	Economy	4000.00
0005433496753	6273	Economy	4000.00
0005433496765	6273	Economy	4000.00
0005434925577	6273	Economy	4000.00
0005434925598	6273	Economy	4000.00
0005433496748	6273	Economy	4000.00
0005434925596	6273	Economy	4000.00
0005434443596	6273	Economy	4000.00
0005433496745	6273	Economy	4000.00
0005433496754	6273	Economy	4000.00
0005433496758	6273	Economy	4000.00
0005434925590	6273	Economy	4000.00
0005434925589	6273	Economy	4000.00
0005433496438	20422	Business	11900.00
0005434443458	20422	Business	11900.00
0005433496636	20422	Business	11900.00
0005434925267	20422	Business	11900.00
0005434925309	20422	Business	11900.00
0005434925315	20422	Business	11900.00
0005433496587	20422	Economy	4000.00
0005433496420	20422	Economy	4000.00
0005433496532	20422	Economy	4000.00
0005434925257	20422	Economy	4000.00
0005433496529	20422	Economy	4400.00
0005433496539	20422	Economy	4400.00
0005433496544	20422	Economy	4400.00
0005434443424	20422	Economy	4400.00
0005433496543	20422	Economy	4000.00
0005434925329	20422	Economy	4000.00
0005434925268	20422	Economy	4000.00
0005433496531	20422	Economy	4000.00
0005433496482	20422	Economy	4000.00
0005434925308	20422	Economy	4000.00
0005433496556	20422	Economy	4000.00
0005433496533	20422	Economy	4000.00
0005434925284	20422	Economy	4000.00
0005434925269	20422	Economy	4000.00
0005434443435	20422	Economy	4000.00
0005433496572	20422	Economy	4000.00
0005434925307	20422	Economy	4000.00
0005433496496	20422	Economy	4000.00
0005433496481	20422	Economy	4000.00
0005433496555	20422	Economy	4000.00
0005434443495	20422	Economy	4000.00
0005434443451	20422	Economy	4000.00
0005434925336	20422	Economy	4000.00
0005433496437	20422	Economy	4000.00
0005433496637	20422	Economy	4000.00
0005433496454	20422	Economy	4000.00
0005434443440	20422	Economy	4000.00
0005434443450	20422	Economy	4000.00
0005433496536	20422	Economy	4000.00
0005434443444	20422	Economy	4000.00
0005434925335	20422	Economy	4000.00
0005433496638	20422	Economy	4000.00
0005433496535	20422	Economy	4000.00
0005433496429	20422	Economy	4000.00
0005433496514	20422	Economy	4000.00
0005433496586	20422	Economy	4000.00
0005433496538	20422	Economy	4000.00
0005434925317	20422	Economy	4000.00
0005433496439	20422	Economy	4000.00
0005433496517	20422	Economy	4000.00
0005433496518	20422	Economy	4000.00
0005434925313	20422	Economy	4000.00
0005433496469	20422	Economy	4000.00
0005433496480	20422	Economy	4000.00
0005433496468	20422	Economy	4000.00
0005434925324	20422	Economy	4000.00
0005435242676	12172	Business	41200.00
0005432783102	12172	Business	41200.00
0005432782872	12172	Business	41200.00
0005432783070	12172	Business	41200.00
0005432783019	12172	Business	41200.00
0005432783072	12172	Business	41200.00
0005432783006	12172	Economy	13700.00
0005435242689	12172	Economy	13700.00
0005435242678	12172	Economy	13700.00
0005435242679	12172	Economy	13700.00
0005432783103	12172	Economy	13700.00
0005432783054	12172	Economy	15100.00
0005432782984	12172	Economy	15100.00
0005432783002	12172	Economy	15100.00
0005435242669	12172	Economy	15100.00
0005432782953	12172	Economy	15100.00
0005432782921	12172	Economy	13700.00
0005435242665	12172	Economy	13700.00
0005432783110	12172	Economy	13700.00
0005435242677	12172	Economy	13700.00
0005435242685	12172	Economy	13700.00
0005432782887	12172	Economy	13700.00
0005435242684	12172	Economy	13700.00
0005432783143	12172	Economy	13700.00
0005432783039	12172	Economy	13700.00
0005435242668	12172	Economy	13700.00
0005435242674	12172	Economy	13700.00
0005435242687	12172	Economy	13700.00
0005432783079	12172	Economy	13700.00
0005435242671	12172	Economy	13700.00
0005432782952	12172	Economy	13700.00
0005432783031	12172	Economy	13700.00
0005432783246	12172	Economy	13700.00
0005432782884	12172	Economy	13700.00
0005432783245	12172	Economy	13700.00
0005432783053	12172	Economy	13700.00
0005432783005	12172	Economy	13700.00
0005432783174	12172	Economy	13700.00
0005435242686	12172	Economy	13700.00
0005432783001	12172	Economy	13700.00
0005435242675	12172	Economy	13700.00
0005435242681	12172	Economy	13700.00
0005432783040	12172	Economy	13700.00
0005435242690	12172	Economy	13700.00
0005432783107	12172	Economy	13700.00
0005435242691	12172	Economy	13700.00
0005435242680	12172	Economy	13700.00
0005435242688	12172	Economy	13700.00
0005435242667	12172	Economy	13700.00
0005432782891	12172	Economy	13700.00
0005435242672	12172	Economy	13700.00
0005432782907	12172	Economy	13700.00
0005435242683	12172	Economy	13700.00
0005435242666	12172	Economy	13700.00
0005432782893	12172	Economy	13700.00
0005432782860	12172	Economy	13700.00
0005432782892	12172	Economy	13700.00
0005435242673	12172	Economy	13700.00
0005432783026	12172	Economy	13700.00
0005432783080	12172	Economy	13700.00
0005435242670	12172	Economy	13700.00
0005432783160	12172	Economy	13700.00
0005435242682	12172	Economy	13700.00
0005432782995	12172	Economy	13700.00
0005435242664	12172	Economy	13700.00
0005435242397	15412	Business	41200.00
0005432783382	15412	Business	41200.00
0005432783363	15412	Business	41200.00
0005432783346	15412	Business	41200.00
0005432783384	15412	Business	41200.00
0005432783364	15412	Business	41200.00
0005432783356	15412	Business	41200.00
0005432783378	15412	Business	41200.00
0005432783347	15412	Business	41200.00
0005432783359	15412	Business	41200.00
0005432783389	15412	Economy	13700.00
0005432783375	15412	Economy	13700.00
0005432783352	15412	Economy	13700.00
0005432783385	15412	Economy	13700.00
0005432783350	15412	Economy	13700.00
0005432783374	15412	Economy	13700.00
0005432783341	15412	Economy	13700.00
0005432783362	15412	Economy	15100.00
0005432783344	15412	Economy	15100.00
0005435242513	15412	Economy	15100.00
0005432783383	15412	Economy	15100.00
0005432783358	15412	Economy	13700.00
0005432783339	15412	Economy	13700.00
0005432783386	15412	Economy	13700.00
0005435242432	15412	Economy	13700.00
0005435242429	15412	Economy	13700.00
0005432783372	15412	Economy	13700.00
0005432783370	15412	Economy	13700.00
0005435242396	15412	Economy	13700.00
0005432783338	15412	Economy	13700.00
0005432783357	15412	Economy	13700.00
0005432783366	15412	Economy	13700.00
0005432783369	15412	Economy	13700.00
0005435242475	15412	Economy	13700.00
0005435242405	15412	Economy	13700.00
0005432783379	15412	Economy	13700.00
0005435242430	15412	Economy	13700.00
0005435242437	15412	Economy	13700.00
0005432783349	15412	Economy	13700.00
0005432783373	15412	Economy	13700.00
0005432783381	15412	Economy	13700.00
0005432783365	15412	Economy	13700.00
0005435242431	15412	Economy	13700.00
0005435242452	15412	Economy	13700.00
0005432783355	15412	Economy	13700.00
0005432783361	15412	Economy	13700.00
0005432783351	15412	Economy	13700.00
0005432783340	15412	Economy	13700.00
0005432783343	15412	Economy	13700.00
0005432783380	15412	Economy	13700.00
0005432783387	15412	Economy	13700.00
0005432783342	15412	Economy	13700.00
0005432783348	15412	Economy	13700.00
0005432783388	15412	Economy	13700.00
0005432783336	15412	Economy	13700.00
0005432783337	15412	Economy	13700.00
0005435242402	15412	Economy	13700.00
0005432783335	15412	Economy	13700.00
0005435242453	15412	Economy	13700.00
0005435242450	15412	Economy	13700.00
0005432783360	15412	Economy	13700.00
0005432783354	15412	Economy	13700.00
0005432783345	15412	Economy	13700.00
0005432783368	15412	Economy	13700.00
0005432783371	15412	Economy	13700.00
0005435242446	15412	Economy	13700.00
0005435242476	15412	Economy	13700.00
0005432783377	15412	Economy	13700.00
0005432783376	15412	Economy	13700.00
0005432783353	15412	Economy	13700.00
0005432783367	15412	Economy	13700.00
0005432783390	15412	Economy	13700.00
0005435242398	15412	Economy	13700.00
0005434876601	10078	Business	49700.00
0005434876922	10078	Business	49700.00
0005434876837	10078	Business	49700.00
0005434877005	10078	Business	49700.00
0005434876748	10078	Business	49700.00
0005434877114	10078	Business	49700.00
0005434876888	10078	Business	49700.00
0005434876929	10078	Business	49700.00
0005434876587	10078	Business	49700.00
0005434876915	10078	Business	49700.00
0005434876565	10078	Business	49700.00
0005434876683	10078	Business	49700.00
0005434876805	10078	Economy	16600.00
0005434876623	10078	Business	49700.00
0005434877031	10078	Economy	16600.00
0005434910093	10078	Economy	16600.00
0005434876577	10078	Economy	16600.00
0005434877115	10078	Economy	16600.00
0005434877077	10078	Economy	16600.00
0005435913910	10078	Economy	16600.00
0005434877072	10078	Economy	16600.00
0005434877004	10078	Economy	16600.00
0005434876707	10078	Economy	16600.00
0005434877127	10078	Economy	16600.00
0005434876710	10078	Economy	18200.00
0005434876949	10078	Economy	18200.00
0005434876706	10078	Economy	16600.00
0005434876872	10078	Economy	16600.00
0005434876711	10078	Economy	16600.00
0005434877078	10078	Economy	16600.00
0005434876943	10078	Economy	16600.00
0005434876797	10078	Economy	16600.00
0005434876942	10078	Economy	16600.00
0005434876776	10078	Economy	16600.00
0005435913909	10078	Economy	16600.00
0005434877065	10078	Economy	16600.00
0005434910094	10078	Economy	16600.00
0005434876687	10078	Economy	16600.00
0005434876634	10078	Economy	16600.00
0005434876599	10078	Economy	16600.00
0005434876597	10078	Economy	16600.00
0005434876618	10078	Economy	16600.00
0005434876651	10078	Economy	16600.00
0005434876702	10078	Economy	16600.00
0005434876838	10078	Economy	16600.00
0005434876995	10078	Economy	16600.00
0005434876747	10078	Economy	16600.00
0005434877148	10078	Economy	16600.00
0005434877146	10078	Economy	16600.00
0005434876721	10078	Economy	16600.00
0005434876975	10078	Economy	16600.00
0005434876887	10078	Economy	16600.00
0005434876719	10078	Economy	16600.00
0005434876689	10078	Economy	16600.00
0005434877147	10078	Economy	16600.00
0005434876559	10078	Economy	16600.00
0005434877323	10078	Economy	16600.00
0005434876897	10078	Economy	16600.00
0005434876596	10078	Economy	16600.00
0005434877046	10078	Economy	16600.00
0005434877066	10078	Economy	16600.00
0005434876840	10078	Economy	16600.00
0005434876720	10078	Economy	16600.00
0005434876854	10078	Economy	16600.00
0005434876653	10078	Economy	16600.00
0005434877087	10078	Economy	16600.00
0005434876600	10078	Economy	16600.00
0005434910092	10078	Economy	16600.00
0005434876853	10078	Economy	16600.00
0005434876873	10078	Economy	16600.00
0005434876781	10078	Economy	16600.00
0005434876566	10078	Economy	16600.00
0005434876910	10078	Economy	16600.00
0005435913911	10078	Economy	16600.00
0005434876920	10078	Economy	16600.00
0005434877576	14597	Business	49700.00
0005434877524	14597	Business	49700.00
0005434877614	14597	Business	49700.00
0005434877585	14597	Business	49700.00
0005434877530	14597	Business	49700.00
0005434877577	14597	Business	49700.00
0005434877562	14597	Business	49700.00
0005434877554	14597	Business	49700.00
0005434877536	14597	Business	49700.00
0005434877574	14597	Business	49700.00
0005434877605	14597	Business	49700.00
0005434877602	14597	Business	49700.00
0005434877533	14597	Business	49700.00
0005434877615	14597	Business	49700.00
0005434877609	14597	Business	49700.00
0005434877569	14597	Business	49700.00
0005434877600	14597	Business	49700.00
0005434877538	14597	Business	49700.00
0005434910073	14597	Economy	16600.00
0005434877597	14597	Economy	16600.00
0005434877618	14597	Economy	16600.00
0005434877587	14597	Economy	16600.00
0005434877527	14597	Economy	16600.00
0005434877620	14597	Economy	16600.00
0005434877537	14597	Economy	16600.00
0005434877584	14597	Economy	16600.00
0005434877542	14597	Economy	16600.00
0005434877568	14597	Economy	16600.00
0005434877583	14597	Economy	16600.00
0005434877573	14597	Economy	16600.00
0005434877588	14597	Economy	18200.00
0005434877599	14597	Economy	18200.00
0005434877525	14597	Economy	18200.00
0005434877608	14597	Economy	18200.00
0005434877558	14597	Economy	16600.00
0005434877534	14597	Economy	16600.00
0005434877564	14597	Economy	16600.00
0005434877563	14597	Economy	16600.00
0005434877593	14597	Economy	16600.00
0005434877559	14597	Economy	16600.00
0005434877549	14597	Economy	16600.00
0005434877592	14597	Economy	16600.00
0005434877601	14597	Economy	16600.00
0005434877619	14597	Economy	16600.00
0005434877578	14597	Economy	16600.00
0005434877551	14597	Economy	16600.00
0005434877546	14597	Economy	16600.00
0005434877603	14597	Economy	16600.00
0005434877616	14597	Economy	16600.00
0005434877586	14597	Economy	16600.00
0005434758877	14597	Economy	16600.00
0005434877613	14597	Economy	16600.00
0005434877531	14597	Economy	16600.00
0005434877548	14597	Economy	16600.00
0005434877570	14597	Economy	16600.00
0005434877543	14597	Economy	16600.00
0005434877539	14597	Economy	16600.00
0005434877566	14597	Economy	16600.00
0005434877580	14597	Economy	16600.00
0005434877572	14597	Economy	16600.00
0005434877545	14597	Economy	16600.00
0005434877560	14597	Economy	16600.00
0005434877590	14597	Economy	16600.00
0005434877612	14597	Economy	16600.00
0005434877552	14597	Economy	16600.00
0005434877571	14597	Economy	16600.00
0005434877579	14597	Economy	16600.00
0005434877607	14597	Economy	16600.00
0005434877610	14597	Economy	16600.00
0005434877529	14597	Economy	16600.00
0005434877581	14597	Economy	16600.00
0005434877595	14597	Economy	16600.00
0005434877526	14597	Economy	16600.00
0005434877556	14597	Economy	16600.00
0005434877565	14597	Economy	16600.00
0005434877591	14597	Economy	16600.00
0005434877582	14597	Economy	16600.00
0005434877555	14597	Economy	16600.00
0005434877553	14597	Economy	16600.00
0005434910078	14597	Economy	16600.00
0005434877540	14597	Economy	16600.00
0005434877561	14597	Economy	16600.00
0005434877594	14597	Economy	16600.00
0005434877604	14597	Economy	16600.00
0005434877547	14597	Economy	16600.00
0005434877567	14597	Economy	16600.00
0005434877575	14597	Economy	16600.00
0005434877557	14597	Economy	16600.00
0005434877611	14597	Economy	16600.00
0005434877532	14597	Economy	16600.00
0005434877528	14597	Economy	16600.00
0005434877596	14597	Economy	16600.00
0005434877598	14597	Economy	16600.00
0005434877544	14597	Economy	16600.00
0005434877606	14597	Economy	16600.00
0005434877617	14597	Economy	16600.00
0005434877550	14597	Economy	16600.00
0005434877523	14597	Economy	16600.00
0005434910077	14597	Economy	16600.00
0005434877541	14597	Economy	16600.00
0005434877535	14597	Economy	16600.00
0005434877589	14597	Economy	16600.00
0005434251806	9255	Economy	22400.00
0005435660055	9255	Economy	22400.00
0005435660061	9255	Economy	20300.00
0005434251807	9255	Economy	20300.00
0005435660058	9255	Economy	20300.00
0005435660062	9255	Economy	20300.00
0005435660057	9255	Economy	20300.00
0005435660056	9255	Economy	20300.00
0005435660060	9255	Economy	20300.00
0005434251845	9255	Economy	20300.00
0005435660052	9255	Economy	20300.00
0005434251805	9255	Economy	20300.00
0005435660054	9255	Economy	20300.00
0005434251795	9255	Economy	20300.00
0005434251798	9255	Economy	20300.00
0005434251824	9255	Economy	20300.00
0005435660059	9255	Economy	20300.00
0005434251796	9255	Economy	20300.00
0005434251814	9255	Economy	20300.00
0005435660053	9255	Economy	20300.00
0005434251893	24636	Economy	22400.00
0005434251894	24636	Economy	20300.00
0005434251898	24636	Economy	20300.00
0005435659973	24636	Economy	20300.00
0005434251901	24636	Economy	20300.00
0005435659954	24636	Economy	20300.00
0005435659959	24636	Economy	20300.00
0005434251897	24636	Economy	20300.00
0005435660000	24636	Economy	20300.00
0005434251895	24636	Economy	20300.00
0005435659950	24636	Economy	20300.00
0005435659942	24636	Economy	20300.00
0005435659943	24636	Economy	20300.00
0005434251896	24636	Economy	20300.00
0005434251899	24636	Economy	20300.00
0005434251900	24636	Economy	20300.00
0005435659982	24636	Economy	20300.00
0005432966584	2814	Business	33000.00
0005433680237	2814	Business	33000.00
0005433680235	2814	Business	33000.00
0005432966506	2814	Business	33000.00
0005433680220	2814	Business	33000.00
0005433684404	2814	Business	33000.00
0005433680224	2814	Business	33000.00
0005433680197	2814	Business	33000.00
0005433680238	2814	Business	33000.00
0005433680228	2814	Business	33000.00
0005433680208	2814	Economy	11000.00
0005433680233	2814	Economy	11000.00
0005432966483	2814	Economy	11000.00
0005432966595	2814	Economy	11000.00
0005433680229	2814	Economy	11000.00
0005433680226	2814	Economy	11000.00
0005433680239	2814	Economy	11000.00
0005433680231	2814	Economy	11000.00
0005432966614	2814	Economy	12100.00
0005432966583	2814	Economy	12100.00
0005433680230	2814	Economy	12100.00
0005433680245	2814	Economy	12100.00
0005432222743	2814	Economy	11000.00
0005432966552	2814	Economy	11000.00
0005432966495	2814	Economy	11000.00
0005433680218	2814	Economy	11000.00
0005433680234	2814	Economy	11000.00
0005432966548	2814	Economy	11000.00
0005433680241	2814	Economy	11000.00
0005433684403	2814	Economy	11000.00
0005432966497	2814	Economy	11000.00
0005433680240	2814	Economy	11000.00
0005433680216	2814	Economy	11000.00
0005432222744	2814	Economy	11000.00
0005433680206	2814	Economy	11000.00
0005433680214	2814	Economy	11000.00
0005433680212	2814	Economy	11000.00
0005432966575	2814	Economy	11000.00
0005433680223	2814	Economy	11000.00
0005432966510	2814	Economy	11000.00
0005432966511	2814	Economy	11000.00
0005433680221	2814	Economy	11000.00
0005432966496	2814	Economy	11000.00
0005432966490	2814	Economy	11000.00
0005432966498	2814	Economy	11000.00
0005432966492	2814	Economy	11000.00
0005432966618	2814	Economy	11000.00
0005433684405	2814	Economy	11000.00
0005433680242	2814	Economy	11000.00
0005433680217	2814	Economy	11000.00
0005433680201	2814	Economy	11000.00
0005433680202	2814	Economy	11000.00
0005433680244	2814	Economy	11000.00
0005433680211	2814	Economy	11000.00
0005433680213	2814	Economy	11000.00
0005432966612	2814	Economy	11000.00
0005433680227	2814	Economy	11000.00
0005433680215	2814	Economy	11000.00
0005432966547	2814	Economy	11000.00
0005433680225	2814	Economy	11000.00
0005433680210	2814	Economy	11000.00
0005432966493	2814	Economy	11000.00
0005432222746	2814	Economy	11000.00
0005432966512	2814	Economy	11000.00
0005433680204	2814	Economy	11000.00
0005433680203	2814	Economy	11000.00
0005433680209	2814	Economy	11000.00
0005433680219	2814	Economy	11000.00
0005433680200	2814	Economy	11000.00
0005433680246	2814	Economy	11000.00
0005432966482	2814	Economy	11000.00
0005433680243	2814	Economy	11000.00
0005433680236	2814	Economy	11000.00
0005432222745	2814	Economy	11000.00
0005433680205	2814	Economy	11000.00
0005432966513	2814	Economy	11000.00
0005432966604	2814	Economy	11000.00
0005432966557	2814	Economy	11000.00
0005433680232	2814	Economy	11000.00
0005432222742	2814	Economy	11000.00
0005433680207	2814	Economy	11000.00
0005433680222	2814	Economy	11000.00
0005433680199	2814	Economy	11000.00
0005433680198	2814	Economy	11000.00
0005433679798	29169	Business	33000.00
0005432966767	29169	Business	33000.00
0005433679834	29169	Business	33000.00
0005432966755	29169	Business	33000.00
0005432966761	29169	Business	33000.00
0005433679908	29169	Business	33000.00
0005433680003	29169	Business	33000.00
0005432966744	29169	Business	33000.00
0005433679929	29169	Business	33000.00
0005432005193	29169	Economy	11000.00
0005433679810	29169	Economy	11000.00
0005432966747	29169	Economy	11000.00
0005433680036	29169	Economy	11000.00
0005433680034	29169	Economy	11000.00
0005433680035	29169	Economy	11000.00
0005433679840	29169	Economy	12100.00
0005432966756	29169	Economy	12100.00
0005432966762	29169	Economy	12100.00
0005433679878	29169	Economy	12100.00
0005433679823	29169	Economy	11000.00
0005432966741	29169	Economy	11000.00
0005433679930	29169	Economy	11000.00
0005433679724	29169	Economy	11000.00
0005432966752	29169	Economy	11000.00
0005432966753	29169	Economy	11000.00
0005433679901	29169	Economy	11000.00
0005433679918	29169	Economy	11000.00
0005433679839	29169	Economy	11000.00
0005433679733	29169	Economy	11000.00
0005433679858	29169	Economy	11000.00
0005433679812	29169	Economy	11000.00
0005432966745	29169	Economy	11000.00
0005433679820	29169	Economy	11000.00
0005432966746	29169	Economy	11000.00
0005432966749	29169	Economy	11000.00
0005433679856	29169	Economy	11000.00
0005432966764	29169	Economy	11000.00
0005433679795	29169	Economy	11000.00
0005432966751	29169	Economy	11000.00
0005433679731	29169	Economy	11000.00
0005433680026	29169	Economy	11000.00
0005433679809	29169	Economy	11000.00
0005432966765	29169	Economy	11000.00
0005433679761	29169	Economy	11000.00
0005433679966	29169	Economy	11000.00
0005432966759	29169	Economy	11000.00
0005432966742	29169	Economy	11000.00
0005432966743	29169	Economy	11000.00
0005433679730	29169	Economy	11000.00
0005433679965	29169	Economy	11000.00
0005433679903	29169	Economy	11000.00
0005433687683	29169	Economy	11000.00
0005432966754	29169	Economy	11000.00
0005433679829	29169	Economy	11000.00
0005433679737	29169	Economy	11000.00
0005433680033	29169	Economy	11000.00
0005432966748	29169	Economy	11000.00
0005432966763	29169	Economy	11000.00
0005433679904	29169	Economy	11000.00
0005433679848	29169	Economy	11000.00
0005433679818	29169	Economy	11000.00
0005433679732	29169	Economy	11000.00
0005433679849	29169	Economy	11000.00
0005433679855	29169	Economy	11000.00
0005432966766	29169	Economy	11000.00
0005432966757	29169	Economy	11000.00
0005433679902	29169	Economy	11000.00
0005433679819	29169	Economy	11000.00
0005432005194	29169	Economy	11000.00
0005432966750	29169	Economy	11000.00
0005432966760	29169	Economy	11000.00
0005433679897	29169	Economy	11000.00
0005432966758	29169	Economy	11000.00
0005433679776	29169	Economy	11000.00
0005433679933	29169	Economy	11000.00
0005433633532	9324	Business	132900.00
0005433614134	9324	Business	132900.00
0005433614060	9324	Business	132900.00
0005434272162	9324	Business	132900.00
0005433614091	9324	Business	132900.00
0005433614122	9324	Business	132900.00
0005433633549	9324	Business	132900.00
0005433633558	9324	Business	132900.00
0005432755050	9324	Business	132900.00
0005433577706	9324	Business	132900.00
0005433633537	9324	Business	132900.00
0005433614108	9324	Business	132900.00
0005433614124	9324	Business	132900.00
0005433614064	9324	Business	132900.00
0005433633529	9324	Business	132900.00
0005433614088	9324	Business	132900.00
0005433614079	9324	Business	132900.00
0005433614095	9324	Business	132900.00
0005433633548	9324	Business	132900.00
0005433633553	9324	Business	132900.00
0005433577710	9324	Business	132900.00
0005433614119	9324	Business	132900.00
0005434272163	9324	Business	132900.00
0005433614129	9324	Economy	48700.00
0005433614099	9324	Economy	48700.00
0005433614085	9324	Economy	48700.00
0005433633531	9324	Economy	48700.00
0005433614067	9324	Economy	48700.00
0005433614111	9324	Economy	48700.00
0005433614069	9324	Economy	44300.00
0005433633536	9324	Economy	44300.00
0005433633552	9324	Economy	44300.00
0005433633541	9324	Economy	44300.00
0005433614078	9324	Economy	44300.00
0005433614070	9324	Economy	44300.00
0005433633550	9324	Economy	44300.00
0005433614074	9324	Economy	44300.00
0005433614126	9324	Economy	44300.00
0005433614123	9324	Economy	44300.00
0005433614112	9324	Economy	44300.00
0005434163484	9324	Economy	44300.00
0005433577700	9324	Economy	44300.00
0005433633561	9324	Economy	44300.00
0005433614107	9324	Economy	44300.00
0005433577707	9324	Economy	44300.00
0005434163471	9324	Economy	44300.00
0005434153517	9324	Economy	44300.00
0005432755049	9324	Economy	44300.00
0005433614068	9324	Economy	44300.00
0005432756823	9324	Economy	44300.00
0005433614077	9324	Economy	44300.00
0005433614117	9324	Economy	44300.00
0005433633556	9324	Economy	44300.00
0005433614098	9324	Economy	44300.00
0005434163521	9324	Economy	44300.00
0005433614118	9324	Economy	44300.00
0005432756821	9324	Economy	44300.00
0005434269072	9324	Economy	44300.00
0005433614061	9324	Economy	44300.00
0005433614116	9324	Economy	44300.00
0005433633543	9324	Economy	44300.00
0005433633559	9324	Economy	44300.00
0005433614073	9324	Economy	44300.00
0005433614103	9324	Economy	44300.00
0005433633533	9324	Economy	44300.00
0005433577705	9324	Economy	44300.00
0005433614104	9324	Economy	44300.00
0005433614109	9324	Economy	44300.00
0005433633530	9324	Economy	44300.00
0005433614092	9324	Economy	44300.00
0005433633542	9324	Economy	44300.00
0005433614132	9324	Economy	44300.00
0005433614084	9324	Economy	44300.00
0005433633528	9324	Economy	44300.00
0005433633545	9324	Economy	44300.00
0005433614087	9324	Economy	44300.00
0005433614083	9324	Economy	44300.00
0005433614096	9324	Economy	44300.00
0005433614120	9324	Economy	44300.00
0005434163489	9324	Economy	44300.00
0005433633540	9324	Economy	44300.00
0005433633555	9324	Economy	44300.00
0005433614133	9324	Economy	44300.00
0005433614063	9324	Economy	48700.00
0005433633546	9324	Economy	48700.00
0005433614072	9324	Economy	48700.00
0005433614127	9324	Economy	48700.00
0005433577708	9324	Economy	44300.00
0005433614093	9324	Economy	48700.00
0005434163464	9324	Economy	44300.00
0005433633527	9324	Economy	44300.00
0005433614128	9324	Economy	44300.00
0005433614081	9324	Economy	48700.00
0005433614066	9324	Economy	44300.00
0005433614100	9324	Economy	44300.00
0005433633547	9324	Economy	44300.00
0005433633544	9324	Economy	44300.00
0005433614075	9324	Economy	44300.00
0005433633534	9324	Economy	44300.00
0005433614076	9324	Economy	44300.00
0005433577704	9324	Economy	44300.00
0005433614121	9324	Economy	44300.00
0005433633554	9324	Economy	44300.00
0005434163486	9324	Economy	44300.00
0005433614082	9324	Economy	44300.00
0005433614125	9324	Economy	44300.00
0005433633551	9324	Economy	44300.00
0005434163520	9324	Economy	44300.00
0005433614086	9324	Economy	44300.00
0005434163488	9324	Economy	44300.00
0005433577712	9324	Economy	44300.00
0005434163477	9324	Economy	44300.00
0005433614106	9324	Economy	44300.00
0005433577701	9324	Economy	44300.00
0005434163476	9324	Economy	44300.00
0005433577699	9324	Economy	44300.00
0005433633535	9324	Economy	44300.00
0005433614105	9324	Economy	44300.00
0005433614113	9324	Economy	44300.00
0005433577709	9324	Economy	44300.00
0005432756822	9324	Economy	44300.00
0005432145094	9324	Economy	44300.00
0005433577703	9324	Economy	44300.00
0005434269073	9324	Economy	44300.00
0005433614110	9324	Economy	44300.00
0005432755051	9324	Economy	44300.00
0005433614131	9324	Economy	44300.00
0005433614090	9324	Economy	44300.00
0005433633560	9324	Economy	44300.00
0005433614114	9324	Economy	44300.00
0005433614102	9324	Economy	44300.00
0005434272164	9324	Economy	44300.00
0005433577702	9324	Economy	44300.00
0005433614130	9324	Economy	44300.00
0005432756824	9324	Economy	44300.00
0005433633557	9324	Economy	44300.00
0005433614065	9324	Economy	44300.00
0005433614094	9324	Economy	44300.00
0005433614101	9324	Economy	44300.00
0005433614071	9324	Economy	44300.00
0005434163487	9324	Economy	44300.00
0005433614115	9324	Economy	44300.00
0005433633538	9324	Economy	44300.00
0005433577711	9324	Economy	44300.00
0005433633539	9324	Economy	44300.00
0005433614089	9324	Economy	44300.00
0005432145095	9324	Economy	44300.00
0005433614097	9324	Economy	44300.00
0005434153515	9324	Economy	44300.00
0005433614080	9324	Economy	44300.00
0005433614062	9324	Economy	44300.00
0005434273064	25251	Business	132900.00
0005433577592	25251	Business	132900.00
0005433577633	25251	Business	132900.00
0005433633225	25251	Business	132900.00
0005432755015	25251	Business	132900.00
0005433613642	25251	Business	132900.00
0005433613420	25251	Business	132900.00
0005433633256	25251	Business	132900.00
0005433613657	25251	Business	132900.00
0005433613533	25251	Business	132900.00
0005433633236	25251	Business	132900.00
0005432751469	25251	Business	132900.00
0005433613723	25251	Business	132900.00
0005434163558	25251	Business	132900.00
0005433633234	25251	Business	132900.00
0005433613532	25251	Business	132900.00
0005433577597	25251	Business	132900.00
0005433633435	25251	Business	132900.00
0005433577593	25251	Business	132900.00
0005433613586	25251	Economy	48700.00
0005433613593	25251	Economy	48700.00
0005433613712	25251	Economy	48700.00
0005433633276	25251	Economy	48700.00
0005433613724	25251	Economy	48700.00
0005433613428	25251	Economy	44300.00
0005433613408	25251	Economy	44300.00
0005433613462	25251	Economy	44300.00
0005434163556	25251	Economy	44300.00
0005433613768	25251	Economy	44300.00
0005433613391	25251	Economy	44300.00
0005433613615	25251	Economy	44300.00
0005434272179	25251	Economy	44300.00
0005433577591	25251	Economy	44300.00
0005433613461	25251	Economy	44300.00
0005434163550	25251	Economy	44300.00
0005433613766	25251	Economy	44300.00
0005433613435	25251	Economy	44300.00
0005434163552	25251	Economy	44300.00
0005433613440	25251	Economy	44300.00
0005433613602	25251	Economy	44300.00
0005433633240	25251	Economy	44300.00
0005433613767	25251	Economy	44300.00
0005433613670	25251	Economy	44300.00
0005433613603	25251	Economy	44300.00
0005433613538	25251	Economy	44300.00
0005433613409	25251	Economy	44300.00
0005433613711	25251	Economy	44300.00
0005433613416	25251	Economy	44300.00
0005432755022	25251	Economy	44300.00
0005433613496	25251	Economy	44300.00
0005434152774	25251	Economy	44300.00
0005433613672	25251	Economy	44300.00
0005434152777	25251	Economy	44300.00
0005433633221	25251	Economy	44300.00
0005433613594	25251	Economy	44300.00
0005432751468	25251	Economy	44300.00
0005434163554	25251	Economy	44300.00
0005433613558	25251	Economy	44300.00
0005433613516	25251	Economy	44300.00
0005433613823	25251	Economy	44300.00
0005434163555	25251	Economy	44300.00
0005433633244	25251	Economy	44300.00
0005433633317	25251	Economy	44300.00
0005433613417	25251	Economy	44300.00
0005433613491	25251	Economy	44300.00
0005433633273	25251	Economy	48700.00
0005434152778	25251	Economy	48700.00
0005432755021	25251	Economy	48700.00
0005433577567	25251	Economy	44300.00
0005433613824	25251	Economy	44300.00
0005433613419	25251	Economy	48700.00
0005433633245	25251	Economy	44300.00
0005434163553	25251	Economy	44300.00
0005434272178	25251	Economy	44300.00
0005433613434	25251	Economy	44300.00
0005433613390	25251	Economy	44300.00
0005434163557	25251	Economy	44300.00
0005433613604	25251	Economy	44300.00
0005433613512	25251	Economy	44300.00
0005433633241	25251	Economy	44300.00
0005433613421	25251	Economy	44300.00
0005434163559	25251	Economy	44300.00
0005433613722	25251	Economy	44300.00
0005433613433	25251	Economy	44300.00
0005433633223	25251	Economy	44300.00
0005434152773	25251	Economy	44300.00
0005434163549	25251	Economy	44300.00
0005434163551	25251	Economy	44300.00
0005433613825	25251	Economy	44300.00
0005433633335	25251	Economy	44300.00
0005434152772	25251	Economy	44300.00
0005433633275	25251	Economy	44300.00
0005434152780	25251	Economy	44300.00
0005434273063	25251	Economy	44300.00
0005433613441	25251	Economy	44300.00
0005433633274	25251	Economy	44300.00
0005433613643	25251	Economy	44300.00
0005434152775	25251	Economy	44300.00
0005433613601	25251	Economy	44300.00
0005433633299	25251	Economy	44300.00
0005433613492	25251	Economy	44300.00
0005433613511	25251	Economy	44300.00
0005433633222	25251	Economy	44300.00
0005433633257	25251	Economy	44300.00
0005434152779	25251	Economy	44300.00
0005433613442	25251	Economy	44300.00
0005434152776	25251	Economy	44300.00
0005433633319	25251	Economy	44300.00
0005433633224	25251	Economy	44300.00
0005435787321	4221	Business	193100.00
0005435787322	4221	Business	193100.00
0005435947024	4221	Business	193100.00
0005435787323	4221	Business	193100.00
0005434271279	4221	Economy	64400.00
0005432184929	4221	Economy	64400.00
0005435856136	4221	Economy	64400.00
0005435947001	4221	Economy	64400.00
0005432184931	4221	Economy	64400.00
0005434271278	4221	Economy	64400.00
0005434271277	4221	Economy	64400.00
0005435856142	4221	Economy	64400.00
0005435947074	4221	Economy	64400.00
0005432571265	4221	Economy	64400.00
0005435856131	4221	Economy	64400.00
0005435856130	4221	Economy	64400.00
0005435946998	4221	Economy	64400.00
0005435947029	4221	Economy	64400.00
0005432571264	4221	Economy	70800.00
0005432571263	4221	Economy	64400.00
0005435947002	4221	Economy	64400.00
0005435947008	4221	Economy	64400.00
0005435947023	4221	Economy	64400.00
0005435946997	4221	Economy	64400.00
0005432571261	4221	Economy	64400.00
0005432571262	4221	Economy	64400.00
0005435856137	4221	Economy	64400.00
0005435947009	4221	Economy	64400.00
0005432184930	4221	Economy	64400.00
0005435947054	4221	Economy	64400.00
0005435947063	4221	Economy	64400.00
0005434271287	4221	Economy	64400.00
0005435947064	4221	Economy	64400.00
0005432571260	4221	Economy	64400.00
0005434271280	4221	Economy	64400.00
0005435947156	26570	Business	193100.00
0005432571297	26570	Business	193100.00
0005435947157	26570	Business	193100.00
0005435947150	26570	Business	193100.00
0005435947149	26570	Business	193100.00
0005435856173	26570	Economy	64400.00
0005435947148	26570	Economy	64400.00
0005435947151	26570	Economy	64400.00
0005435947154	26570	Economy	64400.00
0005435947158	26570	Economy	64400.00
0005432571296	26570	Economy	64400.00
0005435947155	26570	Economy	64400.00
0005432571298	26570	Economy	70800.00
0005435856174	26570	Economy	64400.00
0005435856176	26570	Economy	64400.00
0005435947153	26570	Economy	64400.00
0005435856175	26570	Economy	64400.00
0005435947146	26570	Economy	64400.00
0005432571295	26570	Economy	64400.00
0005435947152	26570	Economy	64400.00
0005435947147	26570	Economy	64400.00
0005435947159	26570	Economy	64400.00
0005433568664	307	Business	21500.00
0005433074274	307	Business	21500.00
0005433568607	307	Business	21500.00
0005433568615	307	Business	21500.00
0005433568625	307	Business	21500.00
0005433568649	307	Business	21500.00
0005433568673	307	Business	21500.00
0005433568645	307	Business	21500.00
0005433568648	307	Business	21500.00
0005432947819	307	Business	21500.00
0005433568647	307	Business	21500.00
0005433568624	307	Business	21500.00
0005433568632	307	Business	21500.00
0005433568637	307	Business	21500.00
0005433074294	307	Business	21500.00
0005433074260	307	Business	21500.00
0005433568678	307	Business	21500.00
0005433568675	307	Business	21500.00
0005433568668	307	Business	21500.00
0005432947838	307	Business	21500.00
0005433568618	307	Business	21500.00
0005432238891	307	Business	21500.00
0005433074295	307	Economy	7900.00
0005432238895	307	Economy	7900.00
0005432947855	307	Economy	7900.00
0005433129213	307	Economy	7900.00
0005433568622	307	Economy	7200.00
0005433568676	307	Economy	7200.00
0005433568623	307	Economy	7200.00
0005433568638	307	Economy	7200.00
0005432947839	307	Economy	7200.00
0005432947895	307	Economy	7200.00
0005433568611	307	Economy	7200.00
0005433568662	307	Economy	7200.00
0005433568670	307	Economy	7200.00
0005432947868	307	Economy	7200.00
0005433134076	307	Economy	7200.00
0005432947842	307	Economy	7200.00
0005433568617	307	Economy	7200.00
0005433568609	307	Economy	7200.00
0005432947849	307	Economy	7200.00
0005433568654	307	Economy	7200.00
0005433568616	307	Economy	7200.00
0005432947821	307	Economy	7200.00
0005432947818	307	Economy	7200.00
0005433568642	307	Economy	7200.00
0005432238892	307	Economy	7200.00
0005433074204	307	Economy	7200.00
0005433568665	307	Economy	7200.00
0005432947853	307	Economy	7200.00
0005433074264	307	Economy	7200.00
0005433568657	307	Economy	7200.00
0005433568626	307	Economy	7200.00
0005433568653	307	Economy	7200.00
0005433129216	307	Economy	7200.00
0005433134062	307	Economy	7200.00
0005433568672	307	Economy	7200.00
0005433074203	307	Economy	7200.00
0005433074269	307	Economy	7200.00
0005432238896	307	Economy	7200.00
0005432947869	307	Economy	7200.00
0005433134064	307	Economy	7200.00
0005433568671	307	Economy	7200.00
0005433568628	307	Economy	7200.00
0005433129212	307	Economy	7200.00
0005432947795	307	Economy	7200.00
0005432238894	307	Economy	7200.00
0005433568659	307	Economy	7200.00
0005433568679	307	Economy	7200.00
0005433568658	307	Economy	7200.00
0005432947777	307	Economy	7200.00
0005433074291	307	Economy	7200.00
0005433568636	307	Economy	7200.00
0005433568669	307	Economy	7200.00
0005432948006	307	Economy	7200.00
0005433568652	307	Economy	7200.00
0005433568639	307	Economy	7900.00
0005432947765	307	Economy	7900.00
0005432947850	307	Economy	7900.00
0005433568650	307	Economy	7200.00
0005432238893	307	Economy	7200.00
0005433568651	307	Economy	7200.00
0005433074218	307	Economy	7200.00
0005433568619	307	Economy	7900.00
0005433568629	307	Economy	7200.00
0005433568621	307	Economy	7200.00
0005433568612	307	Economy	7200.00
0005433568663	307	Economy	7200.00
0005433568633	307	Economy	7200.00
0005433568634	307	Economy	7200.00
0005432947808	307	Economy	7200.00
0005433568640	307	Economy	7200.00
0005432947854	307	Economy	7200.00
0005433568677	307	Economy	7200.00
0005433568631	307	Economy	7200.00
0005432948005	307	Economy	7200.00
0005433568646	307	Economy	7200.00
0005433568613	307	Economy	7200.00
0005433568666	307	Economy	7200.00
0005433074292	307	Economy	7200.00
0005433074351	307	Economy	7200.00
0005433568606	307	Economy	7200.00
0005433568674	307	Economy	7200.00
0005433568660	307	Economy	7200.00
0005433568656	307	Economy	7200.00
0005432947817	307	Economy	7200.00
0005433568610	307	Economy	7200.00
0005433074354	307	Economy	7200.00
0005432947910	307	Economy	7200.00
0005433134077	307	Economy	7200.00
0005433568661	307	Economy	7200.00
0005433568620	307	Economy	7200.00
0005433568614	307	Economy	7200.00
0005432947894	307	Economy	7200.00
0005432947979	307	Economy	7200.00
0005433129217	307	Economy	7200.00
0005433074262	307	Economy	7200.00
0005432238890	307	Economy	7200.00
0005433568630	307	Economy	7200.00
0005433568641	307	Economy	7200.00
0005433074293	307	Economy	7200.00
0005433568643	307	Economy	7200.00
0005433568667	307	Economy	7200.00
0005432947856	307	Economy	7200.00
0005433568644	307	Economy	7200.00
0005433074288	307	Economy	7200.00
0005433134056	307	Economy	7200.00
0005433074273	307	Economy	7200.00
0005433568627	307	Economy	7200.00
0005433568655	307	Economy	7200.00
0005433568635	307	Economy	7200.00
0005433074352	307	Economy	7200.00
0005433568608	307	Economy	7200.00
0005433568022	11583	Business	21500.00
0005433074513	11583	Business	21500.00
0005432948161	11583	Business	21500.00
0005433568112	11583	Business	21500.00
0005433134103	11583	Business	21500.00
0005433131675	11583	Business	21500.00
0005433134106	11583	Business	21500.00
0005433074495	11583	Business	21500.00
0005433074496	11583	Business	21500.00
0005433074494	11583	Business	21500.00
0005432948158	11583	Business	21500.00
0005432948179	11583	Business	21500.00
0005433074508	11583	Business	21500.00
0005432948154	11583	Business	21500.00
0005433074518	11583	Business	21500.00
0005433131676	11583	Business	21500.00
0005433074515	11583	Economy	7900.00
0005432192296	11583	Economy	7900.00
0005432948167	11583	Economy	7900.00
0005433134104	11583	Economy	7900.00
0005432948171	11583	Economy	7200.00
0005433568052	11583	Economy	7200.00
0005432948153	11583	Economy	7200.00
0005433074498	11583	Economy	7200.00
0005433568118	11583	Economy	7200.00
0005432948150	11583	Economy	7200.00
0005433568084	11583	Economy	7200.00
0005432948149	11583	Economy	7200.00
0005433568119	11583	Economy	7200.00
0005433074499	11583	Economy	7200.00
0005433568049	11583	Economy	7200.00
0005433568042	11583	Economy	7200.00
0005432948172	11583	Economy	7200.00
0005433568017	11583	Economy	7200.00
0005432948176	11583	Economy	7200.00
0005432948143	11583	Economy	7200.00
0005433074490	11583	Economy	7200.00
0005432948156	11583	Economy	7200.00
0005433131677	11583	Economy	7200.00
0005432948166	11583	Economy	7200.00
0005432948140	11583	Economy	7200.00
0005433568038	11583	Economy	7200.00
0005433074491	11583	Economy	7200.00
0005433074489	11583	Economy	7200.00
0005432948162	11583	Economy	7200.00
0005432948142	11583	Economy	7200.00
0005433074507	11583	Economy	7200.00
0005432948165	11583	Economy	7200.00
0005432948139	11583	Economy	7200.00
0005432948164	11583	Economy	7200.00
0005433074514	11583	Economy	7200.00
0005433074517	11583	Economy	7200.00
0005432948168	11583	Economy	7200.00
0005433568025	11583	Economy	7200.00
0005432948155	11583	Economy	7200.00
0005432948144	11583	Economy	7200.00
0005433131674	11583	Economy	7200.00
0005432948160	11583	Economy	7200.00
0005433568039	11583	Economy	7200.00
0005433074501	11583	Economy	7900.00
0005433074500	11583	Economy	7900.00
0005432948157	11583	Economy	7900.00
0005433074503	11583	Economy	7900.00
0005433074504	11583	Economy	7200.00
0005432948148	11583	Economy	7200.00
0005433134107	11583	Economy	7200.00
0005433074509	11583	Economy	7200.00
0005433074493	11583	Economy	7200.00
0005432948178	11583	Economy	7200.00
0005433568086	11583	Economy	7200.00
0005433074492	11583	Economy	7200.00
0005433568069	11583	Economy	7200.00
0005432948173	11583	Economy	7200.00
0005433568026	11583	Economy	7200.00
0005433568024	11583	Economy	7200.00
0005433074512	11583	Economy	7200.00
0005433074511	11583	Economy	7200.00
0005433074510	11583	Economy	7200.00
0005432192297	11583	Economy	7200.00
0005432948170	11583	Economy	7200.00
0005432948163	11583	Economy	7200.00
0005432948147	11583	Economy	7200.00
0005432948177	11583	Economy	7200.00
0005432948180	11583	Economy	7200.00
0005432948174	11583	Economy	7200.00
0005433568113	11583	Economy	7200.00
0005433074505	11583	Economy	7200.00
0005433568102	11583	Economy	7200.00
0005432948152	11583	Economy	7200.00
0005433074516	11583	Economy	7200.00
0005432192298	11583	Economy	7200.00
0005433074497	11583	Economy	7200.00
0005432948151	11583	Economy	7200.00
0005433074488	11583	Economy	7200.00
0005432948145	11583	Economy	7200.00
0005433568064	11583	Economy	7200.00
0005433568050	11583	Economy	7200.00
0005433074502	11583	Economy	7200.00
0005432948141	11583	Economy	7200.00
0005433074506	11583	Economy	7200.00
0005432948146	11583	Economy	7200.00
0005432948159	11583	Economy	7200.00
0005433568021	11583	Economy	7200.00
0005433134105	11583	Economy	7200.00
0005432948169	11583	Economy	7200.00
0005432948175	11583	Economy	7200.00
0005433817444	9973	Economy	6300.00
0005434732945	9973	Economy	6300.00
0005433817442	9973	Economy	6300.00
0005434732929	9973	Economy	6300.00
0005433817443	9973	Economy	6300.00
0005434732922	9973	Economy	6300.00
0005433817445	9973	Economy	6300.00
0005433817416	13891	Economy	6300.00
0005434732955	13891	Economy	6300.00
0005433817406	13891	Economy	6300.00
0005434732958	13891	Economy	6300.00
0005433817412	13891	Economy	6300.00
0005433817407	13891	Economy	6300.00
0005434732956	13891	Economy	6300.00
0005433817415	13891	Economy	6300.00
0005433817417	13891	Economy	6300.00
0005434732957	13891	Economy	6300.00
0005433817413	13891	Economy	6300.00
0005433817405	13891	Economy	6300.00
0005433434379	2376	Business	184500.00
0005432655449	2376	Business	184500.00
0005433753809	2376	Business	184500.00
0005432984504	2376	Business	184500.00
0005432984547	2376	Business	184500.00
0005433753840	2376	Business	184500.00
0005433753833	2376	Business	184500.00
0005435982002	2376	Business	184500.00
0005433753837	2376	Business	184500.00
0005433753819	2376	Business	184500.00
0005435981976	2376	Business	184500.00
0005435981968	2376	Business	184500.00
0005432869434	2376	Business	184500.00
0005432226014	2376	Business	184500.00
0005433766614	2376	Business	184500.00
0005435981983	2376	Business	184500.00
0005435982004	2376	Business	184500.00
0005433434294	2376	Business	184500.00
0005433753805	2376	Business	184500.00
0005433753806	2376	Business	184500.00
0005433753825	2376	Business	184500.00
0005435981977	2376	Business	184500.00
0005432984505	2376	Business	184500.00
0005433753803	2376	Business	184500.00
0005433766612	2376	Economy	67700.00
0005433753804	2376	Business	184500.00
0005435982006	2376	Economy	67700.00
0005433753832	2376	Economy	67700.00
0005435982012	2376	Economy	67700.00
0005435981981	2376	Economy	61500.00
0005432226013	2376	Economy	61500.00
0005433764665	2376	Economy	61500.00
0005433753807	2376	Economy	61500.00
0005435981963	2376	Economy	61500.00
0005432984548	2376	Economy	61500.00
0005432300221	2376	Economy	61500.00
0005432655459	2376	Economy	61500.00
0005433753798	2376	Economy	61500.00
0005432984538	2376	Economy	61500.00
0005433753846	2376	Economy	61500.00
0005435981979	2376	Economy	61500.00
0005433434227	2376	Economy	61500.00
0005433753808	2376	Economy	61500.00
0005433434189	2376	Economy	61500.00
0005432655454	2376	Economy	61500.00
0005432984629	2376	Economy	61500.00
0005433753827	2376	Economy	61500.00
0005432655456	2376	Economy	61500.00
0005432984638	2376	Economy	61500.00
0005432984515	2376	Economy	61500.00
0005433434295	2376	Economy	61500.00
0005433434201	2376	Economy	61500.00
0005433753830	2376	Economy	61500.00
0005433753853	2376	Economy	61500.00
0005433434361	2376	Economy	61500.00
0005433753838	2376	Economy	61500.00
0005432655450	2376	Economy	61500.00
0005435981973	2376	Economy	61500.00
0005433434228	2376	Economy	61500.00
0005433766613	2376	Economy	61500.00
0005435982001	2376	Economy	61500.00
0005433434253	2376	Economy	61500.00
0005432300222	2376	Economy	61500.00
0005432655452	2376	Economy	61500.00
0005435981992	2376	Economy	61500.00
0005433753813	2376	Economy	61500.00
0005433753821	2376	Economy	61500.00
0005433434348	2376	Economy	61500.00
0005435981997	2376	Economy	61500.00
0005432984649	2376	Economy	61500.00
0005435981984	2376	Economy	61500.00
0005434731100	2376	Economy	61500.00
0005433753826	2376	Economy	61500.00
0005433753814	2376	Economy	61500.00
0005433753811	2376	Economy	61500.00
0005432655457	2376	Economy	61500.00
0005433753845	2376	Economy	61500.00
0005435981971	2376	Economy	61500.00
0005433434362	2376	Economy	61500.00
0005432655453	2376	Economy	61500.00
0005433764664	2376	Economy	61500.00
0005433753797	2376	Economy	61500.00
0005435982007	2376	Economy	61500.00
0005435982000	2376	Economy	61500.00
0005433434290	2376	Economy	61500.00
0005435981975	2376	Economy	61500.00
0005435981962	2376	Economy	61500.00
0005432984535	2376	Economy	61500.00
0005433753828	2376	Economy	61500.00
0005435982010	2376	Economy	61500.00
0005433753822	2376	Economy	61500.00
0005435981969	2376	Economy	61500.00
0005432984582	2376	Economy	61500.00
0005433753839	2376	Economy	61500.00
0005435982008	2376	Economy	61500.00
0005435981966	2376	Economy	61500.00
0005435981970	2376	Economy	61500.00
0005432655451	2376	Economy	61500.00
0005435981996	2376	Economy	61500.00
0005433753851	2376	Economy	61500.00
0005432226011	2376	Economy	61500.00
0005433753850	2376	Economy	61500.00
0005433434254	2376	Economy	61500.00
0005433753835	2376	Economy	61500.00
0005435981982	2376	Economy	61500.00
0005433753823	2376	Economy	61500.00
0005433753834	2376	Economy	61500.00
0005433434240	2376	Economy	61500.00
0005433753818	2376	Economy	61500.00
0005433434188	2376	Economy	61500.00
0005435981972	2376	Economy	61500.00
0005435981999	2376	Economy	61500.00
0005432300223	2376	Economy	67700.00
0005435981990	2376	Economy	61500.00
0005433753817	2376	Economy	61500.00
0005432984652	2376	Economy	67700.00
0005435981967	2376	Economy	61500.00
0005433434229	2376	Economy	61500.00
0005435981980	2376	Economy	61500.00
0005432655455	2376	Economy	61500.00
0005433753847	2376	Economy	61500.00
0005433753848	2376	Economy	61500.00
0005433753849	2376	Economy	61500.00
0005435981994	2376	Economy	61500.00
0005433753836	2376	Economy	61500.00
0005432869417	2376	Economy	61500.00
0005432226012	2376	Economy	61500.00
0005435981989	2376	Economy	61500.00
0005435981986	2376	Economy	61500.00
0005435981964	2376	Economy	61500.00
0005433753812	2376	Economy	61500.00
0005433766611	2376	Economy	61500.00
0005432655458	2376	Economy	61500.00
0005433434200	2376	Economy	61500.00
0005432984607	2376	Economy	61500.00
0005433753816	2376	Economy	61500.00
0005435981993	2376	Economy	61500.00
0005435981978	2376	Economy	61500.00
0005433434226	2376	Economy	61500.00
0005435982011	2376	Economy	61500.00
0005433753852	2376	Economy	61500.00
0005433753829	2376	Economy	61500.00
0005435981995	2376	Economy	61500.00
0005432984554	2376	Economy	61500.00
0005433753810	2376	Economy	61500.00
0005433753844	2376	Economy	61500.00
0005432984593	2376	Economy	61500.00
0005433753841	2376	Economy	61500.00
0005433753815	2376	Economy	61500.00
0005432300225	2376	Economy	61500.00
0005435981974	2376	Economy	61500.00
0005432984619	2376	Economy	61500.00
0005432984653	2376	Economy	61500.00
0005432984565	2376	Economy	61500.00
0005432984592	2376	Economy	61500.00
0005435981965	2376	Economy	61500.00
0005433753842	2376	Economy	61500.00
0005433753831	2376	Economy	61500.00
0005433753799	2376	Economy	61500.00
0005435982013	2376	Economy	61500.00
0005433434239	2376	Economy	61500.00
0005432984620	2376	Economy	61500.00
0005432300224	2376	Economy	61500.00
0005433753800	2376	Economy	61500.00
0005433764666	2376	Economy	61500.00
0005435982005	2376	Economy	61500.00
0005435981987	2376	Economy	61500.00
0005432869429	2376	Economy	61500.00
0005433753824	2376	Economy	61500.00
0005433753820	2376	Economy	61500.00
0005435981998	2376	Economy	61500.00
0005433753802	2376	Economy	61500.00
0005433753843	2376	Economy	61500.00
0005435981985	2376	Economy	61500.00
0005435982003	2376	Economy	61500.00
0005433753801	2376	Economy	61500.00
0005435982009	2376	Economy	61500.00
0005435981988	2376	Economy	61500.00
0005434731097	2376	Economy	61500.00
0005432984536	2376	Economy	61500.00
0005435981991	2376	Economy	61500.00
0005432226015	2376	Economy	61500.00
0005432226010	2376	Economy	61500.00
0005433753433	26163	Business	184500.00
0005435981571	26163	Business	184500.00
0005433434494	26163	Business	184500.00
0005435981512	26163	Business	184500.00
0005432984841	26163	Business	184500.00
0005432984840	26163	Business	184500.00
0005432984839	26163	Business	184500.00
0005434731141	26163	Business	184500.00
0005433434486	26163	Business	184500.00
0005433434480	26163	Business	184500.00
0005433753289	26163	Business	184500.00
0005435981621	26163	Business	184500.00
0005432984855	26163	Business	184500.00
0005432655328	26163	Business	184500.00
0005433753548	26163	Business	184500.00
0005432984860	26163	Business	184500.00
0005432984848	26163	Business	184500.00
0005435981639	26163	Business	184500.00
0005433753562	26163	Business	184500.00
0005432869475	26163	Business	184500.00
0005435981617	26163	Economy	67700.00
0005434731139	26163	Economy	67700.00
0005433753298	26163	Economy	61500.00
0005432049437	26163	Economy	61500.00
0005432869476	26163	Economy	61500.00
0005433753509	26163	Economy	61500.00
0005433434492	26163	Economy	61500.00
0005435981603	26163	Economy	61500.00
0005433753259	26163	Economy	61500.00
0005433434469	26163	Economy	61500.00
0005435981618	26163	Economy	61500.00
0005432984847	26163	Economy	61500.00
0005433434471	26163	Economy	61500.00
0005433753425	26163	Economy	61500.00
0005433753327	26163	Economy	61500.00
0005435981539	26163	Economy	61500.00
0005432984846	26163	Economy	61500.00
0005432984857	26163	Economy	61500.00
0005434731140	26163	Economy	61500.00
0005433434470	26163	Economy	61500.00
0005435981531	26163	Economy	61500.00
0005435981698	26163	Economy	61500.00
0005433434487	26163	Economy	61500.00
0005433434479	26163	Economy	61500.00
0005435981521	26163	Economy	61500.00
0005433753321	26163	Economy	61500.00
0005433753322	26163	Economy	61500.00
0005433434484	26163	Economy	61500.00
0005435981684	26163	Economy	61500.00
0005432984845	26163	Economy	61500.00
0005433434481	26163	Economy	61500.00
0005433434496	26163	Economy	61500.00
0005435981540	26163	Economy	61500.00
0005433753380	26163	Economy	61500.00
0005435981590	26163	Economy	61500.00
0005433434478	26163	Economy	61500.00
0005433753411	26163	Economy	61500.00
0005432869477	26163	Economy	61500.00
0005432984833	26163	Economy	61500.00
0005433753428	26163	Economy	61500.00
0005432049439	26163	Economy	61500.00
0005435981735	26163	Economy	61500.00
0005433753508	26163	Economy	61500.00
0005432984850	26163	Economy	61500.00
0005432984842	26163	Economy	61500.00
0005432984861	26163	Economy	61500.00
0005433434483	26163	Economy	61500.00
0005433434491	26163	Economy	61500.00
0005432049438	26163	Economy	61500.00
0005432051105	26163	Economy	61500.00
0005433753262	26163	Economy	61500.00
0005435981578	26163	Economy	61500.00
0005432984854	26163	Economy	61500.00
0005433753366	26163	Economy	61500.00
0005432655327	26163	Economy	61500.00
0005435981658	26163	Economy	61500.00
0005432655351	26163	Economy	61500.00
0005433434472	26163	Economy	61500.00
0005432984856	26163	Economy	61500.00
0005433753450	26163	Economy	61500.00
0005435981549	26163	Economy	61500.00
0005432984844	26163	Economy	61500.00
0005433753313	26163	Economy	61500.00
0005435981530	26163	Economy	61500.00
0005433753246	26163	Economy	61500.00
0005432984837	26163	Economy	61500.00
0005432049436	26163	Economy	61500.00
0005432984849	26163	Economy	61500.00
0005433434477	26163	Economy	61500.00
0005433753286	26163	Economy	61500.00
0005435981622	26163	Economy	61500.00
0005433753506	26163	Economy	61500.00
0005432984852	26163	Economy	61500.00
0005435981555	26163	Economy	61500.00
0005433753363	26163	Economy	61500.00
0005435981755	26163	Economy	61500.00
0005435981681	26163	Economy	61500.00
0005435981657	26163	Economy	61500.00
0005432051106	26163	Economy	61500.00
0005432984836	26163	Economy	61500.00
0005432984859	26163	Economy	61500.00
0005432984838	26163	Economy	61500.00
0005433753561	26163	Economy	61500.00
0005435981689	26163	Economy	61500.00
0005435981516	26163	Economy	61500.00
0005433753431	26163	Economy	67700.00
0005435981709	26163	Economy	61500.00
0005432984862	26163	Economy	67700.00
0005433766576	26163	Economy	61500.00
0005435981640	26163	Economy	61500.00
0005433753304	26163	Economy	67700.00
0005432984853	26163	Economy	61500.00
0005432869474	26163	Economy	61500.00
0005432984863	26163	Economy	61500.00
0005435981632	26163	Economy	61500.00
0005435981596	26163	Economy	61500.00
0005435981715	26163	Economy	61500.00
0005432984864	26163	Economy	61500.00
0005435981714	26163	Economy	61500.00
0005433753285	26163	Economy	61500.00
0005432984843	26163	Economy	61500.00
0005432655331	26163	Economy	61500.00
0005433434490	26163	Economy	61500.00
0005433434493	26163	Economy	61500.00
0005432984835	26163	Economy	61500.00
0005435981656	26163	Economy	61500.00
0005432984858	26163	Economy	61500.00
0005435981662	26163	Economy	61500.00
0005432984865	26163	Economy	61500.00
0005435981581	26163	Economy	61500.00
0005433434488	26163	Economy	61500.00
0005432655353	26163	Economy	61500.00
0005433753306	26163	Economy	61500.00
0005432984851	26163	Economy	61500.00
0005433434485	26163	Economy	61500.00
0005433753310	26163	Economy	61500.00
0005435981703	26163	Economy	61500.00
0005433434474	26163	Economy	61500.00
0005433753290	26163	Economy	61500.00
0005435981548	26163	Economy	61500.00
0005432984834	26163	Economy	61500.00
0005433753507	26163	Economy	61500.00
0005433753426	26163	Economy	61500.00
0005433434495	26163	Economy	61500.00
0005432869478	26163	Economy	61500.00
0005435981675	26163	Economy	61500.00
0005433434489	26163	Economy	61500.00
0005432869473	26163	Economy	61500.00
0005432051107	26163	Economy	61500.00
0005433434475	26163	Economy	61500.00
0005432984832	26163	Economy	61500.00
0005433753299	26163	Economy	61500.00
0005433753307	26163	Economy	61500.00
0005433753344	26163	Economy	61500.00
0005433434482	26163	Economy	61500.00
0005433434476	26163	Economy	61500.00
0005434731142	26163	Economy	61500.00
0005433753432	26163	Economy	61500.00
0005433753263	26163	Economy	61500.00
0005432655326	26163	Economy	61500.00
0005433434473	26163	Economy	61500.00
0005433753427	26163	Economy	61500.00
0005433150858	1526	Business	38900.00
0005432267849	1526	Business	38900.00
0005433764643	1526	Business	38900.00
0005433151102	1526	Business	38900.00
0005434374362	1526	Business	38900.00
0005434374311	1526	Business	38900.00
0005434374336	1526	Business	38900.00
0005434374360	1526	Business	38900.00
0005434374342	1526	Business	38900.00
0005433150830	1526	Economy	13000.00
0005434374337	1526	Economy	13000.00
0005433150916	1526	Economy	13000.00
0005434374351	1526	Economy	13000.00
0005433150995	1526	Economy	13000.00
0005434374354	1526	Economy	13000.00
0005433151084	1526	Economy	13000.00
0005434374340	1526	Economy	13000.00
0005433150915	1526	Economy	13000.00
0005433461573	1526	Economy	13000.00
0005434374352	1526	Economy	13000.00
0005434374334	1526	Economy	13000.00
0005433150803	1526	Economy	13000.00
0005433150923	1526	Economy	13000.00
0005434374327	1526	Economy	13000.00
0005434374318	1526	Economy	13000.00
0005433150895	1526	Economy	13000.00
0005433150883	1526	Economy	13000.00
0005433150848	1526	Economy	13000.00
0005433150977	1526	Economy	13000.00
0005433150948	1526	Economy	13000.00
0005434374328	1526	Economy	13000.00
0005434374341	1526	Economy	13000.00
0005432267848	1526	Economy	13000.00
0005433151083	1526	Economy	13000.00
0005434374349	1526	Economy	13000.00
0005434374331	1526	Economy	13000.00
0005433461572	1526	Economy	13000.00
0005434374347	1526	Economy	13000.00
0005434374353	1526	Economy	13000.00
0005434374357	1526	Economy	13000.00
0005434374312	1526	Economy	14300.00
0005434374333	1526	Economy	14300.00
0005433150933	1526	Economy	14300.00
0005434374339	1526	Economy	14300.00
0005433931424	1526	Economy	14300.00
0005434374358	1526	Economy	13000.00
0005434374324	1526	Economy	13000.00
0005434374348	1526	Economy	13000.00
0005433931420	1526	Economy	13000.00
0005433460421	1526	Economy	13000.00
0005433150894	1526	Economy	13000.00
0005433150889	1526	Economy	13000.00
0005434374355	1526	Economy	13000.00
0005433931413	1526	Economy	13000.00
0005434374329	1526	Economy	13000.00
0005433151101	1526	Economy	13000.00
0005433150823	1526	Economy	13000.00
0005434374346	1526	Economy	13000.00
0005432267847	1526	Economy	13000.00
0005434374359	1526	Economy	13000.00
0005433150909	1526	Economy	13000.00
0005433150834	1526	Economy	13000.00
0005433150833	1526	Economy	13000.00
0005433151010	1526	Economy	13000.00
0005434374314	1526	Economy	13000.00
0005433150816	1526	Economy	13000.00
0005434374343	1526	Economy	13000.00
0005434374332	1526	Economy	13000.00
0005433150947	1526	Economy	13000.00
0005434374317	1526	Economy	13000.00
0005432267850	1526	Economy	13000.00
0005433150824	1526	Economy	13000.00
0005434374322	1526	Economy	13000.00
0005434374350	1526	Economy	13000.00
0005434374361	1526	Economy	13000.00
0005433150849	1526	Economy	13000.00
0005434374330	1526	Economy	13000.00
0005434374310	1526	Economy	13000.00
0005434374323	1526	Economy	13000.00
0005434374345	1526	Economy	13000.00
0005434374321	1526	Economy	13000.00
0005434374338	1526	Economy	13000.00
0005434374313	1526	Economy	13000.00
0005433150804	1526	Economy	13000.00
0005434374344	1526	Economy	13000.00
0005434374320	1526	Economy	13000.00
0005433150988	1526	Economy	13000.00
0005434374325	1526	Economy	13000.00
0005434374316	1526	Economy	13000.00
0005434374319	1526	Economy	13000.00
0005433150877	1526	Economy	13000.00
0005434374326	1526	Economy	13000.00
0005434374315	1526	Economy	13000.00
0005433931414	1526	Economy	13000.00
0005433150892	1526	Economy	13000.00
0005433150949	1526	Economy	13000.00
0005433931427	1526	Economy	13000.00
0005433150891	1526	Economy	13000.00
0005432267846	1526	Economy	13000.00
0005432267845	1526	Economy	13000.00
0005433150835	1526	Economy	13000.00
0005434374335	1526	Economy	13000.00
0005433150807	1526	Economy	13000.00
0005433150868	1526	Economy	13000.00
0005434374356	1526	Economy	13000.00
0005433460420	1526	Economy	13000.00
0005433931444	20116	Business	38900.00
0005433151174	20116	Business	38900.00
0005433151171	20116	Business	38900.00
0005434373927	20116	Business	38900.00
0005433151158	20116	Business	38900.00
0005434374063	20116	Business	38900.00
0005433151179	20116	Business	38900.00
0005433151150	20116	Business	38900.00
0005433151146	20116	Business	38900.00
0005434373869	20116	Economy	13000.00
0005434029638	20116	Economy	13000.00
0005433151161	20116	Economy	13000.00
0005433151147	20116	Economy	13000.00
0005433151155	20116	Economy	13000.00
0005434373922	20116	Economy	13000.00
0005433151145	20116	Economy	13000.00
0005434029640	20116	Economy	13000.00
0005434373989	20116	Economy	13000.00
0005434373846	20116	Economy	13000.00
0005433151164	20116	Economy	13000.00
0005433151154	20116	Economy	13000.00
0005434374015	20116	Economy	13000.00
0005434374076	20116	Economy	13000.00
0005434029639	20116	Economy	13000.00
0005434373999	20116	Economy	13000.00
0005433764664	20116	Economy	13000.00
0005434374075	20116	Economy	13000.00
0005433151165	20116	Economy	13000.00
0005434373965	20116	Economy	13000.00
0005433764665	20116	Economy	13000.00
0005432056272	20116	Economy	13000.00
0005434373870	20116	Economy	13000.00
0005433151162	20116	Economy	13000.00
0005433151156	20116	Economy	13000.00
0005433764666	20116	Economy	13000.00
0005433151167	20116	Economy	14300.00
0005433151151	20116	Economy	14300.00
0005434373973	20116	Economy	14300.00
0005434373889	20116	Economy	14300.00
0005433151148	20116	Economy	13000.00
0005433151163	20116	Economy	13000.00
0005434374074	20116	Economy	13000.00
0005434374031	20116	Economy	13000.00
0005433151176	20116	Economy	13000.00
0005433151170	20116	Economy	13000.00
0005434374027	20116	Economy	13000.00
0005433151172	20116	Economy	13000.00
0005434374000	20116	Economy	13000.00
0005433151178	20116	Economy	13000.00
0005434374064	20116	Economy	13000.00
0005434373874	20116	Economy	13000.00
0005433151177	20116	Economy	13000.00
0005434373988	20116	Economy	13000.00
0005434374056	20116	Economy	13000.00
0005434373928	20116	Economy	13000.00
0005433151168	20116	Economy	13000.00
0005434374067	20116	Economy	13000.00
0005432056271	20116	Economy	13000.00
0005434374055	20116	Economy	13000.00
0005433931442	20116	Economy	13000.00
0005434373868	20116	Economy	13000.00
0005433151152	20116	Economy	13000.00
0005433151173	20116	Economy	13000.00
0005434373967	20116	Economy	13000.00
0005434374026	20116	Economy	13000.00
0005434374032	20116	Economy	13000.00
0005434373873	20116	Economy	13000.00
0005433151166	20116	Economy	13000.00
0005434373906	20116	Economy	13000.00
0005433151153	20116	Economy	13000.00
0005433151157	20116	Economy	13000.00
0005433931443	20116	Economy	13000.00
0005434374010	20116	Economy	13000.00
0005434373964	20116	Economy	13000.00
0005433151169	20116	Economy	13000.00
0005434374041	20116	Economy	13000.00
0005433151160	20116	Economy	13000.00
0005434373985	20116	Economy	13000.00
0005433151149	20116	Economy	13000.00
0005434373966	20116	Economy	13000.00
0005433151175	20116	Economy	13000.00
0005434373987	20116	Economy	13000.00
0005433151159	20116	Economy	13000.00
0005432056273	20116	Economy	13000.00
0005432424150	519	Business	27500.00
0005432282811	519	Business	27500.00
0005432424157	519	Business	27500.00
0005432282816	519	Business	27500.00
0005432282812	519	Business	27500.00
0005432424110	519	Business	27500.00
0005432282817	519	Business	27500.00
0005432424122	519	Business	27500.00
0005432424155	519	Business	27500.00
0005432424159	519	Business	27500.00
0005432424139	519	Business	27500.00
0005432424158	519	Business	27500.00
0005432424152	519	Business	27500.00
0005432424113	519	Economy	10100.00
0005432424148	519	Economy	9200.00
0005432282815	519	Economy	9200.00
0005432424117	519	Economy	9200.00
0005432424109	519	Economy	9200.00
0005432282813	519	Economy	9200.00
0005432424156	519	Economy	9200.00
0005432424137	519	Economy	9200.00
0005432424119	519	Economy	9200.00
0005432424098	519	Economy	9200.00
0005432424100	519	Economy	9200.00
0005432424129	519	Economy	9200.00
0005432424125	519	Economy	9200.00
0005432424105	519	Economy	9200.00
0005432424112	519	Economy	9200.00
0005432424134	519	Economy	9200.00
0005432424131	519	Economy	9200.00
0005432424147	519	Economy	9200.00
0005432424135	519	Economy	9200.00
0005432424128	519	Economy	9200.00
0005432424121	519	Economy	9200.00
0005432424107	519	Economy	10100.00
0005432424145	519	Economy	10100.00
0005432424124	519	Economy	10100.00
0005432424143	519	Economy	9200.00
0005432424116	519	Economy	9200.00
0005432424154	519	Economy	9200.00
0005432424151	519	Economy	10100.00
0005432424140	519	Economy	9200.00
0005432282814	519	Economy	9200.00
0005432424115	519	Economy	9200.00
0005432424132	519	Economy	9200.00
0005432424141	519	Economy	9200.00
0005432424104	519	Economy	9200.00
0005432424108	519	Economy	9200.00
0005432424130	519	Economy	9200.00
0005432424127	519	Economy	9200.00
0005432424123	519	Economy	9200.00
0005432424146	519	Economy	9200.00
0005432424136	519	Economy	9200.00
0005432424126	519	Economy	9200.00
0005432424144	519	Economy	9200.00
0005432424111	519	Economy	9200.00
0005432424114	519	Economy	9200.00
0005432424153	519	Economy	9200.00
0005432424101	519	Economy	9200.00
0005432424102	519	Economy	9200.00
0005432424099	519	Economy	9200.00
0005432424138	519	Economy	9200.00
0005432424142	519	Economy	9200.00
0005432424118	519	Economy	9200.00
0005432424133	519	Economy	9200.00
0005432424106	519	Economy	9200.00
0005432424120	519	Economy	9200.00
0005432424149	519	Economy	9200.00
0005432424103	519	Economy	9200.00
0005432302303	12901	Business	27500.00
0005432302305	12901	Business	27500.00
0005432302304	12901	Economy	9200.00
0005432423730	12887	Business	27500.00
0005432423722	12887	Business	27500.00
0005432423729	12887	Business	27500.00
0005432423660	12887	Economy	10100.00
0005432423697	12887	Economy	10100.00
0005432423613	12887	Economy	9200.00
0005432423735	12887	Economy	9200.00
0005432423649	12887	Economy	9200.00
0005432423669	12887	Economy	9200.00
0005432423724	12887	Economy	9200.00
0005432423689	12887	Economy	9200.00
0005432423706	12887	Economy	9200.00
0005432423614	12887	Economy	9200.00
0005432423762	12887	Economy	9200.00
0005432423690	12887	Economy	9200.00
0005432423636	12887	Economy	9200.00
0005432423681	12887	Economy	10100.00
0005432423668	12887	Economy	9200.00
0005432423631	12887	Economy	9200.00
0005432423721	12887	Economy	9200.00
0005432423731	12887	Economy	9200.00
0005432423627	12887	Economy	9200.00
0005432423680	12887	Economy	9200.00
0005432423707	12887	Economy	9200.00
0005432423628	12887	Economy	9200.00
0005432423653	12887	Economy	9200.00
0005432423748	12887	Economy	9200.00
0005432423723	12887	Economy	9200.00
0005432423632	12887	Economy	9200.00
0005434023206	435	Business	24500.00
0005434023241	435	Business	24500.00
0005434023263	435	Business	24500.00
0005434023213	435	Business	24500.00
0005434023256	435	Business	24500.00
0005433057275	435	Business	24500.00
0005434023239	435	Business	24500.00
0005434023217	435	Business	24500.00
0005434023240	435	Business	24500.00
0005434023249	435	Business	24500.00
0005434023209	435	Business	24500.00
0005434023259	435	Business	24500.00
0005434023211	435	Business	24500.00
0005434023246	435	Business	24500.00
0005434023204	435	Business	24500.00
0005433057176	435	Business	24500.00
0005434023230	435	Business	24500.00
0005433929556	435	Business	24500.00
0005434023244	435	Business	24500.00
0005434023254	435	Economy	9000.00
0005434023225	435	Economy	9000.00
0005432235582	435	Economy	8200.00
0005434031986	435	Economy	8200.00
0005433057336	435	Economy	8200.00
0005433929559	435	Economy	8200.00
0005434023233	435	Economy	8200.00
0005433057288	435	Economy	8200.00
0005434023196	435	Economy	8200.00
0005434023200	435	Economy	8200.00
0005433057307	435	Economy	8200.00
0005433057363	435	Economy	8200.00
0005433057194	435	Economy	8200.00
0005433057184	435	Economy	8200.00
0005433057210	435	Economy	8200.00
0005434023250	435	Economy	8200.00
0005433057302	435	Economy	8200.00
0005434023234	435	Economy	8200.00
0005434023216	435	Economy	8200.00
0005434023228	435	Economy	8200.00
0005434023262	435	Economy	8200.00
0005432235584	435	Economy	8200.00
0005433057405	435	Economy	8200.00
0005434023210	435	Economy	8200.00
0005432235588	435	Economy	8200.00
0005434023237	435	Economy	8200.00
0005434031987	435	Economy	8200.00
0005433684392	435	Economy	8200.00
0005434023226	435	Economy	8200.00
0005434023238	435	Economy	8200.00
0005433057352	435	Economy	8200.00
0005434023227	435	Economy	8200.00
0005434023257	435	Economy	8200.00
0005434023198	435	Economy	8200.00
0005434023218	435	Economy	8200.00
0005433057348	435	Economy	8200.00
0005433057355	435	Economy	8200.00
0005433057342	435	Economy	8200.00
0005434023235	435	Economy	8200.00
0005433684390	435	Economy	8200.00
0005434023223	435	Economy	8200.00
0005433057190	435	Economy	8200.00
0005432235586	435	Economy	8200.00
0005433057428	435	Economy	8200.00
0005433057173	435	Economy	8200.00
0005434023243	435	Economy	8200.00
0005433057533	435	Economy	8200.00
0005433057191	435	Economy	8200.00
0005433057174	435	Economy	8200.00
0005432235581	435	Economy	8200.00
0005434023214	435	Economy	8200.00
0005434023261	435	Economy	8200.00
0005434023219	435	Economy	8200.00
0005434023221	435	Economy	8200.00
0005434028275	435	Economy	8200.00
0005433057187	435	Economy	8200.00
0005432235583	435	Economy	8200.00
0005434023222	435	Economy	8200.00
0005434023203	435	Economy	8200.00
0005433929557	435	Economy	8200.00
0005434023251	435	Economy	8200.00
0005434028276	435	Economy	8200.00
0005434023215	435	Economy	8200.00
0005434023248	435	Economy	8200.00
0005433057347	435	Economy	8200.00
0005433057205	435	Economy	9000.00
0005434023258	435	Economy	9000.00
0005434023199	435	Economy	8200.00
0005434031988	435	Economy	8200.00
0005434023220	435	Economy	8200.00
0005433929539	435	Economy	8200.00
0005433057303	435	Economy	8200.00
0005434023229	435	Economy	8200.00
0005434023236	435	Economy	8200.00
0005434735604	435	Economy	8200.00
0005433057440	435	Economy	8200.00
0005433057185	435	Economy	8200.00
0005434023245	435	Economy	8200.00
0005433057331	435	Economy	8200.00
0005433057432	435	Economy	8200.00
0005434029635	435	Economy	8200.00
0005433057308	435	Economy	8200.00
0005432235585	435	Economy	8200.00
0005434023195	435	Economy	8200.00
0005434023212	435	Economy	8200.00
0005433057534	435	Economy	8200.00
0005433057362	435	Economy	8200.00
0005433057249	435	Economy	8200.00
0005433057175	435	Economy	8200.00
0005432045598	435	Economy	8200.00
0005434031989	435	Economy	8200.00
0005434735605	435	Economy	8200.00
0005433057268	435	Economy	8200.00
0005433057433	435	Economy	8200.00
0005433057442	435	Economy	8200.00
0005434023197	435	Economy	8200.00
0005434029637	435	Economy	8200.00
0005434023232	435	Economy	8200.00
0005434023247	435	Economy	8200.00
0005434023201	435	Economy	8200.00
0005434023231	435	Economy	8200.00
0005433057204	435	Economy	8200.00
0005434023242	435	Economy	8200.00
0005434023260	435	Economy	8200.00
0005434023252	435	Economy	8200.00
0005434023205	435	Economy	8200.00
0005434023202	435	Economy	8200.00
0005433929558	435	Economy	8200.00
0005434023255	435	Economy	8200.00
0005432235587	435	Economy	8200.00
0005434029636	435	Economy	8200.00
0005433057298	435	Economy	8200.00
0005433057301	435	Economy	8200.00
0005434023208	435	Economy	8200.00
0005434023224	435	Economy	8200.00
0005434023207	435	Economy	8200.00
0005434023253	435	Economy	8200.00
0005433057443	435	Economy	8200.00
0005433057283	435	Economy	8200.00
0005433057603	12649	Business	24500.00
0005434022679	12649	Business	24500.00
0005433057586	12649	Business	24500.00
0005434022836	12649	Business	24500.00
0005433057581	12649	Business	24500.00
0005434022795	12649	Business	24500.00
0005433057594	12649	Business	24500.00
0005434022736	12649	Business	24500.00
0005434022695	12649	Business	24500.00
0005434022678	12649	Business	24500.00
0005432156335	12649	Business	24500.00
0005434022667	12649	Business	24500.00
0005434735655	12649	Business	24500.00
0005433057605	12649	Business	24500.00
0005434028250	12649	Business	24500.00
0005434022699	12649	Business	24500.00
0005433057588	12649	Business	24500.00
0005433929585	12649	Economy	9000.00
0005434022694	12649	Economy	9000.00
0005434022696	12649	Economy	9000.00
0005433057593	12649	Economy	8200.00
0005433057601	12649	Economy	8200.00
0005433057583	12649	Economy	8200.00
0005433057602	12649	Economy	8200.00
0005434022644	12649	Economy	8200.00
0005434022700	12649	Economy	8200.00
0005433057610	12649	Economy	8200.00
0005433057615	12649	Economy	8200.00
0005433057591	12649	Economy	8200.00
0005434022747	12649	Economy	8200.00
0005433929583	12649	Economy	8200.00
0005433057619	12649	Economy	8200.00
0005434735651	12649	Economy	8200.00
0005433057597	12649	Economy	8200.00
0005434028249	12649	Economy	8200.00
0005434022628	12649	Economy	8200.00
0005434022741	12649	Economy	8200.00
0005434022805	12649	Economy	8200.00
0005433057590	12649	Economy	8200.00
0005434735652	12649	Economy	8200.00
0005434022883	12649	Economy	8200.00
0005434022665	12649	Economy	8200.00
0005433684406	12649	Economy	8200.00
0005434022794	12649	Economy	8200.00
0005434022791	12649	Economy	8200.00
0005434022617	12649	Economy	8200.00
0005433057596	12649	Economy	8200.00
0005434022861	12649	Economy	8200.00
0005433057618	12649	Economy	8200.00
0005434022837	12649	Economy	8200.00
0005434022974	12649	Economy	8200.00
0005433057606	12649	Economy	8200.00
0005433057604	12649	Economy	8200.00
0005433057612	12649	Economy	8200.00
0005434022638	12649	Economy	8200.00
0005433057613	12649	Economy	8200.00
0005432156333	12649	Economy	8200.00
0005432157478	12649	Economy	8200.00
0005434022862	12649	Economy	8200.00
0005433057582	12649	Economy	8200.00
0005434022702	12649	Economy	8200.00
0005434022571	12649	Economy	8200.00
0005433057600	12649	Economy	8200.00
0005434022698	12649	Economy	8200.00
0005434022708	12649	Economy	8200.00
0005433057611	12649	Economy	8200.00
0005434022835	12649	Economy	9000.00
0005434022618	12649	Economy	9000.00
0005433057587	12649	Economy	8200.00
0005433057595	12649	Economy	9000.00
0005432156334	12649	Economy	8200.00
0005433929581	12649	Economy	8200.00
0005433929582	12649	Economy	8200.00
0005433057617	12649	Economy	8200.00
0005434031947	12649	Economy	8200.00
0005434735650	12649	Economy	8200.00
0005433057616	12649	Economy	8200.00
0005433057598	12649	Economy	8200.00
0005434022884	12649	Economy	8200.00
0005434022598	12649	Economy	8200.00
0005433057584	12649	Economy	8200.00
0005434028247	12649	Economy	8200.00
0005433057607	12649	Economy	8200.00
0005434022592	12649	Economy	8200.00
0005434735654	12649	Economy	8200.00
0005434022645	12649	Economy	8200.00
0005434022893	12649	Economy	8200.00
0005432156336	12649	Economy	8200.00
0005433057592	12649	Economy	8200.00
0005434022674	12649	Economy	8200.00
0005433057609	12649	Economy	8200.00
0005434735653	12649	Economy	8200.00
0005434022776	12649	Economy	8200.00
0005434022788	12649	Economy	8200.00
0005433057589	12649	Economy	8200.00
0005433057580	12649	Economy	8200.00
0005434022701	12649	Economy	8200.00
0005433057608	12649	Economy	8200.00
0005434022754	12649	Economy	8200.00
0005434022843	12649	Economy	8200.00
0005433929584	12649	Economy	8200.00
0005434028251	12649	Economy	8200.00
0005433057585	12649	Economy	8200.00
0005434031956	12649	Economy	8200.00
0005434022668	12649	Economy	8200.00
0005434022664	12649	Economy	8200.00
0005434022600	12649	Economy	8200.00
0005434022975	12649	Economy	8200.00
0005434022689	12649	Economy	8200.00
0005433057614	12649	Economy	8200.00
0005434022825	12649	Economy	8200.00
0005433057620	12649	Economy	8200.00
0005433057599	12649	Economy	8200.00
0005434022627	12649	Economy	8200.00
0005433527237	13818	Business	111600.00
0005433529237	13818	Business	111600.00
0005433529248	13818	Business	111600.00
0005433527234	13818	Economy	37200.00
0005433529239	13818	Economy	37200.00
0005433527238	13818	Economy	40900.00
0005433527231	13818	Economy	40900.00
0005433527227	13818	Economy	37200.00
0005433527236	13818	Economy	37200.00
0005433527233	13818	Economy	37200.00
0005433529240	13818	Economy	37200.00
0005433527232	13818	Economy	37200.00
0005433527228	13818	Economy	37200.00
0005433529243	13818	Economy	37200.00
0005433529241	13818	Economy	37200.00
0005433529246	13818	Economy	37200.00
0005433527235	13818	Economy	37200.00
0005433529247	13818	Economy	37200.00
0005433529242	13818	Economy	37200.00
0005433527230	13818	Economy	37200.00
0005433527229	13818	Economy	37200.00
0005433529244	13818	Economy	37200.00
0005433529238	13818	Economy	37200.00
0005433529245	13818	Economy	37200.00
0005433527226	13818	Economy	37200.00
0005433533243	32442	Business	111600.00
0005433533240	32442	Business	111600.00
0005433533257	32442	Business	111600.00
0005433529216	32442	Economy	37200.00
0005433533245	32442	Economy	37200.00
0005433533241	32442	Economy	37200.00
0005433533242	32442	Economy	37200.00
0005433533259	32442	Economy	37200.00
0005433533246	32442	Economy	37200.00
0005433529215	32442	Economy	37200.00
0005433533244	32442	Economy	37200.00
0005433533258	32442	Economy	37200.00
0005433922589	2125	Business	34700.00
0005432231483	2125	Business	34700.00
0005433922623	2125	Business	34700.00
0005433035569	2125	Business	34700.00
0005432231490	2125	Business	34700.00
0005433035436	2125	Business	34700.00
0005433922618	2125	Business	34700.00
0005433922607	2125	Business	34700.00
0005432231484	2125	Business	34700.00
0005432231488	2125	Business	34700.00
0005433929583	2125	Business	34700.00
0005433922663	2125	Business	34700.00
0005433035403	2125	Business	34700.00
0005433035395	2125	Business	34700.00
0005433035482	2125	Business	34700.00
0005433035600	2125	Business	34700.00
0005433035575	2125	Business	34700.00
0005432231486	2125	Business	34700.00
0005433922644	2125	Business	34700.00
0005433931443	2125	Business	34700.00
0005433922578	2125	Business	34700.00
0005433922626	2125	Economy	12700.00
0005433922638	2125	Business	34700.00
0005433035505	2125	Economy	12700.00
0005432231487	2125	Economy	12700.00
0005433035601	2125	Economy	11600.00
0005433035549	2125	Economy	11600.00
0005434028247	2125	Economy	11600.00
0005433922613	2125	Economy	11600.00
0005433922584	2125	Economy	11600.00
0005433922603	2125	Economy	11600.00
0005432231485	2125	Economy	11600.00
0005433922639	2125	Economy	11600.00
0005432231491	2125	Economy	11600.00
0005433035711	2125	Economy	11600.00
0005433035540	2125	Economy	11600.00
0005433922599	2125	Economy	11600.00
0005433922665	2125	Economy	11600.00
0005433922574	2125	Economy	11600.00
0005433922606	2125	Economy	11600.00
0005433035496	2125	Economy	11600.00
0005433922652	2125	Economy	11600.00
0005433035541	2125	Economy	11600.00
0005433035492	2125	Economy	11600.00
0005433922657	2125	Economy	11600.00
0005433922660	2125	Economy	11600.00
0005433035471	2125	Economy	11600.00
0005433922662	2125	Economy	11600.00
0005433922586	2125	Economy	11600.00
0005433922646	2125	Economy	11600.00
0005432231492	2125	Economy	11600.00
0005433931444	2125	Economy	11600.00
0005432231489	2125	Economy	11600.00
0005434028251	2125	Economy	11600.00
0005433922576	2125	Economy	11600.00
0005433922572	2125	Economy	11600.00
0005433922605	2125	Economy	11600.00
0005433035497	2125	Economy	11600.00
0005433922609	2125	Economy	11600.00
0005433922655	2125	Economy	11600.00
0005433922590	2125	Economy	11600.00
0005433035621	2125	Economy	11600.00
0005433929584	2125	Economy	11600.00
0005433922629	2125	Economy	11600.00
0005433922601	2125	Economy	11600.00
0005433035425	2125	Economy	11600.00
0005433922592	2125	Economy	11600.00
0005433035469	2125	Economy	11600.00
0005433922581	2125	Economy	11600.00
0005433922617	2125	Economy	11600.00
0005433035570	2125	Economy	11600.00
0005433035402	2125	Economy	11600.00
0005433922587	2125	Economy	11600.00
0005433922645	2125	Economy	11600.00
0005433035409	2125	Economy	11600.00
0005433922651	2125	Economy	11600.00
0005433922636	2125	Economy	11600.00
0005433922621	2125	Economy	11600.00
0005434028250	2125	Economy	11600.00
0005433922602	2125	Economy	11600.00
0005433035550	2125	Economy	11600.00
0005433035498	2125	Economy	11600.00
0005432044505	2125	Economy	11600.00
0005433922612	2125	Economy	11600.00
0005433922631	2125	Economy	11600.00
0005433922642	2125	Economy	11600.00
0005433922582	2125	Economy	11600.00
0005433922598	2125	Economy	11600.00
0005433922615	2125	Economy	11600.00
0005433035418	2125	Economy	11600.00
0005433922608	2125	Economy	11600.00
0005433922637	2125	Economy	11600.00
0005433922654	2125	Economy	11600.00
0005433922625	2125	Economy	11600.00
0005433922600	2125	Economy	11600.00
0005433929582	2125	Economy	11600.00
0005433035379	2125	Economy	11600.00
0005433035410	2125	Economy	11600.00
0005433922630	2125	Economy	11600.00
0005433035457	2125	Economy	11600.00
0005433931442	2125	Economy	11600.00
0005433922619	2125	Economy	11600.00
0005433035476	2125	Economy	11600.00
0005433922641	2125	Economy	11600.00
0005433922624	2125	Economy	11600.00
0005433922611	2125	Economy	12700.00
0005433035466	2125	Economy	12700.00
0005433922620	2125	Economy	11600.00
0005433922594	2125	Economy	11600.00
0005433922650	2125	Economy	12700.00
0005433035610	2125	Economy	12700.00
0005433922577	2125	Economy	11600.00
0005433922633	2125	Economy	11600.00
0005433922622	2125	Economy	11600.00
0005433922616	2125	Economy	11600.00
0005433922585	2125	Economy	11600.00
0005433922649	2125	Economy	11600.00
0005432231493	2125	Economy	11600.00
0005433922659	2125	Economy	11600.00
0005433922604	2125	Economy	11600.00
0005433875366	2125	Economy	11600.00
0005433922597	2125	Economy	11600.00
0005433922640	2125	Economy	11600.00
0005433035483	2125	Economy	11600.00
0005433035423	2125	Economy	11600.00
0005433922593	2125	Economy	11600.00
0005433922614	2125	Economy	11600.00
0005433922596	2125	Economy	11600.00
0005433035544	2125	Economy	11600.00
0005433922627	2125	Economy	11600.00
0005433035552	2125	Economy	11600.00
0005433035362	2125	Economy	11600.00
0005433922634	2125	Economy	11600.00
0005433035452	2125	Economy	11600.00
0005433035387	2125	Economy	11600.00
0005433922628	2125	Economy	11600.00
0005432231494	2125	Economy	11600.00
0005433922610	2125	Economy	11600.00
0005433922588	2125	Economy	11600.00
0005433922570	2125	Economy	11600.00
0005433922635	2125	Economy	11600.00
0005433035472	2125	Economy	11600.00
0005432044504	2125	Economy	11600.00
0005433035493	2125	Economy	11600.00
0005433035445	2125	Economy	11600.00
0005433035380	2125	Economy	11600.00
0005433922632	2125	Economy	11600.00
0005433922664	2125	Economy	11600.00
0005433035456	2125	Economy	11600.00
0005433922573	2125	Economy	11600.00
0005433922595	2125	Economy	11600.00
0005433922571	2125	Economy	11600.00
0005433922580	2125	Economy	11600.00
0005433922575	2125	Economy	11600.00
0005433035545	2125	Economy	11600.00
0005433922658	2125	Economy	11600.00
0005433922666	2125	Economy	11600.00
0005433035555	2125	Economy	11600.00
0005433929585	2125	Economy	11600.00
0005433035386	2125	Economy	11600.00
0005433922661	2125	Economy	11600.00
0005433035499	2125	Economy	11600.00
0005433922579	2125	Economy	11600.00
0005433922591	2125	Economy	11600.00
0005433035470	2125	Economy	11600.00
0005433929581	2125	Economy	11600.00
0005433922653	2125	Economy	11600.00
0005433922643	2125	Economy	11600.00
0005434028249	2125	Economy	11600.00
0005433922583	2125	Economy	11600.00
0005433035554	2125	Economy	11600.00
0005433922648	2125	Economy	11600.00
0005433922647	2125	Economy	11600.00
0005433922656	2125	Economy	11600.00
0005433921760	24131	Business	34700.00
0005433035914	24131	Business	34700.00
0005432206154	24131	Business	34700.00
0005433922016	24131	Business	34700.00
0005433922034	24131	Business	34700.00
0005433921805	24131	Business	34700.00
0005432207642	24131	Business	34700.00
0005432207644	24131	Business	34700.00
0005433035913	24131	Business	34700.00
0005433035903	24131	Business	34700.00
0005433921667	24131	Business	34700.00
0005433921789	24131	Business	34700.00
0005433929542	24131	Business	34700.00
0005433035941	24131	Business	34700.00
0005433921825	24131	Business	34700.00
0005433921816	24131	Business	34700.00
0005433035905	24131	Business	34700.00
0005433922097	24131	Business	34700.00
0005433035904	24131	Business	34700.00
0005433035906	24131	Business	34700.00
0005433921719	24131	Business	34700.00
0005433931418	24131	Business	34700.00
0005433035924	24131	Business	34700.00
0005433929543	24131	Business	34700.00
0005433921704	24131	Economy	12700.00
0005433922176	24131	Economy	11600.00
0005433035948	24131	Economy	12700.00
0005433921965	24131	Economy	11600.00
0005433035945	24131	Economy	11600.00
0005433035943	24131	Economy	11600.00
0005433035901	24131	Economy	11600.00
0005433921944	24131	Economy	11600.00
0005433921649	24131	Economy	11600.00
0005433921650	24131	Economy	11600.00
0005433921690	24131	Economy	11600.00
0005433035907	24131	Economy	11600.00
0005433921763	24131	Economy	11600.00
0005434028277	24131	Economy	11600.00
0005433922264	24131	Economy	11600.00
0005433035921	24131	Economy	11600.00
0005433921651	24131	Economy	11600.00
0005433921730	24131	Economy	11600.00
0005433922145	24131	Economy	11600.00
0005433931415	24131	Economy	11600.00
0005433035900	24131	Economy	11600.00
0005433921841	24131	Economy	11600.00
0005433035912	24131	Economy	11600.00
0005433921943	24131	Economy	11600.00
0005432207643	24131	Economy	11600.00
0005432206156	24131	Economy	11600.00
0005433035947	24131	Economy	11600.00
0005433922082	24131	Economy	11600.00
0005433921806	24131	Economy	11600.00
0005433929565	24131	Economy	11600.00
0005433921813	24131	Economy	11600.00
0005433035910	24131	Economy	11600.00
0005433035931	24131	Economy	11600.00
0005433921966	24131	Economy	11600.00
0005433922119	24131	Economy	11600.00
0005433035922	24131	Economy	11600.00
0005432749770	24131	Economy	11600.00
0005433922223	24131	Economy	11600.00
0005433035919	24131	Economy	11600.00
0005433921630	24131	Economy	11600.00
0005433921861	24131	Economy	11600.00
0005433035926	24131	Economy	11600.00
0005433929548	24131	Economy	11600.00
0005433035902	24131	Economy	11600.00
0005433921759	24131	Economy	11600.00
0005433035930	24131	Economy	11600.00
0005433921883	24131	Economy	11600.00
0005434028279	24131	Economy	11600.00
0005433921731	24131	Economy	11600.00
0005433921902	24131	Economy	11600.00
0005433929545	24131	Economy	11600.00
0005433921945	24131	Economy	11600.00
0005432749769	24131	Economy	11600.00
0005433921788	24131	Economy	11600.00
0005433921790	24131	Economy	11600.00
0005433035915	24131	Economy	11600.00
0005433921967	24131	Economy	11600.00
0005433035933	24131	Economy	11600.00
0005433921773	24131	Economy	11600.00
0005433035944	24131	Economy	11600.00
0005433922042	24131	Economy	11600.00
0005433921801	24131	Economy	11600.00
0005433035925	24131	Economy	11600.00
0005433035934	24131	Economy	11600.00
0005433921696	24131	Economy	11600.00
0005433922033	24131	Economy	11600.00
0005433921618	24131	Economy	11600.00
0005433035916	24131	Economy	11600.00
0005433929553	24131	Economy	11600.00
0005433035949	24131	Economy	11600.00
0005432206153	24131	Economy	11600.00
0005433035938	24131	Economy	11600.00
0005433035899	24131	Economy	11600.00
0005432207645	24131	Economy	11600.00
0005433921631	24131	Economy	11600.00
0005433922068	24131	Economy	11600.00
0005433921828	24131	Economy	11600.00
0005433921990	24131	Economy	11600.00
0005433035942	24131	Economy	11600.00
0005433921797	24131	Economy	11600.00
0005433035929	24131	Economy	11600.00
0005433921978	24131	Economy	12700.00
0005433035935	24131	Economy	11600.00
0005433921979	24131	Economy	11600.00
0005432206155	24131	Economy	11600.00
0005433035927	24131	Economy	12700.00
0005433035918	24131	Economy	11600.00
0005433921948	24131	Economy	11600.00
0005433035936	24131	Economy	11600.00
0005433921992	24131	Economy	11600.00
0005432206151	24131	Economy	11600.00
0005433922273	24131	Economy	11600.00
0005433921857	24131	Economy	11600.00
0005433921964	24131	Economy	11600.00
0005433922001	24131	Economy	11600.00
0005433922274	24131	Economy	11600.00
0005433035950	24131	Economy	11600.00
0005433922144	24131	Economy	11600.00
0005433921817	24131	Economy	11600.00
0005433921840	24131	Economy	11600.00
0005433921698	24131	Economy	11600.00
0005433921903	24131	Economy	11600.00
0005433921960	24131	Economy	11600.00
0005433921989	24131	Economy	11600.00
0005433931423	24131	Economy	11600.00
0005433035897	24131	Economy	11600.00
0005433035939	24131	Economy	11600.00
0005433922035	24131	Economy	11600.00
0005433035940	24131	Economy	11600.00
0005433931416	24131	Economy	11600.00
0005434028278	24131	Economy	11600.00
0005433921711	24131	Economy	11600.00
0005433921772	24131	Economy	11600.00
0005432206152	24131	Economy	11600.00
0005433035946	24131	Economy	11600.00
0005433035917	24131	Economy	11600.00
0005433922069	24131	Economy	11600.00
0005433921827	24131	Economy	11600.00
0005433922043	24131	Economy	11600.00
0005433922083	24131	Economy	11600.00
0005433922120	24131	Economy	11600.00
0005433931419	24131	Economy	11600.00
0005433035908	24131	Economy	11600.00
0005433035923	24131	Economy	11600.00
0005433035909	24131	Economy	11600.00
0005433921991	24131	Economy	11600.00
0005433035898	24131	Economy	11600.00
0005433922081	24131	Economy	11600.00
0005433921770	24131	Economy	11600.00
0005433035932	24131	Economy	11600.00
0005433921860	24131	Economy	11600.00
0005433921765	24131	Economy	11600.00
0005433035920	24131	Economy	11600.00
0005433035911	24131	Economy	11600.00
0005433921764	24131	Economy	11600.00
0005433035928	24131	Economy	11600.00
0005433921824	24131	Economy	11600.00
0005433921697	24131	Economy	11600.00
0005433929544	24131	Economy	11600.00
0005433921794	24131	Economy	11600.00
0005433035937	24131	Economy	11600.00
0005433921901	24131	Economy	11600.00
0005433921812	24131	Economy	11600.00
0005433921687	24131	Economy	11600.00
0005434724591	272	Business	83700.00
0005434550848	272	Business	83700.00
0005433180707	272	Business	83700.00
0005434550858	272	Business	83700.00
0005434550851	272	Business	83700.00
0005434724568	272	Business	83700.00
0005433233507	272	Business	83700.00
0005433180702	272	Business	83700.00
0005434735649	272	Business	83700.00
0005434550845	272	Business	83700.00
0005433131641	272	Business	83700.00
0005433233249	272	Business	83700.00
0005433233385	272	Business	83700.00
0005435142483	272	Business	83700.00
0005433180741	272	Business	83700.00
0005433233112	272	Business	83700.00
0005432277708	272	Business	83700.00
0005434724665	272	Business	83700.00
0005434550862	272	Business	83700.00
0005434724554	272	Business	83700.00
0005433131640	272	Business	83700.00
0005434724636	272	Business	83700.00
0005434031946	272	Business	83700.00
0005433233226	272	Business	83700.00
0005433233239	272	Business	83700.00
0005433233216	272	Business	83700.00
0005434724593	272	Comfort	47400.00
0005433180681	272	Comfort	47400.00
0005434731135	272	Comfort	47400.00
0005433233270	272	Comfort	47400.00
0005434724648	272	Comfort	47400.00
0005434724571	272	Comfort	47400.00
0005433289741	272	Comfort	47400.00
0005434724671	272	Comfort	47400.00
0005433233301	272	Comfort	47400.00
0005434724653	272	Comfort	47400.00
0005434724599	272	Comfort	47400.00
0005434550833	272	Comfort	47400.00
0005432277720	272	Comfort	47400.00
0005434731137	272	Comfort	47400.00
0005434724622	272	Comfort	47400.00
0005434550847	272	Comfort	47400.00
0005435142475	272	Comfort	47400.00
0005433111470	272	Comfort	47400.00
0005434724560	272	Comfort	47400.00
0005434724629	272	Comfort	47400.00
0005434550826	272	Comfort	47400.00
0005433233271	272	Comfort	47400.00
0005434724573	272	Comfort	47400.00
0005433233215	272	Comfort	47400.00
0005434550838	272	Comfort	47400.00
0005433766578	272	Comfort	47400.00
0005434724580	272	Comfort	47400.00
0005432277707	272	Comfort	47400.00
0005433233252	272	Comfort	47400.00
0005433233409	272	Comfort	47400.00
0005435142476	272	Comfort	47400.00
0005434550856	272	Comfort	47400.00
0005434724578	272	Comfort	47400.00
0005433233272	272	Comfort	47400.00
0005434724592	272	Economy	27900.00
0005433180714	272	Economy	27900.00
0005433233187	272	Economy	27900.00
0005434724640	272	Economy	27900.00
0005434724656	272	Economy	27900.00
0005434724557	272	Economy	27900.00
0005433180715	272	Economy	27900.00
0005433233587	272	Economy	27900.00
0005434550869	272	Economy	27900.00
0005434724563	272	Economy	27900.00
0005434724652	272	Economy	27900.00
0005433180774	272	Economy	27900.00
0005434550859	272	Economy	27900.00
0005434550846	272	Economy	27900.00
0005433233151	272	Economy	27900.00
0005434550829	272	Economy	27900.00
0005434724609	272	Economy	27900.00
0005434724614	272	Economy	27900.00
0005435142481	272	Economy	27900.00
0005434735646	272	Economy	27900.00
0005433233384	272	Economy	27900.00
0005434724632	272	Economy	27900.00
0005435142479	272	Economy	27900.00
0005434731136	272	Economy	27900.00
0005434724577	272	Economy	27900.00
0005433233227	272	Economy	27900.00
0005434724666	272	Economy	27900.00
0005435142487	272	Economy	27900.00
0005434550874	272	Economy	27900.00
0005434724589	272	Economy	27900.00
0005434724600	272	Economy	27900.00
0005433233202	272	Economy	27900.00
0005434550827	272	Economy	27900.00
0005434724588	272	Economy	27900.00
0005434724634	272	Economy	27900.00
0005434550861	272	Economy	27900.00
0005433131638	272	Economy	27900.00
0005434724590	272	Economy	27900.00
0005434724627	272	Economy	27900.00
0005433289733	272	Economy	27900.00
0005434550836	272	Economy	27900.00
0005434550863	272	Economy	27900.00
0005433233111	272	Economy	27900.00
0005434724605	272	Economy	27900.00
0005434724623	272	Economy	27900.00
0005433233107	272	Economy	27900.00
0005434550864	272	Economy	27900.00
0005434724649	272	Economy	27900.00
0005434724556	272	Economy	27900.00
0005434724617	272	Economy	27900.00
0005434550834	272	Economy	27900.00
0005433289759	272	Economy	27900.00
0005435142482	272	Economy	27900.00
0005434724670	272	Economy	27900.00
0005434550819	272	Economy	27900.00
0005435142477	272	Economy	27900.00
0005433233253	272	Economy	27900.00
0005432277714	272	Economy	27900.00
0005434724655	272	Economy	27900.00
0005433180716	272	Economy	27900.00
0005434550867	272	Economy	27900.00
0005434550832	272	Economy	30700.00
0005434724631	272	Economy	27900.00
0005434724587	272	Economy	27900.00
0005433233194	272	Economy	27900.00
0005435142485	272	Economy	30700.00
0005433180655	272	Economy	30700.00
0005434550854	272	Economy	30700.00
0005434724582	272	Economy	27900.00
0005433233115	272	Economy	27900.00
0005434724650	272	Economy	27900.00
0005434550843	272	Economy	27900.00
0005434724581	272	Economy	27900.00
0005435142480	272	Economy	27900.00
0005433766587	272	Economy	27900.00
0005433180775	272	Economy	27900.00
0005434550853	272	Economy	27900.00
0005434724610	272	Economy	27900.00
0005432277713	272	Economy	27900.00
0005434550868	272	Economy	27900.00
0005435142474	272	Economy	27900.00
0005432277709	272	Economy	27900.00
0005434724621	272	Economy	27900.00
0005433126781	272	Economy	27900.00
0005433180659	272	Economy	27900.00
0005434724659	272	Economy	27900.00
0005434724551	272	Economy	27900.00
0005434724553	272	Economy	27900.00
0005433233148	272	Economy	27900.00
0005432277716	272	Economy	27900.00
0005434724596	272	Economy	27900.00
0005434550870	272	Economy	27900.00
0005434550825	272	Economy	27900.00
0005434731138	272	Economy	27900.00
0005434724633	272	Economy	27900.00
0005434724584	272	Economy	27900.00
0005434724658	272	Economy	27900.00
0005433233346	272	Economy	27900.00
0005433180738	272	Economy	27900.00
0005434724615	272	Economy	27900.00
0005434724570	272	Economy	27900.00
0005433233162	272	Economy	27900.00
0005434724585	272	Economy	27900.00
0005434724641	272	Economy	27900.00
0005433233180	272	Economy	27900.00
0005434724558	272	Economy	27900.00
0005434724564	272	Economy	27900.00
0005433233585	272	Economy	27900.00
0005434550823	272	Economy	27900.00
0005433233347	272	Economy	27900.00
0005433131637	272	Economy	27900.00
0005434724549	272	Economy	27900.00
0005433766577	272	Economy	27900.00
0005434724661	272	Economy	27900.00
0005434550828	272	Economy	27900.00
0005434724625	272	Economy	27900.00
0005434724664	272	Economy	27900.00
0005435142486	272	Economy	27900.00
0005433289744	272	Economy	27900.00
0005434550866	272	Economy	27900.00
0005433289734	272	Economy	27900.00
0005434724663	272	Economy	27900.00
0005434724603	272	Economy	27900.00
0005434550872	272	Economy	27900.00
0005434724569	272	Economy	27900.00
0005433180706	272	Economy	27900.00
0005433233217	272	Economy	27900.00
0005433180694	272	Economy	27900.00
0005434550830	272	Economy	27900.00
0005433180710	272	Economy	27900.00
0005434550852	272	Economy	27900.00
0005433233196	272	Economy	27900.00
0005434724645	272	Economy	27900.00
0005434724575	272	Economy	27900.00
0005434724601	272	Economy	27900.00
0005433233388	272	Economy	27900.00
0005433233131	272	Economy	27900.00
0005434724673	272	Economy	27900.00
0005434724602	272	Economy	27900.00
0005434724561	272	Economy	27900.00
0005432277710	272	Economy	27900.00
0005433113498	272	Economy	27900.00
0005433233236	272	Economy	27900.00
0005434735648	272	Economy	27900.00
0005434550860	272	Economy	27900.00
0005434550850	272	Economy	27900.00
0005434724566	272	Economy	27900.00
0005432277712	272	Economy	27900.00
0005433233149	272	Economy	27900.00
0005434724619	272	Economy	27900.00
0005434724660	272	Economy	27900.00
0005434724606	272	Economy	27900.00
0005433180677	272	Economy	27900.00
0005433289760	272	Economy	27900.00
0005434724574	272	Economy	27900.00
0005434550873	272	Economy	27900.00
0005434550822	272	Economy	27900.00
0005432277719	272	Economy	27900.00
0005434724604	272	Economy	27900.00
0005434724552	272	Economy	27900.00
0005434724579	272	Economy	27900.00
0005434724613	272	Economy	30700.00
0005433233130	272	Economy	30700.00
0005434724618	272	Economy	30700.00
0005433233120	272	Economy	30700.00
0005434550835	272	Economy	27900.00
0005433289761	272	Economy	27900.00
0005434724637	272	Economy	27900.00
0005434550820	272	Economy	27900.00
0005433233300	272	Economy	27900.00
0005434735645	272	Economy	27900.00
0005434724624	272	Economy	27900.00
0005434724607	272	Economy	27900.00
0005434724550	272	Economy	27900.00
0005434724620	272	Economy	27900.00
0005433233250	272	Economy	27900.00
0005434724608	272	Economy	27900.00
0005433113499	272	Economy	27900.00
0005433233284	272	Economy	27900.00
0005432277717	272	Economy	27900.00
0005434550844	272	Economy	27900.00
0005434724672	272	Economy	27900.00
0005434302427	272	Economy	27900.00
0005433180735	272	Economy	27900.00
0005434724565	272	Economy	27900.00
0005433233584	272	Economy	27900.00
0005434724616	272	Economy	27900.00
0005434724667	272	Economy	27900.00
0005433180739	272	Economy	27900.00
0005434724654	272	Economy	27900.00
0005434724576	272	Economy	27900.00
0005434550837	272	Economy	27900.00
0005433289743	272	Economy	27900.00
0005433180740	272	Economy	27900.00
0005434724635	272	Economy	27900.00
0005434724642	272	Economy	27900.00
0005433180811	272	Economy	27900.00
0005434724639	272	Economy	27900.00
0005434550857	272	Economy	27900.00
0005433233266	272	Economy	27900.00
0005434724668	272	Economy	27900.00
0005434724611	272	Economy	27900.00
0005434302429	272	Economy	27900.00
0005435142484	272	Economy	27900.00
0005434550871	272	Economy	27900.00
0005432277715	272	Economy	27900.00
0005434724626	272	Economy	27900.00
0005434302428	272	Economy	27900.00
0005434550875	272	Economy	27900.00
0005434724646	272	Economy	27900.00
0005434724562	272	Economy	27900.00
0005433131642	272	Economy	27900.00
0005434724628	272	Economy	27900.00
0005434724595	272	Economy	27900.00
0005434724644	272	Economy	27900.00
0005434550840	272	Economy	27900.00
0005434724651	272	Economy	27900.00
0005433233391	272	Economy	27900.00
0005434724597	272	Economy	27900.00
0005433289740	272	Economy	27900.00
0005434550841	272	Economy	27900.00
0005433233410	272	Economy	27900.00
0005433233269	272	Economy	27900.00
0005433233244	272	Economy	27900.00
0005434724594	272	Economy	27900.00
0005434724630	272	Economy	27900.00
0005434724638	272	Economy	27900.00
0005434724572	272	Economy	27900.00
0005434724598	272	Economy	27900.00
0005433180695	272	Economy	27900.00
0005434550831	272	Economy	27900.00
0005432277718	272	Economy	27900.00
0005434724583	272	Economy	27900.00
0005434550839	272	Economy	27900.00
0005434724586	272	Economy	27900.00
0005434550824	272	Economy	27900.00
0005434550842	272	Economy	27900.00
0005433180705	272	Economy	27900.00
0005434735647	272	Economy	27900.00
0005432277711	272	Economy	27900.00
0005434724647	272	Economy	27900.00
0005434724555	272	Economy	27900.00
0005433233214	272	Economy	27900.00
0005434724612	272	Economy	27900.00
0005434724657	272	Economy	27900.00
0005433233186	272	Economy	27900.00
0005434550821	272	Economy	27900.00
0005435142478	272	Economy	27900.00
0005433233238	272	Economy	27900.00
0005433180682	272	Economy	27900.00
0005434550865	272	Economy	27900.00
0005434724669	272	Economy	27900.00
0005433113497	272	Economy	27900.00
0005434550849	272	Economy	27900.00
0005434724559	272	Economy	27900.00
0005434724567	272	Economy	27900.00
0005434550855	272	Economy	27900.00
0005434724662	272	Economy	27900.00
0005433126777	272	Economy	27900.00
0005433180708	272	Economy	27900.00
0005434724643	272	Economy	27900.00
0005433233742	9825	Business	83700.00
0005434550424	9825	Business	83700.00
0005434723805	9825	Business	83700.00
0005433180922	9825	Business	83700.00
0005434723658	9825	Business	83700.00
0005433233729	9825	Business	83700.00
0005433233740	9825	Business	83700.00
0005433233724	9825	Business	83700.00
0005434550323	9825	Business	83700.00
0005434550353	9825	Business	83700.00
0005433233749	9825	Business	83700.00
0005434550493	9825	Business	83700.00
0005433233751	9825	Business	83700.00
0005433233761	9825	Business	83700.00
0005434723426	9825	Business	83700.00
0005433180932	9825	Business	83700.00
0005433180909	9825	Business	83700.00
0005434723581	9825	Business	83700.00
0005434723456	9825	Business	83700.00
0005434723906	9825	Business	83700.00
0005434550354	9825	Business	83700.00
0005434550506	9825	Business	83700.00
0005434724076	9825	Business	83700.00
0005433180924	9825	Comfort	47400.00
0005434550346	9825	Business	83700.00
0005433233785	9825	Comfort	47400.00
0005434550373	9825	Comfort	47400.00
0005434723723	9825	Comfort	47400.00
0005434550364	9825	Comfort	47400.00
0005433233734	9825	Comfort	47400.00
0005434550369	9825	Comfort	47400.00
0005434550606	9825	Comfort	47400.00
0005434731100	9825	Comfort	47400.00
0005433180918	9825	Comfort	47400.00
0005434550396	9825	Comfort	47400.00
0005433233755	9825	Comfort	47400.00
0005433180912	9825	Comfort	47400.00
0005433233760	9825	Comfort	47400.00
0005434724002	9825	Comfort	47400.00
0005433233777	9825	Comfort	47400.00
0005433289793	9825	Comfort	47400.00
0005434723899	9825	Comfort	47400.00
0005434723955	9825	Comfort	47400.00
0005433129243	9825	Comfort	47400.00
0005433180926	9825	Comfort	47400.00
0005433233736	9825	Comfort	47400.00
0005433233748	9825	Comfort	47400.00
0005434723588	9825	Comfort	47400.00
0005434550261	9825	Comfort	47400.00
0005434550492	9825	Comfort	47400.00
0005433180928	9825	Comfort	47400.00
0005433180920	9825	Comfort	47400.00
0005433233752	9825	Comfort	47400.00
0005433180929	9825	Comfort	47400.00
0005433766611	9825	Comfort	47400.00
0005435142366	9825	Comfort	47400.00
0005433289797	9825	Comfort	47400.00
0005433180907	9825	Comfort	47400.00
0005433233758	9825	Comfort	47400.00
0005434550528	9825	Comfort	47400.00
0005434550293	9825	Comfort	47400.00
0005434550294	9825	Comfort	47400.00
0005433233784	9825	Economy	27900.00
0005433180913	9825	Economy	27900.00
0005434724255	9825	Economy	27900.00
0005434723806	9825	Economy	27900.00
0005434031992	9825	Economy	27900.00
0005434723476	9825	Economy	27900.00
0005434724064	9825	Economy	27900.00
0005433289794	9825	Economy	27900.00
0005434723832	9825	Economy	27900.00
0005434723360	9825	Economy	27900.00
0005434723377	9825	Economy	27900.00
0005433233779	9825	Economy	27900.00
0005434724065	9825	Economy	27900.00
0005434723983	9825	Economy	27900.00
0005434723556	9825	Economy	27900.00
0005434031994	9825	Economy	27900.00
0005433180931	9825	Economy	27900.00
0005434723896	9825	Economy	27900.00
0005433233730	9825	Economy	27900.00
0005434723797	9825	Economy	27900.00
0005434550328	9825	Economy	27900.00
0005434723807	9825	Economy	27900.00
0005434550360	9825	Economy	27900.00
0005433180906	9825	Economy	27900.00
0005434723425	9825	Economy	27900.00
0005434723568	9825	Economy	27900.00
0005434723654	9825	Economy	27900.00
0005434723884	9825	Economy	27900.00
0005434731097	9825	Economy	27900.00
0005434723956	9825	Economy	27900.00
0005433233733	9825	Economy	27900.00
0005434550605	9825	Economy	27900.00
0005434550268	9825	Economy	27900.00
0005434550318	9825	Economy	27900.00
0005434723954	9825	Economy	27900.00
0005434550305	9825	Economy	27900.00
0005433233772	9825	Economy	27900.00
0005433233786	9825	Economy	27900.00
0005433180915	9825	Economy	27900.00
0005434550302	9825	Economy	27900.00
0005433180925	9825	Economy	27900.00
0005435142365	9825	Economy	27900.00
0005434723380	9825	Economy	27900.00
0005434723745	9825	Economy	27900.00
0005433233775	9825	Economy	27900.00
0005434723487	9825	Economy	27900.00
0005434550394	9825	Economy	27900.00
0005434723722	9825	Economy	27900.00
0005434723827	9825	Economy	27900.00
0005434723662	9825	Economy	27900.00
0005434723550	9825	Economy	27900.00
0005434724254	9825	Economy	27900.00
0005432199199	9825	Economy	30700.00
0005434723686	9825	Economy	27900.00
0005433766614	9825	Economy	30700.00
0005433113522	9825	Economy	27900.00
0005433233768	9825	Economy	27900.00
0005434723367	9825	Economy	27900.00
0005433233754	9825	Economy	30700.00
0005435142354	9825	Economy	30700.00
0005434723531	9825	Economy	27900.00
0005433289791	9825	Economy	27900.00
0005434550378	9825	Economy	27900.00
0005434723666	9825	Economy	27900.00
0005434723525	9825	Economy	27900.00
0005434550532	9825	Economy	27900.00
0005433180917	9825	Economy	27900.00
0005433129245	9825	Economy	27900.00
0005433126812	9825	Economy	27900.00
0005433180914	9825	Economy	27900.00
0005433233745	9825	Economy	27900.00
0005434723526	9825	Economy	27900.00
0005434723477	9825	Economy	27900.00
0005434723795	9825	Economy	27900.00
0005433180908	9825	Economy	27900.00
0005433126810	9825	Economy	27900.00
0005433233728	9825	Economy	27900.00
0005434550491	9825	Economy	27900.00
0005433113520	9825	Economy	27900.00
0005434550450	9825	Economy	27900.00
0005434723322	9825	Economy	27900.00
0005433233781	9825	Economy	27900.00
0005434723653	9825	Economy	27900.00
0005434723611	9825	Economy	27900.00
0005434723619	9825	Economy	27900.00
0005433233738	9825	Economy	27900.00
0005434723838	9825	Economy	27900.00
0005434723897	9825	Economy	27900.00
0005433126813	9825	Economy	27900.00
0005432199196	9825	Economy	27900.00
0005434723549	9825	Economy	27900.00
0005433233743	9825	Economy	27900.00
0005433233776	9825	Economy	27900.00
0005434723494	9825	Economy	27900.00
0005433180927	9825	Economy	27900.00
0005434723457	9825	Economy	27900.00
0005434723663	9825	Economy	27900.00
0005433233744	9825	Economy	27900.00
0005434723540	9825	Economy	27900.00
0005434723368	9825	Economy	27900.00
0005433180930	9825	Economy	27900.00
0005434723834	9825	Economy	27900.00
0005434031993	9825	Economy	27900.00
0005434723803	9825	Economy	27900.00
0005434550267	9825	Economy	27900.00
0005433233771	9825	Economy	27900.00
0005434723876	9825	Economy	27900.00
0005434723670	9825	Economy	27900.00
0005434723465	9825	Economy	27900.00
0005433289795	9825	Economy	27900.00
0005433766612	9825	Economy	27900.00
0005433126809	9825	Economy	27900.00
0005434723950	9825	Economy	27900.00
0005433233766	9825	Economy	27900.00
0005434723524	9825	Economy	27900.00
0005434723898	9825	Economy	27900.00
0005433129244	9825	Economy	27900.00
0005434031991	9825	Economy	27900.00
0005433233750	9825	Economy	27900.00
0005433129241	9825	Economy	27900.00
0005435142343	9825	Economy	27900.00
0005433233769	9825	Economy	27900.00
0005433233765	9825	Economy	27900.00
0005433233746	9825	Economy	27900.00
0005432199198	9825	Economy	27900.00
0005433233737	9825	Economy	27900.00
0005434723435	9825	Economy	27900.00
0005434723527	9825	Economy	27900.00
0005433233782	9825	Economy	27900.00
0005434723347	9825	Economy	27900.00
0005433233762	9825	Economy	27900.00
0005434723671	9825	Economy	27900.00
0005433233770	9825	Economy	27900.00
0005434723589	9825	Economy	27900.00
0005433233727	9825	Economy	27900.00
0005433180919	9825	Economy	27900.00
0005434723362	9825	Economy	27900.00
0005434723376	9825	Economy	27900.00
0005434723339	9825	Economy	27900.00
0005433233726	9825	Economy	27900.00
0005434724195	9825	Economy	27900.00
0005434550395	9825	Economy	27900.00
0005434550324	9825	Economy	27900.00
0005433233747	9825	Economy	27900.00
0005434724087	9825	Economy	27900.00
0005434723464	9825	Economy	27900.00
0005434550507	9825	Economy	27900.00
0005433233783	9825	Economy	30700.00
0005434723512	9825	Economy	30700.00
0005434723659	9825	Economy	30700.00
0005434723340	9825	Economy	30700.00
0005434550477	9825	Economy	27900.00
0005434723508	9825	Economy	27900.00
0005433233756	9825	Economy	27900.00
0005433180911	9825	Economy	27900.00
0005433126811	9825	Economy	27900.00
0005434550332	9825	Economy	27900.00
0005434031990	9825	Economy	27900.00
0005434723578	9825	Economy	27900.00
0005434723984	9825	Economy	27900.00
0005433180910	9825	Economy	27900.00
0005434723323	9825	Economy	27900.00
0005433233741	9825	Economy	27900.00
0005433233773	9825	Economy	27900.00
0005434723669	9825	Economy	27900.00
0005434723833	9825	Economy	27900.00
0005434723625	9825	Economy	27900.00
0005434723361	9825	Economy	27900.00
0005434724253	9825	Economy	27900.00
0005433289792	9825	Economy	27900.00
0005433233753	9825	Economy	27900.00
0005434723952	9825	Economy	27900.00
0005433233774	9825	Economy	27900.00
0005432199200	9825	Economy	27900.00
0005433113519	9825	Economy	27900.00
0005433233732	9825	Economy	27900.00
0005434723364	9825	Economy	27900.00
0005433180916	9825	Economy	27900.00
0005434723903	9825	Economy	27900.00
0005433233735	9825	Economy	27900.00
0005432199197	9825	Economy	27900.00
0005434723683	9825	Economy	27900.00
0005433233757	9825	Economy	27900.00
0005435142416	9825	Economy	27900.00
0005434550372	9825	Economy	27900.00
0005434723363	9825	Economy	27900.00
0005434550303	9825	Economy	27900.00
0005434723475	9825	Economy	27900.00
0005434723826	9825	Economy	27900.00
0005434723668	9825	Economy	27900.00
0005434723553	9825	Economy	27900.00
0005433289796	9825	Economy	27900.00
0005434723501	9825	Economy	27900.00
0005434723883	9825	Economy	27900.00
0005434723664	9825	Economy	27900.00
0005432199201	9825	Economy	27900.00
0005434723438	9825	Economy	27900.00
0005434550543	9825	Economy	27900.00
0005434723406	9825	Economy	27900.00
0005433129242	9825	Economy	27900.00
0005433113521	9825	Economy	27900.00
0005434723953	9825	Economy	27900.00
0005433233739	9825	Economy	27900.00
0005434550361	9825	Economy	27900.00
0005434723692	9825	Economy	27900.00
0005434723503	9825	Economy	27900.00
0005433233767	9825	Economy	27900.00
0005434550478	9825	Economy	27900.00
0005433233778	9825	Economy	27900.00
0005434550379	9825	Economy	27900.00
0005434724031	9825	Economy	27900.00
0005434723580	9825	Economy	27900.00
0005433233725	9825	Economy	27900.00
0005434723343	9825	Economy	27900.00
0005434723555	9825	Economy	27900.00
0005433180921	9825	Economy	27900.00
0005433233763	9825	Economy	27900.00
0005434723384	9825	Economy	27900.00
0005432199195	9825	Economy	27900.00
0005435142336	9825	Economy	27900.00
0005434723667	9825	Economy	27900.00
0005433180923	9825	Economy	27900.00
0005434723485	9825	Economy	27900.00
0005433766613	9825	Economy	27900.00
0005434723375	9825	Economy	27900.00
0005433233787	9825	Economy	27900.00
0005434723486	9825	Economy	27900.00
0005434724032	9825	Economy	27900.00
0005434723511	9825	Economy	27900.00
0005434724152	9825	Economy	27900.00
0005434723673	9825	Economy	27900.00
0005433233764	9825	Economy	27900.00
0005433233759	9825	Economy	27900.00
0005434723579	9825	Economy	27900.00
0005434723684	9825	Economy	27900.00
0005434723702	9825	Economy	27900.00
0005434724106	9825	Economy	27900.00
0005433233731	9825	Economy	27900.00
0005434723387	9825	Economy	27900.00
0005434723502	9825	Economy	27900.00
0005434723675	9825	Economy	27900.00
0005433233780	9825	Economy	27900.00
0005434067064	7766	Business	42100.00
0005432527010	7766	Business	42100.00
0005435212437	7766	Business	42100.00
0005434067080	7766	Business	42100.00
0005432527104	7766	Business	42100.00
0005432527053	7766	Business	42100.00
0005435212787	7766	Business	42100.00
0005432533271	7766	Business	42100.00
0005432526983	7766	Business	42100.00
0005435725515	7766	Business	42100.00
0005432527004	7766	Business	42100.00
0005434067041	7766	Business	42100.00
0005435212643	7766	Business	42100.00
0005432526976	7766	Business	42100.00
0005432527022	7766	Business	42100.00
0005432527065	7766	Business	42100.00
0005435725534	7766	Business	42100.00
0005435212785	7766	Business	42100.00
0005434067076	7766	Business	42100.00
0005432527073	7766	Business	42100.00
0005432069544	7766	Business	42100.00
0005432527098	7766	Business	42100.00
0005432527101	7766	Business	42100.00
0005435212663	7766	Business	42100.00
0005432069548	7766	Business	42100.00
0005435212460	7766	Comfort	23900.00
0005434067033	7766	Comfort	23900.00
0005432527025	7766	Comfort	23900.00
0005435212449	7766	Comfort	23900.00
0005434067058	7766	Comfort	23900.00
0005432527089	7766	Comfort	23900.00
0005435212558	7766	Comfort	23900.00
0005435212732	7766	Comfort	23900.00
0005432527054	7766	Comfort	23900.00
0005432428904	7766	Comfort	23900.00
0005432527050	7766	Comfort	23900.00
0005435212475	7766	Comfort	23900.00
0005434067091	7766	Comfort	23900.00
0005432069549	7766	Comfort	23900.00
0005435212501	7766	Comfort	23900.00
0005432526978	7766	Comfort	23900.00
0005435212461	7766	Comfort	23900.00
0005432150138	7766	Comfort	23900.00
0005435212398	7766	Comfort	23900.00
0005432527103	7766	Comfort	23900.00
0005432526979	7766	Comfort	23900.00
0005432527102	7766	Comfort	23900.00
0005432537042	7766	Comfort	23900.00
0005434067072	7766	Comfort	23900.00
0005432535799	7766	Comfort	23900.00
0005434067061	7766	Comfort	23900.00
0005435212361	7766	Comfort	23900.00
0005432069557	7766	Comfort	23900.00
0005435212452	7766	Comfort	23900.00
0005432150134	7766	Comfort	23900.00
0005434067054	7766	Comfort	23900.00
0005434067048	7766	Comfort	23900.00
0005432527006	7766	Comfort	23900.00
0005432527029	7766	Comfort	23900.00
0005432527085	7766	Comfort	23900.00
0005432535800	7766	Comfort	23900.00
0005435212486	7766	Economy	14000.00
0005432527040	7766	Economy	14000.00
0005432527020	7766	Economy	14000.00
0005434067040	7766	Economy	14000.00
0005435212644	7766	Economy	14000.00
0005435212518	7766	Economy	14000.00
0005435212662	7766	Economy	14000.00
0005432527091	7766	Economy	14000.00
0005432069547	7766	Economy	14000.00
0005435212733	7766	Economy	14000.00
0005432527036	7766	Economy	14000.00
0005435630928	7766	Economy	14000.00
0005432526987	7766	Economy	14000.00
0005435212543	7766	Economy	14000.00
0005432527001	7766	Economy	14000.00
0005432526991	7766	Economy	14000.00
0005432527059	7766	Economy	14000.00
0005434067090	7766	Economy	14000.00
0005432526998	7766	Economy	14000.00
0005432527048	7766	Economy	14000.00
0005434067073	7766	Economy	14000.00
0005435212519	7766	Economy	14000.00
0005432527076	7766	Economy	14000.00
0005435212467	7766	Economy	14000.00
0005432527064	7766	Economy	14000.00
0005432069558	7766	Economy	14000.00
0005435212566	7766	Economy	14000.00
0005432526993	7766	Economy	14000.00
0005432535801	7766	Economy	14000.00
0005434067036	7766	Economy	14000.00
0005434067047	7766	Economy	14000.00
0005435212642	7766	Economy	14000.00
0005434067074	7766	Economy	14000.00
0005435212533	7766	Economy	14000.00
0005434067038	7766	Economy	14000.00
0005432527094	7766	Economy	14000.00
0005434067052	7766	Economy	14000.00
0005432527079	7766	Economy	14000.00
0005435212590	7766	Economy	14000.00
0005433656616	7766	Economy	14000.00
0005432527075	7766	Economy	14000.00
0005432527078	7766	Economy	14000.00
0005432526999	7766	Economy	14000.00
0005432527107	7766	Economy	14000.00
0005432533269	7766	Economy	14000.00
0005432526996	7766	Economy	14000.00
0005435212532	7766	Economy	14000.00
0005432527088	7766	Economy	14000.00
0005432527069	7766	Economy	14000.00
0005432527038	7766	Economy	14000.00
0005432535798	7766	Economy	14000.00
0005434067059	7766	Economy	14000.00
0005434067055	7766	Economy	14000.00
0005435212774	7766	Economy	14000.00
0005432527082	7766	Economy	14000.00
0005435212435	7766	Economy	14000.00
0005435212421	7766	Economy	14000.00
0005432069553	7766	Economy	14000.00
0005432527068	7766	Economy	14000.00
0005432527108	7766	Economy	15400.00
0005435725524	7766	Economy	14000.00
0005432533270	7766	Economy	15400.00
0005432527087	7766	Economy	14000.00
0005432527044	7766	Economy	14000.00
0005432527042	7766	Economy	15400.00
0005432527034	7766	Economy	15400.00
0005432527084	7766	Economy	14000.00
0005434067043	7766	Economy	14000.00
0005434067077	7766	Economy	14000.00
0005434067023	7766	Economy	14000.00
0005434067086	7766	Economy	14000.00
0005432527019	7766	Economy	14000.00
0005432527097	7766	Economy	14000.00
0005435212389	7766	Economy	14000.00
0005432527031	7766	Economy	14000.00
0005435212500	7766	Economy	14000.00
0005432527046	7766	Economy	14000.00
0005432527047	7766	Economy	14000.00
0005432527009	7766	Economy	14000.00
0005432527070	7766	Economy	14000.00
0005434067082	7766	Economy	14000.00
0005432527041	7766	Economy	14000.00
0005432527008	7766	Economy	14000.00
0005432527014	7766	Economy	14000.00
0005432527074	7766	Economy	14000.00
0005435212586	7766	Economy	14000.00
0005432527060	7766	Economy	14000.00
0005432527095	7766	Economy	14000.00
0005432527057	7766	Economy	14000.00
0005434067032	7766	Economy	14000.00
0005432526986	7766	Economy	14000.00
0005432526992	7766	Economy	14000.00
0005432069551	7766	Economy	14000.00
0005432527051	7766	Economy	14000.00
0005435212459	7766	Economy	14000.00
0005432527056	7766	Economy	14000.00
0005434067053	7766	Economy	14000.00
0005432527105	7766	Economy	14000.00
0005434067063	7766	Economy	14000.00
0005434067030	7766	Economy	14000.00
0005435630921	7766	Economy	14000.00
0005432527062	7766	Economy	14000.00
0005432527013	7766	Economy	14000.00
0005434067044	7766	Economy	14000.00
0005432526994	7766	Economy	14000.00
0005432527063	7766	Economy	14000.00
0005434067068	7766	Economy	14000.00
0005432526982	7766	Economy	14000.00
0005432527080	7766	Economy	14000.00
0005432069545	7766	Economy	14000.00
0005432150141	7766	Economy	14000.00
0005432527015	7766	Economy	14000.00
0005435212672	7766	Economy	14000.00
0005435212619	7766	Economy	14000.00
0005434067062	7766	Economy	14000.00
0005432527055	7766	Economy	14000.00
0005434067071	7766	Economy	14000.00
0005432527083	7766	Economy	14000.00
0005435725523	7766	Economy	14000.00
0005434067028	7766	Economy	14000.00
0005432527037	7766	Economy	14000.00
0005434067069	7766	Economy	14000.00
0005435212786	7766	Economy	14000.00
0005432527067	7766	Economy	14000.00
0005434067089	7766	Economy	14000.00
0005435725516	7766	Economy	14000.00
0005432527093	7766	Economy	14000.00
0005434067024	7766	Economy	14000.00
0005432069555	7766	Economy	14000.00
0005432527005	7766	Economy	14000.00
0005432527017	7766	Economy	14000.00
0005435212339	7766	Economy	14000.00
0005435212485	7766	Economy	14000.00
0005434067060	7766	Economy	14000.00
0005432527077	7766	Economy	14000.00
0005432526984	7766	Economy	14000.00
0005432428903	7766	Economy	14000.00
0005435212534	7766	Economy	14000.00
0005434067075	7766	Economy	14000.00
0005432527099	7766	Economy	14000.00
0005435212775	7766	Economy	14000.00
0005434067022	7766	Economy	14000.00
0005435212451	7766	Economy	14000.00
0005432428902	7766	Economy	14000.00
0005434067029	7766	Economy	14000.00
0005435725530	7766	Economy	14000.00
0005432526997	7766	Economy	14000.00
0005434067049	7766	Economy	14000.00
0005434067093	7766	Economy	14000.00
0005435725531	7766	Economy	14000.00
0005434067087	7766	Economy	14000.00
0005434067046	7766	Economy	14000.00
0005432069554	7766	Economy	14000.00
0005435630927	7766	Economy	14000.00
0005435212436	7766	Economy	14000.00
0005432527021	7766	Economy	14000.00
0005434067067	7766	Economy	14000.00
0005435212384	7766	Economy	14000.00
0005434067057	7766	Economy	15400.00
0005432527043	7766	Economy	15400.00
0005432150142	7766	Economy	15400.00
0005432527106	7766	Economy	15400.00
0005434067039	7766	Economy	15400.00
0005432527039	7766	Economy	15400.00
0005432527052	7766	Economy	14000.00
0005435212535	7766	Economy	14000.00
0005432069546	7766	Economy	14000.00
0005434067085	7766	Economy	14000.00
0005432150140	7766	Economy	14000.00
0005435212571	7766	Economy	14000.00
0005435212528	7766	Economy	14000.00
0005435212544	7766	Economy	14000.00
0005432527024	7766	Economy	14000.00
0005432150139	7766	Economy	14000.00
0005432526990	7766	Economy	14000.00
0005432535796	7766	Economy	14000.00
0005432527109	7766	Economy	14000.00
0005435212673	7766	Economy	14000.00
0005434067084	7766	Economy	14000.00
0005432527049	7766	Economy	14000.00
0005432150135	7766	Economy	14000.00
0005435212658	7766	Economy	14000.00
0005432527002	7766	Economy	14000.00
0005432526988	7766	Economy	14000.00
0005432527026	7766	Economy	14000.00
0005435212393	7766	Economy	14000.00
0005432527090	7766	Economy	14000.00
0005435212773	7766	Economy	14000.00
0005434067079	7766	Economy	14000.00
0005434067050	7766	Economy	14000.00
0005435212567	7766	Economy	14000.00
0005432527096	7766	Economy	14000.00
0005432527028	7766	Economy	14000.00
0005434067092	7766	Economy	14000.00
0005432527032	7766	Economy	14000.00
0005434067081	7766	Economy	14000.00
0005434067066	7766	Economy	14000.00
0005432527035	7766	Economy	14000.00
0005432527058	7766	Economy	14000.00
0005434067031	7766	Economy	14000.00
0005432526981	7766	Economy	14000.00
0005432527030	7766	Economy	14000.00
0005434067045	7766	Economy	14000.00
0005432527000	7766	Economy	14000.00
0005434067037	7766	Economy	14000.00
0005432527061	7766	Economy	14000.00
0005432526977	7766	Economy	14000.00
0005432527012	7766	Economy	14000.00
0005432428905	7766	Economy	14000.00
0005435630922	7766	Economy	14000.00
0005432150137	7766	Economy	14000.00
0005432527072	7766	Economy	14000.00
0005435212385	7766	Economy	14000.00
0005432527023	7766	Economy	14000.00
0005432527033	7766	Economy	14000.00
0005432527016	7766	Economy	14000.00
0005434067051	7766	Economy	14000.00
0005432526995	7766	Economy	14000.00
0005432069550	7766	Economy	14000.00
0005432527018	7766	Economy	14000.00
0005434067026	7766	Economy	14000.00
0005434067027	7766	Economy	14000.00
0005432526985	7766	Economy	14000.00
0005434067065	7766	Economy	14000.00
0005434067025	7766	Economy	14000.00
0005432069556	7766	Economy	14000.00
0005434067034	7766	Economy	14000.00
0005432527011	7766	Economy	14000.00
0005435212465	7766	Economy	14000.00
0005435212772	7766	Economy	14000.00
0005432527045	7766	Economy	14000.00
0005432527100	7766	Economy	14000.00
0005432527003	7766	Economy	14000.00
0005434067070	7766	Economy	14000.00
0005435212493	7766	Economy	14000.00
0005432069543	7766	Economy	14000.00
0005432527066	7766	Economy	14000.00
0005432537043	7766	Economy	14000.00
0005435212442	7766	Economy	14000.00
0005434067083	7766	Economy	14000.00
0005432527081	7766	Economy	14000.00
0005432069552	7766	Economy	14000.00
0005432527007	7766	Economy	14000.00
0005434067088	7766	Economy	14000.00
0005432527027	7766	Economy	14000.00
0005434067035	7766	Economy	14000.00
0005434067078	7766	Economy	14000.00
0005432526980	7766	Economy	14000.00
0005432535797	7766	Economy	14000.00
0005434067056	7766	Economy	14000.00
0005432526989	7766	Economy	14000.00
0005435212466	7766	Economy	14000.00
0005435212472	7766	Economy	14000.00
0005434067042	7766	Economy	14000.00
0005432527092	7766	Economy	14000.00
0005435212779	7766	Economy	14000.00
0005435212394	7766	Economy	14000.00
0005434067021	7766	Economy	14000.00
0005432527071	7766	Economy	14000.00
0005432527086	7766	Economy	14000.00
0005432150136	7766	Economy	14000.00
0005435423973	5319	Business	43100.00
0005435423858	5319	Business	43100.00
0005435380237	5319	Business	43100.00
0005435612865	5319	Business	43100.00
0005434244577	5319	Business	43100.00
0005435423615	5319	Business	43100.00
0005434573250	5319	Business	43100.00
0005434343982	5319	Business	43100.00
0005434244471	5319	Business	43100.00
0005435423919	5319	Business	43100.00
0005435612815	5319	Business	43100.00
0005434343987	5319	Business	43100.00
0005432133099	5319	Business	43100.00
0005435612905	5319	Business	43100.00
0005435612824	5319	Business	43100.00
0005435424102	5319	Business	43100.00
0005432133104	5319	Business	43100.00
0005432047523	5319	Business	43100.00
0005435490199	5319	Business	43100.00
0005432133101	5319	Business	43100.00
0005435612825	5319	Business	43100.00
0005435612879	5319	Business	43100.00
0005435612831	5319	Comfort	24400.00
0005435612846	5319	Comfort	24400.00
0005435612875	5319	Comfort	24400.00
0005434244576	5319	Comfort	24400.00
0005435612853	5319	Comfort	24400.00
0005435612804	5319	Comfort	24400.00
0005434573256	5319	Comfort	24400.00
0005435612855	5319	Comfort	24400.00
0005432133095	5319	Comfort	24400.00
0005435612867	5319	Comfort	24400.00
0005435612830	5319	Comfort	24400.00
0005432363370	5319	Comfort	24400.00
0005435423784	5319	Comfort	24400.00
0005434343979	5319	Comfort	24400.00
0005434244469	5319	Comfort	24400.00
0005435423683	5319	Comfort	24400.00
0005435612829	5319	Comfort	24400.00
0005435612833	5319	Comfort	24400.00
0005435319454	5319	Comfort	24400.00
0005434244501	5319	Comfort	24400.00
0005434343985	5319	Comfort	24400.00
0005435612864	5319	Comfort	24400.00
0005434573260	5319	Comfort	24400.00
0005434573247	5319	Comfort	24400.00
0005434343986	5319	Comfort	24400.00
0005435612802	5319	Comfort	24400.00
0005435612810	5319	Comfort	24400.00
0005435423738	5319	Comfort	24400.00
0005435612873	5319	Comfort	24400.00
0005435612803	5319	Comfort	24400.00
0005434244575	5319	Comfort	24400.00
0005435612857	5319	Comfort	24400.00
0005435612832	5319	Comfort	24400.00
0005435423756	5319	Comfort	24400.00
0005432047524	5319	Economy	14400.00
0005435423824	5319	Economy	14400.00
0005435612807	5319	Economy	14400.00
0005434244508	5319	Economy	14400.00
0005435490201	5319	Economy	14400.00
0005434343951	5319	Economy	14400.00
0005435612823	5319	Economy	14400.00
0005435423980	5319	Economy	14400.00
0005434343977	5319	Economy	14400.00
0005435612808	5319	Economy	14400.00
0005435423874	5319	Economy	14400.00
0005435612843	5319	Economy	14400.00
0005435319471	5319	Economy	14400.00
0005435424131	5319	Economy	14400.00
0005435423773	5319	Economy	14400.00
0005435612813	5319	Economy	14400.00
0005435612882	5319	Economy	14400.00
0005435612869	5319	Economy	14400.00
0005435424016	5319	Economy	14400.00
0005435612800	5319	Economy	14400.00
0005434343968	5319	Economy	14400.00
0005434573251	5319	Economy	14400.00
0005435612811	5319	Economy	14400.00
0005434343967	5319	Economy	14400.00
0005435612883	5319	Economy	14400.00
0005432133102	5319	Economy	14400.00
0005435490200	5319	Economy	14400.00
0005435612837	5319	Economy	14400.00
0005435612889	5319	Economy	14400.00
0005435612878	5319	Economy	14400.00
0005435423646	5319	Economy	14400.00
0005435555354	5319	Economy	14400.00
0005434656529	5319	Economy	14400.00
0005435612821	5319	Economy	14400.00
0005434343952	5319	Economy	14400.00
0005435612891	5319	Economy	14400.00
0005434343984	5319	Economy	14400.00
0005435612897	5319	Economy	14400.00
0005435612902	5319	Economy	14400.00
0005433719080	5319	Economy	14400.00
0005434244487	5319	Economy	14400.00
0005432363369	5319	Economy	14400.00
0005435424101	5319	Economy	14400.00
0005434343970	5319	Economy	14400.00
0005435423783	5319	Economy	15800.00
0005434244643	5319	Economy	15800.00
0005435612858	5319	Economy	15800.00
0005435424110	5319	Economy	14400.00
0005432363368	5319	Economy	14400.00
0005432133110	5319	Economy	14400.00
0005434573253	5319	Economy	15800.00
0005432133100	5319	Economy	15800.00
0005435423739	5319	Economy	14400.00
0005435423606	5319	Economy	15800.00
0005434244543	5319	Economy	14400.00
0005435423678	5319	Economy	14400.00
0005432047522	5319	Economy	14400.00
0005434343972	5319	Economy	14400.00
0005435423859	5319	Economy	14400.00
0005435097145	5319	Economy	14400.00
0005435612816	5319	Economy	14400.00
0005435423672	5319	Economy	14400.00
0005435423797	5319	Economy	14400.00
0005434244472	5319	Economy	14400.00
0005435612841	5319	Economy	14400.00
0005435423686	5319	Economy	14400.00
0005432047521	5319	Economy	14400.00
0005435612884	5319	Economy	14400.00
0005435424127	5319	Economy	14400.00
0005435612863	5319	Economy	14400.00
0005434244509	5319	Economy	14400.00
0005432133105	5319	Economy	14400.00
0005435423670	5319	Economy	14400.00
0005435423981	5319	Economy	14400.00
0005435612819	5319	Economy	14400.00
0005435612887	5319	Economy	14400.00
0005434343957	5319	Economy	14400.00
0005435423684	5319	Economy	14400.00
0005434343955	5319	Economy	14400.00
0005435612861	5319	Economy	14400.00
0005434343961	5319	Economy	14400.00
0005435612866	5319	Economy	14400.00
0005435097143	5319	Economy	14400.00
0005435423829	5319	Economy	14400.00
0005435612856	5319	Economy	14400.00
0005434244493	5319	Economy	14400.00
0005435612877	5319	Economy	14400.00
0005434343950	5319	Economy	14400.00
0005435319438	5319	Economy	14400.00
0005434244554	5319	Economy	14400.00
0005434244601	5319	Economy	14400.00
0005432133106	5319	Economy	14400.00
0005435423582	5319	Economy	14400.00
0005435319475	5319	Economy	14400.00
0005435612859	5319	Economy	14400.00
0005435424126	5319	Economy	14400.00
0005435319449	5319	Economy	14400.00
0005435423927	5319	Economy	14400.00
0005432133098	5319	Economy	14400.00
0005435612818	5319	Economy	14400.00
0005435612854	5319	Economy	14400.00
0005435612847	5319	Economy	14400.00
0005435319444	5319	Economy	14400.00
0005434343975	5319	Economy	14400.00
0005434343959	5319	Economy	14400.00
0005434656522	5319	Economy	14400.00
0005434343949	5319	Economy	14400.00
0005435423846	5319	Economy	14400.00
0005435423720	5319	Economy	14400.00
0005435612893	5319	Economy	14400.00
0005435423764	5319	Economy	14400.00
0005435612899	5319	Economy	14400.00
0005435612898	5319	Economy	14400.00
0005435424247	5319	Economy	14400.00
0005435612852	5319	Economy	14400.00
0005435612838	5319	Economy	14400.00
0005435612848	5319	Economy	14400.00
0005435424100	5319	Economy	14400.00
0005435612890	5319	Economy	14400.00
0005434244500	5319	Economy	14400.00
0005434343978	5319	Economy	14400.00
0005435424132	5319	Economy	14400.00
0005434343973	5319	Economy	14400.00
0005434343983	5319	Economy	14400.00
0005435612834	5319	Economy	14400.00
0005435612809	5319	Economy	14400.00
0005433719081	5319	Economy	14400.00
0005435423938	5319	Economy	14400.00
0005435612801	5319	Economy	14400.00
0005434343976	5319	Economy	14400.00
0005433719083	5319	Economy	14400.00
0005434244603	5319	Economy	14400.00
0005435612839	5319	Economy	14400.00
0005435423972	5319	Economy	14400.00
0005435612894	5319	Economy	14400.00
0005432363371	5319	Economy	14400.00
0005435612840	5319	Economy	14400.00
0005435423719	5319	Economy	14400.00
0005435302136	5319	Economy	14400.00
0005432133103	5319	Economy	14400.00
0005435097141	5319	Economy	14400.00
0005435612844	5319	Economy	14400.00
0005435612892	5319	Economy	14400.00
0005434343963	5319	Economy	14400.00
0005435612828	5319	Economy	14400.00
0005434343953	5319	Economy	14400.00
0005434343962	5319	Economy	14400.00
0005435612868	5319	Economy	14400.00
0005435612870	5319	Economy	15800.00
0005434573246	5319	Economy	15800.00
0005434244542	5319	Economy	15800.00
0005435423951	5319	Economy	15800.00
0005434656525	5319	Economy	15800.00
0005434573258	5319	Economy	14400.00
0005434343954	5319	Economy	14400.00
0005435612826	5319	Economy	14400.00
0005434244564	5319	Economy	14400.00
0005435302124	5319	Economy	14400.00
0005434573259	5319	Economy	14400.00
0005435302125	5319	Economy	14400.00
0005435612904	5319	Economy	14400.00
0005432133107	5319	Economy	14400.00
0005435612820	5319	Economy	14400.00
0005435319447	5319	Economy	14400.00
0005435612836	5319	Economy	14400.00
0005434343971	5319	Economy	14400.00
0005434343965	5319	Economy	14400.00
0005434573254	5319	Economy	14400.00
0005435612817	5319	Economy	14400.00
0005435612827	5319	Economy	14400.00
0005432133096	5319	Economy	14400.00
0005434343958	5319	Economy	14400.00
0005435612851	5319	Economy	14400.00
0005432133097	5319	Economy	14400.00
0005434343964	5319	Economy	14400.00
0005435612885	5319	Economy	14400.00
0005435612812	5319	Economy	14400.00
0005435423804	5319	Economy	14400.00
0005435423655	5319	Economy	14400.00
0005432133109	5319	Economy	14400.00
0005435612862	5319	Economy	14400.00
0005435097144	5319	Economy	14400.00
0005435612881	5319	Economy	14400.00
0005435612896	5319	Economy	14400.00
0005435491427	5319	Economy	14400.00
0005435423845	5319	Economy	14400.00
0005435423920	5319	Economy	14400.00
0005432133108	5319	Economy	14400.00
0005435423921	5319	Economy	14400.00
0005434343960	5319	Economy	14400.00
0005435555355	5319	Economy	14400.00
0005434343966	5319	Economy	14400.00
0005435423823	5319	Economy	14400.00
0005434573257	5319	Economy	14400.00
0005435612814	5319	Economy	14400.00
0005435612806	5319	Economy	14400.00
0005435612880	5319	Economy	14400.00
0005435612822	5319	Economy	14400.00
0005435490202	5319	Economy	14400.00
0005435612835	5319	Economy	14400.00
0005435612900	5319	Economy	14400.00
0005435423766	5319	Economy	14400.00
0005435423798	5319	Economy	14400.00
0005434343974	5319	Economy	14400.00
0005435423755	5319	Economy	14400.00
0005435612860	5319	Economy	14400.00
0005435423952	5319	Economy	14400.00
0005434343969	5319	Economy	14400.00
0005434343980	5319	Economy	14400.00
0005435612888	5319	Economy	14400.00
0005435612901	5319	Economy	14400.00
0005435423979	5319	Economy	14400.00
0005434244574	5319	Economy	14400.00
0005435423803	5319	Economy	14400.00
0005435612903	5319	Economy	14400.00
0005434244597	5319	Economy	14400.00
0005435319456	5319	Economy	14400.00
0005435491426	5319	Economy	14400.00
0005434573252	5319	Economy	14400.00
0005434573249	5319	Economy	14400.00
0005435423909	5319	Economy	14400.00
0005435097142	5319	Economy	14400.00
0005435612850	5319	Economy	14400.00
0005435612845	5319	Economy	14400.00
0005434343981	5319	Economy	14400.00
0005435612895	5319	Economy	14400.00
0005435612849	5319	Economy	14400.00
0005434573255	5319	Economy	14400.00
0005435612805	5319	Economy	14400.00
0005434244497	5319	Economy	14400.00
0005435612842	5319	Economy	14400.00
0005434244470	5319	Economy	14400.00
0005435612871	5319	Economy	14400.00
0005435612874	5319	Economy	14400.00
0005435612876	5319	Economy	14400.00
0005435612872	5319	Economy	14400.00
0005434573248	5319	Economy	14400.00
0005435423932	5319	Economy	14400.00
0005434343956	5319	Economy	14400.00
0005434244602	5319	Economy	14400.00
0005435319461	5319	Economy	14400.00
0005435319448	5319	Economy	14400.00
0005435612886	5319	Economy	14400.00
0005435423687	5319	Economy	14400.00
0005435612137	10885	Business	43100.00
0005435611941	10885	Business	43100.00
0005434343587	10885	Business	43100.00
0005435611995	10885	Business	43100.00
0005433719117	10885	Business	43100.00
0005435611998	10885	Business	43100.00
0005435424315	10885	Business	43100.00
0005435424327	10885	Business	43100.00
0005435611704	10885	Business	43100.00
0005435424305	10885	Business	43100.00
0005435424286	10885	Business	43100.00
0005435611811	10885	Business	43100.00
0005435424299	10885	Business	43100.00
0005434573163	10885	Business	43100.00
0005434244784	10885	Business	43100.00
0005434343588	10885	Business	43100.00
0005435611964	10885	Business	43100.00
0005434573164	10885	Business	43100.00
0005435611808	10885	Business	43100.00
0005435424284	10885	Business	43100.00
0005432840998	10885	Business	43100.00
0005434244783	10885	Comfort	24400.00
0005435611857	10885	Business	43100.00
0005435424300	10885	Comfort	24400.00
0005435424311	10885	Comfort	24400.00
0005435424348	10885	Comfort	24400.00
0005435612283	10885	Comfort	24400.00
0005435611900	10885	Comfort	24400.00
0005432164986	10885	Comfort	24400.00
0005434343628	10885	Comfort	24400.00
0005435611804	10885	Comfort	24400.00
0005435611875	10885	Comfort	24400.00
0005435612058	10885	Comfort	24400.00
0005434343645	10885	Comfort	24400.00
0005434573116	10885	Comfort	24400.00
0005435424318	10885	Comfort	24400.00
0005435612153	10885	Comfort	24400.00
0005435612056	10885	Comfort	24400.00
0005435612077	10885	Comfort	24400.00
0005435380261	10885	Comfort	24400.00
0005435611779	10885	Comfort	24400.00
0005435611937	10885	Comfort	24400.00
0005435611979	10885	Comfort	24400.00
0005435304123	10885	Comfort	24400.00
0005435424336	10885	Comfort	24400.00
0005432166879	10885	Comfort	24400.00
0005435424319	10885	Comfort	24400.00
0005435424292	10885	Comfort	24400.00
0005435611767	10885	Comfort	24400.00
0005435491408	10885	Comfort	24400.00
0005434343699	10885	Comfort	24400.00
0005434244769	10885	Comfort	24400.00
0005435491412	10885	Economy	14400.00
0005434343648	10885	Economy	14400.00
0005435611869	10885	Economy	14400.00
0005435380260	10885	Economy	14400.00
0005435097089	10885	Economy	14400.00
0005434244754	10885	Economy	14400.00
0005435611883	10885	Economy	14400.00
0005434244768	10885	Economy	14400.00
0005434244780	10885	Economy	14400.00
0005435319510	10885	Economy	14400.00
0005435304124	10885	Economy	14400.00
0005435611772	10885	Economy	14400.00
0005435612027	10885	Economy	14400.00
0005435611973	10885	Economy	14400.00
0005435424340	10885	Economy	14400.00
0005435380262	10885	Economy	14400.00
0005435424320	10885	Economy	14400.00
0005432164980	10885	Economy	14400.00
0005435611768	10885	Economy	14400.00
0005435424280	10885	Economy	14400.00
0005435424298	10885	Economy	14400.00
0005434343710	10885	Economy	14400.00
0005432164979	10885	Economy	14400.00
0005434343597	10885	Economy	14400.00
0005435424321	10885	Economy	14400.00
0005434244766	10885	Economy	14400.00
0005435612035	10885	Economy	14400.00
0005433719118	10885	Economy	14400.00
0005435611814	10885	Economy	14400.00
0005434244771	10885	Economy	14400.00
0005434244776	10885	Economy	14400.00
0005435611936	10885	Economy	14400.00
0005434656542	10885	Economy	14400.00
0005435424297	10885	Economy	14400.00
0005435611885	10885	Economy	14400.00
0005433719116	10885	Economy	14400.00
0005435611967	10885	Economy	14400.00
0005434343630	10885	Economy	14400.00
0005432164981	10885	Economy	14400.00
0005434343621	10885	Economy	14400.00
0005434573130	10885	Economy	14400.00
0005435611924	10885	Economy	14400.00
0005435319513	10885	Economy	14400.00
0005434244772	10885	Economy	14400.00
0005435611809	10885	Economy	14400.00
0005435611996	10885	Economy	14400.00
0005435424314	10885	Economy	14400.00
0005435424322	10885	Economy	14400.00
0005432363393	10885	Economy	14400.00
0005435424288	10885	Economy	14400.00
0005435424349	10885	Economy	14400.00
0005434244757	10885	Economy	14400.00
0005435612105	10885	Economy	14400.00
0005435424313	10885	Economy	14400.00
0005435424341	10885	Economy	14400.00
0005435612089	10885	Economy	14400.00
0005435097063	10885	Economy	14400.00
0005434343583	10885	Economy	14400.00
0005435424295	10885	Economy	14400.00
0005435424332	10885	Economy	14400.00
0005434343598	10885	Economy	15800.00
0005435612260	10885	Economy	15800.00
0005432840997	10885	Economy	14400.00
0005432363392	10885	Economy	14400.00
0005435304125	10885	Economy	14400.00
0005435424324	10885	Economy	14400.00
0005434244762	10885	Economy	14400.00
0005435424283	10885	Economy	14400.00
0005434244777	10885	Economy	14400.00
0005435424338	10885	Economy	14400.00
0005435611741	10885	Economy	14400.00
0005434343684	10885	Economy	14400.00
0005435611939	10885	Economy	14400.00
0005435612020	10885	Economy	14400.00
0005435424345	10885	Economy	14400.00
0005434244785	10885	Economy	14400.00
0005435380263	10885	Economy	14400.00
0005434244779	10885	Economy	14400.00
0005434244767	10885	Economy	14400.00
0005435304122	10885	Economy	14400.00
0005435424281	10885	Economy	14400.00
0005435424330	10885	Economy	14400.00
0005435611813	10885	Economy	14400.00
0005435612218	10885	Economy	14400.00
0005435555343	10885	Economy	14400.00
0005434244781	10885	Economy	14400.00
0005435611958	10885	Economy	14400.00
0005435612149	10885	Economy	14400.00
0005435611985	10885	Economy	14400.00
0005435424337	10885	Economy	14400.00
0005435611807	10885	Economy	14400.00
0005435611805	10885	Economy	14400.00
0005435611918	10885	Economy	14400.00
0005432164985	10885	Economy	14400.00
0005435612135	10885	Economy	14400.00
0005435611930	10885	Economy	14400.00
0005434343609	10885	Economy	14400.00
0005432166876	10885	Economy	14400.00
0005432164984	10885	Economy	14400.00
0005435612098	10885	Economy	14400.00
0005434343611	10885	Economy	14400.00
0005434244758	10885	Economy	14400.00
0005435612187	10885	Economy	14400.00
0005435611780	10885	Economy	14400.00
0005435612316	10885	Economy	14400.00
0005434244764	10885	Economy	14400.00
0005435304126	10885	Economy	14400.00
0005435611923	10885	Economy	14400.00
0005434343610	10885	Economy	14400.00
0005435611858	10885	Economy	14400.00
0005435611781	10885	Economy	14400.00
0005435424287	10885	Economy	14400.00
0005435611730	10885	Economy	14400.00
0005435424308	10885	Economy	14400.00
0005434573141	10885	Economy	14400.00
0005435611974	10885	Economy	14400.00
0005435611959	10885	Economy	14400.00
0005434244761	10885	Economy	14400.00
0005435424317	10885	Economy	14400.00
0005435424333	10885	Economy	14400.00
0005435042837	10885	Economy	14400.00
0005435612078	10885	Economy	14400.00
0005435612026	10885	Economy	14400.00
0005435611812	10885	Economy	14400.00
0005435424291	10885	Economy	14400.00
0005435611751	10885	Economy	14400.00
0005434244755	10885	Economy	14400.00
0005434343663	10885	Economy	14400.00
0005435424339	10885	Economy	14400.00
0005435424302	10885	Economy	14400.00
0005432164982	10885	Economy	14400.00
0005435612315	10885	Economy	14400.00
0005435319509	10885	Economy	14400.00
0005435424326	10885	Economy	14400.00
0005434343599	10885	Economy	14400.00
0005434244760	10885	Economy	14400.00
0005435611997	10885	Economy	14400.00
0005435612182	10885	Economy	14400.00
0005435612049	10885	Economy	14400.00
0005435424329	10885	Economy	14400.00
0005435424282	10885	Economy	14400.00
0005432363391	10885	Economy	14400.00
0005435319508	10885	Economy	14400.00
0005435611971	10885	Economy	14400.00
0005435611778	10885	Economy	14400.00
0005434573183	10885	Economy	14400.00
0005435424306	10885	Economy	14400.00
0005435424342	10885	Economy	14400.00
0005434244770	10885	Economy	14400.00
0005435097062	10885	Economy	14400.00
0005434573168	10885	Economy	14400.00
0005434244759	10885	Economy	15800.00
0005435611934	10885	Economy	15800.00
0005435491411	10885	Economy	15800.00
0005435319511	10885	Economy	15800.00
0005435611966	10885	Economy	15800.00
0005435424312	10885	Economy	15800.00
0005434244774	10885	Economy	14400.00
0005434244778	10885	Economy	14400.00
0005434343631	10885	Economy	14400.00
0005435611925	10885	Economy	14400.00
0005435424304	10885	Economy	14400.00
0005435424294	10885	Economy	14400.00
0005435424309	10885	Economy	14400.00
0005434244763	10885	Economy	14400.00
0005434343589	10885	Economy	14400.00
0005434573175	10885	Economy	14400.00
0005435424323	10885	Economy	14400.00
0005435424346	10885	Economy	14400.00
0005435424344	10885	Economy	14400.00
0005432166877	10885	Economy	14400.00
0005435611870	10885	Economy	14400.00
0005435611848	10885	Economy	14400.00
0005435611892	10885	Economy	14400.00
0005435612097	10885	Economy	14400.00
0005435424307	10885	Economy	14400.00
0005435424293	10885	Economy	14400.00
0005434244765	10885	Economy	14400.00
0005435612285	10885	Economy	14400.00
0005435042838	10885	Economy	14400.00
0005435424285	10885	Economy	14400.00
0005435612120	10885	Economy	14400.00
0005434343606	10885	Economy	14400.00
0005435612136	10885	Economy	14400.00
0005435097045	10885	Economy	14400.00
0005434244775	10885	Economy	14400.00
0005435611927	10885	Economy	14400.00
0005435612012	10885	Economy	14400.00
0005435424290	10885	Economy	14400.00
0005435424296	10885	Economy	14400.00
0005435611742	10885	Economy	14400.00
0005435611931	10885	Economy	14400.00
0005435612183	10885	Economy	14400.00
0005434343672	10885	Economy	14400.00
0005434343703	10885	Economy	14400.00
0005435424343	10885	Economy	14400.00
0005434244756	10885	Economy	14400.00
0005435611705	10885	Economy	14400.00
0005435424303	10885	Economy	14400.00
0005432166878	10885	Economy	14400.00
0005434656541	10885	Economy	14400.00
0005434343605	10885	Economy	14400.00
0005435612121	10885	Economy	14400.00
0005435424350	10885	Economy	14400.00
0005435424316	10885	Economy	14400.00
0005435424347	10885	Economy	14400.00
0005435612147	10885	Economy	14400.00
0005435424334	10885	Economy	14400.00
0005435611929	10885	Economy	14400.00
0005435612096	10885	Economy	14400.00
0005434343673	10885	Economy	14400.00
0005435612095	10885	Economy	14400.00
0005435490170	10885	Economy	14400.00
0005435612059	10885	Economy	14400.00
0005435097044	10885	Economy	14400.00
0005435611926	10885	Economy	14400.00
0005435424310	10885	Economy	14400.00
0005435611986	10885	Economy	14400.00
0005432164983	10885	Economy	14400.00
0005435612327	10885	Economy	14400.00
0005435319512	10885	Economy	14400.00
0005435424301	10885	Economy	14400.00
0005435424289	10885	Economy	14400.00
0005435611957	10885	Economy	14400.00
0005435611899	10885	Economy	14400.00
0005435612227	10885	Economy	14400.00
0005435424325	10885	Economy	14400.00
0005434343664	10885	Economy	14400.00
0005435424335	10885	Economy	14400.00
0005435611749	10885	Economy	14400.00
0005435611795	10885	Economy	14400.00
0005434343649	10885	Economy	14400.00
0005435612144	10885	Economy	14400.00
0005434343709	10885	Economy	14400.00
0005435319507	10885	Economy	14400.00
0005432363394	10885	Economy	14400.00
0005435424331	10885	Economy	14400.00
0005435612266	10885	Economy	14400.00
0005433719115	10885	Economy	14400.00
0005435319506	10885	Economy	14400.00
0005435611773	10885	Economy	14400.00
0005434244782	10885	Economy	14400.00
0005435424328	10885	Economy	14400.00
0005434244773	10885	Economy	14400.00
0005432181563	3398	Business	18800.00
0005433633590	3398	Business	18800.00
0005432458974	3398	Business	18800.00
0005432181552	3398	Business	18800.00
0005432181565	3398	Business	18800.00
0005432459094	3398	Business	18800.00
0005433633592	3398	Business	18800.00
0005433633598	3398	Business	18800.00
0005432181561	3398	Business	18800.00
0005433633580	3398	Business	18800.00
0005432459110	3398	Business	18800.00
0005432459034	3398	Business	18800.00
0005433633574	3398	Business	18800.00
0005432459017	3398	Business	18800.00
0005433805121	3398	Business	18800.00
0005433507053	3398	Business	18800.00
0005433507046	3398	Business	18800.00
0005432181555	3398	Business	18800.00
0005433633568	3398	Business	18800.00
0005432181566	3398	Business	18800.00
0005432458976	3398	Business	18800.00
0005433507052	3398	Business	18800.00
0005432459095	3398	Business	18800.00
0005432459151	3398	Business	18800.00
0005432459109	3398	Business	18800.00
0005433633564	3398	Economy	6900.00
0005432459113	3398	Economy	6900.00
0005433633588	3398	Economy	6900.00
0005432459108	3398	Economy	6900.00
0005432181558	3398	Economy	6300.00
0005433507055	3398	Economy	6300.00
0005433633591	3398	Economy	6300.00
0005432459131	3398	Economy	6300.00
0005432459006	3398	Economy	6300.00
0005432459146	3398	Economy	6300.00
0005432459156	3398	Economy	6300.00
0005432458977	3398	Economy	6300.00
0005433633589	3398	Economy	6300.00
0005433633569	3398	Economy	6300.00
0005432459194	3398	Economy	6300.00
0005432181548	3398	Economy	6300.00
0005433633585	3398	Economy	6300.00
0005433507054	3398	Economy	6300.00
0005432181547	3398	Economy	6300.00
0005432459055	3398	Economy	6300.00
0005433805120	3398	Economy	6300.00
0005432459071	3398	Economy	6300.00
0005432458983	3398	Economy	6300.00
0005432459044	3398	Economy	6300.00
0005432459114	3398	Economy	6300.00
0005433633577	3398	Economy	6300.00
0005432459165	3398	Economy	6300.00
0005432459093	3398	Economy	6300.00
0005432459073	3398	Economy	6300.00
0005432181549	3398	Economy	6300.00
0005433633575	3398	Economy	6300.00
0005432459058	3398	Economy	6300.00
0005433633596	3398	Economy	6300.00
0005432459111	3398	Economy	6300.00
0005433507047	3398	Economy	6300.00
0005433633594	3398	Economy	6300.00
0005433805125	3398	Economy	6300.00
0005432459047	3398	Economy	6300.00
0005433633562	3398	Economy	6300.00
0005432459193	3398	Economy	6300.00
0005433507051	3398	Economy	6300.00
0005433633570	3398	Economy	6300.00
0005433507044	3398	Economy	6300.00
0005433633571	3398	Economy	6300.00
0005433633572	3398	Economy	6300.00
0005432181568	3398	Economy	6300.00
0005432459152	3398	Economy	6300.00
0005432458966	3398	Economy	6300.00
0005433507061	3398	Economy	6300.00
0005432458994	3398	Economy	6300.00
0005432181556	3398	Economy	6300.00
0005432459106	3398	Economy	6300.00
0005432459150	3398	Economy	6300.00
0005432181557	3398	Economy	6300.00
0005432459054	3398	Economy	6300.00
0005433805124	3398	Economy	6900.00
0005433633573	3398	Economy	6900.00
0005432459379	3398	Economy	6900.00
0005433507048	3398	Economy	6900.00
0005433633595	3398	Economy	6300.00
0005433507060	3398	Economy	6300.00
0005432459166	3398	Economy	6300.00
0005432181551	3398	Economy	6300.00
0005433633581	3398	Economy	6900.00
0005433633584	3398	Economy	6300.00
0005432459046	3398	Economy	6300.00
0005432181567	3398	Economy	6300.00
0005432459155	3398	Economy	6300.00
0005433805119	3398	Economy	6300.00
0005433805122	3398	Economy	6300.00
0005432459053	3398	Economy	6300.00
0005432459163	3398	Economy	6300.00
0005433633582	3398	Economy	6300.00
0005432459074	3398	Economy	6300.00
0005432459099	3398	Economy	6300.00
0005432459069	3398	Economy	6300.00
0005433633579	3398	Economy	6300.00
0005433507043	3398	Economy	6300.00
0005432181553	3398	Economy	6300.00
0005433633576	3398	Economy	6300.00
0005432181559	3398	Economy	6300.00
0005432181564	3398	Economy	6300.00
0005432459135	3398	Economy	6300.00
0005432459010	3398	Economy	6300.00
0005432459147	3398	Economy	6300.00
0005433633593	3398	Economy	6300.00
0005433507059	3398	Economy	6300.00
0005433633567	3398	Economy	6300.00
0005433633586	3398	Economy	6300.00
0005432459170	3398	Economy	6300.00
0005432458963	3398	Economy	6300.00
0005432459169	3398	Economy	6300.00
0005433507049	3398	Economy	6300.00
0005433633578	3398	Economy	6300.00
0005433805123	3398	Economy	6300.00
0005432459157	3398	Economy	6300.00
0005433633587	3398	Economy	6300.00
0005433633566	3398	Economy	6300.00
0005433633597	3398	Economy	6300.00
0005433507057	3398	Economy	6300.00
0005432459011	3398	Economy	6300.00
0005432459107	3398	Economy	6300.00
0005433507050	3398	Economy	6300.00
0005432459270	3398	Economy	6300.00
0005432459045	3398	Economy	6300.00
0005432181554	3398	Economy	6300.00
0005432459138	3398	Economy	6300.00
0005432181560	3398	Economy	6300.00
0005433633565	3398	Economy	6300.00
0005433507058	3398	Economy	6300.00
0005432458962	3398	Economy	6300.00
0005432459059	3398	Economy	6300.00
0005433507056	3398	Economy	6300.00
0005433633583	3398	Economy	6300.00
0005432458993	3398	Economy	6300.00
0005432181562	3398	Economy	6300.00
0005433507045	3398	Economy	6300.00
0005433633563	3398	Economy	6300.00
0005432459086	3398	Economy	6300.00
0005432181550	3398	Economy	6300.00
0005432459164	3398	Economy	6300.00
0005432459271	3398	Economy	6300.00
0005435884488	3399	Business	18800.00
0005435884701	3399	Business	18800.00
0005435884690	3399	Business	18800.00
0005435884552	3399	Business	18800.00
0005435884443	3399	Business	18800.00
0005435884717	3399	Business	18800.00
0005435884718	3399	Business	18800.00
0005435884572	3399	Economy	6900.00
0005435884604	3399	Economy	6900.00
0005435884719	3399	Economy	6300.00
0005435884650	3399	Economy	6300.00
0005435884789	3399	Economy	6300.00
0005435884788	3399	Economy	6300.00
0005435884431	3399	Economy	6300.00
0005435884700	3399	Economy	6300.00
0005435884527	3399	Economy	6300.00
0005435884458	3399	Economy	6300.00
0005435884581	3399	Economy	6300.00
0005435884671	3399	Economy	6300.00
0005435884440	3399	Economy	6300.00
0005435884656	3399	Economy	6300.00
0005435884588	3399	Economy	6300.00
0005435884509	3399	Economy	6300.00
0005435884670	3399	Economy	6900.00
0005435884702	3399	Economy	6900.00
0005435884578	3399	Economy	6300.00
0005435884571	3399	Economy	6300.00
0005435884439	3399	Economy	6300.00
0005435884657	3399	Economy	6300.00
0005435884603	3399	Economy	6300.00
0005435884790	3399	Economy	6300.00
0005435884489	3399	Economy	6300.00
0005435884587	3399	Economy	6300.00
0005435884731	3399	Economy	6300.00
0005435884781	3399	Economy	6300.00
0005435884524	3399	Economy	6300.00
0005435884542	3399	Economy	6300.00
0005435884420	3399	Economy	6300.00
0005435884549	3399	Economy	6300.00
0005435884675	3399	Economy	6300.00
0005435884890	8334	Business	18800.00
0005432459533	8334	Business	18800.00
0005432459522	8334	Business	18800.00
0005432459490	8334	Business	18800.00
0005435884871	8334	Business	18800.00
0005432459530	8334	Business	18800.00
0005435884901	8334	Business	18800.00
0005432459526	8334	Business	18800.00
0005435884878	8334	Business	18800.00
0005435884875	8334	Business	18800.00
0005432042610	8334	Business	18800.00
0005434326267	8334	Business	18800.00
0005435884896	8334	Business	18800.00
0005435884899	8334	Business	18800.00
0005432459527	8334	Business	18800.00
0005435884872	8334	Business	18800.00
0005432459514	8334	Business	18800.00
0005432459536	8334	Business	18800.00
0005434312307	8334	Business	18800.00
0005432042616	8334	Business	18800.00
0005432459544	8334	Business	18800.00
0005432459515	8334	Business	18800.00
0005432042618	8334	Business	18800.00
0005432459525	8334	Business	18800.00
0005432042622	8334	Economy	6900.00
0005435884897	8334	Economy	6900.00
0005432459528	8334	Economy	6900.00
0005432459520	8334	Economy	6900.00
0005432459538	8334	Economy	6300.00
0005432459543	8334	Economy	6300.00
0005432459507	8334	Economy	6300.00
0005432459504	8334	Economy	6300.00
0005435884888	8334	Economy	6300.00
0005433506896	8334	Economy	6300.00
0005432459529	8334	Economy	6300.00
0005435884894	8334	Economy	6300.00
0005432459501	8334	Economy	6300.00
0005432459495	8334	Economy	6300.00
0005432459516	8334	Economy	6300.00
0005435884869	8334	Economy	6300.00
0005435884895	8334	Economy	6300.00
0005432459508	8334	Economy	6300.00
0005432459531	8334	Economy	6300.00
0005432459505	8334	Economy	6300.00
0005432042625	8334	Economy	6300.00
0005433506908	8334	Economy	6300.00
0005433506928	8334	Economy	6300.00
0005435884882	8334	Economy	6300.00
0005435884881	8334	Economy	6300.00
0005432459535	8334	Economy	6300.00
0005432042609	8334	Economy	6300.00
0005432042619	8334	Economy	6300.00
0005432459534	8334	Economy	6300.00
0005435884876	8334	Economy	6300.00
0005432459537	8334	Economy	6300.00
0005433506882	8334	Economy	6300.00
0005432459512	8334	Economy	6300.00
0005432459491	8334	Economy	6300.00
0005434312308	8334	Economy	6300.00
0005432459519	8334	Economy	6300.00
0005435884864	8334	Economy	6300.00
0005432459524	8334	Economy	6300.00
0005432459492	8334	Economy	6300.00
0005432459502	8334	Economy	6300.00
0005435884886	8334	Economy	6300.00
0005432459542	8334	Economy	6300.00
0005432042624	8334	Economy	6300.00
0005435884870	8334	Economy	6300.00
0005435884877	8334	Economy	6300.00
0005432459498	8334	Economy	6300.00
0005432042613	8334	Economy	6300.00
0005435884866	8334	Economy	6300.00
0005432459509	8334	Economy	6900.00
0005432459539	8334	Economy	6900.00
0005433506904	8334	Economy	6900.00
0005433506866	8334	Economy	6900.00
0005432042620	8334	Economy	6300.00
0005435884891	8334	Economy	6300.00
0005432459513	8334	Economy	6300.00
0005433506865	8334	Economy	6300.00
0005432042611	8334	Economy	6900.00
0005433506879	8334	Economy	6300.00
0005435884874	8334	Economy	6300.00
0005432459494	8334	Economy	6300.00
0005435884867	8334	Economy	6300.00
0005435884889	8334	Economy	6300.00
0005432042623	8334	Economy	6300.00
0005435884880	8334	Economy	6300.00
0005434312306	8334	Economy	6300.00
0005432459523	8334	Economy	6300.00
0005435884898	8334	Economy	6300.00
0005432459500	8334	Economy	6300.00
0005432459521	8334	Economy	6300.00
0005432459540	8334	Economy	6300.00
0005432459496	8334	Economy	6300.00
0005432459506	8334	Economy	6300.00
0005432459511	8334	Economy	6300.00
0005432042615	8334	Economy	6300.00
0005432042621	8334	Economy	6300.00
0005435884887	8334	Economy	6300.00
0005435884873	8334	Economy	6300.00
0005432459503	8334	Economy	6300.00
0005435884885	8334	Economy	6300.00
0005433506862	8334	Economy	6300.00
0005435884883	8334	Economy	6300.00
0005432459518	8334	Economy	6300.00
0005432042614	8334	Economy	6300.00
0005432459499	8334	Economy	6300.00
0005432459510	8334	Economy	6300.00
0005435884868	8334	Economy	6300.00
0005435884893	8334	Economy	6300.00
0005432459497	8334	Economy	6300.00
0005432459493	8334	Economy	6300.00
0005435884865	8334	Economy	6300.00
0005432459517	8334	Economy	6300.00
0005435884884	8334	Economy	6300.00
0005432042612	8334	Economy	6300.00
0005434326266	8334	Economy	6300.00
0005432459532	8334	Economy	6300.00
0005433506912	8334	Economy	6300.00
0005432459541	8334	Economy	6300.00
0005435884900	8334	Economy	6300.00
0005435884879	8334	Economy	6300.00
0005434312305	8334	Economy	6300.00
0005433506892	8334	Economy	6300.00
0005432042617	8334	Economy	6300.00
0005435884892	8334	Economy	6300.00
0005433633240	8340	Business	18800.00
0005433633244	8340	Business	18800.00
0005433804856	8340	Business	18800.00
0005434271275	8340	Business	18800.00
0005433804804	8340	Business	18800.00
0005433633256	8340	Business	18800.00
0005433804952	8340	Business	18800.00
0005433633435	8340	Business	18800.00
0005433633222	8340	Economy	6900.00
0005433804822	8340	Economy	6900.00
0005433804817	8340	Economy	6900.00
0005433633225	8340	Economy	6300.00
0005433633224	8340	Economy	6300.00
0005433633273	8340	Economy	6300.00
0005433804826	8340	Economy	6300.00
0005433633274	8340	Economy	6300.00
0005433633275	8340	Economy	6300.00
0005433633236	8340	Economy	6300.00
0005433804789	8340	Economy	6300.00
0005433804839	8340	Economy	6300.00
0005433804814	8340	Economy	6300.00
0005433804816	8340	Economy	6300.00
0005434143701	8340	Economy	6300.00
0005433633223	8340	Economy	6300.00
0005433804846	8340	Economy	6300.00
0005433804833	8340	Economy	6300.00
0005433804844	8340	Economy	6900.00
0005433804838	8340	Economy	6300.00
0005433633245	8340	Economy	6300.00
0005433633234	8340	Economy	6300.00
0005433633221	8340	Economy	6300.00
0005434271284	8340	Economy	6300.00
0005434271285	8340	Economy	6300.00
0005433633335	8340	Economy	6300.00
0005433804853	8340	Economy	6300.00
0005433633317	8340	Economy	6300.00
0005433633319	8340	Economy	6300.00
0005433633276	8340	Economy	6300.00
0005433804848	8340	Economy	6300.00
0005433804925	8340	Economy	6300.00
0005433633241	8340	Economy	6300.00
0005433804951	8340	Economy	6300.00
0005433633299	8340	Economy	6300.00
0005433633257	8340	Economy	6300.00
0005433804950	8340	Economy	6300.00
0005433804825	8340	Economy	6300.00
0005434183560	8341	Business	18800.00
0005434183546	8341	Economy	6300.00
0005434183545	8341	Economy	6300.00
0005432382903	4613	Business	9900.00
0005432382919	4613	Business	9900.00
0005432382896	4613	Business	9900.00
0005432727845	4613	Business	9900.00
0005432382924	4613	Business	9900.00
0005433454861	4613	Business	9900.00
0005432382910	4613	Business	9900.00
0005432382918	4613	Business	9900.00
0005432727852	4613	Business	9900.00
0005432382891	4613	Economy	3300.00
0005433454859	4613	Economy	3300.00
0005432382920	4613	Economy	3300.00
0005432382902	4613	Economy	3300.00
0005432382900	4613	Economy	3300.00
0005432382905	4613	Economy	3300.00
0005432382886	4613	Economy	3300.00
0005432382915	4613	Economy	3600.00
0005432382890	4613	Economy	3600.00
0005432382914	4613	Economy	3600.00
0005432382921	4613	Economy	3600.00
0005432727855	4613	Economy	3300.00
0005432727854	4613	Economy	3300.00
0005432382904	4613	Economy	3300.00
0005433722171	4613	Economy	3300.00
0005432382912	4613	Economy	3300.00
0005432382925	4613	Economy	3300.00
0005432727850	4613	Economy	3300.00
0005432727847	4613	Economy	3300.00
0005432382895	4613	Economy	3300.00
0005433722174	4613	Economy	3300.00
0005433722177	4613	Economy	3300.00
0005433722175	4613	Economy	3300.00
0005432382892	4613	Economy	3300.00
0005432382898	4613	Economy	3300.00
0005432382888	4613	Economy	3300.00
0005433722173	4613	Economy	3300.00
0005432382922	4613	Economy	3300.00
0005433722178	4613	Economy	3300.00
0005432382907	4613	Economy	3300.00
0005433722170	4613	Economy	3300.00
0005432727851	4613	Economy	3300.00
0005432727848	4613	Economy	3300.00
0005433722172	4613	Economy	3300.00
0005432382911	4613	Economy	3300.00
0005432727849	4613	Economy	3300.00
0005432382899	4613	Economy	3300.00
0005432382897	4613	Economy	3300.00
0005433453749	4613	Economy	3300.00
0005432382889	4613	Economy	3300.00
0005432382916	4613	Economy	3300.00
0005432727846	4613	Economy	3300.00
0005432382901	4613	Economy	3300.00
0005432382906	4613	Economy	3300.00
0005432727844	4613	Economy	3300.00
0005433722176	4613	Economy	3300.00
0005433454860	4613	Economy	3300.00
0005432382923	4613	Economy	3300.00
0005432382909	4613	Economy	3300.00
0005433454862	4613	Economy	3300.00
0005432727856	4613	Economy	3300.00
0005432382894	4613	Economy	3300.00
0005432382926	4613	Economy	3300.00
0005432382887	4613	Economy	3300.00
0005432382913	4613	Economy	3300.00
0005432727853	4613	Economy	3300.00
0005432382917	4613	Economy	3300.00
0005432382908	4613	Economy	3300.00
0005432382893	4613	Economy	3300.00
0005432727729	30098	Business	9900.00
0005432382521	30098	Business	9900.00
0005432382559	30098	Business	9900.00
0005432727760	30098	Business	9900.00
0005432382509	30098	Business	9900.00
0005432382490	30098	Business	9900.00
0005432727731	30098	Economy	3300.00
0005433194820	30098	Economy	3300.00
0005432727728	30098	Economy	3300.00
0005433451591	30098	Economy	3300.00
0005432382536	30098	Economy	3300.00
0005432382544	30098	Economy	3600.00
0005433453729	30098	Economy	3600.00
0005432382487	30098	Economy	3300.00
0005432382572	30098	Economy	3300.00
0005433451586	30098	Economy	3300.00
0005432727720	30098	Economy	3300.00
0005432382503	30098	Economy	3300.00
0005432382484	30098	Economy	3300.00
0005432727745	30098	Economy	3300.00
0005433451582	30098	Economy	3300.00
0005432727730	30098	Economy	3300.00
0005432382510	30098	Economy	3300.00
0005432382518	30098	Economy	3300.00
0005433451592	30098	Economy	3300.00
0005432382508	30098	Economy	3300.00
0005432382545	30098	Economy	3300.00
0005432382519	30098	Economy	3300.00
0005432727768	30098	Economy	3300.00
0005433194825	30098	Economy	3300.00
0005433194819	30098	Economy	3300.00
0005432382501	30098	Economy	3300.00
0005432727717	30098	Economy	3300.00
0005432382507	30098	Economy	3300.00
0005433194818	30098	Economy	3300.00
0005433451593	30098	Economy	3300.00
0005435529116	1719	Business	57200.00
0005433516820	1719	Business	57200.00
0005435540844	1719	Business	57200.00
0005435529113	1719	Business	57200.00
0005435529120	1719	Business	57200.00
0005435529973	1719	Economy	19100.00
0005435529102	1719	Economy	19100.00
0005435529103	1719	Economy	19100.00
0005435540853	1719	Economy	19100.00
0005435540861	1719	Economy	19100.00
0005435540849	1719	Economy	19100.00
0005433516826	1719	Economy	19100.00
0005435529101	1719	Economy	19100.00
0005433516817	1719	Economy	21000.00
0005433516825	1719	Economy	21000.00
0005433516818	1719	Economy	21000.00
0005435529104	1719	Economy	19100.00
0005432924958	1719	Economy	19100.00
0005432294470	1719	Economy	19100.00
0005435540846	1719	Economy	19100.00
0005435540848	1719	Economy	19100.00
0005433516821	1719	Economy	19100.00
0005435529105	1719	Economy	19100.00
0005435540860	1719	Economy	19100.00
0005435540856	1719	Economy	19100.00
0005435529112	1719	Economy	19100.00
0005435540854	1719	Economy	19100.00
0005435529107	1719	Economy	19100.00
0005435529119	1719	Economy	19100.00
0005435529115	1719	Economy	19100.00
0005435540851	1719	Economy	19100.00
0005435540850	1719	Economy	19100.00
0005435529100	1719	Economy	19100.00
0005433516824	1719	Economy	19100.00
0005432924976	1719	Economy	19100.00
0005435529111	1719	Economy	19100.00
0005435529117	1719	Economy	19100.00
0005432924956	1719	Economy	19100.00
0005432294472	1719	Economy	19100.00
0005435529108	1719	Economy	19100.00
0005435540845	1719	Economy	19100.00
0005435529110	1719	Economy	19100.00
0005435529118	1719	Economy	19100.00
0005435540862	1719	Economy	19100.00
0005433516823	1719	Economy	19100.00
0005435529109	1719	Economy	19100.00
0005435540863	1719	Economy	19100.00
0005435540847	1719	Economy	19100.00
0005435529106	1719	Economy	19100.00
0005435540857	1719	Economy	19100.00
0005435540864	1719	Economy	19100.00
0005435540852	1719	Economy	19100.00
0005435540858	1719	Economy	19100.00
0005435529121	1719	Economy	19100.00
0005433516819	1719	Economy	19100.00
0005432294471	1719	Economy	19100.00
0005432924975	1719	Economy	19100.00
0005433516822	1719	Economy	19100.00
0005435540855	1719	Economy	19100.00
0005435540865	1719	Economy	19100.00
0005435529114	1719	Economy	19100.00
0005435540859	1719	Economy	19100.00
0005435517660	21980	Business	57200.00
0005435540702	21980	Business	57200.00
0005435540642	21980	Economy	19100.00
0005435540685	21980	Economy	19100.00
0005435540728	21980	Economy	19100.00
0005435540672	21980	Economy	19100.00
0005435517628	21980	Economy	19100.00
0005435517680	21980	Economy	19100.00
0005432925004	21980	Economy	21000.00
0005435540655	21980	Economy	21000.00
0005435517687	21980	Economy	21000.00
0005433516745	21980	Economy	21000.00
0005435517607	21980	Economy	19100.00
0005435540671	21980	Economy	19100.00
0005435517645	21980	Economy	19100.00
0005432925003	21980	Economy	19100.00
0005435540664	21980	Economy	19100.00
0005435517661	21980	Economy	19100.00
0005435540656	21980	Economy	19100.00
0005435517611	21980	Economy	19100.00
0005435517679	21980	Economy	19100.00
0005435540629	21980	Economy	19100.00
0005435540663	21980	Economy	19100.00
0005435540674	21980	Economy	19100.00
0005435540631	21980	Economy	19100.00
0005435540729	21980	Economy	19100.00
0005435517608	21980	Economy	19100.00
0005433516737	21980	Economy	19100.00
0005435540632	21980	Economy	19100.00
0005435540622	21980	Economy	19100.00
0005435540695	21980	Economy	19100.00
0005435517707	21980	Economy	19100.00
0005435540654	21980	Economy	19100.00
0005435517621	21980	Economy	19100.00
0005435540697	21980	Economy	19100.00
0005435517644	21980	Economy	19100.00
0005433516748	21980	Economy	19100.00
0005435540684	21980	Economy	19100.00
0005433516743	21980	Economy	19100.00
0005433516735	21980	Economy	19100.00
0005435517626	21980	Economy	19100.00
0005432925001	21980	Economy	19100.00
0005435517604	21980	Economy	19100.00
0005435540686	21980	Economy	19100.00
0005432925002	21980	Economy	19100.00
0005433516736	21980	Economy	19100.00
0005432925000	21980	Economy	19100.00
0005435540623	21980	Economy	19100.00
0005433516727	21980	Economy	19100.00
0005432838829	7405	Business	18500.00
0005432838821	7405	Business	18500.00
0005432838798	7405	Business	18500.00
0005432823434	7405	Business	18500.00
0005432838806	7405	Business	18500.00
0005434458647	7405	Business	18500.00
0005435252410	7405	Business	18500.00
0005432838818	7405	Business	18500.00
0005434664921	7405	Business	18500.00
0005432838813	7405	Business	18500.00
0005434458666	7405	Economy	6200.00
0005432838828	7405	Economy	6200.00
0005432840996	7405	Economy	6200.00
0005432838812	7405	Economy	6200.00
0005435252411	7405	Economy	6200.00
0005432838815	7405	Economy	6200.00
0005435252463	7405	Economy	6200.00
0005432838802	7405	Economy	6200.00
0005432838807	7405	Economy	6800.00
0005435252427	7405	Economy	6800.00
0005432073366	7405	Economy	6800.00
0005432073365	7405	Economy	6800.00
0005435252464	7405	Economy	6200.00
0005432838817	7405	Economy	6200.00
0005432840995	7405	Economy	6200.00
0005432073367	7405	Economy	6200.00
0005432838822	7405	Economy	6200.00
0005434458656	7405	Economy	6200.00
0005432838810	7405	Economy	6200.00
0005432838800	7405	Economy	6200.00
0005432073364	7405	Economy	6200.00
0005432838808	7405	Economy	6200.00
0005432838826	7405	Economy	6200.00
0005434458661	7405	Economy	6200.00
0005432838799	7405	Economy	6200.00
0005432838827	7405	Economy	6200.00
0005435252424	7405	Economy	6200.00
0005434458660	7405	Economy	6200.00
0005434458658	7405	Economy	6200.00
0005432838819	7405	Economy	6200.00
0005435252412	7405	Economy	6200.00
0005434458662	7405	Economy	6200.00
0005432838801	7405	Economy	6200.00
0005434458657	7405	Economy	6200.00
0005432838825	7405	Economy	6200.00
0005434458663	7405	Economy	6200.00
0005434458651	7405	Economy	6200.00
0005435252397	7405	Economy	6200.00
0005435252422	7405	Economy	6200.00
0005432073368	7405	Economy	6200.00
0005434458665	7405	Economy	6200.00
0005432838803	7405	Economy	6200.00
0005434458650	7405	Economy	6200.00
0005435252423	7405	Economy	6200.00
0005434458655	7405	Economy	6200.00
0005435252465	7405	Economy	6200.00
0005432838804	7405	Economy	6200.00
0005432823433	7405	Economy	6200.00
0005432838816	7405	Economy	6200.00
0005432838809	7405	Economy	6200.00
0005434458652	7405	Economy	6200.00
0005432073369	7405	Economy	6200.00
0005432838823	7405	Economy	6200.00
0005434458648	7405	Economy	6200.00
0005432838805	7405	Economy	6200.00
0005432838814	7405	Economy	6200.00
0005435252443	7405	Economy	6200.00
0005435252421	7405	Economy	6200.00
0005432073370	7405	Economy	6200.00
0005432838811	7405	Economy	6200.00
0005435252450	7405	Economy	6200.00
0005435252398	7405	Economy	6200.00
0005434458653	7405	Economy	6200.00
0005434458649	7405	Economy	6200.00
0005435252466	7405	Economy	6200.00
0005434458664	7405	Economy	6200.00
0005432838820	7405	Economy	6200.00
0005434458659	7405	Economy	6200.00
0005435252449	7405	Economy	6200.00
0005432838830	7405	Economy	6200.00
0005432838824	7405	Economy	6200.00
0005435252408	7405	Economy	6200.00
0005434458654	7405	Economy	6200.00
0005432840980	28946	Business	18500.00
0005435252565	28946	Business	18500.00
0005435252577	28946	Business	18500.00
0005435252580	28946	Business	18500.00
0005432838565	28946	Business	18500.00
0005435252567	28946	Business	18500.00
0005432838616	28946	Business	18500.00
0005432840985	28946	Business	18500.00
0005434458509	28946	Business	18500.00
0005432838589	28946	Economy	6200.00
0005435252582	28946	Economy	6200.00
0005432838596	28946	Economy	6200.00
0005434458516	28946	Economy	6200.00
0005432838513	28946	Economy	6200.00
0005434664945	28946	Economy	6200.00
0005435252574	28946	Economy	6200.00
0005432838574	28946	Economy	6800.00
0005432001008	28946	Economy	6800.00
0005434458479	28946	Economy	6800.00
0005435252566	28946	Economy	6800.00
0005435491429	28946	Economy	6800.00
0005432838613	28946	Economy	6200.00
0005432840981	28946	Economy	6200.00
0005432838564	28946	Economy	6200.00
0005432838614	28946	Economy	6200.00
0005435491428	28946	Economy	6200.00
0005432838525	28946	Economy	6200.00
0005435252569	28946	Economy	6200.00
0005432838593	28946	Economy	6200.00
0005432840986	28946	Economy	6200.00
0005435252568	28946	Economy	6200.00
0005432838575	28946	Economy	6200.00
0005434458456	28946	Economy	6200.00
0005434458437	28946	Economy	6200.00
0005434664943	28946	Economy	6200.00
0005432838485	28946	Economy	6200.00
0005432823416	28946	Economy	6200.00
0005434458508	28946	Economy	6200.00
0005432838618	28946	Economy	6200.00
0005434458467	28946	Economy	6200.00
0005432838615	28946	Economy	6200.00
0005434458455	28946	Economy	6200.00
0005434458487	28946	Economy	6200.00
0005434664944	28946	Economy	6200.00
0005434458531	28946	Economy	6200.00
0005432838498	28946	Economy	6200.00
0005432838592	28946	Economy	6200.00
0005432838590	28946	Economy	6200.00
0005434458470	28946	Economy	6200.00
0005432838788	28946	Economy	6200.00
0005432838583	28946	Economy	6200.00
0005435252572	28946	Economy	6200.00
0005434458506	28946	Economy	6200.00
0005432840982	28946	Economy	6200.00
0005435252583	28946	Economy	6200.00
0005435252573	28946	Economy	6200.00
0005434458433	28946	Economy	6200.00
0005432838588	28946	Economy	6200.00
0005435252578	28946	Economy	6200.00
0005435252576	28946	Economy	6200.00
0005434458468	28946	Economy	6200.00
0005435252579	28946	Economy	6200.00
0005435252575	28946	Economy	6200.00
0005434458436	28946	Economy	6200.00
0005432838584	28946	Economy	6200.00
0005434458435	28946	Economy	6200.00
0005432001009	28946	Economy	6200.00
0005435252570	28946	Economy	6200.00
0005434458457	28946	Economy	6200.00
0005434458532	28946	Economy	6200.00
0005435252571	28946	Economy	6200.00
0005434458505	28946	Economy	6200.00
0005435252581	28946	Economy	6200.00
0005432838595	28946	Economy	6200.00
0005435990573	8822	Business	145300.00
0005434275936	8822	Business	145300.00
0005434275967	8822	Business	145300.00
0005435990572	8822	Business	145300.00
0005435990575	8822	Economy	48400.00
0005434275937	8822	Economy	53300.00
0005434275947	8822	Economy	48400.00
0005434275934	8822	Economy	48400.00
0005435990574	8822	Economy	48400.00
0005435990570	8822	Economy	48400.00
0005435990577	8822	Economy	48400.00
0005434275959	8822	Economy	48400.00
0005435990569	8822	Economy	48400.00
0005435990576	8822	Economy	48400.00
0005435990571	8822	Economy	48400.00
0005434275950	8822	Economy	48400.00
0005434275935	8822	Economy	48400.00
0005435990521	15719	Business	145300.00
0005434275988	15719	Business	145300.00
0005435990512	15719	Business	145300.00
0005434275983	15719	Business	145300.00
0005435990513	15719	Business	145300.00
0005435990510	15719	Economy	48400.00
0005434275989	15719	Economy	48400.00
0005434275985	15719	Economy	48400.00
0005434275984	15719	Economy	48400.00
0005435990515	15719	Economy	48400.00
0005435990532	15719	Economy	48400.00
0005434275986	15719	Economy	48400.00
0005435990511	15719	Economy	48400.00
0005434275987	15719	Economy	48400.00
0005432427125	20637	Economy	15900.00
0005432427126	20637	Economy	14500.00
0005432427128	20637	Economy	14500.00
0005432427129	20637	Economy	14500.00
0005433476863	20637	Economy	14500.00
0005433476862	20637	Economy	14500.00
0005432427127	20637	Economy	14500.00
0005435490170	6375	Business	36600.00
0005432360045	6375	Business	36600.00
0005432335953	6375	Business	36600.00
0005432360030	6375	Business	36600.00
0005434149551	6375	Business	36600.00
0005434149542	6375	Business	36600.00
0005434149521	6375	Business	36600.00
0005435176600	6375	Business	36600.00
0005434149534	6375	Business	36600.00
0005434149553	6375	Business	36600.00
0005434149580	6375	Economy	12200.00
0005432335946	6375	Economy	12200.00
0005432335950	6375	Economy	12200.00
0005435176587	6375	Economy	12200.00
0005432360026	6375	Economy	12200.00
0005432360043	6375	Economy	12200.00
0005432335944	6375	Economy	12200.00
0005432360014	6375	Economy	12200.00
0005432360040	6375	Economy	12200.00
0005432360021	6375	Economy	12200.00
0005435176705	6375	Economy	12200.00
0005432360036	6375	Economy	12200.00
0005432360007	6375	Economy	12200.00
0005435176685	6375	Economy	12200.00
0005432335954	6375	Economy	12200.00
0005432360020	6375	Economy	12200.00
0005434149526	6375	Economy	12200.00
0005435176657	6375	Economy	12200.00
0005432360038	6375	Economy	12200.00
0005432360003	6375	Economy	12200.00
0005432360011	6375	Economy	12200.00
0005432359998	6375	Economy	12200.00
0005432335947	6375	Economy	12200.00
0005432360044	6375	Economy	12200.00
0005432360009	6375	Economy	12200.00
0005432360019	6375	Economy	12200.00
0005432062190	6375	Economy	12200.00
0005432360010	6375	Economy	12200.00
0005432363393	6375	Economy	12200.00
0005435176599	6375	Economy	12200.00
0005432363391	6375	Economy	12200.00
0005432360013	6375	Economy	12200.00
0005432360035	6375	Economy	12200.00
0005435176726	6375	Economy	12200.00
0005435176691	6375	Economy	13400.00
0005432360039	6375	Economy	13400.00
0005434149528	6375	Economy	13400.00
0005432360016	6375	Economy	13400.00
0005432360008	6375	Economy	13400.00
0005432360027	6375	Economy	12200.00
0005432360023	6375	Economy	12200.00
0005432360032	6375	Economy	12200.00
0005435176725	6375	Economy	12200.00
0005432360028	6375	Economy	12200.00
0005432062188	6375	Economy	12200.00
0005432360031	6375	Economy	12200.00
0005432360004	6375	Economy	12200.00
0005432360033	6375	Economy	12200.00
0005432360018	6375	Economy	12200.00
0005432360041	6375	Economy	12200.00
0005432360022	6375	Economy	12200.00
0005432335943	6375	Economy	12200.00
0005435176659	6375	Economy	12200.00
0005434149557	6375	Economy	12200.00
0005435176653	6375	Economy	12200.00
0005434149567	6375	Economy	12200.00
0005432360012	6375	Economy	12200.00
0005434149520	6375	Economy	12200.00
0005432360025	6375	Economy	12200.00
0005432360015	6375	Economy	12200.00
0005432062192	6375	Economy	12200.00
0005432363392	6375	Economy	12200.00
0005435176586	6375	Economy	12200.00
0005435176724	6375	Economy	12200.00
0005432360029	6375	Economy	12200.00
0005432335948	6375	Economy	12200.00
0005432062193	6375	Economy	12200.00
0005435176758	6375	Economy	12200.00
0005432360002	6375	Economy	12200.00
0005432335952	6375	Economy	12200.00
0005435176672	6375	Economy	12200.00
0005432360024	6375	Economy	12200.00
0005432360001	6375	Economy	12200.00
0005432359999	6375	Economy	12200.00
0005432062189	6375	Economy	12200.00
0005432360042	6375	Economy	12200.00
0005432335951	6375	Economy	12200.00
0005432335949	6375	Economy	12200.00
0005435176695	6375	Economy	12200.00
0005432062191	6375	Economy	12200.00
0005432360037	6375	Economy	12200.00
0005432360017	6375	Economy	12200.00
0005435176656	6375	Economy	12200.00
0005432360000	6375	Economy	12200.00
0005432360046	6375	Economy	12200.00
0005435723010	6375	Economy	12200.00
0005432363394	6375	Economy	12200.00
0005432335945	6375	Economy	12200.00
0005434149556	6375	Economy	12200.00
0005434149543	6375	Economy	12200.00
0005432062194	6375	Economy	12200.00
0005432360006	6375	Economy	12200.00
0005432360005	6375	Economy	12200.00
0005434149527	6375	Economy	12200.00
0005434149555	6375	Economy	12200.00
0005432360034	6375	Economy	12200.00
0005432335875	21029	Business	36600.00
0005432359571	21029	Business	36600.00
0005432052724	21029	Business	36600.00
0005432359707	21029	Business	36600.00
0005434149650	21029	Business	36600.00
0005432335844	21029	Business	36600.00
0005432359736	21029	Business	36600.00
0005432359631	21029	Business	36600.00
0005432363384	21029	Economy	12200.00
0005435176884	21029	Economy	12200.00
0005432359545	21029	Economy	12200.00
0005435176891	21029	Economy	12200.00
0005432363361	21029	Economy	12200.00
0005434149644	21029	Economy	12200.00
0005435176870	21029	Economy	12200.00
0005432359535	21029	Economy	12200.00
0005435490203	21029	Economy	12200.00
0005432335886	21029	Economy	12200.00
0005432359704	21029	Economy	12200.00
0005432052725	21029	Economy	12200.00
0005432359508	21029	Economy	12200.00
0005432359592	21029	Economy	12200.00
0005435176887	21029	Economy	12200.00
0005432359674	21029	Economy	12200.00
0005435176883	21029	Economy	12200.00
0005432359726	21029	Economy	12200.00
0005435490206	21029	Economy	12200.00
0005435176885	21029	Economy	12200.00
0005435176872	21029	Economy	12200.00
0005435176869	21029	Economy	12200.00
0005434149643	21029	Economy	12200.00
0005432359541	21029	Economy	12200.00
0005434149648	21029	Economy	12200.00
0005434149646	21029	Economy	12200.00
0005432359656	21029	Economy	12200.00
0005435490207	21029	Economy	12200.00
0005432359661	21029	Economy	12200.00
0005432335837	21029	Economy	12200.00
0005435490204	21029	Economy	12200.00
0005435176878	21029	Economy	13400.00
0005434149640	21029	Economy	13400.00
0005435723031	21029	Economy	13400.00
0005435176882	21029	Economy	13400.00
0005432359699	21029	Economy	13400.00
0005435176875	21029	Economy	13400.00
0005435176892	21029	Economy	12200.00
0005432359697	21029	Economy	12200.00
0005432335846	21029	Economy	12200.00
0005432335829	21029	Economy	12200.00
0005432359721	21029	Economy	12200.00
0005432359593	21029	Economy	12200.00
0005432335838	21029	Economy	12200.00
0005432359642	21029	Economy	12200.00
0005432359632	21029	Economy	12200.00
0005432359600	21029	Economy	12200.00
0005434149645	21029	Economy	12200.00
0005432335851	21029	Economy	12200.00
0005432359722	21029	Economy	12200.00
0005435176888	21029	Economy	12200.00
0005435176893	21029	Economy	12200.00
0005435176876	21029	Economy	12200.00
0005435176886	21029	Economy	12200.00
0005435176879	21029	Economy	12200.00
0005432359539	21029	Economy	12200.00
0005434149647	21029	Economy	12200.00
0005432359789	21029	Economy	12200.00
0005434149642	21029	Economy	12200.00
0005434149641	21029	Economy	12200.00
0005432359594	21029	Economy	12200.00
0005432335871	21029	Economy	12200.00
0005432359507	21029	Economy	12200.00
0005432359660	21029	Economy	12200.00
0005432359673	21029	Economy	12200.00
0005435723032	21029	Economy	12200.00
0005432335855	21029	Economy	12200.00
0005435176880	21029	Economy	12200.00
0005435176881	21029	Economy	12200.00
0005435490205	21029	Economy	12200.00
0005432359735	21029	Economy	12200.00
0005434149649	21029	Economy	12200.00
0005435176890	21029	Economy	12200.00
0005432359670	21029	Economy	12200.00
0005432359544	21029	Economy	12200.00
0005435176874	21029	Economy	12200.00
0005432359790	21029	Economy	12200.00
0005435176867	21029	Economy	12200.00
0005435176894	21029	Economy	12200.00
0005434149651	21029	Economy	12200.00
0005435176877	21029	Economy	12200.00
0005432359662	21029	Economy	12200.00
0005435176871	21029	Economy	12200.00
0005435176873	21029	Economy	12200.00
0005432335845	21029	Economy	12200.00
0005435176889	21029	Economy	12200.00
0005435176868	21029	Economy	12200.00
0005432359540	21029	Economy	12200.00
0005434458504	17738	Economy	3400.00
0005434458454	17738	Economy	3400.00
0005434458483	17738	Economy	3400.00
0005434463894	17738	Economy	3100.00
0005434458501	17738	Economy	3100.00
0005434458458	17738	Economy	3100.00
0005434458591	17738	Economy	3100.00
0005434458563	17738	Economy	3100.00
0005434458546	17738	Economy	3100.00
0005434458485	17738	Economy	3100.00
0005434458459	17738	Economy	3100.00
0005434458447	17738	Economy	3100.00
0005434458446	17738	Economy	3100.00
0005434458460	17738	Economy	3100.00
0005434186179	17738	Economy	3100.00
0005434458484	17738	Economy	3100.00
0005434458541	17738	Economy	3100.00
0005434463893	17738	Economy	3100.00
0005434458542	17738	Economy	3100.00
0005434458488	17738	Economy	3100.00
0005434458533	17738	Economy	3100.00
0005434458590	17738	Economy	3100.00
0005434461615	17738	Economy	3100.00
0005434463895	17738	Economy	3100.00
0005434458497	17738	Economy	3100.00
0005434458472	17738	Economy	3100.00
0005434458521	17738	Economy	3100.00
0005434458486	17738	Economy	3100.00
0005434448261	17738	Economy	3100.00
0005434458482	17738	Economy	3100.00
0005434461614	17738	Economy	3100.00
0005434458564	17738	Economy	3100.00
0005434186178	17738	Economy	3100.00
0005434448271	17738	Economy	3100.00
0005434458477	17738	Economy	3100.00
0005434458473	17738	Economy	3100.00
0005434458539	17738	Economy	3100.00
0005434458502	17738	Economy	3100.00
0005434458503	17738	Economy	3100.00
0005434458498	17738	Economy	3100.00
0005434458547	17738	Economy	3100.00
0005434448286	29134	Economy	3400.00
0005434448287	29134	Economy	3400.00
0005434458653	29134	Economy	3100.00
0005434463912	29134	Economy	3100.00
0005434458652	29134	Economy	3100.00
0005434458665	29134	Economy	3100.00
0005434458664	29134	Economy	3100.00
0005434458648	29134	Economy	3100.00
0005434448289	29134	Economy	3100.00
0005434458649	29134	Economy	3100.00
0005434458650	29134	Economy	3100.00
0005434458666	29134	Economy	3100.00
0005434458659	29134	Economy	3100.00
0005434458663	29134	Economy	3100.00
0005434458660	29134	Economy	3100.00
0005434463911	29134	Economy	3100.00
0005434462773	29134	Economy	3100.00
0005434458662	29134	Economy	3100.00
0005434448285	29134	Economy	3100.00
0005434458655	29134	Economy	3100.00
0005434458657	29134	Economy	3100.00
0005434458647	29134	Economy	3100.00
0005434463913	29134	Economy	3100.00
0005434458661	29134	Economy	3100.00
0005434458656	29134	Economy	3100.00
0005434458658	29134	Economy	3100.00
0005434462772	29134	Economy	3100.00
0005434458654	29134	Economy	3100.00
0005434458651	29134	Economy	3100.00
0005434448288	29134	Economy	3100.00
0005432604006	21412	Economy	7300.00
0005432604030	21412	Economy	7300.00
0005432604011	21412	Economy	7300.00
0005432604029	21412	Economy	6600.00
0005432604016	21412	Economy	6600.00
0005432604028	21412	Economy	6600.00
0005432604041	21412	Economy	6600.00
0005432604036	21412	Economy	6600.00
0005432604009	21412	Economy	6600.00
0005432604032	21412	Economy	6600.00
0005432604010	21412	Economy	6600.00
0005432604040	21412	Economy	6600.00
0005432604045	21412	Economy	6600.00
0005432604042	21412	Economy	6600.00
0005432604013	21412	Economy	6600.00
0005432604033	21412	Economy	6600.00
0005432604023	21412	Economy	6600.00
0005432604025	21412	Economy	6600.00
0005432604015	21412	Economy	6600.00
0005432604017	21412	Economy	6600.00
0005432604026	21412	Economy	6600.00
0005432604019	21412	Economy	6600.00
0005432604012	21412	Economy	6600.00
0005432604027	21412	Economy	6600.00
0005432604043	21412	Economy	6600.00
0005432604021	21412	Economy	6600.00
0005432604008	21412	Economy	6600.00
0005432604031	21412	Economy	6600.00
0005432604035	21412	Economy	6600.00
0005432604024	21412	Economy	6600.00
0005432604014	21412	Economy	6600.00
0005432604020	21412	Economy	6600.00
0005432604022	21412	Economy	6600.00
0005432604046	21412	Economy	6600.00
0005432604044	21412	Economy	6600.00
0005432604018	21412	Economy	6600.00
0005432604007	21412	Economy	6600.00
0005432604034	21412	Economy	6600.00
0005432604039	21412	Economy	6600.00
0005432604038	21412	Economy	6600.00
0005432604037	21412	Economy	6600.00
0005432603698	31708	Economy	7300.00
0005432603704	31708	Economy	7300.00
0005432603759	31708	Economy	6600.00
0005432603742	31708	Economy	6600.00
0005432603703	31708	Economy	6600.00
0005432603772	31708	Economy	6600.00
0005432603690	31708	Economy	6600.00
0005432603735	31708	Economy	6600.00
0005432603670	31708	Economy	6600.00
0005435221048	31708	Economy	6600.00
0005432603760	31708	Economy	6600.00
0005432603689	31708	Economy	6600.00
0005432603833	31708	Economy	6600.00
0005432603750	31708	Economy	6600.00
0005432603683	31708	Economy	6600.00
0005432603696	31708	Economy	6600.00
0005432603730	31708	Economy	6600.00
0005435221510	31708	Economy	6600.00
0005432603801	31708	Economy	6600.00
0005432603677	31708	Economy	6600.00
0005435221049	31708	Economy	6600.00
0005432603815	31708	Economy	6600.00
0005432603741	31708	Economy	6600.00
0005432603669	31708	Economy	6600.00
0005432603729	31708	Economy	6600.00
0005432603807	31708	Economy	6600.00
0005432603793	31708	Economy	6600.00
0005435221509	31708	Economy	6600.00
0005433293143	12310	Economy	17800.00
0005434606772	18868	Economy	6600.00
0005434606778	18868	Economy	6600.00
0005434606777	18868	Economy	6600.00
0005435904893	18868	Economy	6600.00
0005434606761	18868	Economy	6600.00
0005434604869	22342	Economy	6600.00
0005434606798	22342	Economy	6600.00
0005434606799	22342	Economy	6600.00
0005434606801	22342	Economy	6600.00
0005434606800	22342	Economy	6600.00
0005434604870	22342	Economy	6600.00
0005432747283	427	Business	44500.00
0005432890726	427	Business	44500.00
0005432747284	427	Business	44500.00
0005432747282	427	Business	44500.00
0005432747263	427	Business	44500.00
0005432747278	427	Business	44500.00
0005435154591	427	Business	44500.00
0005432890808	427	Economy	14800.00
0005432747269	427	Economy	14800.00
0005432747266	427	Economy	14800.00
0005432747291	427	Economy	14800.00
0005432747264	427	Economy	14800.00
0005432747281	427	Economy	14800.00
0005432753273	427	Economy	14800.00
0005432747294	427	Economy	16300.00
0005432751498	427	Economy	16300.00
0005432751499	427	Economy	16300.00
0005432747265	427	Economy	16300.00
0005432747271	427	Economy	14800.00
0005433293157	427	Economy	14800.00
0005432890708	427	Economy	14800.00
0005432747270	427	Economy	14800.00
0005432890709	427	Economy	14800.00
0005432747276	427	Economy	14800.00
0005432219971	427	Economy	14800.00
0005432747268	427	Economy	14800.00
0005432751500	427	Economy	14800.00
0005432751501	427	Economy	14800.00
0005432753275	427	Economy	14800.00
0005432749768	427	Economy	14800.00
0005432890728	427	Economy	14800.00
0005432890686	427	Economy	14800.00
0005432749767	427	Economy	14800.00
0005432747274	427	Economy	14800.00
0005432890672	427	Economy	14800.00
0005433293144	427	Economy	14800.00
0005432747259	427	Economy	14800.00
0005432747267	427	Economy	14800.00
0005432890744	427	Economy	14800.00
0005432890730	427	Economy	14800.00
0005432890700	427	Economy	14800.00
0005432747285	427	Economy	14800.00
0005432890725	427	Economy	14800.00
0005432747272	427	Economy	14800.00
0005432219969	427	Economy	14800.00
0005432890714	427	Economy	14800.00
0005432747275	427	Economy	14800.00
0005433293155	427	Economy	14800.00
0005432219970	427	Economy	14800.00
0005432747293	427	Economy	14800.00
0005432747287	427	Economy	14800.00
0005432219972	427	Economy	14800.00
0005435627115	427	Economy	14800.00
0005432747297	427	Economy	14800.00
0005432747295	427	Economy	14800.00
0005432890727	427	Economy	14800.00
0005432747290	427	Economy	14800.00
0005432747260	427	Economy	14800.00
0005432747296	427	Economy	14800.00
0005432219973	427	Economy	14800.00
0005432747273	427	Economy	14800.00
0005432890712	427	Economy	14800.00
0005432747262	427	Economy	14800.00
0005432747277	427	Economy	14800.00
0005432890745	427	Economy	14800.00
0005432747279	427	Economy	14800.00
0005432747261	427	Economy	14800.00
0005432747292	427	Economy	14800.00
0005435627114	427	Economy	14800.00
0005432747288	427	Economy	14800.00
0005432753274	427	Economy	14800.00
0005432747286	427	Economy	14800.00
0005433293145	427	Economy	14800.00
0005432747289	427	Economy	14800.00
0005432747280	427	Economy	14800.00
0005432747032	12087	Business	44500.00
0005432746957	12087	Business	44500.00
0005432747138	12087	Business	44500.00
0005432746869	12087	Business	44500.00
0005432747009	12087	Business	44500.00
0005432890875	12087	Business	44500.00
0005432747074	12087	Business	44500.00
0005432746971	12087	Business	44500.00
0005432747071	12087	Business	44500.00
0005432890880	12087	Economy	14800.00
0005432756788	12087	Economy	14800.00
0005432890881	12087	Economy	14800.00
0005432746920	12087	Economy	14800.00
0005432890874	12087	Economy	14800.00
0005432890872	12087	Economy	14800.00
0005432746908	12087	Economy	14800.00
0005432747031	12087	Economy	14800.00
0005432890884	12087	Economy	14800.00
0005432747104	12087	Economy	16300.00
0005433875367	12087	Economy	16300.00
0005432747015	12087	Economy	16300.00
0005433293203	12087	Economy	16300.00
0005432746977	12087	Economy	16300.00
0005432746990	12087	Economy	14800.00
0005433293204	12087	Economy	14800.00
0005432756789	12087	Economy	14800.00
0005432890870	12087	Economy	14800.00
0005432747065	12087	Economy	14800.00
0005432747101	12087	Economy	14800.00
0005432214787	12087	Economy	14800.00
0005432746958	12087	Economy	14800.00
0005432746923	12087	Economy	14800.00
0005433293201	12087	Economy	14800.00
0005432890877	12087	Economy	14800.00
0005432890889	12087	Economy	14800.00
0005432746944	12087	Economy	14800.00
0005432747073	12087	Economy	14800.00
0005432753254	12087	Economy	14800.00
0005432890878	12087	Economy	14800.00
0005433293199	12087	Economy	14800.00
0005432756807	12087	Economy	14800.00
0005432753253	12087	Economy	14800.00
0005432746956	12087	Economy	14800.00
0005432746987	12087	Economy	14800.00
0005432746953	12087	Economy	14800.00
0005433293207	12087	Economy	14800.00
0005432747062	12087	Economy	14800.00
0005433293200	12087	Economy	14800.00
0005432747072	12087	Economy	14800.00
0005432747030	12087	Economy	14800.00
0005432890873	12087	Economy	14800.00
0005432890887	12087	Economy	14800.00
0005432890885	12087	Economy	14800.00
0005432746933	12087	Economy	14800.00
0005432890883	12087	Economy	14800.00
0005433293198	12087	Economy	14800.00
0005432890888	12087	Economy	14800.00
0005432747033	12087	Economy	14800.00
0005432746970	12087	Economy	14800.00
0005432890876	12087	Economy	14800.00
0005432890882	12087	Economy	14800.00
0005432753251	12087	Economy	14800.00
0005432214788	12087	Economy	14800.00
0005432747016	12087	Economy	14800.00
0005432746874	12087	Economy	14800.00
0005432746955	12087	Economy	14800.00
0005432746981	12087	Economy	14800.00
0005433293202	12087	Economy	14800.00
0005433293208	12087	Economy	14800.00
0005432890871	12087	Economy	14800.00
0005432747026	12087	Economy	14800.00
0005432890879	12087	Economy	14800.00
0005432746998	12087	Economy	14800.00
0005432746950	12087	Economy	14800.00
0005432746976	12087	Economy	14800.00
0005433293206	12087	Economy	14800.00
0005432753244	12087	Economy	14800.00
0005433293205	12087	Economy	14800.00
0005433293209	12087	Economy	14800.00
0005432890886	12087	Economy	14800.00
0005432746943	12087	Economy	14800.00
0005432746942	12087	Economy	14800.00
0005432746951	12087	Economy	14800.00
0005433524951	18983	Economy	28200.00
0005432927893	18983	Economy	28200.00
0005432927913	18983	Economy	25700.00
0005433533278	18983	Economy	25700.00
0005432927890	18983	Economy	25700.00
0005433524955	18983	Economy	25700.00
0005432927912	18983	Economy	25700.00
0005432927885	18983	Economy	25700.00
0005433531261	18983	Economy	25700.00
0005433531263	18983	Economy	25700.00
0005432927900	18983	Economy	25700.00
0005433533276	18983	Economy	25700.00
0005433524956	18983	Economy	25700.00
0005432927899	18983	Economy	25700.00
0005433524950	18983	Economy	25700.00
0005433524946	18983	Economy	25700.00
0005433524952	18983	Economy	25700.00
0005432927906	18983	Economy	25700.00
0005433524949	18983	Economy	25700.00
0005433524947	18983	Economy	25700.00
0005433531262	18983	Economy	25700.00
0005432927910	18983	Economy	25700.00
0005433524953	18983	Economy	25700.00
0005433533277	18983	Economy	25700.00
0005433531264	18983	Economy	25700.00
0005433524948	18983	Economy	25700.00
0005433524954	18983	Economy	25700.00
0005433531231	32463	Economy	28200.00
0005433524895	32463	Economy	28200.00
0005433524871	32463	Economy	25700.00
0005433524854	32463	Economy	25700.00
0005432927944	32463	Economy	25700.00
0005432927945	32463	Economy	25700.00
0005432927946	32463	Economy	25700.00
0005432927948	32463	Economy	25700.00
0005433524880	32463	Economy	25700.00
0005432927947	32463	Economy	25700.00
0005433524882	32463	Economy	25700.00
0005433524906	32463	Economy	25700.00
0005433524879	32463	Economy	25700.00
0005432927943	32463	Economy	25700.00
0005433524894	32463	Economy	25700.00
0005432927942	32463	Economy	25700.00
0005433524907	32463	Economy	25700.00
0005433531232	32463	Economy	25700.00
0005433531233	32463	Economy	25700.00
0005433524878	32463	Economy	25700.00
0005434664941	5271	Business	84000.00
0005434822633	5271	Business	84000.00
0005434822647	5271	Business	84000.00
0005435372298	5271	Business	84000.00
0005434822623	5271	Business	84000.00
0005434822728	5271	Business	84000.00
0005434822729	5271	Business	84000.00
0005434822637	5271	Business	84000.00
0005435149930	5271	Business	84000.00
0005434822709	5271	Business	84000.00
0005434822723	5271	Business	84000.00
0005434822619	5271	Business	84000.00
0005434822669	5271	Business	84000.00
0005435149935	5271	Business	84000.00
0005435149927	5271	Business	84000.00
0005434822695	5271	Business	84000.00
0005434828675	5271	Comfort	47600.00
0005434822610	5271	Business	84000.00
0005434822675	5271	Comfort	47600.00
0005435735062	5271	Comfort	47600.00
0005435372129	5271	Comfort	47600.00
0005432121228	5271	Comfort	47600.00
0005434822738	5271	Comfort	47600.00
0005434831111	5271	Comfort	47600.00
0005434822665	5271	Comfort	47600.00
0005432121230	5271	Comfort	47600.00
0005435372490	5271	Comfort	47600.00
0005434822704	5271	Comfort	47600.00
0005435372518	5271	Comfort	47600.00
0005434822668	5271	Comfort	47600.00
0005435149931	5271	Comfort	47600.00
0005434822684	5271	Comfort	47600.00
0005434822679	5271	Comfort	47600.00
0005435386476	5271	Comfort	47600.00
0005435372242	5271	Comfort	47600.00
0005434822636	5271	Comfort	47600.00
0005434828674	5271	Comfort	47600.00
0005434822680	5271	Comfort	47600.00
0005434822718	5271	Comfort	47600.00
0005435735066	5271	Comfort	47600.00
0005434822656	5271	Comfort	47600.00
0005432121236	5271	Comfort	47600.00
0005434822614	5271	Comfort	47600.00
0005434822697	5271	Comfort	47600.00
0005434831110	5271	Comfort	47600.00
0005435372169	5271	Comfort	47600.00
0005435372124	5271	Comfort	47600.00
0005432121240	5271	Comfort	47600.00
0005434822713	5271	Economy	28000.00
0005434822629	5271	Economy	28000.00
0005435372388	5271	Economy	28000.00
0005434822626	5271	Economy	28000.00
0005434822648	5271	Economy	28000.00
0005435372441	5271	Economy	28000.00
0005435372300	5271	Economy	28000.00
0005434822685	5271	Economy	28000.00
0005434822661	5271	Economy	28000.00
0005434822678	5271	Economy	28000.00
0005435149933	5271	Economy	28000.00
0005434822644	5271	Economy	28000.00
0005435372205	5271	Economy	28000.00
0005434822672	5271	Economy	28000.00
0005434822715	5271	Economy	28000.00
0005435372161	5271	Economy	28000.00
0005434822617	5271	Economy	28000.00
0005434822708	5271	Economy	28000.00
0005434822707	5271	Economy	28000.00
0005435372353	5271	Economy	28000.00
0005434558217	5271	Economy	28000.00
0005434822649	5271	Economy	28000.00
0005435372318	5271	Economy	28000.00
0005434822691	5271	Economy	28000.00
0005434822724	5271	Economy	28000.00
0005434822705	5271	Economy	28000.00
0005434822620	5271	Economy	28000.00
0005434822622	5271	Economy	28000.00
0005434822640	5271	Economy	28000.00
0005434822694	5271	Economy	28000.00
0005434822650	5271	Economy	28000.00
0005434822662	5271	Economy	28000.00
0005435372167	5271	Economy	28000.00
0005434822667	5271	Economy	28000.00
0005434822616	5271	Economy	28000.00
0005434831112	5271	Economy	28000.00
0005434822673	5271	Economy	28000.00
0005435372305	5271	Economy	30800.00
0005434822664	5271	Economy	30800.00
0005435149929	5271	Economy	28000.00
0005434822674	5271	Economy	30800.00
0005432823427	5271	Economy	28000.00
0005434822641	5271	Economy	28000.00
0005434822716	5271	Economy	28000.00
0005434822687	5271	Economy	28000.00
0005434822733	5271	Economy	28000.00
0005435372219	5271	Economy	28000.00
0005435372196	5271	Economy	28000.00
0005434822727	5271	Economy	28000.00
0005434558218	5271	Economy	28000.00
0005435735063	5271	Economy	28000.00
0005434822717	5271	Economy	28000.00
0005434822689	5271	Economy	28000.00
0005434822660	5271	Economy	28000.00
0005435372185	5271	Economy	28000.00
0005434822734	5271	Economy	28000.00
0005434822671	5271	Economy	28000.00
0005434822737	5271	Economy	28000.00
0005435149932	5271	Economy	28000.00
0005434822711	5271	Economy	28000.00
0005432121231	5271	Economy	28000.00
0005434822681	5271	Economy	28000.00
0005435372387	5271	Economy	28000.00
0005432396212	5271	Economy	28000.00
0005435372101	5271	Economy	28000.00
0005434822706	5271	Economy	28000.00
0005434822621	5271	Economy	28000.00
0005435372299	5271	Economy	28000.00
0005434822702	5271	Economy	28000.00
0005434822730	5271	Economy	28000.00
0005435299709	5271	Economy	28000.00
0005434822736	5271	Economy	28000.00
0005434558215	5271	Economy	28000.00
0005434822690	5271	Economy	28000.00
0005435299708	5271	Economy	28000.00
0005434822659	5271	Economy	28000.00
0005432121238	5271	Economy	28000.00
0005434822701	5271	Economy	28000.00
0005435372304	5271	Economy	28000.00
0005432121226	5271	Economy	28000.00
0005434822677	5271	Economy	28000.00
0005434822703	5271	Economy	28000.00
0005435372130	5271	Economy	28000.00
0005434822720	5271	Economy	28000.00
0005434831113	5271	Economy	28000.00
0005434822732	5271	Economy	28000.00
0005432121235	5271	Economy	28000.00
0005435735055	5271	Economy	28000.00
0005435372341	5271	Economy	28000.00
0005434822652	5271	Economy	28000.00
0005434822712	5271	Economy	28000.00
0005432121234	5271	Economy	28000.00
0005434822645	5271	Economy	28000.00
0005435386477	5271	Economy	28000.00
0005434822634	5271	Economy	28000.00
0005434822688	5271	Economy	28000.00
0005434822698	5271	Economy	28000.00
0005434822725	5271	Economy	28000.00
0005435299702	5271	Economy	28000.00
0005434822710	5271	Economy	28000.00
0005434822686	5271	Economy	28000.00
0005434822625	5271	Economy	28000.00
0005435149934	5271	Economy	28000.00
0005434822682	5271	Economy	28000.00
0005434822654	5271	Economy	28000.00
0005435149936	5271	Economy	28000.00
0005432121232	5271	Economy	30800.00
0005435372111	5271	Economy	30800.00
0005434822628	5271	Economy	30800.00
0005434558212	5271	Economy	28000.00
0005435372269	5271	Economy	28000.00
0005434822653	5271	Economy	28000.00
0005432394076	5271	Economy	28000.00
0005434822663	5271	Economy	28000.00
0005434822657	5271	Economy	28000.00
0005435372322	5271	Economy	28000.00
0005435372256	5271	Economy	28000.00
0005434558214	5271	Economy	28000.00
0005434822630	5271	Economy	28000.00
0005435372255	5271	Economy	28000.00
0005434822611	5271	Economy	28000.00
0005434822655	5271	Economy	28000.00
0005434822651	5271	Economy	28000.00
0005434558213	5271	Economy	28000.00
0005434822719	5271	Economy	28000.00
0005435372321	5271	Economy	28000.00
0005434822627	5271	Economy	28000.00
0005434822632	5271	Economy	28000.00
0005435386499	5271	Economy	28000.00
0005434822683	5271	Economy	28000.00
0005434822692	5271	Economy	28000.00
0005434822714	5271	Economy	28000.00
0005434822624	5271	Economy	28000.00
0005435372302	5271	Economy	28000.00
0005434822618	5271	Economy	28000.00
0005434822699	5271	Economy	28000.00
0005434664942	5271	Economy	28000.00
0005434558211	5271	Economy	28000.00
0005434822646	5271	Economy	28000.00
0005434822638	5271	Economy	28000.00
0005434822726	5271	Economy	28000.00
0005434822666	5271	Economy	28000.00
0005432121229	5271	Economy	28000.00
0005434822721	5271	Economy	28000.00
0005434558216	5271	Economy	28000.00
0005435372195	5271	Economy	28000.00
0005434822643	5271	Economy	28000.00
0005434822613	5271	Economy	28000.00
0005434822609	5271	Economy	28000.00
0005434664940	5271	Economy	28000.00
0005432396213	5271	Economy	28000.00
0005432394074	5271	Economy	28000.00
0005434822612	5271	Economy	28000.00
0005434822631	5271	Economy	28000.00
0005435179688	5271	Economy	28000.00
0005434822696	5271	Economy	28000.00
0005435372297	5271	Economy	28000.00
0005432396214	5271	Economy	28000.00
0005432121237	5271	Economy	28000.00
0005434822658	5271	Economy	28000.00
0005434822731	5271	Economy	28000.00
0005432396215	5271	Economy	28000.00
0005434822615	5271	Economy	28000.00
0005434822700	5271	Economy	28000.00
0005434822735	5271	Economy	28000.00
0005432121233	5271	Economy	28000.00
0005434822676	5271	Economy	28000.00
0005432121239	5271	Economy	28000.00
0005432121227	5271	Economy	28000.00
0005434831114	5271	Economy	28000.00
0005435372168	5271	Economy	28000.00
0005435299711	5271	Economy	28000.00
0005434822635	5271	Economy	28000.00
0005435735061	5271	Economy	28000.00
0005432394075	5271	Economy	28000.00
0005434822670	5271	Economy	28000.00
0005434822639	5271	Economy	28000.00
0005434822722	5271	Economy	28000.00
0005435149928	5271	Economy	28000.00
0005434822693	5271	Economy	28000.00
0005435372123	5271	Economy	28000.00
0005434822642	5271	Economy	28000.00
0005432394073	5271	Economy	28000.00
0005435372822	9934	Business	84000.00
0005435372767	9934	Business	84000.00
0005434821586	9934	Business	84000.00
0005435372770	9934	Business	84000.00
0005435372791	9934	Business	84000.00
0005435372801	9934	Business	84000.00
0005435372795	9934	Business	84000.00
0005435372772	9934	Business	84000.00
0005434821520	9934	Business	84000.00
0005435299742	9934	Business	84000.00
0005434822019	9934	Business	84000.00
0005435372761	9934	Business	84000.00
0005434821952	9934	Business	84000.00
0005435386528	9934	Business	84000.00
0005435372779	9934	Business	84000.00
0005435372806	9934	Business	84000.00
0005435372823	9934	Business	84000.00
0005434822131	9934	Business	84000.00
0005432823436	9934	Business	84000.00
0005435372789	9934	Business	84000.00
0005435372825	9934	Business	84000.00
0005435372799	9934	Business	84000.00
0005434828653	9934	Comfort	47600.00
0005434822096	9934	Comfort	47600.00
0005434821449	9934	Comfort	47600.00
0005435372807	9934	Comfort	47600.00
0005434821838	9934	Comfort	47600.00
0005435372763	9934	Comfort	47600.00
0005434821612	9934	Comfort	47600.00
0005435372821	9934	Comfort	47600.00
0005434821611	9934	Comfort	47600.00
0005435372783	9934	Comfort	47600.00
0005435372781	9934	Comfort	47600.00
0005434821940	9934	Comfort	47600.00
0005434821736	9934	Comfort	47600.00
0005435149818	9934	Comfort	47600.00
0005435372811	9934	Comfort	47600.00
0005434822130	9934	Comfort	47600.00
0005435372818	9934	Comfort	47600.00
0005435372797	9934	Comfort	47600.00
0005434821777	9934	Comfort	47600.00
0005434821462	9934	Comfort	47600.00
0005434821717	9934	Comfort	47600.00
0005434821446	9934	Comfort	47600.00
0005435149789	9934	Comfort	47600.00
0005435372800	9934	Comfort	47600.00
0005435372768	9934	Comfort	47600.00
0005434821941	9934	Comfort	47600.00
0005435302165	9934	Economy	28000.00
0005435149838	9934	Economy	28000.00
0005434821747	9934	Comfort	47600.00
0005435372816	9934	Economy	28000.00
0005434822315	9934	Economy	28000.00
0005435372784	9934	Economy	28000.00
0005434821729	9934	Economy	28000.00
0005435372774	9934	Economy	28000.00
0005435386527	9934	Economy	28000.00
0005434821340	9934	Economy	28000.00
0005434821789	9934	Economy	28000.00
0005434821801	9934	Economy	28000.00
0005435386526	9934	Economy	28000.00
0005435372820	9934	Economy	28000.00
0005434821778	9934	Economy	28000.00
0005435372792	9934	Economy	28000.00
0005435149791	9934	Economy	28000.00
0005435372814	9934	Economy	28000.00
0005434821629	9934	Economy	28000.00
0005434821857	9934	Economy	28000.00
0005435386529	9934	Economy	28000.00
0005434821633	9934	Economy	28000.00
0005435735106	9934	Economy	28000.00
0005434821939	9934	Economy	28000.00
0005435372785	9934	Economy	28000.00
0005434821450	9934	Economy	28000.00
0005435372812	9934	Economy	28000.00
0005434821888	9934	Economy	28000.00
0005434821624	9934	Economy	28000.00
0005434822204	9934	Economy	28000.00
0005434821519	9934	Economy	28000.00
0005435372769	9934	Economy	28000.00
0005435299743	9934	Economy	28000.00
0005434822399	9934	Economy	28000.00
0005435661912	9934	Economy	28000.00
0005435372778	9934	Economy	28000.00
0005434821784	9934	Economy	28000.00
0005435372805	9934	Economy	28000.00
0005435372762	9934	Economy	28000.00
0005434822046	9934	Economy	28000.00
0005435372782	9934	Economy	28000.00
0005434831075	9934	Economy	28000.00
0005435372794	9934	Economy	28000.00
0005434664928	9934	Economy	30800.00
0005434821540	9934	Economy	28000.00
0005434821897	9934	Economy	30800.00
0005434821539	9934	Economy	28000.00
0005435372803	9934	Economy	28000.00
0005434821620	9934	Economy	28000.00
0005435299740	9934	Economy	30800.00
0005434821787	9934	Economy	30800.00
0005435149819	9934	Economy	30800.00
0005434821459	9934	Economy	28000.00
0005434821837	9934	Economy	28000.00
0005435372815	9934	Economy	28000.00
0005434821318	9934	Economy	28000.00
0005434821512	9934	Economy	28000.00
0005434821427	9934	Economy	28000.00
0005434558140	9934	Economy	28000.00
0005434821595	9934	Economy	28000.00
0005432203011	9934	Economy	28000.00
0005434822032	9934	Economy	28000.00
0005435372775	9934	Economy	28000.00
0005435149803	9934	Economy	28000.00
0005434821718	9934	Economy	28000.00
0005434821448	9934	Economy	28000.00
0005434821542	9934	Economy	28000.00
0005435302166	9934	Economy	28000.00
0005432203009	9934	Economy	28000.00
0005435372826	9934	Economy	28000.00
0005434822017	9934	Economy	28000.00
0005435372798	9934	Economy	28000.00
0005435149814	9934	Economy	28000.00
0005435735108	9934	Economy	28000.00
0005435179390	9934	Economy	28000.00
0005434821732	9934	Economy	28000.00
0005434822033	9934	Economy	28000.00
0005434821896	9934	Economy	28000.00
0005432203013	9934	Economy	28000.00
0005434821734	9934	Economy	28000.00
0005434821455	9934	Economy	28000.00
0005434821485	9934	Economy	28000.00
0005434821314	9934	Economy	28000.00
0005435299739	9934	Economy	28000.00
0005434821344	9934	Economy	28000.00
0005435386530	9934	Economy	28000.00
0005435372760	9934	Economy	28000.00
0005435372813	9934	Economy	28000.00
0005435372796	9934	Economy	28000.00
0005434821675	9934	Economy	28000.00
0005435372765	9934	Economy	28000.00
0005434664927	9934	Economy	28000.00
0005434821543	9934	Economy	28000.00
0005435372819	9934	Economy	28000.00
0005435372787	9934	Economy	28000.00
0005434821376	9934	Economy	28000.00
0005435372802	9934	Economy	28000.00
0005434664926	9934	Economy	28000.00
0005434821890	9934	Economy	28000.00
0005435372777	9934	Economy	28000.00
0005432203014	9934	Economy	28000.00
0005435149792	9934	Economy	28000.00
0005434821630	9934	Economy	28000.00
0005435149804	9934	Economy	28000.00
0005435372793	9934	Economy	28000.00
0005434831070	9934	Economy	28000.00
0005435372790	9934	Economy	28000.00
0005434821550	9934	Economy	28000.00
0005435735107	9934	Economy	28000.00
0005434821513	9934	Economy	28000.00
0005434821742	9934	Economy	28000.00
0005434821614	9934	Economy	30800.00
0005434821639	9934	Economy	30800.00
0005434828652	9934	Economy	30800.00
0005434558144	9934	Economy	28000.00
0005434821800	9934	Economy	28000.00
0005435372824	9934	Economy	28000.00
0005435372776	9934	Economy	28000.00
0005434821463	9934	Economy	28000.00
0005434821730	9934	Economy	28000.00
0005432823435	9934	Economy	28000.00
0005434821735	9934	Economy	28000.00
0005435735105	9934	Economy	28000.00
0005434821456	9934	Economy	28000.00
0005432203010	9934	Economy	28000.00
0005434821756	9934	Economy	28000.00
0005435372804	9934	Economy	28000.00
0005434821615	9934	Economy	28000.00
0005435302167	9934	Economy	28000.00
0005434558143	9934	Economy	28000.00
0005434821451	9934	Economy	28000.00
0005434821695	9934	Economy	28000.00
0005434821460	9934	Economy	28000.00
0005435372766	9934	Economy	28000.00
0005434821428	9934	Economy	28000.00
0005434821465	9934	Economy	28000.00
0005435372817	9934	Economy	28000.00
0005434821640	9934	Economy	28000.00
0005434821594	9934	Economy	28000.00
0005435661910	9934	Economy	28000.00
0005434821676	9934	Economy	28000.00
0005435372808	9934	Economy	28000.00
0005435372764	9934	Economy	28000.00
0005432203012	9934	Economy	28000.00
0005435386525	9934	Economy	28000.00
0005435372786	9934	Economy	28000.00
0005434821694	9934	Economy	28000.00
0005434821677	9934	Economy	28000.00
0005435372788	9934	Economy	28000.00
0005434822018	9934	Economy	28000.00
0005435372780	9934	Economy	28000.00
0005434821585	9934	Economy	28000.00
0005434821610	9934	Economy	28000.00
0005434831076	9934	Economy	28000.00
0005435302164	9934	Economy	28000.00
0005434821623	9934	Economy	28000.00
0005435179689	9934	Economy	28000.00
0005435149820	9934	Economy	28000.00
0005435372771	9934	Economy	28000.00
0005435149813	9934	Economy	28000.00
0005435149858	9934	Economy	28000.00
0005434821628	9934	Economy	28000.00
0005435372773	9934	Economy	28000.00
0005434821454	9934	Economy	28000.00
0005434821785	9934	Economy	28000.00
0005435661911	9934	Economy	28000.00
0005434821928	9934	Economy	28000.00
0005434558142	9934	Economy	28000.00
0005435372810	9934	Economy	28000.00
0005434821599	9934	Economy	28000.00
0005435372809	9934	Economy	28000.00
0005435149790	9934	Economy	28000.00
0005435299741	9934	Economy	28000.00
0005434821407	9934	Economy	28000.00
0005434821863	9934	Economy	28000.00
0005434821843	9934	Economy	28000.00
0005435735109	9934	Economy	28000.00
0005434664929	9934	Economy	28000.00
0005434821641	9934	Economy	28000.00
0005434821466	9934	Economy	28000.00
0005435082731	7028	Economy	8200.00
0005435790285	7028	Economy	7400.00
0005435082728	7028	Economy	7400.00
0005435082732	7028	Economy	7400.00
0005435082734	7028	Economy	7400.00
0005435790286	7028	Economy	7400.00
0005435790284	7028	Economy	7400.00
0005435082733	7028	Economy	7400.00
0005435082730	7028	Economy	7400.00
0005435082729	7028	Economy	7400.00
0005435082735	7028	Economy	7400.00
0005435082652	26014	Economy	7400.00
0005435790266	26014	Economy	7400.00
0005435082653	26014	Economy	7400.00
0005435082650	26014	Economy	7400.00
0005435082674	26014	Economy	7400.00
0005435790267	26014	Economy	7400.00
0005435082673	26014	Economy	7400.00
0005434756153	9554	Business	32800.00
0005434756147	9554	Business	32800.00
0005434756129	9554	Business	32800.00
0005434213763	9554	Business	32800.00
0005434213822	9554	Business	32800.00
0005434756158	9554	Business	32800.00
0005434756151	9554	Business	32800.00
0005434756167	9554	Business	32800.00
0005434756146	9554	Business	32800.00
0005434213714	9554	Economy	10900.00
0005434213713	9554	Economy	10900.00
0005434756156	9554	Economy	10900.00
0005434756135	9554	Economy	10900.00
0005434213843	9554	Economy	10900.00
0005434756121	9554	Economy	10900.00
0005434213730	9554	Economy	10900.00
0005434756125	9554	Economy	12000.00
0005434756119	9554	Economy	12000.00
0005434756123	9554	Economy	12000.00
0005434756134	9554	Economy	10900.00
0005434756133	9554	Economy	10900.00
0005434756142	9554	Economy	10900.00
0005434756162	9554	Economy	10900.00
0005434756141	9554	Economy	10900.00
0005434756127	9554	Economy	10900.00
0005434756131	9554	Economy	10900.00
0005434756128	9554	Economy	10900.00
0005434756143	9554	Economy	10900.00
0005434756139	9554	Economy	10900.00
0005434756145	9554	Economy	10900.00
0005434213774	9554	Economy	10900.00
0005434213708	9554	Economy	10900.00
0005434213724	9554	Economy	10900.00
0005434213723	9554	Economy	10900.00
0005434213703	9554	Economy	10900.00
0005434756144	9554	Economy	10900.00
0005434756132	9554	Economy	10900.00
0005434213788	9554	Economy	10900.00
0005434756159	9554	Economy	10900.00
0005434213737	9554	Economy	10900.00
0005434756154	9554	Economy	10900.00
0005434756138	9554	Economy	10900.00
0005434756124	9554	Economy	10900.00
0005434213702	9554	Economy	10900.00
0005434213865	9554	Economy	10900.00
0005434213727	9554	Economy	10900.00
0005434756155	9554	Economy	10900.00
0005434213789	9554	Economy	10900.00
0005434756165	9554	Economy	10900.00
0005434756126	9554	Economy	10900.00
0005434756163	9554	Economy	10900.00
0005434756152	9554	Economy	10900.00
0005434756136	9554	Economy	10900.00
0005434213787	9554	Economy	10900.00
0005434756120	9554	Economy	10900.00
0005434213898	9554	Economy	10900.00
0005434213709	9554	Economy	10900.00
0005434213775	9554	Economy	10900.00
0005434756122	9554	Economy	10900.00
0005434756161	9554	Economy	10900.00
0005434756157	9554	Economy	10900.00
0005434213710	9554	Economy	10900.00
0005434756140	9554	Economy	10900.00
0005434756160	9554	Economy	10900.00
0005434756130	9554	Economy	10900.00
0005434213866	9554	Economy	10900.00
0005434213808	9554	Economy	10900.00
0005434213844	9554	Economy	10900.00
0005434756164	9554	Economy	10900.00
0005434756166	9554	Economy	10900.00
0005434756149	9554	Economy	10900.00
0005434756148	9554	Economy	10900.00
0005434756137	9554	Economy	10900.00
0005434213711	9554	Economy	10900.00
0005434213704	9554	Economy	10900.00
0005434213722	9554	Economy	10900.00
0005434756150	9554	Economy	10900.00
0005434213764	9554	Economy	10900.00
0005434755770	28588	Business	32800.00
0005434214146	28588	Business	32800.00
0005434214150	28588	Business	32800.00
0005434214147	28588	Business	32800.00
0005434755727	28588	Business	32800.00
0005434214152	28588	Business	32800.00
0005434214149	28588	Business	32800.00
0005434214173	28588	Business	32800.00
0005434214153	28588	Business	32800.00
0005434214154	28588	Economy	10900.00
0005434755706	28588	Economy	10900.00
0005434214165	28588	Economy	10900.00
0005434755762	28588	Economy	10900.00
0005434214170	28588	Economy	10900.00
0005434755738	28588	Economy	12000.00
0005434214127	28588	Economy	12000.00
0005434755766	28588	Economy	12000.00
0005434755756	28588	Economy	12000.00
0005434214137	28588	Economy	10900.00
0005434214148	28588	Economy	10900.00
0005434214134	28588	Economy	10900.00
0005434214162	28588	Economy	10900.00
0005434755772	28588	Economy	10900.00
0005434755726	28588	Economy	10900.00
0005434214144	28588	Economy	10900.00
0005434755748	28588	Economy	10900.00
0005434755769	28588	Economy	10900.00
0005434214136	28588	Economy	10900.00
0005434214155	28588	Economy	10900.00
0005434214171	28588	Economy	10900.00
0005434214167	28588	Economy	10900.00
0005434755707	28588	Economy	10900.00
0005434755712	28588	Economy	10900.00
0005434214157	28588	Economy	10900.00
0005434214159	28588	Economy	10900.00
0005434755711	28588	Economy	10900.00
0005434214135	28588	Economy	10900.00
0005434214130	28588	Economy	10900.00
0005434214143	28588	Economy	10900.00
0005434214145	28588	Economy	10900.00
0005434214138	28588	Economy	10900.00
0005434214132	28588	Economy	10900.00
0005434214169	28588	Economy	10900.00
0005434214163	28588	Economy	10900.00
0005434214168	28588	Economy	10900.00
0005434755759	28588	Economy	10900.00
0005434214172	28588	Economy	10900.00
0005434214131	28588	Economy	10900.00
0005434214128	28588	Economy	10900.00
0005434755760	28588	Economy	10900.00
0005434214140	28588	Economy	10900.00
0005434755750	28588	Economy	10900.00
0005434214156	28588	Economy	10900.00
0005434214158	28588	Economy	10900.00
0005434214142	28588	Economy	10900.00
0005434214160	28588	Economy	10900.00
0005434755771	28588	Economy	10900.00
0005434755763	28588	Economy	10900.00
0005434214166	28588	Economy	10900.00
0005434755705	28588	Economy	10900.00
0005434755742	28588	Economy	10900.00
0005434214141	28588	Economy	10900.00
0005434755757	28588	Economy	10900.00
0005434214164	28588	Economy	10900.00
0005434214129	28588	Economy	10900.00
0005434214151	28588	Economy	10900.00
0005434214139	28588	Economy	10900.00
0005434214161	28588	Economy	10900.00
0005434214133	28588	Economy	10900.00
0005435100101	10841	Economy	9800.00
0005434760158	10841	Economy	8900.00
0005435100102	10841	Economy	8900.00
0005435100100	10841	Economy	8900.00
0005434760180	31827	Economy	8900.00
0005435100082	31827	Economy	8900.00
0005435100081	31827	Economy	8900.00
0005434639135	1973	Economy	20900.00
0005434639131	1973	Economy	20900.00
0005434639149	1973	Economy	20900.00
0005434639141	1973	Economy	19000.00
0005435948319	1973	Economy	19000.00
0005434639152	1973	Economy	19000.00
0005434639143	1973	Economy	19000.00
0005432290612	1973	Economy	19000.00
0005434639147	1973	Economy	19000.00
0005433202124	1973	Economy	19000.00
0005433202163	1973	Economy	19000.00
0005432290610	1973	Economy	19000.00
0005433202176	1973	Economy	19000.00
0005434639127	1973	Economy	19000.00
0005434639137	1973	Economy	19000.00
0005434639151	1973	Economy	19000.00
0005434639136	1973	Economy	19000.00
0005434639153	1973	Economy	19000.00
0005434639139	1973	Economy	19000.00
0005435948318	1973	Economy	19000.00
0005433202103	1973	Economy	19000.00
0005434639148	1973	Economy	19000.00
0005432290613	1973	Economy	19000.00
0005432290611	1973	Economy	19000.00
0005434639129	1973	Economy	19000.00
0005434639132	1973	Economy	19000.00
0005434639144	1973	Economy	19000.00
0005433202127	1973	Economy	19000.00
0005435948317	1973	Economy	19000.00
0005434639126	1973	Economy	19000.00
0005434639146	1973	Economy	19000.00
0005434639150	1973	Economy	19000.00
0005434639140	1973	Economy	19000.00
0005434639128	1973	Economy	19000.00
0005432290614	1973	Economy	19000.00
0005434639130	1973	Economy	19000.00
0005434639134	1973	Economy	19000.00
0005433202134	1973	Economy	19000.00
0005434639133	1973	Economy	19000.00
0005433202128	1973	Economy	19000.00
0005434639145	1973	Economy	19000.00
0005434639142	1973	Economy	19000.00
0005434639138	1973	Economy	19000.00
0005433202242	23276	Economy	20900.00
0005433202244	23276	Economy	20900.00
0005434638874	23276	Economy	20900.00
0005433202247	23276	Economy	19000.00
0005433202239	23276	Economy	19000.00
0005434638892	23276	Economy	19000.00
0005435948306	23276	Economy	19000.00
0005434638935	23276	Economy	19000.00
0005434638868	23276	Economy	19000.00
0005433202250	23276	Economy	19000.00
0005434638856	23276	Economy	19000.00
0005434638932	23276	Economy	19000.00
0005433202245	23276	Economy	19000.00
0005435948305	23276	Economy	19000.00
0005434638875	23276	Economy	19000.00
0005434638934	23276	Economy	19000.00
0005434638867	23276	Economy	19000.00
0005433202241	23276	Economy	19000.00
0005433202240	23276	Economy	19000.00
0005433202251	23276	Economy	19000.00
0005434638976	23276	Economy	19000.00
0005433202252	23276	Economy	19000.00
0005433202248	23276	Economy	19000.00
0005434638869	23276	Economy	19000.00
0005433202249	23276	Economy	19000.00
0005434638849	23276	Economy	19000.00
0005433202243	23276	Economy	19000.00
0005434638891	23276	Economy	19000.00
0005434638872	23276	Economy	19000.00
0005434638873	23276	Economy	19000.00
0005433202246	23276	Economy	19000.00
0005435326581	6062	Business	69700.00
0005433533282	6062	Business	69700.00
0005433533279	6062	Business	69700.00
0005434600609	6062	Business	69700.00
0005434600622	6062	Business	69700.00
0005433531265	6062	Economy	23200.00
0005434600624	6062	Economy	23200.00
0005435326534	6062	Economy	23200.00
0005435326537	6062	Economy	23200.00
0005434600608	6062	Economy	23200.00
0005434600610	6062	Economy	23200.00
0005434600628	6062	Economy	23200.00
0005434600623	6062	Economy	23200.00
0005435326514	6062	Economy	23200.00
0005435326505	6062	Economy	23200.00
0005433531267	6062	Economy	23200.00
0005432111257	6062	Economy	23200.00
0005434600618	6062	Economy	23200.00
0005435326550	6062	Economy	23200.00
0005434600603	6062	Economy	23200.00
0005434600617	6062	Economy	23200.00
0005434600625	6062	Economy	23200.00
0005434600607	6062	Economy	23200.00
0005434600627	6062	Economy	23200.00
0005434600615	6062	Economy	23200.00
0005434600605	6062	Economy	23200.00
0005433533281	6062	Economy	23200.00
0005433531268	6062	Economy	23200.00
0005434600621	6062	Economy	23200.00
0005434600606	6062	Economy	23200.00
0005434600620	6062	Economy	23200.00
0005434600613	6062	Economy	23200.00
0005435326497	6062	Economy	23200.00
0005434600619	6062	Economy	23200.00
0005434600604	6062	Economy	23200.00
0005432111258	6062	Economy	23200.00
0005435326533	6062	Economy	23200.00
0005434600612	6062	Economy	23200.00
0005433533280	6062	Economy	23200.00
0005435326538	6062	Economy	23200.00
0005434600616	6062	Economy	23200.00
0005434600629	6062	Economy	23200.00
0005434600614	6062	Economy	23200.00
0005433531266	6062	Economy	23200.00
0005434600626	6062	Economy	23200.00
0005435326580	6062	Economy	23200.00
0005434600611	6062	Economy	23200.00
0005435326513	6062	Economy	23200.00
0005434600424	18611	Business	69700.00
0005434600363	18611	Business	69700.00
0005434600343	18611	Business	69700.00
0005434600335	18611	Business	69700.00
0005434600362	18611	Business	69700.00
0005434600342	18611	Business	69700.00
0005434600375	18611	Business	69700.00
0005434600457	18611	Economy	23200.00
0005435326645	18611	Economy	23200.00
0005435326652	18611	Economy	23200.00
0005434600364	18611	Economy	25600.00
0005434600425	18611	Economy	25600.00
0005433531248	18611	Economy	25600.00
0005434600419	18611	Economy	23200.00
0005434600365	18611	Economy	23200.00
0005434600452	18611	Economy	23200.00
0005434600454	18611	Economy	23200.00
0005434600436	18611	Economy	23200.00
0005434600412	18611	Economy	23200.00
0005435326649	18611	Economy	23200.00
0005435326640	18611	Economy	23200.00
0005435326651	18611	Economy	23200.00
0005435326646	18611	Economy	23200.00
0005435326641	18611	Economy	23200.00
0005433531235	18611	Economy	23200.00
0005434600396	18611	Economy	23200.00
0005435326642	18611	Economy	23200.00
0005435326653	18611	Economy	23200.00
0005433531247	18611	Economy	23200.00
0005435326650	18611	Economy	23200.00
0005435326644	18611	Economy	23200.00
0005433531236	18611	Economy	23200.00
0005434600354	18611	Economy	23200.00
0005435326643	18611	Economy	23200.00
0005435326648	18611	Economy	23200.00
0005434600344	18611	Economy	23200.00
0005434600455	18611	Economy	23200.00
0005435326647	18611	Economy	23200.00
0005433531240	18611	Economy	23200.00
0005434558206	10574	Business	9100.00
0005434550779	10574	Business	9100.00
0005434550775	10574	Business	9100.00
0005433180769	10574	Business	9100.00
0005434550790	10574	Business	9100.00
0005434550793	10574	Business	9100.00
0005434550796	10574	Business	9100.00
0005433180726	10574	Business	9100.00
0005434550766	10574	Economy	3000.00
0005434550810	10574	Economy	3000.00
0005433180673	10574	Economy	3000.00
0005434550776	10574	Economy	3000.00
0005433180713	10574	Economy	3000.00
0005434550800	10574	Economy	3000.00
0005434550806	10574	Economy	3000.00
0005433180651	10574	Economy	3000.00
0005434558205	10574	Economy	3000.00
0005434558207	10574	Economy	3300.00
0005434550798	10574	Economy	3300.00
0005434550792	10574	Economy	3300.00
0005433180674	10574	Economy	3300.00
0005434554047	10574	Economy	3300.00
0005434550771	10574	Economy	3000.00
0005433180712	10574	Economy	3000.00
0005434550801	10574	Economy	3000.00
0005434550812	10574	Economy	3000.00
0005433180685	10574	Economy	3000.00
0005434550799	10574	Economy	3000.00
0005434550788	10574	Economy	3000.00
0005434550815	10574	Economy	3000.00
0005434554048	10574	Economy	3000.00
0005434550770	10574	Economy	3000.00
0005434558210	10574	Economy	3000.00
0005434558208	10574	Economy	3000.00
0005434550797	10574	Economy	3000.00
0005433180684	10574	Economy	3000.00
0005434550774	10574	Economy	3000.00
0005433180650	10574	Economy	3000.00
0005434550773	10574	Economy	3000.00
0005434558209	10574	Economy	3000.00
0005434550794	10574	Economy	3000.00
0005434550791	10574	Economy	3000.00
0005434550805	10574	Economy	3000.00
0005434550795	10574	Economy	3000.00
0005434550782	10574	Economy	3000.00
0005434550764	10574	Economy	3000.00
0005433180661	10574	Economy	3000.00
0005434550769	10574	Economy	3000.00
0005434550804	10574	Economy	3000.00
0005433180664	10574	Economy	3000.00
0005434550765	10574	Economy	3000.00
0005433180686	10574	Economy	3000.00
0005434550780	10574	Economy	3000.00
0005434550803	10574	Economy	3000.00
0005434550817	10574	Economy	3000.00
0005434550816	10574	Economy	3000.00
0005434550814	10574	Economy	3000.00
0005433180727	10574	Economy	3000.00
0005433180662	10574	Economy	3000.00
0005434550785	10574	Economy	3000.00
0005434550767	10574	Economy	3000.00
0005434550781	10574	Economy	3000.00
0005434550813	10574	Economy	3000.00
0005433180665	10574	Economy	3000.00
0005434550768	10574	Economy	3000.00
0005434550802	10574	Economy	3000.00
0005433180663	10574	Economy	3000.00
0005434550789	10574	Economy	3000.00
0005434550784	10574	Economy	3000.00
0005434550787	10574	Economy	3000.00
0005434550777	10574	Economy	3000.00
0005434550811	10574	Economy	3000.00
0005434550818	10574	Economy	3000.00
0005434550808	10574	Economy	3000.00
0005434550763	10574	Economy	3000.00
0005434550807	10574	Economy	3000.00
0005434550772	10574	Economy	3000.00
0005434550783	10574	Economy	3000.00
0005434550786	10574	Economy	3000.00
0005434550809	10574	Economy	3000.00
0005434550778	10574	Economy	3000.00
0005433180906	27741	Business	9100.00
0005433180913	27741	Business	9100.00
0005433180915	27741	Economy	3000.00
0005433180921	27741	Economy	3000.00
0005433180917	27741	Economy	3300.00
0005433180910	27741	Economy	3000.00
0005433180925	27741	Economy	3000.00
0005433180916	27741	Economy	3000.00
0005433180931	27741	Economy	3000.00
0005433180918	27741	Economy	3000.00
0005433180932	27741	Economy	3000.00
0005433180927	27741	Economy	3000.00
0005433180930	27741	Economy	3000.00
0005433180926	27741	Economy	3000.00
0005433180909	27741	Economy	3000.00
0005433180908	27741	Economy	3000.00
0005433180911	27741	Economy	3000.00
0005433180928	27741	Economy	3000.00
0005433180922	27741	Economy	3000.00
0005433180929	27741	Economy	3000.00
0005433180923	27741	Economy	3000.00
0005433180912	27741	Economy	3000.00
0005433180919	27741	Economy	3000.00
0005433180907	27741	Economy	3000.00
0005433180924	27741	Economy	3000.00
0005433180920	27741	Economy	3000.00
0005433180914	27741	Economy	3000.00
0005434550481	27761	Business	9100.00
0005434554031	27761	Business	9100.00
0005434550352	27761	Business	9100.00
0005434550351	27761	Business	9100.00
0005434550366	27761	Business	9100.00
0005434550430	27761	Business	9100.00
0005434550280	27761	Business	9100.00
0005434550480	27761	Business	9100.00
0005434550483	27761	Business	9100.00
0005434550413	27761	Economy	3000.00
0005434550284	27761	Economy	3000.00
0005434550259	27761	Economy	3000.00
0005434550578	27761	Economy	3000.00
0005434550326	27761	Economy	3000.00
0005434550260	27761	Economy	3000.00
0005434550331	27761	Economy	3000.00
0005434554027	27761	Economy	3000.00
0005434550388	27761	Economy	3300.00
0005434550522	27761	Economy	3300.00
0005434550422	27761	Economy	3000.00
0005434550367	27761	Economy	3000.00
0005434550501	27761	Economy	3000.00
0005434550383	27761	Economy	3000.00
0005434550577	27761	Economy	3000.00
0005434550298	27761	Economy	3000.00
0005434550301	27761	Economy	3000.00
0005434550377	27761	Economy	3000.00
0005434550339	27761	Economy	3000.00
0005434550432	27761	Economy	3000.00
0005434550557	27761	Economy	3000.00
0005434550281	27761	Economy	3000.00
0005434550325	27761	Economy	3000.00
0005434550386	27761	Economy	3000.00
0005434550581	27761	Economy	3000.00
0005434550365	27761	Economy	3000.00
0005434550429	27761	Economy	3000.00
0005434550488	27761	Economy	3000.00
0005434550449	27761	Economy	3000.00
0005434550511	27761	Economy	3000.00
0005434550484	27761	Economy	3000.00
0005434550500	27761	Economy	3000.00
0005434550410	27761	Economy	3000.00
0005434550389	27761	Economy	3000.00
0005434550420	27761	Economy	3000.00
0005434550357	27761	Economy	3000.00
0005434550508	27761	Economy	3000.00
0005434550446	27761	Economy	3000.00
0005434550411	27761	Economy	3000.00
0005434550368	27761	Economy	3000.00
0005434550421	27761	Economy	3000.00
0005434550320	27761	Economy	3000.00
0005434554026	27761	Economy	3000.00
0005434550384	27761	Economy	3000.00
0005434550495	27761	Economy	3000.00
0005433459188	6156	Economy	11700.00
0005433459190	6156	Economy	11700.00
0005435254439	6156	Economy	11700.00
0005433459187	6156	Economy	11700.00
0005433459191	6156	Economy	11700.00
0005435254429	6156	Economy	11700.00
0005433459189	6156	Economy	11700.00
0005435254430	6156	Economy	11700.00
0005435254438	6156	Economy	11700.00
0005433459161	19288	Economy	11700.00
0005435254458	19288	Economy	11700.00
0005433459156	19288	Economy	11700.00
0005435254456	19288	Economy	11700.00
0005433459160	19288	Economy	11700.00
0005435254455	19288	Economy	11700.00
0005435254457	19288	Economy	11700.00
0005435681820	6735	Business	51100.00
0005435437665	6735	Business	51100.00
0005435437717	6735	Business	51100.00
0005435681817	6735	Business	51100.00
0005435681821	6735	Business	51100.00
0005435720128	6735	Business	51100.00
0005435437611	6735	Business	51100.00
0005432136132	6735	Business	51100.00
0005435661909	6735	Business	51100.00
0005435437627	6735	Business	51100.00
0005435681811	6735	Economy	17000.00
0005435661907	6735	Economy	17000.00
0005435681830	6735	Economy	17000.00
0005435437559	6735	Economy	17000.00
0005435681843	6735	Economy	17000.00
0005435437616	6735	Economy	17000.00
0005435681835	6735	Economy	17000.00
0005435681833	6735	Economy	18700.00
0005435681837	6735	Economy	18700.00
0005435681831	6735	Economy	18700.00
0005435437666	6735	Economy	18700.00
0005435681810	6735	Economy	17000.00
0005435719562	6735	Economy	17000.00
0005435681829	6735	Economy	17000.00
0005435681842	6735	Economy	17000.00
0005435681838	6735	Economy	17000.00
0005435217678	6735	Economy	17000.00
0005435437579	6735	Economy	17000.00
0005435681847	6735	Economy	17000.00
0005435630941	6735	Economy	17000.00
0005435220285	6735	Economy	17000.00
0005435437647	6735	Economy	17000.00
0005435681841	6735	Economy	17000.00
0005435681836	6735	Economy	17000.00
0005435661908	6735	Economy	17000.00
0005435681828	6735	Economy	17000.00
0005435681815	6735	Economy	17000.00
0005435681825	6735	Economy	17000.00
0005435681824	6735	Economy	17000.00
0005435681840	6735	Economy	17000.00
0005435681822	6735	Economy	17000.00
0005435437597	6735	Economy	17000.00
0005435437624	6735	Economy	17000.00
0005432136133	6735	Economy	17000.00
0005432136130	6735	Economy	17000.00
0005432136134	6735	Economy	17000.00
0005435630943	6735	Economy	17000.00
0005435681845	6735	Economy	17000.00
0005435437684	6735	Economy	17000.00
0005435681826	6735	Economy	17000.00
0005435681813	6735	Economy	17000.00
0005435681823	6735	Economy	17000.00
0005435437636	6735	Economy	17000.00
0005435681844	6735	Economy	17000.00
0005435437610	6735	Economy	17000.00
0005435681846	6735	Economy	17000.00
0005435681816	6735	Economy	17000.00
0005432136131	6735	Economy	17000.00
0005435681839	6735	Economy	17000.00
0005435437637	6735	Economy	17000.00
0005432136135	6735	Economy	17000.00
0005435437664	6735	Economy	17000.00
0005435437650	6735	Economy	17000.00
0005435437623	6735	Economy	17000.00
0005435661906	6735	Economy	17000.00
0005435681832	6735	Economy	17000.00
0005435437626	6735	Economy	17000.00
0005435437628	6735	Economy	17000.00
0005435681819	6735	Economy	17000.00
0005435681812	6735	Economy	17000.00
0005435437668	6735	Economy	17000.00
0005435719561	6735	Economy	17000.00
0005435437625	6735	Economy	17000.00
0005432533240	6735	Economy	17000.00
0005435681834	6735	Economy	17000.00
0005435630942	6735	Economy	17000.00
0005435681827	6735	Economy	17000.00
0005435681814	6735	Economy	17000.00
0005435437646	6735	Economy	17000.00
0005435681818	6735	Economy	17000.00
0005432533271	24564	Business	51100.00
0005435437798	24564	Business	51100.00
0005435681483	24564	Business	51100.00
0005435437780	24564	Business	51100.00
0005435681551	24564	Business	51100.00
0005435437789	24564	Business	51100.00
0005435681556	24564	Business	51100.00
0005435681450	24564	Business	51100.00
0005435681618	24564	Economy	17000.00
0005435437783	24564	Economy	17000.00
0005435681611	24564	Economy	17000.00
0005435681468	24564	Economy	17000.00
0005435437793	24564	Economy	17000.00
0005435681513	24564	Economy	17000.00
0005435437790	24564	Economy	17000.00
0005435681421	24564	Economy	17000.00
0005435681499	24564	Economy	18700.00
0005435437784	24564	Economy	18700.00
0005435437792	24564	Economy	18700.00
0005435681531	24564	Economy	17000.00
0005435681476	24564	Economy	17000.00
0005432305731	24564	Economy	17000.00
0005435219181	24564	Economy	17000.00
0005435219186	24564	Economy	17000.00
0005435630927	24564	Economy	17000.00
0005435681428	24564	Economy	17000.00
0005435681429	24564	Economy	17000.00
0005435681580	24564	Economy	17000.00
0005435681469	24564	Economy	17000.00
0005435219184	24564	Economy	17000.00
0005435437797	24564	Economy	17000.00
0005435437791	24564	Economy	17000.00
0005435720801	24564	Economy	17000.00
0005435681411	24564	Economy	17000.00
0005435681532	24564	Economy	17000.00
0005435220303	24564	Economy	17000.00
0005435220300	24564	Economy	17000.00
0005435220301	24564	Economy	17000.00
0005435681541	24564	Economy	17000.00
0005435437786	24564	Economy	17000.00
0005434828676	24564	Economy	17000.00
0005435630928	24564	Economy	17000.00
0005435681435	24564	Economy	17000.00
0005435681401	24564	Economy	17000.00
0005434828678	24564	Economy	17000.00
0005434828677	24564	Economy	17000.00
0005435437796	24564	Economy	17000.00
0005435437787	24564	Economy	17000.00
0005435681505	24564	Economy	17000.00
0005435681540	24564	Economy	17000.00
0005435661881	24564	Economy	17000.00
0005435437788	24564	Economy	17000.00
0005435630922	24564	Economy	17000.00
0005435220302	24564	Economy	17000.00
0005435219185	24564	Economy	17000.00
0005435681550	24564	Economy	17000.00
0005435681434	24564	Economy	17000.00
0005435437795	24564	Economy	17000.00
0005432533269	24564	Economy	17000.00
0005435219183	24564	Economy	17000.00
0005435437794	24564	Economy	17000.00
0005435681471	24564	Economy	17000.00
0005435437800	24564	Economy	17000.00
0005435437785	24564	Economy	17000.00
0005432533270	24564	Economy	17000.00
0005435437782	24564	Economy	17000.00
0005435661879	24564	Economy	17000.00
0005435630921	24564	Economy	17000.00
0005435681530	24564	Economy	17000.00
0005435437781	24564	Economy	17000.00
0005435219182	24564	Economy	17000.00
0005435437799	24564	Economy	17000.00
0005435681441	24564	Economy	17000.00
0005435437779	24564	Economy	17000.00
0005435220304	24564	Economy	17000.00
0005435126026	11502	Business	26400.00
0005435126027	11502	Business	26400.00
0005435126036	11502	Economy	8800.00
0005435126041	11502	Economy	8800.00
0005435126057	11502	Economy	8800.00
0005435126033	11502	Economy	8800.00
0005435126031	11502	Economy	8800.00
0005435126022	11502	Economy	8800.00
0005435105958	11502	Economy	8800.00
0005435126054	11502	Economy	9700.00
0005435126046	11502	Economy	9700.00
0005435126024	11502	Economy	9700.00
0005435105957	11502	Economy	8800.00
0005435126030	11502	Economy	8800.00
0005435126034	11502	Economy	8800.00
0005435126037	11502	Economy	8800.00
0005435126056	11502	Economy	8800.00
0005435126052	11502	Economy	8800.00
0005435126028	11502	Economy	8800.00
0005435126055	11502	Economy	8800.00
0005435126040	11502	Economy	8800.00
0005435126025	11502	Economy	8800.00
0005435126043	11502	Economy	8800.00
0005435126049	11502	Economy	8800.00
0005435105956	11502	Economy	8800.00
0005435126047	11502	Economy	8800.00
0005435126050	11502	Economy	8800.00
0005435126045	11502	Economy	8800.00
0005435126058	11502	Economy	8800.00
0005435126051	11502	Economy	8800.00
0005435126032	11502	Economy	8800.00
0005435126060	11502	Economy	8800.00
0005435558048	11502	Economy	8800.00
0005435126044	11502	Economy	8800.00
0005435126039	11502	Economy	8800.00
0005435105955	11502	Economy	8800.00
0005435126061	11502	Economy	8800.00
0005435126062	11502	Economy	8800.00
0005435126029	11502	Economy	8800.00
0005435126063	11502	Economy	8800.00
0005435126048	11502	Economy	8800.00
0005435126042	11502	Economy	8800.00
0005435126023	11502	Economy	8800.00
0005435126059	11502	Economy	8800.00
0005435126035	11502	Economy	8800.00
0005435126053	11502	Economy	8800.00
0005435126038	11502	Economy	8800.00
0005435125885	31871	Business	26400.00
0005435125713	31871	Business	26400.00
0005435125809	31871	Business	26400.00
0005435125736	31871	Business	26400.00
0005435558068	31871	Business	26400.00
0005435125723	31871	Economy	8800.00
0005435125739	31871	Economy	8800.00
0005435125666	31871	Economy	8800.00
0005435125738	31871	Economy	8800.00
0005435125702	31871	Economy	8800.00
0005435125758	31871	Economy	8800.00
0005435125759	31871	Economy	9700.00
0005435125665	31871	Economy	9700.00
0005435125699	31871	Economy	8800.00
0005435125686	31871	Economy	8800.00
0005435125788	31871	Economy	8800.00
0005435125800	31871	Economy	8800.00
0005435125737	31871	Economy	8800.00
0005435125664	31871	Economy	8800.00
0005435125817	31871	Economy	8800.00
0005435125792	31871	Economy	8800.00
0005435125785	31871	Economy	8800.00
0005435125842	31871	Economy	8800.00
0005435125651	31871	Economy	8800.00
0005435125720	31871	Economy	8800.00
0005435125847	31871	Economy	8800.00
0005435125740	31871	Economy	8800.00
0005435125756	31871	Economy	8800.00
0005435105937	31871	Economy	8800.00
0005435125724	31871	Economy	8800.00
0005435558067	31871	Economy	8800.00
0005435125683	31871	Economy	8800.00
0005435125846	31871	Economy	8800.00
0005435125650	31871	Economy	8800.00
0005435098522	31871	Economy	8800.00
0005435125884	31871	Economy	8800.00
0005435125789	31871	Economy	8800.00
0005435125766	31871	Economy	8800.00
0005435125700	31871	Economy	8800.00
0005435125757	31871	Economy	8800.00
0005435125706	31871	Economy	8800.00
0005435125763	31871	Economy	8800.00
0005435732196	13556	Business	36600.00
0005433397722	13556	Business	36600.00
0005433397717	13556	Business	36600.00
0005433397720	13556	Business	36600.00
0005433397679	13556	Business	36600.00
0005433397682	13556	Business	36600.00
0005433397721	13556	Business	36600.00
0005433397696	13556	Economy	12200.00
0005433397709	13556	Economy	12200.00
0005433397718	13556	Economy	12200.00
0005433397688	13556	Economy	12200.00
0005433397699	13556	Economy	12200.00
0005435732144	13556	Economy	13400.00
0005433397693	13556	Economy	13400.00
0005433397714	13556	Economy	13400.00
0005433397680	13556	Economy	13400.00
0005433397683	13556	Economy	12200.00
0005433397708	13556	Economy	12200.00
0005433397715	13556	Economy	12200.00
0005435732147	13556	Economy	12200.00
0005433397700	13556	Economy	12200.00
0005433397698	13556	Economy	12200.00
0005433397710	13556	Economy	12200.00
0005433397687	13556	Economy	12200.00
0005433397690	13556	Economy	12200.00
0005435732143	13556	Economy	12200.00
0005435732146	13556	Economy	12200.00
0005433397678	13556	Economy	12200.00
0005435732132	13556	Economy	12200.00
0005435732115	13556	Economy	12200.00
0005433397719	13556	Economy	12200.00
0005433397695	13556	Economy	12200.00
0005433397713	13556	Economy	12200.00
0005433397705	13556	Economy	12200.00
0005433397692	13556	Economy	12200.00
0005433397712	13556	Economy	12200.00
0005433397711	13556	Economy	12200.00
0005433397677	13556	Economy	12200.00
0005433397701	13556	Economy	12200.00
0005433397689	13556	Economy	12200.00
0005433397707	13556	Economy	12200.00
0005433397686	13556	Economy	12200.00
0005435732161	13556	Economy	12200.00
0005433397685	13556	Economy	12200.00
0005433397723	13556	Economy	12200.00
0005435732212	13556	Economy	12200.00
0005433397702	13556	Economy	12200.00
0005433397691	13556	Economy	12200.00
0005433397703	13556	Economy	12200.00
0005433397725	13556	Economy	12200.00
0005433397724	13556	Economy	12200.00
0005435732114	13556	Economy	12200.00
0005433397676	13556	Economy	12200.00
0005433397716	13556	Economy	12200.00
0005433397684	13556	Economy	12200.00
0005435732213	13556	Economy	12200.00
0005433397697	13556	Economy	12200.00
0005433397694	13556	Economy	12200.00
0005433397706	13556	Economy	12200.00
0005433397704	13556	Economy	12200.00
0005433397681	13556	Economy	12200.00
0005433397472	19392	Business	36600.00
0005433397232	19392	Business	36600.00
0005433397231	19392	Business	36600.00
0005435732239	19392	Business	36600.00
0005433397233	19392	Business	36600.00
0005435732235	19392	Business	36600.00
0005435732238	19392	Business	36600.00
0005432297258	19392	Business	36600.00
0005433397311	19392	Economy	12200.00
0005432297259	19392	Economy	12200.00
0005435732246	19392	Economy	12200.00
0005433397223	19392	Economy	12200.00
0005435732243	19392	Economy	12200.00
0005433397349	19392	Economy	13400.00
0005435732254	19392	Economy	13400.00
0005433397261	19392	Economy	13400.00
0005435732252	19392	Economy	12200.00
0005433397186	19392	Economy	12200.00
0005435732236	19392	Economy	12200.00
0005433397193	19392	Economy	12200.00
0005435732250	19392	Economy	12200.00
0005435732251	19392	Economy	12200.00
0005433397280	19392	Economy	12200.00
0005433397294	19392	Economy	12200.00
0005433397180	19392	Economy	12200.00
0005433397329	19392	Economy	12200.00
0005433397192	19392	Economy	12200.00
0005435732242	19392	Economy	12200.00
0005433397235	19392	Economy	12200.00
0005433397281	19392	Economy	12200.00
0005435732244	19392	Economy	12200.00
0005433397282	19392	Economy	12200.00
0005435732237	19392	Economy	12200.00
0005435732234	19392	Economy	12200.00
0005433397320	19392	Economy	12200.00
0005435732241	19392	Economy	12200.00
0005435732247	19392	Economy	12200.00
0005435732248	19392	Economy	12200.00
0005433397253	19392	Economy	12200.00
0005433397328	19392	Economy	12200.00
0005433397295	19392	Economy	12200.00
0005435732240	19392	Economy	12200.00
0005433397243	19392	Economy	12200.00
0005433397399	19392	Economy	12200.00
0005435732233	19392	Economy	12200.00
0005435732255	19392	Economy	12200.00
0005433397277	19392	Economy	12200.00
0005435732256	19392	Economy	12200.00
0005435732245	19392	Economy	12200.00
0005433397312	19392	Economy	12200.00
0005433397400	19392	Economy	12200.00
0005433397256	19392	Economy	12200.00
0005432297257	19392	Economy	12200.00
0005432297260	19392	Economy	12200.00
0005433397240	19392	Economy	12200.00
0005435732253	19392	Economy	12200.00
0005433397519	19392	Economy	12200.00
0005433397344	19392	Economy	12200.00
0005433397458	19392	Economy	12200.00
0005435732249	19392	Economy	12200.00
0005435068354	13177	Business	11300.00
0005435068199	13177	Business	11300.00
0005435068295	13177	Business	11300.00
0005435068298	13177	Business	11300.00
0005435068176	13177	Business	11300.00
0005435068273	13177	Economy	3800.00
0005435068262	13177	Economy	3800.00
0005435068253	13177	Economy	3800.00
0005435068254	13177	Economy	4100.00
0005435068177	13177	Economy	3800.00
0005435068201	13177	Economy	3800.00
0005435068163	13177	Economy	3800.00
0005435068453	13177	Economy	3800.00
0005435068383	13177	Economy	3800.00
0005435068454	13177	Economy	3800.00
0005435068244	13177	Economy	3800.00
0005435068382	13177	Economy	3800.00
0005435068333	13177	Economy	3800.00
0005435068164	13177	Economy	3800.00
0005435068356	13177	Economy	3800.00
0005435068296	13177	Economy	3800.00
0005435068174	13177	Economy	3800.00
0005435068249	13177	Economy	3800.00
0005435068303	13177	Economy	3800.00
0005435068355	13177	Economy	3800.00
0005435068248	13177	Economy	3800.00
0005435068297	13177	Economy	3800.00
0005435068261	13177	Economy	3800.00
0005435068299	13177	Economy	3800.00
0005435068467	13177	Economy	3800.00
0005435068317	13177	Economy	3800.00
0005435068294	13177	Economy	3800.00
0005435068182	13177	Economy	3800.00
0005435068173	13177	Economy	3800.00
0005435068316	13177	Economy	3800.00
0005435068468	13177	Economy	3800.00
0005435068639	15512	Business	11300.00
0005435068680	15512	Business	11300.00
0005435068686	15512	Business	11300.00
0005435068643	15512	Business	11300.00
0005435068638	15512	Business	11300.00
0005435068681	15512	Business	11300.00
0005435068653	15512	Business	11300.00
0005435068658	15512	Business	11300.00
0005435068670	15512	Business	11300.00
0005435925049	15512	Economy	3800.00
0005435068676	15512	Economy	3800.00
0005435068661	15512	Economy	3800.00
0005435068663	15512	Economy	3800.00
0005435925047	15512	Economy	3800.00
0005435068637	15512	Economy	3800.00
0005435068646	15512	Economy	4100.00
0005435068666	15512	Economy	4100.00
0005435068664	15512	Economy	4100.00
0005435068648	15512	Economy	3800.00
0005435068652	15512	Economy	3800.00
0005435068685	15512	Economy	3800.00
0005435068673	15512	Economy	3800.00
0005435068683	15512	Economy	3800.00
0005435068675	15512	Economy	3800.00
0005435068654	15512	Economy	3800.00
0005435925067	15512	Economy	3800.00
0005435925071	15512	Economy	3800.00
0005435068642	15512	Economy	3800.00
0005435068660	15512	Economy	3800.00
0005435068678	15512	Economy	3800.00
0005435068645	15512	Economy	3800.00
0005435068667	15512	Economy	3800.00
0005435068644	15512	Economy	3800.00
0005435925054	15512	Economy	3800.00
0005435068650	15512	Economy	3800.00
0005435068682	15512	Economy	3800.00
0005435068655	15512	Economy	3800.00
0005435068649	15512	Economy	3800.00
0005435068672	15512	Economy	3800.00
0005435068674	15512	Economy	3800.00
0005435068671	15512	Economy	3800.00
0005435068635	15512	Economy	3800.00
0005435068669	15512	Economy	3800.00
0005435068668	15512	Economy	3800.00
0005435925050	15512	Economy	3800.00
0005435068684	15512	Economy	3800.00
0005435068656	15512	Economy	3800.00
0005435068679	15512	Economy	3800.00
0005435068677	15512	Economy	3800.00
0005435068651	15512	Economy	3800.00
0005435925048	15512	Economy	3800.00
0005435068662	15512	Economy	3800.00
0005435925068	15512	Economy	3800.00
0005435068659	15512	Economy	3800.00
0005435068657	15512	Economy	3800.00
0005435068641	15512	Economy	3800.00
0005435925053	15512	Economy	3800.00
0005435068647	15512	Economy	3800.00
0005435068640	15512	Economy	3800.00
0005435068665	15512	Economy	3800.00
0005435068687	15512	Economy	3800.00
0005435068636	15512	Economy	3800.00
0005435808153	23177	Economy	27100.00
0005435808150	23177	Economy	27100.00
0005435808144	23177	Economy	24700.00
0005435808154	23177	Economy	24700.00
0005435808137	23177	Economy	24700.00
0005435808140	23177	Economy	24700.00
0005435808147	23177	Economy	24700.00
0005435808141	23177	Economy	24700.00
0005433407485	23177	Economy	24700.00
0005435808138	23177	Economy	24700.00
0005435808151	23177	Economy	24700.00
0005435808142	23177	Economy	24700.00
0005435808146	23177	Economy	24700.00
0005435808148	23177	Economy	24700.00
0005435808136	23177	Economy	24700.00
0005433407483	23177	Economy	24700.00
0005435808149	23177	Economy	24700.00
0005433407477	23177	Economy	24700.00
0005435808139	23177	Economy	24700.00
0005435808143	23177	Economy	24700.00
0005433407484	23177	Economy	24700.00
0005435808145	23177	Economy	24700.00
0005435808155	23177	Economy	24700.00
0005435808152	23177	Economy	24700.00
0005434755764	10736	Business	61300.00
0005434755703	10736	Business	61300.00
0005434214193	10736	Business	61300.00
0005434214188	10736	Business	61300.00
0005434214200	10736	Business	61300.00
0005434214186	10736	Business	61300.00
0005434214215	10736	Economy	20400.00
0005434214178	10736	Economy	20400.00
0005434214187	10736	Economy	20400.00
0005434214179	10736	Economy	20400.00
0005434214207	10736	Economy	20400.00
0005434214199	10736	Economy	20400.00
0005434214202	10736	Economy	22500.00
0005434214208	10736	Economy	22500.00
0005434214217	10736	Economy	22500.00
0005434214196	10736	Economy	20400.00
0005434755811	10736	Economy	20400.00
0005434214204	10736	Economy	20400.00
0005434755737	10736	Economy	20400.00
0005434755810	10736	Economy	20400.00
0005434755754	10736	Economy	20400.00
0005434755704	10736	Economy	20400.00
0005434214220	10736	Economy	20400.00
0005434214184	10736	Economy	20400.00
0005434214198	10736	Economy	20400.00
0005434214189	10736	Economy	20400.00
0005434214181	10736	Economy	20400.00
0005434214192	10736	Economy	20400.00
0005434214218	10736	Economy	20400.00
0005434214175	10736	Economy	20400.00
0005434755778	10736	Economy	20400.00
0005434755823	10736	Economy	20400.00
0005434755801	10736	Economy	20400.00
0005434214185	10736	Economy	20400.00
0005434214177	10736	Economy	20400.00
0005434214180	10736	Economy	20400.00
0005434755777	10736	Economy	20400.00
0005434755799	10736	Economy	20400.00
0005434214211	10736	Economy	20400.00
0005434214203	10736	Economy	20400.00
0005434755761	10736	Economy	20400.00
0005434214205	10736	Economy	20400.00
0005434214191	10736	Economy	20400.00
0005434214183	10736	Economy	20400.00
0005434755822	10736	Economy	20400.00
0005434214212	10736	Economy	20400.00
0005434214219	10736	Economy	20400.00
0005434214176	10736	Economy	20400.00
0005434755719	10736	Economy	20400.00
0005434214214	10736	Economy	20400.00
0005434214194	10736	Economy	20400.00
0005434214206	10736	Economy	20400.00
0005434755723	10736	Economy	20400.00
0005434214210	10736	Economy	20400.00
0005434214213	10736	Economy	20400.00
0005434755739	10736	Economy	20400.00
0005434214190	10736	Economy	20400.00
0005434214195	10736	Economy	20400.00
0005434214216	10736	Economy	20400.00
0005434755732	10736	Economy	20400.00
0005434214182	10736	Economy	20400.00
0005434214197	10736	Economy	20400.00
0005434214201	10736	Economy	20400.00
0005434755809	10736	Economy	20400.00
0005434755746	10736	Economy	20400.00
0005434755765	10736	Economy	20400.00
0005434755776	10736	Economy	20400.00
0005434755731	10736	Economy	20400.00
0005434214209	10736	Economy	20400.00
0005434755708	10736	Economy	20400.00
0005434214174	10736	Economy	20400.00
0005434756103	28680	Business	61300.00
0005434213792	28680	Business	61300.00
0005434756116	28680	Business	61300.00
0005434213829	28680	Business	61300.00
0005434213707	28680	Business	61300.00
0005434213717	28680	Business	61300.00
0005434756099	28680	Business	61300.00
0005434756118	28680	Business	61300.00
0005434756117	28680	Business	61300.00
0005434213738	28680	Economy	20400.00
0005434213754	28680	Economy	20400.00
0005434213793	28680	Economy	20400.00
0005434213698	28680	Economy	20400.00
0005434756104	28680	Economy	20400.00
0005434756093	28680	Economy	20400.00
0005434756097	28680	Economy	22500.00
0005434756115	28680	Economy	22500.00
0005434756114	28680	Economy	22500.00
0005434213783	28680	Economy	20400.00
0005434756113	28680	Economy	20400.00
0005434756091	28680	Economy	20400.00
0005434756098	28680	Economy	20400.00
0005434213813	28680	Economy	20400.00
0005434213863	28680	Economy	20400.00
0005434213786	28680	Economy	20400.00
0005434756090	28680	Economy	20400.00
0005434756092	28680	Economy	20400.00
0005434756102	28680	Economy	20400.00
0005434756106	28680	Economy	20400.00
0005434756100	28680	Economy	20400.00
0005434756111	28680	Economy	20400.00
0005434756109	28680	Economy	20400.00
0005434213757	28680	Economy	20400.00
0005434756112	28680	Economy	20400.00
0005434213756	28680	Economy	20400.00
0005434213700	28680	Economy	20400.00
0005434213731	28680	Economy	20400.00
0005434756101	28680	Economy	20400.00
0005434756094	28680	Economy	20400.00
0005434756110	28680	Economy	20400.00
0005434213745	28680	Economy	20400.00
0005434756107	28680	Economy	20400.00
0005434213767	28680	Economy	20400.00
0005434213815	28680	Economy	20400.00
0005434213699	28680	Economy	20400.00
0005434213718	28680	Economy	20400.00
0005434213766	28680	Economy	20400.00
0005434213841	28680	Economy	20400.00
0005434756105	28680	Economy	20400.00
0005434756108	28680	Economy	20400.00
0005434213755	28680	Economy	20400.00
0005434756096	28680	Economy	20400.00
0005434213752	28680	Economy	20400.00
0005434756095	28680	Economy	20400.00
0005434213814	28680	Economy	20400.00
0005434213854	28680	Economy	20400.00
0005435039323	5479	Business	29500.00
0005435006846	5479	Business	29500.00
0005435039271	5479	Business	29500.00
0005435039276	5479	Business	29500.00
0005434229056	5479	Business	29500.00
0005435039327	5479	Business	29500.00
0005435039277	5479	Business	29500.00
0005435039307	5479	Business	29500.00
0005434229011	5479	Business	29500.00
0005432125395	5479	Business	29500.00
0005434229061	5479	Business	29500.00
0005432125401	5479	Economy	9800.00
0005432125399	5479	Economy	9800.00
0005435039300	5479	Economy	9800.00
0005435039312	5479	Economy	9800.00
0005435006857	5479	Economy	9800.00
0005435039281	5479	Economy	9800.00
0005435039283	5479	Economy	9800.00
0005435039296	5479	Economy	9800.00
0005435006845	5479	Economy	9800.00
0005435039326	5479	Economy	9800.00
0005435006863	5479	Economy	9800.00
0005435006859	5479	Economy	9800.00
0005432125403	5479	Economy	9800.00
0005435006847	5479	Economy	9800.00
0005435006850	5479	Economy	9800.00
0005435039275	5479	Economy	9800.00
0005435006844	5479	Economy	9800.00
0005435039297	5479	Economy	9800.00
0005435039328	5479	Economy	9800.00
0005435006866	5479	Economy	9800.00
0005434229101	5479	Economy	9800.00
0005432125400	5479	Economy	9800.00
0005435039270	5479	Economy	9800.00
0005435039294	5479	Economy	9800.00
0005432125396	5479	Economy	9800.00
0005435043277	5479	Economy	9800.00
0005434228995	5479	Economy	9800.00
0005435006858	5479	Economy	9800.00
0005435039304	5479	Economy	9800.00
0005435039282	5479	Economy	9800.00
0005435042838	5479	Economy	9800.00
0005435039317	5479	Economy	9800.00
0005432125397	5479	Economy	9800.00
0005435039289	5479	Economy	9800.00
0005435042837	5479	Economy	9800.00
0005435039284	5479	Economy	9800.00
0005435039274	5479	Economy	9800.00
0005435006856	5479	Economy	10800.00
0005435039268	5479	Economy	10800.00
0005435039315	5479	Economy	10800.00
0005435039286	5479	Economy	10800.00
0005434229060	5479	Economy	10800.00
0005435039280	5479	Economy	10800.00
0005435006843	5479	Economy	9800.00
0005435039278	5479	Economy	9800.00
0005435006855	5479	Economy	9800.00
0005435039311	5479	Economy	9800.00
0005434229010	5479	Economy	9800.00
0005434228991	5479	Economy	9800.00
0005432125402	5479	Economy	9800.00
0005434229045	5479	Economy	9800.00
0005435039290	5479	Economy	9800.00
0005435006861	5479	Economy	9800.00
0005434229065	5479	Economy	9800.00
0005435039306	5479	Economy	9800.00
0005435039299	5479	Economy	9800.00
0005435006864	5479	Economy	9800.00
0005435039305	5479	Economy	9800.00
0005435006853	5479	Economy	9800.00
0005435039291	5479	Economy	9800.00
0005435039302	5479	Economy	9800.00
0005435039265	5479	Economy	9800.00
0005435039293	5479	Economy	9800.00
0005434229109	5479	Economy	9800.00
0005435006849	5479	Economy	9800.00
0005435006862	5479	Economy	9800.00
0005435039295	5479	Economy	9800.00
0005435006860	5479	Economy	9800.00
0005435006867	5479	Economy	9800.00
0005435039264	5479	Economy	9800.00
0005435039329	5479	Economy	9800.00
0005435039298	5479	Economy	9800.00
0005435039308	5479	Economy	9800.00
0005435039285	5479	Economy	9800.00
0005435006852	5479	Economy	9800.00
0005435039320	5479	Economy	9800.00
0005432125394	5479	Economy	9800.00
0005434229100	5479	Economy	9800.00
0005435006842	5479	Economy	9800.00
0005435039279	5479	Economy	9800.00
0005435039287	5479	Economy	9800.00
0005435039321	5479	Economy	9800.00
0005435006854	5479	Economy	9800.00
0005434229138	5479	Economy	9800.00
0005435039303	5479	Economy	9800.00
0005435006851	5479	Economy	9800.00
0005434229102	5479	Economy	9800.00
0005435039301	5479	Economy	9800.00
0005435039319	5479	Economy	9800.00
0005435039322	5479	Economy	9800.00
0005435039325	5479	Economy	9800.00
0005435039292	5479	Economy	9800.00
0005434229044	5479	Economy	9800.00
0005435006865	5479	Economy	9800.00
0005432125398	5479	Economy	9800.00
0005435039310	5479	Economy	9800.00
0005435039316	5479	Economy	9800.00
0005435039272	5479	Economy	9800.00
0005435039267	5479	Economy	9800.00
0005435039273	5479	Economy	9800.00
0005435039314	5479	Economy	9800.00
0005435039313	5479	Economy	9800.00
0005434229071	5479	Economy	9800.00
0005435039266	5479	Economy	9800.00
0005434229043	5479	Economy	9800.00
0005434228979	5479	Economy	9800.00
0005435039324	5479	Economy	9800.00
0005435039288	5479	Economy	9800.00
0005435039309	5479	Economy	9800.00
0005435039318	5479	Economy	9800.00
0005435039269	5479	Economy	9800.00
0005435039263	5479	Economy	9800.00
0005435006848	5479	Economy	9800.00
0005435038908	12988	Business	29500.00
0005435038975	12988	Business	29500.00
0005435038801	12988	Business	29500.00
0005435006637	12988	Business	29500.00
0005435042824	12988	Business	29500.00
0005434229214	12988	Business	29500.00
0005434229199	12988	Business	29500.00
0005435038670	12988	Economy	9800.00
0005435038765	12988	Economy	9800.00
0005435038737	12988	Economy	9800.00
0005432304371	12988	Economy	9800.00
0005435377902	12988	Economy	9800.00
0005435038853	12988	Economy	9800.00
0005434229218	12988	Economy	9800.00
0005435038942	12988	Economy	9800.00
0005435377903	12988	Economy	9800.00
0005435038957	12988	Economy	9800.00
0005435038926	12988	Economy	9800.00
0005435038943	12988	Economy	9800.00
0005435006762	12988	Economy	9800.00
0005434229207	12988	Economy	9800.00
0005435038758	12988	Economy	9800.00
0005435042820	12988	Economy	9800.00
0005435038967	12988	Economy	9800.00
0005434229201	12988	Economy	9800.00
0005435038886	12988	Economy	9800.00
0005434229209	12988	Economy	9800.00
0005434229215	12988	Economy	9800.00
0005435042830	12988	Economy	9800.00
0005435038906	12988	Economy	9800.00
0005435038736	12988	Economy	9800.00
0005434229205	12988	Economy	9800.00
0005434229198	12988	Economy	9800.00
0005435039163	12988	Economy	9800.00
0005434229202	12988	Economy	9800.00
0005435038726	12988	Economy	10800.00
0005435006665	12988	Economy	9800.00
0005434229213	12988	Economy	10800.00
0005435006678	12988	Economy	10800.00
0005434229203	12988	Economy	10800.00
0005435038852	12988	Economy	9800.00
0005434229212	12988	Economy	9800.00
0005435006686	12988	Economy	9800.00
0005435006644	12988	Economy	9800.00
0005435006694	12988	Economy	9800.00
0005435038732	12988	Economy	9800.00
0005432304370	12988	Economy	9800.00
0005435039165	12988	Economy	9800.00
0005434229211	12988	Economy	9800.00
0005435006727	12988	Economy	9800.00
0005435038983	12988	Economy	9800.00
0005434229200	12988	Economy	9800.00
0005435006761	12988	Economy	9800.00
0005435377901	12988	Economy	9800.00
0005435038873	12988	Economy	9800.00
0005435042822	12988	Economy	9800.00
0005435038834	12988	Economy	9800.00
0005435006607	12988	Economy	9800.00
0005435038721	12988	Economy	9800.00
0005435039029	12988	Economy	9800.00
0005435042821	12988	Economy	9800.00
0005435038954	12988	Economy	9800.00
0005435039162	12988	Economy	9800.00
0005435038709	12988	Economy	9800.00
0005435038671	12988	Economy	9800.00
0005435038905	12988	Economy	9800.00
0005434229204	12988	Economy	9800.00
0005435038678	12988	Economy	9800.00
0005435006604	12988	Economy	9800.00
0005435006718	12988	Economy	9800.00
0005432304368	12988	Economy	9800.00
0005435039164	12988	Economy	9800.00
0005435038703	12988	Economy	9800.00
0005435038657	12988	Economy	9800.00
0005435038720	12988	Economy	9800.00
0005435006625	12988	Economy	9800.00
0005434229210	12988	Economy	9800.00
0005435006657	12988	Economy	9800.00
0005435038918	12988	Economy	9800.00
0005435006636	12988	Economy	9800.00
0005434229208	12988	Economy	9800.00
0005434229219	12988	Economy	9800.00
0005435038632	12988	Economy	9800.00
0005435038699	12988	Economy	9800.00
0005435038838	12988	Economy	9800.00
0005435006652	12988	Economy	9800.00
0005435038891	12988	Economy	9800.00
0005435042829	12988	Economy	9800.00
0005435038874	12988	Economy	9800.00
0005435038951	12988	Economy	9800.00
0005435038968	12988	Economy	9800.00
0005432304369	12988	Economy	9800.00
0005435006674	12988	Economy	9800.00
0005434229206	12988	Economy	9800.00
0005435006605	12988	Economy	9800.00
0005435038640	12988	Economy	9800.00
0005434229217	12988	Economy	9800.00
0005434229216	12988	Economy	9800.00
0005435006692	12988	Economy	9800.00
0005435038890	12988	Economy	9800.00
0005435038708	12988	Economy	9800.00
0005435038766	12988	Economy	9800.00
0005435042825	12988	Economy	9800.00
0005435902433	14864	Business	52900.00
0005435902432	14864	Business	52900.00
0005434411742	14864	Business	52900.00
0005435554103	14864	Business	52900.00
0005434426383	14864	Business	52900.00
0005435554115	14864	Business	52900.00
0005435902434	14864	Economy	17600.00
0005434426375	14864	Economy	17600.00
0005435902444	14864	Economy	17600.00
0005434411743	14864	Economy	17600.00
0005434426369	14864	Economy	17600.00
0005434426365	14864	Economy	19400.00
0005434426357	14864	Economy	17600.00
0005435902443	14864	Economy	17600.00
0005434426364	14864	Economy	17600.00
0005435902390	14864	Economy	17600.00
0005434426382	14864	Economy	17600.00
0005435902419	14864	Economy	17600.00
0005434426362	14864	Economy	17600.00
0005432188580	14864	Economy	17600.00
0005434426385	14864	Economy	17600.00
0005434426380	14864	Economy	17600.00
0005434426381	14864	Economy	17600.00
0005434426377	14864	Economy	17600.00
0005434426376	14864	Economy	17600.00
0005434426356	14864	Economy	17600.00
0005434426374	14864	Economy	17600.00
0005435902469	14864	Economy	17600.00
0005434426368	14864	Economy	17600.00
0005434426384	14864	Economy	17600.00
0005434426358	14864	Economy	17600.00
0005434426371	14864	Economy	17600.00
0005434426379	14864	Economy	17600.00
0005434426359	14864	Economy	17600.00
0005434426367	14864	Economy	17600.00
0005434426360	14864	Economy	17600.00
0005434426372	14864	Economy	17600.00
0005435902442	14864	Economy	17600.00
0005434426378	14864	Economy	17600.00
0005434411744	14864	Economy	17600.00
0005435554104	14864	Economy	17600.00
0005434411741	14864	Economy	17600.00
0005434426361	14864	Economy	17600.00
0005432188582	14864	Economy	17600.00
0005435902420	14864	Economy	17600.00
0005434426370	14864	Economy	17600.00
0005434426366	14864	Economy	17600.00
0005434426373	14864	Economy	17600.00
0005432188581	14864	Economy	17600.00
0005434426363	14864	Economy	17600.00
0005435902569	20222	Business	52900.00
0005434426129	20222	Business	52900.00
0005435902570	20222	Business	52900.00
0005434426192	20222	Business	52900.00
0005435902582	20222	Business	52900.00
0005434426194	20222	Business	52900.00
0005435554154	20222	Economy	17600.00
0005434426123	20222	Economy	17600.00
0005434426154	20222	Economy	17600.00
0005435902581	20222	Economy	17600.00
0005434426122	20222	Economy	17600.00
0005434411712	20222	Economy	19400.00
0005434411711	20222	Economy	19400.00
0005434426112	20222	Economy	19400.00
0005435902580	20222	Economy	17600.00
0005435902574	20222	Economy	17600.00
0005432059490	20222	Economy	17600.00
0005435902577	20222	Economy	17600.00
0005434426153	20222	Economy	17600.00
0005435902575	20222	Economy	17600.00
0005435554156	20222	Economy	17600.00
0005434426168	20222	Economy	17600.00
0005435902579	20222	Economy	17600.00
0005434426167	20222	Economy	17600.00
0005435554157	20222	Economy	17600.00
0005434426195	20222	Economy	17600.00
0005435902571	20222	Economy	17600.00
0005435554153	20222	Economy	17600.00
0005435902583	20222	Economy	17600.00
0005434411710	20222	Economy	17600.00
0005434426152	20222	Economy	17600.00
0005435902578	20222	Economy	17600.00
0005435902566	20222	Economy	17600.00
0005434426151	20222	Economy	17600.00
0005435902567	20222	Economy	17600.00
0005434426166	20222	Economy	17600.00
0005435554155	20222	Economy	17600.00
0005434426128	20222	Economy	17600.00
0005435902572	20222	Economy	17600.00
0005434426133	20222	Economy	17600.00
0005435902568	20222	Economy	17600.00
0005434426150	20222	Economy	17600.00
0005435902576	20222	Economy	17600.00
0005432059489	20222	Economy	17600.00
0005434426132	20222	Economy	17600.00
0005435902573	20222	Economy	17600.00
0005434426101	20222	Economy	17600.00
0005434426191	20222	Economy	17600.00
0005434426125	20222	Economy	17600.00
0005434426157	20222	Economy	17600.00
0005434426095	20222	Economy	17600.00
0005434523750	30880	Economy	35600.00
0005434523752	30880	Economy	35600.00
0005434523756	30880	Economy	35600.00
0005434523757	30880	Economy	35600.00
0005434523751	30880	Economy	35600.00
0005434523747	30880	Economy	35600.00
0005434523755	30880	Economy	35600.00
0005434523749	30880	Economy	35600.00
0005434523753	30880	Economy	35600.00
0005434523754	30880	Economy	35600.00
0005434523748	30880	Economy	35600.00
0005432300220	26549	Business	18500.00
0005433434261	26549	Business	18500.00
0005433434223	26549	Business	18500.00
0005435981949	26549	Business	18500.00
0005433434219	26549	Business	18500.00
0005435981960	26549	Business	18500.00
0005435981926	26549	Business	18500.00
0005432300215	26549	Business	18500.00
0005432300217	26549	Business	18500.00
0005435981925	26549	Business	18500.00
0005432300214	26549	Economy	6200.00
0005433434256	26549	Economy	6200.00
0005435981940	26549	Economy	6200.00
0005433434255	26549	Economy	6200.00
0005435981943	26549	Economy	6200.00
0005433434235	26549	Economy	6200.00
0005435981927	26549	Economy	6200.00
0005435981945	26549	Economy	6200.00
0005435981956	26549	Economy	6800.00
0005435981928	26549	Economy	6800.00
0005433434218	26549	Economy	6800.00
0005435981935	26549	Economy	6200.00
0005435981955	26549	Economy	6200.00
0005435981942	26549	Economy	6200.00
0005435981939	26549	Economy	6200.00
0005435981951	26549	Economy	6200.00
0005432300216	26549	Economy	6200.00
0005433434260	26549	Economy	6200.00
0005433434258	26549	Economy	6200.00
0005435981938	26549	Economy	6200.00
0005433434270	26549	Economy	6200.00
0005433434284	26549	Economy	6200.00
0005433434222	26549	Economy	6200.00
0005435981936	26549	Economy	6200.00
0005432300219	26549	Economy	6200.00
0005435981946	26549	Economy	6200.00
0005433434269	26549	Economy	6200.00
0005432300218	26549	Economy	6200.00
0005435981933	26549	Economy	6200.00
0005435981937	26549	Economy	6200.00
0005435981941	26549	Economy	6200.00
0005435981931	26549	Economy	6200.00
0005435981929	26549	Economy	6200.00
0005433434257	26549	Economy	6200.00
0005435981947	26549	Economy	6200.00
0005435981930	26549	Economy	6200.00
0005435981944	26549	Economy	6200.00
0005435981957	26549	Economy	6200.00
0005433434259	26549	Economy	6200.00
0005435981950	26549	Economy	6200.00
0005435981954	26549	Economy	6200.00
0005435981934	26549	Economy	6200.00
0005433434236	26549	Economy	6200.00
0005435981952	26549	Economy	6200.00
0005435981924	26549	Economy	6200.00
0005435981932	26549	Economy	6200.00
0005435981953	26549	Economy	6200.00
0005435981961	26549	Economy	6200.00
0005435981958	26549	Economy	6200.00
0005433434347	26549	Economy	6200.00
0005433434234	26549	Economy	6200.00
0005435981959	26549	Economy	6200.00
0005435981948	26549	Economy	6200.00
0005433434477	26719	Business	18500.00
0005434269089	26719	Business	18500.00
0005435981578	26719	Business	18500.00
0005435981698	26719	Business	18500.00
0005433434481	26719	Business	18500.00
0005435981735	26719	Business	18500.00
0005433434479	26719	Business	18500.00
0005435981657	26719	Business	18500.00
0005433434474	26719	Business	18500.00
0005435981709	26719	Business	18500.00
0005433434496	26719	Economy	6200.00
0005434271296	26719	Economy	6200.00
0005435981714	26719	Economy	6200.00
0005435981581	26719	Economy	6200.00
0005435981539	26719	Economy	6200.00
0005435981512	26719	Economy	6200.00
0005433434492	26719	Economy	6200.00
0005434271297	26719	Economy	6800.00
0005433434485	26719	Economy	6800.00
0005432051107	26719	Economy	6800.00
0005433434484	26719	Economy	6800.00
0005435981531	26719	Economy	6200.00
0005435981603	26719	Economy	6200.00
0005433434494	26719	Economy	6200.00
0005435981755	26719	Economy	6200.00
0005435981662	26719	Economy	6200.00
0005433434478	26719	Economy	6200.00
0005433434487	26719	Economy	6200.00
0005435981521	26719	Economy	6200.00
0005433434469	26719	Economy	6200.00
0005435981689	26719	Economy	6200.00
0005435981548	26719	Economy	6200.00
0005435981658	26719	Economy	6200.00
0005433434471	26719	Economy	6200.00
0005433434475	26719	Economy	6200.00
0005434271298	26719	Economy	6200.00
0005435981530	26719	Economy	6200.00
0005433434491	26719	Economy	6200.00
0005434270192	26719	Economy	6200.00
0005433434480	26719	Economy	6200.00
0005435981684	26719	Economy	6200.00
0005435981617	26719	Economy	6200.00
0005432051106	26719	Economy	6200.00
0005433434486	26719	Economy	6200.00
0005435981715	26719	Economy	6200.00
0005433434495	26719	Economy	6200.00
0005435981555	26719	Economy	6200.00
0005433434472	26719	Economy	6200.00
0005435981632	26719	Economy	6200.00
0005434270191	26719	Economy	6200.00
0005433434482	26719	Economy	6200.00
0005435981639	26719	Economy	6200.00
0005435981621	26719	Economy	6200.00
0005435981640	26719	Economy	6200.00
0005433434488	26719	Economy	6200.00
0005435981703	26719	Economy	6200.00
0005435981571	26719	Economy	6200.00
0005433434483	26719	Economy	6200.00
0005432051105	26719	Economy	6200.00
0005434269088	26719	Economy	6200.00
0005433434476	26719	Economy	6200.00
0005435981596	26719	Economy	6200.00
0005435981549	26719	Economy	6200.00
0005435981540	26719	Economy	6200.00
0005433434470	26719	Economy	6200.00
0005433434473	26719	Economy	6200.00
0005433434493	26719	Economy	6200.00
0005435981618	26719	Economy	6200.00
0005435981681	26719	Economy	6200.00
0005435981675	26719	Economy	6200.00
0005433434490	26719	Economy	6200.00
0005435981516	26719	Economy	6200.00
0005435981590	26719	Economy	6200.00
0005433434489	26719	Economy	6200.00
0005435981622	26719	Economy	6200.00
0005435981656	26719	Economy	6200.00
0005432857870	3182	Economy	11100.00
0005432583848	3182	Economy	11100.00
0005432583841	3182	Economy	10100.00
0005432857893	3182	Economy	10100.00
0005432583850	3182	Economy	10100.00
0005432583861	3182	Economy	10100.00
0005432857888	3182	Economy	10100.00
0005432583854	3182	Economy	10100.00
0005432857889	3182	Economy	10100.00
0005432583860	3182	Economy	10100.00
0005432583856	3182	Economy	10100.00
0005432583842	3182	Economy	10100.00
0005432583853	3182	Economy	10100.00
0005432583845	3182	Economy	10100.00
0005432583858	3182	Economy	10100.00
0005432583852	3182	Economy	10100.00
0005432857882	3182	Economy	10100.00
0005432583851	3182	Economy	10100.00
0005432583840	3182	Economy	10100.00
0005432583843	3182	Economy	10100.00
0005432216252	3182	Economy	10100.00
0005432583862	3182	Economy	10100.00
0005432583859	3182	Economy	10100.00
0005432583849	3182	Economy	10100.00
0005432857871	3182	Economy	10100.00
0005432583844	3182	Economy	10100.00
0005432857929	3182	Economy	10100.00
0005432583865	3182	Economy	10100.00
0005432583863	3182	Economy	10100.00
0005432583864	3182	Economy	10100.00
0005432583847	3182	Economy	10100.00
0005432857862	3182	Economy	10100.00
0005432583857	3182	Economy	10100.00
0005432583855	3182	Economy	10100.00
0005432583846	3182	Economy	10100.00
0005432857977	31496	Economy	11100.00
0005432857982	31496	Economy	11100.00
0005432583588	31496	Economy	10100.00
0005432857974	31496	Economy	10100.00
0005432583660	31496	Economy	10100.00
0005432857976	31496	Economy	10100.00
0005432857980	31496	Economy	10100.00
0005432857984	31496	Economy	10100.00
0005432583700	31496	Economy	10100.00
0005432583619	31496	Economy	10100.00
0005432583612	31496	Economy	10100.00
0005432583767	31496	Economy	10100.00
0005432583641	31496	Economy	10100.00
0005432857978	31496	Economy	10100.00
0005432583711	31496	Economy	10100.00
0005432583659	31496	Economy	10100.00
0005432583586	31496	Economy	10100.00
0005432583701	31496	Economy	10100.00
0005432583685	31496	Economy	10100.00
0005432857981	31496	Economy	10100.00
0005432583667	31496	Economy	10100.00
0005432857985	31496	Economy	10100.00
0005432583622	31496	Economy	10100.00
0005432583699	31496	Economy	10100.00
0005432583651	31496	Economy	10100.00
0005432857983	31496	Economy	10100.00
0005432583674	31496	Economy	10100.00
0005432857975	31496	Economy	10100.00
0005432583676	31496	Economy	10100.00
0005432583675	31496	Economy	10100.00
0005432583665	31496	Economy	10100.00
0005432857979	31496	Economy	10100.00
0005432583642	31496	Economy	10100.00
0005432583658	31496	Economy	10100.00
0005432583684	31496	Economy	10100.00
0005432583677	31496	Economy	10100.00
0005432583635	31496	Economy	10100.00
0005434943286	871	Economy	8300.00
0005434943279	871	Economy	8300.00
0005434943285	871	Economy	7500.00
0005433255027	871	Economy	7500.00
0005434943288	871	Economy	7500.00
0005434943287	871	Economy	7500.00
0005433255037	871	Economy	7500.00
0005434943280	871	Economy	7500.00
0005434943282	871	Economy	7500.00
0005434943284	871	Economy	7500.00
0005434943281	871	Economy	7500.00
0005434943283	871	Economy	7500.00
0005433255026	871	Economy	7500.00
0005433255043	871	Economy	7500.00
0005433255077	16224	Economy	8300.00
0005433255081	16224	Economy	7500.00
0005434943193	16224	Economy	7500.00
0005433255082	16224	Economy	7500.00
0005433255080	16224	Economy	7500.00
0005434943220	16224	Economy	7500.00
0005434943213	16224	Economy	7500.00
0005433255079	16224	Economy	7500.00
0005434943185	16224	Economy	7500.00
0005434943194	16224	Economy	7500.00
0005433255078	16224	Economy	7500.00
0005433255083	16224	Economy	7500.00
0005435858519	27612	Business	90500.00
0005435858522	27612	Business	90500.00
0005435858525	27612	Business	90500.00
0005433654652	27612	Business	90500.00
0005433654663	27612	Business	90500.00
0005433654682	27612	Economy	30200.00
0005435858515	27612	Economy	30200.00
0005435858518	27612	Economy	30200.00
0005435858520	27612	Economy	30200.00
0005435858527	27612	Economy	30200.00
0005433654662	27612	Economy	30200.00
0005433654680	27612	Economy	30200.00
0005433654658	27612	Economy	30200.00
0005435858531	27612	Economy	30200.00
0005435858523	27612	Economy	30200.00
0005435858530	27612	Economy	30200.00
0005435858516	27612	Economy	30200.00
0005433654648	27612	Economy	30200.00
0005435858524	27612	Economy	30200.00
0005433654653	27612	Economy	30200.00
0005433654647	27612	Economy	30200.00
0005433654679	27612	Economy	30200.00
0005435858521	27612	Economy	30200.00
0005433654678	27612	Economy	30200.00
0005435858526	27612	Economy	30200.00
0005435858529	27612	Economy	30200.00
0005433654677	27612	Economy	30200.00
0005435858517	27612	Economy	30200.00
0005435858514	27612	Economy	30200.00
0005435858528	27612	Economy	30200.00
0005435652724	21743	Business	9800.00
0005435652671	21743	Business	9800.00
0005435652728	21743	Business	9800.00
0005435652709	21743	Business	9800.00
0005435652703	21743	Business	9800.00
0005435652712	21743	Business	9800.00
0005435652679	21743	Business	9800.00
0005435652698	21743	Business	9800.00
0005435652681	21743	Business	9800.00
0005435652691	21743	Business	9800.00
0005435652694	21743	Economy	3300.00
0005433367371	21743	Economy	3300.00
0005433367471	21743	Economy	3300.00
0005435652680	21743	Economy	3300.00
0005435652687	21743	Economy	3300.00
0005433367354	21743	Economy	3300.00
0005435652674	21743	Economy	3300.00
0005433367298	21743	Economy	3300.00
0005435652693	21743	Economy	3600.00
0005433367227	21743	Economy	3600.00
0005433367377	21743	Economy	3600.00
0005435652729	21743	Economy	3600.00
0005435652705	21743	Economy	3600.00
0005435652682	21743	Economy	3300.00
0005435652675	21743	Economy	3300.00
0005433367385	21743	Economy	3300.00
0005435652707	21743	Economy	3300.00
0005435652723	21743	Economy	3300.00
0005435652726	21743	Economy	3300.00
0005433367243	21743	Economy	3300.00
0005435652711	21743	Economy	3300.00
0005435652688	21743	Economy	3300.00
0005435652677	21743	Economy	3300.00
0005435652725	21743	Economy	3300.00
0005435652719	21743	Economy	3300.00
0005433367355	21743	Economy	3300.00
0005435652714	21743	Economy	3300.00
0005433367472	21743	Economy	3300.00
0005435652720	21743	Economy	3300.00
0005433367299	21743	Economy	3300.00
0005435652715	21743	Economy	3300.00
0005433367323	21743	Economy	3300.00
0005435652721	21743	Economy	3300.00
0005435652700	21743	Economy	3300.00
0005435652722	21743	Economy	3300.00
0005435652676	21743	Economy	3300.00
0005435652683	21743	Economy	3300.00
0005435652690	21743	Economy	3300.00
0005435652670	21743	Economy	3300.00
0005433367264	21743	Economy	3300.00
0005435652713	21743	Economy	3300.00
0005435652717	21743	Economy	3300.00
0005435652678	21743	Economy	3300.00
0005433367317	21743	Economy	3300.00
0005435652685	21743	Economy	3300.00
0005433367260	21743	Economy	3300.00
0005435652730	21743	Economy	3300.00
0005433367297	21743	Economy	3300.00
0005433367266	21743	Economy	3300.00
0005433367406	21743	Economy	3300.00
0005433367357	21743	Economy	3300.00
0005433367261	21743	Economy	3300.00
0005433367337	21743	Economy	3300.00
0005435652684	21743	Economy	3300.00
0005433367285	21743	Economy	3300.00
0005435652699	21743	Economy	3300.00
0005435652696	21743	Economy	3300.00
0005435652701	21743	Economy	3300.00
0005433367370	21743	Economy	3300.00
0005435652697	21743	Economy	3300.00
0005435652692	21743	Economy	3300.00
0005435652695	21743	Economy	3300.00
0005435652727	21743	Economy	3300.00
0005433367286	21743	Economy	3300.00
0005435652718	21743	Economy	3300.00
0005433367378	21743	Economy	3300.00
0005435652702	21743	Economy	3300.00
0005435652710	21743	Economy	3300.00
0005435652686	21743	Economy	3300.00
0005435652673	21743	Economy	3300.00
0005435652689	21743	Economy	3300.00
0005435652716	21743	Economy	3300.00
0005435652672	21743	Economy	3300.00
0005435652708	21743	Economy	3300.00
0005435652704	21743	Economy	3300.00
0005435652706	21743	Economy	3300.00
0005433763096	9352	Business	186200.00
0005433805122	9352	Business	186200.00
0005433805120	9352	Business	186200.00
0005433784682	9352	Business	186200.00
0005433805119	9352	Business	186200.00
0005433784679	9352	Business	186200.00
0005432665260	9352	Business	186200.00
0005433784695	9352	Business	186200.00
0005433784692	9352	Business	186200.00
0005432667439	9352	Economy	68300.00
0005434170825	9352	Economy	68300.00
0005433763099	9352	Economy	68300.00
0005432665259	9352	Economy	62100.00
0005434170873	9352	Economy	62100.00
0005433763094	9352	Economy	62100.00
0005433784674	9352	Economy	62100.00
0005433784670	9352	Economy	62100.00
0005434170835	9352	Economy	62100.00
0005433784669	9352	Economy	62100.00
0005434151668	9352	Economy	62100.00
0005433784694	9352	Economy	62100.00
0005433784672	9352	Economy	62100.00
0005433784678	9352	Economy	62100.00
0005434170813	9352	Economy	62100.00
0005433784668	9352	Economy	62100.00
0005433784681	9352	Economy	62100.00
0005433784691	9352	Economy	62100.00
0005434170822	9352	Economy	62100.00
0005433784693	9352	Economy	62100.00
0005433784688	9352	Economy	62100.00
0005434170850	9352	Economy	62100.00
0005433784690	9352	Economy	62100.00
0005433763101	9352	Economy	62100.00
0005432665258	9352	Economy	62100.00
0005433784698	9352	Economy	62100.00
0005434270178	9352	Economy	62100.00
0005432657427	9352	Economy	62100.00
0005432666373	9352	Economy	62100.00
0005433805121	9352	Economy	62100.00
0005434170828	9352	Economy	62100.00
0005433784677	9352	Economy	62100.00
0005433763100	9352	Economy	62100.00
0005433784680	9352	Economy	62100.00
0005433763105	9352	Economy	62100.00
0005433784667	9352	Economy	62100.00
0005433784663	9352	Economy	62100.00
0005433763102	9352	Economy	62100.00
0005434170843	9352	Economy	62100.00
0005433763098	9352	Economy	62100.00
0005434273055	9352	Economy	62100.00
0005433784666	9352	Economy	62100.00
0005433805124	9352	Economy	62100.00
0005434270179	9352	Economy	62100.00
0005434170844	9352	Economy	62100.00
0005433784664	9352	Economy	62100.00
0005434170854	9352	Economy	68300.00
0005434270171	9352	Economy	62100.00
0005433763092	9352	Economy	68300.00
0005434170863	9352	Economy	62100.00
0005433784665	9352	Economy	68300.00
0005432657426	9352	Economy	62100.00
0005433784684	9352	Economy	62100.00
0005433784696	9352	Economy	62100.00
0005433784687	9352	Economy	62100.00
0005433784683	9352	Economy	62100.00
0005432657428	9352	Economy	62100.00
0005433763106	9352	Economy	62100.00
0005433763107	9352	Economy	62100.00
0005433784673	9352	Economy	62100.00
0005433763093	9352	Economy	62100.00
0005433805125	9352	Economy	62100.00
0005433784697	9352	Economy	62100.00
0005433763104	9352	Economy	62100.00
0005433763097	9352	Economy	62100.00
0005434170849	9352	Economy	62100.00
0005433763095	9352	Economy	62100.00
0005434273056	9352	Economy	62100.00
0005434170806	9352	Economy	62100.00
0005434151669	9352	Economy	62100.00
0005433784675	9352	Economy	62100.00
0005433784689	9352	Economy	62100.00
0005433784671	9352	Economy	62100.00
0005433784686	9352	Economy	62100.00
0005433784685	9352	Economy	62100.00
0005434170848	9352	Economy	62100.00
0005433784676	9352	Economy	62100.00
0005433763103	9352	Economy	62100.00
0005434170836	9352	Economy	62100.00
0005432666374	9352	Economy	62100.00
0005433784699	9352	Economy	62100.00
0005434151662	9352	Economy	62100.00
0005434170840	9352	Economy	62100.00
0005433805123	9352	Economy	62100.00
0005433784318	26233	Business	186200.00
0005433804950	26233	Business	186200.00
0005433784463	26233	Business	186200.00
0005433804817	26233	Business	186200.00
0005433804839	26233	Business	186200.00
0005433804822	26233	Business	186200.00
0005434270189	26233	Business	186200.00
0005435269695	26233	Business	186200.00
0005434170949	26233	Business	186200.00
0005433762966	26233	Business	186200.00
0005433784383	26233	Business	186200.00
0005434151682	26233	Business	186200.00
0005433804853	26233	Business	186200.00
0005433763015	26233	Business	186200.00
0005433784420	26233	Economy	68300.00
0005434269087	26233	Economy	62100.00
0005433763018	26233	Economy	62100.00
0005434170958	26233	Economy	62100.00
0005433784329	26233	Economy	62100.00
0005433784317	26233	Economy	62100.00
0005433784423	26233	Economy	62100.00
0005433784494	26233	Economy	62100.00
0005433804816	26233	Economy	62100.00
0005432666353	26233	Economy	62100.00
0005434170947	26233	Economy	62100.00
0005432659672	26233	Economy	62100.00
0005432657401	26233	Economy	62100.00
0005434170946	26233	Economy	62100.00
0005433804856	26233	Economy	62100.00
0005433784350	26233	Economy	62100.00
0005433784377	26233	Economy	62100.00
0005433784431	26233	Economy	62100.00
0005433804789	26233	Economy	62100.00
0005433784417	26233	Economy	62100.00
0005433762995	26233	Economy	62100.00
0005433763011	26233	Economy	62100.00
0005433784418	26233	Economy	62100.00
0005434170954	26233	Economy	62100.00
0005433804838	26233	Economy	62100.00
0005433784444	26233	Economy	62100.00
0005434151683	26233	Economy	62100.00
0005433784327	26233	Economy	62100.00
0005433762958	26233	Economy	62100.00
0005434170955	26233	Economy	62100.00
0005434151681	26233	Economy	62100.00
0005434170951	26233	Economy	62100.00
0005433784439	26233	Economy	62100.00
0005433804844	26233	Economy	62100.00
0005433784375	26233	Economy	62100.00
0005433784443	26233	Economy	62100.00
0005435269693	26233	Economy	62100.00
0005434170956	26233	Economy	62100.00
0005433784498	26233	Economy	62100.00
0005433784300	26233	Economy	62100.00
0005433804814	26233	Economy	62100.00
0005433784487	26233	Economy	62100.00
0005434170945	26233	Economy	62100.00
0005433804826	26233	Economy	68300.00
0005434170948	26233	Economy	62100.00
0005433762996	26233	Economy	62100.00
0005433804833	26233	Economy	62100.00
0005433784510	26233	Economy	68300.00
0005433804951	26233	Economy	62100.00
0005433784308	26233	Economy	62100.00
0005433784427	26233	Economy	62100.00
0005433762985	26233	Economy	62100.00
0005433804848	26233	Economy	62100.00
0005433784493	26233	Economy	62100.00
0005433784307	26233	Economy	62100.00
0005433784559	26233	Economy	62100.00
0005433784462	26233	Economy	62100.00
0005433804952	26233	Economy	62100.00
0005434170950	26233	Economy	62100.00
0005433804825	26233	Economy	62100.00
0005435269694	26233	Economy	62100.00
0005432666356	26233	Economy	62100.00
0005434170943	26233	Economy	62100.00
0005434170953	26233	Economy	62100.00
0005433804925	26233	Economy	62100.00
0005434270190	26233	Economy	62100.00
0005433784393	26233	Economy	62100.00
0005433762994	26233	Economy	62100.00
0005434269085	26233	Economy	62100.00
0005434170952	26233	Economy	62100.00
0005434269086	26233	Economy	62100.00
0005433804804	26233	Economy	62100.00
0005434170944	26233	Economy	62100.00
0005433762959	26233	Economy	62100.00
0005434271295	26233	Economy	62100.00
0005433763019	26233	Economy	62100.00
0005432666357	26233	Economy	62100.00
0005433804846	26233	Economy	62100.00
0005433762965	26233	Economy	62100.00
0005433784362	26233	Economy	62100.00
0005432666352	26233	Economy	62100.00
0005433784376	26233	Economy	62100.00
0005434170957	26233	Economy	62100.00
0005435929596	4923	Economy	5900.00
0005435135633	4923	Economy	5300.00
0005435135635	4923	Economy	5300.00
0005435135634	4923	Economy	5300.00
0005435135631	4923	Economy	5300.00
0005435929610	4923	Economy	5300.00
0005435135632	4923	Economy	5300.00
0005435929605	4923	Economy	5300.00
0005435929624	33057	Economy	5900.00
0005435135607	33057	Economy	5300.00
0005435929623	33057	Economy	5300.00
0005435135593	33057	Economy	5300.00
0005435929625	33057	Economy	5300.00
0005434983251	9482	Economy	19700.00
0005434217894	9482	Economy	17900.00
0005434983247	9482	Economy	17900.00
0005434983249	9482	Economy	17900.00
0005434217914	9482	Economy	17900.00
0005434983250	9482	Economy	17900.00
0005434217915	9482	Economy	17900.00
0005434217913	9482	Economy	17900.00
0005434983252	9482	Economy	17900.00
0005434983248	9482	Economy	17900.00
0005434983211	27335	Economy	19700.00
0005434217939	27335	Economy	17900.00
0005434217937	27335	Economy	17900.00
0005434983212	27335	Economy	17900.00
0005434217936	27335	Economy	17900.00
0005434217938	27335	Economy	17900.00
0005433985143	24290	Business	36400.00
0005433959960	24290	Business	36400.00
0005433985271	24290	Business	36400.00
0005433985406	24290	Business	36400.00
0005433985140	24290	Business	36400.00
0005433985170	24290	Business	36400.00
0005433959934	24290	Economy	13400.00
0005433959895	24290	Economy	13400.00
0005433959924	24290	Economy	13400.00
0005433985164	24290	Economy	12100.00
0005433985303	24290	Economy	12100.00
0005433985274	24290	Economy	12100.00
0005433959943	24290	Economy	12100.00
0005433985147	24290	Economy	12100.00
0005433959959	24290	Economy	12100.00
0005433985221	24290	Economy	12100.00
0005433985273	24290	Economy	12100.00
0005433959872	24290	Economy	12100.00
0005433985216	24290	Economy	12100.00
0005433985199	24290	Economy	12100.00
0005433985304	24290	Economy	12100.00
0005433959913	24290	Economy	12100.00
0005433959933	24290	Economy	12100.00
0005433959944	24290	Economy	12100.00
0005433959904	24290	Economy	12100.00
0005433985272	24290	Economy	12100.00
0005433985220	24290	Economy	12100.00
0005433959963	24290	Economy	12100.00
0005433959869	24290	Economy	12100.00
0005433985135	24290	Economy	12100.00
0005433985163	24290	Economy	12100.00
0005433985243	24290	Economy	12100.00
0005433985144	24290	Economy	12100.00
0005433985200	24290	Economy	12100.00
0005433985293	24290	Economy	12100.00
0005433959952	24290	Economy	12100.00
0005433985285	24290	Economy	12100.00
0005433959893	24290	Economy	12100.00
0005433985138	24290	Economy	12100.00
0005433959894	24290	Economy	12100.00
0005433985162	24290	Economy	12100.00
0005433985160	24290	Economy	12100.00
0005433985142	24290	Economy	12100.00
0005433959907	24290	Economy	12100.00
0005433985202	24290	Economy	12100.00
0005433985373	24290	Economy	12100.00
0005433985127	24290	Economy	12100.00
0005433985344	24290	Economy	13400.00
0005433985374	24290	Economy	12100.00
0005433985139	24290	Economy	12100.00
0005433985292	24290	Economy	12100.00
0005433959897	24290	Economy	12100.00
0005433959947	24290	Economy	12100.00
0005433985233	24290	Economy	12100.00
0005433959914	24290	Economy	12100.00
0005433959871	24290	Economy	12100.00
0005433985141	24290	Economy	12100.00
0005433985197	24290	Economy	12100.00
0005433985278	24290	Economy	12100.00
0005433959950	24290	Economy	12100.00
0005433985198	24290	Economy	12100.00
0005433985165	24290	Economy	12100.00
0005433959873	24290	Economy	12100.00
0005433985215	24290	Economy	12100.00
0005433985148	24290	Economy	12100.00
0005433985201	24290	Economy	12100.00
0005433959900	24290	Economy	12100.00
0005433985157	24290	Economy	12100.00
0005433959874	24290	Economy	12100.00
0005433960405	25930	Business	36400.00
0005433985559	25930	Business	36400.00
0005433960409	25930	Business	36400.00
0005433985564	25930	Business	36400.00
0005433985582	25930	Business	36400.00
0005433960413	25930	Business	36400.00
0005433960412	25930	Business	36400.00
0005433960429	25930	Business	36400.00
0005433985586	25930	Business	36400.00
0005433985584	25930	Economy	12100.00
0005433960416	25930	Economy	12100.00
0005433960439	25930	Economy	12100.00
0005433985565	25930	Economy	12100.00
0005433960390	25930	Economy	12100.00
0005433985563	25930	Economy	12100.00
0005433960437	25930	Economy	12100.00
0005433985571	25930	Economy	12100.00
0005433985598	25930	Economy	12100.00
0005433960438	25930	Economy	12100.00
0005433960421	25930	Economy	12100.00
0005433960434	25930	Economy	12100.00
0005433985602	25930	Economy	12100.00
0005433960398	25930	Economy	12100.00
0005433985579	25930	Economy	12100.00
0005433985580	25930	Economy	12100.00
0005433960393	25930	Economy	12100.00
0005433985566	25930	Economy	12100.00
0005433960406	25930	Economy	12100.00
0005433985578	25930	Economy	12100.00
0005433985587	25930	Economy	12100.00
0005433960415	25930	Economy	12100.00
0005433985591	25930	Economy	12100.00
0005433985576	25930	Economy	12100.00
0005433960427	25930	Economy	12100.00
0005433960394	25930	Economy	12100.00
0005433960418	25930	Economy	12100.00
0005433985573	25930	Economy	12100.00
0005433985604	25930	Economy	12100.00
0005433960442	25930	Economy	12100.00
0005433985597	25930	Economy	12100.00
0005433960432	25930	Economy	12100.00
0005433960392	25930	Economy	12100.00
0005433985568	25930	Economy	12100.00
0005433985594	25930	Economy	12100.00
0005433985588	25930	Economy	12100.00
0005433985600	25930	Economy	12100.00
0005433960435	25930	Economy	12100.00
0005433960396	25930	Economy	12100.00
0005433960440	25930	Economy	12100.00
0005433960417	25930	Economy	12100.00
0005433985592	25930	Economy	12100.00
0005433985575	25930	Economy	12100.00
0005433960441	25930	Economy	12100.00
0005433985581	25930	Economy	12100.00
0005433985569	25930	Economy	13400.00
0005433960424	25930	Economy	12100.00
0005433960431	25930	Economy	12100.00
0005433960420	25930	Economy	12100.00
0005433985560	25930	Economy	12100.00
0005433960404	25930	Economy	12100.00
0005433985561	25930	Economy	12100.00
0005433960433	25930	Economy	12100.00
0005433985574	25930	Economy	12100.00
0005433985577	25930	Economy	12100.00
0005433960395	25930	Economy	12100.00
0005433960414	25930	Economy	12100.00
0005433960426	25930	Economy	12100.00
0005433985601	25930	Economy	12100.00
0005433985596	25930	Economy	12100.00
0005433960410	25930	Economy	12100.00
0005433960399	25930	Economy	12100.00
0005433960397	25930	Economy	12100.00
0005433985595	25930	Economy	12100.00
0005433960400	25930	Economy	12100.00
0005433960411	25930	Economy	12100.00
0005433960408	25930	Economy	12100.00
0005433985585	25930	Economy	12100.00
0005433985603	25930	Economy	12100.00
0005433960425	25930	Economy	12100.00
0005433960402	25930	Economy	12100.00
0005433960419	25930	Economy	12100.00
0005433985567	25930	Economy	12100.00
0005433985572	25930	Economy	12100.00
0005433960403	25930	Economy	12100.00
0005433985599	25930	Economy	12100.00
0005433985593	25930	Economy	12100.00
0005433985589	25930	Economy	12100.00
0005433960430	25930	Economy	12100.00
0005433960391	25930	Economy	12100.00
0005433985605	25930	Economy	12100.00
0005433960423	25930	Economy	12100.00
0005433960401	25930	Economy	12100.00
0005433985583	25930	Economy	12100.00
0005433985562	25930	Economy	12100.00
0005433960422	25930	Economy	12100.00
0005433985570	25930	Economy	12100.00
0005433985590	25930	Economy	12100.00
0005433960428	25930	Economy	12100.00
0005433960436	25930	Economy	12100.00
0005433960407	25930	Economy	12100.00
0005434480140	924	Economy	25400.00
0005434480154	924	Economy	25400.00
0005434480135	924	Economy	25400.00
0005434480144	924	Economy	23100.00
0005432269475	924	Economy	23100.00
0005433165722	924	Economy	23100.00
0005433165747	924	Economy	23100.00
0005434480147	924	Economy	23100.00
0005434480149	924	Economy	23100.00
0005433165695	924	Economy	23100.00
0005434480142	924	Economy	23100.00
0005433165719	924	Economy	23100.00
0005434480146	924	Economy	23100.00
0005434480148	924	Economy	23100.00
0005434480136	924	Economy	23100.00
0005433165721	924	Economy	23100.00
0005433165705	924	Economy	23100.00
0005434480141	924	Economy	23100.00
0005433165713	924	Economy	23100.00
0005433165696	924	Economy	23100.00
0005433165698	924	Economy	23100.00
0005434480159	924	Economy	23100.00
0005434480138	924	Economy	23100.00
0005434480153	924	Economy	23100.00
0005432269474	924	Economy	23100.00
0005434480152	924	Economy	23100.00
0005434480137	924	Economy	23100.00
0005434480150	924	Economy	23100.00
0005433165720	924	Economy	23100.00
0005434480134	924	Economy	23100.00
0005434480139	924	Economy	23100.00
0005434480156	924	Economy	23100.00
0005434480151	924	Economy	23100.00
0005433165759	924	Economy	23100.00
0005434480145	924	Economy	23100.00
0005434480157	924	Economy	23100.00
0005434480155	924	Economy	23100.00
0005434480143	924	Economy	23100.00
0005434480158	924	Economy	23100.00
0005434479883	16579	Economy	25400.00
0005434479987	16579	Economy	25400.00
0005433165807	16579	Economy	25400.00
0005434479925	16579	Economy	25400.00
0005433165806	16579	Economy	23100.00
0005434479950	16579	Economy	23100.00
0005433165809	16579	Economy	23100.00
0005433165812	16579	Economy	23100.00
0005433165813	16579	Economy	23100.00
0005434479906	16579	Economy	23100.00
0005434480030	16579	Economy	23100.00
0005433165810	16579	Economy	23100.00
0005434479900	16579	Economy	23100.00
0005434479988	16579	Economy	23100.00
0005434479910	16579	Economy	23100.00
0005433165808	16579	Economy	23100.00
0005433165815	16579	Economy	23100.00
0005433165811	16579	Economy	23100.00
0005434479964	16579	Economy	23100.00
0005434479946	16579	Economy	23100.00
0005433165803	16579	Economy	23100.00
0005434479911	16579	Economy	23100.00
0005434479936	16579	Economy	23100.00
0005434480029	16579	Economy	23100.00
0005433165814	16579	Economy	23100.00
0005434479958	16579	Economy	23100.00
0005434479947	16579	Economy	23100.00
0005433165804	16579	Economy	23100.00
0005434479924	16579	Economy	23100.00
0005434479899	16579	Economy	23100.00
0005434479907	16579	Economy	23100.00
0005433165805	16579	Economy	23100.00
0005435149914	10322	Economy	17000.00
0005435142465	10322	Economy	17000.00
0005435149916	10322	Economy	17000.00
0005435142464	10322	Economy	15400.00
0005435149922	10322	Economy	15400.00
0005435142471	10322	Economy	15400.00
0005433289739	10322	Economy	15400.00
0005435149925	10322	Economy	15400.00
0005435142463	10322	Economy	15400.00
0005435142473	10322	Economy	15400.00
0005435149917	10322	Economy	15400.00
0005435149923	10322	Economy	15400.00
0005435149920	10322	Economy	15400.00
0005435149926	10322	Economy	15400.00
0005435142461	10322	Economy	15400.00
0005435142467	10322	Economy	15400.00
0005435142460	10322	Economy	15400.00
0005435149919	10322	Economy	15400.00
0005435142469	10322	Economy	15400.00
0005435149924	10322	Economy	15400.00
0005433289731	10322	Economy	15400.00
0005435142468	10322	Economy	15400.00
0005435149915	10322	Economy	15400.00
0005435149921	10322	Economy	15400.00
0005435142470	10322	Economy	15400.00
0005435386478	10322	Economy	15400.00
0005435149918	10322	Economy	15400.00
0005435142466	10322	Economy	15400.00
0005435142462	10322	Economy	15400.00
0005435386468	10322	Economy	15400.00
0005433289732	10322	Economy	15400.00
0005435142472	10322	Economy	15400.00
0005435149820	21965	Economy	17000.00
0005433289800	21965	Economy	17000.00
0005435142388	21965	Economy	17000.00
0005435149838	21965	Economy	15400.00
0005433289807	21965	Economy	15400.00
0005435149789	21965	Economy	15400.00
0005435149792	21965	Economy	15400.00
0005433289806	21965	Economy	15400.00
0005435386525	21965	Economy	15400.00
0005433289803	21965	Economy	15400.00
0005433289798	21965	Economy	15400.00
0005435149819	21965	Economy	15400.00
0005435386526	21965	Economy	15400.00
0005433289805	21965	Economy	15400.00
0005435142386	21965	Economy	15400.00
0005435142403	21965	Economy	15400.00
0005435386529	21965	Economy	15400.00
0005435142338	21965	Economy	15400.00
0005435149803	21965	Economy	15400.00
0005435142341	21965	Economy	15400.00
0005435149804	21965	Economy	15400.00
0005435142363	21965	Economy	15400.00
0005435386528	21965	Economy	15400.00
0005435142387	21965	Economy	15400.00
0005435149858	21965	Economy	15400.00
0005435386530	21965	Economy	15400.00
0005435142337	21965	Economy	15400.00
0005433289801	21965	Economy	15400.00
0005433289799	21965	Economy	15400.00
0005435149791	21965	Economy	15400.00
0005435142344	21965	Economy	15400.00
0005435386527	21965	Economy	15400.00
0005435142404	21965	Economy	15400.00
0005433289802	21965	Economy	15400.00
0005433289804	21965	Economy	15400.00
0005435149818	21965	Economy	15400.00
0005435149814	21965	Economy	15400.00
0005435149790	21965	Economy	15400.00
0005435142394	21965	Economy	15400.00
0005435149813	21965	Economy	15400.00
0005435319458	11223	Business	57200.00
0005435528916	11223	Business	57200.00
0005434573235	11223	Business	57200.00
0005435502019	11223	Business	57200.00
0005435528902	11223	Business	57200.00
0005434573239	11223	Business	57200.00
0005435528945	11223	Economy	19100.00
0005435545634	11223	Economy	19100.00
0005434573237	11223	Economy	19100.00
0005434573234	11223	Economy	19100.00
0005434573245	11223	Economy	19100.00
0005434573240	11223	Economy	21000.00
0005435528999	11223	Economy	21000.00
0005435501979	11223	Economy	21000.00
0005435502000	11223	Economy	19100.00
0005434573233	11223	Economy	19100.00
0005435502048	11223	Economy	19100.00
0005435319435	11223	Economy	19100.00
0005435502049	11223	Economy	19100.00
0005435528964	11223	Economy	19100.00
0005435528922	11223	Economy	19100.00
0005435528934	11223	Economy	19100.00
0005435528946	11223	Economy	19100.00
0005434573243	11223	Economy	19100.00
0005435528914	11223	Economy	19100.00
0005435528944	11223	Economy	19100.00
0005435528950	11223	Economy	19100.00
0005434573236	11223	Economy	19100.00
0005435502020	11223	Economy	19100.00
0005434573232	11223	Economy	19100.00
0005435501955	11223	Economy	19100.00
0005435528888	11223	Economy	19100.00
0005434573241	11223	Economy	19100.00
0005434573244	11223	Economy	19100.00
0005435319459	11223	Economy	19100.00
0005435501957	11223	Economy	19100.00
0005435528915	11223	Economy	19100.00
0005435545621	11223	Economy	19100.00
0005435545635	11223	Economy	19100.00
0005435501956	11223	Economy	19100.00
0005434573238	11223	Economy	19100.00
0005434573242	11223	Economy	19100.00
0005435502047	11223	Economy	19100.00
0005434573136	20908	Business	57200.00
0005435502146	20908	Business	57200.00
0005435502133	20908	Business	57200.00
0005435517770	20908	Business	57200.00
0005435502150	20908	Business	57200.00
0005435517767	20908	Business	57200.00
0005432291910	20908	Business	57200.00
0005435508275	20908	Business	57200.00
0005435517771	20908	Business	57200.00
0005435502141	20908	Business	57200.00
0005435319516	20908	Economy	19100.00
0005434573118	20908	Economy	19100.00
0005435502138	20908	Economy	19100.00
0005434573117	20908	Economy	19100.00
0005434573155	20908	Economy	19100.00
0005434573113	20908	Economy	19100.00
0005435508272	20908	Economy	21000.00
0005434573111	20908	Economy	21000.00
0005435517766	20908	Economy	21000.00
0005435319522	20908	Economy	19100.00
0005435319521	20908	Economy	19100.00
0005435502152	20908	Economy	19100.00
0005435319517	20908	Economy	19100.00
0005435502145	20908	Economy	19100.00
0005435502136	20908	Economy	19100.00
0005435508269	20908	Economy	19100.00
0005435502149	20908	Economy	19100.00
0005435508267	20908	Economy	19100.00
0005435508270	20908	Economy	19100.00
0005432291911	20908	Economy	19100.00
0005435517775	20908	Economy	19100.00
0005435517774	20908	Economy	19100.00
0005434573114	20908	Economy	19100.00
0005435502143	20908	Economy	19100.00
0005435319520	20908	Economy	19100.00
0005435508266	20908	Economy	19100.00
0005435517777	20908	Economy	19100.00
0005435517768	20908	Economy	19100.00
0005435319523	20908	Economy	19100.00
0005435508274	20908	Economy	19100.00
0005435502144	20908	Economy	19100.00
0005434573121	20908	Economy	19100.00
0005434573133	20908	Economy	19100.00
0005435319514	20908	Economy	19100.00
0005435502148	20908	Economy	19100.00
0005435502134	20908	Economy	19100.00
0005435502132	20908	Economy	19100.00
0005435502137	20908	Economy	19100.00
0005435502142	20908	Economy	19100.00
0005434573157	20908	Economy	19100.00
0005435517776	20908	Economy	19100.00
0005435502135	20908	Economy	19100.00
0005435502139	20908	Economy	19100.00
0005435319518	20908	Economy	19100.00
0005435319519	20908	Economy	19100.00
0005435502140	20908	Economy	19100.00
0005435502147	20908	Economy	19100.00
0005434573154	20908	Economy	19100.00
0005435319515	20908	Economy	19100.00
0005434573153	20908	Economy	19100.00
0005435517773	20908	Economy	19100.00
0005435508273	20908	Economy	19100.00
0005435508271	20908	Economy	19100.00
0005435517772	20908	Economy	19100.00
0005435508268	20908	Economy	19100.00
0005435502151	20908	Economy	19100.00
0005434573107	20908	Economy	19100.00
0005435517769	20908	Economy	19100.00
0005433683316	24307	Economy	17100.00
0005433683314	24307	Economy	17100.00
0005433683312	24307	Economy	17100.00
0005433683317	24307	Economy	17100.00
0005433683319	24307	Economy	17100.00
0005433683315	24307	Economy	17100.00
0005433927400	24307	Economy	17100.00
0005433683318	24307	Economy	17100.00
0005433927403	24307	Economy	17100.00
0005433683313	24307	Economy	17100.00
0005433683299	29286	Economy	18800.00
0005433927419	29286	Economy	18800.00
0005433927420	29286	Economy	17100.00
0005433683298	29286	Economy	17100.00
0005433927421	29286	Economy	17100.00
0005433927418	29286	Economy	17100.00
0005433927424	29286	Economy	17100.00
0005433927417	29286	Economy	17100.00
0005433683300	29286	Economy	17100.00
0005433927423	29286	Economy	17100.00
0005433927422	29286	Economy	17100.00
0005432692545	2938	Business	10300.00
0005432692560	2938	Business	10300.00
0005432692618	2938	Business	10300.00
0005432692634	2938	Economy	3400.00
0005432692530	2938	Economy	3800.00
0005432692538	2938	Economy	3400.00
0005432692533	2938	Economy	3400.00
0005432692529	2938	Economy	3400.00
0005432692595	2938	Economy	3400.00
0005432692559	2938	Economy	3400.00
0005432692556	2938	Economy	3400.00
0005432692546	2938	Economy	3400.00
0005432692544	2938	Economy	3400.00
0005432692591	2938	Economy	3400.00
0005432692604	2938	Economy	3400.00
0005432692596	2938	Economy	3400.00
0005432692700	2938	Economy	3400.00
0005432692615	2938	Economy	3400.00
0005432692539	2938	Economy	3400.00
0005432692597	2938	Economy	3400.00
0005432692699	2938	Economy	3400.00
0005432692564	2938	Economy	3400.00
0005432692594	2938	Economy	3400.00
0005433123607	2924	Business	10300.00
0005432706583	2924	Business	10300.00
0005432706587	2924	Business	10300.00
0005432706579	2924	Business	10300.00
0005433123570	2924	Business	10300.00
0005433194827	2924	Business	10300.00
0005433123643	2924	Economy	3400.00
0005432880568	2924	Economy	3400.00
0005432706591	2924	Economy	3400.00
0005433123608	2924	Economy	3400.00
0005432880601	2924	Economy	3400.00
0005432880603	2924	Economy	3400.00
0005432706569	2924	Economy	3400.00
0005432880662	2924	Economy	3800.00
0005432880602	2924	Economy	3800.00
0005432706572	2924	Economy	3800.00
0005432706580	2924	Economy	3400.00
0005433123600	2924	Economy	3400.00
0005432706573	2924	Economy	3400.00
0005432706584	2924	Economy	3400.00
0005432706592	2924	Economy	3400.00
0005432880559	2924	Economy	3400.00
0005432706578	2924	Economy	3400.00
0005432880558	2924	Economy	3400.00
0005433123617	2924	Economy	3400.00
0005432880570	2924	Economy	3400.00
0005433123592	2924	Economy	3400.00
0005432706585	2924	Economy	3400.00
0005432706589	2924	Economy	3400.00
0005432706590	2924	Economy	3400.00
0005432706574	2924	Economy	3400.00
0005432706593	2924	Economy	3400.00
0005432706577	2924	Economy	3400.00
0005432706571	2924	Economy	3400.00
0005432217755	2924	Economy	3400.00
0005433123648	2924	Economy	3400.00
0005432706575	2924	Economy	3400.00
0005432706570	2924	Economy	3400.00
0005432880606	2924	Economy	3400.00
0005432706581	2924	Economy	3400.00
0005433123644	2924	Economy	3400.00
0005433123595	2924	Economy	3400.00
0005433123606	2924	Economy	3400.00
0005433123622	2924	Economy	3400.00
0005432706586	2924	Economy	3400.00
0005433123614	2924	Economy	3400.00
0005432706576	2924	Economy	3400.00
0005432880577	2924	Economy	3400.00
0005432706594	2924	Economy	3400.00
0005433123599	2924	Economy	3400.00
0005433123565	2924	Economy	3400.00
0005432880608	2924	Economy	3400.00
0005432217756	2924	Economy	3400.00
0005432217754	2924	Economy	3400.00
0005433123647	2924	Economy	3400.00
0005432706588	2924	Economy	3400.00
0005433123649	2924	Economy	3400.00
0005433123597	2924	Economy	3400.00
0005432880569	2924	Economy	3400.00
0005432880578	2924	Economy	3400.00
0005433123594	2924	Economy	3400.00
0005432706582	2924	Economy	3400.00
0005433123598	2924	Economy	3400.00
0005432692858	30064	Business	10300.00
0005432692844	30064	Business	10300.00
0005432692857	30064	Business	10300.00
0005433123762	30064	Business	10300.00
0005432706402	30064	Business	10300.00
0005432706334	30064	Business	10300.00
0005433123775	30064	Business	10300.00
0005432692872	30064	Business	10300.00
0005432692862	30064	Business	10300.00
0005433123771	30064	Business	10300.00
0005432880701	30064	Business	10300.00
0005432692870	30064	Business	10300.00
0005433123776	30064	Economy	3400.00
0005432692859	30064	Economy	3400.00
0005432880711	30064	Economy	3400.00
0005432880706	30064	Economy	3400.00
0005432692869	30064	Economy	3400.00
0005433123777	30064	Economy	3400.00
0005433123766	30064	Economy	3400.00
0005432706408	30064	Economy	3400.00
0005432692866	30064	Economy	3400.00
0005432692856	30064	Economy	3800.00
0005432706347	30064	Economy	3800.00
0005432706435	30064	Economy	3800.00
0005432692854	30064	Economy	3800.00
0005432706394	30064	Economy	3800.00
0005432880710	30064	Economy	3400.00
0005432706453	30064	Economy	3400.00
0005432880712	30064	Economy	3400.00
0005432706320	30064	Economy	3400.00
0005433123779	30064	Economy	3400.00
0005432692845	30064	Economy	3400.00
0005433123768	30064	Economy	3400.00
0005432692847	30064	Economy	3400.00
0005433123770	30064	Economy	3400.00
0005432706356	30064	Economy	3400.00
0005432880703	30064	Economy	3400.00
0005432706426	30064	Economy	3400.00
0005433123769	30064	Economy	3400.00
0005433123773	30064	Economy	3400.00
0005432692861	30064	Economy	3400.00
0005432692851	30064	Economy	3400.00
0005432706369	30064	Economy	3400.00
0005432706336	30064	Economy	3400.00
0005432706509	30064	Economy	3400.00
0005432692848	30064	Economy	3400.00
0005432692867	30064	Economy	3400.00
0005433123765	30064	Economy	3400.00
0005432706434	30064	Economy	3400.00
0005433123774	30064	Economy	3400.00
0005432706477	30064	Economy	3400.00
0005432880704	30064	Economy	3400.00
0005432880715	30064	Economy	3400.00
0005432880713	30064	Economy	3400.00
0005432692850	30064	Economy	3400.00
0005432706427	30064	Economy	3400.00
0005432692846	30064	Economy	3400.00
0005432706436	30064	Economy	3400.00
0005433123763	30064	Economy	3400.00
0005433123761	30064	Economy	3400.00
0005432880708	30064	Economy	3400.00
0005432706484	30064	Economy	3400.00
0005432692871	30064	Economy	3400.00
0005433123767	30064	Economy	3400.00
0005432706407	30064	Economy	3400.00
0005432706333	30064	Economy	3400.00
0005432692855	30064	Economy	3400.00
0005433123778	30064	Economy	3400.00
0005432706452	30064	Economy	3400.00
0005432692865	30064	Economy	3400.00
0005432692843	30064	Economy	3400.00
0005432692863	30064	Economy	3400.00
0005432692868	30064	Economy	3400.00
0005432692853	30064	Economy	3400.00
0005432880714	30064	Economy	3400.00
0005432880705	30064	Economy	3400.00
0005432706399	30064	Economy	3400.00
0005433123772	30064	Economy	3400.00
0005432692852	30064	Economy	3400.00
0005432692860	30064	Economy	3400.00
0005432880707	30064	Economy	3400.00
0005432692864	30064	Economy	3400.00
0005432880702	30064	Economy	3400.00
0005433123760	30064	Economy	3400.00
0005432692849	30064	Economy	3400.00
0005432880709	30064	Economy	3400.00
0005433123780	30064	Economy	3400.00
0005432706410	30064	Economy	3400.00
0005432706398	30064	Economy	3400.00
0005432692873	30064	Economy	3400.00
0005433123764	30064	Economy	3400.00
0005434979557	23678	Economy	4000.00
0005434988647	23678	Economy	4000.00
0005434979559	23678	Economy	4000.00
0005434988651	23678	Economy	4000.00
0005434988648	23678	Economy	3600.00
0005434979542	23678	Economy	3600.00
0005434979538	23678	Economy	3600.00
0005434988646	23678	Economy	3600.00
0005434988650	23678	Economy	3600.00
0005434979551	23678	Economy	3600.00
0005434979532	23678	Economy	3600.00
0005434988642	23678	Economy	3600.00
0005434988638	23678	Economy	3600.00
0005434979548	23678	Economy	3600.00
0005434979534	23678	Economy	3600.00
0005434988645	23678	Economy	3600.00
0005434979533	23678	Economy	3600.00
0005434979546	23678	Economy	3600.00
0005434988652	23678	Economy	3600.00
0005434988649	23678	Economy	3600.00
0005434979535	23678	Economy	3600.00
0005434979537	23678	Economy	3600.00
0005434979550	23678	Economy	3600.00
0005434979536	23678	Economy	3600.00
0005434988639	23678	Economy	3600.00
0005434988644	23678	Economy	3600.00
0005434979531	23678	Economy	3600.00
0005434979555	23678	Economy	3600.00
0005434979553	23678	Economy	3600.00
0005434979554	23678	Economy	3600.00
0005434979556	23678	Economy	3600.00
0005434979558	23678	Economy	3600.00
0005434979549	23678	Economy	3600.00
0005434988641	23678	Economy	3600.00
0005434979529	23678	Economy	3600.00
0005434979539	23678	Economy	3600.00
0005434988653	23678	Economy	3600.00
0005434979544	23678	Economy	3600.00
0005434979543	23678	Economy	3600.00
0005434988643	23678	Economy	3600.00
0005434979540	23678	Economy	3600.00
0005434979547	23678	Economy	3600.00
0005434988640	23678	Economy	3600.00
0005434979545	23678	Economy	3600.00
0005434979530	23678	Economy	3600.00
0005434979541	23678	Economy	3600.00
0005434979552	23678	Economy	3600.00
0005434979391	27518	Economy	4000.00
0005434979294	27518	Economy	4000.00
0005434979372	27518	Economy	4000.00
0005434979289	27518	Economy	3600.00
0005434979279	27518	Economy	3600.00
0005434979284	27518	Economy	3600.00
0005434979266	27518	Economy	3600.00
0005434979307	27518	Economy	3600.00
0005434979309	27518	Economy	3600.00
0005434979290	27518	Economy	3600.00
0005434979310	27518	Economy	3600.00
0005434979342	27518	Economy	3600.00
0005434979381	27518	Economy	3600.00
0005434979267	27518	Economy	3600.00
0005434979276	27518	Economy	3600.00
0005434979288	27518	Economy	3600.00
0005434979355	27518	Economy	3600.00
0005434979271	27518	Economy	3600.00
0005434979349	27518	Economy	3600.00
0005434979457	27518	Economy	3600.00
0005434979458	27518	Economy	3600.00
0005434979357	27518	Economy	3600.00
0005434979268	27518	Economy	3600.00
0005434979308	27518	Economy	3600.00
0005434979380	27518	Economy	3600.00
0005434979382	27518	Economy	3600.00
0005434979269	27518	Economy	3600.00
0005434979348	27518	Economy	3600.00
0005434302421	10300	Economy	19700.00
0005434302426	10300	Economy	19700.00
0005434302425	10300	Economy	19700.00
0005434302424	10300	Economy	19700.00
0005434302423	10300	Economy	19700.00
0005434302854	10300	Economy	19700.00
0005434302422	10300	Economy	19700.00
0005433113519	19618	Economy	19700.00
0005433113520	19618	Economy	19700.00
0005433113521	19618	Economy	19700.00
0005433113522	19618	Economy	19700.00
0005435939863	3582	Business	26900.00
0005435068735	3582	Business	26900.00
0005435068702	3582	Business	26900.00
0005435068706	3582	Business	26900.00
0005435068732	3582	Business	26900.00
0005435068726	3582	Business	26900.00
0005435068728	3582	Business	26900.00
0005435925077	3582	Business	26900.00
0005435068731	3582	Business	26900.00
0005435068707	3582	Business	26900.00
0005435925090	3582	Economy	9000.00
0005435925091	3582	Economy	9000.00
0005435925074	3582	Economy	9000.00
0005435068696	3582	Economy	9000.00
0005435068733	3582	Economy	9000.00
0005435068711	3582	Economy	9000.00
0005435068690	3582	Economy	9000.00
0005435925070	3582	Economy	9900.00
0005435718907	3582	Economy	9900.00
0005435068703	3582	Economy	9900.00
0005435068691	3582	Economy	9000.00
0005435068715	3582	Economy	9000.00
0005435068692	3582	Economy	9000.00
0005435068698	3582	Economy	9000.00
0005435068722	3582	Economy	9000.00
0005435068725	3582	Economy	9000.00
0005435068729	3582	Economy	9000.00
0005435068720	3582	Economy	9000.00
0005435068694	3582	Economy	9000.00
0005435068740	3582	Economy	9000.00
0005435925076	3582	Economy	9000.00
0005435068713	3582	Economy	9000.00
0005435068721	3582	Economy	9000.00
0005435925089	3582	Economy	9000.00
0005435068708	3582	Economy	9000.00
0005435068718	3582	Economy	9000.00
0005435068730	3582	Economy	9000.00
0005435068724	3582	Economy	9000.00
0005435068723	3582	Economy	9000.00
0005435068719	3582	Economy	9000.00
0005435068689	3582	Economy	9000.00
0005435068736	3582	Economy	9000.00
0005435068701	3582	Economy	9000.00
0005435925093	3582	Economy	9000.00
0005435068709	3582	Economy	9000.00
0005435068712	3582	Economy	9000.00
0005435718903	3582	Economy	9000.00
0005435068688	3582	Economy	9000.00
0005435068693	3582	Economy	9000.00
0005435068697	3582	Economy	9000.00
0005435068704	3582	Economy	9000.00
0005435068738	3582	Economy	9000.00
0005435068699	3582	Economy	9000.00
0005435718906	3582	Economy	9000.00
0005435068716	3582	Economy	9000.00
0005435718904	3582	Economy	9000.00
0005435068717	3582	Economy	9000.00
0005435068710	3582	Economy	9000.00
0005435068734	3582	Economy	9000.00
0005435068727	3582	Economy	9000.00
0005435718908	3582	Economy	9000.00
0005435718905	3582	Economy	9000.00
0005435068737	3582	Economy	9000.00
0005435068705	3582	Economy	9000.00
0005435068700	3582	Economy	9000.00
0005435068714	3582	Economy	9000.00
0005435068739	3582	Economy	9000.00
0005435925088	3582	Economy	9000.00
0005435718902	3582	Economy	9000.00
0005435068695	3582	Economy	9000.00
0005435068454	15304	Business	26900.00
0005435068468	15304	Business	26900.00
0005435068273	15304	Business	26900.00
0005435068303	15304	Business	26900.00
0005435068244	15304	Business	26900.00
0005435068182	15304	Economy	9000.00
0005435068317	15304	Economy	9000.00
0005435068261	15304	Economy	9000.00
0005435068297	15304	Economy	9000.00
0005435068354	15304	Economy	9000.00
0005435068382	15304	Economy	9000.00
0005435068262	15304	Economy	9000.00
0005435068176	15304	Economy	9000.00
0005435068201	15304	Economy	9000.00
0005435068356	15304	Economy	9000.00
0005435068248	15304	Economy	9000.00
0005435068298	15304	Economy	9000.00
0005435068467	15304	Economy	9000.00
0005435068199	15304	Economy	9000.00
0005435068174	15304	Economy	9000.00
0005435068173	15304	Economy	9000.00
0005435068253	15304	Economy	9000.00
0005435068163	15304	Economy	9000.00
0005435068333	15304	Economy	9000.00
0005435068164	15304	Economy	9000.00
0005435068316	15304	Economy	9000.00
0005435068295	15304	Economy	9000.00
0005435068249	15304	Economy	9000.00
0005435068296	15304	Economy	9000.00
0005435068254	15304	Economy	9000.00
0005435068299	15304	Economy	9000.00
0005435068294	15304	Economy	9000.00
0005435068383	15304	Economy	9000.00
0005435068453	15304	Economy	9000.00
0005435068177	15304	Economy	9000.00
0005435068355	15304	Economy	9000.00
0005432658576	18116	Economy	5900.00
0005432659691	18116	Economy	5900.00
0005432660802	18116	Economy	5900.00
0005432659690	18116	Economy	5900.00
0005432658577	18116	Economy	5900.00
0005432660803	18116	Economy	5900.00
0005432667420	26405	Economy	5900.00
0005433101273	67	Business	20000.00
0005432677522	67	Business	20000.00
0005432919567	67	Business	20000.00
0005432901298	67	Business	20000.00
0005432677521	67	Business	20000.00
0005432919573	67	Business	20000.00
0005433101216	67	Business	20000.00
0005432919515	67	Business	20000.00
0005432919602	67	Business	20000.00
0005433101308	67	Business	20000.00
0005432919624	67	Business	20000.00
0005433101172	67	Business	20000.00
0005433101203	67	Business	20000.00
0005433101231	67	Business	20000.00
0005432919553	67	Business	20000.00
0005433101264	67	Economy	7300.00
0005432901314	67	Economy	7300.00
0005433101205	67	Economy	7300.00
0005433101331	67	Economy	6700.00
0005433101257	67	Economy	6700.00
0005433101307	67	Economy	6700.00
0005433101272	67	Economy	6700.00
0005432919569	67	Economy	6700.00
0005432901352	67	Economy	6700.00
0005433101206	67	Economy	6700.00
0005432391950	67	Economy	6700.00
0005433101265	67	Economy	6700.00
0005432919534	67	Economy	6700.00
0005433101327	67	Economy	6700.00
0005432901377	67	Economy	6700.00
0005433101289	67	Economy	6700.00
0005432919589	67	Economy	6700.00
0005432919531	67	Economy	6700.00
0005433101326	67	Economy	6700.00
0005433101298	67	Economy	6700.00
0005432919561	67	Economy	6700.00
0005432919563	67	Economy	6700.00
0005432919533	67	Economy	6700.00
0005433101301	67	Economy	6700.00
0005432919570	67	Economy	6700.00
0005432919623	67	Economy	6700.00
0005432919514	67	Economy	6700.00
0005432901351	67	Economy	6700.00
0005433101171	67	Economy	6700.00
0005432919544	67	Economy	6700.00
0005433101200	67	Economy	6700.00
0005433101238	67	Economy	6700.00
0005432919548	67	Economy	6700.00
0005432919564	67	Economy	6700.00
0005432919568	67	Economy	7300.00
0005433101256	67	Economy	7300.00
0005433101288	67	Economy	7300.00
0005432901363	67	Economy	7300.00
0005432919556	67	Economy	6700.00
0005433101328	67	Economy	6700.00
0005433101305	67	Economy	6700.00
0005432901364	67	Economy	6700.00
0005432677513	67	Economy	6700.00
0005433101336	67	Economy	6700.00
0005432919557	67	Economy	6700.00
0005432901313	67	Economy	6700.00
0005433101227	67	Economy	6700.00
0005433101260	67	Economy	6700.00
0005432157478	67	Economy	6700.00
0005432677507	67	Economy	6700.00
0005432919572	67	Economy	6700.00
0005432901325	67	Economy	6700.00
0005432919622	67	Economy	6700.00
0005433101296	67	Economy	6700.00
0005433101218	67	Economy	6700.00
0005433101226	67	Economy	6700.00
0005432901371	67	Economy	6700.00
0005433101228	67	Economy	6700.00
0005433101306	67	Economy	6700.00
0005433101156	67	Economy	6700.00
0005433101204	67	Economy	6700.00
0005433101295	67	Economy	6700.00
0005432919504	67	Economy	6700.00
0005433101235	67	Economy	6700.00
0005432919588	67	Economy	6700.00
0005432677514	67	Economy	6700.00
0005433101333	67	Economy	6700.00
0005432901357	67	Economy	6700.00
0005433101279	67	Economy	6700.00
0005433101329	67	Economy	6700.00
0005432901350	67	Economy	6700.00
0005433101332	67	Economy	6700.00
0005433101330	67	Economy	6700.00
0005432391951	67	Economy	6700.00
0005432817268	229	Business	20000.00
0005432261593	229	Business	20000.00
0005432261589	229	Business	20000.00
0005432261584	229	Business	20000.00
0005432207641	229	Business	20000.00
0005432261575	229	Business	20000.00
0005432817246	229	Business	20000.00
0005432261566	229	Business	20000.00
0005432753245	229	Business	20000.00
0005432261597	229	Business	20000.00
0005432817249	229	Business	20000.00
0005432753258	229	Business	20000.00
0005432756794	229	Business	20000.00
0005432261572	229	Business	20000.00
0005432261590	229	Business	20000.00
0005432817253	229	Business	20000.00
0005432261573	229	Economy	7300.00
0005432817260	229	Economy	6700.00
0005432817252	229	Economy	6700.00
0005432261565	229	Economy	6700.00
0005432817266	229	Economy	6700.00
0005432261594	229	Economy	6700.00
0005432261555	229	Economy	6700.00
0005433690894	229	Economy	6700.00
0005432817254	229	Economy	6700.00
0005432261582	229	Economy	6700.00
0005432817251	229	Economy	6700.00
0005432261559	229	Economy	6700.00
0005432817247	229	Economy	6700.00
0005432261596	229	Economy	6700.00
0005432261556	229	Economy	6700.00
0005432261558	229	Economy	6700.00
0005432261600	229	Economy	6700.00
0005432261601	229	Economy	6700.00
0005432261569	229	Economy	6700.00
0005432817270	229	Economy	6700.00
0005434153525	229	Economy	6700.00
0005432288961	229	Economy	6700.00
0005432817261	229	Economy	6700.00
0005432261560	229	Economy	6700.00
0005432261588	229	Economy	6700.00
0005432261599	229	Economy	6700.00
0005432261591	229	Economy	6700.00
0005432261581	229	Economy	6700.00
0005432261576	229	Economy	6700.00
0005432817242	229	Economy	6700.00
0005432261562	229	Economy	6700.00
0005432261579	229	Economy	6700.00
0005432261578	229	Economy	6700.00
0005432261580	229	Economy	6700.00
0005434153526	229	Economy	6700.00
0005432817269	229	Economy	7300.00
0005432817264	229	Economy	7300.00
0005432817244	229	Economy	6700.00
0005432817241	229	Economy	6700.00
0005432288962	229	Economy	6700.00
0005432817259	229	Economy	6700.00
0005432261577	229	Economy	6700.00
0005432261561	229	Economy	6700.00
0005432261567	229	Economy	6700.00
0005432261592	229	Economy	6700.00
0005432817258	229	Economy	6700.00
0005432261586	229	Economy	6700.00
0005433690899	229	Economy	6700.00
0005432261598	229	Economy	6700.00
0005432261564	229	Economy	6700.00
0005432817248	229	Economy	6700.00
0005432261574	229	Economy	6700.00
0005432261571	229	Economy	6700.00
0005432261602	229	Economy	6700.00
0005432817262	229	Economy	6700.00
0005432817255	229	Economy	6700.00
0005432261563	229	Economy	6700.00
0005432817243	229	Economy	6700.00
0005432817263	229	Economy	6700.00
0005432817257	229	Economy	6700.00
0005432261557	229	Economy	6700.00
0005432261568	229	Economy	6700.00
0005432817267	229	Economy	6700.00
0005432261583	229	Economy	6700.00
0005432756795	229	Economy	6700.00
0005432817265	229	Economy	6700.00
0005432817256	229	Economy	6700.00
0005432261570	229	Economy	6700.00
0005432261595	229	Economy	6700.00
0005432817245	229	Economy	6700.00
0005432288963	229	Economy	6700.00
0005432261585	229	Economy	6700.00
0005432261587	229	Economy	6700.00
0005432817250	229	Economy	6700.00
0005433101745	8041	Business	20000.00
0005432020079	8041	Business	20000.00
0005432919711	8041	Business	20000.00
0005432044505	8041	Business	20000.00
0005433101769	8041	Business	20000.00
0005432391977	8041	Business	20000.00
0005432677547	8041	Business	20000.00
0005433101759	8041	Business	20000.00
0005433101756	8041	Business	20000.00
0005432020053	8041	Business	20000.00
0005433101772	8041	Business	20000.00
0005433101779	8041	Business	20000.00
0005433101739	8041	Business	20000.00
0005432020077	8041	Business	20000.00
0005433101767	8041	Business	20000.00
0005432677544	8041	Business	20000.00
0005432020057	8041	Business	20000.00
0005432751504	8041	Business	20000.00
0005432751503	8041	Business	20000.00
0005432751502	8041	Economy	7300.00
0005433101750	8041	Economy	7300.00
0005433101742	8041	Economy	7300.00
0005432020060	8041	Economy	6700.00
0005432020072	8041	Economy	6700.00
0005432020078	8041	Economy	6700.00
0005432020061	8041	Economy	6700.00
0005432919701	8041	Economy	6700.00
0005432020062	8041	Economy	6700.00
0005433101776	8041	Economy	6700.00
0005432020063	8041	Economy	6700.00
0005432020071	8041	Economy	6700.00
0005433101777	8041	Economy	6700.00
0005432020066	8041	Economy	6700.00
0005433101741	8041	Economy	6700.00
0005433101761	8041	Economy	6700.00
0005433101738	8041	Economy	6700.00
0005432391978	8041	Economy	6700.00
0005432919715	8041	Economy	6700.00
0005432020068	8041	Economy	6700.00
0005433101758	8041	Economy	6700.00
0005432919708	8041	Economy	6700.00
0005433101782	8041	Economy	6700.00
0005433101747	8041	Economy	6700.00
0005433101771	8041	Economy	6700.00
0005432020076	8041	Economy	6700.00
0005432919716	8041	Economy	6700.00
0005433101740	8041	Economy	6700.00
0005432919703	8041	Economy	6700.00
0005432753278	8041	Economy	6700.00
0005432919704	8041	Economy	6700.00
0005432020056	8041	Economy	6700.00
0005433101736	8041	Economy	6700.00
0005432045599	8041	Economy	6700.00
0005432045600	8041	Economy	6700.00
0005433101746	8041	Economy	6700.00
0005432753276	8041	Economy	6700.00
0005433101743	8041	Economy	6700.00
0005433101753	8041	Economy	6700.00
0005432391979	8041	Economy	6700.00
0005432919710	8041	Economy	6700.00
0005432677545	8041	Economy	6700.00
0005432020073	8041	Economy	7300.00
0005432020059	8041	Economy	7300.00
0005432020075	8041	Economy	7300.00
0005432919702	8041	Economy	7300.00
0005432919705	8041	Economy	7300.00
0005432020064	8041	Economy	6700.00
0005432020055	8041	Economy	6700.00
0005433101752	8041	Economy	7300.00
0005432919714	8041	Economy	6700.00
0005433101768	8041	Economy	6700.00
0005433101754	8041	Economy	6700.00
0005433101764	8041	Economy	6700.00
0005432391976	8041	Economy	6700.00
0005432753277	8041	Economy	6700.00
0005432044504	8041	Economy	6700.00
0005433101783	8041	Economy	6700.00
0005432919700	8041	Economy	6700.00
0005433101749	8041	Economy	6700.00
0005432020070	8041	Economy	6700.00
0005432919706	8041	Economy	6700.00
0005432677546	8041	Economy	6700.00
0005433101735	8041	Economy	6700.00
0005433101755	8041	Economy	6700.00
0005432919707	8041	Economy	6700.00
0005433101763	8041	Economy	6700.00
0005432020054	8041	Economy	6700.00
0005432919695	8041	Economy	6700.00
0005432020065	8041	Economy	6700.00
0005433101765	8041	Economy	6700.00
0005432020067	8041	Economy	6700.00
0005432919709	8041	Economy	6700.00
0005433101781	8041	Economy	6700.00
0005433101762	8041	Economy	6700.00
0005433101778	8041	Economy	6700.00
0005433101744	8041	Economy	6700.00
0005433101760	8041	Economy	6700.00
0005433101774	8041	Economy	6700.00
0005432919713	8041	Economy	6700.00
0005433101770	8041	Economy	6700.00
0005432020074	8041	Economy	6700.00
0005433101773	8041	Economy	6700.00
0005432919712	8041	Economy	6700.00
0005432020058	8041	Economy	6700.00
0005433101775	8041	Economy	6700.00
0005432919697	8041	Economy	6700.00
0005432919696	8041	Economy	6700.00
0005433101751	8041	Economy	6700.00
0005433101757	8041	Economy	6700.00
0005433101737	8041	Economy	6700.00
0005433101748	8041	Economy	6700.00
0005433101780	8041	Economy	6700.00
0005432919699	8041	Economy	6700.00
0005432020069	8041	Economy	6700.00
0005432919698	8041	Economy	6700.00
0005433101766	8041	Economy	6700.00
0005432816982	8040	Business	20000.00
0005432817004	8040	Business	20000.00
0005432817062	8040	Business	20000.00
0005432901487	8040	Business	20000.00
0005432901479	8040	Business	20000.00
0005432817133	8040	Business	20000.00
0005432817029	8040	Business	20000.00
0005432901478	8040	Business	20000.00
0005432817122	8040	Business	20000.00
0005432817091	8040	Business	20000.00
0005432002061	8040	Business	20000.00
0005432901481	8040	Economy	7300.00
0005432901474	8040	Economy	7300.00
0005432901491	8040	Economy	7300.00
0005432901476	8040	Economy	6700.00
0005432816946	8040	Economy	6700.00
0005432816973	8040	Economy	6700.00
0005432901477	8040	Economy	6700.00
0005432901486	8040	Economy	6700.00
0005432901482	8040	Economy	6700.00
0005432901484	8040	Economy	6700.00
0005432817003	8040	Economy	6700.00
0005432816997	8040	Economy	6700.00
0005432901483	8040	Economy	6700.00
0005432817035	8040	Economy	6700.00
0005432817064	8040	Economy	6700.00
0005432817092	8040	Economy	6700.00
0005432817093	8040	Economy	6700.00
0005432817002	8040	Economy	6700.00
0005432901480	8040	Economy	6700.00
0005432901488	8040	Economy	7300.00
0005432816996	8040	Economy	7300.00
0005432817072	8040	Economy	6700.00
0005432817005	8040	Economy	6700.00
0005432901473	8040	Economy	6700.00
0005432817028	8040	Economy	6700.00
0005432901485	8040	Economy	6700.00
0005432816998	8040	Economy	6700.00
0005432817121	8040	Economy	6700.00
0005432816947	8040	Economy	6700.00
0005432901490	8040	Economy	6700.00
0005432816999	8040	Economy	6700.00
0005432901489	8040	Economy	6700.00
0005432817063	8040	Economy	6700.00
0005432817040	8040	Economy	6700.00
0005432816967	8040	Economy	6700.00
0005432817001	8040	Economy	6700.00
0005432817065	8040	Economy	6700.00
0005432817019	8040	Economy	6700.00
0005432901475	8040	Economy	6700.00
0005434175680	9638	Economy	6900.00
0005434175690	9638	Economy	6900.00
0005433870715	9638	Economy	6900.00
0005433870714	9638	Economy	6900.00
0005434175723	32333	Economy	6900.00
0005434175720	32333	Economy	6900.00
0005434175721	32333	Economy	6900.00
0005434175722	32333	Economy	6900.00
0005434877524	3508	Business	35000.00
0005432799254	3508	Business	35000.00
0005434877565	3508	Business	35000.00
0005434877560	3508	Business	35000.00
0005434877573	3508	Business	35000.00
0005434877587	3508	Business	35000.00
0005432799256	3508	Business	35000.00
0005434877527	3508	Business	35000.00
0005434877586	3508	Business	35000.00
0005434426408	3508	Business	35000.00
0005434877602	3508	Business	35000.00
0005434877580	3508	Business	35000.00
0005435841081	3508	Business	35000.00
0005435126098	3508	Business	35000.00
0005434426406	3508	Business	35000.00
0005434877577	3508	Business	35000.00
0005434877581	3508	Business	35000.00
0005434877540	3508	Business	35000.00
0005432799267	3508	Business	35000.00
0005435626052	3508	Comfort	19900.00
0005435626045	3508	Comfort	19900.00
0005435626048	3508	Comfort	19900.00
0005434877562	3508	Comfort	19900.00
0005435902392	3508	Comfort	19900.00
0005434877592	3508	Comfort	19900.00
0005434426403	3508	Comfort	19900.00
0005435126070	3508	Comfort	19900.00
0005434877604	3508	Comfort	19900.00
0005434426415	3508	Comfort	19900.00
0005435902448	3508	Comfort	19900.00
0005435126080	3508	Comfort	19900.00
0005434877554	3508	Comfort	19900.00
0005434426409	3508	Comfort	19900.00
0005434877546	3508	Comfort	19900.00
0005434877599	3508	Comfort	19900.00
0005435626053	3508	Comfort	19900.00
0005434877608	3508	Comfort	19900.00
0005435626047	3508	Comfort	19900.00
0005432799265	3508	Comfort	19900.00
0005434877601	3508	Comfort	19900.00
0005435126072	3508	Comfort	19900.00
0005434877568	3508	Comfort	19900.00
0005432188583	3508	Comfort	19900.00
0005434937994	3508	Comfort	19900.00
0005432613834	3508	Comfort	19900.00
0005434937996	3508	Comfort	19900.00
0005434877612	3508	Comfort	19900.00
0005434877552	3508	Comfort	19900.00
0005432611680	3508	Economy	11700.00
0005434877523	3508	Economy	11700.00
0005434877545	3508	Economy	11700.00
0005432611681	3508	Economy	11700.00
0005434426410	3508	Economy	11700.00
0005432799248	3508	Economy	11700.00
0005434877549	3508	Economy	11700.00
0005435902423	3508	Economy	11700.00
0005432613833	3508	Economy	11700.00
0005435126086	3508	Economy	11700.00
0005434877557	3508	Economy	11700.00
0005435126065	3508	Economy	11700.00
0005435902437	3508	Economy	11700.00
0005434426414	3508	Economy	11700.00
0005435626046	3508	Economy	11700.00
0005435126084	3508	Economy	11700.00
0005434937997	3508	Economy	11700.00
0005434426387	3508	Economy	11700.00
0005434877529	3508	Economy	11700.00
0005432799259	3508	Economy	11700.00
0005434877585	3508	Economy	11700.00
0005434877582	3508	Economy	11700.00
0005435126083	3508	Economy	11700.00
0005434877591	3508	Economy	11700.00
0005434877543	3508	Economy	11700.00
0005435626044	3508	Economy	11700.00
0005434426404	3508	Economy	11700.00
0005434877600	3508	Economy	11700.00
0005434938006	3508	Economy	11700.00
0005434877548	3508	Economy	11700.00
0005432799269	3508	Economy	11700.00
0005434877567	3508	Economy	11700.00
0005435126071	3508	Economy	11700.00
0005434938001	3508	Economy	11700.00
0005434877547	3508	Economy	11700.00
0005434877563	3508	Economy	11700.00
0005432799245	3508	Economy	11700.00
0005434877569	3508	Economy	11700.00
0005435126068	3508	Economy	11700.00
0005434877570	3508	Economy	11700.00
0005434877550	3508	Economy	11700.00
0005432799266	3508	Economy	11700.00
0005434877531	3508	Economy	11700.00
0005434877574	3508	Economy	11700.00
0005435126089	3508	Economy	11700.00
0005434426393	3508	Economy	11700.00
0005434426411	3508	Economy	11700.00
0005435626042	3508	Economy	11700.00
0005435902435	3508	Economy	11700.00
0005434877614	3508	Economy	11700.00
0005435126066	3508	Economy	11700.00
0005434877575	3508	Economy	12800.00
0005434937995	3508	Economy	11700.00
0005432183452	3508	Economy	12800.00
0005435126088	3508	Economy	11700.00
0005435126103	3508	Economy	12800.00
0005435126095	3508	Economy	11700.00
0005434937993	3508	Economy	11700.00
0005435126075	3508	Economy	11700.00
0005432183451	3508	Economy	12800.00
0005434938007	3508	Economy	12800.00
0005434877607	3508	Economy	12800.00
0005434426394	3508	Economy	11700.00
0005435126085	3508	Economy	11700.00
0005434877572	3508	Economy	11700.00
0005434877532	3508	Economy	11700.00
0005434426399	3508	Economy	11700.00
0005435126078	3508	Economy	11700.00
0005434877583	3508	Economy	11700.00
0005432799243	3508	Economy	11700.00
0005435626050	3508	Economy	11700.00
0005434877564	3508	Economy	11700.00
0005435902397	3508	Economy	11700.00
0005434937992	3508	Economy	11700.00
0005434877534	3508	Economy	11700.00
0005435902416	3508	Economy	11700.00
0005434937998	3508	Economy	11700.00
0005432799262	3508	Economy	11700.00
0005434877603	3508	Economy	11700.00
0005435902384	3508	Economy	11700.00
0005432799268	3508	Economy	11700.00
0005432799244	3508	Economy	11700.00
0005434877616	3508	Economy	11700.00
0005432799258	3508	Economy	11700.00
0005434877595	3508	Economy	11700.00
0005434877618	3508	Economy	11700.00
0005435902391	3508	Economy	11700.00
0005434426400	3508	Economy	11700.00
0005434877576	3508	Economy	11700.00
0005435126091	3508	Economy	11700.00
0005435626041	3508	Economy	11700.00
0005435126074	3508	Economy	11700.00
0005434877542	3508	Economy	11700.00
0005434877556	3508	Economy	11700.00
0005435126077	3508	Economy	11700.00
0005434877541	3508	Economy	11700.00
0005434877530	3508	Economy	11700.00
0005434426407	3508	Economy	11700.00
0005435126069	3508	Economy	11700.00
0005435126093	3508	Economy	11700.00
0005434426413	3508	Economy	11700.00
0005435126067	3508	Economy	11700.00
0005432799264	3508	Economy	11700.00
0005434877551	3508	Economy	11700.00
0005432799260	3508	Economy	11700.00
0005435902452	3508	Economy	11700.00
0005434877559	3508	Economy	11700.00
0005434877538	3508	Economy	11700.00
0005435626054	3508	Economy	11700.00
0005434877617	3508	Economy	11700.00
0005435841086	3508	Economy	11700.00
0005434938010	3508	Economy	11700.00
0005434426391	3508	Economy	11700.00
0005432188584	3508	Economy	11700.00
0005434877544	3508	Economy	11700.00
0005432799251	3508	Economy	11700.00
0005435126099	3508	Economy	11700.00
0005434877553	3508	Economy	11700.00
0005435126104	3508	Economy	11700.00
0005435126100	3508	Economy	11700.00
0005434877597	3508	Economy	11700.00
0005432611683	3508	Economy	11700.00
0005434877596	3508	Economy	11700.00
0005432799252	3508	Economy	11700.00
0005434877525	3508	Economy	11700.00
0005432799246	3508	Economy	11700.00
0005435126096	3508	Economy	11700.00
0005435902409	3508	Economy	11700.00
0005434426386	3508	Economy	11700.00
0005434426392	3508	Economy	11700.00
0005435902395	3508	Economy	11700.00
0005435126082	3508	Economy	11700.00
0005435126081	3508	Economy	11700.00
0005434426390	3508	Economy	11700.00
0005434877558	3508	Economy	11700.00
0005435902427	3508	Economy	11700.00
0005434938004	3508	Economy	11700.00
0005434937999	3508	Economy	11700.00
0005434877620	3508	Economy	11700.00
0005432188585	3508	Economy	11700.00
0005434426398	3508	Economy	11700.00
0005434426402	3508	Economy	12800.00
0005434877561	3508	Economy	11700.00
0005434877555	3508	Economy	12800.00
0005434426396	3508	Economy	12800.00
0005432611682	3508	Economy	12800.00
0005434877611	3508	Economy	12800.00
0005434426405	3508	Economy	11700.00
0005434938011	3508	Economy	11700.00
0005434426412	3508	Economy	11700.00
0005435902488	3508	Economy	11700.00
0005434877571	3508	Economy	11700.00
0005435126092	3508	Economy	11700.00
0005434938008	3508	Economy	11700.00
0005435126090	3508	Economy	11700.00
0005434426395	3508	Economy	11700.00
0005434938002	3508	Economy	11700.00
0005434877615	3508	Economy	11700.00
0005434877566	3508	Economy	11700.00
0005435626051	3508	Economy	11700.00
0005435902445	3508	Economy	11700.00
0005434877528	3508	Economy	11700.00
0005435126101	3508	Economy	11700.00
0005435626049	3508	Economy	11700.00
0005435902436	3508	Economy	11700.00
0005435841085	3508	Economy	11700.00
0005434426388	3508	Economy	11700.00
0005434877610	3508	Economy	11700.00
0005434877613	3508	Economy	11700.00
0005435126087	3508	Economy	11700.00
0005434877605	3508	Economy	11700.00
0005435126076	3508	Economy	11700.00
0005434877526	3508	Economy	11700.00
0005434877598	3508	Economy	11700.00
0005435626040	3508	Economy	11700.00
0005434877594	3508	Economy	11700.00
0005434426401	3508	Economy	11700.00
0005434877584	3508	Economy	11700.00
0005434877593	3508	Economy	11700.00
0005434938000	3508	Economy	11700.00
0005434877609	3508	Economy	11700.00
0005435126079	3508	Economy	11700.00
0005434877606	3508	Economy	11700.00
0005432799257	3508	Economy	11700.00
0005435902385	3508	Economy	11700.00
0005434877533	3508	Economy	11700.00
0005434877579	3508	Economy	11700.00
0005432799261	3508	Economy	11700.00
0005435902451	3508	Economy	11700.00
0005434877588	3508	Economy	11700.00
0005432613831	3508	Economy	11700.00
0005434877536	3508	Economy	11700.00
0005434938003	3508	Economy	11700.00
0005432799247	3508	Economy	11700.00
0005432799253	3508	Economy	11700.00
0005434877619	3508	Economy	11700.00
0005432183450	3508	Economy	11700.00
0005435126094	3508	Economy	11700.00
0005434877535	3508	Economy	11700.00
0005434877590	3508	Economy	11700.00
0005432799263	3508	Economy	11700.00
0005435126073	3508	Economy	11700.00
0005432613832	3508	Economy	11700.00
0005435126097	3508	Economy	11700.00
0005432799250	3508	Economy	11700.00
0005435126064	3508	Economy	11700.00
0005435126105	3508	Economy	11700.00
0005432799270	3508	Economy	11700.00
0005434877539	3508	Economy	11700.00
0005434426397	3508	Economy	11700.00
0005432799255	3508	Economy	11700.00
0005434426389	3508	Economy	11700.00
0005434938005	3508	Economy	11700.00
0005432799249	3508	Economy	11700.00
0005434877578	3508	Economy	11700.00
0005434938009	3508	Economy	11700.00
0005435626043	3508	Economy	11700.00
0005434877537	3508	Economy	11700.00
0005434877589	3508	Economy	11700.00
0005435902428	3508	Economy	11700.00
0005435126102	3508	Economy	11700.00
0005435125726	14548	Business	35000.00
0005434937844	14548	Business	35000.00
0005434876776	14548	Business	35000.00
0005434876920	14548	Business	35000.00
0005435625885	14548	Business	35000.00
0005434426095	14548	Business	35000.00
0005435125883	14548	Business	35000.00
0005434876872	14548	Business	35000.00
0005432798986	14548	Business	35000.00
0005434876566	14548	Business	35000.00
0005434876634	14548	Business	35000.00
0005432799060	14548	Business	35000.00
0005434426122	14548	Business	35000.00
0005435902578	14548	Comfort	19900.00
0005434876587	14548	Comfort	19900.00
0005435902566	14548	Comfort	19900.00
0005434937884	14548	Comfort	19900.00
0005434937889	14548	Comfort	19900.00
0005435125718	14548	Comfort	19900.00
0005435913909	14548	Comfort	19900.00
0005432798980	14548	Comfort	19900.00
0005434876599	14548	Comfort	19900.00
0005434876689	14548	Comfort	19900.00
0005435125721	14548	Comfort	19900.00
0005435902570	14548	Comfort	19900.00
0005434876943	14548	Comfort	19900.00
0005434876922	14548	Comfort	19900.00
0005434876888	14548	Comfort	19900.00
0005432611643	14548	Comfort	19900.00
0005434876873	14548	Comfort	19900.00
0005434937874	14548	Comfort	19900.00
0005434876949	14548	Comfort	19900.00
0005434877147	14548	Comfort	19900.00
0005434877005	14548	Comfort	19900.00
0005434876710	14548	Comfort	19900.00
0005434426132	14548	Economy	11700.00
0005435125682	14548	Economy	11700.00
0005435902572	14548	Economy	11700.00
0005435125882	14548	Economy	11700.00
0005435902583	14548	Economy	11700.00
0005435625883	14548	Economy	11700.00
0005434426195	14548	Economy	11700.00
0005432607501	14548	Economy	11700.00
0005435625896	14548	Economy	11700.00
0005432607504	14548	Economy	11700.00
0005432607503	14548	Economy	11700.00
0005434876840	14548	Economy	11700.00
0005434876721	14548	Economy	11700.00
0005434876623	14548	Economy	11700.00
0005434876719	14548	Economy	11700.00
0005435125746	14548	Economy	11700.00
0005432059489	14548	Economy	11700.00
0005432799116	14548	Economy	11700.00
0005434937800	14548	Economy	11700.00
0005435125692	14548	Economy	11700.00
0005434876797	14548	Economy	11700.00
0005434876577	14548	Economy	11700.00
0005434876683	14548	Economy	11700.00
0005434877066	14548	Economy	11700.00
0005432799069	14548	Economy	11700.00
0005434876915	14548	Economy	11700.00
0005435625901	14548	Economy	11700.00
0005434877087	14548	Economy	11700.00
0005434426194	14548	Economy	11700.00
0005434876837	14548	Economy	11700.00
0005435902579	14548	Economy	11700.00
0005434937912	14548	Economy	11700.00
0005434876559	14548	Economy	11700.00
0005435842323	14548	Economy	11700.00
0005432799057	14548	Economy	11700.00
0005435125727	14548	Economy	11700.00
0005435125691	14548	Economy	11700.00
0005434876565	14548	Economy	11700.00
0005435625895	14548	Economy	11700.00
0005434937821	14548	Economy	11700.00
0005434877046	14548	Economy	11700.00
0005434876707	14548	Economy	11700.00
0005434877148	14548	Economy	11700.00
0005434876748	14548	Economy	12800.00
0005435842324	14548	Economy	12800.00
0005434937839	14548	Economy	11700.00
0005435125781	14548	Economy	12800.00
0005434876601	14548	Economy	11700.00
0005434937811	14548	Economy	11700.00
0005434937825	14548	Economy	11700.00
0005434877115	14548	Economy	11700.00
0005434876651	14548	Economy	11700.00
0005435125680	14548	Economy	11700.00
0005435625881	14548	Economy	11700.00
0005432798990	14548	Economy	11700.00
0005434426125	14548	Economy	11700.00
0005434876853	14548	Economy	11700.00
0005434426112	14548	Economy	11700.00
0005434876600	14548	Economy	11700.00
0005434877072	14548	Economy	11700.00
0005432799077	14548	Economy	11700.00
0005434877004	14548	Economy	11700.00
0005435902573	14548	Economy	11700.00
0005432799058	14548	Economy	11700.00
0005434426192	14548	Economy	11700.00
0005435125707	14548	Economy	11700.00
0005432799108	14548	Economy	11700.00
0005434426151	14548	Economy	11700.00
0005434426133	14548	Economy	11700.00
0005434876942	14548	Economy	11700.00
0005434426152	14548	Economy	11700.00
0005434426191	14548	Economy	11700.00
0005435902580	14548	Economy	11700.00
0005434876706	14548	Economy	11700.00
0005435914691	14548	Economy	11700.00
0005434876653	14548	Economy	11700.00
0005435125655	14548	Economy	11700.00
0005435125712	14548	Economy	11700.00
0005435125711	14548	Economy	11700.00
0005434876781	14548	Economy	11700.00
0005434876597	14548	Economy	11700.00
0005434937885	14548	Economy	11700.00
0005434426150	14548	Economy	11700.00
0005435902575	14548	Economy	11700.00
0005435125690	14548	Economy	11700.00
0005435902567	14548	Economy	11700.00
0005435841816	14548	Economy	11700.00
0005434426128	14548	Economy	11700.00
0005435125722	14548	Economy	11700.00
0005434876838	14548	Economy	11700.00
0005434937888	14548	Economy	11700.00
0005435625879	14548	Economy	11700.00
0005434876687	14548	Economy	11700.00
0005434426123	14548	Economy	11700.00
0005432799070	14548	Economy	11700.00
0005434937873	14548	Economy	11700.00
0005434877127	14548	Economy	11700.00
0005434426101	14548	Economy	11700.00
0005434876618	14548	Economy	11700.00
0005434876747	14548	Economy	11700.00
0005434937819	14548	Economy	11700.00
0005434877323	14548	Economy	11700.00
0005434877077	14548	Economy	11700.00
0005432798987	14548	Economy	11700.00
0005432799036	14548	Economy	11700.00
0005435902571	14548	Economy	11700.00
0005435902581	14548	Economy	11700.00
0005434426153	14548	Economy	12800.00
0005434877078	14548	Economy	11700.00
0005435125762	14548	Economy	12800.00
0005434937801	14548	Economy	12800.00
0005434937842	14548	Economy	12800.00
0005432798996	14548	Economy	11700.00
0005435841814	14548	Economy	11700.00
0005434876702	14548	Economy	11700.00
0005432798985	14548	Economy	11700.00
0005435125705	14548	Economy	11700.00
0005434877065	14548	Economy	11700.00
0005435902574	14548	Economy	11700.00
0005435902569	14548	Economy	11700.00
0005434426157	14548	Economy	11700.00
0005435125677	14548	Economy	11700.00
0005435902577	14548	Economy	11700.00
0005435125708	14548	Economy	11700.00
0005432799078	14548	Economy	11700.00
0005432799059	14548	Economy	11700.00
0005434937866	14548	Economy	11700.00
0005432799013	14548	Economy	11700.00
0005434876995	14548	Economy	11700.00
0005435125836	14548	Economy	11700.00
0005434426129	14548	Economy	11700.00
0005434877031	14548	Economy	11700.00
0005434426168	14548	Economy	11700.00
0005435902568	14548	Economy	11700.00
0005435125693	14548	Economy	11700.00
0005432799009	14548	Economy	11700.00
0005434426154	14548	Economy	11700.00
0005434937826	14548	Economy	11700.00
0005435914692	14548	Economy	11700.00
0005435125648	14548	Economy	11700.00
0005435913911	14548	Economy	11700.00
0005435125825	14548	Economy	11700.00
0005435625900	14548	Economy	11700.00
0005435125689	14548	Economy	11700.00
0005435125922	14548	Economy	11700.00
0005434877146	14548	Economy	11700.00
0005434876805	14548	Economy	11700.00
0005435841815	14548	Economy	11700.00
0005435625880	14548	Economy	11700.00
0005435902576	14548	Economy	11700.00
0005434876910	14548	Economy	11700.00
0005434876711	14548	Economy	11700.00
0005434876897	14548	Economy	11700.00
0005432059490	14548	Economy	11700.00
0005435913910	14548	Economy	11700.00
0005435125647	14548	Economy	11700.00
0005434876929	14548	Economy	11700.00
0005434876887	14548	Economy	11700.00
0005434876975	14548	Economy	11700.00
0005435625884	14548	Economy	11700.00
0005435902582	14548	Economy	11700.00
0005434877114	14548	Economy	11700.00
0005434426166	14548	Economy	11700.00
0005434876854	14548	Economy	11700.00
0005434426167	14548	Economy	11700.00
0005435625882	14548	Economy	11700.00
0005435125678	14548	Economy	11700.00
0005434937807	14548	Economy	11700.00
0005434876596	14548	Economy	11700.00
0005435125725	14548	Economy	11700.00
0005434876720	14548	Economy	11700.00
0005434325562	3588	Economy	16300.00
0005434325568	3588	Economy	16300.00
0005434325567	3588	Economy	16300.00
0005434325571	3588	Economy	14800.00
0005435889830	3588	Economy	14800.00
0005434312303	3588	Economy	14800.00
0005434312304	3588	Economy	14800.00
0005434325566	3588	Economy	14800.00
0005434325563	3588	Economy	14800.00
0005434325564	3588	Economy	14800.00
0005434325565	3588	Economy	14800.00
0005434325570	3588	Economy	14800.00
0005434325569	3588	Economy	14800.00
0005434325561	3588	Economy	14800.00
0005434325572	3588	Economy	14800.00
0005435889852	15591	Economy	16300.00
0005434325464	15591	Economy	14800.00
0005435889851	15591	Economy	14800.00
0005435889855	15591	Economy	14800.00
0005434325465	15591	Economy	14800.00
0005435889850	15591	Economy	14800.00
0005435889854	15591	Economy	14800.00
0005435889853	15591	Economy	14800.00
0005434325467	15591	Economy	14800.00
0005434325510	15591	Economy	14800.00
0005434325477	15591	Economy	14800.00
0005434325466	15591	Economy	14800.00
0005434325456	15591	Economy	14800.00
0005433420250	650	Economy	4500.00
0005433420288	650	Economy	4500.00
0005433420258	650	Economy	4500.00
0005433420276	650	Economy	4100.00
0005435957592	650	Economy	4100.00
0005433420256	650	Economy	4100.00
0005435957589	650	Economy	4100.00
0005435957603	650	Economy	4100.00
0005435957604	650	Economy	4100.00
0005435957602	650	Economy	4100.00
0005435957599	650	Economy	4100.00
0005435957591	650	Economy	4100.00
0005435957593	650	Economy	4100.00
0005435957590	650	Economy	4100.00
0005435957601	650	Economy	4100.00
0005433420255	650	Economy	4100.00
0005435957594	650	Economy	4100.00
0005435957597	650	Economy	4100.00
0005435957596	650	Economy	4100.00
0005433420251	650	Economy	4100.00
0005435957598	650	Economy	4100.00
0005435957600	650	Economy	4100.00
0005433420289	650	Economy	4100.00
0005435957595	650	Economy	4100.00
0005435957472	15155	Economy	4500.00
0005433420345	15155	Economy	4500.00
0005435957504	15155	Economy	4100.00
0005433420339	15155	Economy	4100.00
0005435957439	15155	Economy	4100.00
0005433420340	15155	Economy	4100.00
0005435957507	15155	Economy	4100.00
0005435957452	15155	Economy	4100.00
0005433420344	15155	Economy	4100.00
0005433420337	15155	Economy	4100.00
0005433420341	15155	Economy	4100.00
0005433420342	15155	Economy	4100.00
0005435957456	15155	Economy	4100.00
0005435957467	15155	Economy	4100.00
0005433420338	15155	Economy	4100.00
0005435957466	15155	Economy	4100.00
0005435957505	15155	Economy	4100.00
0005435957451	15155	Economy	4100.00
0005433420343	15155	Economy	4100.00
0005435957509	15155	Economy	4100.00
0005435216575	31770	Economy	28100.00
0005435216572	31770	Economy	25500.00
0005435218109	31770	Economy	25500.00
0005435217699	31770	Economy	25500.00
0005435216570	31770	Economy	25500.00
0005435216574	31770	Economy	25500.00
0005435217698	31770	Economy	25500.00
0005435217695	31770	Economy	25500.00
0005435217697	31770	Economy	25500.00
0005435216573	31770	Economy	25500.00
0005435216571	31770	Economy	25500.00
0005435217696	31770	Economy	25500.00
0005434995285	6700	Business	94000.00
0005434995289	6700	Business	94000.00
0005434995294	6700	Economy	31300.00
0005434995286	6700	Economy	31300.00
0005434995290	6700	Economy	31300.00
0005434995284	6700	Economy	31300.00
0005434995291	6700	Economy	31300.00
0005434995288	6700	Economy	31300.00
0005434995292	6700	Economy	31300.00
0005434995283	6700	Economy	31300.00
0005434995296	6700	Economy	31300.00
0005434995295	6700	Economy	31300.00
0005434995293	6700	Economy	31300.00
0005434995287	6700	Economy	31300.00
0005435629397	8907	Economy	10400.00
0005434247103	8907	Economy	10400.00
0005435629395	8907	Economy	10400.00
0005435629396	8907	Economy	10400.00
0005434247111	8907	Economy	10400.00
0005434247104	8907	Economy	10400.00
0005435629390	16113	Economy	10400.00
0005434247128	16113	Economy	10400.00
0005434247127	16113	Economy	10400.00
0005434247129	16113	Economy	10400.00
0005434467747	4013	Economy	21200.00
0005434467748	4013	Economy	21200.00
0005434467742	4013	Economy	21200.00
0005434467745	4013	Economy	21200.00
0005434467743	4013	Economy	21200.00
0005434467744	4013	Economy	21200.00
0005434467746	4013	Economy	21200.00
0005434096725	20176	Economy	14700.00
0005434096728	20176	Economy	14700.00
0005434096723	20176	Economy	13400.00
0005434096721	20176	Economy	13400.00
0005434096727	20176	Economy	13400.00
0005434096722	20176	Economy	13400.00
0005434096726	20176	Economy	13400.00
0005434096724	20176	Economy	13400.00
0005432645870	6831	Business	87700.00
0005432645883	6831	Business	87700.00
0005432645877	6831	Business	87700.00
0005435229319	6831	Business	87700.00
0005432645867	6831	Economy	29200.00
0005432645866	6831	Economy	29200.00
0005432645879	6831	Economy	29200.00
0005432645905	6831	Economy	32200.00
0005432645874	6831	Economy	32200.00
0005432645876	6831	Economy	32200.00
0005432645887	6831	Economy	32200.00
0005432645897	6831	Economy	29200.00
0005432645868	6831	Economy	29200.00
0005435229310	6831	Economy	29200.00
0005435229321	6831	Economy	29200.00
0005435229303	6831	Economy	29200.00
0005432645888	6831	Economy	29200.00
0005432645891	6831	Economy	29200.00
0005432645899	6831	Economy	29200.00
0005432645881	6831	Economy	29200.00
0005432645878	6831	Economy	29200.00
0005435229325	6831	Economy	29200.00
0005432645884	6831	Economy	29200.00
0005432645896	6831	Economy	29200.00
0005432645903	6831	Economy	29200.00
0005432645869	6831	Economy	29200.00
0005435229308	6831	Economy	29200.00
0005432645898	6831	Economy	29200.00
0005432645875	6831	Economy	29200.00
0005432645889	6831	Economy	29200.00
0005432645893	6831	Economy	29200.00
0005432645902	6831	Economy	29200.00
0005432645885	6831	Economy	29200.00
0005435229309	6831	Economy	29200.00
0005432645880	6831	Economy	29200.00
0005432645873	6831	Economy	29200.00
0005435229322	6831	Economy	29200.00
0005432645901	6831	Economy	29200.00
0005435229323	6831	Economy	29200.00
0005432645871	6831	Economy	29200.00
0005432645892	6831	Economy	29200.00
0005432645894	6831	Economy	29200.00
0005432645882	6831	Economy	29200.00
0005435229307	6831	Economy	29200.00
0005435229318	6831	Economy	29200.00
0005432645895	6831	Economy	29200.00
0005432645872	6831	Economy	29200.00
0005432645890	6831	Economy	29200.00
0005432645886	6831	Economy	29200.00
0005432645904	6831	Economy	29200.00
0005432645900	6831	Economy	29200.00
0005435229326	6831	Economy	29200.00
0005432645764	25118	Business	87700.00
0005432645775	25118	Business	87700.00
0005435229353	25118	Business	87700.00
0005432645765	25118	Business	87700.00
0005435229354	25118	Business	87700.00
0005435229372	25118	Business	87700.00
0005432645802	25118	Business	87700.00
0005432645796	25118	Economy	29200.00
0005432645805	25118	Economy	29200.00
0005435229379	25118	Economy	29200.00
0005432645768	25118	Economy	29200.00
0005432645776	25118	Economy	29200.00
0005432645761	25118	Economy	29200.00
0005432645809	25118	Economy	29200.00
0005435229366	25118	Economy	29200.00
0005435229375	25118	Economy	32200.00
0005435229362	25118	Economy	32200.00
0005432645774	25118	Economy	32200.00
0005432645766	25118	Economy	32200.00
0005435229381	25118	Economy	29200.00
0005435229373	25118	Economy	29200.00
0005432645788	25118	Economy	29200.00
0005432645804	25118	Economy	29200.00
0005435229377	25118	Economy	29200.00
0005435229361	25118	Economy	29200.00
0005435229363	25118	Economy	29200.00
0005432645812	25118	Economy	29200.00
0005432645770	25118	Economy	29200.00
0005432645763	25118	Economy	29200.00
0005435229367	25118	Economy	29200.00
0005435229360	25118	Economy	29200.00
0005435229359	25118	Economy	29200.00
0005435229371	25118	Economy	29200.00
0005435229358	25118	Economy	29200.00
0005435229376	25118	Economy	29200.00
0005435229355	25118	Economy	29200.00
0005432645810	25118	Economy	29200.00
0005435229382	25118	Economy	29200.00
0005435229356	25118	Economy	29200.00
0005435229374	25118	Economy	29200.00
0005435229368	25118	Economy	29200.00
0005432645811	25118	Economy	29200.00
0005435229364	25118	Economy	29200.00
0005432645762	25118	Economy	29200.00
0005432645787	25118	Economy	29200.00
0005432645795	25118	Economy	29200.00
0005432645801	25118	Economy	29200.00
0005435229365	25118	Economy	29200.00
0005435229383	25118	Economy	29200.00
0005432645803	25118	Economy	29200.00
0005435229378	25118	Economy	29200.00
0005435229357	25118	Economy	29200.00
0005435229369	25118	Economy	29200.00
0005432645767	25118	Economy	29200.00
0005435229380	25118	Economy	29200.00
0005435229370	25118	Economy	29200.00
0005433404692	2871	Business	12600.00
0005433404688	2871	Business	12600.00
0005435797369	2871	Economy	4200.00
0005435797382	2871	Economy	4200.00
0005435797380	2871	Economy	4600.00
0005435797381	2871	Economy	4200.00
0005435797375	2871	Economy	4200.00
0005435797378	2871	Economy	4200.00
0005433404679	2871	Economy	4200.00
0005435797373	2871	Economy	4200.00
0005435797374	2871	Economy	4200.00
0005435797371	2871	Economy	4200.00
0005435797367	2871	Economy	4200.00
0005433404687	2871	Economy	4200.00
0005435797376	2871	Economy	4200.00
0005433404691	2871	Economy	4200.00
0005433404680	2871	Economy	4200.00
0005435797368	2871	Economy	4200.00
0005435797370	2871	Economy	4200.00
0005433404677	2871	Economy	4200.00
0005435797379	2871	Economy	4200.00
0005433404678	2871	Economy	4200.00
0005435797372	2871	Economy	4200.00
0005435797377	2871	Economy	4200.00
0005435797241	29338	Economy	4200.00
0005435797248	29338	Economy	4200.00
0005433404757	29338	Economy	4200.00
0005435797237	29338	Economy	4200.00
0005435797242	29338	Economy	4600.00
0005435797252	29338	Economy	4600.00
0005435797296	29338	Economy	4200.00
0005435797239	29338	Economy	4200.00
0005435797258	29338	Economy	4200.00
0005435797257	29338	Economy	4200.00
0005435797292	29338	Economy	4200.00
0005435797295	29338	Economy	4200.00
0005433404759	29338	Economy	4200.00
0005435797249	29338	Economy	4200.00
0005435797240	29338	Economy	4200.00
0005433404755	29338	Economy	4200.00
0005435797238	29338	Economy	4200.00
0005433404756	29338	Economy	4200.00
0005435797226	29338	Economy	4200.00
0005433404758	29338	Economy	4200.00
0005435797253	29338	Economy	4200.00
0005433404754	29338	Economy	4200.00
0005433404753	29338	Economy	4200.00
0005435376320	5788	Economy	6800.00
0005435376321	5788	Economy	6800.00
0005434947961	5780	Economy	6800.00
0005434947958	5780	Economy	6800.00
0005434947963	5780	Economy	6800.00
0005434947960	5780	Economy	6800.00
0005434947957	5780	Economy	6800.00
0005434947962	5780	Economy	6800.00
0005434947959	5780	Economy	6800.00
0005434947898	16387	Economy	6800.00
0005434947893	16387	Economy	6800.00
0005434947885	16387	Economy	6800.00
0005434947884	16387	Economy	6800.00
0005434947882	16387	Economy	6800.00
0005434947895	16387	Economy	6800.00
0005434947909	16387	Economy	6800.00
0005434947883	16387	Economy	6800.00
0005434947894	16387	Economy	6800.00
0005434947881	16387	Economy	6800.00
0005433960468	6947	Business	21400.00
0005433960449	6947	Business	21400.00
0005433960454	6947	Business	21400.00
0005433960467	6947	Business	21400.00
0005433960476	6947	Business	21400.00
0005433960488	6947	Business	21400.00
0005433960443	6947	Business	21400.00
0005433960477	6947	Economy	7100.00
0005433960457	6947	Economy	7100.00
0005433960459	6947	Economy	7100.00
0005433960481	6947	Economy	7100.00
0005433960486	6947	Economy	7100.00
0005433960487	6947	Economy	7100.00
0005433960460	6947	Economy	7100.00
0005433960445	6947	Economy	7800.00
0005433960466	6947	Economy	7800.00
0005433960482	6947	Economy	7800.00
0005433960495	6947	Economy	7800.00
0005433960498	6947	Economy	7100.00
0005433960496	6947	Economy	7100.00
0005433960475	6947	Economy	7100.00
0005433960489	6947	Economy	7100.00
0005433960458	6947	Economy	7100.00
0005433960473	6947	Economy	7100.00
0005433960456	6947	Economy	7100.00
0005433960450	6947	Economy	7100.00
0005433960451	6947	Economy	7100.00
0005433960463	6947	Economy	7100.00
0005433960474	6947	Economy	7100.00
0005433960490	6947	Economy	7100.00
0005433960471	6947	Economy	7100.00
0005433960491	6947	Economy	7100.00
0005433960462	6947	Economy	7100.00
0005433960472	6947	Economy	7100.00
0005433960461	6947	Economy	7100.00
0005433960448	6947	Economy	7100.00
0005433960483	6947	Economy	7100.00
0005433960479	6947	Economy	7100.00
0005433960484	6947	Economy	7100.00
0005433960447	6947	Economy	7100.00
0005433960492	6947	Economy	7100.00
0005433960464	6947	Economy	7100.00
0005433960470	6947	Economy	7100.00
0005433960494	6947	Economy	7100.00
0005433960480	6947	Economy	7100.00
0005433960453	6947	Economy	7100.00
0005433960478	6947	Economy	7100.00
0005433960446	6947	Economy	7100.00
0005433960469	6947	Economy	7100.00
0005433960493	6947	Economy	7100.00
0005433960465	6947	Economy	7100.00
0005433960497	6947	Economy	7100.00
0005433960444	6947	Economy	7100.00
0005433960455	6947	Economy	7100.00
0005433960485	6947	Economy	7100.00
0005433960452	6947	Economy	7100.00
0005435082674	24502	Economy	3900.00
0005435082673	24502	Economy	3900.00
0005435082652	24502	Economy	3900.00
0005435082653	24502	Economy	3900.00
0005435082650	24502	Economy	3900.00
0005435082727	26117	Economy	3900.00
0005435082722	26117	Economy	3900.00
0005435082723	26117	Economy	3900.00
0005435082726	26117	Economy	3900.00
0005435082719	26117	Economy	3900.00
0005435082725	26117	Economy	3900.00
0005435082721	26117	Economy	3900.00
0005435082720	26117	Economy	3900.00
0005435082718	26117	Economy	3900.00
0005435082724	26117	Economy	3900.00
0005435082717	26117	Economy	3900.00
0005435286548	5235	Business	18000.00
0005434244777	5235	Business	18000.00
0005434244785	5235	Business	18000.00
0005434244757	5235	Business	18000.00
0005434244765	5235	Business	18000.00
0005434244767	5235	Business	18000.00
0005434244754	5235	Business	18000.00
0005434244782	5235	Business	18000.00
0005434244755	5235	Economy	6600.00
0005434244764	5235	Economy	6600.00
0005435286542	5235	Economy	6000.00
0005434244762	5235	Economy	6000.00
0005434244758	5235	Economy	6000.00
0005434244760	5235	Economy	6000.00
0005435286543	5235	Economy	6000.00
0005434244781	5235	Economy	6000.00
0005434244776	5235	Economy	6000.00
0005434244759	5235	Economy	6000.00
0005434244769	5235	Economy	6000.00
0005434244774	5235	Economy	6000.00
0005434244783	5235	Economy	6600.00
0005434244761	5235	Economy	6600.00
0005434244775	5235	Economy	6600.00
0005434244766	5235	Economy	6000.00
0005434244756	5235	Economy	6000.00
0005435286547	5235	Economy	6000.00
0005434244772	5235	Economy	6000.00
0005432166879	5235	Economy	6000.00
0005432166877	5235	Economy	6000.00
0005434244778	5235	Economy	6000.00
0005432166878	5235	Economy	6000.00
0005434244773	5235	Economy	6000.00
0005432166876	5235	Economy	6000.00
0005434244784	5235	Economy	6000.00
0005434244779	5235	Economy	6000.00
0005434244768	5235	Economy	6000.00
0005434244770	5235	Economy	6000.00
0005435286551	5235	Economy	6000.00
0005434244780	5235	Economy	6000.00
0005434244771	5235	Economy	6000.00
0005434244763	5235	Economy	6000.00
0005432145098	5190	Business	18000.00
0005432105201	5190	Business	18000.00
0005432105247	5190	Business	18000.00
0005432105208	5190	Business	18000.00
0005433614136	5190	Business	18000.00
0005433614171	5190	Business	18000.00
0005433614208	5190	Business	18000.00
0005432105213	5190	Business	18000.00
0005432105228	5190	Business	18000.00
0005433614156	5190	Business	18000.00
0005432105204	5190	Business	18000.00
0005432105214	5190	Business	18000.00
0005433614150	5190	Business	18000.00
0005433614140	5190	Business	18000.00
0005433614145	5190	Business	18000.00
0005433784677	5190	Business	18000.00
0005433614178	5190	Business	18000.00
0005432105224	5190	Business	18000.00
0005433614184	5190	Business	18000.00
0005433784686	5190	Business	18000.00
0005433784691	5190	Business	18000.00
0005433784688	5190	Business	18000.00
0005433784669	5190	Business	18000.00
0005433614137	5190	Business	18000.00
0005433784675	5190	Business	18000.00
0005433614138	5190	Business	18000.00
0005433614207	5190	Business	18000.00
0005433614170	5190	Economy	6600.00
0005433614168	5190	Business	18000.00
0005432105222	5190	Economy	6600.00
0005432105237	5190	Economy	6600.00
0005433614142	5190	Economy	6600.00
0005432665258	5190	Economy	6600.00
0005432145097	5190	Economy	6600.00
0005433784699	5190	Economy	6000.00
0005432105203	5190	Economy	6000.00
0005433614167	5190	Economy	6000.00
0005432105212	5190	Economy	6000.00
0005433614172	5190	Economy	6000.00
0005433614199	5190	Economy	6000.00
0005432666374	5190	Economy	6000.00
0005432105245	5190	Economy	6000.00
0005433784694	5190	Economy	6000.00
0005432667439	5190	Economy	6000.00
0005433614153	5190	Economy	6000.00
0005433784690	5190	Economy	6000.00
0005433784663	5190	Economy	6000.00
0005433614179	5190	Economy	6000.00
0005433614151	5190	Economy	6000.00
0005433614169	5190	Economy	6000.00
0005433784683	5190	Economy	6000.00
0005433614160	5190	Economy	6000.00
0005433784697	5190	Economy	6000.00
0005433614193	5190	Economy	6000.00
0005433614204	5190	Economy	6000.00
0005433614176	5190	Economy	6000.00
0005433614186	5190	Economy	6000.00
0005433614154	5190	Economy	6000.00
0005432105248	5190	Economy	6000.00
0005433784692	5190	Economy	6000.00
0005433614147	5190	Economy	6000.00
0005432105249	5190	Economy	6000.00
0005433784666	5190	Economy	6000.00
0005433784664	5190	Economy	6000.00
0005433614188	5190	Economy	6000.00
0005433614152	5190	Economy	6000.00
0005433614197	5190	Economy	6000.00
0005432665259	5190	Economy	6000.00
0005433784667	5190	Economy	6000.00
0005433614144	5190	Economy	6000.00
0005433784693	5190	Economy	6000.00
0005433614195	5190	Economy	6000.00
0005433784681	5190	Economy	6000.00
0005433614187	5190	Economy	6000.00
0005433784687	5190	Economy	6000.00
0005433784684	5190	Economy	6000.00
0005432105232	5190	Economy	6000.00
0005433614173	5190	Economy	6000.00
0005432105233	5190	Economy	6000.00
0005432105215	5190	Economy	6000.00
0005432105240	5190	Economy	6000.00
0005433784680	5190	Economy	6000.00
0005432105216	5190	Economy	6000.00
0005432665260	5190	Economy	6000.00
0005433614183	5190	Economy	6000.00
0005433614198	5190	Economy	6000.00
0005432105219	5190	Economy	6000.00
0005433614166	5190	Economy	6000.00
0005432105229	5190	Economy	6000.00
0005433614157	5190	Economy	6000.00
0005432105211	5190	Economy	6000.00
0005433784682	5190	Economy	6000.00
0005432105244	5190	Economy	6000.00
0005432105202	5190	Economy	6000.00
0005433614141	5190	Economy	6600.00
0005433784698	5190	Economy	6600.00
0005433784665	5190	Economy	6600.00
0005432105223	5190	Economy	6600.00
0005433614202	5190	Economy	6600.00
0005432105209	5190	Economy	6000.00
0005433614158	5190	Economy	6000.00
0005433614163	5190	Economy	6000.00
0005432105235	5190	Economy	6600.00
0005433614161	5190	Economy	6000.00
0005433614205	5190	Economy	6000.00
0005433784671	5190	Economy	6000.00
0005433784670	5190	Economy	6000.00
0005432105218	5190	Economy	6000.00
0005433614175	5190	Economy	6000.00
0005433614149	5190	Economy	6000.00
0005432105221	5190	Economy	6000.00
0005433614192	5190	Economy	6000.00
0005432105230	5190	Economy	6000.00
0005432105236	5190	Economy	6000.00
0005432105220	5190	Economy	6000.00
0005432105205	5190	Economy	6000.00
0005433784679	5190	Economy	6000.00
0005433784685	5190	Economy	6000.00
0005432105239	5190	Economy	6000.00
0005433614182	5190	Economy	6000.00
0005432105206	5190	Economy	6000.00
0005433784696	5190	Economy	6000.00
0005433614162	5190	Economy	6000.00
0005433614143	5190	Economy	6000.00
0005433784678	5190	Economy	6000.00
0005433614189	5190	Economy	6000.00
0005433614135	5190	Economy	6000.00
0005433784695	5190	Economy	6000.00
0005433614200	5190	Economy	6000.00
0005433784674	5190	Economy	6000.00
0005432105207	5190	Economy	6000.00
0005432105238	5190	Economy	6000.00
0005432105243	5190	Economy	6000.00
0005432105241	5190	Economy	6000.00
0005433614203	5190	Economy	6000.00
0005433614148	5190	Economy	6000.00
0005432105225	5190	Economy	6000.00
0005433784689	5190	Economy	6000.00
0005433614194	5190	Economy	6000.00
0005433614196	5190	Economy	6000.00
0005433614209	5190	Economy	6000.00
0005432105231	5190	Economy	6000.00
0005432105242	5190	Economy	6000.00
0005433614180	5190	Economy	6000.00
0005433614190	5190	Economy	6000.00
0005433614165	5190	Economy	6000.00
0005433614155	5190	Economy	6000.00
0005433614201	5190	Economy	6000.00
0005433614185	5190	Economy	6000.00
0005432145096	5190	Economy	6000.00
0005432105226	5190	Economy	6000.00
0005433614139	5190	Economy	6000.00
0005433614164	5190	Economy	6000.00
0005433784676	5190	Economy	6000.00
0005433614159	5190	Economy	6000.00
0005433784672	5190	Economy	6000.00
0005432666373	5190	Economy	6000.00
0005432105210	5190	Economy	6000.00
0005433614177	5190	Economy	6000.00
0005433614206	5190	Economy	6000.00
0005433784668	5190	Economy	6000.00
0005433614181	5190	Economy	6000.00
0005432105227	5190	Economy	6000.00
0005432105234	5190	Economy	6000.00
0005433614146	5190	Economy	6000.00
0005433784673	5190	Economy	6000.00
0005432105217	5190	Economy	6000.00
0005432105246	5190	Economy	6000.00
0005433614191	5190	Economy	6000.00
0005433614174	5190	Economy	6000.00
0005434264958	5139	Business	18000.00
0005434264959	5139	Business	18000.00
0005435006657	5139	Business	18000.00
0005434264948	5139	Business	18000.00
0005435006604	5139	Business	18000.00
0005434229217	5139	Business	18000.00
0005435269624	5139	Business	18000.00
0005434149650	5139	Business	18000.00
0005434264942	5139	Business	18000.00
0005434264953	5139	Business	18000.00
0005434229216	5139	Business	18000.00
0005434229200	5139	Business	18000.00
0005432335838	5139	Business	18000.00
0005434264943	5139	Business	18000.00
0005432335829	5139	Business	18000.00
0005434229201	5139	Business	18000.00
0005434229207	5139	Business	18000.00
0005434311193	5139	Business	18000.00
0005432335851	5139	Business	18000.00
0005435006607	5139	Business	18000.00
0005434264946	5139	Business	18000.00
0005434229203	5139	Business	18000.00
0005434264952	5139	Economy	6600.00
0005434229202	5139	Economy	6600.00
0005435006718	5139	Economy	6600.00
0005435269630	5139	Economy	6600.00
0005435006637	5139	Economy	6000.00
0005432335875	5139	Economy	6000.00
0005434311192	5139	Economy	6000.00
0005432335886	5139	Economy	6000.00
0005434149644	5139	Economy	6000.00
0005435006762	5139	Economy	6000.00
0005432335871	5139	Economy	6000.00
0005433815305	5139	Economy	6000.00
0005435006625	5139	Economy	6000.00
0005434264957	5139	Economy	6000.00
0005435269627	5139	Economy	6000.00
0005434173490	5139	Economy	6000.00
0005435006692	5139	Economy	6000.00
0005434264954	5139	Economy	6000.00
0005433815315	5139	Economy	6000.00
0005434149647	5139	Economy	6000.00
0005434149642	5139	Economy	6000.00
0005434149646	5139	Economy	6000.00
0005434229208	5139	Economy	6000.00
0005435006761	5139	Economy	6000.00
0005434229210	5139	Economy	6000.00
0005434229214	5139	Economy	6000.00
0005432335845	5139	Economy	6000.00
0005434173489	5139	Economy	6000.00
0005434149649	5139	Economy	6000.00
0005434264955	5139	Economy	6000.00
0005434311197	5139	Economy	6000.00
0005434173491	5139	Economy	6000.00
0005434149641	5139	Economy	6000.00
0005434264962	5139	Economy	6000.00
0005435269623	5139	Economy	6000.00
0005434229218	5139	Economy	6000.00
0005433685494	5139	Economy	6000.00
0005434173492	5139	Economy	6000.00
0005435269625	5139	Economy	6000.00
0005434264950	5139	Economy	6000.00
0005434149640	5139	Economy	6000.00
0005433815316	5139	Economy	6000.00
0005434229204	5139	Economy	6000.00
0005435269641	5139	Economy	6000.00
0005434229205	5139	Economy	6000.00
0005435269628	5139	Economy	6000.00
0005432335844	5139	Economy	6600.00
0005434264945	5139	Economy	6600.00
0005434229219	5139	Economy	6000.00
0005434264941	5139	Economy	6000.00
0005435006686	5139	Economy	6000.00
0005434264949	5139	Economy	6000.00
0005434149643	5139	Economy	6600.00
0005434311200	5139	Economy	6000.00
0005434229206	5139	Economy	6000.00
0005435269629	5139	Economy	6000.00
0005435006605	5139	Economy	6000.00
0005435006694	5139	Economy	6000.00
0005434229199	5139	Economy	6000.00
0005434229215	5139	Economy	6000.00
0005433815309	5139	Economy	6000.00
0005435006678	5139	Economy	6000.00
0005434149648	5139	Economy	6000.00
0005434229211	5139	Economy	6000.00
0005435006636	5139	Economy	6000.00
0005434264961	5139	Economy	6000.00
0005434229198	5139	Economy	6000.00
0005435006665	5139	Economy	6000.00
0005435006644	5139	Economy	6000.00
0005432335837	5139	Economy	6000.00
0005434311198	5139	Economy	6000.00
0005434311199	5139	Economy	6000.00
0005432335846	5139	Economy	6000.00
0005435269647	5139	Economy	6000.00
0005434149645	5139	Economy	6000.00
0005433815304	5139	Economy	6000.00
0005435006674	5139	Economy	6000.00
0005434229213	5139	Economy	6000.00
0005434264951	5139	Economy	6000.00
0005434264963	5139	Economy	6000.00
0005434229209	5139	Economy	6000.00
0005434264960	5139	Economy	6000.00
0005435006727	5139	Economy	6000.00
0005435006652	5139	Economy	6000.00
0005432335855	5139	Economy	6000.00
0005434264965	5139	Economy	6000.00
0005435269626	5139	Economy	6000.00
0005435269642	5139	Economy	6000.00
0005434149651	5139	Economy	6000.00
0005434264964	5139	Economy	6000.00
0005434264956	5139	Economy	6000.00
0005434264947	5139	Economy	6000.00
0005434229212	5139	Economy	6000.00
0005434264944	5139	Economy	6000.00
0005433784444	8355	Business	18000.00
0005432666356	8355	Business	18000.00
0005435269693	8355	Business	18000.00
0005433784498	8355	Business	18000.00
0005433784463	8355	Business	18000.00
0005434244567	8355	Business	18000.00
0005433784423	8355	Business	18000.00
0005433784431	8355	Business	18000.00
0005435269694	8355	Business	18000.00
0005434244546	8355	Business	18000.00
0005434244553	8355	Economy	6600.00
0005433784317	8355	Economy	6600.00
0005432666353	8355	Economy	6600.00
0005434244572	8355	Economy	6000.00
0005433784376	8355	Economy	6000.00
0005434244521	8355	Economy	6000.00
0005434244588	8355	Economy	6000.00
0005434244650	8355	Economy	6000.00
0005432666352	8355	Economy	6000.00
0005434244566	8355	Economy	6000.00
0005432659672	8355	Economy	6000.00
0005433784377	8355	Economy	6000.00
0005433784493	8355	Economy	6000.00
0005434244552	8355	Economy	6000.00
0005434244498	8355	Economy	6000.00
0005434244507	8355	Economy	6000.00
0005433784443	8355	Economy	6000.00
0005434244520	8355	Economy	6000.00
0005433784417	8355	Economy	6000.00
0005433784393	8355	Economy	6000.00
0005433784420	8355	Economy	6000.00
0005434244568	8355	Economy	6000.00
0005433784362	8355	Economy	6000.00
0005433784307	8355	Economy	6000.00
0005433784308	8355	Economy	6000.00
0005433784300	8355	Economy	6600.00
0005433784327	8355	Economy	6000.00
0005433784383	8355	Economy	6600.00
0005435269695	8355	Economy	6000.00
0005433784350	8355	Economy	6000.00
0005433784418	8355	Economy	6000.00
0005433784427	8355	Economy	6000.00
0005433784487	8355	Economy	6000.00
0005433784329	8355	Economy	6000.00
0005433784462	8355	Economy	6000.00
0005434244551	8355	Economy	6000.00
0005433784439	8355	Economy	6000.00
0005434244477	8355	Economy	6000.00
0005433784318	8355	Economy	6000.00
0005433784510	8355	Economy	6000.00
0005433784375	8355	Economy	6000.00
0005434244538	8355	Economy	6000.00
0005433784559	8355	Economy	6000.00
0005432666357	8355	Economy	6000.00
0005433784494	8355	Economy	6000.00
0005434244614	8355	Economy	6000.00
0005433613532	8356	Business	18000.00
0005433613416	8356	Business	18000.00
0005433613766	8356	Business	18000.00
0005433613420	8356	Business	18000.00
0005433613421	8356	Business	18000.00
0005433613434	8356	Business	18000.00
0005433613441	8356	Business	18000.00
0005433613672	8356	Economy	6600.00
0005433613512	8356	Economy	6600.00
0005433613642	8356	Economy	6600.00
0005433613538	8356	Economy	6600.00
0005433613496	8356	Economy	6000.00
0005433613593	8356	Economy	6000.00
0005433613768	8356	Economy	6000.00
0005433613724	8356	Economy	6000.00
0005433613594	8356	Economy	6000.00
0005433613391	8356	Economy	6000.00
0005433613712	8356	Economy	6000.00
0005433613428	8356	Economy	6000.00
0005433613417	8356	Economy	6000.00
0005433613442	8356	Economy	6000.00
0005433613433	8356	Economy	6000.00
0005433613604	8356	Economy	6000.00
0005433613492	8356	Economy	6000.00
0005433613711	8356	Economy	6000.00
0005433613533	8356	Economy	6000.00
0005433613511	8356	Economy	6000.00
0005433613491	8356	Economy	6000.00
0005433613462	8356	Economy	6000.00
0005433613722	8356	Economy	6000.00
0005433613723	8356	Economy	6000.00
0005433613823	8356	Economy	6000.00
0005433613586	8356	Economy	6000.00
0005433613440	8356	Economy	6000.00
0005433613603	8356	Economy	6000.00
0005433613558	8356	Economy	6000.00
0005433613602	8356	Economy	6000.00
0005433613419	8356	Economy	6000.00
0005433613408	8356	Economy	6000.00
0005433613615	8356	Economy	6000.00
0005433613657	8356	Economy	6000.00
0005433613643	8356	Economy	6000.00
0005433613435	8356	Economy	6000.00
0005433613601	8356	Economy	6000.00
0005433613824	8356	Economy	6000.00
0005433613767	8356	Economy	6000.00
0005433613409	8356	Economy	6000.00
0005433613670	8356	Economy	6000.00
0005433613461	8356	Economy	6000.00
0005433613390	8356	Economy	6000.00
0005433613825	8356	Economy	6000.00
0005433613516	8356	Economy	6000.00
0005434264702	8357	Business	18000.00
0005435006862	8357	Business	18000.00
0005432034759	8357	Business	18000.00
0005434229010	8357	Business	18000.00
0005432335954	8357	Business	18000.00
0005432034738	8357	Business	18000.00
0005432034760	8357	Business	18000.00
0005435006844	8357	Business	18000.00
0005435286581	8357	Business	18000.00
0005433689897	8357	Business	18000.00
0005432034751	8357	Business	18000.00
0005432034749	8357	Business	18000.00
0005433815354	8357	Business	18000.00
0005434149526	8357	Business	18000.00
0005432034745	8357	Business	18000.00
0005434149555	8357	Business	18000.00
0005434229060	8357	Business	18000.00
0005434229100	8357	Business	18000.00
0005434264797	8357	Business	18000.00
0005433815353	8357	Business	18000.00
0005432034755	8357	Business	18000.00
0005433534482	8357	Business	18000.00
0005434173454	8357	Business	18000.00
0005434264740	8357	Business	18000.00
0005434264789	8357	Business	18000.00
0005432034752	8357	Business	18000.00
0005433689896	8357	Business	18000.00
0005434149534	8357	Business	18000.00
0005434229043	8357	Economy	6600.00
0005432335944	8357	Economy	6600.00
0005433688796	8357	Economy	6600.00
0005434264705	8357	Economy	6600.00
0005434229045	8357	Economy	6600.00
0005434229065	8357	Economy	6000.00
0005435286587	8357	Economy	6000.00
0005435006860	8357	Economy	6000.00
0005435286579	8357	Economy	6000.00
0005432034742	8357	Economy	6000.00
0005433534483	8357	Economy	6000.00
0005435006855	8357	Economy	6000.00
0005432335950	8357	Economy	6000.00
0005435286582	8357	Economy	6000.00
0005432034758	8357	Economy	6000.00
0005435286585	8357	Economy	6000.00
0005432335951	8357	Economy	6000.00
0005432335953	8357	Economy	6000.00
0005433815352	8357	Economy	6000.00
0005432034746	8357	Economy	6000.00
0005435286580	8357	Economy	6000.00
0005434264690	8357	Economy	6000.00
0005432034753	8357	Economy	6000.00
0005435006848	8357	Economy	6000.00
0005434173459	8357	Economy	6000.00
0005432034736	8357	Economy	6000.00
0005434228979	8357	Economy	6000.00
0005434229138	8357	Economy	6000.00
0005434264827	8357	Economy	6000.00
0005432034740	8357	Economy	6000.00
0005434264788	8357	Economy	6000.00
0005434229109	8357	Economy	6000.00
0005435006853	8357	Economy	6000.00
0005434264701	8357	Economy	6000.00
0005433688795	8357	Economy	6000.00
0005434229071	8357	Economy	6000.00
0005434149542	8357	Economy	6000.00
0005434264778	8357	Economy	6000.00
0005434228991	8357	Economy	6000.00
0005434311204	8357	Economy	6000.00
0005435006859	8357	Economy	6000.00
0005434264816	8357	Economy	6000.00
0005435286584	8357	Economy	6000.00
0005435006852	8357	Economy	6000.00
0005432335949	8357	Economy	6000.00
0005435006845	8357	Economy	6000.00
0005434149520	8357	Economy	6000.00
0005434149556	8357	Economy	6000.00
0005432047521	8357	Economy	6000.00
0005432034750	8357	Economy	6000.00
0005432047524	8357	Economy	6000.00
0005434229102	8357	Economy	6000.00
0005434311205	8357	Economy	6000.00
0005432034741	8357	Economy	6000.00
0005434264688	8357	Economy	6000.00
0005435006864	8357	Economy	6000.00
0005432335948	8357	Economy	6000.00
0005434264739	8357	Economy	6000.00
0005432034737	8357	Economy	6000.00
0005434149543	8357	Economy	6000.00
0005434149553	8357	Economy	6600.00
0005433690912	8357	Economy	6600.00
0005434149567	8357	Economy	6600.00
0005432034761	8357	Economy	6600.00
0005432034756	8357	Economy	6600.00
0005433690913	8357	Economy	6000.00
0005434149551	8357	Economy	6000.00
0005435006856	8357	Economy	6000.00
0005435006867	8357	Economy	6000.00
0005435006858	8357	Economy	6600.00
0005434229011	8357	Economy	6000.00
0005435006851	8357	Economy	6000.00
0005434264722	8357	Economy	6000.00
0005434228995	8357	Economy	6000.00
0005435006847	8357	Economy	6000.00
0005434264692	8357	Economy	6000.00
0005434229056	8357	Economy	6000.00
0005432335947	8357	Economy	6000.00
0005432034743	8357	Economy	6000.00
0005432034754	8357	Economy	6000.00
0005435006846	8357	Economy	6000.00
0005434264828	8357	Economy	6000.00
0005434229101	8357	Economy	6000.00
0005435006861	8357	Economy	6000.00
0005434264677	8357	Economy	6000.00
0005434149528	8357	Economy	6000.00
0005435286586	8357	Economy	6000.00
0005435006843	8357	Economy	6000.00
0005434264795	8357	Economy	6000.00
0005435006842	8357	Economy	6000.00
0005434264689	8357	Economy	6000.00
0005435006854	8357	Economy	6000.00
0005432034748	8357	Economy	6000.00
0005434173472	8357	Economy	6000.00
0005435006866	8357	Economy	6000.00
0005434149521	8357	Economy	6000.00
0005434264703	8357	Economy	6000.00
0005432335946	8357	Economy	6000.00
0005434264685	8357	Economy	6000.00
0005434173458	8357	Economy	6000.00
0005434149527	8357	Economy	6000.00
0005432034744	8357	Economy	6000.00
0005435006849	8357	Economy	6000.00
0005434264737	8357	Economy	6000.00
0005432335943	8357	Economy	6000.00
0005432034739	8357	Economy	6000.00
0005434264704	8357	Economy	6000.00
0005433815351	8357	Economy	6000.00
0005432034735	8357	Economy	6000.00
0005433689895	8357	Economy	6000.00
0005434264770	8357	Economy	6000.00
0005432047523	8357	Economy	6000.00
0005434149557	8357	Economy	6000.00
0005435006865	8357	Economy	6000.00
0005432034757	8357	Economy	6000.00
0005434264738	8357	Economy	6000.00
0005434229044	8357	Economy	6000.00
0005432335945	8357	Economy	6000.00
0005434264773	8357	Economy	6000.00
0005434264777	8357	Economy	6000.00
0005432047522	8357	Economy	6000.00
0005434264787	8357	Economy	6000.00
0005435006850	8357	Economy	6000.00
0005434149580	8357	Economy	6000.00
0005432034747	8357	Economy	6000.00
0005434229061	8357	Economy	6000.00
0005434264700	8357	Economy	6000.00
0005432335952	8357	Economy	6000.00
0005434264748	8357	Economy	6000.00
0005435006857	8357	Economy	6000.00
0005435286583	8357	Economy	6000.00
0005435006863	8357	Economy	6000.00
0005434638866	12588	Economy	16200.00
0005433202264	12588	Economy	14800.00
0005433202255	12588	Economy	14800.00
0005434638863	12588	Economy	14800.00
0005434638968	12588	Economy	14800.00
0005434638950	12588	Economy	14800.00
0005433202254	12588	Economy	14800.00
0005434638947	12588	Economy	14800.00
0005434638951	12588	Economy	14800.00
0005434638982	12588	Economy	14800.00
0005433202260	12588	Economy	14800.00
0005433202263	12588	Economy	14800.00
0005434638983	12588	Economy	14800.00
0005434638898	12588	Economy	14800.00
0005433202262	12588	Economy	14800.00
0005434638896	12588	Economy	14800.00
0005433202267	12588	Economy	14800.00
0005433202256	12588	Economy	14800.00
0005433202266	12588	Economy	14800.00
0005434638988	12588	Economy	14800.00
0005434638931	12588	Economy	14800.00
0005433202258	12588	Economy	14800.00
0005434638848	12588	Economy	14800.00
0005434638989	12588	Economy	14800.00
0005433202259	12588	Economy	14800.00
0005433202253	12588	Economy	14800.00
0005433202261	12588	Economy	14800.00
0005434638984	12588	Economy	14800.00
0005434638908	12588	Economy	14800.00
0005434638895	12588	Economy	14800.00
0005433202257	12588	Economy	14800.00
0005433202265	12588	Economy	14800.00
0005434639111	23395	Economy	16200.00
0005433202146	23395	Economy	16200.00
0005434639120	23395	Economy	14800.00
0005433202125	23395	Economy	14800.00
0005434639108	23395	Economy	14800.00
0005433202121	23395	Economy	14800.00
0005434639123	23395	Economy	14800.00
0005434639105	23395	Economy	14800.00
0005434639104	23395	Economy	14800.00
0005434639125	23395	Economy	14800.00
0005433202172	23395	Economy	14800.00
0005434639110	23395	Economy	14800.00
0005434639122	23395	Economy	14800.00
0005434639119	23395	Economy	14800.00
0005434639118	23395	Economy	14800.00
0005434639115	23395	Economy	14800.00
0005434639116	23395	Economy	14800.00
0005434639103	23395	Economy	14800.00
0005434639107	23395	Economy	14800.00
0005434639101	23395	Economy	14800.00
0005433202120	23395	Economy	14800.00
0005433202106	23395	Economy	14800.00
0005434639124	23395	Economy	14800.00
0005433202126	23395	Economy	14800.00
0005434639114	23395	Economy	14800.00
0005434639121	23395	Economy	14800.00
0005434639117	23395	Economy	14800.00
0005434639099	23395	Economy	14800.00
0005432290609	23395	Economy	14800.00
0005434639102	23395	Economy	14800.00
0005432290607	23395	Economy	14800.00
0005434639109	23395	Economy	14800.00
0005433202115	23395	Economy	14800.00
0005433202129	23395	Economy	14800.00
0005434639113	23395	Economy	14800.00
0005434639112	23395	Economy	14800.00
0005434639100	23395	Economy	14800.00
0005433202107	23395	Economy	14800.00
0005432290608	23395	Economy	14800.00
0005434639106	23395	Economy	14800.00
0005432382504	21090	Business	18900.00
0005432382557	21090	Business	18900.00
0005432382643	21090	Business	18900.00
0005432328055	21090	Business	18900.00
0005432054284	21090	Business	18900.00
0005432382546	21090	Business	18900.00
0005432327972	21090	Business	18900.00
0005432054283	21090	Business	18900.00
0005432382563	21090	Business	18900.00
0005432327969	21090	Economy	6300.00
0005432382605	21090	Economy	6300.00
0005432327968	21090	Economy	6300.00
0005432328026	21090	Economy	6300.00
0005432382562	21090	Economy	6300.00
0005432328060	21090	Economy	6300.00
0005432382598	21090	Economy	6300.00
0005432327896	21090	Economy	6300.00
0005432382488	21090	Economy	6300.00
0005432328056	21090	Economy	6900.00
0005432054282	21090	Economy	6900.00
0005432328024	21090	Economy	6300.00
0005432328013	21090	Economy	6300.00
0005432328051	21090	Economy	6300.00
0005432054285	21090	Economy	6300.00
0005432382489	21090	Economy	6300.00
0005432382528	21090	Economy	6300.00
0005432327970	21090	Economy	6300.00
0005432382573	21090	Economy	6300.00
0005432382498	21090	Economy	6300.00
0005432382590	21090	Economy	6300.00
0005432327925	21090	Economy	6300.00
0005432328057	21090	Economy	6300.00
0005432327973	21090	Economy	6300.00
0005432382558	21090	Economy	6300.00
0005432382506	21090	Economy	6300.00
0005432382547	21090	Economy	6300.00
0005432327898	21090	Economy	6300.00
0005432382527	21090	Economy	6300.00
0005432328072	21090	Economy	6300.00
0005432382581	21090	Economy	6300.00
0005432382517	21090	Economy	6300.00
0005432382497	21090	Economy	6300.00
0005432328025	21090	Economy	6300.00
0005432328011	21090	Economy	6300.00
0005432327935	21090	Economy	6300.00
0005432328014	21090	Economy	6300.00
0005432328066	21090	Economy	6300.00
0005432382597	21090	Economy	6300.00
0005432382524	21090	Economy	6300.00
0005432327934	21090	Economy	6300.00
0005432327911	21090	Economy	6300.00
0005432382502	21090	Economy	6300.00
0005432328061	21090	Economy	6300.00
0005432382514	21090	Economy	6300.00
0005432382512	21090	Economy	6300.00
0005432328054	21090	Economy	6300.00
0005432382591	21090	Economy	6300.00
0005432328134	21090	Economy	6300.00
0005432382548	21090	Economy	6300.00
0005432382635	21090	Economy	6300.00
0005432382561	21090	Economy	6300.00
0005432328053	21090	Economy	6300.00
0005432382513	21090	Economy	6300.00
0005432328110	21090	Economy	6300.00
0005432382844	31255	Business	18900.00
0005432382884	31255	Business	18900.00
0005432328337	31255	Business	18900.00
0005432382866	31255	Business	18900.00
0005432328327	31255	Business	18900.00
0005432328342	31255	Business	18900.00
0005432382862	31255	Business	18900.00
0005432328326	31255	Business	18900.00
0005432328343	31255	Business	18900.00
0005432328352	31255	Business	18900.00
0005432328315	31255	Business	18900.00
0005432382845	31255	Business	18900.00
0005432382852	31255	Economy	6300.00
0005432382874	31255	Economy	6300.00
0005432328355	31255	Economy	6300.00
0005432328347	31255	Economy	6300.00
0005432382882	31255	Economy	6300.00
0005432328356	31255	Economy	6300.00
0005432287148	31255	Economy	6300.00
0005432382867	31255	Economy	6300.00
0005432382856	31255	Economy	6300.00
0005432328354	31255	Economy	6300.00
0005432382865	31255	Economy	6900.00
0005432328332	31255	Economy	6900.00
0005432382849	31255	Economy	6900.00
0005432382878	31255	Economy	6900.00
0005432328335	31255	Economy	6300.00
0005432287149	31255	Economy	6300.00
0005432328321	31255	Economy	6300.00
0005432382861	31255	Economy	6300.00
0005432382855	31255	Economy	6300.00
0005432287150	31255	Economy	6300.00
0005432382871	31255	Economy	6300.00
0005432382869	31255	Economy	6300.00
0005432328349	31255	Economy	6300.00
0005432328331	31255	Economy	6300.00
0005432328344	31255	Economy	6300.00
0005432328316	31255	Economy	6300.00
0005432382885	31255	Economy	6300.00
0005432328314	31255	Economy	6300.00
0005432328353	31255	Economy	6300.00
0005432328319	31255	Economy	6300.00
0005432328329	31255	Economy	6300.00
0005432382877	31255	Economy	6300.00
0005432328323	31255	Economy	6300.00
0005432328339	31255	Economy	6300.00
0005432328348	31255	Economy	6300.00
0005432328330	31255	Economy	6300.00
0005432382848	31255	Economy	6300.00
0005432382880	31255	Economy	6300.00
0005432382868	31255	Economy	6300.00
0005432382879	31255	Economy	6300.00
0005432382863	31255	Economy	6300.00
0005432287146	31255	Economy	6300.00
0005432382883	31255	Economy	6300.00
0005432382859	31255	Economy	6300.00
0005432328325	31255	Economy	6300.00
0005432382847	31255	Economy	6300.00
0005432328336	31255	Economy	6300.00
0005432328345	31255	Economy	6300.00
0005432328318	31255	Economy	6300.00
0005432328313	31255	Economy	6300.00
0005432382851	31255	Economy	6300.00
0005432382850	31255	Economy	6300.00
0005432328333	31255	Economy	6300.00
0005432328341	31255	Economy	6300.00
0005432382881	31255	Economy	6300.00
0005432328351	31255	Economy	6300.00
0005432328317	31255	Economy	6300.00
0005432328358	31255	Economy	6300.00
0005432328340	31255	Economy	6300.00
0005432328350	31255	Economy	6300.00
0005432382853	31255	Economy	6300.00
0005432382858	31255	Economy	6300.00
0005432382872	31255	Economy	6300.00
0005432328359	31255	Economy	6300.00
0005432382875	31255	Economy	6300.00
0005432328338	31255	Economy	6300.00
0005432382876	31255	Economy	6300.00
0005432328320	31255	Economy	6300.00
0005432382873	31255	Economy	6300.00
0005432382857	31255	Economy	6300.00
0005432328328	31255	Economy	6300.00
0005432328357	31255	Economy	6300.00
0005432382864	31255	Economy	6300.00
0005432328322	31255	Economy	6300.00
0005432382860	31255	Economy	6300.00
0005432328324	31255	Economy	6300.00
0005432287147	31255	Economy	6300.00
0005432382846	31255	Economy	6300.00
0005432328334	31255	Economy	6300.00
0005432382870	31255	Economy	6300.00
0005432328346	31255	Economy	6300.00
0005432382854	31255	Economy	6300.00
0005432424092	13379	Business	12700.00
0005432424068	13379	Business	12700.00
0005432424062	13379	Business	12700.00
0005432424069	13379	Business	12700.00
0005432424086	13379	Business	12700.00
0005432424087	13379	Economy	4200.00
0005432424093	13379	Economy	4700.00
0005432424078	13379	Economy	4700.00
0005432424075	13379	Economy	4200.00
0005432424085	13379	Economy	4200.00
0005432424064	13379	Economy	4200.00
0005432424058	13379	Economy	4200.00
0005432424088	13379	Economy	4200.00
0005432424060	13379	Economy	4200.00
0005432424079	13379	Economy	4200.00
0005432424070	13379	Economy	4200.00
0005432424076	13379	Economy	4200.00
0005432424072	13379	Economy	4200.00
0005432424073	13379	Economy	4200.00
0005432424074	13379	Economy	4200.00
0005432424071	13379	Economy	4200.00
0005432424059	13379	Economy	4200.00
0005432424084	13379	Economy	4200.00
0005432424082	13379	Economy	4200.00
0005432424094	13379	Economy	4200.00
0005432424067	13379	Economy	4200.00
0005432424080	13379	Economy	4200.00
0005432424063	13379	Economy	4200.00
0005432424089	13379	Economy	4200.00
0005432424065	13379	Economy	4200.00
0005432424081	13379	Economy	4200.00
0005432424096	13379	Economy	4200.00
0005432424066	13379	Economy	4200.00
0005432424097	13379	Economy	4200.00
0005432424090	13379	Economy	4200.00
0005432424083	13379	Economy	4200.00
0005432424095	13379	Economy	4200.00
0005432424061	13379	Economy	4200.00
0005432424091	13379	Economy	4200.00
0005432424077	13379	Economy	4200.00
0005432423706	30749	Business	12700.00
0005432423722	30749	Business	12700.00
0005432423723	30749	Business	12700.00
0005432423689	30749	Business	12700.00
0005432423668	30749	Economy	4200.00
0005432423613	30749	Economy	4200.00
0005432423731	30749	Economy	4200.00
0005432423730	30749	Economy	4700.00
0005432423653	30749	Economy	4700.00
0005432423627	30749	Economy	4700.00
0005432423724	30749	Economy	4200.00
0005432423636	30749	Economy	4200.00
0005432423631	30749	Economy	4200.00
0005432423614	30749	Economy	4200.00
0005432423681	30749	Economy	4200.00
0005432423628	30749	Economy	4200.00
0005432423680	30749	Economy	4200.00
0005432423690	30749	Economy	4200.00
0005432423649	30749	Economy	4200.00
0005432423748	30749	Economy	4200.00
0005432423632	30749	Economy	4200.00
0005432423729	30749	Economy	4200.00
0005432423735	30749	Economy	4200.00
0005432423707	30749	Economy	4200.00
0005432423697	30749	Economy	4200.00
0005432423721	30749	Economy	4200.00
0005432423669	30749	Economy	4200.00
0005432423660	30749	Economy	4200.00
0005432423762	30749	Economy	4200.00
0005434186162	9581	Business	32600.00
0005432817253	9581	Business	32600.00
0005432822149	9581	Business	32600.00
0005432822144	9581	Business	32600.00
0005432288963	9581	Business	32600.00
0005432817268	9581	Business	32600.00
0005432817261	9581	Business	32600.00
0005432817242	9581	Business	32600.00
0005432817257	9581	Economy	10900.00
0005434448290	9581	Economy	10900.00
0005432901359	9581	Economy	10900.00
0005434186153	9581	Economy	10900.00
0005432822150	9581	Economy	10900.00
0005432817259	9581	Economy	10900.00
0005432817241	9581	Economy	10900.00
0005432817250	9581	Economy	11900.00
0005434186161	9581	Economy	11900.00
0005434157361	9581	Economy	10900.00
0005432901388	9581	Economy	10900.00
0005432817246	9581	Economy	10900.00
0005432817245	9581	Economy	10900.00
0005434157373	9581	Economy	10900.00
0005432817244	9581	Economy	10900.00
0005432817264	9581	Economy	10900.00
0005432817252	9581	Economy	10900.00
0005432817248	9581	Economy	10900.00
0005432901296	9581	Economy	10900.00
0005432901323	9581	Economy	10900.00
0005432288961	9581	Economy	10900.00
0005434157353	9581	Economy	10900.00
0005432817270	9581	Economy	10900.00
0005432817263	9581	Economy	10900.00
0005432817256	9581	Economy	10900.00
0005432901322	9581	Economy	10900.00
0005432901337	9581	Economy	10900.00
0005432817269	9581	Economy	10900.00
0005432288962	9581	Economy	10900.00
0005432817247	9581	Economy	10900.00
0005432817258	9581	Economy	10900.00
0005432817262	9581	Economy	10900.00
0005432901328	9581	Economy	10900.00
0005432901355	9581	Economy	10900.00
0005432901362	9581	Economy	10900.00
0005432817255	9581	Economy	10900.00
0005432901344	9581	Economy	10900.00
0005432817249	9581	Economy	10900.00
0005432817266	9581	Economy	10900.00
0005432901360	9581	Economy	10900.00
0005432817254	9581	Economy	10900.00
0005434448291	9581	Economy	10900.00
0005432817251	9581	Economy	10900.00
0005432817260	9581	Economy	10900.00
0005432822145	9581	Economy	10900.00
0005432817265	9581	Economy	10900.00
0005432817267	9581	Economy	10900.00
0005432822146	9581	Economy	10900.00
0005432822143	9581	Economy	10900.00
0005432817243	9581	Economy	10900.00
0005434186147	9581	Economy	10900.00
0005434448292	9581	Economy	10900.00
0005434157372	9581	Economy	10900.00
0005432901343	9581	Economy	10900.00
0005432822147	9581	Economy	10900.00
0005434157347	9581	Economy	10900.00
0005434157352	9581	Economy	10900.00
0005434157362	9581	Economy	10900.00
0005432822148	9581	Economy	10900.00
0005432901482	28979	Business	32600.00
0005432817062	28979	Business	32600.00
0005432817065	28979	Business	32600.00
0005432822103	28979	Business	32600.00
0005432901489	28979	Business	32600.00
0005432901483	28979	Business	32600.00
0005434157422	28979	Business	32600.00
0005434157420	28979	Business	32600.00
0005432002061	28979	Economy	10900.00
0005434157426	28979	Economy	10900.00
0005432817091	28979	Economy	10900.00
0005432817003	28979	Economy	10900.00
0005432901490	28979	Economy	10900.00
0005432817040	28979	Economy	10900.00
0005432901491	28979	Economy	10900.00
0005432901484	28979	Economy	10900.00
0005432901481	28979	Economy	11900.00
0005432816946	28979	Economy	11900.00
0005432817133	28979	Economy	11900.00
0005432816998	28979	Economy	11900.00
0005432817121	28979	Economy	10900.00
0005432822102	28979	Economy	10900.00
0005432901487	28979	Economy	10900.00
0005434186176	28979	Economy	10900.00
0005434157425	28979	Economy	10900.00
0005432901475	28979	Economy	10900.00
0005432817035	28979	Economy	10900.00
0005432817002	28979	Economy	10900.00
0005434186175	28979	Economy	10900.00
0005432817005	28979	Economy	10900.00
0005432817122	28979	Economy	10900.00
0005432822099	28979	Economy	10900.00
0005432901477	28979	Economy	10900.00
0005432822064	28979	Economy	10900.00
0005432901480	28979	Economy	10900.00
0005434157421	28979	Economy	10900.00
0005432822104	28979	Economy	10900.00
0005432816947	28979	Economy	10900.00
0005432822076	28979	Economy	10900.00
0005432816996	28979	Economy	10900.00
0005432901476	28979	Economy	10900.00
0005432817019	28979	Economy	10900.00
0005432901474	28979	Economy	10900.00
0005434186177	28979	Economy	10900.00
0005432816967	28979	Economy	10900.00
0005432901485	28979	Economy	10900.00
0005432816982	28979	Economy	10900.00
0005432817001	28979	Economy	10900.00
0005432822069	28979	Economy	10900.00
0005434448257	28979	Economy	10900.00
0005432901473	28979	Economy	10900.00
0005432817072	28979	Economy	10900.00
0005432817004	28979	Economy	10900.00
0005432901479	28979	Economy	10900.00
0005434157427	28979	Economy	10900.00
0005432822105	28979	Economy	10900.00
0005432901486	28979	Economy	10900.00
0005432901488	28979	Economy	10900.00
0005432817093	28979	Economy	10900.00
0005434157424	28979	Economy	10900.00
0005432816997	28979	Economy	10900.00
0005432817092	28979	Economy	10900.00
0005432817029	28979	Economy	10900.00
0005434157419	28979	Economy	10900.00
0005432901478	28979	Economy	10900.00
0005434157423	28979	Economy	10900.00
0005432816999	28979	Economy	10900.00
0005432816973	28979	Economy	10900.00
0005432817064	28979	Economy	10900.00
0005432817063	28979	Economy	10900.00
0005432817028	28979	Economy	10900.00
0005432613834	15041	Economy	11000.00
0005435841081	15041	Economy	11000.00
0005432613831	15041	Economy	11000.00
0005435841085	15041	Economy	11000.00
0005432613833	15041	Economy	11000.00
0005432611680	15041	Economy	11000.00
0005435841086	15041	Economy	11000.00
0005432611681	15041	Economy	11000.00
0005432613832	15041	Economy	11000.00
0005432611682	15041	Economy	11000.00
0005432611683	15041	Economy	11000.00
0005435842324	31610	Economy	11000.00
0005435841815	31610	Economy	11000.00
0005432607503	31610	Economy	11000.00
0005435841814	31610	Economy	11000.00
0005435842323	31610	Economy	11000.00
0005435841816	31610	Economy	11000.00
0005432611643	31610	Economy	11000.00
0005432607504	31610	Economy	11000.00
0005432607501	31610	Economy	11000.00
0005433568595	11889	Business	105900.00
0005433568598	11889	Business	105900.00
0005433568549	11889	Business	105900.00
0005433568603	11889	Business	105900.00
0005433568602	11889	Business	105900.00
0005433568562	11889	Business	105900.00
0005433568575	11889	Business	105900.00
0005433568571	11889	Business	105900.00
0005433568578	11889	Business	105900.00
0005433568599	11889	Business	105900.00
0005433568605	11889	Business	105900.00
0005432947882	11889	Business	105900.00
0005433568589	11889	Business	105900.00
0005433568569	11889	Business	105900.00
0005433568573	11889	Business	105900.00
0005433568561	11889	Business	105900.00
0005433568572	11889	Economy	35300.00
0005433568548	11889	Economy	35300.00
0005433568594	11889	Economy	35300.00
0005433568555	11889	Economy	35300.00
0005433568574	11889	Economy	35300.00
0005432947932	11889	Economy	35300.00
0005433568544	11889	Economy	35300.00
0005433568556	11889	Economy	35300.00
0005432947956	11889	Economy	38800.00
0005433568587	11889	Economy	38800.00
0005433568551	11889	Economy	35300.00
0005433568552	11889	Economy	35300.00
0005432947953	11889	Economy	35300.00
0005432947881	11889	Economy	35300.00
0005432947823	11889	Economy	35300.00
0005433568576	11889	Economy	35300.00
0005433568600	11889	Economy	35300.00
0005432947915	11889	Economy	35300.00
0005433568550	11889	Economy	35300.00
0005433568592	11889	Economy	35300.00
0005433568559	11889	Economy	35300.00
0005432947779	11889	Economy	35300.00
0005433568554	11889	Economy	35300.00
0005433568546	11889	Economy	35300.00
0005432947917	11889	Economy	35300.00
0005433568604	11889	Economy	35300.00
0005433568593	11889	Economy	35300.00
0005433568590	11889	Economy	35300.00
0005433568597	11889	Economy	35300.00
0005432947857	11889	Economy	35300.00
0005433568568	11889	Economy	35300.00
0005433568547	11889	Economy	35300.00
0005433568584	11889	Economy	35300.00
0005432947916	11889	Economy	35300.00
0005433568596	11889	Economy	35300.00
0005433568557	11889	Economy	35300.00
0005433568582	11889	Economy	35300.00
0005433568601	11889	Economy	35300.00
0005433568566	11889	Economy	35300.00
0005433568580	11889	Economy	35300.00
0005432947955	11889	Economy	35300.00
0005433568560	11889	Economy	35300.00
0005433568579	11889	Economy	35300.00
0005433568558	11889	Economy	35300.00
0005433568570	11889	Economy	35300.00
0005432947954	11889	Economy	35300.00
0005432947825	11889	Economy	35300.00
0005433568581	11889	Economy	35300.00
0005433568565	11889	Economy	35300.00
0005433568563	11889	Economy	35300.00
0005433568564	11889	Economy	35300.00
0005433568545	11889	Economy	35300.00
0005432947899	11889	Economy	35300.00
0005433568583	11889	Economy	35300.00
0005432947803	11889	Economy	35300.00
0005433568577	11889	Economy	35300.00
0005433568567	11889	Economy	35300.00
0005433568585	11889	Economy	35300.00
0005433568553	11889	Economy	35300.00
0005433568591	11889	Economy	35300.00
0005432947824	11889	Economy	35300.00
0005433568588	11889	Economy	35300.00
0005433568586	11889	Economy	35300.00
0005432947931	11889	Economy	35300.00
0005432948207	25323	Business	105900.00
0005433568180	25323	Business	105900.00
0005433568053	25323	Business	105900.00
0005433568162	25323	Business	105900.00
0005433568186	25323	Business	105900.00
0005433568098	25323	Business	105900.00
0005433568048	25323	Business	105900.00
0005433568182	25323	Business	105900.00
0005432948194	25323	Business	105900.00
0005433568059	25323	Business	105900.00
0005432948213	25323	Business	105900.00
0005432948185	25323	Business	105900.00
0005432948215	25323	Business	105900.00
0005433568066	25323	Business	105900.00
0005433568159	25323	Business	105900.00
0005432948191	25323	Economy	35300.00
0005432948216	25323	Economy	35300.00
0005433568018	25323	Economy	35300.00
0005432948188	25323	Economy	35300.00
0005433568198	25323	Economy	35300.00
0005432948187	25323	Economy	35300.00
0005432948181	25323	Economy	35300.00
0005432948202	25323	Economy	35300.00
0005432948190	25323	Economy	35300.00
0005432948203	25323	Economy	38800.00
0005432948184	25323	Economy	38800.00
0005433568140	25323	Economy	38800.00
0005432948183	25323	Economy	35300.00
0005433568099	25323	Economy	35300.00
0005432948201	25323	Economy	35300.00
0005433568015	25323	Economy	35300.00
0005433568029	25323	Economy	35300.00
0005433568215	25323	Economy	35300.00
0005432948189	25323	Economy	35300.00
0005432948200	25323	Economy	35300.00
0005432948219	25323	Economy	35300.00
0005433568183	25323	Economy	35300.00
0005432948198	25323	Economy	35300.00
0005433568152	25323	Economy	35300.00
0005432948204	25323	Economy	35300.00
0005432948211	25323	Economy	35300.00
0005433568028	25323	Economy	35300.00
0005433568108	25323	Economy	35300.00
0005433568160	25323	Economy	35300.00
0005433568217	25323	Economy	35300.00
0005433568104	25323	Economy	35300.00
0005432948195	25323	Economy	35300.00
0005432948214	25323	Economy	35300.00
0005432948197	25323	Economy	35300.00
0005432948220	25323	Economy	35300.00
0005433568103	25323	Economy	35300.00
0005433568155	25323	Economy	35300.00
0005432948206	25323	Economy	35300.00
0005432948199	25323	Economy	35300.00
0005432948182	25323	Economy	35300.00
0005433568185	25323	Economy	35300.00
0005432948212	25323	Economy	35300.00
0005432948205	25323	Economy	35300.00
0005433568030	25323	Economy	35300.00
0005433568101	25323	Economy	35300.00
0005432948208	25323	Economy	35300.00
0005433568120	25323	Economy	35300.00
0005433568121	25323	Economy	35300.00
0005432948210	25323	Economy	35300.00
0005433568058	25323	Economy	35300.00
0005432948193	25323	Economy	35300.00
0005433568175	25323	Economy	35300.00
0005433568041	25323	Economy	35300.00
0005433568019	25323	Economy	35300.00
0005433568031	25323	Economy	35300.00
0005433568218	25323	Economy	35300.00
0005433568204	25323	Economy	35300.00
0005432948209	25323	Economy	35300.00
0005433568184	25323	Economy	35300.00
0005433568096	25323	Economy	35300.00
0005433568256	25323	Economy	35300.00
0005433568224	25323	Economy	35300.00
0005433568097	25323	Economy	35300.00
0005433568063	25323	Economy	35300.00
0005432948186	25323	Economy	35300.00
0005433568134	25323	Economy	35300.00
0005433568156	25323	Economy	35300.00
0005433568179	25323	Economy	35300.00
0005432948221	25323	Economy	35300.00
0005432948218	25323	Economy	35300.00
0005433568016	25323	Economy	35300.00
0005432948192	25323	Economy	35300.00
0005432948217	25323	Economy	35300.00
0005432948196	25323	Economy	35300.00
0005433808342	30820	Business	117400.00
0005432430807	30820	Business	117400.00
0005433808345	30820	Economy	39100.00
0005433808347	30820	Economy	43000.00
0005433808341	30820	Economy	39100.00
0005433812875	30820	Economy	39100.00
0005433808340	30820	Economy	39100.00
0005434026670	30820	Economy	39100.00
0005433808339	30820	Economy	39100.00
0005433808344	30820	Economy	39100.00
0005433808343	30820	Economy	39100.00
0005433812879	30820	Economy	39100.00
0005432430803	30820	Economy	39100.00
0005433812876	30820	Economy	39100.00
0005433808346	30820	Economy	39100.00
0005433812880	30820	Economy	39100.00
0005433812878	30820	Economy	39100.00
0005433812877	30820	Economy	39100.00
0005433808338	30820	Economy	39100.00
0005432430802	30820	Economy	39100.00
0005432430813	30820	Economy	39100.00
0005434026671	30820	Economy	39100.00
0005433808337	30820	Economy	39100.00
0005434026669	30820	Economy	39100.00
0005433808336	30820	Economy	39100.00
0005433812874	30820	Economy	39100.00
0005432114178	5375	Business	67200.00
0005434654463	5375	Business	67200.00
0005434656542	5375	Business	67200.00
0005434654485	5375	Business	67200.00
0005434654482	5375	Business	67200.00
0005434654487	5375	Economy	22400.00
0005434654476	5375	Economy	22400.00
0005434654470	5375	Economy	22400.00
0005434654473	5375	Economy	22400.00
0005435340016	5375	Economy	24600.00
0005434654486	5375	Economy	24600.00
0005434656541	5375	Economy	24600.00
0005434654464	5375	Economy	24600.00
0005434654467	5375	Economy	22400.00
0005435340014	5375	Economy	22400.00
0005434654477	5375	Economy	22400.00
0005435340066	5375	Economy	22400.00
0005435340061	5375	Economy	22400.00
0005434654474	5375	Economy	22400.00
0005434654488	5375	Economy	22400.00
0005435340015	5375	Economy	22400.00
0005434654466	5375	Economy	22400.00
0005434654465	5375	Economy	22400.00
0005434654483	5375	Economy	22400.00
0005434654471	5375	Economy	22400.00
0005435340035	5375	Economy	22400.00
0005434654478	5375	Economy	22400.00
0005435555343	5375	Economy	22400.00
0005434654479	5375	Economy	22400.00
0005432114180	5375	Economy	22400.00
0005434654462	5375	Economy	22400.00
0005435340060	5375	Economy	22400.00
0005434654468	5375	Economy	22400.00
0005434654469	5375	Economy	22400.00
0005434654481	5375	Economy	22400.00
0005435340080	5375	Economy	22400.00
0005435340081	5375	Economy	22400.00
0005435340013	5375	Economy	22400.00
0005434654472	5375	Economy	22400.00
0005434654461	5375	Economy	22400.00
0005432114179	5375	Economy	22400.00
0005434654480	5375	Economy	22400.00
0005434654484	5375	Economy	22400.00
0005434654475	5375	Economy	22400.00
0005435340145	12540	Business	67200.00
0005435340150	12540	Business	67200.00
0005434654337	12540	Business	67200.00
0005434654241	12540	Business	67200.00
0005434654256	12540	Business	67200.00
0005434654269	12540	Business	67200.00
0005434654228	12540	Business	67200.00
0005434654251	12540	Economy	22400.00
0005434654227	12540	Economy	22400.00
0005434654203	12540	Economy	22400.00
0005435340149	12540	Economy	22400.00
0005435340153	12540	Economy	22400.00
0005434654304	12540	Economy	22400.00
0005434654268	12540	Economy	24600.00
0005434654257	12540	Economy	24600.00
0005434654211	12540	Economy	24600.00
0005434654177	12540	Economy	22400.00
0005435340146	12540	Economy	22400.00
0005434654163	12540	Economy	22400.00
0005434654260	12540	Economy	22400.00
0005435340157	12540	Economy	22400.00
0005435340158	12540	Economy	22400.00
0005434654164	12540	Economy	22400.00
0005435340156	12540	Economy	22400.00
0005435340155	12540	Economy	22400.00
0005434654348	12540	Economy	22400.00
0005434654298	12540	Economy	22400.00
0005435340154	12540	Economy	22400.00
0005434654214	12540	Economy	22400.00
0005434654328	12540	Economy	22400.00
0005434654297	12540	Economy	22400.00
0005434654193	12540	Economy	22400.00
0005434654199	12540	Economy	22400.00
0005434654327	12540	Economy	22400.00
0005434654162	12540	Economy	22400.00
0005435340147	12540	Economy	22400.00
0005434654168	12540	Economy	22400.00
0005435340144	12540	Economy	22400.00
0005434654178	12540	Economy	22400.00
0005435340152	12540	Economy	22400.00
0005434654165	12540	Economy	22400.00
0005434654383	12540	Economy	22400.00
0005434654240	12540	Economy	22400.00
0005434654210	12540	Economy	22400.00
0005435340159	12540	Economy	22400.00
0005435340151	12540	Economy	22400.00
0005435340148	12540	Economy	22400.00
0005434654338	12540	Economy	22400.00
0005435555356	12540	Economy	22400.00
0005434654189	12540	Economy	22400.00
0005434654179	12540	Economy	22400.00
0005433656642	7420	Business	32000.00
0005433715613	7420	Business	32000.00
0005433715599	7420	Business	32000.00
0005433715626	7420	Business	32000.00
0005433715605	7420	Business	32000.00
0005433690911	7420	Business	32000.00
0005433715607	7420	Business	32000.00
0005433722168	7420	Economy	10700.00
0005433715587	7420	Economy	10700.00
0005433715584	7420	Economy	10700.00
0005433715597	7420	Economy	10700.00
0005432078065	7420	Economy	10700.00
0005433689894	7420	Economy	10700.00
0005433689893	7420	Economy	10700.00
0005433715627	7420	Economy	10700.00
0005432078067	7420	Economy	10700.00
0005433715594	7420	Economy	10700.00
0005433715621	7420	Economy	10700.00
0005433715602	7420	Economy	10700.00
0005433715590	7420	Economy	10700.00
0005433715623	7420	Economy	10700.00
0005433719114	7420	Economy	10700.00
0005433715578	7420	Economy	10700.00
0005433715586	7420	Economy	10700.00
0005433715625	7420	Economy	10700.00
0005433690910	7420	Economy	10700.00
0005433715614	7420	Economy	10700.00
0005433715591	7420	Economy	10700.00
0005433688794	7420	Economy	10700.00
0005433715580	7420	Economy	11700.00
0005433715581	7420	Economy	11700.00
0005433715620	7420	Economy	11700.00
0005433690909	7420	Economy	11700.00
0005433688793	7420	Economy	10700.00
0005433715608	7420	Economy	10700.00
0005433715612	7420	Economy	10700.00
0005433715618	7420	Economy	10700.00
0005433715606	7420	Economy	10700.00
0005433715615	7420	Economy	10700.00
0005432078070	7420	Economy	10700.00
0005433715610	7420	Economy	10700.00
0005433715604	7420	Economy	10700.00
0005433715583	7420	Economy	10700.00
0005433715619	7420	Economy	10700.00
0005432078069	7420	Economy	10700.00
0005433722167	7420	Economy	10700.00
0005433715577	7420	Economy	10700.00
0005433715617	7420	Economy	10700.00
0005433715579	7420	Economy	10700.00
0005433656643	7420	Economy	10700.00
0005433715592	7420	Economy	10700.00
0005433715611	7420	Economy	10700.00
0005433715593	7420	Economy	10700.00
0005432078068	7420	Economy	10700.00
0005433715595	7420	Economy	10700.00
0005433715616	7420	Economy	10700.00
0005433715609	7420	Economy	10700.00
0005433715603	7420	Economy	10700.00
0005432078066	7420	Economy	10700.00
0005433715588	7420	Economy	10700.00
0005433715600	7420	Economy	10700.00
0005433722169	7420	Economy	10700.00
0005433715622	7420	Economy	10700.00
0005433715585	7420	Economy	10700.00
0005433688792	7420	Economy	10700.00
0005433656644	7420	Economy	10700.00
0005433719113	7420	Economy	10700.00
0005435266074	7420	Economy	10700.00
0005433715598	7420	Economy	10700.00
0005433715582	7420	Economy	10700.00
0005433715589	7420	Economy	10700.00
0005433715601	7420	Economy	10700.00
0005433715624	7420	Economy	10700.00
0005433715596	7420	Economy	10700.00
0005432428902	29248	Business	32000.00
0005433715119	29248	Business	32000.00
0005433715145	29248	Business	32000.00
0005433715282	29248	Business	32000.00
0005433719082	29248	Business	32000.00
0005433722103	29248	Business	32000.00
0005433715313	29248	Economy	10700.00
0005433722115	29248	Economy	10700.00
0005433715180	29248	Economy	10700.00
0005433715364	29248	Economy	10700.00
0005433715143	29248	Economy	10700.00
0005433715188	29248	Economy	10700.00
0005432006739	29248	Economy	10700.00
0005433715209	29248	Economy	10700.00
0005433715210	29248	Economy	10700.00
0005433715144	29248	Economy	10700.00
0005433719089	29248	Economy	10700.00
0005433715298	29248	Economy	10700.00
0005433715208	29248	Economy	10700.00
0005433715108	29248	Economy	10700.00
0005433715349	29248	Economy	10700.00
0005435266120	29248	Economy	10700.00
0005433715135	29248	Economy	11700.00
0005432428905	29248	Economy	10700.00
0005433685494	29248	Economy	10700.00
0005433715146	29248	Economy	10700.00
0005433715175	29248	Economy	10700.00
0005433715174	29248	Economy	10700.00
0005432006740	29248	Economy	10700.00
0005433715077	29248	Economy	10700.00
0005433715110	29248	Economy	10700.00
0005433715283	29248	Economy	10700.00
0005433715288	29248	Economy	10700.00
0005433715151	29248	Economy	10700.00
0005432428903	29248	Economy	10700.00
0005433715150	29248	Economy	10700.00
0005433715226	29248	Economy	10700.00
0005433656616	29248	Economy	10700.00
0005433715117	29248	Economy	10700.00
0005433715296	29248	Economy	10700.00
0005433715279	29248	Economy	10700.00
0005433715225	29248	Economy	10700.00
0005433715109	29248	Economy	10700.00
0005433715085	29248	Economy	10700.00
0005435266119	29248	Economy	10700.00
0005433715245	29248	Economy	10700.00
0005433715134	29248	Economy	10700.00
0005433722106	29248	Economy	10700.00
0005433715215	29248	Economy	10700.00
0005433715224	29248	Economy	10700.00
0005432428904	29248	Economy	10700.00
0005433715136	29248	Economy	10700.00
0005433715345	29248	Economy	10700.00
0005433715129	29248	Economy	10700.00
0005433715419	29248	Economy	10700.00
0005433715297	29248	Economy	10700.00
0005435266118	29248	Economy	10700.00
0005433715173	29248	Economy	10700.00
0005433715363	29248	Economy	10700.00
0005433715096	29248	Economy	10700.00
0005434181982	8650	Business	36500.00
0005434095165	8650	Business	36500.00
0005434182057	8650	Business	36500.00
0005434184632	8650	Business	36500.00
0005434095166	8650	Economy	12200.00
0005434182015	8650	Economy	12200.00
0005434181969	8650	Economy	12200.00
0005434095171	8650	Economy	12200.00
0005434095176	8650	Economy	12200.00
0005434095170	8650	Economy	13400.00
0005434182012	8650	Economy	13400.00
0005434095172	8650	Economy	12200.00
0005434095175	8650	Economy	12200.00
0005434181970	8650	Economy	12200.00
0005434182008	8650	Economy	12200.00
0005434181958	8650	Economy	12200.00
0005434184631	8650	Economy	12200.00
0005434095168	8650	Economy	12200.00
0005434182014	8650	Economy	12200.00
0005434182004	8650	Economy	12200.00
0005434095169	8650	Economy	12200.00
0005434095163	8650	Economy	12200.00
0005434095167	8650	Economy	12200.00
0005434095164	8650	Economy	12200.00
0005434182003	8650	Economy	12200.00
0005434095173	8650	Economy	12200.00
0005434181983	8650	Economy	12200.00
0005434095174	8650	Economy	12200.00
0005434182085	11639	Business	36500.00
0005434184648	11639	Business	36500.00
0005434095128	11639	Business	36500.00
0005434182093	11639	Business	36500.00
0005434182088	11639	Economy	12200.00
0005434182092	11639	Economy	12200.00
0005434182094	11639	Economy	12200.00
0005434095065	11639	Economy	12200.00
0005434184649	11639	Economy	13400.00
0005434182087	11639	Economy	13400.00
0005434095064	11639	Economy	12200.00
0005434182096	11639	Economy	12200.00
0005434326259	11639	Economy	12200.00
0005434095113	11639	Economy	12200.00
0005434326260	11639	Economy	12200.00
0005434182095	11639	Economy	12200.00
0005434182086	11639	Economy	12200.00
0005434182097	11639	Economy	12200.00
0005434182091	11639	Economy	12200.00
0005434095129	11639	Economy	12200.00
0005434095049	11639	Economy	12200.00
0005434095112	11639	Economy	12200.00
0005434182090	11639	Economy	12200.00
0005434095083	11639	Economy	12200.00
0005434184647	11639	Economy	12200.00
0005434095072	11639	Economy	12200.00
0005434095084	11639	Economy	12200.00
0005434143701	11639	Economy	12200.00
0005434182098	11639	Economy	12200.00
0005434095073	11639	Economy	12200.00
0005434182089	11639	Economy	12200.00
0005434183563	11639	Economy	12200.00
0005433397261	1462	Business	33000.00
0005433397180	1462	Business	33000.00
0005433397186	1462	Business	33000.00
0005433397281	1462	Business	33000.00
0005433397519	1462	Business	33000.00
0005435732243	1462	Business	33000.00
0005435732237	1462	Business	33000.00
0005433397253	1462	Business	33000.00
0005433397400	1462	Economy	11000.00
0005435732236	1462	Economy	11000.00
0005435732247	1462	Economy	11000.00
0005433456938	1462	Economy	11000.00
0005433456941	1462	Economy	11000.00
0005433397328	1462	Economy	11000.00
0005433397294	1462	Economy	11000.00
0005433397349	1462	Economy	11000.00
0005433397193	1462	Economy	12100.00
0005435732246	1462	Economy	12100.00
0005435732242	1462	Economy	12100.00
0005433397235	1462	Economy	11000.00
0005433397344	1462	Economy	11000.00
0005433397312	1462	Economy	11000.00
0005435732251	1462	Economy	11000.00
0005433397243	1462	Economy	11000.00
0005435732245	1462	Economy	11000.00
0005435732253	1462	Economy	11000.00
0005433397240	1462	Economy	11000.00
0005435732235	1462	Economy	11000.00
0005433456940	1462	Economy	11000.00
0005433397472	1462	Economy	11000.00
0005435732249	1462	Economy	11000.00
0005433397311	1462	Economy	11000.00
0005433397280	1462	Economy	11000.00
0005435732234	1462	Economy	11000.00
0005435732240	1462	Economy	11000.00
0005435732254	1462	Economy	11000.00
0005435732248	1462	Economy	11000.00
0005433397329	1462	Economy	11000.00
0005433397458	1462	Economy	11000.00
0005435732250	1462	Economy	11000.00
0005432297259	1462	Economy	11000.00
0005433397233	1462	Economy	11000.00
0005433397320	1462	Economy	11000.00
0005435732241	1462	Economy	11000.00
0005433397223	1462	Economy	11000.00
0005432297257	1462	Economy	11000.00
0005435732252	1462	Economy	11000.00
0005435732256	1462	Economy	11000.00
0005435732238	1462	Economy	11000.00
0005433397231	1462	Economy	11000.00
0005433397295	1462	Economy	11000.00
0005433397256	1462	Economy	11000.00
0005433456939	1462	Economy	11000.00
0005435732244	1462	Economy	11000.00
0005432297260	1462	Economy	11000.00
0005435732255	1462	Economy	11000.00
0005433397192	1462	Economy	11000.00
0005433397399	1462	Economy	11000.00
0005435732233	1462	Economy	11000.00
0005433397282	1462	Economy	11000.00
0005435732239	1462	Economy	11000.00
0005432297258	1462	Economy	11000.00
0005433397277	1462	Economy	11000.00
0005433397232	1462	Economy	11000.00
0005433456937	1462	Economy	11000.00
0005435732144	19264	Business	33000.00
0005433397719	19264	Business	33000.00
0005433397687	19264	Business	33000.00
0005433397683	19264	Business	33000.00
0005433397681	19264	Business	33000.00
0005435732213	19264	Business	33000.00
0005433397679	19264	Business	33000.00
0005435732147	19264	Business	33000.00
0005433397724	19264	Business	33000.00
0005433397682	19264	Business	33000.00
0005432906516	19264	Economy	11000.00
0005433397703	19264	Economy	11000.00
0005435732115	19264	Economy	11000.00
0005433397714	19264	Economy	12100.00
0005433397712	19264	Economy	12100.00
0005433397696	19264	Economy	12100.00
0005433397713	19264	Economy	12100.00
0005433397704	19264	Economy	11000.00
0005433397699	19264	Economy	11000.00
0005433397721	19264	Economy	11000.00
0005433397698	19264	Economy	11000.00
0005433456911	19264	Economy	11000.00
0005433397706	19264	Economy	11000.00
0005433397685	19264	Economy	11000.00
0005433397680	19264	Economy	11000.00
0005433397723	19264	Economy	11000.00
0005433397716	19264	Economy	11000.00
0005435732212	19264	Economy	11000.00
0005433397722	19264	Economy	11000.00
0005433397692	19264	Economy	11000.00
0005433397677	19264	Economy	11000.00
0005433397709	19264	Economy	11000.00
0005433456902	19264	Economy	11000.00
0005433397702	19264	Economy	11000.00
0005435732132	19264	Economy	11000.00
0005433397695	19264	Economy	11000.00
0005433397678	19264	Economy	11000.00
0005433397707	19264	Economy	11000.00
0005435732146	19264	Economy	11000.00
0005433397690	19264	Economy	11000.00
0005433397686	19264	Economy	11000.00
0005433397701	19264	Economy	11000.00
0005433456901	19264	Economy	11000.00
0005433397691	19264	Economy	11000.00
0005433397689	19264	Economy	11000.00
0005432906518	19264	Economy	11000.00
0005433397694	19264	Economy	11000.00
0005435732143	19264	Economy	11000.00
0005433397705	19264	Economy	11000.00
0005435732114	19264	Economy	11000.00
0005433397725	19264	Economy	11000.00
0005433456920	19264	Economy	11000.00
0005433397708	19264	Economy	11000.00
0005433397697	19264	Economy	11000.00
0005433397717	19264	Economy	11000.00
0005433397710	19264	Economy	11000.00
0005433397688	19264	Economy	11000.00
0005433397684	19264	Economy	11000.00
0005433397693	19264	Economy	11000.00
0005433397718	19264	Economy	11000.00
0005433397700	19264	Economy	11000.00
0005433397720	19264	Economy	11000.00
0005433397676	19264	Economy	11000.00
0005435732196	19264	Economy	11000.00
0005433397711	19264	Economy	11000.00
0005435732161	19264	Economy	11000.00
0005432906517	19264	Economy	11000.00
0005433397715	19264	Economy	11000.00
0005434443450	17347	Economy	14100.00
0005434443435	17347	Economy	14100.00
0005434443495	17347	Economy	14100.00
0005434443424	17347	Economy	14100.00
0005434443458	17347	Economy	14100.00
0005434443440	17347	Economy	14100.00
0005434443444	17347	Economy	14100.00
0005434443451	17347	Economy	14100.00
0005434443584	20598	Economy	15600.00
0005434443578	20598	Economy	15600.00
0005434443585	20598	Economy	15600.00
0005434443580	20598	Economy	14100.00
0005434443576	20598	Economy	14100.00
0005434443574	20598	Economy	14100.00
0005434443579	20598	Economy	14100.00
0005434443588	20598	Economy	14100.00
0005434443586	20598	Economy	14100.00
0005434443582	20598	Economy	14100.00
0005434443589	20598	Economy	14100.00
0005434443572	20598	Economy	14100.00
0005434443583	20598	Economy	14100.00
0005434443577	20598	Economy	14100.00
0005434443575	20598	Economy	14100.00
0005434443581	20598	Economy	14100.00
0005434443587	20598	Economy	14100.00
0005434443573	20598	Economy	14100.00
0005435377538	7235	Economy	5800.00
0005435377540	7235	Economy	5800.00
0005435377543	7235	Economy	5800.00
0005435377545	7235	Economy	5800.00
0005435377539	7235	Economy	5800.00
0005434954580	7235	Economy	5800.00
0005434954579	7235	Economy	5800.00
0005434954581	7235	Economy	5800.00
0005434954578	7235	Economy	5800.00
0005434954555	28347	Economy	5800.00
0005434954554	28347	Economy	5800.00
0005435377562	28347	Economy	5800.00
0005435377565	28347	Economy	5800.00
0005435377561	28347	Economy	5800.00
0005435377564	28347	Economy	5800.00
0005435377563	28347	Economy	5800.00
0005434351605	4477	Economy	15400.00
0005434351603	4477	Economy	14000.00
0005435893508	4477	Economy	14000.00
0005434351597	4477	Economy	14000.00
0005435893514	4477	Economy	14000.00
0005434351602	4477	Economy	14000.00
0005434326267	4477	Economy	14000.00
0005435893523	4477	Economy	14000.00
0005435893535	4477	Economy	14000.00
0005435893529	4477	Economy	14000.00
0005434351604	4477	Economy	14000.00
0005435893524	4477	Economy	14000.00
0005435893517	4477	Economy	14000.00
0005435893536	4477	Economy	14000.00
0005434351598	4477	Economy	14000.00
0005434183547	4477	Economy	14000.00
0005435893516	4477	Economy	14000.00
0005435893542	4477	Economy	14000.00
0005435893509	4477	Economy	14000.00
0005434351600	4477	Economy	14000.00
0005434351608	4477	Economy	14000.00
0005435893541	4477	Economy	14000.00
0005434351606	4477	Economy	14000.00
0005434351599	4477	Economy	14000.00
0005434351607	4477	Economy	14000.00
0005434351596	4477	Economy	14000.00
0005434351601	4477	Economy	14000.00
0005434351595	4477	Economy	14000.00
0005435893522	4477	Economy	14000.00
0005434326266	4477	Economy	14000.00
0005435893534	4477	Economy	14000.00
0005434351499	29645	Economy	15400.00
0005434351519	29645	Economy	15400.00
0005434351532	29645	Economy	14000.00
0005434351533	29645	Economy	14000.00
0005435893575	29645	Economy	14000.00
0005435893580	29645	Economy	14000.00
0005434351479	29645	Economy	14000.00
0005435893581	29645	Economy	14000.00
0005434351480	29645	Economy	14000.00
0005434351497	29645	Economy	14000.00
0005435893576	29645	Economy	14000.00
0005435893582	29645	Economy	14000.00
0005434351498	29645	Economy	14000.00
0005435893577	29645	Economy	14000.00
0005434351515	29645	Economy	14000.00
0005435893579	29645	Economy	14000.00
0005434351526	29645	Economy	14000.00
0005434351514	29645	Economy	14000.00
0005434351531	29645	Economy	14000.00
0005434351492	29645	Economy	14000.00
0005434351484	29645	Economy	14000.00
0005435893578	29645	Economy	14000.00
0005433341591	1057	Business	30600.00
0005433158102	1057	Business	30600.00
0005433341770	1057	Business	30600.00
0005433341435	1057	Business	30600.00
0005433341491	1057	Business	30600.00
0005433341677	1057	Business	30600.00
0005433341419	1057	Business	30600.00
0005433341609	1057	Business	30600.00
0005433341464	1057	Business	30600.00
0005435092002	1057	Business	30600.00
0005433463884	1057	Business	30600.00
0005433341676	1057	Business	30600.00
0005433341418	1057	Business	30600.00
0005433341482	1057	Business	30600.00
0005433341540	1057	Business	30600.00
0005433341761	1057	Business	30600.00
0005433341503	1057	Business	30600.00
0005433341838	1057	Business	30600.00
0005433341546	1057	Business	30600.00
0005433341753	1057	Economy	11200.00
0005433341526	1057	Economy	11200.00
0005433341392	1057	Economy	10200.00
0005433341837	1057	Economy	10200.00
0005433341795	1057	Economy	10200.00
0005433341732	1057	Economy	10200.00
0005433341467	1057	Economy	10200.00
0005433341745	1057	Economy	10200.00
0005433462731	1057	Economy	10200.00
0005433341523	1057	Economy	10200.00
0005433269637	1057	Economy	10200.00
0005433341706	1057	Economy	10200.00
0005433341644	1057	Economy	10200.00
0005433341680	1057	Economy	10200.00
0005435092005	1057	Economy	10200.00
0005433341763	1057	Economy	10200.00
0005433341437	1057	Economy	10200.00
0005433269639	1057	Economy	10200.00
0005435091998	1057	Economy	10200.00
0005433341839	1057	Economy	10200.00
0005433341541	1057	Economy	10200.00
0005433341499	1057	Economy	10200.00
0005433159279	1057	Economy	10200.00
0005435092001	1057	Economy	10200.00
0005433341652	1057	Economy	10200.00
0005433341744	1057	Economy	10200.00
0005433341804	1057	Economy	10200.00
0005435092000	1057	Economy	10200.00
0005433341830	1057	Economy	10200.00
0005433341771	1057	Economy	10200.00
0005433341645	1057	Economy	10200.00
0005433341516	1057	Economy	10200.00
0005433341937	1057	Economy	10200.00
0005433341875	1057	Economy	10200.00
0005433341542	1057	Economy	10200.00
0005434445232	1057	Economy	10200.00
0005433341829	1057	Economy	10200.00
0005433341874	1057	Economy	10200.00
0005435091997	1057	Economy	10200.00
0005433341438	1057	Economy	10200.00
0005433159280	1057	Economy	10200.00
0005433341840	1057	Economy	10200.00
0005433462730	1057	Economy	10200.00
0005433463885	1057	Economy	10200.00
0005433341457	1057	Economy	10200.00
0005433341524	1057	Economy	10200.00
0005433462732	1057	Economy	10200.00
0005433341512	1057	Economy	10200.00
0005433341705	1057	Economy	10200.00
0005433341865	1057	Economy	10200.00
0005433341762	1057	Economy	10200.00
0005433341610	1057	Economy	10200.00
0005433341397	1057	Economy	10200.00
0005433341479	1057	Economy	10200.00
0005435091996	1057	Economy	10200.00
0005433341444	1057	Economy	10200.00
0005433341420	1057	Economy	10200.00
0005433341681	1057	Economy	10200.00
0005434445231	1057	Economy	10200.00
0005433341547	1057	Economy	10200.00
0005433341659	1057	Economy	11200.00
0005433341746	1057	Economy	10200.00
0005433341841	1057	Economy	11200.00
0005433341388	1057	Economy	10200.00
0005433158103	1057	Economy	10200.00
0005433341674	1057	Economy	10200.00
0005433341436	1057	Economy	10200.00
0005433341707	1057	Economy	10200.00
0005432293190	1057	Economy	10200.00
0005433341588	1057	Economy	10200.00
0005433341543	1057	Economy	10200.00
0005433341666	1057	Economy	10200.00
0005433341504	1057	Economy	10200.00
0005433341393	1057	Economy	10200.00
0005433341936	1057	Economy	10200.00
0005433341498	1057	Economy	10200.00
0005433341640	1057	Economy	10200.00
0005433341571	1057	Economy	10200.00
0005435092003	1057	Economy	10200.00
0005433159277	1057	Economy	10200.00
0005434445230	1057	Economy	10200.00
0005433341517	1057	Economy	10200.00
0005433158101	1057	Economy	10200.00
0005433341511	1057	Economy	10200.00
0005433341668	1057	Economy	10200.00
0005433341718	1057	Economy	10200.00
0005433341660	1057	Economy	10200.00
0005433341463	1057	Economy	10200.00
0005433341521	1057	Economy	10200.00
0005433341522	1057	Economy	10200.00
0005432293189	1057	Economy	10200.00
0005433341398	1057	Economy	10200.00
0005433341445	1057	Economy	10200.00
0005433269620	1057	Economy	10200.00
0005433341483	1057	Economy	10200.00
0005433341394	1057	Economy	10200.00
0005435092004	1057	Economy	10200.00
0005433341717	1057	Economy	10200.00
0005433341769	1057	Economy	10200.00
0005433341468	1057	Economy	10200.00
0005433341497	1057	Economy	10200.00
0005433341456	1057	Economy	10200.00
0005435091999	1057	Economy	10200.00
0005433341794	1057	Economy	10200.00
0005433269638	1057	Economy	10200.00
0005433342310	17059	Business	30600.00
0005433342383	17059	Business	30600.00
0005433342389	17059	Business	30600.00
0005435091933	17059	Business	30600.00
0005435091952	17059	Business	30600.00
0005433342322	17059	Business	30600.00
0005433342311	17059	Business	30600.00
0005433342327	17059	Business	30600.00
0005433342365	17059	Business	30600.00
0005433342328	17059	Business	30600.00
0005433342392	17059	Business	30600.00
0005433342339	17059	Business	30600.00
0005433342369	17059	Business	30600.00
0005433342364	17059	Business	30600.00
0005433342326	17059	Business	30600.00
0005433269680	17059	Business	30600.00
0005433342376	17059	Business	30600.00
0005433342388	17059	Business	30600.00
0005433342306	17059	Economy	11200.00
0005435091910	17059	Economy	11200.00
0005433342301	17059	Economy	10200.00
0005433342359	17059	Economy	10200.00
0005433342366	17059	Economy	10200.00
0005433342362	17059	Economy	10200.00
0005433342313	17059	Economy	10200.00
0005435091916	17059	Economy	10200.00
0005433342342	17059	Economy	10200.00
0005433342348	17059	Economy	10200.00
0005433342357	17059	Economy	10200.00
0005433342371	17059	Economy	10200.00
0005434445211	17059	Economy	10200.00
0005433342296	17059	Economy	10200.00
0005433342323	17059	Economy	10200.00
0005433342375	17059	Economy	10200.00
0005433342374	17059	Economy	10200.00
0005433342379	17059	Economy	10200.00
0005433269676	17059	Economy	10200.00
0005433342370	17059	Economy	10200.00
0005433342312	17059	Economy	10200.00
0005433342333	17059	Economy	10200.00
0005433342367	17059	Economy	10200.00
0005433342324	17059	Economy	10200.00
0005433342295	17059	Economy	10200.00
0005433342352	17059	Economy	10200.00
0005433342384	17059	Economy	10200.00
0005433342309	17059	Economy	10200.00
0005433342330	17059	Economy	10200.00
0005434445212	17059	Economy	10200.00
0005433159297	17059	Economy	10200.00
0005433269679	17059	Economy	10200.00
0005433342336	17059	Economy	10200.00
0005433342360	17059	Economy	10200.00
0005433342294	17059	Economy	10200.00
0005433342303	17059	Economy	10200.00
0005433342353	17059	Economy	10200.00
0005433342325	17059	Economy	10200.00
0005433342318	17059	Economy	10200.00
0005433342378	17059	Economy	10200.00
0005433342305	17059	Economy	10200.00
0005433342304	17059	Economy	10200.00
0005433269677	17059	Economy	10200.00
0005433342391	17059	Economy	10200.00
0005433342350	17059	Economy	10200.00
0005433342332	17059	Economy	10200.00
0005433342361	17059	Economy	10200.00
0005433269675	17059	Economy	10200.00
0005433342363	17059	Economy	10200.00
0005433342308	17059	Economy	10200.00
0005433342349	17059	Economy	10200.00
0005433342351	17059	Economy	10200.00
0005433342377	17059	Economy	10200.00
0005433342340	17059	Economy	10200.00
0005433462708	17059	Economy	11200.00
0005433342345	17059	Economy	10200.00
0005433269678	17059	Economy	11200.00
0005433342329	17059	Economy	10200.00
0005433342355	17059	Economy	10200.00
0005433342354	17059	Economy	10200.00
0005433342358	17059	Economy	10200.00
0005433159296	17059	Economy	10200.00
0005433342334	17059	Economy	10200.00
0005435508164	17059	Economy	10200.00
0005433342372	17059	Economy	10200.00
0005433342394	17059	Economy	10200.00
0005433342302	17059	Economy	10200.00
0005433342315	17059	Economy	10200.00
0005433342316	17059	Economy	10200.00
0005435091937	17059	Economy	10200.00
0005433342356	17059	Economy	10200.00
0005433342297	17059	Economy	10200.00
0005433342314	17059	Economy	10200.00
0005433342393	17059	Economy	10200.00
0005433342320	17059	Economy	10200.00
0005433342341	17059	Economy	10200.00
0005433342373	17059	Economy	10200.00
0005433342390	17059	Economy	10200.00
0005433342385	17059	Economy	10200.00
0005433342338	17059	Economy	10200.00
0005433342299	17059	Economy	10200.00
0005433342380	17059	Economy	10200.00
0005433342347	17059	Economy	10200.00
0005433342321	17059	Economy	10200.00
0005433342387	17059	Economy	10200.00
0005433342317	17059	Economy	10200.00
0005433342344	17059	Economy	10200.00
0005433342335	17059	Economy	10200.00
0005433342381	17059	Economy	10200.00
0005433342337	17059	Economy	10200.00
0005433342307	17059	Economy	10200.00
0005433342331	17059	Economy	10200.00
0005433342343	17059	Economy	10200.00
0005433342298	17059	Economy	10200.00
0005433342382	17059	Economy	10200.00
0005433342386	17059	Economy	10200.00
0005433342319	17059	Economy	10200.00
0005433342346	17059	Economy	10200.00
0005433342368	17059	Economy	10200.00
0005433342300	17059	Economy	10200.00
0005432851872	18266	Business	101000.00
0005432851873	18266	Business	101000.00
0005432851864	18266	Business	101000.00
0005432389940	18266	Business	101000.00
0005432389945	18266	Business	101000.00
0005432851878	18266	Business	101000.00
0005432851870	18266	Economy	33700.00
0005432389939	18266	Economy	33700.00
0005432851865	18266	Economy	33700.00
0005432389955	18266	Economy	37000.00
0005432851866	18266	Economy	33700.00
0005432389934	18266	Economy	33700.00
0005432851881	18266	Economy	33700.00
0005432389935	18266	Economy	33700.00
0005432851871	18266	Economy	33700.00
0005432851869	18266	Economy	33700.00
0005432389961	18266	Economy	33700.00
0005432389933	18266	Economy	33700.00
0005432851882	18266	Economy	33700.00
0005432851877	18266	Economy	33700.00
0005432389941	18266	Economy	33700.00
0005432389963	18266	Economy	33700.00
0005432389950	18266	Economy	33700.00
0005432851876	18266	Economy	33700.00
0005432389960	18266	Economy	33700.00
0005432389954	18266	Economy	33700.00
0005432391951	18266	Economy	33700.00
0005432851875	18266	Economy	33700.00
0005432391950	18266	Economy	33700.00
0005432389943	18266	Economy	33700.00
0005432389936	18266	Economy	33700.00
0005432851880	18266	Economy	33700.00
0005432851874	18266	Economy	33700.00
0005432851879	18266	Economy	33700.00
0005432389984	18266	Economy	33700.00
0005432851868	18266	Economy	33700.00
0005432851867	18266	Economy	33700.00
0005433989686	12771	Business	40300.00
0005434066729	12771	Business	40300.00
0005434066425	12771	Business	40300.00
0005434081615	12771	Business	40300.00
0005434081572	12771	Business	40300.00
0005432433638	12771	Business	40300.00
0005432433637	12771	Business	40300.00
0005434066429	12771	Economy	13400.00
0005434081533	12771	Economy	13400.00
0005434066420	12771	Economy	13400.00
0005432159823	12771	Economy	13400.00
0005434066509	12771	Economy	13400.00
0005434081540	12771	Economy	13400.00
0005434066358	12771	Economy	13400.00
0005434066414	12771	Economy	13400.00
0005432161135	12771	Economy	13400.00
0005432161134	12771	Economy	13400.00
0005434081542	12771	Economy	13400.00
0005434066444	12771	Economy	13400.00
0005434066301	12771	Economy	13400.00
0005433812881	12771	Economy	13400.00
0005434066447	12771	Economy	13400.00
0005434066357	12771	Economy	13400.00
0005434066621	12771	Economy	13400.00
0005434066465	12771	Economy	13400.00
0005434066391	12771	Economy	14800.00
0005434081534	12771	Economy	14800.00
0005434066508	12771	Economy	14800.00
0005432159821	12771	Economy	14800.00
0005434066408	12771	Economy	14800.00
0005434066728	12771	Economy	13400.00
0005434066343	12771	Economy	13400.00
0005434066506	12771	Economy	13400.00
0005434081616	12771	Economy	13400.00
0005434066419	12771	Economy	13400.00
0005434066302	12771	Economy	13400.00
0005434066310	12771	Economy	13400.00
0005432433642	12771	Economy	13400.00
0005434066363	12771	Economy	13400.00
0005434066435	12771	Economy	13400.00
0005434081574	12771	Economy	13400.00
0005432159824	12771	Economy	13400.00
0005434066436	12771	Economy	13400.00
0005434066469	12771	Economy	13400.00
0005434066415	12771	Economy	13400.00
0005433812882	12771	Economy	13400.00
0005434066443	12771	Economy	13400.00
0005433989685	12771	Economy	13400.00
0005434081571	12771	Economy	13400.00
0005434081525	12771	Economy	13400.00
0005434066399	12771	Economy	13400.00
0005434066423	12771	Economy	13400.00
0005434081554	12771	Economy	13400.00
0005432433641	12771	Economy	13400.00
0005434066571	12771	Economy	13400.00
0005433812883	12771	Economy	13400.00
0005432433640	12771	Economy	13400.00
0005433989697	12771	Economy	13400.00
0005433989687	12771	Economy	13400.00
0005434066417	12771	Economy	13400.00
0005434081476	12771	Economy	13400.00
0005434066507	12771	Economy	13400.00
0005434066418	12771	Economy	13400.00
0005432433639	12771	Economy	13400.00
0005432159822	12771	Economy	13400.00
0005434066622	12771	Economy	13400.00
0005432159825	12771	Economy	13400.00
0005434081575	12771	Economy	13400.00
0005434066605	12771	Economy	13400.00
0005434081524	12771	Economy	13400.00
0005434066517	12771	Economy	13400.00
0005434081569	12771	Economy	13400.00
0005434081570	12771	Economy	13400.00
0005433989730	30657	Business	40300.00
0005434066954	30657	Business	40300.00
0005433989733	30657	Business	40300.00
0005434066999	30657	Business	40300.00
0005434081720	30657	Business	40300.00
0005434081727	30657	Business	40300.00
0005432150131	30657	Business	40300.00
0005434081701	30657	Business	40300.00
0005434067006	30657	Business	40300.00
0005434067015	30657	Business	40300.00
0005432186837	30657	Business	40300.00
0005432433602	30657	Economy	13400.00
0005434066950	30657	Economy	13400.00
0005434081714	30657	Economy	13400.00
0005433989731	30657	Economy	13400.00
0005434081698	30657	Economy	13400.00
0005434066976	30657	Economy	13400.00
0005434081706	30657	Economy	13400.00
0005434081704	30657	Economy	13400.00
0005434066975	30657	Economy	13400.00
0005434066961	30657	Economy	13400.00
0005434066977	30657	Economy	13400.00
0005434081723	30657	Economy	13400.00
0005434066970	30657	Economy	13400.00
0005432150129	30657	Economy	13400.00
0005434067016	30657	Economy	13400.00
0005434067010	30657	Economy	13400.00
0005434066994	30657	Economy	13400.00
0005434067001	30657	Economy	13400.00
0005434081707	30657	Economy	13400.00
0005434081702	30657	Economy	13400.00
0005434081713	30657	Economy	13400.00
0005434066972	30657	Economy	13400.00
0005433989734	30657	Economy	13400.00
0005434066956	30657	Economy	13400.00
0005434066982	30657	Economy	13400.00
0005434081715	30657	Economy	13400.00
0005434081725	30657	Economy	13400.00
0005432186839	30657	Economy	13400.00
0005434067012	30657	Economy	13400.00
0005434066968	30657	Economy	13400.00
0005432150127	30657	Economy	13400.00
0005434066964	30657	Economy	13400.00
0005434081710	30657	Economy	13400.00
0005434067004	30657	Economy	13400.00
0005434081719	30657	Economy	13400.00
0005432150133	30657	Economy	13400.00
0005434067014	30657	Economy	13400.00
0005434067003	30657	Economy	13400.00
0005434081724	30657	Economy	13400.00
0005434066960	30657	Economy	14800.00
0005432186838	30657	Economy	14800.00
0005434081709	30657	Economy	14800.00
0005434066997	30657	Economy	14800.00
0005434066966	30657	Economy	14800.00
0005434066951	30657	Economy	14800.00
0005434066981	30657	Economy	13400.00
0005434066995	30657	Economy	13400.00
0005434066969	30657	Economy	13400.00
0005434067007	30657	Economy	13400.00
0005434067019	30657	Economy	13400.00
0005434081717	30657	Economy	13400.00
0005434066971	30657	Economy	13400.00
0005434067020	30657	Economy	13400.00
0005434066955	30657	Economy	13400.00
0005434081726	30657	Economy	13400.00
0005433989732	30657	Economy	13400.00
0005434066996	30657	Economy	13400.00
0005434066986	30657	Economy	13400.00
0005434081716	30657	Economy	13400.00
0005434067017	30657	Economy	13400.00
0005432150128	30657	Economy	13400.00
0005434081722	30657	Economy	13400.00
0005434066973	30657	Economy	13400.00
0005434066987	30657	Economy	13400.00
0005434066967	30657	Economy	13400.00
0005434067000	30657	Economy	13400.00
0005434066963	30657	Economy	13400.00
0005432150126	30657	Economy	13400.00
0005434066984	30657	Economy	13400.00
0005434067011	30657	Economy	13400.00
0005434081712	30657	Economy	13400.00
0005434066983	30657	Economy	13400.00
0005434066989	30657	Economy	13400.00
0005434066949	30657	Economy	13400.00
0005432150132	30657	Economy	13400.00
0005434066958	30657	Economy	13400.00
0005434066991	30657	Economy	13400.00
0005434066978	30657	Economy	13400.00
0005434081711	30657	Economy	13400.00
0005434081703	30657	Economy	13400.00
0005434081718	30657	Economy	13400.00
0005434066988	30657	Economy	13400.00
0005432433595	30657	Economy	13400.00
0005434066990	30657	Economy	13400.00
0005434067013	30657	Economy	13400.00
0005432186840	30657	Economy	13400.00
0005434081700	30657	Economy	13400.00
0005434066993	30657	Economy	13400.00
0005434066965	30657	Economy	13400.00
0005434066979	30657	Economy	13400.00
0005434081699	30657	Economy	13400.00
0005434067018	30657	Economy	13400.00
0005434067008	30657	Economy	13400.00
0005434066953	30657	Economy	13400.00
0005434066992	30657	Economy	13400.00
0005432150130	30657	Economy	13400.00
0005434066980	30657	Economy	13400.00
0005434066952	30657	Economy	13400.00
0005434081705	30657	Economy	13400.00
0005434081708	30657	Economy	13400.00
0005434066998	30657	Economy	13400.00
0005434067009	30657	Economy	13400.00
0005434066985	30657	Economy	13400.00
0005434066974	30657	Economy	13400.00
0005434066962	30657	Economy	13400.00
0005434067005	30657	Economy	13400.00
0005434081721	30657	Economy	13400.00
0005434066948	30657	Economy	13400.00
0005434066957	30657	Economy	13400.00
0005434066959	30657	Economy	13400.00
0005434067002	30657	Economy	13400.00
0005433686621	9046	Economy	19300.00
0005433687689	9046	Economy	17600.00
0005433685509	9046	Economy	17600.00
0005433685508	9046	Economy	17600.00
0005433685507	9046	Economy	17600.00
0005433686619	9046	Economy	17600.00
0005433687696	9046	Economy	17600.00
0005433685513	9046	Economy	17600.00
0005433687695	9046	Economy	17600.00
0005433686623	9046	Economy	17600.00
0005433687693	9046	Economy	17600.00
0005433685511	9046	Economy	17600.00
0005433686620	9046	Economy	17600.00
0005433685510	9046	Economy	17600.00
0005433686617	9046	Economy	17600.00
0005433685514	9046	Economy	17600.00
0005433686622	9046	Economy	17600.00
0005433687692	9046	Economy	17600.00
0005433687690	9046	Economy	17600.00
0005433685512	9046	Economy	17600.00
0005433686618	9046	Economy	17600.00
0005433687691	9046	Economy	17600.00
0005433686624	9046	Economy	17600.00
0005433687694	9046	Economy	17600.00
0005435461828	5515	Business	35300.00
0005434264750	5515	Business	35300.00
0005435765765	5515	Business	35300.00
0005435720818	5515	Business	35300.00
0005432535757	5515	Business	35300.00
0005434264683	5515	Business	35300.00
0005435765795	5515	Business	35300.00
0005434264744	5515	Business	35300.00
0005434264794	5515	Business	35300.00
0005433529249	5515	Business	35300.00
0005432140382	5515	Business	35300.00
0005432535764	5515	Business	35300.00
0005435765789	5515	Business	35300.00
0005435765787	5515	Business	35300.00
0005435765771	5515	Business	35300.00
0005435765768	5515	Business	35300.00
0005432535765	5515	Business	35300.00
0005432140388	5515	Business	35300.00
0005435461909	5515	Business	35300.00
0005434831067	5515	Business	35300.00
0005434831068	5515	Business	35300.00
0005435765751	5515	Business	35300.00
0005434264756	5515	Economy	12900.00
0005435720817	5515	Business	35300.00
0005435765745	5515	Economy	12900.00
0005432140387	5515	Economy	12900.00
0005433529251	5515	Economy	11800.00
0005435765784	5515	Economy	11800.00
0005435765776	5515	Economy	11800.00
0005435765757	5515	Economy	11800.00
0005435765769	5515	Economy	11800.00
0005434264741	5515	Economy	11800.00
0005435461854	5515	Economy	11800.00
0005435765764	5515	Economy	11800.00
0005435461983	5515	Economy	11800.00
0005433529250	5515	Economy	11800.00
0005435765802	5515	Economy	11800.00
0005435765758	5515	Economy	11800.00
0005435765743	5515	Economy	11800.00
0005435765746	5515	Economy	11800.00
0005432535762	5515	Economy	11800.00
0005435461872	5515	Economy	11800.00
0005435765761	5515	Economy	11800.00
0005435722037	5515	Economy	11800.00
0005435765741	5515	Economy	11800.00
0005434264709	5515	Economy	11800.00
0005434264752	5515	Economy	11800.00
0005432140386	5515	Economy	11800.00
0005432535756	5515	Economy	11800.00
0005432535750	5515	Economy	11800.00
0005435722038	5515	Economy	11800.00
0005435725561	5515	Economy	11800.00
0005435722036	5515	Economy	11800.00
0005435765798	5515	Economy	11800.00
0005435735102	5515	Economy	11800.00
0005432140390	5515	Economy	11800.00
0005435765797	5515	Economy	11800.00
0005432140384	5515	Economy	11800.00
0005435461893	5515	Economy	11800.00
0005433527240	5515	Economy	11800.00
0005435765756	5515	Economy	11800.00
0005435765807	5515	Economy	11800.00
0005432535763	5515	Economy	11800.00
0005435723030	5515	Economy	11800.00
0005435765775	5515	Economy	11800.00
0005435735103	5515	Economy	11800.00
0005435765792	5515	Economy	11800.00
0005435765777	5515	Economy	11800.00
0005435461910	5515	Economy	11800.00
0005434831073	5515	Economy	11800.00
0005433529253	5515	Economy	11800.00
0005435765772	5515	Economy	11800.00
0005435765780	5515	Economy	11800.00
0005434831078	5515	Economy	11800.00
0005435765794	5515	Economy	11800.00
0005435765788	5515	Economy	11800.00
0005435765744	5515	Economy	11800.00
0005432140385	5515	Economy	11800.00
0005432140383	5515	Economy	11800.00
0005435765796	5515	Economy	11800.00
0005435765785	5515	Economy	11800.00
0005435461822	5515	Economy	11800.00
0005435461892	5515	Economy	11800.00
0005435461926	5515	Economy	11800.00
0005435461827	5515	Economy	11800.00
0005434264746	5515	Economy	11800.00
0005435765804	5515	Economy	11800.00
0005435461895	5515	Economy	11800.00
0005435461808	5515	Economy	11800.00
0005435765793	5515	Economy	11800.00
0005434264793	5515	Economy	12900.00
0005435461896	5515	Economy	12900.00
0005435461815	5515	Economy	11800.00
0005435735101	5515	Economy	11800.00
0005435735104	5515	Economy	12900.00
0005435765799	5515	Economy	11800.00
0005435725559	5515	Economy	11800.00
0005435765750	5515	Economy	11800.00
0005435461807	5515	Economy	11800.00
0005434264728	5515	Economy	11800.00
0005435765782	5515	Economy	11800.00
0005435765742	5515	Economy	11800.00
0005434264684	5515	Economy	11800.00
0005435765753	5515	Economy	11800.00
0005435765801	5515	Economy	11800.00
0005432140389	5515	Economy	11800.00
0005435765749	5515	Economy	11800.00
0005433527241	5515	Economy	11800.00
0005435765805	5515	Economy	11800.00
0005435765770	5515	Economy	11800.00
0005434264708	5515	Economy	11800.00
0005434264749	5515	Economy	11800.00
0005435735100	5515	Economy	11800.00
0005435765806	5515	Economy	11800.00
0005435765803	5515	Economy	11800.00
0005435765755	5515	Economy	11800.00
0005435461816	5515	Economy	11800.00
0005433527239	5515	Economy	11800.00
0005435461925	5515	Economy	11800.00
0005435765748	5515	Economy	11800.00
0005435765783	5515	Economy	11800.00
0005435765763	5515	Economy	11800.00
0005435461819	5515	Economy	11800.00
0005435765786	5515	Economy	11800.00
0005435765791	5515	Economy	11800.00
0005434264751	5515	Economy	11800.00
0005435765760	5515	Economy	11800.00
0005435765790	5515	Economy	11800.00
0005435765800	5515	Economy	11800.00
0005435765766	5515	Economy	11800.00
0005435765747	5515	Economy	11800.00
0005435765774	5515	Economy	11800.00
0005435725560	5515	Economy	11800.00
0005435765781	5515	Economy	11800.00
0005435461850	5515	Economy	11800.00
0005435461871	5515	Economy	11800.00
0005435461820	5515	Economy	11800.00
0005435461891	5515	Economy	11800.00
0005433529252	5515	Economy	11800.00
0005435765762	5515	Economy	11800.00
0005435765759	5515	Economy	11800.00
0005435765767	5515	Economy	11800.00
0005435725558	5515	Economy	11800.00
0005435765779	5515	Economy	11800.00
0005435725557	5515	Economy	11800.00
0005435765773	5515	Economy	11800.00
0005435461849	5515	Economy	11800.00
0005432535749	5515	Economy	11800.00
0005435765754	5515	Economy	11800.00
0005435765752	5515	Economy	11800.00
0005435765778	5515	Economy	11800.00
0005435461984	5515	Economy	11800.00
0005435765131	13485	Business	35300.00
0005435765178	13485	Business	35300.00
0005435725524	13485	Business	35300.00
0005435462165	13485	Business	35300.00
0005432535796	13485	Business	35300.00
0005435765287	13485	Business	35300.00
0005435765251	13485	Business	35300.00
0005435725534	13485	Business	35300.00
0005432535801	13485	Business	35300.00
0005435462166	13485	Business	35300.00
0005435765222	13485	Business	35300.00
0005435462147	13485	Business	35300.00
0005432535799	13485	Business	35300.00
0005434264948	13485	Business	35300.00
0005435765343	13485	Business	35300.00
0005435462164	13485	Business	35300.00
0005435462159	13485	Business	35300.00
0005435765185	13485	Business	35300.00
0005434264946	13485	Business	35300.00
0005432194481	13485	Business	35300.00
0005435462180	13485	Business	35300.00
0005435462174	13485	Economy	12900.00
0005434264942	13485	Business	35300.00
0005435462150	13485	Economy	12900.00
0005435462149	13485	Economy	12900.00
0005435765283	13485	Economy	12900.00
0005432194480	13485	Economy	11800.00
0005435462157	13485	Economy	11800.00
0005432535797	13485	Economy	11800.00
0005435462163	13485	Economy	11800.00
0005432535798	13485	Economy	11800.00
0005432194479	13485	Economy	11800.00
0005435462177	13485	Economy	11800.00
0005435765405	13485	Economy	11800.00
0005435765180	13485	Economy	11800.00
0005435725523	13485	Economy	11800.00
0005432535800	13485	Economy	11800.00
0005435765184	13485	Economy	11800.00
0005435765395	13485	Economy	11800.00
0005435765366	13485	Economy	11800.00
0005435765129	13485	Economy	11800.00
0005435462158	13485	Economy	11800.00
0005435765133	13485	Economy	11800.00
0005434264955	13485	Economy	11800.00
0005435462156	13485	Economy	11800.00
0005434264961	13485	Economy	11800.00
0005435462169	13485	Economy	11800.00
0005435765284	13485	Economy	11800.00
0005434831115	13485	Economy	11800.00
0005435462168	13485	Economy	11800.00
0005434264963	13485	Economy	11800.00
0005435765301	13485	Economy	11800.00
0005434264947	13485	Economy	11800.00
0005435765223	13485	Economy	11800.00
0005435765394	13485	Economy	11800.00
0005434264960	13485	Economy	11800.00
0005435725531	13485	Economy	11800.00
0005434831120	13485	Economy	11800.00
0005435765118	13485	Economy	11800.00
0005435765484	13485	Economy	11800.00
0005434264964	13485	Economy	11800.00
0005435765295	13485	Economy	11800.00
0005434264962	13485	Economy	11800.00
0005435462152	13485	Economy	11800.00
0005435765244	13485	Economy	11800.00
0005435462143	13485	Economy	11800.00
0005434264957	13485	Economy	11800.00
0005435462153	13485	Economy	11800.00
0005435462175	13485	Economy	11800.00
0005435765286	13485	Economy	11800.00
0005435765491	13485	Economy	11800.00
0005435462155	13485	Economy	11800.00
0005435765547	13485	Economy	11800.00
0005434264956	13485	Economy	11800.00
0005435462161	13485	Economy	11800.00
0005434831118	13485	Economy	11800.00
0005434264953	13485	Economy	11800.00
0005435765139	13485	Economy	11800.00
0005435765365	13485	Economy	11800.00
0005435765224	13485	Economy	11800.00
0005435462167	13485	Economy	12900.00
0005435725530	13485	Economy	11800.00
0005435765229	13485	Economy	11800.00
0005434264943	13485	Economy	12900.00
0005434264951	13485	Economy	11800.00
0005435765265	13485	Economy	11800.00
0005434831119	13485	Economy	11800.00
0005435043277	13485	Economy	11800.00
0005435765546	13485	Economy	11800.00
0005435723010	13485	Economy	11800.00
0005435462179	13485	Economy	11800.00
0005434264958	13485	Economy	11800.00
0005435765105	13485	Economy	11800.00
0005434264950	13485	Economy	11800.00
0005435725516	13485	Economy	11800.00
0005435462178	13485	Economy	11800.00
0005435462146	13485	Economy	11800.00
0005435462148	13485	Economy	11800.00
0005434264954	13485	Economy	11800.00
0005435765179	13485	Economy	11800.00
0005434264952	13485	Economy	11800.00
0005435765293	13485	Economy	11800.00
0005435765545	13485	Economy	11800.00
0005435765210	13485	Economy	11800.00
0005435765130	13485	Economy	11800.00
0005435462176	13485	Economy	11800.00
0005435462151	13485	Economy	11800.00
0005435462172	13485	Economy	11800.00
0005435462173	13485	Economy	11800.00
0005434264949	13485	Economy	11800.00
0005435765404	13485	Economy	11800.00
0005435765106	13485	Economy	11800.00
0005435462160	13485	Economy	11800.00
0005435462144	13485	Economy	11800.00
0005435462162	13485	Economy	11800.00
0005435462171	13485	Economy	11800.00
0005434831116	13485	Economy	11800.00
0005434264944	13485	Economy	11800.00
0005434831117	13485	Economy	11800.00
0005435462145	13485	Economy	11800.00
0005434264945	13485	Economy	11800.00
0005434264959	13485	Economy	11800.00
0005435725515	13485	Economy	11800.00
0005435735060	13485	Economy	11800.00
0005435462154	13485	Economy	11800.00
0005435765159	13485	Economy	11800.00
0005435765302	13485	Economy	11800.00
0005435765107	13485	Economy	11800.00
0005435765209	13485	Economy	11800.00
0005435765611	13485	Economy	11800.00
0005435765294	13485	Economy	11800.00
0005434264941	13485	Economy	11800.00
0005434264965	13485	Economy	11800.00
0005435462170	13485	Economy	11800.00
0005434514946	18654	Economy	3300.00
0005434513557	18654	Economy	3300.00
0005434513560	18654	Economy	3300.00
0005434514947	18654	Economy	3300.00
0005434514945	18654	Economy	3300.00
0005434513559	18654	Economy	3300.00
0005434513558	18654	Economy	3300.00
0005434514926	19200	Economy	3300.00
0005434602878	19200	Economy	3300.00
0005434602877	19200	Economy	3300.00
0005434514934	19200	Economy	3300.00
0005434602879	19200	Economy	3300.00
0005434514935	19200	Economy	3300.00
0005434602876	19200	Economy	3300.00
0005434602875	19200	Economy	3300.00
0005433007908	1847	Business	48700.00
0005433007880	1847	Business	48700.00
0005433007960	1847	Business	48700.00
0005433008034	1847	Business	48700.00
0005433284803	1847	Business	48700.00
0005433007947	1847	Business	48700.00
0005433007843	1847	Business	48700.00
0005433007951	1847	Economy	16200.00
0005432295859	1847	Economy	16200.00
0005433007915	1847	Economy	16200.00
0005433008044	1847	Economy	16200.00
0005433007934	1847	Economy	16200.00
0005433284910	1847	Economy	16200.00
0005433007948	1847	Economy	16200.00
0005433007983	1847	Economy	17900.00
0005433007992	1847	Economy	17900.00
0005433007894	1847	Economy	17900.00
0005432295860	1847	Economy	17900.00
0005433007904	1847	Economy	17900.00
0005433007884	1847	Economy	16200.00
0005433284900	1847	Economy	16200.00
0005433007883	1847	Economy	16200.00
0005433284837	1847	Economy	16200.00
0005433284814	1847	Economy	16200.00
0005433007833	1847	Economy	16200.00
0005433007933	1847	Economy	16200.00
0005433284799	1847	Economy	16200.00
0005433008094	1847	Economy	16200.00
0005433007952	1847	Economy	16200.00
0005433284804	1847	Economy	16200.00
0005433007871	1847	Economy	16200.00
0005433008029	1847	Economy	16200.00
0005433284934	1847	Economy	16200.00
0005433284776	1847	Economy	16200.00
0005433284883	1847	Economy	16200.00
0005433007949	1847	Economy	16200.00
0005433007997	1847	Economy	16200.00
0005433007916	1847	Economy	16200.00
0005433007967	1847	Economy	16200.00
0005432295861	1847	Economy	16200.00
0005433284813	1847	Economy	16200.00
0005433284896	1847	Economy	16200.00
0005433007982	1847	Economy	16200.00
0005433007888	1847	Economy	16200.00
0005433008095	1847	Economy	16200.00
0005433284917	1847	Economy	16200.00
0005433007981	1847	Economy	16200.00
0005433007897	1847	Economy	16200.00
0005433007824	1847	Economy	16200.00
0005433284849	1847	Economy	16200.00
0005433007838	1847	Economy	16200.00
0005433007905	1847	Economy	16200.00
0005433284853	1847	Economy	16200.00
0005433284800	1847	Economy	16200.00
0005433284784	1847	Economy	16200.00
0005433284854	1847	Economy	16200.00
0005433284843	1847	Economy	16200.00
0005433284901	1847	Economy	16200.00
0005433008077	1847	Economy	16200.00
0005433007932	1847	Economy	16200.00
0005433007898	1847	Economy	16200.00
0005433284844	1847	Economy	16200.00
0005433284812	1847	Economy	16200.00
0005433007850	1847	Economy	16200.00
0005433007946	1847	Economy	16200.00
0005433007964	1847	Economy	16200.00
0005433284983	1847	Economy	16200.00
0005433007835	1847	Economy	16200.00
0005433007837	1847	Economy	16200.00
0005433007858	1847	Economy	16200.00
0005433008266	22602	Business	48700.00
0005433008250	22602	Business	48700.00
0005433285046	22602	Business	48700.00
0005433285067	22602	Business	48700.00
0005433008278	22602	Business	48700.00
0005433008281	22602	Business	48700.00
0005433285056	22602	Business	48700.00
0005433285045	22602	Business	48700.00
0005433008284	22602	Economy	16200.00
0005433285049	22602	Economy	16200.00
0005433285070	22602	Economy	16200.00
0005433008245	22602	Economy	16200.00
0005433008262	22602	Economy	16200.00
0005433285042	22602	Economy	16200.00
0005433008279	22602	Economy	17900.00
0005433285040	22602	Economy	17900.00
0005433008242	22602	Economy	17900.00
0005433285061	22602	Economy	17900.00
0005433008283	22602	Economy	16200.00
0005433285065	22602	Economy	16200.00
0005433008277	22602	Economy	16200.00
0005433285039	22602	Economy	16200.00
0005433285062	22602	Economy	16200.00
0005433285064	22602	Economy	16200.00
0005433008275	22602	Economy	16200.00
0005433008270	22602	Economy	16200.00
0005433285069	22602	Economy	16200.00
0005433008285	22602	Economy	16200.00
0005433285044	22602	Economy	16200.00
0005433008282	22602	Economy	16200.00
0005433285047	22602	Economy	16200.00
0005433285054	22602	Economy	16200.00
0005433285048	22602	Economy	16200.00
0005433285057	22602	Economy	16200.00
0005433285055	22602	Economy	16200.00
0005433008248	22602	Economy	16200.00
0005433008252	22602	Economy	16200.00
0005433008280	22602	Economy	16200.00
0005433008257	22602	Economy	16200.00
0005433008247	22602	Economy	16200.00
0005433285068	22602	Economy	16200.00
0005433285052	22602	Economy	16200.00
0005433285053	22602	Economy	16200.00
0005433285066	22602	Economy	16200.00
0005433008243	22602	Economy	16200.00
0005433285043	22602	Economy	16200.00
0005433008265	22602	Economy	16200.00
0005433285063	22602	Economy	16200.00
0005433008240	22602	Economy	16200.00
0005433285060	22602	Economy	16200.00
0005433008263	22602	Economy	16200.00
0005433008255	22602	Economy	16200.00
0005433008271	22602	Economy	16200.00
0005433285058	22602	Economy	16200.00
0005433008267	22602	Economy	16200.00
0005433285050	22602	Economy	16200.00
0005433008272	22602	Economy	16200.00
0005433008256	22602	Economy	16200.00
0005433008246	22602	Economy	16200.00
0005433008268	22602	Economy	16200.00
0005433008273	22602	Economy	16200.00
0005433285059	22602	Economy	16200.00
0005433008269	22602	Economy	16200.00
0005433008258	22602	Economy	16200.00
0005433008274	22602	Economy	16200.00
0005433008260	22602	Economy	16200.00
0005433008264	22602	Economy	16200.00
0005433008251	22602	Economy	16200.00
0005433008249	22602	Economy	16200.00
0005433008261	22602	Economy	16200.00
0005433285041	22602	Economy	16200.00
0005433008244	22602	Economy	16200.00
0005433008259	22602	Economy	16200.00
0005433285051	22602	Economy	16200.00
0005433008276	22602	Economy	16200.00
0005433008254	22602	Economy	16200.00
0005433008253	22602	Economy	16200.00
0005433008241	22602	Economy	16200.00
0005432756811	25336	Business	83800.00
0005432756817	25336	Business	83800.00
0005434152755	25336	Economy	27900.00
0005432755042	25336	Economy	27900.00
0005432755048	25336	Economy	30700.00
0005432755043	25336	Economy	30700.00
0005432756816	25336	Economy	27900.00
0005432755041	25336	Economy	27900.00
0005432756815	25336	Economy	27900.00
0005432756813	25336	Economy	27900.00
0005432755044	25336	Economy	27900.00
0005432756818	25336	Economy	27900.00
0005432755046	25336	Economy	27900.00
0005432756814	25336	Economy	27900.00
0005432756820	25336	Economy	27900.00
0005432755040	25336	Economy	27900.00
0005432756812	25336	Economy	27900.00
0005432755045	25336	Economy	27900.00
0005432755047	25336	Economy	27900.00
0005432755039	25336	Economy	27900.00
0005432756819	25336	Economy	27900.00
0005433846288	5591	Business	99800.00
0005433846290	5591	Business	99800.00
0005433846267	5591	Business	99800.00
0005433846301	5591	Business	99800.00
0005433846279	5591	Business	99800.00
0005433846266	5591	Business	99800.00
0005433846299	5591	Business	99800.00
0005433815348	5591	Business	99800.00
0005435282218	5591	Business	99800.00
0005435282193	5591	Business	99800.00
0005433846281	5591	Business	99800.00
0005433846283	5591	Business	99800.00
0005435282170	5591	Business	99800.00
0005433846289	5591	Business	99800.00
0005433846271	5591	Business	99800.00
0005435282118	5591	Business	99800.00
0005435282127	5591	Business	99800.00
0005435282171	5591	Business	99800.00
0005432081464	5591	Economy	33300.00
0005435282051	5591	Economy	33300.00
0005433846285	5591	Economy	33300.00
0005433846278	5591	Economy	33300.00
0005432081460	5591	Economy	33300.00
0005433846318	5591	Economy	33300.00
0005433846315	5591	Economy	33300.00
0005433846277	5591	Economy	33300.00
0005435282088	5591	Economy	33300.00
0005435282101	5591	Economy	33300.00
0005435282078	5591	Economy	33300.00
0005433846313	5591	Economy	33300.00
0005433846297	5591	Economy	36600.00
0005433846312	5591	Economy	36600.00
0005433846274	5591	Economy	36600.00
0005433846319	5591	Economy	36600.00
0005435282154	5591	Economy	33300.00
0005433846308	5591	Economy	33300.00
0005433815350	5591	Economy	33300.00
0005435282216	5591	Economy	33300.00
0005435282067	5591	Economy	33300.00
0005432081463	5591	Economy	33300.00
0005433846314	5591	Economy	33300.00
0005435282083	5591	Economy	33300.00
0005435282215	5591	Economy	33300.00
0005433846264	5591	Economy	33300.00
0005433846292	5591	Economy	33300.00
0005433815347	5591	Economy	33300.00
0005433846294	5591	Economy	33300.00
0005435282068	5591	Economy	33300.00
0005433846302	5591	Economy	33300.00
0005433846262	5591	Economy	33300.00
0005433846272	5591	Economy	33300.00
0005434173451	5591	Economy	33300.00
0005433846303	5591	Economy	33300.00
0005433846306	5591	Economy	33300.00
0005433846300	5591	Economy	33300.00
0005435282072	5591	Economy	33300.00
0005433846284	5591	Economy	33300.00
0005433846309	5591	Economy	33300.00
0005433846268	5591	Economy	33300.00
0005435282140	5591	Economy	33300.00
0005433846320	5591	Economy	33300.00
0005433846287	5591	Economy	33300.00
0005433846295	5591	Economy	33300.00
0005433846263	5591	Economy	33300.00
0005433846317	5591	Economy	33300.00
0005433815346	5591	Economy	33300.00
0005435282087	5591	Economy	33300.00
0005432081465	5591	Economy	33300.00
0005433846291	5591	Economy	33300.00
0005435282053	5591	Economy	33300.00
0005433846305	5591	Economy	33300.00
0005433815345	5591	Economy	33300.00
0005433846298	5591	Economy	33300.00
0005435282217	5591	Economy	33300.00
0005433846307	5591	Economy	33300.00
0005433846269	5591	Economy	33300.00
0005433846275	5591	Economy	33300.00
0005433846273	5591	Economy	33300.00
0005433815349	5591	Economy	33300.00
0005433846304	5591	Economy	33300.00
0005435282141	5591	Economy	33300.00
0005435282054	5591	Economy	33300.00
0005433846311	5591	Economy	33300.00
0005433846286	5591	Economy	33300.00
0005433846265	5591	Economy	33300.00
0005435282172	5591	Economy	33300.00
0005435282132	5591	Economy	33300.00
0005435282138	5591	Economy	33300.00
0005435282241	5591	Economy	33300.00
0005433846276	5591	Economy	33300.00
0005433846282	5591	Economy	33300.00
0005433846310	5591	Economy	33300.00
0005433846316	5591	Economy	33300.00
0005432081462	5591	Economy	33300.00
0005433846293	5591	Economy	33300.00
0005435282102	5591	Economy	33300.00
0005433846296	5591	Economy	33300.00
0005432081461	5591	Economy	33300.00
0005433846280	5591	Economy	33300.00
0005433846270	5591	Economy	33300.00
0005433845694	13853	Business	99800.00
0005433845680	13853	Business	99800.00
0005433845782	13853	Business	99800.00
0005433845930	13853	Business	99800.00
0005433845696	13853	Business	99800.00
0005434173491	13853	Business	99800.00
0005433815315	13853	Business	99800.00
0005433845828	13853	Business	99800.00
0005433845809	13853	Business	99800.00
0005433815305	13853	Business	99800.00
0005433845958	13853	Economy	33300.00
0005433845715	13853	Business	99800.00
0005433845785	13853	Economy	33300.00
0005435282311	13853	Economy	33300.00
0005433845944	13853	Economy	33300.00
0005433845740	13853	Economy	33300.00
0005433845822	13853	Economy	33300.00
0005435282320	13853	Economy	33300.00
0005435282332	13853	Economy	33300.00
0005433845719	13853	Economy	33300.00
0005435282312	13853	Economy	36600.00
0005433845736	13853	Economy	36600.00
0005435282330	13853	Economy	36600.00
0005435282324	13853	Economy	33300.00
0005433845697	13853	Economy	33300.00
0005433846063	13853	Economy	33300.00
0005435282321	13853	Economy	33300.00
0005435282310	13853	Economy	33300.00
0005433815309	13853	Economy	33300.00
0005433845960	13853	Economy	33300.00
0005435282335	13853	Economy	33300.00
0005433845938	13853	Economy	33300.00
0005435282325	13853	Economy	33300.00
0005435282313	13853	Economy	33300.00
0005435282319	13853	Economy	33300.00
0005433846080	13853	Economy	33300.00
0005433845861	13853	Economy	33300.00
0005433846151	13853	Economy	33300.00
0005433845800	13853	Economy	33300.00
0005433845927	13853	Economy	33300.00
0005432003678	13853	Economy	33300.00
0005433815304	13853	Economy	33300.00
0005433845681	13853	Economy	33300.00
0005434173492	13853	Economy	33300.00
0005433845723	13853	Economy	33300.00
0005433845873	13853	Economy	33300.00
0005434173489	13853	Economy	33300.00
0005433845957	13853	Economy	33300.00
0005435282328	13853	Economy	33300.00
0005433845823	13853	Economy	33300.00
0005433845756	13853	Economy	33300.00
0005435282333	13853	Economy	33300.00
0005435282334	13853	Economy	33300.00
0005435282318	13853	Economy	33300.00
0005432003679	13853	Economy	33300.00
0005433845837	13853	Economy	33300.00
0005432003677	13853	Economy	33300.00
0005435282338	13853	Economy	33300.00
0005435282329	13853	Economy	33300.00
0005434173490	13853	Economy	33300.00
0005433845852	13853	Economy	33300.00
0005433845679	13853	Economy	33300.00
0005435282323	13853	Economy	33300.00
0005435282315	13853	Economy	33300.00
0005435282337	13853	Economy	33300.00
0005435282327	13853	Economy	33300.00
0005433845928	13853	Economy	33300.00
0005433845741	13853	Economy	33300.00
0005433845820	13853	Economy	33300.00
0005433846008	13853	Economy	33300.00
0005433815316	13853	Economy	33300.00
0005433845743	13853	Economy	33300.00
0005435282317	13853	Economy	33300.00
0005433845695	13853	Economy	33300.00
0005435282336	13853	Economy	33300.00
0005435282326	13853	Economy	33300.00
0005433845836	13853	Economy	33300.00
0005435282331	13853	Economy	33300.00
0005435282314	13853	Economy	33300.00
0005435282316	13853	Economy	33300.00
0005433845959	13853	Economy	33300.00
0005433845737	13853	Economy	33300.00
0005433845727	13853	Economy	33300.00
0005433846135	13853	Economy	33300.00
0005435282322	13853	Economy	33300.00
0005434620444	7851	Economy	16600.00
0005434620440	7851	Economy	15100.00
0005432112498	7851	Economy	15100.00
0005434620442	7851	Economy	15100.00
0005435332168	7851	Economy	15100.00
0005434620446	7851	Economy	15100.00
0005434620445	7851	Economy	15100.00
0005435332182	7851	Economy	15100.00
0005434620438	7851	Economy	15100.00
0005435332164	7851	Economy	15100.00
0005432112499	7851	Economy	15100.00
0005434620448	7851	Economy	15100.00
0005434620441	7851	Economy	15100.00
0005434620447	7851	Economy	15100.00
0005434620439	7851	Economy	15100.00
0005434620451	7851	Economy	15100.00
0005434620449	7851	Economy	15100.00
0005434620434	7851	Economy	15100.00
0005434620436	7851	Economy	15100.00
0005434620452	7851	Economy	15100.00
0005434620433	7851	Economy	15100.00
0005434620437	7851	Economy	15100.00
0005435332165	7851	Economy	15100.00
0005434620450	7851	Economy	15100.00
0005434620443	7851	Economy	15100.00
0005434620435	7851	Economy	15100.00
0005435332200	7851	Economy	15100.00
0005434620242	32990	Economy	16600.00
0005435332258	32990	Economy	16600.00
0005434620254	32990	Economy	16600.00
0005434620347	32990	Economy	15100.00
0005434620299	32990	Economy	15100.00
0005434620256	32990	Economy	15100.00
0005434620231	32990	Economy	15100.00
0005434620302	32990	Economy	15100.00
0005434620300	32990	Economy	15100.00
0005434620257	32990	Economy	15100.00
0005435332259	32990	Economy	15100.00
0005434620250	32990	Economy	15100.00
0005434620263	32990	Economy	15100.00
0005435332263	32990	Economy	15100.00
0005434620236	32990	Economy	15100.00
0005434620346	32990	Economy	15100.00
0005435332254	32990	Economy	15100.00
0005435332255	32990	Economy	15100.00
0005435332261	32990	Economy	15100.00
0005434620312	32990	Economy	15100.00
0005434620265	32990	Economy	15100.00
0005434620295	32990	Economy	15100.00
0005434620310	32990	Economy	15100.00
0005435332262	32990	Economy	15100.00
0005434620304	32990	Economy	15100.00
0005435332256	32990	Economy	15100.00
0005434620301	32990	Economy	15100.00
0005434620311	32990	Economy	15100.00
0005434620303	32990	Economy	15100.00
0005435332260	32990	Economy	15100.00
0005435332257	32990	Economy	15100.00
0005434993954	4261	Business	38000.00
0005435787338	4261	Business	38000.00
0005434993953	4261	Business	38000.00
0005432190601	4261	Business	38000.00
0005434993948	4261	Business	38000.00
0005435785082	4261	Business	38000.00
0005435785105	4261	Economy	12700.00
0005432190602	4261	Economy	12700.00
0005432190599	4261	Economy	12700.00
0005435785091	4261	Economy	12700.00
0005435785099	4261	Economy	12700.00
0005435785092	4261	Economy	12700.00
0005434993951	4261	Economy	12700.00
0005434993952	4261	Economy	13900.00
0005435785111	4261	Economy	12700.00
0005435785085	4261	Economy	12700.00
0005435787340	4261	Economy	12700.00
0005435785086	4261	Economy	12700.00
0005435785083	4261	Economy	12700.00
0005435785108	4261	Economy	12700.00
0005435785089	4261	Economy	12700.00
0005435785112	4261	Economy	12700.00
0005435785110	4261	Economy	12700.00
0005435787339	4261	Economy	12700.00
0005435785095	4261	Economy	12700.00
0005435785081	4261	Economy	12700.00
0005435785087	4261	Economy	12700.00
0005435785093	4261	Economy	12700.00
0005435785106	4261	Economy	12700.00
0005435785109	4261	Economy	12700.00
0005435785115	4261	Economy	12700.00
0005434993950	4261	Economy	12700.00
0005435785102	4261	Economy	12700.00
0005435785090	4261	Economy	12700.00
0005435785084	4261	Economy	12700.00
0005434993949	4261	Economy	12700.00
0005434993947	4261	Economy	12700.00
0005435785097	4261	Economy	12700.00
0005435785100	4261	Economy	12700.00
0005435785114	4261	Economy	12700.00
0005435785094	4261	Economy	12700.00
0005435785107	4261	Economy	12700.00
0005432190600	4261	Economy	12700.00
0005435785113	4261	Economy	12700.00
0005435785103	4261	Economy	12700.00
0005434993946	4261	Economy	12700.00
0005435785098	4261	Economy	12700.00
0005435785104	4261	Economy	12700.00
0005435785088	4261	Economy	12700.00
0005435785096	4261	Economy	12700.00
0005435785101	4261	Economy	12700.00
0005435784756	27316	Business	38000.00
0005435787321	27316	Business	38000.00
0005435784798	27316	Business	38000.00
0005434993850	27316	Business	38000.00
0005435784877	27316	Business	38000.00
0005435784874	27316	Economy	12700.00
0005435918619	27316	Economy	12700.00
0005434993849	27316	Economy	12700.00
0005435784799	27316	Economy	12700.00
0005435784737	27316	Economy	13900.00
0005434993862	27316	Economy	12700.00
0005435784757	27316	Economy	12700.00
0005435784736	27316	Economy	12700.00
0005434993855	27316	Economy	12700.00
0005435918618	27316	Economy	12700.00
0005435937346	27316	Economy	12700.00
0005435918617	27316	Economy	12700.00
0005435784856	27316	Economy	12700.00
0005435787322	27316	Economy	12700.00
0005434993866	27316	Economy	12700.00
0005435784902	27316	Economy	12700.00
0005432195676	27316	Economy	12700.00
0005434993865	27316	Economy	12700.00
0005435784885	27316	Economy	12700.00
0005434993863	27316	Economy	12700.00
0005435937345	27316	Economy	12700.00
0005435918620	27316	Economy	12700.00
0005434993875	27316	Economy	12700.00
0005434993874	27316	Economy	12700.00
0005434993858	27316	Economy	12700.00
0005435784758	27316	Economy	12700.00
0005434993881	27316	Economy	12700.00
0005434993848	27316	Economy	12700.00
0005435937344	27316	Economy	12700.00
0005435784797	27316	Economy	12700.00
0005432195677	27316	Economy	12700.00
0005435784759	27316	Economy	12700.00
0005435787323	27316	Economy	12700.00
0005435937347	27316	Economy	12700.00
0005435918621	27316	Economy	12700.00
0005435937348	27316	Economy	12700.00
0005432146183	19862	Economy	12800.00
0005432146182	19862	Economy	12800.00
0005434081728	4714	Business	40900.00
0005432567188	4714	Business	40900.00
0005432459474	4714	Business	40900.00
0005432567198	4714	Business	40900.00
0005432459462	4714	Business	40900.00
0005432567174	4714	Business	40900.00
0005432459487	4714	Business	40900.00
0005432459468	4714	Business	40900.00
0005433452723	4714	Business	40900.00
0005432567193	4714	Business	40900.00
0005432567156	4714	Business	40900.00
0005434081742	4714	Business	40900.00
0005432459445	4714	Business	40900.00
0005432567197	4714	Business	40900.00
0005434081736	4714	Business	40900.00
0005432567203	4714	Business	40900.00
0005432459438	4714	Business	40900.00
0005432567158	4714	Business	40900.00
0005432567157	4714	Business	40900.00
0005432567154	4714	Business	40900.00
0005432459440	4714	Business	40900.00
0005432459444	4714	Business	40900.00
0005432567191	4714	Economy	15000.00
0005434559088	4714	Economy	15000.00
0005432459453	4714	Economy	15000.00
0005432567175	4714	Economy	13600.00
0005432567179	4714	Economy	13600.00
0005434559089	4714	Economy	13600.00
0005432170340	4714	Economy	13600.00
0005432567202	4714	Economy	13600.00
0005432567173	4714	Economy	13600.00
0005434081745	4714	Economy	13600.00
0005432170336	4714	Economy	13600.00
0005432459447	4714	Economy	13600.00
0005434081737	4714	Economy	13600.00
0005432567155	4714	Economy	13600.00
0005432186841	4714	Economy	13600.00
0005432459459	4714	Economy	13600.00
0005432459483	4714	Economy	13600.00
0005432567172	4714	Economy	13600.00
0005434081732	4714	Economy	13600.00
0005432567207	4714	Economy	13600.00
0005432459489	4714	Economy	13600.00
0005433726086	4714	Economy	13600.00
0005432459437	4714	Economy	13600.00
0005432567168	4714	Economy	13600.00
0005433726087	4714	Economy	13600.00
0005432459470	4714	Economy	13600.00
0005432567170	4714	Economy	13600.00
0005432567159	4714	Economy	13600.00
0005434081739	4714	Economy	13600.00
0005432567210	4714	Economy	13600.00
0005432170337	4714	Economy	13600.00
0005432567176	4714	Economy	13600.00
0005432186842	4714	Economy	13600.00
0005432567161	4714	Economy	13600.00
0005432459439	4714	Economy	13600.00
0005432567211	4714	Economy	13600.00
0005432459467	4714	Economy	13600.00
0005434081740	4714	Economy	13600.00
0005432459475	4714	Economy	13600.00
0005432567187	4714	Economy	13600.00
0005432567212	4714	Economy	13600.00
0005432567164	4714	Economy	13600.00
0005432459469	4714	Economy	13600.00
0005434081744	4714	Economy	13600.00
0005432459446	4714	Economy	13600.00
0005434081735	4714	Economy	13600.00
0005432567200	4714	Economy	13600.00
0005432567201	4714	Economy	13600.00
0005432186845	4714	Economy	13600.00
0005433452724	4714	Economy	13600.00
0005432459477	4714	Economy	13600.00
0005432567206	4714	Economy	13600.00
0005432459443	4714	Economy	13600.00
0005432567181	4714	Economy	13600.00
0005432459458	4714	Economy	13600.00
0005432567185	4714	Economy	13600.00
0005432567186	4714	Economy	13600.00
0005432459452	4714	Economy	13600.00
0005434081741	4714	Economy	13600.00
0005432567195	4714	Economy	13600.00
0005432567183	4714	Economy	13600.00
0005432459488	4714	Economy	13600.00
0005432459482	4714	Economy	13600.00
0005434081747	4714	Economy	13600.00
0005432170338	4714	Economy	13600.00
0005434081729	4714	Economy	13600.00
0005432567184	4714	Economy	13600.00
0005432459465	4714	Economy	13600.00
0005432459451	4714	Economy	13600.00
0005432459449	4714	Economy	15000.00
0005432459441	4714	Economy	13600.00
0005432459454	4714	Economy	13600.00
0005432567160	4714	Economy	15000.00
0005433451604	4714	Economy	13600.00
0005432459479	4714	Economy	13600.00
0005432567169	4714	Economy	13600.00
0005432567162	4714	Economy	13600.00
0005432459450	4714	Economy	13600.00
0005432567192	4714	Economy	13600.00
0005432459485	4714	Economy	13600.00
0005432567199	4714	Economy	13600.00
0005432459442	4714	Economy	13600.00
0005432567194	4714	Economy	13600.00
0005432459448	4714	Economy	13600.00
0005432567171	4714	Economy	13600.00
0005432567180	4714	Economy	13600.00
0005432459486	4714	Economy	13600.00
0005432567205	4714	Economy	13600.00
0005432567153	4714	Economy	13600.00
0005432459472	4714	Economy	13600.00
0005432567204	4714	Economy	13600.00
0005432567213	4714	Economy	13600.00
0005432567178	4714	Economy	13600.00
0005432459466	4714	Economy	13600.00
0005432459456	4714	Economy	13600.00
0005434081730	4714	Economy	13600.00
0005432459455	4714	Economy	13600.00
0005434081748	4714	Economy	13600.00
0005432459476	4714	Economy	13600.00
0005432567190	4714	Economy	13600.00
0005432459481	4714	Economy	13600.00
0005432567182	4714	Economy	13600.00
0005432571292	4714	Economy	13600.00
0005432567208	4714	Economy	13600.00
0005432571293	4714	Economy	13600.00
0005434081731	4714	Economy	13600.00
0005432170339	4714	Economy	13600.00
0005434081743	4714	Economy	13600.00
0005432459478	4714	Economy	13600.00
0005432459463	4714	Economy	13600.00
0005434081734	4714	Economy	13600.00
0005432459473	4714	Economy	13600.00
0005432170335	4714	Economy	13600.00
0005432567189	4714	Economy	13600.00
0005434081738	4714	Economy	13600.00
0005432459457	4714	Economy	13600.00
0005432567177	4714	Economy	13600.00
0005432567166	4714	Economy	13600.00
0005432459460	4714	Economy	13600.00
0005432186844	4714	Economy	13600.00
0005432567196	4714	Economy	13600.00
0005432567209	4714	Economy	13600.00
0005433451605	4714	Economy	13600.00
0005434081746	4714	Economy	13600.00
0005432459464	4714	Economy	13600.00
0005434081733	4714	Economy	13600.00
0005432567165	4714	Economy	13600.00
0005433726088	4714	Economy	13600.00
0005432571294	4714	Economy	13600.00
0005432459480	4714	Economy	13600.00
0005432459461	4714	Economy	13600.00
0005432567167	4714	Economy	13600.00
0005432186843	4714	Economy	13600.00
0005432459484	4714	Economy	13600.00
0005432459471	4714	Economy	13600.00
0005432567163	4714	Economy	13600.00
0005432566679	30561	Business	40900.00
0005432213578	30561	Business	40900.00
0005432566633	30561	Business	40900.00
0005432566600	30561	Business	40900.00
0005434081616	30561	Business	40900.00
0005432566632	30561	Business	40900.00
0005432566824	30561	Business	40900.00
0005432566581	30561	Business	40900.00
0005432566751	30561	Business	40900.00
0005432567020	30561	Business	40900.00
0005432161135	30561	Business	40900.00
0005432458970	30561	Business	40900.00
0005432566775	30561	Business	40900.00
0005432566855	30561	Business	40900.00
0005432459286	30561	Business	40900.00
0005432566697	30561	Business	40900.00
0005432566778	30561	Business	40900.00
0005432566852	30561	Business	40900.00
0005432459280	30561	Business	40900.00
0005434081575	30561	Economy	15000.00
0005432566749	30561	Economy	15000.00
0005432459020	30561	Economy	13600.00
0005434081574	30561	Economy	13600.00
0005432566870	30561	Economy	13600.00
0005432566526	30561	Economy	13600.00
0005432566741	30561	Economy	13600.00
0005432566850	30561	Economy	13600.00
0005432566862	30561	Economy	13600.00
0005432459066	30561	Economy	13600.00
0005432566750	30561	Economy	13600.00
0005432571274	30561	Economy	13600.00
0005432566905	30561	Economy	13600.00
0005432566935	30561	Economy	13600.00
0005432459133	30561	Economy	13600.00
0005432566890	30561	Economy	13600.00
0005432459276	30561	Economy	13600.00
0005432566912	30561	Economy	13600.00
0005434081570	30561	Economy	13600.00
0005432566708	30561	Economy	13600.00
0005432459033	30561	Economy	13600.00
0005432459051	30561	Economy	13600.00
0005432459211	30561	Economy	13600.00
0005432566828	30561	Economy	13600.00
0005432566752	30561	Economy	13600.00
0005432213577	30561	Economy	13600.00
0005432566931	30561	Economy	13600.00
0005432566747	30561	Economy	13600.00
0005432566836	30561	Economy	13600.00
0005432459057	30561	Economy	13600.00
0005432566626	30561	Economy	13600.00
0005432459021	30561	Economy	13600.00
0005432459201	30561	Economy	13600.00
0005432459009	30561	Economy	13600.00
0005433452706	30561	Economy	13600.00
0005432213579	30561	Economy	13600.00
0005432459024	30561	Economy	13600.00
0005432566887	30561	Economy	13600.00
0005432566780	30561	Economy	13600.00
0005432566572	30561	Economy	13600.00
0005432458969	30561	Economy	13600.00
0005432566693	30561	Economy	13600.00
0005432566830	30561	Economy	13600.00
0005432566888	30561	Economy	13600.00
0005432566685	30561	Economy	13600.00
0005434081540	30561	Economy	13600.00
0005432459040	30561	Economy	13600.00
0005432566742	30561	Economy	13600.00
0005432566777	30561	Economy	13600.00
0005432459182	30561	Economy	13600.00
0005432566829	30561	Economy	13600.00
0005432459118	30561	Economy	13600.00
0005432458964	30561	Economy	13600.00
0005432566695	30561	Economy	13600.00
0005432566704	30561	Economy	13600.00
0005432566825	30561	Economy	13600.00
0005432566815	30561	Economy	13600.00
0005432161134	30561	Economy	13600.00
0005432566869	30561	Economy	13600.00
0005432566739	30561	Economy	13600.00
0005432459028	30561	Economy	13600.00
0005434081533	30561	Economy	13600.00
0005432566540	30561	Economy	13600.00
0005432458992	30561	Economy	13600.00
0005432566867	30561	Economy	13600.00
0005432566680	30561	Economy	13600.00
0005432459120	30561	Economy	13600.00
0005432459056	30561	Economy	13600.00
0005432566720	30561	Economy	13600.00
0005432458972	30561	Economy	13600.00
0005432459052	30561	Economy	13600.00
0005432566837	30561	Economy	13600.00
0005432566788	30561	Economy	13600.00
0005432567019	30561	Economy	13600.00
0005432459022	30561	Economy	13600.00
0005432566706	30561	Economy	13600.00
0005432566740	30561	Economy	15000.00
0005432566525	30561	Economy	13600.00
0005432459039	30561	Economy	13600.00
0005432566849	30561	Economy	13600.00
0005432571273	30561	Economy	15000.00
0005432459142	30561	Economy	15000.00
0005434081525	30561	Economy	13600.00
0005434081476	30561	Economy	13600.00
0005432459030	30561	Economy	13600.00
0005434081542	30561	Economy	13600.00
0005434081571	30561	Economy	13600.00
0005432458971	30561	Economy	13600.00
0005432571266	30561	Economy	13600.00
0005432566585	30561	Economy	13600.00
0005432566717	30561	Economy	13600.00
0005432459067	30561	Economy	13600.00
0005432459019	30561	Economy	13600.00
0005432459032	30561	Economy	13600.00
0005434081572	30561	Economy	13600.00
0005432459285	30561	Economy	13600.00
0005432566776	30561	Economy	13600.00
0005432566748	30561	Economy	13600.00
0005433454845	30561	Economy	13600.00
0005432459112	30561	Economy	13600.00
0005434081554	30561	Economy	13600.00
0005432566831	30561	Economy	13600.00
0005432566718	30561	Economy	13600.00
0005432566694	30561	Economy	13600.00
0005432459139	30561	Economy	13600.00
0005432459181	30561	Economy	13600.00
0005434081569	30561	Economy	13600.00
0005432566801	30561	Economy	13600.00
0005432566535	30561	Economy	13600.00
0005432566634	30561	Economy	13600.00
0005432459029	30561	Economy	13600.00
0005432566707	30561	Economy	13600.00
0005433454846	30561	Economy	13600.00
0005432459212	30561	Economy	13600.00
0005432566534	30561	Economy	13600.00
0005432566731	30561	Economy	13600.00
0005432566584	30561	Economy	13600.00
0005432566599	30561	Economy	13600.00
0005432566936	30561	Economy	13600.00
0005432566835	30561	Economy	13600.00
0005432566678	30561	Economy	13600.00
0005432566823	30561	Economy	13600.00
0005432458999	30561	Economy	13600.00
0005432566541	30561	Economy	13600.00
0005432566745	30561	Economy	13600.00
0005432566802	30561	Economy	13600.00
0005434081524	30561	Economy	13600.00
0005432566746	30561	Economy	13600.00
0005432566889	30561	Economy	13600.00
0005434081534	30561	Economy	13600.00
0005433454851	30561	Economy	13600.00
0005432459068	30561	Economy	13600.00
0005432566868	30561	Economy	13600.00
0005434081615	30561	Economy	13600.00
0005432459075	30561	Economy	13600.00
0005435722037	13624	Economy	9900.00
0005435722038	13624	Economy	9900.00
0005435720818	13624	Economy	9900.00
0005435722036	13624	Economy	9900.00
0005435720817	13624	Economy	9900.00
0005435720119	21217	Economy	9900.00
0005435720118	21217	Economy	9900.00
0005432295861	22761	Economy	8800.00
0005432295859	22761	Economy	8800.00
0005432295860	22761	Economy	8800.00
0005433342452	11104	Business	23600.00
0005433342453	11104	Business	23600.00
0005433342443	11104	Business	23600.00
0005433342402	11104	Business	23600.00
0005433342486	11104	Business	23600.00
0005433342466	11104	Business	23600.00
0005433342404	11104	Business	23600.00
0005433342442	11104	Business	23600.00
0005433342437	11104	Business	23600.00
0005435380227	11104	Business	23600.00
0005433342398	11104	Business	23600.00
0005433342438	11104	Economy	7900.00
0005435097134	11104	Economy	7900.00
0005433342468	11104	Economy	7900.00
0005433342456	11104	Economy	7900.00
0005433342416	11104	Economy	7900.00
0005435097139	11104	Economy	7900.00
0005433342423	11104	Economy	7900.00
0005433342405	11104	Economy	7900.00
0005433342487	11104	Economy	7900.00
0005433342479	11104	Economy	7900.00
0005433342395	11104	Economy	7900.00
0005433342424	11104	Economy	7900.00
0005433342429	11104	Economy	7900.00
0005433342433	11104	Economy	7900.00
0005433342436	11104	Economy	7900.00
0005433342467	11104	Economy	7900.00
0005435508168	11104	Economy	7900.00
0005433342427	11104	Economy	7900.00
0005435097131	11104	Economy	7900.00
0005433342474	11104	Economy	7900.00
0005433342417	11104	Economy	7900.00
0005433342488	11104	Economy	7900.00
0005435508169	11104	Economy	7900.00
0005433342410	11104	Economy	7900.00
0005433342459	11104	Economy	7900.00
0005435380246	11104	Economy	7900.00
0005433342495	11104	Economy	7900.00
0005433342478	11104	Economy	7900.00
0005433342471	11104	Economy	7900.00
0005433342460	11104	Economy	7900.00
0005433342477	11104	Economy	7900.00
0005433342497	11104	Economy	7900.00
0005433342421	11104	Economy	7900.00
0005433342414	11104	Economy	7900.00
0005433342426	11104	Economy	7900.00
0005433342400	11104	Economy	7900.00
0005433342454	11104	Economy	7900.00
0005433342425	11104	Economy	7900.00
0005433342461	11104	Economy	8600.00
0005433342418	11104	Economy	7900.00
0005433342430	11104	Economy	8600.00
0005433342490	11104	Economy	8600.00
0005433342439	11104	Economy	8600.00
0005435508181	11104	Economy	8600.00
0005433342451	11104	Economy	7900.00
0005433342483	11104	Economy	7900.00
0005433342464	11104	Economy	7900.00
0005433342492	11104	Economy	7900.00
0005433342419	11104	Economy	7900.00
0005435097137	11104	Economy	7900.00
0005433342447	11104	Economy	7900.00
0005433342449	11104	Economy	7900.00
0005433342485	11104	Economy	7900.00
0005435097135	11104	Economy	7900.00
0005435508182	11104	Economy	7900.00
0005433342480	11104	Economy	7900.00
0005433342473	11104	Economy	7900.00
0005433342431	11104	Economy	7900.00
0005433342472	11104	Economy	7900.00
0005435097138	11104	Economy	7900.00
0005433342448	11104	Economy	7900.00
0005433342489	11104	Economy	7900.00
0005433342482	11104	Economy	7900.00
0005433342496	11104	Economy	7900.00
0005433342445	11104	Economy	7900.00
0005433342491	11104	Economy	7900.00
0005433342457	11104	Economy	7900.00
0005433342401	11104	Economy	7900.00
0005433342397	11104	Economy	7900.00
0005433342413	11104	Economy	7900.00
0005433342420	11104	Economy	7900.00
0005433342458	11104	Economy	7900.00
0005435380228	11104	Economy	7900.00
0005433342476	11104	Economy	7900.00
0005433342407	11104	Economy	7900.00
0005433342403	11104	Economy	7900.00
0005433342494	11104	Economy	7900.00
0005433342462	11104	Economy	7900.00
0005433342406	11104	Economy	7900.00
0005433342463	11104	Economy	7900.00
0005433342470	11104	Economy	7900.00
0005433342428	11104	Economy	7900.00
0005433342422	11104	Economy	7900.00
0005433342446	11104	Economy	7900.00
0005433342465	11104	Economy	7900.00
0005433342493	11104	Economy	7900.00
0005433342481	11104	Economy	7900.00
0005435508188	11104	Economy	7900.00
0005433342450	11104	Economy	7900.00
0005433342396	11104	Economy	7900.00
0005435097136	11104	Economy	7900.00
0005433342444	11104	Economy	7900.00
0005435097140	11104	Economy	7900.00
0005433342409	11104	Economy	7900.00
0005435097132	11104	Economy	7900.00
0005435508187	11104	Economy	7900.00
0005433342411	11104	Economy	7900.00
0005433342408	11104	Economy	7900.00
0005433342412	11104	Economy	7900.00
0005433342440	11104	Economy	7900.00
0005433342475	11104	Economy	7900.00
0005433342432	11104	Economy	7900.00
0005433342415	11104	Economy	7900.00
0005433342435	11104	Economy	7900.00
0005433342469	11104	Economy	7900.00
0005435380229	11104	Economy	7900.00
0005433342441	11104	Economy	7900.00
0005435097133	11104	Economy	7900.00
0005433342434	11104	Economy	7900.00
0005433342399	11104	Economy	7900.00
0005433342455	11104	Economy	7900.00
0005435380245	11104	Economy	7900.00
0005433342484	11104	Economy	7900.00
0005435097130	11104	Economy	7900.00
0005433341393	17081	Business	23600.00
0005433341397	17081	Business	23600.00
0005433341499	17081	Business	23600.00
0005433341745	17081	Business	23600.00
0005433341838	17081	Business	23600.00
0005433341526	17081	Business	23600.00
0005433341837	17081	Business	23600.00
0005433341770	17081	Business	23600.00
0005433341660	17081	Business	23600.00
0005433341771	17081	Economy	7900.00
0005433341705	17081	Economy	7900.00
0005433341523	17081	Economy	7900.00
0005432293189	17081	Economy	7900.00
0005433341418	17081	Economy	7900.00
0005433341503	17081	Economy	7900.00
0005433341394	17081	Economy	7900.00
0005433341591	17081	Economy	7900.00
0005433341504	17081	Economy	7900.00
0005433341645	17081	Economy	7900.00
0005433341674	17081	Economy	7900.00
0005433341491	17081	Economy	7900.00
0005433341392	17081	Economy	7900.00
0005433341541	17081	Economy	7900.00
0005433341875	17081	Economy	7900.00
0005433341677	17081	Economy	7900.00
0005433341659	17081	Economy	7900.00
0005433341732	17081	Economy	7900.00
0005433341436	17081	Economy	7900.00
0005433341706	17081	Economy	7900.00
0005433341830	17081	Economy	7900.00
0005433341521	17081	Economy	7900.00
0005433341744	17081	Economy	7900.00
0005433341463	17081	Economy	7900.00
0005433341571	17081	Economy	7900.00
0005433341497	17081	Economy	7900.00
0005432293190	17081	Economy	7900.00
0005433341457	17081	Economy	8600.00
0005433341388	17081	Economy	8600.00
0005433341666	17081	Economy	8600.00
0005433341762	17081	Economy	8600.00
0005433341681	17081	Economy	8600.00
0005433341464	17081	Economy	8600.00
0005433341829	17081	Economy	7900.00
0005433341512	17081	Economy	7900.00
0005433341444	17081	Economy	7900.00
0005433341839	17081	Economy	7900.00
0005433341524	17081	Economy	7900.00
0005433341398	17081	Economy	7900.00
0005433341761	17081	Economy	7900.00
0005433341936	17081	Economy	7900.00
0005433341707	17081	Economy	7900.00
0005433341511	17081	Economy	7900.00
0005433341753	17081	Economy	7900.00
0005433341456	17081	Economy	7900.00
0005433341438	17081	Economy	7900.00
0005433341763	17081	Economy	7900.00
0005433341483	17081	Economy	7900.00
0005433341640	17081	Economy	7900.00
0005433341588	17081	Economy	7900.00
0005433341522	17081	Economy	7900.00
0005433341840	17081	Economy	7900.00
0005433341517	17081	Economy	7900.00
0005433341516	17081	Economy	7900.00
0005433341435	17081	Economy	7900.00
0005433341546	17081	Economy	7900.00
0005433341610	17081	Economy	7900.00
0005433341874	17081	Economy	7900.00
0005433341479	17081	Economy	7900.00
0005433341795	17081	Economy	7900.00
0005433341652	17081	Economy	7900.00
0005433341746	17081	Economy	7900.00
0005433341468	17081	Economy	7900.00
0005433341718	17081	Economy	7900.00
0005433341482	17081	Economy	7900.00
0005433341419	17081	Economy	7900.00
0005433341542	17081	Economy	7900.00
0005433341540	17081	Economy	7900.00
0005433341547	17081	Economy	7900.00
0005433341841	17081	Economy	7900.00
0005433341668	17081	Economy	7900.00
0005433341804	17081	Economy	7900.00
0005433341437	17081	Economy	7900.00
0005433341676	17081	Economy	7900.00
0005433341680	17081	Economy	7900.00
0005433341420	17081	Economy	7900.00
0005433341498	17081	Economy	7900.00
0005433341609	17081	Economy	7900.00
0005433341445	17081	Economy	7900.00
0005433341794	17081	Economy	7900.00
0005433341467	17081	Economy	7900.00
0005433341769	17081	Economy	7900.00
0005433341717	17081	Economy	7900.00
0005433341543	17081	Economy	7900.00
0005433341865	17081	Economy	7900.00
0005433341644	17081	Economy	7900.00
0005433341937	17081	Economy	7900.00
0005433481108	9069	Business	26600.00
0005433507059	9069	Business	26600.00
0005432919503	9069	Business	26600.00
0005433507058	9069	Business	26600.00
0005433507055	9069	Economy	8900.00
0005433507061	9069	Economy	8900.00
0005433481111	9069	Economy	8900.00
0005433507049	9069	Economy	8900.00
0005433481112	9069	Economy	8900.00
0005433481114	9069	Economy	8900.00
0005432919521	9069	Economy	8900.00
0005433507056	9069	Economy	8900.00
0005433507054	9069	Economy	8900.00
0005433507048	9069	Economy	8900.00
0005433481110	9069	Economy	8900.00
0005433507050	9069	Economy	8900.00
0005432919551	9069	Economy	8900.00
0005433507052	9069	Economy	8900.00
0005433507044	9069	Economy	8900.00
0005432919522	9069	Economy	8900.00
0005433481109	9069	Economy	8900.00
0005433507045	9069	Economy	8900.00
0005432919543	9069	Economy	8900.00
0005432919547	9069	Economy	8900.00
0005433507053	9069	Economy	8900.00
0005433507046	9069	Economy	8900.00
0005433507047	9069	Economy	8900.00
0005433507051	9069	Economy	8900.00
0005433507043	9069	Economy	8900.00
0005433507057	9069	Economy	8900.00
0005433481113	9069	Economy	8900.00
0005433507060	9069	Economy	8900.00
0005433481107	9069	Economy	8900.00
0005432919730	20439	Business	26600.00
0005432919731	20439	Business	26600.00
0005432919720	20439	Business	26600.00
0005433506870	20439	Business	26600.00
0005433481046	20439	Business	26600.00
0005432919725	20439	Business	26600.00
0005434158961	20439	Business	26600.00
0005432919723	20439	Business	26600.00
0005433506901	20439	Business	26600.00
0005433506854	20439	Economy	8900.00
0005432919734	20439	Economy	8900.00
0005433506959	20439	Economy	8900.00
0005433506938	20439	Economy	9800.00
0005433506909	20439	Economy	9800.00
0005433481040	20439	Economy	8900.00
0005433481067	20439	Economy	8900.00
0005432919717	20439	Economy	8900.00
0005432919736	20439	Economy	8900.00
0005433506947	20439	Economy	8900.00
0005433481027	20439	Economy	8900.00
0005432919718	20439	Economy	8900.00
0005434158963	20439	Economy	8900.00
0005432919735	20439	Economy	8900.00
0005432919724	20439	Economy	8900.00
0005433506916	20439	Economy	8900.00
0005434158962	20439	Economy	8900.00
0005433481084	20439	Economy	8900.00
0005432919727	20439	Economy	8900.00
0005433506894	20439	Economy	8900.00
0005433481074	20439	Economy	8900.00
0005432919733	20439	Economy	8900.00
0005433481028	20439	Economy	8900.00
0005432919719	20439	Economy	8900.00
0005432919722	20439	Economy	8900.00
0005432919721	20439	Economy	8900.00
0005432919729	20439	Economy	8900.00
0005433506921	20439	Economy	8900.00
0005432919728	20439	Economy	8900.00
0005433481075	20439	Economy	8900.00
0005432919732	20439	Economy	8900.00
0005433506981	20439	Economy	8900.00
0005433481068	20439	Economy	8900.00
0005433506922	20439	Economy	8900.00
0005433506905	20439	Economy	8900.00
0005432919737	20439	Economy	8900.00
0005432919726	20439	Economy	8900.00
0005432394072	10211	Economy	5800.00
0005432396209	10211	Economy	5800.00
0005432394070	10211	Economy	5800.00
0005432396208	10211	Economy	5800.00
0005432394069	10211	Economy	5800.00
0005435179687	10211	Economy	5800.00
0005432396211	10211	Economy	5800.00
0005432394071	10211	Economy	5800.00
0005435179686	10211	Economy	5800.00
0005432396210	10211	Economy	5800.00
0005435179390	18343	Economy	5800.00
0005435179689	18343	Economy	5800.00
0005435125762	11050	Business	9500.00
0005435125692	11050	Business	9500.00
0005434928278	11050	Business	9500.00
0005435556651	11050	Business	9500.00
0005435556649	11050	Business	9500.00
0005435125677	11050	Business	9500.00
0005435625896	11050	Business	9500.00
0005435125689	11050	Business	9500.00
0005435125648	11050	Economy	3200.00
0005434928280	11050	Economy	3200.00
0005435625885	11050	Economy	3200.00
0005434411749	11050	Economy	3200.00
0005435625901	11050	Economy	3200.00
0005435125712	11050	Economy	3200.00
0005435125718	11050	Economy	3500.00
0005434411745	11050	Economy	3500.00
0005434411746	11050	Economy	3500.00
0005435625895	11050	Economy	3500.00
0005435125680	11050	Economy	3200.00
0005435125690	11050	Economy	3200.00
0005435556647	11050	Economy	3200.00
0005435125708	11050	Economy	3200.00
0005434928279	11050	Economy	3200.00
0005434928281	11050	Economy	3200.00
0005435125725	11050	Economy	3200.00
0005435125707	11050	Economy	3200.00
0005435125746	11050	Economy	3200.00
0005435625880	11050	Economy	3200.00
0005435125647	11050	Economy	3200.00
0005435625900	11050	Economy	3200.00
0005435556648	11050	Economy	3200.00
0005435125678	11050	Economy	3200.00
0005435125722	11050	Economy	3200.00
0005435125655	11050	Economy	3200.00
0005435125693	11050	Economy	3200.00
0005435125711	11050	Economy	3200.00
0005435125727	11050	Economy	3200.00
0005434411747	11050	Economy	3200.00
0005435125883	11050	Economy	3200.00
0005435125682	11050	Economy	3200.00
0005435625879	11050	Economy	3200.00
0005434411748	11050	Economy	3200.00
0005435125825	11050	Economy	3200.00
0005435125922	11050	Economy	3200.00
0005435625883	11050	Economy	3200.00
0005435556652	11050	Economy	3200.00
0005435625881	11050	Economy	3200.00
0005435556650	11050	Economy	3200.00
0005435125836	11050	Economy	3200.00
0005435125781	11050	Economy	3200.00
0005435125721	11050	Economy	3200.00
0005435625884	11050	Economy	3200.00
0005435125705	11050	Economy	3200.00
0005435625882	11050	Economy	3200.00
0005435125726	11050	Economy	3200.00
0005435125691	11050	Economy	3200.00
0005435125882	11050	Economy	3200.00
0005435626043	14731	Business	9500.00
0005435626045	14731	Business	9500.00
0005435126077	14731	Business	9500.00
0005435126067	14731	Business	9500.00
0005435126096	14731	Business	9500.00
0005435126076	14731	Economy	3200.00
0005435126071	14731	Economy	3200.00
0005435126081	14731	Economy	3200.00
0005435126099	14731	Economy	3200.00
0005434411708	14731	Economy	3200.00
0005434411701	14731	Economy	3200.00
0005435626050	14731	Economy	3200.00
0005435126095	14731	Economy	3200.00
0005435626051	14731	Economy	3200.00
0005435126082	14731	Economy	3500.00
0005435126094	14731	Economy	3500.00
0005435126098	14731	Economy	3500.00
0005435626046	14731	Economy	3500.00
0005435126078	14731	Economy	3200.00
0005435554149	14731	Economy	3200.00
0005435126075	14731	Economy	3200.00
0005435126088	14731	Economy	3200.00
0005435626047	14731	Economy	3200.00
0005435126091	14731	Economy	3200.00
0005435126083	14731	Economy	3200.00
0005435626042	14731	Economy	3200.00
0005435126090	14731	Economy	3200.00
0005435556672	14731	Economy	3200.00
0005435126092	14731	Economy	3200.00
0005435626048	14731	Economy	3200.00
0005435126101	14731	Economy	3200.00
0005435126100	14731	Economy	3200.00
0005435626041	14731	Economy	3200.00
0005435126097	14731	Economy	3200.00
0005435126089	14731	Economy	3200.00
0005435126073	14731	Economy	3200.00
0005435126103	14731	Economy	3200.00
0005435126085	14731	Economy	3200.00
0005435126093	14731	Economy	3200.00
0005435126084	14731	Economy	3200.00
0005435126066	14731	Economy	3200.00
0005435626049	14731	Economy	3200.00
0005435126087	14731	Economy	3200.00
0005435126069	14731	Economy	3200.00
0005435126068	14731	Economy	3200.00
0005435126086	14731	Economy	3200.00
0005435626044	14731	Economy	3200.00
0005435126070	14731	Economy	3200.00
0005435126080	14731	Economy	3200.00
0005435126102	14731	Economy	3200.00
0005435554152	14731	Economy	3200.00
0005435554151	14731	Economy	3200.00
0005435626053	14731	Economy	3200.00
0005435556673	14731	Economy	3200.00
0005435626040	14731	Economy	3200.00
0005435554150	14731	Economy	3200.00
0005435126065	14731	Economy	3200.00
0005435126064	14731	Economy	3200.00
0005434928258	14731	Economy	3200.00
0005435126072	14731	Economy	3200.00
0005435126079	14731	Economy	3200.00
0005435626052	14731	Economy	3200.00
0005435126105	14731	Economy	3200.00
0005435126074	14731	Economy	3200.00
0005435626054	14731	Economy	3200.00
0005435126104	14731	Economy	3200.00
0005435715338	7115	Business	86900.00
0005435715348	7115	Business	86900.00
0005435715353	7115	Business	86900.00
0005435715339	7115	Business	86900.00
0005435715341	7115	Business	86900.00
0005435219172	7115	Business	86900.00
0005435443188	7115	Business	86900.00
0005435221040	7115	Economy	29000.00
0005432400097	7115	Economy	29000.00
0005435715350	7115	Economy	29000.00
0005435443150	7115	Economy	31900.00
0005435221039	7115	Economy	29000.00
0005432398169	7115	Economy	29000.00
0005435443161	7115	Economy	29000.00
0005432398171	7115	Economy	29000.00
0005435715351	7115	Economy	29000.00
0005432398168	7115	Economy	29000.00
0005432398170	7115	Economy	29000.00
0005435715346	7115	Economy	29000.00
0005435715347	7115	Economy	29000.00
0005435715337	7115	Economy	29000.00
0005435715343	7115	Economy	29000.00
0005435443149	7115	Economy	29000.00
0005435219171	7115	Economy	29000.00
0005435221037	7115	Economy	29000.00
0005432398172	7115	Economy	29000.00
0005435715352	7115	Economy	29000.00
0005435715344	7115	Economy	29000.00
0005435221038	7115	Economy	29000.00
0005435715349	7115	Economy	29000.00
0005435715335	7115	Economy	29000.00
0005435715342	7115	Economy	29000.00
0005435443168	7115	Economy	29000.00
0005435715340	7115	Economy	29000.00
0005435715345	7115	Economy	29000.00
0005435715336	7115	Economy	29000.00
0005432398135	27096	Business	86900.00
0005432398142	27096	Business	86900.00
0005432394042	27096	Business	86900.00
0005435715258	27096	Business	86900.00
0005435443247	27096	Business	86900.00
0005435715226	27096	Economy	29000.00
0005435443244	27096	Economy	29000.00
0005435178483	27096	Economy	29000.00
0005435715273	27096	Economy	29000.00
0005435715173	27096	Economy	29000.00
0005435715274	27096	Economy	29000.00
0005435715259	27096	Economy	31900.00
0005435715214	27096	Economy	29000.00
0005435715251	27096	Economy	29000.00
0005435715218	27096	Economy	29000.00
0005435443242	27096	Economy	29000.00
0005432394045	27096	Economy	29000.00
0005435715222	27096	Economy	29000.00
0005435443243	27096	Economy	29000.00
0005432394041	27096	Economy	29000.00
0005435715187	27096	Economy	29000.00
0005432394034	27096	Economy	29000.00
0005432394046	27096	Economy	29000.00
0005435443245	27096	Economy	29000.00
0005435443248	27096	Economy	29000.00
0005435715223	27096	Economy	29000.00
0005435715191	27096	Economy	29000.00
0005435715201	27096	Economy	29000.00
0005435715221	27096	Economy	29000.00
0005435443249	27096	Economy	29000.00
0005435443246	27096	Economy	29000.00
0005435715250	27096	Economy	29000.00
0005435715192	27096	Economy	29000.00
0005435178482	27096	Economy	29000.00
0005435715188	27096	Economy	29000.00
0005432398131	27096	Economy	29000.00
0005435715264	27096	Economy	29000.00
0005432394044	27096	Economy	29000.00
0005435715200	27096	Economy	29000.00
0005434084898	2715	Economy	7700.00
0005434084896	2715	Economy	7700.00
0005434084897	2715	Economy	7700.00
0005434084899	2715	Economy	7700.00
0005433060377	2715	Economy	7700.00
0005434084869	28492	Economy	7700.00
0005434084880	28492	Economy	7700.00
0005434084863	28492	Economy	7700.00
0005434084881	28492	Economy	7700.00
0005434084879	28492	Economy	7700.00
0005433060394	28492	Economy	7700.00
0005434084851	28492	Economy	7700.00
0005433060393	28492	Economy	7700.00
0005432632666	25199	Economy	29000.00
0005432632674	25199	Economy	29000.00
0005432632659	25199	Economy	26400.00
0005432632655	25199	Economy	26400.00
0005432632679	25199	Economy	26400.00
0005432632656	25199	Economy	26400.00
0005432632668	25199	Economy	26400.00
0005432632660	25199	Economy	26400.00
0005432632678	25199	Economy	26400.00
0005432632680	25199	Economy	26400.00
0005432632671	25199	Economy	26400.00
0005432632683	25199	Economy	26400.00
0005432632664	25199	Economy	26400.00
0005432632669	25199	Economy	26400.00
0005432632676	25199	Economy	26400.00
0005432632670	25199	Economy	26400.00
0005432632657	25199	Economy	26400.00
0005432632677	25199	Economy	26400.00
0005432632682	25199	Economy	26400.00
0005432632661	25199	Economy	26400.00
0005432632675	25199	Economy	26400.00
0005432632681	25199	Economy	26400.00
0005432632672	25199	Economy	26400.00
0005432632667	25199	Economy	26400.00
0005432632673	25199	Economy	26400.00
0005432632665	25199	Economy	26400.00
0005432632662	25199	Economy	26400.00
0005432632658	25199	Economy	26400.00
0005432632663	25199	Economy	26400.00
0005435844288	28170	Economy	29000.00
0005435844292	28170	Economy	29000.00
0005435844294	28170	Economy	26400.00
0005435844297	28170	Economy	26400.00
0005432632636	28170	Economy	26400.00
0005435844289	28170	Economy	26400.00
0005435844298	28170	Economy	26400.00
0005432632629	28170	Economy	26400.00
0005435844284	28170	Economy	26400.00
0005432632632	28170	Economy	26400.00
0005435844295	28170	Economy	26400.00
0005435844296	28170	Economy	26400.00
0005435844290	28170	Economy	26400.00
0005435844291	28170	Economy	26400.00
0005432632623	28170	Economy	26400.00
0005435844285	28170	Economy	26400.00
0005435844287	28170	Economy	26400.00
0005435844293	28170	Economy	26400.00
0005432632640	28170	Economy	26400.00
0005435844283	28170	Economy	26400.00
0005435844286	28170	Economy	26400.00
0005435540700	11417	Business	20200.00
0005435517684	11417	Business	20200.00
0005435540627	11417	Economy	6700.00
0005435517631	11417	Economy	6700.00
0005435517666	11417	Economy	6700.00
0005435517622	11417	Economy	6700.00
0005435517598	11417	Economy	6700.00
0005435540726	11417	Economy	6700.00
0005435540699	11417	Economy	6700.00
0005435540737	11417	Economy	6700.00
0005435540624	11417	Economy	6700.00
0005435517625	11417	Economy	6700.00
0005435517686	11417	Economy	6700.00
0005435517685	11417	Economy	6700.00
0005435517617	11417	Economy	6700.00
0005435540646	11417	Economy	6700.00
0005435517681	11417	Economy	6700.00
0005435540625	11417	Economy	6700.00
0005435540750	11417	Economy	6700.00
0005435540703	11417	Economy	6700.00
0005435540673	11417	Economy	6700.00
0005435517662	11417	Economy	6700.00
0005435517630	11417	Economy	6700.00
0005435517619	11417	Economy	6700.00
0005435540839	22266	Business	20200.00
0005435529079	22266	Business	20200.00
0005435540825	22266	Business	20200.00
0005435529090	22266	Business	20200.00
0005435540843	22266	Business	20200.00
0005435529087	22266	Economy	6700.00
0005435529080	22266	Economy	6700.00
0005435540835	22266	Economy	6700.00
0005435529086	22266	Economy	6700.00
0005435540828	22266	Economy	6700.00
0005435529082	22266	Economy	6700.00
0005435529088	22266	Economy	7400.00
0005435540831	22266	Economy	7400.00
0005435529099	22266	Economy	7400.00
0005435540829	22266	Economy	7400.00
0005435529085	22266	Economy	6700.00
0005435540824	22266	Economy	6700.00
0005435529078	22266	Economy	6700.00
0005435529095	22266	Economy	6700.00
0005435540838	22266	Economy	6700.00
0005435529094	22266	Economy	6700.00
0005435529081	22266	Economy	6700.00
0005435540830	22266	Economy	6700.00
0005435540823	22266	Economy	6700.00
0005435529092	22266	Economy	6700.00
0005435540836	22266	Economy	6700.00
0005432294467	22266	Economy	6700.00
0005435529097	22266	Economy	6700.00
0005435529084	22266	Economy	6700.00
0005435540841	22266	Economy	6700.00
0005435529091	22266	Economy	6700.00
0005435540833	22266	Economy	6700.00
0005435540842	22266	Economy	6700.00
0005435540832	22266	Economy	6700.00
0005432294469	22266	Economy	6700.00
0005435529096	22266	Economy	6700.00
0005435529083	22266	Economy	6700.00
0005432294468	22266	Economy	6700.00
0005435540826	22266	Economy	6700.00
0005435529098	22266	Economy	6700.00
0005435540840	22266	Economy	6700.00
0005435529093	22266	Economy	6700.00
0005435540834	22266	Economy	6700.00
0005435540827	22266	Economy	6700.00
0005435529089	22266	Economy	6700.00
0005435540837	22266	Economy	6700.00
0005433251043	2312	Business	20200.00
0005434906916	2312	Business	20200.00
0005434906928	2312	Business	20200.00
0005434906929	2312	Business	20200.00
0005433250992	2312	Business	20200.00
0005433251105	2312	Business	20200.00
0005434906945	2312	Business	20200.00
0005433250972	2312	Business	20200.00
0005434906936	2312	Business	20200.00
0005433251104	2312	Economy	6700.00
0005434906947	2312	Economy	6700.00
0005433251128	2312	Economy	6700.00
0005433251049	2312	Economy	6700.00
0005433251048	2312	Economy	6700.00
0005433251086	2312	Economy	6700.00
0005434906942	2312	Economy	6700.00
0005434906937	2312	Economy	6700.00
0005434906911	2312	Economy	6700.00
0005434906917	2312	Economy	7400.00
0005434906921	2312	Economy	7400.00
0005433251061	2312	Economy	7400.00
0005434906915	2312	Economy	7400.00
0005433251073	2312	Economy	6700.00
0005434906923	2312	Economy	6700.00
0005434906922	2312	Economy	6700.00
0005434906932	2312	Economy	6700.00
0005434906909	2312	Economy	6700.00
0005433251063	2312	Economy	6700.00
0005433251142	2312	Economy	6700.00
0005434906935	2312	Economy	6700.00
0005434906905	2312	Economy	6700.00
0005433250965	2312	Economy	6700.00
0005433251040	2312	Economy	6700.00
0005434906934	2312	Economy	6700.00
0005434906941	2312	Economy	6700.00
0005433251143	2312	Economy	6700.00
0005434906944	2312	Economy	6700.00
0005434906946	2312	Economy	6700.00
0005434906908	2312	Economy	6700.00
0005434906918	2312	Economy	6700.00
0005434906914	2312	Economy	6700.00
0005434906930	2312	Economy	6700.00
0005433251088	2312	Economy	6700.00
0005434906925	2312	Economy	6700.00
0005433400930	2312	Economy	6700.00
0005434906949	2312	Economy	6700.00
0005434906913	2312	Economy	6700.00
0005434906939	2312	Economy	6700.00
0005434906943	2312	Economy	6700.00
0005433251087	2312	Economy	6700.00
0005433400936	2312	Economy	6700.00
0005433250971	2312	Economy	6700.00
0005434906940	2312	Economy	6700.00
0005434906912	2312	Economy	6700.00
0005433250975	2312	Economy	6700.00
0005433251053	2312	Economy	6700.00
0005434906907	2312	Economy	6700.00
0005434906924	2312	Economy	6700.00
0005434906927	2312	Economy	6700.00
0005433251204	2312	Economy	6700.00
0005434906926	2312	Economy	6700.00
0005433251047	2312	Economy	6700.00
0005434906938	2312	Economy	6700.00
0005434906919	2312	Economy	6700.00
0005434906948	2312	Economy	6700.00
0005433251083	2312	Economy	6700.00
0005434906933	2312	Economy	6700.00
0005433251052	2312	Economy	6700.00
0005434906920	2312	Economy	6700.00
0005434906950	2312	Economy	6700.00
0005433251103	2312	Economy	6700.00
0005434906906	2312	Economy	6700.00
0005434906931	2312	Economy	6700.00
0005434906910	2312	Economy	6700.00
0005433251032	2312	Economy	6700.00
0005433251149	2312	Economy	6700.00
0005433250987	2312	Economy	6700.00
0005433251041	2312	Economy	6700.00
0005433251254	25595	Business	20200.00
0005433251260	25595	Business	20200.00
0005434906556	25595	Business	20200.00
0005433251271	25595	Business	20200.00
0005434906412	25595	Business	20200.00
0005433251247	25595	Business	20200.00
0005433251255	25595	Business	20200.00
0005433251261	25595	Business	20200.00
0005433251264	25595	Business	20200.00
0005434906516	25595	Business	20200.00
0005433251262	25595	Economy	6700.00
0005434906538	25595	Economy	6700.00
0005433400962	25595	Economy	6700.00
0005434906435	25595	Economy	6700.00
0005433251258	25595	Economy	6700.00
0005433251266	25595	Economy	6700.00
0005434906417	25595	Economy	6700.00
0005434906515	25595	Economy	6700.00
0005434906419	25595	Economy	6700.00
0005434906416	25595	Economy	7400.00
0005433251243	25595	Economy	7400.00
0005433251246	25595	Economy	7400.00
0005434906514	25595	Economy	7400.00
0005434906413	25595	Economy	6700.00
0005434906562	25595	Economy	6700.00
0005434906484	25595	Economy	6700.00
0005434906522	25595	Economy	6700.00
0005433251273	25595	Economy	6700.00
0005433251248	25595	Economy	6700.00
0005434906393	25595	Economy	6700.00
0005433400960	25595	Economy	6700.00
0005433251256	25595	Economy	6700.00
0005434906545	25595	Economy	6700.00
0005433251274	25595	Economy	6700.00
0005433251259	25595	Economy	6700.00
0005433251253	25595	Economy	6700.00
0005434906392	25595	Economy	6700.00
0005434906481	25595	Economy	6700.00
0005434906495	25595	Economy	6700.00
0005434906426	25595	Economy	6700.00
0005434906448	25595	Economy	6700.00
0005433251245	25595	Economy	6700.00
0005433251267	25595	Economy	6700.00
0005433251272	25595	Economy	6700.00
0005434906506	25595	Economy	6700.00
0005434906521	25595	Economy	6700.00
0005434906402	25595	Economy	6700.00
0005433251250	25595	Economy	6700.00
0005434906364	25595	Economy	6700.00
0005434906443	25595	Economy	6700.00
0005434906414	25595	Economy	6700.00
0005433251263	25595	Economy	6700.00
0005434906523	25595	Economy	6700.00
0005433251265	25595	Economy	6700.00
0005433251249	25595	Economy	6700.00
0005433251252	25595	Economy	6700.00
0005434906449	25595	Economy	6700.00
0005434906528	25595	Economy	6700.00
0005433400961	25595	Economy	6700.00
0005434906517	25595	Economy	6700.00
0005434906496	25595	Economy	6700.00
0005433251268	25595	Economy	6700.00
0005433251244	25595	Economy	6700.00
0005433251257	25595	Economy	6700.00
0005433251251	25595	Economy	6700.00
0005433251269	25595	Economy	6700.00
0005434906534	25595	Economy	6700.00
0005433251270	25595	Economy	6700.00
0005434906518	25595	Economy	6700.00
0005432862206	2529	Economy	13600.00
0005432862212	2529	Economy	13600.00
0005432620944	2529	Economy	13600.00
0005432862183	2529	Economy	12400.00
0005432862178	2529	Economy	12400.00
0005432620937	2529	Economy	12400.00
0005432620933	2529	Economy	12400.00
0005432620938	2529	Economy	12400.00
0005432620939	2529	Economy	12400.00
0005432862172	2529	Economy	12400.00
0005432620935	2529	Economy	12400.00
0005432620940	2529	Economy	12400.00
0005432862177	2529	Economy	12400.00
0005432862207	2529	Economy	12400.00
0005432862213	2529	Economy	12400.00
0005432620941	2529	Economy	12400.00
0005432620934	2529	Economy	12400.00
0005432862180	2529	Economy	12400.00
0005432620943	2529	Economy	12400.00
0005432620936	2529	Economy	12400.00
0005432862179	2529	Economy	12400.00
0005432862211	2529	Economy	12400.00
0005432862182	2529	Economy	12400.00
0005432620942	2529	Economy	12400.00
0005432862184	2529	Economy	12400.00
0005432620876	28072	Economy	13600.00
0005432620813	28072	Economy	13600.00
0005432620856	28072	Economy	13600.00
0005432862242	28072	Economy	12400.00
0005432862245	28072	Economy	12400.00
0005432620855	28072	Economy	12400.00
0005432620804	28072	Economy	12400.00
0005432862243	28072	Economy	12400.00
0005432620805	28072	Economy	12400.00
0005432620864	28072	Economy	12400.00
0005432862249	28072	Economy	12400.00
0005432862248	28072	Economy	12400.00
0005432862247	28072	Economy	12400.00
0005432620803	28072	Economy	12400.00
0005432620807	28072	Economy	12400.00
0005432862246	28072	Economy	12400.00
0005432620829	28072	Economy	12400.00
0005432620808	28072	Economy	12400.00
0005432620802	28072	Economy	12400.00
0005432620801	28072	Economy	12400.00
0005432862244	28072	Economy	12400.00
0005434097449	11737	Economy	11300.00
0005434097458	11737	Economy	11300.00
0005434097466	13028	Economy	11300.00
0005433451604	31068	Economy	8400.00
0005433451605	31068	Economy	8400.00
0005433452723	31068	Economy	8400.00
0005433452724	31068	Economy	8400.00
0005433452706	31430	Economy	8400.00
0005433454845	31430	Economy	8400.00
0005433454851	31430	Economy	8400.00
0005433454846	31430	Economy	8400.00
0005433129212	12028	Economy	7200.00
0005433134064	12028	Economy	6600.00
0005433134056	12028	Economy	6600.00
0005433134062	12028	Economy	6600.00
0005433134077	12028	Economy	6600.00
0005433129217	12028	Economy	6600.00
0005433134076	12028	Economy	6600.00
0005433129216	12028	Economy	6600.00
0005434142552	12028	Economy	6600.00
0005433129213	12028	Economy	6600.00
0005434142557	12028	Economy	6600.00
0005434142553	12028	Economy	6600.00
0005434142551	12028	Economy	6600.00
0005434183565	29820	Economy	7200.00
0005434184650	29820	Economy	6600.00
0005433134103	29820	Economy	6600.00
0005433134104	29820	Economy	6600.00
0005433134105	29820	Economy	6600.00
0005434142577	29820	Economy	6600.00
0005434183564	29820	Economy	6600.00
0005433134106	29820	Economy	6600.00
0005434142579	29820	Economy	6600.00
0005433131675	29820	Economy	6600.00
0005433131674	29820	Economy	6600.00
0005433134107	29820	Economy	6600.00
0005434142578	29820	Economy	6600.00
0005434184651	29820	Economy	6600.00
0005434142581	29820	Economy	6600.00
0005434142580	29820	Economy	6600.00
0005433131677	29820	Economy	6600.00
0005433131676	29820	Economy	6600.00
0005435697103	16453	Economy	19900.00
0005435697118	16453	Economy	19900.00
0005435697125	16453	Economy	19900.00
0005435697115	16453	Economy	18100.00
0005435697106	16453	Economy	18100.00
0005435697109	16453	Economy	18100.00
0005435697130	16453	Economy	18100.00
0005435697127	16453	Economy	18100.00
0005435697107	16453	Economy	18100.00
0005435697124	16453	Economy	18100.00
0005435934996	16453	Economy	18100.00
0005435697104	16453	Economy	18100.00
0005435697111	16453	Economy	18100.00
0005435697122	16453	Economy	18100.00
0005435697116	16453	Economy	18100.00
0005435697102	16453	Economy	18100.00
0005435697113	16453	Economy	18100.00
0005435697108	16453	Economy	18100.00
0005435697129	16453	Economy	18100.00
0005435697110	16453	Economy	18100.00
0005435697119	16453	Economy	18100.00
0005435697120	16453	Economy	18100.00
0005435697117	16453	Economy	18100.00
0005435697123	16453	Economy	18100.00
0005435697128	16453	Economy	18100.00
0005435697105	16453	Economy	18100.00
0005435934994	16453	Economy	18100.00
0005435934995	16453	Economy	18100.00
0005435697114	16453	Economy	18100.00
0005435697126	16453	Economy	18100.00
0005435697121	16453	Economy	18100.00
0005435697112	16453	Economy	18100.00
0005435696992	24732	Economy	19900.00
0005435696963	24732	Economy	19900.00
0005435935022	24732	Economy	18100.00
0005435696911	24732	Economy	18100.00
0005435696943	24732	Economy	18100.00
0005435696912	24732	Economy	18100.00
0005435696942	24732	Economy	18100.00
0005435696997	24732	Economy	18100.00
0005435935020	24732	Economy	18100.00
0005435696892	24732	Economy	18100.00
0005435696959	24732	Economy	18100.00
0005435935023	24732	Economy	18100.00
0005435696958	24732	Economy	18100.00
0005435696956	24732	Economy	18100.00
0005435696903	24732	Economy	18100.00
0005435696890	24732	Economy	18100.00
0005435696935	24732	Economy	18100.00
0005435696899	24732	Economy	18100.00
0005435696902	24732	Economy	18100.00
0005435696913	24732	Economy	18100.00
0005435696999	24732	Economy	18100.00
0005435696873	24732	Economy	18100.00
0005435696998	24732	Economy	18100.00
0005435696900	24732	Economy	18100.00
0005435935021	24732	Economy	18100.00
0005435696955	24732	Economy	18100.00
0005433724770	18759	Economy	4400.00
0005432968801	18759	Economy	4400.00
0005433724769	18759	Economy	4400.00
0005433724767	18759	Economy	4400.00
0005433724771	18759	Economy	4400.00
0005433724768	18759	Economy	4400.00
0005433724756	21608	Economy	4400.00
0005433724733	21608	Economy	4400.00
0005432968825	21608	Economy	4400.00
0005433724747	21608	Economy	4400.00
0005432968826	21608	Economy	4400.00
0005433724755	21608	Economy	4400.00
0005434137607	7348	Business	23100.00
0005434137557	7348	Business	23100.00
0005434087478	7348	Business	23100.00
0005434137604	7348	Business	23100.00
0005434137616	7348	Business	23100.00
0005434137551	7348	Business	23100.00
0005434137580	7348	Business	23100.00
0005434137591	7348	Business	23100.00
0005434137553	7348	Business	23100.00
0005434137599	7348	Business	23100.00
0005434137608	7348	Economy	7700.00
0005434087477	7348	Economy	7700.00
0005434137541	7348	Economy	7700.00
0005434137560	7348	Economy	7700.00
0005434137576	7348	Economy	7700.00
0005434137617	7348	Economy	7700.00
0005434137572	7348	Economy	7700.00
0005434137620	7348	Economy	7700.00
0005434137565	7348	Economy	7700.00
0005434137547	7348	Economy	7700.00
0005434137585	7348	Economy	8500.00
0005434137561	7348	Economy	8500.00
0005434137601	7348	Economy	8500.00
0005434137605	7348	Economy	8500.00
0005434087479	7348	Economy	7700.00
0005434137543	7348	Economy	7700.00
0005434137562	7348	Economy	7700.00
0005434137611	7348	Economy	7700.00
0005434137544	7348	Economy	7700.00
0005434137564	7348	Economy	7700.00
0005434137567	7348	Economy	7700.00
0005434137618	7348	Economy	7700.00
0005434137583	7348	Economy	7700.00
0005434137595	7348	Economy	7700.00
0005434137593	7348	Economy	7700.00
0005434137549	7348	Economy	7700.00
0005434137570	7348	Economy	7700.00
0005434137615	7348	Economy	7700.00
0005434137546	7348	Economy	7700.00
0005434137554	7348	Economy	7700.00
0005434137540	7348	Economy	7700.00
0005434137614	7348	Economy	7700.00
0005434137573	7348	Economy	7700.00
0005434137556	7348	Economy	7700.00
0005434137577	7348	Economy	7700.00
0005434137563	7348	Economy	7700.00
0005434137590	7348	Economy	7700.00
0005434137602	7348	Economy	7700.00
0005434137552	7348	Economy	7700.00
0005434137606	7348	Economy	7700.00
0005434137596	7348	Economy	7700.00
0005434137609	7348	Economy	7700.00
0005434137610	7348	Economy	7700.00
0005434137575	7348	Economy	7700.00
0005434137538	7348	Economy	7700.00
0005434137555	7348	Economy	7700.00
0005434137594	7348	Economy	7700.00
0005434137588	7348	Economy	7700.00
0005434137574	7348	Economy	7700.00
0005434137571	7348	Economy	7700.00
0005434137545	7348	Economy	7700.00
0005434137548	7348	Economy	7700.00
0005434137579	7348	Economy	7700.00
0005434137619	7348	Economy	7700.00
0005434137539	7348	Economy	7700.00
0005434137613	7348	Economy	7700.00
0005434137566	7348	Economy	7700.00
0005434137542	7348	Economy	7700.00
0005434137569	7348	Economy	7700.00
0005434137597	7348	Economy	7700.00
0005434137598	7348	Economy	7700.00
0005434087480	7348	Economy	7700.00
0005434137582	7348	Economy	7700.00
0005434137587	7348	Economy	7700.00
0005434137622	7348	Economy	7700.00
0005434137589	7348	Economy	7700.00
0005434137558	7348	Economy	7700.00
0005434137600	7348	Economy	7700.00
0005434137586	7348	Economy	7700.00
0005434137603	7348	Economy	7700.00
0005434137592	7348	Economy	7700.00
0005434137559	7348	Economy	7700.00
0005434137550	7348	Economy	7700.00
0005434137581	7348	Economy	7700.00
0005434137578	7348	Economy	7700.00
0005434137584	7348	Economy	7700.00
0005434137621	7348	Economy	7700.00
0005434137612	7348	Economy	7700.00
0005434137568	7348	Economy	7700.00
0005434137623	7348	Economy	7700.00
0005434136930	28585	Business	23100.00
0005434136745	28585	Business	23100.00
0005434136708	28585	Business	23100.00
0005434136771	28585	Business	23100.00
0005434136707	28585	Business	23100.00
0005434136867	28585	Business	23100.00
0005434087427	28585	Economy	7700.00
0005434136835	28585	Economy	7700.00
0005434136703	28585	Economy	7700.00
0005434136691	28585	Economy	7700.00
0005434136830	28585	Economy	7700.00
0005434136681	28585	Economy	7700.00
0005434136819	28585	Economy	8500.00
0005434087428	28585	Economy	8500.00
0005434136747	28585	Economy	8500.00
0005434136916	28585	Economy	8500.00
0005434136786	28585	Economy	7700.00
0005434136885	28585	Economy	7700.00
0005434136906	28585	Economy	7700.00
0005434136915	28585	Economy	7700.00
0005434087441	28585	Economy	7700.00
0005434136878	28585	Economy	7700.00
0005434136744	28585	Economy	7700.00
0005434136710	28585	Economy	7700.00
0005434136752	28585	Economy	7700.00
0005434136702	28585	Economy	7700.00
0005434136799	28585	Economy	7700.00
0005434136727	28585	Economy	7700.00
0005434136732	28585	Economy	7700.00
0005434136905	28585	Economy	7700.00
0005434136756	28585	Economy	7700.00
0005434136735	28585	Economy	7700.00
0005434136925	28585	Economy	7700.00
0005434136919	28585	Economy	7700.00
0005434136731	28585	Economy	7700.00
0005434136785	28585	Economy	7700.00
0005434136815	28585	Economy	7700.00
0005434136929	28585	Economy	7700.00
0005434136746	28585	Economy	7700.00
0005434136763	28585	Economy	7700.00
0005434136734	28585	Economy	7700.00
0005434136816	28585	Economy	7700.00
0005434136797	28585	Economy	7700.00
0005434136793	28585	Economy	7700.00
0005434136704	28585	Economy	7700.00
0005434136866	28585	Economy	7700.00
0005434136834	28585	Economy	7700.00
0005434136924	28585	Economy	7700.00
0005434136792	28585	Economy	7700.00
0005434087442	28585	Economy	7700.00
0005434136714	28585	Economy	7700.00
0005434136693	28585	Economy	7700.00
0005434136692	28585	Economy	7700.00
0005434136711	28585	Economy	7700.00
0005434136841	28585	Economy	7700.00
0005434136713	28585	Economy	7700.00
0005434136791	28585	Economy	7700.00
0005434136879	28585	Economy	7700.00
0005434136904	28585	Economy	7700.00
0005434136839	28585	Economy	7700.00
0005434136712	28585	Economy	7700.00
0005434136880	28585	Economy	7700.00
0005434610204	1930	Economy	23900.00
0005435808163	1930	Economy	23900.00
0005435808158	1930	Economy	21700.00
0005435808160	1930	Economy	21700.00
0005434610205	1930	Economy	21700.00
0005433407489	1930	Economy	21700.00
0005434610203	1930	Economy	21700.00
0005435808165	1930	Economy	21700.00
0005434610202	1930	Economy	21700.00
0005435808166	1930	Economy	21700.00
0005435808164	1930	Economy	21700.00
0005435808156	1930	Economy	21700.00
0005435808161	1930	Economy	21700.00
0005435808159	1930	Economy	21700.00
0005433407502	1930	Economy	21700.00
0005435808167	1930	Economy	21700.00
0005435808157	1930	Economy	21700.00
0005435808162	1930	Economy	21700.00
0005434610201	1930	Economy	21700.00
0005435808062	23079	Economy	23900.00
0005433407529	23079	Economy	23900.00
0005435808073	23079	Economy	23900.00
0005433407526	23079	Economy	21700.00
0005435808058	23079	Economy	21700.00
0005433407520	23079	Economy	21700.00
0005435808059	23079	Economy	21700.00
0005435808066	23079	Economy	21700.00
0005435808064	23079	Economy	21700.00
0005435808060	23079	Economy	21700.00
0005435808067	23079	Economy	21700.00
0005435808070	23079	Economy	21700.00
0005433407527	23079	Economy	21700.00
0005433407523	23079	Economy	21700.00
0005434610171	23079	Economy	21700.00
0005435808061	23079	Economy	21700.00
0005433407524	23079	Economy	21700.00
0005433407519	23079	Economy	21700.00
0005435808055	23079	Economy	21700.00
0005433407518	23079	Economy	21700.00
0005434610172	23079	Economy	21700.00
0005435808054	23079	Economy	21700.00
0005435808069	23079	Economy	21700.00
0005433407521	23079	Economy	21700.00
0005433407528	23079	Economy	21700.00
0005433407522	23079	Economy	21700.00
0005435808065	23079	Economy	21700.00
0005433407525	23079	Economy	21700.00
0005434503498	16701	Economy	7600.00
0005434503633	16701	Economy	7600.00
0005434503607	16701	Economy	7600.00
0005434503471	16701	Economy	6900.00
0005434503604	16701	Economy	6900.00
0005434503631	16701	Economy	6900.00
0005434503532	16701	Economy	6900.00
0005434503470	16701	Economy	6900.00
0005434503512	16701	Economy	6900.00
0005434503497	16701	Economy	6900.00
0005434503609	16701	Economy	6900.00
0005434503582	16701	Economy	6900.00
0005434503508	16701	Economy	6900.00
0005434503559	16701	Economy	6900.00
0005434503555	16701	Economy	6900.00
0005434503558	16701	Economy	6900.00
0005434503632	16701	Economy	6900.00
0005434503507	16701	Economy	6900.00
0005434503598	16701	Economy	6900.00
0005434503472	16701	Economy	6900.00
0005434503482	16701	Economy	6900.00
0005434503517	16701	Economy	6900.00
0005434503573	16701	Economy	6900.00
0005434503824	22891	Economy	7600.00
0005434503851	22891	Economy	7600.00
0005434503839	22891	Economy	7600.00
0005434503846	22891	Economy	6900.00
0005434503835	22891	Economy	6900.00
0005434503856	22891	Economy	6900.00
0005434503857	22891	Economy	6900.00
0005434503832	22891	Economy	6900.00
0005434503836	22891	Economy	6900.00
0005434503829	22891	Economy	6900.00
0005434503834	22891	Economy	6900.00
0005434503825	22891	Economy	6900.00
0005434503854	22891	Economy	6900.00
0005434503830	22891	Economy	6900.00
0005434503847	22891	Economy	6900.00
0005434503850	22891	Economy	6900.00
0005434503853	22891	Economy	6900.00
0005434503842	22891	Economy	6900.00
0005434503840	22891	Economy	6900.00
0005434503861	22891	Economy	6900.00
0005434503852	22891	Economy	6900.00
0005434503855	22891	Economy	6900.00
0005434503837	22891	Economy	6900.00
0005434503860	22891	Economy	6900.00
0005434503838	22891	Economy	6900.00
0005434503826	22891	Economy	6900.00
0005434503858	22891	Economy	6900.00
0005434503848	22891	Economy	6900.00
0005434503831	22891	Economy	6900.00
0005434503841	22891	Economy	6900.00
0005434503828	22891	Economy	6900.00
0005434503823	22891	Economy	6900.00
0005434503844	22891	Economy	6900.00
0005434503859	22891	Economy	6900.00
0005434503843	22891	Economy	6900.00
0005434503862	22891	Economy	6900.00
0005434503849	22891	Economy	6900.00
0005434503833	22891	Economy	6900.00
0005434503845	22891	Economy	6900.00
0005434503827	22891	Economy	6900.00
0005433266581	2179	Economy	7700.00
0005435078223	2179	Economy	7000.00
0005433266582	2179	Economy	7000.00
0005435078225	2179	Economy	7000.00
0005435078238	2179	Economy	7000.00
0005433266559	2179	Economy	7000.00
0005433266573	2179	Economy	7000.00
0005433266560	2179	Economy	7000.00
0005433266572	2179	Economy	7000.00
0005435078226	2179	Economy	7000.00
0005435078236	2179	Economy	7000.00
0005433266568	2179	Economy	7000.00
0005435078235	2179	Economy	7000.00
0005435078233	2179	Economy	7000.00
0005435078230	2179	Economy	7000.00
0005435078224	2179	Economy	7000.00
0005433266569	2179	Economy	7000.00
0005435078228	2179	Economy	7000.00
0005435078227	2179	Economy	7000.00
0005435078232	2179	Economy	7000.00
0005433266621	2179	Economy	7000.00
0005435078237	2179	Economy	7000.00
0005433266583	2179	Economy	7000.00
0005433266587	2179	Economy	7000.00
0005435078231	2179	Economy	7000.00
0005435078229	2179	Economy	7000.00
0005435078234	2179	Economy	7000.00
0005433266658	24375	Economy	7700.00
0005435078109	24375	Economy	7700.00
0005433266657	24375	Economy	7000.00
0005433266654	24375	Economy	7000.00
0005433266660	24375	Economy	7000.00
0005435078072	24375	Economy	7000.00
0005433266659	24375	Economy	7000.00
0005433266655	24375	Economy	7000.00
0005435078079	24375	Economy	7000.00
0005435078078	24375	Economy	7000.00
0005435078114	24375	Economy	7000.00
0005435078096	24375	Economy	7000.00
0005435078069	24375	Economy	7000.00
0005435078093	24375	Economy	7000.00
0005435078091	24375	Economy	7000.00
0005435078073	24375	Economy	7000.00
0005433266653	24375	Economy	7000.00
0005435078145	24375	Economy	7000.00
0005435078123	24375	Economy	7000.00
0005433266656	24375	Economy	7000.00
0005435078088	24375	Economy	7000.00
0005435078122	24375	Economy	7000.00
0005435078097	24375	Economy	7000.00
0005435803242	6655	Economy	10800.00
0005434988655	6655	Economy	10800.00
0005434988657	6655	Economy	9800.00
0005435803241	6655	Economy	9800.00
0005434988666	6655	Economy	9800.00
0005434988663	6655	Economy	9800.00
0005434988662	6655	Economy	9800.00
0005435803245	6655	Economy	9800.00
0005434988665	6655	Economy	9800.00
0005434988660	6655	Economy	9800.00
0005434988661	6655	Economy	9800.00
0005435803244	6655	Economy	9800.00
0005435803243	6655	Economy	9800.00
0005434988656	6655	Economy	9800.00
0005434988664	6655	Economy	9800.00
0005434988658	6655	Economy	9800.00
0005434988659	6655	Economy	9800.00
0005434988654	6655	Economy	9800.00
0005434988564	23629	Economy	10800.00
0005435803226	23629	Economy	9800.00
0005435464492	23629	Economy	9800.00
0005435803218	23629	Economy	9800.00
0005435464493	23629	Economy	9800.00
0005434988560	23629	Economy	9800.00
0005434988561	23629	Economy	9800.00
0005435803219	23629	Economy	9800.00
0005432382926	30507	Business	9900.00
0005433449806	30507	Business	9900.00
0005432382913	30507	Business	9900.00
0005432382920	30507	Business	9900.00
0005433449810	30507	Business	9900.00
0005432382924	30507	Business	9900.00
0005432382915	30507	Business	9900.00
0005433449826	30507	Business	9900.00
0005433449813	30507	Business	9900.00
0005433453749	30507	Business	9900.00
0005433449811	30507	Economy	3300.00
0005432382894	30507	Economy	3300.00
0005433449817	30507	Economy	3300.00
0005433454859	30507	Economy	3300.00
0005432382901	30507	Economy	3300.00
0005433449818	30507	Economy	3300.00
0005432382897	30507	Economy	3300.00
0005432382898	30507	Economy	3300.00
0005432382887	30507	Economy	3600.00
0005432382906	30507	Economy	3600.00
0005433454860	30507	Economy	3300.00
0005432382903	30507	Economy	3300.00
0005433449809	30507	Economy	3300.00
0005432382890	30507	Economy	3300.00
0005432382917	30507	Economy	3300.00
0005432382902	30507	Economy	3300.00
0005432382916	30507	Economy	3300.00
0005433449819	30507	Economy	3300.00
0005432382888	30507	Economy	3300.00
0005433449822	30507	Economy	3300.00
0005432382914	30507	Economy	3300.00
0005432382918	30507	Economy	3300.00
0005432382904	30507	Economy	3300.00
0005432382895	30507	Economy	3300.00
0005433449814	30507	Economy	3300.00
0005433449812	30507	Economy	3300.00
0005433449821	30507	Economy	3300.00
0005432382910	30507	Economy	3300.00
0005433449823	30507	Economy	3300.00
0005433449808	30507	Economy	3300.00
0005433449807	30507	Economy	3300.00
0005432382905	30507	Economy	3300.00
0005432382899	30507	Economy	3300.00
0005432382900	30507	Economy	3300.00
0005433454862	30507	Economy	3300.00
0005432382892	30507	Economy	3300.00
0005432382907	30507	Economy	3300.00
0005433449816	30507	Economy	3300.00
0005432382889	30507	Economy	3300.00
0005432382891	30507	Economy	3300.00
0005432382908	30507	Economy	3300.00
0005433449824	30507	Economy	3300.00
0005432382923	30507	Economy	3300.00
0005432382886	30507	Economy	3300.00
0005432382909	30507	Economy	3300.00
0005433454861	30507	Economy	3300.00
0005433449815	30507	Economy	3300.00
0005432382893	30507	Economy	3300.00
0005432382912	30507	Economy	3300.00
0005433449825	30507	Economy	3300.00
0005432382911	30507	Economy	3300.00
0005432382925	30507	Economy	3300.00
0005432382922	30507	Economy	3300.00
0005433449820	30507	Economy	3300.00
0005432382896	30507	Economy	3300.00
0005433449827	30507	Economy	3300.00
0005432382921	30507	Economy	3300.00
0005432382919	30507	Economy	3300.00
0005433449673	31321	Business	9900.00
0005432382551	31321	Business	9900.00
0005433453740	31321	Business	9900.00
0005433449694	31321	Business	9900.00
0005433451584	31321	Business	9900.00
0005432382550	31321	Economy	3300.00
0005432382764	31321	Economy	3300.00
0005433449678	31321	Economy	3300.00
0005433449607	31321	Economy	3300.00
0005432382668	31321	Economy	3600.00
0005432382593	31321	Economy	3600.00
0005433449600	31321	Economy	3600.00
0005433449611	31321	Economy	3300.00
0005433449669	31321	Economy	3300.00
0005432382585	31321	Economy	3300.00
0005433449672	31321	Economy	3300.00
0005433449708	31321	Economy	3300.00
0005432382567	31321	Economy	3300.00
0005432382560	31321	Economy	3300.00
0005433453742	31321	Economy	3300.00
0005432382765	31321	Economy	3300.00
0005432382549	31321	Economy	3300.00
0005433453741	31321	Economy	3300.00
0005432382612	31321	Economy	3300.00
0005433449601	31321	Economy	3300.00
0005433451585	31321	Economy	3300.00
0005432382594	31321	Economy	3300.00
0005433453726	31321	Economy	3300.00
0005432382522	31321	Economy	3300.00
0005432382530	31321	Economy	3300.00
0005433449755	31321	Economy	3300.00
0005432382537	31321	Economy	3300.00
0005432382538	31321	Economy	3300.00
0005433449667	31321	Economy	3300.00
0005433453727	31321	Economy	3300.00
0005432382667	31321	Economy	3300.00
0005432382486	31321	Economy	3300.00
0005433449657	31321	Economy	3300.00
0005432382599	31321	Economy	3300.00
0005433449587	31321	Economy	3300.00
0005433449592	31321	Economy	3300.00
0005432382539	31321	Economy	3300.00
0005433449620	31321	Economy	3300.00
0005432382485	31321	Economy	3300.00
0005433449645	31321	Economy	3300.00
0005432382529	31321	Economy	3300.00
0005432382766	31321	Economy	3300.00
0005433449756	31321	Economy	3300.00
0005435304099	10753	Economy	17100.00
0005433131636	10753	Economy	15600.00
0005433126768	10753	Economy	15600.00
0005433126769	10753	Economy	15600.00
0005435299706	10753	Economy	15600.00
0005433131634	10753	Economy	15600.00
0005435304097	10753	Economy	15600.00
0005433131644	10753	Economy	15600.00
0005435299700	10753	Economy	15600.00
0005435304100	10753	Economy	15600.00
0005435304092	10753	Economy	15600.00
0005435304107	10753	Economy	15600.00
0005435299701	10753	Economy	15600.00
0005433129247	29734	Economy	17100.00
0005435299748	29734	Economy	17100.00
0005435302172	29734	Economy	15600.00
0005433126817	29734	Economy	15600.00
0005433126815	29734	Economy	15600.00
0005435299744	29734	Economy	15600.00
0005433129246	29734	Economy	15600.00
0005433129248	29734	Economy	15600.00
0005433126816	29734	Economy	15600.00
0005435299749	29734	Economy	15600.00
0005435299745	29734	Economy	15600.00
0005435302168	29734	Economy	15600.00
0005435299746	29734	Economy	15600.00
0005433126819	29734	Economy	15600.00
0005435302171	29734	Economy	15600.00
0005433126814	29734	Economy	15600.00
0005433129251	29734	Economy	15600.00
0005433126818	29734	Economy	15600.00
0005433129249	29734	Economy	15600.00
0005435302169	29734	Economy	15600.00
0005435299747	29734	Economy	15600.00
0005433129250	29734	Economy	15600.00
0005435302170	29734	Economy	15600.00
0005434287123	2408	Economy	17200.00
0005434287125	2408	Economy	17200.00
0005434287130	2408	Economy	15700.00
0005434287134	2408	Economy	15700.00
0005434287121	2408	Economy	15700.00
0005433109885	2408	Economy	15700.00
0005434287126	2408	Economy	15700.00
0005434287133	2408	Economy	15700.00
0005433109884	2408	Economy	15700.00
0005434287131	2408	Economy	15700.00
0005434287138	2408	Economy	15700.00
0005432264458	2408	Economy	15700.00
0005432264457	2408	Economy	15700.00
0005434287141	2408	Economy	15700.00
0005434287129	2408	Economy	15700.00
0005434287137	2408	Economy	15700.00
0005434287136	2408	Economy	15700.00
0005434287127	2408	Economy	15700.00
0005433109887	2408	Economy	15700.00
0005434287128	2408	Economy	15700.00
0005433109889	2408	Economy	15700.00
0005434287122	2408	Economy	15700.00
0005433109864	2408	Economy	15700.00
0005434287139	2408	Economy	15700.00
0005433109888	2408	Economy	15700.00
0005434287140	2408	Economy	15700.00
0005434287132	2408	Economy	15700.00
0005433109886	2408	Economy	15700.00
0005433109879	2408	Economy	15700.00
0005434287124	2408	Economy	15700.00
0005434287135	2408	Economy	15700.00
0005433109963	26855	Economy	17200.00
0005434286952	26855	Economy	17200.00
0005434286914	26855	Economy	15700.00
0005433109968	26855	Economy	15700.00
0005433109964	26855	Economy	15700.00
0005434286960	26855	Economy	15700.00
0005433109971	26855	Economy	15700.00
0005434286989	26855	Economy	15700.00
0005433109970	26855	Economy	15700.00
0005434287005	26855	Economy	15700.00
0005434287041	26855	Economy	15700.00
0005434286953	26855	Economy	15700.00
0005434287020	26855	Economy	15700.00
0005434286971	26855	Economy	15700.00
0005433109962	26855	Economy	15700.00
0005434287021	26855	Economy	15700.00
0005434286909	26855	Economy	15700.00
0005434286958	26855	Economy	15700.00
0005434286984	26855	Economy	15700.00
0005433109969	26855	Economy	15700.00
0005434287040	26855	Economy	15700.00
0005434286929	26855	Economy	15700.00
0005434287019	26855	Economy	15700.00
0005434287012	26855	Economy	15700.00
0005434286957	26855	Economy	15700.00
0005433109966	26855	Economy	15700.00
0005434287011	26855	Economy	15700.00
0005433109967	26855	Economy	15700.00
0005433109965	26855	Economy	15700.00
0005434286976	26855	Economy	15700.00
0005433109972	26855	Economy	15700.00
0005435856173	25445	Economy	25000.00
0005435856175	25445	Economy	22800.00
0005435856176	25445	Economy	22800.00
0005434272169	25445	Economy	22800.00
0005434272170	25445	Economy	22800.00
0005435856174	25445	Economy	22800.00
0005434273066	26645	Economy	22800.00
0005435856144	26645	Economy	22800.00
0005435856145	26645	Economy	22800.00
0005434272180	26645	Economy	22800.00
0005435856134	26645	Economy	22800.00
0005434273065	26645	Economy	22800.00
0005433868172	4802	Economy	19400.00
0005433868150	4802	Economy	19400.00
0005433868139	4802	Economy	17600.00
0005433868170	4802	Economy	17600.00
0005433868156	4802	Economy	17600.00
0005433868137	4802	Economy	17600.00
0005433868174	4802	Economy	17600.00
0005433868146	4802	Economy	17600.00
0005433868158	4802	Economy	17600.00
0005433868151	4802	Economy	17600.00
0005433868140	4802	Economy	17600.00
0005433868145	4802	Economy	17600.00
0005433868142	4802	Economy	17600.00
0005433868138	4802	Economy	17600.00
0005433868171	4802	Economy	17600.00
0005433868148	4802	Economy	17600.00
0005433868160	4802	Economy	17600.00
0005433868141	4802	Economy	17600.00
0005433868147	4802	Economy	17600.00
0005433868167	4802	Economy	17600.00
0005433868154	4802	Economy	17600.00
0005433868162	4802	Economy	17600.00
0005433868159	4802	Economy	17600.00
0005433868178	4802	Economy	17600.00
0005433868144	4802	Economy	17600.00
0005433868149	4802	Economy	17600.00
0005433868175	4802	Economy	17600.00
0005433868152	4802	Economy	17600.00
0005433868155	4802	Economy	17600.00
0005433868168	4802	Economy	17600.00
0005433868161	4802	Economy	17600.00
0005433868166	4802	Economy	17600.00
0005433868165	4802	Economy	17600.00
0005433868143	4802	Economy	17600.00
0005433868157	4802	Economy	17600.00
0005433868169	4802	Economy	17600.00
0005433868164	4802	Economy	17600.00
0005433868177	4802	Economy	17600.00
0005433868173	4802	Economy	17600.00
0005433868163	4802	Economy	17600.00
0005433868176	4802	Economy	17600.00
0005433868153	4802	Economy	17600.00
0005433867738	32572	Economy	19400.00
0005433867789	32572	Economy	19400.00
0005433867767	32572	Economy	19400.00
0005433867727	32572	Economy	17600.00
0005433867777	32572	Economy	17600.00
0005433867813	32572	Economy	17600.00
0005433867795	32572	Economy	17600.00
0005433867840	32572	Economy	17600.00
0005433867744	32572	Economy	17600.00
0005433867807	32572	Economy	17600.00
0005433867743	32572	Economy	17600.00
0005433867831	32572	Economy	17600.00
0005433867786	32572	Economy	17600.00
0005433867839	32572	Economy	17600.00
0005433867737	32572	Economy	17600.00
0005433867818	32572	Economy	17600.00
0005433867832	32572	Economy	17600.00
0005433867847	32572	Economy	17600.00
0005433867846	32572	Economy	17600.00
0005433867787	32572	Economy	17600.00
0005433867804	32572	Economy	17600.00
0005433867788	32572	Economy	17600.00
0005433867816	32572	Economy	17600.00
0005433867778	32572	Economy	17600.00
0005433867779	32572	Economy	17600.00
0005433867817	32572	Economy	17600.00
0005433867830	32572	Economy	17600.00
0005433867791	32572	Economy	17600.00
0005433867825	32572	Economy	17600.00
0005433867790	32572	Economy	17600.00
0005433867808	32572	Economy	17600.00
0005433867768	32572	Economy	17600.00
0005433867769	32572	Economy	17600.00
0005434663311	3441	Economy	24800.00
0005434663312	3441	Economy	24800.00
0005435911341	3441	Economy	24800.00
0005434663313	3441	Economy	22600.00
0005434663317	3441	Economy	22600.00
0005434663307	3441	Economy	22600.00
0005434461631	3441	Economy	22600.00
0005435911350	3441	Economy	22600.00
0005434663310	3441	Economy	22600.00
0005435911352	3441	Economy	22600.00
0005434663318	3441	Economy	22600.00
0005435911345	3441	Economy	22600.00
0005435911372	3441	Economy	22600.00
0005434461633	3441	Economy	22600.00
0005434663315	3441	Economy	22600.00
0005434663316	3441	Economy	22600.00
0005435911325	3441	Economy	22600.00
0005434461632	3441	Economy	22600.00
0005434663309	3441	Economy	22600.00
0005435911336	3441	Economy	22600.00
0005435911346	3441	Economy	22600.00
0005434663314	3441	Economy	22600.00
0005435911353	3441	Economy	22600.00
0005435911373	3441	Economy	22600.00
0005435911351	3441	Economy	22600.00
0005435911331	3441	Economy	22600.00
0005434663308	3441	Economy	22600.00
0005434663173	12453	Economy	24800.00
0005434663202	12453	Economy	22600.00
0005435911399	12453	Economy	22600.00
0005434663193	12453	Economy	22600.00
0005434663232	12453	Economy	22600.00
0005434663194	12453	Economy	22600.00
0005434663204	12453	Economy	22600.00
0005434663246	12453	Economy	22600.00
0005434663219	12453	Economy	22600.00
0005434663191	12453	Economy	22600.00
0005434663233	12453	Economy	22600.00
0005434663182	12453	Economy	22600.00
0005434663165	12453	Economy	22600.00
0005434663207	12453	Economy	22600.00
0005434663245	12453	Economy	22600.00
0005435911394	12453	Economy	22600.00
0005435911400	12453	Economy	22600.00
0005435911397	12453	Economy	22600.00
0005434663209	12453	Economy	22600.00
0005434663203	12453	Economy	22600.00
0005434663210	12453	Economy	22600.00
0005435911395	12453	Economy	22600.00
0005435911396	12453	Economy	22600.00
0005434663228	12453	Economy	22600.00
0005434663231	12453	Economy	22600.00
0005435911398	12453	Economy	22600.00
0005433867743	14511	Economy	18500.00
0005433867790	14511	Economy	18500.00
0005433867787	14511	Economy	16800.00
0005433867807	14511	Economy	16800.00
0005433867816	14511	Economy	16800.00
0005433867847	14511	Economy	16800.00
0005433867727	14511	Economy	16800.00
0005433867786	14511	Economy	16800.00
0005433867830	14511	Economy	16800.00
0005433867831	14511	Economy	16800.00
0005433867768	14511	Economy	16800.00
0005433867795	14511	Economy	16800.00
0005433867789	14511	Economy	16800.00
0005433867804	14511	Economy	16800.00
0005433867769	14511	Economy	16800.00
0005433867737	14511	Economy	16800.00
0005433867779	14511	Economy	16800.00
0005433867777	14511	Economy	16800.00
0005433867832	14511	Economy	16800.00
0005433867846	14511	Economy	16800.00
0005433867818	14511	Economy	16800.00
0005433867788	14511	Economy	16800.00
0005433867791	14511	Economy	16800.00
0005433867778	14511	Economy	16800.00
0005433867808	14511	Economy	16800.00
0005433867813	14511	Economy	16800.00
0005433867744	14511	Economy	16800.00
0005433867840	14511	Economy	16800.00
0005433867839	14511	Economy	16800.00
0005433867767	14511	Economy	16800.00
0005433867738	14511	Economy	16800.00
0005433867817	14511	Economy	16800.00
0005433867825	14511	Economy	16800.00
0005433868097	32671	Economy	18500.00
0005433868095	32671	Economy	18500.00
0005433868136	32671	Economy	18500.00
0005433868098	32671	Economy	18500.00
0005433868099	32671	Economy	16800.00
0005433868118	32671	Economy	16800.00
0005433868113	32671	Economy	16800.00
0005433868114	32671	Economy	16800.00
0005433868127	32671	Economy	16800.00
0005433868135	32671	Economy	16800.00
0005433868122	32671	Economy	16800.00
0005433868120	32671	Economy	16800.00
0005433868117	32671	Economy	16800.00
0005433868121	32671	Economy	16800.00
0005433868101	32671	Economy	16800.00
0005433868116	32671	Economy	16800.00
0005433868129	32671	Economy	16800.00
0005433868107	32671	Economy	16800.00
0005433868111	32671	Economy	16800.00
0005433868130	32671	Economy	16800.00
0005433868125	32671	Economy	16800.00
0005433868115	32671	Economy	16800.00
0005433868112	32671	Economy	16800.00
0005433868096	32671	Economy	16800.00
0005433868100	32671	Economy	16800.00
0005433868131	32671	Economy	16800.00
0005433868132	32671	Economy	16800.00
0005433868123	32671	Economy	16800.00
0005433868134	32671	Economy	16800.00
0005433868104	32671	Economy	16800.00
0005433868103	32671	Economy	16800.00
0005433868109	32671	Economy	16800.00
0005433868124	32671	Economy	16800.00
0005433868128	32671	Economy	16800.00
0005433868133	32671	Economy	16800.00
0005433868106	32671	Economy	16800.00
0005433868105	32671	Economy	16800.00
0005433868102	32671	Economy	16800.00
0005433868110	32671	Economy	16800.00
0005433868108	32671	Economy	16800.00
0005433868126	32671	Economy	16800.00
0005433868119	32671	Economy	16800.00
0005432799060	12131	Economy	4400.00
0005432798996	12131	Economy	4400.00
0005432799108	12131	Economy	4400.00
0005432799009	12131	Economy	4400.00
0005432799036	12131	Economy	4400.00
0005432798985	12131	Economy	4400.00
0005432798987	12131	Economy	4400.00
0005432799057	12131	Economy	4400.00
0005432799058	12131	Economy	4400.00
0005432798980	12131	Economy	4400.00
0005432799069	12131	Economy	4400.00
0005432799070	12131	Economy	4400.00
0005432799059	12131	Economy	4400.00
0005432799116	12131	Economy	4400.00
0005432799077	12131	Economy	4400.00
0005432799078	12131	Economy	4400.00
0005432798990	12131	Economy	4400.00
0005432799013	12131	Economy	4400.00
0005432798986	12131	Economy	4400.00
0005432799240	14780	Economy	4900.00
0005432799228	14780	Economy	4900.00
0005432799236	14780	Economy	4400.00
0005432799222	14780	Economy	4400.00
0005432799237	14780	Economy	4400.00
0005432799216	14780	Economy	4400.00
0005432799234	14780	Economy	4400.00
0005432799224	14780	Economy	4400.00
0005432799215	14780	Economy	4400.00
0005432799227	14780	Economy	4400.00
0005432799230	14780	Economy	4400.00
0005432799229	14780	Economy	4400.00
0005432799225	14780	Economy	4400.00
0005432799235	14780	Economy	4400.00
0005432799241	14780	Economy	4400.00
0005432799239	14780	Economy	4400.00
0005432799238	14780	Economy	4400.00
0005432799217	14780	Economy	4400.00
0005432799218	14780	Economy	4400.00
0005432799231	14780	Economy	4400.00
0005432799223	14780	Economy	4400.00
0005432799242	14780	Economy	4400.00
0005432799214	14780	Economy	4400.00
0005432799219	14780	Economy	4400.00
0005432799233	14780	Economy	4400.00
0005432799232	14780	Economy	4400.00
0005432799220	14780	Economy	4400.00
0005432799221	14780	Economy	4400.00
0005432799213	14780	Economy	4400.00
0005432799226	14780	Economy	4400.00
0005435293072	7080	Business	49100.00
0005434407306	7080	Business	49100.00
0005434407343	7080	Business	49100.00
0005434407319	7080	Business	49100.00
0005434407293	7080	Business	49100.00
0005434299395	7080	Business	49100.00
0005434407330	7080	Business	49100.00
0005434407336	7080	Business	49100.00
0005434407320	7080	Business	49100.00
0005434407317	7080	Business	49100.00
0005434407337	7080	Business	49100.00
0005434407312	7080	Economy	16400.00
0005435293100	7080	Economy	16400.00
0005434299397	7080	Economy	16400.00
0005435293060	7080	Economy	16400.00
0005432153891	7080	Economy	16400.00
0005435293119	7080	Economy	16400.00
0005434299388	7080	Economy	16400.00
0005434299399	7080	Economy	16400.00
0005434407302	7080	Economy	16400.00
0005434299406	7080	Economy	16400.00
0005434407310	7080	Economy	16400.00
0005434407333	7080	Economy	16400.00
0005434299401	7080	Economy	16400.00
0005434407344	7080	Economy	16400.00
0005434407331	7080	Economy	16400.00
0005434407345	7080	Economy	16400.00
0005434407313	7080	Economy	16400.00
0005435293071	7080	Economy	16400.00
0005434407340	7080	Economy	16400.00
0005434407326	7080	Economy	16400.00
0005434407318	7080	Economy	16400.00
0005434299384	7080	Economy	16400.00
0005435293070	7080	Economy	16400.00
0005435293065	7080	Economy	16400.00
0005434299404	7080	Economy	16400.00
0005434407307	7080	Economy	16400.00
0005432153888	7080	Economy	16400.00
0005434299396	7080	Economy	16400.00
0005434407286	7080	Economy	16400.00
0005434407339	7080	Economy	16400.00
0005434299390	7080	Economy	16400.00
0005434407301	7080	Economy	16400.00
0005434407300	7080	Economy	16400.00
0005434299394	7080	Economy	16400.00
0005434407283	7080	Economy	18000.00
0005434407288	7080	Economy	18000.00
0005434299391	7080	Economy	18000.00
0005432108230	7080	Economy	18000.00
0005434299392	7080	Economy	18000.00
0005434407324	7080	Economy	18000.00
0005434407291	7080	Economy	16400.00
0005434407297	7080	Economy	16400.00
0005432153890	7080	Economy	16400.00
0005434407299	7080	Economy	16400.00
0005434407329	7080	Economy	16400.00
0005435293077	7080	Economy	16400.00
0005434407295	7080	Economy	16400.00
0005432153886	7080	Economy	16400.00
0005434407294	7080	Economy	16400.00
0005434407315	7080	Economy	16400.00
0005434407282	7080	Economy	16400.00
0005434407342	7080	Economy	16400.00
0005434299386	7080	Economy	16400.00
0005434407289	7080	Economy	16400.00
0005434299402	7080	Economy	16400.00
0005434407304	7080	Economy	16400.00
0005434407296	7080	Economy	16400.00
0005434407285	7080	Economy	16400.00
0005434407322	7080	Economy	16400.00
0005434299393	7080	Economy	16400.00
0005434407341	7080	Economy	16400.00
0005434407323	7080	Economy	16400.00
0005435293102	7080	Economy	16400.00
0005435293109	7080	Economy	16400.00
0005434407303	7080	Economy	16400.00
0005434407292	7080	Economy	16400.00
0005434407325	7080	Economy	16400.00
0005434407334	7080	Economy	16400.00
0005434299387	7080	Economy	16400.00
0005435293064	7080	Economy	16400.00
0005434407332	7080	Economy	16400.00
0005434407314	7080	Economy	16400.00
0005434407316	7080	Economy	16400.00
0005434407327	7080	Economy	16400.00
0005434407338	7080	Economy	16400.00
0005435293087	7080	Economy	16400.00
0005432153889	7080	Economy	16400.00
0005434407335	7080	Economy	16400.00
0005435293094	7080	Economy	16400.00
0005434299407	7080	Economy	16400.00
0005434407308	7080	Economy	16400.00
0005434407309	7080	Economy	16400.00
0005434407328	7080	Economy	16400.00
0005432108232	7080	Economy	16400.00
0005434299403	7080	Economy	16400.00
0005434407287	7080	Economy	16400.00
0005434407298	7080	Economy	16400.00
0005434299400	7080	Economy	16400.00
0005435293093	7080	Economy	16400.00
0005434407321	7080	Economy	16400.00
0005432108231	7080	Economy	16400.00
0005434407311	7080	Economy	16400.00
0005435293088	7080	Economy	16400.00
0005434299398	7080	Economy	16400.00
0005435293069	7080	Economy	16400.00
0005435293110	7080	Economy	16400.00
0005435293048	7080	Economy	16400.00
0005434299405	7080	Economy	16400.00
0005434407305	7080	Economy	16400.00
0005434407284	7080	Economy	16400.00
0005434407290	7080	Economy	16400.00
0005434407346	7080	Economy	16400.00
0005435293101	7080	Economy	16400.00
0005434299385	7080	Economy	16400.00
0005432153885	7080	Economy	16400.00
0005434299389	7080	Economy	16400.00
0005432153887	7080	Economy	16400.00
0005434299174	26910	Business	49100.00
0005435293169	26910	Business	49100.00
0005434406679	26910	Business	49100.00
0005432058348	26910	Business	49100.00
0005434406986	26910	Business	49100.00
0005435310976	26910	Business	49100.00
0005434406762	26910	Business	49100.00
0005434406773	26910	Business	49100.00
0005435293164	26910	Business	49100.00
0005434406744	26910	Economy	16400.00
0005435293168	26910	Economy	16400.00
0005434406649	26910	Economy	16400.00
0005434406808	26910	Economy	16400.00
0005435293162	26910	Economy	16400.00
0005434406750	26910	Economy	16400.00
0005435310974	26910	Economy	16400.00
0005434406797	26910	Economy	16400.00
0005435293157	26910	Economy	16400.00
0005434299247	26910	Economy	16400.00
0005435310971	26910	Economy	16400.00
0005434406984	26910	Economy	16400.00
0005434299235	26910	Economy	16400.00
0005434406732	26910	Economy	16400.00
0005434406779	26910	Economy	16400.00
0005435293163	26910	Economy	16400.00
0005434299212	26910	Economy	16400.00
0005432058349	26910	Economy	16400.00
0005435310975	26910	Economy	16400.00
0005435310972	26910	Economy	16400.00
0005435310970	26910	Economy	16400.00
0005432058350	26910	Economy	16400.00
0005434406655	26910	Economy	16400.00
0005435293159	26910	Economy	18000.00
0005434299222	26910	Economy	18000.00
0005434407071	26910	Economy	18000.00
0005434299152	26910	Economy	16400.00
0005434299241	26910	Economy	16400.00
0005434406883	26910	Economy	16400.00
0005434299282	26910	Economy	16400.00
0005434299223	26910	Economy	16400.00
0005434299283	26910	Economy	16400.00
0005434299147	26910	Economy	16400.00
0005434299303	26910	Economy	16400.00
0005435310977	26910	Economy	16400.00
0005435293166	26910	Economy	16400.00
0005434299181	26910	Economy	16400.00
0005434406656	26910	Economy	16400.00
0005434406696	26910	Economy	16400.00
0005435293167	26910	Economy	16400.00
0005434299153	26910	Economy	16400.00
0005435293165	26910	Economy	16400.00
0005434406890	26910	Economy	16400.00
0005435310969	26910	Economy	16400.00
0005434406761	26910	Economy	16400.00
0005435293160	26910	Economy	16400.00
0005435310973	26910	Economy	16400.00
0005434406709	26910	Economy	16400.00
0005432058351	26910	Economy	16400.00
0005434406695	26910	Economy	16400.00
0005434406853	26910	Economy	16400.00
0005434406794	26910	Economy	16400.00
0005434299304	26910	Economy	16400.00
0005434406707	26910	Economy	16400.00
0005434406994	26910	Economy	16400.00
0005435293161	26910	Economy	16400.00
0005434406654	26910	Economy	16400.00
0005434406650	26910	Economy	16400.00
0005434406860	26910	Economy	16400.00
0005435293158	26910	Economy	16400.00
0005434406746	26910	Economy	16400.00
0005434406745	26910	Economy	16400.00
0005434299184	26910	Economy	16400.00
0005434406708	26910	Economy	16400.00
0005434406959	26910	Economy	16400.00
0005434406640	26910	Economy	16400.00
0005434406891	26910	Economy	16400.00
0005434406993	26910	Economy	16400.00
0005434406985	26910	Economy	16400.00
0005434406859	26910	Economy	16400.00
0005434299183	26910	Economy	16400.00
0005432604059	6438	Economy	16500.00
0005432604055	6438	Economy	16500.00
0005432604077	6438	Economy	16500.00
0005432604081	6438	Economy	16500.00
0005432604060	6438	Economy	15000.00
0005432604087	6438	Economy	15000.00
0005432604058	6438	Economy	15000.00
0005432604070	6438	Economy	15000.00
0005432604075	6438	Economy	15000.00
0005432604084	6438	Economy	15000.00
0005432604057	6438	Economy	15000.00
0005432604083	6438	Economy	15000.00
0005432604068	6438	Economy	15000.00
0005434512084	6438	Economy	15000.00
0005432604085	6438	Economy	15000.00
0005432604079	6438	Economy	15000.00
0005432604078	6438	Economy	15000.00
0005432604051	6438	Economy	15000.00
0005432604050	6438	Economy	15000.00
0005432604056	6438	Economy	15000.00
0005434512083	6438	Economy	15000.00
0005434512082	6438	Economy	15000.00
0005432604047	6438	Economy	15000.00
0005432604064	6438	Economy	15000.00
0005432604065	6438	Economy	15000.00
0005432604082	6438	Economy	15000.00
0005432604049	6438	Economy	15000.00
0005432604086	6438	Economy	15000.00
0005432604071	6438	Economy	15000.00
0005432604062	6438	Economy	15000.00
0005432604069	6438	Economy	15000.00
0005432604076	6438	Economy	15000.00
0005432604054	6438	Economy	15000.00
0005432604073	6438	Economy	15000.00
0005432604080	6438	Economy	15000.00
0005432604067	6438	Economy	15000.00
0005432604053	6438	Economy	15000.00
0005434512081	6438	Economy	15000.00
0005432604066	6438	Economy	15000.00
0005432604072	6438	Economy	15000.00
0005432604074	6438	Economy	15000.00
0005432604063	6438	Economy	15000.00
0005432604061	6438	Economy	15000.00
0005432604048	6438	Economy	15000.00
0005432604052	6438	Economy	15000.00
0005435218099	6438	Economy	15000.00
0005434512039	21361	Economy	16500.00
0005432603807	21361	Economy	16500.00
0005435221510	21361	Economy	16500.00
0005432603689	21361	Economy	15000.00
0005434512038	21361	Economy	15000.00
0005434512028	21361	Economy	15000.00
0005432603760	21361	Economy	15000.00
0005432603742	21361	Economy	15000.00
0005432603772	21361	Economy	15000.00
0005432603696	21361	Economy	15000.00
0005435221048	21361	Economy	15000.00
0005432603730	21361	Economy	15000.00
0005432603690	21361	Economy	15000.00
0005434512029	21361	Economy	15000.00
0005432603793	21361	Economy	15000.00
0005432603698	21361	Economy	15000.00
0005432603677	21361	Economy	15000.00
0005432603703	21361	Economy	15000.00
0005432603801	21361	Economy	15000.00
0005435221049	21361	Economy	15000.00
0005432603670	21361	Economy	15000.00
0005432603735	21361	Economy	15000.00
0005432603815	21361	Economy	15000.00
0005432603704	21361	Economy	15000.00
0005434512043	21361	Economy	15000.00
0005434512042	21361	Economy	15000.00
0005432603683	21361	Economy	15000.00
0005432603669	21361	Economy	15000.00
0005432603741	21361	Economy	15000.00
0005432603750	21361	Economy	15000.00
0005435221509	21361	Economy	15000.00
0005432603833	21361	Economy	15000.00
0005432603759	21361	Economy	15000.00
0005432603729	21361	Economy	15000.00
0005434906413	15014	Business	18900.00
0005434906515	15014	Business	18900.00
0005433251251	15014	Business	18900.00
0005434906514	15014	Business	18900.00
0005433251272	15014	Business	18900.00
0005433251248	15014	Business	18900.00
0005434906435	15014	Economy	6300.00
0005433251255	15014	Economy	6300.00
0005433251267	15014	Economy	6300.00
0005433251261	15014	Economy	6300.00
0005434906534	15014	Economy	6300.00
0005433251274	15014	Economy	6300.00
0005434906393	15014	Economy	6300.00
0005433251252	15014	Economy	6300.00
0005434906523	15014	Economy	6900.00
0005434906426	15014	Economy	6900.00
0005433251247	15014	Economy	6900.00
0005434906516	15014	Economy	6900.00
0005433251268	15014	Economy	6900.00
0005433251265	15014	Economy	6300.00
0005433251259	15014	Economy	6300.00
0005433251266	15014	Economy	6300.00
0005434906517	15014	Economy	6300.00
0005434906496	15014	Economy	6300.00
0005434906484	15014	Economy	6300.00
0005434906392	15014	Economy	6300.00
0005433251273	15014	Economy	6300.00
0005433251264	15014	Economy	6300.00
0005434906562	15014	Economy	6300.00
0005433251250	15014	Economy	6300.00
0005434906495	15014	Economy	6300.00
0005434906417	15014	Economy	6300.00
0005433251245	15014	Economy	6300.00
0005434906364	15014	Economy	6300.00
0005433251246	15014	Economy	6300.00
0005434906412	15014	Economy	6300.00
0005433251256	15014	Economy	6300.00
0005433251244	15014	Economy	6300.00
0005433251243	15014	Economy	6300.00
0005433251260	15014	Economy	6300.00
0005433251254	15014	Economy	6300.00
0005434906481	15014	Economy	6300.00
0005433251270	15014	Economy	6300.00
0005434906518	15014	Economy	6300.00
0005433251249	15014	Economy	6300.00
0005434906556	15014	Economy	6300.00
0005433251257	15014	Economy	6300.00
0005433251269	15014	Economy	6300.00
0005433251271	15014	Economy	6300.00
0005433251258	15014	Economy	6300.00
0005434906545	15014	Economy	6300.00
0005434906443	15014	Economy	6300.00
0005434906522	15014	Economy	6300.00
0005434906402	15014	Economy	6300.00
0005434906521	15014	Economy	6300.00
0005434906416	15014	Economy	6300.00
0005434906414	15014	Economy	6300.00
0005433251263	15014	Economy	6300.00
0005434906449	15014	Economy	6300.00
0005434906419	15014	Economy	6300.00
0005433251253	15014	Economy	6300.00
0005434906506	15014	Economy	6300.00
0005433251262	15014	Economy	6300.00
0005434906448	15014	Economy	6300.00
0005434906528	15014	Economy	6300.00
0005434906538	15014	Economy	6300.00
0005434906859	25853	Business	18900.00
0005434906863	25853	Business	18900.00
0005434906901	25853	Business	18900.00
0005434906894	25853	Business	18900.00
0005434906902	25853	Business	18900.00
0005434906880	25853	Business	18900.00
0005434906891	25853	Business	18900.00
0005434906890	25853	Business	18900.00
0005434906893	25853	Business	18900.00
0005433250959	25853	Business	18900.00
0005434906895	25853	Business	18900.00
0005434906896	25853	Economy	6300.00
0005434906875	25853	Economy	6300.00
0005434906889	25853	Economy	6300.00
0005433251059	25853	Economy	6300.00
0005434906897	25853	Economy	6900.00
0005434906869	25853	Economy	6900.00
0005434906860	25853	Economy	6900.00
0005433250984	25853	Economy	6300.00
0005433250985	25853	Economy	6300.00
0005434906879	25853	Economy	6300.00
0005434906876	25853	Economy	6300.00
0005434906888	25853	Economy	6300.00
0005433251117	25853	Economy	6300.00
0005434906864	25853	Economy	6300.00
0005434906865	25853	Economy	6300.00
0005434906900	25853	Economy	6300.00
0005434906862	25853	Economy	6300.00
0005434906870	25853	Economy	6300.00
0005433251015	25853	Economy	6300.00
0005434906878	25853	Economy	6300.00
0005434906861	25853	Economy	6300.00
0005434906871	25853	Economy	6300.00
0005433250988	25853	Economy	6300.00
0005433251064	25853	Economy	6300.00
0005434906882	25853	Economy	6300.00
0005434906883	25853	Economy	6300.00
0005433251070	25853	Economy	6300.00
0005433250955	25853	Economy	6300.00
0005434906872	25853	Economy	6300.00
0005433251038	25853	Economy	6300.00
0005434906877	25853	Economy	6300.00
0005434906881	25853	Economy	6300.00
0005433251071	25853	Economy	6300.00
0005433251016	25853	Economy	6300.00
0005434906867	25853	Economy	6300.00
0005434906898	25853	Economy	6300.00
0005434906885	25853	Economy	6300.00
0005433250993	25853	Economy	6300.00
0005434906903	25853	Economy	6300.00
0005434906904	25853	Economy	6300.00
0005433251116	25853	Economy	6300.00
0005434906899	25853	Economy	6300.00
0005433250956	25853	Economy	6300.00
0005434906887	25853	Economy	6300.00
0005433251069	25853	Economy	6300.00
0005434906874	25853	Economy	6300.00
0005434906873	25853	Economy	6300.00
0005434906886	25853	Economy	6300.00
0005434906892	25853	Economy	6300.00
0005434906868	25853	Economy	6300.00
0005434906866	25853	Economy	6300.00
0005434906884	25853	Economy	6300.00
0005432609691	22467	Economy	16400.00
0005432607527	22467	Economy	16400.00
0005432609698	22467	Economy	14900.00
0005432607530	22467	Economy	14900.00
0005432607524	22467	Economy	14900.00
0005432609699	22467	Economy	14900.00
0005435841462	22467	Economy	14900.00
0005432607534	22467	Economy	14900.00
0005432607533	22467	Economy	14900.00
0005432609700	22467	Economy	14900.00
0005432607528	22467	Economy	14900.00
0005432609694	22467	Economy	14900.00
0005432609690	22467	Economy	14900.00
0005432609693	22467	Economy	14900.00
0005432607531	22467	Economy	14900.00
0005432607529	22467	Economy	14900.00
0005432609689	22467	Economy	14900.00
0005435842311	22467	Economy	14900.00
0005432607523	22467	Economy	14900.00
0005432609697	22467	Economy	14900.00
0005432607526	22467	Economy	14900.00
0005432609701	22467	Economy	14900.00
0005435842315	22467	Economy	14900.00
0005432607525	22467	Economy	14900.00
0005432607532	22467	Economy	14900.00
0005432609695	22467	Economy	14900.00
0005432609696	22467	Economy	14900.00
0005435842316	22467	Economy	14900.00
0005432609692	22467	Economy	14900.00
0005435841466	31728	Economy	16400.00
0005432609668	31728	Economy	16400.00
0005435841088	31728	Economy	14900.00
0005432609665	31728	Economy	14900.00
0005432609664	31728	Economy	14900.00
0005432613797	31728	Economy	14900.00
0005435841469	31728	Economy	14900.00
0005435841090	31728	Economy	14900.00
0005435841089	31728	Economy	14900.00
0005432613795	31728	Economy	14900.00
0005435841465	31728	Economy	14900.00
0005435841467	31728	Economy	14900.00
0005432613789	31728	Economy	14900.00
0005432613796	31728	Economy	14900.00
0005432613794	31728	Economy	14900.00
0005435841087	31728	Economy	14900.00
0005435841091	31728	Economy	14900.00
0005435841092	31728	Economy	14900.00
0005432609666	31728	Economy	14900.00
0005435841470	31728	Economy	14900.00
0005435841468	31728	Economy	14900.00
0005433008314	14187	Business	52300.00
0005433008316	14187	Business	52300.00
0005433008323	14187	Business	52300.00
0005433008328	14187	Business	52300.00
0005433008315	14187	Business	52300.00
0005433008292	14187	Business	52300.00
0005433008302	14187	Economy	17400.00
0005433008320	14187	Economy	17400.00
0005433008318	14187	Economy	17400.00
0005433008317	14187	Economy	17400.00
0005433008296	14187	Economy	19200.00
0005433008321	14187	Economy	19200.00
0005433008297	14187	Economy	17400.00
0005433008291	14187	Economy	17400.00
0005433008329	14187	Economy	17400.00
0005433008300	14187	Economy	17400.00
0005433008287	14187	Economy	17400.00
0005433008332	14187	Economy	17400.00
0005433008307	14187	Economy	17400.00
0005433008309	14187	Economy	17400.00
0005433008313	14187	Economy	17400.00
0005433008294	14187	Economy	17400.00
0005433008301	14187	Economy	17400.00
0005433008299	14187	Economy	17400.00
0005433008304	14187	Economy	17400.00
0005433008308	14187	Economy	17400.00
0005433008327	14187	Economy	17400.00
0005433008325	14187	Economy	17400.00
0005433008288	14187	Economy	17400.00
0005433008303	14187	Economy	17400.00
0005433008322	14187	Economy	17400.00
0005433008306	14187	Economy	17400.00
0005433008305	14187	Economy	17400.00
0005433008310	14187	Economy	17400.00
0005433008312	14187	Economy	17400.00
0005433008290	14187	Economy	17400.00
0005433008311	14187	Economy	17400.00
0005433008295	14187	Economy	17400.00
0005433008293	14187	Economy	17400.00
0005433008298	14187	Economy	17400.00
0005433008289	14187	Economy	17400.00
0005433008286	14187	Economy	17400.00
0005433008324	14187	Economy	17400.00
0005433008331	14187	Economy	17400.00
0005433008326	14187	Economy	17400.00
0005433008330	14187	Economy	17400.00
0005433008319	14187	Economy	17400.00
0005433810515	22854	Business	52300.00
0005433008113	22854	Business	52300.00
0005433007844	22854	Business	52300.00
0005433007939	22854	Business	52300.00
0005433810517	22854	Business	52300.00
0005433008049	22854	Business	52300.00
0005433007954	22854	Economy	17400.00
0005433008043	22854	Economy	17400.00
0005433008129	22854	Economy	17400.00
0005433008045	22854	Economy	17400.00
0005433008023	22854	Economy	17400.00
0005433008130	22854	Economy	17400.00
0005433008050	22854	Economy	19200.00
0005433007831	22854	Economy	17400.00
0005433007862	22854	Economy	17400.00
0005433810516	22854	Economy	17400.00
0005433007974	22854	Economy	17400.00
0005433007975	22854	Economy	17400.00
0005433007863	22854	Economy	17400.00
0005433007826	22854	Economy	17400.00
0005433007928	22854	Economy	17400.00
0005433007872	22854	Economy	17400.00
0005433008001	22854	Economy	17400.00
0005433007891	22854	Economy	17400.00
0005433007830	22854	Economy	17400.00
0005433007938	22854	Economy	17400.00
0005433008022	22854	Economy	17400.00
0005433008042	22854	Economy	17400.00
0005433007827	22854	Economy	17400.00
0005433008000	22854	Economy	17400.00
0005433007913	22854	Economy	17400.00
0005433008114	22854	Economy	17400.00
0005433008013	22854	Economy	17400.00
0005433007968	22854	Economy	17400.00
0005434925284	14916	Business	22900.00
0005434925309	14916	Economy	7600.00
0005434925336	14916	Economy	8400.00
0005434925267	14916	Economy	7600.00
0005434925308	14916	Economy	7600.00
0005434925257	14916	Economy	7600.00
0005434925307	14916	Economy	7600.00
0005434925269	14916	Economy	7600.00
0005434925329	14916	Economy	7600.00
0005434925268	14916	Economy	7600.00
0005434925317	14916	Economy	7600.00
0005434925313	14916	Economy	7600.00
0005434925335	14916	Economy	7600.00
0005434925324	14916	Economy	7600.00
0005434925315	14916	Economy	7600.00
0005434925566	20523	Business	22900.00
0005434925548	20523	Business	22900.00
0005434925539	20523	Business	22900.00
0005434925568	20523	Business	22900.00
0005434925547	20523	Business	22900.00
0005434925544	20523	Business	22900.00
0005434925558	20523	Business	22900.00
0005434925562	20523	Economy	7600.00
0005434925571	20523	Economy	7600.00
0005434925552	20523	Economy	7600.00
0005434925555	20523	Economy	8400.00
0005434925536	20523	Economy	8400.00
0005434925556	20523	Economy	7600.00
0005434925557	20523	Economy	7600.00
0005434925540	20523	Economy	7600.00
0005434925538	20523	Economy	7600.00
0005434925541	20523	Economy	7600.00
0005434925561	20523	Economy	7600.00
0005434925543	20523	Economy	7600.00
0005434925537	20523	Economy	7600.00
0005434925545	20523	Economy	7600.00
0005434925570	20523	Economy	7600.00
0005434925549	20523	Economy	7600.00
0005434925559	20523	Economy	7600.00
0005434925535	20523	Economy	7600.00
0005434925553	20523	Economy	7600.00
0005434925533	20523	Economy	7600.00
0005434925542	20523	Economy	7600.00
0005434925551	20523	Economy	7600.00
0005434925550	20523	Economy	7600.00
0005434925563	20523	Economy	7600.00
0005434925567	20523	Economy	7600.00
0005434925565	20523	Economy	7600.00
0005434925534	20523	Economy	7600.00
0005434925546	20523	Economy	7600.00
0005434925564	20523	Economy	7600.00
0005434925560	20523	Economy	7600.00
0005434925554	20523	Economy	7600.00
0005434925569	20523	Economy	7600.00
0005435487676	15817	Economy	8900.00
0005435487690	15817	Economy	8900.00
0005435998991	15817	Economy	8100.00
0005435487683	15817	Economy	8100.00
0005435487696	15817	Economy	8100.00
0005435487688	15817	Economy	8100.00
0005435487685	15817	Economy	8100.00
0005435487686	15817	Economy	8100.00
0005435998961	15817	Economy	8100.00
0005435998953	15817	Economy	8100.00
0005435487677	15817	Economy	8100.00
0005435487682	15817	Economy	8100.00
0005435487678	15817	Economy	8100.00
0005435487691	15817	Economy	8100.00
0005435998983	15817	Economy	8100.00
0005435998979	15817	Economy	8100.00
0005435487679	15817	Economy	8100.00
0005435487695	15817	Economy	8100.00
0005435487692	15817	Economy	8100.00
0005435998996	15817	Economy	8100.00
0005435487684	15817	Economy	8100.00
0005435487689	15817	Economy	8100.00
0005435487687	15817	Economy	8100.00
0005435487694	15817	Economy	8100.00
0005435487681	15817	Economy	8100.00
0005435487680	15817	Economy	8100.00
0005435998951	15817	Economy	8100.00
0005435998965	15817	Economy	8100.00
0005435487693	15817	Economy	8100.00
0005435998952	15817	Economy	8100.00
0005435998995	15817	Economy	8100.00
0005435999115	19665	Economy	8900.00
0005435487480	19665	Economy	8100.00
0005435999123	19665	Economy	8100.00
0005435487457	19665	Economy	8100.00
0005435999117	19665	Economy	8100.00
0005435999126	19665	Economy	8100.00
0005435999112	19665	Economy	8100.00
0005435999114	19665	Economy	8100.00
0005435487508	19665	Economy	8100.00
0005435487464	19665	Economy	8100.00
0005435487479	19665	Economy	8100.00
0005435487467	19665	Economy	8100.00
0005435999121	19665	Economy	8100.00
0005435999124	19665	Economy	8100.00
0005435999128	19665	Economy	8100.00
0005435487456	19665	Economy	8100.00
0005435999119	19665	Economy	8100.00
0005435999125	19665	Economy	8100.00
0005435999116	19665	Economy	8100.00
0005435487465	19665	Economy	8100.00
0005435999118	19665	Economy	8100.00
0005435487459	19665	Economy	8100.00
0005435999120	19665	Economy	8100.00
0005435487458	19665	Economy	8100.00
0005435999113	19665	Economy	8100.00
0005435487466	19665	Economy	8100.00
0005435487489	19665	Economy	8100.00
0005435487475	19665	Economy	8100.00
0005435999122	19665	Economy	8100.00
0005435999127	19665	Economy	8100.00
0005435487463	19665	Economy	8100.00
0005435839252	5978	Business	199300.00
0005435472521	5978	Business	199300.00
0005432659692	5978	Business	199300.00
0005435472522	5978	Business	199300.00
0005435839273	5978	Business	199300.00
0005435839268	5978	Business	199300.00
0005435839253	5978	Business	199300.00
0005435839266	5978	Business	199300.00
0005435839250	5978	Business	199300.00
0005435472554	5978	Economy	66400.00
0005435472571	5978	Economy	66400.00
0005435839263	5978	Economy	66400.00
0005432142230	5978	Economy	66400.00
0005432658578	5978	Economy	73100.00
0005435839265	5978	Economy	73100.00
0005435839261	5978	Economy	73100.00
0005435839254	5978	Economy	66400.00
0005435839257	5978	Economy	66400.00
0005432660805	5978	Economy	66400.00
0005432142229	5978	Economy	66400.00
0005435839249	5978	Economy	66400.00
0005435839269	5978	Economy	66400.00
0005435472569	5978	Economy	66400.00
0005435472513	5978	Economy	66400.00
0005432659693	5978	Economy	66400.00
0005435839251	5978	Economy	66400.00
0005435472560	5978	Economy	66400.00
0005435839259	5978	Economy	66400.00
0005435839264	5978	Economy	66400.00
0005435839256	5978	Economy	66400.00
0005435472570	5978	Economy	66400.00
0005435839248	5978	Economy	66400.00
0005435839258	5978	Economy	66400.00
0005432660804	5978	Economy	66400.00
0005435839272	5978	Economy	66400.00
0005435839271	5978	Economy	66400.00
0005435839247	5978	Economy	66400.00
0005435839262	5978	Economy	66400.00
0005435472547	5978	Economy	66400.00
0005435839260	5978	Economy	66400.00
0005432142231	5978	Economy	66400.00
0005435839267	5978	Economy	66400.00
0005435472535	5978	Economy	66400.00
0005435839255	5978	Economy	66400.00
0005435839270	5978	Economy	66400.00
0005435472561	5978	Economy	66400.00
0005435472555	5978	Economy	66400.00
0005435838996	18090	Business	199300.00
0005435472688	18090	Business	199300.00
0005435472686	18090	Business	199300.00
0005435839020	18090	Business	199300.00
0005435839017	18090	Business	199300.00
0005435472689	18090	Business	199300.00
0005435839008	18090	Business	199300.00
0005435838995	18090	Business	199300.00
0005435839032	18090	Business	199300.00
0005435839024	18090	Business	199300.00
0005435472684	18090	Economy	66400.00
0005435472695	18090	Economy	66400.00
0005435839047	18090	Economy	66400.00
0005435472687	18090	Economy	66400.00
0005435838991	18090	Economy	66400.00
0005435472691	18090	Economy	66400.00
0005435472683	18090	Economy	66400.00
0005435839044	18090	Economy	66400.00
0005435839079	18090	Economy	66400.00
0005435472696	18090	Economy	66400.00
0005432537044	18090	Economy	66400.00
0005435472693	18090	Economy	66400.00
0005435839009	18090	Economy	66400.00
0005435838977	18090	Economy	66400.00
0005435839086	18090	Economy	66400.00
0005435839058	18090	Economy	66400.00
0005435838992	18090	Economy	66400.00
0005435839021	18090	Economy	66400.00
0005435472682	18090	Economy	66400.00
0005435839015	18090	Economy	66400.00
0005435838966	18090	Economy	66400.00
0005435839043	18090	Economy	66400.00
0005435472694	18090	Economy	66400.00
0005435838985	18090	Economy	66400.00
0005435838972	18090	Economy	66400.00
0005435839018	18090	Economy	66400.00
0005435472685	18090	Economy	66400.00
0005435839016	18090	Economy	66400.00
0005435839012	18090	Economy	66400.00
0005435839003	18090	Economy	66400.00
0005435472692	18090	Economy	66400.00
0005435839078	18090	Economy	66400.00
0005435839087	18090	Economy	66400.00
0005435838974	18090	Economy	66400.00
0005435472681	18090	Economy	66400.00
0005435472690	18090	Economy	66400.00
0005433284837	23011	Business	15700.00
0005433284803	23011	Economy	5200.00
0005433284901	23011	Economy	5200.00
0005433284776	23011	Economy	5200.00
0005435103869	23011	Economy	5200.00
0005435103877	23011	Economy	5200.00
0005435103873	23011	Economy	5200.00
0005433284844	23011	Economy	5200.00
0005435103872	23011	Economy	5200.00
0005433284799	23011	Economy	5200.00
0005433284814	23011	Economy	5200.00
0005433284900	23011	Economy	5200.00
0005433284983	23011	Economy	5200.00
0005435103875	23011	Economy	5200.00
0005433284843	23011	Economy	5200.00
0005433284883	23011	Economy	5700.00
0005435103874	23011	Economy	5200.00
0005433284917	23011	Economy	5200.00
0005433284812	23011	Economy	5200.00
0005433284853	23011	Economy	5200.00
0005433284896	23011	Economy	5200.00
0005433284854	23011	Economy	5200.00
0005435103868	23011	Economy	5200.00
0005435103870	23011	Economy	5200.00
0005433284934	23011	Economy	5200.00
0005433284910	23011	Economy	5200.00
0005433284813	23011	Economy	5200.00
0005433284849	23011	Economy	5200.00
0005435103867	23011	Economy	5200.00
0005435103876	23011	Economy	5200.00
0005433284804	23011	Economy	5200.00
0005433284800	23011	Economy	5200.00
0005435103871	23011	Economy	5200.00
0005433284784	23011	Economy	5200.00
0005433285071	32089	Business	15700.00
0005433285075	32089	Business	15700.00
0005433285082	32089	Business	15700.00
0005433285073	32089	Business	15700.00
0005433285087	32089	Economy	5200.00
0005433285079	32089	Economy	5200.00
0005433285084	32089	Economy	5200.00
0005433285080	32089	Economy	5200.00
0005433285097	32089	Economy	5200.00
0005433285072	32089	Economy	5200.00
0005435103800	32089	Economy	5200.00
0005435103799	32089	Economy	5200.00
0005433285089	32089	Economy	5200.00
0005433285081	32089	Economy	5200.00
0005433285078	32089	Economy	5200.00
0005435103797	32089	Economy	5200.00
0005433285093	32089	Economy	5200.00
0005433285088	32089	Economy	5700.00
0005433285096	32089	Economy	5200.00
0005433285102	32089	Economy	5200.00
0005433285076	32089	Economy	5200.00
0005433285086	32089	Economy	5200.00
0005433285090	32089	Economy	5200.00
0005433285091	32089	Economy	5200.00
0005433285095	32089	Economy	5200.00
0005433285094	32089	Economy	5200.00
0005435103802	32089	Economy	5200.00
0005433285099	32089	Economy	5200.00
0005435103793	32089	Economy	5200.00
0005433285101	32089	Economy	5200.00
0005433285074	32089	Economy	5200.00
0005433285098	32089	Economy	5200.00
0005433285085	32089	Economy	5200.00
0005433285092	32089	Economy	5200.00
0005433285100	32089	Economy	5200.00
0005433285083	32089	Economy	5200.00
0005433285077	32089	Economy	5200.00
0005433475639	23859	Economy	13500.00
0005433475634	23859	Economy	12300.00
0005435852558	23859	Economy	12300.00
0005433475635	23859	Economy	12300.00
0005435852556	23859	Economy	12300.00
0005433475630	23859	Economy	12300.00
0005435852554	23859	Economy	12300.00
0005433475659	23859	Economy	12300.00
0005435852555	23859	Economy	12300.00
0005435852557	23859	Economy	12300.00
0005435852553	23859	Economy	12300.00
0005433475631	23859	Economy	12300.00
0005432526356	30619	Business	42100.00
0005435213123	30619	Business	42100.00
0005433656650	30619	Business	42100.00
0005434066520	30619	Business	42100.00
0005432525681	30619	Business	42100.00
0005435213098	30619	Business	42100.00
0005432526205	30619	Business	42100.00
0005432526327	30619	Business	42100.00
0005435213105	30619	Business	42100.00
0005435213107	30619	Business	42100.00
0005435213137	30619	Business	42100.00
0005434066593	30619	Business	42100.00
0005434066545	30619	Business	42100.00
0005435630948	30619	Business	42100.00
0005432428881	30619	Business	42100.00
0005434066562	30619	Business	42100.00
0005434066461	30619	Business	42100.00
0005432525935	30619	Business	42100.00
0005435213093	30619	Business	42100.00
0005432525870	30619	Comfort	23900.00
0005433656649	30619	Comfort	23900.00
0005432526020	30619	Comfort	23900.00
0005435213153	30619	Comfort	23900.00
0005435213109	30619	Comfort	23900.00
0005435213159	30619	Comfort	23900.00
0005435213126	30619	Comfort	23900.00
0005432526206	30619	Comfort	23900.00
0005434066409	30619	Comfort	23900.00
0005432526316	30619	Comfort	23900.00
0005432535766	30619	Comfort	23900.00
0005434066322	30619	Comfort	23900.00
0005432525643	30619	Comfort	23900.00
0005434066771	30619	Comfort	23900.00
0005435213106	30619	Comfort	23900.00
0005435725571	30619	Comfort	23900.00
0005435213111	30619	Comfort	23900.00
0005434066381	30619	Comfort	23900.00
0005432525891	30619	Comfort	23900.00
0005432526369	30619	Comfort	23900.00
0005434066382	30619	Comfort	23900.00
0005435213118	30619	Comfort	23900.00
0005432159830	30619	Comfort	23900.00
0005432526095	30619	Comfort	23900.00
0005435213155	30619	Comfort	23900.00
0005432525826	30619	Comfort	23900.00
0005432526325	30619	Comfort	23900.00
0005432526357	30619	Comfort	23900.00
0005435213143	30619	Comfort	23900.00
0005435213100	30619	Comfort	23900.00
0005432526403	30619	Comfort	23900.00
0005432525862	30619	Comfort	23900.00
0005434066616	30619	Economy	14000.00
0005432526015	30619	Economy	14000.00
0005435725567	30619	Economy	14000.00
0005434066642	30619	Economy	14000.00
0005435213128	30619	Economy	14000.00
0005432526017	30619	Economy	14000.00
0005433656652	30619	Economy	14000.00
0005435725568	30619	Economy	14000.00
0005434066458	30619	Economy	14000.00
0005434066473	30619	Economy	14000.00
0005432525863	30619	Economy	14000.00
0005435213157	30619	Economy	14000.00
0005432526231	30619	Economy	14000.00
0005432525792	30619	Economy	14000.00
0005432159828	30619	Economy	14000.00
0005434066398	30619	Economy	14000.00
0005435213154	30619	Economy	14000.00
0005432526071	30619	Economy	14000.00
0005434066475	30619	Economy	14000.00
0005432526309	30619	Economy	14000.00
0005432526399	30619	Economy	14000.00
0005435213140	30619	Economy	14000.00
0005435213127	30619	Economy	14000.00
0005435213131	30619	Economy	14000.00
0005432526264	30619	Economy	14000.00
0005434066366	30619	Economy	14000.00
0005435213151	30619	Economy	14000.00
0005434066477	30619	Economy	14000.00
0005435213142	30619	Economy	14000.00
0005432526324	30619	Economy	14000.00
0005435213099	30619	Economy	14000.00
0005435213150	30619	Economy	14000.00
0005432525845	30619	Economy	14000.00
0005432535754	30619	Economy	14000.00
0005432526135	30619	Economy	14000.00
0005432526163	30619	Economy	14000.00
0005432526043	30619	Economy	14000.00
0005432526300	30619	Economy	14000.00
0005435213091	30619	Economy	14000.00
0005434066489	30619	Economy	14000.00
0005432159829	30619	Economy	14000.00
0005432525951	30619	Economy	14000.00
0005432526574	30619	Economy	14000.00
0005432526247	30619	Economy	14000.00
0005434066392	30619	Economy	14000.00
0005435630949	30619	Economy	14000.00
0005432525906	30619	Economy	14000.00
0005432428882	30619	Economy	15400.00
0005432525825	30619	Economy	15400.00
0005432537033	30619	Economy	15400.00
0005435213108	30619	Economy	14000.00
0005435213146	30619	Economy	14000.00
0005432526459	30619	Economy	14000.00
0005434066537	30619	Economy	15400.00
0005434066538	30619	Economy	15400.00
0005435213113	30619	Economy	14000.00
0005432533243	30619	Economy	14000.00
0005432211456	30619	Economy	14000.00
0005435213110	30619	Economy	14000.00
0005432526159	30619	Economy	14000.00
0005432525769	30619	Economy	14000.00
0005432526290	30619	Economy	14000.00
0005435213121	30619	Economy	14000.00
0005432535767	30619	Economy	14000.00
0005435213104	30619	Economy	14000.00
0005434066779	30619	Economy	14000.00
0005433656651	30619	Economy	14000.00
0005434066631	30619	Economy	14000.00
0005432525642	30619	Economy	14000.00
0005435213094	30619	Economy	14000.00
0005432526182	30619	Economy	14000.00
0005432526126	30619	Economy	14000.00
0005435213133	30619	Economy	14000.00
0005435213103	30619	Economy	14000.00
0005432211454	30619	Economy	14000.00
0005432526019	30619	Economy	14000.00
0005432526329	30619	Economy	14000.00
0005432428880	30619	Economy	14000.00
0005435213145	30619	Economy	14000.00
0005434066377	30619	Economy	14000.00
0005435213135	30619	Economy	14000.00
0005432159827	30619	Economy	14000.00
0005432526137	30619	Economy	14000.00
0005434066355	30619	Economy	14000.00
0005435213147	30619	Economy	14000.00
0005432535755	30619	Economy	14000.00
0005434066825	30619	Economy	14000.00
0005432526301	30619	Economy	14000.00
0005435213117	30619	Economy	14000.00
0005435213116	30619	Economy	14000.00
0005432525997	30619	Economy	14000.00
0005434066572	30619	Economy	14000.00
0005432526281	30619	Economy	14000.00
0005432526550	30619	Economy	14000.00
0005434066617	30619	Economy	14000.00
0005432526069	30619	Economy	14000.00
0005435213115	30619	Economy	14000.00
0005435213138	30619	Economy	14000.00
0005435213156	30619	Economy	14000.00
0005432526154	30619	Economy	14000.00
0005435213134	30619	Economy	14000.00
0005434066502	30619	Economy	14000.00
0005435213096	30619	Economy	14000.00
0005432526282	30619	Economy	14000.00
0005434066314	30619	Economy	14000.00
0005434066564	30619	Economy	14000.00
0005434066493	30619	Economy	14000.00
0005432525734	30619	Economy	14000.00
0005432526006	30619	Economy	14000.00
0005435213095	30619	Economy	14000.00
0005432525937	30619	Economy	14000.00
0005434066472	30619	Economy	14000.00
0005434066455	30619	Economy	14000.00
0005432526086	30619	Economy	14000.00
0005432526169	30619	Economy	14000.00
0005432526051	30619	Economy	14000.00
0005434066641	30619	Economy	14000.00
0005435213097	30619	Economy	14000.00
0005432526100	30619	Economy	14000.00
0005432525791	30619	Economy	14000.00
0005432526120	30619	Economy	14000.00
0005435213114	30619	Economy	14000.00
0005432526526	30619	Economy	14000.00
0005435213125	30619	Economy	14000.00
0005434066383	30619	Economy	14000.00
0005435725570	30619	Economy	14000.00
0005432526573	30619	Economy	14000.00
0005432526119	30619	Economy	14000.00
0005432211457	30619	Economy	14000.00
0005432211450	30619	Economy	14000.00
0005435213119	30619	Economy	14000.00
0005435213112	30619	Economy	15400.00
0005435213141	30619	Economy	15400.00
0005432526166	30619	Economy	15400.00
0005432526572	30619	Economy	15400.00
0005435213102	30619	Economy	14000.00
0005435213139	30619	Economy	14000.00
0005432525938	30619	Economy	14000.00
0005432526328	30619	Economy	14000.00
0005432526070	30619	Economy	14000.00
0005435213158	30619	Economy	14000.00
0005435213148	30619	Economy	14000.00
0005434066565	30619	Economy	14000.00
0005432526236	30619	Economy	14000.00
0005432211453	30619	Economy	14000.00
0005434066448	30619	Economy	14000.00
0005432525680	30619	Economy	14000.00
0005432526033	30619	Economy	14000.00
0005432525890	30619	Economy	14000.00
0005432537035	30619	Economy	14000.00
0005435725572	30619	Economy	14000.00
0005432526273	30619	Economy	14000.00
0005432526029	30619	Economy	14000.00
0005432525844	30619	Economy	14000.00
0005434066389	30619	Economy	14000.00
0005434066712	30619	Economy	14000.00
0005434066492	30619	Economy	14000.00
0005432211451	30619	Economy	14000.00
0005434066393	30619	Economy	14000.00
0005434066344	30619	Economy	14000.00
0005432159826	30619	Economy	14000.00
0005435725569	30619	Economy	14000.00
0005435213120	30619	Economy	14000.00
0005432211452	30619	Economy	14000.00
0005435213132	30619	Economy	14000.00
0005434066524	30619	Economy	14000.00
0005435213122	30619	Economy	14000.00
0005435213130	30619	Economy	14000.00
0005432525704	30619	Economy	14000.00
0005432533244	30619	Economy	14000.00
0005434066630	30619	Economy	14000.00
0005434066405	30619	Economy	14000.00
0005434066601	30619	Economy	14000.00
0005432526525	30619	Economy	14000.00
0005435213160	30619	Economy	14000.00
0005432526207	30619	Economy	14000.00
0005434066356	30619	Economy	14000.00
0005432525770	30619	Economy	14000.00
0005432526321	30619	Economy	14000.00
0005435213101	30619	Economy	14000.00
0005432428869	30619	Economy	14000.00
0005434066315	30619	Economy	14000.00
0005432525827	30619	Economy	14000.00
0005435213136	30619	Economy	14000.00
0005432535753	30619	Economy	14000.00
0005432525922	30619	Economy	14000.00
0005432525713	30619	Economy	14000.00
0005432525676	30619	Economy	14000.00
0005435213129	30619	Economy	14000.00
0005432526350	30619	Economy	14000.00
0005434066437	30619	Economy	14000.00
0005432526502	30619	Economy	14000.00
0005434066585	30619	Economy	14000.00
0005434066501	30619	Economy	14000.00
0005434066454	30619	Economy	14000.00
0005435213149	30619	Economy	14000.00
0005435213144	30619	Economy	14000.00
0005432526436	30619	Economy	14000.00
0005435213092	30619	Economy	14000.00
0005435213124	30619	Economy	14000.00
0005432211455	30619	Economy	14000.00
0005432526085	30619	Economy	14000.00
0005432526483	30619	Economy	14000.00
0005434066401	30619	Economy	14000.00
0005432525635	30619	Economy	14000.00
0005432525793	30619	Economy	14000.00
0005432526164	30619	Economy	14000.00
0005432525996	30619	Economy	14000.00
0005435213152	30619	Economy	14000.00
0005432526458	30619	Economy	14000.00
0005432526123	30619	Economy	14000.00
0005432526034	30619	Economy	14000.00
0005434066323	30619	Economy	14000.00
0005432525705	30619	Economy	14000.00
0005432537034	30619	Economy	14000.00
0005432526127	30619	Economy	14000.00
0005432525783	30619	Economy	14000.00
0005433367646	24825	Business	9800.00
0005435652464	24825	Business	9800.00
0005435652479	24825	Business	9800.00
0005433367663	24825	Business	9800.00
0005433367664	24825	Business	9800.00
0005435652256	24825	Business	9800.00
0005433367650	24825	Business	9800.00
0005433367675	24825	Business	9800.00
0005433367643	24825	Economy	3300.00
0005435652340	24825	Economy	3300.00
0005433367672	24825	Economy	3300.00
0005433367670	24825	Economy	3300.00
0005435652333	24825	Economy	3300.00
0005435652386	24825	Economy	3300.00
0005433367678	24825	Economy	3300.00
0005433367673	24825	Economy	3600.00
0005433367674	24825	Economy	3600.00
0005433367648	24825	Economy	3600.00
0005435652456	24825	Economy	3600.00
0005433367668	24825	Economy	3300.00
0005433367660	24825	Economy	3300.00
0005435652348	24825	Economy	3300.00
0005435652435	24825	Economy	3300.00
0005435652452	24825	Economy	3300.00
0005433367677	24825	Economy	3300.00
0005435652461	24825	Economy	3300.00
0005435652445	24825	Economy	3300.00
0005435652275	24825	Economy	3300.00
0005435652463	24825	Economy	3300.00
0005435652332	24825	Economy	3300.00
0005435652330	24825	Economy	3300.00
0005433367641	24825	Economy	3300.00
0005435652457	24825	Economy	3300.00
0005435652414	24825	Economy	3300.00
0005435652480	24825	Economy	3300.00
0005433367662	24825	Economy	3300.00
0005435652329	24825	Economy	3300.00
0005433367659	24825	Economy	3300.00
0005433367656	24825	Economy	3300.00
0005433367644	24825	Economy	3300.00
0005433367658	24825	Economy	3300.00
0005435652331	24825	Economy	3300.00
0005433367676	24825	Economy	3300.00
0005435652384	24825	Economy	3300.00
0005435652501	24825	Economy	3300.00
0005435652468	24825	Economy	3300.00
0005433367645	24825	Economy	3300.00
0005435652453	24825	Economy	3300.00
0005435652454	24825	Economy	3300.00
0005433367661	24825	Economy	3300.00
0005435652343	24825	Economy	3300.00
0005435652455	24825	Economy	3300.00
0005435652357	24825	Economy	3300.00
0005433367652	24825	Economy	3300.00
0005433367657	24825	Economy	3300.00
0005433367649	24825	Economy	3300.00
0005433367671	24825	Economy	3300.00
0005435652523	24825	Economy	3300.00
0005435652478	24825	Economy	3300.00
0005433367647	24825	Economy	3300.00
0005435652469	24825	Economy	3300.00
0005433367666	24825	Economy	3300.00
0005433367654	24825	Economy	3300.00
0005433367655	24825	Economy	3300.00
0005433367667	24825	Economy	3300.00
0005435652444	24825	Economy	3300.00
0005435652288	24825	Economy	3300.00
0005433367665	24825	Economy	3300.00
0005435652408	24825	Economy	3300.00
0005433367651	24825	Economy	3300.00
0005433367653	24825	Economy	3300.00
0005433367642	24825	Economy	3300.00
0005433367669	24825	Economy	3300.00
0005435949736	23321	Economy	18700.00
0005435949733	23321	Economy	18700.00
0005435949734	23321	Economy	18700.00
0005435949748	23321	Economy	18700.00
0005435949738	23321	Economy	18700.00
0005435949732	23321	Economy	18700.00
0005435949737	23321	Economy	18700.00
0005435949742	23321	Economy	18700.00
0005434979602	2039	Economy	10500.00
0005434979596	2039	Economy	10500.00
0005435801679	2039	Economy	10500.00
0005434979612	2039	Economy	10500.00
0005434979611	2039	Economy	9500.00
0005434979615	2039	Economy	9500.00
0005434979592	2039	Economy	9500.00
0005434979603	2039	Economy	9500.00
0005434979607	2039	Economy	9500.00
0005434979599	2039	Economy	9500.00
0005434979597	2039	Economy	9500.00
0005434979609	2039	Economy	9500.00
0005434979621	2039	Economy	9500.00
0005434979614	2039	Economy	9500.00
0005434979604	2039	Economy	9500.00
0005434979606	2039	Economy	9500.00
0005435801677	2039	Economy	9500.00
0005434979610	2039	Economy	9500.00
0005434979620	2039	Economy	9500.00
0005434979598	2039	Economy	9500.00
0005434979618	2039	Economy	9500.00
0005434979616	2039	Economy	9500.00
0005434979595	2039	Economy	9500.00
0005434979608	2039	Economy	9500.00
0005434979600	2039	Economy	9500.00
0005434979601	2039	Economy	9500.00
0005435801678	2039	Economy	9500.00
0005434979619	2039	Economy	9500.00
0005435801676	2039	Economy	9500.00
0005434979613	2039	Economy	9500.00
0005434979594	2039	Economy	9500.00
0005434979605	2039	Economy	9500.00
0005434979593	2039	Economy	9500.00
0005434979617	2039	Economy	9500.00
0005435801654	23550	Economy	10500.00
0005434979289	23550	Economy	10500.00
0005434979294	23550	Economy	10500.00
0005434979342	23550	Economy	9500.00
0005434979458	23550	Economy	9500.00
0005434979391	23550	Economy	9500.00
0005434979268	23550	Economy	9500.00
0005434979269	23550	Economy	9500.00
0005434979288	23550	Economy	9500.00
0005435801645	23550	Economy	9500.00
0005434979284	23550	Economy	9500.00
0005434979357	23550	Economy	9500.00
0005434979307	23550	Economy	9500.00
0005434979279	23550	Economy	9500.00
0005434979382	23550	Economy	9500.00
0005434979349	23550	Economy	9500.00
0005434979308	23550	Economy	9500.00
0005434979309	23550	Economy	9500.00
0005434979381	23550	Economy	9500.00
0005434979290	23550	Economy	9500.00
0005435801650	23550	Economy	9500.00
0005434979355	23550	Economy	9500.00
0005435801647	23550	Economy	9500.00
0005434979348	23550	Economy	9500.00
0005435801649	23550	Economy	9500.00
0005435801653	23550	Economy	9500.00
0005434979380	23550	Economy	9500.00
0005434979457	23550	Economy	9500.00
0005434979271	23550	Economy	9500.00
0005434979266	23550	Economy	9500.00
0005434979267	23550	Economy	9500.00
0005434979276	23550	Economy	9500.00
0005434979310	23550	Economy	9500.00
0005434979372	23550	Economy	9500.00
0005434952507	2577	Economy	5300.00
0005434952509	2577	Economy	5300.00
0005434952508	2577	Economy	5300.00
0005434952506	2577	Economy	5300.00
0005433256386	2578	Economy	5300.00
0005433256408	28223	Economy	5300.00
0005434952475	28223	Economy	5300.00
0005433256409	28223	Economy	5300.00
0005434952476	28223	Economy	5300.00
0005433112364	19792	Economy	8700.00
0005433111493	19792	Economy	8700.00
0005433111494	19792	Economy	8700.00
0005433111495	19792	Economy	8700.00
0005433112363	19792	Economy	8700.00
0005433111492	19792	Economy	8700.00
0005434137051	11927	Business	9700.00
0005434136947	11927	Business	9700.00
0005434136724	11927	Business	9700.00
0005434136845	11927	Business	9700.00
0005434136956	11927	Business	9700.00
0005434136937	11927	Business	9700.00
0005434136825	11927	Business	9700.00
0005434136940	11927	Business	9700.00
0005434136826	11927	Business	9700.00
0005434137052	11927	Business	9700.00
0005434136935	11927	Economy	3200.00
0005434137006	11927	Economy	3200.00
0005434136988	11927	Economy	3200.00
0005434137087	11927	Economy	3200.00
0005434137044	11927	Economy	3200.00
0005434136689	11927	Economy	3200.00
0005434136946	11927	Economy	3200.00
0005434136682	11927	Economy	3200.00
0005434136931	11927	Economy	3500.00
0005434137027	11927	Economy	3500.00
0005434137080	11927	Economy	3500.00
0005434137153	11927	Economy	3500.00
0005434137025	11927	Economy	3200.00
0005434136979	11927	Economy	3200.00
0005434136977	11927	Economy	3200.00
0005434137331	11927	Economy	3200.00
0005434136936	11927	Economy	3200.00
0005434137071	11927	Economy	3200.00
0005434136941	11927	Economy	3200.00
0005434137310	11927	Economy	3200.00
0005434136764	11927	Economy	3200.00
0005434137075	11927	Economy	3200.00
0005434136980	11927	Economy	3200.00
0005434136814	11927	Economy	3200.00
0005434137140	11927	Economy	3200.00
0005434137094	11927	Economy	3200.00
0005434137074	11927	Economy	3200.00
0005434137079	11927	Economy	3200.00
0005434137242	11927	Economy	3200.00
0005434137122	11927	Economy	3200.00
0005434136838	11927	Economy	3200.00
0005434136932	11927	Economy	3200.00
0005434136754	11927	Economy	3200.00
0005434137012	11927	Economy	3200.00
0005434136813	11927	Economy	3200.00
0005434136725	11927	Economy	3200.00
0005434136874	11927	Economy	3200.00
0005434136889	11927	Economy	3200.00
0005434137095	11927	Economy	3200.00
0005434137098	11927	Economy	3200.00
0005434137193	11927	Economy	3200.00
0005434136818	11927	Economy	3200.00
0005434137254	11927	Economy	3200.00
0005434137165	11927	Economy	3200.00
0005434136891	11927	Economy	3200.00
0005434137082	11927	Economy	3200.00
0005434136968	11927	Economy	3200.00
0005434136783	11927	Economy	3200.00
0005434137232	11927	Economy	3200.00
0005434137028	11927	Economy	3200.00
0005434137007	11927	Economy	3200.00
0005434136765	11927	Economy	3200.00
0005434137113	11927	Economy	3200.00
0005434136766	11927	Economy	3200.00
0005434137176	11927	Economy	3200.00
0005434137127	11927	Economy	3200.00
0005434136837	11927	Economy	3200.00
0005434137086	11927	Economy	3200.00
0005434136978	11927	Economy	3200.00
0005434136976	11927	Economy	3200.00
0005434137241	11927	Economy	3200.00
0005434137332	11927	Economy	3200.00
0005434137443	11927	Economy	3200.00
0005434137253	11927	Economy	3200.00
0005434137081	11927	Economy	3200.00
0005434137128	11927	Economy	3200.00
0005434137131	11927	Economy	3200.00
0005434136787	11927	Economy	3200.00
0005434137538	28757	Business	9700.00
0005434137566	28757	Business	9700.00
0005434137613	28757	Business	9700.00
0005434137611	28757	Business	9700.00
0005434137608	28757	Business	9700.00
0005434137574	28757	Business	9700.00
0005434137563	28757	Business	9700.00
0005434137595	28757	Business	9700.00
0005434137615	28757	Business	9700.00
0005434137562	28757	Business	9700.00
0005434137589	28757	Economy	3200.00
0005434137618	28757	Economy	3200.00
0005434137619	28757	Economy	3200.00
0005434137590	28757	Economy	3200.00
0005434137539	28757	Economy	3200.00
0005434137545	28757	Economy	3200.00
0005434137579	28757	Economy	3200.00
0005434137580	28757	Economy	3200.00
0005434137555	28757	Economy	3200.00
0005434137601	28757	Economy	3500.00
0005434137543	28757	Economy	3500.00
0005434137610	28757	Economy	3500.00
0005434137577	28757	Economy	3500.00
0005434137606	28757	Economy	3200.00
0005434137592	28757	Economy	3200.00
0005434137553	28757	Economy	3200.00
0005434137616	28757	Economy	3200.00
0005434137607	28757	Economy	3200.00
0005434137558	28757	Economy	3200.00
0005434137564	28757	Economy	3200.00
0005434137585	28757	Economy	3200.00
0005434137600	28757	Economy	3200.00
0005434137593	28757	Economy	3200.00
0005434137573	28757	Economy	3200.00
0005434137581	28757	Economy	3200.00
0005434137582	28757	Economy	3200.00
0005434137565	28757	Economy	3200.00
0005434137622	28757	Economy	3200.00
0005434137597	28757	Economy	3200.00
0005434137542	28757	Economy	3200.00
0005434137568	28757	Economy	3200.00
0005434137591	28757	Economy	3200.00
0005434137559	28757	Economy	3200.00
0005434137550	28757	Economy	3200.00
0005434137621	28757	Economy	3200.00
0005434137570	28757	Economy	3200.00
0005434137614	28757	Economy	3200.00
0005434137554	28757	Economy	3200.00
0005434137567	28757	Economy	3200.00
0005434137578	28757	Economy	3200.00
0005434137575	28757	Economy	3200.00
0005434137571	28757	Economy	3200.00
0005434137551	28757	Economy	3200.00
0005434137604	28757	Economy	3200.00
0005434137547	28757	Economy	3200.00
0005434137557	28757	Economy	3200.00
0005434137602	28757	Economy	3200.00
0005434137540	28757	Economy	3200.00
0005434137587	28757	Economy	3200.00
0005434137572	28757	Economy	3200.00
0005434137588	28757	Economy	3200.00
0005434137561	28757	Economy	3200.00
0005434137544	28757	Economy	3200.00
0005434137599	28757	Economy	3200.00
0005434137576	28757	Economy	3200.00
0005434137620	28757	Economy	3200.00
0005434137586	28757	Economy	3200.00
0005434137617	28757	Economy	3200.00
0005434137583	28757	Economy	3200.00
0005434137546	28757	Economy	3200.00
0005434137584	28757	Economy	3200.00
0005434137549	28757	Economy	3200.00
0005434137612	28757	Economy	3200.00
0005434137552	28757	Economy	3200.00
0005434137605	28757	Economy	3200.00
0005434137548	28757	Economy	3200.00
0005434137541	28757	Economy	3200.00
0005434137556	28757	Economy	3200.00
0005434137603	28757	Economy	3200.00
0005434137594	28757	Economy	3200.00
0005434137569	28757	Economy	3200.00
0005434137609	28757	Economy	3200.00
0005434137596	28757	Economy	3200.00
0005434137560	28757	Economy	3200.00
0005434137623	28757	Economy	3200.00
0005434137598	28757	Economy	3200.00
0005435312771	6581	Economy	23000.00
0005434466430	6581	Economy	20900.00
0005434466426	6581	Economy	20900.00
0005434466429	6581	Economy	20900.00
0005435312768	6581	Economy	20900.00
0005434466428	6581	Economy	20900.00
0005434466431	6581	Economy	20900.00
0005434466427	6581	Economy	20900.00
0005434466432	6581	Economy	20900.00
0005435312767	6581	Economy	20900.00
0005434513543	19099	Economy	26000.00
0005434190391	19099	Economy	23600.00
0005434516049	19099	Economy	23600.00
0005434516047	19099	Economy	23600.00
0005434190385	19099	Economy	23600.00
0005434513546	19099	Economy	23600.00
0005434190389	19099	Economy	23600.00
0005434513538	19099	Economy	23600.00
0005434513537	19099	Economy	23600.00
0005434513539	19099	Economy	23600.00
0005434190386	19099	Economy	23600.00
0005434190388	19099	Economy	23600.00
0005434513545	19099	Economy	23600.00
0005434516050	19099	Economy	23600.00
0005434190387	19099	Economy	23600.00
0005434190390	19099	Economy	23600.00
0005434513542	19099	Economy	23600.00
0005434190392	19099	Economy	23600.00
0005433538817	6815	Economy	10900.00
0005435259701	6815	Economy	10900.00
0005433538814	6815	Economy	9900.00
0005435259690	6815	Economy	9900.00
0005433534484	6815	Economy	9900.00
0005433538822	6815	Economy	9900.00
0005435259692	6815	Economy	9900.00
0005433534485	6815	Economy	9900.00
0005433538820	6815	Economy	9900.00
0005433538815	6815	Economy	9900.00
0005435259691	6815	Economy	9900.00
0005433538819	6815	Economy	9900.00
0005433538813	6815	Economy	9900.00
0005433538816	6815	Economy	9900.00
0005433538821	6815	Economy	9900.00
0005435259693	6815	Economy	9900.00
0005433538818	6815	Economy	9900.00
0005435259689	6815	Economy	9900.00
0005435259704	6815	Economy	9900.00
0005435259705	6815	Economy	9900.00
0005433538742	25017	Economy	10900.00
0005435259731	25017	Economy	9900.00
0005433534460	25017	Economy	9900.00
0005433534469	25017	Economy	9900.00
0005433538748	25017	Economy	9900.00
0005435259730	25017	Economy	9900.00
0005433538718	25017	Economy	9900.00
0005433538758	25017	Economy	9900.00
0005435259729	25017	Economy	9900.00
0005433538757	25017	Economy	9900.00
0005433538717	25017	Economy	9900.00
0005435259728	25017	Economy	9900.00
0005432922462	808	Economy	14600.00
0005432922461	808	Economy	14600.00
0005433511903	808	Economy	14600.00
0005433511901	808	Economy	14600.00
0005433511902	808	Economy	14600.00
0005433511899	808	Economy	14600.00
0005432922456	808	Economy	14600.00
0005433511900	808	Economy	14600.00
0005433511898	808	Economy	14600.00
0005432922464	808	Economy	14600.00
0005433511897	808	Economy	14600.00
0005433511829	16174	Economy	14600.00
0005433511844	16174	Economy	14600.00
0005432922499	16174	Economy	14600.00
0005432922498	16174	Economy	14600.00
0005433511869	16174	Economy	14600.00
0005433511846	16174	Economy	14600.00
0005432922500	16174	Economy	14600.00
0005432922501	16174	Economy	14600.00
0005433511830	16174	Economy	14600.00
0005433511831	16174	Economy	14600.00
0005435697162	3665	Economy	7900.00
0005435697177	3665	Economy	7900.00
0005435697159	3665	Economy	7900.00
0005435697166	3665	Economy	7200.00
0005435697179	3665	Economy	7200.00
0005435697170	3665	Economy	7200.00
0005435697165	3665	Economy	7200.00
0005435697163	3665	Economy	7200.00
0005435697178	3665	Economy	7200.00
0005434950504	3665	Economy	7200.00
0005435697172	3665	Economy	7200.00
0005435697186	3665	Economy	7200.00
0005435935003	3665	Economy	7200.00
0005435697164	3665	Economy	7200.00
0005435697185	3665	Economy	7200.00
0005435697168	3665	Economy	7200.00
0005435697174	3665	Economy	7200.00
0005435697182	3665	Economy	7200.00
0005435935005	3665	Economy	7200.00
0005435935004	3665	Economy	7200.00
0005435697180	3665	Economy	7200.00
0005435697161	3665	Economy	7200.00
0005435935007	3665	Economy	7200.00
0005434950501	3665	Economy	7200.00
0005435697183	3665	Economy	7200.00
0005434950502	3665	Economy	7200.00
0005435697175	3665	Economy	7200.00
0005435697160	3665	Economy	7200.00
0005435935016	3665	Economy	7200.00
0005435697173	3665	Economy	7200.00
0005435697176	3665	Economy	7200.00
0005435697167	3665	Economy	7200.00
0005434950503	3665	Economy	7200.00
0005435697171	3665	Economy	7200.00
0005435697187	3665	Economy	7200.00
0005435697184	3665	Economy	7200.00
0005435697169	3665	Economy	7200.00
0005435697181	3665	Economy	7200.00
0005434950500	3665	Economy	7200.00
0005434950462	16258	Economy	7900.00
0005435696992	16258	Economy	7900.00
0005435696963	16258	Economy	7900.00
0005435696998	16258	Economy	7200.00
0005435916150	16258	Economy	7200.00
0005435935021	16258	Economy	7200.00
0005435916151	16258	Economy	7200.00
0005435696873	16258	Economy	7200.00
0005435696900	16258	Economy	7200.00
0005435935022	16258	Economy	7200.00
0005435696903	16258	Economy	7200.00
0005435696997	16258	Economy	7200.00
0005434950463	16258	Economy	7200.00
0005435696955	16258	Economy	7200.00
0005435696999	16258	Economy	7200.00
0005435696902	16258	Economy	7200.00
0005435696913	16258	Economy	7200.00
0005435696899	16258	Economy	7200.00
0005435696956	16258	Economy	7200.00
0005435696911	16258	Economy	7200.00
0005435935020	16258	Economy	7200.00
0005435696958	16258	Economy	7200.00
0005435935023	16258	Economy	7200.00
0005435696959	16258	Economy	7200.00
0005435696912	16258	Economy	7200.00
0005435696890	16258	Economy	7200.00
0005435696935	16258	Economy	7200.00
0005435696942	16258	Economy	7200.00
0005435696892	16258	Economy	7200.00
0005435696943	16258	Economy	7200.00
0005435916149	16258	Economy	7200.00
0005434604875	3941	Economy	21300.00
0005435853588	3941	Economy	21300.00
0005433519432	3941	Economy	21300.00
0005435853596	3941	Economy	21300.00
0005432607542	3941	Economy	19300.00
0005434606807	3941	Economy	19300.00
0005433519429	3941	Economy	19300.00
0005433519431	3941	Economy	19300.00
0005432607543	3941	Economy	19300.00
0005433519430	3941	Economy	19300.00
0005432609707	3941	Economy	19300.00
0005435842314	3941	Economy	19300.00
0005434604876	3941	Economy	19300.00
0005435853597	3941	Economy	19300.00
0005432609708	3941	Economy	19300.00
0005434606810	3941	Economy	19300.00
0005435853589	3941	Economy	19300.00
0005432609706	3941	Economy	19300.00
0005432609705	3941	Economy	19300.00
0005434606808	3941	Economy	19300.00
0005434604877	3941	Economy	19300.00
0005432607539	3941	Economy	19300.00
0005433519428	3941	Economy	19300.00
0005432607541	3941	Economy	19300.00
0005432607540	3941	Economy	19300.00
0005435853593	3941	Economy	19300.00
0005435842318	3941	Economy	19300.00
0005434606811	3941	Economy	19300.00
0005434604879	3941	Economy	19300.00
0005435853582	3941	Economy	19300.00
0005434606806	3941	Economy	19300.00
0005432609704	3941	Economy	19300.00
0005434606809	3941	Economy	19300.00
0005435853581	3941	Economy	19300.00
0005434604878	3941	Economy	19300.00
0005435853592	3941	Economy	19300.00
0005435841091	22053	Economy	21300.00
0005435841089	22053	Economy	21300.00
0005432609668	22053	Economy	19300.00
0005435841468	22053	Economy	19300.00
0005435841092	22053	Economy	19300.00
0005435841088	22053	Economy	19300.00
0005432613796	22053	Economy	19300.00
0005435841469	22053	Economy	19300.00
0005434606778	22053	Economy	19300.00
0005435841466	22053	Economy	19300.00
0005433519394	22053	Economy	19300.00
0005435853601	22053	Economy	19300.00
0005432609665	22053	Economy	19300.00
0005432609666	22053	Economy	19300.00
0005435841090	22053	Economy	19300.00
0005435853600	22053	Economy	19300.00
0005432613794	22053	Economy	19300.00
0005435841467	22053	Economy	19300.00
0005432613789	22053	Economy	19300.00
0005435904893	22053	Economy	19300.00
0005435841470	22053	Economy	19300.00
0005434606777	22053	Economy	19300.00
0005432613797	22053	Economy	19300.00
0005435841087	22053	Economy	19300.00
0005432613795	22053	Economy	19300.00
0005432609664	22053	Economy	19300.00
0005435841465	22053	Economy	19300.00
0005435853599	22053	Economy	19300.00
0005434606761	22053	Economy	19300.00
0005434606772	22053	Economy	19300.00
0005433348915	786	Economy	3700.00
0005433348900	786	Economy	3700.00
0005433348906	786	Economy	3700.00
0005433348907	786	Economy	3700.00
0005433348893	786	Economy	3700.00
0005433348913	786	Economy	3700.00
0005433348890	786	Economy	3700.00
0005433348914	786	Economy	3700.00
0005433348896	786	Economy	3700.00
0005435628707	786	Economy	3700.00
0005435628708	786	Economy	3700.00
0005433348957	15992	Economy	3700.00
0005433348956	15992	Economy	3700.00
0005433348954	15992	Economy	3700.00
0005435628683	15992	Economy	3700.00
0005435628680	15992	Economy	3700.00
0005433348955	15992	Economy	3700.00
0005435628684	15992	Economy	3700.00
0005433348952	15992	Economy	3700.00
0005435628688	15992	Economy	3700.00
0005433348953	15992	Economy	3700.00
0005435628689	15992	Economy	3700.00
0005434445231	17212	Economy	7100.00
0005433159277	17212	Economy	7100.00
0005433158103	17212	Economy	7100.00
0005433159280	17212	Economy	7100.00
0005434445232	17212	Economy	7100.00
0005433159279	17212	Economy	7100.00
0005433158102	17212	Economy	7100.00
0005433158101	17212	Economy	7100.00
0005434445230	17212	Economy	7100.00
0005433159300	17674	Economy	7100.00
0005433159299	17674	Economy	7100.00
0005434445213	17674	Economy	7100.00
0005435383059	7880	Economy	5900.00
0005435132817	7880	Economy	5900.00
0005435132814	7880	Economy	5400.00
0005435383058	7880	Economy	5400.00
0005435132820	7880	Economy	5400.00
0005435383063	7880	Economy	5400.00
0005435132818	7880	Economy	5400.00
0005435132823	7880	Economy	5400.00
0005435132821	7880	Economy	5400.00
0005435132816	7880	Economy	5400.00
0005435383093	7880	Economy	5400.00
0005435132824	7880	Economy	5400.00
0005435383061	7880	Economy	5400.00
0005435132819	7880	Economy	5400.00
0005435132813	7880	Economy	5400.00
0005435383062	7880	Economy	5400.00
0005435132815	7880	Economy	5400.00
0005435132822	7880	Economy	5400.00
0005435132759	33080	Economy	5900.00
0005435383120	33080	Economy	5400.00
0005435383119	33080	Economy	5400.00
0005435383116	33080	Economy	5400.00
0005435132740	33080	Economy	5400.00
0005435132739	33080	Economy	5400.00
0005435383117	33080	Economy	5400.00
0005435383115	33080	Economy	5400.00
0005435132748	33080	Economy	5400.00
0005435383118	33080	Economy	5400.00
0005435132745	33080	Economy	5400.00
0005435132726	33080	Economy	5400.00
0005435132744	33080	Economy	5400.00
0005435938857	4413	Business	133200.00
0005435938847	4413	Business	133200.00
0005435811038	4413	Business	133200.00
0005435811047	4413	Business	133200.00
0005435811041	4413	Economy	44400.00
0005435811045	4413	Economy	44400.00
0005435811046	4413	Economy	44400.00
0005435811039	4413	Economy	44400.00
0005435811033	4413	Economy	44400.00
0005435811036	4413	Economy	44400.00
0005435811032	4413	Economy	44400.00
0005435811037	4413	Economy	44400.00
0005435811043	4413	Economy	44400.00
0005435811034	4413	Economy	44400.00
0005435811042	4413	Economy	44400.00
0005435811044	4413	Economy	44400.00
0005435811040	4413	Economy	44400.00
0005435811035	4413	Economy	44400.00
0005435810992	29454	Business	133200.00
0005435938868	29454	Economy	44400.00
0005435938865	29454	Economy	44400.00
0005435811004	29454	Economy	44400.00
0005435811010	29454	Economy	44400.00
0005435811007	29454	Economy	44400.00
0005435938867	29454	Economy	44400.00
0005435938870	29454	Economy	44400.00
0005435810994	29454	Economy	44400.00
0005435811002	29454	Economy	44400.00
0005435810993	29454	Economy	44400.00
0005435938872	29454	Economy	44400.00
0005435810991	29454	Economy	44400.00
0005435938869	29454	Economy	44400.00
0005435810987	29454	Economy	44400.00
0005435938871	29454	Economy	44400.00
0005435938866	29454	Economy	44400.00
0005435811005	29454	Economy	44400.00
0005435160230	7505	Economy	13800.00
0005435160233	7505	Economy	12500.00
0005435160229	7505	Economy	12500.00
0005435160236	7505	Economy	12500.00
0005435160238	7505	Economy	12500.00
0005435390151	7505	Economy	12500.00
0005435160237	7505	Economy	12500.00
0005435390152	7505	Economy	12500.00
0005435390124	7505	Economy	12500.00
0005435160232	7505	Economy	12500.00
0005435390159	7505	Economy	12500.00
0005435390143	7505	Economy	12500.00
0005435390128	7505	Economy	12500.00
0005435390125	7505	Economy	12500.00
0005435160239	7505	Economy	12500.00
0005435160235	7505	Economy	12500.00
0005435390134	7505	Economy	12500.00
0005435390158	7505	Economy	12500.00
0005435160234	7505	Economy	12500.00
0005435160231	7505	Economy	12500.00
0005435160162	29563	Economy	12500.00
0005435160133	29563	Economy	12500.00
0005435160115	29563	Economy	12500.00
0005435160130	29563	Economy	12500.00
0005435390196	29563	Economy	12500.00
0005435390200	29563	Economy	12500.00
0005435160109	29563	Economy	12500.00
0005435160131	29563	Economy	12500.00
0005435390201	29563	Economy	12500.00
0005435160150	29563	Economy	12500.00
0005435160193	29563	Economy	12500.00
0005435160139	29563	Economy	12500.00
0005435390197	29563	Economy	12500.00
0005435160140	29563	Economy	12500.00
0005435160134	29563	Economy	12500.00
0005435160151	29563	Economy	12500.00
0005435390198	29563	Economy	12500.00
0005435160124	29563	Economy	12500.00
0005435160173	29563	Economy	12500.00
0005435390199	29563	Economy	12500.00
0005435178487	18427	Economy	4900.00
0005435178488	18427	Economy	4900.00
0005435178989	18427	Economy	4900.00
0005432394032	18427	Economy	4900.00
0005432394043	18427	Economy	4900.00
0005432398154	18427	Economy	4900.00
0005432394048	18427	Economy	4900.00
0005432398171	27168	Economy	4900.00
0005432398168	27168	Economy	4900.00
0005432398169	27168	Economy	4900.00
0005432398170	27168	Economy	4900.00
0005432398172	27168	Economy	4900.00
0005432400097	27168	Economy	4900.00
0005432865928	2254	Business	87300.00
0005432639049	2254	Business	87300.00
0005432865914	2254	Business	87300.00
0005432639048	2254	Business	87300.00
0005432639060	2254	Business	87300.00
0005432865943	2254	Business	87300.00
0005432865910	2254	Economy	29100.00
0005432865913	2254	Economy	29100.00
0005432639064	2254	Economy	29100.00
0005432865912	2254	Economy	32000.00
0005432865894	2254	Economy	32000.00
0005432639047	2254	Economy	29100.00
0005432639063	2254	Economy	29100.00
0005432639065	2254	Economy	29100.00
0005432639062	2254	Economy	29100.00
0005432639050	2254	Economy	29100.00
0005432639058	2254	Economy	29100.00
0005432639046	2254	Economy	29100.00
0005432639056	2254	Economy	29100.00
0005432865909	2254	Economy	29100.00
0005432639055	2254	Economy	29100.00
0005432639043	2254	Economy	29100.00
0005432865917	2254	Economy	29100.00
0005432639054	2254	Economy	29100.00
0005432639044	2254	Economy	29100.00
0005432639053	2254	Economy	29100.00
0005432639051	2254	Economy	29100.00
0005432639059	2254	Economy	29100.00
0005432639052	2254	Economy	29100.00
0005432639045	2254	Economy	29100.00
0005432865904	2254	Economy	29100.00
0005432639066	2254	Economy	29100.00
0005432639042	2254	Economy	29100.00
0005432865903	2254	Economy	29100.00
0005432639061	2254	Economy	29100.00
0005432639057	2254	Economy	29100.00
0005434503939	6518	Business	48400.00
0005434503911	6518	Business	48400.00
0005435103878	6518	Business	48400.00
0005434503908	6518	Business	48400.00
0005434503934	6518	Business	48400.00
0005434503904	6518	Business	48400.00
0005434503910	6518	Business	48400.00
0005434503916	6518	Business	48400.00
0005434503912	6518	Economy	16100.00
0005434503914	6518	Economy	16100.00
0005434503927	6518	Economy	16100.00
0005435103880	6518	Economy	17800.00
0005434503923	6518	Economy	17800.00
0005435103882	6518	Economy	16100.00
0005435103884	6518	Economy	16100.00
0005435103881	6518	Economy	16100.00
0005434503926	6518	Economy	16100.00
0005434503936	6518	Economy	16100.00
0005434503915	6518	Economy	16100.00
0005434503913	6518	Economy	16100.00
0005434503929	6518	Economy	16100.00
0005434503922	6518	Economy	16100.00
0005435103885	6518	Economy	16100.00
0005434503909	6518	Economy	16100.00
0005434503907	6518	Economy	16100.00
0005434503918	6518	Economy	16100.00
0005434503935	6518	Economy	16100.00
0005434503933	6518	Economy	16100.00
0005435103879	6518	Economy	16100.00
0005434503917	6518	Economy	16100.00
0005434503937	6518	Economy	16100.00
0005434503938	6518	Economy	16100.00
0005434503919	6518	Economy	16100.00
0005435103883	6518	Economy	16100.00
0005434503930	6518	Economy	16100.00
0005434503901	6518	Economy	16100.00
0005434503928	6518	Economy	16100.00
0005434503931	6518	Economy	16100.00
0005434503932	6518	Economy	16100.00
0005434503921	6518	Economy	16100.00
0005434503920	6518	Economy	16100.00
0005434503925	6518	Economy	16100.00
0005434503903	6518	Economy	16100.00
0005434503906	6518	Economy	16100.00
0005434503924	6518	Economy	16100.00
0005434503902	6518	Economy	16100.00
0005434503905	6518	Economy	16100.00
0005434503573	22647	Business	48400.00
0005435103797	22647	Business	48400.00
0005434503582	22647	Business	48400.00
0005434503631	22647	Business	48400.00
0005434503607	22647	Economy	16100.00
0005434503559	22647	Economy	16100.00
0005434503497	22647	Economy	16100.00
0005434503532	22647	Economy	17800.00
0005434503508	22647	Economy	17800.00
0005434503598	22647	Economy	17800.00
0005434503555	22647	Economy	17800.00
0005435103793	22647	Economy	16100.00
0005434503633	22647	Economy	16100.00
0005434503498	22647	Economy	16100.00
0005434503604	22647	Economy	16100.00
0005434503507	22647	Economy	16100.00
0005434503609	22647	Economy	16100.00
0005434503512	22647	Economy	16100.00
0005435103799	22647	Economy	16100.00
0005434503471	22647	Economy	16100.00
0005434503558	22647	Economy	16100.00
0005434503470	22647	Economy	16100.00
0005434503517	22647	Economy	16100.00
0005435103800	22647	Economy	16100.00
0005435103802	22647	Economy	16100.00
0005434503632	22647	Economy	16100.00
0005434503482	22647	Economy	16100.00
0005434503472	22647	Economy	16100.00
0005435652814	1657	Business	50000.00
0005433367318	1657	Business	50000.00
0005433367303	1657	Business	50000.00
0005435652833	1657	Business	50000.00
0005435652825	1657	Business	50000.00
0005433367332	1657	Business	50000.00
0005433367244	1657	Business	50000.00
0005435652804	1657	Business	50000.00
0005435652811	1657	Business	50000.00
0005435652828	1657	Economy	16700.00
0005433367312	1657	Economy	16700.00
0005435652802	1657	Economy	16700.00
0005435652827	1657	Economy	16700.00
0005435652817	1657	Economy	16700.00
0005433367306	1657	Economy	16700.00
0005433367250	1657	Economy	16700.00
0005435652794	1657	Economy	16700.00
0005433367276	1657	Economy	18300.00
0005435652791	1657	Economy	18300.00
0005435652821	1657	Economy	18300.00
0005435652836	1657	Economy	18300.00
0005433367559	1657	Economy	18300.00
0005435652796	1657	Economy	16700.00
0005435652799	1657	Economy	16700.00
0005433367558	1657	Economy	16700.00
0005435652788	1657	Economy	16700.00
0005435652829	1657	Economy	16700.00
0005435652819	1657	Economy	16700.00
0005435652810	1657	Economy	16700.00
0005433367367	1657	Economy	16700.00
0005433367238	1657	Economy	16700.00
0005435652805	1657	Economy	16700.00
0005435652812	1657	Economy	16700.00
0005433367352	1657	Economy	16700.00
0005433367356	1657	Economy	16700.00
0005433367283	1657	Economy	16700.00
0005435652822	1657	Economy	16700.00
0005435652803	1657	Economy	16700.00
0005433367341	1657	Economy	16700.00
0005435652786	1657	Economy	16700.00
0005435652798	1657	Economy	16700.00
0005433367259	1657	Economy	16700.00
0005433367265	1657	Economy	16700.00
0005435652800	1657	Economy	16700.00
0005435652797	1657	Economy	16700.00
0005433367368	1657	Economy	16700.00
0005433367304	1657	Economy	16700.00
0005433367557	1657	Economy	16700.00
0005435652809	1657	Economy	16700.00
0005435652787	1657	Economy	16700.00
0005435652830	1657	Economy	16700.00
0005435652835	1657	Economy	16700.00
0005433367239	1657	Economy	16700.00
0005435652816	1657	Economy	16700.00
0005435652792	1657	Economy	16700.00
0005435652824	1657	Economy	16700.00
0005433367360	1657	Economy	16700.00
0005433367249	1657	Economy	16700.00
0005435652826	1657	Economy	16700.00
0005433367382	1657	Economy	16700.00
0005433367387	1657	Economy	16700.00
0005435652834	1657	Economy	16700.00
0005435652832	1657	Economy	16700.00
0005435652823	1657	Economy	16700.00
0005435652808	1657	Economy	16700.00
0005435652795	1657	Economy	16700.00
0005435652807	1657	Economy	16700.00
0005435652793	1657	Economy	16700.00
0005435652837	1657	Economy	16700.00
0005435652831	1657	Economy	16700.00
0005433367366	1657	Economy	16700.00
0005433367372	1657	Economy	16700.00
0005435652801	1657	Economy	16700.00
0005435652815	1657	Economy	16700.00
0005435652818	1657	Economy	16700.00
0005435652789	1657	Economy	16700.00
0005435652820	1657	Economy	16700.00
0005435652813	1657	Economy	16700.00
0005433367383	1657	Economy	16700.00
0005433367311	1657	Economy	16700.00
0005435652790	1657	Economy	16700.00
0005435652806	1657	Economy	16700.00
0005435652480	21662	Business	50000.00
0005435652457	21662	Business	50000.00
0005435652332	21662	Business	50000.00
0005435652386	21662	Business	50000.00
0005433367671	21662	Business	50000.00
0005435652384	21662	Business	50000.00
0005433367678	21662	Business	50000.00
0005433367643	21662	Business	50000.00
0005435652256	21662	Business	50000.00
0005435652463	21662	Business	50000.00
0005435652444	21662	Business	50000.00
0005433367658	21662	Business	50000.00
0005433367645	21662	Economy	16700.00
0005435652479	21662	Economy	16700.00
0005433367675	21662	Economy	16700.00
0005435652275	21662	Economy	16700.00
0005433367662	21662	Economy	16700.00
0005435652445	21662	Economy	16700.00
0005435652343	21662	Economy	16700.00
0005435652461	21662	Economy	18300.00
0005435652331	21662	Economy	18300.00
0005433367676	21662	Economy	18300.00
0005435652408	21662	Economy	18300.00
0005435652456	21662	Economy	16700.00
0005435652454	21662	Economy	16700.00
0005433367664	21662	Economy	16700.00
0005433367651	21662	Economy	16700.00
0005435652330	21662	Economy	16700.00
0005433367663	21662	Economy	16700.00
0005433367665	21662	Economy	16700.00
0005435652468	21662	Economy	16700.00
0005433367669	21662	Economy	16700.00
0005435652455	21662	Economy	16700.00
0005435652469	21662	Economy	16700.00
0005433367673	21662	Economy	16700.00
0005433367670	21662	Economy	16700.00
0005435652348	21662	Economy	16700.00
0005433367642	21662	Economy	16700.00
0005433367668	21662	Economy	16700.00
0005433367653	21662	Economy	16700.00
0005433367659	21662	Economy	16700.00
0005435652453	21662	Economy	16700.00
0005433367674	21662	Economy	16700.00
0005433367641	21662	Economy	16700.00
0005435652501	21662	Economy	16700.00
0005435652435	21662	Economy	16700.00
0005433367648	21662	Economy	16700.00
0005435652452	21662	Economy	16700.00
0005433367660	21662	Economy	16700.00
0005433367657	21662	Economy	16700.00
0005433367655	21662	Economy	16700.00
0005433367647	21662	Economy	16700.00
0005433367649	21662	Economy	16700.00
0005435652478	21662	Economy	16700.00
0005433367666	21662	Economy	16700.00
0005433367677	21662	Economy	16700.00
0005433367652	21662	Economy	16700.00
0005433367667	21662	Economy	16700.00
0005435652414	21662	Economy	16700.00
0005433367654	21662	Economy	16700.00
0005433367656	21662	Economy	16700.00
0005433367644	21662	Economy	16700.00
0005435652333	21662	Economy	16700.00
0005435652340	21662	Economy	16700.00
0005435652357	21662	Economy	16700.00
0005433367672	21662	Economy	16700.00
0005435652329	21662	Economy	16700.00
0005435652523	21662	Economy	16700.00
0005433367650	21662	Economy	16700.00
0005435652288	21662	Economy	16700.00
0005433367646	21662	Economy	16700.00
0005433367661	21662	Economy	16700.00
0005435652464	21662	Economy	16700.00
0005435627114	12221	Economy	11200.00
0005435627115	12221	Economy	11200.00
0005434466390	23225	Economy	23000.00
0005434466376	23225	Economy	23000.00
0005434466379	23225	Economy	23000.00
0005435312788	23225	Economy	23000.00
0005435312790	23225	Economy	20900.00
0005434466394	23225	Economy	20900.00
0005435312789	23225	Economy	20900.00
0005434466389	23225	Economy	20900.00
0005434466395	23225	Economy	20900.00
0005434466382	23225	Economy	20900.00
0005435312793	23225	Economy	20900.00
0005434466407	23225	Economy	20900.00
0005434466383	23225	Economy	20900.00
0005434466408	23225	Economy	20900.00
0005434466372	23225	Economy	20900.00
0005434466380	23225	Economy	20900.00
0005435312792	23225	Economy	20900.00
0005435312791	23225	Economy	20900.00
0005434466403	23225	Economy	20900.00
0005433985652	4184	Business	21500.00
0005433985672	4184	Business	21500.00
0005433985685	4184	Business	21500.00
0005433985659	4184	Business	21500.00
0005433985654	4184	Business	21500.00
0005433985683	4184	Business	21500.00
0005433985665	4184	Economy	7200.00
0005433985682	4184	Economy	7200.00
0005433985666	4184	Economy	7200.00
0005433985671	4184	Economy	7200.00
0005433985656	4184	Economy	7200.00
0005433985680	4184	Economy	7200.00
0005433985677	4184	Economy	7900.00
0005433985678	4184	Economy	7900.00
0005433985658	4184	Economy	7200.00
0005433985664	4184	Economy	7200.00
0005433985670	4184	Economy	7200.00
0005433985650	4184	Economy	7200.00
0005433985688	4184	Economy	7200.00
0005433985662	4184	Economy	7200.00
0005435788756	4184	Economy	7200.00
0005433985679	4184	Economy	7200.00
0005433985651	4184	Economy	7200.00
0005435788755	4184	Economy	7200.00
0005433985660	4184	Economy	7200.00
0005433985657	4184	Economy	7200.00
0005433985673	4184	Economy	7200.00
0005433985687	4184	Economy	7200.00
0005433985663	4184	Economy	7200.00
0005433985649	4184	Economy	7200.00
0005433985676	4184	Economy	7200.00
0005433985653	4184	Economy	7200.00
0005433985686	4184	Economy	7200.00
0005433985675	4184	Economy	7200.00
0005433985669	4184	Economy	7200.00
0005433985674	4184	Economy	7200.00
0005433985648	4184	Economy	7200.00
0005433985684	4184	Economy	7200.00
0005433985668	4184	Economy	7200.00
0005435788754	4184	Economy	7200.00
0005433985655	4184	Economy	7200.00
0005435788757	4184	Economy	7200.00
0005433985681	4184	Economy	7200.00
0005433985667	4184	Economy	7200.00
0005433985661	4184	Economy	7200.00
0005433985242	25693	Business	21500.00
0005433985180	25693	Business	21500.00
0005433985152	25693	Economy	7200.00
0005433985212	25693	Economy	7200.00
0005433985249	25693	Economy	7200.00
0005433985232	25693	Economy	7200.00
0005433985250	25693	Economy	7900.00
0005433985122	25693	Economy	7200.00
0005433985123	25693	Economy	7200.00
0005433985151	25693	Economy	7200.00
0005433985223	25693	Economy	7200.00
0005433985161	25693	Economy	7200.00
0005433985154	25693	Economy	7200.00
0005433985186	25693	Economy	7200.00
0005433985253	25693	Economy	7200.00
0005433985244	25693	Economy	7200.00
0005433985209	25693	Economy	7200.00
0005433985185	25693	Economy	7200.00
0005433985222	25693	Economy	7200.00
0005433985132	25693	Economy	7200.00
0005433985191	25693	Economy	7200.00
0005433985155	25693	Economy	7200.00
0005433985231	25693	Economy	7200.00
0005433985146	25693	Economy	7200.00
0005433985145	25693	Economy	7200.00
0005433985241	25693	Economy	7200.00
0005433985187	25693	Economy	7200.00
0005433985234	25693	Economy	7200.00
0005433985131	25693	Economy	7200.00
0005433985176	25693	Economy	7200.00
0005433463863	19918	Business	201300.00
0005433463861	19918	Economy	67100.00
0005433461563	19918	Economy	67100.00
0005433463862	19918	Economy	67100.00
0005433461564	19918	Economy	67100.00
0005435719561	24757	Economy	9400.00
0005435719562	24757	Economy	9400.00
0005435720128	24757	Economy	9400.00
0005434509095	1616	Economy	17000.00
0005434509107	1616	Economy	15500.00
0005433168304	1616	Economy	15500.00
0005433168322	1616	Economy	15500.00
0005434509105	1616	Economy	15500.00
0005434509106	1616	Economy	15500.00
0005433168302	1616	Economy	15500.00
0005434509099	1616	Economy	15500.00
0005433168305	1616	Economy	15500.00
0005434509100	1616	Economy	15500.00
0005434509102	1616	Economy	15500.00
0005434509087	1616	Economy	15500.00
0005434509103	1616	Economy	15500.00
0005433168306	1616	Economy	15500.00
0005434509094	1616	Economy	15500.00
0005434509089	1616	Economy	15500.00
0005434509085	1616	Economy	15500.00
0005433168311	1616	Economy	15500.00
0005434509088	1616	Economy	15500.00
0005434509104	1616	Economy	15500.00
0005433168309	1616	Economy	15500.00
0005434509091	1616	Economy	15500.00
0005434509086	1616	Economy	15500.00
0005434509098	1616	Economy	15500.00
0005433168308	1616	Economy	15500.00
0005433168315	1616	Economy	15500.00
0005434509097	1616	Economy	15500.00
0005433168321	1616	Economy	15500.00
0005434509093	1616	Economy	15500.00
0005434509096	1616	Economy	15500.00
0005434509090	1616	Economy	15500.00
0005434509092	1616	Economy	15500.00
0005434509101	1616	Economy	15500.00
0005432658567	17836	Business	18000.00
0005432869491	17836	Business	18000.00
0005432655392	17836	Business	18000.00
0005432655365	17836	Economy	6000.00
0005432869486	17836	Economy	6000.00
0005432655344	17836	Economy	6000.00
0005432667421	17836	Economy	6000.00
0005432665249	17836	Economy	6000.00
0005432869490	17836	Economy	6000.00
0005432667418	17836	Economy	6000.00
0005432655345	17836	Economy	6000.00
0005432655350	17836	Economy	6000.00
0005432655342	17836	Economy	6000.00
0005432869489	17836	Economy	6000.00
0005432869487	17836	Economy	6000.00
0005432659671	17836	Economy	6000.00
0005432869488	17836	Economy	6000.00
0005432655376	17836	Economy	6000.00
0005434151689	17836	Economy	6000.00
0005432655375	17836	Economy	6000.00
0005432667422	17836	Economy	6000.00
0005434151669	26326	Business	18000.00
0005432665260	26326	Business	18000.00
0005432657428	26326	Business	18000.00
0005432655443	26326	Business	18000.00
0005432665258	26326	Business	18000.00
0005432664121	26326	Business	18000.00
0005432661907	26326	Business	18000.00
0005432657426	26326	Business	18000.00
0005432869420	26326	Business	18000.00
0005432663021	26326	Business	18000.00
0005432661898	26326	Business	18000.00
0005432664117	26326	Business	18000.00
0005432666374	26326	Economy	6000.00
0005432661909	26326	Economy	6000.00
0005434151662	26326	Economy	6000.00
0005432664115	26326	Economy	6000.00
0005432663015	26326	Economy	6000.00
0005432658577	26326	Economy	6000.00
0005432655438	26326	Economy	6000.00
0005432667439	26326	Economy	6000.00
0005432664126	26326	Economy	6000.00
0005432661905	26326	Economy	6600.00
0005432664114	26326	Economy	6600.00
0005432663016	26326	Economy	6600.00
0005432661912	26326	Economy	6000.00
0005432661906	26326	Economy	6000.00
0005432655442	26326	Economy	6000.00
0005432663013	26326	Economy	6000.00
0005432660802	26326	Economy	6000.00
0005432665259	26326	Economy	6000.00
0005432658576	26326	Economy	6000.00
0005432661904	26326	Economy	6000.00
0005432661900	26326	Economy	6000.00
0005432663020	26326	Economy	6000.00
0005432655448	26326	Economy	6000.00
0005432664123	26326	Economy	6000.00
0005432655446	26326	Economy	6000.00
0005432659690	26326	Economy	6000.00
0005432655437	26326	Economy	6000.00
0005432663019	26326	Economy	6000.00
0005432664118	26326	Economy	6000.00
0005432663012	26326	Economy	6000.00
0005432660803	26326	Economy	6000.00
0005432664127	26326	Economy	6000.00
0005432655447	26326	Economy	6000.00
0005432661899	26326	Economy	6000.00
0005432664124	26326	Economy	6000.00
0005432655440	26326	Economy	6000.00
0005432663018	26326	Economy	6000.00
0005432659691	26326	Economy	6000.00
0005432664116	26326	Economy	6000.00
0005432661908	26326	Economy	6000.00
0005432664122	26326	Economy	6000.00
0005432657427	26326	Economy	6000.00
0005432664120	26326	Economy	6000.00
0005432661903	26326	Economy	6000.00
0005432663024	26326	Economy	6000.00
0005432663026	26326	Economy	6000.00
0005432664125	26326	Economy	6000.00
0005432666373	26326	Economy	6000.00
0005432661910	26326	Economy	6000.00
0005432661901	26326	Economy	6000.00
0005432661911	26326	Economy	6000.00
0005434151668	26326	Economy	6000.00
0005432655436	26326	Economy	6000.00
0005432663023	26326	Economy	6000.00
0005432655444	26326	Economy	6000.00
0005432664113	26326	Economy	6000.00
0005432664119	26326	Economy	6000.00
0005432655441	26326	Economy	6000.00
0005432655439	26326	Economy	6000.00
0005432661902	26326	Economy	6000.00
0005432869419	26326	Economy	6000.00
0005432655445	26326	Economy	6000.00
0005432663017	26326	Economy	6000.00
0005432663022	26326	Economy	6000.00
0005432663025	26326	Economy	6000.00
0005432663014	26326	Economy	6000.00
0005432638969	25059	Business	87300.00
0005432865973	25059	Business	87300.00
0005432638947	25059	Business	87300.00
0005432865970	25059	Business	87300.00
0005432638920	25059	Business	87300.00
0005432865979	25059	Business	87300.00
0005432865977	25059	Business	87300.00
0005432865974	25059	Business	87300.00
0005432638915	25059	Economy	29100.00
0005432865962	25059	Economy	29100.00
0005432865961	25059	Economy	29100.00
0005432865975	25059	Economy	32000.00
0005432865972	25059	Economy	32000.00
0005432865968	25059	Economy	32000.00
0005432638948	25059	Economy	29100.00
0005432638940	25059	Economy	29100.00
0005432865978	25059	Economy	29100.00
0005432865980	25059	Economy	29100.00
0005432638973	25059	Economy	29100.00
0005432865971	25059	Economy	29100.00
0005432638951	25059	Economy	29100.00
0005432638998	25059	Economy	29100.00
0005432865967	25059	Economy	29100.00
0005432638971	25059	Economy	29100.00
0005432638997	25059	Economy	29100.00
0005432638978	25059	Economy	29100.00
0005432865969	25059	Economy	29100.00
0005432638939	25059	Economy	29100.00
0005432638928	25059	Economy	29100.00
0005432638962	25059	Economy	29100.00
0005432638926	25059	Economy	29100.00
0005432865964	25059	Economy	29100.00
0005432638963	25059	Economy	29100.00
0005432638927	25059	Economy	29100.00
0005432865959	25059	Economy	29100.00
0005432638974	25059	Economy	29100.00
0005432865965	25059	Economy	29100.00
0005432638950	25059	Economy	29100.00
0005432638976	25059	Economy	29100.00
0005432865960	25059	Economy	29100.00
0005432865958	25059	Economy	29100.00
0005432638933	25059	Economy	29100.00
0005432865963	25059	Economy	29100.00
0005432638919	25059	Economy	29100.00
0005432865966	25059	Economy	29100.00
0005432639000	25059	Economy	29100.00
0005432638975	25059	Economy	29100.00
0005432865976	25059	Economy	29100.00
0005432638977	25059	Economy	29100.00
0005432638952	25059	Economy	29100.00
0005432328417	3085	Business	16100.00
0005432328422	3085	Business	16100.00
0005432328408	3085	Business	16100.00
0005432287159	3085	Business	16100.00
0005432328410	3085	Business	16100.00
0005432905050	3085	Business	16100.00
0005432328442	3085	Business	16100.00
0005432905020	3085	Business	16100.00
0005432905058	3085	Business	16100.00
0005432328416	3085	Economy	5400.00
0005432328431	3085	Economy	5400.00
0005432287161	3085	Economy	5400.00
0005432328433	3085	Economy	5400.00
0005432905046	3085	Economy	5900.00
0005432287158	3085	Economy	5900.00
0005432328412	3085	Economy	5900.00
0005432328432	3085	Economy	5900.00
0005432905074	3085	Economy	5400.00
0005432328444	3085	Economy	5400.00
0005432905019	3085	Economy	5400.00
0005432328440	3085	Economy	5400.00
0005433438838	3085	Economy	5400.00
0005432328436	3085	Economy	5400.00
0005432905054	3085	Economy	5400.00
0005432905047	3085	Economy	5400.00
0005432328448	3085	Economy	5400.00
0005433438839	3085	Economy	5400.00
0005432328407	3085	Economy	5400.00
0005432328452	3085	Economy	5400.00
0005432905059	3085	Economy	5400.00
0005432328429	3085	Economy	5400.00
0005432287160	3085	Economy	5400.00
0005432328445	3085	Economy	5400.00
0005432328446	3085	Economy	5400.00
0005432328430	3085	Economy	5400.00
0005432328411	3085	Economy	5400.00
0005432905051	3085	Economy	5400.00
0005432328409	3085	Economy	5400.00
0005432328438	3085	Economy	5400.00
0005432328435	3085	Economy	5400.00
0005432328415	3085	Economy	5400.00
0005432328439	3085	Economy	5400.00
0005432328450	3085	Economy	5400.00
0005433438840	3085	Economy	5400.00
0005432328425	3085	Economy	5400.00
0005432328424	3085	Economy	5400.00
0005432328428	3085	Economy	5400.00
0005432328413	3085	Economy	5400.00
0005432328437	3085	Economy	5400.00
0005432328447	3085	Economy	5400.00
0005432328453	3085	Economy	5400.00
0005432328423	3085	Economy	5400.00
0005432328426	3085	Economy	5400.00
0005432328451	3085	Economy	5400.00
0005432328421	3085	Economy	5400.00
0005432328419	3085	Economy	5400.00
0005432328449	3085	Economy	5400.00
0005432328427	3085	Economy	5400.00
0005432328414	3085	Economy	5400.00
0005432328420	3085	Economy	5400.00
0005432328434	3085	Economy	5400.00
0005432328418	3085	Economy	5400.00
0005432328443	3085	Economy	5400.00
0005432328441	3085	Economy	5400.00
0005432328081	31130	Business	16100.00
0005432327923	31130	Business	16100.00
0005432327966	31130	Business	16100.00
0005432328258	31130	Business	16100.00
0005433438798	31130	Business	16100.00
0005432328083	31130	Business	16100.00
0005432905095	31130	Business	16100.00
0005432327918	31130	Business	16100.00
0005432328129	31130	Business	16100.00
0005432905091	31130	Economy	5400.00
0005432327956	31130	Economy	5400.00
0005432327967	31130	Economy	5400.00
0005432328086	31130	Economy	5900.00
0005433438763	31130	Economy	5900.00
0005432327899	31130	Economy	5900.00
0005432328021	31130	Economy	5400.00
0005432327957	31130	Economy	5400.00
0005432327924	31130	Economy	5400.00
0005432328020	31130	Economy	5400.00
0005432848837	31130	Economy	5400.00
0005432327999	31130	Economy	5400.00
0005432328084	31130	Economy	5400.00
0005432328155	31130	Economy	5400.00
0005432328071	31130	Economy	5400.00
0005432327917	31130	Economy	5400.00
0005432327900	31130	Economy	5400.00
0005432327951	31130	Economy	5400.00
0005432328111	31130	Economy	5400.00
0005432905096	31130	Economy	5400.00
0005432327890	31130	Economy	5400.00
0005433438785	31130	Economy	5400.00
0005432327958	31130	Economy	5400.00
0005432328000	31130	Economy	5400.00
0005432327971	31130	Economy	5400.00
0005432327952	31130	Economy	5400.00
0005433438768	31130	Economy	5400.00
0005432054286	31130	Economy	5400.00
0005432905093	31130	Economy	5400.00
0005432328023	31130	Economy	5400.00
0005432327977	31130	Economy	5400.00
0005432328035	31130	Economy	5400.00
0005432054287	31130	Economy	5400.00
0005432328077	31130	Economy	5400.00
0005432905092	31130	Economy	5400.00
0005432327959	31130	Economy	5400.00
0005432328022	31130	Economy	5400.00
0005432328156	31130	Economy	5400.00
0005432328169	31130	Economy	5400.00
0005432327978	31130	Economy	5400.00
0005432328143	31130	Economy	5400.00
0005432327991	31130	Economy	5400.00
0005432327979	31130	Economy	5400.00
0005432328103	31130	Economy	5400.00
0005432905094	31130	Economy	5400.00
0005433438786	31130	Economy	5400.00
0005432328104	31130	Economy	5400.00
0005435999153	6230	Business	124600.00
0005435487515	6230	Business	124600.00
0005435999167	6230	Business	124600.00
0005435999156	6230	Business	124600.00
0005434309660	6230	Business	124600.00
0005432146187	6230	Business	124600.00
0005435999144	6230	Economy	41500.00
0005434309665	6230	Economy	41500.00
0005435296959	6230	Economy	41500.00
0005435999171	6230	Economy	41500.00
0005435999152	6230	Economy	41500.00
0005434309658	6230	Economy	41500.00
0005435999160	6230	Economy	41500.00
0005435487532	6230	Economy	41500.00
0005435999147	6230	Economy	41500.00
0005435999154	6230	Economy	41500.00
0005432146186	6230	Economy	41500.00
0005435999166	6230	Economy	41500.00
0005434309656	6230	Economy	41500.00
0005435999172	6230	Economy	41500.00
0005435999149	6230	Economy	41500.00
0005434309668	6230	Economy	41500.00
0005434309655	6230	Economy	41500.00
0005434309663	6230	Economy	45700.00
0005435999151	6230	Economy	45700.00
0005434309666	6230	Economy	45700.00
0005434309657	6230	Economy	45700.00
0005435296940	6230	Economy	41500.00
0005435487511	6230	Economy	41500.00
0005435999165	6230	Economy	41500.00
0005435296939	6230	Economy	41500.00
0005435487542	6230	Economy	41500.00
0005435487541	6230	Economy	41500.00
0005434309661	6230	Economy	41500.00
0005435999162	6230	Economy	41500.00
0005435999164	6230	Economy	41500.00
0005434309664	6230	Economy	41500.00
0005435999157	6230	Economy	41500.00
0005435999168	6230	Economy	41500.00
0005435999150	6230	Economy	41500.00
0005435999163	6230	Economy	41500.00
0005434309662	6230	Economy	41500.00
0005435999170	6230	Economy	41500.00
0005435999145	6230	Economy	41500.00
0005434309659	6230	Economy	41500.00
0005435999146	6230	Economy	41500.00
0005435999159	6230	Economy	41500.00
0005434309667	6230	Economy	41500.00
0005435999155	6230	Economy	41500.00
0005435487506	6230	Economy	41500.00
0005435296944	6230	Economy	41500.00
0005435487507	6230	Economy	41500.00
0005435999169	6230	Economy	41500.00
0005434309669	6230	Economy	41500.00
0005435999161	6230	Economy	41500.00
0005435999158	6230	Economy	41500.00
0005435999148	6230	Economy	41500.00
0005435487693	19535	Business	124600.00
0005435297017	19535	Business	124600.00
0005435297019	19535	Economy	41500.00
0005435998996	19535	Economy	41500.00
0005435998965	19535	Economy	41500.00
0005434309551	19535	Economy	41500.00
0005435487681	19535	Economy	41500.00
0005435487687	19535	Economy	41500.00
0005435487689	19535	Economy	41500.00
0005435487684	19535	Economy	41500.00
0005435487686	19535	Economy	41500.00
0005435998961	19535	Economy	41500.00
0005435487688	19535	Economy	41500.00
0005435487685	19535	Economy	41500.00
0005435297020	19535	Economy	41500.00
0005435297022	19535	Economy	41500.00
0005435998991	19535	Economy	41500.00
0005435998979	19535	Economy	41500.00
0005435487694	19535	Economy	45700.00
0005435297021	19535	Economy	41500.00
0005435487683	19535	Economy	41500.00
0005435297018	19535	Economy	41500.00
0005435487680	19535	Economy	41500.00
0005435998952	19535	Economy	41500.00
0005435487691	19535	Economy	41500.00
0005435998951	19535	Economy	41500.00
0005435487695	19535	Economy	41500.00
0005434309536	19535	Economy	41500.00
0005435998995	19535	Economy	41500.00
0005435487682	19535	Economy	41500.00
0005435487692	19535	Economy	41500.00
0005434309550	19535	Economy	41500.00
0005434309552	19535	Economy	41500.00
0005435487690	19535	Economy	41500.00
0005435487679	19535	Economy	41500.00
0005435998983	19535	Economy	41500.00
0005435998953	19535	Economy	41500.00
0005435487676	19535	Economy	41500.00
0005435487696	19535	Economy	41500.00
0005434309537	19535	Economy	41500.00
0005435487677	19535	Economy	41500.00
0005435487678	19535	Economy	41500.00
0005433158118	17546	Economy	13600.00
0005434446478	17546	Economy	12300.00
0005434446492	17546	Economy	12300.00
0005434446493	17546	Economy	12300.00
0005434446479	17546	Economy	12300.00
0005434446477	17546	Economy	12300.00
0005433158116	17546	Economy	12300.00
0005434446489	17546	Economy	12300.00
0005434446494	17546	Economy	12300.00
0005434446476	17546	Economy	12300.00
0005434446480	17546	Economy	12300.00
0005434446484	17546	Economy	12300.00
0005434446481	17546	Economy	12300.00
0005433158119	17546	Economy	12300.00
0005433158117	17546	Economy	12300.00
0005435502193	1593	Business	86000.00
0005435508295	1593	Business	86000.00
0005435508288	1593	Business	86000.00
0005434565831	1593	Business	86000.00
0005435502186	1593	Business	86000.00
0005434565835	1593	Business	86000.00
0005435517817	1593	Business	86000.00
0005435517803	1593	Business	86000.00
0005434565829	1593	Business	86000.00
0005435517807	1593	Business	86000.00
0005435502176	1593	Economy	28700.00
0005433185998	1593	Economy	28700.00
0005433186014	1593	Economy	28700.00
0005435502195	1593	Economy	28700.00
0005435508296	1593	Economy	28700.00
0005435517806	1593	Economy	28700.00
0005435517816	1593	Economy	28700.00
0005433186008	1593	Economy	31500.00
0005435517813	1593	Economy	31500.00
0005435502179	1593	Economy	31500.00
0005433186012	1593	Economy	31500.00
0005435502180	1593	Economy	28700.00
0005435517811	1593	Economy	28700.00
0005435502178	1593	Economy	28700.00
0005435508287	1593	Economy	28700.00
0005435502184	1593	Economy	28700.00
0005433186000	1593	Economy	28700.00
0005432291916	1593	Economy	28700.00
0005433186013	1593	Economy	28700.00
0005434565839	1593	Economy	28700.00
0005435517805	1593	Economy	28700.00
0005435517804	1593	Economy	28700.00
0005434565836	1593	Economy	28700.00
0005434565841	1593	Economy	28700.00
0005435502191	1593	Economy	28700.00
0005435502185	1593	Economy	28700.00
0005435508293	1593	Economy	28700.00
0005433185999	1593	Economy	28700.00
0005435502196	1593	Economy	28700.00
0005435517809	1593	Economy	28700.00
0005435502181	1593	Economy	28700.00
0005435502182	1593	Economy	28700.00
0005434565834	1593	Economy	28700.00
0005435502190	1593	Economy	28700.00
0005435508294	1593	Economy	28700.00
0005435502177	1593	Economy	28700.00
0005435517802	1593	Economy	28700.00
0005435517812	1593	Economy	28700.00
0005432291915	1593	Economy	28700.00
0005434565838	1593	Economy	28700.00
0005435517814	1593	Economy	28700.00
0005435508291	1593	Economy	28700.00
0005434565842	1593	Economy	28700.00
0005435508286	1593	Economy	28700.00
0005434565833	1593	Economy	28700.00
0005435517800	1593	Economy	28700.00
0005435517801	1593	Economy	28700.00
0005435502175	1593	Economy	28700.00
0005435502192	1593	Economy	28700.00
0005433185992	1593	Economy	28700.00
0005435517810	1593	Economy	28700.00
0005435508290	1593	Economy	28700.00
0005435508292	1593	Economy	28700.00
0005435502188	1593	Economy	28700.00
0005435517815	1593	Economy	28700.00
0005434565832	1593	Economy	28700.00
0005435502183	1593	Economy	28700.00
0005434565830	1593	Economy	28700.00
0005435502189	1593	Economy	28700.00
0005435517808	1593	Economy	28700.00
0005435502194	1593	Economy	28700.00
0005435502187	1593	Economy	28700.00
0005433186010	1593	Economy	28700.00
0005435508289	1593	Economy	28700.00
0005434565840	1593	Economy	28700.00
0005434565837	1593	Economy	28700.00
0005434565731	20853	Business	86000.00
0005433186072	20853	Business	86000.00
0005435528944	20853	Business	86000.00
0005435528922	20853	Business	86000.00
0005435502048	20853	Business	86000.00
0005435528916	20853	Economy	28700.00
0005434565701	20853	Economy	28700.00
0005435528902	20853	Economy	28700.00
0005434565758	20853	Economy	28700.00
0005433186071	20853	Economy	28700.00
0005434565700	20853	Economy	28700.00
0005434565705	20853	Economy	28700.00
0005434565757	20853	Economy	28700.00
0005433186066	20853	Economy	31500.00
0005435528888	20853	Economy	31500.00
0005434565760	20853	Economy	31500.00
0005435502047	20853	Economy	31500.00
0005435501956	20853	Economy	28700.00
0005435501955	20853	Economy	28700.00
0005435528946	20853	Economy	28700.00
0005435502049	20853	Economy	28700.00
0005435528915	20853	Economy	28700.00
0005434565694	20853	Economy	28700.00
0005435502019	20853	Economy	28700.00
0005435528950	20853	Economy	28700.00
0005434565704	20853	Economy	28700.00
0005433186065	20853	Economy	28700.00
0005435528914	20853	Economy	28700.00
0005435528964	20853	Economy	28700.00
0005433186067	20853	Economy	28700.00
0005434565799	20853	Economy	28700.00
0005434565750	20853	Economy	28700.00
0005435528934	20853	Economy	28700.00
0005435528945	20853	Economy	28700.00
0005434565755	20853	Economy	28700.00
0005434565728	20853	Economy	28700.00
0005435545635	20853	Economy	28700.00
0005435502020	20853	Economy	28700.00
0005434565702	20853	Economy	28700.00
0005434565732	20853	Economy	28700.00
0005435501979	20853	Economy	28700.00
0005434565751	20853	Economy	28700.00
0005433186070	20853	Economy	28700.00
0005435501957	20853	Economy	28700.00
0005434565730	20853	Economy	28700.00
0005435528999	20853	Economy	28700.00
0005434565745	20853	Economy	28700.00
0005435545634	20853	Economy	28700.00
0005433186068	20853	Economy	28700.00
0005433186069	20853	Economy	28700.00
0005435502000	20853	Economy	28700.00
0005434565733	20853	Economy	28700.00
0005435545621	20853	Economy	28700.00
0005434565682	20853	Economy	28700.00
0005435931539	3880	Economy	19700.00
0005435931560	3880	Economy	19700.00
0005435931545	3880	Economy	19700.00
0005435153702	3880	Economy	19700.00
0005435153703	3880	Economy	19700.00
0005435931546	3880	Economy	19700.00
0005435931540	3880	Economy	19700.00
0005435153706	3880	Economy	19700.00
0005435931555	3880	Economy	19700.00
0005435153701	3880	Economy	19700.00
0005435153705	3880	Economy	19700.00
0005435153704	3880	Economy	19700.00
0005435153666	21859	Economy	21600.00
0005435931580	21859	Economy	19700.00
0005435931578	21859	Economy	19700.00
0005435931582	21859	Economy	19700.00
0005435153648	21859	Economy	19700.00
0005435931581	21859	Economy	19700.00
0005435931579	21859	Economy	19700.00
0005435153659	21859	Economy	19700.00
0005435153632	21859	Economy	19700.00
0005435153633	21859	Economy	19700.00
0005435153658	21859	Economy	19700.00
0005432628756	7178	Economy	14300.00
0005432628759	7178	Economy	14300.00
0005435225473	7178	Economy	14300.00
0005432628760	7178	Economy	13000.00
0005432628763	7178	Economy	13000.00
0005435225467	7178	Economy	13000.00
0005432628753	7178	Economy	13000.00
0005435225490	7178	Economy	13000.00
0005435225453	7178	Economy	13000.00
0005435225468	7178	Economy	13000.00
0005432628755	7178	Economy	13000.00
0005435225476	7178	Economy	13000.00
0005432628765	7178	Economy	13000.00
0005432628758	7178	Economy	13000.00
0005435225452	7178	Economy	13000.00
0005432628757	7178	Economy	13000.00
0005432628752	7178	Economy	13000.00
0005432628761	7178	Economy	13000.00
0005432628766	7178	Economy	13000.00
0005432628762	7178	Economy	13000.00
0005435225475	7178	Economy	13000.00
0005432628764	7178	Economy	13000.00
0005435225474	7178	Economy	13000.00
0005432628754	7178	Economy	13000.00
0005432628670	28111	Economy	14300.00
0005432628682	28111	Economy	13000.00
0005432628644	28111	Economy	13000.00
0005435225538	28111	Economy	13000.00
0005432628673	28111	Economy	13000.00
0005432628620	28111	Economy	13000.00
0005432628639	28111	Economy	13000.00
0005435225537	28111	Economy	13000.00
0005435225535	28111	Economy	13000.00
0005435225540	28111	Economy	13000.00
0005432628654	28111	Economy	13000.00
0005432628674	28111	Economy	13000.00
0005432628672	28111	Economy	13000.00
0005435225536	28111	Economy	13000.00
0005435225539	28111	Economy	13000.00
0005432628660	28111	Economy	13000.00
0005435960029	8766	Economy	11500.00
0005435960030	8766	Economy	10500.00
0005435960028	8766	Economy	10500.00
0005435960027	8766	Economy	10500.00
0005435960026	8766	Economy	10500.00
0005434267892	8766	Economy	10500.00
0005434267899	8766	Economy	10500.00
0005434267889	8766	Economy	10500.00
0005434267926	15258	Economy	11500.00
0005434267927	15258	Economy	10500.00
0005434267928	15258	Economy	10500.00
0005435960001	15258	Economy	10500.00
0005434267925	15258	Economy	10500.00
0005435959984	15258	Economy	10500.00
0005435959985	15258	Economy	10500.00
0005434267929	15258	Economy	10500.00
0005432692855	1171	Business	115000.00
0005432677546	1171	Business	115000.00
0005432873208	1171	Business	115000.00
0005432675046	1171	Business	115000.00
0005432675048	1171	Business	115000.00
0005432873177	1171	Business	115000.00
0005432692864	1171	Business	115000.00
0005432692846	1171	Business	115000.00
0005432675040	1171	Business	115000.00
0005432692850	1171	Business	115000.00
0005432692867	1171	Business	115000.00
0005432675043	1171	Business	115000.00
0005432692854	1171	Economy	38300.00
0005432692853	1171	Economy	38300.00
0005432692873	1171	Economy	38300.00
0005432692872	1171	Economy	38300.00
0005432873178	1171	Economy	38300.00
0005432692851	1171	Economy	38300.00
0005432675044	1171	Economy	42200.00
0005432675047	1171	Economy	38300.00
0005432675045	1171	Economy	38300.00
0005432677547	1171	Economy	38300.00
0005432675038	1171	Economy	38300.00
0005432692869	1171	Economy	38300.00
0005432692860	1171	Economy	38300.00
0005432675039	1171	Economy	38300.00
0005432692857	1171	Economy	38300.00
0005432692862	1171	Economy	38300.00
0005432675041	1171	Economy	38300.00
0005432873207	1171	Economy	38300.00
0005432692852	1171	Economy	38300.00
0005432692866	1171	Economy	38300.00
0005432692868	1171	Economy	38300.00
0005432675034	1171	Economy	38300.00
0005432675033	1171	Economy	38300.00
0005432675036	1171	Economy	38300.00
0005432692861	1171	Economy	38300.00
0005432675042	1171	Economy	38300.00
0005432873183	1171	Economy	38300.00
0005432692870	1171	Economy	38300.00
0005432675035	1171	Economy	38300.00
0005432873199	1171	Economy	38300.00
0005432675037	1171	Economy	38300.00
0005432692848	1171	Economy	38300.00
0005432692858	1171	Economy	38300.00
0005432692847	1171	Economy	38300.00
0005432692865	1171	Economy	38300.00
0005432692844	1171	Economy	38300.00
0005432677545	1171	Economy	38300.00
0005432873186	1171	Economy	38300.00
0005432677544	1171	Economy	38300.00
0005432692843	1171	Economy	38300.00
0005432692859	1171	Economy	38300.00
0005432692856	1171	Economy	38300.00
0005432692863	1171	Economy	38300.00
0005432692845	1171	Economy	38300.00
0005432692849	1171	Economy	38300.00
0005432692871	1171	Economy	38300.00
0005432692590	17487	Business	115000.00
0005432692633	17487	Business	115000.00
0005432873248	17487	Business	115000.00
0005432692608	17487	Business	115000.00
0005432692558	17487	Business	115000.00
0005432692647	17487	Business	115000.00
0005432692666	17487	Business	115000.00
0005432674946	17487	Business	115000.00
0005432674876	17487	Economy	38300.00
0005432873250	17487	Economy	38300.00
0005432873247	17487	Economy	38300.00
0005432873246	17487	Economy	38300.00
0005432692675	17487	Economy	38300.00
0005432692639	17487	Economy	42200.00
0005432674901	17487	Economy	42200.00
0005432873252	17487	Economy	42200.00
0005432692534	17487	Economy	38300.00
0005432674928	17487	Economy	38300.00
0005432692638	17487	Economy	38300.00
0005432677512	17487	Economy	38300.00
0005432692627	17487	Economy	38300.00
0005432692631	17487	Economy	38300.00
0005432674877	17487	Economy	38300.00
0005432692537	17487	Economy	38300.00
0005432677511	17487	Economy	38300.00
0005432692603	17487	Economy	38300.00
0005432674945	17487	Economy	38300.00
0005432692569	17487	Economy	38300.00
0005432674966	17487	Economy	38300.00
0005432692645	17487	Economy	38300.00
0005432692568	17487	Economy	38300.00
0005432692557	17487	Economy	38300.00
0005432674923	17487	Economy	38300.00
0005432674919	17487	Economy	38300.00
0005432674879	17487	Economy	38300.00
0005432674880	17487	Economy	38300.00
0005432674902	17487	Economy	38300.00
0005432692582	17487	Economy	38300.00
0005432674878	17487	Economy	38300.00
0005432873251	17487	Economy	38300.00
0005432873249	17487	Economy	38300.00
0005432692674	17487	Economy	38300.00
0005432692682	17487	Economy	38300.00
0005432692683	17487	Economy	38300.00
0005432674915	17487	Economy	38300.00
0005432692648	17487	Economy	38300.00
0005432674967	17487	Economy	38300.00
0005432674918	17487	Economy	38300.00
0005432692571	17487	Economy	38300.00
0005432674916	17487	Economy	38300.00
0005432692646	17487	Economy	38300.00
0005434435087	1105	Economy	15200.00
0005433156665	1105	Economy	13900.00
0005434435086	1105	Economy	13900.00
0005434435098	1105	Economy	13900.00
0005434435096	1105	Economy	13900.00
0005434435094	1105	Economy	13900.00
0005433156620	1105	Economy	13900.00
0005433156633	1105	Economy	13900.00
0005433156658	1105	Economy	13900.00
0005433156625	1105	Economy	13900.00
0005434435092	1105	Economy	13900.00
0005434435083	1105	Economy	13900.00
0005434435091	1105	Economy	13900.00
0005434435089	1105	Economy	13900.00
0005433156628	1105	Economy	13900.00
0005433156627	1105	Economy	13900.00
0005433156634	1105	Economy	13900.00
0005434435093	1105	Economy	13900.00
0005434435095	1105	Economy	13900.00
0005433156666	1105	Economy	13900.00
0005434435082	1105	Economy	13900.00
0005434435084	1105	Economy	13900.00
0005434435097	1105	Economy	13900.00
0005434435088	1105	Economy	13900.00
0005434435085	1105	Economy	13900.00
0005434435090	1105	Economy	13900.00
0005433156693	17290	Economy	15200.00
0005433156700	17290	Economy	15200.00
0005433156701	17290	Economy	15200.00
0005433156697	17290	Economy	13900.00
0005434434994	17290	Economy	13900.00
0005434434912	17290	Economy	13900.00
0005433156699	17290	Economy	13900.00
0005434434997	17290	Economy	13900.00
0005434434998	17290	Economy	13900.00
0005433156696	17290	Economy	13900.00
0005434434946	17290	Economy	13900.00
0005434434943	17290	Economy	13900.00
0005434434954	17290	Economy	13900.00
0005433156694	17290	Economy	13900.00
0005434434955	17290	Economy	13900.00
0005434435015	17290	Economy	13900.00
0005434435024	17290	Economy	13900.00
0005434435026	17290	Economy	13900.00
0005434434918	17290	Economy	13900.00
0005434435023	17290	Economy	13900.00
0005433156698	17290	Economy	13900.00
0005433156695	17290	Economy	13900.00
0005435928088	4088	Economy	8200.00
0005435928070	4088	Economy	7500.00
0005435086791	4088	Economy	7500.00
0005435086786	4088	Economy	7500.00
0005435086793	4088	Economy	7500.00
0005435928057	4088	Economy	7500.00
0005435928065	4088	Economy	7500.00
0005435086792	4088	Economy	7500.00
0005435086785	4088	Economy	7500.00
0005435928058	4088	Economy	7500.00
0005435928064	4088	Economy	7500.00
0005435928066	4088	Economy	7500.00
0005435086788	4088	Economy	7500.00
0005435086789	4088	Economy	7500.00
0005435928059	4088	Economy	7500.00
0005435928067	4088	Economy	7500.00
0005435086790	4088	Economy	7500.00
0005435928068	4088	Economy	7500.00
0005435928087	4088	Economy	7500.00
0005435086787	4088	Economy	7500.00
0005435086744	24388	Economy	7500.00
0005435086722	24388	Economy	7500.00
0005435086706	24388	Economy	7500.00
0005435086742	24388	Economy	7500.00
0005435086701	24388	Economy	7500.00
0005435928116	24388	Economy	7500.00
0005435928114	24388	Economy	7500.00
0005435086725	24388	Economy	7500.00
0005435928113	24388	Economy	7500.00
0005435928115	24388	Economy	7500.00
0005435928111	24388	Economy	7500.00
0005435086743	24388	Economy	7500.00
0005435086723	24388	Economy	7500.00
0005435928112	24388	Economy	7500.00
0005435706293	2445	Business	86800.00
0005435706268	2445	Business	86800.00
0005435706278	2445	Business	86800.00
0005435706264	2445	Business	86800.00
0005435706276	2445	Business	86800.00
0005435706287	2445	Business	86800.00
0005435706282	2445	Economy	28900.00
0005433373391	2445	Economy	28900.00
0005435706294	2445	Economy	28900.00
0005435706295	2445	Economy	28900.00
0005433373381	2445	Economy	28900.00
0005435706279	2445	Economy	28900.00
0005435706263	2445	Economy	31800.00
0005435706280	2445	Economy	31800.00
0005435706271	2445	Economy	31800.00
0005435706266	2445	Economy	28900.00
0005435706277	2445	Economy	28900.00
0005435706275	2445	Economy	28900.00
0005435706274	2445	Economy	28900.00
0005435706270	2445	Economy	28900.00
0005435706267	2445	Economy	28900.00
0005433373413	2445	Economy	28900.00
0005435706265	2445	Economy	28900.00
0005433373406	2445	Economy	28900.00
0005433373426	2445	Economy	28900.00
0005435706289	2445	Economy	28900.00
0005435706269	2445	Economy	28900.00
0005435706272	2445	Economy	28900.00
0005435706288	2445	Economy	28900.00
0005433373414	2445	Economy	28900.00
0005433373405	2445	Economy	28900.00
0005433373388	2445	Economy	28900.00
0005435706281	2445	Economy	28900.00
0005435706286	2445	Economy	28900.00
0005433373415	2445	Economy	28900.00
0005435706296	2445	Economy	28900.00
0005435706284	2445	Economy	28900.00
0005435706292	2445	Economy	28900.00
0005433373432	2445	Economy	28900.00
0005433373389	2445	Economy	28900.00
0005433373376	2445	Economy	28900.00
0005435706285	2445	Economy	28900.00
0005433373429	2445	Economy	28900.00
0005435706283	2445	Economy	28900.00
0005435706291	2445	Economy	28900.00
0005435706290	2445	Economy	28900.00
0005433373390	2445	Economy	28900.00
0005435706273	2445	Economy	28900.00
0005433373380	2445	Economy	28900.00
0005435706105	27026	Business	86800.00
0005435706195	27026	Business	86800.00
0005433373468	27026	Business	86800.00
0005435706102	27026	Business	86800.00
0005435706113	27026	Business	86800.00
0005435706152	27026	Business	86800.00
0005433373476	27026	Business	86800.00
0005435706114	27026	Business	86800.00
0005433373483	27026	Economy	28900.00
0005435706101	27026	Economy	28900.00
0005435706116	27026	Economy	28900.00
0005433373484	27026	Economy	28900.00
0005435706153	27026	Economy	31800.00
0005433373473	27026	Economy	31800.00
0005433373474	27026	Economy	28900.00
0005435706117	27026	Economy	28900.00
0005433373478	27026	Economy	28900.00
0005433373475	27026	Economy	28900.00
0005435706168	27026	Economy	28900.00
0005435706144	27026	Economy	28900.00
0005433373479	27026	Economy	28900.00
0005433373470	27026	Economy	28900.00
0005435706142	27026	Economy	28900.00
0005433373477	27026	Economy	28900.00
0005435706145	27026	Economy	28900.00
0005433373485	27026	Economy	28900.00
0005435706103	27026	Economy	28900.00
0005433373472	27026	Economy	28900.00
0005435706115	27026	Economy	28900.00
0005435706170	27026	Economy	28900.00
0005435706110	27026	Economy	28900.00
0005435706175	27026	Economy	28900.00
0005435706095	27026	Economy	28900.00
0005435706169	27026	Economy	28900.00
0005433373481	27026	Economy	28900.00
0005435706165	27026	Economy	28900.00
0005435706147	27026	Economy	28900.00
0005435706106	27026	Economy	28900.00
0005435706131	27026	Economy	28900.00
0005433373480	27026	Economy	28900.00
0005435706146	27026	Economy	28900.00
0005433373482	27026	Economy	28900.00
0005433373471	27026	Economy	28900.00
0005435706171	27026	Economy	28900.00
0005435706128	27026	Economy	28900.00
0005433373469	27026	Economy	28900.00
0005434964097	1319	Business	203300.00
0005433261444	1319	Business	203300.00
0005433261402	1319	Business	203300.00
0005434964084	1319	Business	203300.00
0005433261451	1319	Business	203300.00
0005434964093	1319	Business	203300.00
0005433261429	1319	Business	203300.00
0005433261428	1319	Business	203300.00
0005433261404	1319	Business	203300.00
0005434964101	1319	Business	203300.00
0005433261443	1319	Business	203300.00
0005433261419	1319	Business	203300.00
0005434964075	1319	Business	203300.00
0005432279258	1319	Economy	74500.00
0005434964085	1319	Economy	74500.00
0005432279255	1319	Economy	67800.00
0005432279259	1319	Economy	67800.00
0005434964099	1319	Economy	67800.00
0005434964122	1319	Economy	67800.00
0005434964089	1319	Economy	67800.00
0005433261413	1319	Economy	67800.00
0005434964117	1319	Economy	67800.00
0005433261388	1319	Economy	67800.00
0005433261395	1319	Economy	67800.00
0005434964086	1319	Economy	67800.00
0005434964105	1319	Economy	67800.00
0005434964119	1319	Economy	67800.00
0005433261450	1319	Economy	67800.00
0005433261408	1319	Economy	67800.00
0005434964111	1319	Economy	67800.00
0005434964071	1319	Economy	67800.00
0005434964091	1319	Economy	67800.00
0005433261422	1319	Economy	67800.00
0005434964096	1319	Economy	67800.00
0005434964104	1319	Economy	67800.00
0005434964107	1319	Economy	67800.00
0005434964121	1319	Economy	67800.00
0005433261389	1319	Economy	67800.00
0005434964080	1319	Economy	67800.00
0005434964108	1319	Economy	67800.00
0005433261414	1319	Economy	67800.00
0005434964092	1319	Economy	67800.00
0005434964083	1319	Economy	67800.00
0005434964094	1319	Economy	67800.00
0005433261403	1319	Economy	67800.00
0005434964102	1319	Economy	67800.00
0005433261417	1319	Economy	67800.00
0005434964087	1319	Economy	67800.00
0005434964081	1319	Economy	67800.00
0005432279257	1319	Economy	67800.00
0005434964120	1319	Economy	67800.00
0005434964077	1319	Economy	67800.00
0005433261400	1319	Economy	67800.00
0005433261420	1319	Economy	67800.00
0005432279261	1319	Economy	67800.00
0005434964076	1319	Economy	67800.00
0005432279260	1319	Economy	67800.00
0005434964115	1319	Economy	74500.00
0005434964073	1319	Economy	67800.00
0005434964078	1319	Economy	67800.00
0005434964116	1319	Economy	67800.00
0005434964125	1319	Economy	67800.00
0005434964074	1319	Economy	67800.00
0005433261423	1319	Economy	67800.00
0005434964126	1319	Economy	67800.00
0005434964103	1319	Economy	67800.00
0005434964098	1319	Economy	67800.00
0005433261427	1319	Economy	67800.00
0005434964118	1319	Economy	67800.00
0005434964090	1319	Economy	67800.00
0005433261418	1319	Economy	67800.00
0005434964110	1319	Economy	67800.00
0005434964123	1319	Economy	67800.00
0005434964109	1319	Economy	67800.00
0005434964114	1319	Economy	67800.00
0005433261397	1319	Economy	67800.00
0005434964128	1319	Economy	67800.00
0005434964113	1319	Economy	67800.00
0005434964095	1319	Economy	67800.00
0005434964112	1319	Economy	67800.00
0005433261455	1319	Economy	67800.00
0005432279256	1319	Economy	67800.00
0005434964124	1319	Economy	67800.00
0005434964079	1319	Economy	67800.00
0005434964082	1319	Economy	67800.00
0005433261396	1319	Economy	67800.00
0005434964106	1319	Economy	67800.00
0005434964100	1319	Economy	67800.00
0005434964072	1319	Economy	67800.00
0005434964127	1319	Economy	67800.00
0005433261421	1319	Economy	67800.00
0005433261412	1319	Economy	67800.00
0005432279254	1319	Economy	67800.00
0005434964088	1319	Economy	67800.00
0005433261401	1319	Economy	67800.00
0005434625909	4820	Business	44200.00
0005434625910	4820	Economy	14700.00
0005434625902	4820	Economy	14700.00
0005435907428	4820	Economy	14700.00
0005435907460	4820	Economy	14700.00
0005434625908	4820	Economy	14700.00
0005434625903	4820	Economy	14700.00
0005435907416	4820	Economy	14700.00
0005434625906	4820	Economy	14700.00
0005433194827	4820	Economy	14700.00
0005434625907	4820	Economy	14700.00
0005434625905	4820	Economy	14700.00
0005434625904	4820	Economy	14700.00
0005433194850	32928	Business	44200.00
0005435907476	32928	Business	44200.00
0005434625853	32928	Business	44200.00
0005433194844	32928	Economy	14700.00
0005434625835	32928	Economy	14700.00
0005433194848	32928	Economy	16200.00
0005435907477	32928	Economy	16200.00
0005434625860	32928	Economy	14700.00
0005434625828	32928	Economy	14700.00
0005434625859	32928	Economy	14700.00
0005433194843	32928	Economy	14700.00
0005435907475	32928	Economy	14700.00
0005434625830	32928	Economy	14700.00
0005435907474	32928	Economy	14700.00
0005435907478	32928	Economy	14700.00
0005434625829	32928	Economy	14700.00
0005434625823	32928	Economy	14700.00
0005433194846	32928	Economy	14700.00
0005434625834	32928	Economy	14700.00
0005435907479	32928	Economy	14700.00
0005433194847	32928	Economy	14700.00
0005434625824	32928	Economy	14700.00
0005433194845	32928	Economy	14700.00
0005434625858	32928	Economy	14700.00
0005433194849	32928	Economy	14700.00
0005435784777	13790	Economy	3400.00
0005435784806	13790	Economy	3400.00
0005435784745	13790	Economy	3100.00
0005435784836	13790	Economy	3100.00
0005435784753	13790	Economy	3100.00
0005435784761	13790	Economy	3100.00
0005435784769	13790	Economy	3100.00
0005435784829	13790	Economy	3100.00
0005432195681	13790	Economy	3100.00
0005435784783	13790	Economy	3100.00
0005435784831	13790	Economy	3100.00
0005435784890	13790	Economy	3100.00
0005435784828	13790	Economy	3100.00
0005435784766	13790	Economy	3100.00
0005435784760	13790	Economy	3100.00
0005435784824	13790	Economy	3100.00
0005435784900	13790	Economy	3100.00
0005435784763	13790	Economy	3100.00
0005432195679	13790	Economy	3100.00
0005435784762	13790	Economy	3100.00
0005435784744	13790	Economy	3100.00
0005435784767	13790	Economy	3100.00
0005435784850	13790	Economy	3100.00
0005435784779	13790	Economy	3100.00
0005435784754	13790	Economy	3100.00
0005435784870	13790	Economy	3100.00
0005432195680	13790	Economy	3100.00
0005435784730	13790	Economy	3100.00
0005435784899	13790	Economy	3100.00
0005435784813	13790	Economy	3100.00
0005435784765	13790	Economy	3100.00
0005435784876	13790	Economy	3100.00
0005435784832	13790	Economy	3100.00
0005435784778	13790	Economy	3100.00
0005435784795	13790	Economy	3100.00
0005435784814	13790	Economy	3100.00
0005435784823	13790	Economy	3100.00
0005435784785	13790	Economy	3100.00
0005435784875	13790	Economy	3100.00
0005435785083	27410	Economy	3400.00
0005432190599	27410	Economy	3400.00
0005435785081	27410	Economy	3400.00
0005435785089	27410	Economy	3400.00
0005435785096	27410	Economy	3100.00
0005435785102	27410	Economy	3100.00
0005435785115	27410	Economy	3100.00
0005435785088	27410	Economy	3100.00
0005435785098	27410	Economy	3100.00
0005435785114	27410	Economy	3100.00
0005435785110	27410	Economy	3100.00
0005432190600	27410	Economy	3100.00
0005435785101	27410	Economy	3100.00
0005435785099	27410	Economy	3100.00
0005435785108	27410	Economy	3100.00
0005435785103	27410	Economy	3100.00
0005435785091	27410	Economy	3100.00
0005435785109	27410	Economy	3100.00
0005432190602	27410	Economy	3100.00
0005435785100	27410	Economy	3100.00
0005435785090	27410	Economy	3100.00
0005435785097	27410	Economy	3100.00
0005435785113	27410	Economy	3100.00
0005435785082	27410	Economy	3100.00
0005435785085	27410	Economy	3100.00
0005435785106	27410	Economy	3100.00
0005435785111	27410	Economy	3100.00
0005435785086	27410	Economy	3100.00
0005435785105	27410	Economy	3100.00
0005435785093	27410	Economy	3100.00
0005435785094	27410	Economy	3100.00
0005435785112	27410	Economy	3100.00
0005435785084	27410	Economy	3100.00
0005435787338	27410	Economy	3100.00
0005435785104	27410	Economy	3100.00
0005432190601	27410	Economy	3100.00
0005435785092	27410	Economy	3100.00
0005435785095	27410	Economy	3100.00
0005435785107	27410	Economy	3100.00
0005435787340	27410	Economy	3100.00
0005435787339	27410	Economy	3100.00
0005435785087	27410	Economy	3100.00
0005434406767	20306	Business	12000.00
0005432058359	20306	Business	12000.00
0005435311000	20306	Business	12000.00
0005434406868	20306	Business	12000.00
0005434406930	20306	Business	12000.00
0005434406706	20306	Business	12000.00
0005434406805	20306	Business	12000.00
0005434406806	20306	Business	12000.00
0005434406935	20306	Business	12000.00
0005434406948	20306	Business	12000.00
0005434407067	20306	Business	12000.00
0005434407078	20306	Economy	4000.00
0005434406803	20306	Economy	4000.00
0005434407018	20306	Economy	4000.00
0005434407057	20306	Economy	4000.00
0005435310996	20306	Economy	4000.00
0005434406818	20306	Economy	4000.00
0005434406651	20306	Economy	4000.00
0005434406766	20306	Economy	4000.00
0005435311007	20306	Economy	4000.00
0005434406833	20306	Economy	4400.00
0005434406642	20306	Economy	4400.00
0005434406982	20306	Economy	4400.00
0005434407047	20306	Economy	4400.00
0005432058358	20306	Economy	4400.00
0005434406787	20306	Economy	4000.00
0005434406820	20306	Economy	4000.00
0005434406848	20306	Economy	4000.00
0005434406749	20306	Economy	4000.00
0005435310998	20306	Economy	4000.00
0005434406971	20306	Economy	4000.00
0005434406819	20306	Economy	4000.00
0005434406817	20306	Economy	4000.00
0005434406852	20306	Economy	4000.00
0005434406757	20306	Economy	4000.00
0005435311001	20306	Economy	4000.00
0005434406949	20306	Economy	4000.00
0005435311004	20306	Economy	4000.00
0005434406756	20306	Economy	4000.00
0005434406877	20306	Economy	4000.00
0005434406931	20306	Economy	4000.00
0005435311012	20306	Economy	4000.00
0005434406768	20306	Economy	4000.00
0005435311009	20306	Economy	4000.00
0005434406953	20306	Economy	4000.00
0005434407017	20306	Economy	4000.00
0005434407040	20306	Economy	4000.00
0005434406802	20306	Economy	4000.00
0005435311008	20306	Economy	4000.00
0005434407066	20306	Economy	4000.00
0005435310997	20306	Economy	4000.00
0005434406755	20306	Economy	4000.00
0005434406764	20306	Economy	4000.00
0005434406804	20306	Economy	4000.00
0005434406816	20306	Economy	4000.00
0005435311011	20306	Economy	4000.00
0005434406782	20306	Economy	4000.00
0005434406685	20306	Economy	4000.00
0005434406932	20306	Economy	4000.00
0005434406954	20306	Economy	4000.00
0005434406851	20306	Economy	4000.00
0005434406866	20306	Economy	4000.00
0005434406869	20306	Economy	4000.00
0005435310999	20306	Economy	4000.00
0005435311005	20306	Economy	4000.00
0005435311013	20306	Economy	4000.00
0005434406785	20306	Economy	4000.00
0005434406737	20306	Economy	4000.00
0005432058357	20306	Economy	4000.00
0005435311010	20306	Economy	4000.00
0005435311014	20306	Economy	4000.00
0005434406889	20306	Economy	4000.00
0005435311003	20306	Economy	4000.00
0005435311002	20306	Economy	4000.00
0005435311006	20306	Economy	4000.00
0005434407381	26991	Business	12000.00
0005434407379	26991	Business	12000.00
0005434407382	26991	Business	12000.00
0005434407406	26991	Business	12000.00
0005434407378	26991	Business	12000.00
0005434407402	26991	Business	12000.00
0005434407391	26991	Business	12000.00
0005432153893	26991	Business	12000.00
0005434407392	26991	Business	12000.00
0005434407383	26991	Business	12000.00
0005434407380	26991	Economy	4000.00
0005434407371	26991	Economy	4000.00
0005434407393	26991	Economy	4000.00
0005434407350	26991	Economy	4000.00
0005435310879	26991	Economy	4000.00
0005435310836	26991	Economy	4000.00
0005434407355	26991	Economy	4000.00
0005434407389	26991	Economy	4400.00
0005434407356	26991	Economy	4400.00
0005435310882	26991	Economy	4400.00
0005434407367	26991	Economy	4400.00
0005434407385	26991	Economy	4000.00
0005434407370	26991	Economy	4000.00
0005434407394	26991	Economy	4000.00
0005434407366	26991	Economy	4000.00
0005434407390	26991	Economy	4000.00
0005435310853	26991	Economy	4000.00
0005434407411	26991	Economy	4000.00
0005432153892	26991	Economy	4000.00
0005434407361	26991	Economy	4000.00
0005434407363	26991	Economy	4000.00
0005432153897	26991	Economy	4000.00
0005434407360	26991	Economy	4000.00
0005435310878	26991	Economy	4000.00
0005434407372	26991	Economy	4000.00
0005434407352	26991	Economy	4000.00
0005434407351	26991	Economy	4000.00
0005434407369	26991	Economy	4000.00
0005435310859	26991	Economy	4000.00
0005434407407	26991	Economy	4000.00
0005435310860	26991	Economy	4000.00
0005434407387	26991	Economy	4000.00
0005435310861	26991	Economy	4000.00
0005434407374	26991	Economy	4000.00
0005434407398	26991	Economy	4000.00
0005432153895	26991	Economy	4000.00
0005435310888	26991	Economy	4000.00
0005434407384	26991	Economy	4000.00
0005434407348	26991	Economy	4000.00
0005434407365	26991	Economy	4000.00
0005434407412	26991	Economy	4000.00
0005434407405	26991	Economy	4000.00
0005434407404	26991	Economy	4000.00
0005434407401	26991	Economy	4000.00
0005434407347	26991	Economy	4000.00
0005432153898	26991	Economy	4000.00
0005434407376	26991	Economy	4000.00
0005432153896	26991	Economy	4000.00
0005434407364	26991	Economy	4000.00
0005434407354	26991	Economy	4000.00
0005434407408	26991	Economy	4000.00
0005434407395	26991	Economy	4000.00
0005435310880	26991	Economy	4000.00
0005434407349	26991	Economy	4000.00
0005434407409	26991	Economy	4000.00
0005434407377	26991	Economy	4000.00
0005434407362	26991	Economy	4000.00
0005434407386	26991	Economy	4000.00
0005434407396	26991	Economy	4000.00
0005434407400	26991	Economy	4000.00
0005434407373	26991	Economy	4000.00
0005434407410	26991	Economy	4000.00
0005432153894	26991	Economy	4000.00
0005434407375	26991	Economy	4000.00
0005434407397	26991	Economy	4000.00
0005434407359	26991	Economy	4000.00
0005434407403	26991	Economy	4000.00
0005434407368	26991	Economy	4000.00
0005434407357	26991	Economy	4000.00
0005435310881	26991	Economy	4000.00
0005434407358	26991	Economy	4000.00
0005434407399	26991	Economy	4000.00
0005434407353	26991	Economy	4000.00
0005434407388	26991	Economy	4000.00
0005435310876	26991	Economy	4000.00
0005433123681	5693	Business	43300.00
0005434319299	5693	Business	43300.00
0005433123719	5693	Business	43300.00
0005433123616	5693	Business	43300.00
0005434311206	5693	Business	43300.00
0005432109685	5693	Business	43300.00
0005434319309	5693	Economy	14400.00
0005434319302	5693	Economy	14400.00
0005433123673	5693	Economy	14400.00
0005433123652	5693	Economy	14400.00
0005434319296	5693	Economy	14400.00
0005434319307	5693	Economy	15900.00
0005434319301	5693	Economy	15900.00
0005434319304	5693	Economy	15900.00
0005433123582	5693	Economy	14400.00
0005433123631	5693	Economy	14400.00
0005434319298	5693	Economy	14400.00
0005433123662	5693	Economy	14400.00
0005433123730	5693	Economy	14400.00
0005434319300	5693	Economy	14400.00
0005433123664	5693	Economy	14400.00
0005434311207	5693	Economy	14400.00
0005433123637	5693	Economy	14400.00
0005433123690	5693	Economy	14400.00
0005433123601	5693	Economy	14400.00
0005434319306	5693	Economy	14400.00
0005434319308	5693	Economy	14400.00
0005433123623	5693	Economy	14400.00
0005433123731	5693	Economy	14400.00
0005433123626	5693	Economy	14400.00
0005434311208	5693	Economy	14400.00
0005434319295	5693	Economy	14400.00
0005434319297	5693	Economy	14400.00
0005432109687	5693	Economy	14400.00
0005433123627	5693	Economy	14400.00
0005433123624	5693	Economy	14400.00
0005433123602	5693	Economy	14400.00
0005434319303	5693	Economy	14400.00
0005433123709	5693	Economy	14400.00
0005434319305	5693	Economy	14400.00
0005433123639	5693	Economy	14400.00
0005433123691	5693	Economy	14400.00
0005432109686	5693	Economy	14400.00
0005434312293	15702	Business	43300.00
0005433123804	15702	Business	43300.00
0005434319174	15702	Business	43300.00
0005434319180	15702	Business	43300.00
0005433123814	15702	Business	43300.00
0005434311188	15702	Business	43300.00
0005434319176	15702	Economy	14400.00
0005433123810	15702	Economy	14400.00
0005433123818	15702	Economy	14400.00
0005434319173	15702	Economy	15900.00
0005434319213	15702	Economy	15900.00
0005433123809	15702	Economy	15900.00
0005434319215	15702	Economy	14400.00
0005433123821	15702	Economy	14400.00
0005434319175	15702	Economy	14400.00
0005433123807	15702	Economy	14400.00
0005433123824	15702	Economy	14400.00
0005433123820	15702	Economy	14400.00
0005434312295	15702	Economy	14400.00
0005434311183	15702	Economy	14400.00
0005433123823	15702	Economy	14400.00
0005433123808	15702	Economy	14400.00
0005434319218	15702	Economy	14400.00
0005433123811	15702	Economy	14400.00
0005433123816	15702	Economy	14400.00
0005434319169	15702	Economy	14400.00
0005434319172	15702	Economy	14400.00
0005433123806	15702	Economy	14400.00
0005434311189	15702	Economy	14400.00
0005434319168	15702	Economy	14400.00
0005433123826	15702	Economy	14400.00
0005433123812	15702	Economy	14400.00
0005434319145	15702	Economy	14400.00
0005434311190	15702	Economy	14400.00
0005433123813	15702	Economy	14400.00
0005433123815	15702	Economy	14400.00
0005433123817	15702	Economy	14400.00
0005433123819	15702	Economy	14400.00
0005433123805	15702	Economy	14400.00
0005434319214	15702	Economy	14400.00
0005433123825	15702	Economy	14400.00
0005434311184	15702	Economy	14400.00
0005433123822	15702	Economy	14400.00
0005435219189	31750	Economy	17100.00
0005435220489	31750	Economy	15500.00
0005435219188	31750	Economy	15500.00
0005435220307	31750	Economy	15500.00
0005435220310	31750	Economy	15500.00
0005435220308	31750	Economy	15500.00
0005435220305	31750	Economy	15500.00
0005435219190	31750	Economy	15500.00
0005435220306	31750	Economy	15500.00
0005435220309	31750	Economy	15500.00
0005435219191	31750	Economy	15500.00
0005435219187	31750	Economy	15500.00
0005434189077	9004	Economy	27400.00
0005434189112	9004	Economy	24900.00
0005434189107	9004	Economy	24900.00
0005434484308	9004	Economy	24900.00
0005434189106	9004	Economy	24900.00
0005434189089	9004	Economy	24900.00
0005434484307	9004	Economy	24900.00
0005434189113	9004	Economy	24900.00
0005434189093	9004	Economy	24900.00
0005434484310	9004	Economy	24900.00
0005434189091	9004	Economy	24900.00
0005434484311	9004	Economy	24900.00
0005434484309	9004	Economy	24900.00
0005434189099	9004	Economy	24900.00
0005434189111	9004	Economy	24900.00
0005434484251	16631	Economy	27400.00
0005434189145	16631	Economy	27400.00
0005434484263	16631	Economy	24900.00
0005434484232	16631	Economy	24900.00
0005434484248	16631	Economy	24900.00
0005434484262	16631	Economy	24900.00
0005434189141	16631	Economy	24900.00
0005434189144	16631	Economy	24900.00
0005434189143	16631	Economy	24900.00
0005434189146	16631	Economy	24900.00
0005434189142	16631	Economy	24900.00
0005434484260	16631	Economy	24900.00
0005434484231	16631	Economy	24900.00
0005434484250	16631	Economy	24900.00
0005433123825	7642	Business	11100.00
0005433123813	7642	Business	11100.00
0005433123804	7642	Business	11100.00
0005433123807	7642	Economy	3700.00
0005433123814	7642	Economy	3700.00
0005433123810	7642	Economy	3700.00
0005433123812	7642	Economy	3700.00
0005433123818	7642	Economy	4100.00
0005433123823	7642	Economy	4100.00
0005433123811	7642	Economy	3700.00
0005433123822	7642	Economy	3700.00
0005433123821	7642	Economy	3700.00
0005433123806	7642	Economy	3700.00
0005433123816	7642	Economy	3700.00
0005433123805	7642	Economy	3700.00
0005433123826	7642	Economy	3700.00
0005433123824	7642	Economy	3700.00
0005433123808	7642	Economy	3700.00
0005433123820	7642	Economy	3700.00
0005433123817	7642	Economy	3700.00
0005433123815	7642	Economy	3700.00
0005433123819	7642	Economy	3700.00
0005433123809	7642	Economy	3700.00
0005433449849	7643	Business	11100.00
0005432692886	7643	Business	11100.00
0005432692892	7643	Business	11100.00
0005433449850	7643	Business	11100.00
0005432720730	7643	Business	11100.00
0005432720750	7643	Business	11100.00
0005432692900	7643	Business	11100.00
0005432692890	7643	Business	11100.00
0005432692893	7643	Business	11100.00
0005432692888	7643	Business	11100.00
0005432692891	7643	Business	11100.00
0005433449839	7643	Business	11100.00
0005433449834	7643	Economy	3700.00
0005432720742	7643	Economy	3700.00
0005432720749	7643	Economy	3700.00
0005432692874	7643	Economy	3700.00
0005432720751	7643	Economy	3700.00
0005432692904	7643	Economy	3700.00
0005432692894	7643	Economy	3700.00
0005433449830	7643	Economy	3700.00
0005432692897	7643	Economy	3700.00
0005433449831	7643	Economy	4100.00
0005433449835	7643	Economy	4100.00
0005432692902	7643	Economy	4100.00
0005432692901	7643	Economy	4100.00
0005432071556	7643	Economy	4100.00
0005432720735	7643	Economy	3700.00
0005433449848	7643	Economy	3700.00
0005432071557	7643	Economy	3700.00
0005432692875	7643	Economy	3700.00
0005433449838	7643	Economy	3700.00
0005432692887	7643	Economy	3700.00
0005432720757	7643	Economy	3700.00
0005432692895	7643	Economy	3700.00
0005432720752	7643	Economy	3700.00
0005433449832	7643	Economy	3700.00
0005432692889	7643	Economy	3700.00
0005432720746	7643	Economy	3700.00
0005432720741	7643	Economy	3700.00
0005433449829	7643	Economy	3700.00
0005432692877	7643	Economy	3700.00
0005432692878	7643	Economy	3700.00
0005432720745	7643	Economy	3700.00
0005432720747	7643	Economy	3700.00
0005432692876	7643	Economy	3700.00
0005432720732	7643	Economy	3700.00
0005432720738	7643	Economy	3700.00
0005433449843	7643	Economy	3700.00
0005432692903	7643	Economy	3700.00
0005433449840	7643	Economy	3700.00
0005432692885	7643	Economy	3700.00
0005433449841	7643	Economy	3700.00
0005432720743	7643	Economy	3700.00
0005432692905	7643	Economy	3700.00
0005432720734	7643	Economy	3700.00
0005432720737	7643	Economy	3700.00
0005432692898	7643	Economy	3700.00
0005432720733	7643	Economy	3700.00
0005432692896	7643	Economy	3700.00
0005432720753	7643	Economy	3700.00
0005432692884	7643	Economy	3700.00
0005432720744	7643	Economy	3700.00
0005433449828	7643	Economy	3700.00
0005432071555	7643	Economy	3700.00
0005432720739	7643	Economy	3700.00
0005432720736	7643	Economy	3700.00
0005432720754	7643	Economy	3700.00
0005433449837	7643	Economy	3700.00
0005432720755	7643	Economy	3700.00
0005433449846	7643	Economy	3700.00
0005432692883	7643	Economy	3700.00
0005433449845	7643	Economy	3700.00
0005432720748	7643	Economy	3700.00
0005433449833	7643	Economy	3700.00
0005432720740	7643	Economy	3700.00
0005433449842	7643	Economy	3700.00
0005433449847	7643	Economy	3700.00
0005432692882	7643	Economy	3700.00
0005432720756	7643	Economy	3700.00
0005433449836	7643	Economy	3700.00
0005432692899	7643	Economy	3700.00
0005432720731	7643	Economy	3700.00
0005433449844	7643	Economy	3700.00
0005432692879	7643	Economy	3700.00
0005432692881	7643	Economy	3700.00
0005432692880	7643	Economy	3700.00
0005432692631	30358	Business	11100.00
0005432692603	30358	Business	11100.00
0005432692558	30358	Business	11100.00
0005433449617	30358	Business	11100.00
0005433449612	30358	Business	11100.00
0005433449614	30358	Business	11100.00
0005433449613	30358	Economy	3700.00
0005432692675	30358	Economy	3700.00
0005432692590	30358	Economy	3700.00
0005433449691	30358	Economy	4100.00
0005433449668	30358	Economy	4100.00
0005432692647	30358	Economy	3700.00
0005432692569	30358	Economy	3700.00
0005433449627	30358	Economy	3700.00
0005433449595	30358	Economy	3700.00
0005433449629	30358	Economy	3700.00
0005432692683	30358	Economy	3700.00
0005432692645	30358	Economy	3700.00
0005432692571	30358	Economy	3700.00
0005432692646	30358	Economy	3700.00
0005432692648	30358	Economy	3700.00
0005433449666	30358	Economy	3700.00
0005432692557	30358	Economy	3700.00
0005432692682	30358	Economy	3700.00
0005432692608	30358	Economy	3700.00
0005433449621	30358	Economy	3700.00
0005432692568	30358	Economy	3700.00
0005433449616	30358	Economy	3700.00
0005432692537	30358	Economy	3700.00
0005432692666	30358	Economy	3700.00
0005433449692	30358	Economy	3700.00
0005432692638	30358	Economy	3700.00
0005432692674	30358	Economy	3700.00
0005432692627	30358	Economy	3700.00
0005432692633	30358	Economy	3700.00
0005432692639	30358	Economy	3700.00
0005433449670	30358	Economy	3700.00
0005432692582	30358	Economy	3700.00
0005432692534	30358	Economy	3700.00
0005433449703	30358	Economy	3700.00
0005433449644	30358	Economy	3700.00
0005432720596	30357	Business	11100.00
0005432720562	30357	Business	11100.00
0005433123637	30357	Business	11100.00
0005433722180	30357	Business	11100.00
0005432720605	30357	Business	11100.00
0005433123616	30357	Business	11100.00
0005432720561	30357	Business	11100.00
0005432720632	30357	Business	11100.00
0005433123639	30357	Economy	3700.00
0005433123691	30357	Economy	3700.00
0005433123623	30357	Economy	3700.00
0005433123690	30357	Economy	3700.00
0005433123681	30357	Economy	3700.00
0005433722186	30357	Economy	3700.00
0005432720609	30357	Economy	3700.00
0005432720459	30357	Economy	4100.00
0005433722179	30357	Economy	4100.00
0005433722182	30357	Economy	3700.00
0005432720519	30357	Economy	3700.00
0005433123624	30357	Economy	3700.00
0005433123731	30357	Economy	3700.00
0005433123582	30357	Economy	3700.00
0005432720591	30357	Economy	3700.00
0005432720614	30357	Economy	3700.00
0005433722181	30357	Economy	3700.00
0005432720523	30357	Economy	3700.00
0005432720465	30357	Economy	3700.00
0005433123652	30357	Economy	3700.00
0005432720563	30357	Economy	3700.00
0005432720506	30357	Economy	3700.00
0005432720538	30357	Economy	3700.00
0005432720428	30357	Economy	3700.00
0005433123602	30357	Economy	3700.00
0005432720551	30357	Economy	3700.00
0005433123662	30357	Economy	3700.00
0005433123601	30357	Economy	3700.00
0005432720597	30357	Economy	3700.00
0005432720608	30357	Economy	3700.00
0005433123627	30357	Economy	3700.00
0005432720532	30357	Economy	3700.00
0005432720458	30357	Economy	3700.00
0005432720499	30357	Economy	3700.00
0005433722183	30357	Economy	3700.00
0005433123673	30357	Economy	3700.00
0005433123631	30357	Economy	3700.00
0005433123709	30357	Economy	3700.00
0005432720530	30357	Economy	3700.00
0005433123664	30357	Economy	3700.00
0005433123730	30357	Economy	3700.00
0005432720456	30357	Economy	3700.00
0005432720489	30357	Economy	3700.00
0005433123719	30357	Economy	3700.00
0005432720466	30357	Economy	3700.00
0005433722184	30357	Economy	3700.00
0005432720490	30357	Economy	3700.00
0005433722185	30357	Economy	3700.00
0005433123626	30357	Economy	3700.00
0005432720491	30357	Economy	3700.00
0005434586464	1397	Business	70400.00
0005434586463	1397	Business	70400.00
0005433192886	1397	Business	70400.00
0005433192847	1397	Business	70400.00
0005433524969	1397	Business	70400.00
0005432968806	1397	Business	70400.00
0005434586451	1397	Business	70400.00
0005434586460	1397	Business	70400.00
0005434586458	1397	Business	70400.00
0005434514953	1397	Business	70400.00
0005433192830	1397	Business	70400.00
0005434586455	1397	Economy	23500.00
0005433724781	1397	Economy	23500.00
0005433524971	1397	Economy	23500.00
0005433192878	1397	Economy	23500.00
0005434586450	1397	Economy	23500.00
0005433524972	1397	Economy	23500.00
0005433192857	1397	Economy	23500.00
0005433524970	1397	Economy	25800.00
0005434586448	1397	Economy	25800.00
0005434586468	1397	Economy	23500.00
0005434586456	1397	Economy	23500.00
0005434514952	1397	Economy	23500.00
0005434586449	1397	Economy	23500.00
0005434586471	1397	Economy	23500.00
0005433192873	1397	Economy	23500.00
0005434586465	1397	Economy	23500.00
0005434586462	1397	Economy	23500.00
0005434586454	1397	Economy	23500.00
0005433724780	1397	Economy	23500.00
0005434514951	1397	Economy	23500.00
0005433724778	1397	Economy	23500.00
0005434586461	1397	Economy	23500.00
0005433192871	1397	Economy	23500.00
0005433192820	1397	Economy	23500.00
0005434586459	1397	Economy	23500.00
0005433192870	1397	Economy	23500.00
0005432270986	1397	Economy	23500.00
0005433524968	1397	Economy	23500.00
0005433524976	1397	Economy	23500.00
0005432270988	1397	Economy	23500.00
0005433192916	1397	Economy	23500.00
0005433524975	1397	Economy	23500.00
0005433192902	1397	Economy	23500.00
0005433192844	1397	Economy	23500.00
0005433724777	1397	Economy	23500.00
0005432927919	1397	Economy	23500.00
0005433524973	1397	Economy	23500.00
0005432927918	1397	Economy	23500.00
0005433192890	1397	Economy	23500.00
0005434586470	1397	Economy	23500.00
0005434514950	1397	Economy	23500.00
0005433724779	1397	Economy	23500.00
0005432270987	1397	Economy	23500.00
0005433524977	1397	Economy	23500.00
0005433524974	1397	Economy	23500.00
0005433192876	1397	Economy	23500.00
0005434586469	1397	Economy	23500.00
0005432927894	1397	Economy	23500.00
0005434586467	1397	Economy	23500.00
0005433524978	1397	Economy	23500.00
0005432927920	1397	Economy	23500.00
0005433192887	1397	Economy	23500.00
0005434586457	1397	Economy	23500.00
0005434586466	1397	Economy	23500.00
0005434586453	1397	Economy	23500.00
0005434586452	1397	Economy	23500.00
0005434586447	1397	Economy	23500.00
0005433524880	18519	Business	70400.00
0005434586178	18519	Business	70400.00
0005434586244	18519	Business	70400.00
0005434586238	18519	Business	70400.00
0005433524879	18519	Business	70400.00
0005433192961	18519	Business	70400.00
0005434586243	18519	Business	70400.00
0005433724755	18519	Business	70400.00
0005433524895	18519	Business	70400.00
0005433192959	18519	Business	70400.00
0005433724733	18519	Economy	23500.00
0005433724756	18519	Economy	23500.00
0005434586258	18519	Economy	23500.00
0005434514935	18519	Economy	23500.00
0005433524878	18519	Economy	23500.00
0005433524882	18519	Economy	23500.00
0005433192968	18519	Economy	23500.00
0005433192970	18519	Economy	25800.00
0005434586192	18519	Economy	25800.00
0005433524907	18519	Economy	25800.00
0005433192972	18519	Economy	25800.00
0005432927942	18519	Economy	25800.00
0005434586283	18519	Economy	23500.00
0005433192964	18519	Economy	23500.00
0005434586284	18519	Economy	23500.00
0005433192971	18519	Economy	23500.00
0005432968825	18519	Economy	23500.00
0005432927946	18519	Economy	23500.00
0005433524906	18519	Economy	23500.00
0005434586260	18519	Economy	23500.00
0005434586179	18519	Economy	23500.00
0005434586326	18519	Economy	23500.00
0005434586298	18519	Economy	23500.00
0005433724747	18519	Economy	23500.00
0005434586233	18519	Economy	23500.00
0005432968826	18519	Economy	23500.00
0005434586275	18519	Economy	23500.00
0005434586357	18519	Economy	23500.00
0005434586320	18519	Economy	23500.00
0005433192969	18519	Economy	23500.00
0005434514934	18519	Economy	23500.00
0005434514926	18519	Economy	23500.00
0005434586204	18519	Economy	23500.00
0005434586205	18519	Economy	23500.00
0005432927948	18519	Economy	23500.00
0005434586259	18519	Economy	23500.00
0005434586314	18519	Economy	23500.00
0005432927944	18519	Economy	23500.00
0005434586234	18519	Economy	23500.00
0005433192967	18519	Economy	23500.00
0005434586159	18519	Economy	23500.00
0005433524871	18519	Economy	23500.00
0005433192966	18519	Economy	23500.00
0005434586327	18519	Economy	23500.00
0005432927947	18519	Economy	23500.00
0005434586228	18519	Economy	23500.00
0005433192962	18519	Economy	23500.00
0005432927945	18519	Economy	23500.00
0005433524894	18519	Economy	23500.00
0005433192963	18519	Economy	23500.00
0005434586207	18519	Economy	23500.00
0005433192960	18519	Economy	23500.00
0005434586344	18519	Economy	23500.00
0005433192965	18519	Economy	23500.00
0005434586229	18519	Economy	23500.00
0005434586202	18519	Economy	23500.00
0005432927943	18519	Economy	23500.00
0005433524854	18519	Economy	23500.00
0005434586345	18519	Economy	23500.00
0005434586299	18519	Economy	23500.00
0005434586203	18519	Economy	23500.00
0005434343983	11423	Economy	4300.00
0005434343982	11423	Economy	4300.00
0005434142587	11423	Economy	4300.00
0005434343966	11423	Economy	4300.00
0005434343955	11423	Economy	4000.00
0005434343978	11423	Economy	4000.00
0005434343961	11423	Economy	4000.00
0005434343979	11423	Economy	4000.00
0005434343954	11423	Economy	4000.00
0005434343975	11423	Economy	4000.00
0005434343977	11423	Economy	4000.00
0005434343974	11423	Economy	4000.00
0005434343969	11423	Economy	4000.00
0005434343953	11423	Economy	4000.00
0005434343972	11423	Economy	4000.00
0005434343985	11423	Economy	4000.00
0005434142588	11423	Economy	4000.00
0005434343962	11423	Economy	4000.00
0005434343959	11423	Economy	4000.00
0005434343968	11423	Economy	4000.00
0005434343973	11423	Economy	4000.00
0005434343980	11423	Economy	4000.00
0005434343957	11423	Economy	4000.00
0005434343950	11423	Economy	4000.00
0005434343956	11423	Economy	4000.00
0005434343967	11423	Economy	4000.00
0005434343951	11423	Economy	4000.00
0005434142586	11423	Economy	4000.00
0005434343964	11423	Economy	4000.00
0005434343958	11423	Economy	4000.00
0005435302124	11423	Economy	4000.00
0005434343960	11423	Economy	4000.00
0005434343952	11423	Economy	4000.00
0005434343984	11423	Economy	4000.00
0005435302136	11423	Economy	4000.00
0005434343963	11423	Economy	4000.00
0005434343986	11423	Economy	4000.00
0005434343976	11423	Economy	4000.00
0005434343970	11423	Economy	4000.00
0005434343981	11423	Economy	4000.00
0005434343971	11423	Economy	4000.00
0005434343965	11423	Economy	4000.00
0005434343987	11423	Economy	4000.00
0005434343949	11423	Economy	4000.00
0005435302125	11423	Economy	4000.00
0005434142585	11423	Economy	4000.00
0005434343789	29786	Economy	4300.00
0005434142552	29786	Economy	4300.00
0005434343624	29786	Economy	4300.00
0005434142553	29786	Economy	4300.00
0005434343836	29786	Economy	4000.00
0005434343723	29786	Economy	4000.00
0005434343746	29786	Economy	4000.00
0005434343727	29786	Economy	4000.00
0005434343604	29786	Economy	4000.00
0005434142551	29786	Economy	4000.00
0005434343687	29786	Economy	4000.00
0005434343714	29786	Economy	4000.00
0005434343608	29786	Economy	4000.00
0005434343696	29786	Economy	4000.00
0005434343835	29786	Economy	4000.00
0005435305006	29786	Economy	4000.00
0005434343724	29786	Economy	4000.00
0005434343729	29786	Economy	4000.00
0005435305005	29786	Economy	4000.00
0005435304136	29786	Economy	4000.00
0005434343702	29786	Economy	4000.00
0005434343747	29786	Economy	4000.00
0005434343743	29786	Economy	4000.00
0005434343750	29786	Economy	4000.00
0005434343623	29786	Economy	4000.00
0005434343682	29786	Economy	4000.00
0005434343646	29786	Economy	4000.00
0005434343711	29786	Economy	4000.00
0005434343691	29786	Economy	4000.00
0005434343647	29786	Economy	4000.00
0005434343837	29786	Economy	4000.00
0005434343697	29786	Economy	4000.00
0005435304133	29786	Economy	4000.00
0005434343686	29786	Economy	4000.00
0005434343680	29786	Economy	4000.00
0005434343692	29786	Economy	4000.00
0005435304134	29786	Economy	4000.00
0005434343783	29786	Economy	4000.00
0005434343683	29786	Economy	4000.00
0005434343728	29786	Economy	4000.00
0005434343752	29786	Economy	4000.00
0005435304132	29786	Economy	4000.00
0005434142557	29786	Economy	4000.00
0005434343748	29786	Economy	4000.00
0005435304135	29786	Economy	4000.00
0005434343590	29786	Economy	4000.00
0005434343798	29786	Economy	4000.00
0005434343665	29786	Economy	4000.00
0005435824455	1254	Business	199800.00
0005435824468	1254	Business	199800.00
0005435824466	1254	Business	199800.00
0005432284540	1254	Business	199800.00
0005433415402	1254	Business	199800.00
0005435824454	1254	Business	199800.00
0005435824481	1254	Business	199800.00
0005435824469	1254	Business	199800.00
0005435824464	1254	Business	199800.00
0005432284542	1254	Business	199800.00
0005435824467	1254	Business	199800.00
0005433415443	1254	Business	199800.00
0005435824457	1254	Economy	66600.00
0005435824459	1254	Economy	73200.00
0005435824478	1254	Economy	73200.00
0005433415503	1254	Economy	66600.00
0005433415444	1254	Economy	66600.00
0005435824480	1254	Economy	66600.00
0005435824458	1254	Economy	66600.00
0005433415393	1254	Economy	66600.00
0005435824473	1254	Economy	66600.00
0005435824477	1254	Economy	66600.00
0005432284539	1254	Economy	66600.00
0005433415399	1254	Economy	66600.00
0005435824476	1254	Economy	66600.00
0005435824462	1254	Economy	66600.00
0005433415499	1254	Economy	66600.00
0005433415427	1254	Economy	66600.00
0005433415470	1254	Economy	66600.00
0005433415392	1254	Economy	66600.00
0005435824474	1254	Economy	66600.00
0005435824470	1254	Economy	66600.00
0005435824460	1254	Economy	66600.00
0005433415442	1254	Economy	66600.00
0005435824471	1254	Economy	66600.00
0005435824475	1254	Economy	66600.00
0005435824463	1254	Economy	66600.00
0005435824472	1254	Economy	66600.00
0005435824453	1254	Economy	66600.00
0005433415434	1254	Economy	66600.00
0005432284541	1254	Economy	66600.00
0005435824465	1254	Economy	66600.00
0005433415428	1254	Economy	66600.00
0005433415457	1254	Economy	66600.00
0005435824461	1254	Economy	66600.00
0005435824456	1254	Economy	66600.00
0005435824479	1254	Economy	66600.00
0005435824242	18007	Business	199800.00
0005433415572	18007	Business	199800.00
0005435824233	18007	Business	199800.00
0005433415567	18007	Economy	66600.00
0005433415562	18007	Economy	66600.00
0005435824247	18007	Economy	66600.00
0005433415559	18007	Economy	66600.00
0005433415569	18007	Economy	66600.00
0005435824311	18007	Economy	73200.00
0005433415566	18007	Economy	66600.00
0005433415571	18007	Economy	73200.00
0005433415568	18007	Economy	66600.00
0005435824271	18007	Economy	66600.00
0005435824159	18007	Economy	66600.00
0005433415565	18007	Economy	66600.00
0005435824308	18007	Economy	66600.00
0005435824192	18007	Economy	66600.00
0005435824240	18007	Economy	66600.00
0005435824312	18007	Economy	66600.00
0005435824246	18007	Economy	66600.00
0005433415574	18007	Economy	66600.00
0005433415573	18007	Economy	66600.00
0005433415561	18007	Economy	66600.00
0005435824193	18007	Economy	66600.00
0005435824166	18007	Economy	66600.00
0005433415558	18007	Economy	66600.00
0005433415560	18007	Economy	66600.00
0005435824258	18007	Economy	66600.00
0005433415564	18007	Economy	66600.00
0005435824281	18007	Economy	66600.00
0005435824269	18007	Economy	66600.00
0005435824194	18007	Economy	66600.00
0005435824270	18007	Economy	66600.00
0005433415570	18007	Economy	66600.00
0005435824230	18007	Economy	66600.00
0005435824231	18007	Economy	66600.00
0005433415563	18007	Economy	66600.00
0005435242464	5640	Business	27800.00
0005432783464	5640	Business	27800.00
0005435242395	5640	Business	27800.00
0005432783496	5640	Business	27800.00
0005435242499	5640	Business	27800.00
0005432783479	5640	Business	27800.00
0005432783455	5640	Business	27800.00
0005435242406	5640	Business	27800.00
0005432783469	5640	Business	27800.00
0005432143966	5640	Business	27800.00
0005432783475	5640	Business	27800.00
0005432783487	5640	Economy	9300.00
0005432783482	5640	Economy	9300.00
0005435476660	5640	Economy	9300.00
0005435242506	5640	Economy	9300.00
0005432143967	5640	Economy	9300.00
0005432783494	5640	Economy	9300.00
0005432783458	5640	Economy	9300.00
0005432783484	5640	Economy	9300.00
0005432783492	5640	Economy	9300.00
0005435242407	5640	Economy	9300.00
0005432783485	5640	Economy	10200.00
0005432783478	5640	Economy	10200.00
0005435242459	5640	Economy	10200.00
0005435242539	5640	Economy	10200.00
0005435476658	5640	Economy	10200.00
0005432783462	5640	Economy	9300.00
0005435242470	5640	Economy	9300.00
0005432783471	5640	Economy	9300.00
0005432783488	5640	Economy	9300.00
0005432143969	5640	Economy	9300.00
0005432783489	5640	Economy	9300.00
0005432783470	5640	Economy	9300.00
0005435476668	5640	Economy	9300.00
0005432783486	5640	Economy	9300.00
0005432783449	5640	Economy	9300.00
0005432783460	5640	Economy	9300.00
0005435242477	5640	Economy	9300.00
0005435242404	5640	Economy	9300.00
0005432783474	5640	Economy	9300.00
0005432783472	5640	Economy	9300.00
0005432783466	5640	Economy	9300.00
0005435476642	5640	Economy	9300.00
0005432783457	5640	Economy	9300.00
0005432783459	5640	Economy	9300.00
0005435242443	5640	Economy	9300.00
0005432783493	5640	Economy	9300.00
0005432783461	5640	Economy	9300.00
0005435242489	5640	Economy	9300.00
0005432783468	5640	Economy	9300.00
0005435476641	5640	Economy	9300.00
0005435242601	5640	Economy	9300.00
0005432783467	5640	Economy	9300.00
0005432783454	5640	Economy	9300.00
0005435476635	5640	Economy	9300.00
0005435242472	5640	Economy	9300.00
0005432783480	5640	Economy	9300.00
0005435242490	5640	Economy	9300.00
0005435242507	5640	Economy	9300.00
0005432783452	5640	Economy	9300.00
0005432783483	5640	Economy	9300.00
0005432783497	5640	Economy	9300.00
0005432783498	5640	Economy	9300.00
0005435242399	5640	Economy	9300.00
0005432783456	5640	Economy	9300.00
0005435476688	5640	Economy	9300.00
0005432783450	5640	Economy	9300.00
0005432783495	5640	Economy	9300.00
0005435242530	5640	Economy	9300.00
0005432143968	5640	Economy	9300.00
0005432783465	5640	Economy	9300.00
0005432783444	5640	Economy	9300.00
0005432783446	5640	Economy	9300.00
0005432783451	5640	Economy	9300.00
0005435242471	5640	Economy	9300.00
0005432783477	5640	Economy	9300.00
0005432783481	5640	Economy	9300.00
0005432783463	5640	Economy	9300.00
0005432783491	5640	Economy	9300.00
0005432783473	5640	Economy	9300.00
0005432783453	5640	Economy	9300.00
0005435242411	5640	Economy	9300.00
0005432783476	5640	Economy	9300.00
0005432783448	5640	Economy	9300.00
0005432783447	5640	Economy	9300.00
0005432783490	5640	Economy	9300.00
0005432783445	5640	Economy	9300.00
0005432782884	15346	Business	27800.00
0005435242672	15346	Business	27800.00
0005435242673	15346	Business	27800.00
0005435476718	15346	Business	27800.00
0005435242668	15346	Business	27800.00
0005432783079	15346	Business	27800.00
0005432783072	15346	Business	27800.00
0005432782907	15346	Business	27800.00
0005435242679	15346	Business	27800.00
0005432783001	15346	Business	27800.00
0005435242677	15346	Business	27800.00
0005435242687	15346	Economy	9300.00
0005432782872	15346	Economy	9300.00
0005432782952	15346	Economy	9300.00
0005432783040	15346	Economy	9300.00
0005435242674	15346	Economy	9300.00
0005432783246	15346	Economy	9300.00
0005432783053	15346	Economy	10200.00
0005432782921	15346	Economy	10200.00
0005435242681	15346	Economy	10200.00
0005432782860	15346	Economy	9300.00
0005432783110	15346	Economy	9300.00
0005435242676	15346	Economy	9300.00
0005432783019	15346	Economy	9300.00
0005432782953	15346	Economy	9300.00
0005435242689	15346	Economy	9300.00
0005432783026	15346	Economy	9300.00
0005432783143	15346	Economy	9300.00
0005435242670	15346	Economy	9300.00
0005435242666	15346	Economy	9300.00
0005432783054	15346	Economy	9300.00
0005432783160	15346	Economy	9300.00
0005435242682	15346	Economy	9300.00
0005435242691	15346	Economy	9300.00
0005432782984	15346	Economy	9300.00
0005435242667	15346	Economy	9300.00
0005432783174	15346	Economy	9300.00
0005432783107	15346	Economy	9300.00
0005435242688	15346	Economy	9300.00
0005435242683	15346	Economy	9300.00
0005435242665	15346	Economy	9300.00
0005432782891	15346	Economy	9300.00
0005435242690	15346	Economy	9300.00
0005435242678	15346	Economy	9300.00
0005435242664	15346	Economy	9300.00
0005432782995	15346	Economy	9300.00
0005432783080	15346	Economy	9300.00
0005435476719	15346	Economy	9300.00
0005432783031	15346	Economy	9300.00
0005432783070	15346	Economy	9300.00
0005432783005	15346	Economy	9300.00
0005435242675	15346	Economy	9300.00
0005435242669	15346	Economy	9300.00
0005435242671	15346	Economy	9300.00
0005435242680	15346	Economy	9300.00
0005432783103	15346	Economy	9300.00
0005432782892	15346	Economy	9300.00
0005435242684	15346	Economy	9300.00
0005435242686	15346	Economy	9300.00
0005432782887	15346	Economy	9300.00
0005432783245	15346	Economy	9300.00
0005432782893	15346	Economy	9300.00
0005435242685	15346	Economy	9300.00
0005432783002	15346	Economy	9300.00
0005432783006	15346	Economy	9300.00
0005432783039	15346	Economy	9300.00
0005435476717	15346	Economy	9300.00
0005432783102	15346	Economy	9300.00
0005432848228	4394	Economy	7000.00
0005432848226	4394	Economy	7000.00
0005434463916	4394	Economy	7000.00
0005432848219	4394	Economy	6300.00
0005435850777	4394	Economy	6300.00
0005432848227	4394	Economy	6300.00
0005434462778	4394	Economy	6300.00
0005432848231	4394	Economy	6300.00
0005432848220	4394	Economy	6300.00
0005434462776	4394	Economy	6300.00
0005434462779	4394	Economy	6300.00
0005434462777	4394	Economy	6300.00
0005432848221	4394	Economy	6300.00
0005432848230	4394	Economy	6300.00
0005432848218	4394	Economy	6300.00
0005435850807	4394	Economy	6300.00
0005432848232	4394	Economy	6300.00
0005434463917	4394	Economy	6300.00
0005435850760	4394	Economy	6300.00
0005432848229	4394	Economy	6300.00
0005435850808	4394	Economy	6300.00
0005432848224	4394	Economy	6300.00
0005435850815	4394	Economy	6300.00
0005432848225	4394	Economy	6300.00
0005435850759	4394	Economy	6300.00
0005434463915	4394	Economy	6300.00
0005432848222	4394	Economy	6300.00
0005432848223	4394	Economy	6300.00
0005432848074	28870	Economy	7000.00
0005432848073	28870	Economy	7000.00
0005432848110	28870	Economy	7000.00
0005432848076	28870	Economy	6300.00
0005435850859	28870	Economy	6300.00
0005432848088	28870	Economy	6300.00
0005432848059	28870	Economy	6300.00
0005432848105	28870	Economy	6300.00
0005434463895	28870	Economy	6300.00
0005432848087	28870	Economy	6300.00
0005435850851	28870	Economy	6300.00
0005434463894	28870	Economy	6300.00
0005435850858	28870	Economy	6300.00
0005435850857	28870	Economy	6300.00
0005435850853	28870	Economy	6300.00
0005434461615	28870	Economy	6300.00
0005432848099	28870	Economy	6300.00
0005435850852	28870	Economy	6300.00
0005432848106	28870	Economy	6300.00
0005434463893	28870	Economy	6300.00
0005432848060	28870	Economy	6300.00
0005435850856	28870	Economy	6300.00
0005434461614	28870	Economy	6300.00
0005432848134	28870	Economy	6300.00
0005432848140	28870	Economy	6300.00
0005432848136	28870	Economy	6300.00
0005435850854	28870	Economy	6300.00
0005432848135	28870	Economy	6300.00
0005432848141	28870	Economy	6300.00
0005432848077	28870	Economy	6300.00
0005435850855	28870	Economy	6300.00
0005434925632	6300	Business	11900.00
0005433496800	6300	Business	11900.00
0005433496791	6300	Business	11900.00
0005434925635	6300	Business	11900.00
0005432075210	6300	Business	11900.00
0005434443612	6300	Business	11900.00
0005432075209	6300	Business	11900.00
0005433496784	6300	Business	11900.00
0005433496774	6300	Business	11900.00
0005434443611	6300	Business	11900.00
0005433496799	6300	Business	11900.00
0005434925631	6300	Business	11900.00
0005434925619	6300	Economy	4000.00
0005434925641	6300	Economy	4000.00
0005434925649	6300	Economy	4000.00
0005434925636	6300	Economy	4000.00
0005434443618	6300	Economy	4000.00
0005433496794	6300	Economy	4000.00
0005434925612	6300	Economy	4000.00
0005434925644	6300	Economy	4000.00
0005434925633	6300	Economy	4000.00
0005433496782	6300	Economy	4000.00
0005433496781	6300	Economy	4400.00
0005434925634	6300	Economy	4400.00
0005433496787	6300	Economy	4400.00
0005433496802	6300	Economy	4400.00
0005434443616	6300	Economy	4400.00
0005434443610	6300	Economy	4000.00
0005434925624	6300	Economy	4000.00
0005434925609	6300	Economy	4000.00
0005434925622	6300	Economy	4000.00
0005433496793	6300	Economy	4000.00
0005434925617	6300	Economy	4000.00
0005433496801	6300	Economy	4000.00
0005433496783	6300	Economy	4000.00
0005434443613	6300	Economy	4000.00
0005433496776	6300	Economy	4000.00
0005433496792	6300	Economy	4000.00
0005434443605	6300	Economy	4000.00
0005434925623	6300	Economy	4000.00
0005434443608	6300	Economy	4000.00
0005434925626	6300	Economy	4000.00
0005434925610	6300	Economy	4000.00
0005433496795	6300	Economy	4000.00
0005434925615	6300	Economy	4000.00
0005434925625	6300	Economy	4000.00
0005434925650	6300	Economy	4000.00
0005433496790	6300	Economy	4000.00
0005434925639	6300	Economy	4000.00
0005433496789	6300	Economy	4000.00
0005433496779	6300	Economy	4000.00
0005434443619	6300	Economy	4000.00
0005434925637	6300	Economy	4000.00
0005434925618	6300	Economy	4000.00
0005434925613	6300	Economy	4000.00
0005434925630	6300	Economy	4000.00
0005433496775	6300	Economy	4000.00
0005433496796	6300	Economy	4000.00
0005434443614	6300	Economy	4000.00
0005434925651	6300	Economy	4000.00
0005433496780	6300	Economy	4000.00
0005434443617	6300	Economy	4000.00
0005434925629	6300	Economy	4000.00
0005434925647	6300	Economy	4000.00
0005433496773	6300	Economy	4000.00
0005434925645	6300	Economy	4000.00
0005434925648	6300	Economy	4000.00
0005434925620	6300	Economy	4000.00
0005433496798	6300	Economy	4000.00
0005434443609	6300	Economy	4000.00
0005434925628	6300	Economy	4000.00
0005434443620	6300	Economy	4000.00
0005434443607	6300	Economy	4000.00
0005434925611	6300	Economy	4000.00
0005434925627	6300	Economy	4000.00
0005434925608	6300	Economy	4000.00
0005434925643	6300	Economy	4000.00
0005433496777	6300	Economy	4000.00
0005434443621	6300	Economy	4000.00
0005434925642	6300	Economy	4000.00
0005434443615	6300	Economy	4000.00
0005434925638	6300	Economy	4000.00
0005433496772	6300	Economy	4000.00
0005433496788	6300	Economy	4000.00
0005434925640	6300	Economy	4000.00
0005433496778	6300	Economy	4000.00
0005434925616	6300	Economy	4000.00
0005434443606	6300	Economy	4000.00
0005434925614	6300	Economy	4000.00
0005433496797	6300	Economy	4000.00
0005434925646	6300	Economy	4000.00
0005433496786	6300	Economy	4000.00
0005433496785	6300	Economy	4000.00
0005434925607	6300	Economy	4000.00
0005434925621	6300	Economy	4000.00
0005434925276	20406	Business	11900.00
0005434925305	20406	Business	11900.00
0005434925361	20406	Business	11900.00
0005434925381	20406	Business	11900.00
0005434443442	20406	Business	11900.00
0005434925265	20406	Business	11900.00
0005433496629	20406	Business	11900.00
0005434443437	20406	Business	11900.00
0005433496640	20406	Business	11900.00
0005434925306	20406	Business	11900.00
0005434443488	20406	Economy	4000.00
0005434925266	20406	Economy	4000.00
0005434443436	20406	Economy	4000.00
0005434925278	20406	Economy	4000.00
0005434443486	20406	Economy	4000.00
0005433496493	20406	Economy	4000.00
0005433496571	20406	Economy	4000.00
0005434925319	20406	Economy	4000.00
0005433496501	20406	Economy	4400.00
0005434925312	20406	Economy	4400.00
0005433496569	20406	Economy	4000.00
0005434925457	20406	Economy	4000.00
0005434925311	20406	Economy	4000.00
0005434925320	20406	Economy	4000.00
0005434925360	20406	Economy	4000.00
0005434925359	20406	Economy	4000.00
0005434925412	20406	Economy	4000.00
0005434925263	20406	Economy	4000.00
0005434925341	20406	Economy	4000.00
0005433496534	20406	Economy	4000.00
0005433496625	20406	Economy	4000.00
0005434925262	20406	Economy	4000.00
0005434443455	20406	Economy	4000.00
0005434925353	20406	Economy	4000.00
0005433496478	20406	Economy	4000.00
0005434925301	20406	Economy	4000.00
0005434925340	20406	Economy	4000.00
0005434925277	20406	Economy	4000.00
0005433496479	20406	Economy	4000.00
0005434925387	20406	Economy	4000.00
0005434443449	20406	Economy	4000.00
0005433496639	20406	Economy	4000.00
0005434925358	20406	Economy	4000.00
0005434443487	20406	Economy	4000.00
0005434443472	20406	Economy	4000.00
0005434925459	20406	Economy	4000.00
0005434443443	20406	Economy	4000.00
0005434443514	20406	Economy	4000.00
0005434925253	20406	Economy	4000.00
0005434443513	20406	Economy	4000.00
0005433496582	20406	Economy	4000.00
0005434443500	20406	Economy	4000.00
0005433496528	20406	Economy	4000.00
0005433496724	20406	Economy	4000.00
0005434925458	20406	Economy	4000.00
0005433496500	20406	Economy	4000.00
0005433496590	20406	Economy	4000.00
0005434443461	20406	Economy	4000.00
0005434443477	20406	Economy	4000.00
0005434925254	20406	Economy	4000.00
0005434925304	20406	Economy	4000.00
0005433496630	20406	Economy	4000.00
0005433496568	20406	Economy	4000.00
0005434925411	20406	Economy	4000.00
0005432782896	12164	Business	41200.00
0005432782969	12164	Business	41200.00
0005435242719	12164	Business	41200.00
0005435242692	12164	Business	41200.00
0005435242713	12164	Business	41200.00
0005432782897	12164	Business	41200.00
0005435242693	12164	Business	41200.00
0005435242712	12164	Business	41200.00
0005432783016	12164	Economy	13700.00
0005432782937	12164	Economy	13700.00
0005432783025	12164	Economy	13700.00
0005435242714	12164	Economy	13700.00
0005432783023	12164	Economy	13700.00
0005432782842	12164	Economy	15100.00
0005432783247	12164	Economy	15100.00
0005432782957	12164	Economy	15100.00
0005435242709	12164	Economy	13700.00
0005432783069	12164	Economy	13700.00
0005435242703	12164	Economy	13700.00
0005432782940	12164	Economy	13700.00
0005435242707	12164	Economy	13700.00
0005435242716	12164	Economy	13700.00
0005432782917	12164	Economy	13700.00
0005435242700	12164	Economy	13700.00
0005432782951	12164	Economy	13700.00
0005432782954	12164	Economy	13700.00
0005432783106	12164	Economy	13700.00
0005432783052	12164	Economy	13700.00
0005432783134	12164	Economy	13700.00
0005432783098	12164	Economy	13700.00
0005435242697	12164	Economy	13700.00
0005432783047	12164	Economy	13700.00
0005432783077	12164	Economy	13700.00
0005432783094	12164	Economy	13700.00
0005435242711	12164	Economy	13700.00
0005435242715	12164	Economy	13700.00
0005435242702	12164	Economy	13700.00
0005432783068	12164	Economy	13700.00
0005432783099	12164	Economy	13700.00
0005432783093	12164	Economy	13700.00
0005435242696	12164	Economy	13700.00
0005432783041	12164	Economy	13700.00
0005435242699	12164	Economy	13700.00
0005432782959	12164	Economy	13700.00
0005432782852	12164	Economy	13700.00
0005435242701	12164	Economy	13700.00
0005432782941	12164	Economy	13700.00
0005432783051	12164	Economy	13700.00
0005435242710	12164	Economy	13700.00
0005432783164	12164	Economy	13700.00
0005432783046	12164	Economy	13700.00
0005435242694	12164	Economy	13700.00
0005432783013	12164	Economy	13700.00
0005435242708	12164	Economy	13700.00
0005435242717	12164	Economy	13700.00
0005435242695	12164	Economy	13700.00
0005432782949	12164	Economy	13700.00
0005432782970	12164	Economy	13700.00
0005432783087	12164	Economy	13700.00
0005435242718	12164	Economy	13700.00
0005435242704	12164	Economy	13700.00
0005435242706	12164	Economy	13700.00
0005432782950	12164	Economy	13700.00
0005432783108	12164	Economy	13700.00
0005435242705	12164	Economy	13700.00
0005432783201	12164	Economy	13700.00
0005435242698	12164	Economy	13700.00
0005435242512	15413	Business	41200.00
0005432783422	15413	Business	41200.00
0005435242457	15413	Business	41200.00
0005432783427	15413	Business	41200.00
0005435242412	15413	Business	41200.00
0005432783439	15413	Economy	13700.00
0005432783399	15413	Economy	13700.00
0005432783426	15413	Economy	13700.00
0005432783411	15413	Economy	13700.00
0005432783401	15413	Economy	13700.00
0005432783408	15413	Economy	13700.00
0005432783443	15413	Economy	13700.00
0005432783418	15413	Economy	15100.00
0005432783395	15413	Economy	15100.00
0005432783438	15413	Economy	15100.00
0005432783425	15413	Economy	15100.00
0005432783437	15413	Economy	15100.00
0005435242480	15413	Economy	13700.00
0005432783397	15413	Economy	13700.00
0005432783416	15413	Economy	13700.00
0005432783430	15413	Economy	13700.00
0005432783434	15413	Economy	13700.00
0005432783440	15413	Economy	13700.00
0005432783415	15413	Economy	13700.00
0005432783410	15413	Economy	13700.00
0005435242553	15413	Economy	13700.00
0005432783428	15413	Economy	13700.00
0005432783424	15413	Economy	13700.00
0005432783419	15413	Economy	13700.00
0005435242481	15413	Economy	13700.00
0005432783396	15413	Economy	13700.00
0005432783400	15413	Economy	13700.00
0005432783402	15413	Economy	13700.00
0005435242428	15413	Economy	13700.00
0005432783431	15413	Economy	13700.00
0005432783442	15413	Economy	13700.00
0005432783393	15413	Economy	13700.00
0005432783433	15413	Economy	13700.00
0005432783407	15413	Economy	13700.00
0005432783423	15413	Economy	13700.00
0005435242448	15413	Economy	13700.00
0005432783435	15413	Economy	13700.00
0005432783398	15413	Economy	13700.00
0005432783404	15413	Economy	13700.00
0005432783391	15413	Economy	13700.00
0005435242456	15413	Economy	13700.00
0005432783432	15413	Economy	13700.00
0005432783406	15413	Economy	13700.00
0005432783403	15413	Economy	13700.00
0005432783436	15413	Economy	13700.00
0005432783413	15413	Economy	13700.00
0005432783394	15413	Economy	13700.00
0005432783417	15413	Economy	13700.00
0005432783421	15413	Economy	13700.00
0005432783420	15413	Economy	13700.00
0005435242418	15413	Economy	13700.00
0005432783412	15413	Economy	13700.00
0005435242552	15413	Economy	13700.00
0005435242389	15413	Economy	13700.00
0005432783392	15413	Economy	13700.00
0005435242403	15413	Economy	13700.00
0005432783409	15413	Economy	13700.00
0005432783441	15413	Economy	13700.00
0005432783414	15413	Economy	13700.00
0005435242390	15413	Economy	13700.00
0005432783429	15413	Economy	13700.00
0005432783405	15413	Economy	13700.00
0005434876938	10066	Business	49700.00
0005434876677	10066	Business	49700.00
0005434876890	10066	Business	49700.00
0005434876885	10066	Business	49700.00
0005434876793	10066	Business	49700.00
0005434876785	10066	Business	49700.00
0005434876901	10066	Business	49700.00
0005434876652	10066	Business	49700.00
0005434876768	10066	Business	49700.00
0005434876914	10066	Business	49700.00
0005435913913	10066	Business	49700.00
0005434876685	10066	Business	49700.00
0005434876877	10066	Business	49700.00
0005434876959	10066	Business	49700.00
0005434876967	10066	Business	49700.00
0005434876911	10066	Business	49700.00
0005434876584	10066	Business	49700.00
0005434877197	10066	Economy	16600.00
0005434876941	10066	Economy	16600.00
0005434877018	10066	Economy	16600.00
0005434876792	10066	Economy	16600.00
0005434876870	10066	Economy	16600.00
0005434876940	10066	Economy	16600.00
0005434876946	10066	Economy	16600.00
0005434876610	10066	Economy	16600.00
0005434876569	10066	Economy	16600.00
0005435913915	10066	Economy	16600.00
0005435913922	10066	Economy	18200.00
0005434910098	10066	Economy	18200.00
0005434758852	10066	Economy	18200.00
0005434877000	10066	Economy	18200.00
0005434876567	10066	Economy	16600.00
0005434877027	10066	Economy	16600.00
0005434876939	10066	Economy	16600.00
0005434876765	10066	Economy	16600.00
0005434876869	10066	Economy	16600.00
0005434876924	10066	Economy	16600.00
0005434876912	10066	Economy	16600.00
0005434877193	10066	Economy	16600.00
0005434876664	10066	Economy	16600.00
0005434876735	10066	Economy	16600.00
0005434876619	10066	Economy	16600.00
0005434876896	10066	Economy	16600.00
0005434876718	10066	Economy	16600.00
0005434877014	10066	Economy	16600.00
0005434876802	10066	Economy	16600.00
0005434876934	10066	Economy	16600.00
0005434876724	10066	Economy	16600.00
0005434876746	10066	Economy	16600.00
0005434876657	10066	Economy	16600.00
0005434877129	10066	Economy	16600.00
0005434877143	10066	Economy	16600.00
0005434876658	10066	Economy	16600.00
0005434876726	10066	Economy	16600.00
0005435913918	10066	Economy	16600.00
0005434876921	10066	Economy	16600.00
0005434876996	10066	Economy	16600.00
0005434876745	10066	Economy	16600.00
0005434876937	10066	Economy	16600.00
0005435913921	10066	Economy	16600.00
0005434876777	10066	Economy	16600.00
0005434876860	10066	Economy	16600.00
0005434876878	10066	Economy	16600.00
0005434876935	10066	Economy	16600.00
0005434910097	10066	Economy	16600.00
0005434876796	10066	Economy	16600.00
0005434876767	10066	Economy	16600.00
0005434877007	10066	Economy	16600.00
0005434876861	10066	Economy	16600.00
0005435913914	10066	Economy	16600.00
0005435913912	10066	Economy	16600.00
0005435913923	10066	Economy	16600.00
0005434758867	10066	Economy	16600.00
0005435913919	10066	Economy	16600.00
0005434876801	10066	Economy	16600.00
0005434876836	10066	Economy	16600.00
0005434876725	10066	Economy	16600.00
0005434876690	10066	Economy	16600.00
0005435913920	10066	Economy	16600.00
0005434910096	10066	Economy	16600.00
0005435913916	10066	Economy	16600.00
0005434876766	10066	Economy	16600.00
0005434876968	10066	Economy	16600.00
0005434876913	10066	Economy	16600.00
0005434876868	10066	Economy	16600.00
0005434877001	10066	Economy	16600.00
0005434876958	10066	Economy	16600.00
0005434876697	10066	Economy	16600.00
0005434876891	10066	Economy	16600.00
0005434876862	10066	Economy	16600.00
0005434910095	10066	Economy	16600.00
0005435913917	10066	Economy	16600.00
0005434876879	10066	Economy	16600.00
0005434877142	10066	Economy	16600.00
0005434877638	14616	Business	49700.00
0005434877694	14616	Business	49700.00
0005434877683	14616	Business	49700.00
0005434877696	14616	Business	49700.00
0005434877648	14616	Business	49700.00
0005434877691	14616	Business	49700.00
0005434877673	14616	Business	49700.00
0005434877674	14616	Business	49700.00
0005434877649	14616	Business	49700.00
0005434877669	14616	Business	49700.00
0005434877709	14616	Business	49700.00
0005434877716	14616	Business	49700.00
0005434877637	14616	Business	49700.00
0005434877641	14616	Business	49700.00
0005434877645	14616	Business	49700.00
0005434877697	14616	Business	49700.00
0005434877657	14616	Business	49700.00
0005434877702	14616	Business	49700.00
0005434877640	14616	Economy	16600.00
0005434877699	14616	Economy	16600.00
0005434877704	14616	Economy	16600.00
0005434758878	14616	Economy	16600.00
0005434877670	14616	Economy	16600.00
0005434877678	14616	Economy	16600.00
0005434877650	14616	Economy	16600.00
0005434877695	14616	Economy	16600.00
0005434877661	14616	Economy	16600.00
0005434877705	14616	Economy	16600.00
0005434877676	14616	Economy	16600.00
0005434877627	14616	Economy	16600.00
0005435913850	14616	Economy	18200.00
0005434877701	14616	Economy	18200.00
0005434877700	14616	Economy	18200.00
0005434877662	14616	Economy	18200.00
0005434877642	14616	Economy	16600.00
0005434877710	14616	Economy	16600.00
0005434877632	14616	Economy	16600.00
0005434877646	14616	Economy	16600.00
0005434910087	14616	Economy	16600.00
0005434877671	14616	Economy	16600.00
0005434877714	14616	Economy	16600.00
0005435913854	14616	Economy	16600.00
0005434877652	14616	Economy	16600.00
0005434758879	14616	Economy	16600.00
0005434877659	14616	Economy	16600.00
0005434877677	14616	Economy	16600.00
0005434877629	14616	Economy	16600.00
0005434877625	14616	Economy	16600.00
0005434877684	14616	Economy	16600.00
0005434877668	14616	Economy	16600.00
0005434877656	14616	Economy	16600.00
0005434877655	14616	Economy	16600.00
0005434877626	14616	Economy	16600.00
0005434877663	14616	Economy	16600.00
0005434877689	14616	Economy	16600.00
0005434877692	14616	Economy	16600.00
0005434877708	14616	Economy	16600.00
0005434877682	14616	Economy	16600.00
0005434877712	14616	Economy	16600.00
0005434877654	14616	Economy	16600.00
0005434877633	14616	Economy	16600.00
0005434877693	14616	Economy	16600.00
0005434877647	14616	Economy	16600.00
0005434877703	14616	Economy	16600.00
0005434877622	14616	Economy	16600.00
0005435913857	14616	Economy	16600.00
0005434877706	14616	Economy	16600.00
0005434877707	14616	Economy	16600.00
0005434877639	14616	Economy	16600.00
0005434877630	14616	Economy	16600.00
0005434877658	14616	Economy	16600.00
0005434877711	14616	Economy	16600.00
0005435913853	14616	Economy	16600.00
0005434877679	14616	Economy	16600.00
0005435913855	14616	Economy	16600.00
0005434877664	14616	Economy	16600.00
0005434877687	14616	Economy	16600.00
0005434877685	14616	Economy	16600.00
0005434877631	14616	Economy	16600.00
0005434877628	14616	Economy	16600.00
0005434877660	14616	Economy	16600.00
0005434877690	14616	Economy	16600.00
0005434910086	14616	Economy	16600.00
0005434877643	14616	Economy	16600.00
0005434877688	14616	Economy	16600.00
0005434877621	14616	Economy	16600.00
0005434877713	14616	Economy	16600.00
0005434877624	14616	Economy	16600.00
0005434877665	14616	Economy	16600.00
0005434877653	14616	Economy	16600.00
0005434877666	14616	Economy	16600.00
0005434877680	14616	Economy	16600.00
0005434877644	14616	Economy	16600.00
0005434877651	14616	Economy	16600.00
0005434877623	14616	Economy	16600.00
0005434877698	14616	Economy	16600.00
0005434877672	14616	Economy	16600.00
0005434877667	14616	Economy	16600.00
0005434877675	14616	Economy	16600.00
0005434877681	14616	Economy	16600.00
0005434877686	14616	Economy	16600.00
0005434877634	14616	Economy	16600.00
0005434877715	14616	Economy	16600.00
0005434877636	14616	Economy	16600.00
0005434877635	14616	Economy	16600.00
0005435660065	9242	Economy	22400.00
0005435660074	9242	Economy	22400.00
0005435660067	9242	Economy	20300.00
0005434251815	9242	Economy	20300.00
0005434251816	9242	Economy	20300.00
0005434251837	9242	Economy	20300.00
0005434251834	9242	Economy	20300.00
0005435660075	9242	Economy	20300.00
0005435660070	9242	Economy	20300.00
0005434251836	9242	Economy	20300.00
0005435660072	9242	Economy	20300.00
0005434251817	9242	Economy	20300.00
0005435660063	9242	Economy	20300.00
0005434251833	9242	Economy	20300.00
0005434251828	9242	Economy	20300.00
0005435660073	9242	Economy	20300.00
0005435660069	9242	Economy	20300.00
0005434251838	9242	Economy	20300.00
0005435660068	9242	Economy	20300.00
0005435660064	9242	Economy	20300.00
0005435660066	9242	Economy	20300.00
0005435660071	9242	Economy	20300.00
0005434251902	24650	Economy	22400.00
0005434251907	24650	Economy	22400.00
0005435659949	24650	Economy	20300.00
0005434251909	24650	Economy	20300.00
0005435659962	24650	Economy	20300.00
0005435659972	24650	Economy	20300.00
0005435659991	24650	Economy	20300.00
0005435660001	24650	Economy	20300.00
0005435659979	24650	Economy	20300.00
0005434251911	24650	Economy	20300.00
0005435659967	24650	Economy	20300.00
0005434251904	24650	Economy	20300.00
0005435659957	24650	Economy	20300.00
0005435659978	24650	Economy	20300.00
0005435659976	24650	Economy	20300.00
0005435659999	24650	Economy	20300.00
0005435659966	24650	Economy	20300.00
0005434251905	24650	Economy	20300.00
0005434251903	24650	Economy	20300.00
0005434251906	24650	Economy	20300.00
0005435659958	24650	Economy	20300.00
0005434251908	24650	Economy	20300.00
0005434251910	24650	Economy	20300.00
0005435659980	24650	Economy	20300.00
0005433680295	2800	Business	33000.00
0005432966543	2800	Business	33000.00
0005433680254	2800	Business	33000.00
0005432222747	2800	Business	33000.00
0005432222752	2800	Business	33000.00
0005433680258	2800	Business	33000.00
0005433680267	2800	Business	33000.00
0005433680262	2800	Business	33000.00
0005433680274	2800	Business	33000.00
0005433680247	2800	Business	33000.00
0005433680271	2800	Business	33000.00
0005432222749	2800	Economy	11000.00
0005433680263	2800	Economy	11000.00
0005433680269	2800	Economy	11000.00
0005432966508	2800	Economy	11000.00
0005433680261	2800	Economy	11000.00
0005432966567	2800	Economy	11000.00
0005433680290	2800	Economy	11000.00
0005433680265	2800	Economy	11000.00
0005432966541	2800	Economy	12100.00
0005433680283	2800	Economy	12100.00
0005432966500	2800	Economy	12100.00
0005433684406	2800	Economy	12100.00
0005432966533	2800	Economy	11000.00
0005433680249	2800	Economy	11000.00
0005433680277	2800	Economy	11000.00
0005433680251	2800	Economy	11000.00
0005433680248	2800	Economy	11000.00
0005433680268	2800	Economy	11000.00
0005433680255	2800	Economy	11000.00
0005433680276	2800	Economy	11000.00
0005433680256	2800	Economy	11000.00
0005433680284	2800	Economy	11000.00
0005432222748	2800	Economy	11000.00
0005432966613	2800	Economy	11000.00
0005432966568	2800	Economy	11000.00
0005432966601	2800	Economy	11000.00
0005432222750	2800	Economy	11000.00
0005433680281	2800	Economy	11000.00
0005433680291	2800	Economy	11000.00
0005433680252	2800	Economy	11000.00
0005433680289	2800	Economy	11000.00
0005433680253	2800	Economy	11000.00
0005433680273	2800	Economy	11000.00
0005433680275	2800	Economy	11000.00
0005433680282	2800	Economy	11000.00
0005432966674	2800	Economy	11000.00
0005433680292	2800	Economy	11000.00
0005433680250	2800	Economy	11000.00
0005432966501	2800	Economy	11000.00
0005432966487	2800	Economy	11000.00
0005433680264	2800	Economy	11000.00
0005433680272	2800	Economy	11000.00
0005433680293	2800	Economy	11000.00
0005433680266	2800	Economy	11000.00
0005433680259	2800	Economy	11000.00
0005433680270	2800	Economy	11000.00
0005432966542	2800	Economy	11000.00
0005432966538	2800	Economy	11000.00
0005432966488	2800	Economy	11000.00
0005432966603	2800	Economy	11000.00
0005432966489	2800	Economy	11000.00
0005433680286	2800	Economy	11000.00
0005433680280	2800	Economy	11000.00
0005433680294	2800	Economy	11000.00
0005433680288	2800	Economy	11000.00
0005433680287	2800	Economy	11000.00
0005432222751	2800	Economy	11000.00
0005433680257	2800	Economy	11000.00
0005433680279	2800	Economy	11000.00
0005432966546	2800	Economy	11000.00
0005433680285	2800	Economy	11000.00
0005432966602	2800	Economy	11000.00
0005433680278	2800	Economy	11000.00
0005433680260	2800	Economy	11000.00
0005432966534	2800	Economy	11000.00
0005432966770	29147	Business	33000.00
0005433679881	29147	Business	33000.00
0005432966782	29147	Business	33000.00
0005432966772	29147	Business	33000.00
0005432966780	29147	Business	33000.00
0005433679889	29147	Business	33000.00
0005432966776	29147	Business	33000.00
0005432966785	29147	Business	33000.00
0005432966768	29147	Business	33000.00
0005433679992	29147	Economy	11000.00
0005432966786	29147	Economy	11000.00
0005433679962	29147	Economy	11000.00
0005433679926	29147	Economy	11000.00
0005433679741	29147	Economy	11000.00
0005432966773	29147	Economy	11000.00
0005433679740	29147	Economy	11000.00
0005433679942	29147	Economy	11000.00
0005433680113	29147	Economy	12100.00
0005432966771	29147	Economy	12100.00
0005433679793	29147	Economy	12100.00
0005432966790	29147	Economy	11000.00
0005433680067	29147	Economy	11000.00
0005432966775	29147	Economy	11000.00
0005432966779	29147	Economy	11000.00
0005433679747	29147	Economy	11000.00
0005433679961	29147	Economy	11000.00
0005433679927	29147	Economy	11000.00
0005432966792	29147	Economy	11000.00
0005432966774	29147	Economy	11000.00
0005433679877	29147	Economy	11000.00
0005433680191	29147	Economy	11000.00
0005432966787	29147	Economy	11000.00
0005433679853	29147	Economy	11000.00
0005432966778	29147	Economy	11000.00
0005433679817	29147	Economy	11000.00
0005433679880	29147	Economy	11000.00
0005433680005	29147	Economy	11000.00
0005432966777	29147	Economy	11000.00
0005432966788	29147	Economy	11000.00
0005433680135	29147	Economy	11000.00
0005433679876	29147	Economy	11000.00
0005433680049	29147	Economy	11000.00
0005432005195	29147	Economy	11000.00
0005432966789	29147	Economy	11000.00
0005432005196	29147	Economy	11000.00
0005433680066	29147	Economy	11000.00
0005433679794	29147	Economy	11000.00
0005432966791	29147	Economy	11000.00
0005432005197	29147	Economy	11000.00
0005433679956	29147	Economy	11000.00
0005433679854	29147	Economy	11000.00
0005433679792	29147	Economy	11000.00
0005433679949	29147	Economy	11000.00
0005433679921	29147	Economy	11000.00
0005433679875	29147	Economy	11000.00
0005433679864	29147	Economy	11000.00
0005432966783	29147	Economy	11000.00
0005433679842	29147	Economy	11000.00
0005432966784	29147	Economy	11000.00
0005432966781	29147	Economy	11000.00
0005433679728	29147	Economy	11000.00
0005433679879	29147	Economy	11000.00
0005433680047	29147	Economy	11000.00
0005432966769	29147	Economy	11000.00
0005433633564	9326	Business	132900.00
0005434163483	9326	Business	132900.00
0005433614141	9326	Business	132900.00
0005433614204	9326	Business	132900.00
0005433614139	9326	Business	132900.00
0005433614138	9326	Business	132900.00
0005433614140	9326	Business	132900.00
0005433614151	9326	Business	132900.00
0005433614153	9326	Business	132900.00
0005433633585	9326	Business	132900.00
0005433614182	9326	Business	132900.00
0005433614170	9326	Business	132900.00
0005433614158	9326	Business	132900.00
0005432145097	9326	Business	132900.00
0005433577721	9326	Business	132900.00
0005433614199	9326	Business	132900.00
0005433633568	9326	Business	132900.00
0005433577723	9326	Business	132900.00
0005433614167	9326	Business	132900.00
0005433577724	9326	Business	132900.00
0005434269067	9326	Business	132900.00
0005433614174	9326	Business	132900.00
0005434163498	9326	Business	132900.00
0005433614168	9326	Business	132900.00
0005434269069	9326	Business	132900.00
0005433633595	9326	Business	132900.00
0005433614198	9326	Business	132900.00
0005432756826	9326	Business	132900.00
0005433614150	9326	Economy	48700.00
0005433614162	9326	Economy	48700.00
0005433577715	9326	Economy	48700.00
0005432755055	9326	Economy	48700.00
0005433614136	9326	Economy	48700.00
0005433633576	9326	Economy	48700.00
0005433614137	9326	Economy	44300.00
0005433633584	9326	Economy	44300.00
0005433633579	9326	Economy	44300.00
0005433614164	9326	Economy	44300.00
0005433633580	9326	Economy	44300.00
0005433577726	9326	Economy	44300.00
0005433577722	9326	Economy	44300.00
0005433614188	9326	Economy	44300.00
0005433633590	9326	Economy	44300.00
0005433577719	9326	Economy	44300.00
0005433577717	9326	Economy	44300.00
0005433577718	9326	Economy	44300.00
0005433614202	9326	Economy	44300.00
0005433614152	9326	Economy	44300.00
0005434269079	9326	Economy	44300.00
0005433614206	9326	Economy	44300.00
0005433614146	9326	Economy	44300.00
0005433614144	9326	Economy	44300.00
0005433614209	9326	Economy	44300.00
0005433614205	9326	Economy	44300.00
0005433614176	9326	Economy	44300.00
0005433633571	9326	Economy	44300.00
0005433614185	9326	Economy	44300.00
0005433633597	9326	Economy	44300.00
0005433633587	9326	Economy	44300.00
0005433633589	9326	Economy	44300.00
0005434269078	9326	Economy	44300.00
0005432755054	9326	Economy	44300.00
0005433614181	9326	Economy	44300.00
0005432756825	9326	Economy	44300.00
0005433633572	9326	Economy	44300.00
0005433614172	9326	Economy	44300.00
0005434163490	9326	Economy	44300.00
0005433614142	9326	Economy	44300.00
0005432755052	9326	Economy	44300.00
0005433614156	9326	Economy	44300.00
0005433614179	9326	Economy	44300.00
0005434152753	9326	Economy	44300.00
0005433614154	9326	Economy	44300.00
0005433614184	9326	Economy	44300.00
0005433614192	9326	Economy	44300.00
0005433577720	9326	Economy	44300.00
0005434163497	9326	Economy	44300.00
0005433633567	9326	Economy	44300.00
0005433614157	9326	Economy	44300.00
0005433614160	9326	Economy	44300.00
0005433614145	9326	Economy	44300.00
0005433633593	9326	Economy	44300.00
0005433614169	9326	Economy	44300.00
0005432756827	9326	Economy	44300.00
0005433614166	9326	Economy	44300.00
0005433633596	9326	Economy	44300.00
0005433614195	9326	Economy	44300.00
0005433633569	9326	Economy	48700.00
0005433614208	9326	Economy	48700.00
0005434163470	9326	Economy	48700.00
0005433577714	9326	Economy	48700.00
0005433633581	9326	Economy	48700.00
0005433633574	9326	Economy	44300.00
0005433614197	9326	Economy	44300.00
0005433614155	9326	Economy	44300.00
0005433614163	9326	Economy	48700.00
0005433633592	9326	Economy	44300.00
0005434163491	9326	Economy	44300.00
0005434163499	9326	Economy	44300.00
0005433633582	9326	Economy	44300.00
0005433614187	9326	Economy	44300.00
0005434269068	9326	Economy	44300.00
0005433633594	9326	Economy	44300.00
0005433614194	9326	Economy	44300.00
0005434163467	9326	Economy	44300.00
0005433633588	9326	Economy	44300.00
0005433614180	9326	Economy	44300.00
0005434163475	9326	Economy	44300.00
0005433614186	9326	Economy	44300.00
0005433577716	9326	Economy	44300.00
0005433614183	9326	Economy	44300.00
0005433614175	9326	Economy	44300.00
0005433614196	9326	Economy	44300.00
0005433633578	9326	Economy	44300.00
0005433633562	9326	Economy	44300.00
0005434152759	9326	Economy	44300.00
0005433633566	9326	Economy	44300.00
0005434272161	9326	Economy	44300.00
0005434272168	9326	Economy	44300.00
0005433614171	9326	Economy	44300.00
0005434152754	9326	Economy	44300.00
0005434152758	9326	Economy	44300.00
0005433614149	9326	Economy	44300.00
0005433633577	9326	Economy	44300.00
0005433614147	9326	Economy	44300.00
0005432145096	9326	Economy	44300.00
0005433633573	9326	Economy	44300.00
0005434153526	9326	Economy	44300.00
0005432145098	9326	Economy	44300.00
0005434163517	9326	Economy	44300.00
0005433614191	9326	Economy	44300.00
0005433577713	9326	Economy	44300.00
0005433614165	9326	Economy	44300.00
0005433633583	9326	Economy	44300.00
0005433633598	9326	Economy	44300.00
0005433577725	9326	Economy	44300.00
0005433614203	9326	Economy	44300.00
0005433633586	9326	Economy	44300.00
0005433614200	9326	Economy	44300.00
0005433633575	9326	Economy	44300.00
0005433614161	9326	Economy	44300.00
0005433614189	9326	Economy	44300.00
0005433614190	9326	Economy	44300.00
0005432755053	9326	Economy	44300.00
0005433614135	9326	Economy	44300.00
0005433633563	9326	Economy	44300.00
0005433614207	9326	Economy	44300.00
0005433614148	9326	Economy	44300.00
0005433614178	9326	Economy	44300.00
0005433633570	9326	Economy	44300.00
0005433633591	9326	Economy	44300.00
0005433614201	9326	Economy	44300.00
0005433614173	9326	Economy	44300.00
0005433614159	9326	Economy	44300.00
0005433633565	9326	Economy	44300.00
0005433614177	9326	Economy	44300.00
0005433614193	9326	Economy	44300.00
0005433614143	9326	Economy	44300.00
0005433613718	25217	Business	132900.00
0005433577578	25217	Business	132900.00
0005433613640	25217	Business	132900.00
0005433613474	25217	Business	132900.00
0005434163568	25217	Business	132900.00
0005433633268	25217	Business	132900.00
0005433633360	25217	Business	132900.00
0005433633265	25217	Business	132900.00
0005433613463	25217	Business	132900.00
0005434163564	25217	Business	132900.00
0005433613717	25217	Business	132900.00
0005433613679	25217	Business	132900.00
0005434163566	25217	Business	132900.00
0005433613449	25217	Business	132900.00
0005433613800	25217	Business	132900.00
0005433633263	25217	Business	132900.00
0005433633267	25217	Business	132900.00
0005433613707	25217	Business	132900.00
0005434163562	25217	Business	132900.00
0005433613784	25217	Business	132900.00
0005433613446	25217	Business	132900.00
0005433613753	25217	Business	132900.00
0005433633351	25217	Economy	48700.00
0005433613826	25217	Economy	48700.00
0005433613411	25217	Economy	48700.00
0005433633258	25217	Economy	44300.00
0005433633237	25217	Economy	44300.00
0005433613473	25217	Economy	44300.00
0005433613639	25217	Economy	44300.00
0005433633294	25217	Economy	44300.00
0005434273065	25217	Economy	44300.00
0005433633293	25217	Economy	44300.00
0005433613514	25217	Economy	44300.00
0005434163563	25217	Economy	44300.00
0005433633387	25217	Economy	44300.00
0005433633264	25217	Economy	44300.00
0005433633228	25217	Economy	44300.00
0005433577564	25217	Economy	44300.00
0005434163569	25217	Economy	44300.00
0005433633239	25217	Economy	44300.00
0005433613465	25217	Economy	44300.00
0005433613549	25217	Economy	44300.00
0005433613708	25217	Economy	44300.00
0005433613500	25217	Economy	44300.00
0005433633280	25217	Economy	44300.00
0005433577577	25217	Economy	44300.00
0005433613488	25217	Economy	44300.00
0005433613669	25217	Economy	44300.00
0005433633349	25217	Economy	44300.00
0005433613682	25217	Economy	44300.00
0005433633261	25217	Economy	44300.00
0005433613403	25217	Economy	44300.00
0005433633260	25217	Economy	44300.00
0005433613557	25217	Economy	44300.00
0005433613659	25217	Economy	44300.00
0005433633343	25217	Economy	44300.00
0005433633262	25217	Economy	44300.00
0005433633350	25217	Economy	44300.00
0005433577623	25217	Economy	44300.00
0005433613709	25217	Economy	44300.00
0005433633229	25217	Economy	44300.00
0005434163565	25217	Economy	44300.00
0005433613541	25217	Economy	44300.00
0005433613404	25217	Economy	44300.00
0005434163560	25217	Economy	44300.00
0005433577594	25217	Economy	44300.00
0005433633310	25217	Economy	44300.00
0005433577629	25217	Economy	44300.00
0005433613422	25217	Economy	44300.00
0005433613681	25217	Economy	44300.00
0005433577585	25217	Economy	44300.00
0005433613481	25217	Economy	48700.00
0005433613528	25217	Economy	48700.00
0005433613579	25217	Economy	48700.00
0005433613542	25217	Economy	48700.00
0005433633259	25217	Economy	44300.00
0005434163570	25217	Economy	44300.00
0005433613751	25217	Economy	44300.00
0005433633311	25217	Economy	44300.00
0005433613470	25217	Economy	44300.00
0005433633238	25217	Economy	48700.00
0005433613628	25217	Economy	44300.00
0005434163567	25217	Economy	44300.00
0005433613641	25217	Economy	44300.00
0005433613475	25217	Economy	44300.00
0005433613821	25217	Economy	44300.00
0005433633300	25217	Economy	44300.00
0005433613425	25217	Economy	44300.00
0005433613543	25217	Economy	44300.00
0005433613501	25217	Economy	44300.00
0005433577637	25217	Economy	44300.00
0005433633331	25217	Economy	44300.00
0005433613400	25217	Economy	44300.00
0005433613788	25217	Economy	44300.00
0005433613489	25217	Economy	44300.00
0005433613402	25217	Economy	44300.00
0005433613401	25217	Economy	44300.00
0005433613635	25217	Economy	44300.00
0005433633364	25217	Economy	44300.00
0005433633384	25217	Economy	44300.00
0005433633356	25217	Economy	44300.00
0005434272180	25217	Economy	44300.00
0005433633266	25217	Economy	44300.00
0005433613513	25217	Economy	44300.00
0005433613445	25217	Economy	44300.00
0005433633348	25217	Economy	44300.00
0005433613450	25217	Economy	44300.00
0005433613458	25217	Economy	44300.00
0005433613595	25217	Economy	44300.00
0005433633298	25217	Economy	44300.00
0005433613654	25217	Economy	44300.00
0005433577617	25217	Economy	44300.00
0005433613550	25217	Economy	44300.00
0005433613576	25217	Economy	44300.00
0005433613556	25217	Economy	44300.00
0005433613754	25217	Economy	44300.00
0005433577653	25217	Economy	44300.00
0005433613577	25217	Economy	44300.00
0005434273066	25217	Economy	44300.00
0005433613733	25217	Economy	44300.00
0005433613634	25217	Economy	44300.00
0005433577596	25217	Economy	44300.00
0005433613760	25217	Economy	44300.00
0005433613560	25217	Economy	44300.00
0005433613396	25217	Economy	44300.00
0005433613457	25217	Economy	44300.00
0005433633326	25217	Economy	44300.00
0005434163561	25217	Economy	44300.00
0005433613769	25217	Economy	44300.00
0005433613578	25217	Economy	44300.00
0005433633304	25217	Economy	44300.00
0005433633325	25217	Economy	44300.00
0005433613759	25217	Economy	44300.00
0005433613783	25217	Economy	44300.00
0005433613476	25217	Economy	44300.00
0005433577624	25217	Economy	44300.00
0005435856154	4216	Business	193100.00
0005435947049	4216	Business	193100.00
0005432184934	4216	Business	193100.00
0005435947047	4216	Business	193100.00
0005434271285	4216	Business	193100.00
0005432184932	4216	Economy	64400.00
0005435856167	4216	Economy	64400.00
0005435947005	4216	Economy	64400.00
0005435856141	4216	Economy	64400.00
0005435856153	4216	Economy	64400.00
0005432571266	4216	Economy	64400.00
0005432571273	4216	Economy	64400.00
0005435946999	4216	Economy	64400.00
0005435947055	4216	Economy	64400.00
0005435986717	4216	Economy	64400.00
0005435947056	4216	Economy	64400.00
0005432571274	4216	Economy	64400.00
0005435986716	4216	Economy	64400.00
0005432184935	4216	Economy	64400.00
0005435947044	4216	Economy	64400.00
0005435947094	4216	Economy	70800.00
0005434271284	4216	Economy	64400.00
0005435947032	4216	Economy	64400.00
0005435947099	4216	Economy	64400.00
0005435947014	4216	Economy	64400.00
0005432184933	4216	Economy	64400.00
0005435947000	4216	Economy	64400.00
0005435947035	4216	Economy	64400.00
0005435947093	4216	Economy	64400.00
0005435947048	4216	Economy	64400.00
0005435947062	4216	Economy	64400.00
0005434271275	4216	Economy	64400.00
0005435856139	4216	Economy	64400.00
0005435947034	4216	Economy	64400.00
0005435947013	4216	Economy	64400.00
0005435856140	4216	Economy	64400.00
0005435856138	4216	Economy	64400.00
0005435856179	26593	Business	193100.00
0005435986654	26593	Business	193100.00
0005435947165	26593	Business	193100.00
0005435986661	26593	Business	193100.00
0005435947167	26593	Business	193100.00
0005432571302	26593	Business	193100.00
0005435947170	26593	Economy	70800.00
0005435947173	26593	Economy	64400.00
0005435947166	26593	Economy	64400.00
0005435947161	26593	Economy	64400.00
0005432571300	26593	Economy	64400.00
0005435787343	26593	Economy	64400.00
0005432571299	26593	Economy	64400.00
0005435856180	26593	Economy	64400.00
0005435947164	26593	Economy	64400.00
0005435986663	26593	Economy	64400.00
0005435947163	26593	Economy	64400.00
0005435947171	26593	Economy	64400.00
0005435986660	26593	Economy	64400.00
0005435787342	26593	Economy	64400.00
0005435856178	26593	Economy	64400.00
0005432571301	26593	Economy	64400.00
0005435787341	26593	Economy	64400.00
0005435947162	26593	Economy	70800.00
0005435947160	26593	Economy	64400.00
0005435856177	26593	Economy	64400.00
0005435947169	26593	Economy	64400.00
0005435947168	26593	Economy	64400.00
0005435947174	26593	Economy	64400.00
0005435947172	26593	Economy	64400.00
0005433568695	308	Business	21500.00
0005433074202	308	Business	21500.00
0005433568697	308	Business	21500.00
0005433134080	308	Business	21500.00
0005433568693	308	Business	21500.00
0005432947969	308	Business	21500.00
0005433568707	308	Business	21500.00
0005433074337	308	Business	21500.00
0005432947951	308	Business	21500.00
0005433568714	308	Business	21500.00
0005433134075	308	Business	21500.00
0005433568709	308	Business	21500.00
0005433568730	308	Business	21500.00
0005433074272	308	Business	21500.00
0005433074240	308	Business	21500.00
0005433074338	308	Business	21500.00
0005433074359	308	Business	21500.00
0005433134066	308	Business	21500.00
0005433568684	308	Business	21500.00
0005433568722	308	Business	21500.00
0005432947780	308	Business	21500.00
0005433568712	308	Business	21500.00
0005433134097	308	Business	21500.00
0005432238902	308	Business	21500.00
0005433568687	308	Economy	7900.00
0005432947921	308	Business	21500.00
0005432238898	308	Economy	7900.00
0005433568731	308	Economy	7900.00
0005432947816	308	Economy	7900.00
0005432947832	308	Economy	7200.00
0005432948008	308	Economy	7200.00
0005432947767	308	Economy	7200.00
0005433568708	308	Economy	7200.00
0005433074197	308	Economy	7200.00
0005433568728	308	Economy	7200.00
0005432947901	308	Economy	7200.00
0005432947866	308	Economy	7200.00
0005433074320	308	Economy	7200.00
0005432238903	308	Economy	7200.00
0005432947970	308	Economy	7200.00
0005433074317	308	Economy	7200.00
0005432947802	308	Economy	7200.00
0005433568681	308	Economy	7200.00
0005432947875	308	Economy	7200.00
0005432947924	308	Economy	7200.00
0005433568700	308	Economy	7200.00
0005433568706	308	Economy	7200.00
0005432947918	308	Economy	7200.00
0005433568736	308	Economy	7200.00
0005433074392	308	Economy	7200.00
0005433074374	308	Economy	7200.00
0005433568710	308	Economy	7200.00
0005433074393	308	Economy	7200.00
0005432238899	308	Economy	7200.00
0005433568725	308	Economy	7200.00
0005433074324	308	Economy	7200.00
0005432947911	308	Economy	7200.00
0005432947923	308	Economy	7200.00
0005433074383	308	Economy	7200.00
0005432947848	308	Economy	7200.00
0005433568727	308	Economy	7200.00
0005433568685	308	Economy	7200.00
0005433568691	308	Economy	7200.00
0005433134069	308	Economy	7200.00
0005432947902	308	Economy	7200.00
0005432947922	308	Economy	7200.00
0005433568680	308	Economy	7200.00
0005433568711	308	Economy	7200.00
0005433129204	308	Economy	7200.00
0005432947768	308	Economy	7200.00
0005433568688	308	Economy	7200.00
0005433074325	308	Economy	7200.00
0005433134078	308	Economy	7200.00
0005433568726	308	Economy	7200.00
0005433568689	308	Economy	7200.00
0005433568732	308	Economy	7200.00
0005432947781	308	Economy	7200.00
0005432947828	308	Economy	7200.00
0005433568698	308	Economy	7200.00
0005432947815	308	Economy	7200.00
0005433568694	308	Economy	7200.00
0005432238900	308	Economy	7200.00
0005433568682	308	Economy	7200.00
0005432947950	308	Economy	7200.00
0005433074364	308	Economy	7200.00
0005433074349	308	Economy	7200.00
0005433134068	308	Economy	7900.00
0005433568704	308	Economy	7900.00
0005432238897	308	Economy	7900.00
0005433568716	308	Economy	7900.00
0005433568699	308	Economy	7200.00
0005433074309	308	Economy	7200.00
0005433568690	308	Economy	7200.00
0005432947766	308	Economy	7900.00
0005432947801	308	Economy	7200.00
0005433568720	308	Economy	7200.00
0005433568696	308	Economy	7200.00
0005433568692	308	Economy	7200.00
0005432947904	308	Economy	7200.00
0005432947844	308	Economy	7200.00
0005433568729	308	Economy	7200.00
0005432947820	308	Economy	7200.00
0005432947822	308	Economy	7200.00
0005433134063	308	Economy	7200.00
0005432947814	308	Economy	7200.00
0005432238901	308	Economy	7200.00
0005433568715	308	Economy	7200.00
0005432947831	308	Economy	7200.00
0005433568703	308	Economy	7200.00
0005432947863	308	Economy	7200.00
0005432947870	308	Economy	7200.00
0005433568702	308	Economy	7200.00
0005433074228	308	Economy	7200.00
0005433568723	308	Economy	7200.00
0005433568721	308	Economy	7200.00
0005432947900	308	Economy	7200.00
0005433134067	308	Economy	7200.00
0005432947871	308	Economy	7200.00
0005432947952	308	Economy	7200.00
0005433568701	308	Economy	7200.00
0005432948009	308	Economy	7200.00
0005432947845	308	Economy	7200.00
0005433568718	308	Economy	7200.00
0005433568734	308	Economy	7200.00
0005432947813	308	Economy	7200.00
0005433568724	308	Economy	7200.00
0005432947885	308	Economy	7200.00
0005433074348	308	Economy	7200.00
0005433074329	308	Economy	7200.00
0005433568686	308	Economy	7200.00
0005433568717	308	Economy	7200.00
0005433568705	308	Economy	7200.00
0005433568733	308	Economy	7200.00
0005433074232	308	Economy	7200.00
0005433568683	308	Economy	7200.00
0005433568735	308	Economy	7200.00
0005433074239	308	Economy	7200.00
0005433568713	308	Economy	7200.00
0005432948082	308	Economy	7200.00
0005433074367	308	Economy	7200.00
0005433134074	308	Economy	7200.00
0005433074227	308	Economy	7200.00
0005432947782	308	Economy	7200.00
0005433568719	308	Economy	7200.00
0005433129205	308	Economy	7200.00
0005433568737	308	Economy	7200.00
0005433074382	308	Economy	7200.00
0005433129210	308	Economy	7200.00
0005432947929	308	Economy	7200.00
0005432948191	11585	Business	21500.00
0005433568218	11585	Business	21500.00
0005433074532	11585	Business	21500.00
0005432948195	11585	Business	21500.00
0005432948212	11585	Business	21500.00
0005433568016	11585	Business	21500.00
0005432948211	11585	Business	21500.00
0005433568031	11585	Business	21500.00
0005433568058	11585	Business	21500.00
0005433074528	11585	Business	21500.00
0005433568121	11585	Business	21500.00
0005433568183	11585	Business	21500.00
0005433074540	11585	Business	21500.00
0005433568134	11585	Business	21500.00
0005433074534	11585	Business	21500.00
0005433074541	11585	Business	21500.00
0005433568018	11585	Business	21500.00
0005433134108	11585	Business	21500.00
0005432948207	11585	Business	21500.00
0005433568041	11585	Business	21500.00
0005433568215	11585	Business	21500.00
0005433134109	11585	Business	21500.00
0005433568104	11585	Business	21500.00
0005433074531	11585	Business	21500.00
0005433568059	11585	Economy	7900.00
0005432948200	11585	Economy	7900.00
0005433131678	11585	Economy	7900.00
0005433568198	11585	Economy	7200.00
0005433074535	11585	Economy	7200.00
0005433568098	11585	Economy	7200.00
0005433074521	11585	Economy	7200.00
0005433568184	11585	Economy	7200.00
0005433568063	11585	Economy	7200.00
0005433131681	11585	Economy	7200.00
0005432948184	11585	Economy	7200.00
0005433568053	11585	Economy	7200.00
0005432948190	11585	Economy	7200.00
0005432948202	11585	Economy	7200.00
0005432192301	11585	Economy	7200.00
0005433568159	11585	Economy	7200.00
0005433074519	11585	Economy	7200.00
0005433568108	11585	Economy	7200.00
0005433074533	11585	Economy	7200.00
0005433074536	11585	Economy	7200.00
0005432948215	11585	Economy	7200.00
0005432948217	11585	Economy	7200.00
0005433568182	11585	Economy	7200.00
0005432948204	11585	Economy	7200.00
0005432948196	11585	Economy	7200.00
0005433074537	11585	Economy	7200.00
0005432948221	11585	Economy	7200.00
0005433568204	11585	Economy	7200.00
0005433568186	11585	Economy	7200.00
0005433568162	11585	Economy	7200.00
0005433568029	11585	Economy	7200.00
0005433568256	11585	Economy	7200.00
0005433568066	11585	Economy	7200.00
0005433568028	11585	Economy	7200.00
0005432948194	11585	Economy	7200.00
0005432948218	11585	Economy	7200.00
0005433568217	11585	Economy	7200.00
0005433074520	11585	Economy	7200.00
0005433131682	11585	Economy	7200.00
0005433074529	11585	Economy	7200.00
0005433074538	11585	Economy	7200.00
0005432948197	11585	Economy	7200.00
0005433131683	11585	Economy	7200.00
0005433568097	11585	Economy	7200.00
0005432192300	11585	Economy	7200.00
0005432948192	11585	Economy	7200.00
0005433131680	11585	Economy	7200.00
0005433568224	11585	Economy	7900.00
0005433074539	11585	Economy	7900.00
0005433131679	11585	Economy	7900.00
0005433134111	11585	Economy	7900.00
0005433074543	11585	Economy	7200.00
0005433568096	11585	Economy	7200.00
0005433074525	11585	Economy	7200.00
0005433568101	11585	Economy	7200.00
0005432948219	11585	Economy	7900.00
0005433074524	11585	Economy	7200.00
0005433568120	11585	Economy	7200.00
0005432948199	11585	Economy	7200.00
0005432948181	11585	Economy	7200.00
0005433074542	11585	Economy	7200.00
0005433568019	11585	Economy	7200.00
0005432948209	11585	Economy	7200.00
0005432948187	11585	Economy	7200.00
0005432948203	11585	Economy	7200.00
0005433568160	11585	Economy	7200.00
0005433568099	11585	Economy	7200.00
0005432948216	11585	Economy	7200.00
0005433568179	11585	Economy	7200.00
0005433568140	11585	Economy	7200.00
0005433074545	11585	Economy	7200.00
0005432948193	11585	Economy	7200.00
0005433568175	11585	Economy	7200.00
0005432192299	11585	Economy	7200.00
0005432948198	11585	Economy	7200.00
0005433568103	11585	Economy	7200.00
0005433568180	11585	Economy	7200.00
0005432948189	11585	Economy	7200.00
0005433568156	11585	Economy	7200.00
0005432948220	11585	Economy	7200.00
0005433568185	11585	Economy	7200.00
0005433074523	11585	Economy	7200.00
0005432948183	11585	Economy	7200.00
0005432948186	11585	Economy	7200.00
0005433134110	11585	Economy	7200.00
0005433074522	11585	Economy	7200.00
0005433568030	11585	Economy	7200.00
0005433074526	11585	Economy	7200.00
0005433074530	11585	Economy	7200.00
0005432948182	11585	Economy	7200.00
0005432948206	11585	Economy	7200.00
0005433568152	11585	Economy	7200.00
0005432948213	11585	Economy	7200.00
0005432948185	11585	Economy	7200.00
0005432948210	11585	Economy	7200.00
0005432948214	11585	Economy	7200.00
0005433074527	11585	Economy	7200.00
0005432948201	11585	Economy	7200.00
0005432948208	11585	Economy	7200.00
0005432948188	11585	Economy	7200.00
0005432948205	11585	Economy	7200.00
0005433074544	11585	Economy	7200.00
0005433568048	11585	Economy	7200.00
0005433568155	11585	Economy	7200.00
0005433568015	11585	Economy	7200.00
0005433817446	9997	Economy	6300.00
0005434732931	9997	Economy	6300.00
0005433817447	9997	Economy	6300.00
0005434732932	9997	Economy	6300.00
0005434732942	9997	Economy	6300.00
0005434732940	9997	Economy	6300.00
0005433817449	9997	Economy	6300.00
0005434732930	9997	Economy	6300.00
0005433817448	9997	Economy	6300.00
0005434732962	13992	Economy	6300.00
0005434732961	13992	Economy	6300.00
0005434732959	13992	Economy	6300.00
0005434732960	13992	Economy	6300.00
0005433434315	2358	Business	184500.00
0005433753875	2358	Business	184500.00
0005432655464	2358	Business	184500.00
0005432226016	2358	Business	184500.00
0005433766615	2358	Business	184500.00
0005433753896	2358	Business	184500.00
0005432984572	2358	Business	184500.00
0005435982046	2358	Business	184500.00
0005433753870	2358	Business	184500.00
0005433434249	2358	Business	184500.00
0005433753865	2358	Business	184500.00
0005435982052	2358	Business	184500.00
0005433753893	2358	Business	184500.00
0005432984527	2358	Business	184500.00
0005435982025	2358	Business	184500.00
0005432984628	2358	Business	184500.00
0005432984604	2358	Business	184500.00
0005432655469	2358	Business	184500.00
0005433753859	2358	Business	184500.00
0005433434314	2358	Business	184500.00
0005435982036	2358	Business	184500.00
0005433434266	2358	Business	184500.00
0005433753905	2358	Business	184500.00
0005433753887	2358	Business	184500.00
0005433753878	2358	Business	184500.00
0005432300230	2358	Business	184500.00
0005435982037	2358	Business	184500.00
0005435982041	2358	Business	184500.00
0005432984560	2358	Business	184500.00
0005433753854	2358	Business	184500.00
0005432226022	2358	Economy	67700.00
0005434731108	2358	Economy	67700.00
0005432655470	2358	Economy	67700.00
0005432300226	2358	Economy	67700.00
0005435982044	2358	Economy	61500.00
0005432984509	2358	Economy	61500.00
0005433434275	2358	Economy	61500.00
0005433753879	2358	Economy	61500.00
0005433753908	2358	Economy	61500.00
0005433434313	2358	Economy	61500.00
0005432984611	2358	Economy	61500.00
0005433753864	2358	Economy	61500.00
0005432655462	2358	Economy	61500.00
0005432300228	2358	Economy	61500.00
0005432984526	2358	Economy	61500.00
0005432984645	2358	Economy	61500.00
0005433766616	2358	Economy	61500.00
0005435982032	2358	Economy	61500.00
0005434731114	2358	Economy	61500.00
0005433753907	2358	Economy	61500.00
0005433753892	2358	Economy	61500.00
0005435982042	2358	Economy	61500.00
0005433753906	2358	Economy	61500.00
0005432984571	2358	Economy	61500.00
0005433753880	2358	Economy	61500.00
0005432984685	2358	Economy	61500.00
0005432984602	2358	Economy	61500.00
0005432655465	2358	Economy	61500.00
0005433434333	2358	Economy	61500.00
0005433434251	2358	Economy	61500.00
0005433753897	2358	Economy	61500.00
0005433753868	2358	Economy	61500.00
0005432300231	2358	Economy	61500.00
0005432984591	2358	Economy	61500.00
0005432984806	2358	Economy	61500.00
0005432984630	2358	Economy	61500.00
0005433753904	2358	Economy	61500.00
0005435982047	2358	Economy	61500.00
0005432655468	2358	Economy	61500.00
0005435982029	2358	Economy	61500.00
0005433753898	2358	Economy	61500.00
0005433753866	2358	Economy	61500.00
0005433434241	2358	Economy	61500.00
0005432226020	2358	Economy	61500.00
0005432300229	2358	Economy	61500.00
0005433753909	2358	Economy	61500.00
0005435982033	2358	Economy	61500.00
0005432984622	2358	Economy	61500.00
0005433753890	2358	Economy	61500.00
0005432655460	2358	Economy	61500.00
0005433753860	2358	Economy	61500.00
0005432984711	2358	Economy	61500.00
0005435982038	2358	Economy	61500.00
0005433753867	2358	Economy	61500.00
0005433753856	2358	Economy	61500.00
0005433753872	2358	Economy	61500.00
0005435982018	2358	Economy	61500.00
0005433753901	2358	Economy	61500.00
0005433753862	2358	Economy	61500.00
0005433753883	2358	Economy	61500.00
0005433753882	2358	Economy	61500.00
0005432226017	2358	Economy	61500.00
0005432984670	2358	Economy	61500.00
0005433434317	2358	Economy	61500.00
0005435982050	2358	Economy	61500.00
0005433434267	2358	Economy	61500.00
0005433434242	2358	Economy	61500.00
0005435982040	2358	Economy	61500.00
0005433434286	2358	Economy	61500.00
0005433434330	2358	Economy	61500.00
0005432984534	2358	Economy	61500.00
0005435982019	2358	Economy	61500.00
0005433764668	2358	Economy	61500.00
0005433753871	2358	Economy	61500.00
0005432984721	2358	Economy	61500.00
0005435982028	2358	Economy	61500.00
0005432984805	2358	Economy	61500.00
0005433753873	2358	Economy	61500.00
0005433753894	2358	Economy	61500.00
0005435982045	2358	Economy	61500.00
0005433753861	2358	Economy	61500.00
0005433753855	2358	Economy	61500.00
0005432869423	2358	Economy	61500.00
0005433753903	2358	Economy	61500.00
0005433434293	2358	Economy	61500.00
0005432984500	2358	Economy	61500.00
0005435982022	2358	Economy	61500.00
0005433434320	2358	Economy	61500.00
0005432226021	2358	Economy	61500.00
0005435982035	2358	Economy	61500.00
0005433753877	2358	Economy	61500.00
0005433753863	2358	Economy	61500.00
0005432984735	2358	Economy	61500.00
0005433753899	2358	Economy	61500.00
0005433764667	2358	Economy	61500.00
0005433434336	2358	Economy	61500.00
0005433753869	2358	Economy	61500.00
0005432226018	2358	Economy	67700.00
0005435982026	2358	Economy	67700.00
0005433434335	2358	Economy	61500.00
0005433753891	2358	Economy	61500.00
0005433434312	2358	Economy	61500.00
0005435982016	2358	Economy	67700.00
0005435982017	2358	Economy	67700.00
0005435982049	2358	Economy	61500.00
0005432869422	2358	Economy	61500.00
0005435982023	2358	Economy	61500.00
0005433434287	2358	Economy	61500.00
0005433753895	2358	Economy	61500.00
0005432984658	2358	Economy	61500.00
0005434731096	2358	Economy	61500.00
0005432984659	2358	Economy	61500.00
0005432984586	2358	Economy	61500.00
0005432984516	2358	Economy	61500.00
0005435982048	2358	Economy	61500.00
0005433434250	2358	Economy	61500.00
0005432655467	2358	Economy	61500.00
0005432984510	2358	Economy	61500.00
0005433434208	2358	Economy	61500.00
0005432984613	2358	Economy	61500.00
0005432869433	2358	Economy	61500.00
0005433753857	2358	Economy	61500.00
0005433753885	2358	Economy	61500.00
0005435982039	2358	Economy	61500.00
0005432984669	2358	Economy	61500.00
0005432984631	2358	Economy	61500.00
0005433753911	2358	Economy	61500.00
0005432655461	2358	Economy	61500.00
0005435982043	2358	Economy	61500.00
0005433753858	2358	Economy	61500.00
0005433753889	2358	Economy	61500.00
0005433434298	2358	Economy	61500.00
0005433753874	2358	Economy	61500.00
0005433753910	2358	Economy	61500.00
0005433434216	2358	Economy	61500.00
0005435982027	2358	Economy	61500.00
0005433753888	2358	Economy	61500.00
0005435982053	2358	Economy	61500.00
0005433753900	2358	Economy	61500.00
0005433766618	2358	Economy	61500.00
0005433434276	2358	Economy	61500.00
0005435982015	2358	Economy	61500.00
0005433753881	2358	Economy	61500.00
0005432984743	2358	Economy	61500.00
0005432869413	2358	Economy	61500.00
0005433434321	2358	Economy	61500.00
0005433434327	2358	Economy	61500.00
0005435982021	2358	Economy	61500.00
0005435982020	2358	Economy	61500.00
0005434731115	2358	Economy	61500.00
0005432226019	2358	Economy	61500.00
0005435982031	2358	Economy	61500.00
0005432300227	2358	Economy	61500.00
0005433766617	2358	Economy	61500.00
0005433434332	2358	Economy	61500.00
0005432984712	2358	Economy	61500.00
0005433753886	2358	Economy	61500.00
0005433753876	2358	Economy	61500.00
0005432655463	2358	Economy	61500.00
0005435982034	2358	Economy	61500.00
0005433434316	2358	Economy	61500.00
0005433434331	2358	Economy	61500.00
0005433434319	2358	Economy	61500.00
0005432655466	2358	Economy	61500.00
0005433753884	2358	Economy	61500.00
0005435982030	2358	Economy	61500.00
0005435982014	2358	Economy	61500.00
0005433753902	2358	Economy	61500.00
0005432655471	2358	Economy	61500.00
0005435982051	2358	Economy	61500.00
0005435982024	2358	Economy	61500.00
0005432984573	2358	Economy	61500.00
0005432869482	26179	Business	184500.00
0005435981746	26179	Business	184500.00
0005433766590	26179	Business	184500.00
0005433753463	26179	Business	184500.00
0005434731147	26179	Business	184500.00
0005433434522	26179	Business	184500.00
0005435981515	26179	Business	184500.00
0005433753552	26179	Business	184500.00
0005432049443	26179	Business	184500.00
0005432051109	26179	Business	184500.00
0005432049441	26179	Business	184500.00
0005433434507	26179	Business	184500.00
0005432984874	26179	Business	184500.00
0005435981619	26179	Business	184500.00
0005433753449	26179	Business	184500.00
0005433434512	26179	Business	184500.00
0005433753240	26179	Business	184500.00
0005433753235	26179	Business	184500.00
0005432051110	26179	Business	184500.00
0005432984884	26179	Business	184500.00
0005435981671	26179	Business	184500.00
0005435981663	26179	Economy	67700.00
0005433434509	26179	Economy	67700.00
0005435981612	26179	Economy	67700.00
0005433753553	26179	Economy	61500.00
0005432984894	26179	Economy	61500.00
0005432869481	26179	Economy	61500.00
0005433753445	26179	Economy	61500.00
0005433753523	26179	Economy	61500.00
0005433753296	26179	Economy	61500.00
0005433753536	26179	Economy	61500.00
0005435981570	26179	Economy	61500.00
0005432984888	26179	Economy	61500.00
0005433434510	26179	Economy	61500.00
0005433753484	26179	Economy	61500.00
0005432984867	26179	Economy	61500.00
0005433753400	26179	Economy	61500.00
0005432984885	26179	Economy	61500.00
0005433753371	26179	Economy	61500.00
0005434731146	26179	Economy	61500.00
0005433753487	26179	Economy	61500.00
0005433753337	26179	Economy	61500.00
0005432655372	26179	Economy	61500.00
0005432984896	26179	Economy	61500.00
0005433434511	26179	Economy	61500.00
0005433434499	26179	Economy	61500.00
0005433753387	26179	Economy	61500.00
0005433434500	26179	Economy	61500.00
0005435981600	26179	Economy	61500.00
0005433753241	26179	Economy	61500.00
0005432984887	26179	Economy	61500.00
0005433753503	26179	Economy	61500.00
0005433753623	26179	Economy	61500.00
0005432984875	26179	Economy	61500.00
0005435981573	26179	Economy	61500.00
0005434731144	26179	Economy	61500.00
0005432049440	26179	Economy	61500.00
0005432655364	26179	Economy	61500.00
0005433753481	26179	Economy	61500.00
0005433434520	26179	Economy	61500.00
0005433434497	26179	Economy	61500.00
0005432984869	26179	Economy	61500.00
0005435981628	26179	Economy	61500.00
0005435981597	26179	Economy	61500.00
0005433434519	26179	Economy	61500.00
0005432869479	26179	Economy	61500.00
0005432984892	26179	Economy	61500.00
0005433434515	26179	Economy	61500.00
0005432984870	26179	Economy	61500.00
0005435981666	26179	Economy	61500.00
0005435981568	26179	Economy	61500.00
0005435981649	26179	Economy	61500.00
0005433434523	26179	Economy	61500.00
0005432984873	26179	Economy	61500.00
0005434731145	26179	Economy	61500.00
0005435981792	26179	Economy	61500.00
0005433753619	26179	Economy	61500.00
0005433434518	26179	Economy	61500.00
0005433764650	26179	Economy	61500.00
0005433766586	26179	Economy	61500.00
0005435981774	26179	Economy	61500.00
0005432655363	26179	Economy	61500.00
0005435981572	26179	Economy	61500.00
0005433766597	26179	Economy	61500.00
0005433753374	26179	Economy	61500.00
0005433753416	26179	Economy	61500.00
0005432869480	26179	Economy	61500.00
0005435981636	26179	Economy	61500.00
0005432984877	26179	Economy	61500.00
0005433434505	26179	Economy	61500.00
0005433753239	26179	Economy	61500.00
0005432984891	26179	Economy	61500.00
0005435981537	26179	Economy	61500.00
0005435981704	26179	Economy	61500.00
0005433434502	26179	Economy	61500.00
0005432984879	26179	Economy	61500.00
0005433434521	26179	Economy	61500.00
0005435981591	26179	Economy	61500.00
0005435981683	26179	Economy	61500.00
0005433753486	26179	Economy	61500.00
0005432984893	26179	Economy	61500.00
0005432984866	26179	Economy	61500.00
0005432984881	26179	Economy	61500.00
0005432984871	26179	Economy	61500.00
0005435981620	26179	Economy	61500.00
0005433434516	26179	Economy	61500.00
0005433434503	26179	Economy	61500.00
0005435981747	26179	Economy	67700.00
0005433753464	26179	Economy	67700.00
0005433753474	26179	Economy	61500.00
0005432051111	26179	Economy	61500.00
0005433434501	26179	Economy	61500.00
0005432051108	26179	Economy	67700.00
0005433434508	26179	Economy	67700.00
0005433434498	26179	Economy	61500.00
0005433753357	26179	Economy	61500.00
0005433753351	26179	Economy	61500.00
0005432984883	26179	Economy	61500.00
0005432655369	26179	Economy	61500.00
0005433434524	26179	Economy	61500.00
0005433434513	26179	Economy	61500.00
0005432049442	26179	Economy	61500.00
0005433753342	26179	Economy	61500.00
0005433753388	26179	Economy	61500.00
0005435981637	26179	Economy	61500.00
0005435981584	26179	Economy	61500.00
0005433766582	26179	Economy	61500.00
0005433434506	26179	Economy	61500.00
0005433753498	26179	Economy	61500.00
0005434731143	26179	Economy	61500.00
0005435981542	26179	Economy	61500.00
0005435981508	26179	Economy	61500.00
0005432984878	26179	Economy	61500.00
0005432984868	26179	Economy	61500.00
0005432655373	26179	Economy	61500.00
0005432655368	26179	Economy	61500.00
0005433753571	26179	Economy	61500.00
0005433434517	26179	Economy	61500.00
0005435981743	26179	Economy	61500.00
0005432984882	26179	Economy	61500.00
0005432984897	26179	Economy	61500.00
0005435981541	26179	Economy	61500.00
0005432984898	26179	Economy	61500.00
0005433753336	26179	Economy	61500.00
0005433753343	26179	Economy	61500.00
0005432984889	26179	Economy	61500.00
0005435981569	26179	Economy	61500.00
0005433434504	26179	Economy	61500.00
0005432984876	26179	Economy	61500.00
0005432655366	26179	Economy	61500.00
0005433753510	26179	Economy	61500.00
0005433753334	26179	Economy	61500.00
0005432984880	26179	Economy	61500.00
0005432984886	26179	Economy	61500.00
0005433753341	26179	Economy	61500.00
0005435981519	26179	Economy	61500.00
0005433753419	26179	Economy	61500.00
0005432984895	26179	Economy	61500.00
0005432869485	26179	Economy	61500.00
0005433753358	26179	Economy	61500.00
0005432655367	26179	Economy	61500.00
0005433753533	26179	Economy	61500.00
0005432984890	26179	Economy	61500.00
0005433434514	26179	Economy	61500.00
0005433753444	26179	Economy	61500.00
0005433753234	26179	Economy	61500.00
0005435981538	26179	Economy	61500.00
0005432984872	26179	Economy	61500.00
0005433753480	26179	Economy	61500.00
0005435981532	26179	Economy	61500.00
0005432869484	26179	Economy	61500.00
0005433753609	26179	Economy	61500.00
0005432869483	26179	Economy	61500.00
0005433753260	26179	Economy	61500.00
0005432049444	26179	Economy	61500.00
0005433151019	1493	Business	38900.00
0005434374403	1493	Business	38900.00
0005434374417	1493	Business	38900.00
0005434374413	1493	Business	38900.00
0005433150902	1493	Business	38900.00
0005432267854	1493	Business	38900.00
0005433931415	1493	Business	38900.00
0005433151038	1493	Business	38900.00
0005434374389	1493	Economy	13000.00
0005434374419	1493	Economy	13000.00
0005433151018	1493	Economy	13000.00
0005433150885	1493	Economy	13000.00
0005434374405	1493	Economy	13000.00
0005434374397	1493	Economy	13000.00
0005434374390	1493	Economy	13000.00
0005434374391	1493	Economy	13000.00
0005434374376	1493	Economy	13000.00
0005433150971	1493	Economy	13000.00
0005434374412	1493	Economy	13000.00
0005433150998	1493	Economy	13000.00
0005433150994	1493	Economy	13000.00
0005434374369	1493	Economy	13000.00
0005434374411	1493	Economy	13000.00
0005434374401	1493	Economy	13000.00
0005432267855	1493	Economy	13000.00
0005434374400	1493	Economy	13000.00
0005433931423	1493	Economy	13000.00
0005433461576	1493	Economy	13000.00
0005433150946	1493	Economy	13000.00
0005433150932	1493	Economy	13000.00
0005434374395	1493	Economy	13000.00
0005434374388	1493	Economy	13000.00
0005434374370	1493	Economy	13000.00
0005434374368	1493	Economy	13000.00
0005433461575	1493	Economy	13000.00
0005434374387	1493	Economy	13000.00
0005433150992	1493	Economy	13000.00
0005434374378	1493	Economy	13000.00
0005434374406	1493	Economy	13000.00
0005434374407	1493	Economy	13000.00
0005434374363	1493	Economy	14300.00
0005434374380	1493	Economy	14300.00
0005433150806	1493	Economy	14300.00
0005434374418	1493	Economy	14300.00
0005434374398	1493	Economy	14300.00
0005433151072	1493	Economy	13000.00
0005434374367	1493	Economy	13000.00
0005434374386	1493	Economy	13000.00
0005433931418	1493	Economy	13000.00
0005434374383	1493	Economy	13000.00
0005434374375	1493	Economy	13000.00
0005434374394	1493	Economy	13000.00
0005433931419	1493	Economy	13000.00
0005433150921	1493	Economy	13000.00
0005434374399	1493	Economy	13000.00
0005433150898	1493	Economy	13000.00
0005434374396	1493	Economy	13000.00
0005434374364	1493	Economy	13000.00
0005433150882	1493	Economy	13000.00
0005434374415	1493	Economy	13000.00
0005434374416	1493	Economy	13000.00
0005433151017	1493	Economy	13000.00
0005433931416	1493	Economy	13000.00
0005434374408	1493	Economy	13000.00
0005434374414	1493	Economy	13000.00
0005434374384	1493	Economy	13000.00
0005433150850	1493	Economy	13000.00
0005432267853	1493	Economy	13000.00
0005434374374	1493	Economy	13000.00
0005434374379	1493	Economy	13000.00
0005433460422	1493	Economy	13000.00
0005434374392	1493	Economy	13000.00
0005433150805	1493	Economy	13000.00
0005434374409	1493	Economy	13000.00
0005433150931	1493	Economy	13000.00
0005434374366	1493	Economy	13000.00
0005434374373	1493	Economy	13000.00
0005433150838	1493	Economy	13000.00
0005432267851	1493	Economy	13000.00
0005433150810	1493	Economy	13000.00
0005432267852	1493	Economy	13000.00
0005433150884	1493	Economy	13000.00
0005434374371	1493	Economy	13000.00
0005434374404	1493	Economy	13000.00
0005433150881	1493	Economy	13000.00
0005433150993	1493	Economy	13000.00
0005434374410	1493	Economy	13000.00
0005433150897	1493	Economy	13000.00
0005433151037	1493	Economy	13000.00
0005434374393	1493	Economy	13000.00
0005433150890	1493	Economy	13000.00
0005434374385	1493	Economy	13000.00
0005433461574	1493	Economy	13000.00
0005432267856	1493	Economy	13000.00
0005434374381	1493	Economy	13000.00
0005434374377	1493	Economy	13000.00
0005434374365	1493	Economy	13000.00
0005434374402	1493	Economy	13000.00
0005433460423	1493	Economy	13000.00
0005434374372	1493	Economy	13000.00
0005434374382	1493	Economy	13000.00
0005433151023	1493	Economy	13000.00
0005432267857	1493	Economy	13000.00
0005434374420	1493	Economy	13000.00
0005434373886	20125	Business	38900.00
0005433151213	20125	Business	38900.00
0005434374054	20125	Business	38900.00
0005434374034	20125	Business	38900.00
0005432056274	20125	Business	38900.00
0005434374059	20125	Business	38900.00
0005434373900	20125	Business	38900.00
0005434373995	20125	Business	38900.00
0005432056276	20125	Business	38900.00
0005434374052	20125	Economy	13000.00
0005434374072	20125	Economy	13000.00
0005434373994	20125	Economy	13000.00
0005433151197	20125	Economy	13000.00
0005434373907	20125	Economy	13000.00
0005433151187	20125	Economy	13000.00
0005434373925	20125	Economy	13000.00
0005433151206	20125	Economy	13000.00
0005434374009	20125	Economy	13000.00
0005434374057	20125	Economy	13000.00
0005434374079	20125	Economy	13000.00
0005433151189	20125	Economy	13000.00
0005434374078	20125	Economy	13000.00
0005434374066	20125	Economy	13000.00
0005434373953	20125	Economy	13000.00
0005433764668	20125	Economy	13000.00
0005433151205	20125	Economy	13000.00
0005433151186	20125	Economy	13000.00
0005434374049	20125	Economy	13000.00
0005434374044	20125	Economy	13000.00
0005434029641	20125	Economy	13000.00
0005433151212	20125	Economy	13000.00
0005434374071	20125	Economy	13000.00
0005433151200	20125	Economy	13000.00
0005434374080	20125	Economy	13000.00
0005434374017	20125	Economy	13000.00
0005433151199	20125	Economy	13000.00
0005433151180	20125	Economy	13000.00
0005433151204	20125	Economy	13000.00
0005434374060	20125	Economy	14300.00
0005433151214	20125	Economy	14300.00
0005433931447	20125	Economy	14300.00
0005433151184	20125	Economy	14300.00
0005434373943	20125	Economy	14300.00
0005434373986	20125	Economy	13000.00
0005434373899	20125	Economy	13000.00
0005433764667	20125	Economy	13000.00
0005433151207	20125	Economy	13000.00
0005433931446	20125	Economy	13000.00
0005433151181	20125	Economy	13000.00
0005434029642	20125	Economy	13000.00
0005434374035	20125	Economy	13000.00
0005434374051	20125	Economy	13000.00
0005433151191	20125	Economy	13000.00
0005434373962	20125	Economy	13000.00
0005433151194	20125	Economy	13000.00
0005433151211	20125	Economy	13000.00
0005434374040	20125	Economy	13000.00
0005434374050	20125	Economy	13000.00
0005433151183	20125	Economy	13000.00
0005434374047	20125	Economy	13000.00
0005434373847	20125	Economy	13000.00
0005434374081	20125	Economy	13000.00
0005434373952	20125	Economy	13000.00
0005433151203	20125	Economy	13000.00
0005434373998	20125	Economy	13000.00
0005432056277	20125	Economy	13000.00
0005434374053	20125	Economy	13000.00
0005434373885	20125	Economy	13000.00
0005434373926	20125	Economy	13000.00
0005434373960	20125	Economy	13000.00
0005433151192	20125	Economy	13000.00
0005433151208	20125	Economy	13000.00
0005434373969	20125	Economy	13000.00
0005433931448	20125	Economy	13000.00
0005434373905	20125	Economy	13000.00
0005433151210	20125	Economy	13000.00
0005433151193	20125	Economy	13000.00
0005433151202	20125	Economy	13000.00
0005433151190	20125	Economy	13000.00
0005433151196	20125	Economy	13000.00
0005434373887	20125	Economy	13000.00
0005433151209	20125	Economy	13000.00
0005433151198	20125	Economy	13000.00
0005433151182	20125	Economy	13000.00
0005434373961	20125	Economy	13000.00
0005432056275	20125	Economy	13000.00
0005433151195	20125	Economy	13000.00
0005433931445	20125	Economy	13000.00
0005433151201	20125	Economy	13000.00
0005433151185	20125	Economy	13000.00
0005433151188	20125	Economy	13000.00
0005434374039	20125	Economy	13000.00
0005434373974	20125	Economy	13000.00
0005432424178	590	Business	27500.00
0005432424188	590	Business	27500.00
0005432424168	590	Business	27500.00
0005432424176	590	Business	27500.00
0005432424171	590	Economy	10100.00
0005432424180	590	Economy	9200.00
0005432424187	590	Economy	9200.00
0005432424184	590	Economy	9200.00
0005432424170	590	Economy	9200.00
0005432282823	590	Economy	9200.00
0005432282820	590	Economy	9200.00
0005432282818	590	Economy	9200.00
0005432424172	590	Economy	9200.00
0005432282822	590	Economy	9200.00
0005432282821	590	Economy	9200.00
0005432424160	590	Economy	9200.00
0005432424182	590	Economy	9200.00
0005432424166	590	Economy	9200.00
0005432424183	590	Economy	9200.00
0005432424163	590	Economy	9200.00
0005432282825	590	Economy	9200.00
0005432424165	590	Economy	10100.00
0005432282819	590	Economy	9200.00
0005432424181	590	Economy	9200.00
0005432424175	590	Economy	9200.00
0005432282824	590	Economy	9200.00
0005432424162	590	Economy	9200.00
0005432424169	590	Economy	9200.00
0005432424173	590	Economy	9200.00
0005432424161	590	Economy	9200.00
0005432424186	590	Economy	9200.00
0005432424179	590	Economy	9200.00
0005432424167	590	Economy	9200.00
0005432424177	590	Economy	9200.00
0005432424164	590	Economy	9200.00
0005432424185	590	Economy	9200.00
0005432424174	590	Economy	9200.00
0005433158116	12881	Business	27500.00
0005433158117	12881	Business	27500.00
0005434446476	12881	Economy	9200.00
0005434446494	12881	Economy	9200.00
0005434446492	12881	Economy	9200.00
0005434446477	12881	Economy	9200.00
0005434446493	12881	Economy	9200.00
0005434446478	12881	Economy	9200.00
0005432302310	12881	Economy	9200.00
0005432302306	12881	Economy	9200.00
0005434446484	12881	Economy	9200.00
0005434446489	12881	Economy	9200.00
0005432302308	12881	Economy	9200.00
0005434446481	12881	Economy	9200.00
0005432302307	12881	Economy	9200.00
0005433158119	12881	Economy	9200.00
0005434446480	12881	Economy	9200.00
0005433158118	12881	Economy	9200.00
0005432302309	12881	Economy	9200.00
0005434446479	12881	Economy	9200.00
0005432423743	12900	Business	27500.00
0005432423733	12900	Business	27500.00
0005432423621	12900	Business	27500.00
0005432423624	12900	Business	27500.00
0005432423741	12900	Business	27500.00
0005432423725	12900	Business	27500.00
0005432423682	12900	Business	27500.00
0005432423718	12900	Economy	10100.00
0005432423700	12900	Business	27500.00
0005432423744	12900	Economy	10100.00
0005432423679	12900	Economy	9200.00
0005432423659	12900	Economy	9200.00
0005432423678	12900	Economy	9200.00
0005432423626	12900	Economy	9200.00
0005432423698	12900	Economy	9200.00
0005432423610	12900	Economy	9200.00
0005432423694	12900	Economy	9200.00
0005432423639	12900	Economy	9200.00
0005432423759	12900	Economy	9200.00
0005432423695	12900	Economy	9200.00
0005432423726	12900	Economy	9200.00
0005432423611	12900	Economy	9200.00
0005432423699	12900	Economy	9200.00
0005432423637	12900	Economy	9200.00
0005432423658	12900	Economy	9200.00
0005432423648	12900	Economy	9200.00
0005432423655	12900	Economy	9200.00
0005432423677	12900	Economy	10100.00
0005432423657	12900	Economy	10100.00
0005432423663	12900	Economy	10100.00
0005432423638	12900	Economy	9200.00
0005432423673	12900	Economy	9200.00
0005432423651	12900	Economy	9200.00
0005432423617	12900	Economy	9200.00
0005432423754	12900	Economy	9200.00
0005432423758	12900	Economy	9200.00
0005432423656	12900	Economy	9200.00
0005432423662	12900	Economy	9200.00
0005432423740	12900	Economy	9200.00
0005432423675	12900	Economy	9200.00
0005432423625	12900	Economy	9200.00
0005432423732	12900	Economy	9200.00
0005432423671	12900	Economy	9200.00
0005432423701	12900	Economy	9200.00
0005432423674	12900	Economy	9200.00
0005432423753	12900	Economy	9200.00
0005432423634	12900	Economy	9200.00
0005432423661	12900	Economy	9200.00
0005432423641	12900	Economy	9200.00
0005434023327	480	Business	24500.00
0005433057384	480	Business	24500.00
0005433929545	480	Business	24500.00
0005434023332	480	Business	24500.00
0005434023297	480	Business	24500.00
0005434023265	480	Business	24500.00
0005433057383	480	Business	24500.00
0005434023296	480	Business	24500.00
0005433057350	480	Business	24500.00
0005433057258	480	Business	24500.00
0005433057455	480	Business	24500.00
0005432235591	480	Business	24500.00
0005434023322	480	Business	24500.00
0005434023315	480	Business	24500.00
0005434023312	480	Business	24500.00
0005434023276	480	Business	24500.00
0005434023270	480	Business	24500.00
0005434023316	480	Economy	9000.00
0005434023287	480	Economy	9000.00
0005433057315	480	Economy	8200.00
0005434023280	480	Economy	8200.00
0005433057349	480	Economy	8200.00
0005433057293	480	Economy	8200.00
0005433057262	480	Economy	8200.00
0005434023298	480	Economy	8200.00
0005434031991	480	Economy	8200.00
0005433057528	480	Economy	8200.00
0005433057261	480	Economy	8200.00
0005434023319	480	Economy	8200.00
0005433057367	480	Economy	8200.00
0005434023307	480	Economy	8200.00
0005434023299	480	Economy	8200.00
0005434023329	480	Economy	8200.00
0005434031990	480	Economy	8200.00
0005433057505	480	Economy	8200.00
0005434023300	480	Economy	8200.00
0005433057390	480	Economy	8200.00
0005434023271	480	Economy	8200.00
0005434023331	480	Economy	8200.00
0005434023295	480	Economy	8200.00
0005433057444	480	Economy	8200.00
0005434023313	480	Economy	8200.00
0005434023275	480	Economy	8200.00
0005433057391	480	Economy	8200.00
0005434023293	480	Economy	8200.00
0005434023306	480	Economy	8200.00
0005433057506	480	Economy	8200.00
0005433057369	480	Economy	8200.00
0005434023302	480	Economy	8200.00
0005434023264	480	Economy	8200.00
0005434023286	480	Economy	8200.00
0005433929565	480	Economy	8200.00
0005433929553	480	Economy	8200.00
0005434023267	480	Economy	8200.00
0005432235592	480	Economy	8200.00
0005433057341	480	Economy	8200.00
0005433057256	480	Economy	8200.00
0005434023266	480	Economy	8200.00
0005434023317	480	Economy	8200.00
0005432235594	480	Economy	8200.00
0005434023333	480	Economy	8200.00
0005433057252	480	Economy	8200.00
0005434023294	480	Economy	8200.00
0005434023328	480	Economy	8200.00
0005433057357	480	Economy	8200.00
0005434031992	480	Economy	8200.00
0005433057241	480	Economy	8200.00
0005433057419	480	Economy	8200.00
0005433057353	480	Economy	8200.00
0005433057407	480	Economy	8200.00
0005432045600	480	Economy	8200.00
0005433057361	480	Economy	8200.00
0005434023268	480	Economy	8200.00
0005433057250	480	Economy	8200.00
0005433057345	480	Economy	8200.00
0005434023326	480	Economy	8200.00
0005434023318	480	Economy	8200.00
0005433057418	480	Economy	8200.00
0005433057309	480	Economy	8200.00
0005434023277	480	Economy	8200.00
0005434023269	480	Economy	8200.00
0005434023323	480	Economy	8200.00
0005433057382	480	Economy	8200.00
0005433057294	480	Economy	8200.00
0005433057356	480	Economy	8200.00
0005434023285	480	Economy	8200.00
0005434023311	480	Economy	8200.00
0005433057522	480	Economy	9000.00
0005433057368	480	Economy	9000.00
0005434029640	480	Economy	8200.00
0005432045599	480	Economy	8200.00
0005433929548	480	Economy	9000.00
0005434023284	480	Economy	9000.00
0005434028277	480	Economy	8200.00
0005434023308	480	Economy	8200.00
0005434023325	480	Economy	8200.00
0005433057215	480	Economy	8200.00
0005434031993	480	Economy	8200.00
0005432235590	480	Economy	8200.00
0005434029639	480	Economy	8200.00
0005434023289	480	Economy	8200.00
0005434023283	480	Economy	8200.00
0005433057417	480	Economy	8200.00
0005432235589	480	Economy	8200.00
0005434023303	480	Economy	8200.00
0005433929544	480	Economy	8200.00
0005434023291	480	Economy	8200.00
0005434023290	480	Economy	8200.00
0005434023330	480	Economy	8200.00
0005433057376	480	Economy	8200.00
0005434023288	480	Economy	8200.00
0005434028278	480	Economy	8200.00
0005433057420	480	Economy	8200.00
0005432235593	480	Economy	8200.00
0005432235595	480	Economy	8200.00
0005434023324	480	Economy	8200.00
0005434023305	480	Economy	8200.00
0005433929542	480	Economy	8200.00
0005434023309	480	Economy	8200.00
0005434023321	480	Economy	8200.00
0005433057242	480	Economy	8200.00
0005434028279	480	Economy	8200.00
0005433057340	480	Economy	8200.00
0005433057523	480	Economy	8200.00
0005434023281	480	Economy	8200.00
0005434023314	480	Economy	8200.00
0005434023301	480	Economy	8200.00
0005434023320	480	Economy	8200.00
0005433057214	480	Economy	8200.00
0005433057251	480	Economy	8200.00
0005434023282	480	Economy	8200.00
0005433057395	480	Economy	8200.00
0005434031994	480	Economy	8200.00
0005434023273	480	Economy	8200.00
0005434023274	480	Economy	8200.00
0005434023278	480	Economy	8200.00
0005433929543	480	Economy	8200.00
0005433057388	480	Economy	8200.00
0005434023272	480	Economy	8200.00
0005434023279	480	Economy	8200.00
0005434023310	480	Economy	8200.00
0005434029638	480	Economy	8200.00
0005434023304	480	Economy	8200.00
0005434023292	480	Economy	8200.00
0005434022889	12688	Business	24500.00
0005433057622	12688	Business	24500.00
0005433929587	12688	Business	24500.00
0005433057645	12688	Business	24500.00
0005434735659	12688	Business	24500.00
0005434028256	12688	Business	24500.00
0005434022953	12688	Business	24500.00
0005433929589	12688	Business	24500.00
0005434022763	12688	Business	24500.00
0005434022683	12688	Business	24500.00
0005434022888	12688	Business	24500.00
0005434022502	12688	Business	24500.00
0005434022876	12688	Business	24500.00
0005433057641	12688	Business	24500.00
0005434022621	12688	Business	24500.00
0005434022692	12688	Business	24500.00
0005433057627	12688	Economy	9000.00
0005432157480	12688	Economy	9000.00
0005432156341	12688	Economy	8200.00
0005433057621	12688	Economy	8200.00
0005434022940	12688	Economy	8200.00
0005433057659	12688	Economy	8200.00
0005434735657	12688	Economy	8200.00
0005433684408	12688	Economy	8200.00
0005434022925	12688	Economy	8200.00
0005433057652	12688	Economy	8200.00
0005434031951	12688	Economy	8200.00
0005434022750	12688	Economy	8200.00
0005433057654	12688	Economy	8200.00
0005434022704	12688	Economy	8200.00
0005434028259	12688	Economy	8200.00
0005434022548	12688	Economy	8200.00
0005433057647	12688	Economy	8200.00
0005433057631	12688	Economy	8200.00
0005434022705	12688	Economy	8200.00
0005434022740	12688	Economy	8200.00
0005434022659	12688	Economy	8200.00
0005434022924	12688	Economy	8200.00
0005434022860	12688	Economy	8200.00
0005433057639	12688	Economy	8200.00
0005434022669	12688	Economy	8200.00
0005432156340	12688	Economy	8200.00
0005434022851	12688	Economy	8200.00
0005434022852	12688	Economy	8200.00
0005433057634	12688	Economy	8200.00
0005434022757	12688	Economy	8200.00
0005433057648	12688	Economy	8200.00
0005434735658	12688	Economy	8200.00
0005434022786	12688	Economy	8200.00
0005434022819	12688	Economy	8200.00
0005434022751	12688	Economy	8200.00
0005434022677	12688	Economy	8200.00
0005433057626	12688	Economy	8200.00
0005434022610	12688	Economy	8200.00
0005433929588	12688	Economy	8200.00
0005434022952	12688	Economy	8200.00
0005433057635	12688	Economy	8200.00
0005433929586	12688	Economy	8200.00
0005433057642	12688	Economy	8200.00
0005434022778	12688	Economy	8200.00
0005433057637	12688	Economy	8200.00
0005434022773	12688	Economy	8200.00
0005433057651	12688	Economy	8200.00
0005432156337	12688	Economy	8200.00
0005434022652	12688	Economy	8200.00
0005434022806	12688	Economy	8200.00
0005433057644	12688	Economy	8200.00
0005434022682	12688	Economy	8200.00
0005433057658	12688	Economy	8200.00
0005434735660	12688	Economy	8200.00
0005433057636	12688	Economy	8200.00
0005433057646	12688	Economy	8200.00
0005434022577	12688	Economy	8200.00
0005433684407	12688	Economy	8200.00
0005433057638	12688	Economy	8200.00
0005433057650	12688	Economy	9000.00
0005434022684	12688	Economy	8200.00
0005434022820	12688	Economy	8200.00
0005434022559	12688	Economy	8200.00
0005434735656	12688	Economy	9000.00
0005434022826	12688	Economy	8200.00
0005434022807	12688	Economy	8200.00
0005432157481	12688	Economy	8200.00
0005434031958	12688	Economy	8200.00
0005433057630	12688	Economy	8200.00
0005433057624	12688	Economy	8200.00
0005433057653	12688	Economy	8200.00
0005434022877	12688	Economy	8200.00
0005434022520	12688	Economy	8200.00
0005434022984	12688	Economy	8200.00
0005434022572	12688	Economy	8200.00
0005432156342	12688	Economy	8200.00
0005433057625	12688	Economy	8200.00
0005433684409	12688	Economy	8200.00
0005433057660	12688	Economy	8200.00
0005433057656	12688	Economy	8200.00
0005434022671	12688	Economy	8200.00
0005433057640	12688	Economy	8200.00
0005432156338	12688	Economy	8200.00
0005434022941	12688	Economy	8200.00
0005434022808	12688	Economy	8200.00
0005434022785	12688	Economy	8200.00
0005434022847	12688	Economy	8200.00
0005434022880	12688	Economy	8200.00
0005433057632	12688	Economy	8200.00
0005434022849	12688	Economy	8200.00
0005434031975	12688	Economy	8200.00
0005434022942	12688	Economy	8200.00
0005434022549	12688	Economy	8200.00
0005434022511	12688	Economy	8200.00
0005434022691	12688	Economy	8200.00
0005432156339	12688	Economy	8200.00
0005432157479	12688	Economy	8200.00
0005433057623	12688	Economy	8200.00
0005433057629	12688	Economy	8200.00
0005434022561	12688	Economy	8200.00
0005433057643	12688	Economy	8200.00
0005434022749	12688	Economy	8200.00
0005434022890	12688	Economy	8200.00
0005434022560	12688	Economy	8200.00
0005433057657	12688	Economy	8200.00
0005433057628	12688	Economy	8200.00
0005434022501	12688	Economy	8200.00
0005433057649	12688	Economy	8200.00
0005433057633	12688	Economy	8200.00
0005433057655	12688	Economy	8200.00
0005433035487	2156	Business	34700.00
0005433922742	2156	Business	34700.00
0005433035358	2156	Business	34700.00
0005433922757	2156	Business	34700.00
0005433922728	2156	Business	34700.00
0005433922729	2156	Business	34700.00
0005433922745	2156	Business	34700.00
0005433035517	2156	Business	34700.00
0005433922667	2156	Business	34700.00
0005433922740	2156	Business	34700.00
0005433922677	2156	Business	34700.00
0005433922678	2156	Business	34700.00
0005433035762	2156	Business	34700.00
0005433922715	2156	Business	34700.00
0005433922688	2156	Business	34700.00
0005433922701	2156	Business	34700.00
0005433922751	2156	Business	34700.00
0005433922699	2156	Business	34700.00
0005433929588	2156	Business	34700.00
0005433922723	2156	Business	34700.00
0005433035668	2156	Business	34700.00
0005433922687	2156	Business	34700.00
0005433922695	2156	Business	34700.00
0005433922756	2156	Business	34700.00
0005433922760	2156	Economy	12700.00
0005433922697	2156	Business	34700.00
0005432231503	2156	Economy	12700.00
0005433922683	2156	Economy	12700.00
0005433929589	2156	Economy	11600.00
0005433922704	2156	Economy	11600.00
0005433922698	2156	Economy	11600.00
0005433931448	2156	Economy	11600.00
0005433922755	2156	Economy	11600.00
0005433035481	2156	Economy	11600.00
0005434028256	2156	Economy	11600.00
0005433922680	2156	Economy	11600.00
0005433035560	2156	Economy	11600.00
0005433922702	2156	Economy	11600.00
0005433922694	2156	Economy	11600.00
0005433922705	2156	Economy	11600.00
0005432044507	2156	Economy	11600.00
0005433922747	2156	Economy	11600.00
0005433035512	2156	Economy	11600.00
0005433035480	2156	Economy	11600.00
0005432231497	2156	Economy	11600.00
0005433922675	2156	Economy	11600.00
0005433922710	2156	Economy	11600.00
0005433922731	2156	Economy	11600.00
0005433922739	2156	Economy	11600.00
0005433929587	2156	Economy	11600.00
0005433922737	2156	Economy	11600.00
0005433922714	2156	Economy	11600.00
0005433035479	2156	Economy	11600.00
0005433922669	2156	Economy	11600.00
0005432231505	2156	Economy	11600.00
0005433922730	2156	Economy	11600.00
0005433922679	2156	Economy	11600.00
0005433035563	2156	Economy	11600.00
0005433035656	2156	Economy	11600.00
0005433922671	2156	Economy	11600.00
0005433931446	2156	Economy	11600.00
0005433035523	2156	Economy	11600.00
0005433922706	2156	Economy	11600.00
0005433035779	2156	Economy	11600.00
0005433922722	2156	Economy	11600.00
0005433931447	2156	Economy	11600.00
0005433922750	2156	Economy	11600.00
0005433035636	2156	Economy	11600.00
0005433922712	2156	Economy	11600.00
0005433922693	2156	Economy	11600.00
0005433035547	2156	Economy	11600.00
0005433922717	2156	Economy	11600.00
0005433875367	2156	Economy	11600.00
0005433922684	2156	Economy	11600.00
0005433035509	2156	Economy	11600.00
0005433035515	2156	Economy	11600.00
0005433922761	2156	Economy	11600.00
0005433035514	2156	Economy	11600.00
0005433922763	2156	Economy	11600.00
0005433922711	2156	Economy	11600.00
0005433035367	2156	Economy	11600.00
0005433922721	2156	Economy	11600.00
0005433922672	2156	Economy	11600.00
0005432231504	2156	Economy	11600.00
0005433922726	2156	Economy	11600.00
0005433035658	2156	Economy	11600.00
0005433035591	2156	Economy	11600.00
0005433922673	2156	Economy	11600.00
0005433922719	2156	Economy	11600.00
0005433922686	2156	Economy	11600.00
0005433035625	2156	Economy	11600.00
0005433922764	2156	Economy	11600.00
0005433922709	2156	Economy	11600.00
0005433035592	2156	Economy	11600.00
0005433035548	2156	Economy	11600.00
0005433035447	2156	Economy	11600.00
0005432231498	2156	Economy	11600.00
0005432231495	2156	Economy	11600.00
0005433922682	2156	Economy	11600.00
0005434028259	2156	Economy	11600.00
0005433035506	2156	Economy	11600.00
0005433922727	2156	Economy	11600.00
0005433035464	2156	Economy	11600.00
0005433922744	2156	Economy	11600.00
0005433035561	2156	Economy	11600.00
0005433922749	2156	Economy	11600.00
0005433922691	2156	Economy	11600.00
0005433035431	2156	Economy	11600.00
0005433922752	2156	Economy	12700.00
0005433922733	2156	Economy	12700.00
0005433922748	2156	Economy	11600.00
0005433929586	2156	Economy	11600.00
0005433922759	2156	Economy	11600.00
0005433035714	2156	Economy	12700.00
0005432231500	2156	Economy	11600.00
0005433922724	2156	Economy	11600.00
0005433922765	2156	Economy	11600.00
0005433922720	2156	Economy	11600.00
0005433922746	2156	Economy	11600.00
0005433922700	2156	Economy	11600.00
0005433035780	2156	Economy	11600.00
0005433922689	2156	Economy	11600.00
0005433922716	2156	Economy	11600.00
0005433922753	2156	Economy	11600.00
0005432231499	2156	Economy	11600.00
0005433035539	2156	Economy	11600.00
0005433922708	2156	Economy	11600.00
0005433035596	2156	Economy	11600.00
0005433035630	2156	Economy	11600.00
0005433922674	2156	Economy	11600.00
0005433035583	2156	Economy	11600.00
0005433035616	2156	Economy	11600.00
0005433922718	2156	Economy	11600.00
0005433035617	2156	Economy	11600.00
0005433035420	2156	Economy	11600.00
0005432044508	2156	Economy	11600.00
0005433922668	2156	Economy	11600.00
0005433922734	2156	Economy	11600.00
0005433922762	2156	Economy	11600.00
0005433035465	2156	Economy	11600.00
0005433922743	2156	Economy	11600.00
0005433035626	2156	Economy	11600.00
0005433922681	2156	Economy	11600.00
0005433035568	2156	Economy	11600.00
0005433922692	2156	Economy	11600.00
0005433922736	2156	Economy	11600.00
0005433035657	2156	Economy	11600.00
0005432231501	2156	Economy	11600.00
0005433922741	2156	Economy	11600.00
0005433922735	2156	Economy	11600.00
0005433922703	2156	Economy	11600.00
0005433035533	2156	Economy	11600.00
0005433035520	2156	Economy	11600.00
0005433922690	2156	Economy	11600.00
0005433922713	2156	Economy	11600.00
0005433035562	2156	Economy	11600.00
0005433035524	2156	Economy	11600.00
0005433035518	2156	Economy	11600.00
0005433922725	2156	Economy	11600.00
0005433922707	2156	Economy	11600.00
0005433922738	2156	Economy	11600.00
0005433931445	2156	Economy	11600.00
0005433922758	2156	Economy	11600.00
0005432231496	2156	Economy	11600.00
0005432044506	2156	Economy	11600.00
0005433035430	2156	Economy	11600.00
0005433922685	2156	Economy	11600.00
0005433035676	2156	Economy	11600.00
0005433035659	2156	Economy	11600.00
0005433922676	2156	Economy	11600.00
0005433922754	2156	Economy	11600.00
0005433922732	2156	Economy	11600.00
0005433922670	2156	Economy	11600.00
0005433922696	2156	Economy	11600.00
0005432231502	2156	Economy	11600.00
0005433921624	24088	Business	34700.00
0005433035981	24088	Business	34700.00
0005432207646	24088	Business	34700.00
0005433035965	24088	Business	34700.00
0005433035960	24088	Business	34700.00
0005433922159	24088	Business	34700.00
0005433035967	24088	Business	34700.00
0005433921904	24088	Business	34700.00
0005433921626	24088	Business	34700.00
0005433921734	24088	Business	34700.00
0005433929566	24088	Business	34700.00
0005433921755	24088	Business	34700.00
0005432749771	24088	Business	34700.00
0005433929550	24088	Business	34700.00
0005433922122	24088	Business	34700.00
0005433921729	24088	Business	34700.00
0005433922039	24088	Business	34700.00
0005433035982	24088	Business	34700.00
0005433035999	24088	Business	34700.00
0005433921689	24088	Business	34700.00
0005433922143	24088	Business	34700.00
0005433035966	24088	Business	34700.00
0005433921749	24088	Business	34700.00
0005433921900	24088	Business	34700.00
0005433921842	24088	Business	34700.00
0005434028280	24088	Business	34700.00
0005433921957	24088	Economy	12700.00
0005432749772	24088	Economy	12700.00
0005433921638	24088	Economy	12700.00
0005433921907	24088	Economy	11600.00
0005433035987	24088	Economy	11600.00
0005433922142	24088	Economy	11600.00
0005433921783	24088	Economy	11600.00
0005433035971	24088	Economy	11600.00
0005432207647	24088	Economy	11600.00
0005433035983	24088	Economy	11600.00
0005433035978	24088	Economy	11600.00
0005433921708	24088	Economy	11600.00
0005433921886	24088	Economy	11600.00
0005433035956	24088	Economy	11600.00
0005433035976	24088	Economy	11600.00
0005433921707	24088	Economy	11600.00
0005433922040	24088	Economy	11600.00
0005433921896	24088	Economy	11600.00
0005433921728	24088	Economy	11600.00
0005433921811	24088	Economy	11600.00
0005433921843	24088	Economy	11600.00
0005433921733	24088	Economy	11600.00
0005433921822	24088	Economy	11600.00
0005433875354	24088	Economy	11600.00
0005433921953	24088	Economy	11600.00
0005433035996	24088	Economy	11600.00
0005433922062	24088	Economy	11600.00
0005433921634	24088	Economy	11600.00
0005433035991	24088	Economy	11600.00
0005433035986	24088	Economy	11600.00
0005433035975	24088	Economy	11600.00
0005433035955	24088	Economy	11600.00
0005433035959	24088	Economy	11600.00
0005433035977	24088	Economy	11600.00
0005433035951	24088	Economy	11600.00
0005433929552	24088	Economy	11600.00
0005433922260	24088	Economy	11600.00
0005433035962	24088	Economy	11600.00
0005433921655	24088	Economy	11600.00
0005433921786	24088	Economy	11600.00
0005433035984	24088	Economy	11600.00
0005433035995	24088	Economy	11600.00
0005433921985	24088	Economy	11600.00
0005433921928	24088	Economy	11600.00
0005433036003	24088	Economy	11600.00
0005433922154	24088	Economy	11600.00
0005433035954	24088	Economy	11600.00
0005434028282	24088	Economy	11600.00
0005433035952	24088	Economy	11600.00
0005433921767	24088	Economy	11600.00
0005433921754	24088	Economy	11600.00
0005432749773	24088	Economy	11600.00
0005433921873	24088	Economy	11600.00
0005433922002	24088	Economy	11600.00
0005433922237	24088	Economy	11600.00
0005433921950	24088	Economy	11600.00
0005433921872	24088	Economy	11600.00
0005433922155	24088	Economy	11600.00
0005433921993	24088	Economy	11600.00
0005433921968	24088	Economy	11600.00
0005433035988	24088	Economy	11600.00
0005433921814	24088	Economy	11600.00
0005433921826	24088	Economy	11600.00
0005433921954	24088	Economy	11600.00
0005434028283	24088	Economy	11600.00
0005433035972	24088	Economy	11600.00
0005433035970	24088	Economy	11600.00
0005433922218	24088	Economy	11600.00
0005433035993	24088	Economy	11600.00
0005433921839	24088	Economy	11600.00
0005433922141	24088	Economy	11600.00
0005433921874	24088	Economy	11600.00
0005433921838	24088	Economy	11600.00
0005432206157	24088	Economy	11600.00
0005433921706	24088	Economy	11600.00
0005433922238	24088	Economy	11600.00
0005434028281	24088	Economy	11600.00
0005433035980	24088	Economy	11600.00
0005433035961	24088	Economy	12700.00
0005433921625	24088	Economy	11600.00
0005433921899	24088	Economy	12700.00
0005432206160	24088	Economy	11600.00
0005432206162	24088	Economy	11600.00
0005432206159	24088	Economy	12700.00
0005433922258	24088	Economy	11600.00
0005432749774	24088	Economy	11600.00
0005433035969	24088	Economy	11600.00
0005433921958	24088	Economy	11600.00
0005433929551	24088	Economy	11600.00
0005433921688	24088	Economy	11600.00
0005433922269	24088	Economy	11600.00
0005433035979	24088	Economy	11600.00
0005433035968	24088	Economy	11600.00
0005433922211	24088	Economy	11600.00
0005433929567	24088	Economy	11600.00
0005432206161	24088	Economy	11600.00
0005433922026	24088	Economy	11600.00
0005432206158	24088	Economy	11600.00
0005433036001	24088	Economy	11600.00
0005433921669	24088	Economy	11600.00
0005433921961	24088	Economy	11600.00
0005433922193	24088	Economy	11600.00
0005433035964	24088	Economy	11600.00
0005433921633	24088	Economy	11600.00
0005433036000	24088	Economy	11600.00
0005433035989	24088	Economy	11600.00
0005433035973	24088	Economy	11600.00
0005433921804	24088	Economy	11600.00
0005433922121	24088	Economy	11600.00
0005433921897	24088	Economy	11600.00
0005433035963	24088	Economy	11600.00
0005433921951	24088	Economy	11600.00
0005433921632	24088	Economy	11600.00
0005433921637	24088	Economy	11600.00
0005433921856	24088	Economy	11600.00
0005433922175	24088	Economy	11600.00
0005433035985	24088	Economy	11600.00
0005433035994	24088	Economy	11600.00
0005433035997	24088	Economy	11600.00
0005433875353	24088	Economy	11600.00
0005433922051	24088	Economy	11600.00
0005433921835	24088	Economy	11600.00
0005433035992	24088	Economy	11600.00
0005433035998	24088	Economy	11600.00
0005433035958	24088	Economy	11600.00
0005433921621	24088	Economy	11600.00
0005433036002	24088	Economy	11600.00
0005433921643	24088	Economy	11600.00
0005433035990	24088	Economy	11600.00
0005433922010	24088	Economy	11600.00
0005433035953	24088	Economy	11600.00
0005433922171	24088	Economy	11600.00
0005433035974	24088	Economy	11600.00
0005433921929	24088	Economy	11600.00
0005433035957	24088	Economy	11600.00
0005433921974	24088	Economy	11600.00
0005433233446	302	Business	83700.00
0005434724776	302	Business	83700.00
0005433180736	302	Business	83700.00
0005433180762	302	Business	83700.00
0005433233295	302	Business	83700.00
0005432277726	302	Business	83700.00
0005435142499	302	Business	83700.00
0005433233208	302	Business	83700.00
0005434550921	302	Business	83700.00
0005433289762	302	Business	83700.00
0005434724709	302	Business	83700.00
0005434724727	302	Business	83700.00
0005434550907	302	Business	83700.00
0005433233305	302	Business	83700.00
0005433180687	302	Business	83700.00
0005434550877	302	Business	83700.00
0005434550891	302	Business	83700.00
0005434550901	302	Business	83700.00
0005433233205	302	Business	83700.00
0005434724708	302	Business	83700.00
0005434724682	302	Business	83700.00
0005434724785	302	Comfort	47400.00
0005434724777	302	Business	83700.00
0005433233243	302	Comfort	47400.00
0005434724734	302	Comfort	47400.00
0005434724720	302	Comfort	47400.00
0005434724794	302	Comfort	47400.00
0005434724764	302	Comfort	47400.00
0005434724695	302	Comfort	47400.00
0005434550893	302	Comfort	47400.00
0005434724751	302	Comfort	47400.00
0005434550903	302	Comfort	47400.00
0005434550913	302	Comfort	47400.00
0005434724719	302	Comfort	47400.00
0005433233344	302	Comfort	47400.00
0005434724686	302	Comfort	47400.00
0005434550917	302	Comfort	47400.00
0005433233433	302	Comfort	47400.00
0005434550923	302	Comfort	47400.00
0005434550898	302	Comfort	47400.00
0005434724767	302	Comfort	47400.00
0005433180737	302	Comfort	47400.00
0005434550885	302	Comfort	47400.00
0005435142491	302	Comfort	47400.00
0005434550930	302	Comfort	47400.00
0005434724688	302	Comfort	47400.00
0005434724728	302	Comfort	47400.00
0005434724684	302	Comfort	47400.00
0005434724677	302	Comfort	47400.00
0005433180697	302	Comfort	47400.00
0005434724753	302	Comfort	47400.00
0005433180698	302	Comfort	47400.00
0005433233081	302	Comfort	47400.00
0005433766576	302	Comfort	47400.00
0005435142500	302	Comfort	47400.00
0005434031947	302	Comfort	47400.00
0005434724730	302	Comfort	47400.00
0005435142501	302	Comfort	47400.00
0005433180689	302	Comfort	47400.00
0005434724713	302	Comfort	47400.00
0005433233085	302	Comfort	47400.00
0005434724769	302	Comfort	47400.00
0005434724791	302	Comfort	47400.00
0005434724726	302	Comfort	47400.00
0005434724786	302	Comfort	47400.00
0005434724788	302	Comfort	47400.00
0005434724773	302	Comfort	47400.00
0005434724707	302	Comfort	47400.00
0005434550909	302	Economy	27900.00
0005434724747	302	Economy	27900.00
0005434550914	302	Economy	27900.00
0005434550889	302	Economy	27900.00
0005433180724	302	Economy	27900.00
0005433131655	302	Economy	27900.00
0005434550928	302	Economy	27900.00
0005434550888	302	Economy	27900.00
0005435142493	302	Economy	27900.00
0005434724787	302	Economy	27900.00
0005434724783	302	Economy	27900.00
0005434724718	302	Economy	27900.00
0005433180700	302	Economy	27900.00
0005433289747	302	Economy	27900.00
0005434724741	302	Economy	27900.00
0005434735654	302	Economy	27900.00
0005434724683	302	Economy	27900.00
0005433233206	302	Economy	27900.00
0005433233440	302	Economy	27900.00
0005433233366	302	Economy	27900.00
0005433233278	302	Economy	27900.00
0005433233200	302	Economy	27900.00
0005434724746	302	Economy	27900.00
0005433233460	302	Economy	27900.00
0005434550911	302	Economy	27900.00
0005434724736	302	Economy	27900.00
0005434724744	302	Economy	27900.00
0005434724737	302	Economy	27900.00
0005434724699	302	Economy	27900.00
0005432277723	302	Economy	27900.00
0005433180699	302	Economy	27900.00
0005434724721	302	Economy	27900.00
0005434550929	302	Economy	27900.00
0005434550925	302	Economy	27900.00
0005433289753	302	Economy	27900.00
0005434724752	302	Economy	27900.00
0005434724705	302	Economy	27900.00
0005434724724	302	Economy	27900.00
0005434724687	302	Economy	27900.00
0005434724679	302	Economy	27900.00
0005433233448	302	Economy	27900.00
0005434724759	302	Economy	27900.00
0005434550924	302	Economy	27900.00
0005432277722	302	Economy	27900.00
0005434550884	302	Economy	27900.00
0005434724704	302	Economy	27900.00
0005434724750	302	Economy	27900.00
0005434724716	302	Economy	27900.00
0005432277724	302	Economy	27900.00
0005432277729	302	Economy	27900.00
0005433233297	302	Economy	27900.00
0005434724749	302	Economy	27900.00
0005434724714	302	Economy	27900.00
0005434724796	302	Economy	30700.00
0005434302430	302	Economy	27900.00
0005434550883	302	Economy	30700.00
0005434724690	302	Economy	27900.00
0005434550895	302	Economy	27900.00
0005434724782	302	Economy	27900.00
0005434724675	302	Economy	30700.00
0005433233246	302	Economy	27900.00
0005434302431	302	Economy	30700.00
0005433180767	302	Economy	27900.00
0005434724732	302	Economy	27900.00
0005434550905	302	Economy	27900.00
0005435142495	302	Economy	27900.00
0005433233477	302	Economy	27900.00
0005433233327	302	Economy	27900.00
0005434724722	302	Economy	27900.00
0005433126780	302	Economy	27900.00
0005433233084	302	Economy	27900.00
0005434724680	302	Economy	27900.00
0005433233459	302	Economy	27900.00
0005434550890	302	Economy	27900.00
0005434302433	302	Economy	27900.00
0005434724692	302	Economy	27900.00
0005434724757	302	Economy	27900.00
0005434724771	302	Economy	27900.00
0005434550927	302	Economy	27900.00
0005433111473	302	Economy	27900.00
0005433233583	302	Economy	27900.00
0005434724768	302	Economy	27900.00
0005434724748	302	Economy	27900.00
0005433180830	302	Economy	27900.00
0005434724715	302	Economy	27900.00
0005434724711	302	Economy	27900.00
0005435142498	302	Economy	27900.00
0005434724762	302	Economy	27900.00
0005434724766	302	Economy	27900.00
0005435142488	302	Economy	27900.00
0005433233127	302	Economy	27900.00
0005433233256	302	Economy	27900.00
0005434735653	302	Economy	27900.00
0005434731141	302	Economy	27900.00
0005434724702	302	Economy	27900.00
0005434724740	302	Economy	27900.00
0005433233432	302	Economy	27900.00
0005434724698	302	Economy	27900.00
0005434724681	302	Economy	27900.00
0005434724760	302	Economy	27900.00
0005432277727	302	Economy	27900.00
0005434724697	302	Economy	27900.00
0005434724793	302	Economy	27900.00
0005434724795	302	Economy	27900.00
0005434550881	302	Economy	27900.00
0005434550918	302	Economy	27900.00
0005433180770	302	Economy	27900.00
0005433233197	302	Economy	27900.00
0005434550916	302	Economy	27900.00
0005432277733	302	Economy	27900.00
0005434724696	302	Economy	27900.00
0005434724735	302	Economy	27900.00
0005433289763	302	Economy	27900.00
0005433233080	302	Economy	27900.00
0005434735651	302	Economy	27900.00
0005434550902	302	Economy	27900.00
0005434724738	302	Economy	27900.00
0005433180725	302	Economy	27900.00
0005433180717	302	Economy	27900.00
0005435142490	302	Economy	27900.00
0005433233325	302	Economy	27900.00
0005434724758	302	Economy	27900.00
0005434731140	302	Economy	27900.00
0005434550900	302	Economy	27900.00
0005434550887	302	Economy	27900.00
0005434550897	302	Economy	27900.00
0005433233486	302	Economy	27900.00
0005434550910	302	Economy	27900.00
0005433233476	302	Economy	27900.00
0005434735650	302	Economy	27900.00
0005434724706	302	Economy	27900.00
0005434724689	302	Economy	27900.00
0005434724745	302	Economy	27900.00
0005434724739	302	Economy	27900.00
0005433233304	302	Economy	27900.00
0005434550876	302	Economy	27900.00
0005434724765	302	Economy	27900.00
0005433233319	302	Economy	27900.00
0005434302434	302	Economy	27900.00
0005433233484	302	Economy	27900.00
0005434550904	302	Economy	27900.00
0005433131656	302	Economy	27900.00
0005434724723	302	Economy	27900.00
0005434735655	302	Economy	27900.00
0005434724693	302	Economy	27900.00
0005434302855	302	Economy	27900.00
0005434724774	302	Economy	27900.00
0005433233195	302	Economy	30700.00
0005434550922	302	Economy	30700.00
0005434724700	302	Economy	30700.00
0005434724789	302	Economy	30700.00
0005433180763	302	Economy	30700.00
0005434724755	302	Economy	30700.00
0005434550919	302	Economy	27900.00
0005434724678	302	Economy	27900.00
0005433233421	302	Economy	27900.00
0005433233207	302	Economy	27900.00
0005435142502	302	Economy	27900.00
0005434724779	302	Economy	27900.00
0005434550906	302	Economy	27900.00
0005433131631	302	Economy	27900.00
0005434724676	302	Economy	27900.00
0005434550879	302	Economy	27900.00
0005435142489	302	Economy	27900.00
0005434724703	302	Economy	27900.00
0005433233392	302	Economy	27900.00
0005434724710	302	Economy	27900.00
0005432277721	302	Economy	27900.00
0005432277728	302	Economy	27900.00
0005434731139	302	Economy	27900.00
0005433233303	302	Economy	27900.00
0005434550880	302	Economy	27900.00
0005434731142	302	Economy	27900.00
0005433233225	302	Economy	27900.00
0005433180798	302	Economy	27900.00
0005434550931	302	Economy	27900.00
0005433233173	302	Economy	27900.00
0005434031956	302	Economy	27900.00
0005433233110	302	Economy	27900.00
0005434724712	302	Economy	27900.00
0005434724770	302	Economy	27900.00
0005432277725	302	Economy	27900.00
0005434724731	302	Economy	27900.00
0005433180754	302	Economy	27900.00
0005434724691	302	Economy	27900.00
0005434724725	302	Economy	27900.00
0005434724763	302	Economy	27900.00
0005434550920	302	Economy	27900.00
0005434724756	302	Economy	27900.00
0005433233320	302	Economy	27900.00
0005434550899	302	Economy	27900.00
0005434550894	302	Economy	27900.00
0005434724717	302	Economy	27900.00
0005434724792	302	Economy	27900.00
0005433180688	302	Economy	27900.00
0005434724742	302	Economy	27900.00
0005434724685	302	Economy	27900.00
0005434724784	302	Economy	27900.00
0005434724780	302	Economy	27900.00
0005434550915	302	Economy	27900.00
0005432277730	302	Economy	27900.00
0005434302432	302	Economy	27900.00
0005434724754	302	Economy	27900.00
0005434724761	302	Economy	27900.00
0005435142492	302	Economy	27900.00
0005434724733	302	Economy	27900.00
0005434550886	302	Economy	27900.00
0005434724775	302	Economy	27900.00
0005433180696	302	Economy	27900.00
0005434550882	302	Economy	27900.00
0005434724674	302	Economy	27900.00
0005433233442	302	Economy	27900.00
0005434724772	302	Economy	27900.00
0005435142496	302	Economy	27900.00
0005434550908	302	Economy	27900.00
0005434724694	302	Economy	27900.00
0005433113501	302	Economy	27900.00
0005434724743	302	Economy	27900.00
0005432277731	302	Economy	27900.00
0005434550926	302	Economy	27900.00
0005435142494	302	Economy	27900.00
0005434550912	302	Economy	27900.00
0005433233345	302	Economy	27900.00
0005433233117	302	Economy	27900.00
0005434724781	302	Economy	27900.00
0005434724701	302	Economy	27900.00
0005433289727	302	Economy	27900.00
0005432277732	302	Economy	27900.00
0005434550878	302	Economy	27900.00
0005434550896	302	Economy	27900.00
0005435142497	302	Economy	27900.00
0005433233203	302	Economy	27900.00
0005434724790	302	Economy	27900.00
0005434735652	302	Economy	27900.00
0005434724778	302	Economy	27900.00
0005434724729	302	Economy	27900.00
0005434550892	302	Economy	27900.00
0005433180948	9836	Business	83700.00
0005433289801	9836	Business	83700.00
0005433233842	9836	Business	83700.00
0005434723529	9836	Business	83700.00
0005433233825	9836	Business	83700.00
0005434723690	9836	Business	83700.00
0005433233822	9836	Business	83700.00
0005433233818	9836	Business	83700.00
0005433233813	9836	Business	83700.00
0005433180934	9836	Business	83700.00
0005434550388	9836	Business	83700.00
0005434723739	9836	Business	83700.00
0005435142337	9836	Business	83700.00
0005433233804	9836	Business	83700.00
0005433289805	9836	Business	83700.00
0005434550386	9836	Business	83700.00
0005434723678	9836	Business	83700.00
0005433289798	9836	Business	83700.00
0005433233823	9836	Business	83700.00
0005433233828	9836	Business	83700.00
0005434550259	9836	Business	83700.00
0005435142386	9836	Business	83700.00
0005433233841	9836	Business	83700.00
0005434724084	9836	Business	83700.00
0005433180953	9836	Comfort	47400.00
0005433233849	9836	Business	83700.00
0005433180949	9836	Comfort	47400.00
0005434723997	9836	Comfort	47400.00
0005433233846	9836	Comfort	47400.00
0005434550281	9836	Comfort	47400.00
0005433233838	9836	Comfort	47400.00
0005434724111	9836	Comfort	47400.00
0005434723913	9836	Comfort	47400.00
0005434550481	9836	Comfort	47400.00
0005433126816	9836	Comfort	47400.00
0005434723774	9836	Comfort	47400.00
0005434550557	9836	Comfort	47400.00
0005433180952	9836	Comfort	47400.00
0005433129247	9836	Comfort	47400.00
0005433129248	9836	Comfort	47400.00
0005435142388	9836	Comfort	47400.00
0005433180951	9836	Comfort	47400.00
0005433766616	9836	Comfort	47400.00
0005433180940	9836	Comfort	47400.00
0005434723442	9836	Comfort	47400.00
0005434723385	9836	Comfort	47400.00
0005434550383	9836	Comfort	47400.00
0005434723404	9836	Comfort	47400.00
0005434550508	9836	Comfort	47400.00
0005434723969	9836	Comfort	47400.00
0005433180944	9836	Comfort	47400.00
0005434723924	9836	Comfort	47400.00
0005434723770	9836	Comfort	47400.00
0005433233844	9836	Comfort	47400.00
0005434723783	9836	Comfort	47400.00
0005433233830	9836	Comfort	47400.00
0005434723925	9836	Comfort	47400.00
0005433126819	9836	Comfort	47400.00
0005434550446	9836	Comfort	47400.00
0005434550430	9836	Comfort	47400.00
0005434724049	9836	Comfort	47400.00
0005433233837	9836	Comfort	47400.00
0005433233810	9836	Comfort	47400.00
0005433180946	9836	Comfort	47400.00
0005434723674	9836	Comfort	47400.00
0005435142403	9836	Comfort	47400.00
0005434724021	9836	Comfort	47400.00
0005434735620	9836	Economy	27900.00
0005434031999	9836	Economy	27900.00
0005434723754	9836	Economy	27900.00
0005432199207	9836	Economy	27900.00
0005434550411	9836	Economy	27900.00
0005434550357	9836	Economy	27900.00
0005435142363	9836	Economy	27900.00
0005434723652	9836	Economy	27900.00
0005433233827	9836	Economy	27900.00
0005434735599	9836	Economy	27900.00
0005434724219	9836	Economy	27900.00
0005434550366	9836	Economy	27900.00
0005433180945	9836	Economy	27900.00
0005434723934	9836	Economy	27900.00
0005433180936	9836	Economy	27900.00
0005433233798	9836	Economy	27900.00
0005434723496	9836	Economy	27900.00
0005434550352	9836	Economy	27900.00
0005434723491	9836	Economy	27900.00
0005434550480	9836	Economy	27900.00
0005433233851	9836	Economy	27900.00
0005433289804	9836	Economy	27900.00
0005435142341	9836	Economy	27900.00
0005434723781	9836	Economy	27900.00
0005433766618	9836	Economy	27900.00
0005434723651	9836	Economy	27900.00
0005434723436	9836	Economy	27900.00
0005434723721	9836	Economy	27900.00
0005434723711	9836	Economy	27900.00
0005434723916	9836	Economy	27900.00
0005434550365	9836	Economy	27900.00
0005434723756	9836	Economy	27900.00
0005434723849	9836	Economy	27900.00
0005434723612	9836	Economy	27900.00
0005434731114	9836	Economy	27900.00
0005433289807	9836	Economy	27900.00
0005434550501	9836	Economy	27900.00
0005434032000	9836	Economy	27900.00
0005434550368	9836	Economy	27900.00
0005433233847	9836	Economy	27900.00
0005434723474	9836	Economy	27900.00
0005433233797	9836	Economy	27900.00
0005434731096	9836	Economy	27900.00
0005434735613	9836	Economy	27900.00
0005434735598	9836	Economy	27900.00
0005434550522	9836	Economy	27900.00
0005433233821	9836	Economy	27900.00
0005433233791	9836	Economy	27900.00
0005434723905	9836	Economy	27900.00
0005433289802	9836	Economy	27900.00
0005434723507	9836	Economy	27900.00
0005433180955	9836	Economy	30700.00
0005432199205	9836	Economy	27900.00
0005433180933	9836	Economy	30700.00
0005434723709	9836	Economy	27900.00
0005432199204	9836	Economy	27900.00
0005433129246	9836	Economy	27900.00
0005434723766	9836	Economy	27900.00
0005434723509	9836	Economy	30700.00
0005434550301	9836	Economy	30700.00
0005433180943	9836	Economy	30700.00
0005433233832	9836	Economy	27900.00
0005433233836	9836	Economy	27900.00
0005434550413	9836	Economy	27900.00
0005434723691	9836	Economy	27900.00
0005432199206	9836	Economy	27900.00
0005434550581	9836	Economy	27900.00
0005434723927	9836	Economy	27900.00
0005434723750	9836	Economy	27900.00
0005434723858	9836	Economy	27900.00
0005434723831	9836	Economy	27900.00
0005434724134	9836	Economy	27900.00
0005434550449	9836	Economy	27900.00
0005433233795	9836	Economy	27900.00
0005433233839	9836	Economy	27900.00
0005433233805	9836	Economy	27900.00
0005433233814	9836	Economy	27900.00
0005433766615	9836	Economy	27900.00
0005434550488	9836	Economy	27900.00
0005433180941	9836	Economy	27900.00
0005433180942	9836	Economy	27900.00
0005433233803	9836	Economy	27900.00
0005433129249	9836	Economy	27900.00
0005433129251	9836	Economy	27900.00
0005433233809	9836	Economy	27900.00
0005434723352	9836	Economy	27900.00
0005434723926	9836	Economy	27900.00
0005433180957	9836	Economy	27900.00
0005434723547	9836	Economy	27900.00
0005435142338	9836	Economy	27900.00
0005434723407	9836	Economy	27900.00
0005434723570	9836	Economy	27900.00
0005434723848	9836	Economy	27900.00
0005434723510	9836	Economy	27900.00
0005433233807	9836	Economy	27900.00
0005434723331	9836	Economy	27900.00
0005434735603	9836	Economy	27900.00
0005434723505	9836	Economy	27900.00
0005434723737	9836	Economy	27900.00
0005434724276	9836	Economy	27900.00
0005433233845	9836	Economy	27900.00
0005433233812	9836	Economy	27900.00
0005434550367	9836	Economy	27900.00
0005433233819	9836	Economy	27900.00
0005434723332	9836	Economy	27900.00
0005434723348	9836	Economy	27900.00
0005434302384	9836	Economy	27900.00
0005433289800	9836	Economy	27900.00
0005433233800	9836	Economy	27900.00
0005434735607	9836	Economy	27900.00
0005434723637	9836	Economy	27900.00
0005434550483	9836	Economy	27900.00
0005434723530	9836	Economy	27900.00
0005434723405	9836	Economy	27900.00
0005433180947	9836	Economy	27900.00
0005434550298	9836	Economy	27900.00
0005434723755	9836	Economy	27900.00
0005434723618	9836	Economy	27900.00
0005434723809	9836	Economy	27900.00
0005433233831	9836	Economy	27900.00
0005434723493	9836	Economy	27900.00
0005434550326	9836	Economy	27900.00
0005433233802	9836	Economy	27900.00
0005433233843	9836	Economy	27900.00
0005434550432	9836	Economy	27900.00
0005434550389	9836	Economy	27900.00
0005433233850	9836	Economy	27900.00
0005435142387	9836	Economy	27900.00
0005434724025	9836	Economy	27900.00
0005434550578	9836	Economy	27900.00
0005434550351	9836	Economy	27900.00
0005434550421	9836	Economy	27900.00
0005434723490	9836	Economy	27900.00
0005433180956	9836	Economy	27900.00
0005434723450	9836	Economy	27900.00
0005435142394	9836	Economy	27900.00
0005432199202	9836	Economy	27900.00
0005433126814	9836	Economy	27900.00
0005434031996	9836	Economy	27900.00
0005434723416	9836	Economy	27900.00
0005433233816	9836	Economy	27900.00
0005433233817	9836	Economy	27900.00
0005433233835	9836	Economy	27900.00
0005435142404	9836	Economy	27900.00
0005434723353	9836	Economy	27900.00
0005433126815	9836	Economy	30700.00
0005433180938	9836	Economy	30700.00
0005434724261	9836	Economy	30700.00
0005433233848	9836	Economy	30700.00
0005434550325	9836	Economy	30700.00
0005434724024	9836	Economy	30700.00
0005434550384	9836	Economy	27900.00
0005433233796	9836	Economy	27900.00
0005434550495	9836	Economy	27900.00
0005435142344	9836	Economy	27900.00
0005434031995	9836	Economy	27900.00
0005434723765	9836	Economy	27900.00
0005433289799	9836	Economy	27900.00
0005433180935	9836	Economy	27900.00
0005434550577	9836	Economy	27900.00
0005434550377	9836	Economy	27900.00
0005433233826	9836	Economy	27900.00
0005434723499	9836	Economy	27900.00
0005434723707	9836	Economy	27900.00
0005434031997	9836	Economy	27900.00
0005434550284	9836	Economy	27900.00
0005434724260	9836	Economy	27900.00
0005434723840	9836	Economy	27900.00
0005433129250	9836	Economy	27900.00
0005434723506	9836	Economy	27900.00
0005432199203	9836	Economy	27900.00
0005433233833	9836	Economy	27900.00
0005433233852	9836	Economy	27900.00
0005434723904	9836	Economy	27900.00
0005433180950	9836	Economy	27900.00
0005434550410	9836	Economy	27900.00
0005434550331	9836	Economy	27900.00
0005434723569	9836	Economy	27900.00
0005434723782	9836	Economy	27900.00
0005434723687	9836	Economy	27900.00
0005434550422	9836	Economy	27900.00
0005433233793	9836	Economy	27900.00
0005433233834	9836	Economy	27900.00
0005433233811	9836	Economy	27900.00
0005433180954	9836	Economy	27900.00
0005434723968	9836	Economy	27900.00
0005433180939	9836	Economy	27900.00
0005433233808	9836	Economy	27900.00
0005433233789	9836	Economy	27900.00
0005433126817	9836	Economy	27900.00
0005433289806	9836	Economy	27900.00
0005434550500	9836	Economy	27900.00
0005433233820	9836	Economy	27900.00
0005434723982	9836	Economy	27900.00
0005433766617	9836	Economy	27900.00
0005434724326	9836	Economy	27900.00
0005434550429	9836	Economy	27900.00
0005434550420	9836	Economy	27900.00
0005433233794	9836	Economy	27900.00
0005434550260	9836	Economy	27900.00
0005434550320	9836	Economy	27900.00
0005434723714	9836	Economy	27900.00
0005434723517	9836	Economy	27900.00
0005434723738	9836	Economy	27900.00
0005434723356	9836	Economy	27900.00
0005434550484	9836	Economy	27900.00
0005433233806	9836	Economy	27900.00
0005434550280	9836	Economy	27900.00
0005434723689	9836	Economy	27900.00
0005433233840	9836	Economy	27900.00
0005434723548	9836	Economy	27900.00
0005434724133	9836	Economy	27900.00
0005434724325	9836	Economy	27900.00
0005434723733	9836	Economy	27900.00
0005433289803	9836	Economy	27900.00
0005434731115	9836	Economy	27900.00
0005433233815	9836	Economy	27900.00
0005434723909	9836	Economy	27900.00
0005434723386	9836	Economy	27900.00
0005433233788	9836	Economy	27900.00
0005434723355	9836	Economy	27900.00
0005433233799	9836	Economy	27900.00
0005433180937	9836	Economy	27900.00
0005433233829	9836	Economy	27900.00
0005434723441	9836	Economy	27900.00
0005433126818	9836	Economy	27900.00
0005433233792	9836	Economy	27900.00
0005434723957	9836	Economy	27900.00
0005434031998	9836	Economy	27900.00
0005433233824	9836	Economy	27900.00
0005434550339	9836	Economy	27900.00
0005434302383	9836	Economy	27900.00
0005433233790	9836	Economy	27900.00
0005434550511	9836	Economy	27900.00
0005434731108	9836	Economy	27900.00
0005432199208	9836	Economy	27900.00
0005434724165	9836	Economy	27900.00
0005433233801	9836	Economy	27900.00
0005434723887	9836	Economy	27900.00
0005432527121	7720	Business	42100.00
0005432527215	7720	Business	42100.00
0005434067138	7720	Business	42100.00
0005434067097	7720	Business	42100.00
0005434067142	7720	Business	42100.00
0005432527195	7720	Business	42100.00
0005435725537	7720	Business	42100.00
0005434067148	7720	Business	42100.00
0005435212791	7720	Business	42100.00
0005435212417	7720	Business	42100.00
0005435212669	7720	Business	42100.00
0005432069562	7720	Business	42100.00
0005434067135	7720	Business	42100.00
0005432527161	7720	Business	42100.00
0005432527122	7720	Business	42100.00
0005432527177	7720	Business	42100.00
0005435212402	7720	Business	42100.00
0005435212577	7720	Business	42100.00
0005432527175	7720	Business	42100.00
0005432527145	7720	Business	42100.00
0005432527111	7720	Business	42100.00
0005435212607	7720	Business	42100.00
0005432527148	7720	Business	42100.00
0005432428908	7720	Business	42100.00
0005434067156	7720	Business	42100.00
0005435212391	7720	Comfort	23900.00
0005432527144	7720	Comfort	23900.00
0005432527160	7720	Comfort	23900.00
0005432527115	7720	Comfort	23900.00
0005432527193	7720	Comfort	23900.00
0005432527139	7720	Comfort	23900.00
0005432527183	7720	Comfort	23900.00
0005434067154	7720	Comfort	23900.00
0005432527170	7720	Comfort	23900.00
0005435212601	7720	Comfort	23900.00
0005432533274	7720	Comfort	23900.00
0005432150149	7720	Comfort	23900.00
0005432150147	7720	Comfort	23900.00
0005434067120	7720	Comfort	23900.00
0005434067126	7720	Comfort	23900.00
0005432527199	7720	Comfort	23900.00
0005435212415	7720	Comfort	23900.00
0005435212517	7720	Comfort	23900.00
0005432527218	7720	Comfort	23900.00
0005432527219	7720	Comfort	23900.00
0005432527213	7720	Comfort	23900.00
0005432527159	7720	Comfort	23900.00
0005432527186	7720	Comfort	23900.00
0005434067146	7720	Comfort	23900.00
0005432527150	7720	Comfort	23900.00
0005432069570	7720	Comfort	23900.00
0005434067127	7720	Comfort	23900.00
0005434067125	7720	Comfort	23900.00
0005435212575	7720	Comfort	23900.00
0005435212539	7720	Comfort	23900.00
0005432527235	7720	Comfort	23900.00
0005435212770	7720	Comfort	23900.00
0005432069571	7720	Comfort	23900.00
0005432535803	7720	Comfort	23900.00
0005435212405	7720	Comfort	23900.00
0005434067145	7720	Economy	14000.00
0005432527136	7720	Economy	14000.00
0005435212585	7720	Economy	14000.00
0005434067122	7720	Economy	14000.00
0005435212330	7720	Economy	14000.00
0005432527174	7720	Economy	14000.00
0005434067155	7720	Economy	14000.00
0005432527129	7720	Economy	14000.00
0005434067143	7720	Economy	14000.00
0005434067161	7720	Economy	14000.00
0005434067113	7720	Economy	14000.00
0005435212657	7720	Economy	14000.00
0005432527176	7720	Economy	14000.00
0005435212353	7720	Economy	14000.00
0005432527214	7720	Economy	14000.00
0005432150144	7720	Economy	14000.00
0005432527133	7720	Economy	14000.00
0005434067128	7720	Economy	14000.00
0005435212814	7720	Economy	14000.00
0005432527208	7720	Economy	14000.00
0005434067166	7720	Economy	14000.00
0005435212769	7720	Economy	14000.00
0005432527242	7720	Economy	14000.00
0005432527217	7720	Economy	14000.00
0005435212511	7720	Economy	14000.00
0005435212715	7720	Economy	14000.00
0005435212484	7720	Economy	14000.00
0005432527172	7720	Economy	14000.00
0005432535806	7720	Economy	14000.00
0005432150143	7720	Economy	14000.00
0005432527234	7720	Economy	14000.00
0005432527114	7720	Economy	14000.00
0005432527236	7720	Economy	14000.00
0005434067123	7720	Economy	14000.00
0005432527157	7720	Economy	14000.00
0005432527188	7720	Economy	14000.00
0005434067108	7720	Economy	14000.00
0005435212329	7720	Economy	14000.00
0005434067100	7720	Economy	14000.00
0005432535804	7720	Economy	14000.00
0005435212403	7720	Economy	14000.00
0005434067147	7720	Economy	14000.00
0005434067158	7720	Economy	14000.00
0005432527239	7720	Economy	14000.00
0005432527196	7720	Economy	14000.00
0005432069567	7720	Economy	14000.00
0005432428906	7720	Economy	14000.00
0005432537044	7720	Economy	14000.00
0005432150145	7720	Economy	14000.00
0005435212667	7720	Economy	14000.00
0005432527155	7720	Economy	14000.00
0005435212404	7720	Economy	14000.00
0005432527241	7720	Economy	14000.00
0005432527209	7720	Economy	14000.00
0005434067132	7720	Economy	14000.00
0005435212602	7720	Economy	14000.00
0005432069559	7720	Economy	14000.00
0005432527143	7720	Economy	14000.00
0005432527229	7720	Economy	14000.00
0005432527202	7720	Economy	15400.00
0005432527227	7720	Economy	15400.00
0005432069560	7720	Economy	15400.00
0005435212625	7720	Economy	14000.00
0005434067111	7720	Economy	14000.00
0005432527138	7720	Economy	15400.00
0005432527124	7720	Economy	14000.00
0005432527127	7720	Economy	15400.00
0005434067103	7720	Economy	15400.00
0005432527220	7720	Economy	14000.00
0005434067139	7720	Economy	14000.00
0005434067117	7720	Economy	14000.00
0005435212574	7720	Economy	14000.00
0005435212450	7720	Economy	14000.00
0005434067109	7720	Economy	14000.00
0005435212722	7720	Economy	14000.00
0005434067151	7720	Economy	14000.00
0005435212700	7720	Economy	14000.00
0005435212568	7720	Economy	14000.00
0005432069568	7720	Economy	14000.00
0005435212661	7720	Economy	14000.00
0005432527110	7720	Economy	14000.00
0005432527212	7720	Economy	14000.00
0005432527153	7720	Economy	14000.00
0005435212504	7720	Economy	14000.00
0005432527166	7720	Economy	14000.00
0005435212395	7720	Economy	14000.00
0005435212453	7720	Economy	14000.00
0005434067134	7720	Economy	14000.00
0005432527112	7720	Economy	14000.00
0005432527135	7720	Economy	14000.00
0005434067099	7720	Economy	14000.00
0005435212438	7720	Economy	14000.00
0005432527154	7720	Economy	14000.00
0005432527120	7720	Economy	14000.00
0005434067159	7720	Economy	14000.00
0005434067112	7720	Economy	14000.00
0005432527221	7720	Economy	14000.00
0005434067149	7720	Economy	14000.00
0005432527207	7720	Economy	14000.00
0005432533272	7720	Economy	14000.00
0005432527149	7720	Economy	14000.00
0005432527163	7720	Economy	14000.00
0005432527243	7720	Economy	14000.00
0005432527158	7720	Economy	14000.00
0005432527123	7720	Economy	14000.00
0005432527147	7720	Economy	14000.00
0005435212576	7720	Economy	14000.00
0005434067104	7720	Economy	14000.00
0005434067164	7720	Economy	14000.00
0005432527187	7720	Economy	14000.00
0005435725519	7720	Economy	14000.00
0005432527178	7720	Economy	14000.00
0005432527117	7720	Economy	14000.00
0005432527210	7720	Economy	14000.00
0005434067160	7720	Economy	14000.00
0005432527190	7720	Economy	14000.00
0005433656613	7720	Economy	14000.00
0005434067133	7720	Economy	14000.00
0005432527180	7720	Economy	14000.00
0005432527146	7720	Economy	14000.00
0005434067110	7720	Economy	14000.00
0005434067119	7720	Economy	14000.00
0005432069566	7720	Economy	14000.00
0005432527224	7720	Economy	14000.00
0005432527119	7720	Economy	14000.00
0005432527223	7720	Economy	14000.00
0005432527140	7720	Economy	14000.00
0005434067136	7720	Economy	14000.00
0005434067140	7720	Economy	14000.00
0005432527203	7720	Economy	14000.00
0005434067107	7720	Economy	14000.00
0005432527182	7720	Economy	14000.00
0005435212573	7720	Economy	14000.00
0005432527171	7720	Economy	14000.00
0005432527116	7720	Economy	14000.00
0005432527238	7720	Economy	14000.00
0005435212670	7720	Economy	14000.00
0005432527126	7720	Economy	14000.00
0005434067165	7720	Economy	14000.00
0005434067153	7720	Economy	14000.00
0005432527240	7720	Economy	14000.00
0005434067150	7720	Economy	14000.00
0005432535802	7720	Economy	14000.00
0005435212433	7720	Economy	14000.00
0005432069561	7720	Economy	14000.00
0005432527211	7720	Economy	14000.00
0005435212600	7720	Economy	14000.00
0005432527189	7720	Economy	14000.00
0005434067130	7720	Economy	14000.00
0005434067121	7720	Economy	14000.00
0005432069563	7720	Economy	14000.00
0005432527216	7720	Economy	14000.00
0005434067102	7720	Economy	15400.00
0005434067144	7720	Economy	15400.00
0005435212538	7720	Economy	15400.00
0005432527173	7720	Economy	15400.00
0005432527165	7720	Economy	15400.00
0005432527230	7720	Economy	14000.00
0005432527179	7720	Economy	15400.00
0005435212588	7720	Economy	14000.00
0005435212656	7720	Economy	14000.00
0005432527168	7720	Economy	14000.00
0005434067101	7720	Economy	14000.00
0005432069565	7720	Economy	14000.00
0005432535805	7720	Economy	14000.00
0005432533273	7720	Economy	14000.00
0005432527226	7720	Economy	14000.00
0005432527113	7720	Economy	14000.00
0005435212714	7720	Economy	14000.00
0005432527205	7720	Economy	14000.00
0005432527204	7720	Economy	14000.00
0005432527132	7720	Economy	14000.00
0005432527137	7720	Economy	14000.00
0005432527225	7720	Economy	14000.00
0005432527169	7720	Economy	14000.00
0005432527156	7720	Economy	14000.00
0005435725538	7720	Economy	14000.00
0005432527118	7720	Economy	14000.00
0005434067094	7720	Economy	14000.00
0005432527192	7720	Economy	14000.00
0005434067114	7720	Economy	14000.00
0005432527151	7720	Economy	14000.00
0005435212572	7720	Economy	14000.00
0005432527198	7720	Economy	14000.00
0005434067152	7720	Economy	14000.00
0005434067163	7720	Economy	14000.00
0005435212797	7720	Economy	14000.00
0005434067137	7720	Economy	14000.00
0005432527232	7720	Economy	14000.00
0005433656614	7720	Economy	14000.00
0005435212366	7720	Economy	14000.00
0005434067162	7720	Economy	14000.00
0005432527128	7720	Economy	14000.00
0005432428907	7720	Economy	14000.00
0005432527228	7720	Economy	14000.00
0005432527233	7720	Economy	14000.00
0005432527184	7720	Economy	14000.00
0005434067157	7720	Economy	14000.00
0005435212507	7720	Economy	14000.00
0005432527162	7720	Economy	14000.00
0005435212367	7720	Economy	14000.00
0005434067095	7720	Economy	14000.00
0005432527237	7720	Economy	14000.00
0005432527185	7720	Economy	14000.00
0005432527134	7720	Economy	14000.00
0005435212668	7720	Economy	14000.00
0005434067115	7720	Economy	14000.00
0005434067105	7720	Economy	14000.00
0005432527131	7720	Economy	14000.00
0005432527141	7720	Economy	14000.00
0005432527142	7720	Economy	14000.00
0005434067116	7720	Economy	14000.00
0005432527201	7720	Economy	14000.00
0005435212587	7720	Economy	14000.00
0005432069569	7720	Economy	14000.00
0005435212792	7720	Economy	14000.00
0005432069564	7720	Economy	14000.00
0005434067141	7720	Economy	14000.00
0005432527167	7720	Economy	14000.00
0005432150146	7720	Economy	14000.00
0005432527164	7720	Economy	14000.00
0005434067118	7720	Economy	14000.00
0005432527181	7720	Economy	14000.00
0005432527200	7720	Economy	14000.00
0005432527231	7720	Economy	14000.00
0005432150148	7720	Economy	14000.00
0005434067096	7720	Economy	14000.00
0005432069572	7720	Economy	14000.00
0005432527197	7720	Economy	14000.00
0005432527130	7720	Economy	14000.00
0005432527191	7720	Economy	14000.00
0005434067106	7720	Economy	14000.00
0005434067131	7720	Economy	14000.00
0005435212399	7720	Economy	14000.00
0005432527194	7720	Economy	14000.00
0005435212392	7720	Economy	14000.00
0005434067124	7720	Economy	14000.00
0005432527222	7720	Economy	14000.00
0005434067129	7720	Economy	14000.00
0005432527152	7720	Economy	14000.00
0005432527125	7720	Economy	14000.00
0005435212328	7720	Economy	14000.00
0005432527206	7720	Economy	14000.00
0005435212458	7720	Economy	14000.00
0005434067098	7720	Economy	14000.00
0005435612946	5310	Business	43100.00
0005434573264	5310	Business	43100.00
0005435612973	5310	Business	43100.00
0005435613019	5310	Business	43100.00
0005435423856	5310	Business	43100.00
0005434343998	5310	Business	43100.00
0005434244507	5310	Business	43100.00
0005435612959	5310	Business	43100.00
0005435612920	5310	Business	43100.00
0005434344009	5310	Business	43100.00
0005435612947	5310	Business	43100.00
0005432133114	5310	Business	43100.00
0005435612943	5310	Business	43100.00
0005434343997	5310	Business	43100.00
0005435319465	5310	Business	43100.00
0005434344002	5310	Business	43100.00
0005435097149	5310	Business	43100.00
0005435423872	5310	Business	43100.00
0005435612986	5310	Business	43100.00
0005432133125	5310	Business	43100.00
0005434344004	5310	Business	43100.00
0005435612930	5310	Business	43100.00
0005434244567	5310	Business	43100.00
0005435423724	5310	Business	43100.00
0005435490206	5310	Comfort	24400.00
0005435423977	5310	Business	43100.00
0005435097146	5310	Comfort	24400.00
0005435612966	5310	Comfort	24400.00
0005435423591	5310	Comfort	24400.00
0005435097151	5310	Comfort	24400.00
0005434344001	5310	Comfort	24400.00
0005434573267	5310	Comfort	24400.00
0005432133111	5310	Comfort	24400.00
0005435424109	5310	Comfort	24400.00
0005435423704	5310	Comfort	24400.00
0005434344008	5310	Comfort	24400.00
0005434343996	5310	Comfort	24400.00
0005434244498	5310	Comfort	24400.00
0005435423978	5310	Comfort	24400.00
0005435423955	5310	Comfort	24400.00
0005435612911	5310	Comfort	24400.00
0005435555356	5310	Comfort	24400.00
0005435423830	5310	Comfort	24400.00
0005432133115	5310	Comfort	24400.00
0005432047527	5310	Comfort	24400.00
0005435612988	5310	Comfort	24400.00
0005434573266	5310	Comfort	24400.00
0005435423800	5310	Comfort	24400.00
0005434344022	5310	Comfort	24400.00
0005435423911	5310	Comfort	24400.00
0005435319450	5310	Comfort	24400.00
0005435491428	5310	Comfort	24400.00
0005435612953	5310	Comfort	24400.00
0005434244572	5310	Comfort	24400.00
0005435380247	5310	Comfort	24400.00
0005432133121	5310	Comfort	24400.00
0005435097147	5310	Comfort	24400.00
0005435612971	5310	Comfort	24400.00
0005435612913	5310	Comfort	24400.00
0005435612936	5310	Comfort	24400.00
0005435319443	5310	Comfort	24400.00
0005435612997	5310	Comfort	24400.00
0005435423914	5310	Comfort	24400.00
0005432840982	5310	Comfort	24400.00
0005435612961	5310	Economy	14400.00
0005435423916	5310	Economy	14400.00
0005435613007	5310	Economy	14400.00
0005435613002	5310	Economy	14400.00
0005435380231	5310	Economy	14400.00
0005435424091	5310	Economy	14400.00
0005435612992	5310	Economy	14400.00
0005435612942	5310	Economy	14400.00
0005435423575	5310	Economy	14400.00
0005434344011	5310	Economy	14400.00
0005435612951	5310	Economy	14400.00
0005434244614	5310	Economy	14400.00
0005435319439	5310	Economy	14400.00
0005432840985	5310	Economy	14400.00
0005435612980	5310	Economy	14400.00
0005435612915	5310	Economy	14400.00
0005435612967	5310	Economy	14400.00
0005434244521	5310	Economy	14400.00
0005435612987	5310	Economy	14400.00
0005435612916	5310	Economy	14400.00
0005434573272	5310	Economy	14400.00
0005434244538	5310	Economy	14400.00
0005435302130	5310	Economy	14400.00
0005435042825	5310	Economy	14400.00
0005434344003	5310	Economy	14400.00
0005434573261	5310	Economy	14400.00
0005435612926	5310	Economy	14400.00
0005434344020	5310	Economy	14400.00
0005435612941	5310	Economy	14400.00
0005435612963	5310	Economy	14400.00
0005435612929	5310	Economy	14400.00
0005435613006	5310	Economy	14400.00
0005435319482	5310	Economy	14400.00
0005435613015	5310	Economy	14400.00
0005435612974	5310	Economy	14400.00
0005434244546	5310	Economy	14400.00
0005435423953	5310	Economy	14400.00
0005435490204	5310	Economy	14400.00
0005435612989	5310	Economy	14400.00
0005432133123	5310	Economy	14400.00
0005435424000	5310	Economy	14400.00
0005434344023	5310	Economy	14400.00
0005435612969	5310	Economy	14400.00
0005435612933	5310	Economy	14400.00
0005435612977	5310	Economy	14400.00
0005434343999	5310	Economy	14400.00
0005435612979	5310	Economy	14400.00
0005434244566	5310	Economy	14400.00
0005435613003	5310	Economy	14400.00
0005434573270	5310	Economy	14400.00
0005435423873	5310	Economy	14400.00
0005435612998	5310	Economy	14400.00
0005435613000	5310	Economy	14400.00
0005434344014	5310	Economy	14400.00
0005435097152	5310	Economy	14400.00
0005435424093	5310	Economy	14400.00
0005432133119	5310	Economy	14400.00
0005435612983	5310	Economy	14400.00
0005434344007	5310	Economy	14400.00
0005434344016	5310	Economy	14400.00
0005435612972	5310	Economy	14400.00
0005435612949	5310	Economy	14400.00
0005435423996	5310	Economy	14400.00
0005435423831	5310	Economy	15800.00
0005432840981	5310	Economy	15800.00
0005434244551	5310	Economy	14400.00
0005435612996	5310	Economy	14400.00
0005435612944	5310	Economy	14400.00
0005435612924	5310	Economy	14400.00
0005435319484	5310	Economy	14400.00
0005434343991	5310	Economy	14400.00
0005435612962	5310	Economy	14400.00
0005435423888	5310	Economy	14400.00
0005434344021	5310	Economy	14400.00
0005434344012	5310	Economy	14400.00
0005435612932	5310	Economy	14400.00
0005435424061	5310	Economy	14400.00
0005435612954	5310	Economy	14400.00
0005435490205	5310	Economy	14400.00
0005435319442	5310	Economy	14400.00
0005435612995	5310	Economy	14400.00
0005434573269	5310	Economy	14400.00
0005435613001	5310	Economy	14400.00
0005435612909	5310	Economy	14400.00
0005433719089	5310	Economy	14400.00
0005435042822	5310	Economy	14400.00
0005435304989	5310	Economy	14400.00
0005432133113	5310	Economy	14400.00
0005435423991	5310	Economy	14400.00
0005435612931	5310	Economy	14400.00
0005434244650	5310	Economy	14400.00
0005435319462	5310	Economy	14400.00
0005435097156	5310	Economy	14400.00
0005435613012	5310	Economy	14400.00
0005435319440	5310	Economy	14400.00
0005434344000	5310	Economy	14400.00
0005435423837	5310	Economy	14400.00
0005435612957	5310	Economy	14400.00
0005435613011	5310	Economy	14400.00
0005435423890	5310	Economy	14400.00
0005434573273	5310	Economy	14400.00
0005435612978	5310	Economy	14400.00
0005435612945	5310	Economy	14400.00
0005435612993	5310	Economy	14400.00
0005435097154	5310	Economy	14400.00
0005434344015	5310	Economy	14400.00
0005435612910	5310	Economy	14400.00
0005434344019	5310	Economy	14400.00
0005435613004	5310	Economy	14400.00
0005435612958	5310	Economy	14400.00
0005434244477	5310	Economy	14400.00
0005435612990	5310	Economy	14400.00
0005434343995	5310	Economy	14400.00
0005435302129	5310	Economy	14400.00
0005435612928	5310	Economy	14400.00
0005435423982	5310	Economy	14400.00
0005432363384	5310	Economy	14400.00
0005435424024	5310	Economy	14400.00
0005435612908	5310	Economy	14400.00
0005434244520	5310	Economy	14400.00
0005435424056	5310	Economy	14400.00
0005435612939	5310	Economy	14400.00
0005434343992	5310	Economy	14400.00
0005434244568	5310	Economy	14400.00
0005434343988	5310	Economy	14400.00
0005435424004	5310	Economy	14400.00
0005435097148	5310	Economy	14400.00
0005435612960	5310	Economy	14400.00
0005435423860	5310	Economy	14400.00
0005435612952	5310	Economy	14400.00
0005435612938	5310	Economy	14400.00
0005434344018	5310	Economy	14400.00
0005435423903	5310	Economy	14400.00
0005432840986	5310	Economy	14400.00
0005435424057	5310	Economy	14400.00
0005432133112	5310	Economy	14400.00
0005435042824	5310	Economy	14400.00
0005435612970	5310	Economy	14400.00
0005435612927	5310	Economy	14400.00
0005435319466	5310	Economy	14400.00
0005435423904	5310	Economy	14400.00
0005435612907	5310	Economy	14400.00
0005435613016	5310	Economy	14400.00
0005435612950	5310	Economy	14400.00
0005435302128	5310	Economy	14400.00
0005434344010	5310	Economy	14400.00
0005435423857	5310	Economy	14400.00
0005435612914	5310	Economy	14400.00
0005434573265	5310	Economy	14400.00
0005434573262	5310	Economy	14400.00
0005432047528	5310	Economy	14400.00
0005435612922	5310	Economy	14400.00
0005435042820	5310	Economy	15800.00
0005434344006	5310	Economy	14400.00
0005434344017	5310	Economy	15800.00
0005435612981	5310	Economy	15800.00
0005435612984	5310	Economy	15800.00
0005432133118	5310	Economy	14400.00
0005434573271	5310	Economy	14400.00
0005434343990	5310	Economy	14400.00
0005433719082	5310	Economy	14400.00
0005435423864	5310	Economy	14400.00
0005434344013	5310	Economy	14400.00
0005435424066	5310	Economy	14400.00
0005434343989	5310	Economy	14400.00
0005435304996	5310	Economy	14400.00
0005434244553	5310	Economy	14400.00
0005435423600	5310	Economy	14400.00
0005435612917	5310	Economy	14400.00
0005435612921	5310	Economy	14400.00
0005435612975	5310	Economy	14400.00
0005435613005	5310	Economy	14400.00
0005435612955	5310	Economy	14400.00
0005435424161	5310	Economy	14400.00
0005435424002	5310	Economy	14400.00
0005435612925	5310	Economy	14400.00
0005435613008	5310	Economy	14400.00
0005435612923	5310	Economy	14400.00
0005435423901	5310	Economy	14400.00
0005435424003	5310	Economy	14400.00
0005435423990	5310	Economy	14400.00
0005435424067	5310	Economy	14400.00
0005435612982	5310	Economy	14400.00
0005435424160	5310	Economy	14400.00
0005435423660	5310	Economy	14400.00
0005435613009	5310	Economy	14400.00
0005435612964	5310	Economy	14400.00
0005435042829	5310	Economy	14400.00
0005432047526	5310	Economy	14400.00
0005432133120	5310	Economy	14400.00
0005435424092	5310	Economy	14400.00
0005434244588	5310	Economy	14400.00
0005435423902	5310	Economy	14400.00
0005435612919	5310	Economy	14400.00
0005435612940	5310	Economy	14400.00
0005435612976	5310	Economy	14400.00
0005435613013	5310	Economy	14400.00
0005435319483	5310	Economy	14400.00
0005435491429	5310	Economy	14400.00
0005434343994	5310	Economy	14400.00
0005435042830	5310	Economy	14400.00
0005435423889	5310	Economy	14400.00
0005435423705	5310	Economy	14400.00
0005435423913	5310	Economy	14400.00
0005432133124	5310	Economy	14400.00
0005435423594	5310	Economy	14400.00
0005435490203	5310	Economy	14400.00
0005435490207	5310	Economy	14400.00
0005434343993	5310	Economy	14400.00
0005435612965	5310	Economy	14400.00
0005435612937	5310	Economy	14400.00
0005435423659	5310	Economy	14400.00
0005434573268	5310	Economy	14400.00
0005435097155	5310	Economy	14400.00
0005435612906	5310	Economy	14400.00
0005435612918	5310	Economy	14400.00
0005435612934	5310	Economy	14400.00
0005435097153	5310	Economy	14400.00
0005435612935	5310	Economy	14400.00
0005435424051	5310	Economy	14400.00
0005435612912	5310	Economy	14400.00
0005435613018	5310	Economy	14400.00
0005432133116	5310	Economy	14400.00
0005434344005	5310	Economy	14400.00
0005435423931	5310	Economy	14400.00
0005435612956	5310	Economy	14400.00
0005432133117	5310	Economy	14400.00
0005432363361	5310	Economy	14400.00
0005435612999	5310	Economy	14400.00
0005435613010	5310	Economy	14400.00
0005435612948	5310	Economy	14400.00
0005435612991	5310	Economy	14400.00
0005435097150	5310	Economy	14400.00
0005435612985	5310	Economy	14400.00
0005435613014	5310	Economy	14400.00
0005434573263	5310	Economy	14400.00
0005432840980	5310	Economy	14400.00
0005432133122	5310	Economy	14400.00
0005434244552	5310	Economy	14400.00
0005435612968	5310	Economy	14400.00
0005432047525	5310	Economy	14400.00
0005435612994	5310	Economy	14400.00
0005435613017	5310	Economy	14400.00
0005435042821	5310	Economy	14400.00
0005435424410	10933	Business	43100.00
0005435424367	10933	Business	43100.00
0005435424353	10933	Business	43100.00
0005435319519	10933	Business	43100.00
0005435611954	10933	Business	43100.00
0005435424407	10933	Business	43100.00
0005435424417	10933	Business	43100.00
0005435611912	10933	Business	43100.00
0005435424416	10933	Business	43100.00
0005435612255	10933	Business	43100.00
0005435611951	10933	Business	43100.00
0005435424369	10933	Business	43100.00
0005435424404	10933	Business	43100.00
0005435491413	10933	Business	43100.00
0005432164993	10933	Business	43100.00
0005435424385	10933	Business	43100.00
0005432164989	10933	Business	43100.00
0005435424420	10933	Business	43100.00
0005435612108	10933	Business	43100.00
0005435424381	10933	Business	43100.00
0005433719121	10933	Comfort	24400.00
0005434343615	10933	Comfort	24400.00
0005434573107	10933	Comfort	24400.00
0005435612102	10933	Comfort	24400.00
0005435612159	10933	Comfort	24400.00
0005435042840	10933	Comfort	24400.00
0005435424360	10933	Comfort	24400.00
0005435042842	10933	Comfort	24400.00
0005435424374	10933	Comfort	24400.00
0005435612054	10933	Comfort	24400.00
0005434244815	10933	Comfort	24400.00
0005435424377	10933	Comfort	24400.00
0005435611788	10933	Comfort	24400.00
0005434244800	10933	Comfort	24400.00
0005435611771	10933	Comfort	24400.00
0005435042843	10933	Comfort	24400.00
0005435612262	10933	Comfort	24400.00
0005435612086	10933	Comfort	24400.00
0005435424397	10933	Comfort	24400.00
0005435319517	10933	Comfort	24400.00
0005435611890	10933	Comfort	24400.00
0005435424366	10933	Comfort	24400.00
0005434343622	10933	Comfort	24400.00
0005435424379	10933	Comfort	24400.00
0005432164987	10933	Comfort	24400.00
0005435612080	10933	Comfort	24400.00
0005435612019	10933	Comfort	24400.00
0005434656543	10933	Comfort	24400.00
0005434573114	10933	Comfort	24400.00
0005435611718	10933	Comfort	24400.00
0005435319514	10933	Comfort	24400.00
0005435612028	10933	Comfort	24400.00
0005435612428	10933	Comfort	24400.00
0005435424351	10933	Comfort	24400.00
0005435424395	10933	Economy	14400.00
0005435555338	10933	Comfort	24400.00
0005435612233	10933	Economy	14400.00
0005434244795	10933	Economy	14400.00
0005434343740	10933	Economy	14400.00
0005435612294	10933	Economy	14400.00
0005435424405	10933	Economy	14400.00
0005435611796	10933	Economy	14400.00
0005435612418	10933	Economy	14400.00
0005435424387	10933	Economy	14400.00
0005435424406	10933	Economy	14400.00
0005434343745	10933	Economy	14400.00
0005435424364	10933	Economy	14400.00
0005434244793	10933	Economy	14400.00
0005435305002	10933	Economy	14400.00
0005435612431	10933	Economy	14400.00
0005435424411	10933	Economy	14400.00
0005434244814	10933	Economy	14400.00
0005435612412	10933	Economy	14400.00
0005434343670	10933	Economy	14400.00
0005434573154	10933	Economy	14400.00
0005435611993	10933	Economy	14400.00
0005435611722	10933	Economy	14400.00
0005435612176	10933	Economy	14400.00
0005435612209	10933	Economy	14400.00
0005434343632	10933	Economy	14400.00
0005435304128	10933	Economy	14400.00
0005432841000	10933	Economy	14400.00
0005434244809	10933	Economy	14400.00
0005434244802	10933	Economy	14400.00
0005435612308	10933	Economy	14400.00
0005435612107	10933	Economy	14400.00
0005434343640	10933	Economy	14400.00
0005435611952	10933	Economy	14400.00
0005435611783	10933	Economy	14400.00
0005435612310	10933	Economy	14400.00
0005435612432	10933	Economy	14400.00
0005435612085	10933	Economy	14400.00
0005434244807	10933	Economy	14400.00
0005435612346	10933	Economy	14400.00
0005434244801	10933	Economy	14400.00
0005435612093	10933	Economy	14400.00
0005435611746	10933	Economy	14400.00
0005434343736	10933	Economy	14400.00
0005434343771	10933	Economy	14400.00
0005435612586	10933	Economy	14400.00
0005435612079	10933	Economy	14400.00
0005435612082	10933	Economy	14400.00
0005434244805	10933	Economy	14400.00
0005435612314	10933	Economy	14400.00
0005435424372	10933	Economy	14400.00
0005435424373	10933	Economy	14400.00
0005435424361	10933	Economy	14400.00
0005435611999	10933	Economy	14400.00
0005434244811	10933	Economy	14400.00
0005435612223	10933	Economy	14400.00
0005435424408	10933	Economy	14400.00
0005435424414	10933	Economy	14400.00
0005435612271	10933	Economy	15800.00
0005435491414	10933	Economy	15800.00
0005434573157	10933	Economy	15800.00
0005435612065	10933	Economy	14400.00
0005435424399	10933	Economy	14400.00
0005434343706	10933	Economy	15800.00
0005434244796	10933	Economy	15800.00
0005435319520	10933	Economy	15800.00
0005433719120	10933	Economy	14400.00
0005434343641	10933	Economy	14400.00
0005435424422	10933	Economy	14400.00
0005435424390	10933	Economy	14400.00
0005434343650	10933	Economy	14400.00
0005435424382	10933	Economy	14400.00
0005435611994	10933	Economy	14400.00
0005435612066	10933	Economy	14400.00
0005435612157	10933	Economy	14400.00
0005434244813	10933	Economy	14400.00
0005434573118	10933	Economy	14400.00
0005435612309	10933	Economy	14400.00
0005435612072	10933	Economy	14400.00
0005435424378	10933	Economy	14400.00
0005435305001	10933	Economy	14400.00
0005435611882	10933	Economy	14400.00
0005432841001	10933	Economy	14400.00
0005435612312	10933	Economy	14400.00
0005435612143	10933	Economy	14400.00
0005435612103	10933	Economy	14400.00
0005434244797	10933	Economy	14400.00
0005434573121	10933	Economy	14400.00
0005435424394	10933	Economy	14400.00
0005435611948	10933	Economy	14400.00
0005435612044	10933	Economy	14400.00
0005435424409	10933	Economy	14400.00
0005435612074	10933	Economy	14400.00
0005435319515	10933	Economy	14400.00
0005435611949	10933	Economy	14400.00
0005434343616	10933	Economy	14400.00
0005435611713	10933	Economy	14400.00
0005435424391	10933	Economy	14400.00
0005435305004	10933	Economy	14400.00
0005434343603	10933	Economy	14400.00
0005435612134	10933	Economy	14400.00
0005435612599	10933	Economy	14400.00
0005435042839	10933	Economy	14400.00
0005435612289	10933	Economy	14400.00
0005435424368	10933	Economy	14400.00
0005435304129	10933	Economy	14400.00
0005434656544	10933	Economy	14400.00
0005432166881	10933	Economy	14400.00
0005435612213	10933	Economy	14400.00
0005435612022	10933	Economy	14400.00
0005434244804	10933	Economy	14400.00
0005435319518	10933	Economy	14400.00
0005435304130	10933	Economy	14400.00
0005435611851	10933	Economy	14400.00
0005435612208	10933	Economy	14400.00
0005435611891	10933	Economy	14400.00
0005435611968	10933	Economy	14400.00
0005435424403	10933	Economy	14400.00
0005435612347	10933	Economy	14400.00
0005435305003	10933	Economy	14400.00
0005435612124	10933	Economy	14400.00
0005435611955	10933	Economy	14400.00
0005434244812	10933	Economy	14400.00
0005434244803	10933	Economy	14400.00
0005435424401	10933	Economy	14400.00
0005434343671	10933	Economy	14400.00
0005434573155	10933	Economy	14400.00
0005435424389	10933	Economy	14400.00
0005435424375	10933	Economy	14400.00
0005435424356	10933	Economy	14400.00
0005434573153	10933	Economy	14400.00
0005435612471	10933	Economy	14400.00
0005434573117	10933	Economy	14400.00
0005432164992	10933	Economy	14400.00
0005435612075	10933	Economy	14400.00
0005435424412	10933	Economy	14400.00
0005435611856	10933	Economy	14400.00
0005434244789	10933	Economy	14400.00
0005435612125	10933	Economy	14400.00
0005432166880	10933	Economy	14400.00
0005434343582	10933	Economy	14400.00
0005432840999	10933	Economy	14400.00
0005435424419	10933	Economy	14400.00
0005435424418	10933	Economy	14400.00
0005435555342	10933	Economy	14400.00
0005435611980	10933	Economy	14400.00
0005434244794	10933	Economy	14400.00
0005435611881	10933	Economy	14400.00
0005435424413	10933	Economy	14400.00
0005434343681	10933	Economy	14400.00
0005435424359	10933	Economy	14400.00
0005435042841	10933	Economy	14400.00
0005435319522	10933	Economy	14400.00
0005435304127	10933	Economy	14400.00
0005435611953	10933	Economy	14400.00
0005432363395	10933	Economy	14400.00
0005434573113	10933	Economy	14400.00
0005435424376	10933	Economy	14400.00
0005435424398	10933	Economy	14400.00
0005434244787	10933	Economy	15800.00
0005435612041	10933	Economy	14400.00
0005435612221	10933	Economy	14400.00
0005435612275	10933	Economy	14400.00
0005432164991	10933	Economy	14400.00
0005435612000	10933	Economy	14400.00
0005434244792	10933	Economy	14400.00
0005432164990	10933	Economy	14400.00
0005434573136	10933	Economy	14400.00
0005435424388	10933	Economy	14400.00
0005435612234	10933	Economy	14400.00
0005434343705	10933	Economy	14400.00
0005435424358	10933	Economy	14400.00
0005435611922	10933	Economy	14400.00
0005432164988	10933	Economy	14400.00
0005434343678	10933	Economy	14400.00
0005434244810	10933	Economy	14400.00
0005435424384	10933	Economy	14400.00
0005435424380	10933	Economy	14400.00
0005435424363	10933	Economy	14400.00
0005435424392	10933	Economy	14400.00
0005435611770	10933	Economy	14400.00
0005435611972	10933	Economy	14400.00
0005435611703	10933	Economy	14400.00
0005434244808	10933	Economy	14400.00
0005435611894	10933	Economy	14400.00
0005433719119	10933	Economy	14400.00
0005435612293	10933	Economy	14400.00
0005435424354	10933	Economy	14400.00
0005435611850	10933	Economy	14400.00
0005435319521	10933	Economy	14400.00
0005434343679	10933	Economy	14400.00
0005435424396	10933	Economy	14400.00
0005435612220	10933	Economy	14400.00
0005435424402	10933	Economy	14400.00
0005435424371	10933	Economy	14400.00
0005435424400	10933	Economy	14400.00
0005435612429	10933	Economy	14400.00
0005435612332	10933	Economy	14400.00
0005434343593	10933	Economy	14400.00
0005435612104	10933	Economy	14400.00
0005434573133	10933	Economy	14400.00
0005435611843	10933	Economy	14400.00
0005435424352	10933	Economy	14400.00
0005435424383	10933	Economy	14400.00
0005435611794	10933	Economy	14400.00
0005435424415	10933	Economy	14400.00
0005435304131	10933	Economy	14400.00
0005435424357	10933	Economy	14400.00
0005435611969	10933	Economy	14400.00
0005432166882	10933	Economy	14400.00
0005435611761	10933	Economy	14400.00
0005434244806	10933	Economy	14400.00
0005435612175	10933	Economy	14400.00
0005435611855	10933	Economy	14400.00
0005432363396	10933	Economy	14400.00
0005435612297	10933	Economy	14400.00
0005434244798	10933	Economy	14400.00
0005435611913	10933	Economy	14400.00
0005435611712	10933	Economy	14400.00
0005435490176	10933	Economy	14400.00
0005435611842	10933	Economy	14400.00
0005432164994	10933	Economy	14400.00
0005435612073	10933	Economy	14400.00
0005434573111	10933	Economy	14400.00
0005435612313	10933	Economy	14400.00
0005435612067	10933	Economy	14400.00
0005435424362	10933	Economy	14400.00
0005435319523	10933	Economy	14400.00
0005435424365	10933	Economy	14400.00
0005435424393	10933	Economy	14400.00
0005432363397	10933	Economy	14400.00
0005435612092	10933	Economy	14400.00
0005435611820	10933	Economy	14400.00
0005434244799	10933	Economy	14400.00
0005435611945	10933	Economy	14400.00
0005434244790	10933	Economy	14400.00
0005435319516	10933	Economy	14400.00
0005435612001	10933	Economy	14400.00
0005435424386	10933	Economy	14400.00
0005434343744	10933	Economy	14400.00
0005434244791	10933	Economy	14400.00
0005434244788	10933	Economy	14400.00
0005434244786	10933	Economy	14400.00
0005435611977	10933	Economy	14400.00
0005435424421	10933	Economy	14400.00
0005434343602	10933	Economy	14400.00
0005435424370	10933	Economy	14400.00
0005435424355	10933	Economy	14400.00
0005433633626	3394	Business	18800.00
0005433805153	3394	Business	18800.00
0005433633625	3394	Business	18800.00
0005433805146	3394	Business	18800.00
0005432459142	3394	Business	18800.00
0005433507062	3394	Business	18800.00
0005432458964	3394	Business	18800.00
0005433805127	3394	Business	18800.00
0005433805159	3394	Business	18800.00
0005432181576	3394	Business	18800.00
0005432459276	3394	Business	18800.00
0005433805158	3394	Business	18800.00
0005432181570	3394	Business	18800.00
0005433507074	3394	Business	18800.00
0005432459040	3394	Business	18800.00
0005432459182	3394	Business	18800.00
0005433805162	3394	Business	18800.00
0005432459280	3394	Business	18800.00
0005432459022	3394	Business	18800.00
0005432459181	3394	Business	18800.00
0005432181585	3394	Business	18800.00
0005433805143	3394	Business	18800.00
0005433805126	3394	Business	18800.00
0005433805156	3394	Business	18800.00
0005433633612	3394	Business	18800.00
0005433507065	3394	Business	18800.00
0005433633608	3394	Economy	6900.00
0005432459056	3394	Economy	6900.00
0005433633631	3394	Economy	6900.00
0005433507075	3394	Economy	6900.00
0005432459139	3394	Economy	6900.00
0005433507068	3394	Economy	6900.00
0005433805129	3394	Economy	6300.00
0005433633615	3394	Economy	6300.00
0005433507063	3394	Economy	6300.00
0005433633629	3394	Economy	6300.00
0005432458969	3394	Economy	6300.00
0005433805128	3394	Economy	6300.00
0005433633611	3394	Economy	6300.00
0005432459066	3394	Economy	6300.00
0005432181582	3394	Economy	6300.00
0005432459133	3394	Economy	6300.00
0005433805137	3394	Economy	6300.00
0005432459024	3394	Economy	6300.00
0005432181590	3394	Economy	6300.00
0005432459051	3394	Economy	6300.00
0005433507069	3394	Economy	6300.00
0005433633616	3394	Economy	6300.00
0005433805133	3394	Economy	6300.00
0005433805138	3394	Economy	6300.00
0005432459028	3394	Economy	6300.00
0005433633618	3394	Economy	6300.00
0005432458970	3394	Economy	6300.00
0005432181583	3394	Economy	6300.00
0005433507066	3394	Economy	6300.00
0005432459009	3394	Economy	6300.00
0005433633600	3394	Economy	6300.00
0005432181589	3394	Economy	6300.00
0005432459286	3394	Economy	6300.00
0005432181574	3394	Economy	6300.00
0005433805132	3394	Economy	6300.00
0005434143715	3394	Economy	6300.00
0005432459030	3394	Economy	6300.00
0005432459201	3394	Economy	6300.00
0005432459112	3394	Economy	6300.00
0005432459211	3394	Economy	6300.00
0005432459052	3394	Economy	6300.00
0005433507067	3394	Economy	6300.00
0005432458999	3394	Economy	6300.00
0005432181572	3394	Economy	6300.00
0005432459039	3394	Economy	6300.00
0005433633602	3394	Economy	6300.00
0005433633607	3394	Economy	6300.00
0005433805165	3394	Economy	6300.00
0005433805140	3394	Economy	6300.00
0005433633613	3394	Economy	6300.00
0005433805151	3394	Economy	6300.00
0005432181569	3394	Economy	6300.00
0005433633628	3394	Economy	6300.00
0005432181584	3394	Economy	6300.00
0005433805131	3394	Economy	6300.00
0005432181581	3394	Economy	6300.00
0005433805135	3394	Economy	6300.00
0005432181575	3394	Economy	6300.00
0005432458992	3394	Economy	6300.00
0005433633603	3394	Economy	6300.00
0005432181588	3394	Economy	6300.00
0005433805142	3394	Economy	6300.00
0005433805163	3394	Economy	6900.00
0005433805139	3394	Economy	6900.00
0005432181580	3394	Economy	6900.00
0005432459033	3394	Economy	6300.00
0005432181577	3394	Economy	6300.00
0005433805155	3394	Economy	6300.00
0005433633606	3394	Economy	6900.00
0005433805157	3394	Economy	6300.00
0005432181571	3394	Economy	6300.00
0005433507070	3394	Economy	6300.00
0005433805149	3394	Economy	6300.00
0005433633601	3394	Economy	6300.00
0005433633623	3394	Economy	6300.00
0005433633610	3394	Economy	6300.00
0005433805154	3394	Economy	6300.00
0005433805164	3394	Economy	6300.00
0005433633617	3394	Economy	6300.00
0005432181578	3394	Economy	6300.00
0005432459029	3394	Economy	6300.00
0005433633630	3394	Economy	6300.00
0005433633609	3394	Economy	6300.00
0005433507064	3394	Economy	6300.00
0005432458971	3394	Economy	6300.00
0005433805147	3394	Economy	6300.00
0005432459019	3394	Economy	6300.00
0005432459020	3394	Economy	6300.00
0005433633627	3394	Economy	6300.00
0005432181586	3394	Economy	6300.00
0005433805161	3394	Economy	6300.00
0005433805160	3394	Economy	6300.00
0005433805134	3394	Economy	6300.00
0005433633622	3394	Economy	6300.00
0005432181573	3394	Economy	6300.00
0005432459032	3394	Economy	6300.00
0005433507076	3394	Economy	6300.00
0005433805130	3394	Economy	6300.00
0005433633614	3394	Economy	6300.00
0005433805141	3394	Economy	6300.00
0005433507073	3394	Economy	6300.00
0005433633620	3394	Economy	6300.00
0005433633624	3394	Economy	6300.00
0005433805152	3394	Economy	6300.00
0005432459068	3394	Economy	6300.00
0005433633604	3394	Economy	6300.00
0005432458972	3394	Economy	6300.00
0005433805150	3394	Economy	6300.00
0005432181591	3394	Economy	6300.00
0005432459212	3394	Economy	6300.00
0005433633621	3394	Economy	6300.00
0005433805166	3394	Economy	6300.00
0005432459021	3394	Economy	6300.00
0005433805167	3394	Economy	6300.00
0005432459057	3394	Economy	6300.00
0005432459118	3394	Economy	6300.00
0005434143716	3394	Economy	6300.00
0005432459285	3394	Economy	6300.00
0005432181579	3394	Economy	6300.00
0005433633605	3394	Economy	6300.00
0005432459120	3394	Economy	6300.00
0005433805148	3394	Economy	6300.00
0005432181587	3394	Economy	6300.00
0005433507071	3394	Economy	6300.00
0005433633599	3394	Economy	6300.00
0005433805144	3394	Economy	6300.00
0005432459075	3394	Economy	6300.00
0005433805145	3394	Economy	6300.00
0005433633619	3394	Economy	6300.00
0005433805136	3394	Economy	6300.00
0005433507072	3394	Economy	6300.00
0005432459067	3394	Economy	6300.00
0005435884521	3393	Business	18800.00
0005435884597	3393	Business	18800.00
0005435884383	3393	Business	18800.00
0005435884469	3393	Business	18800.00
0005435884400	3393	Business	18800.00
0005435884672	3393	Business	18800.00
0005435884479	3393	Economy	6900.00
0005435884827	3393	Economy	6900.00
0005435884494	3393	Economy	6300.00
0005435884530	3393	Economy	6300.00
0005435884410	3393	Economy	6300.00
0005435884699	3393	Economy	6300.00
0005435884513	3393	Economy	6300.00
0005435884442	3393	Economy	6300.00
0005435884495	3393	Economy	6300.00
0005435884821	3393	Economy	6300.00
0005435884624	3393	Economy	6300.00
0005435884625	3393	Economy	6300.00
0005435884475	3393	Economy	6300.00
0005435884626	3393	Economy	6300.00
0005435884646	3393	Economy	6900.00
0005435884569	3393	Economy	6900.00
0005435884654	3393	Economy	6300.00
0005435884453	3393	Economy	6300.00
0005435884645	3393	Economy	6300.00
0005435884474	3393	Economy	6300.00
0005435884546	3393	Economy	6300.00
0005435884548	3393	Economy	6300.00
0005435884655	3393	Economy	6300.00
0005435884547	3393	Economy	6300.00
0005435884529	3393	Economy	6300.00
0005435884436	3393	Economy	6300.00
0005435884470	3393	Economy	6300.00
0005435884545	3393	Economy	6300.00
0005435884769	3393	Economy	6300.00
0005435884435	3393	Economy	6300.00
0005435884660	3393	Economy	6300.00
0005435884534	3393	Economy	6300.00
0005432459549	8188	Business	18800.00
0005435884932	8188	Business	18800.00
0005435884954	8188	Business	18800.00
0005435884924	8188	Business	18800.00
0005435884906	8188	Business	18800.00
0005433506905	8188	Business	18800.00
0005432459553	8188	Business	18800.00
0005435884947	8188	Business	18800.00
0005435884957	8188	Business	18800.00
0005435884958	8188	Business	18800.00
0005432459585	8188	Business	18800.00
0005435884944	8188	Business	18800.00
0005432459564	8188	Business	18800.00
0005432459558	8188	Business	18800.00
0005435884909	8188	Business	18800.00
0005435884917	8188	Business	18800.00
0005435884918	8188	Business	18800.00
0005435884922	8188	Business	18800.00
0005432459568	8188	Business	18800.00
0005432459586	8188	Business	18800.00
0005432459583	8188	Business	18800.00
0005432459548	8188	Business	18800.00
0005432459577	8188	Business	18800.00
0005435884962	8188	Business	18800.00
0005432459560	8188	Business	18800.00
0005432459571	8188	Economy	6900.00
0005435884933	8188	Economy	6900.00
0005435884914	8188	Economy	6900.00
0005435884927	8188	Economy	6900.00
0005435884916	8188	Economy	6900.00
0005432459551	8188	Economy	6300.00
0005435884956	8188	Economy	6300.00
0005435884903	8188	Economy	6300.00
0005435884931	8188	Economy	6300.00
0005435884905	8188	Economy	6300.00
0005435884964	8188	Economy	6300.00
0005435884946	8188	Economy	6300.00
0005435884925	8188	Economy	6300.00
0005432042633	8188	Economy	6300.00
0005432459567	8188	Economy	6300.00
0005432459547	8188	Economy	6300.00
0005435884952	8188	Economy	6300.00
0005432459552	8188	Economy	6300.00
0005435884951	8188	Economy	6300.00
0005432459576	8188	Economy	6300.00
0005432459579	8188	Economy	6300.00
0005432042638	8188	Economy	6300.00
0005433506938	8188	Economy	6300.00
0005433506981	8188	Economy	6300.00
0005435884959	8188	Economy	6300.00
0005432459589	8188	Economy	6300.00
0005435884926	8188	Economy	6300.00
0005432459594	8188	Economy	6300.00
0005432042631	8188	Economy	6300.00
0005432459570	8188	Economy	6300.00
0005435884935	8188	Economy	6300.00
0005432459593	8188	Economy	6300.00
0005432459587	8188	Economy	6300.00
0005433506959	8188	Economy	6300.00
0005435884943	8188	Economy	6300.00
0005432459580	8188	Economy	6300.00
0005432459569	8188	Economy	6300.00
0005435884937	8188	Economy	6300.00
0005435884938	8188	Economy	6300.00
0005435884942	8188	Economy	6300.00
0005432042630	8188	Economy	6300.00
0005435884940	8188	Economy	6300.00
0005432459584	8188	Economy	6300.00
0005435884960	8188	Economy	6300.00
0005435884967	8188	Economy	6300.00
0005435884939	8188	Economy	6300.00
0005435884923	8188	Economy	6300.00
0005433506921	8188	Economy	6300.00
0005432042627	8188	Economy	6300.00
0005432459575	8188	Economy	6300.00
0005432459588	8188	Economy	6300.00
0005435884963	8188	Economy	6300.00
0005433506947	8188	Economy	6300.00
0005435884934	8188	Economy	6300.00
0005435884949	8188	Economy	6300.00
0005432459546	8188	Economy	6300.00
0005435884904	8188	Economy	6900.00
0005432459573	8188	Economy	6900.00
0005432042634	8188	Economy	6900.00
0005435884941	8188	Economy	6900.00
0005433506909	8188	Economy	6300.00
0005435884929	8188	Economy	6300.00
0005432459591	8188	Economy	6300.00
0005432459556	8188	Economy	6300.00
0005435884911	8188	Economy	6300.00
0005432459572	8188	Economy	6300.00
0005435884950	8188	Economy	6300.00
0005432459574	8188	Economy	6300.00
0005432042628	8188	Economy	6300.00
0005432459582	8188	Economy	6300.00
0005432459596	8188	Economy	6300.00
0005435884910	8188	Economy	6300.00
0005432459563	8188	Economy	6300.00
0005432459559	8188	Economy	6300.00
0005435884921	8188	Economy	6300.00
0005433506854	8188	Economy	6300.00
0005432459550	8188	Economy	6300.00
0005435884948	8188	Economy	6300.00
0005432459565	8188	Economy	6300.00
0005432042629	8188	Economy	6300.00
0005435884945	8188	Economy	6300.00
0005432042637	8188	Economy	6300.00
0005432042626	8188	Economy	6300.00
0005433506901	8188	Economy	6300.00
0005432459555	8188	Economy	6300.00
0005435884930	8188	Economy	6300.00
0005433506916	8188	Economy	6300.00
0005435884928	8188	Economy	6300.00
0005432042636	8188	Economy	6300.00
0005432459595	8188	Economy	6300.00
0005433506894	8188	Economy	6300.00
0005432459592	8188	Economy	6300.00
0005435884913	8188	Economy	6300.00
0005432459562	8188	Economy	6300.00
0005435884966	8188	Economy	6300.00
0005435884965	8188	Economy	6300.00
0005435884955	8188	Economy	6300.00
0005435884912	8188	Economy	6300.00
0005432459554	8188	Economy	6300.00
0005432459578	8188	Economy	6300.00
0005435884936	8188	Economy	6300.00
0005432459557	8188	Economy	6300.00
0005432459545	8188	Economy	6300.00
0005432459561	8188	Economy	6300.00
0005435884915	8188	Economy	6300.00
0005432459581	8188	Economy	6300.00
0005435884902	8188	Economy	6300.00
0005433506922	8188	Economy	6300.00
0005435884953	8188	Economy	6300.00
0005432042635	8188	Economy	6300.00
0005435884920	8188	Economy	6300.00
0005435884919	8188	Economy	6300.00
0005432459590	8188	Economy	6300.00
0005432459566	8188	Economy	6300.00
0005435884907	8188	Economy	6300.00
0005435884961	8188	Economy	6300.00
0005435884908	8188	Economy	6300.00
0005432042632	8188	Economy	6300.00
0005433506870	8188	Economy	6300.00
0005433804824	8187	Business	18800.00
0005433804905	8187	Business	18800.00
0005433633229	8187	Business	18800.00
0005433633350	8187	Business	18800.00
0005433633351	8187	Business	18800.00
0005433633294	8187	Business	18800.00
0005433633325	8187	Business	18800.00
0005433633267	8187	Business	18800.00
0005433804819	8187	Business	18800.00
0005433633268	8187	Business	18800.00
0005433633239	8187	Business	18800.00
0005433804834	8187	Economy	6900.00
0005433633343	8187	Economy	6900.00
0005433633384	8187	Economy	6900.00
0005433804921	8187	Economy	6300.00
0005433804945	8187	Economy	6300.00
0005433804876	8187	Economy	6300.00
0005433804835	8187	Economy	6300.00
0005433804821	8187	Economy	6300.00
0005433633300	8187	Economy	6300.00
0005433804968	8187	Economy	6300.00
0005433804942	8187	Economy	6300.00
0005433804946	8187	Economy	6300.00
0005434271283	8187	Economy	6300.00
0005433804937	8187	Economy	6300.00
0005433633259	8187	Economy	6300.00
0005433633348	8187	Economy	6300.00
0005433804831	8187	Economy	6300.00
0005433633260	8187	Economy	6300.00
0005433633237	8187	Economy	6300.00
0005433633263	8187	Economy	6300.00
0005433804873	8187	Economy	6300.00
0005433633387	8187	Economy	6300.00
0005433633360	8187	Economy	6300.00
0005433633280	8187	Economy	6900.00
0005433633364	8187	Economy	6900.00
0005433633293	8187	Economy	6900.00
0005433804930	8187	Economy	6300.00
0005433633304	8187	Economy	6300.00
0005433633266	8187	Economy	6300.00
0005433804845	8187	Economy	6300.00
0005433633349	8187	Economy	6300.00
0005433633265	8187	Economy	6300.00
0005433804944	8187	Economy	6300.00
0005433804813	8187	Economy	6300.00
0005433633311	8187	Economy	6300.00
0005433804896	8187	Economy	6300.00
0005433633264	8187	Economy	6300.00
0005433804894	8187	Economy	6300.00
0005434271282	8187	Economy	6300.00
0005433633356	8187	Economy	6300.00
0005433804872	8187	Economy	6300.00
0005433633326	8187	Economy	6300.00
0005433804875	8187	Economy	6300.00
0005433804893	8187	Economy	6300.00
0005433633298	8187	Economy	6300.00
0005433633262	8187	Economy	6300.00
0005433633261	8187	Economy	6300.00
0005433633310	8187	Economy	6300.00
0005433804915	8187	Economy	6300.00
0005433633258	8187	Economy	6300.00
0005433804862	8187	Economy	6300.00
0005433633331	8187	Economy	6300.00
0005433804881	8187	Economy	6300.00
0005433633228	8187	Economy	6300.00
0005433804851	8187	Economy	6300.00
0005433633238	8187	Economy	6300.00
0005433804899	8187	Economy	6300.00
0005434183550	8186	Business	18800.00
0005433194837	4582	Business	9900.00
0005432382946	4582	Business	9900.00
0005432382937	4582	Business	9900.00
0005433194839	4582	Business	9900.00
0005432382942	4582	Business	9900.00
0005433722182	4582	Business	9900.00
0005432382952	4582	Business	9900.00
0005433722179	4582	Business	9900.00
0005433194836	4582	Business	9900.00
0005433194834	4582	Business	9900.00
0005432382950	4582	Economy	3300.00
0005432382965	4582	Economy	3300.00
0005433722183	4582	Economy	3300.00
0005433722186	4582	Economy	3300.00
0005433722185	4582	Economy	3300.00
0005433722181	4582	Economy	3300.00
0005433194838	4582	Economy	3300.00
0005432382960	4582	Economy	3600.00
0005432382927	4582	Economy	3600.00
0005432382963	4582	Economy	3600.00
0005432382935	4582	Economy	3600.00
0005432382953	4582	Economy	3300.00
0005432382948	4582	Economy	3300.00
0005432727865	4582	Economy	3300.00
0005432727864	4582	Economy	3300.00
0005432382955	4582	Economy	3300.00
0005432382933	4582	Economy	3300.00
0005432382949	4582	Economy	3300.00
0005432727860	4582	Economy	3300.00
0005432382958	4582	Economy	3300.00
0005432727862	4582	Economy	3300.00
0005433453752	4582	Economy	3300.00
0005432382957	4582	Economy	3300.00
0005432382938	4582	Economy	3300.00
0005433194842	4582	Economy	3300.00
0005433722184	4582	Economy	3300.00
0005433194841	4582	Economy	3300.00
0005432382954	4582	Economy	3300.00
0005432382945	4582	Economy	3300.00
0005432382956	4582	Economy	3300.00
0005433453751	4582	Economy	3300.00
0005432382966	4582	Economy	3300.00
0005432382951	4582	Economy	3300.00
0005432382967	4582	Economy	3300.00
0005432382941	4582	Economy	3300.00
0005432727857	4582	Economy	3300.00
0005432727868	4582	Economy	3300.00
0005432727859	4582	Economy	3300.00
0005432382932	4582	Economy	3300.00
0005432382947	4582	Economy	3300.00
0005432382959	4582	Economy	3300.00
0005432727858	4582	Economy	3300.00
0005432727866	4582	Economy	3300.00
0005432727861	4582	Economy	3300.00
0005432382930	4582	Economy	3300.00
0005432727867	4582	Economy	3300.00
0005432382931	4582	Economy	3300.00
0005432382929	4582	Economy	3300.00
0005432382944	4582	Economy	3300.00
0005432382961	4582	Economy	3300.00
0005432382928	4582	Economy	3300.00
0005432382940	4582	Economy	3300.00
0005433722180	4582	Economy	3300.00
0005432382934	4582	Economy	3300.00
0005432382964	4582	Economy	3300.00
0005432382936	4582	Economy	3300.00
0005432727863	4582	Economy	3300.00
0005432382943	4582	Economy	3300.00
0005432382939	4582	Economy	3300.00
0005433453750	4582	Economy	3300.00
0005432382962	4582	Economy	3300.00
0005433194840	4582	Economy	3300.00
0005433194835	4582	Economy	3300.00
0005432382968	4582	Economy	3300.00
0005432382538	30220	Business	9900.00
0005432382766	30220	Business	9900.00
0005432382539	30220	Economy	3300.00
0005433453742	30220	Economy	3300.00
0005432382550	30220	Economy	3300.00
0005432382485	30220	Economy	3600.00
0005432382593	30220	Economy	3600.00
0005433722103	30220	Economy	3300.00
0005433451584	30220	Economy	3300.00
0005432382764	30220	Economy	3300.00
0005433722115	30220	Economy	3300.00
0005432727797	30220	Economy	3300.00
0005432382530	30220	Economy	3300.00
0005432382585	30220	Economy	3300.00
0005432382560	30220	Economy	3300.00
0005433453740	30220	Economy	3300.00
0005432382765	30220	Economy	3300.00
0005433453741	30220	Economy	3300.00
0005432727752	30220	Economy	3300.00
0005432727757	30220	Economy	3300.00
0005432727758	30220	Economy	3300.00
0005432727769	30220	Economy	3300.00
0005432382612	30220	Economy	3300.00
0005433194827	30220	Economy	3300.00
0005432727820	30220	Economy	3300.00
0005433722106	30220	Economy	3300.00
0005432382567	30220	Economy	3300.00
0005432382549	30220	Economy	3300.00
0005432382594	30220	Economy	3300.00
0005432382551	30220	Economy	3300.00
0005432382599	30220	Economy	3300.00
0005432382668	30220	Economy	3300.00
0005433451585	30220	Economy	3300.00
0005432382667	30220	Economy	3300.00
0005432727761	30220	Economy	3300.00
0005433453726	30220	Economy	3300.00
0005432382529	30220	Economy	3300.00
0005432382486	30220	Economy	3300.00
0005432382537	30220	Economy	3300.00
0005432727762	30220	Economy	3300.00
0005432382522	30220	Economy	3300.00
0005433453727	30220	Economy	3300.00
0005435540869	1716	Business	57200.00
0005435540884	1716	Business	57200.00
0005432924963	1716	Business	57200.00
0005435529142	1716	Business	57200.00
0005435529132	1716	Business	57200.00
0005435529141	1716	Business	57200.00
0005435540872	1716	Business	57200.00
0005435540878	1716	Business	57200.00
0005435529123	1716	Economy	19100.00
0005433516835	1716	Economy	19100.00
0005433516834	1716	Economy	19100.00
0005432924967	1716	Economy	19100.00
0005433516830	1716	Economy	19100.00
0005435540873	1716	Economy	19100.00
0005435529139	1716	Economy	21000.00
0005435529129	1716	Economy	21000.00
0005435529127	1716	Economy	21000.00
0005433516827	1716	Economy	19100.00
0005433516831	1716	Economy	19100.00
0005433516832	1716	Economy	19100.00
0005435529124	1716	Economy	19100.00
0005435540881	1716	Economy	19100.00
0005435540870	1716	Economy	19100.00
0005435540867	1716	Economy	19100.00
0005433516828	1716	Economy	19100.00
0005432924953	1716	Economy	19100.00
0005432924960	1716	Economy	19100.00
0005435540882	1716	Economy	19100.00
0005435529133	1716	Economy	19100.00
0005435529134	1716	Economy	19100.00
0005435529140	1716	Economy	19100.00
0005435540875	1716	Economy	19100.00
0005435540866	1716	Economy	19100.00
0005435540883	1716	Economy	19100.00
0005435540868	1716	Economy	19100.00
0005432924962	1716	Economy	19100.00
0005433516833	1716	Economy	19100.00
0005435529138	1716	Economy	19100.00
0005435529131	1716	Economy	19100.00
0005433516829	1716	Economy	19100.00
0005435529122	1716	Economy	19100.00
0005435529125	1716	Economy	19100.00
0005435540877	1716	Economy	19100.00
0005435529137	1716	Economy	19100.00
0005432924959	1716	Economy	19100.00
0005435540879	1716	Economy	19100.00
0005432924983	1716	Economy	19100.00
0005435540885	1716	Economy	19100.00
0005435540887	1716	Economy	19100.00
0005432924982	1716	Economy	19100.00
0005435529128	1716	Economy	19100.00
0005435540876	1716	Economy	19100.00
0005435529135	1716	Economy	19100.00
0005435540871	1716	Economy	19100.00
0005435540886	1716	Economy	19100.00
0005435540880	1716	Economy	19100.00
0005435529126	1716	Economy	19100.00
0005435529143	1716	Economy	19100.00
0005432294473	1716	Economy	19100.00
0005435540874	1716	Economy	19100.00
0005435529130	1716	Economy	19100.00
0005435529136	1716	Economy	19100.00
0005435540699	21986	Business	57200.00
0005435540737	21986	Business	57200.00
0005435517686	21986	Business	57200.00
0005433516776	21986	Economy	19100.00
0005435540726	21986	Economy	19100.00
0005435540700	21986	Economy	19100.00
0005435517681	21986	Economy	19100.00
0005433516796	21986	Economy	19100.00
0005435540750	21986	Economy	19100.00
0005435517619	21986	Economy	21000.00
0005435540673	21986	Economy	21000.00
0005435517662	21986	Economy	19100.00
0005435540625	21986	Economy	19100.00
0005435517617	21986	Economy	19100.00
0005432925006	21986	Economy	19100.00
0005435540627	21986	Economy	19100.00
0005435540624	21986	Economy	19100.00
0005435540646	21986	Economy	19100.00
0005435517631	21986	Economy	19100.00
0005433516759	21986	Economy	19100.00
0005432925007	21986	Economy	19100.00
0005435517625	21986	Economy	19100.00
0005433516731	21986	Economy	19100.00
0005435517684	21986	Economy	19100.00
0005435540703	21986	Economy	19100.00
0005433516730	21986	Economy	19100.00
0005432925009	21986	Economy	19100.00
0005432925005	21986	Economy	19100.00
0005435517685	21986	Economy	19100.00
0005435517622	21986	Economy	19100.00
0005435517666	21986	Economy	19100.00
0005435517598	21986	Economy	19100.00
0005432925008	21986	Economy	19100.00
0005433516751	21986	Economy	19100.00
0005435517630	21986	Economy	19100.00
0005435252489	7385	Business	18500.00
0005434458683	7385	Business	18500.00
0005432838849	7385	Business	18500.00
0005432838852	7385	Business	18500.00
0005432838845	7385	Business	18500.00
0005432838853	7385	Business	18500.00
0005432840998	7385	Business	18500.00
0005432838843	7385	Business	18500.00
0005435252425	7385	Economy	6200.00
0005434458687	7385	Economy	6200.00
0005432838841	7385	Economy	6200.00
0005435252479	7385	Economy	6200.00
0005432838833	7385	Economy	6200.00
0005434458686	7385	Economy	6200.00
0005435252490	7385	Economy	6200.00
0005432838842	7385	Economy	6200.00
0005434458688	7385	Economy	6800.00
0005435491408	7385	Economy	6800.00
0005434458678	7385	Economy	6800.00
0005434458667	7385	Economy	6800.00
0005434664929	7385	Economy	6200.00
0005434458669	7385	Economy	6200.00
0005435252480	7385	Economy	6200.00
0005434458670	7385	Economy	6200.00
0005432823436	7385	Economy	6200.00
0005432838848	7385	Economy	6200.00
0005434458668	7385	Economy	6200.00
0005432823435	7385	Economy	6200.00
0005432838859	7385	Economy	6200.00
0005435252488	7385	Economy	6200.00
0005434458685	7385	Economy	6200.00
0005434458681	7385	Economy	6200.00
0005432838838	7385	Economy	6200.00
0005435252437	7385	Economy	6200.00
0005434458679	7385	Economy	6200.00
0005434664926	7385	Economy	6200.00
0005432838839	7385	Economy	6200.00
0005432838858	7385	Economy	6200.00
0005432838840	7385	Economy	6200.00
0005434458673	7385	Economy	6200.00
0005432838846	7385	Economy	6200.00
0005434458689	7385	Economy	6200.00
0005434458676	7385	Economy	6200.00
0005434458675	7385	Economy	6200.00
0005434458671	7385	Economy	6200.00
0005432838857	7385	Economy	6200.00
0005435491411	7385	Economy	6200.00
0005434458680	7385	Economy	6200.00
0005434664928	7385	Economy	6200.00
0005432838836	7385	Economy	6200.00
0005432838844	7385	Economy	6200.00
0005434664927	7385	Economy	6200.00
0005432838834	7385	Economy	6200.00
0005432838861	7385	Economy	6200.00
0005432838854	7385	Economy	6200.00
0005432838855	7385	Economy	6200.00
0005432838847	7385	Economy	6200.00
0005432838831	7385	Economy	6200.00
0005434458682	7385	Economy	6200.00
0005432838837	7385	Economy	6200.00
0005432838832	7385	Economy	6200.00
0005432838835	7385	Economy	6200.00
0005432838851	7385	Economy	6200.00
0005432838856	7385	Economy	6200.00
0005435252401	7385	Economy	6200.00
0005434458674	7385	Economy	6200.00
0005432838850	7385	Economy	6200.00
0005435491412	7385	Economy	6200.00
0005432840997	7385	Economy	6200.00
0005434458677	7385	Economy	6200.00
0005434458684	7385	Economy	6200.00
0005434458672	7385	Economy	6200.00
0005432838860	7385	Economy	6200.00
0005435252600	28923	Business	18500.00
0005432838608	28923	Business	18500.00
0005435252587	28923	Business	18500.00
0005434458482	28923	Business	18500.00
0005432838750	28923	Business	18500.00
0005434458458	28923	Business	18500.00
0005432838719	28923	Business	18500.00
0005434458472	28923	Business	18500.00
0005434458486	28923	Business	18500.00
0005434458460	28923	Business	18500.00
0005432838679	28923	Business	18500.00
0005435252589	28923	Economy	6200.00
0005435491430	28923	Economy	6200.00
0005434458591	28923	Economy	6200.00
0005435252590	28923	Economy	6200.00
0005432838749	28923	Economy	6200.00
0005432838640	28923	Economy	6200.00
0005434458447	28923	Economy	6200.00
0005434458485	28923	Economy	6200.00
0005434458454	28923	Economy	6200.00
0005434458590	28923	Economy	6200.00
0005432838551	28923	Economy	6800.00
0005434458488	28923	Economy	6800.00
0005432838720	28923	Economy	6800.00
0005432838680	28923	Economy	6800.00
0005432840979	28923	Economy	6800.00
0005434458533	28923	Economy	6200.00
0005435252592	28923	Economy	6200.00
0005432838737	28923	Economy	6200.00
0005432838631	28923	Economy	6200.00
0005435252588	28923	Economy	6200.00
0005432838740	28923	Economy	6200.00
0005435252584	28923	Economy	6200.00
0005432838514	28923	Economy	6200.00
0005432838594	28923	Economy	6200.00
0005435252593	28923	Economy	6200.00
0005432001011	28923	Economy	6200.00
0005434458547	28923	Economy	6200.00
0005432823419	28923	Economy	6200.00
0005432838638	28923	Economy	6200.00
0005435252594	28923	Economy	6200.00
0005434458564	28923	Economy	6200.00
0005434458446	28923	Economy	6200.00
0005432823421	28923	Economy	6200.00
0005432838630	28923	Economy	6200.00
0005434458483	28923	Economy	6200.00
0005432840987	28923	Economy	6200.00
0005432838603	28923	Economy	6200.00
0005432838553	28923	Economy	6200.00
0005435252585	28923	Economy	6200.00
0005434458484	28923	Economy	6200.00
0005432838515	28923	Economy	6200.00
0005432838557	28923	Economy	6200.00
0005434458504	28923	Economy	6200.00
0005434458497	28923	Economy	6200.00
0005434458563	28923	Economy	6200.00
0005434458477	28923	Economy	6200.00
0005434458498	28923	Economy	6200.00
0005432838601	28923	Economy	6200.00
0005432823426	28923	Economy	6200.00
0005434664947	28923	Economy	6200.00
0005434458502	28923	Economy	6200.00
0005432838626	28923	Economy	6200.00
0005435252595	28923	Economy	6200.00
0005432838639	28923	Economy	6200.00
0005434458541	28923	Economy	6200.00
0005432838663	28923	Economy	6200.00
0005432823420	28923	Economy	6200.00
0005434458521	28923	Economy	6200.00
0005432838683	28923	Economy	6200.00
0005435252599	28923	Economy	6200.00
0005432840988	28923	Economy	6200.00
0005432838629	28923	Economy	6200.00
0005434458459	28923	Economy	6200.00
0005434458503	28923	Economy	6200.00
0005435252586	28923	Economy	6200.00
0005434664948	28923	Economy	6200.00
0005434458546	28923	Economy	6200.00
0005432838602	28923	Economy	6200.00
0005435252601	28923	Economy	6200.00
0005432838552	28923	Economy	6200.00
0005434458473	28923	Economy	6200.00
0005435252591	28923	Economy	6200.00
0005434664946	28923	Economy	6200.00
0005432001010	28923	Economy	6200.00
0005435252596	28923	Economy	6200.00
0005434458539	28923	Economy	6200.00
0005435252598	28923	Economy	6200.00
0005435252597	28923	Economy	6200.00
0005432838662	28923	Economy	6200.00
0005432823417	28923	Economy	6200.00
0005434458501	28923	Economy	6200.00
0005434458542	28923	Economy	6200.00
0005435990578	8813	Business	145300.00
0005435990581	8813	Business	145300.00
0005435990583	8813	Economy	48400.00
0005435990584	8813	Economy	48400.00
0005435990585	8813	Economy	48400.00
0005435990579	8813	Economy	48400.00
0005434275956	8813	Economy	48400.00
0005435990580	8813	Economy	48400.00
0005435990582	8813	Economy	48400.00
0005434275994	15758	Business	145300.00
0005434275993	15758	Business	145300.00
0005434275992	15758	Economy	48400.00
0005434275990	15758	Economy	53300.00
0005435990537	15758	Economy	48400.00
0005435990518	15758	Economy	48400.00
0005435990517	15758	Economy	48400.00
0005434275991	15758	Economy	48400.00
0005435990538	15758	Economy	48400.00
0005435990536	15758	Economy	48400.00
0005433476878	30841	Economy	15900.00
0005432427118	30841	Economy	14500.00
0005433476880	30841	Economy	14500.00
0005433476879	30841	Economy	14500.00
0005433476874	30841	Economy	14500.00
0005433476875	30841	Economy	14500.00
0005433476876	30841	Economy	14500.00
0005433476877	30841	Economy	14500.00
0005433468194	23846	Economy	13300.00
0005432909252	23846	Economy	13300.00
0005432909247	23846	Economy	13300.00
0005432909248	23846	Economy	12100.00
0005433468200	23846	Economy	12100.00
0005433468220	23846	Economy	12100.00
0005432909244	23846	Economy	12100.00
0005433468198	23846	Economy	12100.00
0005433468219	23846	Economy	12100.00
0005432909253	23846	Economy	12100.00
0005433468193	23846	Economy	12100.00
0005432909245	23846	Economy	12100.00
0005433468199	23846	Economy	12100.00
0005432909251	23846	Economy	12100.00
0005433468205	23846	Economy	12100.00
0005432909249	23846	Economy	12100.00
0005432909250	23846	Economy	12100.00
0005432909254	23846	Economy	12100.00
0005433468218	23846	Economy	12100.00
0005433468195	23846	Economy	12100.00
0005432909246	23846	Economy	12100.00
0005433468233	23846	Economy	12100.00
0005433468185	23846	Economy	12100.00
0005433468192	23846	Economy	12100.00
0005435176591	6371	Business	36600.00
0005434149563	6371	Business	36600.00
0005432360096	6371	Business	36600.00
0005432062198	6371	Business	36600.00
0005435176757	6371	Business	36600.00
0005432360066	6371	Business	36600.00
0005435176648	6371	Business	36600.00
0005432360073	6371	Business	36600.00
0005434149547	6371	Business	36600.00
0005432360090	6371	Business	36600.00
0005435176592	6371	Business	36600.00
0005432360052	6371	Business	36600.00
0005434149564	6371	Economy	12200.00
0005435723014	6371	Economy	12200.00
0005432360084	6371	Economy	12200.00
0005432360064	6371	Economy	12200.00
0005432335960	6371	Economy	12200.00
0005434149607	6371	Economy	12200.00
0005432363397	6371	Economy	12200.00
0005432360088	6371	Economy	12200.00
0005432360054	6371	Economy	12200.00
0005432360048	6371	Economy	12200.00
0005432360049	6371	Economy	12200.00
0005435176686	6371	Economy	12200.00
0005432335955	6371	Economy	12200.00
0005434149582	6371	Economy	12200.00
0005432360095	6371	Economy	12200.00
0005435176696	6371	Economy	12200.00
0005432335957	6371	Economy	12200.00
0005432360092	6371	Economy	12200.00
0005432335964	6371	Economy	12200.00
0005432363395	6371	Economy	12200.00
0005435176764	6371	Economy	12200.00
0005434149583	6371	Economy	12200.00
0005432335965	6371	Economy	12200.00
0005432360062	6371	Economy	12200.00
0005432335958	6371	Economy	12200.00
0005432360063	6371	Economy	12200.00
0005435176710	6371	Economy	12200.00
0005432335963	6371	Economy	12200.00
0005435176806	6371	Economy	12200.00
0005432360086	6371	Economy	12200.00
0005432062197	6371	Economy	12200.00
0005432335956	6371	Economy	12200.00
0005434149549	6371	Economy	12200.00
0005435176612	6371	Economy	12200.00
0005434149548	6371	Economy	12200.00
0005432335966	6371	Economy	12200.00
0005432062196	6371	Economy	13400.00
0005434149550	6371	Economy	13400.00
0005434149576	6371	Economy	13400.00
0005435176735	6371	Economy	13400.00
0005435176756	6371	Economy	13400.00
0005432062195	6371	Economy	12200.00
0005435176729	6371	Economy	13400.00
0005435176780	6371	Economy	12200.00
0005435176719	6371	Economy	12200.00
0005435176715	6371	Economy	12200.00
0005432360089	6371	Economy	12200.00
0005432360078	6371	Economy	12200.00
0005432360076	6371	Economy	12200.00
0005432360074	6371	Economy	12200.00
0005432360056	6371	Economy	12200.00
0005432363396	6371	Economy	12200.00
0005435176611	6371	Economy	12200.00
0005435176734	6371	Economy	12200.00
0005432360067	6371	Economy	12200.00
0005432360065	6371	Economy	12200.00
0005435176718	6371	Economy	12200.00
0005435176728	6371	Economy	12200.00
0005432360094	6371	Economy	12200.00
0005432335959	6371	Economy	12200.00
0005435176687	6371	Economy	12200.00
0005435176755	6371	Economy	12200.00
0005432360081	6371	Economy	12200.00
0005432360075	6371	Economy	12200.00
0005432360055	6371	Economy	12200.00
0005434149565	6371	Economy	12200.00
0005435176742	6371	Economy	12200.00
0005435176765	6371	Economy	12200.00
0005435176753	6371	Economy	12200.00
0005435176754	6371	Economy	12200.00
0005432360058	6371	Economy	12200.00
0005435176748	6371	Economy	12200.00
0005432360050	6371	Economy	12200.00
0005432360070	6371	Economy	12200.00
0005432360077	6371	Economy	12200.00
0005432360072	6371	Economy	12200.00
0005435176733	6371	Economy	12200.00
0005432360061	6371	Economy	12200.00
0005432360053	6371	Economy	12200.00
0005435176805	6371	Economy	12200.00
0005432360060	6371	Economy	12200.00
0005432360093	6371	Economy	12200.00
0005432360057	6371	Economy	12200.00
0005432360082	6371	Economy	12200.00
0005432360068	6371	Economy	12200.00
0005435723016	6371	Economy	12200.00
0005432360085	6371	Economy	12200.00
0005435176647	6371	Economy	12200.00
0005434149558	6371	Economy	12200.00
0005432360080	6371	Economy	12200.00
0005432360087	6371	Economy	12200.00
0005432335961	6371	Economy	12200.00
0005435490176	6371	Economy	12200.00
0005432360069	6371	Economy	12200.00
0005432360047	6371	Economy	12200.00
0005435176597	6371	Economy	12200.00
0005435176747	6371	Economy	12200.00
0005434149581	6371	Economy	12200.00
0005432360059	6371	Economy	12200.00
0005434149577	6371	Economy	12200.00
0005432360071	6371	Economy	12200.00
0005432360051	6371	Economy	12200.00
0005432360083	6371	Economy	12200.00
0005432335962	6371	Economy	12200.00
0005435176779	6371	Economy	12200.00
0005432360091	6371	Economy	12200.00
0005432360079	6371	Economy	12200.00
0005432335868	20995	Business	36600.00
0005435176910	20995	Business	36600.00
0005435176919	20995	Business	36600.00
0005432359770	20995	Business	36600.00
0005432359613	20995	Business	36600.00
0005432359628	20995	Business	36600.00
0005432335847	20995	Business	36600.00
0005432359744	20995	Business	36600.00
0005435176899	20995	Business	36600.00
0005432359805	20995	Business	36600.00
0005434149660	20995	Business	36600.00
0005432052729	20995	Business	36600.00
0005432359532	20995	Economy	12200.00
0005435490210	20995	Economy	12200.00
0005432359717	20995	Economy	12200.00
0005435176901	20995	Economy	12200.00
0005435176920	20995	Economy	12200.00
0005434149665	20995	Economy	12200.00
0005435176913	20995	Economy	12200.00
0005434149662	20995	Economy	12200.00
0005435490208	20995	Economy	12200.00
0005432359574	20995	Economy	12200.00
0005432359781	20995	Economy	12200.00
0005432359636	20995	Economy	12200.00
0005434149663	20995	Economy	12200.00
0005434149653	20995	Economy	12200.00
0005435176912	20995	Economy	12200.00
0005432359528	20995	Economy	12200.00
0005432359596	20995	Economy	12200.00
0005432359554	20995	Economy	12200.00
0005435176916	20995	Economy	12200.00
0005432359705	20995	Economy	12200.00
0005432335836	20995	Economy	12200.00
0005432335874	20995	Economy	12200.00
0005432359773	20995	Economy	12200.00
0005435176906	20995	Economy	12200.00
0005435176917	20995	Economy	12200.00
0005435176905	20995	Economy	12200.00
0005432359627	20995	Economy	12200.00
0005435176921	20995	Economy	12200.00
0005432335881	20995	Economy	12200.00
0005432359637	20995	Economy	12200.00
0005432335822	20995	Economy	12200.00
0005432359555	20995	Economy	12200.00
0005432359533	20995	Economy	12200.00
0005432335918	20995	Economy	12200.00
0005434149655	20995	Economy	12200.00
0005432359622	20995	Economy	13400.00
0005432335824	20995	Economy	13400.00
0005435176902	20995	Economy	13400.00
0005434149664	20995	Economy	13400.00
0005435176897	20995	Economy	13400.00
0005432052726	20995	Economy	13400.00
0005432359525	20995	Economy	12200.00
0005434149659	20995	Economy	12200.00
0005434149652	20995	Economy	12200.00
0005432335835	20995	Economy	12200.00
0005432359764	20995	Economy	12200.00
0005435176914	20995	Economy	12200.00
0005435176909	20995	Economy	12200.00
0005435176915	20995	Economy	12200.00
0005432335867	20995	Economy	12200.00
0005432359569	20995	Economy	12200.00
0005432363377	20995	Economy	12200.00
0005432359595	20995	Economy	12200.00
0005435176911	20995	Economy	12200.00
0005432359741	20995	Economy	12200.00
0005432359765	20995	Economy	12200.00
0005432359678	20995	Economy	12200.00
0005432359706	20995	Economy	12200.00
0005432359821	20995	Economy	12200.00
0005432359566	20995	Economy	12200.00
0005432359559	20995	Economy	12200.00
0005432359568	20995	Economy	12200.00
0005432335894	20995	Economy	12200.00
0005432359749	20995	Economy	12200.00
0005432359587	20995	Economy	12200.00
0005435176898	20995	Economy	12200.00
0005432359743	20995	Economy	12200.00
0005434149656	20995	Economy	12200.00
0005432335848	20995	Economy	12200.00
0005435723034	20995	Economy	12200.00
0005432359647	20995	Economy	12200.00
0005435176895	20995	Economy	12200.00
0005434149661	20995	Economy	12200.00
0005435176896	20995	Economy	12200.00
0005432359679	20995	Economy	12200.00
0005432359646	20995	Economy	12200.00
0005432359614	20995	Economy	12200.00
0005432359623	20995	Economy	12200.00
0005432359693	20995	Economy	12200.00
0005435176908	20995	Economy	12200.00
0005432359526	20995	Economy	12200.00
0005434149658	20995	Economy	12200.00
0005432359772	20995	Economy	12200.00
0005435176918	20995	Economy	12200.00
0005435176903	20995	Economy	12200.00
0005432052727	20995	Economy	12200.00
0005432335917	20995	Economy	12200.00
0005432335834	20995	Economy	12200.00
0005432359680	20995	Economy	12200.00
0005432335841	20995	Economy	12200.00
0005432359777	20995	Economy	12200.00
0005432359774	20995	Economy	12200.00
0005432359829	20995	Economy	12200.00
0005432359863	20995	Economy	12200.00
0005434149654	20995	Economy	12200.00
0005435176900	20995	Economy	12200.00
0005435176907	20995	Economy	12200.00
0005432052728	20995	Economy	12200.00
0005435176922	20995	Economy	12200.00
0005432359701	20995	Economy	12200.00
0005432359617	20995	Economy	12200.00
0005432335893	20995	Economy	12200.00
0005435490209	20995	Economy	12200.00
0005435176904	20995	Economy	12200.00
0005432359750	20995	Economy	12200.00
0005435723033	20995	Economy	12200.00
0005434149657	20995	Economy	12200.00
0005432359763	20995	Economy	12200.00
0005434458536	17722	Economy	3400.00
0005434458444	17722	Economy	3400.00
0005434458540	17722	Economy	3100.00
0005434463900	17722	Economy	3100.00
0005434463898	17722	Economy	3100.00
0005434458495	17722	Economy	3100.00
0005434461612	17722	Economy	3100.00
0005434461620	17722	Economy	3100.00
0005434458592	17722	Economy	3100.00
0005434186182	17722	Economy	3100.00
0005434458496	17722	Economy	3100.00
0005434458443	17722	Economy	3100.00
0005434463897	17722	Economy	3100.00
0005434458566	17722	Economy	3100.00
0005434448254	17722	Economy	3100.00
0005434458445	17722	Economy	3100.00
0005434458522	17722	Economy	3100.00
0005434458537	17722	Economy	3100.00
0005434458538	17722	Economy	3100.00
0005434458500	17722	Economy	3100.00
0005434448256	17722	Economy	3100.00
0005434186181	17722	Economy	3100.00
0005434458530	17722	Economy	3100.00
0005434461619	17722	Economy	3100.00
0005434458549	17722	Economy	3100.00
0005434458469	17722	Economy	3100.00
0005434458442	17722	Economy	3100.00
0005434458494	17722	Economy	3100.00
0005434448255	17722	Economy	3100.00
0005434461618	17722	Economy	3100.00
0005434186180	17722	Economy	3100.00
0005434458565	17722	Economy	3100.00
0005434463896	17722	Economy	3100.00
0005434458529	17722	Economy	3100.00
0005434461613	17722	Economy	3100.00
0005434448265	17722	Economy	3100.00
0005434458684	29124	Economy	3400.00
0005434458686	29124	Economy	3400.00
0005434458682	29124	Economy	3100.00
0005434458688	29124	Economy	3100.00
0005434458689	29124	Economy	3100.00
0005434186147	29124	Economy	3100.00
0005434448290	29124	Economy	3100.00
0005434458677	29124	Economy	3100.00
0005434458687	29124	Economy	3100.00
0005434458680	29124	Economy	3100.00
0005434458669	29124	Economy	3100.00
0005434462775	29124	Economy	3100.00
0005434458685	29124	Economy	3100.00
0005434462774	29124	Economy	3100.00
0005434458681	29124	Economy	3100.00
0005434448291	29124	Economy	3100.00
0005434458674	29124	Economy	3100.00
0005434458678	29124	Economy	3100.00
0005434186153	29124	Economy	3100.00
0005434458675	29124	Economy	3100.00
0005434458672	29124	Economy	3100.00
0005434458671	29124	Economy	3100.00
0005434458673	29124	Economy	3100.00
0005434458676	29124	Economy	3100.00
0005434458667	29124	Economy	3100.00
0005434458683	29124	Economy	3100.00
0005434458679	29124	Economy	3100.00
0005434448292	29124	Economy	3100.00
0005434463914	29124	Economy	3100.00
0005434186161	29124	Economy	3100.00
0005434186162	29124	Economy	3100.00
0005434458670	29124	Economy	3100.00
0005434458668	29124	Economy	3100.00
0005432604052	21444	Economy	7300.00
0005432604055	21444	Economy	7300.00
0005432604047	21444	Economy	7300.00
0005432604049	21444	Economy	6600.00
0005432604079	21444	Economy	6600.00
0005432604072	21444	Economy	6600.00
0005432604051	21444	Economy	6600.00
0005432604087	21444	Economy	6600.00
0005435218099	21444	Economy	6600.00
0005432604067	21444	Economy	6600.00
0005432604078	21444	Economy	6600.00
0005432604075	21444	Economy	6600.00
0005432604076	21444	Economy	6600.00
0005432604057	21444	Economy	6600.00
0005432604086	21444	Economy	6600.00
0005432604059	21444	Economy	6600.00
0005432604060	21444	Economy	6600.00
0005432604065	21444	Economy	6600.00
0005432604085	21444	Economy	6600.00
0005432604084	21444	Economy	6600.00
0005432604063	21444	Economy	6600.00
0005432604071	21444	Economy	6600.00
0005432604083	21444	Economy	6600.00
0005432604061	21444	Economy	6600.00
0005432604058	21444	Economy	6600.00
0005432604082	21444	Economy	6600.00
0005432604074	21444	Economy	6600.00
0005432604054	21444	Economy	6600.00
0005432604068	21444	Economy	6600.00
0005432604069	21444	Economy	6600.00
0005432604070	21444	Economy	6600.00
0005432604081	21444	Economy	6600.00
0005432604050	21444	Economy	6600.00
0005432604048	21444	Economy	6600.00
0005432604056	21444	Economy	6600.00
0005432604080	21444	Economy	6600.00
0005432604073	21444	Economy	6600.00
0005432604053	21444	Economy	6600.00
0005432604064	21444	Economy	6600.00
0005432604062	21444	Economy	6600.00
0005432604077	21444	Economy	6600.00
0005432604066	21444	Economy	6600.00
0005432603656	31683	Economy	7300.00
0005432603765	31683	Economy	7300.00
0005432603766	31683	Economy	7300.00
0005432603706	31683	Economy	6600.00
0005432603711	31683	Economy	6600.00
0005432603794	31683	Economy	6600.00
0005432603913	31683	Economy	6600.00
0005432603710	31683	Economy	6600.00
0005432603776	31683	Economy	6600.00
0005432604015	31683	Economy	6600.00
0005432603681	31683	Economy	6600.00
0005432603926	31683	Economy	6600.00
0005432603808	31683	Economy	6600.00
0005432603708	31683	Economy	6600.00
0005432603803	31683	Economy	6600.00
0005432603687	31683	Economy	6600.00
0005432603915	31683	Economy	6600.00
0005432603914	31683	Economy	6600.00
0005432603916	31683	Economy	6600.00
0005432603709	31683	Economy	6600.00
0005432603829	31683	Economy	6600.00
0005432603756	31683	Economy	6600.00
0005432603697	31683	Economy	6600.00
0005432603743	31683	Economy	6600.00
0005432603762	31683	Economy	6600.00
0005432603755	31683	Economy	6600.00
0005432603727	31683	Economy	6600.00
0005432603720	31683	Economy	6600.00
0005432603723	31683	Economy	6600.00
0005432603764	31683	Economy	6600.00
0005432603688	31683	Economy	6600.00
0005432603707	31683	Economy	6600.00
0005432603821	31683	Economy	6600.00
0005432603777	31683	Economy	6600.00
0005432604014	31683	Economy	6600.00
0005433293223	29598	Economy	19500.00
0005433293213	29598	Economy	17800.00
0005433293219	29598	Economy	17800.00
0005433293218	29598	Economy	17800.00
0005433293222	29598	Economy	17800.00
0005433293215	29598	Economy	17800.00
0005433293216	29598	Economy	17800.00
0005433293220	29598	Economy	17800.00
0005433293221	29598	Economy	17800.00
0005433293217	29598	Economy	17800.00
0005433293210	29598	Economy	17800.00
0005433293211	29598	Economy	17800.00
0005433293212	29598	Economy	17800.00
0005433293214	29598	Economy	17800.00
0005433473203	6681	Economy	14000.00
0005433473209	6681	Economy	14000.00
0005435257156	6681	Economy	14000.00
0005433473210	6681	Economy	12700.00
0005433473207	6681	Economy	12700.00
0005433473196	6681	Economy	12700.00
0005433473211	6681	Economy	12700.00
0005435257155	6681	Economy	12700.00
0005435257143	6681	Economy	12700.00
0005435257165	6681	Economy	12700.00
0005435257146	6681	Economy	12700.00
0005435257144	6681	Economy	12700.00
0005433473206	6681	Economy	12700.00
0005435257164	6681	Economy	12700.00
0005435257148	6681	Economy	12700.00
0005435257147	6681	Economy	12700.00
0005433473194	6681	Economy	12700.00
0005433473201	6681	Economy	12700.00
0005435257154	6681	Economy	12700.00
0005433473198	6681	Economy	12700.00
0005433473197	6681	Economy	12700.00
0005433473199	6681	Economy	12700.00
0005433473212	6681	Economy	12700.00
0005433473200	6681	Economy	12700.00
0005433473202	6681	Economy	12700.00
0005433473204	6681	Economy	12700.00
0005433473205	6681	Economy	12700.00
0005433473208	6681	Economy	12700.00
0005435257153	6681	Economy	12700.00
0005433473195	6681	Economy	12700.00
0005433473144	23885	Economy	14000.00
0005435257206	23885	Economy	14000.00
0005433473141	23885	Economy	14000.00
0005433473100	23885	Economy	14000.00
0005433473116	23885	Economy	12700.00
0005433473142	23885	Economy	12700.00
0005435257201	23885	Economy	12700.00
0005435257207	23885	Economy	12700.00
0005433473132	23885	Economy	12700.00
0005435257200	23885	Economy	12700.00
0005433473104	23885	Economy	12700.00
0005433473135	23885	Economy	12700.00
0005433473117	23885	Economy	12700.00
0005433473131	23885	Economy	12700.00
0005435257208	23885	Economy	12700.00
0005433473111	23885	Economy	12700.00
0005435257205	23885	Economy	12700.00
0005433473129	23885	Economy	12700.00
0005435257199	23885	Economy	12700.00
0005433473109	23885	Economy	12700.00
0005435257202	23885	Economy	12700.00
0005435257204	23885	Economy	12700.00
0005433473174	23885	Economy	12700.00
0005433473103	23885	Economy	12700.00
0005433473106	23885	Economy	12700.00
0005433473110	23885	Economy	12700.00
0005435257203	23885	Economy	12700.00
0005433473143	23885	Economy	12700.00
0005434606771	18931	Economy	6600.00
0005434606770	18931	Economy	6600.00
0005434606773	18931	Economy	6600.00
0005434606803	22362	Economy	6600.00
0005434604871	22362	Economy	6600.00
0005434606802	22362	Economy	6600.00
0005434606805	22362	Economy	6600.00
0005434604873	22362	Economy	6600.00
0005434604874	22362	Economy	6600.00
0005434606804	22362	Economy	6600.00
0005434604872	22362	Economy	6600.00
0005434602884	3843	Economy	24900.00
0005434522419	3843	Economy	22600.00
0005435904369	3843	Economy	22600.00
0005435904366	3843	Economy	22600.00
0005434602885	3843	Economy	22600.00
0005434602881	3843	Economy	22600.00
0005434602880	3843	Economy	22600.00
0005434522421	3843	Economy	22600.00
0005435904368	3843	Economy	22600.00
0005434522420	3843	Economy	22600.00
0005435904376	3843	Economy	22600.00
0005434522417	3843	Economy	22600.00
0005434602882	3843	Economy	22600.00
0005434522418	3843	Economy	22600.00
0005434522423	3843	Economy	22600.00
0005434602883	3843	Economy	22600.00
0005435904377	3843	Economy	22600.00
0005434522422	3843	Economy	22600.00
0005435904375	3843	Economy	22600.00
0005435904370	3843	Economy	22600.00
0005434604841	19058	Economy	24900.00
0005435904394	19058	Economy	22600.00
0005434602874	19058	Economy	22600.00
0005434522398	19058	Economy	22600.00
0005434602860	19058	Economy	22600.00
0005434604853	19058	Economy	22600.00
0005435904391	19058	Economy	22600.00
0005435904393	19058	Economy	22600.00
0005434522397	19058	Economy	22600.00
0005434522377	19058	Economy	22600.00
0005434602873	19058	Economy	22600.00
0005435904392	19058	Economy	22600.00
0005434522381	19058	Economy	22600.00
0005434604842	19058	Economy	22600.00
0005434522395	19058	Economy	22600.00
0005432747315	425	Business	44500.00
0005432747314	425	Business	44500.00
0005432747304	425	Business	44500.00
0005432747327	425	Business	44500.00
0005432890673	425	Business	44500.00
0005433293147	425	Business	44500.00
0005432747336	425	Business	44500.00
0005432747298	425	Business	44500.00
0005432753277	425	Business	44500.00
0005432747307	425	Economy	14800.00
0005432747323	425	Economy	14800.00
0005432219977	425	Economy	14800.00
0005432747321	425	Economy	14800.00
0005432751503	425	Economy	14800.00
0005432747324	425	Economy	14800.00
0005432747301	425	Economy	14800.00
0005432747333	425	Economy	14800.00
0005432747332	425	Economy	14800.00
0005432219976	425	Economy	16300.00
0005432753276	425	Economy	16300.00
0005432747308	425	Economy	16300.00
0005432747316	425	Economy	14800.00
0005433293174	425	Economy	14800.00
0005432747319	425	Economy	14800.00
0005432219975	425	Economy	14800.00
0005432751504	425	Economy	14800.00
0005432747309	425	Economy	14800.00
0005432747331	425	Economy	14800.00
0005432890676	425	Economy	14800.00
0005432890705	425	Economy	14800.00
0005432753278	425	Economy	14800.00
0005433293152	425	Economy	14800.00
0005432747320	425	Economy	14800.00
0005432890694	425	Economy	14800.00
0005432747329	425	Economy	14800.00
0005432747303	425	Economy	14800.00
0005432747328	425	Economy	14800.00
0005433293173	425	Economy	14800.00
0005432747313	425	Economy	14800.00
0005432747311	425	Economy	14800.00
0005432890678	425	Economy	14800.00
0005432747326	425	Economy	14800.00
0005432747312	425	Economy	14800.00
0005432219974	425	Economy	14800.00
0005435154593	425	Economy	14800.00
0005433293146	425	Economy	14800.00
0005432747299	425	Economy	14800.00
0005433293142	425	Economy	14800.00
0005432747330	425	Economy	14800.00
0005435154592	425	Economy	14800.00
0005432751502	425	Economy	14800.00
0005432747334	425	Economy	14800.00
0005432890706	425	Economy	14800.00
0005432747317	425	Economy	14800.00
0005432749770	425	Economy	14800.00
0005433293153	425	Economy	14800.00
0005432747318	425	Economy	14800.00
0005432747302	425	Economy	14800.00
0005432890677	425	Economy	14800.00
0005432747306	425	Economy	14800.00
0005433293159	425	Economy	14800.00
0005432747325	425	Economy	14800.00
0005432749769	425	Economy	14800.00
0005432747300	425	Economy	14800.00
0005432747335	425	Economy	14800.00
0005432747322	425	Economy	14800.00
0005432747305	425	Economy	14800.00
0005432747310	425	Economy	14800.00
0005432890762	425	Economy	14800.00
0005432747025	12091	Business	44500.00
0005432890903	12091	Business	44500.00
0005432890895	12091	Business	44500.00
0005432747096	12091	Business	44500.00
0005432890906	12091	Business	44500.00
0005432747013	12091	Business	44500.00
0005432890907	12091	Business	44500.00
0005432749752	12091	Economy	14800.00
0005432746965	12091	Economy	14800.00
0005432890890	12091	Economy	14800.00
0005432890908	12091	Economy	14800.00
0005432890896	12091	Economy	14800.00
0005432214790	12091	Economy	16300.00
0005432746982	12091	Economy	16300.00
0005432746975	12091	Economy	14800.00
0005432747080	12091	Economy	14800.00
0005432747024	12091	Economy	14800.00
0005432747042	12091	Economy	14800.00
0005432746889	12091	Economy	14800.00
0005432890892	12091	Economy	14800.00
0005432746952	12091	Economy	14800.00
0005432890897	12091	Economy	14800.00
0005432749758	12091	Economy	14800.00
0005432746865	12091	Economy	14800.00
0005432890898	12091	Economy	14800.00
0005432890902	12091	Economy	14800.00
0005432890901	12091	Economy	14800.00
0005433875369	12091	Economy	14800.00
0005432890905	12091	Economy	14800.00
0005432890900	12091	Economy	14800.00
0005432747302	12091	Economy	14800.00
0005432890891	12091	Economy	14800.00
0005432756792	12091	Economy	14800.00
0005432747099	12091	Economy	14800.00
0005432747095	12091	Economy	14800.00
0005432747081	12091	Economy	14800.00
0005433875368	12091	Economy	14800.00
0005432747114	12091	Economy	14800.00
0005432747028	12091	Economy	14800.00
0005432747005	12091	Economy	14800.00
0005432747014	12091	Economy	14800.00
0005432890904	12091	Economy	14800.00
0005432746909	12091	Economy	14800.00
0005432214789	12091	Economy	14800.00
0005432890894	12091	Economy	14800.00
0005432747066	12091	Economy	14800.00
0005432746885	12091	Economy	14800.00
0005432890893	12091	Economy	14800.00
0005432747098	12091	Economy	14800.00
0005432746964	12091	Economy	14800.00
0005432890899	12091	Economy	14800.00
0005432890909	12091	Economy	14800.00
0005433531267	18991	Economy	25700.00
0005433524966	18991	Economy	25700.00
0005432927902	18991	Economy	25700.00
0005433524964	18991	Economy	25700.00
0005433524959	18991	Economy	25700.00
0005433533282	18991	Economy	25700.00
0005433531266	18991	Economy	25700.00
0005433524963	18991	Economy	25700.00
0005432927886	18991	Economy	25700.00
0005432927889	18991	Economy	25700.00
0005433533281	18991	Economy	25700.00
0005433524962	18991	Economy	25700.00
0005433524958	18991	Economy	25700.00
0005433533279	18991	Economy	25700.00
0005433533280	18991	Economy	25700.00
0005433524960	18991	Economy	25700.00
0005433524965	18991	Economy	25700.00
0005432927901	18991	Economy	25700.00
0005433531265	18991	Economy	25700.00
0005433524967	18991	Economy	25700.00
0005433524961	18991	Economy	25700.00
0005433531268	18991	Economy	25700.00
0005433524957	18991	Economy	25700.00
0005433531241	32478	Economy	28200.00
0005433524876	32478	Economy	25700.00
0005433527203	32478	Economy	25700.00
0005433531242	32478	Economy	25700.00
0005433524848	32478	Economy	25700.00
0005433524847	32478	Economy	25700.00
0005433531225	32478	Economy	25700.00
0005432927953	32478	Economy	25700.00
0005432927950	32478	Economy	25700.00
0005433524851	32478	Economy	25700.00
0005433531226	32478	Economy	25700.00
0005433524917	32478	Economy	25700.00
0005433524903	32478	Economy	25700.00
0005433531239	32478	Economy	25700.00
0005432927951	32478	Economy	25700.00
0005433524866	32478	Economy	25700.00
0005433524918	32478	Economy	25700.00
0005432927949	32478	Economy	25700.00
0005433531234	32478	Economy	25700.00
0005433524891	32478	Economy	25700.00
0005432927952	32478	Economy	25700.00
0005433524877	32478	Economy	25700.00
0005433524890	32478	Economy	25700.00
0005435372505	5242	Business	84000.00
0005435372220	5242	Business	84000.00
0005434822860	5242	Business	84000.00
0005434822753	5242	Business	84000.00
0005435372409	5242	Business	84000.00
0005434822758	5242	Business	84000.00
0005434822769	5242	Business	84000.00
0005432121252	5242	Business	84000.00
0005435149940	5242	Business	84000.00
0005432121246	5242	Business	84000.00
0005434822798	5242	Business	84000.00
0005434822820	5242	Business	84000.00
0005435372412	5242	Business	84000.00
0005435372472	5242	Business	84000.00
0005435372464	5242	Business	84000.00
0005435372471	5242	Business	84000.00
0005434822756	5242	Business	84000.00
0005434822767	5242	Business	84000.00
0005434822791	5242	Business	84000.00
0005434822742	5242	Comfort	47600.00
0005435304108	5242	Comfort	47600.00
0005434822845	5242	Comfort	47600.00
0005434822823	5242	Comfort	47600.00
0005434822789	5242	Comfort	47600.00
0005434822755	5242	Comfort	47600.00
0005435149937	5242	Comfort	47600.00
0005434822787	5242	Comfort	47600.00
0005435372254	5242	Comfort	47600.00
0005435372599	5242	Comfort	47600.00
0005435149944	5242	Comfort	47600.00
0005434822834	5242	Comfort	47600.00
0005434822831	5242	Comfort	47600.00
0005434822843	5242	Comfort	47600.00
0005434822803	5242	Comfort	47600.00
0005435372433	5242	Comfort	47600.00
0005435149948	5242	Comfort	47600.00
0005435386482	5242	Comfort	47600.00
0005434822747	5242	Comfort	47600.00
0005434822846	5242	Comfort	47600.00
0005435372301	5242	Comfort	47600.00
0005435372213	5242	Comfort	47600.00
0005434822856	5242	Comfort	47600.00
0005435372482	5242	Comfort	47600.00
0005435149946	5242	Comfort	47600.00
0005432121250	5242	Comfort	47600.00
0005434822779	5242	Comfort	47600.00
0005435372376	5242	Comfort	47600.00
0005434828676	5242	Comfort	47600.00
0005434822822	5242	Comfort	47600.00
0005434822836	5242	Economy	28000.00
0005435386463	5242	Comfort	47600.00
0005432394078	5242	Economy	28000.00
0005434822746	5242	Economy	28000.00
0005434828677	5242	Economy	28000.00
0005435372413	5242	Economy	28000.00
0005434822867	5242	Economy	28000.00
0005434822830	5242	Economy	28000.00
0005435372479	5242	Economy	28000.00
0005435386479	5242	Economy	28000.00
0005434822776	5242	Economy	28000.00
0005434822751	5242	Economy	28000.00
0005435372432	5242	Economy	28000.00
0005434822740	5242	Economy	28000.00
0005435299696	5242	Economy	28000.00
0005435372132	5242	Economy	28000.00
0005435372252	5242	Economy	28000.00
0005434822752	5242	Economy	28000.00
0005434822761	5242	Economy	28000.00
0005434822768	5242	Economy	28000.00
0005432121243	5242	Economy	28000.00
0005434822771	5242	Economy	28000.00
0005434822804	5242	Economy	28000.00
0005435661881	5242	Economy	28000.00
0005434822833	5242	Economy	28000.00
0005434822763	5242	Economy	28000.00
0005435386454	5242	Economy	28000.00
0005435372377	5242	Economy	28000.00
0005435372316	5242	Economy	28000.00
0005435386466	5242	Economy	28000.00
0005434664945	5242	Economy	28000.00
0005435372317	5242	Economy	28000.00
0005434822777	5242	Economy	28000.00
0005434822857	5242	Economy	28000.00
0005434558225	5242	Economy	28000.00
0005434822812	5242	Economy	28000.00
0005434822858	5242	Economy	28000.00
0005434822807	5242	Economy	28000.00
0005435372122	5242	Economy	28000.00
0005434822759	5242	Economy	28000.00
0005435372683	5242	Economy	28000.00
0005434558219	5242	Economy	28000.00
0005434822814	5242	Economy	28000.00
0005435372331	5242	Economy	28000.00
0005435372244	5242	Economy	28000.00
0005434822741	5242	Economy	28000.00
0005432823416	5242	Economy	28000.00
0005434558222	5242	Economy	28000.00
0005434822854	5242	Economy	28000.00
0005432121247	5242	Economy	28000.00
0005434822743	5242	Economy	28000.00
0005435372480	5242	Economy	28000.00
0005434822816	5242	Economy	28000.00
0005434822813	5242	Economy	30800.00
0005435386483	5242	Economy	28000.00
0005432396217	5242	Economy	30800.00
0005434822835	5242	Economy	28000.00
0005434831116	5242	Economy	28000.00
0005435372100	5242	Economy	30800.00
0005432396219	5242	Economy	30800.00
0005434822795	5242	Economy	30800.00
0005435372131	5242	Economy	28000.00
0005434822852	5242	Economy	28000.00
0005435149947	5242	Economy	28000.00
0005434822848	5242	Economy	28000.00
0005434822828	5242	Economy	28000.00
0005434822773	5242	Economy	28000.00
0005435372399	5242	Economy	28000.00
0005434822757	5242	Economy	28000.00
0005434664944	5242	Economy	28000.00
0005434828678	5242	Economy	28000.00
0005432121251	5242	Economy	28000.00
0005434822806	5242	Economy	28000.00
0005434558226	5242	Economy	28000.00
0005434822838	5242	Economy	28000.00
0005434822784	5242	Economy	28000.00
0005432394079	5242	Economy	28000.00
0005434831119	5242	Economy	28000.00
0005434822774	5242	Economy	28000.00
0005434822801	5242	Economy	28000.00
0005434822786	5242	Economy	28000.00
0005435372400	5242	Economy	28000.00
0005435661879	5242	Economy	28000.00
0005434822815	5242	Economy	28000.00
0005434822825	5242	Economy	28000.00
0005434822862	5242	Economy	28000.00
0005434822824	5242	Economy	28000.00
0005432121241	5242	Economy	28000.00
0005434822762	5242	Economy	28000.00
0005434822826	5242	Economy	28000.00
0005434558223	5242	Economy	28000.00
0005435372265	5242	Economy	28000.00
0005434822829	5242	Economy	28000.00
0005434822866	5242	Economy	28000.00
0005432121244	5242	Economy	28000.00
0005434822775	5242	Economy	28000.00
0005434822859	5242	Economy	28000.00
0005435372348	5242	Economy	28000.00
0005435372368	5242	Economy	28000.00
0005432396216	5242	Economy	28000.00
0005434822797	5242	Economy	28000.00
0005434822766	5242	Economy	28000.00
0005434664943	5242	Economy	28000.00
0005435149942	5242	Economy	28000.00
0005435372186	5242	Economy	28000.00
0005434822864	5242	Economy	28000.00
0005435372245	5242	Economy	28000.00
0005432396218	5242	Economy	28000.00
0005434822819	5242	Economy	28000.00
0005435372107	5242	Economy	28000.00
0005435372397	5242	Economy	28000.00
0005435372378	5242	Economy	28000.00
0005435372176	5242	Economy	28000.00
0005434822827	5242	Economy	28000.00
0005434822855	5242	Economy	28000.00
0005435149941	5242	Economy	28000.00
0005435386480	5242	Economy	28000.00
0005434822792	5242	Economy	28000.00
0005434822749	5242	Economy	28000.00
0005434822837	5242	Economy	28000.00
0005434822760	5242	Economy	28000.00
0005435372224	5242	Economy	28000.00
0005434831118	5242	Economy	28000.00
0005435372221	5242	Economy	28000.00
0005435149949	5242	Economy	28000.00
0005435372287	5242	Economy	28000.00
0005434822799	5242	Economy	28000.00
0005435372113	5242	Economy	28000.00
0005434822849	5242	Economy	28000.00
0005434558221	5242	Economy	28000.00
0005434822847	5242	Economy	28000.00
0005432121242	5242	Economy	28000.00
0005434822782	5242	Economy	28000.00
0005434822790	5242	Economy	28000.00
0005434822793	5242	Economy	28000.00
0005435386467	5242	Economy	28000.00
0005435299703	5242	Economy	28000.00
0005434822841	5242	Economy	28000.00
0005435372506	5242	Economy	28000.00
0005434822811	5242	Economy	28000.00
0005435372414	5242	Economy	30800.00
0005434822817	5242	Economy	28000.00
0005434822783	5242	Economy	30800.00
0005435372098	5242	Economy	30800.00
0005435372226	5242	Economy	30800.00
0005434822765	5242	Economy	28000.00
0005434822810	5242	Economy	28000.00
0005434822832	5242	Economy	28000.00
0005434822745	5242	Economy	28000.00
0005434822805	5242	Economy	28000.00
0005434822780	5242	Economy	28000.00
0005435372545	5242	Economy	28000.00
0005434822778	5242	Economy	28000.00
0005434822770	5242	Economy	28000.00
0005434822750	5242	Economy	28000.00
0005435372270	5242	Economy	28000.00
0005434831117	5242	Economy	28000.00
0005434822839	5242	Economy	28000.00
0005435149943	5242	Economy	28000.00
0005435149938	5242	Economy	28000.00
0005434822840	5242	Economy	28000.00
0005435372166	5242	Economy	28000.00
0005432121248	5242	Economy	28000.00
0005434822772	5242	Economy	28000.00
0005434822850	5242	Economy	28000.00
0005434822844	5242	Economy	28000.00
0005434822748	5242	Economy	28000.00
0005435372481	5242	Economy	28000.00
0005434822788	5242	Economy	28000.00
0005434822796	5242	Economy	28000.00
0005434822809	5242	Economy	28000.00
0005434822861	5242	Economy	28000.00
0005434822863	5242	Economy	28000.00
0005435372520	5242	Economy	28000.00
0005435372349	5242	Economy	28000.00
0005432121245	5242	Economy	28000.00
0005435372521	5242	Economy	28000.00
0005434822800	5242	Economy	28000.00
0005434822754	5242	Economy	28000.00
0005434822868	5242	Economy	28000.00
0005434822865	5242	Economy	28000.00
0005434822808	5242	Economy	28000.00
0005432121253	5242	Economy	28000.00
0005434822744	5242	Economy	28000.00
0005435372332	5242	Economy	28000.00
0005434822739	5242	Economy	28000.00
0005434822785	5242	Economy	28000.00
0005435372600	5242	Economy	28000.00
0005435149939	5242	Economy	28000.00
0005432394077	5242	Economy	28000.00
0005434831115	5242	Economy	28000.00
0005435372470	5242	Economy	28000.00
0005432394080	5242	Economy	28000.00
0005434822764	5242	Economy	28000.00
0005435372106	5242	Economy	28000.00
0005432121254	5242	Economy	28000.00
0005434822853	5242	Economy	28000.00
0005434822794	5242	Economy	28000.00
0005435178978	5242	Economy	28000.00
0005434822842	5242	Economy	28000.00
0005435735060	5242	Economy	28000.00
0005434822851	5242	Economy	28000.00
0005435372282	5242	Economy	28000.00
0005434831120	5242	Economy	28000.00
0005432121255	5242	Economy	28000.00
0005435149945	5242	Economy	28000.00
0005434558220	5242	Economy	28000.00
0005435372177	5242	Economy	28000.00
0005432121249	5242	Economy	28000.00
0005435372375	5242	Economy	28000.00
0005435372291	5242	Economy	28000.00
0005434822818	5242	Economy	28000.00
0005434822781	5242	Economy	28000.00
0005434822802	5242	Economy	28000.00
0005434822821	5242	Economy	28000.00
0005435372443	5242	Economy	28000.00
0005434558224	5242	Economy	28000.00
0005435149849	9931	Business	84000.00
0005435149805	9931	Business	84000.00
0005432203021	9931	Business	84000.00
0005432203019	9931	Business	84000.00
0005434821691	9931	Business	84000.00
0005434831066	9931	Business	84000.00
0005434822157	9931	Business	84000.00
0005434822025	9931	Business	84000.00
0005434821820	9931	Business	84000.00
0005435299747	9931	Business	84000.00
0005432203015	9931	Business	84000.00
0005434821847	9931	Business	84000.00
0005435302169	9931	Business	84000.00
0005434822002	9931	Business	84000.00
0005434821873	9931	Business	84000.00
0005435372867	9931	Business	84000.00
0005432203016	9931	Business	84000.00
0005435372865	9931	Comfort	47600.00
0005434821767	9931	Comfort	47600.00
0005435149807	9931	Comfort	47600.00
0005434822041	9931	Comfort	47600.00
0005435372830	9931	Comfort	47600.00
0005434821728	9931	Comfort	47600.00
0005435372881	9931	Comfort	47600.00
0005435372893	9931	Comfort	47600.00
0005435372871	9931	Comfort	47600.00
0005435372859	9931	Comfort	47600.00
0005435735110	9931	Comfort	47600.00
0005435372853	9931	Comfort	47600.00
0005435372887	9931	Comfort	47600.00
0005434821752	9931	Comfort	47600.00
0005435372875	9931	Comfort	47600.00
0005435299749	9931	Comfort	47600.00
0005435372891	9931	Comfort	47600.00
0005434822042	9931	Comfort	47600.00
0005434821507	9931	Comfort	47600.00
0005434821733	9931	Comfort	47600.00
0005432400066	9931	Comfort	47600.00
0005435372832	9931	Comfort	47600.00
0005435299748	9931	Comfort	47600.00
0005435149862	9931	Comfort	47600.00
0005435386532	9931	Comfort	47600.00
0005434821741	9931	Comfort	47600.00
0005435149795	9931	Comfort	47600.00
0005434821995	9931	Comfort	47600.00
0005434822257	9931	Comfort	47600.00
0005434821687	9931	Economy	28000.00
0005434821596	9931	Economy	28000.00
0005435149861	9931	Economy	28000.00
0005435372846	9931	Economy	28000.00
0005435372864	9931	Economy	28000.00
0005435386538	9931	Economy	28000.00
0005434821727	9931	Economy	28000.00
0005434828649	9931	Economy	28000.00
0005435372884	9931	Economy	28000.00
0005434821712	9931	Economy	28000.00
0005435372844	9931	Economy	28000.00
0005434821608	9931	Economy	28000.00
0005435372876	9931	Economy	28000.00
0005434821766	9931	Economy	28000.00
0005434828651	9931	Economy	28000.00
0005435372873	9931	Economy	28000.00
0005435372894	9931	Economy	28000.00
0005435372863	9931	Economy	28000.00
0005432396173	9931	Economy	28000.00
0005435372836	9931	Economy	28000.00
0005434821685	9931	Economy	28000.00
0005435735113	9931	Economy	28000.00
0005435372860	9931	Economy	28000.00
0005435302168	9931	Economy	28000.00
0005432203017	9931	Economy	28000.00
0005435372843	9931	Economy	28000.00
0005434821665	9931	Economy	28000.00
0005432396193	9931	Economy	28000.00
0005435372872	9931	Economy	28000.00
0005434821575	9931	Economy	28000.00
0005434821768	9931	Economy	28000.00
0005434821377	9931	Economy	28000.00
0005435149787	9931	Economy	28000.00
0005434821498	9931	Economy	28000.00
0005434822237	9931	Economy	28000.00
0005434831079	9931	Economy	28000.00
0005434821786	9931	Economy	28000.00
0005434821638	9931	Economy	28000.00
0005435149806	9931	Economy	28000.00
0005434822318	9931	Economy	28000.00
0005434821505	9931	Economy	28000.00
0005435372842	9931	Economy	28000.00
0005435661913	9931	Economy	28000.00
0005434821474	9931	Economy	28000.00
0005435372848	9931	Economy	28000.00
0005432823438	9931	Economy	28000.00
0005435372866	9931	Economy	28000.00
0005435735112	9931	Economy	28000.00
0005434821895	9931	Economy	28000.00
0005434822003	9931	Economy	30800.00
0005435372862	9931	Economy	28000.00
0005434821350	9931	Economy	30800.00
0005434822069	9931	Economy	30800.00
0005432396180	9931	Economy	30800.00
0005434821499	9931	Economy	28000.00
0005434831084	9931	Economy	28000.00
0005434821435	9931	Economy	28000.00
0005434821381	9931	Economy	28000.00
0005435372874	9931	Economy	28000.00
0005434664923	9931	Economy	28000.00
0005434821858	9931	Economy	28000.00
0005434821744	9931	Economy	28000.00
0005432823437	9931	Economy	28000.00
0005434821731	9931	Economy	28000.00
0005435372845	9931	Economy	28000.00
0005435302172	9931	Economy	28000.00
0005434831088	9931	Economy	28000.00
0005435372849	9931	Economy	28000.00
0005435372850	9931	Economy	28000.00
0005432396197	9931	Economy	28000.00
0005434821437	9931	Economy	28000.00
0005435372831	9931	Economy	28000.00
0005434821802	9931	Economy	28000.00
0005435302171	9931	Economy	28000.00
0005435372885	9931	Economy	28000.00
0005434821336	9931	Economy	28000.00
0005434821506	9931	Economy	28000.00
0005435299746	9931	Economy	28000.00
0005434831077	9931	Economy	28000.00
0005435372833	9931	Economy	28000.00
0005435372889	9931	Economy	28000.00
0005435372877	9931	Economy	28000.00
0005434821764	9931	Economy	28000.00
0005435372854	9931	Economy	28000.00
0005435372861	9931	Economy	28000.00
0005435372890	9931	Economy	28000.00
0005434822202	9931	Economy	28000.00
0005434822317	9931	Economy	28000.00
0005434821808	9931	Economy	28000.00
0005435299745	9931	Economy	28000.00
0005435372837	9931	Economy	28000.00
0005434831085	9931	Economy	28000.00
0005434822004	9931	Economy	28000.00
0005432203018	9931	Economy	28000.00
0005432203020	9931	Economy	28000.00
0005435302170	9931	Economy	28000.00
0005434821480	9931	Economy	28000.00
0005434821546	9931	Economy	28000.00
0005435372829	9931	Economy	28000.00
0005434822333	9931	Economy	28000.00
0005434821946	9931	Economy	28000.00
0005435149826	9931	Economy	28000.00
0005435372851	9931	Economy	28000.00
0005435372841	9931	Economy	28000.00
0005435372834	9931	Economy	28000.00
0005434821872	9931	Economy	28000.00
0005435386537	9931	Economy	28000.00
0005435149850	9931	Economy	28000.00
0005434821686	9931	Economy	28000.00
0005434821935	9931	Economy	28000.00
0005432396179	9931	Economy	28000.00
0005434821829	9931	Economy	28000.00
0005434821636	9931	Economy	28000.00
0005434821637	9931	Economy	28000.00
0005434821871	9931	Economy	28000.00
0005434664920	9931	Economy	28000.00
0005434822036	9931	Economy	28000.00
0005434831095	9931	Economy	28000.00
0005434821815	9931	Economy	28000.00
0005434822331	9931	Economy	28000.00
0005434821481	9931	Economy	28000.00
0005435386536	9931	Economy	28000.00
0005434831096	9931	Economy	28000.00
0005435372892	9931	Economy	28000.00
0005435386533	9931	Economy	28000.00
0005434664924	9931	Economy	28000.00
0005435372868	9931	Economy	28000.00
0005435372840	9931	Economy	28000.00
0005435372869	9931	Economy	28000.00
0005435372880	9931	Economy	28000.00
0005435735115	9931	Economy	28000.00
0005435735114	9931	Economy	28000.00
0005434822193	9931	Economy	28000.00
0005435735116	9931	Economy	30800.00
0005434821609	9931	Economy	30800.00
0005435372878	9931	Economy	30800.00
0005434821579	9931	Economy	30800.00
0005434822186	9931	Economy	28000.00
0005435179391	9931	Economy	28000.00
0005435372870	9931	Economy	28000.00
0005434821494	9931	Economy	28000.00
0005435372855	9931	Economy	28000.00
0005435299744	9931	Economy	28000.00
0005435372828	9931	Economy	28000.00
0005434821804	9931	Economy	28000.00
0005434822035	9931	Economy	28000.00
0005434821980	9931	Economy	28000.00
0005435372883	9931	Economy	28000.00
0005435372857	9931	Economy	28000.00
0005434822072	9931	Economy	28000.00
0005435372888	9931	Economy	28000.00
0005435386534	9931	Economy	28000.00
0005432396183	9931	Economy	28000.00
0005435386531	9931	Economy	28000.00
0005434821619	9931	Economy	28000.00
0005434821814	9931	Economy	28000.00
0005435149788	9931	Economy	28000.00
0005434821894	9931	Economy	28000.00
0005435179690	9931	Economy	28000.00
0005435386535	9931	Economy	28000.00
0005434821592	9931	Economy	28000.00
0005434821469	9931	Economy	28000.00
0005434821667	9931	Economy	28000.00
0005434821962	9931	Economy	28000.00
0005434822037	9931	Economy	28000.00
0005434822068	9931	Economy	28000.00
0005434821514	9931	Economy	28000.00
0005435372839	9931	Economy	28000.00
0005435372856	9931	Economy	28000.00
0005434821805	9931	Economy	28000.00
0005434821436	9931	Economy	28000.00
0005434822263	9931	Economy	28000.00
0005435372886	9931	Economy	28000.00
0005434821889	9931	Economy	28000.00
0005434822038	9931	Economy	28000.00
0005434821704	9931	Economy	28000.00
0005434821523	9931	Economy	28000.00
0005435149796	9931	Economy	28000.00
0005434821993	9931	Economy	28000.00
0005434821762	9931	Economy	28000.00
0005435372827	9931	Economy	28000.00
0005435372847	9931	Economy	28000.00
0005435735111	9931	Economy	28000.00
0005435149800	9931	Economy	28000.00
0005434821486	9931	Economy	28000.00
0005435372835	9931	Economy	28000.00
0005432400072	9931	Economy	28000.00
0005435661914	9931	Economy	28000.00
0005434821666	9931	Economy	28000.00
0005434821369	9931	Economy	28000.00
0005435372882	9931	Economy	28000.00
0005435149863	9931	Economy	28000.00
0005435372852	9931	Economy	28000.00
0005434821902	9931	Economy	28000.00
0005435372858	9931	Economy	28000.00
0005434821751	9931	Economy	28000.00
0005435372879	9931	Economy	28000.00
0005434828650	9931	Economy	28000.00
0005434821574	9931	Economy	28000.00
0005434822334	9931	Economy	28000.00
0005435372838	9931	Economy	28000.00
0005434821576	9931	Economy	28000.00
0005435082739	6980	Economy	8200.00
0005435082736	6980	Economy	7400.00
0005435082738	6980	Economy	7400.00
0005435790289	6980	Economy	7400.00
0005435082737	6980	Economy	7400.00
0005435790291	6980	Economy	7400.00
0005435790290	6980	Economy	7400.00
0005435790288	6980	Economy	7400.00
0005435082740	6980	Economy	7400.00
0005435082741	6980	Economy	7400.00
0005435790287	6980	Economy	7400.00
0005435082651	25966	Economy	8200.00
0005435082665	25966	Economy	7400.00
0005435082666	25966	Economy	7400.00
0005435790272	25966	Economy	7400.00
0005435082669	25966	Economy	7400.00
0005435082675	25966	Economy	7400.00
0005435082658	25966	Economy	7400.00
0005435082659	25966	Economy	7400.00
0005435082657	25966	Economy	7400.00
0005435082664	25966	Economy	7400.00
0005434756200	9551	Business	32800.00
0005434213827	9551	Business	32800.00
0005434756170	9551	Business	32800.00
0005434213874	9551	Business	32800.00
0005434213735	9551	Business	32800.00
0005434756184	9551	Business	32800.00
0005434213725	9551	Business	32800.00
0005434213925	9551	Business	32800.00
0005434213917	9551	Business	32800.00
0005434756173	9551	Business	32800.00
0005434756169	9551	Economy	10900.00
0005434213805	9551	Economy	10900.00
0005434213785	9551	Economy	10900.00
0005434213992	9551	Economy	10900.00
0005434213871	9551	Economy	10900.00
0005434213870	9551	Economy	10900.00
0005434213721	9551	Economy	10900.00
0005434213951	9551	Economy	10900.00
0005434213826	9551	Economy	10900.00
0005434756192	9551	Economy	10900.00
0005434213746	9551	Economy	12000.00
0005434756175	9551	Economy	12000.00
0005434756182	9551	Economy	12000.00
0005434756201	9551	Economy	12000.00
0005434213753	9551	Economy	12000.00
0005434213922	9551	Economy	10900.00
0005434213828	9551	Economy	10900.00
0005434213875	9551	Economy	10900.00
0005434756172	9551	Economy	10900.00
0005434213736	9551	Economy	10900.00
0005434756186	9551	Economy	10900.00
0005434756195	9551	Economy	10900.00
0005434756183	9551	Economy	10900.00
0005434756174	9551	Economy	10900.00
0005434213744	9551	Economy	10900.00
0005434756179	9551	Economy	10900.00
0005434756190	9551	Economy	10900.00
0005434213807	9551	Economy	10900.00
0005434213747	9551	Economy	10900.00
0005434213780	9551	Economy	10900.00
0005434213751	9551	Economy	10900.00
0005434213916	9551	Economy	10900.00
0005434213860	9551	Economy	10900.00
0005434213953	9551	Economy	10900.00
0005434756187	9551	Economy	10900.00
0005434756177	9551	Economy	10900.00
0005434213806	9551	Economy	10900.00
0005434214026	9551	Economy	10900.00
0005434213728	9551	Economy	10900.00
0005434756189	9551	Economy	10900.00
0005434213796	9551	Economy	10900.00
0005434756196	9551	Economy	10900.00
0005434756181	9551	Economy	10900.00
0005434213952	9551	Economy	10900.00
0005434756191	9551	Economy	10900.00
0005434213856	9551	Economy	10900.00
0005434213758	9551	Economy	10900.00
0005434214071	9551	Economy	10900.00
0005434756193	9551	Economy	10900.00
0005434213950	9551	Economy	10900.00
0005434213798	9551	Economy	10900.00
0005434213926	9551	Economy	10900.00
0005434213726	9551	Economy	10900.00
0005434756171	9551	Economy	10900.00
0005434213872	9551	Economy	10900.00
0005434756198	9551	Economy	10900.00
0005434756185	9551	Economy	10900.00
0005434213864	9551	Economy	10900.00
0005434213729	9551	Economy	10900.00
0005434213797	9551	Economy	10900.00
0005434756199	9551	Economy	10900.00
0005434756188	9551	Economy	10900.00
0005434213765	9551	Economy	10900.00
0005434213739	9551	Economy	10900.00
0005434756176	9551	Economy	10900.00
0005434756178	9551	Economy	10900.00
0005434213921	9551	Economy	10900.00
0005434213840	9551	Economy	10900.00
0005434756194	9551	Economy	10900.00
0005434756180	9551	Economy	10900.00
0005434756168	9551	Economy	10900.00
0005434756197	9551	Economy	10900.00
0005434214175	28644	Business	32800.00
0005434214180	28644	Business	32800.00
0005434214184	28644	Business	32800.00
0005434755799	28644	Business	32800.00
0005434755765	28644	Business	32800.00
0005434214176	28644	Business	32800.00
0005434214207	28644	Business	32800.00
0005434214210	28644	Business	32800.00
0005434755777	28644	Business	32800.00
0005434214217	28644	Economy	10900.00
0005434214192	28644	Economy	10900.00
0005434755719	28644	Economy	10900.00
0005434214205	28644	Economy	10900.00
0005434214195	28644	Economy	10900.00
0005434214208	28644	Economy	10900.00
0005434755823	28644	Economy	12000.00
0005434214189	28644	Economy	12000.00
0005434755822	28644	Economy	12000.00
0005434755764	28644	Economy	10900.00
0005434214206	28644	Economy	10900.00
0005434755754	28644	Economy	10900.00
0005434755704	28644	Economy	10900.00
0005434214186	28644	Economy	10900.00
0005434214216	28644	Economy	10900.00
0005434214197	28644	Economy	10900.00
0005434755746	28644	Economy	10900.00
0005434755809	28644	Economy	10900.00
0005434214199	28644	Economy	10900.00
0005434214215	28644	Economy	10900.00
0005434755737	28644	Economy	10900.00
0005434214202	28644	Economy	10900.00
0005434214203	28644	Economy	10900.00
0005434214211	28644	Economy	10900.00
0005434214218	28644	Economy	10900.00
0005434755776	28644	Economy	10900.00
0005434214185	28644	Economy	10900.00
0005434214219	28644	Economy	10900.00
0005434755810	28644	Economy	10900.00
0005434214174	28644	Economy	10900.00
0005434214193	28644	Economy	10900.00
0005434214183	28644	Economy	10900.00
0005434214187	28644	Economy	10900.00
0005434755731	28644	Economy	10900.00
0005434214209	28644	Economy	10900.00
0005434214212	28644	Economy	10900.00
0005434755732	28644	Economy	10900.00
0005434214213	28644	Economy	10900.00
0005434214177	28644	Economy	10900.00
0005434214182	28644	Economy	10900.00
0005434214181	28644	Economy	10900.00
0005434755801	28644	Economy	10900.00
0005434214191	28644	Economy	10900.00
0005434214220	28644	Economy	10900.00
0005434755723	28644	Economy	10900.00
0005434214196	28644	Economy	10900.00
0005434214194	28644	Economy	10900.00
0005434214198	28644	Economy	10900.00
0005434755761	28644	Economy	10900.00
0005434214214	28644	Economy	10900.00
0005434214188	28644	Economy	10900.00
0005434214190	28644	Economy	10900.00
0005434214204	28644	Economy	10900.00
0005434755703	28644	Economy	10900.00
0005434755811	28644	Economy	10900.00
0005434214201	28644	Economy	10900.00
0005434214200	28644	Economy	10900.00
0005434755739	28644	Economy	10900.00
0005434755708	28644	Economy	10900.00
0005434755778	28644	Economy	10900.00
0005434214178	28644	Economy	10900.00
0005434214179	28644	Economy	10900.00
0005435100105	10817	Economy	8900.00
0005435100103	10817	Economy	8900.00
0005434760153	10817	Economy	8900.00
0005435100104	10817	Economy	8900.00
0005434760160	10817	Economy	8900.00
0005435100076	31829	Economy	8900.00
0005435100089	31829	Economy	8900.00
0005434760181	31829	Economy	8900.00
0005434760182	31829	Economy	8900.00
0005434639174	1979	Economy	20900.00
0005432290615	1979	Economy	20900.00
0005434639172	1979	Economy	20900.00
0005434639170	1979	Economy	19000.00
0005434639179	1979	Economy	19000.00
0005434639163	1979	Economy	19000.00
0005434639169	1979	Economy	19000.00
0005434639178	1979	Economy	19000.00
0005433202122	1979	Economy	19000.00
0005433202138	1979	Economy	19000.00
0005434639177	1979	Economy	19000.00
0005434639156	1979	Economy	19000.00
0005433202173	1979	Economy	19000.00
0005434639180	1979	Economy	19000.00
0005434639167	1979	Economy	19000.00
0005434639168	1979	Economy	19000.00
0005434639165	1979	Economy	19000.00
0005433202108	1979	Economy	19000.00
0005433202190	1979	Economy	19000.00
0005434639157	1979	Economy	19000.00
0005433202132	1979	Economy	19000.00
0005433202157	1979	Economy	19000.00
0005433202171	1979	Economy	19000.00
0005434639181	1979	Economy	19000.00
0005433202104	1979	Economy	19000.00
0005434639171	1979	Economy	19000.00
0005434639173	1979	Economy	19000.00
0005434639161	1979	Economy	19000.00
0005434639182	1979	Economy	19000.00
0005433202130	1979	Economy	19000.00
0005435948320	1979	Economy	19000.00
0005434639154	1979	Economy	19000.00
0005432290616	1979	Economy	19000.00
0005434639155	1979	Economy	19000.00
0005433202153	1979	Economy	19000.00
0005435948321	1979	Economy	19000.00
0005433202131	1979	Economy	19000.00
0005434639162	1979	Economy	19000.00
0005434639166	1979	Economy	19000.00
0005434639159	1979	Economy	19000.00
0005434639175	1979	Economy	19000.00
0005434639160	1979	Economy	19000.00
0005433202167	1979	Economy	19000.00
0005434639158	1979	Economy	19000.00
0005434639164	1979	Economy	19000.00
0005434639176	1979	Economy	19000.00
0005433202105	1979	Economy	19000.00
0005433202137	1979	Economy	19000.00
0005433202256	23266	Economy	20900.00
0005434638898	23266	Economy	20900.00
0005433202265	23266	Economy	20900.00
0005434638968	23266	Economy	20900.00
0005433202259	23266	Economy	19000.00
0005433202266	23266	Economy	19000.00
0005433202267	23266	Economy	19000.00
0005433202257	23266	Economy	19000.00
0005433202254	23266	Economy	19000.00
0005434638984	23266	Economy	19000.00
0005433202264	23266	Economy	19000.00
0005434638982	23266	Economy	19000.00
0005434638848	23266	Economy	19000.00
0005433202255	23266	Economy	19000.00
0005434638988	23266	Economy	19000.00
0005433202258	23266	Economy	19000.00
0005433202253	23266	Economy	19000.00
0005434638863	23266	Economy	19000.00
0005433202260	23266	Economy	19000.00
0005434638866	23266	Economy	19000.00
0005434638896	23266	Economy	19000.00
0005434638951	23266	Economy	19000.00
0005434638895	23266	Economy	19000.00
0005433202263	23266	Economy	19000.00
0005434638983	23266	Economy	19000.00
0005434638931	23266	Economy	19000.00
0005433202262	23266	Economy	19000.00
0005434638947	23266	Economy	19000.00
0005434638908	23266	Economy	19000.00
0005434638950	23266	Economy	19000.00
0005434638989	23266	Economy	19000.00
0005433202261	23266	Economy	19000.00
0005433533285	6092	Business	69700.00
0005434600655	6092	Business	69700.00
0005433531271	6092	Business	69700.00
0005434600650	6092	Business	69700.00
0005434600646	6092	Business	69700.00
0005434600656	6092	Business	69700.00
0005435326541	6092	Business	69700.00
0005434600648	6092	Economy	23200.00
0005434600639	6092	Economy	23200.00
0005434600644	6092	Economy	23200.00
0005432111262	6092	Economy	23200.00
0005434600640	6092	Economy	25600.00
0005434600633	6092	Economy	23200.00
0005435326528	6092	Economy	23200.00
0005434600631	6092	Economy	23200.00
0005434600652	6092	Economy	23200.00
0005433531269	6092	Economy	23200.00
0005434600637	6092	Economy	23200.00
0005433531270	6092	Economy	23200.00
0005434600638	6092	Economy	23200.00
0005434600645	6092	Economy	23200.00
0005433533286	6092	Economy	23200.00
0005435326552	6092	Economy	23200.00
0005435326554	6092	Economy	23200.00
0005434600657	6092	Economy	23200.00
0005434600647	6092	Economy	23200.00
0005433533283	6092	Economy	23200.00
0005435326544	6092	Economy	23200.00
0005434600632	6092	Economy	23200.00
0005435326559	6092	Economy	23200.00
0005434600649	6092	Economy	23200.00
0005434600642	6092	Economy	23200.00
0005434600654	6092	Economy	23200.00
0005433533284	6092	Economy	23200.00
0005434600641	6092	Economy	23200.00
0005434600634	6092	Economy	23200.00
0005435326543	6092	Economy	23200.00
0005434600643	6092	Economy	23200.00
0005434600651	6092	Economy	23200.00
0005435326551	6092	Economy	23200.00
0005434600635	6092	Economy	23200.00
0005432111260	6092	Economy	23200.00
0005435326499	6092	Economy	23200.00
0005433531272	6092	Economy	23200.00
0005434600653	6092	Economy	23200.00
0005434600630	6092	Economy	23200.00
0005432111259	6092	Economy	23200.00
0005434600636	6092	Economy	23200.00
0005432111261	6092	Economy	23200.00
0005435326654	18609	Business	69700.00
0005435326666	18609	Business	69700.00
0005435326662	18609	Business	69700.00
0005433531233	18609	Economy	23200.00
0005434600416	18609	Economy	23200.00
0005435326661	18609	Economy	25600.00
0005434600554	18609	Economy	23200.00
0005435326655	18609	Economy	23200.00
0005435326659	18609	Economy	23200.00
0005435326656	18609	Economy	23200.00
0005434600477	18609	Economy	23200.00
0005435326657	18609	Economy	23200.00
0005434600357	18609	Economy	23200.00
0005433531231	18609	Economy	23200.00
0005434600463	18609	Economy	23200.00
0005435326658	18609	Economy	23200.00
0005435326665	18609	Economy	23200.00
0005434600361	18609	Economy	23200.00
0005434600438	18609	Economy	23200.00
0005434600516	18609	Economy	23200.00
0005434600509	18609	Economy	23200.00
0005435326663	18609	Economy	23200.00
0005434600405	18609	Economy	23200.00
0005433531232	18609	Economy	23200.00
0005435326660	18609	Economy	23200.00
0005434600415	18609	Economy	23200.00
0005434600439	18609	Economy	23200.00
0005434600386	18609	Economy	23200.00
0005434600351	18609	Economy	23200.00
0005434600389	18609	Economy	23200.00
0005434600356	18609	Economy	23200.00
0005434600462	18609	Economy	23200.00
0005434600450	18609	Economy	23200.00
0005435326664	18609	Economy	23200.00
0005434600458	18609	Economy	23200.00
0005434550843	10616	Business	9100.00
0005434554050	10616	Business	9100.00
0005434550874	10616	Business	9100.00
0005434550823	10616	Business	9100.00
0005433180706	10616	Business	9100.00
0005434550865	10616	Business	9100.00
0005433180655	10616	Business	9100.00
0005434550847	10616	Business	9100.00
0005433180659	10616	Business	9100.00
0005434550862	10616	Business	9100.00
0005434550870	10616	Business	9100.00
0005433180716	10616	Business	9100.00
0005434550848	10616	Economy	3000.00
0005434550849	10616	Economy	3000.00
0005434550828	10616	Economy	3000.00
0005434550838	10616	Economy	3000.00
0005434550845	10616	Economy	3000.00
0005434550840	10616	Economy	3000.00
0005434558215	10616	Economy	3000.00
0005434550826	10616	Economy	3000.00
0005434558214	10616	Economy	3300.00
0005434550863	10616	Economy	3300.00
0005434550833	10616	Economy	3300.00
0005434550853	10616	Economy	3300.00
0005434550873	10616	Economy	3000.00
0005434550835	10616	Economy	3000.00
0005434558213	10616	Economy	3000.00
0005434550875	10616	Economy	3000.00
0005434550824	10616	Economy	3000.00
0005434550822	10616	Economy	3000.00
0005433180708	10616	Economy	3000.00
0005434550864	10616	Economy	3000.00
0005434550836	10616	Economy	3000.00
0005433180710	10616	Economy	3000.00
0005434550850	10616	Economy	3000.00
0005434550825	10616	Economy	3000.00
0005434550841	10616	Economy	3000.00
0005433180681	10616	Economy	3000.00
0005433180702	10616	Economy	3000.00
0005434550851	10616	Economy	3000.00
0005434550869	10616	Economy	3000.00
0005433180811	10616	Economy	3000.00
0005433180695	10616	Economy	3000.00
0005433180740	10616	Economy	3000.00
0005434550858	10616	Economy	3000.00
0005433180707	10616	Economy	3000.00
0005434550855	10616	Economy	3000.00
0005434550871	10616	Economy	3000.00
0005434550866	10616	Economy	3000.00
0005434550830	10616	Economy	3000.00
0005434550859	10616	Economy	3000.00
0005433180715	10616	Economy	3000.00
0005434550839	10616	Economy	3000.00
0005434550872	10616	Economy	3000.00
0005434558212	10616	Economy	3000.00
0005434558218	10616	Economy	3000.00
0005433180741	10616	Economy	3000.00
0005434550854	10616	Economy	3000.00
0005433180735	10616	Economy	3000.00
0005433180714	10616	Economy	3000.00
0005434554049	10616	Economy	3000.00
0005434550846	10616	Economy	3000.00
0005434550834	10616	Economy	3000.00
0005434550837	10616	Economy	3000.00
0005434550827	10616	Economy	3000.00
0005434550842	10616	Economy	3000.00
0005434558217	10616	Economy	3000.00
0005433180774	10616	Economy	3000.00
0005433180739	10616	Economy	3000.00
0005434550831	10616	Economy	3000.00
0005434550857	10616	Economy	3000.00
0005434550820	10616	Economy	3000.00
0005434550861	10616	Economy	3000.00
0005433180705	10616	Economy	3000.00
0005434550852	10616	Economy	3000.00
0005434550832	10616	Economy	3000.00
0005433180775	10616	Economy	3000.00
0005434550856	10616	Economy	3000.00
0005434550844	10616	Economy	3000.00
0005434558211	10616	Economy	3000.00
0005433180694	10616	Economy	3000.00
0005433180738	10616	Economy	3000.00
0005434550860	10616	Economy	3000.00
0005434558216	10616	Economy	3000.00
0005433180677	10616	Economy	3000.00
0005433180682	10616	Economy	3000.00
0005434550821	10616	Economy	3000.00
0005434550819	10616	Economy	3000.00
0005434550829	10616	Economy	3000.00
0005434550868	10616	Economy	3000.00
0005434550867	10616	Economy	3000.00
0005433180954	27720	Business	9100.00
0005433180952	27720	Economy	3000.00
0005433180933	27720	Economy	3000.00
0005433180940	27720	Economy	3000.00
0005433180944	27720	Economy	3300.00
0005433180939	27720	Economy	3300.00
0005433180955	27720	Economy	3000.00
0005433180945	27720	Economy	3000.00
0005433180942	27720	Economy	3000.00
0005433180948	27720	Economy	3000.00
0005433180950	27720	Economy	3000.00
0005433180936	27720	Economy	3000.00
0005433180935	27720	Economy	3000.00
0005433180951	27720	Economy	3000.00
0005433180946	27720	Economy	3000.00
0005433180937	27720	Economy	3000.00
0005433180947	27720	Economy	3000.00
0005433180957	27720	Economy	3000.00
0005433180953	27720	Economy	3000.00
0005433180938	27720	Economy	3000.00
0005433180943	27720	Economy	3000.00
0005433180941	27720	Economy	3000.00
0005433180934	27720	Economy	3000.00
0005433180949	27720	Economy	3000.00
0005433180956	27720	Economy	3000.00
0005434550317	27721	Business	9100.00
0005434550571	27721	Business	9100.00
0005434550675	27721	Business	9100.00
0005434550575	27721	Business	9100.00
0005434550417	27721	Business	9100.00
0005434550569	27721	Business	9100.00
0005434550358	27721	Business	9100.00
0005434550341	27721	Business	9100.00
0005434554029	27721	Economy	3000.00
0005434550460	27721	Economy	3000.00
0005434550701	27721	Economy	3000.00
0005434558150	27721	Economy	3000.00
0005434550677	27721	Economy	3000.00
0005434550283	27721	Economy	3000.00
0005434550526	27721	Economy	3000.00
0005434558147	27721	Economy	3300.00
0005434550602	27721	Economy	3300.00
0005434550463	27721	Economy	3300.00
0005434550520	27721	Economy	3000.00
0005434550399	27721	Economy	3000.00
0005434550415	27721	Economy	3000.00
0005434550524	27721	Economy	3000.00
0005434550676	27721	Economy	3000.00
0005434550624	27721	Economy	3000.00
0005434550414	27721	Economy	3000.00
0005434550427	27721	Economy	3000.00
0005434550398	27721	Economy	3000.00
0005434550359	27721	Economy	3000.00
0005434550479	27721	Economy	3000.00
0005434550418	27721	Economy	3000.00
0005434550628	27721	Economy	3000.00
0005434550523	27721	Economy	3000.00
0005434558151	27721	Economy	3000.00
0005434558152	27721	Economy	3000.00
0005434550642	27721	Economy	3000.00
0005434550553	27721	Economy	3000.00
0005434550345	27721	Economy	3000.00
0005434550382	27721	Economy	3000.00
0005434550428	27721	Economy	3000.00
0005434550282	27721	Economy	3000.00
0005434550416	27721	Economy	3000.00
0005434550702	27721	Economy	3000.00
0005434550262	27721	Economy	3000.00
0005434550503	27721	Economy	3000.00
0005434550336	27721	Economy	3000.00
0005434550459	27721	Economy	3000.00
0005434550400	27721	Economy	3000.00
0005434550529	27721	Economy	3000.00
0005434550525	27721	Economy	3000.00
0005434558145	27721	Economy	3000.00
0005434554028	27721	Economy	3000.00
0005434550342	27721	Economy	3000.00
0005434550434	27721	Economy	3000.00
0005434550435	27721	Economy	3000.00
0005434550448	27721	Economy	3000.00
0005434550623	27721	Economy	3000.00
0005434558148	27721	Economy	3000.00
0005434550645	27721	Economy	3000.00
0005434550572	27721	Economy	3000.00
0005434550344	27721	Economy	3000.00
0005434550277	27721	Economy	3000.00
0005435254431	6169	Economy	11700.00
0005435254432	6169	Economy	11700.00
0005433459192	6169	Economy	11700.00
0005433459194	6169	Economy	11700.00
0005435254441	6169	Economy	11700.00
0005433459193	6169	Economy	11700.00
0005435254459	19293	Economy	11700.00
0005433459158	19293	Economy	11700.00
0005435254460	19293	Economy	11700.00
0005433459157	19293	Economy	11700.00
0005435254461	19293	Economy	11700.00
0005433459150	19293	Economy	11700.00
0005433459151	19293	Economy	11700.00
0005433459152	19293	Economy	11700.00
0005433459168	19293	Economy	11700.00
0005435719564	6727	Business	51100.00
0005435630944	6727	Business	51100.00
0005435681859	6727	Business	51100.00
0005435681887	6727	Business	51100.00
0005435681879	6727	Business	51100.00
0005435720129	6727	Business	51100.00
0005435681872	6727	Business	51100.00
0005435681857	6727	Business	51100.00
0005435681873	6727	Business	51100.00
0005435681864	6727	Economy	17000.00
0005435681889	6727	Economy	17000.00
0005435630946	6727	Economy	17000.00
0005432533250	6727	Economy	17000.00
0005435681848	6727	Economy	17000.00
0005435217684	6727	Economy	17000.00
0005435681883	6727	Economy	17000.00
0005435681871	6727	Economy	17000.00
0005435681866	6727	Economy	17000.00
0005435681862	6727	Economy	18700.00
0005435661912	6727	Economy	18700.00
0005435437591	6727	Economy	18700.00
0005435437675	6727	Economy	18700.00
0005435437694	6727	Economy	18700.00
0005435681878	6727	Economy	17000.00
0005435437695	6727	Economy	17000.00
0005435681850	6727	Economy	17000.00
0005435661910	6727	Economy	17000.00
0005432136136	6727	Economy	17000.00
0005432136137	6727	Economy	17000.00
0005435681865	6727	Economy	17000.00
0005435661911	6727	Economy	17000.00
0005435437711	6727	Economy	17000.00
0005435681877	6727	Economy	17000.00
0005434828653	6727	Economy	17000.00
0005435630945	6727	Economy	17000.00
0005435681863	6727	Economy	17000.00
0005434828652	6727	Economy	17000.00
0005435681855	6727	Economy	17000.00
0005435681888	6727	Economy	17000.00
0005435681874	6727	Economy	17000.00
0005435437593	6727	Economy	17000.00
0005435437592	6727	Economy	17000.00
0005435681851	6727	Economy	17000.00
0005435681853	6727	Economy	17000.00
0005435681880	6727	Economy	17000.00
0005435437587	6727	Economy	17000.00
0005435681867	6727	Economy	17000.00
0005435221497	6727	Economy	17000.00
0005435437575	6727	Economy	17000.00
0005435437645	6727	Economy	17000.00
0005432533254	6727	Economy	17000.00
0005435681854	6727	Economy	17000.00
0005435437644	6727	Economy	17000.00
0005432136139	6727	Economy	17000.00
0005435681870	6727	Economy	17000.00
0005435681884	6727	Economy	17000.00
0005435719563	6727	Economy	17000.00
0005435681881	6727	Economy	17000.00
0005435681860	6727	Economy	17000.00
0005435681882	6727	Economy	17000.00
0005435681849	6727	Economy	17000.00
0005435630947	6727	Economy	17000.00
0005435221506	6727	Economy	17000.00
0005435681868	6727	Economy	17000.00
0005435681890	6727	Economy	17000.00
0005435681852	6727	Economy	17000.00
0005435681886	6727	Economy	17000.00
0005435437718	6727	Economy	17000.00
0005432136138	6727	Economy	17000.00
0005435681869	6727	Economy	17000.00
0005435437635	6727	Economy	17000.00
0005435217683	6727	Economy	17000.00
0005435681861	6727	Economy	17000.00
0005435437606	6727	Economy	17000.00
0005435220284	6727	Economy	17000.00
0005435681856	6727	Economy	17000.00
0005435681875	6727	Economy	17000.00
0005435437669	6727	Economy	17000.00
0005435681885	6727	Economy	17000.00
0005435437586	6727	Economy	17000.00
0005435681858	6727	Economy	17000.00
0005435681876	6727	Economy	17000.00
0005435437604	6727	Economy	17000.00
0005435437806	24569	Business	51100.00
0005435681480	24569	Business	51100.00
0005435437818	24569	Business	51100.00
0005435681548	24569	Business	51100.00
0005432533273	24569	Business	51100.00
0005435681467	24569	Business	51100.00
0005435720809	24569	Business	51100.00
0005435681526	24569	Business	51100.00
0005435681385	24569	Economy	17000.00
0005435437807	24569	Economy	17000.00
0005435681582	24569	Economy	17000.00
0005435681437	24569	Economy	17000.00
0005435681539	24569	Economy	17000.00
0005435681701	24569	Economy	17000.00
0005435437822	24569	Economy	17000.00
0005435661884	24569	Economy	17000.00
0005435681575	24569	Economy	18700.00
0005432305732	24569	Economy	18700.00
0005435681702	24569	Economy	18700.00
0005435681592	24569	Economy	18700.00
0005435681479	24569	Economy	17000.00
0005435681536	24569	Economy	17000.00
0005435437823	24569	Economy	17000.00
0005435661895	24569	Economy	17000.00
0005435437819	24569	Economy	17000.00
0005432533274	24569	Economy	17000.00
0005432305734	24569	Economy	17000.00
0005435720810	24569	Economy	17000.00
0005435681555	24569	Economy	17000.00
0005435681535	24569	Economy	17000.00
0005435437812	24569	Economy	17000.00
0005435437803	24569	Economy	17000.00
0005434828680	24569	Economy	17000.00
0005435681492	24569	Economy	17000.00
0005435437809	24569	Economy	17000.00
0005435437808	24569	Economy	17000.00
0005435681624	24569	Economy	17000.00
0005435681473	24569	Economy	17000.00
0005435720804	24569	Economy	17000.00
0005435681474	24569	Economy	17000.00
0005435437820	24569	Economy	17000.00
0005435681577	24569	Economy	17000.00
0005435661894	24569	Economy	17000.00
0005435437801	24569	Economy	17000.00
0005435437804	24569	Economy	17000.00
0005435681601	24569	Economy	17000.00
0005435681537	24569	Economy	17000.00
0005435437802	24569	Economy	17000.00
0005435720807	24569	Economy	17000.00
0005435681573	24569	Economy	17000.00
0005435720802	24569	Economy	17000.00
0005432533272	24569	Economy	17000.00
0005434828681	24569	Economy	17000.00
0005435437814	24569	Economy	17000.00
0005435437821	24569	Economy	17000.00
0005435681527	24569	Economy	17000.00
0005432305733	24569	Economy	17000.00
0005435437815	24569	Economy	17000.00
0005435437811	24569	Economy	17000.00
0005435681545	24569	Economy	17000.00
0005435720803	24569	Economy	17000.00
0005435437817	24569	Economy	17000.00
0005435437816	24569	Economy	17000.00
0005435437813	24569	Economy	17000.00
0005435681563	24569	Economy	17000.00
0005435681436	24569	Economy	17000.00
0005435437810	24569	Economy	17000.00
0005435681588	24569	Economy	17000.00
0005434828679	24569	Economy	17000.00
0005435437805	24569	Economy	17000.00
0005435681574	24569	Economy	17000.00
0005435681583	24569	Economy	17000.00
0005435719552	24569	Economy	17000.00
0005435126088	11514	Business	26400.00
0005435126098	11514	Business	26400.00
0005435126093	11514	Business	26400.00
0005435126078	11514	Business	26400.00
0005435098542	11514	Business	26400.00
0005435126072	11514	Business	26400.00
0005435558042	11514	Business	26400.00
0005435098543	11514	Economy	8800.00
0005435126077	11514	Economy	8800.00
0005435126101	11514	Economy	8800.00
0005435126069	11514	Economy	8800.00
0005435098538	11514	Economy	9700.00
0005435126090	11514	Economy	8800.00
0005435098540	11514	Economy	8800.00
0005435126100	11514	Economy	8800.00
0005435126074	11514	Economy	8800.00
0005435126081	11514	Economy	8800.00
0005435105960	11514	Economy	8800.00
0005435126073	11514	Economy	8800.00
0005435098541	11514	Economy	8800.00
0005435126089	11514	Economy	8800.00
0005435126105	11514	Economy	8800.00
0005435126086	11514	Economy	8800.00
0005435126084	11514	Economy	8800.00
0005435126080	11514	Economy	8800.00
0005435126076	11514	Economy	8800.00
0005435126087	11514	Economy	8800.00
0005435126064	11514	Economy	8800.00
0005435126097	11514	Economy	8800.00
0005435098539	11514	Economy	8800.00
0005435126099	11514	Economy	8800.00
0005435126067	11514	Economy	8800.00
0005435126075	11514	Economy	8800.00
0005435126102	11514	Economy	8800.00
0005435126096	11514	Economy	8800.00
0005435126104	11514	Economy	8800.00
0005435126094	11514	Economy	8800.00
0005435126071	11514	Economy	8800.00
0005435126103	11514	Economy	8800.00
0005435126065	11514	Economy	8800.00
0005435126085	11514	Economy	8800.00
0005435105961	11514	Economy	8800.00
0005435126066	11514	Economy	8800.00
0005435126083	11514	Economy	8800.00
0005435126079	11514	Economy	8800.00
0005435126095	11514	Economy	8800.00
0005435126092	11514	Economy	8800.00
0005435126091	11514	Economy	8800.00
0005435105959	11514	Economy	8800.00
0005435126068	11514	Economy	8800.00
0005435126070	11514	Economy	8800.00
0005435126082	11514	Economy	8800.00
0005435125806	31897	Business	26400.00
0005435105931	31897	Business	26400.00
0005435125799	31897	Business	26400.00
0005435125652	31897	Business	26400.00
0005435125742	31897	Business	26400.00
0005435125793	31897	Business	26400.00
0005435125864	31897	Business	26400.00
0005435125741	31897	Economy	8800.00
0005435125816	31897	Economy	8800.00
0005435125663	31897	Economy	8800.00
0005435125704	31897	Economy	8800.00
0005435125795	31897	Economy	9700.00
0005435098528	31897	Economy	9700.00
0005435125834	31897	Economy	8800.00
0005435125710	31897	Economy	8800.00
0005435125841	31897	Economy	8800.00
0005435125805	31897	Economy	8800.00
0005435125910	31897	Economy	8800.00
0005435125764	31897	Economy	8800.00
0005435125897	31897	Economy	8800.00
0005435125911	31897	Economy	8800.00
0005435105930	31897	Economy	8800.00
0005435125794	31897	Economy	8800.00
0005435125804	31897	Economy	8800.00
0005435558070	31897	Economy	8800.00
0005435125895	31897	Economy	8800.00
0005435125937	31897	Economy	8800.00
0005435125844	31897	Economy	8800.00
0005435125869	31897	Economy	8800.00
0005435125824	31897	Economy	8800.00
0005435125667	31897	Economy	8800.00
0005435125760	31897	Economy	8800.00
0005435125796	31897	Economy	8800.00
0005435125761	31897	Economy	8800.00
0005435125913	31897	Economy	8800.00
0005435125654	31897	Economy	8800.00
0005435125653	31897	Economy	8800.00
0005435125863	31897	Economy	8800.00
0005435125751	31897	Economy	8800.00
0005435125912	31897	Economy	8800.00
0005435125752	31897	Economy	8800.00
0005435125896	31897	Economy	8800.00
0005435558069	31897	Economy	8800.00
0005435125891	31897	Economy	8800.00
0005435558071	31897	Economy	8800.00
0005435125728	31897	Economy	8800.00
0005435125894	31897	Economy	8800.00
0005435125770	31897	Economy	8800.00
0005433397729	13521	Business	36600.00
0005433397748	13521	Business	36600.00
0005433397751	13521	Business	36600.00
0005433397736	13521	Business	36600.00
0005433397768	13521	Business	36600.00
0005433397766	13521	Economy	12200.00
0005433397738	13521	Economy	12200.00
0005433397731	13521	Economy	12200.00
0005433397726	13521	Economy	12200.00
0005433397747	13521	Economy	13400.00
0005433397762	13521	Economy	13400.00
0005433397742	13521	Economy	13400.00
0005433397774	13521	Economy	13400.00
0005435732194	13521	Economy	12200.00
0005433397734	13521	Economy	12200.00
0005433397744	13521	Economy	12200.00
0005433397767	13521	Economy	12200.00
0005433397737	13521	Economy	12200.00
0005433397773	13521	Economy	12200.00
0005433397761	13521	Economy	12200.00
0005435732153	13521	Economy	12200.00
0005433397770	13521	Economy	12200.00
0005435732154	13521	Economy	12200.00
0005433397765	13521	Economy	12200.00
0005435732201	13521	Economy	12200.00
0005433397760	13521	Economy	12200.00
0005433397730	13521	Economy	12200.00
0005433397746	13521	Economy	12200.00
0005433397759	13521	Economy	12200.00
0005433397732	13521	Economy	12200.00
0005435732172	13521	Economy	12200.00
0005433397728	13521	Economy	12200.00
0005433397763	13521	Economy	12200.00
0005433397757	13521	Economy	12200.00
0005433397753	13521	Economy	12200.00
0005433397758	13521	Economy	12200.00
0005433397764	13521	Economy	12200.00
0005433397755	13521	Economy	12200.00
0005433397769	13521	Economy	12200.00
0005433397752	13521	Economy	12200.00
0005433397727	13521	Economy	12200.00
0005433397735	13521	Economy	12200.00
0005433397733	13521	Economy	12200.00
0005433397745	13521	Economy	12200.00
0005433397740	13521	Economy	12200.00
0005433397750	13521	Economy	12200.00
0005435732152	13521	Economy	12200.00
0005433397743	13521	Economy	12200.00
0005433397756	13521	Economy	12200.00
0005433397771	13521	Economy	12200.00
0005433397741	13521	Economy	12200.00
0005433397739	13521	Economy	12200.00
0005433397772	13521	Economy	12200.00
0005435732140	13521	Economy	12200.00
0005433397749	13521	Economy	12200.00
0005433397754	13521	Economy	12200.00
0005435732158	13521	Economy	12200.00
0005433397237	19370	Business	36600.00
0005433397303	19370	Business	36600.00
0005435732262	19370	Business	36600.00
0005433397210	19370	Business	36600.00
0005433397496	19370	Business	36600.00
0005433397287	19370	Business	36600.00
0005433397325	19370	Business	36600.00
0005435732258	19370	Business	36600.00
0005435732273	19370	Economy	12200.00
0005433397493	19370	Economy	12200.00
0005433397196	19370	Economy	12200.00
0005433397548	19370	Economy	12200.00
0005435732268	19370	Economy	12200.00
0005432297261	19370	Economy	12200.00
0005433397380	19370	Economy	12200.00
0005433397292	19370	Economy	13400.00
0005435732259	19370	Economy	13400.00
0005433397419	19370	Economy	13400.00
0005433397291	19370	Economy	13400.00
0005433397546	19370	Economy	12200.00
0005435732270	19370	Economy	12200.00
0005433397498	19370	Economy	12200.00
0005435732257	19370	Economy	12200.00
0005433397255	19370	Economy	12200.00
0005433397468	19370	Economy	12200.00
0005433397212	19370	Economy	12200.00
0005435732274	19370	Economy	12200.00
0005433397283	19370	Economy	12200.00
0005435732266	19370	Economy	12200.00
0005433397489	19370	Economy	12200.00
0005433397383	19370	Economy	12200.00
0005433397488	19370	Economy	12200.00
0005433397271	19370	Economy	12200.00
0005433397492	19370	Economy	12200.00
0005435732267	19370	Economy	12200.00
0005433397326	19370	Economy	12200.00
0005433397504	19370	Economy	12200.00
0005435732276	19370	Economy	12200.00
0005435732265	19370	Economy	12200.00
0005433397509	19370	Economy	12200.00
0005433397569	19370	Economy	12200.00
0005433397618	19370	Economy	12200.00
0005435732271	19370	Economy	12200.00
0005435732275	19370	Economy	12200.00
0005433397497	19370	Economy	12200.00
0005433397288	19370	Economy	12200.00
0005433397420	19370	Economy	12200.00
0005433397505	19370	Economy	12200.00
0005433397490	19370	Economy	12200.00
0005435732264	19370	Economy	12200.00
0005435732260	19370	Economy	12200.00
0005435732261	19370	Economy	12200.00
0005435732263	19370	Economy	12200.00
0005435732272	19370	Economy	12200.00
0005433397284	19370	Economy	12200.00
0005433397413	19370	Economy	12200.00
0005433397211	19370	Economy	12200.00
0005433397272	19370	Economy	12200.00
0005433397568	19370	Economy	12200.00
0005433397466	19370	Economy	12200.00
0005435732269	19370	Economy	12200.00
0005433397465	19370	Economy	12200.00
0005433397355	19370	Economy	12200.00
0005435068520	13165	Business	11300.00
0005435068315	13165	Business	11300.00
0005435068426	13165	Business	11300.00
0005435925202	13165	Business	11300.00
0005435068331	13165	Business	11300.00
0005435925196	13165	Business	11300.00
0005435925195	13165	Business	11300.00
0005435925192	13165	Business	11300.00
0005435068314	13165	Business	11300.00
0005435068385	13165	Business	11300.00
0005435068470	13165	Economy	3800.00
0005435068290	13165	Economy	3800.00
0005435925199	13165	Economy	3800.00
0005435068365	13165	Economy	3800.00
0005435068302	13165	Economy	4100.00
0005435925201	13165	Economy	4100.00
0005435068425	13165	Economy	3800.00
0005435068291	13165	Economy	3800.00
0005435068222	13165	Economy	3800.00
0005435068329	13165	Economy	3800.00
0005435068171	13165	Economy	3800.00
0005435068363	13165	Economy	3800.00
0005435925197	13165	Economy	3800.00
0005435068323	13165	Economy	3800.00
0005435068357	13165	Economy	3800.00
0005435925198	13165	Economy	3800.00
0005435068527	13165	Economy	3800.00
0005435068403	13165	Economy	3800.00
0005435068289	13165	Economy	3800.00
0005435068364	13165	Economy	3800.00
0005435068170	13165	Economy	3800.00
0005435068301	13165	Economy	3800.00
0005435925193	13165	Economy	3800.00
0005435068224	13165	Economy	3800.00
0005435068360	13165	Economy	3800.00
0005435925203	13165	Economy	3800.00
0005435068519	13165	Economy	3800.00
0005435068207	13165	Economy	3800.00
0005435068237	13165	Economy	3800.00
0005435068336	13165	Economy	3800.00
0005435068200	13165	Economy	3800.00
0005435068223	13165	Economy	3800.00
0005435068277	13165	Economy	3800.00
0005435068167	13165	Economy	3800.00
0005435068394	13165	Economy	3800.00
0005435068166	13165	Economy	3800.00
0005435925200	13165	Economy	3800.00
0005435068281	13165	Economy	3800.00
0005435068215	13165	Economy	3800.00
0005435068402	13165	Economy	3800.00
0005435068358	13165	Economy	3800.00
0005435068276	13165	Economy	3800.00
0005435068255	13165	Economy	3800.00
0005435068528	13165	Economy	3800.00
0005435925194	13165	Economy	3800.00
0005435068710	15462	Business	11300.00
0005435068735	15462	Business	11300.00
0005435925070	15462	Business	11300.00
0005435068689	15462	Business	11300.00
0005435068713	15462	Business	11300.00
0005435925077	15462	Business	11300.00
0005435068695	15462	Business	11300.00
0005435068709	15462	Business	11300.00
0005435068739	15462	Business	11300.00
0005435068730	15462	Economy	3800.00
0005435068728	15462	Economy	3800.00
0005435068708	15462	Economy	3800.00
0005435925093	15462	Economy	3800.00
0005435925091	15462	Economy	3800.00
0005435068700	15462	Economy	3800.00
0005435068696	15462	Economy	3800.00
0005435068721	15462	Economy	3800.00
0005435068720	15462	Economy	4100.00
0005435068729	15462	Economy	4100.00
0005435068734	15462	Economy	4100.00
0005435068704	15462	Economy	3800.00
0005435068694	15462	Economy	3800.00
0005435068737	15462	Economy	3800.00
0005435925088	15462	Economy	3800.00
0005435068711	15462	Economy	3800.00
0005435068716	15462	Economy	3800.00
0005435925089	15462	Economy	3800.00
0005435068693	15462	Economy	3800.00
0005435925076	15462	Economy	3800.00
0005435068699	15462	Economy	3800.00
0005435068723	15462	Economy	3800.00
0005435068736	15462	Economy	3800.00
0005435068692	15462	Economy	3800.00
0005435068690	15462	Economy	3800.00
0005435068740	15462	Economy	3800.00
0005435068707	15462	Economy	3800.00
0005435068691	15462	Economy	3800.00
0005435068703	15462	Economy	3800.00
0005435068712	15462	Economy	3800.00
0005435068738	15462	Economy	3800.00
0005435925090	15462	Economy	3800.00
0005435068725	15462	Economy	3800.00
0005435068722	15462	Economy	3800.00
0005435068714	15462	Economy	3800.00
0005435068724	15462	Economy	3800.00
0005435068701	15462	Economy	3800.00
0005435068688	15462	Economy	3800.00
0005435068698	15462	Economy	3800.00
0005435068726	15462	Economy	3800.00
0005435068719	15462	Economy	3800.00
0005435068706	15462	Economy	3800.00
0005435068702	15462	Economy	3800.00
0005435068718	15462	Economy	3800.00
0005435068732	15462	Economy	3800.00
0005435068733	15462	Economy	3800.00
0005435068715	15462	Economy	3800.00
0005435068697	15462	Economy	3800.00
0005435068727	15462	Economy	3800.00
0005435068717	15462	Economy	3800.00
0005435068705	15462	Economy	3800.00
0005435925074	15462	Economy	3800.00
0005435068731	15462	Economy	3800.00
0005433407530	29494	Economy	27100.00
0005433407534	29494	Economy	27100.00
0005435808057	29494	Economy	24700.00
0005435808072	29494	Economy	24700.00
0005435808071	29494	Economy	24700.00
0005433407537	29494	Economy	24700.00
0005435808053	29494	Economy	24700.00
0005433407531	29494	Economy	24700.00
0005433407536	29494	Economy	24700.00
0005433407532	29494	Economy	24700.00
0005433407535	29494	Economy	24700.00
0005435808056	29494	Economy	24700.00
0005435808063	29494	Economy	24700.00
0005433407538	29494	Economy	24700.00
0005433407533	29494	Economy	24700.00
0005435808115	29494	Economy	24700.00
0005434214249	10684	Business	61300.00
0005434755870	10684	Business	61300.00
0005434755873	10684	Business	61300.00
0005434755800	10684	Business	61300.00
0005434214245	10684	Business	61300.00
0005434214235	10684	Business	61300.00
0005434214242	10684	Business	61300.00
0005434755874	10684	Business	61300.00
0005434214256	10684	Economy	20400.00
0005434214233	10684	Economy	20400.00
0005434214265	10684	Economy	20400.00
0005434214228	10684	Economy	20400.00
0005434755797	10684	Economy	20400.00
0005434214240	10684	Economy	20400.00
0005434755755	10684	Economy	20400.00
0005434214268	10684	Economy	20400.00
0005434214231	10684	Economy	20400.00
0005434755808	10684	Economy	22500.00
0005434214250	10684	Economy	22500.00
0005434214252	10684	Economy	22500.00
0005434755729	10684	Economy	22500.00
0005434214267	10684	Economy	20400.00
0005434755869	10684	Economy	20400.00
0005434214237	10684	Economy	20400.00
0005434214222	10684	Economy	20400.00
0005434755844	10684	Economy	20400.00
0005434755724	10684	Economy	20400.00
0005434214263	10684	Economy	20400.00
0005434214264	10684	Economy	20400.00
0005434214224	10684	Economy	20400.00
0005434755733	10684	Economy	20400.00
0005434214230	10684	Economy	20400.00
0005434755839	10684	Economy	20400.00
0005434214232	10684	Economy	20400.00
0005434755816	10684	Economy	20400.00
0005434755743	10684	Economy	20400.00
0005434214229	10684	Economy	20400.00
0005434214241	10684	Economy	20400.00
0005434755866	10684	Economy	20400.00
0005434214255	10684	Economy	20400.00
0005434755843	10684	Economy	20400.00
0005434214257	10684	Economy	20400.00
0005434755736	10684	Economy	20400.00
0005434755773	10684	Economy	20400.00
0005434214227	10684	Economy	20400.00
0005434214221	10684	Economy	20400.00
0005434214251	10684	Economy	20400.00
0005434755722	10684	Economy	20400.00
0005434214253	10684	Economy	20400.00
0005434214247	10684	Economy	20400.00
0005434214258	10684	Economy	20400.00
0005434214236	10684	Economy	20400.00
0005434755818	10684	Economy	20400.00
0005434755790	10684	Economy	20400.00
0005434214225	10684	Economy	20400.00
0005434214254	10684	Economy	20400.00
0005434214246	10684	Economy	20400.00
0005434755730	10684	Economy	20400.00
0005434214226	10684	Economy	20400.00
0005434214262	10684	Economy	20400.00
0005434214243	10684	Economy	20400.00
0005434755876	10684	Economy	20400.00
0005434214223	10684	Economy	20400.00
0005434755903	10684	Economy	20400.00
0005434214244	10684	Economy	20400.00
0005434214259	10684	Economy	20400.00
0005434755838	10684	Economy	20400.00
0005434214238	10684	Economy	20400.00
0005434214266	10684	Economy	20400.00
0005434214234	10684	Economy	20400.00
0005434214261	10684	Economy	20400.00
0005434755875	10684	Economy	20400.00
0005434755815	10684	Economy	20400.00
0005434214239	10684	Economy	20400.00
0005434214248	10684	Economy	20400.00
0005434755782	10684	Economy	20400.00
0005434214260	10684	Economy	20400.00
0005434213787	28664	Business	61300.00
0005434756156	28664	Business	61300.00
0005434213713	28664	Business	61300.00
0005434756128	28664	Business	61300.00
0005434756133	28664	Business	61300.00
0005434756163	28664	Business	61300.00
0005434756138	28664	Business	61300.00
0005434213808	28664	Business	61300.00
0005434213788	28664	Business	61300.00
0005434213898	28664	Economy	20400.00
0005434213843	28664	Economy	20400.00
0005434213865	28664	Economy	20400.00
0005434213822	28664	Economy	20400.00
0005434213723	28664	Economy	20400.00
0005434756131	28664	Economy	20400.00
0005434213710	28664	Economy	20400.00
0005434213764	28664	Economy	22500.00
0005434213844	28664	Economy	22500.00
0005434213722	28664	Economy	22500.00
0005434756144	28664	Economy	20400.00
0005434756158	28664	Economy	20400.00
0005434756135	28664	Economy	20400.00
0005434756149	28664	Economy	20400.00
0005434213737	28664	Economy	20400.00
0005434756167	28664	Economy	20400.00
0005434756125	28664	Economy	20400.00
0005434213711	28664	Economy	20400.00
0005434213724	28664	Economy	20400.00
0005434213763	28664	Economy	20400.00
0005434756151	28664	Economy	20400.00
0005434756153	28664	Economy	20400.00
0005434756119	28664	Economy	20400.00
0005434756122	28664	Economy	20400.00
0005434213703	28664	Economy	20400.00
0005434756143	28664	Economy	20400.00
0005434213789	28664	Economy	20400.00
0005434756148	28664	Economy	20400.00
0005434756130	28664	Economy	20400.00
0005434756142	28664	Economy	20400.00
0005434756136	28664	Economy	20400.00
0005434756140	28664	Economy	20400.00
0005434213730	28664	Economy	20400.00
0005434756139	28664	Economy	20400.00
0005434756137	28664	Economy	20400.00
0005434213709	28664	Economy	20400.00
0005434756162	28664	Economy	20400.00
0005434756152	28664	Economy	20400.00
0005434756166	28664	Economy	20400.00
0005434756124	28664	Economy	20400.00
0005434756129	28664	Economy	20400.00
0005434756146	28664	Economy	20400.00
0005434213866	28664	Economy	20400.00
0005434756157	28664	Economy	20400.00
0005434756126	28664	Economy	20400.00
0005434756154	28664	Economy	20400.00
0005434756121	28664	Economy	20400.00
0005434213704	28664	Economy	20400.00
0005434213708	28664	Economy	20400.00
0005434756147	28664	Economy	20400.00
0005434756145	28664	Economy	20400.00
0005434756165	28664	Economy	20400.00
0005434213727	28664	Economy	20400.00
0005434756120	28664	Economy	20400.00
0005434756160	28664	Economy	20400.00
0005434756150	28664	Economy	20400.00
0005434213702	28664	Economy	20400.00
0005434756161	28664	Economy	20400.00
0005434756132	28664	Economy	20400.00
0005434756155	28664	Economy	20400.00
0005434756134	28664	Economy	20400.00
0005434756141	28664	Economy	20400.00
0005434756127	28664	Economy	20400.00
0005434213775	28664	Economy	20400.00
0005434756164	28664	Economy	20400.00
0005434213774	28664	Economy	20400.00
0005434756123	28664	Economy	20400.00
0005434756159	28664	Economy	20400.00
0005434213714	28664	Economy	20400.00
0005435039353	5469	Business	29500.00
0005435039342	5469	Business	29500.00
0005434229079	5469	Business	29500.00
0005435043279	5469	Business	29500.00
0005435039387	5469	Business	29500.00
0005434229090	5469	Business	29500.00
0005435039343	5469	Business	29500.00
0005435039364	5469	Business	29500.00
0005435006885	5469	Business	29500.00
0005434229080	5469	Business	29500.00
0005434229091	5469	Business	29500.00
0005434229119	5469	Economy	9800.00
0005435039394	5469	Economy	9800.00
0005435006875	5469	Economy	9800.00
0005435039391	5469	Economy	9800.00
0005435006876	5469	Economy	9800.00
0005435039389	5469	Economy	9800.00
0005435006878	5469	Economy	9800.00
0005435006887	5469	Economy	9800.00
0005435039345	5469	Economy	9800.00
0005435039332	5469	Economy	9800.00
0005435039384	5469	Economy	9800.00
0005435039396	5469	Economy	9800.00
0005435039392	5469	Economy	9800.00
0005435039361	5469	Economy	9800.00
0005435006877	5469	Economy	9800.00
0005435042842	5469	Economy	9800.00
0005435039393	5469	Economy	9800.00
0005434229032	5469	Economy	9800.00
0005435039333	5469	Economy	9800.00
0005435039348	5469	Economy	9800.00
0005435039366	5469	Economy	9800.00
0005435043278	5469	Economy	9800.00
0005434229030	5469	Economy	9800.00
0005435039337	5469	Economy	9800.00
0005435039362	5469	Economy	9800.00
0005435039360	5469	Economy	9800.00
0005435039331	5469	Economy	9800.00
0005435039358	5469	Economy	9800.00
0005435006872	5469	Economy	9800.00
0005434229031	5469	Economy	9800.00
0005435039350	5469	Economy	9800.00
0005435006868	5469	Economy	9800.00
0005435039339	5469	Economy	9800.00
0005435039354	5469	Economy	9800.00
0005435006870	5469	Economy	9800.00
0005434229052	5469	Economy	9800.00
0005435039376	5469	Economy	9800.00
0005435039386	5469	Economy	9800.00
0005435006869	5469	Economy	10800.00
0005434229033	5469	Economy	10800.00
0005435006882	5469	Economy	10800.00
0005435006892	5469	Economy	10800.00
0005435006871	5469	Economy	10800.00
0005435039371	5469	Economy	10800.00
0005435039330	5469	Economy	9800.00
0005435006874	5469	Economy	9800.00
0005435039395	5469	Economy	9800.00
0005435039338	5469	Economy	9800.00
0005435039374	5469	Economy	9800.00
0005435042841	5469	Economy	9800.00
0005435006891	5469	Economy	9800.00
0005435039351	5469	Economy	9800.00
0005435039372	5469	Economy	9800.00
0005432125408	5469	Economy	9800.00
0005432125407	5469	Economy	9800.00
0005435043280	5469	Economy	9800.00
0005435039335	5469	Economy	9800.00
0005434229014	5469	Economy	9800.00
0005435006884	5469	Economy	9800.00
0005434229024	5469	Economy	9800.00
0005435039388	5469	Economy	9800.00
0005435006879	5469	Economy	9800.00
0005435039385	5469	Economy	9800.00
0005434229022	5469	Economy	9800.00
0005435039370	5469	Economy	9800.00
0005435006890	5469	Economy	9800.00
0005435042840	5469	Economy	9800.00
0005432125404	5469	Economy	9800.00
0005435039334	5469	Economy	9800.00
0005435006888	5469	Economy	9800.00
0005435006886	5469	Economy	9800.00
0005435039369	5469	Economy	9800.00
0005435006880	5469	Economy	9800.00
0005435039377	5469	Economy	9800.00
0005435039383	5469	Economy	9800.00
0005435039357	5469	Economy	9800.00
0005435039344	5469	Economy	9800.00
0005435006881	5469	Economy	9800.00
0005435039340	5469	Economy	9800.00
0005435039378	5469	Economy	9800.00
0005435039352	5469	Economy	9800.00
0005435006883	5469	Economy	9800.00
0005435042839	5469	Economy	9800.00
0005435039359	5469	Economy	9800.00
0005435039379	5469	Economy	9800.00
0005434228999	5469	Economy	9800.00
0005435006889	5469	Economy	9800.00
0005432125405	5469	Economy	9800.00
0005434229141	5469	Economy	9800.00
0005435039365	5469	Economy	9800.00
0005435039382	5469	Economy	9800.00
0005435039356	5469	Economy	9800.00
0005435006873	5469	Economy	9800.00
0005434229093	5469	Economy	9800.00
0005435039341	5469	Economy	9800.00
0005434229075	5469	Economy	9800.00
0005434229120	5469	Economy	9800.00
0005435039336	5469	Economy	9800.00
0005434229015	5469	Economy	9800.00
0005435039373	5469	Economy	9800.00
0005435039347	5469	Economy	9800.00
0005435039368	5469	Economy	9800.00
0005435039363	5469	Economy	9800.00
0005435039349	5469	Economy	9800.00
0005435039390	5469	Economy	9800.00
0005435039381	5469	Economy	9800.00
0005435039367	5469	Economy	9800.00
0005435039375	5469	Economy	9800.00
0005435042843	5469	Economy	9800.00
0005432125406	5469	Economy	9800.00
0005435039346	5469	Economy	9800.00
0005435039380	5469	Economy	9800.00
0005435039355	5469	Economy	9800.00
0005435006651	12962	Business	29500.00
0005435038997	12962	Business	29500.00
0005435006645	12962	Business	29500.00
0005435038930	12962	Business	29500.00
0005435039054	12962	Business	29500.00
0005435038854	12962	Business	29500.00
0005435043273	12962	Business	29500.00
0005434229231	12962	Business	29500.00
0005435038832	12962	Business	29500.00
0005435039053	12962	Business	29500.00
0005432304374	12962	Economy	9800.00
0005435006764	12962	Economy	9800.00
0005435038627	12962	Economy	9800.00
0005435006646	12962	Economy	9800.00
0005435038641	12962	Economy	9800.00
0005435038833	12962	Economy	9800.00
0005435038931	12962	Economy	9800.00
0005432304375	12962	Economy	9800.00
0005435038673	12962	Economy	9800.00
0005435038868	12962	Economy	9800.00
0005435039033	12962	Economy	9800.00
0005435038831	12962	Economy	9800.00
0005435038783	12962	Economy	9800.00
0005434229229	12962	Economy	9800.00
0005435006650	12962	Economy	9800.00
0005434229237	12962	Economy	9800.00
0005434229220	12962	Economy	9800.00
0005435006666	12962	Economy	9800.00
0005435039115	12962	Economy	9800.00
0005435038864	12962	Economy	9800.00
0005435038863	12962	Economy	9800.00
0005434229227	12962	Economy	9800.00
0005434229242	12962	Economy	9800.00
0005434229230	12962	Economy	9800.00
0005435038933	12962	Economy	9800.00
0005434229225	12962	Economy	9800.00
0005435038615	12962	Economy	9800.00
0005434229235	12962	Economy	9800.00
0005435006724	12962	Economy	9800.00
0005434229239	12962	Economy	9800.00
0005435038867	12962	Economy	9800.00
0005435038661	12962	Economy	9800.00
0005432304373	12962	Economy	9800.00
0005435038823	12962	Economy	10800.00
0005435038645	12962	Economy	10800.00
0005434229223	12962	Economy	10800.00
0005435038723	12962	Economy	10800.00
0005435043274	12962	Economy	10800.00
0005435006672	12962	Economy	9800.00
0005434229221	12962	Economy	9800.00
0005435006664	12962	Economy	9800.00
0005434229228	12962	Economy	9800.00
0005434229238	12962	Economy	9800.00
0005435038825	12962	Economy	9800.00
0005435039042	12962	Economy	9800.00
0005434229224	12962	Economy	9800.00
0005435038689	12962	Economy	9800.00
0005435038818	12962	Economy	9800.00
0005435038799	12962	Economy	9800.00
0005435038897	12962	Economy	9800.00
0005434229226	12962	Economy	9800.00
0005435038936	12962	Economy	9800.00
0005435038998	12962	Economy	9800.00
0005435038782	12962	Economy	9800.00
0005435038686	12962	Economy	9800.00
0005434229232	12962	Economy	9800.00
0005435038987	12962	Economy	9800.00
0005435006701	12962	Economy	9800.00
0005434229222	12962	Economy	9800.00
0005435038920	12962	Economy	9800.00
0005435038923	12962	Economy	9800.00
0005435006675	12962	Economy	9800.00
0005434229240	12962	Economy	9800.00
0005435038824	12962	Economy	9800.00
0005435038724	12962	Economy	9800.00
0005434229236	12962	Economy	9800.00
0005435006702	12962	Economy	9800.00
0005435006649	12962	Economy	9800.00
0005434229233	12962	Economy	9800.00
0005435038770	12962	Economy	9800.00
0005435038743	12962	Economy	9800.00
0005435038828	12962	Economy	9800.00
0005435006685	12962	Economy	9800.00
0005435038742	12962	Economy	9800.00
0005435038944	12962	Economy	9800.00
0005435038822	12962	Economy	9800.00
0005435038910	12962	Economy	9800.00
0005435038819	12962	Economy	9800.00
0005435038646	12962	Economy	9800.00
0005435038820	12962	Economy	9800.00
0005435039114	12962	Economy	9800.00
0005435038836	12962	Economy	9800.00
0005435038674	12962	Economy	9800.00
0005435038614	12962	Economy	9800.00
0005434229241	12962	Economy	9800.00
0005435038760	12962	Economy	9800.00
0005434229234	12962	Economy	9800.00
0005435038919	12962	Economy	9800.00
0005435006754	12962	Economy	9800.00
0005432304372	12962	Economy	9800.00
0005434411746	14895	Business	52900.00
0005434426394	14895	Business	52900.00
0005434426391	14895	Business	52900.00
0005434426396	14895	Business	52900.00
0005434426410	14895	Business	52900.00
0005434426402	14895	Business	52900.00
0005434426392	14895	Business	52900.00
0005435902392	14895	Economy	17600.00
0005434426408	14895	Economy	17600.00
0005432188584	14895	Economy	17600.00
0005434426395	14895	Economy	19400.00
0005434411748	14895	Economy	17600.00
0005434426388	14895	Economy	17600.00
0005434426399	14895	Economy	17600.00
0005434426405	14895	Economy	17600.00
0005435902448	14895	Economy	17600.00
0005435902423	14895	Economy	17600.00
0005435902435	14895	Economy	17600.00
0005435902416	14895	Economy	17600.00
0005435902384	14895	Economy	17600.00
0005435902437	14895	Economy	17600.00
0005434426400	14895	Economy	17600.00
0005434426398	14895	Economy	17600.00
0005435902427	14895	Economy	17600.00
0005435902428	14895	Economy	17600.00
0005432188583	14895	Economy	17600.00
0005435902385	14895	Economy	17600.00
0005434426414	14895	Economy	17600.00
0005435902397	14895	Economy	17600.00
0005434411745	14895	Economy	17600.00
0005435902445	14895	Economy	17600.00
0005434426386	14895	Economy	17600.00
0005434426390	14895	Economy	17600.00
0005434426397	14895	Economy	17600.00
0005434426401	14895	Economy	17600.00
0005434426387	14895	Economy	17600.00
0005434426393	14895	Economy	17600.00
0005434426411	14895	Economy	17600.00
0005434426412	14895	Economy	17600.00
0005435902452	14895	Economy	17600.00
0005434426406	14895	Economy	17600.00
0005435902451	14895	Economy	17600.00
0005434426413	14895	Economy	17600.00
0005434426407	14895	Economy	17600.00
0005435902391	14895	Economy	17600.00
0005434411747	14895	Economy	17600.00
0005434426404	14895	Economy	17600.00
0005435902395	14895	Economy	17600.00
0005434426389	14895	Economy	17600.00
0005434411749	14895	Economy	17600.00
0005435902436	14895	Economy	17600.00
0005432188585	14895	Economy	17600.00
0005434426409	14895	Economy	17600.00
0005434426415	14895	Economy	17600.00
0005435902409	14895	Economy	17600.00
0005434426403	14895	Economy	17600.00
0005435902488	14895	Economy	17600.00
0005434426134	20232	Business	52900.00
0005432059493	20232	Business	52900.00
0005434426165	20232	Business	52900.00
0005435902589	20232	Business	52900.00
0005434426198	20232	Business	52900.00
0005434426135	20232	Business	52900.00
0005434426143	20232	Business	52900.00
0005435554161	20232	Business	52900.00
0005432059492	20232	Economy	17600.00
0005435902593	20232	Economy	17600.00
0005434426239	20232	Economy	17600.00
0005435554162	20232	Economy	17600.00
0005432059491	20232	Economy	19400.00
0005435902602	20232	Economy	19400.00
0005434426220	20232	Economy	19400.00
0005435554159	20232	Economy	19400.00
0005434411718	20232	Economy	17600.00
0005434426155	20232	Economy	17600.00
0005434426224	20232	Economy	17600.00
0005435902598	20232	Economy	17600.00
0005434426136	20232	Economy	17600.00
0005434426126	20232	Economy	17600.00
0005435902599	20232	Economy	17600.00
0005434426144	20232	Economy	17600.00
0005434426177	20232	Economy	17600.00
0005435902588	20232	Economy	17600.00
0005435554163	20232	Economy	17600.00
0005435902596	20232	Economy	17600.00
0005434411714	20232	Economy	17600.00
0005434426093	20232	Economy	17600.00
0005435902594	20232	Economy	17600.00
0005435902592	20232	Economy	17600.00
0005434411722	20232	Economy	17600.00
0005435902585	20232	Economy	17600.00
0005435902590	20232	Economy	17600.00
0005434411713	20232	Economy	17600.00
0005434426227	20232	Economy	17600.00
0005434426088	20232	Economy	17600.00
0005435902584	20232	Economy	17600.00
0005434411703	20232	Economy	17600.00
0005435902600	20232	Economy	17600.00
0005434426138	20232	Economy	17600.00
0005435554160	20232	Economy	17600.00
0005435554158	20232	Economy	17600.00
0005435902601	20232	Economy	17600.00
0005434426145	20232	Economy	17600.00
0005435902591	20232	Economy	17600.00
0005435902595	20232	Economy	17600.00
0005435902587	20232	Economy	17600.00
0005434411723	20232	Economy	17600.00
0005435902586	20232	Economy	17600.00
0005435902597	20232	Economy	17600.00
0005435981998	26497	Business	18500.00
0005433434362	26497	Business	18500.00
0005435981990	26497	Business	18500.00
0005434273055	26497	Business	18500.00
0005433434227	26497	Business	18500.00
0005432300221	26497	Business	18500.00
0005435981971	26497	Business	18500.00
0005435981994	26497	Business	18500.00
0005433434290	26497	Business	18500.00
0005435981967	26497	Business	18500.00
0005435981973	26497	Business	18500.00
0005435981966	26497	Economy	6200.00
0005435981980	26497	Economy	6200.00
0005435981992	26497	Economy	6200.00
0005435981976	26497	Economy	6200.00
0005433434254	26497	Economy	6200.00
0005435982005	26497	Economy	6200.00
0005435982009	26497	Economy	6200.00
0005433434239	26497	Economy	6800.00
0005435981986	26497	Economy	6800.00
0005435981962	26497	Economy	6800.00
0005435982012	26497	Economy	6800.00
0005433434229	26497	Economy	6800.00
0005434270178	26497	Economy	6200.00
0005435981977	26497	Economy	6200.00
0005435982008	26497	Economy	6200.00
0005433434361	26497	Economy	6200.00
0005435982006	26497	Economy	6200.00
0005435981988	26497	Economy	6200.00
0005435982001	26497	Economy	6200.00
0005435981983	26497	Economy	6200.00
0005433434200	26497	Economy	6200.00
0005435981963	26497	Economy	6200.00
0005435982007	26497	Economy	6200.00
0005433434188	26497	Economy	6200.00
0005435981982	26497	Economy	6200.00
0005433434294	26497	Economy	6200.00
0005435981964	26497	Economy	6200.00
0005435981997	26497	Economy	6200.00
0005433434228	26497	Economy	6200.00
0005433434189	26497	Economy	6200.00
0005435981985	26497	Economy	6200.00
0005432300223	26497	Economy	6200.00
0005433434226	26497	Economy	6200.00
0005435981978	26497	Economy	6200.00
0005435981984	26497	Economy	6200.00
0005432300224	26497	Economy	6200.00
0005435981981	26497	Economy	6200.00
0005435981991	26497	Economy	6200.00
0005435982013	26497	Economy	6200.00
0005435981969	26497	Economy	6200.00
0005433434348	26497	Economy	6200.00
0005435982010	26497	Economy	6200.00
0005435981999	26497	Economy	6200.00
0005435981979	26497	Economy	6200.00
0005435981987	26497	Economy	6200.00
0005435982004	26497	Economy	6200.00
0005435981989	26497	Economy	6200.00
0005435981968	26497	Economy	6200.00
0005435981993	26497	Economy	6200.00
0005435982002	26497	Economy	6200.00
0005433434240	26497	Economy	6200.00
0005434270179	26497	Economy	6200.00
0005435981972	26497	Economy	6200.00
0005434273056	26497	Economy	6200.00
0005433434201	26497	Economy	6200.00
0005433434379	26497	Economy	6200.00
0005432300222	26497	Economy	6200.00
0005435981965	26497	Economy	6200.00
0005435981975	26497	Economy	6200.00
0005433434253	26497	Economy	6200.00
0005433434295	26497	Economy	6200.00
0005435982011	26497	Economy	6200.00
0005435982000	26497	Economy	6200.00
0005434270171	26497	Economy	6200.00
0005435981970	26497	Economy	6200.00
0005435982003	26497	Economy	6200.00
0005435981995	26497	Economy	6200.00
0005435981996	26497	Economy	6200.00
0005435981974	26497	Economy	6200.00
0005432300225	26497	Economy	6200.00
0005433434524	26712	Business	18500.00
0005433434520	26712	Business	18500.00
0005435981532	26712	Business	18500.00
0005433434504	26712	Business	18500.00
0005432051109	26712	Business	18500.00
0005435981747	26712	Business	18500.00
0005435981537	26712	Business	18500.00
0005435981541	26712	Business	18500.00
0005433434519	26712	Business	18500.00
0005434270193	26712	Economy	6200.00
0005435981637	26712	Economy	6200.00
0005435981515	26712	Economy	6200.00
0005433434513	26712	Economy	6200.00
0005433434506	26712	Economy	6200.00
0005435981568	26712	Economy	6200.00
0005435981663	26712	Economy	6200.00
0005433434512	26712	Economy	6200.00
0005435981774	26712	Economy	6200.00
0005435981600	26712	Economy	6200.00
0005434269091	26712	Economy	6800.00
0005435981683	26712	Economy	6800.00
0005435981743	26712	Economy	6800.00
0005435981591	26712	Economy	6800.00
0005435981619	26712	Economy	6200.00
0005433434503	26712	Economy	6200.00
0005435981538	26712	Economy	6200.00
0005433434521	26712	Economy	6200.00
0005435981792	26712	Economy	6200.00
0005432051108	26712	Economy	6200.00
0005435981704	26712	Economy	6200.00
0005434271299	26712	Economy	6200.00
0005435981542	26712	Economy	6200.00
0005432051110	26712	Economy	6200.00
0005433434502	26712	Economy	6200.00
0005434271300	26712	Economy	6200.00
0005433434505	26712	Economy	6200.00
0005433434514	26712	Economy	6200.00
0005433434517	26712	Economy	6200.00
0005435981636	26712	Economy	6200.00
0005435981573	26712	Economy	6200.00
0005433434500	26712	Economy	6200.00
0005435981572	26712	Economy	6200.00
0005433434518	26712	Economy	6200.00
0005434270194	26712	Economy	6200.00
0005433434522	26712	Economy	6200.00
0005435981628	26712	Economy	6200.00
0005435981671	26712	Economy	6200.00
0005433434509	26712	Economy	6200.00
0005435981569	26712	Economy	6200.00
0005433434508	26712	Economy	6200.00
0005433434499	26712	Economy	6200.00
0005435981746	26712	Economy	6200.00
0005432051111	26712	Economy	6200.00
0005435981508	26712	Economy	6200.00
0005435981612	26712	Economy	6200.00
0005433434501	26712	Economy	6200.00
0005433434498	26712	Economy	6200.00
0005433434523	26712	Economy	6200.00
0005433434507	26712	Economy	6200.00
0005435981519	26712	Economy	6200.00
0005433434510	26712	Economy	6200.00
0005433434511	26712	Economy	6200.00
0005433434497	26712	Economy	6200.00
0005435981649	26712	Economy	6200.00
0005433434515	26712	Economy	6200.00
0005435981597	26712	Economy	6200.00
0005435981584	26712	Economy	6200.00
0005433434516	26712	Economy	6200.00
0005434269090	26712	Economy	6200.00
0005435981620	26712	Economy	6200.00
0005435981570	26712	Economy	6200.00
0005435981666	26712	Economy	6200.00
0005432857861	3134	Economy	11100.00
0005432857885	3134	Economy	11100.00
0005432583889	3134	Economy	11100.00
0005432857913	3134	Economy	10100.00
0005432583878	3134	Economy	10100.00
0005432583883	3134	Economy	10100.00
0005432583881	3134	Economy	10100.00
0005432583866	3134	Economy	10100.00
0005432857899	3134	Economy	10100.00
0005432583886	3134	Economy	10100.00
0005432583871	3134	Economy	10100.00
0005432857887	3134	Economy	10100.00
0005432583873	3134	Economy	10100.00
0005432583885	3134	Economy	10100.00
0005432857859	3134	Economy	10100.00
0005432857920	3134	Economy	10100.00
0005432583879	3134	Economy	10100.00
0005432857907	3134	Economy	10100.00
0005432583868	3134	Economy	10100.00
0005432583874	3134	Economy	10100.00
0005432216253	3134	Economy	10100.00
0005432583875	3134	Economy	10100.00
0005432857860	3134	Economy	10100.00
0005432857868	3134	Economy	10100.00
0005432583877	3134	Economy	10100.00
0005432583887	3134	Economy	10100.00
0005432583876	3134	Economy	10100.00
0005432857923	3134	Economy	10100.00
0005432583867	3134	Economy	10100.00
0005432857912	3134	Economy	10100.00
0005432857909	3134	Economy	10100.00
0005432583882	3134	Economy	10100.00
0005432583869	3134	Economy	10100.00
0005432583872	3134	Economy	10100.00
0005432857918	3134	Economy	10100.00
0005432216254	3134	Economy	10100.00
0005432857869	3134	Economy	10100.00
0005432583880	3134	Economy	10100.00
0005432583890	3134	Economy	10100.00
0005432583870	3134	Economy	10100.00
0005432857932	3134	Economy	10100.00
0005432583884	3134	Economy	10100.00
0005432857921	3134	Economy	10100.00
0005432583888	3134	Economy	10100.00
0005432216255	3134	Economy	10100.00
0005432857990	31473	Economy	11100.00
0005432583719	31473	Economy	11100.00
0005432857989	31473	Economy	11100.00
0005432857997	31473	Economy	11100.00
0005432583681	31473	Economy	10100.00
0005432583584	31473	Economy	10100.00
0005432583718	31473	Economy	10100.00
0005432583601	31473	Economy	10100.00
0005432857994	31473	Economy	10100.00
0005432583691	31473	Economy	10100.00
0005432583650	31473	Economy	10100.00
0005432583666	31473	Economy	10100.00
0005432583585	31473	Economy	10100.00
0005432857993	31473	Economy	10100.00
0005432583731	31473	Economy	10100.00
0005432857988	31473	Economy	10100.00
0005432583698	31473	Economy	10100.00
0005432583640	31473	Economy	10100.00
0005432583730	31473	Economy	10100.00
0005432583716	31473	Economy	10100.00
0005432857991	31473	Economy	10100.00
0005432583600	31473	Economy	10100.00
0005432583693	31473	Economy	10100.00
0005432857986	31473	Economy	10100.00
0005432857992	31473	Economy	10100.00
0005432583740	31473	Economy	10100.00
0005432583739	31473	Economy	10100.00
0005432857995	31473	Economy	10100.00
0005432583690	31473	Economy	10100.00
0005432583672	31473	Economy	10100.00
0005432583745	31473	Economy	10100.00
0005432857987	31473	Economy	10100.00
0005432583682	31473	Economy	10100.00
0005432583673	31473	Economy	10100.00
0005432857996	31473	Economy	10100.00
0005432583734	31473	Economy	10100.00
0005432583735	31473	Economy	10100.00
0005434943294	906	Economy	7500.00
0005433255034	906	Economy	7500.00
0005434943295	906	Economy	7500.00
0005433255031	906	Economy	7500.00
0005434943291	906	Economy	7500.00
0005433255042	906	Economy	7500.00
0005433255041	906	Economy	7500.00
0005434943297	906	Economy	7500.00
0005433255033	906	Economy	7500.00
0005434943293	906	Economy	7500.00
0005434943289	906	Economy	7500.00
0005434943296	906	Economy	7500.00
0005434943290	906	Economy	7500.00
0005434943292	906	Economy	7500.00
0005433255030	906	Economy	7500.00
0005434943248	16250	Economy	7500.00
0005434943215	16250	Economy	7500.00
0005434943259	16250	Economy	7500.00
0005433255086	16250	Economy	7500.00
0005433255087	16250	Economy	7500.00
0005434943250	16250	Economy	7500.00
0005434943195	16250	Economy	7500.00
0005434943186	16250	Economy	7500.00
0005434943249	16250	Economy	7500.00
0005433255084	16250	Economy	7500.00
0005433255085	16250	Economy	7500.00
0005434943204	16250	Economy	7500.00
0005434943260	16250	Economy	7500.00
0005435858485	4321	Business	90500.00
0005433654731	4321	Business	90500.00
0005433654727	4321	Business	90500.00
0005433654714	4321	Business	90500.00
0005435858489	4321	Business	90500.00
0005433654708	4321	Business	90500.00
0005433654733	4321	Business	90500.00
0005433654734	4321	Economy	30200.00
0005433654732	4321	Economy	30200.00
0005435858488	4321	Economy	30200.00
0005433654718	4321	Economy	30200.00
0005433654730	4321	Economy	33200.00
0005435858495	4321	Economy	30200.00
0005433654719	4321	Economy	30200.00
0005433654713	4321	Economy	30200.00
0005435858484	4321	Economy	30200.00
0005435858496	4321	Economy	30200.00
0005435858492	4321	Economy	30200.00
0005435858483	4321	Economy	30200.00
0005433654720	4321	Economy	30200.00
0005433654725	4321	Economy	30200.00
0005433654711	4321	Economy	30200.00
0005433654716	4321	Economy	30200.00
0005433654735	4321	Economy	30200.00
0005433654728	4321	Economy	30200.00
0005435858491	4321	Economy	30200.00
0005433654726	4321	Economy	30200.00
0005435858487	4321	Economy	30200.00
0005433654709	4321	Economy	30200.00
0005433654710	4321	Economy	30200.00
0005433654715	4321	Economy	30200.00
0005433654712	4321	Economy	30200.00
0005433654736	4321	Economy	30200.00
0005433654724	4321	Economy	30200.00
0005433654723	4321	Economy	30200.00
0005433654717	4321	Economy	30200.00
0005435858482	4321	Economy	30200.00
0005433654721	4321	Economy	30200.00
0005433654722	4321	Economy	30200.00
0005435858490	4321	Economy	30200.00
0005433654729	4321	Economy	30200.00
0005435652773	21772	Business	9800.00
0005435652781	21772	Business	9800.00
0005435652772	21772	Business	9800.00
0005435652768	21772	Business	9800.00
0005435652779	21772	Business	9800.00
0005435652737	21772	Business	9800.00
0005433367423	21772	Business	9800.00
0005433367319	21772	Business	9800.00
0005435652731	21772	Business	9800.00
0005433367350	21772	Economy	3300.00
0005433367456	21772	Economy	3300.00
0005435652771	21772	Economy	3300.00
0005435652769	21772	Economy	3300.00
0005435652745	21772	Economy	3300.00
0005435652785	21772	Economy	3300.00
0005435652770	21772	Economy	3300.00
0005433367254	21772	Economy	3300.00
0005433367424	21772	Economy	3300.00
0005433367310	21772	Economy	3300.00
0005435652760	21772	Economy	3600.00
0005435652753	21772	Economy	3600.00
0005433367271	21772	Economy	3600.00
0005433367324	21772	Economy	3600.00
0005433367294	21772	Economy	3600.00
0005435652764	21772	Economy	3300.00
0005433367292	21772	Economy	3300.00
0005435652732	21772	Economy	3300.00
0005433367252	21772	Economy	3300.00
0005435652776	21772	Economy	3300.00
0005435652746	21772	Economy	3300.00
0005433367321	21772	Economy	3300.00
0005435652738	21772	Economy	3300.00
0005433367315	21772	Economy	3300.00
0005435652743	21772	Economy	3300.00
0005435652734	21772	Economy	3300.00
0005435652742	21772	Economy	3300.00
0005435652775	21772	Economy	3300.00
0005435652754	21772	Economy	3300.00
0005435652736	21772	Economy	3300.00
0005435652757	21772	Economy	3300.00
0005435652759	21772	Economy	3300.00
0005435652767	21772	Economy	3300.00
0005435652784	21772	Economy	3300.00
0005435652765	21772	Economy	3300.00
0005435652761	21772	Economy	3300.00
0005435652749	21772	Economy	3300.00
0005435652758	21772	Economy	3300.00
0005435652751	21772	Economy	3300.00
0005435652747	21772	Economy	3300.00
0005435652774	21772	Economy	3300.00
0005435652755	21772	Economy	3300.00
0005435652756	21772	Economy	3300.00
0005435652763	21772	Economy	3300.00
0005435652744	21772	Economy	3300.00
0005435652750	21772	Economy	3300.00
0005433367293	21772	Economy	3300.00
0005433367314	21772	Economy	3300.00
0005435652778	21772	Economy	3300.00
0005433367320	21772	Economy	3300.00
0005433367322	21772	Economy	3300.00
0005433367246	21772	Economy	3300.00
0005435652766	21772	Economy	3300.00
0005435652783	21772	Economy	3300.00
0005435652739	21772	Economy	3300.00
0005435652733	21772	Economy	3300.00
0005435652762	21772	Economy	3300.00
0005433367221	21772	Economy	3300.00
0005433367255	21772	Economy	3300.00
0005435652777	21772	Economy	3300.00
0005435652748	21772	Economy	3300.00
0005435652782	21772	Economy	3300.00
0005435652735	21772	Economy	3300.00
0005435652740	21772	Economy	3300.00
0005435652780	21772	Economy	3300.00
0005433367434	21772	Economy	3300.00
0005435652741	21772	Economy	3300.00
0005435652752	21772	Economy	3300.00
0005433367389	21772	Economy	3300.00
0005434170890	9380	Business	186200.00
0005433763118	9380	Business	186200.00
0005433805149	9380	Business	186200.00
0005433784732	9380	Business	186200.00
0005433805160	9380	Business	186200.00
0005433784712	9380	Business	186200.00
0005433763115	9380	Business	186200.00
0005434151658	9380	Business	186200.00
0005433784713	9380	Business	186200.00
0005435269626	9380	Business	186200.00
0005433784738	9380	Business	186200.00
0005433805158	9380	Business	186200.00
0005434170892	9380	Business	186200.00
0005433805161	9380	Business	186200.00
0005433784707	9380	Business	186200.00
0005433784721	9380	Business	186200.00
0005434151659	9380	Business	186200.00
0005435269623	9380	Business	186200.00
0005433805147	9380	Economy	68300.00
0005433805166	9380	Business	186200.00
0005433784709	9380	Economy	68300.00
0005433763117	9380	Economy	62100.00
0005433784700	9380	Economy	62100.00
0005435269624	9380	Economy	62100.00
0005434151666	9380	Economy	62100.00
0005433805156	9380	Economy	62100.00
0005433784719	9380	Economy	62100.00
0005433784731	9380	Economy	62100.00
0005435269642	9380	Economy	62100.00
0005433805133	9380	Economy	62100.00
0005433805154	9380	Economy	62100.00
0005433805151	9380	Economy	62100.00
0005433805146	9380	Economy	62100.00
0005433784702	9380	Economy	62100.00
0005433805167	9380	Economy	62100.00
0005434170874	9380	Economy	62100.00
0005435269628	9380	Economy	62100.00
0005433763111	9380	Economy	62100.00
0005433805128	9380	Economy	62100.00
0005433805126	9380	Economy	62100.00
0005433805164	9380	Economy	62100.00
0005433805148	9380	Economy	62100.00
0005433805159	9380	Economy	62100.00
0005435269625	9380	Economy	62100.00
0005433805165	9380	Economy	62100.00
0005433805134	9380	Economy	62100.00
0005433763119	9380	Economy	62100.00
0005433805144	9380	Economy	62100.00
0005433784715	9380	Economy	62100.00
0005434170904	9380	Economy	62100.00
0005433784704	9380	Economy	62100.00
0005433805155	9380	Economy	62100.00
0005433805157	9380	Economy	62100.00
0005434170864	9380	Economy	62100.00
0005433805129	9380	Economy	62100.00
0005432665261	9380	Economy	62100.00
0005434270177	9380	Economy	62100.00
0005433805140	9380	Economy	62100.00
0005434170814	9380	Economy	62100.00
0005433784718	9380	Economy	62100.00
0005434170883	9380	Economy	62100.00
0005433784720	9380	Economy	62100.00
0005434170824	9380	Economy	62100.00
0005433784710	9380	Economy	62100.00
0005433784734	9380	Economy	62100.00
0005433784727	9380	Economy	62100.00
0005434170875	9380	Economy	62100.00
0005433763120	9380	Economy	62100.00
0005433805153	9380	Economy	62100.00
0005433805162	9380	Economy	62100.00
0005434151660	9380	Economy	62100.00
0005433784728	9380	Economy	62100.00
0005433763110	9380	Economy	62100.00
0005435269647	9380	Economy	62100.00
0005434151661	9380	Economy	62100.00
0005433763112	9380	Economy	62100.00
0005434151663	9380	Economy	62100.00
0005435269630	9380	Economy	62100.00
0005433763121	9380	Economy	62100.00
0005433805142	9380	Economy	62100.00
0005433784723	9380	Economy	62100.00
0005434170861	9380	Economy	68300.00
0005433784716	9380	Economy	62100.00
0005435269641	9380	Economy	62100.00
0005432667440	9380	Economy	62100.00
0005433763108	9380	Economy	68300.00
0005433805132	9380	Economy	62100.00
0005433805150	9380	Economy	62100.00
0005434170862	9380	Economy	62100.00
0005433784733	9380	Economy	62100.00
0005433763109	9380	Economy	62100.00
0005433805152	9380	Economy	62100.00
0005433784714	9380	Economy	62100.00
0005432666375	9380	Economy	62100.00
0005433784703	9380	Economy	62100.00
0005432657429	9380	Economy	62100.00
0005434170891	9380	Economy	62100.00
0005433784724	9380	Economy	62100.00
0005433805145	9380	Economy	62100.00
0005435269629	9380	Economy	62100.00
0005433784711	9380	Economy	62100.00
0005433763116	9380	Economy	62100.00
0005433805138	9380	Economy	62100.00
0005433784705	9380	Economy	62100.00
0005433784722	9380	Economy	62100.00
0005433784730	9380	Economy	62100.00
0005432657431	9380	Economy	62100.00
0005433784735	9380	Economy	62100.00
0005432667441	9380	Economy	62100.00
0005433805139	9380	Economy	62100.00
0005433763113	9380	Economy	62100.00
0005433784737	9380	Economy	62100.00
0005433805131	9380	Economy	62100.00
0005433763114	9380	Economy	62100.00
0005432666376	9380	Economy	62100.00
0005433805130	9380	Economy	62100.00
0005433805136	9380	Economy	62100.00
0005435269627	9380	Economy	62100.00
0005434170882	9380	Economy	62100.00
0005433784717	9380	Economy	62100.00
0005433784701	9380	Economy	62100.00
0005433805137	9380	Economy	62100.00
0005432657430	9380	Economy	62100.00
0005433805141	9380	Economy	62100.00
0005433805143	9380	Economy	62100.00
0005433784725	9380	Economy	62100.00
0005433784708	9380	Economy	62100.00
0005433784706	9380	Economy	62100.00
0005433784726	9380	Economy	62100.00
0005433784729	9380	Economy	62100.00
0005434170903	9380	Economy	62100.00
0005432665262	9380	Economy	62100.00
0005433805163	9380	Economy	62100.00
0005433805127	9380	Economy	62100.00
0005433805135	9380	Economy	62100.00
0005433784736	9380	Economy	62100.00
0005433784364	26259	Business	186200.00
0005434170960	26259	Business	186200.00
0005433804930	26259	Business	186200.00
0005433763022	26259	Business	186200.00
0005433784434	26259	Business	186200.00
0005434170964	26259	Business	186200.00
0005433784390	26259	Business	186200.00
0005434151687	26259	Business	186200.00
0005433784355	26259	Business	186200.00
0005433804946	26259	Business	186200.00
0005433804937	26259	Business	186200.00
0005434170962	26259	Business	186200.00
0005435269700	26259	Business	186200.00
0005434151684	26259	Business	186200.00
0005434271298	26259	Business	186200.00
0005433763041	26259	Business	186200.00
0005433784386	26259	Business	186200.00
0005433784396	26259	Economy	68300.00
0005433784359	26259	Economy	62100.00
0005433762970	26259	Economy	62100.00
0005433784353	26259	Economy	62100.00
0005433804921	26259	Economy	62100.00
0005435269702	26259	Economy	62100.00
0005433804824	26259	Economy	62100.00
0005433763003	26259	Economy	62100.00
0005433784333	26259	Economy	62100.00
0005433784299	26259	Economy	62100.00
0005433804835	26259	Economy	62100.00
0005433784472	26259	Economy	62100.00
0005433784400	26259	Economy	62100.00
0005435269701	26259	Economy	62100.00
0005433784380	26259	Economy	62100.00
0005433784424	26259	Economy	62100.00
0005434170965	26259	Economy	62100.00
0005433762942	26259	Economy	62100.00
0005433804896	26259	Economy	62100.00
0005433804821	26259	Economy	62100.00
0005433804819	26259	Economy	62100.00
0005434170961	26259	Economy	62100.00
0005434151685	26259	Economy	62100.00
0005433804813	26259	Economy	62100.00
0005435269696	26259	Economy	62100.00
0005433762961	26259	Economy	62100.00
0005433804851	26259	Economy	62100.00
0005434269089	26259	Economy	62100.00
0005433784536	26259	Economy	62100.00
0005433762984	26259	Economy	62100.00
0005432666364	26259	Economy	62100.00
0005433784385	26259	Economy	62100.00
0005433804893	26259	Economy	62100.00
0005432657397	26259	Economy	62100.00
0005433784411	26259	Economy	62100.00
0005433784464	26259	Economy	62100.00
0005434151688	26259	Economy	62100.00
0005434170963	26259	Economy	62100.00
0005433763006	26259	Economy	62100.00
0005433804915	26259	Economy	62100.00
0005434151686	26259	Economy	62100.00
0005433804831	26259	Economy	62100.00
0005433784395	26259	Economy	62100.00
0005434170959	26259	Economy	62100.00
0005434170972	26259	Economy	62100.00
0005434170970	26259	Economy	62100.00
0005432666355	26259	Economy	62100.00
0005433804945	26259	Economy	62100.00
0005433784425	26259	Economy	62100.00
0005434271296	26259	Economy	62100.00
0005434170967	26259	Economy	62100.00
0005432666363	26259	Economy	62100.00
0005433784357	26259	Economy	62100.00
0005433762969	26259	Economy	62100.00
0005432657400	26259	Economy	62100.00
0005434170971	26259	Economy	62100.00
0005433804894	26259	Economy	68300.00
0005433784365	26259	Economy	68300.00
0005433762960	26259	Economy	62100.00
0005433804875	26259	Economy	68300.00
0005434270192	26259	Economy	62100.00
0005433804834	26259	Economy	68300.00
0005433784382	26259	Economy	62100.00
0005432657396	26259	Economy	62100.00
0005433804862	26259	Economy	62100.00
0005433804845	26259	Economy	62100.00
0005435269703	26259	Economy	62100.00
0005433784412	26259	Economy	62100.00
0005433784352	26259	Economy	62100.00
0005433804968	26259	Economy	62100.00
0005433804942	26259	Economy	62100.00
0005433784345	26259	Economy	62100.00
0005434269088	26259	Economy	62100.00
0005435269698	26259	Economy	62100.00
0005433804872	26259	Economy	62100.00
0005433784381	26259	Economy	62100.00
0005434170968	26259	Economy	62100.00
0005433762991	26259	Economy	62100.00
0005433784344	26259	Economy	62100.00
0005433804905	26259	Economy	62100.00
0005433804876	26259	Economy	62100.00
0005433804899	26259	Economy	62100.00
0005433804881	26259	Economy	62100.00
0005433784473	26259	Economy	62100.00
0005433784358	26259	Economy	62100.00
0005433762982	26259	Economy	62100.00
0005434270191	26259	Economy	62100.00
0005433784429	26259	Economy	62100.00
0005434170969	26259	Economy	62100.00
0005433763042	26259	Economy	62100.00
0005433784388	26259	Economy	62100.00
0005434170966	26259	Economy	62100.00
0005433763007	26259	Economy	62100.00
0005433804873	26259	Economy	62100.00
0005433784389	26259	Economy	62100.00
0005434271297	26259	Economy	62100.00
0005435269697	26259	Economy	62100.00
0005435269699	26259	Economy	62100.00
0005433784543	26259	Economy	62100.00
0005433804944	26259	Economy	62100.00
0005435135638	4900	Economy	5300.00
0005435135637	4900	Economy	5300.00
0005435135639	4900	Economy	5300.00
0005435135636	4900	Economy	5300.00
0005435135640	4900	Economy	5300.00
0005435135589	33060	Economy	5900.00
0005435135596	33060	Economy	5300.00
0005435135590	33060	Economy	5300.00
0005435135597	33060	Economy	5300.00
0005435929626	33060	Economy	5300.00
0005435135599	33060	Economy	5300.00
0005435929627	33060	Economy	5300.00
0005434983256	9456	Economy	17900.00
0005434983255	9456	Economy	17900.00
0005434983253	9456	Economy	17900.00
0005434983254	9456	Economy	17900.00
0005434983201	27340	Economy	19700.00
0005434983229	27340	Economy	17900.00
0005434983204	27340	Economy	17900.00
0005434217944	27340	Economy	17900.00
0005434983205	27340	Economy	17900.00
0005434217941	27340	Economy	17900.00
0005434217940	27340	Economy	17900.00
0005434217943	27340	Economy	17900.00
0005434983217	27340	Economy	17900.00
0005434983209	27340	Economy	17900.00
0005434983230	27340	Economy	17900.00
0005434983228	27340	Economy	17900.00
0005434217942	27340	Economy	17900.00
0005434983210	27340	Economy	17900.00
0005433985132	24243	Business	36400.00
0005433985185	24243	Business	36400.00
0005433959899	24243	Business	36400.00
0005433959918	24243	Business	36400.00
0005433959879	24243	Business	36400.00
0005433959877	24243	Business	36400.00
0005433985152	24243	Economy	13400.00
0005433959982	24243	Economy	12100.00
0005433959870	24243	Economy	12100.00
0005433959993	24243	Economy	12100.00
0005433960000	24243	Economy	12100.00
0005433959866	24243	Economy	12100.00
0005433985187	24243	Economy	12100.00
0005433985176	24243	Economy	12100.00
0005433959962	24243	Economy	12100.00
0005433959864	24243	Economy	12100.00
0005433960002	24243	Economy	12100.00
0005433959875	24243	Economy	12100.00
0005433985209	24243	Economy	12100.00
0005433959863	24243	Economy	12100.00
0005433959880	24243	Economy	12100.00
0005433959955	24243	Economy	12100.00
0005433985242	24243	Economy	12100.00
0005433960003	24243	Economy	12100.00
0005433959964	24243	Economy	12100.00
0005433959878	24243	Economy	12100.00
0005433959910	24243	Economy	12100.00
0005433959920	24243	Economy	12100.00
0005433985154	24243	Economy	12100.00
0005433985244	24243	Economy	12100.00
0005433959889	24243	Economy	12100.00
0005433985122	24243	Economy	12100.00
0005433959974	24243	Economy	12100.00
0005433959867	24243	Economy	12100.00
0005433959927	24243	Economy	12100.00
0005433959876	24243	Economy	12100.00
0005433959953	24243	Economy	12100.00
0005433960001	24243	Economy	12100.00
0005433985249	24243	Economy	13400.00
0005433985231	24243	Economy	13400.00
0005433959961	24243	Economy	12100.00
0005433959965	24243	Economy	13400.00
0005433985234	24243	Economy	12100.00
0005433985155	24243	Economy	12100.00
0005433959886	24243	Economy	12100.00
0005433959976	24243	Economy	12100.00
0005433985123	24243	Economy	12100.00
0005433985223	24243	Economy	12100.00
0005433985146	24243	Economy	12100.00
0005433959938	24243	Economy	12100.00
0005433959887	24243	Economy	12100.00
0005433959977	24243	Economy	12100.00
0005433959862	24243	Economy	12100.00
0005433985250	24243	Economy	12100.00
0005433985180	24243	Economy	12100.00
0005433959939	24243	Economy	12100.00
0005433985253	24243	Economy	12100.00
0005433985241	24243	Economy	12100.00
0005433985222	24243	Economy	12100.00
0005433985191	24243	Economy	12100.00
0005433985186	24243	Economy	12100.00
0005433959906	24243	Economy	12100.00
0005433985161	24243	Economy	12100.00
0005433959973	24243	Economy	12100.00
0005433985212	24243	Economy	12100.00
0005433985131	24243	Economy	12100.00
0005433959905	24243	Economy	12100.00
0005433959994	24243	Economy	12100.00
0005433959881	24243	Economy	12100.00
0005433985232	24243	Economy	12100.00
0005433985151	24243	Economy	12100.00
0005433959954	24243	Economy	12100.00
0005433959940	24243	Economy	12100.00
0005433985145	24243	Economy	12100.00
0005433959919	24243	Economy	12100.00
0005433985615	25962	Business	36400.00
0005433985647	25962	Business	36400.00
0005433985639	25962	Business	36400.00
0005433985612	25962	Business	36400.00
0005433985608	25962	Business	36400.00
0005433985617	25962	Business	36400.00
0005433985619	25962	Business	36400.00
0005433960482	25962	Business	36400.00
0005433960471	25962	Business	36400.00
0005433985633	25962	Business	36400.00
0005433960450	25962	Business	36400.00
0005433960495	25962	Economy	13400.00
0005433985638	25962	Economy	13400.00
0005433960458	25962	Economy	13400.00
0005433960480	25962	Economy	12100.00
0005433960476	25962	Economy	12100.00
0005433960490	25962	Economy	12100.00
0005433960467	25962	Economy	12100.00
0005433985643	25962	Economy	12100.00
0005433960489	25962	Economy	12100.00
0005433960455	25962	Economy	12100.00
0005433985623	25962	Economy	12100.00
0005433960466	25962	Economy	12100.00
0005433960488	25962	Economy	12100.00
0005433960479	25962	Economy	12100.00
0005433960444	25962	Economy	12100.00
0005433985634	25962	Economy	12100.00
0005433960484	25962	Economy	12100.00
0005433960445	25962	Economy	12100.00
0005433960473	25962	Economy	12100.00
0005433985607	25962	Economy	12100.00
0005433985626	25962	Economy	12100.00
0005433985628	25962	Economy	12100.00
0005433985632	25962	Economy	12100.00
0005433960446	25962	Economy	12100.00
0005433985644	25962	Economy	12100.00
0005433985613	25962	Economy	12100.00
0005433960448	25962	Economy	12100.00
0005433985620	25962	Economy	12100.00
0005433960451	25962	Economy	12100.00
0005433960460	25962	Economy	12100.00
0005433985621	25962	Economy	12100.00
0005433985629	25962	Economy	12100.00
0005433985618	25962	Economy	12100.00
0005433985616	25962	Economy	12100.00
0005433985609	25962	Economy	12100.00
0005433960463	25962	Economy	12100.00
0005433960457	25962	Economy	12100.00
0005433960486	25962	Economy	12100.00
0005433985641	25962	Economy	12100.00
0005433960447	25962	Economy	12100.00
0005433985625	25962	Economy	12100.00
0005433960496	25962	Economy	12100.00
0005433960465	25962	Economy	12100.00
0005433985627	25962	Economy	12100.00
0005433960478	25962	Economy	13400.00
0005433960485	25962	Economy	13400.00
0005433985635	25962	Economy	12100.00
0005433960477	25962	Economy	13400.00
0005433960494	25962	Economy	12100.00
0005433960452	25962	Economy	12100.00
0005433960497	25962	Economy	12100.00
0005433960481	25962	Economy	12100.00
0005433960464	25962	Economy	12100.00
0005433985614	25962	Economy	12100.00
0005433985640	25962	Economy	12100.00
0005433960483	25962	Economy	12100.00
0005433960472	25962	Economy	12100.00
0005433960493	25962	Economy	12100.00
0005433960498	25962	Economy	12100.00
0005433985636	25962	Economy	12100.00
0005433985637	25962	Economy	12100.00
0005433985611	25962	Economy	12100.00
0005433960469	25962	Economy	12100.00
0005433985610	25962	Economy	12100.00
0005433960449	25962	Economy	12100.00
0005433960492	25962	Economy	12100.00
0005433985606	25962	Economy	12100.00
0005433985645	25962	Economy	12100.00
0005433960475	25962	Economy	12100.00
0005433985630	25962	Economy	12100.00
0005433985642	25962	Economy	12100.00
0005433960456	25962	Economy	12100.00
0005433960491	25962	Economy	12100.00
0005433960454	25962	Economy	12100.00
0005433960462	25962	Economy	12100.00
0005433960453	25962	Economy	12100.00
0005433960461	25962	Economy	12100.00
0005433960459	25962	Economy	12100.00
0005433985624	25962	Economy	12100.00
0005433960443	25962	Economy	12100.00
0005433960470	25962	Economy	12100.00
0005433960474	25962	Economy	12100.00
0005433960468	25962	Economy	12100.00
0005433960487	25962	Economy	12100.00
0005433985622	25962	Economy	12100.00
0005433985631	25962	Economy	12100.00
0005433985646	25962	Economy	12100.00
0005433165684	928	Economy	25400.00
0005433165806	928	Economy	25400.00
0005433165768	928	Economy	25400.00
0005434480168	928	Economy	23100.00
0005432269478	928	Economy	23100.00
0005433165690	928	Economy	23100.00
0005433165773	928	Economy	23100.00
0005434480160	928	Economy	23100.00
0005434480175	928	Economy	23100.00
0005433165753	928	Economy	23100.00
0005434480173	928	Economy	23100.00
0005434480177	928	Economy	23100.00
0005434480164	928	Economy	23100.00
0005434480166	928	Economy	23100.00
0005434480167	928	Economy	23100.00
0005433165689	928	Economy	23100.00
0005434480163	928	Economy	23100.00
0005434480172	928	Economy	23100.00
0005434480181	928	Economy	23100.00
0005434480180	928	Economy	23100.00
0005434480178	928	Economy	23100.00
0005434480182	928	Economy	23100.00
0005434480171	928	Economy	23100.00
0005434480174	928	Economy	23100.00
0005434480185	928	Economy	23100.00
0005434480162	928	Economy	23100.00
0005434480176	928	Economy	23100.00
0005433165697	928	Economy	23100.00
0005434480161	928	Economy	23100.00
0005434480179	928	Economy	23100.00
0005433165685	928	Economy	23100.00
0005432269477	928	Economy	23100.00
0005433165731	928	Economy	23100.00
0005434480184	928	Economy	23100.00
0005434480183	928	Economy	23100.00
0005433165752	928	Economy	23100.00
0005434480165	928	Economy	23100.00
0005434480170	928	Economy	23100.00
0005434480169	928	Economy	23100.00
0005433165805	928	Economy	23100.00
0005432269476	928	Economy	23100.00
0005434480002	16580	Economy	25400.00
0005434479921	16580	Economy	25400.00
0005434479995	16580	Economy	25400.00
0005434479967	16580	Economy	23100.00
0005433165828	16580	Economy	23100.00
0005434480001	16580	Economy	23100.00
0005434479968	16580	Economy	23100.00
0005434479978	16580	Economy	23100.00
0005434479991	16580	Economy	23100.00
0005433165823	16580	Economy	23100.00
0005434479996	16580	Economy	23100.00
0005433165824	16580	Economy	23100.00
0005433165819	16580	Economy	23100.00
0005434479975	16580	Economy	23100.00
0005434479963	16580	Economy	23100.00
0005434479969	16580	Economy	23100.00
0005433165821	16580	Economy	23100.00
0005434479980	16580	Economy	23100.00
0005434479979	16580	Economy	23100.00
0005434479935	16580	Economy	23100.00
0005434479974	16580	Economy	23100.00
0005434479954	16580	Economy	23100.00
0005434479960	16580	Economy	23100.00
0005434480075	16580	Economy	23100.00
0005434479992	16580	Economy	23100.00
0005433165826	16580	Economy	23100.00
0005434479997	16580	Economy	23100.00
0005433165822	16580	Economy	23100.00
0005433165817	16580	Economy	23100.00
0005434480073	16580	Economy	23100.00
0005434479966	16580	Economy	23100.00
0005434479884	16580	Economy	23100.00
0005434480074	16580	Economy	23100.00
0005433165818	16580	Economy	23100.00
0005434479951	16580	Economy	23100.00
0005434480028	16580	Economy	23100.00
0005434480019	16580	Economy	23100.00
0005434479939	16580	Economy	23100.00
0005433165816	16580	Economy	23100.00
0005433165825	16580	Economy	23100.00
0005433165827	16580	Economy	23100.00
0005434479885	16580	Economy	23100.00
0005434479886	16580	Economy	23100.00
0005434479882	16580	Economy	23100.00
0005434479999	16580	Economy	23100.00
0005433165820	16580	Economy	23100.00
0005433872463	3208	Economy	17200.00
0005433872461	3208	Economy	17200.00
0005433872464	3208	Economy	17200.00
0005433872462	3208	Economy	17200.00
0005433872460	3208	Economy	17200.00
0005433872466	3208	Economy	17200.00
0005433872465	3208	Economy	17200.00
0005433872434	32545	Economy	19000.00
0005433872428	32545	Economy	17200.00
0005433872442	32545	Economy	17200.00
0005433872438	32545	Economy	17200.00
0005435142476	10343	Economy	17000.00
0005433289744	10343	Economy	17000.00
0005435142487	10343	Economy	17000.00
0005433289743	10343	Economy	17000.00
0005433289759	10343	Economy	15400.00
0005435386476	10343	Economy	15400.00
0005435142483	10343	Economy	15400.00
0005435149935	10343	Economy	15400.00
0005435142486	10343	Economy	15400.00
0005435142475	10343	Economy	15400.00
0005435142480	10343	Economy	15400.00
0005435142484	10343	Economy	15400.00
0005435149936	10343	Economy	15400.00
0005435142477	10343	Economy	15400.00
0005433289760	10343	Economy	15400.00
0005435149930	10343	Economy	15400.00
0005435142481	10343	Economy	15400.00
0005433289740	10343	Economy	15400.00
0005435386477	10343	Economy	15400.00
0005435386499	10343	Economy	15400.00
0005435142474	10343	Economy	15400.00
0005435149928	10343	Economy	15400.00
0005435149934	10343	Economy	15400.00
0005435149929	10343	Economy	15400.00
0005435142482	10343	Economy	15400.00
0005435149933	10343	Economy	15400.00
0005433289733	10343	Economy	15400.00
0005433289741	10343	Economy	15400.00
0005435149927	10343	Economy	15400.00
0005433289734	10343	Economy	15400.00
0005435142478	10343	Economy	15400.00
0005435142479	10343	Economy	15400.00
0005433289761	10343	Economy	15400.00
0005435149932	10343	Economy	15400.00
0005435149931	10343	Economy	15400.00
0005435142485	10343	Economy	15400.00
0005435142372	21924	Economy	17000.00
0005435142381	21924	Economy	17000.00
0005435149796	21924	Economy	17000.00
0005433289809	21924	Economy	15400.00
0005435149805	21924	Economy	15400.00
0005433289812	21924	Economy	15400.00
0005435386531	21924	Economy	15400.00
0005435386532	21924	Economy	15400.00
0005433289808	21924	Economy	15400.00
0005435386534	21924	Economy	15400.00
0005435149787	21924	Economy	15400.00
0005435386536	21924	Economy	15400.00
0005435149806	21924	Economy	15400.00
0005435142353	21924	Economy	15400.00
0005435142373	21924	Economy	15400.00
0005435149862	21924	Economy	15400.00
0005435386535	21924	Economy	15400.00
0005435386533	21924	Economy	15400.00
0005435149826	21924	Economy	15400.00
0005435149863	21924	Economy	15400.00
0005435149849	21924	Economy	15400.00
0005433289810	21924	Economy	15400.00
0005435142380	21924	Economy	15400.00
0005435142397	21924	Economy	15400.00
0005433289811	21924	Economy	15400.00
0005435149850	21924	Economy	15400.00
0005435149807	21924	Economy	15400.00
0005435149795	21924	Economy	15400.00
0005435149861	21924	Economy	15400.00
0005435142379	21924	Economy	15400.00
0005435149788	21924	Economy	15400.00
0005435142389	21924	Economy	15400.00
0005435386538	21924	Economy	15400.00
0005435149800	21924	Economy	15400.00
0005435386537	21924	Economy	15400.00
0005435502013	11233	Business	57200.00
0005434573247	11233	Business	57200.00
0005435501959	11233	Business	57200.00
0005435528937	11233	Business	57200.00
0005434573253	11233	Business	57200.00
0005434573254	11233	Business	57200.00
0005435501966	11233	Business	57200.00
0005435528936	11233	Business	57200.00
0005434573258	11233	Business	57200.00
0005435319449	11233	Economy	19100.00
0005435501953	11233	Economy	19100.00
0005434573260	11233	Economy	19100.00
0005435528961	11233	Economy	19100.00
0005434573252	11233	Economy	19100.00
0005435502091	11233	Economy	19100.00
0005434573250	11233	Economy	19100.00
0005435528903	11233	Economy	19100.00
0005435528978	11233	Economy	19100.00
0005435528911	11233	Economy	21000.00
0005435528962	11233	Economy	21000.00
0005435528979	11233	Economy	21000.00
0005435502065	11233	Economy	21000.00
0005435528881	11233	Economy	19100.00
0005435501958	11233	Economy	19100.00
0005435501954	11233	Economy	19100.00
0005435501933	11233	Economy	19100.00
0005435319471	11233	Economy	19100.00
0005435545616	11233	Economy	19100.00
0005435501975	11233	Economy	19100.00
0005435528988	11233	Economy	19100.00
0005434573259	11233	Economy	19100.00
0005434573256	11233	Economy	19100.00
0005435319444	11233	Economy	19100.00
0005435502014	11233	Economy	19100.00
0005435529011	11233	Economy	19100.00
0005435528982	11233	Economy	19100.00
0005435502016	11233	Economy	19100.00
0005435319448	11233	Economy	19100.00
0005435501932	11233	Economy	19100.00
0005434573249	11233	Economy	19100.00
0005435502089	11233	Economy	19100.00
0005435528963	11233	Economy	19100.00
0005435528987	11233	Economy	19100.00
0005435319454	11233	Economy	19100.00
0005435502004	11233	Economy	19100.00
0005435319461	11233	Economy	19100.00
0005434573248	11233	Economy	19100.00
0005435319475	11233	Economy	19100.00
0005434573257	11233	Economy	19100.00
0005435319438	11233	Economy	19100.00
0005435528948	11233	Economy	19100.00
0005435502015	11233	Economy	19100.00
0005435528912	11233	Economy	19100.00
0005434573255	11233	Economy	19100.00
0005435528924	11233	Economy	19100.00
0005435501986	11233	Economy	19100.00
0005435529012	11233	Economy	19100.00
0005435319447	11233	Economy	19100.00
0005435528932	11233	Economy	19100.00
0005435501990	11233	Economy	19100.00
0005435319456	11233	Economy	19100.00
0005435528943	11233	Economy	19100.00
0005435528949	11233	Economy	19100.00
0005434573246	11233	Economy	19100.00
0005435528923	11233	Economy	19100.00
0005435502090	11233	Economy	19100.00
0005435528990	11233	Economy	19100.00
0005434573251	11233	Economy	19100.00
0005435502160	20927	Business	57200.00
0005435517795	20927	Business	57200.00
0005432291914	20927	Business	57200.00
0005434573103	20927	Business	57200.00
0005435502163	20927	Business	57200.00
0005435508280	20927	Business	57200.00
0005434573104	20927	Business	57200.00
0005435508276	20927	Business	57200.00
0005435502168	20927	Business	57200.00
0005435502171	20927	Business	57200.00
0005434573120	20927	Business	57200.00
0005432291912	20927	Economy	19100.00
0005435508283	20927	Economy	19100.00
0005435319530	20927	Economy	19100.00
0005435502169	20927	Economy	19100.00
0005435517789	20927	Economy	19100.00
0005434573101	20927	Economy	19100.00
0005435508284	20927	Economy	21000.00
0005435319527	20927	Economy	21000.00
0005435319524	20927	Economy	19100.00
0005435502166	20927	Economy	19100.00
0005435502155	20927	Economy	19100.00
0005435517791	20927	Economy	19100.00
0005435502157	20927	Economy	19100.00
0005435502170	20927	Economy	19100.00
0005434573170	20927	Economy	19100.00
0005435502173	20927	Economy	19100.00
0005435517788	20927	Economy	19100.00
0005435319525	20927	Economy	19100.00
0005435517797	20927	Economy	19100.00
0005435502156	20927	Economy	19100.00
0005434573102	20927	Economy	19100.00
0005435508277	20927	Economy	19100.00
0005435502159	20927	Economy	19100.00
0005435508279	20927	Economy	19100.00
0005435502153	20927	Economy	19100.00
0005435508278	20927	Economy	19100.00
0005435517792	20927	Economy	19100.00
0005435517786	20927	Economy	19100.00
0005434573171	20927	Economy	19100.00
0005435517796	20927	Economy	19100.00
0005435508281	20927	Economy	19100.00
0005435517782	20927	Economy	19100.00
0005435502154	20927	Economy	19100.00
0005435319526	20927	Economy	19100.00
0005434573135	20927	Economy	19100.00
0005435502167	20927	Economy	19100.00
0005435319531	20927	Economy	19100.00
0005435502165	20927	Economy	19100.00
0005435517784	20927	Economy	19100.00
0005435517790	20927	Economy	19100.00
0005435517787	20927	Economy	19100.00
0005432291913	20927	Economy	19100.00
0005435517783	20927	Economy	19100.00
0005434573123	20927	Economy	19100.00
0005435319528	20927	Economy	19100.00
0005435517781	20927	Economy	19100.00
0005435517778	20927	Economy	19100.00
0005435502174	20927	Economy	19100.00
0005435319529	20927	Economy	19100.00
0005435517794	20927	Economy	19100.00
0005435517799	20927	Economy	19100.00
0005435502162	20927	Economy	19100.00
0005434573161	20927	Economy	19100.00
0005434573167	20927	Economy	19100.00
0005435502172	20927	Economy	19100.00
0005435517793	20927	Economy	19100.00
0005435517798	20927	Economy	19100.00
0005435502164	20927	Economy	19100.00
0005435502161	20927	Economy	19100.00
0005435502158	20927	Economy	19100.00
0005435517780	20927	Economy	19100.00
0005435517779	20927	Economy	19100.00
0005434573172	20927	Economy	19100.00
0005434573160	20927	Economy	19100.00
0005435508282	20927	Economy	19100.00
0005435517785	20927	Economy	19100.00
0005434573159	20927	Economy	19100.00
0005435508285	20927	Economy	19100.00
0005432692571	2896	Business	10300.00
0005432692683	2896	Business	10300.00
0005432692534	2896	Business	10300.00
0005432692558	2896	Business	10300.00
0005432692638	2896	Economy	3400.00
0005432692569	2896	Economy	3400.00
0005432692647	2896	Economy	3800.00
0005432692666	2896	Economy	3400.00
0005432692631	2896	Economy	3400.00
0005432692608	2896	Economy	3400.00
0005432692674	2896	Economy	3400.00
0005432692646	2896	Economy	3400.00
0005432692603	2896	Economy	3400.00
0005432692582	2896	Economy	3400.00
0005432692627	2896	Economy	3400.00
0005432692557	2896	Economy	3400.00
0005432692648	2896	Economy	3400.00
0005432692590	2896	Economy	3400.00
0005432692633	2896	Economy	3400.00
0005432692682	2896	Economy	3400.00
0005432692645	2896	Economy	3400.00
0005432692639	2896	Economy	3400.00
0005432692675	2896	Economy	3400.00
0005432692568	2896	Economy	3400.00
0005432692537	2896	Economy	3400.00
0005432706613	2897	Business	10300.00
0005432706603	2897	Business	10300.00
0005432706616	2897	Business	10300.00
0005433194822	2897	Business	10300.00
0005432706607	2897	Business	10300.00
0005432880611	2897	Business	10300.00
0005432706608	2897	Business	10300.00
0005432706620	2897	Business	10300.00
0005433123662	2897	Business	10300.00
0005433123624	2897	Business	10300.00
0005433123627	2897	Economy	3400.00
0005432706595	2897	Economy	3400.00
0005432706618	2897	Economy	3400.00
0005433123673	2897	Economy	3400.00
0005432706602	2897	Economy	3400.00
0005432706611	2897	Economy	3400.00
0005432706604	2897	Economy	3400.00
0005432706596	2897	Economy	3800.00
0005432706612	2897	Economy	3800.00
0005433123664	2897	Economy	3800.00
0005433123731	2897	Economy	3800.00
0005433123709	2897	Economy	3400.00
0005432706619	2897	Economy	3400.00
0005432706614	2897	Economy	3400.00
0005433123626	2897	Economy	3400.00
0005432706598	2897	Economy	3400.00
0005432880553	2897	Economy	3400.00
0005432706601	2897	Economy	3400.00
0005432880585	2897	Economy	3400.00
0005432706609	2897	Economy	3400.00
0005433123602	2897	Economy	3400.00
0005433123719	2897	Economy	3400.00
0005433123730	2897	Economy	3400.00
0005433123652	2897	Economy	3400.00
0005432706597	2897	Economy	3400.00
0005432706617	2897	Economy	3400.00
0005432706615	2897	Economy	3400.00
0005432706606	2897	Economy	3400.00
0005432706605	2897	Economy	3400.00
0005432880639	2897	Economy	3400.00
0005433123601	2897	Economy	3400.00
0005432706610	2897	Economy	3400.00
0005432217757	2897	Economy	3400.00
0005432880621	2897	Economy	3400.00
0005432880615	2897	Economy	3400.00
0005433123639	2897	Economy	3400.00
0005432706599	2897	Economy	3400.00
0005433194823	2897	Economy	3400.00
0005433123690	2897	Economy	3400.00
0005433123616	2897	Economy	3400.00
0005433123637	2897	Economy	3400.00
0005433123582	2897	Economy	3400.00
0005432880620	2897	Economy	3400.00
0005432217758	2897	Economy	3400.00
0005433123631	2897	Economy	3400.00
0005432880555	2897	Economy	3400.00
0005432706600	2897	Economy	3400.00
0005433123681	2897	Economy	3400.00
0005433123691	2897	Economy	3400.00
0005433194824	2897	Economy	3400.00
0005433123623	2897	Economy	3400.00
0005432706489	29942	Business	10300.00
0005432692903	29942	Business	10300.00
0005432880731	29942	Business	10300.00
0005432692875	29942	Business	10300.00
0005433123789	29942	Business	10300.00
0005432692896	29942	Business	10300.00
0005433123781	29942	Business	10300.00
0005432706403	29942	Business	10300.00
0005432692874	29942	Business	10300.00
0005433123791	29942	Business	10300.00
0005432706488	29942	Business	10300.00
0005432692888	29942	Business	10300.00
0005433123792	29942	Economy	3400.00
0005432706475	29942	Economy	3400.00
0005433194842	29942	Economy	3400.00
0005432692879	29942	Economy	3400.00
0005432706440	29942	Economy	3400.00
0005432880718	29942	Economy	3400.00
0005432692905	29942	Economy	3400.00
0005432692880	29942	Economy	3400.00
0005432880725	29942	Economy	3400.00
0005433123784	29942	Economy	3400.00
0005432880730	29942	Economy	3800.00
0005432692892	29942	Economy	3800.00
0005432706442	29942	Economy	3800.00
0005433123783	29942	Economy	3800.00
0005432692883	29942	Economy	3800.00
0005432692886	29942	Economy	3400.00
0005433123794	29942	Economy	3400.00
0005433123800	29942	Economy	3400.00
0005432692893	29942	Economy	3400.00
0005432692891	29942	Economy	3400.00
0005433123787	29942	Economy	3400.00
0005432880724	29942	Economy	3400.00
0005433194839	29942	Economy	3400.00
0005432692894	29942	Economy	3400.00
0005433123786	29942	Economy	3400.00
0005432706472	29942	Economy	3400.00
0005432880719	29942	Economy	3400.00
0005432706508	29942	Economy	3400.00
0005432880721	29942	Economy	3400.00
0005433123801	29942	Economy	3400.00
0005432880723	29942	Economy	3400.00
0005432692876	29942	Economy	3400.00
0005432692878	29942	Economy	3400.00
0005433194835	29942	Economy	3400.00
0005432706468	29942	Economy	3400.00
0005432692904	29942	Economy	3400.00
0005432692899	29942	Economy	3400.00
0005432692898	29942	Economy	3400.00
0005433123796	29942	Economy	3400.00
0005433123788	29942	Economy	3400.00
0005433123802	29942	Economy	3400.00
0005433194834	29942	Economy	3400.00
0005432880729	29942	Economy	3400.00
0005432706409	29942	Economy	3400.00
0005432692887	29942	Economy	3400.00
0005432880728	29942	Economy	3400.00
0005432706506	29942	Economy	3400.00
0005432692882	29942	Economy	3400.00
0005432692895	29942	Economy	3400.00
0005433123795	29942	Economy	3400.00
0005432692890	29942	Economy	3400.00
0005432880716	29942	Economy	3400.00
0005433123793	29942	Economy	3400.00
0005433123798	29942	Economy	3400.00
0005432692901	29942	Economy	3400.00
0005432692902	29942	Economy	3400.00
0005432880722	29942	Economy	3400.00
0005432692884	29942	Economy	3400.00
0005432692897	29942	Economy	3400.00
0005433123803	29942	Economy	3400.00
0005433194836	29942	Economy	3400.00
0005432880717	29942	Economy	3400.00
0005432692885	29942	Economy	3400.00
0005433123797	29942	Economy	3400.00
0005432706439	29942	Economy	3400.00
0005432880727	29942	Economy	3400.00
0005432706375	29942	Economy	3400.00
0005432692900	29942	Economy	3400.00
0005432880720	29942	Economy	3400.00
0005432692881	29942	Economy	3400.00
0005432692877	29942	Economy	3400.00
0005432706455	29942	Economy	3400.00
0005432880726	29942	Economy	3400.00
0005433123790	29942	Economy	3400.00
0005432706379	29942	Economy	3400.00
0005433194837	29942	Economy	3400.00
0005432706473	29942	Economy	3400.00
0005433194838	29942	Economy	3400.00
0005433194840	29942	Economy	3400.00
0005432706443	29942	Economy	3400.00
0005432692889	29942	Economy	3400.00
0005433123782	29942	Economy	3400.00
0005433123799	29942	Economy	3400.00
0005433194841	29942	Economy	3400.00
0005433123785	29942	Economy	3400.00
0005434979577	23672	Economy	4000.00
0005434979583	23672	Economy	4000.00
0005434979589	23672	Economy	4000.00
0005434979563	23672	Economy	4000.00
0005434979591	23672	Economy	3600.00
0005434988655	23672	Economy	3600.00
0005434979579	23672	Economy	3600.00
0005434979565	23672	Economy	3600.00
0005434979580	23672	Economy	3600.00
0005434979561	23672	Economy	3600.00
0005434979582	23672	Economy	3600.00
0005434988657	23672	Economy	3600.00
0005434979568	23672	Economy	3600.00
0005434988662	23672	Economy	3600.00
0005434979560	23672	Economy	3600.00
0005434979567	23672	Economy	3600.00
0005434979584	23672	Economy	3600.00
0005434979581	23672	Economy	3600.00
0005434988663	23672	Economy	3600.00
0005434988656	23672	Economy	3600.00
0005434988654	23672	Economy	3600.00
0005434979570	23672	Economy	3600.00
0005434979569	23672	Economy	3600.00
0005434988666	23672	Economy	3600.00
0005434979585	23672	Economy	3600.00
0005434979586	23672	Economy	3600.00
0005434988658	23672	Economy	3600.00
0005434979578	23672	Economy	3600.00
0005434979587	23672	Economy	3600.00
0005434988664	23672	Economy	3600.00
0005434988660	23672	Economy	3600.00
0005434979566	23672	Economy	3600.00
0005434988659	23672	Economy	3600.00
0005434979572	23672	Economy	3600.00
0005434979574	23672	Economy	3600.00
0005434988661	23672	Economy	3600.00
0005434979571	23672	Economy	3600.00
0005434979590	23672	Economy	3600.00
0005434988665	23672	Economy	3600.00
0005434979564	23672	Economy	3600.00
0005434979575	23672	Economy	3600.00
0005434979588	23672	Economy	3600.00
0005434979562	23672	Economy	3600.00
0005434979576	23672	Economy	3600.00
0005434979573	23672	Economy	3600.00
0005434979323	27565	Economy	4000.00
0005434979335	27565	Economy	3600.00
0005434979264	27565	Economy	3600.00
0005434979314	27565	Economy	3600.00
0005434979352	27565	Economy	3600.00
0005434979360	27565	Economy	3600.00
0005434979390	27565	Economy	3600.00
0005434979263	27565	Economy	3600.00
0005434988569	27565	Economy	3600.00
0005434979407	27565	Economy	3600.00
0005434979319	27565	Economy	3600.00
0005434988565	27565	Economy	3600.00
0005434979351	27565	Economy	3600.00
0005434979256	27565	Economy	3600.00
0005434979399	27565	Economy	3600.00
0005434979430	27565	Economy	3600.00
0005434979398	27565	Economy	3600.00
0005434979336	27565	Economy	3600.00
0005434979345	27565	Economy	3600.00
0005434979334	27565	Economy	3600.00
0005434988563	27565	Economy	3600.00
0005434988559	27565	Economy	3600.00
0005434988562	27565	Economy	3600.00
0005434979257	27565	Economy	3600.00
0005434988556	27565	Economy	3600.00
0005434988566	27565	Economy	3600.00
0005434979465	27565	Economy	3600.00
0005434979359	27565	Economy	3600.00
0005434979370	27565	Economy	3600.00
0005434988572	27565	Economy	3600.00
0005434979318	27565	Economy	3600.00
0005434979369	27565	Economy	3600.00
0005434302428	10257	Economy	19700.00
0005434302427	10257	Economy	19700.00
0005434302429	10257	Economy	19700.00
0005433113499	10257	Economy	19700.00
0005433113497	10257	Economy	19700.00
0005433111470	10257	Economy	19700.00
0005433113498	10257	Economy	19700.00
0005434302383	19619	Economy	19700.00
0005434302384	19619	Economy	19700.00
0005435718913	3554	Business	26900.00
0005435068783	3554	Business	26900.00
0005435718916	3554	Business	26900.00
0005435068779	3554	Business	26900.00
0005435068766	3554	Business	26900.00
0005435718909	3554	Business	26900.00
0005435068763	3554	Business	26900.00
0005435068764	3554	Business	26900.00
0005435068788	3554	Business	26900.00
0005435068780	3554	Business	26900.00
0005435068793	3554	Business	26900.00
0005435068743	3554	Economy	9000.00
0005435068752	3554	Economy	9000.00
0005435068756	3554	Economy	9000.00
0005435068790	3554	Economy	9000.00
0005435068755	3554	Economy	9000.00
0005435068774	3554	Economy	9000.00
0005435925046	3554	Economy	9000.00
0005435068762	3554	Economy	9900.00
0005435068787	3554	Economy	9900.00
0005435068773	3554	Economy	9900.00
0005435925120	3554	Economy	9900.00
0005435068758	3554	Economy	9000.00
0005435068761	3554	Economy	9000.00
0005435068741	3554	Economy	9000.00
0005435068771	3554	Economy	9000.00
0005435068765	3554	Economy	9000.00
0005435068775	3554	Economy	9000.00
0005435068751	3554	Economy	9000.00
0005435925069	3554	Economy	9000.00
0005435068760	3554	Economy	9000.00
0005435718915	3554	Economy	9000.00
0005435925051	3554	Economy	9000.00
0005435068750	3554	Economy	9000.00
0005435718912	3554	Economy	9000.00
0005435068772	3554	Economy	9000.00
0005435068781	3554	Economy	9000.00
0005435068789	3554	Economy	9000.00
0005435068748	3554	Economy	9000.00
0005435925110	3554	Economy	9000.00
0005435925092	3554	Economy	9000.00
0005435925052	3554	Economy	9000.00
0005435068746	3554	Economy	9000.00
0005435068757	3554	Economy	9000.00
0005435718911	3554	Economy	9000.00
0005435068744	3554	Economy	9000.00
0005435068782	3554	Economy	9000.00
0005435068770	3554	Economy	9000.00
0005435925085	3554	Economy	9000.00
0005435068742	3554	Economy	9000.00
0005435068768	3554	Economy	9000.00
0005435925119	3554	Economy	9000.00
0005435068792	3554	Economy	9000.00
0005435068749	3554	Economy	9000.00
0005435925115	3554	Economy	9000.00
0005435925098	3554	Economy	9000.00
0005435068791	3554	Economy	9000.00
0005435925075	3554	Economy	9000.00
0005435068747	3554	Economy	9000.00
0005435718914	3554	Economy	9000.00
0005435718910	3554	Economy	9000.00
0005435925072	3554	Economy	9000.00
0005435068767	3554	Economy	9000.00
0005435068745	3554	Economy	9000.00
0005435718917	3554	Economy	9000.00
0005435925111	3554	Economy	9000.00
0005435068778	3554	Economy	9000.00
0005435068754	3554	Economy	9000.00
0005435068759	3554	Economy	9000.00
0005435068753	3554	Economy	9000.00
0005435068785	3554	Economy	9000.00
0005435068786	3554	Economy	9000.00
0005435068769	3554	Economy	9000.00
0005435068784	3554	Economy	9000.00
0005435068777	3554	Economy	9000.00
0005435068776	3554	Economy	9000.00
0005435068331	15290	Business	26900.00
0005435939870	15290	Business	26900.00
0005435939867	15290	Business	26900.00
0005435068365	15290	Business	26900.00
0005435925201	15290	Business	26900.00
0005435068170	15290	Business	26900.00
0005435068171	15290	Business	26900.00
0005435925203	15290	Business	26900.00
0005435068364	15290	Economy	9000.00
0005435068289	15290	Economy	9000.00
0005435925195	15290	Economy	9000.00
0005435068281	15290	Economy	9000.00
0005435068215	15290	Economy	9000.00
0005435068385	15290	Economy	9000.00
0005435068302	15290	Economy	9000.00
0005435068315	15290	Economy	9900.00
0005435925196	15290	Economy	9900.00
0005435068291	15290	Economy	9000.00
0005435068200	15290	Economy	9000.00
0005435068323	15290	Economy	9000.00
0005435068358	15290	Economy	9000.00
0005435068276	15290	Economy	9000.00
0005435925199	15290	Economy	9000.00
0005435068255	15290	Economy	9000.00
0005435068402	15290	Economy	9000.00
0005435939866	15290	Economy	9000.00
0005435068224	15290	Economy	9000.00
0005435068360	15290	Economy	9000.00
0005435068470	15290	Economy	9000.00
0005435068336	15290	Economy	9000.00
0005435925200	15290	Economy	9000.00
0005435068363	15290	Economy	9000.00
0005435068528	15290	Economy	9000.00
0005435925197	15290	Economy	9000.00
0005435925194	15290	Economy	9000.00
0005435068167	15290	Economy	9000.00
0005435068329	15290	Economy	9000.00
0005435925192	15290	Economy	9000.00
0005435068277	15290	Economy	9000.00
0005435925198	15290	Economy	9000.00
0005435068394	15290	Economy	9000.00
0005435068301	15290	Economy	9000.00
0005435068520	15290	Economy	9000.00
0005435068207	15290	Economy	9000.00
0005435925202	15290	Economy	9000.00
0005435068290	15290	Economy	9000.00
0005435068425	15290	Economy	9000.00
0005435068403	15290	Economy	9000.00
0005435068519	15290	Economy	9000.00
0005435068166	15290	Economy	9000.00
0005435068314	15290	Economy	9000.00
0005435068223	15290	Economy	9000.00
0005435939869	15290	Economy	9000.00
0005435068222	15290	Economy	9000.00
0005435068527	15290	Economy	9000.00
0005435068426	15290	Economy	9000.00
0005435925193	15290	Economy	9000.00
0005435068357	15290	Economy	9000.00
0005435939868	15290	Economy	9000.00
0005435068237	15290	Economy	9000.00
0005432659693	18162	Economy	5900.00
0005432658578	18162	Economy	5900.00
0005432659692	18162	Economy	5900.00
0005432660805	18162	Economy	5900.00
0005432660804	18162	Economy	5900.00
0005432660786	26343	Economy	5900.00
0005432667419	26343	Economy	5900.00
0005432660787	26343	Economy	5900.00
0005432919507	181	Business	20000.00
0005433101316	181	Business	20000.00
0005433101314	181	Business	20000.00
0005432901386	181	Business	20000.00
0005432901330	181	Business	20000.00
0005432901402	181	Business	20000.00
0005433101202	181	Business	20000.00
0005433101320	181	Business	20000.00
0005433101303	181	Business	20000.00
0005432919525	181	Business	20000.00
0005433101184	181	Business	20000.00
0005432919550	181	Business	20000.00
0005432901338	181	Business	20000.00
0005432919587	181	Business	20000.00
0005432919509	181	Business	20000.00
0005432919607	181	Business	20000.00
0005433101167	181	Economy	7300.00
0005433101236	181	Economy	7300.00
0005432901334	181	Economy	7300.00
0005432901341	181	Economy	6700.00
0005433101149	181	Economy	6700.00
0005432901374	181	Economy	6700.00
0005432901419	181	Economy	6700.00
0005433101315	181	Economy	6700.00
0005433101309	181	Economy	6700.00
0005433101376	181	Economy	6700.00
0005432919586	181	Economy	6700.00
0005432919526	181	Economy	6700.00
0005432919629	181	Economy	6700.00
0005432919508	181	Economy	6700.00
0005433101161	181	Economy	6700.00
0005433101246	181	Economy	6700.00
0005433101221	181	Economy	6700.00
0005433101185	181	Economy	6700.00
0005433101201	181	Economy	6700.00
0005433101174	181	Economy	6700.00
0005433101381	181	Economy	6700.00
0005432919545	181	Economy	6700.00
0005432919605	181	Economy	6700.00
0005433101223	181	Economy	6700.00
0005433101363	181	Economy	6700.00
0005433101346	181	Economy	6700.00
0005432919585	181	Economy	6700.00
0005432919510	181	Economy	6700.00
0005433101220	181	Economy	6700.00
0005433101283	181	Economy	6700.00
0005433101234	181	Economy	6700.00
0005432919620	181	Economy	6700.00
0005432919584	181	Economy	6700.00
0005433101384	181	Economy	6700.00
0005433101166	181	Economy	7300.00
0005432919595	181	Economy	7300.00
0005433101343	181	Economy	6700.00
0005432901385	181	Economy	6700.00
0005433101380	181	Economy	6700.00
0005432919606	181	Economy	6700.00
0005432901372	181	Economy	6700.00
0005432677512	181	Economy	6700.00
0005433101370	181	Economy	6700.00
0005433101302	181	Economy	6700.00
0005433101300	181	Economy	6700.00
0005433101347	181	Economy	6700.00
0005433101199	181	Economy	6700.00
0005432901333	181	Economy	6700.00
0005433101198	181	Economy	6700.00
0005432901375	181	Economy	6700.00
0005432901384	181	Economy	6700.00
0005432677511	181	Economy	6700.00
0005432919596	181	Economy	6700.00
0005433101162	181	Economy	6700.00
0005433101197	181	Economy	6700.00
0005432157481	181	Economy	6700.00
0005433101304	181	Economy	6700.00
0005432157480	181	Economy	6700.00
0005433101321	181	Economy	6700.00
0005432157479	181	Economy	6700.00
0005433101367	181	Economy	6700.00
0005432901358	181	Economy	6700.00
0005433101250	181	Economy	6700.00
0005433101369	181	Economy	6700.00
0005433101222	181	Economy	6700.00
0005433101150	181	Economy	6700.00
0005433101313	181	Economy	6700.00
0005432261610	183	Business	20000.00
0005432261614	183	Business	20000.00
0005432817290	183	Business	20000.00
0005432817294	183	Business	20000.00
0005432261629	183	Business	20000.00
0005432207644	183	Business	20000.00
0005432817296	183	Business	20000.00
0005432817283	183	Business	20000.00
0005432288966	183	Business	20000.00
0005432817291	183	Business	20000.00
0005432261644	183	Business	20000.00
0005432261615	183	Business	20000.00
0005432817299	183	Business	20000.00
0005432261606	183	Business	20000.00
0005432261643	183	Business	20000.00
0005432261639	183	Business	20000.00
0005432753254	183	Economy	7300.00
0005432261646	183	Economy	7300.00
0005432817286	183	Economy	7300.00
0005432817285	183	Economy	7300.00
0005432817298	183	Economy	6700.00
0005432261617	183	Economy	6700.00
0005432817287	183	Economy	6700.00
0005432261616	183	Economy	6700.00
0005432261634	183	Economy	6700.00
0005432817276	183	Economy	6700.00
0005432261622	183	Economy	6700.00
0005432261647	183	Economy	6700.00
0005432817301	183	Economy	6700.00
0005432756788	183	Economy	6700.00
0005432817274	183	Economy	6700.00
0005432817280	183	Economy	6700.00
0005432207645	183	Economy	6700.00
0005432261612	183	Economy	6700.00
0005432261608	183	Economy	6700.00
0005432261633	183	Economy	6700.00
0005432261645	183	Economy	6700.00
0005432261641	183	Economy	6700.00
0005432261626	183	Economy	6700.00
0005432817281	183	Economy	6700.00
0005432261635	183	Economy	6700.00
0005432261623	183	Economy	6700.00
0005432756807	183	Economy	6700.00
0005432288964	183	Economy	6700.00
0005432753244	183	Economy	6700.00
0005432817293	183	Economy	6700.00
0005432817300	183	Economy	6700.00
0005432817273	183	Economy	6700.00
0005432207643	183	Economy	7300.00
0005432261603	183	Economy	6700.00
0005432261619	183	Economy	6700.00
0005432261605	183	Economy	6700.00
0005432288965	183	Economy	6700.00
0005432261609	183	Economy	6700.00
0005432261611	183	Economy	6700.00
0005432753251	183	Economy	6700.00
0005432756789	183	Economy	6700.00
0005433687683	183	Economy	6700.00
0005432817284	183	Economy	6700.00
0005432261632	183	Economy	6700.00
0005432261642	183	Economy	6700.00
0005432817297	183	Economy	6700.00
0005432261631	183	Economy	6700.00
0005432207642	183	Economy	6700.00
0005432817275	183	Economy	6700.00
0005432817289	183	Economy	6700.00
0005432261648	183	Economy	6700.00
0005432261624	183	Economy	6700.00
0005432817282	183	Economy	6700.00
0005432261613	183	Economy	6700.00
0005432261630	183	Economy	6700.00
0005432261627	183	Economy	6700.00
0005432817278	183	Economy	6700.00
0005432261640	183	Economy	6700.00
0005432261638	183	Economy	6700.00
0005432817271	183	Economy	6700.00
0005432817279	183	Economy	6700.00
0005432261607	183	Economy	6700.00
0005432261637	183	Economy	6700.00
0005432817277	183	Economy	6700.00
0005432817272	183	Economy	6700.00
0005432817295	183	Economy	6700.00
0005432261604	183	Economy	6700.00
0005432753253	183	Economy	6700.00
0005432817288	183	Economy	6700.00
0005432261628	183	Economy	6700.00
0005432261618	183	Economy	6700.00
0005432261621	183	Economy	6700.00
0005432261620	183	Economy	6700.00
0005432817292	183	Economy	6700.00
0005432261625	183	Economy	6700.00
0005432261636	183	Economy	6700.00
0005433101829	7930	Business	20000.00
0005432020085	7930	Business	20000.00
0005433101839	7930	Business	20000.00
0005433101794	7930	Business	20000.00
0005433101821	7930	Business	20000.00
0005433101815	7930	Business	20000.00
0005432919718	7930	Business	20000.00
0005432919730	7930	Business	20000.00
0005432751505	7930	Business	20000.00
0005432020090	7930	Business	20000.00
0005433101803	7930	Business	20000.00
0005432919727	7930	Business	20000.00
0005433101830	7930	Business	20000.00
0005433101827	7930	Business	20000.00
0005432919724	7930	Business	20000.00
0005432044507	7930	Business	20000.00
0005433101819	7930	Business	20000.00
0005432044506	7930	Business	20000.00
0005432020091	7930	Business	20000.00
0005433101792	7930	Business	20000.00
0005433101826	7930	Business	20000.00
0005432751506	7930	Business	20000.00
0005433101797	7930	Economy	7300.00
0005432751507	7930	Economy	7300.00
0005432751508	7930	Economy	7300.00
0005432020107	7930	Economy	7300.00
0005433101823	7930	Economy	7300.00
0005432753279	7930	Economy	6700.00
0005432391980	7930	Economy	7300.00
0005432391981	7930	Economy	6700.00
0005432020097	7930	Economy	6700.00
0005433101791	7930	Economy	6700.00
0005432020092	7930	Economy	6700.00
0005432020083	7930	Economy	6700.00
0005432919725	7930	Economy	6700.00
0005433101795	7930	Economy	6700.00
0005432020087	7930	Economy	6700.00
0005433101805	7930	Economy	6700.00
0005433101814	7930	Economy	6700.00
0005433101790	7930	Economy	6700.00
0005433101793	7930	Economy	6700.00
0005432020098	7930	Economy	6700.00
0005433101811	7930	Economy	6700.00
0005433101836	7930	Economy	6700.00
0005433101784	7930	Economy	6700.00
0005432020102	7930	Economy	6700.00
0005433101837	7930	Economy	6700.00
0005432753280	7930	Economy	6700.00
0005432677550	7930	Economy	6700.00
0005432045603	7930	Economy	6700.00
0005432919728	7930	Economy	6700.00
0005433101786	7930	Economy	6700.00
0005433101799	7930	Economy	6700.00
0005432677551	7930	Economy	6700.00
0005432919723	7930	Economy	6700.00
0005432919719	7930	Economy	6700.00
0005433101812	7930	Economy	6700.00
0005432919721	7930	Economy	6700.00
0005433101822	7930	Economy	6700.00
0005433101828	7930	Economy	6700.00
0005433101813	7930	Economy	6700.00
0005432677548	7930	Economy	6700.00
0005432020089	7930	Economy	6700.00
0005433101809	7930	Economy	6700.00
0005433101831	7930	Economy	6700.00
0005433101789	7930	Economy	6700.00
0005432919726	7930	Economy	6700.00
0005432919731	7930	Economy	6700.00
0005433101824	7930	Economy	6700.00
0005432020082	7930	Economy	6700.00
0005432020093	7930	Economy	6700.00
0005433101835	7930	Economy	6700.00
0005432391982	7930	Economy	7300.00
0005432020099	7930	Economy	7300.00
0005432919735	7930	Economy	7300.00
0005432020101	7930	Economy	7300.00
0005433101788	7930	Economy	6700.00
0005433101820	7930	Economy	6700.00
0005433101800	7930	Economy	7300.00
0005432020086	7930	Economy	6700.00
0005432020080	7930	Economy	6700.00
0005433101798	7930	Economy	6700.00
0005433101807	7930	Economy	6700.00
0005433101808	7930	Economy	6700.00
0005433101818	7930	Economy	6700.00
0005433101834	7930	Economy	6700.00
0005433101841	7930	Economy	6700.00
0005433101838	7930	Economy	6700.00
0005432919737	7930	Economy	6700.00
0005432045602	7930	Economy	6700.00
0005432753281	7930	Economy	6700.00
0005432919729	7930	Economy	6700.00
0005432919732	7930	Economy	6700.00
0005432753282	7930	Economy	6700.00
0005432020095	7930	Economy	6700.00
0005432020081	7930	Economy	6700.00
0005432919734	7930	Economy	6700.00
0005433101810	7930	Economy	6700.00
0005432919736	7930	Economy	6700.00
0005432919722	7930	Economy	6700.00
0005432044508	7930	Economy	6700.00
0005432020105	7930	Economy	6700.00
0005433101816	7930	Economy	6700.00
0005433101833	7930	Economy	6700.00
0005432919717	7930	Economy	6700.00
0005432020104	7930	Economy	6700.00
0005432020094	7930	Economy	6700.00
0005433101785	7930	Economy	6700.00
0005432020096	7930	Economy	6700.00
0005433101787	7930	Economy	6700.00
0005432020100	7930	Economy	6700.00
0005432677549	7930	Economy	6700.00
0005432919720	7930	Economy	6700.00
0005432919733	7930	Economy	6700.00
0005433101804	7930	Economy	6700.00
0005433101801	7930	Economy	6700.00
0005432753283	7930	Economy	6700.00
0005432391983	7930	Economy	6700.00
0005433101842	7930	Economy	6700.00
0005432020084	7930	Economy	6700.00
0005433101825	7930	Economy	6700.00
0005432020106	7930	Economy	6700.00
0005433101832	7930	Economy	6700.00
0005433101817	7930	Economy	6700.00
0005433101840	7930	Economy	6700.00
0005433101802	7930	Economy	6700.00
0005432020103	7930	Economy	6700.00
0005432020088	7930	Economy	6700.00
0005433101796	7930	Economy	6700.00
0005432045601	7930	Economy	6700.00
0005433101806	7930	Economy	6700.00
0005432816962	7929	Business	20000.00
0005432816971	7929	Business	20000.00
0005432901496	7929	Business	20000.00
0005432817073	7929	Business	20000.00
0005432817034	7929	Business	20000.00
0005432816970	7929	Business	20000.00
0005432817033	7929	Business	20000.00
0005434513546	7929	Business	20000.00
0005432901508	7929	Business	20000.00
0005432901501	7929	Business	20000.00
0005432901492	7929	Economy	7300.00
0005432817056	7929	Economy	6700.00
0005432817088	7929	Economy	6700.00
0005432816949	7929	Economy	6700.00
0005434513545	7929	Economy	6700.00
0005432816979	7929	Economy	6700.00
0005432817017	7929	Economy	6700.00
0005432901503	7929	Economy	6700.00
0005434513537	7929	Economy	6700.00
0005432816941	7929	Economy	6700.00
0005432817027	7929	Economy	6700.00
0005432901494	7929	Economy	6700.00
0005434513543	7929	Economy	6700.00
0005432002063	7929	Economy	6700.00
0005432901499	7929	Economy	6700.00
0005432817084	7929	Economy	6700.00
0005432901498	7929	Economy	6700.00
0005432901502	7929	Economy	6700.00
0005432817096	7929	Economy	6700.00
0005432817011	7929	Economy	6700.00
0005434513538	7929	Economy	6700.00
0005434513542	7929	Economy	6700.00
0005432817047	7929	Economy	6700.00
0005432901507	7929	Economy	6700.00
0005432901493	7929	Economy	6700.00
0005432817071	7929	Economy	6700.00
0005432816983	7929	Economy	7300.00
0005432816950	7929	Economy	7300.00
0005432901495	7929	Economy	6700.00
0005432817055	7929	Economy	6700.00
0005432816942	7929	Economy	7300.00
0005432816978	7929	Economy	6700.00
0005432817167	7929	Economy	6700.00
0005432002062	7929	Economy	6700.00
0005434513539	7929	Economy	6700.00
0005432816951	7929	Economy	6700.00
0005432817018	7929	Economy	6700.00
0005432002064	7929	Economy	6700.00
0005432817097	7929	Economy	6700.00
0005432816956	7929	Economy	6700.00
0005432901504	7929	Economy	6700.00
0005432901506	7929	Economy	6700.00
0005432901500	7929	Economy	6700.00
0005432817057	7929	Economy	6700.00
0005432901497	7929	Economy	6700.00
0005432816984	7929	Economy	6700.00
0005432817168	7929	Economy	6700.00
0005432817087	7929	Economy	6700.00
0005432901505	7929	Economy	6700.00
0005432817006	7929	Economy	6700.00
0005432817026	7929	Economy	6700.00
0005433870717	9661	Economy	6900.00
0005433870716	9661	Economy	6900.00
0005434175726	32355	Economy	6900.00
0005433870700	32355	Economy	6900.00
0005434175724	32355	Economy	6900.00
0005434175725	32355	Economy	6900.00
0005434175728	32355	Economy	6900.00
0005434175727	32355	Economy	6900.00
0005435902498	3477	Business	35000.00
0005435126133	3477	Business	35000.00
0005435913853	3477	Business	35000.00
0005434877637	3477	Business	35000.00
0005435126113	3477	Business	35000.00
0005434877653	3477	Business	35000.00
0005434877652	3477	Business	35000.00
0005434426434	3477	Business	35000.00
0005434426421	3477	Business	35000.00
0005434877644	3477	Business	35000.00
0005432611685	3477	Business	35000.00
0005432799292	3477	Business	35000.00
0005432613838	3477	Business	35000.00
0005434877622	3477	Business	35000.00
0005435126124	3477	Business	35000.00
0005435626065	3477	Business	35000.00
0005434877716	3477	Business	35000.00
0005434877624	3477	Business	35000.00
0005435126123	3477	Comfort	19900.00
0005434877683	3477	Business	35000.00
0005435626064	3477	Comfort	19900.00
0005432799301	3477	Comfort	19900.00
0005432799298	3477	Comfort	19900.00
0005432188586	3477	Comfort	19900.00
0005432188588	3477	Comfort	19900.00
0005434877693	3477	Comfort	19900.00
0005435626061	3477	Comfort	19900.00
0005434877674	3477	Comfort	19900.00
0005432611687	3477	Comfort	19900.00
0005435126125	3477	Comfort	19900.00
0005435126117	3477	Comfort	19900.00
0005435126110	3477	Comfort	19900.00
0005432611688	3477	Comfort	19900.00
0005435902417	3477	Comfort	19900.00
0005432799281	3477	Comfort	19900.00
0005435126141	3477	Comfort	19900.00
0005432613837	3477	Comfort	19900.00
0005435126143	3477	Comfort	19900.00
0005435902415	3477	Comfort	19900.00
0005432799277	3477	Comfort	19900.00
0005435126115	3477	Comfort	19900.00
0005435126131	3477	Comfort	19900.00
0005434877664	3477	Comfort	19900.00
0005434877711	3477	Comfort	19900.00
0005434877641	3477	Comfort	19900.00
0005435902487	3477	Comfort	19900.00
0005432799272	3477	Comfort	19900.00
0005435126137	3477	Comfort	19900.00
0005434426417	3477	Comfort	19900.00
0005434877675	3477	Comfort	19900.00
0005435126135	3477	Economy	11700.00
0005432799278	3477	Economy	11700.00
0005434877631	3477	Economy	11700.00
0005435126126	3477	Economy	11700.00
0005434877635	3477	Economy	11700.00
0005434877633	3477	Economy	11700.00
0005435626062	3477	Economy	11700.00
0005434877654	3477	Economy	11700.00
0005435902418	3477	Economy	11700.00
0005432799300	3477	Economy	11700.00
0005434877676	3477	Economy	11700.00
0005434877715	3477	Economy	11700.00
0005434877707	3477	Economy	11700.00
0005432611684	3477	Economy	11700.00
0005434426447	3477	Economy	11700.00
0005434877691	3477	Economy	11700.00
0005432188587	3477	Economy	11700.00
0005435913855	3477	Economy	11700.00
0005435126127	3477	Economy	11700.00
0005435913857	3477	Economy	11700.00
0005434938020	3477	Economy	11700.00
0005434877687	3477	Economy	11700.00
0005434938031	3477	Economy	11700.00
0005434877650	3477	Economy	11700.00
0005432799294	3477	Economy	11700.00
0005434426445	3477	Economy	11700.00
0005432799271	3477	Economy	11700.00
0005434938015	3477	Economy	11700.00
0005434426416	3477	Economy	11700.00
0005435126129	3477	Economy	11700.00
0005435902468	3477	Economy	11700.00
0005434938022	3477	Economy	11700.00
0005434938025	3477	Economy	11700.00
0005434877655	3477	Economy	11700.00
0005435626059	3477	Economy	11700.00
0005435626067	3477	Economy	11700.00
0005435126111	3477	Economy	11700.00
0005434938019	3477	Economy	11700.00
0005435902410	3477	Economy	11700.00
0005432799295	3477	Economy	11700.00
0005434877710	3477	Economy	11700.00
0005434877667	3477	Economy	11700.00
0005432799280	3477	Economy	11700.00
0005434877659	3477	Economy	11700.00
0005435902446	3477	Economy	11700.00
0005432611686	3477	Economy	11700.00
0005435126142	3477	Economy	11700.00
0005432799285	3477	Economy	11700.00
0005435913850	3477	Economy	11700.00
0005435126139	3477	Economy	11700.00
0005434877694	3477	Economy	11700.00
0005434877623	3477	Economy	11700.00
0005434877670	3477	Economy	11700.00
0005434426424	3477	Economy	11700.00
0005432613835	3477	Economy	11700.00
0005435126145	3477	Economy	11700.00
0005434877706	3477	Economy	11700.00
0005435902470	3477	Economy	11700.00
0005435902422	3477	Economy	12800.00
0005434426418	3477	Economy	12800.00
0005432183453	3477	Economy	12800.00
0005434877705	3477	Economy	11700.00
0005434426444	3477	Economy	11700.00
0005434877700	3477	Economy	11700.00
0005432799291	3477	Economy	11700.00
0005434938023	3477	Economy	12800.00
0005434877656	3477	Economy	11700.00
0005434877669	3477	Economy	11700.00
0005434426436	3477	Economy	11700.00
0005435626060	3477	Economy	11700.00
0005434877657	3477	Economy	11700.00
0005432799288	3477	Economy	11700.00
0005434877702	3477	Economy	11700.00
0005434877642	3477	Economy	11700.00
0005434938026	3477	Economy	11700.00
0005434877714	3477	Economy	11700.00
0005435126140	3477	Economy	11700.00
0005434877621	3477	Economy	11700.00
0005434877662	3477	Economy	11700.00
0005432183454	3477	Economy	11700.00
0005432799286	3477	Economy	11700.00
0005434877701	3477	Economy	11700.00
0005434877686	3477	Economy	11700.00
0005435126112	3477	Economy	11700.00
0005434877682	3477	Economy	11700.00
0005434877666	3477	Economy	11700.00
0005434938024	3477	Economy	11700.00
0005434877646	3477	Economy	11700.00
0005435902447	3477	Economy	11700.00
0005434877685	3477	Economy	11700.00
0005434426420	3477	Economy	11700.00
0005434877696	3477	Economy	11700.00
0005434877648	3477	Economy	11700.00
0005435626055	3477	Economy	11700.00
0005435126121	3477	Economy	11700.00
0005434938013	3477	Economy	11700.00
0005434877647	3477	Economy	11700.00
0005434426427	3477	Economy	11700.00
0005432799275	3477	Economy	11700.00
0005434938018	3477	Economy	11700.00
0005432799289	3477	Economy	11700.00
0005435913854	3477	Economy	11700.00
0005435126136	3477	Economy	11700.00
0005434938016	3477	Economy	11700.00
0005434877665	3477	Economy	11700.00
0005432799299	3477	Economy	11700.00
0005434877709	3477	Economy	11700.00
0005434877671	3477	Economy	11700.00
0005432799276	3477	Economy	11700.00
0005435126120	3477	Economy	11700.00
0005434877634	3477	Economy	11700.00
0005435126118	3477	Economy	11700.00
0005434426442	3477	Economy	11700.00
0005435126134	3477	Economy	11700.00
0005434426423	3477	Economy	11700.00
0005432799283	3477	Economy	11700.00
0005434938027	3477	Economy	11700.00
0005434426446	3477	Economy	11700.00
0005434877677	3477	Economy	11700.00
0005435626069	3477	Economy	11700.00
0005435126108	3477	Economy	11700.00
0005435626068	3477	Economy	11700.00
0005435126122	3477	Economy	11700.00
0005434877643	3477	Economy	11700.00
0005434877630	3477	Economy	11700.00
0005435126130	3477	Economy	11700.00
0005434877713	3477	Economy	11700.00
0005434877679	3477	Economy	11700.00
0005432799282	3477	Economy	11700.00
0005435902438	3477	Economy	11700.00
0005434426443	3477	Economy	11700.00
0005434426439	3477	Economy	11700.00
0005434426430	3477	Economy	11700.00
0005434877684	3477	Economy	11700.00
0005434877704	3477	Economy	11700.00
0005434877663	3477	Economy	11700.00
0005434426441	3477	Economy	11700.00
0005434938028	3477	Economy	11700.00
0005435126128	3477	Economy	11700.00
0005435126147	3477	Economy	11700.00
0005434877651	3477	Economy	11700.00
0005434877658	3477	Economy	11700.00
0005434877695	3477	Economy	11700.00
0005434877632	3477	Economy	11700.00
0005432799297	3477	Economy	11700.00
0005434426431	3477	Economy	11700.00
0005435126107	3477	Economy	11700.00
0005434877645	3477	Economy	11700.00
0005434426432	3477	Economy	11700.00
0005434877639	3477	Economy	11700.00
0005434426425	3477	Economy	12800.00
0005434877628	3477	Economy	11700.00
0005432799273	3477	Economy	12800.00
0005434877660	3477	Economy	11700.00
0005435126106	3477	Economy	11700.00
0005435626066	3477	Economy	11700.00
0005432799296	3477	Economy	11700.00
0005435126138	3477	Economy	11700.00
0005435126148	3477	Economy	11700.00
0005435626063	3477	Economy	11700.00
0005435902486	3477	Economy	11700.00
0005434877698	3477	Economy	11700.00
0005435126116	3477	Economy	11700.00
0005434938021	3477	Economy	11700.00
0005434426429	3477	Economy	11700.00
0005435126109	3477	Economy	11700.00
0005434877625	3477	Economy	11700.00
0005435126146	3477	Economy	11700.00
0005434938014	3477	Economy	11700.00
0005434877689	3477	Economy	11700.00
0005435841083	3477	Economy	11700.00
0005434877627	3477	Economy	11700.00
0005434877708	3477	Economy	11700.00
0005434938012	3477	Economy	11700.00
0005434877636	3477	Economy	11700.00
0005434877680	3477	Economy	11700.00
0005434877672	3477	Economy	11700.00
0005434426419	3477	Economy	11700.00
0005434877678	3477	Economy	11700.00
0005434877629	3477	Economy	11700.00
0005432613836	3477	Economy	11700.00
0005435126119	3477	Economy	11700.00
0005435841084	3477	Economy	11700.00
0005434426438	3477	Economy	11700.00
0005434877673	3477	Economy	11700.00
0005434877703	3477	Economy	11700.00
0005434877649	3477	Economy	11700.00
0005434877681	3477	Economy	11700.00
0005435626056	3477	Economy	11700.00
0005434877712	3477	Economy	11700.00
0005432799290	3477	Economy	11700.00
0005434426437	3477	Economy	11700.00
0005434426426	3477	Economy	11700.00
0005435126114	3477	Economy	11700.00
0005434426435	3477	Economy	11700.00
0005434877699	3477	Economy	11700.00
0005434938029	3477	Economy	11700.00
0005435626058	3477	Economy	11700.00
0005434938017	3477	Economy	11700.00
0005432799274	3477	Economy	11700.00
0005432188589	3477	Economy	11700.00
0005434877626	3477	Economy	11700.00
0005434877690	3477	Economy	11700.00
0005434877661	3477	Economy	11700.00
0005434426428	3477	Economy	11700.00
0005434426433	3477	Economy	11700.00
0005432799284	3477	Economy	11700.00
0005435126132	3477	Economy	11700.00
0005434426422	3477	Economy	11700.00
0005434426440	3477	Economy	11700.00
0005432799279	3477	Economy	11700.00
0005434877688	3477	Economy	11700.00
0005435126144	3477	Economy	11700.00
0005432799287	3477	Economy	11700.00
0005432799293	3477	Economy	11700.00
0005434877697	3477	Economy	11700.00
0005434877638	3477	Economy	11700.00
0005434877668	3477	Economy	11700.00
0005434877692	3477	Economy	11700.00
0005434877640	3477	Economy	11700.00
0005434938030	3477	Economy	11700.00
0005435902439	3477	Economy	11700.00
0005435626057	3477	Economy	11700.00
0005434937823	14546	Business	35000.00
0005435913923	14546	Business	35000.00
0005435625899	14546	Business	35000.00
0005434877142	14546	Business	35000.00
0005434426177	14546	Business	35000.00
0005434876718	14546	Business	35000.00
0005434877197	14546	Business	35000.00
0005432799067	14546	Business	35000.00
0005434876767	14546	Business	35000.00
0005434876911	14546	Business	35000.00
0005435902600	14546	Business	35000.00
0005435902587	14546	Business	35000.00
0005435913922	14546	Business	35000.00
0005435913913	14546	Business	35000.00
0005435125763	14546	Business	35000.00
0005435125736	14546	Business	35000.00
0005434876870	14546	Business	35000.00
0005435125759	14546	Business	35000.00
0005434426224	14546	Business	35000.00
0005435125785	14546	Business	35000.00
0005434877001	14546	Comfort	19900.00
0005435625876	14546	Comfort	19900.00
0005435913920	14546	Comfort	19900.00
0005435125666	14546	Comfort	19900.00
0005434937794	14546	Comfort	19900.00
0005434876924	14546	Comfort	19900.00
0005434876726	14546	Comfort	19900.00
0005434877000	14546	Comfort	19900.00
0005432607516	14546	Comfort	19900.00
0005432799030	14546	Comfort	19900.00
0005432799151	14546	Comfort	19900.00
0005435125702	14546	Comfort	19900.00
0005434876890	14546	Comfort	19900.00
0005434426136	14546	Comfort	19900.00
0005434937954	14546	Comfort	19900.00
0005434877193	14546	Comfort	19900.00
0005435125706	14546	Comfort	19900.00
0005435913912	14546	Comfort	19900.00
0005434876658	14546	Comfort	19900.00
0005435125713	14546	Comfort	19900.00
0005434876869	14546	Comfort	19900.00
0005434937847	14546	Comfort	19900.00
0005432799026	14546	Comfort	19900.00
0005434876802	14546	Comfort	19900.00
0005435125740	14546	Comfort	19900.00
0005432611650	14546	Comfort	19900.00
0005434426198	14546	Comfort	19900.00
0005434937878	14546	Comfort	19900.00
0005435125789	14546	Economy	11700.00
0005434426145	14546	Economy	11700.00
0005434876765	14546	Economy	11700.00
0005435125809	14546	Economy	11700.00
0005432798999	14546	Economy	11700.00
0005434937862	14546	Economy	11700.00
0005434876914	14546	Economy	11700.00
0005435902596	14546	Economy	11700.00
0005435902584	14546	Economy	11700.00
0005434877014	14546	Economy	11700.00
0005434937953	14546	Economy	11700.00
0005434876891	14546	Economy	11700.00
0005435625877	14546	Economy	11700.00
0005434876584	14546	Economy	11700.00
0005434937879	14546	Economy	11700.00
0005435902601	14546	Economy	11700.00
0005434876885	14546	Economy	11700.00
0005432799152	14546	Economy	11700.00
0005434426220	14546	Economy	11700.00
0005432799202	14546	Economy	11700.00
0005435902599	14546	Economy	11700.00
0005432799065	14546	Economy	11700.00
0005435625860	14546	Economy	11700.00
0005432799031	14546	Economy	11700.00
0005432611647	14546	Economy	11700.00
0005434426126	14546	Economy	11700.00
0005435125686	14546	Economy	11700.00
0005434876766	14546	Economy	11700.00
0005435125683	14546	Economy	11700.00
0005435914693	14546	Economy	11700.00
0005434877027	14546	Economy	11700.00
0005435902598	14546	Economy	11700.00
0005432059491	14546	Economy	11700.00
0005435902602	14546	Economy	11700.00
0005434876934	14546	Economy	12800.00
0005434937835	14546	Economy	11700.00
0005434876785	14546	Economy	12800.00
0005434426134	14546	Economy	11700.00
0005434877007	14546	Economy	11700.00
0005434876946	14546	Economy	11700.00
0005432607502	14546	Economy	11700.00
0005434426227	14546	Economy	11700.00
0005435125665	14546	Economy	11700.00
0005434937834	14546	Economy	11700.00
0005434876768	14546	Economy	11700.00
0005434937867	14546	Economy	11700.00
0005434876879	14546	Economy	11700.00
0005434876619	14546	Economy	11700.00
0005434937916	14546	Economy	11700.00
0005435902588	14546	Economy	11700.00
0005434876724	14546	Economy	11700.00
0005434937840	14546	Economy	11700.00
0005434876937	14546	Economy	11700.00
0005435913914	14546	Economy	11700.00
0005434937896	14546	Economy	11700.00
0005435913919	14546	Economy	11700.00
0005435125800	14546	Economy	11700.00
0005435913916	14546	Economy	11700.00
0005435902590	14546	Economy	11700.00
0005434426239	14546	Economy	11700.00
0005435125846	14546	Economy	11700.00
0005434876901	14546	Economy	11700.00
0005434876896	14546	Economy	11700.00
0005432799066	14546	Economy	11700.00
0005435125847	14546	Economy	11700.00
0005434876967	14546	Economy	11700.00
0005434876746	14546	Economy	11700.00
0005434937841	14546	Economy	11700.00
0005432799025	14546	Economy	11700.00
0005432607517	14546	Economy	11700.00
0005434876878	14546	Economy	11700.00
0005434937848	14546	Economy	11700.00
0005434426138	14546	Economy	11700.00
0005435125738	14546	Economy	11700.00
0005432059492	14546	Economy	11700.00
0005435125720	14546	Economy	11700.00
0005435902595	14546	Economy	11700.00
0005432059493	14546	Economy	11700.00
0005435125651	14546	Economy	11700.00
0005434876793	14546	Economy	11700.00
0005435625898	14546	Economy	11700.00
0005435125699	14546	Economy	11700.00
0005432799064	14546	Economy	11700.00
0005434876941	14546	Economy	11700.00
0005434426135	14546	Economy	11700.00
0005435902591	14546	Economy	11700.00
0005434876745	14546	Economy	11700.00
0005435125737	14546	Economy	11700.00
0005432799139	14546	Economy	11700.00
0005432799203	14546	Economy	11700.00
0005435913915	14546	Economy	11700.00
0005435902593	14546	Economy	11700.00
0005435841817	14546	Economy	11700.00
0005434877018	14546	Economy	11700.00
0005434876860	14546	Economy	11700.00
0005434876912	14546	Economy	11700.00
0005432799072	14546	Economy	11700.00
0005434876913	14546	Economy	11700.00
0005434877143	14546	Economy	11700.00
0005434876796	14546	Economy	11700.00
0005432798994	14546	Economy	11700.00
0005435125723	14546	Economy	11700.00
0005435125756	14546	Economy	11700.00
0005434876862	14546	Economy	11700.00
0005435125757	14546	Economy	11700.00
0005435125664	14546	Economy	11700.00
0005435125817	14546	Economy	11700.00
0005434426143	14546	Economy	11700.00
0005435125788	14546	Economy	11700.00
0005434426155	14546	Economy	11700.00
0005434876921	14546	Economy	11700.00
0005434876685	14546	Economy	11700.00
0005432798984	14546	Economy	11700.00
0005432799024	14546	Economy	11700.00
0005434876567	14546	Economy	11700.00
0005435125792	14546	Economy	11700.00
0005435625886	14546	Economy	12800.00
0005434876877	14546	Economy	11700.00
0005432798962	14546	Economy	12800.00
0005435625902	14546	Economy	12800.00
0005434876968	14546	Economy	12800.00
0005435902597	14546	Economy	12800.00
0005434937795	14546	Economy	12800.00
0005434937824	14546	Economy	11700.00
0005434876664	14546	Economy	11700.00
0005435902592	14546	Economy	11700.00
0005434426144	14546	Economy	11700.00
0005435902589	14546	Economy	11700.00
0005435913921	14546	Economy	11700.00
0005434937861	14546	Economy	11700.00
0005434876935	14546	Economy	11700.00
0005435125739	14546	Economy	11700.00
0005434876868	14546	Economy	11700.00
0005434876958	14546	Economy	11700.00
0005432799048	14546	Economy	11700.00
0005434876861	14546	Economy	11700.00
0005434876610	14546	Economy	11700.00
0005432611645	14546	Economy	11700.00
0005435625878	14546	Economy	11700.00
0005435902585	14546	Economy	11700.00
0005434876677	14546	Economy	11700.00
0005435625869	14546	Economy	11700.00
0005434876792	14546	Economy	11700.00
0005434426165	14546	Economy	11700.00
0005434876996	14546	Economy	11700.00
0005434426093	14546	Economy	11700.00
0005434876697	14546	Economy	11700.00
0005435125766	14546	Economy	11700.00
0005435625889	14546	Economy	11700.00
0005435913917	14546	Economy	11700.00
0005432799123	14546	Economy	11700.00
0005434876959	14546	Economy	11700.00
0005434876652	14546	Economy	11700.00
0005435902594	14546	Economy	11700.00
0005435125884	14546	Economy	11700.00
0005434876801	14546	Economy	11700.00
0005434876940	14546	Economy	11700.00
0005434876725	14546	Economy	11700.00
0005432607515	14546	Economy	11700.00
0005435125842	14546	Economy	11700.00
0005434876657	14546	Economy	11700.00
0005435902586	14546	Economy	11700.00
0005435125758	14546	Economy	11700.00
0005434937932	14546	Economy	11700.00
0005434876569	14546	Economy	11700.00
0005432607500	14546	Economy	11700.00
0005434876939	14546	Economy	11700.00
0005434876690	14546	Economy	11700.00
0005435125724	14546	Economy	11700.00
0005434876938	14546	Economy	11700.00
0005435913918	14546	Economy	11700.00
0005434937931	14546	Economy	11700.00
0005434876735	14546	Economy	11700.00
0005435125650	14546	Economy	11700.00
0005435625861	14546	Economy	11700.00
0005434876836	14546	Economy	11700.00
0005432799054	14546	Economy	11700.00
0005435125700	14546	Economy	11700.00
0005434876777	14546	Economy	11700.00
0005435125885	14546	Economy	11700.00
0005432799120	14546	Economy	11700.00
0005434426088	14546	Economy	11700.00
0005434877129	14546	Economy	11700.00
0005434312305	3637	Economy	16300.00
0005435889790	3637	Economy	14800.00
0005434325574	3637	Economy	14800.00
0005435889832	3637	Economy	14800.00
0005434325580	3637	Economy	14800.00
0005434325576	3637	Economy	14800.00
0005435889788	3637	Economy	14800.00
0005434325581	3637	Economy	14800.00
0005434325573	3637	Economy	14800.00
0005435889806	3637	Economy	14800.00
0005435889824	3637	Economy	14800.00
0005434325578	3637	Economy	14800.00
0005435889800	3637	Economy	14800.00
0005434325583	3637	Economy	14800.00
0005435889791	3637	Economy	14800.00
0005434325584	3637	Economy	14800.00
0005435889789	3637	Economy	14800.00
0005434325582	3637	Economy	14800.00
0005434325579	3637	Economy	14800.00
0005434325577	3637	Economy	14800.00
0005434312306	3637	Economy	14800.00
0005434325575	3637	Economy	14800.00
0005434312308	3637	Economy	14800.00
0005434312307	3637	Economy	14800.00
0005435889860	15647	Economy	16300.00
0005435889856	15647	Economy	14800.00
0005434325491	15647	Economy	14800.00
0005435889861	15647	Economy	14800.00
0005435889859	15647	Economy	14800.00
0005434325522	15647	Economy	14800.00
0005435889858	15647	Economy	14800.00
0005434325475	15647	Economy	14800.00
0005435889862	15647	Economy	14800.00
0005435889857	15647	Economy	14800.00
0005435957605	670	Economy	4500.00
0005433420259	670	Economy	4500.00
0005433420286	670	Economy	4100.00
0005435957613	670	Economy	4100.00
0005433420291	670	Economy	4100.00
0005433420292	670	Economy	4100.00
0005433420260	670	Economy	4100.00
0005435957615	670	Economy	4100.00
0005435957617	670	Economy	4100.00
0005435957620	670	Economy	4100.00
0005433420290	670	Economy	4100.00
0005435957609	670	Economy	4100.00
0005435957618	670	Economy	4100.00
0005433420261	670	Economy	4100.00
0005435957616	670	Economy	4100.00
0005435957611	670	Economy	4100.00
0005433420296	670	Economy	4100.00
0005433420264	670	Economy	4100.00
0005435957614	670	Economy	4100.00
0005435957619	670	Economy	4100.00
0005435957612	670	Economy	4100.00
0005435957607	670	Economy	4100.00
0005435957606	670	Economy	4100.00
0005433420295	670	Economy	4100.00
0005433420282	670	Economy	4100.00
0005433420254	670	Economy	4100.00
0005435957608	670	Economy	4100.00
0005433420281	670	Economy	4100.00
0005435957610	670	Economy	4100.00
0005435957490	15194	Economy	4500.00
0005435957506	15194	Economy	4100.00
0005435957446	15194	Economy	4500.00
0005433420349	15194	Economy	4100.00
0005435957440	15194	Economy	4100.00
0005433420347	15194	Economy	4100.00
0005435957526	15194	Economy	4100.00
0005435957461	15194	Economy	4100.00
0005435957497	15194	Economy	4100.00
0005433420346	15194	Economy	4100.00
0005435957510	15194	Economy	4100.00
0005435957524	15194	Economy	4100.00
0005435957489	15194	Economy	4100.00
0005435957462	15194	Economy	4100.00
0005433420350	15194	Economy	4100.00
0005433420351	15194	Economy	4100.00
0005435957445	15194	Economy	4100.00
0005435957511	15194	Economy	4100.00
0005433420352	15194	Economy	4100.00
0005433420354	15194	Economy	4100.00
0005433420353	15194	Economy	4100.00
0005435957535	15194	Economy	4100.00
0005433420348	15194	Economy	4100.00
0005435957496	15194	Economy	4100.00
0005435221038	27270	Economy	28100.00
0005435219173	27270	Economy	28100.00
0005435219168	27270	Economy	25500.00
0005435221040	27270	Economy	25500.00
0005435219172	27270	Economy	25500.00
0005435221036	27270	Economy	25500.00
0005435221039	27270	Economy	25500.00
0005435221037	27270	Economy	25500.00
0005435219171	27270	Economy	25500.00
0005435219165	27270	Economy	25500.00
0005435216560	27270	Economy	25500.00
0005435629398	8878	Economy	10400.00
0005435629384	16004	Economy	10400.00
0005434247132	16004	Economy	10400.00
0005434247130	16004	Economy	10400.00
0005435629385	16004	Economy	10400.00
0005434247131	16004	Economy	10400.00
0005435629389	16004	Economy	10400.00
0005435933395	4436	Economy	13400.00
0005435163200	4436	Economy	13400.00
0005435163199	4436	Economy	13400.00
0005435163194	4436	Economy	12200.00
0005435163204	4436	Economy	12200.00
0005435933397	4436	Economy	12200.00
0005435163195	4436	Economy	12200.00
0005435163202	4436	Economy	12200.00
0005435163196	4436	Economy	12200.00
0005435163203	4436	Economy	12200.00
0005435163198	4436	Economy	12200.00
0005435163201	4436	Economy	12200.00
0005435933396	4436	Economy	12200.00
0005435163197	4436	Economy	12200.00
0005435797385	2850	Business	12600.00
0005433404693	2850	Business	12600.00
0005435797386	2850	Business	12600.00
0005435797396	2850	Economy	4200.00
0005433404690	2850	Economy	4200.00
0005435797392	2850	Economy	4600.00
0005435797393	2850	Economy	4600.00
0005435797391	2850	Economy	4200.00
0005433404689	2850	Economy	4200.00
0005433404735	2850	Economy	4200.00
0005435797387	2850	Economy	4200.00
0005435797395	2850	Economy	4200.00
0005435797389	2850	Economy	4200.00
0005435797383	2850	Economy	4200.00
0005433404713	2850	Economy	4200.00
0005435797390	2850	Economy	4200.00
0005435797394	2850	Economy	4200.00
0005435797388	2850	Economy	4200.00
0005433404714	2850	Economy	4200.00
0005435797384	2850	Economy	4200.00
0005435797297	29313	Business	12600.00
0005433404764	29313	Business	12600.00
0005435797256	29313	Economy	4200.00
0005435797285	29313	Economy	4200.00
0005433404760	29313	Economy	4200.00
0005433404762	29313	Economy	4200.00
0005433404766	29313	Economy	4200.00
0005433404767	29313	Economy	4200.00
0005433404761	29313	Economy	4200.00
0005435797287	29313	Economy	4200.00
0005435797330	29313	Economy	4200.00
0005435797305	29313	Economy	4200.00
0005433404763	29313	Economy	4200.00
0005435797289	29313	Economy	4200.00
0005435797288	29313	Economy	4200.00
0005435797284	29313	Economy	4200.00
0005435797333	29313	Economy	4200.00
0005435797298	29313	Economy	4200.00
0005435797293	29313	Economy	4200.00
0005433404765	29313	Economy	4200.00
0005435376325	5849	Economy	6800.00
0005434947967	5850	Economy	6800.00
0005434947971	5850	Economy	6800.00
0005434947969	5850	Economy	6800.00
0005434947964	5850	Economy	6800.00
0005434947972	5850	Economy	6800.00
0005434947973	5850	Economy	6800.00
0005434947968	5850	Economy	6800.00
0005434947966	5850	Economy	6800.00
0005434947970	5850	Economy	6800.00
0005434947965	5850	Economy	6800.00
0005435376335	16383	Economy	6800.00
0005434947920	16383	Economy	6800.00
0005434947914	16383	Economy	6800.00
0005434947902	16383	Economy	6800.00
0005434947903	16383	Economy	6800.00
0005434947921	16383	Economy	6800.00
0005434947922	16383	Economy	6800.00
0005434947932	16383	Economy	6800.00
0005434947888	16383	Economy	6800.00
0005434947912	16383	Economy	6800.00
0005434947911	16383	Economy	6800.00
0005434947927	16383	Economy	6800.00
0005433960504	6892	Business	21400.00
0005433960519	6892	Business	21400.00
0005433960511	6892	Business	21400.00
0005433960561	6892	Business	21400.00
0005433960537	6892	Business	21400.00
0005433960517	6892	Business	21400.00
0005433960500	6892	Business	21400.00
0005433960513	6892	Business	21400.00
0005433960542	6892	Business	21400.00
0005433960530	6892	Economy	7100.00
0005433960522	6892	Economy	7100.00
0005433960518	6892	Economy	7100.00
0005433960557	6892	Economy	7100.00
0005433960507	6892	Economy	7100.00
0005433960503	6892	Economy	7100.00
0005433960565	6892	Economy	7100.00
0005433960528	6892	Economy	7800.00
0005433960546	6892	Economy	7800.00
0005433960566	6892	Economy	7800.00
0005433960529	6892	Economy	7100.00
0005433960514	6892	Economy	7100.00
0005433960505	6892	Economy	7100.00
0005433960558	6892	Economy	7100.00
0005433960569	6892	Economy	7100.00
0005433960501	6892	Economy	7100.00
0005433960525	6892	Economy	7100.00
0005433960499	6892	Economy	7100.00
0005433960520	6892	Economy	7100.00
0005433960531	6892	Economy	7100.00
0005433960556	6892	Economy	7100.00
0005433960524	6892	Economy	7100.00
0005433960560	6892	Economy	7100.00
0005433960510	6892	Economy	7100.00
0005433960543	6892	Economy	7100.00
0005433960536	6892	Economy	7100.00
0005433960552	6892	Economy	7100.00
0005433960571	6892	Economy	7100.00
0005433960540	6892	Economy	7100.00
0005433960512	6892	Economy	7100.00
0005433960544	6892	Economy	7100.00
0005433960568	6892	Economy	7100.00
0005433960515	6892	Economy	7100.00
0005433960547	6892	Economy	7100.00
0005433960521	6892	Economy	7100.00
0005433960563	6892	Economy	7100.00
0005433960534	6892	Economy	7100.00
0005433960548	6892	Economy	7100.00
0005433960559	6892	Economy	7100.00
0005433960527	6892	Economy	7100.00
0005433960516	6892	Economy	7100.00
0005433960567	6892	Economy	7100.00
0005433960523	6892	Economy	7100.00
0005433960553	6892	Economy	7100.00
0005433960539	6892	Economy	7100.00
0005433960506	6892	Economy	7100.00
0005433960550	6892	Economy	7100.00
0005433960562	6892	Economy	7100.00
0005433960502	6892	Economy	7100.00
0005433960570	6892	Economy	7100.00
0005433960554	6892	Economy	7100.00
0005433960509	6892	Economy	7100.00
0005433960564	6892	Economy	7100.00
0005433960555	6892	Economy	7100.00
0005433960551	6892	Economy	7100.00
0005433960508	6892	Economy	7100.00
0005433960533	6892	Economy	7100.00
0005433960549	6892	Economy	7100.00
0005433960532	6892	Economy	7100.00
0005433960526	6892	Economy	7100.00
0005433960541	6892	Economy	7100.00
0005433960545	6892	Economy	7100.00
0005433960538	6892	Economy	7100.00
0005433960535	6892	Economy	7100.00
0005433959950	25763	Business	21400.00
0005433959874	25763	Business	21400.00
0005433959873	25763	Business	21400.00
0005433959934	25763	Economy	7800.00
0005433959897	25763	Economy	7800.00
0005433959895	25763	Economy	7100.00
0005433959907	25763	Economy	7100.00
0005433959960	25763	Economy	7100.00
0005433959894	25763	Economy	7100.00
0005433959947	25763	Economy	7100.00
0005433959933	25763	Economy	7100.00
0005433959869	25763	Economy	7100.00
0005433959963	25763	Economy	7100.00
0005433959952	25763	Economy	7100.00
0005433959924	25763	Economy	7100.00
0005433959871	25763	Economy	7100.00
0005433959900	25763	Economy	7100.00
0005433959893	25763	Economy	7100.00
0005433959914	25763	Economy	7100.00
0005433959872	25763	Economy	7100.00
0005433959913	25763	Economy	7100.00
0005433959943	25763	Economy	7100.00
0005433959959	25763	Economy	7100.00
0005433959904	25763	Economy	7100.00
0005433959944	25763	Economy	7100.00
0005435082657	24514	Economy	3900.00
0005435082651	24514	Economy	3900.00
0005435082658	24514	Economy	3900.00
0005435082664	24514	Economy	3900.00
0005435082675	24514	Economy	3900.00
0005435082659	24514	Economy	3900.00
0005435082666	24514	Economy	3900.00
0005435082669	24514	Economy	3900.00
0005435082665	24514	Economy	3900.00
0005435082732	26093	Economy	3900.00
0005435082729	26093	Economy	3900.00
0005435082728	26093	Economy	3900.00
0005435082735	26093	Economy	3900.00
0005435082733	26093	Economy	3900.00
0005435082734	26093	Economy	3900.00
0005435082731	26093	Economy	3900.00
0005435082730	26093	Economy	3900.00
0005434244794	5153	Business	18000.00
0005434244792	5153	Business	18000.00
0005432166882	5153	Business	18000.00
0005434244801	5153	Business	18000.00
0005434244789	5153	Business	18000.00
0005434244802	5153	Business	18000.00
0005434244786	5153	Business	18000.00
0005435286552	5153	Business	18000.00
0005434244807	5153	Economy	6600.00
0005432166880	5153	Economy	6000.00
0005434244809	5153	Economy	6000.00
0005434244796	5153	Economy	6000.00
0005432166881	5153	Economy	6000.00
0005434244814	5153	Economy	6000.00
0005434244805	5153	Economy	6000.00
0005434244811	5153	Economy	6000.00
0005434244795	5153	Economy	6000.00
0005434244798	5153	Economy	6000.00
0005433534469	5153	Economy	6000.00
0005434244812	5153	Economy	6000.00
0005434244806	5153	Economy	6600.00
0005434244788	5153	Economy	6000.00
0005434244797	5153	Economy	6000.00
0005434244803	5153	Economy	6000.00
0005434244810	5153	Economy	6000.00
0005434244815	5153	Economy	6000.00
0005434244804	5153	Economy	6000.00
0005434244800	5153	Economy	6000.00
0005434244799	5153	Economy	6000.00
0005434244790	5153	Economy	6000.00
0005433534460	5153	Economy	6000.00
0005434244791	5153	Economy	6000.00
0005434244813	5153	Economy	6000.00
0005434244808	5153	Economy	6000.00
0005434244793	5153	Economy	6000.00
0005434244787	5153	Economy	6000.00
0005433614245	5152	Business	18000.00
0005433614281	5152	Business	18000.00
0005432105283	5152	Business	18000.00
0005432105285	5152	Business	18000.00
0005432105270	5152	Business	18000.00
0005432105264	5152	Business	18000.00
0005432105262	5152	Business	18000.00
0005433784716	5152	Business	18000.00
0005433614263	5152	Business	18000.00
0005433614254	5152	Business	18000.00
0005433784709	5152	Business	18000.00
0005432105261	5152	Business	18000.00
0005433784733	5152	Business	18000.00
0005432105267	5152	Business	18000.00
0005433614244	5152	Business	18000.00
0005433614231	5152	Business	18000.00
0005433784714	5152	Business	18000.00
0005433784702	5152	Business	18000.00
0005433614250	5152	Business	18000.00
0005433614221	5152	Business	18000.00
0005433614247	5152	Business	18000.00
0005433614255	5152	Business	18000.00
0005432105281	5152	Business	18000.00
0005432665262	5152	Business	18000.00
0005433784723	5152	Business	18000.00
0005433784718	5152	Business	18000.00
0005432105292	5152	Business	18000.00
0005433784730	5152	Business	18000.00
0005433784729	5152	Economy	6600.00
0005433784708	5152	Economy	6600.00
0005433784719	5152	Economy	6600.00
0005432105277	5152	Economy	6600.00
0005433614248	5152	Economy	6600.00
0005433784707	5152	Economy	6600.00
0005433614232	5152	Economy	6000.00
0005433614237	5152	Economy	6000.00
0005433614212	5152	Economy	6000.00
0005433784724	5152	Economy	6000.00
0005433614273	5152	Economy	6000.00
0005433784726	5152	Economy	6000.00
0005433614258	5152	Economy	6000.00
0005433784734	5152	Economy	6000.00
0005433614235	5152	Economy	6000.00
0005433614271	5152	Economy	6000.00
0005432105260	5152	Economy	6000.00
0005432667440	5152	Economy	6000.00
0005433614276	5152	Economy	6000.00
0005433784737	5152	Economy	6000.00
0005432105288	5152	Economy	6000.00
0005433614277	5152	Economy	6000.00
0005432105257	5152	Economy	6000.00
0005433614266	5152	Economy	6000.00
0005432145099	5152	Economy	6000.00
0005432665261	5152	Economy	6000.00
0005433784731	5152	Economy	6000.00
0005433784727	5152	Economy	6000.00
0005432105251	5152	Economy	6000.00
0005432105275	5152	Economy	6000.00
0005432666375	5152	Economy	6000.00
0005433614217	5152	Economy	6000.00
0005433614264	5152	Economy	6000.00
0005433614219	5152	Economy	6000.00
0005433614226	5152	Economy	6000.00
0005433784704	5152	Economy	6000.00
0005433614213	5152	Economy	6000.00
0005432105273	5152	Economy	6000.00
0005432105282	5152	Economy	6000.00
0005433614242	5152	Economy	6000.00
0005433614239	5152	Economy	6000.00
0005433614270	5152	Economy	6000.00
0005432105272	5152	Economy	6000.00
0005432105254	5152	Economy	6000.00
0005433784736	5152	Economy	6000.00
0005433614222	5152	Economy	6000.00
0005432105287	5152	Economy	6000.00
0005432105266	5152	Economy	6000.00
0005433614233	5152	Economy	6000.00
0005433784703	5152	Economy	6000.00
0005432105290	5152	Economy	6000.00
0005432105286	5152	Economy	6000.00
0005433614267	5152	Economy	6000.00
0005432666376	5152	Economy	6000.00
0005433784701	5152	Economy	6000.00
0005433614261	5152	Economy	6000.00
0005433784722	5152	Economy	6000.00
0005432105293	5152	Economy	6000.00
0005433614268	5152	Economy	6000.00
0005432105297	5152	Economy	6000.00
0005432105271	5152	Economy	6000.00
0005433784715	5152	Economy	6000.00
0005432105263	5152	Economy	6000.00
0005432105265	5152	Economy	6000.00
0005432105295	5152	Economy	6000.00
0005433614253	5152	Economy	6600.00
0005432105253	5152	Economy	6000.00
0005433784732	5152	Economy	6600.00
0005433614234	5152	Economy	6600.00
0005433784735	5152	Economy	6600.00
0005432105294	5152	Economy	6600.00
0005433614210	5152	Economy	6000.00
0005433614274	5152	Economy	6000.00
0005432105268	5152	Economy	6000.00
0005433614238	5152	Economy	6000.00
0005433614269	5152	Economy	6000.00
0005433784700	5152	Economy	6600.00
0005432105250	5152	Economy	6000.00
0005433614251	5152	Economy	6000.00
0005433614282	5152	Economy	6000.00
0005433614265	5152	Economy	6000.00
0005432105279	5152	Economy	6000.00
0005433784705	5152	Economy	6000.00
0005433614283	5152	Economy	6000.00
0005433614214	5152	Economy	6000.00
0005433614275	5152	Economy	6000.00
0005432105298	5152	Economy	6000.00
0005433614260	5152	Economy	6000.00
0005433614278	5152	Economy	6000.00
0005433614215	5152	Economy	6000.00
0005433614259	5152	Economy	6000.00
0005433614230	5152	Economy	6000.00
0005433614246	5152	Economy	6000.00
0005433784717	5152	Economy	6000.00
0005433614229	5152	Economy	6000.00
0005433784713	5152	Economy	6000.00
0005433614240	5152	Economy	6000.00
0005433784706	5152	Economy	6000.00
0005432105252	5152	Economy	6000.00
0005432105284	5152	Economy	6000.00
0005432105255	5152	Economy	6000.00
0005433784710	5152	Economy	6000.00
0005433614249	5152	Economy	6000.00
0005432105291	5152	Economy	6000.00
0005433614272	5152	Economy	6000.00
0005433614243	5152	Economy	6000.00
0005433614236	5152	Economy	6000.00
0005432105278	5152	Economy	6000.00
0005433614216	5152	Economy	6000.00
0005433614228	5152	Economy	6000.00
0005433784725	5152	Economy	6000.00
0005433784720	5152	Economy	6000.00
0005432105256	5152	Economy	6000.00
0005432105274	5152	Economy	6000.00
0005433614211	5152	Economy	6000.00
0005432105289	5152	Economy	6000.00
0005433784711	5152	Economy	6000.00
0005433614224	5152	Economy	6000.00
0005432105269	5152	Economy	6000.00
0005433614220	5152	Economy	6000.00
0005433614225	5152	Economy	6000.00
0005433784738	5152	Economy	6000.00
0005433614252	5152	Economy	6000.00
0005432105276	5152	Economy	6000.00
0005433614262	5152	Economy	6000.00
0005433614256	5152	Economy	6000.00
0005432105259	5152	Economy	6000.00
0005433784721	5152	Economy	6000.00
0005433614227	5152	Economy	6000.00
0005433614218	5152	Economy	6000.00
0005433784712	5152	Economy	6000.00
0005432105258	5152	Economy	6000.00
0005433614279	5152	Economy	6000.00
0005433784728	5152	Economy	6000.00
0005432105280	5152	Economy	6000.00
0005432667441	5152	Economy	6000.00
0005433614257	5152	Economy	6000.00
0005433614280	5152	Economy	6000.00
0005433614241	5152	Economy	6000.00
0005433614284	5152	Economy	6000.00
0005433614223	5152	Economy	6000.00
0005432105296	5152	Economy	6000.00
0005434264970	5150	Business	18000.00
0005434312293	5150	Business	18000.00
0005434149656	5150	Business	18000.00
0005432335824	5150	Business	18000.00
0005432335867	5150	Business	18000.00
0005432335917	5150	Business	18000.00
0005434149665	5150	Business	18000.00
0005434229224	5150	Business	18000.00
0005434264976	5150	Business	18000.00
0005434149664	5150	Business	18000.00
0005434229236	5150	Business	18000.00
0005435269631	5150	Business	18000.00
0005435006664	5150	Business	18000.00
0005434149654	5150	Business	18000.00
0005434229242	5150	Business	18000.00
0005434229223	5150	Business	18000.00
0005434264983	5150	Business	18000.00
0005435006685	5150	Business	18000.00
0005435006651	5150	Business	18000.00
0005434312295	5150	Business	18000.00
0005432335918	5150	Economy	6600.00
0005434264985	5150	Economy	6600.00
0005434149660	5150	Economy	6600.00
0005434173495	5150	Economy	6600.00
0005435006646	5150	Economy	6600.00
0005434264972	5150	Economy	6000.00
0005434229241	5150	Economy	6000.00
0005434264982	5150	Economy	6000.00
0005432335894	5150	Economy	6000.00
0005434149657	5150	Economy	6000.00
0005432335834	5150	Economy	6000.00
0005434229227	5150	Economy	6000.00
0005434264978	5150	Economy	6000.00
0005434229233	5150	Economy	6000.00
0005433688781	5150	Economy	6000.00
0005433688777	5150	Economy	6000.00
0005434264990	5150	Economy	6000.00
0005434264968	5150	Economy	6000.00
0005435006675	5150	Economy	6000.00
0005433688779	5150	Economy	6000.00
0005434264974	5150	Economy	6000.00
0005434229220	5150	Economy	6000.00
0005434229226	5150	Economy	6000.00
0005434264987	5150	Economy	6000.00
0005433688778	5150	Economy	6000.00
0005435006650	5150	Economy	6000.00
0005434311188	5150	Economy	6000.00
0005435269621	5150	Economy	6000.00
0005434311184	5150	Economy	6000.00
0005435006666	5150	Economy	6000.00
0005434264971	5150	Economy	6000.00
0005434149661	5150	Economy	6000.00
0005435269632	5150	Economy	6000.00
0005434264973	5150	Economy	6000.00
0005434264984	5150	Economy	6000.00
0005435006672	5150	Economy	6000.00
0005435006649	5150	Economy	6000.00
0005432335835	5150	Economy	6000.00
0005434173493	5150	Economy	6000.00
0005432335881	5150	Economy	6000.00
0005434229235	5150	Economy	6000.00
0005434229231	5150	Economy	6600.00
0005434173497	5150	Economy	6600.00
0005434149663	5150	Economy	6600.00
0005432335848	5150	Economy	6600.00
0005434229225	5150	Economy	6000.00
0005434264989	5150	Economy	6000.00
0005434229239	5150	Economy	6000.00
0005432335893	5150	Economy	6000.00
0005432335841	5150	Economy	6000.00
0005434264977	5150	Economy	6000.00
0005434229240	5150	Economy	6000.00
0005433815314	5150	Economy	6000.00
0005434264986	5150	Economy	6000.00
0005434311190	5150	Economy	6000.00
0005434311183	5150	Economy	6000.00
0005432335874	5150	Economy	6000.00
0005434264979	5150	Economy	6000.00
0005434149652	5150	Economy	6000.00
0005434229221	5150	Economy	6000.00
0005433688780	5150	Economy	6000.00
0005434149658	5150	Economy	6000.00
0005434229238	5150	Economy	6000.00
0005434264980	5150	Economy	6000.00
0005434264966	5150	Economy	6000.00
0005434229229	5150	Economy	6000.00
0005435006701	5150	Economy	6000.00
0005434264981	5150	Economy	6000.00
0005435006724	5150	Economy	6000.00
0005434264975	5150	Economy	6000.00
0005434311189	5150	Economy	6000.00
0005434149662	5150	Economy	6000.00
0005435006754	5150	Economy	6000.00
0005435006702	5150	Economy	6000.00
0005434149653	5150	Economy	6000.00
0005435006645	5150	Economy	6000.00
0005434149655	5150	Economy	6000.00
0005434264969	5150	Economy	6000.00
0005432335847	5150	Economy	6000.00
0005434229222	5150	Economy	6000.00
0005434264991	5150	Economy	6000.00
0005432335868	5150	Economy	6000.00
0005434229232	5150	Economy	6000.00
0005434173494	5150	Economy	6000.00
0005434229228	5150	Economy	6000.00
0005434264988	5150	Economy	6000.00
0005434264967	5150	Economy	6000.00
0005435006764	5150	Economy	6000.00
0005434173496	5150	Economy	6000.00
0005434149659	5150	Economy	6000.00
0005434229230	5150	Economy	6000.00
0005434229237	5150	Economy	6000.00
0005432335836	5150	Economy	6000.00
0005434229234	5150	Economy	6000.00
0005432335822	5150	Economy	6000.00
0005433784389	8365	Business	18000.00
0005434244482	8365	Business	18000.00
0005433784388	8365	Business	18000.00
0005434244592	8365	Business	18000.00
0005433784473	8365	Business	18000.00
0005434244515	8365	Business	18000.00
0005433784400	8365	Business	18000.00
0005434244705	8365	Business	18000.00
0005433784386	8365	Business	18000.00
0005434244526	8365	Business	18000.00
0005434244531	8365	Business	18000.00
0005434244529	8365	Business	18000.00
0005434244479	8365	Business	18000.00
0005433784333	8365	Business	18000.00
0005434244594	8365	Business	18000.00
0005434244687	8365	Business	18000.00
0005433784412	8365	Economy	6600.00
0005434244523	8365	Economy	6600.00
0005434244682	8365	Economy	6000.00
0005435269702	8365	Economy	6000.00
0005435269700	8365	Economy	6000.00
0005433784536	8365	Economy	6000.00
0005434244496	8365	Economy	6000.00
0005433784424	8365	Economy	6000.00
0005433784355	8365	Economy	6000.00
0005434244626	8365	Economy	6000.00
0005434244547	8365	Economy	6000.00
0005434244681	8365	Economy	6000.00
0005435269697	8365	Economy	6000.00
0005433784359	8365	Economy	6000.00
0005434244593	8365	Economy	6000.00
0005433784344	8365	Economy	6000.00
0005433784352	8365	Economy	6000.00
0005432666363	8365	Economy	6000.00
0005433784543	8365	Economy	6000.00
0005434244622	8365	Economy	6000.00
0005433784364	8365	Economy	6000.00
0005433784395	8365	Economy	6000.00
0005433784380	8365	Economy	6000.00
0005434244586	8365	Economy	6000.00
0005434244562	8365	Economy	6000.00
0005433784358	8365	Economy	6000.00
0005432666355	8365	Economy	6000.00
0005434244579	8365	Economy	6000.00
0005434244598	8365	Economy	6000.00
0005433784396	8365	Economy	6000.00
0005433784434	8365	Economy	6000.00
0005434244555	8365	Economy	6000.00
0005433784299	8365	Economy	6000.00
0005433784464	8365	Economy	6600.00
0005433784411	8365	Economy	6000.00
0005434244527	8365	Economy	6000.00
0005433784381	8365	Economy	6600.00
0005434244599	8365	Economy	6000.00
0005433784472	8365	Economy	6000.00
0005434244653	8365	Economy	6000.00
0005434244516	8365	Economy	6000.00
0005434244619	8365	Economy	6000.00
0005434244686	8365	Economy	6000.00
0005433784390	8365	Economy	6000.00
0005434244625	8365	Economy	6000.00
0005433784365	8365	Economy	6000.00
0005433784385	8365	Economy	6000.00
0005433784429	8365	Economy	6000.00
0005434244704	8365	Economy	6000.00
0005435269701	8365	Economy	6000.00
0005435269696	8365	Economy	6000.00
0005433784425	8365	Economy	6000.00
0005434244519	8365	Economy	6000.00
0005434244620	8365	Economy	6000.00
0005435269699	8365	Economy	6000.00
0005433784382	8365	Economy	6000.00
0005432666364	8365	Economy	6000.00
0005434244635	8365	Economy	6000.00
0005434244480	8365	Economy	6000.00
0005434244483	8365	Economy	6000.00
0005434244666	8365	Economy	6000.00
0005433784353	8365	Economy	6000.00
0005435269698	8365	Economy	6000.00
0005433784357	8365	Economy	6000.00
0005435269703	8365	Economy	6000.00
0005433784345	8365	Economy	6000.00
0005434244548	8365	Economy	6000.00
0005433613463	8366	Business	18000.00
0005433613475	8366	Business	18000.00
0005433613474	8366	Business	18000.00
0005433613458	8366	Business	18000.00
0005433613628	8366	Business	18000.00
0005433613754	8366	Business	18000.00
0005433613465	8366	Business	18000.00
0005433613717	8366	Business	18000.00
0005433613488	8366	Business	18000.00
0005433613826	8366	Business	18000.00
0005433613654	8366	Economy	6600.00
0005433613556	8366	Economy	6600.00
0005433613707	8366	Economy	6600.00
0005433613784	8366	Economy	6000.00
0005433613542	8366	Economy	6000.00
0005433613578	8366	Economy	6000.00
0005433613550	8366	Economy	6000.00
0005433613513	8366	Economy	6000.00
0005433613470	8366	Economy	6000.00
0005433613769	8366	Economy	6000.00
0005433613634	8366	Economy	6000.00
0005433613541	8366	Economy	6000.00
0005433613450	8366	Economy	6000.00
0005433613449	8366	Economy	6000.00
0005433613659	8366	Economy	6000.00
0005433613639	8366	Economy	6000.00
0005433613446	8366	Economy	6000.00
0005433613411	8366	Economy	6000.00
0005433613753	8366	Economy	6000.00
0005433613425	8366	Economy	6000.00
0005433613473	8366	Economy	6000.00
0005433613669	8366	Economy	6000.00
0005433613783	8366	Economy	6000.00
0005433613800	8366	Economy	6000.00
0005433613422	8366	Economy	6000.00
0005433613821	8366	Economy	6000.00
0005433613549	8366	Economy	6000.00
0005433613709	8366	Economy	6600.00
0005433613595	8366	Economy	6600.00
0005433613543	8366	Economy	6600.00
0005433613751	8366	Economy	6000.00
0005433613476	8366	Economy	6600.00
0005433613557	8366	Economy	6000.00
0005433613759	8366	Economy	6000.00
0005433613402	8366	Economy	6000.00
0005433613396	8366	Economy	6000.00
0005433613733	8366	Economy	6000.00
0005433613445	8366	Economy	6000.00
0005433613489	8366	Economy	6000.00
0005433613403	8366	Economy	6000.00
0005433613579	8366	Economy	6000.00
0005433613501	8366	Economy	6000.00
0005433613760	8366	Economy	6000.00
0005433613640	8366	Economy	6000.00
0005433613577	8366	Economy	6000.00
0005433613514	8366	Economy	6000.00
0005433613400	8366	Economy	6000.00
0005433613528	8366	Economy	6000.00
0005433613576	8366	Economy	6000.00
0005433613401	8366	Economy	6000.00
0005433613718	8366	Economy	6000.00
0005433613788	8366	Economy	6000.00
0005433613679	8366	Economy	6000.00
0005433613641	8366	Economy	6000.00
0005433613635	8366	Economy	6000.00
0005433613457	8366	Economy	6000.00
0005433613682	8366	Economy	6000.00
0005433613708	8366	Economy	6000.00
0005433613500	8366	Economy	6000.00
0005433613481	8366	Economy	6000.00
0005433613560	8366	Economy	6000.00
0005433613404	8366	Economy	6000.00
0005433613681	8366	Economy	6000.00
0005433534484	8367	Business	18000.00
0005434264815	8367	Business	18000.00
0005434229032	8367	Business	18000.00
0005434264837	8367	Business	18000.00
0005432034787	8367	Business	18000.00
0005434229093	8367	Business	18000.00
0005433534485	8367	Business	18000.00
0005434264714	8367	Business	18000.00
0005435286589	8367	Business	18000.00
0005434229080	8367	Business	18000.00
0005434311208	8367	Business	18000.00
0005434149583	8367	Business	18000.00
0005434264743	8367	Business	18000.00
0005434149549	8367	Business	18000.00
0005434228999	8367	Business	18000.00
0005434229014	8367	Business	18000.00
0005433689898	8367	Business	18000.00
0005434264822	8367	Business	18000.00
0005434229079	8367	Business	18000.00
0005434149577	8367	Business	18000.00
0005435006890	8367	Business	18000.00
0005434229015	8367	Business	18000.00
0005434149563	8367	Economy	6600.00
0005435286595	8367	Economy	6600.00
0005434264712	8367	Economy	6600.00
0005432034767	8367	Economy	6000.00
0005435006871	8367	Economy	6000.00
0005435006892	8367	Economy	6000.00
0005432034784	8367	Economy	6000.00
0005435006889	8367	Economy	6000.00
0005435006884	8367	Economy	6000.00
0005432034780	8367	Economy	6000.00
0005433690914	8367	Economy	6000.00
0005435006875	8367	Economy	6000.00
0005432335960	8367	Economy	6000.00
0005434149607	8367	Economy	6000.00
0005434149550	8367	Economy	6000.00
0005434229024	8367	Economy	6000.00
0005432034770	8367	Economy	6000.00
0005432335963	8367	Economy	6000.00
0005432335957	8367	Economy	6000.00
0005434264813	8367	Economy	6000.00
0005435006877	8367	Economy	6000.00
0005432034790	8367	Economy	6000.00
0005433815358	8367	Economy	6000.00
0005434264808	8367	Economy	6000.00
0005432047526	8367	Economy	6000.00
0005433815355	8367	Economy	6000.00
0005434149548	8367	Economy	6000.00
0005433688797	8367	Economy	6000.00
0005432034771	8367	Economy	6000.00
0005432034768	8367	Economy	6000.00
0005432034786	8367	Economy	6000.00
0005435006868	8367	Economy	6000.00
0005434264819	8367	Economy	6000.00
0005434149558	8367	Economy	6000.00
0005432034764	8367	Economy	6000.00
0005434229022	8367	Economy	6000.00
0005434264754	8367	Economy	6000.00
0005433815357	8367	Economy	6000.00
0005435006878	8367	Economy	6000.00
0005435286591	8367	Economy	6000.00
0005432034776	8367	Economy	6000.00
0005433690916	8367	Economy	6000.00
0005435006885	8367	Economy	6000.00
0005432335959	8367	Economy	6000.00
0005434229141	8367	Economy	6000.00
0005435286592	8367	Economy	6000.00
0005434264742	8367	Economy	6000.00
0005435006879	8367	Economy	6000.00
0005432034765	8367	Economy	6000.00
0005435286594	8367	Economy	6000.00
0005435006880	8367	Economy	6000.00
0005434264732	8367	Economy	6000.00
0005434264803	8367	Economy	6000.00
0005432034766	8367	Economy	6000.00
0005435006883	8367	Economy	6000.00
0005435006872	8367	Economy	6000.00
0005435006888	8367	Economy	6000.00
0005432034772	8367	Economy	6000.00
0005433690915	8367	Economy	6600.00
0005435006881	8367	Economy	6600.00
0005434229075	8367	Economy	6600.00
0005434264818	8367	Economy	6600.00
0005434229090	8367	Economy	6600.00
0005432335965	8367	Economy	6000.00
0005434311206	8367	Economy	6000.00
0005434229120	8367	Economy	6000.00
0005434229119	8367	Economy	6000.00
0005432335958	8367	Economy	6000.00
0005432335964	8367	Economy	6000.00
0005432034783	8367	Economy	6000.00
0005435006891	8367	Economy	6000.00
0005434311207	8367	Economy	6000.00
0005435006874	8367	Economy	6000.00
0005432335956	8367	Economy	6000.00
0005432034782	8367	Economy	6000.00
0005435286590	8367	Economy	6000.00
0005432034763	8367	Economy	6000.00
0005434229030	8367	Economy	6000.00
0005434149582	8367	Economy	6000.00
0005432047528	8367	Economy	6000.00
0005434229052	8367	Economy	6000.00
0005433815356	8367	Economy	6000.00
0005435006882	8367	Economy	6000.00
0005434264711	8367	Economy	6000.00
0005432034785	8367	Economy	6000.00
0005432034779	8367	Economy	6000.00
0005432034789	8367	Economy	6000.00
0005435006870	8367	Economy	6000.00
0005432335955	8367	Economy	6000.00
0005432335961	8367	Economy	6000.00
0005434229033	8367	Economy	6000.00
0005435006869	8367	Economy	6000.00
0005435006876	8367	Economy	6000.00
0005432034769	8367	Economy	6000.00
0005432034788	8367	Economy	6000.00
0005432034781	8367	Economy	6000.00
0005435286593	8367	Economy	6000.00
0005434264676	8367	Economy	6000.00
0005432335962	8367	Economy	6000.00
0005432034774	8367	Economy	6000.00
0005432034775	8367	Economy	6000.00
0005434264762	8367	Economy	6000.00
0005434149564	8367	Economy	6000.00
0005434149576	8367	Economy	6000.00
0005434264761	8367	Economy	6000.00
0005434149547	8367	Economy	6000.00
0005434149581	8367	Economy	6000.00
0005432034777	8367	Economy	6000.00
0005432034773	8367	Economy	6000.00
0005434229091	8367	Economy	6000.00
0005432047527	8367	Economy	6000.00
0005432034778	8367	Economy	6000.00
0005432047525	8367	Economy	6000.00
0005435006887	8367	Economy	6000.00
0005432034762	8367	Economy	6000.00
0005434149565	8367	Economy	6000.00
0005435286588	8367	Economy	6000.00
0005432335966	8367	Economy	6000.00
0005434264880	8367	Economy	6000.00
0005433689899	8367	Economy	6000.00
0005434229031	8367	Economy	6000.00
0005435006873	8367	Economy	6000.00
0005435006886	8367	Economy	6000.00
0005434638901	12629	Economy	16200.00
0005434638860	12629	Economy	16200.00
0005434638952	12629	Economy	16200.00
0005434639011	12629	Economy	14800.00
0005433202275	12629	Economy	14800.00
0005434638912	12629	Economy	14800.00
0005434638949	12629	Economy	14800.00
0005434638877	12629	Economy	14800.00
0005434638876	12629	Economy	14800.00
0005434638888	12629	Economy	14800.00
0005433202279	12629	Economy	14800.00
0005434638948	12629	Economy	14800.00
0005434638963	12629	Economy	14800.00
0005434638956	12629	Economy	14800.00
0005433202271	12629	Economy	14800.00
0005434638964	12629	Economy	14800.00
0005433202268	12629	Economy	14800.00
0005433202272	12629	Economy	14800.00
0005434638880	12629	Economy	14800.00
0005434638980	12629	Economy	14800.00
0005434638970	12629	Economy	14800.00
0005434639005	12629	Economy	14800.00
0005433202278	12629	Economy	14800.00
0005433202282	12629	Economy	14800.00
0005433202269	12629	Economy	14800.00
0005434638953	12629	Economy	14800.00
0005433202277	12629	Economy	14800.00
0005433202274	12629	Economy	14800.00
0005434638858	12629	Economy	14800.00
0005433202273	12629	Economy	14800.00
0005434638918	12629	Economy	14800.00
0005434638857	12629	Economy	14800.00
0005434638911	12629	Economy	14800.00
0005434639059	12629	Economy	14800.00
0005433202276	12629	Economy	14800.00
0005433202280	12629	Economy	14800.00
0005434638967	12629	Economy	14800.00
0005434638922	12629	Economy	14800.00
0005433202270	12629	Economy	14800.00
0005433202281	12629	Economy	14800.00
0005434638962	12629	Economy	14800.00
0005434638923	12629	Economy	14800.00
0005434638940	12629	Economy	14800.00
0005434638944	12629	Economy	14800.00
0005434638945	12629	Economy	14800.00
0005434638925	12629	Economy	14800.00
0005432290613	23343	Economy	16200.00
0005434639140	23343	Economy	16200.00
0005434639142	23343	Economy	16200.00
0005434639147	23343	Economy	16200.00
0005434639134	23343	Economy	14800.00
0005434639133	23343	Economy	14800.00
0005434639141	23343	Economy	14800.00
0005434639126	23343	Economy	14800.00
0005434639146	23343	Economy	14800.00
0005434639129	23343	Economy	14800.00
0005433202163	23343	Economy	14800.00
0005434639144	23343	Economy	14800.00
0005434639131	23343	Economy	14800.00
0005434639138	23343	Economy	14800.00
0005434639130	23343	Economy	14800.00
0005432290612	23343	Economy	14800.00
0005434639151	23343	Economy	14800.00
0005433202124	23343	Economy	14800.00
0005434639139	23343	Economy	14800.00
0005434639153	23343	Economy	14800.00
0005434639127	23343	Economy	14800.00
0005434639150	23343	Economy	14800.00
0005432290610	23343	Economy	14800.00
0005433202176	23343	Economy	14800.00
0005432290614	23343	Economy	14800.00
0005434639148	23343	Economy	14800.00
0005434639135	23343	Economy	14800.00
0005434639145	23343	Economy	14800.00
0005434639136	23343	Economy	14800.00
0005434639132	23343	Economy	14800.00
0005433202127	23343	Economy	14800.00
0005434639128	23343	Economy	14800.00
0005433202103	23343	Economy	14800.00
0005434639152	23343	Economy	14800.00
0005433202134	23343	Economy	14800.00
0005432290611	23343	Economy	14800.00
0005434639137	23343	Economy	14800.00
0005434639149	23343	Economy	14800.00
0005433202128	23343	Economy	14800.00
0005434639143	23343	Economy	14800.00
0005432327924	21078	Business	18900.00
0005432327952	21078	Business	18900.00
0005432327900	21078	Business	18900.00
0005432382706	21078	Business	18900.00
0005432382802	21078	Business	18900.00
0005432382592	21078	Business	18900.00
0005432327957	21078	Business	18900.00
0005432327917	21078	Business	18900.00
0005432327918	21078	Business	18900.00
0005432382515	21078	Business	18900.00
0005432054287	21078	Economy	6300.00
0005432327956	21078	Economy	6300.00
0005432327890	21078	Economy	6300.00
0005432382493	21078	Economy	6300.00
0005432382571	21078	Economy	6300.00
0005432382575	21078	Economy	6300.00
0005432054286	21078	Economy	6300.00
0005432328021	21078	Economy	6900.00
0005432382494	21078	Economy	6900.00
0005432382678	21078	Economy	6900.00
0005432382692	21078	Economy	6300.00
0005432328035	21078	Economy	6300.00
0005432327923	21078	Economy	6300.00
0005432328086	21078	Economy	6300.00
0005432382564	21078	Economy	6300.00
0005432382570	21078	Economy	6300.00
0005432382693	21078	Economy	6300.00
0005432327966	21078	Economy	6300.00
0005432327978	21078	Economy	6300.00
0005432328111	21078	Economy	6300.00
0005432328022	21078	Economy	6300.00
0005432327979	21078	Economy	6300.00
0005432328081	21078	Economy	6300.00
0005432328155	21078	Economy	6300.00
0005432327951	21078	Economy	6300.00
0005432382607	21078	Economy	6300.00
0005432328083	21078	Economy	6300.00
0005432382633	21078	Economy	6300.00
0005432327977	21078	Economy	6300.00
0005432327958	21078	Economy	6300.00
0005432328000	21078	Economy	6300.00
0005432328156	21078	Economy	6300.00
0005432328169	21078	Economy	6300.00
0005432327899	21078	Economy	6300.00
0005432328077	21078	Economy	6300.00
0005432327999	21078	Economy	6300.00
0005432382622	21078	Economy	6300.00
0005432382803	21078	Economy	6300.00
0005432382617	21078	Economy	6300.00
0005432382516	21078	Economy	6300.00
0005432382499	21078	Economy	6300.00
0005432328143	21078	Economy	6300.00
0005432327991	21078	Economy	6300.00
0005432327967	21078	Economy	6300.00
0005432328023	21078	Economy	6300.00
0005432382707	21078	Economy	6300.00
0005432327971	21078	Economy	6300.00
0005432382610	21078	Economy	6300.00
0005432328104	21078	Economy	6300.00
0005432328084	21078	Economy	6300.00
0005432328129	21078	Economy	6300.00
0005432328071	21078	Economy	6300.00
0005432328258	21078	Economy	6300.00
0005432848837	21078	Economy	6300.00
0005432327959	21078	Economy	6300.00
0005432382609	21078	Economy	6300.00
0005432328103	21078	Economy	6300.00
0005432328020	21078	Economy	6300.00
0005432382891	31236	Business	18900.00
0005432328390	31236	Business	18900.00
0005432328377	31236	Business	18900.00
0005432328381	31236	Business	18900.00
0005432328374	31236	Business	18900.00
0005432382925	31236	Business	18900.00
0005432328392	31236	Business	18900.00
0005432328371	31236	Business	18900.00
0005432328360	31236	Business	18900.00
0005432328405	31236	Business	18900.00
0005432328398	31236	Business	18900.00
0005432382907	31236	Business	18900.00
0005432328370	31236	Economy	6300.00
0005432287152	31236	Economy	6300.00
0005432328402	31236	Economy	6300.00
0005432328406	31236	Economy	6300.00
0005432287156	31236	Economy	6300.00
0005432328369	31236	Economy	6300.00
0005432328375	31236	Economy	6300.00
0005432328384	31236	Economy	6300.00
0005432328385	31236	Economy	6300.00
0005432382919	31236	Economy	6300.00
0005432328362	31236	Economy	6900.00
0005432382902	31236	Economy	6900.00
0005432328394	31236	Economy	6900.00
0005432328399	31236	Economy	6900.00
0005432382921	31236	Economy	6900.00
0005432328382	31236	Economy	6300.00
0005432382901	31236	Economy	6300.00
0005432382913	31236	Economy	6300.00
0005432382910	31236	Economy	6300.00
0005432382903	31236	Economy	6300.00
0005432382894	31236	Economy	6300.00
0005432328380	31236	Economy	6300.00
0005432382905	31236	Economy	6300.00
0005432287157	31236	Economy	6300.00
0005432328387	31236	Economy	6300.00
0005432382897	31236	Economy	6300.00
0005432382917	31236	Economy	6300.00
0005432328368	31236	Economy	6300.00
0005432382926	31236	Economy	6300.00
0005432382918	31236	Economy	6300.00
0005432328403	31236	Economy	6300.00
0005432328364	31236	Economy	6300.00
0005432328400	31236	Economy	6300.00
0005432287153	31236	Economy	6300.00
0005432382890	31236	Economy	6300.00
0005432382900	31236	Economy	6300.00
0005432382889	31236	Economy	6300.00
0005432328361	31236	Economy	6300.00
0005432328367	31236	Economy	6300.00
0005432382922	31236	Economy	6300.00
0005432382898	31236	Economy	6300.00
0005432328378	31236	Economy	6300.00
0005432328363	31236	Economy	6300.00
0005432382895	31236	Economy	6300.00
0005432382888	31236	Economy	6300.00
0005432382899	31236	Economy	6300.00
0005432328388	31236	Economy	6300.00
0005432328389	31236	Economy	6300.00
0005432382906	31236	Economy	6300.00
0005432287154	31236	Economy	6300.00
0005432328397	31236	Economy	6300.00
0005432382920	31236	Economy	6300.00
0005432382915	31236	Economy	6300.00
0005432382893	31236	Economy	6300.00
0005432382914	31236	Economy	6300.00
0005432382887	31236	Economy	6300.00
0005432328376	31236	Economy	6300.00
0005432328386	31236	Economy	6300.00
0005432382896	31236	Economy	6300.00
0005432328379	31236	Economy	6300.00
0005432382923	31236	Economy	6300.00
0005432382908	31236	Economy	6300.00
0005432328404	31236	Economy	6300.00
0005432328393	31236	Economy	6300.00
0005432382904	31236	Economy	6300.00
0005432382924	31236	Economy	6300.00
0005432328373	31236	Economy	6300.00
0005432328365	31236	Economy	6300.00
0005432328401	31236	Economy	6300.00
0005432382909	31236	Economy	6300.00
0005432382911	31236	Economy	6300.00
0005432328396	31236	Economy	6300.00
0005432328383	31236	Economy	6300.00
0005432382886	31236	Economy	6300.00
0005432328372	31236	Economy	6300.00
0005432328366	31236	Economy	6300.00
0005432287151	31236	Economy	6300.00
0005432382892	31236	Economy	6300.00
0005432328391	31236	Economy	6300.00
0005432382916	31236	Economy	6300.00
0005432287155	31236	Economy	6300.00
0005432382912	31236	Economy	6300.00
0005432328395	31236	Economy	6300.00
0005433642238	2480	Business	89600.00
0005433642244	2480	Business	89600.00
0005432953819	2480	Business	89600.00
0005433642246	2480	Business	89600.00
0005432953811	2480	Economy	29900.00
0005432953798	2480	Economy	29900.00
0005432953807	2480	Economy	29900.00
0005433642245	2480	Economy	29900.00
0005433642248	2480	Economy	32800.00
0005432953808	2480	Economy	32800.00
0005432953809	2480	Economy	29900.00
0005433642247	2480	Economy	29900.00
0005433642242	2480	Economy	29900.00
0005432953793	2480	Economy	29900.00
0005433642256	2480	Economy	29900.00
0005433642252	2480	Economy	29900.00
0005432953789	2480	Economy	29900.00
0005433642237	2480	Economy	29900.00
0005433642239	2480	Economy	29900.00
0005433642253	2480	Economy	29900.00
0005433642243	2480	Economy	29900.00
0005432953810	2480	Economy	29900.00
0005432953792	2480	Economy	29900.00
0005432953806	2480	Economy	29900.00
0005433642251	2480	Economy	29900.00
0005432953802	2480	Economy	29900.00
0005432953794	2480	Economy	29900.00
0005433642236	2480	Economy	29900.00
0005432953791	2480	Economy	29900.00
0005433642231	2480	Economy	29900.00
0005433642230	2480	Economy	29900.00
0005433642250	2480	Economy	29900.00
0005432953799	2480	Economy	29900.00
0005433642255	2480	Economy	29900.00
0005433642241	2480	Economy	29900.00
0005433642249	2480	Economy	29900.00
0005433642232	2480	Economy	29900.00
0005433642254	2480	Economy	29900.00
0005433642235	2480	Economy	29900.00
0005433642233	2480	Economy	29900.00
0005432953801	2480	Economy	29900.00
0005432953800	2480	Economy	29900.00
0005433642240	2480	Economy	29900.00
0005433642257	2480	Economy	29900.00
0005433642229	2480	Economy	29900.00
0005433642234	2480	Economy	29900.00
0005433642099	27591	Business	89600.00
0005433642079	27591	Business	89600.00
0005432953873	27591	Business	89600.00
0005433642123	27591	Business	89600.00
0005432953879	27591	Business	89600.00
0005432953878	27591	Business	89600.00
0005433642117	27591	Business	89600.00
0005432953882	27591	Economy	29900.00
0005433642078	27591	Economy	29900.00
0005432953877	27591	Economy	29900.00
0005432953875	27591	Economy	29900.00
0005432953884	27591	Economy	32800.00
0005433642089	27591	Economy	29900.00
0005433642127	27591	Economy	29900.00
0005432953880	27591	Economy	29900.00
0005433642143	27591	Economy	29900.00
0005432953883	27591	Economy	29900.00
0005433642144	27591	Economy	29900.00
0005432953881	27591	Economy	29900.00
0005433642145	27591	Economy	29900.00
0005433642075	27591	Economy	29900.00
0005433642084	27591	Economy	29900.00
0005433642090	27591	Economy	29900.00
0005433642120	27591	Economy	29900.00
0005432953888	27591	Economy	29900.00
0005432953889	27591	Economy	29900.00
0005433642074	27591	Economy	29900.00
0005433642110	27591	Economy	29900.00
0005433642116	27591	Economy	29900.00
0005432953885	27591	Economy	29900.00
0005432953886	27591	Economy	29900.00
0005433642121	27591	Economy	29900.00
0005433642148	27591	Economy	29900.00
0005433642109	27591	Economy	29900.00
0005433642142	27591	Economy	29900.00
0005433642147	27591	Economy	29900.00
0005432953874	27591	Economy	29900.00
0005433642126	27591	Economy	29900.00
0005433642128	27591	Economy	29900.00
0005432953876	27591	Economy	29900.00
0005433642100	27591	Economy	29900.00
0005433642093	27591	Economy	29900.00
0005433642088	27591	Economy	29900.00
0005433642149	27591	Economy	29900.00
0005432953887	27591	Economy	29900.00
0005432424158	13260	Business	12700.00
0005432424142	13260	Business	12700.00
0005432424119	13260	Business	12700.00
0005432424156	13260	Business	12700.00
0005432424107	13260	Business	12700.00
0005432424112	13260	Business	12700.00
0005432424103	13260	Business	12700.00
0005432424127	13260	Business	12700.00
0005432424129	13260	Business	12700.00
0005432424145	13260	Economy	4200.00
0005432424136	13260	Economy	4200.00
0005432424114	13260	Economy	4200.00
0005432424144	13260	Economy	4200.00
0005432424140	13260	Economy	4200.00
0005432424111	13260	Economy	4200.00
0005432424118	13260	Economy	4700.00
0005432424150	13260	Economy	4700.00
0005432424105	13260	Economy	4200.00
0005432424143	13260	Economy	4200.00
0005432424115	13260	Economy	4200.00
0005432424155	13260	Economy	4200.00
0005432424126	13260	Economy	4200.00
0005432424151	13260	Economy	4200.00
0005432424153	13260	Economy	4200.00
0005432424109	13260	Economy	4200.00
0005432424149	13260	Economy	4200.00
0005432424106	13260	Economy	4200.00
0005432424139	13260	Economy	4200.00
0005432424147	13260	Economy	4200.00
0005432424098	13260	Economy	4200.00
0005432424137	13260	Economy	4200.00
0005432424113	13260	Economy	4200.00
0005432424138	13260	Economy	4200.00
0005432424148	13260	Economy	4200.00
0005432424102	13260	Economy	4200.00
0005432424132	13260	Economy	4200.00
0005432424117	13260	Economy	4200.00
0005432424121	13260	Economy	4200.00
0005432424099	13260	Economy	4200.00
0005432424146	13260	Economy	4200.00
0005432424104	13260	Economy	4200.00
0005432424128	13260	Economy	4200.00
0005432424108	13260	Economy	4200.00
0005432424120	13260	Economy	4200.00
0005432424134	13260	Economy	4200.00
0005432424116	13260	Economy	4200.00
0005432424133	13260	Economy	4200.00
0005432424122	13260	Economy	4200.00
0005432424159	13260	Economy	4200.00
0005432424124	13260	Economy	4200.00
0005432424123	13260	Economy	4200.00
0005432424157	13260	Economy	4200.00
0005432424141	13260	Economy	4200.00
0005432424131	13260	Economy	4200.00
0005432424101	13260	Economy	4200.00
0005432424125	13260	Economy	4200.00
0005432424100	13260	Economy	4200.00
0005432424152	13260	Economy	4200.00
0005432424130	13260	Economy	4200.00
0005432424135	13260	Economy	4200.00
0005432424110	13260	Economy	4200.00
0005432424154	13260	Economy	4200.00
0005432423621	30799	Business	12700.00
0005432423758	30799	Business	12700.00
0005432423639	30799	Business	12700.00
0005432423656	30799	Business	12700.00
0005432423610	30799	Business	12700.00
0005432423625	30799	Economy	4200.00
0005432423659	30799	Economy	4200.00
0005432423743	30799	Economy	4200.00
0005432423744	30799	Economy	4200.00
0005432423655	30799	Economy	4200.00
0005432423624	30799	Economy	4200.00
0005432423638	30799	Economy	4200.00
0005432423754	30799	Economy	4200.00
0005432423673	30799	Economy	4700.00
0005432423674	30799	Economy	4700.00
0005432423733	30799	Economy	4200.00
0005432423700	30799	Economy	4200.00
0005432423699	30799	Economy	4200.00
0005432423662	30799	Economy	4200.00
0005432423718	30799	Economy	4200.00
0005432423732	30799	Economy	4200.00
0005432423726	30799	Economy	4200.00
0005432423611	30799	Economy	4200.00
0005432423663	30799	Economy	4200.00
0005432423648	30799	Economy	4200.00
0005432423641	30799	Economy	4200.00
0005432423658	30799	Economy	4200.00
0005432423679	30799	Economy	4200.00
0005432423698	30799	Economy	4200.00
0005432423661	30799	Economy	4200.00
0005432423740	30799	Economy	4200.00
0005432423651	30799	Economy	4200.00
0005432423675	30799	Economy	4200.00
0005432423637	30799	Economy	4200.00
0005432423753	30799	Economy	4200.00
0005432423682	30799	Economy	4200.00
0005432423695	30799	Economy	4200.00
0005432423677	30799	Economy	4200.00
0005432423759	30799	Economy	4200.00
0005432423671	30799	Economy	4200.00
0005432423701	30799	Economy	4200.00
0005432423694	30799	Economy	4200.00
0005432423678	30799	Economy	4200.00
0005432423617	30799	Economy	4200.00
0005432423626	30799	Economy	4200.00
0005432423725	30799	Economy	4200.00
0005432423741	30799	Economy	4200.00
0005432423634	30799	Economy	4200.00
0005432423657	30799	Economy	4200.00
0005432817282	9616	Business	32600.00
0005432288966	9616	Business	32600.00
0005432901313	9616	Business	32600.00
0005434157382	9616	Business	32600.00
0005432817273	9616	Business	32600.00
0005432901325	9616	Business	32600.00
0005432822155	9616	Business	32600.00
0005432822151	9616	Business	32600.00
0005434157381	9616	Economy	10900.00
0005432822153	9616	Economy	10900.00
0005432817297	9616	Economy	10900.00
0005432817299	9616	Economy	10900.00
0005432817291	9616	Economy	10900.00
0005432817279	9616	Economy	10900.00
0005432901350	9616	Economy	11900.00
0005432817284	9616	Economy	11900.00
0005432817287	9616	Economy	11900.00
0005434186156	9616	Economy	11900.00
0005434157343	9616	Economy	10900.00
0005432822152	9616	Economy	10900.00
0005432817300	9616	Economy	10900.00
0005432817272	9616	Economy	10900.00
0005432817301	9616	Economy	10900.00
0005432817283	9616	Economy	10900.00
0005432901357	9616	Economy	10900.00
0005434186148	9616	Economy	10900.00
0005432822157	9616	Economy	10900.00
0005432822158	9616	Economy	10900.00
0005432817276	9616	Economy	10900.00
0005432288964	9616	Economy	10900.00
0005434186155	9616	Economy	10900.00
0005432817290	9616	Economy	10900.00
0005432817285	9616	Economy	10900.00
0005432817298	9616	Economy	10900.00
0005432288965	9616	Economy	10900.00
0005432817296	9616	Economy	10900.00
0005432901298	9616	Economy	10900.00
0005432817271	9616	Economy	10900.00
0005432901377	9616	Economy	10900.00
0005432817295	9616	Economy	10900.00
0005432817293	9616	Economy	10900.00
0005432817289	9616	Economy	10900.00
0005432817274	9616	Economy	10900.00
0005432822154	9616	Economy	10900.00
0005432817280	9616	Economy	10900.00
0005434448295	9616	Economy	10900.00
0005432817275	9616	Economy	10900.00
0005434157374	9616	Economy	10900.00
0005432901314	9616	Economy	10900.00
0005432817281	9616	Economy	10900.00
0005432817278	9616	Economy	10900.00
0005432901351	9616	Economy	10900.00
0005432901371	9616	Economy	10900.00
0005432901363	9616	Economy	10900.00
0005432817286	9616	Economy	10900.00
0005432822156	9616	Economy	10900.00
0005434448294	9616	Economy	10900.00
0005434448293	9616	Economy	10900.00
0005434186149	9616	Economy	10900.00
0005432817292	9616	Economy	10900.00
0005432817288	9616	Economy	10900.00
0005434186160	9616	Economy	10900.00
0005432817294	9616	Economy	10900.00
0005432901364	9616	Economy	10900.00
0005432901352	9616	Economy	10900.00
0005432817277	9616	Economy	10900.00
0005434157380	9616	Economy	10900.00
0005432822068	29006	Business	32600.00
0005432817047	29006	Business	32600.00
0005432817011	29006	Business	32600.00
0005432817034	29006	Business	32600.00
0005432816941	29006	Business	32600.00
0005432822100	29006	Business	32600.00
0005432817084	29006	Business	32600.00
0005432901503	29006	Business	32600.00
0005432822101	29006	Business	32600.00
0005434157428	29006	Business	32600.00
0005432817087	29006	Business	32600.00
0005432901494	29006	Economy	10900.00
0005432901501	29006	Economy	10900.00
0005432817097	29006	Economy	10900.00
0005432901506	29006	Economy	10900.00
0005434448261	29006	Economy	10900.00
0005434448271	29006	Economy	10900.00
0005434157434	29006	Economy	10900.00
0005432901502	29006	Economy	10900.00
0005432822127	29006	Economy	11900.00
0005432002062	29006	Economy	11900.00
0005432822077	29006	Economy	11900.00
0005434186178	29006	Economy	11900.00
0005432901495	29006	Economy	10900.00
0005432822084	29006	Economy	10900.00
0005432822078	29006	Economy	10900.00
0005432817026	29006	Economy	10900.00
0005432822079	29006	Economy	10900.00
0005432817006	29006	Economy	10900.00
0005432822065	29006	Economy	10900.00
0005432817096	29006	Economy	10900.00
0005434157430	29006	Economy	10900.00
0005432901508	29006	Economy	10900.00
0005432817056	29006	Economy	10900.00
0005432817027	29006	Economy	10900.00
0005432002064	29006	Economy	10900.00
0005432817088	29006	Economy	10900.00
0005432816951	29006	Economy	10900.00
0005432817017	29006	Economy	10900.00
0005432822083	29006	Economy	10900.00
0005432901499	29006	Economy	10900.00
0005432816979	29006	Economy	10900.00
0005432816950	29006	Economy	10900.00
0005432817018	29006	Economy	10900.00
0005432822075	29006	Economy	10900.00
0005432901500	29006	Economy	10900.00
0005432817167	29006	Economy	10900.00
0005432816949	29006	Economy	10900.00
0005432822129	29006	Economy	10900.00
0005432817168	29006	Economy	10900.00
0005434157435	29006	Economy	10900.00
0005432901493	29006	Economy	10900.00
0005432817033	29006	Economy	10900.00
0005432816956	29006	Economy	10900.00
0005432901505	29006	Economy	10900.00
0005432901497	29006	Economy	10900.00
0005432002063	29006	Economy	10900.00
0005432816942	29006	Economy	10900.00
0005432817071	29006	Economy	10900.00
0005432901498	29006	Economy	10900.00
0005432816962	29006	Economy	10900.00
0005432901496	29006	Economy	10900.00
0005432817073	29006	Economy	10900.00
0005432822066	29006	Economy	10900.00
0005434157429	29006	Economy	10900.00
0005432816984	29006	Economy	10900.00
0005432816978	29006	Economy	10900.00
0005434157432	29006	Economy	10900.00
0005434186179	29006	Economy	10900.00
0005432901492	29006	Economy	10900.00
0005432816983	29006	Economy	10900.00
0005432822074	29006	Economy	10900.00
0005432901507	29006	Economy	10900.00
0005432817055	29006	Economy	10900.00
0005432816971	29006	Economy	10900.00
0005432901504	29006	Economy	10900.00
0005432816970	29006	Economy	10900.00
0005432817057	29006	Economy	10900.00
0005432822090	29006	Economy	10900.00
0005434157431	29006	Economy	10900.00
0005432822128	29006	Economy	10900.00
0005434157433	29006	Economy	10900.00
0005432611687	15033	Economy	11000.00
0005432611686	15033	Economy	11000.00
0005432613835	15033	Economy	11000.00
0005432613838	15033	Economy	11000.00
0005432611688	15033	Economy	11000.00
0005435841083	15033	Economy	11000.00
0005432611684	15033	Economy	11000.00
0005432611685	15033	Economy	11000.00
0005432613837	15033	Economy	11000.00
0005432613836	15033	Economy	11000.00
0005435841084	15033	Economy	11000.00
0005435841817	31538	Economy	11000.00
0005432607515	31538	Economy	11000.00
0005432607500	31538	Economy	11000.00
0005432611647	31538	Economy	11000.00
0005432611650	31538	Economy	11000.00
0005432607516	31538	Economy	11000.00
0005432611645	31538	Economy	11000.00
0005432607517	31538	Economy	11000.00
0005432607502	31538	Economy	11000.00
0005433568646	11885	Business	105900.00
0005433568640	11885	Business	105900.00
0005432947854	11885	Business	105900.00
0005433568676	11885	Business	105900.00
0005432947849	11885	Business	105900.00
0005433568625	11885	Business	105900.00
0005433568638	11885	Business	105900.00
0005433568633	11885	Business	105900.00
0005433568607	11885	Business	105900.00
0005432947855	11885	Business	105900.00
0005433568668	11885	Business	105900.00
0005433568674	11885	Business	105900.00
0005432948005	11885	Business	105900.00
0005433568631	11885	Business	105900.00
0005432947839	11885	Business	105900.00
0005433568672	11885	Business	105900.00
0005433568643	11885	Business	105900.00
0005433568645	11885	Economy	35300.00
0005433568665	11885	Economy	35300.00
0005432948006	11885	Economy	35300.00
0005433568634	11885	Economy	35300.00
0005432947765	11885	Economy	35300.00
0005433568647	11885	Economy	35300.00
0005433568609	11885	Economy	35300.00
0005433568624	11885	Economy	35300.00
0005433568658	11885	Economy	35300.00
0005433568627	11885	Economy	35300.00
0005433568661	11885	Economy	35300.00
0005432947821	11885	Economy	38800.00
0005433568641	11885	Economy	38800.00
0005433568678	11885	Economy	35300.00
0005432947895	11885	Economy	35300.00
0005433568616	11885	Economy	35300.00
0005433568662	11885	Economy	35300.00
0005432947817	11885	Economy	35300.00
0005433568670	11885	Economy	35300.00
0005433568622	11885	Economy	35300.00
0005432947777	11885	Economy	35300.00
0005432947838	11885	Economy	35300.00
0005433568612	11885	Economy	35300.00
0005433568623	11885	Economy	35300.00
0005432947819	11885	Economy	35300.00
0005433568628	11885	Economy	35300.00
0005433568637	11885	Economy	35300.00
0005433568626	11885	Economy	35300.00
0005433568642	11885	Economy	35300.00
0005432947853	11885	Economy	35300.00
0005433568614	11885	Economy	35300.00
0005433568675	11885	Economy	35300.00
0005433568671	11885	Economy	35300.00
0005433568610	11885	Economy	35300.00
0005433568651	11885	Economy	35300.00
0005433568650	11885	Economy	35300.00
0005433568673	11885	Economy	35300.00
0005432947795	11885	Economy	35300.00
0005433568666	11885	Economy	35300.00
0005433568620	11885	Economy	35300.00
0005433568621	11885	Economy	35300.00
0005433568608	11885	Economy	35300.00
0005433568639	11885	Economy	35300.00
0005433568649	11885	Economy	35300.00
0005433568636	11885	Economy	35300.00
0005433568660	11885	Economy	35300.00
0005433568644	11885	Economy	35300.00
0005433568656	11885	Economy	35300.00
0005432947869	11885	Economy	35300.00
0005433568648	11885	Economy	35300.00
0005432947850	11885	Economy	35300.00
0005433568659	11885	Economy	35300.00
0005432947894	11885	Economy	35300.00
0005432947842	11885	Economy	35300.00
0005433568615	11885	Economy	35300.00
0005433568652	11885	Economy	35300.00
0005433568617	11885	Economy	35300.00
0005432947818	11885	Economy	35300.00
0005433568619	11885	Economy	35300.00
0005433568679	11885	Economy	35300.00
0005433568657	11885	Economy	35300.00
0005432947808	11885	Economy	35300.00
0005433568669	11885	Economy	35300.00
0005433568606	11885	Economy	35300.00
0005433568667	11885	Economy	35300.00
0005433568653	11885	Economy	35300.00
0005433568632	11885	Economy	35300.00
0005433568629	11885	Economy	35300.00
0005433568654	11885	Economy	35300.00
0005433568618	11885	Economy	35300.00
0005433568655	11885	Economy	35300.00
0005432947868	11885	Economy	35300.00
0005433568613	11885	Economy	35300.00
0005432947910	11885	Economy	35300.00
0005433568611	11885	Economy	35300.00
0005433568677	11885	Economy	35300.00
0005432947856	11885	Economy	35300.00
0005433568630	11885	Economy	35300.00
0005433568663	11885	Economy	35300.00
0005433568635	11885	Economy	35300.00
0005432947979	11885	Economy	35300.00
0005433568664	11885	Economy	35300.00
0005432948260	25296	Business	105900.00
0005433568161	25296	Business	105900.00
0005433568107	25296	Business	105900.00
0005432948222	25296	Business	105900.00
0005432948257	25296	Business	105900.00
0005432948235	25296	Business	105900.00
0005433568176	25296	Business	105900.00
0005432948240	25296	Business	105900.00
0005433568169	25296	Business	105900.00
0005432948244	25296	Business	105900.00
0005432948223	25296	Business	105900.00
0005432948253	25296	Business	105900.00
0005432948245	25296	Business	105900.00
0005432948255	25296	Economy	35300.00
0005432948250	25296	Economy	35300.00
0005433568106	25296	Economy	35300.00
0005432948251	25296	Economy	35300.00
0005433568189	25296	Economy	35300.00
0005433568095	25296	Economy	35300.00
0005432948262	25296	Economy	35300.00
0005433568088	25296	Economy	35300.00
0005432948230	25296	Economy	35300.00
0005433568114	25296	Economy	35300.00
0005432948239	25296	Economy	38800.00
0005432948252	25296	Economy	38800.00
0005432948227	25296	Economy	38800.00
0005432948229	25296	Economy	35300.00
0005432948256	25296	Economy	35300.00
0005433568177	25296	Economy	35300.00
0005433568083	25296	Economy	35300.00
0005432948247	25296	Economy	35300.00
0005432948248	25296	Economy	35300.00
0005433568132	25296	Economy	35300.00
0005432948241	25296	Economy	35300.00
0005432948254	25296	Economy	35300.00
0005432948236	25296	Economy	35300.00
0005433568174	25296	Economy	35300.00
0005433568157	25296	Economy	35300.00
0005432948228	25296	Economy	35300.00
0005433568214	25296	Economy	35300.00
0005433568077	25296	Economy	35300.00
0005432948243	25296	Economy	35300.00
0005433568094	25296	Economy	35300.00
0005433568212	25296	Economy	35300.00
0005433568188	25296	Economy	35300.00
0005432948246	25296	Economy	35300.00
0005433568238	25296	Economy	35300.00
0005432948238	25296	Economy	35300.00
0005432948259	25296	Economy	35300.00
0005432948242	25296	Economy	35300.00
0005432948231	25296	Economy	35300.00
0005432948263	25296	Economy	35300.00
0005432948224	25296	Economy	35300.00
0005433568207	25296	Economy	35300.00
0005432948261	25296	Economy	35300.00
0005432948232	25296	Economy	35300.00
0005433568081	25296	Economy	35300.00
0005433568206	25296	Economy	35300.00
0005432948249	25296	Economy	35300.00
0005432948258	25296	Economy	35300.00
0005432948234	25296	Economy	35300.00
0005433568213	25296	Economy	35300.00
0005433568111	25296	Economy	35300.00
0005433568089	25296	Economy	35300.00
0005432948237	25296	Economy	35300.00
0005433568158	25296	Economy	35300.00
0005432948226	25296	Economy	35300.00
0005433568166	25296	Economy	35300.00
0005433568067	25296	Economy	35300.00
0005432948225	25296	Economy	35300.00
0005433568105	25296	Economy	35300.00
0005433568173	25296	Economy	35300.00
0005432948233	25296	Economy	35300.00
0005433568068	25296	Economy	35300.00
0005433808307	14455	Business	117400.00
0005433808308	14455	Business	117400.00
0005433812860	14455	Business	117400.00
0005433808318	14455	Business	117400.00
0005433808311	14455	Business	117400.00
0005434026687	14455	Business	117400.00
0005432430844	14455	Business	117400.00
0005434026690	14455	Business	117400.00
0005434026689	14455	Business	117400.00
0005434026693	14455	Economy	39100.00
0005433808319	14455	Economy	39100.00
0005432430830	14455	Economy	39100.00
0005434026694	14455	Economy	39100.00
0005432430837	14455	Economy	39100.00
0005433812857	14455	Economy	39100.00
0005432430843	14455	Economy	39100.00
0005434026688	14455	Economy	39100.00
0005433812859	14455	Economy	39100.00
0005433812858	14455	Economy	39100.00
0005432430836	14455	Economy	39100.00
0005432430840	14455	Economy	39100.00
0005432430831	14455	Economy	39100.00
0005433808309	14455	Economy	39100.00
0005434026691	14455	Economy	39100.00
0005432430841	14455	Economy	39100.00
0005432430842	14455	Economy	39100.00
0005432430838	14455	Economy	39100.00
0005432430834	14455	Economy	39100.00
0005433808317	14455	Economy	39100.00
0005432430833	14455	Economy	39100.00
0005432430832	14455	Economy	39100.00
0005432430835	14455	Economy	39100.00
0005432430839	14455	Economy	39100.00
0005433808306	14455	Economy	39100.00
0005434026692	14455	Economy	39100.00
0005434654503	5376	Business	67200.00
0005434654510	5376	Business	67200.00
0005434656543	5376	Business	67200.00
0005435340128	5376	Business	67200.00
0005435340045	5376	Business	67200.00
0005435340072	5376	Business	67200.00
0005435340034	5376	Business	67200.00
0005434654491	5376	Economy	22400.00
0005435340026	5376	Economy	22400.00
0005435340044	5376	Economy	22400.00
0005435340103	5376	Economy	22400.00
0005435555338	5376	Economy	22400.00
0005434656544	5376	Economy	24600.00
0005434654500	5376	Economy	24600.00
0005434654512	5376	Economy	24600.00
0005434654504	5376	Economy	24600.00
0005434654509	5376	Economy	22400.00
0005434654505	5376	Economy	22400.00
0005432114181	5376	Economy	22400.00
0005434654496	5376	Economy	22400.00
0005434654516	5376	Economy	22400.00
0005435340030	5376	Economy	22400.00
0005434654493	5376	Economy	22400.00
0005434654492	5376	Economy	22400.00
0005435340062	5376	Economy	22400.00
0005434654501	5376	Economy	22400.00
0005435340079	5376	Economy	22400.00
0005434654514	5376	Economy	22400.00
0005435340031	5376	Economy	22400.00
0005435340104	5376	Economy	22400.00
0005435340033	5376	Economy	22400.00
0005435340017	5376	Economy	22400.00
0005434654495	5376	Economy	22400.00
0005434654511	5376	Economy	22400.00
0005432114182	5376	Economy	22400.00
0005435340059	5376	Economy	22400.00
0005434654489	5376	Economy	22400.00
0005434654490	5376	Economy	22400.00
0005434654508	5376	Economy	22400.00
0005434654506	5376	Economy	22400.00
0005434654513	5376	Economy	22400.00
0005434654517	5376	Economy	22400.00
0005434654498	5376	Economy	22400.00
0005432114183	5376	Economy	22400.00
0005435340032	5376	Economy	22400.00
0005435340073	5376	Economy	22400.00
0005435340025	5376	Economy	22400.00
0005434654507	5376	Economy	22400.00
0005434654499	5376	Economy	22400.00
0005434654502	5376	Economy	22400.00
0005432114184	5376	Economy	22400.00
0005435555342	5376	Economy	22400.00
0005434654497	5376	Economy	22400.00
0005434654515	5376	Economy	22400.00
0005434654494	5376	Economy	22400.00
0005434654212	12507	Business	67200.00
0005434656528	12507	Business	67200.00
0005435340168	12507	Business	67200.00
0005434654273	12507	Business	67200.00
0005434654308	12507	Business	67200.00
0005435340174	12507	Business	67200.00
0005434654325	12507	Business	67200.00
0005434654254	12507	Economy	22400.00
0005434654307	12507	Economy	22400.00
0005434654180	12507	Economy	22400.00
0005435340173	12507	Economy	24600.00
0005434654181	12507	Economy	22400.00
0005435340166	12507	Economy	22400.00
0005435555358	12507	Economy	22400.00
0005434654287	12507	Economy	22400.00
0005434654285	12507	Economy	22400.00
0005434654242	12507	Economy	22400.00
0005435340165	12507	Economy	22400.00
0005435555357	12507	Economy	22400.00
0005435340161	12507	Economy	22400.00
0005435340172	12507	Economy	22400.00
0005435340164	12507	Economy	22400.00
0005435340163	12507	Economy	22400.00
0005434654213	12507	Economy	22400.00
0005434654284	12507	Economy	22400.00
0005435340169	12507	Economy	22400.00
0005434654319	12507	Economy	22400.00
0005434654323	12507	Economy	22400.00
0005434654197	12507	Economy	22400.00
0005434654191	12507	Economy	22400.00
0005435340167	12507	Economy	22400.00
0005435340171	12507	Economy	22400.00
0005435340160	12507	Economy	22400.00
0005434654324	12507	Economy	22400.00
0005434654192	12507	Economy	22400.00
0005434654230	12507	Economy	22400.00
0005435340162	12507	Economy	22400.00
0005434654272	12507	Economy	22400.00
0005435340170	12507	Economy	22400.00
0005432078071	7469	Business	32000.00
0005433656645	7469	Business	32000.00
0005433656647	7469	Business	32000.00
0005433715644	7469	Business	32000.00
0005433715654	7469	Business	32000.00
0005433715643	7469	Business	32000.00
0005433715672	7469	Business	32000.00
0005433715674	7469	Economy	10700.00
0005433715630	7469	Economy	10700.00
0005433715667	7469	Economy	10700.00
0005433715666	7469	Economy	10700.00
0005433715649	7469	Economy	10700.00
0005433715657	7469	Economy	10700.00
0005433715634	7469	Economy	10700.00
0005433715663	7469	Economy	10700.00
0005432078073	7469	Economy	10700.00
0005433715633	7469	Economy	10700.00
0005433690913	7469	Economy	10700.00
0005433715645	7469	Economy	10700.00
0005433715640	7469	Economy	10700.00
0005433715635	7469	Economy	10700.00
0005433715650	7469	Economy	10700.00
0005433715678	7469	Economy	10700.00
0005433719118	7469	Economy	10700.00
0005433722174	7469	Economy	10700.00
0005433688796	7469	Economy	10700.00
0005433715637	7469	Economy	10700.00
0005433715632	7469	Economy	10700.00
0005433722178	7469	Economy	10700.00
0005433690912	7469	Economy	10700.00
0005433715662	7469	Economy	10700.00
0005433715661	7469	Economy	10700.00
0005433715659	7469	Economy	10700.00
0005433722176	7469	Economy	10700.00
0005433719115	7469	Economy	10700.00
0005433688795	7469	Economy	10700.00
0005432078072	7469	Economy	10700.00
0005433715675	7469	Economy	10700.00
0005432428879	7469	Economy	10700.00
0005433715646	7469	Economy	11700.00
0005432078076	7469	Economy	11700.00
0005433715631	7469	Economy	11700.00
0005433715652	7469	Economy	11700.00
0005433715677	7469	Economy	10700.00
0005433722177	7469	Economy	10700.00
0005433656648	7469	Economy	10700.00
0005433715658	7469	Economy	10700.00
0005433715653	7469	Economy	10700.00
0005432078075	7469	Economy	10700.00
0005433715673	7469	Economy	10700.00
0005433715671	7469	Economy	10700.00
0005433715641	7469	Economy	10700.00
0005432078074	7469	Economy	10700.00
0005433715669	7469	Economy	10700.00
0005433715638	7469	Economy	10700.00
0005433722170	7469	Economy	10700.00
0005433715636	7469	Economy	10700.00
0005433715668	7469	Economy	10700.00
0005433715651	7469	Economy	10700.00
0005433715655	7469	Economy	10700.00
0005433656646	7469	Economy	10700.00
0005433715670	7469	Economy	10700.00
0005433719116	7469	Economy	10700.00
0005433722173	7469	Economy	10700.00
0005433715639	7469	Economy	10700.00
0005433715642	7469	Economy	10700.00
0005433689897	7469	Economy	10700.00
0005433715628	7469	Economy	10700.00
0005433715676	7469	Economy	10700.00
0005433689896	7469	Economy	10700.00
0005435266075	7469	Economy	10700.00
0005433715656	7469	Economy	10700.00
0005433715647	7469	Economy	10700.00
0005433715629	7469	Economy	10700.00
0005433722172	7469	Economy	10700.00
0005433689895	7469	Economy	10700.00
0005433715664	7469	Economy	10700.00
0005433719117	7469	Economy	10700.00
0005433715648	7469	Economy	10700.00
0005433715665	7469	Economy	10700.00
0005433715660	7469	Economy	10700.00
0005433722171	7469	Economy	10700.00
0005433715679	7469	Economy	10700.00
0005433722175	7469	Economy	10700.00
0005433715161	29235	Business	32000.00
0005432428906	29235	Business	32000.00
0005433688779	29235	Business	32000.00
0005433715071	29235	Business	32000.00
0005433715319	29235	Business	32000.00
0005435266123	29235	Business	32000.00
0005433715253	29235	Business	32000.00
0005433715070	29235	Business	32000.00
0005433688778	29235	Economy	10700.00
0005433715249	29235	Economy	10700.00
0005433715088	29235	Economy	10700.00
0005433715244	29235	Economy	10700.00
0005433715067	29235	Economy	10700.00
0005433656614	29235	Economy	10700.00
0005433715105	29235	Economy	10700.00
0005433715229	29235	Economy	10700.00
0005433688781	29235	Economy	10700.00
0005433715348	29235	Economy	10700.00
0005433715198	29235	Economy	10700.00
0005435266124	29235	Economy	10700.00
0005433715230	29235	Economy	10700.00
0005433715350	29235	Economy	10700.00
0005433715377	29235	Economy	10700.00
0005433715331	29235	Economy	10700.00
0005433715168	29235	Economy	10700.00
0005433715262	29235	Economy	10700.00
0005433715430	29235	Economy	11700.00
0005433715207	29235	Economy	11700.00
0005433715241	29235	Economy	10700.00
0005432006741	29235	Economy	11700.00
0005433715318	29235	Economy	10700.00
0005433715177	29235	Economy	10700.00
0005433688780	29235	Economy	10700.00
0005433715261	29235	Economy	10700.00
0005433715159	29235	Economy	10700.00
0005433715104	29235	Economy	10700.00
0005435266122	29235	Economy	10700.00
0005433715206	29235	Economy	10700.00
0005433715382	29235	Economy	10700.00
0005433719099	29235	Economy	10700.00
0005433715275	29235	Economy	10700.00
0005433715429	29235	Economy	10700.00
0005432006743	29235	Economy	10700.00
0005433715103	29235	Economy	10700.00
0005433715199	29235	Economy	10700.00
0005433715179	29235	Economy	10700.00
0005433715306	29235	Economy	10700.00
0005433688777	29235	Economy	10700.00
0005433715162	29235	Economy	10700.00
0005433715346	29235	Economy	10700.00
0005433656613	29235	Economy	10700.00
0005432428908	29235	Economy	10700.00
0005433715221	29235	Economy	10700.00
0005433715272	29235	Economy	10700.00
0005435266121	29235	Economy	10700.00
0005433715178	29235	Economy	10700.00
0005432428907	29235	Economy	10700.00
0005433715347	29235	Economy	10700.00
0005433715165	29235	Economy	10700.00
0005433715258	29235	Economy	10700.00
0005432006742	29235	Economy	10700.00
0005433715205	29235	Economy	10700.00
0005434095187	8655	Business	36500.00
0005434182010	8655	Business	36500.00
0005434182007	8655	Business	36500.00
0005434095177	8655	Business	36500.00
0005434181999	8655	Business	36500.00
0005434181971	8655	Economy	12200.00
0005434095185	8655	Economy	12200.00
0005434181986	8655	Economy	12200.00
0005434095181	8655	Economy	12200.00
0005434095190	8655	Economy	13400.00
0005434182027	8655	Economy	13400.00
0005434181972	8655	Economy	13400.00
0005434095179	8655	Economy	12200.00
0005434095182	8655	Economy	12200.00
0005434095186	8655	Economy	12200.00
0005434181973	8655	Economy	12200.00
0005434095183	8655	Economy	12200.00
0005434095189	8655	Economy	12200.00
0005434095178	8655	Economy	12200.00
0005434181987	8655	Economy	12200.00
0005434143716	8655	Economy	12200.00
0005434143715	8655	Economy	12200.00
0005434181981	8655	Economy	12200.00
0005434095191	8655	Economy	12200.00
0005434095184	8655	Economy	12200.00
0005434095180	8655	Economy	12200.00
0005434095188	8655	Economy	12200.00
0005434182013	8655	Economy	12200.00
0005434095038	11654	Business	36500.00
0005434095037	11654	Business	36500.00
0005434183564	11654	Business	36500.00
0005434182109	11654	Business	36500.00
0005434182106	11654	Economy	12200.00
0005434182104	11654	Economy	12200.00
0005434182105	11654	Economy	13400.00
0005434182103	11654	Economy	13400.00
0005434182108	11654	Economy	12200.00
0005434182110	11654	Economy	12200.00
0005434184651	11654	Economy	12200.00
0005434182107	11654	Economy	12200.00
0005434183565	11654	Economy	12200.00
0005434095040	11654	Economy	12200.00
0005434095042	11654	Economy	12200.00
0005434182100	11654	Economy	12200.00
0005434095030	11654	Economy	12200.00
0005434184650	11654	Economy	12200.00
0005434182102	11654	Economy	12200.00
0005434095130	11654	Economy	12200.00
0005434095060	11654	Economy	12200.00
0005434182099	11654	Economy	12200.00
0005434095020	11654	Economy	12200.00
0005434095041	11654	Economy	12200.00
0005434182101	11654	Economy	12200.00
0005433397326	1436	Business	33000.00
0005433397618	1436	Business	33000.00
0005433397488	1436	Business	33000.00
0005433397548	1436	Business	33000.00
0005435732275	1436	Business	33000.00
0005433397303	1436	Business	33000.00
0005433397272	1436	Economy	11000.00
0005433456942	1436	Economy	11000.00
0005432297261	1436	Economy	11000.00
0005433397211	1436	Economy	11000.00
0005433397237	1436	Economy	11000.00
0005433397291	1436	Economy	11000.00
0005433397355	1436	Economy	11000.00
0005435732262	1436	Economy	12100.00
0005433397504	1436	Economy	11000.00
0005433397292	1436	Economy	11000.00
0005433397383	1436	Economy	11000.00
0005433397466	1436	Economy	11000.00
0005433397413	1436	Economy	11000.00
0005433397283	1436	Economy	11000.00
0005433397509	1436	Economy	11000.00
0005433397490	1436	Economy	11000.00
0005433397468	1436	Economy	11000.00
0005433397505	1436	Economy	11000.00
0005435732269	1436	Economy	11000.00
0005433397568	1436	Economy	11000.00
0005433397420	1436	Economy	11000.00
0005433397288	1436	Economy	11000.00
0005435732274	1436	Economy	11000.00
0005435732261	1436	Economy	11000.00
0005433397496	1436	Economy	11000.00
0005433397196	1436	Economy	11000.00
0005433397419	1436	Economy	11000.00
0005435732271	1436	Economy	11000.00
0005435732264	1436	Economy	11000.00
0005435732272	1436	Economy	11000.00
0005433397325	1436	Economy	11000.00
0005435732273	1436	Economy	11000.00
0005433397271	1436	Economy	11000.00
0005432906499	1436	Economy	11000.00
0005433397498	1436	Economy	11000.00
0005435732267	1436	Economy	11000.00
0005433397212	1436	Economy	11000.00
0005433397465	1436	Economy	11000.00
0005435732260	1436	Economy	11000.00
0005433397255	1436	Economy	11000.00
0005435732258	1436	Economy	11000.00
0005432906497	1436	Economy	11000.00
0005433397489	1436	Economy	11000.00
0005433397284	1436	Economy	11000.00
0005435732263	1436	Economy	11000.00
0005435732265	1436	Economy	11000.00
0005435732259	1436	Economy	11000.00
0005433456944	1436	Economy	11000.00
0005435732276	1436	Economy	11000.00
0005433397493	1436	Economy	11000.00
0005433456945	1436	Economy	11000.00
0005435732270	1436	Economy	11000.00
0005433397569	1436	Economy	11000.00
0005432906501	1436	Economy	11000.00
0005433397210	1436	Economy	11000.00
0005432906498	1436	Economy	11000.00
0005433397497	1436	Economy	11000.00
0005433397546	1436	Economy	11000.00
0005435732257	1436	Economy	11000.00
0005435732266	1436	Economy	11000.00
0005433456943	1436	Economy	11000.00
0005435732268	1436	Economy	11000.00
0005433397492	1436	Economy	11000.00
0005433397287	1436	Economy	11000.00
0005433397380	1436	Economy	11000.00
0005433397768	19272	Business	33000.00
0005433397736	19272	Business	33000.00
0005433397756	19272	Business	33000.00
0005432906521	19272	Business	33000.00
0005433397770	19272	Business	33000.00
0005432906519	19272	Business	33000.00
0005433397727	19272	Business	33000.00
0005433397764	19272	Business	33000.00
0005433397728	19272	Business	33000.00
0005433397754	19272	Business	33000.00
0005433397757	19272	Economy	11000.00
0005433397755	19272	Economy	11000.00
0005433397742	19272	Economy	11000.00
0005433397726	19272	Economy	11000.00
0005433397751	19272	Economy	11000.00
0005433397762	19272	Economy	11000.00
0005433397766	19272	Economy	11000.00
0005435732140	19272	Economy	12100.00
0005433397753	19272	Economy	12100.00
0005433397731	19272	Economy	12100.00
0005433397774	19272	Economy	11000.00
0005433397734	19272	Economy	11000.00
0005433456898	19272	Economy	11000.00
0005433397771	19272	Economy	11000.00
0005433397739	19272	Economy	11000.00
0005433397729	19272	Economy	11000.00
0005433397738	19272	Economy	11000.00
0005433397747	19272	Economy	11000.00
0005433397759	19272	Economy	11000.00
0005433397741	19272	Economy	11000.00
0005433397763	19272	Economy	11000.00
0005435732152	19272	Economy	11000.00
0005433397743	19272	Economy	11000.00
0005433397773	19272	Economy	11000.00
0005435732153	19272	Economy	11000.00
0005433397767	19272	Economy	11000.00
0005433397772	19272	Economy	11000.00
0005433397748	19272	Economy	11000.00
0005433397746	19272	Economy	11000.00
0005435732154	19272	Economy	11000.00
0005433456905	19272	Economy	11000.00
0005433397735	19272	Economy	11000.00
0005433397744	19272	Economy	11000.00
0005435732172	19272	Economy	11000.00
0005435732158	19272	Economy	11000.00
0005433397733	19272	Economy	11000.00
0005433456910	19272	Economy	11000.00
0005433397769	19272	Economy	11000.00
0005433456909	19272	Economy	11000.00
0005433397765	19272	Economy	11000.00
0005433397761	19272	Economy	11000.00
0005433397749	19272	Economy	11000.00
0005433397732	19272	Economy	11000.00
0005433397737	19272	Economy	11000.00
0005433397740	19272	Economy	11000.00
0005435732201	19272	Economy	11000.00
0005433456897	19272	Economy	11000.00
0005432906520	19272	Economy	11000.00
0005433397758	19272	Economy	11000.00
0005433397745	19272	Economy	11000.00
0005433397760	19272	Economy	11000.00
0005433397750	19272	Economy	11000.00
0005433397730	19272	Economy	11000.00
0005435732194	19272	Economy	11000.00
0005433397752	19272	Economy	11000.00
0005433456916	19272	Economy	11000.00
0005434443461	17381	Economy	15600.00
0005434443486	17381	Economy	14100.00
0005434443437	17381	Economy	14100.00
0005434443455	17381	Economy	14100.00
0005434443477	17381	Economy	14100.00
0005434443488	17381	Economy	14100.00
0005434443449	17381	Economy	14100.00
0005434443442	17381	Economy	14100.00
0005434443443	17381	Economy	14100.00
0005434443472	17381	Economy	14100.00
0005434443514	17381	Economy	14100.00
0005434443513	17381	Economy	14100.00
0005434443500	17381	Economy	14100.00
0005434443436	17381	Economy	14100.00
0005434443487	17381	Economy	14100.00
0005434443604	20604	Economy	15600.00
0005434443603	20604	Economy	15600.00
0005434443599	20604	Economy	14100.00
0005434443590	20604	Economy	14100.00
0005434443598	20604	Economy	14100.00
0005434443596	20604	Economy	14100.00
0005434443597	20604	Economy	14100.00
0005434443602	20604	Economy	14100.00
0005434443600	20604	Economy	14100.00
0005434443594	20604	Economy	14100.00
0005434443601	20604	Economy	14100.00
0005434443592	20604	Economy	14100.00
0005434443595	20604	Economy	14100.00
0005434443591	20604	Economy	14100.00
0005434443593	20604	Economy	14100.00
0005434954582	7242	Economy	5800.00
0005435377544	7242	Economy	5800.00
0005434954585	7242	Economy	5800.00
0005434954584	7242	Economy	5800.00
0005434954583	7242	Economy	5800.00
0005434954549	28315	Economy	5800.00
0005434954546	28315	Economy	5800.00
0005434954550	28315	Economy	5800.00
0005434351617	4497	Economy	15400.00
0005434351614	4497	Economy	15400.00
0005434351615	4497	Economy	14000.00
0005434351620	4497	Economy	14000.00
0005434351618	4497	Economy	14000.00
0005434183545	4497	Economy	14000.00
0005434351611	4497	Economy	14000.00
0005435893527	4497	Economy	14000.00
0005435893515	4497	Economy	14000.00
0005434351609	4497	Economy	14000.00
0005435893518	4497	Economy	14000.00
0005435893503	4497	Economy	14000.00
0005434183560	4497	Economy	14000.00
0005435893525	4497	Economy	14000.00
0005434183546	4497	Economy	14000.00
0005434351619	4497	Economy	14000.00
0005435893513	4497	Economy	14000.00
0005434351610	4497	Economy	14000.00
0005435893526	4497	Economy	14000.00
0005434351616	4497	Economy	14000.00
0005434351613	4497	Economy	14000.00
0005435893528	4497	Economy	14000.00
0005435893555	4497	Economy	14000.00
0005435893519	4497	Economy	14000.00
0005434351612	4497	Economy	14000.00
0005435893583	29678	Economy	15400.00
0005434351501	29678	Economy	14000.00
0005434351542	29678	Economy	14000.00
0005434351477	29678	Economy	14000.00
0005435893584	29678	Economy	14000.00
0005434351500	29678	Economy	14000.00
0005434351544	29678	Economy	14000.00
0005435893589	29678	Economy	14000.00
0005434351490	29678	Economy	14000.00
0005434351496	29678	Economy	14000.00
0005434351539	29678	Economy	14000.00
0005435893585	29678	Economy	14000.00
0005434351510	29678	Economy	14000.00
0005435893588	29678	Economy	14000.00
0005435893590	29678	Economy	14000.00
0005435893586	29678	Economy	14000.00
0005435893587	29678	Economy	14000.00
0005433341711	1064	Business	30600.00
0005433341562	1064	Business	30600.00
0005433269663	1064	Business	30600.00
0005435545681	1064	Business	30600.00
0005433341493	1064	Business	30600.00
0005433342085	1064	Business	30600.00
0005433341451	1064	Business	30600.00
0005432293192	1064	Business	30600.00
0005433341539	1064	Business	30600.00
0005433341662	1064	Business	30600.00
0005432293195	1064	Business	30600.00
0005433341519	1064	Business	30600.00
0005433341709	1064	Business	30600.00
0005433341737	1064	Business	30600.00
0005433341695	1064	Business	30600.00
0005434446504	1064	Business	30600.00
0005433341724	1064	Business	30600.00
0005433341712	1064	Business	30600.00
0005433341534	1064	Business	30600.00
0005433341885	1064	Business	30600.00
0005433341506	1064	Economy	11200.00
0005433341886	1064	Economy	11200.00
0005435545684	1064	Economy	10200.00
0005433341688	1064	Economy	10200.00
0005433341638	1064	Economy	10200.00
0005433341812	1064	Economy	10200.00
0005433341759	1064	Economy	10200.00
0005433341551	1064	Economy	10200.00
0005435545676	1064	Economy	10200.00
0005432293194	1064	Economy	10200.00
0005433341639	1064	Economy	10200.00
0005435545679	1064	Economy	10200.00
0005435545678	1064	Economy	10200.00
0005435545675	1064	Economy	10200.00
0005433341626	1064	Economy	10200.00
0005433341663	1064	Economy	10200.00
0005433341611	1064	Economy	10200.00
0005433341781	1064	Economy	10200.00
0005433341651	1064	Economy	10200.00
0005433341378	1064	Economy	10200.00
0005433341857	1064	Economy	10200.00
0005433341687	1064	Economy	10200.00
0005433463886	1064	Economy	10200.00
0005434446507	1064	Economy	10200.00
0005433341439	1064	Economy	10200.00
0005433341678	1064	Economy	10200.00
0005433341559	1064	Economy	10200.00
0005433341784	1064	Economy	10200.00
0005432293193	1064	Economy	10200.00
0005434445233	1064	Economy	10200.00
0005433341552	1064	Economy	10200.00
0005435092014	1064	Economy	10200.00
0005433341682	1064	Economy	10200.00
0005433341454	1064	Economy	10200.00
0005433158093	1064	Economy	10200.00
0005433341710	1064	Economy	10200.00
0005432293191	1064	Economy	10200.00
0005434446506	1064	Economy	10200.00
0005435545673	1064	Economy	10200.00
0005433341750	1064	Economy	10200.00
0005435545689	1064	Economy	10200.00
0005433341725	1064	Economy	10200.00
0005433341700	1064	Economy	10200.00
0005435092012	1064	Economy	10200.00
0005435092010	1064	Economy	10200.00
0005433341555	1064	Economy	10200.00
0005435545686	1064	Economy	10200.00
0005433341530	1064	Economy	10200.00
0005435545688	1064	Economy	10200.00
0005433269644	1064	Economy	10200.00
0005435092009	1064	Economy	10200.00
0005433341487	1064	Economy	10200.00
0005435092006	1064	Economy	10200.00
0005433158094	1064	Economy	10200.00
0005435545683	1064	Economy	10200.00
0005434445234	1064	Economy	10200.00
0005435545690	1064	Economy	11200.00
0005433269630	1064	Economy	10200.00
0005433341399	1064	Economy	10200.00
0005435545677	1064	Economy	10200.00
0005433341520	1064	Economy	10200.00
0005433341783	1064	Economy	10200.00
0005433341557	1064	Economy	10200.00
0005433341699	1064	Economy	10200.00
0005435092011	1064	Economy	10200.00
0005435092007	1064	Economy	10200.00
0005433341478	1064	Economy	10200.00
0005433341379	1064	Economy	10200.00
0005433341507	1064	Economy	10200.00
0005435545685	1064	Economy	10200.00
0005435092008	1064	Economy	10200.00
0005433462733	1064	Economy	10200.00
0005434445235	1064	Economy	10200.00
0005433341515	1064	Economy	10200.00
0005433463887	1064	Economy	10200.00
0005433342084	1064	Economy	10200.00
0005433341887	1064	Economy	10200.00
0005433341403	1064	Economy	10200.00
0005432293196	1064	Economy	10200.00
0005433341768	1064	Economy	10200.00
0005435545687	1064	Economy	10200.00
0005433341510	1064	Economy	10200.00
0005433341450	1064	Economy	10200.00
0005433341715	1064	Economy	10200.00
0005433341834	1064	Economy	10200.00
0005435545672	1064	Economy	10200.00
0005435545674	1064	Economy	10200.00
0005433341563	1064	Economy	10200.00
0005433341531	1064	Economy	10200.00
0005433341514	1064	Economy	10200.00
0005435545680	1064	Economy	10200.00
0005433341694	1064	Economy	10200.00
0005433341556	1064	Economy	10200.00
0005435092013	1064	Economy	10200.00
0005433269650	1064	Economy	10200.00
0005433341579	1064	Economy	10200.00
0005435545682	1064	Economy	10200.00
0005433341956	1064	Economy	10200.00
0005433341772	1064	Economy	10200.00
0005434446505	1064	Economy	10200.00
0005433342412	17022	Business	30600.00
0005433342418	17022	Business	30600.00
0005433342478	17022	Business	30600.00
0005435508188	17022	Business	30600.00
0005433342479	17022	Business	30600.00
0005433342472	17022	Business	30600.00
0005433342489	17022	Business	30600.00
0005433342463	17022	Business	30600.00
0005433342431	17022	Business	30600.00
0005433342420	17022	Business	30600.00
0005433342407	17022	Business	30600.00
0005433342422	17022	Business	30600.00
0005433342457	17022	Business	30600.00
0005435508181	17022	Business	30600.00
0005433342419	17022	Business	30600.00
0005433342473	17022	Business	30600.00
0005433342493	17022	Business	30600.00
0005433342456	17022	Business	30600.00
0005433342442	17022	Business	30600.00
0005433269685	17022	Business	30600.00
0005435091913	17022	Economy	11200.00
0005433342464	17022	Economy	11200.00
0005433342446	17022	Economy	11200.00
0005433342495	17022	Economy	10200.00
0005435091940	17022	Economy	10200.00
0005433342402	17022	Economy	10200.00
0005433342477	17022	Economy	10200.00
0005433342403	17022	Economy	10200.00
0005433269684	17022	Economy	10200.00
0005433342465	17022	Economy	10200.00
0005433342443	17022	Economy	10200.00
0005433342449	17022	Economy	10200.00
0005433342474	17022	Economy	10200.00
0005433342445	17022	Economy	10200.00
0005435091968	17022	Economy	10200.00
0005433342494	17022	Economy	10200.00
0005433342423	17022	Economy	10200.00
0005433342428	17022	Economy	10200.00
0005433342485	17022	Economy	10200.00
0005433342395	17022	Economy	10200.00
0005433342414	17022	Economy	10200.00
0005433342454	17022	Economy	10200.00
0005433342486	17022	Economy	10200.00
0005433342458	17022	Economy	10200.00
0005433342491	17022	Economy	10200.00
0005433342487	17022	Economy	10200.00
0005433342416	17022	Economy	10200.00
0005433342404	17022	Economy	10200.00
0005433342488	17022	Economy	10200.00
0005433342448	17022	Economy	10200.00
0005433342429	17022	Economy	10200.00
0005433342490	17022	Economy	10200.00
0005433342400	17022	Economy	10200.00
0005433342453	17022	Economy	10200.00
0005433342459	17022	Economy	10200.00
0005433342483	17022	Economy	10200.00
0005435508187	17022	Economy	10200.00
0005433342410	17022	Economy	10200.00
0005433342421	17022	Economy	10200.00
0005433342497	17022	Economy	10200.00
0005433269682	17022	Economy	10200.00
0005433342401	17022	Economy	10200.00
0005433342396	17022	Economy	10200.00
0005433342484	17022	Economy	10200.00
0005435091949	17022	Economy	10200.00
0005433342451	17022	Economy	10200.00
0005433342426	17022	Economy	10200.00
0005435508182	17022	Economy	10200.00
0005433342462	17022	Economy	10200.00
0005433342435	17022	Economy	10200.00
0005433342470	17022	Economy	10200.00
0005433342409	17022	Economy	11200.00
0005433342413	17022	Economy	11200.00
0005433342444	17022	Economy	10200.00
0005433342471	17022	Economy	11200.00
0005433342406	17022	Economy	11200.00
0005435508169	17022	Economy	10200.00
0005435508168	17022	Economy	10200.00
0005433342452	17022	Economy	10200.00
0005433342466	17022	Economy	10200.00
0005433342460	17022	Economy	10200.00
0005433342455	17022	Economy	10200.00
0005433342469	17022	Economy	10200.00
0005433342433	17022	Economy	10200.00
0005433342468	17022	Economy	10200.00
0005433342467	17022	Economy	10200.00
0005433342441	17022	Economy	10200.00
0005433342461	17022	Economy	10200.00
0005433342427	17022	Economy	10200.00
0005435091939	17022	Economy	10200.00
0005433269681	17022	Economy	10200.00
0005435091951	17022	Economy	10200.00
0005433342480	17022	Economy	10200.00
0005433342439	17022	Economy	10200.00
0005433342440	17022	Economy	10200.00
0005433342408	17022	Economy	10200.00
0005433342397	17022	Economy	10200.00
0005433342476	17022	Economy	10200.00
0005433342398	17022	Economy	10200.00
0005433342481	17022	Economy	10200.00
0005433342399	17022	Economy	10200.00
0005433342432	17022	Economy	10200.00
0005433342482	17022	Economy	10200.00
0005435091953	17022	Economy	10200.00
0005434445207	17022	Economy	10200.00
0005433342475	17022	Economy	10200.00
0005433342437	17022	Economy	10200.00
0005433342424	17022	Economy	10200.00
0005433342492	17022	Economy	10200.00
0005433342438	17022	Economy	10200.00
0005433342415	17022	Economy	10200.00
0005433342450	17022	Economy	10200.00
0005433342411	17022	Economy	10200.00
0005433342434	17022	Economy	10200.00
0005433342496	17022	Economy	10200.00
0005433342417	17022	Economy	10200.00
0005433342405	17022	Economy	10200.00
0005433269683	17022	Economy	10200.00
0005433159298	17022	Economy	10200.00
0005433342436	17022	Economy	10200.00
0005433342430	17022	Economy	10200.00
0005433342447	17022	Economy	10200.00
0005433342425	17022	Economy	10200.00
0005434066492	12769	Business	40300.00
0005434066493	12769	Business	40300.00
0005434081511	12769	Business	40300.00
0005434066472	12769	Business	40300.00
0005434081594	12769	Business	40300.00
0005432433643	12769	Business	40300.00
0005434066355	12769	Business	40300.00
0005434066642	12769	Business	40300.00
0005434081538	12769	Economy	13400.00
0005434066383	12769	Economy	13400.00
0005434081515	12769	Economy	13400.00
0005434066593	12769	Economy	13400.00
0005434066779	12769	Economy	13400.00
0005434081499	12769	Economy	13400.00
0005434026675	12769	Economy	13400.00
0005434081593	12769	Economy	13400.00
0005432433644	12769	Economy	13400.00
0005434066344	12769	Economy	13400.00
0005434066455	12769	Economy	13400.00
0005434066631	12769	Economy	13400.00
0005434066475	12769	Economy	13400.00
0005434066473	12769	Economy	13400.00
0005434066501	12769	Economy	13400.00
0005432159827	12769	Economy	13400.00
0005434066389	12769	Economy	13400.00
0005434081487	12769	Economy	13400.00
0005434081555	12769	Economy	13400.00
0005432161138	12769	Economy	13400.00
0005434066437	12769	Economy	13400.00
0005434081544	12769	Economy	13400.00
0005434066545	12769	Economy	13400.00
0005434066398	12769	Economy	13400.00
0005434066712	12769	Economy	13400.00
0005434066458	12769	Economy	13400.00
0005434066564	12769	Economy	14800.00
0005434066401	12769	Economy	14800.00
0005432159829	12769	Economy	14800.00
0005434066502	12769	Economy	14800.00
0005434066771	12769	Economy	14800.00
0005432433647	12769	Economy	13400.00
0005434066322	12769	Economy	13400.00
0005434066382	12769	Economy	13400.00
0005434081484	12769	Economy	13400.00
0005434066323	12769	Economy	13400.00
0005434066641	12769	Economy	13400.00
0005434066477	12769	Economy	13400.00
0005433812885	12769	Economy	13400.00
0005433989681	12769	Economy	13400.00
0005434066356	12769	Economy	13400.00
0005434066314	12769	Economy	13400.00
0005434066366	12769	Economy	13400.00
0005432161136	12769	Economy	13400.00
0005434081579	12769	Economy	13400.00
0005434066520	12769	Economy	13400.00
0005434066617	12769	Economy	13400.00
0005434066572	12769	Economy	13400.00
0005434066630	12769	Economy	13400.00
0005434066489	12769	Economy	13400.00
0005434066454	12769	Economy	13400.00
0005434066538	12769	Economy	13400.00
0005432161139	12769	Economy	13400.00
0005433989682	12769	Economy	13400.00
0005434066377	12769	Economy	13400.00
0005432159830	12769	Economy	13400.00
0005434066524	12769	Economy	13400.00
0005434066393	12769	Economy	13400.00
0005434026674	12769	Economy	13400.00
0005434066825	12769	Economy	13400.00
0005432159828	12769	Economy	13400.00
0005434066461	12769	Economy	13400.00
0005434066381	12769	Economy	13400.00
0005434066585	12769	Economy	13400.00
0005434066562	12769	Economy	13400.00
0005434066405	12769	Economy	13400.00
0005434066565	12769	Economy	13400.00
0005434066601	12769	Economy	13400.00
0005434066448	12769	Economy	13400.00
0005434081519	12769	Economy	13400.00
0005434081520	12769	Economy	13400.00
0005432433645	12769	Economy	13400.00
0005432161137	12769	Economy	13400.00
0005434081550	12769	Economy	13400.00
0005434066392	12769	Economy	13400.00
0005434026676	12769	Economy	13400.00
0005434081512	12769	Economy	13400.00
0005434066315	12769	Economy	13400.00
0005433812884	12769	Economy	13400.00
0005434066616	12769	Economy	13400.00
0005434066537	12769	Economy	13400.00
0005434066409	12769	Economy	13400.00
0005432433646	12769	Economy	13400.00
0005434081530	12769	Economy	13400.00
0005434081477	12769	Economy	13400.00
0005432159826	12769	Economy	13400.00
0005434067023	30695	Business	40300.00
0005434067022	30695	Business	40300.00
0005434067060	30695	Business	40300.00
0005434067045	30695	Business	40300.00
0005434067077	30695	Business	40300.00
0005432186845	30695	Business	40300.00
0005434067065	30695	Business	40300.00
0005434081731	30695	Business	40300.00
0005434067051	30695	Business	40300.00
0005432150140	30695	Business	40300.00
0005434067087	30695	Business	40300.00
0005434067024	30695	Economy	13400.00
0005434067079	30695	Economy	13400.00
0005434067086	30695	Economy	13400.00
0005433989736	30695	Economy	13400.00
0005434081728	30695	Economy	13400.00
0005434067049	30695	Economy	13400.00
0005434067052	30695	Economy	13400.00
0005434067069	30695	Economy	13400.00
0005434067036	30695	Economy	13400.00
0005432186841	30695	Economy	13400.00
0005434067025	30695	Economy	13400.00
0005434067040	30695	Economy	13400.00
0005434081737	30695	Economy	13400.00
0005432150137	30695	Economy	13400.00
0005434067092	30695	Economy	13400.00
0005432150136	30695	Economy	13400.00
0005434067041	30695	Economy	13400.00
0005434067043	30695	Economy	13400.00
0005434067056	30695	Economy	13400.00
0005434067066	30695	Economy	13400.00
0005434067037	30695	Economy	13400.00
0005433989738	30695	Economy	13400.00
0005432150138	30695	Economy	13400.00
0005434067035	30695	Economy	13400.00
0005432433589	30695	Economy	13400.00
0005434067090	30695	Economy	13400.00
0005434067068	30695	Economy	13400.00
0005434081735	30695	Economy	13400.00
0005432150142	30695	Economy	13400.00
0005434081730	30695	Economy	13400.00
0005434067078	30695	Economy	13400.00
0005434067091	30695	Economy	13400.00
0005434067089	30695	Economy	13400.00
0005434067085	30695	Economy	13400.00
0005434067054	30695	Economy	13400.00
0005434067050	30695	Economy	13400.00
0005434067088	30695	Economy	14800.00
0005432186843	30695	Economy	14800.00
0005434067083	30695	Economy	14800.00
0005434067026	30695	Economy	14800.00
0005434067062	30695	Economy	14800.00
0005434067033	30695	Economy	13400.00
0005434067064	30695	Economy	13400.00
0005434081729	30695	Economy	13400.00
0005433989739	30695	Economy	13400.00
0005432150139	30695	Economy	13400.00
0005434067073	30695	Economy	13400.00
0005434067093	30695	Economy	13400.00
0005434067061	30695	Economy	13400.00
0005433989737	30695	Economy	13400.00
0005434067034	30695	Economy	13400.00
0005434067044	30695	Economy	13400.00
0005434081748	30695	Economy	13400.00
0005434067039	30695	Economy	13400.00
0005434067031	30695	Economy	13400.00
0005434067048	30695	Economy	13400.00
0005434081742	30695	Economy	13400.00
0005434081739	30695	Economy	13400.00
0005434067030	30695	Economy	13400.00
0005434081747	30695	Economy	13400.00
0005432433584	30695	Economy	13400.00
0005432150135	30695	Economy	13400.00
0005434067046	30695	Economy	13400.00
0005434081743	30695	Economy	13400.00
0005434067021	30695	Economy	13400.00
0005434067059	30695	Economy	13400.00
0005432150141	30695	Economy	13400.00
0005434067027	30695	Economy	13400.00
0005434081740	30695	Economy	13400.00
0005434067067	30695	Economy	13400.00
0005434067032	30695	Economy	13400.00
0005434067029	30695	Economy	13400.00
0005434067038	30695	Economy	13400.00
0005434067082	30695	Economy	13400.00
0005434067080	30695	Economy	13400.00
0005434067072	30695	Economy	13400.00
0005432150134	30695	Economy	13400.00
0005434067058	30695	Economy	13400.00
0005434067081	30695	Economy	13400.00
0005434067047	30695	Economy	13400.00
0005434081732	30695	Economy	13400.00
0005434067070	30695	Economy	13400.00
0005434067028	30695	Economy	13400.00
0005434081738	30695	Economy	13400.00
0005433989735	30695	Economy	13400.00
0005434067057	30695	Economy	13400.00
0005434081746	30695	Economy	13400.00
0005432186842	30695	Economy	13400.00
0005432433593	30695	Economy	13400.00
0005434081745	30695	Economy	13400.00
0005432186844	30695	Economy	13400.00
0005434067071	30695	Economy	13400.00
0005434067063	30695	Economy	13400.00
0005434067042	30695	Economy	13400.00
0005434067075	30695	Economy	13400.00
0005434081733	30695	Economy	13400.00
0005434067084	30695	Economy	13400.00
0005434067074	30695	Economy	13400.00
0005432433590	30695	Economy	13400.00
0005432433583	30695	Economy	13400.00
0005434067076	30695	Economy	13400.00
0005434081741	30695	Economy	13400.00
0005434081734	30695	Economy	13400.00
0005434067055	30695	Economy	13400.00
0005432433591	30695	Economy	13400.00
0005434081736	30695	Economy	13400.00
0005434067053	30695	Economy	13400.00
0005434081744	30695	Economy	13400.00
0005433689878	19365	Economy	17600.00
0005433689877	19365	Economy	17600.00
0005433689884	19365	Economy	17600.00
0005433689879	19365	Economy	17600.00
0005433689874	19365	Economy	17600.00
0005433689883	19365	Economy	17600.00
0005433689881	19365	Economy	17600.00
0005433689882	19365	Economy	17600.00
0005433689880	19365	Economy	17600.00
0005434264692	5501	Business	35300.00
0005435765830	5501	Business	35300.00
0005435765869	5501	Business	35300.00
0005434264748	5501	Business	35300.00
0005435461930	5501	Business	35300.00
0005434264737	5501	Business	35300.00
0005435765851	5501	Business	35300.00
0005434264677	5501	Business	35300.00
0005435461933	5501	Business	35300.00
0005435765850	5501	Business	35300.00
0005433527243	5501	Business	35300.00
0005435461913	5501	Business	35300.00
0005435765854	5501	Business	35300.00
0005434264700	5501	Business	35300.00
0005434264797	5501	Business	35300.00
0005435725563	5501	Business	35300.00
0005435765849	5501	Business	35300.00
0005435765812	5501	Business	35300.00
0005435765823	5501	Business	35300.00
0005435461859	5501	Business	35300.00
0005435722040	5501	Economy	12900.00
0005435765853	5501	Economy	12900.00
0005435765848	5501	Economy	11800.00
0005435765831	5501	Economy	11800.00
0005434264722	5501	Economy	11800.00
0005435461902	5501	Economy	11800.00
0005435765860	5501	Economy	11800.00
0005435461813	5501	Economy	11800.00
0005434264773	5501	Economy	11800.00
0005435765858	5501	Economy	11800.00
0005435461968	5501	Economy	11800.00
0005435765837	5501	Economy	11800.00
0005435461977	5501	Economy	11800.00
0005435461834	5501	Economy	11800.00
0005435765835	5501	Economy	11800.00
0005435765843	5501	Economy	11800.00
0005435461878	5501	Economy	11800.00
0005435461768	5501	Economy	11800.00
0005433527242	5501	Economy	11800.00
0005435765832	5501	Economy	11800.00
0005435765826	5501	Economy	11800.00
0005435461914	5501	Economy	11800.00
0005434264788	5501	Economy	11800.00
0005434264739	5501	Economy	11800.00
0005435461814	5501	Economy	11800.00
0005434264703	5501	Economy	11800.00
0005435723031	5501	Economy	11800.00
0005434264828	5501	Economy	11800.00
0005435765808	5501	Economy	11800.00
0005435725564	5501	Economy	11800.00
0005435765845	5501	Economy	11800.00
0005435765817	5501	Economy	11800.00
0005433529255	5501	Economy	11800.00
0005434264827	5501	Economy	11800.00
0005434264705	5501	Economy	11800.00
0005435765842	5501	Economy	11800.00
0005433529256	5501	Economy	11800.00
0005435461797	5501	Economy	11800.00
0005435765815	5501	Economy	11800.00
0005435765824	5501	Economy	11800.00
0005435461879	5501	Economy	11800.00
0005435765864	5501	Economy	11800.00
0005433527246	5501	Economy	11800.00
0005435765866	5501	Economy	11800.00
0005435765861	5501	Economy	11800.00
0005435765821	5501	Economy	11800.00
0005434264777	5501	Economy	11800.00
0005435461795	5501	Economy	11800.00
0005435461931	5501	Economy	11800.00
0005435765829	5501	Economy	11800.00
0005435765820	5501	Economy	11800.00
0005435461903	5501	Economy	11800.00
0005435735106	5501	Economy	11800.00
0005435461890	5501	Economy	11800.00
0005435765839	5501	Economy	11800.00
0005435461858	5501	Economy	11800.00
0005435461973	5501	Economy	11800.00
0005435461907	5501	Economy	11800.00
0005435765871	5501	Economy	11800.00
0005434264770	5501	Economy	11800.00
0005434264690	5501	Economy	11800.00
0005434264789	5501	Economy	11800.00
0005435765811	5501	Economy	11800.00
0005435765809	5501	Economy	11800.00
0005435722039	5501	Economy	11800.00
0005435765816	5501	Economy	11800.00
0005435765828	5501	Economy	11800.00
0005435735108	5501	Economy	11800.00
0005432140396	5501	Economy	11800.00
0005434264689	5501	Economy	11800.00
0005432140392	5501	Economy	11800.00
0005435461857	5501	Economy	11800.00
0005435765844	5501	Economy	11800.00
0005435765870	5501	Economy	11800.00
0005435461937	5501	Economy	11800.00
0005435461901	5501	Economy	11800.00
0005435723032	5501	Economy	11800.00
0005434264704	5501	Economy	11800.00
0005435461801	5501	Economy	11800.00
0005435735105	5501	Economy	11800.00
0005435461938	5501	Economy	12900.00
0005435765827	5501	Economy	11800.00
0005435765814	5501	Economy	12900.00
0005435765838	5501	Economy	11800.00
0005435725565	5501	Economy	11800.00
0005435765856	5501	Economy	12900.00
0005434264740	5501	Economy	12900.00
0005432140393	5501	Economy	11800.00
0005435461851	5501	Economy	11800.00
0005435725562	5501	Economy	11800.00
0005432140398	5501	Economy	11800.00
0005432140391	5501	Economy	11800.00
0005433527244	5501	Economy	11800.00
0005434264795	5501	Economy	11800.00
0005434264685	5501	Economy	11800.00
0005435765868	5501	Economy	11800.00
0005435765855	5501	Economy	11800.00
0005435765813	5501	Economy	11800.00
0005435461853	5501	Economy	11800.00
0005435765836	5501	Economy	11800.00
0005435765865	5501	Economy	11800.00
0005435765857	5501	Economy	11800.00
0005435765852	5501	Economy	11800.00
0005435765834	5501	Economy	11800.00
0005435461774	5501	Economy	11800.00
0005435765846	5501	Economy	11800.00
0005432140397	5501	Economy	11800.00
0005435461976	5501	Economy	11800.00
0005432140394	5501	Economy	11800.00
0005433529254	5501	Economy	11800.00
0005434831076	5501	Economy	11800.00
0005435461784	5501	Economy	11800.00
0005434264701	5501	Economy	11800.00
0005434831075	5501	Economy	11800.00
0005435461783	5501	Economy	11800.00
0005435765822	5501	Economy	11800.00
0005435461904	5501	Economy	11800.00
0005435765810	5501	Economy	11800.00
0005435765859	5501	Economy	11800.00
0005435765833	5501	Economy	11800.00
0005435765819	5501	Economy	11800.00
0005432140395	5501	Economy	11800.00
0005434831070	5501	Economy	11800.00
0005435461802	5501	Economy	11800.00
0005434264816	5501	Economy	11800.00
0005435765825	5501	Economy	11800.00
0005435461767	5501	Economy	11800.00
0005434264738	5501	Economy	11800.00
0005435461882	5501	Economy	11800.00
0005433527245	5501	Economy	11800.00
0005434264778	5501	Economy	11800.00
0005434264787	5501	Economy	11800.00
0005435765840	5501	Economy	11800.00
0005435735107	5501	Economy	11800.00
0005435765863	5501	Economy	11800.00
0005435765867	5501	Economy	11800.00
0005434264702	5501	Economy	11800.00
0005435725566	5501	Economy	11800.00
0005435765862	5501	Economy	11800.00
0005435735109	5501	Economy	11800.00
0005434264688	5501	Economy	11800.00
0005435765841	5501	Economy	11800.00
0005435765818	5501	Economy	11800.00
0005435461844	5501	Economy	11800.00
0005435461886	5501	Economy	11800.00
0005435765847	5501	Economy	11800.00
0005435461912	5501	Economy	11800.00
0005434264983	13471	Business	35300.00
0005434264980	13471	Business	35300.00
0005434264979	13471	Business	35300.00
0005435462182	13471	Business	35300.00
0005435765313	13471	Business	35300.00
0005433533241	13471	Business	35300.00
0005434264978	13471	Business	35300.00
0005435462206	13471	Business	35300.00
0005435720119	13471	Business	35300.00
0005434264967	13471	Business	35300.00
0005433529215	13471	Business	35300.00
0005432535802	13471	Business	35300.00
0005432194486	13471	Business	35300.00
0005434264987	13471	Business	35300.00
0005434264991	13471	Business	35300.00
0005435723016	13471	Business	35300.00
0005434264982	13471	Economy	12900.00
0005434264986	13471	Economy	12900.00
0005435765236	13471	Economy	12900.00
0005433533240	13471	Economy	11800.00
0005435462190	13471	Economy	11800.00
0005435462211	13471	Economy	11800.00
0005435765221	13471	Economy	11800.00
0005435462189	13471	Economy	11800.00
0005435765199	13471	Economy	11800.00
0005432535805	13471	Economy	11800.00
0005433533244	13471	Economy	11800.00
0005435765151	13471	Economy	11800.00
0005435462185	13471	Economy	11800.00
0005435765332	13471	Economy	11800.00
0005435765275	13471	Economy	11800.00
0005435765279	13471	Economy	11800.00
0005435765276	13471	Economy	11800.00
0005435765225	13471	Economy	11800.00
0005435765200	13471	Economy	11800.00
0005434264976	13471	Economy	11800.00
0005435725538	13471	Economy	11800.00
0005435462213	13471	Economy	11800.00
0005435765330	13471	Economy	11800.00
0005434264990	13471	Economy	11800.00
0005435462194	13471	Economy	11800.00
0005434264966	13471	Economy	11800.00
0005435765150	13471	Economy	11800.00
0005435462215	13471	Economy	11800.00
0005435043280	13471	Economy	11800.00
0005433533242	13471	Economy	11800.00
0005433533243	13471	Economy	11800.00
0005435043278	13471	Economy	11800.00
0005435765230	13471	Economy	11800.00
0005433533259	13471	Economy	11800.00
0005435462192	13471	Economy	11800.00
0005435462183	13471	Economy	11800.00
0005434831121	13471	Economy	11800.00
0005435462201	13471	Economy	11800.00
0005435735082	13471	Economy	11800.00
0005435765298	13471	Economy	11800.00
0005435462193	13471	Economy	11800.00
0005435462198	13471	Economy	11800.00
0005435462218	13471	Economy	11800.00
0005434264975	13471	Economy	11800.00
0005435765331	13471	Economy	11800.00
0005435043279	13471	Economy	11800.00
0005435462191	13471	Economy	11800.00
0005435462202	13471	Economy	11800.00
0005434264974	13471	Economy	11800.00
0005434264972	13471	Economy	11800.00
0005434264969	13471	Economy	11800.00
0005435765157	13471	Economy	11800.00
0005435462209	13471	Economy	11800.00
0005435462195	13471	Economy	11800.00
0005435765158	13471	Economy	11800.00
0005435462196	13471	Economy	11800.00
0005435462208	13471	Economy	11800.00
0005434831123	13471	Economy	11800.00
0005435462214	13471	Economy	12900.00
0005435765193	13471	Economy	11800.00
0005435462186	13471	Economy	11800.00
0005435765192	13471	Economy	12900.00
0005435725519	13471	Economy	12900.00
0005434831122	13471	Economy	11800.00
0005435765288	13471	Economy	11800.00
0005435765266	13471	Economy	11800.00
0005435765154	13471	Economy	11800.00
0005435462200	13471	Economy	11800.00
0005433533246	13471	Economy	11800.00
0005435765198	13471	Economy	11800.00
0005435725537	13471	Economy	11800.00
0005432194485	13471	Economy	11800.00
0005432194482	13471	Economy	11800.00
0005435462184	13471	Economy	11800.00
0005435720118	13471	Economy	11800.00
0005435462216	13471	Economy	11800.00
0005434264971	13471	Economy	11800.00
0005435462204	13471	Economy	11800.00
0005434264989	13471	Economy	11800.00
0005435462217	13471	Economy	11800.00
0005434264985	13471	Economy	11800.00
0005433533257	13471	Economy	11800.00
0005435462199	13471	Economy	11800.00
0005435462203	13471	Economy	11800.00
0005435765258	13471	Economy	11800.00
0005435765227	13471	Economy	11800.00
0005435462207	13471	Economy	11800.00
0005435462219	13471	Economy	11800.00
0005435462205	13471	Economy	11800.00
0005435462197	13471	Economy	11800.00
0005435765194	13471	Economy	11800.00
0005434264970	13471	Economy	11800.00
0005435462210	13471	Economy	11800.00
0005432535806	13471	Economy	11800.00
0005434264968	13471	Economy	11800.00
0005434264988	13471	Economy	11800.00
0005435462181	13471	Economy	11800.00
0005434264973	13471	Economy	11800.00
0005432535804	13471	Economy	11800.00
0005435462188	13471	Economy	11800.00
0005433533258	13471	Economy	11800.00
0005432194484	13471	Economy	11800.00
0005432535803	13471	Economy	11800.00
0005435765231	13471	Economy	11800.00
0005433529216	13471	Economy	11800.00
0005434264984	13471	Economy	11800.00
0005435765226	13471	Economy	11800.00
0005435723014	13471	Economy	11800.00
0005432194483	13471	Economy	11800.00
0005435462187	13471	Economy	11800.00
0005434264977	13471	Economy	11800.00
0005435462212	13471	Economy	11800.00
0005434264981	13471	Economy	11800.00
0005433533245	13471	Economy	11800.00
0005434602859	18743	Economy	3300.00
0005434602862	18743	Economy	3300.00
0005434602863	18743	Economy	3300.00
0005434602858	18743	Economy	3300.00
0005434602861	18743	Economy	3300.00
0005434513561	18671	Economy	3300.00
0005434604841	18671	Economy	3300.00
0005434604842	18671	Economy	3300.00
0005434513563	18671	Economy	3300.00
0005434514949	18671	Economy	3300.00
0005434513562	18671	Economy	3300.00
0005434513564	18671	Economy	3300.00
0005434514948	18671	Economy	3300.00
0005434604853	18671	Economy	3300.00
0005432632704	4122	Business	88300.00
0005435844260	4122	Business	88300.00
0005435846195	4122	Business	88300.00
0005435846197	4122	Economy	29400.00
0005432632687	4122	Economy	29400.00
0005432649361	4122	Economy	29400.00
0005432649360	4122	Economy	29400.00
0005432632694	4122	Economy	29400.00
0005432632688	4122	Economy	32400.00
0005432649369	4122	Economy	32400.00
0005432632699	4122	Economy	32400.00
0005432632691	4122	Economy	32400.00
0005432649363	4122	Economy	29400.00
0005432649364	4122	Economy	29400.00
0005432632705	4122	Economy	29400.00
0005432632686	4122	Economy	29400.00
0005432649357	4122	Economy	29400.00
0005435846193	4122	Economy	29400.00
0005432649362	4122	Economy	29400.00
0005432632700	4122	Economy	29400.00
0005432632701	4122	Economy	29400.00
0005432632690	4122	Economy	29400.00
0005432649368	4122	Economy	29400.00
0005432632684	4122	Economy	29400.00
0005432649365	4122	Economy	29400.00
0005432649353	4122	Economy	29400.00
0005435844261	4122	Economy	29400.00
0005432632693	4122	Economy	29400.00
0005435846196	4122	Economy	29400.00
0005432649352	4122	Economy	29400.00
0005435846216	4122	Economy	29400.00
0005432649359	4122	Economy	29400.00
0005435846191	4122	Economy	29400.00
0005435846200	4122	Economy	29400.00
0005432632702	4122	Economy	29400.00
0005432649354	4122	Economy	29400.00
0005432632703	4122	Economy	29400.00
0005432632685	4122	Economy	29400.00
0005432632695	4122	Economy	29400.00
0005432632696	4122	Economy	29400.00
0005432632689	4122	Economy	29400.00
0005432649356	4122	Economy	29400.00
0005432632692	4122	Economy	29400.00
0005432649367	4122	Economy	29400.00
0005432649355	4122	Economy	29400.00
0005432649366	4122	Economy	29400.00
0005432632697	4122	Economy	29400.00
0005432649358	4122	Economy	29400.00
0005432632698	4122	Economy	29400.00
0005432295862	1818	Business	48700.00
0005433008038	1818	Business	48700.00
0005433007931	1818	Business	48700.00
0005433007890	1818	Business	48700.00
0005433284871	1818	Business	48700.00
0005433284833	1818	Business	48700.00
0005433284908	1818	Business	48700.00
0005433284778	1818	Business	48700.00
0005433284839	1818	Business	48700.00
0005433284922	1818	Business	48700.00
0005433284874	1818	Business	48700.00
0005433284864	1818	Business	48700.00
0005433007972	1818	Economy	16200.00
0005433284926	1818	Economy	16200.00
0005433284960	1818	Economy	16200.00
0005433284832	1818	Economy	16200.00
0005433008212	1818	Economy	16200.00
0005433284959	1818	Economy	16200.00
0005433284779	1818	Economy	16200.00
0005433284882	1818	Economy	16200.00
0005433008109	1818	Economy	16200.00
0005432295865	1818	Economy	17900.00
0005433007958	1818	Economy	17900.00
0005433007923	1818	Economy	17900.00
0005433008121	1818	Economy	17900.00
0005433007980	1818	Economy	17900.00
0005433008016	1818	Economy	16200.00
0005432295863	1818	Economy	16200.00
0005433007944	1818	Economy	16200.00
0005433284810	1818	Economy	16200.00
0005433284863	1818	Economy	16200.00
0005433284827	1818	Economy	16200.00
0005433284811	1818	Economy	16200.00
0005433008073	1818	Economy	16200.00
0005433008028	1818	Economy	16200.00
0005433284826	1818	Economy	16200.00
0005433284880	1818	Economy	16200.00
0005433284889	1818	Economy	16200.00
0005433007943	1818	Economy	16200.00
0005433284940	1818	Economy	16200.00
0005433284920	1818	Economy	16200.00
0005433284927	1818	Economy	16200.00
0005433284847	1818	Economy	16200.00
0005433284921	1818	Economy	16200.00
0005433284835	1818	Economy	16200.00
0005433007925	1818	Economy	16200.00
0005433007878	1818	Economy	16200.00
0005433007924	1818	Economy	16200.00
0005433284943	1818	Economy	16200.00
0005433810520	1818	Economy	16200.00
0005433007893	1818	Economy	16200.00
0005433284846	1818	Economy	16200.00
0005433284881	1818	Economy	16200.00
0005433284862	1818	Economy	16200.00
0005433284836	1818	Economy	16200.00
0005433284831	1818	Economy	16200.00
0005433007953	1818	Economy	16200.00
0005432295864	1818	Economy	16200.00
0005433284834	1818	Economy	16200.00
0005433007971	1818	Economy	16200.00
0005433007970	1818	Economy	16200.00
0005433007959	1818	Economy	16200.00
0005433810518	1818	Economy	16200.00
0005433284830	1818	Economy	16200.00
0005433284937	1818	Economy	16200.00
0005433008116	1818	Economy	16200.00
0005433284909	1818	Economy	16200.00
0005433284860	1818	Economy	16200.00
0005433284850	1818	Economy	16200.00
0005433007969	1818	Economy	16200.00
0005433007841	1818	Economy	16200.00
0005433007930	1818	Economy	16200.00
0005433007973	1818	Economy	16200.00
0005433007917	1818	Economy	16200.00
0005433008063	1818	Economy	16200.00
0005433007879	1818	Economy	16200.00
0005433284789	1818	Economy	16200.00
0005433008085	1818	Economy	16200.00
0005433008074	1818	Economy	16200.00
0005433810519	1818	Economy	16200.00
0005433007979	1818	Economy	16200.00
0005433008017	1818	Economy	16200.00
0005433284848	1818	Economy	16200.00
0005433008027	1818	Economy	16200.00
0005433284851	1818	Economy	16200.00
0005433284790	1818	Economy	16200.00
0005433285075	22596	Business	48700.00
0005433008306	22596	Business	48700.00
0005433008292	22596	Business	48700.00
0005433285083	22596	Business	48700.00
0005433285100	22596	Business	48700.00
0005433008320	22596	Business	48700.00
0005433285072	22596	Business	48700.00
0005433285080	22596	Business	48700.00
0005433285091	22596	Business	48700.00
0005433285092	22596	Business	48700.00
0005433008309	22596	Business	48700.00
0005433008294	22596	Economy	16200.00
0005433008289	22596	Economy	16200.00
0005433008305	22596	Economy	16200.00
0005433285081	22596	Economy	16200.00
0005433008310	22596	Economy	16200.00
0005433008290	22596	Economy	17900.00
0005433008286	22596	Economy	17900.00
0005433008327	22596	Economy	17900.00
0005433008304	22596	Economy	17900.00
0005433285087	22596	Economy	17900.00
0005433285094	22596	Economy	16200.00
0005433285098	22596	Economy	16200.00
0005433008301	22596	Economy	16200.00
0005433008317	22596	Economy	16200.00
0005433285089	22596	Economy	16200.00
0005433008316	22596	Economy	16200.00
0005433008311	22596	Economy	16200.00
0005433285101	22596	Economy	16200.00
0005433008293	22596	Economy	16200.00
0005433008329	22596	Economy	16200.00
0005433008319	22596	Economy	16200.00
0005433008287	22596	Economy	16200.00
0005433008291	22596	Economy	16200.00
0005433008314	22596	Economy	16200.00
0005433008297	22596	Economy	16200.00
0005433008298	22596	Economy	16200.00
0005433008332	22596	Economy	16200.00
0005433008315	22596	Economy	16200.00
0005433008330	22596	Economy	16200.00
0005433008322	22596	Economy	16200.00
0005433008328	22596	Economy	16200.00
0005433285082	22596	Economy	16200.00
0005433008321	22596	Economy	16200.00
0005433285090	22596	Economy	16200.00
0005433008318	22596	Economy	16200.00
0005433008295	22596	Economy	16200.00
0005433008303	22596	Economy	16200.00
0005433285077	22596	Economy	16200.00
0005433285073	22596	Economy	16200.00
0005433008296	22596	Economy	16200.00
0005433285074	22596	Economy	16200.00
0005433008307	22596	Economy	16200.00
0005433285095	22596	Economy	16200.00
0005433008312	22596	Economy	16200.00
0005433285093	22596	Economy	16200.00
0005433285076	22596	Economy	16200.00
0005433285088	22596	Economy	16200.00
0005433008324	22596	Economy	16200.00
0005433285079	22596	Economy	16200.00
0005433285078	22596	Economy	16200.00
0005433008326	22596	Economy	16200.00
0005433285084	22596	Economy	16200.00
0005433008331	22596	Economy	16200.00
0005433285086	22596	Economy	16200.00
0005433008300	22596	Economy	16200.00
0005433008325	22596	Economy	16200.00
0005433008313	22596	Economy	16200.00
0005433008323	22596	Economy	16200.00
0005433285096	22596	Economy	16200.00
0005433008302	22596	Economy	16200.00
0005433008288	22596	Economy	16200.00
0005433285102	22596	Economy	16200.00
0005433008308	22596	Economy	16200.00
0005433008299	22596	Economy	16200.00
0005433285099	22596	Economy	16200.00
0005433285071	22596	Economy	16200.00
0005433285097	22596	Economy	16200.00
0005433285085	22596	Economy	16200.00
0005433846366	5590	Business	99800.00
0005435282109	5590	Business	99800.00
0005435282055	5590	Business	99800.00
0005435282176	5590	Business	99800.00
0005433846348	5590	Business	99800.00
0005433815352	5590	Business	99800.00
0005433846378	5590	Business	99800.00
0005433815354	5590	Business	99800.00
0005433815353	5590	Business	99800.00
0005433846370	5590	Business	99800.00
0005432081469	5590	Business	99800.00
0005435282188	5590	Business	99800.00
0005433846359	5590	Business	99800.00
0005433846336	5590	Business	99800.00
0005433846349	5590	Business	99800.00
0005434173459	5590	Economy	33300.00
0005433815351	5590	Business	99800.00
0005433846352	5590	Economy	33300.00
0005433846328	5590	Economy	33300.00
0005433846362	5590	Economy	33300.00
0005433846356	5590	Economy	33300.00
0005433846324	5590	Economy	33300.00
0005433846369	5590	Economy	33300.00
0005433846344	5590	Economy	36600.00
0005433846373	5590	Economy	36600.00
0005435282175	5590	Economy	33300.00
0005433846342	5590	Economy	36600.00
0005433846351	5590	Economy	33300.00
0005433846329	5590	Economy	33300.00
0005435282065	5590	Economy	33300.00
0005433846365	5590	Economy	33300.00
0005435282203	5590	Economy	33300.00
0005433846376	5590	Economy	33300.00
0005432081472	5590	Economy	33300.00
0005433846331	5590	Economy	33300.00
0005435282122	5590	Economy	33300.00
0005433846335	5590	Economy	33300.00
0005433846361	5590	Economy	33300.00
0005433846346	5590	Economy	33300.00
0005433846363	5590	Economy	33300.00
0005435282202	5590	Economy	33300.00
0005433846350	5590	Economy	33300.00
0005432081471	5590	Economy	33300.00
0005433846325	5590	Economy	33300.00
0005435282189	5590	Economy	33300.00
0005434173472	5590	Economy	33300.00
0005435282066	5590	Economy	33300.00
0005433846338	5590	Economy	33300.00
0005433846337	5590	Economy	33300.00
0005433846368	5590	Economy	33300.00
0005433846353	5590	Economy	33300.00
0005433846357	5590	Economy	33300.00
0005433846340	5590	Economy	33300.00
0005435282149	5590	Economy	33300.00
0005433846345	5590	Economy	33300.00
0005433846334	5590	Economy	33300.00
0005435282167	5590	Economy	33300.00
0005432081468	5590	Economy	33300.00
0005435282181	5590	Economy	33300.00
0005433846341	5590	Economy	33300.00
0005434173458	5590	Economy	33300.00
0005433846354	5590	Economy	33300.00
0005433846355	5590	Economy	33300.00
0005433846367	5590	Economy	33300.00
0005435282147	5590	Economy	33300.00
0005433846360	5590	Economy	33300.00
0005433846321	5590	Economy	33300.00
0005432081467	5590	Economy	33300.00
0005433846374	5590	Economy	33300.00
0005433846358	5590	Economy	33300.00
0005433846375	5590	Economy	33300.00
0005433846326	5590	Economy	33300.00
0005433846343	5590	Economy	33300.00
0005433846327	5590	Economy	33300.00
0005433846332	5590	Economy	33300.00
0005433846330	5590	Economy	33300.00
0005433846364	5590	Economy	33300.00
0005433846371	5590	Economy	33300.00
0005434173454	5590	Economy	33300.00
0005433846339	5590	Economy	33300.00
0005433846347	5590	Economy	33300.00
0005433846322	5590	Economy	33300.00
0005433846377	5590	Economy	33300.00
0005435282086	5590	Economy	33300.00
0005433846372	5590	Economy	33300.00
0005433846379	5590	Economy	33300.00
0005435282056	5590	Economy	33300.00
0005435282110	5590	Economy	33300.00
0005433846333	5590	Economy	33300.00
0005433846323	5590	Economy	33300.00
0005432081470	5590	Economy	33300.00
0005432081466	5590	Economy	33300.00
0005434173497	13857	Business	99800.00
0005435282344	13857	Business	99800.00
0005433845911	13857	Business	99800.00
0005435282347	13857	Business	99800.00
0005435282364	13857	Business	99800.00
0005433846065	13857	Business	99800.00
0005433845786	13857	Business	99800.00
0005433845922	13857	Business	99800.00
0005435282361	13857	Business	99800.00
0005433845827	13857	Business	99800.00
0005435282362	13857	Business	99800.00
0005435282363	13857	Business	99800.00
0005433846055	13857	Business	99800.00
0005433845714	13857	Business	99800.00
0005433845804	13857	Economy	33300.00
0005435282348	13857	Economy	33300.00
0005432003681	13857	Economy	33300.00
0005433845819	13857	Economy	33300.00
0005433845742	13857	Economy	33300.00
0005433845989	13857	Economy	33300.00
0005435282360	13857	Economy	33300.00
0005433845712	13857	Economy	33300.00
0005433845954	13857	Economy	33300.00
0005433845945	13857	Economy	36600.00
0005433846054	13857	Economy	36600.00
0005435282340	13857	Economy	36600.00
0005433845891	13857	Economy	33300.00
0005435282359	13857	Economy	33300.00
0005435282353	13857	Economy	33300.00
0005435282367	13857	Economy	33300.00
0005433845838	13857	Economy	33300.00
0005433846025	13857	Economy	33300.00
0005433845975	13857	Economy	33300.00
0005433845803	13857	Economy	33300.00
0005433845898	13857	Economy	33300.00
0005435282366	13857	Economy	33300.00
0005435282339	13857	Economy	33300.00
0005433845713	13857	Economy	33300.00
0005435282358	13857	Economy	33300.00
0005433845781	13857	Economy	33300.00
0005435282357	13857	Economy	33300.00
0005433845774	13857	Economy	33300.00
0005433846000	13857	Economy	33300.00
0005433815314	13857	Economy	33300.00
0005434173494	13857	Economy	33300.00
0005435282355	13857	Economy	33300.00
0005435282356	13857	Economy	33300.00
0005435282351	13857	Economy	33300.00
0005433845874	13857	Economy	33300.00
0005433845705	13857	Economy	33300.00
0005433845683	13857	Economy	33300.00
0005435282352	13857	Economy	33300.00
0005435282349	13857	Economy	33300.00
0005433845815	13857	Economy	33300.00
0005433845889	13857	Economy	33300.00
0005432003680	13857	Economy	33300.00
0005433845856	13857	Economy	33300.00
0005434173493	13857	Economy	33300.00
0005435282346	13857	Economy	33300.00
0005433845885	13857	Economy	33300.00
0005435282354	13857	Economy	33300.00
0005433845818	13857	Economy	33300.00
0005433845859	13857	Economy	33300.00
0005433845929	13857	Economy	33300.00
0005435282342	13857	Economy	33300.00
0005432003682	13857	Economy	33300.00
0005433845711	13857	Economy	33300.00
0005433845787	13857	Economy	33300.00
0005435282345	13857	Economy	33300.00
0005433846053	13857	Economy	33300.00
0005435282365	13857	Economy	33300.00
0005433845892	13857	Economy	33300.00
0005433845988	13857	Economy	33300.00
0005433845914	13857	Economy	33300.00
0005433845934	13857	Economy	33300.00
0005433845884	13857	Economy	33300.00
0005433845807	13857	Economy	33300.00
0005433845995	13857	Economy	33300.00
0005435282341	13857	Economy	33300.00
0005433845779	13857	Economy	33300.00
0005433845990	13857	Economy	33300.00
0005433845996	13857	Economy	33300.00
0005434173496	13857	Economy	33300.00
0005435282350	13857	Economy	33300.00
0005433846039	13857	Economy	33300.00
0005433845780	13857	Economy	33300.00
0005435282343	13857	Economy	33300.00
0005433845976	13857	Economy	33300.00
0005433845899	13857	Economy	33300.00
0005434173495	13857	Economy	33300.00
0005434620473	7824	Economy	16600.00
0005434620465	7824	Economy	16600.00
0005434620458	7824	Economy	16600.00
0005435332177	7824	Economy	16600.00
0005434620464	7824	Economy	15100.00
0005434620466	7824	Economy	15100.00
0005435332189	7824	Economy	15100.00
0005434620471	7824	Economy	15100.00
0005434620454	7824	Economy	15100.00
0005434620453	7824	Economy	15100.00
0005434620455	7824	Economy	15100.00
0005434620461	7824	Economy	15100.00
0005432112501	7824	Economy	15100.00
0005434620468	7824	Economy	15100.00
0005432112502	7824	Economy	15100.00
0005435332190	7824	Economy	15100.00
0005434620467	7824	Economy	15100.00
0005434620457	7824	Economy	15100.00
0005435332184	7824	Economy	15100.00
0005435332203	7824	Economy	15100.00
0005435332204	7824	Economy	15100.00
0005434620456	7824	Economy	15100.00
0005435332202	7824	Economy	15100.00
0005434620470	7824	Economy	15100.00
0005434620459	7824	Economy	15100.00
0005434620469	7824	Economy	15100.00
0005435332212	7824	Economy	15100.00
0005434620463	7824	Economy	15100.00
0005432112500	7824	Economy	15100.00
0005434620462	7824	Economy	15100.00
0005435332213	7824	Economy	15100.00
0005434620472	7824	Economy	15100.00
0005434620460	7824	Economy	15100.00
0005434620233	32963	Economy	16600.00
0005434620366	32963	Economy	16600.00
0005434620343	32963	Economy	15100.00
0005434620365	32963	Economy	15100.00
0005434620315	32963	Economy	15100.00
0005434620305	32963	Economy	15100.00
0005434620247	32963	Economy	15100.00
0005434620314	32963	Economy	15100.00
0005434620318	32963	Economy	15100.00
0005434620367	32963	Economy	15100.00
0005434620232	32963	Economy	15100.00
0005435332265	32963	Economy	15100.00
0005435332273	32963	Economy	15100.00
0005434620238	32963	Economy	15100.00
0005435332271	32963	Economy	15100.00
0005434620248	32963	Economy	15100.00
0005435332264	32963	Economy	15100.00
0005434620237	32963	Economy	15100.00
0005434620319	32963	Economy	15100.00
0005435332270	32963	Economy	15100.00
0005434620342	32963	Economy	15100.00
0005435332272	32963	Economy	15100.00
0005434620283	32963	Economy	15100.00
0005434620279	32963	Economy	15100.00
0005435332267	32963	Economy	15100.00
0005435332269	32963	Economy	15100.00
0005434620282	32963	Economy	15100.00
0005435332266	32963	Economy	15100.00
0005435332268	32963	Economy	15100.00
0005435785123	4278	Business	38000.00
0005435785126	4278	Business	38000.00
0005432190606	4278	Business	38000.00
0005434993962	4278	Business	38000.00
0005435785146	4278	Business	38000.00
0005435785122	4278	Business	38000.00
0005435785139	4278	Business	38000.00
0005435785117	4278	Business	38000.00
0005435785118	4278	Business	38000.00
0005434993960	4278	Economy	12700.00
0005435785142	4278	Economy	12700.00
0005435785135	4278	Economy	12700.00
0005435785125	4278	Economy	12700.00
0005435785130	4278	Economy	12700.00
0005435785150	4278	Economy	12700.00
0005435785133	4278	Economy	12700.00
0005435937323	4278	Economy	12700.00
0005435937324	4278	Economy	13900.00
0005435937307	4278	Economy	13900.00
0005434993955	4278	Economy	12700.00
0005435785140	4278	Economy	12700.00
0005435918598	4278	Economy	12700.00
0005435785136	4278	Economy	12700.00
0005435785144	4278	Economy	12700.00
0005435918580	4278	Economy	12700.00
0005434993958	4278	Economy	12700.00
0005435785124	4278	Economy	12700.00
0005435918610	4278	Economy	12700.00
0005435785129	4278	Economy	12700.00
0005432190604	4278	Economy	12700.00
0005435785132	4278	Economy	12700.00
0005434993961	4278	Economy	12700.00
0005435785148	4278	Economy	12700.00
0005434993964	4278	Economy	12700.00
0005434993957	4278	Economy	12700.00
0005435918589	4278	Economy	12700.00
0005435785143	4278	Economy	12700.00
0005435785127	4278	Economy	12700.00
0005435785138	4278	Economy	12700.00
0005435785120	4278	Economy	12700.00
0005432190603	4278	Economy	12700.00
0005434993956	4278	Economy	12700.00
0005435937319	4278	Economy	12700.00
0005435785145	4278	Economy	12700.00
0005435918588	4278	Economy	12700.00
0005435785131	4278	Economy	12700.00
0005435785147	4278	Economy	12700.00
0005435937308	4278	Economy	12700.00
0005435785121	4278	Economy	12700.00
0005435785149	4278	Economy	12700.00
0005435785119	4278	Economy	12700.00
0005435785116	4278	Economy	12700.00
0005434993963	4278	Economy	12700.00
0005435937322	4278	Economy	12700.00
0005435918592	4278	Economy	12700.00
0005432190605	4278	Economy	12700.00
0005434993959	4278	Economy	12700.00
0005435785141	4278	Economy	12700.00
0005435785134	4278	Economy	12700.00
0005435785137	4278	Economy	12700.00
0005435785128	4278	Economy	12700.00
0005435785152	4278	Economy	12700.00
0005435785151	4278	Economy	12700.00
0005435784742	27306	Business	38000.00
0005435784768	27306	Business	38000.00
0005435784873	27306	Business	38000.00
0005435918623	27306	Business	38000.00
0005435784755	27306	Business	38000.00
0005435784776	27306	Business	38000.00
0005432195678	27306	Business	38000.00
0005435784780	27306	Economy	12700.00
0005435784853	27306	Economy	12700.00
0005435784739	27306	Economy	12700.00
0005435784825	27306	Economy	12700.00
0005434993903	27306	Economy	12700.00
0005435784833	27306	Economy	12700.00
0005435784789	27306	Economy	13900.00
0005434993901	27306	Economy	13900.00
0005435784775	27306	Economy	13900.00
0005435784858	27306	Economy	12700.00
0005435784770	27306	Economy	12700.00
0005434993868	27306	Economy	12700.00
0005435784830	27306	Economy	12700.00
0005434993902	27306	Economy	12700.00
0005435784808	27306	Economy	12700.00
0005435784812	27306	Economy	12700.00
0005435784793	27306	Economy	12700.00
0005435937357	27306	Economy	12700.00
0005434993876	27306	Economy	12700.00
0005435937352	27306	Economy	12700.00
0005435937353	27306	Economy	12700.00
0005435784792	27306	Economy	12700.00
0005434993873	27306	Economy	12700.00
0005435918626	27306	Economy	12700.00
0005435937349	27306	Economy	12700.00
0005434993847	27306	Economy	12700.00
0005435937355	27306	Economy	12700.00
0005435784904	27306	Economy	12700.00
0005435784807	27306	Economy	12700.00
0005435918624	27306	Economy	12700.00
0005434993869	27306	Economy	12700.00
0005435784844	27306	Economy	12700.00
0005435784774	27306	Economy	12700.00
0005435784738	27306	Economy	12700.00
0005435918625	27306	Economy	12700.00
0005435937350	27306	Economy	12700.00
0005435937356	27306	Economy	12700.00
0005435937354	27306	Economy	12700.00
0005435784903	27306	Economy	12700.00
0005435784826	27306	Economy	12700.00
0005435918622	27306	Economy	12700.00
0005435937351	27306	Economy	12700.00
0005432146184	19853	Economy	12800.00
0005432146185	19853	Economy	12800.00
0005432459516	4724	Business	40900.00
0005432459517	4724	Business	40900.00
0005433451607	4724	Business	40900.00
0005432567254	4724	Business	40900.00
0005432459535	4724	Business	40900.00
0005432459493	4724	Business	40900.00
0005432571298	4724	Business	40900.00
0005434081751	4724	Business	40900.00
0005432567274	4724	Business	40900.00
0005432459496	4724	Business	40900.00
0005432459506	4724	Business	40900.00
0005432459503	4724	Business	40900.00
0005432459534	4724	Business	40900.00
0005432186847	4724	Business	40900.00
0005432459509	4724	Business	40900.00
0005432459505	4724	Business	40900.00
0005433452728	4724	Business	40900.00
0005432459525	4724	Business	40900.00
0005432567217	4724	Economy	15000.00
0005434081755	4724	Economy	15000.00
0005432459491	4724	Economy	15000.00
0005432567245	4724	Economy	13600.00
0005432567225	4724	Economy	13600.00
0005432567237	4724	Economy	13600.00
0005432459508	4724	Economy	13600.00
0005432567239	4724	Economy	13600.00
0005432459492	4724	Economy	13600.00
0005432170343	4724	Economy	13600.00
0005432459499	4724	Economy	13600.00
0005434081753	4724	Economy	13600.00
0005432459538	4724	Economy	13600.00
0005432567264	4724	Economy	13600.00
0005432567249	4724	Economy	13600.00
0005434081754	4724	Economy	13600.00
0005432567250	4724	Economy	13600.00
0005432459530	4724	Economy	13600.00
0005432567255	4724	Economy	13600.00
0005432567214	4724	Economy	13600.00
0005432170341	4724	Economy	13600.00
0005433452727	4724	Economy	13600.00
0005432567235	4724	Economy	13600.00
0005432567222	4724	Economy	13600.00
0005432459510	4724	Economy	13600.00
0005432459539	4724	Economy	13600.00
0005432567253	4724	Economy	13600.00
0005432459495	4724	Economy	13600.00
0005432170347	4724	Economy	13600.00
0005432567260	4724	Economy	13600.00
0005432459518	4724	Economy	13600.00
0005432186846	4724	Economy	13600.00
0005432567269	4724	Economy	13600.00
0005432567267	4724	Economy	13600.00
0005432459500	4724	Economy	13600.00
0005432567231	4724	Economy	13600.00
0005432459494	4724	Economy	13600.00
0005432459541	4724	Economy	13600.00
0005432170345	4724	Economy	13600.00
0005432459512	4724	Economy	13600.00
0005432459521	4724	Economy	13600.00
0005432567262	4724	Economy	13600.00
0005432567257	4724	Economy	13600.00
0005432567258	4724	Economy	13600.00
0005432567263	4724	Economy	13600.00
0005432459522	4724	Economy	13600.00
0005433451606	4724	Economy	13600.00
0005432567252	4724	Economy	13600.00
0005432567271	4724	Economy	13600.00
0005432567241	4724	Economy	13600.00
0005432571295	4724	Economy	13600.00
0005432170344	4724	Economy	13600.00
0005432459542	4724	Economy	13600.00
0005432459537	4724	Economy	13600.00
0005432459531	4724	Economy	13600.00
0005432571296	4724	Economy	13600.00
0005432567251	4724	Economy	13600.00
0005432459513	4724	Economy	13600.00
0005432567270	4724	Economy	13600.00
0005432459515	4724	Economy	13600.00
0005432567228	4724	Economy	13600.00
0005434081749	4724	Economy	13600.00
0005432567273	4724	Economy	13600.00
0005432567247	4724	Economy	13600.00
0005432567261	4724	Economy	13600.00
0005432459504	4724	Economy	13600.00
0005432567256	4724	Economy	13600.00
0005432459523	4724	Economy	13600.00
0005432567246	4724	Economy	13600.00
0005432567227	4724	Economy	13600.00
0005432459528	4724	Economy	13600.00
0005432459514	4724	Economy	13600.00
0005432459520	4724	Economy	13600.00
0005432567226	4724	Economy	13600.00
0005432170346	4724	Economy	15000.00
0005432567268	4724	Economy	15000.00
0005434081758	4724	Economy	15000.00
0005434081752	4724	Economy	13600.00
0005432571297	4724	Economy	13600.00
0005432567221	4724	Economy	13600.00
0005432567224	4724	Economy	13600.00
0005432567238	4724	Economy	13600.00
0005432459507	4724	Economy	13600.00
0005432459490	4724	Economy	13600.00
0005432567266	4724	Economy	13600.00
0005432459543	4724	Economy	13600.00
0005432567242	4724	Economy	13600.00
0005432567230	4724	Economy	13600.00
0005434081757	4724	Economy	13600.00
0005432459511	4724	Economy	13600.00
0005432567265	4724	Economy	13600.00
0005432459498	4724	Economy	13600.00
0005432567220	4724	Economy	13600.00
0005432567215	4724	Economy	13600.00
0005432459519	4724	Economy	13600.00
0005433726090	4724	Economy	13600.00
0005432567259	4724	Economy	13600.00
0005432567233	4724	Economy	13600.00
0005432459544	4724	Economy	13600.00
0005432567229	4724	Economy	13600.00
0005432459497	4724	Economy	13600.00
0005433452725	4724	Economy	13600.00
0005432459540	4724	Economy	13600.00
0005432567219	4724	Economy	13600.00
0005432567240	4724	Economy	13600.00
0005432567272	4724	Economy	13600.00
0005432567236	4724	Economy	13600.00
0005432459502	4724	Economy	13600.00
0005432567218	4724	Economy	13600.00
0005434081756	4724	Economy	13600.00
0005434559090	4724	Economy	13600.00
0005432459536	4724	Economy	13600.00
0005432567243	4724	Economy	13600.00
0005432170342	4724	Economy	13600.00
0005434559091	4724	Economy	13600.00
0005432459533	4724	Economy	13600.00
0005432567244	4724	Economy	13600.00
0005432567275	4724	Economy	13600.00
0005432459501	4724	Economy	13600.00
0005432459529	4724	Economy	13600.00
0005432459526	4724	Economy	13600.00
0005432459524	4724	Economy	13600.00
0005432459527	4724	Economy	13600.00
0005434081750	4724	Economy	13600.00
0005432567248	4724	Economy	13600.00
0005432459532	4724	Economy	13600.00
0005433726089	4724	Economy	13600.00
0005432567223	4724	Economy	13600.00
0005433452726	4724	Economy	13600.00
0005432567232	4724	Economy	13600.00
0005432567216	4724	Economy	13600.00
0005432567234	4724	Economy	13600.00
0005432459213	30570	Business	40900.00
0005432459141	30570	Business	40900.00
0005432566593	30570	Business	40900.00
0005432566886	30570	Business	40900.00
0005432459016	30570	Business	40900.00
0005432459173	30570	Business	40900.00
0005432459233	30570	Business	40900.00
0005432566621	30570	Business	40900.00
0005432213582	30570	Business	40900.00
0005432566875	30570	Business	40900.00
0005432213583	30570	Business	40900.00
0005432459215	30570	Economy	15000.00
0005432459382	30570	Business	40900.00
0005434081499	30570	Economy	15000.00
0005432458997	30570	Economy	15000.00
0005432566723	30570	Economy	13600.00
0005432566842	30570	Economy	13600.00
0005432459347	30570	Economy	13600.00
0005432458979	30570	Economy	13600.00
0005434081512	30570	Economy	13600.00
0005434081579	30570	Economy	13600.00
0005432566612	30570	Economy	13600.00
0005432566605	30570	Economy	13600.00
0005432459297	30570	Economy	13600.00
0005434081519	30570	Economy	13600.00
0005433454844	30570	Economy	13600.00
0005434081538	30570	Economy	13600.00
0005432458991	30570	Economy	13600.00
0005432571257	30570	Economy	13600.00
0005432213581	30570	Economy	13600.00
0005432459346	30570	Economy	13600.00
0005432566766	30570	Economy	13600.00
0005432566671	30570	Economy	13600.00
0005435840359	30570	Economy	13600.00
0005432459243	30570	Economy	13600.00
0005432571289	30570	Economy	13600.00
0005432459207	30570	Economy	13600.00
0005432458961	30570	Economy	13600.00
0005432566702	30570	Economy	13600.00
0005432458998	30570	Economy	13600.00
0005432566881	30570	Economy	13600.00
0005434081477	30570	Economy	13600.00
0005432458990	30570	Economy	13600.00
0005434081484	30570	Economy	13600.00
0005432459078	30570	Economy	13600.00
0005432566874	30570	Economy	13600.00
0005432566606	30570	Economy	13600.00
0005432566672	30570	Economy	13600.00
0005432566715	30570	Economy	13600.00
0005432566798	30570	Economy	13600.00
0005434081530	30570	Economy	13600.00
0005432571272	30570	Economy	13600.00
0005432161139	30570	Economy	13600.00
0005432161137	30570	Economy	13600.00
0005432459023	30570	Economy	13600.00
0005432567002	30570	Economy	13600.00
0005432571276	30570	Economy	13600.00
0005434081550	30570	Economy	13600.00
0005432566954	30570	Economy	13600.00
0005432566703	30570	Economy	13600.00
0005434081520	30570	Economy	13600.00
0005432459200	30570	Economy	13600.00
0005432566925	30570	Economy	13600.00
0005432566893	30570	Economy	13600.00
0005432459090	30570	Economy	13600.00
0005432566757	30570	Economy	13600.00
0005432566729	30570	Economy	13600.00
0005432566910	30570	Economy	13600.00
0005432458989	30570	Economy	13600.00
0005434081555	30570	Economy	13600.00
0005432459012	30570	Economy	13600.00
0005432459015	30570	Economy	15000.00
0005432566785	30570	Economy	15000.00
0005432213580	30570	Economy	13600.00
0005432459206	30570	Economy	13600.00
0005432566552	30570	Economy	13600.00
0005432566765	30570	Economy	13600.00
0005432459216	30570	Economy	13600.00
0005432459274	30570	Economy	13600.00
0005434081593	30570	Economy	13600.00
0005432566730	30570	Economy	13600.00
0005434081487	30570	Economy	13600.00
0005432459246	30570	Economy	13600.00
0005432566670	30570	Economy	13600.00
0005432566724	30570	Economy	13600.00
0005432161138	30570	Economy	13600.00
0005432566992	30570	Economy	13600.00
0005432566989	30570	Economy	13600.00
0005432567011	30570	Economy	13600.00
0005432459159	30570	Economy	13600.00
0005432458995	30570	Economy	13600.00
0005432459105	30570	Economy	13600.00
0005434081511	30570	Economy	13600.00
0005432459199	30570	Economy	13600.00
0005432458996	30570	Economy	13600.00
0005432459091	30570	Economy	13600.00
0005432566786	30570	Economy	13600.00
0005432566773	30570	Economy	13600.00
0005432566608	30570	Economy	13600.00
0005432566882	30570	Economy	13600.00
0005432566764	30570	Economy	13600.00
0005432566993	30570	Economy	13600.00
0005432459115	30570	Economy	13600.00
0005432161136	30570	Economy	13600.00
0005432566771	30570	Economy	13600.00
0005432566787	30570	Economy	13600.00
0005432459104	30570	Economy	13600.00
0005432566607	30570	Economy	13600.00
0005432566879	30570	Economy	13600.00
0005432566968	30570	Economy	13600.00
0005432571268	30570	Economy	13600.00
0005432459160	30570	Economy	13600.00
0005434081515	30570	Economy	13600.00
0005432566840	30570	Economy	13600.00
0005432566620	30570	Economy	13600.00
0005434081594	30570	Economy	13600.00
0005432566944	30570	Economy	13600.00
0005434081544	30570	Economy	13600.00
0005432566819	30570	Economy	13600.00
0005435722040	13569	Economy	9900.00
0005435722039	13569	Economy	9900.00
0005435720126	21141	Economy	9900.00
0005435720125	21141	Economy	9900.00
0005435722032	21141	Economy	9900.00
0005435722033	21141	Economy	9900.00
0005435722013	21141	Economy	9900.00
0005432295863	22806	Economy	8800.00
0005432295864	22806	Economy	8800.00
0005432295865	22806	Economy	8800.00
0005432295862	22806	Economy	8800.00
0005433342570	11111	Business	23600.00
0005435508185	11111	Business	23600.00
0005433342583	11111	Business	23600.00
0005433342504	11111	Business	23600.00
0005433342531	11111	Business	23600.00
0005433342515	11111	Business	23600.00
0005433342545	11111	Business	23600.00
0005433342586	11111	Business	23600.00
0005433342558	11111	Business	23600.00
0005433342544	11111	Business	23600.00
0005433342591	11111	Business	23600.00
0005433342548	11111	Economy	7900.00
0005435097141	11111	Economy	7900.00
0005433342555	11111	Economy	7900.00
0005433342507	11111	Economy	7900.00
0005433342501	11111	Economy	7900.00
0005433342588	11111	Economy	7900.00
0005435508184	11111	Economy	7900.00
0005433342596	11111	Economy	7900.00
0005433342500	11111	Economy	7900.00
0005435508178	11111	Economy	7900.00
0005435508196	11111	Economy	7900.00
0005433342498	11111	Economy	7900.00
0005433342546	11111	Economy	7900.00
0005433342551	11111	Economy	7900.00
0005435508212	11111	Economy	7900.00
0005433342516	11111	Economy	7900.00
0005433342510	11111	Economy	7900.00
0005433342564	11111	Economy	7900.00
0005433342559	11111	Economy	7900.00
0005433342577	11111	Economy	7900.00
0005433342506	11111	Economy	7900.00
0005433342539	11111	Economy	7900.00
0005433342561	11111	Economy	7900.00
0005433342576	11111	Economy	7900.00
0005433342598	11111	Economy	7900.00
0005433342528	11111	Economy	7900.00
0005435508192	11111	Economy	7900.00
0005433342529	11111	Economy	7900.00
0005433342581	11111	Economy	7900.00
0005433342517	11111	Economy	7900.00
0005433342549	11111	Economy	7900.00
0005433342532	11111	Economy	7900.00
0005433342593	11111	Economy	7900.00
0005433342527	11111	Economy	7900.00
0005433342579	11111	Economy	7900.00
0005433342585	11111	Economy	7900.00
0005433342508	11111	Economy	7900.00
0005433342526	11111	Economy	7900.00
0005433342590	11111	Economy	7900.00
0005433342562	11111	Economy	8600.00
0005433342513	11111	Economy	8600.00
0005433342578	11111	Economy	8600.00
0005433342584	11111	Economy	8600.00
0005433342597	11111	Economy	8600.00
0005433342518	11111	Economy	7900.00
0005435508183	11111	Economy	7900.00
0005433342511	11111	Economy	7900.00
0005433342514	11111	Economy	7900.00
0005433342573	11111	Economy	7900.00
0005433342580	11111	Economy	7900.00
0005435097143	11111	Economy	7900.00
0005435097145	11111	Economy	7900.00
0005433342554	11111	Economy	7900.00
0005435097142	11111	Economy	7900.00
0005433342542	11111	Economy	7900.00
0005433342530	11111	Economy	7900.00
0005435508194	11111	Economy	7900.00
0005433342571	11111	Economy	7900.00
0005433342556	11111	Economy	7900.00
0005433342582	11111	Economy	7900.00
0005433342589	11111	Economy	7900.00
0005433342565	11111	Economy	7900.00
0005433342543	11111	Economy	7900.00
0005433342552	11111	Economy	7900.00
0005433342574	11111	Economy	7900.00
0005433342535	11111	Economy	7900.00
0005433342567	11111	Economy	7900.00
0005433342568	11111	Economy	7900.00
0005433342499	11111	Economy	7900.00
0005435380237	11111	Economy	7900.00
0005433342563	11111	Economy	7900.00
0005433342541	11111	Economy	7900.00
0005433342512	11111	Economy	7900.00
0005435508208	11111	Economy	7900.00
0005433342566	11111	Economy	7900.00
0005435508209	11111	Economy	7900.00
0005433342575	11111	Economy	7900.00
0005433342521	11111	Economy	7900.00
0005435508172	11111	Economy	7900.00
0005435508195	11111	Economy	7900.00
0005433342523	11111	Economy	7900.00
0005433342502	11111	Economy	7900.00
0005433342533	11111	Economy	7900.00
0005433342587	11111	Economy	7900.00
0005433342569	11111	Economy	7900.00
0005433342537	11111	Economy	7900.00
0005433342553	11111	Economy	7900.00
0005435097144	11111	Economy	7900.00
0005433342572	11111	Economy	7900.00
0005433342538	11111	Economy	7900.00
0005433342505	11111	Economy	7900.00
0005433342520	11111	Economy	7900.00
0005433342560	11111	Economy	7900.00
0005435508193	11111	Economy	7900.00
0005435508198	11111	Economy	7900.00
0005435508197	11111	Economy	7900.00
0005433342534	11111	Economy	7900.00
0005433342519	11111	Economy	7900.00
0005433342522	11111	Economy	7900.00
0005433342503	11111	Economy	7900.00
0005433342595	11111	Economy	7900.00
0005435508230	11111	Economy	7900.00
0005433342550	11111	Economy	7900.00
0005433342592	11111	Economy	7900.00
0005433342525	11111	Economy	7900.00
0005433342536	11111	Economy	7900.00
0005435508179	11111	Economy	7900.00
0005433342557	11111	Economy	7900.00
0005433342509	11111	Economy	7900.00
0005433342547	11111	Economy	7900.00
0005433342594	11111	Economy	7900.00
0005433342540	11111	Economy	7900.00
0005433342524	11111	Economy	7900.00
0005435545684	17097	Business	23600.00
0005435545672	17097	Business	23600.00
0005433341493	17097	Business	23600.00
0005435545682	17097	Business	23600.00
0005433341725	17097	Business	23600.00
0005435545678	17097	Business	23600.00
0005433341682	17097	Business	23600.00
0005433341772	17097	Business	23600.00
0005435545677	17097	Business	23600.00
0005435545680	17097	Business	23600.00
0005433341530	17097	Economy	7900.00
0005433342084	17097	Economy	7900.00
0005432293194	17097	Economy	7900.00
0005433341626	17097	Economy	7900.00
0005433341552	17097	Economy	7900.00
0005432293196	17097	Economy	7900.00
0005435545685	17097	Economy	7900.00
0005433341562	17097	Economy	7900.00
0005433341663	17097	Economy	7900.00
0005433341695	17097	Economy	7900.00
0005433341834	17097	Economy	7900.00
0005432293195	17097	Economy	7900.00
0005433341515	17097	Economy	7900.00
0005433341724	17097	Economy	7900.00
0005435097084	17097	Economy	7900.00
0005433341450	17097	Economy	7900.00
0005433341750	17097	Economy	7900.00
0005435097067	17097	Economy	7900.00
0005435545686	17097	Economy	7900.00
0005433341710	17097	Economy	7900.00
0005435097054	17097	Economy	7900.00
0005435545673	17097	Economy	7900.00
0005433341559	17097	Economy	7900.00
0005435545681	17097	Economy	7900.00
0005433341711	17097	Economy	7900.00
0005435545687	17097	Economy	7900.00
0005435380268	17097	Economy	7900.00
0005433341759	17097	Economy	7900.00
0005433341579	17097	Economy	7900.00
0005433341519	17097	Economy	7900.00
0005433341783	17097	Economy	7900.00
0005433341699	17097	Economy	7900.00
0005433341378	17097	Economy	7900.00
0005433341956	17097	Economy	7900.00
0005435545679	17097	Economy	7900.00
0005433341520	17097	Economy	8600.00
0005433341478	17097	Economy	8600.00
0005433341514	17097	Economy	8600.00
0005435545689	17097	Economy	8600.00
0005433341715	17097	Economy	8600.00
0005435545675	17097	Economy	7900.00
0005433342085	17097	Economy	7900.00
0005433341768	17097	Economy	7900.00
0005435380265	17097	Economy	7900.00
0005433341487	17097	Economy	7900.00
0005435545683	17097	Economy	7900.00
0005435097083	17097	Economy	7900.00
0005433341403	17097	Economy	7900.00
0005435380266	17097	Economy	7900.00
0005433341887	17097	Economy	7900.00
0005433341611	17097	Economy	7900.00
0005432293193	17097	Economy	7900.00
0005433341712	17097	Economy	7900.00
0005432293191	17097	Economy	7900.00
0005435545690	17097	Economy	7900.00
0005433341885	17097	Economy	7900.00
0005433341700	17097	Economy	7900.00
0005435380264	17097	Economy	7900.00
0005435380267	17097	Economy	7900.00
0005435097091	17097	Economy	7900.00
0005433341555	17097	Economy	7900.00
0005433341399	17097	Economy	7900.00
0005432293192	17097	Economy	7900.00
0005433341510	17097	Economy	7900.00
0005433341556	17097	Economy	7900.00
0005433341857	17097	Economy	7900.00
0005433341709	17097	Economy	7900.00
0005433341781	17097	Economy	7900.00
0005433341439	17097	Economy	7900.00
0005433341662	17097	Economy	7900.00
0005433341563	17097	Economy	7900.00
0005433341678	17097	Economy	7900.00
0005433341687	17097	Economy	7900.00
0005433341539	17097	Economy	7900.00
0005435545676	17097	Economy	7900.00
0005433341379	17097	Economy	7900.00
0005435380269	17097	Economy	7900.00
0005435545688	17097	Economy	7900.00
0005433341557	17097	Economy	7900.00
0005433341784	17097	Economy	7900.00
0005433341886	17097	Economy	7900.00
0005433341638	17097	Economy	7900.00
0005433341534	17097	Economy	7900.00
0005433341737	17097	Economy	7900.00
0005435545674	17097	Economy	7900.00
0005433341454	17097	Economy	7900.00
0005433341507	17097	Economy	7900.00
0005433341506	17097	Economy	7900.00
0005433341451	17097	Economy	7900.00
0005433341694	17097	Economy	7900.00
0005433341551	17097	Economy	7900.00
0005433341688	17097	Economy	7900.00
0005433341531	17097	Economy	7900.00
0005433341639	17097	Economy	7900.00
0005435097077	17097	Economy	7900.00
0005433341812	17097	Economy	7900.00
0005433341651	17097	Economy	7900.00
0005432919573	9077	Business	26600.00
0005433481115	9077	Business	26600.00
0005432919563	9077	Business	26600.00
0005433507075	9077	Economy	8900.00
0005433507072	9077	Economy	8900.00
0005432919553	9077	Economy	8900.00
0005432919622	9077	Economy	8900.00
0005433481116	9077	Economy	8900.00
0005432919515	9077	Economy	8900.00
0005433507076	9077	Economy	9800.00
0005433507071	9077	Economy	9800.00
0005432919589	9077	Economy	9800.00
0005432919624	9077	Economy	8900.00
0005433507062	9077	Economy	8900.00
0005433481122	9077	Economy	8900.00
0005432919557	9077	Economy	8900.00
0005432919567	9077	Economy	8900.00
0005432919533	9077	Economy	8900.00
0005432919561	9077	Economy	8900.00
0005433481119	9077	Economy	8900.00
0005432919623	9077	Economy	8900.00
0005432919534	9077	Economy	8900.00
0005432919570	9077	Economy	8900.00
0005432919569	9077	Economy	8900.00
0005433507068	9077	Economy	8900.00
0005433507067	9077	Economy	8900.00
0005433481120	9077	Economy	8900.00
0005433481118	9077	Economy	8900.00
0005433507065	9077	Economy	8900.00
0005432919564	9077	Economy	8900.00
0005432919572	9077	Economy	8900.00
0005432919568	9077	Economy	8900.00
0005433507063	9077	Economy	8900.00
0005432919588	9077	Economy	8900.00
0005433507070	9077	Economy	8900.00
0005432919531	9077	Economy	8900.00
0005432919556	9077	Economy	8900.00
0005432919602	9077	Economy	8900.00
0005433507073	9077	Economy	8900.00
0005433507074	9077	Economy	8900.00
0005432919504	9077	Economy	8900.00
0005432919514	9077	Economy	8900.00
0005433481121	9077	Economy	8900.00
0005432919544	9077	Economy	8900.00
0005432919548	9077	Economy	8900.00
0005433507066	9077	Economy	8900.00
0005433507069	9077	Economy	8900.00
0005433507064	9077	Economy	8900.00
0005433481117	9077	Economy	8900.00
0005433506931	20443	Business	26600.00
0005432919740	20443	Business	26600.00
0005432919745	20443	Business	26600.00
0005433506975	20443	Business	26600.00
0005432919742	20443	Business	26600.00
0005433506860	20443	Business	26600.00
0005432919758	20443	Business	26600.00
0005433506969	20443	Economy	8900.00
0005433506972	20443	Economy	8900.00
0005432919746	20443	Economy	8900.00
0005433481069	20443	Economy	8900.00
0005432919749	20443	Economy	8900.00
0005433481053	20443	Economy	8900.00
0005433506982	20443	Economy	9800.00
0005432919743	20443	Economy	9800.00
0005433506979	20443	Economy	9800.00
0005433506889	20443	Economy	8900.00
0005433506888	20443	Economy	8900.00
0005432919739	20443	Economy	8900.00
0005433506943	20443	Economy	8900.00
0005432919747	20443	Economy	8900.00
0005433506878	20443	Economy	8900.00
0005433506970	20443	Economy	8900.00
0005433506973	20443	Economy	8900.00
0005432919757	20443	Economy	8900.00
0005434158964	20443	Economy	8900.00
0005432919748	20443	Economy	8900.00
0005432919751	20443	Economy	8900.00
0005432919759	20443	Economy	8900.00
0005432919750	20443	Economy	8900.00
0005433481036	20443	Economy	8900.00
0005432919753	20443	Economy	8900.00
0005433506906	20443	Economy	8900.00
0005432919744	20443	Economy	8900.00
0005433481049	20443	Economy	8900.00
0005432919741	20443	Economy	8900.00
0005433481038	20443	Economy	8900.00
0005432919752	20443	Economy	8900.00
0005433481050	20443	Economy	8900.00
0005433506989	20443	Economy	8900.00
0005434158965	20443	Economy	8900.00
0005432919754	20443	Economy	8900.00
0005433506990	20443	Economy	8900.00
0005433506877	20443	Economy	8900.00
0005432919755	20443	Economy	8900.00
0005433506971	20443	Economy	8900.00
0005433506907	20443	Economy	8900.00
0005433481037	20443	Economy	8900.00
0005432919756	20443	Economy	8900.00
0005432919738	20443	Economy	8900.00
0005432396213	10209	Economy	5800.00
0005435179688	10209	Economy	5800.00
0005432396215	10209	Economy	5800.00
0005432396214	10209	Economy	5800.00
0005432394075	10209	Economy	5800.00
0005432396212	10209	Economy	5800.00
0005432394074	10209	Economy	5800.00
0005432394076	10209	Economy	5800.00
0005432394073	10209	Economy	5800.00
0005432396183	18301	Economy	5800.00
0005432396197	18301	Economy	5800.00
0005432396193	18301	Economy	5800.00
0005432396179	18301	Economy	5800.00
0005432400066	18301	Economy	5800.00
0005435179391	18301	Economy	5800.00
0005432396180	18301	Economy	5800.00
0005432396173	18301	Economy	5800.00
0005432400072	18301	Economy	5800.00
0005435179690	18301	Economy	5800.00
0005435125736	10980	Business	9500.00
0005434411751	10980	Business	9500.00
0005435125665	10980	Business	9500.00
0005435125766	10980	Business	9500.00
0005435125788	10980	Business	9500.00
0005435125666	10980	Business	9500.00
0005435125706	10980	Business	9500.00
0005435625869	10980	Business	9500.00
0005435125756	10980	Business	9500.00
0005435125847	10980	Economy	3200.00
0005435556658	10980	Economy	3200.00
0005435125724	10980	Economy	3200.00
0005435625898	10980	Economy	3200.00
0005435125723	10980	Economy	3200.00
0005435625877	10980	Economy	3200.00
0005435125759	10980	Economy	3500.00
0005435125817	10980	Economy	3500.00
0005434928283	10980	Economy	3500.00
0005435556662	10980	Economy	3500.00
0005435125683	10980	Economy	3200.00
0005435125651	10980	Economy	3200.00
0005435554116	10980	Economy	3200.00
0005435125763	10980	Economy	3200.00
0005435625886	10980	Economy	3200.00
0005435125739	10980	Economy	3200.00
0005435125785	10980	Economy	3200.00
0005435125740	10980	Economy	3200.00
0005435125664	10980	Economy	3200.00
0005435125846	10980	Economy	3200.00
0005435125757	10980	Economy	3200.00
0005435625902	10980	Economy	3200.00
0005435554123	10980	Economy	3200.00
0005435554110	10980	Economy	3200.00
0005435556661	10980	Economy	3200.00
0005435625860	10980	Economy	3200.00
0005435125885	10980	Economy	3200.00
0005435125713	10980	Economy	3200.00
0005434411750	10980	Economy	3200.00
0005435125738	10980	Economy	3200.00
0005434411753	10980	Economy	3200.00
0005435625878	10980	Economy	3200.00
0005435625899	10980	Economy	3200.00
0005435125720	10980	Economy	3200.00
0005435125737	10980	Economy	3200.00
0005435125650	10980	Economy	3200.00
0005435125758	10980	Economy	3200.00
0005434928282	10980	Economy	3200.00
0005435125699	10980	Economy	3200.00
0005435554117	10980	Economy	3200.00
0005435125792	10980	Economy	3200.00
0005435125789	10980	Economy	3200.00
0005435125809	10980	Economy	3200.00
0005435125702	10980	Economy	3200.00
0005435125800	10980	Economy	3200.00
0005435125700	10980	Economy	3200.00
0005435625889	10980	Economy	3200.00
0005435625876	10980	Economy	3200.00
0005435625861	10980	Economy	3200.00
0005435125884	10980	Economy	3200.00
0005434411752	10980	Economy	3200.00
0005435125686	10980	Economy	3200.00
0005435125842	10980	Economy	3200.00
0005435626069	14702	Business	9500.00
0005435556676	14702	Business	9500.00
0005435126137	14702	Business	9500.00
0005434411711	14702	Business	9500.00
0005435626064	14702	Business	9500.00
0005435126143	14702	Business	9500.00
0005435126130	14702	Business	9500.00
0005434411712	14702	Business	9500.00
0005435126133	14702	Business	9500.00
0005435556679	14702	Business	9500.00
0005435554153	14702	Economy	3200.00
0005435126140	14702	Economy	3200.00
0005435126112	14702	Economy	3200.00
0005435126106	14702	Economy	3200.00
0005435126122	14702	Economy	3200.00
0005435626068	14702	Economy	3200.00
0005435554154	14702	Economy	3200.00
0005435126136	14702	Economy	3200.00
0005435126138	14702	Economy	3500.00
0005435126115	14702	Economy	3500.00
0005435626061	14702	Economy	3500.00
0005435126145	14702	Economy	3200.00
0005435126125	14702	Economy	3200.00
0005435126110	14702	Economy	3200.00
0005435126144	14702	Economy	3200.00
0005435554155	14702	Economy	3200.00
0005435626057	14702	Economy	3200.00
0005435626058	14702	Economy	3200.00
0005435126108	14702	Economy	3200.00
0005435126113	14702	Economy	3200.00
0005435126146	14702	Economy	3200.00
0005435126121	14702	Economy	3200.00
0005435556678	14702	Economy	3200.00
0005435126132	14702	Economy	3200.00
0005435626065	14702	Economy	3200.00
0005435126116	14702	Economy	3200.00
0005435126120	14702	Economy	3200.00
0005435626063	14702	Economy	3200.00
0005435126139	14702	Economy	3200.00
0005435126142	14702	Economy	3200.00
0005435126147	14702	Economy	3200.00
0005435626060	14702	Economy	3200.00
0005435126141	14702	Economy	3200.00
0005435126109	14702	Economy	3200.00
0005435126119	14702	Economy	3200.00
0005435126124	14702	Economy	3200.00
0005435126128	14702	Economy	3200.00
0005435626059	14702	Economy	3200.00
0005435126118	14702	Economy	3200.00
0005435126114	14702	Economy	3200.00
0005435126148	14702	Economy	3200.00
0005435556677	14702	Economy	3200.00
0005435554157	14702	Economy	3200.00
0005435554156	14702	Economy	3200.00
0005435126134	14702	Economy	3200.00
0005435556674	14702	Economy	3200.00
0005435126117	14702	Economy	3200.00
0005435556675	14702	Economy	3200.00
0005435126107	14702	Economy	3200.00
0005435126126	14702	Economy	3200.00
0005435626066	14702	Economy	3200.00
0005435626062	14702	Economy	3200.00
0005434411710	14702	Economy	3200.00
0005435126131	14702	Economy	3200.00
0005435626056	14702	Economy	3200.00
0005435126129	14702	Economy	3200.00
0005435626067	14702	Economy	3200.00
0005435126123	14702	Economy	3200.00
0005435126135	14702	Economy	3200.00
0005435626055	14702	Economy	3200.00
0005435126127	14702	Economy	3200.00
0005435126111	14702	Economy	3200.00
0005435715359	7091	Business	86900.00
0005435715368	7091	Business	86900.00
0005435715355	7091	Economy	29000.00
0005432398173	7091	Economy	29000.00
0005432400099	7091	Economy	31900.00
0005435715360	7091	Economy	31900.00
0005435715369	7091	Economy	31900.00
0005435715358	7091	Economy	29000.00
0005435715356	7091	Economy	29000.00
0005435216560	7091	Economy	29000.00
0005435715365	7091	Economy	29000.00
0005435443171	7091	Economy	29000.00
0005435219165	7091	Economy	29000.00
0005435715364	7091	Economy	29000.00
0005432398174	7091	Economy	29000.00
0005435715354	7091	Economy	29000.00
0005435715363	7091	Economy	29000.00
0005435715357	7091	Economy	29000.00
0005435443166	7091	Economy	29000.00
0005432400098	7091	Economy	29000.00
0005432398175	7091	Economy	29000.00
0005435715361	7091	Economy	29000.00
0005432400100	7091	Economy	29000.00
0005435443172	7091	Economy	29000.00
0005435179389	7091	Economy	29000.00
0005435715362	7091	Economy	29000.00
0005435443170	7091	Economy	29000.00
0005435715366	7091	Economy	29000.00
0005435715367	7091	Economy	29000.00
0005435443253	27081	Business	86900.00
0005435216571	27081	Business	86900.00
0005432398144	27081	Business	86900.00
0005435443254	27081	Business	86900.00
0005435715190	27081	Business	86900.00
0005435216574	27081	Business	86900.00
0005435178484	27081	Business	86900.00
0005435217697	27081	Economy	29000.00
0005435715189	27081	Economy	29000.00
0005435715196	27081	Economy	29000.00
0005435715211	27081	Economy	29000.00
0005435715253	27081	Economy	31900.00
0005435218109	27081	Economy	31900.00
0005435443255	27081	Economy	31900.00
0005435216572	27081	Economy	29000.00
0005435443250	27081	Economy	29000.00
0005435715184	27081	Economy	29000.00
0005435715239	27081	Economy	29000.00
0005435715183	27081	Economy	29000.00
0005435443258	27081	Economy	29000.00
0005435178987	27081	Economy	29000.00
0005432398145	27081	Economy	29000.00
0005435217696	27081	Economy	29000.00
0005435178988	27081	Economy	29000.00
0005435178485	27081	Economy	29000.00
0005435216570	27081	Economy	29000.00
0005435178486	27081	Economy	29000.00
0005435216573	27081	Economy	29000.00
0005435217695	27081	Economy	29000.00
0005435178985	27081	Economy	29000.00
0005435443256	27081	Economy	29000.00
0005435217698	27081	Economy	29000.00
0005435443259	27081	Economy	29000.00
0005435443257	27081	Economy	29000.00
0005435715240	27081	Economy	29000.00
0005435178986	27081	Economy	29000.00
0005435715199	27081	Economy	29000.00
0005435443251	27081	Economy	29000.00
0005435217699	27081	Economy	29000.00
0005435443252	27081	Economy	29000.00
0005435715198	27081	Economy	29000.00
0005435715195	27081	Economy	29000.00
0005435216575	27081	Economy	29000.00
0005432398143	27081	Economy	29000.00
0005435715212	27081	Economy	29000.00
0005434084902	2709	Economy	7700.00
0005434084904	2709	Economy	7700.00
0005434084903	2709	Economy	7700.00
0005434084900	2709	Economy	7700.00
0005434084901	2709	Economy	7700.00
0005434084872	28523	Economy	7700.00
0005433060397	28523	Economy	7700.00
0005434084867	28523	Economy	7700.00
0005433060395	28523	Economy	7700.00
0005434084864	28523	Economy	7700.00
0005434084874	28523	Economy	7700.00
0005433060396	28523	Economy	7700.00
0005435548422	11166	Economy	27100.00
0005433788188	11166	Economy	24600.00
0005433788183	11166	Economy	24600.00
0005433788187	11166	Economy	24600.00
0005433788189	11166	Economy	24600.00
0005435548433	11166	Economy	24600.00
0005433788185	11166	Economy	24600.00
0005433788184	11166	Economy	24600.00
0005435548436	11166	Economy	24600.00
0005435548434	11166	Economy	24600.00
0005433788182	11166	Economy	24600.00
0005435548435	11166	Economy	24600.00
0005433788186	11166	Economy	24600.00
0005433788178	11166	Economy	24600.00
0005433788179	11166	Economy	24600.00
0005435548423	11166	Economy	24600.00
0005433788180	11166	Economy	24600.00
0005433788181	11166	Economy	24600.00
0005435548470	20672	Economy	27100.00
0005433788141	20672	Economy	27100.00
0005435548467	20672	Economy	27100.00
0005435548469	20672	Economy	24600.00
0005435548460	20672	Economy	24600.00
0005435548459	20672	Economy	24600.00
0005435548458	20672	Economy	24600.00
0005433788148	20672	Economy	24600.00
0005433788158	20672	Economy	24600.00
0005435548454	20672	Economy	24600.00
0005433788143	20672	Economy	24600.00
0005435548452	20672	Economy	24600.00
0005435548457	20672	Economy	24600.00
0005435548455	20672	Economy	24600.00
0005435548453	20672	Economy	24600.00
0005435548451	20672	Economy	24600.00
0005435548461	20672	Economy	24600.00
0005435548463	20672	Economy	24600.00
0005435548471	20672	Economy	24600.00
0005435548464	20672	Economy	24600.00
0005435548468	20672	Economy	24600.00
0005435548456	20672	Economy	24600.00
0005435548472	20672	Economy	24600.00
0005433788142	20672	Economy	24600.00
0005435548465	20672	Economy	24600.00
0005435548466	20672	Economy	24600.00
0005433788144	20672	Economy	24600.00
0005435548462	20672	Economy	24600.00
0005433788154	20672	Economy	24600.00
0005435548450	20672	Economy	24600.00
0005435548473	20672	Economy	24600.00
0005435540710	11401	Business	20200.00
0005435517652	11401	Business	20200.00
0005435517594	11401	Business	20200.00
0005435517710	11401	Economy	6700.00
0005435517641	11401	Economy	6700.00
0005435540752	11401	Economy	6700.00
0005435540764	11401	Economy	6700.00
0005435540704	11401	Economy	7400.00
0005435540692	11401	Economy	7400.00
0005435517596	11401	Economy	6700.00
0005435540648	11401	Economy	6700.00
0005435517588	11401	Economy	6700.00
0005435540694	11401	Economy	6700.00
0005435540718	11401	Economy	6700.00
0005435540765	11401	Economy	6700.00
0005435540759	11401	Economy	6700.00
0005435540760	11401	Economy	6700.00
0005435517637	11401	Economy	6700.00
0005435540651	11401	Economy	6700.00
0005435540640	11401	Economy	6700.00
0005435517714	11401	Economy	6700.00
0005435517636	11401	Economy	6700.00
0005435540796	11401	Economy	6700.00
0005435540628	11401	Economy	6700.00
0005435540668	11401	Economy	6700.00
0005435517709	11401	Economy	6700.00
0005435517648	11401	Economy	6700.00
0005435540682	11401	Economy	6700.00
0005435540649	11401	Economy	6700.00
0005435517620	11401	Economy	6700.00
0005435517649	11401	Economy	6700.00
0005435540691	11401	Economy	6700.00
0005435540667	11401	Economy	6700.00
0005435517654	11401	Economy	6700.00
0005435540795	11401	Economy	6700.00
0005435540705	11401	Economy	6700.00
0005435540719	11401	Economy	6700.00
0005435517655	11401	Economy	6700.00
0005435517653	11401	Economy	6700.00
0005435517640	11401	Economy	6700.00
0005435540753	11401	Economy	6700.00
0005435540769	11401	Economy	6700.00
0005435517633	11401	Economy	6700.00
0005435540650	11401	Economy	6700.00
0005435540683	11401	Economy	6700.00
0005435529111	22239	Business	20200.00
0005435540856	22239	Business	20200.00
0005435529104	22239	Business	20200.00
0005435529102	22239	Business	20200.00
0005435540858	22239	Business	20200.00
0005435529101	22239	Business	20200.00
0005435540865	22239	Economy	6700.00
0005432294472	22239	Economy	6700.00
0005435529120	22239	Economy	6700.00
0005435540852	22239	Economy	6700.00
0005432294470	22239	Economy	7400.00
0005435540850	22239	Economy	7400.00
0005435540857	22239	Economy	6700.00
0005435540864	22239	Economy	6700.00
0005435529114	22239	Economy	6700.00
0005435540863	22239	Economy	6700.00
0005435540851	22239	Economy	6700.00
0005435529107	22239	Economy	6700.00
0005435529105	22239	Economy	6700.00
0005435540849	22239	Economy	6700.00
0005435540854	22239	Economy	6700.00
0005435529108	22239	Economy	6700.00
0005435529100	22239	Economy	6700.00
0005435529118	22239	Economy	6700.00
0005435540859	22239	Economy	6700.00
0005435529110	22239	Economy	6700.00
0005435540848	22239	Economy	6700.00
0005435529973	22239	Economy	6700.00
0005435529113	22239	Economy	6700.00
0005435529115	22239	Economy	6700.00
0005435540846	22239	Economy	6700.00
0005435529119	22239	Economy	6700.00
0005435529109	22239	Economy	6700.00
0005435529117	22239	Economy	6700.00
0005435540860	22239	Economy	6700.00
0005435540855	22239	Economy	6700.00
0005435529112	22239	Economy	6700.00
0005435540844	22239	Economy	6700.00
0005435540845	22239	Economy	6700.00
0005435540862	22239	Economy	6700.00
0005435529121	22239	Economy	6700.00
0005435529116	22239	Economy	6700.00
0005435529106	22239	Economy	6700.00
0005435540853	22239	Economy	6700.00
0005435540861	22239	Economy	6700.00
0005435529103	22239	Economy	6700.00
0005435540847	22239	Economy	6700.00
0005432294471	22239	Economy	6700.00
0005434907000	2263	Business	20200.00
0005433251039	2263	Business	20200.00
0005434906978	2263	Business	20200.00
0005433251000	2263	Business	20200.00
0005433251007	2263	Business	20200.00
0005434907005	2263	Business	20200.00
0005433400935	2263	Business	20200.00
0005434907007	2263	Business	20200.00
0005434906979	2263	Business	20200.00
0005434906985	2263	Business	20200.00
0005433251072	2263	Business	20200.00
0005434907009	2263	Business	20200.00
0005434906969	2263	Economy	6700.00
0005434906989	2263	Economy	6700.00
0005434906974	2263	Economy	6700.00
0005434907010	2263	Economy	6700.00
0005434906984	2263	Economy	6700.00
0005434906976	2263	Economy	6700.00
0005434906987	2263	Economy	6700.00
0005434906998	2263	Economy	6700.00
0005434906988	2263	Economy	6700.00
0005434906977	2263	Economy	6700.00
0005433400946	2263	Economy	7400.00
0005434906970	2263	Economy	7400.00
0005433251001	2263	Economy	7400.00
0005434906972	2263	Economy	7400.00
0005434906965	2263	Economy	7400.00
0005433251130	2263	Economy	6700.00
0005434906986	2263	Economy	6700.00
0005434906983	2263	Economy	6700.00
0005434907008	2263	Economy	6700.00
0005433250978	2263	Economy	6700.00
0005434906982	2263	Economy	6700.00
0005434906963	2263	Economy	6700.00
0005433251062	2263	Economy	6700.00
0005434906980	2263	Economy	6700.00
0005433251014	2263	Economy	6700.00
0005434906995	2263	Economy	6700.00
0005433250991	2263	Economy	6700.00
0005434906956	2263	Economy	6700.00
0005433251250	2263	Economy	6700.00
0005433250990	2263	Economy	6700.00
0005433251045	2263	Economy	6700.00
0005434906993	2263	Economy	6700.00
0005434906975	2263	Economy	6700.00
0005433251054	2263	Economy	6700.00
0005434906968	2263	Economy	6700.00
0005434906961	2263	Economy	6700.00
0005434907004	2263	Economy	6700.00
0005433251160	2263	Economy	6700.00
0005433250998	2263	Economy	6700.00
0005434907006	2263	Economy	6700.00
0005433251075	2263	Economy	6700.00
0005433251215	2263	Economy	6700.00
0005434906999	2263	Economy	6700.00
0005433250976	2263	Economy	6700.00
0005434906957	2263	Economy	6700.00
0005434906996	2263	Economy	6700.00
0005433251021	2263	Economy	6700.00
0005434906958	2263	Economy	6700.00
0005434906994	2263	Economy	6700.00
0005434906997	2263	Economy	6700.00
0005434907002	2263	Economy	6700.00
0005434906966	2263	Economy	6700.00
0005434906992	2263	Economy	6700.00
0005433251020	2263	Economy	6700.00
0005433251044	2263	Economy	6700.00
0005433250999	2263	Economy	6700.00
0005433250977	2263	Economy	6700.00
0005434906954	2263	Economy	6700.00
0005434906953	2263	Economy	6700.00
0005433250944	2263	Economy	6700.00
0005434906990	2263	Economy	6700.00
0005434906964	2263	Economy	6700.00
0005433251238	2263	Economy	6700.00
0005434906991	2263	Economy	6700.00
0005434906960	2263	Economy	6700.00
0005434906959	2263	Economy	6700.00
0005434906955	2263	Economy	6700.00
0005434907003	2263	Economy	6700.00
0005433251076	2263	Economy	6700.00
0005433251008	2263	Economy	6700.00
0005433251129	2263	Economy	6700.00
0005433251050	2263	Economy	6700.00
0005434906951	2263	Economy	6700.00
0005434906962	2263	Economy	6700.00
0005434906973	2263	Economy	6700.00
0005434906971	2263	Economy	6700.00
0005434906967	2263	Economy	6700.00
0005433251051	2263	Economy	6700.00
0005434906981	2263	Economy	6700.00
0005433251158	2263	Economy	6700.00
0005434907001	2263	Economy	6700.00
0005434906952	2263	Economy	6700.00
0005434906533	25608	Business	20200.00
0005433251294	25608	Business	20200.00
0005434906452	25608	Business	20200.00
0005434906603	25608	Business	20200.00
0005434906536	25608	Business	20200.00
0005434906432	25608	Business	20200.00
0005433251290	25608	Business	20200.00
0005433251299	25608	Business	20200.00
0005433251305	25608	Business	20200.00
0005434906532	25608	Business	20200.00
0005433251278	25608	Economy	6700.00
0005433251284	25608	Economy	6700.00
0005434906460	25608	Economy	6700.00
0005433251286	25608	Economy	6700.00
0005434906434	25608	Economy	6700.00
0005434906519	25608	Economy	6700.00
0005433251300	25608	Economy	6700.00
0005433251277	25608	Economy	6700.00
0005433251292	25608	Economy	6700.00
0005434906363	25608	Economy	6700.00
0005434906512	25608	Economy	7400.00
0005433251297	25608	Economy	7400.00
0005433251287	25608	Economy	7400.00
0005433251275	25608	Economy	7400.00
0005433251281	25608	Economy	6700.00
0005434906505	25608	Economy	6700.00
0005434906411	25608	Economy	6700.00
0005434906461	25608	Economy	6700.00
0005434906477	25608	Economy	6700.00
0005433251293	25608	Economy	6700.00
0005434906480	25608	Economy	6700.00
0005433251303	25608	Economy	6700.00
0005433400965	25608	Economy	6700.00
0005434906388	25608	Economy	6700.00
0005433251291	25608	Economy	6700.00
0005434906575	25608	Economy	6700.00
0005434906453	25608	Economy	6700.00
0005433251279	25608	Economy	6700.00
0005434906398	25608	Economy	6700.00
0005434906493	25608	Economy	6700.00
0005433251304	25608	Economy	6700.00
0005434906459	25608	Economy	6700.00
0005434906387	25608	Economy	6700.00
0005433251282	25608	Economy	6700.00
0005434906668	25608	Economy	6700.00
0005434906551	25608	Economy	6700.00
0005434906399	25608	Economy	6700.00
0005434906550	25608	Economy	6700.00
0005433400964	25608	Economy	6700.00
0005434906359	25608	Economy	6700.00
0005433251296	25608	Economy	6700.00
0005433251288	25608	Economy	6700.00
0005434906520	25608	Economy	6700.00
0005434906458	25608	Economy	6700.00
0005434906619	25608	Economy	6700.00
0005433251280	25608	Economy	6700.00
0005433251301	25608	Economy	6700.00
0005433400963	25608	Economy	6700.00
0005434906669	25608	Economy	6700.00
0005434906585	25608	Economy	6700.00
0005434906677	25608	Economy	6700.00
0005434906464	25608	Economy	6700.00
0005434906676	25608	Economy	6700.00
0005433251302	25608	Economy	6700.00
0005434906482	25608	Economy	6700.00
0005434906671	25608	Economy	6700.00
0005433251295	25608	Economy	6700.00
0005434906690	25608	Economy	6700.00
0005433251298	25608	Economy	6700.00
0005434906476	25608	Economy	6700.00
0005433251285	25608	Economy	6700.00
0005433251276	25608	Economy	6700.00
0005433251289	25608	Economy	6700.00
0005433251283	25608	Economy	6700.00
0005434906474	25608	Economy	6700.00
0005432620958	2527	Economy	13600.00
0005432862174	2527	Economy	13600.00
0005432862186	2527	Economy	12400.00
0005432862164	2527	Economy	12400.00
0005432620959	2527	Economy	12400.00
0005432620947	2527	Economy	12400.00
0005432620946	2527	Economy	12400.00
0005432620956	2527	Economy	12400.00
0005432620957	2527	Economy	12400.00
0005432620945	2527	Economy	12400.00
0005432620954	2527	Economy	12400.00
0005432620948	2527	Economy	12400.00
0005432620955	2527	Economy	12400.00
0005432620953	2527	Economy	12400.00
0005432620949	2527	Economy	12400.00
0005432620951	2527	Economy	12400.00
0005432862203	2527	Economy	12400.00
0005432620950	2527	Economy	12400.00
0005432620952	2527	Economy	12400.00
0005432862202	2527	Economy	12400.00
0005432862256	28055	Economy	13600.00
0005432620820	28055	Economy	12400.00
0005432620793	28055	Economy	12400.00
0005432620832	28055	Economy	12400.00
0005432620842	28055	Economy	12400.00
0005432620788	28055	Economy	12400.00
0005432862258	28055	Economy	12400.00
0005432862250	28055	Economy	12400.00
0005432862255	28055	Economy	12400.00
0005432620843	28055	Economy	12400.00
0005432620889	28055	Economy	12400.00
0005432620890	28055	Economy	12400.00
0005432862251	28055	Economy	12400.00
0005432862253	28055	Economy	12400.00
0005432620792	28055	Economy	12400.00
0005432620841	28055	Economy	12400.00
0005432620791	28055	Economy	12400.00
0005432620867	28055	Economy	12400.00
0005432862257	28055	Economy	12400.00
0005432862252	28055	Economy	12400.00
0005432620819	28055	Economy	12400.00
0005432620845	28055	Economy	12400.00
0005432862254	28055	Economy	12400.00
0005434097450	11759	Economy	11300.00
0005434097453	11759	Economy	11300.00
0005434097452	11759	Economy	11300.00
0005434097451	11759	Economy	11300.00
0005434097467	13064	Economy	11300.00
0005433452725	31016	Economy	8400.00
0005433451607	31016	Economy	8400.00
0005433451606	31016	Economy	8400.00
0005433452728	31016	Economy	8400.00
0005433452727	31016	Economy	8400.00
0005433452726	31016	Economy	8400.00
0005433454844	31375	Economy	8400.00
0005434184631	11995	Economy	7200.00
0005433134063	11995	Economy	7200.00
0005433134068	11995	Economy	6600.00
0005433134067	11995	Economy	6600.00
0005433134097	11995	Economy	6600.00
0005434142548	11995	Economy	6600.00
0005433129205	11995	Economy	6600.00
0005433134080	11995	Economy	6600.00
0005434184632	11995	Economy	6600.00
0005433129210	11995	Economy	6600.00
0005433134069	11995	Economy	6600.00
0005433134074	11995	Economy	6600.00
0005433129204	11995	Economy	6600.00
0005433134066	11995	Economy	6600.00
0005433134078	11995	Economy	6600.00
0005433134075	11995	Economy	6600.00
0005434183566	29850	Economy	7200.00
0005434142582	29850	Economy	7200.00
0005433134108	29850	Economy	7200.00
0005434184652	29850	Economy	6600.00
0005434142583	29850	Economy	6600.00
0005433134110	29850	Economy	6600.00
0005434142584	29850	Economy	6600.00
0005433131681	29850	Economy	6600.00
0005433134111	29850	Economy	6600.00
0005433131680	29850	Economy	6600.00
0005434184653	29850	Economy	6600.00
0005433134109	29850	Economy	6600.00
0005434183567	29850	Economy	6600.00
0005433131682	29850	Economy	6600.00
0005433131678	29850	Economy	6600.00
0005433131683	29850	Economy	6600.00
0005433131679	29850	Economy	6600.00
0005435697150	16476	Economy	19900.00
0005435935009	16476	Economy	19900.00
0005435697158	16476	Economy	19900.00
0005435697137	16476	Economy	18100.00
0005435697157	16476	Economy	18100.00
0005435934992	16476	Economy	18100.00
0005435697133	16476	Economy	18100.00
0005435697152	16476	Economy	18100.00
0005435697156	16476	Economy	18100.00
0005435697131	16476	Economy	18100.00
0005435697139	16476	Economy	18100.00
0005435697149	16476	Economy	18100.00
0005435697141	16476	Economy	18100.00
0005435697155	16476	Economy	18100.00
0005435697148	16476	Economy	18100.00
0005435697132	16476	Economy	18100.00
0005435697153	16476	Economy	18100.00
0005435697144	16476	Economy	18100.00
0005435697134	16476	Economy	18100.00
0005435697151	16476	Economy	18100.00
0005435697146	16476	Economy	18100.00
0005435697140	16476	Economy	18100.00
0005435934999	16476	Economy	18100.00
0005435697142	16476	Economy	18100.00
0005435935008	16476	Economy	18100.00
0005435697143	16476	Economy	18100.00
0005435697145	16476	Economy	18100.00
0005435697154	16476	Economy	18100.00
0005435697147	16476	Economy	18100.00
0005435697135	16476	Economy	18100.00
0005435697136	16476	Economy	18100.00
0005435697138	16476	Economy	18100.00
0005435696861	24688	Economy	19900.00
0005435697033	24688	Economy	19900.00
0005435696860	24688	Economy	19900.00
0005435696987	24688	Economy	18100.00
0005435696933	24688	Economy	18100.00
0005435696984	24688	Economy	18100.00
0005435696970	24688	Economy	18100.00
0005435935026	24688	Economy	18100.00
0005435696884	24688	Economy	18100.00
0005435697023	24688	Economy	18100.00
0005435696926	24688	Economy	18100.00
0005435696967	24688	Economy	18100.00
0005435697019	24688	Economy	18100.00
0005435696952	24688	Economy	18100.00
0005435696925	24688	Economy	18100.00
0005435696893	24688	Economy	18100.00
0005435935025	24688	Economy	18100.00
0005435696969	24688	Economy	18100.00
0005435935024	24688	Economy	18100.00
0005435696957	24688	Economy	18100.00
0005435935027	24688	Economy	18100.00
0005435697060	24688	Economy	18100.00
0005435696928	24688	Economy	18100.00
0005435696850	24688	Economy	18100.00
0005435696932	24688	Economy	18100.00
0005435696947	24688	Economy	18100.00
0005435696927	24688	Economy	18100.00
0005435696985	24688	Economy	18100.00
0005435696885	24688	Economy	18100.00
0005435696968	24688	Economy	18100.00
0005435696966	24688	Economy	18100.00
0005432968803	18762	Economy	4400.00
0005433724775	18762	Economy	4400.00
0005433724773	18762	Economy	4400.00
0005433724776	18762	Economy	4400.00
0005432968802	18762	Economy	4400.00
0005432968811	18762	Economy	4400.00
0005433724774	18762	Economy	4400.00
0005433724772	18762	Economy	4400.00
0005432968828	21651	Economy	4400.00
0005433724724	21651	Economy	4400.00
0005433724736	21651	Economy	4400.00
0005432968829	21651	Economy	4400.00
0005432968827	21651	Economy	4400.00
0005433724740	21651	Economy	4400.00
0005434137644	7297	Business	23100.00
0005434137683	7297	Business	23100.00
0005434137669	7297	Business	23100.00
0005434137660	7297	Business	23100.00
0005434137690	7297	Business	23100.00
0005434137698	7297	Business	23100.00
0005434137641	7297	Business	23100.00
0005434137665	7297	Business	23100.00
0005434137642	7297	Business	23100.00
0005434137625	7297	Business	23100.00
0005434137633	7297	Business	23100.00
0005434137629	7297	Economy	7700.00
0005434137684	7297	Economy	7700.00
0005434137647	7297	Economy	7700.00
0005434137657	7297	Economy	7700.00
0005434137694	7297	Economy	7700.00
0005434087485	7297	Economy	7700.00
0005434137628	7297	Economy	7700.00
0005434137705	7297	Economy	7700.00
0005434137654	7297	Economy	7700.00
0005434137681	7297	Economy	8500.00
0005434137674	7297	Economy	8500.00
0005434137666	7297	Economy	8500.00
0005434137662	7297	Economy	8500.00
0005434087486	7297	Economy	8500.00
0005434137630	7297	Economy	7700.00
0005434137649	7297	Economy	7700.00
0005434137637	7297	Economy	7700.00
0005434137696	7297	Economy	7700.00
0005434137675	7297	Economy	7700.00
0005434137672	7297	Economy	7700.00
0005434137677	7297	Economy	7700.00
0005434137635	7297	Economy	7700.00
0005434137663	7297	Economy	7700.00
0005434137646	7297	Economy	7700.00
0005434137692	7297	Economy	7700.00
0005434137688	7297	Economy	7700.00
0005434137651	7297	Economy	7700.00
0005434137679	7297	Economy	7700.00
0005434137703	7297	Economy	7700.00
0005434087481	7297	Economy	7700.00
0005434087484	7297	Economy	7700.00
0005434137687	7297	Economy	7700.00
0005434137631	7297	Economy	7700.00
0005434137678	7297	Economy	7700.00
0005434137700	7297	Economy	7700.00
0005434137689	7297	Economy	7700.00
0005434137640	7297	Economy	7700.00
0005434137643	7297	Economy	7700.00
0005434137658	7297	Economy	7700.00
0005434137695	7297	Economy	7700.00
0005434137691	7297	Economy	7700.00
0005434137634	7297	Economy	7700.00
0005434137653	7297	Economy	7700.00
0005434137686	7297	Economy	7700.00
0005434137655	7297	Economy	7700.00
0005434137661	7297	Economy	7700.00
0005434137638	7297	Economy	7700.00
0005434137701	7297	Economy	7700.00
0005434137706	7297	Economy	7700.00
0005434137676	7297	Economy	7700.00
0005434137670	7297	Economy	7700.00
0005434137671	7297	Economy	7700.00
0005434137648	7297	Economy	7700.00
0005434137697	7297	Economy	7700.00
0005434137624	7297	Economy	7700.00
0005434137680	7297	Economy	7700.00
0005434137699	7297	Economy	7700.00
0005434137702	7297	Economy	7700.00
0005434137652	7297	Economy	7700.00
0005434137667	7297	Economy	7700.00
0005434087483	7297	Economy	7700.00
0005434137685	7297	Economy	7700.00
0005434137668	7297	Economy	7700.00
0005434087482	7297	Economy	7700.00
0005434137627	7297	Economy	7700.00
0005434137704	7297	Economy	7700.00
0005434137626	7297	Economy	7700.00
0005434137639	7297	Economy	7700.00
0005434137632	7297	Economy	7700.00
0005434137645	7297	Economy	7700.00
0005434137659	7297	Economy	7700.00
0005434137682	7297	Economy	7700.00
0005434137673	7297	Economy	7700.00
0005434137693	7297	Economy	7700.00
0005434137656	7297	Economy	7700.00
0005434137636	7297	Economy	7700.00
0005434137664	7297	Economy	7700.00
0005434137650	7297	Economy	7700.00
0005434137707	7297	Economy	7700.00
0005434136796	28580	Business	23100.00
0005434137008	28580	Business	23100.00
0005434136983	28580	Business	23100.00
0005434136922	28580	Business	23100.00
0005434136742	28580	Business	23100.00
0005434136804	28580	Business	23100.00
0005434136743	28580	Business	23100.00
0005434136948	28580	Business	23100.00
0005434136729	28580	Economy	7700.00
0005434136894	28580	Economy	7700.00
0005434137023	28580	Economy	7700.00
0005434136913	28580	Economy	7700.00
0005434136857	28580	Economy	7700.00
0005434136690	28580	Economy	7700.00
0005434136864	28580	Economy	7700.00
0005434136959	28580	Economy	7700.00
0005434087450	28580	Economy	7700.00
0005434137060	28580	Economy	7700.00
0005434136897	28580	Economy	8500.00
0005434136861	28580	Economy	8500.00
0005434136809	28580	Economy	8500.00
0005434136993	28580	Economy	8500.00
0005434136762	28580	Economy	8500.00
0005434137070	28580	Economy	7700.00
0005434137061	28580	Economy	7700.00
0005434136974	28580	Economy	7700.00
0005434136992	28580	Economy	7700.00
0005434137045	28580	Economy	7700.00
0005434136908	28580	Economy	7700.00
0005434136911	28580	Economy	7700.00
0005434136805	28580	Economy	7700.00
0005434136965	28580	Economy	7700.00
0005434136811	28580	Economy	7700.00
0005434136715	28580	Economy	7700.00
0005434136750	28580	Economy	7700.00
0005434136716	28580	Economy	7700.00
0005434137021	28580	Economy	7700.00
0005434136842	28580	Economy	7700.00
0005434136909	28580	Economy	7700.00
0005434136918	28580	Economy	7700.00
0005434136808	28580	Economy	7700.00
0005434136984	28580	Economy	7700.00
0005434137101	28580	Economy	7700.00
0005434137056	28580	Economy	7700.00
0005434136921	28580	Economy	7700.00
0005434137097	28580	Economy	7700.00
0005434136877	28580	Economy	7700.00
0005434137035	28580	Economy	7700.00
0005434136975	28580	Economy	7700.00
0005434136914	28580	Economy	7700.00
0005434137002	28580	Economy	7700.00
0005434136728	28580	Economy	7700.00
0005434136846	28580	Economy	7700.00
0005434136912	28580	Economy	7700.00
0005434137034	28580	Economy	7700.00
0005434136730	28580	Economy	7700.00
0005434136755	28580	Economy	7700.00
0005434136910	28580	Economy	7700.00
0005434136843	28580	Economy	7700.00
0005434136949	28580	Economy	7700.00
0005434137096	28580	Economy	7700.00
0005434136810	28580	Economy	7700.00
0005434136720	28580	Economy	7700.00
0005434136886	28580	Economy	7700.00
0005434137046	28580	Economy	7700.00
0005434137069	28580	Economy	7700.00
0005434136888	28580	Economy	7700.00
0005434136776	28580	Economy	7700.00
0005434136881	28580	Economy	7700.00
0005434136862	28580	Economy	7700.00
0005434136960	28580	Economy	7700.00
0005434136772	28580	Economy	7700.00
0005434136817	28580	Economy	7700.00
0005434136966	28580	Economy	7700.00
0005434136917	28580	Economy	7700.00
0005434087451	28580	Economy	7700.00
0005434137064	28580	Economy	7700.00
0005434136887	28580	Economy	7700.00
0005434136863	28580	Economy	7700.00
0005434136751	28580	Economy	7700.00
0005435808171	1902	Economy	23900.00
0005435808174	1902	Economy	21700.00
0005435808168	1902	Economy	21700.00
0005434610207	1902	Economy	21700.00
0005433407478	1902	Economy	21700.00
0005433407479	1902	Economy	21700.00
0005433407490	1902	Economy	21700.00
0005435808172	1902	Economy	21700.00
0005435808173	1902	Economy	21700.00
0005435808175	1902	Economy	21700.00
0005435808169	1902	Economy	21700.00
0005434610208	1902	Economy	21700.00
0005434610206	1902	Economy	21700.00
0005435808170	1902	Economy	21700.00
0005435808176	1902	Economy	21700.00
0005434610177	23067	Economy	21700.00
0005434610170	23067	Economy	21700.00
0005434610169	23067	Economy	21700.00
0005434610181	23067	Economy	21700.00
0005434610180	23067	Economy	21700.00
0005434503615	16729	Economy	7600.00
0005434503458	16729	Economy	7600.00
0005434503503	16729	Economy	7600.00
0005434503550	16729	Economy	6900.00
0005434503513	16729	Economy	6900.00
0005434503565	16729	Economy	6900.00
0005434503608	16729	Economy	6900.00
0005434503535	16729	Economy	6900.00
0005434503610	16729	Economy	6900.00
0005434503521	16729	Economy	6900.00
0005434503514	16729	Economy	6900.00
0005434503566	16729	Economy	6900.00
0005434503536	16729	Economy	6900.00
0005434503659	16729	Economy	6900.00
0005434503502	16729	Economy	6900.00
0005434503592	16729	Economy	6900.00
0005434503534	16729	Economy	6900.00
0005434503576	16729	Economy	6900.00
0005434503538	16729	Economy	6900.00
0005434503548	16729	Economy	6900.00
0005434503583	16729	Economy	6900.00
0005434503640	16729	Economy	6900.00
0005434503549	16729	Economy	6900.00
0005434503476	16729	Economy	6900.00
0005434503520	16729	Economy	6900.00
0005434503611	16729	Economy	6900.00
0005434503485	16729	Economy	6900.00
0005434503643	16729	Economy	6900.00
0005434503899	22915	Economy	7600.00
0005434503884	22915	Economy	7600.00
0005434503865	22915	Economy	6900.00
0005434503897	22915	Economy	6900.00
0005434503888	22915	Economy	6900.00
0005434503866	22915	Economy	6900.00
0005434503886	22915	Economy	6900.00
0005434503898	22915	Economy	6900.00
0005434503875	22915	Economy	6900.00
0005434503874	22915	Economy	6900.00
0005434503881	22915	Economy	6900.00
0005434503867	22915	Economy	6900.00
0005434503887	22915	Economy	6900.00
0005434503868	22915	Economy	6900.00
0005434503871	22915	Economy	6900.00
0005434503863	22915	Economy	6900.00
0005434503876	22915	Economy	6900.00
0005434503864	22915	Economy	6900.00
0005434503894	22915	Economy	6900.00
0005434503896	22915	Economy	6900.00
0005434503878	22915	Economy	6900.00
0005434503883	22915	Economy	6900.00
0005434503895	22915	Economy	6900.00
0005434503877	22915	Economy	6900.00
0005434503900	22915	Economy	6900.00
0005434503873	22915	Economy	6900.00
0005434503870	22915	Economy	6900.00
0005434503890	22915	Economy	6900.00
0005434503872	22915	Economy	6900.00
0005434503879	22915	Economy	6900.00
0005434503885	22915	Economy	6900.00
0005434503869	22915	Economy	6900.00
0005434503893	22915	Economy	6900.00
0005434503891	22915	Economy	6900.00
0005434503889	22915	Economy	6900.00
0005434503880	22915	Economy	6900.00
0005434503892	22915	Economy	6900.00
0005434503882	22915	Economy	6900.00
0005435078244	2227	Economy	7700.00
0005433266556	2227	Economy	7700.00
0005435078243	2227	Economy	7000.00
0005435078248	2227	Economy	7000.00
0005435078241	2227	Economy	7000.00
0005435078250	2227	Economy	7000.00
0005435078251	2227	Economy	7000.00
0005435078239	2227	Economy	7000.00
0005433266565	2227	Economy	7000.00
0005433266570	2227	Economy	7000.00
0005435078246	2227	Economy	7000.00
0005435078242	2227	Economy	7000.00
0005433266577	2227	Economy	7000.00
0005433266614	2227	Economy	7000.00
0005433266599	2227	Economy	7000.00
0005435078247	2227	Economy	7000.00
0005435078249	2227	Economy	7000.00
0005435078253	2227	Economy	7000.00
0005433266606	2227	Economy	7000.00
0005433266607	2227	Economy	7000.00
0005433266566	2227	Economy	7000.00
0005435078245	2227	Economy	7000.00
0005433266602	2227	Economy	7000.00
0005435078240	2227	Economy	7000.00
0005433266615	2227	Economy	7000.00
0005435078252	2227	Economy	7000.00
0005433266600	2227	Economy	7000.00
0005435078254	2227	Economy	7000.00
0005435078107	24364	Economy	7700.00
0005435078067	24364	Economy	7700.00
0005435078087	24364	Economy	7000.00
0005433266662	24364	Economy	7000.00
0005433266667	24364	Economy	7000.00
0005433266670	24364	Economy	7000.00
0005433266665	24364	Economy	7000.00
0005435078156	24364	Economy	7000.00
0005433266668	24364	Economy	7000.00
0005433266672	24364	Economy	7000.00
0005433266664	24364	Economy	7000.00
0005435078068	24364	Economy	7000.00
0005435078128	24364	Economy	7000.00
0005435078144	24364	Economy	7000.00
0005435078074	24364	Economy	7000.00
0005435078089	24364	Economy	7000.00
0005433266663	24364	Economy	7000.00
0005435078075	24364	Economy	7000.00
0005435078129	24364	Economy	7000.00
0005433266669	24364	Economy	7000.00
0005435078157	24364	Economy	7000.00
0005433266661	24364	Economy	7000.00
0005433266671	24364	Economy	7000.00
0005435078066	24364	Economy	7000.00
0005433266666	24364	Economy	7000.00
0005435464479	6615	Economy	10800.00
0005435464477	6615	Economy	10800.00
0005434988667	6615	Economy	9800.00
0005434988672	6615	Economy	9800.00
0005434988677	6615	Economy	9800.00
0005435464478	6615	Economy	9800.00
0005434988673	6615	Economy	9800.00
0005434988670	6615	Economy	9800.00
0005434988669	6615	Economy	9800.00
0005434988676	6615	Economy	9800.00
0005435803246	6615	Economy	9800.00
0005434988675	6615	Economy	9800.00
0005435803247	6615	Economy	9800.00
0005434988674	6615	Economy	9800.00
0005434988668	6615	Economy	9800.00
0005434988671	6615	Economy	9800.00
0005435803213	23597	Economy	10800.00
0005435464495	23597	Economy	10800.00
0005435803212	23597	Economy	9800.00
0005435803227	23597	Economy	9800.00
0005435464494	23597	Economy	9800.00
0005432382965	30495	Business	9900.00
0005432382928	30495	Business	9900.00
0005432382938	30495	Business	9900.00
0005433449831	30495	Business	9900.00
0005432382954	30495	Business	9900.00
0005432382944	30495	Business	9900.00
0005433449834	30495	Business	9900.00
0005433449837	30495	Economy	3300.00
0005432382946	30495	Economy	3300.00
0005433453752	30495	Economy	3300.00
0005432382930	30495	Economy	3300.00
0005432382947	30495	Economy	3300.00
0005433449840	30495	Economy	3300.00
0005433449850	30495	Economy	3300.00
0005432382955	30495	Economy	3600.00
0005433449849	30495	Economy	3600.00
0005432382952	30495	Economy	3600.00
0005432382951	30495	Economy	3600.00
0005432382936	30495	Economy	3300.00
0005433449844	30495	Economy	3300.00
0005432382964	30495	Economy	3300.00
0005432382927	30495	Economy	3300.00
0005432382949	30495	Economy	3300.00
0005432382939	30495	Economy	3300.00
0005433449848	30495	Economy	3300.00
0005433449835	30495	Economy	3300.00
0005433449829	30495	Economy	3300.00
0005432382929	30495	Economy	3300.00
0005432382942	30495	Economy	3300.00
0005432382956	30495	Economy	3300.00
0005432382966	30495	Economy	3300.00
0005433453751	30495	Economy	3300.00
0005433449847	30495	Economy	3300.00
0005433449830	30495	Economy	3300.00
0005433449842	30495	Economy	3300.00
0005433449841	30495	Economy	3300.00
0005432382948	30495	Economy	3300.00
0005433449846	30495	Economy	3300.00
0005432382959	30495	Economy	3300.00
0005432382945	30495	Economy	3300.00
0005432382963	30495	Economy	3300.00
0005432382943	30495	Economy	3300.00
0005433449833	30495	Economy	3300.00
0005432382932	30495	Economy	3300.00
0005432382961	30495	Economy	3300.00
0005433449828	30495	Economy	3300.00
0005432382960	30495	Economy	3300.00
0005432382967	30495	Economy	3300.00
0005433449845	30495	Economy	3300.00
0005432382933	30495	Economy	3300.00
0005432382937	30495	Economy	3300.00
0005433453750	30495	Economy	3300.00
0005432382950	30495	Economy	3300.00
0005432382962	30495	Economy	3300.00
0005432382957	30495	Economy	3300.00
0005432382934	30495	Economy	3300.00
0005433449839	30495	Economy	3300.00
0005432382958	30495	Economy	3300.00
0005433449832	30495	Economy	3300.00
0005433449843	30495	Economy	3300.00
0005432382941	30495	Economy	3300.00
0005432382931	30495	Economy	3300.00
0005433449836	30495	Economy	3300.00
0005432382968	30495	Economy	3300.00
0005433449838	30495	Economy	3300.00
0005432382935	30495	Economy	3300.00
0005432382953	30495	Economy	3300.00
0005432382940	30495	Economy	3300.00
0005432382506	31282	Business	9900.00
0005432382547	31282	Business	9900.00
0005433449703	31282	Business	9900.00
0005432382527	31282	Business	9900.00
0005432382514	31282	Business	9900.00
0005432382557	31282	Business	9900.00
0005432382502	31282	Business	9900.00
0005433449692	31282	Business	9900.00
0005433449629	31282	Economy	3300.00
0005432382488	31282	Economy	3300.00
0005433449627	31282	Economy	3300.00
0005432382498	31282	Economy	3300.00
0005433449616	31282	Economy	3600.00
0005433449670	31282	Economy	3600.00
0005433453730	31282	Economy	3600.00
0005432382546	31282	Economy	3300.00
0005432382489	31282	Economy	3300.00
0005433453739	31282	Economy	3300.00
0005432382591	31282	Economy	3300.00
0005432382598	31282	Economy	3300.00
0005433449614	31282	Economy	3300.00
0005433453731	31282	Economy	3300.00
0005432382562	31282	Economy	3300.00
0005432382504	31282	Economy	3300.00
0005433449666	31282	Economy	3300.00
0005432382597	31282	Economy	3300.00
0005433449691	31282	Economy	3300.00
0005432382581	31282	Economy	3300.00
0005432382513	31282	Economy	3300.00
0005433449668	31282	Economy	3300.00
0005432382590	31282	Economy	3300.00
0005432382512	31282	Economy	3300.00
0005433449621	31282	Economy	3300.00
0005432382497	31282	Economy	3300.00
0005433449595	31282	Economy	3300.00
0005432382528	31282	Economy	3300.00
0005432382558	31282	Economy	3300.00
0005432382563	31282	Economy	3300.00
0005433449612	31282	Economy	3300.00
0005432382643	31282	Economy	3300.00
0005432382635	31282	Economy	3300.00
0005433449617	31282	Economy	3300.00
0005432382573	31282	Economy	3300.00
0005433453738	31282	Economy	3300.00
0005433449644	31282	Economy	3300.00
0005432382548	31282	Economy	3300.00
0005433451599	31282	Economy	3300.00
0005432382524	31282	Economy	3300.00
0005433449613	31282	Economy	3300.00
0005432382561	31282	Economy	3300.00
0005432382517	31282	Economy	3300.00
0005432382605	31282	Economy	3300.00
0005435548467	26462	Economy	23800.00
0005435548464	26462	Economy	23800.00
0005435548463	26462	Economy	23800.00
0005435548468	26462	Economy	23800.00
0005435548472	26462	Economy	23800.00
0005433788154	26462	Economy	23800.00
0005435548471	26462	Economy	23800.00
0005433788158	26462	Economy	23800.00
0005435548473	26462	Economy	23800.00
0005433788143	26462	Economy	23800.00
0005435548469	26462	Economy	23800.00
0005435548470	26462	Economy	23800.00
0005435548466	26462	Economy	23800.00
0005435548465	26462	Economy	23800.00
0005433126781	10772	Economy	17100.00
0005433131638	10772	Economy	15600.00
0005435299711	10772	Economy	15600.00
0005433126777	10772	Economy	15600.00
0005433131640	10772	Economy	15600.00
0005433131637	10772	Economy	15600.00
0005435299708	10772	Economy	15600.00
0005435299702	10772	Economy	15600.00
0005433131642	10772	Economy	15600.00
0005435299709	10772	Economy	15600.00
0005433131641	10772	Economy	15600.00
0005433126821	29693	Economy	17100.00
0005435299750	29693	Economy	15600.00
0005435302178	29693	Economy	15600.00
0005433129252	29693	Economy	15600.00
0005435302176	29693	Economy	15600.00
0005433126822	29693	Economy	15600.00
0005435302174	29693	Economy	15600.00
0005435299753	29693	Economy	15600.00
0005433126820	29693	Economy	15600.00
0005435302173	29693	Economy	15600.00
0005435302175	29693	Economy	15600.00
0005433129253	29693	Economy	15600.00
0005435299752	29693	Economy	15600.00
0005435302177	29693	Economy	15600.00
0005435299751	29693	Economy	15600.00
0005432264459	2422	Economy	17200.00
0005434287162	2422	Economy	17200.00
0005432264461	2422	Economy	17200.00
0005433109863	2422	Economy	17200.00
0005434287164	2422	Economy	15700.00
0005434287151	2422	Economy	15700.00
0005433109869	2422	Economy	15700.00
0005434287163	2422	Economy	15700.00
0005433109846	2422	Economy	15700.00
0005433109934	2422	Economy	15700.00
0005434287152	2422	Economy	15700.00
0005434287157	2422	Economy	15700.00
0005434287155	2422	Economy	15700.00
0005433109900	2422	Economy	15700.00
0005434287161	2422	Economy	15700.00
0005434287148	2422	Economy	15700.00
0005434287159	2422	Economy	15700.00
0005434287154	2422	Economy	15700.00
0005433109897	2422	Economy	15700.00
0005433109845	2422	Economy	15700.00
0005434287158	2422	Economy	15700.00
0005433109868	2422	Economy	15700.00
0005434287147	2422	Economy	15700.00
0005434287146	2422	Economy	15700.00
0005434287143	2422	Economy	15700.00
0005434287156	2422	Economy	15700.00
0005433109902	2422	Economy	15700.00
0005434287160	2422	Economy	15700.00
0005434287153	2422	Economy	15700.00
0005434287145	2422	Economy	15700.00
0005434287149	2422	Economy	15700.00
0005434287144	2422	Economy	15700.00
0005432264460	2422	Economy	15700.00
0005434287150	2422	Economy	15700.00
0005433109931	2422	Economy	15700.00
0005434287142	2422	Economy	15700.00
0005433109906	2422	Economy	15700.00
0005433109871	2422	Economy	15700.00
0005433109898	2422	Economy	15700.00
0005434286980	26869	Economy	17200.00
0005433109977	26869	Economy	17200.00
0005433109982	26869	Economy	15700.00
0005434287024	26869	Economy	15700.00
0005434286951	26869	Economy	15700.00
0005433109974	26869	Economy	15700.00
0005434286993	26869	Economy	15700.00
0005434286997	26869	Economy	15700.00
0005433109976	26869	Economy	15700.00
0005434286979	26869	Economy	15700.00
0005433109979	26869	Economy	15700.00
0005433109973	26869	Economy	15700.00
0005433109978	26869	Economy	15700.00
0005433109981	26869	Economy	15700.00
0005434286992	26869	Economy	15700.00
0005434287017	26869	Economy	15700.00
0005434286995	26869	Economy	15700.00
0005434286936	26869	Economy	15700.00
0005433109975	26869	Economy	15700.00
0005433109984	26869	Economy	15700.00
0005433109985	26869	Economy	15700.00
0005434287018	26869	Economy	15700.00
0005433109983	26869	Economy	15700.00
0005434287016	26869	Economy	15700.00
0005433109980	26869	Economy	15700.00
0005434286921	26869	Economy	15700.00
0005434272164	25490	Economy	25000.00
0005435856180	25490	Economy	22800.00
0005435856178	25490	Economy	22800.00
0005434272162	25490	Economy	22800.00
0005434272163	25490	Economy	22800.00
0005434269072	25490	Economy	22800.00
0005434269073	25490	Economy	22800.00
0005435856177	25490	Economy	22800.00
0005435856179	25490	Economy	22800.00
0005434272181	26640	Economy	22800.00
0005435856133	26640	Economy	22800.00
0005434273068	26640	Economy	22800.00
0005434272182	26640	Economy	22800.00
0005434273067	26640	Economy	22800.00
0005434520137	19081	Economy	24600.00
0005434520145	19081	Economy	24600.00
0005435314809	19081	Economy	24600.00
0005435314802	19081	Economy	22300.00
0005435314803	19081	Economy	22300.00
0005434520151	19081	Economy	22300.00
0005434520139	19081	Economy	22300.00
0005435314804	19081	Economy	22300.00
0005434520157	19081	Economy	22300.00
0005435314808	19081	Economy	22300.00
0005434520126	19081	Economy	22300.00
0005434520132	19081	Economy	22300.00
0005434520150	19081	Economy	22300.00
0005435314807	19081	Economy	22300.00
0005435314812	19081	Economy	22300.00
0005434520140	19081	Economy	22300.00
0005435314811	19081	Economy	22300.00
0005434520127	19081	Economy	22300.00
0005434520146	19081	Economy	22300.00
0005434520147	19081	Economy	22300.00
0005434520149	19081	Economy	22300.00
0005434520142	19081	Economy	22300.00
0005434520148	19081	Economy	22300.00
0005434520165	19081	Economy	22300.00
0005435314806	19081	Economy	22300.00
0005435314805	19081	Economy	22300.00
0005434520141	19081	Economy	22300.00
0005435314810	19081	Economy	22300.00
0005435314814	19081	Economy	22300.00
0005434520133	19081	Economy	22300.00
0005434520134	19081	Economy	22300.00
0005434520138	19081	Economy	22300.00
0005434520144	19081	Economy	22300.00
0005435314813	19081	Economy	22300.00
0005433874332	7793	Economy	19200.00
0005433874334	7793	Economy	17400.00
0005433874330	7793	Economy	17400.00
0005433874321	7793	Economy	17400.00
0005433874322	7793	Economy	17400.00
0005433874331	7793	Economy	17400.00
0005433874329	7793	Economy	17400.00
0005433874320	7793	Economy	17400.00
0005433874325	7793	Economy	17400.00
0005433874333	7793	Economy	17400.00
0005433874328	7793	Economy	17400.00
0005433874323	7793	Economy	17400.00
0005433874326	7793	Economy	17400.00
0005433874327	7793	Economy	17400.00
0005433874324	7793	Economy	17400.00
0005433874319	32638	Economy	17400.00
0005433874307	32638	Economy	17400.00
0005433874302	32638	Economy	17400.00
0005433874298	32638	Economy	17400.00
0005433874297	32638	Economy	17400.00
0005433874318	32638	Economy	17400.00
0005433874295	32638	Economy	17400.00
0005433874306	32638	Economy	17400.00
0005433874292	32638	Economy	17400.00
0005433874291	32638	Economy	17400.00
0005433868211	4758	Economy	19400.00
0005433868190	4758	Economy	19400.00
0005433868215	4758	Economy	19400.00
0005433868182	4758	Economy	17600.00
0005435860432	4758	Economy	17600.00
0005433868203	4758	Economy	17600.00
0005433868202	4758	Economy	17600.00
0005433868210	4758	Economy	17600.00
0005433868186	4758	Economy	17600.00
0005433868181	4758	Economy	17600.00
0005433868209	4758	Economy	17600.00
0005433868179	4758	Economy	17600.00
0005433868220	4758	Economy	17600.00
0005433868199	4758	Economy	17600.00
0005433868191	4758	Economy	17600.00
0005433868193	4758	Economy	17600.00
0005433868188	4758	Economy	17600.00
0005433868194	4758	Economy	17600.00
0005433868185	4758	Economy	17600.00
0005433868198	4758	Economy	17600.00
0005433868192	4758	Economy	17600.00
0005433868205	4758	Economy	17600.00
0005433868208	4758	Economy	17600.00
0005433868216	4758	Economy	17600.00
0005433868195	4758	Economy	17600.00
0005433868204	4758	Economy	17600.00
0005433868201	4758	Economy	17600.00
0005433868187	4758	Economy	17600.00
0005433868219	4758	Economy	17600.00
0005433868212	4758	Economy	17600.00
0005433868200	4758	Economy	17600.00
0005433868213	4758	Economy	17600.00
0005433868197	4758	Economy	17600.00
0005435860433	4758	Economy	17600.00
0005433868183	4758	Economy	17600.00
0005433868184	4758	Economy	17600.00
0005433868196	4758	Economy	17600.00
0005433868180	4758	Economy	17600.00
0005433868189	4758	Economy	17600.00
0005433868218	4758	Economy	17600.00
0005433868217	4758	Economy	17600.00
0005433868207	4758	Economy	17600.00
0005433868206	4758	Economy	17600.00
0005433868214	4758	Economy	17600.00
0005433867829	32568	Economy	19400.00
0005433867859	32568	Economy	19400.00
0005433867878	32568	Economy	19400.00
0005433867888	32568	Economy	19400.00
0005433867977	32568	Economy	17600.00
0005433867823	32568	Economy	17600.00
0005433867784	32568	Economy	17600.00
0005433867824	32568	Economy	17600.00
0005433867879	32568	Economy	17600.00
0005433867954	32568	Economy	17600.00
0005433867877	32568	Economy	17600.00
0005433867837	32568	Economy	17600.00
0005433867822	32568	Economy	17600.00
0005433867745	32568	Economy	17600.00
0005433867750	32568	Economy	17600.00
0005433867835	32568	Economy	17600.00
0005433867978	32568	Economy	17600.00
0005433867783	32568	Economy	17600.00
0005433867741	32568	Economy	17600.00
0005433867950	32568	Economy	17600.00
0005433867851	32568	Economy	17600.00
0005433867875	32568	Economy	17600.00
0005433867946	32568	Economy	17600.00
0005433867913	32568	Economy	17600.00
0005433867928	32568	Economy	17600.00
0005433867843	32568	Economy	17600.00
0005435860467	32568	Economy	17600.00
0005433867838	32568	Economy	17600.00
0005433867739	32568	Economy	17600.00
0005433867742	32568	Economy	17600.00
0005433867749	32568	Economy	17600.00
0005433867842	32568	Economy	17600.00
0005433867929	32568	Economy	17600.00
0005433867836	32568	Economy	17600.00
0005433867841	32568	Economy	17600.00
0005433867900	32568	Economy	17600.00
0005433867785	32568	Economy	17600.00
0005433867951	32568	Economy	17600.00
0005433868030	32568	Economy	17600.00
0005433867927	32568	Economy	17600.00
0005433867856	32568	Economy	17600.00
0005433867999	32568	Economy	17600.00
0005434663319	3452	Economy	24800.00
0005434460494	3452	Economy	24800.00
0005434663323	3452	Economy	24800.00
0005434663331	3452	Economy	22600.00
0005434663320	3452	Economy	22600.00
0005434663329	3452	Economy	22600.00
0005434663328	3452	Economy	22600.00
0005434663330	3452	Economy	22600.00
0005435911340	3452	Economy	22600.00
0005434663332	3452	Economy	22600.00
0005434663327	3452	Economy	22600.00
0005434460493	3452	Economy	22600.00
0005434460492	3452	Economy	22600.00
0005434663324	3452	Economy	22600.00
0005434663321	3452	Economy	22600.00
0005434460491	3452	Economy	22600.00
0005434663326	3452	Economy	22600.00
0005434461634	3452	Economy	22600.00
0005435911321	3452	Economy	22600.00
0005435911332	3452	Economy	22600.00
0005434663322	3452	Economy	22600.00
0005434663325	3452	Economy	22600.00
0005435911405	12450	Economy	24800.00
0005434663199	12450	Economy	24800.00
0005435911401	12450	Economy	22600.00
0005434663223	12450	Economy	22600.00
0005434462757	12450	Economy	22600.00
0005434460473	12450	Economy	22600.00
0005435911409	12450	Economy	22600.00
0005434663190	12450	Economy	22600.00
0005434663179	12450	Economy	22600.00
0005435911404	12450	Economy	22600.00
0005435911403	12450	Economy	22600.00
0005434462752	12450	Economy	22600.00
0005434663189	12450	Economy	22600.00
0005435911402	12450	Economy	22600.00
0005434460468	12450	Economy	22600.00
0005435911408	12450	Economy	22600.00
0005434460476	12450	Economy	22600.00
0005434663263	12450	Economy	22600.00
0005434663188	12450	Economy	22600.00
0005435911407	12450	Economy	22600.00
0005434663222	12450	Economy	22600.00
0005434460466	12450	Economy	22600.00
0005434663206	12450	Economy	22600.00
0005435911406	12450	Economy	22600.00
0005433867739	14489	Economy	18500.00
0005433867745	14489	Economy	18500.00
0005433867783	14489	Economy	18500.00
0005433867784	14489	Economy	16800.00
0005433867829	14489	Economy	16800.00
0005433867954	14489	Economy	16800.00
0005433867856	14489	Economy	16800.00
0005433867785	14489	Economy	16800.00
0005433867838	14489	Economy	16800.00
0005433867742	14489	Economy	16800.00
0005433867900	14489	Economy	16800.00
0005433867836	14489	Economy	16800.00
0005433867877	14489	Economy	16800.00
0005433867824	14489	Economy	16800.00
0005433867841	14489	Economy	16800.00
0005433867843	14489	Economy	16800.00
0005433867875	14489	Economy	16800.00
0005433867927	14489	Economy	16800.00
0005433867928	14489	Economy	16800.00
0005433867837	14489	Economy	16800.00
0005433867951	14489	Economy	16800.00
0005433867842	14489	Economy	16800.00
0005433867946	14489	Economy	16800.00
0005433867822	14489	Economy	16800.00
0005433867835	14489	Economy	16800.00
0005433867823	14489	Economy	16800.00
0005433867879	14489	Economy	16800.00
0005433867878	14489	Economy	16800.00
0005435860467	14489	Economy	16800.00
0005433867950	14489	Economy	16800.00
0005433867888	14489	Economy	16800.00
0005433867978	14489	Economy	16800.00
0005433867999	14489	Economy	16800.00
0005433868030	14489	Economy	16800.00
0005433867913	14489	Economy	16800.00
0005433867977	14489	Economy	16800.00
0005433867859	14489	Economy	16800.00
0005433867749	14489	Economy	16800.00
0005433867741	14489	Economy	16800.00
0005433867929	14489	Economy	16800.00
0005433867851	14489	Economy	16800.00
0005433867750	14489	Economy	16800.00
0005433868155	32679	Economy	18500.00
0005433868174	32679	Economy	18500.00
0005433868171	32679	Economy	18500.00
0005433868163	32679	Economy	16800.00
0005433868150	32679	Economy	16800.00
0005433868158	32679	Economy	16800.00
0005433868162	32679	Economy	16800.00
0005433868145	32679	Economy	16800.00
0005433868175	32679	Economy	16800.00
0005433868169	32679	Economy	16800.00
0005433868153	32679	Economy	16800.00
0005433868152	32679	Economy	16800.00
0005433868178	32679	Economy	16800.00
0005433868170	32679	Economy	16800.00
0005433868165	32679	Economy	16800.00
0005433868142	32679	Economy	16800.00
0005433868149	32679	Economy	16800.00
0005433868159	32679	Economy	16800.00
0005433868140	32679	Economy	16800.00
0005433868141	32679	Economy	16800.00
0005433868154	32679	Economy	16800.00
0005433868139	32679	Economy	16800.00
0005433868164	32679	Economy	16800.00
0005433868173	32679	Economy	16800.00
0005433868138	32679	Economy	16800.00
0005433868161	32679	Economy	16800.00
0005433868148	32679	Economy	16800.00
0005433868176	32679	Economy	16800.00
0005433868143	32679	Economy	16800.00
0005433868160	32679	Economy	16800.00
0005433868172	32679	Economy	16800.00
0005433868147	32679	Economy	16800.00
0005433868167	32679	Economy	16800.00
0005433868177	32679	Economy	16800.00
0005433868144	32679	Economy	16800.00
0005433868168	32679	Economy	16800.00
0005433868156	32679	Economy	16800.00
0005433868146	32679	Economy	16800.00
0005433868137	32679	Economy	16800.00
0005433868166	32679	Economy	16800.00
0005433868157	32679	Economy	16800.00
0005433868151	32679	Economy	16800.00
0005432799024	12138	Economy	4900.00
0005432799031	12138	Economy	4900.00
0005432798984	12138	Economy	4900.00
0005432799120	12138	Economy	4400.00
0005432798994	12138	Economy	4400.00
0005432799067	12138	Economy	4400.00
0005432799203	12138	Economy	4400.00
0005432798962	12138	Economy	4400.00
0005432799030	12138	Economy	4400.00
0005432799066	12138	Economy	4400.00
0005432799026	12138	Economy	4400.00
0005432799025	12138	Economy	4400.00
0005432799072	12138	Economy	4400.00
0005432799064	12138	Economy	4400.00
0005432799065	12138	Economy	4400.00
0005432799123	12138	Economy	4400.00
0005432799202	12138	Economy	4400.00
0005432799152	12138	Economy	4400.00
0005432799048	12138	Economy	4400.00
0005432799151	12138	Economy	4400.00
0005432799054	12138	Economy	4400.00
0005432798999	12138	Economy	4400.00
0005432799139	12138	Economy	4400.00
0005432799251	14783	Economy	4900.00
0005432799248	14783	Economy	4900.00
0005432799255	14783	Economy	4900.00
0005432799254	14783	Economy	4400.00
0005432799250	14783	Economy	4400.00
0005432799262	14783	Economy	4400.00
0005432799263	14783	Economy	4400.00
0005432799267	14783	Economy	4400.00
0005432799257	14783	Economy	4400.00
0005432799256	14783	Economy	4400.00
0005432799253	14783	Economy	4400.00
0005432799249	14783	Economy	4400.00
0005432799259	14783	Economy	4400.00
0005432799246	14783	Economy	4400.00
0005432799260	14783	Economy	4400.00
0005432799252	14783	Economy	4400.00
0005432799243	14783	Economy	4400.00
0005432799268	14783	Economy	4400.00
0005432799264	14783	Economy	4400.00
0005432799245	14783	Economy	4400.00
0005432799266	14783	Economy	4400.00
0005432799247	14783	Economy	4400.00
0005432799258	14783	Economy	4400.00
0005432799244	14783	Economy	4400.00
0005432799269	14783	Economy	4400.00
0005432799270	14783	Economy	4400.00
0005432799265	14783	Economy	4400.00
0005432799261	14783	Economy	4400.00
0005434299421	7050	Business	49100.00
0005434407397	7050	Business	49100.00
0005432108235	7050	Business	49100.00
0005435310853	7050	Business	49100.00
0005434407402	7050	Business	49100.00
0005435310859	7050	Business	49100.00
0005434299419	7050	Business	49100.00
0005434407412	7050	Business	49100.00
0005434299418	7050	Business	49100.00
0005434407348	7050	Business	49100.00
0005434407387	7050	Economy	16400.00
0005435310888	7050	Economy	16400.00
0005434407369	7050	Economy	16400.00
0005434407376	7050	Economy	16400.00
0005434407400	7050	Economy	16400.00
0005432153896	7050	Economy	16400.00
0005434407350	7050	Economy	16400.00
0005432153895	7050	Economy	16400.00
0005435310860	7050	Economy	16400.00
0005434407391	7050	Economy	16400.00
0005434299409	7050	Economy	16400.00
0005434407383	7050	Economy	16400.00
0005434407375	7050	Economy	16400.00
0005434299420	7050	Economy	16400.00
0005434407401	7050	Economy	16400.00
0005434407399	7050	Economy	16400.00
0005435293046	7050	Economy	16400.00
0005434407377	7050	Economy	16400.00
0005434407411	7050	Economy	16400.00
0005434299430	7050	Economy	16400.00
0005434299417	7050	Economy	16400.00
0005434299422	7050	Economy	16400.00
0005434407361	7050	Economy	16400.00
0005434407410	7050	Economy	16400.00
0005434407398	7050	Economy	16400.00
0005434299426	7050	Economy	16400.00
0005434299414	7050	Economy	16400.00
0005432108233	7050	Economy	16400.00
0005434407384	7050	Economy	16400.00
0005434407365	7050	Economy	16400.00
0005434407366	7050	Economy	16400.00
0005435310836	7050	Economy	16400.00
0005434407352	7050	Economy	16400.00
0005434299429	7050	Economy	16400.00
0005434407355	7050	Economy	16400.00
0005435310861	7050	Economy	16400.00
0005435293047	7050	Economy	16400.00
0005434299413	7050	Economy	16400.00
0005434407362	7050	Economy	18000.00
0005434407394	7050	Economy	18000.00
0005435293112	7050	Economy	18000.00
0005435310879	7050	Economy	18000.00
0005434407359	7050	Economy	18000.00
0005435293089	7050	Economy	18000.00
0005432153892	7050	Economy	16400.00
0005434407363	7050	Economy	16400.00
0005434407389	7050	Economy	16400.00
0005434407408	7050	Economy	16400.00
0005434407392	7050	Economy	16400.00
0005434407368	7050	Economy	16400.00
0005434407396	7050	Economy	16400.00
0005434407406	7050	Economy	16400.00
0005434407354	7050	Economy	16400.00
0005434407374	7050	Economy	16400.00
0005432108236	7050	Economy	16400.00
0005434299408	7050	Economy	16400.00
0005434299415	7050	Economy	16400.00
0005434407382	7050	Economy	16400.00
0005434407405	7050	Economy	16400.00
0005434407347	7050	Economy	16400.00
0005435310880	7050	Economy	16400.00
0005435293081	7050	Economy	16400.00
0005434299424	7050	Economy	16400.00
0005432153893	7050	Economy	16400.00
0005434407388	7050	Economy	16400.00
0005434407380	7050	Economy	16400.00
0005434407409	7050	Economy	16400.00
0005435293085	7050	Economy	16400.00
0005432153894	7050	Economy	16400.00
0005434407385	7050	Economy	16400.00
0005434299427	7050	Economy	16400.00
0005432108234	7050	Economy	16400.00
0005434299423	7050	Economy	16400.00
0005434407386	7050	Economy	16400.00
0005434299416	7050	Economy	16400.00
0005434407393	7050	Economy	16400.00
0005434407407	7050	Economy	16400.00
0005434407372	7050	Economy	16400.00
0005432153898	7050	Economy	16400.00
0005435310882	7050	Economy	16400.00
0005434407367	7050	Economy	16400.00
0005434299410	7050	Economy	16400.00
0005434299428	7050	Economy	16400.00
0005434407371	7050	Economy	16400.00
0005434407370	7050	Economy	16400.00
0005434407349	7050	Economy	16400.00
0005434407360	7050	Economy	16400.00
0005435310876	7050	Economy	16400.00
0005434407373	7050	Economy	16400.00
0005434299431	7050	Economy	16400.00
0005434407390	7050	Economy	16400.00
0005434407357	7050	Economy	16400.00
0005434407356	7050	Economy	16400.00
0005434407379	7050	Economy	16400.00
0005434299412	7050	Economy	16400.00
0005434407381	7050	Economy	16400.00
0005434407404	7050	Economy	16400.00
0005435310878	7050	Economy	16400.00
0005435293124	7050	Economy	16400.00
0005434407358	7050	Economy	16400.00
0005432153897	7050	Economy	16400.00
0005434299425	7050	Economy	16400.00
0005434407403	7050	Economy	16400.00
0005434407378	7050	Economy	16400.00
0005434407351	7050	Economy	16400.00
0005435310881	7050	Economy	16400.00
0005435293057	7050	Economy	16400.00
0005434299411	7050	Economy	16400.00
0005434407353	7050	Economy	16400.00
0005435293123	7050	Economy	16400.00
0005434407364	7050	Economy	16400.00
0005434407395	7050	Economy	16400.00
0005435310979	26905	Business	49100.00
0005434406807	26905	Business	49100.00
0005434406672	26905	Business	49100.00
0005435293176	26905	Business	49100.00
0005435310991	26905	Business	49100.00
0005434406845	26905	Business	49100.00
0005434406731	26905	Business	49100.00
0005434407087	26905	Business	49100.00
0005435293179	26905	Business	49100.00
0005434406895	26905	Business	49100.00
0005434299202	26905	Business	49100.00
0005434299278	26905	Economy	16400.00
0005434299338	26905	Economy	16400.00
0005432058354	26905	Economy	16400.00
0005434406671	26905	Economy	16400.00
0005434406814	26905	Economy	16400.00
0005434406774	26905	Economy	16400.00
0005434406780	26905	Economy	16400.00
0005434299337	26905	Economy	16400.00
0005435310994	26905	Economy	16400.00
0005434406738	26905	Economy	16400.00
0005432058355	26905	Economy	16400.00
0005435293173	26905	Economy	16400.00
0005435293177	26905	Economy	16400.00
0005434406739	26905	Economy	16400.00
0005435293175	26905	Economy	16400.00
0005435310989	26905	Economy	16400.00
0005434406811	26905	Economy	16400.00
0005434406967	26905	Economy	16400.00
0005434406725	26905	Economy	16400.00
0005434406678	26905	Economy	16400.00
0005435310992	26905	Economy	16400.00
0005435310981	26905	Economy	16400.00
0005434406659	26905	Economy	16400.00
0005434406882	26905	Economy	16400.00
0005434406657	26905	Economy	16400.00
0005435310978	26905	Economy	16400.00
0005434406648	26905	Economy	16400.00
0005435310984	26905	Economy	16400.00
0005434406893	26905	Economy	16400.00
0005434406658	26905	Economy	16400.00
0005435310990	26905	Economy	16400.00
0005434299297	26905	Economy	16400.00
0005432058353	26905	Economy	18000.00
0005435293181	26905	Economy	18000.00
0005434406781	26905	Economy	18000.00
0005434406697	26905	Economy	18000.00
0005434406699	26905	Economy	16400.00
0005434406753	26905	Economy	16400.00
0005434406943	26905	Economy	16400.00
0005434299291	26905	Economy	16400.00
0005434299177	26905	Economy	16400.00
0005434299336	26905	Economy	16400.00
0005434406718	26905	Economy	16400.00
0005434299264	26905	Economy	16400.00
0005435310985	26905	Economy	16400.00
0005432058356	26905	Economy	16400.00
0005434406703	26905	Economy	16400.00
0005435293171	26905	Economy	16400.00
0005434299199	26905	Economy	16400.00
0005434406880	26905	Economy	16400.00
0005434299288	26905	Economy	16400.00
0005435310988	26905	Economy	16400.00
0005435310993	26905	Economy	16400.00
0005434299295	26905	Economy	16400.00
0005434406978	26905	Economy	16400.00
0005434406641	26905	Economy	16400.00
0005434406977	26905	Economy	16400.00
0005434299296	26905	Economy	16400.00
0005434406752	26905	Economy	16400.00
0005435310986	26905	Economy	16400.00
0005434406684	26905	Economy	16400.00
0005434299249	26905	Economy	16400.00
0005434299149	26905	Economy	16400.00
0005434406843	26905	Economy	16400.00
0005434299226	26905	Economy	16400.00
0005434406698	26905	Economy	16400.00
0005435293178	26905	Economy	16400.00
0005434406936	26905	Economy	16400.00
0005434299203	26905	Economy	16400.00
0005435310995	26905	Economy	16400.00
0005435293180	26905	Economy	16400.00
0005435293174	26905	Economy	16400.00
0005434407048	26905	Economy	16400.00
0005434406881	26905	Economy	16400.00
0005434406844	26905	Economy	16400.00
0005435310987	26905	Economy	16400.00
0005434406812	26905	Economy	16400.00
0005434406754	26905	Economy	16400.00
0005434406760	26905	Economy	16400.00
0005435310982	26905	Economy	16400.00
0005434299178	26905	Economy	16400.00
0005434406689	26905	Economy	16400.00
0005432058352	26905	Economy	16400.00
0005434406688	26905	Economy	16400.00
0005434406894	26905	Economy	16400.00
0005435310983	26905	Economy	16400.00
0005434406842	26905	Economy	16400.00
0005434406676	26905	Economy	16400.00
0005434407033	26905	Economy	16400.00
0005434299248	26905	Economy	16400.00
0005435310980	26905	Economy	16400.00
0005434299326	26905	Economy	16400.00
0005434406901	26905	Economy	16400.00
0005435293170	26905	Economy	16400.00
0005435293172	26905	Economy	16400.00
0005434406677	26905	Economy	16400.00
0005434406702	26905	Economy	16400.00
0005432604092	6471	Economy	16500.00
0005434512087	6471	Economy	16500.00
0005435218102	6471	Economy	16500.00
0005432604105	6471	Economy	16500.00
0005432604120	6471	Economy	15000.00
0005432604095	6471	Economy	15000.00
0005432604093	6471	Economy	15000.00
0005432604125	6471	Economy	15000.00
0005432604124	6471	Economy	15000.00
0005432604115	6471	Economy	15000.00
0005432604123	6471	Economy	15000.00
0005432604097	6471	Economy	15000.00
0005432604099	6471	Economy	15000.00
0005434512085	6471	Economy	15000.00
0005432604103	6471	Economy	15000.00
0005432604111	6471	Economy	15000.00
0005432604107	6471	Economy	15000.00
0005432604109	6471	Economy	15000.00
0005432604104	6471	Economy	15000.00
0005434512088	6471	Economy	15000.00
0005432604091	6471	Economy	15000.00
0005432604119	6471	Economy	15000.00
0005432604110	6471	Economy	15000.00
0005432604106	6471	Economy	15000.00
0005432604096	6471	Economy	15000.00
0005432604090	6471	Economy	15000.00
0005432604102	6471	Economy	15000.00
0005432604127	6471	Economy	15000.00
0005434512089	6471	Economy	15000.00
0005432604122	6471	Economy	15000.00
0005432604088	6471	Economy	15000.00
0005432604112	6471	Economy	15000.00
0005432604100	6471	Economy	15000.00
0005432604108	6471	Economy	15000.00
0005432604094	6471	Economy	15000.00
0005432604118	6471	Economy	15000.00
0005432604089	6471	Economy	15000.00
0005432604116	6471	Economy	15000.00
0005434512086	6471	Economy	15000.00
0005432604113	6471	Economy	15000.00
0005432604098	6471	Economy	15000.00
0005432604117	6471	Economy	15000.00
0005432604126	6471	Economy	15000.00
0005432604114	6471	Economy	15000.00
0005432604101	6471	Economy	15000.00
0005432604121	6471	Economy	15000.00
0005435218101	6471	Economy	15000.00
0005432603776	21342	Economy	16500.00
0005432603756	21342	Economy	16500.00
0005432603914	21342	Economy	16500.00
0005432604014	21342	Economy	15000.00
0005432604015	21342	Economy	15000.00
0005432603656	21342	Economy	15000.00
0005432603727	21342	Economy	15000.00
0005432603764	21342	Economy	15000.00
0005434512020	21342	Economy	15000.00
0005432603709	21342	Economy	15000.00
0005432603765	21342	Economy	15000.00
0005434512047	21342	Economy	15000.00
0005432603706	21342	Economy	15000.00
0005432603755	21342	Economy	15000.00
0005432603821	21342	Economy	15000.00
0005434512056	21342	Economy	15000.00
0005432603913	21342	Economy	15000.00
0005434512031	21342	Economy	15000.00
0005432603688	21342	Economy	15000.00
0005432603707	21342	Economy	15000.00
0005432603710	21342	Economy	15000.00
0005434512050	21342	Economy	15000.00
0005432603794	21342	Economy	15000.00
0005432603697	21342	Economy	15000.00
0005432603915	21342	Economy	15000.00
0005432603743	21342	Economy	15000.00
0005432603723	21342	Economy	15000.00
0005432603808	21342	Economy	15000.00
0005432603720	21342	Economy	15000.00
0005432603681	21342	Economy	15000.00
0005432603711	21342	Economy	15000.00
0005432603926	21342	Economy	15000.00
0005434512019	21342	Economy	15000.00
0005432603829	21342	Economy	15000.00
0005434512018	21342	Economy	15000.00
0005432603803	21342	Economy	15000.00
0005432603708	21342	Economy	15000.00
0005434512035	21342	Economy	15000.00
0005432603916	21342	Economy	15000.00
0005432603766	21342	Economy	15000.00
0005432603687	21342	Economy	15000.00
0005432603762	21342	Economy	15000.00
0005432603777	21342	Economy	15000.00
0005433251289	14984	Business	18900.00
0005434906533	14984	Business	18900.00
0005433251296	14984	Business	18900.00
0005433251292	14984	Business	18900.00
0005433251282	14984	Business	18900.00
0005434906575	14984	Business	18900.00
0005433251285	14984	Economy	6300.00
0005434906619	14984	Economy	6300.00
0005434906677	14984	Economy	6300.00
0005434906476	14984	Economy	6300.00
0005433251294	14984	Economy	6300.00
0005433251293	14984	Economy	6300.00
0005433251300	14984	Economy	6300.00
0005434906452	14984	Economy	6300.00
0005433251284	14984	Economy	6300.00
0005434906669	14984	Economy	6900.00
0005433251287	14984	Economy	6900.00
0005434906363	14984	Economy	6900.00
0005434906482	14984	Economy	6900.00
0005433251298	14984	Economy	6300.00
0005434906551	14984	Economy	6300.00
0005433251281	14984	Economy	6300.00
0005434906460	14984	Economy	6300.00
0005434906668	14984	Economy	6300.00
0005434906474	14984	Economy	6300.00
0005433251280	14984	Economy	6300.00
0005433251286	14984	Economy	6300.00
0005434906532	14984	Economy	6300.00
0005434906519	14984	Economy	6300.00
0005433251295	14984	Economy	6300.00
0005433251301	14984	Economy	6300.00
0005434906536	14984	Economy	6300.00
0005434906458	14984	Economy	6300.00
0005434906398	14984	Economy	6300.00
0005434906432	14984	Economy	6300.00
0005434906387	14984	Economy	6300.00
0005433251304	14984	Economy	6300.00
0005434906477	14984	Economy	6300.00
0005433251277	14984	Economy	6300.00
0005434906671	14984	Economy	6300.00
0005434906399	14984	Economy	6300.00
0005434906493	14984	Economy	6300.00
0005433251299	14984	Economy	6300.00
0005434906359	14984	Economy	6300.00
0005433251278	14984	Economy	6300.00
0005433251275	14984	Economy	6300.00
0005434906459	14984	Economy	6300.00
0005433251276	14984	Economy	6300.00
0005433251283	14984	Economy	6300.00
0005434906690	14984	Economy	6300.00
0005434906520	14984	Economy	6300.00
0005433251290	14984	Economy	6300.00
0005434906464	14984	Economy	6300.00
0005433251288	14984	Economy	6300.00
0005433251279	14984	Economy	6300.00
0005434906585	14984	Economy	6300.00
0005433251305	14984	Economy	6300.00
0005434906603	14984	Economy	6300.00
0005434906550	14984	Economy	6300.00
0005433251291	14984	Economy	6300.00
0005434906676	14984	Economy	6300.00
0005434906411	14984	Economy	6300.00
0005434906453	14984	Economy	6300.00
0005434906512	14984	Economy	6300.00
0005433251302	14984	Economy	6300.00
0005434906505	14984	Economy	6300.00
0005434906434	14984	Economy	6300.00
0005434906480	14984	Economy	6300.00
0005434906461	14984	Economy	6300.00
0005433251303	14984	Economy	6300.00
0005434906388	14984	Economy	6300.00
0005433251297	14984	Economy	6300.00
0005434906925	25863	Business	18900.00
0005434906905	25863	Business	18900.00
0005434906937	25863	Business	18900.00
0005434906920	25863	Business	18900.00
0005434906915	25863	Business	18900.00
0005433250992	25863	Business	18900.00
0005434906934	25863	Business	18900.00
0005433251149	25863	Business	18900.00
0005434906930	25863	Business	18900.00
0005433251105	25863	Business	18900.00
0005434906921	25863	Business	18900.00
0005434906922	25863	Economy	6300.00
0005434906912	25863	Economy	6300.00
0005433251083	25863	Economy	6300.00
0005433251142	25863	Economy	6300.00
0005433251088	25863	Economy	6300.00
0005434906940	25863	Economy	6300.00
0005433251032	25863	Economy	6300.00
0005433251049	25863	Economy	6900.00
0005433251143	25863	Economy	6900.00
0005434906924	25863	Economy	6900.00
0005434906911	25863	Economy	6900.00
0005434906907	25863	Economy	6300.00
0005434906933	25863	Economy	6300.00
0005433251043	25863	Economy	6300.00
0005434906936	25863	Economy	6300.00
0005434906916	25863	Economy	6300.00
0005433251103	25863	Economy	6300.00
0005433251073	25863	Economy	6300.00
0005433251052	25863	Economy	6300.00
0005434906910	25863	Economy	6300.00
0005434906945	25863	Economy	6300.00
0005434906943	25863	Economy	6300.00
0005433251040	25863	Economy	6300.00
0005433251047	25863	Economy	6300.00
0005433251053	25863	Economy	6300.00
0005434906928	25863	Economy	6300.00
0005434906938	25863	Economy	6300.00
0005434906926	25863	Economy	6300.00
0005434906948	25863	Economy	6300.00
0005434906932	25863	Economy	6300.00
0005433251086	25863	Economy	6300.00
0005434906927	25863	Economy	6300.00
0005434906939	25863	Economy	6300.00
0005434906950	25863	Economy	6300.00
0005434906935	25863	Economy	6300.00
0005434906942	25863	Economy	6300.00
0005433251048	25863	Economy	6300.00
0005433250987	25863	Economy	6300.00
0005433251087	25863	Economy	6300.00
0005433251204	25863	Economy	6300.00
0005434906929	25863	Economy	6300.00
0005434906917	25863	Economy	6300.00
0005434906947	25863	Economy	6300.00
0005433250971	25863	Economy	6300.00
0005434906944	25863	Economy	6300.00
0005434906946	25863	Economy	6300.00
0005434906909	25863	Economy	6300.00
0005434906919	25863	Economy	6300.00
0005433251061	25863	Economy	6300.00
0005433250965	25863	Economy	6300.00
0005433250972	25863	Economy	6300.00
0005434906931	25863	Economy	6300.00
0005434906913	25863	Economy	6300.00
0005434906923	25863	Economy	6300.00
0005434906908	25863	Economy	6300.00
0005433251104	25863	Economy	6300.00
0005434906949	25863	Economy	6300.00
0005434906914	25863	Economy	6300.00
0005434906941	25863	Economy	6300.00
0005433251041	25863	Economy	6300.00
0005433250975	25863	Economy	6300.00
0005433251063	25863	Economy	6300.00
0005433251128	25863	Economy	6300.00
0005434906906	25863	Economy	6300.00
0005434906918	25863	Economy	6300.00
0005433008377	14191	Business	52300.00
0005433008337	14191	Business	52300.00
0005433008341	14191	Business	52300.00
0005433008333	14191	Business	52300.00
0005433008357	14191	Business	52300.00
0005433008339	14191	Business	52300.00
0005433008354	14191	Business	52300.00
0005433008360	14191	Economy	17400.00
0005433008343	14191	Economy	17400.00
0005433008364	14191	Economy	17400.00
0005433008334	14191	Economy	17400.00
0005433008342	14191	Economy	17400.00
0005433008350	14191	Economy	17400.00
0005433008352	14191	Economy	19200.00
0005433008375	14191	Economy	19200.00
0005433008378	14191	Economy	19200.00
0005433008344	14191	Economy	17400.00
0005433008369	14191	Economy	17400.00
0005433008348	14191	Economy	17400.00
0005433008367	14191	Economy	17400.00
0005433008366	14191	Economy	17400.00
0005433008336	14191	Economy	17400.00
0005433008362	14191	Economy	17400.00
0005433008370	14191	Economy	17400.00
0005433008345	14191	Economy	17400.00
0005433008349	14191	Economy	17400.00
0005433008356	14191	Economy	17400.00
0005433008347	14191	Economy	17400.00
0005433008353	14191	Economy	17400.00
0005433008355	14191	Economy	17400.00
0005433008373	14191	Economy	17400.00
0005433008338	14191	Economy	17400.00
0005433008335	14191	Economy	17400.00
0005433008361	14191	Economy	17400.00
0005433008368	14191	Economy	17400.00
0005433008374	14191	Economy	17400.00
0005433008351	14191	Economy	17400.00
0005433008376	14191	Economy	17400.00
0005433008372	14191	Economy	17400.00
0005433008371	14191	Economy	17400.00
0005433810488	14191	Economy	17400.00
0005433008358	14191	Economy	17400.00
0005433008363	14191	Economy	17400.00
0005433008346	14191	Economy	17400.00
0005433008340	14191	Economy	17400.00
0005433008365	14191	Economy	17400.00
0005433008359	14191	Economy	17400.00
0005433007883	22830	Business	52300.00
0005433007850	22830	Business	52300.00
0005433007838	22830	Business	52300.00
0005433007915	22830	Business	52300.00
0005433007949	22830	Business	52300.00
0005433007948	22830	Business	52300.00
0005433007997	22830	Business	52300.00
0005433007934	22830	Business	52300.00
0005433007897	22830	Business	52300.00
0005433008034	22830	Economy	17400.00
0005433008094	22830	Economy	17400.00
0005433008077	22830	Economy	17400.00
0005433007904	22830	Economy	17400.00
0005433007905	22830	Economy	17400.00
0005433007888	22830	Economy	17400.00
0005433007952	22830	Economy	17400.00
0005433008029	22830	Economy	17400.00
0005433007992	22830	Economy	17400.00
0005433007933	22830	Economy	17400.00
0005433007932	22830	Economy	17400.00
0005433007981	22830	Economy	17400.00
0005433007916	22830	Economy	17400.00
0005433007946	22830	Economy	17400.00
0005433007880	22830	Economy	17400.00
0005433007898	22830	Economy	17400.00
0005433007983	22830	Economy	17400.00
0005433007908	22830	Economy	17400.00
0005433007871	22830	Economy	17400.00
0005433008095	22830	Economy	17400.00
0005433007967	22830	Economy	17400.00
0005433008044	22830	Economy	17400.00
0005433007960	22830	Economy	17400.00
0005433007894	22830	Economy	17400.00
0005433007833	22830	Economy	17400.00
0005433007824	22830	Economy	17400.00
0005433007858	22830	Economy	17400.00
0005433007982	22830	Economy	17400.00
0005433007843	22830	Economy	17400.00
0005433007947	22830	Economy	17400.00
0005433007884	22830	Economy	17400.00
0005433007835	22830	Economy	17400.00
0005433007951	22830	Economy	17400.00
0005433007837	22830	Economy	17400.00
0005433007964	22830	Economy	17400.00
0005434925301	14911	Business	22900.00
0005434925340	14911	Business	22900.00
0005434925381	14911	Business	22900.00
0005434925319	14911	Economy	7600.00
0005434925459	14911	Economy	7600.00
0005434925253	14911	Economy	7600.00
0005434925361	14911	Economy	7600.00
0005434925277	14911	Economy	8400.00
0005434925263	14911	Economy	8400.00
0005434925358	14911	Economy	7600.00
0005434925265	14911	Economy	7600.00
0005434925457	14911	Economy	7600.00
0005434925266	14911	Economy	7600.00
0005434925306	14911	Economy	7600.00
0005434925353	14911	Economy	7600.00
0005434925411	14911	Economy	7600.00
0005434925359	14911	Economy	7600.00
0005434925262	14911	Economy	7600.00
0005434925278	14911	Economy	7600.00
0005434925304	14911	Economy	7600.00
0005434925360	14911	Economy	7600.00
0005434925254	14911	Economy	7600.00
0005434925458	14911	Economy	7600.00
0005434925311	14911	Economy	7600.00
0005434925312	14911	Economy	7600.00
0005434925412	14911	Economy	7600.00
0005434925387	14911	Economy	7600.00
0005434925320	14911	Economy	7600.00
0005434925276	14911	Economy	7600.00
0005434925305	14911	Economy	7600.00
0005434925341	14911	Economy	7600.00
0005434925585	20495	Business	22900.00
0005434925596	20495	Economy	7600.00
0005434925606	20495	Economy	7600.00
0005434925594	20495	Economy	7600.00
0005434925590	20495	Economy	8400.00
0005434925573	20495	Economy	8400.00
0005434925604	20495	Economy	7600.00
0005434925603	20495	Economy	7600.00
0005434925600	20495	Economy	7600.00
0005434925578	20495	Economy	7600.00
0005434925592	20495	Economy	7600.00
0005434925588	20495	Economy	7600.00
0005434925574	20495	Economy	7600.00
0005434925587	20495	Economy	7600.00
0005434925584	20495	Economy	7600.00
0005434925593	20495	Economy	7600.00
0005434925599	20495	Economy	7600.00
0005434925589	20495	Economy	7600.00
0005434925583	20495	Economy	7600.00
0005434925605	20495	Economy	7600.00
0005434925580	20495	Economy	7600.00
0005434925597	20495	Economy	7600.00
0005434925579	20495	Economy	7600.00
0005434925586	20495	Economy	7600.00
0005434925591	20495	Economy	7600.00
0005434925581	20495	Economy	7600.00
0005434925572	20495	Economy	7600.00
0005434925577	20495	Economy	7600.00
0005434925595	20495	Economy	7600.00
0005434925601	20495	Economy	7600.00
0005434925582	20495	Economy	7600.00
0005434925575	20495	Economy	7600.00
0005434925576	20495	Economy	7600.00
0005434925602	20495	Economy	7600.00
0005434925598	20495	Economy	7600.00
0005435998974	15819	Economy	8900.00
0005435487699	15819	Economy	8900.00
0005435998998	15819	Economy	8900.00
0005435487716	15819	Economy	8100.00
0005435487713	15819	Economy	8100.00
0005435998992	15819	Economy	8100.00
0005435998985	15819	Economy	8100.00
0005435487701	15819	Economy	8100.00
0005435487711	15819	Economy	8100.00
0005435998986	15819	Economy	8100.00
0005435998954	15819	Economy	8100.00
0005435487714	15819	Economy	8100.00
0005435998993	15819	Economy	8100.00
0005435487702	15819	Economy	8100.00
0005435487712	15819	Economy	8100.00
0005435487706	15819	Economy	8100.00
0005435487698	15819	Economy	8100.00
0005435998956	15819	Economy	8100.00
0005435998958	15819	Economy	8100.00
0005435487718	15819	Economy	8100.00
0005435998977	15819	Economy	8100.00
0005435998960	15819	Economy	8100.00
0005435487704	15819	Economy	8100.00
0005435998959	15819	Economy	8100.00
0005435487700	15819	Economy	8100.00
0005435998997	15819	Economy	8100.00
0005435998963	15819	Economy	8100.00
0005435487703	15819	Economy	8100.00
0005435487710	15819	Economy	8100.00
0005435487705	15819	Economy	8100.00
0005435998955	15819	Economy	8100.00
0005435998981	15819	Economy	8100.00
0005435487707	15819	Economy	8100.00
0005435487717	15819	Economy	8100.00
0005435487709	15819	Economy	8100.00
0005435487708	15819	Economy	8100.00
0005435998994	15819	Economy	8100.00
0005435487697	15819	Economy	8100.00
0005435998964	15819	Economy	8100.00
0005435998973	15819	Economy	8100.00
0005435487715	15819	Economy	8100.00
0005435999140	19689	Economy	8900.00
0005435999135	19689	Economy	8900.00
0005435487535	19689	Economy	8100.00
0005435487493	19689	Economy	8100.00
0005435999136	19689	Economy	8100.00
0005435487488	19689	Economy	8100.00
0005435487537	19689	Economy	8100.00
0005435487483	19689	Economy	8100.00
0005435999141	19689	Economy	8100.00
0005435999129	19689	Economy	8100.00
0005435487460	19689	Economy	8100.00
0005435999132	19689	Economy	8100.00
0005435487536	19689	Economy	8100.00
0005435999130	19689	Economy	8100.00
0005435999138	19689	Economy	8100.00
0005435487524	19689	Economy	8100.00
0005435999133	19689	Economy	8100.00
0005435487454	19689	Economy	8100.00
0005435487471	19689	Economy	8100.00
0005435999134	19689	Economy	8100.00
0005435487546	19689	Economy	8100.00
0005435487455	19689	Economy	8100.00
0005435487453	19689	Economy	8100.00
0005435999131	19689	Economy	8100.00
0005435487545	19689	Economy	8100.00
0005435999142	19689	Economy	8100.00
0005435999137	19689	Economy	8100.00
0005435487525	19689	Economy	8100.00
0005435999143	19689	Economy	8100.00
0005435487462	19689	Economy	8100.00
0005435487487	19689	Economy	8100.00
0005435487623	19689	Economy	8100.00
0005435999139	19689	Economy	8100.00
0005435472604	6021	Business	199300.00
0005435839285	6021	Business	199300.00
0005435839294	6021	Business	199300.00
0005435839301	6021	Business	199300.00
0005435472530	6021	Business	199300.00
0005435839297	6021	Business	199300.00
0005435472566	6021	Business	199300.00
0005435472545	6021	Business	199300.00
0005432660806	6021	Economy	66400.00
0005432659694	6021	Economy	66400.00
0005435839280	6021	Economy	73100.00
0005435839298	6021	Economy	73100.00
0005435839296	6021	Economy	73100.00
0005432659696	6021	Economy	66400.00
0005432142233	6021	Economy	66400.00
0005435839300	6021	Economy	66400.00
0005435839291	6021	Economy	66400.00
0005435472546	6021	Economy	66400.00
0005435839290	6021	Economy	66400.00
0005432142234	6021	Economy	66400.00
0005435472563	6021	Economy	66400.00
0005435839274	6021	Economy	66400.00
0005435472559	6021	Economy	66400.00
0005435472610	6021	Economy	66400.00
0005435839276	6021	Economy	66400.00
0005435839281	6021	Economy	66400.00
0005435839282	6021	Economy	66400.00
0005435472529	6021	Economy	66400.00
0005435839299	6021	Economy	66400.00
0005435839293	6021	Economy	66400.00
0005435839286	6021	Economy	66400.00
0005432658579	6021	Economy	66400.00
0005435472562	6021	Economy	66400.00
0005435839284	6021	Economy	66400.00
0005435472564	6021	Economy	66400.00
0005435472567	6021	Economy	66400.00
0005435472611	6021	Economy	66400.00
0005435839289	6021	Economy	66400.00
0005435839279	6021	Economy	66400.00
0005435839275	6021	Economy	66400.00
0005435839283	6021	Economy	66400.00
0005435839288	6021	Economy	66400.00
0005432142232	6021	Economy	66400.00
0005435839287	6021	Economy	66400.00
0005432660807	6021	Economy	66400.00
0005432659695	6021	Economy	66400.00
0005435472551	6021	Economy	66400.00
0005435839292	6021	Economy	66400.00
0005435839278	6021	Economy	66400.00
0005432658580	6021	Economy	66400.00
0005435839277	6021	Economy	66400.00
0005435839295	6021	Economy	66400.00
0005435472531	6021	Economy	66400.00
0005435472603	6021	Economy	66400.00
0005435839302	6021	Economy	66400.00
0005432658581	6021	Economy	66400.00
0005432667420	18073	Business	199300.00
0005435472698	18073	Business	199300.00
0005435839128	18073	Business	199300.00
0005435472705	18073	Business	199300.00
0005432537046	18073	Business	199300.00
0005435839158	18073	Economy	66400.00
0005435472701	18073	Economy	66400.00
0005435839061	18073	Economy	73100.00
0005435839104	18073	Economy	66400.00
0005435838962	18073	Economy	66400.00
0005435839108	18073	Economy	66400.00
0005435472699	18073	Economy	66400.00
0005435472706	18073	Economy	66400.00
0005435839107	18073	Economy	66400.00
0005435839010	18073	Economy	66400.00
0005435472697	18073	Economy	66400.00
0005435472711	18073	Economy	66400.00
0005435839057	18073	Economy	66400.00
0005435838961	18073	Economy	66400.00
0005435472710	18073	Economy	66400.00
0005435839105	18073	Economy	66400.00
0005435839046	18073	Economy	66400.00
0005435472703	18073	Economy	66400.00
0005435472709	18073	Economy	66400.00
0005435472708	18073	Economy	66400.00
0005435839045	18073	Economy	66400.00
0005435472707	18073	Economy	66400.00
0005435472702	18073	Economy	66400.00
0005435472704	18073	Economy	66400.00
0005435839106	18073	Economy	66400.00
0005435839040	18073	Economy	66400.00
0005435472712	18073	Economy	66400.00
0005435472713	18073	Economy	66400.00
0005435839041	18073	Economy	66400.00
0005435472700	18073	Economy	66400.00
0005432537047	18073	Economy	66400.00
0005432537045	18073	Economy	66400.00
0005435839011	18073	Economy	66400.00
0005435839157	18073	Economy	66400.00
0005433284937	23044	Business	15700.00
0005433284833	23044	Business	15700.00
0005433284863	23044	Business	15700.00
0005433284920	23044	Business	15700.00
0005433284881	23044	Business	15700.00
0005433284921	23044	Business	15700.00
0005433284908	23044	Economy	5200.00
0005433284790	23044	Economy	5200.00
0005433284960	23044	Economy	5200.00
0005433284779	23044	Economy	5200.00
0005433284874	23044	Economy	5200.00
0005433284926	23044	Economy	5200.00
0005433284830	23044	Economy	5200.00
0005433284846	23044	Economy	5200.00
0005433284864	23044	Economy	5200.00
0005433284850	23044	Economy	5200.00
0005433284778	23044	Economy	5200.00
0005433284789	23044	Economy	5200.00
0005433284827	23044	Economy	5200.00
0005433284847	23044	Economy	5200.00
0005433284831	23044	Economy	5700.00
0005433284862	23044	Economy	5200.00
0005433284810	23044	Economy	5200.00
0005433284832	23044	Economy	5200.00
0005433284880	23044	Economy	5200.00
0005433284826	23044	Economy	5200.00
0005433284851	23044	Economy	5200.00
0005433284871	23044	Economy	5200.00
0005433284860	23044	Economy	5200.00
0005433284943	23044	Economy	5200.00
0005433284848	23044	Economy	5200.00
0005433284836	23044	Economy	5200.00
0005433284882	23044	Economy	5200.00
0005433284922	23044	Economy	5200.00
0005433284940	23044	Economy	5200.00
0005433284927	23044	Economy	5200.00
0005433284835	23044	Economy	5200.00
0005433284889	23044	Economy	5200.00
0005433284839	23044	Economy	5200.00
0005433284811	23044	Economy	5200.00
0005433284834	23044	Economy	5200.00
0005433284959	23044	Economy	5200.00
0005433284909	23044	Economy	5200.00
0005433285133	32075	Business	15700.00
0005433285106	32075	Economy	5200.00
0005435103817	32075	Economy	5200.00
0005433285124	32075	Economy	5200.00
0005433285125	32075	Economy	5200.00
0005433285113	32075	Economy	5200.00
0005433285104	32075	Economy	5200.00
0005433285123	32075	Economy	5200.00
0005433285112	32075	Economy	5200.00
0005433285117	32075	Economy	5200.00
0005435103811	32075	Economy	5200.00
0005433285128	32075	Economy	5200.00
0005433285110	32075	Economy	5200.00
0005433285109	32075	Economy	5200.00
0005435103806	32075	Economy	5200.00
0005433285121	32075	Economy	5700.00
0005433285116	32075	Economy	5700.00
0005433285134	32075	Economy	5200.00
0005433285114	32075	Economy	5200.00
0005433285129	32075	Economy	5200.00
0005433285105	32075	Economy	5200.00
0005433285122	32075	Economy	5200.00
0005433285120	32075	Economy	5200.00
0005433285131	32075	Economy	5200.00
0005435103803	32075	Economy	5200.00
0005433285108	32075	Economy	5200.00
0005433285130	32075	Economy	5200.00
0005433285118	32075	Economy	5200.00
0005433285111	32075	Economy	5200.00
0005435103810	32075	Economy	5200.00
0005433285132	32075	Economy	5200.00
0005435103816	32075	Economy	5200.00
0005433285127	32075	Economy	5200.00
0005433285103	32075	Economy	5200.00
0005433285119	32075	Economy	5200.00
0005433285107	32075	Economy	5200.00
0005433285126	32075	Economy	5200.00
0005433285115	32075	Economy	5200.00
0005435213204	30586	Business	42100.00
0005435213227	30586	Business	42100.00
0005432525982	30586	Business	42100.00
0005432526111	30586	Business	42100.00
0005435213197	30586	Business	42100.00
0005435213185	30586	Business	42100.00
0005432526686	30586	Business	42100.00
0005435213196	30586	Business	42100.00
0005435213170	30586	Business	42100.00
0005432211459	30586	Business	42100.00
0005434066746	30586	Business	42100.00
0005432526267	30586	Business	42100.00
0005434066730	30586	Business	42100.00
0005434066534	30586	Business	42100.00
0005432526056	30586	Business	42100.00
0005432526194	30586	Business	42100.00
0005432525672	30586	Business	42100.00
0005432526219	30586	Business	42100.00
0005432526418	30586	Business	42100.00
0005432526440	30586	Business	42100.00
0005432525835	30586	Comfort	23900.00
0005432525735	30586	Comfort	23900.00
0005432526491	30586	Comfort	23900.00
0005432526308	30586	Comfort	23900.00
0005435213208	30586	Comfort	23900.00
0005434066845	30586	Comfort	23900.00
0005434066402	30586	Comfort	23900.00
0005435213163	30586	Comfort	23900.00
0005432525811	30586	Comfort	23900.00
0005434066464	30586	Comfort	23900.00
0005434066451	30586	Comfort	23900.00
0005434066608	30586	Comfort	23900.00
0005432525957	30586	Comfort	23900.00
0005435213195	30586	Comfort	23900.00
0005432526439	30586	Comfort	23900.00
0005432428887	30586	Comfort	23900.00
0005432525708	30586	Comfort	23900.00
0005432533247	30586	Comfort	23900.00
0005432526183	30586	Comfort	23900.00
0005434066636	30586	Comfort	23900.00
0005432526446	30586	Comfort	23900.00
0005432526339	30586	Comfort	23900.00
0005434066514	30586	Comfort	23900.00
0005432525803	30586	Comfort	23900.00
0005434066846	30586	Comfort	23900.00
0005432526537	30586	Comfort	23900.00
0005435630952	30586	Comfort	23900.00
0005432428876	30586	Comfort	23900.00
0005432526068	30586	Comfort	23900.00
0005434066681	30586	Comfort	23900.00
0005435213201	30586	Comfort	23900.00
0005435213226	30586	Comfort	23900.00
0005435213192	30586	Comfort	23900.00
0005432525874	30586	Comfort	23900.00
0005433656654	30586	Comfort	23900.00
0005434066650	30586	Comfort	23900.00
0005435213202	30586	Comfort	23900.00
0005434066536	30586	Economy	14000.00
0005435213164	30586	Economy	14000.00
0005432526736	30586	Economy	14000.00
0005432525970	30586	Economy	14000.00
0005432526234	30586	Economy	14000.00
0005434066370	30586	Economy	14000.00
0005434066431	30586	Economy	14000.00
0005435213228	30586	Economy	14000.00
0005432526118	30586	Economy	14000.00
0005434066635	30586	Economy	14000.00
0005435213168	30586	Economy	14000.00
0005432526737	30586	Economy	14000.00
0005432525812	30586	Economy	14000.00
0005434066535	30586	Economy	14000.00
0005432526185	30586	Economy	14000.00
0005432535745	30586	Economy	14000.00
0005435213166	30586	Economy	14000.00
0005432525786	30586	Economy	14000.00
0005435213176	30586	Economy	14000.00
0005435213174	30586	Economy	14000.00
0005432525752	30586	Economy	14000.00
0005432526407	30586	Economy	14000.00
0005435213191	30586	Economy	14000.00
0005432526437	30586	Economy	14000.00
0005432526042	30586	Economy	14000.00
0005435213207	30586	Economy	14000.00
0005434066541	30586	Economy	14000.00
0005432525920	30586	Economy	14000.00
0005434066453	30586	Economy	14000.00
0005432526404	30586	Economy	14000.00
0005434066573	30586	Economy	14000.00
0005434066628	30586	Economy	14000.00
0005432526200	30586	Economy	14000.00
0005435725574	30586	Economy	14000.00
0005435213171	30586	Economy	14000.00
0005435213162	30586	Economy	14000.00
0005432526101	30586	Economy	14000.00
0005432537028	30586	Economy	14000.00
0005432526536	30586	Economy	14000.00
0005432526687	30586	Economy	14000.00
0005432526140	30586	Economy	14000.00
0005435213188	30586	Economy	14000.00
0005432526331	30586	Economy	14000.00
0005435213216	30586	Economy	14000.00
0005435630954	30586	Economy	14000.00
0005432526237	30586	Economy	14000.00
0005432159836	30586	Economy	14000.00
0005432526568	30586	Economy	14000.00
0005432525910	30586	Economy	14000.00
0005432525987	30586	Economy	14000.00
0005434066372	30586	Economy	14000.00
0005435725575	30586	Economy	14000.00
0005432525921	30586	Economy	14000.00
0005432526105	30586	Economy	14000.00
0005432533251	30586	Economy	14000.00
0005434066484	30586	Economy	15400.00
0005432526098	30586	Economy	14000.00
0005434066609	30586	Economy	15400.00
0005434066396	30586	Economy	15400.00
0005432525898	30586	Economy	14000.00
0005432526117	30586	Economy	14000.00
0005434066570	30586	Economy	14000.00
0005432526157	30586	Economy	14000.00
0005432525695	30586	Economy	14000.00
0005432526416	30586	Economy	14000.00
0005432526067	30586	Economy	14000.00
0005435213213	30586	Economy	14000.00
0005432525850	30586	Economy	14000.00
0005432211464	30586	Economy	14000.00
0005432428877	30586	Economy	14000.00
0005434066738	30586	Economy	14000.00
0005432526028	30586	Economy	14000.00
0005432527097	30586	Economy	14000.00
0005435213211	30586	Economy	14000.00
0005435213173	30586	Economy	14000.00
0005435213181	30586	Economy	14000.00
0005434066553	30586	Economy	14000.00
0005432159833	30586	Economy	14000.00
0005432428875	30586	Economy	14000.00
0005435213200	30586	Economy	14000.00
0005432526688	30586	Economy	14000.00
0005434066580	30586	Economy	14000.00
0005434066582	30586	Economy	14000.00
0005432526397	30586	Economy	14000.00
0005432526677	30586	Economy	14000.00
0005435213186	30586	Economy	14000.00
0005432526287	30586	Economy	14000.00
0005432525787	30586	Economy	14000.00
0005432428867	30586	Economy	14000.00
0005432525668	30586	Economy	14000.00
0005432526302	30586	Economy	14000.00
0005434066332	30586	Economy	14000.00
0005432159835	30586	Economy	14000.00
0005435213199	30586	Economy	14000.00
0005432526604	30586	Economy	14000.00
0005435213215	30586	Economy	14000.00
0005432526226	30586	Economy	14000.00
0005432526139	30586	Economy	14000.00
0005435213190	30586	Economy	14000.00
0005432525897	30586	Economy	14000.00
0005432211460	30586	Economy	14000.00
0005435213224	30586	Economy	14000.00
0005432525912	30586	Economy	14000.00
0005432526233	30586	Economy	14000.00
0005432526303	30586	Economy	14000.00
0005432526255	30586	Economy	14000.00
0005432526352	30586	Economy	14000.00
0005435725577	30586	Economy	14000.00
0005432428878	30586	Economy	14000.00
0005432526296	30586	Economy	14000.00
0005435213218	30586	Economy	14000.00
0005432527071	30586	Economy	14000.00
0005432526094	30586	Economy	14000.00
0005434066471	30586	Economy	14000.00
0005434066416	30586	Economy	14000.00
0005434066452	30586	Economy	14000.00
0005432526426	30586	Economy	14000.00
0005432525802	30586	Economy	14000.00
0005432533249	30586	Economy	14000.00
0005434066404	30586	Economy	14000.00
0005432533255	30586	Economy	14000.00
0005432525881	30586	Economy	14000.00
0005432526167	30586	Economy	14000.00
0005435213210	30586	Economy	14000.00
0005435213219	30586	Economy	14000.00
0005435213175	30586	Economy	14000.00
0005432526529	30586	Economy	14000.00
0005435725576	30586	Economy	14000.00
0005432525785	30586	Economy	14000.00
0005435630950	30586	Economy	14000.00
0005434066550	30586	Economy	14000.00
0005434066403	30586	Economy	14000.00
0005432526312	30586	Economy	14000.00
0005432526396	30586	Economy	14000.00
0005435213229	30586	Economy	14000.00
0005433656653	30586	Economy	14000.00
0005432526203	30586	Economy	14000.00
0005432526186	30586	Economy	14000.00
0005435213169	30586	Economy	14000.00
0005434066373	30586	Economy	14000.00
0005432525958	30586	Economy	14000.00
0005435213206	30586	Economy	14000.00
0005435213167	30586	Economy	14000.00
0005435213165	30586	Economy	14000.00
0005432211461	30586	Economy	14000.00
0005435213161	30586	Economy	14000.00
0005432535769	30586	Economy	14000.00
0005432211465	30586	Economy	14000.00
0005432526372	30586	Economy	14000.00
0005434066333	30586	Economy	14000.00
0005432525833	30586	Economy	14000.00
0005434066334	30586	Economy	14000.00
0005435213222	30586	Economy	14000.00
0005434066354	30586	Economy	15400.00
0005435213223	30586	Economy	15400.00
0005432525981	30586	Economy	15400.00
0005432526066	30586	Economy	15400.00
0005432526125	30586	Economy	15400.00
0005435213172	30586	Economy	14000.00
0005432526438	30586	Economy	14000.00
0005435213220	30586	Economy	14000.00
0005432525847	30586	Economy	14000.00
0005432526099	30586	Economy	14000.00
0005434066574	30586	Economy	14000.00
0005434066559	30586	Economy	14000.00
0005434066556	30586	Economy	14000.00
0005434066632	30586	Economy	14000.00
0005432525804	30586	Economy	14000.00
0005432526156	30586	Economy	14000.00
0005432526503	30586	Economy	14000.00
0005435630953	30586	Economy	14000.00
0005434066651	30586	Economy	14000.00
0005435213221	30586	Economy	14000.00
0005432525797	30586	Economy	14000.00
0005432526112	30586	Economy	14000.00
0005432525911	30586	Economy	14000.00
0005434066347	30586	Economy	14000.00
0005432526263	30586	Economy	14000.00
0005435213179	30586	Economy	14000.00
0005432526027	30586	Economy	14000.00
0005432535768	30586	Economy	14000.00
0005432211458	30586	Economy	14000.00
0005434066557	30586	Economy	14000.00
0005432526304	30586	Economy	14000.00
0005434066680	30586	Economy	14000.00
0005432159834	30586	Economy	14000.00
0005434066584	30586	Economy	14000.00
0005432526286	30586	Economy	14000.00
0005432526225	30586	Economy	14000.00
0005432211463	30586	Economy	14000.00
0005432526415	30586	Economy	14000.00
0005432526220	30586	Economy	14000.00
0005435213184	30586	Economy	14000.00
0005432211462	30586	Economy	14000.00
0005432533248	30586	Economy	14000.00
0005434066446	30586	Economy	14000.00
0005435630951	30586	Economy	14000.00
0005435213187	30586	Economy	14000.00
0005434066814	30586	Economy	14000.00
0005432526244	30586	Economy	14000.00
0005435213203	30586	Economy	14000.00
0005432526087	30586	Economy	14000.00
0005432211466	30586	Economy	14000.00
0005435213217	30586	Economy	14000.00
0005432159832	30586	Economy	14000.00
0005435213178	30586	Economy	14000.00
0005435213209	30586	Economy	14000.00
0005432526055	30586	Economy	14000.00
0005435213214	30586	Economy	14000.00
0005432526827	30586	Economy	14000.00
0005434066518	30586	Economy	14000.00
0005434066335	30586	Economy	14000.00
0005434066581	30586	Economy	14000.00
0005432526035	30586	Economy	14000.00
0005432526254	30586	Economy	14000.00
0005435213177	30586	Economy	14000.00
0005433656655	30586	Economy	14000.00
0005432526447	30586	Economy	14000.00
0005432526077	30586	Economy	14000.00
0005435213205	30586	Economy	14000.00
0005432526367	30586	Economy	14000.00
0005435213193	30586	Economy	14000.00
0005435213189	30586	Economy	14000.00
0005435213198	30586	Economy	14000.00
0005432526544	30586	Economy	14000.00
0005432159831	30586	Economy	14000.00
0005432428886	30586	Economy	14000.00
0005435213183	30586	Economy	14000.00
0005432526545	30586	Economy	14000.00
0005432526603	30586	Economy	14000.00
0005435213180	30586	Economy	14000.00
0005434066371	30586	Economy	14000.00
0005432525846	30586	Economy	14000.00
0005435213194	30586	Economy	14000.00
0005435213212	30586	Economy	14000.00
0005434066627	30586	Economy	14000.00
0005435213225	30586	Economy	14000.00
0005434066682	30586	Economy	14000.00
0005432537029	30586	Economy	14000.00
0005432428885	30586	Economy	14000.00
0005434066549	30586	Economy	14000.00
0005435213182	30586	Economy	14000.00
0005434066847	30586	Economy	14000.00
0005434066569	30586	Economy	14000.00
0005435725573	30586	Economy	14000.00
0005432525882	30586	Economy	14000.00
0005434066600	30586	Economy	14000.00
0005432526262	30586	Economy	14000.00
0005432526088	30586	Economy	14000.00
0005432525971	30586	Economy	14000.00
0005432526460	30586	Economy	14000.00
0005432526702	30586	Economy	14000.00
0005434066519	30586	Economy	14000.00
0005433367712	24857	Business	9800.00
0005435652393	24857	Business	9800.00
0005433367714	24857	Business	9800.00
0005435652257	24857	Business	9800.00
0005433367680	24857	Business	9800.00
0005435652420	24857	Business	9800.00
0005435652264	24857	Business	9800.00
0005433367693	24857	Business	9800.00
0005435652413	24857	Business	9800.00
0005435652387	24857	Business	9800.00
0005433367690	24857	Business	9800.00
0005435652427	24857	Economy	3300.00
0005435652317	24857	Economy	3300.00
0005435652342	24857	Economy	3300.00
0005433367703	24857	Economy	3300.00
0005435652278	24857	Economy	3300.00
0005435652418	24857	Economy	3300.00
0005435652383	24857	Economy	3600.00
0005435652326	24857	Economy	3600.00
0005435652316	24857	Economy	3600.00
0005435652259	24857	Economy	3600.00
0005433367682	24857	Economy	3300.00
0005433367681	24857	Economy	3300.00
0005433367706	24857	Economy	3300.00
0005435652319	24857	Economy	3300.00
0005433367709	24857	Economy	3300.00
0005433367716	24857	Economy	3300.00
0005435652409	24857	Economy	3300.00
0005433367711	24857	Economy	3300.00
0005435652388	24857	Economy	3300.00
0005435652364	24857	Economy	3300.00
0005433367695	24857	Economy	3300.00
0005433367692	24857	Economy	3300.00
0005435652392	24857	Economy	3300.00
0005433367715	24857	Economy	3300.00
0005435652371	24857	Economy	3300.00
0005433367694	24857	Economy	3300.00
0005435652394	24857	Economy	3300.00
0005435652368	24857	Economy	3300.00
0005433367679	24857	Economy	3300.00
0005435652382	24857	Economy	3300.00
0005433367683	24857	Economy	3300.00
0005433367708	24857	Economy	3300.00
0005433367710	24857	Economy	3300.00
0005433367696	24857	Economy	3300.00
0005433367705	24857	Economy	3300.00
0005435652321	24857	Economy	3300.00
0005433367702	24857	Economy	3300.00
0005433367699	24857	Economy	3300.00
0005435652363	24857	Economy	3300.00
0005433367698	24857	Economy	3300.00
0005435652361	24857	Economy	3300.00
0005435652260	24857	Economy	3300.00
0005435652318	24857	Economy	3300.00
0005433367704	24857	Economy	3300.00
0005435652304	24857	Economy	3300.00
0005433367691	24857	Economy	3300.00
0005433367685	24857	Economy	3300.00
0005433367684	24857	Economy	3300.00
0005435652362	24857	Economy	3300.00
0005433367687	24857	Economy	3300.00
0005433367688	24857	Economy	3300.00
0005435652446	24857	Economy	3300.00
0005433367686	24857	Economy	3300.00
0005433367689	24857	Economy	3300.00
0005435652255	24857	Economy	3300.00
0005435652410	24857	Economy	3300.00
0005433367713	24857	Economy	3300.00
0005435652433	24857	Economy	3300.00
0005433367707	24857	Economy	3300.00
0005433367701	24857	Economy	3300.00
0005433367697	24857	Economy	3300.00
0005435652419	24857	Economy	3300.00
0005433367700	24857	Economy	3300.00
0005435652341	24857	Economy	3300.00
0005435652349	24857	Economy	3300.00
0005435652441	24857	Economy	3300.00
0005435801680	2035	Economy	10500.00
0005434979648	2035	Economy	10500.00
0005434979637	2035	Economy	9500.00
0005434979629	2035	Economy	9500.00
0005434979647	2035	Economy	9500.00
0005434979635	2035	Economy	9500.00
0005434979626	2035	Economy	9500.00
0005434979632	2035	Economy	9500.00
0005434979645	2035	Economy	9500.00
0005434979625	2035	Economy	9500.00
0005434979633	2035	Economy	9500.00
0005434979643	2035	Economy	9500.00
0005434979641	2035	Economy	9500.00
0005435801681	2035	Economy	9500.00
0005434979642	2035	Economy	9500.00
0005434979651	2035	Economy	9500.00
0005434979644	2035	Economy	9500.00
0005434979638	2035	Economy	9500.00
0005434979628	2035	Economy	9500.00
0005434979622	2035	Economy	9500.00
0005434979639	2035	Economy	9500.00
0005434979631	2035	Economy	9500.00
0005434979630	2035	Economy	9500.00
0005434979624	2035	Economy	9500.00
0005434979623	2035	Economy	9500.00
0005434979627	2035	Economy	9500.00
0005434979646	2035	Economy	9500.00
0005434979649	2035	Economy	9500.00
0005434979636	2035	Economy	9500.00
0005434979650	2035	Economy	9500.00
0005434979634	2035	Economy	9500.00
0005434979640	2035	Economy	9500.00
0005434979335	23558	Economy	10500.00
0005434979399	23558	Economy	10500.00
0005434979334	23558	Economy	10500.00
0005434979369	23558	Economy	9500.00
0005435801660	23558	Economy	9500.00
0005434979407	23558	Economy	9500.00
0005434979323	23558	Economy	9500.00
0005434979360	23558	Economy	9500.00
0005434979430	23558	Economy	9500.00
0005434979336	23558	Economy	9500.00
0005434979390	23558	Economy	9500.00
0005434979370	23558	Economy	9500.00
0005435801651	23558	Economy	9500.00
0005434979257	23558	Economy	9500.00
0005434979345	23558	Economy	9500.00
0005434979398	23558	Economy	9500.00
0005434979465	23558	Economy	9500.00
0005434979264	23558	Economy	9500.00
0005434979318	23558	Economy	9500.00
0005434979263	23558	Economy	9500.00
0005434979351	23558	Economy	9500.00
0005434979319	23558	Economy	9500.00
0005434979256	23558	Economy	9500.00
0005434979352	23558	Economy	9500.00
0005434979314	23558	Economy	9500.00
0005434979359	23558	Economy	9500.00
0005434952512	2590	Economy	5300.00
0005434952510	2590	Economy	5300.00
0005434952513	2590	Economy	5300.00
0005434952511	2590	Economy	5300.00
0005433256391	2589	Economy	5300.00
0005433256396	2589	Economy	5300.00
0005433256398	2589	Economy	5300.00
0005433256397	2589	Economy	5300.00
0005433256410	28228	Economy	5300.00
0005434952473	28228	Economy	5300.00
0005433112365	19787	Economy	8700.00
0005433112366	19787	Economy	8700.00
0005434136858	11951	Business	9700.00
0005434137029	11951	Business	9700.00
0005434136759	11951	Business	9700.00
0005434137180	11951	Business	9700.00
0005434136939	11951	Business	9700.00
0005434136991	11951	Business	9700.00
0005434136774	11951	Business	9700.00
0005434137173	11951	Business	9700.00
0005434136685	11951	Economy	3200.00
0005434137160	11951	Economy	3200.00
0005434137161	11951	Economy	3200.00
0005434136990	11951	Economy	3200.00
0005434137019	11951	Economy	3200.00
0005434136784	11951	Economy	3200.00
0005434136986	11951	Economy	3200.00
0005434136833	11951	Economy	3200.00
0005434136695	11951	Economy	3500.00
0005434136927	11951	Economy	3500.00
0005434136923	11951	Economy	3500.00
0005434137084	11951	Economy	3200.00
0005434137145	11951	Economy	3200.00
0005434137047	11951	Economy	3200.00
0005434137136	11951	Economy	3200.00
0005434137308	11951	Economy	3200.00
0005434136697	11951	Economy	3200.00
0005434136892	11951	Economy	3200.00
0005434137201	11951	Economy	3200.00
0005434136782	11951	Economy	3200.00
0005434137211	11951	Economy	3200.00
0005434136971	11951	Economy	3200.00
0005434136790	11951	Economy	3200.00
0005434136795	11951	Economy	3200.00
0005434137020	11951	Economy	3200.00
0005434136705	11951	Economy	3200.00
0005434137252	11951	Economy	3200.00
0005434136775	11951	Economy	3200.00
0005434137125	11951	Economy	3200.00
0005434137207	11951	Economy	3200.00
0005434137174	11951	Economy	3200.00
0005434136901	11951	Economy	3200.00
0005434137171	11951	Economy	3200.00
0005434136794	11951	Economy	3200.00
0005434136996	11951	Economy	3200.00
0005434136951	11951	Economy	3200.00
0005434137251	11951	Economy	3200.00
0005434136789	11951	Economy	3200.00
0005434137085	11951	Economy	3200.00
0005434136953	11951	Economy	3200.00
0005434137083	11951	Economy	3200.00
0005434136985	11951	Economy	3200.00
0005434136696	11951	Economy	3200.00
0005434136694	11951	Economy	3200.00
0005434136820	11951	Economy	3200.00
0005434137172	11951	Economy	3200.00
0005434137055	11951	Economy	3200.00
0005434136972	11951	Economy	3200.00
0005434137236	11951	Economy	3200.00
0005434136952	11951	Economy	3200.00
0005434137126	11951	Economy	3200.00
0005434136954	11951	Economy	3200.00
0005434137163	11951	Economy	3200.00
0005434136989	11951	Economy	3200.00
0005434137137	11951	Economy	3200.00
0005434137162	11951	Economy	3200.00
0005434136847	11951	Economy	3200.00
0005434136926	11951	Economy	3200.00
0005434136987	11951	Economy	3200.00
0005434137175	11951	Economy	3200.00
0005434137092	11951	Economy	3200.00
0005434137102	11951	Economy	3200.00
0005434137292	11951	Economy	3200.00
0005434137022	11951	Economy	3200.00
0005434137190	11951	Economy	3200.00
0005434137293	11951	Economy	3200.00
0005434136824	11951	Economy	3200.00
0005434136706	11951	Economy	3200.00
0005434136997	11951	Economy	3200.00
0005434137200	11951	Economy	3200.00
0005434137644	28711	Business	9700.00
0005434137707	28711	Business	9700.00
0005434137703	28711	Business	9700.00
0005434137666	28711	Business	9700.00
0005434137697	28711	Business	9700.00
0005434137702	28711	Business	9700.00
0005434137679	28711	Business	9700.00
0005434137658	28711	Business	9700.00
0005434137637	28711	Business	9700.00
0005434137667	28711	Business	9700.00
0005434137690	28711	Economy	3200.00
0005434137625	28711	Economy	3200.00
0005434137698	28711	Economy	3200.00
0005434137705	28711	Economy	3200.00
0005434137675	28711	Economy	3200.00
0005434137632	28711	Economy	3200.00
0005434137687	28711	Economy	3200.00
0005434137642	28711	Economy	3200.00
0005434137680	28711	Economy	3500.00
0005434137659	28711	Economy	3500.00
0005434137665	28711	Economy	3500.00
0005434137694	28711	Economy	3500.00
0005434137695	28711	Economy	3200.00
0005434137700	28711	Economy	3200.00
0005434137669	28711	Economy	3200.00
0005434137630	28711	Economy	3200.00
0005434137636	28711	Economy	3200.00
0005434137635	28711	Economy	3200.00
0005434137691	28711	Economy	3200.00
0005434137677	28711	Economy	3200.00
0005434137668	28711	Economy	3200.00
0005434137682	28711	Economy	3200.00
0005434137693	28711	Economy	3200.00
0005434137699	28711	Economy	3200.00
0005434137643	28711	Economy	3200.00
0005434137640	28711	Economy	3200.00
0005434137661	28711	Economy	3200.00
0005434137686	28711	Economy	3200.00
0005434137651	28711	Economy	3200.00
0005434137657	28711	Economy	3200.00
0005434137664	28711	Economy	3200.00
0005434137624	28711	Economy	3200.00
0005434137648	28711	Economy	3200.00
0005434137653	28711	Economy	3200.00
0005434137652	28711	Economy	3200.00
0005434137670	28711	Economy	3200.00
0005434137684	28711	Economy	3200.00
0005434137650	28711	Economy	3200.00
0005434137639	28711	Economy	3200.00
0005434137673	28711	Economy	3200.00
0005434137647	28711	Economy	3200.00
0005434137627	28711	Economy	3200.00
0005434137681	28711	Economy	3200.00
0005434137676	28711	Economy	3200.00
0005434137646	28711	Economy	3200.00
0005434137689	28711	Economy	3200.00
0005434137629	28711	Economy	3200.00
0005434137671	28711	Economy	3200.00
0005434137655	28711	Economy	3200.00
0005434137701	28711	Economy	3200.00
0005434137688	28711	Economy	3200.00
0005434137683	28711	Economy	3200.00
0005434137656	28711	Economy	3200.00
0005434137649	28711	Economy	3200.00
0005434137662	28711	Economy	3200.00
0005434137706	28711	Economy	3200.00
0005434137641	28711	Economy	3200.00
0005434137663	28711	Economy	3200.00
0005434137660	28711	Economy	3200.00
0005434137704	28711	Economy	3200.00
0005434137678	28711	Economy	3200.00
0005434137645	28711	Economy	3200.00
0005434137685	28711	Economy	3200.00
0005434137634	28711	Economy	3200.00
0005434137633	28711	Economy	3200.00
0005434137674	28711	Economy	3200.00
0005434137654	28711	Economy	3200.00
0005434137626	28711	Economy	3200.00
0005434137672	28711	Economy	3200.00
0005434137692	28711	Economy	3200.00
0005434137638	28711	Economy	3200.00
0005434137631	28711	Economy	3200.00
0005434137628	28711	Economy	3200.00
0005434137696	28711	Economy	3200.00
0005435259706	6818	Economy	10900.00
0005433538825	6818	Economy	10900.00
0005433538828	6818	Economy	10900.00
0005433538826	6818	Economy	9900.00
0005433534486	6818	Economy	9900.00
0005433538829	6818	Economy	9900.00
0005433534488	6818	Economy	9900.00
0005433538831	6818	Economy	9900.00
0005435259694	6818	Economy	9900.00
0005433538823	6818	Economy	9900.00
0005433538824	6818	Economy	9900.00
0005435259707	6818	Economy	9900.00
0005433538827	6818	Economy	9900.00
0005433534487	6818	Economy	9900.00
0005435259708	6818	Economy	9900.00
0005433538830	6818	Economy	9900.00
0005433538782	25033	Economy	9900.00
0005435259733	25033	Economy	9900.00
0005435259732	25033	Economy	9900.00
0005435259736	25033	Economy	9900.00
0005435259734	25033	Economy	9900.00
0005435259735	25033	Economy	9900.00
0005433538722	25033	Economy	9900.00
0005433538723	25033	Economy	9900.00
0005433511905	841	Economy	16100.00
0005433511913	841	Economy	14600.00
0005432922493	841	Economy	14600.00
0005433511904	841	Economy	14600.00
0005433511908	841	Economy	14600.00
0005432922460	841	Economy	14600.00
0005433511912	841	Economy	14600.00
0005433511907	841	Economy	14600.00
0005433511911	841	Economy	14600.00
0005433511910	841	Economy	14600.00
0005433511909	841	Economy	14600.00
0005433511906	841	Economy	14600.00
0005433511815	16164	Economy	16100.00
0005433511832	16164	Economy	14600.00
0005432922502	16164	Economy	14600.00
0005433511816	16164	Economy	14600.00
0005433511861	16164	Economy	14600.00
0005432922504	16164	Economy	14600.00
0005432922503	16164	Economy	14600.00
0005433511827	16164	Economy	14600.00
0005433511833	16164	Economy	14600.00
0005432922505	16164	Economy	14600.00
0005433475677	4031	Economy	13500.00
0005433475675	4031	Economy	12300.00
0005433475679	4031	Economy	12300.00
0005433475681	4031	Economy	12300.00
0005433475686	4031	Economy	12300.00
0005433475688	4031	Economy	12300.00
0005435852542	4031	Economy	12300.00
0005433475676	4031	Economy	12300.00
0005433475678	4031	Economy	12300.00
0005435852527	4031	Economy	12300.00
0005433475682	4031	Economy	12300.00
0005435852531	4031	Economy	12300.00
0005433475674	4031	Economy	12300.00
0005435852543	4031	Economy	12300.00
0005433475687	4031	Economy	12300.00
0005433475680	4031	Economy	12300.00
0005433475685	4031	Economy	12300.00
0005435852529	4031	Economy	12300.00
0005433475683	4031	Economy	12300.00
0005433475684	4031	Economy	12300.00
0005435697216	3668	Economy	7900.00
0005435697194	3668	Economy	7900.00
0005435697208	3668	Economy	7900.00
0005435697200	3668	Economy	7200.00
0005435697201	3668	Economy	7200.00
0005435697198	3668	Economy	7200.00
0005435697206	3668	Economy	7200.00
0005435697189	3668	Economy	7200.00
0005435697214	3668	Economy	7200.00
0005435697215	3668	Economy	7200.00
0005435697188	3668	Economy	7200.00
0005435697204	3668	Economy	7200.00
0005435697199	3668	Economy	7200.00
0005435916129	3668	Economy	7200.00
0005435697203	3668	Economy	7200.00
0005435697207	3668	Economy	7200.00
0005435916138	3668	Economy	7200.00
0005435697197	3668	Economy	7200.00
0005435697205	3668	Economy	7200.00
0005434950508	3668	Economy	7200.00
0005435916146	3668	Economy	7200.00
0005435697191	3668	Economy	7200.00
0005434950506	3668	Economy	7200.00
0005434950505	3668	Economy	7200.00
0005435697209	3668	Economy	7200.00
0005435935006	3668	Economy	7200.00
0005435697213	3668	Economy	7200.00
0005435697210	3668	Economy	7200.00
0005435697196	3668	Economy	7200.00
0005435697192	3668	Economy	7200.00
0005435697193	3668	Economy	7200.00
0005434950507	3668	Economy	7200.00
0005435697190	3668	Economy	7200.00
0005435697212	3668	Economy	7200.00
0005435697211	3668	Economy	7200.00
0005435916126	3668	Economy	7200.00
0005435916125	3668	Economy	7200.00
0005435697195	3668	Economy	7200.00
0005435697202	3668	Economy	7200.00
0005434950490	16269	Economy	7900.00
0005435696926	16269	Economy	7900.00
0005435696932	16269	Economy	7900.00
0005435696985	16269	Economy	7900.00
0005435697060	16269	Economy	7200.00
0005435696861	16269	Economy	7200.00
0005435696893	16269	Economy	7200.00
0005435935025	16269	Economy	7200.00
0005435696952	16269	Economy	7200.00
0005435916152	16269	Economy	7200.00
0005435696970	16269	Economy	7200.00
0005434950465	16269	Economy	7200.00
0005435697023	16269	Economy	7200.00
0005435935024	16269	Economy	7200.00
0005435916154	16269	Economy	7200.00
0005435696860	16269	Economy	7200.00
0005435696947	16269	Economy	7200.00
0005435696850	16269	Economy	7200.00
0005435696884	16269	Economy	7200.00
0005435696968	16269	Economy	7200.00
0005435696969	16269	Economy	7200.00
0005435696925	16269	Economy	7200.00
0005434950478	16269	Economy	7200.00
0005435696928	16269	Economy	7200.00
0005435696933	16269	Economy	7200.00
0005435696885	16269	Economy	7200.00
0005435696984	16269	Economy	7200.00
0005434950479	16269	Economy	7200.00
0005435916153	16269	Economy	7200.00
0005435696967	16269	Economy	7200.00
0005435696927	16269	Economy	7200.00
0005435696966	16269	Economy	7200.00
0005435935026	16269	Economy	7200.00
0005435696957	16269	Economy	7200.00
0005435697033	16269	Economy	7200.00
0005435696987	16269	Economy	7200.00
0005435697019	16269	Economy	7200.00
0005435935027	16269	Economy	7200.00
0005434950477	16269	Economy	7200.00
0005432609713	3954	Economy	21300.00
0005434604880	3954	Economy	19300.00
0005432609710	3954	Economy	19300.00
0005432609709	3954	Economy	19300.00
0005432607547	3954	Economy	19300.00
0005432607545	3954	Economy	19300.00
0005435904890	3954	Economy	19300.00
0005434606814	3954	Economy	19300.00
0005433519434	3954	Economy	19300.00
0005432607544	3954	Economy	19300.00
0005433519433	3954	Economy	19300.00
0005433519436	3954	Economy	19300.00
0005435853590	3954	Economy	19300.00
0005434604881	3954	Economy	19300.00
0005435853586	3954	Economy	19300.00
0005434606812	3954	Economy	19300.00
0005432609712	3954	Economy	19300.00
0005433519435	3954	Economy	19300.00
0005435842319	3954	Economy	19300.00
0005432607546	3954	Economy	19300.00
0005432609711	3954	Economy	19300.00
0005435853585	3954	Economy	19300.00
0005434606813	3954	Economy	19300.00
0005433519390	22054	Economy	21300.00
0005433519396	22054	Economy	19300.00
0005434606773	22054	Economy	19300.00
0005433519389	22054	Economy	19300.00
0005435853603	22054	Economy	19300.00
0005433519392	22054	Economy	19300.00
0005434606771	22054	Economy	19300.00
0005434606770	22054	Economy	19300.00
0005433519393	22054	Economy	19300.00
0005435853602	22054	Economy	19300.00
0005435853604	22054	Economy	19300.00
0005433348930	674	Economy	3700.00
0005433348903	674	Economy	3700.00
0005433348898	674	Economy	3700.00
0005433348918	674	Economy	3700.00
0005433348963	15974	Economy	3700.00
0005435628681	15974	Economy	3700.00
0005433348962	15974	Economy	3700.00
0005433348961	15974	Economy	3700.00
0005435628676	15974	Economy	3700.00
0005433348960	15974	Economy	3700.00
0005433348959	15974	Economy	3700.00
0005433348958	15974	Economy	3700.00
0005435628679	15974	Economy	3700.00
0005435628682	15974	Economy	3700.00
0005434445233	17245	Economy	7100.00
0005434446504	17245	Economy	7100.00
0005434445235	17245	Economy	7100.00
0005434446506	17245	Economy	7100.00
0005433158094	17245	Economy	7100.00
0005433158093	17245	Economy	7100.00
0005434445234	17245	Economy	7100.00
0005434446505	17245	Economy	7100.00
0005434446507	17245	Economy	7100.00
0005433159302	17642	Economy	7100.00
0005433159301	17642	Economy	7100.00
0005433159303	17642	Economy	7100.00
0005434445216	17642	Economy	7100.00
0005435132833	7903	Economy	5900.00
0005435132827	7903	Economy	5900.00
0005435132829	7903	Economy	5900.00
0005435132825	7903	Economy	5400.00
0005435132831	7903	Economy	5400.00
0005435383072	7903	Economy	5400.00
0005435132832	7903	Economy	5400.00
0005435132828	7903	Economy	5400.00
0005435132830	7903	Economy	5400.00
0005435132834	7903	Economy	5400.00
0005435132826	7903	Economy	5400.00
0005435383125	33118	Economy	5900.00
0005435383121	33118	Economy	5400.00
0005435132735	33118	Economy	5400.00
0005435132736	33118	Economy	5400.00
0005435132751	33118	Economy	5400.00
0005435132776	33118	Economy	5400.00
0005435383123	33118	Economy	5400.00
0005435383124	33118	Economy	5400.00
0005435132737	33118	Economy	5400.00
0005435132775	33118	Economy	5400.00
0005435383122	33118	Economy	5400.00
0005435132752	33118	Economy	5400.00
0005435132765	33118	Economy	5400.00
0005435132764	33118	Economy	5400.00
0005435132729	33118	Economy	5400.00
0005435132734	33118	Economy	5400.00
0005435160246	7482	Economy	13800.00
0005435390139	7482	Economy	13800.00
0005435390147	7482	Economy	12500.00
0005435390154	7482	Economy	12500.00
0005435160251	7482	Economy	12500.00
0005435390141	7482	Economy	12500.00
0005435390140	7482	Economy	12500.00
0005435390150	7482	Economy	12500.00
0005435390146	7482	Economy	12500.00
0005435160248	7482	Economy	12500.00
0005435160247	7482	Economy	12500.00
0005435160244	7482	Economy	12500.00
0005435160243	7482	Economy	12500.00
0005435390149	7482	Economy	12500.00
0005435160240	7482	Economy	12500.00
0005435390153	7482	Economy	12500.00
0005435160250	7482	Economy	12500.00
0005435160241	7482	Economy	12500.00
0005435160249	7482	Economy	12500.00
0005435160245	7482	Economy	12500.00
0005435160242	7482	Economy	12500.00
0005435390203	29532	Economy	13800.00
0005435390205	29532	Economy	13800.00
0005435160172	29532	Economy	12500.00
0005435160159	29532	Economy	12500.00
0005435160144	29532	Economy	12500.00
0005435390202	29532	Economy	12500.00
0005435160190	29532	Economy	12500.00
0005435390206	29532	Economy	12500.00
0005435160158	29532	Economy	12500.00
0005435160160	29532	Economy	12500.00
0005435160188	29532	Economy	12500.00
0005435160189	29532	Economy	12500.00
0005435160145	29532	Economy	12500.00
0005435160192	29532	Economy	12500.00
0005435160143	29532	Economy	12500.00
0005435390204	29532	Economy	12500.00
0005435160142	29532	Economy	12500.00
0005435390207	29532	Economy	12500.00
0005435160146	29532	Economy	12500.00
0005435160156	29532	Economy	12500.00
0005435390208	29532	Economy	12500.00
0005435178490	18438	Economy	4900.00
0005432394059	18438	Economy	4900.00
0005432398136	18438	Economy	4900.00
0005432398139	18438	Economy	4900.00
0005435178990	18438	Economy	4900.00
0005432398146	18438	Economy	4900.00
0005432398140	18438	Economy	4900.00
0005432394047	18438	Economy	4900.00
0005432398151	18438	Economy	4900.00
0005432398141	18438	Economy	4900.00
0005435178489	18438	Economy	4900.00
0005435179389	27166	Economy	4900.00
0005432400098	27166	Economy	4900.00
0005432398175	27166	Economy	4900.00
0005432398174	27166	Economy	4900.00
0005432398173	27166	Economy	4900.00
0005432400100	27166	Economy	4900.00
0005432400099	27166	Economy	4900.00
0005434191261	9708	Economy	4400.00
0005434191260	9708	Economy	4400.00
0005435103892	6532	Business	48400.00
0005435103900	6532	Business	48400.00
0005435103896	6532	Business	48400.00
0005435103894	6532	Business	48400.00
0005434503940	6532	Business	48400.00
0005434503978	6532	Business	48400.00
0005434503959	6532	Business	48400.00
0005434503963	6532	Business	48400.00
0005434503979	6532	Business	48400.00
0005434503957	6532	Economy	16100.00
0005434503980	6532	Economy	16100.00
0005434503976	6532	Economy	16100.00
0005434503941	6532	Economy	16100.00
0005435103893	6532	Economy	16100.00
0005434503975	6532	Economy	17800.00
0005435103891	6532	Economy	17800.00
0005435103889	6532	Economy	17800.00
0005434503965	6532	Economy	17800.00
0005434503972	6532	Economy	16100.00
0005434503961	6532	Economy	16100.00
0005434503966	6532	Economy	16100.00
0005434503974	6532	Economy	16100.00
0005434503981	6532	Economy	16100.00
0005434503942	6532	Economy	16100.00
0005434503954	6532	Economy	16100.00
0005434503971	6532	Economy	16100.00
0005435103888	6532	Economy	16100.00
0005434503956	6532	Economy	16100.00
0005435103897	6532	Economy	16100.00
0005434503950	6532	Economy	16100.00
0005434503967	6532	Economy	16100.00
0005434503948	6532	Economy	16100.00
0005434503946	6532	Economy	16100.00
0005434503947	6532	Economy	16100.00
0005435103886	6532	Economy	16100.00
0005435103901	6532	Economy	16100.00
0005434503977	6532	Economy	16100.00
0005434503945	6532	Economy	16100.00
0005434503962	6532	Economy	16100.00
0005435103898	6532	Economy	16100.00
0005435103890	6532	Economy	16100.00
0005434503960	6532	Economy	16100.00
0005434503964	6532	Economy	16100.00
0005434503952	6532	Economy	16100.00
0005435103887	6532	Economy	16100.00
0005434503949	6532	Economy	16100.00
0005434503968	6532	Economy	16100.00
0005434503973	6532	Economy	16100.00
0005435103895	6532	Economy	16100.00
0005434503943	6532	Economy	16100.00
0005434503951	6532	Economy	16100.00
0005435103899	6532	Economy	16100.00
0005434503944	6532	Economy	16100.00
0005434503955	6532	Economy	16100.00
0005434503970	6532	Economy	16100.00
0005434503953	6532	Economy	16100.00
0005434503969	6532	Economy	16100.00
0005434503958	6532	Economy	16100.00
0005434503538	22689	Business	48400.00
0005434503476	22689	Business	48400.00
0005434503640	22689	Business	48400.00
0005434503503	22689	Economy	16100.00
0005435103811	22689	Economy	16100.00
0005434503611	22689	Economy	16100.00
0005434503550	22689	Economy	17800.00
0005434503566	22689	Economy	16100.00
0005434503583	22689	Economy	16100.00
0005434503458	22689	Economy	16100.00
0005434503521	22689	Economy	16100.00
0005435103806	22689	Economy	16100.00
0005435103816	22689	Economy	16100.00
0005434503485	22689	Economy	16100.00
0005434503549	22689	Economy	16100.00
0005434503502	22689	Economy	16100.00
0005434503536	22689	Economy	16100.00
0005434503659	22689	Economy	16100.00
0005434503608	22689	Economy	16100.00
0005434503615	22689	Economy	16100.00
0005435103817	22689	Economy	16100.00
0005434503514	22689	Economy	16100.00
0005434503576	22689	Economy	16100.00
0005434503610	22689	Economy	16100.00
0005434503535	22689	Economy	16100.00
0005435103803	22689	Economy	16100.00
0005434503643	22689	Economy	16100.00
0005434503592	22689	Economy	16100.00
0005434503565	22689	Economy	16100.00
0005434503513	22689	Economy	16100.00
0005434503534	22689	Economy	16100.00
0005434503548	22689	Economy	16100.00
0005434503520	22689	Economy	16100.00
0005435103810	22689	Economy	16100.00
0005435652870	1661	Business	50000.00
0005435652875	1661	Business	50000.00
0005433367348	1661	Business	50000.00
0005433367338	1661	Business	50000.00
0005435652843	1661	Business	50000.00
0005435652858	1661	Business	50000.00
0005435652868	1661	Business	50000.00
0005435652857	1661	Business	50000.00
0005433367228	1661	Business	50000.00
0005435652856	1661	Economy	16700.00
0005435652865	1661	Economy	16700.00
0005433367428	1661	Economy	16700.00
0005433367329	1661	Economy	16700.00
0005435652853	1661	Economy	16700.00
0005433367396	1661	Economy	16700.00
0005433367340	1661	Economy	16700.00
0005435652872	1661	Economy	16700.00
0005435652862	1661	Economy	16700.00
0005433367358	1661	Economy	18300.00
0005433367468	1661	Economy	18300.00
0005435652855	1661	Economy	18300.00
0005435652860	1661	Economy	16700.00
0005435652840	1661	Economy	16700.00
0005435652844	1661	Economy	16700.00
0005433367483	1661	Economy	16700.00
0005435652842	1661	Economy	16700.00
0005433367270	1661	Economy	16700.00
0005433367446	1661	Economy	16700.00
0005435652859	1661	Economy	16700.00
0005433367403	1661	Economy	16700.00
0005433367237	1661	Economy	16700.00
0005433367349	1661	Economy	16700.00
0005435652871	1661	Economy	16700.00
0005435652874	1661	Economy	16700.00
0005433367345	1661	Economy	16700.00
0005433367347	1661	Economy	16700.00
0005435652845	1661	Economy	16700.00
0005435652869	1661	Economy	16700.00
0005435652849	1661	Economy	16700.00
0005433367289	1661	Economy	16700.00
0005433367400	1661	Economy	16700.00
0005433367339	1661	Economy	16700.00
0005433367278	1661	Economy	16700.00
0005433367359	1661	Economy	16700.00
0005435652838	1661	Economy	16700.00
0005433367346	1661	Economy	16700.00
0005435652841	1661	Economy	16700.00
0005433367543	1661	Economy	16700.00
0005435652864	1661	Economy	16700.00
0005435652876	1661	Economy	16700.00
0005435652852	1661	Economy	16700.00
0005435652873	1661	Economy	16700.00
0005435652861	1661	Economy	16700.00
0005435652854	1661	Economy	16700.00
0005433367279	1661	Economy	16700.00
0005435652867	1661	Economy	16700.00
0005433367290	1661	Economy	16700.00
0005433367222	1661	Economy	16700.00
0005433367263	1661	Economy	16700.00
0005435652877	1661	Economy	16700.00
0005433367219	1661	Economy	16700.00
0005435652847	1661	Economy	16700.00
0005433367309	1661	Economy	16700.00
0005435652848	1661	Economy	16700.00
0005433367405	1661	Economy	16700.00
0005435652851	1661	Economy	16700.00
0005435652850	1661	Economy	16700.00
0005435652846	1661	Economy	16700.00
0005433367351	1661	Economy	16700.00
0005433367328	1661	Economy	16700.00
0005435652839	1661	Economy	16700.00
0005433367327	1661	Economy	16700.00
0005433367398	1661	Economy	16700.00
0005435652863	1661	Economy	16700.00
0005435652866	1661	Economy	16700.00
0005433367516	1661	Economy	16700.00
0005435652318	21678	Business	50000.00
0005435652317	21678	Business	50000.00
0005433367708	21678	Business	50000.00
0005435652304	21678	Business	50000.00
0005433367701	21678	Business	50000.00
0005433367692	21678	Business	50000.00
0005435652342	21678	Business	50000.00
0005435652255	21678	Business	50000.00
0005435652363	21678	Business	50000.00
0005433367690	21678	Business	50000.00
0005433367710	21678	Economy	16700.00
0005433367711	21678	Economy	16700.00
0005435652433	21678	Economy	16700.00
0005435652260	21678	Economy	16700.00
0005435652382	21678	Economy	16700.00
0005435652383	21678	Economy	16700.00
0005433367688	21678	Economy	18300.00
0005433367709	21678	Economy	18300.00
0005435652446	21678	Economy	18300.00
0005435652257	21678	Economy	18300.00
0005435652321	21678	Economy	16700.00
0005433367695	21678	Economy	16700.00
0005433367703	21678	Economy	16700.00
0005433367699	21678	Economy	16700.00
0005433367715	21678	Economy	16700.00
0005433367713	21678	Economy	16700.00
0005435652319	21678	Economy	16700.00
0005435652427	21678	Economy	16700.00
0005433367702	21678	Economy	16700.00
0005433367679	21678	Economy	16700.00
0005435652392	21678	Economy	16700.00
0005433367705	21678	Economy	16700.00
0005433367706	21678	Economy	16700.00
0005433367685	21678	Economy	16700.00
0005435652413	21678	Economy	16700.00
0005435652278	21678	Economy	16700.00
0005433367683	21678	Economy	16700.00
0005435652341	21678	Economy	16700.00
0005433367707	21678	Economy	16700.00
0005435652418	21678	Economy	16700.00
0005435652316	21678	Economy	16700.00
0005433367682	21678	Economy	16700.00
0005433367680	21678	Economy	16700.00
0005433367704	21678	Economy	16700.00
0005433367681	21678	Economy	16700.00
0005435652393	21678	Economy	16700.00
0005435652362	21678	Economy	16700.00
0005435652420	21678	Economy	16700.00
0005435652387	21678	Economy	16700.00
0005435652364	21678	Economy	16700.00
0005433367691	21678	Economy	16700.00
0005433367697	21678	Economy	16700.00
0005433367700	21678	Economy	16700.00
0005435652388	21678	Economy	16700.00
0005433367714	21678	Economy	16700.00
0005433367684	21678	Economy	16700.00
0005435652371	21678	Economy	16700.00
0005435652368	21678	Economy	16700.00
0005433367693	21678	Economy	16700.00
0005435652419	21678	Economy	16700.00
0005433367698	21678	Economy	16700.00
0005435652349	21678	Economy	16700.00
0005435652409	21678	Economy	16700.00
0005435652361	21678	Economy	16700.00
0005435652259	21678	Economy	16700.00
0005433367696	21678	Economy	16700.00
0005435652410	21678	Economy	16700.00
0005435652441	21678	Economy	16700.00
0005433367689	21678	Economy	16700.00
0005433367712	21678	Economy	16700.00
0005433367716	21678	Economy	16700.00
0005433367687	21678	Economy	16700.00
0005435652326	21678	Economy	16700.00
0005433367686	21678	Economy	16700.00
0005433367694	21678	Economy	16700.00
0005435652264	21678	Economy	16700.00
0005435652394	21678	Economy	16700.00
0005433985735	4180	Business	21500.00
0005433985702	4180	Business	21500.00
0005433985701	4180	Business	21500.00
0005433985729	4180	Business	21500.00
0005433985722	4180	Business	21500.00
0005433985715	4180	Business	21500.00
0005433985707	4180	Business	21500.00
0005433985698	4180	Business	21500.00
0005433985717	4180	Business	21500.00
0005433985731	4180	Business	21500.00
0005433985718	4180	Economy	7200.00
0005433985700	4180	Economy	7200.00
0005433985733	4180	Economy	7200.00
0005433985716	4180	Economy	7200.00
0005433985734	4180	Economy	7200.00
0005433985696	4180	Economy	7200.00
0005433985704	4180	Economy	7900.00
0005433985721	4180	Economy	7900.00
0005433985725	4180	Economy	7900.00
0005433985737	4180	Economy	7200.00
0005433985710	4180	Economy	7200.00
0005433985703	4180	Economy	7200.00
0005433985690	4180	Economy	7200.00
0005433985695	4180	Economy	7200.00
0005433985726	4180	Economy	7200.00
0005433985724	4180	Economy	7200.00
0005433985730	4180	Economy	7200.00
0005433985736	4180	Economy	7200.00
0005433985708	4180	Economy	7200.00
0005433985732	4180	Economy	7200.00
0005433985727	4180	Economy	7200.00
0005433985738	4180	Economy	7200.00
0005435788758	4180	Economy	7200.00
0005433985719	4180	Economy	7200.00
0005433985728	4180	Economy	7200.00
0005433985699	4180	Economy	7200.00
0005433985691	4180	Economy	7200.00
0005433985712	4180	Economy	7200.00
0005433985689	4180	Economy	7200.00
0005433985711	4180	Economy	7200.00
0005433985692	4180	Economy	7200.00
0005433985709	4180	Economy	7200.00
0005433985713	4180	Economy	7200.00
0005433985705	4180	Economy	7200.00
0005433985697	4180	Economy	7200.00
0005433985720	4180	Economy	7200.00
0005433985693	4180	Economy	7200.00
0005435788759	4180	Economy	7200.00
0005433985694	4180	Economy	7200.00
0005433985706	4180	Economy	7200.00
0005433985723	4180	Economy	7200.00
0005433985714	4180	Economy	7200.00
0005433985158	25678	Business	21500.00
0005433985283	25678	Business	21500.00
0005433985206	25678	Business	21500.00
0005433985315	25678	Business	21500.00
0005433985282	25678	Economy	7200.00
0005433985194	25678	Economy	7200.00
0005433985265	25678	Economy	7200.00
0005433985346	25678	Economy	7200.00
0005433985333	25678	Economy	7200.00
0005433985354	25678	Economy	7200.00
0005433985370	25678	Economy	7200.00
0005433985359	25678	Economy	7900.00
0005433985149	25678	Economy	7900.00
0005433985267	25678	Economy	7200.00
0005433985237	25678	Economy	7200.00
0005433985435	25678	Economy	7200.00
0005433985195	25678	Economy	7200.00
0005433985332	25678	Economy	7200.00
0005433985156	25678	Economy	7200.00
0005433985167	25678	Economy	7200.00
0005433985205	25678	Economy	7200.00
0005433985400	25678	Economy	7200.00
0005433985266	25678	Economy	7200.00
0005433985433	25678	Economy	7200.00
0005433985299	25678	Economy	7200.00
0005433985369	25678	Economy	7200.00
0005433985402	25678	Economy	7200.00
0005433985178	25678	Economy	7200.00
0005433985196	25678	Economy	7200.00
0005433985533	25678	Economy	7200.00
0005433985401	25678	Economy	7200.00
0005433985314	25678	Economy	7200.00
0005433985547	25678	Economy	7200.00
0005433985349	25678	Economy	7200.00
0005433985424	25678	Economy	7200.00
0005433985238	25678	Economy	7200.00
0005433985184	25678	Economy	7200.00
0005435788740	25678	Economy	7200.00
0005433985318	25678	Economy	7200.00
0005433985281	25678	Economy	7200.00
0005433985360	25678	Economy	7200.00
0005433985166	25678	Economy	7200.00
0005433985240	25678	Economy	7200.00
0005433985254	25678	Economy	7200.00
0005433985239	25678	Economy	7200.00
0005433985225	25678	Economy	7200.00
0005433985423	25678	Economy	7200.00
0005433985298	25678	Economy	7200.00
0005433985334	25678	Economy	7200.00
0005433985313	25678	Economy	7200.00
0005433985422	25678	Economy	7200.00
0005433985255	25678	Economy	7200.00
0005433985345	25678	Economy	7200.00
0005435720129	24784	Economy	9400.00
0005435719563	24784	Economy	9400.00
0005435719564	24784	Economy	9400.00
0005433168354	21318	Economy	17000.00
0005434509031	21318	Economy	17000.00
0005434509042	21318	Economy	17000.00
0005434509062	21318	Economy	17000.00
0005433168348	21318	Economy	15500.00
0005434509040	21318	Economy	15500.00
0005434509083	21318	Economy	15500.00
0005434509033	21318	Economy	15500.00
0005434509023	21318	Economy	15500.00
0005434509038	21318	Economy	15500.00
0005434509049	21318	Economy	15500.00
0005434509053	21318	Economy	15500.00
0005434509025	21318	Economy	15500.00
0005434509017	21318	Economy	15500.00
0005434509032	21318	Economy	15500.00
0005434509026	21318	Economy	15500.00
0005433168350	21318	Economy	15500.00
0005434509058	21318	Economy	15500.00
0005433168344	21318	Economy	15500.00
0005434509052	21318	Economy	15500.00
0005433168346	21318	Economy	15500.00
0005434509022	21318	Economy	15500.00
0005433168351	21318	Economy	15500.00
0005434509048	21318	Economy	15500.00
0005433168345	21318	Economy	15500.00
0005434509059	21318	Economy	15500.00
0005434509041	21318	Economy	15500.00
0005433168347	21318	Economy	15500.00
0005434509075	21318	Economy	15500.00
0005434509063	21318	Economy	15500.00
0005434509037	21318	Economy	15500.00
0005433168355	21318	Economy	15500.00
0005434509018	21318	Economy	15500.00
0005433168353	21318	Economy	15500.00
0005433168352	21318	Economy	15500.00
0005434509020	21318	Economy	15500.00
0005434509047	21318	Economy	15500.00
0005434509046	21318	Economy	15500.00
0005433168349	21318	Economy	15500.00
0005434509039	21318	Economy	15500.00
0005434509045	21318	Economy	15500.00
0005433168342	21318	Economy	15500.00
0005433168343	21318	Economy	15500.00
0005434509021	21318	Economy	15500.00
0005434509084	21318	Economy	15500.00
0005432657410	17852	Business	18000.00
0005432665250	17852	Business	18000.00
0005434151690	17852	Business	18000.00
0005432655334	17852	Business	18000.00
0005432667427	17852	Economy	6000.00
0005432659679	17852	Economy	6000.00
0005432659683	17852	Economy	6000.00
0005432655383	17852	Economy	6000.00
0005432655382	17852	Economy	6600.00
0005432869493	17852	Economy	6000.00
0005432655343	17852	Economy	6000.00
0005432869494	17852	Economy	6000.00
0005432655354	17852	Economy	6000.00
0005432659677	17852	Economy	6000.00
0005432869492	17852	Economy	6000.00
0005432655410	17852	Economy	6000.00
0005432659678	17852	Economy	6000.00
0005432655338	17852	Economy	6000.00
0005432660789	17852	Economy	6000.00
0005432655339	17852	Economy	6000.00
0005432655359	17852	Economy	6000.00
0005432657417	17852	Economy	6000.00
0005432657404	17852	Economy	6000.00
0005432655352	17852	Economy	6000.00
0005432869498	17852	Economy	6000.00
0005434151691	17852	Economy	6000.00
0005432655346	17852	Economy	6000.00
0005432655329	17852	Economy	6000.00
0005432869496	17852	Economy	6000.00
0005432659682	17852	Economy	6000.00
0005432667426	17852	Economy	6000.00
0005432869497	17852	Economy	6000.00
0005432667428	17852	Economy	6000.00
0005434151692	17852	Economy	6000.00
0005432660790	17852	Economy	6000.00
0005432869495	17852	Economy	6000.00
0005432655330	17852	Economy	6000.00
0005432660788	17852	Economy	6000.00
0005432666376	26283	Business	18000.00
0005432869434	26283	Business	18000.00
0005432657431	26283	Business	18000.00
0005434151660	26283	Economy	6000.00
0005432869429	26283	Economy	6000.00
0005432655451	26283	Economy	6000.00
0005432667441	26283	Economy	6000.00
0005432655454	26283	Economy	6600.00
0005434151663	26283	Economy	6000.00
0005432657429	26283	Economy	6000.00
0005432655457	26283	Economy	6000.00
0005432666375	26283	Economy	6000.00
0005432660805	26283	Economy	6000.00
0005432657430	26283	Economy	6000.00
0005434151658	26283	Economy	6000.00
0005432655455	26283	Economy	6000.00
0005432659693	26283	Economy	6000.00
0005432660804	26283	Economy	6000.00
0005432869417	26283	Economy	6000.00
0005432665261	26283	Economy	6000.00
0005432658578	26283	Economy	6000.00
0005432655453	26283	Economy	6000.00
0005432659692	26283	Economy	6000.00
0005432655458	26283	Economy	6000.00
0005432655449	26283	Economy	6000.00
0005432655450	26283	Economy	6000.00
0005432667440	26283	Economy	6000.00
0005434151659	26283	Economy	6000.00
0005434151661	26283	Economy	6000.00
0005432655459	26283	Economy	6000.00
0005432655452	26283	Economy	6000.00
0005434151666	26283	Economy	6000.00
0005432665262	26283	Economy	6000.00
0005432655456	26283	Economy	6000.00
0005432328462	3126	Business	16100.00
0005432328495	3126	Business	16100.00
0005432905045	3126	Business	16100.00
0005432905044	3126	Business	16100.00
0005432328469	3126	Business	16100.00
0005432328460	3126	Business	16100.00
0005432328471	3126	Business	16100.00
0005432328497	3126	Economy	5400.00
0005433438845	3126	Economy	5400.00
0005432328500	3126	Economy	5400.00
0005433438841	3126	Economy	5400.00
0005432328493	3126	Economy	5400.00
0005432328482	3126	Economy	5400.00
0005432328464	3126	Economy	5400.00
0005432328499	3126	Economy	5900.00
0005432287164	3126	Economy	5900.00
0005432328473	3126	Economy	5900.00
0005433438844	3126	Economy	5900.00
0005432328468	3126	Economy	5900.00
0005432905042	3126	Economy	5400.00
0005432328483	3126	Economy	5400.00
0005432328492	3126	Economy	5400.00
0005432287167	3126	Economy	5400.00
0005432328465	3126	Economy	5400.00
0005432328475	3126	Economy	5400.00
0005432328484	3126	Economy	5400.00
0005433438842	3126	Economy	5400.00
0005432328457	3126	Economy	5400.00
0005432328491	3126	Economy	5400.00
0005432287163	3126	Economy	5400.00
0005433438843	3126	Economy	5400.00
0005432328490	3126	Economy	5400.00
0005432328481	3126	Economy	5400.00
0005432328487	3126	Economy	5400.00
0005432328477	3126	Economy	5400.00
0005432905035	3126	Economy	5400.00
0005432905026	3126	Economy	5400.00
0005432328463	3126	Economy	5400.00
0005432328489	3126	Economy	5400.00
0005432328478	3126	Economy	5400.00
0005432328480	3126	Economy	5400.00
0005433438846	3126	Economy	5400.00
0005432287166	3126	Economy	5400.00
0005432328454	3126	Economy	5400.00
0005432328470	3126	Economy	5400.00
0005432287162	3126	Economy	5400.00
0005432328498	3126	Economy	5400.00
0005433438847	3126	Economy	5400.00
0005432328459	3126	Economy	5400.00
0005432905034	3126	Economy	5400.00
0005432328488	3126	Economy	5400.00
0005432328476	3126	Economy	5400.00
0005432328461	3126	Economy	5400.00
0005432328472	3126	Economy	5400.00
0005432328474	3126	Economy	5400.00
0005432328486	3126	Economy	5400.00
0005432328458	3126	Economy	5400.00
0005432328467	3126	Economy	5400.00
0005432328479	3126	Economy	5400.00
0005432328496	3126	Economy	5400.00
0005432328456	3126	Economy	5400.00
0005432328485	3126	Economy	5400.00
0005432328494	3126	Economy	5400.00
0005432328466	3126	Economy	5400.00
0005432287165	3126	Economy	5400.00
0005432328455	3126	Economy	5400.00
0005432327975	31128	Business	16100.00
0005433438815	31128	Business	16100.00
0005432327974	31128	Business	16100.00
0005432328043	31128	Business	16100.00
0005432328016	31128	Business	16100.00
0005432327922	31128	Business	16100.00
0005432327987	31128	Economy	5400.00
0005432327964	31128	Economy	5400.00
0005432054289	31128	Economy	5400.00
0005432905102	31128	Economy	5400.00
0005432905101	31128	Economy	5400.00
0005432327976	31128	Economy	5900.00
0005432054291	31128	Economy	5900.00
0005432328041	31128	Economy	5900.00
0005432328050	31128	Economy	5400.00
0005432327986	31128	Economy	5400.00
0005432328123	31128	Economy	5400.00
0005433438797	31128	Economy	5400.00
0005432327988	31128	Economy	5400.00
0005432328207	31128	Economy	5400.00
0005432328074	31128	Economy	5400.00
0005432327953	31128	Economy	5400.00
0005432905098	31128	Economy	5400.00
0005432905100	31128	Economy	5400.00
0005432328008	31128	Economy	5400.00
0005432328046	31128	Economy	5400.00
0005432328045	31128	Economy	5400.00
0005432327963	31128	Economy	5400.00
0005432328132	31128	Economy	5400.00
0005432054288	31128	Economy	5400.00
0005432328216	31128	Economy	5400.00
0005432328122	31128	Economy	5400.00
0005432328048	31128	Economy	5400.00
0005433438816	31128	Economy	5400.00
0005432327927	31128	Economy	5400.00
0005432328032	31128	Economy	5400.00
0005432327926	31128	Economy	5400.00
0005432328007	31128	Economy	5400.00
0005433438773	31128	Economy	5400.00
0005432328042	31128	Economy	5400.00
0005432328044	31128	Economy	5400.00
0005433438774	31128	Economy	5400.00
0005432905097	31128	Economy	5400.00
0005432327961	31128	Economy	5400.00
0005432328047	31128	Economy	5400.00
0005432054290	31128	Economy	5400.00
0005432328049	31128	Economy	5400.00
0005432328017	31128	Economy	5400.00
0005432905099	31128	Economy	5400.00
0005432327960	31128	Economy	5400.00
0005432905103	31128	Economy	5400.00
0005432328215	31128	Economy	5400.00
0005432328036	31128	Economy	5400.00
0005432328157	31128	Economy	5400.00
0005435296970	6210	Business	124600.00
0005435999177	6210	Business	124600.00
0005435487531	6210	Business	124600.00
0005432146189	6210	Business	124600.00
0005435487470	6210	Business	124600.00
0005435487476	6210	Business	124600.00
0005435999174	6210	Economy	41500.00
0005435999181	6210	Economy	41500.00
0005435999178	6210	Economy	41500.00
0005435296962	6210	Economy	41500.00
0005434309674	6210	Economy	41500.00
0005435999175	6210	Economy	41500.00
0005435296963	6210	Economy	41500.00
0005435487547	6210	Economy	41500.00
0005434309673	6210	Economy	41500.00
0005435487490	6210	Economy	41500.00
0005435487570	6210	Economy	41500.00
0005434309682	6210	Economy	41500.00
0005435487576	6210	Economy	41500.00
0005434309680	6210	Economy	41500.00
0005435487528	6210	Economy	41500.00
0005435487598	6210	Economy	41500.00
0005434309681	6210	Economy	41500.00
0005435487526	6210	Economy	41500.00
0005435487509	6210	Economy	41500.00
0005435999173	6210	Economy	41500.00
0005434309672	6210	Economy	41500.00
0005432146188	6210	Economy	41500.00
0005435487548	6210	Economy	41500.00
0005434309675	6210	Economy	41500.00
0005435487543	6210	Economy	41500.00
0005435487498	6210	Economy	41500.00
0005435487560	6210	Economy	41500.00
0005435487544	6210	Economy	41500.00
0005434309670	6210	Economy	41500.00
0005435296948	6210	Economy	41500.00
0005435487597	6210	Economy	41500.00
0005435296964	6210	Economy	41500.00
0005435487527	6210	Economy	41500.00
0005435487558	6210	Economy	41500.00
0005435487492	6210	Economy	41500.00
0005434309676	6210	Economy	41500.00
0005434309677	6210	Economy	41500.00
0005435999179	6210	Economy	41500.00
0005434309679	6210	Economy	41500.00
0005432146190	6210	Economy	41500.00
0005435296971	6210	Economy	41500.00
0005435999176	6210	Economy	41500.00
0005434309678	6210	Economy	41500.00
0005434309671	6210	Economy	41500.00
0005435487499	6210	Economy	41500.00
0005435487574	6210	Economy	41500.00
0005435487584	6210	Economy	41500.00
0005435487522	6210	Economy	41500.00
0005435999180	6210	Economy	41500.00
0005435487491	6210	Economy	41500.00
0005435487585	6210	Economy	41500.00
0005435487575	6210	Economy	41500.00
0005435487620	6210	Economy	41500.00
0005435487500	6210	Economy	41500.00
0005435487571	6210	Economy	41500.00
0005435487563	6210	Economy	41500.00
0005435998954	19525	Business	124600.00
0005435998994	19525	Business	124600.00
0005434309583	19525	Business	124600.00
0005435998960	19525	Business	124600.00
0005434309586	19525	Business	124600.00
0005435998985	19525	Business	124600.00
0005435998998	19525	Business	124600.00
0005435998956	19525	Economy	41500.00
0005435297023	19525	Economy	41500.00
0005435487702	19525	Economy	41500.00
0005435998997	19525	Economy	41500.00
0005435487712	19525	Economy	41500.00
0005435998977	19525	Economy	41500.00
0005435487703	19525	Economy	41500.00
0005434309582	19525	Economy	41500.00
0005435998993	19525	Economy	41500.00
0005435487706	19525	Economy	41500.00
0005435487713	19525	Economy	41500.00
0005435487711	19525	Economy	41500.00
0005435487705	19525	Economy	41500.00
0005435297026	19525	Economy	41500.00
0005435487716	19525	Economy	41500.00
0005435487718	19525	Economy	41500.00
0005434309588	19525	Economy	45700.00
0005435998958	19525	Economy	41500.00
0005435487710	19525	Economy	41500.00
0005435487708	19525	Economy	41500.00
0005434309549	19525	Economy	41500.00
0005434309568	19525	Economy	41500.00
0005434309587	19525	Economy	41500.00
0005434309579	19525	Economy	41500.00
0005435297028	19525	Economy	41500.00
0005435487715	19525	Economy	41500.00
0005434309578	19525	Economy	41500.00
0005435487714	19525	Economy	41500.00
0005435998955	19525	Economy	41500.00
0005435487717	19525	Economy	41500.00
0005435487700	19525	Economy	41500.00
0005435998963	19525	Economy	41500.00
0005435998992	19525	Economy	41500.00
0005434309567	19525	Economy	41500.00
0005435487709	19525	Economy	41500.00
0005435297024	19525	Economy	41500.00
0005434309544	19525	Economy	41500.00
0005435487699	19525	Economy	41500.00
0005434309534	19525	Economy	41500.00
0005435998981	19525	Economy	41500.00
0005435487701	19525	Economy	41500.00
0005435998973	19525	Economy	41500.00
0005435487697	19525	Economy	41500.00
0005435998959	19525	Economy	41500.00
0005435487704	19525	Economy	41500.00
0005435487707	19525	Economy	41500.00
0005435487698	19525	Economy	41500.00
0005435297027	19525	Economy	41500.00
0005435297025	19525	Economy	41500.00
0005435998964	19525	Economy	41500.00
0005435998974	19525	Economy	41500.00
0005434309585	19525	Economy	41500.00
0005435998986	19525	Economy	41500.00
0005435502208	1582	Business	86000.00
0005434565852	1582	Business	86000.00
0005435517821	1582	Business	86000.00
0005433185995	1582	Business	86000.00
0005435502211	1582	Business	86000.00
0005434565854	1582	Business	86000.00
0005435502205	1582	Business	86000.00
0005433186032	1582	Business	86000.00
0005435502200	1582	Business	86000.00
0005432291919	1582	Economy	28700.00
0005435508306	1582	Economy	28700.00
0005435508302	1582	Economy	28700.00
0005435508298	1582	Economy	28700.00
0005434565855	1582	Economy	28700.00
0005435508297	1582	Economy	28700.00
0005435508304	1582	Economy	28700.00
0005433186018	1582	Economy	28700.00
0005433186033	1582	Economy	31500.00
0005435502204	1582	Economy	31500.00
0005435502198	1582	Economy	31500.00
0005435502218	1582	Economy	28700.00
0005435502212	1582	Economy	28700.00
0005435517823	1582	Economy	28700.00
0005434565844	1582	Economy	28700.00
0005434565848	1582	Economy	28700.00
0005435517828	1582	Economy	28700.00
0005435517834	1582	Economy	28700.00
0005435517832	1582	Economy	28700.00
0005433186011	1582	Economy	28700.00
0005432291920	1582	Economy	28700.00
0005435517833	1582	Economy	28700.00
0005435508305	1582	Economy	28700.00
0005435517830	1582	Economy	28700.00
0005435502217	1582	Economy	28700.00
0005435508301	1582	Economy	28700.00
0005435502215	1582	Economy	28700.00
0005435517822	1582	Economy	28700.00
0005435517820	1582	Economy	28700.00
0005435502213	1582	Economy	28700.00
0005435517819	1582	Economy	28700.00
0005435517836	1582	Economy	28700.00
0005435502216	1582	Economy	28700.00
0005435517824	1582	Economy	28700.00
0005435508300	1582	Economy	28700.00
0005434565846	1582	Economy	28700.00
0005435502209	1582	Economy	28700.00
0005435517835	1582	Economy	28700.00
0005434565850	1582	Economy	28700.00
0005434565851	1582	Economy	28700.00
0005435502210	1582	Economy	28700.00
0005435517829	1582	Economy	28700.00
0005435517827	1582	Economy	28700.00
0005435517831	1582	Economy	28700.00
0005435502197	1582	Economy	28700.00
0005435517826	1582	Economy	28700.00
0005435502207	1582	Economy	28700.00
0005434565847	1582	Economy	28700.00
0005435508303	1582	Economy	28700.00
0005432291917	1582	Economy	28700.00
0005435502203	1582	Economy	28700.00
0005432291918	1582	Economy	28700.00
0005435517825	1582	Economy	28700.00
0005435508299	1582	Economy	28700.00
0005435508307	1582	Economy	28700.00
0005435502214	1582	Economy	28700.00
0005434565853	1582	Economy	28700.00
0005435517818	1582	Economy	28700.00
0005435508308	1582	Economy	28700.00
0005434565849	1582	Economy	28700.00
0005435502199	1582	Economy	28700.00
0005434565843	1582	Economy	28700.00
0005435502201	1582	Economy	28700.00
0005434565845	1582	Economy	28700.00
0005435502202	1582	Economy	28700.00
0005435502206	1582	Economy	28700.00
0005434565752	20886	Business	86000.00
0005435528912	20886	Business	86000.00
0005435502091	20886	Business	86000.00
0005433186074	20886	Business	86000.00
0005434565729	20886	Business	86000.00
0005435528943	20886	Business	86000.00
0005435528978	20886	Business	86000.00
0005434565707	20886	Economy	28700.00
0005434565749	20886	Economy	28700.00
0005434565681	20886	Economy	28700.00
0005435528911	20886	Economy	28700.00
0005435528948	20886	Economy	28700.00
0005435528923	20886	Economy	28700.00
0005433186078	20886	Economy	28700.00
0005435528903	20886	Economy	31500.00
0005435502065	20886	Economy	31500.00
0005433186073	20886	Economy	31500.00
0005434565725	20886	Economy	31500.00
0005435501954	20886	Economy	28700.00
0005435501975	20886	Economy	28700.00
0005435528979	20886	Economy	28700.00
0005435528924	20886	Economy	28700.00
0005435528963	20886	Economy	28700.00
0005435501933	20886	Economy	28700.00
0005435501990	20886	Economy	28700.00
0005435528982	20886	Economy	28700.00
0005434565748	20886	Economy	28700.00
0005435528937	20886	Economy	28700.00
0005435501959	20886	Economy	28700.00
0005435528881	20886	Economy	28700.00
0005435529012	20886	Economy	28700.00
0005435502014	20886	Economy	28700.00
0005435528988	20886	Economy	28700.00
0005433186077	20886	Economy	28700.00
0005435545616	20886	Economy	28700.00
0005433186081	20886	Economy	28700.00
0005435528990	20886	Economy	28700.00
0005433186079	20886	Economy	28700.00
0005435501953	20886	Economy	28700.00
0005435528936	20886	Economy	28700.00
0005434565677	20886	Economy	28700.00
0005434565680	20886	Economy	28700.00
0005435501932	20886	Economy	28700.00
0005435502015	20886	Economy	28700.00
0005435528962	20886	Economy	28700.00
0005435528987	20886	Economy	28700.00
0005433186075	20886	Economy	28700.00
0005435528949	20886	Economy	28700.00
0005435502090	20886	Economy	28700.00
0005433186080	20886	Economy	28700.00
0005435502013	20886	Economy	28700.00
0005435528961	20886	Economy	28700.00
0005435528932	20886	Economy	28700.00
0005435502089	20886	Economy	28700.00
0005435529011	20886	Economy	28700.00
0005433186076	20886	Economy	28700.00
0005435501958	20886	Economy	28700.00
0005434565724	20886	Economy	28700.00
0005435501986	20886	Economy	28700.00
0005434565722	20886	Economy	28700.00
0005435502016	20886	Economy	28700.00
0005435501966	20886	Economy	28700.00
0005435502004	20886	Economy	28700.00
0005435931558	3896	Economy	19700.00
0005435153711	3896	Economy	19700.00
0005435153712	3896	Economy	19700.00
0005435931543	3896	Economy	19700.00
0005435931544	3896	Economy	19700.00
0005435931557	3896	Economy	19700.00
0005435153707	3896	Economy	19700.00
0005435153709	3896	Economy	19700.00
0005435153708	3896	Economy	19700.00
0005435153710	3896	Economy	19700.00
0005435153655	21860	Economy	19700.00
0005435153645	21860	Economy	19700.00
0005435153660	21860	Economy	19700.00
0005435153656	21860	Economy	19700.00
0005435153654	21860	Economy	19700.00
0005435931584	21860	Economy	19700.00
0005435931583	21860	Economy	19700.00
0005435931585	21860	Economy	19700.00
0005435153644	21860	Economy	19700.00
0005435153657	21860	Economy	19700.00
0005432628768	7188	Economy	14300.00
0005432628769	7188	Economy	14300.00
0005435225446	7188	Economy	13000.00
0005435225449	7188	Economy	13000.00
0005432628770	7188	Economy	13000.00
0005432628774	7188	Economy	13000.00
0005432628781	7188	Economy	13000.00
0005432628767	7188	Economy	13000.00
0005435225458	7188	Economy	13000.00
0005432628776	7188	Economy	13000.00
0005432628771	7188	Economy	13000.00
0005432628779	7188	Economy	13000.00
0005432628772	7188	Economy	13000.00
0005432628778	7188	Economy	13000.00
0005432628780	7188	Economy	13000.00
0005432628775	7188	Economy	13000.00
0005432628773	7188	Economy	13000.00
0005435225463	7188	Economy	13000.00
0005432628777	7188	Economy	13000.00
0005432628676	28140	Economy	14300.00
0005435225548	28140	Economy	14300.00
0005432628657	28140	Economy	14300.00
0005435225547	28140	Economy	13000.00
0005432628714	28140	Economy	13000.00
0005435225543	28140	Economy	13000.00
0005432628652	28140	Economy	13000.00
0005432628662	28140	Economy	13000.00
0005432628595	28140	Economy	13000.00
0005432628692	28140	Economy	13000.00
0005432628647	28140	Economy	13000.00
0005435225545	28140	Economy	13000.00
0005435225544	28140	Economy	13000.00
0005432628664	28140	Economy	13000.00
0005435225549	28140	Economy	13000.00
0005432628668	28140	Economy	13000.00
0005432628606	28140	Economy	13000.00
0005435225546	28140	Economy	13000.00
0005432628648	28140	Economy	13000.00
0005432628638	28140	Economy	13000.00
0005432628653	28140	Economy	13000.00
0005432628675	28140	Economy	13000.00
0005435225542	28140	Economy	13000.00
0005435225541	28140	Economy	13000.00
0005432628656	28140	Economy	13000.00
0005432628663	28140	Economy	13000.00
0005434267900	8739	Economy	10500.00
0005435960033	8739	Economy	10500.00
0005434267894	8739	Economy	10500.00
0005434267913	8739	Economy	10500.00
0005435960032	8739	Economy	10500.00
0005434267887	8739	Economy	10500.00
0005435960031	8739	Economy	10500.00
0005435959993	15217	Economy	10500.00
0005435960003	15217	Economy	10500.00
0005435960011	15217	Economy	10500.00
0005435959990	15217	Economy	10500.00
0005435960016	15217	Economy	10500.00
0005435960025	15217	Economy	10500.00
0005435959991	15217	Economy	10500.00
0005434267930	15217	Economy	10500.00
0005434267931	15217	Economy	10500.00
0005435960005	15217	Economy	10500.00
0005435959992	15217	Economy	10500.00
0005434267932	15217	Economy	10500.00
0005435960000	15217	Economy	10500.00
0005432692898	1188	Business	115000.00
0005432692879	1188	Business	115000.00
0005432692890	1188	Business	115000.00
0005432873198	1188	Business	115000.00
0005432873216	1188	Business	115000.00
0005432692875	1188	Business	115000.00
0005432692883	1188	Business	115000.00
0005432677549	1188	Business	115000.00
0005432692889	1188	Business	115000.00
0005432692891	1188	Business	115000.00
0005432692902	1188	Business	115000.00
0005432675051	1188	Business	115000.00
0005432692896	1188	Economy	38300.00
0005432692884	1188	Economy	38300.00
0005432873180	1188	Economy	38300.00
0005432677550	1188	Economy	38300.00
0005432675059	1188	Economy	38300.00
0005432692876	1188	Economy	38300.00
0005432692888	1188	Economy	38300.00
0005432692881	1188	Economy	38300.00
0005432675055	1188	Economy	42200.00
0005432692897	1188	Economy	42200.00
0005432677551	1188	Economy	38300.00
0005432675057	1188	Economy	38300.00
0005432692900	1188	Economy	38300.00
0005432692882	1188	Economy	38300.00
0005432692893	1188	Economy	38300.00
0005432873197	1188	Economy	38300.00
0005432675058	1188	Economy	38300.00
0005432692905	1188	Economy	38300.00
0005432692901	1188	Economy	38300.00
0005432675060	1188	Economy	38300.00
0005432692887	1188	Economy	38300.00
0005432675062	1188	Economy	38300.00
0005432675061	1188	Economy	38300.00
0005432675053	1188	Economy	38300.00
0005432692903	1188	Economy	38300.00
0005432692885	1188	Economy	38300.00
0005432692895	1188	Economy	38300.00
0005432692886	1188	Economy	38300.00
0005432675050	1188	Economy	38300.00
0005432692899	1188	Economy	38300.00
0005432692894	1188	Economy	38300.00
0005432692878	1188	Economy	38300.00
0005432692880	1188	Economy	38300.00
0005432692904	1188	Economy	38300.00
0005432675052	1188	Economy	38300.00
0005432675049	1188	Economy	38300.00
0005432873188	1188	Economy	38300.00
0005432692877	1188	Economy	38300.00
0005432675054	1188	Economy	38300.00
0005432677548	1188	Economy	38300.00
0005432692892	1188	Economy	38300.00
0005432675063	1188	Economy	38300.00
0005432692874	1188	Economy	38300.00
0005432675056	1188	Economy	38300.00
0005432873253	17500	Business	115000.00
0005432677518	17500	Business	115000.00
0005432674964	17500	Business	115000.00
0005432692719	17500	Business	115000.00
0005432692602	17500	Business	115000.00
0005432692667	17500	Business	115000.00
0005432873258	17500	Business	115000.00
0005432692678	17500	Business	115000.00
0005432674911	17500	Business	115000.00
0005432692676	17500	Economy	38300.00
0005432692690	17500	Economy	38300.00
0005432692704	17500	Economy	38300.00
0005432692540	17500	Economy	38300.00
0005432692619	17500	Economy	38300.00
0005432692668	17500	Economy	42200.00
0005432674943	17500	Economy	42200.00
0005432674887	17500	Economy	42200.00
0005432692706	17500	Economy	38300.00
0005432692599	17500	Economy	38300.00
0005432677523	17500	Economy	38300.00
0005432692711	17500	Economy	38300.00
0005432692679	17500	Economy	38300.00
0005432873256	17500	Economy	38300.00
0005432692673	17500	Economy	38300.00
0005432692548	17500	Economy	38300.00
0005432692549	17500	Economy	38300.00
0005432692588	17500	Economy	38300.00
0005432692735	17500	Economy	38300.00
0005432692677	17500	Economy	38300.00
0005432692720	17500	Economy	38300.00
0005432674912	17500	Economy	38300.00
0005432674910	17500	Economy	38300.00
0005432674909	17500	Economy	38300.00
0005432873259	17500	Economy	38300.00
0005432692550	17500	Economy	38300.00
0005432692614	17500	Economy	38300.00
0005432692587	17500	Economy	38300.00
0005432692736	17500	Economy	38300.00
0005432873254	17500	Economy	38300.00
0005432873255	17500	Economy	38300.00
0005432692600	17500	Economy	38300.00
0005432692689	17500	Economy	38300.00
0005432692803	17500	Economy	38300.00
0005432873257	17500	Economy	38300.00
0005432692672	17500	Economy	38300.00
0005432674869	17500	Economy	38300.00
0005433156612	1111	Economy	15200.00
0005433156635	1111	Economy	15200.00
0005434435101	1111	Economy	15200.00
0005433156637	1111	Economy	13900.00
0005433156649	1111	Economy	13900.00
0005433156611	1111	Economy	13900.00
0005433156657	1111	Economy	13900.00
0005434435104	1111	Economy	13900.00
0005434435111	1111	Economy	13900.00
0005434435105	1111	Economy	13900.00
0005434435108	1111	Economy	13900.00
0005433156636	1111	Economy	13900.00
0005434435109	1111	Economy	13900.00
0005434435099	1111	Economy	13900.00
0005433156654	1111	Economy	13900.00
0005434435110	1111	Economy	13900.00
0005433156650	1111	Economy	13900.00
0005433156647	1111	Economy	13900.00
0005434435107	1111	Economy	13900.00
0005433156646	1111	Economy	13900.00
0005434435112	1111	Economy	13900.00
0005434435113	1111	Economy	13900.00
0005433156648	1111	Economy	13900.00
0005433156638	1111	Economy	13900.00
0005434435106	1111	Economy	13900.00
0005434435102	1111	Economy	13900.00
0005434435100	1111	Economy	13900.00
0005434435103	1111	Economy	13900.00
0005433156705	17286	Economy	15200.00
0005433156702	17286	Economy	15200.00
0005433156709	17286	Economy	13900.00
0005434435031	17286	Economy	13900.00
0005434434914	17286	Economy	13900.00
0005434434963	17286	Economy	13900.00
0005434434973	17286	Economy	13900.00
0005434434976	17286	Economy	13900.00
0005434435029	17286	Economy	13900.00
0005433156707	17286	Economy	13900.00
0005434434982	17286	Economy	13900.00
0005433156704	17286	Economy	13900.00
0005434435030	17286	Economy	13900.00
0005433156710	17286	Economy	13900.00
0005433156703	17286	Economy	13900.00
0005434434985	17286	Economy	13900.00
0005434434945	17286	Economy	13900.00
0005433156708	17286	Economy	13900.00
0005434435003	17286	Economy	13900.00
0005434434986	17286	Economy	13900.00
0005434435002	17286	Economy	13900.00
0005433156706	17286	Economy	13900.00
0005434434972	17286	Economy	13900.00
0005434435032	17286	Economy	13900.00
0005434435004	17286	Economy	13900.00
0005435086799	4071	Economy	8200.00
0005435086796	4071	Economy	7500.00
0005435928074	4071	Economy	7500.00
0005435928072	4071	Economy	7500.00
0005435086800	4071	Economy	7500.00
0005435086795	4071	Economy	7500.00
0005435928073	4071	Economy	7500.00
0005435086797	4071	Economy	7500.00
0005435086794	4071	Economy	7500.00
0005435086798	4071	Economy	7500.00
0005435928082	4071	Economy	7500.00
0005435086750	24427	Economy	8200.00
0005435928117	24427	Economy	7500.00
0005435086739	24427	Economy	7500.00
0005435086717	24427	Economy	7500.00
0005435928118	24427	Economy	7500.00
0005435928119	24427	Economy	7500.00
0005435928120	24427	Economy	7500.00
0005435086745	24427	Economy	7500.00
0005434625913	4847	Business	44200.00
0005434625912	4847	Business	44200.00
0005433194824	4847	Business	44200.00
0005434625917	4847	Economy	14700.00
0005434625918	4847	Economy	16200.00
0005435907458	4847	Economy	14700.00
0005434625915	4847	Economy	14700.00
0005433194823	4847	Economy	14700.00
0005434625916	4847	Economy	14700.00
0005434625911	4847	Economy	14700.00
0005435907439	4847	Economy	14700.00
0005434625914	4847	Economy	14700.00
0005433194822	4847	Economy	14700.00
0005434625919	4847	Economy	14700.00
0005435907459	4847	Economy	14700.00
0005434625875	32904	Business	44200.00
0005434625845	32904	Business	44200.00
0005435907483	32904	Business	44200.00
0005434625863	32904	Business	44200.00
0005435907482	32904	Economy	14700.00
0005435907480	32904	Economy	16200.00
0005434625862	32904	Economy	14700.00
0005434625855	32904	Economy	14700.00
0005434625818	32904	Economy	14700.00
0005434625840	32904	Economy	14700.00
0005435907484	32904	Economy	14700.00
0005434625861	32904	Economy	14700.00
0005434625812	32904	Economy	14700.00
0005434625810	32904	Economy	14700.00
0005435907481	32904	Economy	14700.00
0005435784821	13775	Economy	3400.00
0005435784840	13775	Economy	3400.00
0005435784863	13775	Economy	3400.00
0005435784815	13775	Economy	3400.00
0005435937358	13775	Economy	3100.00
0005435784800	13775	Economy	3100.00
0005435937365	13775	Economy	3100.00
0005435784855	13775	Economy	3100.00
0005435937360	13775	Economy	3100.00
0005435784822	13775	Economy	3100.00
0005432195682	13775	Economy	3100.00
0005435784911	13775	Economy	3100.00
0005435787326	13775	Economy	3100.00
0005435937366	13775	Economy	3100.00
0005435787325	13775	Economy	3100.00
0005435784860	13775	Economy	3100.00
0005435784886	13775	Economy	3100.00
0005435784805	13775	Economy	3100.00
0005435784889	13775	Economy	3100.00
0005435784820	13775	Economy	3100.00
0005435784732	13775	Economy	3100.00
0005435937361	13775	Economy	3100.00
0005435784771	13775	Economy	3100.00
0005435784918	13775	Economy	3100.00
0005435784901	13775	Economy	3100.00
0005435784788	13775	Economy	3100.00
0005435784912	13775	Economy	3100.00
0005435784837	13775	Economy	3100.00
0005435784818	13775	Economy	3100.00
0005435937364	13775	Economy	3100.00
0005435784731	13775	Economy	3100.00
0005435784949	13775	Economy	3100.00
0005435784787	13775	Economy	3100.00
0005435784868	13775	Economy	3100.00
0005435784917	13775	Economy	3100.00
0005432195683	13775	Economy	3100.00
0005435937363	13775	Economy	3100.00
0005435787324	13775	Economy	3100.00
0005435784794	13775	Economy	3100.00
0005435784746	13775	Economy	3100.00
0005435784772	13775	Economy	3100.00
0005435784888	13775	Economy	3100.00
0005435937359	13775	Economy	3100.00
0005435784773	13775	Economy	3100.00
0005435937362	13775	Economy	3100.00
0005435785121	27441	Economy	3400.00
0005435937308	27441	Economy	3400.00
0005435785129	27441	Economy	3400.00
0005435785140	27441	Economy	3100.00
0005435785119	27441	Economy	3100.00
0005435937322	27441	Economy	3100.00
0005432190604	27441	Economy	3100.00
0005435785150	27441	Economy	3100.00
0005435785122	27441	Economy	3100.00
0005435937319	27441	Economy	3100.00
0005435785127	27441	Economy	3100.00
0005435785148	27441	Economy	3100.00
0005435785146	27441	Economy	3100.00
0005435785117	27441	Economy	3100.00
0005435785151	27441	Economy	3100.00
0005435937307	27441	Economy	3100.00
0005435785145	27441	Economy	3100.00
0005435785139	27441	Economy	3100.00
0005432190605	27441	Economy	3100.00
0005435785116	27441	Economy	3100.00
0005435785118	27441	Economy	3100.00
0005435785137	27441	Economy	3100.00
0005435785149	27441	Economy	3100.00
0005435785143	27441	Economy	3100.00
0005432190603	27441	Economy	3100.00
0005435785123	27441	Economy	3100.00
0005435785134	27441	Economy	3100.00
0005435785142	27441	Economy	3100.00
0005435785126	27441	Economy	3100.00
0005435785138	27441	Economy	3100.00
0005435785131	27441	Economy	3100.00
0005435785141	27441	Economy	3100.00
0005432190606	27441	Economy	3100.00
0005435937323	27441	Economy	3100.00
0005435785152	27441	Economy	3100.00
0005435785147	27441	Economy	3100.00
0005435785133	27441	Economy	3100.00
0005435785120	27441	Economy	3100.00
0005435785132	27441	Economy	3100.00
0005435937324	27441	Economy	3100.00
0005435785128	27441	Economy	3100.00
0005435785136	27441	Economy	3100.00
0005435785130	27441	Economy	3100.00
0005435785125	27441	Economy	3100.00
0005435785124	27441	Economy	3100.00
0005435785144	27441	Economy	3100.00
0005435785135	27441	Economy	3100.00
0005434407056	20269	Business	12000.00
0005434407109	20269	Business	12000.00
0005434406871	20269	Business	12000.00
0005434406910	20269	Business	12000.00
0005435311019	20269	Business	12000.00
0005434406735	20269	Business	12000.00
0005434406711	20269	Business	12000.00
0005434406875	20269	Business	12000.00
0005434406876	20269	Business	12000.00
0005434406828	20269	Business	12000.00
0005434407143	20269	Business	12000.00
0005434407165	20269	Economy	4000.00
0005432058363	20269	Economy	4000.00
0005434407144	20269	Economy	4000.00
0005434407064	20269	Economy	4000.00
0005434406832	20269	Economy	4000.00
0005434406886	20269	Economy	4000.00
0005435311015	20269	Economy	4000.00
0005432058362	20269	Economy	4000.00
0005434406652	20269	Economy	4400.00
0005434406983	20269	Economy	4400.00
0005435311022	20269	Economy	4400.00
0005434406741	20269	Economy	4400.00
0005434407019	20269	Economy	4400.00
0005434406916	20269	Economy	4000.00
0005434406772	20269	Economy	4000.00
0005435311021	20269	Economy	4000.00
0005434406736	20269	Economy	4000.00
0005432058360	20269	Economy	4000.00
0005434406643	20269	Economy	4000.00
0005434406896	20269	Economy	4000.00
0005434406793	20269	Economy	4000.00
0005434406769	20269	Economy	4000.00
0005434406734	20269	Economy	4000.00
0005434406763	20269	Economy	4000.00
0005434406775	20269	Economy	4000.00
0005434406992	20269	Economy	4000.00
0005435311024	20269	Economy	4000.00
0005434406923	20269	Economy	4000.00
0005434406765	20269	Economy	4000.00
0005434406872	20269	Economy	4000.00
0005434407014	20269	Economy	4000.00
0005434406771	20269	Economy	4000.00
0005435311018	20269	Economy	4000.00
0005432058361	20269	Economy	4000.00
0005434406719	20269	Economy	4000.00
0005434406909	20269	Economy	4000.00
0005434406873	20269	Economy	4000.00
0005434406924	20269	Economy	4000.00
0005434406712	20269	Economy	4000.00
0005435311020	20269	Economy	4000.00
0005435311017	20269	Economy	4000.00
0005434406887	20269	Economy	4000.00
0005434406653	20269	Economy	4000.00
0005434406867	20269	Economy	4000.00
0005434406847	20269	Economy	4000.00
0005434406801	20269	Economy	4000.00
0005435311023	20269	Economy	4000.00
0005434407110	20269	Economy	4000.00
0005434406829	20269	Economy	4000.00
0005434407065	20269	Economy	4000.00
0005434406929	20269	Economy	4000.00
0005434406826	20269	Economy	4000.00
0005434406897	20269	Economy	4000.00
0005435311025	20269	Economy	4000.00
0005434406740	20269	Economy	4000.00
0005434406900	20269	Economy	4000.00
0005434406692	20269	Economy	4000.00
0005434406835	20269	Economy	4000.00
0005434406838	20269	Economy	4000.00
0005434407005	20269	Economy	4000.00
0005434406965	20269	Economy	4000.00
0005434406846	20269	Economy	4000.00
0005434406898	20269	Economy	4000.00
0005434406878	20269	Economy	4000.00
0005434406950	20269	Economy	4000.00
0005434406934	20269	Economy	4000.00
0005434406644	20269	Economy	4000.00
0005434406879	20269	Economy	4000.00
0005435311016	20269	Economy	4000.00
0005434407004	20269	Economy	4000.00
0005434406710	20269	Economy	4000.00
0005434406911	20269	Economy	4000.00
0005434406888	20269	Economy	4000.00
0005434406945	20269	Economy	4000.00
0005434407013	20269	Economy	4000.00
0005434407145	20269	Economy	4000.00
0005434406830	20269	Economy	4000.00
0005434406786	20269	Economy	4000.00
0005434407421	27004	Business	12000.00
0005434407463	27004	Business	12000.00
0005434407441	27004	Business	12000.00
0005434407442	27004	Business	12000.00
0005434407445	27004	Business	12000.00
0005434407447	27004	Business	12000.00
0005432153903	27004	Business	12000.00
0005434407446	27004	Business	12000.00
0005434407444	27004	Business	12000.00
0005432153901	27004	Business	12000.00
0005435310849	27004	Economy	4000.00
0005434407468	27004	Economy	4000.00
0005434407415	27004	Economy	4000.00
0005434407455	27004	Economy	4000.00
0005434407423	27004	Economy	4000.00
0005434407420	27004	Economy	4000.00
0005435310884	27004	Economy	4000.00
0005434407432	27004	Economy	4000.00
0005432153904	27004	Economy	4000.00
0005434407451	27004	Economy	4400.00
0005434407475	27004	Economy	4400.00
0005434407413	27004	Economy	4400.00
0005434407427	27004	Economy	4400.00
0005434407466	27004	Economy	4000.00
0005434407422	27004	Economy	4000.00
0005434407460	27004	Economy	4000.00
0005434407454	27004	Economy	4000.00
0005434407448	27004	Economy	4000.00
0005434407434	27004	Economy	4000.00
0005434407461	27004	Economy	4000.00
0005432153905	27004	Economy	4000.00
0005434407471	27004	Economy	4000.00
0005435310837	27004	Economy	4000.00
0005434407428	27004	Economy	4000.00
0005434407419	27004	Economy	4000.00
0005434407431	27004	Economy	4000.00
0005434407470	27004	Economy	4000.00
0005434407414	27004	Economy	4000.00
0005435310848	27004	Economy	4000.00
0005434407433	27004	Economy	4000.00
0005434407459	27004	Economy	4000.00
0005434407437	27004	Economy	4000.00
0005434407456	27004	Economy	4000.00
0005434407462	27004	Economy	4000.00
0005434407443	27004	Economy	4000.00
0005434407418	27004	Economy	4000.00
0005434407430	27004	Economy	4000.00
0005435310863	27004	Economy	4000.00
0005435310885	27004	Economy	4000.00
0005432153900	27004	Economy	4000.00
0005434407452	27004	Economy	4000.00
0005434407436	27004	Economy	4000.00
0005434407473	27004	Economy	4000.00
0005435310847	27004	Economy	4000.00
0005434407458	27004	Economy	4000.00
0005434407439	27004	Economy	4000.00
0005435310894	27004	Economy	4000.00
0005434407464	27004	Economy	4000.00
0005434407429	27004	Economy	4000.00
0005434407426	27004	Economy	4000.00
0005434407450	27004	Economy	4000.00
0005434407465	27004	Economy	4000.00
0005435310889	27004	Economy	4000.00
0005434407472	27004	Economy	4000.00
0005435310869	27004	Economy	4000.00
0005434407469	27004	Economy	4000.00
0005434407474	27004	Economy	4000.00
0005434407457	27004	Economy	4000.00
0005434407438	27004	Economy	4000.00
0005434407435	27004	Economy	4000.00
0005434407416	27004	Economy	4000.00
0005434407425	27004	Economy	4000.00
0005434407424	27004	Economy	4000.00
0005432153899	27004	Economy	4000.00
0005434407417	27004	Economy	4000.00
0005434407449	27004	Economy	4000.00
0005434407440	27004	Economy	4000.00
0005434407476	27004	Economy	4000.00
0005434407467	27004	Economy	4000.00
0005435310862	27004	Economy	4000.00
0005434407453	27004	Economy	4000.00
0005432153902	27004	Economy	4000.00
0005434319317	5695	Business	43300.00
0005433123611	5695	Business	43300.00
0005433123645	5695	Business	43300.00
0005432109689	5695	Business	43300.00
0005434319313	5695	Business	43300.00
0005433123618	5695	Business	43300.00
0005434319310	5695	Economy	14400.00
0005434319321	5695	Economy	14400.00
0005434319311	5695	Economy	14400.00
0005432109690	5695	Economy	14400.00
0005433123650	5695	Economy	14400.00
0005433123684	5695	Economy	15900.00
0005434319324	5695	Economy	15900.00
0005434319328	5695	Economy	14400.00
0005433123621	5695	Economy	14400.00
0005434319319	5695	Economy	14400.00
0005433123615	5695	Economy	14400.00
0005434311209	5695	Economy	14400.00
0005434319323	5695	Economy	14400.00
0005434319325	5695	Economy	14400.00
0005434319327	5695	Economy	14400.00
0005434319320	5695	Economy	14400.00
0005434319316	5695	Economy	14400.00
0005433123619	5695	Economy	14400.00
0005434319312	5695	Economy	14400.00
0005434319318	5695	Economy	14400.00
0005433123658	5695	Economy	14400.00
0005432109688	5695	Economy	14400.00
0005433123620	5695	Economy	14400.00
0005433123635	5695	Economy	14400.00
0005433123685	5695	Economy	14400.00
0005434319322	5695	Economy	14400.00
0005434319326	5695	Economy	14400.00
0005433123634	5695	Economy	14400.00
0005433123660	5695	Economy	14400.00
0005434319315	5695	Economy	14400.00
0005433123603	5695	Economy	14400.00
0005434319314	5695	Economy	14400.00
0005433123831	15650	Business	43300.00
0005433123838	15650	Business	43300.00
0005433123840	15650	Business	43300.00
0005434319231	15650	Business	43300.00
0005434312294	15650	Economy	14400.00
0005434319167	15650	Economy	14400.00
0005434319155	15650	Economy	14400.00
0005433123835	15650	Economy	14400.00
0005434319164	15650	Economy	14400.00
0005434312290	15650	Economy	14400.00
0005434319170	15650	Economy	14400.00
0005433123834	15650	Economy	14400.00
0005433123842	15650	Economy	14400.00
0005434319156	15650	Economy	14400.00
0005433123832	15650	Economy	14400.00
0005433123833	15650	Economy	14400.00
0005434319166	15650	Economy	14400.00
0005434312284	15650	Economy	14400.00
0005434319189	15650	Economy	14400.00
0005433123837	15650	Economy	14400.00
0005433123827	15650	Economy	14400.00
0005434312289	15650	Economy	14400.00
0005433123828	15650	Economy	14400.00
0005433123829	15650	Economy	14400.00
0005433123830	15650	Economy	14400.00
0005433123839	15650	Economy	14400.00
0005434311186	15650	Economy	14400.00
0005434311187	15650	Economy	14400.00
0005433123836	15650	Economy	14400.00
0005434319210	15650	Economy	14400.00
0005433123843	15650	Economy	14400.00
0005434319171	15650	Economy	14400.00
0005433123841	15650	Economy	14400.00
0005434484315	8977	Economy	27400.00
0005434484316	8977	Economy	24900.00
0005434189105	8977	Economy	24900.00
0005434189110	8977	Economy	24900.00
0005434484319	8977	Economy	24900.00
0005434189102	8977	Economy	24900.00
0005434484318	8977	Economy	24900.00
0005434484312	8977	Economy	24900.00
0005434484313	8977	Economy	24900.00
0005434484314	8977	Economy	24900.00
0005434189087	8977	Economy	24900.00
0005434484317	8977	Economy	24900.00
0005434189092	8977	Economy	24900.00
0005434484264	16648	Economy	27400.00
0005434189151	16648	Economy	24900.00
0005434189150	16648	Economy	24900.00
0005434484276	16648	Economy	24900.00
0005434484282	16648	Economy	24900.00
0005434189148	16648	Economy	24900.00
0005434189147	16648	Economy	24900.00
0005434484261	16648	Economy	24900.00
0005434189149	16648	Economy	24900.00
0005434484240	16648	Economy	24900.00
0005434484241	16648	Economy	24900.00
0005434484236	16648	Economy	24900.00
0005434189152	16648	Economy	24900.00
0005433123838	7670	Business	11100.00
0005433722105	7670	Business	11100.00
0005433123837	7670	Business	11100.00
0005433123834	7670	Economy	3700.00
0005433722124	7670	Economy	3700.00
0005433722110	7670	Economy	3700.00
0005433123839	7670	Economy	3700.00
0005433123835	7670	Economy	3700.00
0005433722130	7670	Economy	3700.00
0005433123833	7670	Economy	3700.00
0005433123836	7670	Economy	3700.00
0005433123828	7670	Economy	3700.00
0005433123831	7670	Economy	3700.00
0005433722111	7670	Economy	3700.00
0005433722117	7670	Economy	3700.00
0005433123843	7670	Economy	3700.00
0005433123832	7670	Economy	3700.00
0005433722112	7670	Economy	3700.00
0005433722120	7670	Economy	3700.00
0005433123829	7670	Economy	3700.00
0005433123830	7670	Economy	3700.00
0005433123827	7670	Economy	3700.00
0005433123841	7670	Economy	3700.00
0005433123840	7670	Economy	3700.00
0005433123842	7670	Economy	3700.00
0005433722107	7670	Economy	3700.00
0005433722109	7670	Economy	3700.00
0005432692924	7666	Business	11100.00
0005432692912	7666	Business	11100.00
0005433449872	7666	Business	11100.00
0005433449852	7666	Business	11100.00
0005432071558	7666	Business	11100.00
0005433449868	7666	Business	11100.00
0005432692923	7666	Business	11100.00
0005432720763	7666	Business	11100.00
0005432692907	7666	Business	11100.00
0005432692933	7666	Business	11100.00
0005432692909	7666	Business	11100.00
0005433449870	7666	Economy	3700.00
0005432720769	7666	Economy	3700.00
0005432720778	7666	Economy	3700.00
0005432720758	7666	Economy	3700.00
0005432720762	7666	Economy	3700.00
0005432720780	7666	Economy	3700.00
0005433449853	7666	Economy	3700.00
0005432720760	7666	Economy	3700.00
0005432720771	7666	Economy	3700.00
0005433449865	7666	Economy	4100.00
0005433449861	7666	Economy	4100.00
0005433449859	7666	Economy	4100.00
0005432692922	7666	Economy	4100.00
0005432692932	7666	Economy	4100.00
0005432692920	7666	Economy	3700.00
0005432692913	7666	Economy	3700.00
0005432720761	7666	Economy	3700.00
0005433449864	7666	Economy	3700.00
0005432720766	7666	Economy	3700.00
0005433449860	7666	Economy	3700.00
0005432720764	7666	Economy	3700.00
0005432692925	7666	Economy	3700.00
0005433449866	7666	Economy	3700.00
0005433449862	7666	Economy	3700.00
0005433449857	7666	Economy	3700.00
0005432720784	7666	Economy	3700.00
0005433449863	7666	Economy	3700.00
0005432720782	7666	Economy	3700.00
0005432692935	7666	Economy	3700.00
0005432720775	7666	Economy	3700.00
0005432692906	7666	Economy	3700.00
0005432692911	7666	Economy	3700.00
0005432692931	7666	Economy	3700.00
0005433449858	7666	Economy	3700.00
0005432692926	7666	Economy	3700.00
0005432692936	7666	Economy	3700.00
0005432720759	7666	Economy	3700.00
0005432720767	7666	Economy	3700.00
0005432720770	7666	Economy	3700.00
0005432720774	7666	Economy	3700.00
0005433449855	7666	Economy	3700.00
0005432692916	7666	Economy	3700.00
0005433449871	7666	Economy	3700.00
0005432692918	7666	Economy	3700.00
0005432692914	7666	Economy	3700.00
0005432692928	7666	Economy	3700.00
0005432692927	7666	Economy	3700.00
0005432720781	7666	Economy	3700.00
0005432720783	7666	Economy	3700.00
0005432720773	7666	Economy	3700.00
0005432692919	7666	Economy	3700.00
0005433449851	7666	Economy	3700.00
0005432692915	7666	Economy	3700.00
0005432720779	7666	Economy	3700.00
0005432720765	7666	Economy	3700.00
0005433449854	7666	Economy	3700.00
0005432720776	7666	Economy	3700.00
0005433449856	7666	Economy	3700.00
0005432692910	7666	Economy	3700.00
0005432692930	7666	Economy	3700.00
0005432720777	7666	Economy	3700.00
0005432071559	7666	Economy	3700.00
0005432720772	7666	Economy	3700.00
0005432692908	7666	Economy	3700.00
0005433449867	7666	Economy	3700.00
0005432692921	7666	Economy	3700.00
0005432692934	7666	Economy	3700.00
0005432692917	7666	Economy	3700.00
0005432720768	7666	Economy	3700.00
0005433449869	7666	Economy	3700.00
0005432692929	7666	Economy	3700.00
0005432692676	30349	Business	11100.00
0005433449656	30349	Business	11100.00
0005432692672	30349	Business	11100.00
0005433449745	30349	Business	11100.00
0005432692599	30349	Business	11100.00
0005432692540	30349	Economy	3700.00
0005432692600	30349	Economy	3700.00
0005432692679	30349	Economy	3700.00
0005432692706	30349	Economy	3700.00
0005433449608	30349	Economy	3700.00
0005433449625	30349	Economy	4100.00
0005433449734	30349	Economy	4100.00
0005433449677	30349	Economy	4100.00
0005432692735	30349	Economy	4100.00
0005432692711	30349	Economy	4100.00
0005433449809	30349	Economy	3700.00
0005432692548	30349	Economy	3700.00
0005433449654	30349	Economy	3700.00
0005432692668	30349	Economy	3700.00
0005432692690	30349	Economy	3700.00
0005432692677	30349	Economy	3700.00
0005433449624	30349	Economy	3700.00
0005432692587	30349	Economy	3700.00
0005432692720	30349	Economy	3700.00
0005433449658	30349	Economy	3700.00
0005432692588	30349	Economy	3700.00
0005433449671	30349	Economy	3700.00
0005433449746	30349	Economy	3700.00
0005432692619	30349	Economy	3700.00
0005433449731	30349	Economy	3700.00
0005432692549	30349	Economy	3700.00
0005433449631	30349	Economy	3700.00
0005432692678	30349	Economy	3700.00
0005433449640	30349	Economy	3700.00
0005433449674	30349	Economy	3700.00
0005432692667	30349	Economy	3700.00
0005432692689	30349	Economy	3700.00
0005433449655	30349	Economy	3700.00
0005432692614	30349	Economy	3700.00
0005433449641	30349	Economy	3700.00
0005432692704	30349	Economy	3700.00
0005433449732	30349	Economy	3700.00
0005433449626	30349	Economy	3700.00
0005433449638	30349	Economy	3700.00
0005432692803	30349	Economy	3700.00
0005433449630	30349	Economy	3700.00
0005433449675	30349	Economy	3700.00
0005432692550	30349	Economy	3700.00
0005433449676	30349	Economy	3700.00
0005432692602	30349	Economy	3700.00
0005433449680	30349	Economy	3700.00
0005432692719	30349	Economy	3700.00
0005432692736	30349	Economy	3700.00
0005433449735	30349	Economy	3700.00
0005432692673	30349	Economy	3700.00
0005433123603	30348	Business	11100.00
0005432720598	30348	Business	11100.00
0005432720488	30348	Business	11100.00
0005433123685	30348	Business	11100.00
0005433123645	30348	Business	11100.00
0005432720444	30348	Economy	3700.00
0005433123618	30348	Economy	3700.00
0005433123615	30348	Economy	3700.00
0005433722191	30348	Economy	3700.00
0005432720487	30348	Economy	3700.00
0005433722196	30348	Economy	3700.00
0005433722194	30348	Economy	3700.00
0005433123684	30348	Economy	3700.00
0005432720445	30348	Economy	3700.00
0005432720625	30348	Economy	4100.00
0005432720522	30348	Economy	4100.00
0005432720509	30348	Economy	4100.00
0005433123621	30348	Economy	3700.00
0005432720510	30348	Economy	3700.00
0005433722193	30348	Economy	3700.00
0005432720639	30348	Economy	3700.00
0005432720554	30348	Economy	3700.00
0005432720513	30348	Economy	3700.00
0005432720647	30348	Economy	3700.00
0005432720556	30348	Economy	3700.00
0005433123660	30348	Economy	3700.00
0005432720634	30348	Economy	3700.00
0005432720443	30348	Economy	3700.00
0005432720479	30348	Economy	3700.00
0005433123658	30348	Economy	3700.00
0005433722189	30348	Economy	3700.00
0005433722187	30348	Economy	3700.00
0005432720570	30348	Economy	3700.00
0005433722195	30348	Economy	3700.00
0005433123611	30348	Economy	3700.00
0005432720565	30348	Economy	3700.00
0005432720503	30348	Economy	3700.00
0005432720564	30348	Economy	3700.00
0005432720590	30348	Economy	3700.00
0005432720696	30348	Economy	3700.00
0005432720515	30348	Economy	3700.00
0005432720648	30348	Economy	3700.00
0005432720633	30348	Economy	3700.00
0005432720502	30348	Economy	3700.00
0005432720698	30348	Economy	3700.00
0005433722192	30348	Economy	3700.00
0005433123619	30348	Economy	3700.00
0005432720697	30348	Economy	3700.00
0005432720521	30348	Economy	3700.00
0005432720566	30348	Economy	3700.00
0005432720472	30348	Economy	3700.00
0005433722188	30348	Economy	3700.00
0005432720542	30348	Economy	3700.00
0005432720520	30348	Economy	3700.00
0005432720577	30348	Economy	3700.00
0005432720557	30348	Economy	3700.00
0005433123650	30348	Economy	3700.00
0005433722190	30348	Economy	3700.00
0005432720498	30348	Economy	3700.00
0005432720610	30348	Economy	3700.00
0005433123635	30348	Economy	3700.00
0005432720578	30348	Economy	3700.00
0005433123634	30348	Economy	3700.00
0005432720555	30348	Economy	3700.00
0005432720543	30348	Economy	3700.00
0005433123620	30348	Economy	3700.00
0005433192861	1367	Business	70400.00
0005434586489	1367	Business	70400.00
0005432270989	1367	Business	70400.00
0005434514954	1367	Business	70400.00
0005433524981	1367	Business	70400.00
0005434513568	1367	Business	70400.00
0005433192925	1367	Business	70400.00
0005434586472	1367	Business	70400.00
0005433524986	1367	Business	70400.00
0005434586487	1367	Business	70400.00
0005433192829	1367	Business	70400.00
0005434586490	1367	Economy	23500.00
0005434586494	1367	Economy	23500.00
0005433192892	1367	Economy	23500.00
0005434586491	1367	Economy	23500.00
0005434586495	1367	Economy	23500.00
0005433192856	1367	Economy	23500.00
0005434513565	1367	Economy	23500.00
0005432927915	1367	Economy	23500.00
0005433192855	1367	Economy	23500.00
0005434586473	1367	Economy	25800.00
0005433192891	1367	Economy	25800.00
0005433524983	1367	Economy	25800.00
0005433524987	1367	Economy	25800.00
0005433524982	1367	Economy	25800.00
0005432968808	1367	Economy	23500.00
0005433524989	1367	Economy	23500.00
0005434586478	1367	Economy	23500.00
0005433192851	1367	Economy	23500.00
0005434586477	1367	Economy	23500.00
0005433192816	1367	Economy	23500.00
0005432927950	1367	Economy	23500.00
0005432270991	1367	Economy	23500.00
0005434586499	1367	Economy	23500.00
0005434586481	1367	Economy	23500.00
0005433192926	1367	Economy	23500.00
0005433192942	1367	Economy	23500.00
0005432927914	1367	Economy	23500.00
0005434586476	1367	Economy	23500.00
0005434586486	1367	Economy	23500.00
0005432968809	1367	Economy	23500.00
0005434586479	1367	Economy	23500.00
0005433192866	1367	Economy	23500.00
0005432927917	1367	Economy	23500.00
0005434514956	1367	Economy	23500.00
0005434586498	1367	Economy	23500.00
0005433724782	1367	Economy	23500.00
0005434586497	1367	Economy	23500.00
0005432927916	1367	Economy	23500.00
0005432927909	1367	Economy	23500.00
0005434586484	1367	Economy	23500.00
0005432927924	1367	Economy	23500.00
0005432927923	1367	Economy	23500.00
0005433524980	1367	Economy	23500.00
0005433192924	1367	Economy	23500.00
0005433724785	1367	Economy	23500.00
0005433524985	1367	Economy	23500.00
0005434513567	1367	Economy	23500.00
0005434586496	1367	Economy	23500.00
0005433524984	1367	Economy	23500.00
0005433192879	1367	Economy	23500.00
0005434586474	1367	Economy	23500.00
0005432927922	1367	Economy	23500.00
0005434586480	1367	Economy	23500.00
0005432968805	1367	Economy	23500.00
0005432270990	1367	Economy	23500.00
0005434586492	1367	Economy	23500.00
0005433192817	1367	Economy	23500.00
0005432968804	1367	Economy	23500.00
0005434513566	1367	Economy	23500.00
0005433524988	1367	Economy	23500.00
0005434514955	1367	Economy	23500.00
0005433724786	1367	Economy	23500.00
0005434586493	1367	Economy	23500.00
0005432927888	1367	Economy	23500.00
0005434586485	1367	Economy	23500.00
0005434586488	1367	Economy	23500.00
0005434586483	1367	Economy	23500.00
0005433192828	1367	Economy	23500.00
0005433724784	1367	Economy	23500.00
0005433724783	1367	Economy	23500.00
0005433524990	1367	Economy	23500.00
0005434586475	1367	Economy	23500.00
0005434586482	1367	Economy	23500.00
0005433524979	1367	Economy	23500.00
0005433524890	18505	Business	70400.00
0005433192974	18505	Business	70400.00
0005434586210	18505	Business	70400.00
0005433192976	18505	Business	70400.00
0005433524847	18505	Business	70400.00
0005433724740	18505	Economy	23500.00
0005434586253	18505	Economy	23500.00
0005432968827	18505	Economy	23500.00
0005434586322	18505	Economy	23500.00
0005433524918	18505	Economy	23500.00
0005433192985	18505	Economy	23500.00
0005433192984	18505	Economy	23500.00
0005433524891	18505	Economy	25800.00
0005433724736	18505	Economy	25800.00
0005432927951	18505	Economy	25800.00
0005433524917	18505	Economy	23500.00
0005433724724	18505	Economy	23500.00
0005434586290	18505	Economy	23500.00
0005433192980	18505	Economy	23500.00
0005433192978	18505	Economy	23500.00
0005434586158	18505	Economy	23500.00
0005432927949	18505	Economy	23500.00
0005434586292	18505	Economy	23500.00
0005434586197	18505	Economy	23500.00
0005433192981	18505	Economy	23500.00
0005434586356	18505	Economy	23500.00
0005434586219	18505	Economy	23500.00
0005433524851	18505	Economy	23500.00
0005432927952	18505	Economy	23500.00
0005433192975	18505	Economy	23500.00
0005433524903	18505	Economy	23500.00
0005433192982	18505	Economy	23500.00
0005433192973	18505	Economy	23500.00
0005434586257	18505	Economy	23500.00
0005433524877	18505	Economy	23500.00
0005434586313	18505	Economy	23500.00
0005434586256	18505	Economy	23500.00
0005434586269	18505	Economy	23500.00
0005434586263	18505	Economy	23500.00
0005433192979	18505	Economy	23500.00
0005432968828	18505	Economy	23500.00
0005434586319	18505	Economy	23500.00
0005433192977	18505	Economy	23500.00
0005433192983	18505	Economy	23500.00
0005432927950	18505	Economy	23500.00
0005432968829	18505	Economy	23500.00
0005434586323	18505	Economy	23500.00
0005433524866	18505	Economy	23500.00
0005434586211	18505	Economy	23500.00
0005433524876	18505	Economy	23500.00
0005434586328	18505	Economy	23500.00
0005433192986	18505	Economy	23500.00
0005432927953	18505	Economy	23500.00
0005433524848	18505	Economy	23500.00
0005434586289	18505	Economy	23500.00
0005434586232	18505	Economy	23500.00
0005434586360	18505	Economy	23500.00
0005434586252	18505	Economy	23500.00
0005434586291	18505	Economy	23500.00
0005434343997	11469	Economy	4300.00
0005434343999	11469	Economy	4300.00
0005434344018	11469	Economy	4300.00
0005434344010	11469	Economy	4300.00
0005434344013	11469	Economy	4000.00
0005434344016	11469	Economy	4000.00
0005434343991	11469	Economy	4000.00
0005434142590	11469	Economy	4000.00
0005434343989	11469	Economy	4000.00
0005434343993	11469	Economy	4000.00
0005434142592	11469	Economy	4000.00
0005434344001	11469	Economy	4000.00
0005434343994	11469	Economy	4000.00
0005434343992	11469	Economy	4000.00
0005434344004	11469	Economy	4000.00
0005435302128	11469	Economy	4000.00
0005434344021	11469	Economy	4000.00
0005434344008	11469	Economy	4000.00
0005434343998	11469	Economy	4000.00
0005434344017	11469	Economy	4000.00
0005434343995	11469	Economy	4000.00
0005434344000	11469	Economy	4000.00
0005434344005	11469	Economy	4000.00
0005434344003	11469	Economy	4000.00
0005435304996	11469	Economy	4000.00
0005434344007	11469	Economy	4000.00
0005435302130	11469	Economy	4000.00
0005434343996	11469	Economy	4000.00
0005434344020	11469	Economy	4000.00
0005434344022	11469	Economy	4000.00
0005434344002	11469	Economy	4000.00
0005434344023	11469	Economy	4000.00
0005434344006	11469	Economy	4000.00
0005435302129	11469	Economy	4000.00
0005434344012	11469	Economy	4000.00
0005434142591	11469	Economy	4000.00
0005434344015	11469	Economy	4000.00
0005434344014	11469	Economy	4000.00
0005434344009	11469	Economy	4000.00
0005434142589	11469	Economy	4000.00
0005434344011	11469	Economy	4000.00
0005434343988	11469	Economy	4000.00
0005434344019	11469	Economy	4000.00
0005435304989	11469	Economy	4000.00
0005434343990	11469	Economy	4000.00
0005434343917	29765	Economy	4300.00
0005434343655	29765	Economy	4300.00
0005434343635	29765	Economy	4300.00
0005434343716	29765	Economy	4300.00
0005434343695	29765	Economy	4000.00
0005434343613	29765	Economy	4000.00
0005434343595	29765	Economy	4000.00
0005434343760	29765	Economy	4000.00
0005435304138	29765	Economy	4000.00
0005434343636	29765	Economy	4000.00
0005434343685	29765	Economy	4000.00
0005434343637	29765	Economy	4000.00
0005434343639	29765	Economy	4000.00
0005434343585	29765	Economy	4000.00
0005434343690	29765	Economy	4000.00
0005434343627	29765	Economy	4000.00
0005434343715	29765	Economy	4000.00
0005434343612	29765	Economy	4000.00
0005434343761	29765	Economy	4000.00
0005434343675	29765	Economy	4000.00
0005434343625	29765	Economy	4000.00
0005434343674	29765	Economy	4000.00
0005434343708	29765	Economy	4000.00
0005434343701	29765	Economy	4000.00
0005434343889	29765	Economy	4000.00
0005434343638	29765	Economy	4000.00
0005435304137	29765	Economy	4000.00
0005434343634	29765	Economy	4000.00
0005434343773	29765	Economy	4000.00
0005434142548	29765	Economy	4000.00
0005434343720	29765	Economy	4000.00
0005434343626	29765	Economy	4000.00
0005434343617	29765	Economy	4000.00
0005434343741	29765	Economy	4000.00
0005434343614	29765	Economy	4000.00
0005434343620	29765	Economy	4000.00
0005434343831	29765	Economy	4000.00
0005434343644	29765	Economy	4000.00
0005434343721	29765	Economy	4000.00
0005434343772	29765	Economy	4000.00
0005434343633	29765	Economy	4000.00
0005434343586	29765	Economy	4000.00
0005434343888	29765	Economy	4000.00
0005434343643	29765	Economy	4000.00
0005434343596	29765	Economy	4000.00
0005434343656	29765	Economy	4000.00
0005434343757	29765	Economy	4000.00
0005433415459	1255	Business	199800.00
0005433415471	1255	Business	199800.00
0005435824505	1255	Business	199800.00
0005433415516	1255	Business	199800.00
0005435824490	1255	Business	199800.00
0005433415450	1255	Business	199800.00
0005432284543	1255	Business	199800.00
0005435824492	1255	Business	199800.00
0005435824491	1255	Business	199800.00
0005435824498	1255	Economy	66600.00
0005435824503	1255	Economy	66600.00
0005433415485	1255	Economy	66600.00
0005433415467	1255	Economy	66600.00
0005435824494	1255	Economy	66600.00
0005435824502	1255	Economy	66600.00
0005435824495	1255	Economy	66600.00
0005433415468	1255	Economy	66600.00
0005435824485	1255	Economy	66600.00
0005435824508	1255	Economy	66600.00
0005433415507	1255	Economy	66600.00
0005435824496	1255	Economy	66600.00
0005435824500	1255	Economy	66600.00
0005433415472	1255	Economy	66600.00
0005432284544	1255	Economy	66600.00
0005435824506	1255	Economy	66600.00
0005435824504	1255	Economy	66600.00
0005433415421	1255	Economy	66600.00
0005435824497	1255	Economy	66600.00
0005432284545	1255	Economy	66600.00
0005435824493	1255	Economy	66600.00
0005433415446	1255	Economy	66600.00
0005435824487	1255	Economy	66600.00
0005435824488	1255	Economy	66600.00
0005433415455	1255	Economy	66600.00
0005435824486	1255	Economy	66600.00
0005435824483	1255	Economy	66600.00
0005435824482	1255	Economy	66600.00
0005433415413	1255	Economy	66600.00
0005433415449	1255	Economy	66600.00
0005433415447	1255	Economy	66600.00
0005433415422	1255	Economy	66600.00
0005435824484	1255	Economy	66600.00
0005433415466	1255	Economy	66600.00
0005435824489	1255	Economy	66600.00
0005435824507	1255	Economy	66600.00
0005435824499	1255	Economy	66600.00
0005433415508	1255	Economy	66600.00
0005435824501	1255	Economy	66600.00
0005433415448	1255	Economy	66600.00
0005433415477	1255	Economy	66600.00
0005435824321	17973	Business	199800.00
0005435824287	17973	Business	199800.00
0005435824232	17973	Business	199800.00
0005433415576	17973	Business	199800.00
0005433415580	17973	Business	199800.00
0005435824249	17973	Economy	66600.00
0005435824306	17973	Economy	66600.00
0005435824245	17973	Economy	73200.00
0005435824326	17973	Economy	73200.00
0005433415588	17973	Economy	73200.00
0005435824188	17973	Economy	73200.00
0005435824250	17973	Economy	66600.00
0005435824303	17973	Economy	66600.00
0005435824221	17973	Economy	66600.00
0005433415575	17973	Economy	66600.00
0005433415587	17973	Economy	66600.00
0005435824310	17973	Economy	66600.00
0005433415583	17973	Economy	66600.00
0005435824175	17973	Economy	66600.00
0005433415589	17973	Economy	66600.00
0005433415577	17973	Economy	66600.00
0005435824327	17973	Economy	66600.00
0005433415586	17973	Economy	66600.00
0005435824154	17973	Economy	66600.00
0005433415585	17973	Economy	66600.00
0005433415584	17973	Economy	66600.00
0005435824361	17973	Economy	66600.00
0005435824282	17973	Economy	66600.00
0005435824380	17973	Economy	66600.00
0005435824212	17973	Economy	66600.00
0005433415581	17973	Economy	66600.00
0005433415582	17973	Economy	66600.00
0005435824302	17973	Economy	66600.00
0005433415578	17973	Economy	66600.00
0005435824153	17973	Economy	66600.00
0005433415590	17973	Economy	66600.00
0005435824241	17973	Economy	66600.00
0005433415579	17973	Economy	66600.00
0005435824189	17973	Economy	66600.00
0005435824360	17973	Economy	66600.00
0005434461631	12566	Economy	14800.00
0005434460494	12566	Economy	14800.00
0005434460493	12566	Economy	13500.00
0005434461632	12566	Economy	13500.00
0005434461633	12566	Economy	13500.00
0005434460486	12566	Economy	13500.00
0005434460492	12566	Economy	13500.00
0005434460491	12566	Economy	13500.00
0005434461628	12566	Economy	13500.00
0005434460487	12566	Economy	13500.00
0005434460488	12566	Economy	13500.00
0005434460490	12566	Economy	13500.00
0005434460485	12566	Economy	13500.00
0005434461629	12566	Economy	13500.00
0005434460484	12566	Economy	13500.00
0005434460489	12566	Economy	13500.00
0005434461634	12566	Economy	13500.00
0005434461630	12566	Economy	13500.00
0005432783508	5667	Business	27800.00
0005432783540	5667	Business	27800.00
0005432783499	5667	Business	27800.00
0005432783505	5667	Business	27800.00
0005435242426	5667	Business	27800.00
0005432783536	5667	Business	27800.00
0005432783546	5667	Business	27800.00
0005432783523	5667	Business	27800.00
0005432783515	5667	Business	27800.00
0005432783550	5667	Business	27800.00
0005432783513	5667	Business	27800.00
0005435242527	5667	Economy	9300.00
0005432783500	5667	Economy	9300.00
0005432783541	5667	Economy	9300.00
0005435242487	5667	Economy	9300.00
0005432783528	5667	Economy	9300.00
0005435476639	5667	Economy	9300.00
0005432783532	5667	Economy	9300.00
0005432783514	5667	Economy	9300.00
0005432783521	5667	Economy	9300.00
0005435242469	5667	Economy	10200.00
0005432783526	5667	Economy	10200.00
0005435242494	5667	Economy	10200.00
0005432783542	5667	Economy	10200.00
0005435242421	5667	Economy	10200.00
0005432143971	5667	Economy	9300.00
0005435242444	5667	Economy	9300.00
0005432783504	5667	Economy	9300.00
0005435242434	5667	Economy	9300.00
0005435242455	5667	Economy	9300.00
0005432783529	5667	Economy	9300.00
0005435242501	5667	Economy	9300.00
0005432783553	5667	Economy	9300.00
0005435242610	5667	Economy	9300.00
0005432783538	5667	Economy	9300.00
0005432783537	5667	Economy	9300.00
0005432783512	5667	Economy	9300.00
0005432783535	5667	Economy	9300.00
0005432783506	5667	Economy	9300.00
0005435242609	5667	Economy	9300.00
0005432783533	5667	Economy	9300.00
0005432783502	5667	Economy	9300.00
0005435242607	5667	Economy	9300.00
0005432783503	5667	Economy	9300.00
0005432143972	5667	Economy	9300.00
0005435242485	5667	Economy	9300.00
0005432783551	5667	Economy	9300.00
0005435242484	5667	Economy	9300.00
0005432783507	5667	Economy	9300.00
0005435242496	5667	Economy	9300.00
0005432143970	5667	Economy	9300.00
0005435242495	5667	Economy	9300.00
0005432783511	5667	Economy	9300.00
0005435242486	5667	Economy	9300.00
0005432783520	5667	Economy	9300.00
0005435242420	5667	Economy	9300.00
0005435242579	5667	Economy	9300.00
0005432783510	5667	Economy	9300.00
0005432783527	5667	Economy	9300.00
0005435242445	5667	Economy	9300.00
0005432783509	5667	Economy	9300.00
0005432783519	5667	Economy	9300.00
0005432783547	5667	Economy	9300.00
0005432783517	5667	Economy	9300.00
0005435476650	5667	Economy	9300.00
0005435242419	5667	Economy	9300.00
0005432783552	5667	Economy	9300.00
0005432783522	5667	Economy	9300.00
0005435476651	5667	Economy	9300.00
0005432783534	5667	Economy	9300.00
0005432783543	5667	Economy	9300.00
0005435476638	5667	Economy	9300.00
0005432783545	5667	Economy	9300.00
0005432783530	5667	Economy	9300.00
0005432783539	5667	Economy	9300.00
0005432783544	5667	Economy	9300.00
0005432783549	5667	Economy	9300.00
0005435242521	5667	Economy	9300.00
0005432783525	5667	Economy	9300.00
0005435242438	5667	Economy	9300.00
0005435242608	5667	Economy	9300.00
0005432783531	5667	Economy	9300.00
0005432783548	5667	Economy	9300.00
0005432783518	5667	Economy	9300.00
0005432783501	5667	Economy	9300.00
0005435242500	5667	Economy	9300.00
0005432783516	5667	Economy	9300.00
0005432783524	5667	Economy	9300.00
0005432782969	15350	Business	27800.00
0005435476726	15350	Business	27800.00
0005432783106	15350	Business	27800.00
0005432783094	15350	Business	27800.00
0005435476731	15350	Business	27800.00
0005432782957	15350	Business	27800.00
0005432783087	15350	Business	27800.00
0005432783093	15350	Business	27800.00
0005432783247	15350	Business	27800.00
0005432782896	15350	Business	27800.00
0005435476730	15350	Business	27800.00
0005432783047	15350	Economy	9300.00
0005432783134	15350	Economy	9300.00
0005435242698	15350	Economy	9300.00
0005435476727	15350	Economy	9300.00
0005435476724	15350	Economy	9300.00
0005432783013	15350	Economy	9300.00
0005432782937	15350	Economy	9300.00
0005435242705	15350	Economy	10200.00
0005435242700	15350	Economy	10200.00
0005435242697	15350	Economy	10200.00
0005435242708	15350	Economy	10200.00
0005432782852	15350	Economy	10200.00
0005435242695	15350	Economy	9300.00
0005435242706	15350	Economy	9300.00
0005435476722	15350	Economy	9300.00
0005435242702	15350	Economy	9300.00
0005435476721	15350	Economy	9300.00
0005435242696	15350	Economy	9300.00
0005435242717	15350	Economy	9300.00
0005435242712	15350	Economy	9300.00
0005432783016	15350	Economy	9300.00
0005432783201	15350	Economy	9300.00
0005435242704	15350	Economy	9300.00
0005435242707	15350	Economy	9300.00
0005432782941	15350	Economy	9300.00
0005435242692	15350	Economy	9300.00
0005432783023	15350	Economy	9300.00
0005432783051	15350	Economy	9300.00
0005435242714	15350	Economy	9300.00
0005432783098	15350	Economy	9300.00
0005435242718	15350	Economy	9300.00
0005435242713	15350	Economy	9300.00
0005435242716	15350	Economy	9300.00
0005435476720	15350	Economy	9300.00
0005432782970	15350	Economy	9300.00
0005432782950	15350	Economy	9300.00
0005435242694	15350	Economy	9300.00
0005435242710	15350	Economy	9300.00
0005435242699	15350	Economy	9300.00
0005432783108	15350	Economy	9300.00
0005432782954	15350	Economy	9300.00
0005432782897	15350	Economy	9300.00
0005432782951	15350	Economy	9300.00
0005432783046	15350	Economy	9300.00
0005435242701	15350	Economy	9300.00
0005435242693	15350	Economy	9300.00
0005435242719	15350	Economy	9300.00
0005432783052	15350	Economy	9300.00
0005432783077	15350	Economy	9300.00
0005432783068	15350	Economy	9300.00
0005435242703	15350	Economy	9300.00
0005432783041	15350	Economy	9300.00
0005435476728	15350	Economy	9300.00
0005435242711	15350	Economy	9300.00
0005432782917	15350	Economy	9300.00
0005432783069	15350	Economy	9300.00
0005432782959	15350	Economy	9300.00
0005432782940	15350	Economy	9300.00
0005432782949	15350	Economy	9300.00
0005435242709	15350	Economy	9300.00
0005432782842	15350	Economy	9300.00
0005435476729	15350	Economy	9300.00
0005432783025	15350	Economy	9300.00
0005435242715	15350	Economy	9300.00
0005435476723	15350	Economy	9300.00
0005435476725	15350	Economy	9300.00
0005432783164	15350	Economy	9300.00
0005432783099	15350	Economy	9300.00
0005435850783	4368	Economy	7000.00
0005435850792	4368	Economy	7000.00
0005434462780	4368	Economy	6300.00
0005432848242	4368	Economy	6300.00
0005432848244	4368	Economy	6300.00
0005432848234	4368	Economy	6300.00
0005432848246	4368	Economy	6300.00
0005432848235	4368	Economy	6300.00
0005435850768	4368	Economy	6300.00
0005432848239	4368	Economy	6300.00
0005432848236	4368	Economy	6300.00
0005434463919	4368	Economy	6300.00
0005435850805	4368	Economy	6300.00
0005435850828	4368	Economy	6300.00
0005432848247	4368	Economy	6300.00
0005432848233	4368	Economy	6300.00
0005435850810	4368	Economy	6300.00
0005435850829	4368	Economy	6300.00
0005432848237	4368	Economy	6300.00
0005432848245	4368	Economy	6300.00
0005435850821	4368	Economy	6300.00
0005435850791	4368	Economy	6300.00
0005432848240	4368	Economy	6300.00
0005435850798	4368	Economy	6300.00
0005435850794	4368	Economy	6300.00
0005432848243	4368	Economy	6300.00
0005434463918	4368	Economy	6300.00
0005432848241	4368	Economy	6300.00
0005432848238	4368	Economy	6300.00
0005435850817	4368	Economy	6300.00
0005434461620	28834	Economy	7000.00
0005435850868	28834	Economy	7000.00
0005432848079	28834	Economy	6300.00
0005432848100	28834	Economy	6300.00
0005435850867	28834	Economy	6300.00
0005432848113	28834	Economy	6300.00
0005435850860	28834	Economy	6300.00
0005435850866	28834	Economy	6300.00
0005435850864	28834	Economy	6300.00
0005432848126	28834	Economy	6300.00
0005434463900	28834	Economy	6300.00
0005434461612	28834	Economy	6300.00
0005432848142	28834	Economy	6300.00
0005434463898	28834	Economy	6300.00
0005435850862	28834	Economy	6300.00
0005435850863	28834	Economy	6300.00
0005434461613	28834	Economy	6300.00
0005435850869	28834	Economy	6300.00
0005434461618	28834	Economy	6300.00
0005432848138	28834	Economy	6300.00
0005434463896	28834	Economy	6300.00
0005432848127	28834	Economy	6300.00
0005432848130	28834	Economy	6300.00
0005435850865	28834	Economy	6300.00
0005434461619	28834	Economy	6300.00
0005435850861	28834	Economy	6300.00
0005434463897	28834	Economy	6300.00
0005432848150	28834	Economy	6300.00
0005432848148	28834	Economy	6300.00
0005432848149	28834	Economy	6300.00
0005433496834	6299	Business	11900.00
0005434443622	6299	Business	11900.00
0005434925654	6299	Business	11900.00
0005434925676	6299	Business	11900.00
0005433496830	6299	Business	11900.00
0005433496820	6299	Business	11900.00
0005434925653	6299	Business	11900.00
0005434925671	6299	Business	11900.00
0005434925673	6299	Business	11900.00
0005433496821	6299	Economy	4000.00
0005433496812	6299	Economy	4000.00
0005433496803	6299	Economy	4000.00
0005434443628	6299	Economy	4000.00
0005434925664	6299	Economy	4000.00
0005434443631	6299	Economy	4000.00
0005433496824	6299	Economy	4000.00
0005434925657	6299	Economy	4000.00
0005434925652	6299	Economy	4000.00
0005434443624	6299	Economy	4400.00
0005434925660	6299	Economy	4400.00
0005434443637	6299	Economy	4400.00
0005434925674	6299	Economy	4400.00
0005433496831	6299	Economy	4400.00
0005434925667	6299	Economy	4000.00
0005434925656	6299	Economy	4000.00
0005433496826	6299	Economy	4000.00
0005434443629	6299	Economy	4000.00
0005434925675	6299	Economy	4000.00
0005433496810	6299	Economy	4000.00
0005432075214	6299	Economy	4000.00
0005433496817	6299	Economy	4000.00
0005433496815	6299	Economy	4000.00
0005433496819	6299	Economy	4000.00
0005434443626	6299	Economy	4000.00
0005434443625	6299	Economy	4000.00
0005434925661	6299	Economy	4000.00
0005433496813	6299	Economy	4000.00
0005433496829	6299	Economy	4000.00
0005434443635	6299	Economy	4000.00
0005434443634	6299	Economy	4000.00
0005433496809	6299	Economy	4000.00
0005434925668	6299	Economy	4000.00
0005434443630	6299	Economy	4000.00
0005433496811	6299	Economy	4000.00
0005434443636	6299	Economy	4000.00
0005434925670	6299	Economy	4000.00
0005434443627	6299	Economy	4000.00
0005432075213	6299	Economy	4000.00
0005434925659	6299	Economy	4000.00
0005434925658	6299	Economy	4000.00
0005433496832	6299	Economy	4000.00
0005433496807	6299	Economy	4000.00
0005433496833	6299	Economy	4000.00
0005432075212	6299	Economy	4000.00
0005434925663	6299	Economy	4000.00
0005433496814	6299	Economy	4000.00
0005432075211	6299	Economy	4000.00
0005434443632	6299	Economy	4000.00
0005433496828	6299	Economy	4000.00
0005433496806	6299	Economy	4000.00
0005433496823	6299	Economy	4000.00
0005433496805	6299	Economy	4000.00
0005434925666	6299	Economy	4000.00
0005434925672	6299	Economy	4000.00
0005433496825	6299	Economy	4000.00
0005434925655	6299	Economy	4000.00
0005433496804	6299	Economy	4000.00
0005434443623	6299	Economy	4000.00
0005434925677	6299	Economy	4000.00
0005433496816	6299	Economy	4000.00
0005433496818	6299	Economy	4000.00
0005434443633	6299	Economy	4000.00
0005434925665	6299	Economy	4000.00
0005434925662	6299	Economy	4000.00
0005433496827	6299	Economy	4000.00
0005433496822	6299	Economy	4000.00
0005434925669	6299	Economy	4000.00
0005433496808	6299	Economy	4000.00
0005434925385	20317	Business	11900.00
0005434925275	20317	Business	11900.00
0005434443530	20317	Business	11900.00
0005433496738	20317	Business	11900.00
0005433496667	20317	Business	11900.00
0005434925378	20317	Business	11900.00
0005434925274	20317	Business	11900.00
0005434925349	20317	Business	11900.00
0005434925362	20317	Business	11900.00
0005434925347	20317	Business	11900.00
0005434925338	20317	Economy	4000.00
0005434925285	20317	Economy	4000.00
0005434443529	20317	Economy	4000.00
0005434925382	20317	Economy	4000.00
0005433496605	20317	Economy	4000.00
0005434925390	20317	Economy	4000.00
0005433496546	20317	Economy	4000.00
0005434443473	20317	Economy	4000.00
0005434443456	20317	Economy	4400.00
0005433496600	20317	Economy	4400.00
0005434925426	20317	Economy	4400.00
0005434925283	20317	Economy	4400.00
0005434925379	20317	Economy	4400.00
0005433496673	20317	Economy	4000.00
0005434925332	20317	Economy	4000.00
0005434925389	20317	Economy	4000.00
0005433496588	20317	Economy	4000.00
0005434925491	20317	Economy	4000.00
0005433496666	20317	Economy	4000.00
0005433496545	20317	Economy	4000.00
0005434925439	20317	Economy	4000.00
0005434925465	20317	Economy	4000.00
0005433496604	20317	Economy	4000.00
0005433496564	20317	Economy	4000.00
0005434443538	20317	Economy	4000.00
0005433496603	20317	Economy	4000.00
0005434443532	20317	Economy	4000.00
0005433496584	20317	Economy	4000.00
0005434443454	20317	Economy	4000.00
0005434925427	20317	Economy	4000.00
0005433496594	20317	Economy	4000.00
0005434925522	20317	Economy	4000.00
0005434443503	20317	Economy	4000.00
0005434925325	20317	Economy	4000.00
0005434925377	20317	Economy	4000.00
0005434443464	20317	Economy	4000.00
0005433496485	20317	Economy	4000.00
0005433496599	20317	Economy	4000.00
0005434443471	20317	Economy	4000.00
0005434925348	20317	Economy	4000.00
0005434925337	20317	Economy	4000.00
0005434925339	20317	Economy	4000.00
0005433496606	20317	Economy	4000.00
0005434443439	20317	Economy	4000.00
0005433496657	20317	Economy	4000.00
0005434443531	20317	Economy	4000.00
0005434925503	20317	Economy	4000.00
0005434925286	20317	Economy	4000.00
0005434925416	20317	Economy	4000.00
0005434925489	20317	Economy	4000.00
0005433496505	20317	Economy	4000.00
0005433496523	20317	Economy	4000.00
0005434925380	20317	Economy	4000.00
0005433496674	20317	Economy	4000.00
0005434443445	20317	Economy	4000.00
0005434925490	20317	Economy	4000.00
0005434925296	20317	Economy	4000.00
0005434925326	20317	Economy	4000.00
0005434443489	20317	Economy	4000.00
0005433496537	20317	Economy	4000.00
0005434925280	20317	Economy	4000.00
0005434925470	20317	Economy	4000.00
0005434443490	20317	Economy	4000.00
0005432782928	12188	Business	41200.00
0005435242723	12188	Business	41200.00
0005432782986	12188	Business	41200.00
0005435242730	12188	Business	41200.00
0005435242738	12188	Business	41200.00
0005435242733	12188	Business	41200.00
0005432783265	12188	Business	41200.00
0005432783320	12188	Business	41200.00
0005432783116	12188	Business	41200.00
0005435242725	12188	Business	41200.00
0005432783097	12188	Business	41200.00
0005432782926	12188	Business	41200.00
0005432782981	12188	Economy	13700.00
0005435242734	12188	Economy	13700.00
0005432783035	12188	Economy	13700.00
0005432782925	12188	Economy	13700.00
0005435242739	12188	Economy	13700.00
0005432783184	12188	Economy	13700.00
0005432783119	12188	Economy	13700.00
0005432783172	12188	Economy	13700.00
0005432783125	12188	Economy	13700.00
0005432783066	12188	Economy	13700.00
0005432782910	12188	Economy	15100.00
0005435242728	12188	Economy	15100.00
0005432782994	12188	Economy	15100.00
0005432783264	12188	Economy	15100.00
0005432783177	12188	Economy	15100.00
0005432783055	12188	Economy	13700.00
0005435242732	12188	Economy	13700.00
0005432783270	12188	Economy	13700.00
0005432782977	12188	Economy	13700.00
0005432782913	12188	Economy	13700.00
0005432782903	12188	Economy	13700.00
0005432782963	12188	Economy	13700.00
0005432783004	12188	Economy	13700.00
0005432783048	12188	Economy	13700.00
0005432782912	12188	Economy	13700.00
0005432783196	12188	Economy	13700.00
0005435242737	12188	Economy	13700.00
0005432783183	12188	Economy	13700.00
0005435242724	12188	Economy	13700.00
0005432783105	12188	Economy	13700.00
0005432783319	12188	Economy	13700.00
0005432782927	12188	Economy	13700.00
0005435242722	12188	Economy	13700.00
0005435242720	12188	Economy	13700.00
0005432783074	12188	Economy	13700.00
0005435242729	12188	Economy	13700.00
0005432783256	12188	Economy	13700.00
0005432782998	12188	Economy	13700.00
0005432782858	12188	Economy	13700.00
0005432783036	12188	Economy	13700.00
0005432783197	12188	Economy	13700.00
0005432782914	12188	Economy	13700.00
0005432783082	12188	Economy	13700.00
0005432782975	12188	Economy	13700.00
0005432783065	12188	Economy	13700.00
0005432783064	12188	Economy	13700.00
0005432782945	12188	Economy	13700.00
0005432782915	12188	Economy	13700.00
0005432782920	12188	Economy	13700.00
0005435242736	12188	Economy	13700.00
0005432782861	12188	Economy	13700.00
0005432782859	12188	Economy	13700.00
0005432783096	12188	Economy	13700.00
0005435242731	12188	Economy	13700.00
0005432782965	12188	Economy	13700.00
0005432782974	12188	Economy	13700.00
0005432782862	12188	Economy	13700.00
0005435242740	12188	Economy	13700.00
0005432783129	12188	Economy	13700.00
0005432782966	12188	Economy	13700.00
0005435242727	12188	Economy	13700.00
0005432783218	12188	Economy	13700.00
0005435242735	12188	Economy	13700.00
0005432782997	12188	Economy	13700.00
0005432783083	12188	Economy	13700.00
0005432782973	12188	Economy	13700.00
0005432783003	12188	Economy	13700.00
0005432782972	12188	Economy	13700.00
0005432783084	12188	Economy	13700.00
0005432783061	12188	Economy	13700.00
0005435242726	12188	Economy	13700.00
0005432783081	12188	Economy	13700.00
0005432783171	12188	Economy	13700.00
0005432783095	12188	Economy	13700.00
0005432783037	12188	Economy	13700.00
0005432783139	12188	Economy	13700.00
0005432783104	12188	Economy	13700.00
0005432783219	12188	Economy	13700.00
0005432783038	12188	Economy	13700.00
0005435242741	12188	Economy	13700.00
0005435242721	12188	Economy	13700.00
0005432783187	12188	Economy	13700.00
0005432782982	12188	Economy	13700.00
0005432783195	12188	Economy	13700.00
0005432782976	12188	Economy	13700.00
0005432783479	15415	Business	41200.00
0005432783463	15415	Business	41200.00
0005432783491	15415	Business	41200.00
0005435242406	15415	Business	41200.00
0005435242395	15415	Business	41200.00
0005432783455	15415	Business	41200.00
0005432783480	15415	Business	41200.00
0005432783476	15415	Business	41200.00
0005435242601	15415	Business	41200.00
0005435242471	15415	Business	41200.00
0005432783460	15415	Economy	13700.00
0005435242507	15415	Economy	13700.00
0005432783464	15415	Economy	13700.00
0005432783468	15415	Economy	13700.00
0005435242490	15415	Economy	13700.00
0005432783495	15415	Economy	13700.00
0005435242472	15415	Economy	13700.00
0005432783492	15415	Economy	13700.00
0005435242470	15415	Economy	13700.00
0005432783494	15415	Economy	15100.00
0005432783489	15415	Economy	15100.00
0005432783498	15415	Economy	15100.00
0005432783477	15415	Economy	13700.00
0005435242539	15415	Economy	13700.00
0005432783459	15415	Economy	13700.00
0005435242499	15415	Economy	13700.00
0005432783481	15415	Economy	13700.00
0005432783444	15415	Economy	13700.00
0005432783487	15415	Economy	13700.00
0005432783484	15415	Economy	13700.00
0005432783450	15415	Economy	13700.00
0005432783470	15415	Economy	13700.00
0005432783445	15415	Economy	13700.00
0005432783469	15415	Economy	13700.00
0005432783466	15415	Economy	13700.00
0005432783458	15415	Economy	13700.00
0005432783472	15415	Economy	13700.00
0005432783496	15415	Economy	13700.00
0005432783448	15415	Economy	13700.00
0005432783471	15415	Economy	13700.00
0005435242489	15415	Economy	13700.00
0005435242399	15415	Economy	13700.00
0005432783457	15415	Economy	13700.00
0005432783456	15415	Economy	13700.00
0005435242477	15415	Economy	13700.00
0005435242459	15415	Economy	13700.00
0005432783467	15415	Economy	13700.00
0005432783473	15415	Economy	13700.00
0005432783454	15415	Economy	13700.00
0005432783485	15415	Economy	13700.00
0005432783490	15415	Economy	13700.00
0005432783453	15415	Economy	13700.00
0005432783465	15415	Economy	13700.00
0005432783483	15415	Economy	13700.00
0005432783447	15415	Economy	13700.00
0005432783475	15415	Economy	13700.00
0005432783474	15415	Economy	13700.00
0005432783446	15415	Economy	13700.00
0005435242404	15415	Economy	13700.00
0005432783452	15415	Economy	13700.00
0005432783493	15415	Economy	13700.00
0005432783451	15415	Economy	13700.00
0005435242464	15415	Economy	13700.00
0005432783461	15415	Economy	13700.00
0005432783478	15415	Economy	13700.00
0005435242407	15415	Economy	13700.00
0005432783486	15415	Economy	13700.00
0005432783449	15415	Economy	13700.00
0005432783497	15415	Economy	13700.00
0005432783482	15415	Economy	13700.00
0005435242506	15415	Economy	13700.00
0005435242443	15415	Economy	13700.00
0005432783488	15415	Economy	13700.00
0005435242411	15415	Economy	13700.00
0005435242530	15415	Economy	13700.00
0005432783462	15415	Economy	13700.00
0005434758857	10088	Business	49700.00
0005434876999	10088	Business	49700.00
0005434877024	10088	Business	49700.00
0005435913924	10088	Business	49700.00
0005434876842	10088	Business	49700.00
0005434876635	10088	Business	49700.00
0005434877445	10088	Business	49700.00
0005434876775	10088	Business	49700.00
0005434876598	10088	Business	49700.00
0005434876865	10088	Business	49700.00
0005434877064	10088	Business	49700.00
0005434877083	10088	Business	49700.00
0005434877229	10088	Business	49700.00
0005434876755	10088	Business	49700.00
0005434876779	10088	Business	49700.00
0005434758858	10088	Business	49700.00
0005434876903	10088	Economy	16600.00
0005434877086	10088	Economy	16600.00
0005434877043	10088	Economy	16600.00
0005434876928	10088	Economy	16600.00
0005434910099	10088	Economy	16600.00
0005434876631	10088	Economy	16600.00
0005434877232	10088	Economy	16600.00
0005434877025	10088	Economy	16600.00
0005434877002	10088	Economy	16600.00
0005434877089	10088	Economy	16600.00
0005434876811	10088	Economy	18200.00
0005434910100	10088	Economy	18200.00
0005434876756	10088	Economy	18200.00
0005434876773	10088	Economy	16600.00
0005434876948	10088	Economy	16600.00
0005434876713	10088	Economy	16600.00
0005434876980	10088	Economy	16600.00
0005434877313	10088	Economy	16600.00
0005434910101	10088	Economy	16600.00
0005434876998	10088	Economy	16600.00
0005434877363	10088	Economy	16600.00
0005434877326	10088	Economy	16600.00
0005434876714	10088	Economy	16600.00
0005434877163	10088	Economy	16600.00
0005434876798	10088	Economy	16600.00
0005434876589	10088	Economy	16600.00
0005434876947	10088	Economy	16600.00
0005435913926	10088	Economy	16600.00
0005434876850	10088	Economy	16600.00
0005434877165	10088	Economy	16600.00
0005434876953	10088	Economy	16600.00
0005434877048	10088	Economy	16600.00
0005434877171	10088	Economy	16600.00
0005434876780	10088	Economy	16600.00
0005434876691	10088	Economy	16600.00
0005434877085	10088	Economy	16600.00
0005434876954	10088	Economy	16600.00
0005434877399	10088	Economy	16600.00
0005434877170	10088	Economy	16600.00
0005434877010	10088	Economy	16600.00
0005435913927	10088	Economy	16600.00
0005434876889	10088	Economy	16600.00
0005434876807	10088	Economy	16600.00
0005434876758	10088	Economy	16600.00
0005434876774	10088	Economy	16600.00
0005434876904	10088	Economy	16600.00
0005435913925	10088	Economy	16600.00
0005434877386	10088	Economy	16600.00
0005434877162	10088	Economy	16600.00
0005434877230	10088	Economy	16600.00
0005434877172	10088	Economy	16600.00
0005434877050	10088	Economy	16600.00
0005434877530	10088	Economy	16600.00
0005434877049	10088	Economy	16600.00
0005434876740	10088	Economy	16600.00
0005434876926	10088	Economy	16600.00
0005434876757	10088	Economy	16600.00
0005434877045	10088	Economy	16600.00
0005434876907	10088	Economy	16600.00
0005434876812	10088	Economy	16600.00
0005434876944	10088	Economy	16600.00
0005434876957	10088	Economy	16600.00
0005434876663	10088	Economy	16600.00
0005434876997	10088	Economy	16600.00
0005434876678	10088	Economy	16600.00
0005434876886	10088	Economy	16600.00
0005434876736	10088	Economy	16600.00
0005434876984	10088	Economy	16600.00
0005434877387	10088	Economy	16600.00
0005434877026	10088	Economy	16600.00
0005434876927	10088	Economy	16600.00
0005434877044	10088	Economy	16600.00
0005434877128	10088	Economy	16600.00
0005434876590	10088	Economy	16600.00
0005434877159	10088	Economy	16600.00
0005434876591	10088	Economy	16600.00
0005434877195	10088	Economy	16600.00
0005434877166	10088	Economy	16600.00
0005434877084	10088	Economy	16600.00
0005434877208	10088	Economy	16600.00
0005434877730	14642	Business	49700.00
0005434877766	14642	Business	49700.00
0005434877800	14642	Business	49700.00
0005434877793	14642	Business	49700.00
0005434877802	14642	Business	49700.00
0005434877787	14642	Business	49700.00
0005434877721	14642	Business	49700.00
0005434877808	14642	Business	49700.00
0005434877768	14642	Business	49700.00
0005434877788	14642	Business	49700.00
0005434877724	14642	Business	49700.00
0005434877791	14642	Business	49700.00
0005434877754	14642	Business	49700.00
0005434877806	14642	Business	49700.00
0005434877739	14642	Business	49700.00
0005434877815	14642	Business	49700.00
0005434877719	14642	Business	49700.00
0005434877805	14642	Business	49700.00
0005434877772	14642	Economy	16600.00
0005434877769	14642	Economy	16600.00
0005434877731	14642	Economy	16600.00
0005434877785	14642	Economy	16600.00
0005434877771	14642	Economy	16600.00
0005434877732	14642	Economy	16600.00
0005434758880	14642	Economy	16600.00
0005434877737	14642	Economy	16600.00
0005434877796	14642	Economy	16600.00
0005434910072	14642	Economy	16600.00
0005434877763	14642	Economy	18200.00
0005434877735	14642	Economy	16600.00
0005434877783	14642	Economy	18200.00
0005434877717	14642	Economy	18200.00
0005434877797	14642	Economy	16600.00
0005434877814	14642	Economy	18200.00
0005434877747	14642	Economy	16600.00
0005434877773	14642	Economy	16600.00
0005434877767	14642	Economy	16600.00
0005434877733	14642	Economy	16600.00
0005434877741	14642	Economy	16600.00
0005434877734	14642	Economy	16600.00
0005434877725	14642	Economy	16600.00
0005434877812	14642	Economy	16600.00
0005434877809	14642	Economy	16600.00
0005434877726	14642	Economy	16600.00
0005434877738	14642	Economy	16600.00
0005434877795	14642	Economy	16600.00
0005434877777	14642	Economy	16600.00
0005434758881	14642	Economy	16600.00
0005434877810	14642	Economy	16600.00
0005434877789	14642	Economy	16600.00
0005434877720	14642	Economy	16600.00
0005434877765	14642	Economy	16600.00
0005434877786	14642	Economy	16600.00
0005434877807	14642	Economy	16600.00
0005434877722	14642	Economy	16600.00
0005434877718	14642	Economy	16600.00
0005434877750	14642	Economy	16600.00
0005434877804	14642	Economy	16600.00
0005434877755	14642	Economy	16600.00
0005434877742	14642	Economy	16600.00
0005434877748	14642	Economy	16600.00
0005434877746	14642	Economy	16600.00
0005434877743	14642	Economy	16600.00
0005434877727	14642	Economy	16600.00
0005434877775	14642	Economy	16600.00
0005434877752	14642	Economy	16600.00
0005434877798	14642	Economy	16600.00
0005434877778	14642	Economy	16600.00
0005434877759	14642	Economy	16600.00
0005434877749	14642	Economy	16600.00
0005434877790	14642	Economy	16600.00
0005434877761	14642	Economy	16600.00
0005434877813	14642	Economy	16600.00
0005435913852	14642	Economy	16600.00
0005434877736	14642	Economy	16600.00
0005434877745	14642	Economy	16600.00
0005434877776	14642	Economy	16600.00
0005434877792	14642	Economy	16600.00
0005434758882	14642	Economy	16600.00
0005434877744	14642	Economy	16600.00
0005434877803	14642	Economy	16600.00
0005434877756	14642	Economy	16600.00
0005434877794	14642	Economy	16600.00
0005434877811	14642	Economy	16600.00
0005434877779	14642	Economy	16600.00
0005434877740	14642	Economy	16600.00
0005434877799	14642	Economy	16600.00
0005434877729	14642	Economy	16600.00
0005434877762	14642	Economy	16600.00
0005434877760	14642	Economy	16600.00
0005434877770	14642	Economy	16600.00
0005434877782	14642	Economy	16600.00
0005434877757	14642	Economy	16600.00
0005434877728	14642	Economy	16600.00
0005434877781	14642	Economy	16600.00
0005434877774	14642	Economy	16600.00
0005434877751	14642	Economy	16600.00
0005434877780	14642	Economy	16600.00
0005434877801	14642	Economy	16600.00
0005434877764	14642	Economy	16600.00
0005434877758	14642	Economy	16600.00
0005434877753	14642	Economy	16600.00
0005434877723	14642	Economy	16600.00
0005434877784	14642	Economy	16600.00
0005435913851	14642	Economy	16600.00
0005434251812	9210	Economy	22400.00
0005435660086	9210	Economy	20300.00
0005435660082	9210	Economy	20300.00
0005435660079	9210	Economy	20300.00
0005435660084	9210	Economy	20300.00
0005434251829	9210	Economy	20300.00
0005434251859	9210	Economy	20300.00
0005435660080	9210	Economy	20300.00
0005434251853	9210	Economy	20300.00
0005435660083	9210	Economy	20300.00
0005434251810	9210	Economy	20300.00
0005434251809	9210	Economy	20300.00
0005435660078	9210	Economy	20300.00
0005435660076	9210	Economy	20300.00
0005435660081	9210	Economy	20300.00
0005434251854	9210	Economy	20300.00
0005434251832	9210	Economy	20300.00
0005434251827	9210	Economy	20300.00
0005434251851	9210	Economy	20300.00
0005435660077	9210	Economy	20300.00
0005435660085	9210	Economy	20300.00
0005434251914	24669	Economy	20300.00
0005435659941	24669	Economy	20300.00
0005435659981	24669	Economy	20300.00
0005435659983	24669	Economy	20300.00
0005434251917	24669	Economy	20300.00
0005434251918	24669	Economy	20300.00
0005434251913	24669	Economy	20300.00
0005435659985	24669	Economy	20300.00
0005435659984	24669	Economy	20300.00
0005434251920	24669	Economy	20300.00
0005434251915	24669	Economy	20300.00
0005434251912	24669	Economy	20300.00
0005434251919	24669	Economy	20300.00
0005435660005	24669	Economy	20300.00
0005434251921	24669	Economy	20300.00
0005435660004	24669	Economy	20300.00
0005434251916	24669	Economy	20300.00
0005434251922	24669	Economy	20300.00
0005435660009	24669	Economy	20300.00
0005432966673	2777	Business	33000.00
0005433680310	2777	Business	33000.00
0005433684408	2777	Business	33000.00
0005433680306	2777	Business	33000.00
0005432966652	2777	Business	33000.00
0005433680326	2777	Business	33000.00
0005432966646	2777	Business	33000.00
0005432966505	2777	Business	33000.00
0005432966627	2777	Business	33000.00
0005432966634	2777	Business	33000.00
0005433680343	2777	Business	33000.00
0005433684407	2777	Economy	11000.00
0005433680339	2777	Economy	11000.00
0005433680313	2777	Economy	11000.00
0005433680320	2777	Economy	11000.00
0005433680332	2777	Economy	11000.00
0005433680328	2777	Economy	11000.00
0005432222753	2777	Economy	11000.00
0005433680308	2777	Economy	11000.00
0005433680297	2777	Economy	11000.00
0005432966560	2777	Economy	12100.00
0005433680312	2777	Economy	12100.00
0005433680318	2777	Economy	12100.00
0005432966651	2777	Economy	12100.00
0005433680322	2777	Economy	12100.00
0005433680305	2777	Economy	11000.00
0005433680342	2777	Economy	11000.00
0005433680317	2777	Economy	11000.00
0005433680330	2777	Economy	11000.00
0005432966630	2777	Economy	11000.00
0005433680336	2777	Economy	11000.00
0005432222754	2777	Economy	11000.00
0005432966570	2777	Economy	11000.00
0005432966520	2777	Economy	11000.00
0005433680340	2777	Economy	11000.00
0005432222757	2777	Economy	11000.00
0005433680341	2777	Economy	11000.00
0005432966564	2777	Economy	11000.00
0005433680327	2777	Economy	11000.00
0005433680309	2777	Economy	11000.00
0005433680323	2777	Economy	11000.00
0005433680301	2777	Economy	11000.00
0005432966703	2777	Economy	11000.00
0005432966561	2777	Economy	11000.00
0005433680298	2777	Economy	11000.00
0005433680329	2777	Economy	11000.00
0005433680311	2777	Economy	11000.00
0005433680333	2777	Economy	11000.00
0005433680319	2777	Economy	11000.00
0005433680300	2777	Economy	11000.00
0005433680316	2777	Economy	11000.00
0005433680299	2777	Economy	11000.00
0005433680314	2777	Economy	11000.00
0005432966485	2777	Economy	11000.00
0005432966518	2777	Economy	11000.00
0005432966609	2777	Economy	11000.00
0005432966626	2777	Economy	11000.00
0005432966571	2777	Economy	11000.00
0005433680307	2777	Economy	11000.00
0005433680324	2777	Economy	11000.00
0005432966553	2777	Economy	11000.00
0005433680338	2777	Economy	11000.00
0005432966544	2777	Economy	11000.00
0005433680302	2777	Economy	11000.00
0005432966579	2777	Economy	11000.00
0005433680303	2777	Economy	11000.00
0005432966559	2777	Economy	11000.00
0005432966580	2777	Economy	11000.00
0005433680344	2777	Economy	11000.00
0005433680296	2777	Economy	11000.00
0005433680334	2777	Economy	11000.00
0005432966519	2777	Economy	11000.00
0005432966484	2777	Economy	11000.00
0005433680331	2777	Economy	11000.00
0005432966517	2777	Economy	11000.00
0005432222755	2777	Economy	11000.00
0005433680304	2777	Economy	11000.00
0005433680321	2777	Economy	11000.00
0005433680337	2777	Economy	11000.00
0005433684409	2777	Economy	11000.00
0005433680335	2777	Economy	11000.00
0005432966569	2777	Economy	11000.00
0005433680325	2777	Economy	11000.00
0005433680315	2777	Economy	11000.00
0005432222756	2777	Economy	11000.00
0005432966811	29170	Business	33000.00
0005433680043	29170	Business	33000.00
0005432966818	29170	Business	33000.00
0005432966808	29170	Business	33000.00
0005432966814	29170	Business	33000.00
0005432966802	29170	Business	33000.00
0005433679989	29170	Business	33000.00
0005432966797	29170	Business	33000.00
0005432966817	29170	Business	33000.00
0005433679845	29170	Business	33000.00
0005433680118	29170	Business	33000.00
0005433680136	29170	Business	33000.00
0005433679987	29170	Economy	11000.00
0005433679847	29170	Economy	11000.00
0005433680000	29170	Economy	11000.00
0005432966801	29170	Economy	11000.00
0005433679870	29170	Economy	11000.00
0005433680079	29170	Economy	11000.00
0005433680045	29170	Economy	11000.00
0005432966799	29170	Economy	11000.00
0005433679988	29170	Economy	12100.00
0005433679945	29170	Economy	12100.00
0005433679866	29170	Economy	12100.00
0005433679943	29170	Economy	12100.00
0005433680057	29170	Economy	11000.00
0005433680019	29170	Economy	11000.00
0005433679868	29170	Economy	11000.00
0005432966806	29170	Economy	11000.00
0005433679822	29170	Economy	11000.00
0005432966813	29170	Economy	11000.00
0005432966800	29170	Economy	11000.00
0005432966810	29170	Economy	11000.00
0005433680101	29170	Economy	11000.00
0005433679916	29170	Economy	11000.00
0005432966809	29170	Economy	11000.00
0005433679895	29170	Economy	11000.00
0005432966794	29170	Economy	11000.00
0005433679890	29170	Economy	11000.00
0005433680016	29170	Economy	11000.00
0005432966805	29170	Economy	11000.00
0005433680058	29170	Economy	11000.00
0005433680062	29170	Economy	11000.00
0005433679758	29170	Economy	11000.00
0005432966795	29170	Economy	11000.00
0005433679894	29170	Economy	11000.00
0005433679981	29170	Economy	11000.00
0005433680020	29170	Economy	11000.00
0005433680063	29170	Economy	11000.00
0005433679871	29170	Economy	11000.00
0005433679893	29170	Economy	11000.00
0005433680119	29170	Economy	11000.00
0005433680044	29170	Economy	11000.00
0005433679726	29170	Economy	11000.00
0005433679979	29170	Economy	11000.00
0005432966803	29170	Economy	11000.00
0005433679905	29170	Economy	11000.00
0005432966816	29170	Economy	11000.00
0005433679963	29170	Economy	11000.00
0005433679865	29170	Economy	11000.00
0005433679869	29170	Economy	11000.00
0005433679885	29170	Economy	11000.00
0005433679977	29170	Economy	11000.00
0005432966807	29170	Economy	11000.00
0005433679993	29170	Economy	11000.00
0005433679896	29170	Economy	11000.00
0005432005198	29170	Economy	11000.00
0005432966798	29170	Economy	11000.00
0005432966793	29170	Economy	11000.00
0005432966815	29170	Economy	11000.00
0005433679980	29170	Economy	11000.00
0005432966796	29170	Economy	11000.00
0005433679771	29170	Economy	11000.00
0005433679955	29170	Economy	11000.00
0005433680092	29170	Economy	11000.00
0005433679867	29170	Economy	11000.00
0005433680042	29170	Economy	11000.00
0005432966812	29170	Economy	11000.00
0005433679990	29170	Economy	11000.00
0005432005199	29170	Economy	11000.00
0005433679763	29170	Economy	11000.00
0005433679969	29170	Economy	11000.00
0005433680004	29170	Economy	11000.00
0005433679846	29170	Economy	11000.00
0005433679831	29170	Economy	11000.00
0005433679982	29170	Economy	11000.00
0005432966804	29170	Economy	11000.00
0005433614276	9316	Business	132900.00
0005433614216	9316	Business	132900.00
0005433577730	9316	Business	132900.00
0005433614261	9316	Business	132900.00
0005432755056	9316	Business	132900.00
0005433614279	9316	Business	132900.00
0005433577740	9316	Business	132900.00
0005432756830	9316	Business	132900.00
0005433633629	9316	Business	132900.00
0005433614278	9316	Business	132900.00
0005433633604	9316	Business	132900.00
0005433614272	9316	Business	132900.00
0005433614227	9316	Business	132900.00
0005433614240	9316	Business	132900.00
0005433614228	9316	Business	132900.00
0005433614270	9316	Business	132900.00
0005433614235	9316	Business	132900.00
0005433614263	9316	Business	132900.00
0005433633616	9316	Business	132900.00
0005433614269	9316	Business	132900.00
0005433633617	9316	Business	132900.00
0005433633600	9316	Economy	48700.00
0005433614245	9316	Economy	48700.00
0005433577731	9316	Economy	48700.00
0005433614242	9316	Economy	48700.00
0005433577729	9316	Economy	48700.00
0005433614256	9316	Economy	48700.00
0005433614266	9316	Economy	44300.00
0005433577733	9316	Economy	44300.00
0005433614212	9316	Economy	44300.00
0005433633608	9316	Economy	44300.00
0005433614265	9316	Economy	44300.00
0005433614260	9316	Economy	44300.00
0005433614226	9316	Economy	44300.00
0005433577727	9316	Economy	44300.00
0005433577735	9316	Economy	44300.00
0005434272166	9316	Economy	44300.00
0005434163510	9316	Economy	44300.00
0005433614284	9316	Economy	44300.00
0005433614271	9316	Economy	44300.00
0005433614213	9316	Economy	44300.00
0005433614282	9316	Economy	44300.00
0005433633628	9316	Economy	44300.00
0005433614246	9316	Economy	44300.00
0005433633611	9316	Economy	44300.00
0005433633625	9316	Economy	44300.00
0005433633605	9316	Economy	44300.00
0005433614277	9316	Economy	44300.00
0005433614254	9316	Economy	44300.00
0005433633599	9316	Economy	44300.00
0005433614241	9316	Economy	44300.00
0005433614211	9316	Economy	44300.00
0005433633627	9316	Economy	44300.00
0005433614248	9316	Economy	44300.00
0005433614225	9316	Economy	44300.00
0005433614220	9316	Economy	44300.00
0005433614250	9316	Economy	44300.00
0005433614234	9316	Economy	44300.00
0005433633612	9316	Economy	44300.00
0005432756828	9316	Economy	44300.00
0005433614267	9316	Economy	44300.00
0005433577736	9316	Economy	44300.00
0005434163508	9316	Economy	44300.00
0005434152765	9316	Economy	44300.00
0005433614233	9316	Economy	44300.00
0005433614247	9316	Economy	44300.00
0005433633606	9316	Economy	44300.00
0005433577734	9316	Economy	44300.00
0005434163503	9316	Economy	44300.00
0005433614232	9316	Economy	44300.00
0005433614258	9316	Economy	44300.00
0005433614251	9316	Economy	44300.00
0005433577739	9316	Economy	44300.00
0005433614210	9316	Economy	44300.00
0005433614257	9316	Economy	44300.00
0005433614215	9316	Economy	44300.00
0005433614275	9316	Economy	48700.00
0005433633613	9316	Economy	48700.00
0005433614283	9316	Economy	48700.00
0005433633624	9316	Economy	48700.00
0005433614217	9316	Economy	48700.00
0005432756831	9316	Economy	44300.00
0005433614274	9316	Economy	44300.00
0005433614224	9316	Economy	48700.00
0005433614280	9316	Economy	44300.00
0005433633630	9316	Economy	44300.00
0005433633619	9316	Economy	44300.00
0005433633602	9316	Economy	44300.00
0005433614273	9316	Economy	44300.00
0005433614230	9316	Economy	44300.00
0005433633614	9316	Economy	44300.00
0005433614219	9316	Economy	44300.00
0005433633618	9316	Economy	44300.00
0005433577732	9316	Economy	44300.00
0005433614239	9316	Economy	44300.00
0005433614268	9316	Economy	44300.00
0005433633615	9316	Economy	44300.00
0005432756832	9316	Economy	44300.00
0005433614262	9316	Economy	44300.00
0005433633603	9316	Economy	44300.00
0005433577728	9316	Economy	44300.00
0005433614264	9316	Economy	44300.00
0005433614249	9316	Economy	44300.00
0005433614255	9316	Economy	44300.00
0005433614231	9316	Economy	44300.00
0005433614223	9316	Economy	44300.00
0005432145099	9316	Economy	44300.00
0005433633610	9316	Economy	44300.00
0005433577738	9316	Economy	44300.00
0005433633621	9316	Economy	44300.00
0005432756829	9316	Economy	44300.00
0005434272171	9316	Economy	44300.00
0005433614281	9316	Economy	44300.00
0005433633609	9316	Economy	44300.00
0005433614222	9316	Economy	44300.00
0005433614237	9316	Economy	44300.00
0005433633607	9316	Economy	44300.00
0005433614253	9316	Economy	44300.00
0005433614243	9316	Economy	44300.00
0005433633631	9316	Economy	44300.00
0005433614221	9316	Economy	44300.00
0005433633601	9316	Economy	44300.00
0005433614238	9316	Economy	44300.00
0005433577737	9316	Economy	44300.00
0005433614252	9316	Economy	44300.00
0005433614214	9316	Economy	44300.00
0005433614229	9316	Economy	44300.00
0005433614244	9316	Economy	44300.00
0005432755057	9316	Economy	44300.00
0005433614236	9316	Economy	44300.00
0005432755058	9316	Economy	44300.00
0005433633623	9316	Economy	44300.00
0005433633626	9316	Economy	44300.00
0005433633622	9316	Economy	44300.00
0005433614259	9316	Economy	44300.00
0005433633620	9316	Economy	44300.00
0005434152751	9316	Economy	44300.00
0005433614218	9316	Economy	44300.00
0005434163509	9316	Economy	44300.00
0005433577635	25229	Business	132900.00
0005434163572	25229	Business	132900.00
0005433613607	25229	Business	132900.00
0005433633328	25229	Business	132900.00
0005434163580	25229	Business	132900.00
0005433633337	25229	Business	132900.00
0005433613714	25229	Business	132900.00
0005433613622	25229	Business	132900.00
0005433613713	25229	Business	132900.00
0005433613752	25229	Business	132900.00
0005433613705	25229	Business	132900.00
0005433613479	25229	Business	132900.00
0005433577602	25229	Business	132900.00
0005433613636	25229	Business	132900.00
0005435854049	25229	Business	132900.00
0005433613468	25229	Business	132900.00
0005433633383	25229	Business	132900.00
0005433613531	25229	Economy	48700.00
0005433633327	25229	Economy	48700.00
0005433613623	25229	Economy	48700.00
0005433577588	25229	Economy	48700.00
0005433613690	25229	Economy	44300.00
0005433613506	25229	Economy	44300.00
0005433633333	25229	Economy	44300.00
0005433613482	25229	Economy	44300.00
0005433633340	25229	Economy	44300.00
0005433633458	25229	Economy	44300.00
0005434163577	25229	Economy	44300.00
0005433577604	25229	Economy	44300.00
0005433633397	25229	Economy	44300.00
0005433613697	25229	Economy	44300.00
0005433577589	25229	Economy	44300.00
0005433613606	25229	Economy	44300.00
0005434273068	25229	Economy	44300.00
0005433613497	25229	Economy	44300.00
0005434163575	25229	Economy	44300.00
0005433577668	25229	Economy	44300.00
0005433613598	25229	Economy	44300.00
0005433633235	25229	Economy	44300.00
0005433633243	25229	Economy	44300.00
0005433613515	25229	Economy	44300.00
0005433633230	25229	Economy	44300.00
0005433613537	25229	Economy	44300.00
0005433633339	25229	Economy	44300.00
0005433613507	25229	Economy	44300.00
0005433633398	25229	Economy	44300.00
0005433633402	25229	Economy	44300.00
0005433577601	25229	Economy	44300.00
0005433577606	25229	Economy	44300.00
0005435854048	25229	Economy	44300.00
0005434273067	25229	Economy	44300.00
0005433577613	25229	Economy	44300.00
0005433613793	25229	Economy	44300.00
0005433633231	25229	Economy	44300.00
0005433633318	25229	Economy	44300.00
0005434163574	25229	Economy	44300.00
0005434163576	25229	Economy	44300.00
0005433613658	25229	Economy	44300.00
0005433577603	25229	Economy	48700.00
0005433633434	25229	Economy	48700.00
0005434272182	25229	Economy	48700.00
0005433633426	25229	Economy	44300.00
0005433633305	25229	Economy	44300.00
0005433633282	25229	Economy	44300.00
0005433577627	25229	Economy	48700.00
0005433633338	25229	Economy	44300.00
0005433613702	25229	Economy	44300.00
0005433613673	25229	Economy	44300.00
0005433613596	25229	Economy	44300.00
0005433613677	25229	Economy	44300.00
0005433613517	25229	Economy	44300.00
0005433613575	25229	Economy	44300.00
0005434163579	25229	Economy	44300.00
0005433613725	25229	Economy	44300.00
0005433613483	25229	Economy	44300.00
0005433613552	25229	Economy	44300.00
0005433613735	25229	Economy	44300.00
0005433633334	25229	Economy	44300.00
0005433633286	25229	Economy	44300.00
0005433633308	25229	Economy	44300.00
0005433633281	25229	Economy	44300.00
0005433613597	25229	Economy	44300.00
0005433613469	25229	Economy	44300.00
0005433633437	25229	Economy	44300.00
0005433613553	25229	Economy	44300.00
0005433613574	25229	Economy	44300.00
0005433633459	25229	Economy	44300.00
0005433613621	25229	Economy	44300.00
0005433633242	25229	Economy	44300.00
0005433613555	25229	Economy	44300.00
0005433613850	25229	Economy	44300.00
0005433633306	25229	Economy	44300.00
0005433613605	25229	Economy	44300.00
0005433633372	25229	Economy	44300.00
0005433633307	25229	Economy	44300.00
0005433613536	25229	Economy	44300.00
0005433577599	25229	Economy	44300.00
0005433613715	25229	Economy	44300.00
0005433577605	25229	Economy	44300.00
0005435854050	25229	Economy	44300.00
0005433613655	25229	Economy	44300.00
0005433613466	25229	Economy	44300.00
0005434163571	25229	Economy	44300.00
0005433613841	25229	Economy	44300.00
0005433577600	25229	Economy	44300.00
0005434163573	25229	Economy	44300.00
0005434163578	25229	Economy	44300.00
0005433613701	25229	Economy	44300.00
0005433613680	25229	Economy	44300.00
0005434272181	25229	Economy	44300.00
0005433577598	25229	Economy	44300.00
0005433613547	25229	Economy	44300.00
0005432571276	4215	Business	193100.00
0005435947051	4215	Business	193100.00
0005435856152	4215	Economy	70800.00
0005432571272	4215	Economy	70800.00
0005432184937	4215	Economy	64400.00
0005435947098	4215	Economy	64400.00
0005435947050	4215	Economy	64400.00
0005432571268	4215	Economy	64400.00
0005435947107	4215	Economy	64400.00
0005435986720	4215	Economy	64400.00
0005435947017	4215	Economy	64400.00
0005435854044	4215	Economy	64400.00
0005435947083	4215	Economy	64400.00
0005435947052	4215	Economy	64400.00
0005435856159	4215	Economy	70800.00
0005435947018	4215	Economy	70800.00
0005435856150	4215	Economy	64400.00
0005435947120	4215	Economy	64400.00
0005432571289	4215	Economy	64400.00
0005435947068	4215	Economy	64400.00
0005435986719	4215	Economy	64400.00
0005432571257	4215	Economy	64400.00
0005434271282	4215	Economy	64400.00
0005435856146	4215	Economy	64400.00
0005435986718	4215	Economy	64400.00
0005434271283	4215	Economy	64400.00
0005435854041	4215	Economy	64400.00
0005432184936	4215	Economy	64400.00
0005435986659	26557	Business	193100.00
0005435947184	26557	Business	193100.00
0005435856184	26557	Business	193100.00
0005435856183	26557	Business	193100.00
0005435947178	26557	Business	193100.00
0005435947189	26557	Business	193100.00
0005435947185	26557	Economy	64400.00
0005432571304	26557	Economy	64400.00
0005432571305	26557	Economy	64400.00
0005435856182	26557	Economy	64400.00
0005432571306	26557	Economy	64400.00
0005435947182	26557	Economy	64400.00
0005435947177	26557	Economy	64400.00
0005435986653	26557	Economy	64400.00
0005435947188	26557	Economy	64400.00
0005435856181	26557	Economy	64400.00
0005435947180	26557	Economy	64400.00
0005435986657	26557	Economy	64400.00
0005435947175	26557	Economy	64400.00
0005432571307	26557	Economy	64400.00
0005435947183	26557	Economy	64400.00
0005435947186	26557	Economy	70800.00
0005435947179	26557	Economy	64400.00
0005435947181	26557	Economy	64400.00
0005435986668	26557	Economy	64400.00
0005435787345	26557	Economy	64400.00
0005435947176	26557	Economy	64400.00
0005435787344	26557	Economy	64400.00
0005432571303	26557	Economy	64400.00
0005435986667	26557	Economy	64400.00
0005435947187	26557	Economy	64400.00
0005435986669	26557	Economy	64400.00
0005433568795	312	Business	21500.00
0005432947914	312	Business	21500.00
0005433568759	312	Business	21500.00
0005433129218	312	Business	21500.00
0005432238908	312	Business	21500.00
0005432947905	312	Business	21500.00
0005433074368	312	Business	21500.00
0005433568786	312	Business	21500.00
0005433074410	312	Business	21500.00
0005433074318	312	Business	21500.00
0005433129209	312	Business	21500.00
0005433568777	312	Business	21500.00
0005432238907	312	Business	21500.00
0005433568801	312	Business	21500.00
0005433568752	312	Business	21500.00
0005433568767	312	Business	21500.00
0005433568753	312	Business	21500.00
0005433074416	312	Business	21500.00
0005432947957	312	Business	21500.00
0005432947861	312	Business	21500.00
0005433134085	312	Business	21500.00
0005433568746	312	Business	21500.00
0005433568792	312	Business	21500.00
0005433568780	312	Business	21500.00
0005433568776	312	Economy	7900.00
0005432947948	312	Economy	7900.00
0005432947878	312	Economy	7900.00
0005433134086	312	Economy	7900.00
0005433568738	312	Economy	7900.00
0005433568797	312	Economy	7900.00
0005433568740	312	Economy	7200.00
0005433568770	312	Economy	7200.00
0005433568739	312	Economy	7200.00
0005432948024	312	Economy	7200.00
0005433074287	312	Economy	7200.00
0005432947778	312	Economy	7200.00
0005432947852	312	Economy	7200.00
0005432947851	312	Economy	7200.00
0005432947890	312	Economy	7200.00
0005433568755	312	Economy	7200.00
0005432238906	312	Economy	7200.00
0005433129214	312	Economy	7200.00
0005433568749	312	Economy	7200.00
0005432947933	312	Economy	7200.00
0005433568791	312	Economy	7200.00
0005433074384	312	Economy	7200.00
0005433568762	312	Economy	7200.00
0005433568763	312	Economy	7200.00
0005433568741	312	Economy	7200.00
0005433074305	312	Economy	7200.00
0005433134088	312	Economy	7200.00
0005433074286	312	Economy	7200.00
0005433568773	312	Economy	7200.00
0005432948004	312	Economy	7200.00
0005433568771	312	Economy	7200.00
0005433568750	312	Economy	7200.00
0005432238904	312	Economy	7200.00
0005433568778	312	Economy	7200.00
0005433074233	312	Economy	7200.00
0005432947790	312	Economy	7200.00
0005433074301	312	Economy	7200.00
0005432947967	312	Economy	7200.00
0005432947880	312	Economy	7200.00
0005433074254	312	Economy	7200.00
0005432947805	312	Economy	7200.00
0005433568745	312	Economy	7200.00
0005433568754	312	Economy	7200.00
0005433074415	312	Economy	7200.00
0005433568798	312	Economy	7200.00
0005432947891	312	Economy	7200.00
0005432948055	312	Economy	7200.00
0005433568751	312	Economy	7200.00
0005433074380	312	Economy	7200.00
0005433074345	312	Economy	7200.00
0005433074298	312	Economy	7200.00
0005432948001	312	Economy	7200.00
0005433134087	312	Economy	7200.00
0005433074350	312	Economy	7200.00
0005432947990	312	Economy	7200.00
0005433568802	312	Economy	7200.00
0005432947913	312	Economy	7200.00
0005433074208	312	Economy	7200.00
0005433568769	312	Economy	7200.00
0005433568768	312	Economy	7900.00
0005432947930	312	Economy	7900.00
0005433074226	312	Economy	7900.00
0005433568796	312	Economy	7900.00
0005432947806	312	Economy	7200.00
0005433568774	312	Economy	7900.00
0005433568787	312	Economy	7200.00
0005433134073	312	Economy	7200.00
0005432948023	312	Economy	7200.00
0005432947928	312	Economy	7900.00
0005433568761	312	Economy	7200.00
0005433568772	312	Economy	7200.00
0005433074356	312	Economy	7200.00
0005433568748	312	Economy	7200.00
0005433568758	312	Economy	7200.00
0005433568788	312	Economy	7200.00
0005433074310	312	Economy	7200.00
0005433568789	312	Economy	7200.00
0005433074311	312	Economy	7200.00
0005433568744	312	Economy	7200.00
0005432947958	312	Economy	7200.00
0005433074253	312	Economy	7200.00
0005432947860	312	Economy	7200.00
0005433074209	312	Economy	7200.00
0005433568756	312	Economy	7200.00
0005432947906	312	Economy	7200.00
0005432947959	312	Economy	7200.00
0005433568800	312	Economy	7200.00
0005433568775	312	Economy	7200.00
0005433074378	312	Economy	7200.00
0005433074302	312	Economy	7200.00
0005433568743	312	Economy	7200.00
0005432948102	312	Economy	7200.00
0005433568790	312	Economy	7200.00
0005433568766	312	Economy	7200.00
0005432947984	312	Economy	7200.00
0005433568784	312	Economy	7200.00
0005432948026	312	Economy	7200.00
0005432238905	312	Economy	7200.00
0005432948025	312	Economy	7200.00
0005432947791	312	Economy	7200.00
0005433074381	312	Economy	7200.00
0005432947889	312	Economy	7200.00
0005433568781	312	Economy	7200.00
0005433568779	312	Economy	7200.00
0005432947991	312	Economy	7200.00
0005433074358	312	Economy	7200.00
0005433568765	312	Economy	7200.00
0005433568799	312	Economy	7200.00
0005433568764	312	Economy	7200.00
0005433568783	312	Economy	7200.00
0005433074306	312	Economy	7200.00
0005433074303	312	Economy	7200.00
0005433568757	312	Economy	7200.00
0005433568742	312	Economy	7200.00
0005433568793	312	Economy	7200.00
0005433074304	312	Economy	7200.00
0005433568760	312	Economy	7200.00
0005432947807	312	Economy	7200.00
0005433568785	312	Economy	7200.00
0005433568782	312	Economy	7200.00
0005432947983	312	Economy	7200.00
0005433568794	312	Economy	7200.00
0005432947949	312	Economy	7200.00
0005432947886	312	Economy	7200.00
0005432947966	312	Economy	7200.00
0005432947879	312	Economy	7200.00
0005433568747	312	Economy	7200.00
0005432948248	11582	Business	21500.00
0005433134112	11582	Business	21500.00
0005433074563	11582	Business	21500.00
0005433568238	11582	Business	21500.00
0005433074556	11582	Business	21500.00
0005432948232	11582	Business	21500.00
0005433568206	11582	Business	21500.00
0005432948231	11582	Business	21500.00
0005433074565	11582	Business	21500.00
0005433568105	11582	Business	21500.00
0005433074553	11582	Business	21500.00
0005433134116	11582	Business	21500.00
0005433568157	11582	Business	21500.00
0005433568077	11582	Business	21500.00
0005432948252	11582	Business	21500.00
0005432948255	11582	Business	21500.00
0005433134114	11582	Business	21500.00
0005433074560	11582	Business	21500.00
0005433074557	11582	Economy	7900.00
0005433074567	11582	Economy	7900.00
0005432192304	11582	Economy	7900.00
0005433568158	11582	Economy	7900.00
0005433568068	11582	Economy	7900.00
0005433074554	11582	Economy	7200.00
0005432948230	11582	Economy	7200.00
0005432948243	11582	Economy	7200.00
0005432948247	11582	Economy	7200.00
0005432948254	11582	Economy	7200.00
0005432192302	11582	Economy	7200.00
0005433568177	11582	Economy	7200.00
0005433074566	11582	Economy	7200.00
0005432948237	11582	Economy	7200.00
0005433568095	11582	Economy	7200.00
0005433568081	11582	Economy	7200.00
0005433134113	11582	Economy	7200.00
0005432948229	11582	Economy	7200.00
0005433074561	11582	Economy	7200.00
0005433568214	11582	Economy	7200.00
0005433074549	11582	Economy	7200.00
0005433131686	11582	Economy	7200.00
0005432948256	11582	Economy	7200.00
0005433568213	11582	Economy	7200.00
0005433568083	11582	Economy	7200.00
0005432948257	11582	Economy	7200.00
0005432948223	11582	Economy	7200.00
0005433074569	11582	Economy	7200.00
0005433074568	11582	Economy	7200.00
0005433074551	11582	Economy	7200.00
0005433131685	11582	Economy	7200.00
0005433074547	11582	Economy	7200.00
0005433074562	11582	Economy	7200.00
0005433074546	11582	Economy	7200.00
0005432948239	11582	Economy	7200.00
0005432948224	11582	Economy	7200.00
0005433568106	11582	Economy	7200.00
0005433568189	11582	Economy	7200.00
0005432948235	11582	Economy	7200.00
0005432948234	11582	Economy	7200.00
0005433134115	11582	Economy	7200.00
0005432948261	11582	Economy	7200.00
0005432948241	11582	Economy	7200.00
0005433568114	11582	Economy	7200.00
0005432948259	11582	Economy	7200.00
0005433568166	11582	Economy	7200.00
0005433074574	11582	Economy	7200.00
0005432948258	11582	Economy	7200.00
0005432948236	11582	Economy	7200.00
0005432948244	11582	Economy	7200.00
0005433568174	11582	Economy	7900.00
0005432192303	11582	Economy	7900.00
0005432948263	11582	Economy	7900.00
0005433074548	11582	Economy	7200.00
0005433568132	11582	Economy	7200.00
0005433568207	11582	Economy	7900.00
0005432948226	11582	Economy	7200.00
0005433074555	11582	Economy	7200.00
0005433568111	11582	Economy	7200.00
0005433568088	11582	Economy	7200.00
0005432948225	11582	Economy	7200.00
0005432948227	11582	Economy	7200.00
0005433074573	11582	Economy	7200.00
0005432948238	11582	Economy	7200.00
0005432948222	11582	Economy	7200.00
0005433074550	11582	Economy	7200.00
0005432948246	11582	Economy	7200.00
0005433568173	11582	Economy	7200.00
0005433074558	11582	Economy	7200.00
0005433568212	11582	Economy	7200.00
0005433568067	11582	Economy	7200.00
0005433074572	11582	Economy	7200.00
0005433568107	11582	Economy	7200.00
0005432948251	11582	Economy	7200.00
0005433568094	11582	Economy	7200.00
0005432948233	11582	Economy	7200.00
0005432948260	11582	Economy	7200.00
0005432948262	11582	Economy	7200.00
0005432948249	11582	Economy	7200.00
0005433568188	11582	Economy	7200.00
0005432948245	11582	Economy	7200.00
0005432948240	11582	Economy	7200.00
0005432948242	11582	Economy	7200.00
0005433568161	11582	Economy	7200.00
0005433074564	11582	Economy	7200.00
0005432948253	11582	Economy	7200.00
0005433568089	11582	Economy	7200.00
0005433074559	11582	Economy	7200.00
0005433568176	11582	Economy	7200.00
0005432948228	11582	Economy	7200.00
0005433568169	11582	Economy	7200.00
0005433074570	11582	Economy	7200.00
0005433131684	11582	Economy	7200.00
0005433074571	11582	Economy	7200.00
0005432948250	11582	Economy	7200.00
0005433074552	11582	Economy	7200.00
0005433817450	10030	Economy	6300.00
0005433817454	10030	Economy	6300.00
0005433817452	10030	Economy	6300.00
0005433817451	10030	Economy	6300.00
0005434732943	10030	Economy	6300.00
0005433817453	10030	Economy	6300.00
0005434732947	10030	Economy	6300.00
0005434732944	10030	Economy	6300.00
0005434732964	13989	Economy	6300.00
0005433817430	13989	Economy	6300.00
0005434732965	13989	Economy	6300.00
0005433817429	13989	Economy	6300.00
0005434732963	13989	Economy	6300.00
0005433817410	13989	Economy	6300.00
0005433817411	13989	Economy	6300.00
0005435982075	2326	Business	184500.00
0005433753926	2326	Business	184500.00
0005432984532	2326	Business	184500.00
0005433753951	2326	Business	184500.00
0005435982091	2326	Business	184500.00
0005433753959	2326	Business	184500.00
0005433753939	2326	Business	184500.00
0005433434264	2326	Business	184500.00
0005434731116	2326	Business	184500.00
0005433753936	2326	Business	184500.00
0005432869435	2326	Business	184500.00
0005433434215	2326	Business	184500.00
0005433753963	2326	Business	184500.00
0005433434338	2326	Business	184500.00
0005433434386	2326	Business	184500.00
0005432226027	2326	Business	184500.00
0005433753953	2326	Business	184500.00
0005435982067	2326	Business	184500.00
0005433753924	2326	Business	184500.00
0005433753949	2326	Business	184500.00
0005432655477	2326	Business	184500.00
0005433434387	2326	Business	184500.00
0005435982056	2326	Business	184500.00
0005432226023	2326	Business	184500.00
0005435982076	2326	Business	184500.00
0005433434263	2326	Economy	67700.00
0005434731102	2326	Economy	67700.00
0005435982094	2326	Economy	67700.00
0005434731105	2326	Economy	67700.00
0005435982080	2326	Economy	61500.00
0005433753934	2326	Economy	61500.00
0005432226025	2326	Economy	61500.00
0005432226029	2326	Economy	61500.00
0005433753929	2326	Economy	61500.00
0005433434262	2326	Economy	61500.00
0005432984661	2326	Economy	61500.00
0005435982084	2326	Economy	61500.00
0005433753921	2326	Economy	61500.00
0005434731101	2326	Economy	61500.00
0005432984662	2326	Economy	61500.00
0005433766620	2326	Economy	61500.00
0005433753932	2326	Economy	61500.00
0005432300234	2326	Economy	61500.00
0005433753952	2326	Economy	61500.00
0005433753950	2326	Economy	61500.00
0005435982063	2326	Economy	61500.00
0005433434247	2326	Economy	61500.00
0005435982071	2326	Economy	61500.00
0005433434230	2326	Economy	61500.00
0005433434322	2326	Economy	61500.00
0005435982062	2326	Economy	61500.00
0005435982081	2326	Economy	61500.00
0005433434371	2326	Economy	61500.00
0005432869414	2326	Economy	61500.00
0005432655480	2326	Economy	61500.00
0005435982065	2326	Economy	61500.00
0005435982061	2326	Economy	61500.00
0005432655475	2326	Economy	61500.00
0005433753964	2326	Economy	61500.00
0005433753944	2326	Economy	61500.00
0005435982089	2326	Economy	61500.00
0005434731129	2326	Economy	61500.00
0005433753943	2326	Economy	61500.00
0005433753931	2326	Economy	61500.00
0005435982095	2326	Economy	61500.00
0005433753919	2326	Economy	61500.00
0005432869460	2326	Economy	61500.00
0005432226028	2326	Economy	61500.00
0005433753918	2326	Economy	61500.00
0005433434372	2326	Economy	61500.00
0005433753965	2326	Economy	61500.00
0005432655473	2326	Economy	61500.00
0005435982092	2326	Economy	61500.00
0005432984507	2326	Economy	61500.00
0005433753935	2326	Economy	61500.00
0005435982090	2326	Economy	61500.00
0005433753941	2326	Economy	61500.00
0005433434233	2326	Economy	61500.00
0005433753917	2326	Economy	61500.00
0005435982072	2326	Economy	61500.00
0005433753962	2326	Economy	61500.00
0005433753915	2326	Economy	61500.00
0005433753938	2326	Economy	61500.00
0005433434373	2326	Economy	61500.00
0005433753920	2326	Economy	61500.00
0005432984688	2326	Economy	61500.00
0005435982088	2326	Economy	61500.00
0005433753967	2326	Economy	61500.00
0005432984657	2326	Economy	61500.00
0005433434277	2326	Economy	61500.00
0005432984617	2326	Economy	61500.00
0005433753937	2326	Economy	61500.00
0005433753912	2326	Economy	61500.00
0005433753914	2326	Economy	61500.00
0005432869455	2326	Economy	61500.00
0005433753928	2326	Economy	61500.00
0005432984609	2326	Economy	61500.00
0005433753956	2326	Economy	61500.00
0005433753925	2326	Economy	61500.00
0005433753957	2326	Economy	61500.00
0005435982093	2326	Economy	61500.00
0005432984511	2326	Economy	61500.00
0005435982058	2326	Economy	61500.00
0005432655472	2326	Economy	61500.00
0005435982086	2326	Economy	61500.00
0005433753955	2326	Economy	61500.00
0005433753942	2326	Economy	61500.00
0005433753930	2326	Economy	61500.00
0005432984517	2326	Economy	61500.00
0005435982068	2326	Economy	61500.00
0005433753916	2326	Economy	61500.00
0005435982070	2326	Economy	61500.00
0005433766622	2326	Economy	61500.00
0005433766621	2326	Economy	61500.00
0005432984726	2326	Economy	61500.00
0005432226024	2326	Economy	61500.00
0005432984702	2326	Economy	61500.00
0005433753947	2326	Economy	61500.00
0005432226026	2326	Economy	61500.00
0005435982057	2326	Economy	61500.00
0005432655481	2326	Economy	61500.00
0005435982073	2326	Economy	61500.00
0005433753969	2326	Economy	61500.00
0005433753966	2326	Economy	61500.00
0005433766619	2326	Economy	67700.00
0005432655483	2326	Economy	67700.00
0005433434308	2326	Economy	61500.00
0005434731128	2326	Economy	61500.00
0005433764669	2326	Economy	61500.00
0005433753954	2326	Economy	67700.00
0005432300233	2326	Economy	67700.00
0005432984700	2326	Economy	61500.00
0005432984663	2326	Economy	61500.00
0005433753948	2326	Economy	61500.00
0005433434301	2326	Economy	61500.00
0005433753960	2326	Economy	61500.00
0005435982083	2326	Economy	61500.00
0005432984730	2326	Economy	61500.00
0005435982082	2326	Economy	61500.00
0005433434292	2326	Economy	61500.00
0005433434231	2326	Economy	61500.00
0005432655479	2326	Economy	61500.00
0005432655478	2326	Economy	61500.00
0005433764670	2326	Economy	61500.00
0005433434300	2326	Economy	61500.00
0005432984660	2326	Economy	61500.00
0005432869459	2326	Economy	61500.00
0005435982087	2326	Economy	61500.00
0005432984642	2326	Economy	61500.00
0005432984699	2326	Economy	61500.00
0005432655476	2326	Economy	61500.00
0005433434246	2326	Economy	61500.00
0005435982085	2326	Economy	61500.00
0005432984608	2326	Economy	61500.00
0005432984656	2326	Economy	61500.00
0005432300236	2326	Economy	61500.00
0005433434281	2326	Economy	61500.00
0005434731103	2326	Economy	61500.00
0005433753913	2326	Economy	61500.00
0005433753946	2326	Economy	61500.00
0005435982079	2326	Economy	61500.00
0005432984716	2326	Economy	61500.00
0005433753945	2326	Economy	61500.00
0005432984512	2326	Economy	61500.00
0005435982077	2326	Economy	61500.00
0005433753927	2326	Economy	61500.00
0005433753968	2326	Economy	61500.00
0005435982078	2326	Economy	61500.00
0005432300235	2326	Economy	61500.00
0005433434309	2326	Economy	61500.00
0005433753961	2326	Economy	61500.00
0005433434370	2326	Economy	61500.00
0005435982059	2326	Economy	61500.00
0005433434211	2326	Economy	61500.00
0005433434291	2326	Economy	61500.00
0005432984585	2326	Economy	61500.00
0005433753933	2326	Economy	61500.00
0005432869428	2326	Economy	61500.00
0005433434265	2326	Economy	61500.00
0005433434288	2326	Economy	61500.00
0005432300237	2326	Economy	61500.00
0005433753958	2326	Economy	61500.00
0005432984506	2326	Economy	61500.00
0005433434339	2326	Economy	61500.00
0005433753922	2326	Economy	61500.00
0005435982060	2326	Economy	61500.00
0005433753923	2326	Economy	61500.00
0005433753940	2326	Economy	61500.00
0005435982069	2326	Economy	61500.00
0005432300232	2326	Economy	61500.00
0005433434310	2326	Economy	61500.00
0005433434289	2326	Economy	61500.00
0005433434311	2326	Economy	61500.00
0005433434341	2326	Economy	61500.00
0005435982054	2326	Economy	61500.00
0005432655474	2326	Economy	61500.00
0005432655482	2326	Economy	61500.00
0005435982064	2326	Economy	61500.00
0005435982066	2326	Economy	61500.00
0005435982055	2326	Economy	61500.00
0005432655484	2326	Economy	61500.00
0005435982074	2326	Economy	61500.00
0005433753439	26181	Business	184500.00
0005435981707	26181	Business	184500.00
0005433753236	26181	Business	184500.00
0005432984927	26181	Business	184500.00
0005433753513	26181	Business	184500.00
0005433434538	26181	Business	184500.00
0005432984922	26181	Business	184500.00
0005432655342	26181	Business	184500.00
0005432984901	26181	Business	184500.00
0005432655375	26181	Business	184500.00
0005433434532	26181	Business	184500.00
0005433434542	26181	Business	184500.00
0005432869490	26181	Business	184500.00
0005435981699	26181	Business	184500.00
0005433434548	26181	Business	184500.00
0005433753538	26181	Business	184500.00
0005433753558	26181	Business	184500.00
0005433753382	26181	Business	184500.00
0005432655344	26181	Business	184500.00
0005433434549	26181	Business	184500.00
0005432051112	26181	Business	184500.00
0005435981599	26181	Business	184500.00
0005433434528	26181	Business	184500.00
0005432984915	26181	Business	184500.00
0005435981745	26181	Business	184500.00
0005432984902	26181	Business	184500.00
0005435981661	26181	Business	184500.00
0005433753601	26181	Business	184500.00
0005435981623	26181	Economy	67700.00
0005433753500	26181	Economy	67700.00
0005433753499	26181	Economy	67700.00
0005432049448	26181	Economy	61500.00
0005435981830	26181	Economy	67700.00
0005433434543	26181	Economy	61500.00
0005433753496	26181	Economy	61500.00
0005435981793	26181	Economy	61500.00
0005432984920	26181	Economy	61500.00
0005433753346	26181	Economy	61500.00
0005432984906	26181	Economy	61500.00
0005435981701	26181	Economy	61500.00
0005433753305	26181	Economy	61500.00
0005432655365	26181	Economy	61500.00
0005433434526	26181	Economy	61500.00
0005433753440	26181	Economy	61500.00
0005435981678	26181	Economy	61500.00
0005433753596	26181	Economy	61500.00
0005433753402	26181	Economy	61500.00
0005433764649	26181	Economy	61500.00
0005432984923	26181	Economy	61500.00
0005435981626	26181	Economy	61500.00
0005432984912	26181	Economy	61500.00
0005434731150	26181	Economy	61500.00
0005433753323	26181	Economy	61500.00
0005433753467	26181	Economy	61500.00
0005433753489	26181	Economy	61500.00
0005432869488	26181	Economy	61500.00
0005432869486	26181	Economy	61500.00
0005433434525	26181	Economy	61500.00
0005434731148	26181	Economy	61500.00
0005433753243	26181	Economy	61500.00
0005432869487	26181	Economy	61500.00
0005433753636	26181	Economy	61500.00
0005432984899	26181	Economy	61500.00
0005433434552	26181	Economy	61500.00
0005435981593	26181	Economy	61500.00
0005432984903	26181	Economy	61500.00
0005433753495	26181	Economy	61500.00
0005432655376	26181	Economy	61500.00
0005434731149	26181	Economy	61500.00
0005435981660	26181	Economy	61500.00
0005432869489	26181	Economy	61500.00
0005433434527	26181	Economy	61500.00
0005432984904	26181	Economy	61500.00
0005435981595	26181	Economy	61500.00
0005435981768	26181	Economy	61500.00
0005433753451	26181	Economy	61500.00
0005433434545	26181	Economy	61500.00
0005435981526	26181	Economy	61500.00
0005433753331	26181	Economy	61500.00
0005433434536	26181	Economy	61500.00
0005433753424	26181	Economy	61500.00
0005433434534	26181	Economy	61500.00
0005432984910	26181	Economy	61500.00
0005433753537	26181	Economy	61500.00
0005432655392	26181	Economy	61500.00
0005433434531	26181	Economy	61500.00
0005432984916	26181	Economy	61500.00
0005433434550	26181	Economy	61500.00
0005435981567	26181	Economy	61500.00
0005433753355	26181	Economy	61500.00
0005432984914	26181	Economy	61500.00
0005435981611	26181	Economy	61500.00
0005433434551	26181	Economy	61500.00
0005435981609	26181	Economy	61500.00
0005433753278	26181	Economy	61500.00
0005433753303	26181	Economy	61500.00
0005433753595	26181	Economy	61500.00
0005432984913	26181	Economy	61500.00
0005435981566	26181	Economy	61500.00
0005433764648	26181	Economy	61500.00
0005433753535	26181	Economy	61500.00
0005433434535	26181	Economy	61500.00
0005432984911	26181	Economy	61500.00
0005433434530	26181	Economy	61500.00
0005433766601	26181	Economy	61500.00
0005433753502	26181	Economy	61500.00
0005432984926	26181	Economy	61500.00
0005433753458	26181	Economy	61500.00
0005435981602	26181	Economy	61500.00
0005433753488	26181	Economy	61500.00
0005432984917	26181	Economy	61500.00
0005435981672	26181	Economy	61500.00
0005432984924	26181	Economy	61500.00
0005433753597	26181	Economy	61500.00
0005435981625	26181	Economy	61500.00
0005435981744	26181	Economy	61500.00
0005432984930	26181	Economy	61500.00
0005434731151	26181	Economy	61500.00
0005433753330	26181	Economy	61500.00
0005433753242	26181	Economy	61500.00
0005435981669	26181	Economy	61500.00
0005432051113	26181	Economy	67700.00
0005433766585	26181	Economy	61500.00
0005433434546	26181	Economy	61500.00
0005433753314	26181	Economy	61500.00
0005433753302	26181	Economy	67700.00
0005433434537	26181	Economy	61500.00
0005432984907	26181	Economy	61500.00
0005433434529	26181	Economy	61500.00
0005433753455	26181	Economy	61500.00
0005433753356	26181	Economy	61500.00
0005433753237	26181	Economy	61500.00
0005435981700	26181	Economy	61500.00
0005433766588	26181	Economy	61500.00
0005432049446	26181	Economy	61500.00
0005433753459	26181	Economy	61500.00
0005432984905	26181	Economy	61500.00
0005433753350	26181	Economy	61500.00
0005433753381	26181	Economy	61500.00
0005433753512	26181	Economy	61500.00
0005433753332	26181	Economy	61500.00
0005435981529	26181	Economy	61500.00
0005432984925	26181	Economy	61500.00
0005432655345	26181	Economy	61500.00
0005435981528	26181	Economy	61500.00
0005435981751	26181	Economy	61500.00
0005432984929	26181	Economy	61500.00
0005435981783	26181	Economy	61500.00
0005435981642	26181	Economy	61500.00
0005435981579	26181	Economy	61500.00
0005432984921	26181	Economy	61500.00
0005432655350	26181	Economy	61500.00
0005435981525	26181	Economy	61500.00
0005433434533	26181	Economy	61500.00
0005433753301	26181	Economy	61500.00
0005433764647	26181	Economy	61500.00
0005432984919	26181	Economy	61500.00
0005433434541	26181	Economy	61500.00
0005433753604	26181	Economy	61500.00
0005433753311	26181	Economy	61500.00
0005435981592	26181	Economy	61500.00
0005433753394	26181	Economy	61500.00
0005433753401	26181	Economy	61500.00
0005433434547	26181	Economy	61500.00
0005433753347	26181	Economy	61500.00
0005433766589	26181	Economy	61500.00
0005435981883	26181	Economy	61500.00
0005432049445	26181	Economy	61500.00
0005433753429	26181	Economy	61500.00
0005432984918	26181	Economy	61500.00
0005433434553	26181	Economy	61500.00
0005432051114	26181	Economy	61500.00
0005433434539	26181	Economy	61500.00
0005435981580	26181	Economy	61500.00
0005432869491	26181	Economy	61500.00
0005435981594	26181	Economy	61500.00
0005433753580	26181	Economy	61500.00
0005435981923	26181	Economy	61500.00
0005433753434	26181	Economy	61500.00
0005433753438	26181	Economy	61500.00
0005433753312	26181	Economy	61500.00
0005432984908	26181	Economy	61500.00
0005433753430	26181	Economy	61500.00
0005432049447	26181	Economy	61500.00
0005433753338	26181	Economy	61500.00
0005435981677	26181	Economy	61500.00
0005433753404	26181	Economy	61500.00
0005435981601	26181	Economy	61500.00
0005435981670	26181	Economy	61500.00
0005433753787	26181	Economy	61500.00
0005435981598	26181	Economy	61500.00
0005432984909	26181	Economy	61500.00
0005432049449	26181	Economy	61500.00
0005433434544	26181	Economy	61500.00
0005435981574	26181	Economy	61500.00
0005435981695	26181	Economy	61500.00
0005432984928	26181	Economy	61500.00
0005432984900	26181	Economy	61500.00
0005433434540	26181	Economy	61500.00
0005433753405	26181	Economy	61500.00
0005434374423	1491	Business	38900.00
0005432267860	1491	Business	38900.00
0005434374437	1491	Business	38900.00
0005434374443	1491	Business	38900.00
0005433151044	1491	Business	38900.00
0005434374454	1491	Business	38900.00
0005434374458	1491	Business	38900.00
0005434374431	1491	Business	38900.00
0005434374438	1491	Business	38900.00
0005434374449	1491	Economy	13000.00
0005433151091	1491	Economy	13000.00
0005433151026	1491	Economy	13000.00
0005434374459	1491	Economy	13000.00
0005433460426	1491	Economy	13000.00
0005433151041	1491	Economy	13000.00
0005432267861	1491	Economy	13000.00
0005433151022	1491	Economy	13000.00
0005434374446	1491	Economy	13000.00
0005433151043	1491	Economy	13000.00
0005434374425	1491	Economy	13000.00
0005433150962	1491	Economy	13000.00
0005434374445	1491	Economy	13000.00
0005433150958	1491	Economy	13000.00
0005434374453	1491	Economy	13000.00
0005432267863	1491	Economy	13000.00
0005433150983	1491	Economy	13000.00
0005432267864	1491	Economy	13000.00
0005434374421	1491	Economy	13000.00
0005434374442	1491	Economy	13000.00
0005433151053	1491	Economy	13000.00
0005434374426	1491	Economy	13000.00
0005434374439	1491	Economy	13000.00
0005433150920	1491	Economy	13000.00
0005433461578	1491	Economy	13000.00
0005434374451	1491	Economy	13000.00
0005433150991	1491	Economy	13000.00
0005432267862	1491	Economy	13000.00
0005432267859	1491	Economy	13000.00
0005433151042	1491	Economy	13000.00
0005434374435	1491	Economy	13000.00
0005434374436	1491	Economy	14300.00
0005433151004	1491	Economy	14300.00
0005433150942	1491	Economy	14300.00
0005433150984	1491	Economy	14300.00
0005434374432	1491	Economy	13000.00
0005434374447	1491	Economy	13000.00
0005434374430	1491	Economy	13000.00
0005433151024	1491	Economy	13000.00
0005433150940	1491	Economy	13000.00
0005433764650	1491	Economy	13000.00
0005434374448	1491	Economy	13000.00
0005433150829	1491	Economy	13000.00
0005434374433	1491	Economy	13000.00
0005432267858	1491	Economy	13000.00
0005433150979	1491	Economy	13000.00
0005433461579	1491	Economy	13000.00
0005433150929	1491	Economy	13000.00
0005434029617	1491	Economy	13000.00
0005433461577	1491	Economy	13000.00
0005433150978	1491	Economy	13000.00
0005434029616	1491	Economy	13000.00
0005434374455	1491	Economy	13000.00
0005434029614	1491	Economy	13000.00
0005433150941	1491	Economy	13000.00
0005433150873	1491	Economy	13000.00
0005434029615	1491	Economy	13000.00
0005433151013	1491	Economy	13000.00
0005433151156	1491	Economy	13000.00
0005433150966	1491	Economy	13000.00
0005433151025	1491	Economy	13000.00
0005433151054	1491	Economy	13000.00
0005432267865	1491	Economy	13000.00
0005434374450	1491	Economy	13000.00
0005433460424	1491	Economy	13000.00
0005434374429	1491	Economy	13000.00
0005433151036	1491	Economy	13000.00
0005434374424	1491	Economy	13000.00
0005433460425	1491	Economy	13000.00
0005433150832	1491	Economy	13000.00
0005434374456	1491	Economy	13000.00
0005434374440	1491	Economy	13000.00
0005434374422	1491	Economy	13000.00
0005433151069	1491	Economy	13000.00
0005433151002	1491	Economy	13000.00
0005433150844	1491	Economy	13000.00
0005433151157	1491	Economy	13000.00
0005434374457	1491	Economy	13000.00
0005434374441	1491	Economy	13000.00
0005434374434	1491	Economy	13000.00
0005434374428	1491	Economy	13000.00
0005434374444	1491	Economy	13000.00
0005434374452	1491	Economy	13000.00
0005434029618	1491	Economy	13000.00
0005433151003	1491	Economy	13000.00
0005433150959	1491	Economy	13000.00
0005433151092	1491	Economy	13000.00
0005434374427	1491	Economy	13000.00
0005433151235	20141	Business	38900.00
0005433151225	20141	Business	38900.00
0005434029643	20141	Business	38900.00
0005433151226	20141	Business	38900.00
0005434029644	20141	Business	38900.00
0005433151243	20141	Business	38900.00
0005433151234	20141	Business	38900.00
0005433151224	20141	Business	38900.00
0005433151227	20141	Economy	13000.00
0005434373863	20141	Economy	13000.00
0005433151249	20141	Economy	13000.00
0005433151215	20141	Economy	13000.00
0005433931449	20141	Economy	13000.00
0005433151218	20141	Economy	13000.00
0005433151238	20141	Economy	13000.00
0005433151231	20141	Economy	13000.00
0005434373929	20141	Economy	13000.00
0005433151232	20141	Economy	13000.00
0005433151236	20141	Economy	13000.00
0005434373862	20141	Economy	13000.00
0005433931451	20141	Economy	13000.00
0005432056281	20141	Economy	13000.00
0005434374058	20141	Economy	13000.00
0005434373930	20141	Economy	13000.00
0005433151219	20141	Economy	13000.00
0005433151242	20141	Economy	13000.00
0005433151217	20141	Economy	13000.00
0005432056278	20141	Economy	13000.00
0005434373957	20141	Economy	13000.00
0005434373941	20141	Economy	13000.00
0005433151240	20141	Economy	13000.00
0005434374036	20141	Economy	13000.00
0005433151248	20141	Economy	13000.00
0005433461564	20141	Economy	13000.00
0005433764670	20141	Economy	14300.00
0005433151216	20141	Economy	14300.00
0005433151241	20141	Economy	14300.00
0005434373934	20141	Economy	14300.00
0005433151222	20141	Economy	14300.00
0005433151250	20141	Economy	13000.00
0005434373901	20141	Economy	13000.00
0005433463862	20141	Economy	13000.00
0005433931450	20141	Economy	13000.00
0005434373902	20141	Economy	13000.00
0005433151221	20141	Economy	13000.00
0005434374002	20141	Economy	13000.00
0005432056280	20141	Economy	13000.00
0005434373942	20141	Economy	13000.00
0005433151233	20141	Economy	13000.00
0005433151246	20141	Economy	13000.00
0005434373933	20141	Economy	13000.00
0005433461563	20141	Economy	13000.00
0005434373963	20141	Economy	13000.00
0005433931452	20141	Economy	13000.00
0005434374008	20141	Economy	13000.00
0005432056279	20141	Economy	13000.00
0005433151220	20141	Economy	13000.00
0005434374001	20141	Economy	13000.00
0005434373932	20141	Economy	13000.00
0005433151223	20141	Economy	13000.00
0005433151237	20141	Economy	13000.00
0005433151247	20141	Economy	13000.00
0005433463861	20141	Economy	13000.00
0005433151244	20141	Economy	13000.00
0005434374042	20141	Economy	13000.00
0005434373945	20141	Economy	13000.00
0005433151228	20141	Economy	13000.00
0005433151239	20141	Economy	13000.00
0005433463863	20141	Economy	13000.00
0005433151229	20141	Economy	13000.00
0005433151245	20141	Economy	13000.00
0005434373958	20141	Economy	13000.00
0005433764669	20141	Economy	13000.00
0005433151230	20141	Economy	13000.00
0005434373931	20141	Economy	13000.00
0005432424203	505	Business	27500.00
0005432424218	505	Business	27500.00
0005432424208	505	Business	27500.00
0005432424214	505	Business	27500.00
0005432424198	505	Business	27500.00
0005432282826	505	Business	27500.00
0005432424195	505	Business	27500.00
0005432424224	505	Business	27500.00
0005432424229	505	Business	27500.00
0005432282828	505	Economy	10100.00
0005432424222	505	Economy	9200.00
0005432424202	505	Economy	9200.00
0005432424205	505	Economy	9200.00
0005432424230	505	Economy	9200.00
0005432424226	505	Economy	9200.00
0005432424211	505	Economy	9200.00
0005432282831	505	Economy	9200.00
0005432424213	505	Economy	9200.00
0005432424221	505	Economy	9200.00
0005432282830	505	Economy	9200.00
0005432424210	505	Economy	9200.00
0005432424200	505	Economy	9200.00
0005432424199	505	Economy	9200.00
0005432424227	505	Economy	9200.00
0005432424228	505	Economy	9200.00
0005432424216	505	Economy	9200.00
0005432424220	505	Economy	9200.00
0005432424196	505	Economy	10100.00
0005432424212	505	Economy	10100.00
0005432282829	505	Economy	9200.00
0005432424215	505	Economy	9200.00
0005432424190	505	Economy	9200.00
0005432424192	505	Economy	9200.00
0005432424209	505	Economy	9200.00
0005432424193	505	Economy	9200.00
0005432424206	505	Economy	9200.00
0005432424191	505	Economy	9200.00
0005432424207	505	Economy	9200.00
0005432424217	505	Economy	9200.00
0005432424223	505	Economy	9200.00
0005432424219	505	Economy	9200.00
0005432424197	505	Economy	9200.00
0005432424204	505	Economy	9200.00
0005432424201	505	Economy	9200.00
0005432424189	505	Economy	9200.00
0005432424225	505	Economy	9200.00
0005432282827	505	Economy	9200.00
0005432424194	505	Economy	9200.00
0005432302313	12872	Business	27500.00
0005432302311	12872	Economy	9200.00
0005432302312	12872	Economy	9200.00
0005432302314	12872	Economy	9200.00
0005432423605	12867	Business	27500.00
0005432423666	12867	Business	27500.00
0005432423801	12867	Business	27500.00
0005432423805	12867	Business	27500.00
0005432423809	12867	Business	27500.00
0005432423622	12867	Business	27500.00
0005432423667	12867	Economy	10100.00
0005432423709	12867	Economy	9200.00
0005432423772	12867	Economy	9200.00
0005432423683	12867	Economy	9200.00
0005432423692	12867	Economy	9200.00
0005432423687	12867	Economy	9200.00
0005432423800	12867	Economy	9200.00
0005432423790	12867	Economy	9200.00
0005432423693	12867	Economy	9200.00
0005432423782	12867	Economy	9200.00
0005432423650	12867	Economy	9200.00
0005432423643	12867	Economy	9200.00
0005432423791	12867	Economy	9200.00
0005432423672	12867	Economy	9200.00
0005432423688	12867	Economy	9200.00
0005432423702	12867	Economy	9200.00
0005432423736	12867	Economy	10100.00
0005432423738	12867	Economy	9200.00
0005432423808	12867	Economy	9200.00
0005432423818	12867	Economy	9200.00
0005432423789	12867	Economy	9200.00
0005432423630	12867	Economy	9200.00
0005432423703	12867	Economy	9200.00
0005432423633	12867	Economy	9200.00
0005432423737	12867	Economy	9200.00
0005432423764	12867	Economy	9200.00
0005432423684	12867	Economy	9200.00
0005432423691	12867	Economy	9200.00
0005432423803	12867	Economy	9200.00
0005432423623	12867	Economy	9200.00
0005432423629	12867	Economy	9200.00
0005432423804	12867	Economy	9200.00
0005433057291	441	Business	24500.00
0005432235596	441	Business	24500.00
0005433057322	441	Business	24500.00
0005433057399	441	Business	24500.00
0005434028280	441	Business	24500.00
0005434023400	441	Business	24500.00
0005434023370	441	Business	24500.00
0005432235603	441	Business	24500.00
0005433057483	441	Business	24500.00
0005434028281	441	Business	24500.00
0005434023342	441	Business	24500.00
0005433057458	441	Business	24500.00
0005434023386	441	Business	24500.00
0005433057375	441	Business	24500.00
0005432235602	441	Business	24500.00
0005434023339	441	Business	24500.00
0005433057518	441	Business	24500.00
0005434023353	441	Business	24500.00
0005434023368	441	Economy	9000.00
0005434023379	441	Economy	9000.00
0005433057359	441	Economy	8200.00
0005434023385	441	Economy	8200.00
0005434032000	441	Economy	8200.00
0005434023396	441	Economy	8200.00
0005434023351	441	Economy	8200.00
0005434023394	441	Economy	8200.00
0005434023375	441	Economy	8200.00
0005433057580	441	Economy	8200.00
0005434023362	441	Economy	8200.00
0005434023383	441	Economy	8200.00
0005434023350	441	Economy	8200.00
0005434023354	441	Economy	8200.00
0005434023347	441	Economy	8200.00
0005434023356	441	Economy	8200.00
0005434023397	441	Economy	8200.00
0005433929550	441	Economy	8200.00
0005433057323	441	Economy	8200.00
0005434023372	441	Economy	8200.00
0005434023348	441	Economy	8200.00
0005434023345	441	Economy	8200.00
0005433057381	441	Economy	8200.00
0005433929552	441	Economy	8200.00
0005434023390	441	Economy	8200.00
0005434735599	441	Economy	8200.00
0005434023377	441	Economy	8200.00
0005434023355	441	Economy	8200.00
0005432045601	441	Economy	8200.00
0005433057216	441	Economy	8200.00
0005434023334	441	Economy	8200.00
0005432235598	441	Economy	8200.00
0005434023338	441	Economy	8200.00
0005434023367	441	Economy	8200.00
0005433057591	441	Economy	8200.00
0005434735613	441	Economy	8200.00
0005434023388	441	Economy	8200.00
0005434023371	441	Economy	8200.00
0005434023389	441	Economy	8200.00
0005432045602	441	Economy	8200.00
0005433929566	441	Economy	8200.00
0005434023401	441	Economy	8200.00
0005433057329	441	Economy	8200.00
0005434023392	441	Economy	8200.00
0005433057515	441	Economy	8200.00
0005433057282	441	Economy	8200.00
0005434023359	441	Economy	8200.00
0005434023398	441	Economy	8200.00
0005434023380	441	Economy	8200.00
0005434023391	441	Economy	8200.00
0005434023374	441	Economy	8200.00
0005434735598	441	Economy	8200.00
0005433057343	441	Economy	8200.00
0005433057290	441	Economy	8200.00
0005434023365	441	Economy	8200.00
0005434031999	441	Economy	8200.00
0005433057321	441	Economy	8200.00
0005434023337	441	Economy	8200.00
0005433057287	441	Economy	8200.00
0005434023341	441	Economy	8200.00
0005432235599	441	Economy	8200.00
0005434028283	441	Economy	8200.00
0005432235597	441	Economy	8200.00
0005434023399	441	Economy	8200.00
0005434023363	441	Economy	8200.00
0005434031997	441	Economy	8200.00
0005434023369	441	Economy	9000.00
0005433057484	441	Economy	8200.00
0005433057255	441	Economy	8200.00
0005433057400	441	Economy	8200.00
0005434735607	441	Economy	9000.00
0005434023382	441	Economy	9000.00
0005433057296	441	Economy	8200.00
0005433057457	441	Economy	8200.00
0005433057380	441	Economy	8200.00
0005434023360	441	Economy	8200.00
0005434735620	441	Economy	8200.00
0005434023335	441	Economy	8200.00
0005434735603	441	Economy	8200.00
0005434023381	441	Economy	8200.00
0005434023336	441	Economy	8200.00
0005434023346	441	Economy	8200.00
0005433057297	441	Economy	8200.00
0005433057364	441	Economy	8200.00
0005433057425	441	Economy	8200.00
0005433057545	441	Economy	8200.00
0005434023378	441	Economy	8200.00
0005433057415	441	Economy	8200.00
0005434023376	441	Economy	8200.00
0005433057254	441	Economy	8200.00
0005433057448	441	Economy	8200.00
0005433057365	441	Economy	8200.00
0005434023384	441	Economy	8200.00
0005432045603	441	Economy	8200.00
0005433057208	441	Economy	8200.00
0005432235600	441	Economy	8200.00
0005434023393	441	Economy	8200.00
0005434029642	441	Economy	8200.00
0005432235601	441	Economy	8200.00
0005434023366	441	Economy	8200.00
0005434028282	441	Economy	8200.00
0005434023358	441	Economy	8200.00
0005434031995	441	Economy	8200.00
0005434023361	441	Economy	8200.00
0005434023344	441	Economy	8200.00
0005434023352	441	Economy	8200.00
0005433057371	441	Economy	8200.00
0005434029641	441	Economy	8200.00
0005433057217	441	Economy	8200.00
0005434031996	441	Economy	8200.00
0005434023343	441	Economy	8200.00
0005433057438	441	Economy	8200.00
0005434023357	441	Economy	8200.00
0005434023349	441	Economy	8200.00
0005433057447	441	Economy	8200.00
0005433057459	441	Economy	8200.00
0005434023340	441	Economy	8200.00
0005434031998	441	Economy	8200.00
0005433057517	441	Economy	8200.00
0005433057592	441	Economy	8200.00
0005433929551	441	Economy	8200.00
0005433057324	441	Economy	8200.00
0005434023395	441	Economy	8200.00
0005433057358	441	Economy	8200.00
0005434023364	441	Economy	8200.00
0005433929567	441	Economy	8200.00
0005434023387	441	Economy	8200.00
0005434023373	441	Economy	8200.00
0005433057401	441	Economy	8200.00
0005433057701	12693	Business	24500.00
0005434022842	12693	Business	24500.00
0005433057679	12693	Business	24500.00
0005434022574	12693	Business	24500.00
0005434022796	12693	Business	24500.00
0005433057677	12693	Business	24500.00
0005434735661	12693	Business	24500.00
0005433057695	12693	Business	24500.00
0005434022838	12693	Business	24500.00
0005434022723	12693	Business	24500.00
0005434022772	12693	Business	24500.00
0005434022591	12693	Business	24500.00
0005433057689	12693	Business	24500.00
0005434031948	12693	Business	24500.00
0005433057669	12693	Business	24500.00
0005434022537	12693	Business	24500.00
0005434022817	12693	Business	24500.00
0005433057699	12693	Business	24500.00
0005432156343	12693	Economy	9000.00
0005434023130	12693	Economy	8200.00
0005433057692	12693	Economy	8200.00
0005434022854	12693	Economy	8200.00
0005432156344	12693	Economy	8200.00
0005434022881	12693	Economy	8200.00
0005434022845	12693	Economy	8200.00
0005434735663	12693	Economy	8200.00
0005433057670	12693	Economy	8200.00
0005434023029	12693	Economy	8200.00
0005434031949	12693	Economy	8200.00
0005434022935	12693	Economy	8200.00
0005433057671	12693	Economy	8200.00
0005433929592	12693	Economy	8200.00
0005434022894	12693	Economy	8200.00
0005433684411	12693	Economy	8200.00
0005434022722	12693	Economy	8200.00
0005434022586	12693	Economy	8200.00
0005434022815	12693	Economy	8200.00
0005433057664	12693	Economy	8200.00
0005434735664	12693	Economy	8200.00
0005434022873	12693	Economy	8200.00
0005433684410	12693	Economy	8200.00
0005433057694	12693	Economy	8200.00
0005433057662	12693	Economy	8200.00
0005433057672	12693	Economy	8200.00
0005433057682	12693	Economy	8200.00
0005434022789	12693	Economy	8200.00
0005434022766	12693	Economy	8200.00
0005434022777	12693	Economy	8200.00
0005433057663	12693	Economy	8200.00
0005433057691	12693	Economy	8200.00
0005433057667	12693	Economy	8200.00
0005434022615	12693	Economy	8200.00
0005433929590	12693	Economy	8200.00
0005434735665	12693	Economy	8200.00
0005434022660	12693	Economy	8200.00
0005433057684	12693	Economy	8200.00
0005434022846	12693	Economy	8200.00
0005434023041	12693	Economy	8200.00
0005434022765	12693	Economy	8200.00
0005434022797	12693	Economy	8200.00
0005434031954	12693	Economy	8200.00
0005434022738	12693	Economy	8200.00
0005433057697	12693	Economy	8200.00
0005433057693	12693	Economy	8200.00
0005433057700	12693	Economy	8200.00
0005434022769	12693	Economy	8200.00
0005433057685	12693	Economy	8200.00
0005433057673	12693	Economy	8200.00
0005434022771	12693	Economy	8200.00
0005434022874	12693	Economy	8200.00
0005434028254	12693	Economy	8200.00
0005433057668	12693	Economy	8200.00
0005433684412	12693	Economy	8200.00
0005434022661	12693	Economy	8200.00
0005434735662	12693	Economy	9000.00
0005434022901	12693	Economy	9000.00
0005433057686	12693	Economy	8200.00
0005434022802	12693	Economy	8200.00
0005434022816	12693	Economy	8200.00
0005434022720	12693	Economy	9000.00
0005433057678	12693	Economy	9000.00
0005433057698	12693	Economy	8200.00
0005434029617	12693	Economy	8200.00
0005433057661	12693	Economy	8200.00
0005434031955	12693	Economy	8200.00
0005434022790	12693	Economy	8200.00
0005434022672	12693	Economy	8200.00
0005433057674	12693	Economy	8200.00
0005433057680	12693	Economy	8200.00
0005433057666	12693	Economy	8200.00
0005434022737	12693	Economy	8200.00
0005434022859	12693	Economy	8200.00
0005434022651	12693	Economy	8200.00
0005434022855	12693	Economy	8200.00
0005433929593	12693	Economy	8200.00
0005433057675	12693	Economy	8200.00
0005433057696	12693	Economy	8200.00
0005434022895	12693	Economy	8200.00
0005434023131	12693	Economy	8200.00
0005434022581	12693	Economy	8200.00
0005434029618	12693	Economy	8200.00
0005433057681	12693	Economy	8200.00
0005434029615	12693	Economy	8200.00
0005434022673	12693	Economy	8200.00
0005433057690	12693	Economy	8200.00
0005434029614	12693	Economy	8200.00
0005434022824	12693	Economy	8200.00
0005434023011	12693	Economy	8200.00
0005434022538	12693	Economy	8200.00
0005433057676	12693	Economy	8200.00
0005434022724	12693	Economy	8200.00
0005434022869	12693	Economy	8200.00
0005434022582	12693	Economy	8200.00
0005433057665	12693	Economy	8200.00
0005433057687	12693	Economy	8200.00
0005434023036	12693	Economy	8200.00
0005434022875	12693	Economy	8200.00
0005432157482	12693	Economy	8200.00
0005433057688	12693	Economy	8200.00
0005434022770	12693	Economy	8200.00
0005434022827	12693	Economy	8200.00
0005433057683	12693	Economy	8200.00
0005434022828	12693	Economy	8200.00
0005434022721	12693	Economy	8200.00
0005433929591	12693	Economy	8200.00
0005434029616	12693	Economy	8200.00
0005433035577	2138	Business	34700.00
0005433922803	2138	Business	34700.00
0005433922776	2138	Business	34700.00
0005433922766	2138	Business	34700.00
0005433035439	2138	Business	34700.00
0005433922769	2138	Business	34700.00
0005433922786	2138	Business	34700.00
0005433922805	2138	Business	34700.00
0005433922815	2138	Business	34700.00
0005432749752	2138	Business	34700.00
0005433922846	2138	Business	34700.00
0005433922800	2138	Business	34700.00
0005433035624	2138	Business	34700.00
0005433922813	2138	Business	34700.00
0005433922794	2138	Business	34700.00
0005433922782	2138	Business	34700.00
0005433035521	2138	Business	34700.00
0005432231514	2138	Business	34700.00
0005432749758	2138	Business	34700.00
0005433922792	2138	Business	34700.00
0005433035675	2138	Business	34700.00
0005433922787	2138	Business	34700.00
0005433035566	2138	Business	34700.00
0005433922829	2138	Business	34700.00
0005433922840	2138	Economy	12700.00
0005433922768	2138	Economy	12700.00
0005433035536	2138	Economy	12700.00
0005433922857	2138	Economy	11600.00
0005433922772	2138	Economy	11600.00
0005433922834	2138	Economy	11600.00
0005433035467	2138	Economy	11600.00
0005432231509	2138	Economy	11600.00
0005433922774	2138	Economy	11600.00
0005433922812	2138	Economy	11600.00
0005433035527	2138	Economy	11600.00
0005433922843	2138	Economy	11600.00
0005433922821	2138	Economy	11600.00
0005433035502	2138	Economy	11600.00
0005433922836	2138	Economy	11600.00
0005433035746	2138	Economy	11600.00
0005433875368	2138	Economy	11600.00
0005433929592	2138	Economy	11600.00
0005433922826	2138	Economy	11600.00
0005433922809	2138	Economy	11600.00
0005433922825	2138	Economy	11600.00
0005433035682	2138	Economy	11600.00
0005432044511	2138	Economy	11600.00
0005433035749	2138	Economy	11600.00
0005433035604	2138	Economy	11600.00
0005433035687	2138	Economy	11600.00
0005432044509	2138	Economy	11600.00
0005433922839	2138	Economy	11600.00
0005433922847	2138	Economy	11600.00
0005433922788	2138	Economy	11600.00
0005433035413	2138	Economy	11600.00
0005433922798	2138	Economy	11600.00
0005432231506	2138	Economy	11600.00
0005433035414	2138	Economy	11600.00
0005433922818	2138	Economy	11600.00
0005433922777	2138	Economy	11600.00
0005433922831	2138	Economy	11600.00
0005433875369	2138	Economy	11600.00
0005433922844	2138	Economy	11600.00
0005433922851	2138	Economy	11600.00
0005433922852	2138	Economy	11600.00
0005433922827	2138	Economy	11600.00
0005433922802	2138	Economy	11600.00
0005433922791	2138	Economy	11600.00
0005433922859	2138	Economy	11600.00
0005433922819	2138	Economy	11600.00
0005433922795	2138	Economy	11600.00
0005433922790	2138	Economy	11600.00
0005433922862	2138	Economy	11600.00
0005433035661	2138	Economy	11600.00
0005433922804	2138	Economy	11600.00
0005433035495	2138	Economy	11600.00
0005433922767	2138	Economy	11600.00
0005433931451	2138	Economy	11600.00
0005433922811	2138	Economy	11600.00
0005433922780	2138	Economy	11600.00
0005433035580	2138	Economy	11600.00
0005433035564	2138	Economy	11600.00
0005433929593	2138	Economy	11600.00
0005433922775	2138	Economy	11600.00
0005433922770	2138	Economy	11600.00
0005433922773	2138	Economy	11600.00
0005433922828	2138	Economy	11600.00
0005433922850	2138	Economy	11600.00
0005433931449	2138	Economy	11600.00
0005433922849	2138	Economy	11600.00
0005433922785	2138	Economy	11600.00
0005433922838	2138	Economy	11600.00
0005433035449	2138	Economy	11600.00
0005433035664	2138	Economy	11600.00
0005432231507	2138	Economy	11600.00
0005433922820	2138	Economy	11600.00
0005432231513	2138	Economy	11600.00
0005433929591	2138	Economy	11600.00
0005433035788	2138	Economy	11600.00
0005433922853	2138	Economy	11600.00
0005433035662	2138	Economy	12700.00
0005433035477	2138	Economy	11600.00
0005433922817	2138	Economy	11600.00
0005433922807	2138	Economy	11600.00
0005433922823	2138	Economy	12700.00
0005433922783	2138	Economy	12700.00
0005433922771	2138	Economy	11600.00
0005433922858	2138	Economy	11600.00
0005433922832	2138	Economy	11600.00
0005433035565	2138	Economy	11600.00
0005433922778	2138	Economy	11600.00
0005433922841	2138	Economy	11600.00
0005433922861	2138	Economy	11600.00
0005433922793	2138	Economy	11600.00
0005433035468	2138	Economy	11600.00
0005433922822	2138	Economy	11600.00
0005433035586	2138	Economy	11600.00
0005433922855	2138	Economy	11600.00
0005433922816	2138	Economy	11600.00
0005433922860	2138	Economy	11600.00
0005433035522	2138	Economy	11600.00
0005433922824	2138	Economy	11600.00
0005433922810	2138	Economy	11600.00
0005433035674	2138	Economy	11600.00
0005433922830	2138	Economy	11600.00
0005433035613	2138	Economy	11600.00
0005433922842	2138	Economy	11600.00
0005433931450	2138	Economy	11600.00
0005433035546	2138	Economy	11600.00
0005433035685	2138	Economy	11600.00
0005433035651	2138	Economy	11600.00
0005433035618	2138	Economy	11600.00
0005433922781	2138	Economy	11600.00
0005432231515	2138	Economy	11600.00
0005433922799	2138	Economy	11600.00
0005433922784	2138	Economy	11600.00
0005433929590	2138	Economy	11600.00
0005432231510	2138	Economy	11600.00
0005432231511	2138	Economy	11600.00
0005432231512	2138	Economy	11600.00
0005432044510	2138	Economy	11600.00
0005433035491	2138	Economy	11600.00
0005433922848	2138	Economy	11600.00
0005433922835	2138	Economy	11600.00
0005433922854	2138	Economy	11600.00
0005432231516	2138	Economy	11600.00
0005433035598	2138	Economy	11600.00
0005433922833	2138	Economy	11600.00
0005433035611	2138	Economy	11600.00
0005434028254	2138	Economy	11600.00
0005433922806	2138	Economy	11600.00
0005433035581	2138	Economy	11600.00
0005433922837	2138	Economy	11600.00
0005433035458	2138	Economy	11600.00
0005433922845	2138	Economy	11600.00
0005433922779	2138	Economy	11600.00
0005433035448	2138	Economy	11600.00
0005433922796	2138	Economy	11600.00
0005433922801	2138	Economy	11600.00
0005433931452	2138	Economy	11600.00
0005432231508	2138	Economy	11600.00
0005433035599	2138	Economy	11600.00
0005433035612	2138	Economy	11600.00
0005433922797	2138	Economy	11600.00
0005433922789	2138	Economy	11600.00
0005433922814	2138	Economy	11600.00
0005433035740	2138	Economy	11600.00
0005433035771	2138	Economy	11600.00
0005433035572	2138	Economy	11600.00
0005433922856	2138	Economy	11600.00
0005433922808	2138	Economy	11600.00
0005433035637	2138	Economy	11600.00
0005433922278	24109	Business	34700.00
0005433036027	24109	Business	34700.00
0005433036016	24109	Business	34700.00
0005433036043	24109	Business	34700.00
0005433922112	24109	Business	34700.00
0005433922066	24109	Business	34700.00
0005433921640	24109	Business	34700.00
0005433929540	24109	Business	34700.00
0005432206168	24109	Business	34700.00
0005433036056	24109	Business	34700.00
0005433036058	24109	Business	34700.00
0005433922138	24109	Business	34700.00
0005433921830	24109	Business	34700.00
0005433922076	24109	Business	34700.00
0005433921691	24109	Business	34700.00
0005433036032	24109	Business	34700.00
0005433921635	24109	Business	34700.00
0005433036048	24109	Business	34700.00
0005432206165	24109	Business	34700.00
0005433921854	24109	Business	34700.00
0005433922078	24109	Business	34700.00
0005433922098	24109	Business	34700.00
0005433929578	24109	Business	34700.00
0005433921889	24109	Business	34700.00
0005433921864	24109	Economy	12700.00
0005433922503	24109	Economy	12700.00
0005433036045	24109	Economy	12700.00
0005433921877	24109	Economy	11600.00
0005433921802	24109	Economy	11600.00
0005433875364	24109	Economy	11600.00
0005433921604	24109	Economy	11600.00
0005433921878	24109	Economy	11600.00
0005433921879	24109	Economy	11600.00
0005433921890	24109	Economy	11600.00
0005433921881	24109	Economy	11600.00
0005433036049	24109	Economy	11600.00
0005432206167	24109	Economy	11600.00
0005433922389	24109	Economy	11600.00
0005433922077	24109	Economy	11600.00
0005433921983	24109	Economy	11600.00
0005433922307	24109	Economy	11600.00
0005433922327	24109	Economy	11600.00
0005432206166	24109	Economy	11600.00
0005434028286	24109	Economy	11600.00
0005433036038	24109	Economy	11600.00
0005433036014	24109	Economy	11600.00
0005433921613	24109	Economy	11600.00
0005433921935	24109	Economy	11600.00
0005433922370	24109	Economy	11600.00
0005433922158	24109	Economy	11600.00
0005433922306	24109	Economy	11600.00
0005433036004	24109	Economy	11600.00
0005433921936	24109	Economy	11600.00
0005433921605	24109	Economy	11600.00
0005433922364	24109	Economy	11600.00
0005433875352	24109	Economy	11600.00
0005433036040	24109	Economy	11600.00
0005433922250	24109	Economy	11600.00
0005433922067	24109	Economy	11600.00
0005433036015	24109	Economy	11600.00
0005433036005	24109	Economy	11600.00
0005433922059	24109	Economy	11600.00
0005433036054	24109	Economy	11600.00
0005433922028	24109	Economy	11600.00
0005433929562	24109	Economy	11600.00
0005433921829	24109	Economy	11600.00
0005433036052	24109	Economy	11600.00
0005433922188	24109	Economy	11600.00
0005433921882	24109	Economy	11600.00
0005434028287	24109	Economy	11600.00
0005433036007	24109	Economy	11600.00
0005433922362	24109	Economy	11600.00
0005433036036	24109	Economy	11600.00
0005432206163	24109	Economy	11600.00
0005433922210	24109	Economy	11600.00
0005433036051	24109	Economy	11600.00
0005433921865	24109	Economy	11600.00
0005433921658	24109	Economy	11600.00
0005433922111	24109	Economy	11600.00
0005433036037	24109	Economy	11600.00
0005433922425	24109	Economy	11600.00
0005432207648	24109	Economy	11600.00
0005432207650	24109	Economy	11600.00
0005433929579	24109	Economy	11600.00
0005433036009	24109	Economy	11600.00
0005433921871	24109	Economy	11600.00
0005433922282	24109	Economy	11600.00
0005433036026	24109	Economy	11600.00
0005433036030	24109	Economy	11600.00
0005433922453	24109	Economy	11600.00
0005433922298	24109	Economy	11600.00
0005433921984	24109	Economy	11600.00
0005433036044	24109	Economy	11600.00
0005433036034	24109	Economy	11600.00
0005433036031	24109	Economy	11600.00
0005433922247	24109	Economy	11600.00
0005433036033	24109	Economy	11600.00
0005433922139	24109	Economy	11600.00
0005433922064	24109	Economy	12700.00
0005433922005	24109	Economy	11600.00
0005433036047	24109	Economy	11600.00
0005433922318	24109	Economy	12700.00
0005433921934	24109	Economy	12700.00
0005433922172	24109	Economy	11600.00
0005433921598	24109	Economy	11600.00
0005433921870	24109	Economy	11600.00
0005433036039	24109	Economy	11600.00
0005433921603	24109	Economy	11600.00
0005433036018	24109	Economy	11600.00
0005433036028	24109	Economy	11600.00
0005433036013	24109	Economy	11600.00
0005433929541	24109	Economy	11600.00
0005433921803	24109	Economy	11600.00
0005433921891	24109	Economy	11600.00
0005433921724	24109	Economy	11600.00
0005433036011	24109	Economy	11600.00
0005433036046	24109	Economy	11600.00
0005433036008	24109	Economy	11600.00
0005433921762	24109	Economy	11600.00
0005433036055	24109	Economy	11600.00
0005433036021	24109	Economy	11600.00
0005433921792	24109	Economy	11600.00
0005433921692	24109	Economy	11600.00
0005433922283	24109	Economy	11600.00
0005432206164	24109	Economy	11600.00
0005433921959	24109	Economy	11600.00
0005433036050	24109	Economy	11600.00
0005433036042	24109	Economy	11600.00
0005433922261	24109	Economy	11600.00
0005433921614	24109	Economy	11600.00
0005433921793	24109	Economy	11600.00
0005433922004	24109	Economy	11600.00
0005433921938	24109	Economy	11600.00
0005433931425	24109	Economy	11600.00
0005433922157	24109	Economy	11600.00
0005433921937	24109	Economy	11600.00
0005432207651	24109	Economy	11600.00
0005433922063	24109	Economy	11600.00
0005433036025	24109	Economy	11600.00
0005433036019	24109	Economy	11600.00
0005433036020	24109	Economy	11600.00
0005433922003	24109	Economy	11600.00
0005434028284	24109	Economy	11600.00
0005433036041	24109	Economy	11600.00
0005433036023	24109	Economy	11600.00
0005433036029	24109	Economy	11600.00
0005433036006	24109	Economy	11600.00
0005433921956	24109	Economy	11600.00
0005433036017	24109	Economy	11600.00
0005433921910	24109	Economy	11600.00
0005433921851	24109	Economy	11600.00
0005433036024	24109	Economy	11600.00
0005432207649	24109	Economy	11600.00
0005434028285	24109	Economy	11600.00
0005433036035	24109	Economy	11600.00
0005433922052	24109	Economy	11600.00
0005433922295	24109	Economy	11600.00
0005433922328	24109	Economy	11600.00
0005433036010	24109	Economy	11600.00
0005433036057	24109	Economy	11600.00
0005433921717	24109	Economy	11600.00
0005433921821	24109	Economy	11600.00
0005433036022	24109	Economy	11600.00
0005433036053	24109	Economy	11600.00
0005433036012	24109	Economy	11600.00
0005433922329	24109	Economy	11600.00
0005433921715	24109	Economy	11600.00
0005434031951	265	Business	83700.00
0005435142504	265	Business	83700.00
0005434724899	265	Business	83700.00
0005433180828	265	Business	83700.00
0005435142507	265	Business	83700.00
0005434724809	265	Business	83700.00
0005433233263	265	Business	83700.00
0005433289738	265	Business	83700.00
0005434724896	265	Business	83700.00
0005434550959	265	Business	83700.00
0005433233307	265	Business	83700.00
0005433233371	265	Business	83700.00
0005434731147	265	Business	83700.00
0005434550953	265	Business	83700.00
0005434724825	265	Business	83700.00
0005434724900	265	Business	83700.00
0005434724842	265	Business	83700.00
0005434550954	265	Business	83700.00
0005434724901	265	Business	83700.00
0005434724914	265	Business	83700.00
0005433233150	265	Business	83700.00
0005434550940	265	Business	83700.00
0005434724835	265	Business	83700.00
0005434724917	265	Business	83700.00
0005432277739	265	Business	83700.00
0005434550979	265	Business	83700.00
0005433233306	265	Business	83700.00
0005433233288	265	Comfort	47400.00
0005433180824	265	Comfort	47400.00
0005434724898	265	Comfort	47400.00
0005433289748	265	Comfort	47400.00
0005433180657	265	Comfort	47400.00
0005433233093	265	Comfort	47400.00
0005434731144	265	Comfort	47400.00
0005434550942	265	Comfort	47400.00
0005435142512	265	Comfort	47400.00
0005434550967	265	Comfort	47400.00
0005434302438	265	Comfort	47400.00
0005434724887	265	Comfort	47400.00
0005433233609	265	Comfort	47400.00
0005434724840	265	Comfort	47400.00
0005434724866	265	Comfort	47400.00
0005432277735	265	Comfort	47400.00
0005434724884	265	Comfort	47400.00
0005434550941	265	Comfort	47400.00
0005434550946	265	Comfort	47400.00
0005434724808	265	Comfort	47400.00
0005434550960	265	Comfort	47400.00
0005434550956	265	Comfort	47400.00
0005433233294	265	Comfort	47400.00
0005432277745	265	Comfort	47400.00
0005434550966	265	Comfort	47400.00
0005434724908	265	Comfort	47400.00
0005433180790	265	Comfort	47400.00
0005435142506	265	Comfort	47400.00
0005434724851	265	Comfort	47400.00
0005433233622	265	Comfort	47400.00
0005433289768	265	Comfort	47400.00
0005433233593	265	Comfort	47400.00
0005434724846	265	Comfort	47400.00
0005434724823	265	Comfort	47400.00
0005434735656	265	Comfort	47400.00
0005434550968	265	Comfort	47400.00
0005434731145	265	Comfort	47400.00
0005434550939	265	Comfort	47400.00
0005433180768	265	Economy	27900.00
0005434550955	265	Economy	27900.00
0005434724860	265	Economy	27900.00
0005434724903	265	Economy	27900.00
0005434724805	265	Economy	27900.00
0005433233368	265	Economy	27900.00
0005432277743	265	Economy	27900.00
0005433766590	265	Economy	27900.00
0005432277741	265	Economy	27900.00
0005433289742	265	Economy	27900.00
0005433289736	265	Economy	27900.00
0005433233268	265	Economy	27900.00
0005434550982	265	Economy	27900.00
0005434724813	265	Economy	27900.00
0005433233296	265	Economy	27900.00
0005434724895	265	Economy	27900.00
0005433180732	265	Economy	27900.00
0005434724889	265	Economy	27900.00
0005434550985	265	Economy	27900.00
0005433180845	265	Economy	27900.00
0005433233404	265	Economy	27900.00
0005434724874	265	Economy	27900.00
0005434724839	265	Economy	27900.00
0005435142503	265	Economy	27900.00
0005434550973	265	Economy	27900.00
0005434724905	265	Economy	27900.00
0005433233170	265	Economy	27900.00
0005434724861	265	Economy	27900.00
0005433180755	265	Economy	27900.00
0005434724855	265	Economy	27900.00
0005434724816	265	Economy	27900.00
0005433289754	265	Economy	27900.00
0005433131635	265	Economy	27900.00
0005434724838	265	Economy	27900.00
0005434724920	265	Economy	27900.00
0005434724812	265	Economy	27900.00
0005433233232	265	Economy	27900.00
0005434031975	265	Economy	27900.00
0005432277744	265	Economy	27900.00
0005434731143	265	Economy	27900.00
0005433233367	265	Economy	27900.00
0005434724819	265	Economy	27900.00
0005433180766	265	Economy	27900.00
0005434724910	265	Economy	27900.00
0005433180748	265	Economy	27900.00
0005434724829	265	Economy	27900.00
0005433233369	265	Economy	27900.00
0005434724859	265	Economy	27900.00
0005434724915	265	Economy	27900.00
0005434550937	265	Economy	27900.00
0005434724815	265	Economy	27900.00
0005434724854	265	Economy	27900.00
0005434550970	265	Economy	27900.00
0005433233114	265	Economy	27900.00
0005433180719	265	Economy	27900.00
0005434724904	265	Economy	27900.00
0005434724882	265	Economy	27900.00
0005433180843	265	Economy	27900.00
0005434724872	265	Economy	27900.00
0005433233607	265	Economy	27900.00
0005434550963	265	Economy	27900.00
0005433180822	265	Economy	30700.00
0005432277738	265	Economy	27900.00
0005434724848	265	Economy	27900.00
0005434724877	265	Economy	27900.00
0005433180693	265	Economy	30700.00
0005433233209	265	Economy	30700.00
0005434724878	265	Economy	27900.00
0005433233248	265	Economy	27900.00
0005434724875	265	Economy	27900.00
0005434550977	265	Economy	27900.00
0005433233444	265	Economy	27900.00
0005434724858	265	Economy	27900.00
0005433233277	265	Economy	27900.00
0005434550958	265	Economy	27900.00
0005434724844	265	Economy	27900.00
0005433233265	265	Economy	27900.00
0005434550936	265	Economy	27900.00
0005434550951	265	Economy	27900.00
0005434724918	265	Economy	27900.00
0005434724820	265	Economy	27900.00
0005433289737	265	Economy	27900.00
0005434550961	265	Economy	27900.00
0005434724876	265	Economy	27900.00
0005433131639	265	Economy	27900.00
0005434724890	265	Economy	27900.00
0005434724857	265	Economy	27900.00
0005434724799	265	Economy	27900.00
0005433180733	265	Economy	27900.00
0005433233299	265	Economy	27900.00
0005434550981	265	Economy	27900.00
0005433233324	265	Economy	27900.00
0005434724818	265	Economy	27900.00
0005434550986	265	Economy	27900.00
0005434724849	265	Economy	27900.00
0005434724802	265	Economy	27900.00
0005434724909	265	Economy	27900.00
0005433180761	265	Economy	27900.00
0005433233461	265	Economy	27900.00
0005434724881	265	Economy	27900.00
0005434550934	265	Economy	27900.00
0005434724798	265	Economy	27900.00
0005434724867	265	Economy	27900.00
0005434724824	265	Economy	27900.00
0005434724810	265	Economy	27900.00
0005433289755	265	Economy	27900.00
0005433233373	265	Economy	27900.00
0005434724873	265	Economy	27900.00
0005435142514	265	Economy	27900.00
0005434724892	265	Economy	27900.00
0005434735658	265	Economy	27900.00
0005434302856	265	Economy	27900.00
0005433233491	265	Economy	27900.00
0005434724886	265	Economy	27900.00
0005434731146	265	Economy	27900.00
0005434302436	265	Economy	27900.00
0005434724912	265	Economy	27900.00
0005434724868	265	Economy	27900.00
0005433766586	265	Economy	27900.00
0005434724831	265	Economy	27900.00
0005434724850	265	Economy	27900.00
0005433289725	265	Economy	27900.00
0005433233403	265	Economy	27900.00
0005434550975	265	Economy	27900.00
0005434031958	265	Economy	27900.00
0005433233113	265	Economy	27900.00
0005434724817	265	Economy	27900.00
0005433233098	265	Economy	27900.00
0005434724856	265	Economy	27900.00
0005433233578	265	Economy	27900.00
0005434724800	265	Economy	27900.00
0005434724830	265	Economy	27900.00
0005434724853	265	Economy	27900.00
0005435142510	265	Economy	27900.00
0005434550944	265	Economy	27900.00
0005433233292	265	Economy	27900.00
0005433289766	265	Economy	27900.00
0005434550933	265	Economy	27900.00
0005433180823	265	Economy	27900.00
0005434724897	265	Economy	27900.00
0005434550984	265	Economy	27900.00
0005433180791	265	Economy	27900.00
0005434550972	265	Economy	27900.00
0005434724801	265	Economy	27900.00
0005433233372	265	Economy	27900.00
0005434550938	265	Economy	27900.00
0005434724811	265	Economy	27900.00
0005434550935	265	Economy	27900.00
0005434724832	265	Economy	27900.00
0005434724852	265	Economy	27900.00
0005434550980	265	Economy	27900.00
0005434724807	265	Economy	27900.00
0005434724864	265	Economy	27900.00
0005432277734	265	Economy	27900.00
0005435142513	265	Economy	27900.00
0005433233466	265	Economy	27900.00
0005433180718	265	Economy	27900.00
0005434724907	265	Economy	27900.00
0005434724828	265	Economy	27900.00
0005433289767	265	Economy	27900.00
0005432277740	265	Economy	30700.00
0005433233330	265	Economy	30700.00
0005433289726	265	Economy	30700.00
0005434302437	265	Economy	30700.00
0005432277742	265	Economy	30700.00
0005434302435	265	Economy	27900.00
0005434550983	265	Economy	27900.00
0005434724894	265	Economy	27900.00
0005432277746	265	Economy	27900.00
0005434550969	265	Economy	27900.00
0005434724826	265	Economy	27900.00
0005434724871	265	Economy	27900.00
0005433180777	265	Economy	27900.00
0005433180789	265	Economy	27900.00
0005434724870	265	Economy	27900.00
0005434550974	265	Economy	27900.00
0005434724821	265	Economy	27900.00
0005434550978	265	Economy	27900.00
0005434724883	265	Economy	27900.00
0005434724814	265	Economy	27900.00
0005434550976	265	Economy	27900.00
0005432277736	265	Economy	27900.00
0005434724921	265	Economy	27900.00
0005433113502	265	Economy	27900.00
0005433289735	265	Economy	27900.00
0005434724879	265	Economy	27900.00
0005433180778	265	Economy	27900.00
0005433233289	265	Economy	27900.00
0005433233506	265	Economy	27900.00
0005434724911	265	Economy	27900.00
0005435142511	265	Economy	27900.00
0005434724906	265	Economy	27900.00
0005434550965	265	Economy	27900.00
0005433233097	265	Economy	27900.00
0005434724913	265	Economy	27900.00
0005433233465	265	Economy	27900.00
0005434724837	265	Economy	27900.00
0005434550950	265	Economy	27900.00
0005434724919	265	Economy	27900.00
0005432277737	265	Economy	27900.00
0005434724888	265	Economy	27900.00
0005435142505	265	Economy	27900.00
0005433233608	265	Economy	27900.00
0005434724803	265	Economy	27900.00
0005433233291	265	Economy	27900.00
0005433180844	265	Economy	27900.00
0005433766597	265	Economy	27900.00
0005434724902	265	Economy	27900.00
0005433233467	265	Economy	27900.00
0005434735660	265	Economy	27900.00
0005434724885	265	Economy	27900.00
0005434724836	265	Economy	27900.00
0005433233235	265	Economy	27900.00
0005433233287	265	Economy	27900.00
0005435142509	265	Economy	27900.00
0005434550945	265	Economy	27900.00
0005434550947	265	Economy	27900.00
0005434724891	265	Economy	27900.00
0005434735659	265	Economy	27900.00
0005433766582	265	Economy	27900.00
0005434550932	265	Economy	27900.00
0005434550943	265	Economy	27900.00
0005434724841	265	Economy	27900.00
0005434550957	265	Economy	27900.00
0005434724880	265	Economy	27900.00
0005434550952	265	Economy	27900.00
0005434724862	265	Economy	27900.00
0005434735657	265	Economy	27900.00
0005434724916	265	Economy	27900.00
0005434724833	265	Economy	27900.00
0005434724804	265	Economy	27900.00
0005434550964	265	Economy	27900.00
0005434724869	265	Economy	27900.00
0005434550962	265	Economy	27900.00
0005434724865	265	Economy	27900.00
0005433233169	265	Economy	27900.00
0005434724797	265	Economy	27900.00
0005435142508	265	Economy	27900.00
0005434550971	265	Economy	27900.00
0005434724843	265	Economy	27900.00
0005433233571	265	Economy	27900.00
0005434724822	265	Economy	27900.00
0005434724893	265	Economy	27900.00
0005433180751	265	Economy	27900.00
0005433180656	265	Economy	27900.00
0005434724845	265	Economy	27900.00
0005434724834	265	Economy	27900.00
0005433233267	265	Economy	27900.00
0005433233262	265	Economy	27900.00
0005434724806	265	Economy	27900.00
0005433233514	265	Economy	27900.00
0005434724827	265	Economy	27900.00
0005434724847	265	Economy	27900.00
0005434550948	265	Economy	27900.00
0005433233515	265	Economy	27900.00
0005433233331	265	Economy	27900.00
0005434724863	265	Economy	27900.00
0005434550949	265	Economy	27900.00
0005433180977	9869	Business	83700.00
0005434550414	9869	Business	83700.00
0005434724380	9869	Business	83700.00
0005433113524	9869	Business	83700.00
0005434723921	9869	Business	83700.00
0005433233915	9869	Business	83700.00
0005433233864	9869	Business	83700.00
0005434724182	9869	Business	83700.00
0005434724069	9869	Business	83700.00
0005432199216	9869	Business	83700.00
0005433233870	9869	Business	83700.00
0005433233871	9869	Business	83700.00
0005434723762	9869	Business	83700.00
0005434723945	9869	Business	83700.00
0005434550317	9869	Business	83700.00
0005433233911	9869	Business	83700.00
0005434723504	9869	Business	83700.00
0005433233912	9869	Business	83700.00
0005433233895	9869	Business	83700.00
0005434550526	9869	Business	83700.00
0005433180980	9869	Business	83700.00
0005434550262	9869	Business	83700.00
0005434724073	9869	Business	83700.00
0005434550336	9869	Business	83700.00
0005434550448	9869	Business	83700.00
0005434724109	9869	Business	83700.00
0005433233892	9869	Business	83700.00
0005434550463	9869	Comfort	47400.00
0005434723696	9869	Business	83700.00
0005434723818	9869	Comfort	47400.00
0005434550283	9869	Comfort	47400.00
0005434724198	9869	Comfort	47400.00
0005434724104	9869	Comfort	47400.00
0005434723878	9869	Comfort	47400.00
0005434724202	9869	Comfort	47400.00
0005434723919	9869	Comfort	47400.00
0005433233910	9869	Comfort	47400.00
0005433180958	9869	Comfort	47400.00
0005434723794	9869	Comfort	47400.00
0005433180968	9869	Comfort	47400.00
0005433233858	9869	Comfort	47400.00
0005434723742	9869	Comfort	47400.00
0005434723563	9869	Comfort	47400.00
0005433233856	9869	Comfort	47400.00
0005434723799	9869	Comfort	47400.00
0005433180971	9869	Comfort	47400.00
0005433180962	9869	Comfort	47400.00
0005434724342	9869	Comfort	47400.00
0005433180983	9869	Comfort	47400.00
0005434724072	9869	Comfort	47400.00
0005434723583	9869	Comfort	47400.00
0005434723609	9869	Comfort	47400.00
0005434731103	9869	Comfort	47400.00
0005434723328	9869	Comfort	47400.00
0005434724007	9869	Comfort	47400.00
0005434723577	9869	Comfort	47400.00
0005433126822	9869	Comfort	47400.00
0005434723462	9869	Comfort	47400.00
0005433233908	9869	Comfort	47400.00
0005434723846	9869	Comfort	47400.00
0005434723796	9869	Comfort	47400.00
0005433233866	9869	Comfort	47400.00
0005434724041	9869	Comfort	47400.00
0005434723937	9869	Comfort	47400.00
0005434724019	9869	Comfort	47400.00
0005433233872	9869	Comfort	47400.00
0005432199209	9869	Economy	27900.00
0005434550417	9869	Economy	27900.00
0005433233889	9869	Economy	27900.00
0005433233863	9869	Economy	27900.00
0005434723859	9869	Economy	27900.00
0005434550459	9869	Economy	27900.00
0005433233906	9869	Economy	27900.00
0005434723860	9869	Economy	27900.00
0005434723394	9869	Economy	27900.00
0005434550427	9869	Economy	27900.00
0005433180965	9869	Economy	27900.00
0005433233859	9869	Economy	27900.00
0005433766619	9869	Economy	27900.00
0005434550520	9869	Economy	27900.00
0005433180964	9869	Economy	27900.00
0005433233900	9869	Economy	27900.00
0005433289812	9869	Economy	27900.00
0005433766620	9869	Economy	27900.00
0005434550569	9869	Economy	27900.00
0005434550416	9869	Economy	27900.00
0005435142381	9869	Economy	27900.00
0005434723944	9869	Economy	27900.00
0005433180960	9869	Economy	27900.00
0005433180966	9869	Economy	27900.00
0005434550342	9869	Economy	27900.00
0005434550572	9869	Economy	27900.00
0005434032001	9869	Economy	27900.00
0005434724051	9869	Economy	27900.00
0005433233854	9869	Economy	27900.00
0005433180961	9869	Economy	27900.00
0005434724074	9869	Economy	27900.00
0005434724070	9869	Economy	27900.00
0005432199212	9869	Economy	27900.00
0005434723779	9869	Economy	27900.00
0005433180973	9869	Economy	27900.00
0005434723463	9869	Economy	27900.00
0005434723681	9869	Economy	27900.00
0005434731105	9869	Economy	27900.00
0005434550677	9869	Economy	27900.00
0005434723923	9869	Economy	27900.00
0005434724194	9869	Economy	27900.00
0005434723895	9869	Economy	27900.00
0005434723865	9869	Economy	27900.00
0005434550624	9869	Economy	27900.00
0005434723446	9869	Economy	27900.00
0005434550399	9869	Economy	27900.00
0005434723936	9869	Economy	27900.00
0005434723790	9869	Economy	27900.00
0005434724229	9869	Economy	27900.00
0005433233901	9869	Economy	27900.00
0005433233869	9869	Economy	27900.00
0005433289809	9869	Economy	27900.00
0005434550628	9869	Economy	27900.00
0005434550571	9869	Economy	27900.00
0005434723677	9869	Economy	27900.00
0005434723727	9869	Economy	27900.00
0005434550503	9869	Economy	27900.00
0005434723454	9869	Economy	27900.00
0005434723628	9869	Economy	27900.00
0005434724263	9869	Economy	30700.00
0005434723829	9869	Economy	27900.00
0005434550418	9869	Economy	30700.00
0005434723752	9869	Economy	27900.00
0005434550428	9869	Economy	30700.00
0005434550400	9869	Economy	27900.00
0005433233913	9869	Economy	27900.00
0005434724110	9869	Economy	27900.00
0005434302386	9869	Economy	30700.00
0005433233887	9869	Economy	30700.00
0005434723788	9869	Economy	27900.00
0005434302397	9869	Economy	30700.00
0005433233907	9869	Economy	27900.00
0005434723595	9869	Economy	27900.00
0005433233888	9869	Economy	27900.00
0005433180975	9869	Economy	27900.00
0005434723839	9869	Economy	27900.00
0005434550358	9869	Economy	27900.00
0005434723819	9869	Economy	27900.00
0005433233876	9869	Economy	27900.00
0005434723572	9869	Economy	27900.00
0005433180982	9869	Economy	27900.00
0005434723800	9869	Economy	27900.00
0005433233853	9869	Economy	27900.00
0005434550529	9869	Economy	27900.00
0005433233886	9869	Economy	27900.00
0005435142353	9869	Economy	27900.00
0005434723787	9869	Economy	27900.00
0005434723943	9869	Economy	27900.00
0005434723842	9869	Economy	27900.00
0005434723447	9869	Economy	27900.00
0005435142373	9869	Economy	27900.00
0005433233868	9869	Economy	27900.00
0005432199210	9869	Economy	27900.00
0005434724322	9869	Economy	27900.00
0005434723582	9869	Economy	27900.00
0005434723616	9869	Economy	27900.00
0005434723778	9869	Economy	27900.00
0005434550460	9869	Economy	27900.00
0005434731102	9869	Economy	27900.00
0005434550341	9869	Economy	27900.00
0005434550702	9869	Economy	27900.00
0005434723821	9869	Economy	27900.00
0005434723920	9869	Economy	27900.00
0005434550642	9869	Economy	27900.00
0005434723717	9869	Economy	27900.00
0005434550434	9869	Economy	27900.00
0005434302396	9869	Economy	27900.00
0005433233877	9869	Economy	27900.00
0005434723598	9869	Economy	27900.00
0005433289810	9869	Economy	27900.00
0005434723342	9869	Economy	27900.00
0005433233881	9869	Economy	27900.00
0005434550479	9869	Economy	27900.00
0005434550282	9869	Economy	27900.00
0005434723824	9869	Economy	27900.00
0005432199211	9869	Economy	27900.00
0005434550345	9869	Economy	27900.00
0005434550701	9869	Economy	27900.00
0005434724029	9869	Economy	27900.00
0005433233909	9869	Economy	27900.00
0005433233862	9869	Economy	27900.00
0005434550553	9869	Economy	27900.00
0005434724186	9869	Economy	27900.00
0005433180979	9869	Economy	27900.00
0005434731129	9869	Economy	27900.00
0005433180972	9869	Economy	27900.00
0005434723682	9869	Economy	27900.00
0005434723836	9869	Economy	27900.00
0005433766622	9869	Economy	27900.00
0005434723728	9869	Economy	27900.00
0005434550575	9869	Economy	27900.00
0005433129253	9869	Economy	27900.00
0005435142379	9869	Economy	27900.00
0005434723959	9869	Economy	27900.00
0005434723680	9869	Economy	27900.00
0005433180976	9869	Economy	27900.00
0005434723697	9869	Economy	27900.00
0005434302394	9869	Economy	27900.00
0005434723751	9869	Economy	27900.00
0005433126820	9869	Economy	27900.00
0005434723676	9869	Economy	27900.00
0005434550277	9869	Economy	27900.00
0005433180969	9869	Economy	27900.00
0005433233885	9869	Economy	27900.00
0005434724163	9869	Economy	27900.00
0005434550415	9869	Economy	27900.00
0005433233890	9869	Economy	27900.00
0005434723764	9869	Economy	27900.00
0005433180984	9869	Economy	27900.00
0005434724023	9869	Economy	27900.00
0005434724169	9869	Economy	27900.00
0005434723617	9869	Economy	27900.00
0005434724033	9869	Economy	27900.00
0005433233894	9869	Economy	27900.00
0005432199215	9869	Economy	27900.00
0005433233916	9869	Economy	27900.00
0005434723701	9869	Economy	27900.00
0005434723538	9869	Economy	27900.00
0005434723867	9869	Economy	27900.00
0005434550623	9869	Economy	27900.00
0005434723552	9869	Economy	27900.00
0005434550382	9869	Economy	27900.00
0005434723395	9869	Economy	27900.00
0005434723942	9869	Economy	27900.00
0005434723593	9869	Economy	27900.00
0005433233896	9869	Economy	27900.00
0005433233860	9869	Economy	27900.00
0005434723922	9869	Economy	27900.00
0005433180981	9869	Economy	30700.00
0005434550645	9869	Economy	30700.00
0005434550435	9869	Economy	30700.00
0005433233891	9869	Economy	30700.00
0005434723891	9869	Economy	30700.00
0005434723960	9869	Economy	27900.00
0005433180963	9869	Economy	27900.00
0005434723716	9869	Economy	27900.00
0005433233861	9869	Economy	27900.00
0005434550602	9869	Economy	27900.00
0005433233867	9869	Economy	27900.00
0005434724101	9869	Economy	27900.00
0005434550525	9869	Economy	27900.00
0005435142372	9869	Economy	27900.00
0005434550676	9869	Economy	27900.00
0005434302387	9869	Economy	27900.00
0005433233879	9869	Economy	27900.00
0005433233855	9869	Economy	27900.00
0005433233905	9869	Economy	27900.00
0005433289811	9869	Economy	27900.00
0005433126821	9869	Economy	27900.00
0005433233873	9869	Economy	27900.00
0005434723820	9869	Economy	27900.00
0005434731128	9869	Economy	27900.00
0005434724220	9869	Economy	27900.00
0005434723639	9869	Economy	27900.00
0005433180974	9869	Economy	27900.00
0005434723789	9869	Economy	27900.00
0005434724042	9869	Economy	27900.00
0005433180978	9869	Economy	27900.00
0005433113525	9869	Economy	27900.00
0005434723777	9869	Economy	27900.00
0005434723726	9869	Economy	27900.00
0005434723700	9869	Economy	27900.00
0005433233914	9869	Economy	27900.00
0005434724321	9869	Economy	27900.00
0005434723594	9869	Economy	27900.00
0005434032003	9869	Economy	27900.00
0005434723571	9869	Economy	27900.00
0005434724091	9869	Economy	27900.00
0005433180970	9869	Economy	27900.00
0005433233898	9869	Economy	27900.00
0005433129252	9869	Economy	27900.00
0005435142389	9869	Economy	27900.00
0005433233897	9869	Economy	27900.00
0005434550359	9869	Economy	27900.00
0005433766621	9869	Economy	27900.00
0005434724267	9869	Economy	27900.00
0005434724050	9869	Economy	27900.00
0005433233899	9869	Economy	27900.00
0005434723461	9869	Economy	27900.00
0005434724003	9869	Economy	27900.00
0005434723900	9869	Economy	27900.00
0005434731116	9869	Economy	27900.00
0005433233903	9869	Economy	27900.00
0005434724454	9869	Economy	27900.00
0005433233878	9869	Economy	27900.00
0005434723793	9869	Economy	27900.00
0005434724020	9869	Economy	27900.00
0005434723729	9869	Economy	27900.00
0005434723695	9869	Economy	27900.00
0005433233882	9869	Economy	27900.00
0005434723890	9869	Economy	27900.00
0005433233904	9869	Economy	27900.00
0005434724144	9869	Economy	27900.00
0005434550524	9869	Economy	27900.00
0005434723596	9869	Economy	27900.00
0005434723455	9869	Economy	27900.00
0005434550344	9869	Economy	27900.00
0005434723763	9869	Economy	27900.00
0005433113523	9869	Economy	27900.00
0005434550398	9869	Economy	27900.00
0005434032002	9869	Economy	27900.00
0005435142397	9869	Economy	27900.00
0005433233893	9869	Economy	27900.00
0005433233865	9869	Economy	27900.00
0005432199213	9869	Economy	27900.00
0005433233857	9869	Economy	27900.00
0005435142380	9869	Economy	27900.00
0005433233874	9869	Economy	27900.00
0005434723537	9869	Economy	27900.00
0005433180959	9869	Economy	27900.00
0005433233884	9869	Economy	27900.00
0005433233902	9869	Economy	27900.00
0005433233875	9869	Economy	27900.00
0005433180967	9869	Economy	27900.00
0005433233880	9869	Economy	27900.00
0005434550675	9869	Economy	27900.00
0005433289808	9869	Economy	27900.00
0005434724147	9869	Economy	27900.00
0005434723551	9869	Economy	27900.00
0005434723597	9869	Economy	27900.00
0005434731101	9869	Economy	27900.00
0005434550523	9869	Economy	27900.00
0005434723397	9869	Economy	27900.00
0005432199214	9869	Economy	27900.00
0005433233883	9869	Economy	27900.00
0005432527274	7737	Business	42100.00
0005434067177	7737	Business	42100.00
0005435212717	7737	Business	42100.00
0005435212614	7737	Business	42100.00
0005432535811	7737	Business	42100.00
0005434067211	7737	Business	42100.00
0005435212474	7737	Business	42100.00
0005434067207	7737	Business	42100.00
0005432150152	7737	Business	42100.00
0005432527251	7737	Business	42100.00
0005435212920	7737	Business	42100.00
0005432527327	7737	Business	42100.00
0005435212633	7737	Business	42100.00
0005435212471	7737	Business	42100.00
0005434067195	7737	Business	42100.00
0005435212743	7737	Business	42100.00
0005435212551	7737	Business	42100.00
0005432527298	7737	Business	42100.00
0005435212683	7737	Business	42100.00
0005435212693	7737	Business	42100.00
0005432527285	7737	Business	42100.00
0005432527369	7737	Business	42100.00
0005432527303	7737	Business	42100.00
0005432069576	7737	Business	42100.00
0005435212509	7737	Business	42100.00
0005435212431	7737	Business	42100.00
0005432527314	7737	Comfort	23900.00
0005434067174	7737	Business	42100.00
0005435212692	7737	Comfort	23900.00
0005434067218	7737	Comfort	23900.00
0005434067231	7737	Comfort	23900.00
0005434067168	7737	Comfort	23900.00
0005434067227	7737	Comfort	23900.00
0005432527320	7737	Comfort	23900.00
0005432527335	7737	Comfort	23900.00
0005434067186	7737	Comfort	23900.00
0005432527330	7737	Comfort	23900.00
0005432527368	7737	Comfort	23900.00
0005432527273	7737	Comfort	23900.00
0005435212813	7737	Comfort	23900.00
0005434067198	7737	Comfort	23900.00
0005433656621	7737	Comfort	23900.00
0005432527318	7737	Comfort	23900.00
0005432069581	7737	Comfort	23900.00
0005432527355	7737	Comfort	23900.00
0005432537047	7737	Comfort	23900.00
0005432527306	7737	Comfort	23900.00
0005432527282	7737	Comfort	23900.00
0005434067170	7737	Comfort	23900.00
0005432527347	7737	Comfort	23900.00
0005432527352	7737	Comfort	23900.00
0005434067202	7737	Comfort	23900.00
0005432527345	7737	Comfort	23900.00
0005434067215	7737	Comfort	23900.00
0005432069587	7737	Comfort	23900.00
0005432428911	7737	Comfort	23900.00
0005435212653	7737	Comfort	23900.00
0005434067209	7737	Comfort	23900.00
0005435212705	7737	Comfort	23900.00
0005432527377	7737	Comfort	23900.00
0005434067197	7737	Comfort	23900.00
0005434067233	7737	Comfort	23900.00
0005432527367	7737	Comfort	23900.00
0005434067237	7737	Comfort	23900.00
0005432533275	7737	Comfort	23900.00
0005432527260	7737	Comfort	23900.00
0005432527305	7737	Comfort	23900.00
0005433656626	7737	Economy	14000.00
0005434067173	7737	Economy	14000.00
0005435212514	7737	Economy	14000.00
0005432150155	7737	Economy	14000.00
0005434067223	7737	Economy	14000.00
0005434067169	7737	Economy	14000.00
0005434067224	7737	Economy	14000.00
0005432527295	7737	Economy	14000.00
0005432533276	7737	Economy	14000.00
0005435212659	7737	Economy	14000.00
0005435212599	7737	Economy	14000.00
0005435630934	7737	Economy	14000.00
0005432527359	7737	Economy	14000.00
0005432150150	7737	Economy	14000.00
0005432527290	7737	Economy	14000.00
0005434067210	7737	Economy	14000.00
0005434067190	7737	Economy	14000.00
0005434067183	7737	Economy	14000.00
0005432527257	7737	Economy	14000.00
0005432527315	7737	Economy	14000.00
0005432527268	7737	Economy	14000.00
0005435725529	7737	Economy	14000.00
0005432527343	7737	Economy	14000.00
0005434067196	7737	Economy	14000.00
0005435212409	7737	Economy	14000.00
0005432527255	7737	Economy	14000.00
0005432150153	7737	Economy	14000.00
0005435212556	7737	Economy	14000.00
0005432527334	7737	Economy	14000.00
0005432527337	7737	Economy	14000.00
0005432527322	7737	Economy	14000.00
0005432527363	7737	Economy	14000.00
0005434067181	7737	Economy	14000.00
0005432527325	7737	Economy	14000.00
0005435212445	7737	Economy	14000.00
0005432527287	7737	Economy	14000.00
0005432527249	7737	Economy	14000.00
0005434067213	7737	Economy	14000.00
0005435212578	7737	Economy	14000.00
0005432527336	7737	Economy	14000.00
0005435212760	7737	Economy	14000.00
0005435212734	7737	Economy	14000.00
0005432527329	7737	Economy	14000.00
0005432527312	7737	Economy	14000.00
0005432069575	7737	Economy	14000.00
0005432428910	7737	Economy	14000.00
0005432527373	7737	Economy	14000.00
0005432527248	7737	Economy	14000.00
0005432527297	7737	Economy	14000.00
0005435630937	7737	Economy	14000.00
0005432527356	7737	Economy	14000.00
0005432527304	7737	Economy	14000.00
0005435212684	7737	Economy	14000.00
0005432527245	7737	Economy	14000.00
0005432069582	7737	Economy	14000.00
0005432527357	7737	Economy	14000.00
0005432150151	7737	Economy	14000.00
0005435212660	7737	Economy	14000.00
0005432535808	7737	Economy	14000.00
0005432527263	7737	Economy	14000.00
0005432527307	7737	Economy	14000.00
0005432069579	7737	Economy	14000.00
0005432527344	7737	Economy	15400.00
0005434067225	7737	Economy	14000.00
0005432527291	7737	Economy	15400.00
0005432069583	7737	Economy	15400.00
0005435212921	7737	Economy	14000.00
0005434067238	7737	Economy	15400.00
0005432527341	7737	Economy	14000.00
0005433656618	7737	Economy	15400.00
0005435212636	7737	Economy	14000.00
0005432527375	7737	Economy	14000.00
0005432527311	7737	Economy	14000.00
0005432527339	7737	Economy	14000.00
0005432527267	7737	Economy	14000.00
0005435212706	7737	Economy	14000.00
0005435212710	7737	Economy	14000.00
0005432527340	7737	Economy	14000.00
0005432527264	7737	Economy	14000.00
0005435212635	7737	Economy	14000.00
0005434067212	7737	Economy	14000.00
0005432527275	7737	Economy	14000.00
0005432428912	7737	Economy	14000.00
0005432527280	7737	Economy	14000.00
0005435212591	7737	Economy	14000.00
0005435212553	7737	Economy	14000.00
0005432527266	7737	Economy	14000.00
0005432527362	7737	Economy	14000.00
0005432069577	7737	Economy	14000.00
0005432527326	7737	Economy	14000.00
0005435212592	7737	Economy	14000.00
0005435212634	7737	Economy	14000.00
0005432527376	7737	Economy	14000.00
0005432150158	7737	Economy	14000.00
0005435212432	7737	Economy	14000.00
0005434067185	7737	Economy	14000.00
0005434067204	7737	Economy	14000.00
0005432527258	7737	Economy	14000.00
0005434067234	7737	Economy	14000.00
0005432527247	7737	Economy	14000.00
0005432527270	7737	Economy	14000.00
0005432069578	7737	Economy	14000.00
0005435212520	7737	Economy	14000.00
0005435212523	7737	Economy	14000.00
0005432527374	7737	Economy	14000.00
0005435725517	7737	Economy	14000.00
0005434067194	7737	Economy	14000.00
0005434067217	7737	Economy	14000.00
0005432527299	7737	Economy	14000.00
0005432535810	7737	Economy	14000.00
0005435212609	7737	Economy	14000.00
0005435212470	7737	Economy	14000.00
0005432527346	7737	Economy	14000.00
0005435212707	7737	Economy	14000.00
0005434067216	7737	Economy	14000.00
0005434067178	7737	Economy	14000.00
0005432069573	7737	Economy	14000.00
0005435212753	7737	Economy	14000.00
0005432535809	7737	Economy	14000.00
0005432527351	7737	Economy	14000.00
0005432527252	7737	Economy	14000.00
0005432527253	7737	Economy	14000.00
0005432533277	7737	Economy	14000.00
0005434067182	7737	Economy	14000.00
0005432527365	7737	Economy	14000.00
0005435212694	7737	Economy	14000.00
0005435212563	7737	Economy	14000.00
0005434067180	7737	Economy	14000.00
0005432527246	7737	Economy	14000.00
0005435212637	7737	Economy	14000.00
0005435212473	7737	Economy	14000.00
0005432150154	7737	Economy	14000.00
0005432069580	7737	Economy	14000.00
0005432527316	7737	Economy	14000.00
0005434067221	7737	Economy	14000.00
0005432527358	7737	Economy	14000.00
0005435212674	7737	Economy	14000.00
0005434067208	7737	Economy	14000.00
0005435630924	7737	Economy	14000.00
0005432527301	7737	Economy	14000.00
0005435212358	7737	Economy	14000.00
0005432527254	7737	Economy	14000.00
0005434067167	7737	Economy	14000.00
0005434067222	7737	Economy	14000.00
0005435212812	7737	Economy	14000.00
0005432537046	7737	Economy	14000.00
0005435212552	7737	Economy	14000.00
0005435212557	7737	Economy	14000.00
0005432527348	7737	Economy	14000.00
0005434067189	7737	Economy	14000.00
0005432527313	7737	Economy	14000.00
0005435212434	7737	Economy	14000.00
0005432069584	7737	Economy	14000.00
0005434067187	7737	Economy	14000.00
0005434067201	7737	Economy	14000.00
0005434067193	7737	Economy	14000.00
0005432527328	7737	Economy	14000.00
0005434067232	7737	Economy	14000.00
0005435212396	7737	Economy	14000.00
0005432527256	7737	Economy	14000.00
0005432527350	7737	Economy	14000.00
0005432527333	7737	Economy	14000.00
0005432428909	7737	Economy	14000.00
0005435212664	7737	Economy	14000.00
0005432527310	7737	Economy	14000.00
0005432527324	7737	Economy	14000.00
0005435212819	7737	Economy	14000.00
0005432527317	7737	Economy	14000.00
0005432150157	7737	Economy	14000.00
0005432527296	7737	Economy	14000.00
0005432527354	7737	Economy	14000.00
0005432527308	7737	Economy	14000.00
0005432527293	7737	Economy	14000.00
0005435212354	7737	Economy	14000.00
0005435212691	7737	Economy	15400.00
0005432527269	7737	Economy	14000.00
0005432527371	7737	Economy	15400.00
0005432527286	7737	Economy	15400.00
0005435212757	7737	Economy	15400.00
0005435212702	7737	Economy	15400.00
0005435212332	7737	Economy	14000.00
0005435212613	7737	Economy	15400.00
0005435212464	7737	Economy	14000.00
0005435212555	7737	Economy	14000.00
0005434067220	7737	Economy	14000.00
0005432527353	7737	Economy	14000.00
0005435212735	7737	Economy	14000.00
0005432527250	7737	Economy	14000.00
0005435212815	7737	Economy	14000.00
0005435212589	7737	Economy	14000.00
0005435212736	7737	Economy	14000.00
0005434067199	7737	Economy	14000.00
0005432537045	7737	Economy	14000.00
0005432527279	7737	Economy	14000.00
0005434067219	7737	Economy	14000.00
0005432527361	7737	Economy	14000.00
0005434067176	7737	Economy	14000.00
0005435212598	7737	Economy	14000.00
0005435212521	7737	Economy	14000.00
0005435212652	7737	Economy	14000.00
0005432527289	7737	Economy	14000.00
0005432150156	7737	Economy	14000.00
0005435212510	7737	Economy	14000.00
0005432527323	7737	Economy	14000.00
0005432527372	7737	Economy	14000.00
0005435212564	7737	Economy	14000.00
0005432527284	7737	Economy	14000.00
0005432533278	7737	Economy	14000.00
0005433656623	7737	Economy	14000.00
0005434067226	7737	Economy	14000.00
0005434067184	7737	Economy	14000.00
0005432527300	7737	Economy	14000.00
0005435725518	7737	Economy	14000.00
0005432527276	7737	Economy	14000.00
0005434067188	7737	Economy	14000.00
0005432069585	7737	Economy	14000.00
0005435212562	7737	Economy	14000.00
0005432069586	7737	Economy	14000.00
0005432527261	7737	Economy	14000.00
0005432069574	7737	Economy	14000.00
0005432527277	7737	Economy	14000.00
0005433656617	7737	Economy	14000.00
0005434067192	7737	Economy	14000.00
0005435212641	7737	Economy	14000.00
0005434067230	7737	Economy	14000.00
0005434067203	7737	Economy	14000.00
0005432527278	7737	Economy	14000.00
0005435212554	7737	Economy	14000.00
0005432527370	7737	Economy	14000.00
0005434067214	7737	Economy	14000.00
0005432527288	7737	Economy	14000.00
0005434067175	7737	Economy	14000.00
0005432527272	7737	Economy	14000.00
0005435212357	7737	Economy	14000.00
0005435212818	7737	Economy	14000.00
0005432527294	7737	Economy	14000.00
0005434067191	7737	Economy	14000.00
0005432527262	7737	Economy	14000.00
0005432527259	7737	Economy	14000.00
0005432527309	7737	Economy	14000.00
0005434067206	7737	Economy	14000.00
0005432527332	7737	Economy	14000.00
0005432527281	7737	Economy	14000.00
0005432527319	7737	Economy	14000.00
0005432527331	7737	Economy	14000.00
0005432527271	7737	Economy	14000.00
0005434067200	7737	Economy	14000.00
0005434067171	7737	Economy	14000.00
0005435212623	7737	Economy	14000.00
0005435212508	7737	Economy	14000.00
0005432527364	7737	Economy	14000.00
0005435212758	7737	Economy	14000.00
0005434067179	7737	Economy	14000.00
0005435212408	7737	Economy	14000.00
0005434067229	7737	Economy	14000.00
0005435212447	7737	Economy	14000.00
0005432527360	7737	Economy	14000.00
0005432527244	7737	Economy	14000.00
0005432535807	7737	Economy	14000.00
0005434067172	7737	Economy	14000.00
0005434067235	7737	Economy	14000.00
0005432527349	7737	Economy	14000.00
0005434067205	7737	Economy	14000.00
0005434067236	7737	Economy	14000.00
0005432527342	7737	Economy	14000.00
0005432527366	7737	Economy	14000.00
0005432533279	7737	Economy	14000.00
0005435212701	7737	Economy	14000.00
0005435212638	7737	Economy	14000.00
0005435630925	7737	Economy	14000.00
0005432527338	7737	Economy	14000.00
0005432527265	7737	Economy	14000.00
0005434067228	7737	Economy	14000.00
0005432527292	7737	Economy	14000.00
0005435212759	7737	Economy	14000.00
0005432527302	7737	Economy	14000.00
0005432527321	7737	Economy	14000.00
0005432527283	7737	Economy	14000.00
0005435423985	5333	Business	43100.00
0005434344038	5333	Business	43100.00
0005435613028	5333	Business	43100.00
0005432133128	5333	Business	43100.00
0005435423987	5333	Business	43100.00
0005435424021	5333	Business	43100.00
0005434244526	5333	Business	43100.00
0005435613101	5333	Business	43100.00
0005434573275	5333	Business	43100.00
0005434573282	5333	Business	43100.00
0005435613091	5333	Business	43100.00
0005435613108	5333	Business	43100.00
0005435319457	5333	Business	43100.00
0005434244480	5333	Business	43100.00
0005432133131	5333	Business	43100.00
0005435613033	5333	Business	43100.00
0005435097164	5333	Business	43100.00
0005435423868	5333	Business	43100.00
0005435613105	5333	Business	43100.00
0005435319470	5333	Business	43100.00
0005432133127	5333	Business	43100.00
0005435613085	5333	Business	43100.00
0005434573283	5333	Business	43100.00
0005435302122	5333	Business	43100.00
0005434344041	5333	Business	43100.00
0005432133135	5333	Business	43100.00
0005434344030	5333	Business	43100.00
0005433719099	5333	Business	43100.00
0005435423653	5333	Comfort	24400.00
0005435424200	5333	Comfort	24400.00
0005435613110	5333	Comfort	24400.00
0005435613099	5333	Comfort	24400.00
0005435613083	5333	Comfort	24400.00
0005435302121	5333	Comfort	24400.00
0005434244598	5333	Comfort	24400.00
0005434244635	5333	Comfort	24400.00
0005432133141	5333	Comfort	24400.00
0005435423762	5333	Comfort	24400.00
0005435423876	5333	Comfort	24400.00
0005435613095	5333	Comfort	24400.00
0005435613044	5333	Comfort	24400.00
0005434244599	5333	Comfort	24400.00
0005435319433	5333	Comfort	24400.00
0005435423763	5333	Comfort	24400.00
0005435423945	5333	Comfort	24400.00
0005432047529	5333	Comfort	24400.00
0005435424001	5333	Comfort	24400.00
0005435423988	5333	Comfort	24400.00
0005435424017	5333	Comfort	24400.00
0005435613056	5333	Comfort	24400.00
0005435613076	5333	Comfort	24400.00
0005434244666	5333	Comfort	24400.00
0005435302123	5333	Comfort	24400.00
0005434244519	5333	Comfort	24400.00
0005435423661	5333	Comfort	24400.00
0005434244620	5333	Comfort	24400.00
0005432363377	5333	Comfort	24400.00
0005434244527	5333	Comfort	24400.00
0005435319460	5333	Comfort	24400.00
0005435423941	5333	Comfort	24400.00
0005435555358	5333	Comfort	24400.00
0005435613045	5333	Comfort	24400.00
0005434244686	5333	Comfort	24400.00
0005434244625	5333	Comfort	24400.00
0005435423841	5333	Comfort	24400.00
0005435423758	5333	Comfort	24400.00
0005435613063	5333	Comfort	24400.00
0005434344029	5333	Comfort	24400.00
0005435613057	5333	Comfort	24400.00
0005434244479	5333	Economy	14400.00
0005435424162	5333	Economy	14400.00
0005435380232	5333	Economy	14400.00
0005434573286	5333	Economy	14400.00
0005435319463	5333	Economy	14400.00
0005435423826	5333	Economy	14400.00
0005435613097	5333	Economy	14400.00
0005435613104	5333	Economy	14400.00
0005435302148	5333	Economy	14400.00
0005435423654	5333	Economy	14400.00
0005435613121	5333	Economy	14400.00
0005432133137	5333	Economy	14400.00
0005435424037	5333	Economy	14400.00
0005434573285	5333	Economy	14400.00
0005435423862	5333	Economy	14400.00
0005435423757	5333	Economy	14400.00
0005434244682	5333	Economy	14400.00
0005434244579	5333	Economy	14400.00
0005435424065	5333	Economy	14400.00
0005432840987	5333	Economy	14400.00
0005435613020	5333	Economy	14400.00
0005435490209	5333	Economy	14400.00
0005435319467	5333	Economy	14400.00
0005435613120	5333	Economy	14400.00
0005432133136	5333	Economy	14400.00
0005435613122	5333	Economy	14400.00
0005435613080	5333	Economy	14400.00
0005435424040	5333	Economy	14400.00
0005435613062	5333	Economy	14400.00
0005435613092	5333	Economy	14400.00
0005435424078	5333	Economy	14400.00
0005435424043	5333	Economy	14400.00
0005435423866	5333	Economy	14400.00
0005434573277	5333	Economy	14400.00
0005434344031	5333	Economy	14400.00
0005435423744	5333	Economy	14400.00
0005435613038	5333	Economy	14400.00
0005435613052	5333	Economy	14400.00
0005435424029	5333	Economy	14400.00
0005434244705	5333	Economy	14400.00
0005435424272	5333	Economy	14400.00
0005434244653	5333	Economy	14400.00
0005435423828	5333	Economy	14400.00
0005435613087	5333	Economy	14400.00
0005434573274	5333	Economy	14400.00
0005435423702	5333	Economy	14400.00
0005432133133	5333	Economy	14400.00
0005435423950	5333	Economy	14400.00
0005434244626	5333	Economy	14400.00
0005432133139	5333	Economy	14400.00
0005434573281	5333	Economy	14400.00
0005434344027	5333	Economy	14400.00
0005434244516	5333	Economy	14400.00
0005434344047	5333	Economy	14400.00
0005435423936	5333	Economy	14400.00
0005435380235	5333	Economy	14400.00
0005434244547	5333	Economy	14400.00
0005435613036	5333	Economy	14400.00
0005435613069	5333	Economy	14400.00
0005434344032	5333	Economy	14400.00
0005435613106	5333	Economy	14400.00
0005435613111	5333	Economy	15800.00
0005434244592	5333	Economy	14400.00
0005435423745	5333	Economy	15800.00
0005435423867	5333	Economy	15800.00
0005435613077	5333	Economy	14400.00
0005434344044	5333	Economy	14400.00
0005435423748	5333	Economy	15800.00
0005435613088	5333	Economy	15800.00
0005435424038	5333	Economy	14400.00
0005435613024	5333	Economy	15800.00
0005435613064	5333	Economy	14400.00
0005434344051	5333	Economy	14400.00
0005434244555	5333	Economy	14400.00
0005435613058	5333	Economy	14400.00
0005435423848	5333	Economy	14400.00
0005435613027	5333	Economy	14400.00
0005435423905	5333	Economy	14400.00
0005435423939	5333	Economy	14400.00
0005435613078	5333	Economy	14400.00
0005435613103	5333	Economy	14400.00
0005435097158	5333	Economy	14400.00
0005434244483	5333	Economy	14400.00
0005434656528	5333	Economy	14400.00
0005435613046	5333	Economy	14400.00
0005435424234	5333	Economy	14400.00
0005434244515	5333	Economy	14400.00
0005435423937	5333	Economy	14400.00
0005435613117	5333	Economy	14400.00
0005435613030	5333	Economy	14400.00
0005435423810	5333	Economy	14400.00
0005435613089	5333	Economy	14400.00
0005434344039	5333	Economy	14400.00
0005435097157	5333	Economy	14400.00
0005434344056	5333	Economy	14400.00
0005435613032	5333	Economy	14400.00
0005435423696	5333	Economy	14400.00
0005435613075	5333	Economy	14400.00
0005435613094	5333	Economy	14400.00
0005435613100	5333	Economy	14400.00
0005432840979	5333	Economy	14400.00
0005434244529	5333	Economy	14400.00
0005435423723	5333	Economy	14400.00
0005432133132	5333	Economy	14400.00
0005435097160	5333	Economy	14400.00
0005434344042	5333	Economy	14400.00
0005434344059	5333	Economy	14400.00
0005432133129	5333	Economy	14400.00
0005435613026	5333	Economy	14400.00
0005435613041	5333	Economy	14400.00
0005435380233	5333	Economy	14400.00
0005435097165	5333	Economy	14400.00
0005434344036	5333	Economy	14400.00
0005435097161	5333	Economy	14400.00
0005435424036	5333	Economy	14400.00
0005434244593	5333	Economy	14400.00
0005434573276	5333	Economy	14400.00
0005435424060	5333	Economy	14400.00
0005432133140	5333	Economy	14400.00
0005435613040	5333	Economy	14400.00
0005435613037	5333	Economy	14400.00
0005435613034	5333	Economy	14400.00
0005435613031	5333	Economy	14400.00
0005435613043	5333	Economy	14400.00
0005435613084	5333	Economy	14400.00
0005435423906	5333	Economy	14400.00
0005435613029	5333	Economy	14400.00
0005435613113	5333	Economy	14400.00
0005435424236	5333	Economy	14400.00
0005435097162	5333	Economy	14400.00
0005435613081	5333	Economy	14400.00
0005434344046	5333	Economy	14400.00
0005434573278	5333	Economy	14400.00
0005435423765	5333	Economy	14400.00
0005435613079	5333	Economy	14400.00
0005435555357	5333	Economy	14400.00
0005435613070	5333	Economy	14400.00
0005435423869	5333	Economy	14400.00
0005434244482	5333	Economy	14400.00
0005435613066	5333	Economy	14400.00
0005434344043	5333	Economy	14400.00
0005435423811	5333	Economy	14400.00
0005435423943	5333	Economy	14400.00
0005435613114	5333	Economy	14400.00
0005435613023	5333	Economy	14400.00
0005435613116	5333	Economy	14400.00
0005435423787	5333	Economy	14400.00
0005434244562	5333	Economy	14400.00
0005435613124	5333	Economy	14400.00
0005435613059	5333	Economy	14400.00
0005434244594	5333	Economy	14400.00
0005435424201	5333	Economy	14400.00
0005435423984	5333	Economy	14400.00
0005435613090	5333	Economy	14400.00
0005434344058	5333	Economy	14400.00
0005435423741	5333	Economy	14400.00
0005435613035	5333	Economy	14400.00
0005435613086	5333	Economy	14400.00
0005435613055	5333	Economy	14400.00
0005435424209	5333	Economy	14400.00
0005435423910	5333	Economy	14400.00
0005435424019	5333	Economy	14400.00
0005435613082	5333	Economy	14400.00
0005434244619	5333	Economy	14400.00
0005435423946	5333	Economy	14400.00
0005435613065	5333	Economy	14400.00
0005434244586	5333	Economy	14400.00
0005434244548	5333	Economy	14400.00
0005434244622	5333	Economy	14400.00
0005435613096	5333	Economy	15800.00
0005434344045	5333	Economy	15800.00
0005434344054	5333	Economy	15800.00
0005435613072	5333	Economy	15800.00
0005435613074	5333	Economy	15800.00
0005432047532	5333	Economy	14400.00
0005435613071	5333	Economy	14400.00
0005434344053	5333	Economy	14400.00
0005435319455	5333	Economy	14400.00
0005435319430	5333	Economy	14400.00
0005434244523	5333	Economy	14400.00
0005435319434	5333	Economy	14400.00
0005434344049	5333	Economy	14400.00
0005435424208	5333	Economy	14400.00
0005435613112	5333	Economy	14400.00
0005435423725	5333	Economy	14400.00
0005435613049	5333	Economy	14400.00
0005435423701	5333	Economy	14400.00
0005432047530	5333	Economy	14400.00
0005434344024	5333	Economy	14400.00
0005435613042	5333	Economy	14400.00
0005435613047	5333	Economy	14400.00
0005434344037	5333	Economy	14400.00
0005435423847	5333	Economy	14400.00
0005435302147	5333	Economy	14400.00
0005435613118	5333	Economy	14400.00
0005435613025	5333	Economy	14400.00
0005434573280	5333	Economy	14400.00
0005435613039	5333	Economy	14400.00
0005435097163	5333	Economy	14400.00
0005435424018	5333	Economy	14400.00
0005432133126	5333	Economy	14400.00
0005432133134	5333	Economy	14400.00
0005435613125	5333	Economy	14400.00
0005435423935	5333	Economy	14400.00
0005434344048	5333	Economy	14400.00
0005434344040	5333	Economy	14400.00
0005435613119	5333	Economy	14400.00
0005435423825	5333	Economy	14400.00
0005435423940	5333	Economy	14400.00
0005434344050	5333	Economy	14400.00
0005435613067	5333	Economy	14400.00
0005435304992	5333	Economy	14400.00
0005435423875	5333	Economy	14400.00
0005435380226	5333	Economy	14400.00
0005435319464	5333	Economy	14400.00
0005435613022	5333	Economy	14400.00
0005435490208	5333	Economy	14400.00
0005435423827	5333	Economy	14400.00
0005432133138	5333	Economy	14400.00
0005435613021	5333	Economy	14400.00
0005435613048	5333	Economy	14400.00
0005434244496	5333	Economy	14400.00
0005435613109	5333	Economy	14400.00
0005435613051	5333	Economy	14400.00
0005434573284	5333	Economy	14400.00
0005435490210	5333	Economy	14400.00
0005434344028	5333	Economy	14400.00
0005435613054	5333	Economy	14400.00
0005435097159	5333	Economy	14400.00
0005434344025	5333	Economy	14400.00
0005435613061	5333	Economy	14400.00
0005434244531	5333	Economy	14400.00
0005435613123	5333	Economy	14400.00
0005435613068	5333	Economy	14400.00
0005435424237	5333	Economy	14400.00
0005434344057	5333	Economy	14400.00
0005434244687	5333	Economy	14400.00
0005434344035	5333	Economy	14400.00
0005434573279	5333	Economy	14400.00
0005435319431	5333	Economy	14400.00
0005435491430	5333	Economy	14400.00
0005435423983	5333	Economy	14400.00
0005434344034	5333	Economy	14400.00
0005435613073	5333	Economy	14400.00
0005434344060	5333	Economy	14400.00
0005435613053	5333	Economy	14400.00
0005434344033	5333	Economy	14400.00
0005435380236	5333	Economy	14400.00
0005435613098	5333	Economy	14400.00
0005435613050	5333	Economy	14400.00
0005432047531	5333	Economy	14400.00
0005434344026	5333	Economy	14400.00
0005434573288	5333	Economy	14400.00
0005432840988	5333	Economy	14400.00
0005434244681	5333	Economy	14400.00
0005434244704	5333	Economy	14400.00
0005434573287	5333	Economy	14400.00
0005435613093	5333	Economy	14400.00
0005435613102	5333	Economy	14400.00
0005435613060	5333	Economy	14400.00
0005434344052	5333	Economy	14400.00
0005435613107	5333	Economy	14400.00
0005435424039	5333	Economy	14400.00
0005435423842	5333	Economy	14400.00
0005432133130	5333	Economy	14400.00
0005434344055	5333	Economy	14400.00
0005435380234	5333	Economy	14400.00
0005435423749	5333	Economy	14400.00
0005435613115	5333	Economy	14400.00
0005435424020	5333	Economy	14400.00
0005435424157	5333	Economy	14400.00
0005435424431	10924	Business	43100.00
0005434244824	10924	Business	43100.00
0005432841003	10924	Business	43100.00
0005435612634	10924	Business	43100.00
0005435612331	10924	Business	43100.00
0005435611777	10924	Business	43100.00
0005434343683	10924	Business	43100.00
0005432164998	10924	Business	43100.00
0005435611710	10924	Business	43100.00
0005434573171	10924	Business	43100.00
0005435424435	10924	Business	43100.00
0005435612300	10924	Business	43100.00
0005435612302	10924	Business	43100.00
0005435612161	10924	Business	43100.00
0005435611748	10924	Business	43100.00
0005435611946	10924	Business	43100.00
0005434656545	10924	Business	43100.00
0005435612247	10924	Business	43100.00
0005435490175	10924	Business	43100.00
0005435424452	10924	Business	43100.00
0005435424456	10924	Business	43100.00
0005434343590	10924	Business	43100.00
0005435611907	10924	Comfort	24400.00
0005434244840	10924	Business	43100.00
0005435380266	10924	Comfort	24400.00
0005435042847	10924	Comfort	24400.00
0005435042846	10924	Comfort	24400.00
0005434343687	10924	Comfort	24400.00
0005435612156	10924	Comfort	24400.00
0005435424443	10924	Comfort	24400.00
0005435612038	10924	Comfort	24400.00
0005435424490	10924	Comfort	24400.00
0005435612487	10924	Comfort	24400.00
0005435612350	10924	Comfort	24400.00
0005435612023	10924	Comfort	24400.00
0005435424447	10924	Comfort	24400.00
0005434244838	10924	Comfort	24400.00
0005435612021	10924	Comfort	24400.00
0005435424462	10924	Comfort	24400.00
0005434573159	10924	Comfort	24400.00
0005435555341	10924	Comfort	24400.00
0005432165001	10924	Comfort	24400.00
0005432165000	10924	Comfort	24400.00
0005435611723	10924	Comfort	24400.00
0005435612455	10924	Comfort	24400.00
0005435097067	10924	Comfort	24400.00
0005435612498	10924	Comfort	24400.00
0005434573160	10924	Comfort	24400.00
0005434244832	10924	Comfort	24400.00
0005435304133	10924	Comfort	24400.00
0005435424455	10924	Comfort	24400.00
0005434244821	10924	Comfort	24400.00
0005435424472	10924	Comfort	24400.00
0005435424430	10924	Comfort	24400.00
0005434343711	10924	Comfort	24400.00
0005434343647	10924	Comfort	24400.00
0005435491416	10924	Comfort	24400.00
0005434656546	10924	Comfort	24400.00
0005434244841	10924	Comfort	24400.00
0005435611933	10924	Economy	14400.00
0005435612482	10924	Economy	14400.00
0005434244837	10924	Economy	14400.00
0005435319528	10924	Economy	14400.00
0005435424485	10924	Economy	14400.00
0005433719126	10924	Economy	14400.00
0005435612355	10924	Economy	14400.00
0005435612414	10924	Economy	14400.00
0005434343692	10924	Economy	14400.00
0005434244817	10924	Economy	14400.00
0005435612030	10924	Economy	14400.00
0005435424450	10924	Economy	14400.00
0005435555344	10924	Economy	14400.00
0005434244826	10924	Economy	14400.00
0005435424434	10924	Economy	14400.00
0005435319530	10924	Economy	14400.00
0005434244842	10924	Economy	14400.00
0005434244830	10924	Economy	14400.00
0005435612015	10924	Economy	14400.00
0005435611981	10924	Economy	14400.00
0005435424476	10924	Economy	14400.00
0005435612224	10924	Economy	14400.00
0005435612050	10924	Economy	14400.00
0005435612351	10924	Economy	14400.00
0005435611940	10924	Economy	14400.00
0005434244827	10924	Economy	14400.00
0005435611724	10924	Economy	14400.00
0005435612394	10924	Economy	14400.00
0005435424440	10924	Economy	14400.00
0005434343682	10924	Economy	14400.00
0005434244845	10924	Economy	14400.00
0005432841002	10924	Economy	14400.00
0005435612494	10924	Economy	14400.00
0005435612210	10924	Economy	14400.00
0005434244818	10924	Economy	14400.00
0005434244836	10924	Economy	14400.00
0005434343680	10924	Economy	14400.00
0005435612126	10924	Economy	14400.00
0005435612378	10924	Economy	14400.00
0005434343723	10924	Economy	14400.00
0005435612373	10924	Economy	14400.00
0005435424453	10924	Economy	14400.00
0005435424436	10924	Economy	14400.00
0005435424487	10924	Economy	14400.00
0005435380264	10924	Economy	14400.00
0005435424425	10924	Economy	14400.00
0005434244835	10924	Economy	14400.00
0005435612406	10924	Economy	14400.00
0005435097054	10924	Economy	14400.00
0005435424474	10924	Economy	14400.00
0005435424463	10924	Economy	14400.00
0005435611944	10924	Economy	14400.00
0005435611960	10924	Economy	14400.00
0005435611908	10924	Economy	14400.00
0005434244834	10924	Economy	14400.00
0005434343727	10924	Economy	15800.00
0005435612488	10924	Economy	15800.00
0005435612379	10924	Economy	14400.00
0005435611789	10924	Economy	15800.00
0005435612138	10924	Economy	14400.00
0005435097084	10924	Economy	15800.00
0005435097077	10924	Economy	14400.00
0005435424469	10924	Economy	15800.00
0005435424439	10924	Economy	14400.00
0005434573102	10924	Economy	14400.00
0005435611915	10924	Economy	14400.00
0005435424459	10924	Economy	14400.00
0005434573123	10924	Economy	14400.00
0005435424475	10924	Economy	14400.00
0005435612141	10924	Economy	14400.00
0005435612290	10924	Economy	14400.00
0005435424454	10924	Economy	14400.00
0005434343728	10924	Economy	14400.00
0005435319526	10924	Economy	14400.00
0005435612162	10924	Economy	14400.00
0005434343714	10924	Economy	14400.00
0005435305005	10924	Economy	14400.00
0005435424464	10924	Economy	14400.00
0005435612052	10924	Economy	14400.00
0005435611987	10924	Economy	14400.00
0005435612493	10924	Economy	14400.00
0005435611961	10924	Economy	14400.00
0005435612280	10924	Economy	14400.00
0005435611901	10924	Economy	14400.00
0005435617167	10924	Economy	14400.00
0005435304132	10924	Economy	14400.00
0005435424471	10924	Economy	14400.00
0005435612635	10924	Economy	14400.00
0005435612246	10924	Economy	14400.00
0005435612341	10924	Economy	14400.00
0005435612299	10924	Economy	14400.00
0005435611888	10924	Economy	14400.00
0005434343837	10924	Economy	14400.00
0005435424480	10924	Economy	14400.00
0005435612288	10924	Economy	14400.00
0005435424486	10924	Economy	14400.00
0005435042844	10924	Economy	14400.00
0005435612261	10924	Economy	14400.00
0005434343623	10924	Economy	14400.00
0005434343697	10924	Economy	14400.00
0005435611919	10924	Economy	14400.00
0005435424479	10924	Economy	14400.00
0005434244843	10924	Economy	14400.00
0005435424437	10924	Economy	14400.00
0005432165002	10924	Economy	14400.00
0005432363398	10924	Economy	14400.00
0005435424461	10924	Economy	14400.00
0005434343789	10924	Economy	14400.00
0005435612392	10924	Economy	14400.00
0005435612435	10924	Economy	14400.00
0005435424449	10924	Economy	14400.00
0005435424446	10924	Economy	14400.00
0005435611988	10924	Economy	14400.00
0005435424428	10924	Economy	14400.00
0005435612170	10924	Economy	14400.00
0005435611839	10924	Economy	14400.00
0005435424441	10924	Economy	14400.00
0005434343747	10924	Economy	14400.00
0005435097083	10924	Economy	14400.00
0005434343750	10924	Economy	14400.00
0005435611775	10924	Economy	14400.00
0005435424488	10924	Economy	14400.00
0005435424477	10924	Economy	14400.00
0005434343783	10924	Economy	14400.00
0005435612171	10924	Economy	14400.00
0005435424432	10924	Economy	14400.00
0005434343746	10924	Economy	14400.00
0005435424448	10924	Economy	14400.00
0005434343752	10924	Economy	14400.00
0005435612352	10924	Economy	14400.00
0005435424458	10924	Economy	14400.00
0005435612009	10924	Economy	14400.00
0005435611889	10924	Economy	14400.00
0005435380269	10924	Economy	14400.00
0005434244831	10924	Economy	14400.00
0005435304136	10924	Economy	14400.00
0005435612139	10924	Economy	14400.00
0005435612099	10924	Economy	14400.00
0005435555334	10924	Economy	14400.00
0005435097091	10924	Economy	14400.00
0005435424473	10924	Economy	14400.00
0005434343665	10924	Economy	14400.00
0005435612245	10924	Economy	14400.00
0005435042845	10924	Economy	14400.00
0005435319527	10924	Economy	14400.00
0005434573161	10924	Economy	14400.00
0005435490184	10924	Economy	14400.00
0005435612712	10924	Economy	14400.00
0005432363400	10924	Economy	14400.00
0005435612024	10924	Economy	14400.00
0005432166885	10924	Economy	14400.00
0005433719125	10924	Economy	14400.00
0005435319524	10924	Economy	14400.00
0005435611902	10924	Economy	14400.00
0005435424483	10924	Economy	14400.00
0005435611725	10924	Economy	14400.00
0005435305006	10924	Economy	14400.00
0005435555335	10924	Economy	14400.00
0005435611982	10924	Economy	14400.00
0005435424457	10924	Economy	14400.00
0005435612319	10924	Economy	14400.00
0005435612142	10924	Economy	14400.00
0005435611932	10924	Economy	14400.00
0005435612291	10924	Economy	14400.00
0005434343724	10924	Economy	14400.00
0005434573101	10924	Economy	14400.00
0005435424466	10924	Economy	15800.00
0005435611762	10924	Economy	14400.00
0005434343624	10924	Economy	15800.00
0005434244839	10924	Economy	15800.00
0005434343748	10924	Economy	15800.00
0005435424465	10924	Economy	15800.00
0005434343835	10924	Economy	15800.00
0005434244819	10924	Economy	14400.00
0005434343604	10924	Economy	14400.00
0005434343686	10924	Economy	14400.00
0005435424433	10924	Economy	14400.00
0005433719124	10924	Economy	14400.00
0005435612356	10924	Economy	14400.00
0005434573135	10924	Economy	14400.00
0005435612039	10924	Economy	14400.00
0005433719122	10924	Economy	14400.00
0005434343702	10924	Economy	14400.00
0005435319525	10924	Economy	14400.00
0005432363399	10924	Economy	14400.00
0005434244816	10924	Economy	14400.00
0005435424426	10924	Economy	14400.00
0005435424445	10924	Economy	14400.00
0005435424451	10924	Economy	14400.00
0005435611832	10924	Economy	14400.00
0005435424429	10924	Economy	14400.00
0005435319529	10924	Economy	14400.00
0005435424438	10924	Economy	14400.00
0005435612330	10924	Economy	14400.00
0005435424482	10924	Economy	14400.00
0005434573120	10924	Economy	14400.00
0005432164996	10924	Economy	14400.00
0005435490174	10924	Economy	14400.00
0005435424491	10924	Economy	14400.00
0005435612442	10924	Economy	14400.00
0005435319531	10924	Economy	14400.00
0005434343696	10924	Economy	14400.00
0005435380267	10924	Economy	14400.00
0005434244820	10924	Economy	14400.00
0005435424492	10924	Economy	14400.00
0005435424427	10924	Economy	14400.00
0005435304135	10924	Economy	14400.00
0005434573103	10924	Economy	14400.00
0005435617166	10924	Economy	14400.00
0005435612248	10924	Economy	14400.00
0005435612713	10924	Economy	14400.00
0005434343798	10924	Economy	14400.00
0005434244828	10924	Economy	14400.00
0005434343729	10924	Economy	14400.00
0005432166884	10924	Economy	14400.00
0005435612164	10924	Economy	14400.00
0005434244823	10924	Economy	14400.00
0005432164995	10924	Economy	14400.00
0005435612181	10924	Economy	14400.00
0005435612483	10924	Economy	14400.00
0005434573170	10924	Economy	14400.00
0005435424484	10924	Economy	14400.00
0005434343743	10924	Economy	14400.00
0005434343836	10924	Economy	14400.00
0005434343646	10924	Economy	14400.00
0005432164999	10924	Economy	14400.00
0005435304134	10924	Economy	14400.00
0005435612163	10924	Economy	14400.00
0005435424444	10924	Economy	14400.00
0005435611729	10924	Economy	14400.00
0005434244844	10924	Economy	14400.00
0005434244825	10924	Economy	14400.00
0005434244833	10924	Economy	14400.00
0005435424478	10924	Economy	14400.00
0005435612440	10924	Economy	14400.00
0005435612305	10924	Economy	14400.00
0005435424489	10924	Economy	14400.00
0005435424468	10924	Economy	14400.00
0005435380265	10924	Economy	14400.00
0005435612554	10924	Economy	14400.00
0005435611938	10924	Economy	14400.00
0005434343691	10924	Economy	14400.00
0005434573167	10924	Economy	14400.00
0005435424460	10924	Economy	14400.00
0005435424481	10924	Economy	14400.00
0005435424423	10924	Economy	14400.00
0005434573104	10924	Economy	14400.00
0005432164997	10924	Economy	14400.00
0005435424424	10924	Economy	14400.00
0005432166883	10924	Economy	14400.00
0005435424470	10924	Economy	14400.00
0005433719123	10924	Economy	14400.00
0005435424467	10924	Economy	14400.00
0005435612391	10924	Economy	14400.00
0005434244829	10924	Economy	14400.00
0005435612016	10924	Economy	14400.00
0005434573172	10924	Economy	14400.00
0005434343608	10924	Economy	14400.00
0005435380268	10924	Economy	14400.00
0005435612010	10924	Economy	14400.00
0005435424442	10924	Economy	14400.00
0005434244822	10924	Economy	14400.00
0005435612711	10924	Economy	14400.00
0005435612383	10924	Economy	14400.00
0005435617168	10924	Economy	14400.00
0005432181612	3382	Business	18800.00
0005433507088	3382	Business	18800.00
0005433507093	3382	Business	18800.00
0005432459297	3382	Business	18800.00
0005434143724	3382	Business	18800.00
0005432181600	3382	Business	18800.00
0005432459091	3382	Business	18800.00
0005432459115	3382	Business	18800.00
0005433633657	3382	Business	18800.00
0005433805202	3382	Business	18800.00
0005432181607	3382	Business	18800.00
0005433805187	3382	Business	18800.00
0005433633635	3382	Business	18800.00
0005433805207	3382	Business	18800.00
0005433633647	3382	Business	18800.00
0005433805201	3382	Business	18800.00
0005432458995	3382	Business	18800.00
0005432459213	3382	Business	18800.00
0005433633663	3382	Business	18800.00
0005433805203	3382	Business	18800.00
0005433507097	3382	Business	18800.00
0005433805196	3382	Business	18800.00
0005433805197	3382	Business	18800.00
0005433805198	3382	Business	18800.00
0005434143723	3382	Business	18800.00
0005433805192	3382	Business	18800.00
0005432181598	3382	Business	18800.00
0005434143720	3382	Economy	6900.00
0005433633652	3382	Business	18800.00
0005433633643	3382	Economy	6900.00
0005432459015	3382	Economy	6900.00
0005433805168	3382	Economy	6900.00
0005433633639	3382	Economy	6900.00
0005433805190	3382	Economy	6300.00
0005432459233	3382	Economy	6900.00
0005433633650	3382	Economy	6300.00
0005433507081	3382	Economy	6300.00
0005433507086	3382	Economy	6300.00
0005432458989	3382	Economy	6300.00
0005433805183	3382	Economy	6300.00
0005433507091	3382	Economy	6300.00
0005432458996	3382	Economy	6300.00
0005433805178	3382	Economy	6300.00
0005433805194	3382	Economy	6300.00
0005433507094	3382	Economy	6300.00
0005433633661	3382	Economy	6300.00
0005433633658	3382	Economy	6300.00
0005433805205	3382	Economy	6300.00
0005432459274	3382	Economy	6300.00
0005433805191	3382	Economy	6300.00
0005432458961	3382	Economy	6300.00
0005433507092	3382	Economy	6300.00
0005433805170	3382	Economy	6300.00
0005433633659	3382	Economy	6300.00
0005432459199	3382	Economy	6300.00
0005433805181	3382	Economy	6300.00
0005433805208	3382	Economy	6300.00
0005432181601	3382	Economy	6300.00
0005432181604	3382	Economy	6300.00
0005433805193	3382	Economy	6300.00
0005432459173	3382	Economy	6300.00
0005432181594	3382	Economy	6300.00
0005433633656	3382	Economy	6300.00
0005432458991	3382	Economy	6300.00
0005432181596	3382	Economy	6300.00
0005432181614	3382	Economy	6300.00
0005432459141	3382	Economy	6300.00
0005434143718	3382	Economy	6300.00
0005432458990	3382	Economy	6300.00
0005433633644	3382	Economy	6300.00
0005432181599	3382	Economy	6300.00
0005433805174	3382	Economy	6300.00
0005433633660	3382	Economy	6300.00
0005433633641	3382	Economy	6300.00
0005432459090	3382	Economy	6300.00
0005433805199	3382	Economy	6300.00
0005433633645	3382	Economy	6300.00
0005432181610	3382	Economy	6300.00
0005432459105	3382	Economy	6300.00
0005433507080	3382	Economy	6300.00
0005432459216	3382	Economy	6300.00
0005433805204	3382	Economy	6300.00
0005433805188	3382	Economy	6300.00
0005433633642	3382	Economy	6300.00
0005433633634	3382	Economy	6300.00
0005432459016	3382	Economy	6300.00
0005433633653	3382	Economy	6300.00
0005432459206	3382	Economy	6300.00
0005433805180	3382	Economy	6300.00
0005432181603	3382	Economy	6300.00
0005432181595	3382	Economy	6300.00
0005433507096	3382	Economy	6300.00
0005433805184	3382	Economy	6900.00
0005433805171	3382	Economy	6900.00
0005433633662	3382	Economy	6900.00
0005432181611	3382	Economy	6900.00
0005433633636	3382	Economy	6900.00
0005432459023	3382	Economy	6300.00
0005433633654	3382	Economy	6300.00
0005433633651	3382	Economy	6300.00
0005432459160	3382	Economy	6300.00
0005432459382	3382	Economy	6900.00
0005433805172	3382	Economy	6300.00
0005432458998	3382	Economy	6300.00
0005433507095	3382	Economy	6300.00
0005434143717	3382	Economy	6300.00
0005433633638	3382	Economy	6300.00
0005433507077	3382	Economy	6300.00
0005433805179	3382	Economy	6300.00
0005432459207	3382	Economy	6300.00
0005432459246	3382	Economy	6300.00
0005433633646	3382	Economy	6300.00
0005433633640	3382	Economy	6300.00
0005432459104	3382	Economy	6300.00
0005432459159	3382	Economy	6300.00
0005432181608	3382	Economy	6300.00
0005432459012	3382	Economy	6300.00
0005432458997	3382	Economy	6300.00
0005433507082	3382	Economy	6300.00
0005433805195	3382	Economy	6300.00
0005432181605	3382	Economy	6300.00
0005432181613	3382	Economy	6300.00
0005433805189	3382	Economy	6300.00
0005434143722	3382	Economy	6300.00
0005432181602	3382	Economy	6300.00
0005433805182	3382	Economy	6300.00
0005433805176	3382	Economy	6300.00
0005433633648	3382	Economy	6300.00
0005433805169	3382	Economy	6300.00
0005433633664	3382	Economy	6300.00
0005432181592	3382	Economy	6300.00
0005433805200	3382	Economy	6300.00
0005432181606	3382	Economy	6300.00
0005432181597	3382	Economy	6300.00
0005432459347	3382	Economy	6300.00
0005433633655	3382	Economy	6300.00
0005434143721	3382	Economy	6300.00
0005432181609	3382	Economy	6300.00
0005433633633	3382	Economy	6300.00
0005433805175	3382	Economy	6300.00
0005433507083	3382	Economy	6300.00
0005432459215	3382	Economy	6300.00
0005433507078	3382	Economy	6300.00
0005432458979	3382	Economy	6300.00
0005433507084	3382	Economy	6300.00
0005432181593	3382	Economy	6300.00
0005433805173	3382	Economy	6300.00
0005433633649	3382	Economy	6300.00
0005433507085	3382	Economy	6300.00
0005433805206	3382	Economy	6300.00
0005432459243	3382	Economy	6300.00
0005433507089	3382	Economy	6300.00
0005433805209	3382	Economy	6300.00
0005432459200	3382	Economy	6300.00
0005432459078	3382	Economy	6300.00
0005434143719	3382	Economy	6300.00
0005433633665	3382	Economy	6300.00
0005433805177	3382	Economy	6300.00
0005433507079	3382	Economy	6300.00
0005433633637	3382	Economy	6300.00
0005433507087	3382	Economy	6300.00
0005433805186	3382	Economy	6300.00
0005433633632	3382	Economy	6300.00
0005433507090	3382	Economy	6300.00
0005433805185	3382	Economy	6300.00
0005433805210	3382	Economy	6300.00
0005432459346	3382	Economy	6300.00
0005433633666	3382	Economy	6300.00
0005435884551	3381	Business	18800.00
0005435884484	3381	Business	18800.00
0005435884800	3381	Business	18800.00
0005435884636	3381	Business	18800.00
0005435884455	3381	Business	18800.00
0005435884627	3381	Business	18800.00
0005435884558	3381	Business	18800.00
0005435884602	3381	Business	18800.00
0005435884799	3381	Business	18800.00
0005435884697	3381	Business	18800.00
0005435884623	3381	Economy	6900.00
0005435884733	3381	Economy	6300.00
0005435884743	3381	Economy	6300.00
0005435884601	3381	Economy	6300.00
0005435884483	3381	Economy	6300.00
0005435884740	3381	Economy	6300.00
0005435884454	3381	Economy	6300.00
0005435884677	3381	Economy	6300.00
0005435884668	3381	Economy	6300.00
0005435884638	3381	Economy	6300.00
0005435884696	3381	Economy	6300.00
0005435884481	3381	Economy	6300.00
0005435884658	3381	Economy	6300.00
0005435884580	3381	Economy	6300.00
0005435884535	3381	Economy	6300.00
0005435884814	3381	Economy	6300.00
0005435884389	3381	Economy	6300.00
0005435884713	3381	Economy	6300.00
0005435884698	3381	Economy	6300.00
0005435884615	3381	Economy	6300.00
0005435884715	3381	Economy	6300.00
0005435884460	3381	Economy	6300.00
0005435884822	3381	Economy	6300.00
0005435884736	3381	Economy	6300.00
0005435884734	3381	Economy	6300.00
0005435884659	3381	Economy	6300.00
0005435884739	3381	Economy	6300.00
0005435884704	3381	Economy	6300.00
0005435884823	3381	Economy	6300.00
0005435884450	3381	Economy	6300.00
0005435884596	3381	Economy	6300.00
0005435884595	3381	Economy	6300.00
0005435884388	3381	Economy	6300.00
0005435884579	3381	Economy	6300.00
0005435884536	3381	Economy	6300.00
0005435884526	3381	Economy	6300.00
0005435884605	3381	Economy	6300.00
0005435884678	3381	Economy	6300.00
0005435884614	3381	Economy	6300.00
0005435884976	8202	Business	18800.00
0005432042639	8202	Business	18800.00
0005433506878	8202	Business	18800.00
0005432459645	8202	Business	18800.00
0005435884994	8202	Business	18800.00
0005435884977	8202	Business	18800.00
0005435885000	8202	Business	18800.00
0005435885019	8202	Business	18800.00
0005435884981	8202	Business	18800.00
0005432459605	8202	Business	18800.00
0005434326268	8202	Business	18800.00
0005432459631	8202	Business	18800.00
0005432459633	8202	Business	18800.00
0005432459600	8202	Business	18800.00
0005433506979	8202	Business	18800.00
0005432459619	8202	Business	18800.00
0005432459634	8202	Business	18800.00
0005435884972	8202	Business	18800.00
0005435885001	8202	Business	18800.00
0005432459626	8202	Business	18800.00
0005432459624	8202	Business	18800.00
0005433506888	8202	Business	18800.00
0005432042640	8202	Business	18800.00
0005432459597	8202	Economy	6900.00
0005435884996	8202	Economy	6900.00
0005432459603	8202	Economy	6900.00
0005435884980	8202	Economy	6900.00
0005432459625	8202	Economy	6300.00
0005432459598	8202	Economy	6300.00
0005435885013	8202	Economy	6300.00
0005432459646	8202	Economy	6300.00
0005433506990	8202	Economy	6300.00
0005435884971	8202	Economy	6300.00
0005433506975	8202	Economy	6300.00
0005435884970	8202	Economy	6300.00
0005432459647	8202	Economy	6300.00
0005432459623	8202	Economy	6300.00
0005435884974	8202	Economy	6300.00
0005434312310	8202	Economy	6300.00
0005432042651	8202	Economy	6300.00
0005433506931	8202	Economy	6300.00
0005435884983	8202	Economy	6300.00
0005435884991	8202	Economy	6300.00
0005432459622	8202	Economy	6300.00
0005435885012	8202	Economy	6300.00
0005435884973	8202	Economy	6300.00
0005435884979	8202	Economy	6300.00
0005435884995	8202	Economy	6300.00
0005433506889	8202	Economy	6300.00
0005432459627	8202	Economy	6300.00
0005433506860	8202	Economy	6300.00
0005435884987	8202	Economy	6300.00
0005432459609	8202	Economy	6300.00
0005435884968	8202	Economy	6300.00
0005435884992	8202	Economy	6300.00
0005432459635	8202	Economy	6300.00
0005435884998	8202	Economy	6300.00
0005432459617	8202	Economy	6300.00
0005432042642	8202	Economy	6300.00
0005435884985	8202	Economy	6300.00
0005433506971	8202	Economy	6300.00
0005435885004	8202	Economy	6300.00
0005432459618	8202	Economy	6300.00
0005432459643	8202	Economy	6300.00
0005435885006	8202	Economy	6300.00
0005432459614	8202	Economy	6300.00
0005432459641	8202	Economy	6300.00
0005435884997	8202	Economy	6300.00
0005432459642	8202	Economy	6300.00
0005433506972	8202	Economy	6300.00
0005432459621	8202	Economy	6300.00
0005432459637	8202	Economy	6300.00
0005433506877	8202	Economy	6300.00
0005432042645	8202	Economy	6300.00
0005433506970	8202	Economy	6300.00
0005432459615	8202	Economy	6300.00
0005435884986	8202	Economy	6300.00
0005435885002	8202	Economy	6300.00
0005432042647	8202	Economy	6300.00
0005432459602	8202	Economy	6300.00
0005434312311	8202	Economy	6300.00
0005435885014	8202	Economy	6300.00
0005432042649	8202	Economy	6900.00
0005432459613	8202	Economy	6900.00
0005432459616	8202	Economy	6900.00
0005435885008	8202	Economy	6900.00
0005432459638	8202	Economy	6300.00
0005432459629	8202	Economy	6300.00
0005433506982	8202	Economy	6300.00
0005434312309	8202	Economy	6300.00
0005435884969	8202	Economy	6900.00
0005435885007	8202	Economy	6300.00
0005432459648	8202	Economy	6300.00
0005435885011	8202	Economy	6300.00
0005435884990	8202	Economy	6300.00
0005435884975	8202	Economy	6300.00
0005435884993	8202	Economy	6300.00
0005433506973	8202	Economy	6300.00
0005435885010	8202	Economy	6300.00
0005435885009	8202	Economy	6300.00
0005432459640	8202	Economy	6300.00
0005435885003	8202	Economy	6300.00
0005432042644	8202	Economy	6300.00
0005432459632	8202	Economy	6300.00
0005435885016	8202	Economy	6300.00
0005432459628	8202	Economy	6300.00
0005432459604	8202	Economy	6300.00
0005432459607	8202	Economy	6300.00
0005432459611	8202	Economy	6300.00
0005432459620	8202	Economy	6300.00
0005432459608	8202	Economy	6300.00
0005435884984	8202	Economy	6300.00
0005435885017	8202	Economy	6300.00
0005433506989	8202	Economy	6300.00
0005432459644	8202	Economy	6300.00
0005432459601	8202	Economy	6300.00
0005432042646	8202	Economy	6300.00
0005432459630	8202	Economy	6300.00
0005432459636	8202	Economy	6300.00
0005435884978	8202	Economy	6300.00
0005432459650	8202	Economy	6300.00
0005432459599	8202	Economy	6300.00
0005432459606	8202	Economy	6300.00
0005432042650	8202	Economy	6300.00
0005433506943	8202	Economy	6300.00
0005432042641	8202	Economy	6300.00
0005432042648	8202	Economy	6300.00
0005432042643	8202	Economy	6300.00
0005433506906	8202	Economy	6300.00
0005435884988	8202	Economy	6300.00
0005433506907	8202	Economy	6300.00
0005435885020	8202	Economy	6300.00
0005435884982	8202	Economy	6300.00
0005432459639	8202	Economy	6300.00
0005432459612	8202	Economy	6300.00
0005435885015	8202	Economy	6300.00
0005432459610	8202	Economy	6300.00
0005435884999	8202	Economy	6300.00
0005432459649	8202	Economy	6300.00
0005433506969	8202	Economy	6300.00
0005435884989	8202	Economy	6300.00
0005435885018	8202	Economy	6300.00
0005435885005	8202	Economy	6300.00
0005433633337	8206	Business	18800.00
0005433804884	8206	Business	18800.00
0005433804997	8206	Business	18800.00
0005433804860	8206	Business	18800.00
0005433633282	8206	Business	18800.00
0005433804913	8206	Business	18800.00
0005433633308	8206	Business	18800.00
0005433633372	8206	Business	18800.00
0005433633340	8206	Business	18800.00
0005433633281	8206	Business	18800.00
0005433633306	8206	Business	18800.00
0005433633339	8206	Business	18800.00
0005433633230	8206	Business	18800.00
0005434143698	8206	Business	18800.00
0005433633398	8206	Economy	6900.00
0005433633426	8206	Economy	6900.00
0005433633318	8206	Economy	6900.00
0005433633328	8206	Economy	6300.00
0005433804882	8206	Economy	6300.00
0005433805038	8206	Economy	6300.00
0005434271288	8206	Economy	6300.00
0005433804902	8206	Economy	6300.00
0005433804874	8206	Economy	6300.00
0005435854050	8206	Economy	6300.00
0005433804983	8206	Economy	6300.00
0005433804820	8206	Economy	6300.00
0005433633338	8206	Economy	6300.00
0005433804929	8206	Economy	6300.00
0005433804900	8206	Economy	6300.00
0005433633402	8206	Economy	6300.00
0005433804880	8206	Economy	6300.00
0005433804955	8206	Economy	6300.00
0005433804898	8206	Economy	6300.00
0005433804933	8206	Economy	6300.00
0005433804971	8206	Economy	6300.00
0005433633231	8206	Economy	6300.00
0005433804901	8206	Economy	6300.00
0005433633305	8206	Economy	6300.00
0005433804877	8206	Economy	6300.00
0005433804878	8206	Economy	6300.00
0005433804904	8206	Economy	6300.00
0005435854048	8206	Economy	6900.00
0005433633397	8206	Economy	6900.00
0005433633458	8206	Economy	6300.00
0005433633327	8206	Economy	6300.00
0005433633434	8206	Economy	6300.00
0005433804903	8206	Economy	6300.00
0005433804970	8206	Economy	6300.00
0005433804998	8206	Economy	6300.00
0005433804982	8206	Economy	6300.00
0005433633333	8206	Economy	6300.00
0005433804885	8206	Economy	6300.00
0005433804810	8206	Economy	6300.00
0005433633242	8206	Economy	6300.00
0005433633459	8206	Economy	6300.00
0005433633383	8206	Economy	6300.00
0005433805040	8206	Economy	6300.00
0005433804809	8206	Economy	6300.00
0005435854049	8206	Economy	6300.00
0005433804811	8206	Economy	6300.00
0005433633437	8206	Economy	6300.00
0005433633286	8206	Economy	6300.00
0005433633334	8206	Economy	6300.00
0005433804999	8206	Economy	6300.00
0005433804883	8206	Economy	6300.00
0005433633307	8206	Economy	6300.00
0005433633243	8206	Economy	6300.00
0005433633235	8206	Economy	6300.00
0005433804890	8206	Economy	6300.00
0005434183559	8208	Economy	6900.00
0005434183551	8208	Economy	6300.00
0005434183552	8208	Economy	6300.00
0005434183558	8208	Economy	6300.00
0005433194845	4668	Business	9900.00
0005432382986	4668	Business	9900.00
0005433454866	4668	Business	9900.00
0005432383009	4668	Business	9900.00
0005432727869	4668	Business	9900.00
0005432727879	4668	Business	9900.00
0005432382974	4668	Business	9900.00
0005432383003	4668	Business	9900.00
0005432383010	4668	Business	9900.00
0005432383005	4668	Economy	3300.00
0005432383001	4668	Economy	3300.00
0005433722190	4668	Economy	3300.00
0005432382993	4668	Economy	3300.00
0005433453754	4668	Economy	3300.00
0005433194848	4668	Economy	3300.00
0005432382985	4668	Economy	3300.00
0005432383008	4668	Economy	3300.00
0005433453753	4668	Economy	3600.00
0005432383012	4668	Economy	3600.00
0005432382977	4668	Economy	3600.00
0005433722196	4668	Economy	3600.00
0005432382997	4668	Economy	3300.00
0005433194847	4668	Economy	3300.00
0005433722194	4668	Economy	3300.00
0005432382981	4668	Economy	3300.00
0005432382996	4668	Economy	3300.00
0005433722189	4668	Economy	3300.00
0005433454865	4668	Economy	3300.00
0005433722187	4668	Economy	3300.00
0005432382994	4668	Economy	3300.00
0005432727874	4668	Economy	3300.00
0005432727872	4668	Economy	3300.00
0005432727877	4668	Economy	3300.00
0005432383011	4668	Economy	3300.00
0005432382969	4668	Economy	3300.00
0005433194843	4668	Economy	3300.00
0005432382970	4668	Economy	3300.00
0005432727880	4668	Economy	3300.00
0005433454863	4668	Economy	3300.00
0005432383006	4668	Economy	3300.00
0005432727878	4668	Economy	3300.00
0005432383007	4668	Economy	3300.00
0005432382982	4668	Economy	3300.00
0005432382973	4668	Economy	3300.00
0005432383002	4668	Economy	3300.00
0005432382984	4668	Economy	3300.00
0005432382971	4668	Economy	3300.00
0005432383000	4668	Economy	3300.00
0005433722188	4668	Economy	3300.00
0005432382983	4668	Economy	3300.00
0005432382998	4668	Economy	3300.00
0005432727873	4668	Economy	3300.00
0005432382975	4668	Economy	3300.00
0005432382995	4668	Economy	3300.00
0005433194849	4668	Economy	3300.00
0005432727876	4668	Economy	3300.00
0005433194846	4668	Economy	3300.00
0005433722192	4668	Economy	3300.00
0005432382992	4668	Economy	3300.00
0005433194850	4668	Economy	3300.00
0005432383004	4668	Economy	3300.00
0005432382987	4668	Economy	3300.00
0005433722195	4668	Economy	3300.00
0005433722191	4668	Economy	3300.00
0005433194844	4668	Economy	3300.00
0005432382991	4668	Economy	3300.00
0005433722193	4668	Economy	3300.00
0005432382979	4668	Economy	3300.00
0005432382988	4668	Economy	3300.00
0005432727871	4668	Economy	3300.00
0005432382976	4668	Economy	3300.00
0005432382978	4668	Economy	3300.00
0005432382980	4668	Economy	3300.00
0005432727870	4668	Economy	3300.00
0005432382990	4668	Economy	3300.00
0005432727882	4668	Economy	3300.00
0005432727875	4668	Economy	3300.00
0005432382999	4668	Economy	3300.00
0005432727881	4668	Economy	3300.00
0005432382989	4668	Economy	3300.00
0005432382972	4668	Economy	3300.00
0005433454864	4668	Economy	3300.00
0005432382561	30229	Business	9900.00
0005432727793	30229	Business	9900.00
0005432382581	30229	Business	9900.00
0005432382563	30229	Business	9900.00
0005432727794	30229	Business	9900.00
0005432382512	30229	Economy	3300.00
0005432382517	30229	Economy	3300.00
0005433453730	30229	Economy	3300.00
0005433453739	30229	Economy	3300.00
0005432727739	30229	Economy	3300.00
0005433194824	30229	Economy	3600.00
0005432382502	30229	Economy	3600.00
0005432382506	30229	Economy	3600.00
0005432382527	30229	Economy	3300.00
0005432382558	30229	Economy	3300.00
0005432727770	30229	Economy	3300.00
0005433451599	30229	Economy	3300.00
0005433453738	30229	Economy	3300.00
0005432382557	30229	Economy	3300.00
0005432382546	30229	Economy	3300.00
0005432727776	30229	Economy	3300.00
0005432382562	30229	Economy	3300.00
0005432382598	30229	Economy	3300.00
0005432727735	30229	Economy	3300.00
0005432382573	30229	Economy	3300.00
0005432382488	30229	Economy	3300.00
0005432382635	30229	Economy	3300.00
0005433194822	30229	Economy	3300.00
0005432382643	30229	Economy	3300.00
0005432382597	30229	Economy	3300.00
0005432727734	30229	Economy	3300.00
0005432382590	30229	Economy	3300.00
0005432382497	30229	Economy	3300.00
0005432382548	30229	Economy	3300.00
0005432382514	30229	Economy	3300.00
0005432382489	30229	Economy	3300.00
0005432382513	30229	Economy	3300.00
0005432727744	30229	Economy	3300.00
0005432382605	30229	Economy	3300.00
0005433453731	30229	Economy	3300.00
0005432382498	30229	Economy	3300.00
0005432727736	30229	Economy	3300.00
0005432382591	30229	Economy	3300.00
0005432382547	30229	Economy	3300.00
0005432727756	30229	Economy	3300.00
0005432727719	30229	Economy	3300.00
0005432382528	30229	Economy	3300.00
0005432382504	30229	Economy	3300.00
0005433194823	30229	Economy	3300.00
0005432382524	30229	Economy	3300.00
0005435540898	1723	Business	57200.00
0005435540891	1723	Business	57200.00
0005435540904	1723	Business	57200.00
0005435529146	1723	Business	57200.00
0005435540910	1723	Business	57200.00
0005435529165	1723	Business	57200.00
0005435540902	1723	Economy	19100.00
0005433516840	1723	Economy	19100.00
0005435529155	1723	Economy	19100.00
0005435540906	1723	Economy	19100.00
0005435540888	1723	Economy	19100.00
0005435540895	1723	Economy	19100.00
0005435529166	1723	Economy	19100.00
0005432294476	1723	Economy	19100.00
0005432294474	1723	Economy	21000.00
0005435529151	1723	Economy	21000.00
0005433516838	1723	Economy	21000.00
0005435529157	1723	Economy	21000.00
0005435540899	1723	Economy	19100.00
0005435540897	1723	Economy	19100.00
0005435529147	1723	Economy	19100.00
0005435540901	1723	Economy	19100.00
0005435529149	1723	Economy	19100.00
0005435529145	1723	Economy	19100.00
0005435529153	1723	Economy	19100.00
0005433516837	1723	Economy	19100.00
0005435529156	1723	Economy	19100.00
0005433516842	1723	Economy	19100.00
0005435540900	1723	Economy	19100.00
0005435529164	1723	Economy	19100.00
0005435529159	1723	Economy	19100.00
0005432924977	1723	Economy	19100.00
0005433516843	1723	Economy	19100.00
0005435540903	1723	Economy	19100.00
0005435540896	1723	Economy	19100.00
0005435540889	1723	Economy	19100.00
0005435540908	1723	Economy	19100.00
0005435529150	1723	Economy	19100.00
0005435529162	1723	Economy	19100.00
0005435529148	1723	Economy	19100.00
0005435529163	1723	Economy	19100.00
0005435540894	1723	Economy	19100.00
0005435540905	1723	Economy	19100.00
0005435529152	1723	Economy	19100.00
0005435540907	1723	Economy	19100.00
0005433516839	1723	Economy	19100.00
0005435529158	1723	Economy	19100.00
0005435540892	1723	Economy	19100.00
0005435540909	1723	Economy	19100.00
0005433516836	1723	Economy	19100.00
0005435529154	1723	Economy	19100.00
0005435529144	1723	Economy	19100.00
0005432294475	1723	Economy	19100.00
0005435540890	1723	Economy	19100.00
0005433516844	1723	Economy	19100.00
0005435529161	1723	Economy	19100.00
0005435529160	1723	Economy	19100.00
0005435540893	1723	Economy	19100.00
0005433516841	1723	Economy	19100.00
0005435540692	21998	Business	57200.00
0005435540710	21998	Business	57200.00
0005435540651	21998	Business	57200.00
0005435517640	21998	Business	57200.00
0005433516762	21998	Business	57200.00
0005435517637	21998	Business	57200.00
0005435540796	21998	Business	57200.00
0005435517649	21998	Business	57200.00
0005435540694	21998	Economy	19100.00
0005435540752	21998	Economy	19100.00
0005435517641	21998	Economy	19100.00
0005435517653	21998	Economy	19100.00
0005435517710	21998	Economy	19100.00
0005435540719	21998	Economy	19100.00
0005432925012	21998	Economy	19100.00
0005435517652	21998	Economy	21000.00
0005435517655	21998	Economy	21000.00
0005432925010	21998	Economy	21000.00
0005433516793	21998	Economy	21000.00
0005435540795	21998	Economy	19100.00
0005433516777	21998	Economy	19100.00
0005435540667	21998	Economy	19100.00
0005433516752	21998	Economy	19100.00
0005435540628	21998	Economy	19100.00
0005435540753	21998	Economy	19100.00
0005435540759	21998	Economy	19100.00
0005435540764	21998	Economy	19100.00
0005435540650	21998	Economy	19100.00
0005435540718	21998	Economy	19100.00
0005435517714	21998	Economy	19100.00
0005435540668	21998	Economy	19100.00
0005435540769	21998	Economy	19100.00
0005435540765	21998	Economy	19100.00
0005435517588	21998	Economy	19100.00
0005435517594	21998	Economy	19100.00
0005435540705	21998	Economy	19100.00
0005435517709	21998	Economy	19100.00
0005435517596	21998	Economy	19100.00
0005435540683	21998	Economy	19100.00
0005435540640	21998	Economy	19100.00
0005435540682	21998	Economy	19100.00
0005432925014	21998	Economy	19100.00
0005432925011	21998	Economy	19100.00
0005435517648	21998	Economy	19100.00
0005433516763	21998	Economy	19100.00
0005435517654	21998	Economy	19100.00
0005435540760	21998	Economy	19100.00
0005435540704	21998	Economy	19100.00
0005432925013	21998	Economy	19100.00
0005435517620	21998	Economy	19100.00
0005435540649	21998	Economy	19100.00
0005435540691	21998	Economy	19100.00
0005435517633	21998	Economy	19100.00
0005435540648	21998	Economy	19100.00
0005435517636	21998	Economy	19100.00
0005432838876	7362	Business	18500.00
0005434458704	7362	Business	18500.00
0005435252420	7362	Business	18500.00
0005432838870	7362	Business	18500.00
0005434664924	7362	Business	18500.00
0005432823437	7362	Business	18500.00
0005435252430	7362	Business	18500.00
0005432073374	7362	Business	18500.00
0005434458708	7362	Business	18500.00
0005432838867	7362	Business	18500.00
0005432838882	7362	Economy	6200.00
0005432838880	7362	Economy	6200.00
0005434458707	7362	Economy	6200.00
0005434458697	7362	Economy	6200.00
0005432838892	7362	Economy	6200.00
0005432838863	7362	Economy	6200.00
0005432838864	7362	Economy	6200.00
0005432073372	7362	Economy	6200.00
0005432838890	7362	Economy	6200.00
0005434458705	7362	Economy	6800.00
0005434458694	7362	Economy	6800.00
0005435252431	7362	Economy	6800.00
0005434458699	7362	Economy	6800.00
0005434458706	7362	Economy	6200.00
0005435252487	7362	Economy	6200.00
0005434458711	7362	Economy	6200.00
0005432838866	7362	Economy	6200.00
0005432841001	7362	Economy	6200.00
0005434458701	7362	Economy	6200.00
0005432838872	7362	Economy	6200.00
0005434458693	7362	Economy	6200.00
0005434458709	7362	Economy	6200.00
0005432838883	7362	Economy	6200.00
0005435252426	7362	Economy	6200.00
0005434458703	7362	Economy	6200.00
0005432838886	7362	Economy	6200.00
0005432838878	7362	Economy	6200.00
0005432823438	7362	Economy	6200.00
0005432838888	7362	Economy	6200.00
0005432838868	7362	Economy	6200.00
0005434458702	7362	Economy	6200.00
0005432838893	7362	Economy	6200.00
0005432838884	7362	Economy	6200.00
0005435252515	7362	Economy	6200.00
0005432073373	7362	Economy	6200.00
0005432838891	7362	Economy	6200.00
0005434458698	7362	Economy	6200.00
0005432838869	7362	Economy	6200.00
0005435252429	7362	Economy	6200.00
0005432838885	7362	Economy	6200.00
0005435252448	7362	Economy	6200.00
0005432838875	7362	Economy	6200.00
0005432073371	7362	Economy	6200.00
0005435252441	7362	Economy	6200.00
0005432838889	7362	Economy	6200.00
0005434458691	7362	Economy	6200.00
0005432838881	7362	Economy	6200.00
0005435252440	7362	Economy	6200.00
0005432838874	7362	Economy	6200.00
0005432840999	7362	Economy	6200.00
0005435252511	7362	Economy	6200.00
0005434458690	7362	Economy	6200.00
0005435491414	7362	Economy	6200.00
0005434458692	7362	Economy	6200.00
0005432838873	7362	Economy	6200.00
0005434458695	7362	Economy	6200.00
0005432838871	7362	Economy	6200.00
0005432838879	7362	Economy	6200.00
0005435252442	7362	Economy	6200.00
0005434458710	7362	Economy	6200.00
0005432838887	7362	Economy	6200.00
0005434664923	7362	Economy	6200.00
0005435252439	7362	Economy	6200.00
0005434664920	7362	Economy	6200.00
0005434458700	7362	Economy	6200.00
0005432838865	7362	Economy	6200.00
0005432838877	7362	Economy	6200.00
0005432841000	7362	Economy	6200.00
0005435252462	7362	Economy	6200.00
0005435252536	7362	Economy	6200.00
0005434458696	7362	Economy	6200.00
0005435491413	7362	Economy	6200.00
0005432838862	7362	Economy	6200.00
0005434458469	28932	Business	18500.00
0005432838579	28932	Business	18500.00
0005432838632	28932	Business	18500.00
0005432838678	28932	Business	18500.00
0005432838775	28932	Business	18500.00
0005435252612	28932	Business	18500.00
0005434458522	28932	Business	18500.00
0005432838537	28932	Business	18500.00
0005432838577	28932	Business	18500.00
0005432838561	28932	Business	18500.00
0005434458494	28932	Business	18500.00
0005432838540	28932	Economy	6200.00
0005434458537	28932	Economy	6200.00
0005434458565	28932	Economy	6200.00
0005435252603	28932	Economy	6200.00
0005435252604	28932	Economy	6200.00
0005432838578	28932	Economy	6200.00
0005434458529	28932	Economy	6200.00
0005434458536	28932	Economy	6200.00
0005434458530	28932	Economy	6200.00
0005435252614	28932	Economy	6200.00
0005432838558	28932	Economy	6800.00
0005434458496	28932	Economy	6800.00
0005435252609	28932	Economy	6800.00
0005435252602	28932	Economy	6800.00
0005432838654	28932	Economy	6200.00
0005432823422	28932	Economy	6200.00
0005434458444	28932	Economy	6200.00
0005432838709	28932	Economy	6200.00
0005435252607	28932	Economy	6200.00
0005434458592	28932	Economy	6200.00
0005432838622	28932	Economy	6200.00
0005435252618	28932	Economy	6200.00
0005432838668	28932	Economy	6200.00
0005432838652	28932	Economy	6200.00
0005432838617	28932	Economy	6200.00
0005432840983	28932	Economy	6200.00
0005435252619	28932	Economy	6200.00
0005435491432	28932	Economy	6200.00
0005432838653	28932	Economy	6200.00
0005435252613	28932	Economy	6200.00
0005435252617	28932	Economy	6200.00
0005432838697	28932	Economy	6200.00
0005432838643	28932	Economy	6200.00
0005432838636	28932	Economy	6200.00
0005435252616	28932	Economy	6200.00
0005432001012	28932	Economy	6200.00
0005434458549	28932	Economy	6200.00
0005432838691	28932	Economy	6200.00
0005432001013	28932	Economy	6200.00
0005434458495	28932	Economy	6200.00
0005434458540	28932	Economy	6200.00
0005432838644	28932	Economy	6200.00
0005435252615	28932	Economy	6200.00
0005432823423	28932	Economy	6200.00
0005434458538	28932	Economy	6200.00
0005435252611	28932	Economy	6200.00
0005432823429	28932	Economy	6200.00
0005434458566	28932	Economy	6200.00
0005434458443	28932	Economy	6200.00
0005432838633	28932	Economy	6200.00
0005435252610	28932	Economy	6200.00
0005434458500	28932	Economy	6200.00
0005432838655	28932	Economy	6200.00
0005434458442	28932	Economy	6200.00
0005432838751	28932	Economy	6200.00
0005432838713	28932	Economy	6200.00
0005434458445	28932	Economy	6200.00
0005432838645	28932	Economy	6200.00
0005435252605	28932	Economy	6200.00
0005432838755	28932	Economy	6200.00
0005435252620	28932	Economy	6200.00
0005432838756	28932	Economy	6200.00
0005434664949	28932	Economy	6200.00
0005432838634	28932	Economy	6200.00
0005432838538	28932	Economy	6200.00
0005432840984	28932	Economy	6200.00
0005432838539	28932	Economy	6200.00
0005435252606	28932	Economy	6200.00
0005432838562	28932	Economy	6200.00
0005435491431	28932	Economy	6200.00
0005435252608	28932	Economy	6200.00
0005434664950	28932	Economy	6200.00
0005432823430	28932	Economy	6200.00
0005435990589	8809	Business	145300.00
0005434275965	8809	Business	145300.00
0005434275929	8809	Economy	48400.00
0005434275968	8809	Economy	53300.00
0005434275958	8809	Economy	48400.00
0005435990590	8809	Economy	48400.00
0005434275951	8809	Economy	48400.00
0005434275928	8809	Economy	48400.00
0005434275961	8809	Economy	48400.00
0005434275969	8809	Economy	48400.00
0005435990586	8809	Economy	48400.00
0005435990588	8809	Economy	48400.00
0005435990587	8809	Economy	48400.00
0005434275997	15765	Business	145300.00
0005434276001	15765	Economy	48400.00
0005435990519	15765	Economy	48400.00
0005435990504	15765	Economy	53300.00
0005435990520	15765	Economy	48400.00
0005435990541	15765	Economy	48400.00
0005434275995	15765	Economy	48400.00
0005435990540	15765	Economy	48400.00
0005434275999	15765	Economy	48400.00
0005434276000	15765	Economy	48400.00
0005435990506	15765	Economy	48400.00
0005434275996	15765	Economy	48400.00
0005434275998	15765	Economy	48400.00
0005434276002	15765	Economy	48400.00
0005433468286	2082	Economy	13300.00
0005433468290	2082	Economy	13300.00
0005433468292	2082	Economy	13300.00
0005433468287	2082	Economy	12100.00
0005432909220	2082	Economy	12100.00
0005433468276	2082	Economy	12100.00
0005432909196	2082	Economy	12100.00
0005432909203	2082	Economy	12100.00
0005433468277	2082	Economy	12100.00
0005433468285	2082	Economy	12100.00
0005432909211	2082	Economy	12100.00
0005432909202	2082	Economy	12100.00
0005433468278	2082	Economy	12100.00
0005433468288	2082	Economy	12100.00
0005432909210	2082	Economy	12100.00
0005433468279	2082	Economy	12100.00
0005433468289	2082	Economy	12100.00
0005433468295	2082	Economy	12100.00
0005432909190	2082	Economy	12100.00
0005433468291	2082	Economy	12100.00
0005433468297	2082	Economy	12100.00
0005432909191	2082	Economy	12100.00
0005432909195	2082	Economy	12100.00
0005433468275	2082	Economy	12100.00
0005433468280	2082	Economy	12100.00
0005433468294	2082	Economy	12100.00
0005433468271	2082	Economy	12100.00
0005433468283	2082	Economy	12100.00
0005432909219	2082	Economy	12100.00
0005433468274	2082	Economy	12100.00
0005433468296	2082	Economy	12100.00
0005432909189	2082	Economy	12100.00
0005433468281	2082	Economy	12100.00
0005432909201	2082	Economy	12100.00
0005433468272	2082	Economy	12100.00
0005433468293	2082	Economy	12100.00
0005433468273	2082	Economy	12100.00
0005433468284	2082	Economy	12100.00
0005433468282	2082	Economy	12100.00
0005432909216	2082	Economy	12100.00
0005434149522	6398	Business	36600.00
0005434149598	6398	Business	36600.00
0005435176595	6398	Business	36600.00
0005435176614	6398	Business	36600.00
0005432360111	6398	Business	36600.00
0005435176731	6398	Business	36600.00
0005432360145	6398	Business	36600.00
0005432360126	6398	Business	36600.00
0005434149552	6398	Business	36600.00
0005432360129	6398	Business	36600.00
0005432360127	6398	Business	36600.00
0005432360103	6398	Business	36600.00
0005432360109	6398	Economy	12200.00
0005434149660	6398	Economy	12200.00
0005432360117	6398	Economy	12200.00
0005432360130	6398	Economy	12200.00
0005435176698	6398	Economy	12200.00
0005432335967	6398	Economy	12200.00
0005432360121	6398	Economy	12200.00
0005435176693	6398	Economy	12200.00
0005432360143	6398	Economy	12200.00
0005432360128	6398	Economy	12200.00
0005432360101	6398	Economy	12200.00
0005432360108	6398	Economy	12200.00
0005432062199	6398	Economy	12200.00
0005432360119	6398	Economy	12200.00
0005434149560	6398	Economy	12200.00
0005432062203	6398	Economy	12200.00
0005432062200	6398	Economy	12200.00
0005432335970	6398	Economy	12200.00
0005434149523	6398	Economy	12200.00
0005432360141	6398	Economy	12200.00
0005435176664	6398	Economy	12200.00
0005434149532	6398	Economy	12200.00
0005432335977	6398	Economy	12200.00
0005434149535	6398	Economy	12200.00
0005432335976	6398	Economy	12200.00
0005432360099	6398	Economy	12200.00
0005434149533	6398	Economy	12200.00
0005435176746	6398	Economy	12200.00
0005432363400	6398	Economy	12200.00
0005432360105	6398	Economy	12200.00
0005435490175	6398	Economy	12200.00
0005432360136	6398	Economy	12200.00
0005432335978	6398	Economy	12200.00
0005432360134	6398	Economy	12200.00
0005435176613	6398	Economy	12200.00
0005432360106	6398	Economy	12200.00
0005432360100	6398	Economy	12200.00
0005432360142	6398	Economy	13400.00
0005432360113	6398	Economy	13400.00
0005435176671	6398	Economy	13400.00
0005435176670	6398	Economy	13400.00
0005434149524	6398	Economy	12200.00
0005432360114	6398	Economy	13400.00
0005435176708	6398	Economy	12200.00
0005435176707	6398	Economy	12200.00
0005435490174	6398	Economy	12200.00
0005432335968	6398	Economy	12200.00
0005432363399	6398	Economy	12200.00
0005432360138	6398	Economy	12200.00
0005432062206	6398	Economy	12200.00
0005434149569	6398	Economy	12200.00
0005435176673	6398	Economy	12200.00
0005435176776	6398	Economy	12200.00
0005432360115	6398	Economy	12200.00
0005432360104	6398	Economy	12200.00
0005435176732	6398	Economy	12200.00
0005432360123	6398	Economy	12200.00
0005435176626	6398	Economy	12200.00
0005432360135	6398	Economy	12200.00
0005432062201	6398	Economy	12200.00
0005432360132	6398	Economy	12200.00
0005435176745	6398	Economy	12200.00
0005435176730	6398	Economy	12200.00
0005432062204	6398	Economy	12200.00
0005432335975	6398	Economy	12200.00
0005435490184	6398	Economy	12200.00
0005432360122	6398	Economy	12200.00
0005432363398	6398	Economy	12200.00
0005435176837	6398	Economy	12200.00
0005432360125	6398	Economy	12200.00
0005432360098	6398	Economy	12200.00
0005432360112	6398	Economy	12200.00
0005435176714	6398	Economy	12200.00
0005432062205	6398	Economy	12200.00
0005435176712	6398	Economy	12200.00
0005432360131	6398	Economy	12200.00
0005432335971	6398	Economy	12200.00
0005432360139	6398	Economy	12200.00
0005432335973	6398	Economy	12200.00
0005432360120	6398	Economy	12200.00
0005435176646	6398	Economy	12200.00
0005432360137	6398	Economy	12200.00
0005435176752	6398	Economy	12200.00
0005432360116	6398	Economy	12200.00
0005432360118	6398	Economy	12200.00
0005432335972	6398	Economy	12200.00
0005435176596	6398	Economy	12200.00
0005432360144	6398	Economy	12200.00
0005432360097	6398	Economy	12200.00
0005434149586	6398	Economy	12200.00
0005432335974	6398	Economy	12200.00
0005435176814	6398	Economy	12200.00
0005432360140	6398	Economy	12200.00
0005435176694	6398	Economy	12200.00
0005434149597	6398	Economy	12200.00
0005432360107	6398	Economy	12200.00
0005432335969	6398	Economy	12200.00
0005432360133	6398	Economy	12200.00
0005432360102	6398	Economy	12200.00
0005432360110	6398	Economy	12200.00
0005432062202	6398	Economy	12200.00
0005432360124	6398	Economy	12200.00
0005434149568	6398	Economy	12200.00
0005432359667	21040	Business	36600.00
0005432359794	21040	Business	36600.00
0005432335843	21040	Business	36600.00
0005432359570	21040	Business	36600.00
0005435176928	21040	Business	36600.00
0005434149672	21040	Business	36600.00
0005432359591	21040	Business	36600.00
0005434149668	21040	Business	36600.00
0005435176931	21040	Business	36600.00
0005432359740	21040	Business	36600.00
0005432359666	21040	Economy	12200.00
0005435176940	21040	Economy	12200.00
0005432359612	21040	Economy	12200.00
0005435176948	21040	Economy	12200.00
0005435176943	21040	Economy	12200.00
0005432359518	21040	Economy	12200.00
0005435176929	21040	Economy	12200.00
0005432359739	21040	Economy	12200.00
0005432335857	21040	Economy	12200.00
0005435176941	21040	Economy	12200.00
0005434149673	21040	Economy	12200.00
0005435176923	21040	Economy	12200.00
0005435176938	21040	Economy	12200.00
0005435176947	21040	Economy	12200.00
0005432335863	21040	Economy	12200.00
0005432359837	21040	Economy	12200.00
0005434149669	21040	Economy	12200.00
0005435176925	21040	Economy	12200.00
0005432359689	21040	Economy	12200.00
0005432052731	21040	Economy	12200.00
0005432335870	21040	Economy	12200.00
0005434149667	21040	Economy	12200.00
0005432359694	21040	Economy	12200.00
0005432359695	21040	Economy	12200.00
0005435176924	21040	Economy	12200.00
0005435490213	21040	Economy	12200.00
0005432359915	21040	Economy	12200.00
0005434149675	21040	Economy	12200.00
0005432359855	21040	Economy	12200.00
0005432335876	21040	Economy	12200.00
0005432359651	21040	Economy	12200.00
0005435490212	21040	Economy	12200.00
0005432359688	21040	Economy	12200.00
0005435176937	21040	Economy	12200.00
0005435176945	21040	Economy	13400.00
0005435176936	21040	Economy	13400.00
0005432359664	21040	Economy	13400.00
0005435176935	21040	Economy	13400.00
0005432359643	21040	Economy	13400.00
0005432359815	21040	Economy	12200.00
0005435723035	21040	Economy	12200.00
0005432359652	21040	Economy	12200.00
0005432359514	21040	Economy	12200.00
0005432335877	21040	Economy	12200.00
0005435176946	21040	Economy	12200.00
0005434149670	21040	Economy	12200.00
0005435490214	21040	Economy	12200.00
0005432359626	21040	Economy	12200.00
0005432359675	21040	Economy	12200.00
0005434149676	21040	Economy	12200.00
0005432359859	21040	Economy	12200.00
0005432359858	21040	Economy	12200.00
0005432335929	21040	Economy	12200.00
0005435176950	21040	Economy	12200.00
0005435176933	21040	Economy	12200.00
0005432359687	21040	Economy	12200.00
0005432359657	21040	Economy	12200.00
0005432335883	21040	Economy	12200.00
0005435176932	21040	Economy	12200.00
0005432359825	21040	Economy	12200.00
0005432359521	21040	Economy	12200.00
0005432359685	21040	Economy	12200.00
0005432359702	21040	Economy	12200.00
0005432052730	21040	Economy	12200.00
0005432335856	21040	Economy	12200.00
0005432359831	21040	Economy	12200.00
0005435176949	21040	Economy	12200.00
0005432359788	21040	Economy	12200.00
0005435176944	21040	Economy	12200.00
0005432359724	21040	Economy	12200.00
0005432335842	21040	Economy	12200.00
0005432359787	21040	Economy	12200.00
0005435490215	21040	Economy	12200.00
0005432359814	21040	Economy	12200.00
0005434149674	21040	Economy	12200.00
0005432359723	21040	Economy	12200.00
0005432359520	21040	Economy	12200.00
0005435176926	21040	Economy	12200.00
0005435176930	21040	Economy	12200.00
0005432359584	21040	Economy	12200.00
0005432359665	21040	Economy	12200.00
0005434149671	21040	Economy	12200.00
0005432359936	21040	Economy	12200.00
0005435176934	21040	Economy	12200.00
0005432359703	21040	Economy	12200.00
0005432359793	21040	Economy	12200.00
0005435723036	21040	Economy	12200.00
0005434149666	21040	Economy	12200.00
0005435176927	21040	Economy	12200.00
0005432359935	21040	Economy	12200.00
0005435176939	21040	Economy	12200.00
0005435490211	21040	Economy	12200.00
0005432335872	21040	Economy	12200.00
0005435176942	21040	Economy	12200.00
0005434458579	17699	Economy	3400.00
0005434458489	17699	Economy	3100.00
0005434458553	17699	Economy	3100.00
0005434186183	17699	Economy	3100.00
0005434448281	17699	Economy	3100.00
0005434448272	17699	Economy	3100.00
0005434458535	17699	Economy	3100.00
0005434458534	17699	Economy	3100.00
0005434463906	17699	Economy	3100.00
0005434458528	17699	Economy	3100.00
0005434186186	17699	Economy	3100.00
0005434458578	17699	Economy	3100.00
0005434186185	17699	Economy	3100.00
0005434458548	17699	Economy	3100.00
0005434458569	17699	Economy	3100.00
0005434458623	17699	Economy	3100.00
0005434448269	17699	Economy	3100.00
0005434448267	17699	Economy	3100.00
0005434463904	17699	Economy	3100.00
0005434186184	17699	Economy	3100.00
0005434458571	17699	Economy	3100.00
0005434458570	17699	Economy	3100.00
0005434186160	29117	Economy	3400.00
0005434458691	29117	Economy	3400.00
0005434448295	29117	Economy	3400.00
0005434458696	29117	Economy	3100.00
0005434462779	29117	Economy	3100.00
0005434458698	29117	Economy	3100.00
0005434458693	29117	Economy	3100.00
0005434458705	29117	Economy	3100.00
0005434458702	29117	Economy	3100.00
0005434462778	29117	Economy	3100.00
0005434462776	29117	Economy	3100.00
0005434463915	29117	Economy	3100.00
0005434458701	29117	Economy	3100.00
0005434448294	29117	Economy	3100.00
0005434458710	29117	Economy	3100.00
0005434458700	29117	Economy	3100.00
0005434458711	29117	Economy	3100.00
0005434458704	29117	Economy	3100.00
0005434186149	29117	Economy	3100.00
0005434448293	29117	Economy	3100.00
0005434458709	29117	Economy	3100.00
0005434186156	29117	Economy	3100.00
0005434458708	29117	Economy	3100.00
0005434458690	29117	Economy	3100.00
0005434463916	29117	Economy	3100.00
0005434458699	29117	Economy	3100.00
0005434458703	29117	Economy	3100.00
0005434458706	29117	Economy	3100.00
0005434458694	29117	Economy	3100.00
0005434463917	29117	Economy	3100.00
0005434186155	29117	Economy	3100.00
0005434462777	29117	Economy	3100.00
0005434458707	29117	Economy	3100.00
0005434186148	29117	Economy	3100.00
0005434458695	29117	Economy	3100.00
0005434458697	29117	Economy	3100.00
0005434458692	29117	Economy	3100.00
0005432604088	21455	Economy	7300.00
0005432604115	21455	Economy	7300.00
0005432604097	21455	Economy	7300.00
0005432604122	21455	Economy	6600.00
0005432604103	21455	Economy	6600.00
0005432604123	21455	Economy	6600.00
0005435218102	21455	Economy	6600.00
0005432604104	21455	Economy	6600.00
0005432604090	21455	Economy	6600.00
0005432604093	21455	Economy	6600.00
0005432604124	21455	Economy	6600.00
0005432604116	21455	Economy	6600.00
0005432604101	21455	Economy	6600.00
0005432604091	21455	Economy	6600.00
0005432604120	21455	Economy	6600.00
0005432604121	21455	Economy	6600.00
0005432604098	21455	Economy	6600.00
0005432604089	21455	Economy	6600.00
0005432604119	21455	Economy	6600.00
0005432604095	21455	Economy	6600.00
0005432604111	21455	Economy	6600.00
0005432604112	21455	Economy	6600.00
0005432604127	21455	Economy	6600.00
0005432604110	21455	Economy	6600.00
0005432604100	21455	Economy	6600.00
0005432604113	21455	Economy	6600.00
0005432604107	21455	Economy	6600.00
0005432604125	21455	Economy	6600.00
0005432604099	21455	Economy	6600.00
0005432604105	21455	Economy	6600.00
0005432604117	21455	Economy	6600.00
0005432604108	21455	Economy	6600.00
0005432604106	21455	Economy	6600.00
0005432604094	21455	Economy	6600.00
0005432604096	21455	Economy	6600.00
0005432604109	21455	Economy	6600.00
0005432604092	21455	Economy	6600.00
0005432604102	21455	Economy	6600.00
0005435218101	21455	Economy	6600.00
0005432604126	21455	Economy	6600.00
0005432604114	21455	Economy	6600.00
0005432604118	21455	Economy	6600.00
0005432603686	31699	Economy	7300.00
0005432603774	31699	Economy	7300.00
0005435221511	31699	Economy	7300.00
0005432603767	31699	Economy	7300.00
0005432603718	31699	Economy	6600.00
0005432603721	31699	Economy	6600.00
0005432603789	31699	Economy	6600.00
0005432603717	31699	Economy	6600.00
0005432603781	31699	Economy	6600.00
0005432603733	31699	Economy	6600.00
0005432603752	31699	Economy	6600.00
0005432603722	31699	Economy	6600.00
0005432603939	31699	Economy	6600.00
0005432603912	31699	Economy	6600.00
0005432603818	31699	Economy	6600.00
0005432603716	31699	Economy	6600.00
0005432603817	31699	Economy	6600.00
0005432603664	31699	Economy	6600.00
0005435221512	31699	Economy	6600.00
0005432603841	31699	Economy	6600.00
0005435221513	31699	Economy	6600.00
0005435221051	31699	Economy	6600.00
0005435221050	31699	Economy	6600.00
0005432603646	31699	Economy	6600.00
0005432603773	31699	Economy	6600.00
0005432603732	31699	Economy	6600.00
0005432603728	31699	Economy	6600.00
0005432603731	31699	Economy	6600.00
0005432603911	31699	Economy	6600.00
0005432603889	31699	Economy	6600.00
0005432603890	31699	Economy	6600.00
0005432603891	31699	Economy	6600.00
0005435904894	18928	Economy	6600.00
0005434606791	18928	Economy	6600.00
0005434606766	18928	Economy	6600.00
0005434606767	18928	Economy	6600.00
0005434604877	22372	Economy	6600.00
0005434604879	22372	Economy	6600.00
0005434606810	22372	Economy	6600.00
0005434606809	22372	Economy	6600.00
0005434604875	22372	Economy	6600.00
0005434604876	22372	Economy	6600.00
0005434606811	22372	Economy	6600.00
0005434604878	22372	Economy	6600.00
0005434606808	22372	Economy	6600.00
0005434606806	22372	Economy	6600.00
0005434606807	22372	Economy	6600.00
0005432219981	422	Business	44500.00
0005432890717	422	Business	44500.00
0005432747375	422	Business	44500.00
0005433293163	422	Business	44500.00
0005433293158	422	Business	44500.00
0005432747346	422	Business	44500.00
0005432890842	422	Business	44500.00
0005432890695	422	Business	44500.00
0005432890741	422	Business	44500.00
0005432747364	422	Business	44500.00
0005432890802	422	Business	44500.00
0005433293167	422	Business	44500.00
0005432747347	422	Economy	14800.00
0005432219978	422	Economy	14800.00
0005432747338	422	Economy	14800.00
0005432890734	422	Economy	14800.00
0005433293149	422	Economy	14800.00
0005432747348	422	Economy	14800.00
0005432219980	422	Economy	14800.00
0005432890764	422	Economy	14800.00
0005432747363	422	Economy	14800.00
0005432747339	422	Economy	16300.00
0005432747341	422	Economy	16300.00
0005432747340	422	Economy	16300.00
0005432747361	422	Economy	16300.00
0005433293148	422	Economy	16300.00
0005432890693	422	Economy	14800.00
0005432890718	422	Economy	14800.00
0005432747344	422	Economy	14800.00
0005432747343	422	Economy	14800.00
0005433875354	422	Economy	14800.00
0005432747349	422	Economy	14800.00
0005432753282	422	Economy	14800.00
0005432747357	422	Economy	14800.00
0005432890774	422	Economy	14800.00
0005432219983	422	Economy	14800.00
0005432890742	422	Economy	14800.00
0005432747359	422	Economy	14800.00
0005432747377	422	Economy	14800.00
0005432890750	422	Economy	14800.00
0005432890749	422	Economy	14800.00
0005432747373	422	Economy	14800.00
0005433293161	422	Economy	14800.00
0005432749772	422	Economy	14800.00
0005432749773	422	Economy	14800.00
0005432747368	422	Economy	14800.00
0005432747371	422	Economy	14800.00
0005432747374	422	Economy	14800.00
0005432747365	422	Economy	14800.00
0005432753283	422	Economy	14800.00
0005432890773	422	Economy	14800.00
0005432747362	422	Economy	14800.00
0005433293166	422	Economy	14800.00
0005432753281	422	Economy	14800.00
0005432747353	422	Economy	14800.00
0005432890801	422	Economy	14800.00
0005432753280	422	Economy	14800.00
0005432747358	422	Economy	14800.00
0005432890755	422	Economy	14800.00
0005432747376	422	Economy	14800.00
0005432747342	422	Economy	14800.00
0005432749774	422	Economy	14800.00
0005432747369	422	Economy	14800.00
0005432747372	422	Economy	14800.00
0005432747367	422	Economy	14800.00
0005432890818	422	Economy	14800.00
0005432747355	422	Economy	14800.00
0005432747360	422	Economy	14800.00
0005432747345	422	Economy	14800.00
0005432890710	422	Economy	14800.00
0005432219979	422	Economy	14800.00
0005433293165	422	Economy	14800.00
0005432747354	422	Economy	14800.00
0005432747356	422	Economy	14800.00
0005432753279	422	Economy	14800.00
0005432747351	422	Economy	14800.00
0005432890765	422	Economy	14800.00
0005432751505	422	Economy	14800.00
0005432219982	422	Economy	14800.00
0005432890692	422	Economy	14800.00
0005433875353	422	Economy	14800.00
0005432747352	422	Economy	14800.00
0005432890763	422	Economy	14800.00
0005432747337	422	Economy	14800.00
0005432890739	422	Economy	14800.00
0005432751507	422	Economy	14800.00
0005432749771	422	Economy	14800.00
0005432890738	422	Economy	14800.00
0005432890756	422	Economy	14800.00
0005432890696	422	Economy	14800.00
0005432751508	422	Economy	14800.00
0005432747370	422	Economy	14800.00
0005433293162	422	Economy	14800.00
0005432747366	422	Economy	14800.00
0005432747350	422	Economy	14800.00
0005432751506	422	Economy	14800.00
0005432890910	12082	Business	44500.00
0005432214792	12082	Business	44500.00
0005433293215	12082	Business	44500.00
0005432746993	12082	Business	44500.00
0005433293213	12082	Business	44500.00
0005432746995	12082	Business	44500.00
0005432890911	12082	Business	44500.00
0005432890919	12082	Business	44500.00
0005432756804	12082	Business	44500.00
0005433293219	12082	Business	44500.00
0005433293212	12082	Business	44500.00
0005432747121	12082	Business	44500.00
0005433293218	12082	Economy	14800.00
0005432890920	12082	Economy	14800.00
0005432890915	12082	Economy	14800.00
0005432749754	12082	Economy	14800.00
0005432756790	12082	Economy	14800.00
0005432890922	12082	Economy	14800.00
0005432746992	12082	Economy	14800.00
0005432747076	12082	Economy	14800.00
0005433293214	12082	Economy	14800.00
0005432747018	12082	Economy	14800.00
0005432890918	12082	Economy	16300.00
0005433293222	12082	Economy	16300.00
0005432890912	12082	Economy	16300.00
0005432746967	12082	Economy	16300.00
0005432746947	12082	Economy	16300.00
0005432756793	12082	Economy	14800.00
0005433293211	12082	Economy	14800.00
0005432747203	12082	Economy	14800.00
0005432747212	12082	Economy	14800.00
0005432747078	12082	Economy	14800.00
0005432890917	12082	Economy	14800.00
0005432747010	12082	Economy	14800.00
0005432746927	12082	Economy	14800.00
0005432746966	12082	Economy	14800.00
0005432746915	12082	Economy	14800.00
0005432747075	12082	Economy	14800.00
0005433293221	12082	Economy	14800.00
0005432747040	12082	Economy	14800.00
0005432746994	12082	Economy	14800.00
0005432890921	12082	Economy	14800.00
0005432756802	12082	Economy	14800.00
0005432747120	12082	Economy	14800.00
0005432890916	12082	Economy	14800.00
0005432747152	12082	Economy	14800.00
0005432747050	12082	Economy	14800.00
0005433293216	12082	Economy	14800.00
0005432890925	12082	Economy	14800.00
0005432749762	12082	Economy	14800.00
0005432747123	12082	Economy	14800.00
0005433293217	12082	Economy	14800.00
0005433293223	12082	Economy	14800.00
0005433293210	12082	Economy	14800.00
0005432746892	12082	Economy	14800.00
0005432747027	12082	Economy	14800.00
0005432747145	12082	Economy	14800.00
0005432214791	12082	Economy	14800.00
0005432756803	12082	Economy	14800.00
0005432747194	12082	Economy	14800.00
0005432890929	12082	Economy	14800.00
0005432746948	12082	Economy	14800.00
0005432746996	12082	Economy	14800.00
0005432747022	12082	Economy	14800.00
0005432747213	12082	Economy	14800.00
0005432890913	12082	Economy	14800.00
0005432746913	12082	Economy	14800.00
0005432747146	12082	Economy	14800.00
0005432746986	12082	Economy	14800.00
0005432756791	12082	Economy	14800.00
0005432746914	12082	Economy	14800.00
0005432890930	12082	Economy	14800.00
0005432890914	12082	Economy	14800.00
0005432747119	12082	Economy	14800.00
0005432890927	12082	Economy	14800.00
0005432747041	12082	Economy	14800.00
0005432746984	12082	Economy	14800.00
0005432747077	12082	Economy	14800.00
0005433875370	12082	Economy	14800.00
0005432890923	12082	Economy	14800.00
0005433293220	12082	Economy	14800.00
0005432890926	12082	Economy	14800.00
0005432746985	12082	Economy	14800.00
0005432747153	12082	Economy	14800.00
0005432747011	12082	Economy	14800.00
0005432753255	12082	Economy	14800.00
0005432890928	12082	Economy	14800.00
0005432747122	12082	Economy	14800.00
0005434153527	12082	Economy	14800.00
0005432890924	12082	Economy	14800.00
0005432747195	12082	Economy	14800.00
0005432753278	12082	Economy	14800.00
0005433524971	18984	Economy	28200.00
0005433533284	18984	Economy	28200.00
0005433531269	18984	Economy	28200.00
0005433524977	18984	Economy	25700.00
0005432927920	18984	Economy	25700.00
0005433524973	18984	Economy	25700.00
0005433531271	18984	Economy	25700.00
0005433524972	18984	Economy	25700.00
0005433531272	18984	Economy	25700.00
0005433524978	18984	Economy	25700.00
0005432927918	18984	Economy	25700.00
0005432927919	18984	Economy	25700.00
0005433524974	18984	Economy	25700.00
0005433533285	18984	Economy	25700.00
0005433531270	18984	Economy	25700.00
0005433524975	18984	Economy	25700.00
0005433533286	18984	Economy	25700.00
0005433524970	18984	Economy	25700.00
0005433524976	18984	Economy	25700.00
0005433524969	18984	Economy	25700.00
0005433533283	18984	Economy	25700.00
0005433524968	18984	Economy	25700.00
0005432927894	18984	Economy	25700.00
0005433524908	32485	Economy	28200.00
0005433531230	32485	Economy	28200.00
0005432927956	32485	Economy	25700.00
0005432927959	32485	Economy	25700.00
0005433524925	32485	Economy	25700.00
0005432927958	32485	Economy	25700.00
0005432927955	32485	Economy	25700.00
0005433531243	32485	Economy	25700.00
0005433524867	32485	Economy	25700.00
0005432927954	32485	Economy	25700.00
0005433531237	32485	Economy	25700.00
0005433531244	32485	Economy	25700.00
0005433527202	32485	Economy	25700.00
0005433524926	32485	Economy	25700.00
0005432927957	32485	Economy	25700.00
0005433524868	32485	Economy	25700.00
0005433524869	32485	Economy	25700.00
0005434822884	5252	Business	84000.00
0005432121261	5252	Business	84000.00
0005434664947	5252	Business	84000.00
0005432396220	5252	Business	84000.00
0005435372232	5252	Business	84000.00
0005434822930	5252	Business	84000.00
0005434822877	5252	Business	84000.00
0005432823426	5252	Business	84000.00
0005432121258	5252	Business	84000.00
0005434822894	5252	Business	84000.00
0005435372416	5252	Business	84000.00
0005435661895	5252	Business	84000.00
0005435372229	5252	Business	84000.00
0005434822939	5252	Business	84000.00
0005434822915	5252	Business	84000.00
0005435149957	5252	Business	84000.00
0005434822931	5252	Business	84000.00
0005434822899	5252	Business	84000.00
0005432121265	5252	Business	84000.00
0005434822966	5252	Business	84000.00
0005434822871	5252	Comfort	47600.00
0005435372156	5252	Comfort	47600.00
0005434822962	5252	Comfort	47600.00
0005434822986	5252	Comfort	47600.00
0005434822923	5252	Comfort	47600.00
0005432394083	5252	Comfort	47600.00
0005434822975	5252	Comfort	47600.00
0005434828680	5252	Comfort	47600.00
0005434822900	5252	Comfort	47600.00
0005434822874	5252	Comfort	47600.00
0005435149958	5252	Comfort	47600.00
0005434822881	5252	Comfort	47600.00
0005435372202	5252	Comfort	47600.00
0005434822978	5252	Comfort	47600.00
0005435372561	5252	Comfort	47600.00
0005434822932	5252	Comfort	47600.00
0005435372439	5252	Comfort	47600.00
0005434822889	5252	Comfort	47600.00
0005434558227	5252	Comfort	47600.00
0005435149950	5252	Comfort	47600.00
0005434822997	5252	Comfort	47600.00
0005435386496	5252	Comfort	47600.00
0005432394081	5252	Comfort	47600.00
0005434822907	5252	Comfort	47600.00
0005434822977	5252	Comfort	47600.00
0005434822909	5252	Comfort	47600.00
0005435735082	5252	Comfort	47600.00
0005434822906	5252	Comfort	47600.00
0005434822965	5252	Comfort	47600.00
0005434822890	5252	Economy	28000.00
0005434822998	5252	Economy	28000.00
0005434822878	5252	Economy	28000.00
0005434831121	5252	Economy	28000.00
0005435372201	5252	Economy	28000.00
0005435299704	5252	Economy	28000.00
0005434822960	5252	Economy	28000.00
0005432121267	5252	Economy	28000.00
0005434822925	5252	Economy	28000.00
0005434822872	5252	Economy	28000.00
0005435386497	5252	Economy	28000.00
0005434822898	5252	Economy	28000.00
0005432823421	5252	Economy	28000.00
0005434822970	5252	Economy	28000.00
0005434822912	5252	Economy	28000.00
0005434822885	5252	Economy	28000.00
0005434822961	5252	Economy	28000.00
0005435149951	5252	Economy	28000.00
0005434822926	5252	Economy	28000.00
0005432121262	5252	Economy	28000.00
0005435372560	5252	Economy	28000.00
0005434822927	5252	Economy	28000.00
0005434822942	5252	Economy	28000.00
0005434822887	5252	Economy	28000.00
0005435372369	5252	Economy	28000.00
0005434822987	5252	Economy	28000.00
0005434822893	5252	Economy	28000.00
0005434822950	5252	Economy	28000.00
0005434822968	5252	Economy	28000.00
0005435372558	5252	Economy	28000.00
0005435149955	5252	Economy	28000.00
0005435372588	5252	Economy	28000.00
0005434822895	5252	Economy	28000.00
0005435178979	5252	Economy	28000.00
0005434822963	5252	Economy	28000.00
0005435372509	5252	Economy	28000.00
0005434822991	5252	Economy	28000.00
0005434822905	5252	Economy	28000.00
0005434822951	5252	Economy	28000.00
0005435661894	5252	Economy	28000.00
0005435372435	5252	Economy	28000.00
0005434822922	5252	Economy	28000.00
0005434822892	5252	Economy	28000.00
0005432394082	5252	Economy	28000.00
0005434828679	5252	Economy	28000.00
0005435372347	5252	Economy	28000.00
0005435149956	5252	Economy	30800.00
0005434822917	5252	Economy	30800.00
0005435149954	5252	Economy	28000.00
0005434822959	5252	Economy	30800.00
0005435304105	5252	Economy	28000.00
0005434822958	5252	Economy	28000.00
0005434664946	5252	Economy	30800.00
0005434822979	5252	Economy	28000.00
0005435372147	5252	Economy	28000.00
0005432121260	5252	Economy	28000.00
0005435149961	5252	Economy	28000.00
0005435372629	5252	Economy	28000.00
0005434822941	5252	Economy	28000.00
0005435372423	5252	Economy	28000.00
0005432121268	5252	Economy	28000.00
0005432121263	5252	Economy	28000.00
0005434822981	5252	Economy	28000.00
0005435386469	5252	Economy	28000.00
0005435372593	5252	Economy	28000.00
0005435386489	5252	Economy	28000.00
0005434822918	5252	Economy	28000.00
0005434822883	5252	Economy	28000.00
0005434822985	5252	Economy	28000.00
0005432121256	5252	Economy	28000.00
0005434822938	5252	Economy	28000.00
0005435372340	5252	Economy	28000.00
0005435372236	5252	Economy	28000.00
0005434822933	5252	Economy	28000.00
0005434822873	5252	Economy	28000.00
0005432823419	5252	Economy	28000.00
0005434828681	5252	Economy	28000.00
0005434558228	5252	Economy	28000.00
0005434822879	5252	Economy	28000.00
0005435372228	5252	Economy	28000.00
0005435372592	5252	Economy	28000.00
0005434822901	5252	Economy	28000.00
0005435372540	5252	Economy	28000.00
0005435372517	5252	Economy	28000.00
0005434822993	5252	Economy	28000.00
0005435372385	5252	Economy	28000.00
0005435661884	5252	Economy	28000.00
0005434822903	5252	Economy	28000.00
0005434822869	5252	Economy	28000.00
0005432396223	5252	Economy	28000.00
0005434822924	5252	Economy	28000.00
0005434822886	5252	Economy	28000.00
0005435299707	5252	Economy	28000.00
0005434822957	5252	Economy	28000.00
0005434822990	5252	Economy	28000.00
0005434822913	5252	Economy	28000.00
0005435372504	5252	Economy	28000.00
0005434822949	5252	Economy	28000.00
0005434822935	5252	Economy	28000.00
0005435372361	5252	Economy	28000.00
0005434822982	5252	Economy	28000.00
0005435386488	5252	Economy	28000.00
0005434822910	5252	Economy	28000.00
0005434822992	5252	Economy	28000.00
0005434822891	5252	Economy	28000.00
0005432121269	5252	Economy	28000.00
0005434822967	5252	Economy	28000.00
0005434822902	5252	Economy	28000.00
0005435372449	5252	Economy	28000.00
0005435372363	5252	Economy	28000.00
0005435372326	5252	Economy	28000.00
0005434822995	5252	Economy	28000.00
0005434822911	5252	Economy	28000.00
0005434822936	5252	Economy	28000.00
0005435372206	5252	Economy	28000.00
0005434822994	5252	Economy	28000.00
0005434822973	5252	Economy	28000.00
0005434822929	5252	Economy	28000.00
0005435372227	5252	Economy	28000.00
0005435149963	5252	Economy	28000.00
0005435372516	5252	Economy	28000.00
0005434822921	5252	Economy	28000.00
0005435386470	5252	Economy	28000.00
0005434822904	5252	Economy	28000.00
0005435372157	5252	Economy	28000.00
0005435386456	5252	Economy	28000.00
0005434822947	5252	Economy	28000.00
0005434822969	5252	Economy	30800.00
0005434822996	5252	Economy	28000.00
0005432823417	5252	Economy	30800.00
0005435149959	5252	Economy	30800.00
0005434822984	5252	Economy	30800.00
0005434822916	5252	Economy	30800.00
0005434822870	5252	Economy	28000.00
0005435372155	5252	Economy	28000.00
0005432396221	5252	Economy	28000.00
0005434822964	5252	Economy	28000.00
0005434822974	5252	Economy	28000.00
0005435372329	5252	Economy	28000.00
0005434822988	5252	Economy	28000.00
0005434831123	5252	Economy	28000.00
0005434822989	5252	Economy	28000.00
0005432121266	5252	Economy	28000.00
0005435149952	5252	Economy	28000.00
0005435372355	5252	Economy	28000.00
0005435372230	5252	Economy	28000.00
0005435372330	5252	Economy	28000.00
0005435386494	5252	Economy	28000.00
0005435386457	5252	Economy	28000.00
0005435372384	5252	Economy	28000.00
0005432121257	5252	Economy	28000.00
0005435372444	5252	Economy	28000.00
0005434822888	5252	Economy	28000.00
0005435372426	5252	Economy	28000.00
0005434822875	5252	Economy	28000.00
0005434822948	5252	Economy	28000.00
0005434822937	5252	Economy	28000.00
0005435304106	5252	Economy	28000.00
0005434822943	5252	Economy	28000.00
0005435372597	5252	Economy	28000.00
0005434822952	5252	Economy	28000.00
0005434822954	5252	Economy	28000.00
0005435178980	5252	Economy	28000.00
0005435304116	5252	Economy	28000.00
0005435372263	5252	Economy	28000.00
0005434822945	5252	Economy	28000.00
0005434822972	5252	Economy	28000.00
0005434822940	5252	Economy	28000.00
0005434822914	5252	Economy	28000.00
0005435299710	5252	Economy	28000.00
0005435372240	5252	Economy	28000.00
0005434822897	5252	Economy	28000.00
0005435149953	5252	Economy	28000.00
0005434822880	5252	Economy	28000.00
0005432394084	5252	Economy	28000.00
0005435372598	5252	Economy	28000.00
0005434822896	5252	Economy	28000.00
0005435149962	5252	Economy	28000.00
0005435372283	5252	Economy	28000.00
0005434822955	5252	Economy	28000.00
0005434822983	5252	Economy	28000.00
0005435372339	5252	Economy	28000.00
0005434822908	5252	Economy	28000.00
0005435149960	5252	Economy	28000.00
0005435372233	5252	Economy	28000.00
0005434822956	5252	Economy	28000.00
0005432121264	5252	Economy	28000.00
0005434822928	5252	Economy	28000.00
0005434664948	5252	Economy	28000.00
0005434822882	5252	Economy	28000.00
0005434822971	5252	Economy	28000.00
0005434831122	5252	Economy	28000.00
0005435386495	5252	Economy	28000.00
0005432121259	5252	Economy	28000.00
0005435372264	5252	Economy	28000.00
0005434822946	5252	Economy	28000.00
0005435372362	5252	Economy	28000.00
0005434822980	5252	Economy	28000.00
0005432396222	5252	Economy	28000.00
0005435372539	5252	Economy	28000.00
0005434822920	5252	Economy	28000.00
0005434822944	5252	Economy	28000.00
0005435372453	5252	Economy	28000.00
0005432823420	5252	Economy	28000.00
0005434822953	5252	Economy	28000.00
0005435386471	5252	Economy	28000.00
0005435372239	5252	Economy	28000.00
0005434822919	5252	Economy	28000.00
0005434822934	5252	Economy	28000.00
0005434822876	5252	Economy	28000.00
0005434822976	5252	Economy	28000.00
0005432823439	9938	Business	84000.00
0005434821680	9938	Business	84000.00
0005434821621	9938	Business	84000.00
0005435372932	9938	Business	84000.00
0005434821634	9938	Business	84000.00
0005434828666	9938	Business	84000.00
0005435372940	9938	Business	84000.00
0005434821984	9938	Business	84000.00
0005434821412	9938	Business	84000.00
0005434821683	9938	Business	84000.00
0005434821548	9938	Business	84000.00
0005432400087	9938	Business	84000.00
0005435372907	9938	Business	84000.00
0005435372914	9938	Business	84000.00
0005434821651	9938	Business	84000.00
0005434822259	9938	Business	84000.00
0005434822232	9938	Comfort	47600.00
0005434821917	9938	Comfort	47600.00
0005434821885	9938	Comfort	47600.00
0005434822430	9938	Comfort	47600.00
0005434821411	9938	Comfort	47600.00
0005435372897	9938	Comfort	47600.00
0005435372904	9938	Comfort	47600.00
0005435372941	9938	Comfort	47600.00
0005434822355	9938	Comfort	47600.00
0005432396182	9938	Comfort	47600.00
0005435372923	9938	Comfort	47600.00
0005434821926	9938	Comfort	47600.00
0005434821743	9938	Comfort	47600.00
0005432396186	9938	Comfort	47600.00
0005432400079	9938	Comfort	47600.00
0005435372953	9938	Comfort	47600.00
0005434821817	9938	Comfort	47600.00
0005432203028	9938	Comfort	47600.00
0005435372947	9938	Comfort	47600.00
0005432203026	9938	Comfort	47600.00
0005435299750	9938	Comfort	47600.00
0005434822028	9938	Comfort	47600.00
0005434821884	9938	Comfort	47600.00
0005435372910	9938	Comfort	47600.00
0005434822104	9938	Comfort	47600.00
0005434821887	9938	Comfort	47600.00
0005435372902	9938	Comfort	47600.00
0005435372922	9938	Comfort	47600.00
0005434821653	9938	Economy	28000.00
0005432203029	9938	Economy	28000.00
0005435372928	9938	Economy	28000.00
0005435372913	9938	Economy	28000.00
0005434831071	9938	Economy	28000.00
0005435299753	9938	Economy	28000.00
0005434821960	9938	Economy	28000.00
0005435372930	9938	Economy	28000.00
0005434821652	9938	Economy	28000.00
0005435149831	9938	Economy	28000.00
0005435302175	9938	Economy	28000.00
0005434821852	9938	Economy	28000.00
0005434821911	9938	Economy	28000.00
0005435386542	9938	Economy	28000.00
0005434822233	9938	Economy	28000.00
0005434822203	9938	Economy	28000.00
0005434821848	9938	Economy	28000.00
0005435299752	9938	Economy	28000.00
0005434822127	9938	Economy	28000.00
0005434822040	9938	Economy	28000.00
0005434821327	9938	Economy	28000.00
0005434558151	9938	Economy	28000.00
0005434821868	9938	Economy	28000.00
0005434821745	9938	Economy	28000.00
0005435372958	9938	Economy	28000.00
0005434821754	9938	Economy	28000.00
0005434821483	9938	Economy	28000.00
0005435735117	9938	Economy	28000.00
0005435149881	9938	Economy	28000.00
0005434822258	9938	Economy	28000.00
0005435372933	9938	Economy	28000.00
0005434821876	9938	Economy	28000.00
0005435372912	9938	Economy	28000.00
0005435386540	9938	Economy	28000.00
0005432203022	9938	Economy	28000.00
0005435372920	9938	Economy	28000.00
0005434822180	9938	Economy	28000.00
0005434822279	9938	Economy	28000.00
0005432400085	9938	Economy	28000.00
0005435372898	9938	Economy	28000.00
0005435372906	9938	Economy	28000.00
0005434822429	9938	Economy	30800.00
0005434821860	9938	Economy	28000.00
0005435302178	9938	Economy	28000.00
0005435149836	9938	Economy	28000.00
0005435386541	9938	Economy	30800.00
0005434822240	9938	Economy	30800.00
0005435372935	9938	Economy	28000.00
0005435299751	9938	Economy	28000.00
0005435661915	9938	Economy	28000.00
0005435179392	9938	Economy	28000.00
0005434822463	9938	Economy	28000.00
0005434821740	9938	Economy	28000.00
0005435149834	9938	Economy	28000.00
0005434558152	9938	Economy	28000.00
0005434821898	9938	Economy	28000.00
0005432396181	9938	Economy	28000.00
0005434821763	9938	Economy	28000.00
0005434822066	9938	Economy	28000.00
0005434822016	9938	Economy	28000.00
0005434821602	9938	Economy	28000.00
0005434822245	9938	Economy	28000.00
0005434558148	9938	Economy	28000.00
0005435372899	9938	Economy	28000.00
0005435149890	9938	Economy	28000.00
0005434821328	9938	Economy	28000.00
0005434822050	9938	Economy	28000.00
0005435372925	9938	Economy	28000.00
0005434821719	9938	Economy	28000.00
0005434821588	9938	Economy	28000.00
0005434821878	9938	Economy	28000.00
0005434664936	9938	Economy	28000.00
0005434822185	9938	Economy	28000.00
0005435372895	9938	Economy	28000.00
0005434821688	9938	Economy	28000.00
0005435372934	9938	Economy	28000.00
0005435372954	9938	Economy	28000.00
0005434822051	9938	Economy	28000.00
0005435372901	9938	Economy	28000.00
0005435372943	9938	Economy	28000.00
0005435372950	9938	Economy	28000.00
0005434821953	9938	Economy	28000.00
0005434821317	9938	Economy	28000.00
0005435372919	9938	Economy	28000.00
0005434821598	9938	Economy	28000.00
0005434821618	9938	Economy	28000.00
0005435372924	9938	Economy	28000.00
0005432400078	9938	Economy	28000.00
0005432203023	9938	Economy	28000.00
0005434821476	9938	Economy	28000.00
0005434822280	9938	Economy	28000.00
0005435149835	9938	Economy	28000.00
0005434821912	9938	Economy	28000.00
0005435372929	9938	Economy	28000.00
0005434821670	9938	Economy	28000.00
0005434821547	9938	Economy	28000.00
0005435372957	9938	Economy	28000.00
0005435661916	9938	Economy	28000.00
0005434822087	9938	Economy	28000.00
0005434821504	9938	Economy	28000.00
0005434821517	9938	Economy	28000.00
0005435372917	9938	Economy	28000.00
0005435149815	9938	Economy	28000.00
0005434821832	9938	Economy	28000.00
0005434821925	9938	Economy	28000.00
0005435386543	9938	Economy	28000.00
0005434821573	9938	Economy	28000.00
0005434821716	9938	Economy	28000.00
0005434821329	9938	Economy	28000.00
0005434821999	9938	Economy	28000.00
0005434558145	9938	Economy	28000.00
0005434821959	9938	Economy	28000.00
0005434821755	9938	Economy	28000.00
0005434821635	9938	Economy	28000.00
0005434821866	9938	Economy	28000.00
0005435372938	9938	Economy	28000.00
0005434822005	9938	Economy	28000.00
0005435372931	9938	Economy	28000.00
0005434821955	9938	Economy	28000.00
0005434821826	9938	Economy	28000.00
0005434821646	9938	Economy	28000.00
0005434821961	9938	Economy	28000.00
0005434822322	9938	Economy	28000.00
0005434821509	9938	Economy	28000.00
0005434821482	9938	Economy	28000.00
0005434821991	9938	Economy	28000.00
0005434822234	9938	Economy	28000.00
0005435302176	9938	Economy	28000.00
0005434558147	9938	Economy	28000.00
0005434822126	9938	Economy	30800.00
0005435372905	9938	Economy	30800.00
0005435372942	9938	Economy	30800.00
0005434821816	9938	Economy	30800.00
0005435372937	9938	Economy	28000.00
0005434821668	9938	Economy	28000.00
0005435149830	9938	Economy	28000.00
0005435149837	9938	Economy	28000.00
0005435372952	9938	Economy	28000.00
0005434821846	9938	Economy	28000.00
0005434822086	9938	Economy	28000.00
0005435735119	9938	Economy	28000.00
0005435372915	9938	Economy	28000.00
0005434821511	9938	Economy	28000.00
0005435372926	9938	Economy	28000.00
0005435372918	9938	Economy	28000.00
0005434821790	9938	Economy	28000.00
0005435372908	9938	Economy	28000.00
0005435372948	9938	Economy	28000.00
0005434558150	9938	Economy	28000.00
0005435372911	9938	Economy	28000.00
0005435372945	9938	Economy	28000.00
0005434821679	9938	Economy	28000.00
0005434821582	9938	Economy	28000.00
0005435302173	9938	Economy	28000.00
0005435149889	9938	Economy	28000.00
0005432203025	9938	Economy	28000.00
0005434821739	9938	Economy	28000.00
0005435372955	9938	Economy	28000.00
0005435372956	9938	Economy	28000.00
0005435386545	9938	Economy	28000.00
0005434822054	9938	Economy	28000.00
0005435372900	9938	Economy	28000.00
0005435149896	9938	Economy	28000.00
0005434821484	9938	Economy	28000.00
0005435372939	9938	Economy	28000.00
0005435735118	9938	Economy	28000.00
0005435302177	9938	Economy	28000.00
0005434821922	9938	Economy	28000.00
0005435372916	9938	Economy	28000.00
0005434821998	9938	Economy	28000.00
0005435372960	9938	Economy	28000.00
0005435372936	9938	Economy	28000.00
0005435372903	9938	Economy	28000.00
0005432823440	9938	Economy	28000.00
0005435372946	9938	Economy	28000.00
0005434822000	9938	Economy	28000.00
0005432203024	9938	Economy	28000.00
0005435372896	9938	Economy	28000.00
0005435372921	9938	Economy	28000.00
0005432203027	9938	Economy	28000.00
0005434821918	9938	Economy	28000.00
0005435149797	9938	Economy	28000.00
0005434821601	9938	Economy	28000.00
0005435372909	9938	Economy	28000.00
0005434822525	9938	Economy	28000.00
0005432396185	9938	Economy	28000.00
0005434822272	9938	Economy	28000.00
0005434821558	9938	Economy	28000.00
0005435372959	9938	Economy	28000.00
0005435386544	9938	Economy	28000.00
0005434822358	9938	Economy	28000.00
0005435372944	9938	Economy	28000.00
0005435386539	9938	Economy	28000.00
0005434822268	9938	Economy	28000.00
0005435372927	9938	Economy	28000.00
0005435149897	9938	Economy	28000.00
0005435302174	9938	Economy	28000.00
0005434822103	9938	Economy	28000.00
0005434822024	9938	Economy	28000.00
0005434821720	9938	Economy	28000.00
0005434822160	9938	Economy	28000.00
0005434821510	9938	Economy	28000.00
0005435661917	9938	Economy	28000.00
0005435372949	9938	Economy	28000.00
0005435372951	9938	Economy	28000.00
0005435082742	6996	Economy	8200.00
0005435790293	6996	Economy	8200.00
0005435082745	6996	Economy	7400.00
0005435082747	6996	Economy	7400.00
0005435082748	6996	Economy	7400.00
0005435790292	6996	Economy	7400.00
0005435082743	6996	Economy	7400.00
0005435082750	6996	Economy	7400.00
0005435082744	6996	Economy	7400.00
0005435082746	6996	Economy	7400.00
0005435082751	6996	Economy	7400.00
0005435082749	6996	Economy	7400.00
0005435082709	26015	Economy	8200.00
0005435790271	26015	Economy	8200.00
0005435082654	26015	Economy	7400.00
0005435082662	26015	Economy	7400.00
0005435082670	26015	Economy	7400.00
0005435082663	26015	Economy	7400.00
0005435082676	26015	Economy	7400.00
0005435790270	26015	Economy	7400.00
0005435082699	26015	Economy	7400.00
0005435082668	26015	Economy	7400.00
0005435790274	26015	Economy	7400.00
0005435082700	26015	Economy	7400.00
0005435790275	26015	Economy	7400.00
0005434756222	9523	Business	32800.00
0005434213963	9523	Business	32800.00
0005434756208	9523	Business	32800.00
0005434756207	9523	Business	32800.00
0005434756229	9523	Business	32800.00
0005434213861	9523	Business	32800.00
0005434213919	9523	Business	32800.00
0005434756202	9523	Business	32800.00
0005434213802	9523	Business	32800.00
0005434213760	9523	Business	32800.00
0005434756212	9523	Economy	10900.00
0005434756230	9523	Economy	10900.00
0005434213821	9523	Economy	10900.00
0005434213877	9523	Economy	10900.00
0005434213759	9523	Economy	10900.00
0005434756204	9523	Economy	10900.00
0005434213838	9523	Economy	10900.00
0005434213837	9523	Economy	10900.00
0005434213818	9523	Economy	10900.00
0005434213867	9523	Economy	12000.00
0005434213858	9523	Economy	12000.00
0005434213896	9523	Economy	12000.00
0005434756225	9523	Economy	12000.00
0005434214048	9523	Economy	12000.00
0005434756210	9523	Economy	10900.00
0005434213964	9523	Economy	10900.00
0005434214014	9523	Economy	10900.00
0005434756231	9523	Economy	10900.00
0005434213803	9523	Economy	10900.00
0005434214003	9523	Economy	10900.00
0005434756206	9523	Economy	10900.00
0005434756226	9523	Economy	10900.00
0005434213839	9523	Economy	10900.00
0005434213761	9523	Economy	10900.00
0005434214015	9523	Economy	10900.00
0005434213996	9523	Economy	10900.00
0005434213842	9523	Economy	10900.00
0005434756232	9523	Economy	10900.00
0005434756228	9523	Economy	10900.00
0005434214106	9523	Economy	10900.00
0005434213868	9523	Economy	10900.00
0005434213779	9523	Economy	10900.00
0005434756203	9523	Economy	10900.00
0005434213762	9523	Economy	10900.00
0005434756215	9523	Economy	10900.00
0005434756218	9523	Economy	10900.00
0005434756205	9523	Economy	10900.00
0005434213795	9523	Economy	10900.00
0005434213905	9523	Economy	10900.00
0005434214084	9523	Economy	10900.00
0005434213948	9523	Economy	10900.00
0005434213999	9523	Economy	10900.00
0005434756219	9523	Economy	10900.00
0005434756209	9523	Economy	10900.00
0005434213965	9523	Economy	10900.00
0005434756233	9523	Economy	10900.00
0005434756223	9523	Economy	10900.00
0005434213790	9523	Economy	10900.00
0005434213859	9523	Economy	10900.00
0005434213820	9523	Economy	10900.00
0005434756211	9523	Economy	10900.00
0005434756214	9523	Economy	10900.00
0005434213894	9523	Economy	10900.00
0005434213719	9523	Economy	10900.00
0005434756213	9523	Economy	10900.00
0005434213918	9523	Economy	10900.00
0005434214016	9523	Economy	10900.00
0005434213966	9523	Economy	10900.00
0005434213812	9523	Economy	10900.00
0005434213720	9523	Economy	10900.00
0005434756221	9523	Economy	10900.00
0005434213804	9523	Economy	10900.00
0005434213893	9523	Economy	10900.00
0005434213910	9523	Economy	10900.00
0005434756224	9523	Economy	10900.00
0005434213997	9523	Economy	10900.00
0005434213909	9523	Economy	10900.00
0005434213895	9523	Economy	10900.00
0005434213904	9523	Economy	10900.00
0005434756220	9523	Economy	10900.00
0005434756227	9523	Economy	10900.00
0005434213773	9523	Economy	10900.00
0005434756217	9523	Economy	10900.00
0005434756216	9523	Economy	10900.00
0005434755869	28589	Business	32800.00
0005434214259	28589	Business	32800.00
0005434214262	28589	Business	32800.00
0005434214233	28589	Business	32800.00
0005434214254	28589	Business	32800.00
0005434214244	28589	Business	32800.00
0005434214250	28589	Business	32800.00
0005434214224	28589	Business	32800.00
0005434214249	28589	Business	32800.00
0005434214243	28589	Economy	10900.00
0005434755797	28589	Economy	10900.00
0005434214260	28589	Economy	10900.00
0005434755773	28589	Economy	10900.00
0005434214257	28589	Economy	10900.00
0005434214231	28589	Economy	10900.00
0005434214230	28589	Economy	12000.00
0005434214247	28589	Economy	12000.00
0005434214222	28589	Economy	12000.00
0005434214226	28589	Economy	12000.00
0005434755733	28589	Economy	10900.00
0005434214248	28589	Economy	10900.00
0005434755874	28589	Economy	10900.00
0005434214245	28589	Economy	10900.00
0005434214242	28589	Economy	10900.00
0005434214263	28589	Economy	10900.00
0005434214264	28589	Economy	10900.00
0005434214221	28589	Economy	10900.00
0005434214229	28589	Economy	10900.00
0005434755736	28589	Economy	10900.00
0005434755839	28589	Economy	10900.00
0005434214234	28589	Economy	10900.00
0005434755755	28589	Economy	10900.00
0005434214256	28589	Economy	10900.00
0005434755729	28589	Economy	10900.00
0005434755743	28589	Economy	10900.00
0005434755790	28589	Economy	10900.00
0005434214266	28589	Economy	10900.00
0005434214228	28589	Economy	10900.00
0005434214267	28589	Economy	10900.00
0005434755782	28589	Economy	10900.00
0005434214258	28589	Economy	10900.00
0005434214255	28589	Economy	10900.00
0005434755866	28589	Economy	10900.00
0005434214241	28589	Economy	10900.00
0005434214236	28589	Economy	10900.00
0005434214261	28589	Economy	10900.00
0005434755903	28589	Economy	10900.00
0005434755818	28589	Economy	10900.00
0005434214239	28589	Economy	10900.00
0005434755722	28589	Economy	10900.00
0005434214240	28589	Economy	10900.00
0005434755875	28589	Economy	10900.00
0005434214253	28589	Economy	10900.00
0005434755800	28589	Economy	10900.00
0005434214268	28589	Economy	10900.00
0005434755730	28589	Economy	10900.00
0005434214235	28589	Economy	10900.00
0005434755843	28589	Economy	10900.00
0005434214223	28589	Economy	10900.00
0005434214225	28589	Economy	10900.00
0005434755870	28589	Economy	10900.00
0005434214227	28589	Economy	10900.00
0005434214246	28589	Economy	10900.00
0005434214251	28589	Economy	10900.00
0005434214265	28589	Economy	10900.00
0005434214238	28589	Economy	10900.00
0005434755816	28589	Economy	10900.00
0005434755808	28589	Economy	10900.00
0005434214252	28589	Economy	10900.00
0005434755724	28589	Economy	10900.00
0005434755876	28589	Economy	10900.00
0005434214237	28589	Economy	10900.00
0005434214232	28589	Economy	10900.00
0005434755844	28589	Economy	10900.00
0005434755838	28589	Economy	10900.00
0005434755873	28589	Economy	10900.00
0005434755815	28589	Economy	10900.00
0005435100106	10818	Economy	8900.00
0005435100109	10818	Economy	8900.00
0005435100107	10818	Economy	8900.00
0005434760174	10818	Economy	8900.00
0005435100108	10818	Economy	8900.00
0005434760175	10818	Economy	8900.00
0005434760186	31828	Economy	8900.00
0005435100079	31828	Economy	8900.00
0005434760183	31828	Economy	8900.00
0005434760184	31828	Economy	8900.00
0005434760185	31828	Economy	8900.00
0005434760187	31828	Economy	8900.00
0005434639196	2007	Economy	20900.00
0005434639210	2007	Economy	20900.00
0005434639188	2007	Economy	20900.00
0005433202151	2007	Economy	20900.00
0005434639192	2007	Economy	19000.00
0005434639194	2007	Economy	19000.00
0005434639209	2007	Economy	19000.00
0005434639206	2007	Economy	19000.00
0005434639199	2007	Economy	19000.00
0005433202117	2007	Economy	19000.00
0005434639189	2007	Economy	19000.00
0005434639185	2007	Economy	19000.00
0005434639200	2007	Economy	19000.00
0005434639195	2007	Economy	19000.00
0005433202118	2007	Economy	19000.00
0005432290617	2007	Economy	19000.00
0005433202181	2007	Economy	19000.00
0005434639207	2007	Economy	19000.00
0005434639202	2007	Economy	19000.00
0005434639183	2007	Economy	19000.00
0005434639191	2007	Economy	19000.00
0005434639190	2007	Economy	19000.00
0005434639198	2007	Economy	19000.00
0005434639204	2007	Economy	19000.00
0005434639186	2007	Economy	19000.00
0005435948324	2007	Economy	19000.00
0005433202166	2007	Economy	19000.00
0005432290618	2007	Economy	19000.00
0005433202133	2007	Economy	19000.00
0005433202175	2007	Economy	19000.00
0005434639187	2007	Economy	19000.00
0005434639197	2007	Economy	19000.00
0005433202152	2007	Economy	19000.00
0005433202150	2007	Economy	19000.00
0005435948323	2007	Economy	19000.00
0005434639203	2007	Economy	19000.00
0005434639205	2007	Economy	19000.00
0005434639208	2007	Economy	19000.00
0005432290619	2007	Economy	19000.00
0005434639201	2007	Economy	19000.00
0005433202149	2007	Economy	19000.00
0005434639184	2007	Economy	19000.00
0005434639193	2007	Economy	19000.00
0005435948322	2007	Economy	19000.00
0005434638876	23260	Economy	20900.00
0005434638860	23260	Economy	20900.00
0005434638964	23260	Economy	20900.00
0005434638918	23260	Economy	19000.00
0005434638945	23260	Economy	19000.00
0005434638970	23260	Economy	19000.00
0005433202282	23260	Economy	19000.00
0005433202268	23260	Economy	19000.00
0005433202279	23260	Economy	19000.00
0005435948307	23260	Economy	19000.00
0005434638911	23260	Economy	19000.00
0005433202270	23260	Economy	19000.00
0005433202280	23260	Economy	19000.00
0005434638962	23260	Economy	19000.00
0005434638963	23260	Economy	19000.00
0005434638952	23260	Economy	19000.00
0005434638949	23260	Economy	19000.00
0005433202278	23260	Economy	19000.00
0005434638922	23260	Economy	19000.00
0005434638940	23260	Economy	19000.00
0005433202272	23260	Economy	19000.00
0005434638857	23260	Economy	19000.00
0005434638953	23260	Economy	19000.00
0005433202277	23260	Economy	19000.00
0005434638925	23260	Economy	19000.00
0005434638944	23260	Economy	19000.00
0005434639011	23260	Economy	19000.00
0005434639005	23260	Economy	19000.00
0005433202273	23260	Economy	19000.00
0005434638880	23260	Economy	19000.00
0005434638901	23260	Economy	19000.00
0005434638956	23260	Economy	19000.00
0005434638980	23260	Economy	19000.00
0005433202275	23260	Economy	19000.00
0005433202281	23260	Economy	19000.00
0005434638967	23260	Economy	19000.00
0005434638923	23260	Economy	19000.00
0005434639059	23260	Economy	19000.00
0005434638912	23260	Economy	19000.00
0005433202276	23260	Economy	19000.00
0005434638888	23260	Economy	19000.00
0005434638877	23260	Economy	19000.00
0005433202271	23260	Economy	19000.00
0005434638948	23260	Economy	19000.00
0005433202274	23260	Economy	19000.00
0005434638858	23260	Economy	19000.00
0005433202269	23260	Economy	19000.00
0005435326595	6058	Business	69700.00
0005435326531	6058	Business	69700.00
0005434600679	6058	Business	69700.00
0005435326547	6058	Business	69700.00
0005435326530	6058	Business	69700.00
0005433531275	6058	Business	69700.00
0005433533287	6058	Business	69700.00
0005434600672	6058	Business	69700.00
0005434600658	6058	Business	69700.00
0005434600669	6058	Economy	23200.00
0005435326600	6058	Economy	23200.00
0005433533289	6058	Economy	23200.00
0005434600674	6058	Economy	23200.00
0005432111263	6058	Economy	23200.00
0005434600682	6058	Economy	25600.00
0005434600675	6058	Economy	25600.00
0005433533290	6058	Economy	23200.00
0005435326597	6058	Economy	23200.00
0005434600665	6058	Economy	23200.00
0005434600670	6058	Economy	23200.00
0005432111264	6058	Economy	23200.00
0005435326598	6058	Economy	23200.00
0005433531274	6058	Economy	23200.00
0005435326614	6058	Economy	23200.00
0005434600660	6058	Economy	23200.00
0005433531277	6058	Economy	23200.00
0005433531273	6058	Economy	23200.00
0005435326548	6058	Economy	23200.00
0005435326601	6058	Economy	23200.00
0005434600680	6058	Economy	23200.00
0005435326563	6058	Economy	23200.00
0005435326564	6058	Economy	23200.00
0005434600681	6058	Economy	23200.00
0005434600671	6058	Economy	23200.00
0005434600684	6058	Economy	23200.00
0005433533288	6058	Economy	23200.00
0005434600662	6058	Economy	23200.00
0005434600677	6058	Economy	23200.00
0005435326596	6058	Economy	23200.00
0005435326556	6058	Economy	23200.00
0005434600664	6058	Economy	23200.00
0005434600668	6058	Economy	23200.00
0005435326535	6058	Economy	23200.00
0005434600661	6058	Economy	23200.00
0005434600673	6058	Economy	23200.00
0005435326567	6058	Economy	23200.00
0005434600678	6058	Economy	23200.00
0005434600666	6058	Economy	23200.00
0005434600659	6058	Economy	23200.00
0005434600667	6058	Economy	23200.00
0005434600683	6058	Economy	23200.00
0005434600685	6058	Economy	23200.00
0005434600676	6058	Economy	23200.00
0005434600663	6058	Economy	23200.00
0005435326582	6058	Economy	23200.00
0005435326602	6058	Economy	23200.00
0005433531276	6058	Economy	23200.00
0005435326677	18604	Business	69700.00
0005435326674	18604	Business	69700.00
0005434600480	18604	Business	69700.00
0005434600430	18604	Business	69700.00
0005433527203	18604	Business	69700.00
0005434600428	18604	Economy	23200.00
0005435326679	18604	Economy	23200.00
0005435326675	18604	Economy	23200.00
0005435326672	18604	Economy	23200.00
0005435326669	18604	Economy	23200.00
0005433531226	18604	Economy	23200.00
0005434600398	18604	Economy	23200.00
0005435326678	18604	Economy	25600.00
0005434600576	18604	Economy	25600.00
0005435326670	18604	Economy	25600.00
0005434600534	18604	Economy	25600.00
0005433531225	18604	Economy	23200.00
0005435326668	18604	Economy	23200.00
0005434600426	18604	Economy	23200.00
0005434600578	18604	Economy	23200.00
0005435326671	18604	Economy	23200.00
0005435326680	18604	Economy	23200.00
0005434600417	18604	Economy	23200.00
0005433531241	18604	Economy	23200.00
0005434600501	18604	Economy	23200.00
0005434600348	18604	Economy	23200.00
0005434600427	18604	Economy	23200.00
0005433531242	18604	Economy	23200.00
0005435326676	18604	Economy	23200.00
0005434600503	18604	Economy	23200.00
0005433531234	18604	Economy	23200.00
0005434600349	18604	Economy	23200.00
0005434600429	18604	Economy	23200.00
0005434600432	18604	Economy	23200.00
0005434600483	18604	Economy	23200.00
0005434600410	18604	Economy	23200.00
0005434600475	18604	Economy	23200.00
0005434600465	18604	Economy	23200.00
0005433531239	18604	Economy	23200.00
0005435326667	18604	Economy	23200.00
0005435326673	18604	Economy	23200.00
0005434600422	18604	Economy	23200.00
0005434600484	18604	Economy	23200.00
0005434600447	18604	Economy	23200.00
0005434600577	18604	Economy	23200.00
0005434550907	10569	Business	9100.00
0005434550928	10569	Business	9100.00
0005433180688	10569	Business	9100.00
0005433180687	10569	Business	9100.00
0005434550885	10569	Business	9100.00
0005434550922	10569	Business	9100.00
0005434550876	10569	Business	9100.00
0005434550902	10569	Business	9100.00
0005434558219	10569	Business	9100.00
0005434550903	10569	Business	9100.00
0005434558225	10569	Economy	3000.00
0005434550905	10569	Economy	3000.00
0005433180700	10569	Economy	3000.00
0005433180762	10569	Economy	3000.00
0005434550910	10569	Economy	3000.00
0005434554052	10569	Economy	3000.00
0005434554053	10569	Economy	3000.00
0005434550890	10569	Economy	3000.00
0005433180697	10569	Economy	3000.00
0005434558222	10569	Economy	3300.00
0005434550923	10569	Economy	3300.00
0005434554051	10569	Economy	3300.00
0005433180767	10569	Economy	3300.00
0005433180699	10569	Economy	3000.00
0005434558223	10569	Economy	3000.00
0005433180689	10569	Economy	3000.00
0005434550929	10569	Economy	3000.00
0005434550918	10569	Economy	3000.00
0005434550909	10569	Economy	3000.00
0005434550878	10569	Economy	3000.00
0005434550926	10569	Economy	3000.00
0005433180754	10569	Economy	3000.00
0005434550901	10569	Economy	3000.00
0005434550898	10569	Economy	3000.00
0005434550916	10569	Economy	3000.00
0005434550892	10569	Economy	3000.00
0005434550884	10569	Economy	3000.00
0005433180696	10569	Economy	3000.00
0005434550919	10569	Economy	3000.00
0005434550917	10569	Economy	3000.00
0005434550886	10569	Economy	3000.00
0005434550900	10569	Economy	3000.00
0005434550896	10569	Economy	3000.00
0005434550913	10569	Economy	3000.00
0005434550925	10569	Economy	3000.00
0005433180725	10569	Economy	3000.00
0005434550879	10569	Economy	3000.00
0005434550893	10569	Economy	3000.00
0005434550930	10569	Economy	3000.00
0005434550877	10569	Economy	3000.00
0005434550914	10569	Economy	3000.00
0005434550927	10569	Economy	3000.00
0005434550895	10569	Economy	3000.00
0005434550881	10569	Economy	3000.00
0005434550883	10569	Economy	3000.00
0005434558220	10569	Economy	3000.00
0005434550911	10569	Economy	3000.00
0005434550882	10569	Economy	3000.00
0005433180770	10569	Economy	3000.00
0005434550897	10569	Economy	3000.00
0005433180698	10569	Economy	3000.00
0005434550894	10569	Economy	3000.00
0005434550889	10569	Economy	3000.00
0005433180830	10569	Economy	3000.00
0005434550924	10569	Economy	3000.00
0005434550888	10569	Economy	3000.00
0005434550908	10569	Economy	3000.00
0005434550920	10569	Economy	3000.00
0005433180763	10569	Economy	3000.00
0005434558226	10569	Economy	3000.00
0005434554054	10569	Economy	3000.00
0005434550899	10569	Economy	3000.00
0005434550912	10569	Economy	3000.00
0005434550904	10569	Economy	3000.00
0005433180798	10569	Economy	3000.00
0005434550887	10569	Economy	3000.00
0005433180724	10569	Economy	3000.00
0005434550915	10569	Economy	3000.00
0005434550891	10569	Economy	3000.00
0005434550880	10569	Economy	3000.00
0005433180736	10569	Economy	3000.00
0005433180737	10569	Economy	3000.00
0005434550931	10569	Economy	3000.00
0005434550906	10569	Economy	3000.00
0005434550921	10569	Economy	3000.00
0005434558221	10569	Economy	3000.00
0005433180717	10569	Economy	3000.00
0005434558224	10569	Economy	3000.00
0005433180958	27767	Business	9100.00
0005433180959	27767	Business	9100.00
0005433180984	27767	Business	9100.00
0005433180976	27767	Economy	3000.00
0005433180964	27767	Economy	3000.00
0005433180979	27767	Economy	3000.00
0005433180975	27767	Economy	3300.00
0005433180972	27767	Economy	3000.00
0005433180978	27767	Economy	3000.00
0005433180982	27767	Economy	3000.00
0005433180970	27767	Economy	3000.00
0005433180962	27767	Economy	3000.00
0005433180974	27767	Economy	3000.00
0005433180969	27767	Economy	3000.00
0005433180961	27767	Economy	3000.00
0005433180967	27767	Economy	3000.00
0005433180965	27767	Economy	3000.00
0005433180973	27767	Economy	3000.00
0005433180980	27767	Economy	3000.00
0005433180977	27767	Economy	3000.00
0005433180960	27767	Economy	3000.00
0005433180963	27767	Economy	3000.00
0005433180966	27767	Economy	3000.00
0005433180968	27767	Economy	3000.00
0005433180983	27767	Economy	3000.00
0005433180971	27767	Economy	3000.00
0005433180981	27767	Economy	3000.00
0005434550549	27768	Business	9100.00
0005434550567	27768	Business	9100.00
0005434550316	27768	Business	9100.00
0005434558156	27768	Business	9100.00
0005434550502	27768	Business	9100.00
0005434554041	27768	Business	9100.00
0005434550588	27768	Business	9100.00
0005434550300	27768	Business	9100.00
0005434550504	27768	Business	9100.00
0005434550308	27768	Business	9100.00
0005434550322	27768	Economy	3000.00
0005434550387	27768	Economy	3000.00
0005434550306	27768	Economy	3000.00
0005434558165	27768	Economy	3000.00
0005434550583	27768	Economy	3000.00
0005434550375	27768	Economy	3000.00
0005434550444	27768	Economy	3000.00
0005434550573	27768	Economy	3000.00
0005434558159	27768	Economy	3300.00
0005434550576	27768	Economy	3300.00
0005434550376	27768	Economy	3300.00
0005434558158	27768	Economy	3300.00
0005434550803	27768	Economy	3000.00
0005434550505	27768	Economy	3000.00
0005434550570	27768	Economy	3000.00
0005434558164	27768	Economy	3000.00
0005434550299	27768	Economy	3000.00
0005434550461	27768	Economy	3000.00
0005434550374	27768	Economy	3000.00
0005434550380	27768	Economy	3000.00
0005434550471	27768	Economy	3000.00
0005434550330	27768	Economy	3000.00
0005434550439	27768	Economy	3000.00
0005434550598	27768	Economy	3000.00
0005434550451	27768	Economy	3000.00
0005434550599	27768	Economy	3000.00
0005434550470	27768	Economy	3000.00
0005434550568	27768	Economy	3000.00
0005434558157	27768	Economy	3000.00
0005434550802	27768	Economy	3000.00
0005434550589	27768	Economy	3000.00
0005434550412	27768	Economy	3000.00
0005434550660	27768	Economy	3000.00
0005434550472	27768	Economy	3000.00
0005434558155	27768	Economy	3000.00
0005434550264	27768	Economy	3000.00
0005434550637	27768	Economy	3000.00
0005434558139	27768	Economy	3000.00
0005434550603	27768	Economy	3000.00
0005434550438	27768	Economy	3000.00
0005434550314	27768	Economy	3000.00
0005434550514	27768	Economy	3000.00
0005434550469	27768	Economy	3000.00
0005434550309	27768	Economy	3000.00
0005434550681	27768	Economy	3000.00
0005434550638	27768	Economy	3000.00
0005434550315	27768	Economy	3000.00
0005434550550	27768	Economy	3000.00
0005434550468	27768	Economy	3000.00
0005434550329	27768	Economy	3000.00
0005434550321	27768	Economy	3000.00
0005434550462	27768	Economy	3000.00
0005434550445	27768	Economy	3000.00
0005433459198	6142	Economy	11700.00
0005433459197	6142	Economy	11700.00
0005435254435	6142	Economy	11700.00
0005433459195	6142	Economy	11700.00
0005433459196	6142	Economy	11700.00
0005435254434	6142	Economy	11700.00
0005435254436	6142	Economy	11700.00
0005435254462	19300	Economy	11700.00
0005433459181	19300	Economy	11700.00
0005433459180	19300	Economy	11700.00
0005435437727	6720	Business	51100.00
0005435681911	6720	Business	51100.00
0005435437712	6720	Business	51100.00
0005435681918	6720	Business	51100.00
0005435437743	6720	Business	51100.00
0005435681923	6720	Business	51100.00
0005435437741	6720	Business	51100.00
0005435437767	6720	Business	51100.00
0005435437682	6720	Business	51100.00
0005435437683	6720	Business	51100.00
0005435681895	6720	Business	51100.00
0005435681899	6720	Economy	17000.00
0005435681915	6720	Economy	17000.00
0005435437729	6720	Economy	17000.00
0005435681917	6720	Economy	17000.00
0005434828651	6720	Economy	17000.00
0005435681898	6720	Economy	17000.00
0005435437696	6720	Economy	17000.00
0005435681912	6720	Economy	17000.00
0005435681932	6720	Economy	17000.00
0005435437631	6720	Economy	17000.00
0005435437728	6720	Economy	18700.00
0005435437634	6720	Economy	18700.00
0005435681922	6720	Economy	18700.00
0005435681920	6720	Economy	18700.00
0005435681926	6720	Economy	17000.00
0005432136142	6720	Economy	17000.00
0005435681929	6720	Economy	17000.00
0005432533243	6720	Economy	17000.00
0005435220293	6720	Economy	17000.00
0005435681907	6720	Economy	17000.00
0005435681924	6720	Economy	17000.00
0005435437630	6720	Economy	17000.00
0005435681905	6720	Economy	17000.00
0005435437701	6720	Economy	17000.00
0005435681909	6720	Economy	17000.00
0005435437572	6720	Economy	17000.00
0005435661914	6720	Economy	17000.00
0005435681906	6720	Economy	17000.00
0005435681921	6720	Economy	17000.00
0005435681902	6720	Economy	17000.00
0005435661913	6720	Economy	17000.00
0005435681925	6720	Economy	17000.00
0005435681892	6720	Economy	17000.00
0005432136144	6720	Economy	17000.00
0005435220291	6720	Economy	17000.00
0005435681897	6720	Economy	17000.00
0005435681894	6720	Economy	17000.00
0005435437633	6720	Economy	17000.00
0005435437641	6720	Economy	17000.00
0005435681893	6720	Economy	17000.00
0005435437670	6720	Economy	17000.00
0005435437687	6720	Economy	17000.00
0005435681904	6720	Economy	17000.00
0005435220289	6720	Economy	17000.00
0005432136143	6720	Economy	17000.00
0005435681931	6720	Economy	17000.00
0005435220294	6720	Economy	17000.00
0005435681891	6720	Economy	17000.00
0005435437607	6720	Economy	17000.00
0005435681901	6720	Economy	17000.00
0005435681930	6720	Economy	17000.00
0005435437686	6720	Economy	17000.00
0005435437769	6720	Economy	17000.00
0005435437655	6720	Economy	17000.00
0005432533244	6720	Economy	17000.00
0005435437768	6720	Economy	17000.00
0005432136141	6720	Economy	17000.00
0005434828650	6720	Economy	17000.00
0005432136140	6720	Economy	17000.00
0005435437658	6720	Economy	17000.00
0005435681903	6720	Economy	17000.00
0005435681928	6720	Economy	17000.00
0005435437632	6720	Economy	17000.00
0005435681914	6720	Economy	17000.00
0005435681927	6720	Economy	17000.00
0005435220290	6720	Economy	17000.00
0005435681916	6720	Economy	17000.00
0005435437656	6720	Economy	17000.00
0005435681933	6720	Economy	17000.00
0005435437700	6720	Economy	17000.00
0005435630948	6720	Economy	17000.00
0005435630949	6720	Economy	17000.00
0005435437702	6720	Economy	17000.00
0005435681900	6720	Economy	17000.00
0005435437642	6720	Economy	17000.00
0005435681913	6720	Economy	17000.00
0005435681910	6720	Economy	17000.00
0005434828649	6720	Economy	17000.00
0005435437742	6720	Economy	17000.00
0005435681908	6720	Economy	17000.00
0005435437730	6720	Economy	17000.00
0005435681896	6720	Economy	17000.00
0005435681919	6720	Economy	17000.00
0005435437835	24571	Business	51100.00
0005435681591	24571	Business	51100.00
0005435681419	24571	Business	51100.00
0005435681423	24571	Business	51100.00
0005435437829	24571	Business	51100.00
0005435220306	24571	Business	51100.00
0005435681515	24571	Business	51100.00
0005435681485	24571	Business	51100.00
0005435681590	24571	Business	51100.00
0005435630924	24571	Business	51100.00
0005435681658	24571	Business	51100.00
0005435681547	24571	Business	51100.00
0005435681507	24571	Economy	17000.00
0005435437846	24571	Economy	17000.00
0005435220307	24571	Economy	17000.00
0005435681552	24571	Economy	17000.00
0005435437832	24571	Economy	17000.00
0005435681659	24571	Economy	17000.00
0005435220309	24571	Economy	17000.00
0005434828684	24571	Economy	17000.00
0005434828683	24571	Economy	17000.00
0005435437844	24571	Economy	17000.00
0005435681523	24571	Economy	18700.00
0005435437845	24571	Economy	18700.00
0005435681606	24571	Economy	18700.00
0005435681442	24571	Economy	18700.00
0005435437825	24571	Economy	17000.00
0005432533276	24571	Economy	17000.00
0005435681544	24571	Economy	17000.00
0005435681443	24571	Economy	17000.00
0005435437840	24571	Economy	17000.00
0005435437828	24571	Economy	17000.00
0005435437841	24571	Economy	17000.00
0005435437824	24571	Economy	17000.00
0005435681506	24571	Economy	17000.00
0005432305737	24571	Economy	17000.00
0005434828682	24571	Economy	17000.00
0005435681514	24571	Economy	17000.00
0005432533279	24571	Economy	17000.00
0005435220489	24571	Economy	17000.00
0005435681387	24571	Economy	17000.00
0005435681662	24571	Economy	17000.00
0005435681607	24571	Economy	17000.00
0005435437831	24571	Economy	17000.00
0005435437843	24571	Economy	17000.00
0005435437847	24571	Economy	17000.00
0005435437839	24571	Economy	17000.00
0005435437826	24571	Economy	17000.00
0005435681564	24571	Economy	17000.00
0005432305736	24571	Economy	17000.00
0005435630925	24571	Economy	17000.00
0005435681422	24571	Economy	17000.00
0005432533277	24571	Economy	17000.00
0005435219190	24571	Economy	17000.00
0005435681656	24571	Economy	17000.00
0005435219188	24571	Economy	17000.00
0005435437827	24571	Economy	17000.00
0005435681633	24571	Economy	17000.00
0005435681517	24571	Economy	17000.00
0005435681484	24571	Economy	17000.00
0005435437834	24571	Economy	17000.00
0005435220305	24571	Economy	17000.00
0005435661885	24571	Economy	17000.00
0005435437830	24571	Economy	17000.00
0005435681657	24571	Economy	17000.00
0005435681605	24571	Economy	17000.00
0005435437837	24571	Economy	17000.00
0005435630934	24571	Economy	17000.00
0005435219187	24571	Economy	17000.00
0005435437836	24571	Economy	17000.00
0005435661890	24571	Economy	17000.00
0005435437838	24571	Economy	17000.00
0005435220310	24571	Economy	17000.00
0005432533275	24571	Economy	17000.00
0005435437842	24571	Economy	17000.00
0005432305735	24571	Economy	17000.00
0005432533278	24571	Economy	17000.00
0005435681508	24571	Economy	17000.00
0005435630937	24571	Economy	17000.00
0005435219191	24571	Economy	17000.00
0005435681486	24571	Economy	17000.00
0005435681646	24571	Economy	17000.00
0005435220308	24571	Economy	17000.00
0005435219189	24571	Economy	17000.00
0005435681549	24571	Economy	17000.00
0005435681518	24571	Economy	17000.00
0005435437833	24571	Economy	17000.00
0005435681524	24571	Economy	17000.00
0005435126124	11523	Business	26400.00
0005435126117	11523	Business	26400.00
0005435126147	11523	Business	26400.00
0005435126116	11523	Business	26400.00
0005435105963	11523	Business	26400.00
0005435126132	11523	Business	26400.00
0005435126130	11523	Business	26400.00
0005435126136	11523	Economy	8800.00
0005435126128	11523	Economy	8800.00
0005435126118	11523	Economy	8800.00
0005435126133	11523	Economy	8800.00
0005435126145	11523	Economy	8800.00
0005435126111	11523	Economy	8800.00
0005435558055	11523	Economy	9700.00
0005435126134	11523	Economy	9700.00
0005435558052	11523	Economy	9700.00
0005435558057	11523	Economy	8800.00
0005435126112	11523	Economy	8800.00
0005435126125	11523	Economy	8800.00
0005435126107	11523	Economy	8800.00
0005435126120	11523	Economy	8800.00
0005435126138	11523	Economy	8800.00
0005435126119	11523	Economy	8800.00
0005435126121	11523	Economy	8800.00
0005435126115	11523	Economy	8800.00
0005435558058	11523	Economy	8800.00
0005435105964	11523	Economy	8800.00
0005435126114	11523	Economy	8800.00
0005435126109	11523	Economy	8800.00
0005435126113	11523	Economy	8800.00
0005435126140	11523	Economy	8800.00
0005435126146	11523	Economy	8800.00
0005435126143	11523	Economy	8800.00
0005435126106	11523	Economy	8800.00
0005435126110	11523	Economy	8800.00
0005435126144	11523	Economy	8800.00
0005435126126	11523	Economy	8800.00
0005435126135	11523	Economy	8800.00
0005435126123	11523	Economy	8800.00
0005435126122	11523	Economy	8800.00
0005435126131	11523	Economy	8800.00
0005435558053	11523	Economy	8800.00
0005435126142	11523	Economy	8800.00
0005435126137	11523	Economy	8800.00
0005435126127	11523	Economy	8800.00
0005435126129	11523	Economy	8800.00
0005435126139	11523	Economy	8800.00
0005435126141	11523	Economy	8800.00
0005435126148	11523	Economy	8800.00
0005435126108	11523	Economy	8800.00
0005435105962	11523	Economy	8800.00
0005435098526	31906	Business	26400.00
0005435125876	31906	Business	26400.00
0005435125819	31906	Business	26400.00
0005435098525	31906	Business	26400.00
0005435125866	31906	Economy	8800.00
0005435125778	31906	Economy	8800.00
0005435125771	31906	Economy	8800.00
0005435105933	31906	Economy	8800.00
0005435125776	31906	Economy	9700.00
0005435125670	31906	Economy	9700.00
0005435125814	31906	Economy	8800.00
0005435098523	31906	Economy	8800.00
0005435125774	31906	Economy	8800.00
0005435125831	31906	Economy	8800.00
0005435105935	31906	Economy	8800.00
0005435125807	31906	Economy	8800.00
0005435125828	31906	Economy	8800.00
0005435125772	31906	Economy	8800.00
0005435125798	31906	Economy	8800.00
0005435125773	31906	Economy	8800.00
0005435125750	31906	Economy	8800.00
0005435558072	31906	Economy	8800.00
0005435126053	31906	Economy	8800.00
0005435125808	31906	Economy	8800.00
0005435125875	31906	Economy	8800.00
0005435125787	31906	Economy	8800.00
0005435125830	31906	Economy	8800.00
0005435125935	31906	Economy	8800.00
0005435125820	31906	Economy	8800.00
0005435558073	31906	Economy	8800.00
0005435126054	31906	Economy	8800.00
0005435125775	31906	Economy	8800.00
0005435125777	31906	Economy	8800.00
0005435125867	31906	Economy	8800.00
0005435125818	31906	Economy	8800.00
0005435105936	31906	Economy	8800.00
0005435125827	31906	Economy	8800.00
0005435125765	31906	Economy	8800.00
0005435125939	31906	Economy	8800.00
0005435125715	31906	Economy	8800.00
0005435125934	31906	Economy	8800.00
0005435125681	31906	Economy	8800.00
0005435098524	31906	Economy	8800.00
0005433397824	13540	Business	36600.00
0005433397794	13540	Business	36600.00
0005433397777	13540	Business	36600.00
0005433397812	13540	Business	36600.00
0005435732139	13540	Business	36600.00
0005433397793	13540	Business	36600.00
0005435732125	13540	Business	36600.00
0005433397782	13540	Business	36600.00
0005433397798	13540	Business	36600.00
0005435732135	13540	Economy	12200.00
0005433397804	13540	Economy	12200.00
0005433397813	13540	Economy	12200.00
0005435732195	13540	Economy	12200.00
0005433397802	13540	Economy	12200.00
0005435732191	13540	Economy	12200.00
0005435732179	13540	Economy	12200.00
0005433397784	13540	Economy	12200.00
0005433397799	13540	Economy	13400.00
0005435732157	13540	Economy	13400.00
0005433397796	13540	Economy	12200.00
0005433397809	13540	Economy	12200.00
0005433397808	13540	Economy	12200.00
0005433397783	13540	Economy	12200.00
0005433397823	13540	Economy	12200.00
0005433397820	13540	Economy	12200.00
0005433397780	13540	Economy	12200.00
0005433397775	13540	Economy	12200.00
0005433397801	13540	Economy	12200.00
0005433397814	13540	Economy	12200.00
0005433397821	13540	Economy	12200.00
0005433397822	13540	Economy	12200.00
0005433397806	13540	Economy	12200.00
0005433397816	13540	Economy	12200.00
0005433397792	13540	Economy	12200.00
0005435732134	13540	Economy	12200.00
0005433397795	13540	Economy	12200.00
0005433397791	13540	Economy	12200.00
0005435732182	13540	Economy	12200.00
0005435732145	13540	Economy	12200.00
0005433397811	13540	Economy	12200.00
0005433397781	13540	Economy	12200.00
0005433397818	13540	Economy	12200.00
0005433397810	13540	Economy	12200.00
0005433397819	13540	Economy	12200.00
0005435732181	13540	Economy	12200.00
0005433397786	13540	Economy	12200.00
0005433397825	13540	Economy	12200.00
0005433397790	13540	Economy	12200.00
0005433397805	13540	Economy	12200.00
0005433397807	13540	Economy	12200.00
0005435732156	13540	Economy	12200.00
0005435732188	13540	Economy	12200.00
0005433397803	13540	Economy	12200.00
0005433397776	13540	Economy	12200.00
0005433397815	13540	Economy	12200.00
0005433397779	13540	Economy	12200.00
0005433397778	13540	Economy	12200.00
0005433397787	13540	Economy	12200.00
0005433397785	13540	Economy	12200.00
0005433397789	13540	Economy	12200.00
0005433397797	13540	Economy	12200.00
0005433397788	13540	Economy	12200.00
0005433397800	13540	Economy	12200.00
0005433397817	13540	Economy	12200.00
0005433397530	19384	Business	36600.00
0005433397319	19384	Business	36600.00
0005433397448	19384	Business	36600.00
0005433397350	19384	Business	36600.00
0005433397357	19384	Business	36600.00
0005433397354	19384	Business	36600.00
0005433397387	19384	Business	36600.00
0005433397398	19384	Business	36600.00
0005435732277	19384	Economy	12200.00
0005433397375	19384	Economy	12200.00
0005433397302	19384	Economy	12200.00
0005433397239	19384	Economy	12200.00
0005433397457	19384	Economy	12200.00
0005433397208	19384	Economy	12200.00
0005433397352	19384	Economy	12200.00
0005433397363	19384	Economy	13400.00
0005435732281	19384	Economy	13400.00
0005433397218	19384	Economy	12200.00
0005433397431	19384	Economy	12200.00
0005433397408	19384	Economy	12200.00
0005433397342	19384	Economy	12200.00
0005432297264	19384	Economy	12200.00
0005433397405	19384	Economy	12200.00
0005433397467	19384	Economy	12200.00
0005433397552	19384	Economy	12200.00
0005433397367	19384	Economy	12200.00
0005433397388	19384	Economy	12200.00
0005435732279	19384	Economy	12200.00
0005433397285	19384	Economy	12200.00
0005433397533	19384	Economy	12200.00
0005432297263	19384	Economy	12200.00
0005433397508	19384	Economy	12200.00
0005433397353	19384	Economy	12200.00
0005433397425	19384	Economy	12200.00
0005433397660	19384	Economy	12200.00
0005433397332	19384	Economy	12200.00
0005432297262	19384	Economy	12200.00
0005433397531	19384	Economy	12200.00
0005433397356	19384	Economy	12200.00
0005435732278	19384	Economy	12200.00
0005433397658	19384	Economy	12200.00
0005433397289	19384	Economy	12200.00
0005433397659	19384	Economy	12200.00
0005433397563	19384	Economy	12200.00
0005433397199	19384	Economy	12200.00
0005433397179	19384	Economy	12200.00
0005433397360	19384	Economy	12200.00
0005433397564	19384	Economy	12200.00
0005433397286	19384	Economy	12200.00
0005433397551	19384	Economy	12200.00
0005433397374	19384	Economy	12200.00
0005433397572	19384	Economy	12200.00
0005433397523	19384	Economy	12200.00
0005435732280	19384	Economy	12200.00
0005433397430	19384	Economy	12200.00
0005433397390	19384	Economy	12200.00
0005433397207	19384	Economy	12200.00
0005433397362	19384	Economy	12200.00
0005433397407	19384	Economy	12200.00
0005433397236	19384	Economy	12200.00
0005433397351	19384	Economy	12200.00
0005433397331	19384	Economy	12200.00
0005433397534	19384	Economy	12200.00
0005435925207	13159	Business	11300.00
0005435068326	13159	Business	11300.00
0005435068347	13159	Business	11300.00
0005435068378	13159	Business	11300.00
0005435068175	13159	Business	11300.00
0005435068417	13159	Business	11300.00
0005435068279	13159	Business	11300.00
0005435068481	13159	Business	11300.00
0005435068324	13159	Business	11300.00
0005435068327	13159	Business	11300.00
0005435068319	13159	Business	11300.00
0005435925216	13159	Economy	3800.00
0005435068278	13159	Economy	3800.00
0005435068372	13159	Economy	3800.00
0005435068247	13159	Economy	3800.00
0005435068328	13159	Economy	3800.00
0005435068198	13159	Economy	3800.00
0005435068300	13159	Economy	3800.00
0005435068280	13159	Economy	3800.00
0005435068196	13159	Economy	4100.00
0005435068242	13159	Economy	4100.00
0005435068433	13159	Economy	4100.00
0005435068501	13159	Economy	4100.00
0005435068400	13159	Economy	4100.00
0005435925206	13159	Economy	3800.00
0005435925217	13159	Economy	3800.00
0005435925213	13159	Economy	3800.00
0005435068432	13159	Economy	3800.00
0005435068482	13159	Economy	3800.00
0005435925215	13159	Economy	3800.00
0005435068195	13159	Economy	3800.00
0005435068380	13159	Economy	3800.00
0005435068246	13159	Economy	3800.00
0005435068337	13159	Economy	3800.00
0005435068206	13159	Economy	3800.00
0005435068168	13159	Economy	3800.00
0005435925205	13159	Economy	3800.00
0005435068451	13159	Economy	3800.00
0005435068313	13159	Economy	3800.00
0005435925211	13159	Economy	3800.00
0005435068475	13159	Economy	3800.00
0005435068412	13159	Economy	3800.00
0005435068205	13159	Economy	3800.00
0005435068287	13159	Economy	3800.00
0005435068393	13159	Economy	3800.00
0005435925218	13159	Economy	3800.00
0005435925208	13159	Economy	3800.00
0005435068283	13159	Economy	3800.00
0005435068318	13159	Economy	3800.00
0005435925209	13159	Economy	3800.00
0005435068476	13159	Economy	3800.00
0005435068416	13159	Economy	3800.00
0005435068452	13159	Economy	3800.00
0005435068243	13159	Economy	3800.00
0005435925214	13159	Economy	3800.00
0005435068227	13159	Economy	3800.00
0005435068293	13159	Economy	3800.00
0005435925210	13159	Economy	3800.00
0005435068282	13159	Economy	3800.00
0005435068250	13159	Economy	3800.00
0005435925212	13159	Economy	3800.00
0005435068197	13159	Economy	3800.00
0005435068377	13159	Economy	3800.00
0005435068439	13159	Economy	3800.00
0005435068384	13159	Economy	3800.00
0005435925204	13159	Economy	3800.00
0005435068500	13159	Economy	3800.00
0005435068245	13159	Economy	3800.00
0005435068274	13159	Economy	3800.00
0005435068352	13159	Economy	3800.00
0005435068388	13159	Economy	3800.00
0005435925085	15473	Business	11300.00
0005435068783	15473	Business	11300.00
0005435925051	15473	Business	11300.00
0005435068770	15473	Business	11300.00
0005435068768	15473	Business	11300.00
0005435068752	15473	Business	11300.00
0005435068741	15473	Business	11300.00
0005435925075	15473	Business	11300.00
0005435068763	15473	Business	11300.00
0005435068755	15473	Business	11300.00
0005435068756	15473	Economy	3800.00
0005435068787	15473	Economy	3800.00
0005435068788	15473	Economy	3800.00
0005435068750	15473	Economy	3800.00
0005435068758	15473	Economy	3800.00
0005435068785	15473	Economy	4100.00
0005435068767	15473	Economy	3800.00
0005435068782	15473	Economy	3800.00
0005435068778	15473	Economy	3800.00
0005435925115	15473	Economy	3800.00
0005435068773	15473	Economy	3800.00
0005435068759	15473	Economy	3800.00
0005435068777	15473	Economy	3800.00
0005435068754	15473	Economy	3800.00
0005435068774	15473	Economy	3800.00
0005435068762	15473	Economy	3800.00
0005435925110	15473	Economy	3800.00
0005435068780	15473	Economy	3800.00
0005435068781	15473	Economy	3800.00
0005435925069	15473	Economy	3800.00
0005435068789	15473	Economy	3800.00
0005435068748	15473	Economy	3800.00
0005435068760	15473	Economy	3800.00
0005435068775	15473	Economy	3800.00
0005435068746	15473	Economy	3800.00
0005435068751	15473	Economy	3800.00
0005435925120	15473	Economy	3800.00
0005435068765	15473	Economy	3800.00
0005435068753	15473	Economy	3800.00
0005435925072	15473	Economy	3800.00
0005435068790	15473	Economy	3800.00
0005435068761	15473	Economy	3800.00
0005435068743	15473	Economy	3800.00
0005435068757	15473	Economy	3800.00
0005435925092	15473	Economy	3800.00
0005435068771	15473	Economy	3800.00
0005435068745	15473	Economy	3800.00
0005435068779	15473	Economy	3800.00
0005435068776	15473	Economy	3800.00
0005435068749	15473	Economy	3800.00
0005435068793	15473	Economy	3800.00
0005435925111	15473	Economy	3800.00
0005435068784	15473	Economy	3800.00
0005435925119	15473	Economy	3800.00
0005435068772	15473	Economy	3800.00
0005435925098	15473	Economy	3800.00
0005435925046	15473	Economy	3800.00
0005435068764	15473	Economy	3800.00
0005435068791	15473	Economy	3800.00
0005435068786	15473	Economy	3800.00
0005435068792	15473	Economy	3800.00
0005435068747	15473	Economy	3800.00
0005435925052	15473	Economy	3800.00
0005435068769	15473	Economy	3800.00
0005435068742	15473	Economy	3800.00
0005435068744	15473	Economy	3800.00
0005435068766	15473	Economy	3800.00
0005434214295	10700	Business	61300.00
0005434755863	10700	Business	61300.00
0005434214289	10700	Business	61300.00
0005434755735	10700	Business	61300.00
0005434755840	10700	Business	61300.00
0005434214281	10700	Business	61300.00
0005434214282	10700	Business	61300.00
0005434755856	10700	Business	61300.00
0005434214274	10700	Business	61300.00
0005434755721	10700	Business	61300.00
0005434755988	10700	Business	61300.00
0005434214276	10700	Business	61300.00
0005434214298	10700	Economy	20400.00
0005434214316	10700	Economy	20400.00
0005434214300	10700	Economy	20400.00
0005434214309	10700	Economy	20400.00
0005434755753	10700	Economy	20400.00
0005434214312	10700	Economy	20400.00
0005434214287	10700	Economy	20400.00
0005434755890	10700	Economy	20400.00
0005434755791	10700	Economy	20400.00
0005434214315	10700	Economy	20400.00
0005434214275	10700	Economy	22500.00
0005434214284	10700	Economy	22500.00
0005434755959	10700	Economy	22500.00
0005434214310	10700	Economy	22500.00
0005434214273	10700	Economy	22500.00
0005434755864	10700	Economy	20400.00
0005434214301	10700	Economy	20400.00
0005434755780	10700	Economy	20400.00
0005434214283	10700	Economy	20400.00
0005434214278	10700	Economy	20400.00
0005434755887	10700	Economy	20400.00
0005434214314	10700	Economy	20400.00
0005434214302	10700	Economy	20400.00
0005434214272	10700	Economy	20400.00
0005434755919	10700	Economy	20400.00
0005434214288	10700	Economy	20400.00
0005434755922	10700	Economy	20400.00
0005434755720	10700	Economy	20400.00
0005434755831	10700	Economy	20400.00
0005434214285	10700	Economy	20400.00
0005434214280	10700	Economy	20400.00
0005434755734	10700	Economy	20400.00
0005434755905	10700	Economy	20400.00
0005434214293	10700	Economy	20400.00
0005434214279	10700	Economy	20400.00
0005434214306	10700	Economy	20400.00
0005434755710	10700	Economy	20400.00
0005434755830	10700	Economy	20400.00
0005434755793	10700	Economy	20400.00
0005434214313	10700	Economy	20400.00
0005434755968	10700	Economy	20400.00
0005434755806	10700	Economy	20400.00
0005434755906	10700	Economy	20400.00
0005434755825	10700	Economy	20400.00
0005434214296	10700	Economy	20400.00
0005434214297	10700	Economy	20400.00
0005434755794	10700	Economy	20400.00
0005434755954	10700	Economy	20400.00
0005434214305	10700	Economy	20400.00
0005434755718	10700	Economy	20400.00
0005434214299	10700	Economy	20400.00
0005434755779	10700	Economy	20400.00
0005434214294	10700	Economy	20400.00
0005434755802	10700	Economy	20400.00
0005434755850	10700	Economy	20400.00
0005434755837	10700	Economy	20400.00
0005434755752	10700	Economy	20400.00
0005434214303	10700	Economy	20400.00
0005434755967	10700	Economy	20400.00
0005434755942	10700	Economy	20400.00
0005434755803	10700	Economy	20400.00
0005434755807	10700	Economy	20400.00
0005434214286	10700	Economy	20400.00
0005434755960	10700	Economy	20400.00
0005434214290	10700	Economy	20400.00
0005434214308	10700	Economy	20400.00
0005434755857	10700	Economy	20400.00
0005434214311	10700	Economy	20400.00
0005434755852	10700	Economy	20400.00
0005434214269	10700	Economy	20400.00
0005434755891	10700	Economy	20400.00
0005434755767	10700	Economy	20400.00
0005434214291	10700	Economy	20400.00
0005434214292	10700	Economy	20400.00
0005434214271	10700	Economy	20400.00
0005434755849	10700	Economy	20400.00
0005434755749	10700	Economy	20400.00
0005434214277	10700	Economy	20400.00
0005434214270	10700	Economy	20400.00
0005434214307	10700	Economy	20400.00
0005434214304	10700	Economy	20400.00
0005434755958	10700	Economy	20400.00
0005434755824	10700	Economy	20400.00
0005434213952	28660	Business	61300.00
0005434756189	28660	Business	61300.00
0005434213870	28660	Business	61300.00
0005434213805	28660	Business	61300.00
0005434756187	28660	Business	61300.00
0005434213921	28660	Business	61300.00
0005434756201	28660	Business	61300.00
0005434756195	28660	Business	61300.00
0005434756169	28660	Business	61300.00
0005434213736	28660	Economy	20400.00
0005434213871	28660	Economy	20400.00
0005434213827	28660	Economy	20400.00
0005434756178	28660	Economy	20400.00
0005434756193	28660	Economy	20400.00
0005434213785	28660	Economy	20400.00
0005434213751	28660	Economy	20400.00
0005434213840	28660	Economy	20400.00
0005434213735	28660	Economy	20400.00
0005434213721	28660	Economy	22500.00
0005434213728	28660	Economy	22500.00
0005434213950	28660	Economy	22500.00
0005434213925	28660	Economy	22500.00
0005434756196	28660	Economy	20400.00
0005434756197	28660	Economy	20400.00
0005434213953	28660	Economy	20400.00
0005434756180	28660	Economy	20400.00
0005434756200	28660	Economy	20400.00
0005434213826	28660	Economy	20400.00
0005434213797	28660	Economy	20400.00
0005434756177	28660	Economy	20400.00
0005434213922	28660	Economy	20400.00
0005434756181	28660	Economy	20400.00
0005434756185	28660	Economy	20400.00
0005434213926	28660	Economy	20400.00
0005434214026	28660	Economy	20400.00
0005434756174	28660	Economy	20400.00
0005434213951	28660	Economy	20400.00
0005434213872	28660	Economy	20400.00
0005434756184	28660	Economy	20400.00
0005434213746	28660	Economy	20400.00
0005434213753	28660	Economy	20400.00
0005434756194	28660	Economy	20400.00
0005434213796	28660	Economy	20400.00
0005434756179	28660	Economy	20400.00
0005434213864	28660	Economy	20400.00
0005434213874	28660	Economy	20400.00
0005434756175	28660	Economy	20400.00
0005434756176	28660	Economy	20400.00
0005434756170	28660	Economy	20400.00
0005434213860	28660	Economy	20400.00
0005434213747	28660	Economy	20400.00
0005434213758	28660	Economy	20400.00
0005434756188	28660	Economy	20400.00
0005434213917	28660	Economy	20400.00
0005434213798	28660	Economy	20400.00
0005434213992	28660	Economy	20400.00
0005434213828	28660	Economy	20400.00
0005434756190	28660	Economy	20400.00
0005434756198	28660	Economy	20400.00
0005434756191	28660	Economy	20400.00
0005434756172	28660	Economy	20400.00
0005434756171	28660	Economy	20400.00
0005434756186	28660	Economy	20400.00
0005434756173	28660	Economy	20400.00
0005434213726	28660	Economy	20400.00
0005434756199	28660	Economy	20400.00
0005434213739	28660	Economy	20400.00
0005434756168	28660	Economy	20400.00
0005434213856	28660	Economy	20400.00
0005434213875	28660	Economy	20400.00
0005434213916	28660	Economy	20400.00
0005434213725	28660	Economy	20400.00
0005434756182	28660	Economy	20400.00
0005434213765	28660	Economy	20400.00
0005434213780	28660	Economy	20400.00
0005434756183	28660	Economy	20400.00
0005434213744	28660	Economy	20400.00
0005434213807	28660	Economy	20400.00
0005434213806	28660	Economy	20400.00
0005434756192	28660	Economy	20400.00
0005434214071	28660	Economy	20400.00
0005434213729	28660	Economy	20400.00
0005435006899	5482	Business	29500.00
0005435039447	5482	Business	29500.00
0005435006902	5482	Business	29500.00
0005435039437	5482	Business	29500.00
0005434229037	5482	Business	29500.00
0005435039426	5482	Business	29500.00
0005432125415	5482	Business	29500.00
0005435006897	5482	Business	29500.00
0005432125411	5482	Business	29500.00
0005435006915	5482	Business	29500.00
0005434229000	5482	Business	29500.00
0005435039425	5482	Business	29500.00
0005434228994	5482	Economy	9800.00
0005434229095	5482	Economy	9800.00
0005434229096	5482	Economy	9800.00
0005435006898	5482	Economy	9800.00
0005435039423	5482	Economy	9800.00
0005435039422	5482	Economy	9800.00
0005435039415	5482	Economy	9800.00
0005435006914	5482	Economy	9800.00
0005435039403	5482	Economy	9800.00
0005435006910	5482	Economy	9800.00
0005435039414	5482	Economy	9800.00
0005435039441	5482	Economy	9800.00
0005435006909	5482	Economy	9800.00
0005435039419	5482	Economy	9800.00
0005435006918	5482	Economy	9800.00
0005434229049	5482	Economy	9800.00
0005435006896	5482	Economy	9800.00
0005435039439	5482	Economy	9800.00
0005435039407	5482	Economy	9800.00
0005435039435	5482	Economy	9800.00
0005435039430	5482	Economy	9800.00
0005435039400	5482	Economy	9800.00
0005435039397	5482	Economy	9800.00
0005435039420	5482	Economy	9800.00
0005435006911	5482	Economy	9800.00
0005432125416	5482	Economy	9800.00
0005435039452	5482	Economy	9800.00
0005434229036	5482	Economy	9800.00
0005435006917	5482	Economy	9800.00
0005434228982	5482	Economy	9800.00
0005434229094	5482	Economy	9800.00
0005435039411	5482	Economy	9800.00
0005435006905	5482	Economy	9800.00
0005435039453	5482	Economy	9800.00
0005435039433	5482	Economy	9800.00
0005435039428	5482	Economy	9800.00
0005435039402	5482	Economy	9800.00
0005435039434	5482	Economy	9800.00
0005435039409	5482	Economy	10800.00
0005435039408	5482	Economy	10800.00
0005435039418	5482	Economy	10800.00
0005435006916	5482	Economy	10800.00
0005435039410	5482	Economy	10800.00
0005435039417	5482	Economy	9800.00
0005435006894	5482	Economy	10800.00
0005435006903	5482	Economy	9800.00
0005435039445	5482	Economy	9800.00
0005435006901	5482	Economy	9800.00
0005435006900	5482	Economy	9800.00
0005435039444	5482	Economy	9800.00
0005435039440	5482	Economy	9800.00
0005435039451	5482	Economy	9800.00
0005435039401	5482	Economy	9800.00
0005435039412	5482	Economy	9800.00
0005435039406	5482	Economy	9800.00
0005435042844	5482	Economy	9800.00
0005432125412	5482	Economy	9800.00
0005435039460	5482	Economy	9800.00
0005432125410	5482	Economy	9800.00
0005435039404	5482	Economy	9800.00
0005435039429	5482	Economy	9800.00
0005435039424	5482	Economy	9800.00
0005435039456	5482	Economy	9800.00
0005435039463	5482	Economy	9800.00
0005435039449	5482	Economy	9800.00
0005432125414	5482	Economy	9800.00
0005435039399	5482	Economy	9800.00
0005434229009	5482	Economy	9800.00
0005435006907	5482	Economy	9800.00
0005432125409	5482	Economy	9800.00
0005435042845	5482	Economy	9800.00
0005435039443	5482	Economy	9800.00
0005435039455	5482	Economy	9800.00
0005434229063	5482	Economy	9800.00
0005435039431	5482	Economy	9800.00
0005435039421	5482	Economy	9800.00
0005435039438	5482	Economy	9800.00
0005435043281	5482	Economy	9800.00
0005435039405	5482	Economy	9800.00
0005432125413	5482	Economy	9800.00
0005435006893	5482	Economy	9800.00
0005435042846	5482	Economy	9800.00
0005435006908	5482	Economy	9800.00
0005434229083	5482	Economy	9800.00
0005435039398	5482	Economy	9800.00
0005435039458	5482	Economy	9800.00
0005435039461	5482	Economy	9800.00
0005435039446	5482	Economy	9800.00
0005435039416	5482	Economy	9800.00
0005434229064	5482	Economy	9800.00
0005435006906	5482	Economy	9800.00
0005435006913	5482	Economy	9800.00
0005435039448	5482	Economy	9800.00
0005435039462	5482	Economy	9800.00
0005435039457	5482	Economy	9800.00
0005434229118	5482	Economy	9800.00
0005435006895	5482	Economy	9800.00
0005435006912	5482	Economy	9800.00
0005435039459	5482	Economy	9800.00
0005435039432	5482	Economy	9800.00
0005434229082	5482	Economy	9800.00
0005434229038	5482	Economy	9800.00
0005435039454	5482	Economy	9800.00
0005435042847	5482	Economy	9800.00
0005435039442	5482	Economy	9800.00
0005435006904	5482	Economy	9800.00
0005435039413	5482	Economy	9800.00
0005434229092	5482	Economy	9800.00
0005435039450	5482	Economy	9800.00
0005435039427	5482	Economy	9800.00
0005435039436	5482	Economy	9800.00
0005435038771	12963	Business	29500.00
0005435038940	12963	Business	29500.00
0005435006759	12963	Business	29500.00
0005435006653	12963	Business	29500.00
0005435006688	12963	Business	29500.00
0005435039031	12963	Business	29500.00
0005435038960	12963	Business	29500.00
0005434229249	12963	Business	29500.00
0005435006781	12963	Business	29500.00
0005435006608	12963	Business	29500.00
0005434229243	12963	Business	29500.00
0005432304376	12963	Business	29500.00
0005435006709	12963	Economy	9800.00
0005435006691	12963	Economy	9800.00
0005435038970	12963	Economy	9800.00
0005432304380	12963	Economy	9800.00
0005435038787	12963	Economy	9800.00
0005435038927	12963	Economy	9800.00
0005435038768	12963	Economy	9800.00
0005435038778	12963	Economy	9800.00
0005435038767	12963	Economy	9800.00
0005434229250	12963	Economy	9800.00
0005435038965	12963	Economy	9800.00
0005435038808	12963	Economy	9800.00
0005435039174	12963	Economy	9800.00
0005435038871	12963	Economy	9800.00
0005435038710	12963	Economy	9800.00
0005435038861	12963	Economy	9800.00
0005434229258	12963	Economy	9800.00
0005434229260	12963	Economy	9800.00
0005435038735	12963	Economy	9800.00
0005435038895	12963	Economy	9800.00
0005435038882	12963	Economy	9800.00
0005435038909	12963	Economy	9800.00
0005435038915	12963	Economy	9800.00
0005435038955	12963	Economy	9800.00
0005435006712	12963	Economy	9800.00
0005435038694	12963	Economy	9800.00
0005432304378	12963	Economy	9800.00
0005434229265	12963	Economy	9800.00
0005435006713	12963	Economy	9800.00
0005435038662	12963	Economy	9800.00
0005435039231	12963	Economy	9800.00
0005435038677	12963	Economy	9800.00
0005435038705	12963	Economy	9800.00
0005435006749	12963	Economy	9800.00
0005435038877	12963	Economy	9800.00
0005435038814	12963	Economy	9800.00
0005435038800	12963	Economy	9800.00
0005435038984	12963	Economy	9800.00
0005435039037	12963	Economy	10800.00
0005435006741	12963	Economy	10800.00
0005434229253	12963	Economy	10800.00
0005435038769	12963	Economy	10800.00
0005435038748	12963	Economy	10800.00
0005434229248	12963	Economy	10800.00
0005432304377	12963	Economy	9800.00
0005434229259	12963	Economy	9800.00
0005435038850	12963	Economy	9800.00
0005435039038	12963	Economy	9800.00
0005435006810	12963	Economy	9800.00
0005435039000	12963	Economy	9800.00
0005435006765	12963	Economy	9800.00
0005435006698	12963	Economy	9800.00
0005435039191	12963	Economy	9800.00
0005434229251	12963	Economy	9800.00
0005435038950	12963	Economy	9800.00
0005434229254	12963	Economy	9800.00
0005435038817	12963	Economy	9800.00
0005435006699	12963	Economy	9800.00
0005435038945	12963	Economy	9800.00
0005435006634	12963	Economy	9800.00
0005435006663	12963	Economy	9800.00
0005435038797	12963	Economy	9800.00
0005435038875	12963	Economy	9800.00
0005435006669	12963	Economy	9800.00
0005435006676	12963	Economy	9800.00
0005434229257	12963	Economy	9800.00
0005435042823	12963	Economy	9800.00
0005435038815	12963	Economy	9800.00
0005435006668	12963	Economy	9800.00
0005435038872	12963	Economy	9800.00
0005435039230	12963	Economy	9800.00
0005435006690	12963	Economy	9800.00
0005435038883	12963	Economy	9800.00
0005434229244	12963	Economy	9800.00
0005434229246	12963	Economy	9800.00
0005435039175	12963	Economy	9800.00
0005435038676	12963	Economy	9800.00
0005435038916	12963	Economy	9800.00
0005434229261	12963	Economy	9800.00
0005435038941	12963	Economy	9800.00
0005435038884	12963	Economy	9800.00
0005435006722	12963	Economy	9800.00
0005435038862	12963	Economy	9800.00
0005434229256	12963	Economy	9800.00
0005435006677	12963	Economy	9800.00
0005435038969	12963	Economy	9800.00
0005435039049	12963	Economy	9800.00
0005435006689	12963	Economy	9800.00
0005435038805	12963	Economy	9800.00
0005435039021	12963	Economy	9800.00
0005434229247	12963	Economy	9800.00
0005432304379	12963	Economy	9800.00
0005434229264	12963	Economy	9800.00
0005435039090	12963	Economy	9800.00
0005435038788	12963	Economy	9800.00
0005434229263	12963	Economy	9800.00
0005435006654	12963	Economy	9800.00
0005435038878	12963	Economy	9800.00
0005435038899	12963	Economy	9800.00
0005435038690	12963	Economy	9800.00
0005435039113	12963	Economy	9800.00
0005435038734	12963	Economy	9800.00
0005435038959	12963	Economy	9800.00
0005434229255	12963	Economy	9800.00
0005435039022	12963	Economy	9800.00
0005434229262	12963	Economy	9800.00
0005434229245	12963	Economy	9800.00
0005434229252	12963	Economy	9800.00
0005435039050	12963	Economy	9800.00
0005434426429	14899	Business	52900.00
0005435902415	14899	Business	52900.00
0005435554123	14899	Business	52900.00
0005434426425	14899	Business	52900.00
0005434426428	14899	Business	52900.00
0005434426431	14899	Business	52900.00
0005434426441	14899	Business	52900.00
0005435902446	14899	Business	52900.00
0005435902418	14899	Business	52900.00
0005434411751	14899	Economy	17600.00
0005435902417	14899	Economy	17600.00
0005434426418	14899	Economy	17600.00
0005434426447	14899	Economy	17600.00
0005434426434	14899	Economy	17600.00
0005434426446	14899	Economy	19400.00
0005434426417	14899	Economy	19400.00
0005435902486	14899	Economy	19400.00
0005434426430	14899	Economy	19400.00
0005434426426	14899	Economy	19400.00
0005434426440	14899	Economy	17600.00
0005435554116	14899	Economy	17600.00
0005434411750	14899	Economy	17600.00
0005434426444	14899	Economy	17600.00
0005434426438	14899	Economy	17600.00
0005434426436	14899	Economy	17600.00
0005434426433	14899	Economy	17600.00
0005434426419	14899	Economy	17600.00
0005435902468	14899	Economy	17600.00
0005434426439	14899	Economy	17600.00
0005432188588	14899	Economy	17600.00
0005435554110	14899	Economy	17600.00
0005434411753	14899	Economy	17600.00
0005432188586	14899	Economy	17600.00
0005435902487	14899	Economy	17600.00
0005434426432	14899	Economy	17600.00
0005434426427	14899	Economy	17600.00
0005434426420	14899	Economy	17600.00
0005432188587	14899	Economy	17600.00
0005434426445	14899	Economy	17600.00
0005435902447	14899	Economy	17600.00
0005434426435	14899	Economy	17600.00
0005434426422	14899	Economy	17600.00
0005435902438	14899	Economy	17600.00
0005434426416	14899	Economy	17600.00
0005434426443	14899	Economy	17600.00
0005435902422	14899	Economy	17600.00
0005435902439	14899	Economy	17600.00
0005435902498	14899	Economy	17600.00
0005434411752	14899	Economy	17600.00
0005432188589	14899	Economy	17600.00
0005435554117	14899	Economy	17600.00
0005434426421	14899	Economy	17600.00
0005434426437	14899	Economy	17600.00
0005434426423	14899	Economy	17600.00
0005435902410	14899	Economy	17600.00
0005434426424	14899	Economy	17600.00
0005435902470	14899	Economy	17600.00
0005434426442	14899	Economy	17600.00
0005435902614	20184	Business	52900.00
0005434426254	20184	Business	52900.00
0005434426257	20184	Business	52900.00
0005435902611	20184	Business	52900.00
0005434426181	20184	Economy	17600.00
0005434426266	20184	Economy	17600.00
0005434426316	20184	Economy	17600.00
0005434426258	20184	Economy	17600.00
0005434426213	20184	Economy	17600.00
0005434426229	20184	Economy	17600.00
0005435902618	20184	Economy	17600.00
0005435902615	20184	Economy	19400.00
0005435902619	20184	Economy	19400.00
0005434426182	20184	Economy	17600.00
0005434426221	20184	Economy	17600.00
0005432059494	20184	Economy	17600.00
0005435902610	20184	Economy	17600.00
0005435902609	20184	Economy	17600.00
0005434426196	20184	Economy	17600.00
0005434426131	20184	Economy	17600.00
0005434426116	20184	Economy	17600.00
0005434426183	20184	Economy	17600.00
0005434426222	20184	Economy	17600.00
0005435902608	20184	Economy	17600.00
0005434426117	20184	Economy	17600.00
0005435902620	20184	Economy	17600.00
0005435902616	20184	Economy	17600.00
0005435902606	20184	Economy	17600.00
0005434426218	20184	Economy	17600.00
0005435554165	20184	Economy	17600.00
0005434426255	20184	Economy	17600.00
0005434426250	20184	Economy	17600.00
0005435902617	20184	Economy	17600.00
0005434426345	20184	Economy	17600.00
0005435902605	20184	Economy	17600.00
0005434426253	20184	Economy	17600.00
0005435554166	20184	Economy	17600.00
0005434426246	20184	Economy	17600.00
0005434426223	20184	Economy	17600.00
0005435902607	20184	Economy	17600.00
0005434426252	20184	Economy	17600.00
0005434411725	20184	Economy	17600.00
0005435902613	20184	Economy	17600.00
0005435902603	20184	Economy	17600.00
0005434426130	20184	Economy	17600.00
0005434426197	20184	Economy	17600.00
0005434426247	20184	Economy	17600.00
0005435902604	20184	Economy	17600.00
0005434426251	20184	Economy	17600.00
0005434411715	20184	Economy	17600.00
0005435554164	20184	Economy	17600.00
0005435902612	20184	Economy	17600.00
0005434426219	20184	Economy	17600.00
0005434426259	20184	Economy	17600.00
0005434426248	20184	Economy	17600.00
0005435982023	26496	Business	18500.00
0005433434313	26496	Business	18500.00
0005435982032	26496	Business	18500.00
0005433434242	26496	Business	18500.00
0005433434320	26496	Business	18500.00
0005435982043	26496	Business	18500.00
0005435982015	26496	Business	18500.00
0005433434336	26496	Business	18500.00
0005435982020	26496	Business	18500.00
0005433434312	26496	Business	18500.00
0005433434287	26496	Business	18500.00
0005433434315	26496	Economy	6200.00
0005433434330	26496	Economy	6200.00
0005435982044	26496	Economy	6200.00
0005435982018	26496	Economy	6200.00
0005435982021	26496	Economy	6200.00
0005435982042	26496	Economy	6200.00
0005435982034	26496	Economy	6200.00
0005435982051	26496	Economy	6200.00
0005435982049	26496	Economy	6800.00
0005435982030	26496	Economy	6800.00
0005435982046	26496	Economy	6800.00
0005435982053	26496	Economy	6800.00
0005435982040	26496	Economy	6200.00
0005435982026	26496	Economy	6200.00
0005433434332	26496	Economy	6200.00
0005435982033	26496	Economy	6200.00
0005435982025	26496	Economy	6200.00
0005433434293	26496	Economy	6200.00
0005433434331	26496	Economy	6200.00
0005435982022	26496	Economy	6200.00
0005433434317	26496	Economy	6200.00
0005433434316	26496	Economy	6200.00
0005433434314	26496	Economy	6200.00
0005435982028	26496	Economy	6200.00
0005433434216	26496	Economy	6200.00
0005435982029	26496	Economy	6200.00
0005435982038	26496	Economy	6200.00
0005434270177	26496	Economy	6200.00
0005433434319	26496	Economy	6200.00
0005435982027	26496	Economy	6200.00
0005433434275	26496	Economy	6200.00
0005432300231	26496	Economy	6200.00
0005433434286	26496	Economy	6200.00
0005432300229	26496	Economy	6200.00
0005435982047	26496	Economy	6200.00
0005433434208	26496	Economy	6200.00
0005435982045	26496	Economy	6200.00
0005433434333	26496	Economy	6200.00
0005432300227	26496	Economy	6200.00
0005433434241	26496	Economy	6200.00
0005435982050	26496	Economy	6200.00
0005435982019	26496	Economy	6200.00
0005435982037	26496	Economy	6200.00
0005433434267	26496	Economy	6200.00
0005432300226	26496	Economy	6200.00
0005435982035	26496	Economy	6200.00
0005433434321	26496	Economy	6200.00
0005435982014	26496	Economy	6200.00
0005435982036	26496	Economy	6200.00
0005435982031	26496	Economy	6200.00
0005435982048	26496	Economy	6200.00
0005433434276	26496	Economy	6200.00
0005432300228	26496	Economy	6200.00
0005433434249	26496	Economy	6200.00
0005435982039	26496	Economy	6200.00
0005433434251	26496	Economy	6200.00
0005435982016	26496	Economy	6200.00
0005433434250	26496	Economy	6200.00
0005435982024	26496	Economy	6200.00
0005433434266	26496	Economy	6200.00
0005435982052	26496	Economy	6200.00
0005433434327	26496	Economy	6200.00
0005432300230	26496	Economy	6200.00
0005435982017	26496	Economy	6200.00
0005435982041	26496	Economy	6200.00
0005433434298	26496	Economy	6200.00
0005433434335	26496	Economy	6200.00
0005432051113	26725	Business	18500.00
0005433434543	26725	Business	18500.00
0005433434525	26725	Business	18500.00
0005433434536	26725	Business	18500.00
0005433434527	26725	Business	18500.00
0005435981695	26725	Business	18500.00
0005435981883	26725	Business	18500.00
0005435981601	26725	Business	18500.00
0005435981661	26725	Business	18500.00
0005433434530	26725	Business	18500.00
0005435981599	26725	Business	18500.00
0005433434534	26725	Economy	6200.00
0005435981744	26725	Economy	6200.00
0005435981768	26725	Economy	6200.00
0005435981580	26725	Economy	6200.00
0005435981598	26725	Economy	6200.00
0005433434544	26725	Economy	6200.00
0005433434526	26725	Economy	6200.00
0005435981672	26725	Economy	6200.00
0005434270197	26725	Economy	6200.00
0005435981609	26725	Economy	6200.00
0005432051114	26725	Economy	6800.00
0005433434529	26725	Economy	6800.00
0005435981579	26725	Economy	6800.00
0005433434547	26725	Economy	6800.00
0005433434550	26725	Economy	6800.00
0005435981793	26725	Economy	6200.00
0005433434528	26725	Economy	6200.00
0005435981830	26725	Economy	6200.00
0005435981783	26725	Economy	6200.00
0005435981593	26725	Economy	6200.00
0005433434533	26725	Economy	6200.00
0005434269092	26725	Economy	6200.00
0005435981594	26725	Economy	6200.00
0005435981701	26725	Economy	6200.00
0005434271303	26725	Economy	6200.00
0005433434553	26725	Economy	6200.00
0005435981751	26725	Economy	6200.00
0005434271301	26725	Economy	6200.00
0005435981642	26725	Economy	6200.00
0005435981670	26725	Economy	6200.00
0005433434537	26725	Economy	6200.00
0005433434538	26725	Economy	6200.00
0005433434540	26725	Economy	6200.00
0005435981660	26725	Economy	6200.00
0005434270195	26725	Economy	6200.00
0005435981526	26725	Economy	6200.00
0005433434535	26725	Economy	6200.00
0005433434532	26725	Economy	6200.00
0005433434539	26725	Economy	6200.00
0005432051112	26725	Economy	6200.00
0005433434551	26725	Economy	6200.00
0005433434546	26725	Economy	6200.00
0005435981625	26725	Economy	6200.00
0005435981677	26725	Economy	6200.00
0005435981567	26725	Economy	6200.00
0005435981623	26725	Economy	6200.00
0005433434548	26725	Economy	6200.00
0005435981592	26725	Economy	6200.00
0005435981923	26725	Economy	6200.00
0005435981595	26725	Economy	6200.00
0005434270196	26725	Economy	6200.00
0005435981566	26725	Economy	6200.00
0005434270198	26725	Economy	6200.00
0005433434549	26725	Economy	6200.00
0005434271302	26725	Economy	6200.00
0005435981574	26725	Economy	6200.00
0005433434531	26725	Economy	6200.00
0005435981707	26725	Economy	6200.00
0005433434545	26725	Economy	6200.00
0005435981525	26725	Economy	6200.00
0005435981602	26725	Economy	6200.00
0005434269093	26725	Economy	6200.00
0005435981700	26725	Economy	6200.00
0005435981611	26725	Economy	6200.00
0005435981699	26725	Economy	6200.00
0005433434552	26725	Economy	6200.00
0005435981528	26725	Economy	6200.00
0005435981745	26725	Economy	6200.00
0005435981529	26725	Economy	6200.00
0005433434541	26725	Economy	6200.00
0005435981669	26725	Economy	6200.00
0005435981678	26725	Economy	6200.00
0005433434542	26725	Economy	6200.00
0005435981626	26725	Economy	6200.00
0005432583893	3189	Economy	11100.00
0005432583892	3189	Economy	11100.00
0005432583898	3189	Economy	11100.00
0005432583904	3189	Economy	11100.00
0005432216258	3189	Economy	10100.00
0005432583895	3189	Economy	10100.00
0005432857927	3189	Economy	10100.00
0005432583896	3189	Economy	10100.00
0005432857906	3189	Economy	10100.00
0005432583900	3189	Economy	10100.00
0005432216257	3189	Economy	10100.00
0005432583917	3189	Economy	10100.00
0005432857905	3189	Economy	10100.00
0005432583913	3189	Economy	10100.00
0005432583906	3189	Economy	10100.00
0005432857856	3189	Economy	10100.00
0005432857891	3189	Economy	10100.00
0005432857897	3189	Economy	10100.00
0005432583910	3189	Economy	10100.00
0005432583894	3189	Economy	10100.00
0005432583901	3189	Economy	10100.00
0005432583899	3189	Economy	10100.00
0005432857901	3189	Economy	10100.00
0005432583909	3189	Economy	10100.00
0005432583902	3189	Economy	10100.00
0005432583907	3189	Economy	10100.00
0005432216256	3189	Economy	10100.00
0005432583891	3189	Economy	10100.00
0005432583914	3189	Economy	10100.00
0005432583897	3189	Economy	10100.00
0005432583912	3189	Economy	10100.00
0005432857880	3189	Economy	10100.00
0005432583903	3189	Economy	10100.00
0005432857900	3189	Economy	10100.00
0005432583911	3189	Economy	10100.00
0005432857857	3189	Economy	10100.00
0005432583916	3189	Economy	10100.00
0005432857879	3189	Economy	10100.00
0005432583915	3189	Economy	10100.00
0005432857892	3189	Economy	10100.00
0005432583908	3189	Economy	10100.00
0005432583905	3189	Economy	10100.00
0005432858010	31518	Economy	11100.00
0005432583733	31518	Economy	11100.00
0005432583703	31518	Economy	10100.00
0005432583657	31518	Economy	10100.00
0005432583746	31518	Economy	10100.00
0005432858007	31518	Economy	10100.00
0005432583738	31518	Economy	10100.00
0005432583756	31518	Economy	10100.00
0005432858004	31518	Economy	10100.00
0005432858003	31518	Economy	10100.00
0005432857998	31518	Economy	10100.00
0005432583714	31518	Economy	10100.00
0005432858009	31518	Economy	10100.00
0005432858001	31518	Economy	10100.00
0005432858008	31518	Economy	10100.00
0005432583704	31518	Economy	10100.00
0005432583688	31518	Economy	10100.00
0005432858006	31518	Economy	10100.00
0005432583707	31518	Economy	10100.00
0005432858000	31518	Economy	10100.00
0005432583713	31518	Economy	10100.00
0005432583737	31518	Economy	10100.00
0005432583757	31518	Economy	10100.00
0005432858005	31518	Economy	10100.00
0005432857999	31518	Economy	10100.00
0005432858002	31518	Economy	10100.00
0005434943301	856	Economy	7500.00
0005434943299	856	Economy	7500.00
0005434943305	856	Economy	7500.00
0005434943303	856	Economy	7500.00
0005434943307	856	Economy	7500.00
0005434943300	856	Economy	7500.00
0005434943298	856	Economy	7500.00
0005434943306	856	Economy	7500.00
0005433255082	856	Economy	7500.00
0005433255083	856	Economy	7500.00
0005434943302	856	Economy	7500.00
0005433255032	856	Economy	7500.00
0005434943304	856	Economy	7500.00
0005433255081	856	Economy	7500.00
0005433255080	856	Economy	7500.00
0005433255029	856	Economy	7500.00
0005434943263	16226	Economy	7500.00
0005433255092	16226	Economy	7500.00
0005433255091	16226	Economy	7500.00
0005434943216	16226	Economy	7500.00
0005434943218	16226	Economy	7500.00
0005433255090	16226	Economy	7500.00
0005434943208	16226	Economy	7500.00
0005434943207	16226	Economy	7500.00
0005434943262	16226	Economy	7500.00
0005433255089	16226	Economy	7500.00
0005434943258	16226	Economy	7500.00
0005433255088	16226	Economy	7500.00
0005434943225	16226	Economy	7500.00
0005434943236	16226	Economy	7500.00
0005434943219	16226	Economy	7500.00
0005434943239	16226	Economy	7500.00
0005434943257	16226	Economy	7500.00
0005433811615	14374	Economy	4400.00
0005433367366	21723	Business	9800.00
0005433367276	21723	Business	9800.00
0005435652834	21723	Business	9800.00
0005433367306	21723	Business	9800.00
0005435652829	21723	Business	9800.00
0005435652819	21723	Business	9800.00
0005433367382	21723	Business	9800.00
0005433367372	21723	Business	9800.00
0005435652793	21723	Business	9800.00
0005435652806	21723	Business	9800.00
0005433367383	21723	Economy	3300.00
0005435652831	21723	Economy	3300.00
0005433367557	21723	Economy	3300.00
0005435652808	21723	Economy	3300.00
0005435652804	21723	Economy	3300.00
0005433367239	21723	Economy	3300.00
0005435652823	21723	Economy	3300.00
0005435652828	21723	Economy	3300.00
0005433367311	21723	Economy	3300.00
0005433367259	21723	Economy	3600.00
0005433367249	21723	Economy	3600.00
0005433367559	21723	Economy	3600.00
0005435652821	21723	Economy	3600.00
0005433367341	21723	Economy	3600.00
0005435652810	21723	Economy	3300.00
0005435652796	21723	Economy	3300.00
0005433367356	21723	Economy	3300.00
0005435652817	21723	Economy	3300.00
0005435652830	21723	Economy	3300.00
0005435652802	21723	Economy	3300.00
0005435652825	21723	Economy	3300.00
0005435652827	21723	Economy	3300.00
0005433367250	21723	Economy	3300.00
0005435652811	21723	Economy	3300.00
0005435652795	21723	Economy	3300.00
0005433367332	21723	Economy	3300.00
0005435652824	21723	Economy	3300.00
0005435652820	21723	Economy	3300.00
0005435652818	21723	Economy	3300.00
0005435652790	21723	Economy	3300.00
0005433367304	21723	Economy	3300.00
0005435652826	21723	Economy	3300.00
0005435652812	21723	Economy	3300.00
0005435652815	21723	Economy	3300.00
0005435652794	21723	Economy	3300.00
0005435652814	21723	Economy	3300.00
0005435652798	21723	Economy	3300.00
0005433367244	21723	Economy	3300.00
0005435652801	21723	Economy	3300.00
0005435652799	21723	Economy	3300.00
0005435652788	21723	Economy	3300.00
0005435652809	21723	Economy	3300.00
0005435652791	21723	Economy	3300.00
0005433367367	21723	Economy	3300.00
0005433367238	21723	Economy	3300.00
0005433367352	21723	Economy	3300.00
0005433367303	21723	Economy	3300.00
0005435652822	21723	Economy	3300.00
0005433367368	21723	Economy	3300.00
0005433367283	21723	Economy	3300.00
0005433367318	21723	Economy	3300.00
0005435652835	21723	Economy	3300.00
0005435652837	21723	Economy	3300.00
0005433367360	21723	Economy	3300.00
0005435652803	21723	Economy	3300.00
0005435652813	21723	Economy	3300.00
0005435652836	21723	Economy	3300.00
0005435652816	21723	Economy	3300.00
0005433367265	21723	Economy	3300.00
0005435652787	21723	Economy	3300.00
0005435652800	21723	Economy	3300.00
0005435652805	21723	Economy	3300.00
0005433367312	21723	Economy	3300.00
0005435652792	21723	Economy	3300.00
0005435652786	21723	Economy	3300.00
0005435652797	21723	Economy	3300.00
0005435652832	21723	Economy	3300.00
0005435652833	21723	Economy	3300.00
0005433367387	21723	Economy	3300.00
0005433367558	21723	Economy	3300.00
0005435652789	21723	Economy	3300.00
0005435652807	21723	Economy	3300.00
0005433784769	9389	Business	186200.00
0005433805179	9389	Business	186200.00
0005433805182	9389	Business	186200.00
0005433805170	9389	Business	186200.00
0005433805175	9389	Business	186200.00
0005433763133	9389	Business	186200.00
0005432667442	9389	Business	186200.00
0005432657432	9389	Business	186200.00
0005433805168	9389	Business	186200.00
0005433784750	9389	Business	186200.00
0005433805205	9389	Business	186200.00
0005434170880	9389	Business	186200.00
0005433805197	9389	Business	186200.00
0005433805187	9389	Business	186200.00
0005433805203	9389	Business	186200.00
0005433805201	9389	Business	186200.00
0005433784768	9389	Business	186200.00
0005433763132	9389	Business	186200.00
0005434273047	9389	Economy	68300.00
0005433805210	9389	Economy	62100.00
0005433784770	9389	Economy	62100.00
0005434273057	9389	Economy	62100.00
0005433784743	9389	Economy	62100.00
0005435269631	9389	Economy	62100.00
0005433784756	9389	Economy	62100.00
0005433805198	9389	Economy	62100.00
0005432657434	9389	Economy	62100.00
0005433805169	9389	Economy	62100.00
0005434273058	9389	Economy	62100.00
0005433805189	9389	Economy	62100.00
0005433784763	9389	Economy	62100.00
0005433805193	9389	Economy	62100.00
0005432666377	9389	Economy	62100.00
0005433784752	9389	Economy	62100.00
0005434270185	9389	Economy	62100.00
0005433805204	9389	Economy	62100.00
0005433763136	9389	Economy	62100.00
0005433763134	9389	Economy	62100.00
0005434170839	9389	Economy	62100.00
0005434170859	9389	Economy	62100.00
0005434270182	9389	Economy	62100.00
0005434151665	9389	Economy	62100.00
0005433784741	9389	Economy	62100.00
0005433784745	9389	Economy	62100.00
0005433784744	9389	Economy	62100.00
0005433784740	9389	Economy	62100.00
0005432667443	9389	Economy	62100.00
0005433805196	9389	Economy	62100.00
0005433784757	9389	Economy	62100.00
0005435269632	9389	Economy	62100.00
0005433784755	9389	Economy	62100.00
0005433763122	9389	Economy	62100.00
0005434273053	9389	Economy	62100.00
0005433784739	9389	Economy	62100.00
0005433784746	9389	Economy	62100.00
0005433763123	9389	Economy	62100.00
0005433763126	9389	Economy	62100.00
0005433784742	9389	Economy	62100.00
0005433763135	9389	Economy	62100.00
0005433805188	9389	Economy	62100.00
0005433784762	9389	Economy	62100.00
0005433805194	9389	Economy	62100.00
0005433805200	9389	Economy	62100.00
0005434170881	9389	Economy	62100.00
0005433805207	9389	Economy	62100.00
0005433784747	9389	Economy	62100.00
0005434270183	9389	Economy	62100.00
0005433763124	9389	Economy	62100.00
0005433763131	9389	Economy	62100.00
0005433784771	9389	Economy	62100.00
0005433805208	9389	Economy	62100.00
0005433805199	9389	Economy	62100.00
0005434270184	9389	Economy	62100.00
0005434270180	9389	Economy	62100.00
0005434151678	9389	Economy	62100.00
0005434170914	9389	Economy	62100.00
0005433784749	9389	Economy	62100.00
0005433805183	9389	Economy	62100.00
0005432657433	9389	Economy	62100.00
0005433784772	9389	Economy	62100.00
0005434273054	9389	Economy	62100.00
0005433784765	9389	Economy	62100.00
0005433805206	9389	Economy	62100.00
0005433763130	9389	Economy	62100.00
0005433805195	9389	Economy	68300.00
0005432665263	9389	Economy	62100.00
0005433763129	9389	Economy	68300.00
0005433784766	9389	Economy	62100.00
0005433805177	9389	Economy	62100.00
0005434170913	9389	Economy	62100.00
0005433784764	9389	Economy	62100.00
0005433784761	9389	Economy	62100.00
0005434273051	9389	Economy	62100.00
0005433784751	9389	Economy	62100.00
0005433763127	9389	Economy	62100.00
0005434273050	9389	Economy	62100.00
0005433805202	9389	Economy	62100.00
0005433784767	9389	Economy	62100.00
0005434270186	9389	Economy	62100.00
0005433805174	9389	Economy	62100.00
0005433805171	9389	Economy	62100.00
0005433805191	9389	Economy	62100.00
0005434170887	9389	Economy	62100.00
0005433784758	9389	Economy	62100.00
0005433805178	9389	Economy	62100.00
0005433763128	9389	Economy	62100.00
0005433805192	9389	Economy	62100.00
0005434170860	9389	Economy	62100.00
0005433805190	9389	Economy	62100.00
0005433784754	9389	Economy	62100.00
0005433763125	9389	Economy	62100.00
0005432665264	9389	Economy	62100.00
0005433784748	9389	Economy	62100.00
0005434170852	9389	Economy	62100.00
0005433805209	9389	Economy	62100.00
0005434170868	9389	Economy	62100.00
0005433784753	9389	Economy	62100.00
0005434170858	9389	Economy	62100.00
0005435269621	9389	Economy	62100.00
0005433805184	9389	Economy	62100.00
0005434170895	9389	Economy	62100.00
0005434170894	9389	Economy	62100.00
0005433805181	9389	Economy	62100.00
0005433805173	9389	Economy	62100.00
0005433784760	9389	Economy	62100.00
0005434151664	9389	Economy	62100.00
0005432666378	9389	Economy	62100.00
0005433805180	9389	Economy	62100.00
0005433805172	9389	Economy	62100.00
0005433805176	9389	Economy	62100.00
0005433784759	9389	Economy	62100.00
0005434170884	9389	Economy	62100.00
0005434170841	9389	Economy	62100.00
0005433805186	9389	Economy	62100.00
0005433805185	9389	Economy	62100.00
0005434170982	26228	Business	186200.00
0005433804874	26228	Business	186200.00
0005435269717	26228	Business	186200.00
0005433784454	26228	Business	186200.00
0005433763016	26228	Business	186200.00
0005435269714	26228	Business	186200.00
0005435269705	26228	Business	186200.00
0005433762989	26228	Business	186200.00
0005435269723	26228	Business	186200.00
0005433804955	26228	Business	186200.00
0005433804999	26228	Business	186200.00
0005433763035	26228	Business	186200.00
0005433762964	26228	Business	186200.00
0005433784337	26228	Business	186200.00
0005433784514	26228	Business	186200.00
0005433784516	26228	Business	186200.00
0005433804877	26228	Economy	68300.00
0005433784338	26228	Economy	68300.00
0005434170984	26228	Economy	62100.00
0005435269716	26228	Economy	62100.00
0005434170977	26228	Economy	62100.00
0005433804929	26228	Economy	62100.00
0005433784538	26228	Economy	62100.00
0005433804878	26228	Economy	62100.00
0005435269719	26228	Economy	62100.00
0005434170978	26228	Economy	62100.00
0005433784517	26228	Economy	62100.00
0005433784532	26228	Economy	62100.00
0005433784478	26228	Economy	62100.00
0005435269720	26228	Economy	62100.00
0005433804880	26228	Economy	62100.00
0005434170973	26228	Economy	62100.00
0005435269709	26228	Economy	62100.00
0005433804997	26228	Economy	62100.00
0005433805040	26228	Economy	62100.00
0005433784422	26228	Economy	62100.00
0005433763004	26228	Economy	62100.00
0005434170987	26228	Economy	62100.00
0005433804904	26228	Economy	62100.00
0005433762997	26228	Economy	62100.00
0005433763075	26228	Economy	62100.00
0005435269715	26228	Economy	62100.00
0005433784489	26228	Economy	62100.00
0005433784590	26228	Economy	62100.00
0005433804902	26228	Economy	62100.00
0005435269708	26228	Economy	62100.00
0005433784410	26228	Economy	62100.00
0005433804890	26228	Economy	62100.00
0005433804820	26228	Economy	62100.00
0005433784505	26228	Economy	62100.00
0005434269090	26228	Economy	62100.00
0005434270193	26228	Economy	62100.00
0005435269707	26228	Economy	62100.00
0005433804885	26228	Economy	62100.00
0005433763034	26228	Economy	62100.00
0005434270194	26228	Economy	62100.00
0005433763005	26228	Economy	62100.00
0005434151689	26228	Economy	62100.00
0005433763056	26228	Economy	62100.00
0005433784346	26228	Economy	62100.00
0005433804883	26228	Economy	62100.00
0005434170983	26228	Economy	62100.00
0005433763045	26228	Economy	62100.00
0005434170986	26228	Economy	62100.00
0005433762962	26228	Economy	62100.00
0005433784539	26228	Economy	62100.00
0005433784347	26228	Economy	62100.00
0005433784384	26228	Economy	62100.00
0005433784453	26228	Economy	62100.00
0005433804971	26228	Economy	62100.00
0005433784369	26228	Economy	62100.00
0005433784371	26228	Economy	62100.00
0005433784343	26228	Economy	62100.00
0005433784459	26228	Economy	62100.00
0005433763023	26228	Economy	62100.00
0005433784408	26228	Economy	62100.00
0005433784372	26228	Economy	62100.00
0005433804809	26228	Economy	62100.00
0005433805038	26228	Economy	62100.00
0005433784450	26228	Economy	62100.00
0005433762975	26228	Economy	62100.00
0005433762976	26228	Economy	62100.00
0005435269711	26228	Economy	68300.00
0005435269710	26228	Economy	62100.00
0005433763057	26228	Economy	62100.00
0005435269706	26228	Economy	68300.00
0005433804898	26228	Economy	62100.00
0005433784421	26228	Economy	62100.00
0005433804933	26228	Economy	62100.00
0005434170985	26228	Economy	62100.00
0005433763044	26228	Economy	62100.00
0005434170988	26228	Economy	62100.00
0005433762963	26228	Economy	62100.00
0005433784394	26228	Economy	62100.00
0005433784325	26228	Economy	62100.00
0005433804810	26228	Economy	62100.00
0005434271300	26228	Economy	62100.00
0005435269713	26228	Economy	62100.00
0005434170980	26228	Economy	62100.00
0005433784455	26228	Economy	62100.00
0005433804983	26228	Economy	62100.00
0005433804882	26228	Economy	62100.00
0005434269091	26228	Economy	62100.00
0005433784511	26228	Economy	62100.00
0005433784438	26228	Economy	62100.00
0005435269712	26228	Economy	62100.00
0005434170976	26228	Economy	62100.00
0005433784525	26228	Economy	62100.00
0005433784342	26228	Economy	62100.00
0005434271299	26228	Economy	62100.00
0005433784548	26228	Economy	62100.00
0005434170975	26228	Economy	62100.00
0005433804913	26228	Economy	62100.00
0005433804900	26228	Economy	62100.00
0005433762968	26228	Economy	62100.00
0005433784398	26228	Economy	62100.00
0005435269721	26228	Economy	62100.00
0005433784348	26228	Economy	62100.00
0005433804901	26228	Economy	62100.00
0005433804998	26228	Economy	62100.00
0005433762990	26228	Economy	62100.00
0005432659671	26228	Economy	62100.00
0005433804860	26228	Economy	62100.00
0005433784370	26228	Economy	62100.00
0005435269704	26228	Economy	62100.00
0005433784481	26228	Economy	62100.00
0005434170974	26228	Economy	62100.00
0005435269722	26228	Economy	62100.00
0005433784407	26228	Economy	62100.00
0005433784349	26228	Economy	62100.00
0005433804970	26228	Economy	62100.00
0005433804884	26228	Economy	62100.00
0005433784414	26228	Economy	62100.00
0005433804903	26228	Economy	62100.00
0005434170981	26228	Economy	62100.00
0005435269718	26228	Economy	62100.00
0005433804811	26228	Economy	62100.00
0005435269724	26228	Economy	62100.00
0005433804982	26228	Economy	62100.00
0005434170979	26228	Economy	62100.00
0005435135644	4927	Economy	5300.00
0005435929616	4927	Economy	5300.00
0005435135645	4927	Economy	5300.00
0005435929600	4927	Economy	5300.00
0005435135646	4927	Economy	5300.00
0005435929609	4927	Economy	5300.00
0005435135642	4927	Economy	5300.00
0005435929608	4927	Economy	5300.00
0005435135641	4927	Economy	5300.00
0005435135643	4927	Economy	5300.00
0005435135615	33028	Economy	5300.00
0005435135612	33028	Economy	5300.00
0005435929629	33028	Economy	5300.00
0005435135606	33028	Economy	5300.00
0005435135616	33028	Economy	5300.00
0005435929628	33028	Economy	5300.00
0005435135586	33028	Economy	5300.00
0005435135591	33028	Economy	5300.00
0005435929630	33028	Economy	5300.00
0005434983258	9480	Economy	17900.00
0005434983260	9480	Economy	17900.00
0005434217896	9480	Economy	17900.00
0005434217895	9480	Economy	17900.00
0005434217910	9480	Economy	17900.00
0005434983262	9480	Economy	17900.00
0005434217933	9480	Economy	17900.00
0005434983261	9480	Economy	17900.00
0005434217909	9480	Economy	17900.00
0005434983259	9480	Economy	17900.00
0005434217911	9480	Economy	17900.00
0005434983257	9480	Economy	17900.00
0005434217948	27369	Economy	17900.00
0005434217947	27369	Economy	17900.00
0005434983227	27369	Economy	17900.00
0005434217949	27369	Economy	17900.00
0005434983216	27369	Economy	17900.00
0005434217945	27369	Economy	17900.00
0005434983218	27369	Economy	17900.00
0005434217946	27369	Economy	17900.00
0005433959971	24242	Business	36400.00
0005433960076	24242	Business	36400.00
0005433960028	24242	Business	36400.00
0005433985194	24242	Business	36400.00
0005433985149	24242	Business	36400.00
0005433985238	24242	Business	36400.00
0005433960073	24242	Business	36400.00
0005433959930	24242	Business	36400.00
0005433985400	24242	Business	36400.00
0005433959946	24242	Business	36400.00
0005433960051	24242	Business	36400.00
0005433959922	24242	Business	36400.00
0005433959917	24242	Business	36400.00
0005433960072	24242	Business	36400.00
0005433959978	24242	Business	36400.00
0005433985435	24242	Business	36400.00
0005433985255	24242	Business	36400.00
0005433985240	24242	Economy	13400.00
0005433959921	24242	Economy	13400.00
0005433959979	24242	Economy	12100.00
0005433960066	24242	Economy	12100.00
0005433960034	24242	Economy	12100.00
0005433959912	24242	Economy	12100.00
0005433985156	24242	Economy	12100.00
0005433959966	24242	Economy	12100.00
0005433959931	24242	Economy	12100.00
0005433985195	24242	Economy	12100.00
0005433960071	24242	Economy	12100.00
0005433959981	24242	Economy	12100.00
0005433959956	24242	Economy	12100.00
0005433985313	24242	Economy	12100.00
0005433985167	24242	Economy	12100.00
0005433985315	24242	Economy	12100.00
0005433985349	24242	Economy	12100.00
0005433985266	24242	Economy	12100.00
0005433985423	24242	Economy	12100.00
0005433959925	24242	Economy	12100.00
0005433985370	24242	Economy	12100.00
0005433985298	24242	Economy	12100.00
0005433959898	24242	Economy	12100.00
0005433960014	24242	Economy	12100.00
0005433959951	24242	Economy	12100.00
0005433985265	24242	Economy	12100.00
0005433985334	24242	Economy	12100.00
0005433985401	24242	Economy	12100.00
0005433960038	24242	Economy	12100.00
0005433985225	24242	Economy	12100.00
0005433985360	24242	Economy	12100.00
0005433985239	24242	Economy	12100.00
0005433960037	24242	Economy	12100.00
0005433960075	24242	Economy	12100.00
0005433960022	24242	Economy	12100.00
0005433985283	24242	Economy	12100.00
0005433959967	24242	Economy	12100.00
0005433985166	24242	Economy	12100.00
0005433985206	24242	Economy	12100.00
0005433960032	24242	Economy	12100.00
0005433985533	24242	Economy	12100.00
0005433960063	24242	Economy	12100.00
0005433985346	24242	Economy	12100.00
0005433960006	24242	Economy	12100.00
0005433960061	24242	Economy	12100.00
0005433960068	24242	Economy	12100.00
0005433985178	24242	Economy	12100.00
0005433985158	24242	Economy	13400.00
0005433985184	24242	Economy	12100.00
0005433960031	24242	Economy	12100.00
0005433960036	24242	Economy	12100.00
0005433959923	24242	Economy	12100.00
0005433959916	24242	Economy	12100.00
0005433985254	24242	Economy	12100.00
0005433960009	24242	Economy	12100.00
0005433985318	24242	Economy	12100.00
0005433985402	24242	Economy	12100.00
0005433985422	24242	Economy	12100.00
0005433985333	24242	Economy	12100.00
0005433959890	24242	Economy	12100.00
0005433985267	24242	Economy	12100.00
0005433985354	24242	Economy	12100.00
0005433985205	24242	Economy	12100.00
0005433985547	24242	Economy	12100.00
0005433985345	24242	Economy	12100.00
0005433985237	24242	Economy	12100.00
0005433985369	24242	Economy	12100.00
0005433959995	24242	Economy	12100.00
0005433985281	24242	Economy	12100.00
0005433960070	24242	Economy	12100.00
0005433959970	24242	Economy	12100.00
0005433985359	24242	Economy	12100.00
0005433985314	24242	Economy	12100.00
0005433985332	24242	Economy	12100.00
0005433960021	24242	Economy	12100.00
0005433959969	24242	Economy	12100.00
0005433959957	24242	Economy	12100.00
0005433985282	24242	Economy	12100.00
0005433959932	24242	Economy	12100.00
0005433985433	24242	Economy	12100.00
0005433959945	24242	Economy	12100.00
0005433960030	24242	Economy	12100.00
0005433959891	24242	Economy	12100.00
0005433985196	24242	Economy	12100.00
0005433985299	24242	Economy	12100.00
0005433960033	24242	Economy	12100.00
0005433985424	24242	Economy	12100.00
0005433960558	25954	Business	36400.00
0005433960562	25954	Business	36400.00
0005433960571	25954	Business	36400.00
0005433960569	25954	Business	36400.00
0005433985682	25954	Business	36400.00
0005433960559	25954	Business	36400.00
0005433960524	25954	Business	36400.00
0005433960560	25954	Business	36400.00
0005433960546	25954	Business	36400.00
0005433960532	25954	Business	36400.00
0005433960550	25954	Business	36400.00
0005433985649	25954	Business	36400.00
0005433960514	25954	Business	36400.00
0005433985664	25954	Business	36400.00
0005433985681	25954	Economy	13400.00
0005433960568	25954	Economy	13400.00
0005433960499	25954	Economy	12100.00
0005433985650	25954	Economy	12100.00
0005433960508	25954	Economy	12100.00
0005433985651	25954	Economy	12100.00
0005433960557	25954	Economy	12100.00
0005433985669	25954	Economy	12100.00
0005433960533	25954	Economy	12100.00
0005433960505	25954	Economy	12100.00
0005433960567	25954	Economy	12100.00
0005433960539	25954	Economy	12100.00
0005433985662	25954	Economy	12100.00
0005433960555	25954	Economy	12100.00
0005433960517	25954	Economy	12100.00
0005433985670	25954	Economy	12100.00
0005433985654	25954	Economy	12100.00
0005433985672	25954	Economy	12100.00
0005433985686	25954	Economy	12100.00
0005433985674	25954	Economy	12100.00
0005433960506	25954	Economy	12100.00
0005433960538	25954	Economy	12100.00
0005433985687	25954	Economy	12100.00
0005433985656	25954	Economy	12100.00
0005433985679	25954	Economy	12100.00
0005433985671	25954	Economy	12100.00
0005433985655	25954	Economy	12100.00
0005433985688	25954	Economy	12100.00
0005433960537	25954	Economy	12100.00
0005433960561	25954	Economy	12100.00
0005433960535	25954	Economy	12100.00
0005433985653	25954	Economy	12100.00
0005433960547	25954	Economy	12100.00
0005433960518	25954	Economy	12100.00
0005433985675	25954	Economy	12100.00
0005433960513	25954	Economy	12100.00
0005433960552	25954	Economy	12100.00
0005433960553	25954	Economy	12100.00
0005433960556	25954	Economy	12100.00
0005433985684	25954	Economy	12100.00
0005433960563	25954	Economy	12100.00
0005433960521	25954	Economy	12100.00
0005433960516	25954	Economy	12100.00
0005433960512	25954	Economy	12100.00
0005433960566	25954	Economy	12100.00
0005433960543	25954	Economy	12100.00
0005433960509	25954	Economy	12100.00
0005433985658	25954	Economy	12100.00
0005433960504	25954	Economy	12100.00
0005433960536	25954	Economy	12100.00
0005433960500	25954	Economy	12100.00
0005433960542	25954	Economy	12100.00
0005433960519	25954	Economy	12100.00
0005433985685	25954	Economy	12100.00
0005433960531	25954	Economy	12100.00
0005433960502	25954	Economy	12100.00
0005433960503	25954	Economy	12100.00
0005433960545	25954	Economy	13400.00
0005433960551	25954	Economy	12100.00
0005433960525	25954	Economy	12100.00
0005433985660	25954	Economy	12100.00
0005433985680	25954	Economy	12100.00
0005433985677	25954	Economy	12100.00
0005433985661	25954	Economy	12100.00
0005433960540	25954	Economy	12100.00
0005433960564	25954	Economy	12100.00
0005433960520	25954	Economy	12100.00
0005433985659	25954	Economy	12100.00
0005433960526	25954	Economy	12100.00
0005433960527	25954	Economy	12100.00
0005433985683	25954	Economy	12100.00
0005433985648	25954	Economy	12100.00
0005433960554	25954	Economy	12100.00
0005433985657	25954	Economy	12100.00
0005433985665	25954	Economy	12100.00
0005433960501	25954	Economy	12100.00
0005433960511	25954	Economy	12100.00
0005433960529	25954	Economy	12100.00
0005433960523	25954	Economy	12100.00
0005433985666	25954	Economy	12100.00
0005433985663	25954	Economy	12100.00
0005433985676	25954	Economy	12100.00
0005433960548	25954	Economy	12100.00
0005433960549	25954	Economy	12100.00
0005433960515	25954	Economy	12100.00
0005433960510	25954	Economy	12100.00
0005433960544	25954	Economy	12100.00
0005433960507	25954	Economy	12100.00
0005433960528	25954	Economy	12100.00
0005433985673	25954	Economy	12100.00
0005433985678	25954	Economy	12100.00
0005433960530	25954	Economy	12100.00
0005433960565	25954	Economy	12100.00
0005433960522	25954	Economy	12100.00
0005433960541	25954	Economy	12100.00
0005433985652	25954	Economy	12100.00
0005433960534	25954	Economy	12100.00
0005433960570	25954	Economy	12100.00
0005433985668	25954	Economy	12100.00
0005433985667	25954	Economy	12100.00
0005434480193	975	Economy	25400.00
0005433165748	975	Economy	25400.00
0005434480203	975	Economy	25400.00
0005434480200	975	Economy	25400.00
0005433165779	975	Economy	23100.00
0005434480202	975	Economy	23100.00
0005433165692	975	Economy	23100.00
0005434480209	975	Economy	23100.00
0005432269481	975	Economy	23100.00
0005432269480	975	Economy	23100.00
0005434480191	975	Economy	23100.00
0005434480189	975	Economy	23100.00
0005434480206	975	Economy	23100.00
0005434480198	975	Economy	23100.00
0005434480186	975	Economy	23100.00
0005434480199	975	Economy	23100.00
0005434480204	975	Economy	23100.00
0005432269482	975	Economy	23100.00
0005434480208	975	Economy	23100.00
0005434480207	975	Economy	23100.00
0005433165778	975	Economy	23100.00
0005433165709	975	Economy	23100.00
0005433165693	975	Economy	23100.00
0005433165757	975	Economy	23100.00
0005434480197	975	Economy	23100.00
0005434480195	975	Economy	23100.00
0005434480201	975	Economy	23100.00
0005434480190	975	Economy	23100.00
0005434480210	975	Economy	23100.00
0005433165712	975	Economy	23100.00
0005433165702	975	Economy	23100.00
0005433165714	975	Economy	23100.00
0005434480205	975	Economy	23100.00
0005434480211	975	Economy	23100.00
0005433165736	975	Economy	23100.00
0005433165749	975	Economy	23100.00
0005434480188	975	Economy	23100.00
0005433165733	975	Economy	23100.00
0005433165711	975	Economy	23100.00
0005432269479	975	Economy	23100.00
0005434480194	975	Economy	23100.00
0005434480192	975	Economy	23100.00
0005434480187	975	Economy	23100.00
0005434480196	975	Economy	23100.00
0005433165832	16584	Economy	25400.00
0005433165830	16584	Economy	25400.00
0005434480022	16584	Economy	25400.00
0005433165837	16584	Economy	23100.00
0005434479922	16584	Economy	23100.00
0005433165838	16584	Economy	23100.00
0005434479985	16584	Economy	23100.00
0005434480025	16584	Economy	23100.00
0005433165840	16584	Economy	23100.00
0005434480000	16584	Economy	23100.00
0005433165834	16584	Economy	23100.00
0005434480053	16584	Economy	23100.00
0005434480089	16584	Economy	23100.00
0005433165843	16584	Economy	23100.00
0005433165842	16584	Economy	23100.00
0005434479989	16584	Economy	23100.00
0005433165839	16584	Economy	23100.00
0005434480010	16584	Economy	23100.00
0005434479938	16584	Economy	23100.00
0005433165829	16584	Economy	23100.00
0005434479990	16584	Economy	23100.00
0005434480009	16584	Economy	23100.00
0005433165836	16584	Economy	23100.00
0005434480013	16584	Economy	23100.00
0005434480039	16584	Economy	23100.00
0005433165831	16584	Economy	23100.00
0005433165833	16584	Economy	23100.00
0005433165835	16584	Economy	23100.00
0005433165841	16584	Economy	23100.00
0005435386479	10339	Economy	17000.00
0005435149938	10339	Economy	17000.00
0005435142498	10339	Economy	15400.00
0005433289763	10339	Economy	15400.00
0005435149940	10339	Economy	15400.00
0005435149946	10339	Economy	15400.00
0005433289753	10339	Economy	15400.00
0005435386454	10339	Economy	15400.00
0005435142490	10339	Economy	15400.00
0005433289747	10339	Economy	15400.00
0005435149949	10339	Economy	15400.00
0005435142491	10339	Economy	15400.00
0005435149944	10339	Economy	15400.00
0005435149945	10339	Economy	15400.00
0005435386483	10339	Economy	15400.00
0005435386463	10339	Economy	15400.00
0005435386480	10339	Economy	15400.00
0005435142500	10339	Economy	15400.00
0005435142494	10339	Economy	15400.00
0005435149947	10339	Economy	15400.00
0005435142502	10339	Economy	15400.00
0005435149943	10339	Economy	15400.00
0005433289727	10339	Economy	15400.00
0005435142501	10339	Economy	15400.00
0005435149939	10339	Economy	15400.00
0005435149937	10339	Economy	15400.00
0005435142496	10339	Economy	15400.00
0005435142492	10339	Economy	15400.00
0005435386466	10339	Economy	15400.00
0005435149942	10339	Economy	15400.00
0005435386467	10339	Economy	15400.00
0005435149941	10339	Economy	15400.00
0005435142495	10339	Economy	15400.00
0005435149948	10339	Economy	15400.00
0005433289762	10339	Economy	15400.00
0005435142488	10339	Economy	15400.00
0005435386482	10339	Economy	15400.00
0005435142493	10339	Economy	15400.00
0005435142497	10339	Economy	15400.00
0005435142489	10339	Economy	15400.00
0005435142499	10339	Economy	15400.00
0005435386543	21944	Economy	17000.00
0005435149815	21944	Economy	17000.00
0005435142351	21944	Economy	17000.00
0005435149835	21944	Economy	17000.00
0005433289818	21944	Economy	15400.00
0005435142407	21944	Economy	15400.00
0005435149896	21944	Economy	15400.00
0005433289813	21944	Economy	15400.00
0005435142359	21944	Economy	15400.00
0005435149889	21944	Economy	15400.00
0005435142352	21944	Economy	15400.00
0005435149837	21944	Economy	15400.00
0005435142471	21944	Economy	15400.00
0005435149897	21944	Economy	15400.00
0005435142406	21944	Economy	15400.00
0005435142429	21944	Economy	15400.00
0005435149881	21944	Economy	15400.00
0005435386544	21944	Economy	15400.00
0005435386545	21944	Economy	15400.00
0005435142355	21944	Economy	15400.00
0005433289817	21944	Economy	15400.00
0005435142360	21944	Economy	15400.00
0005435142470	21944	Economy	15400.00
0005435386542	21944	Economy	15400.00
0005435142430	21944	Economy	15400.00
0005435386541	21944	Economy	15400.00
0005435142348	21944	Economy	15400.00
0005435386540	21944	Economy	15400.00
0005435149836	21944	Economy	15400.00
0005435149890	21944	Economy	15400.00
0005435142385	21944	Economy	15400.00
0005435386539	21944	Economy	15400.00
0005433289819	21944	Economy	15400.00
0005433289816	21944	Economy	15400.00
0005435149831	21944	Economy	15400.00
0005433289815	21944	Economy	15400.00
0005435142413	21944	Economy	15400.00
0005435142356	21944	Economy	15400.00
0005435149834	21944	Economy	15400.00
0005435142361	21944	Economy	15400.00
0005435149797	21944	Economy	15400.00
0005435149830	21944	Economy	15400.00
0005433289814	21944	Economy	15400.00
0005435142340	21944	Economy	15400.00
0005435501992	11217	Business	57200.00
0005435545630	11217	Business	57200.00
0005435501962	11217	Business	57200.00
0005435502021	11217	Business	57200.00
0005435528959	11217	Business	57200.00
0005435501973	11217	Business	57200.00
0005435528933	11217	Business	57200.00
0005435502041	11217	Business	57200.00
0005435545628	11217	Business	57200.00
0005435502028	11217	Economy	19100.00
0005435502036	11217	Economy	19100.00
0005435502053	11217	Economy	19100.00
0005435319482	11217	Economy	19100.00
0005435502052	11217	Economy	19100.00
0005434573269	11217	Economy	19100.00
0005435319484	11217	Economy	19100.00
0005435528995	11217	Economy	21000.00
0005435502037	11217	Economy	21000.00
0005434573273	11217	Economy	21000.00
0005434573271	11217	Economy	19100.00
0005435501950	11217	Economy	19100.00
0005435545649	11217	Economy	19100.00
0005435528965	11217	Economy	19100.00
0005434573268	11217	Economy	19100.00
0005435319462	11217	Economy	19100.00
0005434573261	11217	Economy	19100.00
0005435528958	11217	Economy	19100.00
0005435319450	11217	Economy	19100.00
0005435502100	11217	Economy	19100.00
0005435528889	11217	Economy	19100.00
0005435502040	11217	Economy	19100.00
0005435545648	11217	Economy	19100.00
0005434573263	11217	Economy	19100.00
0005434573267	11217	Economy	19100.00
0005435502063	11217	Economy	19100.00
0005435528879	11217	Economy	19100.00
0005435502067	11217	Economy	19100.00
0005435528994	11217	Economy	19100.00
0005435501960	11217	Economy	19100.00
0005435528973	11217	Economy	19100.00
0005435502059	11217	Economy	19100.00
0005435502018	11217	Economy	19100.00
0005435545625	11217	Economy	19100.00
0005435529077	11217	Economy	19100.00
0005434573265	11217	Economy	19100.00
0005435501984	11217	Economy	19100.00
0005435501972	11217	Economy	19100.00
0005435319466	11217	Economy	19100.00
0005435502101	11217	Economy	19100.00
0005435528991	11217	Economy	19100.00
0005435502034	11217	Economy	19100.00
0005435528981	11217	Economy	19100.00
0005434573266	11217	Economy	19100.00
0005434573262	11217	Economy	19100.00
0005435319442	11217	Economy	19100.00
0005435528880	11217	Economy	19100.00
0005435528941	11217	Economy	19100.00
0005435528972	11217	Economy	19100.00
0005435528892	11217	Economy	19100.00
0005435502060	11217	Economy	19100.00
0005434573270	11217	Economy	19100.00
0005435319439	11217	Economy	19100.00
0005435319443	11217	Economy	19100.00
0005434573264	11217	Economy	19100.00
0005435501974	11217	Economy	19100.00
0005435529076	11217	Economy	19100.00
0005435319465	11217	Economy	19100.00
0005435501961	11217	Economy	19100.00
0005435319483	11217	Economy	19100.00
0005435528966	11217	Economy	19100.00
0005435502093	11217	Economy	19100.00
0005435319440	11217	Economy	19100.00
0005435502062	11217	Economy	19100.00
0005434573272	11217	Economy	19100.00
0005435528967	11217	Economy	19100.00
0005435545629	11217	Economy	19100.00
0005435502102	11217	Economy	19100.00
0005435502181	20922	Business	57200.00
0005434573115	20922	Business	57200.00
0005435502187	20922	Business	57200.00
0005435517801	20922	Business	57200.00
0005434573105	20922	Business	57200.00
0005435517812	20922	Business	57200.00
0005435502196	20922	Business	57200.00
0005435502190	20922	Business	57200.00
0005435319535	20922	Business	57200.00
0005434573148	20922	Economy	19100.00
0005435319537	20922	Economy	19100.00
0005435502178	20922	Economy	19100.00
0005435517808	20922	Economy	19100.00
0005435502175	20922	Economy	19100.00
0005435502188	20922	Economy	19100.00
0005435517800	20922	Economy	19100.00
0005435517802	20922	Economy	19100.00
0005435517816	20922	Economy	21000.00
0005435502184	20922	Economy	21000.00
0005435517807	20922	Economy	21000.00
0005435508293	20922	Economy	21000.00
0005435517811	20922	Economy	19100.00
0005435508291	20922	Economy	19100.00
0005435517806	20922	Economy	19100.00
0005434573139	20922	Economy	19100.00
0005435319532	20922	Economy	19100.00
0005435502192	20922	Economy	19100.00
0005435508290	20922	Economy	19100.00
0005435517804	20922	Economy	19100.00
0005435502179	20922	Economy	19100.00
0005435502189	20922	Economy	19100.00
0005435502177	20922	Economy	19100.00
0005435319534	20922	Economy	19100.00
0005435508287	20922	Economy	19100.00
0005435508292	20922	Economy	19100.00
0005435502176	20922	Economy	19100.00
0005435508295	20922	Economy	19100.00
0005435517813	20922	Economy	19100.00
0005435517815	20922	Economy	19100.00
0005435508288	20922	Economy	19100.00
0005435502195	20922	Economy	19100.00
0005435508294	20922	Economy	19100.00
0005435502182	20922	Economy	19100.00
0005435502191	20922	Economy	19100.00
0005435517817	20922	Economy	19100.00
0005435319539	20922	Economy	19100.00
0005435502180	20922	Economy	19100.00
0005435319540	20922	Economy	19100.00
0005435517803	20922	Economy	19100.00
0005432291915	20922	Economy	19100.00
0005435517805	20922	Economy	19100.00
0005435502183	20922	Economy	19100.00
0005435502185	20922	Economy	19100.00
0005435502194	20922	Economy	19100.00
0005435502186	20922	Economy	19100.00
0005435508286	20922	Economy	19100.00
0005435319533	20922	Economy	19100.00
0005435508296	20922	Economy	19100.00
0005435517810	20922	Economy	19100.00
0005432291916	20922	Economy	19100.00
0005435517814	20922	Economy	19100.00
0005435517809	20922	Economy	19100.00
0005435319538	20922	Economy	19100.00
0005434573147	20922	Economy	19100.00
0005435508289	20922	Economy	19100.00
0005435502193	20922	Economy	19100.00
0005434573106	20922	Economy	19100.00
0005435319536	20922	Economy	19100.00
0005432692672	3029	Business	10300.00
0005432692719	3029	Business	10300.00
0005432692550	3029	Business	10300.00
0005432692602	3029	Business	10300.00
0005432692678	3029	Economy	3400.00
0005432692706	3029	Economy	3400.00
0005432692540	3029	Economy	3400.00
0005432692720	3029	Economy	3800.00
0005432692735	3029	Economy	3400.00
0005432692614	3029	Economy	3400.00
0005432692676	3029	Economy	3400.00
0005432692588	3029	Economy	3400.00
0005432692679	3029	Economy	3400.00
0005432692587	3029	Economy	3400.00
0005432692704	3029	Economy	3400.00
0005432692803	3029	Economy	3400.00
0005432692677	3029	Economy	3400.00
0005432692667	3029	Economy	3400.00
0005432692619	3029	Economy	3400.00
0005432692548	3029	Economy	3400.00
0005432692668	3029	Economy	3400.00
0005432692599	3029	Economy	3400.00
0005432692600	3029	Economy	3400.00
0005432692736	3029	Economy	3400.00
0005432692689	3029	Economy	3400.00
0005432692549	3029	Economy	3400.00
0005432692673	3029	Economy	3400.00
0005432692690	3029	Economy	3400.00
0005432692711	3029	Economy	3400.00
0005433194830	3031	Business	10300.00
0005432706631	3031	Business	10300.00
0005432217760	3031	Business	10300.00
0005432706647	3031	Business	10300.00
0005432706624	3031	Business	10300.00
0005433123619	3031	Business	10300.00
0005432880676	3031	Economy	3400.00
0005432706642	3031	Economy	3400.00
0005432706636	3031	Economy	3400.00
0005432217761	3031	Economy	3400.00
0005433123603	3031	Economy	3400.00
0005432706622	3031	Economy	3400.00
0005433123684	3031	Economy	3800.00
0005432880571	3031	Economy	3400.00
0005432706639	3031	Economy	3400.00
0005432880626	3031	Economy	3400.00
0005432880592	3031	Economy	3400.00
0005432706633	3031	Economy	3400.00
0005433123611	3031	Economy	3400.00
0005432880556	3031	Economy	3400.00
0005432706627	3031	Economy	3400.00
0005432706623	3031	Economy	3400.00
0005432880627	3031	Economy	3400.00
0005432706640	3031	Economy	3400.00
0005432706644	3031	Economy	3400.00
0005433123621	3031	Economy	3400.00
0005432217759	3031	Economy	3400.00
0005432706643	3031	Economy	3400.00
0005432706634	3031	Economy	3400.00
0005432706628	3031	Economy	3400.00
0005433123615	3031	Economy	3400.00
0005432706638	3031	Economy	3400.00
0005432706626	3031	Economy	3400.00
0005432706629	3031	Economy	3400.00
0005432880636	3031	Economy	3400.00
0005433123635	3031	Economy	3400.00
0005432706641	3031	Economy	3400.00
0005432706621	3031	Economy	3400.00
0005433123618	3031	Economy	3400.00
0005433123634	3031	Economy	3400.00
0005433123658	3031	Economy	3400.00
0005432880591	3031	Economy	3400.00
0005433123620	3031	Economy	3400.00
0005433123685	3031	Economy	3400.00
0005433123660	3031	Economy	3400.00
0005433123650	3031	Economy	3400.00
0005432706637	3031	Economy	3400.00
0005433194821	3031	Economy	3400.00
0005432706632	3031	Economy	3400.00
0005433194829	3031	Economy	3400.00
0005433123645	3031	Economy	3400.00
0005432706646	3031	Economy	3400.00
0005432706625	3031	Economy	3400.00
0005432880665	3031	Economy	3400.00
0005432706635	3031	Economy	3400.00
0005432706630	3031	Economy	3400.00
0005432706645	3031	Economy	3400.00
0005432880735	29996	Business	10300.00
0005433123814	29996	Business	10300.00
0005432706511	29996	Business	10300.00
0005432692923	29996	Business	10300.00
0005433123822	29996	Business	10300.00
0005432880738	29996	Business	10300.00
0005433194845	29996	Business	10300.00
0005432706415	29996	Business	10300.00
0005432692933	29996	Business	10300.00
0005432706461	29996	Business	10300.00
0005433123810	29996	Business	10300.00
0005432706485	29996	Business	10300.00
0005433123817	29996	Economy	3400.00
0005432692936	29996	Economy	3400.00
0005433123824	29996	Economy	3400.00
0005432706385	29996	Economy	3400.00
0005433194848	29996	Economy	3400.00
0005433123804	29996	Economy	3400.00
0005432692928	29996	Economy	3400.00
0005433123820	29996	Economy	3400.00
0005432880736	29996	Economy	3400.00
0005433123806	29996	Economy	3400.00
0005432692924	29996	Economy	3800.00
0005432880734	29996	Economy	3800.00
0005433194846	29996	Economy	3800.00
0005432692929	29996	Economy	3800.00
0005433123815	29996	Economy	3800.00
0005432692931	29996	Economy	3400.00
0005433123813	29996	Economy	3400.00
0005432706476	29996	Economy	3400.00
0005432706474	29996	Economy	3400.00
0005432692927	29996	Economy	3400.00
0005432706387	29996	Economy	3400.00
0005432692921	29996	Economy	3400.00
0005432692926	29996	Economy	3400.00
0005432880740	29996	Economy	3400.00
0005432880744	29996	Economy	3400.00
0005432692908	29996	Economy	3400.00
0005433123818	29996	Economy	3400.00
0005432692907	29996	Economy	3400.00
0005432692918	29996	Economy	3400.00
0005432692932	29996	Economy	3400.00
0005432692917	29996	Economy	3400.00
0005432706481	29996	Economy	3400.00
0005432880739	29996	Economy	3400.00
0005432706322	29996	Economy	3400.00
0005432692920	29996	Economy	3400.00
0005433123821	29996	Economy	3400.00
0005433194844	29996	Economy	3400.00
0005432706378	29996	Economy	3400.00
0005432692916	29996	Economy	3400.00
0005432692935	29996	Economy	3400.00
0005432692915	29996	Economy	3400.00
0005432706512	29996	Economy	3400.00
0005432706337	29996	Economy	3400.00
0005433123826	29996	Economy	3400.00
0005432692922	29996	Economy	3400.00
0005432880742	29996	Economy	3400.00
0005432692912	29996	Economy	3400.00
0005432706412	29996	Economy	3400.00
0005432706366	29996	Economy	3400.00
0005432692909	29996	Economy	3400.00
0005432706384	29996	Economy	3400.00
0005433123811	29996	Economy	3400.00
0005432692913	29996	Economy	3400.00
0005432880737	29996	Economy	3400.00
0005432880741	29996	Economy	3400.00
0005433194849	29996	Economy	3400.00
0005432692906	29996	Economy	3400.00
0005433123823	29996	Economy	3400.00
0005433194850	29996	Economy	3400.00
0005432880743	29996	Economy	3400.00
0005432692934	29996	Economy	3400.00
0005432692911	29996	Economy	3400.00
0005433123825	29996	Economy	3400.00
0005433123812	29996	Economy	3400.00
0005433194843	29996	Economy	3400.00
0005433123809	29996	Economy	3400.00
0005432706454	29996	Economy	3400.00
0005433123819	29996	Economy	3400.00
0005433123807	29996	Economy	3400.00
0005432880732	29996	Economy	3400.00
0005432706462	29996	Economy	3400.00
0005432692925	29996	Economy	3400.00
0005433123816	29996	Economy	3400.00
0005433123808	29996	Economy	3400.00
0005432692910	29996	Economy	3400.00
0005432706429	29996	Economy	3400.00
0005432692930	29996	Economy	3400.00
0005432692919	29996	Economy	3400.00
0005432880733	29996	Economy	3400.00
0005433123805	29996	Economy	3400.00
0005432880745	29996	Economy	3400.00
0005433194847	29996	Economy	3400.00
0005432706321	29996	Economy	3400.00
0005432692914	29996	Economy	3400.00
0005434988669	23650	Economy	4000.00
0005434979619	23650	Economy	4000.00
0005434979593	23650	Economy	4000.00
0005434979620	23650	Economy	3600.00
0005434979617	23650	Economy	3600.00
0005434988677	23650	Economy	3600.00
0005434979608	23650	Economy	3600.00
0005434979612	23650	Economy	3600.00
0005434988676	23650	Economy	3600.00
0005434979610	23650	Economy	3600.00
0005434988673	23650	Economy	3600.00
0005434979600	23650	Economy	3600.00
0005434979611	23650	Economy	3600.00
0005434979613	23650	Economy	3600.00
0005434979616	23650	Economy	3600.00
0005434979609	23650	Economy	3600.00
0005434979598	23650	Economy	3600.00
0005434988670	23650	Economy	3600.00
0005434979594	23650	Economy	3600.00
0005434979614	23650	Economy	3600.00
0005434979606	23650	Economy	3600.00
0005434979618	23650	Economy	3600.00
0005434979592	23650	Economy	3600.00
0005434979615	23650	Economy	3600.00
0005434979604	23650	Economy	3600.00
0005434979599	23650	Economy	3600.00
0005434979603	23650	Economy	3600.00
0005434988675	23650	Economy	3600.00
0005434979605	23650	Economy	3600.00
0005434988668	23650	Economy	3600.00
0005434988671	23650	Economy	3600.00
0005434979601	23650	Economy	3600.00
0005434979621	23650	Economy	3600.00
0005434979602	23650	Economy	3600.00
0005434979597	23650	Economy	3600.00
0005434988667	23650	Economy	3600.00
0005434979596	23650	Economy	3600.00
0005434979595	23650	Economy	3600.00
0005434979607	23650	Economy	3600.00
0005434988674	23650	Economy	3600.00
0005434988672	23650	Economy	3600.00
0005434988597	27573	Economy	4000.00
0005434979287	27573	Economy	4000.00
0005434988583	27573	Economy	4000.00
0005434979255	27573	Economy	3600.00
0005434979486	27573	Economy	3600.00
0005434988587	27573	Economy	3600.00
0005434988585	27573	Economy	3600.00
0005434979261	27573	Economy	3600.00
0005434979356	27573	Economy	3600.00
0005434988576	27573	Economy	3600.00
0005434979368	27573	Economy	3600.00
0005434979393	27573	Economy	3600.00
0005434988584	27573	Economy	3600.00
0005434979262	27573	Economy	3600.00
0005434988557	27573	Economy	3600.00
0005434988582	27573	Economy	3600.00
0005434979330	27573	Economy	3600.00
0005434979436	27573	Economy	3600.00
0005434979312	27573	Economy	3600.00
0005434979377	27573	Economy	3600.00
0005434979366	27573	Economy	3600.00
0005434979476	27573	Economy	3600.00
0005434988594	27573	Economy	3600.00
0005434979434	27573	Economy	3600.00
0005434988575	27573	Economy	3600.00
0005434979435	27573	Economy	3600.00
0005434979306	27573	Economy	3600.00
0005434988570	27573	Economy	3600.00
0005434979350	27573	Economy	3600.00
0005434979305	27573	Economy	3600.00
0005434979442	27573	Economy	3600.00
0005434988571	27573	Economy	3600.00
0005434988586	27573	Economy	3600.00
0005434979365	27573	Economy	3600.00
0005434979311	27573	Economy	3600.00
0005434979328	27573	Economy	3600.00
0005434988598	27573	Economy	3600.00
0005434979477	27573	Economy	3600.00
0005434302433	10251	Economy	19700.00
0005434302434	10251	Economy	19700.00
0005433113501	10251	Economy	19700.00
0005434302431	10251	Economy	19700.00
0005434302855	10251	Economy	19700.00
0005433111473	10251	Economy	19700.00
0005434302432	10251	Economy	19700.00
0005434302430	10251	Economy	19700.00
0005433113525	19624	Economy	19700.00
0005434302397	19624	Economy	19700.00
0005434302386	19624	Economy	19700.00
0005434302394	19624	Economy	19700.00
0005433113524	19624	Economy	19700.00
0005434302396	19624	Economy	19700.00
0005433113523	19624	Economy	19700.00
0005434302387	19624	Economy	19700.00
0005435925116	3575	Business	26900.00
0005435068813	3575	Business	26900.00
0005435068833	3575	Business	26900.00
0005435068842	3575	Business	26900.00
0005435939858	3575	Business	26900.00
0005435068799	3575	Business	26900.00
0005435068820	3575	Business	26900.00
0005435068807	3575	Business	26900.00
0005435068804	3575	Business	26900.00
0005435068817	3575	Economy	9000.00
0005435068800	3575	Economy	9000.00
0005435068811	3575	Economy	9000.00
0005435068844	3575	Economy	9000.00
0005435068816	3575	Economy	9000.00
0005435068837	3575	Economy	9000.00
0005435068846	3575	Economy	9000.00
0005435068808	3575	Economy	9900.00
0005435068805	3575	Economy	9900.00
0005435068834	3575	Economy	9900.00
0005435068798	3575	Economy	9000.00
0005435068795	3575	Economy	9000.00
0005435068823	3575	Economy	9000.00
0005435068827	3575	Economy	9000.00
0005435925079	3575	Economy	9000.00
0005435068809	3575	Economy	9000.00
0005435068821	3575	Economy	9000.00
0005435939859	3575	Economy	9000.00
0005435925078	3575	Economy	9000.00
0005435925087	3575	Economy	9000.00
0005435068828	3575	Economy	9000.00
0005435068801	3575	Economy	9000.00
0005435068824	3575	Economy	9000.00
0005435068829	3575	Economy	9000.00
0005435925112	3575	Economy	9000.00
0005435068819	3575	Economy	9000.00
0005435068818	3575	Economy	9000.00
0005435068832	3575	Economy	9000.00
0005435068845	3575	Economy	9000.00
0005435068838	3575	Economy	9000.00
0005435068796	3575	Economy	9000.00
0005435925057	3575	Economy	9000.00
0005435068841	3575	Economy	9000.00
0005435925113	3575	Economy	9000.00
0005435068830	3575	Economy	9000.00
0005435925083	3575	Economy	9000.00
0005435068815	3575	Economy	9000.00
0005435925058	3575	Economy	9000.00
0005435068839	3575	Economy	9000.00
0005435068802	3575	Economy	9000.00
0005435068810	3575	Economy	9000.00
0005435068794	3575	Economy	9000.00
0005435068806	3575	Economy	9000.00
0005435925122	3575	Economy	9000.00
0005435068831	3575	Economy	9000.00
0005435718918	3575	Economy	9000.00
0005435068822	3575	Economy	9000.00
0005435925117	3575	Economy	9000.00
0005435068840	3575	Economy	9000.00
0005435068825	3575	Economy	9000.00
0005435068836	3575	Economy	9000.00
0005435068835	3575	Economy	9000.00
0005435068843	3575	Economy	9000.00
0005435925084	3575	Economy	9000.00
0005435718919	3575	Economy	9000.00
0005435939860	3575	Economy	9000.00
0005435068803	3575	Economy	9000.00
0005435068797	3575	Economy	9000.00
0005435068826	3575	Economy	9000.00
0005435068814	3575	Economy	9000.00
0005435068812	3575	Economy	9000.00
0005435068327	15331	Business	26900.00
0005435925205	15331	Business	26900.00
0005435925213	15331	Business	26900.00
0005435068388	15331	Business	26900.00
0005435925204	15331	Business	26900.00
0005435068393	15331	Business	26900.00
0005435068400	15331	Business	26900.00
0005435068378	15331	Business	26900.00
0005435068352	15331	Business	26900.00
0005435068280	15331	Business	26900.00
0005435068377	15331	Business	26900.00
0005435068417	15331	Economy	9000.00
0005435925217	15331	Economy	9000.00
0005435068433	15331	Economy	9000.00
0005435925216	15331	Economy	9000.00
0005435925209	15331	Economy	9000.00
0005435068278	15331	Economy	9000.00
0005435068318	15331	Economy	9000.00
0005435068324	15331	Economy	9000.00
0005435068452	15331	Economy	9000.00
0005435068293	15331	Economy	9900.00
0005435925210	15331	Economy	9900.00
0005435068196	15331	Economy	9900.00
0005435068247	15331	Economy	9000.00
0005435068242	15331	Economy	9000.00
0005435068205	15331	Economy	9000.00
0005435925214	15331	Economy	9000.00
0005435068439	15331	Economy	9000.00
0005435068197	15331	Economy	9000.00
0005435068195	15331	Economy	9000.00
0005435939871	15331	Economy	9000.00
0005435068274	15331	Economy	9000.00
0005435068328	15331	Economy	9000.00
0005435068198	15331	Economy	9000.00
0005435068416	15331	Economy	9000.00
0005435068451	15331	Economy	9000.00
0005435068243	15331	Economy	9000.00
0005435068326	15331	Economy	9000.00
0005435925218	15331	Economy	9000.00
0005435068206	15331	Economy	9000.00
0005435925207	15331	Economy	9000.00
0005435068432	15331	Economy	9000.00
0005435068300	15331	Economy	9000.00
0005435068313	15331	Economy	9000.00
0005435068380	15331	Economy	9000.00
0005435925206	15331	Economy	9000.00
0005435068287	15331	Economy	9000.00
0005435068384	15331	Economy	9000.00
0005435068501	15331	Economy	9000.00
0005435068412	15331	Economy	9000.00
0005435925215	15331	Economy	9000.00
0005435068482	15331	Economy	9000.00
0005435068347	15331	Economy	9000.00
0005435925211	15331	Economy	9000.00
0005435068481	15331	Economy	9000.00
0005435068476	15331	Economy	9000.00
0005435068279	15331	Economy	9000.00
0005435068475	15331	Economy	9000.00
0005435068227	15331	Economy	9000.00
0005435068168	15331	Economy	9000.00
0005435068246	15331	Economy	9000.00
0005435068283	15331	Economy	9000.00
0005435068245	15331	Economy	9000.00
0005435939872	15331	Economy	9000.00
0005435068319	15331	Economy	9000.00
0005435068175	15331	Economy	9000.00
0005435068337	15331	Economy	9000.00
0005435068500	15331	Economy	9000.00
0005435068250	15331	Economy	9000.00
0005435068372	15331	Economy	9000.00
0005435925212	15331	Economy	9000.00
0005435925208	15331	Economy	9000.00
0005435068282	15331	Economy	9000.00
0005432658581	18219	Economy	5900.00
0005432659696	18219	Economy	5900.00
0005432658579	18219	Economy	5900.00
0005432660806	18219	Economy	5900.00
0005432658580	18219	Economy	5900.00
0005432659695	18219	Economy	5900.00
0005432659694	18219	Economy	5900.00
0005432660807	18219	Economy	5900.00
0005432667421	26370	Economy	5900.00
0005432667418	26370	Economy	5900.00
0005432667422	26370	Economy	5900.00
0005433101439	25	Business	20000.00
0005432919571	25	Business	20000.00
0005433101389	25	Business	20000.00
0005433101357	25	Business	20000.00
0005433101415	25	Business	20000.00
0005433101292	25	Business	20000.00
0005432919638	25	Business	20000.00
0005433101360	25	Business	20000.00
0005433101398	25	Business	20000.00
0005433101335	25	Business	20000.00
0005432919621	25	Business	20000.00
0005432919542	25	Business	20000.00
0005433101387	25	Business	20000.00
0005433101427	25	Business	20000.00
0005433101416	25	Business	20000.00
0005433101457	25	Business	20000.00
0005433101401	25	Business	20000.00
0005432901459	25	Business	20000.00
0005432919632	25	Business	20000.00
0005433101458	25	Business	20000.00
0005432919518	25	Business	20000.00
0005433101409	25	Economy	7300.00
0005433101237	25	Economy	7300.00
0005433101177	25	Economy	7300.00
0005433101417	25	Economy	7300.00
0005433101435	25	Economy	7300.00
0005432901414	25	Economy	6700.00
0005432677523	25	Economy	6700.00
0005433101341	25	Economy	6700.00
0005433101324	25	Economy	6700.00
0005433101195	25	Economy	6700.00
0005432901412	25	Economy	6700.00
0005432901401	25	Economy	6700.00
0005433101268	25	Economy	6700.00
0005433101358	25	Economy	6700.00
0005432919601	25	Economy	6700.00
0005433101399	25	Economy	6700.00
0005433101352	25	Economy	6700.00
0005433101414	25	Economy	6700.00
0005432901399	25	Economy	6700.00
0005433101168	25	Economy	6700.00
0005433101390	25	Economy	6700.00
0005432901376	25	Economy	6700.00
0005432901315	25	Economy	6700.00
0005432901348	25	Economy	6700.00
0005433101291	25	Economy	6700.00
0005433101421	25	Economy	6700.00
0005432919631	25	Economy	6700.00
0005432901331	25	Economy	6700.00
0005433101339	25	Economy	6700.00
0005432901387	25	Economy	6700.00
0005432901400	25	Economy	6700.00
0005433101422	25	Economy	6700.00
0005432901367	25	Economy	6700.00
0005432919554	25	Economy	6700.00
0005432919583	25	Economy	6700.00
0005433101284	25	Economy	6700.00
0005432901413	25	Economy	6700.00
0005432901349	25	Economy	6700.00
0005433101385	25	Economy	6700.00
0005432919576	25	Economy	6700.00
0005432919517	25	Economy	6700.00
0005432901368	25	Economy	6700.00
0005433101403	25	Economy	7300.00
0005432919618	25	Economy	6700.00
0005433101169	25	Economy	7300.00
0005433101446	25	Economy	7300.00
0005433101413	25	Economy	6700.00
0005433101375	25	Economy	6700.00
0005432919653	25	Economy	6700.00
0005432919652	25	Economy	6700.00
0005432919512	25	Economy	6700.00
0005432919619	25	Economy	6700.00
0005433101426	25	Economy	6700.00
0005433101405	25	Economy	6700.00
0005433101382	25	Economy	6700.00
0005433101383	25	Economy	6700.00
0005433101311	25	Economy	6700.00
0005433101442	25	Economy	6700.00
0005433101365	25	Economy	6700.00
0005433101359	25	Economy	6700.00
0005433101312	25	Economy	6700.00
0005433101374	25	Economy	6700.00
0005432677518	25	Economy	6700.00
0005432157482	25	Economy	6700.00
0005432919537	25	Economy	6700.00
0005433101441	25	Economy	6700.00
0005432919538	25	Economy	6700.00
0005433101164	25	Economy	6700.00
0005432901347	25	Economy	6700.00
0005433101430	25	Economy	6700.00
0005433101386	25	Economy	6700.00
0005433101438	25	Economy	6700.00
0005432901391	25	Economy	6700.00
0005433101402	25	Economy	6700.00
0005433101434	25	Economy	6700.00
0005432901342	25	Economy	6700.00
0005433101334	25	Economy	6700.00
0005433101388	25	Economy	6700.00
0005433101325	25	Economy	6700.00
0005432919552	25	Economy	6700.00
0005433101340	25	Economy	6700.00
0005433101242	25	Economy	6700.00
0005432901332	25	Economy	6700.00
0005433101456	25	Economy	6700.00
0005433101342	25	Economy	6700.00
0005433101368	25	Economy	6700.00
0005432901408	25	Economy	6700.00
0005433101425	25	Economy	6700.00
0005433101310	25	Economy	6700.00
0005432919513	25	Economy	6700.00
0005433101455	25	Economy	6700.00
0005432919555	25	Economy	6700.00
0005433101322	25	Economy	6700.00
0005432919511	25	Economy	6700.00
0005432261694	38	Business	20000.00
0005432817304	38	Business	20000.00
0005432261668	38	Business	20000.00
0005432817324	38	Business	20000.00
0005432207647	38	Business	20000.00
0005432817318	38	Business	20000.00
0005432261674	38	Business	20000.00
0005432288970	38	Business	20000.00
0005432261651	38	Business	20000.00
0005432261687	38	Business	20000.00
0005432261682	38	Economy	6700.00
0005432261660	38	Economy	6700.00
0005432817306	38	Economy	6700.00
0005432817315	38	Economy	6700.00
0005432261662	38	Economy	6700.00
0005432817302	38	Economy	6700.00
0005432261675	38	Economy	6700.00
0005432261661	38	Economy	6700.00
0005432817323	38	Economy	6700.00
0005432261666	38	Economy	6700.00
0005432261659	38	Economy	6700.00
0005432817312	38	Economy	6700.00
0005432756792	38	Economy	6700.00
0005432817311	38	Economy	6700.00
0005432261679	38	Economy	6700.00
0005432261683	38	Economy	6700.00
0005432817328	38	Economy	6700.00
0005432288967	38	Economy	6700.00
0005432261656	38	Economy	6700.00
0005432261678	38	Economy	6700.00
0005432207646	38	Economy	6700.00
0005432261681	38	Economy	6700.00
0005432261691	38	Economy	6700.00
0005432261676	38	Economy	6700.00
0005432817309	38	Economy	6700.00
0005432817329	38	Economy	6700.00
0005432817320	38	Economy	6700.00
0005432261652	38	Economy	6700.00
0005432288968	38	Economy	6700.00
0005432817310	38	Economy	6700.00
0005432288969	38	Economy	6700.00
0005432817316	38	Economy	6700.00
0005432261686	38	Economy	6700.00
0005432261684	38	Economy	7300.00
0005432261672	38	Economy	7300.00
0005432261688	38	Economy	7300.00
0005432261658	38	Economy	6700.00
0005432261673	38	Economy	6700.00
0005432817327	38	Economy	6700.00
0005432261692	38	Economy	6700.00
0005432261665	38	Economy	6700.00
0005432817317	38	Economy	6700.00
0005432817331	38	Economy	6700.00
0005432261657	38	Economy	6700.00
0005432261671	38	Economy	6700.00
0005432817322	38	Economy	6700.00
0005432817330	38	Economy	6700.00
0005432817305	38	Economy	6700.00
0005432261677	38	Economy	6700.00
0005432817325	38	Economy	6700.00
0005432817303	38	Economy	6700.00
0005432261653	38	Economy	6700.00
0005432817319	38	Economy	6700.00
0005432261669	38	Economy	6700.00
0005432261693	38	Economy	6700.00
0005432261680	38	Economy	6700.00
0005432261655	38	Economy	6700.00
0005432817314	38	Economy	6700.00
0005432261649	38	Economy	6700.00
0005432817313	38	Economy	6700.00
0005432261689	38	Economy	6700.00
0005432261650	38	Economy	6700.00
0005432817321	38	Economy	6700.00
0005432261690	38	Economy	6700.00
0005432817307	38	Economy	6700.00
0005432817308	38	Economy	6700.00
0005432261654	38	Economy	6700.00
0005432261667	38	Economy	6700.00
0005432261670	38	Economy	6700.00
0005432817326	38	Economy	6700.00
0005432261685	38	Economy	6700.00
0005432261663	38	Economy	6700.00
0005432261664	38	Economy	6700.00
0005433101892	8031	Business	20000.00
0005433101897	8031	Business	20000.00
0005432020113	8031	Business	20000.00
0005432677554	8031	Business	20000.00
0005432020115	8031	Business	20000.00
0005432919759	8031	Business	20000.00
0005432020123	8031	Business	20000.00
0005432020128	8031	Business	20000.00
0005433101882	8031	Business	20000.00
0005433101858	8031	Business	20000.00
0005432677555	8031	Business	20000.00
0005433101898	8031	Business	20000.00
0005432919756	8031	Business	20000.00
0005433101860	8031	Business	20000.00
0005433101863	8031	Business	20000.00
0005433101870	8031	Business	20000.00
0005433101901	8031	Business	20000.00
0005432919757	8031	Business	20000.00
0005432020119	8031	Economy	7300.00
0005433101853	8031	Economy	7300.00
0005432391985	8031	Economy	7300.00
0005432020116	8031	Economy	6700.00
0005433101896	8031	Economy	6700.00
0005433101873	8031	Economy	6700.00
0005433101889	8031	Economy	6700.00
0005433101883	8031	Economy	6700.00
0005432751509	8031	Economy	6700.00
0005432020122	8031	Economy	6700.00
0005432020132	8031	Economy	6700.00
0005432020120	8031	Economy	6700.00
0005433101869	8031	Economy	6700.00
0005433101887	8031	Economy	6700.00
0005432044511	8031	Economy	6700.00
0005432919753	8031	Economy	6700.00
0005432919742	8031	Economy	6700.00
0005433101846	8031	Economy	6700.00
0005433101876	8031	Economy	6700.00
0005433101872	8031	Economy	6700.00
0005432919743	8031	Economy	6700.00
0005432045604	8031	Economy	6700.00
0005432677553	8031	Economy	6700.00
0005432919751	8031	Economy	6700.00
0005432020111	8031	Economy	6700.00
0005433101862	8031	Economy	6700.00
0005432020130	8031	Economy	6700.00
0005432020131	8031	Economy	6700.00
0005433101886	8031	Economy	6700.00
0005433101854	8031	Economy	6700.00
0005432020126	8031	Economy	6700.00
0005432020112	8031	Economy	6700.00
0005433101850	8031	Economy	6700.00
0005432919755	8031	Economy	6700.00
0005432751511	8031	Economy	6700.00
0005433101871	8031	Economy	6700.00
0005433101865	8031	Economy	6700.00
0005433101844	8031	Economy	6700.00
0005433101884	8031	Economy	6700.00
0005432020118	8031	Economy	6700.00
0005433101888	8031	Economy	6700.00
0005432919754	8031	Economy	6700.00
0005432919752	8031	Economy	6700.00
0005433101893	8031	Economy	6700.00
0005432919750	8031	Economy	6700.00
0005432919739	8031	Economy	6700.00
0005432919747	8031	Economy	6700.00
0005432020133	8031	Economy	7300.00
0005433101864	8031	Economy	6700.00
0005433101878	8031	Economy	7300.00
0005433101875	8031	Economy	7300.00
0005433101895	8031	Economy	6700.00
0005432919749	8031	Economy	6700.00
0005433101843	8031	Economy	6700.00
0005433101879	8031	Economy	7300.00
0005433101866	8031	Economy	6700.00
0005433101851	8031	Economy	6700.00
0005433101868	8031	Economy	6700.00
0005432919748	8031	Economy	6700.00
0005433101894	8031	Economy	6700.00
0005432753284	8031	Economy	6700.00
0005433101899	8031	Economy	6700.00
0005432919738	8031	Economy	6700.00
0005433101856	8031	Economy	6700.00
0005433101900	8031	Economy	6700.00
0005432753285	8031	Economy	6700.00
0005432020110	8031	Economy	6700.00
0005433101861	8031	Economy	6700.00
0005433101845	8031	Economy	6700.00
0005433101881	8031	Economy	6700.00
0005433101877	8031	Economy	6700.00
0005432919740	8031	Economy	6700.00
0005432020121	8031	Economy	6700.00
0005433101848	8031	Economy	6700.00
0005432044509	8031	Economy	6700.00
0005433101885	8031	Economy	6700.00
0005433101855	8031	Economy	6700.00
0005433101847	8031	Economy	6700.00
0005432020135	8031	Economy	6700.00
0005432020109	8031	Economy	6700.00
0005432020125	8031	Economy	6700.00
0005432391984	8031	Economy	6700.00
0005432020114	8031	Economy	6700.00
0005432919744	8031	Economy	6700.00
0005433101859	8031	Economy	6700.00
0005433101857	8031	Economy	6700.00
0005432919745	8031	Economy	6700.00
0005433101867	8031	Economy	6700.00
0005433101849	8031	Economy	6700.00
0005432020129	8031	Economy	6700.00
0005432020127	8031	Economy	6700.00
0005433101852	8031	Economy	6700.00
0005432751510	8031	Economy	6700.00
0005432044510	8031	Economy	6700.00
0005432020134	8031	Economy	6700.00
0005433101890	8031	Economy	6700.00
0005432919758	8031	Economy	6700.00
0005432020124	8031	Economy	6700.00
0005433101891	8031	Economy	6700.00
0005433101880	8031	Economy	6700.00
0005432919746	8031	Economy	6700.00
0005432020117	8031	Economy	6700.00
0005433101874	8031	Economy	6700.00
0005432020108	8031	Economy	6700.00
0005432677552	8031	Economy	6700.00
0005432919741	8031	Economy	6700.00
0005432817104	8033	Business	20000.00
0005432817137	8033	Business	20000.00
0005432901519	8033	Business	20000.00
0005432817085	8033	Business	20000.00
0005432901513	8033	Business	20000.00
0005432901517	8033	Business	20000.00
0005432817114	8033	Economy	7300.00
0005432901521	8033	Economy	6700.00
0005432817151	8033	Economy	6700.00
0005432817037	8033	Economy	6700.00
0005432817007	8033	Economy	6700.00
0005432901514	8033	Economy	6700.00
0005432816986	8033	Economy	6700.00
0005432901511	8033	Economy	6700.00
0005432816974	8033	Economy	6700.00
0005432817172	8033	Economy	6700.00
0005432901525	8033	Economy	6700.00
0005432901512	8033	Economy	6700.00
0005432901524	8033	Economy	6700.00
0005432817129	8033	Economy	6700.00
0005432816985	8033	Economy	6700.00
0005432901518	8033	Economy	6700.00
0005432901509	8033	Economy	7300.00
0005432817016	8033	Economy	6700.00
0005432901520	8033	Economy	6700.00
0005432901522	8033	Economy	6700.00
0005432901516	8033	Economy	6700.00
0005432817070	8033	Economy	6700.00
0005432817130	8033	Economy	6700.00
0005432901523	8033	Economy	6700.00
0005432817069	8033	Economy	6700.00
0005432817023	8033	Economy	6700.00
0005432901510	8033	Economy	6700.00
0005432901515	8033	Economy	6700.00
0005432901526	8033	Economy	6700.00
0005432002065	8033	Economy	6700.00
0005434175701	9667	Economy	6900.00
0005433870720	9667	Economy	6900.00
0005434175697	9667	Economy	6900.00
0005433870718	9667	Economy	6900.00
0005434175699	9667	Economy	6900.00
0005433870719	9667	Economy	6900.00
0005434175696	9667	Economy	6900.00
0005433870704	32370	Economy	6900.00
0005433870703	32370	Economy	6900.00
0005433870696	32370	Economy	6900.00
0005433870699	32370	Economy	6900.00
0005434175731	32370	Economy	6900.00
0005434175729	32370	Economy	6900.00
0005433870692	32370	Economy	6900.00
0005433870697	32370	Economy	6900.00
0005433870691	32370	Economy	6900.00
0005433870698	32370	Economy	6900.00
0005434175732	32370	Economy	6900.00
0005434175730	32370	Economy	6900.00
0005434877748	3522	Business	35000.00
0005434877741	3522	Business	35000.00
0005434877795	3522	Business	35000.00
0005435902461	3522	Business	35000.00
0005435626086	3522	Business	35000.00
0005435626071	3522	Business	35000.00
0005435626091	3522	Business	35000.00
0005434877784	3522	Business	35000.00
0005434877738	3522	Business	35000.00
0005435902460	3522	Business	35000.00
0005434877742	3522	Business	35000.00
0005435626075	3522	Business	35000.00
0005434877763	3522	Business	35000.00
0005435626082	3522	Business	35000.00
0005432799318	3522	Business	35000.00
0005432799303	3522	Business	35000.00
0005434877797	3522	Business	35000.00
0005434877771	3522	Business	35000.00
0005434877729	3522	Comfort	19900.00
0005435626072	3522	Comfort	19900.00
0005435126167	3522	Comfort	19900.00
0005435902454	3522	Comfort	19900.00
0005434877785	3522	Comfort	19900.00
0005435626073	3522	Comfort	19900.00
0005434426460	3522	Comfort	19900.00
0005434426457	3522	Comfort	19900.00
0005435902453	3522	Comfort	19900.00
0005435626070	3522	Comfort	19900.00
0005435626081	3522	Comfort	19900.00
0005434426467	3522	Comfort	19900.00
0005435626087	3522	Comfort	19900.00
0005434877799	3522	Comfort	19900.00
0005434877726	3522	Comfort	19900.00
0005434877718	3522	Comfort	19900.00
0005435126177	3522	Comfort	19900.00
0005435126178	3522	Comfort	19900.00
0005435126151	3522	Comfort	19900.00
0005434877811	3522	Comfort	19900.00
0005435914682	3522	Comfort	19900.00
0005434426474	3522	Comfort	19900.00
0005435126185	3522	Comfort	19900.00
0005435126149	3522	Comfort	19900.00
0005434877731	3522	Comfort	19900.00
0005432799316	3522	Comfort	19900.00
0005435126176	3522	Comfort	19900.00
0005435902407	3522	Comfort	19900.00
0005435126173	3522	Comfort	19900.00
0005434938035	3522	Comfort	19900.00
0005432799310	3522	Comfort	19900.00
0005434877761	3522	Comfort	19900.00
0005435841810	3522	Comfort	19900.00
0005434877753	3522	Comfort	19900.00
0005435126152	3522	Comfort	19900.00
0005434877788	3522	Comfort	19900.00
0005435126179	3522	Comfort	19900.00
0005434877806	3522	Economy	11700.00
0005435914683	3522	Economy	11700.00
0005434938044	3522	Economy	11700.00
0005432613843	3522	Economy	11700.00
0005434877756	3522	Economy	11700.00
0005434426463	3522	Economy	11700.00
0005432188591	3522	Economy	11700.00
0005434426468	3522	Economy	11700.00
0005435126160	3522	Economy	11700.00
0005434426461	3522	Economy	11700.00
0005435126154	3522	Economy	11700.00
0005434877740	3522	Economy	11700.00
0005435126180	3522	Economy	11700.00
0005432799317	3522	Economy	11700.00
0005434877774	3522	Economy	11700.00
0005435126184	3522	Economy	11700.00
0005434938036	3522	Economy	11700.00
0005434877794	3522	Economy	11700.00
0005434877725	3522	Economy	11700.00
0005434877749	3522	Economy	11700.00
0005434877781	3522	Economy	11700.00
0005435126187	3522	Economy	11700.00
0005434877752	3522	Economy	11700.00
0005434877796	3522	Economy	11700.00
0005435902421	3522	Economy	11700.00
0005434877758	3522	Economy	11700.00
0005434877779	3522	Economy	11700.00
0005434426466	3522	Economy	11700.00
0005434426459	3522	Economy	11700.00
0005432799321	3522	Economy	11700.00
0005434877773	3522	Economy	11700.00
0005434877786	3522	Economy	11700.00
0005432613839	3522	Economy	11700.00
0005434877745	3522	Economy	11700.00
0005435126181	3522	Economy	11700.00
0005434877717	3522	Economy	11700.00
0005432799315	3522	Economy	11700.00
0005435902480	3522	Economy	11700.00
0005432183457	3522	Economy	11700.00
0005435126174	3522	Economy	11700.00
0005434877798	3522	Economy	11700.00
0005435126156	3522	Economy	11700.00
0005434877768	3522	Economy	11700.00
0005434877770	3522	Economy	12800.00
0005432799302	3522	Economy	12800.00
0005435126162	3522	Economy	11700.00
0005434877757	3522	Economy	11700.00
0005434877754	3522	Economy	11700.00
0005434877776	3522	Economy	12800.00
0005434426449	3522	Economy	11700.00
0005434938041	3522	Economy	12800.00
0005434877723	3522	Economy	11700.00
0005434877766	3522	Economy	11700.00
0005434877765	3522	Economy	11700.00
0005434426450	3522	Economy	11700.00
0005435902430	3522	Economy	11700.00
0005432183455	3522	Economy	11700.00
0005434426465	3522	Economy	11700.00
0005434877759	3522	Economy	11700.00
0005432799306	3522	Economy	11700.00
0005435902455	3522	Economy	11700.00
0005434938045	3522	Economy	11700.00
0005435626077	3522	Economy	11700.00
0005434426469	3522	Economy	11700.00
0005432799323	3522	Economy	11700.00
0005434877807	3522	Economy	11700.00
0005434938051	3522	Economy	11700.00
0005432611689	3522	Economy	11700.00
0005434877809	3522	Economy	11700.00
0005435902424	3522	Economy	11700.00
0005435126164	3522	Economy	11700.00
0005434426464	3522	Economy	11700.00
0005434426456	3522	Economy	11700.00
0005435126171	3522	Economy	11700.00
0005434877805	3522	Economy	11700.00
0005434877800	3522	Economy	11700.00
0005435126175	3522	Economy	11700.00
0005434938042	3522	Economy	11700.00
0005434877735	3522	Economy	11700.00
0005432799324	3522	Economy	11700.00
0005435126172	3522	Economy	11700.00
0005434938034	3522	Economy	11700.00
0005434877720	3522	Economy	11700.00
0005435126169	3522	Economy	11700.00
0005434877739	3522	Economy	11700.00
0005435126170	3522	Economy	11700.00
0005432799304	3522	Economy	11700.00
0005432611692	3522	Economy	11700.00
0005434877722	3522	Economy	11700.00
0005432613840	3522	Economy	11700.00
0005435126163	3522	Economy	11700.00
0005435126150	3522	Economy	11700.00
0005434877746	3522	Economy	11700.00
0005434877762	3522	Economy	11700.00
0005434938046	3522	Economy	11700.00
0005432799307	3522	Economy	11700.00
0005432799325	3522	Economy	11700.00
0005434877769	3522	Economy	11700.00
0005435902425	3522	Economy	11700.00
0005434426458	3522	Economy	11700.00
0005434938048	3522	Economy	11700.00
0005435126183	3522	Economy	11700.00
0005434877782	3522	Economy	11700.00
0005434877728	3522	Economy	11700.00
0005435902482	3522	Economy	11700.00
0005434877734	3522	Economy	11700.00
0005434426451	3522	Economy	11700.00
0005432183456	3522	Economy	11700.00
0005434877810	3522	Economy	11700.00
0005434426470	3522	Economy	11700.00
0005434877727	3522	Economy	11700.00
0005435902396	3522	Economy	11700.00
0005432799313	3522	Economy	11700.00
0005435126166	3522	Economy	11700.00
0005434938038	3522	Economy	11700.00
0005434877780	3522	Economy	11700.00
0005434877792	3522	Economy	11700.00
0005434877803	3522	Economy	11700.00
0005435626079	3522	Economy	11700.00
0005435126168	3522	Economy	11700.00
0005434877802	3522	Economy	11700.00
0005434877815	3522	Economy	11700.00
0005434877751	3522	Economy	11700.00
0005432613842	3522	Economy	11700.00
0005434877812	3522	Economy	11700.00
0005434877743	3522	Economy	11700.00
0005434938039	3522	Economy	11700.00
0005434938049	3522	Economy	11700.00
0005434426471	3522	Economy	11700.00
0005432799320	3522	Economy	11700.00
0005434877804	3522	Economy	11700.00
0005434938047	3522	Economy	11700.00
0005434938032	3522	Economy	11700.00
0005435902431	3522	Economy	11700.00
0005434877778	3522	Economy	11700.00
0005434877814	3522	Economy	11700.00
0005432188590	3522	Economy	11700.00
0005434426475	3522	Economy	11700.00
0005434877733	3522	Economy	12800.00
0005435126158	3522	Economy	12800.00
0005434877747	3522	Economy	12800.00
0005432188593	3522	Economy	12800.00
0005432799305	3522	Economy	11700.00
0005434938050	3522	Economy	11700.00
0005434426454	3522	Economy	11700.00
0005435902506	3522	Economy	11700.00
0005434938043	3522	Economy	11700.00
0005434877724	3522	Economy	11700.00
0005434938033	3522	Economy	11700.00
0005432799308	3522	Economy	11700.00
0005435126159	3522	Economy	11700.00
0005435626083	3522	Economy	11700.00
0005435626090	3522	Economy	11700.00
0005434877790	3522	Economy	11700.00
0005434426462	3522	Economy	11700.00
0005432799319	3522	Economy	11700.00
0005435626076	3522	Economy	11700.00
0005434426473	3522	Economy	11700.00
0005434426448	3522	Economy	11700.00
0005432799326	3522	Economy	11700.00
0005434877719	3522	Economy	11700.00
0005434877736	3522	Economy	11700.00
0005435626078	3522	Economy	11700.00
0005435902515	3522	Economy	11700.00
0005432799322	3522	Economy	11700.00
0005434877772	3522	Economy	11700.00
0005435913852	3522	Economy	11700.00
0005434877730	3522	Economy	11700.00
0005434938037	3522	Economy	11700.00
0005432611691	3522	Economy	11700.00
0005435626074	3522	Economy	11700.00
0005435126165	3522	Economy	11700.00
0005432799327	3522	Economy	11700.00
0005434877737	3522	Economy	11700.00
0005434877732	3522	Economy	11700.00
0005435902408	3522	Economy	11700.00
0005432188592	3522	Economy	11700.00
0005434877801	3522	Economy	11700.00
0005434877767	3522	Economy	11700.00
0005435126161	3522	Economy	11700.00
0005435126157	3522	Economy	11700.00
0005434877793	3522	Economy	11700.00
0005434877744	3522	Economy	11700.00
0005434877783	3522	Economy	11700.00
0005435626080	3522	Economy	11700.00
0005434877777	3522	Economy	11700.00
0005432799311	3522	Economy	11700.00
0005435126186	3522	Economy	11700.00
0005434426453	3522	Economy	11700.00
0005434877808	3522	Economy	11700.00
0005435902456	3522	Economy	11700.00
0005435126182	3522	Economy	11700.00
0005435626084	3522	Economy	11700.00
0005432613841	3522	Economy	11700.00
0005434426455	3522	Economy	11700.00
0005434877813	3522	Economy	11700.00
0005432611690	3522	Economy	11700.00
0005435626085	3522	Economy	11700.00
0005432799314	3522	Economy	11700.00
0005435626088	3522	Economy	11700.00
0005434426452	3522	Economy	11700.00
0005434877775	3522	Economy	11700.00
0005434877791	3522	Economy	11700.00
0005434938040	3522	Economy	11700.00
0005435902472	3522	Economy	11700.00
0005432799328	3522	Economy	11700.00
0005434877750	3522	Economy	11700.00
0005434877755	3522	Economy	11700.00
0005434877789	3522	Economy	11700.00
0005435126153	3522	Economy	11700.00
0005435902481	3522	Economy	11700.00
0005435626089	3522	Economy	11700.00
0005435913851	3522	Economy	11700.00
0005434426472	3522	Economy	11700.00
0005435841811	3522	Economy	11700.00
0005432799312	3522	Economy	11700.00
0005435126155	3522	Economy	11700.00
0005432799309	3522	Economy	11700.00
0005434877721	3522	Economy	11700.00
0005434877764	3522	Economy	11700.00
0005434877787	3522	Economy	11700.00
0005434877760	3522	Economy	11700.00
0005432799127	14584	Business	35000.00
0005435125834	14584	Business	35000.00
0005434876907	14584	Business	35000.00
0005434877229	14584	Business	35000.00
0005434877170	14584	Business	35000.00
0005435902609	14584	Business	35000.00
0005432798979	14584	Business	35000.00
0005435125752	14584	Business	35000.00
0005434876997	14584	Business	35000.00
0005432059494	14584	Business	35000.00
0005435125897	14584	Business	35000.00
0005434877085	14584	Business	35000.00
0005435125863	14584	Business	35000.00
0005435125796	14584	Business	35000.00
0005434937893	14584	Business	35000.00
0005435625875	14584	Business	35000.00
0005434877163	14584	Business	35000.00
0005435125793	14584	Business	35000.00
0005434876812	14584	Business	35000.00
0005435625911	14584	Comfort	19900.00
0005434876948	14584	Comfort	19900.00
0005434426259	14584	Comfort	19900.00
0005434876774	14584	Comfort	19900.00
0005434937950	14584	Comfort	19900.00
0005434876954	14584	Comfort	19900.00
0005435125654	14584	Comfort	19900.00
0005434876889	14584	Comfort	19900.00
0005434876842	14584	Comfort	19900.00
0005434876757	14584	Comfort	19900.00
0005434876811	14584	Comfort	19900.00
0005432799050	14584	Comfort	19900.00
0005434876758	14584	Comfort	19900.00
0005435125770	14584	Comfort	19900.00
0005435125761	14584	Comfort	19900.00
0005434877313	14584	Comfort	19900.00
0005435125742	14584	Comfort	19900.00
0005435125937	14584	Comfort	19900.00
0005434876663	14584	Comfort	19900.00
0005435902614	14584	Comfort	19900.00
0005435902615	14584	Comfort	19900.00
0005434876780	14584	Comfort	19900.00
0005434426345	14584	Comfort	19900.00
0005435625918	14584	Comfort	19900.00
0005434877026	14584	Comfort	19900.00
0005434876591	14584	Comfort	19900.00
0005435125824	14584	Comfort	19900.00
0005434877044	14584	Comfort	19900.00
0005434876865	14584	Comfort	19900.00
0005432799082	14584	Comfort	19900.00
0005434877128	14584	Comfort	19900.00
0005435125806	14584	Comfort	19900.00
0005435125667	14584	Economy	11700.00
0005435913926	14584	Comfort	19900.00
0005434877445	14584	Economy	11700.00
0005434937881	14584	Economy	11700.00
0005432798972	14584	Economy	11700.00
0005434426116	14584	Economy	11700.00
0005434876736	14584	Economy	11700.00
0005434426117	14584	Economy	11700.00
0005435902608	14584	Economy	11700.00
0005432799083	14584	Economy	11700.00
0005432799004	14584	Economy	11700.00
0005434426252	14584	Economy	11700.00
0005434426257	14584	Economy	11700.00
0005432607496	14584	Economy	11700.00
0005435902606	14584	Economy	11700.00
0005432798975	14584	Economy	11700.00
0005434426221	14584	Economy	11700.00
0005432799075	14584	Economy	11700.00
0005434877086	14584	Economy	11700.00
0005435625912	14584	Economy	11700.00
0005434877171	14584	Economy	11700.00
0005434877083	14584	Economy	11700.00
0005434876928	14584	Economy	11700.00
0005432607499	14584	Economy	11700.00
0005432799154	14584	Economy	11700.00
0005434937908	14584	Economy	11700.00
0005434426253	14584	Economy	11700.00
0005434877195	14584	Economy	11700.00
0005434876927	14584	Economy	11700.00
0005435902617	14584	Economy	11700.00
0005435125805	14584	Economy	11700.00
0005435125869	14584	Economy	11700.00
0005434877172	14584	Economy	11700.00
0005434876589	14584	Economy	11700.00
0005434876590	14584	Economy	11700.00
0005434426130	14584	Economy	11700.00
0005435902620	14584	Economy	11700.00
0005434877024	14584	Economy	11700.00
0005434877166	14584	Economy	11700.00
0005432799111	14584	Economy	11700.00
0005432799042	14584	Economy	11700.00
0005435841819	14584	Economy	11700.00
0005432799149	14584	Economy	11700.00
0005435125663	14584	Economy	11700.00
0005432799150	14584	Economy	11700.00
0005435625868	14584	Economy	11700.00
0005434877010	14584	Economy	11700.00
0005434937886	14584	Economy	12800.00
0005434877165	14584	Economy	12800.00
0005435841818	14584	Economy	11700.00
0005435625905	14584	Economy	11700.00
0005435125653	14584	Economy	11700.00
0005434877043	14584	Economy	12800.00
0005435625893	14584	Economy	12800.00
0005434876807	14584	Economy	11700.00
0005432798998	14584	Economy	11700.00
0005434876926	14584	Economy	11700.00
0005434876598	14584	Economy	11700.00
0005435125896	14584	Economy	11700.00
0005434426181	14584	Economy	11700.00
0005434937990	14584	Economy	11700.00
0005435125799	14584	Economy	11700.00
0005435125760	14584	Economy	11700.00
0005434426248	14584	Economy	11700.00
0005435125794	14584	Economy	11700.00
0005434426254	14584	Economy	11700.00
0005435902605	14584	Economy	11700.00
0005434876714	14584	Economy	11700.00
0005434937960	14584	Economy	11700.00
0005434426196	14584	Economy	11700.00
0005432799101	14584	Economy	11700.00
0005434876635	14584	Economy	11700.00
0005435125764	14584	Economy	11700.00
0005434876850	14584	Economy	11700.00
0005435902612	14584	Economy	11700.00
0005434426222	14584	Economy	11700.00
0005432799051	14584	Economy	11700.00
0005435902603	14584	Economy	11700.00
0005434876713	14584	Economy	11700.00
0005434877162	14584	Economy	11700.00
0005434426255	14584	Economy	11700.00
0005434937892	14584	Economy	11700.00
0005434876957	14584	Economy	11700.00
0005432799148	14584	Economy	11700.00
0005434426197	14584	Economy	11700.00
0005435125652	14584	Economy	11700.00
0005434876944	14584	Economy	11700.00
0005434876953	14584	Economy	11700.00
0005435902604	14584	Economy	11700.00
0005434426251	14584	Economy	11700.00
0005434876678	14584	Economy	11700.00
0005434876904	14584	Economy	11700.00
0005434877048	14584	Economy	11700.00
0005434876999	14584	Economy	11700.00
0005434877084	14584	Economy	11700.00
0005434426247	14584	Economy	11700.00
0005435125911	14584	Economy	11700.00
0005432799126	14584	Economy	11700.00
0005434426246	14584	Economy	11700.00
0005434876691	14584	Economy	11700.00
0005434876756	14584	Economy	11700.00
0005435625919	14584	Economy	11700.00
0005434876998	14584	Economy	11700.00
0005434877089	14584	Economy	11700.00
0005432607510	14584	Economy	11700.00
0005435125913	14584	Economy	11700.00
0005434426218	14584	Economy	11700.00
0005434937864	14584	Economy	11700.00
0005432799074	14584	Economy	11700.00
0005434937961	14584	Economy	11700.00
0005434877232	14584	Economy	11700.00
0005432799091	14584	Economy	11700.00
0005434426182	14584	Economy	11700.00
0005435125912	14584	Economy	11700.00
0005435125741	14584	Economy	11700.00
0005435125804	14584	Economy	11700.00
0005434877064	14584	Economy	11700.00
0005435902611	14584	Economy	11700.00
0005434426229	14584	Economy	11700.00
0005435125891	14584	Economy	11700.00
0005435625894	14584	Economy	11700.00
0005434876984	14584	Economy	11700.00
0005435913927	14584	Economy	11700.00
0005434877025	14584	Economy	11700.00
0005434877045	14584	Economy	11700.00
0005432799197	14584	Economy	11700.00
0005432799129	14584	Economy	11700.00
0005432799011	14584	Economy	11700.00
0005435125841	14584	Economy	11700.00
0005435625916	14584	Economy	11700.00
0005434877326	14584	Economy	12800.00
0005432799153	14584	Economy	12800.00
0005434426219	14584	Economy	12800.00
0005434877050	14584	Economy	12800.00
0005432798997	14584	Economy	11700.00
0005432798973	14584	Economy	11700.00
0005435625915	14584	Economy	11700.00
0005435125704	14584	Economy	11700.00
0005434937951	14584	Economy	11700.00
0005434876775	14584	Economy	11700.00
0005434877387	14584	Economy	11700.00
0005435125795	14584	Economy	11700.00
0005435125895	14584	Economy	11700.00
0005434426316	14584	Economy	11700.00
0005434426223	14584	Economy	11700.00
0005434937900	14584	Economy	11700.00
0005432799052	14584	Economy	11700.00
0005434876798	14584	Economy	11700.00
0005434876903	14584	Economy	11700.00
0005434937905	14584	Economy	11700.00
0005434877363	14584	Economy	11700.00
0005435125844	14584	Economy	11700.00
0005435125710	14584	Economy	11700.00
0005435902616	14584	Economy	11700.00
0005434877530	14584	Economy	11700.00
0005435125816	14584	Economy	11700.00
0005432799110	14584	Economy	11700.00
0005432799063	14584	Economy	11700.00
0005434877002	14584	Economy	11700.00
0005435125864	14584	Economy	11700.00
0005434426250	14584	Economy	11700.00
0005434877049	14584	Economy	11700.00
0005434426131	14584	Economy	11700.00
0005435902613	14584	Economy	11700.00
0005432798974	14584	Economy	11700.00
0005435902607	14584	Economy	11700.00
0005434876947	14584	Economy	11700.00
0005434876755	14584	Economy	11700.00
0005434426213	14584	Economy	11700.00
0005434876980	14584	Economy	11700.00
0005435125894	14584	Economy	11700.00
0005434937887	14584	Economy	11700.00
0005434426266	14584	Economy	11700.00
0005434876740	14584	Economy	11700.00
0005434877386	14584	Economy	11700.00
0005435902610	14584	Economy	11700.00
0005434426183	14584	Economy	11700.00
0005434877159	14584	Economy	11700.00
0005432611655	14584	Economy	11700.00
0005434876886	14584	Economy	11700.00
0005434877208	14584	Economy	11700.00
0005432607495	14584	Economy	11700.00
0005435913924	14584	Economy	11700.00
0005435902618	14584	Economy	11700.00
0005434877230	14584	Economy	11700.00
0005434876779	14584	Economy	11700.00
0005434876631	14584	Economy	11700.00
0005435125751	14584	Economy	11700.00
0005432607520	14584	Economy	11700.00
0005435625904	14584	Economy	11700.00
0005434426258	14584	Economy	11700.00
0005435125910	14584	Economy	11700.00
0005432799128	14584	Economy	11700.00
0005434877399	14584	Economy	11700.00
0005435913925	14584	Economy	11700.00
0005435902619	14584	Economy	11700.00
0005435125728	14584	Economy	11700.00
0005434937812	14584	Economy	11700.00
0005434876773	14584	Economy	11700.00
0005434325592	3600	Economy	16300.00
0005434325594	3600	Economy	16300.00
0005434325589	3600	Economy	14800.00
0005434325595	3600	Economy	14800.00
0005435889826	3600	Economy	14800.00
0005435889822	3600	Economy	14800.00
0005434325585	3600	Economy	14800.00
0005434325590	3600	Economy	14800.00
0005435889808	3600	Economy	14800.00
0005435889838	3600	Economy	14800.00
0005434325591	3600	Economy	14800.00
0005434325588	3600	Economy	14800.00
0005434325586	3600	Economy	14800.00
0005435889807	3600	Economy	14800.00
0005435889837	3600	Economy	14800.00
0005434325596	3600	Economy	14800.00
0005434325587	3600	Economy	14800.00
0005435889795	3600	Economy	14800.00
0005434325593	3600	Economy	14800.00
0005435889831	3600	Economy	14800.00
0005434325543	15642	Economy	16300.00
0005435889866	15642	Economy	16300.00
0005435889863	15642	Economy	14800.00
0005434325505	15642	Economy	14800.00
0005435889865	15642	Economy	14800.00
0005435889867	15642	Economy	14800.00
0005434325549	15642	Economy	14800.00
0005434325486	15642	Economy	14800.00
0005434325492	15642	Economy	14800.00
0005434325493	15642	Economy	14800.00
0005434325468	15642	Economy	14800.00
0005434325494	15642	Economy	14800.00
0005434325524	15642	Economy	14800.00
0005434325526	15642	Economy	14800.00
0005434325511	15642	Economy	14800.00
0005435889868	15642	Economy	14800.00
0005434325544	15642	Economy	14800.00
0005435889864	15642	Economy	14800.00
0005434325512	15642	Economy	14800.00
0005434325514	15642	Economy	14800.00
0005434325495	15642	Economy	14800.00
0005434325525	15642	Economy	14800.00
0005435957624	615	Economy	4500.00
0005433420306	615	Economy	4500.00
0005435957628	615	Economy	4100.00
0005435957634	615	Economy	4100.00
0005435957633	615	Economy	4100.00
0005435957622	615	Economy	4100.00
0005433420307	615	Economy	4100.00
0005435957625	615	Economy	4100.00
0005433420309	615	Economy	4100.00
0005435957623	615	Economy	4100.00
0005433420285	615	Economy	4100.00
0005433420267	615	Economy	4100.00
0005435957627	615	Economy	4100.00
0005435957631	615	Economy	4100.00
0005433420280	615	Economy	4100.00
0005435957630	615	Economy	4100.00
0005435957632	615	Economy	4100.00
0005433420308	615	Economy	4100.00
0005435957621	615	Economy	4100.00
0005433420278	615	Economy	4100.00
0005433420277	615	Economy	4100.00
0005435957629	615	Economy	4100.00
0005435957626	615	Economy	4100.00
0005433420262	615	Economy	4100.00
0005433420263	615	Economy	4100.00
0005435957548	15212	Economy	4500.00
0005435957495	15212	Economy	4500.00
0005435957542	15212	Economy	4500.00
0005433420360	15212	Economy	4100.00
0005433420364	15212	Economy	4100.00
0005433420359	15212	Economy	4100.00
0005435957547	15212	Economy	4100.00
0005433420361	15212	Economy	4100.00
0005435957555	15212	Economy	4100.00
0005435957493	15212	Economy	4100.00
0005435957494	15212	Economy	4100.00
0005435957502	15212	Economy	4100.00
0005433420362	15212	Economy	4100.00
0005435957464	15212	Economy	4100.00
0005433420358	15212	Economy	4100.00
0005433420357	15212	Economy	4100.00
0005435957521	15212	Economy	4100.00
0005433420363	15212	Economy	4100.00
0005435957468	15212	Economy	4100.00
0005433420355	15212	Economy	4100.00
0005435957503	15212	Economy	4100.00
0005435957543	15212	Economy	4100.00
0005433420356	15212	Economy	4100.00
0005435629399	8913	Economy	10400.00
0005434247112	8913	Economy	10400.00
0005434247113	8913	Economy	10400.00
0005434247106	8913	Economy	10400.00
0005434247134	16014	Economy	10400.00
0005434247133	16014	Economy	10400.00
0005435629394	16014	Economy	10400.00
0005435933435	29527	Economy	13400.00
0005435163179	29527	Economy	13400.00
0005435163139	29527	Economy	12200.00
0005435163161	29527	Economy	12200.00
0005435163165	29527	Economy	12200.00
0005435933430	29527	Economy	12200.00
0005435163151	29527	Economy	12200.00
0005435933432	29527	Economy	12200.00
0005435163164	29527	Economy	12200.00
0005435163149	29527	Economy	12200.00
0005435163148	29527	Economy	12200.00
0005435163153	29527	Economy	12200.00
0005435933437	29527	Economy	12200.00
0005435933438	29527	Economy	12200.00
0005435163156	29527	Economy	12200.00
0005435933429	29527	Economy	12200.00
0005435163159	29527	Economy	12200.00
0005435933436	29527	Economy	12200.00
0005435163160	29527	Economy	12200.00
0005435933431	29527	Economy	12200.00
0005435933434	29527	Economy	12200.00
0005435933433	29527	Economy	12200.00
0005435163150	29527	Economy	12200.00
0005433404698	2832	Economy	4200.00
0005433404720	2832	Economy	4600.00
0005435797406	2832	Economy	4200.00
0005435797402	2832	Economy	4200.00
0005433404694	2832	Economy	4200.00
0005435797408	2832	Economy	4200.00
0005435797410	2832	Economy	4200.00
0005435797405	2832	Economy	4200.00
0005435797398	2832	Economy	4200.00
0005435797397	2832	Economy	4200.00
0005435797401	2832	Economy	4200.00
0005435797403	2832	Economy	4200.00
0005435797407	2832	Economy	4200.00
0005435797409	2832	Economy	4200.00
0005433404697	2832	Economy	4200.00
0005435797400	2832	Economy	4200.00
0005435797399	2832	Economy	4200.00
0005433404721	2832	Economy	4200.00
0005435797404	2832	Economy	4200.00
0005433404703	2832	Economy	4200.00
0005433404772	29330	Business	12600.00
0005435797334	29330	Business	12600.00
0005433404773	29330	Economy	4200.00
0005435797263	29330	Economy	4600.00
0005435797278	29330	Economy	4600.00
0005435797262	29330	Economy	4600.00
0005435797276	29330	Economy	4200.00
0005435797300	29330	Economy	4200.00
0005433404774	29330	Economy	4200.00
0005435797301	29330	Economy	4200.00
0005433404771	29330	Economy	4200.00
0005435797279	29330	Economy	4200.00
0005433404770	29330	Economy	4200.00
0005433404768	29330	Economy	4200.00
0005433404769	29330	Economy	4200.00
0005434947975	5792	Economy	6800.00
0005434947981	5792	Economy	6800.00
0005434947976	5792	Economy	6800.00
0005434947974	5792	Economy	6800.00
0005434947978	5792	Economy	6800.00
0005434947983	5792	Economy	6800.00
0005434947977	5792	Economy	6800.00
0005434947980	5792	Economy	6800.00
0005434947979	5792	Economy	6800.00
0005434947982	5792	Economy	6800.00
0005435376336	16379	Economy	6800.00
0005435376338	16379	Economy	6800.00
0005434947918	16379	Economy	6800.00
0005435376339	16379	Economy	6800.00
0005434947919	16379	Economy	6800.00
0005434947917	16379	Economy	6800.00
0005434947931	16379	Economy	6800.00
0005435376337	16379	Economy	6800.00
0005435376340	16379	Economy	6800.00
0005434947916	16379	Economy	6800.00
0005434947925	16379	Economy	6800.00
0005433960625	6933	Business	21400.00
0005433960588	6933	Business	21400.00
0005433960579	6933	Business	21400.00
0005433960575	6933	Business	21400.00
0005433960616	6933	Business	21400.00
0005433960586	6933	Business	21400.00
0005433960580	6933	Economy	7100.00
0005433960626	6933	Economy	7100.00
0005433960578	6933	Economy	7100.00
0005433960622	6933	Economy	7100.00
0005433960587	6933	Economy	7100.00
0005433960590	6933	Economy	7800.00
0005433960576	6933	Economy	7800.00
0005433960591	6933	Economy	7800.00
0005433960583	6933	Economy	7800.00
0005433960621	6933	Economy	7800.00
0005433960612	6933	Economy	7100.00
0005433960597	6933	Economy	7100.00
0005433960584	6933	Economy	7100.00
0005433960605	6933	Economy	7100.00
0005433960585	6933	Economy	7100.00
0005433960607	6933	Economy	7100.00
0005433960581	6933	Economy	7100.00
0005433960615	6933	Economy	7100.00
0005433960603	6933	Economy	7100.00
0005433960619	6933	Economy	7100.00
0005433960595	6933	Economy	7100.00
0005433960582	6933	Economy	7100.00
0005433960611	6933	Economy	7100.00
0005433960601	6933	Economy	7100.00
0005433960574	6933	Economy	7100.00
0005433960600	6933	Economy	7100.00
0005433960617	6933	Economy	7100.00
0005433960596	6933	Economy	7100.00
0005433960604	6933	Economy	7100.00
0005433960623	6933	Economy	7100.00
0005433960577	6933	Economy	7100.00
0005433960589	6933	Economy	7100.00
0005433960627	6933	Economy	7100.00
0005433960610	6933	Economy	7100.00
0005433960598	6933	Economy	7100.00
0005433960620	6933	Economy	7100.00
0005433960614	6933	Economy	7100.00
0005433960599	6933	Economy	7100.00
0005433960624	6933	Economy	7100.00
0005433960572	6933	Economy	7100.00
0005433960606	6933	Economy	7100.00
0005433960592	6933	Economy	7100.00
0005433960618	6933	Economy	7100.00
0005433960593	6933	Economy	7100.00
0005433960594	6933	Economy	7100.00
0005433960628	6933	Economy	7100.00
0005433960609	6933	Economy	7100.00
0005433960573	6933	Economy	7100.00
0005433960608	6933	Economy	7100.00
0005433960602	6933	Economy	7100.00
0005433960613	6933	Economy	7100.00
0005433959920	25736	Business	21400.00
0005433959863	25736	Business	21400.00
0005433960002	25736	Business	21400.00
0005433959905	25736	Business	21400.00
0005433959939	25736	Business	21400.00
0005433959977	25736	Economy	7100.00
0005433959918	25736	Economy	7100.00
0005433959973	25736	Economy	7100.00
0005433959910	25736	Economy	7800.00
0005433959962	25736	Economy	7800.00
0005433959876	25736	Economy	7800.00
0005433959864	25736	Economy	7100.00
0005433959965	25736	Economy	7100.00
0005433959887	25736	Economy	7100.00
0005433959974	25736	Economy	7100.00
0005433959878	25736	Economy	7100.00
0005433959994	25736	Economy	7100.00
0005433959976	25736	Economy	7100.00
0005433959938	25736	Economy	7100.00
0005433959889	25736	Economy	7100.00
0005433959875	25736	Economy	7100.00
0005433959866	25736	Economy	7100.00
0005433959919	25736	Economy	7100.00
0005433959953	25736	Economy	7100.00
0005433959879	25736	Economy	7100.00
0005433959961	25736	Economy	7100.00
0005433959862	25736	Economy	7100.00
0005433959870	25736	Economy	7100.00
0005433959886	25736	Economy	7100.00
0005433959993	25736	Economy	7100.00
0005433959880	25736	Economy	7100.00
0005433959881	25736	Economy	7100.00
0005433959964	25736	Economy	7100.00
0005433959955	25736	Economy	7100.00
0005433960001	25736	Economy	7100.00
0005433959982	25736	Economy	7100.00
0005433959877	25736	Economy	7100.00
0005433959940	25736	Economy	7100.00
0005433960000	25736	Economy	7100.00
0005433960003	25736	Economy	7100.00
0005433959899	25736	Economy	7100.00
0005433959954	25736	Economy	7100.00
0005433959906	25736	Economy	7100.00
0005433959867	25736	Economy	7100.00
0005433959927	25736	Economy	7100.00
0005435082670	24529	Economy	3900.00
0005435082663	24529	Economy	3900.00
0005435082676	24529	Economy	3900.00
0005435082662	24529	Economy	3900.00
0005435082654	24529	Economy	3900.00
0005435082699	24529	Economy	3900.00
0005435082709	24529	Economy	3900.00
0005435082668	24529	Economy	3900.00
0005435082700	24529	Economy	3900.00
0005435082739	26059	Economy	3900.00
0005435082737	26059	Economy	3900.00
0005435082736	26059	Economy	3900.00
0005435082741	26059	Economy	3900.00
0005435082738	26059	Economy	3900.00
0005435082740	26059	Economy	3900.00
0005435286557	5065	Business	18000.00
0005434244845	5065	Business	18000.00
0005434244825	5065	Business	18000.00
0005434244828	5065	Business	18000.00
0005434244822	5065	Business	18000.00
0005434244818	5065	Economy	6600.00
0005434244839	5065	Economy	6000.00
0005432166884	5065	Economy	6000.00
0005434244831	5065	Economy	6000.00
0005434244824	5065	Economy	6000.00
0005434244844	5065	Economy	6000.00
0005434244820	5065	Economy	6000.00
0005434244819	5065	Economy	6000.00
0005434244817	5065	Economy	6000.00
0005434244835	5065	Economy	6000.00
0005434244827	5065	Economy	6000.00
0005434244826	5065	Economy	6000.00
0005434244830	5065	Economy	6000.00
0005434244832	5065	Economy	6000.00
0005434244837	5065	Economy	6000.00
0005434244834	5065	Economy	6000.00
0005434244816	5065	Economy	6600.00
0005434244840	5065	Economy	6000.00
0005432166883	5065	Economy	6000.00
0005434244842	5065	Economy	6000.00
0005434244833	5065	Economy	6000.00
0005435286545	5065	Economy	6000.00
0005435286546	5065	Economy	6000.00
0005434244841	5065	Economy	6000.00
0005434244843	5065	Economy	6000.00
0005434244829	5065	Economy	6000.00
0005434244838	5065	Economy	6000.00
0005434244821	5065	Economy	6000.00
0005432166885	5065	Economy	6000.00
0005434244836	5065	Economy	6000.00
0005434244823	5065	Economy	6000.00
0005433614303	5064	Business	18000.00
0005433614343	5064	Business	18000.00
0005432105349	5064	Business	18000.00
0005432105310	5064	Business	18000.00
0005432105338	5064	Business	18000.00
0005433784753	5064	Business	18000.00
0005433614354	5064	Business	18000.00
0005433784765	5064	Business	18000.00
0005433614350	5064	Business	18000.00
0005433784762	5064	Business	18000.00
0005433784759	5064	Business	18000.00
0005433614285	5064	Business	18000.00
0005432666378	5064	Business	18000.00
0005433614302	5064	Business	18000.00
0005433614313	5064	Business	18000.00
0005433614320	5064	Business	18000.00
0005433784770	5064	Business	18000.00
0005432145103	5064	Business	18000.00
0005433784743	5064	Business	18000.00
0005433614339	5064	Business	18000.00
0005432105317	5064	Business	18000.00
0005433614327	5064	Business	18000.00
0005433614296	5064	Business	18000.00
0005433614340	5064	Business	18000.00
0005432105302	5064	Business	18000.00
0005433784768	5064	Business	18000.00
0005433614323	5064	Business	18000.00
0005433614335	5064	Business	18000.00
0005432105324	5064	Economy	6600.00
0005433614305	5064	Economy	6600.00
0005432105326	5064	Economy	6600.00
0005433614326	5064	Economy	6600.00
0005433614295	5064	Economy	6600.00
0005433614322	5064	Economy	6600.00
0005433614356	5064	Economy	6000.00
0005432665263	5064	Economy	6000.00
0005433614358	5064	Economy	6000.00
0005433784771	5064	Economy	6000.00
0005433614329	5064	Economy	6000.00
0005433784747	5064	Economy	6000.00
0005433614330	5064	Economy	6000.00
0005432105300	5064	Economy	6000.00
0005433784761	5064	Economy	6000.00
0005433784772	5064	Economy	6000.00
0005432105348	5064	Economy	6000.00
0005433614318	5064	Economy	6000.00
0005433614333	5064	Economy	6000.00
0005433784766	5064	Economy	6000.00
0005432105320	5064	Economy	6000.00
0005432105337	5064	Economy	6000.00
0005432105314	5064	Economy	6000.00
0005433614347	5064	Economy	6000.00
0005433614337	5064	Economy	6000.00
0005432105299	5064	Economy	6000.00
0005433614332	5064	Economy	6000.00
0005432145100	5064	Economy	6000.00
0005432105306	5064	Economy	6000.00
0005433614328	5064	Economy	6000.00
0005433614319	5064	Economy	6000.00
0005432145102	5064	Economy	6000.00
0005432105344	5064	Economy	6000.00
0005432665264	5064	Economy	6000.00
0005432105330	5064	Economy	6000.00
0005433614315	5064	Economy	6000.00
0005433614336	5064	Economy	6000.00
0005433784745	5064	Economy	6000.00
0005433784760	5064	Economy	6000.00
0005433784750	5064	Economy	6000.00
0005433614304	5064	Economy	6000.00
0005432105312	5064	Economy	6000.00
0005432105325	5064	Economy	6000.00
0005432105333	5064	Economy	6000.00
0005433614331	5064	Economy	6000.00
0005432105334	5064	Economy	6000.00
0005432105309	5064	Economy	6000.00
0005433784758	5064	Economy	6000.00
0005433614290	5064	Economy	6000.00
0005433614357	5064	Economy	6000.00
0005432105313	5064	Economy	6000.00
0005433614301	5064	Economy	6000.00
0005433614344	5064	Economy	6000.00
0005432105301	5064	Economy	6000.00
0005432105347	5064	Economy	6000.00
0005433784769	5064	Economy	6000.00
0005432105322	5064	Economy	6000.00
0005433784754	5064	Economy	6000.00
0005433784741	5064	Economy	6000.00
0005433614307	5064	Economy	6000.00
0005432105336	5064	Economy	6000.00
0005433614297	5064	Economy	6000.00
0005432145101	5064	Economy	6000.00
0005433614312	5064	Economy	6000.00
0005433784742	5064	Economy	6000.00
0005433614300	5064	Economy	6000.00
0005432105340	5064	Economy	6600.00
0005433614334	5064	Economy	6600.00
0005433614355	5064	Economy	6600.00
0005432105303	5064	Economy	6600.00
0005433614286	5064	Economy	6600.00
0005432105311	5064	Economy	6000.00
0005433784744	5064	Economy	6000.00
0005433614353	5064	Economy	6000.00
0005432667442	5064	Economy	6000.00
0005433614294	5064	Economy	6000.00
0005433784767	5064	Economy	6600.00
0005433784755	5064	Economy	6000.00
0005432105319	5064	Economy	6000.00
0005432105316	5064	Economy	6000.00
0005433784763	5064	Economy	6000.00
0005433614316	5064	Economy	6000.00
0005433614311	5064	Economy	6000.00
0005433614321	5064	Economy	6000.00
0005433614346	5064	Economy	6000.00
0005432105329	5064	Economy	6000.00
0005433784740	5064	Economy	6000.00
0005432105308	5064	Economy	6000.00
0005433614298	5064	Economy	6000.00
0005432105304	5064	Economy	6000.00
0005433614351	5064	Economy	6000.00
0005432666377	5064	Economy	6000.00
0005432105307	5064	Economy	6000.00
0005432105341	5064	Economy	6000.00
0005433614289	5064	Economy	6000.00
0005433784757	5064	Economy	6000.00
0005432105345	5064	Economy	6000.00
0005433614287	5064	Economy	6000.00
0005433614314	5064	Economy	6000.00
0005432105305	5064	Economy	6000.00
0005432105318	5064	Economy	6000.00
0005432105321	5064	Economy	6000.00
0005433614310	5064	Economy	6000.00
0005433784739	5064	Economy	6000.00
0005432105331	5064	Economy	6000.00
0005433784748	5064	Economy	6000.00
0005433614309	5064	Economy	6000.00
0005433784752	5064	Economy	6000.00
0005433614348	5064	Economy	6000.00
0005432105332	5064	Economy	6000.00
0005433784746	5064	Economy	6000.00
0005432105328	5064	Economy	6000.00
0005433614299	5064	Economy	6000.00
0005433784751	5064	Economy	6000.00
0005432105323	5064	Economy	6000.00
0005433784764	5064	Economy	6000.00
0005433614308	5064	Economy	6000.00
0005433614325	5064	Economy	6000.00
0005433614288	5064	Economy	6000.00
0005433784749	5064	Economy	6000.00
0005432105343	5064	Economy	6000.00
0005433614292	5064	Economy	6000.00
0005432105315	5064	Economy	6000.00
0005433614291	5064	Economy	6000.00
0005433614341	5064	Economy	6000.00
0005432105335	5064	Economy	6000.00
0005433614306	5064	Economy	6000.00
0005433614352	5064	Economy	6000.00
0005432105346	5064	Economy	6000.00
0005433614293	5064	Economy	6000.00
0005433614349	5064	Economy	6000.00
0005433614342	5064	Economy	6000.00
0005433614345	5064	Economy	6000.00
0005432105327	5064	Economy	6000.00
0005433784756	5064	Economy	6000.00
0005433614338	5064	Economy	6000.00
0005433614324	5064	Economy	6000.00
0005432105339	5064	Economy	6000.00
0005432105342	5064	Economy	6000.00
0005432667443	5064	Economy	6000.00
0005433614317	5064	Economy	6000.00
0005435006765	5062	Business	18000.00
0005433688774	5062	Business	18000.00
0005434149666	5062	Business	18000.00
0005435006689	5062	Business	18000.00
0005435006690	5062	Business	18000.00
0005434265013	5062	Business	18000.00
0005434229257	5062	Business	18000.00
0005434312284	5062	Business	18000.00
0005433688775	5062	Business	18000.00
0005435006676	5062	Business	18000.00
0005434265017	5062	Business	18000.00
0005435006722	5062	Business	18000.00
0005434149674	5062	Business	18000.00
0005434229245	5062	Business	18000.00
0005434229243	5062	Business	18000.00
0005433685491	5062	Business	18000.00
0005434264993	5062	Business	18000.00
0005434229254	5062	Business	18000.00
0005435006712	5062	Business	18000.00
0005434312289	5062	Economy	6600.00
0005435006677	5062	Economy	6600.00
0005435006709	5062	Economy	6600.00
0005432335872	5062	Economy	6600.00
0005434229260	5062	Economy	6000.00
0005434229263	5062	Economy	6000.00
0005434265004	5062	Economy	6000.00
0005434149673	5062	Economy	6000.00
0005434229246	5062	Economy	6000.00
0005434149668	5062	Economy	6000.00
0005434265008	5062	Economy	6000.00
0005434311186	5062	Economy	6000.00
0005434265006	5062	Economy	6000.00
0005435006691	5062	Economy	6000.00
0005434173500	5062	Economy	6000.00
0005434265001	5062	Economy	6000.00
0005432335877	5062	Economy	6000.00
0005435006653	5062	Economy	6000.00
0005434149667	5062	Economy	6000.00
0005432335863	5062	Economy	6000.00
0005432335843	5062	Economy	6000.00
0005434312290	5062	Economy	6000.00
0005434149669	5062	Economy	6000.00
0005432335876	5062	Economy	6000.00
0005434265000	5062	Economy	6000.00
0005432335857	5062	Economy	6000.00
0005434264998	5062	Economy	6000.00
0005435006810	5062	Economy	6000.00
0005434229244	5062	Economy	6000.00
0005435006688	5062	Economy	6000.00
0005434264995	5062	Economy	6000.00
0005434264992	5062	Economy	6000.00
0005432335870	5062	Economy	6000.00
0005434229259	5062	Economy	6000.00
0005435006781	5062	Economy	6000.00
0005435006749	5062	Economy	6000.00
0005434173498	5062	Economy	6000.00
0005434265011	5062	Economy	6000.00
0005434265010	5062	Economy	6000.00
0005435006634	5062	Economy	6000.00
0005434264999	5062	Economy	6000.00
0005434265015	5062	Economy	6000.00
0005434312294	5062	Economy	6000.00
0005434149676	5062	Economy	6000.00
0005434229248	5062	Economy	6600.00
0005435006713	5062	Economy	6600.00
0005434265012	5062	Economy	6000.00
0005434229249	5062	Economy	6000.00
0005434173499	5062	Economy	6000.00
0005434149671	5062	Economy	6600.00
0005434229252	5062	Economy	6000.00
0005433815311	5062	Economy	6000.00
0005434229247	5062	Economy	6000.00
0005434265002	5062	Economy	6000.00
0005434265014	5062	Economy	6000.00
0005434264997	5062	Economy	6000.00
0005434229255	5062	Economy	6000.00
0005435006663	5062	Economy	6000.00
0005435006654	5062	Economy	6000.00
0005434229251	5062	Economy	6000.00
0005432335856	5062	Economy	6000.00
0005434229261	5062	Economy	6000.00
0005434229250	5062	Economy	6000.00
0005432335929	5062	Economy	6000.00
0005434149672	5062	Economy	6000.00
0005432335883	5062	Economy	6000.00
0005435006698	5062	Economy	6000.00
0005434149670	5062	Economy	6000.00
0005435006669	5062	Economy	6000.00
0005434229256	5062	Economy	6000.00
0005434265016	5062	Economy	6000.00
0005434265018	5062	Economy	6000.00
0005435006699	5062	Economy	6000.00
0005432335842	5062	Economy	6000.00
0005434149675	5062	Economy	6000.00
0005435006759	5062	Economy	6000.00
0005434265009	5062	Economy	6000.00
0005434264996	5062	Economy	6000.00
0005435269644	5062	Economy	6000.00
0005435006668	5062	Economy	6000.00
0005434229262	5062	Economy	6000.00
0005434265003	5062	Economy	6000.00
0005434311187	5062	Economy	6000.00
0005434229258	5062	Economy	6000.00
0005434229264	5062	Economy	6000.00
0005435006608	5062	Economy	6000.00
0005434264994	5062	Economy	6000.00
0005434229265	5062	Economy	6000.00
0005434265005	5062	Economy	6000.00
0005435006741	5062	Economy	6000.00
0005434229253	5062	Economy	6000.00
0005434265007	5062	Economy	6000.00
0005434244671	8380	Business	18000.00
0005433784369	8380	Business	18000.00
0005434244606	8380	Business	18000.00
0005433784505	8380	Business	18000.00
0005433784450	8380	Business	18000.00
0005435269724	8380	Business	18000.00
0005433784343	8380	Business	18000.00
0005433784539	8380	Business	18000.00
0005434244672	8380	Business	18000.00
0005434244561	8380	Business	18000.00
0005433784338	8380	Business	18000.00
0005433784337	8380	Business	18000.00
0005434244557	8380	Business	18000.00
0005434244612	8380	Business	18000.00
0005435269719	8380	Business	18000.00
0005435269712	8380	Business	18000.00
0005433784454	8380	Business	18000.00
0005435269711	8380	Economy	6600.00
0005435269723	8380	Economy	6600.00
0005435269720	8380	Economy	6000.00
0005433784422	8380	Economy	6000.00
0005434244573	8380	Economy	6000.00
0005435269706	8380	Economy	6000.00
0005433784453	8380	Economy	6000.00
0005434244578	8380	Economy	6000.00
0005434244710	8380	Economy	6000.00
0005435269709	8380	Economy	6000.00
0005433784346	8380	Economy	6000.00
0005434244711	8380	Economy	6000.00
0005433784525	8380	Economy	6000.00
0005434244524	8380	Economy	6000.00
0005433784349	8380	Economy	6000.00
0005435269705	8380	Economy	6000.00
0005433784514	8380	Economy	6000.00
0005433784398	8380	Economy	6000.00
0005434244709	8380	Economy	6000.00
0005433784407	8380	Economy	6000.00
0005435269714	8380	Economy	6000.00
0005434244517	8380	Economy	6000.00
0005433784408	8380	Economy	6000.00
0005434244649	8380	Economy	6000.00
0005434244581	8380	Economy	6000.00
0005433784325	8380	Economy	6000.00
0005435269716	8380	Economy	6000.00
0005434244609	8380	Economy	6000.00
0005433784532	8380	Economy	6000.00
0005435269707	8380	Economy	6000.00
0005434244634	8380	Economy	6000.00
0005433784410	8380	Economy	6000.00
0005433784516	8380	Economy	6000.00
0005434244558	8380	Economy	6000.00
0005433784371	8380	Economy	6000.00
0005434244720	8380	Economy	6000.00
0005435269715	8380	Economy	6600.00
0005434244560	8380	Economy	6000.00
0005433784459	8380	Economy	6000.00
0005433784348	8380	Economy	6600.00
0005434244580	8380	Economy	6000.00
0005433784478	8380	Economy	6000.00
0005433784370	8380	Economy	6000.00
0005433784347	8380	Economy	6000.00
0005433784590	8380	Economy	6000.00
0005435269713	8380	Economy	6000.00
0005435269704	8380	Economy	6000.00
0005434244670	8380	Economy	6000.00
0005435269717	8380	Economy	6000.00
0005433784421	8380	Economy	6000.00
0005434244613	8380	Economy	6000.00
0005434244648	8380	Economy	6000.00
0005435269718	8380	Economy	6000.00
0005432659671	8380	Economy	6000.00
0005433784394	8380	Economy	6000.00
0005433784489	8380	Economy	6000.00
0005433784548	8380	Economy	6000.00
0005434244518	8380	Economy	6000.00
0005434244584	8380	Economy	6000.00
0005433784481	8380	Economy	6000.00
0005435269708	8380	Economy	6000.00
0005435269722	8380	Economy	6000.00
0005433784517	8380	Economy	6000.00
0005434244608	8380	Economy	6000.00
0005433784511	8380	Economy	6000.00
0005433784438	8380	Economy	6000.00
0005434244692	8380	Economy	6000.00
0005434244540	8380	Economy	6000.00
0005434244563	8380	Economy	6000.00
0005434244633	8380	Economy	6000.00
0005435269721	8380	Economy	6000.00
0005433784372	8380	Economy	6000.00
0005433784538	8380	Economy	6000.00
0005434244541	8380	Economy	6000.00
0005434244645	8380	Economy	6000.00
0005433784455	8380	Economy	6000.00
0005433784342	8380	Economy	6000.00
0005434244640	8380	Economy	6000.00
0005434244639	8380	Economy	6000.00
0005433784414	8380	Economy	6000.00
0005435269710	8380	Economy	6000.00
0005433784384	8380	Economy	6000.00
0005433613658	8381	Business	18000.00
0005433613479	8381	Business	18000.00
0005433613537	8381	Business	18000.00
0005433613483	8381	Business	18000.00
0005433613469	8381	Business	18000.00
0005433613702	8381	Business	18000.00
0005433613621	8381	Business	18000.00
0005433613713	8381	Business	18000.00
0005433613680	8381	Business	18000.00
0005433613735	8381	Business	18000.00
0005433613466	8381	Economy	6600.00
0005433613515	8381	Economy	6000.00
0005433613697	8381	Economy	6000.00
0005433613596	8381	Economy	6000.00
0005433613677	8381	Economy	6000.00
0005433613531	8381	Economy	6000.00
0005433613536	8381	Economy	6000.00
0005433613705	8381	Economy	6000.00
0005433613507	8381	Economy	6000.00
0005433613468	8381	Economy	6000.00
0005433613841	8381	Economy	6000.00
0005433613714	8381	Economy	6000.00
0005433613725	8381	Economy	6000.00
0005433613607	8381	Economy	6000.00
0005433613655	8381	Economy	6000.00
0005433613636	8381	Economy	6000.00
0005433613547	8381	Economy	6000.00
0005433613701	8381	Economy	6600.00
0005433613673	8381	Economy	6000.00
0005433613623	8381	Economy	6000.00
0005433613552	8381	Economy	6000.00
0005433613605	8381	Economy	6000.00
0005433613574	8381	Economy	6000.00
0005433613597	8381	Economy	6000.00
0005433613497	8381	Economy	6000.00
0005433613622	8381	Economy	6000.00
0005433613553	8381	Economy	6000.00
0005433613606	8381	Economy	6000.00
0005433613598	8381	Economy	6000.00
0005433613752	8381	Economy	6000.00
0005433613482	8381	Economy	6000.00
0005433613517	8381	Economy	6000.00
0005433613715	8381	Economy	6000.00
0005433613555	8381	Economy	6000.00
0005433613793	8381	Economy	6000.00
0005433613850	8381	Economy	6000.00
0005433613690	8381	Economy	6000.00
0005433613575	8381	Economy	6000.00
0005433613506	8381	Economy	6000.00
0005434149552	8382	Business	18000.00
0005435006902	8382	Business	18000.00
0005435006916	8382	Business	18000.00
0005434149586	8382	Business	18000.00
0005433815360	8382	Business	18000.00
0005432047529	8382	Business	18000.00
0005432034804	8382	Business	18000.00
0005432034810	8382	Business	18000.00
0005435286597	8382	Business	18000.00
0005432034792	8382	Business	18000.00
0005434149523	8382	Business	18000.00
0005432034793	8382	Business	18000.00
0005433534488	8382	Business	18000.00
0005433815363	8382	Business	18000.00
0005434264729	8382	Business	18000.00
0005434149660	8382	Business	18000.00
0005432034811	8382	Business	18000.00
0005434264802	8382	Business	18000.00
0005432034815	8382	Business	18000.00
0005434229049	8382	Business	18000.00
0005434229038	8382	Business	18000.00
0005435006898	8382	Business	18000.00
0005434229037	8382	Business	18000.00
0005432034791	8382	Business	18000.00
0005432034806	8382	Business	18000.00
0005434173479	8382	Business	18000.00
0005434229064	8382	Economy	6600.00
0005432034805	8382	Economy	6600.00
0005435006911	8382	Economy	6600.00
0005432335974	8382	Economy	6600.00
0005432034817	8382	Economy	6600.00
0005434149597	8382	Economy	6600.00
0005435006914	8382	Economy	6000.00
0005433688799	8382	Economy	6000.00
0005434264745	8382	Economy	6000.00
0005432034809	8382	Economy	6000.00
0005435006917	8382	Economy	6000.00
0005432034799	8382	Economy	6000.00
0005434264783	8382	Economy	6000.00
0005434264838	8382	Economy	6000.00
0005435286599	8382	Economy	6000.00
0005435006907	8382	Economy	6000.00
0005434228994	8382	Economy	6000.00
0005434229094	8382	Economy	6000.00
0005433815361	8382	Economy	6000.00
0005434229083	8382	Economy	6000.00
0005432034795	8382	Economy	6000.00
0005432335971	8382	Economy	6000.00
0005433534486	8382	Economy	6000.00
0005432335970	8382	Economy	6000.00
0005432335967	8382	Economy	6000.00
0005432034798	8382	Economy	6000.00
0005434264710	8382	Economy	6000.00
0005432034801	8382	Economy	6000.00
0005435006912	8382	Economy	6000.00
0005435006899	8382	Economy	6000.00
0005435006894	8382	Economy	6000.00
0005434228982	8382	Economy	6000.00
0005434229009	8382	Economy	6000.00
0005432335973	8382	Economy	6000.00
0005432034803	8382	Economy	6000.00
0005434229000	8382	Economy	6000.00
0005432047531	8382	Economy	6000.00
0005434229082	8382	Economy	6000.00
0005435006908	8382	Economy	6000.00
0005435286602	8382	Economy	6000.00
0005434264775	8382	Economy	6000.00
0005435006893	8382	Economy	6000.00
0005434264821	8382	Economy	6000.00
0005435006904	8382	Economy	6000.00
0005434149522	8382	Economy	6000.00
0005434311209	8382	Economy	6000.00
0005434264865	8382	Economy	6000.00
0005435006915	8382	Economy	6000.00
0005432047530	8382	Economy	6000.00
0005433689901	8382	Economy	6000.00
0005432034802	8382	Economy	6000.00
0005434229092	8382	Economy	6000.00
0005435006901	8382	Economy	6000.00
0005432335975	8382	Economy	6000.00
0005432034797	8382	Economy	6000.00
0005432034816	8382	Economy	6600.00
0005434229036	8382	Economy	6600.00
0005432335978	8382	Economy	6600.00
0005435286598	8382	Economy	6000.00
0005435006918	8382	Economy	6000.00
0005432034813	8382	Economy	6000.00
0005434264784	8382	Economy	6000.00
0005435006895	8382	Economy	6600.00
0005434229063	8382	Economy	6000.00
0005434173455	8382	Economy	6000.00
0005435006910	8382	Economy	6000.00
0005433815362	8382	Economy	6000.00
0005435006906	8382	Economy	6000.00
0005432034812	8382	Economy	6000.00
0005435286603	8382	Economy	6000.00
0005434149598	8382	Economy	6000.00
0005432335969	8382	Economy	6000.00
0005434149560	8382	Economy	6000.00
0005434264730	8382	Economy	6000.00
0005434173462	8382	Economy	6000.00
0005434264731	8382	Economy	6000.00
0005434264721	8382	Economy	6000.00
0005435006896	8382	Economy	6000.00
0005432335976	8382	Economy	6000.00
0005435006913	8382	Economy	6000.00
0005434149533	8382	Economy	6000.00
0005433688798	8382	Economy	6000.00
0005434229096	8382	Economy	6000.00
0005432034819	8382	Economy	6000.00
0005434173463	8382	Economy	6000.00
0005435286604	8382	Economy	6000.00
0005433815359	8382	Economy	6000.00
0005434149535	8382	Economy	6000.00
0005432034800	8382	Economy	6000.00
0005434149524	8382	Economy	6000.00
0005434264834	8382	Economy	6000.00
0005432034794	8382	Economy	6000.00
0005434229118	8382	Economy	6000.00
0005434149532	8382	Economy	6000.00
0005435286600	8382	Economy	6000.00
0005435006903	8382	Economy	6000.00
0005435006897	8382	Economy	6000.00
0005432047532	8382	Economy	6000.00
0005435286596	8382	Economy	6000.00
0005435286601	8382	Economy	6000.00
0005432034814	8382	Economy	6000.00
0005435006909	8382	Economy	6000.00
0005434264785	8382	Economy	6000.00
0005432335968	8382	Economy	6000.00
0005434149568	8382	Economy	6000.00
0005434264871	8382	Economy	6000.00
0005432335977	8382	Economy	6000.00
0005432034808	8382	Economy	6000.00
0005434264698	8382	Economy	6000.00
0005435006905	8382	Economy	6000.00
0005432034807	8382	Economy	6000.00
0005434264776	8382	Economy	6000.00
0005434229095	8382	Economy	6000.00
0005434173464	8382	Economy	6000.00
0005432335972	8382	Economy	6000.00
0005432034796	8382	Economy	6000.00
0005434149569	8382	Economy	6000.00
0005435006900	8382	Economy	6000.00
0005434264801	8382	Economy	6000.00
0005434264833	8382	Economy	6000.00
0005433689900	8382	Economy	6000.00
0005432034818	8382	Economy	6000.00
0005433534487	8382	Economy	6000.00
0005433202288	12609	Economy	16200.00
0005433202285	12609	Economy	16200.00
0005434638965	12609	Economy	16200.00
0005433202294	12609	Economy	16200.00
0005434639035	12609	Economy	14800.00
0005434639047	12609	Economy	14800.00
0005434639008	12609	Economy	14800.00
0005434638966	12609	Economy	14800.00
0005434639056	12609	Economy	14800.00
0005434638884	12609	Economy	14800.00
0005433202292	12609	Economy	14800.00
0005433202290	12609	Economy	14800.00
0005433202289	12609	Economy	14800.00
0005433202283	12609	Economy	14800.00
0005433202287	12609	Economy	14800.00
0005433202291	12609	Economy	14800.00
0005434639075	12609	Economy	14800.00
0005433202284	12609	Economy	14800.00
0005434638933	12609	Economy	14800.00
0005434639055	12609	Economy	14800.00
0005434639007	12609	Economy	14800.00
0005434639021	12609	Economy	14800.00
0005433202296	12609	Economy	14800.00
0005433202293	12609	Economy	14800.00
0005434639052	12609	Economy	14800.00
0005434638977	12609	Economy	14800.00
0005434638998	12609	Economy	14800.00
0005434638897	12609	Economy	14800.00
0005433202295	12609	Economy	14800.00
0005434639016	12609	Economy	14800.00
0005434638883	12609	Economy	14800.00
0005434638865	12609	Economy	14800.00
0005434639089	12609	Economy	14800.00
0005434639076	12609	Economy	14800.00
0005434639036	12609	Economy	14800.00
0005434638997	12609	Economy	14800.00
0005434639046	12609	Economy	14800.00
0005434639074	12609	Economy	14800.00
0005434638936	12609	Economy	14800.00
0005433202286	12609	Economy	14800.00
0005433202297	12609	Economy	14800.00
0005434638902	12609	Economy	14800.00
0005434639175	23350	Economy	16200.00
0005434639164	23350	Economy	16200.00
0005433202153	23350	Economy	16200.00
0005434639162	23350	Economy	16200.00
0005434639171	23350	Economy	14800.00
0005434639156	23350	Economy	14800.00
0005434639174	23350	Economy	14800.00
0005434639173	23350	Economy	14800.00
0005433202171	23350	Economy	14800.00
0005433202130	23350	Economy	14800.00
0005434639176	23350	Economy	14800.00
0005434639179	23350	Economy	14800.00
0005434639154	23350	Economy	14800.00
0005434639161	23350	Economy	14800.00
0005434639155	23350	Economy	14800.00
0005433202137	23350	Economy	14800.00
0005434639166	23350	Economy	14800.00
0005433202131	23350	Economy	14800.00
0005432290615	23350	Economy	14800.00
0005433202190	23350	Economy	14800.00
0005433202105	23350	Economy	14800.00
0005434639157	23350	Economy	14800.00
0005433202104	23350	Economy	14800.00
0005434639167	23350	Economy	14800.00
0005432290616	23350	Economy	14800.00
0005434639159	23350	Economy	14800.00
0005434639177	23350	Economy	14800.00
0005434639165	23350	Economy	14800.00
0005434639168	23350	Economy	14800.00
0005434639169	23350	Economy	14800.00
0005434639180	23350	Economy	14800.00
0005433202173	23350	Economy	14800.00
0005433202167	23350	Economy	14800.00
0005434639170	23350	Economy	14800.00
0005433202138	23350	Economy	14800.00
0005433202122	23350	Economy	14800.00
0005434639158	23350	Economy	14800.00
0005434639163	23350	Economy	14800.00
0005434639172	23350	Economy	14800.00
0005433202108	23350	Economy	14800.00
0005433202157	23350	Economy	14800.00
0005434639181	23350	Economy	14800.00
0005433202132	23350	Economy	14800.00
0005434639178	23350	Economy	14800.00
0005434639182	23350	Economy	14800.00
0005434639160	23350	Economy	14800.00
0005432054290	21068	Business	18900.00
0005432382681	21068	Business	18900.00
0005432382600	21068	Business	18900.00
0005432382644	21068	Business	18900.00
0005432382738	21068	Business	18900.00
0005432328132	21068	Business	18900.00
0005432382525	21068	Business	18900.00
0005432382661	21068	Business	18900.00
0005432382651	21068	Business	18900.00
0005432327960	21068	Business	18900.00
0005432382495	21068	Business	18900.00
0005432328123	21068	Business	18900.00
0005432382500	21068	Economy	6300.00
0005432382505	21068	Economy	6300.00
0005432328216	21068	Economy	6300.00
0005432327926	21068	Economy	6300.00
0005432328215	21068	Economy	6300.00
0005432382637	21068	Economy	6300.00
0005432382624	21068	Economy	6300.00
0005432054291	21068	Economy	6300.00
0005432327974	21068	Economy	6300.00
0005432382496	21068	Economy	6900.00
0005432328050	21068	Economy	6900.00
0005432382580	21068	Economy	6900.00
0005432328122	21068	Economy	6900.00
0005432327975	21068	Economy	6300.00
0005432328008	21068	Economy	6300.00
0005432328007	21068	Economy	6300.00
0005432382899	21068	Economy	6300.00
0005432054288	21068	Economy	6300.00
0005432382534	21068	Economy	6300.00
0005432382636	21068	Economy	6300.00
0005432382645	21068	Economy	6300.00
0005432382680	21068	Economy	6300.00
0005432328046	21068	Economy	6300.00
0005432382711	21068	Economy	6300.00
0005432328041	21068	Economy	6300.00
0005432382662	21068	Economy	6300.00
0005432382596	21068	Economy	6300.00
0005432382613	21068	Economy	6300.00
0005432327961	21068	Economy	6300.00
0005432382784	21068	Economy	6300.00
0005432327927	21068	Economy	6300.00
0005432382523	21068	Economy	6300.00
0005432328036	21068	Economy	6300.00
0005432382712	21068	Economy	6300.00
0005432327963	21068	Economy	6300.00
0005432328044	21068	Economy	6300.00
0005432328016	21068	Economy	6300.00
0005432328048	21068	Economy	6300.00
0005432382619	21068	Economy	6300.00
0005432382776	21068	Economy	6300.00
0005432382898	21068	Economy	6300.00
0005432382614	21068	Economy	6300.00
0005432328207	21068	Economy	6300.00
0005432382535	21068	Economy	6300.00
0005432382579	21068	Economy	6300.00
0005432382656	21068	Economy	6300.00
0005432328032	21068	Economy	6300.00
0005432382657	21068	Economy	6300.00
0005432382708	21068	Economy	6300.00
0005432328045	21068	Economy	6300.00
0005432382595	21068	Economy	6300.00
0005432382629	21068	Economy	6300.00
0005432382601	21068	Economy	6300.00
0005432327986	21068	Economy	6300.00
0005432328042	21068	Economy	6300.00
0005432328049	21068	Economy	6300.00
0005432328047	21068	Economy	6300.00
0005432054289	21068	Economy	6300.00
0005432328157	21068	Economy	6300.00
0005432382655	21068	Economy	6300.00
0005432327987	21068	Economy	6300.00
0005432327953	21068	Economy	6300.00
0005432382654	21068	Economy	6300.00
0005432327988	21068	Economy	6300.00
0005432327964	21068	Economy	6300.00
0005432382673	21068	Economy	6300.00
0005432328017	21068	Economy	6300.00
0005432328074	21068	Economy	6300.00
0005432327922	21068	Economy	6300.00
0005432382625	21068	Economy	6300.00
0005432328043	21068	Economy	6300.00
0005432382618	21068	Economy	6300.00
0005432327976	21068	Economy	6300.00
0005432328428	31229	Business	18900.00
0005432287160	31229	Business	18900.00
0005432328409	31229	Business	18900.00
0005432328437	31229	Business	18900.00
0005432382946	31229	Business	18900.00
0005432382945	31229	Business	18900.00
0005432328407	31229	Business	18900.00
0005432382944	31229	Business	18900.00
0005432328413	31229	Business	18900.00
0005432328431	31229	Business	18900.00
0005432382939	31229	Business	18900.00
0005432382952	31229	Economy	6300.00
0005432328436	31229	Economy	6300.00
0005432382951	31229	Economy	6300.00
0005432382955	31229	Economy	6300.00
0005432382954	31229	Economy	6300.00
0005432328410	31229	Economy	6300.00
0005432328451	31229	Economy	6300.00
0005432382965	31229	Economy	6300.00
0005432382936	31229	Economy	6300.00
0005432328443	31229	Economy	6300.00
0005432382934	31229	Economy	6900.00
0005432382941	31229	Economy	6900.00
0005432287159	31229	Economy	6900.00
0005432382958	31229	Economy	6900.00
0005432382956	31229	Economy	6900.00
0005432382960	31229	Economy	6300.00
0005432382928	31229	Economy	6300.00
0005432328424	31229	Economy	6300.00
0005432382948	31229	Economy	6300.00
0005432328414	31229	Economy	6300.00
0005432328420	31229	Economy	6300.00
0005432328425	31229	Economy	6300.00
0005432287161	31229	Economy	6300.00
0005432328444	31229	Economy	6300.00
0005432382963	31229	Economy	6300.00
0005432382957	31229	Economy	6300.00
0005432328450	31229	Economy	6300.00
0005432328435	31229	Economy	6300.00
0005432328419	31229	Economy	6300.00
0005432328447	31229	Economy	6300.00
0005432328433	31229	Economy	6300.00
0005432328449	31229	Economy	6300.00
0005432382968	31229	Economy	6300.00
0005432382967	31229	Economy	6300.00
0005432328446	31229	Economy	6300.00
0005432328452	31229	Economy	6300.00
0005432328448	31229	Economy	6300.00
0005432328408	31229	Economy	6300.00
0005432328416	31229	Economy	6300.00
0005432328415	31229	Economy	6300.00
0005432328427	31229	Economy	6300.00
0005432328440	31229	Economy	6300.00
0005432382947	31229	Economy	6300.00
0005432287158	31229	Economy	6300.00
0005432382950	31229	Economy	6300.00
0005432328434	31229	Economy	6300.00
0005432328453	31229	Economy	6300.00
0005432382937	31229	Economy	6300.00
0005432382932	31229	Economy	6300.00
0005432382949	31229	Economy	6300.00
0005432382933	31229	Economy	6300.00
0005432328423	31229	Economy	6300.00
0005432382953	31229	Economy	6300.00
0005432382927	31229	Economy	6300.00
0005432328417	31229	Economy	6300.00
0005432328438	31229	Economy	6300.00
0005432328439	31229	Economy	6300.00
0005432328430	31229	Economy	6300.00
0005432328445	31229	Economy	6300.00
0005432382964	31229	Economy	6300.00
0005432382935	31229	Economy	6300.00
0005432328421	31229	Economy	6300.00
0005432328429	31229	Economy	6300.00
0005432382940	31229	Economy	6300.00
0005432382938	31229	Economy	6300.00
0005432382930	31229	Economy	6300.00
0005432328441	31229	Economy	6300.00
0005432328426	31229	Economy	6300.00
0005432328422	31229	Economy	6300.00
0005432382959	31229	Economy	6300.00
0005432328418	31229	Economy	6300.00
0005432382931	31229	Economy	6300.00
0005432382929	31229	Economy	6300.00
0005432382943	31229	Economy	6300.00
0005432382962	31229	Economy	6300.00
0005432328411	31229	Economy	6300.00
0005432328432	31229	Economy	6300.00
0005432382961	31229	Economy	6300.00
0005432382966	31229	Economy	6300.00
0005432328442	31229	Economy	6300.00
0005432382942	31229	Economy	6300.00
0005432328412	31229	Economy	6300.00
0005432424168	13352	Business	12700.00
0005432424167	13352	Business	12700.00
0005432424173	13352	Business	12700.00
0005432424174	13352	Business	12700.00
0005432424188	13352	Economy	4200.00
0005432424169	13352	Economy	4200.00
0005432424183	13352	Economy	4200.00
0005432424184	13352	Economy	4200.00
0005432424161	13352	Economy	4200.00
0005432424178	13352	Economy	4200.00
0005432424177	13352	Economy	4200.00
0005432424170	13352	Economy	4200.00
0005432424162	13352	Economy	4200.00
0005432424160	13352	Economy	4200.00
0005432424187	13352	Economy	4200.00
0005432424182	13352	Economy	4200.00
0005432424181	13352	Economy	4200.00
0005432424176	13352	Economy	4200.00
0005432424166	13352	Economy	4200.00
0005432424186	13352	Economy	4200.00
0005432424165	13352	Economy	4200.00
0005432424180	13352	Economy	4200.00
0005432424164	13352	Economy	4200.00
0005432424175	13352	Economy	4200.00
0005432424179	13352	Economy	4200.00
0005432424163	13352	Economy	4200.00
0005432424172	13352	Economy	4200.00
0005432424171	13352	Economy	4200.00
0005432424185	13352	Economy	4200.00
0005432423738	30763	Business	12700.00
0005432423666	30763	Business	12700.00
0005432423790	30763	Business	12700.00
0005432423772	30763	Business	12700.00
0005432423683	30763	Business	12700.00
0005432423693	30763	Business	12700.00
0005432423801	30763	Economy	4200.00
0005432423764	30763	Economy	4200.00
0005432423643	30763	Economy	4200.00
0005432423789	30763	Economy	4700.00
0005432423667	30763	Economy	4700.00
0005432423736	30763	Economy	4200.00
0005432423630	30763	Economy	4200.00
0005432423809	30763	Economy	4200.00
0005432423650	30763	Economy	4200.00
0005432423808	30763	Economy	4200.00
0005432423687	30763	Economy	4200.00
0005432423633	30763	Economy	4200.00
0005432423672	30763	Economy	4200.00
0005432423800	30763	Economy	4200.00
0005432423691	30763	Economy	4200.00
0005432423709	30763	Economy	4200.00
0005432423805	30763	Economy	4200.00
0005432423703	30763	Economy	4200.00
0005432423737	30763	Economy	4200.00
0005432423791	30763	Economy	4200.00
0005432423818	30763	Economy	4200.00
0005432423688	30763	Economy	4200.00
0005432423684	30763	Economy	4200.00
0005432423629	30763	Economy	4200.00
0005432423605	30763	Economy	4200.00
0005432423692	30763	Economy	4200.00
0005432423803	30763	Economy	4200.00
0005432423782	30763	Economy	4200.00
0005432423622	30763	Economy	4200.00
0005432423702	30763	Economy	4200.00
0005432423804	30763	Economy	4200.00
0005432423623	30763	Economy	4200.00
0005432822159	9574	Business	32600.00
0005432822165	9574	Business	32600.00
0005432817320	9574	Business	32600.00
0005432817307	9574	Business	32600.00
0005432901374	9574	Business	32600.00
0005432901358	9574	Business	32600.00
0005432817323	9574	Business	32600.00
0005434157399	9574	Business	32600.00
0005432817313	9574	Business	32600.00
0005432288969	9574	Business	32600.00
0005432817318	9574	Business	32600.00
0005432901338	9574	Business	32600.00
0005432901384	9574	Economy	10900.00
0005432822160	9574	Economy	10900.00
0005432288970	9574	Economy	10900.00
0005432817316	9574	Economy	10900.00
0005432817306	9574	Economy	10900.00
0005434448296	9574	Economy	10900.00
0005432822162	9574	Economy	11900.00
0005432822163	9574	Economy	11900.00
0005432817326	9574	Economy	11900.00
0005432817321	9574	Economy	10900.00
0005434157377	9574	Economy	10900.00
0005432817303	9574	Economy	10900.00
0005434448298	9574	Economy	10900.00
0005434448297	9574	Economy	10900.00
0005432901334	9574	Economy	10900.00
0005432822166	9574	Economy	10900.00
0005432817315	9574	Economy	10900.00
0005432817312	9574	Economy	10900.00
0005432817302	9574	Economy	10900.00
0005434157376	9574	Economy	10900.00
0005434157395	9574	Economy	10900.00
0005432817325	9574	Economy	10900.00
0005432901330	9574	Economy	10900.00
0005432901333	9574	Economy	10900.00
0005432817310	9574	Economy	10900.00
0005432817305	9574	Economy	10900.00
0005434157396	9574	Economy	10900.00
0005432817330	9574	Economy	10900.00
0005434157384	9574	Economy	10900.00
0005432817322	9574	Economy	10900.00
0005432901386	9574	Economy	10900.00
0005432901385	9574	Economy	10900.00
0005434157383	9574	Economy	10900.00
0005432817324	9574	Economy	10900.00
0005434157385	9574	Economy	10900.00
0005432817311	9574	Economy	10900.00
0005432817308	9574	Economy	10900.00
0005432817304	9574	Economy	10900.00
0005434157364	9574	Economy	10900.00
0005432817331	9574	Economy	10900.00
0005434157414	9574	Economy	10900.00
0005432901419	9574	Economy	10900.00
0005434157397	9574	Economy	10900.00
0005432817319	9574	Economy	10900.00
0005432901375	9574	Economy	10900.00
0005432817314	9574	Economy	10900.00
0005434157363	9574	Economy	10900.00
0005432901402	9574	Economy	10900.00
0005432817329	9574	Economy	10900.00
0005432822161	9574	Economy	10900.00
0005432901372	9574	Economy	10900.00
0005434157389	9574	Economy	10900.00
0005432288968	9574	Economy	10900.00
0005432817327	9574	Economy	10900.00
0005432288967	9574	Economy	10900.00
0005432817328	9574	Economy	10900.00
0005434157388	9574	Economy	10900.00
0005432817309	9574	Economy	10900.00
0005434157378	9574	Economy	10900.00
0005434157371	9574	Economy	10900.00
0005432817317	9574	Economy	10900.00
0005432901341	9574	Economy	10900.00
0005432822164	9574	Economy	10900.00
0005434157406	9574	Economy	10900.00
0005432816985	28964	Business	32600.00
0005432901520	28964	Business	32600.00
0005434157441	28964	Business	32600.00
0005432901522	28964	Business	32600.00
0005432822085	28964	Business	32600.00
0005432901515	28964	Business	32600.00
0005432816974	28964	Economy	10900.00
0005434157436	28964	Economy	10900.00
0005432901512	28964	Economy	10900.00
0005432817016	28964	Economy	10900.00
0005434157439	28964	Economy	10900.00
0005432822089	28964	Economy	11900.00
0005432901523	28964	Economy	11900.00
0005432817137	28964	Economy	11900.00
0005432817007	28964	Economy	10900.00
0005432817104	28964	Economy	10900.00
0005434157440	28964	Economy	10900.00
0005432817151	28964	Economy	10900.00
0005434157442	28964	Economy	10900.00
0005432817069	28964	Economy	10900.00
0005432901525	28964	Economy	10900.00
0005432901516	28964	Economy	10900.00
0005432901526	28964	Economy	10900.00
0005432816986	28964	Economy	10900.00
0005432817129	28964	Economy	10900.00
0005434157438	28964	Economy	10900.00
0005434448254	28964	Economy	10900.00
0005432817114	28964	Economy	10900.00
0005432817130	28964	Economy	10900.00
0005432002065	28964	Economy	10900.00
0005432901511	28964	Economy	10900.00
0005432817023	28964	Economy	10900.00
0005432822088	28964	Economy	10900.00
0005432817172	28964	Economy	10900.00
0005434186181	28964	Economy	10900.00
0005432901513	28964	Economy	10900.00
0005432901521	28964	Economy	10900.00
0005434448265	28964	Economy	10900.00
0005432901524	28964	Economy	10900.00
0005434448256	28964	Economy	10900.00
0005432901517	28964	Economy	10900.00
0005434448255	28964	Economy	10900.00
0005434157437	28964	Economy	10900.00
0005432901519	28964	Economy	10900.00
0005432817037	28964	Economy	10900.00
0005432901514	28964	Economy	10900.00
0005432901518	28964	Economy	10900.00
0005432901509	28964	Economy	10900.00
0005434186182	28964	Economy	10900.00
0005432817085	28964	Economy	10900.00
0005432901510	28964	Economy	10900.00
0005434186180	28964	Economy	10900.00
0005432817070	28964	Economy	10900.00
0005432822121	28964	Economy	10900.00
0005432822086	28964	Economy	10900.00
0005435841810	15080	Economy	11000.00
0005432613840	15080	Economy	11000.00
0005432611691	15080	Economy	11000.00
0005432613842	15080	Economy	11000.00
0005432613841	15080	Economy	11000.00
0005435841811	15080	Economy	11000.00
0005432613843	15080	Economy	11000.00
0005432611690	15080	Economy	11000.00
0005432613839	15080	Economy	11000.00
0005432611689	15080	Economy	11000.00
0005432611692	15080	Economy	11000.00
0005435841819	31553	Economy	11000.00
0005432607510	31553	Economy	11000.00
0005432607499	31553	Economy	11000.00
0005432611655	31553	Economy	11000.00
0005432607520	31553	Economy	11000.00
0005435841818	31553	Economy	11000.00
0005432607496	31553	Economy	11000.00
0005432607495	31553	Economy	11000.00
0005433568704	11851	Business	105900.00
0005433568702	11851	Business	105900.00
0005432947814	11851	Business	105900.00
0005433568703	11851	Business	105900.00
0005432947813	11851	Business	105900.00
0005433568724	11851	Business	105900.00
0005432947951	11851	Business	105900.00
0005432947801	11851	Business	105900.00
0005433568717	11851	Business	105900.00
0005433568720	11851	Business	105900.00
0005432947844	11851	Business	105900.00
0005432947828	11851	Business	105900.00
0005433568682	11851	Business	105900.00
0005433568733	11851	Business	105900.00
0005432948009	11851	Business	105900.00
0005433568710	11851	Business	105900.00
0005433568705	11851	Business	105900.00
0005432947924	11851	Business	105900.00
0005433568688	11851	Business	105900.00
0005432947902	11851	Business	105900.00
0005433568712	11851	Economy	35300.00
0005432947923	11851	Economy	35300.00
0005433568698	11851	Economy	35300.00
0005432947870	11851	Economy	35300.00
0005433568735	11851	Economy	35300.00
0005433568721	11851	Economy	35300.00
0005432947918	11851	Economy	35300.00
0005433568719	11851	Economy	35300.00
0005433568709	11851	Economy	35300.00
0005432947848	11851	Economy	35300.00
0005433568731	11851	Economy	38800.00
0005433568714	11851	Economy	38800.00
0005433568689	11851	Economy	38800.00
0005433568728	11851	Economy	35300.00
0005433568715	11851	Economy	35300.00
0005433568684	11851	Economy	35300.00
0005432947767	11851	Economy	35300.00
0005433568681	11851	Economy	35300.00
0005433568706	11851	Economy	35300.00
0005432947871	11851	Economy	35300.00
0005433568695	11851	Economy	35300.00
0005433568737	11851	Economy	35300.00
0005432947900	11851	Economy	35300.00
0005433568726	11851	Economy	35300.00
0005432947904	11851	Economy	35300.00
0005433568716	11851	Economy	35300.00
0005433568729	11851	Economy	35300.00
0005433568690	11851	Economy	35300.00
0005433568730	11851	Economy	35300.00
0005433568685	11851	Economy	35300.00
0005432947815	11851	Economy	35300.00
0005432947816	11851	Economy	35300.00
0005433568697	11851	Economy	35300.00
0005432947820	11851	Economy	35300.00
0005432947921	11851	Economy	35300.00
0005433568722	11851	Economy	35300.00
0005432947768	11851	Economy	35300.00
0005432947922	11851	Economy	35300.00
0005432947863	11851	Economy	35300.00
0005432947831	11851	Economy	35300.00
0005432947970	11851	Economy	35300.00
0005433568691	11851	Economy	35300.00
0005432947929	11851	Economy	35300.00
0005433568692	11851	Economy	35300.00
0005433568718	11851	Economy	35300.00
0005433568680	11851	Economy	35300.00
0005433568696	11851	Economy	35300.00
0005432947875	11851	Economy	35300.00
0005432947822	11851	Economy	35300.00
0005432947766	11851	Economy	35300.00
0005433568727	11851	Economy	35300.00
0005432947845	11851	Economy	35300.00
0005432947950	11851	Economy	35300.00
0005432947780	11851	Economy	35300.00
0005432947866	11851	Economy	35300.00
0005433568707	11851	Economy	35300.00
0005433568723	11851	Economy	35300.00
0005432947781	11851	Economy	35300.00
0005433568687	11851	Economy	35300.00
0005433568736	11851	Economy	35300.00
0005433568734	11851	Economy	35300.00
0005432947885	11851	Economy	35300.00
0005433568732	11851	Economy	35300.00
0005433568700	11851	Economy	35300.00
0005433568683	11851	Economy	35300.00
0005432947969	11851	Economy	35300.00
0005433568686	11851	Economy	35300.00
0005433568711	11851	Economy	35300.00
0005432948082	11851	Economy	35300.00
0005433568693	11851	Economy	35300.00
0005432947901	11851	Economy	35300.00
0005432947782	11851	Economy	35300.00
0005433568713	11851	Economy	35300.00
0005433568699	11851	Economy	35300.00
0005432947952	11851	Economy	35300.00
0005433568708	11851	Economy	35300.00
0005432947802	11851	Economy	35300.00
0005432947911	11851	Economy	35300.00
0005432948008	11851	Economy	35300.00
0005433568725	11851	Economy	35300.00
0005433568701	11851	Economy	35300.00
0005433568694	11851	Economy	35300.00
0005432947832	11851	Economy	35300.00
0005432948288	25269	Business	105900.00
0005432948300	25269	Business	105900.00
0005433568046	25269	Business	105900.00
0005433568352	25269	Business	105900.00
0005433568291	25269	Business	105900.00
0005433568139	25269	Business	105900.00
0005432948267	25269	Business	105900.00
0005432948297	25269	Business	105900.00
0005432948281	25269	Business	105900.00
0005433568311	25269	Business	105900.00
0005433568080	25269	Business	105900.00
0005432948287	25269	Business	105900.00
0005433568246	25269	Business	105900.00
0005433568276	25269	Business	105900.00
0005433568116	25269	Business	105900.00
0005433568247	25269	Business	105900.00
0005433568079	25269	Business	105900.00
0005432948301	25269	Economy	35300.00
0005433568208	25269	Economy	35300.00
0005432948302	25269	Economy	35300.00
0005433568034	25269	Economy	35300.00
0005433568223	25269	Economy	35300.00
0005432948277	25269	Economy	35300.00
0005432948291	25269	Economy	35300.00
0005433568127	25269	Economy	35300.00
0005432948275	25269	Economy	38800.00
0005433568308	25269	Economy	38800.00
0005433568241	25269	Economy	35300.00
0005433568153	25269	Economy	35300.00
0005433568115	25269	Economy	35300.00
0005433568164	25269	Economy	35300.00
0005433568245	25269	Economy	35300.00
0005432948279	25269	Economy	35300.00
0005433568136	25269	Economy	35300.00
0005432948271	25269	Economy	35300.00
0005433568172	25269	Economy	35300.00
0005432948294	25269	Economy	35300.00
0005433568318	25269	Economy	35300.00
0005432948286	25269	Economy	35300.00
0005433568299	25269	Economy	35300.00
0005432948284	25269	Economy	35300.00
0005432948283	25269	Economy	35300.00
0005433568045	25269	Economy	35300.00
0005433568266	25269	Economy	35300.00
0005433568307	25269	Economy	35300.00
0005433568216	25269	Economy	35300.00
0005433568351	25269	Economy	35300.00
0005433568128	25269	Economy	35300.00
0005432948274	25269	Economy	35300.00
0005433568090	25269	Economy	35300.00
0005432948295	25269	Economy	35300.00
0005432948285	25269	Economy	35300.00
0005433568149	25269	Economy	35300.00
0005433568333	25269	Economy	35300.00
0005432948293	25269	Economy	35300.00
0005433568129	25269	Economy	35300.00
0005433568057	25269	Economy	35300.00
0005432948290	25269	Economy	35300.00
0005432948269	25269	Economy	35300.00
0005432948268	25269	Economy	35300.00
0005432948278	25269	Economy	35300.00
0005433568168	25269	Economy	35300.00
0005432948264	25269	Economy	35300.00
0005433568154	25269	Economy	35300.00
0005432948265	25269	Economy	35300.00
0005433568209	25269	Economy	35300.00
0005432948289	25269	Economy	35300.00
0005433568047	25269	Economy	35300.00
0005432948276	25269	Economy	35300.00
0005433568171	25269	Economy	35300.00
0005432948270	25269	Economy	35300.00
0005432948266	25269	Economy	35300.00
0005433568147	25269	Economy	35300.00
0005432948298	25269	Economy	35300.00
0005433568239	25269	Economy	35300.00
0005433568269	25269	Economy	35300.00
0005433568137	25269	Economy	35300.00
0005432948280	25269	Economy	35300.00
0005432948304	25269	Economy	35300.00
0005433568078	25269	Economy	35300.00
0005433568279	25269	Economy	35300.00
0005433568170	25269	Economy	35300.00
0005433568221	25269	Economy	35300.00
0005432948303	25269	Economy	35300.00
0005433568306	25269	Economy	35300.00
0005433568061	25269	Economy	35300.00
0005433568300	25269	Economy	35300.00
0005433568062	25269	Economy	35300.00
0005433568327	25269	Economy	35300.00
0005432948292	25269	Economy	35300.00
0005432948299	25269	Economy	35300.00
0005432948273	25269	Economy	35300.00
0005433568332	25269	Economy	35300.00
0005433568222	25269	Economy	35300.00
0005433568356	25269	Economy	35300.00
0005433568065	25269	Economy	35300.00
0005432948282	25269	Economy	35300.00
0005432948272	25269	Economy	35300.00
0005432948296	25269	Economy	35300.00
0005434654538	5421	Business	67200.00
0005434654544	5421	Business	67200.00
0005434654539	5421	Business	67200.00
0005434654521	5421	Business	67200.00
0005434654545	5421	Business	67200.00
0005434654527	5421	Economy	22400.00
0005434654536	5421	Economy	22400.00
0005435340071	5421	Economy	22400.00
0005434654523	5421	Economy	22400.00
0005434654534	5421	Economy	22400.00
0005434654531	5421	Economy	24600.00
0005434654529	5421	Economy	24600.00
0005435340075	5421	Economy	22400.00
0005434654526	5421	Economy	22400.00
0005434654541	5421	Economy	22400.00
0005434654533	5421	Economy	22400.00
0005435340004	5421	Economy	22400.00
0005435340053	5421	Economy	22400.00
0005435555341	5421	Economy	22400.00
0005435340077	5421	Economy	22400.00
0005432114186	5421	Economy	22400.00
0005434654543	5421	Economy	22400.00
0005434654535	5421	Economy	22400.00
0005434654537	5421	Economy	22400.00
0005434654542	5421	Economy	22400.00
0005435340065	5421	Economy	22400.00
0005435340083	5421	Economy	22400.00
0005434654522	5421	Economy	22400.00
0005434654518	5421	Economy	22400.00
0005435340029	5421	Economy	22400.00
0005435555334	5421	Economy	22400.00
0005435340008	5421	Economy	22400.00
0005434654532	5421	Economy	22400.00
0005432114187	5421	Economy	22400.00
0005435555335	5421	Economy	22400.00
0005434656545	5421	Economy	22400.00
0005434654528	5421	Economy	22400.00
0005434654540	5421	Economy	22400.00
0005434656546	5421	Economy	22400.00
0005435555344	5421	Economy	22400.00
0005434654546	5421	Economy	22400.00
0005434654520	5421	Economy	22400.00
0005434654547	5421	Economy	22400.00
0005435340052	5421	Economy	22400.00
0005434654519	5421	Economy	22400.00
0005434654530	5421	Economy	22400.00
0005434654525	5421	Economy	22400.00
0005435340087	5421	Economy	22400.00
0005435340007	5421	Economy	22400.00
0005432114185	5421	Economy	22400.00
0005434654524	5421	Economy	22400.00
0005434654418	12536	Business	67200.00
0005435340184	12536	Business	67200.00
0005435340190	12536	Business	67200.00
0005435340176	12536	Business	67200.00
0005434654222	12536	Business	67200.00
0005434656524	12536	Business	67200.00
0005435340179	12536	Business	67200.00
0005434654419	12536	Business	67200.00
0005435340180	12536	Business	67200.00
0005435555360	12536	Economy	22400.00
0005434654420	12536	Economy	22400.00
0005434654358	12536	Economy	22400.00
0005434656530	12536	Economy	22400.00
0005434654274	12536	Economy	22400.00
0005434654231	12536	Economy	24600.00
0005434654173	12536	Economy	24600.00
0005434656531	12536	Economy	22400.00
0005434654351	12536	Economy	22400.00
0005434654394	12536	Economy	22400.00
0005434654349	12536	Economy	22400.00
0005434654368	12536	Economy	22400.00
0005435340182	12536	Economy	22400.00
0005435340187	12536	Economy	22400.00
0005434654350	12536	Economy	22400.00
0005435340189	12536	Economy	22400.00
0005434654314	12536	Economy	22400.00
0005434654366	12536	Economy	22400.00
0005434654167	12536	Economy	22400.00
0005434654218	12536	Economy	22400.00
0005434654277	12536	Economy	22400.00
0005435340183	12536	Economy	22400.00
0005435555361	12536	Economy	22400.00
0005434654275	12536	Economy	22400.00
0005435340181	12536	Economy	22400.00
0005434654290	12536	Economy	22400.00
0005434654248	12536	Economy	22400.00
0005435340178	12536	Economy	22400.00
0005435340185	12536	Economy	22400.00
0005434654356	12536	Economy	22400.00
0005435340177	12536	Economy	22400.00
0005434654247	12536	Economy	22400.00
0005435340191	12536	Economy	22400.00
0005435555359	12536	Economy	22400.00
0005434654403	12536	Economy	22400.00
0005435340175	12536	Economy	22400.00
0005434654357	12536	Economy	22400.00
0005434656527	12536	Economy	22400.00
0005435340188	12536	Economy	22400.00
0005435340186	12536	Economy	22400.00
0005434654296	12536	Economy	22400.00
0005434654207	12536	Economy	22400.00
0005434654172	12536	Economy	22400.00
0005432428882	7460	Business	32000.00
0005433715688	7460	Business	32000.00
0005433715722	7460	Business	32000.00
0005433689899	7460	Business	32000.00
0005433715704	7460	Business	32000.00
0005433715718	7460	Business	32000.00
0005433715693	7460	Business	32000.00
0005433719120	7460	Economy	10700.00
0005433722182	7460	Economy	10700.00
0005432078080	7460	Economy	10700.00
0005433715697	7460	Economy	10700.00
0005433722183	7460	Economy	10700.00
0005433715706	7460	Economy	10700.00
0005433715725	7460	Economy	10700.00
0005433719121	7460	Economy	10700.00
0005433688797	7460	Economy	10700.00
0005433715724	7460	Economy	10700.00
0005435266097	7460	Economy	10700.00
0005433656651	7460	Economy	10700.00
0005433656650	7460	Economy	10700.00
0005433715720	7460	Economy	10700.00
0005433715710	7460	Economy	10700.00
0005433690914	7460	Economy	10700.00
0005433690915	7460	Economy	10700.00
0005433715680	7460	Economy	10700.00
0005433715689	7460	Economy	10700.00
0005433715717	7460	Economy	10700.00
0005433715690	7460	Economy	10700.00
0005433715683	7460	Economy	10700.00
0005432428869	7460	Economy	10700.00
0005433715702	7460	Economy	10700.00
0005433715723	7460	Economy	10700.00
0005433715694	7460	Economy	11700.00
0005433722180	7460	Economy	11700.00
0005433715711	7460	Economy	11700.00
0005433690916	7460	Economy	11700.00
0005433722184	7460	Economy	10700.00
0005432428880	7460	Economy	10700.00
0005433715721	7460	Economy	10700.00
0005433722186	7460	Economy	10700.00
0005433722185	7460	Economy	10700.00
0005433715692	7460	Economy	10700.00
0005433715726	7460	Economy	10700.00
0005433715701	7460	Economy	10700.00
0005433719119	7460	Economy	10700.00
0005433715719	7460	Economy	10700.00
0005432078077	7460	Economy	10700.00
0005432078081	7460	Economy	10700.00
0005433715691	7460	Economy	10700.00
0005433715712	7460	Economy	10700.00
0005433656652	7460	Economy	10700.00
0005433715681	7460	Economy	10700.00
0005433715684	7460	Economy	10700.00
0005433715700	7460	Economy	10700.00
0005433715709	7460	Economy	10700.00
0005435266093	7460	Economy	10700.00
0005433722181	7460	Economy	10700.00
0005433656649	7460	Economy	10700.00
0005433715728	7460	Economy	10700.00
0005432428881	7460	Economy	10700.00
0005433715713	7460	Economy	10700.00
0005433715686	7460	Economy	10700.00
0005433715708	7460	Economy	10700.00
0005435266078	7460	Economy	10700.00
0005433715716	7460	Economy	10700.00
0005433715682	7460	Economy	10700.00
0005433715698	7460	Economy	10700.00
0005433715703	7460	Economy	10700.00
0005433715715	7460	Economy	10700.00
0005433715707	7460	Economy	10700.00
0005433689898	7460	Economy	10700.00
0005433715727	7460	Economy	10700.00
0005433715687	7460	Economy	10700.00
0005433715714	7460	Economy	10700.00
0005433715699	7460	Economy	10700.00
0005432078078	7460	Economy	10700.00
0005433715730	7460	Economy	10700.00
0005433715695	7460	Economy	10700.00
0005433722179	7460	Economy	10700.00
0005433715685	7460	Economy	10700.00
0005432078079	7460	Economy	10700.00
0005433715705	7460	Economy	10700.00
0005433715696	7460	Economy	10700.00
0005433715729	7460	Economy	10700.00
0005433715432	29206	Business	32000.00
0005433715396	29206	Business	32000.00
0005433722124	29206	Business	32000.00
0005433722107	29206	Business	32000.00
0005433715194	29206	Business	32000.00
0005435266126	29206	Business	32000.00
0005433715246	29206	Business	32000.00
0005433715372	29206	Business	32000.00
0005432006745	29206	Business	32000.00
0005433715102	29206	Economy	10700.00
0005433715287	29206	Economy	10700.00
0005433715176	29206	Economy	10700.00
0005433715281	29206	Economy	10700.00
0005433715458	29206	Economy	10700.00
0005435266133	29206	Economy	10700.00
0005433688774	29206	Economy	10700.00
0005433719097	29206	Economy	10700.00
0005435266131	29206	Economy	10700.00
0005432006744	29206	Economy	10700.00
0005433715127	29206	Economy	10700.00
0005433715247	29206	Economy	10700.00
0005433715408	29206	Economy	10700.00
0005433719085	29206	Economy	10700.00
0005433656617	29206	Economy	10700.00
0005435266129	29206	Economy	10700.00
0005433722111	29206	Economy	10700.00
0005433715266	29206	Economy	10700.00
0005433715267	29206	Economy	10700.00
0005433688775	29206	Economy	10700.00
0005433715406	29206	Economy	10700.00
0005433715334	29206	Economy	10700.00
0005433715250	29206	Economy	11700.00
0005433722110	29206	Economy	10700.00
0005433715137	29206	Economy	11700.00
0005433715447	29206	Economy	11700.00
0005433715317	29206	Economy	10700.00
0005433722105	29206	Economy	10700.00
0005433715232	29206	Economy	10700.00
0005433715223	29206	Economy	10700.00
0005433656623	29206	Economy	10700.00
0005433715260	29206	Economy	10700.00
0005433722112	29206	Economy	10700.00
0005433685491	29206	Economy	10700.00
0005433715383	29206	Economy	10700.00
0005433715299	29206	Economy	10700.00
0005435266132	29206	Economy	10700.00
0005432428912	29206	Economy	10700.00
0005435266125	29206	Economy	10700.00
0005433715395	29206	Economy	10700.00
0005433722117	29206	Economy	10700.00
0005433715195	29206	Economy	10700.00
0005433715294	29206	Economy	10700.00
0005433715371	29206	Economy	10700.00
0005433715394	29206	Economy	10700.00
0005433656621	29206	Economy	10700.00
0005433715259	29206	Economy	10700.00
0005432428910	29206	Economy	10700.00
0005433656626	29206	Economy	10700.00
0005433722130	29206	Economy	10700.00
0005432428909	29206	Economy	10700.00
0005435266130	29206	Economy	10700.00
0005435266127	29206	Economy	10700.00
0005433715471	29206	Economy	10700.00
0005433715423	29206	Economy	10700.00
0005433715089	29206	Economy	10700.00
0005433715405	29206	Economy	10700.00
0005433715201	29206	Economy	10700.00
0005433715422	29206	Economy	10700.00
0005433715268	29206	Economy	10700.00
0005432006746	29206	Economy	10700.00
0005433722120	29206	Economy	10700.00
0005433722109	29206	Economy	10700.00
0005432428911	29206	Economy	10700.00
0005433715222	29206	Economy	10700.00
0005433656618	29206	Economy	10700.00
0005433715407	29206	Economy	10700.00
0005435266128	29206	Economy	10700.00
0005434182019	8703	Business	36500.00
0005434095194	8703	Business	36500.00
0005434184635	8703	Business	36500.00
0005434182022	8703	Business	36500.00
0005434143719	8703	Business	36500.00
0005434095192	8703	Economy	12200.00
0005434095205	8703	Economy	12200.00
0005434095206	8703	Economy	12200.00
0005434095193	8703	Economy	13400.00
0005434095202	8703	Economy	13400.00
0005434143721	8703	Economy	13400.00
0005434143718	8703	Economy	12200.00
0005434143720	8703	Economy	12200.00
0005434095200	8703	Economy	12200.00
0005434095199	8703	Economy	12200.00
0005434182050	8703	Economy	12200.00
0005434095204	8703	Economy	12200.00
0005434143723	8703	Economy	12200.00
0005434095203	8703	Economy	12200.00
0005434184634	8703	Economy	12200.00
0005434181995	8703	Economy	12200.00
0005434182021	8703	Economy	12200.00
0005434143722	8703	Economy	12200.00
0005434182020	8703	Economy	12200.00
0005434095198	8703	Economy	12200.00
0005434182051	8703	Economy	12200.00
0005434095196	8703	Economy	12200.00
0005434143724	8703	Economy	12200.00
0005434143717	8703	Economy	12200.00
0005434095195	8703	Economy	12200.00
0005434095201	8703	Economy	12200.00
0005434095197	8703	Economy	12200.00
0005434182023	8703	Economy	12200.00
0005434095054	11674	Business	36500.00
0005434182113	11674	Business	36500.00
0005434182117	11674	Business	36500.00
0005434182114	11674	Business	36500.00
0005434182111	11674	Business	36500.00
0005434183566	11674	Economy	12200.00
0005434143698	11674	Economy	13400.00
0005434095070	11674	Economy	13400.00
0005434182118	11674	Economy	12200.00
0005434182121	11674	Economy	12200.00
0005434095023	11674	Economy	12200.00
0005434095052	11674	Economy	12200.00
0005434182116	11674	Economy	12200.00
0005434184652	11674	Economy	12200.00
0005434182112	11674	Economy	12200.00
0005434182119	11674	Economy	12200.00
0005434095053	11674	Economy	12200.00
0005434182120	11674	Economy	12200.00
0005434182122	11674	Economy	12200.00
0005434182123	11674	Economy	12200.00
0005434095059	11674	Economy	12200.00
0005434183567	11674	Economy	12200.00
0005434182115	11674	Economy	12200.00
0005434184653	11674	Economy	12200.00
0005434095044	11674	Economy	12200.00
0005433397285	1419	Business	33000.00
0005433397362	1419	Business	33000.00
0005433456947	1419	Business	33000.00
0005433397289	1419	Business	33000.00
0005433397530	1419	Business	33000.00
0005433397207	1419	Economy	11000.00
0005433397467	1419	Economy	11000.00
0005433397367	1419	Economy	11000.00
0005433397431	1419	Economy	11000.00
0005433397236	1419	Economy	11000.00
0005433397363	1419	Economy	11000.00
0005433397660	1419	Economy	11000.00
0005433397353	1419	Economy	11000.00
0005433397342	1419	Economy	11000.00
0005433397405	1419	Economy	11000.00
0005433397387	1419	Economy	12100.00
0005435732279	1419	Economy	12100.00
0005432297264	1419	Economy	11000.00
0005433397360	1419	Economy	11000.00
0005433456946	1419	Economy	11000.00
0005433397208	1419	Economy	11000.00
0005435732278	1419	Economy	11000.00
0005433397563	1419	Economy	11000.00
0005433397408	1419	Economy	11000.00
0005433397388	1419	Economy	11000.00
0005433397239	1419	Economy	11000.00
0005433397374	1419	Economy	11000.00
0005432906496	1419	Economy	11000.00
0005432297263	1419	Economy	11000.00
0005433397357	1419	Economy	11000.00
0005433397351	1419	Economy	11000.00
0005433397430	1419	Economy	11000.00
0005433397523	1419	Economy	11000.00
0005433397331	1419	Economy	11000.00
0005435732281	1419	Economy	11000.00
0005433397286	1419	Economy	11000.00
0005433456949	1419	Economy	11000.00
0005433397319	1419	Economy	11000.00
0005433397508	1419	Economy	11000.00
0005433397302	1419	Economy	11000.00
0005433397390	1419	Economy	11000.00
0005433397659	1419	Economy	11000.00
0005433397398	1419	Economy	11000.00
0005433397375	1419	Economy	11000.00
0005433397407	1419	Economy	11000.00
0005433456948	1419	Economy	11000.00
0005432297262	1419	Economy	11000.00
0005433397552	1419	Economy	11000.00
0005433397425	1419	Economy	11000.00
0005435732277	1419	Economy	11000.00
0005433397533	1419	Economy	11000.00
0005433397551	1419	Economy	11000.00
0005433397350	1419	Economy	11000.00
0005433397332	1419	Economy	11000.00
0005433397356	1419	Economy	11000.00
0005433397179	1419	Economy	11000.00
0005433397448	1419	Economy	11000.00
0005433397658	1419	Economy	11000.00
0005433397199	1419	Economy	11000.00
0005433397534	1419	Economy	11000.00
0005433397531	1419	Economy	11000.00
0005432906508	1419	Economy	11000.00
0005433397352	1419	Economy	11000.00
0005433456950	1419	Economy	11000.00
0005433397572	1419	Economy	11000.00
0005435732280	1419	Economy	11000.00
0005433456951	1419	Economy	11000.00
0005433397564	1419	Economy	11000.00
0005433397354	1419	Economy	11000.00
0005433397218	1419	Economy	11000.00
0005433397457	1419	Economy	11000.00
0005433397804	19228	Business	33000.00
0005433397796	19228	Business	33000.00
0005433397805	19228	Business	33000.00
0005435732181	19228	Business	33000.00
0005433397813	19228	Business	33000.00
0005435732135	19228	Business	33000.00
0005433397824	19228	Business	33000.00
0005433397790	19228	Business	33000.00
0005433397783	19228	Business	33000.00
0005432906523	19228	Economy	11000.00
0005433397815	19228	Economy	11000.00
0005433397817	19228	Economy	11000.00
0005433397784	19228	Economy	11000.00
0005433397778	19228	Economy	11000.00
0005433397802	19228	Economy	11000.00
0005433397779	19228	Economy	12100.00
0005433397780	19228	Economy	12100.00
0005433397788	19228	Economy	12100.00
0005433397808	19228	Economy	12100.00
0005433397803	19228	Economy	11000.00
0005433397825	19228	Economy	11000.00
0005433397814	19228	Economy	11000.00
0005435732157	19228	Economy	11000.00
0005435732191	19228	Economy	11000.00
0005433397811	19228	Economy	11000.00
0005433397812	19228	Economy	11000.00
0005433397775	19228	Economy	11000.00
0005433397785	19228	Economy	11000.00
0005433397798	19228	Economy	11000.00
0005433456921	19228	Economy	11000.00
0005433456915	19228	Economy	11000.00
0005433397781	19228	Economy	11000.00
0005435732134	19228	Economy	11000.00
0005433397776	19228	Economy	11000.00
0005433397789	19228	Economy	11000.00
0005435732195	19228	Economy	11000.00
0005432906522	19228	Economy	11000.00
0005433397794	19228	Economy	11000.00
0005433397809	19228	Economy	11000.00
0005433397786	19228	Economy	11000.00
0005433397822	19228	Economy	11000.00
0005433397806	19228	Economy	11000.00
0005433397820	19228	Economy	11000.00
0005433397777	19228	Economy	11000.00
0005435732145	19228	Economy	11000.00
0005433456922	19228	Economy	11000.00
0005433397787	19228	Economy	11000.00
0005433456917	19228	Economy	11000.00
0005435732139	19228	Economy	11000.00
0005433397819	19228	Economy	11000.00
0005435732182	19228	Economy	11000.00
0005435732125	19228	Economy	11000.00
0005435732156	19228	Economy	11000.00
0005433397807	19228	Economy	11000.00
0005433397791	19228	Economy	11000.00
0005433397816	19228	Economy	11000.00
0005433397782	19228	Economy	11000.00
0005433397821	19228	Economy	11000.00
0005435732188	19228	Economy	11000.00
0005435732179	19228	Economy	11000.00
0005433397799	19228	Economy	11000.00
0005433397792	19228	Economy	11000.00
0005433397801	19228	Economy	11000.00
0005433397823	19228	Economy	11000.00
0005433397795	19228	Economy	11000.00
0005433397800	19228	Economy	11000.00
0005433397810	19228	Economy	11000.00
0005433397797	19228	Economy	11000.00
0005433397793	19228	Economy	11000.00
0005433397818	19228	Economy	11000.00
0005434443456	17360	Economy	15600.00
0005434443531	17360	Economy	15600.00
0005434443445	17360	Economy	14100.00
0005434443439	17360	Economy	14100.00
0005434443454	17360	Economy	14100.00
0005434443503	17360	Economy	14100.00
0005434443489	17360	Economy	14100.00
0005434443471	17360	Economy	14100.00
0005434443532	17360	Economy	14100.00
0005434443473	17360	Economy	14100.00
0005434443530	17360	Economy	14100.00
0005434443538	17360	Economy	14100.00
0005434443529	17360	Economy	14100.00
0005434443464	17360	Economy	14100.00
0005434443490	17360	Economy	14100.00
0005434443614	20603	Economy	15600.00
0005434443621	20603	Economy	14100.00
0005434443609	20603	Economy	14100.00
0005434443606	20603	Economy	14100.00
0005434443617	20603	Economy	14100.00
0005434443615	20603	Economy	14100.00
0005434443619	20603	Economy	14100.00
0005434443608	20603	Economy	14100.00
0005434443612	20603	Economy	14100.00
0005434443607	20603	Economy	14100.00
0005434443610	20603	Economy	14100.00
0005434443616	20603	Economy	14100.00
0005434443618	20603	Economy	14100.00
0005434443611	20603	Economy	14100.00
0005434443605	20603	Economy	14100.00
0005434443613	20603	Economy	14100.00
0005434443620	20603	Economy	14100.00
0005434954586	7248	Economy	5800.00
0005434954589	7248	Economy	5800.00
0005435377550	7248	Economy	5800.00
0005435377552	7248	Economy	5800.00
0005434954587	7248	Economy	5800.00
0005434954588	7248	Economy	5800.00
0005435377551	7248	Economy	5800.00
0005434954573	28340	Economy	5800.00
0005434954542	28340	Economy	5800.00
0005434954570	28340	Economy	5800.00
0005435377569	28340	Economy	5800.00
0005434954552	28340	Economy	5800.00
0005435377566	28340	Economy	5800.00
0005435377567	28340	Economy	5800.00
0005434954564	28340	Economy	5800.00
0005434954553	28340	Economy	5800.00
0005435377568	28340	Economy	5800.00
0005434954569	28340	Economy	5800.00
0005434351631	4489	Economy	15400.00
0005435893510	4489	Economy	14000.00
0005434351626	4489	Economy	14000.00
0005434351630	4489	Economy	14000.00
0005434351624	4489	Economy	14000.00
0005435893591	4489	Economy	14000.00
0005434351625	4489	Economy	14000.00
0005434351629	4489	Economy	14000.00
0005434351621	4489	Economy	14000.00
0005434351628	4489	Economy	14000.00
0005434183550	4489	Economy	14000.00
0005434326268	4489	Economy	14000.00
0005434351627	4489	Economy	14000.00
0005434351633	4489	Economy	14000.00
0005434351622	4489	Economy	14000.00
0005435893592	4489	Economy	14000.00
0005434351634	4489	Economy	14000.00
0005434351632	4489	Economy	14000.00
0005434351623	4489	Economy	14000.00
0005435893591	29647	Economy	14000.00
0005434351507	29647	Economy	14000.00
0005434351509	29647	Economy	14000.00
0005434351528	29647	Economy	14000.00
0005434351488	29647	Economy	14000.00
0005435893596	29647	Economy	14000.00
0005434351536	29647	Economy	14000.00
0005435893593	29647	Economy	14000.00
0005435893595	29647	Economy	14000.00
0005435893594	29647	Economy	14000.00
0005434351508	29647	Economy	14000.00
0005434351550	29647	Economy	14000.00
0005434351537	29647	Economy	14000.00
0005434351535	29647	Economy	14000.00
0005434351538	29647	Economy	14000.00
0005434351489	29647	Economy	14000.00
0005435893592	29647	Economy	14000.00
0005433341903	1065	Business	30600.00
0005433341416	1065	Business	30600.00
0005433341633	1065	Business	30600.00
0005433341797	1065	Business	30600.00
0005435092025	1065	Business	30600.00
0005433462735	1065	Business	30600.00
0005433341592	1065	Business	30600.00
0005433341509	1065	Business	30600.00
0005433341598	1065	Business	30600.00
0005433463888	1065	Business	30600.00
0005435545694	1065	Business	30600.00
0005433341803	1065	Business	30600.00
0005433341889	1065	Business	30600.00
0005435092021	1065	Business	30600.00
0005433341495	1065	Business	30600.00
0005433341593	1065	Business	30600.00
0005433341513	1065	Business	30600.00
0005433341570	1065	Business	30600.00
0005433269649	1065	Economy	11200.00
0005433342063	1065	Economy	11200.00
0005433341698	1065	Economy	11200.00
0005435545693	1065	Economy	11200.00
0005435092023	1065	Economy	10200.00
0005433341554	1065	Economy	10200.00
0005434446511	1065	Economy	10200.00
0005433341690	1065	Economy	10200.00
0005433341564	1065	Economy	10200.00
0005433341545	1065	Economy	10200.00
0005433341508	1065	Economy	10200.00
0005433341654	1065	Economy	10200.00
0005433341459	1065	Economy	10200.00
0005433341380	1065	Economy	10200.00
0005433342093	1065	Economy	10200.00
0005433342064	1065	Economy	10200.00
0005435092027	1065	Economy	10200.00
0005433341951	1065	Economy	10200.00
0005434445237	1065	Economy	10200.00
0005433341615	1065	Economy	10200.00
0005433342255	1065	Economy	10200.00
0005433463889	1065	Economy	10200.00
0005434446510	1065	Economy	10200.00
0005433342256	1065	Economy	10200.00
0005433341544	1065	Economy	10200.00
0005434446508	1065	Economy	10200.00
0005433269667	1065	Economy	10200.00
0005433341739	1065	Economy	10200.00
0005433341492	1065	Economy	10200.00
0005433341801	1065	Economy	10200.00
0005433341594	1065	Economy	10200.00
0005435092026	1065	Economy	10200.00
0005433462734	1065	Economy	10200.00
0005433341600	1065	Economy	10200.00
0005434446509	1065	Economy	10200.00
0005433269645	1065	Economy	10200.00
0005433341458	1065	Economy	10200.00
0005435092020	1065	Economy	10200.00
0005435092016	1065	Economy	10200.00
0005435092024	1065	Economy	10200.00
0005433342281	1065	Economy	10200.00
0005433341606	1065	Economy	10200.00
0005433341381	1065	Economy	10200.00
0005435545691	1065	Economy	10200.00
0005433341385	1065	Economy	10200.00
0005433341716	1065	Economy	10200.00
0005433341496	1065	Economy	10200.00
0005433341584	1065	Economy	10200.00
0005433341867	1065	Economy	10200.00
0005433341585	1065	Economy	10200.00
0005435092017	1065	Economy	10200.00
0005435092019	1065	Economy	10200.00
0005433341657	1065	Economy	10200.00
0005433342075	1065	Economy	10200.00
0005433341713	1065	Economy	11200.00
0005433341972	1065	Economy	10200.00
0005433341599	1065	Economy	11200.00
0005433341597	1065	Economy	10200.00
0005433341589	1065	Economy	10200.00
0005433341565	1065	Economy	10200.00
0005433341802	1065	Economy	10200.00
0005433341918	1065	Economy	10200.00
0005433341494	1065	Economy	10200.00
0005433341583	1065	Economy	10200.00
0005435545695	1065	Economy	10200.00
0005435545692	1065	Economy	10200.00
0005433341553	1065	Economy	10200.00
0005433342068	1065	Economy	10200.00
0005433341806	1065	Economy	10200.00
0005433341740	1065	Economy	10200.00
0005433341714	1065	Economy	10200.00
0005434445236	1065	Economy	10200.00
0005433341722	1065	Economy	10200.00
0005433341920	1065	Economy	10200.00
0005433341954	1065	Economy	10200.00
0005435092015	1065	Economy	10200.00
0005433341800	1065	Economy	10200.00
0005433341848	1065	Economy	10200.00
0005433159286	1065	Economy	10200.00
0005433341847	1065	Economy	10200.00
0005433269653	1065	Economy	10200.00
0005433158100	1065	Economy	10200.00
0005433341569	1065	Economy	10200.00
0005435092018	1065	Economy	10200.00
0005433341689	1065	Economy	10200.00
0005433342070	1065	Economy	10200.00
0005435545696	1065	Economy	10200.00
0005433341573	1065	Economy	10200.00
0005433341984	1065	Economy	10200.00
0005433341950	1065	Economy	10200.00
0005433269668	1065	Economy	10200.00
0005433341672	1065	Economy	10200.00
0005435092022	1065	Economy	10200.00
0005433341846	1065	Economy	10200.00
0005433341831	1065	Economy	10200.00
0005433341658	1065	Economy	10200.00
0005433342257	1065	Economy	10200.00
0005433341921	1065	Economy	10200.00
0005433341723	1065	Economy	10200.00
0005433341527	1065	Economy	10200.00
0005433341953	1065	Economy	10200.00
0005433342553	17069	Business	30600.00
0005433342509	17069	Business	30600.00
0005435508193	17069	Business	30600.00
0005433342584	17069	Business	30600.00
0005433342569	17069	Business	30600.00
0005433342520	17069	Business	30600.00
0005433342566	17069	Business	30600.00
0005433342519	17069	Business	30600.00
0005435091943	17069	Business	30600.00
0005433342561	17069	Business	30600.00
0005433269688	17069	Business	30600.00
0005435091912	17069	Business	30600.00
0005433342521	17069	Business	30600.00
0005433342576	17069	Business	30600.00
0005433342578	17069	Business	30600.00
0005433342512	17069	Business	30600.00
0005433342502	17069	Business	30600.00
0005433342551	17069	Business	30600.00
0005433342564	17069	Economy	11200.00
0005435508184	17069	Economy	10200.00
0005433342514	17069	Economy	10200.00
0005435508178	17069	Economy	10200.00
0005433269690	17069	Economy	10200.00
0005433342522	17069	Economy	10200.00
0005433342586	17069	Economy	10200.00
0005433342537	17069	Economy	10200.00
0005433342595	17069	Economy	10200.00
0005433342591	17069	Economy	10200.00
0005435508209	17069	Economy	10200.00
0005435091892	17069	Economy	10200.00
0005433342547	17069	Economy	10200.00
0005433342498	17069	Economy	10200.00
0005435508198	17069	Economy	10200.00
0005433342524	17069	Economy	10200.00
0005435091911	17069	Economy	10200.00
0005433342560	17069	Economy	10200.00
0005433342538	17069	Economy	10200.00
0005433342513	17069	Economy	10200.00
0005433342511	17069	Economy	10200.00
0005435508179	17069	Economy	10200.00
0005433342541	17069	Economy	10200.00
0005433342507	17069	Economy	10200.00
0005433342568	17069	Economy	10200.00
0005433342539	17069	Economy	10200.00
0005435508172	17069	Economy	10200.00
0005433342532	17069	Economy	10200.00
0005433342534	17069	Economy	10200.00
0005433342587	17069	Economy	10200.00
0005433342571	17069	Economy	10200.00
0005433342510	17069	Economy	10200.00
0005433269686	17069	Economy	10200.00
0005435508192	17069	Economy	10200.00
0005433342535	17069	Economy	10200.00
0005433342526	17069	Economy	10200.00
0005433342572	17069	Economy	10200.00
0005433342518	17069	Economy	10200.00
0005433269687	17069	Economy	10200.00
0005433342506	17069	Economy	10200.00
0005433342505	17069	Economy	10200.00
0005435508196	17069	Economy	10200.00
0005433159300	17069	Economy	10200.00
0005433342581	17069	Economy	10200.00
0005433342546	17069	Economy	10200.00
0005435508230	17069	Economy	10200.00
0005435508194	17069	Economy	10200.00
0005433342563	17069	Economy	10200.00
0005433269691	17069	Economy	10200.00
0005433342557	17069	Economy	10200.00
0005433342550	17069	Economy	10200.00
0005433342580	17069	Economy	10200.00
0005433342588	17069	Economy	10200.00
0005433159299	17069	Economy	10200.00
0005433342501	17069	Economy	10200.00
0005433342567	17069	Economy	10200.00
0005433342556	17069	Economy	10200.00
0005433342552	17069	Economy	10200.00
0005435091947	17069	Economy	10200.00
0005433342543	17069	Economy	10200.00
0005433342545	17069	Economy	10200.00
0005433342533	17069	Economy	10200.00
0005433342570	17069	Economy	10200.00
0005433342583	17069	Economy	10200.00
0005433342573	17069	Economy	10200.00
0005433342575	17069	Economy	10200.00
0005433342598	17069	Economy	11200.00
0005433342565	17069	Economy	10200.00
0005433342528	17069	Economy	10200.00
0005433342542	17069	Economy	10200.00
0005433342544	17069	Economy	10200.00
0005433342530	17069	Economy	11200.00
0005433342577	17069	Economy	10200.00
0005433342596	17069	Economy	10200.00
0005433269689	17069	Economy	10200.00
0005435508212	17069	Economy	10200.00
0005435508185	17069	Economy	10200.00
0005433342590	17069	Economy	10200.00
0005433342504	17069	Economy	10200.00
0005433342517	17069	Economy	10200.00
0005433342548	17069	Economy	10200.00
0005433342503	17069	Economy	10200.00
0005433342594	17069	Economy	10200.00
0005433342562	17069	Economy	10200.00
0005433342540	17069	Economy	10200.00
0005433342549	17069	Economy	10200.00
0005433342574	17069	Economy	10200.00
0005433342555	17069	Economy	10200.00
0005433342593	17069	Economy	10200.00
0005433342536	17069	Economy	10200.00
0005433342589	17069	Economy	10200.00
0005433342531	17069	Economy	10200.00
0005433342592	17069	Economy	10200.00
0005433342516	17069	Economy	10200.00
0005433342585	17069	Economy	10200.00
0005433342554	17069	Economy	10200.00
0005433342499	17069	Economy	10200.00
0005433342597	17069	Economy	10200.00
0005433342527	17069	Economy	10200.00
0005433342559	17069	Economy	10200.00
0005433342529	17069	Economy	10200.00
0005435508197	17069	Economy	10200.00
0005434445213	17069	Economy	10200.00
0005433342579	17069	Economy	10200.00
0005433342508	17069	Economy	10200.00
0005435508195	17069	Economy	10200.00
0005435508183	17069	Economy	10200.00
0005433342523	17069	Economy	10200.00
0005433342525	17069	Economy	10200.00
0005433342582	17069	Economy	10200.00
0005435508208	17069	Economy	10200.00
0005433342500	17069	Economy	10200.00
0005433342558	17069	Economy	10200.00
0005433342515	17069	Economy	10200.00
0005434081611	12783	Business	40300.00
0005434081551	12783	Business	40300.00
0005434066464	12783	Business	40300.00
0005434066814	12783	Business	40300.00
0005434066404	12783	Business	40300.00
0005432433651	12783	Business	40300.00
0005434066574	12783	Business	40300.00
0005434066451	12783	Business	40300.00
0005434066484	12783	Business	40300.00
0005434081548	12783	Economy	13400.00
0005432161140	12783	Economy	13400.00
0005434066682	12783	Economy	13400.00
0005434066636	12783	Economy	13400.00
0005434081560	12783	Economy	13400.00
0005434066431	12783	Economy	13400.00
0005434066514	12783	Economy	13400.00
0005432159835	12783	Economy	13400.00
0005433812888	12783	Economy	13400.00
0005434066446	12783	Economy	13400.00
0005434066354	12783	Economy	13400.00
0005434066580	12783	Economy	13400.00
0005434066372	12783	Economy	13400.00
0005434066846	12783	Economy	13400.00
0005434066549	12783	Economy	13400.00
0005434066519	12783	Economy	13400.00
0005434066332	12783	Economy	13400.00
0005434066609	12783	Economy	13400.00
0005434066635	12783	Economy	13400.00
0005433989700	12783	Economy	13400.00
0005432433648	12783	Economy	13400.00
0005434066396	12783	Economy	13400.00
0005434066570	12783	Economy	13400.00
0005434066559	12783	Economy	13400.00
0005434066347	12783	Economy	13400.00
0005434081609	12783	Economy	13400.00
0005434081597	12783	Economy	13400.00
0005434066584	12783	Economy	13400.00
0005434066573	12783	Economy	13400.00
0005432433652	12783	Economy	13400.00
0005434066650	12783	Economy	13400.00
0005433812889	12783	Economy	13400.00
0005434066371	12783	Economy	13400.00
0005434066334	12783	Economy	13400.00
0005434081582	12783	Economy	14800.00
0005432161141	12783	Economy	14800.00
0005433989712	12783	Economy	14800.00
0005432159832	12783	Economy	14800.00
0005434066402	12783	Economy	14800.00
0005433989714	12783	Economy	13400.00
0005434066553	12783	Economy	13400.00
0005434066681	12783	Economy	13400.00
0005434066627	12783	Economy	13400.00
0005432159831	12783	Economy	13400.00
0005434066335	12783	Economy	13400.00
0005434081561	12783	Economy	13400.00
0005434066471	12783	Economy	13400.00
0005433989693	12783	Economy	13400.00
0005434066847	12783	Economy	13400.00
0005432433653	12783	Economy	13400.00
0005433812886	12783	Economy	13400.00
0005434066746	12783	Economy	13400.00
0005432433649	12783	Economy	13400.00
0005432159836	12783	Economy	13400.00
0005434066582	12783	Economy	13400.00
0005434081508	12783	Economy	13400.00
0005434066651	12783	Economy	13400.00
0005432433650	12783	Economy	13400.00
0005434081502	12783	Economy	13400.00
0005434081527	12783	Economy	13400.00
0005433989711	12783	Economy	13400.00
0005434066535	12783	Economy	13400.00
0005434066680	12783	Economy	13400.00
0005434066730	12783	Economy	13400.00
0005434066608	12783	Economy	13400.00
0005434066628	12783	Economy	13400.00
0005434066557	12783	Economy	13400.00
0005434081470	12783	Economy	13400.00
0005434066845	12783	Economy	13400.00
0005434066518	12783	Economy	13400.00
0005434081549	12783	Economy	13400.00
0005434081608	12783	Economy	13400.00
0005434066556	12783	Economy	13400.00
0005434066333	12783	Economy	13400.00
0005434081596	12783	Economy	13400.00
0005434081598	12783	Economy	13400.00
0005433989704	12783	Economy	13400.00
0005434066569	12783	Economy	13400.00
0005432159833	12783	Economy	13400.00
0005434081559	12783	Economy	13400.00
0005432159834	12783	Economy	13400.00
0005434066536	12783	Economy	13400.00
0005434066581	12783	Economy	13400.00
0005433812887	12783	Economy	13400.00
0005434066600	12783	Economy	13400.00
0005434066370	12783	Economy	13400.00
0005434081532	12783	Economy	13400.00
0005434066403	12783	Economy	13400.00
0005434066452	12783	Economy	13400.00
0005434066534	12783	Economy	13400.00
0005434066632	12783	Economy	13400.00
0005433989694	12783	Economy	13400.00
0005434066550	12783	Economy	13400.00
0005434066738	12783	Economy	13400.00
0005434066416	12783	Economy	13400.00
0005434081526	12783	Economy	13400.00
0005434066453	12783	Economy	13400.00
0005434081509	12783	Economy	13400.00
0005434081486	12783	Economy	13400.00
0005434066541	12783	Economy	13400.00
0005434066373	12783	Economy	13400.00
0005434067148	30683	Business	40300.00
0005432150144	30683	Business	40300.00
0005434067106	30683	Business	40300.00
0005434067120	30683	Business	40300.00
0005434067137	30683	Business	40300.00
0005434067161	30683	Business	40300.00
0005434026691	30683	Business	40300.00
0005433812859	30683	Business	40300.00
0005434081755	30683	Business	40300.00
0005434067095	30683	Business	40300.00
0005434067111	30683	Business	40300.00
0005434067108	30683	Economy	13400.00
0005434067142	30683	Economy	13400.00
0005432150143	30683	Economy	13400.00
0005432433618	30683	Economy	13400.00
0005432150145	30683	Economy	13400.00
0005434067144	30683	Economy	13400.00
0005434067107	30683	Economy	13400.00
0005434067163	30683	Economy	13400.00
0005432433619	30683	Economy	13400.00
0005434067122	30683	Economy	13400.00
0005434067138	30683	Economy	13400.00
0005432150149	30683	Economy	13400.00
0005433812857	30683	Economy	13400.00
0005434067113	30683	Economy	13400.00
0005434067116	30683	Economy	13400.00
0005434067139	30683	Economy	13400.00
0005434067098	30683	Economy	13400.00
0005432150148	30683	Economy	13400.00
0005432433601	30683	Economy	13400.00
0005434026687	30683	Economy	13400.00
0005434067155	30683	Economy	13400.00
0005434067152	30683	Economy	13400.00
0005432433617	30683	Economy	13400.00
0005434067136	30683	Economy	13400.00
0005434026690	30683	Economy	13400.00
0005434067129	30683	Economy	13400.00
0005434067140	30683	Economy	13400.00
0005434067128	30683	Economy	13400.00
0005434026693	30683	Economy	13400.00
0005434067156	30683	Economy	13400.00
0005434067149	30683	Economy	13400.00
0005432433613	30683	Economy	13400.00
0005433812858	30683	Economy	13400.00
0005434067110	30683	Economy	13400.00
0005434026689	30683	Economy	13400.00
0005434081754	30683	Economy	14800.00
0005434067134	30683	Economy	13400.00
0005434026692	30683	Economy	14800.00
0005434067109	30683	Economy	14800.00
0005434067121	30683	Economy	14800.00
0005434067166	30683	Economy	13400.00
0005434067124	30683	Economy	13400.00
0005432150146	30683	Economy	13400.00
0005434081758	30683	Economy	13400.00
0005434067104	30683	Economy	13400.00
0005434067151	30683	Economy	13400.00
0005434067158	30683	Economy	13400.00
0005433989743	30683	Economy	13400.00
0005434067165	30683	Economy	13400.00
0005433989740	30683	Economy	13400.00
0005434067127	30683	Economy	13400.00
0005432150147	30683	Economy	13400.00
0005434067159	30683	Economy	13400.00
0005434081753	30683	Economy	13400.00
0005434067150	30683	Economy	13400.00
0005434081757	30683	Economy	13400.00
0005434067164	30683	Economy	13400.00
0005434067115	30683	Economy	13400.00
0005434067147	30683	Economy	13400.00
0005434067132	30683	Economy	13400.00
0005432186847	30683	Economy	13400.00
0005432433614	30683	Economy	13400.00
0005434067125	30683	Economy	13400.00
0005434067135	30683	Economy	13400.00
0005433989741	30683	Economy	13400.00
0005434067123	30683	Economy	13400.00
0005434067126	30683	Economy	13400.00
0005434067118	30683	Economy	13400.00
0005434081749	30683	Economy	13400.00
0005434081750	30683	Economy	13400.00
0005434067146	30683	Economy	13400.00
0005434026694	30683	Economy	13400.00
0005434026688	30683	Economy	13400.00
0005434081756	30683	Economy	13400.00
0005434067096	30683	Economy	13400.00
0005434067153	30683	Economy	13400.00
0005434067112	30683	Economy	13400.00
0005434067102	30683	Economy	13400.00
0005434067141	30683	Economy	13400.00
0005434067162	30683	Economy	13400.00
0005434067105	30683	Economy	13400.00
0005434067117	30683	Economy	13400.00
0005434067119	30683	Economy	13400.00
0005434067133	30683	Economy	13400.00
0005434067131	30683	Economy	13400.00
0005434067157	30683	Economy	13400.00
0005434081752	30683	Economy	13400.00
0005434067094	30683	Economy	13400.00
0005433812860	30683	Economy	13400.00
0005434067145	30683	Economy	13400.00
0005433989742	30683	Economy	13400.00
0005434067160	30683	Economy	13400.00
0005434067100	30683	Economy	13400.00
0005434081751	30683	Economy	13400.00
0005434067097	30683	Economy	13400.00
0005434067114	30683	Economy	13400.00
0005432186846	30683	Economy	13400.00
0005434067154	30683	Economy	13400.00
0005434067103	30683	Economy	13400.00
0005434067101	30683	Economy	13400.00
0005434067130	30683	Economy	13400.00
0005434067099	30683	Economy	13400.00
0005434067143	30683	Economy	13400.00
0005432535753	5499	Business	35300.00
0005434264742	5499	Business	35300.00
0005432535766	5499	Business	35300.00
0005435765936	5499	Business	35300.00
0005435461959	5499	Business	35300.00
0005435765895	5499	Business	35300.00
0005435765902	5499	Business	35300.00
0005435765919	5499	Business	35300.00
0005435725567	5499	Business	35300.00
0005435765905	5499	Business	35300.00
0005435765873	5499	Business	35300.00
0005435722043	5499	Business	35300.00
0005435765885	5499	Business	35300.00
0005434264714	5499	Business	35300.00
0005433529258	5499	Business	35300.00
0005435765921	5499	Business	35300.00
0005435461943	5499	Business	35300.00
0005435725570	5499	Business	35300.00
0005435461990	5499	Business	35300.00
0005435735116	5499	Business	35300.00
0005434831096	5499	Business	35300.00
0005435765881	5499	Business	35300.00
0005435765874	5499	Business	35300.00
0005435723034	5499	Business	35300.00
0005435735115	5499	Economy	12900.00
0005435765934	5499	Economy	12900.00
0005433527247	5499	Economy	12900.00
0005435765937	5499	Economy	12900.00
0005432140399	5499	Economy	11800.00
0005435765920	5499	Economy	11800.00
0005435765894	5499	Economy	11800.00
0005435461868	5499	Economy	11800.00
0005435725572	5499	Economy	11800.00
0005435765893	5499	Economy	11800.00
0005434264732	5499	Economy	11800.00
0005432140406	5499	Economy	11800.00
0005435765928	5499	Economy	11800.00
0005435765878	5499	Economy	11800.00
0005435765883	5499	Economy	11800.00
0005434831084	5499	Economy	11800.00
0005435765932	5499	Economy	11800.00
0005435765901	5499	Economy	11800.00
0005435461869	5499	Economy	11800.00
0005435461803	5499	Economy	11800.00
0005434264712	5499	Economy	11800.00
0005435765897	5499	Economy	11800.00
0005434264822	5499	Economy	11800.00
0005435765898	5499	Economy	11800.00
0005432140407	5499	Economy	11800.00
0005434831088	5499	Economy	11800.00
0005434264819	5499	Economy	11800.00
0005435765908	5499	Economy	11800.00
0005435462014	5499	Economy	11800.00
0005435461947	5499	Economy	11800.00
0005435461757	5499	Economy	11800.00
0005435735110	5499	Economy	11800.00
0005432535767	5499	Economy	11800.00
0005435765929	5499	Economy	11800.00
0005435765917	5499	Economy	11800.00
0005435765918	5499	Economy	11800.00
0005432140405	5499	Economy	11800.00
0005435461775	5499	Economy	11800.00
0005435765892	5499	Economy	11800.00
0005432140404	5499	Economy	11800.00
0005433529260	5499	Economy	11800.00
0005435461946	5499	Economy	11800.00
0005432140401	5499	Economy	11800.00
0005435461965	5499	Economy	11800.00
0005435722041	5499	Economy	11800.00
0005435461836	5499	Economy	11800.00
0005435765912	5499	Economy	11800.00
0005435462023	5499	Economy	11800.00
0005434264761	5499	Economy	11800.00
0005435461758	5499	Economy	11800.00
0005435765886	5499	Economy	11800.00
0005435735111	5499	Economy	11800.00
0005435461998	5499	Economy	11800.00
0005435765914	5499	Economy	11800.00
0005434264803	5499	Economy	11800.00
0005435723033	5499	Economy	11800.00
0005434264754	5499	Economy	11800.00
0005435765933	5499	Economy	11800.00
0005434831079	5499	Economy	11800.00
0005435725569	5499	Economy	11800.00
0005435765903	5499	Economy	11800.00
0005434264837	5499	Economy	11800.00
0005435461908	5499	Economy	11800.00
0005435722042	5499	Economy	11800.00
0005435461898	5499	Economy	11800.00
0005435462049	5499	Economy	11800.00
0005435765938	5499	Economy	11800.00
0005432140402	5499	Economy	11800.00
0005435765922	5499	Economy	11800.00
0005434264813	5499	Economy	11800.00
0005435461897	5499	Economy	11800.00
0005435461776	5499	Economy	11800.00
0005435765915	5499	Economy	11800.00
0005435765931	5499	Economy	11800.00
0005435765891	5499	Economy	11800.00
0005435765907	5499	Economy	11800.00
0005434831085	5499	Economy	11800.00
0005435765926	5499	Economy	11800.00
0005434264743	5499	Economy	11800.00
0005435735113	5499	Economy	11800.00
0005435735114	5499	Economy	11800.00
0005435461924	5499	Economy	11800.00
0005435765927	5499	Economy	11800.00
0005435765890	5499	Economy	12900.00
0005435735112	5499	Economy	12900.00
0005435720819	5499	Economy	11800.00
0005435765899	5499	Economy	12900.00
0005434264762	5499	Economy	11800.00
0005433529259	5499	Economy	11800.00
0005435765872	5499	Economy	11800.00
0005435043274	5499	Economy	11800.00
0005433529257	5499	Economy	11800.00
0005434264676	5499	Economy	11800.00
0005434831077	5499	Economy	11800.00
0005434264711	5499	Economy	11800.00
0005435765904	5499	Economy	11800.00
0005435725571	5499	Economy	11800.00
0005434831095	5499	Economy	11800.00
0005434264808	5499	Economy	11800.00
0005432140403	5499	Economy	11800.00
0005435765935	5499	Economy	11800.00
0005435462013	5499	Economy	11800.00
0005435765888	5499	Economy	11800.00
0005435765884	5499	Economy	11800.00
0005435765930	5499	Economy	11800.00
0005435765880	5499	Economy	11800.00
0005435765896	5499	Economy	11800.00
0005435461835	5499	Economy	11800.00
0005435461964	5499	Economy	11800.00
0005435765879	5499	Economy	11800.00
0005435461923	5499	Economy	11800.00
0005432140400	5499	Economy	11800.00
0005435765911	5499	Economy	11800.00
0005434264815	5499	Economy	11800.00
0005435765924	5499	Economy	11800.00
0005435765939	5499	Economy	11800.00
0005433527250	5499	Economy	11800.00
0005435765875	5499	Economy	11800.00
0005435725568	5499	Economy	11800.00
0005435461992	5499	Economy	11800.00
0005435765916	5499	Economy	11800.00
0005434264818	5499	Economy	11800.00
0005435765910	5499	Economy	11800.00
0005435461756	5499	Economy	11800.00
0005434831066	5499	Economy	11800.00
0005435461974	5499	Economy	11800.00
0005432535754	5499	Economy	11800.00
0005435462061	5499	Economy	11800.00
0005435462029	5499	Economy	11800.00
0005435765909	5499	Economy	11800.00
0005435461962	5499	Economy	11800.00
0005432140408	5499	Economy	11800.00
0005435765889	5499	Economy	11800.00
0005435765877	5499	Economy	11800.00
0005432535755	5499	Economy	11800.00
0005433527248	5499	Economy	11800.00
0005435765887	5499	Economy	11800.00
0005433527249	5499	Economy	11800.00
0005435765923	5499	Economy	11800.00
0005435043273	5499	Economy	11800.00
0005435765906	5499	Economy	11800.00
0005435765882	5499	Economy	11800.00
0005435765925	5499	Economy	11800.00
0005435765900	5499	Economy	11800.00
0005434264880	5499	Economy	11800.00
0005435765876	5499	Economy	11800.00
0005435765913	5499	Economy	11800.00
0005435462221	13502	Business	35300.00
0005435722033	13502	Business	35300.00
0005435462248	13502	Business	35300.00
0005435765537	13502	Business	35300.00
0005435735067	13502	Business	35300.00
0005435462228	13502	Business	35300.00
0005435462233	13502	Business	35300.00
0005435765383	13502	Business	35300.00
0005435765412	13502	Business	35300.00
0005435765424	13502	Business	35300.00
0005434265001	13502	Business	35300.00
0005435765714	13502	Business	35300.00
0005435462220	13502	Business	35300.00
0005435765731	13502	Business	35300.00
0005432535810	13502	Business	35300.00
0005432535809	13502	Business	35300.00
0005435765488	13502	Business	35300.00
0005432535811	13502	Business	35300.00
0005435765538	13502	Business	35300.00
0005435462235	13502	Business	35300.00
0005434265013	13502	Economy	12900.00
0005435765431	13502	Economy	12900.00
0005435462247	13502	Economy	11800.00
0005435735058	13502	Economy	11800.00
0005435765217	13502	Economy	11800.00
0005435765446	13502	Economy	11800.00
0005435765349	13502	Economy	11800.00
0005435765350	13502	Economy	11800.00
0005435765591	13502	Economy	11800.00
0005435765289	13502	Economy	11800.00
0005435462231	13502	Economy	11800.00
0005434831124	13502	Economy	11800.00
0005435765267	13502	Economy	11800.00
0005434265002	13502	Economy	11800.00
0005432194487	13502	Economy	11800.00
0005434265017	13502	Economy	11800.00
0005434265018	13502	Economy	11800.00
0005435462246	13502	Economy	11800.00
0005435765382	13502	Economy	11800.00
0005435462232	13502	Economy	11800.00
0005435720126	13502	Economy	11800.00
0005435462253	13502	Economy	11800.00
0005434831125	13502	Economy	11800.00
0005435765448	13502	Economy	11800.00
0005435765292	13502	Economy	11800.00
0005435765503	13502	Economy	11800.00
0005435462227	13502	Economy	11800.00
0005435765522	13502	Economy	11800.00
0005435765713	13502	Economy	11800.00
0005434265015	13502	Economy	11800.00
0005434265014	13502	Economy	11800.00
0005435765629	13502	Economy	11800.00
0005435765579	13502	Economy	11800.00
0005435765379	13502	Economy	11800.00
0005435462223	13502	Economy	11800.00
0005435722013	13502	Economy	11800.00
0005435765216	13502	Economy	11800.00
0005435462236	13502	Economy	11800.00
0005435462222	13502	Economy	11800.00
0005435765268	13502	Economy	11800.00
0005435725517	13502	Economy	11800.00
0005435765370	13502	Economy	11800.00
0005434264995	13502	Economy	11800.00
0005435765125	13502	Economy	11800.00
0005435462251	13502	Economy	11800.00
0005435765578	13502	Economy	11800.00
0005435722032	13502	Economy	11800.00
0005435765413	13502	Economy	11800.00
0005432194490	13502	Economy	11800.00
0005435765122	13502	Economy	11800.00
0005435765201	13502	Economy	11800.00
0005435765406	13502	Economy	11800.00
0005435765362	13502	Economy	11800.00
0005435735064	13502	Economy	11800.00
0005435765246	13502	Economy	11800.00
0005435462241	13502	Economy	11800.00
0005435765628	13502	Economy	11800.00
0005435462230	13502	Economy	11800.00
0005434264997	13502	Economy	11800.00
0005435765462	13502	Economy	11800.00
0005435765608	13502	Economy	11800.00
0005435765378	13502	Economy	11800.00
0005435765427	13502	Economy	11800.00
0005435765340	13502	Economy	11800.00
0005434265008	13502	Economy	11800.00
0005435462244	13502	Economy	11800.00
0005434831126	13502	Economy	11800.00
0005435735071	13502	Economy	11800.00
0005435765544	13502	Economy	11800.00
0005434265004	13502	Economy	11800.00
0005434265012	13502	Economy	11800.00
0005435765342	13502	Economy	11800.00
0005435462226	13502	Economy	11800.00
0005435765270	13502	Economy	12900.00
0005435765322	13502	Economy	12900.00
0005434264992	13502	Economy	11800.00
0005435765215	13502	Economy	11800.00
0005434264994	13502	Economy	12900.00
0005435462254	13502	Economy	11800.00
0005435725529	13502	Economy	11800.00
0005435725518	13502	Economy	11800.00
0005435462256	13502	Economy	11800.00
0005434831127	13502	Economy	11800.00
0005435462257	13502	Economy	11800.00
0005435765269	13502	Economy	11800.00
0005434264993	13502	Economy	11800.00
0005435462243	13502	Economy	11800.00
0005434265011	13502	Economy	11800.00
0005435765445	13502	Economy	11800.00
0005435462234	13502	Economy	11800.00
0005435462237	13502	Economy	11800.00
0005434265016	13502	Economy	11800.00
0005434264998	13502	Economy	11800.00
0005435462229	13502	Economy	11800.00
0005432535807	13502	Economy	11800.00
0005434265005	13502	Economy	11800.00
0005434264996	13502	Economy	11800.00
0005434265000	13502	Economy	11800.00
0005435462224	13502	Economy	11800.00
0005435765597	13502	Economy	11800.00
0005435462250	13502	Economy	11800.00
0005435720125	13502	Economy	11800.00
0005435765381	13502	Economy	11800.00
0005434265006	13502	Economy	11800.00
0005435765380	13502	Economy	11800.00
0005434264999	13502	Economy	11800.00
0005435765539	13502	Economy	11800.00
0005434831128	13502	Economy	11800.00
0005435765324	13502	Economy	11800.00
0005435043281	13502	Economy	11800.00
0005435462245	13502	Economy	11800.00
0005434265003	13502	Economy	11800.00
0005435462240	13502	Economy	11800.00
0005435765430	13502	Economy	11800.00
0005434265007	13502	Economy	11800.00
0005435765607	13502	Economy	11800.00
0005432535808	13502	Economy	11800.00
0005435765512	13502	Economy	11800.00
0005432194489	13502	Economy	11800.00
0005435765712	13502	Economy	11800.00
0005435765454	13502	Economy	11800.00
0005435765590	13502	Economy	11800.00
0005432194488	13502	Economy	11800.00
0005435462242	13502	Economy	11800.00
0005435765447	13502	Economy	11800.00
0005435765458	13502	Economy	11800.00
0005435765363	13502	Economy	11800.00
0005435462238	13502	Economy	11800.00
0005434265009	13502	Economy	11800.00
0005435765297	13502	Economy	11800.00
0005435462252	13502	Economy	11800.00
0005434265010	13502	Economy	11800.00
0005435462255	13502	Economy	11800.00
0005435462258	13502	Economy	11800.00
0005435462225	13502	Economy	11800.00
0005435765344	13502	Economy	11800.00
0005435462249	13502	Economy	11800.00
0005435462239	13502	Economy	11800.00
0005435765300	13502	Economy	11800.00
0005434602866	18680	Economy	3300.00
0005434602872	18680	Economy	3300.00
0005434602867	18680	Economy	3300.00
0005434514950	18681	Economy	3300.00
0005434604854	18681	Economy	3300.00
0005434514953	18681	Economy	3300.00
0005434604845	18681	Economy	3300.00
0005434514951	18681	Economy	3300.00
0005434514952	18681	Economy	3300.00
0005434604855	18681	Economy	3300.00
0005434602883	19145	Economy	3300.00
0005434514929	19145	Economy	3300.00
0005434602884	19145	Economy	3300.00
0005434602885	19145	Economy	3300.00
0005434602880	19145	Economy	3300.00
0005434602882	19145	Economy	3300.00
0005434602881	19145	Economy	3300.00
0005435844284	25099	Business	88300.00
0005435844287	25099	Business	88300.00
0005435846225	25099	Business	88300.00
0005432649300	25099	Business	88300.00
0005435844286	25099	Business	88300.00
0005435846226	25099	Business	88300.00
0005432649338	25099	Economy	29400.00
0005432649308	25099	Economy	29400.00
0005432632636	25099	Economy	29400.00
0005435846228	25099	Economy	32400.00
0005432632629	25099	Economy	29400.00
0005435844294	25099	Economy	29400.00
0005435846227	25099	Economy	29400.00
0005435844297	25099	Economy	29400.00
0005435846229	25099	Economy	29400.00
0005435846230	25099	Economy	29400.00
0005435844285	25099	Economy	29400.00
0005435844288	25099	Economy	29400.00
0005435846232	25099	Economy	29400.00
0005435844292	25099	Economy	29400.00
0005432649304	25099	Economy	29400.00
0005435844293	25099	Economy	29400.00
0005435844289	25099	Economy	29400.00
0005435844295	25099	Economy	29400.00
0005432632640	25099	Economy	29400.00
0005435846231	25099	Economy	29400.00
0005432632632	25099	Economy	29400.00
0005435844290	25099	Economy	29400.00
0005432649305	25099	Economy	29400.00
0005432649306	25099	Economy	29400.00
0005435844298	25099	Economy	29400.00
0005432649299	25099	Economy	29400.00
0005432649337	25099	Economy	29400.00
0005435846234	25099	Economy	29400.00
0005435846235	25099	Economy	29400.00
0005432632623	25099	Economy	29400.00
0005435844296	25099	Economy	29400.00
0005432649326	25099	Economy	29400.00
0005435846233	25099	Economy	29400.00
0005435844283	25099	Economy	29400.00
0005435844291	25099	Economy	29400.00
0005432649310	25099	Economy	29400.00
0005433284861	1809	Business	48700.00
0005433007845	1809	Business	48700.00
0005433284857	1809	Business	48700.00
0005433284894	1809	Business	48700.00
0005433284791	1809	Business	48700.00
0005433007907	1809	Business	48700.00
0005433008142	1809	Business	48700.00
0005433284987	1809	Business	48700.00
0005433284968	1809	Business	48700.00
0005433284885	1809	Business	48700.00
0005433007965	1809	Economy	16200.00
0005433007999	1809	Economy	16200.00
0005433007846	1809	Economy	16200.00
0005433007896	1809	Economy	16200.00
0005433008009	1809	Economy	16200.00
0005433007945	1809	Economy	16200.00
0005433008053	1809	Economy	16200.00
0005433008080	1809	Economy	16200.00
0005433008162	1809	Economy	16200.00
0005433284884	1809	Economy	17900.00
0005433284858	1809	Economy	17900.00
0005433284984	1809	Economy	17900.00
0005433284875	1809	Economy	17900.00
0005433810522	1809	Economy	16200.00
0005433284887	1809	Economy	16200.00
0005433008089	1809	Economy	16200.00
0005433007867	1809	Economy	16200.00
0005433284988	1809	Economy	16200.00
0005433007995	1809	Economy	16200.00
0005433284806	1809	Economy	16200.00
0005433284939	1809	Economy	16200.00
0005433007978	1809	Economy	16200.00
0005433007906	1809	Economy	16200.00
0005433007963	1809	Economy	16200.00
0005433007998	1809	Economy	16200.00
0005433008107	1809	Economy	16200.00
0005433007866	1809	Economy	16200.00
0005433007865	1809	Economy	16200.00
0005433007864	1809	Economy	16200.00
0005433008173	1809	Economy	16200.00
0005432295866	1809	Economy	16200.00
0005433284895	1809	Economy	16200.00
0005433008161	1809	Economy	16200.00
0005433284903	1809	Economy	16200.00
0005433284802	1809	Economy	16200.00
0005433008056	1809	Economy	16200.00
0005433284801	1809	Economy	16200.00
0005433007940	1809	Economy	16200.00
0005433007966	1809	Economy	16200.00
0005433008081	1809	Economy	16200.00
0005433008214	1809	Economy	16200.00
0005433284974	1809	Economy	16200.00
0005433007937	1809	Economy	16200.00
0005433284852	1809	Economy	16200.00
0005433284868	1809	Economy	16200.00
0005433284898	1809	Economy	16200.00
0005433008213	1809	Economy	16200.00
0005433008008	1809	Economy	16200.00
0005433284867	1809	Economy	16200.00
0005433284797	1809	Economy	16200.00
0005433810521	1809	Economy	16200.00
0005432295867	1809	Economy	16200.00
0005433008088	1809	Economy	16200.00
0005433284870	1809	Economy	16200.00
0005433007994	1809	Economy	16200.00
0005433284869	1809	Economy	16200.00
0005433284897	1809	Economy	16200.00
0005433284915	1809	Economy	16200.00
0005433284809	1809	Economy	16200.00
0005433284952	1809	Economy	16200.00
0005433008054	1809	Economy	16200.00
0005433008120	1809	Economy	16200.00
0005433284941	1809	Economy	16200.00
0005433284938	1809	Economy	16200.00
0005433810523	1809	Economy	16200.00
0005433284982	1809	Economy	16200.00
0005433008062	1809	Economy	16200.00
0005433008377	22584	Business	48700.00
0005433285106	22584	Business	48700.00
0005433285117	22584	Business	48700.00
0005433008335	22584	Business	48700.00
0005433008362	22584	Business	48700.00
0005433285109	22584	Business	48700.00
0005433285116	22584	Business	48700.00
0005433008349	22584	Business	48700.00
0005433285114	22584	Business	48700.00
0005433285105	22584	Business	48700.00
0005433008361	22584	Business	48700.00
0005433008375	22584	Economy	16200.00
0005433008341	22584	Economy	16200.00
0005433285120	22584	Economy	16200.00
0005433008352	22584	Economy	16200.00
0005433285129	22584	Economy	16200.00
0005433285130	22584	Economy	16200.00
0005433008357	22584	Economy	16200.00
0005433285111	22584	Economy	16200.00
0005433285125	22584	Economy	17900.00
0005433285133	22584	Economy	17900.00
0005433008354	22584	Economy	17900.00
0005433008367	22584	Economy	17900.00
0005433285107	22584	Economy	16200.00
0005433008368	22584	Economy	16200.00
0005433008345	22584	Economy	16200.00
0005433008351	22584	Economy	16200.00
0005433008340	22584	Economy	16200.00
0005433008365	22584	Economy	16200.00
0005433285110	22584	Economy	16200.00
0005433285134	22584	Economy	16200.00
0005433285123	22584	Economy	16200.00
0005433008378	22584	Economy	16200.00
0005433008346	22584	Economy	16200.00
0005433008337	22584	Economy	16200.00
0005433285132	22584	Economy	16200.00
0005433008366	22584	Economy	16200.00
0005433285108	22584	Economy	16200.00
0005433008355	22584	Economy	16200.00
0005433008347	22584	Economy	16200.00
0005433008336	22584	Economy	16200.00
0005433008370	22584	Economy	16200.00
0005433008374	22584	Economy	16200.00
0005433008343	22584	Economy	16200.00
0005433285103	22584	Economy	16200.00
0005433285127	22584	Economy	16200.00
0005433008350	22584	Economy	16200.00
0005433285113	22584	Economy	16200.00
0005433008364	22584	Economy	16200.00
0005433008363	22584	Economy	16200.00
0005433285118	22584	Economy	16200.00
0005433008356	22584	Economy	16200.00
0005433810488	22584	Economy	16200.00
0005433008371	22584	Economy	16200.00
0005433008344	22584	Economy	16200.00
0005433285126	22584	Economy	16200.00
0005433008369	22584	Economy	16200.00
0005433008338	22584	Economy	16200.00
0005433285128	22584	Economy	16200.00
0005433008359	22584	Economy	16200.00
0005433008372	22584	Economy	16200.00
0005433285122	22584	Economy	16200.00
0005433285119	22584	Economy	16200.00
0005433285131	22584	Economy	16200.00
0005433008339	22584	Economy	16200.00
0005433008358	22584	Economy	16200.00
0005433285115	22584	Economy	16200.00
0005433008348	22584	Economy	16200.00
0005433008353	22584	Economy	16200.00
0005433285121	22584	Economy	16200.00
0005433008360	22584	Economy	16200.00
0005433008334	22584	Economy	16200.00
0005433008373	22584	Economy	16200.00
0005433008376	22584	Economy	16200.00
0005433285112	22584	Economy	16200.00
0005433285124	22584	Economy	16200.00
0005433285104	22584	Economy	16200.00
0005433008333	22584	Economy	16200.00
0005433008342	22584	Economy	16200.00
0005433846390	5575	Business	99800.00
0005435282145	5575	Business	99800.00
0005435282106	5575	Business	99800.00
0005432081474	5575	Business	99800.00
0005435282144	5575	Business	99800.00
0005433815357	5575	Business	99800.00
0005433815356	5575	Business	99800.00
0005433846391	5575	Business	99800.00
0005435282163	5575	Business	99800.00
0005433846389	5575	Business	99800.00
0005433846417	5575	Business	99800.00
0005433846402	5575	Business	99800.00
0005433846422	5575	Business	99800.00
0005435282159	5575	Business	99800.00
0005433846420	5575	Economy	33300.00
0005433846404	5575	Economy	33300.00
0005433846439	5575	Economy	33300.00
0005433846394	5575	Economy	33300.00
0005433846424	5575	Economy	33300.00
0005433846419	5575	Economy	33300.00
0005435282158	5575	Economy	33300.00
0005433846425	5575	Economy	33300.00
0005435282165	5575	Economy	33300.00
0005435282142	5575	Economy	33300.00
0005433846407	5575	Economy	36600.00
0005433846409	5575	Economy	36600.00
0005435282160	5575	Economy	36600.00
0005435282112	5575	Economy	33300.00
0005433846434	5575	Economy	33300.00
0005433846392	5575	Economy	33300.00
0005433846415	5575	Economy	33300.00
0005433846430	5575	Economy	33300.00
0005433846410	5575	Economy	33300.00
0005435282155	5575	Economy	33300.00
0005433846380	5575	Economy	33300.00
0005433846418	5575	Economy	33300.00
0005433846387	5575	Economy	33300.00
0005435282105	5575	Economy	33300.00
0005433846393	5575	Economy	33300.00
0005433846432	5575	Economy	33300.00
0005433846408	5575	Economy	33300.00
0005435282091	5575	Economy	33300.00
0005435282100	5575	Economy	33300.00
0005433846423	5575	Economy	33300.00
0005435282103	5575	Economy	33300.00
0005433846386	5575	Economy	33300.00
0005435282113	5575	Economy	33300.00
0005433846385	5575	Economy	33300.00
0005435282096	5575	Economy	33300.00
0005435282166	5575	Economy	33300.00
0005433846414	5575	Economy	33300.00
0005435282156	5575	Economy	33300.00
0005433846383	5575	Economy	33300.00
0005433846431	5575	Economy	33300.00
0005433846427	5575	Economy	33300.00
0005433846435	5575	Economy	33300.00
0005432081478	5575	Economy	33300.00
0005433846413	5575	Economy	33300.00
0005433846398	5575	Economy	33300.00
0005432081476	5575	Economy	33300.00
0005433846381	5575	Economy	33300.00
0005435282157	5575	Economy	33300.00
0005433846416	5575	Economy	33300.00
0005433846388	5575	Economy	33300.00
0005433846429	5575	Economy	33300.00
0005435282146	5575	Economy	33300.00
0005435282099	5575	Economy	33300.00
0005433815358	5575	Economy	33300.00
0005433846426	5575	Economy	33300.00
0005435282071	5575	Economy	33300.00
0005435282098	5575	Economy	33300.00
0005433846384	5575	Economy	33300.00
0005432081473	5575	Economy	33300.00
0005433846401	5575	Economy	33300.00
0005433846436	5575	Economy	33300.00
0005433846406	5575	Economy	33300.00
0005433846395	5575	Economy	33300.00
0005433846405	5575	Economy	33300.00
0005433846396	5575	Economy	33300.00
0005435282092	5575	Economy	33300.00
0005433846403	5575	Economy	33300.00
0005433846412	5575	Economy	33300.00
0005433846411	5575	Economy	33300.00
0005432081477	5575	Economy	33300.00
0005432081475	5575	Economy	33300.00
0005432081479	5575	Economy	33300.00
0005433846399	5575	Economy	33300.00
0005433846400	5575	Economy	33300.00
0005433846437	5575	Economy	33300.00
0005433846382	5575	Economy	33300.00
0005435282123	5575	Economy	33300.00
0005435282114	5575	Economy	33300.00
0005433815355	5575	Economy	33300.00
0005435282143	5575	Economy	33300.00
0005433846428	5575	Economy	33300.00
0005433846438	5575	Economy	33300.00
0005433846433	5575	Economy	33300.00
0005433846421	5575	Economy	33300.00
0005433846397	5575	Economy	33300.00
0005433845710	13831	Business	99800.00
0005433845817	13831	Business	99800.00
0005433845876	13831	Business	99800.00
0005433845745	13831	Business	99800.00
0005433846007	13831	Business	99800.00
0005433845882	13831	Business	99800.00
0005433845907	13831	Business	99800.00
0005433845753	13831	Business	99800.00
0005433845894	13831	Business	99800.00
0005433845829	13831	Business	99800.00
0005433845699	13831	Business	99800.00
0005433845850	13831	Business	99800.00
0005435282385	13831	Business	99800.00
0005433845972	13831	Business	99800.00
0005435282383	13831	Business	99800.00
0005433845953	13831	Business	99800.00
0005435282382	13831	Business	99800.00
0005433846138	13831	Business	99800.00
0005433845788	13831	Business	99800.00
0005435282373	13831	Economy	33300.00
0005434173498	13831	Economy	33300.00
0005433845924	13831	Economy	33300.00
0005433815311	13831	Economy	33300.00
0005433845949	13831	Economy	33300.00
0005435282387	13831	Economy	33300.00
0005433845677	13831	Economy	33300.00
0005435282390	13831	Economy	33300.00
0005433845701	13831	Economy	33300.00
0005435282386	13831	Economy	33300.00
0005434173500	13831	Economy	33300.00
0005433845733	13831	Economy	33300.00
0005435282388	13831	Economy	36600.00
0005435282381	13831	Economy	36600.00
0005433846021	13831	Economy	36600.00
0005433845858	13831	Economy	36600.00
0005434173499	13831	Economy	33300.00
0005433846260	13831	Economy	33300.00
0005432003683	13831	Economy	33300.00
0005433845971	13831	Economy	33300.00
0005433845849	13831	Economy	33300.00
0005433845867	13831	Economy	33300.00
0005433845676	13831	Economy	33300.00
0005433845747	13831	Economy	33300.00
0005433845831	13831	Economy	33300.00
0005435282389	13831	Economy	33300.00
0005435282391	13831	Economy	33300.00
0005433845845	13831	Economy	33300.00
0005433845794	13831	Economy	33300.00
0005435282380	13831	Economy	33300.00
0005433846006	13831	Economy	33300.00
0005435282375	13831	Economy	33300.00
0005433845987	13831	Economy	33300.00
0005435282368	13831	Economy	33300.00
0005433845912	13831	Economy	33300.00
0005433845752	13831	Economy	33300.00
0005433845678	13831	Economy	33300.00
0005433845729	13831	Economy	33300.00
0005433845789	13831	Economy	33300.00
0005433845764	13831	Economy	33300.00
0005433845724	13831	Economy	33300.00
0005432003685	13831	Economy	33300.00
0005433845925	13831	Economy	33300.00
0005433846085	13831	Economy	33300.00
0005433845973	13831	Economy	33300.00
0005432003684	13831	Economy	33300.00
0005433845951	13831	Economy	33300.00
0005433846024	13831	Economy	33300.00
0005433845909	13831	Economy	33300.00
0005435282376	13831	Economy	33300.00
0005435282371	13831	Economy	33300.00
0005435282384	13831	Economy	33300.00
0005433845883	13831	Economy	33300.00
0005433845732	13831	Economy	33300.00
0005433845961	13831	Economy	33300.00
0005433846261	13831	Economy	33300.00
0005432003686	13831	Economy	33300.00
0005433845851	13831	Economy	33300.00
0005433845923	13831	Economy	33300.00
0005433846010	13831	Economy	33300.00
0005435282392	13831	Economy	33300.00
0005433845746	13831	Economy	33300.00
0005435282379	13831	Economy	33300.00
0005433845947	13831	Economy	33300.00
0005433845952	13831	Economy	33300.00
0005433845908	13831	Economy	33300.00
0005433845703	13831	Economy	33300.00
0005435282374	13831	Economy	33300.00
0005433846012	13831	Economy	33300.00
0005433845918	13831	Economy	33300.00
0005433845763	13831	Economy	33300.00
0005433845997	13831	Economy	33300.00
0005433845868	13831	Economy	33300.00
0005435282377	13831	Economy	33300.00
0005433845731	13831	Economy	33300.00
0005433845702	13831	Economy	33300.00
0005433846137	13831	Economy	33300.00
0005433845900	13831	Economy	33300.00
0005433845877	13831	Economy	33300.00
0005433846064	13831	Economy	33300.00
0005435282378	13831	Economy	33300.00
0005435282372	13831	Economy	33300.00
0005433845969	13831	Economy	33300.00
0005435282369	13831	Economy	33300.00
0005433845728	13831	Economy	33300.00
0005435282370	13831	Economy	33300.00
0005434620479	7809	Economy	16600.00
0005435332197	7809	Economy	16600.00
0005434620491	7809	Economy	15100.00
0005435332196	7809	Economy	15100.00
0005434620493	7809	Economy	15100.00
0005435332223	7809	Economy	15100.00
0005434620485	7809	Economy	15100.00
0005434620474	7809	Economy	15100.00
0005434620481	7809	Economy	15100.00
0005434620492	7809	Economy	15100.00
0005432112505	7809	Economy	15100.00
0005432112503	7809	Economy	15100.00
0005434620484	7809	Economy	15100.00
0005434620482	7809	Economy	15100.00
0005434620476	7809	Economy	15100.00
0005435332222	7809	Economy	15100.00
0005434620487	7809	Economy	15100.00
0005434620480	7809	Economy	15100.00
0005435332205	7809	Economy	15100.00
0005434620483	7809	Economy	15100.00
0005434620475	7809	Economy	15100.00
0005435332198	7809	Economy	15100.00
0005435332176	7809	Economy	15100.00
0005432112504	7809	Economy	15100.00
0005434620490	7809	Economy	15100.00
0005434620477	7809	Economy	15100.00
0005435332195	7809	Economy	15100.00
0005434620486	7809	Economy	15100.00
0005434620489	7809	Economy	15100.00
0005434620488	7809	Economy	15100.00
0005434620494	7809	Economy	15100.00
0005434620478	7809	Economy	15100.00
0005435332277	32998	Economy	16600.00
0005434620264	32998	Economy	16600.00
0005434620276	32998	Economy	16600.00
0005434620224	32998	Economy	16600.00
0005435332281	32998	Economy	15100.00
0005434620287	32998	Economy	15100.00
0005435332283	32998	Economy	15100.00
0005435332275	32998	Economy	15100.00
0005434620288	32998	Economy	15100.00
0005434620285	32998	Economy	15100.00
0005434620275	32998	Economy	15100.00
0005435332282	32998	Economy	15100.00
0005434620361	32998	Economy	15100.00
0005435332276	32998	Economy	15100.00
0005434620286	32998	Economy	15100.00
0005435332280	32998	Economy	15100.00
0005435332274	32998	Economy	15100.00
0005435332284	32998	Economy	15100.00
0005434620223	32998	Economy	15100.00
0005434620360	32998	Economy	15100.00
0005435332278	32998	Economy	15100.00
0005434620292	32998	Economy	15100.00
0005434620341	32998	Economy	15100.00
0005434620270	32998	Economy	15100.00
0005434620240	32998	Economy	15100.00
0005434620336	32998	Economy	15100.00
0005434620239	32998	Economy	15100.00
0005434620330	32998	Economy	15100.00
0005434620329	32998	Economy	15100.00
0005435332279	32998	Economy	15100.00
0005435918616	4267	Business	38000.00
0005435918577	4267	Business	38000.00
0005435785156	4267	Business	38000.00
0005435785162	4267	Business	38000.00
0005435785159	4267	Business	38000.00
0005435785171	4267	Business	38000.00
0005435785165	4267	Business	38000.00
0005435785177	4267	Economy	12700.00
0005435785185	4267	Economy	12700.00
0005435787343	4267	Economy	12700.00
0005435785174	4267	Economy	12700.00
0005434993967	4267	Economy	12700.00
0005435918594	4267	Economy	13900.00
0005435785184	4267	Economy	13900.00
0005434993973	4267	Economy	13900.00
0005435785173	4267	Economy	12700.00
0005435785155	4267	Economy	12700.00
0005435785160	4267	Economy	12700.00
0005435787341	4267	Economy	12700.00
0005434993974	4267	Economy	12700.00
0005435785172	4267	Economy	12700.00
0005432190607	4267	Economy	12700.00
0005435785163	4267	Economy	12700.00
0005432190611	4267	Economy	12700.00
0005435785180	4267	Economy	12700.00
0005435918578	4267	Economy	12700.00
0005432190608	4267	Economy	12700.00
0005435785168	4267	Economy	12700.00
0005434993970	4267	Economy	12700.00
0005435785166	4267	Economy	12700.00
0005432190609	4267	Economy	12700.00
0005435785181	4267	Economy	12700.00
0005435785167	4267	Economy	12700.00
0005434993972	4267	Economy	12700.00
0005435785157	4267	Economy	12700.00
0005435785176	4267	Economy	12700.00
0005435785175	4267	Economy	12700.00
0005434993965	4267	Economy	12700.00
0005435785182	4267	Economy	12700.00
0005435785183	4267	Economy	12700.00
0005435785164	4267	Economy	12700.00
0005435785154	4267	Economy	12700.00
0005435787342	4267	Economy	12700.00
0005434993969	4267	Economy	12700.00
0005435937309	4267	Economy	12700.00
0005435785170	4267	Economy	12700.00
0005435785161	4267	Economy	12700.00
0005435785158	4267	Economy	12700.00
0005435785178	4267	Economy	12700.00
0005434993968	4267	Economy	12700.00
0005435785169	4267	Economy	12700.00
0005435785186	4267	Economy	12700.00
0005435937312	4267	Economy	12700.00
0005434993966	4267	Economy	12700.00
0005434993971	4267	Economy	12700.00
0005435785153	4267	Economy	12700.00
0005435785179	4267	Economy	12700.00
0005432190610	4267	Economy	12700.00
0005435784744	27329	Business	38000.00
0005435784806	27329	Business	38000.00
0005435784795	27329	Business	38000.00
0005435784783	27329	Business	38000.00
0005435784829	27329	Economy	12700.00
0005435784831	27329	Economy	12700.00
0005435784777	27329	Economy	12700.00
0005434993851	27329	Economy	12700.00
0005432195680	27329	Economy	12700.00
0005432195681	27329	Economy	12700.00
0005435784753	27329	Economy	13900.00
0005435784765	27329	Economy	13900.00
0005435784900	27329	Economy	12700.00
0005434993909	27329	Economy	12700.00
0005435784876	27329	Economy	12700.00
0005435918631	27329	Economy	12700.00
0005435784824	27329	Economy	12700.00
0005435784836	27329	Economy	12700.00
0005435784760	27329	Economy	12700.00
0005435784761	27329	Economy	12700.00
0005435784769	27329	Economy	12700.00
0005435784778	27329	Economy	12700.00
0005435784850	27329	Economy	12700.00
0005435918629	27329	Economy	12700.00
0005435918627	27329	Economy	12700.00
0005434993852	27329	Economy	12700.00
0005435784754	27329	Economy	12700.00
0005435784870	27329	Economy	12700.00
0005434993934	27329	Economy	12700.00
0005435784763	27329	Economy	12700.00
0005435918630	27329	Economy	12700.00
0005435784832	27329	Economy	12700.00
0005435784899	27329	Economy	12700.00
0005435784779	27329	Economy	12700.00
0005435784767	27329	Economy	12700.00
0005435784785	27329	Economy	12700.00
0005435784766	27329	Economy	12700.00
0005435784762	27329	Economy	12700.00
0005435784745	27329	Economy	12700.00
0005435784828	27329	Economy	12700.00
0005435784823	27329	Economy	12700.00
0005432195679	27329	Economy	12700.00
0005435918628	27329	Economy	12700.00
0005435784890	27329	Economy	12700.00
0005435784814	27329	Economy	12700.00
0005435784730	27329	Economy	12700.00
0005435784875	27329	Economy	12700.00
0005435784813	27329	Economy	12700.00
0005432146186	19893	Economy	12800.00
0005432146187	19893	Economy	12800.00
0005432567278	4709	Business	40900.00
0005432459596	4709	Business	40900.00
0005432459590	4709	Business	40900.00
0005432567329	4709	Business	40900.00
0005434081771	4709	Business	40900.00
0005432567328	4709	Business	40900.00
0005432459569	4709	Business	40900.00
0005432459566	4709	Business	40900.00
0005432459547	4709	Business	40900.00
0005434081782	4709	Business	40900.00
0005432567322	4709	Business	40900.00
0005433726092	4709	Business	40900.00
0005432567281	4709	Business	40900.00
0005432567315	4709	Business	40900.00
0005432567295	4709	Business	40900.00
0005432459555	4709	Business	40900.00
0005432567283	4709	Business	40900.00
0005432567318	4709	Business	40900.00
0005432186850	4709	Business	40900.00
0005432567279	4709	Business	40900.00
0005434081776	4709	Business	40900.00
0005434081772	4709	Business	40900.00
0005432567332	4709	Economy	15000.00
0005434081784	4709	Economy	15000.00
0005434081774	4709	Economy	15000.00
0005432170349	4709	Economy	15000.00
0005432567293	4709	Economy	13600.00
0005432170354	4709	Economy	13600.00
0005432170348	4709	Economy	13600.00
0005434081779	4709	Economy	13600.00
0005432567331	4709	Economy	13600.00
0005432459570	4709	Economy	13600.00
0005432567317	4709	Economy	13600.00
0005434081764	4709	Economy	13600.00
0005432459568	4709	Economy	13600.00
0005432567324	4709	Economy	13600.00
0005432186851	4709	Economy	13600.00
0005432459594	4709	Economy	13600.00
0005432170352	4709	Economy	13600.00
0005432459574	4709	Economy	13600.00
0005432459593	4709	Economy	13600.00
0005432459572	4709	Economy	13600.00
0005432567308	4709	Economy	13600.00
0005432459567	4709	Economy	13600.00
0005433451608	4709	Economy	13600.00
0005432459551	4709	Economy	13600.00
0005432567321	4709	Economy	13600.00
0005432459564	4709	Economy	13600.00
0005432459565	4709	Economy	13600.00
0005434081762	4709	Economy	13600.00
0005432567282	4709	Economy	13600.00
0005432567334	4709	Economy	13600.00
0005434081780	4709	Economy	13600.00
0005434081766	4709	Economy	13600.00
0005432567307	4709	Economy	13600.00
0005432567313	4709	Economy	13600.00
0005432567285	4709	Economy	13600.00
0005432567280	4709	Economy	13600.00
0005432459582	4709	Economy	13600.00
0005432567327	4709	Economy	13600.00
0005432459586	4709	Economy	13600.00
0005432567291	4709	Economy	13600.00
0005432459550	4709	Economy	13600.00
0005432567323	4709	Economy	13600.00
0005432170350	4709	Economy	13600.00
0005434081781	4709	Economy	13600.00
0005434081761	4709	Economy	13600.00
0005432567319	4709	Economy	13600.00
0005432459576	4709	Economy	13600.00
0005432459589	4709	Economy	13600.00
0005432459584	4709	Economy	13600.00
0005432459581	4709	Economy	13600.00
0005432567304	4709	Economy	13600.00
0005432567302	4709	Economy	13600.00
0005432459553	4709	Economy	13600.00
0005434081775	4709	Economy	13600.00
0005432567276	4709	Economy	13600.00
0005432571301	4709	Economy	13600.00
0005432567287	4709	Economy	13600.00
0005432459579	4709	Economy	13600.00
0005432459595	4709	Economy	13600.00
0005434081773	4709	Economy	13600.00
0005432567338	4709	Economy	13600.00
0005434081770	4709	Economy	13600.00
0005432567333	4709	Economy	13600.00
0005432459580	4709	Economy	13600.00
0005432459561	4709	Economy	13600.00
0005432567309	4709	Economy	13600.00
0005432459592	4709	Economy	13600.00
0005433726091	4709	Economy	13600.00
0005432567288	4709	Economy	13600.00
0005432567314	4709	Economy	13600.00
0005434081778	4709	Economy	13600.00
0005432459548	4709	Economy	13600.00
0005432459549	4709	Economy	13600.00
0005432459558	4709	Economy	13600.00
0005432567286	4709	Economy	13600.00
0005432567289	4709	Economy	13600.00
0005434081768	4709	Economy	13600.00
0005432459563	4709	Economy	13600.00
0005432567296	4709	Economy	13600.00
0005432186848	4709	Economy	13600.00
0005434081759	4709	Economy	13600.00
0005434081788	4709	Economy	13600.00
0005432567303	4709	Economy	15000.00
0005434081763	4709	Economy	13600.00
0005432567311	4709	Economy	13600.00
0005432567305	4709	Economy	13600.00
0005434081765	4709	Economy	15000.00
0005432459571	4709	Economy	15000.00
0005432567301	4709	Economy	13600.00
0005432567306	4709	Economy	13600.00
0005432571302	4709	Economy	13600.00
0005432567337	4709	Economy	13600.00
0005432170351	4709	Economy	13600.00
0005432459546	4709	Economy	13600.00
0005432567292	4709	Economy	13600.00
0005432567298	4709	Economy	13600.00
0005432567299	4709	Economy	13600.00
0005434081760	4709	Economy	13600.00
0005432459557	4709	Economy	13600.00
0005433451609	4709	Economy	13600.00
0005432459573	4709	Economy	13600.00
0005434081777	4709	Economy	13600.00
0005432571300	4709	Economy	13600.00
0005432459562	4709	Economy	13600.00
0005432459585	4709	Economy	13600.00
0005434081769	4709	Economy	13600.00
0005432170353	4709	Economy	13600.00
0005432459575	4709	Economy	13600.00
0005432567316	4709	Economy	13600.00
0005432567320	4709	Economy	13600.00
0005434081767	4709	Economy	13600.00
0005432567300	4709	Economy	13600.00
0005432459556	4709	Economy	13600.00
0005432567290	4709	Economy	13600.00
0005432567277	4709	Economy	13600.00
0005434081783	4709	Economy	13600.00
0005432459554	4709	Economy	13600.00
0005432459545	4709	Economy	13600.00
0005434081789	4709	Economy	13600.00
0005432567284	4709	Economy	13600.00
0005432571299	4709	Economy	13600.00
0005432459588	4709	Economy	13600.00
0005432186849	4709	Economy	13600.00
0005432459577	4709	Economy	13600.00
0005434081787	4709	Economy	13600.00
0005432567294	4709	Economy	13600.00
0005432459591	4709	Economy	13600.00
0005432459587	4709	Economy	13600.00
0005432567297	4709	Economy	13600.00
0005432567336	4709	Economy	13600.00
0005432567325	4709	Economy	13600.00
0005432459560	4709	Economy	13600.00
0005432567312	4709	Economy	13600.00
0005432567326	4709	Economy	13600.00
0005432459583	4709	Economy	13600.00
0005434081786	4709	Economy	13600.00
0005432567339	4709	Economy	13600.00
0005434081785	4709	Economy	13600.00
0005432567335	4709	Economy	13600.00
0005432567330	4709	Economy	13600.00
0005432459578	4709	Economy	13600.00
0005432459559	4709	Economy	13600.00
0005432459552	4709	Economy	13600.00
0005432567310	4709	Economy	13600.00
0005432459315	30549	Business	40900.00
0005432459377	30549	Business	40900.00
0005432459048	30549	Business	40900.00
0005432459320	30549	Business	40900.00
0005432566743	30549	Business	40900.00
0005432459192	30549	Business	40900.00
0005432213584	30549	Business	40900.00
0005432459187	30549	Business	40900.00
0005432459132	30549	Business	40900.00
0005432566960	30549	Business	40900.00
0005434081611	30549	Business	40900.00
0005432459189	30549	Business	40900.00
0005432213586	30549	Business	40900.00
0005434081486	30549	Business	40900.00
0005434081551	30549	Business	40900.00
0005432458982	30549	Economy	15000.00
0005432566800	30549	Economy	15000.00
0005432459321	30549	Economy	15000.00
0005432459070	30549	Economy	13600.00
0005433452705	30549	Economy	13600.00
0005432566578	30549	Economy	13600.00
0005432459083	30549	Economy	13600.00
0005432566911	30549	Economy	13600.00
0005434081609	30549	Economy	13600.00
0005433452701	30549	Economy	13600.00
0005432459284	30549	Economy	13600.00
0005432459237	30549	Economy	13600.00
0005432459027	30549	Economy	13600.00
0005432566900	30549	Economy	13600.00
0005434081598	30549	Economy	13600.00
0005432459266	30549	Economy	13600.00
0005432459035	30549	Economy	13600.00
0005432566848	30549	Economy	13600.00
0005434081596	30549	Economy	13600.00
0005432459092	30549	Economy	13600.00
0005432566728	30549	Economy	13600.00
0005432459241	30549	Economy	13600.00
0005432566813	30549	Economy	13600.00
0005432459265	30549	Economy	13600.00
0005434081470	30549	Economy	13600.00
0005434081548	30549	Economy	13600.00
0005432566967	30549	Economy	13600.00
0005434081532	30549	Economy	13600.00
0005434081502	30549	Economy	13600.00
0005432566872	30549	Economy	13600.00
0005432459316	30549	Economy	13600.00
0005432459283	30549	Economy	13600.00
0005432566809	30549	Economy	13600.00
0005432459158	30549	Economy	13600.00
0005434081560	30549	Economy	13600.00
0005432566942	30549	Economy	13600.00
0005432459127	30549	Economy	13600.00
0005432161141	30549	Economy	13600.00
0005432566873	30549	Economy	13600.00
0005432459154	30549	Economy	13600.00
0005432459065	30549	Economy	13600.00
0005432459081	30549	Economy	13600.00
0005433454848	30549	Economy	13600.00
0005432459172	30549	Economy	13600.00
0005432459376	30549	Economy	13600.00
0005432566781	30549	Economy	13600.00
0005432459144	30549	Economy	13600.00
0005432571291	30549	Economy	13600.00
0005432566803	30549	Economy	13600.00
0005432567032	30549	Economy	13600.00
0005432566696	30549	Economy	13600.00
0005432459082	30549	Economy	13600.00
0005432566732	30549	Economy	13600.00
0005434081608	30549	Economy	13600.00
0005434081509	30549	Economy	13600.00
0005432459214	30549	Economy	13600.00
0005432566768	30549	Economy	13600.00
0005432459122	30549	Economy	13600.00
0005432567034	30549	Economy	13600.00
0005432566755	30549	Economy	13600.00
0005432566877	30549	Economy	13600.00
0005432566907	30549	Economy	13600.00
0005432566959	30549	Economy	13600.00
0005432459185	30549	Economy	13600.00
0005432571275	30549	Economy	13600.00
0005432213585	30549	Economy	13600.00
0005432566916	30549	Economy	15000.00
0005432459188	30549	Economy	13600.00
0005432566654	30549	Economy	13600.00
0005433452716	30549	Economy	15000.00
0005432459153	30549	Economy	13600.00
0005432459064	30549	Economy	13600.00
0005432459293	30549	Economy	13600.00
0005432566899	30549	Economy	13600.00
0005434081527	30549	Economy	13600.00
0005434081582	30549	Economy	13600.00
0005432459202	30549	Economy	13600.00
0005434081561	30549	Economy	13600.00
0005432459279	30549	Economy	13600.00
0005432566940	30549	Economy	13600.00
0005432459076	30549	Economy	13600.00
0005432567152	30549	Economy	13600.00
0005432459128	30549	Economy	13600.00
0005434081549	30549	Economy	13600.00
0005433452704	30549	Economy	13600.00
0005432567003	30549	Economy	13600.00
0005432459234	30549	Economy	13600.00
0005432566856	30549	Economy	13600.00
0005432567035	30549	Economy	13600.00
0005432459275	30549	Economy	13600.00
0005432566767	30549	Economy	13600.00
0005432566733	30549	Economy	13600.00
0005432459026	30549	Economy	13600.00
0005432459080	30549	Economy	13600.00
0005432566832	30549	Economy	13600.00
0005432459063	30549	Economy	13600.00
0005432566943	30549	Economy	13600.00
0005432566652	30549	Economy	13600.00
0005432566805	30549	Economy	13600.00
0005432566994	30549	Economy	13600.00
0005432566804	30549	Economy	13600.00
0005432566917	30549	Economy	13600.00
0005432213587	30549	Economy	13600.00
0005432566814	30549	Economy	13600.00
0005432566779	30549	Economy	13600.00
0005432459183	30549	Economy	13600.00
0005432459186	30549	Economy	13600.00
0005432566799	30549	Economy	13600.00
0005434081559	30549	Economy	13600.00
0005432213588	30549	Economy	13600.00
0005432566716	30549	Economy	13600.00
0005432459178	30549	Economy	13600.00
0005432567151	30549	Economy	13600.00
0005432459179	30549	Economy	13600.00
0005434081526	30549	Economy	13600.00
0005434081508	30549	Economy	13600.00
0005432566579	30549	Economy	13600.00
0005432566986	30549	Economy	13600.00
0005432566795	30549	Economy	13600.00
0005432161140	30549	Economy	13600.00
0005434081597	30549	Economy	13600.00
0005432567150	30549	Economy	13600.00
0005432566906	30549	Economy	13600.00
0005432566812	30549	Economy	13600.00
0005435720819	13608	Economy	9900.00
0005435722042	13608	Economy	9900.00
0005435722043	13608	Economy	9900.00
0005435722041	13608	Economy	9900.00
0005435722019	21214	Economy	9900.00
0005435722017	21214	Economy	9900.00
0005435722020	21214	Economy	9900.00
0005435722030	21214	Economy	9900.00
0005435720121	21214	Economy	9900.00
0005435722021	21214	Economy	9900.00
0005435722016	21214	Economy	9900.00
0005435722018	21214	Economy	9900.00
0005432295866	22786	Economy	8800.00
0005432295867	22786	Economy	8800.00
0005433342626	11077	Business	23600.00
0005433342661	11077	Business	23600.00
0005433342666	11077	Business	23600.00
0005433342635	11077	Business	23600.00
0005433342599	11077	Business	23600.00
0005433342615	11077	Business	23600.00
0005435508177	11077	Business	23600.00
0005435097146	11077	Business	23600.00
0005433342690	11077	Business	23600.00
0005433342612	11077	Business	23600.00
0005433342611	11077	Business	23600.00
0005433342657	11077	Economy	7900.00
0005433342685	11077	Economy	7900.00
0005433342619	11077	Economy	7900.00
0005433342689	11077	Economy	7900.00
0005433342696	11077	Economy	7900.00
0005433342606	11077	Economy	7900.00
0005433342600	11077	Economy	7900.00
0005435097149	11077	Economy	7900.00
0005433342616	11077	Economy	7900.00
0005433342617	11077	Economy	7900.00
0005433342658	11077	Economy	7900.00
0005433342680	11077	Economy	7900.00
0005433342636	11077	Economy	7900.00
0005433342624	11077	Economy	7900.00
0005433342669	11077	Economy	7900.00
0005433342672	11077	Economy	7900.00
0005433342607	11077	Economy	7900.00
0005433342651	11077	Economy	7900.00
0005433342632	11077	Economy	7900.00
0005433342698	11077	Economy	7900.00
0005433342625	11077	Economy	7900.00
0005433342671	11077	Economy	7900.00
0005433342609	11077	Economy	7900.00
0005433342634	11077	Economy	7900.00
0005433342622	11077	Economy	7900.00
0005433342613	11077	Economy	7900.00
0005433342654	11077	Economy	7900.00
0005435097151	11077	Economy	7900.00
0005433342673	11077	Economy	7900.00
0005433342643	11077	Economy	7900.00
0005435508176	11077	Economy	7900.00
0005433342679	11077	Economy	7900.00
0005433342655	11077	Economy	7900.00
0005433342623	11077	Economy	7900.00
0005433342629	11077	Economy	7900.00
0005435097147	11077	Economy	7900.00
0005433342684	11077	Economy	7900.00
0005433342653	11077	Economy	7900.00
0005433342675	11077	Economy	7900.00
0005433342686	11077	Economy	7900.00
0005433342641	11077	Economy	8600.00
0005435508189	11077	Economy	8600.00
0005433342631	11077	Economy	8600.00
0005433342656	11077	Economy	8600.00
0005435380247	11077	Economy	8600.00
0005435097148	11077	Economy	7900.00
0005433342691	11077	Economy	8600.00
0005433342645	11077	Economy	7900.00
0005433342677	11077	Economy	7900.00
0005433342642	11077	Economy	7900.00
0005433342605	11077	Economy	7900.00
0005433342610	11077	Economy	7900.00
0005433342637	11077	Economy	7900.00
0005433342682	11077	Economy	7900.00
0005433342694	11077	Economy	7900.00
0005433342627	11077	Economy	7900.00
0005433342633	11077	Economy	7900.00
0005433342662	11077	Economy	7900.00
0005435508218	11077	Economy	7900.00
0005433342664	11077	Economy	7900.00
0005433342644	11077	Economy	7900.00
0005433342668	11077	Economy	7900.00
0005433342649	11077	Economy	7900.00
0005433342697	11077	Economy	7900.00
0005433342652	11077	Economy	7900.00
0005433342603	11077	Economy	7900.00
0005433342676	11077	Economy	7900.00
0005433342608	11077	Economy	7900.00
0005433342646	11077	Economy	7900.00
0005435508220	11077	Economy	7900.00
0005433342620	11077	Economy	7900.00
0005433342663	11077	Economy	7900.00
0005433342692	11077	Economy	7900.00
0005435097153	11077	Economy	7900.00
0005435508204	11077	Economy	7900.00
0005433342640	11077	Economy	7900.00
0005435097156	11077	Economy	7900.00
0005433342618	11077	Economy	7900.00
0005433342693	11077	Economy	7900.00
0005433342701	11077	Economy	7900.00
0005433342639	11077	Economy	7900.00
0005433342667	11077	Economy	7900.00
0005435508166	11077	Economy	7900.00
0005433342687	11077	Economy	7900.00
0005435508186	11077	Economy	7900.00
0005433342665	11077	Economy	7900.00
0005433342670	11077	Economy	7900.00
0005433342660	11077	Economy	7900.00
0005433342638	11077	Economy	7900.00
0005433342695	11077	Economy	7900.00
0005433342688	11077	Economy	7900.00
0005433342700	11077	Economy	7900.00
0005433342614	11077	Economy	7900.00
0005433342681	11077	Economy	7900.00
0005433342604	11077	Economy	7900.00
0005433342683	11077	Economy	7900.00
0005433342699	11077	Economy	7900.00
0005435097150	11077	Economy	7900.00
0005435097154	11077	Economy	7900.00
0005435097155	11077	Economy	7900.00
0005433342659	11077	Economy	7900.00
0005433342621	11077	Economy	7900.00
0005435380231	11077	Economy	7900.00
0005433342674	11077	Economy	7900.00
0005433342628	11077	Economy	7900.00
0005433342678	11077	Economy	7900.00
0005433342602	11077	Economy	7900.00
0005433342601	11077	Economy	7900.00
0005435508175	11077	Economy	7900.00
0005435508190	11077	Economy	7900.00
0005435097152	11077	Economy	7900.00
0005433342650	11077	Economy	7900.00
0005433342630	11077	Economy	7900.00
0005435508217	11077	Economy	7900.00
0005433342647	11077	Economy	7900.00
0005433342648	11077	Economy	7900.00
0005433341800	17140	Business	23600.00
0005433341527	17140	Business	23600.00
0005433341569	17140	Business	23600.00
0005433342070	17140	Business	23600.00
0005433341597	17140	Business	23600.00
0005433341802	17140	Business	23600.00
0005433341954	17140	Business	23600.00
0005433341672	17140	Business	23600.00
0005433341846	17140	Business	23600.00
0005433341848	17140	Business	23600.00
0005433341951	17140	Business	23600.00
0005433341723	17140	Business	23600.00
0005433341654	17140	Economy	7900.00
0005433341972	17140	Economy	7900.00
0005433341565	17140	Economy	7900.00
0005433341740	17140	Economy	7900.00
0005435097082	17140	Economy	7900.00
0005433341584	17140	Economy	7900.00
0005435097097	17140	Economy	7900.00
0005433341589	17140	Economy	7900.00
0005435380270	17140	Economy	7900.00
0005433341494	17140	Economy	7900.00
0005433341458	17140	Economy	7900.00
0005435380274	17140	Economy	7900.00
0005433341690	17140	Economy	7900.00
0005433341716	17140	Economy	7900.00
0005433341658	17140	Economy	7900.00
0005433341633	17140	Economy	7900.00
0005433341698	17140	Economy	7900.00
0005433341689	17140	Economy	7900.00
0005433341564	17140	Economy	7900.00
0005435380273	17140	Economy	7900.00
0005435097080	17140	Economy	7900.00
0005435097072	17140	Economy	7900.00
0005435097056	17140	Economy	7900.00
0005433341495	17140	Economy	7900.00
0005435545694	17140	Economy	7900.00
0005433342255	17140	Economy	7900.00
0005433341508	17140	Economy	7900.00
0005435545695	17140	Economy	7900.00
0005433341492	17140	Economy	7900.00
0005433341554	17140	Economy	7900.00
0005435097059	17140	Economy	7900.00
0005433341594	17140	Economy	7900.00
0005433341921	17140	Economy	7900.00
0005435545696	17140	Economy	7900.00
0005433341416	17140	Economy	7900.00
0005435545692	17140	Economy	8600.00
0005433341867	17140	Economy	8600.00
0005435545693	17140	Economy	8600.00
0005433341797	17140	Economy	8600.00
0005433341545	17140	Economy	8600.00
0005435097081	17140	Economy	7900.00
0005433341713	17140	Economy	8600.00
0005433341806	17140	Economy	7900.00
0005433341593	17140	Economy	7900.00
0005433341831	17140	Economy	7900.00
0005433341920	17140	Economy	7900.00
0005433341803	17140	Economy	7900.00
0005435097057	17140	Economy	7900.00
0005433341553	17140	Economy	7900.00
0005433341598	17140	Economy	7900.00
0005435097058	17140	Economy	7900.00
0005433341801	17140	Economy	7900.00
0005435545691	17140	Economy	7900.00
0005435097087	17140	Economy	7900.00
0005433341513	17140	Economy	7900.00
0005433341657	17140	Economy	7900.00
0005433341509	17140	Economy	7900.00
0005433341600	17140	Economy	7900.00
0005433341950	17140	Economy	7900.00
0005433341903	17140	Economy	7900.00
0005435097085	17140	Economy	7900.00
0005433341385	17140	Economy	7900.00
0005433341381	17140	Economy	7900.00
0005433341918	17140	Economy	7900.00
0005435380271	17140	Economy	7900.00
0005433341459	17140	Economy	7900.00
0005433341496	17140	Economy	7900.00
0005433342281	17140	Economy	7900.00
0005433341573	17140	Economy	7900.00
0005435097061	17140	Economy	7900.00
0005435097068	17140	Economy	7900.00
0005433341847	17140	Economy	7900.00
0005435097066	17140	Economy	7900.00
0005433341585	17140	Economy	7900.00
0005433342068	17140	Economy	7900.00
0005433341739	17140	Economy	7900.00
0005433342257	17140	Economy	7900.00
0005435097060	17140	Economy	7900.00
0005433341583	17140	Economy	7900.00
0005433341984	17140	Economy	7900.00
0005435097049	17140	Economy	7900.00
0005435380272	17140	Economy	7900.00
0005433341599	17140	Economy	7900.00
0005433342093	17140	Economy	7900.00
0005433341889	17140	Economy	7900.00
0005433342256	17140	Economy	7900.00
0005433341714	17140	Economy	7900.00
0005435097051	17140	Economy	7900.00
0005435097048	17140	Economy	7900.00
0005433341615	17140	Economy	7900.00
0005433342064	17140	Economy	7900.00
0005433342075	17140	Economy	7900.00
0005433341722	17140	Economy	7900.00
0005433342063	17140	Economy	7900.00
0005433341570	17140	Economy	7900.00
0005433341592	17140	Economy	7900.00
0005433341380	17140	Economy	7900.00
0005433341544	17140	Economy	7900.00
0005435097065	17140	Economy	7900.00
0005435097079	17140	Economy	7900.00
0005433341606	17140	Economy	7900.00
0005435097086	17140	Economy	7900.00
0005433341953	17140	Economy	7900.00
0005433507085	9061	Business	26600.00
0005432919545	9061	Business	26600.00
0005433507097	9061	Business	26600.00
0005433507080	9061	Business	26600.00
0005432919629	9061	Economy	8900.00
0005432919507	9061	Economy	8900.00
0005432919620	9061	Economy	8900.00
0005433481128	9061	Economy	8900.00
0005433481123	9061	Economy	8900.00
0005432919525	9061	Economy	9800.00
0005432919595	9061	Economy	9800.00
0005432919607	9061	Economy	9800.00
0005433507086	9061	Economy	8900.00
0005432919508	9061	Economy	8900.00
0005433507092	9061	Economy	8900.00
0005433507078	9061	Economy	8900.00
0005432919510	9061	Economy	8900.00
0005433507077	9061	Economy	8900.00
0005432919550	9061	Economy	8900.00
0005432919605	9061	Economy	8900.00
0005433507095	9061	Economy	8900.00
0005433481124	9061	Economy	8900.00
0005432919586	9061	Economy	8900.00
0005433507093	9061	Economy	8900.00
0005434158946	9061	Economy	8900.00
0005433481130	9061	Economy	8900.00
0005432919606	9061	Economy	8900.00
0005433507089	9061	Economy	8900.00
0005432919587	9061	Economy	8900.00
0005433507091	9061	Economy	8900.00
0005433481126	9061	Economy	8900.00
0005433507094	9061	Economy	8900.00
0005433507082	9061	Economy	8900.00
0005432919526	9061	Economy	8900.00
0005433481125	9061	Economy	8900.00
0005433507081	9061	Economy	8900.00
0005433507087	9061	Economy	8900.00
0005433507088	9061	Economy	8900.00
0005433481127	9061	Economy	8900.00
0005433481129	9061	Economy	8900.00
0005433507096	9061	Economy	8900.00
0005432919584	9061	Economy	8900.00
0005433507090	9061	Economy	8900.00
0005432919585	9061	Economy	8900.00
0005432919509	9061	Economy	8900.00
0005433507083	9061	Economy	8900.00
0005433507079	9061	Economy	8900.00
0005433507084	9061	Economy	8900.00
0005432919596	9061	Economy	8900.00
0005433481131	9061	Economy	8900.00
0005432919769	20446	Business	26600.00
0005432919776	20446	Business	26600.00
0005433506974	20446	Business	26600.00
0005433506927	20446	Business	26600.00
0005433481048	20446	Business	26600.00
0005433506964	20446	Business	26600.00
0005433506993	20446	Business	26600.00
0005434158967	20446	Economy	8900.00
0005432919765	20446	Economy	8900.00
0005433506963	20446	Economy	9800.00
0005433506929	20446	Economy	9800.00
0005432919761	20446	Economy	8900.00
0005432919764	20446	Economy	8900.00
0005432919762	20446	Economy	8900.00
0005432919777	20446	Economy	8900.00
0005433507036	20446	Economy	8900.00
0005432919766	20446	Economy	8900.00
0005432919779	20446	Economy	8900.00
0005433506934	20446	Economy	8900.00
0005432919767	20446	Economy	8900.00
0005432919775	20446	Economy	8900.00
0005433506935	20446	Economy	8900.00
0005433506891	20446	Economy	8900.00
0005433481070	20446	Economy	8900.00
0005434158966	20446	Economy	8900.00
0005432919771	20446	Economy	8900.00
0005432919780	20446	Economy	8900.00
0005433481047	20446	Economy	8900.00
0005433481054	20446	Economy	8900.00
0005433481081	20446	Economy	8900.00
0005433506925	20446	Economy	8900.00
0005433481064	20446	Economy	8900.00
0005433506932	20446	Economy	8900.00
0005432919770	20446	Economy	8900.00
0005432919760	20446	Economy	8900.00
0005433506920	20446	Economy	8900.00
0005432919773	20446	Economy	8900.00
0005432919763	20446	Economy	8900.00
0005433506915	20446	Economy	8900.00
0005432919774	20446	Economy	8900.00
0005433506933	20446	Economy	8900.00
0005433481098	20446	Economy	8900.00
0005433506976	20446	Economy	8900.00
0005433481044	20446	Economy	8900.00
0005432919778	20446	Economy	8900.00
0005432919768	20446	Economy	8900.00
0005433481073	20446	Economy	8900.00
0005432919772	20446	Economy	8900.00
0005433506955	20446	Economy	8900.00
0005433481045	20446	Economy	8900.00
0005433481065	20446	Economy	8900.00
0005432396218	10222	Economy	5800.00
0005432394080	10222	Economy	5800.00
0005435178978	10222	Economy	5800.00
0005432394077	10222	Economy	5800.00
0005432396217	10222	Economy	5800.00
0005432394078	10222	Economy	5800.00
0005432396216	10222	Economy	5800.00
0005432394079	10222	Economy	5800.00
0005432396219	10222	Economy	5800.00
0005432400085	18286	Economy	5800.00
0005432400078	18286	Economy	5800.00
0005432400087	18286	Economy	5800.00
0005432396185	18286	Economy	5800.00
0005432400079	18286	Economy	5800.00
0005432396182	18286	Economy	5800.00
0005435179392	18286	Economy	5800.00
0005432396181	18286	Economy	5800.00
0005432396186	18286	Economy	5800.00
0005435125652	10964	Business	9500.00
0005435125728	10964	Business	9500.00
0005435125912	10964	Business	9500.00
0005434411755	10964	Business	9500.00
0005434411758	10964	Business	9500.00
0005434411754	10964	Business	9500.00
0005435125895	10964	Business	9500.00
0005435625875	10964	Business	9500.00
0005435125794	10964	Business	9500.00
0005435554122	10964	Economy	3200.00
0005435125663	10964	Economy	3200.00
0005435125841	10964	Economy	3200.00
0005435125710	10964	Economy	3200.00
0005435125864	10964	Economy	3200.00
0005435625911	10964	Economy	3200.00
0005435125761	10964	Economy	3200.00
0005435625919	10964	Economy	3200.00
0005435125805	10964	Economy	3200.00
0005435125863	10964	Economy	3500.00
0005435125913	10964	Economy	3500.00
0005434928284	10964	Economy	3500.00
0005435625912	10964	Economy	3200.00
0005435125891	10964	Economy	3200.00
0005434411759	10964	Economy	3200.00
0005435625916	10964	Economy	3200.00
0005435625904	10964	Economy	3200.00
0005435125760	10964	Economy	3200.00
0005435125667	10964	Economy	3200.00
0005435125752	10964	Economy	3200.00
0005434411756	10964	Economy	3200.00
0005435625915	10964	Economy	3200.00
0005435125910	10964	Economy	3200.00
0005435125770	10964	Economy	3200.00
0005435125894	10964	Economy	3200.00
0005435125654	10964	Economy	3200.00
0005435125804	10964	Economy	3200.00
0005435125795	10964	Economy	3200.00
0005435125751	10964	Economy	3200.00
0005435554112	10964	Economy	3200.00
0005435125896	10964	Economy	3200.00
0005435125897	10964	Economy	3200.00
0005434411757	10964	Economy	3200.00
0005435125796	10964	Economy	3200.00
0005435625868	10964	Economy	3200.00
0005435125741	10964	Economy	3200.00
0005435125834	10964	Economy	3200.00
0005435554114	10964	Economy	3200.00
0005435625905	10964	Economy	3200.00
0005435125911	10964	Economy	3200.00
0005435125742	10964	Economy	3200.00
0005435625894	10964	Economy	3200.00
0005435125793	10964	Economy	3200.00
0005435125653	10964	Economy	3200.00
0005435125764	10964	Economy	3200.00
0005434928285	10964	Economy	3200.00
0005435625918	10964	Economy	3200.00
0005435125799	10964	Economy	3200.00
0005435125869	10964	Economy	3200.00
0005435125937	10964	Economy	3200.00
0005435125806	10964	Economy	3200.00
0005435125824	10964	Economy	3200.00
0005435625893	10964	Economy	3200.00
0005435125704	10964	Economy	3200.00
0005435125844	10964	Economy	3200.00
0005435125816	10964	Economy	3200.00
0005435554159	14744	Business	9500.00
0005435126185	14744	Business	9500.00
0005435626085	14744	Business	9500.00
0005435626084	14744	Business	9500.00
0005435126151	14744	Business	9500.00
0005435126174	14744	Business	9500.00
0005435126154	14744	Business	9500.00
0005435126173	14744	Business	9500.00
0005435126161	14744	Business	9500.00
0005435126163	14744	Business	9500.00
0005435126186	14744	Economy	3200.00
0005435126156	14744	Economy	3200.00
0005434928261	14744	Economy	3200.00
0005435126176	14744	Economy	3200.00
0005435626087	14744	Economy	3200.00
0005435626080	14744	Economy	3200.00
0005434928267	14744	Economy	3200.00
0005435126180	14744	Economy	3200.00
0005434928264	14744	Economy	3200.00
0005435126175	14744	Economy	3500.00
0005434411722	14744	Economy	3500.00
0005435626078	14744	Economy	3500.00
0005435126184	14744	Economy	3500.00
0005435126166	14744	Economy	3500.00
0005435626075	14744	Economy	3200.00
0005434928255	14744	Economy	3200.00
0005435626070	14744	Economy	3200.00
0005435126160	14744	Economy	3200.00
0005435126183	14744	Economy	3200.00
0005435126187	14744	Economy	3200.00
0005434928257	14744	Economy	3200.00
0005435126165	14744	Economy	3200.00
0005434411703	14744	Economy	3200.00
0005435126164	14744	Economy	3200.00
0005435126149	14744	Economy	3200.00
0005435126171	14744	Economy	3200.00
0005435626074	14744	Economy	3200.00
0005435554160	14744	Economy	3200.00
0005435126172	14744	Economy	3200.00
0005435126170	14744	Economy	3200.00
0005435126157	14744	Economy	3200.00
0005435126155	14744	Economy	3200.00
0005435126181	14744	Economy	3200.00
0005435126150	14744	Economy	3200.00
0005434411718	14744	Economy	3200.00
0005435626089	14744	Economy	3200.00
0005434411723	14744	Economy	3200.00
0005435554161	14744	Economy	3200.00
0005435626090	14744	Economy	3200.00
0005435626088	14744	Economy	3200.00
0005434411713	14744	Economy	3200.00
0005435126178	14744	Economy	3200.00
0005435126152	14744	Economy	3200.00
0005435554163	14744	Economy	3200.00
0005435626076	14744	Economy	3200.00
0005435554158	14744	Economy	3200.00
0005435126179	14744	Economy	3200.00
0005435126162	14744	Economy	3200.00
0005435126167	14744	Economy	3200.00
0005435626077	14744	Economy	3200.00
0005435626091	14744	Economy	3200.00
0005435626081	14744	Economy	3200.00
0005435626073	14744	Economy	3200.00
0005435626079	14744	Economy	3200.00
0005435126169	14744	Economy	3200.00
0005435626071	14744	Economy	3200.00
0005434928256	14744	Economy	3200.00
0005434928262	14744	Economy	3200.00
0005435126177	14744	Economy	3200.00
0005435554162	14744	Economy	3200.00
0005435626083	14744	Economy	3200.00
0005435626082	14744	Economy	3200.00
0005435126153	14744	Economy	3200.00
0005435126159	14744	Economy	3200.00
0005435126182	14744	Economy	3200.00
0005435626086	14744	Economy	3200.00
0005435126158	14744	Economy	3200.00
0005435126168	14744	Economy	3200.00
0005435626072	14744	Economy	3200.00
0005434411714	14744	Economy	3200.00
0005435715377	7126	Business	86900.00
0005435443192	7126	Business	86900.00
0005435715372	7126	Business	86900.00
0005435715370	7126	Business	86900.00
0005435715385	7126	Business	86900.00
0005432400103	7126	Economy	29000.00
0005432400104	7126	Economy	29000.00
0005435179384	7126	Economy	29000.00
0005435715374	7126	Economy	29000.00
0005435715387	7126	Economy	31900.00
0005435715378	7126	Economy	29000.00
0005435715379	7126	Economy	29000.00
0005435715376	7126	Economy	29000.00
0005435715375	7126	Economy	29000.00
0005435715380	7126	Economy	29000.00
0005435443169	7126	Economy	29000.00
0005435715382	7126	Economy	29000.00
0005435443200	7126	Economy	29000.00
0005435715371	7126	Economy	29000.00
0005435715373	7126	Economy	29000.00
0005435715384	7126	Economy	29000.00
0005435715383	7126	Economy	29000.00
0005435443215	7126	Economy	29000.00
0005435443173	7126	Economy	29000.00
0005432398179	7126	Economy	29000.00
0005435443193	7126	Economy	29000.00
0005435715388	7126	Economy	29000.00
0005432398177	7126	Economy	29000.00
0005435179383	7126	Economy	29000.00
0005435216558	7126	Economy	29000.00
0005435715386	7126	Economy	29000.00
0005432398176	7126	Economy	29000.00
0005435219169	7126	Economy	29000.00
0005432400102	7126	Economy	29000.00
0005432400101	7126	Economy	29000.00
0005435443203	7126	Economy	29000.00
0005435443220	7126	Economy	29000.00
0005435715381	7126	Economy	29000.00
0005432398178	7126	Economy	29000.00
0005435443184	7126	Economy	29000.00
0005435443201	7126	Economy	29000.00
0005435443263	27069	Business	86900.00
0005435715249	27069	Business	86900.00
0005432398154	27069	Economy	29000.00
0005435178989	27069	Economy	29000.00
0005435715267	27069	Economy	29000.00
0005435443268	27069	Economy	29000.00
0005435443262	27069	Economy	31900.00
0005435715243	27069	Economy	31900.00
0005432394048	27069	Economy	29000.00
0005435715255	27069	Economy	29000.00
0005435715256	27069	Economy	29000.00
0005435443261	27069	Economy	29000.00
0005435715272	27069	Economy	29000.00
0005432394043	27069	Economy	29000.00
0005435443265	27069	Economy	29000.00
0005435443264	27069	Economy	29000.00
0005435715244	27069	Economy	29000.00
0005435715232	27069	Economy	29000.00
0005435443260	27069	Economy	29000.00
0005435178487	27069	Economy	29000.00
0005435443266	27069	Economy	29000.00
0005435715262	27069	Economy	29000.00
0005435715263	27069	Economy	29000.00
0005435715242	27069	Economy	29000.00
0005435178488	27069	Economy	29000.00
0005432394032	27069	Economy	29000.00
0005435715241	27069	Economy	29000.00
0005435443267	27069	Economy	29000.00
0005434084909	2717	Economy	7700.00
0005434084907	2717	Economy	7700.00
0005434084905	2717	Economy	7700.00
0005434084908	2717	Economy	7700.00
0005434084906	2717	Economy	7700.00
0005433060399	28466	Economy	7700.00
0005433060400	28466	Economy	7700.00
0005433060401	28466	Economy	7700.00
0005434084860	28466	Economy	7700.00
0005433060398	28466	Economy	7700.00
0005435540675	11391	Business	20200.00
0005435517716	11391	Business	20200.00
0005435517667	11391	Business	20200.00
0005435540711	11391	Business	20200.00
0005435517699	11391	Business	20200.00
0005435517635	11391	Business	20200.00
0005435517656	11391	Economy	6700.00
0005435540833	11391	Economy	6700.00
0005435517634	11391	Economy	6700.00
0005435517659	11391	Economy	6700.00
0005435540757	11391	Economy	6700.00
0005435517703	11391	Economy	6700.00
0005435517688	11391	Economy	7400.00
0005435540661	11391	Economy	7400.00
0005435540701	11391	Economy	6700.00
0005435517675	11391	Economy	6700.00
0005435540715	11391	Economy	6700.00
0005435517715	11391	Economy	6700.00
0005435540772	11391	Economy	6700.00
0005435517700	11391	Economy	6700.00
0005435540748	11391	Economy	6700.00
0005435540749	11391	Economy	6700.00
0005435540741	11391	Economy	6700.00
0005435517740	11391	Economy	6700.00
0005435517597	11391	Economy	6700.00
0005435540832	11391	Economy	6700.00
0005435540687	11391	Economy	6700.00
0005435517658	11391	Economy	6700.00
0005435540639	11391	Economy	6700.00
0005435517585	11391	Economy	6700.00
0005435540690	11391	Economy	6700.00
0005435540714	11391	Economy	6700.00
0005435517657	11391	Economy	6700.00
0005435540653	11391	Economy	6700.00
0005435517713	11391	Economy	6700.00
0005435540676	11391	Economy	6700.00
0005435540660	11391	Economy	6700.00
0005435517629	11391	Economy	6700.00
0005435540652	11391	Economy	6700.00
0005435517698	11391	Economy	6700.00
0005435517741	11391	Economy	6700.00
0005435540735	11391	Economy	6700.00
0005435540877	22248	Business	20200.00
0005435529140	22248	Business	20200.00
0005435540874	22248	Business	20200.00
0005432294473	22248	Business	20200.00
0005435529141	22248	Economy	6700.00
0005435540883	22248	Economy	6700.00
0005435540872	22248	Economy	6700.00
0005435540886	22248	Economy	6700.00
0005435529133	22248	Economy	6700.00
0005435540875	22248	Economy	7400.00
0005435540885	22248	Economy	7400.00
0005435529134	22248	Economy	7400.00
0005435529137	22248	Economy	6700.00
0005435540867	22248	Economy	6700.00
0005435529128	22248	Economy	6700.00
0005435540871	22248	Economy	6700.00
0005435540887	22248	Economy	6700.00
0005435529127	22248	Economy	6700.00
0005435540866	22248	Economy	6700.00
0005435540884	22248	Economy	6700.00
0005435540870	22248	Economy	6700.00
0005435540876	22248	Economy	6700.00
0005435529125	22248	Economy	6700.00
0005435529132	22248	Economy	6700.00
0005435540881	22248	Economy	6700.00
0005435540879	22248	Economy	6700.00
0005435529124	22248	Economy	6700.00
0005435529123	22248	Economy	6700.00
0005435529129	22248	Economy	6700.00
0005435529122	22248	Economy	6700.00
0005435529143	22248	Economy	6700.00
0005435540880	22248	Economy	6700.00
0005435529139	22248	Economy	6700.00
0005435529136	22248	Economy	6700.00
0005435529130	22248	Economy	6700.00
0005435540878	22248	Economy	6700.00
0005435540868	22248	Economy	6700.00
0005435529138	22248	Economy	6700.00
0005435529142	22248	Economy	6700.00
0005435529135	22248	Economy	6700.00
0005435540869	22248	Economy	6700.00
0005435540882	22248	Economy	6700.00
0005435529131	22248	Economy	6700.00
0005435529126	22248	Economy	6700.00
0005435540873	22248	Economy	6700.00
0005433251108	2262	Business	20200.00
0005434907037	2262	Business	20200.00
0005433251155	2262	Business	20200.00
0005434907024	2262	Business	20200.00
0005433400939	2262	Business	20200.00
0005433251026	2262	Business	20200.00
0005433251077	2262	Business	20200.00
0005433400945	2262	Business	20200.00
0005434907048	2262	Business	20200.00
0005433251208	2262	Business	20200.00
0005434907045	2262	Business	20200.00
0005434907021	2262	Business	20200.00
0005433251152	2262	Economy	6700.00
0005433251079	2262	Economy	6700.00
0005434907014	2262	Economy	6700.00
0005433251114	2262	Economy	6700.00
0005433251085	2262	Economy	6700.00
0005434907034	2262	Economy	6700.00
0005433251055	2262	Economy	6700.00
0005434907013	2262	Economy	6700.00
0005434907028	2262	Economy	7400.00
0005433251123	2262	Economy	7400.00
0005434907052	2262	Economy	7400.00
0005433400953	2262	Economy	7400.00
0005434907044	2262	Economy	7400.00
0005434907032	2262	Economy	6700.00
0005433251060	2262	Economy	6700.00
0005434907050	2262	Economy	6700.00
0005433251151	2262	Economy	6700.00
0005433251199	2262	Economy	6700.00
0005434907035	2262	Economy	6700.00
0005434907049	2262	Economy	6700.00
0005433251107	2262	Economy	6700.00
0005433251102	2262	Economy	6700.00
0005433251042	2262	Economy	6700.00
0005433400940	2262	Economy	6700.00
0005433250994	2262	Economy	6700.00
0005434907017	2262	Economy	6700.00
0005433251023	2262	Economy	6700.00
0005434907019	2262	Economy	6700.00
0005434907030	2262	Economy	6700.00
0005433251027	2262	Economy	6700.00
0005433400952	2262	Economy	6700.00
0005433251127	2262	Economy	6700.00
0005434907051	2262	Economy	6700.00
0005433251134	2262	Economy	6700.00
0005434907011	2262	Economy	6700.00
0005433400947	2262	Economy	6700.00
0005434907040	2262	Economy	6700.00
0005434907023	2262	Economy	6700.00
0005433400938	2262	Economy	6700.00
0005434907033	2262	Economy	6700.00
0005433251176	2262	Economy	6700.00
0005434907026	2262	Economy	6700.00
0005433251089	2262	Economy	6700.00
0005434907047	2262	Economy	6700.00
0005434907038	2262	Economy	6700.00
0005434907018	2262	Economy	6700.00
0005434907015	2262	Economy	6700.00
0005434907025	2262	Economy	6700.00
0005434907022	2262	Economy	6700.00
0005433251056	2262	Economy	6700.00
0005434907042	2262	Economy	6700.00
0005433251097	2262	Economy	6700.00
0005433251109	2262	Economy	6700.00
0005434907053	2262	Economy	6700.00
0005433400944	2262	Economy	6700.00
0005434907020	2262	Economy	6700.00
0005433251006	2262	Economy	6700.00
0005434907046	2262	Economy	6700.00
0005433251175	2262	Economy	6700.00
0005434907039	2262	Economy	6700.00
0005434907036	2262	Economy	6700.00
0005434907027	2262	Economy	6700.00
0005434907041	2262	Economy	6700.00
0005433251024	2262	Economy	6700.00
0005434907043	2262	Economy	6700.00
0005434907031	2262	Economy	6700.00
0005434907016	2262	Economy	6700.00
0005433251094	2262	Economy	6700.00
0005433250968	2262	Economy	6700.00
0005434907029	2262	Economy	6700.00
0005433251198	2262	Economy	6700.00
0005433251028	2262	Economy	6700.00
0005433251156	2262	Economy	6700.00
0005434907012	2262	Economy	6700.00
0005433251115	2262	Economy	6700.00
0005433251078	2262	Economy	6700.00
0005433251131	2262	Economy	6700.00
0005433251197	2262	Economy	6700.00
0005433250940	2262	Economy	6700.00
0005433251025	2262	Economy	6700.00
0005433251090	2262	Economy	6700.00
0005433251057	2262	Economy	6700.00
0005433251306	25626	Business	20200.00
0005433251316	25626	Business	20200.00
0005433251321	25626	Business	20200.00
0005434906465	25626	Business	20200.00
0005433251337	25626	Business	20200.00
0005434906491	25626	Business	20200.00
0005433400969	25626	Business	20200.00
0005433251334	25626	Business	20200.00
0005434906592	25626	Business	20200.00
0005433400968	25626	Business	20200.00
0005433251314	25626	Economy	6700.00
0005433251310	25626	Economy	6700.00
0005434906503	25626	Economy	6700.00
0005433251309	25626	Economy	6700.00
0005433400966	25626	Economy	6700.00
0005434906382	25626	Economy	6700.00
0005434906451	25626	Economy	6700.00
0005434906783	25626	Economy	7400.00
0005433251320	25626	Economy	7400.00
0005433251332	25626	Economy	7400.00
0005434906614	25626	Economy	7400.00
0005433251319	25626	Economy	6700.00
0005433251327	25626	Economy	6700.00
0005434906472	25626	Economy	6700.00
0005434906510	25626	Economy	6700.00
0005434906554	25626	Economy	6700.00
0005434906797	25626	Economy	6700.00
0005433251308	25626	Economy	6700.00
0005434906666	25626	Economy	6700.00
0005434906440	25626	Economy	6700.00
0005434906383	25626	Economy	6700.00
0005433251311	25626	Economy	6700.00
0005433251315	25626	Economy	6700.00
0005434906468	25626	Economy	6700.00
0005434906509	25626	Economy	6700.00
0005434906467	25626	Economy	6700.00
0005434906529	25626	Economy	6700.00
0005433251324	25626	Economy	6700.00
0005434906450	25626	Economy	6700.00
0005434906466	25626	Economy	6700.00
0005433251323	25626	Economy	6700.00
0005434906439	25626	Economy	6700.00
0005433251313	25626	Economy	6700.00
0005434906604	25626	Economy	6700.00
0005433251317	25626	Economy	6700.00
0005433251307	25626	Economy	6700.00
0005434906377	25626	Economy	6700.00
0005434906384	25626	Economy	6700.00
0005433251333	25626	Economy	6700.00
0005434906469	25626	Economy	6700.00
0005433251325	25626	Economy	6700.00
0005434906540	25626	Economy	6700.00
0005433251312	25626	Economy	6700.00
0005434906396	25626	Economy	6700.00
0005434906784	25626	Economy	6700.00
0005433251328	25626	Economy	6700.00
0005433400967	25626	Economy	6700.00
0005433251331	25626	Economy	6700.00
0005434906372	25626	Economy	6700.00
0005434906563	25626	Economy	6700.00
0005433251335	25626	Economy	6700.00
0005434906606	25626	Economy	6700.00
0005434906612	25626	Economy	6700.00
0005434906833	25626	Economy	6700.00
0005434906371	25626	Economy	6700.00
0005433251326	25626	Economy	6700.00
0005434906365	25626	Economy	6700.00
0005433251330	25626	Economy	6700.00
0005433251329	25626	Economy	6700.00
0005433251318	25626	Economy	6700.00
0005433251322	25626	Economy	6700.00
0005434906471	25626	Economy	6700.00
0005433251336	25626	Economy	6700.00
0005432620964	2524	Economy	13600.00
0005432620967	2524	Economy	13600.00
0005432620962	2524	Economy	12400.00
0005432620968	2524	Economy	12400.00
0005432620966	2524	Economy	12400.00
0005432620972	2524	Economy	12400.00
0005432862242	2524	Economy	12400.00
0005432620970	2524	Economy	12400.00
0005432862198	2524	Economy	12400.00
0005432620963	2524	Economy	12400.00
0005432862195	2524	Economy	12400.00
0005432862166	2524	Economy	12400.00
0005432620965	2524	Economy	12400.00
0005432862185	2524	Economy	12400.00
0005432620971	2524	Economy	12400.00
0005432620973	2524	Economy	12400.00
0005432862199	2524	Economy	12400.00
0005432620969	2524	Economy	12400.00
0005432620960	2524	Economy	12400.00
0005432862238	2524	Economy	12400.00
0005432862237	2524	Economy	12400.00
0005432620961	2524	Economy	12400.00
0005432862259	28031	Economy	13600.00
0005432620892	28031	Economy	12400.00
0005432862260	28031	Economy	12400.00
0005432620857	28031	Economy	12400.00
0005432620830	28031	Economy	12400.00
0005432862262	28031	Economy	12400.00
0005432620877	28031	Economy	12400.00
0005432862264	28031	Economy	12400.00
0005432620847	28031	Economy	12400.00
0005432862261	28031	Economy	12400.00
0005432862263	28031	Economy	12400.00
0005432620815	28031	Economy	12400.00
0005432862265	28031	Economy	12400.00
0005432862267	28031	Economy	12400.00
0005432620835	28031	Economy	12400.00
0005432620848	28031	Economy	12400.00
0005432620831	28031	Economy	12400.00
0005432620851	28031	Economy	12400.00
0005432862266	28031	Economy	12400.00
0005432620854	28031	Economy	12400.00
0005432620839	28031	Economy	12400.00
0005432620853	28031	Economy	12400.00
0005432620816	28031	Economy	12400.00
0005432620852	28031	Economy	12400.00
0005434097468	13081	Economy	11300.00
0005434097469	13081	Economy	11300.00
0005433451608	31046	Economy	8400.00
0005433451609	31046	Economy	8400.00
0005433452704	31459	Economy	8400.00
0005433452701	31459	Economy	8400.00
0005433452716	31459	Economy	8400.00
0005433452705	31459	Economy	8400.00
0005433454848	31459	Economy	8400.00
0005433134086	11973	Economy	7200.00
0005433129218	11973	Economy	6600.00
0005434142549	11973	Economy	6600.00
0005433134085	11973	Economy	6600.00
0005433134073	11973	Economy	6600.00
0005434142546	11973	Economy	6600.00
0005433134088	11973	Economy	6600.00
0005433134087	11973	Economy	6600.00
0005433129209	11973	Economy	6600.00
0005434142545	11973	Economy	6600.00
0005433129214	11973	Economy	6600.00
0005433134114	29841	Economy	6600.00
0005433134113	29841	Economy	6600.00
0005434326084	29841	Economy	6600.00
0005434184655	29841	Economy	6600.00
0005433131686	29841	Economy	6600.00
0005434183568	29841	Economy	6600.00
0005434183570	29841	Economy	6600.00
0005434184654	29841	Economy	6600.00
0005434142587	29841	Economy	6600.00
0005434142586	29841	Economy	6600.00
0005433131685	29841	Economy	6600.00
0005434142585	29841	Economy	6600.00
0005433131684	29841	Economy	6600.00
0005433134115	29841	Economy	6600.00
0005434142588	29841	Economy	6600.00
0005433134116	29841	Economy	6600.00
0005434183569	29841	Economy	6600.00
0005433134112	29841	Economy	6600.00
0005435697161	16490	Economy	19900.00
0005435697187	16490	Economy	19900.00
0005435697160	16490	Economy	19900.00
0005435697168	16490	Economy	19900.00
0005435697169	16490	Economy	18100.00
0005435697178	16490	Economy	18100.00
0005435697174	16490	Economy	18100.00
0005435935007	16490	Economy	18100.00
0005435697185	16490	Economy	18100.00
0005435697176	16490	Economy	18100.00
0005435697159	16490	Economy	18100.00
0005435697179	16490	Economy	18100.00
0005435697162	16490	Economy	18100.00
0005435697180	16490	Economy	18100.00
0005435697181	16490	Economy	18100.00
0005435697167	16490	Economy	18100.00
0005435697165	16490	Economy	18100.00
0005435935005	16490	Economy	18100.00
0005435697175	16490	Economy	18100.00
0005435697171	16490	Economy	18100.00
0005435697186	16490	Economy	18100.00
0005435697164	16490	Economy	18100.00
0005435697172	16490	Economy	18100.00
0005435935003	16490	Economy	18100.00
0005435697182	16490	Economy	18100.00
0005435697177	16490	Economy	18100.00
0005435697173	16490	Economy	18100.00
0005435697184	16490	Economy	18100.00
0005435697163	16490	Economy	18100.00
0005435935004	16490	Economy	18100.00
0005435697170	16490	Economy	18100.00
0005435697166	16490	Economy	18100.00
0005435935016	16490	Economy	18100.00
0005435697183	16490	Economy	18100.00
0005435697026	24693	Economy	19900.00
0005435696910	24693	Economy	19900.00
0005435696961	24693	Economy	18100.00
0005435697038	24693	Economy	18100.00
0005435935029	24693	Economy	18100.00
0005435697025	24693	Economy	18100.00
0005435697031	24693	Economy	18100.00
0005435696931	24693	Economy	18100.00
0005435697032	24693	Economy	18100.00
0005435696936	24693	Economy	18100.00
0005435696937	24693	Economy	18100.00
0005435697003	24693	Economy	18100.00
0005435697024	24693	Economy	18100.00
0005435696867	24693	Economy	18100.00
0005435696930	24693	Economy	18100.00
0005435697014	24693	Economy	18100.00
0005435697128	24693	Economy	18100.00
0005435697037	24693	Economy	18100.00
0005435935028	24693	Economy	18100.00
0005435696946	24693	Economy	18100.00
0005435697013	24693	Economy	18100.00
0005435697004	24693	Economy	18100.00
0005435696888	24693	Economy	18100.00
0005435696960	24693	Economy	18100.00
0005435696868	24693	Economy	18100.00
0005435696945	24693	Economy	18100.00
0005433724781	18807	Economy	4400.00
0005433724779	18807	Economy	4400.00
0005432968806	18807	Economy	4400.00
0005433724780	18807	Economy	4400.00
0005433724777	18807	Economy	4400.00
0005433724778	18807	Economy	4400.00
0005433724728	21635	Economy	4400.00
0005433724735	21635	Economy	4400.00
0005433724743	21635	Economy	4400.00
0005432968830	21635	Economy	4400.00
0005433724732	21635	Economy	4400.00
0005433724729	21635	Economy	4400.00
0005432968831	21635	Economy	4400.00
0005434137742	7333	Business	23100.00
0005434087487	7333	Business	23100.00
0005434137768	7333	Business	23100.00
0005434137753	7333	Business	23100.00
0005434137780	7333	Business	23100.00
0005434137749	7333	Business	23100.00
0005434137725	7333	Business	23100.00
0005434137774	7333	Business	23100.00
0005434137709	7333	Business	23100.00
0005434137737	7333	Business	23100.00
0005434137734	7333	Economy	7700.00
0005434137712	7333	Economy	7700.00
0005434137755	7333	Economy	7700.00
0005434137724	7333	Economy	7700.00
0005434087488	7333	Economy	7700.00
0005434137746	7333	Economy	7700.00
0005434137782	7333	Economy	7700.00
0005434137751	7333	Economy	7700.00
0005434137722	7333	Economy	7700.00
0005434137777	7333	Economy	8500.00
0005434137764	7333	Economy	8500.00
0005434137769	7333	Economy	8500.00
0005434137760	7333	Economy	8500.00
0005434137754	7333	Economy	8500.00
0005434137747	7333	Economy	7700.00
0005434137759	7333	Economy	7700.00
0005434137766	7333	Economy	7700.00
0005434137741	7333	Economy	7700.00
0005434137708	7333	Economy	7700.00
0005434137727	7333	Economy	7700.00
0005434137783	7333	Economy	7700.00
0005434137778	7333	Economy	7700.00
0005434137779	7333	Economy	7700.00
0005434137731	7333	Economy	7700.00
0005434137762	7333	Economy	7700.00
0005434137717	7333	Economy	7700.00
0005434137781	7333	Economy	7700.00
0005434137732	7333	Economy	7700.00
0005434137770	7333	Economy	7700.00
0005434137744	7333	Economy	7700.00
0005434137740	7333	Economy	7700.00
0005434137757	7333	Economy	7700.00
0005434137773	7333	Economy	7700.00
0005434137763	7333	Economy	7700.00
0005434137743	7333	Economy	7700.00
0005434137730	7333	Economy	7700.00
0005434137710	7333	Economy	7700.00
0005434137750	7333	Economy	7700.00
0005434137748	7333	Economy	7700.00
0005434137745	7333	Economy	7700.00
0005434137721	7333	Economy	7700.00
0005434137729	7333	Economy	7700.00
0005434137758	7333	Economy	7700.00
0005434137715	7333	Economy	7700.00
0005434137720	7333	Economy	7700.00
0005434137765	7333	Economy	7700.00
0005434137733	7333	Economy	7700.00
0005434137756	7333	Economy	7700.00
0005434137776	7333	Economy	7700.00
0005434137714	7333	Economy	7700.00
0005434137767	7333	Economy	7700.00
0005434087489	7333	Economy	7700.00
0005434137728	7333	Economy	7700.00
0005434137771	7333	Economy	7700.00
0005434087490	7333	Economy	7700.00
0005434137772	7333	Economy	7700.00
0005434137761	7333	Economy	7700.00
0005434137739	7333	Economy	7700.00
0005434137784	7333	Economy	7700.00
0005434137716	7333	Economy	7700.00
0005434137719	7333	Economy	7700.00
0005434137735	7333	Economy	7700.00
0005434137723	7333	Economy	7700.00
0005434137752	7333	Economy	7700.00
0005434137738	7333	Economy	7700.00
0005434137718	7333	Economy	7700.00
0005434137726	7333	Economy	7700.00
0005434137775	7333	Economy	7700.00
0005434137713	7333	Economy	7700.00
0005434137711	7333	Economy	7700.00
0005434137736	7333	Economy	7700.00
0005434137006	28575	Business	23100.00
0005434137095	28575	Business	23100.00
0005434137027	28575	Business	23100.00
0005434136837	28575	Business	23100.00
0005434137051	28575	Business	23100.00
0005434137080	28575	Business	23100.00
0005434136941	28575	Business	23100.00
0005434136931	28575	Business	23100.00
0005434137443	28575	Business	23100.00
0005434136845	28575	Economy	7700.00
0005434136754	28575	Economy	7700.00
0005434137310	28575	Economy	7700.00
0005434137094	28575	Economy	7700.00
0005434137127	28575	Economy	7700.00
0005434136889	28575	Economy	7700.00
0005434136980	28575	Economy	7700.00
0005434137253	28575	Economy	7700.00
0005434137131	28575	Economy	7700.00
0005434136826	28575	Economy	8500.00
0005434137087	28575	Economy	8500.00
0005434137232	28575	Economy	8500.00
0005434137332	28575	Economy	8500.00
0005434137331	28575	Economy	8500.00
0005434087465	28575	Economy	7700.00
0005434137075	28575	Economy	7700.00
0005434137028	28575	Economy	7700.00
0005434136891	28575	Economy	7700.00
0005434136976	28575	Economy	7700.00
0005434137176	28575	Economy	7700.00
0005434136787	28575	Economy	7700.00
0005434136979	28575	Economy	7700.00
0005434136978	28575	Economy	7700.00
0005434087466	28575	Economy	7700.00
0005434137242	28575	Economy	7700.00
0005434136838	28575	Economy	7700.00
0005434087453	28575	Economy	7700.00
0005434136968	28575	Economy	7700.00
0005434137086	28575	Economy	7700.00
0005434136946	28575	Economy	7700.00
0005434136818	28575	Economy	7700.00
0005434136936	28575	Economy	7700.00
0005434136874	28575	Economy	7700.00
0005434137153	28575	Economy	7700.00
0005434136765	28575	Economy	7700.00
0005434136764	28575	Economy	7700.00
0005434137140	28575	Economy	7700.00
0005434137098	28575	Economy	7700.00
0005434137071	28575	Economy	7700.00
0005434137165	28575	Economy	7700.00
0005434137007	28575	Economy	7700.00
0005434137113	28575	Economy	7700.00
0005434136682	28575	Economy	7700.00
0005434137052	28575	Economy	7700.00
0005434136937	28575	Economy	7700.00
0005434136977	28575	Economy	7700.00
0005434136932	28575	Economy	7700.00
0005434087452	28575	Economy	7700.00
0005434137128	28575	Economy	7700.00
0005434136935	28575	Economy	7700.00
0005434136988	28575	Economy	7700.00
0005434137241	28575	Economy	7700.00
0005434136814	28575	Economy	7700.00
0005434136689	28575	Economy	7700.00
0005434136725	28575	Economy	7700.00
0005434137074	28575	Economy	7700.00
0005434137079	28575	Economy	7700.00
0005434137122	28575	Economy	7700.00
0005434137025	28575	Economy	7700.00
0005434136783	28575	Economy	7700.00
0005434136813	28575	Economy	7700.00
0005434136947	28575	Economy	7700.00
0005434137012	28575	Economy	7700.00
0005434137193	28575	Economy	7700.00
0005434136766	28575	Economy	7700.00
0005434137044	28575	Economy	7700.00
0005434137081	28575	Economy	7700.00
0005434137082	28575	Economy	7700.00
0005434137254	28575	Economy	7700.00
0005434136956	28575	Economy	7700.00
0005434136940	28575	Economy	7700.00
0005434087432	28575	Economy	7700.00
0005434136724	28575	Economy	7700.00
0005434136825	28575	Economy	7700.00
0005433407487	1939	Economy	23900.00
0005435808182	1939	Economy	23900.00
0005435808179	1939	Economy	21700.00
0005435808187	1939	Economy	21700.00
0005435808177	1939	Economy	21700.00
0005433407488	1939	Economy	21700.00
0005435808184	1939	Economy	21700.00
0005435808185	1939	Economy	21700.00
0005435808183	1939	Economy	21700.00
0005435808178	1939	Economy	21700.00
0005435808181	1939	Economy	21700.00
0005435808186	1939	Economy	21700.00
0005434610211	1939	Economy	21700.00
0005434610212	1939	Economy	21700.00
0005435808180	1939	Economy	21700.00
0005434610209	1939	Economy	21700.00
0005433407486	1939	Economy	21700.00
0005434610210	1939	Economy	21700.00
0005433407481	1939	Economy	21700.00
0005433407494	1939	Economy	21700.00
0005434610167	23108	Economy	23900.00
0005433407533	23108	Economy	23900.00
0005433407536	23108	Economy	21700.00
0005433407537	23108	Economy	21700.00
0005435808053	23108	Economy	21700.00
0005433407532	23108	Economy	21700.00
0005433407530	23108	Economy	21700.00
0005434610182	23108	Economy	21700.00
0005435808072	23108	Economy	21700.00
0005435808057	23108	Economy	21700.00
0005434610166	23108	Economy	21700.00
0005433407531	23108	Economy	21700.00
0005433407538	23108	Economy	21700.00
0005435808071	23108	Economy	21700.00
0005435808063	23108	Economy	21700.00
0005435808115	23108	Economy	21700.00
0005435808056	23108	Economy	21700.00
0005433407534	23108	Economy	21700.00
0005433407535	23108	Economy	21700.00
0005434610168	23108	Economy	21700.00
0005434610183	23108	Economy	21700.00
0005434503489	16673	Economy	7600.00
0005434503603	16673	Economy	6900.00
0005434503624	16673	Economy	6900.00
0005434503551	16673	Economy	6900.00
0005434503586	16673	Economy	6900.00
0005434503577	16673	Economy	6900.00
0005434503562	16673	Economy	6900.00
0005434503557	16673	Economy	6900.00
0005434503473	16673	Economy	6900.00
0005434503466	16673	Economy	6900.00
0005434503491	16673	Economy	6900.00
0005434503587	16673	Economy	6900.00
0005434503580	16673	Economy	6900.00
0005434503506	16673	Economy	6900.00
0005434503797	16673	Economy	6900.00
0005434503523	16673	Economy	6900.00
0005434503539	16673	Economy	6900.00
0005434503581	16673	Economy	6900.00
0005434503684	16673	Economy	6900.00
0005434503527	16673	Economy	6900.00
0005434503556	16673	Economy	6900.00
0005434503505	16673	Economy	6900.00
0005434503509	16673	Economy	6900.00
0005434503579	16673	Economy	6900.00
0005434503490	16673	Economy	6900.00
0005434503653	16673	Economy	6900.00
0005434503522	16673	Economy	6900.00
0005434503578	16673	Economy	6900.00
0005434503630	16673	Economy	6900.00
0005434503531	16673	Economy	6900.00
0005434503504	16673	Economy	6900.00
0005434503593	16673	Economy	6900.00
0005434503524	16673	Economy	6900.00
0005434503652	16673	Economy	6900.00
0005434503465	16673	Economy	6900.00
0005434503904	22932	Economy	7600.00
0005434503934	22932	Economy	7600.00
0005434503912	22932	Economy	7600.00
0005434503925	22932	Economy	7600.00
0005434503930	22932	Economy	6900.00
0005434503905	22932	Economy	6900.00
0005434503917	22932	Economy	6900.00
0005434503911	22932	Economy	6900.00
0005434503903	22932	Economy	6900.00
0005434503919	22932	Economy	6900.00
0005434503932	22932	Economy	6900.00
0005434503924	22932	Economy	6900.00
0005434503908	22932	Economy	6900.00
0005434503909	22932	Economy	6900.00
0005434503906	22932	Economy	6900.00
0005434503902	22932	Economy	6900.00
0005434503937	22932	Economy	6900.00
0005434503916	22932	Economy	6900.00
0005434503929	22932	Economy	6900.00
0005434503914	22932	Economy	6900.00
0005434503922	22932	Economy	6900.00
0005434503938	22932	Economy	6900.00
0005434503923	22932	Economy	6900.00
0005434503936	22932	Economy	6900.00
0005434503933	22932	Economy	6900.00
0005434503926	22932	Economy	6900.00
0005434503931	22932	Economy	6900.00
0005434503901	22932	Economy	6900.00
0005434503920	22932	Economy	6900.00
0005434503935	22932	Economy	6900.00
0005434503921	22932	Economy	6900.00
0005434503910	22932	Economy	6900.00
0005434503915	22932	Economy	6900.00
0005434503907	22932	Economy	6900.00
0005434503927	22932	Economy	6900.00
0005434503928	22932	Economy	6900.00
0005434503918	22932	Economy	6900.00
0005434503939	22932	Economy	6900.00
0005434503913	22932	Economy	6900.00
0005435078268	2211	Economy	7700.00
0005433266601	2211	Economy	7000.00
0005433266622	2211	Economy	7000.00
0005433266574	2211	Economy	7000.00
0005435078256	2211	Economy	7000.00
0005435078267	2211	Economy	7000.00
0005435078261	2211	Economy	7000.00
0005435078260	2211	Economy	7000.00
0005435078263	2211	Economy	7000.00
0005435078264	2211	Economy	7000.00
0005433266589	2211	Economy	7000.00
0005435078262	2211	Economy	7000.00
0005435078259	2211	Economy	7000.00
0005435078269	2211	Economy	7000.00
0005435078265	2211	Economy	7000.00
0005435078258	2211	Economy	7000.00
0005435078270	2211	Economy	7000.00
0005435078266	2211	Economy	7000.00
0005433266592	2211	Economy	7000.00
0005433266623	2211	Economy	7000.00
0005435078255	2211	Economy	7000.00
0005435078257	2211	Economy	7000.00
0005435078271	2211	Economy	7000.00
0005433266673	24341	Economy	7700.00
0005435078153	24341	Economy	7000.00
0005435078140	24341	Economy	7000.00
0005433266677	24341	Economy	7000.00
0005435078139	24341	Economy	7000.00
0005433266680	24341	Economy	7000.00
0005435078119	24341	Economy	7000.00
0005435078173	24341	Economy	7000.00
0005433266678	24341	Economy	7000.00
0005435078149	24341	Economy	7000.00
0005435078124	24341	Economy	7000.00
0005435078080	24341	Economy	7000.00
0005433266679	24341	Economy	7000.00
0005435078141	24341	Economy	7000.00
0005433266675	24341	Economy	7000.00
0005435078098	24341	Economy	7000.00
0005435078148	24341	Economy	7000.00
0005435078152	24341	Economy	7000.00
0005433266674	24341	Economy	7000.00
0005435078099	24341	Economy	7000.00
0005433266676	24341	Economy	7000.00
0005434988681	6628	Economy	10800.00
0005435464480	6628	Economy	10800.00
0005434988687	6628	Economy	10800.00
0005435803249	6628	Economy	9800.00
0005434988682	6628	Economy	9800.00
0005434988688	6628	Economy	9800.00
0005435803250	6628	Economy	9800.00
0005434988679	6628	Economy	9800.00
0005434988683	6628	Economy	9800.00
0005434988680	6628	Economy	9800.00
0005434988678	6628	Economy	9800.00
0005435464483	6628	Economy	9800.00
0005435803251	6628	Economy	9800.00
0005435803248	6628	Economy	9800.00
0005434988686	6628	Economy	9800.00
0005435464481	6628	Economy	9800.00
0005435464487	6628	Economy	9800.00
0005434988689	6628	Economy	9800.00
0005434988684	6628	Economy	9800.00
0005435464488	6628	Economy	9800.00
0005434988685	6628	Economy	9800.00
0005434988566	23630	Economy	10800.00
0005435464496	23630	Economy	9800.00
0005434988556	23630	Economy	9800.00
0005435803220	23630	Economy	9800.00
0005434988572	23630	Economy	9800.00
0005435464497	23630	Economy	9800.00
0005435803224	23630	Economy	9800.00
0005434988563	23630	Economy	9800.00
0005434988559	23630	Economy	9800.00
0005435803225	23630	Economy	9800.00
0005435803221	23630	Economy	9800.00
0005435803223	23630	Economy	9800.00
0005435803228	23630	Economy	9800.00
0005434988569	23630	Economy	9800.00
0005434988562	23630	Economy	9800.00
0005434988565	23630	Economy	9800.00
0005432382981	30463	Business	9900.00
0005432382984	30463	Business	9900.00
0005433453753	30463	Business	9900.00
0005432382977	30463	Business	9900.00
0005432382992	30463	Business	9900.00
0005432382969	30463	Business	9900.00
0005432383012	30463	Business	9900.00
0005432383002	30463	Business	9900.00
0005432383005	30463	Economy	3300.00
0005433449854	30463	Economy	3300.00
0005432382994	30463	Economy	3300.00
0005432382971	30463	Economy	3300.00
0005432383009	30463	Economy	3300.00
0005433453754	30463	Economy	3300.00
0005433449863	30463	Economy	3300.00
0005433449870	30463	Economy	3300.00
0005432383007	30463	Economy	3600.00
0005432382985	30463	Economy	3600.00
0005433449853	30463	Economy	3600.00
0005433449858	30463	Economy	3300.00
0005432382983	30463	Economy	3300.00
0005433449859	30463	Economy	3300.00
0005432382976	30463	Economy	3300.00
0005433449856	30463	Economy	3300.00
0005432383004	30463	Economy	3300.00
0005432382986	30463	Economy	3300.00
0005433449852	30463	Economy	3300.00
0005432382979	30463	Economy	3300.00
0005432382988	30463	Economy	3300.00
0005433454864	30463	Economy	3300.00
0005432382990	30463	Economy	3300.00
0005432382980	30463	Economy	3300.00
0005433449860	30463	Economy	3300.00
0005433454866	30463	Economy	3300.00
0005433449851	30463	Economy	3300.00
0005433449864	30463	Economy	3300.00
0005433449866	30463	Economy	3300.00
0005432382972	30463	Economy	3300.00
0005432383006	30463	Economy	3300.00
0005433454865	30463	Economy	3300.00
0005433449855	30463	Economy	3300.00
0005432383008	30463	Economy	3300.00
0005432382982	30463	Economy	3300.00
0005432383003	30463	Economy	3300.00
0005432382998	30463	Economy	3300.00
0005432383010	30463	Economy	3300.00
0005432382999	30463	Economy	3300.00
0005432382991	30463	Economy	3300.00
0005433449862	30463	Economy	3300.00
0005433449872	30463	Economy	3300.00
0005433449867	30463	Economy	3300.00
0005432382997	30463	Economy	3300.00
0005432382993	30463	Economy	3300.00
0005432383001	30463	Economy	3300.00
0005433449857	30463	Economy	3300.00
0005433449871	30463	Economy	3300.00
0005432382973	30463	Economy	3300.00
0005432383000	30463	Economy	3300.00
0005432383011	30463	Economy	3300.00
0005432382996	30463	Economy	3300.00
0005432382975	30463	Economy	3300.00
0005432382989	30463	Economy	3300.00
0005432382978	30463	Economy	3300.00
0005432382974	30463	Economy	3300.00
0005432382995	30463	Economy	3300.00
0005433449868	30463	Economy	3300.00
0005433454863	30463	Economy	3300.00
0005433449865	30463	Economy	3300.00
0005433449869	30463	Economy	3300.00
0005433449861	30463	Economy	3300.00
0005432382970	30463	Economy	3300.00
0005432382987	30463	Economy	3300.00
0005432382570	31298	Business	9900.00
0005432382564	31298	Business	9900.00
0005432382692	31298	Business	9900.00
0005433449732	31298	Business	9900.00
0005433449654	31298	Business	9900.00
0005432382610	31298	Business	9900.00
0005433449731	31298	Economy	3300.00
0005432382678	31298	Economy	3300.00
0005433449624	31298	Economy	3300.00
0005432382802	31298	Economy	3300.00
0005432382617	31298	Economy	3300.00
0005433449671	31298	Economy	3300.00
0005433449608	31298	Economy	3600.00
0005433449630	31298	Economy	3600.00
0005433449676	31298	Economy	3600.00
0005433449656	31298	Economy	3600.00
0005432382633	31298	Economy	3600.00
0005432382803	31298	Economy	3300.00
0005433449674	31298	Economy	3300.00
0005432382706	31298	Economy	3300.00
0005432382516	31298	Economy	3300.00
0005433449745	31298	Economy	3300.00
0005433449631	31298	Economy	3300.00
0005432382693	31298	Economy	3300.00
0005433449658	31298	Economy	3300.00
0005433449746	31298	Economy	3300.00
0005433449625	31298	Economy	3300.00
0005432382622	31298	Economy	3300.00
0005433449626	31298	Economy	3300.00
0005433449641	31298	Economy	3300.00
0005432382609	31298	Economy	3300.00
0005433449655	31298	Economy	3300.00
0005432382499	31298	Economy	3300.00
0005432382707	31298	Economy	3300.00
0005433449677	31298	Economy	3300.00
0005432382575	31298	Economy	3300.00
0005433449638	31298	Economy	3300.00
0005433449734	31298	Economy	3300.00
0005432382571	31298	Economy	3300.00
0005432382515	31298	Economy	3300.00
0005432382494	31298	Economy	3300.00
0005433449640	31298	Economy	3300.00
0005433449809	31298	Economy	3300.00
0005433449675	31298	Economy	3300.00
0005432382493	31298	Economy	3300.00
0005433449735	31298	Economy	3300.00
0005432382592	31298	Economy	3300.00
0005433453732	31298	Economy	3300.00
0005433449680	31298	Economy	3300.00
0005432382607	31298	Economy	3300.00
0005433131656	10750	Economy	17100.00
0005433131631	10750	Economy	15600.00
0005433126780	10750	Economy	15600.00
0005435299696	10750	Economy	15600.00
0005433131655	10750	Economy	15600.00
0005435304108	10750	Economy	15600.00
0005435299703	10750	Economy	15600.00
0005433129258	29724	Economy	17100.00
0005435299756	29724	Economy	15600.00
0005435299754	29724	Economy	15600.00
0005435299755	29724	Economy	15600.00
0005435302181	29724	Economy	15600.00
0005433129254	29724	Economy	15600.00
0005433126826	29724	Economy	15600.00
0005433126827	29724	Economy	15600.00
0005435299758	29724	Economy	15600.00
0005433126823	29724	Economy	15600.00
0005435302179	29724	Economy	15600.00
0005433129255	29724	Economy	15600.00
0005433129259	29724	Economy	15600.00
0005433129256	29724	Economy	15600.00
0005435302184	29724	Economy	15600.00
0005433126824	29724	Economy	15600.00
0005433126825	29724	Economy	15600.00
0005433129257	29724	Economy	15600.00
0005435299757	29724	Economy	15600.00
0005435302180	29724	Economy	15600.00
0005433126828	29724	Economy	15600.00
0005435302182	29724	Economy	15600.00
0005435302183	29724	Economy	15600.00
0005433109926	2394	Economy	17200.00
0005432264462	2394	Economy	17200.00
0005433109840	2394	Economy	17200.00
0005434287183	2394	Economy	15700.00
0005434287179	2394	Economy	15700.00
0005434287181	2394	Economy	15700.00
0005433109911	2394	Economy	15700.00
0005434287186	2394	Economy	15700.00
0005434287185	2394	Economy	15700.00
0005434287178	2394	Economy	15700.00
0005434287182	2394	Economy	15700.00
0005434287173	2394	Economy	15700.00
0005433109917	2394	Economy	15700.00
0005433109891	2394	Economy	15700.00
0005433109920	2394	Economy	15700.00
0005434287177	2394	Economy	15700.00
0005434287169	2394	Economy	15700.00
0005434287180	2394	Economy	15700.00
0005432264463	2394	Economy	15700.00
0005434287187	2394	Economy	15700.00
0005434287165	2394	Economy	15700.00
0005434287174	2394	Economy	15700.00
0005434287166	2394	Economy	15700.00
0005434287172	2394	Economy	15700.00
0005434287176	2394	Economy	15700.00
0005434287170	2394	Economy	15700.00
0005433109918	2394	Economy	15700.00
0005434287175	2394	Economy	15700.00
0005433109905	2394	Economy	15700.00
0005434287171	2394	Economy	15700.00
0005433109916	2394	Economy	15700.00
0005434287184	2394	Economy	15700.00
0005434287167	2394	Economy	15700.00
0005433109928	2394	Economy	15700.00
0005433109855	2394	Economy	15700.00
0005433109910	2394	Economy	15700.00
0005433109841	2394	Economy	15700.00
0005434287168	2394	Economy	15700.00
0005433109988	26825	Economy	17200.00
0005434286981	26825	Economy	17200.00
0005434286920	26825	Economy	17200.00
0005433109993	26825	Economy	17200.00
0005434287070	26825	Economy	15700.00
0005434286982	26825	Economy	15700.00
0005434287069	26825	Economy	15700.00
0005434286941	26825	Economy	15700.00
0005434286990	26825	Economy	15700.00
0005434286975	26825	Economy	15700.00
0005434286942	26825	Economy	15700.00
0005433109991	26825	Economy	15700.00
0005433109987	26825	Economy	15700.00
0005434286959	26825	Economy	15700.00
0005434286939	26825	Economy	15700.00
0005433109989	26825	Economy	15700.00
0005433109990	26825	Economy	15700.00
0005433109994	26825	Economy	15700.00
0005433109992	26825	Economy	15700.00
0005434287003	26825	Economy	15700.00
0005433109996	26825	Economy	15700.00
0005434286996	26825	Economy	15700.00
0005434286894	26825	Economy	15700.00
0005434287034	26825	Economy	15700.00
0005434286967	26825	Economy	15700.00
0005434286918	26825	Economy	15700.00
0005434286966	26825	Economy	15700.00
0005434287027	26825	Economy	15700.00
0005433109986	26825	Economy	15700.00
0005433109997	26825	Economy	15700.00
0005434287035	26825	Economy	15700.00
0005434286935	26825	Economy	15700.00
0005434286962	26825	Economy	15700.00
0005434286895	26825	Economy	15700.00
0005434286961	26825	Economy	15700.00
0005434287036	26825	Economy	15700.00
0005434286906	26825	Economy	15700.00
0005433109995	26825	Economy	15700.00
0005435856182	25483	Economy	25000.00
0005435856181	25483	Economy	22800.00
0005434269078	25483	Economy	22800.00
0005434272168	25483	Economy	22800.00
0005434269079	25483	Economy	22800.00
0005435856184	25483	Economy	22800.00
0005434269067	25483	Economy	22800.00
0005434269068	25483	Economy	22800.00
0005435856183	25483	Economy	22800.00
0005434269069	25483	Economy	22800.00
0005434272161	25483	Economy	22800.00
0005434272183	26632	Economy	25000.00
0005435856136	26632	Economy	25000.00
0005434272185	26632	Economy	22800.00
0005435856142	26632	Economy	22800.00
0005435856137	26632	Economy	22800.00
0005434272186	26632	Economy	22800.00
0005434273070	26632	Economy	22800.00
0005435856130	26632	Economy	22800.00
0005434273069	26632	Economy	22800.00
0005435856131	26632	Economy	22800.00
0005434272184	26632	Economy	22800.00
0005435263531	7152	Business	89800.00
0005433650567	7152	Business	89800.00
0005435263500	7152	Business	89800.00
0005435263499	7152	Business	89800.00
0005435263501	7152	Business	89800.00
0005433650541	7152	Business	89800.00
0005433650572	7152	Business	89800.00
0005433650569	7152	Business	89800.00
0005433650542	7152	Business	89800.00
0005433650536	7152	Economy	29900.00
0005433650560	7152	Economy	29900.00
0005433650566	7152	Economy	29900.00
0005433650565	7152	Economy	29900.00
0005433650571	7152	Economy	29900.00
0005435263507	7152	Economy	29900.00
0005433650535	7152	Economy	29900.00
0005433650544	7152	Economy	32900.00
0005433650528	7152	Economy	32900.00
0005433650543	7152	Economy	32900.00
0005433650550	7152	Economy	32900.00
0005433650575	7152	Economy	29900.00
0005433650534	7152	Economy	29900.00
0005433650548	7152	Economy	29900.00
0005435263513	7152	Economy	29900.00
0005433650530	7152	Economy	29900.00
0005433650570	7152	Economy	29900.00
0005433650549	7152	Economy	29900.00
0005433650558	7152	Economy	29900.00
0005433650545	7152	Economy	29900.00
0005433650533	7152	Economy	29900.00
0005433650557	7152	Economy	29900.00
0005433650538	7152	Economy	29900.00
0005433650574	7152	Economy	29900.00
0005433650546	7152	Economy	29900.00
0005433650552	7152	Economy	29900.00
0005435263534	7152	Economy	29900.00
0005433650553	7152	Economy	29900.00
0005435263516	7152	Economy	29900.00
0005435263492	7152	Economy	29900.00
0005433650568	7152	Economy	29900.00
0005433650551	7152	Economy	29900.00
0005435263504	7152	Economy	29900.00
0005433650554	7152	Economy	29900.00
0005435263496	7152	Economy	29900.00
0005433650563	7152	Economy	29900.00
0005433650527	7152	Economy	29900.00
0005435263495	7152	Economy	29900.00
0005435263483	7152	Economy	29900.00
0005433650564	7152	Economy	29900.00
0005433650562	7152	Economy	29900.00
0005435263530	7152	Economy	29900.00
0005433650561	7152	Economy	29900.00
0005435263528	7152	Economy	29900.00
0005433650556	7152	Economy	29900.00
0005433650547	7152	Economy	29900.00
0005435263527	7152	Economy	29900.00
0005435263517	7152	Economy	29900.00
0005433650555	7152	Economy	29900.00
0005433650529	7152	Economy	29900.00
0005435263503	7152	Economy	29900.00
0005433650532	7152	Economy	29900.00
0005435263529	7152	Economy	29900.00
0005433650559	7152	Economy	29900.00
0005433650573	7152	Economy	29900.00
0005433650540	7152	Economy	29900.00
0005433650531	7152	Economy	29900.00
0005435263502	7152	Economy	29900.00
0005433650539	7152	Economy	29900.00
0005435263514	7152	Economy	29900.00
0005433650537	7152	Economy	29900.00
0005433868225	4814	Economy	19400.00
0005433868227	4814	Economy	19400.00
0005433868243	4814	Economy	19400.00
0005433868255	4814	Economy	19400.00
0005433868244	4814	Economy	17600.00
0005433868259	4814	Economy	17600.00
0005433868229	4814	Economy	17600.00
0005433868249	4814	Economy	17600.00
0005433868250	4814	Economy	17600.00
0005433868233	4814	Economy	17600.00
0005433868231	4814	Economy	17600.00
0005435860440	4814	Economy	17600.00
0005433868256	4814	Economy	17600.00
0005433868239	4814	Economy	17600.00
0005433868226	4814	Economy	17600.00
0005433868241	4814	Economy	17600.00
0005433868253	4814	Economy	17600.00
0005433868242	4814	Economy	17600.00
0005433868240	4814	Economy	17600.00
0005433868223	4814	Economy	17600.00
0005433868245	4814	Economy	17600.00
0005433868222	4814	Economy	17600.00
0005433868236	4814	Economy	17600.00
0005433868257	4814	Economy	17600.00
0005433868258	4814	Economy	17600.00
0005433868246	4814	Economy	17600.00
0005433868237	4814	Economy	17600.00
0005433868261	4814	Economy	17600.00
0005433868254	4814	Economy	17600.00
0005433868221	4814	Economy	17600.00
0005433868260	4814	Economy	17600.00
0005435860441	4814	Economy	17600.00
0005433868238	4814	Economy	17600.00
0005435860438	4814	Economy	17600.00
0005433868232	4814	Economy	17600.00
0005433868224	4814	Economy	17600.00
0005433868252	4814	Economy	17600.00
0005433868235	4814	Economy	17600.00
0005433868251	4814	Economy	17600.00
0005433868228	4814	Economy	17600.00
0005433868234	4814	Economy	17600.00
0005433868247	4814	Economy	17600.00
0005433868262	4814	Economy	17600.00
0005433868230	4814	Economy	17600.00
0005433868248	4814	Economy	17600.00
0005433867860	32615	Economy	19400.00
0005433867940	32615	Economy	19400.00
0005433867969	32615	Economy	19400.00
0005433867852	32615	Economy	17600.00
0005435860474	32615	Economy	17600.00
0005433867845	32615	Economy	17600.00
0005433867805	32615	Economy	17600.00
0005433867965	32615	Economy	17600.00
0005433867871	32615	Economy	17600.00
0005433867967	32615	Economy	17600.00
0005433867811	32615	Economy	17600.00
0005435860469	32615	Economy	17600.00
0005433867770	32615	Economy	17600.00
0005435860471	32615	Economy	17600.00
0005433867876	32615	Economy	17600.00
0005433867922	32615	Economy	17600.00
0005435860468	32615	Economy	17600.00
0005433867880	32615	Economy	17600.00
0005433867828	32615	Economy	17600.00
0005433867964	32615	Economy	17600.00
0005433867932	32615	Economy	17600.00
0005435860473	32615	Economy	17600.00
0005433867782	32615	Economy	17600.00
0005433867781	32615	Economy	17600.00
0005433867740	32615	Economy	17600.00
0005433867934	32615	Economy	17600.00
0005433867926	32615	Economy	17600.00
0005433867884	32615	Economy	17600.00
0005435860472	32615	Economy	17600.00
0005433867925	32615	Economy	17600.00
0005433867909	32615	Economy	17600.00
0005433867974	32615	Economy	17600.00
0005433867812	32615	Economy	17600.00
0005433867821	32615	Economy	17600.00
0005433867923	32615	Economy	17600.00
0005433867939	32615	Economy	17600.00
0005433867899	32615	Economy	17600.00
0005433867975	32615	Economy	17600.00
0005433867844	32615	Economy	17600.00
0005435860470	32615	Economy	17600.00
0005434663341	3421	Economy	24800.00
0005435911357	3421	Economy	22600.00
0005434461637	3421	Economy	22600.00
0005434663338	3421	Economy	22600.00
0005434663340	3421	Economy	22600.00
0005434663336	3421	Economy	22600.00
0005434663346	3421	Economy	22600.00
0005435911342	3421	Economy	22600.00
0005434461635	3421	Economy	22600.00
0005434460495	3421	Economy	22600.00
0005435911344	3421	Economy	22600.00
0005435911333	3421	Economy	22600.00
0005434663345	3421	Economy	22600.00
0005434663333	3421	Economy	22600.00
0005434663335	3421	Economy	22600.00
0005435911343	3421	Economy	22600.00
0005434663339	3421	Economy	22600.00
0005434663343	3421	Economy	22600.00
0005434663344	3421	Economy	22600.00
0005434460496	3421	Economy	22600.00
0005434663342	3421	Economy	22600.00
0005434663334	3421	Economy	22600.00
0005434663337	3421	Economy	22600.00
0005434461636	3421	Economy	22600.00
0005434663208	12486	Economy	24800.00
0005434663229	12486	Economy	22600.00
0005435911417	12486	Economy	22600.00
0005435911412	12486	Economy	22600.00
0005434663184	12486	Economy	22600.00
0005434663183	12486	Economy	22600.00
0005435911418	12486	Economy	22600.00
0005434663247	12486	Economy	22600.00
0005434663280	12486	Economy	22600.00
0005435911415	12486	Economy	22600.00
0005435911411	12486	Economy	22600.00
0005434663227	12486	Economy	22600.00
0005435911413	12486	Economy	22600.00
0005435911414	12486	Economy	22600.00
0005435911410	12486	Economy	22600.00
0005434663230	12486	Economy	22600.00
0005435911416	12486	Economy	22600.00
0005434663212	12486	Economy	22600.00
0005433867812	14504	Economy	18500.00
0005433867770	14504	Economy	18500.00
0005433867781	14504	Economy	18500.00
0005433867845	14504	Economy	18500.00
0005433867782	14504	Economy	16800.00
0005433867964	14504	Economy	16800.00
0005433867880	14504	Economy	16800.00
0005433867965	14504	Economy	16800.00
0005433867909	14504	Economy	16800.00
0005433867871	14504	Economy	16800.00
0005433867899	14504	Economy	16800.00
0005433867923	14504	Economy	16800.00
0005433867821	14504	Economy	16800.00
0005435860471	14504	Economy	16800.00
0005433867975	14504	Economy	16800.00
0005433867940	14504	Economy	16800.00
0005435860468	14504	Economy	16800.00
0005433867811	14504	Economy	16800.00
0005433867805	14504	Economy	16800.00
0005433867740	14504	Economy	16800.00
0005433867967	14504	Economy	16800.00
0005435860474	14504	Economy	16800.00
0005433867926	14504	Economy	16800.00
0005435860470	14504	Economy	16800.00
0005433867932	14504	Economy	16800.00
0005433867876	14504	Economy	16800.00
0005435860473	14504	Economy	16800.00
0005433867939	14504	Economy	16800.00
0005433867969	14504	Economy	16800.00
0005433867934	14504	Economy	16800.00
0005435860469	14504	Economy	16800.00
0005433867828	14504	Economy	16800.00
0005433867925	14504	Economy	16800.00
0005433867844	14504	Economy	16800.00
0005433867852	14504	Economy	16800.00
0005433867922	14504	Economy	16800.00
0005435860472	14504	Economy	16800.00
0005433867974	14504	Economy	16800.00
0005433867884	14504	Economy	16800.00
0005433867860	14504	Economy	16800.00
0005433868181	32694	Economy	18500.00
0005433868180	32694	Economy	18500.00
0005433868210	32694	Economy	18500.00
0005433868194	32694	Economy	16800.00
0005433868186	32694	Economy	16800.00
0005433868196	32694	Economy	16800.00
0005433868189	32694	Economy	16800.00
0005433868205	32694	Economy	16800.00
0005433868191	32694	Economy	16800.00
0005433868209	32694	Economy	16800.00
0005433868200	32694	Economy	16800.00
0005433868215	32694	Economy	16800.00
0005433868213	32694	Economy	16800.00
0005433868185	32694	Economy	16800.00
0005433868220	32694	Economy	16800.00
0005433868211	32694	Economy	16800.00
0005433868184	32694	Economy	16800.00
0005433868179	32694	Economy	16800.00
0005433868206	32694	Economy	16800.00
0005433868208	32694	Economy	16800.00
0005435860432	32694	Economy	16800.00
0005433868192	32694	Economy	16800.00
0005433868207	32694	Economy	16800.00
0005433868198	32694	Economy	16800.00
0005433868204	32694	Economy	16800.00
0005433868187	32694	Economy	16800.00
0005433868193	32694	Economy	16800.00
0005433868216	32694	Economy	16800.00
0005433868182	32694	Economy	16800.00
0005433868195	32694	Economy	16800.00
0005433868197	32694	Economy	16800.00
0005433868203	32694	Economy	16800.00
0005433868214	32694	Economy	16800.00
0005433868183	32694	Economy	16800.00
0005433868202	32694	Economy	16800.00
0005433868188	32694	Economy	16800.00
0005433868212	32694	Economy	16800.00
0005435860433	32694	Economy	16800.00
0005433868218	32694	Economy	16800.00
0005433868217	32694	Economy	16800.00
0005433868201	32694	Economy	16800.00
0005433868199	32694	Economy	16800.00
0005433868219	32694	Economy	16800.00
0005433868190	32694	Economy	16800.00
0005432799050	12151	Economy	4900.00
0005432799004	12151	Economy	4900.00
0005432799075	12151	Economy	4900.00
0005432799082	12151	Economy	4900.00
0005432799126	12151	Economy	4400.00
0005432799197	12151	Economy	4400.00
0005432799148	12151	Economy	4400.00
0005432799154	12151	Economy	4400.00
0005432799083	12151	Economy	4400.00
0005432799051	12151	Economy	4400.00
0005432798972	12151	Economy	4400.00
0005432799129	12151	Economy	4400.00
0005432799063	12151	Economy	4400.00
0005432799149	12151	Economy	4400.00
0005432799110	12151	Economy	4400.00
0005432798973	12151	Economy	4400.00
0005432798975	12151	Economy	4400.00
0005432798979	12151	Economy	4400.00
0005432799128	12151	Economy	4400.00
0005432798997	12151	Economy	4400.00
0005432799101	12151	Economy	4400.00
0005432798974	12151	Economy	4400.00
0005432799091	12151	Economy	4400.00
0005432799011	12151	Economy	4400.00
0005432799150	12151	Economy	4400.00
0005432799153	12151	Economy	4400.00
0005432799127	12151	Economy	4400.00
0005432799111	12151	Economy	4400.00
0005432799074	12151	Economy	4400.00
0005432799052	12151	Economy	4400.00
0005432798998	12151	Economy	4400.00
0005432799042	12151	Economy	4400.00
0005432799287	14825	Economy	4900.00
0005432799292	14825	Economy	4900.00
0005432799297	14825	Economy	4400.00
0005432799293	14825	Economy	4400.00
0005432799275	14825	Economy	4400.00
0005432799283	14825	Economy	4400.00
0005432799285	14825	Economy	4400.00
0005432799286	14825	Economy	4400.00
0005432799290	14825	Economy	4400.00
0005432799274	14825	Economy	4400.00
0005432799288	14825	Economy	4400.00
0005432799282	14825	Economy	4400.00
0005432799295	14825	Economy	4400.00
0005432799298	14825	Economy	4400.00
0005432799284	14825	Economy	4400.00
0005432799279	14825	Economy	4400.00
0005432799289	14825	Economy	4400.00
0005432799294	14825	Economy	4400.00
0005432799301	14825	Economy	4400.00
0005432799272	14825	Economy	4400.00
0005432799273	14825	Economy	4400.00
0005432799271	14825	Economy	4400.00
0005432799280	14825	Economy	4400.00
0005432799296	14825	Economy	4400.00
0005432799300	14825	Economy	4400.00
0005432799299	14825	Economy	4400.00
0005432799276	14825	Economy	4400.00
0005432799277	14825	Economy	4400.00
0005432799291	14825	Economy	4400.00
0005432799278	14825	Economy	4400.00
0005432799281	14825	Economy	4400.00
0005434407432	7042	Business	49100.00
0005435310863	7042	Business	49100.00
0005434407422	7042	Business	49100.00
0005434407435	7042	Business	49100.00
0005434299433	7042	Business	49100.00
0005434407476	7042	Business	49100.00
0005434407416	7042	Business	49100.00
0005435310889	7042	Business	49100.00
0005435310849	7042	Business	49100.00
0005434299434	7042	Business	49100.00
0005434299447	7042	Economy	16400.00
0005434407436	7042	Economy	16400.00
0005432153901	7042	Economy	16400.00
0005434407473	7042	Economy	16400.00
0005434299451	7042	Economy	16400.00
0005434407440	7042	Economy	16400.00
0005434407447	7042	Economy	16400.00
0005434407429	7042	Economy	16400.00
0005434407469	7042	Economy	16400.00
0005434299445	7042	Economy	16400.00
0005435310885	7042	Economy	16400.00
0005434407450	7042	Economy	16400.00
0005434407431	7042	Economy	16400.00
0005434407471	7042	Economy	16400.00
0005435293115	7042	Economy	16400.00
0005434299440	7042	Economy	16400.00
0005434299432	7042	Economy	16400.00
0005435293095	7042	Economy	16400.00
0005434299453	7042	Economy	16400.00
0005434407437	7042	Economy	16400.00
0005434299441	7042	Economy	16400.00
0005434407442	7042	Economy	16400.00
0005432108237	7042	Economy	16400.00
0005434407458	7042	Economy	16400.00
0005435310847	7042	Economy	16400.00
0005434407424	7042	Economy	16400.00
0005434299448	7042	Economy	16400.00
0005434407433	7042	Economy	16400.00
0005434407460	7042	Economy	16400.00
0005432153904	7042	Economy	16400.00
0005434407472	7042	Economy	16400.00
0005435310884	7042	Economy	16400.00
0005434299439	7042	Economy	16400.00
0005434299452	7042	Economy	16400.00
0005434407456	7042	Economy	16400.00
0005434407452	7042	Economy	16400.00
0005434407475	7042	Economy	16400.00
0005434407451	7042	Economy	18000.00
0005435293098	7042	Economy	18000.00
0005434299442	7042	Economy	18000.00
0005434407443	7042	Economy	18000.00
0005434407468	7042	Economy	18000.00
0005434299455	7042	Economy	18000.00
0005435310869	7042	Economy	16400.00
0005434407434	7042	Economy	16400.00
0005434407454	7042	Economy	16400.00
0005434299443	7042	Economy	16400.00
0005434407455	7042	Economy	16400.00
0005434407427	7042	Economy	16400.00
0005434407445	7042	Economy	16400.00
0005434407441	7042	Economy	16400.00
0005434407449	7042	Economy	16400.00
0005432153899	7042	Economy	16400.00
0005434299444	7042	Economy	16400.00
0005432153902	7042	Economy	16400.00
0005434407439	7042	Economy	16400.00
0005434407463	7042	Economy	16400.00
0005435310862	7042	Economy	16400.00
0005434407457	7042	Economy	16400.00
0005434407446	7042	Economy	16400.00
0005434407461	7042	Economy	16400.00
0005434299454	7042	Economy	16400.00
0005434407425	7042	Economy	16400.00
0005434407421	7042	Economy	16400.00
0005434407474	7042	Economy	16400.00
0005435293080	7042	Economy	16400.00
0005434407464	7042	Economy	16400.00
0005434407467	7042	Economy	16400.00
0005434407462	7042	Economy	16400.00
0005434407466	7042	Economy	16400.00
0005434299438	7042	Economy	16400.00
0005434299436	7042	Economy	16400.00
0005434407430	7042	Economy	16400.00
0005435293084	7042	Economy	16400.00
0005434407448	7042	Economy	16400.00
0005434407459	7042	Economy	16400.00
0005434407419	7042	Economy	16400.00
0005434299435	7042	Economy	16400.00
0005434407423	7042	Economy	16400.00
0005434299437	7042	Economy	16400.00
0005434407470	7042	Economy	16400.00
0005434299446	7042	Economy	16400.00
0005435293097	7042	Economy	16400.00
0005435293116	7042	Economy	16400.00
0005434407413	7042	Economy	16400.00
0005434407418	7042	Economy	16400.00
0005434407426	7042	Economy	16400.00
0005434407414	7042	Economy	16400.00
0005435293103	7042	Economy	16400.00
0005432153905	7042	Economy	16400.00
0005434299449	7042	Economy	16400.00
0005434407415	7042	Economy	16400.00
0005434407465	7042	Economy	16400.00
0005432153900	7042	Economy	16400.00
0005434407417	7042	Economy	16400.00
0005434407444	7042	Economy	16400.00
0005435293083	7042	Economy	16400.00
0005432108238	7042	Economy	16400.00
0005435310894	7042	Economy	16400.00
0005434407453	7042	Economy	16400.00
0005435293079	7042	Economy	16400.00
0005435310837	7042	Economy	16400.00
0005432153903	7042	Economy	16400.00
0005434299450	7042	Economy	16400.00
0005434407428	7042	Economy	16400.00
0005434407420	7042	Economy	16400.00
0005434407438	7042	Economy	16400.00
0005435310848	7042	Economy	16400.00
0005434299159	26903	Business	49100.00
0005434299305	26903	Business	49100.00
0005435293190	26903	Business	49100.00
0005434406953	26903	Business	49100.00
0005435311012	26903	Business	49100.00
0005434407017	26903	Business	49100.00
0005434406818	26903	Business	49100.00
0005434299266	26903	Business	49100.00
0005434406820	26903	Business	49100.00
0005434299208	26903	Economy	16400.00
0005435293188	26903	Economy	16400.00
0005435311007	26903	Economy	16400.00
0005434299195	26903	Economy	16400.00
0005434406931	26903	Economy	16400.00
0005435311002	26903	Economy	16400.00
0005434406982	26903	Economy	16400.00
0005432058359	26903	Economy	16400.00
0005434406848	26903	Economy	16400.00
0005434406851	26903	Economy	16400.00
0005434406706	26903	Economy	16400.00
0005434406833	26903	Economy	16400.00
0005434299363	26903	Economy	16400.00
0005434406767	26903	Economy	16400.00
0005434299194	26903	Economy	16400.00
0005434407078	26903	Economy	16400.00
0005434406806	26903	Economy	16400.00
0005435311009	26903	Economy	16400.00
0005435293189	26903	Economy	16400.00
0005435311000	26903	Economy	16400.00
0005435293183	26903	Economy	16400.00
0005435293193	26903	Economy	16400.00
0005434299293	26903	Economy	16400.00
0005435310998	26903	Economy	16400.00
0005434406768	26903	Economy	16400.00
0005434406971	26903	Economy	16400.00
0005434406785	26903	Economy	16400.00
0005432058358	26903	Economy	16400.00
0005434406803	26903	Economy	16400.00
0005434406749	26903	Economy	16400.00
0005434406817	26903	Economy	16400.00
0005435311010	26903	Economy	16400.00
0005432058357	26903	Economy	16400.00
0005434299246	26903	Economy	16400.00
0005434406787	26903	Economy	16400.00
0005434406889	26903	Economy	18000.00
0005434406651	26903	Economy	18000.00
0005434407057	26903	Economy	18000.00
0005434406756	26903	Economy	18000.00
0005435310999	26903	Economy	18000.00
0005434406954	26903	Economy	16400.00
0005435311014	26903	Economy	16400.00
0005435311005	26903	Economy	16400.00
0005434406935	26903	Economy	16400.00
0005434406930	26903	Economy	16400.00
0005434299301	26903	Economy	16400.00
0005434407040	26903	Economy	16400.00
0005434406766	26903	Economy	16400.00
0005434299300	26903	Economy	16400.00
0005434406816	26903	Economy	16400.00
0005434406804	26903	Economy	16400.00
0005435311011	26903	Economy	16400.00
0005434406755	26903	Economy	16400.00
0005435293191	26903	Economy	16400.00
0005435293194	26903	Economy	16400.00
0005434406642	26903	Economy	16400.00
0005434406869	26903	Economy	16400.00
0005435311013	26903	Economy	16400.00
0005434299245	26903	Economy	16400.00
0005435310997	26903	Economy	16400.00
0005434406802	26903	Economy	16400.00
0005434299172	26903	Economy	16400.00
0005435293182	26903	Economy	16400.00
0005434406948	26903	Economy	16400.00
0005434406782	26903	Economy	16400.00
0005434406737	26903	Economy	16400.00
0005434406868	26903	Economy	16400.00
0005434406949	26903	Economy	16400.00
0005434299265	26903	Economy	16400.00
0005435311008	26903	Economy	16400.00
0005435311001	26903	Economy	16400.00
0005434406819	26903	Economy	16400.00
0005435311003	26903	Economy	16400.00
0005434406805	26903	Economy	16400.00
0005435293192	26903	Economy	16400.00
0005434406932	26903	Economy	16400.00
0005434406852	26903	Economy	16400.00
0005434406866	26903	Economy	16400.00
0005435293187	26903	Economy	16400.00
0005434406877	26903	Economy	16400.00
0005434407047	26903	Economy	16400.00
0005434406685	26903	Economy	16400.00
0005435311006	26903	Economy	16400.00
0005435293185	26903	Economy	16400.00
0005434406757	26903	Economy	16400.00
0005434406764	26903	Economy	16400.00
0005434299259	26903	Economy	16400.00
0005434407067	26903	Economy	16400.00
0005435293186	26903	Economy	16400.00
0005434299294	26903	Economy	16400.00
0005434299329	26903	Economy	16400.00
0005434407018	26903	Economy	16400.00
0005435293184	26903	Economy	16400.00
0005434299302	26903	Economy	16400.00
0005435311004	26903	Economy	16400.00
0005434407066	26903	Economy	16400.00
0005435310996	26903	Economy	16400.00
0005432604165	6477	Economy	16500.00
0005432604155	6477	Economy	16500.00
0005432604139	6477	Economy	16500.00
0005434512093	6477	Economy	15000.00
0005432604146	6477	Economy	15000.00
0005432604130	6477	Economy	15000.00
0005432604135	6477	Economy	15000.00
0005432604153	6477	Economy	15000.00
0005434512091	6477	Economy	15000.00
0005432604156	6477	Economy	15000.00
0005432604148	6477	Economy	15000.00
0005432604137	6477	Economy	15000.00
0005432604168	6477	Economy	15000.00
0005432604151	6477	Economy	15000.00
0005432604167	6477	Economy	15000.00
0005432604154	6477	Economy	15000.00
0005432604149	6477	Economy	15000.00
0005432604145	6477	Economy	15000.00
0005432604132	6477	Economy	15000.00
0005434512092	6477	Economy	15000.00
0005432604150	6477	Economy	15000.00
0005432604152	6477	Economy	15000.00
0005432604128	6477	Economy	15000.00
0005432604160	6477	Economy	15000.00
0005432604159	6477	Economy	15000.00
0005432604138	6477	Economy	15000.00
0005432604147	6477	Economy	15000.00
0005432604163	6477	Economy	15000.00
0005432604143	6477	Economy	15000.00
0005432604161	6477	Economy	15000.00
0005432604158	6477	Economy	15000.00
0005432604166	6477	Economy	15000.00
0005432604142	6477	Economy	15000.00
0005432604141	6477	Economy	15000.00
0005432604129	6477	Economy	15000.00
0005434512090	6477	Economy	15000.00
0005432604134	6477	Economy	15000.00
0005432604133	6477	Economy	15000.00
0005432604131	6477	Economy	15000.00
0005432604164	6477	Economy	15000.00
0005432604162	6477	Economy	15000.00
0005432604157	6477	Economy	15000.00
0005435218100	6477	Economy	15000.00
0005432604140	6477	Economy	15000.00
0005432604136	6477	Economy	15000.00
0005432604144	6477	Economy	15000.00
0005435221513	21382	Economy	16500.00
0005432603939	21382	Economy	15000.00
0005432603890	21382	Economy	15000.00
0005435221050	21382	Economy	15000.00
0005432603728	21382	Economy	15000.00
0005432603767	21382	Economy	15000.00
0005432603717	21382	Economy	15000.00
0005434512027	21382	Economy	15000.00
0005432603889	21382	Economy	15000.00
0005432603664	21382	Economy	15000.00
0005432603732	21382	Economy	15000.00
0005435221512	21382	Economy	15000.00
0005432603912	21382	Economy	15000.00
0005434512063	21382	Economy	15000.00
0005432603752	21382	Economy	15000.00
0005432603789	21382	Economy	15000.00
0005432603891	21382	Economy	15000.00
0005432603841	21382	Economy	15000.00
0005432603733	21382	Economy	15000.00
0005432603686	21382	Economy	15000.00
0005435221051	21382	Economy	15000.00
0005432603721	21382	Economy	15000.00
0005432603731	21382	Economy	15000.00
0005432603716	21382	Economy	15000.00
0005432603774	21382	Economy	15000.00
0005432603781	21382	Economy	15000.00
0005432603722	21382	Economy	15000.00
0005432603646	21382	Economy	15000.00
0005432603718	21382	Economy	15000.00
0005432603773	21382	Economy	15000.00
0005432603817	21382	Economy	15000.00
0005432603818	21382	Economy	15000.00
0005435221511	21382	Economy	15000.00
0005432603911	21382	Economy	15000.00
0005434512074	21382	Economy	15000.00
0005434512034	21382	Economy	15000.00
0005434906468	14996	Business	18900.00
0005434906529	14996	Business	18900.00
0005433251323	14996	Business	18900.00
0005434906365	14996	Business	18900.00
0005434906451	14996	Business	18900.00
0005434906503	14996	Business	18900.00
0005433251331	14996	Business	18900.00
0005433251307	14996	Business	18900.00
0005433251337	14996	Business	18900.00
0005433251327	14996	Business	18900.00
0005434906604	14996	Economy	6300.00
0005433251329	14996	Economy	6300.00
0005434906372	14996	Economy	6300.00
0005434906614	14996	Economy	6300.00
0005434906540	14996	Economy	6300.00
0005433251328	14996	Economy	6300.00
0005433251334	14996	Economy	6300.00
0005433251315	14996	Economy	6300.00
0005434906666	14996	Economy	6900.00
0005434906554	14996	Economy	6900.00
0005433251311	14996	Economy	6900.00
0005434906509	14996	Economy	6300.00
0005433251330	14996	Economy	6300.00
0005434906371	14996	Economy	6300.00
0005433251321	14996	Economy	6300.00
0005433251314	14996	Economy	6300.00
0005434906606	14996	Economy	6300.00
0005434906469	14996	Economy	6300.00
0005433251322	14996	Economy	6300.00
0005433251313	14996	Economy	6300.00
0005434906465	14996	Economy	6300.00
0005434906797	14996	Economy	6300.00
0005434906439	14996	Economy	6300.00
0005434906563	14996	Economy	6300.00
0005433251312	14996	Economy	6300.00
0005433251332	14996	Economy	6300.00
0005433251326	14996	Economy	6300.00
0005433251308	14996	Economy	6300.00
0005434906472	14996	Economy	6300.00
0005433251333	14996	Economy	6300.00
0005433251310	14996	Economy	6300.00
0005434906510	14996	Economy	6300.00
0005433251319	14996	Economy	6300.00
0005434906377	14996	Economy	6300.00
0005433251309	14996	Economy	6300.00
0005434906784	14996	Economy	6300.00
0005434906384	14996	Economy	6300.00
0005434906440	14996	Economy	6300.00
0005434906592	14996	Economy	6300.00
0005434906467	14996	Economy	6300.00
0005434906833	14996	Economy	6300.00
0005433251324	14996	Economy	6300.00
0005433251317	14996	Economy	6300.00
0005433251335	14996	Economy	6300.00
0005433251336	14996	Economy	6300.00
0005433251325	14996	Economy	6300.00
0005433251320	14996	Economy	6300.00
0005434906450	14996	Economy	6300.00
0005434906783	14996	Economy	6300.00
0005434906382	14996	Economy	6300.00
0005434906383	14996	Economy	6300.00
0005434906491	14996	Economy	6300.00
0005434906612	14996	Economy	6300.00
0005433251316	14996	Economy	6300.00
0005434906396	14996	Economy	6300.00
0005433251306	14996	Economy	6300.00
0005434906466	14996	Economy	6300.00
0005434906471	14996	Economy	6300.00
0005433251318	14996	Economy	6300.00
0005434906995	25839	Business	18900.00
0005434906996	25839	Business	18900.00
0005434906972	25839	Business	18900.00
0005433251215	25839	Business	18900.00
0005434906997	25839	Business	18900.00
0005434907005	25839	Business	18900.00
0005434907001	25839	Business	18900.00
0005433251075	25839	Business	18900.00
0005434906967	25839	Business	18900.00
0005434907000	25839	Business	18900.00
0005434906971	25839	Business	18900.00
0005433251054	25839	Economy	6300.00
0005433251021	25839	Economy	6300.00
0005433251160	25839	Economy	6300.00
0005434906983	25839	Economy	6300.00
0005434906986	25839	Economy	6300.00
0005434907009	25839	Economy	6300.00
0005434906973	25839	Economy	6300.00
0005433250998	25839	Economy	6300.00
0005433251062	25839	Economy	6300.00
0005434906978	25839	Economy	6300.00
0005434906969	25839	Economy	6900.00
0005434906994	25839	Economy	6900.00
0005434906961	25839	Economy	6900.00
0005434906955	25839	Economy	6900.00
0005433250990	25839	Economy	6900.00
0005433251250	25839	Economy	6300.00
0005434907002	25839	Economy	6300.00
0005433251051	25839	Economy	6300.00
0005433250978	25839	Economy	6300.00
0005434906954	25839	Economy	6300.00
0005434906993	25839	Economy	6300.00
0005434907010	25839	Economy	6300.00
0005434906977	25839	Economy	6300.00
0005434906989	25839	Economy	6300.00
0005433251044	25839	Economy	6300.00
0005433251020	25839	Economy	6300.00
0005434906988	25839	Economy	6300.00
0005433251007	25839	Economy	6300.00
0005433250976	25839	Economy	6300.00
0005434907004	25839	Economy	6300.00
0005434906991	25839	Economy	6300.00
0005433251130	25839	Economy	6300.00
0005433250977	25839	Economy	6300.00
0005433251238	25839	Economy	6300.00
0005433251039	25839	Economy	6300.00
0005434906970	25839	Economy	6300.00
0005434906980	25839	Economy	6300.00
0005434906968	25839	Economy	6300.00
0005434906962	25839	Economy	6300.00
0005433251076	25839	Economy	6300.00
0005433251000	25839	Economy	6300.00
0005434906982	25839	Economy	6300.00
0005433251045	25839	Economy	6300.00
0005434906981	25839	Economy	6300.00
0005434906960	25839	Economy	6300.00
0005433251008	25839	Economy	6300.00
0005434906958	25839	Economy	6300.00
0005433250991	25839	Economy	6300.00
0005434906974	25839	Economy	6300.00
0005434907008	25839	Economy	6300.00
0005434906964	25839	Economy	6300.00
0005434906992	25839	Economy	6300.00
0005434906984	25839	Economy	6300.00
0005434906975	25839	Economy	6300.00
0005433251072	25839	Economy	6300.00
0005433251158	25839	Economy	6300.00
0005433251050	25839	Economy	6300.00
0005434907006	25839	Economy	6300.00
0005434906959	25839	Economy	6300.00
0005434906965	25839	Economy	6300.00
0005434906979	25839	Economy	6300.00
0005434906951	25839	Economy	6300.00
0005434907007	25839	Economy	6300.00
0005433251001	25839	Economy	6300.00
0005433250944	25839	Economy	6300.00
0005434906990	25839	Economy	6300.00
0005434906963	25839	Economy	6300.00
0005433251129	25839	Economy	6300.00
0005434906976	25839	Economy	6300.00
0005434906987	25839	Economy	6300.00
0005433251014	25839	Economy	6300.00
0005434906953	25839	Economy	6300.00
0005434906966	25839	Economy	6300.00
0005434906985	25839	Economy	6300.00
0005434906957	25839	Economy	6300.00
0005434906952	25839	Economy	6300.00
0005434906956	25839	Economy	6300.00
0005434906999	25839	Economy	6300.00
0005433250999	25839	Economy	6300.00
0005434907003	25839	Economy	6300.00
0005434906998	25839	Economy	6300.00
0005433008412	14156	Business	52300.00
0005433008408	14156	Business	52300.00
0005433008388	14156	Business	52300.00
0005433008391	14156	Business	52300.00
0005433008406	14156	Business	52300.00
0005433008402	14156	Business	52300.00
0005433008418	14156	Business	52300.00
0005433008379	14156	Business	52300.00
0005433008404	14156	Business	52300.00
0005433008416	14156	Economy	17400.00
0005433008422	14156	Economy	17400.00
0005433810490	14156	Economy	17400.00
0005433008383	14156	Economy	17400.00
0005433008385	14156	Economy	17400.00
0005433008410	14156	Economy	19200.00
0005433008424	14156	Economy	19200.00
0005433008423	14156	Economy	17400.00
0005433008396	14156	Economy	17400.00
0005433008400	14156	Economy	17400.00
0005433008405	14156	Economy	17400.00
0005433008411	14156	Economy	17400.00
0005433008380	14156	Economy	17400.00
0005433008415	14156	Economy	17400.00
0005433008407	14156	Economy	17400.00
0005433008384	14156	Economy	17400.00
0005433008419	14156	Economy	17400.00
0005433008401	14156	Economy	17400.00
0005433008413	14156	Economy	17400.00
0005433008421	14156	Economy	17400.00
0005433008393	14156	Economy	17400.00
0005433008390	14156	Economy	17400.00
0005433008409	14156	Economy	17400.00
0005433008382	14156	Economy	17400.00
0005433008420	14156	Economy	17400.00
0005433008387	14156	Economy	17400.00
0005433008381	14156	Economy	17400.00
0005433008414	14156	Economy	17400.00
0005433008395	14156	Economy	17400.00
0005433008417	14156	Economy	17400.00
0005433008397	14156	Economy	17400.00
0005433008389	14156	Economy	17400.00
0005433008399	14156	Economy	17400.00
0005433008403	14156	Economy	17400.00
0005433008398	14156	Economy	17400.00
0005433008386	14156	Economy	17400.00
0005433008392	14156	Economy	17400.00
0005433008394	14156	Economy	17400.00
0005433007953	22820	Business	52300.00
0005433007970	22820	Business	52300.00
0005433007972	22820	Business	52300.00
0005433008085	22820	Business	52300.00
0005433007930	22820	Business	52300.00
0005433007917	22820	Business	52300.00
0005433008027	22820	Economy	17400.00
0005433007971	22820	Economy	17400.00
0005433810519	22820	Economy	17400.00
0005433007969	22820	Economy	17400.00
0005433007931	22820	Economy	17400.00
0005433008028	22820	Economy	17400.00
0005433007980	22820	Economy	17400.00
0005433008073	22820	Economy	17400.00
0005433007979	22820	Economy	17400.00
0005433008212	22820	Economy	17400.00
0005433008109	22820	Economy	17400.00
0005433007925	22820	Economy	17400.00
0005433008063	22820	Economy	17400.00
0005433008116	22820	Economy	17400.00
0005433008016	22820	Economy	17400.00
0005433007879	22820	Economy	17400.00
0005433007893	22820	Economy	17400.00
0005433810518	22820	Economy	17400.00
0005433007923	22820	Economy	17400.00
0005433008017	22820	Economy	17400.00
0005433007943	22820	Economy	17400.00
0005433007958	22820	Economy	17400.00
0005433007890	22820	Economy	17400.00
0005433007924	22820	Economy	17400.00
0005433008038	22820	Economy	17400.00
0005433007944	22820	Economy	17400.00
0005433007959	22820	Economy	17400.00
0005433008121	22820	Economy	17400.00
0005433007973	22820	Economy	17400.00
0005433810520	22820	Economy	17400.00
0005433008074	22820	Economy	17400.00
0005433007878	22820	Economy	17400.00
0005433007841	22820	Economy	17400.00
0005434925416	14951	Business	22900.00
0005434925378	14951	Business	22900.00
0005434925465	14951	Business	22900.00
0005434925275	14951	Business	22900.00
0005434925326	14951	Business	22900.00
0005434925490	14951	Economy	7600.00
0005434925503	14951	Economy	7600.00
0005434925427	14951	Economy	7600.00
0005434925285	14951	Economy	7600.00
0005434925332	14951	Economy	8400.00
0005434925274	14951	Economy	7600.00
0005434925390	14951	Economy	7600.00
0005434925382	14951	Economy	7600.00
0005434925379	14951	Economy	7600.00
0005434925339	14951	Economy	7600.00
0005434925325	14951	Economy	7600.00
0005434925522	14951	Economy	7600.00
0005434925296	14951	Economy	7600.00
0005434925286	14951	Economy	7600.00
0005434925439	14951	Economy	7600.00
0005434925280	14951	Economy	7600.00
0005434925377	14951	Economy	7600.00
0005434925491	14951	Economy	7600.00
0005434925347	14951	Economy	7600.00
0005434925283	14951	Economy	7600.00
0005434925380	14951	Economy	7600.00
0005434925489	14951	Economy	7600.00
0005434925385	14951	Economy	7600.00
0005434925426	14951	Economy	7600.00
0005434925362	14951	Economy	7600.00
0005434925349	14951	Economy	7600.00
0005434925337	14951	Economy	7600.00
0005434925338	14951	Economy	7600.00
0005434925470	14951	Economy	7600.00
0005434925389	14951	Economy	7600.00
0005434925348	14951	Economy	7600.00
0005434925643	20530	Business	22900.00
0005434925637	20530	Business	22900.00
0005434925642	20530	Business	22900.00
0005434925626	20530	Business	22900.00
0005434925641	20530	Economy	7600.00
0005434925623	20530	Economy	7600.00
0005434925616	20530	Economy	7600.00
0005434925636	20530	Economy	7600.00
0005434925615	20530	Economy	7600.00
0005434925612	20530	Economy	7600.00
0005434925624	20530	Economy	7600.00
0005434925639	20530	Economy	7600.00
0005434925631	20530	Economy	7600.00
0005434925608	20530	Economy	7600.00
0005434925617	20530	Economy	7600.00
0005434925619	20530	Economy	7600.00
0005434925651	20530	Economy	7600.00
0005434925649	20530	Economy	7600.00
0005434925621	20530	Economy	7600.00
0005434925620	20530	Economy	7600.00
0005434925638	20530	Economy	7600.00
0005434925648	20530	Economy	7600.00
0005434925627	20530	Economy	7600.00
0005434925633	20530	Economy	7600.00
0005434925645	20530	Economy	7600.00
0005434925618	20530	Economy	7600.00
0005434925646	20530	Economy	7600.00
0005434925632	20530	Economy	7600.00
0005434925614	20530	Economy	7600.00
0005434925647	20530	Economy	7600.00
0005434925635	20530	Economy	7600.00
0005434925650	20530	Economy	7600.00
0005434925609	20530	Economy	7600.00
0005434925630	20530	Economy	7600.00
0005434925610	20530	Economy	7600.00
0005434925629	20530	Economy	7600.00
0005434925634	20530	Economy	7600.00
0005434925644	20530	Economy	7600.00
0005434925611	20530	Economy	7600.00
0005434925628	20530	Economy	7600.00
0005434925607	20530	Economy	7600.00
0005434925622	20530	Economy	7600.00
0005434925625	20530	Economy	7600.00
0005434925640	20530	Economy	7600.00
0005434925613	20530	Economy	7600.00
0005435487733	15822	Economy	8900.00
0005435487719	15822	Economy	8900.00
0005435487723	15822	Economy	8900.00
0005435487725	15822	Economy	8900.00
0005435999025	15822	Economy	8100.00
0005435487724	15822	Economy	8100.00
0005435487740	15822	Economy	8100.00
0005435999040	15822	Economy	8100.00
0005435487739	15822	Economy	8100.00
0005435487730	15822	Economy	8100.00
0005435487738	15822	Economy	8100.00
0005435487734	15822	Economy	8100.00
0005435999042	15822	Economy	8100.00
0005435998990	15822	Economy	8100.00
0005435487737	15822	Economy	8100.00
0005435999014	15822	Economy	8100.00
0005435999026	15822	Economy	8100.00
0005435487735	15822	Economy	8100.00
0005435487728	15822	Economy	8100.00
0005435487731	15822	Economy	8100.00
0005435487732	15822	Economy	8100.00
0005435487727	15822	Economy	8100.00
0005435998968	15822	Economy	8100.00
0005435998975	15822	Economy	8100.00
0005435487726	15822	Economy	8100.00
0005435998999	15822	Economy	8100.00
0005435487736	15822	Economy	8100.00
0005435998989	15822	Economy	8100.00
0005435487722	15822	Economy	8100.00
0005435487720	15822	Economy	8100.00
0005435487721	15822	Economy	8100.00
0005435999035	15822	Economy	8100.00
0005435487729	15822	Economy	8100.00
0005435487542	19679	Economy	8900.00
0005435999146	19679	Economy	8900.00
0005435999170	19679	Economy	8900.00
0005435999155	19679	Economy	8900.00
0005435999157	19679	Economy	8100.00
0005435999148	19679	Economy	8100.00
0005435999156	19679	Economy	8100.00
0005435999161	19679	Economy	8100.00
0005435999169	19679	Economy	8100.00
0005435999150	19679	Economy	8100.00
0005435999166	19679	Economy	8100.00
0005435999158	19679	Economy	8100.00
0005435999165	19679	Economy	8100.00
0005435999163	19679	Economy	8100.00
0005435487507	19679	Economy	8100.00
0005435487532	19679	Economy	8100.00
0005435999151	19679	Economy	8100.00
0005435487506	19679	Economy	8100.00
0005435999168	19679	Economy	8100.00
0005435999149	19679	Economy	8100.00
0005435999162	19679	Economy	8100.00
0005435487511	19679	Economy	8100.00
0005435999144	19679	Economy	8100.00
0005435999172	19679	Economy	8100.00
0005435487541	19679	Economy	8100.00
0005435999171	19679	Economy	8100.00
0005435999164	19679	Economy	8100.00
0005435999159	19679	Economy	8100.00
0005435487515	19679	Economy	8100.00
0005435999153	19679	Economy	8100.00
0005435999160	19679	Economy	8100.00
0005435999167	19679	Economy	8100.00
0005435999145	19679	Economy	8100.00
0005435999152	19679	Economy	8100.00
0005435999147	19679	Economy	8100.00
0005435999154	19679	Economy	8100.00
0005435472588	6015	Business	199300.00
0005432537034	6015	Business	199300.00
0005435839318	6015	Business	199300.00
0005432537033	6015	Business	199300.00
0005435472594	6015	Business	199300.00
0005435472581	6015	Business	199300.00
0005435472553	6015	Business	199300.00
0005432537035	6015	Business	199300.00
0005435839316	6015	Business	199300.00
0005435472595	6015	Economy	66400.00
0005432660809	6015	Business	199300.00
0005435839325	6015	Economy	66400.00
0005435839311	6015	Economy	66400.00
0005435472635	6015	Economy	66400.00
0005435839320	6015	Economy	66400.00
0005435839303	6015	Economy	66400.00
0005435839308	6015	Economy	73100.00
0005435472634	6015	Economy	66400.00
0005435839323	6015	Economy	66400.00
0005432658582	6015	Economy	66400.00
0005435472601	6015	Economy	66400.00
0005435472632	6015	Economy	66400.00
0005435839304	6015	Economy	66400.00
0005435839321	6015	Economy	66400.00
0005435839310	6015	Economy	66400.00
0005435472579	6015	Economy	66400.00
0005435472578	6015	Economy	66400.00
0005435472552	6015	Economy	66400.00
0005435472619	6015	Economy	66400.00
0005432142235	6015	Economy	66400.00
0005435839314	6015	Economy	66400.00
0005435472543	6015	Economy	66400.00
0005435472587	6015	Economy	66400.00
0005435839306	6015	Economy	66400.00
0005435472565	6015	Economy	66400.00
0005432659698	6015	Economy	66400.00
0005435839312	6015	Economy	66400.00
0005435472623	6015	Economy	66400.00
0005432660810	6015	Economy	66400.00
0005435839315	6015	Economy	66400.00
0005435839317	6015	Economy	66400.00
0005435472542	6015	Economy	66400.00
0005435472583	6015	Economy	66400.00
0005432659697	6015	Economy	66400.00
0005432142237	6015	Economy	66400.00
0005432142236	6015	Economy	66400.00
0005435839328	6015	Economy	66400.00
0005435839327	6015	Economy	66400.00
0005435839319	6015	Economy	66400.00
0005435472557	6015	Economy	66400.00
0005435839329	6015	Economy	66400.00
0005435839331	6015	Economy	66400.00
0005435839330	6015	Economy	66400.00
0005435472602	6015	Economy	66400.00
0005435472589	6015	Economy	66400.00
0005435839326	6015	Economy	66400.00
0005435839307	6015	Economy	66400.00
0005432660808	6015	Economy	66400.00
0005435839309	6015	Economy	66400.00
0005435839313	6015	Economy	66400.00
0005435839324	6015	Economy	66400.00
0005435472584	6015	Economy	66400.00
0005435839322	6015	Economy	66400.00
0005435839305	6015	Economy	66400.00
0005435472730	18068	Business	199300.00
0005435472726	18068	Business	199300.00
0005435838997	18068	Business	199300.00
0005435472718	18068	Business	199300.00
0005435838993	18068	Business	199300.00
0005435839050	18068	Business	199300.00
0005435839204	18068	Business	199300.00
0005435839039	18068	Business	199300.00
0005435839051	18068	Business	199300.00
0005435839080	18068	Business	199300.00
0005435839120	18068	Business	199300.00
0005435839076	18068	Economy	66400.00
0005435472720	18068	Economy	66400.00
0005435839034	18068	Economy	66400.00
0005435472717	18068	Economy	66400.00
0005435472716	18068	Economy	66400.00
0005435839064	18068	Economy	73100.00
0005435472723	18068	Economy	66400.00
0005432660787	18068	Economy	66400.00
0005435472728	18068	Economy	66400.00
0005435839072	18068	Economy	66400.00
0005435839112	18068	Economy	66400.00
0005435472725	18068	Economy	66400.00
0005435839049	18068	Economy	66400.00
0005435472721	18068	Economy	66400.00
0005435472727	18068	Economy	66400.00
0005435472719	18068	Economy	66400.00
0005435839198	18068	Economy	66400.00
0005432667419	18068	Economy	66400.00
0005435472722	18068	Economy	66400.00
0005435472729	18068	Economy	66400.00
0005435839098	18068	Economy	66400.00
0005432537049	18068	Economy	66400.00
0005435472731	18068	Economy	66400.00
0005435838990	18068	Economy	66400.00
0005435472715	18068	Economy	66400.00
0005435839183	18068	Economy	66400.00
0005435839053	18068	Economy	66400.00
0005432537050	18068	Economy	66400.00
0005435839075	18068	Economy	66400.00
0005435472724	18068	Economy	66400.00
0005435839071	18068	Economy	66400.00
0005435472714	18068	Economy	66400.00
0005432537048	18068	Economy	66400.00
0005432660786	18068	Economy	66400.00
0005435839054	18068	Economy	66400.00
0005435103879	23049	Business	15700.00
0005433284984	23049	Business	15700.00
0005433284982	23049	Business	15700.00
0005433284861	23049	Business	15700.00
0005433284869	23049	Economy	5200.00
0005435103884	23049	Economy	5200.00
0005433284802	23049	Economy	5200.00
0005435103880	23049	Economy	5200.00
0005433284870	23049	Economy	5200.00
0005435103885	23049	Economy	5200.00
0005433284952	23049	Economy	5200.00
0005433284974	23049	Economy	5200.00
0005433284987	23049	Economy	5200.00
0005433284897	23049	Economy	5200.00
0005433284809	23049	Economy	5200.00
0005433284988	23049	Economy	5200.00
0005433284903	23049	Economy	5200.00
0005433284857	23049	Economy	5700.00
0005433284852	23049	Economy	5700.00
0005433284797	23049	Economy	5200.00
0005433284898	23049	Economy	5200.00
0005433284895	23049	Economy	5200.00
0005433284885	23049	Economy	5200.00
0005433284806	23049	Economy	5200.00
0005435103878	23049	Economy	5200.00
0005435103882	23049	Economy	5200.00
0005433284791	23049	Economy	5200.00
0005433284915	23049	Economy	5200.00
0005433284941	23049	Economy	5200.00
0005433284968	23049	Economy	5200.00
0005433284884	23049	Economy	5200.00
0005433284887	23049	Economy	5200.00
0005433284938	23049	Economy	5200.00
0005433284858	23049	Economy	5200.00
0005433284939	23049	Economy	5200.00
0005433284894	23049	Economy	5200.00
0005433284875	23049	Economy	5200.00
0005433284867	23049	Economy	5200.00
0005433284868	23049	Economy	5200.00
0005435103883	23049	Economy	5200.00
0005435103881	23049	Economy	5200.00
0005433284801	23049	Economy	5200.00
0005433285159	32048	Business	15700.00
0005433285153	32048	Business	15700.00
0005433285140	32048	Business	15700.00
0005433285142	32048	Business	15700.00
0005433285137	32048	Business	15700.00
0005433285157	32048	Economy	5200.00
0005435103818	32048	Economy	5200.00
0005433285143	32048	Economy	5200.00
0005433285166	32048	Economy	5200.00
0005433285151	32048	Economy	5200.00
0005433285138	32048	Economy	5200.00
0005433285154	32048	Economy	5200.00
0005433285158	32048	Economy	5200.00
0005433285139	32048	Economy	5200.00
0005433285152	32048	Economy	5200.00
0005433285161	32048	Economy	5200.00
0005435103795	32048	Economy	5200.00
0005433285148	32048	Economy	5200.00
0005433285144	32048	Economy	5700.00
0005433285141	32048	Economy	5200.00
0005433285163	32048	Economy	5200.00
0005433285145	32048	Economy	5200.00
0005435103794	32048	Economy	5200.00
0005433285150	32048	Economy	5200.00
0005433285146	32048	Economy	5200.00
0005433285165	32048	Economy	5200.00
0005435103796	32048	Economy	5200.00
0005433285149	32048	Economy	5200.00
0005433285162	32048	Economy	5200.00
0005433285164	32048	Economy	5200.00
0005433285155	32048	Economy	5200.00
0005433285156	32048	Economy	5200.00
0005433285147	32048	Economy	5200.00
0005433285136	32048	Economy	5200.00
0005433285160	32048	Economy	5200.00
0005433285135	32048	Economy	5200.00
0005435103809	32048	Economy	5200.00
0005435852562	23879	Economy	13500.00
0005433475641	23879	Economy	12300.00
0005435852561	23879	Economy	12300.00
0005433475642	23879	Economy	12300.00
0005433475637	23879	Economy	12300.00
0005435852563	23879	Economy	12300.00
0005435852560	23879	Economy	12300.00
0005435852559	23879	Economy	12300.00
0005433475643	23879	Economy	12300.00
0005433475656	23879	Economy	12300.00
0005433475638	23879	Economy	12300.00
0005432526338	30581	Business	42100.00
0005432526073	30581	Business	42100.00
0005432526390	30581	Business	42100.00
0005432526591	30581	Business	42100.00
0005432526078	30581	Business	42100.00
0005432526049	30581	Business	42100.00
0005432525969	30581	Business	42100.00
0005432525949	30581	Business	42100.00
0005432526050	30581	Business	42100.00
0005432526589	30581	Business	42100.00
0005432526709	30581	Business	42100.00
0005434066802	30581	Business	42100.00
0005432526334	30581	Business	42100.00
0005432526485	30581	Business	42100.00
0005434066668	30581	Business	42100.00
0005432526697	30581	Business	42100.00
0005432526212	30581	Business	42100.00
0005435213267	30581	Business	42100.00
0005432526072	30581	Business	42100.00
0005432526093	30581	Business	42100.00
0005435213297	30581	Business	42100.00
0005435213273	30581	Business	42100.00
0005435213262	30581	Business	42100.00
0005432526795	30581	Business	42100.00
0005432526340	30581	Comfort	23900.00
0005432526341	30581	Comfort	23900.00
0005435213241	30581	Comfort	23900.00
0005432526454	30581	Comfort	23900.00
0005432525967	30581	Comfort	23900.00
0005432526590	30581	Comfort	23900.00
0005435213255	30581	Comfort	23900.00
0005434066603	30581	Comfort	23900.00
0005432526413	30581	Comfort	23900.00
0005434066687	30581	Comfort	23900.00
0005432526320	30581	Comfort	23900.00
0005435213293	30581	Comfort	23900.00
0005432211472	30581	Comfort	23900.00
0005435213280	30581	Comfort	23900.00
0005432428884	30581	Comfort	23900.00
0005432526824	30581	Comfort	23900.00
0005434066567	30581	Comfort	23900.00
0005432159839	30581	Comfort	23900.00
0005434066922	30581	Comfort	23900.00
0005432526749	30581	Comfort	23900.00
0005435213236	30581	Comfort	23900.00
0005435213286	30581	Comfort	23900.00
0005432535780	30581	Comfort	23900.00
0005434066558	30581	Comfort	23900.00
0005432526405	30581	Comfort	23900.00
0005432526382	30581	Comfort	23900.00
0005432525866	30581	Comfort	23900.00
0005434066586	30581	Comfort	23900.00
0005435213285	30581	Comfort	23900.00
0005432159838	30581	Comfort	23900.00
0005432526080	30581	Comfort	23900.00
0005434066669	30581	Comfort	23900.00
0005432526862	30581	Comfort	23900.00
0005432526047	30581	Comfort	23900.00
0005432526121	30581	Comfort	23900.00
0005435213295	30581	Comfort	23900.00
0005432533264	30581	Comfort	23900.00
0005435213278	30581	Comfort	23900.00
0005434066326	30581	Comfort	23900.00
0005434066923	30581	Economy	14000.00
0005434066533	30581	Economy	14000.00
0005432526176	30581	Economy	14000.00
0005432526700	30581	Economy	14000.00
0005434066490	30581	Economy	14000.00
0005432525915	30581	Economy	14000.00
0005433656658	30581	Economy	14000.00
0005434066568	30581	Economy	14000.00
0005434066877	30581	Economy	14000.00
0005432526248	30581	Economy	14000.00
0005435725580	30581	Economy	14000.00
0005432211469	30581	Economy	14000.00
0005432526553	30581	Economy	14000.00
0005434066876	30581	Economy	14000.00
0005435213258	30581	Economy	14000.00
0005435213268	30581	Economy	14000.00
0005434066629	30581	Economy	14000.00
0005432535774	30581	Economy	14000.00
0005432526441	30581	Economy	14000.00
0005435213230	30581	Economy	14000.00
0005432526041	30581	Economy	14000.00
0005435213244	30581	Economy	14000.00
0005432526189	30581	Economy	14000.00
0005434066787	30581	Economy	14000.00
0005435213271	30581	Economy	14000.00
0005434066993	30581	Economy	14000.00
0005432526455	30581	Economy	14000.00
0005432526463	30581	Economy	14000.00
0005432526228	30581	Economy	14000.00
0005435213288	30581	Economy	14000.00
0005432526216	30581	Economy	14000.00
0005434066704	30581	Economy	14000.00
0005434066527	30581	Economy	14000.00
0005434066563	30581	Economy	14000.00
0005432526173	30581	Economy	14000.00
0005435213272	30581	Economy	14000.00
0005432526197	30581	Economy	14000.00
0005432526809	30581	Economy	14000.00
0005434066512	30581	Economy	14000.00
0005434066839	30581	Economy	14000.00
0005434066462	30581	Economy	14000.00
0005435213248	30581	Economy	14000.00
0005432526750	30581	Economy	14000.00
0005432526354	30581	Economy	14000.00
0005434066547	30581	Economy	14000.00
0005435213289	30581	Economy	14000.00
0005434066686	30581	Economy	14000.00
0005434066532	30581	Economy	14000.00
0005435213254	30581	Economy	14000.00
0005432537027	30581	Economy	14000.00
0005435213276	30581	Economy	14000.00
0005434066587	30581	Economy	14000.00
0005432526757	30581	Economy	14000.00
0005432526696	30581	Economy	14000.00
0005434066428	30581	Economy	14000.00
0005432533260	30581	Economy	14000.00
0005432526149	30581	Economy	14000.00
0005432526376	30581	Economy	14000.00
0005432535758	30581	Economy	14000.00
0005435725581	30581	Economy	14000.00
0005433656657	30581	Economy	14000.00
0005432526531	30581	Economy	14000.00
0005432526114	30581	Economy	14000.00
0005435213237	30581	Economy	14000.00
0005434066539	30581	Economy	15400.00
0005435213290	30581	Economy	15400.00
0005434066735	30581	Economy	15400.00
0005432526465	30581	Economy	15400.00
0005435213281	30581	Economy	14000.00
0005435725579	30581	Economy	14000.00
0005435213249	30581	Economy	14000.00
0005432526632	30581	Economy	14000.00
0005432526466	30581	Economy	14000.00
0005435213243	30581	Economy	14000.00
0005434066546	30581	Economy	14000.00
0005432526375	30581	Economy	14000.00
0005432526878	30581	Economy	14000.00
0005432526298	30581	Economy	14000.00
0005432526552	30581	Economy	14000.00
0005434066638	30581	Economy	14000.00
0005432526374	30581	Economy	14000.00
0005435213279	30581	Economy	14000.00
0005435213298	30581	Economy	14000.00
0005432526293	30581	Economy	14000.00
0005432526204	30581	Economy	14000.00
0005432526383	30581	Economy	14000.00
0005432526091	30581	Economy	14000.00
0005432526593	30581	Economy	14000.00
0005432526414	30581	Economy	14000.00
0005432526184	30581	Economy	14000.00
0005434066760	30581	Economy	14000.00
0005435213296	30581	Economy	14000.00
0005434066657	30581	Economy	14000.00
0005435213246	30581	Economy	14000.00
0005432526170	30581	Economy	14000.00
0005434066594	30581	Economy	14000.00
0005432526380	30581	Economy	14000.00
0005432526366	30581	Economy	14000.00
0005435213250	30581	Economy	14000.00
0005432526422	30581	Economy	14000.00
0005432526823	30581	Economy	14000.00
0005432526187	30581	Economy	14000.00
0005434066688	30581	Economy	14000.00
0005432526530	30581	Economy	14000.00
0005432526444	30581	Economy	14000.00
0005434066551	30581	Economy	14000.00
0005435213251	30581	Economy	14000.00
0005434066905	30581	Economy	14000.00
0005432526442	30581	Economy	14000.00
0005435213291	30581	Economy	14000.00
0005435213263	30581	Economy	14000.00
0005434066694	30581	Economy	14000.00
0005432526299	30581	Economy	14000.00
0005434066397	30581	Economy	14000.00
0005432526048	30581	Economy	14000.00
0005432526472	30581	Economy	14000.00
0005432526828	30581	Economy	14000.00
0005434066566	30581	Economy	14000.00
0005432526116	30581	Economy	14000.00
0005435213274	30581	Economy	14000.00
0005432526092	30581	Economy	14000.00
0005435213253	30581	Economy	14000.00
0005434066554	30581	Economy	14000.00
0005435213238	30581	Economy	14000.00
0005432526571	30581	Economy	14000.00
0005432526495	30581	Economy	14000.00
0005432526333	30581	Economy	14000.00
0005435213245	30581	Economy	14000.00
0005435213260	30581	Economy	14000.00
0005434066470	30581	Economy	14000.00
0005435213247	30581	Economy	14000.00
0005432526453	30581	Economy	14000.00
0005435213240	30581	Economy	14000.00
0005432526061	30581	Economy	14000.00
0005432211468	30581	Economy	14000.00
0005432533265	30581	Economy	14000.00
0005435213292	30581	Economy	14000.00
0005432525810	30581	Economy	14000.00
0005435213287	30581	Economy	14000.00
0005432526106	30581	Economy	14000.00
0005434066720	30581	Economy	14000.00
0005434066625	30581	Economy	14000.00
0005432526556	30581	Economy	14000.00
0005432535773	30581	Economy	14000.00
0005434066640	30581	Economy	14000.00
0005434066863	30581	Economy	14000.00
0005434066639	30581	Economy	14000.00
0005432526319	30581	Economy	14000.00
0005432159840	30581	Economy	14000.00
0005435213265	30581	Economy	14000.00
0005432526860	30581	Economy	14000.00
0005434066768	30581	Economy	14000.00
0005432526174	30581	Economy	14000.00
0005435213277	30581	Economy	14000.00
0005432211471	30581	Economy	14000.00
0005432526188	30581	Economy	14000.00
0005434066596	30581	Economy	14000.00
0005434066992	30581	Economy	14000.00
0005432535772	30581	Economy	14000.00
0005435213282	30581	Economy	14000.00
0005432526113	30581	Economy	14000.00
0005435213269	30581	Economy	14000.00
0005435213259	30581	Economy	15400.00
0005434066483	30581	Economy	14000.00
0005435213235	30581	Economy	15400.00
0005432526283	30581	Economy	15400.00
0005432526861	30581	Economy	15400.00
0005432526040	30581	Economy	14000.00
0005432526155	30581	Economy	14000.00
0005432526400	30581	Economy	14000.00
0005435213232	30581	Economy	14000.00
0005435213239	30581	Economy	14000.00
0005432537026	30581	Economy	14000.00
0005432159837	30581	Economy	14000.00
0005434066480	30581	Economy	14000.00
0005435213284	30581	Economy	14000.00
0005432526089	30581	Economy	14000.00
0005432526359	30581	Economy	14000.00
0005432526592	30581	Economy	14000.00
0005432526337	30581	Economy	14000.00
0005435213233	30581	Economy	14000.00
0005432526452	30581	Economy	14000.00
0005432526794	30581	Economy	14000.00
0005432526370	30581	Economy	14000.00
0005434066788	30581	Economy	14000.00
0005435725582	30581	Economy	14000.00
0005434066703	30581	Economy	14000.00
0005432526358	30581	Economy	14000.00
0005435213252	30581	Economy	14000.00
0005434066481	30581	Economy	14000.00
0005432526829	30581	Economy	14000.00
0005435213261	30581	Economy	14000.00
0005434066552	30581	Economy	14000.00
0005432525916	30581	Economy	14000.00
0005435213294	30581	Economy	14000.00
0005432526193	30581	Economy	14000.00
0005435725578	30581	Economy	14000.00
0005434066488	30581	Economy	14000.00
0005432211467	30581	Economy	14000.00
0005432525944	30581	Economy	14000.00
0005432526365	30581	Economy	14000.00
0005432526353	30581	Economy	14000.00
0005434066705	30581	Economy	14000.00
0005432526175	30581	Economy	14000.00
0005434066478	30581	Economy	14000.00
0005432211470	30581	Economy	14000.00
0005432526699	30581	Economy	14000.00
0005435213231	30581	Economy	14000.00
0005435213257	30581	Economy	14000.00
0005432526122	30581	Economy	14000.00
0005435213242	30581	Economy	14000.00
0005435213283	30581	Economy	14000.00
0005435213275	30581	Economy	14000.00
0005432526417	30581	Economy	14000.00
0005432526265	30581	Economy	14000.00
0005435213256	30581	Economy	14000.00
0005434066482	30581	Economy	14000.00
0005432525945	30581	Economy	14000.00
0005432537025	30581	Economy	14000.00
0005432526406	30581	Economy	14000.00
0005432526708	30581	Economy	14000.00
0005435213266	30581	Economy	14000.00
0005432526524	30581	Economy	14000.00
0005432526423	30581	Economy	14000.00
0005434066803	30581	Economy	14000.00
0005433656656	30581	Economy	14000.00
0005434066595	30581	Economy	14000.00
0005432526473	30581	Economy	14000.00
0005432525968	30581	Economy	14000.00
0005435213234	30581	Economy	14000.00
0005432526381	30581	Economy	14000.00
0005432526596	30581	Economy	14000.00
0005432526624	30581	Economy	14000.00
0005434066904	30581	Economy	14000.00
0005432525809	30581	Economy	14000.00
0005432526566	30581	Economy	14000.00
0005434066592	30581	Economy	14000.00
0005435630955	30581	Economy	14000.00
0005435213264	30581	Economy	14000.00
0005432526335	30581	Economy	14000.00
0005432526484	30581	Economy	14000.00
0005432526192	30581	Economy	14000.00
0005435213270	30581	Economy	14000.00
0005434066747	30581	Economy	14000.00
0005435630956	30581	Economy	14000.00
0005432526679	30581	Economy	14000.00
0005432526953	30581	Economy	14000.00
0005434066607	30581	Economy	14000.00
0005432526332	30581	Economy	14000.00
0005434066513	30581	Economy	14000.00
0005434066602	30581	Economy	14000.00
0005435652436	24875	Business	9800.00
0005433367754	24875	Business	9800.00
0005435652442	24875	Business	9800.00
0005435652473	24875	Business	9800.00
0005433367735	24875	Business	9800.00
0005435652449	24875	Business	9800.00
0005433367739	24875	Business	9800.00
0005433367742	24875	Business	9800.00
0005433367721	24875	Business	9800.00
0005435652353	24875	Economy	3300.00
0005433367723	24875	Economy	3300.00
0005435652434	24875	Economy	3300.00
0005433367745	24875	Economy	3300.00
0005435652305	24875	Economy	3300.00
0005435652437	24875	Economy	3300.00
0005433367755	24875	Economy	3300.00
0005433367731	24875	Economy	3600.00
0005435652292	24875	Economy	3600.00
0005435652375	24875	Economy	3600.00
0005435652403	24875	Economy	3600.00
0005435652301	24875	Economy	3600.00
0005433367740	24875	Economy	3300.00
0005435652404	24875	Economy	3300.00
0005435652300	24875	Economy	3300.00
0005433367718	24875	Economy	3300.00
0005433367717	24875	Economy	3300.00
0005433367720	24875	Economy	3300.00
0005435652398	24875	Economy	3300.00
0005435652339	24875	Economy	3300.00
0005435652411	24875	Economy	3300.00
0005435652467	24875	Economy	3300.00
0005435652366	24875	Economy	3300.00
0005433367724	24875	Economy	3300.00
0005433367729	24875	Economy	3300.00
0005433367752	24875	Economy	3300.00
0005435652324	24875	Economy	3300.00
0005433367741	24875	Economy	3300.00
0005433367727	24875	Economy	3300.00
0005435652320	24875	Economy	3300.00
0005433367730	24875	Economy	3300.00
0005435652412	24875	Economy	3300.00
0005433367734	24875	Economy	3300.00
0005433367747	24875	Economy	3300.00
0005433367743	24875	Economy	3300.00
0005435652399	24875	Economy	3300.00
0005435652397	24875	Economy	3300.00
0005433367726	24875	Economy	3300.00
0005433367736	24875	Economy	3300.00
0005433367746	24875	Economy	3300.00
0005433367738	24875	Economy	3300.00
0005433367753	24875	Economy	3300.00
0005435652417	24875	Economy	3300.00
0005433367748	24875	Economy	3300.00
0005435652460	24875	Economy	3300.00
0005433367751	24875	Economy	3300.00
0005435652405	24875	Economy	3300.00
0005435652367	24875	Economy	3300.00
0005435652481	24875	Economy	3300.00
0005435652299	24875	Economy	3300.00
0005433367732	24875	Economy	3300.00
0005435652482	24875	Economy	3300.00
0005433367744	24875	Economy	3300.00
0005435652344	24875	Economy	3300.00
0005435652376	24875	Economy	3300.00
0005435652338	24875	Economy	3300.00
0005433367722	24875	Economy	3300.00
0005435652450	24875	Economy	3300.00
0005433367725	24875	Economy	3300.00
0005433367733	24875	Economy	3300.00
0005433367719	24875	Economy	3300.00
0005433367750	24875	Economy	3300.00
0005435652325	24875	Economy	3300.00
0005435652472	24875	Economy	3300.00
0005433367749	24875	Economy	3300.00
0005435652401	24875	Economy	3300.00
0005435652470	24875	Economy	3300.00
0005433367728	24875	Economy	3300.00
0005433367737	24875	Economy	3300.00
0005435949767	6604	Economy	20600.00
0005435949768	6604	Economy	18700.00
0005435949765	6604	Economy	18700.00
0005435949770	6604	Economy	18700.00
0005435949766	6604	Economy	18700.00
0005435949769	6604	Economy	18700.00
0005435949771	6604	Economy	18700.00
0005434979670	2015	Economy	10500.00
0005435801683	2015	Economy	10500.00
0005434979666	2015	Economy	10500.00
0005435801682	2015	Economy	10500.00
0005434979669	2015	Economy	9500.00
0005434979671	2015	Economy	9500.00
0005434979664	2015	Economy	9500.00
0005434979679	2015	Economy	9500.00
0005434979678	2015	Economy	9500.00
0005434979653	2015	Economy	9500.00
0005434979654	2015	Economy	9500.00
0005434979677	2015	Economy	9500.00
0005434979655	2015	Economy	9500.00
0005434979657	2015	Economy	9500.00
0005434979665	2015	Economy	9500.00
0005434979681	2015	Economy	9500.00
0005434979658	2015	Economy	9500.00
0005434979661	2015	Economy	9500.00
0005434979672	2015	Economy	9500.00
0005434979674	2015	Economy	9500.00
0005434979660	2015	Economy	9500.00
0005434979676	2015	Economy	9500.00
0005434979668	2015	Economy	9500.00
0005434979667	2015	Economy	9500.00
0005434979662	2015	Economy	9500.00
0005434979680	2015	Economy	9500.00
0005434979659	2015	Economy	9500.00
0005434979673	2015	Economy	9500.00
0005435801684	2015	Economy	9500.00
0005434979652	2015	Economy	9500.00
0005434979656	2015	Economy	9500.00
0005434979663	2015	Economy	9500.00
0005434979682	2015	Economy	9500.00
0005434979675	2015	Economy	9500.00
0005434979476	23531	Economy	10500.00
0005434979305	23531	Economy	10500.00
0005434979486	23531	Economy	10500.00
0005434979261	23531	Economy	9500.00
0005434979368	23531	Economy	9500.00
0005434979311	23531	Economy	9500.00
0005434979377	23531	Economy	9500.00
0005434979436	23531	Economy	9500.00
0005434979435	23531	Economy	9500.00
0005434979434	23531	Economy	9500.00
0005434979330	23531	Economy	9500.00
0005434979366	23531	Economy	9500.00
0005434979350	23531	Economy	9500.00
0005434979306	23531	Economy	9500.00
0005434979328	23531	Economy	9500.00
0005434979477	23531	Economy	9500.00
0005434979262	23531	Economy	9500.00
0005434979442	23531	Economy	9500.00
0005434979393	23531	Economy	9500.00
0005434979356	23531	Economy	9500.00
0005434979255	23531	Economy	9500.00
0005434979365	23531	Economy	9500.00
0005435801667	23531	Economy	9500.00
0005434979287	23531	Economy	9500.00
0005434979312	23531	Economy	9500.00
0005434952515	2563	Economy	5300.00
0005434952517	2563	Economy	5300.00
0005434952514	2563	Economy	5300.00
0005434952516	2563	Economy	5300.00
0005433256394	2564	Economy	5300.00
0005433256400	2564	Economy	5300.00
0005433256395	2564	Economy	5300.00
0005433256399	2564	Economy	5300.00
0005433256393	2564	Economy	5300.00
0005433256390	2564	Economy	5300.00
0005433256389	2564	Economy	5300.00
0005433256411	28254	Economy	5300.00
0005434952490	28254	Economy	5300.00
0005434952478	28254	Economy	5300.00
0005434952487	28254	Economy	5300.00
0005434952491	28254	Economy	5300.00
0005434952489	28254	Economy	5300.00
0005433256412	28254	Economy	5300.00
0005434952488	28254	Economy	5300.00
0005433256413	28254	Economy	5300.00
0005434952479	28254	Economy	5300.00
0005433111496	19780	Economy	8700.00
0005434302853	19780	Economy	8700.00
0005433111498	19780	Economy	8700.00
0005433112368	19780	Economy	8700.00
0005433111497	19780	Economy	8700.00
0005433112367	19780	Economy	8700.00
0005434137404	11937	Business	9700.00
0005434137017	11937	Business	9700.00
0005434137066	11937	Business	9700.00
0005434137129	11937	Business	9700.00
0005434136741	11937	Business	9700.00
0005434137088	11937	Business	9700.00
0005434136740	11937	Business	9700.00
0005434137277	11937	Business	9700.00
0005434137454	11937	Business	9700.00
0005434137248	11937	Business	9700.00
0005434136895	11937	Business	9700.00
0005434137328	11937	Economy	3200.00
0005434136768	11937	Economy	3200.00
0005434137067	11937	Economy	3200.00
0005434137062	11937	Economy	3200.00
0005434137058	11937	Economy	3200.00
0005434136999	11937	Economy	3200.00
0005434137276	11937	Economy	3200.00
0005434137068	11937	Economy	3200.00
0005434137142	11937	Economy	3500.00
0005434137146	11937	Economy	3500.00
0005434137063	11937	Economy	3500.00
0005434137383	11937	Economy	3500.00
0005434137000	11937	Economy	3200.00
0005434137015	11937	Economy	3200.00
0005434137001	11937	Economy	3200.00
0005434137286	11937	Economy	3200.00
0005434137355	11937	Economy	3200.00
0005434137141	11937	Economy	3200.00
0005434137320	11937	Economy	3200.00
0005434137090	11937	Economy	3200.00
0005434137217	11937	Economy	3200.00
0005434136961	11937	Economy	3200.00
0005434136963	11937	Economy	3200.00
0005434137278	11937	Economy	3200.00
0005434137111	11937	Economy	3200.00
0005434137362	11937	Economy	3200.00
0005434136769	11937	Economy	3200.00
0005434137382	11937	Economy	3200.00
0005434137371	11937	Economy	3200.00
0005434137115	11937	Economy	3200.00
0005434137414	11937	Economy	3200.00
0005434137223	11937	Economy	3200.00
0005434136812	11937	Economy	3200.00
0005434137166	11937	Economy	3200.00
0005434137065	11937	Economy	3200.00
0005434137099	11937	Economy	3200.00
0005434137280	11937	Economy	3200.00
0005434136962	11937	Economy	3200.00
0005434136896	11937	Economy	3200.00
0005434137202	11937	Economy	3200.00
0005434136944	11937	Economy	3200.00
0005434136770	11937	Economy	3200.00
0005434137260	11937	Economy	3200.00
0005434137089	11937	Economy	3200.00
0005434137192	11937	Economy	3200.00
0005434137249	11937	Economy	3200.00
0005434137038	11937	Economy	3200.00
0005434137318	11937	Economy	3200.00
0005434137373	11937	Economy	3200.00
0005434137509	11937	Economy	3200.00
0005434137191	11937	Economy	3200.00
0005434137150	11937	Economy	3200.00
0005434137363	11937	Economy	3200.00
0005434137130	11937	Economy	3200.00
0005434136964	11937	Economy	3200.00
0005434137116	11937	Economy	3200.00
0005434137208	11937	Economy	3200.00
0005434137413	11937	Economy	3200.00
0005434137319	11937	Economy	3200.00
0005434137405	11937	Economy	3200.00
0005434137329	11937	Economy	3200.00
0005434137224	11937	Economy	3200.00
0005434136943	11937	Economy	3200.00
0005434137053	11937	Economy	3200.00
0005434136945	11937	Economy	3200.00
0005434137072	11937	Economy	3200.00
0005434137143	11937	Economy	3200.00
0005434137285	11937	Economy	3200.00
0005434137356	11937	Economy	3200.00
0005434137014	11937	Economy	3200.00
0005434137194	11937	Economy	3200.00
0005434137091	11937	Economy	3200.00
0005434137590	11937	Economy	3200.00
0005434137718	28724	Business	9700.00
0005434137767	28724	Business	9700.00
0005434137715	28724	Business	9700.00
0005434137764	28724	Business	9700.00
0005434137720	28724	Business	9700.00
0005434137755	28724	Business	9700.00
0005434137758	28724	Business	9700.00
0005434137776	28724	Business	9700.00
0005434137737	28724	Economy	3200.00
0005434137780	28724	Economy	3200.00
0005434137738	28724	Economy	3200.00
0005434137719	28724	Economy	3200.00
0005434137777	28724	Economy	3200.00
0005434137724	28724	Economy	3200.00
0005434137751	28724	Economy	3200.00
0005434137778	28724	Economy	3200.00
0005434137729	28724	Economy	3200.00
0005434137763	28724	Economy	3200.00
0005434137750	28724	Economy	3500.00
0005434137762	28724	Economy	3500.00
0005434137731	28724	Economy	3500.00
0005434137783	28724	Economy	3200.00
0005434137736	28724	Economy	3200.00
0005434137782	28724	Economy	3200.00
0005434137774	28724	Economy	3200.00
0005434137722	28724	Economy	3200.00
0005434137754	28724	Economy	3200.00
0005434137743	28724	Economy	3200.00
0005434137714	28724	Economy	3200.00
0005434137733	28724	Economy	3200.00
0005434137734	28724	Economy	3200.00
0005434137711	28724	Economy	3200.00
0005434137735	28724	Economy	3200.00
0005434137721	28724	Economy	3200.00
0005434137725	28724	Economy	3200.00
0005434137772	28724	Economy	3200.00
0005434137760	28724	Economy	3200.00
0005434137756	28724	Economy	3200.00
0005434137746	28724	Economy	3200.00
0005434137708	28724	Economy	3200.00
0005434137770	28724	Economy	3200.00
0005434137740	28724	Economy	3200.00
0005434137717	28724	Economy	3200.00
0005434137726	28724	Economy	3200.00
0005434137779	28724	Economy	3200.00
0005434137728	28724	Economy	3200.00
0005434137739	28724	Economy	3200.00
0005434137712	28724	Economy	3200.00
0005434137730	28724	Economy	3200.00
0005434137766	28724	Economy	3200.00
0005434137775	28724	Economy	3200.00
0005434137710	28724	Economy	3200.00
0005434137713	28724	Economy	3200.00
0005434137744	28724	Economy	3200.00
0005434137727	28724	Economy	3200.00
0005434137747	28724	Economy	3200.00
0005434137781	28724	Economy	3200.00
0005434137742	28724	Economy	3200.00
0005434137709	28724	Economy	3200.00
0005434137748	28724	Economy	3200.00
0005434137753	28724	Economy	3200.00
0005434137757	28724	Economy	3200.00
0005434137752	28724	Economy	3200.00
0005434137765	28724	Economy	3200.00
0005434137761	28724	Economy	3200.00
0005434137741	28724	Economy	3200.00
0005434137749	28724	Economy	3200.00
0005434137769	28724	Economy	3200.00
0005434137723	28724	Economy	3200.00
0005434137773	28724	Economy	3200.00
0005434137784	28724	Economy	3200.00
0005434137732	28724	Economy	3200.00
0005434137716	28724	Economy	3200.00
0005434137771	28724	Economy	3200.00
0005434137745	28724	Economy	3200.00
0005434137759	28724	Economy	3200.00
0005434137768	28724	Economy	3200.00
0005435312775	6587	Economy	23000.00
0005434466433	6587	Economy	20900.00
0005434466441	6587	Economy	20900.00
0005434466438	6587	Economy	20900.00
0005435312764	6587	Economy	20900.00
0005434466439	6587	Economy	20900.00
0005435312776	6587	Economy	20900.00
0005434466437	6587	Economy	20900.00
0005434466440	6587	Economy	20900.00
0005434466442	6587	Economy	20900.00
0005434466435	6587	Economy	20900.00
0005435312770	6587	Economy	20900.00
0005434466436	6587	Economy	20900.00
0005434466434	6587	Economy	20900.00
0005433538837	6797	Economy	9900.00
0005433538838	6797	Economy	9900.00
0005433538839	6797	Economy	9900.00
0005435259699	6797	Economy	9900.00
0005433538833	6797	Economy	9900.00
0005435259698	6797	Economy	9900.00
0005433538836	6797	Economy	9900.00
0005433538834	6797	Economy	9900.00
0005433534490	6797	Economy	9900.00
0005433538835	6797	Economy	9900.00
0005433538832	6797	Economy	9900.00
0005435259700	6797	Economy	9900.00
0005433534489	6797	Economy	9900.00
0005435259717	6797	Economy	9900.00
0005433538765	24994	Economy	10900.00
0005433538753	24994	Economy	9900.00
0005433538784	24994	Economy	9900.00
0005433538754	24994	Economy	9900.00
0005433538737	24994	Economy	9900.00
0005433538776	24994	Economy	9900.00
0005433538743	24994	Economy	9900.00
0005433538770	24994	Economy	9900.00
0005433538751	24994	Economy	9900.00
0005433538761	24994	Economy	9900.00
0005435259740	24994	Economy	9900.00
0005433538741	24994	Economy	9900.00
0005435259739	24994	Economy	9900.00
0005435259738	24994	Economy	9900.00
0005433538760	24994	Economy	9900.00
0005435259737	24994	Economy	9900.00
0005433538769	24994	Economy	9900.00
0005433538752	24994	Economy	9900.00
0005432922488	829	Economy	16100.00
0005432922453	829	Economy	16100.00
0005432922477	829	Economy	14600.00
0005433511918	829	Economy	14600.00
0005433511917	829	Economy	14600.00
0005432922469	829	Economy	14600.00
0005432922487	829	Economy	14600.00
0005433511919	829	Economy	14600.00
0005432922454	829	Economy	14600.00
0005433511916	829	Economy	14600.00
0005432922489	829	Economy	14600.00
0005433511915	829	Economy	14600.00
0005432922484	829	Economy	14600.00
0005433511914	829	Economy	14600.00
0005432922466	829	Economy	14600.00
0005432922468	829	Economy	14600.00
0005433511920	829	Economy	14600.00
0005432922510	16148	Economy	14600.00
0005432922506	16148	Economy	14600.00
0005433511852	16148	Economy	14600.00
0005433511870	16148	Economy	14600.00
0005432922508	16148	Economy	14600.00
0005433511826	16148	Economy	14600.00
0005433511877	16148	Economy	14600.00
0005432922509	16148	Economy	14600.00
0005433511851	16148	Economy	14600.00
0005433511876	16148	Economy	14600.00
0005432922507	16148	Economy	14600.00
0005435697242	3647	Economy	7900.00
0005435697221	3647	Economy	7200.00
0005435935000	3647	Economy	7200.00
0005435697224	3647	Economy	7200.00
0005435697222	3647	Economy	7200.00
0005435697226	3647	Economy	7200.00
0005435697233	3647	Economy	7200.00
0005435916131	3647	Economy	7200.00
0005435697241	3647	Economy	7200.00
0005435916122	3647	Economy	7200.00
0005435697217	3647	Economy	7200.00
0005435697230	3647	Economy	7200.00
0005435697220	3647	Economy	7200.00
0005435697235	3647	Economy	7200.00
0005434950511	3647	Economy	7200.00
0005434950510	3647	Economy	7200.00
0005435697243	3647	Economy	7200.00
0005435697219	3647	Economy	7200.00
0005435697234	3647	Economy	7200.00
0005435697232	3647	Economy	7200.00
0005435697231	3647	Economy	7200.00
0005435697229	3647	Economy	7200.00
0005435697239	3647	Economy	7200.00
0005435697218	3647	Economy	7200.00
0005434950509	3647	Economy	7200.00
0005435697228	3647	Economy	7200.00
0005435697225	3647	Economy	7200.00
0005434950512	3647	Economy	7200.00
0005435916136	3647	Economy	7200.00
0005435697237	3647	Economy	7200.00
0005435697240	3647	Economy	7200.00
0005435697223	3647	Economy	7200.00
0005435697244	3647	Economy	7200.00
0005435697236	3647	Economy	7200.00
0005434950513	3647	Economy	7200.00
0005435697227	3647	Economy	7200.00
0005435697238	3647	Economy	7200.00
0005435697031	16297	Economy	7900.00
0005435696960	16297	Economy	7900.00
0005434950460	16297	Economy	7900.00
0005435697003	16297	Economy	7900.00
0005435697037	16297	Economy	7200.00
0005435697014	16297	Economy	7200.00
0005435697013	16297	Economy	7200.00
0005435696936	16297	Economy	7200.00
0005435916157	16297	Economy	7200.00
0005435697032	16297	Economy	7200.00
0005435696946	16297	Economy	7200.00
0005435697128	16297	Economy	7200.00
0005435696910	16297	Economy	7200.00
0005435935028	16297	Economy	7200.00
0005435696868	16297	Economy	7200.00
0005435696945	16297	Economy	7200.00
0005435697038	16297	Economy	7200.00
0005435696888	16297	Economy	7200.00
0005434950461	16297	Economy	7200.00
0005435916155	16297	Economy	7200.00
0005434950459	16297	Economy	7200.00
0005435916156	16297	Economy	7200.00
0005435696867	16297	Economy	7200.00
0005435696961	16297	Economy	7200.00
0005435696931	16297	Economy	7200.00
0005435697024	16297	Economy	7200.00
0005435697004	16297	Economy	7200.00
0005435696930	16297	Economy	7200.00
0005434950476	16297	Economy	7200.00
0005435697025	16297	Economy	7200.00
0005435697026	16297	Economy	7200.00
0005434950475	16297	Economy	7200.00
0005435696937	16297	Economy	7200.00
0005434950468	16297	Economy	7200.00
0005435935029	16297	Economy	7200.00
0005432609715	3989	Economy	19300.00
0005432607552	3989	Economy	19300.00
0005432609716	3989	Economy	19300.00
0005432609714	3989	Economy	19300.00
0005434604882	3989	Economy	19300.00
0005434604884	3989	Economy	19300.00
0005432607549	3989	Economy	19300.00
0005434606816	3989	Economy	19300.00
0005432607548	3989	Economy	19300.00
0005432607550	3989	Economy	19300.00
0005434606818	3989	Economy	19300.00
0005433519437	3989	Economy	19300.00
0005434604883	3989	Economy	19300.00
0005434604885	3989	Economy	19300.00
0005434606815	3989	Economy	19300.00
0005433519441	3989	Economy	19300.00
0005432607551	3989	Economy	19300.00
0005433519440	3989	Economy	19300.00
0005435841463	3989	Economy	19300.00
0005433519438	3989	Economy	19300.00
0005433519439	3989	Economy	19300.00
0005434606817	3989	Economy	19300.00
0005435853606	22085	Economy	19300.00
0005435853605	22085	Economy	19300.00
0005434606791	22085	Economy	19300.00
0005435904894	22085	Economy	19300.00
0005434606766	22085	Economy	19300.00
0005433519386	22085	Economy	19300.00
0005434606767	22085	Economy	19300.00
0005433519387	22085	Economy	19300.00
0005433519388	22085	Economy	19300.00
0005435628712	724	Economy	3700.00
0005435628709	724	Economy	3700.00
0005433348919	724	Economy	3700.00
0005433348929	724	Economy	3700.00
0005433348917	724	Economy	3700.00
0005435628711	724	Economy	3700.00
0005433348920	724	Economy	3700.00
0005433348938	724	Economy	3700.00
0005435628710	724	Economy	3700.00
0005433348967	15914	Economy	3700.00
0005433348964	15914	Economy	3700.00
0005433348965	15914	Economy	3700.00
0005433348966	15914	Economy	3700.00
0005433348969	15914	Economy	3700.00
0005435628687	15914	Economy	3700.00
0005433348968	15914	Economy	3700.00
0005435628694	15914	Economy	3700.00
0005435628697	15914	Economy	3700.00
0005433159286	17222	Economy	7100.00
0005433158100	17222	Economy	7100.00
0005434446511	17222	Economy	7100.00
0005434446508	17222	Economy	7100.00
0005434446510	17222	Economy	7100.00
0005434446509	17222	Economy	7100.00
0005434445237	17222	Economy	7100.00
0005434445236	17222	Economy	7100.00
0005433159304	17579	Economy	7100.00
0005433159305	17579	Economy	7100.00
0005435132842	7859	Economy	5900.00
0005435383076	7859	Economy	5900.00
0005435132835	7859	Economy	5900.00
0005435383086	7859	Economy	5400.00
0005435383087	7859	Economy	5400.00
0005435383085	7859	Economy	5400.00
0005435132845	7859	Economy	5400.00
0005435383075	7859	Economy	5400.00
0005435132840	7859	Economy	5400.00
0005435132843	7859	Economy	5400.00
0005435383074	7859	Economy	5400.00
0005435132837	7859	Economy	5400.00
0005435132841	7859	Economy	5400.00
0005435132836	7859	Economy	5400.00
0005435132838	7859	Economy	5400.00
0005435132844	7859	Economy	5400.00
0005435132839	7859	Economy	5400.00
0005435383131	33103	Economy	5900.00
0005435132792	33103	Economy	5900.00
0005435132727	33103	Economy	5400.00
0005435132763	33103	Economy	5400.00
0005435132787	33103	Economy	5400.00
0005435383129	33103	Economy	5400.00
0005435383127	33103	Economy	5400.00
0005435132753	33103	Economy	5400.00
0005435383126	33103	Economy	5400.00
0005435132780	33103	Economy	5400.00
0005435383128	33103	Economy	5400.00
0005435132728	33103	Economy	5400.00
0005435383130	33103	Economy	5400.00
0005435132802	33103	Economy	5400.00
0005435811054	4415	Business	133200.00
0005435811049	4415	Business	133200.00
0005435811055	4415	Economy	44400.00
0005435938844	4415	Economy	44400.00
0005435811050	4415	Economy	44400.00
0005435811052	4415	Economy	44400.00
0005435938851	4415	Economy	44400.00
0005435938845	4415	Economy	44400.00
0005435811056	4415	Economy	44400.00
0005435811048	4415	Economy	44400.00
0005435811057	4415	Economy	44400.00
0005435938846	4415	Economy	44400.00
0005435811051	4415	Economy	44400.00
0005435811053	4415	Economy	44400.00
0005435810998	29435	Business	133200.00
0005435810995	29435	Business	133200.00
0005435811017	29435	Business	133200.00
0005435811021	29435	Business	133200.00
0005435810996	29435	Business	133200.00
0005435811016	29435	Business	133200.00
0005435938873	29435	Business	133200.00
0005435938875	29435	Economy	44400.00
0005435938876	29435	Economy	44400.00
0005435811008	29435	Economy	44400.00
0005435811020	29435	Economy	44400.00
0005435810999	29435	Economy	44400.00
0005435938874	29435	Economy	44400.00
0005435810988	29435	Economy	44400.00
0005435811000	29435	Economy	44400.00
0005435811003	29435	Economy	44400.00
0005435938878	29435	Economy	44400.00
0005435811009	29435	Economy	44400.00
0005435938877	29435	Economy	44400.00
0005435811030	29435	Economy	44400.00
0005435810997	29435	Economy	44400.00
0005435160254	7504	Economy	12500.00
0005435390174	7504	Economy	12500.00
0005435390161	7504	Economy	12500.00
0005435160253	7504	Economy	12500.00
0005435160260	7504	Economy	12500.00
0005435160257	7504	Economy	12500.00
0005435160262	7504	Economy	12500.00
0005435390138	7504	Economy	12500.00
0005435160263	7504	Economy	12500.00
0005435160252	7504	Economy	12500.00
0005435390137	7504	Economy	12500.00
0005435390171	7504	Economy	12500.00
0005435160259	7504	Economy	12500.00
0005435160255	7504	Economy	12500.00
0005435160258	7504	Economy	12500.00
0005435160256	7504	Economy	12500.00
0005435390160	7504	Economy	12500.00
0005435390173	7504	Economy	12500.00
0005435160261	7504	Economy	12500.00
0005435160129	29545	Economy	13800.00
0005435160178	29545	Economy	13800.00
0005435160168	29545	Economy	12500.00
0005435390215	29545	Economy	12500.00
0005435390211	29545	Economy	12500.00
0005435390209	29545	Economy	12500.00
0005435390210	29545	Economy	12500.00
0005435160166	29545	Economy	12500.00
0005435390214	29545	Economy	12500.00
0005435160161	29545	Economy	12500.00
0005435160177	29545	Economy	12500.00
0005435390212	29545	Economy	12500.00
0005435160174	29545	Economy	12500.00
0005435390213	29545	Economy	12500.00
0005432398133	18477	Economy	4900.00
0005432398138	18477	Economy	4900.00
0005432394054	18477	Economy	4900.00
0005432394049	18477	Economy	4900.00
0005432398152	18477	Economy	4900.00
0005432398137	18477	Economy	4900.00
0005432398130	18477	Economy	4900.00
0005432398129	18477	Economy	4900.00
0005432394040	18477	Economy	4900.00
0005432394065	18477	Economy	4900.00
0005432398134	18477	Economy	4900.00
0005432394050	18477	Economy	4900.00
0005432398178	27165	Economy	4900.00
0005435179384	27165	Economy	4900.00
0005432398179	27165	Economy	4900.00
0005432400102	27165	Economy	4900.00
0005432398176	27165	Economy	4900.00
0005432400103	27165	Economy	4900.00
0005432398177	27165	Economy	4900.00
0005435179383	27165	Economy	4900.00
0005432400104	27165	Economy	4900.00
0005432400101	27165	Economy	4900.00
0005432865939	2237	Business	87300.00
0005432639089	2237	Business	87300.00
0005432639091	2237	Business	87300.00
0005432639082	2237	Business	87300.00
0005432639073	2237	Business	87300.00
0005432639072	2237	Economy	29100.00
0005432639078	2237	Economy	29100.00
0005432639071	2237	Economy	29100.00
0005432865922	2237	Economy	32000.00
0005432639090	2237	Economy	29100.00
0005432865924	2237	Economy	29100.00
0005432865901	2237	Economy	29100.00
0005432639092	2237	Economy	29100.00
0005432865925	2237	Economy	29100.00
0005432865921	2237	Economy	29100.00
0005432865902	2237	Economy	29100.00
0005432639076	2237	Economy	29100.00
0005432865927	2237	Economy	29100.00
0005432865923	2237	Economy	29100.00
0005432639079	2237	Economy	29100.00
0005432639077	2237	Economy	29100.00
0005432639083	2237	Economy	29100.00
0005432639080	2237	Economy	29100.00
0005432639070	2237	Economy	29100.00
0005432639081	2237	Economy	29100.00
0005432639069	2237	Economy	29100.00
0005432639088	2237	Economy	29100.00
0005432639068	2237	Economy	29100.00
0005432639084	2237	Economy	29100.00
0005432639067	2237	Economy	29100.00
0005432865898	2237	Economy	29100.00
0005432865926	2237	Economy	29100.00
0005432639074	2237	Economy	29100.00
0005432639085	2237	Economy	29100.00
0005432639075	2237	Economy	29100.00
0005432865935	2237	Economy	29100.00
0005432865911	2237	Economy	29100.00
0005432639086	2237	Economy	29100.00
0005432639087	2237	Economy	29100.00
0005433811628	24293	Business	105400.00
0005433811623	24293	Business	105400.00
0005433811626	24293	Economy	35100.00
0005433811622	24293	Economy	38600.00
0005433811629	24293	Economy	38600.00
0005433811632	24293	Economy	35100.00
0005433811630	24293	Economy	35100.00
0005433811621	24293	Economy	35100.00
0005433811631	24293	Economy	35100.00
0005433811627	24293	Economy	35100.00
0005433811625	24293	Economy	35100.00
0005433811624	24293	Economy	35100.00
0005434191257	9800	Economy	4400.00
0005434191252	9800	Economy	4400.00
0005434191256	9800	Economy	4400.00
0005434191253	9800	Economy	4400.00
0005434191251	9800	Economy	4400.00
0005434191269	32796	Economy	4400.00
0005434191267	32796	Economy	4400.00
0005434191266	32796	Economy	4400.00
0005434191270	32796	Economy	4400.00
0005434191264	32796	Economy	4400.00
0005434191273	32796	Economy	4400.00
0005434191272	32796	Economy	4400.00
0005434191265	32796	Economy	4400.00
0005434191268	32796	Economy	4400.00
0005434191263	32796	Economy	4400.00
0005434191262	32796	Economy	4400.00
0005434191271	32796	Economy	4400.00
0005432658556	26492	Business	92200.00
0005432658561	26492	Economy	30700.00
0005432665242	26492	Economy	33800.00
0005432658566	26492	Economy	30700.00
0005432665244	26492	Economy	30700.00
0005432665250	26492	Economy	30700.00
0005432665249	26492	Economy	30700.00
0005432665243	26492	Economy	30700.00
0005432658567	26492	Economy	30700.00
0005432658565	26492	Economy	30700.00
0005432665245	26492	Economy	30700.00
0005432665238	26492	Economy	30700.00
0005432665237	26492	Economy	30700.00
0005432665241	26492	Economy	30700.00
0005432665239	26492	Economy	30700.00
0005432665240	26492	Economy	30700.00
0005432658555	26492	Economy	30700.00
0005434504006	6538	Business	48400.00
0005434504002	6538	Business	48400.00
0005434504003	6538	Business	48400.00
0005434504001	6538	Business	48400.00
0005434503988	6538	Business	48400.00
0005434503995	6538	Business	48400.00
0005434503994	6538	Business	48400.00
0005434504014	6538	Business	48400.00
0005434503985	6538	Business	48400.00
0005434504004	6538	Business	48400.00
0005434504016	6538	Economy	16100.00
0005435103902	6538	Economy	16100.00
0005434503986	6538	Economy	16100.00
0005435103908	6538	Economy	17800.00
0005435103904	6538	Economy	17800.00
0005434504019	6538	Economy	16100.00
0005435103907	6538	Economy	16100.00
0005434504018	6538	Economy	16100.00
0005434503993	6538	Economy	16100.00
0005434504000	6538	Economy	16100.00
0005434504010	6538	Economy	16100.00
0005434504021	6538	Economy	16100.00
0005434504017	6538	Economy	16100.00
0005434503996	6538	Economy	16100.00
0005434503991	6538	Economy	16100.00
0005434504005	6538	Economy	16100.00
0005434503983	6538	Economy	16100.00
0005434503992	6538	Economy	16100.00
0005434503982	6538	Economy	16100.00
0005434504015	6538	Economy	16100.00
0005434503990	6538	Economy	16100.00
0005435103903	6538	Economy	16100.00
0005434504011	6538	Economy	16100.00
0005434503998	6538	Economy	16100.00
0005435103906	6538	Economy	16100.00
0005434503989	6538	Economy	16100.00
0005434503984	6538	Economy	16100.00
0005435103905	6538	Economy	16100.00
0005434503999	6538	Economy	16100.00
0005434503987	6538	Economy	16100.00
0005434504013	6538	Economy	16100.00
0005434503997	6538	Economy	16100.00
0005434504007	6538	Economy	16100.00
0005434504012	6538	Economy	16100.00
0005434504008	6538	Economy	16100.00
0005434504009	6538	Economy	16100.00
0005434504020	6538	Economy	16100.00
0005434503509	22685	Business	48400.00
0005434503652	22685	Business	48400.00
0005434503506	22685	Business	48400.00
0005434503581	22685	Business	48400.00
0005434503587	22685	Business	48400.00
0005434503593	22685	Business	48400.00
0005435103795	22685	Business	48400.00
0005434503523	22685	Business	48400.00
0005434503531	22685	Economy	16100.00
0005434503653	22685	Economy	16100.00
0005435103796	22685	Economy	16100.00
0005434503505	22685	Economy	16100.00
0005434503586	22685	Economy	16100.00
0005434503473	22685	Economy	16100.00
0005434503489	22685	Economy	16100.00
0005435103809	22685	Economy	16100.00
0005434503797	22685	Economy	16100.00
0005434503465	22685	Economy	16100.00
0005434503603	22685	Economy	16100.00
0005434503539	22685	Economy	16100.00
0005434503504	22685	Economy	16100.00
0005434503490	22685	Economy	16100.00
0005434503579	22685	Economy	16100.00
0005434503466	22685	Economy	16100.00
0005434503557	22685	Economy	16100.00
0005434503491	22685	Economy	16100.00
0005435103794	22685	Economy	16100.00
0005434503551	22685	Economy	16100.00
0005434503580	22685	Economy	16100.00
0005435103818	22685	Economy	16100.00
0005434503577	22685	Economy	16100.00
0005434503522	22685	Economy	16100.00
0005434503524	22685	Economy	16100.00
0005434503578	22685	Economy	16100.00
0005434503562	22685	Economy	16100.00
0005434503684	22685	Economy	16100.00
0005434503624	22685	Economy	16100.00
0005434503556	22685	Economy	16100.00
0005434503630	22685	Economy	16100.00
0005434503527	22685	Economy	16100.00
0005433367444	1681	Business	50000.00
0005433367637	1681	Business	50000.00
0005433367486	1681	Business	50000.00
0005433367343	1681	Business	50000.00
0005433367478	1681	Business	50000.00
0005435652900	1681	Business	50000.00
0005435652882	1681	Business	50000.00
0005433367334	1681	Business	50000.00
0005433367482	1681	Business	50000.00
0005433367524	1681	Business	50000.00
0005435652879	1681	Business	50000.00
0005433367435	1681	Business	50000.00
0005435652911	1681	Economy	16700.00
0005435652913	1681	Economy	16700.00
0005435652906	1681	Economy	16700.00
0005433367369	1681	Economy	16700.00
0005433367379	1681	Economy	16700.00
0005433367420	1681	Economy	16700.00
0005435652901	1681	Economy	16700.00
0005435652915	1681	Economy	18300.00
0005435652890	1681	Economy	18300.00
0005433367591	1681	Economy	18300.00
0005433367305	1681	Economy	18300.00
0005433367430	1681	Economy	18300.00
0005435652905	1681	Economy	16700.00
0005435652910	1681	Economy	16700.00
0005435652908	1681	Economy	16700.00
0005433367268	1681	Economy	16700.00
0005433367295	1681	Economy	16700.00
0005435652878	1681	Economy	16700.00
0005435652891	1681	Economy	16700.00
0005435652898	1681	Economy	16700.00
0005433367595	1681	Economy	16700.00
0005433367579	1681	Economy	16700.00
0005435652914	1681	Economy	16700.00
0005435652894	1681	Economy	16700.00
0005435652896	1681	Economy	16700.00
0005433367218	1681	Economy	16700.00
0005433367336	1681	Economy	16700.00
0005435652912	1681	Economy	16700.00
0005435652884	1681	Economy	16700.00
0005433367594	1681	Economy	16700.00
0005433367551	1681	Economy	16700.00
0005435652907	1681	Economy	16700.00
0005433367326	1681	Economy	16700.00
0005433367518	1681	Economy	16700.00
0005433367479	1681	Economy	16700.00
0005433367384	1681	Economy	16700.00
0005435652888	1681	Economy	16700.00
0005435652883	1681	Economy	16700.00
0005433367593	1681	Economy	16700.00
0005435652909	1681	Economy	16700.00
0005433367269	1681	Economy	16700.00
0005435652902	1681	Economy	16700.00
0005433367335	1681	Economy	16700.00
0005433367353	1681	Economy	16700.00
0005433367416	1681	Economy	16700.00
0005433367224	1681	Economy	16700.00
0005435652893	1681	Economy	16700.00
0005433367429	1681	Economy	16700.00
0005435652899	1681	Economy	16700.00
0005435652881	1681	Economy	16700.00
0005435652904	1681	Economy	16700.00
0005435652895	1681	Economy	16700.00
0005433367549	1681	Economy	16700.00
0005435652886	1681	Economy	16700.00
0005435652903	1681	Economy	16700.00
0005433367504	1681	Economy	16700.00
0005435652916	1681	Economy	16700.00
0005433367325	1681	Economy	16700.00
0005433367388	1681	Economy	16700.00
0005433367550	1681	Economy	16700.00
0005435652885	1681	Economy	16700.00
0005435652887	1681	Economy	16700.00
0005435652889	1681	Economy	16700.00
0005435652880	1681	Economy	16700.00
0005433367344	1681	Economy	16700.00
0005433367503	1681	Economy	16700.00
0005433367592	1681	Economy	16700.00
0005435652897	1681	Economy	16700.00
0005435652892	1681	Economy	16700.00
0005433367401	1681	Economy	16700.00
0005435652405	21680	Business	50000.00
0005435652344	21680	Business	50000.00
0005433367721	21680	Business	50000.00
0005433367725	21680	Business	50000.00
0005433367751	21680	Business	50000.00
0005433367731	21680	Business	50000.00
0005435652481	21680	Business	50000.00
0005433367737	21680	Business	50000.00
0005435652472	21680	Business	50000.00
0005435652434	21680	Economy	16700.00
0005433367722	21680	Economy	16700.00
0005435652399	21680	Economy	16700.00
0005433367732	21680	Economy	16700.00
0005433367717	21680	Economy	16700.00
0005435652292	21680	Economy	16700.00
0005435652300	21680	Economy	16700.00
0005435652411	21680	Economy	16700.00
0005435652412	21680	Economy	16700.00
0005435652403	21680	Economy	18300.00
0005433367741	21680	Economy	18300.00
0005433367733	21680	Economy	18300.00
0005433367728	21680	Economy	16700.00
0005435652397	21680	Economy	16700.00
0005435652450	21680	Economy	16700.00
0005435652376	21680	Economy	16700.00
0005435652460	21680	Economy	16700.00
0005433367730	21680	Economy	16700.00
0005435652299	21680	Economy	16700.00
0005435652467	21680	Economy	16700.00
0005435652436	21680	Economy	16700.00
0005435652398	21680	Economy	16700.00
0005435652449	21680	Economy	16700.00
0005433367747	21680	Economy	16700.00
0005433367745	21680	Economy	16700.00
0005433367734	21680	Economy	16700.00
0005433367718	21680	Economy	16700.00
0005435652353	21680	Economy	16700.00
0005435652437	21680	Economy	16700.00
0005433367736	21680	Economy	16700.00
0005433367726	21680	Economy	16700.00
0005435652305	21680	Economy	16700.00
0005433367752	21680	Economy	16700.00
0005433367755	21680	Economy	16700.00
0005435652442	21680	Economy	16700.00
0005433367743	21680	Economy	16700.00
0005435652339	21680	Economy	16700.00
0005433367723	21680	Economy	16700.00
0005435652320	21680	Economy	16700.00
0005435652366	21680	Economy	16700.00
0005433367740	21680	Economy	16700.00
0005435652367	21680	Economy	16700.00
0005435652325	21680	Economy	16700.00
0005435652470	21680	Economy	16700.00
0005435652404	21680	Economy	16700.00
0005433367742	21680	Economy	16700.00
0005433367719	21680	Economy	16700.00
0005435652482	21680	Economy	16700.00
0005433367753	21680	Economy	16700.00
0005435652473	21680	Economy	16700.00
0005435652301	21680	Economy	16700.00
0005433367729	21680	Economy	16700.00
0005433367748	21680	Economy	16700.00
0005435652338	21680	Economy	16700.00
0005435652401	21680	Economy	16700.00
0005433367738	21680	Economy	16700.00
0005433367727	21680	Economy	16700.00
0005433367744	21680	Economy	16700.00
0005433367749	21680	Economy	16700.00
0005433367750	21680	Economy	16700.00
0005435652324	21680	Economy	16700.00
0005433367735	21680	Economy	16700.00
0005433367754	21680	Economy	16700.00
0005435652417	21680	Economy	16700.00
0005435652375	21680	Economy	16700.00
0005433367739	21680	Economy	16700.00
0005433367746	21680	Economy	16700.00
0005433367724	21680	Economy	16700.00
0005433367720	21680	Economy	16700.00
0005434466399	23233	Economy	20900.00
0005434466398	23233	Economy	20900.00
0005435312798	23233	Economy	20900.00
0005434466421	23233	Economy	20900.00
0005434466397	23233	Economy	20900.00
0005434466393	23233	Economy	20900.00
0005434466404	23233	Economy	20900.00
0005435312796	23233	Economy	20900.00
0005434466388	23233	Economy	20900.00
0005434466400	23233	Economy	20900.00
0005435312795	23233	Economy	20900.00
0005435312794	23233	Economy	20900.00
0005434466396	23233	Economy	20900.00
0005435312797	23233	Economy	20900.00
0005434466384	23233	Economy	20900.00
0005433985747	4144	Business	21500.00
0005433985751	4144	Business	21500.00
0005433985780	4144	Business	21500.00
0005433985772	4144	Business	21500.00
0005433985745	4144	Business	21500.00
0005435788762	4144	Business	21500.00
0005433985754	4144	Business	21500.00
0005433985777	4144	Business	21500.00
0005433985752	4144	Business	21500.00
0005433985769	4144	Economy	7200.00
0005433985763	4144	Economy	7200.00
0005433985790	4144	Economy	7200.00
0005433985776	4144	Economy	7200.00
0005433985771	4144	Economy	7200.00
0005433985746	4144	Economy	7200.00
0005433985787	4144	Economy	7900.00
0005433985755	4144	Economy	7900.00
0005433985779	4144	Economy	7900.00
0005433985767	4144	Economy	7900.00
0005433985770	4144	Economy	7200.00
0005433985741	4144	Economy	7200.00
0005433985760	4144	Economy	7200.00
0005433985743	4144	Economy	7200.00
0005433985782	4144	Economy	7200.00
0005433985740	4144	Economy	7200.00
0005433985773	4144	Economy	7200.00
0005435788760	4144	Economy	7200.00
0005433985742	4144	Economy	7200.00
0005435788761	4144	Economy	7200.00
0005433985750	4144	Economy	7200.00
0005433985774	4144	Economy	7200.00
0005433985784	4144	Economy	7200.00
0005433985744	4144	Economy	7200.00
0005433985788	4144	Economy	7200.00
0005433985765	4144	Economy	7200.00
0005433985739	4144	Economy	7200.00
0005433985758	4144	Economy	7200.00
0005433985785	4144	Economy	7200.00
0005433985748	4144	Economy	7200.00
0005433985768	4144	Economy	7200.00
0005433985753	4144	Economy	7200.00
0005433985775	4144	Economy	7200.00
0005433985783	4144	Economy	7200.00
0005433985789	4144	Economy	7200.00
0005433985756	4144	Economy	7200.00
0005433985778	4144	Economy	7200.00
0005433985759	4144	Economy	7200.00
0005433985766	4144	Economy	7200.00
0005433985762	4144	Economy	7200.00
0005433985786	4144	Economy	7200.00
0005433985757	4144	Economy	7200.00
0005433985749	4144	Economy	7200.00
0005433985781	4144	Economy	7200.00
0005433985761	4144	Economy	7200.00
0005433985764	4144	Economy	7200.00
0005433985245	25664	Business	21500.00
0005433985296	25664	Business	21500.00
0005433985173	25664	Business	21500.00
0005433985434	25664	Business	21500.00
0005433985217	25664	Business	21500.00
0005433985336	25664	Business	21500.00
0005433985256	25664	Business	21500.00
0005433985306	25664	Economy	7200.00
0005433985337	25664	Economy	7200.00
0005433985280	25664	Economy	7200.00
0005433985449	25664	Economy	7200.00
0005433985236	25664	Economy	7200.00
0005433985207	25664	Economy	7200.00
0005433985302	25664	Economy	7900.00
0005433985348	25664	Economy	7200.00
0005435788750	25664	Economy	7200.00
0005433985275	25664	Economy	7200.00
0005433985529	25664	Economy	7200.00
0005433985301	25664	Economy	7200.00
0005433985208	25664	Economy	7200.00
0005433985376	25664	Economy	7200.00
0005433985497	25664	Economy	7200.00
0005433985317	25664	Economy	7200.00
0005433985364	25664	Economy	7200.00
0005433985312	25664	Economy	7200.00
0005433985329	25664	Economy	7200.00
0005433985258	25664	Economy	7200.00
0005435788751	25664	Economy	7200.00
0005433985365	25664	Economy	7200.00
0005433985316	25664	Economy	7200.00
0005433985286	25664	Economy	7200.00
0005433985514	25664	Economy	7200.00
0005433985168	25664	Economy	7200.00
0005433985300	25664	Economy	7200.00
0005433985169	25664	Economy	7200.00
0005433985297	25664	Economy	7200.00
0005435788748	25664	Economy	7200.00
0005433985137	25664	Economy	7200.00
0005433985257	25664	Economy	7200.00
0005433985172	25664	Economy	7200.00
0005433985188	25664	Economy	7200.00
0005433985343	25664	Economy	7200.00
0005433985259	25664	Economy	7200.00
0005433985189	25664	Economy	7200.00
0005433985260	25664	Economy	7200.00
0005433985505	25664	Economy	7200.00
0005435720811	21284	Economy	9400.00
0005435720812	21284	Economy	9400.00
0005435719551	21284	Economy	9400.00
0005435719550	21284	Economy	9400.00
0005434509114	1637	Economy	17000.00
0005434509113	1637	Economy	15500.00
0005434509112	1637	Economy	15500.00
0005433168331	1637	Economy	15500.00
0005434509123	1637	Economy	15500.00
0005433168330	1637	Economy	15500.00
0005433168324	1637	Economy	15500.00
0005433168319	1637	Economy	15500.00
0005434509117	1637	Economy	15500.00
0005433168328	1637	Economy	15500.00
0005434509118	1637	Economy	15500.00
0005434509108	1637	Economy	15500.00
0005434509115	1637	Economy	15500.00
0005434509122	1637	Economy	15500.00
0005434509120	1637	Economy	15500.00
0005434509110	1637	Economy	15500.00
0005434509116	1637	Economy	15500.00
0005434509119	1637	Economy	15500.00
0005434509109	1637	Economy	15500.00
0005434509121	1637	Economy	15500.00
0005433168323	1637	Economy	15500.00
0005433168333	1637	Economy	15500.00
0005433168316	1637	Economy	15500.00
0005434509111	1637	Economy	15500.00
0005434516071	9020	Economy	23600.00
0005434190380	9020	Economy	23600.00
0005434190371	9020	Economy	23600.00
0005434190369	9020	Economy	23600.00
0005434516070	9020	Economy	23600.00
0005434516069	9020	Economy	23600.00
0005434190376	9020	Economy	23600.00
0005434516067	9020	Economy	23600.00
0005434516072	9020	Economy	23600.00
0005434516068	9020	Economy	23600.00
0005434190373	9020	Economy	23600.00
0005434516073	9020	Economy	23600.00
0005434190370	9020	Economy	23600.00
0005434151693	17864	Business	18000.00
0005432659673	17864	Business	18000.00
0005432655374	17864	Business	18000.00
0005432869504	17864	Business	18000.00
0005432667423	17864	Business	18000.00
0005432655355	17864	Economy	6000.00
0005432659680	17864	Economy	6000.00
0005432657422	17864	Economy	6000.00
0005432660792	17864	Economy	6000.00
0005432659675	17864	Economy	6000.00
0005432655356	17864	Economy	6600.00
0005432660791	17864	Economy	6600.00
0005432655349	17864	Economy	6600.00
0005432667425	17864	Economy	6000.00
0005432869505	17864	Economy	6000.00
0005432657405	17864	Economy	6000.00
0005432659676	17864	Economy	6000.00
0005432655389	17864	Economy	6000.00
0005432657408	17864	Economy	6000.00
0005432658568	17864	Economy	6000.00
0005432659681	17864	Economy	6000.00
0005432869499	17864	Economy	6000.00
0005434151694	17864	Economy	6000.00
0005432660785	17864	Economy	6000.00
0005432655381	17864	Economy	6000.00
0005432655395	17864	Economy	6000.00
0005432655379	17864	Economy	6000.00
0005432869500	17864	Economy	6000.00
0005434151695	17864	Economy	6000.00
0005432660784	17864	Economy	6000.00
0005432869503	17864	Economy	6000.00
0005432657406	17864	Economy	6000.00
0005432667424	17864	Economy	6000.00
0005432869506	17864	Economy	6000.00
0005434151697	17864	Economy	6000.00
0005432869501	17864	Economy	6000.00
0005434151696	17864	Economy	6000.00
0005432869502	17864	Economy	6000.00
0005432658580	26303	Business	18000.00
0005432655465	26303	Business	18000.00
0005432655468	26303	Business	18000.00
0005432655464	26303	Business	18000.00
0005432655469	26303	Economy	6000.00
0005432659694	26303	Economy	6000.00
0005432658581	26303	Economy	6000.00
0005432869422	26303	Economy	6600.00
0005432660807	26303	Economy	6000.00
0005432869433	26303	Economy	6000.00
0005432655467	26303	Economy	6000.00
0005432655466	26303	Economy	6000.00
0005432657433	26303	Economy	6000.00
0005432667442	26303	Economy	6000.00
0005432869413	26303	Economy	6000.00
0005432666377	26303	Economy	6000.00
0005432655461	26303	Economy	6000.00
0005432666378	26303	Economy	6000.00
0005432655463	26303	Economy	6000.00
0005432655460	26303	Economy	6000.00
0005434151664	26303	Economy	6000.00
0005432657432	26303	Economy	6000.00
0005432665263	26303	Economy	6000.00
0005432655471	26303	Economy	6000.00
0005434151678	26303	Economy	6000.00
0005432659695	26303	Economy	6000.00
0005434151665	26303	Economy	6000.00
0005432660806	26303	Economy	6000.00
0005432655470	26303	Economy	6000.00
0005432665264	26303	Economy	6000.00
0005432869423	26303	Economy	6000.00
0005432667443	26303	Economy	6000.00
0005432657434	26303	Economy	6000.00
0005432659696	26303	Economy	6000.00
0005432658579	26303	Economy	6000.00
0005432655462	26303	Economy	6000.00
0005432865983	25052	Business	87300.00
0005432865981	25052	Business	87300.00
0005432865987	25052	Business	87300.00
0005432638955	25052	Business	87300.00
0005432865993	25052	Economy	29100.00
0005432865986	25052	Economy	29100.00
0005432638959	25052	Economy	29100.00
0005432865989	25052	Economy	29100.00
0005432638961	25052	Economy	29100.00
0005432638968	25052	Economy	29100.00
0005432865982	25052	Economy	29100.00
0005432638990	25052	Economy	29100.00
0005432638972	25052	Economy	29100.00
0005432865985	25052	Economy	29100.00
0005432865991	25052	Economy	29100.00
0005432638956	25052	Economy	29100.00
0005432638953	25052	Economy	29100.00
0005432865984	25052	Economy	29100.00
0005432638992	25052	Economy	29100.00
0005432865990	25052	Economy	29100.00
0005432865992	25052	Economy	29100.00
0005432638943	25052	Economy	29100.00
0005432638979	25052	Economy	29100.00
0005432638957	25052	Economy	29100.00
0005432639002	25052	Economy	29100.00
0005432638958	25052	Economy	29100.00
0005432638930	25052	Economy	29100.00
0005432639020	25052	Economy	29100.00
0005432865988	25052	Economy	29100.00
0005432638954	25052	Economy	29100.00
0005432638944	25052	Economy	29100.00
0005432328531	3078	Business	16100.00
0005432328547	3078	Business	16100.00
0005432905073	3078	Business	16100.00
0005432328517	3078	Business	16100.00
0005432328546	3078	Business	16100.00
0005432287168	3078	Business	16100.00
0005432328524	3078	Business	16100.00
0005432328525	3078	Business	16100.00
0005432905039	3078	Business	16100.00
0005432328522	3078	Economy	5400.00
0005432328507	3078	Economy	5400.00
0005432328540	3078	Economy	5400.00
0005432328504	3078	Economy	5400.00
0005432905065	3078	Economy	5400.00
0005432905096	3078	Economy	5400.00
0005432328520	3078	Economy	5400.00
0005432905037	3078	Economy	5400.00
0005432328538	3078	Economy	5400.00
0005432328534	3078	Economy	5900.00
0005432328503	3078	Economy	5900.00
0005432287169	3078	Economy	5900.00
0005432328509	3078	Economy	5900.00
0005432328530	3078	Economy	5400.00
0005432328511	3078	Economy	5400.00
0005432328518	3078	Economy	5400.00
0005432328527	3078	Economy	5400.00
0005432328521	3078	Economy	5400.00
0005432328528	3078	Economy	5400.00
0005432328549	3078	Economy	5400.00
0005432905038	3078	Economy	5400.00
0005432328506	3078	Economy	5400.00
0005432328548	3078	Economy	5400.00
0005432328510	3078	Economy	5400.00
0005432905067	3078	Economy	5400.00
0005432328508	3078	Economy	5400.00
0005432328505	3078	Economy	5400.00
0005432328502	3078	Economy	5400.00
0005432328535	3078	Economy	5400.00
0005432328537	3078	Economy	5400.00
0005432905064	3078	Economy	5400.00
0005432328523	3078	Economy	5400.00
0005432328533	3078	Economy	5400.00
0005432328514	3078	Economy	5400.00
0005432905049	3078	Economy	5400.00
0005432328512	3078	Economy	5400.00
0005432328529	3078	Economy	5400.00
0005432287171	3078	Economy	5400.00
0005433438848	3078	Economy	5400.00
0005432905060	3078	Economy	5400.00
0005432328519	3078	Economy	5400.00
0005432328544	3078	Economy	5400.00
0005432328542	3078	Economy	5400.00
0005432328513	3078	Economy	5400.00
0005432328543	3078	Economy	5400.00
0005432328526	3078	Economy	5400.00
0005432905095	3078	Economy	5400.00
0005432328515	3078	Economy	5400.00
0005432328536	3078	Economy	5400.00
0005432328539	3078	Economy	5400.00
0005432328545	3078	Economy	5400.00
0005432287170	3078	Economy	5400.00
0005432328532	3078	Economy	5400.00
0005432328541	3078	Economy	5400.00
0005432328516	3078	Economy	5400.00
0005432328501	3078	Economy	5400.00
0005432905066	3078	Economy	5400.00
0005432328107	31146	Business	16100.00
0005432327908	31146	Business	16100.00
0005432328070	31146	Business	16100.00
0005432328031	31146	Business	16100.00
0005432328116	31146	Business	16100.00
0005432328062	31146	Business	16100.00
0005432328165	31146	Business	16100.00
0005432905104	31146	Business	16100.00
0005433438787	31146	Economy	5400.00
0005432328106	31146	Economy	5400.00
0005432327994	31146	Economy	5400.00
0005432328030	31146	Economy	5400.00
0005432328191	31146	Economy	5900.00
0005432328040	31146	Economy	5900.00
0005432327993	31146	Economy	5900.00
0005432328118	31146	Economy	5900.00
0005432328271	31146	Economy	5400.00
0005432328001	31146	Economy	5400.00
0005432328108	31146	Economy	5400.00
0005432328091	31146	Economy	5400.00
0005432328298	31146	Economy	5400.00
0005432328202	31146	Economy	5400.00
0005432905107	31146	Economy	5400.00
0005433438788	31146	Economy	5400.00
0005432327990	31146	Economy	5400.00
0005432328183	31146	Economy	5400.00
0005432328100	31146	Economy	5400.00
0005432328019	31146	Economy	5400.00
0005433438778	31146	Economy	5400.00
0005432327904	31146	Economy	5400.00
0005432327940	31146	Economy	5400.00
0005432905108	31146	Economy	5400.00
0005432328164	31146	Economy	5400.00
0005432054293	31146	Economy	5400.00
0005432327933	31146	Economy	5400.00
0005432328101	31146	Economy	5400.00
0005432328294	31146	Economy	5400.00
0005432328210	31146	Economy	5400.00
0005433438803	31146	Economy	5400.00
0005432328105	31146	Economy	5400.00
0005432328092	31146	Economy	5400.00
0005432328212	31146	Economy	5400.00
0005432328153	31146	Economy	5400.00
0005432327941	31146	Economy	5400.00
0005432328018	31146	Economy	5400.00
0005433438776	31146	Economy	5400.00
0005432328299	31146	Economy	5400.00
0005432054292	31146	Economy	5400.00
0005432328247	31146	Economy	5400.00
0005432328192	31146	Economy	5400.00
0005432327932	31146	Economy	5400.00
0005432328154	31146	Economy	5400.00
0005432328331	31146	Economy	5400.00
0005432328238	31146	Economy	5400.00
0005432328010	31146	Economy	5400.00
0005432328029	31146	Economy	5400.00
0005432327998	31146	Economy	5400.00
0005432327939	31146	Economy	5400.00
0005433438777	31146	Economy	5400.00
0005432328078	31146	Economy	5400.00
0005432328015	31146	Economy	5400.00
0005432327907	31146	Economy	5400.00
0005432905106	31146	Economy	5400.00
0005432327950	31146	Economy	5400.00
0005433438802	31146	Economy	5400.00
0005432905105	31146	Economy	5400.00
0005432327909	31146	Economy	5400.00
0005432328039	31146	Economy	5400.00
0005432328063	31146	Economy	5400.00
0005434309689	6211	Business	124600.00
0005435999192	6211	Business	124600.00
0005432146191	6211	Business	124600.00
0005434309695	6211	Business	124600.00
0005435487566	6211	Business	124600.00
0005435487519	6211	Economy	41500.00
0005435999186	6211	Economy	41500.00
0005435999188	6211	Economy	41500.00
0005435296972	6211	Economy	41500.00
0005435487473	6211	Economy	41500.00
0005435487606	6211	Economy	41500.00
0005434309686	6211	Economy	41500.00
0005435999184	6211	Economy	41500.00
0005434309690	6211	Economy	41500.00
0005435999189	6211	Economy	41500.00
0005435999195	6211	Economy	41500.00
0005435999190	6211	Economy	41500.00
0005435487518	6211	Economy	41500.00
0005435296980	6211	Economy	41500.00
0005435999187	6211	Economy	41500.00
0005435296943	6211	Economy	41500.00
0005435296976	6211	Economy	45700.00
0005435487614	6211	Economy	45700.00
0005435296987	6211	Economy	45700.00
0005435999193	6211	Economy	41500.00
0005434309693	6211	Economy	41500.00
0005435487583	6211	Economy	41500.00
0005434309683	6211	Economy	41500.00
0005435297000	6211	Economy	41500.00
0005434309684	6211	Economy	41500.00
0005435487607	6211	Economy	41500.00
0005435999194	6211	Economy	41500.00
0005435487608	6211	Economy	41500.00
0005435487474	6211	Economy	41500.00
0005434309685	6211	Economy	41500.00
0005435487562	6211	Economy	41500.00
0005434309688	6211	Economy	41500.00
0005435999183	6211	Economy	41500.00
0005435487613	6211	Economy	41500.00
0005434309691	6211	Economy	41500.00
0005435487517	6211	Economy	41500.00
0005435487595	6211	Economy	41500.00
0005435999182	6211	Economy	41500.00
0005435487567	6211	Economy	41500.00
0005434309694	6211	Economy	41500.00
0005435487481	6211	Economy	41500.00
0005435999185	6211	Economy	41500.00
0005435296984	6211	Economy	41500.00
0005435999191	6211	Economy	41500.00
0005435487596	6211	Economy	41500.00
0005435487638	6211	Economy	41500.00
0005435487553	6211	Economy	41500.00
0005434309687	6211	Economy	41500.00
0005435487530	6211	Economy	41500.00
0005434309692	6211	Economy	41500.00
0005435487551	6211	Economy	41500.00
0005435296958	6211	Economy	41500.00
0005434309514	19549	Business	124600.00
0005435487727	19549	Business	124600.00
0005435487723	19549	Business	124600.00
0005435487734	19549	Business	124600.00
0005434309597	19549	Economy	41500.00
0005435487720	19549	Economy	41500.00
0005434309590	19549	Economy	41500.00
0005435487733	19549	Economy	41500.00
0005435487728	19549	Economy	41500.00
0005435487739	19549	Economy	41500.00
0005435999014	19549	Economy	41500.00
0005435487719	19549	Economy	41500.00
0005435487738	19549	Economy	41500.00
0005435998975	19549	Economy	41500.00
0005435998999	19549	Economy	41500.00
0005435487736	19549	Economy	41500.00
0005435297034	19549	Economy	45700.00
0005435487731	19549	Economy	45700.00
0005435999025	19549	Economy	41500.00
0005435998989	19549	Economy	41500.00
0005435487729	19549	Economy	41500.00
0005435297029	19549	Economy	41500.00
0005435487722	19549	Economy	41500.00
0005435487730	19549	Economy	41500.00
0005435297031	19549	Economy	41500.00
0005435297033	19549	Economy	41500.00
0005435998990	19549	Economy	41500.00
0005435999035	19549	Economy	41500.00
0005435999042	19549	Economy	41500.00
0005434309559	19549	Economy	41500.00
0005435998968	19549	Economy	41500.00
0005434309516	19549	Economy	41500.00
0005435297032	19549	Economy	41500.00
0005435487735	19549	Economy	41500.00
0005435487721	19549	Economy	41500.00
0005435297030	19549	Economy	41500.00
0005435487726	19549	Economy	41500.00
0005435999026	19549	Economy	41500.00
0005435999040	19549	Economy	41500.00
0005435487740	19549	Economy	41500.00
0005434309558	19549	Economy	41500.00
0005435297035	19549	Economy	41500.00
0005435487725	19549	Economy	41500.00
0005435487737	19549	Economy	41500.00
0005434309593	19549	Economy	41500.00
0005435487732	19549	Economy	41500.00
0005434309515	19549	Economy	41500.00
0005435487724	19549	Economy	41500.00
0005434565868	1555	Business	86000.00
0005435508313	1555	Business	86000.00
0005433186031	1555	Business	86000.00
0005435517851	1555	Business	86000.00
0005435502222	1555	Business	86000.00
0005435502220	1555	Business	86000.00
0005435508312	1555	Business	86000.00
0005435517847	1555	Business	86000.00
0005434565861	1555	Business	86000.00
0005435502233	1555	Business	86000.00
0005435502241	1555	Business	86000.00
0005434565869	1555	Economy	28700.00
0005435508320	1555	Economy	28700.00
0005433185994	1555	Economy	28700.00
0005433186030	1555	Economy	28700.00
0005435517838	1555	Economy	28700.00
0005433186021	1555	Economy	28700.00
0005435508317	1555	Economy	28700.00
0005435502242	1555	Economy	31500.00
0005435517842	1555	Economy	31500.00
0005433186009	1555	Economy	31500.00
0005435517840	1555	Economy	31500.00
0005434565860	1555	Economy	28700.00
0005435502223	1555	Economy	28700.00
0005435502224	1555	Economy	28700.00
0005433185997	1555	Economy	28700.00
0005435502226	1555	Economy	28700.00
0005433186016	1555	Economy	28700.00
0005434565867	1555	Economy	28700.00
0005435508309	1555	Economy	28700.00
0005435508321	1555	Economy	28700.00
0005435517849	1555	Economy	28700.00
0005434565862	1555	Economy	28700.00
0005435502237	1555	Economy	28700.00
0005434565865	1555	Economy	28700.00
0005435502240	1555	Economy	28700.00
0005435517839	1555	Economy	28700.00
0005435508311	1555	Economy	28700.00
0005435502234	1555	Economy	28700.00
0005434565857	1555	Economy	28700.00
0005435517844	1555	Economy	28700.00
0005435502239	1555	Economy	28700.00
0005433185996	1555	Economy	28700.00
0005435502229	1555	Economy	28700.00
0005435508316	1555	Economy	28700.00
0005435502221	1555	Economy	28700.00
0005435517843	1555	Economy	28700.00
0005435517841	1555	Economy	28700.00
0005435508314	1555	Economy	28700.00
0005435502235	1555	Economy	28700.00
0005435508322	1555	Economy	28700.00
0005435517850	1555	Economy	28700.00
0005435502236	1555	Economy	28700.00
0005434565866	1555	Economy	28700.00
0005434565864	1555	Economy	28700.00
0005433185993	1555	Economy	28700.00
0005435508318	1555	Economy	28700.00
0005434565870	1555	Economy	28700.00
0005434565859	1555	Economy	28700.00
0005435508310	1555	Economy	28700.00
0005435502230	1555	Economy	28700.00
0005435502219	1555	Economy	28700.00
0005434565858	1555	Economy	28700.00
0005435508315	1555	Economy	28700.00
0005435502231	1555	Economy	28700.00
0005433185986	1555	Economy	28700.00
0005435502238	1555	Economy	28700.00
0005435517837	1555	Economy	28700.00
0005435502225	1555	Economy	28700.00
0005434565856	1555	Economy	28700.00
0005435517848	1555	Economy	28700.00
0005435517846	1555	Economy	28700.00
0005435502232	1555	Economy	28700.00
0005433185985	1555	Economy	28700.00
0005435502227	1555	Economy	28700.00
0005432291921	1555	Economy	28700.00
0005435508319	1555	Economy	28700.00
0005435502228	1555	Economy	28700.00
0005434565863	1555	Economy	28700.00
0005435517845	1555	Economy	28700.00
0005434565786	20845	Business	86000.00
0005434565743	20845	Business	86000.00
0005435528966	20845	Business	86000.00
0005435502063	20845	Business	86000.00
0005434565746	20845	Business	86000.00
0005435501973	20845	Business	86000.00
0005435502067	20845	Business	86000.00
0005435545628	20845	Business	86000.00
0005435502100	20845	Business	86000.00
0005435528995	20845	Business	86000.00
0005435502101	20845	Business	86000.00
0005435502018	20845	Business	86000.00
0005433186088	20845	Economy	28700.00
0005434565763	20845	Economy	28700.00
0005435502040	20845	Economy	28700.00
0005435528959	20845	Economy	28700.00
0005435528889	20845	Economy	28700.00
0005433186089	20845	Economy	28700.00
0005435528994	20845	Economy	28700.00
0005434565770	20845	Economy	28700.00
0005435528965	20845	Economy	28700.00
0005435502021	20845	Economy	31500.00
0005433186085	20845	Economy	31500.00
0005433186083	20845	Economy	28700.00
0005435528958	20845	Economy	28700.00
0005435545625	20845	Economy	28700.00
0005435502028	20845	Economy	28700.00
0005435528892	20845	Economy	28700.00
0005435501992	20845	Economy	28700.00
0005435502036	20845	Economy	28700.00
0005435545629	20845	Economy	28700.00
0005435528991	20845	Economy	28700.00
0005434565783	20845	Economy	28700.00
0005435502102	20845	Economy	28700.00
0005435545649	20845	Economy	28700.00
0005434565695	20845	Economy	28700.00
0005435529076	20845	Economy	28700.00
0005435528933	20845	Economy	28700.00
0005435528941	20845	Economy	28700.00
0005433186086	20845	Economy	28700.00
0005435528981	20845	Economy	28700.00
0005435528967	20845	Economy	28700.00
0005435502093	20845	Economy	28700.00
0005435528880	20845	Economy	28700.00
0005435501961	20845	Economy	28700.00
0005435502037	20845	Economy	28700.00
0005435502059	20845	Economy	28700.00
0005435528973	20845	Economy	28700.00
0005434565703	20845	Economy	28700.00
0005433186084	20845	Economy	28700.00
0005435502062	20845	Economy	28700.00
0005435502041	20845	Economy	28700.00
0005434565744	20845	Economy	28700.00
0005435501950	20845	Economy	28700.00
0005435529077	20845	Economy	28700.00
0005435545630	20845	Economy	28700.00
0005435545648	20845	Economy	28700.00
0005435501984	20845	Economy	28700.00
0005435501972	20845	Economy	28700.00
0005434565753	20845	Economy	28700.00
0005434565747	20845	Economy	28700.00
0005435501960	20845	Economy	28700.00
0005435502052	20845	Economy	28700.00
0005435502034	20845	Economy	28700.00
0005433186082	20845	Economy	28700.00
0005435528879	20845	Economy	28700.00
0005434565785	20845	Economy	28700.00
0005435501974	20845	Economy	28700.00
0005433186087	20845	Economy	28700.00
0005435502060	20845	Economy	28700.00
0005434565787	20845	Economy	28700.00
0005435501962	20845	Economy	28700.00
0005435502053	20845	Economy	28700.00
0005435528972	20845	Economy	28700.00
0005434565784	20845	Economy	28700.00
0005435153718	3911	Economy	21600.00
0005435153721	3911	Economy	19700.00
0005435153713	3911	Economy	19700.00
0005435153720	3911	Economy	19700.00
0005435153719	3911	Economy	19700.00
0005435153717	3911	Economy	19700.00
0005435153714	3911	Economy	19700.00
0005435153716	3911	Economy	19700.00
0005435153722	3911	Economy	19700.00
0005435153715	3911	Economy	19700.00
0005435931586	21861	Economy	19700.00
0005435153640	21861	Economy	19700.00
0005435153662	21861	Economy	19700.00
0005435931587	21861	Economy	19700.00
0005435153663	21861	Economy	19700.00
0005435153668	21861	Economy	19700.00
0005435931588	21861	Economy	19700.00
0005432628789	7200	Economy	14300.00
0005435225496	7200	Economy	13000.00
0005432628786	7200	Economy	13000.00
0005432628793	7200	Economy	13000.00
0005432628783	7200	Economy	13000.00
0005432628794	7200	Economy	13000.00
0005432628787	7200	Economy	13000.00
0005435225487	7200	Economy	13000.00
0005432628788	7200	Economy	13000.00
0005435225472	7200	Economy	13000.00
0005432628784	7200	Economy	13000.00
0005432628785	7200	Economy	13000.00
0005432628795	7200	Economy	13000.00
0005435225471	7200	Economy	13000.00
0005432628792	7200	Economy	13000.00
0005432628791	7200	Economy	13000.00
0005435225470	7200	Economy	13000.00
0005435225480	7200	Economy	13000.00
0005432628790	7200	Economy	13000.00
0005432628797	7200	Economy	13000.00
0005435225511	7200	Economy	13000.00
0005435225481	7200	Economy	13000.00
0005432628782	7200	Economy	13000.00
0005432628796	7200	Economy	13000.00
0005432628677	28129	Economy	14300.00
0005432628698	28129	Economy	14300.00
0005432628665	28129	Economy	13000.00
0005435225555	28129	Economy	13000.00
0005432628632	28129	Economy	13000.00
0005435225554	28129	Economy	13000.00
0005432628646	28129	Economy	13000.00
0005435225550	28129	Economy	13000.00
0005432628699	28129	Economy	13000.00
0005435225557	28129	Economy	13000.00
0005432628715	28129	Economy	13000.00
0005435225552	28129	Economy	13000.00
0005432628645	28129	Economy	13000.00
0005432628643	28129	Economy	13000.00
0005435225551	28129	Economy	13000.00
0005432628701	28129	Economy	13000.00
0005435225556	28129	Economy	13000.00
0005432628642	28129	Economy	13000.00
0005432628655	28129	Economy	13000.00
0005435225553	28129	Economy	13000.00
0005432628631	28129	Economy	13000.00
0005435225558	28129	Economy	13000.00
0005432628666	28129	Economy	13000.00
0005432628623	28129	Economy	13000.00
0005432628747	28129	Economy	13000.00
0005432628678	28129	Economy	13000.00
0005432628600	28129	Economy	13000.00
0005432628697	28129	Economy	13000.00
0005435960036	8715	Economy	10500.00
0005435960035	8715	Economy	10500.00
0005435960034	8715	Economy	10500.00
0005434267933	15219	Economy	11500.00
0005434267936	15219	Economy	10500.00
0005434267934	15219	Economy	10500.00
0005434267935	15219	Economy	10500.00
0005435960006	15219	Economy	10500.00
0005435959983	15219	Economy	10500.00
0005435960002	15219	Economy	10500.00
0005435960021	15219	Economy	10500.00
0005432692928	1209	Business	115000.00
0005432692931	1209	Business	115000.00
0005432692915	1209	Business	115000.00
0005432873181	1209	Business	115000.00
0005432692925	1209	Business	115000.00
0005432692922	1209	Business	115000.00
0005432692911	1209	Business	115000.00
0005432675077	1209	Business	115000.00
0005432677553	1209	Business	115000.00
0005432692929	1209	Business	115000.00
0005432675079	1209	Business	115000.00
0005432692914	1209	Business	115000.00
0005432675078	1209	Business	115000.00
0005432677552	1209	Economy	38300.00
0005432873218	1209	Economy	38300.00
0005432692908	1209	Economy	38300.00
0005432873196	1209	Economy	38300.00
0005432873200	1209	Economy	38300.00
0005432692921	1209	Economy	38300.00
0005432675065	1209	Economy	38300.00
0005432692906	1209	Economy	38300.00
0005432677555	1209	Economy	38300.00
0005432873212	1209	Economy	38300.00
0005432692909	1209	Economy	38300.00
0005432675064	1209	Economy	38300.00
0005432692910	1209	Economy	38300.00
0005432675069	1209	Economy	38300.00
0005432675075	1209	Economy	38300.00
0005432692919	1209	Economy	38300.00
0005432873187	1209	Economy	38300.00
0005432692917	1209	Economy	38300.00
0005432692934	1209	Economy	38300.00
0005432692924	1209	Economy	38300.00
0005432692935	1209	Economy	38300.00
0005432675074	1209	Economy	38300.00
0005432692933	1209	Economy	38300.00
0005432692936	1209	Economy	38300.00
0005432675072	1209	Economy	38300.00
0005432677554	1209	Economy	38300.00
0005432692916	1209	Economy	38300.00
0005432692927	1209	Economy	38300.00
0005432692918	1209	Economy	38300.00
0005432692920	1209	Economy	38300.00
0005432692907	1209	Economy	38300.00
0005432692926	1209	Economy	38300.00
0005432692930	1209	Economy	38300.00
0005432675067	1209	Economy	38300.00
0005432675070	1209	Economy	38300.00
0005432675071	1209	Economy	38300.00
0005432873204	1209	Economy	38300.00
0005432873206	1209	Economy	38300.00
0005432675073	1209	Economy	38300.00
0005432692923	1209	Economy	38300.00
0005432675066	1209	Economy	38300.00
0005432692913	1209	Economy	38300.00
0005432873182	1209	Economy	38300.00
0005432675076	1209	Economy	38300.00
0005432675068	1209	Economy	38300.00
0005432873217	1209	Economy	38300.00
0005432692912	1209	Economy	38300.00
0005432692932	1209	Economy	38300.00
0005432692657	17468	Business	115000.00
0005432674926	17468	Business	115000.00
0005432692611	17468	Business	115000.00
0005432692543	17468	Business	115000.00
0005432674907	17468	Business	115000.00
0005432674933	17468	Business	115000.00
0005432692609	17468	Business	115000.00
0005432674906	17468	Business	115000.00
0005432692709	17468	Business	115000.00
0005432692617	17468	Business	115000.00
0005432692745	17468	Business	115000.00
0005432674962	17468	Business	115000.00
0005432674990	17468	Business	115000.00
0005432674991	17468	Business	115000.00
0005432692632	17468	Business	115000.00
0005432873266	17468	Economy	38300.00
0005432677519	17468	Economy	38300.00
0005432692708	17468	Economy	38300.00
0005432873263	17468	Economy	38300.00
0005432674940	17468	Economy	38300.00
0005432692636	17468	Economy	38300.00
0005432692593	17468	Economy	38300.00
0005432692610	17468	Economy	38300.00
0005432674908	17468	Economy	42200.00
0005432692574	17468	Economy	42200.00
0005432692589	17468	Economy	38300.00
0005432675003	17468	Economy	42200.00
0005432692598	17468	Economy	38300.00
0005432674930	17468	Economy	38300.00
0005432674973	17468	Economy	38300.00
0005432692713	17468	Economy	38300.00
0005432873261	17468	Economy	38300.00
0005432873265	17468	Economy	38300.00
0005432675004	17468	Economy	38300.00
0005432873267	17468	Economy	38300.00
0005432692616	17468	Economy	38300.00
0005432674934	17468	Economy	38300.00
0005432677529	17468	Economy	38300.00
0005432692705	17468	Economy	38300.00
0005432692624	17468	Economy	38300.00
0005432692664	17468	Economy	38300.00
0005432692575	17468	Economy	38300.00
0005432692630	17468	Economy	38300.00
0005432692663	17468	Economy	38300.00
0005432674939	17468	Economy	38300.00
0005432692707	17468	Economy	38300.00
0005432873264	17468	Economy	38300.00
0005432692629	17468	Economy	38300.00
0005432692643	17468	Economy	38300.00
0005432677528	17468	Economy	38300.00
0005432692641	17468	Economy	38300.00
0005432692654	17468	Economy	38300.00
0005432692658	17468	Economy	38300.00
0005432692765	17468	Economy	38300.00
0005432873262	17468	Economy	38300.00
0005432692652	17468	Economy	38300.00
0005432692527	17468	Economy	38300.00
0005432692715	17468	Economy	38300.00
0005432674942	17468	Economy	38300.00
0005432692655	17468	Economy	38300.00
0005432692628	17468	Economy	38300.00
0005432692764	17468	Economy	38300.00
0005432677533	17468	Economy	38300.00
0005432674929	17468	Economy	38300.00
0005432873260	17468	Economy	38300.00
0005432692625	17468	Economy	38300.00
0005432692592	17468	Economy	38300.00
0005432674941	17468	Economy	38300.00
0005432674951	17468	Economy	38300.00
0005432674944	17468	Economy	38300.00
0005432692623	17468	Economy	38300.00
0005432674963	17468	Economy	38300.00
0005433156623	1120	Economy	13900.00
0005434435127	1120	Economy	13900.00
0005434435121	1120	Economy	13900.00
0005433156653	1120	Economy	13900.00
0005433156655	1120	Economy	13900.00
0005433156632	1120	Economy	13900.00
0005433156651	1120	Economy	13900.00
0005434435128	1120	Economy	13900.00
0005434435120	1120	Economy	13900.00
0005434435114	1120	Economy	13900.00
0005434435126	1120	Economy	13900.00
0005434435115	1120	Economy	13900.00
0005434435117	1120	Economy	13900.00
0005434435118	1120	Economy	13900.00
0005433156624	1120	Economy	13900.00
0005434435119	1120	Economy	13900.00
0005433156608	1120	Economy	13900.00
0005433156682	1120	Economy	13900.00
0005434435125	1120	Economy	13900.00
0005434435123	1120	Economy	13900.00
0005434435124	1120	Economy	13900.00
0005434435122	1120	Economy	13900.00
0005434435116	1120	Economy	13900.00
0005434434999	17297	Economy	15200.00
0005434435019	17297	Economy	15200.00
0005434434958	17297	Economy	15200.00
0005434435007	17297	Economy	13900.00
0005434435012	17297	Economy	13900.00
0005434434979	17297	Economy	13900.00
0005434435013	17297	Economy	13900.00
0005434434989	17297	Economy	13900.00
0005434435011	17297	Economy	13900.00
0005433156718	17297	Economy	13900.00
0005434435001	17297	Economy	13900.00
0005433156712	17297	Economy	13900.00
0005434435018	17297	Economy	13900.00
0005433156715	17297	Economy	13900.00
0005434434952	17297	Economy	13900.00
0005434435042	17297	Economy	13900.00
0005434434951	17297	Economy	13900.00
0005434434975	17297	Economy	13900.00
0005434435006	17297	Economy	13900.00
0005434434932	17297	Economy	13900.00
0005434435008	17297	Economy	13900.00
0005434435014	17297	Economy	13900.00
0005434435058	17297	Economy	13900.00
0005433156716	17297	Economy	13900.00
0005434434987	17297	Economy	13900.00
0005433156714	17297	Economy	13900.00
0005434435028	17297	Economy	13900.00
0005434435027	17297	Economy	13900.00
0005434434974	17297	Economy	13900.00
0005433156717	17297	Economy	13900.00
0005434435043	17297	Economy	13900.00
0005434435000	17297	Economy	13900.00
0005433156711	17297	Economy	13900.00
0005434434978	17297	Economy	13900.00
0005433156713	17297	Economy	13900.00
0005434434977	17297	Economy	13900.00
0005433156719	17297	Economy	13900.00
0005434435010	17297	Economy	13900.00
0005434434953	17297	Economy	13900.00
0005435086801	4098	Economy	8200.00
0005435086806	4098	Economy	8200.00
0005435928091	4098	Economy	7500.00
0005435086803	4098	Economy	7500.00
0005435086804	4098	Economy	7500.00
0005435086802	4098	Economy	7500.00
0005435086805	4098	Economy	7500.00
0005435928102	4098	Economy	7500.00
0005435086807	4098	Economy	7500.00
0005435086808	4098	Economy	7500.00
0005435928125	24393	Economy	7500.00
0005435928124	24393	Economy	7500.00
0005435086700	24393	Economy	7500.00
0005435086724	24393	Economy	7500.00
0005435086730	24393	Economy	7500.00
0005435086729	24393	Economy	7500.00
0005435086752	24393	Economy	7500.00
0005435928121	24393	Economy	7500.00
0005435086726	24393	Economy	7500.00
0005435086751	24393	Economy	7500.00
0005435928122	24393	Economy	7500.00
0005435928123	24393	Economy	7500.00
0005435551496	11063	Business	144300.00
0005435098528	11063	Business	144300.00
0005435098526	11063	Business	144300.00
0005435551495	11063	Business	144300.00
0005435551513	11063	Economy	48100.00
0005435551497	11063	Economy	48100.00
0005435551512	11063	Economy	48100.00
0005435098522	11063	Economy	48100.00
0005435098524	11063	Economy	48100.00
0005435551516	11063	Economy	48100.00
0005435551515	11063	Economy	48100.00
0005435551505	11063	Economy	48100.00
0005435551494	11063	Economy	48100.00
0005435551492	11063	Economy	48100.00
0005435551522	11063	Economy	48100.00
0005435098523	11063	Economy	48100.00
0005435551490	11063	Economy	48100.00
0005435098525	11063	Economy	48100.00
0005435551511	11063	Economy	48100.00
0005435706321	2464	Business	86800.00
0005435706312	2464	Business	86800.00
0005433373464	2464	Business	86800.00
0005435706299	2464	Business	86800.00
0005435706327	2464	Business	86800.00
0005435706313	2464	Business	86800.00
0005435706310	2464	Business	86800.00
0005433373410	2464	Business	86800.00
0005433373374	2464	Business	86800.00
0005435706303	2464	Economy	28900.00
0005435706301	2464	Economy	28900.00
0005435706325	2464	Economy	28900.00
0005435706314	2464	Economy	28900.00
0005433373375	2464	Economy	28900.00
0005433373423	2464	Economy	28900.00
0005435706318	2464	Economy	31800.00
0005433373398	2464	Economy	28900.00
0005435706305	2464	Economy	28900.00
0005435706311	2464	Economy	28900.00
0005435706319	2464	Economy	28900.00
0005433373404	2464	Economy	28900.00
0005435706308	2464	Economy	28900.00
0005433373425	2464	Economy	28900.00
0005435706307	2464	Economy	28900.00
0005433373401	2464	Economy	28900.00
0005435706300	2464	Economy	28900.00
0005435706306	2464	Economy	28900.00
0005435706328	2464	Economy	28900.00
0005433373409	2464	Economy	28900.00
0005433373417	2464	Economy	28900.00
0005433373403	2464	Economy	28900.00
0005433373435	2464	Economy	28900.00
0005433373402	2464	Economy	28900.00
0005435706323	2464	Economy	28900.00
0005435706326	2464	Economy	28900.00
0005433373377	2464	Economy	28900.00
0005433373392	2464	Economy	28900.00
0005435706297	2464	Economy	28900.00
0005435706309	2464	Economy	28900.00
0005435706298	2464	Economy	28900.00
0005435706304	2464	Economy	28900.00
0005435706320	2464	Economy	28900.00
0005433373437	2464	Economy	28900.00
0005435706324	2464	Economy	28900.00
0005433373378	2464	Economy	28900.00
0005435706329	2464	Economy	28900.00
0005433373424	2464	Economy	28900.00
0005435706316	2464	Economy	28900.00
0005433373436	2464	Economy	28900.00
0005435706302	2464	Economy	28900.00
0005435706317	2464	Economy	28900.00
0005433373411	2464	Economy	28900.00
0005435706322	2464	Economy	28900.00
0005433373419	2464	Economy	28900.00
0005433373463	2464	Economy	28900.00
0005435706315	2464	Economy	28900.00
0005433373502	27038	Business	86800.00
0005435706180	27038	Business	86800.00
0005435706191	27038	Business	86800.00
0005435706141	27038	Business	86800.00
0005433373488	27038	Business	86800.00
0005435706150	27038	Business	86800.00
0005433373503	27038	Business	86800.00
0005435706134	27038	Economy	28900.00
0005433373487	27038	Economy	28900.00
0005433373492	27038	Economy	28900.00
0005433373491	27038	Economy	28900.00
0005435706205	27038	Economy	28900.00
0005433373498	27038	Economy	31800.00
0005433373494	27038	Economy	28900.00
0005435706193	27038	Economy	28900.00
0005435706179	27038	Economy	28900.00
0005435706154	27038	Economy	28900.00
0005435706123	27038	Economy	28900.00
0005435706098	27038	Economy	28900.00
0005435706120	27038	Economy	28900.00
0005433373486	27038	Economy	28900.00
0005433373489	27038	Economy	28900.00
0005435706166	27038	Economy	28900.00
0005435706278	27038	Economy	28900.00
0005433373501	27038	Economy	28900.00
0005433373490	27038	Economy	28900.00
0005435706130	27038	Economy	28900.00
0005435706279	27038	Economy	28900.00
0005435706121	27038	Economy	28900.00
0005435706118	27038	Economy	28900.00
0005435706124	27038	Economy	28900.00
0005433373493	27038	Economy	28900.00
0005435706190	27038	Economy	28900.00
0005433373496	27038	Economy	28900.00
0005435706151	27038	Economy	28900.00
0005433373497	27038	Economy	28900.00
0005435706100	27038	Economy	28900.00
0005433373500	27038	Economy	28900.00
0005433373499	27038	Economy	28900.00
0005435706133	27038	Economy	28900.00
0005435706177	27038	Economy	28900.00
0005433373495	27038	Economy	28900.00
0005435706099	27038	Economy	28900.00
0005435706178	27038	Economy	28900.00
0005435706189	27038	Economy	28900.00
0005433261416	1308	Business	203300.00
0005434964151	1308	Business	203300.00
0005434964149	1308	Business	203300.00
0005434964150	1308	Business	203300.00
0005433261411	1308	Business	203300.00
0005434964129	1308	Business	203300.00
0005434964140	1308	Business	203300.00
0005433261442	1308	Business	203300.00
0005434964157	1308	Economy	67800.00
0005434964160	1308	Economy	67800.00
0005434964139	1308	Economy	67800.00
0005432279262	1308	Economy	67800.00
0005434964142	1308	Economy	67800.00
0005434964158	1308	Economy	67800.00
0005434964147	1308	Economy	67800.00
0005434964143	1308	Economy	67800.00
0005433261447	1308	Economy	67800.00
0005433261448	1308	Economy	67800.00
0005433261467	1308	Economy	67800.00
0005432279263	1308	Economy	67800.00
0005434964130	1308	Economy	67800.00
0005433261415	1308	Economy	67800.00
0005434964162	1308	Economy	67800.00
0005433261456	1308	Economy	67800.00
0005434964161	1308	Economy	67800.00
0005434964134	1308	Economy	67800.00
0005434964146	1308	Economy	67800.00
0005434964152	1308	Economy	67800.00
0005434964137	1308	Economy	67800.00
0005434964153	1308	Economy	67800.00
0005434964166	1308	Economy	74500.00
0005434964135	1308	Economy	74500.00
0005434964155	1308	Economy	67800.00
0005434964164	1308	Economy	67800.00
0005434964159	1308	Economy	67800.00
0005434964138	1308	Economy	67800.00
0005434964148	1308	Economy	67800.00
0005434964163	1308	Economy	67800.00
0005433261480	1308	Economy	67800.00
0005434964154	1308	Economy	67800.00
0005434964165	1308	Economy	67800.00
0005433261457	1308	Economy	67800.00
0005433261477	1308	Economy	67800.00
0005433261426	1308	Economy	67800.00
0005434964136	1308	Economy	67800.00
0005434964156	1308	Economy	67800.00
0005434964131	1308	Economy	67800.00
0005434964167	1308	Economy	67800.00
0005433261468	1308	Economy	67800.00
0005433261409	1308	Economy	67800.00
0005433261441	1308	Economy	67800.00
0005434964141	1308	Economy	67800.00
0005434964132	1308	Economy	67800.00
0005434964144	1308	Economy	67800.00
0005434964133	1308	Economy	67800.00
0005434964145	1308	Economy	67800.00
0005432279264	1308	Economy	67800.00
0005433261469	1308	Economy	67800.00
0005434964030	18236	Business	203300.00
0005434963922	18236	Business	203300.00
0005433261506	18236	Business	203300.00
0005434963957	18236	Business	203300.00
0005433261530	18236	Business	203300.00
0005434963982	18236	Business	203300.00
0005434964007	18236	Business	203300.00
0005434963902	18236	Business	203300.00
0005434964023	18236	Business	203300.00
0005433261504	18236	Business	203300.00
0005433261529	18236	Business	203300.00
0005433261519	18236	Economy	74500.00
0005434963993	18236	Economy	74500.00
0005434963905	18236	Economy	74500.00
0005434963932	18236	Economy	67800.00
0005433261523	18236	Economy	67800.00
0005434963947	18236	Economy	67800.00
0005434963971	18236	Economy	67800.00
0005433261515	18236	Economy	67800.00
0005434963941	18236	Economy	67800.00
0005433261508	18236	Economy	67800.00
0005434964057	18236	Economy	67800.00
0005434963981	18236	Economy	67800.00
0005434963978	18236	Economy	67800.00
0005434963918	18236	Economy	67800.00
0005434963962	18236	Economy	67800.00
0005433261512	18236	Economy	67800.00
0005433261528	18236	Economy	67800.00
0005433261522	18236	Economy	67800.00
0005433261521	18236	Economy	67800.00
0005434963969	18236	Economy	67800.00
0005434963973	18236	Economy	67800.00
0005434963938	18236	Economy	67800.00
0005433261509	18236	Economy	67800.00
0005434963974	18236	Economy	67800.00
0005433261514	18236	Economy	67800.00
0005433261505	18236	Economy	67800.00
0005434963916	18236	Economy	67800.00
0005433261507	18236	Economy	67800.00
0005434963934	18236	Economy	67800.00
0005434964039	18236	Economy	67800.00
0005433261524	18236	Economy	67800.00
0005434963988	18236	Economy	67800.00
0005434964064	18236	Economy	67800.00
0005434963965	18236	Economy	67800.00
0005433261532	18236	Economy	67800.00
0005433261513	18236	Economy	67800.00
0005433261518	18236	Economy	67800.00
0005433261520	18236	Economy	67800.00
0005434963929	18236	Economy	67800.00
0005434964019	18236	Economy	67800.00
0005434963915	18236	Economy	67800.00
0005434963991	18236	Economy	67800.00
0005433261516	18236	Economy	67800.00
0005434964028	18236	Economy	67800.00
0005433261517	18236	Economy	67800.00
0005434963895	18236	Economy	67800.00
0005433261527	18236	Economy	67800.00
0005434963935	18236	Economy	67800.00
0005434963956	18236	Economy	67800.00
0005434963990	18236	Economy	67800.00
0005433261526	18236	Economy	67800.00
0005434963937	18236	Economy	67800.00
0005434963904	18236	Economy	67800.00
0005433261525	18236	Economy	67800.00
0005434963946	18236	Economy	67800.00
0005433261510	18236	Economy	67800.00
0005433261533	18236	Economy	67800.00
0005434964029	18236	Economy	67800.00
0005434963907	18236	Economy	67800.00
0005434964010	18236	Economy	67800.00
0005433261511	18236	Economy	67800.00
0005434964011	18236	Economy	67800.00
0005434963942	18236	Economy	67800.00
0005434963970	18236	Economy	67800.00
0005434963977	18236	Economy	67800.00
0005434963989	18236	Economy	67800.00
0005433261531	18236	Economy	67800.00
0005434963903	18236	Economy	67800.00
0005434625927	4823	Business	44200.00
0005435907451	4823	Business	44200.00
0005435907452	4823	Economy	14700.00
0005433194830	4823	Economy	14700.00
0005434625925	4823	Economy	14700.00
0005434625922	4823	Economy	16200.00
0005434625929	4823	Economy	14700.00
0005434625928	4823	Economy	14700.00
0005435907438	4823	Economy	14700.00
0005434625921	4823	Economy	14700.00
0005434625926	4823	Economy	14700.00
0005434625924	4823	Economy	14700.00
0005434625923	4823	Economy	14700.00
0005433194829	4823	Economy	14700.00
0005433194821	4823	Economy	14700.00
0005435907440	4823	Economy	14700.00
0005434625920	4823	Economy	14700.00
0005434625804	32909	Business	44200.00
0005435907489	32909	Business	44200.00
0005434625816	32909	Economy	14700.00
0005435907485	32909	Economy	14700.00
0005434625847	32909	Economy	14700.00
0005435907488	32909	Economy	14700.00
0005434625865	32909	Economy	14700.00
0005434625871	32909	Economy	14700.00
0005435907486	32909	Economy	14700.00
0005435907487	32909	Economy	14700.00
0005434625848	32909	Economy	14700.00
0005434625857	32909	Economy	14700.00
0005435907490	32909	Economy	14700.00
0005434625870	32909	Economy	14700.00
0005432195684	13773	Economy	3400.00
0005435937372	13773	Economy	3400.00
0005435784914	13773	Economy	3400.00
0005435937369	13773	Economy	3400.00
0005435784905	13773	Economy	3100.00
0005435784884	13773	Economy	3100.00
0005435937368	13773	Economy	3100.00
0005435784965	13773	Economy	3100.00
0005432195685	13773	Economy	3100.00
0005435937370	13773	Economy	3100.00
0005435784967	13773	Economy	3100.00
0005435784861	13773	Economy	3100.00
0005435784862	13773	Economy	3100.00
0005435785006	13773	Economy	3100.00
0005435784752	13773	Economy	3100.00
0005435784966	13773	Economy	3100.00
0005435784934	13773	Economy	3100.00
0005435784962	13773	Economy	3100.00
0005435937367	13773	Economy	3100.00
0005435784935	13773	Economy	3100.00
0005435784946	13773	Economy	3100.00
0005435784994	13773	Economy	3100.00
0005435784915	13773	Economy	3100.00
0005435784842	13773	Economy	3100.00
0005435937374	13773	Economy	3100.00
0005435784869	13773	Economy	3100.00
0005435784999	13773	Economy	3100.00
0005435785005	13773	Economy	3100.00
0005435937371	13773	Economy	3100.00
0005435784910	13773	Economy	3100.00
0005435784786	13773	Economy	3100.00
0005435784928	13773	Economy	3100.00
0005435784751	13773	Economy	3100.00
0005435784741	13773	Economy	3100.00
0005435785007	13773	Economy	3100.00
0005435937373	13773	Economy	3100.00
0005435784964	13773	Economy	3100.00
0005435784923	13773	Economy	3100.00
0005435784883	13773	Economy	3100.00
0005435784887	13773	Economy	3100.00
0005435784796	13773	Economy	3100.00
0005435785159	27455	Economy	3400.00
0005432190611	27455	Economy	3400.00
0005435785177	27455	Economy	3400.00
0005435785170	27455	Economy	3400.00
0005435785154	27455	Economy	3100.00
0005435785168	27455	Economy	3100.00
0005435937309	27455	Economy	3100.00
0005435785174	27455	Economy	3100.00
0005432190609	27455	Economy	3100.00
0005435785156	27455	Economy	3100.00
0005432190607	27455	Economy	3100.00
0005435785158	27455	Economy	3100.00
0005432190610	27455	Economy	3100.00
0005435785153	27455	Economy	3100.00
0005435785176	27455	Economy	3100.00
0005435785185	27455	Economy	3100.00
0005435785157	27455	Economy	3100.00
0005435785183	27455	Economy	3100.00
0005435785169	27455	Economy	3100.00
0005435785180	27455	Economy	3100.00
0005435785181	27455	Economy	3100.00
0005435785167	27455	Economy	3100.00
0005435785171	27455	Economy	3100.00
0005435785184	27455	Economy	3100.00
0005435785165	27455	Economy	3100.00
0005435785186	27455	Economy	3100.00
0005435787343	27455	Economy	3100.00
0005432190608	27455	Economy	3100.00
0005435785182	27455	Economy	3100.00
0005435787341	27455	Economy	3100.00
0005435937312	27455	Economy	3100.00
0005435785161	27455	Economy	3100.00
0005435785179	27455	Economy	3100.00
0005435785173	27455	Economy	3100.00
0005435785162	27455	Economy	3100.00
0005435785163	27455	Economy	3100.00
0005435785178	27455	Economy	3100.00
0005435785175	27455	Economy	3100.00
0005435787342	27455	Economy	3100.00
0005435785164	27455	Economy	3100.00
0005435785155	27455	Economy	3100.00
0005435785166	27455	Economy	3100.00
0005435785160	27455	Economy	3100.00
0005435785172	27455	Economy	3100.00
0005434406714	20300	Business	12000.00
0005435311032	20300	Business	12000.00
0005434406726	20300	Business	12000.00
0005434406981	20300	Business	12000.00
0005434407162	20300	Business	12000.00
0005434406966	20300	Business	12000.00
0005434406970	20300	Business	12000.00
0005434406964	20300	Business	12000.00
0005434406715	20300	Business	12000.00
0005434406849	20300	Business	12000.00
0005434407022	20300	Economy	4000.00
0005434406941	20300	Economy	4000.00
0005434406947	20300	Economy	4000.00
0005434406721	20300	Economy	4000.00
0005435311033	20300	Economy	4000.00
0005434406904	20300	Economy	4000.00
0005434407324	20300	Economy	4000.00
0005435311027	20300	Economy	4000.00
0005434406976	20300	Economy	4000.00
0005434407001	20300	Economy	4400.00
0005434407023	20300	Economy	4400.00
0005434406905	20300	Economy	4400.00
0005434407043	20300	Economy	4400.00
0005434406865	20300	Economy	4000.00
0005434406856	20300	Economy	4000.00
0005434407280	20300	Economy	4000.00
0005434407002	20300	Economy	4000.00
0005434406790	20300	Economy	4000.00
0005434406798	20300	Economy	4000.00
0005434407044	20300	Economy	4000.00
0005434407102	20300	Economy	4000.00
0005434406841	20300	Economy	4000.00
0005434407202	20300	Economy	4000.00
0005434406937	20300	Economy	4000.00
0005435311029	20300	Economy	4000.00
0005434406758	20300	Economy	4000.00
0005434406942	20300	Economy	4000.00
0005434407024	20300	Economy	4000.00
0005434407042	20300	Economy	4000.00
0005434406705	20300	Economy	4000.00
0005434406854	20300	Economy	4000.00
0005434406791	20300	Economy	4000.00
0005434406997	20300	Economy	4000.00
0005434407323	20300	Economy	4000.00
0005432058366	20300	Economy	4000.00
0005434407188	20300	Economy	4000.00
0005435311026	20300	Economy	4000.00
0005434406831	20300	Economy	4000.00
0005434406980	20300	Economy	4000.00
0005434407027	20300	Economy	4000.00
0005434406792	20300	Economy	4000.00
0005434406913	20300	Economy	4000.00
0005434407239	20300	Economy	4000.00
0005434406720	20300	Economy	4000.00
0005435311034	20300	Economy	4000.00
0005434406974	20300	Economy	4000.00
0005434406925	20300	Economy	4000.00
0005434406815	20300	Economy	4000.00
0005434406836	20300	Economy	4000.00
0005434406839	20300	Economy	4000.00
0005434407128	20300	Economy	4000.00
0005434407028	20300	Economy	4000.00
0005434407133	20300	Economy	4000.00
0005432058367	20300	Economy	4000.00
0005434406940	20300	Economy	4000.00
0005434406840	20300	Economy	4000.00
0005432058364	20300	Economy	4000.00
0005434407012	20300	Economy	4000.00
0005434407189	20300	Economy	4000.00
0005435311031	20300	Economy	4000.00
0005434406944	20300	Economy	4000.00
0005434407146	20300	Economy	4000.00
0005432058365	20300	Economy	4000.00
0005435311030	20300	Economy	4000.00
0005434406979	20300	Economy	4000.00
0005434406813	20300	Economy	4000.00
0005435311028	20300	Economy	4000.00
0005434406759	20300	Economy	4000.00
0005434407520	27016	Business	12000.00
0005434407490	27016	Business	12000.00
0005435310886	27016	Business	12000.00
0005434407507	27016	Business	12000.00
0005434407512	27016	Business	12000.00
0005434407484	27016	Business	12000.00
0005434407524	27016	Business	12000.00
0005434407477	27016	Business	12000.00
0005434407538	27016	Business	12000.00
0005435310901	27016	Business	12000.00
0005434407498	27016	Economy	4000.00
0005434407522	27016	Economy	4000.00
0005434407487	27016	Economy	4000.00
0005434407495	27016	Economy	4000.00
0005434407513	27016	Economy	4000.00
0005434407529	27016	Economy	4000.00
0005434407530	27016	Economy	4000.00
0005434407510	27016	Economy	4000.00
0005435310921	27016	Economy	4000.00
0005435310910	27016	Economy	4400.00
0005434407489	27016	Economy	4400.00
0005434407537	27016	Economy	4400.00
0005434407499	27016	Economy	4400.00
0005432153912	27016	Economy	4000.00
0005434407494	27016	Economy	4000.00
0005434407511	27016	Economy	4000.00
0005434407528	27016	Economy	4000.00
0005434407491	27016	Economy	4000.00
0005434407482	27016	Economy	4000.00
0005434407509	27016	Economy	4000.00
0005435310908	27016	Economy	4000.00
0005434407501	27016	Economy	4000.00
0005434407483	27016	Economy	4000.00
0005435310909	27016	Economy	4000.00
0005432153906	27016	Economy	4000.00
0005435310868	27016	Economy	4000.00
0005434407515	27016	Economy	4000.00
0005434407532	27016	Economy	4000.00
0005432153910	27016	Economy	4000.00
0005435310920	27016	Economy	4000.00
0005432153909	27016	Economy	4000.00
0005434407527	27016	Economy	4000.00
0005434407525	27016	Economy	4000.00
0005434407485	27016	Economy	4000.00
0005435310839	27016	Economy	4000.00
0005434407516	27016	Economy	4000.00
0005434407506	27016	Economy	4000.00
0005434407531	27016	Economy	4000.00
0005435310877	27016	Economy	4000.00
0005434407521	27016	Economy	4000.00
0005435310874	27016	Economy	4000.00
0005434407539	27016	Economy	4000.00
0005435310906	27016	Economy	4000.00
0005434407523	27016	Economy	4000.00
0005434407488	27016	Economy	4000.00
0005434407496	27016	Economy	4000.00
0005432153911	27016	Economy	4000.00
0005435310866	27016	Economy	4000.00
0005434407540	27016	Economy	4000.00
0005434407533	27016	Economy	4000.00
0005434407519	27016	Economy	4000.00
0005432153907	27016	Economy	4000.00
0005434407514	27016	Economy	4000.00
0005434407481	27016	Economy	4000.00
0005432153908	27016	Economy	4000.00
0005434407504	27016	Economy	4000.00
0005434407500	27016	Economy	4000.00
0005434407536	27016	Economy	4000.00
0005434407518	27016	Economy	4000.00
0005435310875	27016	Economy	4000.00
0005434407535	27016	Economy	4000.00
0005434407502	27016	Economy	4000.00
0005434407505	27016	Economy	4000.00
0005435310890	27016	Economy	4000.00
0005435310883	27016	Economy	4000.00
0005434407508	27016	Economy	4000.00
0005434407534	27016	Economy	4000.00
0005434407493	27016	Economy	4000.00
0005434407478	27016	Economy	4000.00
0005434407479	27016	Economy	4000.00
0005434407503	27016	Economy	4000.00
0005434407480	27016	Economy	4000.00
0005434407492	27016	Economy	4000.00
0005434407517	27016	Economy	4000.00
0005434407497	27016	Economy	4000.00
0005434407486	27016	Economy	4000.00
0005435310900	27016	Economy	4000.00
0005434407526	27016	Economy	4000.00
0005432109691	5698	Business	43300.00
0005434319341	5698	Business	43300.00
0005434319339	5698	Business	43300.00
0005434319332	5698	Economy	14400.00
0005433123605	5698	Economy	14400.00
0005433123659	5698	Economy	14400.00
0005433123688	5698	Economy	15900.00
0005433123633	5698	Economy	15900.00
0005433123669	5698	Economy	15900.00
0005434319340	5698	Economy	14400.00
0005434319330	5698	Economy	14400.00
0005434311210	5698	Economy	14400.00
0005434319337	5698	Economy	14400.00
0005433123675	5698	Economy	14400.00
0005433123655	5698	Economy	14400.00
0005433123668	5698	Economy	14400.00
0005433123674	5698	Economy	14400.00
0005433123629	5698	Economy	14400.00
0005433123680	5698	Economy	14400.00
0005433123676	5698	Economy	14400.00
0005432109692	5698	Economy	14400.00
0005434319336	5698	Economy	14400.00
0005433123630	5698	Economy	14400.00
0005433123628	5698	Economy	14400.00
0005432109693	5698	Economy	14400.00
0005434319334	5698	Economy	14400.00
0005433123625	5698	Economy	14400.00
0005434311211	5698	Economy	14400.00
0005434319329	5698	Economy	14400.00
0005433123687	5698	Economy	14400.00
0005434319333	5698	Economy	14400.00
0005433123646	5698	Economy	14400.00
0005434319338	5698	Economy	14400.00
0005434319335	5698	Economy	14400.00
0005434319331	5698	Economy	14400.00
0005434319342	5698	Economy	14400.00
0005433123854	15667	Business	43300.00
0005434319243	15667	Business	43300.00
0005434319186	15667	Business	43300.00
0005433123848	15667	Business	43300.00
0005433123855	15667	Business	43300.00
0005434319236	15667	Economy	14400.00
0005434319224	15667	Economy	14400.00
0005433123858	15667	Economy	14400.00
0005434319181	15667	Economy	14400.00
0005434319232	15667	Economy	14400.00
0005434319217	15667	Economy	15900.00
0005434319212	15667	Economy	15900.00
0005434319220	15667	Economy	15900.00
0005434319159	15667	Economy	15900.00
0005433123850	15667	Economy	14400.00
0005434312291	15667	Economy	14400.00
0005434319185	15667	Economy	14400.00
0005433123856	15667	Economy	14400.00
0005434319216	15667	Economy	14400.00
0005433123865	15667	Economy	14400.00
0005433123849	15667	Economy	14400.00
0005434319187	15667	Economy	14400.00
0005434319201	15667	Economy	14400.00
0005433123862	15667	Economy	14400.00
0005434311181	15667	Economy	14400.00
0005433123846	15667	Economy	14400.00
0005433123844	15667	Economy	14400.00
0005434319219	15667	Economy	14400.00
0005433123847	15667	Economy	14400.00
0005434319228	15667	Economy	14400.00
0005433123863	15667	Economy	14400.00
0005433123851	15667	Economy	14400.00
0005433123853	15667	Economy	14400.00
0005433123857	15667	Economy	14400.00
0005433123845	15667	Economy	14400.00
0005433123861	15667	Economy	14400.00
0005433123860	15667	Economy	14400.00
0005433123852	15667	Economy	14400.00
0005433123864	15667	Economy	14400.00
0005433123859	15667	Economy	14400.00
0005434319158	15667	Economy	14400.00
0005435220293	24979	Economy	17100.00
0005435217683	24979	Economy	17100.00
0005435220284	24979	Economy	15500.00
0005435220289	24979	Economy	15500.00
0005435220294	24979	Economy	15500.00
0005435221506	24979	Economy	15500.00
0005435220291	24979	Economy	15500.00
0005435220285	24979	Economy	15500.00
0005435217684	24979	Economy	15500.00
0005435221497	24979	Economy	15500.00
0005435217678	24979	Economy	15500.00
0005435220290	24979	Economy	15500.00
0005434189118	8980	Economy	27400.00
0005434189088	8980	Economy	24900.00
0005434189108	8980	Economy	24900.00
0005434484320	8980	Economy	24900.00
0005434189117	8980	Economy	24900.00
0005434484321	8980	Economy	24900.00
0005434484322	8980	Economy	24900.00
0005434189101	8980	Economy	24900.00
0005434484323	8980	Economy	24900.00
0005434189100	8980	Economy	24900.00
0005434189090	8980	Economy	24900.00
0005434189094	8980	Economy	24900.00
0005434484324	8980	Economy	24900.00
0005434484278	16668	Economy	27400.00
0005434189156	16668	Economy	24900.00
0005434484275	16668	Economy	24900.00
0005434484268	16668	Economy	24900.00
0005434484253	16668	Economy	24900.00
0005434189158	16668	Economy	24900.00
0005434484270	16668	Economy	24900.00
0005434189155	16668	Economy	24900.00
0005434189154	16668	Economy	24900.00
0005434189153	16668	Economy	24900.00
0005434484274	16668	Economy	24900.00
0005434484254	16668	Economy	24900.00
0005434189157	16668	Economy	24900.00
0005433123856	7549	Business	11100.00
0005433123864	7549	Business	11100.00
0005433123846	7549	Business	11100.00
0005433123852	7549	Economy	3700.00
0005433123858	7549	Economy	3700.00
0005433123854	7549	Economy	4100.00
0005433123862	7549	Economy	3700.00
0005433123847	7549	Economy	3700.00
0005433123857	7549	Economy	3700.00
0005433123851	7549	Economy	3700.00
0005433722114	7549	Economy	3700.00
0005433123850	7549	Economy	3700.00
0005433123853	7549	Economy	3700.00
0005433722108	7549	Economy	3700.00
0005433123865	7549	Economy	3700.00
0005433123861	7549	Economy	3700.00
0005433123863	7549	Economy	3700.00
0005433123845	7549	Economy	3700.00
0005433123855	7549	Economy	3700.00
0005433123860	7549	Economy	3700.00
0005433123844	7549	Economy	3700.00
0005433123849	7549	Economy	3700.00
0005433123859	7549	Economy	3700.00
0005433123848	7549	Economy	3700.00
0005433722113	7549	Economy	3700.00
0005432720812	7546	Business	11100.00
0005432692968	7546	Business	11100.00
0005433449874	7546	Business	11100.00
0005432720790	7546	Business	11100.00
0005433449890	7546	Business	11100.00
0005432720793	7546	Business	11100.00
0005432720789	7546	Business	11100.00
0005432720804	7546	Business	11100.00
0005432720792	7546	Business	11100.00
0005432720796	7546	Business	11100.00
0005432692955	7546	Economy	3700.00
0005432720797	7546	Economy	3700.00
0005432720801	7546	Economy	3700.00
0005432692940	7546	Economy	3700.00
0005432692958	7546	Economy	3700.00
0005433449879	7546	Economy	3700.00
0005432692966	7546	Economy	3700.00
0005432692960	7546	Economy	3700.00
0005432720803	7546	Economy	3700.00
0005432720800	7546	Economy	4100.00
0005433449888	7546	Economy	4100.00
0005432692964	7546	Economy	4100.00
0005432692963	7546	Economy	4100.00
0005433449875	7546	Economy	4100.00
0005432720810	7546	Economy	3700.00
0005433449893	7546	Economy	3700.00
0005432720788	7546	Economy	3700.00
0005432720791	7546	Economy	3700.00
0005432692946	7546	Economy	3700.00
0005433449880	7546	Economy	3700.00
0005432692948	7546	Economy	3700.00
0005433449873	7546	Economy	3700.00
0005433449884	7546	Economy	3700.00
0005432692939	7546	Economy	3700.00
0005432692961	7546	Economy	3700.00
0005432692967	7546	Economy	3700.00
0005432692943	7546	Economy	3700.00
0005432071560	7546	Economy	3700.00
0005433449887	7546	Economy	3700.00
0005433449886	7546	Economy	3700.00
0005433449885	7546	Economy	3700.00
0005432720794	7546	Economy	3700.00
0005432692947	7546	Economy	3700.00
0005432720809	7546	Economy	3700.00
0005432720799	7546	Economy	3700.00
0005432720807	7546	Economy	3700.00
0005433449877	7546	Economy	3700.00
0005432692949	7546	Economy	3700.00
0005432692944	7546	Economy	3700.00
0005432071562	7546	Economy	3700.00
0005432071561	7546	Economy	3700.00
0005432720785	7546	Economy	3700.00
0005433449878	7546	Economy	3700.00
0005432692942	7546	Economy	3700.00
0005433449876	7546	Economy	3700.00
0005432720808	7546	Economy	3700.00
0005432692956	7546	Economy	3700.00
0005432720805	7546	Economy	3700.00
0005432692954	7546	Economy	3700.00
0005433449882	7546	Economy	3700.00
0005433449883	7546	Economy	3700.00
0005432692953	7546	Economy	3700.00
0005433449892	7546	Economy	3700.00
0005432692962	7546	Economy	3700.00
0005432692951	7546	Economy	3700.00
0005432692957	7546	Economy	3700.00
0005432692941	7546	Economy	3700.00
0005433449889	7546	Economy	3700.00
0005432720811	7546	Economy	3700.00
0005432692959	7546	Economy	3700.00
0005432720806	7546	Economy	3700.00
0005432720787	7546	Economy	3700.00
0005432692937	7546	Economy	3700.00
0005432692950	7546	Economy	3700.00
0005432720795	7546	Economy	3700.00
0005432692952	7546	Economy	3700.00
0005432692945	7546	Economy	3700.00
0005432692965	7546	Economy	3700.00
0005433449894	7546	Economy	3700.00
0005433449881	7546	Economy	3700.00
0005433449891	7546	Economy	3700.00
0005432720802	7546	Economy	3700.00
0005432692938	7546	Economy	3700.00
0005432720786	7546	Economy	3700.00
0005432720798	7546	Economy	3700.00
0005432692625	30340	Business	11100.00
0005433449715	30340	Business	11100.00
0005433449684	30340	Business	11100.00
0005432692764	30340	Business	11100.00
0005433449689	30340	Business	11100.00
0005432692705	30340	Business	11100.00
0005433449589	30340	Business	11100.00
0005433449663	30340	Business	11100.00
0005433449714	30340	Business	11100.00
0005432692623	30340	Business	11100.00
0005432692630	30340	Economy	3700.00
0005432692593	30340	Economy	3700.00
0005433449690	30340	Economy	3700.00
0005433449662	30340	Economy	3700.00
0005433449716	30340	Economy	4100.00
0005432692765	30340	Economy	4100.00
0005432692624	30340	Economy	4100.00
0005432692657	30340	Economy	4100.00
0005433449764	30340	Economy	3700.00
0005432692709	30340	Economy	3700.00
0005432692610	30340	Economy	3700.00
0005432692641	30340	Economy	3700.00
0005432692713	30340	Economy	3700.00
0005432692609	30340	Economy	3700.00
0005433449736	30340	Economy	3700.00
0005432692636	30340	Economy	3700.00
0005432692527	30340	Economy	3700.00
0005432692543	30340	Economy	3700.00
0005432692663	30340	Economy	3700.00
0005432692652	30340	Economy	3700.00
0005432692643	30340	Economy	3700.00
0005433449795	30340	Economy	3700.00
0005432692598	30340	Economy	3700.00
0005433449686	30340	Economy	3700.00
0005432692715	30340	Economy	3700.00
0005432692664	30340	Economy	3700.00
0005433449727	30340	Economy	3700.00
0005432692592	30340	Economy	3700.00
0005433449702	30340	Economy	3700.00
0005433449697	30340	Economy	3700.00
0005432692574	30340	Economy	3700.00
0005432692745	30340	Economy	3700.00
0005433449706	30340	Economy	3700.00
0005432692632	30340	Economy	3700.00
0005432692617	30340	Economy	3700.00
0005433449685	30340	Economy	3700.00
0005432692611	30340	Economy	3700.00
0005432692708	30340	Economy	3700.00
0005433449698	30340	Economy	3700.00
0005432692575	30340	Economy	3700.00
0005433449713	30340	Economy	3700.00
0005432692655	30340	Economy	3700.00
0005432692616	30340	Economy	3700.00
0005433449699	30340	Economy	3700.00
0005432692654	30340	Economy	3700.00
0005432692707	30340	Economy	3700.00
0005433449730	30340	Economy	3700.00
0005433449647	30340	Economy	3700.00
0005432692658	30340	Economy	3700.00
0005432692589	30340	Economy	3700.00
0005432692629	30340	Economy	3700.00
0005432692628	30340	Economy	3700.00
0005433449700	30340	Economy	3700.00
0005433449679	30340	Economy	3700.00
0005433123669	30339	Business	11100.00
0005433123625	30339	Business	11100.00
0005432720644	30339	Business	11100.00
0005433123633	30339	Business	11100.00
0005432720528	30339	Business	11100.00
0005432720645	30339	Business	11100.00
0005433123680	30339	Business	11100.00
0005432720607	30339	Economy	3700.00
0005433123605	30339	Economy	3700.00
0005433722199	30339	Economy	3700.00
0005433722198	30339	Economy	3700.00
0005432720585	30339	Economy	3700.00
0005433123674	30339	Economy	4100.00
0005432720690	30339	Economy	3700.00
0005432720649	30339	Economy	3700.00
0005432720686	30339	Economy	3700.00
0005433123687	30339	Economy	3700.00
0005432720527	30339	Economy	3700.00
0005432720691	30339	Economy	3700.00
0005432720646	30339	Economy	3700.00
0005433123668	30339	Economy	3700.00
0005433123675	30339	Economy	3700.00
0005432720493	30339	Economy	3700.00
0005432720660	30339	Economy	3700.00
0005433722197	30339	Economy	3700.00
0005432720728	30339	Economy	3700.00
0005432720699	30339	Economy	3700.00
0005433123659	30339	Economy	3700.00
0005432720594	30339	Economy	3700.00
0005433123655	30339	Economy	3700.00
0005433123688	30339	Economy	3700.00
0005432720545	30339	Economy	3700.00
0005432720544	30339	Economy	3700.00
0005433123646	30339	Economy	3700.00
0005432720492	30339	Economy	3700.00
0005433123676	30339	Economy	3700.00
0005432720589	30339	Economy	3700.00
0005432720529	30339	Economy	3700.00
0005433123629	30339	Economy	3700.00
0005433123628	30339	Economy	3700.00
0005433123630	30339	Economy	3700.00
0005432720606	30339	Economy	3700.00
0005432720593	30339	Economy	3700.00
0005432720708	30339	Economy	3700.00
0005432720540	30339	Economy	3700.00
0005433524991	1408	Business	70400.00
0005434586524	1408	Business	70400.00
0005434586500	1408	Business	70400.00
0005434586506	1408	Business	70400.00
0005434586514	1408	Business	70400.00
0005433724788	1408	Business	70400.00
0005433192921	1408	Business	70400.00
0005432270993	1408	Business	70400.00
0005433724789	1408	Business	70400.00
0005432270992	1408	Business	70400.00
0005433724787	1408	Economy	23500.00
0005433192920	1408	Economy	23500.00
0005434586510	1408	Economy	23500.00
0005434513569	1408	Economy	23500.00
0005432968819	1408	Economy	23500.00
0005434586520	1408	Economy	23500.00
0005433192909	1408	Economy	25800.00
0005433192922	1408	Economy	25800.00
0005432927905	1408	Economy	25800.00
0005433524995	1408	Economy	25800.00
0005434586513	1408	Economy	23500.00
0005434586521	1408	Economy	23500.00
0005434586518	1408	Economy	23500.00
0005434586517	1408	Economy	23500.00
0005432927904	1408	Economy	23500.00
0005433525002	1408	Economy	23500.00
0005433525000	1408	Economy	23500.00
0005434586523	1408	Economy	23500.00
0005434586522	1408	Economy	23500.00
0005434514958	1408	Economy	23500.00
0005434586502	1408	Economy	23500.00
0005432927911	1408	Economy	23500.00
0005434586519	1408	Economy	23500.00
0005433524996	1408	Economy	23500.00
0005433192900	1408	Economy	23500.00
0005433724790	1408	Economy	23500.00
0005432270994	1408	Economy	23500.00
0005433192889	1408	Economy	23500.00
0005433524994	1408	Economy	23500.00
0005432927898	1408	Economy	23500.00
0005434586501	1408	Economy	23500.00
0005434586508	1408	Economy	23500.00
0005433192888	1408	Economy	23500.00
0005434586504	1408	Economy	23500.00
0005433524999	1408	Economy	23500.00
0005433524992	1408	Economy	23500.00
0005434514957	1408	Economy	23500.00
0005433524993	1408	Economy	23500.00
0005434513570	1408	Economy	23500.00
0005433524998	1408	Economy	23500.00
0005432968815	1408	Economy	23500.00
0005433192848	1408	Economy	23500.00
0005433524997	1408	Economy	23500.00
0005434586516	1408	Economy	23500.00
0005434586511	1408	Economy	23500.00
0005434586515	1408	Economy	23500.00
0005434586525	1408	Economy	23500.00
0005434586512	1408	Economy	23500.00
0005434586503	1408	Economy	23500.00
0005434586505	1408	Economy	23500.00
0005433192849	1408	Economy	23500.00
0005434586507	1408	Economy	23500.00
0005433724791	1408	Economy	23500.00
0005433525001	1408	Economy	23500.00
0005434586509	1408	Economy	23500.00
0005433192994	18520	Business	70400.00
0005433724735	18520	Business	70400.00
0005432968831	18520	Business	70400.00
0005433192999	18520	Business	70400.00
0005434586274	18520	Business	70400.00
0005432927958	18520	Business	70400.00
0005434586340	18520	Business	70400.00
0005434586288	18520	Business	70400.00
0005434586277	18520	Economy	23500.00
0005434586324	18520	Economy	23500.00
0005433192987	18520	Economy	23500.00
0005434586215	18520	Economy	23500.00
0005434586297	18520	Economy	23500.00
0005434586305	18520	Economy	23500.00
0005434586330	18520	Economy	23500.00
0005433724729	18520	Economy	25800.00
0005433192995	18520	Economy	25800.00
0005434586301	18520	Economy	25800.00
0005433192992	18520	Economy	25800.00
0005434586241	18520	Economy	23500.00
0005434586230	18520	Economy	23500.00
0005434586231	18520	Economy	23500.00
0005434586276	18520	Economy	23500.00
0005434586388	18520	Economy	23500.00
0005434586273	18520	Economy	23500.00
0005434586318	18520	Economy	23500.00
0005433192996	18520	Economy	23500.00
0005434586342	18520	Economy	23500.00
0005434586353	18520	Economy	23500.00
0005433524868	18520	Economy	23500.00
0005434586308	18520	Economy	23500.00
0005434586331	18520	Economy	23500.00
0005434586338	18520	Economy	23500.00
0005433524925	18520	Economy	23500.00
0005433724728	18520	Economy	23500.00
0005432927957	18520	Economy	23500.00
0005434586339	18520	Economy	23500.00
0005434586321	18520	Economy	23500.00
0005432927956	18520	Economy	23500.00
0005434586310	18520	Economy	23500.00
0005434586343	18520	Economy	23500.00
0005434586272	18520	Economy	23500.00
0005434586304	18520	Economy	23500.00
0005433524926	18520	Economy	23500.00
0005433192991	18520	Economy	23500.00
0005433192997	18520	Economy	23500.00
0005433524908	18520	Economy	23500.00
0005434586302	18520	Economy	23500.00
0005432968830	18520	Economy	23500.00
0005433192989	18520	Economy	23500.00
0005432927955	18520	Economy	23500.00
0005434586404	18520	Economy	23500.00
0005434514929	18520	Economy	23500.00
0005434586389	18520	Economy	23500.00
0005432927959	18520	Economy	23500.00
0005433724732	18520	Economy	23500.00
0005433192988	18520	Economy	23500.00
0005432927954	18520	Economy	23500.00
0005433524867	18520	Economy	23500.00
0005433524869	18520	Economy	23500.00
0005434586461	18520	Economy	23500.00
0005434586354	18520	Economy	23500.00
0005434586341	18520	Economy	23500.00
0005433192990	18520	Economy	23500.00
0005433192998	18520	Economy	23500.00
0005433192993	18520	Economy	23500.00
0005433724743	18520	Economy	23500.00
0005435302147	11467	Economy	4300.00
0005434344040	11467	Economy	4300.00
0005434344044	11467	Economy	4300.00
0005434344045	11467	Economy	4300.00
0005434344059	11467	Economy	4000.00
0005434344026	11467	Economy	4000.00
0005434344057	11467	Economy	4000.00
0005435302122	11467	Economy	4000.00
0005434344055	11467	Economy	4000.00
0005435304992	11467	Economy	4000.00
0005434344058	11467	Economy	4000.00
0005434344051	11467	Economy	4000.00
0005434344060	11467	Economy	4000.00
0005434344041	11467	Economy	4000.00
0005434344036	11467	Economy	4000.00
0005434142595	11467	Economy	4000.00
0005434344035	11467	Economy	4000.00
0005434344043	11467	Economy	4000.00
0005434344053	11467	Economy	4000.00
0005434344056	11467	Economy	4000.00
0005434344034	11467	Economy	4000.00
0005434344052	11467	Economy	4000.00
0005434344042	11467	Economy	4000.00
0005434344032	11467	Economy	4000.00
0005435302148	11467	Economy	4000.00
0005434344024	11467	Economy	4000.00
0005434344025	11467	Economy	4000.00
0005435302123	11467	Economy	4000.00
0005434344039	11467	Economy	4000.00
0005434142594	11467	Economy	4000.00
0005434142593	11467	Economy	4000.00
0005434344048	11467	Economy	4000.00
0005434344037	11467	Economy	4000.00
0005434344038	11467	Economy	4000.00
0005435302121	11467	Economy	4000.00
0005434344029	11467	Economy	4000.00
0005434344027	11467	Economy	4000.00
0005434344047	11467	Economy	4000.00
0005434344028	11467	Economy	4000.00
0005434344033	11467	Economy	4000.00
0005434344030	11467	Economy	4000.00
0005434344054	11467	Economy	4000.00
0005434344046	11467	Economy	4000.00
0005434344050	11467	Economy	4000.00
0005434142596	11467	Economy	4000.00
0005434344049	11467	Economy	4000.00
0005434344031	11467	Economy	4000.00
0005434343618	29752	Economy	4300.00
0005435305007	29752	Economy	4300.00
0005434343867	29752	Economy	4300.00
0005434343713	29752	Economy	4000.00
0005434343758	29752	Economy	4000.00
0005434343759	29752	Economy	4000.00
0005434343797	29752	Economy	4000.00
0005434343668	29752	Economy	4000.00
0005434343811	29752	Economy	4000.00
0005434142549	29752	Economy	4000.00
0005435304140	29752	Economy	4000.00
0005434343817	29752	Economy	4000.00
0005435305009	29752	Economy	4000.00
0005435304141	29752	Economy	4000.00
0005434343698	29752	Economy	4000.00
0005435304143	29752	Economy	4000.00
0005435304142	29752	Economy	4000.00
0005434142545	29752	Economy	4000.00
0005435304144	29752	Economy	4000.00
0005434343725	29752	Economy	4000.00
0005434343765	29752	Economy	4000.00
0005434343796	29752	Economy	4000.00
0005435304139	29752	Economy	4000.00
0005434343726	29752	Economy	4000.00
0005434343781	29752	Economy	4000.00
0005434343810	29752	Economy	4000.00
0005434343661	29752	Economy	4000.00
0005434343807	29752	Economy	4000.00
0005434343751	29752	Economy	4000.00
0005434343808	29752	Economy	4000.00
0005434343601	29752	Economy	4000.00
0005434343895	29752	Economy	4000.00
0005434343816	29752	Economy	4000.00
0005434343731	29752	Economy	4000.00
0005434142546	29752	Economy	4000.00
0005434343868	29752	Economy	4000.00
0005434343778	29752	Economy	4000.00
0005434343733	29752	Economy	4000.00
0005434343712	29752	Economy	4000.00
0005435305008	29752	Economy	4000.00
0005434343869	29752	Economy	4000.00
0005435824528	1267	Business	199800.00
0005435824523	1267	Business	199800.00
0005435824534	1267	Business	199800.00
0005435824514	1267	Business	199800.00
0005433415489	1267	Business	199800.00
0005435824511	1267	Business	199800.00
0005435824535	1267	Economy	66600.00
0005435824519	1267	Economy	66600.00
0005435824522	1267	Economy	66600.00
0005435824532	1267	Economy	66600.00
0005435824525	1267	Economy	66600.00
0005435824516	1267	Economy	66600.00
0005433415454	1267	Economy	73200.00
0005435824520	1267	Economy	66600.00
0005433415469	1267	Economy	66600.00
0005433415483	1267	Economy	66600.00
0005432284546	1267	Economy	66600.00
0005435824509	1267	Economy	66600.00
0005433415509	1267	Economy	66600.00
0005435824513	1267	Economy	66600.00
0005432284547	1267	Economy	66600.00
0005435824510	1267	Economy	66600.00
0005435824531	1267	Economy	66600.00
0005435824530	1267	Economy	66600.00
0005435824517	1267	Economy	66600.00
0005435824529	1267	Economy	66600.00
0005435824515	1267	Economy	66600.00
0005435824533	1267	Economy	66600.00
0005433415523	1267	Economy	66600.00
0005435824521	1267	Economy	66600.00
0005433415536	1267	Economy	66600.00
0005435824526	1267	Economy	66600.00
0005435824524	1267	Economy	66600.00
0005433415474	1267	Economy	66600.00
0005433415481	1267	Economy	66600.00
0005433415482	1267	Economy	66600.00
0005435824518	1267	Economy	66600.00
0005433415473	1267	Economy	66600.00
0005435824527	1267	Economy	66600.00
0005435824512	1267	Economy	66600.00
0005435824307	18014	Business	199800.00
0005435824266	18014	Business	199800.00
0005435824407	18014	Business	199800.00
0005433415598	18014	Business	199800.00
0005433415595	18014	Business	199800.00
0005433415603	18014	Economy	66600.00
0005433415597	18014	Economy	66600.00
0005435824239	18014	Economy	66600.00
0005435824350	18014	Economy	66600.00
0005435824280	18014	Economy	66600.00
0005433415604	18014	Economy	73200.00
0005433415605	18014	Economy	66600.00
0005435824410	18014	Economy	66600.00
0005433415600	18014	Economy	66600.00
0005433415602	18014	Economy	66600.00
0005435824351	18014	Economy	66600.00
0005435824349	18014	Economy	66600.00
0005435824268	18014	Economy	66600.00
0005433415593	18014	Economy	66600.00
0005435824309	18014	Economy	66600.00
0005435824370	18014	Economy	66600.00
0005435824248	18014	Economy	66600.00
0005435824267	18014	Economy	66600.00
0005435824276	18014	Economy	66600.00
0005435824225	18014	Economy	66600.00
0005435824299	18014	Economy	66600.00
0005435824254	18014	Economy	66600.00
0005435824244	18014	Economy	66600.00
0005433415592	18014	Economy	66600.00
0005433415591	18014	Economy	66600.00
0005433415596	18014	Economy	66600.00
0005435824348	18014	Economy	66600.00
0005433415601	18014	Economy	66600.00
0005433415594	18014	Economy	66600.00
0005435824236	18014	Economy	66600.00
0005435824238	18014	Economy	66600.00
0005435824199	18014	Economy	66600.00
0005435824235	18014	Economy	66600.00
0005433415599	18014	Economy	66600.00
0005435824243	18014	Economy	66600.00
0005434460478	17521	Economy	14800.00
0005434460480	17521	Economy	14800.00
0005434462765	17521	Economy	13500.00
0005434462754	17521	Economy	13500.00
0005434460483	17521	Economy	13500.00
0005434462760	17521	Economy	13500.00
0005434460475	17521	Economy	13500.00
0005434462758	17521	Economy	13500.00
0005434460471	17521	Economy	13500.00
0005434462753	17521	Economy	13500.00
0005434462755	17521	Economy	13500.00
0005434460474	17521	Economy	13500.00
0005434462759	17521	Economy	13500.00
0005434462764	17521	Economy	13500.00
0005434462756	17521	Economy	13500.00
0005434460482	17521	Economy	13500.00
0005434460481	17521	Economy	13500.00
0005435242447	5651	Business	27800.00
0005435242516	5651	Business	27800.00
0005432783589	5651	Business	27800.00
0005432783578	5651	Business	27800.00
0005432783582	5651	Business	27800.00
0005435242439	5651	Business	27800.00
0005435242528	5651	Business	27800.00
0005432783595	5651	Business	27800.00
0005435242498	5651	Business	27800.00
0005432783574	5651	Business	27800.00
0005432783600	5651	Business	27800.00
0005435476702	5651	Economy	9300.00
0005432783594	5651	Economy	9300.00
0005432783560	5651	Economy	9300.00
0005432783586	5651	Economy	9300.00
0005435242473	5651	Economy	9300.00
0005435242460	5651	Economy	9300.00
0005435242514	5651	Economy	9300.00
0005435242574	5651	Economy	9300.00
0005435242625	5651	Economy	9300.00
0005432783590	5651	Economy	9300.00
0005432783584	5651	Economy	10200.00
0005435242462	5651	Economy	10200.00
0005435476703	5651	Economy	10200.00
0005432783604	5651	Economy	10200.00
0005435242561	5651	Economy	9300.00
0005432783571	5651	Economy	9300.00
0005435476700	5651	Economy	9300.00
0005432783579	5651	Economy	9300.00
0005435242560	5651	Economy	9300.00
0005432783562	5651	Economy	9300.00
0005432783564	5651	Economy	9300.00
0005432783597	5651	Economy	9300.00
0005432783566	5651	Economy	9300.00
0005432783575	5651	Economy	9300.00
0005432783580	5651	Economy	9300.00
0005432143975	5651	Economy	9300.00
0005435476666	5651	Economy	9300.00
0005435242491	5651	Economy	9300.00
0005432783563	5651	Economy	9300.00
0005432783577	5651	Economy	9300.00
0005435242502	5651	Economy	9300.00
0005432783581	5651	Economy	9300.00
0005432783591	5651	Economy	9300.00
0005432783569	5651	Economy	9300.00
0005432783554	5651	Economy	9300.00
0005432783572	5651	Economy	9300.00
0005432783567	5651	Economy	9300.00
0005435242537	5651	Economy	9300.00
0005435242474	5651	Economy	9300.00
0005432143973	5651	Economy	9300.00
0005432783568	5651	Economy	9300.00
0005435242427	5651	Economy	9300.00
0005432783592	5651	Economy	9300.00
0005432783556	5651	Economy	9300.00
0005432783607	5651	Economy	9300.00
0005432783559	5651	Economy	9300.00
0005435242562	5651	Economy	9300.00
0005435476678	5651	Economy	9300.00
0005432783573	5651	Economy	9300.00
0005432783565	5651	Economy	9300.00
0005432783583	5651	Economy	9300.00
0005432783608	5651	Economy	9300.00
0005432783558	5651	Economy	9300.00
0005432783606	5651	Economy	9300.00
0005435242461	5651	Economy	9300.00
0005432143974	5651	Economy	9300.00
0005435476665	5651	Economy	9300.00
0005435242492	5651	Economy	9300.00
0005432783598	5651	Economy	9300.00
0005435242538	5651	Economy	9300.00
0005432783599	5651	Economy	9300.00
0005432783605	5651	Economy	9300.00
0005435242417	5651	Economy	9300.00
0005432783555	5651	Economy	9300.00
0005435242463	5651	Economy	9300.00
0005432783588	5651	Economy	9300.00
0005432783587	5651	Economy	9300.00
0005432783576	5651	Economy	9300.00
0005432783570	5651	Economy	9300.00
0005432783603	5651	Economy	9300.00
0005432783601	5651	Economy	9300.00
0005432783596	5651	Economy	9300.00
0005432783585	5651	Economy	9300.00
0005435476667	5651	Economy	9300.00
0005435242515	5651	Economy	9300.00
0005432783593	5651	Economy	9300.00
0005432783602	5651	Economy	9300.00
0005432783561	5651	Economy	9300.00
0005432783557	5651	Economy	9300.00
0005435476677	5651	Economy	9300.00
0005432782914	15374	Business	27800.00
0005432783083	15374	Business	27800.00
0005432783218	15374	Business	27800.00
0005432782972	15374	Business	27800.00
0005432783055	15374	Business	27800.00
0005432783177	15374	Business	27800.00
0005432782994	15374	Business	27800.00
0005432783074	15374	Business	27800.00
0005432783187	15374	Business	27800.00
0005432783183	15374	Business	27800.00
0005432782925	15374	Business	27800.00
0005432783105	15374	Business	27800.00
0005432782997	15374	Economy	9300.00
0005432782976	15374	Economy	9300.00
0005432782913	15374	Economy	9300.00
0005432783172	15374	Economy	9300.00
0005435242727	15374	Economy	9300.00
0005432783048	15374	Economy	9300.00
0005432783038	15374	Economy	9300.00
0005435242737	15374	Economy	9300.00
0005432782965	15374	Economy	9300.00
0005432783084	15374	Economy	9300.00
0005432783116	15374	Economy	10200.00
0005435242721	15374	Economy	10200.00
0005432782966	15374	Economy	10200.00
0005435242732	15374	Economy	10200.00
0005432783139	15374	Economy	10200.00
0005435242720	15374	Economy	9300.00
0005432783082	15374	Economy	9300.00
0005432782861	15374	Economy	9300.00
0005432783097	15374	Economy	9300.00
0005432783265	15374	Economy	9300.00
0005432782912	15374	Economy	9300.00
0005432782963	15374	Economy	9300.00
0005432782998	15374	Economy	9300.00
0005435242736	15374	Economy	9300.00
0005432782986	15374	Economy	9300.00
0005435242722	15374	Economy	9300.00
0005432783035	15374	Economy	9300.00
0005435242731	15374	Economy	9300.00
0005432783119	15374	Economy	9300.00
0005432783065	15374	Economy	9300.00
0005432783125	15374	Economy	9300.00
0005432782928	15374	Economy	9300.00
0005432783037	15374	Economy	9300.00
0005435242728	15374	Economy	9300.00
0005432782910	15374	Economy	9300.00
0005435242734	15374	Economy	9300.00
0005435242738	15374	Economy	9300.00
0005432782982	15374	Economy	9300.00
0005432783004	15374	Economy	9300.00
0005432783104	15374	Economy	9300.00
0005435242740	15374	Economy	9300.00
0005432783129	15374	Economy	9300.00
0005435242733	15374	Economy	9300.00
0005432782926	15374	Economy	9300.00
0005432783036	15374	Economy	9300.00
0005435242723	15374	Economy	9300.00
0005432783320	15374	Economy	9300.00
0005432782945	15374	Economy	9300.00
0005432783256	15374	Economy	9300.00
0005435242739	15374	Economy	9300.00
0005435242735	15374	Economy	9300.00
0005432783096	15374	Economy	9300.00
0005432783003	15374	Economy	9300.00
0005432782915	15374	Economy	9300.00
0005432782920	15374	Economy	9300.00
0005432782973	15374	Economy	9300.00
0005432783095	15374	Economy	9300.00
0005432783184	15374	Economy	9300.00
0005432783197	15374	Economy	9300.00
0005432782977	15374	Economy	9300.00
0005432783264	15374	Economy	9300.00
0005432783064	15374	Economy	9300.00
0005432783219	15374	Economy	9300.00
0005432783195	15374	Economy	9300.00
0005432782858	15374	Economy	9300.00
0005432782927	15374	Economy	9300.00
0005432782981	15374	Economy	9300.00
0005435242730	15374	Economy	9300.00
0005432783270	15374	Economy	9300.00
0005432783066	15374	Economy	9300.00
0005432782975	15374	Economy	9300.00
0005432782974	15374	Economy	9300.00
0005432783319	15374	Economy	9300.00
0005432783196	15374	Economy	9300.00
0005435242726	15374	Economy	9300.00
0005432783061	15374	Economy	9300.00
0005435242729	15374	Economy	9300.00
0005432783081	15374	Economy	9300.00
0005435242725	15374	Economy	9300.00
0005435242724	15374	Economy	9300.00
0005432783171	15374	Economy	9300.00
0005432782859	15374	Economy	9300.00
0005435242741	15374	Economy	9300.00
0005432782903	15374	Economy	9300.00
0005432782862	15374	Economy	9300.00
0005435850790	4360	Economy	7000.00
0005435850795	4360	Economy	7000.00
0005434462782	4360	Economy	6300.00
0005432848258	4360	Economy	6300.00
0005432848256	4360	Economy	6300.00
0005434462781	4360	Economy	6300.00
0005435850849	4360	Economy	6300.00
0005434463920	4360	Economy	6300.00
0005432848263	4360	Economy	6300.00
0005432848249	4360	Economy	6300.00
0005432848251	4360	Economy	6300.00
0005432848260	4360	Economy	6300.00
0005432848248	4360	Economy	6300.00
0005435850819	4360	Economy	6300.00
0005432848253	4360	Economy	6300.00
0005432848262	4360	Economy	6300.00
0005435850820	4360	Economy	6300.00
0005432848250	4360	Economy	6300.00
0005432848255	4360	Economy	6300.00
0005432848257	4360	Economy	6300.00
0005435850818	4360	Economy	6300.00
0005432848252	4360	Economy	6300.00
0005432848259	4360	Economy	6300.00
0005432848254	4360	Economy	6300.00
0005434463921	4360	Economy	6300.00
0005432848261	4360	Economy	6300.00
0005435850837	4360	Economy	6300.00
0005432848091	28874	Economy	7000.00
0005432848174	28874	Economy	7000.00
0005432848118	28874	Economy	7000.00
0005432848159	28874	Economy	6300.00
0005435850877	28874	Economy	6300.00
0005432848104	28874	Economy	6300.00
0005435850876	28874	Economy	6300.00
0005432848094	28874	Economy	6300.00
0005432848173	28874	Economy	6300.00
0005435850878	28874	Economy	6300.00
0005432848184	28874	Economy	6300.00
0005432848147	28874	Economy	6300.00
0005435850870	28874	Economy	6300.00
0005432848102	28874	Economy	6300.00
0005432848067	28874	Economy	6300.00
0005432848103	28874	Economy	6300.00
0005432848124	28874	Economy	6300.00
0005435850873	28874	Economy	6300.00
0005432848120	28874	Economy	6300.00
0005432848155	28874	Economy	6300.00
0005432848156	28874	Economy	6300.00
0005432848068	28874	Economy	6300.00
0005434463906	28874	Economy	6300.00
0005435850871	28874	Economy	6300.00
0005432848092	28874	Economy	6300.00
0005432848123	28874	Economy	6300.00
0005435850872	28874	Economy	6300.00
0005432848095	28874	Economy	6300.00
0005432848117	28874	Economy	6300.00
0005432848131	28874	Economy	6300.00
0005435850879	28874	Economy	6300.00
0005432848119	28874	Economy	6300.00
0005435850880	28874	Economy	6300.00
0005432848157	28874	Economy	6300.00
0005432848075	28874	Economy	6300.00
0005434463904	28874	Economy	6300.00
0005435850874	28874	Economy	6300.00
0005435850875	28874	Economy	6300.00
0005434925705	6297	Business	11900.00
0005433496865	6297	Business	11900.00
0005432075216	6297	Business	11900.00
0005434925682	6297	Business	11900.00
0005434443649	6297	Business	11900.00
0005434925685	6297	Business	11900.00
0005434443651	6297	Business	11900.00
0005433496835	6297	Business	11900.00
0005434925713	6297	Business	11900.00
0005434925692	6297	Business	11900.00
0005433496854	6297	Business	11900.00
0005433496857	6297	Business	11900.00
0005434443646	6297	Economy	4000.00
0005434925707	6297	Economy	4000.00
0005434925704	6297	Economy	4000.00
0005433496858	6297	Economy	4000.00
0005433496849	6297	Economy	4000.00
0005434443640	6297	Economy	4000.00
0005434925693	6297	Economy	4000.00
0005434925696	6297	Economy	4000.00
0005434925712	6297	Economy	4000.00
0005434925706	6297	Economy	4400.00
0005434925703	6297	Economy	4400.00
0005433496839	6297	Economy	4400.00
0005434925700	6297	Economy	4400.00
0005433496850	6297	Economy	4400.00
0005433496842	6297	Economy	4000.00
0005434443648	6297	Economy	4000.00
0005433496843	6297	Economy	4000.00
0005433496860	6297	Economy	4000.00
0005434443645	6297	Economy	4000.00
0005434925694	6297	Economy	4000.00
0005433496848	6297	Economy	4000.00
0005434925695	6297	Economy	4000.00
0005434443641	6297	Economy	4000.00
0005433496836	6297	Economy	4000.00
0005434925702	6297	Economy	4000.00
0005434443653	6297	Economy	4000.00
0005434925711	6297	Economy	4000.00
0005434925678	6297	Economy	4000.00
0005434443650	6297	Economy	4000.00
0005434443642	6297	Economy	4000.00
0005433496847	6297	Economy	4000.00
0005433496845	6297	Economy	4000.00
0005433496844	6297	Economy	4000.00
0005434443644	6297	Economy	4000.00
0005434925687	6297	Economy	4000.00
0005433496837	6297	Economy	4000.00
0005434925715	6297	Economy	4000.00
0005433496859	6297	Economy	4000.00
0005434925691	6297	Economy	4000.00
0005434925679	6297	Economy	4000.00
0005432075218	6297	Economy	4000.00
0005433496852	6297	Economy	4000.00
0005433496853	6297	Economy	4000.00
0005434443654	6297	Economy	4000.00
0005434925689	6297	Economy	4000.00
0005434925714	6297	Economy	4000.00
0005434925681	6297	Economy	4000.00
0005433496861	6297	Economy	4000.00
0005433496838	6297	Economy	4000.00
0005434925680	6297	Economy	4000.00
0005433496840	6297	Economy	4000.00
0005434925683	6297	Economy	4000.00
0005433496851	6297	Economy	4000.00
0005433496856	6297	Economy	4000.00
0005432075215	6297	Economy	4000.00
0005434925699	6297	Economy	4000.00
0005434443638	6297	Economy	4000.00
0005434443647	6297	Economy	4000.00
0005433496841	6297	Economy	4000.00
0005434925701	6297	Economy	4000.00
0005434925708	6297	Economy	4000.00
0005434925686	6297	Economy	4000.00
0005433496864	6297	Economy	4000.00
0005434925690	6297	Economy	4000.00
0005432075217	6297	Economy	4000.00
0005434443652	6297	Economy	4000.00
0005434925710	6297	Economy	4000.00
0005434443643	6297	Economy	4000.00
0005434443639	6297	Economy	4000.00
0005433496863	6297	Economy	4000.00
0005433496862	6297	Economy	4000.00
0005434925709	6297	Economy	4000.00
0005434925697	6297	Economy	4000.00
0005433496855	6297	Economy	4000.00
0005434925684	6297	Economy	4000.00
0005434925688	6297	Economy	4000.00
0005434925716	6297	Economy	4000.00
0005434925698	6297	Economy	4000.00
0005433496846	6297	Economy	4000.00
0005434443507	20384	Business	11900.00
0005433496680	20384	Business	11900.00
0005434443492	20384	Business	11900.00
0005433496682	20384	Business	11900.00
0005433496626	20384	Business	11900.00
0005434443427	20384	Business	11900.00
0005433496671	20384	Business	11900.00
0005434443506	20384	Business	11900.00
0005434925346	20384	Business	11900.00
0005434925334	20384	Business	11900.00
0005434925316	20384	Business	11900.00
0005434925256	20384	Economy	4000.00
0005434443441	20384	Economy	4000.00
0005433496686	20384	Economy	4000.00
0005434443501	20384	Economy	4000.00
0005434925294	20384	Economy	4000.00
0005433496519	20384	Economy	4000.00
0005433496613	20384	Economy	4000.00
0005433496511	20384	Economy	4000.00
0005434443485	20384	Economy	4000.00
0005433496559	20384	Economy	4000.00
0005434925289	20384	Economy	4400.00
0005433496547	20384	Economy	4400.00
0005433496579	20384	Economy	4400.00
0005434443534	20384	Economy	4400.00
0005433496627	20384	Economy	4400.00
0005433496685	20384	Economy	4000.00
0005433496681	20384	Economy	4000.00
0005433496570	20384	Economy	4000.00
0005434925318	20384	Economy	4000.00
0005434443426	20384	Economy	4000.00
0005434925345	20384	Economy	4000.00
0005434925322	20384	Economy	4000.00
0005434925255	20384	Economy	4000.00
0005433496512	20384	Economy	4000.00
0005434443494	20384	Economy	4000.00
0005433496608	20384	Economy	4000.00
0005433496553	20384	Economy	4000.00
0005434925323	20384	Economy	4000.00
0005434443462	20384	Economy	4000.00
0005434925298	20384	Economy	4000.00
0005434925342	20384	Economy	4000.00
0005434925258	20384	Economy	4000.00
0005433496591	20384	Economy	4000.00
0005433496758	20384	Economy	4000.00
0005433496585	20384	Economy	4000.00
0005433496675	20384	Economy	4000.00
0005434443466	20384	Economy	4000.00
0005434925251	20384	Economy	4000.00
0005434925259	20384	Economy	4000.00
0005434443519	20384	Economy	4000.00
0005433496510	20384	Economy	4000.00
0005433496714	20384	Economy	4000.00
0005434443493	20384	Economy	4000.00
0005434925297	20384	Economy	4000.00
0005433496676	20384	Economy	4000.00
0005433496520	20384	Economy	4000.00
0005434443537	20384	Economy	4000.00
0005433496455	20384	Economy	4000.00
0005433496542	20384	Economy	4000.00
0005434443533	20384	Economy	4000.00
0005433496560	20384	Economy	4000.00
0005433496658	20384	Economy	4000.00
0005434443465	20384	Economy	4000.00
0005433496739	20384	Economy	4000.00
0005433496783	20384	Economy	4000.00
0005434443526	20384	Economy	4000.00
0005433496580	20384	Economy	4000.00
0005434443468	20384	Economy	4000.00
0005433496651	20384	Economy	4000.00
0005433496607	20384	Economy	4000.00
0005433496601	20384	Economy	4000.00
0005434925352	20384	Economy	4000.00
0005434443505	20384	Economy	4000.00
0005433496628	20384	Economy	4000.00
0005433496677	20384	Economy	4000.00
0005434443474	20384	Economy	4000.00
0005433496527	20384	Economy	4000.00
0005433496759	20384	Economy	4000.00
0005434925288	20384	Economy	4000.00
0005433496581	20384	Economy	4000.00
0005433496670	20384	Economy	4000.00
0005433496578	20384	Economy	4000.00
0005434443448	20384	Economy	4000.00
0005434925287	20384	Economy	4000.00
0005434925333	20384	Economy	4000.00
0005434443480	20384	Economy	4000.00
0005434443535	20384	Economy	4000.00
0005433496733	20384	Economy	4000.00
0005432782999	12214	Business	41200.00
0005432783085	12214	Business	41200.00
0005435242746	12214	Business	41200.00
0005432783034	12214	Business	41200.00
0005435242756	12214	Business	41200.00
0005435242760	12214	Business	41200.00
0005432783020	12214	Business	41200.00
0005435242768	12214	Business	41200.00
0005435242754	12214	Business	41200.00
0005432783128	12214	Business	41200.00
0005432783008	12214	Business	41200.00
0005435242751	12214	Economy	13700.00
0005432783268	12214	Economy	13700.00
0005432783203	12214	Economy	13700.00
0005435242767	12214	Economy	13700.00
0005432783109	12214	Economy	13700.00
0005432783209	12214	Economy	13700.00
0005432783049	12214	Economy	13700.00
0005432782979	12214	Economy	13700.00
0005432783346	12214	Economy	13700.00
0005432783150	12214	Economy	13700.00
0005432783280	12214	Economy	15100.00
0005432783230	12214	Economy	15100.00
0005432783541	12214	Economy	15100.00
0005435242747	12214	Economy	15100.00
0005435242765	12214	Economy	15100.00
0005432783149	12214	Economy	13700.00
0005432783148	12214	Economy	13700.00
0005432783056	12214	Economy	13700.00
0005435242750	12214	Economy	13700.00
0005435242744	12214	Economy	13700.00
0005435242753	12214	Economy	13700.00
0005432782985	12214	Economy	13700.00
0005432783275	12214	Economy	13700.00
0005435242752	12214	Economy	13700.00
0005432783267	12214	Economy	13700.00
0005432783158	12214	Economy	13700.00
0005432783086	12214	Economy	13700.00
0005432783007	12214	Economy	13700.00
0005435242743	12214	Economy	13700.00
0005432782932	12214	Economy	13700.00
0005435242762	12214	Economy	13700.00
0005432783161	12214	Economy	13700.00
0005432783147	12214	Economy	13700.00
0005432783067	12214	Economy	13700.00
0005435242742	12214	Economy	13700.00
0005432783325	12214	Economy	13700.00
0005432782996	12214	Economy	13700.00
0005432783000	12214	Economy	13700.00
0005432783208	12214	Economy	13700.00
0005432783050	12214	Economy	13700.00
0005435242748	12214	Economy	13700.00
0005435242766	12214	Economy	13700.00
0005432782933	12214	Economy	13700.00
0005432782978	12214	Economy	13700.00
0005432782878	12214	Economy	13700.00
0005432783210	12214	Economy	13700.00
0005432783181	12214	Economy	13700.00
0005435242758	12214	Economy	13700.00
0005435242764	12214	Economy	13700.00
0005435242761	12214	Economy	13700.00
0005435242749	12214	Economy	13700.00
0005435242763	12214	Economy	13700.00
0005432783377	12214	Economy	13700.00
0005432783186	12214	Economy	13700.00
0005432783146	12214	Economy	13700.00
0005432783127	12214	Economy	13700.00
0005432783211	12214	Economy	13700.00
0005435242745	12214	Economy	13700.00
0005432783140	12214	Economy	13700.00
0005432783120	12214	Economy	13700.00
0005432783540	12214	Economy	13700.00
0005432783043	12214	Economy	13700.00
0005432783030	12214	Economy	13700.00
0005435242755	12214	Economy	13700.00
0005432783028	12214	Economy	13700.00
0005432783281	12214	Economy	13700.00
0005432783163	12214	Economy	13700.00
0005432783180	12214	Economy	13700.00
0005432782935	12214	Economy	13700.00
0005432783199	12214	Economy	13700.00
0005432783029	12214	Economy	13700.00
0005432782958	12214	Economy	13700.00
0005432782980	12214	Economy	13700.00
0005432783159	12214	Economy	13700.00
0005432783157	12214	Economy	13700.00
0005432783058	12214	Economy	13700.00
0005435242757	12214	Economy	13700.00
0005435242759	12214	Economy	13700.00
0005435242769	12214	Economy	13700.00
0005432783115	12214	Economy	13700.00
0005432783517	15416	Business	41200.00
0005435242486	15416	Business	41200.00
0005435242444	15416	Business	41200.00
0005435242455	15416	Business	41200.00
0005432783547	15416	Business	41200.00
0005432783526	15416	Business	41200.00
0005432783550	15416	Business	41200.00
0005432783540	15416	Business	41200.00
0005435242579	15416	Business	41200.00
0005432783545	15416	Economy	13700.00
0005432783546	15416	Economy	13700.00
0005432783502	15416	Economy	13700.00
0005435242426	15416	Economy	13700.00
0005435242487	15416	Economy	13700.00
0005432783501	15416	Economy	13700.00
0005432783538	15416	Economy	13700.00
0005432783544	15416	Economy	13700.00
0005435242434	15416	Economy	13700.00
0005432783520	15416	Economy	15100.00
0005435242610	15416	Economy	15100.00
0005435242501	15416	Economy	15100.00
0005432783537	15416	Economy	15100.00
0005435242608	15416	Economy	15100.00
0005435242438	15416	Economy	13700.00
0005432783505	15416	Economy	13700.00
0005432783548	15416	Economy	13700.00
0005432783503	15416	Economy	13700.00
0005435242500	15416	Economy	13700.00
0005432783521	15416	Economy	13700.00
0005432783529	15416	Economy	13700.00
0005432783527	15416	Economy	13700.00
0005432783533	15416	Economy	13700.00
0005432783515	15416	Economy	13700.00
0005432783509	15416	Economy	13700.00
0005432783541	15416	Economy	13700.00
0005432783512	15416	Economy	13700.00
0005432783508	15416	Economy	13700.00
0005432783504	15416	Economy	13700.00
0005432783542	15416	Economy	13700.00
0005435242607	15416	Economy	13700.00
0005432783525	15416	Economy	13700.00
0005432783514	15416	Economy	13700.00
0005435242485	15416	Economy	13700.00
0005432783543	15416	Economy	13700.00
0005435242421	15416	Economy	13700.00
0005435242496	15416	Economy	13700.00
0005432783516	15416	Economy	13700.00
0005432783524	15416	Economy	13700.00
0005432783511	15416	Economy	13700.00
0005432783551	15416	Economy	13700.00
0005432783549	15416	Economy	13700.00
0005435242484	15416	Economy	13700.00
0005432783531	15416	Economy	13700.00
0005432783522	15416	Economy	13700.00
0005432783519	15416	Economy	13700.00
0005435242420	15416	Economy	13700.00
0005432783518	15416	Economy	13700.00
0005435242527	15416	Economy	13700.00
0005432783513	15416	Economy	13700.00
0005432783506	15416	Economy	13700.00
0005432783523	15416	Economy	13700.00
0005432783536	15416	Economy	13700.00
0005435242494	15416	Economy	13700.00
0005432783552	15416	Economy	13700.00
0005432783528	15416	Economy	13700.00
0005432783535	15416	Economy	13700.00
0005432783532	15416	Economy	13700.00
0005432783510	15416	Economy	13700.00
0005432783499	15416	Economy	13700.00
0005435242445	15416	Economy	13700.00
0005435242521	15416	Economy	13700.00
0005432783500	15416	Economy	13700.00
0005432783553	15416	Economy	13700.00
0005432783534	15416	Economy	13700.00
0005435242495	15416	Economy	13700.00
0005432783530	15416	Economy	13700.00
0005435242609	15416	Economy	13700.00
0005432783507	15416	Economy	13700.00
0005435242469	15416	Economy	13700.00
0005432783539	15416	Economy	13700.00
0005435242419	15416	Economy	13700.00
0005434877211	10119	Business	49700.00
0005434876816	10119	Business	49700.00
0005434877070	10119	Business	49700.00
0005434877302	10119	Business	49700.00
0005434877068	10119	Business	49700.00
0005434876827	10119	Business	49700.00
0005434876933	10119	Business	49700.00
0005434877140	10119	Business	49700.00
0005434877185	10119	Business	49700.00
0005434876749	10119	Business	49700.00
0005434876818	10119	Business	49700.00
0005434877209	10119	Business	49700.00
0005434877020	10119	Business	49700.00
0005434876786	10119	Business	49700.00
0005434876863	10119	Business	49700.00
0005434877430	10119	Business	49700.00
0005434876762	10119	Business	49700.00
0005434877103	10119	Business	49700.00
0005434877213	10119	Business	49700.00
0005434877119	10119	Economy	16600.00
0005434877006	10119	Economy	16600.00
0005434876955	10119	Economy	16600.00
0005434877412	10119	Economy	16600.00
0005434877098	10119	Economy	16600.00
0005434876754	10119	Economy	16600.00
0005434877034	10119	Economy	16600.00
0005434876830	10119	Economy	16600.00
0005434876992	10119	Economy	16600.00
0005434877393	10119	Economy	16600.00
0005434876821	10119	Economy	16600.00
0005434877347	10119	Economy	16600.00
0005434876978	10119	Economy	16600.00
0005434877198	10119	Economy	18200.00
0005434877122	10119	Economy	18200.00
0005434877073	10119	Economy	18200.00
0005434877210	10119	Economy	18200.00
0005434876787	10119	Economy	16600.00
0005434877036	10119	Economy	16600.00
0005434876814	10119	Economy	16600.00
0005434876558	10119	Economy	16600.00
0005434876856	10119	Economy	16600.00
0005434877243	10119	Economy	16600.00
0005434876964	10119	Economy	16600.00
0005434877177	10119	Economy	16600.00
0005434877081	10119	Economy	16600.00
0005434877021	10119	Economy	16600.00
0005434877067	10119	Economy	16600.00
0005434877104	10119	Economy	16600.00
0005434876977	10119	Economy	16600.00
0005434876979	10119	Economy	16600.00
0005434877189	10119	Economy	16600.00
0005434877301	10119	Economy	16600.00
0005434877055	10119	Economy	16600.00
0005434876764	10119	Economy	16600.00
0005434877348	10119	Economy	16600.00
0005434877355	10119	Economy	16600.00
0005434876991	10119	Economy	16600.00
0005434877056	10119	Economy	16600.00
0005434877339	10119	Economy	16600.00
0005434877194	10119	Economy	16600.00
0005434876750	10119	Economy	16600.00
0005434877139	10119	Economy	16600.00
0005434877299	10119	Economy	16600.00
0005434877130	10119	Economy	16600.00
0005434877019	10119	Economy	16600.00
0005434877023	10119	Economy	16600.00
0005434877242	10119	Economy	16600.00
0005434877058	10119	Economy	16600.00
0005434877190	10119	Economy	16600.00
0005434876917	10119	Economy	16600.00
0005434876983	10119	Economy	16600.00
0005434877080	10119	Economy	16600.00
0005434877131	10119	Economy	16600.00
0005434876956	10119	Economy	16600.00
0005434877035	10119	Economy	16600.00
0005434876993	10119	Economy	16600.00
0005434876867	10119	Economy	16600.00
0005434876763	10119	Economy	16600.00
0005434877057	10119	Economy	16600.00
0005434877132	10119	Economy	16600.00
0005434876971	10119	Economy	16600.00
0005434876916	10119	Economy	16600.00
0005434877278	10119	Economy	16600.00
0005434876973	10119	Economy	16600.00
0005434876855	10119	Economy	16600.00
0005434876829	10119	Economy	16600.00
0005434876972	10119	Economy	16600.00
0005434876969	10119	Economy	16600.00
0005434758868	10119	Economy	16600.00
0005434877178	10119	Economy	16600.00
0005434876834	10119	Economy	16600.00
0005434877227	10119	Economy	16600.00
0005434876828	10119	Economy	16600.00
0005434877394	10119	Economy	16600.00
0005434876694	10119	Economy	16600.00
0005434876925	10119	Economy	16600.00
0005434877373	10119	Economy	16600.00
0005434877255	10119	Economy	16600.00
0005434877260	10119	Economy	16600.00
0005434876974	10119	Economy	16600.00
0005434877413	10119	Economy	16600.00
0005434876815	10119	Economy	16600.00
0005434877338	10119	Economy	16600.00
0005434877118	10119	Economy	16600.00
0005434877079	10119	Economy	16600.00
0005434877039	10119	Economy	16600.00
0005434877292	10119	Economy	16600.00
0005434876932	10119	Economy	16600.00
0005434877191	10119	Economy	16600.00
0005434877123	10119	Economy	16600.00
0005434876985	10119	Economy	16600.00
0005434876864	10119	Economy	16600.00
0005434877852	14634	Business	49700.00
0005434877867	14634	Business	49700.00
0005434877906	14634	Business	49700.00
0005434877819	14634	Business	49700.00
0005434877842	14634	Business	49700.00
0005434877893	14634	Business	49700.00
0005434877877	14634	Business	49700.00
0005434877879	14634	Business	49700.00
0005435913867	14634	Business	49700.00
0005434877898	14634	Business	49700.00
0005434877858	14634	Business	49700.00
0005434877834	14634	Business	49700.00
0005434877865	14634	Business	49700.00
0005434877887	14634	Business	49700.00
0005434877856	14634	Business	49700.00
0005434877888	14634	Business	49700.00
0005434877826	14634	Business	49700.00
0005434877818	14634	Business	49700.00
0005434877904	14634	Economy	16600.00
0005434877871	14634	Economy	16600.00
0005434877870	14634	Economy	16600.00
0005434877894	14634	Economy	16600.00
0005434877881	14634	Economy	16600.00
0005434877885	14634	Economy	16600.00
0005434877859	14634	Economy	16600.00
0005434877862	14634	Economy	16600.00
0005434877830	14634	Economy	16600.00
0005434877882	14634	Economy	18200.00
0005434877857	14634	Economy	18200.00
0005434877835	14634	Economy	18200.00
0005434877874	14634	Economy	16600.00
0005434877838	14634	Economy	16600.00
0005434877861	14634	Economy	16600.00
0005434877848	14634	Economy	16600.00
0005434877843	14634	Economy	16600.00
0005434877841	14634	Economy	16600.00
0005434877899	14634	Economy	16600.00
0005434877850	14634	Economy	16600.00
0005434877910	14634	Economy	16600.00
0005434877889	14634	Economy	16600.00
0005434877845	14634	Economy	16600.00
0005434877831	14634	Economy	16600.00
0005434877901	14634	Economy	16600.00
0005434877822	14634	Economy	16600.00
0005434877876	14634	Economy	16600.00
0005434877892	14634	Economy	16600.00
0005434877897	14634	Economy	16600.00
0005434910074	14634	Economy	16600.00
0005434877816	14634	Economy	16600.00
0005434877868	14634	Economy	16600.00
0005434877839	14634	Economy	16600.00
0005435913863	14634	Economy	16600.00
0005434877828	14634	Economy	16600.00
0005434877860	14634	Economy	16600.00
0005434877833	14634	Economy	16600.00
0005434877905	14634	Economy	16600.00
0005434877851	14634	Economy	16600.00
0005435913856	14634	Economy	16600.00
0005434877825	14634	Economy	16600.00
0005434877875	14634	Economy	16600.00
0005434877866	14634	Economy	16600.00
0005435913864	14634	Economy	16600.00
0005434877854	14634	Economy	16600.00
0005434877864	14634	Economy	16600.00
0005434877873	14634	Economy	16600.00
0005434877907	14634	Economy	16600.00
0005434877853	14634	Economy	16600.00
0005434877855	14634	Economy	16600.00
0005434877872	14634	Economy	16600.00
0005434877886	14634	Economy	16600.00
0005434877820	14634	Economy	16600.00
0005434758883	14634	Economy	16600.00
0005434877847	14634	Economy	16600.00
0005434877840	14634	Economy	16600.00
0005434877832	14634	Economy	16600.00
0005434877869	14634	Economy	16600.00
0005434877890	14634	Economy	16600.00
0005434877827	14634	Economy	16600.00
0005434758884	14634	Economy	16600.00
0005435913858	14634	Economy	16600.00
0005434877896	14634	Economy	16600.00
0005434877902	14634	Economy	16600.00
0005434877829	14634	Economy	16600.00
0005434877844	14634	Economy	16600.00
0005434877880	14634	Economy	16600.00
0005434877849	14634	Economy	16600.00
0005434877823	14634	Economy	16600.00
0005434877821	14634	Economy	16600.00
0005434877863	14634	Economy	16600.00
0005434877846	14634	Economy	16600.00
0005434877878	14634	Economy	16600.00
0005435913866	14634	Economy	16600.00
0005434877909	14634	Economy	16600.00
0005434877900	14634	Economy	16600.00
0005434877837	14634	Economy	16600.00
0005434877895	14634	Economy	16600.00
0005434877903	14634	Economy	16600.00
0005434877908	14634	Economy	16600.00
0005435913865	14634	Economy	16600.00
0005434877884	14634	Economy	16600.00
0005434877824	14634	Economy	16600.00
0005434877817	14634	Economy	16600.00
0005434877883	14634	Economy	16600.00
0005434877836	14634	Economy	16600.00
0005434877891	14634	Economy	16600.00
0005435660092	9226	Economy	22400.00
0005434251847	9226	Economy	22400.00
0005435660089	9226	Economy	20300.00
0005435660090	9226	Economy	20300.00
0005434251842	9226	Economy	20300.00
0005435660093	9226	Economy	20300.00
0005435660094	9226	Economy	20300.00
0005434251850	9226	Economy	20300.00
0005434251840	9226	Economy	20300.00
0005435660091	9226	Economy	20300.00
0005434251861	9226	Economy	20300.00
0005435660097	9226	Economy	20300.00
0005434251823	9226	Economy	20300.00
0005434251839	9226	Economy	20300.00
0005434251822	9226	Economy	20300.00
0005434251849	9226	Economy	20300.00
0005434251856	9226	Economy	20300.00
0005435660088	9226	Economy	20300.00
0005434251855	9226	Economy	20300.00
0005434251846	9226	Economy	20300.00
0005435660096	9226	Economy	20300.00
0005434251860	9226	Economy	20300.00
0005435660087	9226	Economy	20300.00
0005435660095	9226	Economy	20300.00
0005434251931	24666	Economy	22400.00
0005435659990	24666	Economy	22400.00
0005434251926	24666	Economy	20300.00
0005434251927	24666	Economy	20300.00
0005434251930	24666	Economy	20300.00
0005435659994	24666	Economy	20300.00
0005434251923	24666	Economy	20300.00
0005434251924	24666	Economy	20300.00
0005435659995	24666	Economy	20300.00
0005434251928	24666	Economy	20300.00
0005435660007	24666	Economy	20300.00
0005434251925	24666	Economy	20300.00
0005435660008	24666	Economy	20300.00
0005434251929	24666	Economy	20300.00
0005433680362	2793	Business	33000.00
0005433680359	2793	Business	33000.00
0005433680384	2793	Business	33000.00
0005433680386	2793	Business	33000.00
0005433680369	2793	Business	33000.00
0005432222758	2793	Business	33000.00
0005433680345	2793	Business	33000.00
0005433680355	2793	Business	33000.00
0005433680373	2793	Business	33000.00
0005432966566	2793	Business	33000.00
0005433680357	2793	Business	33000.00
0005433680379	2793	Economy	11000.00
0005433680349	2793	Economy	11000.00
0005432222763	2793	Economy	11000.00
0005433680368	2793	Economy	11000.00
0005433680392	2793	Economy	11000.00
0005433680352	2793	Economy	11000.00
0005433680380	2793	Economy	11000.00
0005433680377	2793	Economy	11000.00
0005432222762	2793	Economy	11000.00
0005433680381	2793	Economy	12100.00
0005432222760	2793	Economy	12100.00
0005432222759	2793	Economy	12100.00
0005433680358	2793	Economy	12100.00
0005433680363	2793	Economy	12100.00
0005433680356	2793	Economy	11000.00
0005432966641	2793	Economy	11000.00
0005432966610	2793	Economy	11000.00
0005433680382	2793	Economy	11000.00
0005432966724	2793	Economy	11000.00
0005433680348	2793	Economy	11000.00
0005432966587	2793	Economy	11000.00
0005433680367	2793	Economy	11000.00
0005432966654	2793	Economy	11000.00
0005433680353	2793	Economy	11000.00
0005433680390	2793	Economy	11000.00
0005433680366	2793	Economy	11000.00
0005432966711	2793	Economy	11000.00
0005432966749	2793	Economy	11000.00
0005432966751	2793	Economy	11000.00
0005433680376	2793	Economy	11000.00
0005433680375	2793	Economy	11000.00
0005432966666	2793	Economy	11000.00
0005432966509	2793	Economy	11000.00
0005433680347	2793	Economy	11000.00
0005432966655	2793	Economy	11000.00
0005432966573	2793	Economy	11000.00
0005433680365	2793	Economy	11000.00
0005432222761	2793	Economy	11000.00
0005433680378	2793	Economy	11000.00
0005433680387	2793	Economy	11000.00
0005433684411	2793	Economy	11000.00
0005433680346	2793	Economy	11000.00
0005432966635	2793	Economy	11000.00
0005433680364	2793	Economy	11000.00
0005433680372	2793	Economy	11000.00
0005433680383	2793	Economy	11000.00
0005432966572	2793	Economy	11000.00
0005432966598	2793	Economy	11000.00
0005432966530	2793	Economy	11000.00
0005433680354	2793	Economy	11000.00
0005433684412	2793	Economy	11000.00
0005433684410	2793	Economy	11000.00
0005432966723	2793	Economy	11000.00
0005432966638	2793	Economy	11000.00
0005432966617	2793	Economy	11000.00
0005433680385	2793	Economy	11000.00
0005432966661	2793	Economy	11000.00
0005432222764	2793	Economy	11000.00
0005432966662	2793	Economy	11000.00
0005432966750	2793	Economy	11000.00
0005433680370	2793	Economy	11000.00
0005432966649	2793	Economy	11000.00
0005432966565	2793	Economy	11000.00
0005432966585	2793	Economy	11000.00
0005433680351	2793	Economy	11000.00
0005433680361	2793	Economy	11000.00
0005432966667	2793	Economy	11000.00
0005433680360	2793	Economy	11000.00
0005432966611	2793	Economy	11000.00
0005433680371	2793	Economy	11000.00
0005432966586	2793	Economy	11000.00
0005433680350	2793	Economy	11000.00
0005433680389	2793	Economy	11000.00
0005432966725	2793	Economy	11000.00
0005433680374	2793	Economy	11000.00
0005433680391	2793	Economy	11000.00
0005432966558	2793	Economy	11000.00
0005433680388	2793	Economy	11000.00
0005432966640	2793	Economy	11000.00
0005433690905	29136	Business	33000.00
0005432966823	29136	Business	33000.00
0005433680027	29136	Business	33000.00
0005432966833	29136	Business	33000.00
0005432966843	29136	Business	33000.00
0005433684393	29136	Business	33000.00
0005432966822	29136	Business	33000.00
0005432966834	29136	Business	33000.00
0005433680109	29136	Business	33000.00
0005433679888	29136	Business	33000.00
0005432005201	29136	Economy	11000.00
0005433680161	29136	Economy	11000.00
0005433680137	29136	Economy	11000.00
0005432966839	29136	Economy	11000.00
0005433690902	29136	Economy	11000.00
0005433680054	29136	Economy	11000.00
0005433680150	29136	Economy	11000.00
0005433679937	29136	Economy	11000.00
0005432966831	29136	Economy	11000.00
0005433680235	29136	Economy	12100.00
0005432966829	29136	Economy	12100.00
0005433680031	29136	Economy	12100.00
0005433684397	29136	Economy	12100.00
0005433679836	29136	Economy	12100.00
0005433680081	29136	Economy	11000.00
0005433679909	29136	Economy	11000.00
0005432005200	29136	Economy	11000.00
0005433679713	29136	Economy	11000.00
0005433679959	29136	Economy	11000.00
0005433679976	29136	Economy	11000.00
0005433680129	29136	Economy	11000.00
0005432966826	29136	Economy	11000.00
0005433679936	29136	Economy	11000.00
0005433680192	29136	Economy	11000.00
0005432966841	29136	Economy	11000.00
0005433679924	29136	Economy	11000.00
0005433679974	29136	Economy	11000.00
0005432966830	29136	Economy	11000.00
0005432966844	29136	Economy	11000.00
0005432966828	29136	Economy	11000.00
0005433687686	29136	Economy	11000.00
0005432966838	29136	Economy	11000.00
0005432966827	29136	Economy	11000.00
0005433680139	29136	Economy	11000.00
0005433680080	29136	Economy	11000.00
0005433684398	29136	Economy	11000.00
0005433679984	29136	Economy	11000.00
0005432966842	29136	Economy	11000.00
0005433680181	29136	Economy	11000.00
0005432966837	29136	Economy	11000.00
0005433680138	29136	Economy	11000.00
0005432966819	29136	Economy	11000.00
0005432966836	29136	Economy	11000.00
0005432966825	29136	Economy	11000.00
0005433680077	29136	Economy	11000.00
0005433680046	29136	Economy	11000.00
0005432966835	29136	Economy	11000.00
0005433690901	29136	Economy	11000.00
0005432966832	29136	Economy	11000.00
0005432966840	29136	Economy	11000.00
0005433679874	29136	Economy	11000.00
0005432966820	29136	Economy	11000.00
0005433679914	29136	Economy	11000.00
0005433679835	29136	Economy	11000.00
0005433680128	29136	Economy	11000.00
0005433680146	29136	Economy	11000.00
0005433687687	29136	Economy	11000.00
0005433679821	29136	Economy	11000.00
0005433680075	29136	Economy	11000.00
0005433680074	29136	Economy	11000.00
0005433679837	29136	Economy	11000.00
0005433679915	29136	Economy	11000.00
0005433680193	29136	Economy	11000.00
0005433679975	29136	Economy	11000.00
0005433680078	29136	Economy	11000.00
0005433680110	29136	Economy	11000.00
0005433679960	29136	Economy	11000.00
0005432966824	29136	Economy	11000.00
0005433679887	29136	Economy	11000.00
0005432005202	29136	Economy	11000.00
0005433680053	29136	Economy	11000.00
0005432966821	29136	Economy	11000.00
0005433679925	29136	Economy	11000.00
0005433577743	9280	Business	132900.00
0005433633665	9280	Business	132900.00
0005433633640	9280	Business	132900.00
0005433633660	9280	Business	132900.00
0005433614333	9280	Business	132900.00
0005433614353	9280	Business	132900.00
0005433577752	9280	Business	132900.00
0005433614294	9280	Business	132900.00
0005433614300	9280	Business	132900.00
0005433614315	9280	Business	132900.00
0005433633659	9280	Business	132900.00
0005433577755	9280	Business	132900.00
0005433633643	9280	Business	132900.00
0005433614331	9280	Business	132900.00
0005433614350	9280	Business	132900.00
0005434152752	9280	Business	132900.00
0005433614302	9280	Business	132900.00
0005432755060	9280	Business	132900.00
0005433614291	9280	Business	132900.00
0005433633656	9280	Business	132900.00
0005432755063	9280	Business	132900.00
0005433614289	9280	Business	132900.00
0005433577749	9280	Business	132900.00
0005433633633	9280	Business	132900.00
0005432145102	9280	Economy	48700.00
0005433614299	9280	Economy	48700.00
0005433614337	9280	Economy	48700.00
0005432756833	9280	Economy	48700.00
0005433614351	9280	Economy	48700.00
0005432755059	9280	Economy	48700.00
0005433633634	9280	Economy	44300.00
0005432755062	9280	Economy	44300.00
0005434163511	9280	Economy	44300.00
0005433577744	9280	Economy	44300.00
0005432145103	9280	Economy	44300.00
0005434163512	9280	Economy	44300.00
0005433614344	9280	Economy	44300.00
0005433633637	9280	Economy	44300.00
0005433614342	9280	Economy	44300.00
0005433633657	9280	Economy	44300.00
0005433614285	9280	Economy	44300.00
0005433614296	9280	Economy	44300.00
0005433614317	9280	Economy	44300.00
0005433614307	9280	Economy	44300.00
0005433614347	9280	Economy	44300.00
0005433614304	9280	Economy	44300.00
0005434163533	9280	Economy	44300.00
0005433614297	9280	Economy	44300.00
0005433614348	9280	Economy	44300.00
0005433614301	9280	Economy	44300.00
0005433633646	9280	Economy	44300.00
0005433614292	9280	Economy	44300.00
0005433614339	9280	Economy	44300.00
0005433633645	9280	Economy	44300.00
0005433614336	9280	Economy	44300.00
0005433614320	9280	Economy	44300.00
0005433633664	9280	Economy	44300.00
0005433614323	9280	Economy	44300.00
0005433614313	9280	Economy	44300.00
0005433633655	9280	Economy	44300.00
0005433614308	9280	Economy	44300.00
0005433614346	9280	Economy	44300.00
0005434163523	9280	Economy	44300.00
0005432145101	9280	Economy	44300.00
0005433633649	9280	Economy	44300.00
0005433614334	9280	Economy	44300.00
0005433633652	9280	Economy	44300.00
0005433614318	9280	Economy	44300.00
0005433614321	9280	Economy	44300.00
0005433614343	9280	Economy	44300.00
0005433614287	9280	Economy	44300.00
0005434163513	9280	Economy	44300.00
0005433614327	9280	Economy	44300.00
0005433633662	9280	Economy	44300.00
0005433614352	9280	Economy	44300.00
0005434152771	9280	Economy	44300.00
0005433633639	9280	Economy	44300.00
0005433614349	9280	Economy	44300.00
0005433614319	9280	Economy	44300.00
0005433614324	9280	Economy	48700.00
0005433614332	9280	Economy	48700.00
0005433614309	9280	Economy	48700.00
0005433614290	9280	Economy	48700.00
0005432145100	9280	Economy	48700.00
0005433577748	9280	Economy	44300.00
0005433614356	9280	Economy	44300.00
0005433614293	9280	Economy	44300.00
0005432756834	9280	Economy	44300.00
0005433633635	9280	Economy	48700.00
0005433614303	9280	Economy	44300.00
0005433633653	9280	Economy	44300.00
0005433633644	9280	Economy	44300.00
0005433633663	9280	Economy	44300.00
0005433614345	9280	Economy	44300.00
0005433614288	9280	Economy	44300.00
0005433633642	9280	Economy	44300.00
0005433577741	9280	Economy	44300.00
0005433614286	9280	Economy	44300.00
0005433614354	9280	Economy	44300.00
0005433614326	9280	Economy	44300.00
0005433614340	9280	Economy	44300.00
0005433614358	9280	Economy	44300.00
0005433614355	9280	Economy	44300.00
0005433614335	9280	Economy	44300.00
0005433614295	9280	Economy	44300.00
0005433633650	9280	Economy	44300.00
0005433614310	9280	Economy	44300.00
0005433614322	9280	Economy	44300.00
0005433633661	9280	Economy	44300.00
0005433633654	9280	Economy	44300.00
0005433614316	9280	Economy	44300.00
0005433577746	9280	Economy	44300.00
0005433614306	9280	Economy	44300.00
0005434163524	9280	Economy	44300.00
0005433614314	9280	Economy	44300.00
0005433614329	9280	Economy	44300.00
0005433577742	9280	Economy	44300.00
0005432755061	9280	Economy	44300.00
0005433633638	9280	Economy	44300.00
0005433614325	9280	Economy	44300.00
0005433577751	9280	Economy	44300.00
0005433577754	9280	Economy	44300.00
0005433633636	9280	Economy	44300.00
0005433633632	9280	Economy	44300.00
0005433633651	9280	Economy	44300.00
0005433614341	9280	Economy	44300.00
0005434163496	9280	Economy	44300.00
0005433614328	9280	Economy	44300.00
0005433614298	9280	Economy	44300.00
0005433614305	9280	Economy	44300.00
0005433577745	9280	Economy	44300.00
0005433633647	9280	Economy	44300.00
0005433577750	9280	Economy	44300.00
0005433633641	9280	Economy	44300.00
0005433614357	9280	Economy	44300.00
0005433577753	9280	Economy	44300.00
0005433633666	9280	Economy	44300.00
0005433614311	9280	Economy	44300.00
0005433577747	9280	Economy	44300.00
0005433633648	9280	Economy	44300.00
0005433614312	9280	Economy	44300.00
0005433614330	9280	Economy	44300.00
0005433614338	9280	Economy	44300.00
0005433633658	9280	Economy	44300.00
0005433613744	25242	Business	132900.00
0005433633503	25242	Business	132900.00
0005434163589	25242	Business	132900.00
0005434163591	25242	Business	132900.00
0005435854056	25242	Business	132900.00
0005434272183	25242	Business	132900.00
0005433613685	25242	Business	132900.00
0005434163583	25242	Business	132900.00
0005433613484	25242	Business	132900.00
0005433633353	25242	Business	132900.00
0005433613905	25242	Business	132900.00
0005433613530	25242	Business	132900.00
0005433613667	25242	Business	132900.00
0005433613866	25242	Business	132900.00
0005434163587	25242	Business	132900.00
0005433633332	25242	Business	132900.00
0005433613755	25242	Business	132900.00
0005433613508	25242	Business	132900.00
0005433613572	25242	Economy	48700.00
0005433577657	25242	Economy	48700.00
0005433577647	25242	Economy	48700.00
0005433613925	25242	Economy	48700.00
0005433577608	25242	Economy	44300.00
0005434163581	25242	Economy	44300.00
0005434272184	25242	Economy	44300.00
0005435854053	25242	Economy	44300.00
0005433613721	25242	Economy	44300.00
0005433613592	25242	Economy	44300.00
0005433633447	25242	Economy	44300.00
0005434163584	25242	Economy	44300.00
0005433613749	25242	Economy	44300.00
0005433613737	25242	Economy	44300.00
0005433613656	25242	Economy	44300.00
0005433613872	25242	Economy	44300.00
0005433613581	25242	Economy	44300.00
0005433613915	25242	Economy	44300.00
0005434163588	25242	Economy	44300.00
0005433577584	25242	Economy	44300.00
0005433577640	25242	Economy	44300.00
0005433613774	25242	Economy	44300.00
0005433613587	25242	Economy	44300.00
0005435854055	25242	Economy	44300.00
0005434273070	25242	Economy	44300.00
0005433577568	25242	Economy	44300.00
0005433613756	25242	Economy	44300.00
0005433613795	25242	Economy	44300.00
0005434272186	25242	Economy	44300.00
0005433613727	25242	Economy	44300.00
0005433613620	25242	Economy	44300.00
0005433613882	25242	Economy	44300.00
0005433613914	25242	Economy	44300.00
0005433613644	25242	Economy	44300.00
0005434163590	25242	Economy	44300.00
0005433577656	25242	Economy	44300.00
0005433613683	25242	Economy	44300.00
0005433633371	25242	Economy	44300.00
0005433633386	25242	Economy	44300.00
0005433577616	25242	Economy	44300.00
0005435854051	25242	Economy	44300.00
0005433633359	25242	Economy	44300.00
0005433613584	25242	Economy	44300.00
0005433613525	25242	Economy	44300.00
0005433577583	25242	Economy	44300.00
0005433613499	25242	Economy	44300.00
0005435854054	25242	Economy	44300.00
0005433613619	25242	Economy	44300.00
0005434272185	25242	Economy	44300.00
0005434163582	25242	Economy	44300.00
0005433577672	25242	Economy	48700.00
0005433633354	25242	Economy	48700.00
0005434163586	25242	Economy	44300.00
0005433613524	25242	Economy	44300.00
0005434273069	25242	Economy	44300.00
0005433613704	25242	Economy	44300.00
0005433613772	25242	Economy	44300.00
0005433613498	25242	Economy	44300.00
0005433613534	25242	Economy	44300.00
0005433613585	25242	Economy	44300.00
0005433633373	25242	Economy	44300.00
0005433577569	25242	Economy	44300.00
0005433613485	25242	Economy	44300.00
0005433613803	25242	Economy	44300.00
0005433633352	25242	Economy	44300.00
0005433577609	25242	Economy	44300.00
0005433613773	25242	Economy	44300.00
0005433613521	25242	Economy	44300.00
0005433613529	25242	Economy	44300.00
0005433633330	25242	Economy	44300.00
0005433613695	25242	Economy	44300.00
0005433613877	25242	Economy	44300.00
0005433613559	25242	Economy	44300.00
0005433577673	25242	Economy	44300.00
0005433613822	25242	Economy	44300.00
0005433613588	25242	Economy	44300.00
0005433633385	25242	Economy	44300.00
0005433613580	25242	Economy	44300.00
0005433613974	25242	Economy	44300.00
0005435854052	25242	Economy	44300.00
0005433613686	25242	Economy	44300.00
0005433613904	25242	Economy	44300.00
0005433633320	25242	Economy	44300.00
0005433613694	25242	Economy	44300.00
0005433577607	25242	Economy	44300.00
0005433613684	25242	Economy	44300.00
0005433613827	25242	Economy	44300.00
0005434163592	25242	Economy	44300.00
0005433577570	25242	Economy	44300.00
0005433613527	25242	Economy	44300.00
0005433633247	25242	Economy	44300.00
0005433577658	25242	Economy	44300.00
0005433633329	25242	Economy	44300.00
0005433577646	25242	Economy	44300.00
0005433613726	25242	Economy	44300.00
0005433633448	25242	Economy	44300.00
0005434163585	25242	Economy	44300.00
0005433633370	25242	Economy	44300.00
0005433613414	25242	Economy	44300.00
0005433613806	25242	Economy	44300.00
0005433613509	25242	Economy	44300.00
0005435986732	4196	Business	193100.00
0005435787324	4196	Business	193100.00
0005435986724	4196	Business	193100.00
0005432571275	4196	Business	193100.00
0005432184939	4196	Business	193100.00
0005432184938	4196	Economy	64400.00
0005435787326	4196	Economy	64400.00
0005432184940	4196	Economy	64400.00
0005435986723	4196	Economy	64400.00
0005435856147	4196	Economy	64400.00
0005435947069	4196	Economy	64400.00
0005435986730	4196	Economy	64400.00
0005435986721	4196	Economy	64400.00
0005435986722	4196	Economy	64400.00
0005435947088	4196	Economy	64400.00
0005435947070	4196	Economy	64400.00
0005435986726	4196	Economy	64400.00
0005435947091	4196	Economy	64400.00
0005434271288	4196	Economy	64400.00
0005435856148	4196	Economy	64400.00
0005435854042	4196	Economy	64400.00
0005435854043	4196	Economy	64400.00
0005435787325	4196	Economy	64400.00
0005435947053	4196	Economy	64400.00
0005435986729	4196	Economy	64400.00
0005432571291	4196	Economy	64400.00
0005435986725	4196	Economy	64400.00
0005435986727	4196	Economy	64400.00
0005435947092	4196	Economy	64400.00
0005435947026	4196	Economy	64400.00
0005435986731	4196	Economy	64400.00
0005435986728	4196	Economy	64400.00
0005435787348	26579	Business	193100.00
0005435947194	26579	Business	193100.00
0005435856189	26579	Business	193100.00
0005435986649	26579	Business	193100.00
0005435856185	26579	Economy	70800.00
0005435947199	26579	Economy	70800.00
0005435947193	26579	Economy	64400.00
0005435947203	26579	Economy	64400.00
0005432571311	26579	Economy	64400.00
0005432571309	26579	Economy	64400.00
0005435947202	26579	Economy	64400.00
0005435856186	26579	Economy	64400.00
0005432571310	26579	Economy	64400.00
0005435947191	26579	Economy	64400.00
0005435947204	26579	Economy	64400.00
0005435856188	26579	Economy	64400.00
0005435986665	26579	Economy	64400.00
0005435986662	26579	Economy	64400.00
0005435947195	26579	Economy	64400.00
0005435947200	26579	Economy	64400.00
0005432571308	26579	Economy	64400.00
0005435787346	26579	Economy	64400.00
0005435947197	26579	Economy	64400.00
0005435856187	26579	Economy	64400.00
0005435986664	26579	Economy	64400.00
0005435947190	26579	Economy	64400.00
0005435947192	26579	Economy	64400.00
0005435787347	26579	Economy	64400.00
0005435947198	26579	Economy	64400.00
0005435947196	26579	Economy	64400.00
0005435947201	26579	Economy	64400.00
0005432948012	317	Business	21500.00
0005433129222	317	Business	21500.00
0005433568804	317	Business	21500.00
0005433568858	317	Business	21500.00
0005433568852	317	Business	21500.00
0005432238913	317	Business	21500.00
0005433568861	317	Business	21500.00
0005433074420	317	Business	21500.00
0005433568825	317	Business	21500.00
0005432947862	317	Business	21500.00
0005433568859	317	Business	21500.00
0005433568850	317	Business	21500.00
0005432947872	317	Business	21500.00
0005433129199	317	Business	21500.00
0005432947811	317	Business	21500.00
0005432947809	317	Business	21500.00
0005433074400	317	Business	21500.00
0005433568815	317	Business	21500.00
0005433568824	317	Business	21500.00
0005433074268	317	Business	21500.00
0005433568838	317	Business	21500.00
0005433568867	317	Business	21500.00
0005432238912	317	Business	21500.00
0005433074222	317	Business	21500.00
0005433074357	317	Business	21500.00
0005433134082	317	Economy	7900.00
0005433568840	317	Economy	7900.00
0005433074271	317	Economy	7900.00
0005433568813	317	Economy	7900.00
0005432947944	317	Economy	7900.00
0005433568832	317	Economy	7200.00
0005432947877	317	Economy	7200.00
0005432947883	317	Economy	7200.00
0005433074314	317	Economy	7200.00
0005433568827	317	Economy	7200.00
0005432947785	317	Economy	7200.00
0005433568835	317	Economy	7200.00
0005433568860	317	Economy	7200.00
0005433568842	317	Economy	7200.00
0005432947884	317	Economy	7200.00
0005433074344	317	Economy	7200.00
0005433568866	317	Economy	7200.00
0005433568868	317	Economy	7200.00
0005433568862	317	Economy	7200.00
0005433568846	317	Economy	7200.00
0005433568809	317	Economy	7200.00
0005433568822	317	Economy	7200.00
0005432238914	317	Economy	7200.00
0005432947977	317	Economy	7200.00
0005433568826	317	Economy	7200.00
0005433568863	317	Economy	7200.00
0005433568818	317	Economy	7200.00
0005433568853	317	Economy	7200.00
0005433074221	317	Economy	7200.00
0005432947867	317	Economy	7200.00
0005432948067	317	Economy	7200.00
0005432238909	317	Economy	7200.00
0005433074331	317	Economy	7200.00
0005433074265	317	Economy	7200.00
0005433074377	317	Economy	7200.00
0005433568810	317	Economy	7200.00
0005432947982	317	Economy	7200.00
0005433568831	317	Economy	7200.00
0005433129237	317	Economy	7200.00
0005433568845	317	Economy	7200.00
0005433568828	317	Economy	7200.00
0005432947988	317	Economy	7200.00
0005432238910	317	Economy	7200.00
0005433074316	317	Economy	7200.00
0005433074451	317	Economy	7200.00
0005433568821	317	Economy	7200.00
0005432947925	317	Economy	7200.00
0005433568811	317	Economy	7200.00
0005433568833	317	Economy	7200.00
0005433134083	317	Economy	7200.00
0005433568844	317	Economy	7200.00
0005433568848	317	Economy	7200.00
0005433568864	317	Economy	7200.00
0005433074399	317	Economy	7200.00
0005433568843	317	Economy	7200.00
0005433074270	317	Economy	7200.00
0005433568814	317	Economy	7200.00
0005432947898	317	Economy	7900.00
0005433129228	317	Economy	7900.00
0005433568839	317	Economy	7200.00
0005433129234	317	Economy	7200.00
0005433568803	317	Economy	7200.00
0005432947876	317	Economy	7900.00
0005433129215	317	Economy	7200.00
0005432947965	317	Economy	7200.00
0005433568823	317	Economy	7200.00
0005433568856	317	Economy	7200.00
0005433568855	317	Economy	7200.00
0005433129226	317	Economy	7200.00
0005433074500	317	Economy	7200.00
0005433568819	317	Economy	7200.00
0005433129221	317	Economy	7200.00
0005433568812	317	Economy	7200.00
0005433568854	317	Economy	7200.00
0005432947945	317	Economy	7200.00
0005433074388	317	Economy	7200.00
0005433074313	317	Economy	7200.00
0005433568857	317	Economy	7200.00
0005433568837	317	Economy	7200.00
0005433568820	317	Economy	7200.00
0005432948066	317	Economy	7200.00
0005433568847	317	Economy	7200.00
0005432947833	317	Economy	7200.00
0005432947897	317	Economy	7200.00
0005433568865	317	Economy	7200.00
0005433568808	317	Economy	7200.00
0005432238911	317	Economy	7200.00
0005433568830	317	Economy	7200.00
0005432948087	317	Economy	7200.00
0005432948131	317	Economy	7200.00
0005433074332	317	Economy	7200.00
0005432947971	317	Economy	7200.00
0005433568816	317	Economy	7200.00
0005433568834	317	Economy	7200.00
0005433568829	317	Economy	7200.00
0005433129203	317	Economy	7200.00
0005432948011	317	Economy	7200.00
0005432948031	317	Economy	7200.00
0005432947810	317	Economy	7200.00
0005433074312	317	Economy	7200.00
0005433568807	317	Economy	7200.00
0005433568817	317	Economy	7200.00
0005433568805	317	Economy	7200.00
0005432947995	317	Economy	7200.00
0005432948032	317	Economy	7200.00
0005433568849	317	Economy	7200.00
0005432947964	317	Economy	7200.00
0005433568836	317	Economy	7200.00
0005433129235	317	Economy	7200.00
0005433568841	317	Economy	7200.00
0005433568806	317	Economy	7200.00
0005433074452	317	Economy	7200.00
0005433129198	317	Economy	7200.00
0005433074223	317	Economy	7200.00
0005433134084	317	Economy	7200.00
0005432947843	317	Economy	7200.00
0005433129227	317	Economy	7200.00
0005433074398	317	Economy	7200.00
0005432948029	317	Economy	7200.00
0005433074335	317	Economy	7200.00
0005433568851	317	Economy	7200.00
0005433568279	11601	Business	21500.00
0005432948291	11601	Business	21500.00
0005433568079	11601	Business	21500.00
0005432948302	11601	Business	21500.00
0005433074590	11601	Business	21500.00
0005433568170	11601	Business	21500.00
0005433568127	11601	Business	21500.00
0005433568062	11601	Business	21500.00
0005432948280	11601	Business	21500.00
0005433568307	11601	Business	21500.00
0005432948298	11601	Business	21500.00
0005432192305	11601	Business	21500.00
0005433568065	11601	Business	21500.00
0005433134119	11601	Business	21500.00
0005433568137	11601	Business	21500.00
0005433568351	11601	Business	21500.00
0005432948282	11601	Business	21500.00
0005433568299	11601	Business	21500.00
0005433131688	11601	Business	21500.00
0005433568327	11601	Business	21500.00
0005432948300	11601	Business	21500.00
0005432948293	11601	Economy	7900.00
0005433074578	11601	Economy	7900.00
0005432948276	11601	Economy	7900.00
0005433074599	11601	Economy	7900.00
0005433568306	11601	Economy	7900.00
0005433568269	11601	Economy	7900.00
0005432948266	11601	Economy	7200.00
0005433568128	11601	Economy	7200.00
0005433074604	11601	Economy	7200.00
0005433134118	11601	Economy	7200.00
0005433131690	11601	Economy	7200.00
0005433568241	11601	Economy	7200.00
0005432948295	11601	Economy	7200.00
0005433568129	11601	Economy	7200.00
0005433074597	11601	Economy	7200.00
0005433568222	11601	Economy	7200.00
0005432948286	11601	Economy	7200.00
0005433568332	11601	Economy	7200.00
0005432948289	11601	Economy	7200.00
0005433568352	11601	Economy	7200.00
0005433568300	11601	Economy	7200.00
0005433568266	11601	Economy	7200.00
0005433568139	11601	Economy	7200.00
0005432948279	11601	Economy	7200.00
0005432948285	11601	Economy	7200.00
0005432948278	11601	Economy	7200.00
0005433568057	11601	Economy	7200.00
0005433131689	11601	Economy	7200.00
0005433074576	11601	Economy	7200.00
0005432192307	11601	Economy	7200.00
0005432192306	11601	Economy	7200.00
0005432948303	11601	Economy	7200.00
0005433074600	11601	Economy	7200.00
0005432948267	11601	Economy	7200.00
0005433568308	11601	Economy	7200.00
0005433568318	11601	Economy	7200.00
0005432948297	11601	Economy	7200.00
0005432948271	11601	Economy	7200.00
0005433568223	11601	Economy	7200.00
0005433568034	11601	Economy	7200.00
0005433568168	11601	Economy	7200.00
0005433568171	11601	Economy	7200.00
0005433074587	11601	Economy	7200.00
0005433074589	11601	Economy	7200.00
0005432948277	11601	Economy	7200.00
0005432948294	11601	Economy	7200.00
0005433568115	11601	Economy	7200.00
0005433074598	11601	Economy	7200.00
0005433074591	11601	Economy	7200.00
0005433568333	11601	Economy	7200.00
0005433074603	11601	Economy	7200.00
0005433074580	11601	Economy	7200.00
0005432192308	11601	Economy	7200.00
0005433134117	11601	Economy	7200.00
0005433568154	11601	Economy	7200.00
0005433568078	11601	Economy	7200.00
0005432948292	11601	Economy	7200.00
0005433568291	11601	Economy	7900.00
0005433568080	11601	Economy	7900.00
0005433568245	11601	Economy	7900.00
0005432192309	11601	Economy	7900.00
0005433568045	11601	Economy	7900.00
0005432948287	11601	Economy	7200.00
0005433074586	11601	Economy	7200.00
0005433074594	11601	Economy	7200.00
0005433568090	11601	Economy	7200.00
0005433568047	11601	Economy	7900.00
0005433074602	11601	Economy	7200.00
0005433074593	11601	Economy	7200.00
0005432948296	11601	Economy	7200.00
0005433568276	11601	Economy	7200.00
0005432948304	11601	Economy	7200.00
0005432948275	11601	Economy	7200.00
0005433074596	11601	Economy	7200.00
0005433568247	11601	Economy	7200.00
0005433568311	11601	Economy	7200.00
0005432948268	11601	Economy	7200.00
0005433568246	11601	Economy	7200.00
0005432948269	11601	Economy	7200.00
0005432948281	11601	Economy	7200.00
0005433568209	11601	Economy	7200.00
0005433568153	11601	Economy	7200.00
0005432948270	11601	Economy	7200.00
0005433074585	11601	Economy	7200.00
0005433074583	11601	Economy	7200.00
0005433568136	11601	Economy	7200.00
0005433074575	11601	Economy	7200.00
0005433074588	11601	Economy	7200.00
0005432948301	11601	Economy	7200.00
0005433568221	11601	Economy	7200.00
0005433568046	11601	Economy	7200.00
0005433074584	11601	Economy	7200.00
0005433074581	11601	Economy	7200.00
0005432948283	11601	Economy	7200.00
0005433131687	11601	Economy	7200.00
0005433568061	11601	Economy	7200.00
0005432948288	11601	Economy	7200.00
0005432948272	11601	Economy	7200.00
0005433074595	11601	Economy	7200.00
0005433568356	11601	Economy	7200.00
0005432948265	11601	Economy	7200.00
0005433074582	11601	Economy	7200.00
0005433568164	11601	Economy	7200.00
0005433568239	11601	Economy	7200.00
0005433074577	11601	Economy	7200.00
0005432948274	11601	Economy	7200.00
0005432948284	11601	Economy	7200.00
0005432948273	11601	Economy	7200.00
0005432948264	11601	Economy	7200.00
0005432948290	11601	Economy	7200.00
0005433568149	11601	Economy	7200.00
0005433131691	11601	Economy	7200.00
0005433568216	11601	Economy	7200.00
0005433568208	11601	Economy	7200.00
0005433074579	11601	Economy	7200.00
0005433568116	11601	Economy	7200.00
0005433568172	11601	Economy	7200.00
0005433134121	11601	Economy	7200.00
0005433074601	11601	Economy	7200.00
0005433074592	11601	Economy	7200.00
0005432948299	11601	Economy	7200.00
0005433134120	11601	Economy	7200.00
0005433568147	11601	Economy	7200.00
0005434732939	10019	Economy	6300.00
0005433817457	10019	Economy	6300.00
0005434732935	10019	Economy	6300.00
0005434732951	10019	Economy	6300.00
0005433817455	10019	Economy	6300.00
0005433817456	10019	Economy	6300.00
0005434732967	13889	Economy	6300.00
0005433817425	13889	Economy	6300.00
0005434732968	13889	Economy	6300.00
0005433817426	13889	Economy	6300.00
0005433817424	13889	Economy	6300.00
0005434732966	13889	Economy	6300.00
0005433817408	13889	Economy	6300.00
0005433817423	13889	Economy	6300.00
0005433817409	13889	Economy	6300.00
0005433754002	2329	Business	184500.00
0005433754011	2329	Business	184500.00
0005432984590	2329	Business	184500.00
0005432655493	2329	Business	184500.00
0005433434340	2329	Business	184500.00
0005435982129	2329	Business	184500.00
0005432869445	2329	Business	184500.00
0005435982102	2329	Business	184500.00
0005433753983	2329	Business	184500.00
0005433754012	2329	Business	184500.00
0005433434280	2329	Business	184500.00
0005432226030	2329	Business	184500.00
0005433754021	2329	Business	184500.00
0005433434353	2329	Business	184500.00
0005433754001	2329	Business	184500.00
0005435982096	2329	Business	184500.00
0005432984530	2329	Business	184500.00
0005432869444	2329	Business	184500.00
0005435982119	2329	Business	184500.00
0005435982109	2329	Business	184500.00
0005433434397	2329	Business	184500.00
0005433434329	2329	Business	184500.00
0005433753973	2329	Business	184500.00
0005432869454	2329	Business	184500.00
0005432984693	2329	Business	184500.00
0005432655494	2329	Business	184500.00
0005435982127	2329	Business	184500.00
0005433753984	2329	Business	184500.00
0005432869437	2329	Business	184500.00
0005433753994	2329	Economy	67700.00
0005433753998	2329	Economy	67700.00
0005432984594	2329	Economy	67700.00
0005432869432	2329	Economy	61500.00
0005433434376	2329	Economy	61500.00
0005432226031	2329	Economy	61500.00
0005435982121	2329	Economy	61500.00
0005433766625	2329	Economy	61500.00
0005433753976	2329	Economy	61500.00
0005432984748	2329	Economy	61500.00
0005433434268	2329	Economy	61500.00
0005433434355	2329	Economy	61500.00
0005433753985	2329	Economy	61500.00
0005432984654	2329	Economy	61500.00
0005435982116	2329	Economy	61500.00
0005434731112	2329	Economy	61500.00
0005433753980	2329	Economy	61500.00
0005433764671	2329	Economy	61500.00
0005433434364	2329	Economy	61500.00
0005434731109	2329	Economy	61500.00
0005435982098	2329	Economy	61500.00
0005432984684	2329	Economy	61500.00
0005433753975	2329	Economy	61500.00
0005432655488	2329	Economy	61500.00
0005432984696	2329	Economy	61500.00
0005435982103	2329	Economy	61500.00
0005433754005	2329	Economy	61500.00
0005435982114	2329	Economy	61500.00
0005433754014	2329	Economy	61500.00
0005433434391	2329	Economy	61500.00
0005435982110	2329	Economy	61500.00
0005432984639	2329	Economy	61500.00
0005433753993	2329	Economy	61500.00
0005433434406	2329	Economy	61500.00
0005435982125	2329	Economy	61500.00
0005434731113	2329	Economy	61500.00
0005433753977	2329	Economy	61500.00
0005433754003	2329	Economy	61500.00
0005433434328	2329	Economy	61500.00
0005433764672	2329	Economy	61500.00
0005432984722	2329	Economy	61500.00
0005433753987	2329	Economy	61500.00
0005433753999	2329	Economy	61500.00
0005432655495	2329	Economy	61500.00
0005435982100	2329	Economy	61500.00
0005433434318	2329	Economy	61500.00
0005433766623	2329	Economy	61500.00
0005435982113	2329	Economy	61500.00
0005432984814	2329	Economy	61500.00
0005432984695	2329	Economy	61500.00
0005433753997	2329	Economy	61500.00
0005433754026	2329	Economy	61500.00
0005433434285	2329	Economy	61500.00
0005433434418	2329	Economy	61500.00
0005433434344	2329	Economy	61500.00
0005432226032	2329	Economy	61500.00
0005433753970	2329	Economy	61500.00
0005433753982	2329	Economy	61500.00
0005435982105	2329	Economy	61500.00
0005435982115	2329	Economy	61500.00
0005435982136	2329	Economy	61500.00
0005432984682	2329	Economy	61500.00
0005432869441	2329	Economy	61500.00
0005432655485	2329	Economy	61500.00
0005433754025	2329	Economy	61500.00
0005435982104	2329	Economy	61500.00
0005435982126	2329	Economy	61500.00
0005432984644	2329	Economy	61500.00
0005432655490	2329	Economy	61500.00
0005433434365	2329	Economy	61500.00
0005433434405	2329	Economy	61500.00
0005435982122	2329	Economy	61500.00
0005433434377	2329	Economy	61500.00
0005433434392	2329	Economy	61500.00
0005435982108	2329	Economy	61500.00
0005432984680	2329	Economy	61500.00
0005435982135	2329	Economy	61500.00
0005432984757	2329	Economy	61500.00
0005435982134	2329	Economy	61500.00
0005432984595	2329	Economy	61500.00
0005432984647	2329	Economy	61500.00
0005435982137	2329	Economy	61500.00
0005435982101	2329	Economy	61500.00
0005435982120	2329	Economy	61500.00
0005433754022	2329	Economy	61500.00
0005432984756	2329	Economy	61500.00
0005433753978	2329	Economy	61500.00
0005435982106	2329	Economy	61500.00
0005435982133	2329	Economy	61500.00
0005432300238	2329	Economy	61500.00
0005435982128	2329	Economy	61500.00
0005435982124	2329	Economy	61500.00
0005432984697	2329	Economy	61500.00
0005433753995	2329	Economy	61500.00
0005433434409	2329	Economy	61500.00
0005432984749	2329	Economy	61500.00
0005433754010	2329	Economy	61500.00
0005434731099	2329	Economy	61500.00
0005433434378	2329	Economy	61500.00
0005433753988	2329	Economy	61500.00
0005433754015	2329	Economy	61500.00
0005433753989	2329	Economy	67700.00
0005433753986	2329	Economy	67700.00
0005435982123	2329	Economy	61500.00
0005432655489	2329	Economy	61500.00
0005434731110	2329	Economy	61500.00
0005432869436	2329	Economy	67700.00
0005433753972	2329	Economy	61500.00
0005432226034	2329	Economy	67700.00
0005433753981	2329	Economy	61500.00
0005433764673	2329	Economy	61500.00
0005435982118	2329	Economy	61500.00
0005433753979	2329	Economy	61500.00
0005432984558	2329	Economy	61500.00
0005433434396	2329	Economy	61500.00
0005433753971	2329	Economy	61500.00
0005433754007	2329	Economy	61500.00
0005435982140	2329	Economy	61500.00
0005433754006	2329	Economy	61500.00
0005432984640	2329	Economy	61500.00
0005433754019	2329	Economy	61500.00
0005432300239	2329	Economy	61500.00
0005433754024	2329	Economy	61500.00
0005435982097	2329	Economy	61500.00
0005433754023	2329	Economy	61500.00
0005435982130	2329	Economy	61500.00
0005433766627	2329	Economy	61500.00
0005432300241	2329	Economy	61500.00
0005434731111	2329	Economy	61500.00
0005435982139	2329	Economy	61500.00
0005432984678	2329	Economy	61500.00
0005432300240	2329	Economy	61500.00
0005432226033	2329	Economy	61500.00
0005432984744	2329	Economy	61500.00
0005435982112	2329	Economy	61500.00
0005433434299	2329	Economy	61500.00
0005432300243	2329	Economy	61500.00
0005433754018	2329	Economy	61500.00
0005435982111	2329	Economy	61500.00
0005432984550	2329	Economy	61500.00
0005433434217	2329	Economy	61500.00
0005435982132	2329	Economy	61500.00
0005432300242	2329	Economy	61500.00
0005433434403	2329	Economy	61500.00
0005432655496	2329	Economy	61500.00
0005435982099	2329	Economy	61500.00
0005433434278	2329	Economy	61500.00
0005432984813	2329	Economy	61500.00
0005432655487	2329	Economy	61500.00
0005433753974	2329	Economy	61500.00
0005435982107	2329	Economy	61500.00
0005432984683	2329	Economy	61500.00
0005432655492	2329	Economy	61500.00
0005433753992	2329	Economy	61500.00
0005432984643	2329	Economy	61500.00
0005433434407	2329	Economy	61500.00
0005433754017	2329	Economy	61500.00
0005432984568	2329	Economy	61500.00
0005435982131	2329	Economy	61500.00
0005433754020	2329	Economy	61500.00
0005435982117	2329	Economy	61500.00
0005433766626	2329	Economy	61500.00
0005433434354	2329	Economy	61500.00
0005433434408	2329	Economy	61500.00
0005433434352	2329	Economy	61500.00
0005433753996	2329	Economy	61500.00
0005433753991	2329	Economy	61500.00
0005433754004	2329	Economy	61500.00
0005433754009	2329	Economy	61500.00
0005433754016	2329	Economy	61500.00
0005433766624	2329	Economy	61500.00
0005432655486	2329	Economy	61500.00
0005433754000	2329	Economy	61500.00
0005432984623	2329	Economy	61500.00
0005433753990	2329	Economy	61500.00
0005433754008	2329	Economy	61500.00
0005432984679	2329	Economy	61500.00
0005432984551	2329	Economy	61500.00
0005433434402	2329	Economy	61500.00
0005433434279	2329	Economy	61500.00
0005433754013	2329	Economy	61500.00
0005434731117	2329	Economy	61500.00
0005435982138	2329	Economy	61500.00
0005432655491	2329	Economy	61500.00
0005432984701	2329	Economy	61500.00
0005433434302	2329	Economy	61500.00
0005432984747	2329	Economy	61500.00
0005433753528	26198	Business	184500.00
0005433434580	26198	Business	184500.00
0005435981654	26198	Business	184500.00
0005433434557	26198	Business	184500.00
0005433753519	26198	Business	184500.00
0005435981817	26198	Business	184500.00
0005432984943	26198	Business	184500.00
0005432869492	26198	Business	184500.00
0005435981575	26198	Business	184500.00
0005433434556	26198	Business	184500.00
0005433753729	26198	Business	184500.00
0005432655352	26198	Business	184500.00
0005434731153	26198	Business	184500.00
0005433766596	26198	Business	184500.00
0005432655339	26198	Business	184500.00
0005433753640	26198	Business	184500.00
0005432655330	26198	Business	184500.00
0005433753520	26198	Business	184500.00
0005433753491	26198	Business	184500.00
0005433753599	26198	Business	184500.00
0005433753447	26198	Business	184500.00
0005432984960	26198	Business	184500.00
0005435981576	26198	Business	184500.00
0005435981631	26198	Business	184500.00
0005433753320	26198	Business	184500.00
0005432984952	26198	Business	184500.00
0005435981577	26198	Business	184500.00
0005432984933	26198	Business	184500.00
0005433434570	26198	Economy	67700.00
0005433434567	26198	Economy	67700.00
0005435981720	26198	Economy	67700.00
0005434731152	26198	Economy	61500.00
0005435981734	26198	Economy	61500.00
0005433753723	26198	Economy	61500.00
0005435981841	26198	Economy	61500.00
0005432984955	26198	Economy	61500.00
0005433764653	26198	Economy	61500.00
0005432984942	26198	Economy	61500.00
0005435981724	26198	Economy	61500.00
0005433766599	26198	Economy	61500.00
0005432984938	26198	Economy	61500.00
0005432984941	26198	Economy	61500.00
0005432984950	26198	Economy	61500.00
0005435981680	26198	Economy	61500.00
0005433753249	26198	Economy	61500.00
0005434731155	26198	Economy	61500.00
0005432655410	26198	Economy	61500.00
0005432984935	26198	Economy	61500.00
0005432984957	26198	Economy	61500.00
0005433753482	26198	Economy	61500.00
0005433753365	26198	Economy	61500.00
0005433764658	26198	Economy	61500.00
0005433753247	26198	Economy	61500.00
0005432984964	26198	Economy	61500.00
0005433753468	26198	Economy	61500.00
0005433766592	26198	Economy	61500.00
0005432984946	26198	Economy	61500.00
0005432655338	26198	Economy	61500.00
0005433753554	26198	Economy	61500.00
0005433434555	26198	Economy	61500.00
0005435981697	26198	Economy	61500.00
0005434731154	26198	Economy	61500.00
0005435981725	26198	Economy	61500.00
0005432869495	26198	Economy	61500.00
0005432655359	26198	Economy	61500.00
0005432984958	26198	Economy	61500.00
0005433764652	26198	Economy	61500.00
0005433753669	26198	Economy	61500.00
0005435981813	26198	Economy	61500.00
0005432869493	26198	Economy	61500.00
0005433753518	26198	Economy	61500.00
0005435981673	26198	Economy	61500.00
0005433434578	26198	Economy	61500.00
0005433753398	26198	Economy	61500.00
0005433434581	26198	Economy	61500.00
0005435981718	26198	Economy	61500.00
0005432984954	26198	Economy	61500.00
0005433753245	26198	Economy	61500.00
0005435981757	26198	Economy	61500.00
0005432984963	26198	Economy	61500.00
0005433753662	26198	Economy	61500.00
0005435981608	26198	Economy	61500.00
0005432655334	26198	Economy	61500.00
0005435981753	26198	Economy	61500.00
0005433753318	26198	Economy	61500.00
0005435981756	26198	Economy	61500.00
0005433434563	26198	Economy	61500.00
0005432655382	26198	Economy	61500.00
0005433753497	26198	Economy	61500.00
0005433753515	26198	Economy	61500.00
0005433753652	26198	Economy	61500.00
0005433753546	26198	Economy	61500.00
0005435981588	26198	Economy	61500.00
0005433753514	26198	Economy	61500.00
0005432655346	26198	Economy	61500.00
0005433753469	26198	Economy	61500.00
0005433434573	26198	Economy	61500.00
0005433434574	26198	Economy	61500.00
0005433753625	26198	Economy	61500.00
0005435981727	26198	Economy	61500.00
0005433753622	26198	Economy	61500.00
0005432655354	26198	Economy	61500.00
0005435981814	26198	Economy	61500.00
0005435981556	26198	Economy	61500.00
0005433434572	26198	Economy	61500.00
0005433434566	26198	Economy	61500.00
0005433434554	26198	Economy	61500.00
0005433753287	26198	Economy	61500.00
0005432051117	26198	Economy	61500.00
0005435981630	26198	Economy	61500.00
0005433434568	26198	Economy	61500.00
0005435981818	26198	Economy	61500.00
0005435981857	26198	Economy	61500.00
0005432984931	26198	Economy	61500.00
0005435981560	26198	Economy	61500.00
0005433753248	26198	Economy	61500.00
0005433753319	26198	Economy	61500.00
0005432984953	26198	Economy	61500.00
0005433434561	26198	Economy	61500.00
0005433753375	26198	Economy	61500.00
0005432984949	26198	Economy	61500.00
0005433434575	26198	Economy	61500.00
0005433753317	26198	Economy	61500.00
0005433753568	26198	Economy	67700.00
0005433434562	26198	Economy	61500.00
0005433753547	26198	Economy	67700.00
0005433434582	26198	Economy	61500.00
0005432051116	26198	Economy	61500.00
0005432984932	26198	Economy	67700.00
0005432869494	26198	Economy	61500.00
0005432984948	26198	Economy	67700.00
0005433753410	26198	Economy	61500.00
0005435981784	26198	Economy	61500.00
0005435981829	26198	Economy	61500.00
0005435981721	26198	Economy	61500.00
0005435981535	26198	Economy	61500.00
0005435981705	26198	Economy	61500.00
0005433753492	26198	Economy	61500.00
0005433434576	26198	Economy	61500.00
0005435981651	26198	Economy	61500.00
0005435981561	26198	Economy	61500.00
0005433753527	26198	Economy	61500.00
0005433753614	26198	Economy	61500.00
0005432655343	26198	Economy	61500.00
0005435981557	26198	Economy	61500.00
0005433753505	26198	Economy	61500.00
0005432051115	26198	Economy	61500.00
0005435981728	26198	Economy	61500.00
0005435981696	26198	Economy	61500.00
0005435981752	26198	Economy	61500.00
0005433753316	26198	Economy	61500.00
0005433753540	26198	Economy	61500.00
0005432984945	26198	Economy	61500.00
0005433434560	26198	Economy	61500.00
0005432984956	26198	Economy	61500.00
0005435981558	26198	Economy	61500.00
0005433753399	26198	Economy	61500.00
0005433753493	26198	Economy	61500.00
0005433753412	26198	Economy	61500.00
0005433753295	26198	Economy	61500.00
0005433753586	26198	Economy	61500.00
0005432984962	26198	Economy	61500.00
0005435981562	26198	Economy	61500.00
0005433753335	26198	Economy	61500.00
0005432984937	26198	Economy	61500.00
0005435981589	26198	Economy	61500.00
0005432984961	26198	Economy	61500.00
0005435981607	26198	Economy	61500.00
0005432869498	26198	Economy	61500.00
0005433434559	26198	Economy	61500.00
0005432984939	26198	Economy	61500.00
0005435981811	26198	Economy	61500.00
0005432984951	26198	Economy	61500.00
0005433766598	26198	Economy	61500.00
0005433434571	26198	Economy	61500.00
0005433753364	26198	Economy	61500.00
0005432049450	26198	Economy	61500.00
0005432655383	26198	Economy	61500.00
0005433753448	26198	Economy	61500.00
0005432984944	26198	Economy	61500.00
0005433753587	26198	Economy	61500.00
0005433766591	26198	Economy	61500.00
0005433753417	26198	Economy	61500.00
0005432869497	26198	Economy	61500.00
0005435981787	26198	Economy	61500.00
0005435981788	26198	Economy	61500.00
0005433434577	26198	Economy	61500.00
0005435981719	26198	Economy	61500.00
0005432984947	26198	Economy	61500.00
0005433434569	26198	Economy	61500.00
0005433753339	26198	Economy	61500.00
0005433434558	26198	Economy	61500.00
0005432984959	26198	Economy	61500.00
0005433434564	26198	Economy	61500.00
0005433434579	26198	Economy	61500.00
0005432984934	26198	Economy	61500.00
0005433434565	26198	Economy	61500.00
0005433753244	26198	Economy	61500.00
0005433753589	26198	Economy	61500.00
0005432869496	26198	Economy	61500.00
0005432984936	26198	Economy	61500.00
0005432655329	26198	Economy	61500.00
0005432984940	26198	Economy	61500.00
0005433151000	1501	Business	38900.00
0005434374498	1501	Business	38900.00
0005434374483	1501	Business	38900.00
0005434374492	1501	Business	38900.00
0005434374490	1501	Business	38900.00
0005433460428	1501	Business	38900.00
0005434374475	1501	Business	38900.00
0005433764649	1501	Business	38900.00
0005434374470	1501	Business	38900.00
0005434374491	1501	Business	38900.00
0005433460427	1501	Economy	13000.00
0005433151062	1501	Economy	13000.00
0005434374466	1501	Economy	13000.00
0005433150899	1501	Economy	13000.00
0005434374501	1501	Economy	13000.00
0005433150906	1501	Economy	13000.00
0005433931425	1501	Economy	13000.00
0005434374505	1501	Economy	13000.00
0005434374506	1501	Economy	13000.00
0005433151081	1501	Economy	13000.00
0005433764648	1501	Economy	13000.00
0005434374497	1501	Economy	13000.00
0005434374461	1501	Economy	13000.00
0005434374476	1501	Economy	13000.00
0005433764647	1501	Economy	13000.00
0005434374485	1501	Economy	13000.00
0005434374486	1501	Economy	13000.00
0005433151104	1501	Economy	13000.00
0005434374508	1501	Economy	13000.00
0005433150996	1501	Economy	13000.00
0005433150953	1501	Economy	13000.00
0005433150954	1501	Economy	13000.00
0005433150969	1501	Economy	13000.00
0005434374504	1501	Economy	13000.00
0005434374493	1501	Economy	13000.00
0005433150986	1501	Economy	13000.00
0005433151011	1501	Economy	14300.00
0005433150907	1501	Economy	14300.00
0005433150904	1501	Economy	14300.00
0005434029619	1501	Economy	14300.00
0005434374489	1501	Economy	14300.00
0005433151129	1501	Economy	13000.00
0005433150945	1501	Economy	13000.00
0005433150908	1501	Economy	13000.00
0005432267869	1501	Economy	13000.00
0005433150856	1501	Economy	13000.00
0005434374484	1501	Economy	13000.00
0005434374469	1501	Economy	13000.00
0005432267866	1501	Economy	13000.00
0005433150905	1501	Economy	13000.00
0005434374495	1501	Economy	13000.00
0005434374463	1501	Economy	13000.00
0005433151005	1501	Economy	13000.00
0005434374474	1501	Economy	13000.00
0005434374460	1501	Economy	13000.00
0005432267867	1501	Economy	13000.00
0005433151090	1501	Economy	13000.00
0005433150985	1501	Economy	13000.00
0005433151012	1501	Economy	13000.00
0005434374462	1501	Economy	13000.00
0005434374496	1501	Economy	13000.00
0005434374488	1501	Economy	13000.00
0005434374503	1501	Economy	13000.00
0005434029626	1501	Economy	13000.00
0005433151049	1501	Economy	13000.00
0005434374502	1501	Economy	13000.00
0005434374465	1501	Economy	13000.00
0005434374464	1501	Economy	13000.00
0005433151128	1501	Economy	13000.00
0005434029631	1501	Economy	13000.00
0005434374477	1501	Economy	13000.00
0005433150968	1501	Economy	13000.00
0005434374487	1501	Economy	13000.00
0005434374467	1501	Economy	13000.00
0005434374478	1501	Economy	13000.00
0005434374482	1501	Economy	13000.00
0005433151001	1501	Economy	13000.00
0005433461580	1501	Economy	13000.00
0005434374473	1501	Economy	13000.00
0005434374507	1501	Economy	13000.00
0005433150982	1501	Economy	13000.00
0005434374509	1501	Economy	13000.00
0005434374472	1501	Economy	13000.00
0005434374499	1501	Economy	13000.00
0005434374481	1501	Economy	13000.00
0005432267871	1501	Economy	13000.00
0005434374480	1501	Economy	13000.00
0005434374500	1501	Economy	13000.00
0005434374471	1501	Economy	13000.00
0005433150903	1501	Economy	13000.00
0005434374468	1501	Economy	13000.00
0005433151050	1501	Economy	13000.00
0005432267870	1501	Economy	13000.00
0005434374479	1501	Economy	13000.00
0005434374494	1501	Economy	13000.00
0005434029620	1501	Economy	13000.00
0005432267868	1501	Economy	13000.00
0005433764673	20156	Business	38900.00
0005433151279	20156	Business	38900.00
0005434374029	20156	Business	38900.00
0005434374226	20156	Business	38900.00
0005434029645	20156	Business	38900.00
0005434374127	20156	Business	38900.00
0005433151281	20156	Business	38900.00
0005433151283	20156	Economy	13000.00
0005434374048	20156	Economy	13000.00
0005434374207	20156	Economy	13000.00
0005433764672	20156	Economy	13000.00
0005434374234	20156	Economy	13000.00
0005434373921	20156	Economy	13000.00
0005433151256	20156	Economy	13000.00
0005432056282	20156	Economy	13000.00
0005434374264	20156	Economy	13000.00
0005434374151	20156	Economy	13000.00
0005432056284	20156	Economy	13000.00
0005433151251	20156	Economy	13000.00
0005434374084	20156	Economy	13000.00
0005434373993	20156	Economy	13000.00
0005434374014	20156	Economy	13000.00
0005433151276	20156	Economy	13000.00
0005433151253	20156	Economy	13000.00
0005433151252	20156	Economy	13000.00
0005434374354	20156	Economy	13000.00
0005433151267	20156	Economy	13000.00
0005434374108	20156	Economy	13000.00
0005434029647	20156	Economy	13000.00
0005432056286	20156	Economy	13000.00
0005433151263	20156	Economy	13000.00
0005433151269	20156	Economy	13000.00
0005434374189	20156	Economy	13000.00
0005434374150	20156	Economy	13000.00
0005434374096	20156	Economy	13000.00
0005433151268	20156	Economy	13000.00
0005434374016	20156	Economy	14300.00
0005434374175	20156	Economy	14300.00
0005434374130	20156	Economy	14300.00
0005434374176	20156	Economy	13000.00
0005433151254	20156	Economy	13000.00
0005434029646	20156	Economy	13000.00
0005434374138	20156	Economy	13000.00
0005434374004	20156	Economy	13000.00
0005433151277	20156	Economy	13000.00
0005433151257	20156	Economy	13000.00
0005432056287	20156	Economy	13000.00
0005433151271	20156	Economy	13000.00
0005434373916	20156	Economy	13000.00
0005433151255	20156	Economy	13000.00
0005434374145	20156	Economy	13000.00
0005434374098	20156	Economy	13000.00
0005434374206	20156	Economy	13000.00
0005434373975	20156	Economy	13000.00
0005434374154	20156	Economy	13000.00
0005434373976	20156	Economy	13000.00
0005434374132	20156	Economy	13000.00
0005433151260	20156	Economy	13000.00
0005433151262	20156	Economy	13000.00
0005433764671	20156	Economy	13000.00
0005433151259	20156	Economy	13000.00
0005434373920	20156	Economy	13000.00
0005433151275	20156	Economy	13000.00
0005433151264	20156	Economy	13000.00
0005434374136	20156	Economy	13000.00
0005434374126	20156	Economy	13000.00
0005433151273	20156	Economy	13000.00
0005432056283	20156	Economy	13000.00
0005433151274	20156	Economy	13000.00
0005434373992	20156	Economy	13000.00
0005433931455	20156	Economy	13000.00
0005434374005	20156	Economy	13000.00
0005433151258	20156	Economy	13000.00
0005433931454	20156	Economy	13000.00
0005433151282	20156	Economy	13000.00
0005433151272	20156	Economy	13000.00
0005433151280	20156	Economy	13000.00
0005434374030	20156	Economy	13000.00
0005434374094	20156	Economy	13000.00
0005434374149	20156	Economy	13000.00
0005434373971	20156	Economy	13000.00
0005434029648	20156	Economy	13000.00
0005434374018	20156	Economy	13000.00
0005433151265	20156	Economy	13000.00
0005434374191	20156	Economy	13000.00
0005433151270	20156	Economy	13000.00
0005434374109	20156	Economy	13000.00
0005433151285	20156	Economy	13000.00
0005433151278	20156	Economy	13000.00
0005432056285	20156	Economy	13000.00
0005433151261	20156	Economy	13000.00
0005433931453	20156	Economy	13000.00
0005433151284	20156	Economy	13000.00
0005433151266	20156	Economy	13000.00
0005432424259	582	Business	27500.00
0005432424233	582	Business	27500.00
0005432282835	582	Business	27500.00
0005432424250	582	Business	27500.00
0005432282833	582	Business	27500.00
0005432424266	582	Business	27500.00
0005432424257	582	Business	27500.00
0005432424261	582	Business	27500.00
0005432282839	582	Economy	10100.00
0005432424239	582	Economy	10100.00
0005432424235	582	Economy	10100.00
0005432424231	582	Economy	9200.00
0005432424238	582	Economy	9200.00
0005432424247	582	Economy	9200.00
0005432424263	582	Economy	9200.00
0005432424236	582	Economy	9200.00
0005432424237	582	Economy	9200.00
0005432424240	582	Economy	9200.00
0005432424260	582	Economy	9200.00
0005432424253	582	Economy	9200.00
0005432282836	582	Economy	9200.00
0005432282834	582	Economy	9200.00
0005432424267	582	Economy	9200.00
0005432424241	582	Economy	9200.00
0005432282837	582	Economy	9200.00
0005432424264	582	Economy	9200.00
0005432282840	582	Economy	9200.00
0005432424251	582	Economy	10100.00
0005432424245	582	Economy	10100.00
0005432282838	582	Economy	9200.00
0005432424244	582	Economy	9200.00
0005432424252	582	Economy	9200.00
0005432424242	582	Economy	9200.00
0005432424246	582	Economy	9200.00
0005432424255	582	Economy	9200.00
0005432424234	582	Economy	9200.00
0005432424258	582	Economy	9200.00
0005432424268	582	Economy	9200.00
0005432424256	582	Economy	9200.00
0005432424262	582	Economy	9200.00
0005432424249	582	Economy	9200.00
0005432424243	582	Economy	9200.00
0005432424248	582	Economy	9200.00
0005432424232	582	Economy	9200.00
0005432282832	582	Economy	9200.00
0005432424254	582	Economy	9200.00
0005432424265	582	Economy	9200.00
0005432302317	12876	Business	27500.00
0005432302316	12876	Economy	9200.00
0005432302315	12876	Economy	9200.00
0005432423780	12847	Business	27500.00
0005432423781	12847	Business	27500.00
0005432423608	12847	Business	27500.00
0005432423858	12847	Business	27500.00
0005432423786	12847	Economy	10100.00
0005432423711	12847	Economy	10100.00
0005432423696	12847	Economy	10100.00
0005432423833	12847	Economy	10100.00
0005432423857	12847	Economy	9200.00
0005432423727	12847	Economy	9200.00
0005432423796	12847	Economy	9200.00
0005432423712	12847	Economy	9200.00
0005432423771	12847	Economy	9200.00
0005432423832	12847	Economy	9200.00
0005432423609	12847	Economy	9200.00
0005432423647	12847	Economy	9200.00
0005432423642	12847	Economy	9200.00
0005432423811	12847	Economy	9200.00
0005432423670	12847	Economy	9200.00
0005432423734	12847	Economy	9200.00
0005432423859	12847	Economy	9200.00
0005432423812	12847	Economy	9200.00
0005432423716	12847	Economy	9200.00
0005432423810	12847	Economy	10100.00
0005432423766	12847	Economy	9200.00
0005432423836	12847	Economy	10100.00
0005432423838	12847	Economy	9200.00
0005432423739	12847	Economy	9200.00
0005432423756	12847	Economy	9200.00
0005432423785	12847	Economy	9200.00
0005432423856	12847	Economy	9200.00
0005432423765	12847	Economy	9200.00
0005432423768	12847	Economy	9200.00
0005432423828	12847	Economy	9200.00
0005432423612	12847	Economy	9200.00
0005432423757	12847	Economy	9200.00
0005432423775	12847	Economy	9200.00
0005432423798	12847	Economy	9200.00
0005432423853	12847	Economy	9200.00
0005432423776	12847	Economy	9200.00
0005432423713	12847	Economy	9200.00
0005432423618	12847	Economy	9200.00
0005432423795	12847	Economy	9200.00
0005432423815	12847	Economy	9200.00
0005432423767	12847	Economy	9200.00
0005432423728	12847	Economy	9200.00
0005432423837	12847	Economy	9200.00
0005432423787	12847	Economy	9200.00
0005433057552	447	Business	24500.00
0005434023439	447	Business	24500.00
0005434023413	447	Business	24500.00
0005434023430	447	Business	24500.00
0005434023446	447	Business	24500.00
0005432235608	447	Business	24500.00
0005433057462	447	Business	24500.00
0005434023436	447	Business	24500.00
0005434023423	447	Business	24500.00
0005434032003	447	Business	24500.00
0005434023435	447	Business	24500.00
0005434032002	447	Business	24500.00
0005434023416	447	Business	24500.00
0005433057213	447	Economy	9000.00
0005432235605	447	Economy	9000.00
0005434023452	447	Economy	9000.00
0005433057402	447	Economy	8200.00
0005434023419	447	Economy	8200.00
0005434023428	447	Economy	8200.00
0005433057463	447	Economy	8200.00
0005434023445	447	Economy	8200.00
0005433057437	447	Economy	8200.00
0005434023412	447	Economy	8200.00
0005434023457	447	Economy	8200.00
0005434023417	447	Economy	8200.00
0005434028285	447	Economy	8200.00
0005434023415	447	Economy	8200.00
0005434023420	447	Economy	8200.00
0005433057422	447	Economy	8200.00
0005433057180	447	Economy	8200.00
0005434023431	447	Economy	8200.00
0005434023432	447	Economy	8200.00
0005433057320	447	Economy	8200.00
0005434023459	447	Economy	8200.00
0005433057394	447	Economy	8200.00
0005432235604	447	Economy	8200.00
0005433057377	447	Economy	8200.00
0005434023438	447	Economy	8200.00
0005434023414	447	Economy	8200.00
0005434029644	447	Economy	8200.00
0005433929541	447	Economy	8200.00
0005434023406	447	Economy	8200.00
0005433057423	447	Economy	8200.00
0005434028286	447	Economy	8200.00
0005433057430	447	Economy	8200.00
0005434023405	447	Economy	8200.00
0005434023441	447	Economy	8200.00
0005434023427	447	Economy	8200.00
0005433057439	447	Economy	8200.00
0005434032001	447	Economy	8200.00
0005434023470	447	Economy	8200.00
0005433929562	447	Economy	8200.00
0005434023456	447	Economy	8200.00
0005434028284	447	Economy	8200.00
0005433057305	447	Economy	8200.00
0005433057181	447	Economy	8200.00
0005434029643	447	Economy	8200.00
0005434023433	447	Economy	8200.00
0005434023421	447	Economy	8200.00
0005434023453	447	Economy	8200.00
0005434023466	447	Economy	8200.00
0005434023437	447	Economy	8200.00
0005432045604	447	Economy	8200.00
0005434023403	447	Economy	8200.00
0005433057464	447	Economy	8200.00
0005434023442	447	Economy	8200.00
0005432235609	447	Economy	8200.00
0005434023450	447	Economy	8200.00
0005432235611	447	Economy	8200.00
0005433057461	447	Economy	8200.00
0005434023426	447	Economy	8200.00
0005434023443	447	Economy	8200.00
0005433057414	447	Economy	8200.00
0005433057421	447	Economy	8200.00
0005434023410	447	Economy	9000.00
0005433929578	447	Economy	8200.00
0005434023454	447	Economy	8200.00
0005433929579	447	Economy	9000.00
0005433057431	447	Economy	8200.00
0005433057496	447	Economy	9000.00
0005434023460	447	Economy	8200.00
0005433057412	447	Economy	8200.00
0005434023448	447	Economy	8200.00
0005434023411	447	Economy	8200.00
0005434023407	447	Economy	8200.00
0005433057229	447	Economy	8200.00
0005434023449	447	Economy	8200.00
0005434023440	447	Economy	8200.00
0005434023468	447	Economy	8200.00
0005434023402	447	Economy	8200.00
0005434023434	447	Economy	8200.00
0005434023451	447	Economy	8200.00
0005434023467	447	Economy	8200.00
0005434023425	447	Economy	8200.00
0005434023408	447	Economy	8200.00
0005433057306	447	Economy	8200.00
0005433057304	447	Economy	8200.00
0005432235606	447	Economy	8200.00
0005433057487	447	Economy	8200.00
0005433057408	447	Economy	8200.00
0005433057495	447	Economy	8200.00
0005434023455	447	Economy	8200.00
0005434023424	447	Economy	8200.00
0005433057411	447	Economy	8200.00
0005434023404	447	Economy	8200.00
0005433929540	447	Economy	8200.00
0005434023469	447	Economy	8200.00
0005434023444	447	Economy	8200.00
0005434023465	447	Economy	8200.00
0005434028287	447	Economy	8200.00
0005434023447	447	Economy	8200.00
0005434023463	447	Economy	8200.00
0005434023464	447	Economy	8200.00
0005432235610	447	Economy	8200.00
0005434023422	447	Economy	8200.00
0005432235607	447	Economy	8200.00
0005434023462	447	Economy	8200.00
0005433057413	447	Economy	8200.00
0005434023461	447	Economy	8200.00
0005434023458	447	Economy	8200.00
0005434023409	447	Economy	8200.00
0005433057488	447	Economy	8200.00
0005434023429	447	Economy	8200.00
0005434023418	447	Economy	8200.00
0005434022752	12680	Business	24500.00
0005434022912	12680	Business	24500.00
0005433057716	12680	Business	24500.00
0005433057741	12680	Business	24500.00
0005434023030	12680	Business	24500.00
0005434022719	12680	Business	24500.00
0005434028267	12680	Business	24500.00
0005434022798	12680	Business	24500.00
0005434735668	12680	Business	24500.00
0005434022995	12680	Business	24500.00
0005434022948	12680	Business	24500.00
0005434022706	12680	Business	24500.00
0005433057704	12680	Business	24500.00
0005434022897	12680	Business	24500.00
0005433057736	12680	Business	24500.00
0005434022583	12680	Business	24500.00
0005434022792	12680	Business	24500.00
0005434022964	12680	Business	24500.00
0005434022957	12680	Business	24500.00
0005434022733	12680	Business	24500.00
0005433057738	12680	Business	24500.00
0005434022911	12680	Business	24500.00
0005434022814	12680	Business	24500.00
0005434022907	12680	Business	24500.00
0005434023086	12680	Business	24500.00
0005434028260	12680	Economy	9000.00
0005433929598	12680	Economy	9000.00
0005432156349	12680	Economy	9000.00
0005432157484	12680	Economy	8200.00
0005434022697	12680	Economy	8200.00
0005434022896	12680	Economy	8200.00
0005433057727	12680	Economy	8200.00
0005433057732	12680	Economy	8200.00
0005434023121	12680	Economy	8200.00
0005434022970	12680	Economy	8200.00
0005432156347	12680	Economy	8200.00
0005433057733	12680	Economy	8200.00
0005434735671	12680	Economy	8200.00
0005434022509	12680	Economy	8200.00
0005433057739	12680	Economy	8200.00
0005433057724	12680	Economy	8200.00
0005432157485	12680	Economy	8200.00
0005434022655	12680	Economy	8200.00
0005434022972	12680	Economy	8200.00
0005433057708	12680	Economy	8200.00
0005434023000	12680	Economy	8200.00
0005433057707	12680	Economy	8200.00
0005434022985	12680	Economy	8200.00
0005433057711	12680	Economy	8200.00
0005434735670	12680	Economy	8200.00
0005433929595	12680	Economy	8200.00
0005433057726	12680	Economy	8200.00
0005434023013	12680	Economy	8200.00
0005434022906	12680	Economy	8200.00
0005434022505	12680	Economy	8200.00
0005433057710	12680	Economy	8200.00
0005434022675	12680	Economy	8200.00
0005434022830	12680	Economy	8200.00
0005434735667	12680	Economy	8200.00
0005434022658	12680	Economy	8200.00
0005433057712	12680	Economy	8200.00
0005434029620	12680	Economy	8200.00
0005434023016	12680	Economy	8200.00
0005432156345	12680	Economy	8200.00
0005434022716	12680	Economy	8200.00
0005433057714	12680	Economy	8200.00
0005434022718	12680	Economy	8200.00
0005434022821	12680	Economy	8200.00
0005433057722	12680	Economy	8200.00
0005434022570	12680	Economy	8200.00
0005433057715	12680	Economy	8200.00
0005434022865	12680	Economy	8200.00
0005434029631	12680	Economy	8200.00
0005434022993	12680	Economy	8200.00
0005434023006	12680	Economy	8200.00
0005433057729	12680	Economy	8200.00
0005434022793	12680	Economy	8200.00
0005434022565	12680	Economy	8200.00
0005433057735	12680	Economy	8200.00
0005434022956	12680	Economy	8200.00
0005434022744	12680	Economy	8200.00
0005434022566	12680	Economy	8200.00
0005434022681	12680	Economy	8200.00
0005433057706	12680	Economy	8200.00
0005434023044	12680	Economy	8200.00
0005434029626	12680	Economy	8200.00
0005434022707	12680	Economy	8200.00
0005434022887	12680	Economy	8200.00
0005433057703	12680	Economy	8200.00
0005434022596	12680	Economy	8200.00
0005434022510	12680	Economy	8200.00
0005434031969	12680	Economy	8200.00
0005434031957	12680	Economy	8200.00
0005434028266	12680	Economy	8200.00
0005434022822	12680	Economy	8200.00
0005433057742	12680	Economy	8200.00
0005434023012	12680	Economy	8200.00
0005433057725	12680	Economy	8200.00
0005434022933	12680	Economy	8200.00
0005434022564	12680	Economy	8200.00
0005434022546	12680	Economy	8200.00
0005434028255	12680	Economy	8200.00
0005434029619	12680	Economy	8200.00
0005433057717	12680	Economy	8200.00
0005433057730	12680	Economy	8200.00
0005434022929	12680	Economy	9000.00
0005434028258	12680	Economy	9000.00
0005433057705	12680	Economy	8200.00
0005434022649	12680	Economy	8200.00
0005434022514	12680	Economy	8200.00
0005434735666	12680	Economy	9000.00
0005434022654	12680	Economy	9000.00
0005434023043	12680	Economy	8200.00
0005434022735	12680	Economy	8200.00
0005434022863	12680	Economy	8200.00
0005433057728	12680	Economy	8200.00
0005434022753	12680	Economy	8200.00
0005434022965	12680	Economy	8200.00
0005433057720	12680	Economy	8200.00
0005434022734	12680	Economy	8200.00
0005434022768	12680	Economy	8200.00
0005434022648	12680	Economy	8200.00
0005433929596	12680	Economy	8200.00
0005434031971	12680	Economy	8200.00
0005433057740	12680	Economy	8200.00
0005433057723	12680	Economy	8200.00
0005433057737	12680	Economy	8200.00
0005434022813	12680	Economy	8200.00
0005434022717	12680	Economy	8200.00
0005434022947	12680	Economy	8200.00
0005434022908	12680	Economy	8200.00
0005434023007	12680	Economy	8200.00
0005434028257	12680	Economy	8200.00
0005434735669	12680	Economy	8200.00
0005434022971	12680	Economy	8200.00
0005434022934	12680	Economy	8200.00
0005434022848	12680	Economy	8200.00
0005434022745	12680	Economy	8200.00
0005433057721	12680	Economy	8200.00
0005434023122	12680	Economy	8200.00
0005434022650	12680	Economy	8200.00
0005434022743	12680	Economy	8200.00
0005432157483	12680	Economy	8200.00
0005434031967	12680	Economy	8200.00
0005434022973	12680	Economy	8200.00
0005434022969	12680	Economy	8200.00
0005433929599	12680	Economy	8200.00
0005434022823	12680	Economy	8200.00
0005434022756	12680	Economy	8200.00
0005433057713	12680	Economy	8200.00
0005433684413	12680	Economy	8200.00
0005432156346	12680	Economy	8200.00
0005432156348	12680	Economy	8200.00
0005434031961	12680	Economy	8200.00
0005433057702	12680	Economy	8200.00
0005434022864	12680	Economy	8200.00
0005434022996	12680	Economy	8200.00
0005433057718	12680	Economy	8200.00
0005433929594	12680	Economy	8200.00
0005433929597	12680	Economy	8200.00
0005434023078	12680	Economy	8200.00
0005433057731	12680	Economy	8200.00
0005433057719	12680	Economy	8200.00
0005433057734	12680	Economy	8200.00
0005434023010	12680	Economy	8200.00
0005434022779	12680	Economy	8200.00
0005434022866	12680	Economy	8200.00
0005434022966	12680	Economy	8200.00
0005434022506	12680	Economy	8200.00
0005434023158	12680	Economy	8200.00
0005434022762	12680	Economy	8200.00
0005433057709	12680	Economy	8200.00
0005432231520	2166	Business	34700.00
0005433035705	2166	Business	34700.00
0005433922930	2166	Business	34700.00
0005433922944	2166	Business	34700.00
0005433922914	2166	Business	34700.00
0005433035646	2166	Business	34700.00
0005433035673	2166	Business	34700.00
0005433035537	2166	Business	34700.00
0005433922899	2166	Business	34700.00
0005432231525	2166	Business	34700.00
0005433922898	2166	Business	34700.00
0005434028258	2166	Business	34700.00
0005433922947	2166	Business	34700.00
0005433922961	2166	Business	34700.00
0005432749754	2166	Business	34700.00
0005433922917	2166	Business	34700.00
0005433922942	2166	Business	34700.00
0005433035595	2166	Business	34700.00
0005433035574	2166	Business	34700.00
0005432231524	2166	Business	34700.00
0005433922948	2166	Business	34700.00
0005433035501	2166	Business	34700.00
0005433922885	2166	Business	34700.00
0005433922958	2166	Business	34700.00
0005433929594	2166	Business	34700.00
0005433035585	2166	Economy	12700.00
0005433922932	2166	Economy	12700.00
0005433922895	2166	Economy	11600.00
0005433922907	2166	Economy	11600.00
0005433922873	2166	Economy	11600.00
0005433922920	2166	Economy	11600.00
0005433922904	2166	Economy	11600.00
0005433922884	2166	Economy	11600.00
0005433922863	2166	Economy	11600.00
0005433035615	2166	Economy	11600.00
0005433035868	2166	Economy	11600.00
0005433922905	2166	Economy	11600.00
0005433922922	2166	Economy	11600.00
0005433922868	2166	Economy	11600.00
0005433929595	2166	Economy	11600.00
0005433035597	2166	Economy	11600.00
0005433035669	2166	Economy	11600.00
0005433035650	2166	Economy	11600.00
0005433035584	2166	Economy	11600.00
0005432231521	2166	Economy	11600.00
0005433035623	2166	Economy	11600.00
0005433035582	2166	Economy	11600.00
0005433035446	2166	Economy	11600.00
0005433922875	2166	Economy	11600.00
0005433922893	2166	Economy	11600.00
0005433035768	2166	Economy	11600.00
0005433922897	2166	Economy	11600.00
0005433931454	2166	Economy	11600.00
0005433922896	2166	Economy	11600.00
0005432231518	2166	Economy	11600.00
0005433035605	2166	Economy	11600.00
0005433922874	2166	Economy	11600.00
0005432231526	2166	Economy	11600.00
0005433035726	2166	Economy	11600.00
0005433922953	2166	Economy	11600.00
0005433922946	2166	Economy	11600.00
0005433922935	2166	Economy	11600.00
0005433929598	2166	Economy	11600.00
0005433035529	2166	Economy	11600.00
0005433922952	2166	Economy	11600.00
0005433922872	2166	Economy	11600.00
0005433035494	2166	Economy	11600.00
0005433922937	2166	Economy	11600.00
0005433035827	2166	Economy	11600.00
0005433035500	2166	Economy	11600.00
0005433922957	2166	Economy	11600.00
0005433922913	2166	Economy	11600.00
0005433922877	2166	Economy	11600.00
0005433035614	2166	Economy	11600.00
0005433922936	2166	Economy	11600.00
0005433922894	2166	Economy	11600.00
0005433035706	2166	Economy	11600.00
0005433035718	2166	Economy	11600.00
0005433922883	2166	Economy	11600.00
0005433035734	2166	Economy	11600.00
0005433922882	2166	Economy	11600.00
0005433922903	2166	Economy	11600.00
0005433922876	2166	Economy	11600.00
0005433922939	2166	Economy	11600.00
0005433922960	2166	Economy	11600.00
0005433922933	2166	Economy	11600.00
0005433931455	2166	Economy	11600.00
0005433035826	2166	Economy	11600.00
0005433035769	2166	Economy	11600.00
0005432231523	2166	Economy	11600.00
0005433922912	2166	Economy	11600.00
0005433035648	2166	Economy	11600.00
0005433922871	2166	Economy	11600.00
0005433922880	2166	Economy	11600.00
0005433035553	2166	Economy	11600.00
0005433922929	2166	Economy	11600.00
0005434028260	2166	Economy	11600.00
0005434028255	2166	Economy	11600.00
0005433035867	2166	Economy	11600.00
0005432044512	2166	Economy	11600.00
0005433035695	2166	Economy	11600.00
0005433922908	2166	Economy	11600.00
0005433922916	2166	Economy	11600.00
0005433035510	2166	Economy	11600.00
0005433922950	2166	Economy	11600.00
0005433922943	2166	Economy	11600.00
0005433929596	2166	Economy	11600.00
0005433922915	2166	Economy	11600.00
0005433922869	2166	Economy	11600.00
0005432231522	2166	Economy	11600.00
0005433922866	2166	Economy	12700.00
0005433929597	2166	Economy	12700.00
0005433922909	2166	Economy	11600.00
0005433922901	2166	Economy	11600.00
0005433035678	2166	Economy	12700.00
0005434028257	2166	Economy	11600.00
0005433035573	2166	Economy	12700.00
0005433922949	2166	Economy	11600.00
0005433035511	2166	Economy	11600.00
0005434028266	2166	Economy	11600.00
0005433922940	2166	Economy	11600.00
0005433035733	2166	Economy	11600.00
0005433929599	2166	Economy	11600.00
0005433922879	2166	Economy	11600.00
0005433035629	2166	Economy	11600.00
0005432231517	2166	Economy	11600.00
0005433035679	2166	Economy	11600.00
0005433035484	2166	Economy	11600.00
0005433035704	2166	Economy	11600.00
0005433922923	2166	Economy	11600.00
0005433922921	2166	Economy	11600.00
0005433035593	2166	Economy	11600.00
0005433922924	2166	Economy	11600.00
0005433922887	2166	Economy	11600.00
0005433035486	2166	Economy	11600.00
0005433922870	2166	Economy	11600.00
0005433922886	2166	Economy	11600.00
0005433922902	2166	Economy	11600.00
0005433922934	2166	Economy	11600.00
0005432749762	2166	Economy	11600.00
0005433922941	2166	Economy	11600.00
0005433035530	2166	Economy	11600.00
0005433922918	2166	Economy	11600.00
0005433922954	2166	Economy	11600.00
0005433035862	2166	Economy	11600.00
0005433922910	2166	Economy	11600.00
0005433035594	2166	Economy	11600.00
0005433922892	2166	Economy	11600.00
0005433922951	2166	Economy	11600.00
0005433922926	2166	Economy	11600.00
0005433922878	2166	Economy	11600.00
0005433922938	2166	Economy	11600.00
0005433922945	2166	Economy	11600.00
0005433922890	2166	Economy	11600.00
0005433922955	2166	Economy	11600.00
0005433922928	2166	Economy	11600.00
0005433922927	2166	Economy	11600.00
0005433035863	2166	Economy	11600.00
0005433922891	2166	Economy	11600.00
0005433035485	2166	Economy	11600.00
0005433922864	2166	Economy	11600.00
0005433922925	2166	Economy	11600.00
0005433922911	2166	Economy	11600.00
0005433922881	2166	Economy	11600.00
0005433922919	2166	Economy	11600.00
0005432044514	2166	Economy	11600.00
0005433931453	2166	Economy	11600.00
0005434028267	2166	Economy	11600.00
0005433922900	2166	Economy	11600.00
0005432044513	2166	Economy	11600.00
0005433922956	2166	Economy	11600.00
0005433922889	2166	Economy	11600.00
0005433922931	2166	Economy	11600.00
0005433035747	2166	Economy	11600.00
0005433035647	2166	Economy	11600.00
0005433035785	2166	Economy	11600.00
0005433922888	2166	Economy	11600.00
0005432231519	2166	Economy	11600.00
0005433035786	2166	Economy	11600.00
0005433922865	2166	Economy	11600.00
0005433922906	2166	Economy	11600.00
0005433875370	2166	Economy	11600.00
0005433922959	2166	Economy	11600.00
0005433922867	2166	Economy	11600.00
0005433922152	24122	Business	34700.00
0005433922114	24122	Business	34700.00
0005433922173	24122	Business	34700.00
0005433922410	24122	Business	34700.00
0005433921939	24122	Business	34700.00
0005433922009	24122	Business	34700.00
0005433921932	24122	Business	34700.00
0005433922036	24122	Business	34700.00
0005432206174	24122	Business	34700.00
0005433922293	24122	Business	34700.00
0005433036090	24122	Business	34700.00
0005433922253	24122	Business	34700.00
0005433921678	24122	Business	34700.00
0005433036072	24122	Business	34700.00
0005433929564	24122	Business	34700.00
0005433929560	24122	Business	34700.00
0005433921997	24122	Business	34700.00
0005433922227	24122	Business	34700.00
0005433036111	24122	Business	34700.00
0005433036077	24122	Business	34700.00
0005433922006	24122	Business	34700.00
0005433036069	24122	Business	34700.00
0005433922391	24122	Business	34700.00
0005433922127	24122	Business	34700.00
0005433922486	24122	Business	34700.00
0005433036085	24122	Business	34700.00
0005433921996	24122	Business	34700.00
0005433036107	24122	Economy	12700.00
0005433922361	24122	Economy	12700.00
0005432206172	24122	Economy	12700.00
0005433921682	24122	Economy	11600.00
0005433921911	24122	Economy	11600.00
0005433921973	24122	Economy	11600.00
0005433922354	24122	Economy	11600.00
0005433921683	24122	Economy	11600.00
0005433922522	24122	Economy	11600.00
0005433922056	24122	Economy	11600.00
0005433921875	24122	Economy	11600.00
0005433921949	24122	Economy	11600.00
0005433921808	24122	Economy	11600.00
0005433922451	24122	Economy	11600.00
0005433921946	24122	Economy	11600.00
0005433036061	24122	Economy	11600.00
0005432207652	24122	Economy	11600.00
0005433921876	24122	Economy	11600.00
0005432207653	24122	Economy	11600.00
0005433922226	24122	Economy	11600.00
0005433922150	24122	Economy	11600.00
0005433036092	24122	Economy	11600.00
0005433922244	24122	Economy	11600.00
0005433922017	24122	Economy	11600.00
0005433921720	24122	Economy	11600.00
0005433922065	24122	Economy	11600.00
0005433922151	24122	Economy	11600.00
0005433036071	24122	Economy	11600.00
0005433922125	24122	Economy	11600.00
0005433921679	24122	Economy	11600.00
0005433036112	24122	Economy	11600.00
0005433921846	24122	Economy	11600.00
0005433922545	24122	Economy	11600.00
0005433922057	24122	Economy	11600.00
0005433922548	24122	Economy	11600.00
0005433922071	24122	Economy	11600.00
0005433036091	24122	Economy	11600.00
0005432749775	24122	Economy	11600.00
0005433036098	24122	Economy	11600.00
0005433922368	24122	Economy	11600.00
0005433921986	24122	Economy	11600.00
0005433922286	24122	Economy	11600.00
0005433922556	24122	Economy	11600.00
0005432206173	24122	Economy	11600.00
0005433922357	24122	Economy	11600.00
0005433921809	24122	Economy	11600.00
0005433922025	24122	Economy	11600.00
0005433922072	24122	Economy	11600.00
0005433922229	24122	Economy	11600.00
0005433036079	24122	Economy	11600.00
0005433922565	24122	Economy	11600.00
0005433036066	24122	Economy	11600.00
0005433036060	24122	Economy	11600.00
0005433921591	24122	Economy	11600.00
0005433922411	24122	Economy	11600.00
0005433036101	24122	Economy	11600.00
0005433922113	24122	Economy	11600.00
0005433036087	24122	Economy	11600.00
0005433036074	24122	Economy	11600.00
0005433929569	24122	Economy	11600.00
0005433036082	24122	Economy	11600.00
0005432206171	24122	Economy	11600.00
0005433922118	24122	Economy	11600.00
0005433922386	24122	Economy	11600.00
0005433036070	24122	Economy	11600.00
0005433922360	24122	Economy	11600.00
0005433036097	24122	Economy	11600.00
0005433921837	24122	Economy	11600.00
0005433922207	24122	Economy	11600.00
0005433922140	24122	Economy	11600.00
0005433036062	24122	Economy	11600.00
0005433922392	24122	Economy	11600.00
0005433922105	24122	Economy	11600.00
0005433929547	24122	Economy	11600.00
0005433036106	24122	Economy	11600.00
0005433036078	24122	Economy	11600.00
0005433036059	24122	Economy	11600.00
0005433921695	24122	Economy	11600.00
0005433922487	24122	Economy	11600.00
0005433921971	24122	Economy	11600.00
0005433922190	24122	Economy	11600.00
0005433921926	24122	Economy	11600.00
0005433922149	24122	Economy	11600.00
0005432206169	24122	Economy	11600.00
0005433036081	24122	Economy	11600.00
0005433922099	24122	Economy	11600.00
0005433922450	24122	Economy	11600.00
0005433922246	24122	Economy	11600.00
0005433921963	24122	Economy	11600.00
0005433922037	24122	Economy	11600.00
0005433922153	24122	Economy	11600.00
0005433922180	24122	Economy	11600.00
0005433921684	24122	Economy	12700.00
0005433922147	24122	Economy	11600.00
0005433921681	24122	Economy	12700.00
0005433922075	24122	Economy	11600.00
0005433921732	24122	Economy	11600.00
0005433922128	24122	Economy	12700.00
0005433036096	24122	Economy	12700.00
0005432206175	24122	Economy	11600.00
0005433036076	24122	Economy	11600.00
0005433921977	24122	Economy	11600.00
0005433036064	24122	Economy	11600.00
0005433922206	24122	Economy	11600.00
0005433921925	24122	Economy	11600.00
0005433036110	24122	Economy	11600.00
0005433922523	24122	Economy	11600.00
0005433036080	24122	Economy	11600.00
0005433922339	24122	Economy	11600.00
0005433036108	24122	Economy	11600.00
0005433922367	24122	Economy	11600.00
0005433921721	24122	Economy	11600.00
0005433922566	24122	Economy	11600.00
0005433922126	24122	Economy	11600.00
0005433036068	24122	Economy	11600.00
0005433036065	24122	Economy	11600.00
0005433922008	24122	Economy	11600.00
0005433036099	24122	Economy	11600.00
0005433036073	24122	Economy	11600.00
0005433036104	24122	Economy	11600.00
0005432206170	24122	Economy	11600.00
0005433036093	24122	Economy	11600.00
0005433929563	24122	Economy	11600.00
0005433922315	24122	Economy	11600.00
0005433036086	24122	Economy	11600.00
0005433036109	24122	Economy	11600.00
0005433921592	24122	Economy	11600.00
0005433921970	24122	Economy	11600.00
0005433922074	24122	Economy	11600.00
0005433922345	24122	Economy	11600.00
0005433036103	24122	Economy	11600.00
0005433922202	24122	Economy	11600.00
0005433922544	24122	Economy	11600.00
0005433921947	24122	Economy	11600.00
0005433036075	24122	Economy	11600.00
0005433922007	24122	Economy	11600.00
0005433036095	24122	Economy	11600.00
0005432749776	24122	Economy	11600.00
0005433036100	24122	Economy	11600.00
0005433922148	24122	Economy	11600.00
0005433922038	24122	Economy	11600.00
0005433036088	24122	Economy	11600.00
0005433922115	24122	Economy	11600.00
0005433921668	24122	Economy	11600.00
0005433921952	24122	Economy	11600.00
0005433036067	24122	Economy	11600.00
0005432749777	24122	Economy	11600.00
0005433922524	24122	Economy	11600.00
0005433922209	24122	Economy	11600.00
0005433036089	24122	Economy	11600.00
0005433929561	24122	Economy	11600.00
0005433036094	24122	Economy	11600.00
0005433875357	24122	Economy	11600.00
0005433922470	24122	Economy	11600.00
0005433922245	24122	Economy	11600.00
0005433922106	24122	Economy	11600.00
0005433922430	24122	Economy	11600.00
0005433036083	24122	Economy	11600.00
0005433036084	24122	Economy	11600.00
0005433922285	24122	Economy	11600.00
0005433036063	24122	Economy	11600.00
0005433922225	24122	Economy	11600.00
0005433036105	24122	Economy	11600.00
0005433036102	24122	Economy	11600.00
0005433922177	24122	Economy	11600.00
0005433921680	24122	Economy	11600.00
0005433922567	24122	Economy	11600.00
0005433036113	24122	Economy	11600.00
0005434725025	259	Business	83700.00
0005434551028	259	Business	83700.00
0005434550999	259	Business	83700.00
0005434725039	259	Business	83700.00
0005434725020	259	Business	83700.00
0005433233407	259	Business	83700.00
0005434550994	259	Business	83700.00
0005434550995	259	Business	83700.00
0005433233380	259	Business	83700.00
0005432277757	259	Business	83700.00
0005433180765	259	Business	83700.00
0005434551021	259	Business	83700.00
0005433233399	259	Business	83700.00
0005434551011	259	Business	83700.00
0005433180785	259	Business	83700.00
0005434724947	259	Business	83700.00
0005432277747	259	Business	83700.00
0005434724967	259	Business	83700.00
0005434551040	259	Business	83700.00
0005435142525	259	Business	83700.00
0005433233223	259	Business	83700.00
0005435142519	259	Business	83700.00
0005433113508	259	Business	83700.00
0005434724962	259	Business	83700.00
0005434724973	259	Business	83700.00
0005433766588	259	Business	83700.00
0005433233386	259	Business	83700.00
0005433233415	259	Comfort	47400.00
0005433233532	259	Comfort	47400.00
0005434735665	259	Comfort	47400.00
0005433233438	259	Comfort	47400.00
0005433233224	259	Comfort	47400.00
0005433131649	259	Comfort	47400.00
0005434724951	259	Comfort	47400.00
0005433233321	259	Comfort	47400.00
0005433233323	259	Comfort	47400.00
0005434725005	259	Comfort	47400.00
0005433113509	259	Comfort	47400.00
0005434724950	259	Comfort	47400.00
0005434031954	259	Comfort	47400.00
0005433233339	259	Comfort	47400.00
0005434724956	259	Comfort	47400.00
0005433233254	259	Comfort	47400.00
0005434725022	259	Comfort	47400.00
0005432277750	259	Comfort	47400.00
0005434550993	259	Comfort	47400.00
0005434551036	259	Comfort	47400.00
0005434725044	259	Comfort	47400.00
0005433233469	259	Comfort	47400.00
0005434551005	259	Comfort	47400.00
0005434724938	259	Comfort	47400.00
0005433289750	259	Comfort	47400.00
0005434725011	259	Comfort	47400.00
0005434731149	259	Comfort	47400.00
0005433180764	259	Comfort	47400.00
0005434551033	259	Comfort	47400.00
0005434551019	259	Comfort	47400.00
0005433180704	259	Comfort	47400.00
0005433289745	259	Comfort	47400.00
0005433180934	259	Comfort	47400.00
0005434725002	259	Comfort	47400.00
0005433131650	259	Comfort	47400.00
0005434725032	259	Comfort	47400.00
0005434724969	259	Comfort	47400.00
0005433233713	259	Comfort	47400.00
0005434551037	259	Comfort	47400.00
0005434724937	259	Comfort	47400.00
0005434724977	259	Comfort	47400.00
0005433180701	259	Comfort	47400.00
0005434725038	259	Comfort	47400.00
0005434724985	259	Economy	27900.00
0005434724936	259	Comfort	47400.00
0005434725014	259	Economy	27900.00
0005433180781	259	Economy	27900.00
0005434725019	259	Economy	27900.00
0005434302442	259	Economy	27900.00
0005434724993	259	Economy	27900.00
0005434724933	259	Economy	27900.00
0005434551035	259	Economy	27900.00
0005434724999	259	Economy	27900.00
0005434725037	259	Economy	27900.00
0005432277749	259	Economy	27900.00
0005434302857	259	Economy	27900.00
0005434550998	259	Economy	27900.00
0005434725001	259	Economy	27900.00
0005434551030	259	Economy	27900.00
0005434724961	259	Economy	27900.00
0005434724935	259	Economy	27900.00
0005433233436	259	Economy	27900.00
0005434551023	259	Economy	27900.00
0005433233518	259	Economy	27900.00
0005434724930	259	Economy	27900.00
0005433180759	259	Economy	27900.00
0005434724952	259	Economy	27900.00
0005434724980	259	Economy	27900.00
0005433180758	259	Economy	27900.00
0005434551008	259	Economy	27900.00
0005433233349	259	Economy	27900.00
0005434724946	259	Economy	27900.00
0005434551009	259	Economy	27900.00
0005433180821	259	Economy	27900.00
0005434551043	259	Economy	27900.00
0005434551042	259	Economy	27900.00
0005434724924	259	Economy	27900.00
0005434551006	259	Economy	27900.00
0005434724953	259	Economy	27900.00
0005434724929	259	Economy	27900.00
0005434302858	259	Economy	27900.00
0005433233370	259	Economy	27900.00
0005434725031	259	Economy	27900.00
0005433126812	259	Economy	27900.00
0005433113512	259	Economy	27900.00
0005434724939	259	Economy	27900.00
0005433233437	259	Economy	27900.00
0005433233457	259	Economy	27900.00
0005432277756	259	Economy	27900.00
0005434551018	259	Economy	27900.00
0005434724994	259	Economy	27900.00
0005434724995	259	Economy	27900.00
0005432277751	259	Economy	27900.00
0005434724998	259	Economy	27900.00
0005435142520	259	Economy	27900.00
0005434551010	259	Economy	27900.00
0005433131643	259	Economy	27900.00
0005433233338	259	Economy	27900.00
0005435142522	259	Economy	27900.00
0005434551001	259	Economy	27900.00
0005434725026	259	Economy	27900.00
0005434550987	259	Economy	27900.00
0005433233237	259	Economy	27900.00
0005433131653	259	Economy	30700.00
0005434725041	259	Economy	30700.00
0005434551016	259	Economy	30700.00
0005433233128	259	Economy	27900.00
0005434302443	259	Economy	27900.00
0005434724974	259	Economy	27900.00
0005433180876	259	Economy	30700.00
0005434724963	259	Economy	30700.00
0005433180772	259	Economy	27900.00
0005434724932	259	Economy	27900.00
0005432277754	259	Economy	27900.00
0005434551000	259	Economy	27900.00
0005434725004	259	Economy	27900.00
0005434724945	259	Economy	27900.00
0005434551014	259	Economy	27900.00
0005434551039	259	Economy	27900.00
0005434551003	259	Economy	27900.00
0005434725023	259	Economy	27900.00
0005434735664	259	Economy	27900.00
0005434724934	259	Economy	27900.00
0005434551027	259	Economy	27900.00
0005433233434	259	Economy	27900.00
0005433766589	259	Economy	27900.00
0005433289775	259	Economy	27900.00
0005434551031	259	Economy	27900.00
0005434725012	259	Economy	27900.00
0005434551022	259	Economy	27900.00
0005434724972	259	Economy	27900.00
0005433233411	259	Economy	27900.00
0005434551041	259	Economy	27900.00
0005434550989	259	Economy	27900.00
0005434725015	259	Economy	27900.00
0005433766585	259	Economy	27900.00
0005434550997	259	Economy	27900.00
0005434551012	259	Economy	27900.00
0005434735662	259	Economy	27900.00
0005435142523	259	Economy	27900.00
0005434725016	259	Economy	27900.00
0005433233497	259	Economy	27900.00
0005434724931	259	Economy	27900.00
0005433233520	259	Economy	27900.00
0005434724992	259	Economy	27900.00
0005434724978	259	Economy	27900.00
0005433233480	259	Economy	27900.00
0005433180839	259	Economy	27900.00
0005434725036	259	Economy	27900.00
0005434724944	259	Economy	27900.00
0005434724954	259	Economy	27900.00
0005433289746	259	Economy	27900.00
0005433180786	259	Economy	27900.00
0005433180731	259	Economy	27900.00
0005433180813	259	Economy	27900.00
0005434724948	259	Economy	27900.00
0005433233212	259	Economy	27900.00
0005434725018	259	Economy	27900.00
0005434725029	259	Economy	27900.00
0005433233417	259	Economy	27900.00
0005434725013	259	Economy	27900.00
0005434725033	259	Economy	27900.00
0005433126785	259	Economy	27900.00
0005434550990	259	Economy	27900.00
0005433180753	259	Economy	27900.00
0005433233722	259	Economy	27900.00
0005433180803	259	Economy	27900.00
0005434731150	259	Economy	27900.00
0005434724927	259	Economy	27900.00
0005434551038	259	Economy	27900.00
0005434724928	259	Economy	27900.00
0005434550996	259	Economy	27900.00
0005433233255	259	Economy	27900.00
0005434724971	259	Economy	27900.00
0005433180873	259	Economy	27900.00
0005434551020	259	Economy	27900.00
0005434725035	259	Economy	27900.00
0005434724983	259	Economy	27900.00
0005434550991	259	Economy	27900.00
0005434551013	259	Economy	27900.00
0005433233280	259	Economy	27900.00
0005434724943	259	Economy	27900.00
0005435142515	259	Economy	27900.00
0005434725027	259	Economy	27900.00
0005433233279	259	Economy	27900.00
0005434031949	259	Economy	27900.00
0005434031955	259	Economy	27900.00
0005434724988	259	Economy	27900.00
0005433233375	259	Economy	27900.00
0005434724941	259	Economy	27900.00
0005434551007	259	Economy	27900.00
0005434724986	259	Economy	27900.00
0005433233479	259	Economy	27900.00
0005434551017	259	Economy	27900.00
0005433180667	259	Economy	27900.00
0005434724949	259	Economy	27900.00
0005434724958	259	Economy	27900.00
0005434302440	259	Economy	27900.00
0005434551002	259	Economy	27900.00
0005433180703	259	Economy	27900.00
0005432277755	259	Economy	27900.00
0005435142521	259	Economy	27900.00
0005432277748	259	Economy	27900.00
0005433233398	259	Economy	27900.00
0005433233400	259	Economy	27900.00
0005434725006	259	Economy	27900.00
0005433180897	259	Economy	27900.00
0005434725010	259	Economy	27900.00
0005434724940	259	Economy	27900.00
0005433289774	259	Economy	30700.00
0005435142518	259	Economy	30700.00
0005433180935	259	Economy	30700.00
0005433233538	259	Economy	30700.00
0005434724926	259	Economy	30700.00
0005434724964	259	Economy	27900.00
0005434724975	259	Economy	27900.00
0005433233337	259	Economy	27900.00
0005432277758	259	Economy	27900.00
0005433233348	259	Economy	27900.00
0005434302441	259	Economy	27900.00
0005432277760	259	Economy	27900.00
0005434724981	259	Economy	27900.00
0005434724991	259	Economy	27900.00
0005434725021	259	Economy	27900.00
0005433233492	259	Economy	27900.00
0005433233408	259	Economy	27900.00
0005433180838	259	Economy	27900.00
0005433233528	259	Economy	27900.00
0005433289758	259	Economy	27900.00
0005433233468	259	Economy	27900.00
0005434725034	259	Economy	27900.00
0005434724923	259	Economy	27900.00
0005434724970	259	Economy	27900.00
0005434725028	259	Economy	27900.00
0005433233475	259	Economy	27900.00
0005434725024	259	Economy	27900.00
0005433233478	259	Economy	27900.00
0005433180826	259	Economy	27900.00
0005433233498	259	Economy	27900.00
0005434735661	259	Economy	27900.00
0005434725043	259	Economy	27900.00
0005433233454	259	Economy	27900.00
0005435142528	259	Economy	27900.00
0005433233322	259	Economy	27900.00
0005435142517	259	Economy	27900.00
0005434551032	259	Economy	27900.00
0005434724989	259	Economy	27900.00
0005433180825	259	Economy	27900.00
0005434725030	259	Economy	27900.00
0005433233721	259	Economy	27900.00
0005432277753	259	Economy	27900.00
0005434725000	259	Economy	27900.00
0005434731151	259	Economy	27900.00
0005434724990	259	Economy	27900.00
0005433233447	259	Economy	27900.00
0005434725042	259	Economy	27900.00
0005433233453	259	Economy	27900.00
0005433233211	259	Economy	27900.00
0005433233298	259	Economy	27900.00
0005434551004	259	Economy	27900.00
0005434724960	259	Economy	27900.00
0005433233643	259	Economy	27900.00
0005434735663	259	Economy	27900.00
0005433233642	259	Economy	27900.00
0005434551034	259	Economy	27900.00
0005433233544	259	Economy	27900.00
0005434724942	259	Economy	27900.00
0005433180771	259	Economy	27900.00
0005434551029	259	Economy	27900.00
0005435142526	259	Economy	27900.00
0005433233144	259	Economy	27900.00
0005434550992	259	Economy	27900.00
0005433289757	259	Economy	27900.00
0005434724966	259	Economy	27900.00
0005432277752	259	Economy	27900.00
0005432277759	259	Economy	27900.00
0005434724982	259	Economy	27900.00
0005434551024	259	Economy	27900.00
0005433233439	259	Economy	27900.00
0005433233712	259	Economy	27900.00
0005434724922	259	Economy	27900.00
0005434725003	259	Economy	27900.00
0005434724979	259	Economy	27900.00
0005434724925	259	Economy	27900.00
0005433233376	259	Economy	27900.00
0005434724996	259	Economy	27900.00
0005433233487	259	Economy	27900.00
0005433180752	259	Economy	27900.00
0005434724976	259	Economy	27900.00
0005434724959	259	Economy	27900.00
0005434551026	259	Economy	27900.00
0005434724987	259	Economy	27900.00
0005434724965	259	Economy	27900.00
0005434550988	259	Economy	27900.00
0005433233723	259	Economy	27900.00
0005435142529	259	Economy	27900.00
0005433180872	259	Economy	27900.00
0005434724997	259	Economy	27900.00
0005434724984	259	Economy	27900.00
0005434724955	259	Economy	27900.00
0005434725017	259	Economy	27900.00
0005434724968	259	Economy	27900.00
0005434725007	259	Economy	27900.00
0005435142516	259	Economy	27900.00
0005435142527	259	Economy	27900.00
0005433766601	259	Economy	27900.00
0005434725009	259	Economy	27900.00
0005434725008	259	Economy	27900.00
0005434725040	259	Economy	27900.00
0005435142524	259	Economy	27900.00
0005434302439	259	Economy	27900.00
0005433180827	259	Economy	27900.00
0005434731148	259	Economy	27900.00
0005433233431	259	Economy	27900.00
0005434551025	259	Economy	27900.00
0005434031948	259	Economy	27900.00
0005434551015	259	Economy	27900.00
0005433233414	259	Economy	27900.00
0005434724957	259	Economy	27900.00
0005434735626	9820	Business	83700.00
0005434723603	9820	Business	83700.00
0005433233923	9820	Business	83700.00
0005434735638	9820	Business	83700.00
0005434724127	9820	Business	83700.00
0005434724305	9820	Business	83700.00
0005434724037	9820	Business	83700.00
0005434032008	9820	Business	83700.00
0005434723939	9820	Business	83700.00
0005434723940	9820	Business	83700.00
0005434550598	9820	Business	83700.00
0005433129254	9820	Business	83700.00
0005434724038	9820	Business	83700.00
0005433233917	9820	Business	83700.00
0005433233962	9820	Business	83700.00
0005433233960	9820	Business	83700.00
0005433181003	9820	Business	83700.00
0005435142352	9820	Business	83700.00
0005434724126	9820	Business	83700.00
0005434550468	9820	Business	83700.00
0005434550470	9820	Business	83700.00
0005433233978	9820	Business	83700.00
0005434724129	9820	Business	83700.00
0005434723327	9820	Business	83700.00
0005434550637	9820	Business	83700.00
0005433126827	9820	Comfort	47400.00
0005434550603	9820	Business	83700.00
0005433766624	9820	Comfort	47400.00
0005433180994	9820	Comfort	47400.00
0005433181010	9820	Comfort	47400.00
0005434550316	9820	Comfort	47400.00
0005433233967	9820	Comfort	47400.00
0005434550589	9820	Comfort	47400.00
0005433180997	9820	Comfort	47400.00
0005433289817	9820	Comfort	47400.00
0005434731113	9820	Comfort	47400.00
0005434723767	9820	Comfort	47400.00
0005434724081	9820	Comfort	47400.00
0005434550573	9820	Comfort	47400.00
0005434550549	9820	Comfort	47400.00
0005433233963	9820	Comfort	47400.00
0005433113528	9820	Comfort	47400.00
0005433233938	9820	Comfort	47400.00
0005434723401	9820	Comfort	47400.00
0005434550444	9820	Comfort	47400.00
0005433766625	9820	Comfort	47400.00
0005433181008	9820	Comfort	47400.00
0005434724132	9820	Comfort	47400.00
0005433181005	9820	Comfort	47400.00
0005434723971	9820	Comfort	47400.00
0005433180991	9820	Comfort	47400.00
0005434032009	9820	Comfort	47400.00
0005433233922	9820	Comfort	47400.00
0005433233929	9820	Comfort	47400.00
0005433766626	9820	Comfort	47400.00
0005434550376	9820	Comfort	47400.00
0005434550412	9820	Comfort	47400.00
0005434550472	9820	Comfort	47400.00
0005434723614	9820	Comfort	47400.00
0005434735636	9820	Comfort	47400.00
0005434731117	9820	Comfort	47400.00
0005433289813	9820	Comfort	47400.00
0005433126825	9820	Comfort	47400.00
0005434723383	9820	Economy	27900.00
0005435142470	9820	Economy	27900.00
0005434724030	9820	Economy	27900.00
0005434724171	9820	Economy	27900.00
0005434724122	9820	Economy	27900.00
0005433181004	9820	Economy	27900.00
0005434550329	9820	Economy	27900.00
0005433181007	9820	Economy	27900.00
0005433126824	9820	Economy	27900.00
0005433180995	9820	Economy	27900.00
0005434731110	9820	Economy	27900.00
0005434723877	9820	Economy	27900.00
0005434724055	9820	Economy	27900.00
0005434550504	9820	Economy	27900.00
0005433233980	9820	Economy	27900.00
0005432199221	9820	Economy	27900.00
0005434723815	9820	Economy	27900.00
0005434550322	9820	Economy	27900.00
0005433180996	9820	Economy	27900.00
0005433289814	9820	Economy	27900.00
0005435142413	9820	Economy	27900.00
0005433233932	9820	Economy	27900.00
0005434550330	9820	Economy	27900.00
0005433233939	9820	Economy	27900.00
0005435142406	9820	Economy	27900.00
0005435142385	9820	Economy	27900.00
0005433233934	9820	Economy	27900.00
0005433233956	9820	Economy	27900.00
0005435142429	9820	Economy	27900.00
0005433233968	9820	Economy	27900.00
0005434731109	9820	Economy	27900.00
0005434724161	9820	Economy	27900.00
0005434550660	9820	Economy	27900.00
0005434724304	9820	Economy	27900.00
0005434723785	9820	Economy	27900.00
0005434723561	9820	Economy	27900.00
0005434550570	9820	Economy	27900.00
0005434724005	9820	Economy	27900.00
0005434723605	9820	Economy	27900.00
0005434550380	9820	Economy	27900.00
0005434550550	9820	Economy	27900.00
0005434550514	9820	Economy	27900.00
0005434550321	9820	Economy	27900.00
0005433233979	9820	Economy	27900.00
0005434724082	9820	Economy	27900.00
0005433233940	9820	Economy	27900.00
0005433233933	9820	Economy	27900.00
0005434723843	9820	Economy	27900.00
0005433233970	9820	Economy	27900.00
0005434550505	9820	Economy	27900.00
0005433233928	9820	Economy	27900.00
0005434550502	9820	Economy	27900.00
0005433233982	9820	Economy	27900.00
0005434550314	9820	Economy	27900.00
0005435142356	9820	Economy	27900.00
0005434723784	9820	Economy	27900.00
0005433180989	9820	Economy	27900.00
0005434724500	9820	Economy	27900.00
0005434724190	9820	Economy	27900.00
0005433233976	9820	Economy	27900.00
0005433233965	9820	Economy	30700.00
0005433233918	9820	Economy	30700.00
0005433233920	9820	Economy	30700.00
0005433233950	9820	Economy	27900.00
0005433180987	9820	Economy	27900.00
0005433233949	9820	Economy	30700.00
0005433289816	9820	Economy	27900.00
0005433233971	9820	Economy	30700.00
0005433233930	9820	Economy	30700.00
0005434724232	9820	Economy	27900.00
0005434724191	9820	Economy	27900.00
0005433180998	9820	Economy	27900.00
0005434731099	9820	Economy	27900.00
0005433233981	9820	Economy	27900.00
0005434550588	9820	Economy	27900.00
0005433180999	9820	Economy	27900.00
0005434550308	9820	Economy	27900.00
0005433289815	9820	Economy	27900.00
0005434550374	9820	Economy	27900.00
0005434550471	9820	Economy	27900.00
0005435142407	9820	Economy	27900.00
0005434723484	9820	Economy	27900.00
0005433129258	9820	Economy	27900.00
0005432199218	9820	Economy	27900.00
0005433766623	9820	Economy	27900.00
0005435142351	9820	Economy	27900.00
0005435142355	9820	Economy	27900.00
0005434724398	9820	Economy	27900.00
0005434731112	9820	Economy	27900.00
0005434724043	9820	Economy	27900.00
0005434723705	9820	Economy	27900.00
0005434550439	9820	Economy	27900.00
0005434723483	9820	Economy	27900.00
0005434723749	9820	Economy	27900.00
0005434550462	9820	Economy	27900.00
0005434724118	9820	Economy	27900.00
0005433126823	9820	Economy	27900.00
0005433233955	9820	Economy	27900.00
0005433129257	9820	Economy	27900.00
0005433233966	9820	Economy	27900.00
0005433233943	9820	Economy	27900.00
0005433181009	9820	Economy	27900.00
0005434723907	9820	Economy	27900.00
0005434550299	9820	Economy	27900.00
0005434723812	9820	Economy	27900.00
0005433180985	9820	Economy	27900.00
0005434731111	9820	Economy	27900.00
0005434723591	9820	Economy	27900.00
0005433233952	9820	Economy	27900.00
0005433181000	9820	Economy	27900.00
0005434723786	9820	Economy	27900.00
0005434723987	9820	Economy	27900.00
0005433233961	9820	Economy	27900.00
0005434550306	9820	Economy	27900.00
0005432199222	9820	Economy	27900.00
0005433233974	9820	Economy	27900.00
0005434550567	9820	Economy	27900.00
0005434550681	9820	Economy	27900.00
0005435142348	9820	Economy	27900.00
0005433233935	9820	Economy	27900.00
0005434723310	9820	Economy	27900.00
0005434724039	9820	Economy	27900.00
0005433180992	9820	Economy	27900.00
0005434723933	9820	Economy	27900.00
0005434723941	9820	Economy	27900.00
0005434723801	9820	Economy	27900.00
0005433233951	9820	Economy	27900.00
0005434735624	9820	Economy	27900.00
0005434550568	9820	Economy	27900.00
0005434735625	9820	Economy	27900.00
0005434550375	9820	Economy	27900.00
0005433233919	9820	Economy	27900.00
0005433233975	9820	Economy	27900.00
0005433233957	9820	Economy	27900.00
0005433233953	9820	Economy	27900.00
0005433233944	9820	Economy	27900.00
0005433233925	9820	Economy	27900.00
0005434724536	9820	Economy	27900.00
0005434032006	9820	Economy	27900.00
0005433233972	9820	Economy	27900.00
0005434724066	9820	Economy	27900.00
0005434723685	9820	Economy	27900.00
0005434723970	9820	Economy	27900.00
0005434723949	9820	Economy	27900.00
0005434724006	9820	Economy	27900.00
0005434723992	9820	Economy	27900.00
0005434723995	9820	Economy	27900.00
0005433289818	9820	Economy	27900.00
0005433766627	9820	Economy	27900.00
0005434724016	9820	Economy	27900.00
0005434723864	9820	Economy	27900.00
0005435142340	9820	Economy	27900.00
0005434724265	9820	Economy	27900.00
0005434550461	9820	Economy	27900.00
0005433233948	9820	Economy	27900.00
0005433113526	9820	Economy	27900.00
0005434723704	9820	Economy	27900.00
0005434723845	9820	Economy	27900.00
0005433233926	9820	Economy	27900.00
0005434723996	9820	Economy	27900.00
0005434724068	9820	Economy	27900.00
0005433233959	9820	Economy	27900.00
0005433181001	9820	Economy	27900.00
0005434724107	9820	Economy	30700.00
0005434724214	9820	Economy	30700.00
0005434724192	9820	Economy	30700.00
0005433180986	9820	Economy	30700.00
0005432199220	9820	Economy	30700.00
0005434550309	9820	Economy	30700.00
0005434724056	9820	Economy	27900.00
0005434724537	9820	Economy	27900.00
0005433113527	9820	Economy	27900.00
0005433289819	9820	Economy	27900.00
0005434550387	9820	Economy	27900.00
0005434550445	9820	Economy	27900.00
0005433233942	9820	Economy	27900.00
0005435142430	9820	Economy	27900.00
0005434723974	9820	Economy	27900.00
0005434723946	9820	Economy	27900.00
0005434723326	9820	Economy	27900.00
0005434550638	9820	Economy	27900.00
0005435142359	9820	Economy	27900.00
0005434724431	9820	Economy	27900.00
0005434724098	9820	Economy	27900.00
0005434724162	9820	Economy	27900.00
0005434550469	9820	Economy	27900.00
0005434724099	9820	Economy	27900.00
0005434550264	9820	Economy	27900.00
0005434724430	9820	Economy	27900.00
0005434723604	9820	Economy	27900.00
0005434723759	9820	Economy	27900.00
0005433233969	9820	Economy	27900.00
0005434032004	9820	Economy	27900.00
0005433233946	9820	Economy	27900.00
0005433126826	9820	Economy	27900.00
0005434723947	9820	Economy	27900.00
0005433129256	9820	Economy	27900.00
0005434723703	9820	Economy	27900.00
0005433233954	9820	Economy	27900.00
0005433233977	9820	Economy	27900.00
0005434724130	9820	Economy	27900.00
0005434723768	9820	Economy	27900.00
0005434724026	9820	Economy	27900.00
0005433181002	9820	Economy	27900.00
0005433233924	9820	Economy	27900.00
0005434724015	9820	Economy	27900.00
0005434032007	9820	Economy	27900.00
0005434723935	9820	Economy	27900.00
0005434032005	9820	Economy	27900.00
0005433233921	9820	Economy	27900.00
0005435142361	9820	Economy	27900.00
0005434723655	9820	Economy	27900.00
0005434724067	9820	Economy	27900.00
0005434550803	9820	Economy	27900.00
0005434550438	9820	Economy	27900.00
0005433233964	9820	Economy	27900.00
0005434550599	9820	Economy	27900.00
0005433129259	9820	Economy	27900.00
0005434723810	9820	Economy	27900.00
0005434550300	9820	Economy	27900.00
0005434724361	9820	Economy	27900.00
0005433233945	9820	Economy	27900.00
0005434724079	9820	Economy	27900.00
0005434724119	9820	Economy	27900.00
0005434723975	9820	Economy	27900.00
0005434550576	9820	Economy	27900.00
0005433233947	9820	Economy	27900.00
0005433181006	9820	Economy	27900.00
0005434550802	9820	Economy	27900.00
0005433180990	9820	Economy	27900.00
0005434723562	9820	Economy	27900.00
0005433180988	9820	Economy	27900.00
0005434723811	9820	Economy	27900.00
0005434723932	9820	Economy	27900.00
0005433180993	9820	Economy	27900.00
0005434302398	9820	Economy	27900.00
0005433126828	9820	Economy	27900.00
0005433233927	9820	Economy	27900.00
0005434724213	9820	Economy	27900.00
0005435142360	9820	Economy	27900.00
0005434723699	9820	Economy	27900.00
0005432199219	9820	Economy	27900.00
0005434724010	9820	Economy	27900.00
0005434724306	9820	Economy	27900.00
0005433233936	9820	Economy	27900.00
0005434723908	9820	Economy	27900.00
0005433233931	9820	Economy	27900.00
0005433129255	9820	Economy	27900.00
0005434550583	9820	Economy	27900.00
0005434723964	9820	Economy	27900.00
0005433233941	9820	Economy	27900.00
0005432199217	9820	Economy	27900.00
0005433233937	9820	Economy	27900.00
0005433233973	9820	Economy	27900.00
0005434723863	9820	Economy	27900.00
0005435142471	9820	Economy	27900.00
0005434735637	9820	Economy	27900.00
0005434550451	9820	Economy	27900.00
0005434550315	9820	Economy	27900.00
0005434723930	9820	Economy	27900.00
0005434724399	9820	Economy	27900.00
0005433233958	9820	Economy	27900.00
0005435212537	7771	Business	42100.00
0005432527426	7771	Business	42100.00
0005432527399	7771	Business	42100.00
0005432527429	7771	Business	42100.00
0005432527431	7771	Business	42100.00
0005432527442	7771	Business	42100.00
0005434067253	7771	Business	42100.00
0005432069598	7771	Business	42100.00
0005432527428	7771	Business	42100.00
0005432535813	7771	Business	42100.00
0005432428915	7771	Business	42100.00
0005435212865	7771	Business	42100.00
0005434067295	7771	Business	42100.00
0005432527434	7771	Business	42100.00
0005435212524	7771	Business	42100.00
0005432527419	7771	Business	42100.00
0005432527451	7771	Business	42100.00
0005434067292	7771	Business	42100.00
0005434067254	7771	Business	42100.00
0005432527495	7771	Business	42100.00
0005432527457	7771	Business	42100.00
0005432527427	7771	Business	42100.00
0005432527384	7771	Business	42100.00
0005432527441	7771	Business	42100.00
0005434067302	7771	Comfort	23900.00
0005432527382	7771	Business	42100.00
0005432535812	7771	Comfort	23900.00
0005432527463	7771	Comfort	23900.00
0005435630920	7771	Comfort	23900.00
0005432069595	7771	Comfort	23900.00
0005435212604	7771	Comfort	23900.00
0005434067249	7771	Comfort	23900.00
0005434067274	7771	Comfort	23900.00
0005435212675	7771	Comfort	23900.00
0005435212489	7771	Comfort	23900.00
0005435212851	7771	Comfort	23900.00
0005434067248	7771	Comfort	23900.00
0005432527407	7771	Comfort	23900.00
0005434067298	7771	Comfort	23900.00
0005434067277	7771	Comfort	23900.00
0005432527416	7771	Comfort	23900.00
0005432527420	7771	Comfort	23900.00
0005434067251	7771	Comfort	23900.00
0005435630923	7771	Comfort	23900.00
0005434067293	7771	Comfort	23900.00
0005432527479	7771	Comfort	23900.00
0005432069589	7771	Comfort	23900.00
0005432527445	7771	Comfort	23900.00
0005432527379	7771	Comfort	23900.00
0005434067282	7771	Comfort	23900.00
0005432527506	7771	Comfort	23900.00
0005432527381	7771	Comfort	23900.00
0005435212549	7771	Comfort	23900.00
0005432527511	7771	Comfort	23900.00
0005432527400	7771	Comfort	23900.00
0005432527412	7771	Comfort	23900.00
0005432527447	7771	Comfort	23900.00
0005435213000	7771	Comfort	23900.00
0005434067239	7771	Comfort	23900.00
0005432527470	7771	Economy	14000.00
0005434067284	7771	Economy	14000.00
0005434067303	7771	Economy	14000.00
0005432527508	7771	Economy	14000.00
0005434067258	7771	Economy	14000.00
0005432069592	7771	Economy	14000.00
0005432527388	7771	Economy	14000.00
0005434067246	7771	Economy	14000.00
0005432527394	7771	Economy	14000.00
0005434067241	7771	Economy	14000.00
0005432527481	7771	Economy	14000.00
0005432527414	7771	Economy	14000.00
0005432537049	7771	Economy	14000.00
0005432150165	7771	Economy	14000.00
0005432527408	7771	Economy	14000.00
0005432527489	7771	Economy	14000.00
0005435212704	7771	Economy	14000.00
0005432535814	7771	Economy	14000.00
0005435212860	7771	Economy	14000.00
0005435725541	7771	Economy	14000.00
0005434067259	7771	Economy	14000.00
0005432527509	7771	Economy	14000.00
0005432069590	7771	Economy	14000.00
0005435212580	7771	Economy	14000.00
0005432527477	7771	Economy	14000.00
0005434067301	7771	Economy	14000.00
0005435212620	7771	Economy	14000.00
0005434067261	7771	Economy	14000.00
0005434067289	7771	Economy	14000.00
0005434067276	7771	Economy	14000.00
0005434067299	7771	Economy	14000.00
0005432527507	7771	Economy	14000.00
0005432527401	7771	Economy	14000.00
0005435212688	7771	Economy	14000.00
0005432527490	7771	Economy	14000.00
0005434067243	7771	Economy	14000.00
0005432527460	7771	Economy	14000.00
0005432527453	7771	Economy	14000.00
0005432527497	7771	Economy	14000.00
0005434067257	7771	Economy	14000.00
0005432527455	7771	Economy	14000.00
0005432069599	7771	Economy	14000.00
0005432527396	7771	Economy	14000.00
0005435212526	7771	Economy	14000.00
0005432527387	7771	Economy	14000.00
0005434067297	7771	Economy	14000.00
0005435212676	7771	Economy	14000.00
0005434067244	7771	Economy	14000.00
0005432527437	7771	Economy	14000.00
0005432527409	7771	Economy	14000.00
0005432150162	7771	Economy	14000.00
0005433656622	7771	Economy	14000.00
0005432527448	7771	Economy	14000.00
0005434067265	7771	Economy	14000.00
0005434067269	7771	Economy	14000.00
0005432527500	7771	Economy	14000.00
0005432527424	7771	Economy	15400.00
0005432527486	7771	Economy	15400.00
0005434067281	7771	Economy	14000.00
0005432527478	7771	Economy	15400.00
0005435212737	7771	Economy	14000.00
0005432527494	7771	Economy	15400.00
0005435212903	7771	Economy	14000.00
0005432537050	7771	Economy	14000.00
0005432527450	7771	Economy	14000.00
0005435212666	7771	Economy	14000.00
0005434067305	7771	Economy	14000.00
0005435725539	7771	Economy	14000.00
0005435212798	7771	Economy	14000.00
0005432150163	7771	Economy	14000.00
0005432527465	7771	Economy	14000.00
0005432527406	7771	Economy	14000.00
0005434067272	7771	Economy	14000.00
0005432527491	7771	Economy	14000.00
0005435212929	7771	Economy	14000.00
0005434067290	7771	Economy	14000.00
0005434067275	7771	Economy	14000.00
0005432527498	7771	Economy	14000.00
0005432069600	7771	Economy	14000.00
0005434067263	7771	Economy	14000.00
0005432527473	7771	Economy	14000.00
0005435212603	7771	Economy	14000.00
0005432428914	7771	Economy	14000.00
0005432527472	7771	Economy	14000.00
0005435212671	7771	Economy	14000.00
0005432150159	7771	Economy	14000.00
0005432527403	7771	Economy	14000.00
0005434067310	7771	Economy	14000.00
0005434067252	7771	Economy	14000.00
0005432527397	7771	Economy	14000.00
0005432069596	7771	Economy	14000.00
0005432527444	7771	Economy	14000.00
0005435630933	7771	Economy	14000.00
0005434067240	7771	Economy	14000.00
0005432527466	7771	Economy	14000.00
0005435212624	7771	Economy	14000.00
0005432527496	7771	Economy	14000.00
0005432527386	7771	Economy	14000.00
0005432527485	7771	Economy	14000.00
0005432527510	7771	Economy	14000.00
0005434067271	7771	Economy	14000.00
0005435212579	7771	Economy	14000.00
0005432527413	7771	Economy	14000.00
0005432527435	7771	Economy	14000.00
0005434067267	7771	Economy	14000.00
0005432069602	7771	Economy	14000.00
0005435212525	7771	Economy	14000.00
0005435212703	7771	Economy	14000.00
0005432527482	7771	Economy	14000.00
0005432527422	7771	Economy	14000.00
0005432527392	7771	Economy	14000.00
0005434067256	7771	Economy	14000.00
0005432069597	7771	Economy	14000.00
0005434067286	7771	Economy	14000.00
0005432527502	7771	Economy	14000.00
0005434067250	7771	Economy	14000.00
0005432527467	7771	Economy	14000.00
0005435212522	7771	Economy	14000.00
0005432527503	7771	Economy	14000.00
0005435212794	7771	Economy	14000.00
0005432527404	7771	Economy	14000.00
0005432069601	7771	Economy	14000.00
0005434067283	7771	Economy	14000.00
0005432069591	7771	Economy	14000.00
0005432527512	7771	Economy	14000.00
0005434067242	7771	Economy	14000.00
0005434067308	7771	Economy	14000.00
0005432527487	7771	Economy	14000.00
0005432527480	7771	Economy	14000.00
0005435212904	7771	Economy	14000.00
0005435212582	7771	Economy	14000.00
0005432527462	7771	Economy	14000.00
0005434067268	7771	Economy	14000.00
0005432527449	7771	Economy	14000.00
0005432527417	7771	Economy	14000.00
0005432150160	7771	Economy	14000.00
0005435212621	7771	Economy	14000.00
0005432527471	7771	Economy	14000.00
0005432527391	7771	Economy	14000.00
0005432527443	7771	Economy	14000.00
0005432527492	7771	Economy	14000.00
0005432527456	7771	Economy	14000.00
0005432527474	7771	Economy	14000.00
0005432527484	7771	Economy	14000.00
0005435212856	7771	Economy	14000.00
0005432150161	7771	Economy	14000.00
0005432527476	7771	Economy	14000.00
0005432535815	7771	Economy	14000.00
0005435212595	7771	Economy	14000.00
0005435212536	7771	Economy	14000.00
0005434067262	7771	Economy	14000.00
0005434067307	7771	Economy	14000.00
0005435725540	7771	Economy	15400.00
0005432527410	7771	Economy	14000.00
0005435212724	7771	Economy	15400.00
0005432527398	7771	Economy	15400.00
0005432527436	7771	Economy	15400.00
0005434067288	7771	Economy	14000.00
0005432527464	7771	Economy	14000.00
0005432527483	7771	Economy	14000.00
0005434067287	7771	Economy	14000.00
0005434067273	7771	Economy	14000.00
0005432527438	7771	Economy	14000.00
0005434067264	7771	Economy	14000.00
0005434067266	7771	Economy	14000.00
0005435725547	7771	Economy	14000.00
0005434067296	7771	Economy	14000.00
0005434067279	7771	Economy	14000.00
0005432527405	7771	Economy	14000.00
0005432527459	7771	Economy	14000.00
0005432069593	7771	Economy	14000.00
0005432537048	7771	Economy	14000.00
0005434067300	7771	Economy	14000.00
0005432527383	7771	Economy	14000.00
0005435212594	7771	Economy	14000.00
0005435212689	7771	Economy	14000.00
0005434067309	7771	Economy	14000.00
0005432527499	7771	Economy	14000.00
0005432527425	7771	Economy	14000.00
0005432527504	7771	Economy	14000.00
0005432533281	7771	Economy	14000.00
0005432527458	7771	Economy	14000.00
0005432535816	7771	Economy	14000.00
0005432527461	7771	Economy	14000.00
0005432533280	7771	Economy	14000.00
0005432527468	7771	Economy	14000.00
0005432527501	7771	Economy	14000.00
0005435212780	7771	Economy	14000.00
0005432527380	7771	Economy	14000.00
0005432527452	7771	Economy	14000.00
0005434067278	7771	Economy	14000.00
0005434067294	7771	Economy	14000.00
0005435212488	7771	Economy	14000.00
0005435212655	7771	Economy	14000.00
0005434067306	7771	Economy	14000.00
0005434067247	7771	Economy	14000.00
0005434067255	7771	Economy	14000.00
0005432527385	7771	Economy	14000.00
0005432069594	7771	Economy	14000.00
0005432527446	7771	Economy	14000.00
0005432527395	7771	Economy	14000.00
0005435212852	7771	Economy	14000.00
0005435212799	7771	Economy	14000.00
0005434067260	7771	Economy	14000.00
0005432527389	7771	Economy	14000.00
0005435212725	7771	Economy	14000.00
0005434067270	7771	Economy	14000.00
0005432527439	7771	Economy	14000.00
0005435212864	7771	Economy	14000.00
0005432527378	7771	Economy	14000.00
0005435213001	7771	Economy	14000.00
0005432527505	7771	Economy	14000.00
0005434067245	7771	Economy	14000.00
0005432527415	7771	Economy	14000.00
0005435212645	7771	Economy	14000.00
0005432527493	7771	Economy	14000.00
0005434067304	7771	Economy	14000.00
0005432527475	7771	Economy	14000.00
0005435212605	7771	Economy	14000.00
0005432527390	7771	Economy	14000.00
0005435212905	7771	Economy	14000.00
0005432527430	7771	Economy	14000.00
0005435212938	7771	Economy	14000.00
0005432527488	7771	Economy	14000.00
0005432150164	7771	Economy	14000.00
0005435212723	7771	Economy	14000.00
0005435212439	7771	Economy	14000.00
0005434067291	7771	Economy	14000.00
0005432527440	7771	Economy	14000.00
0005432527469	7771	Economy	14000.00
0005432527433	7771	Economy	14000.00
0005432069588	7771	Economy	14000.00
0005432527454	7771	Economy	14000.00
0005432527418	7771	Economy	14000.00
0005434067285	7771	Economy	14000.00
0005432527421	7771	Economy	14000.00
0005432527411	7771	Economy	14000.00
0005432527393	7771	Economy	14000.00
0005432527402	7771	Economy	14000.00
0005434067280	7771	Economy	14000.00
0005435212581	7771	Economy	14000.00
0005432527432	7771	Economy	14000.00
0005432428913	7771	Economy	14000.00
0005432527423	7771	Economy	14000.00
0005435423733	5312	Business	43100.00
0005432047535	5312	Business	43100.00
0005434244581	5312	Business	43100.00
0005435613186	5312	Business	43100.00
0005432133154	5312	Business	43100.00
0005434344080	5312	Business	43100.00
0005434573299	5312	Business	43100.00
0005435423727	5312	Business	43100.00
0005435613206	5312	Business	43100.00
0005435613144	5312	Business	43100.00
0005434244557	5312	Business	43100.00
0005435424174	5312	Business	43100.00
0005434573289	5312	Business	43100.00
0005435319452	5312	Business	43100.00
0005434573297	5312	Business	43100.00
0005435097166	5312	Business	43100.00
0005435613164	5312	Business	43100.00
0005435424138	5312	Business	43100.00
0005435424034	5312	Business	43100.00
0005434344064	5312	Business	43100.00
0005432133145	5312	Business	43100.00
0005435555361	5312	Business	43100.00
0005435613207	5312	Business	43100.00
0005435424088	5312	Business	43100.00
0005434244633	5312	Comfort	24400.00
0005435613230	5312	Comfort	24400.00
0005432047534	5312	Comfort	24400.00
0005435613234	5312	Comfort	24400.00
0005435613240	5312	Comfort	24400.00
0005435613151	5312	Comfort	24400.00
0005435613134	5312	Comfort	24400.00
0005435424032	5312	Comfort	24400.00
0005435491432	5312	Comfort	24400.00
0005435319473	5312	Comfort	24400.00
0005435097167	5312	Comfort	24400.00
0005435613253	5312	Comfort	24400.00
0005435491431	5312	Comfort	24400.00
0005435613251	5312	Comfort	24400.00
0005435424112	5312	Comfort	24400.00
0005435613159	5312	Comfort	24400.00
0005435423964	5312	Comfort	24400.00
0005435613243	5312	Comfort	24400.00
0005434244563	5312	Comfort	24400.00
0005435613208	5312	Comfort	24400.00
0005435613211	5312	Comfort	24400.00
0005435613196	5312	Comfort	24400.00
0005435423852	5312	Comfort	24400.00
0005434344088	5312	Comfort	24400.00
0005434344096	5312	Comfort	24400.00
0005435319451	5312	Comfort	24400.00
0005435424035	5312	Comfort	24400.00
0005434244709	5312	Comfort	24400.00
0005435423934	5312	Comfort	24400.00
0005434244561	5312	Comfort	24400.00
0005434244710	5312	Comfort	24400.00
0005435613249	5312	Comfort	24400.00
0005435613155	5312	Comfort	24400.00
0005434573292	5312	Comfort	24400.00
0005435613135	5312	Comfort	24400.00
0005435613231	5312	Comfort	24400.00
0005435424149	5312	Economy	14400.00
0005434244573	5312	Economy	14400.00
0005435613172	5312	Economy	14400.00
0005435613255	5312	Economy	14400.00
0005434573302	5312	Economy	14400.00
0005434244612	5312	Economy	14400.00
0005435613241	5312	Economy	14400.00
0005434244613	5312	Economy	14400.00
0005435613153	5312	Economy	14400.00
0005434573293	5312	Economy	14400.00
0005435613170	5312	Economy	14400.00
0005434344087	5312	Economy	14400.00
0005434344075	5312	Economy	14400.00
0005435613226	5312	Economy	14400.00
0005435613182	5312	Economy	14400.00
0005435613133	5312	Economy	14400.00
0005435423747	5312	Economy	14400.00
0005434656531	5312	Economy	14400.00
0005435613175	5312	Economy	14400.00
0005435423878	5312	Economy	14400.00
0005435613245	5312	Economy	14400.00
0005435423717	5312	Economy	14400.00
0005435424145	5312	Economy	14400.00
0005434573296	5312	Economy	14400.00
0005435613257	5312	Economy	14400.00
0005435613239	5312	Economy	14400.00
0005435380244	5312	Economy	14400.00
0005435613143	5312	Economy	14400.00
0005435613237	5312	Economy	14400.00
0005435613137	5312	Economy	14400.00
0005434344092	5312	Economy	14400.00
0005435613247	5312	Economy	14400.00
0005435613188	5312	Economy	14400.00
0005435613221	5312	Economy	14400.00
0005435613156	5312	Economy	14400.00
0005432133156	5312	Economy	14400.00
0005434244649	5312	Economy	14400.00
0005432133152	5312	Economy	14400.00
0005434244560	5312	Economy	14400.00
0005435613254	5312	Economy	14400.00
0005435613213	5312	Economy	14400.00
0005435613181	5312	Economy	14400.00
0005435423970	5312	Economy	14400.00
0005435319491	5312	Economy	14400.00
0005434344078	5312	Economy	14400.00
0005435097171	5312	Economy	14400.00
0005435613217	5312	Economy	14400.00
0005435423865	5312	Economy	14400.00
0005435424068	5312	Economy	14400.00
0005435613171	5312	Economy	14400.00
0005435613236	5312	Economy	14400.00
0005435613246	5312	Economy	14400.00
0005435319472	5312	Economy	14400.00
0005435613138	5312	Economy	14400.00
0005435302135	5312	Economy	14400.00
0005435613205	5312	Economy	14400.00
0005435613190	5312	Economy	14400.00
0005435380240	5312	Economy	14400.00
0005435423815	5312	Economy	14400.00
0005435613129	5312	Economy	14400.00
0005435490215	5312	Economy	15800.00
0005434244541	5312	Economy	14400.00
0005435613140	5312	Economy	15800.00
0005435613223	5312	Economy	15800.00
0005433719097	5312	Economy	14400.00
0005435423998	5312	Economy	14400.00
0005435424121	5312	Economy	14400.00
0005435613152	5312	Economy	15800.00
0005434344068	5312	Economy	14400.00
0005435423781	5312	Economy	15800.00
0005435319492	5312	Economy	14400.00
0005435613183	5312	Economy	14400.00
0005434344079	5312	Economy	14400.00
0005435613139	5312	Economy	14400.00
0005434344089	5312	Economy	14400.00
0005435613214	5312	Economy	14400.00
0005434244645	5312	Economy	14400.00
0005435613147	5312	Economy	14400.00
0005435042823	5312	Economy	14400.00
0005434244634	5312	Economy	14400.00
0005434344065	5312	Economy	14400.00
0005432047533	5312	Economy	14400.00
0005434573300	5312	Economy	14400.00
0005435613176	5312	Economy	14400.00
0005434244540	5312	Economy	14400.00
0005435613161	5312	Economy	14400.00
0005434344073	5312	Economy	14400.00
0005434573290	5312	Economy	14400.00
0005434244608	5312	Economy	14400.00
0005434573295	5312	Economy	14400.00
0005435613192	5312	Economy	14400.00
0005435613210	5312	Economy	14400.00
0005435613203	5312	Economy	14400.00
0005435613142	5312	Economy	14400.00
0005435613229	5312	Economy	14400.00
0005432133147	5312	Economy	14400.00
0005435613235	5312	Economy	14400.00
0005435613149	5312	Economy	14400.00
0005435613227	5312	Economy	14400.00
0005435380251	5312	Economy	14400.00
0005433719085	5312	Economy	14400.00
0005435613252	5312	Economy	14400.00
0005432133150	5312	Economy	14400.00
0005434344085	5312	Economy	14400.00
0005435613163	5312	Economy	14400.00
0005435424111	5312	Economy	14400.00
0005435423999	5312	Economy	14400.00
0005435613160	5312	Economy	14400.00
0005435613197	5312	Economy	14400.00
0005435319493	5312	Economy	14400.00
0005434344098	5312	Economy	14400.00
0005435424173	5312	Economy	14400.00
0005435613244	5312	Economy	14400.00
0005434344072	5312	Economy	14400.00
0005434244640	5312	Economy	14400.00
0005435423863	5312	Economy	14400.00
0005434244711	5312	Economy	14400.00
0005435423746	5312	Economy	14400.00
0005435424013	5312	Economy	14400.00
0005432133153	5312	Economy	14400.00
0005434344083	5312	Economy	14400.00
0005435613225	5312	Economy	14400.00
0005435613127	5312	Economy	14400.00
0005434344070	5312	Economy	14400.00
0005434244639	5312	Economy	14400.00
0005435424184	5312	Economy	14400.00
0005434244609	5312	Economy	14400.00
0005432133144	5312	Economy	14400.00
0005434344097	5312	Economy	14400.00
0005434344084	5312	Economy	14400.00
0005435424205	5312	Economy	14400.00
0005435613219	5312	Economy	14400.00
0005434244578	5312	Economy	14400.00
0005435490214	5312	Economy	14400.00
0005435424114	5312	Economy	14400.00
0005434344074	5312	Economy	14400.00
0005435613215	5312	Economy	14400.00
0005435423930	5312	Economy	14400.00
0005435490213	5312	Economy	14400.00
0005435424094	5312	Economy	14400.00
0005435097170	5312	Economy	14400.00
0005435380242	5312	Economy	14400.00
0005435613228	5312	Economy	14400.00
0005435423627	5312	Economy	14400.00
0005435613157	5312	Economy	14400.00
0005434244584	5312	Economy	14400.00
0005435423974	5312	Economy	14400.00
0005434244670	5312	Economy	14400.00
0005434344071	5312	Economy	14400.00
0005435380241	5312	Economy	14400.00
0005435555359	5312	Economy	14400.00
0005435613248	5312	Economy	14400.00
0005435423933	5312	Economy	14400.00
0005434344082	5312	Economy	14400.00
0005435613179	5312	Economy	14400.00
0005435613220	5312	Economy	14400.00
0005435424146	5312	Economy	14400.00
0005435613250	5312	Economy	14400.00
0005435613209	5312	Economy	14400.00
0005435423854	5312	Economy	14400.00
0005435423626	5312	Economy	14400.00
0005435319426	5312	Economy	14400.00
0005432133151	5312	Economy	14400.00
0005435613199	5312	Economy	14400.00
0005434344086	5312	Economy	14400.00
0005434656524	5312	Economy	14400.00
0005432133142	5312	Economy	14400.00
0005432133143	5312	Economy	14400.00
0005435424168	5312	Economy	14400.00
0005435613162	5312	Economy	14400.00
0005435613195	5312	Economy	14400.00
0005435613146	5312	Economy	14400.00
0005434344077	5312	Economy	14400.00
0005434656530	5312	Economy	14400.00
0005435613178	5312	Economy	15800.00
0005435613169	5312	Economy	14400.00
0005435423822	5312	Economy	15800.00
0005434573294	5312	Economy	15800.00
0005432133148	5312	Economy	15800.00
0005435613224	5312	Economy	14400.00
0005432840983	5312	Economy	15800.00
0005435423780	5312	Economy	14400.00
0005435613150	5312	Economy	14400.00
0005434344063	5312	Economy	14400.00
0005435613166	5312	Economy	14400.00
0005435613202	5312	Economy	14400.00
0005435424137	5312	Economy	14400.00
0005434573298	5312	Economy	14400.00
0005435424122	5312	Economy	14400.00
0005435613126	5312	Economy	14400.00
0005435613145	5312	Economy	14400.00
0005435423853	5312	Economy	14400.00
0005434244648	5312	Economy	14400.00
0005435613130	5312	Economy	14400.00
0005434244692	5312	Economy	14400.00
0005435613222	5312	Economy	14400.00
0005435613132	5312	Economy	14400.00
0005434344061	5312	Economy	14400.00
0005434344067	5312	Economy	14400.00
0005435613200	5312	Economy	14400.00
0005435424206	5312	Economy	14400.00
0005435613216	5312	Economy	14400.00
0005435613168	5312	Economy	14400.00
0005434573301	5312	Economy	14400.00
0005435613204	5312	Economy	14400.00
0005434344093	5312	Economy	14400.00
0005435613191	5312	Economy	14400.00
0005435613158	5312	Economy	14400.00
0005435613256	5312	Economy	14400.00
0005435613233	5312	Economy	14400.00
0005435490211	5312	Economy	14400.00
0005435613212	5312	Economy	14400.00
0005434244580	5312	Economy	14400.00
0005434656527	5312	Economy	14400.00
0005432047536	5312	Economy	14400.00
0005434344062	5312	Economy	14400.00
0005435613201	5312	Economy	14400.00
0005434244518	5312	Economy	14400.00
0005435097169	5312	Economy	14400.00
0005435424089	5312	Economy	14400.00
0005432840984	5312	Economy	14400.00
0005435613154	5312	Economy	14400.00
0005434244606	5312	Economy	14400.00
0005434344066	5312	Economy	14400.00
0005435613238	5312	Economy	14400.00
0005435613185	5312	Economy	14400.00
0005434244517	5312	Economy	14400.00
0005435613141	5312	Economy	14400.00
0005435423861	5312	Economy	14400.00
0005434573303	5312	Economy	14400.00
0005435302134	5312	Economy	14400.00
0005435613173	5312	Economy	14400.00
0005435097168	5312	Economy	14400.00
0005435613174	5312	Economy	14400.00
0005432133149	5312	Economy	14400.00
0005435613184	5312	Economy	14400.00
0005435613167	5312	Economy	14400.00
0005435424115	5312	Economy	14400.00
0005434344091	5312	Economy	14400.00
0005434344076	5312	Economy	14400.00
0005435613128	5312	Economy	14400.00
0005435613136	5312	Economy	14400.00
0005432133146	5312	Economy	14400.00
0005434244524	5312	Economy	14400.00
0005435302133	5312	Economy	14400.00
0005435423971	5312	Economy	14400.00
0005435613148	5312	Economy	14400.00
0005434344095	5312	Economy	14400.00
0005434344081	5312	Economy	14400.00
0005434573291	5312	Economy	14400.00
0005435423855	5312	Economy	14400.00
0005434244672	5312	Economy	14400.00
0005435423897	5312	Economy	14400.00
0005435555360	5312	Economy	14400.00
0005434244671	5312	Economy	14400.00
0005435423986	5312	Economy	14400.00
0005435613198	5312	Economy	14400.00
0005435613242	5312	Economy	14400.00
0005435613194	5312	Economy	14400.00
0005435613232	5312	Economy	14400.00
0005435380243	5312	Economy	14400.00
0005435613193	5312	Economy	14400.00
0005432133155	5312	Economy	14400.00
0005435304995	5312	Economy	14400.00
0005435613187	5312	Economy	14400.00
0005435613165	5312	Economy	14400.00
0005434244720	5312	Economy	14400.00
0005435613189	5312	Economy	14400.00
0005435423899	5312	Economy	14400.00
0005435613180	5312	Economy	14400.00
0005434344090	5312	Economy	14400.00
0005435613131	5312	Economy	14400.00
0005434344069	5312	Economy	14400.00
0005435423885	5312	Economy	14400.00
0005435613177	5312	Economy	14400.00
0005435423814	5312	Economy	14400.00
0005435424070	5312	Economy	14400.00
0005434244558	5312	Economy	14400.00
0005435424119	5312	Economy	14400.00
0005435423960	5312	Economy	14400.00
0005435490212	5312	Economy	14400.00
0005435613218	5312	Economy	14400.00
0005434344094	5312	Economy	14400.00
0005435612117	10875	Business	43100.00
0005435611806	10875	Business	43100.00
0005435319539	10875	Business	43100.00
0005435612090	10875	Business	43100.00
0005434343620	10875	Business	43100.00
0005432165011	10875	Business	43100.00
0005434244858	10875	Business	43100.00
0005435612236	10875	Business	43100.00
0005435424501	10875	Business	43100.00
0005435424553	10875	Business	43100.00
0005432363402	10875	Business	43100.00
0005434656547	10875	Business	43100.00
0005432165004	10875	Business	43100.00
0005435424540	10875	Business	43100.00
0005435380271	10875	Business	43100.00
0005435612249	10875	Business	43100.00
0005435097082	10875	Business	43100.00
0005435424506	10875	Business	43100.00
0005434244862	10875	Business	43100.00
0005435612597	10875	Business	43100.00
0005435304137	10875	Business	43100.00
0005435424526	10875	Business	43100.00
0005435424529	10875	Business	43100.00
0005434343675	10875	Business	43100.00
0005435424503	10875	Comfort	24400.00
0005435424493	10875	Comfort	24400.00
0005434573106	10875	Comfort	24400.00
0005432165005	10875	Comfort	24400.00
0005435611905	10875	Comfort	24400.00
0005433719127	10875	Comfort	24400.00
0005435319532	10875	Comfort	24400.00
0005435424532	10875	Comfort	24400.00
0005435424510	10875	Comfort	24400.00
0005435612088	10875	Comfort	24400.00
0005435424509	10875	Comfort	24400.00
0005435097081	10875	Comfort	24400.00
0005435319540	10875	Comfort	24400.00
0005434343637	10875	Comfort	24400.00
0005435097087	10875	Comfort	24400.00
0005435612354	10875	Comfort	24400.00
0005433719128	10875	Comfort	24400.00
0005435612466	10875	Comfort	24400.00
0005435612168	10875	Comfort	24400.00
0005435612169	10875	Comfort	24400.00
0005435424504	10875	Comfort	24400.00
0005434244866	10875	Comfort	24400.00
0005434244873	10875	Comfort	24400.00
0005435611827	10875	Comfort	24400.00
0005434343757	10875	Comfort	24400.00
0005434343627	10875	Comfort	24400.00
0005434343695	10875	Comfort	24400.00
0005435424547	10875	Comfort	24400.00
0005435612091	10875	Comfort	24400.00
0005435424497	10875	Comfort	24400.00
0005435612055	10875	Comfort	24400.00
0005435612195	10875	Comfort	24400.00
0005435612408	10875	Comfort	24400.00
0005435612598	10875	Comfort	24400.00
0005435097057	10875	Comfort	24400.00
0005435424516	10875	Comfort	24400.00
0005434343708	10875	Comfort	24400.00
0005434343644	10875	Comfort	24400.00
0005435612174	10875	Comfort	24400.00
0005435612003	10875	Comfort	24400.00
0005435424528	10875	Economy	14400.00
0005432165010	10875	Economy	14400.00
0005435097051	10875	Economy	14400.00
0005435097048	10875	Economy	14400.00
0005435612198	10875	Economy	14400.00
0005434343917	10875	Economy	14400.00
0005435611976	10875	Economy	14400.00
0005434244874	10875	Economy	14400.00
0005432166889	10875	Economy	14400.00
0005435612119	10875	Economy	14400.00
0005435612166	10875	Economy	14400.00
0005435424544	10875	Economy	14400.00
0005435380270	10875	Economy	14400.00
0005435097068	10875	Economy	14400.00
0005435424533	10875	Economy	14400.00
0005435612230	10875	Economy	14400.00
0005435612109	10875	Economy	14400.00
0005435612116	10875	Economy	14400.00
0005435424494	10875	Economy	14400.00
0005435424530	10875	Economy	14400.00
0005434244863	10875	Economy	14400.00
0005435611935	10875	Economy	14400.00
0005434244872	10875	Economy	14400.00
0005434343889	10875	Economy	14400.00
0005432363401	10875	Economy	14400.00
0005435611828	10875	Economy	14400.00
0005434343613	10875	Economy	14400.00
0005435612465	10875	Economy	14400.00
0005434343685	10875	Economy	14400.00
0005435424546	10875	Economy	14400.00
0005435424537	10875	Economy	14400.00
0005435611854	10875	Economy	14400.00
0005435612295	10875	Economy	14400.00
0005434244852	10875	Economy	14400.00
0005435611921	10875	Economy	14400.00
0005435424560	10875	Economy	14400.00
0005435424518	10875	Economy	14400.00
0005434244869	10875	Economy	14400.00
0005435612025	10875	Economy	14400.00
0005434343595	10875	Economy	14400.00
0005435424551	10875	Economy	14400.00
0005435490190	10875	Economy	14400.00
0005435097056	10875	Economy	14400.00
0005435612303	10875	Economy	14400.00
0005434343626	10875	Economy	14400.00
0005435380274	10875	Economy	14400.00
0005432166887	10875	Economy	14400.00
0005435424556	10875	Economy	14400.00
0005434244857	10875	Economy	14400.00
0005435424555	10875	Economy	14400.00
0005435424527	10875	Economy	14400.00
0005435612472	10875	Economy	14400.00
0005435612362	10875	Economy	14400.00
0005435612489	10875	Economy	15800.00
0005435612231	10875	Economy	15800.00
0005435424500	10875	Economy	14400.00
0005435612194	10875	Economy	15800.00
0005435424507	10875	Economy	14400.00
0005435097080	10875	Economy	14400.00
0005435611711	10875	Economy	15800.00
0005435612357	10875	Economy	14400.00
0005435097065	10875	Economy	15800.00
0005434343831	10875	Economy	15800.00
0005435424535	10875	Economy	14400.00
0005435612118	10875	Economy	14400.00
0005435612306	10875	Economy	14400.00
0005435424512	10875	Economy	14400.00
0005435612211	10875	Economy	14400.00
0005435097049	10875	Economy	14400.00
0005434343612	10875	Economy	14400.00
0005435424534	10875	Economy	14400.00
0005435612344	10875	Economy	14400.00
0005434343636	10875	Economy	14400.00
0005435612240	10875	Economy	14400.00
0005435424496	10875	Economy	14400.00
0005435612441	10875	Economy	14400.00
0005434244861	10875	Economy	14400.00
0005435612069	10875	Economy	14400.00
0005435612200	10875	Economy	14400.00
0005435424557	10875	Economy	14400.00
0005435097085	10875	Economy	14400.00
0005434573147	10875	Economy	14400.00
0005435612360	10875	Economy	14400.00
0005435611992	10875	Economy	14400.00
0005435612588	10875	Economy	14400.00
0005435612196	10875	Economy	14400.00
0005435611991	10875	Economy	14400.00
0005435424552	10875	Economy	14400.00
0005434244854	10875	Economy	14400.00
0005435612467	10875	Economy	14400.00
0005435612503	10875	Economy	14400.00
0005434244853	10875	Economy	14400.00
0005435612212	10875	Economy	14400.00
0005435097066	10875	Economy	14400.00
0005434244848	10875	Economy	14400.00
0005435612068	10875	Economy	14400.00
0005435612146	10875	Economy	14400.00
0005435319536	10875	Economy	14400.00
0005435424495	10875	Economy	14400.00
0005434343690	10875	Economy	14400.00
0005435097061	10875	Economy	14400.00
0005434244860	10875	Economy	14400.00
0005435424519	10875	Economy	14400.00
0005435612523	10875	Economy	14400.00
0005435424515	10875	Economy	14400.00
0005434244847	10875	Economy	14400.00
0005434244871	10875	Economy	14400.00
0005435612081	10875	Economy	14400.00
0005435319533	10875	Economy	14400.00
0005435424543	10875	Economy	14400.00
0005435612594	10875	Economy	14400.00
0005435612217	10875	Economy	14400.00
0005435612185	10875	Economy	14400.00
0005435424549	10875	Economy	14400.00
0005435612084	10875	Economy	14400.00
0005434244851	10875	Economy	14400.00
0005434573115	10875	Economy	14400.00
0005434244859	10875	Economy	14400.00
0005435612057	10875	Economy	14400.00
0005434656548	10875	Economy	14400.00
0005435612070	10875	Economy	14400.00
0005435612029	10875	Economy	14400.00
0005435612033	10875	Economy	14400.00
0005435097079	10875	Economy	14400.00
0005435612287	10875	Economy	14400.00
0005435424513	10875	Economy	14400.00
0005434343639	10875	Economy	14400.00
0005435612353	10875	Economy	14400.00
0005435612407	10875	Economy	14400.00
0005434244870	10875	Economy	14400.00
0005434343715	10875	Economy	14400.00
0005435612325	10875	Economy	14400.00
0005435612399	10875	Economy	14400.00
0005435612087	10875	Economy	14400.00
0005432841004	10875	Economy	14400.00
0005434343741	10875	Economy	14400.00
0005435611792	10875	Economy	14400.00
0005434343720	10875	Economy	14400.00
0005435424559	10875	Economy	14400.00
0005432841005	10875	Economy	14400.00
0005434244864	10875	Economy	14400.00
0005432363403	10875	Economy	14400.00
0005435611904	10875	Economy	14400.00
0005432165003	10875	Economy	14400.00
0005432165006	10875	Economy	14400.00
0005435424524	10875	Economy	14400.00
0005435612241	10875	Economy	14400.00
0005435612359	10875	Economy	14400.00
0005434244867	10875	Economy	14400.00
0005434343772	10875	Economy	14400.00
0005435424541	10875	Economy	14400.00
0005434343643	10875	Economy	14400.00
0005434343701	10875	Economy	14400.00
0005435097097	10875	Economy	14400.00
0005435424538	10875	Economy	14400.00
0005435424561	10875	Economy	14400.00
0005435612145	10875	Economy	14400.00
0005435424558	10875	Economy	14400.00
0005435424505	10875	Economy	14400.00
0005435612002	10875	Economy	14400.00
0005435424545	10875	Economy	15800.00
0005435611920	10875	Economy	15800.00
0005435612450	10875	Economy	15800.00
0005435611895	10875	Economy	15800.00
0005434343716	10875	Economy	15800.00
0005434343634	10875	Economy	14400.00
0005435612343	10875	Economy	15800.00
0005435612401	10875	Economy	14400.00
0005435424531	10875	Economy	14400.00
0005434343586	10875	Economy	14400.00
0005434244868	10875	Economy	14400.00
0005434343721	10875	Economy	14400.00
0005434343633	10875	Economy	14400.00
0005435424499	10875	Economy	14400.00
0005432165008	10875	Economy	14400.00
0005435319537	10875	Economy	14400.00
0005435424536	10875	Economy	14400.00
0005435612130	10875	Economy	14400.00
0005435097060	10875	Economy	14400.00
0005435424554	10875	Economy	14400.00
0005434573148	10875	Economy	14400.00
0005435611826	10875	Economy	14400.00
0005435612140	10875	Economy	14400.00
0005432166888	10875	Economy	14400.00
0005435424522	10875	Economy	14400.00
0005435424517	10875	Economy	14400.00
0005432166886	10875	Economy	14400.00
0005435424498	10875	Economy	14400.00
0005435380272	10875	Economy	14400.00
0005434343655	10875	Economy	14400.00
0005435424539	10875	Economy	14400.00
0005435612172	10875	Economy	14400.00
0005435424550	10875	Economy	14400.00
0005435611943	10875	Economy	14400.00
0005435612034	10875	Economy	14400.00
0005434343585	10875	Economy	14400.00
0005435611903	10875	Economy	14400.00
0005434244855	10875	Economy	14400.00
0005435097086	10875	Economy	14400.00
0005435304138	10875	Economy	14400.00
0005434244846	10875	Economy	14400.00
0005435380273	10875	Economy	14400.00
0005434343596	10875	Economy	14400.00
0005434343617	10875	Economy	14400.00
0005435612368	10875	Economy	14400.00
0005434343656	10875	Economy	14400.00
0005435424511	10875	Economy	14400.00
0005434343773	10875	Economy	14400.00
0005434244856	10875	Economy	14400.00
0005435097058	10875	Economy	14400.00
0005434244849	10875	Economy	14400.00
0005432165009	10875	Economy	14400.00
0005434573105	10875	Economy	14400.00
0005435612115	10875	Economy	14400.00
0005435097059	10875	Economy	14400.00
0005434343625	10875	Economy	14400.00
0005435612173	10875	Economy	14400.00
0005435319535	10875	Economy	14400.00
0005435319538	10875	Economy	14400.00
0005435424508	10875	Economy	14400.00
0005434343614	10875	Economy	14400.00
0005435612367	10875	Economy	14400.00
0005435612110	10875	Economy	14400.00
0005435424520	10875	Economy	14400.00
0005434343761	10875	Economy	14400.00
0005434244865	10875	Economy	14400.00
0005435491405	10875	Economy	14400.00
0005435319534	10875	Economy	14400.00
0005434244850	10875	Economy	14400.00
0005434343674	10875	Economy	14400.00
0005432363404	10875	Economy	14400.00
0005435424523	10875	Economy	14400.00
0005435424525	10875	Economy	14400.00
0005435424502	10875	Economy	14400.00
0005435611942	10875	Economy	14400.00
0005435612335	10875	Economy	14400.00
0005435424514	10875	Economy	14400.00
0005434343888	10875	Economy	14400.00
0005435424542	10875	Economy	14400.00
0005435424548	10875	Economy	14400.00
0005435555355	10875	Economy	14400.00
0005434573139	10875	Economy	14400.00
0005435424521	10875	Economy	14400.00
0005435555354	10875	Economy	14400.00
0005434343760	10875	Economy	14400.00
0005434343638	10875	Economy	14400.00
0005434343635	10875	Economy	14400.00
0005432165007	10875	Economy	14400.00
0005435097072	10875	Economy	14400.00
0005433805217	3367	Business	18800.00
0005433805232	3367	Business	18800.00
0005433805228	3367	Business	18800.00
0005432459183	3367	Business	18800.00
0005432181625	3367	Business	18800.00
0005433805231	3367	Business	18800.00
0005432459092	3367	Business	18800.00
0005433633687	3367	Business	18800.00
0005433507114	3367	Business	18800.00
0005433633689	3367	Business	18800.00
0005432459065	3367	Business	18800.00
0005432459241	3367	Business	18800.00
0005433805229	3367	Business	18800.00
0005432459189	3367	Business	18800.00
0005433633673	3367	Business	18800.00
0005432459315	3367	Business	18800.00
0005432459265	3367	Business	18800.00
0005432181623	3367	Business	18800.00
0005433507108	3367	Business	18800.00
0005433633698	3367	Business	18800.00
0005432459320	3367	Business	18800.00
0005432459144	3367	Business	18800.00
0005432459377	3367	Business	18800.00
0005433633691	3367	Business	18800.00
0005433805223	3367	Business	18800.00
0005433507103	3367	Business	18800.00
0005432181624	3367	Business	18800.00
0005432459293	3367	Business	18800.00
0005432459214	3367	Economy	6900.00
0005432459186	3367	Economy	6900.00
0005433507105	3367	Economy	6900.00
0005433805236	3367	Economy	6900.00
0005432181635	3367	Economy	6900.00
0005432459070	3367	Economy	6300.00
0005433507112	3367	Economy	6300.00
0005432181621	3367	Economy	6300.00
0005432459321	3367	Economy	6300.00
0005433633683	3367	Economy	6300.00
0005433507109	3367	Economy	6300.00
0005433805222	3367	Economy	6300.00
0005433805239	3367	Economy	6300.00
0005433633685	3367	Economy	6300.00
0005433633667	3367	Economy	6300.00
0005433805242	3367	Economy	6300.00
0005432459081	3367	Economy	6300.00
0005432181637	3367	Economy	6300.00
0005432459063	3367	Economy	6300.00
0005432459026	3367	Economy	6300.00
0005432181615	3367	Economy	6300.00
0005432459082	3367	Economy	6300.00
0005433805235	3367	Economy	6300.00
0005433633672	3367	Economy	6300.00
0005432181622	3367	Economy	6300.00
0005433507111	3367	Economy	6300.00
0005432459178	3367	Economy	6300.00
0005433507101	3367	Economy	6300.00
0005432181617	3367	Economy	6300.00
0005433805241	3367	Economy	6300.00
0005432459154	3367	Economy	6300.00
0005433805240	3367	Economy	6300.00
0005432459187	3367	Economy	6300.00
0005433633701	3367	Economy	6300.00
0005433633688	3367	Economy	6300.00
0005433805219	3367	Economy	6300.00
0005432459027	3367	Economy	6300.00
0005433805243	3367	Economy	6300.00
0005433633692	3367	Economy	6300.00
0005433805226	3367	Economy	6300.00
0005433633686	3367	Economy	6300.00
0005433507100	3367	Economy	6300.00
0005432459316	3367	Economy	6300.00
0005433805225	3367	Economy	6300.00
0005433633675	3367	Economy	6300.00
0005432459275	3367	Economy	6300.00
0005433507115	3367	Economy	6300.00
0005433633669	3367	Economy	6300.00
0005433507099	3367	Economy	6300.00
0005433507098	3367	Economy	6300.00
0005432459083	3367	Economy	6300.00
0005432459283	3367	Economy	6300.00
0005433633676	3367	Economy	6300.00
0005432181631	3367	Economy	6300.00
0005432459234	3367	Economy	6300.00
0005432459266	3367	Economy	6300.00
0005433805244	3367	Economy	6300.00
0005432181616	3367	Economy	6300.00
0005432459080	3367	Economy	6300.00
0005433805238	3367	Economy	6300.00
0005432181626	3367	Economy	6300.00
0005433805224	3367	Economy	6300.00
0005432459179	3367	Economy	6900.00
0005432459127	3367	Economy	6900.00
0005433633700	3367	Economy	6900.00
0005433633678	3367	Economy	6900.00
0005433805245	3367	Economy	6900.00
0005433633668	3367	Economy	6300.00
0005432459172	3367	Economy	6300.00
0005433805233	3367	Economy	6300.00
0005432459132	3367	Economy	6900.00
0005433633680	3367	Economy	6300.00
0005433633696	3367	Economy	6300.00
0005433633682	3367	Economy	6300.00
0005433633693	3367	Economy	6300.00
0005433507104	3367	Economy	6300.00
0005432459122	3367	Economy	6300.00
0005432181628	3367	Economy	6300.00
0005433805211	3367	Economy	6300.00
0005433507102	3367	Economy	6300.00
0005433805230	3367	Economy	6300.00
0005433633671	3367	Economy	6300.00
0005433507110	3367	Economy	6300.00
0005433507106	3367	Economy	6300.00
0005432459185	3367	Economy	6300.00
0005432459192	3367	Economy	6300.00
0005433633697	3367	Economy	6300.00
0005433805218	3367	Economy	6300.00
0005432459284	3367	Economy	6300.00
0005432459035	3367	Economy	6300.00
0005433805216	3367	Economy	6300.00
0005432181633	3367	Economy	6300.00
0005433805215	3367	Economy	6300.00
0005432459076	3367	Economy	6300.00
0005432181618	3367	Economy	6300.00
0005432181636	3367	Economy	6300.00
0005432459202	3367	Economy	6300.00
0005432459237	3367	Economy	6300.00
0005432181619	3367	Economy	6300.00
0005433633679	3367	Economy	6300.00
0005433805212	3367	Economy	6300.00
0005432459158	3367	Economy	6300.00
0005432459064	3367	Economy	6300.00
0005433633674	3367	Economy	6300.00
0005432181634	3367	Economy	6300.00
0005433507117	3367	Economy	6300.00
0005432459376	3367	Economy	6300.00
0005433633690	3367	Economy	6300.00
0005433633695	3367	Economy	6300.00
0005433507113	3367	Economy	6300.00
0005432459128	3367	Economy	6300.00
0005432459048	3367	Economy	6300.00
0005432181630	3367	Economy	6300.00
0005432458982	3367	Economy	6300.00
0005432459153	3367	Economy	6300.00
0005433633677	3367	Economy	6300.00
0005433633684	3367	Economy	6300.00
0005432459188	3367	Economy	6300.00
0005433805234	3367	Economy	6300.00
0005433507107	3367	Economy	6300.00
0005432181620	3367	Economy	6300.00
0005433507116	3367	Economy	6300.00
0005432181632	3367	Economy	6300.00
0005433805227	3367	Economy	6300.00
0005433805214	3367	Economy	6300.00
0005432459279	3367	Economy	6300.00
0005432181627	3367	Economy	6300.00
0005433805213	3367	Economy	6300.00
0005433633681	3367	Economy	6300.00
0005433805220	3367	Economy	6300.00
0005433805237	3367	Economy	6300.00
0005433633670	3367	Economy	6300.00
0005433805221	3367	Economy	6300.00
0005432181629	3367	Economy	6300.00
0005433633699	3367	Economy	6300.00
0005433633694	3367	Economy	6300.00
0005435884748	3366	Business	18800.00
0005435884630	3366	Business	18800.00
0005435884665	3366	Business	18800.00
0005435884653	3366	Business	18800.00
0005435884568	3366	Business	18800.00
0005435884429	3366	Business	18800.00
0005435884560	3366	Business	18800.00
0005435884693	3366	Business	18800.00
0005435884691	3366	Economy	6900.00
0005435884637	3366	Economy	6300.00
0005435884635	3366	Economy	6300.00
0005435884694	3366	Economy	6300.00
0005435884829	3366	Economy	6300.00
0005435884754	3366	Economy	6300.00
0005435884634	3366	Economy	6300.00
0005435884567	3366	Economy	6300.00
0005435884682	3366	Economy	6300.00
0005435884652	3366	Economy	6300.00
0005435884884	3366	Economy	6300.00
0005435884589	3366	Economy	6300.00
0005435884820	3366	Economy	6300.00
0005435884744	3366	Economy	6300.00
0005435884687	3366	Economy	6300.00
0005435884706	3366	Economy	6300.00
0005435884703	3366	Economy	6300.00
0005435884727	3366	Economy	6300.00
0005435884544	3366	Economy	6300.00
0005435884607	3366	Economy	6900.00
0005435884795	3366	Economy	6300.00
0005435884667	3366	Economy	6900.00
0005435884502	3366	Economy	6300.00
0005435884531	3366	Economy	6300.00
0005435884482	3366	Economy	6300.00
0005435884728	3366	Economy	6300.00
0005435884732	3366	Economy	6300.00
0005435884613	3366	Economy	6300.00
0005435884619	3366	Economy	6300.00
0005435884543	3366	Economy	6300.00
0005435884745	3366	Economy	6300.00
0005435884848	3366	Economy	6300.00
0005435884666	3366	Economy	6300.00
0005435884716	3366	Economy	6300.00
0005435884859	3366	Economy	6300.00
0005435884612	3366	Economy	6300.00
0005435884550	3366	Economy	6300.00
0005435884849	3366	Economy	6300.00
0005435884765	3366	Economy	6300.00
0005435884590	3366	Economy	6300.00
0005435884492	3366	Economy	6300.00
0005435884674	3366	Economy	6300.00
0005435884561	3366	Economy	6300.00
0005435884860	3366	Economy	6300.00
0005435884593	3366	Economy	6300.00
0005435884600	3366	Economy	6300.00
0005435885025	8239	Business	18800.00
0005435885057	8239	Business	18800.00
0005432459670	8239	Business	18800.00
0005432459699	8239	Business	18800.00
0005432459669	8239	Business	18800.00
0005435885052	8239	Business	18800.00
0005432459653	8239	Business	18800.00
0005435885049	8239	Business	18800.00
0005432459668	8239	Business	18800.00
0005435885067	8239	Business	18800.00
0005435885051	8239	Business	18800.00
0005435885066	8239	Business	18800.00
0005435885042	8239	Business	18800.00
0005432042654	8239	Business	18800.00
0005432459662	8239	Business	18800.00
0005434326269	8239	Business	18800.00
0005432459701	8239	Business	18800.00
0005435885033	8239	Business	18800.00
0005435885024	8239	Business	18800.00
0005435885070	8239	Business	18800.00
0005432459700	8239	Economy	6900.00
0005432042666	8239	Economy	6900.00
0005433506929	8239	Economy	6900.00
0005435885063	8239	Economy	6900.00
0005435885043	8239	Economy	6900.00
0005433506935	8239	Economy	6900.00
0005435885030	8239	Economy	6300.00
0005435885039	8239	Economy	6300.00
0005432459655	8239	Economy	6300.00
0005432459696	8239	Economy	6300.00
0005432459689	8239	Economy	6300.00
0005432459702	8239	Economy	6300.00
0005432459683	8239	Economy	6300.00
0005432042661	8239	Economy	6300.00
0005435885029	8239	Economy	6300.00
0005433506915	8239	Economy	6300.00
0005435885053	8239	Economy	6300.00
0005435885035	8239	Economy	6300.00
0005435885069	8239	Economy	6300.00
0005435885038	8239	Economy	6300.00
0005435885068	8239	Economy	6300.00
0005432459690	8239	Economy	6300.00
0005432459657	8239	Economy	6300.00
0005435885056	8239	Economy	6300.00
0005432042655	8239	Economy	6300.00
0005433506934	8239	Economy	6300.00
0005432459673	8239	Economy	6300.00
0005432459678	8239	Economy	6300.00
0005432459691	8239	Economy	6300.00
0005432459688	8239	Economy	6300.00
0005432459666	8239	Economy	6300.00
0005432459687	8239	Economy	6300.00
0005432459652	8239	Economy	6300.00
0005432042662	8239	Economy	6300.00
0005432459676	8239	Economy	6300.00
0005432459659	8239	Economy	6300.00
0005435885026	8239	Economy	6300.00
0005432459694	8239	Economy	6300.00
0005432042660	8239	Economy	6300.00
0005435885055	8239	Economy	6300.00
0005432459677	8239	Economy	6300.00
0005434312313	8239	Economy	6300.00
0005435885046	8239	Economy	6300.00
0005435885023	8239	Economy	6300.00
0005435885054	8239	Economy	6300.00
0005432459680	8239	Economy	6300.00
0005432459675	8239	Economy	6300.00
0005432459667	8239	Economy	6300.00
0005432459674	8239	Economy	6300.00
0005432459661	8239	Economy	6300.00
0005435885050	8239	Economy	6300.00
0005432459693	8239	Economy	6300.00
0005432459664	8239	Economy	6300.00
0005435885034	8239	Economy	6300.00
0005432459703	8239	Economy	6300.00
0005432459686	8239	Economy	6300.00
0005433506891	8239	Economy	6300.00
0005432459663	8239	Economy	6300.00
0005432459656	8239	Economy	6300.00
0005432459684	8239	Economy	6900.00
0005435885071	8239	Economy	6900.00
0005433506933	8239	Economy	6300.00
0005432459660	8239	Economy	6300.00
0005432042652	8239	Economy	6300.00
0005432459672	8239	Economy	6900.00
0005435885059	8239	Economy	6300.00
0005432042657	8239	Economy	6300.00
0005432042663	8239	Economy	6300.00
0005432459698	8239	Economy	6300.00
0005435885048	8239	Economy	6300.00
0005432459671	8239	Economy	6300.00
0005433506963	8239	Economy	6300.00
0005434312312	8239	Economy	6300.00
0005435885062	8239	Economy	6300.00
0005432459695	8239	Economy	6300.00
0005433506932	8239	Economy	6300.00
0005435885032	8239	Economy	6300.00
0005432459681	8239	Economy	6300.00
0005433506964	8239	Economy	6300.00
0005432042656	8239	Economy	6300.00
0005432042659	8239	Economy	6300.00
0005432459651	8239	Economy	6300.00
0005433506925	8239	Economy	6300.00
0005433506955	8239	Economy	6300.00
0005432459679	8239	Economy	6300.00
0005435885044	8239	Economy	6300.00
0005433506993	8239	Economy	6300.00
0005435885022	8239	Economy	6300.00
0005433507036	8239	Economy	6300.00
0005435885040	8239	Economy	6300.00
0005435885037	8239	Economy	6300.00
0005432459654	8239	Economy	6300.00
0005432042664	8239	Economy	6300.00
0005435885031	8239	Economy	6300.00
0005433506976	8239	Economy	6300.00
0005435885060	8239	Economy	6300.00
0005432459682	8239	Economy	6300.00
0005432042658	8239	Economy	6300.00
0005435885036	8239	Economy	6300.00
0005432459697	8239	Economy	6300.00
0005435885041	8239	Economy	6300.00
0005432459658	8239	Economy	6300.00
0005435885058	8239	Economy	6300.00
0005432459665	8239	Economy	6300.00
0005435885027	8239	Economy	6300.00
0005435885045	8239	Economy	6300.00
0005435885021	8239	Economy	6300.00
0005432042653	8239	Economy	6300.00
0005432042665	8239	Economy	6300.00
0005435885064	8239	Economy	6300.00
0005432459685	8239	Economy	6300.00
0005433506927	8239	Economy	6300.00
0005435885065	8239	Economy	6300.00
0005435885061	8239	Economy	6300.00
0005432459692	8239	Economy	6300.00
0005435885028	8239	Economy	6300.00
0005433506974	8239	Economy	6300.00
0005433506920	8239	Economy	6300.00
0005435885047	8239	Economy	6300.00
0005433805110	8258	Business	18800.00
0005433804832	8258	Business	18800.00
0005435854056	8258	Business	18800.00
0005433804886	8258	Business	18800.00
0005433805109	8258	Business	18800.00
0005433804987	8258	Business	18800.00
0005433633247	8258	Business	18800.00
0005433804964	8258	Business	18800.00
0005433633503	8258	Economy	6900.00
0005433805090	8258	Economy	6900.00
0005433805003	8258	Economy	6300.00
0005433805002	8258	Economy	6300.00
0005433804808	8258	Economy	6300.00
0005433804895	8258	Economy	6300.00
0005433804917	8258	Economy	6300.00
0005433805058	8258	Economy	6300.00
0005433804949	8258	Economy	6300.00
0005433805033	8258	Economy	6300.00
0005433805111	8258	Economy	6300.00
0005433804972	8258	Economy	6300.00
0005433805064	8258	Economy	6300.00
0005433805057	8258	Economy	6300.00
0005435854052	8258	Economy	6300.00
0005433804897	8258	Economy	6300.00
0005435854053	8258	Economy	6300.00
0005433804861	8258	Economy	6300.00
0005433804993	8258	Economy	6300.00
0005433633373	8258	Economy	6300.00
0005433805075	8258	Economy	6300.00
0005434143699	8258	Economy	6300.00
0005433804859	8258	Economy	6300.00
0005433633447	8258	Economy	6300.00
0005433633330	8258	Economy	6300.00
0005433633385	8258	Economy	6300.00
0005433633359	8258	Economy	6300.00
0005433633386	8258	Economy	6300.00
0005433804936	8258	Economy	6300.00
0005433804969	8258	Economy	6300.00
0005433633448	8258	Economy	6900.00
0005433804973	8258	Economy	6300.00
0005433804887	8258	Economy	6300.00
0005433804941	8258	Economy	6300.00
0005433633352	8258	Economy	6300.00
0005433804988	8258	Economy	6300.00
0005433804858	8258	Economy	6300.00
0005433633370	8258	Economy	6300.00
0005433633371	8258	Economy	6300.00
0005433804923	8258	Economy	6300.00
0005435854055	8258	Economy	6300.00
0005433633332	8258	Economy	6300.00
0005433633354	8258	Economy	6300.00
0005434143708	8258	Economy	6300.00
0005433805091	8258	Economy	6300.00
0005433804918	8258	Economy	6300.00
0005433633320	8258	Economy	6300.00
0005435854054	8258	Economy	6300.00
0005433805015	8258	Economy	6300.00
0005433804920	8258	Economy	6300.00
0005433804850	8258	Economy	6300.00
0005434143700	8258	Economy	6300.00
0005433804863	8258	Economy	6300.00
0005433633353	8258	Economy	6300.00
0005433805034	8258	Economy	6300.00
0005433633329	8258	Economy	6300.00
0005435854051	8258	Economy	6300.00
0005434143709	8258	Economy	6300.00
0005434183555	8276	Business	18800.00
0005432383044	4599	Business	9900.00
0005432383023	4599	Business	9900.00
0005432383016	4599	Business	9900.00
0005433454868	4599	Business	9900.00
0005432383043	4599	Business	9900.00
0005432383050	4599	Business	9900.00
0005432383027	4599	Business	9900.00
0005432383048	4599	Business	9900.00
0005432383056	4599	Business	9900.00
0005432727887	4599	Economy	3300.00
0005432383021	4599	Economy	3300.00
0005432383026	4599	Economy	3300.00
0005432383036	4599	Economy	3300.00
0005432383041	4599	Economy	3300.00
0005433453757	4599	Economy	3300.00
0005432383025	4599	Economy	3300.00
0005433722198	4599	Economy	3300.00
0005432727893	4599	Economy	3300.00
0005432383032	4599	Economy	3600.00
0005432383051	4599	Economy	3600.00
0005432383028	4599	Economy	3600.00
0005432383039	4599	Economy	3600.00
0005432383013	4599	Economy	3300.00
0005432383047	4599	Economy	3300.00
0005432383040	4599	Economy	3300.00
0005432383014	4599	Economy	3300.00
0005433722197	4599	Economy	3300.00
0005432727892	4599	Economy	3300.00
0005433722199	4599	Economy	3300.00
0005432383020	4599	Economy	3300.00
0005432383037	4599	Economy	3300.00
0005432383034	4599	Economy	3300.00
0005432727883	4599	Economy	3300.00
0005432727888	4599	Economy	3300.00
0005433454867	4599	Economy	3300.00
0005433453756	4599	Economy	3300.00
0005432383015	4599	Economy	3300.00
0005432727890	4599	Economy	3300.00
0005432727891	4599	Economy	3300.00
0005432383033	4599	Economy	3300.00
0005432383038	4599	Economy	3300.00
0005432383018	4599	Economy	3300.00
0005432383017	4599	Economy	3300.00
0005432383042	4599	Economy	3300.00
0005432383045	4599	Economy	3300.00
0005432383053	4599	Economy	3300.00
0005432383024	4599	Economy	3300.00
0005432727885	4599	Economy	3300.00
0005432383031	4599	Economy	3300.00
0005432727886	4599	Economy	3300.00
0005432383049	4599	Economy	3300.00
0005433453755	4599	Economy	3300.00
0005432383055	4599	Economy	3300.00
0005432383019	4599	Economy	3300.00
0005432383030	4599	Economy	3300.00
0005432383029	4599	Economy	3300.00
0005432383022	4599	Economy	3300.00
0005432383054	4599	Economy	3300.00
0005433454869	4599	Economy	3300.00
0005432383052	4599	Economy	3300.00
0005432383035	4599	Economy	3300.00
0005432727894	4599	Economy	3300.00
0005432727884	4599	Economy	3300.00
0005432727889	4599	Economy	3300.00
0005432383046	4599	Economy	3300.00
0005432727816	30103	Business	9900.00
0005433722109	30103	Business	9900.00
0005432382570	30103	Business	9900.00
0005432727813	30103	Business	9900.00
0005433722117	30103	Business	9900.00
0005432727784	30103	Business	9900.00
0005432727811	30103	Business	9900.00
0005432382571	30103	Economy	3300.00
0005432382692	30103	Economy	3300.00
0005433722130	30103	Economy	3300.00
0005432382515	30103	Economy	3300.00
0005433194830	30103	Economy	3300.00
0005432382693	30103	Economy	3600.00
0005432382516	30103	Economy	3600.00
0005432382803	30103	Economy	3600.00
0005432727841	30103	Economy	3600.00
0005432727749	30103	Economy	3300.00
0005432382707	30103	Economy	3300.00
0005433722112	30103	Economy	3300.00
0005433722110	30103	Economy	3300.00
0005432382610	30103	Economy	3300.00
0005432382802	30103	Economy	3300.00
0005432382678	30103	Economy	3300.00
0005432727754	30103	Economy	3300.00
0005433722105	30103	Economy	3300.00
0005433722120	30103	Economy	3300.00
0005432382575	30103	Economy	3300.00
0005432382622	30103	Economy	3300.00
0005432382609	30103	Economy	3300.00
0005432382633	30103	Economy	3300.00
0005432382617	30103	Economy	3300.00
0005432727777	30103	Economy	3300.00
0005432727748	30103	Economy	3300.00
0005433722107	30103	Economy	3300.00
0005432382494	30103	Economy	3300.00
0005432727778	30103	Economy	3300.00
0005433453732	30103	Economy	3300.00
0005432382592	30103	Economy	3300.00
0005432727755	30103	Economy	3300.00
0005432382607	30103	Economy	3300.00
0005433194821	30103	Economy	3300.00
0005433722111	30103	Economy	3300.00
0005432382499	30103	Economy	3300.00
0005432727814	30103	Economy	3300.00
0005432382493	30103	Economy	3300.00
0005433722124	30103	Economy	3300.00
0005432727780	30103	Economy	3300.00
0005432382564	30103	Economy	3300.00
0005432727781	30103	Economy	3300.00
0005432727817	30103	Economy	3300.00
0005432727753	30103	Economy	3300.00
0005432727782	30103	Economy	3300.00
0005432382706	30103	Economy	3300.00
0005433194829	30103	Economy	3300.00
0005435540932	1733	Business	57200.00
0005435540918	1733	Business	57200.00
0005435529184	1733	Business	57200.00
0005433516850	1733	Business	57200.00
0005435529182	1733	Business	57200.00
0005432924972	1733	Business	57200.00
0005435540914	1733	Business	57200.00
0005435529175	1733	Business	57200.00
0005435540930	1733	Economy	19100.00
0005435540917	1733	Economy	19100.00
0005435540911	1733	Economy	19100.00
0005435529183	1733	Economy	19100.00
0005435529174	1733	Economy	19100.00
0005433516853	1733	Economy	19100.00
0005435540922	1733	Economy	19100.00
0005435529167	1733	Economy	21000.00
0005435540927	1733	Economy	21000.00
0005432924990	1733	Economy	21000.00
0005432924973	1733	Economy	21000.00
0005433516851	1733	Economy	19100.00
0005433516852	1733	Economy	19100.00
0005433516845	1733	Economy	19100.00
0005435529187	1733	Economy	19100.00
0005432924971	1733	Economy	19100.00
0005435540926	1733	Economy	19100.00
0005435529179	1733	Economy	19100.00
0005435529186	1733	Economy	19100.00
0005435529170	1733	Economy	19100.00
0005435540931	1733	Economy	19100.00
0005435529171	1733	Economy	19100.00
0005433516847	1733	Economy	19100.00
0005435540915	1733	Economy	19100.00
0005433516849	1733	Economy	19100.00
0005435529185	1733	Economy	19100.00
0005435540924	1733	Economy	19100.00
0005433516854	1733	Economy	19100.00
0005435529173	1733	Economy	19100.00
0005433516846	1733	Economy	19100.00
0005435540925	1733	Economy	19100.00
0005435540921	1733	Economy	19100.00
0005435540916	1733	Economy	19100.00
0005432924989	1733	Economy	19100.00
0005433516848	1733	Economy	19100.00
0005435529180	1733	Economy	19100.00
0005435540928	1733	Economy	19100.00
0005435540912	1733	Economy	19100.00
0005435529169	1733	Economy	19100.00
0005435529188	1733	Economy	19100.00
0005435529168	1733	Economy	19100.00
0005432294478	1733	Economy	19100.00
0005435540913	1733	Economy	19100.00
0005435540929	1733	Economy	19100.00
0005435540919	1733	Economy	19100.00
0005435540923	1733	Economy	19100.00
0005432294477	1733	Economy	19100.00
0005435529176	1733	Economy	19100.00
0005435529177	1733	Economy	19100.00
0005435540920	1733	Economy	19100.00
0005435529181	1733	Economy	19100.00
0005435529178	1733	Economy	19100.00
0005435529172	1733	Economy	19100.00
0005435517713	21988	Business	57200.00
0005433516774	21988	Business	57200.00
0005433516755	21988	Business	57200.00
0005435540639	21988	Business	57200.00
0005435540735	21988	Business	57200.00
0005435540676	21988	Business	57200.00
0005435540715	21988	Business	57200.00
0005435517700	21988	Economy	19100.00
0005435517688	21988	Economy	19100.00
0005435540833	21988	Economy	19100.00
0005433516754	21988	Economy	19100.00
0005433516784	21988	Economy	21000.00
0005433516775	21988	Economy	21000.00
0005435540757	21988	Economy	21000.00
0005432925015	21988	Economy	21000.00
0005435540690	21988	Economy	19100.00
0005435540652	21988	Economy	19100.00
0005435517698	21988	Economy	19100.00
0005435540711	21988	Economy	19100.00
0005433516741	21988	Economy	19100.00
0005435517675	21988	Economy	19100.00
0005435517657	21988	Economy	19100.00
0005435517716	21988	Economy	19100.00
0005435517658	21988	Economy	19100.00
0005435540675	21988	Economy	19100.00
0005435517667	21988	Economy	19100.00
0005435540748	21988	Economy	19100.00
0005435540741	21988	Economy	19100.00
0005435517699	21988	Economy	19100.00
0005435540772	21988	Economy	19100.00
0005435517715	21988	Economy	19100.00
0005433516783	21988	Economy	19100.00
0005435517597	21988	Economy	19100.00
0005435517659	21988	Economy	19100.00
0005433516765	21988	Economy	19100.00
0005435517703	21988	Economy	19100.00
0005435517635	21988	Economy	19100.00
0005435540749	21988	Economy	19100.00
0005432925017	21988	Economy	19100.00
0005435517656	21988	Economy	19100.00
0005435517585	21988	Economy	19100.00
0005432925016	21988	Economy	19100.00
0005433516782	21988	Economy	19100.00
0005432925018	21988	Economy	19100.00
0005435540661	21988	Economy	19100.00
0005435517634	21988	Economy	19100.00
0005435540714	21988	Economy	19100.00
0005435540687	21988	Economy	19100.00
0005433516797	21988	Economy	19100.00
0005435540701	21988	Economy	19100.00
0005432925019	21988	Economy	19100.00
0005435540832	21988	Economy	19100.00
0005433516757	21988	Economy	19100.00
0005435540660	21988	Economy	19100.00
0005435517740	21988	Economy	19100.00
0005433516749	21988	Economy	19100.00
0005435517629	21988	Economy	19100.00
0005433516742	21988	Economy	19100.00
0005435517741	21988	Economy	19100.00
0005435540653	21988	Economy	19100.00
0005432823440	7395	Business	18500.00
0005432838920	7395	Business	18500.00
0005432838899	7395	Business	18500.00
0005435252533	7395	Business	18500.00
0005432838922	7395	Business	18500.00
0005434458717	7395	Business	18500.00
0005435252428	7395	Business	18500.00
0005432838911	7395	Business	18500.00
0005432073375	7395	Business	18500.00
0005435252469	7395	Business	18500.00
0005434458719	7395	Business	18500.00
0005435252483	7395	Economy	6200.00
0005432838916	7395	Economy	6200.00
0005435252432	7395	Economy	6200.00
0005432838905	7395	Economy	6200.00
0005434458730	7395	Economy	6200.00
0005435252485	7395	Economy	6200.00
0005432073377	7395	Economy	6200.00
0005435252514	7395	Economy	6200.00
0005432823439	7395	Economy	6200.00
0005435252540	7395	Economy	6200.00
0005435252486	7395	Economy	6800.00
0005435252446	7395	Economy	6800.00
0005435252484	7395	Economy	6800.00
0005435252472	7395	Economy	6200.00
0005435252380	7395	Economy	6200.00
0005434458720	7395	Economy	6200.00
0005432838909	7395	Economy	6200.00
0005432838924	7395	Economy	6200.00
0005432838919	7395	Economy	6200.00
0005435252482	7395	Economy	6200.00
0005434458718	7395	Economy	6200.00
0005432838908	7395	Economy	6200.00
0005435252501	7395	Economy	6200.00
0005435252438	7395	Economy	6200.00
0005432838904	7395	Economy	6200.00
0005434458723	7395	Economy	6200.00
0005434458712	7395	Economy	6200.00
0005434458729	7395	Economy	6200.00
0005432838901	7395	Economy	6200.00
0005432838896	7395	Economy	6200.00
0005434458721	7395	Economy	6200.00
0005432073378	7395	Economy	6200.00
0005432841002	7395	Economy	6200.00
0005434458713	7395	Economy	6200.00
0005434458724	7395	Economy	6200.00
0005435252481	7395	Economy	6200.00
0005435252419	7395	Economy	6200.00
0005434458715	7395	Economy	6200.00
0005432838902	7395	Economy	6200.00
0005432838903	7395	Economy	6200.00
0005432838897	7395	Economy	6200.00
0005435252471	7395	Economy	6200.00
0005434458726	7395	Economy	6200.00
0005435252580	7395	Economy	6200.00
0005432838912	7395	Economy	6200.00
0005434458716	7395	Economy	6200.00
0005432838925	7395	Economy	6200.00
0005434664936	7395	Economy	6200.00
0005435252381	7395	Economy	6200.00
0005432838894	7395	Economy	6200.00
0005435491416	7395	Economy	6200.00
0005434458722	7395	Economy	6200.00
0005432838914	7395	Economy	6200.00
0005432838900	7395	Economy	6200.00
0005435252500	7395	Economy	6200.00
0005432838906	7395	Economy	6200.00
0005434458725	7395	Economy	6200.00
0005432838895	7395	Economy	6200.00
0005432838898	7395	Economy	6200.00
0005432838907	7395	Economy	6200.00
0005435252447	7395	Economy	6200.00
0005434458727	7395	Economy	6200.00
0005432838915	7395	Economy	6200.00
0005434458728	7395	Economy	6200.00
0005432841003	7395	Economy	6200.00
0005432838918	7395	Economy	6200.00
0005432838923	7395	Economy	6200.00
0005435252512	7395	Economy	6200.00
0005434458714	7395	Economy	6200.00
0005432838921	7395	Economy	6200.00
0005432838910	7395	Economy	6200.00
0005432838913	7395	Economy	6200.00
0005432073376	7395	Economy	6200.00
0005432838917	7395	Economy	6200.00
0005435252451	7395	Economy	6200.00
0005434458489	28949	Business	18500.00
0005432840989	28949	Business	18500.00
0005435252630	28949	Business	18500.00
0005435252625	28949	Business	18500.00
0005434664951	28949	Business	18500.00
0005435252628	28949	Business	18500.00
0005434458570	28949	Business	18500.00
0005435252622	28949	Business	18500.00
0005432838811	28949	Business	18500.00
0005435252636	28949	Economy	6200.00
0005435252639	28949	Economy	6200.00
0005435252627	28949	Economy	6200.00
0005432838658	28949	Economy	6200.00
0005435252631	28949	Economy	6200.00
0005435252621	28949	Economy	6200.00
0005432838754	28949	Economy	6200.00
0005435252637	28949	Economy	6800.00
0005432001014	28949	Economy	6800.00
0005432838700	28949	Economy	6800.00
0005432823425	28949	Economy	6800.00
0005432838776	28949	Economy	6200.00
0005432838597	28949	Economy	6200.00
0005434458571	28949	Economy	6200.00
0005432838569	28949	Economy	6200.00
0005434458569	28949	Economy	6200.00
0005432838677	28949	Economy	6200.00
0005435252626	28949	Economy	6200.00
0005432823424	28949	Economy	6200.00
0005432838729	28949	Economy	6200.00
0005434458578	28949	Economy	6200.00
0005435252633	28949	Economy	6200.00
0005432838692	28949	Economy	6200.00
0005432838599	28949	Economy	6200.00
0005435252641	28949	Economy	6200.00
0005432838647	28949	Economy	6200.00
0005432838676	28949	Economy	6200.00
0005435491434	28949	Economy	6200.00
0005435252635	28949	Economy	6200.00
0005432838718	28949	Economy	6200.00
0005432838581	28949	Economy	6200.00
0005432838659	28949	Economy	6200.00
0005434458579	28949	Economy	6200.00
0005434458534	28949	Economy	6200.00
0005432838600	28949	Economy	6200.00
0005432838621	28949	Economy	6200.00
0005432838781	28949	Economy	6200.00
0005435252624	28949	Economy	6200.00
0005435252634	28949	Economy	6200.00
0005432838708	28949	Economy	6200.00
0005432838568	28949	Economy	6200.00
0005435252623	28949	Economy	6200.00
0005435491433	28949	Economy	6200.00
0005432838777	28949	Economy	6200.00
0005432838591	28949	Economy	6200.00
0005434458548	28949	Economy	6200.00
0005434458528	28949	Economy	6200.00
0005435252632	28949	Economy	6200.00
0005432001015	28949	Economy	6200.00
0005432840990	28949	Economy	6200.00
0005435252629	28949	Economy	6200.00
0005432838660	28949	Economy	6200.00
0005434458553	28949	Economy	6200.00
0005432838541	28949	Economy	6200.00
0005435252640	28949	Economy	6200.00
0005434458623	28949	Economy	6200.00
0005435252638	28949	Economy	6200.00
0005432838648	28949	Economy	6200.00
0005432838722	28949	Economy	6200.00
0005432838780	28949	Economy	6200.00
0005432838779	28949	Economy	6200.00
0005432838657	28949	Economy	6200.00
0005432838656	28949	Economy	6200.00
0005432838699	28949	Economy	6200.00
0005434458535	28949	Economy	6200.00
0005432838717	28949	Economy	6200.00
0005432838628	28949	Economy	6200.00
0005434275960	8791	Business	145300.00
0005435990597	8791	Business	145300.00
0005435990595	8791	Business	145300.00
0005435990598	8791	Economy	48400.00
0005435990593	8791	Economy	48400.00
0005435990592	8791	Economy	48400.00
0005434275966	8791	Economy	48400.00
0005435990594	8791	Economy	48400.00
0005435990591	8791	Economy	48400.00
0005435990596	8791	Economy	48400.00
0005434275964	8791	Economy	48400.00
0005434276004	15746	Business	145300.00
0005435990554	15746	Business	145300.00
0005435990529	15746	Economy	53300.00
0005435990543	15746	Economy	48400.00
0005435990526	15746	Economy	48400.00
0005434276006	15746	Economy	48400.00
0005435990509	15746	Economy	48400.00
0005435990525	15746	Economy	48400.00
0005434276003	15746	Economy	48400.00
0005435990528	15746	Economy	48400.00
0005434276005	15746	Economy	48400.00
0005432427131	20618	Economy	15900.00
0005433476860	20618	Economy	14500.00
0005433476856	20618	Economy	14500.00
0005433476867	20618	Economy	14500.00
0005433476866	20618	Economy	14500.00
0005433476861	20618	Economy	14500.00
0005432427130	20618	Economy	14500.00
0005432427132	20618	Economy	14500.00
0005432427133	20618	Economy	14500.00
0005432427135	20618	Economy	14500.00
0005432427134	20618	Economy	14500.00
0005433476870	20618	Economy	14500.00
0005433476859	20618	Economy	14500.00
0005433476884	30852	Economy	15900.00
0005433476882	30852	Economy	15900.00
0005432427113	30852	Economy	14500.00
0005432427110	30852	Economy	14500.00
0005433476881	30852	Economy	14500.00
0005433476883	30852	Economy	14500.00
0005432427116	30852	Economy	14500.00
0005433476885	30852	Economy	14500.00
0005432427114	30852	Economy	14500.00
0005432909255	23851	Economy	13300.00
0005433468239	23851	Economy	13300.00
0005432909265	23851	Economy	13300.00
0005433468227	23851	Economy	13300.00
0005433468221	23851	Economy	12100.00
0005433468213	23851	Economy	12100.00
0005433468196	23851	Economy	12100.00
0005433468202	23851	Economy	12100.00
0005432909263	23851	Economy	12100.00
0005432909259	23851	Economy	12100.00
0005433468208	23851	Economy	12100.00
0005433468217	23851	Economy	12100.00
0005432909264	23851	Economy	12100.00
0005432909258	23851	Economy	12100.00
0005433468182	23851	Economy	12100.00
0005432909260	23851	Economy	12100.00
0005432909262	23851	Economy	12100.00
0005432909261	23851	Economy	12100.00
0005433468201	23851	Economy	12100.00
0005433468207	23851	Economy	12100.00
0005433468183	23851	Economy	12100.00
0005433468197	23851	Economy	12100.00
0005433468180	23851	Economy	12100.00
0005433468267	23851	Economy	12100.00
0005433468245	23851	Economy	12100.00
0005433468222	23851	Economy	12100.00
0005433468226	23851	Economy	12100.00
0005433468225	23851	Economy	12100.00
0005433468246	23851	Economy	12100.00
0005432909257	23851	Economy	12100.00
0005433468191	23851	Economy	12100.00
0005432909256	23851	Economy	12100.00
0005433468216	23851	Economy	12100.00
0005433468190	23851	Economy	12100.00
0005433468189	23851	Economy	12100.00
0005432360177	6357	Business	36600.00
0005432360162	6357	Business	36600.00
0005432360146	6357	Business	36600.00
0005432360166	6357	Business	36600.00
0005432360178	6357	Business	36600.00
0005435176702	6357	Business	36600.00
0005432363401	6357	Business	36600.00
0005432360185	6357	Business	36600.00
0005432363404	6357	Business	36600.00
0005435176621	6357	Business	36600.00
0005435176703	6357	Economy	12200.00
0005435176777	6357	Economy	12200.00
0005432360155	6357	Economy	12200.00
0005434149600	6357	Economy	12200.00
0005432363403	6357	Economy	12200.00
0005432360148	6357	Economy	12200.00
0005435176618	6357	Economy	12200.00
0005435723022	6357	Economy	12200.00
0005434149561	6357	Economy	12200.00
0005435723021	6357	Economy	12200.00
0005434149573	6357	Economy	12200.00
0005435176856	6357	Economy	12200.00
0005434149566	6357	Economy	12200.00
0005432360187	6357	Economy	12200.00
0005432335979	6357	Economy	12200.00
0005432360156	6357	Economy	12200.00
0005434149619	6357	Economy	12200.00
0005432360189	6357	Economy	12200.00
0005435176679	6357	Economy	12200.00
0005432335982	6357	Economy	12200.00
0005432335991	6357	Economy	12200.00
0005432360161	6357	Economy	12200.00
0005435723017	6357	Economy	12200.00
0005432363402	6357	Economy	12200.00
0005435176723	6357	Economy	12200.00
0005435176778	6357	Economy	12200.00
0005432360183	6357	Economy	12200.00
0005435176658	6357	Economy	12200.00
0005432335992	6357	Economy	12200.00
0005432360151	6357	Economy	12200.00
0005432360147	6357	Economy	12200.00
0005432360193	6357	Economy	12200.00
0005432360179	6357	Economy	12200.00
0005434149574	6357	Economy	12200.00
0005432360194	6357	Economy	12200.00
0005435176799	6357	Economy	12200.00
0005434149575	6357	Economy	12200.00
0005435176680	6357	Economy	13400.00
0005435176759	6357	Economy	12200.00
0005432360159	6357	Economy	13400.00
0005432360152	6357	Economy	13400.00
0005432062209	6357	Economy	13400.00
0005434149584	6357	Economy	13400.00
0005432360153	6357	Economy	12200.00
0005432360188	6357	Economy	12200.00
0005432360181	6357	Economy	12200.00
0005432360150	6357	Economy	12200.00
0005432335983	6357	Economy	12200.00
0005432360186	6357	Economy	12200.00
0005432360191	6357	Economy	12200.00
0005432360180	6357	Economy	12200.00
0005435176804	6357	Economy	12200.00
0005434149603	6357	Economy	12200.00
0005435176829	6357	Economy	12200.00
0005432360192	6357	Economy	12200.00
0005435723019	6357	Economy	12200.00
0005432360172	6357	Economy	12200.00
0005432360160	6357	Economy	12200.00
0005434149620	6357	Economy	12200.00
0005435723018	6357	Economy	12200.00
0005432335988	6357	Economy	12200.00
0005432360168	6357	Economy	12200.00
0005432360165	6357	Economy	12200.00
0005432360190	6357	Economy	12200.00
0005432360167	6357	Economy	12200.00
0005432360173	6357	Economy	12200.00
0005435176828	6357	Economy	12200.00
0005432335990	6357	Economy	12200.00
0005432360175	6357	Economy	12200.00
0005432335981	6357	Economy	12200.00
0005435176865	6357	Economy	12200.00
0005435176619	6357	Economy	12200.00
0005432062207	6357	Economy	12200.00
0005432360169	6357	Economy	12200.00
0005435176853	6357	Economy	12200.00
0005435176650	6357	Economy	12200.00
0005432360174	6357	Economy	12200.00
0005432360164	6357	Economy	12200.00
0005435176701	6357	Economy	12200.00
0005432360163	6357	Economy	12200.00
0005435176763	6357	Economy	12200.00
0005435176697	6357	Economy	12200.00
0005432360176	6357	Economy	12200.00
0005432335993	6357	Economy	12200.00
0005432335987	6357	Economy	12200.00
0005432062208	6357	Economy	12200.00
0005432335980	6357	Economy	12200.00
0005435176789	6357	Economy	12200.00
0005432360182	6357	Economy	12200.00
0005432335986	6357	Economy	12200.00
0005432360170	6357	Economy	12200.00
0005434149588	6357	Economy	12200.00
0005434149585	6357	Economy	12200.00
0005435176645	6357	Economy	12200.00
0005432335989	6357	Economy	12200.00
0005432360154	6357	Economy	12200.00
0005435490190	6357	Economy	12200.00
0005432335985	6357	Economy	12200.00
0005432360158	6357	Economy	12200.00
0005435176649	6357	Economy	12200.00
0005432360184	6357	Economy	12200.00
0005435176762	6357	Economy	12200.00
0005432335984	6357	Economy	12200.00
0005435176815	6357	Economy	12200.00
0005432360171	6357	Economy	12200.00
0005435176620	6357	Economy	12200.00
0005432360157	6357	Economy	12200.00
0005432360149	6357	Economy	12200.00
0005435176978	21027	Business	36600.00
0005435176972	21027	Business	36600.00
0005434149678	21027	Business	36600.00
0005435176970	21027	Business	36600.00
0005435176966	21027	Business	36600.00
0005432359638	21027	Business	36600.00
0005432363376	21027	Business	36600.00
0005434149679	21027	Business	36600.00
0005435176959	21027	Business	36600.00
0005434149681	21027	Business	36600.00
0005432335864	21027	Business	36600.00
0005434149688	21027	Economy	12200.00
0005432335914	21027	Economy	12200.00
0005432359922	21027	Economy	12200.00
0005434149683	21027	Economy	12200.00
0005435176967	21027	Economy	12200.00
0005434149687	21027	Economy	12200.00
0005432359958	21027	Economy	12200.00
0005435176975	21027	Economy	12200.00
0005435723037	21027	Economy	12200.00
0005432359658	21027	Economy	12200.00
0005432359578	21027	Economy	12200.00
0005432359719	21027	Economy	12200.00
0005432359564	21027	Economy	12200.00
0005435490216	21027	Economy	12200.00
0005435490217	21027	Economy	12200.00
0005432359551	21027	Economy	12200.00
0005432359737	21027	Economy	12200.00
0005432335879	21027	Economy	12200.00
0005432335890	21027	Economy	12200.00
0005432359849	21027	Economy	12200.00
0005432359738	21027	Economy	12200.00
0005432359716	21027	Economy	12200.00
0005432359903	21027	Economy	12200.00
0005435723038	21027	Economy	12200.00
0005432359850	21027	Economy	12200.00
0005435176969	21027	Economy	12200.00
0005434149684	21027	Economy	12200.00
0005432359577	21027	Economy	12200.00
0005432335880	21027	Economy	12200.00
0005432359659	21027	Economy	12200.00
0005432359883	21027	Economy	12200.00
0005432335882	21027	Economy	12200.00
0005432363382	21027	Economy	12200.00
0005432359748	21027	Economy	12200.00
0005432335849	21027	Economy	13400.00
0005435176951	21027	Economy	13400.00
0005435176962	21027	Economy	13400.00
0005432359841	21027	Economy	13400.00
0005432359848	21027	Economy	13400.00
0005432359884	21027	Economy	13400.00
0005432359715	21027	Economy	12200.00
0005432359668	21027	Economy	12200.00
0005435176952	21027	Economy	12200.00
0005432359840	21027	Economy	12200.00
0005434149680	21027	Economy	12200.00
0005432359844	21027	Economy	12200.00
0005432363380	21027	Economy	12200.00
0005432359562	21027	Economy	12200.00
0005432359698	21027	Economy	12200.00
0005432359923	21027	Economy	12200.00
0005432359838	21027	Economy	12200.00
0005432359892	21027	Economy	12200.00
0005432359902	21027	Economy	12200.00
0005435176957	21027	Economy	12200.00
0005432359901	21027	Economy	12200.00
0005434149682	21027	Economy	12200.00
0005432359734	21027	Economy	12200.00
0005432335896	21027	Economy	12200.00
0005432359904	21027	Economy	12200.00
0005435176968	21027	Economy	12200.00
0005435176965	21027	Economy	12200.00
0005434149685	21027	Economy	12200.00
0005432359563	21027	Economy	12200.00
0005432359708	21027	Economy	12200.00
0005432359808	21027	Economy	12200.00
0005432359561	21027	Economy	12200.00
0005432335878	21027	Economy	12200.00
0005435176974	21027	Economy	12200.00
0005435176958	21027	Economy	12200.00
0005432335852	21027	Economy	12200.00
0005435176979	21027	Economy	12200.00
0005432359669	21027	Economy	12200.00
0005435176977	21027	Economy	12200.00
0005435176954	21027	Economy	12200.00
0005435176963	21027	Economy	12200.00
0005435176964	21027	Economy	12200.00
0005435176953	21027	Economy	12200.00
0005432359714	21027	Economy	12200.00
0005432359718	21027	Economy	12200.00
0005432363381	21027	Economy	12200.00
0005435176971	21027	Economy	12200.00
0005432359601	21027	Economy	12200.00
0005432359537	21027	Economy	12200.00
0005434149686	21027	Economy	12200.00
0005435176961	21027	Economy	12200.00
0005432052734	21027	Economy	12200.00
0005432052733	21027	Economy	12200.00
0005432052732	21027	Economy	12200.00
0005432052735	21027	Economy	12200.00
0005435176973	21027	Economy	12200.00
0005435176976	21027	Economy	12200.00
0005432335897	21027	Economy	12200.00
0005432335891	21027	Economy	12200.00
0005435176956	21027	Economy	12200.00
0005432359639	21027	Economy	12200.00
0005435176955	21027	Economy	12200.00
0005435176960	21027	Economy	12200.00
0005434149677	21027	Economy	12200.00
0005432359538	21027	Economy	12200.00
0005432359565	21027	Economy	12200.00
0005434458478	17711	Economy	3400.00
0005434458555	17711	Economy	3400.00
0005434458510	17711	Economy	3400.00
0005434186187	17711	Economy	3100.00
0005434458551	17711	Economy	3100.00
0005434458658	17711	Economy	3100.00
0005434448276	17711	Economy	3100.00
0005434458557	17711	Economy	3100.00
0005434458606	17711	Economy	3100.00
0005434448285	17711	Economy	3100.00
0005434463908	17711	Economy	3100.00
0005434448275	17711	Economy	3100.00
0005434448286	17711	Economy	3100.00
0005434458519	17711	Economy	3100.00
0005434448274	17711	Economy	3100.00
0005434448266	17711	Economy	3100.00
0005434458550	17711	Economy	3100.00
0005434458589	17711	Economy	3100.00
0005434448273	17711	Economy	3100.00
0005434458511	17711	Economy	3100.00
0005434186188	17711	Economy	3100.00
0005434458575	17711	Economy	3100.00
0005434458599	17711	Economy	3100.00
0005434458512	17711	Economy	3100.00
0005434458556	17711	Economy	3100.00
0005434458600	17711	Economy	3100.00
0005434458520	17711	Economy	3100.00
0005434458573	17711	Economy	3100.00
0005434458615	17711	Economy	3100.00
0005434458572	17711	Economy	3100.00
0005434458715	29082	Economy	3400.00
0005434458723	29082	Economy	3400.00
0005434458712	29082	Economy	3400.00
0005434462780	29082	Economy	3100.00
0005434448296	29082	Economy	3100.00
0005434458728	29082	Economy	3100.00
0005434448297	29082	Economy	3100.00
0005434458719	29082	Economy	3100.00
0005434458718	29082	Economy	3100.00
0005434458720	29082	Economy	3100.00
0005434458729	29082	Economy	3100.00
0005434458726	29082	Economy	3100.00
0005434463919	29082	Economy	3100.00
0005434458725	29082	Economy	3100.00
0005434458721	29082	Economy	3100.00
0005434458717	29082	Economy	3100.00
0005434458714	29082	Economy	3100.00
0005434458727	29082	Economy	3100.00
0005434463918	29082	Economy	3100.00
0005434458724	29082	Economy	3100.00
0005434448298	29082	Economy	3100.00
0005434458716	29082	Economy	3100.00
0005434458713	29082	Economy	3100.00
0005434458730	29082	Economy	3100.00
0005434458722	29082	Economy	3100.00
0005432661914	6495	Business	185300.00
0005432664130	6495	Business	185300.00
0005432664136	6495	Business	185300.00
0005432664141	6495	Business	185300.00
0005432661915	6495	Business	185300.00
0005432664134	6495	Business	185300.00
0005432664138	6495	Economy	61800.00
0005432663030	6495	Economy	61800.00
0005432661917	6495	Economy	61800.00
0005432663031	6495	Economy	61800.00
0005432663033	6495	Economy	61800.00
0005432663029	6495	Economy	61800.00
0005432661913	6495	Economy	61800.00
0005432663028	6495	Economy	61800.00
0005432661923	6495	Economy	61800.00
0005432661927	6495	Economy	61800.00
0005432663032	6495	Economy	61800.00
0005432664142	6495	Economy	61800.00
0005432663034	6495	Economy	61800.00
0005432661922	6495	Economy	61800.00
0005432661924	6495	Economy	61800.00
0005432663035	6495	Economy	61800.00
0005432661919	6495	Economy	61800.00
0005432663038	6495	Economy	61800.00
0005432664132	6495	Economy	61800.00
0005432664129	6495	Economy	61800.00
0005432663027	6495	Economy	61800.00
0005432661916	6495	Economy	61800.00
0005432664140	6495	Economy	61800.00
0005432663040	6495	Economy	61800.00
0005432661920	6495	Economy	61800.00
0005432663036	6495	Economy	61800.00
0005432664133	6495	Economy	61800.00
0005432661921	6495	Economy	61800.00
0005432661926	6495	Economy	61800.00
0005432661925	6495	Economy	61800.00
0005432663037	6495	Economy	61800.00
0005432664135	6495	Economy	61800.00
0005432664128	6495	Economy	61800.00
0005432664131	6495	Economy	61800.00
0005432664139	6495	Economy	61800.00
0005432663039	6495	Economy	61800.00
0005432661918	6495	Economy	61800.00
0005432664137	6495	Economy	61800.00
0005432604149	21434	Economy	7300.00
0005432604157	21434	Economy	7300.00
0005432604160	21434	Economy	7300.00
0005432604166	21434	Economy	7300.00
0005432604154	21434	Economy	6600.00
0005432604134	21434	Economy	6600.00
0005432604147	21434	Economy	6600.00
0005432604131	21434	Economy	6600.00
0005432604167	21434	Economy	6600.00
0005432604140	21434	Economy	6600.00
0005432604161	21434	Economy	6600.00
0005432604146	21434	Economy	6600.00
0005432604145	21434	Economy	6600.00
0005432604133	21434	Economy	6600.00
0005432604159	21434	Economy	6600.00
0005432604141	21434	Economy	6600.00
0005432604168	21434	Economy	6600.00
0005435218100	21434	Economy	6600.00
0005432604162	21434	Economy	6600.00
0005432604155	21434	Economy	6600.00
0005432604135	21434	Economy	6600.00
0005432604151	21434	Economy	6600.00
0005432604130	21434	Economy	6600.00
0005432604152	21434	Economy	6600.00
0005432604128	21434	Economy	6600.00
0005432604148	21434	Economy	6600.00
0005432604144	21434	Economy	6600.00
0005432604165	21434	Economy	6600.00
0005432604150	21434	Economy	6600.00
0005432604138	21434	Economy	6600.00
0005432604143	21434	Economy	6600.00
0005432604137	21434	Economy	6600.00
0005432604129	21434	Economy	6600.00
0005432604142	21434	Economy	6600.00
0005432604158	21434	Economy	6600.00
0005432604132	21434	Economy	6600.00
0005432604153	21434	Economy	6600.00
0005432604156	21434	Economy	6600.00
0005432604163	21434	Economy	6600.00
0005432604164	21434	Economy	6600.00
0005432604139	21434	Economy	6600.00
0005432604136	21434	Economy	6600.00
0005432603798	31679	Economy	7300.00
0005432603843	31679	Economy	7300.00
0005432603881	31679	Economy	7300.00
0005432603946	31679	Economy	7300.00
0005432603823	31679	Economy	6600.00
0005432603838	31679	Economy	6600.00
0005432603805	31679	Economy	6600.00
0005432603875	31679	Economy	6600.00
0005432603834	31679	Economy	6600.00
0005432603771	31679	Economy	6600.00
0005432603786	31679	Economy	6600.00
0005432603860	31679	Economy	6600.00
0005432603745	31679	Economy	6600.00
0005432603868	31679	Economy	6600.00
0005432603746	31679	Economy	6600.00
0005432603824	31679	Economy	6600.00
0005432603809	31679	Economy	6600.00
0005432603863	31679	Economy	6600.00
0005432603796	31679	Economy	6600.00
0005432603804	31679	Economy	6600.00
0005432603693	31679	Economy	6600.00
0005432603770	31679	Economy	6600.00
0005432603775	31679	Economy	6600.00
0005432603859	31679	Economy	6600.00
0005432603901	31679	Economy	6600.00
0005432603840	31679	Economy	6600.00
0005432603892	31679	Economy	6600.00
0005432603806	31679	Economy	6600.00
0005432603747	31679	Economy	6600.00
0005432603769	31679	Economy	6600.00
0005432603839	31679	Economy	6600.00
0005432603825	31679	Economy	6600.00
0005432603662	31679	Economy	6600.00
0005432603810	31679	Economy	6600.00
0005432603779	31679	Economy	6600.00
0005432603822	31679	Economy	6600.00
0005432603903	31679	Economy	6600.00
0005432603700	31679	Economy	6600.00
0005432603778	31679	Economy	6600.00
0005432603951	31679	Economy	6600.00
0005432603748	31679	Economy	6600.00
0005432603757	31679	Economy	6600.00
0005432603865	31679	Economy	6600.00
0005433293142	12305	Economy	19500.00
0005433293167	12305	Economy	17800.00
0005433293173	12305	Economy	17800.00
0005435154592	12305	Economy	17800.00
0005433293152	12305	Economy	17800.00
0005433293163	12305	Economy	17800.00
0005433293149	12305	Economy	17800.00
0005433293155	12305	Economy	17800.00
0005433293146	12305	Economy	17800.00
0005433293161	12305	Economy	17800.00
0005433293166	12305	Economy	17800.00
0005433293158	12305	Economy	17800.00
0005435154593	12305	Economy	17800.00
0005435154591	12305	Economy	17800.00
0005433293147	12305	Economy	17800.00
0005433293162	12305	Economy	17800.00
0005433293153	12305	Economy	17800.00
0005433293145	12305	Economy	17800.00
0005433293144	12305	Economy	17800.00
0005433293174	12305	Economy	17800.00
0005433293159	12305	Economy	17800.00
0005433293157	12305	Economy	17800.00
0005433293165	12305	Economy	17800.00
0005433293148	12305	Economy	17800.00
0005433473133	23890	Economy	14000.00
0005435257216	23890	Economy	14000.00
0005433473125	23890	Economy	14000.00
0005435257209	23890	Economy	12700.00
0005433473127	23890	Economy	12700.00
0005433473126	23890	Economy	12700.00
0005435257210	23890	Economy	12700.00
0005433473145	23890	Economy	12700.00
0005433473151	23890	Economy	12700.00
0005435257221	23890	Economy	12700.00
0005433473130	23890	Economy	12700.00
0005435257219	23890	Economy	12700.00
0005435257211	23890	Economy	12700.00
0005435257218	23890	Economy	12700.00
0005433473134	23890	Economy	12700.00
0005435257214	23890	Economy	12700.00
0005435257220	23890	Economy	12700.00
0005435257212	23890	Economy	12700.00
0005433473113	23890	Economy	12700.00
0005435257213	23890	Economy	12700.00
0005433473114	23890	Economy	12700.00
0005435257215	23890	Economy	12700.00
0005433473138	23890	Economy	12700.00
0005435257217	23890	Economy	12700.00
0005433473112	23890	Economy	12700.00
0005434606775	18869	Economy	6600.00
0005434606782	18869	Economy	6600.00
0005434606783	18869	Economy	6600.00
0005434606812	22390	Economy	6600.00
0005434606813	22390	Economy	6600.00
0005434604881	22390	Economy	6600.00
0005435904890	22390	Economy	6600.00
0005434604880	22390	Economy	6600.00
0005434606814	22390	Economy	6600.00
0005434602888	3840	Economy	24900.00
0005435904373	3840	Economy	24900.00
0005434522430	3840	Economy	24900.00
0005434522424	3840	Economy	24900.00
0005435904371	3840	Economy	22600.00
0005434602890	3840	Economy	22600.00
0005434522427	3840	Economy	22600.00
0005435904372	3840	Economy	22600.00
0005434522425	3840	Economy	22600.00
0005435904374	3840	Economy	22600.00
0005434602893	3840	Economy	22600.00
0005434603020	3840	Economy	22600.00
0005434522426	3840	Economy	22600.00
0005434522428	3840	Economy	22600.00
0005434603019	3840	Economy	22600.00
0005434522429	3840	Economy	22600.00
0005434602891	3840	Economy	22600.00
0005434602889	3840	Economy	22600.00
0005434602892	3840	Economy	22600.00
0005434602886	3840	Economy	22600.00
0005434602887	3840	Economy	22600.00
0005434604845	19063	Economy	24900.00
0005434604854	19063	Economy	24900.00
0005434602863	19063	Economy	22600.00
0005435904399	19063	Economy	22600.00
0005434522403	19063	Economy	22600.00
0005434522389	19063	Economy	22600.00
0005435904400	19063	Economy	22600.00
0005434522414	19063	Economy	22600.00
0005434522392	19063	Economy	22600.00
0005435904398	19063	Economy	22600.00
0005435904397	19063	Economy	22600.00
0005434604848	19063	Economy	22600.00
0005434602866	19063	Economy	22600.00
0005434522379	19063	Economy	22600.00
0005434602859	19063	Economy	22600.00
0005434602862	19063	Economy	22600.00
0005434604855	19063	Economy	22600.00
0005434522405	19063	Economy	22600.00
0005434522410	19063	Economy	22600.00
0005434522388	19063	Economy	22600.00
0005434604860	19063	Economy	22600.00
0005434522390	19063	Economy	22600.00
0005434602872	19063	Economy	22600.00
0005434602867	19063	Economy	22600.00
0005434602861	19063	Economy	22600.00
0005434522413	19063	Economy	22600.00
0005434522382	19063	Economy	22600.00
0005434522404	19063	Economy	22600.00
0005434602858	19063	Economy	22600.00
0005435904396	19063	Economy	22600.00
0005435904395	19063	Economy	22600.00
0005432747387	418	Business	44500.00
0005432747392	418	Business	44500.00
0005432890780	418	Business	44500.00
0005432890785	418	Business	44500.00
0005432890759	418	Business	44500.00
0005432747388	418	Business	44500.00
0005432890752	418	Business	44500.00
0005432747395	418	Business	44500.00
0005432747410	418	Business	44500.00
0005432753284	418	Economy	14800.00
0005432890731	418	Economy	14800.00
0005432747402	418	Economy	14800.00
0005435627116	418	Economy	14800.00
0005432747413	418	Economy	14800.00
0005432747408	418	Economy	14800.00
0005432219986	418	Economy	14800.00
0005432219984	418	Economy	14800.00
0005433875364	418	Economy	14800.00
0005432751511	418	Economy	16300.00
0005432747415	418	Economy	16300.00
0005432747378	418	Economy	16300.00
0005432747383	418	Economy	14800.00
0005432890690	418	Economy	14800.00
0005432890754	418	Economy	14800.00
0005432747382	418	Economy	14800.00
0005432747394	418	Economy	14800.00
0005432747393	418	Economy	14800.00
0005433293150	418	Economy	14800.00
0005432890826	418	Economy	14800.00
0005432747403	418	Economy	14800.00
0005432747404	418	Economy	14800.00
0005432751509	418	Economy	14800.00
0005432890784	418	Economy	14800.00
0005432747386	418	Economy	14800.00
0005432747398	418	Economy	14800.00
0005435154594	418	Economy	14800.00
0005432890777	418	Economy	14800.00
0005432747397	418	Economy	14800.00
0005432747390	418	Economy	14800.00
0005433293151	418	Economy	14800.00
0005432753285	418	Economy	14800.00
0005435627117	418	Economy	14800.00
0005432890827	418	Economy	14800.00
0005432219985	418	Economy	14800.00
0005432747389	418	Economy	14800.00
0005432890716	418	Economy	14800.00
0005433875352	418	Economy	14800.00
0005433293160	418	Economy	14800.00
0005435154595	418	Economy	14800.00
0005432890855	418	Economy	14800.00
0005432747406	418	Economy	14800.00
0005432747405	418	Economy	14800.00
0005432747399	418	Economy	14800.00
0005432747384	418	Economy	14800.00
0005432747411	418	Economy	14800.00
0005433293193	418	Economy	14800.00
0005432747381	418	Economy	14800.00
0005432747379	418	Economy	14800.00
0005433293209	418	Economy	14800.00
0005432747396	418	Economy	14800.00
0005432747400	418	Economy	14800.00
0005432747380	418	Economy	14800.00
0005432751510	418	Economy	14800.00
0005432890691	418	Economy	14800.00
0005432747407	418	Economy	14800.00
0005432890779	418	Economy	14800.00
0005432747409	418	Economy	14800.00
0005432747412	418	Economy	14800.00
0005432890753	418	Economy	14800.00
0005432890813	418	Economy	14800.00
0005432747391	418	Economy	14800.00
0005432890751	418	Economy	14800.00
0005432747414	418	Economy	14800.00
0005432890778	418	Economy	14800.00
0005432747401	418	Economy	14800.00
0005432747385	418	Economy	14800.00
0005432753250	12089	Business	44500.00
0005432214793	12089	Business	44500.00
0005432890940	12089	Business	44500.00
0005432747151	12089	Business	44500.00
0005432747141	12089	Business	44500.00
0005432747183	12089	Business	44500.00
0005432747054	12089	Business	44500.00
0005433875371	12089	Business	44500.00
0005432747184	12089	Economy	14800.00
0005432890937	12089	Economy	14800.00
0005432747177	12089	Economy	14800.00
0005432747113	12089	Economy	14800.00
0005432890942	12089	Economy	14800.00
0005432749755	12089	Economy	14800.00
0005432747111	12089	Economy	14800.00
0005432747285	12089	Economy	14800.00
0005432890936	12089	Economy	16300.00
0005432890935	12089	Economy	16300.00
0005432747057	12089	Economy	16300.00
0005432214795	12089	Economy	16300.00
0005432753256	12089	Economy	16300.00
0005432747149	12089	Economy	14800.00
0005432756806	12089	Economy	14800.00
0005432890943	12089	Economy	14800.00
0005432749756	12089	Economy	14800.00
0005432890939	12089	Economy	14800.00
0005432747064	12089	Economy	14800.00
0005432747058	12089	Economy	14800.00
0005432756805	12089	Economy	14800.00
0005432747330	12089	Economy	14800.00
0005432890931	12089	Economy	14800.00
0005432214794	12089	Economy	14800.00
0005432747092	12089	Economy	14800.00
0005432747094	12089	Economy	14800.00
0005432747179	12089	Economy	14800.00
0005432890941	12089	Economy	14800.00
0005432747059	12089	Economy	14800.00
0005432747286	12089	Economy	14800.00
0005432747053	12089	Economy	14800.00
0005432747093	12089	Economy	14800.00
0005432890945	12089	Economy	14800.00
0005432747003	12089	Economy	14800.00
0005432747188	12089	Economy	14800.00
0005432746945	12089	Economy	14800.00
0005432890932	12089	Economy	14800.00
0005432747112	12089	Economy	14800.00
0005432747004	12089	Economy	14800.00
0005432747070	12089	Economy	14800.00
0005432890934	12089	Economy	14800.00
0005432753257	12089	Economy	14800.00
0005432749759	12089	Economy	14800.00
0005432890948	12089	Economy	14800.00
0005432747230	12089	Economy	14800.00
0005432747140	12089	Economy	14800.00
0005432749751	12089	Economy	14800.00
0005432747110	12089	Economy	14800.00
0005432890933	12089	Economy	14800.00
0005432747189	12089	Economy	14800.00
0005432747069	12089	Economy	14800.00
0005432747201	12089	Economy	14800.00
0005432746901	12089	Economy	14800.00
0005432747051	12089	Economy	14800.00
0005432747180	12089	Economy	14800.00
0005432746961	12089	Economy	14800.00
0005432747187	12089	Economy	14800.00
0005432753261	12089	Economy	14800.00
0005432747061	12089	Economy	14800.00
0005432747060	12089	Economy	14800.00
0005432890949	12089	Economy	14800.00
0005432747067	12089	Economy	14800.00
0005432890946	12089	Economy	14800.00
0005432890947	12089	Economy	14800.00
0005432747037	12089	Economy	14800.00
0005432756809	12089	Economy	14800.00
0005432746946	12089	Economy	14800.00
0005432890938	12089	Economy	14800.00
0005432890944	12089	Economy	14800.00
0005432747240	12089	Economy	14800.00
0005432927923	18939	Economy	28200.00
0005433524987	18939	Economy	28200.00
0005433533287	18939	Economy	25700.00
0005433524988	18939	Economy	25700.00
0005432927922	18939	Economy	25700.00
0005433524983	18939	Economy	25700.00
0005433524981	18939	Economy	25700.00
0005433531275	18939	Economy	25700.00
0005433531276	18939	Economy	25700.00
0005433524979	18939	Economy	25700.00
0005432927909	18939	Economy	25700.00
0005433524985	18939	Economy	25700.00
0005432927915	18939	Economy	25700.00
0005432927914	18939	Economy	25700.00
0005433531273	18939	Economy	25700.00
0005433531274	18939	Economy	25700.00
0005433531277	18939	Economy	25700.00
0005433524984	18939	Economy	25700.00
0005433524986	18939	Economy	25700.00
0005433524989	18939	Economy	25700.00
0005433524980	18939	Economy	25700.00
0005433524990	18939	Economy	25700.00
0005432927916	18939	Economy	25700.00
0005433533288	18939	Economy	25700.00
0005432927888	18939	Economy	25700.00
0005432927950	18939	Economy	25700.00
0005433524982	18939	Economy	25700.00
0005432927924	18939	Economy	25700.00
0005433533290	18939	Economy	25700.00
0005433533289	18939	Economy	25700.00
0005432927917	18939	Economy	25700.00
0005433524913	32501	Economy	25700.00
0005432927961	32501	Economy	25700.00
0005433524864	32501	Economy	25700.00
0005432927960	32501	Economy	25700.00
0005433524898	32501	Economy	25700.00
0005433524899	32501	Economy	25700.00
0005433531261	32501	Economy	25700.00
0005433524883	32501	Economy	25700.00
0005432927963	32501	Economy	25700.00
0005432927962	32501	Economy	25700.00
0005433524884	32501	Economy	25700.00
0005433531238	32501	Economy	25700.00
0005433531262	32501	Economy	25700.00
0005433524865	32501	Economy	25700.00
0005432927965	32501	Economy	25700.00
0005433527221	32501	Economy	25700.00
0005432927964	32501	Economy	25700.00
0005434823033	5301	Business	84000.00
0005435372563	5301	Business	84000.00
0005435372607	5301	Business	84000.00
0005435372276	5301	Business	84000.00
0005435149964	5301	Business	84000.00
0005434823122	5301	Business	84000.00
0005434823078	5301	Business	84000.00
0005434823072	5301	Business	84000.00
0005434823025	5301	Business	84000.00
0005435372438	5301	Business	84000.00
0005434823080	5301	Business	84000.00
0005435372529	5301	Business	84000.00
0005435735058	5301	Business	84000.00
0005432394085	5301	Business	84000.00
0005435661890	5301	Business	84000.00
0005434823038	5301	Business	84000.00
0005435178981	5301	Business	84000.00
0005434828682	5301	Business	84000.00
0005434823035	5301	Business	84000.00
0005434823086	5301	Business	84000.00
0005435735071	5301	Comfort	47600.00
0005434823088	5301	Comfort	47600.00
0005434823054	5301	Comfort	47600.00
0005434823050	5301	Comfort	47600.00
0005435386514	5301	Comfort	47600.00
0005435149971	5301	Comfort	47600.00
0005434823085	5301	Comfort	47600.00
0005434823034	5301	Comfort	47600.00
0005434823119	5301	Comfort	47600.00
0005435372238	5301	Comfort	47600.00
0005435149969	5301	Comfort	47600.00
0005434823024	5301	Comfort	47600.00
0005434823019	5301	Comfort	47600.00
0005435178982	5301	Comfort	47600.00
0005434823071	5301	Comfort	47600.00
0005434823052	5301	Comfort	47600.00
0005435299729	5301	Comfort	47600.00
0005435372389	5301	Comfort	47600.00
0005435149976	5301	Comfort	47600.00
0005434823015	5301	Comfort	47600.00
0005435372460	5301	Comfort	47600.00
0005434823017	5301	Comfort	47600.00
0005435372395	5301	Comfort	47600.00
0005435386492	5301	Comfort	47600.00
0005434823124	5301	Comfort	47600.00
0005434823087	5301	Comfort	47600.00
0005435386472	5301	Comfort	47600.00
0005435149974	5301	Comfort	47600.00
0005434823110	5301	Comfort	47600.00
0005435372335	5301	Comfort	47600.00
0005435735064	5301	Comfort	47600.00
0005434823045	5301	Comfort	47600.00
0005435372295	5301	Comfort	47600.00
0005434823092	5301	Economy	28000.00
0005434823029	5301	Economy	28000.00
0005434558231	5301	Economy	28000.00
0005434823010	5301	Economy	28000.00
0005434823053	5301	Economy	28000.00
0005435372498	5301	Economy	28000.00
0005434823128	5301	Economy	28000.00
0005432394088	5301	Economy	28000.00
0005434823108	5301	Economy	28000.00
0005435372141	5301	Economy	28000.00
0005435372324	5301	Economy	28000.00
0005434823090	5301	Economy	28000.00
0005432121281	5301	Economy	28000.00
0005434823007	5301	Economy	28000.00
0005435149966	5301	Economy	28000.00
0005434823076	5301	Economy	28000.00
0005435372810	5301	Economy	28000.00
0005435372138	5301	Economy	28000.00
0005435372496	5301	Economy	28000.00
0005435735067	5301	Economy	28000.00
0005434823051	5301	Economy	28000.00
0005435372275	5301	Economy	28000.00
0005435386459	5301	Economy	28000.00
0005434823104	5301	Economy	28000.00
0005435149973	5301	Economy	28000.00
0005434823126	5301	Economy	28000.00
0005434823003	5301	Economy	28000.00
0005434823096	5301	Economy	28000.00
0005435372451	5301	Economy	28000.00
0005435386515	5301	Economy	28000.00
0005434823113	5301	Economy	28000.00
0005432121272	5301	Economy	28000.00
0005432121277	5301	Economy	28000.00
0005434823065	5301	Economy	28000.00
0005434823008	5301	Economy	28000.00
0005435149965	5301	Economy	28000.00
0005432823429	5301	Economy	28000.00
0005435304115	5301	Economy	28000.00
0005434823059	5301	Economy	28000.00
0005434828684	5301	Economy	28000.00
0005434823091	5301	Economy	28000.00
0005434823009	5301	Economy	28000.00
0005435372473	5301	Economy	28000.00
0005434823127	5301	Economy	28000.00
0005432396227	5301	Economy	28000.00
0005435386474	5301	Economy	28000.00
0005434823055	5301	Economy	28000.00
0005434823040	5301	Economy	28000.00
0005432121278	5301	Economy	28000.00
0005432121283	5301	Economy	30800.00
0005435372323	5301	Economy	30800.00
0005435372688	5301	Economy	30800.00
0005434823020	5301	Economy	28000.00
0005434823064	5301	Economy	28000.00
0005434823107	5301	Economy	28000.00
0005435372237	5301	Economy	30800.00
0005434823121	5301	Economy	28000.00
0005434823032	5301	Economy	30800.00
0005434828683	5301	Economy	30800.00
0005434823004	5301	Economy	28000.00
0005435372261	5301	Economy	28000.00
0005434823060	5301	Economy	28000.00
0005435372562	5301	Economy	28000.00
0005434831124	5301	Economy	28000.00
0005434831125	5301	Economy	28000.00
0005434823047	5301	Economy	28000.00
0005435299728	5301	Economy	28000.00
0005435372723	5301	Economy	28000.00
0005435372544	5301	Economy	28000.00
0005435386493	5301	Economy	28000.00
0005435372398	5301	Economy	28000.00
0005434823036	5301	Economy	28000.00
0005434823039	5301	Economy	28000.00
0005434823070	5301	Economy	28000.00
0005434823073	5301	Economy	28000.00
0005434823063	5301	Economy	28000.00
0005434823112	5301	Economy	28000.00
0005435372532	5301	Economy	28000.00
0005434823081	5301	Economy	28000.00
0005432121276	5301	Economy	28000.00
0005435386484	5301	Economy	28000.00
0005434823028	5301	Economy	28000.00
0005434823023	5301	Economy	28000.00
0005435149978	5301	Economy	28000.00
0005435372619	5301	Economy	28000.00
0005434823100	5301	Economy	28000.00
0005435386458	5301	Economy	28000.00
0005434823095	5301	Economy	28000.00
0005434823082	5301	Economy	28000.00
0005434823084	5301	Economy	28000.00
0005434823012	5301	Economy	28000.00
0005432121271	5301	Economy	28000.00
0005434823011	5301	Economy	28000.00
0005432121274	5301	Economy	28000.00
0005434823013	5301	Economy	28000.00
0005434823117	5301	Economy	28000.00
0005434823030	5301	Economy	28000.00
0005435372137	5301	Economy	28000.00
0005434823043	5301	Economy	28000.00
0005432121273	5301	Economy	28000.00
0005432394087	5301	Economy	28000.00
0005432394086	5301	Economy	28000.00
0005435372603	5301	Economy	28000.00
0005435372311	5301	Economy	28000.00
0005432121280	5301	Economy	28000.00
0005435149975	5301	Economy	28000.00
0005434823001	5301	Economy	28000.00
0005434823123	5301	Economy	28000.00
0005434823018	5301	Economy	28000.00
0005434822999	5301	Economy	28000.00
0005432823430	5301	Economy	28000.00
0005432396225	5301	Economy	28000.00
0005434823057	5301	Economy	28000.00
0005435372427	5301	Economy	28000.00
0005435372483	5301	Economy	28000.00
0005435372458	5301	Economy	28000.00
0005435149972	5301	Economy	28000.00
0005434823115	5301	Economy	28000.00
0005435372390	5301	Economy	28000.00
0005435372485	5301	Economy	28000.00
0005435149970	5301	Economy	28000.00
0005434664949	5301	Economy	28000.00
0005435372474	5301	Economy	28000.00
0005434823014	5301	Economy	28000.00
0005434558230	5301	Economy	28000.00
0005435149977	5301	Economy	28000.00
0005435372152	5301	Economy	28000.00
0005435372415	5301	Economy	28000.00
0005434823105	5301	Economy	28000.00
0005435372538	5301	Economy	28000.00
0005435372450	5301	Economy	28000.00
0005434823098	5301	Economy	28000.00
0005434664950	5301	Economy	28000.00
0005435372717	5301	Economy	28000.00
0005434823002	5301	Economy	28000.00
0005435386475	5301	Economy	28000.00
0005435304112	5301	Economy	28000.00
0005434823111	5301	Economy	28000.00
0005432121275	5301	Economy	28000.00
0005434823026	5301	Economy	28000.00
0005432394089	5301	Economy	28000.00
0005434823116	5301	Economy	28000.00
0005434823016	5301	Economy	28000.00
0005434558229	5301	Economy	30800.00
0005434823031	5301	Economy	30800.00
0005435372135	5301	Economy	30800.00
0005434823101	5301	Economy	30800.00
0005434823048	5301	Economy	30800.00
0005434823079	5301	Economy	28000.00
0005434823083	5301	Economy	28000.00
0005435372396	5301	Economy	28000.00
0005435149968	5301	Economy	28000.00
0005432823422	5301	Economy	28000.00
0005434823044	5301	Economy	28000.00
0005432121270	5301	Economy	28000.00
0005434823109	5301	Economy	28000.00
0005434823021	5301	Economy	28000.00
0005434823069	5301	Economy	28000.00
0005434823103	5301	Economy	28000.00
0005432121279	5301	Economy	28000.00
0005435372365	5301	Economy	28000.00
0005435299727	5301	Economy	28000.00
0005435372459	5301	Economy	28000.00
0005435386460	5301	Economy	28000.00
0005434823056	5301	Economy	28000.00
0005434823042	5301	Economy	28000.00
0005432396228	5301	Economy	28000.00
0005435372222	5301	Economy	28000.00
0005432396226	5301	Economy	28000.00
0005435372428	5301	Economy	28000.00
0005435149967	5301	Economy	28000.00
0005434558232	5301	Economy	28000.00
0005434823093	5301	Economy	28000.00
0005434823106	5301	Economy	28000.00
0005435372726	5301	Economy	28000.00
0005434831127	5301	Economy	28000.00
0005434823067	5301	Economy	28000.00
0005434823102	5301	Economy	28000.00
0005434823077	5301	Economy	28000.00
0005435372262	5301	Economy	28000.00
0005434823118	5301	Economy	28000.00
0005434823027	5301	Economy	28000.00
0005434823094	5301	Economy	28000.00
0005434831128	5301	Economy	28000.00
0005435304110	5301	Economy	28000.00
0005432396224	5301	Economy	28000.00
0005434823000	5301	Economy	28000.00
0005434823120	5301	Economy	28000.00
0005434823061	5301	Economy	28000.00
0005435372223	5301	Economy	28000.00
0005435372327	5301	Economy	28000.00
0005434823062	5301	Economy	28000.00
0005435372602	5301	Economy	28000.00
0005434831126	5301	Economy	28000.00
0005434823049	5301	Economy	28000.00
0005434823066	5301	Economy	28000.00
0005435372381	5301	Economy	28000.00
0005435304109	5301	Economy	28000.00
0005434823046	5301	Economy	28000.00
0005435386513	5301	Economy	28000.00
0005435372359	5301	Economy	28000.00
0005435661885	5301	Economy	28000.00
0005434823074	5301	Economy	28000.00
0005434823041	5301	Economy	28000.00
0005434823068	5301	Economy	28000.00
0005434823022	5301	Economy	28000.00
0005435386486	5301	Economy	28000.00
0005435372312	5301	Economy	28000.00
0005434823099	5301	Economy	28000.00
0005435372401	5301	Economy	28000.00
0005435372524	5301	Economy	28000.00
0005434823089	5301	Economy	28000.00
0005435372328	5301	Economy	28000.00
0005434823037	5301	Economy	28000.00
0005434823075	5301	Economy	28000.00
0005435372260	5301	Economy	28000.00
0005435372497	5301	Economy	28000.00
0005434823125	5301	Economy	28000.00
0005435372360	5301	Economy	28000.00
0005434823097	5301	Economy	28000.00
0005434823005	5301	Economy	28000.00
0005434823058	5301	Economy	28000.00
0005432121282	5301	Economy	28000.00
0005432823423	5301	Economy	28000.00
0005435372442	5301	Economy	28000.00
0005434823114	5301	Economy	28000.00
0005434823006	5301	Economy	28000.00
0005434821825	9925	Business	84000.00
0005432400088	9925	Business	84000.00
0005434821440	9925	Business	84000.00
0005435372981	9925	Business	84000.00
0005434822144	9925	Business	84000.00
0005435373000	9925	Business	84000.00
0005435372962	9925	Business	84000.00
0005434822082	9925	Business	84000.00
0005434822070	9925	Business	84000.00
0005434558159	9925	Business	84000.00
0005434821875	9925	Business	84000.00
0005434821643	9925	Business	84000.00
0005435149874	9925	Business	84000.00
0005434821330	9925	Business	84000.00
0005435149875	9925	Business	84000.00
0005434822094	9925	Business	84000.00
0005434821874	9925	Business	84000.00
0005434822136	9925	Business	84000.00
0005434821799	9925	Business	84000.00
0005434822152	9925	Comfort	47600.00
0005434822023	9925	Business	84000.00
0005434821500	9925	Comfort	47600.00
0005434821879	9925	Comfort	47600.00
0005434821933	9925	Comfort	47600.00
0005435735120	9925	Comfort	47600.00
0005435735121	9925	Comfort	47600.00
0005435149876	9925	Comfort	47600.00
0005435661919	9925	Comfort	47600.00
0005434821414	9925	Comfort	47600.00
0005435373013	9925	Comfort	47600.00
0005434821909	9925	Comfort	47600.00
0005434822330	9925	Comfort	47600.00
0005435372967	9925	Comfort	47600.00
0005432396190	9925	Comfort	47600.00
0005435372968	9925	Comfort	47600.00
0005435373024	9925	Comfort	47600.00
0005432396187	9925	Comfort	47600.00
0005434821986	9925	Comfort	47600.00
0005435373003	9925	Comfort	47600.00
0005435373006	9925	Comfort	47600.00
0005435373017	9925	Comfort	47600.00
0005434822102	9925	Comfort	47600.00
0005434821464	9925	Comfort	47600.00
0005434822129	9925	Comfort	47600.00
0005434822216	9925	Comfort	47600.00
0005434822073	9925	Comfort	47600.00
0005435372966	9925	Comfort	47600.00
0005435372995	9925	Comfort	47600.00
0005434821856	9925	Comfort	47600.00
0005435373021	9925	Comfort	47600.00
0005435299757	9925	Comfort	47600.00
0005432396200	9925	Comfort	47600.00
0005435386549	9925	Comfort	47600.00
0005435149808	9925	Comfort	47600.00
0005435372991	9925	Comfort	47600.00
0005435373026	9925	Comfort	47600.00
0005435372985	9925	Economy	28000.00
0005434822143	9925	Economy	28000.00
0005435373009	9925	Economy	28000.00
0005434822101	9925	Economy	28000.00
0005435386547	9925	Economy	28000.00
0005435386546	9925	Economy	28000.00
0005434821442	9925	Economy	28000.00
0005434822323	9925	Economy	28000.00
0005432203032	9925	Economy	28000.00
0005434822071	9925	Economy	28000.00
0005435373020	9925	Economy	28000.00
0005434822074	9925	Economy	28000.00
0005435302183	9925	Economy	28000.00
0005435149887	9925	Economy	28000.00
0005435386553	9925	Economy	28000.00
0005435149894	9925	Economy	28000.00
0005434821954	9925	Economy	28000.00
0005435372965	9925	Economy	28000.00
0005434821553	9925	Economy	28000.00
0005435372993	9925	Economy	28000.00
0005435149866	9925	Economy	28000.00
0005435372988	9925	Economy	28000.00
0005432396189	9925	Economy	28000.00
0005435373015	9925	Economy	28000.00
0005434822277	9925	Economy	28000.00
0005432400069	9925	Economy	28000.00
0005434821914	9925	Economy	28000.00
0005435372972	9925	Economy	28000.00
0005435372961	9925	Economy	28000.00
0005434822503	9925	Economy	28000.00
0005434822218	9925	Economy	28000.00
0005434831080	9925	Economy	28000.00
0005434821985	9925	Economy	28000.00
0005432396199	9925	Economy	28000.00
0005434822125	9925	Economy	28000.00
0005432400089	9925	Economy	28000.00
0005435373019	9925	Economy	28000.00
0005435372973	9925	Economy	28000.00
0005435372983	9925	Economy	28000.00
0005432400090	9925	Economy	28000.00
0005434822239	9925	Economy	28000.00
0005435149817	9925	Economy	28000.00
0005432823444	9925	Economy	28000.00
0005434821862	9925	Economy	28000.00
0005435386550	9925	Economy	28000.00
0005434821967	9925	Economy	28000.00
0005435735123	9925	Economy	28000.00
0005435149848	9925	Economy	30800.00
0005432823442	9925	Economy	28000.00
0005434821538	9925	Economy	30800.00
0005435372976	9925	Economy	30800.00
0005435372982	9925	Economy	28000.00
0005435372974	9925	Economy	28000.00
0005435373025	9925	Economy	28000.00
0005435372978	9925	Economy	30800.00
0005434821867	9925	Economy	28000.00
0005434821746	9925	Economy	28000.00
0005434558156	9925	Economy	28000.00
0005435372989	9925	Economy	28000.00
0005435373022	9925	Economy	28000.00
0005435302181	9925	Economy	28000.00
0005434821783	9925	Economy	28000.00
0005434822217	9925	Economy	28000.00
0005432396191	9925	Economy	28000.00
0005434821810	9925	Economy	28000.00
0005435299758	9925	Economy	28000.00
0005434822351	9925	Economy	28000.00
0005434821809	9925	Economy	28000.00
0005432203035	9925	Economy	28000.00
0005434822146	9925	Economy	28000.00
0005434821726	9925	Economy	28000.00
0005434831081	9925	Economy	28000.00
0005434822031	9925	Economy	28000.00
0005434822058	9925	Economy	28000.00
0005435373023	9925	Economy	28000.00
0005435372992	9925	Economy	28000.00
0005435372969	9925	Economy	28000.00
0005435302179	9925	Economy	28000.00
0005434821855	9925	Economy	28000.00
0005432823441	9925	Economy	28000.00
0005435149847	9925	Economy	28000.00
0005435372971	9925	Economy	28000.00
0005434822137	9925	Economy	28000.00
0005434821859	9925	Economy	28000.00
0005434822124	9925	Economy	28000.00
0005434822238	9925	Economy	28000.00
0005434821571	9925	Economy	28000.00
0005434821865	9925	Economy	28000.00
0005435149865	9925	Economy	28000.00
0005434822841	9925	Economy	28000.00
0005435373004	9925	Economy	28000.00
0005434822581	9925	Economy	28000.00
0005434822107	9925	Economy	28000.00
0005432203034	9925	Economy	28000.00
0005435149884	9925	Economy	28000.00
0005434821708	9925	Economy	28000.00
0005435149816	9925	Economy	28000.00
0005432203030	9925	Economy	28000.00
0005435372986	9925	Economy	28000.00
0005434822156	9925	Economy	28000.00
0005435299755	9925	Economy	28000.00
0005435735122	9925	Economy	28000.00
0005434821650	9925	Economy	28000.00
0005434822276	9925	Economy	28000.00
0005435302182	9925	Economy	28000.00
0005434821658	9925	Economy	28000.00
0005432823443	9925	Economy	28000.00
0005435372964	9925	Economy	28000.00
0005434821932	9925	Economy	28000.00
0005435149872	9925	Economy	28000.00
0005435372984	9925	Economy	28000.00
0005434821983	9925	Economy	28000.00
0005434822314	9925	Economy	28000.00
0005434822168	9925	Economy	28000.00
0005434831113	9925	Economy	28000.00
0005435373007	9925	Economy	28000.00
0005434821649	9925	Economy	28000.00
0005435372997	9925	Economy	28000.00
0005435372979	9925	Economy	28000.00
0005434822140	9925	Economy	28000.00
0005434558165	9925	Economy	28000.00
0005434821821	9925	Economy	28000.00
0005434821331	9925	Economy	28000.00
0005434821654	9925	Economy	28000.00
0005435299754	9925	Economy	28000.00
0005435661920	9925	Economy	28000.00
0005435661918	9925	Economy	30800.00
0005435372994	9925	Economy	30800.00
0005435372963	9925	Economy	30800.00
0005434821536	9925	Economy	30800.00
0005434821769	9925	Economy	28000.00
0005435372998	9925	Economy	28000.00
0005435372970	9925	Economy	28000.00
0005435373012	9925	Economy	28000.00
0005434821845	9925	Economy	28000.00
0005435372999	9925	Economy	28000.00
0005434822273	9925	Economy	28000.00
0005434822169	9925	Economy	28000.00
0005434558157	9925	Economy	28000.00
0005435149833	9925	Economy	28000.00
0005434822132	9925	Economy	28000.00
0005434821910	9925	Economy	28000.00
0005434821807	9925	Economy	28000.00
0005435373016	9925	Economy	28000.00
0005434822347	9925	Economy	28000.00
0005435302180	9925	Economy	28000.00
0005434821721	9925	Economy	28000.00
0005434822172	9925	Economy	28000.00
0005434821982	9925	Economy	28000.00
0005434558164	9925	Economy	28000.00
0005435373001	9925	Economy	28000.00
0005434821657	9925	Economy	28000.00
0005435372996	9925	Economy	28000.00
0005434822141	9925	Economy	28000.00
0005434821572	9925	Economy	28000.00
0005434821864	9925	Economy	28000.00
0005434822582	9925	Economy	28000.00
0005435372990	9925	Economy	28000.00
0005435386548	9925	Economy	28000.00
0005434822211	9925	Economy	28000.00
0005435299756	9925	Economy	28000.00
0005434558158	9925	Economy	28000.00
0005434821537	9925	Economy	28000.00
0005434822067	9925	Economy	28000.00
0005434822320	9925	Economy	28000.00
0005434821981	9925	Economy	28000.00
0005435373002	9925	Economy	28000.00
0005435372977	9925	Economy	28000.00
0005432203036	9925	Economy	28000.00
0005434821806	9925	Economy	28000.00
0005434821690	9925	Economy	28000.00
0005434822235	9925	Economy	28000.00
0005432203033	9925	Economy	28000.00
0005434821656	9925	Economy	28000.00
0005435386551	9925	Economy	28000.00
0005434821833	9925	Economy	28000.00
0005434822329	9925	Economy	28000.00
0005435373014	9925	Economy	28000.00
0005434821915	9925	Economy	28000.00
0005434822206	9925	Economy	28000.00
0005434822151	9925	Economy	28000.00
0005434822091	9925	Economy	28000.00
0005435373005	9925	Economy	28000.00
0005434822207	9925	Economy	28000.00
0005434822171	9925	Economy	28000.00
0005434821771	9925	Economy	28000.00
0005434828648	9925	Economy	28000.00
0005434822215	9925	Economy	28000.00
0005435373008	9925	Economy	28000.00
0005434558155	9925	Economy	28000.00
0005434821441	9925	Economy	28000.00
0005434558139	9925	Economy	28000.00
0005434821854	9925	Economy	28000.00
0005432396188	9925	Economy	28000.00
0005435386552	9925	Economy	28000.00
0005434831106	9925	Economy	28000.00
0005434664925	9925	Economy	28000.00
0005434822319	9925	Economy	28000.00
0005435373018	9925	Economy	28000.00
0005432203031	9925	Economy	28000.00
0005434821723	9925	Economy	28000.00
0005435373011	9925	Economy	28000.00
0005435372987	9925	Economy	28000.00
0005434822352	9925	Economy	28000.00
0005435373010	9925	Economy	28000.00
0005435735124	9925	Economy	28000.00
0005435372975	9925	Economy	28000.00
0005435372980	9925	Economy	28000.00
0005434821988	9925	Economy	28000.00
0005434821722	9925	Economy	28000.00
0005435302184	9925	Economy	28000.00
0005435082762	6975	Economy	8200.00
0005435082760	6975	Economy	8200.00
0005435082755	6975	Economy	7400.00
0005435790295	6975	Economy	7400.00
0005435082753	6975	Economy	7400.00
0005435082757	6975	Economy	7400.00
0005435790294	6975	Economy	7400.00
0005435082758	6975	Economy	7400.00
0005435082759	6975	Economy	7400.00
0005435082752	6975	Economy	7400.00
0005435082763	6975	Economy	7400.00
0005435082756	6975	Economy	7400.00
0005435082754	6975	Economy	7400.00
0005435082761	6975	Economy	7400.00
0005435082681	25993	Economy	8200.00
0005435082655	25993	Economy	7400.00
0005435082697	25993	Economy	7400.00
0005435790257	25993	Economy	7400.00
0005435082682	25993	Economy	7400.00
0005435082677	25993	Economy	7400.00
0005435790283	25993	Economy	7400.00
0005435082694	25993	Economy	7400.00
0005435082671	25993	Economy	7400.00
0005435082656	25993	Economy	7400.00
0005435790282	25993	Economy	7400.00
0005435082683	25993	Economy	7400.00
0005435082672	25993	Economy	7400.00
0005435790278	25993	Economy	7400.00
0005434756275	9552	Business	32800.00
0005434756277	9552	Business	32800.00
0005434756270	9552	Business	32800.00
0005434756285	9552	Business	32800.00
0005434213733	9552	Business	32800.00
0005434214006	9552	Business	32800.00
0005434213928	9552	Business	32800.00
0005434756243	9552	Business	32800.00
0005434213853	9552	Business	32800.00
0005434214065	9552	Business	32800.00
0005434756235	9552	Business	32800.00
0005434213902	9552	Business	32800.00
0005434213929	9552	Economy	10900.00
0005434756249	9552	Economy	10900.00
0005434756237	9552	Economy	10900.00
0005434214142	9552	Economy	10900.00
0005434213845	9552	Economy	10900.00
0005434213913	9552	Economy	10900.00
0005434756259	9552	Economy	10900.00
0005434756238	9552	Economy	10900.00
0005434756282	9552	Economy	10900.00
0005434756239	9552	Economy	10900.00
0005434756260	9552	Economy	12000.00
0005434214024	9552	Economy	12000.00
0005434756250	9552	Economy	12000.00
0005434214077	9552	Economy	12000.00
0005434756272	9552	Economy	12000.00
0005434756268	9552	Economy	10900.00
0005434756265	9552	Economy	10900.00
0005434756255	9552	Economy	10900.00
0005434756261	9552	Economy	10900.00
0005434756258	9552	Economy	10900.00
0005434213748	9552	Economy	10900.00
0005434213941	9552	Economy	10900.00
0005434213976	9552	Economy	10900.00
0005434756241	9552	Economy	10900.00
0005434756246	9552	Economy	10900.00
0005434756262	9552	Economy	10900.00
0005434756264	9552	Economy	10900.00
0005434756257	9552	Economy	10900.00
0005434213831	9552	Economy	10900.00
0005434756267	9552	Economy	10900.00
0005434756276	9552	Economy	10900.00
0005434756245	9552	Economy	10900.00
0005434213970	9552	Economy	10900.00
0005434756274	9552	Economy	10900.00
0005434756280	9552	Economy	10900.00
0005434756278	9552	Economy	10900.00
0005434756248	9552	Economy	10900.00
0005434214056	9552	Economy	10900.00
0005434214023	9552	Economy	10900.00
0005434214022	9552	Economy	10900.00
0005434213937	9552	Economy	10900.00
0005434214055	9552	Economy	10900.00
0005434213940	9552	Economy	10900.00
0005434213794	9552	Economy	10900.00
0005434756271	9552	Economy	10900.00
0005434756273	9552	Economy	10900.00
0005434214032	9552	Economy	10900.00
0005434756256	9552	Economy	10900.00
0005434213836	9552	Economy	10900.00
0005434213825	9552	Economy	10900.00
0005434756269	9552	Economy	10900.00
0005434756254	9552	Economy	10900.00
0005434213801	9552	Economy	10900.00
0005434756247	9552	Economy	10900.00
0005434756284	9552	Economy	10900.00
0005434214021	9552	Economy	10900.00
0005434214088	9552	Economy	10900.00
0005434756279	9552	Economy	10900.00
0005434756263	9552	Economy	10900.00
0005434213945	9552	Economy	10900.00
0005434213974	9552	Economy	10900.00
0005434213912	9552	Economy	10900.00
0005434213887	9552	Economy	10900.00
0005434213975	9552	Economy	10900.00
0005434213888	9552	Economy	10900.00
0005434756266	9552	Economy	10900.00
0005434756283	9552	Economy	10900.00
0005434756242	9552	Economy	10900.00
0005434756253	9552	Economy	10900.00
0005434213816	9552	Economy	10900.00
0005434756240	9552	Economy	10900.00
0005434756251	9552	Economy	10900.00
0005434214031	9552	Economy	10900.00
0005434756234	9552	Economy	10900.00
0005434756252	9552	Economy	10900.00
0005434213989	9552	Economy	10900.00
0005434756286	9552	Economy	10900.00
0005434213968	9552	Economy	10900.00
0005434213908	9552	Economy	10900.00
0005434756244	9552	Economy	10900.00
0005434756281	9552	Economy	10900.00
0005434756236	9552	Economy	10900.00
0005434755959	28646	Business	32800.00
0005434755825	28646	Business	32800.00
0005434214302	28646	Business	32800.00
0005434755791	28646	Business	32800.00
0005434755890	28646	Business	32800.00
0005434214312	28646	Business	32800.00
0005434755803	28646	Business	32800.00
0005434214301	28646	Business	32800.00
0005434214311	28646	Business	32800.00
0005434755967	28646	Business	32800.00
0005434755922	28646	Business	32800.00
0005434755749	28646	Business	32800.00
0005434214308	28646	Economy	10900.00
0005434755958	28646	Economy	10900.00
0005434755919	28646	Economy	10900.00
0005434755752	28646	Economy	10900.00
0005434755850	28646	Economy	10900.00
0005434755767	28646	Economy	10900.00
0005434214281	28646	Economy	10900.00
0005434214298	28646	Economy	10900.00
0005434214313	28646	Economy	10900.00
0005434214304	28646	Economy	12000.00
0005434214287	28646	Economy	12000.00
0005434755968	28646	Economy	12000.00
0005434755849	28646	Economy	12000.00
0005434755721	28646	Economy	12000.00
0005434214271	28646	Economy	10900.00
0005434214293	28646	Economy	10900.00
0005434755753	28646	Economy	10900.00
0005434755794	28646	Economy	10900.00
0005434755793	28646	Economy	10900.00
0005434755891	28646	Economy	10900.00
0005434214315	28646	Economy	10900.00
0005434755720	28646	Economy	10900.00
0005434755806	28646	Economy	10900.00
0005434755960	28646	Economy	10900.00
0005434755802	28646	Economy	10900.00
0005434214289	28646	Economy	10900.00
0005434755718	28646	Economy	10900.00
0005434214309	28646	Economy	10900.00
0005434214286	28646	Economy	10900.00
0005434755906	28646	Economy	10900.00
0005434214295	28646	Economy	10900.00
0005434214296	28646	Economy	10900.00
0005434214294	28646	Economy	10900.00
0005434214300	28646	Economy	10900.00
0005434755863	28646	Economy	10900.00
0005434755857	28646	Economy	10900.00
0005434214276	28646	Economy	10900.00
0005434214299	28646	Economy	10900.00
0005434214273	28646	Economy	10900.00
0005434755852	28646	Economy	10900.00
0005434755837	28646	Economy	10900.00
0005434755988	28646	Economy	10900.00
0005434214310	28646	Economy	10900.00
0005434214279	28646	Economy	10900.00
0005434214316	28646	Economy	10900.00
0005434755734	28646	Economy	10900.00
0005434755710	28646	Economy	10900.00
0005434214278	28646	Economy	10900.00
0005434214291	28646	Economy	10900.00
0005434214283	28646	Economy	10900.00
0005434214285	28646	Economy	10900.00
0005434755887	28646	Economy	10900.00
0005434755735	28646	Economy	10900.00
0005434214288	28646	Economy	10900.00
0005434214275	28646	Economy	10900.00
0005434755856	28646	Economy	10900.00
0005434755864	28646	Economy	10900.00
0005434214306	28646	Economy	10900.00
0005434214290	28646	Economy	10900.00
0005434755779	28646	Economy	10900.00
0005434214297	28646	Economy	10900.00
0005434755824	28646	Economy	10900.00
0005434214284	28646	Economy	10900.00
0005434214272	28646	Economy	10900.00
0005434755830	28646	Economy	10900.00
0005434214282	28646	Economy	10900.00
0005434214307	28646	Economy	10900.00
0005434214277	28646	Economy	10900.00
0005434214314	28646	Economy	10900.00
0005434755840	28646	Economy	10900.00
0005434755954	28646	Economy	10900.00
0005434214292	28646	Economy	10900.00
0005434755780	28646	Economy	10900.00
0005434214270	28646	Economy	10900.00
0005434214269	28646	Economy	10900.00
0005434214305	28646	Economy	10900.00
0005434214280	28646	Economy	10900.00
0005434755942	28646	Economy	10900.00
0005434214303	28646	Economy	10900.00
0005434214274	28646	Economy	10900.00
0005434755831	28646	Economy	10900.00
0005434755905	28646	Economy	10900.00
0005434755807	28646	Economy	10900.00
0005434760156	10807	Economy	8900.00
0005435100111	10807	Economy	8900.00
0005435100110	10807	Economy	8900.00
0005435100078	31801	Economy	9800.00
0005435100086	31801	Economy	8900.00
0005434639221	1972	Economy	20900.00
0005433202144	1972	Economy	20900.00
0005433202162	1972	Economy	20900.00
0005433202206	1972	Economy	20900.00
0005434639228	1972	Economy	19000.00
0005433202187	1972	Economy	19000.00
0005434639234	1972	Economy	19000.00
0005434639231	1972	Economy	19000.00
0005434639222	1972	Economy	19000.00
0005434639223	1972	Economy	19000.00
0005432290621	1972	Economy	19000.00
0005434639227	1972	Economy	19000.00
0005433202154	1972	Economy	19000.00
0005434639236	1972	Economy	19000.00
0005433202238	1972	Economy	19000.00
0005434639226	1972	Economy	19000.00
0005433202145	1972	Economy	19000.00
0005432290620	1972	Economy	19000.00
0005433202155	1972	Economy	19000.00
0005434639220	1972	Economy	19000.00
0005433202161	1972	Economy	19000.00
0005433202148	1972	Economy	19000.00
0005434639216	1972	Economy	19000.00
0005434639229	1972	Economy	19000.00
0005434639215	1972	Economy	19000.00
0005434639214	1972	Economy	19000.00
0005432290622	1972	Economy	19000.00
0005434639235	1972	Economy	19000.00
0005434639211	1972	Economy	19000.00
0005434639213	1972	Economy	19000.00
0005433202147	1972	Economy	19000.00
0005434639225	1972	Economy	19000.00
0005433202212	1972	Economy	19000.00
0005434639212	1972	Economy	19000.00
0005433202170	1972	Economy	19000.00
0005433202211	1972	Economy	19000.00
0005434639230	1972	Economy	19000.00
0005433202215	1972	Economy	19000.00
0005434639233	1972	Economy	19000.00
0005433202189	1972	Economy	19000.00
0005434639217	1972	Economy	19000.00
0005434639232	1972	Economy	19000.00
0005433202237	1972	Economy	19000.00
0005433202213	1972	Economy	19000.00
0005434639224	1972	Economy	19000.00
0005433202188	1972	Economy	19000.00
0005434639218	1972	Economy	19000.00
0005434639237	1972	Economy	19000.00
0005434639219	1972	Economy	19000.00
0005434639046	23252	Economy	20900.00
0005433202289	23252	Economy	20900.00
0005433202290	23252	Economy	20900.00
0005433202286	23252	Economy	19000.00
0005434638884	23252	Economy	19000.00
0005433202288	23252	Economy	19000.00
0005434638883	23252	Economy	19000.00
0005434638998	23252	Economy	19000.00
0005434639052	23252	Economy	19000.00
0005433202294	23252	Economy	19000.00
0005433202283	23252	Economy	19000.00
0005434639056	23252	Economy	19000.00
0005435948304	23252	Economy	19000.00
0005434639021	23252	Economy	19000.00
0005433202284	23252	Economy	19000.00
0005434639035	23252	Economy	19000.00
0005433202296	23252	Economy	19000.00
0005434638902	23252	Economy	19000.00
0005433202293	23252	Economy	19000.00
0005435948310	23252	Economy	19000.00
0005434639016	23252	Economy	19000.00
0005434638897	23252	Economy	19000.00
0005434639007	23252	Economy	19000.00
0005434638966	23252	Economy	19000.00
0005433202297	23252	Economy	19000.00
0005434639055	23252	Economy	19000.00
0005434639075	23252	Economy	19000.00
0005434638933	23252	Economy	19000.00
0005434639008	23252	Economy	19000.00
0005434638977	23252	Economy	19000.00
0005434638865	23252	Economy	19000.00
0005434639047	23252	Economy	19000.00
0005435948315	23252	Economy	19000.00
0005434639089	23252	Economy	19000.00
0005434639074	23252	Economy	19000.00
0005433202295	23252	Economy	19000.00
0005433202285	23252	Economy	19000.00
0005433202291	23252	Economy	19000.00
0005434638936	23252	Economy	19000.00
0005434638997	23252	Economy	19000.00
0005434638965	23252	Economy	19000.00
0005434639076	23252	Economy	19000.00
0005433202287	23252	Economy	19000.00
0005433202292	23252	Economy	19000.00
0005434639036	23252	Economy	19000.00
0005434600703	6053	Business	69700.00
0005435326589	6053	Business	69700.00
0005435326573	6053	Business	69700.00
0005433533295	6053	Business	69700.00
0005434600712	6053	Economy	23200.00
0005434600697	6053	Economy	23200.00
0005435326612	6053	Economy	23200.00
0005434600694	6053	Economy	23200.00
0005434600690	6053	Economy	23200.00
0005434600711	6053	Economy	23200.00
0005433533294	6053	Economy	25600.00
0005433533293	6053	Economy	25600.00
0005434600688	6053	Economy	25600.00
0005435326526	6053	Economy	23200.00
0005434600700	6053	Economy	23200.00
0005435326529	6053	Economy	23200.00
0005435326540	6053	Economy	23200.00
0005434600710	6053	Economy	23200.00
0005433533291	6053	Economy	23200.00
0005435326549	6053	Economy	23200.00
0005434600686	6053	Economy	23200.00
0005435326522	6053	Economy	23200.00
0005435326539	6053	Economy	23200.00
0005434600708	6053	Economy	23200.00
0005435326608	6053	Economy	23200.00
0005433531278	6053	Economy	23200.00
0005434600704	6053	Economy	23200.00
0005435326613	6053	Economy	23200.00
0005434600707	6053	Economy	23200.00
0005434600702	6053	Economy	23200.00
0005433533292	6053	Economy	23200.00
0005434600705	6053	Economy	23200.00
0005434600699	6053	Economy	23200.00
0005435326557	6053	Economy	23200.00
0005435326562	6053	Economy	23200.00
0005434600692	6053	Economy	23200.00
0005435326525	6053	Economy	23200.00
0005432111265	6053	Economy	23200.00
0005433531279	6053	Economy	23200.00
0005435326555	6053	Economy	23200.00
0005434600691	6053	Economy	23200.00
0005435326536	6053	Economy	23200.00
0005434600689	6053	Economy	23200.00
0005435326542	6053	Economy	23200.00
0005435326576	6053	Economy	23200.00
0005435326558	6053	Economy	23200.00
0005434600701	6053	Economy	23200.00
0005432111267	6053	Economy	23200.00
0005434600706	6053	Economy	23200.00
0005434600709	6053	Economy	23200.00
0005434600698	6053	Economy	23200.00
0005432111266	6053	Economy	23200.00
0005434600695	6053	Economy	23200.00
0005434600693	6053	Economy	23200.00
0005435326577	6053	Economy	23200.00
0005434600696	6053	Economy	23200.00
0005435326574	6053	Economy	23200.00
0005434600687	6053	Economy	23200.00
0005434600377	18600	Business	69700.00
0005435326693	18600	Business	69700.00
0005434600519	18600	Business	69700.00
0005434600421	18600	Business	69700.00
0005434600543	18600	Economy	23200.00
0005434600481	18600	Economy	23200.00
0005434600511	18600	Economy	23200.00
0005435326694	18600	Economy	23200.00
0005434600467	18600	Economy	23200.00
0005434600545	18600	Economy	25600.00
0005434600544	18600	Economy	25600.00
0005435326682	18600	Economy	25600.00
0005433531244	18600	Economy	23200.00
0005435326687	18600	Economy	23200.00
0005434600378	18600	Economy	23200.00
0005435326695	18600	Economy	23200.00
0005434600431	18600	Economy	23200.00
0005433531243	18600	Economy	23200.00
0005434600506	18600	Economy	23200.00
0005434600404	18600	Economy	23200.00
0005434600336	18600	Economy	23200.00
0005434600581	18600	Economy	23200.00
0005434600459	18600	Economy	23200.00
0005434600565	18600	Economy	23200.00
0005435326690	18600	Economy	23200.00
0005433531237	18600	Economy	23200.00
0005435326692	18600	Economy	23200.00
0005434600451	18600	Economy	23200.00
0005434600399	18600	Economy	23200.00
0005435326683	18600	Economy	23200.00
0005433527202	18600	Economy	23200.00
0005434600505	18600	Economy	23200.00
0005435326691	18600	Economy	23200.00
0005434600379	18600	Economy	23200.00
0005435326685	18600	Economy	23200.00
0005435326681	18600	Economy	23200.00
0005434600376	18600	Economy	23200.00
0005434600533	18600	Economy	23200.00
0005434600500	18600	Economy	23200.00
0005434600418	18600	Economy	23200.00
0005435326686	18600	Economy	23200.00
0005435326684	18600	Economy	23200.00
0005434600460	18600	Economy	23200.00
0005433531230	18600	Economy	23200.00
0005434600403	18600	Economy	23200.00
0005435326689	18600	Economy	23200.00
0005435326688	18600	Economy	23200.00
0005434600337	18600	Economy	23200.00
0005434600499	18600	Economy	23200.00
0005434600381	18600	Economy	23200.00
0005434600502	18600	Economy	23200.00
0005434600520	18600	Economy	23200.00
0005433180844	10654	Business	9100.00
0005434550972	10654	Business	9100.00
0005433180751	10654	Business	9100.00
0005433180824	10654	Business	9100.00
0005434550971	10654	Business	9100.00
0005434550948	10654	Business	9100.00
0005433180791	10654	Business	9100.00
0005434550968	10654	Business	9100.00
0005434550961	10654	Business	9100.00
0005434550947	10654	Business	9100.00
0005434550935	10654	Business	9100.00
0005434550984	10654	Economy	3000.00
0005433180719	10654	Economy	3000.00
0005434550946	10654	Economy	3000.00
0005434550939	10654	Economy	3000.00
0005434550938	10654	Economy	3000.00
0005433180755	10654	Economy	3000.00
0005434550959	10654	Economy	3000.00
0005433180789	10654	Economy	3000.00
0005434550983	10654	Economy	3000.00
0005433180768	10654	Economy	3300.00
0005434550970	10654	Economy	3300.00
0005434550977	10654	Economy	3300.00
0005434550982	10654	Economy	3300.00
0005434550975	10654	Economy	3000.00
0005434550949	10654	Economy	3000.00
0005433180761	10654	Economy	3000.00
0005434550933	10654	Economy	3000.00
0005434550985	10654	Economy	3000.00
0005434550973	10654	Economy	3000.00
0005434550979	10654	Economy	3000.00
0005434550932	10654	Economy	3000.00
0005434550945	10654	Economy	3000.00
0005433180766	10654	Economy	3000.00
0005434550950	10654	Economy	3000.00
0005433180656	10654	Economy	3000.00
0005433180822	10654	Economy	3000.00
0005434550941	10654	Economy	3000.00
0005434550974	10654	Economy	3000.00
0005434550944	10654	Economy	3000.00
0005433180657	10654	Economy	3000.00
0005434550969	10654	Economy	3000.00
0005434550978	10654	Economy	3000.00
0005434550940	10654	Economy	3000.00
0005434550953	10654	Economy	3000.00
0005433180777	10654	Economy	3000.00
0005434558227	10654	Economy	3000.00
0005433180823	10654	Economy	3000.00
0005434550981	10654	Economy	3000.00
0005433180718	10654	Economy	3000.00
0005434550956	10654	Economy	3000.00
0005434550952	10654	Economy	3000.00
0005434550954	10654	Economy	3000.00
0005434550986	10654	Economy	3000.00
0005434550955	10654	Economy	3000.00
0005434550965	10654	Economy	3000.00
0005434550937	10654	Economy	3000.00
0005434550967	10654	Economy	3000.00
0005433180845	10654	Economy	3000.00
0005434550936	10654	Economy	3000.00
0005434558228	10654	Economy	3000.00
0005433180732	10654	Economy	3000.00
0005434550976	10654	Economy	3000.00
0005434550957	10654	Economy	3000.00
0005434550943	10654	Economy	3000.00
0005433180733	10654	Economy	3000.00
0005434550966	10654	Economy	3000.00
0005434550958	10654	Economy	3000.00
0005434550964	10654	Economy	3000.00
0005434550942	10654	Economy	3000.00
0005434554056	10654	Economy	3000.00
0005434554057	10654	Economy	3000.00
0005434550962	10654	Economy	3000.00
0005433180790	10654	Economy	3000.00
0005433180778	10654	Economy	3000.00
0005434550960	10654	Economy	3000.00
0005434550963	10654	Economy	3000.00
0005433180843	10654	Economy	3000.00
0005433180748	10654	Economy	3000.00
0005434550934	10654	Economy	3000.00
0005434554055	10654	Economy	3000.00
0005433180693	10654	Economy	3000.00
0005433180828	10654	Economy	3000.00
0005434550980	10654	Economy	3000.00
0005434550951	10654	Economy	3000.00
0005433181004	27677	Business	9100.00
0005433181009	27677	Business	9100.00
0005433180987	27677	Business	9100.00
0005433180986	27677	Economy	3000.00
0005433180996	27677	Economy	3000.00
0005433180992	27677	Economy	3300.00
0005433180989	27677	Economy	3000.00
0005433181007	27677	Economy	3000.00
0005433180998	27677	Economy	3000.00
0005433181010	27677	Economy	3000.00
0005433180988	27677	Economy	3000.00
0005433180985	27677	Economy	3000.00
0005433180990	27677	Economy	3000.00
0005433181002	27677	Economy	3000.00
0005433180997	27677	Economy	3000.00
0005433180995	27677	Economy	3000.00
0005433181003	27677	Economy	3000.00
0005433180993	27677	Economy	3000.00
0005433181001	27677	Economy	3000.00
0005433180991	27677	Economy	3000.00
0005433181006	27677	Economy	3000.00
0005433180994	27677	Economy	3000.00
0005433180999	27677	Economy	3000.00
0005433181005	27677	Economy	3000.00
0005433181000	27677	Economy	3000.00
0005433181008	27677	Economy	3000.00
0005434550452	27676	Business	9100.00
0005434550356	27676	Business	9100.00
0005434550755	27676	Business	9100.00
0005434550610	27676	Business	9100.00
0005434550679	27676	Business	9100.00
0005434558171	27676	Business	9100.00
0005434550467	27676	Business	9100.00
0005434550454	27676	Business	9100.00
0005434550695	27676	Economy	3000.00
0005434550545	27676	Economy	3000.00
0005434550704	27676	Economy	3000.00
0005434550440	27676	Economy	3000.00
0005434550611	27676	Economy	3000.00
0005434550534	27676	Economy	3000.00
0005434550706	27676	Economy	3300.00
0005434550510	27676	Economy	3300.00
0005434550402	27676	Economy	3000.00
0005434550489	27676	Economy	3000.00
0005434550594	27676	Economy	3000.00
0005434558146	27676	Economy	3000.00
0005434554030	27676	Economy	3000.00
0005434550604	27676	Economy	3000.00
0005434550696	27676	Economy	3000.00
0005434550551	27676	Economy	3000.00
0005434550433	27676	Economy	3000.00
0005434550442	27676	Economy	3000.00
0005434550546	27676	Economy	3000.00
0005434558153	27676	Economy	3000.00
0005434550466	27676	Economy	3000.00
0005434550475	27676	Economy	3000.00
0005434550593	27676	Economy	3000.00
0005434550431	27676	Economy	3000.00
0005434550540	27676	Economy	3000.00
0005434550436	27676	Economy	3000.00
0005434550533	27676	Economy	3000.00
0005434550649	27676	Economy	3000.00
0005434550705	27676	Economy	3000.00
0005434550726	27676	Economy	3000.00
0005434550873	27676	Economy	3000.00
0005434550651	27676	Economy	3000.00
0005434550650	27676	Economy	3000.00
0005434558154	27676	Economy	3000.00
0005434550385	27676	Economy	3000.00
0005434558182	27676	Economy	3000.00
0005434558162	27676	Economy	3000.00
0005434550487	27676	Economy	3000.00
0005434550425	27676	Economy	3000.00
0005434550741	27676	Economy	3000.00
0005434558172	27676	Economy	3000.00
0005434550403	27676	Economy	3000.00
0005434550437	27676	Economy	3000.00
0005434550636	27676	Economy	3000.00
0005434550727	27676	Economy	3000.00
0005434550453	27676	Economy	3000.00
0005434558173	27676	Economy	3000.00
0005434558187	27676	Economy	3000.00
0005434550541	27676	Economy	3000.00
0005434550535	27676	Economy	3000.00
0005434550609	27676	Economy	3000.00
0005434558163	27676	Economy	3000.00
0005434550441	27676	Economy	3000.00
0005434550548	27676	Economy	3000.00
0005433459201	6145	Economy	11700.00
0005433459203	6145	Economy	11700.00
0005433459199	6145	Economy	11700.00
0005433459200	6145	Economy	11700.00
0005433459202	6145	Economy	11700.00
0005433459173	19348	Economy	11700.00
0005433459167	19348	Economy	11700.00
0005435254465	19348	Economy	11700.00
0005435254464	19348	Economy	11700.00
0005433459174	19348	Economy	11700.00
0005435254463	19348	Economy	11700.00
0005435681954	6719	Business	51100.00
0005435681979	6719	Business	51100.00
0005435681938	6719	Business	51100.00
0005435437638	6719	Business	51100.00
0005435681948	6719	Business	51100.00
0005435681974	6719	Business	51100.00
0005435437653	6719	Business	51100.00
0005435437795	6719	Business	51100.00
0005435437692	6719	Business	51100.00
0005435681973	6719	Business	51100.00
0005435681978	6719	Business	51100.00
0005435681946	6719	Economy	17000.00
0005435437735	6719	Economy	17000.00
0005435681975	6719	Economy	17000.00
0005435661916	6719	Economy	17000.00
0005435630952	6719	Economy	17000.00
0005435437713	6719	Economy	17000.00
0005435681968	6719	Economy	17000.00
0005435681936	6719	Economy	17000.00
0005435681956	6719	Economy	17000.00
0005435681955	6719	Economy	17000.00
0005435681971	6719	Economy	18700.00
0005432136147	6719	Economy	18700.00
0005435681976	6719	Economy	18700.00
0005435681960	6719	Economy	18700.00
0005432533255	6719	Economy	18700.00
0005435437672	6719	Economy	17000.00
0005435681944	6719	Economy	17000.00
0005435681943	6719	Economy	17000.00
0005432136148	6719	Economy	17000.00
0005435681937	6719	Economy	17000.00
0005435681951	6719	Economy	17000.00
0005435630951	6719	Economy	17000.00
0005435681967	6719	Economy	17000.00
0005435437749	6719	Economy	17000.00
0005435437739	6719	Economy	17000.00
0005435221502	6719	Economy	17000.00
0005435681969	6719	Economy	17000.00
0005435437745	6719	Economy	17000.00
0005435220295	6719	Economy	17000.00
0005435681935	6719	Economy	17000.00
0005435437744	6719	Economy	17000.00
0005435681972	6719	Economy	17000.00
0005435437691	6719	Economy	17000.00
0005435681959	6719	Economy	17000.00
0005434828666	6719	Economy	17000.00
0005435681947	6719	Economy	17000.00
0005432533251	6719	Economy	17000.00
0005435437714	6719	Economy	17000.00
0005435681939	6719	Economy	17000.00
0005435719565	6719	Economy	17000.00
0005435437677	6719	Economy	17000.00
0005432136146	6719	Economy	17000.00
0005435437750	6719	Economy	17000.00
0005435681941	6719	Economy	17000.00
0005435681965	6719	Economy	17000.00
0005435681961	6719	Economy	17000.00
0005435681963	6719	Economy	17000.00
0005435681966	6719	Economy	17000.00
0005435681977	6719	Economy	17000.00
0005432136150	6719	Economy	17000.00
0005435681934	6719	Economy	17000.00
0005435221501	6719	Economy	17000.00
0005435681940	6719	Economy	17000.00
0005435681964	6719	Economy	17000.00
0005432533249	6719	Economy	17000.00
0005435681958	6719	Economy	17000.00
0005435437676	6719	Economy	17000.00
0005435437651	6719	Economy	17000.00
0005435630953	6719	Economy	17000.00
0005435681957	6719	Economy	17000.00
0005432136145	6719	Economy	17000.00
0005435221503	6719	Economy	17000.00
0005435661915	6719	Economy	17000.00
0005435681953	6719	Economy	17000.00
0005435437652	6719	Economy	17000.00
0005435681942	6719	Economy	17000.00
0005435437671	6719	Economy	17000.00
0005435681945	6719	Economy	17000.00
0005435630954	6719	Economy	17000.00
0005435661917	6719	Economy	17000.00
0005432533247	6719	Economy	17000.00
0005435681962	6719	Economy	17000.00
0005432533248	6719	Economy	17000.00
0005435681949	6719	Economy	17000.00
0005435681970	6719	Economy	17000.00
0005432136149	6719	Economy	17000.00
0005435681952	6719	Economy	17000.00
0005435681950	6719	Economy	17000.00
0005435630950	6719	Economy	17000.00
0005435437706	6719	Economy	17000.00
0005432305738	24610	Business	51100.00
0005435681609	24610	Business	51100.00
0005435681635	24610	Business	51100.00
0005435681407	24610	Business	51100.00
0005432305739	24610	Business	51100.00
0005435681628	24610	Business	51100.00
0005435681595	24610	Business	51100.00
0005435681615	24610	Business	51100.00
0005435681718	24610	Business	51100.00
0005435681482	24610	Business	51100.00
0005435437854	24610	Business	51100.00
0005435681578	24610	Business	51100.00
0005435681386	24610	Economy	17000.00
0005435437850	24610	Economy	17000.00
0005435681496	24610	Economy	17000.00
0005435681579	24610	Economy	17000.00
0005435681608	24610	Economy	17000.00
0005435681637	24610	Economy	17000.00
0005435437851	24610	Economy	17000.00
0005435681570	24610	Economy	17000.00
0005435681456	24610	Economy	17000.00
0005435437864	24610	Economy	17000.00
0005435681519	24610	Economy	18700.00
0005435681738	24610	Economy	18700.00
0005435661898	24610	Economy	18700.00
0005434828687	24610	Economy	18700.00
0005435681602	24610	Economy	18700.00
0005435681707	24610	Economy	17000.00
0005435681629	24610	Economy	17000.00
0005435437855	24610	Economy	17000.00
0005435437856	24610	Economy	17000.00
0005432533281	24610	Economy	17000.00
0005435681477	24610	Economy	17000.00
0005435437863	24610	Economy	17000.00
0005435437857	24610	Economy	17000.00
0005435681713	24610	Economy	17000.00
0005435437849	24610	Economy	17000.00
0005434828685	24610	Economy	17000.00
0005435437865	24610	Economy	17000.00
0005435681487	24610	Economy	17000.00
0005435437869	24610	Economy	17000.00
0005435681649	24610	Economy	17000.00
0005435437848	24610	Economy	17000.00
0005435437868	24610	Economy	17000.00
0005435681684	24610	Economy	17000.00
0005435681478	24610	Economy	17000.00
0005435681714	24610	Economy	17000.00
0005435437858	24610	Economy	17000.00
0005435681625	24610	Economy	17000.00
0005435681689	24610	Economy	17000.00
0005435681676	24610	Economy	17000.00
0005435681498	24610	Economy	17000.00
0005435681596	24610	Economy	17000.00
0005435681638	24610	Economy	17000.00
0005435681417	24610	Economy	17000.00
0005435681706	24610	Economy	17000.00
0005432533280	24610	Economy	17000.00
0005435681600	24610	Economy	17000.00
0005435681673	24610	Economy	17000.00
0005435681576	24610	Economy	17000.00
0005435681520	24610	Economy	17000.00
0005435681466	24610	Economy	17000.00
0005435681503	24610	Economy	17000.00
0005435681397	24610	Economy	17000.00
0005435437860	24610	Economy	17000.00
0005435681447	24610	Economy	17000.00
0005435681613	24610	Economy	17000.00
0005435681500	24610	Economy	17000.00
0005435437853	24610	Economy	17000.00
0005435681597	24610	Economy	17000.00
0005435681614	24610	Economy	17000.00
0005435437861	24610	Economy	17000.00
0005434828686	24610	Economy	17000.00
0005435681717	24610	Economy	17000.00
0005435681681	24610	Economy	17000.00
0005435681497	24610	Economy	17000.00
0005435630923	24610	Economy	17000.00
0005435630920	24610	Economy	17000.00
0005435437859	24610	Economy	17000.00
0005435681594	24610	Economy	17000.00
0005435681690	24610	Economy	17000.00
0005435681610	24610	Economy	17000.00
0005435681418	24610	Economy	17000.00
0005435681669	24610	Economy	17000.00
0005435437866	24610	Economy	17000.00
0005435681491	24610	Economy	17000.00
0005435437867	24610	Economy	17000.00
0005435681675	24610	Economy	17000.00
0005435437862	24610	Economy	17000.00
0005435681495	24610	Economy	17000.00
0005435661899	24610	Economy	17000.00
0005435681584	24610	Economy	17000.00
0005435681528	24610	Economy	17000.00
0005435437852	24610	Economy	17000.00
0005435681567	24610	Economy	17000.00
0005435630933	24610	Economy	17000.00
0005435681616	24610	Economy	17000.00
0005435126174	11557	Business	26400.00
0005435126157	11557	Business	26400.00
0005435126151	11557	Business	26400.00
0005435105965	11557	Economy	8800.00
0005435126169	11557	Economy	8800.00
0005435126156	11557	Economy	8800.00
0005435126184	11557	Economy	9700.00
0005435126163	11557	Economy	9700.00
0005435126159	11557	Economy	9700.00
0005435126153	11557	Economy	8800.00
0005435126179	11557	Economy	8800.00
0005435126182	11557	Economy	8800.00
0005435126165	11557	Economy	8800.00
0005435126180	11557	Economy	8800.00
0005435126152	11557	Economy	8800.00
0005435126172	11557	Economy	8800.00
0005435126158	11557	Economy	8800.00
0005435126164	11557	Economy	8800.00
0005435126161	11557	Economy	8800.00
0005435126175	11557	Economy	8800.00
0005435126150	11557	Economy	8800.00
0005435126177	11557	Economy	8800.00
0005435126170	11557	Economy	8800.00
0005435126185	11557	Economy	8800.00
0005435126166	11557	Economy	8800.00
0005435126171	11557	Economy	8800.00
0005435105966	11557	Economy	8800.00
0005435126181	11557	Economy	8800.00
0005435126176	11557	Economy	8800.00
0005435126187	11557	Economy	8800.00
0005435126186	11557	Economy	8800.00
0005435126149	11557	Economy	8800.00
0005435126160	11557	Economy	8800.00
0005435126183	11557	Economy	8800.00
0005435126168	11557	Economy	8800.00
0005435126154	11557	Economy	8800.00
0005435105967	11557	Economy	8800.00
0005435126173	11557	Economy	8800.00
0005435126162	11557	Economy	8800.00
0005435126155	11557	Economy	8800.00
0005435126178	11557	Economy	8800.00
0005435126167	11557	Economy	8800.00
0005435125790	31884	Business	26400.00
0005435558074	31884	Business	26400.00
0005435558077	31884	Business	26400.00
0005435126021	31884	Business	26400.00
0005435125881	31884	Economy	8800.00
0005435105944	31884	Economy	8800.00
0005435125915	31884	Economy	8800.00
0005435098529	31884	Economy	8800.00
0005435125714	31884	Economy	9700.00
0005435125909	31884	Economy	8800.00
0005435125929	31884	Economy	8800.00
0005435125886	31884	Economy	8800.00
0005435125833	31884	Economy	8800.00
0005435558076	31884	Economy	8800.00
0005435125890	31884	Economy	8800.00
0005435125813	31884	Economy	8800.00
0005435125853	31884	Economy	8800.00
0005435125879	31884	Economy	8800.00
0005435125887	31884	Economy	8800.00
0005435125857	31884	Economy	8800.00
0005435125914	31884	Economy	8800.00
0005435125854	31884	Economy	8800.00
0005435125839	31884	Economy	8800.00
0005435125855	31884	Economy	8800.00
0005435125840	31884	Economy	8800.00
0005435125889	31884	Economy	8800.00
0005435125991	31884	Economy	8800.00
0005435125856	31884	Economy	8800.00
0005435125812	31884	Economy	8800.00
0005435125845	31884	Economy	8800.00
0005435125908	31884	Economy	8800.00
0005435558075	31884	Economy	8800.00
0005435732256	13563	Business	36600.00
0005433397862	13563	Business	36600.00
0005433397842	13563	Business	36600.00
0005433397855	13563	Business	36600.00
0005433397839	13563	Business	36600.00
0005433397854	13563	Business	36600.00
0005433397838	13563	Business	36600.00
0005435732155	13563	Business	36600.00
0005433397831	13563	Business	36600.00
0005433397830	13563	Business	36600.00
0005433397845	13563	Economy	12200.00
0005433397841	13563	Economy	12200.00
0005433397835	13563	Economy	12200.00
0005433397865	13563	Economy	12200.00
0005433397826	13563	Economy	13400.00
0005433397873	13563	Economy	13400.00
0005433397858	13563	Economy	13400.00
0005433397869	13563	Economy	12200.00
0005435732133	13563	Economy	12200.00
0005435732164	13563	Economy	12200.00
0005433397848	13563	Economy	12200.00
0005433397870	13563	Economy	12200.00
0005433397867	13563	Economy	12200.00
0005433397871	13563	Economy	12200.00
0005433397863	13563	Economy	12200.00
0005433397834	13563	Economy	12200.00
0005433397853	13563	Economy	12200.00
0005433397872	13563	Economy	12200.00
0005433397866	13563	Economy	12200.00
0005435732204	13563	Economy	12200.00
0005433397832	13563	Economy	12200.00
0005435732129	13563	Economy	12200.00
0005433397847	13563	Economy	12200.00
0005433397843	13563	Economy	12200.00
0005433397861	13563	Economy	12200.00
0005435732255	13563	Economy	12200.00
0005433397857	13563	Economy	12200.00
0005433397868	13563	Economy	12200.00
0005433397827	13563	Economy	12200.00
0005433397856	13563	Economy	12200.00
0005435732170	13563	Economy	12200.00
0005433397859	13563	Economy	12200.00
0005435732165	13563	Economy	12200.00
0005433397844	13563	Economy	12200.00
0005433397851	13563	Economy	12200.00
0005433397860	13563	Economy	12200.00
0005433397833	13563	Economy	12200.00
0005433397829	13563	Economy	12200.00
0005435732178	13563	Economy	12200.00
0005435732175	13563	Economy	12200.00
0005433397846	13563	Economy	12200.00
0005433397837	13563	Economy	12200.00
0005435732187	13563	Economy	12200.00
0005433397840	13563	Economy	12200.00
0005435732171	13563	Economy	12200.00
0005433397836	13563	Economy	12200.00
0005433397850	13563	Economy	12200.00
0005435732177	13563	Economy	12200.00
0005435732119	13563	Economy	12200.00
0005433397828	13563	Economy	12200.00
0005433397864	13563	Economy	12200.00
0005433397849	13563	Economy	12200.00
0005433397852	13563	Economy	12200.00
0005435732176	13563	Economy	12200.00
0005433397506	19401	Business	36600.00
0005435732287	19401	Business	36600.00
0005433397518	19401	Business	36600.00
0005433397373	19401	Business	36600.00
0005433397324	19401	Business	36600.00
0005433397242	19401	Business	36600.00
0005432297265	19401	Business	36600.00
0005433397238	19401	Business	36600.00
0005433397517	19401	Economy	12200.00
0005433397343	19401	Economy	12200.00
0005433397422	19401	Economy	12200.00
0005433397487	19401	Economy	12200.00
0005433397416	19401	Economy	12200.00
0005433397565	19401	Economy	12200.00
0005433397241	19401	Economy	12200.00
0005433397335	19401	Economy	13400.00
0005433397550	19401	Economy	13400.00
0005433397336	19401	Economy	13400.00
0005432297266	19401	Economy	12200.00
0005433397189	19401	Economy	12200.00
0005433397268	19401	Economy	12200.00
0005433397368	19401	Economy	12200.00
0005433397426	19401	Economy	12200.00
0005432297267	19401	Economy	12200.00
0005433397338	19401	Economy	12200.00
0005433397428	19401	Economy	12200.00
0005433397339	19401	Economy	12200.00
0005433397507	19401	Economy	12200.00
0005435732282	19401	Economy	12200.00
0005433397421	19401	Economy	12200.00
0005433397446	19401	Economy	12200.00
0005433397359	19401	Economy	12200.00
0005435732292	19401	Economy	12200.00
0005433397501	19401	Economy	12200.00
0005433397474	19401	Economy	12200.00
0005433397370	19401	Economy	12200.00
0005433397267	19401	Economy	12200.00
0005435732290	19401	Economy	12200.00
0005435732288	19401	Economy	12200.00
0005435732284	19401	Economy	12200.00
0005433397573	19401	Economy	12200.00
0005433397476	19401	Economy	12200.00
0005433397445	19401	Economy	12200.00
0005433397309	19401	Economy	12200.00
0005433397593	19401	Economy	12200.00
0005435732285	19401	Economy	12200.00
0005433397334	19401	Economy	12200.00
0005433397395	19401	Economy	12200.00
0005433397502	19401	Economy	12200.00
0005433397414	19401	Economy	12200.00
0005433397455	19401	Economy	12200.00
0005433397562	19401	Economy	12200.00
0005433397485	19401	Economy	12200.00
0005433397394	19401	Economy	12200.00
0005433397369	19401	Economy	12200.00
0005435732291	19401	Economy	12200.00
0005435732286	19401	Economy	12200.00
0005433397372	19401	Economy	12200.00
0005433397382	19401	Economy	12200.00
0005435732283	19401	Economy	12200.00
0005433397415	19401	Economy	12200.00
0005433397441	19401	Economy	12200.00
0005433397371	19401	Economy	12200.00
0005435732289	19401	Economy	12200.00
0005433397427	19401	Economy	12200.00
0005435068471	13183	Business	11300.00
0005435068537	13183	Business	11300.00
0005435068268	13183	Business	11300.00
0005435068409	13183	Business	11300.00
0005435925229	13183	Business	11300.00
0005435068269	13183	Business	11300.00
0005435068496	13183	Business	11300.00
0005435068404	13183	Business	11300.00
0005435925226	13183	Business	11300.00
0005435068239	13183	Economy	3800.00
0005435068499	13183	Economy	3800.00
0005435068252	13183	Economy	3800.00
0005435925219	13183	Economy	3800.00
0005435068310	13183	Economy	3800.00
0005435068405	13183	Economy	3800.00
0005435925221	13183	Economy	3800.00
0005435068526	13183	Economy	3800.00
0005435068440	13183	Economy	4100.00
0005435925237	13183	Economy	4100.00
0005435068497	13183	Economy	4100.00
0005435925230	13183	Economy	3800.00
0005435068263	13183	Economy	3800.00
0005435068428	13183	Economy	3800.00
0005435068381	13183	Economy	3800.00
0005435068270	13183	Economy	3800.00
0005435068335	13183	Economy	3800.00
0005435068498	13183	Economy	3800.00
0005435068350	13183	Economy	3800.00
0005435925239	13183	Economy	3800.00
0005435925242	13183	Economy	3800.00
0005435068212	13183	Economy	3800.00
0005435068429	13183	Economy	3800.00
0005435068334	13183	Economy	3800.00
0005435925220	13183	Economy	3800.00
0005435068265	13183	Economy	3800.00
0005435068361	13183	Economy	3800.00
0005435068272	13183	Economy	3800.00
0005435925232	13183	Economy	3800.00
0005435925224	13183	Economy	3800.00
0005435925227	13183	Economy	3800.00
0005435925240	13183	Economy	3800.00
0005435068495	13183	Economy	3800.00
0005435925223	13183	Economy	3800.00
0005435068343	13183	Economy	3800.00
0005435068169	13183	Economy	3800.00
0005435925243	13183	Economy	3800.00
0005435068271	13183	Economy	3800.00
0005435068371	13183	Economy	3800.00
0005435925225	13183	Economy	3800.00
0005435068446	13183	Economy	3800.00
0005435925241	13183	Economy	3800.00
0005435925234	13183	Economy	3800.00
0005435068448	13183	Economy	3800.00
0005435068362	13183	Economy	3800.00
0005435068581	13183	Economy	3800.00
0005435068447	13183	Economy	3800.00
0005435925236	13183	Economy	3800.00
0005435925228	13183	Economy	3800.00
0005435068221	13183	Economy	3800.00
0005435068438	13183	Economy	3800.00
0005435925235	13183	Economy	3800.00
0005435068311	13183	Economy	3800.00
0005435068538	13183	Economy	3800.00
0005435925222	13183	Economy	3800.00
0005435068251	13183	Economy	3800.00
0005435925233	13183	Economy	3800.00
0005435925238	13183	Economy	3800.00
0005435068536	13183	Economy	3800.00
0005435925231	13183	Economy	3800.00
0005435068488	13183	Economy	3800.00
0005435068406	13183	Economy	3800.00
0005435068435	13183	Economy	3800.00
0005435068489	13183	Economy	3800.00
0005435068825	15482	Business	11300.00
0005435068822	15482	Business	11300.00
0005435068834	15482	Business	11300.00
0005435068830	15482	Business	11300.00
0005435925058	15482	Business	11300.00
0005435068823	15482	Business	11300.00
0005435068843	15482	Business	11300.00
0005435068798	15482	Business	11300.00
0005435068819	15482	Business	11300.00
0005435068829	15482	Business	11300.00
0005435068814	15482	Economy	3800.00
0005435068836	15482	Economy	3800.00
0005435068804	15482	Economy	3800.00
0005435068821	15482	Economy	3800.00
0005435925122	15482	Economy	3800.00
0005435925084	15482	Economy	3800.00
0005435068815	15482	Economy	3800.00
0005435068832	15482	Economy	4100.00
0005435068794	15482	Economy	4100.00
0005435068845	15482	Economy	3800.00
0005435068826	15482	Economy	3800.00
0005435925057	15482	Economy	3800.00
0005435068841	15482	Economy	3800.00
0005435068803	15482	Economy	3800.00
0005435068817	15482	Economy	3800.00
0005435068807	15482	Economy	3800.00
0005435925112	15482	Economy	3800.00
0005435068837	15482	Economy	3800.00
0005435925087	15482	Economy	3800.00
0005435068842	15482	Economy	3800.00
0005435068808	15482	Economy	3800.00
0005435068844	15482	Economy	3800.00
0005435068846	15482	Economy	3800.00
0005435068799	15482	Economy	3800.00
0005435068806	15482	Economy	3800.00
0005435068838	15482	Economy	3800.00
0005435925116	15482	Economy	3800.00
0005435068805	15482	Economy	3800.00
0005435068796	15482	Economy	3800.00
0005435068818	15482	Economy	3800.00
0005435925117	15482	Economy	3800.00
0005435068828	15482	Economy	3800.00
0005435068827	15482	Economy	3800.00
0005435068795	15482	Economy	3800.00
0005435068824	15482	Economy	3800.00
0005435925079	15482	Economy	3800.00
0005435068810	15482	Economy	3800.00
0005435068816	15482	Economy	3800.00
0005435068802	15482	Economy	3800.00
0005435925083	15482	Economy	3800.00
0005435068831	15482	Economy	3800.00
0005435068833	15482	Economy	3800.00
0005435068809	15482	Economy	3800.00
0005435925078	15482	Economy	3800.00
0005435925113	15482	Economy	3800.00
0005435068811	15482	Economy	3800.00
0005435068800	15482	Economy	3800.00
0005435068812	15482	Economy	3800.00
0005435068820	15482	Economy	3800.00
0005435068801	15482	Economy	3800.00
0005435068797	15482	Economy	3800.00
0005435068840	15482	Economy	3800.00
0005435068839	15482	Economy	3800.00
0005435068813	15482	Economy	3800.00
0005435068835	15482	Economy	3800.00
0005435808181	23174	Economy	27100.00
0005435808182	23174	Economy	27100.00
0005435808160	23174	Economy	27100.00
0005435808186	23174	Economy	24700.00
0005433407487	23174	Economy	24700.00
0005433407479	23174	Economy	24700.00
0005435808178	23174	Economy	24700.00
0005435808173	23174	Economy	24700.00
0005435808171	23174	Economy	24700.00
0005435808156	23174	Economy	24700.00
0005435808167	23174	Economy	24700.00
0005433407490	23174	Economy	24700.00
0005435808165	23174	Economy	24700.00
0005435808163	23174	Economy	24700.00
0005435808170	23174	Economy	24700.00
0005435808164	23174	Economy	24700.00
0005433407481	23174	Economy	24700.00
0005435808175	23174	Economy	24700.00
0005435808185	23174	Economy	24700.00
0005435808176	23174	Economy	24700.00
0005435808184	23174	Economy	24700.00
0005435808183	23174	Economy	24700.00
0005435808174	23174	Economy	24700.00
0005435808179	23174	Economy	24700.00
0005435808169	23174	Economy	24700.00
0005435808177	23174	Economy	24700.00
0005433407478	23174	Economy	24700.00
0005435808187	23174	Economy	24700.00
0005435808157	23174	Economy	24700.00
0005433407488	23174	Economy	24700.00
0005433407494	23174	Economy	24700.00
0005435808166	23174	Economy	24700.00
0005433407489	23174	Economy	24700.00
0005433407502	23174	Economy	24700.00
0005435808168	23174	Economy	24700.00
0005435808159	23174	Economy	24700.00
0005435808180	23174	Economy	24700.00
0005435808161	23174	Economy	24700.00
0005435808162	23174	Economy	24700.00
0005433407486	23174	Economy	24700.00
0005435808158	23174	Economy	24700.00
0005435808172	23174	Economy	24700.00
0005434214329	10728	Business	61300.00
0005434755918	10728	Business	61300.00
0005434214333	10728	Business	61300.00
0005434755867	10728	Business	61300.00
0005434755851	10728	Business	61300.00
0005434214352	10728	Business	61300.00
0005434755935	10728	Business	61300.00
0005434755847	10728	Business	61300.00
0005434755936	10728	Business	61300.00
0005434214346	10728	Business	61300.00
0005434755789	10728	Business	61300.00
0005434755901	10728	Business	61300.00
0005434214354	10728	Economy	20400.00
0005434214327	10728	Economy	20400.00
0005434755841	10728	Economy	20400.00
0005434214319	10728	Economy	20400.00
0005434755716	10728	Economy	20400.00
0005434214317	10728	Economy	20400.00
0005434214351	10728	Economy	20400.00
0005434755775	10728	Economy	20400.00
0005434756018	10728	Economy	20400.00
0005434214348	10728	Economy	20400.00
0005434755784	10728	Economy	22500.00
0005434214343	10728	Economy	22500.00
0005434214335	10728	Economy	22500.00
0005434755917	10728	Economy	22500.00
0005434755774	10728	Economy	22500.00
0005434214340	10728	Economy	20400.00
0005434214336	10728	Economy	20400.00
0005434755911	10728	Economy	20400.00
0005434214337	10728	Economy	20400.00
0005434755827	10728	Economy	20400.00
0005434214339	10728	Economy	20400.00
0005434214357	10728	Economy	20400.00
0005434214362	10728	Economy	20400.00
0005434755848	10728	Economy	20400.00
0005434756028	10728	Economy	20400.00
0005434755715	10728	Economy	20400.00
0005434214326	10728	Economy	20400.00
0005434214325	10728	Economy	20400.00
0005434214338	10728	Economy	20400.00
0005434755965	10728	Economy	20400.00
0005434214324	10728	Economy	20400.00
0005434214359	10728	Economy	20400.00
0005434214347	10728	Economy	20400.00
0005434214345	10728	Economy	20400.00
0005434214320	10728	Economy	20400.00
0005434214332	10728	Economy	20400.00
0005434214322	10728	Economy	20400.00
0005434755751	10728	Economy	20400.00
0005434755877	10728	Economy	20400.00
0005434214349	10728	Economy	20400.00
0005434214330	10728	Economy	20400.00
0005434214334	10728	Economy	20400.00
0005434755788	10728	Economy	20400.00
0005434214361	10728	Economy	20400.00
0005434755986	10728	Economy	20400.00
0005434214341	10728	Economy	20400.00
0005434755714	10728	Economy	20400.00
0005434755957	10728	Economy	20400.00
0005434755999	10728	Economy	20400.00
0005434755828	10728	Economy	20400.00
0005434755842	10728	Economy	20400.00
0005434214318	10728	Economy	20400.00
0005434214321	10728	Economy	20400.00
0005434755713	10728	Economy	20400.00
0005434755886	10728	Economy	20400.00
0005434755826	10728	Economy	20400.00
0005434214342	10728	Economy	20400.00
0005434214350	10728	Economy	20400.00
0005434214360	10728	Economy	20400.00
0005434214331	10728	Economy	20400.00
0005434755805	10728	Economy	20400.00
0005434214323	10728	Economy	20400.00
0005434755744	10728	Economy	20400.00
0005434214344	10728	Economy	20400.00
0005434756019	10728	Economy	20400.00
0005434755745	10728	Economy	20400.00
0005434755785	10728	Economy	20400.00
0005434755821	10728	Economy	20400.00
0005434756015	10728	Economy	20400.00
0005434214363	10728	Economy	20400.00
0005434755885	10728	Economy	20400.00
0005434755804	10728	Economy	20400.00
0005434214355	10728	Economy	20400.00
0005434214328	10728	Economy	20400.00
0005434755832	10728	Economy	20400.00
0005434755998	10728	Economy	20400.00
0005434214353	10728	Economy	20400.00
0005434755995	10728	Economy	20400.00
0005434214358	10728	Economy	20400.00
0005434214356	10728	Economy	20400.00
0005434213948	28682	Business	61300.00
0005434214014	28682	Business	61300.00
0005434213867	28682	Business	61300.00
0005434213910	28682	Business	61300.00
0005434213760	28682	Business	61300.00
0005434756217	28682	Business	61300.00
0005434756202	28682	Business	61300.00
0005434756203	28682	Business	61300.00
0005434214084	28682	Business	61300.00
0005434213999	28682	Business	61300.00
0005434756230	28682	Business	61300.00
0005434213761	28682	Business	61300.00
0005434756226	28682	Economy	20400.00
0005434756221	28682	Economy	20400.00
0005434214015	28682	Economy	20400.00
0005434213859	28682	Economy	20400.00
0005434213895	28682	Economy	20400.00
0005434213904	28682	Economy	20400.00
0005434213804	28682	Economy	20400.00
0005434213839	28682	Economy	20400.00
0005434213719	28682	Economy	22500.00
0005434213720	28682	Economy	22500.00
0005434213812	28682	Economy	22500.00
0005434214003	28682	Economy	22500.00
0005434213837	28682	Economy	20400.00
0005434214106	28682	Economy	20400.00
0005434213963	28682	Economy	20400.00
0005434213858	28682	Economy	20400.00
0005434213997	28682	Economy	20400.00
0005434213821	28682	Economy	20400.00
0005434756227	28682	Economy	20400.00
0005434756231	28682	Economy	20400.00
0005434213802	28682	Economy	20400.00
0005434213896	28682	Economy	20400.00
0005434756211	28682	Economy	20400.00
0005434213779	28682	Economy	20400.00
0005434756210	28682	Economy	20400.00
0005434213762	28682	Economy	20400.00
0005434213795	28682	Economy	20400.00
0005434213877	28682	Economy	20400.00
0005434213893	28682	Economy	20400.00
0005434756223	28682	Economy	20400.00
0005434213790	28682	Economy	20400.00
0005434213905	28682	Economy	20400.00
0005434756209	28682	Economy	20400.00
0005434213842	28682	Economy	20400.00
0005434756204	28682	Economy	20400.00
0005434756205	28682	Economy	20400.00
0005434756224	28682	Economy	20400.00
0005434213909	28682	Economy	20400.00
0005434213818	28682	Economy	20400.00
0005434756220	28682	Economy	20400.00
0005434756206	28682	Economy	20400.00
0005434756212	28682	Economy	20400.00
0005434756218	28682	Economy	20400.00
0005434756216	28682	Economy	20400.00
0005434756228	28682	Economy	20400.00
0005434756213	28682	Economy	20400.00
0005434756232	28682	Economy	20400.00
0005434756214	28682	Economy	20400.00
0005434213759	28682	Economy	20400.00
0005434756222	28682	Economy	20400.00
0005434213964	28682	Economy	20400.00
0005434213861	28682	Economy	20400.00
0005434756207	28682	Economy	20400.00
0005434756233	28682	Economy	20400.00
0005434756225	28682	Economy	20400.00
0005434213820	28682	Economy	20400.00
0005434213966	28682	Economy	20400.00
0005434213894	28682	Economy	20400.00
0005434213838	28682	Economy	20400.00
0005434214048	28682	Economy	20400.00
0005434214016	28682	Economy	20400.00
0005434756208	28682	Economy	20400.00
0005434213773	28682	Economy	20400.00
0005434213965	28682	Economy	20400.00
0005434756215	28682	Economy	20400.00
0005434213868	28682	Economy	20400.00
0005434213918	28682	Economy	20400.00
0005434756219	28682	Economy	20400.00
0005434756229	28682	Economy	20400.00
0005434213996	28682	Economy	20400.00
0005434213803	28682	Economy	20400.00
0005434213919	28682	Economy	20400.00
0005435039482	5452	Business	29500.00
0005435006926	5452	Business	29500.00
0005435039529	5452	Business	29500.00
0005432125421	5452	Business	29500.00
0005435039495	5452	Business	29500.00
0005434228974	5452	Business	29500.00
0005435039526	5452	Business	29500.00
0005435039505	5452	Business	29500.00
0005435039525	5452	Business	29500.00
0005435006931	5452	Business	29500.00
0005435006941	5452	Business	29500.00
0005435039473	5452	Business	29500.00
0005435039494	5452	Economy	9800.00
0005435039527	5452	Economy	9800.00
0005435039511	5452	Economy	9800.00
0005435006920	5452	Economy	9800.00
0005435039470	5452	Economy	9800.00
0005435006936	5452	Economy	9800.00
0005435039514	5452	Economy	9800.00
0005435006922	5452	Economy	9800.00
0005435006929	5452	Economy	9800.00
0005435039528	5452	Economy	9800.00
0005435039503	5452	Economy	9800.00
0005435039512	5452	Economy	9800.00
0005435039472	5452	Economy	9800.00
0005435039471	5452	Economy	9800.00
0005435006921	5452	Economy	9800.00
0005435006934	5452	Economy	9800.00
0005435039499	5452	Economy	9800.00
0005435039464	5452	Economy	9800.00
0005435039491	5452	Economy	9800.00
0005434229077	5452	Economy	9800.00
0005435039485	5452	Economy	9800.00
0005435039519	5452	Economy	9800.00
0005435043282	5452	Economy	9800.00
0005434229046	5452	Economy	9800.00
0005434229067	5452	Economy	9800.00
0005435039517	5452	Economy	9800.00
0005434229069	5452	Economy	9800.00
0005435039524	5452	Economy	9800.00
0005434229057	5452	Economy	9800.00
0005432125423	5452	Economy	9800.00
0005435039502	5452	Economy	9800.00
0005432125420	5452	Economy	9800.00
0005435039487	5452	Economy	9800.00
0005435039474	5452	Economy	9800.00
0005434229087	5452	Economy	9800.00
0005435039507	5452	Economy	9800.00
0005435039484	5452	Economy	9800.00
0005435043283	5452	Economy	9800.00
0005432125418	5452	Economy	9800.00
0005434229097	5452	Economy	10800.00
0005435006937	5452	Economy	10800.00
0005434229012	5452	Economy	10800.00
0005434229058	5452	Economy	10800.00
0005435006919	5452	Economy	10800.00
0005435039516	5452	Economy	10800.00
0005435039498	5452	Economy	9800.00
0005435006930	5452	Economy	9800.00
0005435039510	5452	Economy	9800.00
0005435039469	5452	Economy	9800.00
0005435039478	5452	Economy	9800.00
0005435039496	5452	Economy	9800.00
0005434229070	5452	Economy	9800.00
0005435006943	5452	Economy	9800.00
0005435039490	5452	Economy	9800.00
0005435039489	5452	Economy	9800.00
0005435039497	5452	Economy	9800.00
0005435039509	5452	Economy	9800.00
0005432125422	5452	Economy	9800.00
0005435039515	5452	Economy	9800.00
0005435006939	5452	Economy	9800.00
0005435006938	5452	Economy	9800.00
0005435039477	5452	Economy	9800.00
0005435006935	5452	Economy	9800.00
0005434229143	5452	Economy	9800.00
0005435039513	5452	Economy	9800.00
0005432125419	5452	Economy	9800.00
0005435006940	5452	Economy	9800.00
0005435039522	5452	Economy	9800.00
0005435039521	5452	Economy	9800.00
0005435039479	5452	Economy	9800.00
0005435039530	5452	Economy	9800.00
0005435006925	5452	Economy	9800.00
0005434229147	5452	Economy	9800.00
0005435039493	5452	Economy	9800.00
0005434229078	5452	Economy	9800.00
0005435039506	5452	Economy	9800.00
0005435039480	5452	Economy	9800.00
0005435039481	5452	Economy	9800.00
0005435039467	5452	Economy	9800.00
0005435006923	5452	Economy	9800.00
0005435039520	5452	Economy	9800.00
0005435039508	5452	Economy	9800.00
0005434229076	5452	Economy	9800.00
0005435006932	5452	Economy	9800.00
0005434229114	5452	Economy	9800.00
0005435039488	5452	Economy	9800.00
0005435039468	5452	Economy	9800.00
0005435006942	5452	Economy	9800.00
0005435039518	5452	Economy	9800.00
0005435039465	5452	Economy	9800.00
0005435039483	5452	Economy	9800.00
0005435006927	5452	Economy	9800.00
0005435006924	5452	Economy	9800.00
0005435039466	5452	Economy	9800.00
0005432125417	5452	Economy	9800.00
0005435039476	5452	Economy	9800.00
0005434229113	5452	Economy	9800.00
0005434229023	5452	Economy	9800.00
0005435039475	5452	Economy	9800.00
0005435039523	5452	Economy	9800.00
0005434229123	5452	Economy	9800.00
0005434229161	5452	Economy	9800.00
0005435039501	5452	Economy	9800.00
0005435039500	5452	Economy	9800.00
0005435039504	5452	Economy	9800.00
0005435377900	5452	Economy	9800.00
0005435039531	5452	Economy	9800.00
0005435039492	5452	Economy	9800.00
0005435039486	5452	Economy	9800.00
0005435006928	5452	Economy	9800.00
0005435006933	5452	Economy	9800.00
0005434228990	5452	Economy	9800.00
0005435006624	12968	Business	29500.00
0005435039170	12968	Business	29500.00
0005435039161	12968	Business	29500.00
0005434229266	12968	Business	29500.00
0005432304381	12968	Business	29500.00
0005435038777	12968	Business	29500.00
0005435038893	12968	Business	29500.00
0005435006757	12968	Business	29500.00
0005435039045	12968	Economy	9800.00
0005435006703	12968	Economy	9800.00
0005434229284	12968	Economy	9800.00
0005435039194	12968	Economy	9800.00
0005435038978	12968	Economy	9800.00
0005434229273	12968	Economy	9800.00
0005434229277	12968	Economy	9800.00
0005432304382	12968	Economy	9800.00
0005435006756	12968	Economy	9800.00
0005435039173	12968	Economy	9800.00
0005435038781	12968	Economy	9800.00
0005434229280	12968	Economy	9800.00
0005435038917	12968	Economy	9800.00
0005435039057	12968	Economy	9800.00
0005435038876	12968	Economy	9800.00
0005435038869	12968	Economy	9800.00
0005435038974	12968	Economy	9800.00
0005435038904	12968	Economy	9800.00
0005434229267	12968	Economy	9800.00
0005435039146	12968	Economy	9800.00
0005435006704	12968	Economy	9800.00
0005435038913	12968	Economy	9800.00
0005435038889	12968	Economy	9800.00
0005435038932	12968	Economy	9800.00
0005434229287	12968	Economy	9800.00
0005435038963	12968	Economy	9800.00
0005435038848	12968	Economy	9800.00
0005435006784	12968	Economy	9800.00
0005435038971	12968	Economy	9800.00
0005435038958	12968	Economy	10800.00
0005434229269	12968	Economy	10800.00
0005435006817	12968	Economy	10800.00
0005435038849	12968	Economy	10800.00
0005435039007	12968	Economy	9800.00
0005435038879	12968	Economy	9800.00
0005435039044	12968	Economy	9800.00
0005435039120	12968	Economy	9800.00
0005435006793	12968	Economy	9800.00
0005435006729	12968	Economy	9800.00
0005435038896	12968	Economy	9800.00
0005434229279	12968	Economy	9800.00
0005435038929	12968	Economy	9800.00
0005435039064	12968	Economy	9800.00
0005435039006	12968	Economy	9800.00
0005435039040	12968	Economy	9800.00
0005434229271	12968	Economy	9800.00
0005435039048	12968	Economy	9800.00
0005434229286	12968	Economy	9800.00
0005435038840	12968	Economy	9800.00
0005434229282	12968	Economy	9800.00
0005435039105	12968	Economy	9800.00
0005434229283	12968	Economy	9800.00
0005435038973	12968	Economy	9800.00
0005434229272	12968	Economy	9800.00
0005434229288	12968	Economy	9800.00
0005435039056	12968	Economy	9800.00
0005435039193	12968	Economy	9800.00
0005434229278	12968	Economy	9800.00
0005435039155	12968	Economy	9800.00
0005434229275	12968	Economy	9800.00
0005435006656	12968	Economy	9800.00
0005435039106	12968	Economy	9800.00
0005434229281	12968	Economy	9800.00
0005435006623	12968	Economy	9800.00
0005434229274	12968	Economy	9800.00
0005435038776	12968	Economy	9800.00
0005435006655	12968	Economy	9800.00
0005435043275	12968	Economy	9800.00
0005434229276	12968	Economy	9800.00
0005434229270	12968	Economy	9800.00
0005435039098	12968	Economy	9800.00
0005435038841	12968	Economy	9800.00
0005435038912	12968	Economy	9800.00
0005435039171	12968	Economy	9800.00
0005435006683	12968	Economy	9800.00
0005435006658	12968	Economy	9800.00
0005435038842	12968	Economy	9800.00
0005435039160	12968	Economy	9800.00
0005435038806	12968	Economy	9800.00
0005434229268	12968	Economy	9800.00
0005435039217	12968	Economy	9800.00
0005435039014	12968	Economy	9800.00
0005435038870	12968	Economy	9800.00
0005435006714	12968	Economy	9800.00
0005435006760	12968	Economy	9800.00
0005435039182	12968	Economy	9800.00
0005435039039	12968	Economy	9800.00
0005434229285	12968	Economy	9800.00
0005435039108	12968	Economy	9800.00
0005432304383	12968	Economy	9800.00
0005435554114	14851	Business	52900.00
0005435554112	14851	Business	52900.00
0005435902456	14851	Business	52900.00
0005434426459	14851	Business	52900.00
0005435902480	14851	Business	52900.00
0005435902396	14851	Business	52900.00
0005432188593	14851	Business	52900.00
0005434426465	14851	Business	52900.00
0005434411758	14851	Economy	17600.00
0005435902481	14851	Economy	17600.00
0005434426454	14851	Economy	17600.00
0005434411755	14851	Economy	17600.00
0005434426456	14851	Economy	17600.00
0005435902453	14851	Economy	17600.00
0005434411754	14851	Economy	17600.00
0005435902460	14851	Economy	19400.00
0005434411757	14851	Economy	17600.00
0005434426472	14851	Economy	17600.00
0005434426468	14851	Economy	17600.00
0005435902431	14851	Economy	17600.00
0005434426462	14851	Economy	17600.00
0005434426475	14851	Economy	17600.00
0005434426469	14851	Economy	17600.00
0005435902430	14851	Economy	17600.00
0005435902515	14851	Economy	17600.00
0005435902482	14851	Economy	17600.00
0005434426466	14851	Economy	17600.00
0005435902472	14851	Economy	17600.00
0005434426458	14851	Economy	17600.00
0005434426473	14851	Economy	17600.00
0005434426453	14851	Economy	17600.00
0005435902408	14851	Economy	17600.00
0005434426450	14851	Economy	17600.00
0005434426457	14851	Economy	17600.00
0005435554122	14851	Economy	17600.00
0005434426474	14851	Economy	17600.00
0005434426455	14851	Economy	17600.00
0005434426460	14851	Economy	17600.00
0005434426463	14851	Economy	17600.00
0005435902461	14851	Economy	17600.00
0005434426452	14851	Economy	17600.00
0005434426448	14851	Economy	17600.00
0005432188592	14851	Economy	17600.00
0005435902455	14851	Economy	17600.00
0005435902425	14851	Economy	17600.00
0005435902421	14851	Economy	17600.00
0005432188591	14851	Economy	17600.00
0005434426471	14851	Economy	17600.00
0005435902454	14851	Economy	17600.00
0005434426470	14851	Economy	17600.00
0005435902424	14851	Economy	17600.00
0005434426451	14851	Economy	17600.00
0005435902506	14851	Economy	17600.00
0005432188590	14851	Economy	17600.00
0005434426467	14851	Economy	17600.00
0005434426464	14851	Economy	17600.00
0005434426449	14851	Economy	17600.00
0005434411756	14851	Economy	17600.00
0005435902407	14851	Economy	17600.00
0005434411759	14851	Economy	17600.00
0005434426461	14851	Economy	17600.00
0005435554169	20227	Business	52900.00
0005434426303	20227	Business	52900.00
0005435902622	20227	Business	52900.00
0005434426180	20227	Business	52900.00
0005434411716	20227	Business	52900.00
0005435902630	20227	Economy	17600.00
0005435902623	20227	Economy	17600.00
0005435902621	20227	Economy	17600.00
0005435902628	20227	Economy	17600.00
0005435902626	20227	Economy	17600.00
0005435902625	20227	Economy	17600.00
0005434426245	20227	Economy	19400.00
0005434411728	20227	Economy	19400.00
0005434426312	20227	Economy	19400.00
0005435902631	20227	Economy	19400.00
0005435902632	20227	Economy	17600.00
0005435902637	20227	Economy	17600.00
0005435554168	20227	Economy	17600.00
0005434426317	20227	Economy	17600.00
0005435554167	20227	Economy	17600.00
0005434426287	20227	Economy	17600.00
0005434426324	20227	Economy	17600.00
0005434426288	20227	Economy	17600.00
0005432059495	20227	Economy	17600.00
0005435902634	20227	Economy	17600.00
0005434426159	20227	Economy	17600.00
0005435902629	20227	Economy	17600.00
0005434426260	20227	Economy	17600.00
0005434426204	20227	Economy	17600.00
0005434426304	20227	Economy	17600.00
0005435902633	20227	Economy	17600.00
0005435554171	20227	Economy	17600.00
0005435902627	20227	Economy	17600.00
0005435554170	20227	Economy	17600.00
0005432059496	20227	Economy	17600.00
0005434426292	20227	Economy	17600.00
0005434411745	20227	Economy	17600.00
0005434426275	20227	Economy	17600.00
0005434426334	20227	Economy	17600.00
0005434426274	20227	Economy	17600.00
0005434426209	20227	Economy	17600.00
0005434426232	20227	Economy	17600.00
0005434411742	20227	Economy	17600.00
0005434411717	20227	Economy	17600.00
0005434426174	20227	Economy	17600.00
0005434426210	20227	Economy	17600.00
0005434426158	20227	Economy	17600.00
0005435902636	20227	Economy	17600.00
0005434411729	20227	Economy	17600.00
0005434426325	20227	Economy	17600.00
0005434426241	20227	Economy	17600.00
0005435902624	20227	Economy	17600.00
0005434411730	20227	Economy	17600.00
0005434426276	20227	Economy	17600.00
0005435902638	20227	Economy	17600.00
0005435902635	20227	Economy	17600.00
0005435554172	20227	Economy	17600.00
0005432462505	28011	Economy	35600.00
0005434523739	28011	Economy	35600.00
0005432462501	28011	Economy	35600.00
0005434523731	28011	Economy	35600.00
0005432462502	28011	Economy	35600.00
0005432462500	28011	Economy	35600.00
0005434523740	28011	Economy	35600.00
0005432462503	28011	Economy	39200.00
0005434523743	28011	Economy	35600.00
0005432462504	28011	Economy	35600.00
0005434523744	28011	Economy	35600.00
0005434523735	28011	Economy	35600.00
0005432462506	28011	Economy	35600.00
0005434523732	28011	Economy	35600.00
0005434523742	28011	Economy	35600.00
0005434523762	30893	Business	106800.00
0005434559089	30893	Business	106800.00
0005434523758	30893	Economy	35600.00
0005434523764	30893	Economy	35600.00
0005432462491	30893	Economy	35600.00
0005434559091	30893	Economy	35600.00
0005434523761	30893	Economy	35600.00
0005434559090	30893	Economy	35600.00
0005432462478	30893	Economy	35600.00
0005432462479	30893	Economy	35600.00
0005434523765	30893	Economy	35600.00
0005432462481	30893	Economy	35600.00
0005434523766	30893	Economy	35600.00
0005434559088	30893	Economy	35600.00
0005434523763	30893	Economy	35600.00
0005434523760	30893	Economy	35600.00
0005434523759	30893	Economy	35600.00
0005433726082	30865	Economy	30600.00
0005433726089	30865	Economy	30600.00
0005433726076	30865	Economy	30600.00
0005433726090	30865	Economy	30600.00
0005433726087	30865	Economy	30600.00
0005433726091	30865	Economy	30600.00
0005433726085	30865	Economy	33600.00
0005433726084	30865	Economy	30600.00
0005433726079	30865	Economy	30600.00
0005433726081	30865	Economy	30600.00
0005433726083	30865	Economy	30600.00
0005433726078	30865	Economy	30600.00
0005433726080	30865	Economy	30600.00
0005433726088	30865	Economy	30600.00
0005433726086	30865	Economy	30600.00
0005433726092	30865	Economy	30600.00
0005433726077	30865	Economy	30600.00
0005433434288	26531	Business	18500.00
0005435982077	26531	Business	18500.00
0005433434262	26531	Business	18500.00
0005435982066	26531	Business	18500.00
0005435982090	26531	Business	18500.00
0005435982071	26531	Business	18500.00
0005434273053	26531	Business	18500.00
0005435982072	26531	Business	18500.00
0005435982079	26531	Business	18500.00
0005435982064	26531	Business	18500.00
0005435982054	26531	Business	18500.00
0005435982081	26531	Economy	6200.00
0005433434373	26531	Economy	6200.00
0005434270184	26531	Economy	6200.00
0005433434387	26531	Economy	6200.00
0005433434233	26531	Economy	6200.00
0005435982083	26531	Economy	6200.00
0005433434322	26531	Economy	6200.00
0005435982062	26531	Economy	6200.00
0005433434277	26531	Economy	6200.00
0005432300232	26531	Economy	6200.00
0005434270186	26531	Economy	6800.00
0005435982085	26531	Economy	6800.00
0005433434341	26531	Economy	6800.00
0005435982095	26531	Economy	6800.00
0005434270182	26531	Economy	6800.00
0005433434289	26531	Economy	6200.00
0005435982073	26531	Economy	6200.00
0005433434308	26531	Economy	6200.00
0005435982063	26531	Economy	6200.00
0005433434247	26531	Economy	6200.00
0005435982068	26531	Economy	6200.00
0005435982057	26531	Economy	6200.00
0005434273047	26531	Economy	6200.00
0005434270183	26531	Economy	6200.00
0005435982086	26531	Economy	6200.00
0005433434291	26531	Economy	6200.00
0005433434300	26531	Economy	6200.00
0005433434370	26531	Economy	6200.00
0005435982091	26531	Economy	6200.00
0005434270180	26531	Economy	6200.00
0005433434372	26531	Economy	6200.00
0005433434301	26531	Economy	6200.00
0005433434310	26531	Economy	6200.00
0005433434265	26531	Economy	6200.00
0005433434231	26531	Economy	6200.00
0005434273058	26531	Economy	6200.00
0005433434311	26531	Economy	6200.00
0005435982070	26531	Economy	6200.00
0005435982055	26531	Economy	6200.00
0005433434230	26531	Economy	6200.00
0005435982088	26531	Economy	6200.00
0005433434281	26531	Economy	6200.00
0005432300233	26531	Economy	6200.00
0005432300236	26531	Economy	6200.00
0005433434263	26531	Economy	6200.00
0005432300237	26531	Economy	6200.00
0005435982061	26531	Economy	6200.00
0005435982069	26531	Economy	6200.00
0005434273050	26531	Economy	6200.00
0005433434211	26531	Economy	6200.00
0005433434386	26531	Economy	6200.00
0005433434339	26531	Economy	6200.00
0005435982059	26531	Economy	6200.00
0005435982076	26531	Economy	6200.00
0005435982056	26531	Economy	6200.00
0005435982067	26531	Economy	6200.00
0005433434309	26531	Economy	6200.00
0005432300234	26531	Economy	6200.00
0005433434338	26531	Economy	6200.00
0005435982065	26531	Economy	6200.00
0005435982060	26531	Economy	6200.00
0005435982078	26531	Economy	6200.00
0005433434215	26531	Economy	6200.00
0005435982075	26531	Economy	6200.00
0005435982058	26531	Economy	6200.00
0005433434292	26531	Economy	6200.00
0005435982087	26531	Economy	6200.00
0005435982092	26531	Economy	6200.00
0005433434246	26531	Economy	6200.00
0005435982094	26531	Economy	6200.00
0005435982082	26531	Economy	6200.00
0005435982074	26531	Economy	6200.00
0005434273054	26531	Economy	6200.00
0005435982093	26531	Economy	6200.00
0005435982084	26531	Economy	6200.00
0005433434371	26531	Economy	6200.00
0005432300235	26531	Economy	6200.00
0005435982089	26531	Economy	6200.00
0005434270185	26531	Economy	6200.00
0005435982080	26531	Economy	6200.00
0005434273051	26531	Economy	6200.00
0005433434264	26531	Economy	6200.00
0005434273057	26531	Economy	6200.00
0005435981588	26729	Business	18500.00
0005435981813	26729	Business	18500.00
0005435981757	26729	Business	18500.00
0005435981562	26729	Business	18500.00
0005435981734	26729	Business	18500.00
0005435981724	26729	Business	18500.00
0005435981680	26729	Business	18500.00
0005435981535	26729	Business	18500.00
0005432051117	26729	Business	18500.00
0005435981728	26729	Business	18500.00
0005435981589	26729	Business	18500.00
0005433434566	26729	Economy	6200.00
0005433434568	26729	Economy	6200.00
0005433434554	26729	Economy	6200.00
0005435981817	26729	Economy	6200.00
0005435981725	26729	Economy	6200.00
0005433434573	26729	Economy	6200.00
0005433434557	26729	Economy	6800.00
0005435981719	26729	Economy	6800.00
0005435981829	26729	Economy	6800.00
0005435981857	26729	Economy	6800.00
0005435981841	26729	Economy	6200.00
0005433434563	26729	Economy	6200.00
0005435981705	26729	Economy	6200.00
0005433434562	26729	Economy	6200.00
0005435981756	26729	Economy	6200.00
0005433434581	26729	Economy	6200.00
0005435981576	26729	Economy	6200.00
0005433434559	26729	Economy	6200.00
0005433434575	26729	Economy	6200.00
0005433434564	26729	Economy	6200.00
0005432051116	26729	Economy	6200.00
0005435981557	26729	Economy	6200.00
0005433434567	26729	Economy	6200.00
0005433434580	26729	Economy	6200.00
0005433434555	26729	Economy	6200.00
0005434271304	26729	Economy	6200.00
0005435981608	26729	Economy	6200.00
0005433434569	26729	Economy	6200.00
0005435981556	26729	Economy	6200.00
0005435981788	26729	Economy	6200.00
0005435981811	26729	Economy	6200.00
0005433434579	26729	Economy	6200.00
0005433434561	26729	Economy	6200.00
0005435981654	26729	Economy	6200.00
0005433434582	26729	Economy	6200.00
0005433434556	26729	Economy	6200.00
0005433434558	26729	Economy	6200.00
0005435981727	26729	Economy	6200.00
0005433434560	26729	Economy	6200.00
0005435981630	26729	Economy	6200.00
0005434269094	26729	Economy	6200.00
0005435981673	26729	Economy	6200.00
0005435981697	26729	Economy	6200.00
0005433434574	26729	Economy	6200.00
0005435981631	26729	Economy	6200.00
0005433434577	26729	Economy	6200.00
0005435981787	26729	Economy	6200.00
0005435981560	26729	Economy	6200.00
0005435981575	26729	Economy	6200.00
0005435981651	26729	Economy	6200.00
0005433434570	26729	Economy	6200.00
0005435981753	26729	Economy	6200.00
0005432051115	26729	Economy	6200.00
0005433434572	26729	Economy	6200.00
0005435981577	26729	Economy	6200.00
0005433434571	26729	Economy	6200.00
0005435981814	26729	Economy	6200.00
0005435981784	26729	Economy	6200.00
0005435981718	26729	Economy	6200.00
0005433434565	26729	Economy	6200.00
0005435981558	26729	Economy	6200.00
0005435981696	26729	Economy	6200.00
0005433434578	26729	Economy	6200.00
0005435981752	26729	Economy	6200.00
0005434269095	26729	Economy	6200.00
0005433434576	26729	Economy	6200.00
0005435981561	26729	Economy	6200.00
0005435981607	26729	Economy	6200.00
0005435981720	26729	Economy	6200.00
0005435981818	26729	Economy	6200.00
0005435981721	26729	Economy	6200.00
0005433689887	29271	Economy	19100.00
0005433686609	29271	Economy	19100.00
0005433689876	29271	Economy	19100.00
0005433689888	29271	Economy	19100.00
0005433686614	29271	Economy	19100.00
0005432583931	3133	Economy	11100.00
0005432583936	3133	Economy	11100.00
0005432857928	3133	Economy	11100.00
0005432216260	3133	Economy	11100.00
0005432583929	3133	Economy	10100.00
0005432857982	3133	Economy	10100.00
0005432583937	3133	Economy	10100.00
0005432583919	3133	Economy	10100.00
0005432857954	3133	Economy	10100.00
0005432583927	3133	Economy	10100.00
0005432857941	3133	Economy	10100.00
0005432583920	3133	Economy	10100.00
0005432583942	3133	Economy	10100.00
0005432583939	3133	Economy	10100.00
0005432583932	3133	Economy	10100.00
0005432583930	3133	Economy	10100.00
0005432583925	3133	Economy	10100.00
0005432583928	3133	Economy	10100.00
0005432583918	3133	Economy	10100.00
0005432857940	3133	Economy	10100.00
0005432857948	3133	Economy	10100.00
0005432583922	3133	Economy	10100.00
0005432583933	3133	Economy	10100.00
0005432583935	3133	Economy	10100.00
0005432857958	3133	Economy	10100.00
0005432583934	3133	Economy	10100.00
0005432583938	3133	Economy	10100.00
0005432216261	3133	Economy	10100.00
0005432583926	3133	Economy	10100.00
0005432583940	3133	Economy	10100.00
0005432583924	3133	Economy	10100.00
0005432583921	3133	Economy	10100.00
0005432216259	3133	Economy	10100.00
0005432583923	3133	Economy	10100.00
0005432583941	3133	Economy	10100.00
0005432857930	3133	Economy	10100.00
0005432857908	3133	Economy	10100.00
0005432857890	3133	Economy	10100.00
0005432858019	31506	Economy	11100.00
0005432583860	31506	Economy	11100.00
0005432583726	31506	Economy	11100.00
0005432858022	31506	Economy	11100.00
0005432858020	31506	Economy	10100.00
0005432583758	31506	Economy	10100.00
0005432583793	31506	Economy	10100.00
0005432583706	31506	Economy	10100.00
0005432858018	31506	Economy	10100.00
0005432858011	31506	Economy	10100.00
0005432583794	31506	Economy	10100.00
0005432858017	31506	Economy	10100.00
0005432858016	31506	Economy	10100.00
0005432583825	31506	Economy	10100.00
0005432583762	31506	Economy	10100.00
0005432858021	31506	Economy	10100.00
0005432583649	31506	Economy	10100.00
0005432583808	31506	Economy	10100.00
0005432858012	31506	Economy	10100.00
0005432583727	31506	Economy	10100.00
0005432583826	31506	Economy	10100.00
0005432583732	31506	Economy	10100.00
0005432583770	31506	Economy	10100.00
0005432858013	31506	Economy	10100.00
0005432583614	31506	Economy	10100.00
0005432583728	31506	Economy	10100.00
0005432583725	31506	Economy	10100.00
0005432583613	31506	Economy	10100.00
0005432858014	31506	Economy	10100.00
0005432858015	31506	Economy	10100.00
0005432583765	31506	Economy	10100.00
0005433255060	863	Economy	8300.00
0005433255044	863	Economy	8300.00
0005433255022	863	Economy	7500.00
0005434943310	863	Economy	7500.00
0005434943314	863	Economy	7500.00
0005433255049	863	Economy	7500.00
0005434943311	863	Economy	7500.00
0005433255050	863	Economy	7500.00
0005434943312	863	Economy	7500.00
0005434943309	863	Economy	7500.00
0005434943315	863	Economy	7500.00
0005434943308	863	Economy	7500.00
0005434943316	863	Economy	7500.00
0005434943313	863	Economy	7500.00
0005433255023	863	Economy	7500.00
0005433255059	863	Economy	7500.00
0005434943201	16217	Economy	8300.00
0005434943253	16217	Economy	8300.00
0005434943200	16217	Economy	7500.00
0005434943256	16217	Economy	7500.00
0005434943240	16217	Economy	7500.00
0005433255095	16217	Economy	7500.00
0005434943241	16217	Economy	7500.00
0005433255098	16217	Economy	7500.00
0005433255096	16217	Economy	7500.00
0005433255093	16217	Economy	7500.00
0005433255097	16217	Economy	7500.00
0005434943221	16217	Economy	7500.00
0005433255094	16217	Economy	7500.00
0005435858532	27605	Business	90500.00
0005433654659	27605	Business	90500.00
0005433654676	27605	Business	90500.00
0005433654695	27605	Business	90500.00
0005433654673	27605	Economy	30200.00
0005433654696	27605	Economy	30200.00
0005433654664	27605	Economy	30200.00
0005435858544	27605	Economy	30200.00
0005435858536	27605	Economy	33200.00
0005435858534	27605	Economy	33200.00
0005433654660	27605	Economy	33200.00
0005433654651	27605	Economy	30200.00
0005433654661	27605	Economy	30200.00
0005433654669	27605	Economy	30200.00
0005435858540	27605	Economy	30200.00
0005435858537	27605	Economy	30200.00
0005435858543	27605	Economy	30200.00
0005433654654	27605	Economy	30200.00
0005433654683	27605	Economy	30200.00
0005435858542	27605	Economy	30200.00
0005435858539	27605	Economy	30200.00
0005433654665	27605	Economy	30200.00
0005433654666	27605	Economy	30200.00
0005433654670	27605	Economy	30200.00
0005435858541	27605	Economy	30200.00
0005435858535	27605	Economy	30200.00
0005433654675	27605	Economy	30200.00
0005433654674	27605	Economy	30200.00
0005435858533	27605	Economy	30200.00
0005435858538	27605	Economy	30200.00
0005433654650	27605	Economy	30200.00
0005433811611	14334	Economy	4400.00
0005433811610	14334	Economy	4400.00
0005435652853	21741	Business	9800.00
0005435652858	21741	Business	9800.00
0005433367400	21741	Business	9800.00
0005433367263	21741	Business	9800.00
0005433367328	21741	Business	9800.00
0005435652874	21741	Business	9800.00
0005435652856	21741	Business	9800.00
0005433367219	21741	Business	9800.00
0005433367396	21741	Business	9800.00
0005433367359	21741	Business	9800.00
0005433367358	21741	Business	9800.00
0005435652863	21741	Business	9800.00
0005435652851	21741	Economy	3300.00
0005435652862	21741	Economy	3300.00
0005435652860	21741	Economy	3300.00
0005433367351	21741	Economy	3300.00
0005433367403	21741	Economy	3300.00
0005433367347	21741	Economy	3300.00
0005433367428	21741	Economy	3300.00
0005435652848	21741	Economy	3600.00
0005433367468	21741	Economy	3600.00
0005433367339	21741	Economy	3600.00
0005435652843	21741	Economy	3600.00
0005435652855	21741	Economy	3300.00
0005435652846	21741	Economy	3300.00
0005433367348	21741	Economy	3300.00
0005435652839	21741	Economy	3300.00
0005433367290	21741	Economy	3300.00
0005433367270	21741	Economy	3300.00
0005435652857	21741	Economy	3300.00
0005435652869	21741	Economy	3300.00
0005433367398	21741	Economy	3300.00
0005435652852	21741	Economy	3300.00
0005435652868	21741	Economy	3300.00
0005435652840	21741	Economy	3300.00
0005435652867	21741	Economy	3300.00
0005433367228	21741	Economy	3300.00
0005435652865	21741	Economy	3300.00
0005435652842	21741	Economy	3300.00
0005435652850	21741	Economy	3300.00
0005435652870	21741	Economy	3300.00
0005435652845	21741	Economy	3300.00
0005435652871	21741	Economy	3300.00
0005435652841	21741	Economy	3300.00
0005435652859	21741	Economy	3300.00
0005435652877	21741	Economy	3300.00
0005433367543	21741	Economy	3300.00
0005433367338	21741	Economy	3300.00
0005433367222	21741	Economy	3300.00
0005433367345	21741	Economy	3300.00
0005433367327	21741	Economy	3300.00
0005433367279	21741	Economy	3300.00
0005433367349	21741	Economy	3300.00
0005435652875	21741	Economy	3300.00
0005433367346	21741	Economy	3300.00
0005433367483	21741	Economy	3300.00
0005433367405	21741	Economy	3300.00
0005435652847	21741	Economy	3300.00
0005435652849	21741	Economy	3300.00
0005433367329	21741	Economy	3300.00
0005435652876	21741	Economy	3300.00
0005435652838	21741	Economy	3300.00
0005433367237	21741	Economy	3300.00
0005433367278	21741	Economy	3300.00
0005433367516	21741	Economy	3300.00
0005435652854	21741	Economy	3300.00
0005433367289	21741	Economy	3300.00
0005433367309	21741	Economy	3300.00
0005435652872	21741	Economy	3300.00
0005435652861	21741	Economy	3300.00
0005433367446	21741	Economy	3300.00
0005435652844	21741	Economy	3300.00
0005433367340	21741	Economy	3300.00
0005435652866	21741	Economy	3300.00
0005435652864	21741	Economy	3300.00
0005435652873	21741	Economy	3300.00
0005433784774	9386	Business	186200.00
0005434170851	9386	Business	186200.00
0005433763149	9386	Business	186200.00
0005432665265	9386	Business	186200.00
0005433805232	9386	Business	186200.00
0005433784813	9386	Business	186200.00
0005434273060	9386	Business	186200.00
0005434170916	9386	Business	186200.00
0005433805244	9386	Business	186200.00
0005433805240	9386	Business	186200.00
0005433784805	9386	Business	186200.00
0005434170889	9386	Business	186200.00
0005433805211	9386	Business	186200.00
0005433763146	9386	Economy	68300.00
0005433784782	9386	Economy	68300.00
0005433805238	9386	Economy	68300.00
0005434170872	9386	Economy	68300.00
0005433763147	9386	Economy	62100.00
0005433805231	9386	Economy	62100.00
0005433784779	9386	Economy	62100.00
0005433784795	9386	Economy	62100.00
0005433784792	9386	Economy	62100.00
0005434151674	9386	Economy	62100.00
0005433805237	9386	Economy	62100.00
0005433784809	9386	Economy	62100.00
0005433805224	9386	Economy	62100.00
0005435269644	9386	Economy	62100.00
0005433805225	9386	Economy	62100.00
0005433784798	9386	Economy	62100.00
0005433763150	9386	Economy	62100.00
0005433784797	9386	Economy	62100.00
0005433784788	9386	Economy	62100.00
0005433805213	9386	Economy	62100.00
0005433805243	9386	Economy	62100.00
0005433805226	9386	Economy	62100.00
0005433784786	9386	Economy	62100.00
0005433805223	9386	Economy	62100.00
0005433805230	9386	Economy	62100.00
0005433763144	9386	Economy	62100.00
0005433805239	9386	Economy	62100.00
0005434170953	9386	Economy	62100.00
0005434270181	9386	Economy	62100.00
0005433784793	9386	Economy	62100.00
0005432657437	9386	Economy	62100.00
0005433784803	9386	Economy	62100.00
0005433805218	9386	Economy	62100.00
0005434273061	9386	Economy	62100.00
0005433805216	9386	Economy	62100.00
0005433805212	9386	Economy	62100.00
0005434170909	9386	Economy	62100.00
0005434170867	9386	Economy	62100.00
0005433805229	9386	Economy	62100.00
0005433763142	9386	Economy	62100.00
0005433763145	9386	Economy	62100.00
0005432657436	9386	Economy	62100.00
0005432665266	9386	Economy	62100.00
0005434273048	9386	Economy	62100.00
0005434170856	9386	Economy	62100.00
0005433784775	9386	Economy	62100.00
0005433805236	9386	Economy	62100.00
0005434151675	9386	Economy	62100.00
0005433784812	9386	Economy	62100.00
0005433805233	9386	Economy	62100.00
0005433784800	9386	Economy	62100.00
0005433805215	9386	Economy	62100.00
0005433784810	9386	Economy	62100.00
0005433784801	9386	Economy	62100.00
0005433805217	9386	Economy	62100.00
0005433784773	9386	Economy	62100.00
0005433784808	9386	Economy	62100.00
0005433763141	9386	Economy	62100.00
0005433763137	9386	Economy	62100.00
0005434151670	9386	Economy	62100.00
0005432666380	9386	Economy	62100.00
0005432667445	9386	Economy	62100.00
0005432666379	9386	Economy	62100.00
0005433805245	9386	Economy	62100.00
0005433784780	9386	Economy	68300.00
0005434151671	9386	Economy	68300.00
0005433805221	9386	Economy	62100.00
0005433805242	9386	Economy	68300.00
0005433784784	9386	Economy	68300.00
0005433784777	9386	Economy	62100.00
0005433784811	9386	Economy	62100.00
0005433784807	9386	Economy	62100.00
0005433784790	9386	Economy	62100.00
0005433763151	9386	Economy	62100.00
0005433784794	9386	Economy	62100.00
0005433805241	9386	Economy	62100.00
0005433784781	9386	Economy	62100.00
0005433784776	9386	Economy	62100.00
0005433763140	9386	Economy	62100.00
0005433805227	9386	Economy	62100.00
0005433784785	9386	Economy	62100.00
0005433763148	9386	Economy	62100.00
0005433805219	9386	Economy	62100.00
0005433805214	9386	Economy	62100.00
0005433805222	9386	Economy	62100.00
0005434170906	9386	Economy	62100.00
0005433784804	9386	Economy	62100.00
0005433763138	9386	Economy	62100.00
0005433805234	9386	Economy	62100.00
0005433805220	9386	Economy	62100.00
0005433784787	9386	Economy	62100.00
0005433763139	9386	Economy	62100.00
0005433784791	9386	Economy	62100.00
0005433784778	9386	Economy	62100.00
0005433763143	9386	Economy	62100.00
0005434170905	9386	Economy	62100.00
0005433784783	9386	Economy	62100.00
0005433784789	9386	Economy	62100.00
0005432667444	9386	Economy	62100.00
0005434273049	9386	Economy	62100.00
0005433784799	9386	Economy	62100.00
0005432667446	9386	Economy	62100.00
0005433784806	9386	Economy	62100.00
0005432657435	9386	Economy	62100.00
0005433805235	9386	Economy	62100.00
0005433784802	9386	Economy	62100.00
0005433784796	9386	Economy	62100.00
0005434170910	9386	Economy	62100.00
0005433805228	9386	Economy	62100.00
0005433804897	26274	Business	186200.00
0005433784426	26274	Business	186200.00
0005433784549	26274	Business	186200.00
0005432657404	26274	Business	186200.00
0005434170990	26274	Business	186200.00
0005433804923	26274	Business	186200.00
0005434170997	26274	Business	186200.00
0005433804988	26274	Business	186200.00
0005434171000	26274	Business	186200.00
0005434151692	26274	Business	186200.00
0005434170996	26274	Business	186200.00
0005434269092	26274	Business	186200.00
0005434269093	26274	Business	186200.00
0005433762988	26274	Business	186200.00
0005435269726	26274	Business	186200.00
0005433784335	26274	Business	186200.00
0005435269728	26274	Business	186200.00
0005433804861	26274	Business	186200.00
0005433804863	26274	Business	186200.00
0005433805033	26274	Business	186200.00
0005433784501	26274	Economy	68300.00
0005433784391	26274	Economy	68300.00
0005433804886	26274	Economy	68300.00
0005434270195	26274	Economy	62100.00
0005433784496	26274	Economy	62100.00
0005435269735	26274	Economy	62100.00
0005433804832	26274	Economy	62100.00
0005433784550	26274	Economy	62100.00
0005433804808	26274	Economy	62100.00
0005433804949	26274	Economy	62100.00
0005432659683	26274	Economy	62100.00
0005433784565	26274	Economy	62100.00
0005432659677	26274	Economy	62100.00
0005433804918	26274	Economy	62100.00
0005432659678	26274	Economy	62100.00
0005433805003	26274	Economy	62100.00
0005434170998	26274	Economy	62100.00
0005433804917	26274	Economy	62100.00
0005434170993	26274	Economy	62100.00
0005434170999	26274	Economy	62100.00
0005433805075	26274	Economy	62100.00
0005434151691	26274	Economy	62100.00
0005433805002	26274	Economy	62100.00
0005434270196	26274	Economy	62100.00
0005433784445	26274	Economy	62100.00
0005433805109	26274	Economy	62100.00
0005434170989	26274	Economy	62100.00
0005433763013	26274	Economy	62100.00
0005434151690	26274	Economy	62100.00
0005433762999	26274	Economy	62100.00
0005435269732	26274	Economy	62100.00
0005433805064	26274	Economy	62100.00
0005435269725	26274	Economy	62100.00
0005433784373	26274	Economy	62100.00
0005433804859	26274	Economy	62100.00
0005434270198	26274	Economy	62100.00
0005433805057	26274	Economy	62100.00
0005433804973	26274	Economy	62100.00
0005435269733	26274	Economy	62100.00
0005434171001	26274	Economy	62100.00
0005433804920	26274	Economy	62100.00
0005435269727	26274	Economy	62100.00
0005433784636	26274	Economy	62100.00
0005432657417	26274	Economy	62100.00
0005433762943	26274	Economy	62100.00
0005433784569	26274	Economy	62100.00
0005433784465	26274	Economy	62100.00
0005433784447	26274	Economy	62100.00
0005433784486	26274	Economy	62100.00
0005433763001	26274	Economy	62100.00
0005433804895	26274	Economy	62100.00
0005433805090	26274	Economy	62100.00
0005433784446	26274	Economy	62100.00
0005433805111	26274	Economy	62100.00
0005433805110	26274	Economy	68300.00
0005433763012	26274	Economy	68300.00
0005434270197	26274	Economy	62100.00
0005434170995	26274	Economy	62100.00
0005434170994	26274	Economy	68300.00
0005433784336	26274	Economy	62100.00
0005433763000	26274	Economy	62100.00
0005433804993	26274	Economy	62100.00
0005433805058	26274	Economy	62100.00
0005433763055	26274	Economy	62100.00
0005434271302	26274	Economy	62100.00
0005434170991	26274	Economy	62100.00
0005434271303	26274	Economy	62100.00
0005435269731	26274	Economy	62100.00
0005433784564	26274	Economy	62100.00
0005433784524	26274	Economy	62100.00
0005433784448	26274	Economy	62100.00
0005432657410	26274	Economy	62100.00
0005433804964	26274	Economy	62100.00
0005433784490	26274	Economy	62100.00
0005433804887	26274	Economy	62100.00
0005433784635	26274	Economy	62100.00
0005433762952	26274	Economy	62100.00
0005435269730	26274	Economy	62100.00
0005433784470	26274	Economy	62100.00
0005433804969	26274	Economy	62100.00
0005433805091	26274	Economy	62100.00
0005433804972	26274	Economy	62100.00
0005433804850	26274	Economy	62100.00
0005433784449	26274	Economy	62100.00
0005432659682	26274	Economy	62100.00
0005433784392	26274	Economy	62100.00
0005434170992	26274	Economy	62100.00
0005433763054	26274	Economy	62100.00
0005433784495	26274	Economy	62100.00
0005433762944	26274	Economy	62100.00
0005433804858	26274	Economy	62100.00
0005433784452	26274	Economy	62100.00
0005433804987	26274	Economy	62100.00
0005433804941	26274	Economy	62100.00
0005434271301	26274	Economy	62100.00
0005435269729	26274	Economy	62100.00
0005433784500	26274	Economy	62100.00
0005433763002	26274	Economy	62100.00
0005433784601	26274	Economy	62100.00
0005433804936	26274	Economy	62100.00
0005433805015	26274	Economy	62100.00
0005432659679	26274	Economy	62100.00
0005435269734	26274	Economy	62100.00
0005433805034	26274	Economy	62100.00
0005433762998	26274	Economy	62100.00
0005435929613	4886	Economy	5300.00
0005435929612	4886	Economy	5300.00
0005435135647	4886	Economy	5300.00
0005435135650	4886	Economy	5300.00
0005435135651	4886	Economy	5300.00
0005435135649	4886	Economy	5300.00
0005435135648	4886	Economy	5300.00
0005435929615	4886	Economy	5300.00
0005435135611	33020	Economy	5900.00
0005435135608	33020	Economy	5900.00
0005435929631	33020	Economy	5300.00
0005435135614	33020	Economy	5300.00
0005435135610	33020	Economy	5300.00
0005435135617	33020	Economy	5300.00
0005435135605	33020	Economy	5300.00
0005435135618	33020	Economy	5300.00
0005435929632	33020	Economy	5300.00
0005435929633	33020	Economy	5300.00
0005435135600	33020	Economy	5300.00
0005435135604	33020	Economy	5300.00
0005435135624	33020	Economy	5300.00
0005435135592	33020	Economy	5300.00
0005435135609	33020	Economy	5300.00
0005435135613	33020	Economy	5300.00
0005435135601	33020	Economy	5300.00
0005434983267	9472	Economy	19700.00
0005434983265	9472	Economy	17900.00
0005434217904	9472	Economy	17900.00
0005434217917	9472	Economy	17900.00
0005434983266	9472	Economy	17900.00
0005434217918	9472	Economy	17900.00
0005434983264	9472	Economy	17900.00
0005434217919	9472	Economy	17900.00
0005434217908	9472	Economy	17900.00
0005434217903	9472	Economy	17900.00
0005434217920	9472	Economy	17900.00
0005434217916	9472	Economy	17900.00
0005434983263	9472	Economy	17900.00
0005434983245	27358	Economy	19700.00
0005434983246	27358	Economy	17900.00
0005434217951	27358	Economy	17900.00
0005434217950	27358	Economy	17900.00
0005434217952	27358	Economy	17900.00
0005433960137	24263	Business	36400.00
0005433985245	24263	Business	36400.00
0005433959941	24263	Business	36400.00
0005433985497	24263	Business	36400.00
0005433985365	24263	Business	36400.00
0005433960136	24263	Business	36400.00
0005433959935	24263	Business	36400.00
0005433985514	24263	Business	36400.00
0005433985336	24263	Business	36400.00
0005433959928	24263	Business	36400.00
0005433959903	24263	Business	36400.00
0005433985317	24263	Economy	13400.00
0005433985306	24263	Economy	12100.00
0005433960050	24263	Economy	12100.00
0005433959936	24263	Economy	12100.00
0005433985505	24263	Economy	12100.00
0005433985188	24263	Economy	12100.00
0005433960023	24263	Economy	12100.00
0005433960077	24263	Economy	12100.00
0005433960016	24263	Economy	12100.00
0005433985302	24263	Economy	12100.00
0005433985236	24263	Economy	12100.00
0005433985301	24263	Economy	12100.00
0005433960105	24263	Economy	12100.00
0005433985173	24263	Economy	12100.00
0005433959902	24263	Economy	12100.00
0005433985343	24263	Economy	12100.00
0005433960024	24263	Economy	12100.00
0005433960112	24263	Economy	12100.00
0005433959859	24263	Economy	12100.00
0005433960135	24263	Economy	12100.00
0005433960119	24263	Economy	12100.00
0005433985275	24263	Economy	12100.00
0005433985280	24263	Economy	12100.00
0005433985434	24263	Economy	12100.00
0005433960087	24263	Economy	12100.00
0005433985137	24263	Economy	12100.00
0005433959985	24263	Economy	12100.00
0005433959860	24263	Economy	12100.00
0005433960113	24263	Economy	12100.00
0005433985217	24263	Economy	12100.00
0005433959888	24263	Economy	12100.00
0005433985260	24263	Economy	12100.00
0005433960010	24263	Economy	12100.00
0005433985169	24263	Economy	12100.00
0005433985286	24263	Economy	12100.00
0005433985172	24263	Economy	12100.00
0005433985348	24263	Economy	12100.00
0005433985376	24263	Economy	12100.00
0005433960026	24263	Economy	12100.00
0005433985312	24263	Economy	12100.00
0005433960018	24263	Economy	12100.00
0005433959901	24263	Economy	12100.00
0005433985329	24263	Economy	12100.00
0005433959990	24263	Economy	12100.00
0005433985449	24263	Economy	12100.00
0005433985189	24263	Economy	13400.00
0005433960017	24263	Economy	12100.00
0005433985300	24263	Economy	13400.00
0005433960044	24263	Economy	12100.00
0005433985297	24263	Economy	12100.00
0005433959882	24263	Economy	12100.00
0005433959937	24263	Economy	12100.00
0005433960057	24263	Economy	12100.00
0005433959885	24263	Economy	12100.00
0005433985364	24263	Economy	12100.00
0005433959883	24263	Economy	12100.00
0005433960108	24263	Economy	12100.00
0005433960124	24263	Economy	12100.00
0005433959958	24263	Economy	12100.00
0005433985259	24263	Economy	12100.00
0005433960056	24263	Economy	12100.00
0005433985257	24263	Economy	12100.00
0005433959968	24263	Economy	12100.00
0005433960107	24263	Economy	12100.00
0005433960027	24263	Economy	12100.00
0005433960060	24263	Economy	12100.00
0005433960083	24263	Economy	12100.00
0005433985316	24263	Economy	12100.00
0005433960059	24263	Economy	12100.00
0005433960005	24263	Economy	12100.00
0005433985296	24263	Economy	12100.00
0005433960106	24263	Economy	12100.00
0005433960131	24263	Economy	12100.00
0005433985168	24263	Economy	12100.00
0005433985337	24263	Economy	12100.00
0005433959992	24263	Economy	12100.00
0005433985207	24263	Economy	12100.00
0005433985529	24263	Economy	12100.00
0005433959896	24263	Economy	12100.00
0005433960007	24263	Economy	12100.00
0005433959980	24263	Economy	12100.00
0005433959884	24263	Economy	12100.00
0005433960025	24263	Economy	12100.00
0005433985208	24263	Economy	12100.00
0005433959911	24263	Economy	12100.00
0005433960035	24263	Economy	12100.00
0005433959929	24263	Economy	12100.00
0005433985258	24263	Economy	12100.00
0005433959984	24263	Economy	12100.00
0005433985256	24263	Economy	12100.00
0005433960605	25943	Business	36400.00
0005433960612	25943	Business	36400.00
0005433960603	25943	Business	36400.00
0005433960590	25943	Business	36400.00
0005433960578	25943	Business	36400.00
0005433960614	25943	Business	36400.00
0005433985723	25943	Business	36400.00
0005433985718	25943	Business	36400.00
0005433985708	25943	Business	36400.00
0005433960602	25943	Business	36400.00
0005433960607	25943	Business	36400.00
0005433985730	25943	Business	36400.00
0005433985706	25943	Business	36400.00
0005433985733	25943	Business	36400.00
0005433960585	25943	Economy	13400.00
0005433960583	25943	Economy	13400.00
0005433960604	25943	Economy	13400.00
0005433985694	25943	Economy	12100.00
0005433960573	25943	Economy	12100.00
0005433960584	25943	Economy	12100.00
0005433960580	25943	Economy	12100.00
0005433985720	25943	Economy	12100.00
0005433960589	25943	Economy	12100.00
0005433985715	25943	Economy	12100.00
0005433985717	25943	Economy	12100.00
0005433985729	25943	Economy	12100.00
0005433985713	25943	Economy	12100.00
0005433960574	25943	Economy	12100.00
0005433985703	25943	Economy	12100.00
0005433960577	25943	Economy	12100.00
0005433985725	25943	Economy	12100.00
0005433960619	25943	Economy	12100.00
0005433985732	25943	Economy	12100.00
0005433985697	25943	Economy	12100.00
0005433960618	25943	Economy	12100.00
0005433985709	25943	Economy	12100.00
0005433960579	25943	Economy	12100.00
0005433985731	25943	Economy	12100.00
0005433960595	25943	Economy	12100.00
0005433985699	25943	Economy	12100.00
0005433960608	25943	Economy	12100.00
0005433960606	25943	Economy	12100.00
0005433985698	25943	Economy	12100.00
0005433960627	25943	Economy	12100.00
0005433960613	25943	Economy	12100.00
0005433985712	25943	Economy	12100.00
0005433985704	25943	Economy	12100.00
0005433960587	25943	Economy	12100.00
0005433985719	25943	Economy	12100.00
0005433960576	25943	Economy	12100.00
0005433960620	25943	Economy	12100.00
0005433960598	25943	Economy	12100.00
0005433985735	25943	Economy	12100.00
0005433985693	25943	Economy	12100.00
0005433960591	25943	Economy	12100.00
0005433960575	25943	Economy	12100.00
0005433985738	25943	Economy	12100.00
0005433985727	25943	Economy	12100.00
0005433960601	25943	Economy	12100.00
0005433960615	25943	Economy	12100.00
0005433960581	25943	Economy	12100.00
0005433985728	25943	Economy	12100.00
0005433985726	25943	Economy	12100.00
0005433985689	25943	Economy	12100.00
0005433985737	25943	Economy	12100.00
0005433985711	25943	Economy	13400.00
0005433985721	25943	Economy	12100.00
0005433960628	25943	Economy	13400.00
0005433985695	25943	Economy	13400.00
0005433960610	25943	Economy	13400.00
0005433960623	25943	Economy	12100.00
0005433960625	25943	Economy	12100.00
0005433985724	25943	Economy	12100.00
0005433960572	25943	Economy	12100.00
0005433960588	25943	Economy	12100.00
0005433960600	25943	Economy	12100.00
0005433960597	25943	Economy	12100.00
0005433960617	25943	Economy	12100.00
0005433960596	25943	Economy	12100.00
0005433985734	25943	Economy	12100.00
0005433985690	25943	Economy	12100.00
0005433985736	25943	Economy	12100.00
0005433960594	25943	Economy	12100.00
0005433985707	25943	Economy	12100.00
0005433960593	25943	Economy	12100.00
0005433985701	25943	Economy	12100.00
0005433985702	25943	Economy	12100.00
0005433985705	25943	Economy	12100.00
0005433985722	25943	Economy	12100.00
0005433960609	25943	Economy	12100.00
0005433985710	25943	Economy	12100.00
0005433960616	25943	Economy	12100.00
0005433985700	25943	Economy	12100.00
0005433960622	25943	Economy	12100.00
0005433960592	25943	Economy	12100.00
0005433985692	25943	Economy	12100.00
0005433960621	25943	Economy	12100.00
0005433985696	25943	Economy	12100.00
0005433985716	25943	Economy	12100.00
0005433960626	25943	Economy	12100.00
0005433960624	25943	Economy	12100.00
0005433985691	25943	Economy	12100.00
0005433960611	25943	Economy	12100.00
0005433985714	25943	Economy	12100.00
0005433960586	25943	Economy	12100.00
0005433960599	25943	Economy	12100.00
0005433960582	25943	Economy	12100.00
0005434480231	925	Economy	25400.00
0005434480227	925	Economy	25400.00
0005433165716	925	Economy	25400.00
0005434480212	925	Economy	25400.00
0005433165715	925	Economy	23100.00
0005434480229	925	Economy	23100.00
0005434480217	925	Economy	23100.00
0005434480218	925	Economy	23100.00
0005434480214	925	Economy	23100.00
0005434480230	925	Economy	23100.00
0005434480236	925	Economy	23100.00
0005434480223	925	Economy	23100.00
0005434480215	925	Economy	23100.00
0005434480213	925	Economy	23100.00
0005434480226	925	Economy	23100.00
0005433165776	925	Economy	23100.00
0005432269483	925	Economy	23100.00
0005434480224	925	Economy	23100.00
0005434480235	925	Economy	23100.00
0005433165734	925	Economy	23100.00
0005434480233	925	Economy	23100.00
0005433165708	925	Economy	23100.00
0005434480228	925	Economy	23100.00
0005433165703	925	Economy	23100.00
0005434480221	925	Economy	23100.00
0005433165732	925	Economy	23100.00
0005433165673	925	Economy	23100.00
0005434480232	925	Economy	23100.00
0005433165707	925	Economy	23100.00
0005433165811	925	Economy	23100.00
0005434480219	925	Economy	23100.00
0005434480234	925	Economy	23100.00
0005432269484	925	Economy	23100.00
0005434480216	925	Economy	23100.00
0005433165727	925	Economy	23100.00
0005434480220	925	Economy	23100.00
0005434480222	925	Economy	23100.00
0005434480225	925	Economy	23100.00
0005433165754	925	Economy	23100.00
0005433165723	925	Economy	23100.00
0005434480068	16582	Economy	25400.00
0005433165847	16582	Economy	25400.00
0005434480043	16582	Economy	25400.00
0005433165850	16582	Economy	23100.00
0005434479941	16582	Economy	23100.00
0005434479973	16582	Economy	23100.00
0005434480016	16582	Economy	23100.00
0005434480023	16582	Economy	23100.00
0005434480015	16582	Economy	23100.00
0005434480017	16582	Economy	23100.00
0005433165851	16582	Economy	23100.00
0005434480005	16582	Economy	23100.00
0005433165846	16582	Economy	23100.00
0005434480004	16582	Economy	23100.00
0005434480026	16582	Economy	23100.00
0005433165855	16582	Economy	23100.00
0005434479972	16582	Economy	23100.00
0005434480127	16582	Economy	23100.00
0005434479940	16582	Economy	23100.00
0005433165854	16582	Economy	23100.00
0005434480044	16582	Economy	23100.00
0005433165853	16582	Economy	23100.00
0005434480042	16582	Economy	23100.00
0005434480045	16582	Economy	23100.00
0005433165849	16582	Economy	23100.00
0005434479976	16582	Economy	23100.00
0005434480027	16582	Economy	23100.00
0005434480063	16582	Economy	23100.00
0005434480062	16582	Economy	23100.00
0005434479943	16582	Economy	23100.00
0005434479942	16582	Economy	23100.00
0005434480070	16582	Economy	23100.00
0005433165856	16582	Economy	23100.00
0005433165852	16582	Economy	23100.00
0005434479977	16582	Economy	23100.00
0005433165848	16582	Economy	23100.00
0005434480018	16582	Economy	23100.00
0005433165844	16582	Economy	23100.00
0005433165845	16582	Economy	23100.00
0005434480069	16582	Economy	23100.00
0005434479971	16582	Economy	23100.00
0005435142504	10319	Economy	17000.00
0005433289735	10319	Economy	17000.00
0005433289766	10319	Economy	17000.00
0005435149951	10319	Economy	17000.00
0005435149960	10319	Economy	15400.00
0005433289726	10319	Economy	15400.00
0005435142511	10319	Economy	15400.00
0005435149953	10319	Economy	15400.00
0005433289754	10319	Economy	15400.00
0005435149962	10319	Economy	15400.00
0005435386471	10319	Economy	15400.00
0005435149963	10319	Economy	15400.00
0005435149950	10319	Economy	15400.00
0005435142505	10319	Economy	15400.00
0005435149957	10319	Economy	15400.00
0005433289767	10319	Economy	15400.00
0005433289768	10319	Economy	15400.00
0005435386494	10319	Economy	15400.00
0005435386489	10319	Economy	15400.00
0005435149958	10319	Economy	15400.00
0005433289755	10319	Economy	15400.00
0005435142509	10319	Economy	15400.00
0005435142507	10319	Economy	15400.00
0005435149959	10319	Economy	15400.00
0005433289742	10319	Economy	15400.00
0005435386497	10319	Economy	15400.00
0005433289748	10319	Economy	15400.00
0005435142503	10319	Economy	15400.00
0005435149955	10319	Economy	15400.00
0005433289737	10319	Economy	15400.00
0005433289725	10319	Economy	15400.00
0005435386496	10319	Economy	15400.00
0005435149961	10319	Economy	15400.00
0005435386469	10319	Economy	15400.00
0005435386488	10319	Economy	15400.00
0005435142508	10319	Economy	15400.00
0005435142513	10319	Economy	15400.00
0005433289736	10319	Economy	15400.00
0005435149952	10319	Economy	15400.00
0005435386470	10319	Economy	15400.00
0005435149954	10319	Economy	15400.00
0005435142514	10319	Economy	15400.00
0005435386495	10319	Economy	15400.00
0005433289738	10319	Economy	15400.00
0005435142512	10319	Economy	15400.00
0005435142506	10319	Economy	15400.00
0005435386457	10319	Economy	15400.00
0005435142510	10319	Economy	15400.00
0005435149956	10319	Economy	15400.00
0005435386456	10319	Economy	15400.00
0005435149816	21915	Economy	17000.00
0005433289825	21915	Economy	17000.00
0005433289822	21915	Economy	17000.00
0005435142384	21915	Economy	15400.00
0005435386552	21915	Economy	15400.00
0005435142392	21915	Economy	15400.00
0005435149833	21915	Economy	15400.00
0005435149848	21915	Economy	15400.00
0005435149887	21915	Economy	15400.00
0005435149808	21915	Economy	15400.00
0005435142432	21915	Economy	15400.00
0005435149847	21915	Economy	15400.00
0005435149876	21915	Economy	15400.00
0005435149884	21915	Economy	15400.00
0005435149817	21915	Economy	15400.00
0005435149894	21915	Economy	15400.00
0005433289823	21915	Economy	15400.00
0005433289824	21915	Economy	15400.00
0005435142369	21915	Economy	15400.00
0005433289821	21915	Economy	15400.00
0005433289827	21915	Economy	15400.00
0005435142426	21915	Economy	15400.00
0005435149866	21915	Economy	15400.00
0005435386548	21915	Economy	15400.00
0005435142364	21915	Economy	15400.00
0005435386550	21915	Economy	15400.00
0005435149865	21915	Economy	15400.00
0005435142393	21915	Economy	15400.00
0005435386553	21915	Economy	15400.00
0005433289820	21915	Economy	15400.00
0005435386546	21915	Economy	15400.00
0005435149874	21915	Economy	15400.00
0005433289826	21915	Economy	15400.00
0005435149872	21915	Economy	15400.00
0005435149875	21915	Economy	15400.00
0005435386549	21915	Economy	15400.00
0005435142427	21915	Economy	15400.00
0005435386547	21915	Economy	15400.00
0005435142402	21915	Economy	15400.00
0005435142357	21915	Economy	15400.00
0005435386551	21915	Economy	15400.00
0005435142412	21915	Economy	15400.00
0005434573282	11182	Business	57200.00
0005435319470	11182	Business	57200.00
0005435529015	11182	Business	57200.00
0005435528975	11182	Business	57200.00
0005435529043	11182	Business	57200.00
0005435529017	11182	Business	57200.00
0005435528890	11182	Business	57200.00
0005435545623	11182	Business	57200.00
0005435501999	11182	Business	57200.00
0005435528974	11182	Business	57200.00
0005435501988	11182	Business	57200.00
0005434573283	11182	Economy	19100.00
0005435502140	11182	Economy	19100.00
0005435501987	11182	Economy	19100.00
0005434573280	11182	Economy	19100.00
0005435529018	11182	Economy	19100.00
0005435502133	11182	Economy	19100.00
0005435528917	11182	Economy	19100.00
0005435502010	11182	Economy	19100.00
0005435528997	11182	Economy	19100.00
0005435319460	11182	Economy	21000.00
0005435502029	11182	Economy	21000.00
0005435528910	11182	Economy	21000.00
0005434573278	11182	Economy	21000.00
0005435319464	11182	Economy	21000.00
0005435502126	11182	Economy	19100.00
0005435502007	11182	Economy	19100.00
0005435319467	11182	Economy	19100.00
0005435501983	11182	Economy	19100.00
0005435501998	11182	Economy	19100.00
0005435528926	11182	Economy	19100.00
0005435502011	11182	Economy	19100.00
0005435545617	11182	Economy	19100.00
0005434573284	11182	Economy	19100.00
0005435528953	11182	Economy	19100.00
0005435528956	11182	Economy	19100.00
0005435319430	11182	Economy	19100.00
0005435528927	11182	Economy	19100.00
0005435502023	11182	Economy	19100.00
0005435528996	11182	Economy	19100.00
0005434573285	11182	Economy	19100.00
0005435319455	11182	Economy	19100.00
0005434573287	11182	Economy	19100.00
0005435528989	11182	Economy	19100.00
0005435502141	11182	Economy	19100.00
0005435502111	11182	Economy	19100.00
0005435528993	11182	Economy	19100.00
0005435501952	11182	Economy	19100.00
0005434573286	11182	Economy	19100.00
0005435545613	11182	Economy	19100.00
0005435545620	11182	Economy	19100.00
0005435528891	11182	Economy	19100.00
0005435502099	11182	Economy	19100.00
0005434573275	11182	Economy	19100.00
0005435528971	11182	Economy	19100.00
0005434573276	11182	Economy	19100.00
0005435528925	11182	Economy	19100.00
0005435319433	11182	Economy	19100.00
0005435529044	11182	Economy	19100.00
0005435528955	11182	Economy	19100.00
0005434573281	11182	Economy	19100.00
0005435319457	11182	Economy	19100.00
0005434573277	11182	Economy	19100.00
0005435545642	11182	Economy	19100.00
0005435502008	11182	Economy	19100.00
0005435501982	11182	Economy	19100.00
0005435528968	11182	Economy	19100.00
0005435319463	11182	Economy	19100.00
0005435545622	11182	Economy	19100.00
0005434573279	11182	Economy	19100.00
0005435319434	11182	Economy	19100.00
0005435528935	11182	Economy	19100.00
0005434573274	11182	Economy	19100.00
0005435529010	11182	Economy	19100.00
0005434573288	11182	Economy	19100.00
0005435319431	11182	Economy	19100.00
0005435502084	11182	Economy	19100.00
0005435502125	11182	Economy	19100.00
0005435508299	20943	Business	57200.00
0005434573150	20943	Business	57200.00
0005435502197	20943	Business	57200.00
0005432291918	20943	Business	57200.00
0005435508306	20943	Business	57200.00
0005435502210	20943	Business	57200.00
0005435502204	20943	Business	57200.00
0005435508305	20943	Business	57200.00
0005435508303	20943	Business	57200.00
0005434573228	20943	Business	57200.00
0005434573152	20943	Business	57200.00
0005435517834	20943	Economy	19100.00
0005435319543	20943	Economy	19100.00
0005435517827	20943	Economy	19100.00
0005435319546	20943	Economy	19100.00
0005435517828	20943	Economy	19100.00
0005435502215	20943	Economy	19100.00
0005435517829	20943	Economy	19100.00
0005435319541	20943	Economy	19100.00
0005435508304	20943	Economy	21000.00
0005435319547	20943	Economy	21000.00
0005434573202	20943	Economy	19100.00
0005435319549	20943	Economy	19100.00
0005434573169	20943	Economy	19100.00
0005435319548	20943	Economy	19100.00
0005434573233	20943	Economy	19100.00
0005434573181	20943	Economy	19100.00
0005435517833	20943	Economy	19100.00
0005435502203	20943	Economy	19100.00
0005435502205	20943	Economy	19100.00
0005435502201	20943	Economy	19100.00
0005435517830	20943	Economy	19100.00
0005435502206	20943	Economy	19100.00
0005435517836	20943	Economy	19100.00
0005434573143	20943	Economy	19100.00
0005435508301	20943	Economy	19100.00
0005435502212	20943	Economy	19100.00
0005435502202	20943	Economy	19100.00
0005435517832	20943	Economy	19100.00
0005434573142	20943	Economy	19100.00
0005435502218	20943	Economy	19100.00
0005434573137	20943	Economy	19100.00
0005435502217	20943	Economy	19100.00
0005435517821	20943	Economy	19100.00
0005435508302	20943	Economy	19100.00
0005434573146	20943	Economy	19100.00
0005435319545	20943	Economy	19100.00
0005435517835	20943	Economy	19100.00
0005434573227	20943	Economy	19100.00
0005435517819	20943	Economy	19100.00
0005435517823	20943	Economy	19100.00
0005434573138	20943	Economy	19100.00
0005432291917	20943	Economy	19100.00
0005435517818	20943	Economy	19100.00
0005435517822	20943	Economy	19100.00
0005435502199	20943	Economy	19100.00
0005434573201	20943	Economy	19100.00
0005435517826	20943	Economy	19100.00
0005435502214	20943	Economy	19100.00
0005435502207	20943	Economy	19100.00
0005435502198	20943	Economy	19100.00
0005435319542	20943	Economy	19100.00
0005435319544	20943	Economy	19100.00
0005435517831	20943	Economy	19100.00
0005435517825	20943	Economy	19100.00
0005434573182	20943	Economy	19100.00
0005435508300	20943	Economy	19100.00
0005435517824	20943	Economy	19100.00
0005435502211	20943	Economy	19100.00
0005435517820	20943	Economy	19100.00
0005435508297	20943	Economy	19100.00
0005435502216	20943	Economy	19100.00
0005435508307	20943	Economy	19100.00
0005434573149	20943	Economy	19100.00
0005435502200	20943	Economy	19100.00
0005432291919	20943	Economy	19100.00
0005435502213	20943	Economy	19100.00
0005435502209	20943	Economy	19100.00
0005432291920	20943	Economy	19100.00
0005435508298	20943	Economy	19100.00
0005435508308	20943	Economy	19100.00
0005435502208	20943	Economy	19100.00
0005432692610	2951	Business	10300.00
0005432692663	2951	Business	10300.00
0005432692616	2951	Business	10300.00
0005432692574	2951	Business	10300.00
0005432692764	2951	Economy	3400.00
0005432692705	2951	Economy	3400.00
0005432692624	2951	Economy	3400.00
0005432692629	2951	Economy	3400.00
0005432692623	2951	Economy	3800.00
0005432692657	2951	Economy	3800.00
0005432692636	2951	Economy	3400.00
0005432692592	2951	Economy	3400.00
0005432692630	2951	Economy	3400.00
0005432692652	2951	Economy	3400.00
0005432692643	2951	Economy	3400.00
0005432692658	2951	Economy	3400.00
0005432692527	2951	Economy	3400.00
0005432692708	2951	Economy	3400.00
0005432692707	2951	Economy	3400.00
0005432692664	2951	Economy	3400.00
0005432692589	2951	Economy	3400.00
0005432692715	2951	Economy	3400.00
0005432692611	2951	Economy	3400.00
0005432692628	2951	Economy	3400.00
0005432692709	2951	Economy	3400.00
0005432692598	2951	Economy	3400.00
0005432692575	2951	Economy	3400.00
0005432692609	2951	Economy	3400.00
0005432692625	2951	Economy	3400.00
0005432692765	2951	Economy	3400.00
0005432692641	2951	Economy	3400.00
0005432692593	2951	Economy	3400.00
0005432692632	2951	Economy	3400.00
0005432692617	2951	Economy	3400.00
0005432692745	2951	Economy	3400.00
0005432692713	2951	Economy	3400.00
0005432692543	2951	Economy	3400.00
0005432692655	2951	Economy	3400.00
0005432692654	2951	Economy	3400.00
0005432706659	2952	Business	10300.00
0005433123628	2952	Business	10300.00
0005433123676	2952	Business	10300.00
0005432706664	2952	Business	10300.00
0005433123605	2952	Business	10300.00
0005432880643	2952	Business	10300.00
0005432880624	2952	Business	10300.00
0005433123680	2952	Business	10300.00
0005432706650	2952	Business	10300.00
0005432706655	2952	Economy	3400.00
0005432706674	2952	Economy	3400.00
0005432880609	2952	Economy	3400.00
0005433123668	2952	Economy	3400.00
0005432706667	2952	Economy	3400.00
0005432706649	2952	Economy	3400.00
0005432706651	2952	Economy	3400.00
0005432880623	2952	Economy	3400.00
0005432880625	2952	Economy	3800.00
0005433123675	2952	Economy	3800.00
0005432706662	2952	Economy	3800.00
0005432880672	2952	Economy	3400.00
0005433123625	2952	Economy	3400.00
0005432217765	2952	Economy	3400.00
0005432706666	2952	Economy	3400.00
0005433123633	2952	Economy	3400.00
0005433123669	2952	Economy	3400.00
0005432706668	2952	Economy	3400.00
0005433123687	2952	Economy	3400.00
0005432706652	2952	Economy	3400.00
0005432880596	2952	Economy	3400.00
0005432706654	2952	Economy	3400.00
0005433123674	2952	Economy	3400.00
0005432880586	2952	Economy	3400.00
0005432706663	2952	Economy	3400.00
0005433123630	2952	Economy	3400.00
0005433123629	2952	Economy	3400.00
0005432706661	2952	Economy	3400.00
0005432706653	2952	Economy	3400.00
0005433123659	2952	Economy	3400.00
0005432706656	2952	Economy	3400.00
0005432217764	2952	Economy	3400.00
0005432706672	2952	Economy	3400.00
0005432880644	2952	Economy	3400.00
0005432706670	2952	Economy	3400.00
0005432706669	2952	Economy	3400.00
0005433123688	2952	Economy	3400.00
0005432706658	2952	Economy	3400.00
0005432706648	2952	Economy	3400.00
0005432217762	2952	Economy	3400.00
0005432706673	2952	Economy	3400.00
0005432706660	2952	Economy	3400.00
0005432880610	2952	Economy	3400.00
0005432880622	2952	Economy	3400.00
0005433123655	2952	Economy	3400.00
0005432706657	2952	Economy	3400.00
0005432217763	2952	Economy	3400.00
0005432706665	2952	Economy	3400.00
0005432880637	2952	Economy	3400.00
0005432880600	2952	Economy	3400.00
0005433123646	2952	Economy	3400.00
0005432880646	2952	Economy	3400.00
0005432706671	2952	Economy	3400.00
0005432880754	30018	Business	10300.00
0005433123838	30018	Business	10300.00
0005432706492	30018	Business	10300.00
0005432880748	30018	Business	10300.00
0005432692949	30018	Business	10300.00
0005432692966	30018	Business	10300.00
0005433123830	30018	Business	10300.00
0005432692937	30018	Business	10300.00
0005432692938	30018	Business	10300.00
0005432692941	30018	Business	10300.00
0005432692960	30018	Business	10300.00
0005432692944	30018	Business	10300.00
0005432880750	30018	Economy	3400.00
0005432692945	30018	Economy	3400.00
0005432692959	30018	Economy	3400.00
0005433123841	30018	Economy	3400.00
0005432706458	30018	Economy	3400.00
0005432880746	30018	Economy	3400.00
0005433123834	30018	Economy	3400.00
0005432692939	30018	Economy	3400.00
0005433123836	30018	Economy	3400.00
0005433123833	30018	Economy	3400.00
0005432692950	30018	Economy	3800.00
0005432706449	30018	Economy	3800.00
0005432706502	30018	Economy	3800.00
0005432706500	30018	Economy	3800.00
0005432692952	30018	Economy	3800.00
0005433123843	30018	Economy	3400.00
0005432692958	30018	Economy	3400.00
0005433123842	30018	Economy	3400.00
0005433123829	30018	Economy	3400.00
0005432880749	30018	Economy	3400.00
0005432706486	30018	Economy	3400.00
0005432706531	30018	Economy	3400.00
0005432880755	30018	Economy	3400.00
0005432706557	30018	Economy	3400.00
0005432880757	30018	Economy	3400.00
0005432706478	30018	Economy	3400.00
0005432692963	30018	Economy	3400.00
0005432880751	30018	Economy	3400.00
0005432692957	30018	Economy	3400.00
0005432706537	30018	Economy	3400.00
0005432706441	30018	Economy	3400.00
0005432692954	30018	Economy	3400.00
0005432706487	30018	Economy	3400.00
0005432880759	30018	Economy	3400.00
0005432692968	30018	Economy	3400.00
0005432706450	30018	Economy	3400.00
0005432706493	30018	Economy	3400.00
0005432706536	30018	Economy	3400.00
0005433123827	30018	Economy	3400.00
0005432706389	30018	Economy	3400.00
0005432706510	30018	Economy	3400.00
0005432706444	30018	Economy	3400.00
0005432706420	30018	Economy	3400.00
0005432706496	30018	Economy	3400.00
0005433123828	30018	Economy	3400.00
0005432706425	30018	Economy	3400.00
0005432692965	30018	Economy	3400.00
0005432692967	30018	Economy	3400.00
0005432692942	30018	Economy	3400.00
0005432706491	30018	Economy	3400.00
0005432706446	30018	Economy	3400.00
0005432706419	30018	Economy	3400.00
0005432706507	30018	Economy	3400.00
0005432692940	30018	Economy	3400.00
0005432706483	30018	Economy	3400.00
0005432692956	30018	Economy	3400.00
0005432706570	30018	Economy	3400.00
0005432880756	30018	Economy	3400.00
0005432706503	30018	Economy	3400.00
0005432692946	30018	Economy	3400.00
0005432706390	30018	Economy	3400.00
0005433123831	30018	Economy	3400.00
0005432692962	30018	Economy	3400.00
0005432692948	30018	Economy	3400.00
0005432880752	30018	Economy	3400.00
0005432692961	30018	Economy	3400.00
0005432692951	30018	Economy	3400.00
0005432706501	30018	Economy	3400.00
0005432692943	30018	Economy	3400.00
0005433123839	30018	Economy	3400.00
0005433123840	30018	Economy	3400.00
0005432692964	30018	Economy	3400.00
0005432880753	30018	Economy	3400.00
0005432880747	30018	Economy	3400.00
0005432706479	30018	Economy	3400.00
0005432706494	30018	Economy	3400.00
0005433123837	30018	Economy	3400.00
0005432692955	30018	Economy	3400.00
0005432880760	30018	Economy	3400.00
0005432692947	30018	Economy	3400.00
0005432880758	30018	Economy	3400.00
0005432692953	30018	Economy	3400.00
0005432706530	30018	Economy	3400.00
0005433123832	30018	Economy	3400.00
0005433123835	30018	Economy	3400.00
0005434979627	23671	Economy	4000.00
0005434979631	23671	Economy	4000.00
0005434988682	23671	Economy	4000.00
0005434979633	23671	Economy	3600.00
0005434979646	23671	Economy	3600.00
0005434988683	23671	Economy	3600.00
0005434979636	23671	Economy	3600.00
0005434979623	23671	Economy	3600.00
0005434979637	23671	Economy	3600.00
0005434979649	23671	Economy	3600.00
0005434988687	23671	Economy	3600.00
0005434979628	23671	Economy	3600.00
0005434979644	23671	Economy	3600.00
0005434979629	23671	Economy	3600.00
0005434988678	23671	Economy	3600.00
0005434979635	23671	Economy	3600.00
0005434979634	23671	Economy	3600.00
0005434988689	23671	Economy	3600.00
0005434979641	23671	Economy	3600.00
0005434979648	23671	Economy	3600.00
0005434979651	23671	Economy	3600.00
0005434988684	23671	Economy	3600.00
0005434979643	23671	Economy	3600.00
0005434979632	23671	Economy	3600.00
0005434979645	23671	Economy	3600.00
0005434988688	23671	Economy	3600.00
0005434988685	23671	Economy	3600.00
0005434988681	23671	Economy	3600.00
0005434979625	23671	Economy	3600.00
0005434979640	23671	Economy	3600.00
0005434979647	23671	Economy	3600.00
0005434979650	23671	Economy	3600.00
0005434988680	23671	Economy	3600.00
0005434979642	23671	Economy	3600.00
0005434979626	23671	Economy	3600.00
0005434979630	23671	Economy	3600.00
0005434979639	23671	Economy	3600.00
0005434988686	23671	Economy	3600.00
0005434979638	23671	Economy	3600.00
0005434979622	23671	Economy	3600.00
0005434988679	23671	Economy	3600.00
0005434979624	23671	Economy	3600.00
0005434988578	27523	Economy	4000.00
0005434979333	27523	Economy	4000.00
0005434979405	27523	Economy	4000.00
0005434979402	27523	Economy	4000.00
0005434979401	27523	Economy	3600.00
0005434979429	27523	Economy	3600.00
0005434979340	27523	Economy	3600.00
0005434979304	27523	Economy	3600.00
0005434988567	27523	Economy	3600.00
0005434979371	27523	Economy	3600.00
0005434979408	27523	Economy	3600.00
0005434979316	27523	Economy	3600.00
0005434979364	27523	Economy	3600.00
0005434979415	27523	Economy	3600.00
0005434988581	27523	Economy	3600.00
0005434979386	27523	Economy	3600.00
0005434979453	27523	Economy	3600.00
0005434979361	27523	Economy	3600.00
0005434979461	27523	Economy	3600.00
0005434979346	27523	Economy	3600.00
0005434979332	27523	Economy	3600.00
0005434979404	27523	Economy	3600.00
0005434979324	27523	Economy	3600.00
0005434979444	27523	Economy	3600.00
0005434979409	27523	Economy	3600.00
0005434979292	27523	Economy	3600.00
0005434988577	27523	Economy	3600.00
0005434979339	27523	Economy	3600.00
0005434988558	27523	Economy	3600.00
0005434979414	27523	Economy	3600.00
0005434979460	27523	Economy	3600.00
0005434979329	27523	Economy	3600.00
0005434979387	27523	Economy	3600.00
0005434979326	27523	Economy	3600.00
0005434979467	27523	Economy	3600.00
0005434979406	27523	Economy	3600.00
0005434988579	27523	Economy	3600.00
0005434979394	27523	Economy	3600.00
0005434979277	27523	Economy	3600.00
0005434979315	27523	Economy	3600.00
0005434988580	27523	Economy	3600.00
0005434979400	27523	Economy	3600.00
0005434988568	27523	Economy	3600.00
0005434979385	27523	Economy	3600.00
0005434302438	10294	Economy	21600.00
0005434302436	10294	Economy	19700.00
0005434302435	10294	Economy	19700.00
0005434302856	10294	Economy	19700.00
0005434302437	10294	Economy	19700.00
0005433113502	10294	Economy	19700.00
0005433113527	19639	Economy	19700.00
0005433113526	19639	Economy	19700.00
0005434302398	19639	Economy	19700.00
0005433113528	19639	Economy	19700.00
0005435068865	3548	Business	26900.00
0005435068848	3548	Business	26900.00
0005435068892	3548	Business	26900.00
0005435068861	3548	Business	26900.00
0005435068868	3548	Business	26900.00
0005435068874	3548	Business	26900.00
0005435068851	3548	Business	26900.00
0005435068850	3548	Business	26900.00
0005435068860	3548	Business	26900.00
0005435068863	3548	Economy	9000.00
0005435925065	3548	Economy	9000.00
0005435068856	3548	Economy	9000.00
0005435068847	3548	Economy	9000.00
0005435925080	3548	Economy	9900.00
0005435068864	3548	Economy	9900.00
0005435068889	3548	Economy	9900.00
0005435068880	3548	Economy	9900.00
0005435068877	3548	Economy	9000.00
0005435068888	3548	Economy	9000.00
0005435925102	3548	Economy	9000.00
0005435068855	3548	Economy	9000.00
0005435068872	3548	Economy	9000.00
0005435068883	3548	Economy	9000.00
0005435068881	3548	Economy	9000.00
0005435925095	3548	Economy	9000.00
0005435068884	3548	Economy	9000.00
0005435068897	3548	Economy	9000.00
0005435925062	3548	Economy	9000.00
0005435068862	3548	Economy	9000.00
0005435068894	3548	Economy	9000.00
0005435068867	3548	Economy	9000.00
0005435718920	3548	Economy	9000.00
0005435068879	3548	Economy	9000.00
0005435068891	3548	Economy	9000.00
0005435068898	3548	Economy	9000.00
0005435068869	3548	Economy	9000.00
0005435068858	3548	Economy	9000.00
0005435068857	3548	Economy	9000.00
0005435068895	3548	Economy	9000.00
0005435925107	3548	Economy	9000.00
0005435068852	3548	Economy	9000.00
0005435068873	3548	Economy	9000.00
0005435068885	3548	Economy	9000.00
0005435068854	3548	Economy	9000.00
0005435068849	3548	Economy	9000.00
0005435068890	3548	Economy	9000.00
0005435068878	3548	Economy	9000.00
0005435068900	3548	Economy	9000.00
0005435925103	3548	Economy	9000.00
0005435925106	3548	Economy	9000.00
0005435068853	3548	Economy	9000.00
0005435068866	3548	Economy	9000.00
0005435068887	3548	Economy	9000.00
0005435068886	3548	Economy	9000.00
0005435068896	3548	Economy	9000.00
0005435068876	3548	Economy	9000.00
0005435068875	3548	Economy	9000.00
0005435068871	3548	Economy	9000.00
0005435925097	3548	Economy	9000.00
0005435068893	3548	Economy	9000.00
0005435068882	3548	Economy	9000.00
0005435068870	3548	Economy	9000.00
0005435925101	3548	Economy	9000.00
0005435068899	3548	Economy	9000.00
0005435068859	3548	Economy	9000.00
0005435925104	3548	Economy	9000.00
0005435068362	15275	Business	26900.00
0005435068428	15275	Business	26900.00
0005435925241	15275	Business	26900.00
0005435925238	15275	Business	26900.00
0005435925235	15275	Business	26900.00
0005435925236	15275	Business	26900.00
0005435068252	15275	Business	26900.00
0005435939873	15275	Business	26900.00
0005435925229	15275	Business	26900.00
0005435068429	15275	Economy	9000.00
0005435068271	15275	Economy	9000.00
0005435068361	15275	Economy	9000.00
0005435925224	15275	Economy	9000.00
0005435068496	15275	Economy	9000.00
0005435068272	15275	Economy	9000.00
0005435068497	15275	Economy	9000.00
0005435068350	15275	Economy	9000.00
0005435068404	15275	Economy	9900.00
0005435925233	15275	Economy	9900.00
0005435068265	15275	Economy	9000.00
0005435068448	15275	Economy	9000.00
0005435068447	15275	Economy	9000.00
0005435925242	15275	Economy	9000.00
0005435068526	15275	Economy	9000.00
0005435939874	15275	Economy	9000.00
0005435068495	15275	Economy	9000.00
0005435068471	15275	Economy	9000.00
0005435068446	15275	Economy	9000.00
0005435068239	15275	Economy	9000.00
0005435068435	15275	Economy	9000.00
0005435925225	15275	Economy	9000.00
0005435068169	15275	Economy	9000.00
0005435068268	15275	Economy	9000.00
0005435068335	15275	Economy	9000.00
0005435925228	15275	Economy	9000.00
0005435068251	15275	Economy	9000.00
0005435068438	15275	Economy	9000.00
0005435925226	15275	Economy	9000.00
0005435068489	15275	Economy	9000.00
0005435068498	15275	Economy	9000.00
0005435068406	15275	Economy	9000.00
0005435068263	15275	Economy	9000.00
0005435068311	15275	Economy	9000.00
0005435068499	15275	Economy	9000.00
0005435068269	15275	Economy	9000.00
0005435068440	15275	Economy	9000.00
0005435925230	15275	Economy	9000.00
0005435925222	15275	Economy	9000.00
0005435068310	15275	Economy	9000.00
0005435925240	15275	Economy	9000.00
0005435068212	15275	Economy	9000.00
0005435068537	15275	Economy	9000.00
0005435925227	15275	Economy	9000.00
0005435068538	15275	Economy	9000.00
0005435068270	15275	Economy	9000.00
0005435925231	15275	Economy	9000.00
0005435925234	15275	Economy	9000.00
0005435925223	15275	Economy	9000.00
0005435068581	15275	Economy	9000.00
0005435068409	15275	Economy	9000.00
0005435068221	15275	Economy	9000.00
0005435925219	15275	Economy	9000.00
0005435925232	15275	Economy	9000.00
0005435925237	15275	Economy	9000.00
0005435068536	15275	Economy	9000.00
0005435068405	15275	Economy	9000.00
0005435925220	15275	Economy	9000.00
0005435925239	15275	Economy	9000.00
0005435068371	15275	Economy	9000.00
0005435068381	15275	Economy	9000.00
0005435068343	15275	Economy	9000.00
0005435925221	15275	Economy	9000.00
0005435068488	15275	Economy	9000.00
0005435925243	15275	Economy	9000.00
0005435068334	15275	Economy	9000.00
0005432660808	18213	Economy	5900.00
0005432659697	18213	Economy	5900.00
0005432660809	18213	Economy	5900.00
0005432658582	18213	Economy	5900.00
0005432660810	18213	Economy	5900.00
0005432659698	18213	Economy	5900.00
0005432667427	26426	Economy	5900.00
0005432660788	26426	Economy	5900.00
0005432660790	26426	Economy	5900.00
0005432667428	26426	Economy	5900.00
0005432667426	26426	Economy	5900.00
0005432660789	26426	Economy	5900.00
0005433101490	125	Business	20000.00
0005433101568	125	Business	20000.00
0005433101474	125	Business	20000.00
0005433101483	125	Business	20000.00
0005433101555	125	Business	20000.00
0005433101584	125	Business	20000.00
0005432919591	125	Business	20000.00
0005433101575	125	Business	20000.00
0005433101437	125	Business	20000.00
0005432919669	125	Business	20000.00
0005433101547	125	Business	20000.00
0005433101408	125	Business	20000.00
0005433101469	125	Business	20000.00
0005433101372	125	Business	20000.00
0005433101516	125	Business	20000.00
0005433101564	125	Economy	7300.00
0005433101536	125	Economy	7300.00
0005432677519	125	Economy	6700.00
0005433101480	125	Economy	6700.00
0005432157483	125	Economy	6700.00
0005433101400	125	Economy	6700.00
0005433101299	125	Economy	6700.00
0005433101522	125	Economy	6700.00
0005433101433	125	Economy	6700.00
0005432157485	125	Economy	6700.00
0005433101350	125	Economy	6700.00
0005433101576	125	Economy	6700.00
0005432901501	125	Economy	6700.00
0005432901379	125	Economy	6700.00
0005432919578	125	Economy	6700.00
0005433101371	125	Economy	6700.00
0005432677533	125	Economy	6700.00
0005433101395	125	Economy	6700.00
0005433101349	125	Economy	6700.00
0005432919643	125	Economy	6700.00
0005433101423	125	Economy	6700.00
0005433101556	125	Economy	6700.00
0005433101245	125	Economy	6700.00
0005432919617	125	Economy	6700.00
0005432677529	125	Economy	6700.00
0005432901410	125	Economy	6700.00
0005433101193	125	Economy	6700.00
0005433101475	125	Economy	6700.00
0005433101361	125	Economy	6700.00
0005433101192	125	Economy	6700.00
0005433101482	125	Economy	6700.00
0005433101255	125	Economy	6700.00
0005433101419	125	Economy	6700.00
0005432901403	125	Economy	6700.00
0005433101492	125	Economy	6700.00
0005432901353	125	Economy	6700.00
0005432919710	125	Economy	6700.00
0005433101436	125	Economy	6700.00
0005433101472	125	Economy	6700.00
0005432919539	125	Economy	6700.00
0005433101407	125	Economy	6700.00
0005432901406	125	Economy	6700.00
0005432919614	125	Economy	6700.00
0005433101470	125	Economy	6700.00
0005433101452	125	Economy	7300.00
0005432919615	125	Economy	7300.00
0005433101348	125	Economy	7300.00
0005432157484	125	Economy	7300.00
0005432901417	125	Economy	6700.00
0005432919530	125	Economy	6700.00
0005433101294	125	Economy	6700.00
0005433101391	125	Economy	6700.00
0005433101510	125	Economy	7300.00
0005433101444	125	Economy	6700.00
0005433101535	125	Economy	6700.00
0005432919549	125	Economy	6700.00
0005433101565	125	Economy	6700.00
0005432901418	125	Economy	6700.00
0005432677528	125	Economy	6700.00
0005433101319	125	Economy	6700.00
0005433101420	125	Economy	6700.00
0005433101558	125	Economy	6700.00
0005432919644	125	Economy	6700.00
0005432919628	125	Economy	6700.00
0005433101515	125	Economy	6700.00
0005433101406	125	Economy	6700.00
0005433101481	125	Economy	6700.00
0005433101454	125	Economy	6700.00
0005433101520	125	Economy	6700.00
0005432919577	125	Economy	6700.00
0005433101583	125	Economy	6700.00
0005433101548	125	Economy	6700.00
0005433101585	125	Economy	6700.00
0005432919616	125	Economy	6700.00
0005432901407	125	Economy	6700.00
0005433101373	125	Economy	6700.00
0005433101489	125	Economy	6700.00
0005432901463	125	Economy	6700.00
0005433101297	125	Economy	6700.00
0005432901373	125	Economy	6700.00
0005433101574	125	Economy	6700.00
0005433101354	125	Economy	6700.00
0005433101546	125	Economy	6700.00
0005432919654	125	Economy	6700.00
0005433101362	125	Economy	6700.00
0005433101445	125	Economy	6700.00
0005433101353	125	Economy	6700.00
0005433101253	125	Economy	6700.00
0005432901366	125	Economy	6700.00
0005433101509	125	Economy	6700.00
0005432919711	125	Economy	6700.00
0005433101355	125	Economy	6700.00
0005433101563	125	Economy	6700.00
0005432919546	125	Economy	6700.00
0005433101379	125	Economy	6700.00
0005432919590	125	Economy	6700.00
0005433101511	125	Economy	6700.00
0005433101254	125	Economy	6700.00
0005432919655	125	Economy	6700.00
0005432261733	126	Business	20000.00
0005432817345	126	Business	20000.00
0005432261703	126	Business	20000.00
0005432261717	126	Business	20000.00
0005432261738	126	Business	20000.00
0005432756793	126	Business	20000.00
0005432817360	126	Business	20000.00
0005432261705	126	Business	20000.00
0005432261697	126	Business	20000.00
0005432817332	126	Business	20000.00
0005432817352	126	Business	20000.00
0005432261727	126	Business	20000.00
0005432817336	126	Business	20000.00
0005432261704	126	Business	20000.00
0005432817349	126	Business	20000.00
0005432817351	126	Business	20000.00
0005432817348	126	Business	20000.00
0005432261698	126	Economy	7300.00
0005432817342	126	Economy	7300.00
0005432207651	126	Economy	7300.00
0005432261699	126	Economy	7300.00
0005432261710	126	Economy	6700.00
0005432756802	126	Economy	6700.00
0005432261702	126	Economy	6700.00
0005432261708	126	Economy	6700.00
0005432261696	126	Economy	6700.00
0005432261732	126	Economy	6700.00
0005432817362	126	Economy	6700.00
0005432817341	126	Economy	6700.00
0005432261700	126	Economy	6700.00
0005432817344	126	Economy	6700.00
0005432817347	126	Economy	6700.00
0005432817346	126	Economy	6700.00
0005432207648	126	Economy	6700.00
0005432753278	126	Economy	6700.00
0005432261719	126	Economy	6700.00
0005432261731	126	Economy	6700.00
0005432288973	126	Economy	6700.00
0005432261722	126	Economy	6700.00
0005432261726	126	Economy	6700.00
0005432261729	126	Economy	6700.00
0005432817340	126	Economy	6700.00
0005432817357	126	Economy	6700.00
0005432817334	126	Economy	6700.00
0005432756791	126	Economy	6700.00
0005432817335	126	Economy	6700.00
0005432817356	126	Economy	6700.00
0005432207649	126	Economy	6700.00
0005432261736	126	Economy	6700.00
0005432261709	126	Economy	6700.00
0005432817333	126	Economy	6700.00
0005432817338	126	Economy	6700.00
0005432261706	126	Economy	7300.00
0005432756790	126	Economy	7300.00
0005434153527	126	Economy	7300.00
0005432817354	126	Economy	6700.00
0005432261734	126	Economy	6700.00
0005432261741	126	Economy	6700.00
0005432817343	126	Economy	6700.00
0005432261724	126	Economy	6700.00
0005432261728	126	Economy	6700.00
0005432261715	126	Economy	6700.00
0005432261716	126	Economy	6700.00
0005432817355	126	Economy	6700.00
0005432261720	126	Economy	6700.00
0005432261739	126	Economy	6700.00
0005432261712	126	Economy	6700.00
0005432261721	126	Economy	6700.00
0005432288972	126	Economy	6700.00
0005432261723	126	Economy	6700.00
0005432753255	126	Economy	6700.00
0005432261714	126	Economy	6700.00
0005432817358	126	Economy	6700.00
0005432261695	126	Economy	6700.00
0005432261718	126	Economy	6700.00
0005432288971	126	Economy	6700.00
0005432261730	126	Economy	6700.00
0005432207650	126	Economy	6700.00
0005432261713	126	Economy	6700.00
0005432261735	126	Economy	6700.00
0005432261707	126	Economy	6700.00
0005432261740	126	Economy	6700.00
0005432817361	126	Economy	6700.00
0005432261737	126	Economy	6700.00
0005432756804	126	Economy	6700.00
0005432756803	126	Economy	6700.00
0005432817353	126	Economy	6700.00
0005432817339	126	Economy	6700.00
0005432817359	126	Economy	6700.00
0005432261701	126	Economy	6700.00
0005432817337	126	Economy	6700.00
0005432817350	126	Economy	6700.00
0005432261725	126	Economy	6700.00
0005432261711	126	Economy	6700.00
0005432261742	126	Economy	6700.00
0005433101906	8115	Business	20000.00
0005433101946	8115	Business	20000.00
0005433101954	8115	Business	20000.00
0005432751513	8115	Business	20000.00
0005433101960	8115	Business	20000.00
0005433101933	8115	Business	20000.00
0005432919778	8115	Business	20000.00
0005432020145	8115	Business	20000.00
0005432020143	8115	Business	20000.00
0005433101918	8115	Business	20000.00
0005433101920	8115	Business	20000.00
0005432919767	8115	Business	20000.00
0005432753286	8115	Business	20000.00
0005433101941	8115	Business	20000.00
0005433101952	8115	Business	20000.00
0005432919770	8115	Business	20000.00
0005432677558	8115	Business	20000.00
0005433101964	8115	Business	20000.00
0005433101928	8115	Business	20000.00
0005432919768	8115	Business	20000.00
0005433101942	8115	Business	20000.00
0005432020148	8115	Economy	7300.00
0005433101959	8115	Economy	7300.00
0005433101949	8115	Economy	7300.00
0005432919765	8115	Economy	7300.00
0005433101932	8115	Economy	7300.00
0005432044513	8115	Economy	7300.00
0005433101925	8115	Economy	6700.00
0005433101948	8115	Economy	6700.00
0005433101937	8115	Economy	6700.00
0005432020155	8115	Economy	6700.00
0005433101911	8115	Economy	6700.00
0005432020149	8115	Economy	6700.00
0005432020159	8115	Economy	6700.00
0005433101947	8115	Economy	6700.00
0005432020146	8115	Economy	6700.00
0005432919763	8115	Economy	6700.00
0005432919777	8115	Economy	6700.00
0005433101902	8115	Economy	6700.00
0005433101944	8115	Economy	6700.00
0005432045606	8115	Economy	6700.00
0005432020158	8115	Economy	6700.00
0005433101917	8115	Economy	6700.00
0005432919760	8115	Economy	6700.00
0005432020154	8115	Economy	6700.00
0005433101963	8115	Economy	6700.00
0005432919774	8115	Economy	6700.00
0005433101935	8115	Economy	6700.00
0005432919776	8115	Economy	6700.00
0005432919773	8115	Economy	6700.00
0005432020153	8115	Economy	6700.00
0005433101936	8115	Economy	6700.00
0005433101938	8115	Economy	6700.00
0005432919762	8115	Economy	6700.00
0005433101907	8115	Economy	6700.00
0005432919769	8115	Economy	6700.00
0005432020136	8115	Economy	6700.00
0005433101930	8115	Economy	6700.00
0005433101913	8115	Economy	6700.00
0005433101912	8115	Economy	6700.00
0005433101915	8115	Economy	6700.00
0005432677556	8115	Economy	6700.00
0005432391988	8115	Economy	6700.00
0005432391986	8115	Economy	6700.00
0005433101910	8115	Economy	6700.00
0005433101909	8115	Economy	6700.00
0005433101921	8115	Economy	6700.00
0005432919780	8115	Economy	6700.00
0005432753287	8115	Economy	6700.00
0005432020147	8115	Economy	6700.00
0005432020160	8115	Economy	6700.00
0005432919766	8115	Economy	6700.00
0005433101908	8115	Economy	7300.00
0005433101934	8115	Economy	6700.00
0005432919764	8115	Economy	7300.00
0005432751514	8115	Economy	7300.00
0005433101914	8115	Economy	7300.00
0005432020151	8115	Economy	6700.00
0005432020157	8115	Economy	7300.00
0005433101955	8115	Economy	6700.00
0005433101919	8115	Economy	6700.00
0005433101926	8115	Economy	6700.00
0005432020140	8115	Economy	6700.00
0005432677559	8115	Economy	6700.00
0005433101904	8115	Economy	6700.00
0005432020156	8115	Economy	6700.00
0005432020152	8115	Economy	6700.00
0005432020138	8115	Economy	6700.00
0005433101945	8115	Economy	6700.00
0005432919775	8115	Economy	6700.00
0005433101931	8115	Economy	6700.00
0005433101924	8115	Economy	6700.00
0005432751512	8115	Economy	6700.00
0005433101923	8115	Economy	6700.00
0005433101958	8115	Economy	6700.00
0005432020161	8115	Economy	6700.00
0005432044512	8115	Economy	6700.00
0005433101905	8115	Economy	6700.00
0005433101957	8115	Economy	6700.00
0005433101927	8115	Economy	6700.00
0005433101950	8115	Economy	6700.00
0005432020150	8115	Economy	6700.00
0005432020141	8115	Economy	6700.00
0005433101929	8115	Economy	6700.00
0005432020139	8115	Economy	6700.00
0005433101922	8115	Economy	6700.00
0005433101961	8115	Economy	6700.00
0005433101916	8115	Economy	6700.00
0005432919761	8115	Economy	6700.00
0005432753288	8115	Economy	6700.00
0005432020162	8115	Economy	6700.00
0005432044514	8115	Economy	6700.00
0005432919771	8115	Economy	6700.00
0005433101951	8115	Economy	6700.00
0005433101953	8115	Economy	6700.00
0005433101903	8115	Economy	6700.00
0005432919772	8115	Economy	6700.00
0005432677557	8115	Economy	6700.00
0005432020144	8115	Economy	6700.00
0005433101962	8115	Economy	6700.00
0005433101956	8115	Economy	6700.00
0005432020137	8115	Economy	6700.00
0005432045607	8115	Economy	6700.00
0005432020142	8115	Economy	6700.00
0005433101943	8115	Economy	6700.00
0005433101939	8115	Economy	6700.00
0005433101940	8115	Economy	6700.00
0005432391987	8115	Economy	6700.00
0005432045605	8115	Economy	6700.00
0005432753289	8115	Economy	6700.00
0005432919779	8115	Economy	6700.00
0005432817046	8114	Business	20000.00
0005432901541	8114	Business	20000.00
0005432817146	8114	Business	20000.00
0005432817161	8114	Business	20000.00
0005432901534	8114	Business	20000.00
0005432817135	8114	Business	20000.00
0005432817109	8114	Business	20000.00
0005432817031	8114	Business	20000.00
0005432817030	8114	Business	20000.00
0005432901540	8114	Business	20000.00
0005432817058	8114	Business	20000.00
0005432901531	8114	Economy	7300.00
0005432002067	8114	Economy	6700.00
0005432901530	8114	Economy	6700.00
0005432901536	8114	Economy	6700.00
0005432817038	8114	Economy	6700.00
0005432817045	8114	Economy	6700.00
0005432816957	8114	Economy	6700.00
0005432817120	8114	Economy	6700.00
0005432817154	8114	Economy	6700.00
0005432901542	8114	Economy	6700.00
0005432817118	8114	Economy	6700.00
0005432901545	8114	Economy	6700.00
0005432817025	8114	Economy	6700.00
0005432901544	8114	Economy	6700.00
0005432002066	8114	Economy	6700.00
0005432817162	8114	Economy	6700.00
0005432901528	8114	Economy	6700.00
0005432817082	8114	Economy	6700.00
0005432817039	8114	Economy	6700.00
0005432901533	8114	Economy	6700.00
0005432817032	8114	Economy	6700.00
0005432901527	8114	Economy	6700.00
0005432817083	8114	Economy	6700.00
0005432816965	8114	Economy	6700.00
0005432901538	8114	Economy	6700.00
0005432817153	8114	Economy	6700.00
0005432901543	8114	Economy	6700.00
0005432817112	8114	Economy	6700.00
0005432901537	8114	Economy	6700.00
0005432901539	8114	Economy	6700.00
0005432901535	8114	Economy	6700.00
0005432901532	8114	Economy	6700.00
0005432901529	8114	Economy	6700.00
0005432817081	8114	Economy	6700.00
0005432817012	8114	Economy	6700.00
0005432817134	8114	Economy	6700.00
0005432817024	8114	Economy	6700.00
0005432817013	8114	Economy	6700.00
0005432817100	8114	Economy	6700.00
0005433870721	9668	Economy	6900.00
0005434175704	9668	Economy	6900.00
0005433870722	9668	Economy	6900.00
0005434175694	9668	Economy	6900.00
0005434175698	9668	Economy	6900.00
0005434175716	9668	Economy	6900.00
0005434175736	32353	Economy	6900.00
0005433870701	32353	Economy	6900.00
0005433870702	32353	Economy	6900.00
0005434175735	32353	Economy	6900.00
0005434175734	32353	Economy	6900.00
0005434175733	32353	Economy	6900.00
0005434426492	3506	Business	35000.00
0005432188596	3506	Business	35000.00
0005434877835	3506	Business	35000.00
0005435902441	3506	Business	35000.00
0005434426476	3506	Business	35000.00
0005435126217	3506	Business	35000.00
0005434877873	3506	Business	35000.00
0005434877817	3506	Business	35000.00
0005434877869	3506	Business	35000.00
0005435913858	3506	Business	35000.00
0005435626096	3506	Business	35000.00
0005434877844	3506	Business	35000.00
0005434426504	3506	Business	35000.00
0005435902449	3506	Business	35000.00
0005435902429	3506	Business	35000.00
0005434877895	3506	Business	35000.00
0005434877850	3506	Business	35000.00
0005434877857	3506	Business	35000.00
0005432799345	3506	Business	35000.00
0005432799341	3506	Business	35000.00
0005434877827	3506	Business	35000.00
0005434877837	3506	Comfort	19900.00
0005435626093	3506	Comfort	19900.00
0005434877823	3506	Comfort	19900.00
0005434877896	3506	Comfort	19900.00
0005434938063	3506	Comfort	19900.00
0005434877907	3506	Comfort	19900.00
0005435126200	3506	Comfort	19900.00
0005434938066	3506	Comfort	19900.00
0005434877822	3506	Comfort	19900.00
0005434877885	3506	Comfort	19900.00
0005435902440	3506	Comfort	19900.00
0005435902546	3506	Comfort	19900.00
0005435126214	3506	Comfort	19900.00
0005435126215	3506	Comfort	19900.00
0005434426479	3506	Comfort	19900.00
0005435126220	3506	Comfort	19900.00
0005434938068	3506	Comfort	19900.00
0005435841082	3506	Comfort	19900.00
0005434877856	3506	Comfort	19900.00
0005435626097	3506	Comfort	19900.00
0005435902512	3506	Comfort	19900.00
0005434877880	3506	Comfort	19900.00
0005434877821	3506	Comfort	19900.00
0005434426493	3506	Comfort	19900.00
0005434877883	3506	Comfort	19900.00
0005435126211	3506	Comfort	19900.00
0005434938056	3506	Comfort	19900.00
0005434877881	3506	Comfort	19900.00
0005434877864	3506	Comfort	19900.00
0005434426499	3506	Comfort	19900.00
0005434877858	3506	Economy	11700.00
0005434877900	3506	Economy	11700.00
0005434938059	3506	Economy	11700.00
0005435126230	3506	Economy	11700.00
0005435126191	3506	Economy	11700.00
0005434877876	3506	Economy	11700.00
0005434877830	3506	Economy	11700.00
0005435913863	3506	Economy	11700.00
0005432799337	3506	Economy	11700.00
0005434426498	3506	Economy	11700.00
0005435126229	3506	Economy	11700.00
0005434877889	3506	Economy	11700.00
0005432799357	3506	Economy	11700.00
0005434426503	3506	Economy	11700.00
0005434877852	3506	Economy	11700.00
0005434938065	3506	Economy	11700.00
0005434877849	3506	Economy	11700.00
0005434877820	3506	Economy	11700.00
0005434877887	3506	Economy	11700.00
0005434877819	3506	Economy	11700.00
0005432799340	3506	Economy	11700.00
0005435126201	3506	Economy	11700.00
0005432799343	3506	Economy	11700.00
0005435126225	3506	Economy	11700.00
0005434426497	3506	Economy	11700.00
0005435126228	3506	Economy	11700.00
0005435902543	3506	Economy	11700.00
0005435126188	3506	Economy	11700.00
0005435126207	3506	Economy	11700.00
0005432183458	3506	Economy	11700.00
0005434938055	3506	Economy	11700.00
0005435626094	3506	Economy	11700.00
0005434426487	3506	Economy	11700.00
0005434938069	3506	Economy	11700.00
0005435626095	3506	Economy	11700.00
0005434877863	3506	Economy	11700.00
0005435126199	3506	Economy	11700.00
0005434877826	3506	Economy	11700.00
0005432799347	3506	Economy	11700.00
0005432611695	3506	Economy	11700.00
0005434877870	3506	Economy	11700.00
0005432799336	3506	Economy	11700.00
0005435626106	3506	Economy	11700.00
0005434877855	3506	Economy	11700.00
0005434877901	3506	Economy	11700.00
0005435626102	3506	Economy	11700.00
0005434877872	3506	Economy	12800.00
0005434938061	3506	Economy	11700.00
0005434877908	3506	Economy	12800.00
0005435126223	3506	Economy	12800.00
0005435126206	3506	Economy	11700.00
0005432799331	3506	Economy	11700.00
0005435626108	3506	Economy	11700.00
0005435902387	3506	Economy	12800.00
0005434877847	3506	Economy	12800.00
0005434877879	3506	Economy	11700.00
0005434938057	3506	Economy	12800.00
0005435126210	3506	Economy	11700.00
0005432611694	3506	Economy	11700.00
0005434426501	3506	Economy	11700.00
0005435126227	3506	Economy	11700.00
0005434938058	3506	Economy	11700.00
0005434877877	3506	Economy	11700.00
0005435126198	3506	Economy	11700.00
0005432799346	3506	Economy	11700.00
0005434938072	3506	Economy	11700.00
0005432799356	3506	Economy	11700.00
0005434877898	3506	Economy	11700.00
0005434938064	3506	Economy	11700.00
0005435126219	3506	Economy	11700.00
0005434938053	3506	Economy	11700.00
0005434426488	3506	Economy	11700.00
0005434877843	3506	Economy	11700.00
0005434877838	3506	Economy	11700.00
0005435626101	3506	Economy	11700.00
0005434877897	3506	Economy	11700.00
0005434877831	3506	Economy	11700.00
0005435126195	3506	Economy	11700.00
0005432799342	3506	Economy	11700.00
0005434877832	3506	Economy	11700.00
0005435126189	3506	Economy	11700.00
0005434877833	3506	Economy	11700.00
0005434938054	3506	Economy	11700.00
0005434877845	3506	Economy	11700.00
0005435626105	3506	Economy	11700.00
0005434877899	3506	Economy	11700.00
0005432799339	3506	Economy	11700.00
0005435902492	3506	Economy	11700.00
0005434877890	3506	Economy	11700.00
0005432799353	3506	Economy	11700.00
0005435913864	3506	Economy	11700.00
0005434877894	3506	Economy	11700.00
0005435126208	3506	Economy	11700.00
0005434426505	3506	Economy	11700.00
0005434877860	3506	Economy	11700.00
0005434938062	3506	Economy	11700.00
0005434426495	3506	Economy	11700.00
0005434877867	3506	Economy	11700.00
0005435913856	3506	Economy	11700.00
0005435902491	3506	Economy	11700.00
0005434877836	3506	Economy	11700.00
0005435841813	3506	Economy	11700.00
0005434938070	3506	Economy	11700.00
0005435126204	3506	Economy	11700.00
0005434877854	3506	Economy	11700.00
0005432188597	3506	Economy	11700.00
0005434877910	3506	Economy	11700.00
0005434877875	3506	Economy	11700.00
0005432799330	3506	Economy	11700.00
0005434877868	3506	Economy	11700.00
0005434938060	3506	Economy	11700.00
0005435902389	3506	Economy	11700.00
0005435126193	3506	Economy	11700.00
0005435126190	3506	Economy	11700.00
0005434877892	3506	Economy	11700.00
0005434877905	3506	Economy	11700.00
0005432799350	3506	Economy	11700.00
0005434426484	3506	Economy	11700.00
0005434877859	3506	Economy	11700.00
0005435126221	3506	Economy	11700.00
0005434877816	3506	Economy	11700.00
0005435126196	3506	Economy	11700.00
0005434877886	3506	Economy	11700.00
0005435126209	3506	Economy	11700.00
0005435902466	3506	Economy	11700.00
0005434877824	3506	Economy	11700.00
0005435913867	3506	Economy	11700.00
0005434877878	3506	Economy	11700.00
0005434877882	3506	Economy	11700.00
0005432799335	3506	Economy	11700.00
0005432799329	3506	Economy	11700.00
0005432613845	3506	Economy	11700.00
0005435126218	3506	Economy	11700.00
0005432188595	3506	Economy	11700.00
0005435913865	3506	Economy	11700.00
0005435126226	3506	Economy	11700.00
0005434426494	3506	Economy	11700.00
0005434426477	3506	Economy	11700.00
0005435902542	3506	Economy	11700.00
0005432799352	3506	Economy	11700.00
0005434426478	3506	Economy	11700.00
0005434426485	3506	Economy	11700.00
0005434426491	3506	Economy	12800.00
0005432799344	3506	Economy	12800.00
0005434426500	3506	Economy	12800.00
0005432799348	3506	Economy	12800.00
0005435626109	3506	Economy	11700.00
0005432613844	3506	Economy	11700.00
0005434877865	3506	Economy	11700.00
0005432799354	3506	Economy	11700.00
0005434877884	3506	Economy	11700.00
0005434877866	3506	Economy	11700.00
0005434877893	3506	Economy	11700.00
0005434877906	3506	Economy	11700.00
0005435913866	3506	Economy	11700.00
0005435902503	3506	Economy	11700.00
0005435902504	3506	Economy	11700.00
0005434426483	3506	Economy	11700.00
0005434426490	3506	Economy	11700.00
0005434877842	3506	Economy	11700.00
0005435626098	3506	Economy	11700.00
0005432799351	3506	Economy	11700.00
0005435902386	3506	Economy	11700.00
0005432799338	3506	Economy	11700.00
0005434877818	3506	Economy	11700.00
0005435902388	3506	Economy	11700.00
0005435902467	3506	Economy	11700.00
0005435902464	3506	Economy	11700.00
0005434877888	3506	Economy	11700.00
0005434426489	3506	Economy	11700.00
0005435626103	3506	Economy	11700.00
0005434877848	3506	Economy	11700.00
0005435126194	3506	Economy	11700.00
0005434938067	3506	Economy	11700.00
0005434877903	3506	Economy	11700.00
0005432799333	3506	Economy	11700.00
0005432188594	3506	Economy	11700.00
0005435126205	3506	Economy	11700.00
0005435126213	3506	Economy	11700.00
0005435126192	3506	Economy	11700.00
0005432799355	3506	Economy	11700.00
0005434877871	3506	Economy	11700.00
0005435626099	3506	Economy	11700.00
0005434426480	3506	Economy	11700.00
0005434877862	3506	Economy	11700.00
0005434877828	3506	Economy	11700.00
0005435126197	3506	Economy	11700.00
0005435126222	3506	Economy	11700.00
0005435126224	3506	Economy	11700.00
0005434877839	3506	Economy	11700.00
0005435126202	3506	Economy	11700.00
0005434877909	3506	Economy	11700.00
0005434877904	3506	Economy	11700.00
0005435902516	3506	Economy	11700.00
0005435126212	3506	Economy	11700.00
0005434938071	3506	Economy	11700.00
0005435626104	3506	Economy	11700.00
0005434877874	3506	Economy	11700.00
0005434426496	3506	Economy	11700.00
0005435126203	3506	Economy	11700.00
0005435626107	3506	Economy	11700.00
0005434877834	3506	Economy	11700.00
0005434877861	3506	Economy	11700.00
0005435626092	3506	Economy	11700.00
0005435626100	3506	Economy	11700.00
0005434426486	3506	Economy	11700.00
0005435902406	3506	Economy	11700.00
0005434877841	3506	Economy	11700.00
0005432613846	3506	Economy	11700.00
0005432799334	3506	Economy	11700.00
0005434877840	3506	Economy	11700.00
0005434426481	3506	Economy	11700.00
0005434877902	3506	Economy	11700.00
0005434877825	3506	Economy	11700.00
0005434877846	3506	Economy	11700.00
0005434426502	3506	Economy	11700.00
0005434877853	3506	Economy	11700.00
0005435126216	3506	Economy	11700.00
0005434877891	3506	Economy	11700.00
0005434877829	3506	Economy	11700.00
0005434938052	3506	Economy	11700.00
0005434877851	3506	Economy	11700.00
0005434426482	3506	Economy	11700.00
0005432799332	3506	Economy	11700.00
0005432611693	3506	Economy	11700.00
0005432799349	3506	Economy	11700.00
0005434937863	14591	Business	35000.00
0005434876750	14591	Business	35000.00
0005435902633	14591	Business	35000.00
0005432799071	14591	Business	35000.00
0005434876992	14591	Business	35000.00
0005435125814	14591	Business	35000.00
0005435125787	14591	Business	35000.00
0005434877189	14591	Business	35000.00
0005434877338	14591	Business	35000.00
0005435125827	14591	Business	35000.00
0005432799003	14591	Business	35000.00
0005435625914	14591	Business	35000.00
0005434876964	14591	Business	35000.00
0005432611665	14591	Business	35000.00
0005434877119	14591	Business	35000.00
0005434876932	14591	Business	35000.00
0005434426303	14591	Business	35000.00
0005432059495	14591	Business	35000.00
0005434426260	14591	Business	35000.00
0005432799122	14591	Business	35000.00
0005435125765	14591	Comfort	19900.00
0005434877020	14591	Business	35000.00
0005434937897	14591	Comfort	19900.00
0005432799100	14591	Comfort	19900.00
0005434877067	14591	Comfort	19900.00
0005435625890	14591	Comfort	19900.00
0005434877242	14591	Comfort	19900.00
0005434876978	14591	Comfort	19900.00
0005435125715	14591	Comfort	19900.00
0005435625920	14591	Comfort	19900.00
0005434877139	14591	Comfort	19900.00
0005434877140	14591	Comfort	19900.00
0005434877131	14591	Comfort	19900.00
0005432799187	14591	Comfort	19900.00
0005434937895	14591	Comfort	19900.00
0005432059496	14591	Comfort	19900.00
0005434877055	14591	Comfort	19900.00
0005435902630	14591	Comfort	19900.00
0005434877347	14591	Comfort	19900.00
0005432799125	14591	Comfort	19900.00
0005434876955	14591	Comfort	19900.00
0005432799102	14591	Comfort	19900.00
0005434877036	14591	Comfort	19900.00
0005434426204	14591	Comfort	19900.00
0005435625941	14591	Comfort	19900.00
0005434877123	14591	Comfort	19900.00
0005434876821	14591	Comfort	19900.00
0005435125750	14591	Comfort	19900.00
0005435625888	14591	Comfort	19900.00
0005435625887	14591	Comfort	19900.00
0005434876828	14591	Comfort	19900.00
0005435902623	14591	Comfort	19900.00
0005432799020	14591	Comfort	19900.00
0005434877185	14591	Comfort	19900.00
0005434876983	14591	Comfort	19900.00
0005434877227	14591	Comfort	19900.00
0005432799081	14591	Economy	11700.00
0005434426241	14591	Economy	11700.00
0005434877191	14591	Economy	11700.00
0005434937907	14591	Economy	11700.00
0005434876829	14591	Economy	11700.00
0005432611666	14591	Economy	11700.00
0005434426209	14591	Economy	11700.00
0005435625903	14591	Economy	11700.00
0005432611652	14591	Economy	11700.00
0005432799112	14591	Economy	11700.00
0005435625945	14591	Economy	11700.00
0005434876956	14591	Economy	11700.00
0005432799103	14591	Economy	11700.00
0005434876974	14591	Economy	11700.00
0005432799145	14591	Economy	11700.00
0005434877118	14591	Economy	11700.00
0005434426288	14591	Economy	11700.00
0005434877177	14591	Economy	11700.00
0005434877058	14591	Economy	11700.00
0005434877021	14591	Economy	11700.00
0005432799093	14591	Economy	11700.00
0005435125867	14591	Economy	11700.00
0005434937793	14591	Economy	11700.00
0005432611658	14591	Economy	11700.00
0005434877081	14591	Economy	11700.00
0005435125828	14591	Economy	11700.00
0005432799190	14591	Economy	11700.00
0005435625924	14591	Economy	11700.00
0005435902637	14591	Economy	11700.00
0005434877070	14591	Economy	11700.00
0005434877301	14591	Economy	11700.00
0005434877122	14591	Economy	11700.00
0005434877039	14591	Economy	11700.00
0005434876786	14591	Economy	11700.00
0005435125818	14591	Economy	11700.00
0005434877278	14591	Economy	11700.00
0005434876855	14591	Economy	11700.00
0005432611642	14591	Economy	11700.00
0005432799015	14591	Economy	11700.00
0005435902627	14591	Economy	11700.00
0005435902632	14591	Economy	11700.00
0005434876787	14591	Economy	11700.00
0005435902635	14591	Economy	11700.00
0005435125681	14591	Economy	11700.00
0005434937934	14591	Economy	12800.00
0005434876993	14591	Economy	11700.00
0005434877080	14591	Economy	11700.00
0005435126054	14591	Economy	11700.00
0005434877132	14591	Economy	11700.00
0005434937843	14591	Economy	12800.00
0005434877255	14591	Economy	12800.00
0005432799096	14591	Economy	11700.00
0005432799032	14591	Economy	11700.00
0005432611675	14591	Economy	11700.00
0005434876979	14591	Economy	11700.00
0005434876856	14591	Economy	11700.00
0005432799212	14591	Economy	11700.00
0005435902622	14591	Economy	11700.00
0005434937872	14591	Economy	11700.00
0005435625935	14591	Economy	11700.00
0005434877034	14591	Economy	11700.00
0005435625940	14591	Economy	11700.00
0005435625858	14591	Economy	11700.00
0005434876818	14591	Economy	11700.00
0005435126053	14591	Economy	11700.00
0005434877355	14591	Economy	11700.00
0005434876814	14591	Economy	11700.00
0005434876972	14591	Economy	11700.00
0005435125819	14591	Economy	11700.00
0005434877209	14591	Economy	11700.00
0005434876863	14591	Economy	11700.00
0005434877211	14591	Economy	11700.00
0005435125773	14591	Economy	11700.00
0005435625897	14591	Economy	11700.00
0005434426292	14591	Economy	11700.00
0005434937958	14591	Economy	11700.00
0005432799113	14591	Economy	11700.00
0005434877104	14591	Economy	11700.00
0005435902628	14591	Economy	11700.00
0005434877413	14591	Economy	11700.00
0005434937894	14591	Economy	11700.00
0005434937936	14591	Economy	11700.00
0005434877393	14591	Economy	11700.00
0005434877006	14591	Economy	11700.00
0005435902621	14591	Economy	11700.00
0005434877019	14591	Economy	11700.00
0005434876864	14591	Economy	11700.00
0005434876925	14591	Economy	11700.00
0005434877210	14591	Economy	11700.00
0005435625946	14591	Economy	11700.00
0005432799142	14591	Economy	11700.00
0005432799220	14591	Economy	11700.00
0005434937957	14591	Economy	11700.00
0005435902634	14591	Economy	11700.00
0005432799191	14591	Economy	11700.00
0005435625891	14591	Economy	11700.00
0005434877348	14591	Economy	11700.00
0005432607522	14591	Economy	11700.00
0005435125775	14591	Economy	11700.00
0005434877130	14591	Economy	11700.00
0005435125830	14591	Economy	11700.00
0005435125670	14591	Economy	11700.00
0005432799143	14591	Economy	11700.00
0005434937898	14591	Economy	11700.00
0005435902626	14591	Economy	11700.00
0005434876558	14591	Economy	11700.00
0005432799033	14591	Economy	11700.00
0005434877068	14591	Economy	11700.00
0005435125935	14591	Economy	11700.00
0005434426232	14591	Economy	11700.00
0005434877299	14591	Economy	11700.00
0005434426210	14591	Economy	11700.00
0005434876867	14591	Economy	11700.00
0005434876754	14591	Economy	11700.00
0005434876916	14591	Economy	11700.00
0005434426245	14591	Economy	11700.00
0005434877260	14591	Economy	11700.00
0005432799124	14591	Economy	11700.00
0005434876973	14591	Economy	11700.00
0005434937920	14591	Economy	11700.00
0005435125939	14591	Economy	11700.00
0005435625937	14591	Economy	11700.00
0005434877073	14591	Economy	11700.00
0005435125776	14591	Economy	11700.00
0005434876694	14591	Economy	11700.00
0005434937921	14591	Economy	11700.00
0005434426334	14591	Economy	11700.00
0005434877194	14591	Economy	11700.00
0005435625857	14591	Economy	11700.00
0005434876991	14591	Economy	11700.00
0005435125774	14591	Economy	11700.00
0005434426304	14591	Economy	11700.00
0005434877213	14591	Economy	11700.00
0005434877394	14591	Economy	11700.00
0005434877373	14591	Economy	11700.00
0005434876762	14591	Economy	12800.00
0005432799019	14591	Economy	11700.00
0005434877023	14591	Economy	12800.00
0005434426287	14591	Economy	12800.00
0005434426180	14591	Economy	11700.00
0005432799141	14591	Economy	11700.00
0005435125934	14591	Economy	11700.00
0005434426274	14591	Economy	11700.00
0005434426174	14591	Economy	11700.00
0005434937935	14591	Economy	11700.00
0005434426159	14591	Economy	11700.00
0005434877103	14591	Economy	11700.00
0005434877057	14591	Economy	11700.00
0005434937945	14591	Economy	11700.00
0005434877098	14591	Economy	11700.00
0005434937946	14591	Economy	11700.00
0005434426325	14591	Economy	11700.00
0005435125820	14591	Economy	11700.00
0005435125866	14591	Economy	11700.00
0005432799017	14591	Economy	11700.00
0005434876933	14591	Economy	11700.00
0005434937919	14591	Economy	11700.00
0005434877292	14591	Economy	11700.00
0005435125798	14591	Economy	11700.00
0005435902638	14591	Economy	11700.00
0005434877198	14591	Economy	11700.00
0005434877035	14591	Economy	11700.00
0005434877079	14591	Economy	11700.00
0005434426158	14591	Economy	11700.00
0005435902631	14591	Economy	11700.00
0005434937880	14591	Economy	11700.00
0005434877243	14591	Economy	11700.00
0005435125831	14591	Economy	11700.00
0005435902629	14591	Economy	11700.00
0005434876971	14591	Economy	11700.00
0005434877302	14591	Economy	11700.00
0005435125778	14591	Economy	11700.00
0005434876917	14591	Economy	11700.00
0005434876985	14591	Economy	11700.00
0005434877178	14591	Economy	11700.00
0005435125777	14591	Economy	11700.00
0005434937906	14591	Economy	11700.00
0005435125808	14591	Economy	11700.00
0005435125807	14591	Economy	11700.00
0005432799095	14591	Economy	11700.00
0005434877430	14591	Economy	11700.00
0005434426317	14591	Economy	11700.00
0005435125772	14591	Economy	11700.00
0005434426312	14591	Economy	11700.00
0005435902636	14591	Economy	11700.00
0005434937845	14591	Economy	11700.00
0005434877056	14591	Economy	11700.00
0005434877339	14591	Economy	11700.00
0005435902624	14591	Economy	11700.00
0005434937956	14591	Economy	11700.00
0005434876969	14591	Economy	11700.00
0005435842325	14591	Economy	11700.00
0005435125771	14591	Economy	11700.00
0005434876834	14591	Economy	11700.00
0005435625929	14591	Economy	11700.00
0005432799140	14591	Economy	11700.00
0005435125876	14591	Economy	11700.00
0005434877190	14591	Economy	11700.00
0005434426324	14591	Economy	11700.00
0005435902625	14591	Economy	11700.00
0005434426276	14591	Economy	11700.00
0005434876816	14591	Economy	11700.00
0005434876830	14591	Economy	11700.00
0005434876749	14591	Economy	11700.00
0005435625930	14591	Economy	11700.00
0005434876764	14591	Economy	11700.00
0005435625921	14591	Economy	11700.00
0005432799018	14591	Economy	11700.00
0005434877412	14591	Economy	11700.00
0005435125875	14591	Economy	11700.00
0005432799144	14591	Economy	11700.00
0005432799053	14591	Economy	11700.00
0005434876763	14591	Economy	11700.00
0005434876815	14591	Economy	11700.00
0005434426275	14591	Economy	11700.00
0005434876827	14591	Economy	11700.00
0005434876977	14591	Economy	11700.00
0005434937792	14591	Economy	11700.00
0005434325598	3611	Economy	16300.00
0005435889814	3611	Economy	16300.00
0005434325604	3611	Economy	14800.00
0005435889821	3611	Economy	14800.00
0005435889799	3611	Economy	14800.00
0005434325608	3611	Economy	14800.00
0005435889817	3611	Economy	14800.00
0005434325599	3611	Economy	14800.00
0005434325601	3611	Economy	14800.00
0005434312310	3611	Economy	14800.00
0005434325605	3611	Economy	14800.00
0005434312309	3611	Economy	14800.00
0005434312311	3611	Economy	14800.00
0005435889827	3611	Economy	14800.00
0005434325607	3611	Economy	14800.00
0005434325606	3611	Economy	14800.00
0005434325603	3611	Economy	14800.00
0005435889823	3611	Economy	14800.00
0005434325602	3611	Economy	14800.00
0005434325597	3611	Economy	14800.00
0005435889815	3611	Economy	14800.00
0005434325600	3611	Economy	14800.00
0005435889818	3611	Economy	14800.00
0005435889871	15638	Economy	16300.00
0005434325536	15638	Economy	16300.00
0005435889870	15638	Economy	14800.00
0005435889874	15638	Economy	14800.00
0005434325558	15638	Economy	14800.00
0005434325504	15638	Economy	14800.00
0005434325564	15638	Economy	14800.00
0005435889872	15638	Economy	14800.00
0005434325586	15638	Economy	14800.00
0005434325534	15638	Economy	14800.00
0005435889869	15638	Economy	14800.00
0005434325559	15638	Economy	14800.00
0005434325515	15638	Economy	14800.00
0005434325535	15638	Economy	14800.00
0005434325587	15638	Economy	14800.00
0005435889873	15638	Economy	14800.00
0005435889875	15638	Economy	14800.00
0005434325565	15638	Economy	14800.00
0005434325539	15638	Economy	14800.00
0005434325529	15638	Economy	14800.00
0005434325518	15638	Economy	14800.00
0005434325530	15638	Economy	14800.00
0005434325533	15638	Economy	14800.00
0005435957638	651	Economy	4500.00
0005435957635	651	Economy	4100.00
0005435957640	651	Economy	4100.00
0005435957643	651	Economy	4100.00
0005433420271	651	Economy	4100.00
0005435957644	651	Economy	4100.00
0005433420270	651	Economy	4100.00
0005435957648	651	Economy	4100.00
0005433420294	651	Economy	4100.00
0005435957645	651	Economy	4100.00
0005435957636	651	Economy	4100.00
0005435957637	651	Economy	4100.00
0005435957647	651	Economy	4100.00
0005435957642	651	Economy	4100.00
0005435957646	651	Economy	4100.00
0005435957649	651	Economy	4100.00
0005435957639	651	Economy	4100.00
0005433420320	651	Economy	4100.00
0005435957641	651	Economy	4100.00
0005435957485	15198	Economy	4500.00
0005435957470	15198	Economy	4500.00
0005435957515	15198	Economy	4500.00
0005435957569	15198	Economy	4500.00
0005435957520	15198	Economy	4100.00
0005433420365	15198	Economy	4100.00
0005433420370	15198	Economy	4100.00
0005435957516	15198	Economy	4100.00
0005435957498	15198	Economy	4100.00
0005435957478	15198	Economy	4100.00
0005433420367	15198	Economy	4100.00
0005435957518	15198	Economy	4100.00
0005433420368	15198	Economy	4100.00
0005435957512	15198	Economy	4100.00
0005433420369	15198	Economy	4100.00
0005435957539	15198	Economy	4100.00
0005435957534	15198	Economy	4100.00
0005435957559	15198	Economy	4100.00
0005435957517	15198	Economy	4100.00
0005435957463	15198	Economy	4100.00
0005435957483	15198	Economy	4100.00
0005435957481	15198	Economy	4100.00
0005435957565	15198	Economy	4100.00
0005435957540	15198	Economy	4100.00
0005435957482	15198	Economy	4100.00
0005435957477	15198	Economy	4100.00
0005435957570	15198	Economy	4100.00
0005435957514	15198	Economy	4100.00
0005435957553	15198	Economy	4100.00
0005435957484	15198	Economy	4100.00
0005433420371	15198	Economy	4100.00
0005435957479	15198	Economy	4100.00
0005435957486	15198	Economy	4100.00
0005435957571	15198	Economy	4100.00
0005433420366	15198	Economy	4100.00
0005435957492	15198	Economy	4100.00
0005435957523	15198	Economy	4100.00
0005435957438	15198	Economy	4100.00
0005434247120	8950	Economy	10400.00
0005434247121	8950	Economy	10400.00
0005434247122	8950	Economy	10400.00
0005435629391	16020	Economy	10400.00
0005435629392	16020	Economy	10400.00
0005434247135	16020	Economy	10400.00
0005434247138	16020	Economy	10400.00
0005434247137	16020	Economy	10400.00
0005434247136	16020	Economy	10400.00
0005434096717	11828	Economy	13400.00
0005434096707	11828	Economy	13400.00
0005434096712	11828	Economy	13400.00
0005434096713	11828	Economy	13400.00
0005434096708	11828	Economy	13400.00
0005434096716	11828	Economy	13400.00
0005434096733	20165	Economy	13400.00
0005434096734	20165	Economy	13400.00
0005434096729	20165	Economy	13400.00
0005434096732	20165	Economy	13400.00
0005434096735	20165	Economy	13400.00
0005434096730	20165	Economy	13400.00
0005434096731	20165	Economy	13400.00
0005435229392	25111	Business	87700.00
0005435229400	25111	Business	87700.00
0005435229387	25111	Business	87700.00
0005432645859	25111	Business	87700.00
0005435229389	25111	Business	87700.00
0005432645840	25111	Business	87700.00
0005432645808	25111	Business	87700.00
0005432645794	25111	Economy	29200.00
0005432645828	25111	Economy	29200.00
0005432645846	25111	Economy	29200.00
0005432645829	25111	Economy	29200.00
0005432645781	25111	Economy	32200.00
0005432645790	25111	Economy	29200.00
0005435229388	25111	Economy	29200.00
0005432645780	25111	Economy	29200.00
0005435229386	25111	Economy	29200.00
0005432645779	25111	Economy	29200.00
0005432645782	25111	Economy	29200.00
0005435229395	25111	Economy	29200.00
0005435229397	25111	Economy	29200.00
0005432645785	25111	Economy	29200.00
0005432645838	25111	Economy	29200.00
0005432645791	25111	Economy	29200.00
0005432645858	25111	Economy	29200.00
0005432645799	25111	Economy	29200.00
0005432645806	25111	Economy	29200.00
0005435229405	25111	Economy	29200.00
0005432645793	25111	Economy	29200.00
0005435229385	25111	Economy	29200.00
0005435229402	25111	Economy	29200.00
0005435229406	25111	Economy	29200.00
0005432645807	25111	Economy	29200.00
0005432645778	25111	Economy	29200.00
0005432645792	25111	Economy	29200.00
0005435229404	25111	Economy	29200.00
0005435229403	25111	Economy	29200.00
0005435229393	25111	Economy	29200.00
0005432645842	25111	Economy	29200.00
0005432645786	25111	Economy	29200.00
0005432645800	25111	Economy	29200.00
0005432645860	25111	Economy	29200.00
0005432645784	25111	Economy	29200.00
0005432645789	25111	Economy	29200.00
0005435229401	25111	Economy	29200.00
0005435229396	25111	Economy	29200.00
0005432645798	25111	Economy	29200.00
0005435229399	25111	Economy	29200.00
0005435229384	25111	Economy	29200.00
0005435229394	25111	Economy	29200.00
0005432645854	25111	Economy	29200.00
0005432645777	25111	Economy	29200.00
0005435229390	25111	Economy	29200.00
0005432645841	25111	Economy	29200.00
0005435229398	25111	Economy	29200.00
0005435229391	25111	Economy	29200.00
0005433404731	2831	Business	12600.00
0005435797418	2831	Business	12600.00
0005433404730	2831	Business	12600.00
0005435797414	2831	Economy	4200.00
0005435797415	2831	Economy	4200.00
0005435797413	2831	Economy	4200.00
0005435797417	2831	Economy	4600.00
0005433404732	2831	Economy	4600.00
0005435797412	2831	Economy	4600.00
0005435797424	2831	Economy	4200.00
0005433404709	2831	Economy	4200.00
0005435797411	2831	Economy	4200.00
0005433404733	2831	Economy	4200.00
0005433404734	2831	Economy	4200.00
0005435797421	2831	Economy	4200.00
0005435797416	2831	Economy	4200.00
0005435797419	2831	Economy	4200.00
0005435797420	2831	Economy	4200.00
0005435797423	2831	Economy	4200.00
0005433404700	2831	Economy	4200.00
0005433404725	2831	Economy	4200.00
0005435797422	2831	Economy	4200.00
0005435797337	29340	Business	12600.00
0005435797343	29340	Business	12600.00
0005433404779	29340	Business	12600.00
0005435797321	29340	Business	12600.00
0005435797274	29340	Business	12600.00
0005435797324	29340	Economy	4200.00
0005433404783	29340	Economy	4200.00
0005435797315	29340	Economy	4600.00
0005435797331	29340	Economy	4600.00
0005435797308	29340	Economy	4200.00
0005435797294	29340	Economy	4200.00
0005435797320	29340	Economy	4200.00
0005433404777	29340	Economy	4200.00
0005433404781	29340	Economy	4200.00
0005435797322	29340	Economy	4200.00
0005435797314	29340	Economy	4200.00
0005435797302	29340	Economy	4200.00
0005433404778	29340	Economy	4200.00
0005433404780	29340	Economy	4200.00
0005435797335	29340	Economy	4200.00
0005435797303	29340	Economy	4200.00
0005435797325	29340	Economy	4200.00
0005433404775	29340	Economy	4200.00
0005435797272	29340	Economy	4200.00
0005435797336	29340	Economy	4200.00
0005435797379	29340	Economy	4200.00
0005435797338	29340	Economy	4200.00
0005435797286	29340	Economy	4200.00
0005433404782	29340	Economy	4200.00
0005433404776	29340	Economy	4200.00
0005435797304	29340	Economy	4200.00
0005435797332	29340	Economy	4200.00
0005435376319	5824	Economy	6800.00
0005435376332	5824	Economy	6800.00
0005435376331	5824	Economy	6800.00
0005434947984	5821	Economy	6800.00
0005434947990	5821	Economy	6800.00
0005434947989	5821	Economy	6800.00
0005434947985	5821	Economy	6800.00
0005434947991	5821	Economy	6800.00
0005434947988	5821	Economy	6800.00
0005434947987	5821	Economy	6800.00
0005434947986	5821	Economy	6800.00
0005434947892	16377	Economy	6800.00
0005434947906	16377	Economy	6800.00
0005434947896	16377	Economy	6800.00
0005434947937	16377	Economy	6800.00
0005434947947	16377	Economy	6800.00
0005435376342	16377	Economy	6800.00
0005434947963	16377	Economy	6800.00
0005434947891	16377	Economy	6800.00
0005435376341	16377	Economy	6800.00
0005434947948	16377	Economy	6800.00
0005434947905	16377	Economy	6800.00
0005434947910	16377	Economy	6800.00
0005433960641	6948	Business	21400.00
0005433960640	6948	Business	21400.00
0005433960658	6948	Business	21400.00
0005433960673	6948	Business	21400.00
0005433960630	6948	Business	21400.00
0005433960660	6948	Business	21400.00
0005433960645	6948	Business	21400.00
0005433960659	6948	Economy	7100.00
0005433960633	6948	Economy	7100.00
0005433960649	6948	Economy	7100.00
0005433960631	6948	Economy	7100.00
0005433960672	6948	Economy	7100.00
0005433960654	6948	Economy	7100.00
0005433960661	6948	Economy	7800.00
0005433960632	6948	Economy	7800.00
0005433960655	6948	Economy	7800.00
0005433960668	6948	Economy	7100.00
0005433960629	6948	Economy	7100.00
0005433960644	6948	Economy	7100.00
0005433960667	6948	Economy	7100.00
0005433960656	6948	Economy	7100.00
0005433960646	6948	Economy	7100.00
0005433960650	6948	Economy	7100.00
0005433960637	6948	Economy	7100.00
0005433960638	6948	Economy	7100.00
0005433960669	6948	Economy	7100.00
0005433960639	6948	Economy	7100.00
0005433960670	6948	Economy	7100.00
0005433960648	6948	Economy	7100.00
0005433960665	6948	Economy	7100.00
0005433960642	6948	Economy	7100.00
0005433960651	6948	Economy	7100.00
0005433960671	6948	Economy	7100.00
0005433960662	6948	Economy	7100.00
0005433960636	6948	Economy	7100.00
0005433960643	6948	Economy	7100.00
0005433960657	6948	Economy	7100.00
0005433960634	6948	Economy	7100.00
0005433960635	6948	Economy	7100.00
0005433960664	6948	Economy	7100.00
0005433960666	6948	Economy	7100.00
0005433960647	6948	Economy	7100.00
0005433960653	6948	Economy	7100.00
0005433960663	6948	Economy	7100.00
0005433960652	6948	Economy	7100.00
0005433960674	6948	Economy	7100.00
0005433959921	25718	Business	21400.00
0005433960071	25718	Business	21400.00
0005433959978	25718	Business	21400.00
0005433959925	25718	Business	21400.00
0005433960066	25718	Business	21400.00
0005433959898	25718	Business	21400.00
0005433959922	25718	Economy	7100.00
0005433959981	25718	Economy	7100.00
0005433960068	25718	Economy	7100.00
0005433959971	25718	Economy	7100.00
0005433959931	25718	Economy	7100.00
0005433959891	25718	Economy	7800.00
0005433960063	25718	Economy	7800.00
0005433960033	25718	Economy	7800.00
0005433959916	25718	Economy	7800.00
0005433959951	25718	Economy	7100.00
0005433959967	25718	Economy	7100.00
0005433960075	25718	Economy	7100.00
0005433960030	25718	Economy	7100.00
0005433960061	25718	Economy	7100.00
0005433960009	25718	Economy	7100.00
0005433960076	25718	Economy	7100.00
0005433960006	25718	Economy	7100.00
0005433960021	25718	Economy	7100.00
0005433959970	25718	Economy	7100.00
0005433959946	25718	Economy	7100.00
0005433960073	25718	Economy	7100.00
0005433960022	25718	Economy	7100.00
0005433959956	25718	Economy	7100.00
0005433959966	25718	Economy	7100.00
0005433960037	25718	Economy	7100.00
0005433960036	25718	Economy	7100.00
0005433960070	25718	Economy	7100.00
0005433959912	25718	Economy	7100.00
0005433960038	25718	Economy	7100.00
0005433960051	25718	Economy	7100.00
0005433959995	25718	Economy	7100.00
0005433959930	25718	Economy	7100.00
0005433959917	25718	Economy	7100.00
0005433959890	25718	Economy	7100.00
0005433960014	25718	Economy	7100.00
0005433959979	25718	Economy	7100.00
0005433959969	25718	Economy	7100.00
0005433959932	25718	Economy	7100.00
0005433960031	25718	Economy	7100.00
0005433959923	25718	Economy	7100.00
0005433960032	25718	Economy	7100.00
0005433959957	25718	Economy	7100.00
0005433960072	25718	Economy	7100.00
0005433959945	25718	Economy	7100.00
0005433960034	25718	Economy	7100.00
0005433960028	25718	Economy	7100.00
0005435082677	24541	Economy	3900.00
0005435082683	24541	Economy	3900.00
0005435082694	24541	Economy	3900.00
0005435082671	24541	Economy	3900.00
0005435082672	24541	Economy	3900.00
0005435082697	24541	Economy	3900.00
0005435082682	24541	Economy	3900.00
0005435082656	24541	Economy	3900.00
0005435082655	24541	Economy	3900.00
0005435082681	24541	Economy	3900.00
0005435082749	26155	Economy	3900.00
0005435082751	26155	Economy	3900.00
0005435082748	26155	Economy	3900.00
0005435082747	26155	Economy	3900.00
0005435082743	26155	Economy	3900.00
0005435082746	26155	Economy	3900.00
0005435082742	26155	Economy	3900.00
0005435082744	26155	Economy	3900.00
0005435082745	26155	Economy	3900.00
0005435082750	26155	Economy	3900.00
0005434244871	4990	Business	18000.00
0005434244867	4990	Business	18000.00
0005434244874	4990	Business	18000.00
0005434244868	4990	Business	18000.00
0005434244854	4990	Business	18000.00
0005432166889	4990	Business	18000.00
0005435286558	4990	Business	18000.00
0005434244847	4990	Business	18000.00
0005434244861	4990	Business	18000.00
0005434244857	4990	Business	18000.00
0005434244851	4990	Economy	6600.00
0005435286555	4990	Economy	6000.00
0005435286556	4990	Economy	6000.00
0005432166887	4990	Economy	6000.00
0005434244862	4990	Economy	6000.00
0005434244863	4990	Economy	6000.00
0005435286559	4990	Economy	6000.00
0005434244866	4990	Economy	6000.00
0005435286554	4990	Economy	6000.00
0005434244865	4990	Economy	6000.00
0005434244872	4990	Economy	6000.00
0005434244853	4990	Economy	6000.00
0005434244848	4990	Economy	6000.00
0005434244846	4990	Economy	6600.00
0005432166886	4990	Economy	6000.00
0005434244858	4990	Economy	6000.00
0005435286539	4990	Economy	6000.00
0005434244852	4990	Economy	6000.00
0005434244873	4990	Economy	6000.00
0005434244870	4990	Economy	6000.00
0005434244864	4990	Economy	6000.00
0005435286562	4990	Economy	6000.00
0005434244869	4990	Economy	6000.00
0005434244855	4990	Economy	6000.00
0005432166888	4990	Economy	6000.00
0005434244849	4990	Economy	6000.00
0005434244859	4990	Economy	6000.00
0005434244850	4990	Economy	6000.00
0005434244860	4990	Economy	6000.00
0005434244856	4990	Economy	6000.00
0005432105355	4989	Business	18000.00
0005433784783	4989	Business	18000.00
0005433784794	4989	Business	18000.00
0005433614417	4989	Business	18000.00
0005433614406	4989	Business	18000.00
0005433614361	4989	Business	18000.00
0005433614370	4989	Business	18000.00
0005433614426	4989	Business	18000.00
0005432666380	4989	Business	18000.00
0005432105353	4989	Business	18000.00
0005433614430	4989	Business	18000.00
0005432105364	4989	Business	18000.00
0005433614387	4989	Business	18000.00
0005433614416	4989	Business	18000.00
0005432105365	4989	Business	18000.00
0005432105380	4989	Business	18000.00
0005432105375	4989	Business	18000.00
0005432105366	4989	Business	18000.00
0005432667444	4989	Business	18000.00
0005433614397	4989	Business	18000.00
0005433614414	4989	Business	18000.00
0005433614428	4989	Business	18000.00
0005433614422	4989	Business	18000.00
0005432105350	4989	Business	18000.00
0005432105395	4989	Business	18000.00
0005433614410	4989	Business	18000.00
0005432105362	4989	Business	18000.00
0005433614366	4989	Business	18000.00
0005433784788	4989	Economy	6600.00
0005433614409	4989	Economy	6600.00
0005433784776	4989	Economy	6600.00
0005433614371	4989	Economy	6600.00
0005433614419	4989	Economy	6600.00
0005433614403	4989	Economy	6600.00
0005433784797	4989	Economy	6000.00
0005433614394	4989	Economy	6000.00
0005432666379	4989	Economy	6000.00
0005433784808	4989	Economy	6000.00
0005433614429	4989	Economy	6000.00
0005433614404	4989	Economy	6000.00
0005433784780	4989	Economy	6000.00
0005432105373	4989	Economy	6000.00
0005432105393	4989	Economy	6000.00
0005433614411	4989	Economy	6000.00
0005432105381	4989	Economy	6000.00
0005433614399	4989	Economy	6000.00
0005432105378	4989	Economy	6000.00
0005433614395	4989	Economy	6000.00
0005433614418	4989	Economy	6000.00
0005432105396	4989	Economy	6000.00
0005433614421	4989	Economy	6000.00
0005433614362	4989	Economy	6000.00
0005433614402	4989	Economy	6000.00
0005433614382	4989	Economy	6000.00
0005433784790	4989	Economy	6000.00
0005433784796	4989	Economy	6000.00
0005432665266	4989	Economy	6000.00
0005433784799	4989	Economy	6000.00
0005433784813	4989	Economy	6000.00
0005432105369	4989	Economy	6000.00
0005432105351	4989	Economy	6000.00
0005433784800	4989	Economy	6000.00
0005432105360	4989	Economy	6000.00
0005432105370	4989	Economy	6000.00
0005433614392	4989	Economy	6000.00
0005433614423	4989	Economy	6000.00
0005433784789	4989	Economy	6000.00
0005433614420	4989	Economy	6000.00
0005433614374	4989	Economy	6000.00
0005433784802	4989	Economy	6000.00
0005433614433	4989	Economy	6000.00
0005433614386	4989	Economy	6000.00
0005433784811	4989	Economy	6000.00
0005432665265	4989	Economy	6000.00
0005433614363	4989	Economy	6000.00
0005433614372	4989	Economy	6000.00
0005433614379	4989	Economy	6000.00
0005432105377	4989	Economy	6000.00
0005433614377	4989	Economy	6000.00
0005433784792	4989	Economy	6000.00
0005433614431	4989	Economy	6000.00
0005433784810	4989	Economy	6000.00
0005432667446	4989	Economy	6000.00
0005433614407	4989	Economy	6000.00
0005433784779	4989	Economy	6000.00
0005433614384	4989	Economy	6000.00
0005433614408	4989	Economy	6000.00
0005432105384	4989	Economy	6000.00
0005433614376	4989	Economy	6000.00
0005433614385	4989	Economy	6000.00
0005433614378	4989	Economy	6000.00
0005433614427	4989	Economy	6000.00
0005433614432	4989	Economy	6000.00
0005433614388	4989	Economy	6600.00
0005433614396	4989	Economy	6000.00
0005433614375	4989	Economy	6600.00
0005432667445	4989	Economy	6600.00
0005433614380	4989	Economy	6600.00
0005433784809	4989	Economy	6000.00
0005433784787	4989	Economy	6600.00
0005433784791	4989	Economy	6000.00
0005433614381	4989	Economy	6000.00
0005433784786	4989	Economy	6000.00
0005433614390	4989	Economy	6600.00
0005433784778	4989	Economy	6000.00
0005432105358	4989	Economy	6000.00
0005432105385	4989	Economy	6000.00
0005432105356	4989	Economy	6000.00
0005432105359	4989	Economy	6000.00
0005433614413	4989	Economy	6000.00
0005432105379	4989	Economy	6000.00
0005432105389	4989	Economy	6000.00
0005432105372	4989	Economy	6000.00
0005432105352	4989	Economy	6000.00
0005433784807	4989	Economy	6000.00
0005433784798	4989	Economy	6000.00
0005433784803	4989	Economy	6000.00
0005433614425	4989	Economy	6000.00
0005433784782	4989	Economy	6000.00
0005432105392	4989	Economy	6000.00
0005433614383	4989	Economy	6000.00
0005433614369	4989	Economy	6000.00
0005433784785	4989	Economy	6000.00
0005433614424	4989	Economy	6000.00
0005433784773	4989	Economy	6000.00
0005433614398	4989	Economy	6000.00
0005433784795	4989	Economy	6000.00
0005432105363	4989	Economy	6000.00
0005433614415	4989	Economy	6000.00
0005433614360	4989	Economy	6000.00
0005433614391	4989	Economy	6000.00
0005433784793	4989	Economy	6000.00
0005432105354	4989	Economy	6000.00
0005433784775	4989	Economy	6000.00
0005433614364	4989	Economy	6000.00
0005433614393	4989	Economy	6000.00
0005432105367	4989	Economy	6000.00
0005433614405	4989	Economy	6000.00
0005433614412	4989	Economy	6000.00
0005433784774	4989	Economy	6000.00
0005433784777	4989	Economy	6000.00
0005432105368	4989	Economy	6000.00
0005432105386	4989	Economy	6000.00
0005432105391	4989	Economy	6000.00
0005432105387	4989	Economy	6000.00
0005433614359	4989	Economy	6000.00
0005433784801	4989	Economy	6000.00
0005432105390	4989	Economy	6000.00
0005433784806	4989	Economy	6000.00
0005432105371	4989	Economy	6000.00
0005433614400	4989	Economy	6000.00
0005432105394	4989	Economy	6000.00
0005433614373	4989	Economy	6000.00
0005432105361	4989	Economy	6000.00
0005433784781	4989	Economy	6000.00
0005432105357	4989	Economy	6000.00
0005433614367	4989	Economy	6000.00
0005433784812	4989	Economy	6000.00
0005433614368	4989	Economy	6000.00
0005433614389	4989	Economy	6000.00
0005433784805	4989	Economy	6000.00
0005432105382	4989	Economy	6000.00
0005433784784	4989	Economy	6000.00
0005432105383	4989	Economy	6000.00
0005433784804	4989	Economy	6000.00
0005432105388	4989	Economy	6000.00
0005433614365	4989	Economy	6000.00
0005432105374	4989	Economy	6000.00
0005432105376	4989	Economy	6000.00
0005433614401	4989	Economy	6000.00
0005434229273	4987	Business	18000.00
0005432335896	4987	Business	18000.00
0005435269662	4987	Business	18000.00
0005433815326	4987	Business	18000.00
0005434149682	4987	Business	18000.00
0005434229277	4987	Business	18000.00
0005434173502	4987	Business	18000.00
0005435269635	4987	Business	18000.00
0005435006683	4987	Business	18000.00
0005434149688	4987	Business	18000.00
0005434265021	4987	Business	18000.00
0005434173503	4987	Business	18000.00
0005434229269	4987	Business	18000.00
0005434229284	4987	Business	18000.00
0005434265027	4987	Business	18000.00
0005435269661	4987	Business	18000.00
0005434265032	4987	Business	18000.00
0005434265040	4987	Economy	6600.00
0005434265042	4987	Economy	6600.00
0005434265035	4987	Economy	6600.00
0005434229274	4987	Economy	6600.00
0005434265039	4987	Economy	6000.00
0005434149684	4987	Economy	6000.00
0005434229283	4987	Economy	6000.00
0005434311181	4987	Economy	6000.00
0005435269639	4987	Economy	6000.00
0005435006760	4987	Economy	6000.00
0005433815329	4987	Economy	6000.00
0005435269636	4987	Economy	6000.00
0005434265023	4987	Economy	6000.00
0005434229287	4987	Economy	6000.00
0005434265028	4987	Economy	6000.00
0005435269654	4987	Economy	6000.00
0005434265029	4987	Economy	6000.00
0005435006793	4987	Economy	6000.00
0005434229266	4987	Economy	6000.00
0005435006729	4987	Economy	6000.00
0005434229270	4987	Economy	6000.00
0005434229267	4987	Economy	6000.00
0005435006703	4987	Economy	6000.00
0005435006714	4987	Economy	6000.00
0005434173504	4987	Economy	6000.00
0005434229285	4987	Economy	6000.00
0005435006704	4987	Economy	6000.00
0005434149686	4987	Economy	6000.00
0005434265020	4987	Economy	6000.00
0005434149679	4987	Economy	6000.00
0005435269664	4987	Economy	6000.00
0005435006656	4987	Economy	6000.00
0005434265022	4987	Economy	6000.00
0005435269653	4987	Economy	6000.00
0005434265041	4987	Economy	6000.00
0005434265024	4987	Economy	6000.00
0005434229276	4987	Economy	6000.00
0005434265044	4987	Economy	6000.00
0005435006757	4987	Economy	6000.00
0005434149681	4987	Economy	6000.00
0005434265019	4987	Economy	6000.00
0005434265038	4987	Economy	6000.00
0005435006817	4987	Economy	6000.00
0005434265025	4987	Economy	6000.00
0005434229288	4987	Economy	6000.00
0005435269658	4987	Economy	6000.00
0005434265037	4987	Economy	6000.00
0005435006658	4987	Economy	6000.00
0005434229272	4987	Economy	6600.00
0005435006784	4987	Economy	6600.00
0005434265034	4987	Economy	6000.00
0005434229278	4987	Economy	6000.00
0005432335890	4987	Economy	6000.00
0005434265043	4987	Economy	6000.00
0005435269634	4987	Economy	6000.00
0005432335882	4987	Economy	6000.00
0005432335897	4987	Economy	6000.00
0005434229281	4987	Economy	6000.00
0005432335864	4987	Economy	6000.00
0005434229286	4987	Economy	6000.00
0005435269646	4987	Economy	6000.00
0005434229268	4987	Economy	6000.00
0005434149685	4987	Economy	6000.00
0005434229271	4987	Economy	6000.00
0005434173501	4987	Economy	6000.00
0005435269663	4987	Economy	6000.00
0005434265031	4987	Economy	6000.00
0005432335849	4987	Economy	6000.00
0005434149687	4987	Economy	6000.00
0005435269648	4987	Economy	6000.00
0005434149680	4987	Economy	6000.00
0005434312291	4987	Economy	6000.00
0005434173505	4987	Economy	6000.00
0005432335914	4987	Economy	6000.00
0005432335852	4987	Economy	6000.00
0005435269655	4987	Economy	6000.00
0005434229279	4987	Economy	6000.00
0005434149683	4987	Economy	6000.00
0005432335880	4987	Economy	6000.00
0005435006756	4987	Economy	6000.00
0005434265036	4987	Economy	6000.00
0005435006655	4987	Economy	6000.00
0005435006624	4987	Economy	6000.00
0005434265033	4987	Economy	6000.00
0005435269645	4987	Economy	6000.00
0005432335878	4987	Economy	6000.00
0005432335891	4987	Economy	6000.00
0005434265030	4987	Economy	6000.00
0005435269649	4987	Economy	6000.00
0005434149677	4987	Economy	6000.00
0005432335879	4987	Economy	6000.00
0005435006623	4987	Economy	6000.00
0005434149678	4987	Economy	6000.00
0005434229280	4987	Economy	6000.00
0005434229282	4987	Economy	6000.00
0005434265026	4987	Economy	6000.00
0005434229275	4987	Economy	6000.00
0005432659679	8400	Business	18000.00
0005432659683	8400	Business	18000.00
0005434244780	8400	Business	18000.00
0005433784490	8400	Business	18000.00
0005433784500	8400	Business	18000.00
0005433784452	8400	Business	18000.00
0005434244724	8400	Business	18000.00
0005435269729	8400	Business	18000.00
0005435269731	8400	Business	18000.00
0005433784550	8400	Business	18000.00
0005434244760	8400	Business	18000.00
0005434244689	8400	Business	18000.00
0005435269733	8400	Economy	6600.00
0005433784635	8400	Economy	6600.00
0005433784392	8400	Economy	6600.00
0005434244587	8400	Economy	6600.00
0005434244628	8400	Economy	6000.00
0005435269730	8400	Economy	6600.00
0005434244759	8400	Economy	6000.00
0005434244506	8400	Economy	6000.00
0005433784446	8400	Economy	6000.00
0005435269735	8400	Economy	6000.00
0005433784564	8400	Economy	6000.00
0005434244532	8400	Economy	6000.00
0005433784426	8400	Economy	6000.00
0005433784336	8400	Economy	6000.00
0005433784447	8400	Economy	6000.00
0005435269726	8400	Economy	6000.00
0005433784486	8400	Economy	6000.00
0005434244505	8400	Economy	6000.00
0005433784524	8400	Economy	6000.00
0005433784569	8400	Economy	6000.00
0005434244585	8400	Economy	6000.00
0005433784565	8400	Economy	6000.00
0005433784449	8400	Economy	6000.00
0005434244565	8400	Economy	6000.00
0005434244771	8400	Economy	6000.00
0005435269734	8400	Economy	6000.00
0005433784448	8400	Economy	6000.00
0005434244596	8400	Economy	6000.00
0005434244641	8400	Economy	6000.00
0005434244655	8400	Economy	6000.00
0005434244630	8400	Economy	6000.00
0005434244688	8400	Economy	6000.00
0005434244600	8400	Economy	6600.00
0005434244644	8400	Economy	6000.00
0005433784636	8400	Economy	6600.00
0005433784373	8400	Economy	6600.00
0005435269728	8400	Economy	6000.00
0005433784549	8400	Economy	6000.00
0005434244642	8400	Economy	6000.00
0005434244595	8400	Economy	6000.00
0005433784501	8400	Economy	6000.00
0005434244591	8400	Economy	6000.00
0005435269725	8400	Economy	6000.00
0005433784495	8400	Economy	6000.00
0005435269727	8400	Economy	6000.00
0005433784335	8400	Economy	6000.00
0005432659678	8400	Economy	6000.00
0005434244654	8400	Economy	6000.00
0005433784496	8400	Economy	6000.00
0005434244631	8400	Economy	6000.00
0005434244773	8400	Economy	6000.00
0005434244723	8400	Economy	6000.00
0005432659677	8400	Economy	6000.00
0005434244504	8400	Economy	6000.00
0005433784445	8400	Economy	6000.00
0005435269732	8400	Economy	6000.00
0005434244629	8400	Economy	6000.00
0005434244605	8400	Economy	6000.00
0005433784470	8400	Economy	6000.00
0005434244621	8400	Economy	6000.00
0005433784391	8400	Economy	6000.00
0005433784601	8400	Economy	6000.00
0005434244772	8400	Economy	6000.00
0005432659682	8400	Economy	6000.00
0005433784465	8400	Economy	6000.00
0005434244761	8400	Economy	6000.00
0005434244533	8400	Economy	6000.00
0005434244499	8400	Economy	6000.00
0005433613527	8401	Business	18000.00
0005433613521	8401	Business	18000.00
0005433613694	8401	Business	18000.00
0005433613498	8401	Business	18000.00
0005433613925	8401	Business	18000.00
0005433613587	8401	Business	18000.00
0005433613525	8401	Business	18000.00
0005433613644	8401	Business	18000.00
0005433613683	8401	Business	18000.00
0005433613572	8401	Business	18000.00
0005433613529	8401	Economy	6600.00
0005433613866	8401	Economy	6600.00
0005433613773	8401	Economy	6600.00
0005433613872	8401	Economy	6600.00
0005433613588	8401	Economy	6000.00
0005433613755	8401	Economy	6000.00
0005433613915	8401	Economy	6000.00
0005433613704	8401	Economy	6000.00
0005433613905	8401	Economy	6000.00
0005433613795	8401	Economy	6000.00
0005433613904	8401	Economy	6000.00
0005433613686	8401	Economy	6000.00
0005433613727	8401	Economy	6000.00
0005433613484	8401	Economy	6000.00
0005433613882	8401	Economy	6000.00
0005433613756	8401	Economy	6000.00
0005433613695	8401	Economy	6000.00
0005433613749	8401	Economy	6000.00
0005433613559	8401	Economy	6000.00
0005433613822	8401	Economy	6000.00
0005433613585	8401	Economy	6000.00
0005433613974	8401	Economy	6000.00
0005433613667	8401	Economy	6000.00
0005433613414	8401	Economy	6000.00
0005433613580	8401	Economy	6000.00
0005433613772	8401	Economy	6000.00
0005433613737	8401	Economy	6000.00
0005433613803	8401	Economy	6600.00
0005433613499	8401	Economy	6600.00
0005433613584	8401	Economy	6600.00
0005433613877	8401	Economy	6600.00
0005433613744	8401	Economy	6600.00
0005433613656	8401	Economy	6000.00
0005433613581	8401	Economy	6000.00
0005433613914	8401	Economy	6000.00
0005433613485	8401	Economy	6000.00
0005433613509	8401	Economy	6000.00
0005433613685	8401	Economy	6000.00
0005433613508	8401	Economy	6000.00
0005433613524	8401	Economy	6000.00
0005433613534	8401	Economy	6000.00
0005433613592	8401	Economy	6000.00
0005433613530	8401	Economy	6000.00
0005433613806	8401	Economy	6000.00
0005433613726	8401	Economy	6000.00
0005433613620	8401	Economy	6000.00
0005433613774	8401	Economy	6000.00
0005433613619	8401	Economy	6000.00
0005433613721	8401	Economy	6000.00
0005433613684	8401	Economy	6000.00
0005433613827	8401	Economy	6000.00
0005435006931	8402	Business	18000.00
0005432335981	8402	Business	18000.00
0005434173468	8402	Business	18000.00
0005432034828	8402	Business	18000.00
0005432034846	8402	Business	18000.00
0005432047533	8402	Business	18000.00
0005433690920	8402	Business	18000.00
0005434149584	8402	Business	18000.00
0005434229143	8402	Business	18000.00
0005434149603	8402	Business	18000.00
0005432034836	8402	Business	18000.00
0005433815368	8402	Business	18000.00
0005432034832	8402	Business	18000.00
0005433815366	8402	Business	18000.00
0005433815369	8402	Business	18000.00
0005434149575	8402	Business	18000.00
0005432335990	8402	Business	18000.00
0005432034848	8402	Business	18000.00
0005434264798	8402	Business	18000.00
0005434149619	8402	Business	18000.00
0005432034837	8402	Business	18000.00
0005434229057	8402	Business	18000.00
0005435006934	8402	Business	18000.00
0005435006938	8402	Business	18000.00
0005433690919	8402	Economy	6600.00
0005434149561	8402	Economy	6600.00
0005434264849	8402	Economy	6600.00
0005434229078	8402	Economy	6600.00
0005434149574	8402	Economy	6600.00
0005434264913	8402	Economy	6600.00
0005432335993	8402	Economy	6000.00
0005434149566	8402	Economy	6000.00
0005433815364	8402	Economy	6000.00
0005434229069	8402	Economy	6000.00
0005434229070	8402	Economy	6000.00
0005433689903	8402	Economy	6000.00
0005434229113	8402	Economy	6000.00
0005432034838	8402	Economy	6000.00
0005434264757	8402	Economy	6000.00
0005434264850	8402	Economy	6000.00
0005432034820	8402	Economy	6000.00
0005434173457	8402	Economy	6000.00
0005434264861	8402	Economy	6000.00
0005432335991	8402	Economy	6000.00
0005434311211	8402	Economy	6000.00
0005435006920	8402	Economy	6000.00
0005432034822	8402	Economy	6000.00
0005435006937	8402	Economy	6000.00
0005432335988	8402	Economy	6000.00
0005434264858	8402	Economy	6000.00
0005434264872	8402	Economy	6000.00
0005434149600	8402	Economy	6000.00
0005434149573	8402	Economy	6000.00
0005433534489	8402	Economy	6000.00
0005432335983	8402	Economy	6000.00
0005432034847	8402	Economy	6000.00
0005434264758	8402	Economy	6000.00
0005435006932	8402	Economy	6000.00
0005432335987	8402	Economy	6000.00
0005435006923	8402	Economy	6000.00
0005434229046	8402	Economy	6000.00
0005433815367	8402	Economy	6000.00
0005434229077	8402	Economy	6000.00
0005432034844	8402	Economy	6000.00
0005432034825	8402	Economy	6000.00
0005434149585	8402	Economy	6000.00
0005434228990	8402	Economy	6000.00
0005432034842	8402	Economy	6000.00
0005432034827	8402	Economy	6000.00
0005432034830	8402	Economy	6000.00
0005434264873	8402	Economy	6000.00
0005434173480	8402	Economy	6000.00
0005435006929	8402	Economy	6000.00
0005432034845	8402	Economy	6000.00
0005434264792	8402	Economy	6000.00
0005435006930	8402	Economy	6000.00
0005432034831	8402	Economy	6000.00
0005432335992	8402	Economy	6000.00
0005435006926	8402	Economy	6000.00
0005434229076	8402	Economy	6000.00
0005432034833	8402	Economy	6000.00
0005432034834	8402	Economy	6000.00
0005432034840	8402	Economy	6000.00
0005435006919	8402	Economy	6000.00
0005434229161	8402	Economy	6000.00
0005435006936	8402	Economy	6000.00
0005433688800	8402	Economy	6600.00
0005433690918	8402	Economy	6600.00
0005432034829	8402	Economy	6600.00
0005434229012	8402	Economy	6600.00
0005434229097	8402	Economy	6000.00
0005433689904	8402	Economy	6000.00
0005434229123	8402	Economy	6000.00
0005434264875	8402	Economy	6600.00
0005434229147	8402	Economy	6000.00
0005433690921	8402	Economy	6000.00
0005434229067	8402	Economy	6000.00
0005434311210	8402	Economy	6000.00
0005432335986	8402	Economy	6000.00
0005435006941	8402	Economy	6000.00
0005435006925	8402	Economy	6000.00
0005435006921	8402	Economy	6000.00
0005434264893	8402	Economy	6000.00
0005434173469	8402	Economy	6000.00
0005432034835	8402	Economy	6000.00
0005435006928	8402	Economy	6000.00
0005435006927	8402	Economy	6000.00
0005432335980	8402	Economy	6000.00
0005433690917	8402	Economy	6000.00
0005432034841	8402	Economy	6000.00
0005432034839	8402	Economy	6000.00
0005434264848	8402	Economy	6000.00
0005434264912	8402	Economy	6000.00
0005434149588	8402	Economy	6000.00
0005432047535	8402	Economy	6000.00
0005433688801	8402	Economy	6000.00
0005435006935	8402	Economy	6000.00
0005432034821	8402	Economy	6000.00
0005432034826	8402	Economy	6000.00
0005433815365	8402	Economy	6000.00
0005432047536	8402	Economy	6000.00
0005434229023	8402	Economy	6000.00
0005435006942	8402	Economy	6000.00
0005432335984	8402	Economy	6000.00
0005435006922	8402	Economy	6000.00
0005433534490	8402	Economy	6000.00
0005434264839	8402	Economy	6000.00
0005435006939	8402	Economy	6000.00
0005435006933	8402	Economy	6000.00
0005432034823	8402	Economy	6000.00
0005435006943	8402	Economy	6000.00
0005434264840	8402	Economy	6000.00
0005432034843	8402	Economy	6000.00
0005434149620	8402	Economy	6000.00
0005432034824	8402	Economy	6000.00
0005433689902	8402	Economy	6000.00
0005432335979	8402	Economy	6000.00
0005434264727	8402	Economy	6000.00
0005432335982	8402	Economy	6000.00
0005434229058	8402	Economy	6000.00
0005432047534	8402	Economy	6000.00
0005434264856	8402	Economy	6000.00
0005434264782	8402	Economy	6000.00
0005432335985	8402	Economy	6000.00
0005435006924	8402	Economy	6000.00
0005434264887	8402	Economy	6000.00
0005434229114	8402	Economy	6000.00
0005434264857	8402	Economy	6000.00
0005432034849	8402	Economy	6000.00
0005434264941	8402	Economy	6000.00
0005434228974	8402	Economy	6000.00
0005432335989	8402	Economy	6000.00
0005434229087	8402	Economy	6000.00
0005435006940	8402	Economy	6000.00
0005434638926	12600	Economy	16200.00
0005434638957	12600	Economy	16200.00
0005434639064	12600	Economy	16200.00
0005434639015	12600	Economy	14800.00
0005434639030	12600	Economy	14800.00
0005434638985	12600	Economy	14800.00
0005434638961	12600	Economy	14800.00
0005433202303	12600	Economy	14800.00
0005434639073	12600	Economy	14800.00
0005434638909	12600	Economy	14800.00
0005433202305	12600	Economy	14800.00
0005433202307	12600	Economy	14800.00
0005434639013	12600	Economy	14800.00
0005434638921	12600	Economy	14800.00
0005434639003	12600	Economy	14800.00
0005433202309	12600	Economy	14800.00
0005434638975	12600	Economy	14800.00
0005433202310	12600	Economy	14800.00
0005434638958	12600	Economy	14800.00
0005433202299	12600	Economy	14800.00
0005433202301	12600	Economy	14800.00
0005433202306	12600	Economy	14800.00
0005434638996	12600	Economy	14800.00
0005434638937	12600	Economy	14800.00
0005434639038	12600	Economy	14800.00
0005433202312	12600	Economy	14800.00
0005434638920	12600	Economy	14800.00
0005434639029	12600	Economy	14800.00
0005433202300	12600	Economy	14800.00
0005434638995	12600	Economy	14800.00
0005434638960	12600	Economy	14800.00
0005434638959	12600	Economy	14800.00
0005434639032	12600	Economy	14800.00
0005434638919	12600	Economy	14800.00
0005433202308	12600	Economy	14800.00
0005434638938	12600	Economy	14800.00
0005434638939	12600	Economy	14800.00
0005434639014	12600	Economy	14800.00
0005434638981	12600	Economy	14800.00
0005434638910	12600	Economy	14800.00
0005434638954	12600	Economy	14800.00
0005433202298	12600	Economy	14800.00
0005433202311	12600	Economy	14800.00
0005434638907	12600	Economy	14800.00
0005433202302	12600	Economy	14800.00
0005434639031	12600	Economy	14800.00
0005433202304	12600	Economy	14800.00
0005434639033	12600	Economy	14800.00
0005434639206	23358	Economy	16200.00
0005434639190	23358	Economy	16200.00
0005434639204	23358	Economy	16200.00
0005434639209	23358	Economy	16200.00
0005434639203	23358	Economy	14800.00
0005434639192	23358	Economy	14800.00
0005434639196	23358	Economy	14800.00
0005434639201	23358	Economy	14800.00
0005433202152	23358	Economy	14800.00
0005434639193	23358	Economy	14800.00
0005433202181	23358	Economy	14800.00
0005434639210	23358	Economy	14800.00
0005434639194	23358	Economy	14800.00
0005434639188	23358	Economy	14800.00
0005434639202	23358	Economy	14800.00
0005432290617	23358	Economy	14800.00
0005432290618	23358	Economy	14800.00
0005434639186	23358	Economy	14800.00
0005434639195	23358	Economy	14800.00
0005433202150	23358	Economy	14800.00
0005433202133	23358	Economy	14800.00
0005433202175	23358	Economy	14800.00
0005434639208	23358	Economy	14800.00
0005434639200	23358	Economy	14800.00
0005434639198	23358	Economy	14800.00
0005434639185	23358	Economy	14800.00
0005434639197	23358	Economy	14800.00
0005434639205	23358	Economy	14800.00
0005434639199	23358	Economy	14800.00
0005434639191	23358	Economy	14800.00
0005434639184	23358	Economy	14800.00
0005434639187	23358	Economy	14800.00
0005433202118	23358	Economy	14800.00
0005432290619	23358	Economy	14800.00
0005434639189	23358	Economy	14800.00
0005433202117	23358	Economy	14800.00
0005433202166	23358	Economy	14800.00
0005434639207	23358	Economy	14800.00
0005433202151	23358	Economy	14800.00
0005434639183	23358	Economy	14800.00
0005433202149	23358	Economy	14800.00
0005432328063	21052	Business	18900.00
0005432328108	21052	Business	18900.00
0005432327939	21052	Business	18900.00
0005432327990	21052	Business	18900.00
0005432328191	21052	Business	18900.00
0005432382565	21052	Business	18900.00
0005432328299	21052	Business	18900.00
0005432328153	21052	Business	18900.00
0005432382653	21052	Business	18900.00
0005432382691	21052	Business	18900.00
0005432328039	21052	Business	18900.00
0005432382801	21052	Economy	6300.00
0005432054293	21052	Economy	6300.00
0005432327940	21052	Economy	6300.00
0005432382639	21052	Economy	6300.00
0005432328018	21052	Economy	6300.00
0005432327932	21052	Economy	6300.00
0005432328106	21052	Economy	6300.00
0005432382663	21052	Economy	6300.00
0005432327908	21052	Economy	6300.00
0005432328298	21052	Economy	6900.00
0005432327907	21052	Economy	6900.00
0005432382797	21052	Economy	6900.00
0005432328118	21052	Economy	6900.00
0005432328210	21052	Economy	6300.00
0005432382640	21052	Economy	6300.00
0005432328010	21052	Economy	6300.00
0005432328062	21052	Economy	6300.00
0005432327909	21052	Economy	6300.00
0005432328030	21052	Economy	6300.00
0005432328192	21052	Economy	6300.00
0005432382626	21052	Economy	6300.00
0005432328331	21052	Economy	6300.00
0005432382664	21052	Economy	6300.00
0005432328100	21052	Economy	6300.00
0005432328101	21052	Economy	6300.00
0005432328019	21052	Economy	6300.00
0005432328070	21052	Economy	6300.00
0005432327933	21052	Economy	6300.00
0005432382641	21052	Economy	6300.00
0005432382690	21052	Economy	6300.00
0005432382642	21052	Economy	6300.00
0005432382752	21052	Economy	6300.00
0005432328107	21052	Economy	6300.00
0005432328238	21052	Economy	6300.00
0005432382760	21052	Economy	6300.00
0005432382700	21052	Economy	6300.00
0005432382714	21052	Economy	6300.00
0005432327994	21052	Economy	6300.00
0005432382746	21052	Economy	6300.00
0005432328105	21052	Economy	6300.00
0005432328091	21052	Economy	6300.00
0005432382753	21052	Economy	6300.00
0005432328092	21052	Economy	6300.00
0005432382732	21052	Economy	6300.00
0005432382698	21052	Economy	6300.00
0005432328202	21052	Economy	6300.00
0005432328154	21052	Economy	6300.00
0005432328212	21052	Economy	6300.00
0005432328040	21052	Economy	6300.00
0005432382578	21052	Economy	6300.00
0005432328031	21052	Economy	6300.00
0005432328001	21052	Economy	6300.00
0005432328078	21052	Economy	6300.00
0005432382720	21052	Economy	6300.00
0005432327993	21052	Economy	6300.00
0005432327941	21052	Economy	6300.00
0005432327998	21052	Economy	6300.00
0005432327950	21052	Economy	6300.00
0005432382566	21052	Economy	6300.00
0005432382800	21052	Economy	6300.00
0005432328294	21052	Economy	6300.00
0005432382638	21052	Economy	6300.00
0005432328247	21052	Economy	6300.00
0005432328116	21052	Economy	6300.00
0005432328165	21052	Economy	6300.00
0005432327904	21052	Economy	6300.00
0005432328183	21052	Economy	6300.00
0005432328029	21052	Economy	6300.00
0005432054292	21052	Economy	6300.00
0005432328164	21052	Economy	6300.00
0005432328015	21052	Economy	6300.00
0005432382715	21052	Economy	6300.00
0005432382670	21052	Economy	6300.00
0005432328271	21052	Economy	6300.00
0005432382726	21052	Economy	6300.00
0005432382994	31240	Business	18900.00
0005432382992	31240	Business	18900.00
0005432328482	31240	Business	18900.00
0005432328457	31240	Business	18900.00
0005432383000	31240	Business	18900.00
0005432328472	31240	Business	18900.00
0005432328471	31240	Business	18900.00
0005432328464	31240	Business	18900.00
0005432328488	31240	Business	18900.00
0005432328476	31240	Business	18900.00
0005432382989	31240	Business	18900.00
0005432383012	31240	Business	18900.00
0005432383008	31240	Economy	6300.00
0005432328497	31240	Economy	6300.00
0005432287163	31240	Economy	6300.00
0005432328495	31240	Economy	6300.00
0005432287167	31240	Economy	6300.00
0005432382981	31240	Economy	6300.00
0005432328489	31240	Economy	6300.00
0005432383011	31240	Economy	6300.00
0005432383006	31240	Economy	6300.00
0005432382980	31240	Economy	6300.00
0005432382996	31240	Economy	6900.00
0005432382997	31240	Economy	6900.00
0005432382972	31240	Economy	6900.00
0005432383009	31240	Economy	6900.00
0005432382977	31240	Economy	6900.00
0005432328491	31240	Economy	6300.00
0005432382974	31240	Economy	6300.00
0005432328492	31240	Economy	6300.00
0005432328468	31240	Economy	6300.00
0005432328470	31240	Economy	6300.00
0005432382998	31240	Economy	6300.00
0005432328493	31240	Economy	6300.00
0005432287162	31240	Economy	6300.00
0005432287164	31240	Economy	6300.00
0005432382995	31240	Economy	6300.00
0005432382987	31240	Economy	6300.00
0005432328496	31240	Economy	6300.00
0005432328459	31240	Economy	6300.00
0005432328467	31240	Economy	6300.00
0005432328473	31240	Economy	6300.00
0005432382976	31240	Economy	6300.00
0005432382991	31240	Economy	6300.00
0005432383005	31240	Economy	6300.00
0005432328460	31240	Economy	6300.00
0005432328456	31240	Economy	6300.00
0005432328458	31240	Economy	6300.00
0005432328485	31240	Economy	6300.00
0005432382973	31240	Economy	6300.00
0005432382978	31240	Economy	6300.00
0005432287165	31240	Economy	6300.00
0005432382979	31240	Economy	6300.00
0005432382993	31240	Economy	6300.00
0005432383001	31240	Economy	6300.00
0005432328484	31240	Economy	6300.00
0005432328500	31240	Economy	6300.00
0005432382983	31240	Economy	6300.00
0005432328481	31240	Economy	6300.00
0005432287166	31240	Economy	6300.00
0005432383002	31240	Economy	6300.00
0005432328469	31240	Economy	6300.00
0005432383007	31240	Economy	6300.00
0005432328455	31240	Economy	6300.00
0005432328474	31240	Economy	6300.00
0005432383004	31240	Economy	6300.00
0005432328466	31240	Economy	6300.00
0005432382999	31240	Economy	6300.00
0005432382975	31240	Economy	6300.00
0005432382984	31240	Economy	6300.00
0005432328461	31240	Economy	6300.00
0005432328498	31240	Economy	6300.00
0005432328486	31240	Economy	6300.00
0005432383010	31240	Economy	6300.00
0005432328499	31240	Economy	6300.00
0005432328494	31240	Economy	6300.00
0005432328478	31240	Economy	6300.00
0005432328465	31240	Economy	6300.00
0005432328463	31240	Economy	6300.00
0005432382970	31240	Economy	6300.00
0005432382986	31240	Economy	6300.00
0005432382990	31240	Economy	6300.00
0005432328483	31240	Economy	6300.00
0005432328462	31240	Economy	6300.00
0005432328477	31240	Economy	6300.00
0005432328490	31240	Economy	6300.00
0005432328487	31240	Economy	6300.00
0005432382982	31240	Economy	6300.00
0005432382988	31240	Economy	6300.00
0005432328454	31240	Economy	6300.00
0005432382985	31240	Economy	6300.00
0005432328479	31240	Economy	6300.00
0005432382971	31240	Economy	6300.00
0005432383003	31240	Economy	6300.00
0005432328480	31240	Economy	6300.00
0005432382969	31240	Economy	6300.00
0005432328475	31240	Economy	6300.00
0005432953901	27590	Business	89600.00
0005432953891	27590	Business	89600.00
0005433642139	27590	Business	89600.00
0005433642141	27590	Business	89600.00
0005433642153	27590	Business	89600.00
0005433642124	27590	Business	89600.00
0005432953897	27590	Business	89600.00
0005432953898	27590	Economy	29900.00
0005432953903	27590	Economy	29900.00
0005433642101	27590	Economy	32800.00
0005432953902	27590	Economy	29900.00
0005433642118	27590	Economy	29900.00
0005432953895	27590	Economy	29900.00
0005432953893	27590	Economy	29900.00
0005432953905	27590	Economy	29900.00
0005432953892	27590	Economy	29900.00
0005433642091	27590	Economy	29900.00
0005432953904	27590	Economy	29900.00
0005433642096	27590	Economy	29900.00
0005432953900	27590	Economy	29900.00
0005432953894	27590	Economy	29900.00
0005433642194	27590	Economy	29900.00
0005433642199	27590	Economy	29900.00
0005433642188	27590	Economy	29900.00
0005433642163	27590	Economy	29900.00
0005432953890	27590	Economy	29900.00
0005433642162	27590	Economy	29900.00
0005432953899	27590	Economy	29900.00
0005433642138	27590	Economy	29900.00
0005433642155	27590	Economy	29900.00
0005433642119	27590	Economy	29900.00
0005432953906	27590	Economy	29900.00
0005433642131	27590	Economy	29900.00
0005433642182	27590	Economy	29900.00
0005433642132	27590	Economy	29900.00
0005433642133	27590	Economy	29900.00
0005433642108	27590	Economy	29900.00
0005433642164	27590	Economy	29900.00
0005432953896	27590	Economy	29900.00
0005432424217	13285	Business	12700.00
0005432424196	13285	Business	12700.00
0005432424208	13285	Business	12700.00
0005432424191	13285	Business	12700.00
0005432424227	13285	Business	12700.00
0005432424230	13285	Business	12700.00
0005432424221	13285	Economy	4200.00
0005432424210	13285	Economy	4200.00
0005432424198	13285	Economy	4200.00
0005432424216	13285	Economy	4200.00
0005432424201	13285	Economy	4700.00
0005432424214	13285	Economy	4700.00
0005432424200	13285	Economy	4200.00
0005432424190	13285	Economy	4200.00
0005432424195	13285	Economy	4200.00
0005432424207	13285	Economy	4200.00
0005432424212	13285	Economy	4200.00
0005432424220	13285	Economy	4200.00
0005432424211	13285	Economy	4200.00
0005432424219	13285	Economy	4200.00
0005432424218	13285	Economy	4200.00
0005432424225	13285	Economy	4200.00
0005432424229	13285	Economy	4200.00
0005432424222	13285	Economy	4200.00
0005432424228	13285	Economy	4200.00
0005432424204	13285	Economy	4200.00
0005432424202	13285	Economy	4200.00
0005432424203	13285	Economy	4200.00
0005432424224	13285	Economy	4200.00
0005432424206	13285	Economy	4200.00
0005432424223	13285	Economy	4200.00
0005432424209	13285	Economy	4200.00
0005432424197	13285	Economy	4200.00
0005432424189	13285	Economy	4200.00
0005432424199	13285	Economy	4200.00
0005432424192	13285	Economy	4200.00
0005432424215	13285	Economy	4200.00
0005432424193	13285	Economy	4200.00
0005432424205	13285	Economy	4200.00
0005432424213	13285	Economy	4200.00
0005432424194	13285	Economy	4200.00
0005432424226	13285	Economy	4200.00
0005432423815	30816	Business	12700.00
0005432423780	30816	Business	12700.00
0005432423857	30816	Business	12700.00
0005432423768	30816	Business	12700.00
0005432423775	30816	Business	12700.00
0005432423837	30816	Business	12700.00
0005432423828	30816	Business	12700.00
0005432423798	30816	Economy	4200.00
0005432423832	30816	Economy	4200.00
0005432423771	30816	Economy	4200.00
0005432423609	30816	Economy	4200.00
0005432423765	30816	Economy	4200.00
0005432423810	30816	Economy	4200.00
0005432423856	30816	Economy	4200.00
0005432423812	30816	Economy	4700.00
0005432423833	30816	Economy	4700.00
0005432423766	30816	Economy	4700.00
0005432423739	30816	Economy	4200.00
0005432423757	30816	Economy	4200.00
0005432423796	30816	Economy	4200.00
0005432423756	30816	Economy	4200.00
0005432423858	30816	Economy	4200.00
0005432423859	30816	Economy	4200.00
0005432423696	30816	Economy	4200.00
0005432423787	30816	Economy	4200.00
0005432423727	30816	Economy	4200.00
0005432423767	30816	Economy	4200.00
0005432423711	30816	Economy	4200.00
0005432423786	30816	Economy	4200.00
0005432423785	30816	Economy	4200.00
0005432423776	30816	Economy	4200.00
0005432423853	30816	Economy	4200.00
0005432423647	30816	Economy	4200.00
0005432423781	30816	Economy	4200.00
0005432423838	30816	Economy	4200.00
0005432423795	30816	Economy	4200.00
0005432423716	30816	Economy	4200.00
0005432423811	30816	Economy	4200.00
0005432423734	30816	Economy	4200.00
0005432423728	30816	Economy	4200.00
0005432423608	30816	Economy	4200.00
0005432423612	30816	Economy	4200.00
0005432423670	30816	Economy	4200.00
0005432423642	30816	Economy	4200.00
0005432423836	30816	Economy	4200.00
0005432423618	30816	Economy	4200.00
0005432423713	30816	Economy	4200.00
0005432423712	30816	Economy	4200.00
0005432817334	9602	Business	32600.00
0005434157357	9602	Business	32600.00
0005432817332	9602	Business	32600.00
0005432817348	9602	Business	32600.00
0005432817355	9602	Business	32600.00
0005432817346	9602	Business	32600.00
0005432817344	9602	Business	32600.00
0005432901401	9602	Business	32600.00
0005432817335	9602	Business	32600.00
0005432817339	9602	Business	32600.00
0005432901331	9602	Economy	10900.00
0005432817362	9602	Economy	10900.00
0005432822171	9602	Economy	10900.00
0005432901414	9602	Economy	10900.00
0005434448302	9602	Economy	10900.00
0005432901391	9602	Economy	10900.00
0005432817352	9602	Economy	11900.00
0005432817347	9602	Economy	11900.00
0005434448300	9602	Economy	11900.00
0005432901412	9602	Economy	11900.00
0005432817340	9602	Economy	10900.00
0005432817357	9602	Economy	10900.00
0005432901315	9602	Economy	10900.00
0005432288971	9602	Economy	10900.00
0005432817345	9602	Economy	10900.00
0005432822173	9602	Economy	10900.00
0005432817333	9602	Economy	10900.00
0005434448301	9602	Economy	10900.00
0005434448303	9602	Economy	10900.00
0005432822169	9602	Economy	10900.00
0005432817356	9602	Economy	10900.00
0005432817350	9602	Economy	10900.00
0005432822172	9602	Economy	10900.00
0005432817361	9602	Economy	10900.00
0005432817338	9602	Economy	10900.00
0005432901376	9602	Economy	10900.00
0005432817341	9602	Economy	10900.00
0005432817337	9602	Economy	10900.00
0005432901342	9602	Economy	10900.00
0005434186167	9602	Economy	10900.00
0005434157422	9602	Economy	10900.00
0005432901332	9602	Economy	10900.00
0005432817360	9602	Economy	10900.00
0005432822170	9602	Economy	10900.00
0005434186165	9602	Economy	10900.00
0005432288973	9602	Economy	10900.00
0005432817359	9602	Economy	10900.00
0005432817353	9602	Economy	10900.00
0005432817342	9602	Economy	10900.00
0005432817336	9602	Economy	10900.00
0005432901413	9602	Economy	10900.00
0005432901348	9602	Economy	10900.00
0005432288972	9602	Economy	10900.00
0005432901367	9602	Economy	10900.00
0005432817351	9602	Economy	10900.00
0005432822175	9602	Economy	10900.00
0005434186166	9602	Economy	10900.00
0005432901399	9602	Economy	10900.00
0005432822168	9602	Economy	10900.00
0005434157421	9602	Economy	10900.00
0005432817343	9602	Economy	10900.00
0005432822174	9602	Economy	10900.00
0005432901368	9602	Economy	10900.00
0005432901349	9602	Economy	10900.00
0005432901387	9602	Economy	10900.00
0005432817358	9602	Economy	10900.00
0005432817354	9602	Economy	10900.00
0005432901408	9602	Economy	10900.00
0005432901347	9602	Economy	10900.00
0005432822167	9602	Economy	10900.00
0005432817349	9602	Economy	10900.00
0005432901459	9602	Economy	10900.00
0005434448299	9602	Economy	10900.00
0005432901400	9602	Economy	10900.00
0005434186186	28976	Business	32600.00
0005432901532	28976	Business	32600.00
0005432901530	28976	Business	32600.00
0005434186184	28976	Business	32600.00
0005432817045	28976	Business	32600.00
0005432822120	28976	Business	32600.00
0005434157444	28976	Business	32600.00
0005432901542	28976	Business	32600.00
0005432002067	28976	Business	32600.00
0005432817083	28976	Economy	10900.00
0005434448267	28976	Economy	10900.00
0005432901545	28976	Economy	10900.00
0005434157448	28976	Economy	10900.00
0005434157450	28976	Economy	10900.00
0005434448272	28976	Economy	10900.00
0005432822067	28976	Economy	10900.00
0005432901540	28976	Economy	11900.00
0005432817135	28976	Economy	11900.00
0005432817146	28976	Economy	11900.00
0005432901535	28976	Economy	11900.00
0005434157451	28976	Economy	11900.00
0005434157445	28976	Economy	10900.00
0005432002066	28976	Economy	10900.00
0005432901531	28976	Economy	10900.00
0005432817109	28976	Economy	10900.00
0005432822110	28976	Economy	10900.00
0005434186185	28976	Economy	10900.00
0005432901534	28976	Economy	10900.00
0005432822119	28976	Economy	10900.00
0005432817039	28976	Economy	10900.00
0005432901529	28976	Economy	10900.00
0005432822109	28976	Economy	10900.00
0005434157443	28976	Economy	10900.00
0005434157447	28976	Economy	10900.00
0005432817032	28976	Economy	10900.00
0005432901538	28976	Economy	10900.00
0005432901537	28976	Economy	10900.00
0005434186183	28976	Economy	10900.00
0005432817024	28976	Economy	10900.00
0005432817013	28976	Economy	10900.00
0005434448281	28976	Economy	10900.00
0005432817012	28976	Economy	10900.00
0005432901533	28976	Economy	10900.00
0005432901527	28976	Economy	10900.00
0005432817081	28976	Economy	10900.00
0005432817038	28976	Economy	10900.00
0005432817112	28976	Economy	10900.00
0005432901541	28976	Economy	10900.00
0005432817154	28976	Economy	10900.00
0005432901539	28976	Economy	10900.00
0005432817058	28976	Economy	10900.00
0005432817120	28976	Economy	10900.00
0005432817082	28976	Economy	10900.00
0005432817031	28976	Economy	10900.00
0005434157449	28976	Economy	10900.00
0005432817134	28976	Economy	10900.00
0005432901543	28976	Economy	10900.00
0005432822117	28976	Economy	10900.00
0005432817118	28976	Economy	10900.00
0005432901544	28976	Economy	10900.00
0005432817030	28976	Economy	10900.00
0005432816957	28976	Economy	10900.00
0005432817161	28976	Economy	10900.00
0005432822118	28976	Economy	10900.00
0005432817162	28976	Economy	10900.00
0005432901536	28976	Economy	10900.00
0005432817153	28976	Economy	10900.00
0005432817046	28976	Economy	10900.00
0005432901528	28976	Economy	10900.00
0005432817025	28976	Economy	10900.00
0005434448269	28976	Economy	10900.00
0005434157446	28976	Economy	10900.00
0005432816965	28976	Economy	10900.00
0005432817100	28976	Economy	10900.00
0005435841813	15127	Economy	11000.00
0005432611694	15127	Economy	11000.00
0005432611693	15127	Economy	11000.00
0005432613846	15127	Economy	11000.00
0005432613845	15127	Economy	11000.00
0005432613844	15127	Economy	11000.00
0005432611695	15127	Economy	11000.00
0005435841082	15127	Economy	11000.00
0005432611658	31580	Economy	11000.00
0005432611675	31580	Economy	11000.00
0005432611666	31580	Economy	11000.00
0005435842325	31580	Economy	11000.00
0005432607522	31580	Economy	11000.00
0005432611665	31580	Economy	11000.00
0005432611642	31580	Economy	11000.00
0005432611652	31580	Economy	11000.00
0005432947889	11864	Business	105900.00
0005432947905	11864	Business	105900.00
0005432947807	11864	Business	105900.00
0005433568741	11864	Business	105900.00
0005433568793	11864	Business	105900.00
0005433568759	11864	Business	105900.00
0005432947991	11864	Business	105900.00
0005433568757	11864	Business	105900.00
0005433568785	11864	Business	105900.00
0005432947966	11864	Business	105900.00
0005432947890	11864	Business	105900.00
0005432947805	11864	Business	105900.00
0005432947806	11864	Business	105900.00
0005433568800	11864	Business	105900.00
0005433568781	11864	Business	105900.00
0005433568792	11864	Business	105900.00
0005433568762	11864	Business	105900.00
0005433568775	11864	Business	105900.00
0005433568791	11864	Business	105900.00
0005433568753	11864	Economy	35300.00
0005432947790	11864	Economy	35300.00
0005433568801	11864	Economy	35300.00
0005433568796	11864	Economy	35300.00
0005433568774	11864	Economy	35300.00
0005433568787	11864	Economy	35300.00
0005433568773	11864	Economy	35300.00
0005432948001	11864	Economy	35300.00
0005432947860	11864	Economy	35300.00
0005432947913	11864	Economy	35300.00
0005433568764	11864	Economy	35300.00
0005433568778	11864	Economy	38800.00
0005433568747	11864	Economy	38800.00
0005433568763	11864	Economy	38800.00
0005432947906	11864	Economy	38800.00
0005433568788	11864	Economy	35300.00
0005433568766	11864	Economy	35300.00
0005432947791	11864	Economy	35300.00
0005433568771	11864	Economy	35300.00
0005433568795	11864	Economy	35300.00
0005433568744	11864	Economy	35300.00
0005433568740	11864	Economy	35300.00
0005433568752	11864	Economy	35300.00
0005432948025	11864	Economy	35300.00
0005433568765	11864	Economy	35300.00
0005433568749	11864	Economy	35300.00
0005432947984	11864	Economy	35300.00
0005433568742	11864	Economy	35300.00
0005433568746	11864	Economy	35300.00
0005433568782	11864	Economy	35300.00
0005432947880	11864	Economy	35300.00
0005433568777	11864	Economy	35300.00
0005432948102	11864	Economy	35300.00
0005433568738	11864	Economy	35300.00
0005432947914	11864	Economy	35300.00
0005433568769	11864	Economy	35300.00
0005433568798	11864	Economy	35300.00
0005433568784	11864	Economy	35300.00
0005433568750	11864	Economy	35300.00
0005432947933	11864	Economy	35300.00
0005432947949	11864	Economy	35300.00
0005433568783	11864	Economy	35300.00
0005433568799	11864	Economy	35300.00
0005432947891	11864	Economy	35300.00
0005433568743	11864	Economy	35300.00
0005432947879	11864	Economy	35300.00
0005432947928	11864	Economy	35300.00
0005432947957	11864	Economy	35300.00
0005432947983	11864	Economy	35300.00
0005432948024	11864	Economy	35300.00
0005432947990	11864	Economy	35300.00
0005432947959	11864	Economy	35300.00
0005433568760	11864	Economy	35300.00
0005433568794	11864	Economy	35300.00
0005432948055	11864	Economy	35300.00
0005432947930	11864	Economy	35300.00
0005433568789	11864	Economy	35300.00
0005433568776	11864	Economy	35300.00
0005432947861	11864	Economy	35300.00
0005433568755	11864	Economy	35300.00
0005433568767	11864	Economy	35300.00
0005432948023	11864	Economy	35300.00
0005432947948	11864	Economy	35300.00
0005432948026	11864	Economy	35300.00
0005433568802	11864	Economy	35300.00
0005432947851	11864	Economy	35300.00
0005432948004	11864	Economy	35300.00
0005433568779	11864	Economy	35300.00
0005433568768	11864	Economy	35300.00
0005432947958	11864	Economy	35300.00
0005433568786	11864	Economy	35300.00
0005433568751	11864	Economy	35300.00
0005432947886	11864	Economy	35300.00
0005433568772	11864	Economy	35300.00
0005433568761	11864	Economy	35300.00
0005433568748	11864	Economy	35300.00
0005433568739	11864	Economy	35300.00
0005432947878	11864	Economy	35300.00
0005433568797	11864	Economy	35300.00
0005432947778	11864	Economy	35300.00
0005432947967	11864	Economy	35300.00
0005433568758	11864	Economy	35300.00
0005433568754	11864	Economy	35300.00
0005433568790	11864	Economy	35300.00
0005433568780	11864	Economy	35300.00
0005433568745	11864	Economy	35300.00
0005432947852	11864	Economy	35300.00
0005433568770	11864	Economy	35300.00
0005433568756	11864	Economy	35300.00
0005432948321	25279	Business	105900.00
0005433568197	25279	Business	105900.00
0005433568348	25279	Business	105900.00
0005432948327	25279	Business	105900.00
0005433568284	25279	Business	105900.00
0005432948329	25279	Business	105900.00
0005433568195	25279	Business	105900.00
0005433568126	25279	Business	105900.00
0005433568143	25279	Business	105900.00
0005433568201	25279	Business	105900.00
0005433568020	25279	Business	105900.00
0005433568056	25279	Business	105900.00
0005432948312	25279	Business	105900.00
0005432948333	25279	Business	105900.00
0005432948320	25279	Business	105900.00
0005433568109	25279	Business	105900.00
0005432948324	25279	Business	105900.00
0005433568288	25279	Business	105900.00
0005433568252	25279	Economy	35300.00
0005433568313	25279	Business	105900.00
0005433568341	25279	Economy	35300.00
0005433568165	25279	Economy	35300.00
0005432948341	25279	Economy	35300.00
0005432948328	25279	Economy	35300.00
0005433568231	25279	Economy	35300.00
0005432948314	25279	Economy	35300.00
0005432948309	25279	Economy	35300.00
0005432948306	25279	Economy	35300.00
0005432948330	25279	Economy	35300.00
0005433568295	25279	Economy	35300.00
0005433568123	25279	Economy	35300.00
0005433568312	25279	Economy	38800.00
0005433568240	25279	Economy	35300.00
0005432948343	25279	Economy	38800.00
0005433568210	25279	Economy	38800.00
0005433568236	25279	Economy	38800.00
0005433568202	25279	Economy	35300.00
0005432948337	25279	Economy	35300.00
0005433568093	25279	Economy	35300.00
0005433568360	25279	Economy	35300.00
0005433568142	25279	Economy	35300.00
0005433568270	25279	Economy	35300.00
0005433568358	25279	Economy	35300.00
0005432948338	25279	Economy	35300.00
0005433568092	25279	Economy	35300.00
0005433568280	25279	Economy	35300.00
0005432948322	25279	Economy	35300.00
0005433568294	25279	Economy	35300.00
0005433568293	25279	Economy	35300.00
0005433568355	25279	Economy	35300.00
0005433568199	25279	Economy	35300.00
0005433568091	25279	Economy	35300.00
0005432948319	25279	Economy	35300.00
0005433568261	25279	Economy	35300.00
0005433568251	25279	Economy	35300.00
0005432948325	25279	Economy	35300.00
0005432948313	25279	Economy	35300.00
0005433568122	25279	Economy	35300.00
0005433568286	25279	Economy	35300.00
0005433568036	25279	Economy	35300.00
0005433568296	25279	Economy	35300.00
0005432948340	25279	Economy	35300.00
0005433568196	25279	Economy	35300.00
0005433568305	25279	Economy	35300.00
0005433568342	25279	Economy	35300.00
0005433568361	25279	Economy	35300.00
0005432948318	25279	Economy	35300.00
0005432948317	25279	Economy	35300.00
0005433568131	25279	Economy	35300.00
0005433568110	25279	Economy	35300.00
0005432948307	25279	Economy	35300.00
0005432948342	25279	Economy	35300.00
0005432948323	25279	Economy	35300.00
0005433568230	25279	Economy	35300.00
0005433568289	25279	Economy	35300.00
0005433568205	25279	Economy	35300.00
0005432948315	25279	Economy	35300.00
0005433568259	25279	Economy	35300.00
0005432948344	25279	Economy	35300.00
0005432948345	25279	Economy	35300.00
0005433568130	25279	Economy	35300.00
0005433568237	25279	Economy	35300.00
0005432948316	25279	Economy	35300.00
0005432948331	25279	Economy	35300.00
0005433568250	25279	Economy	35300.00
0005433568287	25279	Economy	35300.00
0005432948335	25279	Economy	35300.00
0005432948332	25279	Economy	35300.00
0005432948308	25279	Economy	35300.00
0005433568283	25279	Economy	35300.00
0005433568211	25279	Economy	35300.00
0005433568075	25279	Economy	35300.00
0005432948326	25279	Economy	35300.00
0005432948346	25279	Economy	35300.00
0005433568304	25279	Economy	35300.00
0005433568035	25279	Economy	35300.00
0005433568249	25279	Economy	35300.00
0005432948311	25279	Economy	35300.00
0005432948310	25279	Economy	35300.00
0005433568260	25279	Economy	35300.00
0005433568314	25279	Economy	35300.00
0005433568200	25279	Economy	35300.00
0005432948334	25279	Economy	35300.00
0005432948339	25279	Economy	35300.00
0005433568074	25279	Economy	35300.00
0005432948336	25279	Economy	35300.00
0005432948305	25279	Economy	35300.00
0005433568285	25279	Economy	35300.00
0005434654561	5405	Business	67200.00
0005434656547	5405	Business	67200.00
0005434654558	5405	Business	67200.00
0005435340055	5405	Business	67200.00
0005434654566	5405	Business	67200.00
0005434654576	5405	Business	67200.00
0005435555355	5405	Business	67200.00
0005435555354	5405	Business	67200.00
0005434654548	5405	Business	67200.00
0005434654549	5405	Economy	22400.00
0005434654560	5405	Economy	22400.00
0005434654575	5405	Economy	24600.00
0005434654557	5405	Economy	24600.00
0005434654555	5405	Economy	22400.00
0005435340064	5405	Economy	22400.00
0005434656548	5405	Economy	22400.00
0005435340139	5405	Economy	22400.00
0005434654550	5405	Economy	22400.00
0005434654551	5405	Economy	22400.00
0005434654564	5405	Economy	22400.00
0005434654554	5405	Economy	22400.00
0005434654569	5405	Economy	22400.00
0005432114190	5405	Economy	22400.00
0005432114188	5405	Economy	22400.00
0005434654573	5405	Economy	22400.00
0005435340068	5405	Economy	22400.00
0005434654570	5405	Economy	22400.00
0005434654572	5405	Economy	22400.00
0005434654563	5405	Economy	22400.00
0005435340067	5405	Economy	22400.00
0005435340138	5405	Economy	22400.00
0005434654553	5405	Economy	22400.00
0005434654556	5405	Economy	22400.00
0005434654567	5405	Economy	22400.00
0005434654559	5405	Economy	22400.00
0005434654562	5405	Economy	22400.00
0005434654552	5405	Economy	22400.00
0005432114189	5405	Economy	22400.00
0005435340069	5405	Economy	22400.00
0005434654571	5405	Economy	22400.00
0005434654574	5405	Economy	22400.00
0005434654568	5405	Economy	22400.00
0005434654565	5405	Economy	22400.00
0005434654577	5405	Economy	22400.00
0005435555362	12549	Business	67200.00
0005435340195	12549	Business	67200.00
0005434654291	12549	Business	67200.00
0005434654292	12549	Business	67200.00
0005434654371	12549	Business	67200.00
0005434654326	12549	Business	67200.00
0005434654252	12549	Economy	22400.00
0005435340193	12549	Economy	22400.00
0005435340206	12549	Economy	22400.00
0005435340200	12549	Economy	24600.00
0005435340196	12549	Economy	24600.00
0005434654424	12549	Economy	24600.00
0005434654317	12549	Economy	22400.00
0005435340197	12549	Economy	22400.00
0005434656537	12549	Economy	22400.00
0005435340192	12549	Economy	22400.00
0005434654224	12549	Economy	22400.00
0005434656536	12549	Economy	22400.00
0005434654295	12549	Economy	22400.00
0005434654336	12549	Economy	22400.00
0005434654300	12549	Economy	22400.00
0005434654423	12549	Economy	22400.00
0005435340205	12549	Economy	22400.00
0005434656526	12549	Economy	22400.00
0005434654318	12549	Economy	22400.00
0005434654421	12549	Economy	22400.00
0005434654372	12549	Economy	22400.00
0005434656535	12549	Economy	22400.00
0005435340202	12549	Economy	22400.00
0005434654253	12549	Economy	22400.00
0005435340204	12549	Economy	22400.00
0005434654299	12549	Economy	22400.00
0005434654306	12549	Economy	22400.00
0005435340194	12549	Economy	22400.00
0005434654321	12549	Economy	22400.00
0005435340201	12549	Economy	22400.00
0005435340199	12549	Economy	22400.00
0005434656534	12549	Economy	22400.00
0005435340203	12549	Economy	22400.00
0005434654223	12549	Economy	22400.00
0005435340198	12549	Economy	22400.00
0005434654322	12549	Economy	22400.00
0005433715731	7450	Business	32000.00
0005433715753	7450	Business	32000.00
0005433715743	7450	Business	32000.00
0005433715771	7450	Business	32000.00
0005433715749	7450	Business	32000.00
0005433715736	7450	Business	32000.00
0005433689901	7450	Business	32000.00
0005433715770	7450	Business	32000.00
0005432428878	7450	Business	32000.00
0005433722194	7450	Economy	10700.00
0005433715740	7450	Economy	10700.00
0005433715776	7450	Economy	10700.00
0005433656654	7450	Economy	10700.00
0005433722189	7450	Economy	10700.00
0005433715780	7450	Economy	10700.00
0005433715759	7450	Economy	10700.00
0005432078084	7450	Economy	10700.00
0005433688798	7450	Economy	10700.00
0005433715765	7450	Economy	10700.00
0005433715778	7450	Economy	10700.00
0005433722188	7450	Economy	10700.00
0005433715750	7450	Economy	10700.00
0005432078087	7450	Economy	10700.00
0005433715739	7450	Economy	10700.00
0005433715752	7450	Economy	10700.00
0005433719125	7450	Economy	10700.00
0005433722191	7450	Economy	10700.00
0005433715755	7450	Economy	10700.00
0005433715763	7450	Economy	10700.00
0005433715741	7450	Economy	10700.00
0005433715745	7450	Economy	10700.00
0005433715781	7450	Economy	10700.00
0005433715769	7450	Economy	10700.00
0005432428875	7450	Economy	10700.00
0005433715737	7450	Economy	10700.00
0005433722193	7450	Economy	10700.00
0005433719124	7450	Economy	11700.00
0005433722190	7450	Economy	10700.00
0005433715775	7450	Economy	11700.00
0005433722192	7450	Economy	11700.00
0005433715746	7450	Economy	11700.00
0005433719126	7450	Economy	11700.00
0005432078086	7450	Economy	10700.00
0005432428885	7450	Economy	10700.00
0005433715777	7450	Economy	10700.00
0005432078082	7450	Economy	10700.00
0005433715767	7450	Economy	10700.00
0005433715747	7450	Economy	10700.00
0005433715760	7450	Economy	10700.00
0005433715748	7450	Economy	10700.00
0005433715738	7450	Economy	10700.00
0005433715762	7450	Economy	10700.00
0005433715757	7450	Economy	10700.00
0005433715732	7450	Economy	10700.00
0005432428867	7450	Economy	10700.00
0005433656653	7450	Economy	10700.00
0005433722196	7450	Economy	10700.00
0005432428877	7450	Economy	10700.00
0005433688799	7450	Economy	10700.00
0005433715766	7450	Economy	10700.00
0005433722195	7450	Economy	10700.00
0005433715754	7450	Economy	10700.00
0005433715751	7450	Economy	10700.00
0005433719123	7450	Economy	10700.00
0005432428887	7450	Economy	10700.00
0005433715768	7450	Economy	10700.00
0005433715764	7450	Economy	10700.00
0005432078088	7450	Economy	10700.00
0005432078083	7450	Economy	10700.00
0005433715758	7450	Economy	10700.00
0005433715779	7450	Economy	10700.00
0005433715772	7450	Economy	10700.00
0005433722187	7450	Economy	10700.00
0005432078085	7450	Economy	10700.00
0005433715744	7450	Economy	10700.00
0005433715742	7450	Economy	10700.00
0005433715774	7450	Economy	10700.00
0005432428876	7450	Economy	10700.00
0005433715773	7450	Economy	10700.00
0005433719122	7450	Economy	10700.00
0005433715761	7450	Economy	10700.00
0005433715733	7450	Economy	10700.00
0005433715735	7450	Economy	10700.00
0005433656655	7450	Economy	10700.00
0005433689900	7450	Economy	10700.00
0005433715734	7450	Economy	10700.00
0005432428886	7450	Economy	10700.00
0005433715756	7450	Economy	10700.00
0005433715506	29244	Business	32000.00
0005432428913	29244	Business	32000.00
0005433722114	29244	Business	32000.00
0005433715385	29244	Business	32000.00
0005433719093	29244	Business	32000.00
0005433715357	29244	Business	32000.00
0005433715475	29244	Business	32000.00
0005433715263	29244	Economy	10700.00
0005433715289	29244	Economy	10700.00
0005433715265	29244	Economy	10700.00
0005433715505	29244	Economy	10700.00
0005433715360	29244	Economy	10700.00
0005433719094	29244	Economy	10700.00
0005433656622	29244	Economy	10700.00
0005433715284	29244	Economy	10700.00
0005433715228	29244	Economy	10700.00
0005433715308	29244	Economy	10700.00
0005433715320	29244	Economy	10700.00
0005433715504	29244	Economy	10700.00
0005433715368	29244	Economy	10700.00
0005433715361	29244	Economy	10700.00
0005433715381	29244	Economy	10700.00
0005433715276	29244	Economy	10700.00
0005433719110	29244	Economy	10700.00
0005433715543	29244	Economy	10700.00
0005433719109	29244	Economy	10700.00
0005433719092	29244	Economy	10700.00
0005433715397	29244	Economy	10700.00
0005433715316	29244	Economy	10700.00
0005433715373	29244	Economy	10700.00
0005433715312	29244	Economy	10700.00
0005433715248	29244	Economy	11700.00
0005435266135	29244	Economy	11700.00
0005433715157	29244	Economy	11700.00
0005433719084	29244	Economy	11700.00
0005433715507	29244	Economy	10700.00
0005433715384	29244	Economy	10700.00
0005433715216	29244	Economy	10700.00
0005433715101	29244	Economy	10700.00
0005433715440	29244	Economy	10700.00
0005433715401	29244	Economy	10700.00
0005433715285	29244	Economy	10700.00
0005433715302	29244	Economy	10700.00
0005433722113	29244	Economy	10700.00
0005433715300	29244	Economy	10700.00
0005433715560	29244	Economy	10700.00
0005433715100	29244	Economy	10700.00
0005435266134	29244	Economy	10700.00
0005433715472	29244	Economy	10700.00
0005433715473	29244	Economy	10700.00
0005433715321	29244	Economy	10700.00
0005433715494	29244	Economy	10700.00
0005432006748	29244	Economy	10700.00
0005433715231	29244	Economy	10700.00
0005433715337	29244	Economy	10700.00
0005433715356	29244	Economy	10700.00
0005433719108	29244	Economy	10700.00
0005432006747	29244	Economy	10700.00
0005433715451	29244	Economy	10700.00
0005433715374	29244	Economy	10700.00
0005433715362	29244	Economy	10700.00
0005433715386	29244	Economy	10700.00
0005432428914	29244	Economy	10700.00
0005433715359	29244	Economy	10700.00
0005433715476	29244	Economy	10700.00
0005432428915	29244	Economy	10700.00
0005433715303	29244	Economy	10700.00
0005433715301	29244	Economy	10700.00
0005432006749	29244	Economy	10700.00
0005433722108	29244	Economy	10700.00
0005433715295	29244	Economy	10700.00
0005433715264	29244	Economy	10700.00
0005433715375	29244	Economy	10700.00
0005433719103	29244	Economy	10700.00
0005434095218	8660	Business	36500.00
0005434095221	8660	Economy	12200.00
0005434182055	8660	Economy	12200.00
0005434095220	8660	Economy	12200.00
0005434182001	8660	Economy	12200.00
0005434095213	8660	Economy	13400.00
0005434182040	8660	Economy	12200.00
0005434182017	8660	Economy	12200.00
0005434095208	8660	Economy	12200.00
0005434095219	8660	Economy	12200.00
0005434184642	8660	Economy	12200.00
0005434182087	8660	Economy	12200.00
0005434095209	8660	Economy	12200.00
0005434182045	8660	Economy	12200.00
0005434095216	8660	Economy	12200.00
0005434095217	8660	Economy	12200.00
0005434184649	8660	Economy	12200.00
0005434182039	8660	Economy	12200.00
0005434095212	8660	Economy	12200.00
0005434182038	8660	Economy	12200.00
0005434095210	8660	Economy	12200.00
0005434182056	8660	Economy	12200.00
0005434095211	8660	Economy	12200.00
0005434184641	8660	Economy	12200.00
0005434095214	8660	Economy	12200.00
0005434095215	8660	Economy	12200.00
0005434095207	8660	Economy	12200.00
0005434182125	11650	Business	36500.00
0005434182134	11650	Business	36500.00
0005434182136	11650	Business	36500.00
0005434183568	11650	Business	36500.00
0005434182124	11650	Business	36500.00
0005434183570	11650	Economy	12200.00
0005434182128	11650	Economy	12200.00
0005434182129	11650	Economy	12200.00
0005434095067	11650	Economy	12200.00
0005434143708	11650	Economy	13400.00
0005434095131	11650	Economy	13400.00
0005434095076	11650	Economy	12200.00
0005434095110	11650	Economy	12200.00
0005434183569	11650	Economy	12200.00
0005434184655	11650	Economy	12200.00
0005434326084	11650	Economy	12200.00
0005434095115	11650	Economy	12200.00
0005434095085	11650	Economy	12200.00
0005434095116	11650	Economy	12200.00
0005434143709	11650	Economy	12200.00
0005434095096	11650	Economy	12200.00
0005434184654	11650	Economy	12200.00
0005434095075	11650	Economy	12200.00
0005434182127	11650	Economy	12200.00
0005434182126	11650	Economy	12200.00
0005434095140	11650	Economy	12200.00
0005434182131	11650	Economy	12200.00
0005434182133	11650	Economy	12200.00
0005434182132	11650	Economy	12200.00
0005434182130	11650	Economy	12200.00
0005434095111	11650	Economy	12200.00
0005434095095	11650	Economy	12200.00
0005434095139	11650	Economy	12200.00
0005434095066	11650	Economy	12200.00
0005434095144	11650	Economy	12200.00
0005434095132	11650	Economy	12200.00
0005434182135	11650	Economy	12200.00
0005434143699	11650	Economy	12200.00
0005434095046	11650	Economy	12200.00
0005434143700	11650	Economy	12200.00
0005435732286	1469	Business	33000.00
0005435732291	1469	Business	33000.00
0005435732287	1469	Business	33000.00
0005433397476	1469	Business	33000.00
0005433397189	1469	Business	33000.00
0005433397372	1469	Business	33000.00
0005433397336	1469	Business	33000.00
0005433397455	1469	Business	33000.00
0005433397446	1469	Business	33000.00
0005433397394	1469	Economy	11000.00
0005435732290	1469	Economy	11000.00
0005433397422	1469	Economy	11000.00
0005433397517	1469	Economy	11000.00
0005433397507	1469	Economy	11000.00
0005435732289	1469	Economy	11000.00
0005433397487	1469	Economy	11000.00
0005435732288	1469	Economy	11000.00
0005433397573	1469	Economy	11000.00
0005433397343	1469	Economy	12100.00
0005433397382	1469	Economy	12100.00
0005435732283	1469	Economy	12100.00
0005433397518	1469	Economy	12100.00
0005435732285	1469	Economy	12100.00
0005433456953	1469	Economy	11000.00
0005433397414	1469	Economy	11000.00
0005433397421	1469	Economy	11000.00
0005435732284	1469	Economy	11000.00
0005433397370	1469	Economy	11000.00
0005433397501	1469	Economy	11000.00
0005433456952	1469	Economy	11000.00
0005433397309	1469	Economy	11000.00
0005433397416	1469	Economy	11000.00
0005433397506	1469	Economy	11000.00
0005432906505	1469	Economy	11000.00
0005435732292	1469	Economy	11000.00
0005433397238	1469	Economy	11000.00
0005432906506	1469	Economy	11000.00
0005433397415	1469	Economy	11000.00
0005433397241	1469	Economy	11000.00
0005432297266	1469	Economy	11000.00
0005433397368	1469	Economy	11000.00
0005433397338	1469	Economy	11000.00
0005433397395	1469	Economy	11000.00
0005433397324	1469	Economy	11000.00
0005433397371	1469	Economy	11000.00
0005432906494	1469	Economy	11000.00
0005433397550	1469	Economy	11000.00
0005433397441	1469	Economy	11000.00
0005432297265	1469	Economy	11000.00
0005433397426	1469	Economy	11000.00
0005433397474	1469	Economy	11000.00
0005433397427	1469	Economy	11000.00
0005433397445	1469	Economy	11000.00
0005433397565	1469	Economy	11000.00
0005433397369	1469	Economy	11000.00
0005435732282	1469	Economy	11000.00
0005433397268	1469	Economy	11000.00
0005433397242	1469	Economy	11000.00
0005432297267	1469	Economy	11000.00
0005433397485	1469	Economy	11000.00
0005433397428	1469	Economy	11000.00
0005433397502	1469	Economy	11000.00
0005433397373	1469	Economy	11000.00
0005432906493	1469	Economy	11000.00
0005433397334	1469	Economy	11000.00
0005433397335	1469	Economy	11000.00
0005433397562	1469	Economy	11000.00
0005433397267	1469	Economy	11000.00
0005433397593	1469	Economy	11000.00
0005433397339	1469	Economy	11000.00
0005433397359	1469	Economy	11000.00
0005433397829	19266	Business	33000.00
0005433397834	19266	Business	33000.00
0005433456907	19266	Business	33000.00
0005433397841	19266	Business	33000.00
0005435732165	19266	Business	33000.00
0005433397827	19266	Business	33000.00
0005435732256	19266	Business	33000.00
0005433397842	19266	Economy	11000.00
0005433397868	19266	Economy	11000.00
0005435732255	19266	Economy	11000.00
0005435732164	19266	Economy	11000.00
0005433397860	19266	Economy	11000.00
0005433397843	19266	Economy	11000.00
0005433397832	19266	Economy	11000.00
0005435732133	19266	Economy	11000.00
0005433397854	19266	Economy	12100.00
0005433397866	19266	Economy	12100.00
0005433397863	19266	Economy	12100.00
0005435732204	19266	Economy	12100.00
0005433397867	19266	Economy	11000.00
0005433397870	19266	Economy	11000.00
0005433397845	19266	Economy	11000.00
0005435732155	19266	Economy	11000.00
0005433397850	19266	Economy	11000.00
0005433397861	19266	Economy	11000.00
0005433397833	19266	Economy	11000.00
0005435732187	19266	Economy	11000.00
0005433397848	19266	Economy	11000.00
0005433397851	19266	Economy	11000.00
0005433397856	19266	Economy	11000.00
0005432906524	19266	Economy	11000.00
0005433397859	19266	Economy	11000.00
0005433397831	19266	Economy	11000.00
0005432906525	19266	Economy	11000.00
0005433397864	19266	Economy	11000.00
0005433397838	19266	Economy	11000.00
0005433397835	19266	Economy	11000.00
0005433397862	19266	Economy	11000.00
0005433397852	19266	Economy	11000.00
0005432906526	19266	Economy	11000.00
0005433397869	19266	Economy	11000.00
0005435732175	19266	Economy	11000.00
0005433397844	19266	Economy	11000.00
0005435732177	19266	Economy	11000.00
0005433397865	19266	Economy	11000.00
0005433397828	19266	Economy	11000.00
0005433397836	19266	Economy	11000.00
0005433397846	19266	Economy	11000.00
0005433397873	19266	Economy	11000.00
0005433397837	19266	Economy	11000.00
0005435732119	19266	Economy	11000.00
0005433397853	19266	Economy	11000.00
0005433397830	19266	Economy	11000.00
0005433397855	19266	Economy	11000.00
0005433397840	19266	Economy	11000.00
0005433397826	19266	Economy	11000.00
0005435732176	19266	Economy	11000.00
0005433456908	19266	Economy	11000.00
0005433397847	19266	Economy	11000.00
0005435732171	19266	Economy	11000.00
0005433397839	19266	Economy	11000.00
0005435732170	19266	Economy	11000.00
0005433397872	19266	Economy	11000.00
0005433397849	19266	Economy	11000.00
0005435732178	19266	Economy	11000.00
0005433397857	19266	Economy	11000.00
0005433397871	19266	Economy	11000.00
0005435732129	19266	Economy	11000.00
0005433397858	19266	Economy	11000.00
0005434443462	17358	Economy	15600.00
0005434443492	17358	Economy	15600.00
0005434443506	17358	Economy	14100.00
0005434443494	17358	Economy	14100.00
0005434443537	17358	Economy	14100.00
0005434443526	17358	Economy	14100.00
0005434443480	17358	Economy	14100.00
0005434443501	17358	Economy	14100.00
0005434443519	17358	Economy	14100.00
0005434443507	17358	Economy	14100.00
0005434443466	17358	Economy	14100.00
0005434443426	17358	Economy	14100.00
0005434443533	17358	Economy	14100.00
0005434443493	17358	Economy	14100.00
0005434443441	17358	Economy	14100.00
0005434443534	17358	Economy	14100.00
0005434443505	17358	Economy	14100.00
0005434443474	17358	Economy	14100.00
0005434443535	17358	Economy	14100.00
0005434443465	17358	Economy	14100.00
0005434443485	17358	Economy	14100.00
0005434443427	17358	Economy	14100.00
0005434443468	17358	Economy	14100.00
0005434443448	17358	Economy	14100.00
0005434443626	20571	Economy	15600.00
0005434443634	20571	Economy	15600.00
0005434443633	20571	Economy	14100.00
0005434443637	20571	Economy	14100.00
0005434443629	20571	Economy	14100.00
0005434443632	20571	Economy	14100.00
0005434443623	20571	Economy	14100.00
0005434443630	20571	Economy	14100.00
0005434443624	20571	Economy	14100.00
0005434443636	20571	Economy	14100.00
0005434443628	20571	Economy	14100.00
0005434443622	20571	Economy	14100.00
0005434443625	20571	Economy	14100.00
0005434443631	20571	Economy	14100.00
0005434443635	20571	Economy	14100.00
0005434443627	20571	Economy	14100.00
0005434954591	7244	Economy	5800.00
0005435377559	7244	Economy	5800.00
0005434954592	7244	Economy	5800.00
0005435377558	7244	Economy	5800.00
0005435377557	7244	Economy	5800.00
0005434954590	7244	Economy	5800.00
0005434954593	7244	Economy	5800.00
0005435377560	7244	Economy	5800.00
0005434954558	28351	Economy	5800.00
0005434954544	28351	Economy	5800.00
0005434954556	28351	Economy	5800.00
0005435377570	28351	Economy	5800.00
0005434954557	28351	Economy	5800.00
0005435377571	28351	Economy	5800.00
0005434954545	28351	Economy	5800.00
0005434954568	28351	Economy	5800.00
0005434954551	28351	Economy	5800.00
0005434351643	4482	Economy	15400.00
0005434351639	4482	Economy	14000.00
0005434351640	4482	Economy	14000.00
0005434351637	4482	Economy	14000.00
0005434351638	4482	Economy	14000.00
0005434326269	4482	Economy	14000.00
0005434351645	4482	Economy	14000.00
0005434351644	4482	Economy	14000.00
0005434183551	4482	Economy	14000.00
0005434351636	4482	Economy	14000.00
0005434183559	4482	Economy	14000.00
0005435893558	4482	Economy	14000.00
0005434183552	4482	Economy	14000.00
0005434351641	4482	Economy	14000.00
0005434351642	4482	Economy	14000.00
0005434183558	4482	Economy	14000.00
0005434351646	4482	Economy	14000.00
0005434351635	4482	Economy	14000.00
0005435893602	29658	Economy	15400.00
0005434351494	29658	Economy	15400.00
0005435893598	29658	Economy	15400.00
0005435893601	29658	Economy	14000.00
0005435893597	29658	Economy	14000.00
0005434351483	29658	Economy	14000.00
0005434351478	29658	Economy	14000.00
0005434351513	29658	Economy	14000.00
0005434351530	29658	Economy	14000.00
0005435893600	29658	Economy	14000.00
0005434351529	29658	Economy	14000.00
0005435893603	29658	Economy	14000.00
0005435893599	29658	Economy	14000.00
0005434351567	29658	Economy	14000.00
0005434351527	29658	Economy	14000.00
0005434351545	29658	Economy	14000.00
0005435893604	29658	Economy	14000.00
0005434351603	29658	Economy	14000.00
0005434351604	29658	Economy	14000.00
0005433341624	1051	Business	30600.00
0005435545710	1051	Business	30600.00
0005433342309	1051	Business	30600.00
0005435092034	1051	Business	30600.00
0005433341426	1051	Business	30600.00
0005435545711	1051	Business	30600.00
0005433341888	1051	Business	30600.00
0005433342172	1051	Business	30600.00
0005433342177	1051	Business	30600.00
0005433342101	1051	Business	30600.00
0005433341767	1051	Business	30600.00
0005433341728	1051	Business	30600.00
0005433341742	1051	Business	30600.00
0005433463892	1051	Business	30600.00
0005433341582	1051	Business	30600.00
0005433342179	1051	Business	30600.00
0005433342054	1051	Business	30600.00
0005433341986	1051	Business	30600.00
0005433462738	1051	Business	30600.00
0005433341817	1051	Business	30600.00
0005435092028	1051	Economy	11200.00
0005433341446	1051	Economy	11200.00
0005433269627	1051	Economy	10200.00
0005433341489	1051	Economy	10200.00
0005435092033	1051	Economy	10200.00
0005433341747	1051	Economy	10200.00
0005433341632	1051	Economy	10200.00
0005433341788	1051	Economy	10200.00
0005433341849	1051	Economy	10200.00
0005435545712	1051	Economy	10200.00
0005433341685	1051	Economy	10200.00
0005433341729	1051	Economy	10200.00
0005433341726	1051	Economy	10200.00
0005433341686	1051	Economy	10200.00
0005435545697	1051	Economy	10200.00
0005435092035	1051	Economy	10200.00
0005433342251	1051	Economy	10200.00
0005435545709	1051	Economy	10200.00
0005433341757	1051	Economy	10200.00
0005433158096	1051	Economy	10200.00
0005435092032	1051	Economy	10200.00
0005433341701	1051	Economy	10200.00
0005433159276	1051	Economy	10200.00
0005433463891	1051	Economy	10200.00
0005435545714	1051	Economy	10200.00
0005433342189	1051	Economy	10200.00
0005435545713	1051	Economy	10200.00
0005435545700	1051	Economy	10200.00
0005433342021	1051	Economy	10200.00
0005432293197	1051	Economy	10200.00
0005433342072	1051	Economy	10200.00
0005433342188	1051	Economy	10200.00
0005433341816	1051	Economy	10200.00
0005433341844	1051	Economy	10200.00
0005433341821	1051	Economy	10200.00
0005433341741	1051	Economy	10200.00
0005433462736	1051	Economy	10200.00
0005433342019	1051	Economy	10200.00
0005434445239	1051	Economy	10200.00
0005433341965	1051	Economy	10200.00
0005433269643	1051	Economy	10200.00
0005435545701	1051	Economy	10200.00
0005433463890	1051	Economy	10200.00
0005433341572	1051	Economy	10200.00
0005433341755	1051	Economy	10200.00
0005433341581	1051	Economy	10200.00
0005433158104	1051	Economy	10200.00
0005433341843	1051	Economy	10200.00
0005433462737	1051	Economy	10200.00
0005433341813	1051	Economy	10200.00
0005433342337	1051	Economy	10200.00
0005435545699	1051	Economy	10200.00
0005433342018	1051	Economy	10200.00
0005435092029	1051	Economy	10200.00
0005432293198	1051	Economy	10200.00
0005435545706	1051	Economy	10200.00
0005433341752	1051	Economy	10200.00
0005433462739	1051	Economy	10200.00
0005433341390	1051	Economy	10200.00
0005433342176	1051	Economy	10200.00
0005433341766	1051	Economy	10200.00
0005433341805	1051	Economy	10200.00
0005433269664	1051	Economy	10200.00
0005433341675	1051	Economy	10200.00
0005433341754	1051	Economy	10200.00
0005433269651	1051	Economy	10200.00
0005433341447	1051	Economy	10200.00
0005433341845	1051	Economy	10200.00
0005433341455	1051	Economy	10200.00
0005433341389	1051	Economy	10200.00
0005435545702	1051	Economy	11200.00
0005433342062	1051	Economy	10200.00
0005433158105	1051	Economy	10200.00
0005433342178	1051	Economy	11200.00
0005435545698	1051	Economy	10200.00
0005433342017	1051	Economy	10200.00
0005435545703	1051	Economy	10200.00
0005433342250	1051	Economy	10200.00
0005433341765	1051	Economy	10200.00
0005433341631	1051	Economy	10200.00
0005435545704	1051	Economy	10200.00
0005433341981	1051	Economy	10200.00
0005433342099	1051	Economy	10200.00
0005433341625	1051	Economy	10200.00
0005435545707	1051	Economy	10200.00
0005433342053	1051	Economy	10200.00
0005433341427	1051	Economy	10200.00
0005435092030	1051	Economy	10200.00
0005433342138	1051	Economy	10200.00
0005433342045	1051	Economy	10200.00
0005433158098	1051	Economy	10200.00
0005433341413	1051	Economy	10200.00
0005434445238	1051	Economy	10200.00
0005433341966	1051	Economy	10200.00
0005435092031	1051	Economy	10200.00
0005433341842	1051	Economy	10200.00
0005433341535	1051	Economy	10200.00
0005433341873	1051	Economy	10200.00
0005433341748	1051	Economy	10200.00
0005433341655	1051	Economy	10200.00
0005433341998	1051	Economy	10200.00
0005433341751	1051	Economy	10200.00
0005433341623	1051	Economy	10200.00
0005433341862	1051	Economy	10200.00
0005433341727	1051	Economy	10200.00
0005433341490	1051	Economy	10200.00
0005432293199	1051	Economy	10200.00
0005433158097	1051	Economy	10200.00
0005433341949	1051	Economy	10200.00
0005433342275	1051	Economy	10200.00
0005433341612	1051	Economy	10200.00
0005433159275	1051	Economy	10200.00
0005435545705	1051	Economy	10200.00
0005433342173	1051	Economy	10200.00
0005433341995	1051	Economy	10200.00
0005433342044	1051	Economy	10200.00
0005433342182	1051	Economy	10200.00
0005433341789	1051	Economy	10200.00
0005435545708	1051	Economy	10200.00
0005433341548	1051	Economy	10200.00
0005433342617	17050	Business	30600.00
0005433342644	17050	Business	30600.00
0005433342663	17050	Business	30600.00
0005433342648	17050	Business	30600.00
0005433342613	17050	Business	30600.00
0005435091950	17050	Business	30600.00
0005433342687	17050	Business	30600.00
0005433342658	17050	Business	30600.00
0005433342627	17050	Business	30600.00
0005434445216	17050	Business	30600.00
0005435092010	17050	Business	30600.00
0005435508190	17050	Business	30600.00
0005433342645	17050	Business	30600.00
0005433342699	17050	Business	30600.00
0005435091928	17050	Business	30600.00
0005433342683	17050	Business	30600.00
0005433342700	17050	Business	30600.00
0005433342608	17050	Business	30600.00
0005433342649	17050	Business	30600.00
0005433342656	17050	Business	30600.00
0005433342688	17050	Business	30600.00
0005435508186	17050	Economy	11200.00
0005433342684	17050	Business	30600.00
0005435091956	17050	Economy	11200.00
0005433159303	17050	Economy	10200.00
0005433342654	17050	Economy	10200.00
0005433342660	17050	Economy	10200.00
0005435508176	17050	Economy	10200.00
0005433342650	17050	Economy	10200.00
0005433342606	17050	Economy	10200.00
0005435508166	17050	Economy	10200.00
0005433342599	17050	Economy	10200.00
0005433342651	17050	Economy	10200.00
0005433342652	17050	Economy	10200.00
0005433342677	17050	Economy	10200.00
0005433342647	17050	Economy	10200.00
0005433342653	17050	Economy	10200.00
0005433342690	17050	Economy	10200.00
0005433342625	17050	Economy	10200.00
0005433342661	17050	Economy	10200.00
0005433342633	17050	Economy	10200.00
0005433342635	17050	Economy	10200.00
0005433342665	17050	Economy	10200.00
0005433342675	17050	Economy	10200.00
0005433269696	17050	Economy	10200.00
0005435508220	17050	Economy	10200.00
0005435508175	17050	Economy	10200.00
0005433342697	17050	Economy	10200.00
0005433342671	17050	Economy	10200.00
0005435508189	17050	Economy	10200.00
0005433342676	17050	Economy	10200.00
0005433342696	17050	Economy	10200.00
0005433342618	17050	Economy	10200.00
0005433342668	17050	Economy	10200.00
0005435091948	17050	Economy	10200.00
0005433342686	17050	Economy	10200.00
0005433342634	17050	Economy	10200.00
0005433342692	17050	Economy	10200.00
0005433342642	17050	Economy	10200.00
0005433342695	17050	Economy	10200.00
0005433342637	17050	Economy	10200.00
0005433342680	17050	Economy	10200.00
0005433342631	17050	Economy	10200.00
0005435508204	17050	Economy	10200.00
0005433342612	17050	Economy	10200.00
0005433342674	17050	Economy	10200.00
0005433342609	17050	Economy	10200.00
0005433342640	17050	Economy	10200.00
0005433342639	17050	Economy	10200.00
0005435091975	17050	Economy	10200.00
0005435091954	17050	Economy	10200.00
0005433342630	17050	Economy	10200.00
0005435508218	17050	Economy	10200.00
0005433342628	17050	Economy	10200.00
0005433342615	17050	Economy	10200.00
0005433159301	17050	Economy	10200.00
0005433342636	17050	Economy	10200.00
0005433342669	17050	Economy	10200.00
0005433342605	17050	Economy	10200.00
0005433342664	17050	Economy	10200.00
0005433342600	17050	Economy	10200.00
0005433342620	17050	Economy	10200.00
0005433342679	17050	Economy	11200.00
0005433342622	17050	Economy	10200.00
0005433342685	17050	Economy	10200.00
0005433342604	17050	Economy	10200.00
0005433269692	17050	Economy	10200.00
0005433342667	17050	Economy	10200.00
0005433342646	17050	Economy	10200.00
0005433342657	17050	Economy	10200.00
0005433342694	17050	Economy	10200.00
0005433342655	17050	Economy	10200.00
0005433342629	17050	Economy	10200.00
0005433269697	17050	Economy	10200.00
0005433342603	17050	Economy	10200.00
0005435508217	17050	Economy	10200.00
0005433342616	17050	Economy	10200.00
0005433342643	17050	Economy	10200.00
0005433342701	17050	Economy	10200.00
0005433269694	17050	Economy	10200.00
0005433342682	17050	Economy	10200.00
0005433342623	17050	Economy	10200.00
0005433342698	17050	Economy	10200.00
0005433342641	17050	Economy	10200.00
0005433269695	17050	Economy	10200.00
0005435091986	17050	Economy	10200.00
0005433342610	17050	Economy	10200.00
0005435091923	17050	Economy	10200.00
0005433342621	17050	Economy	10200.00
0005433342611	17050	Economy	10200.00
0005433342689	17050	Economy	10200.00
0005433342662	17050	Economy	10200.00
0005435508177	17050	Economy	10200.00
0005433342601	17050	Economy	10200.00
0005433269693	17050	Economy	10200.00
0005433342678	17050	Economy	10200.00
0005433342638	17050	Economy	10200.00
0005433342672	17050	Economy	10200.00
0005435091982	17050	Economy	10200.00
0005433342659	17050	Economy	10200.00
0005433342666	17050	Economy	10200.00
0005433342681	17050	Economy	10200.00
0005433342607	17050	Economy	10200.00
0005433342614	17050	Economy	10200.00
0005433342632	17050	Economy	10200.00
0005433342626	17050	Economy	10200.00
0005433342619	17050	Economy	10200.00
0005433342602	17050	Economy	10200.00
0005435091922	17050	Economy	10200.00
0005433342693	17050	Economy	10200.00
0005435092011	17050	Economy	10200.00
0005433342624	17050	Economy	10200.00
0005433159302	17050	Economy	10200.00
0005433342670	17050	Economy	10200.00
0005433342673	17050	Economy	10200.00
0005433342691	17050	Economy	10200.00
0005432851825	1335	Business	101000.00
0005432390098	1335	Business	101000.00
0005432390094	1335	Business	101000.00
0005432391982	1335	Business	101000.00
0005432851820	1335	Business	101000.00
0005432390066	1335	Business	101000.00
0005432390091	1335	Business	101000.00
0005432391977	1335	Business	101000.00
0005432390055	1335	Business	101000.00
0005432390089	1335	Business	101000.00
0005432390064	1335	Business	101000.00
0005432851837	1335	Business	101000.00
0005432391980	1335	Business	101000.00
0005432390072	1335	Business	101000.00
0005432390062	1335	Business	101000.00
0005432390061	1335	Economy	33700.00
0005432390057	1335	Economy	33700.00
0005432390084	1335	Economy	33700.00
0005432851823	1335	Economy	33700.00
0005432390060	1335	Economy	33700.00
0005432851828	1335	Economy	33700.00
0005432390073	1335	Economy	33700.00
0005432390068	1335	Economy	33700.00
0005432390080	1335	Economy	37000.00
0005432391973	1335	Economy	37000.00
0005432390077	1335	Economy	37000.00
0005432851835	1335	Economy	37000.00
0005432390090	1335	Economy	33700.00
0005432390096	1335	Economy	33700.00
0005432391976	1335	Economy	33700.00
0005432390075	1335	Economy	33700.00
0005432390069	1335	Economy	33700.00
0005432391975	1335	Economy	33700.00
0005432390092	1335	Economy	33700.00
0005432851838	1335	Economy	33700.00
0005432390056	1335	Economy	33700.00
0005432390058	1335	Economy	33700.00
0005432390076	1335	Economy	33700.00
0005432390070	1335	Economy	33700.00
0005432390081	1335	Economy	33700.00
0005432851821	1335	Economy	33700.00
0005432391985	1335	Economy	33700.00
0005432391978	1335	Economy	33700.00
0005432390088	1335	Economy	33700.00
0005432390065	1335	Economy	33700.00
0005432391974	1335	Economy	33700.00
0005432390078	1335	Economy	33700.00
0005432390052	1335	Economy	33700.00
0005432390085	1335	Economy	33700.00
0005432390053	1335	Economy	33700.00
0005432390097	1335	Economy	33700.00
0005432391984	1335	Economy	33700.00
0005432390082	1335	Economy	33700.00
0005432390059	1335	Economy	33700.00
0005432390067	1335	Economy	33700.00
0005432391979	1335	Economy	33700.00
0005432390083	1335	Economy	33700.00
0005432391981	1335	Economy	33700.00
0005432390074	1335	Economy	33700.00
0005432851826	1335	Economy	33700.00
0005432390063	1335	Economy	33700.00
0005432851827	1335	Economy	33700.00
0005432390093	1335	Economy	33700.00
0005432851816	1335	Economy	33700.00
0005432390087	1335	Economy	33700.00
0005432391983	1335	Economy	33700.00
0005432390071	1335	Economy	33700.00
0005432390086	1335	Economy	33700.00
0005432390079	1335	Economy	33700.00
0005432851836	1335	Economy	33700.00
0005432390095	1335	Economy	33700.00
0005432390054	1335	Economy	33700.00
0005432851829	1335	Economy	33700.00
0005432159839	12768	Business	40300.00
0005434066488	12768	Business	40300.00
0005434081565	12768	Business	40300.00
0005434066602	12768	Business	40300.00
0005434066397	12768	Business	40300.00
0005434081471	12768	Business	40300.00
0005434066629	12768	Business	40300.00
0005434066625	12768	Business	40300.00
0005433989718	12768	Business	40300.00
0005434081580	12768	Business	40300.00
0005434066478	12768	Business	40300.00
0005434066551	12768	Economy	13400.00
0005434066803	12768	Economy	13400.00
0005434081642	12768	Economy	13400.00
0005432433658	12768	Economy	13400.00
0005433989707	12768	Economy	13400.00
0005434066720	12768	Economy	13400.00
0005434066483	12768	Economy	13400.00
0005434066554	12768	Economy	13400.00
0005434066905	12768	Economy	13400.00
0005434066768	12768	Economy	13400.00
0005434066735	12768	Economy	13400.00
0005434066687	12768	Economy	13400.00
0005434081648	12768	Economy	13400.00
0005434081576	12768	Economy	13400.00
0005434066587	12768	Economy	13400.00
0005434066839	12768	Economy	13400.00
0005434066558	12768	Economy	13400.00
0005434066747	12768	Economy	13400.00
0005433989695	12768	Economy	13400.00
0005434066568	12768	Economy	13400.00
0005434066993	12768	Economy	13400.00
0005434081578	12768	Economy	13400.00
0005434081581	12768	Economy	13400.00
0005434081610	12768	Economy	13400.00
0005434066863	12768	Economy	13400.00
0005434066490	12768	Economy	13400.00
0005434066992	12768	Economy	13400.00
0005434066703	12768	Economy	13400.00
0005434066563	12768	Economy	13400.00
0005434066552	12768	Economy	13400.00
0005434066566	12768	Economy	13400.00
0005434081631	12768	Economy	13400.00
0005432433654	12768	Economy	13400.00
0005434066788	12768	Economy	13400.00
0005434081504	12768	Economy	13400.00
0005434066640	12768	Economy	13400.00
0005434066595	12768	Economy	13400.00
0005434066704	12768	Economy	13400.00
0005432159840	12768	Economy	13400.00
0005433989706	12768	Economy	14800.00
0005434066922	12768	Economy	14800.00
0005433812890	12768	Economy	14800.00
0005433812891	12768	Economy	14800.00
0005434066428	12768	Economy	13400.00
0005434066787	12768	Economy	13400.00
0005434066877	12768	Economy	13400.00
0005434066546	12768	Economy	13400.00
0005434066592	12768	Economy	13400.00
0005432433655	12768	Economy	13400.00
0005432433656	12768	Economy	13400.00
0005433989716	12768	Economy	13400.00
0005434066607	12768	Economy	13400.00
0005433989696	12768	Economy	13400.00
0005434066686	12768	Economy	13400.00
0005434066596	12768	Economy	13400.00
0005434081577	12768	Economy	13400.00
0005432433657	12768	Economy	13400.00
0005434066923	12768	Economy	13400.00
0005432159837	12768	Economy	13400.00
0005432161142	12768	Economy	13400.00
0005432159838	12768	Economy	13400.00
0005434066512	12768	Economy	13400.00
0005434066326	12768	Economy	13400.00
0005434081564	12768	Economy	13400.00
0005433989705	12768	Economy	13400.00
0005434066470	12768	Economy	13400.00
0005434081590	12768	Economy	13400.00
0005434066586	12768	Economy	13400.00
0005434066668	12768	Economy	13400.00
0005434066876	12768	Economy	13400.00
0005434066480	12768	Economy	13400.00
0005433989692	12768	Economy	13400.00
0005434066533	12768	Economy	13400.00
0005434066657	12768	Economy	13400.00
0005433989698	12768	Economy	13400.00
0005432161143	12768	Economy	13400.00
0005434066513	12768	Economy	13400.00
0005434066532	12768	Economy	13400.00
0005434081619	12768	Economy	13400.00
0005434066688	12768	Economy	13400.00
0005434081553	12768	Economy	13400.00
0005434066904	12768	Economy	13400.00
0005434066760	12768	Economy	13400.00
0005434066527	12768	Economy	13400.00
0005434066705	12768	Economy	13400.00
0005434066694	12768	Economy	13400.00
0005434026679	12768	Economy	13400.00
0005434066539	12768	Economy	13400.00
0005434066638	12768	Economy	13400.00
0005434066802	12768	Economy	13400.00
0005434026680	12768	Economy	13400.00
0005433989717	12768	Economy	13400.00
0005434081632	12768	Economy	13400.00
0005434066669	12768	Economy	13400.00
0005434081518	12768	Economy	13400.00
0005434066639	12768	Economy	13400.00
0005434066547	12768	Economy	13400.00
0005434066594	12768	Economy	13400.00
0005433989708	12768	Economy	13400.00
0005434066482	12768	Economy	13400.00
0005434066567	12768	Economy	13400.00
0005434066481	12768	Economy	13400.00
0005434066462	12768	Economy	13400.00
0005434066603	12768	Economy	13400.00
0005434067215	30668	Business	40300.00
0005434067174	30668	Business	40300.00
0005434067225	30668	Business	40300.00
0005434081759	30668	Business	40300.00
0005434067194	30668	Business	40300.00
0005433989748	30668	Business	40300.00
0005434081781	30668	Business	40300.00
0005434081774	30668	Business	40300.00
0005433989744	30668	Business	40300.00
0005434067230	30668	Business	40300.00
0005433989745	30668	Business	40300.00
0005434067200	30668	Business	40300.00
0005434081786	30668	Economy	13400.00
0005434067216	30668	Economy	13400.00
0005434067218	30668	Economy	13400.00
0005434081777	30668	Economy	13400.00
0005434067212	30668	Economy	13400.00
0005434081773	30668	Economy	13400.00
0005434081778	30668	Economy	13400.00
0005434067208	30668	Economy	13400.00
0005434067211	30668	Economy	13400.00
0005434067213	30668	Economy	13400.00
0005434067228	30668	Economy	13400.00
0005434067227	30668	Economy	13400.00
0005434067199	30668	Economy	13400.00
0005434067204	30668	Economy	13400.00
0005434081769	30668	Economy	13400.00
0005434067179	30668	Economy	13400.00
0005434067226	30668	Economy	13400.00
0005434067206	30668	Economy	13400.00
0005434067168	30668	Economy	13400.00
0005434067203	30668	Economy	13400.00
0005432150153	30668	Economy	13400.00
0005434067178	30668	Economy	13400.00
0005434067201	30668	Economy	13400.00
0005434067185	30668	Economy	13400.00
0005434067170	30668	Economy	13400.00
0005434081768	30668	Economy	13400.00
0005434067177	30668	Economy	13400.00
0005434081760	30668	Economy	13400.00
0005434081776	30668	Economy	13400.00
0005434067237	30668	Economy	13400.00
0005434067197	30668	Economy	13400.00
0005434067173	30668	Economy	13400.00
0005434081771	30668	Economy	13400.00
0005434081763	30668	Economy	13400.00
0005432150158	30668	Economy	13400.00
0005432186851	30668	Economy	13400.00
0005434081788	30668	Economy	13400.00
0005434067176	30668	Economy	13400.00
0005434067222	30668	Economy	13400.00
0005434081783	30668	Economy	13400.00
0005432433598	30668	Economy	14800.00
0005434067223	30668	Economy	14800.00
0005434067183	30668	Economy	14800.00
0005434067229	30668	Economy	14800.00
0005434067192	30668	Economy	13400.00
0005434067232	30668	Economy	14800.00
0005432150151	30668	Economy	13400.00
0005434067180	30668	Economy	13400.00
0005432433627	30668	Economy	13400.00
0005434067195	30668	Economy	13400.00
0005434067217	30668	Economy	13400.00
0005432186849	30668	Economy	13400.00
0005434067214	30668	Economy	13400.00
0005433989746	30668	Economy	13400.00
0005434081780	30668	Economy	13400.00
0005434081765	30668	Economy	13400.00
0005432433603	30668	Economy	13400.00
0005434067220	30668	Economy	13400.00
0005434067172	30668	Economy	13400.00
0005432150152	30668	Economy	13400.00
0005434067182	30668	Economy	13400.00
0005432150157	30668	Economy	13400.00
0005434081779	30668	Economy	13400.00
0005434067235	30668	Economy	13400.00
0005434067209	30668	Economy	13400.00
0005434081785	30668	Economy	13400.00
0005434067167	30668	Economy	13400.00
0005434067190	30668	Economy	13400.00
0005434067236	30668	Economy	13400.00
0005434067233	30668	Economy	13400.00
0005432433609	30668	Economy	13400.00
0005434067169	30668	Economy	13400.00
0005434067184	30668	Economy	13400.00
0005434067171	30668	Economy	13400.00
0005434081761	30668	Economy	13400.00
0005434067198	30668	Economy	13400.00
0005434067186	30668	Economy	13400.00
0005434067224	30668	Economy	13400.00
0005434067188	30668	Economy	13400.00
0005434081784	30668	Economy	13400.00
0005434081782	30668	Economy	13400.00
0005434081787	30668	Economy	13400.00
0005432150150	30668	Economy	13400.00
0005434081766	30668	Economy	13400.00
0005434067191	30668	Economy	13400.00
0005434067207	30668	Economy	13400.00
0005432433604	30668	Economy	13400.00
0005434081762	30668	Economy	13400.00
0005434067210	30668	Economy	13400.00
0005434067205	30668	Economy	13400.00
0005432150154	30668	Economy	13400.00
0005434081775	30668	Economy	13400.00
0005434067221	30668	Economy	13400.00
0005434081764	30668	Economy	13400.00
0005434067187	30668	Economy	13400.00
0005434067193	30668	Economy	13400.00
0005433989747	30668	Economy	13400.00
0005434067231	30668	Economy	13400.00
0005434067189	30668	Economy	13400.00
0005432433610	30668	Economy	13400.00
0005432186850	30668	Economy	13400.00
0005434067238	30668	Economy	13400.00
0005434067181	30668	Economy	13400.00
0005434081772	30668	Economy	13400.00
0005434067234	30668	Economy	13400.00
0005434067196	30668	Economy	13400.00
0005434081767	30668	Economy	13400.00
0005432186848	30668	Economy	13400.00
0005434067202	30668	Economy	13400.00
0005434067219	30668	Economy	13400.00
0005432150155	30668	Economy	13400.00
0005433989749	30668	Economy	13400.00
0005432150156	30668	Economy	13400.00
0005434081770	30668	Economy	13400.00
0005434081789	30668	Economy	13400.00
0005434067175	30668	Economy	13400.00
0005433687701	9042	Economy	19300.00
0005433685517	9042	Economy	19300.00
0005433685519	9042	Economy	17600.00
0005433686627	9042	Economy	17600.00
0005433685520	9042	Economy	17600.00
0005433687700	9042	Economy	17600.00
0005433685515	9042	Economy	17600.00
0005433686626	9042	Economy	17600.00
0005433687698	9042	Economy	17600.00
0005433687702	9042	Economy	17600.00
0005433685518	9042	Economy	17600.00
0005433687703	9042	Economy	17600.00
0005433686630	9042	Economy	17600.00
0005433687699	9042	Economy	17600.00
0005433687697	9042	Economy	17600.00
0005433685516	9042	Economy	17600.00
0005433686625	9042	Economy	17600.00
0005433686629	9042	Economy	17600.00
0005433686628	9042	Economy	17600.00
0005435765948	5527	Business	35300.00
0005435765966	5527	Business	35300.00
0005435765941	5527	Business	35300.00
0005435722044	5527	Business	35300.00
0005435461887	5527	Business	35300.00
0005435765998	5527	Business	35300.00
0005435462002	5527	Business	35300.00
0005435765975	5527	Business	35300.00
0005435765955	5527	Business	35300.00
0005433529261	5527	Business	35300.00
0005435765960	5527	Business	35300.00
0005433527252	5527	Business	35300.00
0005432140410	5527	Business	35300.00
0005435461861	5527	Business	35300.00
0005435765967	5527	Business	35300.00
0005434264731	5527	Business	35300.00
0005435765940	5527	Business	35300.00
0005435765997	5527	Business	35300.00
0005435765969	5527	Economy	12900.00
0005435765953	5527	Economy	11800.00
0005435765956	5527	Economy	11800.00
0005435766003	5527	Economy	11800.00
0005435765972	5527	Economy	11800.00
0005435765943	5527	Economy	11800.00
0005432535768	5527	Economy	11800.00
0005435735117	5527	Economy	11800.00
0005434264698	5527	Economy	11800.00
0005432140409	5527	Economy	11800.00
0005435765976	5527	Economy	11800.00
0005435723036	5527	Economy	11800.00
0005433529264	5527	Economy	11800.00
0005432140413	5527	Economy	11800.00
0005435462081	5527	Economy	11800.00
0005435765989	5527	Economy	11800.00
0005434264710	5527	Economy	11800.00
0005435617167	5527	Economy	11800.00
0005435765994	5527	Economy	11800.00
0005434264834	5527	Economy	11800.00
0005435765985	5527	Economy	11800.00
0005435765987	5527	Economy	11800.00
0005435765963	5527	Economy	11800.00
0005435766001	5527	Economy	11800.00
0005432140415	5527	Economy	11800.00
0005435765978	5527	Economy	11800.00
0005434264871	5527	Economy	11800.00
0005435765999	5527	Economy	11800.00
0005435765993	5527	Economy	11800.00
0005434264729	5527	Economy	11800.00
0005435765958	5527	Economy	11800.00
0005435765996	5527	Economy	11800.00
0005432535769	5527	Economy	11800.00
0005432535745	5527	Economy	11800.00
0005435725573	5527	Economy	11800.00
0005434264821	5527	Economy	11800.00
0005435765974	5527	Economy	11800.00
0005435765990	5527	Economy	11800.00
0005435725577	5527	Economy	11800.00
0005435725575	5527	Economy	11800.00
0005434264721	5527	Economy	11800.00
0005434264783	5527	Economy	11800.00
0005435725576	5527	Economy	11800.00
0005435765947	5527	Economy	11800.00
0005435617166	5527	Economy	11800.00
0005435617168	5527	Economy	11800.00
0005435723035	5527	Economy	11800.00
0005433527253	5527	Economy	11800.00
0005434264784	5527	Economy	11800.00
0005435735118	5527	Economy	11800.00
0005434264801	5527	Economy	11800.00
0005435461889	5527	Economy	11800.00
0005435765984	5527	Economy	11800.00
0005434831071	5527	Economy	11800.00
0005435765944	5527	Economy	11800.00
0005432140411	5527	Economy	11800.00
0005435765979	5527	Economy	11800.00
0005435462030	5527	Economy	11800.00
0005435461883	5527	Economy	11800.00
0005435765992	5527	Economy	11800.00
0005435765991	5527	Economy	11800.00
0005435766007	5527	Economy	11800.00
0005435765986	5527	Economy	11800.00
0005435765980	5527	Economy	11800.00
0005435765970	5527	Economy	11800.00
0005435722045	5527	Economy	12900.00
0005435725574	5527	Economy	12900.00
0005435766006	5527	Economy	12900.00
0005434264730	5527	Economy	12900.00
0005435765973	5527	Economy	11800.00
0005435765965	5527	Economy	11800.00
0005435461975	5527	Economy	11800.00
0005435461936	5527	Economy	11800.00
0005435765961	5527	Economy	11800.00
0005435765949	5527	Economy	11800.00
0005435461812	5527	Economy	11800.00
0005435462009	5527	Economy	11800.00
0005435461873	5527	Economy	11800.00
0005434264776	5527	Economy	11800.00
0005435766002	5527	Economy	11800.00
0005434264745	5527	Economy	11800.00
0005433529263	5527	Economy	11800.00
0005435765959	5527	Economy	11800.00
0005435765982	5527	Economy	11800.00
0005435765942	5527	Economy	11800.00
0005435765981	5527	Economy	11800.00
0005435766004	5527	Economy	11800.00
0005435766000	5527	Economy	11800.00
0005435765954	5527	Economy	11800.00
0005435765945	5527	Economy	11800.00
0005435461972	5527	Economy	11800.00
0005435461833	5527	Economy	11800.00
0005435461860	5527	Economy	11800.00
0005435765964	5527	Economy	11800.00
0005434264785	5527	Economy	11800.00
0005435462008	5527	Economy	11800.00
0005435461969	5527	Economy	11800.00
0005435765962	5527	Economy	11800.00
0005435765988	5527	Economy	11800.00
0005434264833	5527	Economy	11800.00
0005435766005	5527	Economy	11800.00
0005435765946	5527	Economy	11800.00
0005434264838	5527	Economy	11800.00
0005433527251	5527	Economy	11800.00
0005435765995	5527	Economy	11800.00
0005435765952	5527	Economy	11800.00
0005435461966	5527	Economy	11800.00
0005435765971	5527	Economy	11800.00
0005433529262	5527	Economy	11800.00
0005435765951	5527	Economy	11800.00
0005432140414	5527	Economy	11800.00
0005434264775	5527	Economy	11800.00
0005432140412	5527	Economy	11800.00
0005434264802	5527	Economy	11800.00
0005434264865	5527	Economy	11800.00
0005435765977	5527	Economy	11800.00
0005435765957	5527	Economy	11800.00
0005435765968	5527	Economy	11800.00
0005435735119	5527	Economy	11800.00
0005435765950	5527	Economy	11800.00
0005435765983	5527	Economy	11800.00
0005435765346	13488	Business	35300.00
0005435462284	13488	Business	35300.00
0005435765584	13488	Business	35300.00
0005435765583	13488	Business	35300.00
0005434265033	13488	Business	35300.00
0005435462281	13488	Business	35300.00
0005435765134	13488	Business	35300.00
0005435735087	13488	Business	35300.00
0005435462279	13488	Business	35300.00
0005435765337	13488	Business	35300.00
0005435765262	13488	Business	35300.00
0005435723021	13488	Business	35300.00
0005435765570	13488	Business	35300.00
0005435462294	13488	Business	35300.00
0005432194491	13488	Business	35300.00
0005434265034	13488	Business	35300.00
0005434265022	13488	Business	35300.00
0005434265042	13488	Business	35300.00
0005434265020	13488	Business	35300.00
0005435725540	13488	Business	35300.00
0005434831131	13488	Business	35300.00
0005434831130	13488	Business	35300.00
0005435765501	13488	Business	35300.00
0005434265032	13488	Business	35300.00
0005435722017	13488	Business	35300.00
0005435462275	13488	Business	35300.00
0005435765119	13488	Economy	12900.00
0005435765565	13488	Economy	12900.00
0005432194492	13488	Economy	12900.00
0005432194493	13488	Economy	11800.00
0005435765434	13488	Economy	12900.00
0005435765532	13488	Economy	11800.00
0005435765280	13488	Economy	11800.00
0005435462296	13488	Economy	11800.00
0005434265037	13488	Economy	11800.00
0005434265026	13488	Economy	11800.00
0005435765477	13488	Economy	11800.00
0005434831132	13488	Economy	11800.00
0005435462265	13488	Economy	11800.00
0005435765528	13488	Economy	11800.00
0005435765352	13488	Economy	11800.00
0005435462269	13488	Economy	11800.00
0005432194494	13488	Economy	11800.00
0005435462264	13488	Economy	11800.00
0005435765207	13488	Economy	11800.00
0005435462290	13488	Economy	11800.00
0005435043282	13488	Economy	11800.00
0005435462263	13488	Economy	11800.00
0005435462291	13488	Economy	11800.00
0005435722020	13488	Economy	11800.00
0005435765325	13488	Economy	11800.00
0005435765235	13488	Economy	11800.00
0005435765326	13488	Economy	11800.00
0005435765186	13488	Economy	11800.00
0005435462289	13488	Economy	11800.00
0005434265031	13488	Economy	11800.00
0005435462293	13488	Economy	11800.00
0005435765360	13488	Economy	11800.00
0005435462285	13488	Economy	11800.00
0005435765351	13488	Economy	11800.00
0005435462261	13488	Economy	11800.00
0005435765586	13488	Economy	11800.00
0005435765463	13488	Economy	11800.00
0005435720121	13488	Economy	11800.00
0005435765135	13488	Economy	11800.00
0005435462295	13488	Economy	11800.00
0005435765400	13488	Economy	11800.00
0005434265030	13488	Economy	11800.00
0005435765368	13488	Economy	11800.00
0005435723019	13488	Economy	11800.00
0005435765536	13488	Economy	11800.00
0005435765500	13488	Economy	11800.00
0005432535815	13488	Economy	11800.00
0005435462259	13488	Economy	11800.00
0005434265025	13488	Economy	11800.00
0005435462288	13488	Economy	11800.00
0005435462273	13488	Economy	11800.00
0005435462287	13488	Economy	11800.00
0005434265029	13488	Economy	11800.00
0005434265040	13488	Economy	11800.00
0005435765347	13488	Economy	11800.00
0005435722016	13488	Economy	11800.00
0005435722018	13488	Economy	11800.00
0005435765641	13488	Economy	11800.00
0005435765656	13488	Economy	11800.00
0005435765272	13488	Economy	11800.00
0005435735080	13488	Economy	11800.00
0005435765499	13488	Economy	11800.00
0005435765299	13488	Economy	11800.00
0005435462270	13488	Economy	11800.00
0005435765461	13488	Economy	11800.00
0005434265043	13488	Economy	11800.00
0005435735072	13488	Economy	11800.00
0005435462260	13488	Economy	11800.00
0005434265035	13488	Economy	11800.00
0005434265039	13488	Economy	11800.00
0005435765243	13488	Economy	11800.00
0005435765614	13488	Economy	11800.00
0005435765640	13488	Economy	11800.00
0005435765473	13488	Economy	11800.00
0005435765228	13488	Economy	11800.00
0005435765264	13488	Economy	11800.00
0005434265038	13488	Economy	11800.00
0005435723018	13488	Economy	11800.00
0005435765535	13488	Economy	11800.00
0005435765464	13488	Economy	11800.00
0005435765176	13488	Economy	11800.00
0005435765137	13488	Economy	11800.00
0005434265044	13488	Economy	11800.00
0005435765219	13488	Economy	11800.00
0005435725539	13488	Economy	12900.00
0005434265036	13488	Economy	11800.00
0005435765390	13488	Economy	11800.00
0005435735070	13488	Economy	11800.00
0005435765393	13488	Economy	11800.00
0005435765359	13488	Economy	11800.00
0005435722030	13488	Economy	11800.00
0005434265019	13488	Economy	11800.00
0005435723017	13488	Economy	11800.00
0005435765327	13488	Economy	11800.00
0005434265024	13488	Economy	11800.00
0005435765361	13488	Economy	11800.00
0005435462262	13488	Economy	11800.00
0005435765478	13488	Economy	11800.00
0005432535812	13488	Economy	11800.00
0005434265021	13488	Economy	11800.00
0005435462292	13488	Economy	11800.00
0005435725547	13488	Economy	11800.00
0005435765208	13488	Economy	11800.00
0005434831129	13488	Economy	11800.00
0005435765328	13488	Economy	11800.00
0005435765112	13488	Economy	11800.00
0005435462280	13488	Economy	11800.00
0005435765277	13488	Economy	11800.00
0005435462274	13488	Economy	11800.00
0005435462282	13488	Economy	11800.00
0005435765392	13488	Economy	11800.00
0005435462271	13488	Economy	11800.00
0005435765187	13488	Economy	11800.00
0005435722019	13488	Economy	11800.00
0005435765136	13488	Economy	11800.00
0005435765290	13488	Economy	11800.00
0005434831133	13488	Economy	11800.00
0005435462277	13488	Economy	11800.00
0005435765177	13488	Economy	11800.00
0005435765234	13488	Economy	11800.00
0005435765113	13488	Economy	11800.00
0005435462278	13488	Economy	11800.00
0005432535816	13488	Economy	11800.00
0005435765233	13488	Economy	11800.00
0005435462267	13488	Economy	11800.00
0005434265023	13488	Economy	11800.00
0005435735073	13488	Economy	11800.00
0005435462266	13488	Economy	11800.00
0005434265028	13488	Economy	11800.00
0005435725541	13488	Economy	11800.00
0005435765574	13488	Economy	11800.00
0005435765564	13488	Economy	11800.00
0005435765114	13488	Economy	11800.00
0005435462272	13488	Economy	11800.00
0005435765369	13488	Economy	11800.00
0005435462276	13488	Economy	11800.00
0005435765212	13488	Economy	11800.00
0005435765242	13488	Economy	11800.00
0005435765345	13488	Economy	11800.00
0005435462286	13488	Economy	11800.00
0005435765553	13488	Economy	11800.00
0005432535813	13488	Economy	11800.00
0005435765218	13488	Economy	11800.00
0005435462283	13488	Economy	11800.00
0005434265027	13488	Economy	11800.00
0005435043283	13488	Economy	11800.00
0005435722021	13488	Economy	11800.00
0005435765389	13488	Economy	11800.00
0005432535814	13488	Economy	11800.00
0005435723022	13488	Economy	11800.00
0005435765428	13488	Economy	11800.00
0005435462268	13488	Economy	11800.00
0005435735079	13488	Economy	11800.00
0005435765523	13488	Economy	11800.00
0005434265041	13488	Economy	11800.00
0005435765195	13488	Economy	11800.00
0005435765109	13488	Economy	11800.00
0005435765367	13488	Economy	11800.00
0005434514956	18688	Economy	3300.00
0005434513565	18688	Economy	3300.00
0005434513568	18688	Economy	3300.00
0005434604860	18688	Economy	3300.00
0005434513566	18688	Economy	3300.00
0005434514954	18688	Economy	3300.00
0005434604848	18688	Economy	3300.00
0005434513567	18688	Economy	3300.00
0005434514955	18688	Economy	3300.00
0005434514932	19118	Economy	3300.00
0005434514933	19118	Economy	3300.00
0005434514930	19118	Economy	3300.00
0005434514948	19118	Economy	3300.00
0005434514942	19118	Economy	3300.00
0005435846204	4131	Business	88300.00
0005432649382	4131	Business	88300.00
0005435844266	4131	Business	88300.00
0005435844270	4131	Business	88300.00
0005432632707	4131	Business	88300.00
0005435846198	4131	Business	88300.00
0005435844279	4131	Economy	29400.00
0005432649376	4131	Economy	29400.00
0005432649375	4131	Economy	29400.00
0005432649377	4131	Economy	29400.00
0005432649378	4131	Economy	32400.00
0005432632718	4131	Economy	32400.00
0005435844265	4131	Economy	29400.00
0005432632709	4131	Economy	29400.00
0005435846201	4131	Economy	29400.00
0005432632708	4131	Economy	29400.00
0005432632717	4131	Economy	29400.00
0005432649373	4131	Economy	29400.00
0005435846205	4131	Economy	29400.00
0005432632706	4131	Economy	29400.00
0005435844280	4131	Economy	29400.00
0005435846207	4131	Economy	29400.00
0005435846189	4131	Economy	29400.00
0005432632711	4131	Economy	29400.00
0005432632715	4131	Economy	29400.00
0005435846199	4131	Economy	29400.00
0005432649381	4131	Economy	29400.00
0005435844262	4131	Economy	29400.00
0005432649374	4131	Economy	29400.00
0005432649370	4131	Economy	29400.00
0005432649380	4131	Economy	29400.00
0005435844269	4131	Economy	29400.00
0005435846206	4131	Economy	29400.00
0005432632716	4131	Economy	29400.00
0005432649372	4131	Economy	29400.00
0005435844264	4131	Economy	29400.00
0005432632713	4131	Economy	29400.00
0005432649379	4131	Economy	29400.00
0005432632710	4131	Economy	29400.00
0005432632719	4131	Economy	29400.00
0005432649371	4131	Economy	29400.00
0005432632712	4131	Economy	29400.00
0005432632714	4131	Economy	29400.00
0005433008084	1851	Business	48700.00
0005433007984	1851	Business	48700.00
0005433008011	1851	Business	48700.00
0005433008127	1851	Business	48700.00
0005433284904	1851	Business	48700.00
0005433284821	1851	Business	48700.00
0005433007993	1851	Business	48700.00
0005433008180	1851	Business	48700.00
0005433285029	1851	Business	48700.00
0005433284911	1851	Business	48700.00
0005433810527	1851	Business	48700.00
0005433008191	1851	Economy	16200.00
0005433008064	1851	Economy	16200.00
0005433008067	1851	Economy	16200.00
0005433008082	1851	Economy	16200.00
0005433284905	1851	Economy	16200.00
0005433810528	1851	Economy	16200.00
0005433008010	1851	Economy	16200.00
0005433007996	1851	Economy	17900.00
0005433007955	1851	Economy	17900.00
0005433008012	1851	Economy	17900.00
0005433008083	1851	Economy	17900.00
0005433284935	1851	Economy	16200.00
0005433008058	1851	Economy	16200.00
0005433008007	1851	Economy	16200.00
0005433284928	1851	Economy	16200.00
0005433284912	1851	Economy	16200.00
0005433007942	1851	Economy	16200.00
0005433284822	1851	Economy	16200.00
0005433007941	1851	Economy	16200.00
0005433007926	1851	Economy	16200.00
0005433008179	1851	Economy	16200.00
0005433810526	1851	Economy	16200.00
0005433284973	1851	Economy	16200.00
0005433284992	1851	Economy	16200.00
0005433284913	1851	Economy	16200.00
0005433008093	1851	Economy	16200.00
0005433007903	1851	Economy	16200.00
0005433284888	1851	Economy	16200.00
0005433284956	1851	Economy	16200.00
0005433008059	1851	Economy	16200.00
0005433008026	1851	Economy	16200.00
0005433008057	1851	Economy	16200.00
0005433008254	1851	Economy	16200.00
0005433008190	1851	Economy	16200.00
0005433008020	1851	Economy	16200.00
0005433008075	1851	Economy	16200.00
0005433008189	1851	Economy	16200.00
0005433008167	1851	Economy	16200.00
0005433008040	1851	Economy	16200.00
0005433284954	1851	Economy	16200.00
0005433284991	1851	Economy	16200.00
0005433007922	1851	Economy	16200.00
0005433007956	1851	Economy	16200.00
0005433008066	1851	Economy	16200.00
0005433284777	1851	Economy	16200.00
0005433008090	1851	Economy	16200.00
0005433007902	1851	Economy	16200.00
0005432295868	1851	Economy	16200.00
0005433008137	1851	Economy	16200.00
0005433008065	1851	Economy	16200.00
0005433008105	1851	Economy	16200.00
0005433008222	1851	Economy	16200.00
0005433008051	1851	Economy	16200.00
0005433810524	1851	Economy	16200.00
0005433810525	1851	Economy	16200.00
0005433008052	1851	Economy	16200.00
0005433008086	1851	Economy	16200.00
0005433007957	1851	Economy	16200.00
0005433008177	1851	Economy	16200.00
0005433008070	1851	Economy	16200.00
0005433007927	1851	Economy	16200.00
0005432295869	1851	Economy	16200.00
0005433284955	1851	Economy	16200.00
0005433008406	22580	Business	48700.00
0005433008398	22580	Business	48700.00
0005433008421	22580	Business	48700.00
0005433285149	22580	Business	48700.00
0005433008397	22580	Business	48700.00
0005433008412	22580	Business	48700.00
0005433285145	22580	Business	48700.00
0005433008389	22580	Business	48700.00
0005433008401	22580	Economy	16200.00
0005433285147	22580	Economy	16200.00
0005433008410	22580	Economy	16200.00
0005433008409	22580	Economy	16200.00
0005433008383	22580	Economy	16200.00
0005433008422	22580	Economy	16200.00
0005433008379	22580	Economy	16200.00
0005433285157	22580	Economy	17900.00
0005433008403	22580	Economy	17900.00
0005433008411	22580	Economy	17900.00
0005433008391	22580	Economy	17900.00
0005433008382	22580	Economy	17900.00
0005433285146	22580	Economy	16200.00
0005433008394	22580	Economy	16200.00
0005433285140	22580	Economy	16200.00
0005433285142	22580	Economy	16200.00
0005433008402	22580	Economy	16200.00
0005433285148	22580	Economy	16200.00
0005433285138	22580	Economy	16200.00
0005433008396	22580	Economy	16200.00
0005433008399	22580	Economy	16200.00
0005433285144	22580	Economy	16200.00
0005433285161	22580	Economy	16200.00
0005433285158	22580	Economy	16200.00
0005433008395	22580	Economy	16200.00
0005433285152	22580	Economy	16200.00
0005433285137	22580	Economy	16200.00
0005433285159	22580	Economy	16200.00
0005433810490	22580	Economy	16200.00
0005433285150	22580	Economy	16200.00
0005433285164	22580	Economy	16200.00
0005433285163	22580	Economy	16200.00
0005433008418	22580	Economy	16200.00
0005433008408	22580	Economy	16200.00
0005433285154	22580	Economy	16200.00
0005433285151	22580	Economy	16200.00
0005433008414	22580	Economy	16200.00
0005433008388	22580	Economy	16200.00
0005433008390	22580	Economy	16200.00
0005433008423	22580	Economy	16200.00
0005433008386	22580	Economy	16200.00
0005433008387	22580	Economy	16200.00
0005433285139	22580	Economy	16200.00
0005433008417	22580	Economy	16200.00
0005433285165	22580	Economy	16200.00
0005433285160	22580	Economy	16200.00
0005433285162	22580	Economy	16200.00
0005433285143	22580	Economy	16200.00
0005433285153	22580	Economy	16200.00
0005433008400	22580	Economy	16200.00
0005433008380	22580	Economy	16200.00
0005433008420	22580	Economy	16200.00
0005433008384	22580	Economy	16200.00
0005433285135	22580	Economy	16200.00
0005433008424	22580	Economy	16200.00
0005433285155	22580	Economy	16200.00
0005433008404	22580	Economy	16200.00
0005433008416	22580	Economy	16200.00
0005433008415	22580	Economy	16200.00
0005433285136	22580	Economy	16200.00
0005433008413	22580	Economy	16200.00
0005433008385	22580	Economy	16200.00
0005433008407	22580	Economy	16200.00
0005433285156	22580	Economy	16200.00
0005433008381	22580	Economy	16200.00
0005433008393	22580	Economy	16200.00
0005433008419	22580	Economy	16200.00
0005433008392	22580	Economy	16200.00
0005433285141	22580	Economy	16200.00
0005433008405	22580	Economy	16200.00
0005433285166	22580	Economy	16200.00
0005432755030	12284	Business	83800.00
0005432751473	12284	Economy	27900.00
0005432751480	12284	Economy	27900.00
0005432755016	12284	Economy	27900.00
0005432755020	12284	Economy	27900.00
0005432751470	12284	Economy	27900.00
0005432751479	12284	Economy	27900.00
0005432751493	12284	Economy	27900.00
0005432751471	12284	Economy	27900.00
0005432751476	12284	Economy	27900.00
0005432755017	12284	Economy	27900.00
0005432751477	12284	Economy	27900.00
0005432751475	12284	Economy	27900.00
0005432755025	12284	Economy	27900.00
0005432755023	12284	Economy	27900.00
0005432751482	12284	Economy	27900.00
0005432751472	12284	Economy	27900.00
0005432751474	12284	Economy	27900.00
0005432755024	12284	Economy	27900.00
0005433846480	5552	Business	99800.00
0005435282094	5552	Business	99800.00
0005432081482	5552	Business	99800.00
0005435282074	5552	Business	99800.00
0005435282204	5552	Business	99800.00
0005433846471	5552	Business	99800.00
0005433846479	5552	Business	99800.00
0005433846453	5552	Business	99800.00
0005432081485	5552	Business	99800.00
0005433846498	5552	Business	99800.00
0005435282237	5552	Business	99800.00
0005433846456	5552	Business	99800.00
0005433846466	5552	Business	99800.00
0005433846470	5552	Business	99800.00
0005434173463	5552	Business	99800.00
0005435282153	5552	Business	99800.00
0005435282164	5552	Business	99800.00
0005433846486	5552	Economy	33300.00
0005433846491	5552	Economy	33300.00
0005432081480	5552	Economy	33300.00
0005433846474	5552	Economy	33300.00
0005433846447	5552	Economy	33300.00
0005433846494	5552	Economy	33300.00
0005435282201	5552	Economy	33300.00
0005433846487	5552	Economy	33300.00
0005435282168	5552	Economy	33300.00
0005433846476	5552	Economy	33300.00
0005435282233	5552	Economy	33300.00
0005433846444	5552	Economy	33300.00
0005433846496	5552	Economy	36600.00
0005433846451	5552	Economy	36600.00
0005433846488	5552	Economy	36600.00
0005432081486	5552	Economy	33300.00
0005433846477	5552	Economy	33300.00
0005433846450	5552	Economy	33300.00
0005435282173	5552	Economy	33300.00
0005432081484	5552	Economy	33300.00
0005433846472	5552	Economy	33300.00
0005435282169	5552	Economy	33300.00
0005434173455	5552	Economy	33300.00
0005432081483	5552	Economy	33300.00
0005435282174	5552	Economy	33300.00
0005433846440	5552	Economy	33300.00
0005435282161	5552	Economy	33300.00
0005433846445	5552	Economy	33300.00
0005433846443	5552	Economy	33300.00
0005433846460	5552	Economy	33300.00
0005433815359	5552	Economy	33300.00
0005433815361	5552	Economy	33300.00
0005433846481	5552	Economy	33300.00
0005433846441	5552	Economy	33300.00
0005433846495	5552	Economy	33300.00
0005433846467	5552	Economy	33300.00
0005433846482	5552	Economy	33300.00
0005433846489	5552	Economy	33300.00
0005433846464	5552	Economy	33300.00
0005435282236	5552	Economy	33300.00
0005435282095	5552	Economy	33300.00
0005433815360	5552	Economy	33300.00
0005433846461	5552	Economy	33300.00
0005435282186	5552	Economy	33300.00
0005433846457	5552	Economy	33300.00
0005433846465	5552	Economy	33300.00
0005434173464	5552	Economy	33300.00
0005435282187	5552	Economy	33300.00
0005433815362	5552	Economy	33300.00
0005433846449	5552	Economy	33300.00
0005433846462	5552	Economy	33300.00
0005433846458	5552	Economy	33300.00
0005433846493	5552	Economy	33300.00
0005435282117	5552	Economy	33300.00
0005435282270	5552	Economy	33300.00
0005433846446	5552	Economy	33300.00
0005433846455	5552	Economy	33300.00
0005433846442	5552	Economy	33300.00
0005433846459	5552	Economy	33300.00
0005435282125	5552	Economy	33300.00
0005433846454	5552	Economy	33300.00
0005435282089	5552	Economy	33300.00
0005433846469	5552	Economy	33300.00
0005433815363	5552	Economy	33300.00
0005433846478	5552	Economy	33300.00
0005432081481	5552	Economy	33300.00
0005433846492	5552	Economy	33300.00
0005433846490	5552	Economy	33300.00
0005433846475	5552	Economy	33300.00
0005433846483	5552	Economy	33300.00
0005433846473	5552	Economy	33300.00
0005434173479	5552	Economy	33300.00
0005435282269	5552	Economy	33300.00
0005435282108	5552	Economy	33300.00
0005435282073	5552	Economy	33300.00
0005433846497	5552	Economy	33300.00
0005433846484	5552	Economy	33300.00
0005435282180	5552	Economy	33300.00
0005433846452	5552	Economy	33300.00
0005433846485	5552	Economy	33300.00
0005435282126	5552	Economy	33300.00
0005433846463	5552	Economy	33300.00
0005433846468	5552	Economy	33300.00
0005435282232	5552	Economy	33300.00
0005435282205	5552	Economy	33300.00
0005433846448	5552	Economy	33300.00
0005434173462	5552	Economy	33300.00
0005433846499	5552	Economy	33300.00
0005434173503	13847	Business	99800.00
0005433845986	13847	Business	99800.00
0005432003689	13847	Business	99800.00
0005435282398	13847	Business	99800.00
0005435282406	13847	Business	99800.00
0005433846098	13847	Business	99800.00
0005435282416	13847	Business	99800.00
0005433846201	13847	Business	99800.00
0005435282414	13847	Business	99800.00
0005433845846	13847	Business	99800.00
0005433846073	13847	Business	99800.00
0005433845984	13847	Business	99800.00
0005435282417	13847	Business	99800.00
0005433845765	13847	Business	99800.00
0005433846031	13847	Business	99800.00
0005433845881	13847	Business	99800.00
0005433845797	13847	Business	99800.00
0005435282402	13847	Economy	33300.00
0005435282410	13847	Economy	33300.00
0005435282399	13847	Economy	33300.00
0005433846093	13847	Economy	33300.00
0005433846158	13847	Economy	33300.00
0005433845770	13847	Economy	33300.00
0005434173501	13847	Economy	33300.00
0005435282397	13847	Economy	33300.00
0005435282409	13847	Economy	33300.00
0005433846029	13847	Economy	33300.00
0005435282412	13847	Economy	33300.00
0005435282407	13847	Economy	36600.00
0005433845926	13847	Economy	33300.00
0005435282420	13847	Economy	36600.00
0005435282415	13847	Economy	36600.00
0005433846001	13847	Economy	36600.00
0005433845847	13847	Economy	33300.00
0005433845967	13847	Economy	33300.00
0005435282393	13847	Economy	33300.00
0005435282413	13847	Economy	33300.00
0005435282419	13847	Economy	33300.00
0005433845919	13847	Economy	33300.00
0005435282394	13847	Economy	33300.00
0005432003688	13847	Economy	33300.00
0005433845796	13847	Economy	33300.00
0005433845985	13847	Economy	33300.00
0005433846227	13847	Economy	33300.00
0005435282404	13847	Economy	33300.00
0005433846228	13847	Economy	33300.00
0005433846193	13847	Economy	33300.00
0005433845935	13847	Economy	33300.00
0005434173505	13847	Economy	33300.00
0005435282395	13847	Economy	33300.00
0005433846018	13847	Economy	33300.00
0005433846094	13847	Economy	33300.00
0005435282400	13847	Economy	33300.00
0005435282411	13847	Economy	33300.00
0005435282401	13847	Economy	33300.00
0005433846095	13847	Economy	33300.00
0005433845943	13847	Economy	33300.00
0005433846202	13847	Economy	33300.00
0005433846014	13847	Economy	33300.00
0005433846017	13847	Economy	33300.00
0005435282405	13847	Economy	33300.00
0005433845983	13847	Economy	33300.00
0005433845999	13847	Economy	33300.00
0005434173502	13847	Economy	33300.00
0005432003687	13847	Economy	33300.00
0005433846106	13847	Economy	33300.00
0005433845998	13847	Economy	33300.00
0005433846066	13847	Economy	33300.00
0005433846084	13847	Economy	33300.00
0005433846003	13847	Economy	33300.00
0005433845860	13847	Economy	33300.00
0005433815326	13847	Economy	33300.00
0005434173504	13847	Economy	33300.00
0005435282403	13847	Economy	33300.00
0005433845890	13847	Economy	33300.00
0005435282418	13847	Economy	33300.00
0005433845793	13847	Economy	33300.00
0005433846032	13847	Economy	33300.00
0005433845832	13847	Economy	33300.00
0005433845801	13847	Economy	33300.00
0005433845946	13847	Economy	33300.00
0005433845798	13847	Economy	33300.00
0005433845915	13847	Economy	33300.00
0005435282396	13847	Economy	33300.00
0005433846150	13847	Economy	33300.00
0005435282408	13847	Economy	33300.00
0005433846002	13847	Economy	33300.00
0005433845950	13847	Economy	33300.00
0005433845920	13847	Economy	33300.00
0005433846013	13847	Economy	33300.00
0005433845687	13847	Economy	33300.00
0005433845994	13847	Economy	33300.00
0005433846173	13847	Economy	33300.00
0005433815329	13847	Economy	33300.00
0005433845795	13847	Economy	33300.00
0005433845880	13847	Economy	33300.00
0005434620499	7810	Economy	16600.00
0005435332228	7810	Economy	16600.00
0005435332249	7810	Economy	16600.00
0005435332210	7810	Economy	16600.00
0005434620507	7810	Economy	15100.00
0005434620503	7810	Economy	15100.00
0005434620495	7810	Economy	15100.00
0005434620506	7810	Economy	15100.00
0005435332232	7810	Economy	15100.00
0005434620505	7810	Economy	15100.00
0005432112506	7810	Economy	15100.00
0005435332186	7810	Economy	15100.00
0005435332185	7810	Economy	15100.00
0005434620509	7810	Economy	15100.00
0005435332188	7810	Economy	15100.00
0005435332208	7810	Economy	15100.00
0005434620512	7810	Economy	15100.00
0005434620500	7810	Economy	15100.00
0005434620504	7810	Economy	15100.00
0005434620508	7810	Economy	15100.00
0005434620513	7810	Economy	15100.00
0005434620502	7810	Economy	15100.00
0005434620515	7810	Economy	15100.00
0005434620514	7810	Economy	15100.00
0005434620501	7810	Economy	15100.00
0005434620511	7810	Economy	15100.00
0005434620498	7810	Economy	15100.00
0005434620510	7810	Economy	15100.00
0005435332251	7810	Economy	15100.00
0005435332250	7810	Economy	15100.00
0005435332181	7810	Economy	15100.00
0005434620496	7810	Economy	15100.00
0005434620497	7810	Economy	15100.00
0005434620278	32996	Economy	16600.00
0005435332290	32996	Economy	15100.00
0005434620335	32996	Economy	15100.00
0005434620405	32996	Economy	15100.00
0005435332285	32996	Economy	15100.00
0005435332293	32996	Economy	15100.00
0005434620344	32996	Economy	15100.00
0005434620290	32996	Economy	15100.00
0005434620363	32996	Economy	15100.00
0005434620358	32996	Economy	15100.00
0005435332294	32996	Economy	15100.00
0005434620331	32996	Economy	15100.00
0005434620414	32996	Economy	15100.00
0005435332289	32996	Economy	15100.00
0005435332291	32996	Economy	15100.00
0005435332288	32996	Economy	15100.00
0005434620362	32996	Economy	15100.00
0005435332287	32996	Economy	15100.00
0005434620386	32996	Economy	15100.00
0005435332286	32996	Economy	15100.00
0005435332292	32996	Economy	15100.00
0005434620345	32996	Economy	15100.00
0005434620352	32996	Economy	15100.00
0005434620380	32996	Economy	15100.00
0005434620376	32996	Economy	15100.00
0005435937315	4301	Business	38000.00
0005435937326	4301	Business	38000.00
0005432190612	4301	Business	38000.00
0005435785196	4301	Business	38000.00
0005435787345	4301	Business	38000.00
0005435785211	4301	Economy	12700.00
0005435785208	4301	Economy	12700.00
0005434993979	4301	Economy	12700.00
0005434993976	4301	Economy	12700.00
0005434993981	4301	Economy	12700.00
0005435785209	4301	Economy	13900.00
0005435785201	4301	Economy	13900.00
0005435785221	4301	Economy	13900.00
0005435785206	4301	Economy	12700.00
0005434993982	4301	Economy	12700.00
0005435785189	4301	Economy	12700.00
0005435918613	4301	Economy	12700.00
0005435918618	4301	Economy	12700.00
0005435785205	4301	Economy	12700.00
0005434993975	4301	Economy	12700.00
0005435785195	4301	Economy	12700.00
0005435785218	4301	Economy	12700.00
0005435785190	4301	Economy	12700.00
0005435785217	4301	Economy	12700.00
0005434993980	4301	Economy	12700.00
0005435785222	4301	Economy	12700.00
0005435937313	4301	Economy	12700.00
0005434993977	4301	Economy	12700.00
0005435785191	4301	Economy	12700.00
0005435785188	4301	Economy	12700.00
0005435785199	4301	Economy	12700.00
0005435785193	4301	Economy	12700.00
0005435785220	4301	Economy	12700.00
0005435785197	4301	Economy	12700.00
0005434993983	4301	Economy	12700.00
0005435937325	4301	Economy	12700.00
0005435785203	4301	Economy	12700.00
0005435785202	4301	Economy	12700.00
0005435785215	4301	Economy	12700.00
0005435918603	4301	Economy	12700.00
0005435785187	4301	Economy	12700.00
0005435785216	4301	Economy	12700.00
0005435785198	4301	Economy	12700.00
0005435918587	4301	Economy	12700.00
0005435785204	4301	Economy	12700.00
0005435937314	4301	Economy	12700.00
0005435785214	4301	Economy	12700.00
0005435785200	4301	Economy	12700.00
0005435785212	4301	Economy	12700.00
0005435785213	4301	Economy	12700.00
0005434993978	4301	Economy	12700.00
0005435785194	4301	Economy	12700.00
0005432190614	4301	Economy	12700.00
0005435785207	4301	Economy	12700.00
0005434993984	4301	Economy	12700.00
0005435785192	4301	Economy	12700.00
0005435785210	4301	Economy	12700.00
0005435787344	4301	Economy	12700.00
0005435785219	4301	Economy	12700.00
0005432190613	4301	Economy	12700.00
0005435937358	27327	Business	38000.00
0005434993906	27327	Business	38000.00
0005435784771	27327	Business	38000.00
0005435784746	27327	Business	38000.00
0005435784837	27327	Business	38000.00
0005435918637	27327	Economy	12700.00
0005435784815	27327	Economy	12700.00
0005435784860	27327	Economy	12700.00
0005435784855	27327	Economy	12700.00
0005434993889	27327	Economy	12700.00
0005434993883	27327	Economy	12700.00
0005434993922	27327	Economy	12700.00
0005435784788	27327	Economy	13900.00
0005435784773	27327	Economy	13900.00
0005435784732	27327	Economy	13900.00
0005435784800	27327	Economy	12700.00
0005435784820	27327	Economy	12700.00
0005435937362	27327	Economy	12700.00
0005435784772	27327	Economy	12700.00
0005434993888	27327	Economy	12700.00
0005435784818	27327	Economy	12700.00
0005435787325	27327	Economy	12700.00
0005435918635	27327	Economy	12700.00
0005435784805	27327	Economy	12700.00
0005435784888	27327	Economy	12700.00
0005435784821	27327	Economy	12700.00
0005434993891	27327	Economy	12700.00
0005435784863	27327	Economy	12700.00
0005434993904	27327	Economy	12700.00
0005435784886	27327	Economy	12700.00
0005435787324	27327	Economy	12700.00
0005434993882	27327	Economy	12700.00
0005435937359	27327	Economy	12700.00
0005435784840	27327	Economy	12700.00
0005435918632	27327	Economy	12700.00
0005435784822	27327	Economy	12700.00
0005435784889	27327	Economy	12700.00
0005434993890	27327	Economy	12700.00
0005435937366	27327	Economy	12700.00
0005435784949	27327	Economy	12700.00
0005435784918	27327	Economy	12700.00
0005435784901	27327	Economy	12700.00
0005435937363	27327	Economy	12700.00
0005435784911	27327	Economy	12700.00
0005435937365	27327	Economy	12700.00
0005432195682	27327	Economy	12700.00
0005435937360	27327	Economy	12700.00
0005434993895	27327	Economy	12700.00
0005435918636	27327	Economy	12700.00
0005435784868	27327	Economy	12700.00
0005434993905	27327	Economy	12700.00
0005435937364	27327	Economy	12700.00
0005435918633	27327	Economy	12700.00
0005435784794	27327	Economy	12700.00
0005435784912	27327	Economy	12700.00
0005435787326	27327	Economy	12700.00
0005435784917	27327	Economy	12700.00
0005432195683	27327	Economy	12700.00
0005435918634	27327	Economy	12700.00
0005435784731	27327	Economy	12700.00
0005435937361	27327	Economy	12700.00
0005435784787	27327	Economy	12700.00
0005432146189	19884	Economy	12800.00
0005432146188	19884	Economy	12800.00
0005432146190	19884	Economy	12800.00
0005432459604	4751	Business	40900.00
0005434081801	4751	Business	40900.00
0005434081809	4751	Business	40900.00
0005432459647	4751	Business	40900.00
0005432459626	4751	Business	40900.00
0005432567347	4751	Business	40900.00
0005434081804	4751	Business	40900.00
0005432459605	4751	Business	40900.00
0005434081818	4751	Business	40900.00
0005432186855	4751	Business	40900.00
0005432459607	4751	Business	40900.00
0005432567374	4751	Business	40900.00
0005434081815	4751	Business	40900.00
0005432459639	4751	Business	40900.00
0005432571303	4751	Business	40900.00
0005432567349	4751	Business	40900.00
0005432567343	4751	Business	40900.00
0005432459598	4751	Business	40900.00
0005432567392	4751	Business	40900.00
0005432567352	4751	Business	40900.00
0005432567345	4751	Business	40900.00
0005432170361	4751	Business	40900.00
0005432567363	4751	Business	40900.00
0005432567377	4751	Economy	15000.00
0005432459616	4751	Economy	15000.00
0005434081800	4751	Economy	15000.00
0005432459600	4751	Economy	15000.00
0005434081807	4751	Economy	13600.00
0005432459629	4751	Economy	13600.00
0005432459619	4751	Economy	13600.00
0005432567355	4751	Economy	13600.00
0005432567398	4751	Economy	13600.00
0005432459597	4751	Economy	13600.00
0005432567353	4751	Economy	13600.00
0005434081799	4751	Economy	13600.00
0005432459620	4751	Economy	13600.00
0005432459623	4751	Economy	13600.00
0005432459608	4751	Economy	13600.00
0005432567391	4751	Economy	13600.00
0005434559092	4751	Economy	13600.00
0005432567351	4751	Economy	13600.00
0005432567357	4751	Economy	13600.00
0005434559094	4751	Economy	13600.00
0005432459630	4751	Economy	13600.00
0005432567365	4751	Economy	13600.00
0005432459640	4751	Economy	13600.00
0005434081798	4751	Economy	13600.00
0005432567368	4751	Economy	13600.00
0005432567385	4751	Economy	13600.00
0005433452731	4751	Economy	13600.00
0005432567366	4751	Economy	13600.00
0005434081814	4751	Economy	13600.00
0005432567375	4751	Economy	13600.00
0005432459643	4751	Economy	13600.00
0005432567388	4751	Economy	13600.00
0005432567370	4751	Economy	13600.00
0005432567382	4751	Economy	13600.00
0005432567390	4751	Economy	13600.00
0005432567354	4751	Economy	13600.00
0005432459617	4751	Economy	13600.00
0005432170356	4751	Economy	13600.00
0005432567384	4751	Economy	13600.00
0005432567350	4751	Economy	13600.00
0005433451612	4751	Economy	13600.00
0005434081808	4751	Economy	13600.00
0005432459625	4751	Economy	13600.00
0005432567394	4751	Economy	13600.00
0005432170360	4751	Economy	13600.00
0005432567381	4751	Economy	13600.00
0005432567369	4751	Economy	13600.00
0005432567373	4751	Economy	13600.00
0005432459603	4751	Economy	13600.00
0005432567348	4751	Economy	13600.00
0005432459610	4751	Economy	13600.00
0005434081790	4751	Economy	13600.00
0005432567359	4751	Economy	13600.00
0005434081817	4751	Economy	13600.00
0005434081802	4751	Economy	13600.00
0005434081796	4751	Economy	13600.00
0005432567358	4751	Economy	13600.00
0005432567389	4751	Economy	13600.00
0005432186853	4751	Economy	13600.00
0005432459644	4751	Economy	13600.00
0005434559093	4751	Economy	13600.00
0005433452729	4751	Economy	13600.00
0005432567376	4751	Economy	13600.00
0005434081794	4751	Economy	13600.00
0005432459646	4751	Economy	13600.00
0005432170357	4751	Economy	13600.00
0005433726094	4751	Economy	13600.00
0005432571304	4751	Economy	13600.00
0005432567397	4751	Economy	13600.00
0005432567362	4751	Economy	13600.00
0005432459631	4751	Economy	13600.00
0005432459618	4751	Economy	13600.00
0005432567372	4751	Economy	13600.00
0005432459612	4751	Economy	13600.00
0005432459601	4751	Economy	13600.00
0005432567396	4751	Economy	13600.00
0005432571307	4751	Economy	13600.00
0005432459602	4751	Economy	13600.00
0005434081816	4751	Economy	13600.00
0005432567387	4751	Economy	13600.00
0005434081797	4751	Economy	13600.00
0005432567360	4751	Economy	13600.00
0005432170355	4751	Economy	13600.00
0005433452732	4751	Economy	13600.00
0005434081791	4751	Economy	13600.00
0005432459614	4751	Economy	15000.00
0005434081812	4751	Economy	15000.00
0005432459649	4751	Economy	13600.00
0005432567378	4751	Economy	13600.00
0005432459606	4751	Economy	15000.00
0005432459638	4751	Economy	13600.00
0005432459622	4751	Economy	13600.00
0005432459645	4751	Economy	13600.00
0005433451610	4751	Economy	13600.00
0005432567361	4751	Economy	13600.00
0005432459637	4751	Economy	13600.00
0005432567344	4751	Economy	13600.00
0005432567386	4751	Economy	13600.00
0005432459650	4751	Economy	13600.00
0005432186852	4751	Economy	13600.00
0005432170359	4751	Economy	13600.00
0005432459628	4751	Economy	13600.00
0005432459633	4751	Economy	13600.00
0005434081795	4751	Economy	13600.00
0005432170358	4751	Economy	13600.00
0005432567340	4751	Economy	13600.00
0005432567399	4751	Economy	13600.00
0005432567383	4751	Economy	13600.00
0005432459621	4751	Economy	13600.00
0005432567342	4751	Economy	13600.00
0005432459636	4751	Economy	13600.00
0005432459613	4751	Economy	13600.00
0005434081805	4751	Economy	13600.00
0005434081813	4751	Economy	13600.00
0005432567341	4751	Economy	13600.00
0005432459627	4751	Economy	13600.00
0005432567367	4751	Economy	13600.00
0005433452730	4751	Economy	13600.00
0005432459634	4751	Economy	13600.00
0005432459642	4751	Economy	13600.00
0005432567395	4751	Economy	13600.00
0005433726093	4751	Economy	13600.00
0005434081806	4751	Economy	13600.00
0005432459635	4751	Economy	13600.00
0005432459611	4751	Economy	13600.00
0005432459641	4751	Economy	13600.00
0005432459648	4751	Economy	13600.00
0005432459632	4751	Economy	13600.00
0005432459609	4751	Economy	13600.00
0005434559095	4751	Economy	13600.00
0005432567364	4751	Economy	13600.00
0005432567380	4751	Economy	13600.00
0005434081810	4751	Economy	13600.00
0005432567356	4751	Economy	13600.00
0005434081811	4751	Economy	13600.00
0005432567379	4751	Economy	13600.00
0005432459624	4751	Economy	13600.00
0005434081792	4751	Economy	13600.00
0005432567346	4751	Economy	13600.00
0005432567371	4751	Economy	13600.00
0005432571305	4751	Economy	13600.00
0005432571306	4751	Economy	13600.00
0005433451611	4751	Economy	13600.00
0005434081803	4751	Economy	13600.00
0005434081793	4751	Economy	13600.00
0005432459615	4751	Economy	13600.00
0005432567400	4751	Economy	13600.00
0005432459599	4751	Economy	13600.00
0005432186854	4751	Economy	13600.00
0005432567393	4751	Economy	13600.00
0005432459235	30520	Business	40900.00
0005433454847	30520	Business	40900.00
0005432567122	30520	Business	40900.00
0005434081565	30520	Business	40900.00
0005434081632	30520	Business	40900.00
0005432459117	30520	Business	40900.00
0005432459195	30520	Business	40900.00
0005432566860	30520	Business	40900.00
0005432459485	30520	Business	40900.00
0005432567088	30520	Business	40900.00
0005434081648	30520	Business	40900.00
0005432459013	30520	Business	40900.00
0005432459338	30520	Business	40900.00
0005432567059	30520	Business	40900.00
0005433452711	30520	Business	40900.00
0005432459307	30520	Business	40900.00
0005432566839	30520	Business	40900.00
0005433452709	30520	Economy	15000.00
0005432459344	30520	Economy	15000.00
0005432459252	30520	Economy	15000.00
0005432459251	30520	Economy	13600.00
0005432566826	30520	Economy	13600.00
0005432567007	30520	Economy	13600.00
0005432566913	30520	Economy	13600.00
0005433454842	30520	Economy	13600.00
0005432567073	30520	Economy	13600.00
0005432567060	30520	Economy	13600.00
0005432567006	30520	Economy	13600.00
0005432566843	30520	Economy	13600.00
0005432459458	30520	Economy	13600.00
0005434081590	30520	Economy	13600.00
0005432459432	30520	Economy	13600.00
0005432459456	30520	Economy	13600.00
0005432566851	30520	Economy	13600.00
0005432566861	30520	Economy	13600.00
0005434081578	30520	Economy	13600.00
0005432459228	30520	Economy	13600.00
0005432566793	30520	Economy	13600.00
0005432459261	30520	Economy	13600.00
0005432459350	30520	Economy	13600.00
0005432459244	30520	Economy	13600.00
0005434081581	30520	Economy	13600.00
0005432566769	30520	Economy	13600.00
0005432566914	30520	Economy	13600.00
0005432571278	30520	Economy	13600.00
0005432566806	30520	Economy	13600.00
0005432459231	30520	Economy	13600.00
0005432459433	30520	Economy	13600.00
0005434081577	30520	Economy	13600.00
0005432566655	30520	Economy	13600.00
0005432459168	30520	Economy	13600.00
0005432459102	30520	Economy	13600.00
0005432566990	30520	Economy	13600.00
0005432459249	30520	Economy	13600.00
0005432566995	30520	Economy	13600.00
0005432459351	30520	Economy	13600.00
0005432459313	30520	Economy	13600.00
0005432567097	30520	Economy	13600.00
0005432213590	30520	Economy	13600.00
0005432459349	30520	Economy	13600.00
0005432459314	30520	Economy	13600.00
0005434081504	30520	Economy	13600.00
0005432459236	30520	Economy	13600.00
0005432566597	30520	Economy	13600.00
0005432459319	30520	Economy	13600.00
0005432459457	30520	Economy	13600.00
0005432458975	30520	Economy	13600.00
0005432566811	30520	Economy	13600.00
0005432566735	30520	Economy	13600.00
0005433454841	30520	Economy	13600.00
0005434081576	30520	Economy	13600.00
0005432567013	30520	Economy	13600.00
0005432567098	30520	Economy	13600.00
0005432459116	30520	Economy	13600.00
0005432459294	30520	Economy	13600.00
0005432566871	30520	Economy	13600.00
0005432459264	30520	Economy	13600.00
0005432566563	30520	Economy	13600.00
0005432566991	30520	Economy	13600.00
0005432566816	30520	Economy	13600.00
0005432213589	30520	Economy	13600.00
0005432459245	30520	Economy	13600.00
0005432567044	30520	Economy	13600.00
0005432566915	30520	Economy	13600.00
0005432161143	30520	Economy	13600.00
0005434081610	30520	Economy	13600.00
0005432566531	30520	Economy	13600.00
0005432566841	30520	Economy	13600.00
0005434081518	30520	Economy	13600.00
0005432459298	30520	Economy	15000.00
0005433452702	30520	Economy	15000.00
0005432161142	30520	Economy	13600.00
0005434081553	30520	Economy	13600.00
0005432566908	30520	Economy	13600.00
0005432459337	30520	Economy	13600.00
0005432459229	30520	Economy	13600.00
0005432566996	30520	Economy	13600.00
0005433452710	30520	Economy	13600.00
0005432213591	30520	Economy	13600.00
0005432459219	30520	Economy	13600.00
0005432459343	30520	Economy	13600.00
0005432566662	30520	Economy	13600.00
0005432459250	30520	Economy	13600.00
0005432566857	30520	Economy	13600.00
0005432459196	30520	Economy	13600.00
0005432459323	30520	Economy	13600.00
0005432566744	30520	Economy	13600.00
0005434081564	30520	Economy	13600.00
0005434081631	30520	Economy	13600.00
0005434081619	30520	Economy	13600.00
0005432566966	30520	Economy	13600.00
0005432459079	30520	Economy	13600.00
0005432459306	30520	Economy	13600.00
0005432567001	30520	Economy	13600.00
0005432459203	30520	Economy	13600.00
0005434081471	30520	Economy	13600.00
0005432566810	30520	Economy	13600.00
0005432566770	30520	Economy	13600.00
0005432566982	30520	Economy	13600.00
0005432459248	30520	Economy	13600.00
0005432567049	30520	Economy	13600.00
0005433452703	30520	Economy	13600.00
0005432459204	30520	Economy	13600.00
0005432566677	30520	Economy	13600.00
0005433452708	30520	Economy	13600.00
0005434081580	30520	Economy	13600.00
0005432459089	30520	Economy	13600.00
0005434081642	30520	Economy	13600.00
0005435722044	13596	Economy	9900.00
0005435722045	13596	Economy	9900.00
0005435720122	21231	Economy	9900.00
0005435720123	21231	Economy	9900.00
0005435722014	21231	Economy	9900.00
0005432295869	22767	Economy	8800.00
0005432295868	22767	Economy	8800.00
0005433342759	11098	Business	23600.00
0005435508199	11098	Business	23600.00
0005433342743	11098	Business	23600.00
0005433342761	11098	Business	23600.00
0005433342716	11098	Business	23600.00
0005435380232	11098	Business	23600.00
0005435508205	11098	Business	23600.00
0005433342739	11098	Business	23600.00
0005433342764	11098	Business	23600.00
0005433342733	11098	Business	23600.00
0005433342803	11098	Business	23600.00
0005433342713	11098	Economy	7900.00
0005433342800	11098	Economy	7900.00
0005433342722	11098	Economy	7900.00
0005433342728	11098	Economy	7900.00
0005435097161	11098	Economy	7900.00
0005433342751	11098	Economy	7900.00
0005433342794	11098	Economy	7900.00
0005435097158	11098	Economy	7900.00
0005433342737	11098	Economy	7900.00
0005435380235	11098	Economy	7900.00
0005433342789	11098	Economy	7900.00
0005433342750	11098	Economy	7900.00
0005433342801	11098	Economy	7900.00
0005435380236	11098	Economy	7900.00
0005433342749	11098	Economy	7900.00
0005433342709	11098	Economy	7900.00
0005433342744	11098	Economy	7900.00
0005433342735	11098	Economy	7900.00
0005433342765	11098	Economy	7900.00
0005433342711	11098	Economy	7900.00
0005433342714	11098	Economy	7900.00
0005433342776	11098	Economy	7900.00
0005433342795	11098	Economy	7900.00
0005433342786	11098	Economy	7900.00
0005435508207	11098	Economy	7900.00
0005433342704	11098	Economy	7900.00
0005435097165	11098	Economy	7900.00
0005433342791	11098	Economy	7900.00
0005433342708	11098	Economy	7900.00
0005433342729	11098	Economy	7900.00
0005433342797	11098	Economy	7900.00
0005433342762	11098	Economy	7900.00
0005433342771	11098	Economy	7900.00
0005433342775	11098	Economy	7900.00
0005435097162	11098	Economy	7900.00
0005433342745	11098	Economy	7900.00
0005433342757	11098	Economy	7900.00
0005435380233	11098	Economy	7900.00
0005433342730	11098	Economy	8600.00
0005433342741	11098	Economy	8600.00
0005433342780	11098	Economy	8600.00
0005433342767	11098	Economy	8600.00
0005433342778	11098	Economy	8600.00
0005433342760	11098	Economy	8600.00
0005433342756	11098	Economy	7900.00
0005433342736	11098	Economy	7900.00
0005435097157	11098	Economy	7900.00
0005433342747	11098	Economy	7900.00
0005433342798	11098	Economy	7900.00
0005433342731	11098	Economy	7900.00
0005433342712	11098	Economy	7900.00
0005433342792	11098	Economy	7900.00
0005435508203	11098	Economy	7900.00
0005433342755	11098	Economy	7900.00
0005433342705	11098	Economy	7900.00
0005433342782	11098	Economy	7900.00
0005433342781	11098	Economy	7900.00
0005433342753	11098	Economy	7900.00
0005435097163	11098	Economy	7900.00
0005433342732	11098	Economy	7900.00
0005433342720	11098	Economy	7900.00
0005433342788	11098	Economy	7900.00
0005433342779	11098	Economy	7900.00
0005433342715	11098	Economy	7900.00
0005433342719	11098	Economy	7900.00
0005433342783	11098	Economy	7900.00
0005433342738	11098	Economy	7900.00
0005435097159	11098	Economy	7900.00
0005433342802	11098	Economy	7900.00
0005433342726	11098	Economy	7900.00
0005433342742	11098	Economy	7900.00
0005433342773	11098	Economy	7900.00
0005435508200	11098	Economy	7900.00
0005433342766	11098	Economy	7900.00
0005433342796	11098	Economy	7900.00
0005433342734	11098	Economy	7900.00
0005433342740	11098	Economy	7900.00
0005433342769	11098	Economy	7900.00
0005433342710	11098	Economy	7900.00
0005433342707	11098	Economy	7900.00
0005433342790	11098	Economy	7900.00
0005433342721	11098	Economy	7900.00
0005435380226	11098	Economy	7900.00
0005433342748	11098	Economy	7900.00
0005433342706	11098	Economy	7900.00
0005433342723	11098	Economy	7900.00
0005433342702	11098	Economy	7900.00
0005433342774	11098	Economy	7900.00
0005435508180	11098	Economy	7900.00
0005433342787	11098	Economy	7900.00
0005433342727	11098	Economy	7900.00
0005433342785	11098	Economy	7900.00
0005433342763	11098	Economy	7900.00
0005433342724	11098	Economy	7900.00
0005433342725	11098	Economy	7900.00
0005433342758	11098	Economy	7900.00
0005435380234	11098	Economy	7900.00
0005433342746	11098	Economy	7900.00
0005435097160	11098	Economy	7900.00
0005435508210	11098	Economy	7900.00
0005433342793	11098	Economy	7900.00
0005433342768	11098	Economy	7900.00
0005433342777	11098	Economy	7900.00
0005433342784	11098	Economy	7900.00
0005433342752	11098	Economy	7900.00
0005433342703	11098	Economy	7900.00
0005433342770	11098	Economy	7900.00
0005433342804	11098	Economy	7900.00
0005435097164	11098	Economy	7900.00
0005433342799	11098	Economy	7900.00
0005433342754	11098	Economy	7900.00
0005433342718	11098	Economy	7900.00
0005435508206	11098	Economy	7900.00
0005433342717	11098	Economy	7900.00
0005433342772	11098	Economy	7900.00
0005435545701	17101	Business	23600.00
0005433341726	17101	Business	23600.00
0005435545706	17101	Business	23600.00
0005433342182	17101	Business	23600.00
0005433341754	17101	Business	23600.00
0005435545700	17101	Business	23600.00
0005433341535	17101	Business	23600.00
0005433342189	17101	Business	23600.00
0005433341426	17101	Business	23600.00
0005435097111	17101	Business	23600.00
0005432293197	17101	Business	23600.00
0005433341413	17101	Business	23600.00
0005433341623	17101	Economy	7900.00
0005433341805	17101	Economy	7900.00
0005433341986	17101	Economy	7900.00
0005433341631	17101	Economy	7900.00
0005433341447	17101	Economy	7900.00
0005433341821	17101	Economy	7900.00
0005433342177	17101	Economy	7900.00
0005433341862	17101	Economy	7900.00
0005432293198	17101	Economy	7900.00
0005433341655	17101	Economy	7900.00
0005433341572	17101	Economy	7900.00
0005433342044	17101	Economy	7900.00
0005435545699	17101	Economy	7900.00
0005433342337	17101	Economy	7900.00
0005433342275	17101	Economy	7900.00
0005435380280	17101	Economy	7900.00
0005433342309	17101	Economy	7900.00
0005433342017	17101	Economy	7900.00
0005433341390	17101	Economy	7900.00
0005433342178	17101	Economy	7900.00
0005435545713	17101	Economy	7900.00
0005433341489	17101	Economy	7900.00
0005433341966	17101	Economy	7900.00
0005433342176	17101	Economy	7900.00
0005435545711	17101	Economy	7900.00
0005433341675	17101	Economy	7900.00
0005433341427	17101	Economy	7900.00
0005435545712	17101	Economy	7900.00
0005433341446	17101	Economy	7900.00
0005433342250	17101	Economy	7900.00
0005435380277	17101	Economy	7900.00
0005433341624	17101	Economy	7900.00
0005433341727	17101	Economy	7900.00
0005433341582	17101	Economy	7900.00
0005433341888	17101	Economy	7900.00
0005435380275	17101	Economy	7900.00
0005432293199	17101	Economy	8600.00
0005433342172	17101	Economy	7900.00
0005433342101	17101	Economy	8600.00
0005435380276	17101	Economy	8600.00
0005433341612	17101	Economy	8600.00
0005435545714	17101	Economy	8600.00
0005433341752	17101	Economy	7900.00
0005433341625	17101	Economy	7900.00
0005435545710	17101	Economy	7900.00
0005433341995	17101	Economy	7900.00
0005433341490	17101	Economy	7900.00
0005433342099	17101	Economy	7900.00
0005433342179	17101	Economy	7900.00
0005435545697	17101	Economy	7900.00
0005433342019	17101	Economy	7900.00
0005435545708	17101	Economy	7900.00
0005435545709	17101	Economy	7900.00
0005433341685	17101	Economy	7900.00
0005433341981	17101	Economy	7900.00
0005433342251	17101	Economy	7900.00
0005433342072	17101	Economy	7900.00
0005433341873	17101	Economy	7900.00
0005433341755	17101	Economy	7900.00
0005435545703	17101	Economy	7900.00
0005433341949	17101	Economy	7900.00
0005433341757	17101	Economy	7900.00
0005433341686	17101	Economy	7900.00
0005433341817	17101	Economy	7900.00
0005433342018	17101	Economy	7900.00
0005433341751	17101	Economy	7900.00
0005433342021	17101	Economy	7900.00
0005433341789	17101	Economy	7900.00
0005433342138	17101	Economy	7900.00
0005433341849	17101	Economy	7900.00
0005435545707	17101	Economy	7900.00
0005433341998	17101	Economy	7900.00
0005433341844	17101	Economy	7900.00
0005433341813	17101	Economy	7900.00
0005433341741	17101	Economy	7900.00
0005433341748	17101	Economy	7900.00
0005433341965	17101	Economy	7900.00
0005433341842	17101	Economy	7900.00
0005433342188	17101	Economy	7900.00
0005435097050	17101	Economy	7900.00
0005433342045	17101	Economy	7900.00
0005435545704	17101	Economy	7900.00
0005435380278	17101	Economy	7900.00
0005433341816	17101	Economy	7900.00
0005433341766	17101	Economy	7900.00
0005435545702	17101	Economy	7900.00
0005433341632	17101	Economy	7900.00
0005433342062	17101	Economy	7900.00
0005433341747	17101	Economy	7900.00
0005433341455	17101	Economy	7900.00
0005433341581	17101	Economy	7900.00
0005435545698	17101	Economy	7900.00
0005435097095	17101	Economy	7900.00
0005433341701	17101	Economy	7900.00
0005435380279	17101	Economy	7900.00
0005433341548	17101	Economy	7900.00
0005433341765	17101	Economy	7900.00
0005433341728	17101	Economy	7900.00
0005435097110	17101	Economy	7900.00
0005433341788	17101	Economy	7900.00
0005433341843	17101	Economy	7900.00
0005433341767	17101	Economy	7900.00
0005433341389	17101	Economy	7900.00
0005433342054	17101	Economy	7900.00
0005435545705	17101	Economy	7900.00
0005433342173	17101	Economy	7900.00
0005433341729	17101	Economy	7900.00
0005433341845	17101	Economy	7900.00
0005433341742	17101	Economy	7900.00
0005435097043	17101	Economy	7900.00
0005433342053	17101	Economy	7900.00
0005433507115	9097	Business	26600.00
0005433481138	9097	Business	26600.00
0005432919652	9097	Business	26600.00
0005433507117	9097	Business	26600.00
0005432919511	9097	Business	26600.00
0005432919571	9097	Business	26600.00
0005433481139	9097	Economy	8900.00
0005433507107	9097	Economy	8900.00
0005433507104	9097	Economy	8900.00
0005433507116	9097	Economy	8900.00
0005432919542	9097	Economy	8900.00
0005433507098	9097	Economy	8900.00
0005433507103	9097	Economy	9800.00
0005432919583	9097	Economy	8900.00
0005433507113	9097	Economy	8900.00
0005432919552	9097	Economy	8900.00
0005432919621	9097	Economy	8900.00
0005432919631	9097	Economy	8900.00
0005433507102	9097	Economy	8900.00
0005432919554	9097	Economy	8900.00
0005433481132	9097	Economy	8900.00
0005432919619	9097	Economy	8900.00
0005432919513	9097	Economy	8900.00
0005432919653	9097	Economy	8900.00
0005432919601	9097	Economy	8900.00
0005433507099	9097	Economy	8900.00
0005433507106	9097	Economy	8900.00
0005433507114	9097	Economy	8900.00
0005433507110	9097	Economy	8900.00
0005433507105	9097	Economy	8900.00
0005432919632	9097	Economy	8900.00
0005432919638	9097	Economy	8900.00
0005433481133	9097	Economy	8900.00
0005433481137	9097	Economy	8900.00
0005432919518	9097	Economy	8900.00
0005432919555	9097	Economy	8900.00
0005433507111	9097	Economy	8900.00
0005433481135	9097	Economy	8900.00
0005432919538	9097	Economy	8900.00
0005432919512	9097	Economy	8900.00
0005433507100	9097	Economy	8900.00
0005432919517	9097	Economy	8900.00
0005433481134	9097	Economy	8900.00
0005433507112	9097	Economy	8900.00
0005432919618	9097	Economy	8900.00
0005433507108	9097	Economy	8900.00
0005433507109	9097	Economy	8900.00
0005432919537	9097	Economy	8900.00
0005433507101	9097	Economy	8900.00
0005432919576	9097	Economy	8900.00
0005433481136	9097	Economy	8900.00
0005433506913	20450	Business	26600.00
0005432919791	20450	Business	26600.00
0005433506899	20450	Business	26600.00
0005433506957	20450	Business	26600.00
0005432919800	20450	Business	26600.00
0005433506995	20450	Business	26600.00
0005434158970	20450	Business	26600.00
0005432919794	20450	Economy	8900.00
0005433506914	20450	Economy	8900.00
0005433506937	20450	Economy	8900.00
0005432919784	20450	Economy	8900.00
0005433507068	20450	Economy	9800.00
0005434158968	20450	Economy	9800.00
0005433506926	20450	Economy	9800.00
0005433506885	20450	Economy	8900.00
0005433507069	20450	Economy	8900.00
0005432919798	20450	Economy	8900.00
0005433481052	20450	Economy	8900.00
0005432919796	20450	Economy	8900.00
0005432919783	20450	Economy	8900.00
0005433481095	20450	Economy	8900.00
0005433506900	20450	Economy	8900.00
0005434158972	20450	Economy	8900.00
0005433506898	20450	Economy	8900.00
0005432919785	20450	Economy	8900.00
0005433481066	20450	Economy	8900.00
0005433507001	20450	Economy	8900.00
0005433481076	20450	Economy	8900.00
0005432919795	20450	Economy	8900.00
0005433506950	20450	Economy	8900.00
0005433506875	20450	Economy	8900.00
0005433507014	20450	Economy	8900.00
0005432919792	20450	Economy	8900.00
0005434158971	20450	Economy	8900.00
0005433506936	20450	Economy	8900.00
0005432919797	20450	Economy	8900.00
0005432919787	20450	Economy	8900.00
0005432919786	20450	Economy	8900.00
0005433506954	20450	Economy	8900.00
0005432919788	20450	Economy	8900.00
0005432919793	20450	Economy	8900.00
0005434158969	20450	Economy	8900.00
0005433506966	20450	Economy	8900.00
0005433506960	20450	Economy	8900.00
0005432919799	20450	Economy	8900.00
0005432919801	20450	Economy	8900.00
0005433506951	20450	Economy	8900.00
0005432919789	20450	Economy	8900.00
0005433506967	20450	Economy	8900.00
0005432919781	20450	Economy	8900.00
0005433506956	20450	Economy	8900.00
0005433481077	20450	Economy	8900.00
0005432919782	20450	Economy	8900.00
0005432919790	20450	Economy	8900.00
0005432396221	10172	Economy	5800.00
0005432396220	10172	Economy	5800.00
0005432394084	10172	Economy	5800.00
0005432394082	10172	Economy	5800.00
0005435178980	10172	Economy	5800.00
0005432396223	10172	Economy	5800.00
0005432394081	10172	Economy	5800.00
0005435178979	10172	Economy	5800.00
0005432396222	10172	Economy	5800.00
0005432394083	10172	Economy	5800.00
0005432396188	18357	Economy	5800.00
0005432400089	18357	Economy	5800.00
0005432400090	18357	Economy	5800.00
0005432400088	18357	Economy	5800.00
0005432396200	18357	Economy	5800.00
0005432396187	18357	Economy	5800.00
0005432396191	18357	Economy	5800.00
0005432396199	18357	Economy	5800.00
0005432396189	18357	Economy	5800.00
0005432400069	18357	Economy	5800.00
0005432396190	18357	Economy	5800.00
0005435625920	10977	Business	9500.00
0005435125818	10977	Business	9500.00
0005435625941	10977	Business	9500.00
0005435125778	10977	Business	9500.00
0005435125808	10977	Business	9500.00
0005434928287	10977	Business	9500.00
0005435125867	10977	Business	9500.00
0005435625929	10977	Economy	3200.00
0005434411760	10977	Economy	3200.00
0005435625937	10977	Economy	3200.00
0005435125777	10977	Economy	3200.00
0005435625888	10977	Economy	3200.00
0005435125774	10977	Economy	3200.00
0005435554129	10977	Economy	3200.00
0005435125773	10977	Economy	3500.00
0005435625858	10977	Economy	3500.00
0005435125807	10977	Economy	3200.00
0005435126054	10977	Economy	3200.00
0005435125819	10977	Economy	3200.00
0005435554125	10977	Economy	3200.00
0005434411761	10977	Economy	3200.00
0005435125831	10977	Economy	3200.00
0005435125875	10977	Economy	3200.00
0005435625914	10977	Economy	3200.00
0005435554124	10977	Economy	3200.00
0005435125750	10977	Economy	3200.00
0005435125787	10977	Economy	3200.00
0005435625940	10977	Economy	3200.00
0005435625930	10977	Economy	3200.00
0005435125775	10977	Economy	3200.00
0005435125876	10977	Economy	3200.00
0005435554121	10977	Economy	3200.00
0005435125934	10977	Economy	3200.00
0005435125715	10977	Economy	3200.00
0005435625897	10977	Economy	3200.00
0005435125681	10977	Economy	3200.00
0005435625890	10977	Economy	3200.00
0005435625921	10977	Economy	3200.00
0005435125814	10977	Economy	3200.00
0005435125798	10977	Economy	3200.00
0005435126053	10977	Economy	3200.00
0005435125776	10977	Economy	3200.00
0005435625945	10977	Economy	3200.00
0005435625891	10977	Economy	3200.00
0005435125820	10977	Economy	3200.00
0005435125765	10977	Economy	3200.00
0005435125830	10977	Economy	3200.00
0005435554130	10977	Economy	3200.00
0005434411763	10977	Economy	3200.00
0005435625946	10977	Economy	3200.00
0005435554126	10977	Economy	3200.00
0005435125828	10977	Economy	3200.00
0005435556659	10977	Economy	3200.00
0005435556660	10977	Economy	3200.00
0005435125866	10977	Economy	3200.00
0005435125827	10977	Economy	3200.00
0005435125939	10977	Economy	3200.00
0005435125771	10977	Economy	3200.00
0005435125670	10977	Economy	3200.00
0005435125935	10977	Economy	3200.00
0005435625857	10977	Economy	3200.00
0005435625887	10977	Economy	3200.00
0005434928286	10977	Economy	3200.00
0005434928288	10977	Economy	3200.00
0005435625924	10977	Economy	3200.00
0005435625935	10977	Economy	3200.00
0005435125772	10977	Economy	3200.00
0005435625903	10977	Economy	3200.00
0005434411762	10977	Economy	3200.00
0005435126211	14750	Business	9500.00
0005435126199	14750	Business	9500.00
0005435126196	14750	Business	9500.00
0005435126214	14750	Business	9500.00
0005435126222	14750	Business	9500.00
0005435126188	14750	Business	9500.00
0005435626094	14750	Economy	3200.00
0005435126197	14750	Economy	3200.00
0005435126210	14750	Economy	3200.00
0005435126192	14750	Economy	3200.00
0005435626101	14750	Economy	3200.00
0005435626107	14750	Economy	3200.00
0005434928266	14750	Economy	3200.00
0005435554164	14750	Economy	3200.00
0005435126226	14750	Economy	3500.00
0005434928263	14750	Economy	3500.00
0005435126195	14750	Economy	3500.00
0005435556681	14750	Economy	3200.00
0005435626104	14750	Economy	3200.00
0005435126202	14750	Economy	3200.00
0005435626095	14750	Economy	3200.00
0005435626100	14750	Economy	3200.00
0005435626099	14750	Economy	3200.00
0005435126201	14750	Economy	3200.00
0005435126227	14750	Economy	3200.00
0005435126224	14750	Economy	3200.00
0005435126216	14750	Economy	3200.00
0005435626097	14750	Economy	3200.00
0005435626108	14750	Economy	3200.00
0005435126223	14750	Economy	3200.00
0005435126220	14750	Economy	3200.00
0005435126194	14750	Economy	3200.00
0005435126203	14750	Economy	3200.00
0005435126200	14750	Economy	3200.00
0005435126213	14750	Economy	3200.00
0005435126208	14750	Economy	3200.00
0005435126190	14750	Economy	3200.00
0005435126189	14750	Economy	3200.00
0005435626109	14750	Economy	3200.00
0005435126218	14750	Economy	3200.00
0005435126191	14750	Economy	3200.00
0005434928269	14750	Economy	3200.00
0005435626092	14750	Economy	3200.00
0005435126219	14750	Economy	3200.00
0005435626093	14750	Economy	3200.00
0005435626106	14750	Economy	3200.00
0005435126217	14750	Economy	3200.00
0005435554165	14750	Economy	3200.00
0005434928270	14750	Economy	3200.00
0005435126230	14750	Economy	3200.00
0005435626103	14750	Economy	3200.00
0005434411725	14750	Economy	3200.00
0005435126212	14750	Economy	3200.00
0005435126193	14750	Economy	3200.00
0005435556683	14750	Economy	3200.00
0005435126204	14750	Economy	3200.00
0005435126225	14750	Economy	3200.00
0005435126198	14750	Economy	3200.00
0005435126215	14750	Economy	3200.00
0005435626105	14750	Economy	3200.00
0005435126207	14750	Economy	3200.00
0005435126228	14750	Economy	3200.00
0005435556682	14750	Economy	3200.00
0005435556680	14750	Economy	3200.00
0005434411715	14750	Economy	3200.00
0005435126209	14750	Economy	3200.00
0005435126206	14750	Economy	3200.00
0005435126205	14750	Economy	3200.00
0005435626102	14750	Economy	3200.00
0005434928273	14750	Economy	3200.00
0005435126229	14750	Economy	3200.00
0005435626096	14750	Economy	3200.00
0005435626098	14750	Economy	3200.00
0005435554166	14750	Economy	3200.00
0005435126221	14750	Economy	3200.00
0005432400105	7108	Business	86900.00
0005435715393	7108	Business	86900.00
0005435443177	7108	Business	86900.00
0005435219167	7108	Business	86900.00
0005435216565	7108	Business	86900.00
0005435443162	7108	Business	86900.00
0005435443186	7108	Business	86900.00
0005435715389	7108	Business	86900.00
0005435715391	7108	Economy	29000.00
0005432400108	7108	Economy	29000.00
0005432398180	7108	Economy	29000.00
0005435443153	7108	Economy	31900.00
0005435216553	7108	Economy	29000.00
0005435715392	7108	Economy	29000.00
0005435443216	7108	Economy	29000.00
0005432398183	7108	Economy	29000.00
0005435715397	7108	Economy	29000.00
0005435715405	7108	Economy	29000.00
0005432400107	7108	Economy	29000.00
0005435715400	7108	Economy	29000.00
0005432398181	7108	Economy	29000.00
0005435443219	7108	Economy	29000.00
0005435219174	7108	Economy	29000.00
0005435715398	7108	Economy	29000.00
0005435715390	7108	Economy	29000.00
0005435216554	7108	Economy	29000.00
0005435443179	7108	Economy	29000.00
0005435178470	7108	Economy	29000.00
0005432400106	7108	Economy	29000.00
0005435443248	7108	Economy	29000.00
0005435715395	7108	Economy	29000.00
0005435715404	7108	Economy	29000.00
0005435715399	7108	Economy	29000.00
0005435443249	7108	Economy	29000.00
0005435216564	7108	Economy	29000.00
0005435216559	7108	Economy	29000.00
0005432400109	7108	Economy	29000.00
0005435715403	7108	Economy	29000.00
0005435443178	7108	Economy	29000.00
0005432398185	7108	Economy	29000.00
0005435715396	7108	Economy	29000.00
0005435715402	7108	Economy	29000.00
0005432398182	7108	Economy	29000.00
0005432398184	7108	Economy	29000.00
0005435715394	7108	Economy	29000.00
0005435443217	7108	Economy	29000.00
0005435443227	7108	Economy	29000.00
0005435715401	7108	Economy	29000.00
0005435219180	7108	Economy	29000.00
0005435216566	7108	Economy	29000.00
0005432398151	27062	Business	86900.00
0005435715230	27062	Business	86900.00
0005435715219	27062	Business	86900.00
0005435715185	27062	Business	86900.00
0005435715202	27062	Business	86900.00
0005435715284	27062	Business	86900.00
0005435715268	27062	Economy	29000.00
0005432394047	27062	Economy	29000.00
0005432398146	27062	Economy	29000.00
0005432398136	27062	Economy	31900.00
0005435178990	27062	Economy	31900.00
0005435715215	27062	Economy	29000.00
0005435443272	27062	Economy	29000.00
0005435178489	27062	Economy	29000.00
0005435715231	27062	Economy	29000.00
0005432398141	27062	Economy	29000.00
0005435715285	27062	Economy	29000.00
0005432394059	27062	Economy	29000.00
0005435715248	27062	Economy	29000.00
0005435443278	27062	Economy	29000.00
0005432398140	27062	Economy	29000.00
0005435443276	27062	Economy	29000.00
0005435443277	27062	Economy	29000.00
0005435715205	27062	Economy	29000.00
0005432398139	27062	Economy	29000.00
0005435443270	27062	Economy	29000.00
0005435178490	27062	Economy	29000.00
0005435715325	27062	Economy	29000.00
0005435715289	27062	Economy	29000.00
0005435715203	27062	Economy	29000.00
0005435715186	27062	Economy	29000.00
0005435715246	27062	Economy	29000.00
0005435715209	27062	Economy	29000.00
0005435443271	27062	Economy	29000.00
0005435715220	27062	Economy	29000.00
0005435443269	27062	Economy	29000.00
0005435715247	27062	Economy	29000.00
0005435443273	27062	Economy	29000.00
0005435715210	27062	Economy	29000.00
0005435443275	27062	Economy	29000.00
0005435443274	27062	Economy	29000.00
0005434084912	2743	Economy	7700.00
0005434084910	2743	Economy	7700.00
0005434084914	2743	Economy	7700.00
0005433060385	2743	Economy	7700.00
0005434084913	2743	Economy	7700.00
0005434084911	2743	Economy	7700.00
0005433060386	2743	Economy	7700.00
0005433060402	28500	Economy	7700.00
0005434084865	28500	Economy	7700.00
0005434084871	28500	Economy	7700.00
0005434084866	28500	Economy	7700.00
0005432632698	25195	Economy	29000.00
0005432632697	25195	Economy	29000.00
0005432632689	25195	Economy	29000.00
0005432632695	25195	Economy	26400.00
0005432632703	25195	Economy	26400.00
0005432632691	25195	Economy	26400.00
0005432632684	25195	Economy	26400.00
0005432632694	25195	Economy	26400.00
0005432632690	25195	Economy	26400.00
0005432632699	25195	Economy	26400.00
0005432632685	25195	Economy	26400.00
0005432632692	25195	Economy	26400.00
0005432632701	25195	Economy	26400.00
0005435844260	25195	Economy	26400.00
0005432632696	25195	Economy	26400.00
0005432632704	25195	Economy	26400.00
0005432632688	25195	Economy	26400.00
0005432632693	25195	Economy	26400.00
0005432632700	25195	Economy	26400.00
0005435844261	25195	Economy	26400.00
0005432632702	25195	Economy	26400.00
0005432632705	25195	Economy	26400.00
0005432632686	25195	Economy	26400.00
0005432632687	25195	Economy	26400.00
0005432632626	28173	Economy	29000.00
0005435844305	28173	Economy	26400.00
0005432632645	28173	Economy	26400.00
0005432632625	28173	Economy	26400.00
0005435844300	28173	Economy	26400.00
0005435844309	28173	Economy	26400.00
0005435844306	28173	Economy	26400.00
0005432632637	28173	Economy	26400.00
0005432632639	28173	Economy	26400.00
0005432632622	28173	Economy	26400.00
0005435844312	28173	Economy	26400.00
0005435844304	28173	Economy	26400.00
0005432632653	28173	Economy	26400.00
0005435844301	28173	Economy	26400.00
0005432632654	28173	Economy	26400.00
0005435844310	28173	Economy	26400.00
0005432632638	28173	Economy	26400.00
0005435844307	28173	Economy	26400.00
0005435844303	28173	Economy	26400.00
0005435844308	28173	Economy	26400.00
0005432632628	28173	Economy	26400.00
0005435844311	28173	Economy	26400.00
0005432632621	28173	Economy	26400.00
0005432632642	28173	Economy	26400.00
0005435844302	28173	Economy	26400.00
0005435844299	28173	Economy	26400.00
0005432632630	28173	Economy	26400.00
0005432632646	28173	Economy	26400.00
0005435540849	11380	Business	20200.00
0005435517749	11380	Business	20200.00
0005435517664	11380	Business	20200.00
0005435540738	11380	Business	20200.00
0005435517677	11380	Business	20200.00
0005435540774	11380	Economy	6700.00
0005435517788	11380	Economy	6700.00
0005435517676	11380	Economy	6700.00
0005435540815	11380	Economy	6700.00
0005435540634	11380	Economy	6700.00
0005435540756	11380	Economy	7400.00
0005435540678	11380	Economy	7400.00
0005435517724	11380	Economy	6700.00
0005435540742	11380	Economy	6700.00
0005435540732	11380	Economy	6700.00
0005435540635	11380	Economy	6700.00
0005435540633	11380	Economy	6700.00
0005435517711	11380	Economy	6700.00
0005435540696	11380	Economy	6700.00
0005435517765	11380	Economy	6700.00
0005435540740	11380	Economy	6700.00
0005435540768	11380	Economy	6700.00
0005435517764	11380	Economy	6700.00
0005435517712	11380	Economy	6700.00
0005435540679	11380	Economy	6700.00
0005435540727	11380	Economy	6700.00
0005435517665	11380	Economy	6700.00
0005435517689	11380	Economy	6700.00
0005435517746	11380	Economy	6700.00
0005435517732	11380	Economy	6700.00
0005435540677	11380	Economy	6700.00
0005435540739	11380	Economy	6700.00
0005435517624	11380	Economy	6700.00
0005435540733	11380	Economy	6700.00
0005435517623	11380	Economy	6700.00
0005435540850	11380	Economy	6700.00
0005435517683	11380	Economy	6700.00
0005435529158	22247	Business	20200.00
0005432294474	22247	Business	20200.00
0005435540900	22247	Business	20200.00
0005435540909	22247	Economy	6700.00
0005435529160	22247	Economy	6700.00
0005435540910	22247	Economy	6700.00
0005435540906	22247	Economy	6700.00
0005435540891	22247	Economy	6700.00
0005435529157	22247	Economy	6700.00
0005435540896	22247	Economy	7400.00
0005435529153	22247	Economy	7400.00
0005435540890	22247	Economy	6700.00
0005435529162	22247	Economy	6700.00
0005435529152	22247	Economy	6700.00
0005435540902	22247	Economy	6700.00
0005432294475	22247	Economy	6700.00
0005435529163	22247	Economy	6700.00
0005432294476	22247	Economy	6700.00
0005435529147	22247	Economy	6700.00
0005435529148	22247	Economy	6700.00
0005435540897	22247	Economy	6700.00
0005435529145	22247	Economy	6700.00
0005435540892	22247	Economy	6700.00
0005435540903	22247	Economy	6700.00
0005435529150	22247	Economy	6700.00
0005435529164	22247	Economy	6700.00
0005435529159	22247	Economy	6700.00
0005435529161	22247	Economy	6700.00
0005435540907	22247	Economy	6700.00
0005435540898	22247	Economy	6700.00
0005435529151	22247	Economy	6700.00
0005435540899	22247	Economy	6700.00
0005435540888	22247	Economy	6700.00
0005435540905	22247	Economy	6700.00
0005435540904	22247	Economy	6700.00
0005435529166	22247	Economy	6700.00
0005435529144	22247	Economy	6700.00
0005435540895	22247	Economy	6700.00
0005435540893	22247	Economy	6700.00
0005435540889	22247	Economy	6700.00
0005435529165	22247	Economy	6700.00
0005435529149	22247	Economy	6700.00
0005435540901	22247	Economy	6700.00
0005435529154	22247	Economy	6700.00
0005435529146	22247	Economy	6700.00
0005435540908	22247	Economy	6700.00
0005435540894	22247	Economy	6700.00
0005435529156	22247	Economy	6700.00
0005435529155	22247	Economy	6700.00
0005433250945	2313	Business	20200.00
0005433250946	2313	Business	20200.00
0005433251148	2313	Business	20200.00
0005434907056	2313	Business	20200.00
0005433251106	2313	Business	20200.00
0005434907071	2313	Business	20200.00
0005434907074	2313	Business	20200.00
0005433251178	2313	Business	20200.00
0005434907075	2313	Business	20200.00
0005434907094	2313	Economy	6700.00
0005434907091	2313	Economy	6700.00
0005434907063	2313	Economy	6700.00
0005433251196	2313	Economy	6700.00
0005434907055	2313	Economy	6700.00
0005433251112	2313	Economy	6700.00
0005433251169	2313	Economy	6700.00
0005434907102	2313	Economy	6700.00
0005433400941	2313	Economy	6700.00
0005434907078	2313	Economy	7400.00
0005434907081	2313	Economy	7400.00
0005433251099	2313	Economy	7400.00
0005434907099	2313	Economy	7400.00
0005433400943	2313	Economy	7400.00
0005434907103	2313	Economy	6700.00
0005434907090	2313	Economy	6700.00
0005434907060	2313	Economy	6700.00
0005434907068	2313	Economy	6700.00
0005434907100	2313	Economy	6700.00
0005434907088	2313	Economy	6700.00
0005433251147	2313	Economy	6700.00
0005433250948	2313	Economy	6700.00
0005434907070	2313	Economy	6700.00
0005433250947	2313	Economy	6700.00
0005434907085	2313	Economy	6700.00
0005434907080	2313	Economy	6700.00
0005434907092	2313	Economy	6700.00
0005434907058	2313	Economy	6700.00
0005434907093	2313	Economy	6700.00
0005434907087	2313	Economy	6700.00
0005433251100	2313	Economy	6700.00
0005433251168	2313	Economy	6700.00
0005433251177	2313	Economy	6700.00
0005434907101	2313	Economy	6700.00
0005433400949	2313	Economy	6700.00
0005433251121	2313	Economy	6700.00
0005434907076	2313	Economy	6700.00
0005434907067	2313	Economy	6700.00
0005434907077	2313	Economy	6700.00
0005433400948	2313	Economy	6700.00
0005434907095	2313	Economy	6700.00
0005434907089	2313	Economy	6700.00
0005434907079	2313	Economy	6700.00
0005434907061	2313	Economy	6700.00
0005434907082	2313	Economy	6700.00
0005434907072	2313	Economy	6700.00
0005434907066	2313	Economy	6700.00
0005434907096	2313	Economy	6700.00
0005433251092	2313	Economy	6700.00
0005433251137	2313	Economy	6700.00
0005433251195	2313	Economy	6700.00
0005434907069	2313	Economy	6700.00
0005433251273	2313	Economy	6700.00
0005433251203	2313	Economy	6700.00
0005434907057	2313	Economy	6700.00
0005434907097	2313	Economy	6700.00
0005434907086	2313	Economy	6700.00
0005434907054	2313	Economy	6700.00
0005434907062	2313	Economy	6700.00
0005434907073	2313	Economy	6700.00
0005433251101	2313	Economy	6700.00
0005433251207	2313	Economy	6700.00
0005433251035	2313	Economy	6700.00
0005433400942	2313	Economy	6700.00
0005433251046	2313	Economy	6700.00
0005433251113	2313	Economy	6700.00
0005434907098	2313	Economy	6700.00
0005434907059	2313	Economy	6700.00
0005433250961	2313	Economy	6700.00
0005433251017	2313	Economy	6700.00
0005434907084	2313	Economy	6700.00
0005434907064	2313	Economy	6700.00
0005434907083	2313	Economy	6700.00
0005433251034	2313	Economy	6700.00
0005434907065	2313	Economy	6700.00
0005433250960	2313	Economy	6700.00
0005433251359	25577	Business	20200.00
0005433251344	25577	Business	20200.00
0005434906779	25577	Business	20200.00
0005434906487	25577	Business	20200.00
0005433251366	25577	Business	20200.00
0005434906580	25577	Business	20200.00
0005433251345	25577	Business	20200.00
0005433251367	25577	Business	20200.00
0005433251350	25577	Business	20200.00
0005433251362	25577	Business	20200.00
0005433251353	25577	Business	20200.00
0005433251342	25577	Business	20200.00
0005433251365	25577	Economy	6700.00
0005434906574	25577	Economy	6700.00
0005434906722	25577	Economy	6700.00
0005433251363	25577	Economy	6700.00
0005434906746	25577	Economy	6700.00
0005434906729	25577	Economy	6700.00
0005433251369	25577	Economy	6700.00
0005434906362	25577	Economy	6700.00
0005433251368	25577	Economy	6700.00
0005434906571	25577	Economy	6700.00
0005434906678	25577	Economy	7400.00
0005433251346	25577	Economy	7400.00
0005434906679	25577	Economy	7400.00
0005434906483	25577	Economy	7400.00
0005434906504	25577	Economy	7400.00
0005434906799	25577	Economy	6700.00
0005433251343	25577	Economy	6700.00
0005434906379	25577	Economy	6700.00
0005434906406	25577	Economy	6700.00
0005434906488	25577	Economy	6700.00
0005433251358	25577	Economy	6700.00
0005433251364	25577	Economy	6700.00
0005434906780	25577	Economy	6700.00
0005433251360	25577	Economy	6700.00
0005434906617	25577	Economy	6700.00
0005434906652	25577	Economy	6700.00
0005433251356	25577	Economy	6700.00
0005433251357	25577	Economy	6700.00
0005433251340	25577	Economy	6700.00
0005434906638	25577	Economy	6700.00
0005434906794	25577	Economy	6700.00
0005434906809	25577	Economy	6700.00
0005434906404	25577	Economy	6700.00
0005433251341	25577	Economy	6700.00
0005434906596	25577	Economy	6700.00
0005434906665	25577	Economy	6700.00
0005434906579	25577	Economy	6700.00
0005433251355	25577	Economy	6700.00
0005433251361	25577	Economy	6700.00
0005433251354	25577	Economy	6700.00
0005434906639	25577	Economy	6700.00
0005434906651	25577	Economy	6700.00
0005434906611	25577	Economy	6700.00
0005434906819	25577	Economy	6700.00
0005433251352	25577	Economy	6700.00
0005433400970	25577	Economy	6700.00
0005433251338	25577	Economy	6700.00
0005433251349	25577	Economy	6700.00
0005434906489	25577	Economy	6700.00
0005434906618	25577	Economy	6700.00
0005434906531	25577	Economy	6700.00
0005434906429	25577	Economy	6700.00
0005434906756	25577	Economy	6700.00
0005433251347	25577	Economy	6700.00
0005434906793	25577	Economy	6700.00
0005433251351	25577	Economy	6700.00
0005434906680	25577	Economy	6700.00
0005434906623	25577	Economy	6700.00
0005434906747	25577	Economy	6700.00
0005434906616	25577	Economy	6700.00
0005434906380	25577	Economy	6700.00
0005433400971	25577	Economy	6700.00
0005434906561	25577	Economy	6700.00
0005434906408	25577	Economy	6700.00
0005434906810	25577	Economy	6700.00
0005434906745	25577	Economy	6700.00
0005433400972	25577	Economy	6700.00
0005433251370	25577	Economy	6700.00
0005434906405	25577	Economy	6700.00
0005433251348	25577	Economy	6700.00
0005434906728	25577	Economy	6700.00
0005433251339	25577	Economy	6700.00
0005434906494	25577	Economy	6700.00
0005434906578	25577	Economy	6700.00
0005434906557	25577	Economy	6700.00
0005434906564	25577	Economy	6700.00
0005434906430	25577	Economy	6700.00
0005434906361	25577	Economy	6700.00
0005434906501	25577	Economy	6700.00
0005432620978	2502	Economy	13600.00
0005432620975	2502	Economy	12400.00
0005432620980	2502	Economy	12400.00
0005432620984	2502	Economy	12400.00
0005432862226	2502	Economy	12400.00
0005432862197	2502	Economy	12400.00
0005432862225	2502	Economy	12400.00
0005432620977	2502	Economy	12400.00
0005432620985	2502	Economy	12400.00
0005432620979	2502	Economy	12400.00
0005432862190	2502	Economy	12400.00
0005432862224	2502	Economy	12400.00
0005432620981	2502	Economy	12400.00
0005432862208	2502	Economy	12400.00
0005432862196	2502	Economy	12400.00
0005432620974	2502	Economy	12400.00
0005432620986	2502	Economy	12400.00
0005432620982	2502	Economy	12400.00
0005432620976	2502	Economy	12400.00
0005432620987	2502	Economy	12400.00
0005432620988	2502	Economy	12400.00
0005432620983	2502	Economy	12400.00
0005432862205	2502	Economy	12400.00
0005432862268	28036	Economy	13600.00
0005432620806	28036	Economy	13600.00
0005432620886	28036	Economy	12400.00
0005432620850	28036	Economy	12400.00
0005432862269	28036	Economy	12400.00
0005432620885	28036	Economy	12400.00
0005432620884	28036	Economy	12400.00
0005432862273	28036	Economy	12400.00
0005432620865	28036	Economy	12400.00
0005432862272	28036	Economy	12400.00
0005432620871	28036	Economy	12400.00
0005432620887	28036	Economy	12400.00
0005432862271	28036	Economy	12400.00
0005432862270	28036	Economy	12400.00
0005434097457	11711	Economy	11300.00
0005434097465	11711	Economy	11300.00
0005434097461	11711	Economy	11300.00
0005434097463	11711	Economy	11300.00
0005434097462	11711	Economy	11300.00
0005434097471	13016	Economy	11300.00
0005434097470	13016	Economy	11300.00
0005434191272	28026	Business	89600.00
0005434191266	28026	Economy	29900.00
0005434191262	28026	Economy	29900.00
0005434191271	28026	Economy	29900.00
0005434191267	28026	Economy	29900.00
0005434191269	28026	Economy	29900.00
0005434191265	28026	Economy	29900.00
0005434191263	28026	Economy	29900.00
0005434191273	28026	Economy	29900.00
0005434191264	28026	Economy	29900.00
0005434191270	28026	Economy	29900.00
0005434191268	28026	Economy	29900.00
0005433451610	30987	Economy	8400.00
0005433452730	30987	Economy	8400.00
0005433452732	30987	Economy	8400.00
0005433452731	30987	Economy	8400.00
0005433451612	30987	Economy	8400.00
0005433451611	30987	Economy	8400.00
0005433452729	30987	Economy	8400.00
0005433452702	31399	Economy	8400.00
0005433452708	31399	Economy	8400.00
0005433452709	31399	Economy	8400.00
0005433452711	31399	Economy	8400.00
0005433454842	31399	Economy	8400.00
0005433452703	31399	Economy	8400.00
0005433452710	31399	Economy	8400.00
0005433454841	31399	Economy	8400.00
0005433454847	31399	Economy	8400.00
0005433129226	12011	Economy	7200.00
0005434184634	12011	Economy	6600.00
0005433129203	12011	Economy	6600.00
0005433129215	12011	Economy	6600.00
0005433134084	12011	Economy	6600.00
0005433129235	12011	Economy	6600.00
0005434184635	12011	Economy	6600.00
0005433129221	12011	Economy	6600.00
0005433134083	12011	Economy	6600.00
0005434142565	12011	Economy	6600.00
0005433129227	12011	Economy	6600.00
0005433129199	12011	Economy	6600.00
0005433129234	12011	Economy	6600.00
0005433129228	12011	Economy	6600.00
0005434142547	12011	Economy	6600.00
0005433129237	12011	Economy	6600.00
0005433134082	12011	Economy	6600.00
0005434142561	12011	Economy	6600.00
0005434142572	12011	Economy	6600.00
0005433129222	12011	Economy	6600.00
0005433129198	12011	Economy	6600.00
0005434142573	12011	Economy	6600.00
0005434142591	29831	Economy	7200.00
0005434142590	29831	Economy	6600.00
0005433134120	29831	Economy	6600.00
0005434184657	29831	Economy	6600.00
0005433131688	29831	Economy	6600.00
0005434183571	29831	Economy	6600.00
0005434142589	29831	Economy	6600.00
0005434183572	29831	Economy	6600.00
0005433131691	29831	Economy	6600.00
0005433131689	29831	Economy	6600.00
0005434184656	29831	Economy	6600.00
0005433131690	29831	Economy	6600.00
0005433134121	29831	Economy	6600.00
0005434184658	29831	Economy	6600.00
0005433134117	29831	Economy	6600.00
0005433134119	29831	Economy	6600.00
0005433131687	29831	Economy	6600.00
0005434142592	29831	Economy	6600.00
0005433134118	29831	Economy	6600.00
0005435697199	16493	Economy	19900.00
0005435697188	16493	Economy	19900.00
0005435697205	16493	Economy	19900.00
0005435697216	16493	Economy	18100.00
0005435697208	16493	Economy	18100.00
0005435697204	16493	Economy	18100.00
0005435697201	16493	Economy	18100.00
0005435697211	16493	Economy	18100.00
0005435697196	16493	Economy	18100.00
0005435697190	16493	Economy	18100.00
0005435697210	16493	Economy	18100.00
0005435697198	16493	Economy	18100.00
0005435697192	16493	Economy	18100.00
0005435697203	16493	Economy	18100.00
0005435697197	16493	Economy	18100.00
0005435697206	16493	Economy	18100.00
0005435697189	16493	Economy	18100.00
0005435697195	16493	Economy	18100.00
0005435697191	16493	Economy	18100.00
0005435697209	16493	Economy	18100.00
0005435697193	16493	Economy	18100.00
0005435697212	16493	Economy	18100.00
0005435697214	16493	Economy	18100.00
0005435697194	16493	Economy	18100.00
0005435697200	16493	Economy	18100.00
0005435697207	16493	Economy	18100.00
0005435697213	16493	Economy	18100.00
0005435697215	16493	Economy	18100.00
0005435935006	16493	Economy	18100.00
0005435697202	16493	Economy	18100.00
0005435696980	24692	Economy	19900.00
0005435696981	24692	Economy	19900.00
0005435696929	24692	Economy	19900.00
0005435696917	24692	Economy	18100.00
0005435696971	24692	Economy	18100.00
0005435697110	24692	Economy	18100.00
0005435696939	24692	Economy	18100.00
0005435697091	24692	Economy	18100.00
0005435935032	24692	Economy	18100.00
0005435696862	24692	Economy	18100.00
0005435935031	24692	Economy	18100.00
0005435696982	24692	Economy	18100.00
0005435935030	24692	Economy	18100.00
0005435696972	24692	Economy	18100.00
0005435696901	24692	Economy	18100.00
0005435697083	24692	Economy	18100.00
0005435696979	24692	Economy	18100.00
0005435696863	24692	Economy	18100.00
0005435697076	24692	Economy	18100.00
0005435697109	24692	Economy	18100.00
0005435697006	24692	Economy	18100.00
0005435697075	24692	Economy	18100.00
0005435697067	24692	Economy	18100.00
0005435697086	24692	Economy	18100.00
0005433724783	18766	Economy	4400.00
0005433724782	18766	Economy	4400.00
0005432968805	18766	Economy	4400.00
0005432968804	18766	Economy	4400.00
0005432968809	18766	Economy	4400.00
0005432968808	18766	Economy	4400.00
0005433724784	18766	Economy	4400.00
0005433724786	18766	Economy	4400.00
0005433724785	18766	Economy	4400.00
0005433724731	21645	Economy	4400.00
0005432968832	21645	Economy	4400.00
0005433724752	21645	Economy	4400.00
0005433724751	21645	Economy	4400.00
0005433724753	21645	Economy	4400.00
0005432968833	21645	Economy	4400.00
0005433724754	21645	Economy	4400.00
0005434137860	7311	Business	23100.00
0005434137798	7311	Business	23100.00
0005434137870	7311	Business	23100.00
0005434137846	7311	Business	23100.00
0005434137845	7311	Business	23100.00
0005434137865	7311	Business	23100.00
0005434137820	7311	Business	23100.00
0005434137833	7311	Business	23100.00
0005434137832	7311	Business	23100.00
0005434137859	7311	Business	23100.00
0005434137799	7311	Business	23100.00
0005434137817	7311	Business	23100.00
0005434137850	7311	Economy	7700.00
0005434137807	7311	Economy	7700.00
0005434137797	7311	Economy	7700.00
0005434137806	7311	Economy	7700.00
0005434087493	7311	Economy	7700.00
0005434137855	7311	Economy	7700.00
0005434137794	7311	Economy	7700.00
0005434137862	7311	Economy	7700.00
0005434137813	7311	Economy	7700.00
0005434137834	7311	Economy	8500.00
0005434137801	7311	Economy	8500.00
0005434137809	7311	Economy	8500.00
0005434137808	7311	Economy	8500.00
0005434137867	7311	Economy	8500.00
0005434087491	7311	Economy	7700.00
0005434137786	7311	Economy	7700.00
0005434137819	7311	Economy	7700.00
0005434137803	7311	Economy	7700.00
0005434087495	7311	Economy	7700.00
0005434137785	7311	Economy	7700.00
0005434137792	7311	Economy	7700.00
0005434137868	7311	Economy	7700.00
0005434137804	7311	Economy	7700.00
0005434137790	7311	Economy	7700.00
0005434137837	7311	Economy	7700.00
0005434137811	7311	Economy	7700.00
0005434137821	7311	Economy	7700.00
0005434137826	7311	Economy	7700.00
0005434137852	7311	Economy	7700.00
0005434137829	7311	Economy	7700.00
0005434137842	7311	Economy	7700.00
0005434087494	7311	Economy	7700.00
0005434137800	7311	Economy	7700.00
0005434137843	7311	Economy	7700.00
0005434137824	7311	Economy	7700.00
0005434137793	7311	Economy	7700.00
0005434137840	7311	Economy	7700.00
0005434137823	7311	Economy	7700.00
0005434137858	7311	Economy	7700.00
0005434137815	7311	Economy	7700.00
0005434137848	7311	Economy	7700.00
0005434137866	7311	Economy	7700.00
0005434137851	7311	Economy	7700.00
0005434137818	7311	Economy	7700.00
0005434137789	7311	Economy	7700.00
0005434137795	7311	Economy	7700.00
0005434137812	7311	Economy	7700.00
0005434137791	7311	Economy	7700.00
0005434137805	7311	Economy	7700.00
0005434137788	7311	Economy	7700.00
0005434137825	7311	Economy	7700.00
0005434137816	7311	Economy	7700.00
0005434137787	7311	Economy	7700.00
0005434137856	7311	Economy	7700.00
0005434137838	7311	Economy	7700.00
0005434137869	7311	Economy	7700.00
0005434137835	7311	Economy	7700.00
0005434137853	7311	Economy	7700.00
0005434137864	7311	Economy	7700.00
0005434137847	7311	Economy	7700.00
0005434137844	7311	Economy	7700.00
0005434137836	7311	Economy	7700.00
0005434137861	7311	Economy	7700.00
0005434137841	7311	Economy	7700.00
0005434137863	7311	Economy	7700.00
0005434137839	7311	Economy	7700.00
0005434137830	7311	Economy	7700.00
0005434137857	7311	Economy	7700.00
0005434137822	7311	Economy	7700.00
0005434137796	7311	Economy	7700.00
0005434137849	7311	Economy	7700.00
0005434137810	7311	Economy	7700.00
0005434137828	7311	Economy	7700.00
0005434137827	7311	Economy	7700.00
0005434137854	7311	Economy	7700.00
0005434087492	7311	Economy	7700.00
0005434137814	7311	Economy	7700.00
0005434137831	7311	Economy	7700.00
0005434137802	7311	Economy	7700.00
0005434136789	28570	Business	23100.00
0005434136790	28570	Business	23100.00
0005434137020	28570	Business	23100.00
0005434136954	28570	Business	23100.00
0005434136782	28570	Business	23100.00
0005434136774	28570	Business	23100.00
0005434136759	28570	Business	23100.00
0005434137055	28570	Business	23100.00
0005434087464	28570	Business	23100.00
0005434137175	28570	Business	23100.00
0005434087449	28570	Business	23100.00
0005434137180	28570	Business	23100.00
0005434137236	28570	Economy	7700.00
0005434137137	28570	Economy	7700.00
0005434136784	28570	Economy	7700.00
0005434137136	28570	Economy	7700.00
0005434136985	28570	Economy	7700.00
0005434087456	28570	Economy	7700.00
0005434137161	28570	Economy	7700.00
0005434136892	28570	Economy	7700.00
0005434087457	28570	Economy	8500.00
0005434137172	28570	Economy	8500.00
0005434136991	28570	Economy	8500.00
0005434136996	28570	Economy	8500.00
0005434136820	28570	Economy	7700.00
0005434137163	28570	Economy	7700.00
0005434136987	28570	Economy	7700.00
0005434137162	28570	Economy	7700.00
0005434087438	28570	Economy	7700.00
0005434136990	28570	Economy	7700.00
0005434137125	28570	Economy	7700.00
0005434137126	28570	Economy	7700.00
0005434137083	28570	Economy	7700.00
0005434136685	28570	Economy	7700.00
0005434137293	28570	Economy	7700.00
0005434136696	28570	Economy	7700.00
0005434137092	28570	Economy	7700.00
0005434136695	28570	Economy	7700.00
0005434137084	28570	Economy	7700.00
0005434087443	28570	Economy	7700.00
0005434137047	28570	Economy	7700.00
0005434136901	28570	Economy	7700.00
0005434137207	28570	Economy	7700.00
0005434137292	28570	Economy	7700.00
0005434087439	28570	Economy	7700.00
0005434137160	28570	Economy	7700.00
0005434136952	28570	Economy	7700.00
0005434137085	28570	Economy	7700.00
0005434136775	28570	Economy	7700.00
0005434136847	28570	Economy	7700.00
0005434136858	28570	Economy	7700.00
0005434136926	28570	Economy	7700.00
0005434136705	28570	Economy	7700.00
0005434137200	28570	Economy	7700.00
0005434136697	28570	Economy	7700.00
0005434136833	28570	Economy	7700.00
0005434136997	28570	Economy	7700.00
0005434137145	28570	Economy	7700.00
0005434137308	28570	Economy	7700.00
0005434137174	28570	Economy	7700.00
0005434136986	28570	Economy	7700.00
0005434136953	28570	Economy	7700.00
0005434137190	28570	Economy	7700.00
0005434137173	28570	Economy	7700.00
0005434087454	28570	Economy	7700.00
0005434137019	28570	Economy	7700.00
0005434136989	28570	Economy	7700.00
0005434137029	28570	Economy	7700.00
0005434136694	28570	Economy	7700.00
0005434087448	28570	Economy	7700.00
0005434137252	28570	Economy	7700.00
0005434137102	28570	Economy	7700.00
0005434136794	28570	Economy	7700.00
0005434136824	28570	Economy	7700.00
0005434136972	28570	Economy	7700.00
0005434136971	28570	Economy	7700.00
0005434136927	28570	Economy	7700.00
0005434137171	28570	Economy	7700.00
0005434136939	28570	Economy	7700.00
0005434137211	28570	Economy	7700.00
0005434137022	28570	Economy	7700.00
0005434137201	28570	Economy	7700.00
0005434136706	28570	Economy	7700.00
0005434087463	28570	Economy	7700.00
0005434136951	28570	Economy	7700.00
0005434136923	28570	Economy	7700.00
0005434137251	28570	Economy	7700.00
0005434136795	28570	Economy	7700.00
0005434087455	28570	Economy	7700.00
0005435808191	1914	Economy	21700.00
0005435808198	1914	Economy	21700.00
0005433407482	1914	Economy	21700.00
0005434610213	1914	Economy	21700.00
0005435808197	1914	Economy	21700.00
0005435808190	1914	Economy	21700.00
0005434610214	1914	Economy	21700.00
0005433407491	1914	Economy	21700.00
0005435808193	1914	Economy	21700.00
0005435808189	1914	Economy	21700.00
0005434610215	1914	Economy	21700.00
0005435808199	1914	Economy	21700.00
0005435808192	1914	Economy	21700.00
0005435808195	1914	Economy	21700.00
0005435808188	1914	Economy	21700.00
0005435808196	1914	Economy	21700.00
0005435808194	1914	Economy	21700.00
0005434610188	23103	Economy	23900.00
0005434610185	23103	Economy	21700.00
0005434610187	23103	Economy	21700.00
0005434610186	23103	Economy	21700.00
0005434610178	23103	Economy	21700.00
0005434610189	23103	Economy	21700.00
0005434610179	23103	Economy	21700.00
0005434503518	16708	Economy	7600.00
0005434503601	16708	Economy	7600.00
0005434503672	16708	Economy	7600.00
0005434503596	16708	Economy	6900.00
0005434503552	16708	Economy	6900.00
0005434503861	16708	Economy	6900.00
0005434503860	16708	Economy	6900.00
0005434503467	16708	Economy	6900.00
0005434503764	16708	Economy	6900.00
0005434503588	16708	Economy	6900.00
0005434503671	16708	Economy	6900.00
0005434503553	16708	Economy	6900.00
0005434503511	16708	Economy	6900.00
0005434503641	16708	Economy	6900.00
0005434503590	16708	Economy	6900.00
0005434503618	16708	Economy	6900.00
0005434503479	16708	Economy	6900.00
0005434503475	16708	Economy	6900.00
0005434503459	16708	Economy	6900.00
0005434503722	16708	Economy	6900.00
0005434503519	16708	Economy	6900.00
0005434503510	16708	Economy	6900.00
0005434503721	16708	Economy	6900.00
0005434503664	16708	Economy	6900.00
0005434503637	16708	Economy	6900.00
0005434503695	16708	Economy	6900.00
0005434503599	16708	Economy	6900.00
0005434503600	16708	Economy	6900.00
0005434503460	16708	Economy	6900.00
0005434503567	16708	Economy	6900.00
0005434503762	16708	Economy	6900.00
0005434503474	16708	Economy	6900.00
0005434503468	16708	Economy	6900.00
0005434503785	16708	Economy	6900.00
0005434503481	16708	Economy	6900.00
0005434503707	16708	Economy	6900.00
0005434503688	16708	Economy	6900.00
0005434503692	16708	Economy	6900.00
0005434503765	16708	Economy	6900.00
0005434503648	16708	Economy	6900.00
0005434503612	16708	Economy	6900.00
0005434503484	16708	Economy	6900.00
0005434503626	16708	Economy	6900.00
0005434503621	16708	Economy	6900.00
0005434503480	16708	Economy	6900.00
0005434503642	16708	Economy	6900.00
0005434503602	16708	Economy	6900.00
0005434503959	22923	Economy	7600.00
0005434503956	22923	Economy	7600.00
0005434503975	22923	Economy	7600.00
0005434503976	22923	Economy	6900.00
0005434503957	22923	Economy	6900.00
0005434503946	22923	Economy	6900.00
0005434503954	22923	Economy	6900.00
0005434503945	22923	Economy	6900.00
0005434503966	22923	Economy	6900.00
0005434503970	22923	Economy	6900.00
0005434503969	22923	Economy	6900.00
0005434503962	22923	Economy	6900.00
0005434503978	22923	Economy	6900.00
0005434503941	22923	Economy	6900.00
0005434503980	22923	Economy	6900.00
0005434503949	22923	Economy	6900.00
0005434503965	22923	Economy	6900.00
0005434503955	22923	Economy	6900.00
0005434503948	22923	Economy	6900.00
0005434503981	22923	Economy	6900.00
0005434503974	22923	Economy	6900.00
0005434503953	22923	Economy	6900.00
0005434503968	22923	Economy	6900.00
0005434503973	22923	Economy	6900.00
0005434503942	22923	Economy	6900.00
0005434503943	22923	Economy	6900.00
0005434503944	22923	Economy	6900.00
0005434503972	22923	Economy	6900.00
0005434503958	22923	Economy	6900.00
0005434503977	22923	Economy	6900.00
0005434503950	22923	Economy	6900.00
0005434503952	22923	Economy	6900.00
0005434503967	22923	Economy	6900.00
0005434503979	22923	Economy	6900.00
0005434503940	22923	Economy	6900.00
0005434503960	22923	Economy	6900.00
0005434503951	22923	Economy	6900.00
0005434503947	22923	Economy	6900.00
0005434503963	22923	Economy	6900.00
0005434503961	22923	Economy	6900.00
0005434503964	22923	Economy	6900.00
0005434503971	22923	Economy	6900.00
0005435078276	2173	Economy	7700.00
0005433266580	2173	Economy	7000.00
0005435078279	2173	Economy	7000.00
0005435078274	2173	Economy	7000.00
0005435078280	2173	Economy	7000.00
0005435078283	2173	Economy	7000.00
0005433266567	2173	Economy	7000.00
0005435078286	2173	Economy	7000.00
0005435078278	2173	Economy	7000.00
0005433266609	2173	Economy	7000.00
0005435078275	2173	Economy	7000.00
0005433266626	2173	Economy	7000.00
0005433266625	2173	Economy	7000.00
0005435078277	2173	Economy	7000.00
0005435078272	2173	Economy	7000.00
0005433266603	2173	Economy	7000.00
0005435078285	2173	Economy	7000.00
0005433266579	2173	Economy	7000.00
0005435078282	2173	Economy	7000.00
0005435078273	2173	Economy	7000.00
0005435078284	2173	Economy	7000.00
0005435078281	2173	Economy	7000.00
0005435078154	24327	Economy	7700.00
0005435078196	24327	Economy	7000.00
0005435078090	24327	Economy	7000.00
0005433266685	24327	Economy	7000.00
0005433266684	24327	Economy	7000.00
0005435078111	24327	Economy	7000.00
0005435078159	24327	Economy	7000.00
0005435078116	24327	Economy	7000.00
0005433266683	24327	Economy	7000.00
0005433266686	24327	Economy	7000.00
0005433266687	24327	Economy	7000.00
0005433266688	24327	Economy	7000.00
0005433266689	24327	Economy	7000.00
0005433266681	24327	Economy	7000.00
0005435078176	24327	Economy	7000.00
0005435078197	24327	Economy	7000.00
0005435078100	24327	Economy	7000.00
0005435078113	24327	Economy	7000.00
0005435078115	24327	Economy	7000.00
0005435078112	24327	Economy	7000.00
0005435078137	24327	Economy	7000.00
0005435078104	24327	Economy	7000.00
0005435078110	24327	Economy	7000.00
0005433266682	24327	Economy	7000.00
0005434988700	6646	Economy	10800.00
0005434988692	6646	Economy	9800.00
0005434988701	6646	Economy	9800.00
0005434988698	6646	Economy	9800.00
0005435803253	6646	Economy	9800.00
0005434988696	6646	Economy	9800.00
0005434988699	6646	Economy	9800.00
0005434988690	6646	Economy	9800.00
0005434988691	6646	Economy	9800.00
0005434988693	6646	Economy	9800.00
0005434988697	6646	Economy	9800.00
0005434988694	6646	Economy	9800.00
0005434988695	6646	Economy	9800.00
0005435803252	6646	Economy	9800.00
0005434988575	23645	Economy	10800.00
0005434988584	23645	Economy	10800.00
0005435803222	23645	Economy	10800.00
0005434988557	23645	Economy	10800.00
0005435464498	23645	Economy	9800.00
0005434988582	23645	Economy	9800.00
0005434988587	23645	Economy	9800.00
0005434988597	23645	Economy	9800.00
0005434988586	23645	Economy	9800.00
0005435464500	23645	Economy	9800.00
0005434988594	23645	Economy	9800.00
0005435803231	23645	Economy	9800.00
0005435464499	23645	Economy	9800.00
0005435803229	23645	Economy	9800.00
0005434988571	23645	Economy	9800.00
0005434988598	23645	Economy	9800.00
0005434988576	23645	Economy	9800.00
0005434988585	23645	Economy	9800.00
0005434988570	23645	Economy	9800.00
0005434988583	23645	Economy	9800.00
0005432383033	30497	Business	9900.00
0005432383018	30497	Business	9900.00
0005433453755	30497	Business	9900.00
0005432383045	30497	Business	9900.00
0005432383014	30497	Business	9900.00
0005433449893	30497	Business	9900.00
0005433449890	30497	Business	9900.00
0005432383020	30497	Business	9900.00
0005432383038	30497	Business	9900.00
0005432383035	30497	Economy	3300.00
0005433454869	30497	Economy	3300.00
0005433449885	30497	Economy	3300.00
0005432383036	30497	Economy	3300.00
0005433449891	30497	Economy	3300.00
0005432383015	30497	Economy	3300.00
0005432383056	30497	Economy	3300.00
0005432383034	30497	Economy	3600.00
0005432383050	30497	Economy	3600.00
0005432383030	30497	Economy	3600.00
0005432383016	30497	Economy	3300.00
0005433449874	30497	Economy	3300.00
0005433449878	30497	Economy	3300.00
0005433449886	30497	Economy	3300.00
0005433449873	30497	Economy	3300.00
0005433449879	30497	Economy	3300.00
0005433449889	30497	Economy	3300.00
0005433449875	30497	Economy	3300.00
0005432383031	30497	Economy	3300.00
0005432383027	30497	Economy	3300.00
0005432383042	30497	Economy	3300.00
0005433449877	30497	Economy	3300.00
0005433454868	30497	Economy	3300.00
0005432383044	30497	Economy	3300.00
0005433449888	30497	Economy	3300.00
0005432383054	30497	Economy	3300.00
0005432383029	30497	Economy	3300.00
0005433449880	30497	Economy	3300.00
0005432383017	30497	Economy	3300.00
0005433449892	30497	Economy	3300.00
0005432383023	30497	Economy	3300.00
0005432383053	30497	Economy	3300.00
0005432383026	30497	Economy	3300.00
0005432383013	30497	Economy	3300.00
0005432383019	30497	Economy	3300.00
0005432383028	30497	Economy	3300.00
0005433449884	30497	Economy	3300.00
0005433449876	30497	Economy	3300.00
0005432383051	30497	Economy	3300.00
0005432383041	30497	Economy	3300.00
0005432383049	30497	Economy	3300.00
0005432383032	30497	Economy	3300.00
0005432383047	30497	Economy	3300.00
0005432383043	30497	Economy	3300.00
0005432383048	30497	Economy	3300.00
0005433449882	30497	Economy	3300.00
0005433449881	30497	Economy	3300.00
0005432383039	30497	Economy	3300.00
0005433449894	30497	Economy	3300.00
0005432383055	30497	Economy	3300.00
0005433454867	30497	Economy	3300.00
0005432383024	30497	Economy	3300.00
0005432383021	30497	Economy	3300.00
0005433449887	30497	Economy	3300.00
0005432383025	30497	Economy	3300.00
0005432383046	30497	Economy	3300.00
0005432383040	30497	Economy	3300.00
0005432383037	30497	Economy	3300.00
0005433453756	30497	Economy	3300.00
0005433453757	30497	Economy	3300.00
0005432383022	30497	Economy	3300.00
0005432383052	30497	Economy	3300.00
0005433449883	30497	Economy	3300.00
0005432382505	31317	Business	9900.00
0005432382680	31317	Business	9900.00
0005432382662	31317	Business	9900.00
0005432382655	31317	Business	9900.00
0005433449764	31317	Business	9900.00
0005432382613	31317	Business	9900.00
0005433449699	31317	Business	9900.00
0005432382601	31317	Business	9900.00
0005433449690	31317	Economy	3300.00
0005432382738	31317	Economy	3300.00
0005432382656	31317	Economy	3300.00
0005432382645	31317	Economy	3300.00
0005432382523	31317	Economy	3300.00
0005432382898	31317	Economy	3300.00
0005433449715	31317	Economy	3300.00
0005432382899	31317	Economy	3300.00
0005432382595	31317	Economy	3300.00
0005433451594	31317	Economy	3300.00
0005433449736	31317	Economy	3600.00
0005433449684	31317	Economy	3600.00
0005432382651	31317	Economy	3600.00
0005433449662	31317	Economy	3600.00
0005433449689	31317	Economy	3300.00
0005432382637	31317	Economy	3300.00
0005432382657	31317	Economy	3300.00
0005432382624	31317	Economy	3300.00
0005432382708	31317	Economy	3300.00
0005432382619	31317	Economy	3300.00
0005433449663	31317	Economy	3300.00
0005432382495	31317	Economy	3300.00
0005432382525	31317	Economy	3300.00
0005432382496	31317	Economy	3300.00
0005433449686	31317	Economy	3300.00
0005433451595	31317	Economy	3300.00
0005433453733	31317	Economy	3300.00
0005432382600	31317	Economy	3300.00
0005432382654	31317	Economy	3300.00
0005433453734	31317	Economy	3300.00
0005433449647	31317	Economy	3300.00
0005432382712	31317	Economy	3300.00
0005432382776	31317	Economy	3300.00
0005433449730	31317	Economy	3300.00
0005433449713	31317	Economy	3300.00
0005432382644	31317	Economy	3300.00
0005432382579	31317	Economy	3300.00
0005433449714	31317	Economy	3300.00
0005432382625	31317	Economy	3300.00
0005433449706	31317	Economy	3300.00
0005433449589	31317	Economy	3300.00
0005433451596	31317	Economy	3300.00
0005432382711	31317	Economy	3300.00
0005432382580	31317	Economy	3300.00
0005432382535	31317	Economy	3300.00
0005432382614	31317	Economy	3300.00
0005433449698	31317	Economy	3300.00
0005432382534	31317	Economy	3300.00
0005433449702	31317	Economy	3300.00
0005433449716	31317	Economy	3300.00
0005432382681	31317	Economy	3300.00
0005433449700	31317	Economy	3300.00
0005432382596	31317	Economy	3300.00
0005432382784	31317	Economy	3300.00
0005432382629	31317	Economy	3300.00
0005433453735	31317	Economy	3300.00
0005433449679	31317	Economy	3300.00
0005433449685	31317	Economy	3300.00
0005432382500	31317	Economy	3300.00
0005433449795	31317	Economy	3300.00
0005432382636	31317	Economy	3300.00
0005433449727	31317	Economy	3300.00
0005432382618	31317	Economy	3300.00
0005432382661	31317	Economy	3300.00
0005433449697	31317	Economy	3300.00
0005432382673	31317	Economy	3300.00
0005435548481	26469	Economy	23800.00
0005435548474	26469	Economy	23800.00
0005435548480	26469	Economy	23800.00
0005435548475	26469	Economy	23800.00
0005433788146	26469	Economy	23800.00
0005435548483	26469	Economy	23800.00
0005435548477	26469	Economy	23800.00
0005435548479	26469	Economy	23800.00
0005435548482	26469	Economy	23800.00
0005433788145	26469	Economy	23800.00
0005435548476	26469	Economy	23800.00
0005433788147	26469	Economy	23800.00
0005435548478	26469	Economy	23800.00
0005435304116	10760	Economy	17100.00
0005435299710	10760	Economy	17100.00
0005435299704	10760	Economy	15600.00
0005435304106	10760	Economy	15600.00
0005435304105	10760	Economy	15600.00
0005433131635	10760	Economy	15600.00
0005433131639	10760	Economy	15600.00
0005435299707	10760	Economy	15600.00
0005433126832	29709	Economy	17100.00
0005433129262	29709	Economy	17100.00
0005435299759	29709	Economy	15600.00
0005433126833	29709	Economy	15600.00
0005433126830	29709	Economy	15600.00
0005435302185	29709	Economy	15600.00
0005435299762	29709	Economy	15600.00
0005433129261	29709	Economy	15600.00
0005435299761	29709	Economy	15600.00
0005433126834	29709	Economy	15600.00
0005435302186	29709	Economy	15600.00
0005433129260	29709	Economy	15600.00
0005435299760	29709	Economy	15600.00
0005435299763	29709	Economy	15600.00
0005433129263	29709	Economy	15600.00
0005433126829	29709	Economy	15600.00
0005435302188	29709	Economy	15600.00
0005433126831	29709	Economy	15600.00
0005435302187	29709	Economy	15600.00
0005434287210	2391	Economy	17200.00
0005433109880	2391	Economy	17200.00
0005434287189	2391	Economy	17200.00
0005434287198	2391	Economy	17200.00
0005433109908	2391	Economy	15700.00
0005433109890	2391	Economy	15700.00
0005432264464	2391	Economy	15700.00
0005434287194	2391	Economy	15700.00
0005434287200	2391	Economy	15700.00
0005434287206	2391	Economy	15700.00
0005434287197	2391	Economy	15700.00
0005434287208	2391	Economy	15700.00
0005434287209	2391	Economy	15700.00
0005432264466	2391	Economy	15700.00
0005433109922	2391	Economy	15700.00
0005433109883	2391	Economy	15700.00
0005433109907	2391	Economy	15700.00
0005434287196	2391	Economy	15700.00
0005434287188	2391	Economy	15700.00
0005434287199	2391	Economy	15700.00
0005434287201	2391	Economy	15700.00
0005432264465	2391	Economy	15700.00
0005434287203	2391	Economy	15700.00
0005433109951	2391	Economy	15700.00
0005434287191	2391	Economy	15700.00
0005434287195	2391	Economy	15700.00
0005434287193	2391	Economy	15700.00
0005433109881	2391	Economy	15700.00
0005433109854	2391	Economy	15700.00
0005434287205	2391	Economy	15700.00
0005433109921	2391	Economy	15700.00
0005433109912	2391	Economy	15700.00
0005433109882	2391	Economy	15700.00
0005434287202	2391	Economy	15700.00
0005433109927	2391	Economy	15700.00
0005433109913	2391	Economy	15700.00
0005433109870	2391	Economy	15700.00
0005434287204	2391	Economy	15700.00
0005433109903	2391	Economy	15700.00
0005434287192	2391	Economy	15700.00
0005434287190	2391	Economy	15700.00
0005433109872	2391	Economy	15700.00
0005434287207	2391	Economy	15700.00
0005433109853	2391	Economy	15700.00
0005433110002	26873	Economy	17200.00
0005433110000	26873	Economy	17200.00
0005434286977	26873	Economy	17200.00
0005433110008	26873	Economy	17200.00
0005434286930	26873	Economy	15700.00
0005433109998	26873	Economy	15700.00
0005434287025	26873	Economy	15700.00
0005433110004	26873	Economy	15700.00
0005434286946	26873	Economy	15700.00
0005433109999	26873	Economy	15700.00
0005434287006	26873	Economy	15700.00
0005434287038	26873	Economy	15700.00
0005434286988	26873	Economy	15700.00
0005434287010	26873	Economy	15700.00
0005434287004	26873	Economy	15700.00
0005434286985	26873	Economy	15700.00
0005433110009	26873	Economy	15700.00
0005434286944	26873	Economy	15700.00
0005433110007	26873	Economy	15700.00
0005433110010	26873	Economy	15700.00
0005433110003	26873	Economy	15700.00
0005433110006	26873	Economy	15700.00
0005434286986	26873	Economy	15700.00
0005433110005	26873	Economy	15700.00
0005434287014	26873	Economy	15700.00
0005434286987	26873	Economy	15700.00
0005434287037	26873	Economy	15700.00
0005434286945	26873	Economy	15700.00
0005433110001	26873	Economy	15700.00
0005434286978	26873	Economy	15700.00
0005434287042	26873	Economy	15700.00
0005434286931	26873	Economy	15700.00
0005435856186	25502	Economy	22800.00
0005434272171	25502	Economy	22800.00
0005435856185	25502	Economy	22800.00
0005434272166	25502	Economy	22800.00
0005435856187	25502	Economy	22800.00
0005435856189	25502	Economy	22800.00
0005435856188	25502	Economy	22800.00
0005435856138	26625	Economy	22800.00
0005435856154	26625	Economy	22800.00
0005435856139	26625	Economy	22800.00
0005435856167	26625	Economy	22800.00
0005435856140	26625	Economy	22800.00
0005435856141	26625	Economy	22800.00
0005435856153	26625	Economy	22800.00
0005434520228	6102	Economy	24600.00
0005434520238	6102	Economy	24600.00
0005434520241	6102	Economy	24600.00
0005434520240	6102	Economy	22300.00
0005434520244	6102	Economy	22300.00
0005435314780	6102	Economy	22300.00
0005434520229	6102	Economy	22300.00
0005434520218	6102	Economy	22300.00
0005434520221	6102	Economy	22300.00
0005434520212	6102	Economy	22300.00
0005434520235	6102	Economy	22300.00
0005435314774	6102	Economy	22300.00
0005434520230	6102	Economy	22300.00
0005435314772	6102	Economy	22300.00
0005435314781	6102	Economy	22300.00
0005434520215	6102	Economy	22300.00
0005434520214	6102	Economy	22300.00
0005434520232	6102	Economy	22300.00
0005435314779	6102	Economy	22300.00
0005434520231	6102	Economy	22300.00
0005435314767	6102	Economy	22300.00
0005434520222	6102	Economy	22300.00
0005434520220	6102	Economy	22300.00
0005434520243	6102	Economy	22300.00
0005435314783	6102	Economy	22300.00
0005434520234	6102	Economy	22300.00
0005434520217	6102	Economy	22300.00
0005434520236	6102	Economy	22300.00
0005435314785	6102	Economy	22300.00
0005434520213	6102	Economy	22300.00
0005434520242	6102	Economy	22300.00
0005435314786	6102	Economy	22300.00
0005434520224	6102	Economy	22300.00
0005434520226	6102	Economy	22300.00
0005435314773	6102	Economy	22300.00
0005434520239	6102	Economy	22300.00
0005434520233	6102	Economy	22300.00
0005435314768	6102	Economy	22300.00
0005434520227	6102	Economy	22300.00
0005434520219	6102	Economy	22300.00
0005434520216	6102	Economy	22300.00
0005434520211	6102	Economy	22300.00
0005434520225	6102	Economy	22300.00
0005434520237	6102	Economy	22300.00
0005435314787	6102	Economy	22300.00
0005434520223	6102	Economy	22300.00
0005433650410	27635	Business	89800.00
0005433650421	27635	Business	89800.00
0005433650378	27635	Business	89800.00
0005433650413	27635	Business	89800.00
0005435263583	27635	Business	89800.00
0005433650414	27635	Business	89800.00
0005435263577	27635	Business	89800.00
0005433650368	27635	Business	89800.00
0005435263572	27635	Business	89800.00
0005433650403	27635	Business	89800.00
0005435263575	27635	Economy	29900.00
0005435263570	27635	Economy	29900.00
0005433650438	27635	Economy	29900.00
0005435263580	27635	Economy	29900.00
0005435263586	27635	Economy	29900.00
0005433650372	27635	Economy	29900.00
0005433650373	27635	Economy	29900.00
0005435263574	27635	Economy	32900.00
0005433650382	27635	Economy	32900.00
0005435263564	27635	Economy	32900.00
0005433650447	27635	Economy	32900.00
0005433650393	27635	Economy	32900.00
0005435263593	27635	Economy	29900.00
0005433650460	27635	Economy	29900.00
0005435263565	27635	Economy	29900.00
0005435263578	27635	Economy	29900.00
0005433650457	27635	Economy	29900.00
0005433650402	27635	Economy	29900.00
0005435263590	27635	Economy	29900.00
0005435263582	27635	Economy	29900.00
0005433650418	27635	Economy	29900.00
0005433650480	27635	Economy	29900.00
0005433650380	27635	Economy	29900.00
0005433650399	27635	Economy	29900.00
0005435263587	27635	Economy	29900.00
0005435263569	27635	Economy	29900.00
0005433650458	27635	Economy	29900.00
0005435263573	27635	Economy	29900.00
0005433650423	27635	Economy	29900.00
0005433650417	27635	Economy	29900.00
0005435263568	27635	Economy	29900.00
0005435263589	27635	Economy	29900.00
0005435263567	27635	Economy	29900.00
0005433650397	27635	Economy	29900.00
0005433650429	27635	Economy	29900.00
0005433650379	27635	Economy	29900.00
0005433650371	27635	Economy	29900.00
0005435263591	27635	Economy	29900.00
0005435263594	27635	Economy	29900.00
0005433650405	27635	Economy	29900.00
0005435263595	27635	Economy	29900.00
0005433650440	27635	Economy	29900.00
0005433650504	27635	Economy	29900.00
0005433650377	27635	Economy	29900.00
0005433650425	27635	Economy	29900.00
0005433650389	27635	Economy	29900.00
0005435263571	27635	Economy	29900.00
0005435263585	27635	Economy	29900.00
0005435263579	27635	Economy	29900.00
0005435263581	27635	Economy	29900.00
0005435263566	27635	Economy	29900.00
0005435263576	27635	Economy	29900.00
0005433650407	27635	Economy	29900.00
0005433650459	27635	Economy	29900.00
0005433650398	27635	Economy	29900.00
0005433650404	27635	Economy	29900.00
0005433650383	27635	Economy	29900.00
0005435263592	27635	Economy	29900.00
0005435263584	27635	Economy	29900.00
0005433650439	27635	Economy	29900.00
0005433650424	27635	Economy	29900.00
0005433650390	27635	Economy	29900.00
0005433650452	27635	Economy	29900.00
0005433650365	27635	Economy	29900.00
0005435263588	27635	Economy	29900.00
0005433868266	4790	Economy	19400.00
0005433868291	4790	Economy	19400.00
0005433868294	4790	Economy	19400.00
0005433868273	4790	Economy	19400.00
0005433868297	4790	Economy	17600.00
0005433868268	4790	Economy	17600.00
0005433868284	4790	Economy	17600.00
0005433868274	4790	Economy	17600.00
0005433868282	4790	Economy	17600.00
0005433868277	4790	Economy	17600.00
0005433868276	4790	Economy	17600.00
0005433868295	4790	Economy	17600.00
0005433868298	4790	Economy	17600.00
0005433868270	4790	Economy	17600.00
0005433868278	4790	Economy	17600.00
0005433868265	4790	Economy	17600.00
0005433868289	4790	Economy	17600.00
0005433868285	4790	Economy	17600.00
0005433868264	4790	Economy	17600.00
0005433868271	4790	Economy	17600.00
0005433868300	4790	Economy	17600.00
0005433868304	4790	Economy	17600.00
0005433868299	4790	Economy	17600.00
0005433868283	4790	Economy	17600.00
0005433868286	4790	Economy	17600.00
0005433868290	4790	Economy	17600.00
0005433868269	4790	Economy	17600.00
0005433868263	4790	Economy	17600.00
0005433868267	4790	Economy	17600.00
0005433868293	4790	Economy	17600.00
0005433868301	4790	Economy	17600.00
0005433868303	4790	Economy	17600.00
0005433868275	4790	Economy	17600.00
0005433868288	4790	Economy	17600.00
0005433868296	4790	Economy	17600.00
0005433868292	4790	Economy	17600.00
0005433868279	4790	Economy	17600.00
0005433868272	4790	Economy	17600.00
0005433868281	4790	Economy	17600.00
0005433868287	4790	Economy	17600.00
0005433868302	4790	Economy	17600.00
0005433868280	4790	Economy	17600.00
0005433867938	32577	Economy	19400.00
0005433868012	32577	Economy	19400.00
0005435860478	32577	Economy	19400.00
0005433867908	32577	Economy	17600.00
0005433867887	32577	Economy	17600.00
0005433867959	32577	Economy	17600.00
0005433867870	32577	Economy	17600.00
0005435860475	32577	Economy	17600.00
0005435860480	32577	Economy	17600.00
0005433867753	32577	Economy	17600.00
0005433867949	32577	Economy	17600.00
0005433867756	32577	Economy	17600.00
0005433868093	32577	Economy	17600.00
0005433868092	32577	Economy	17600.00
0005433867757	32577	Economy	17600.00
0005435860477	32577	Economy	17600.00
0005433867862	32577	Economy	17600.00
0005435860479	32577	Economy	17600.00
0005433867972	32577	Economy	17600.00
0005433867912	32577	Economy	17600.00
0005433867947	32577	Economy	17600.00
0005433867806	32577	Economy	17600.00
0005433867895	32577	Economy	17600.00
0005433867854	32577	Economy	17600.00
0005433867920	32577	Economy	17600.00
0005433868004	32577	Economy	17600.00
0005433867894	32577	Economy	17600.00
0005433867867	32577	Economy	17600.00
0005433867907	32577	Economy	17600.00
0005433868029	32577	Economy	17600.00
0005433867981	32577	Economy	17600.00
0005433867869	32577	Economy	17600.00
0005433867924	32577	Economy	17600.00
0005433867868	32577	Economy	17600.00
0005435860476	32577	Economy	17600.00
0005433867993	32577	Economy	17600.00
0005433867911	32577	Economy	17600.00
0005433867855	32577	Economy	17600.00
0005433867861	32577	Economy	17600.00
0005434663354	3457	Economy	24800.00
0005434663350	3457	Economy	24800.00
0005435911363	3457	Economy	24800.00
0005435911327	3457	Economy	24800.00
0005434663358	3457	Economy	22600.00
0005434663349	3457	Economy	22600.00
0005434663355	3457	Economy	22600.00
0005435911362	3457	Economy	22600.00
0005434663352	3457	Economy	22600.00
0005434461639	3457	Economy	22600.00
0005435911358	3457	Economy	22600.00
0005434461638	3457	Economy	22600.00
0005434460497	3457	Economy	22600.00
0005435911365	3457	Economy	22600.00
0005434663348	3457	Economy	22600.00
0005434663353	3457	Economy	22600.00
0005435911361	3457	Economy	22600.00
0005435911339	3457	Economy	22600.00
0005435911337	3457	Economy	22600.00
0005434663359	3457	Economy	22600.00
0005434663351	3457	Economy	22600.00
0005434663347	3457	Economy	22600.00
0005434663356	3457	Economy	22600.00
0005434663357	3457	Economy	22600.00
0005435911338	3457	Economy	22600.00
0005434663214	12483	Economy	24800.00
0005434663205	12483	Economy	24800.00
0005434663295	12483	Economy	22600.00
0005434663248	12483	Economy	22600.00
0005434663241	12483	Economy	22600.00
0005435911425	12483	Economy	22600.00
0005434663296	12483	Economy	22600.00
0005434663256	12483	Economy	22600.00
0005434663249	12483	Economy	22600.00
0005434663262	12483	Economy	22600.00
0005434663236	12483	Economy	22600.00
0005434663289	12483	Economy	22600.00
0005434663288	12483	Economy	22600.00
0005435911422	12483	Economy	22600.00
0005434663255	12483	Economy	22600.00
0005435911423	12483	Economy	22600.00
0005434663242	12483	Economy	22600.00
0005435911421	12483	Economy	22600.00
0005435911419	12483	Economy	22600.00
0005434663254	12483	Economy	22600.00
0005434663258	12483	Economy	22600.00
0005435911424	12483	Economy	22600.00
0005435911420	12483	Economy	22600.00
0005433867938	14478	Economy	18500.00
0005433867894	14478	Economy	18500.00
0005433867920	14478	Economy	18500.00
0005433867854	14478	Economy	18500.00
0005433867870	14478	Economy	16800.00
0005433867753	14478	Economy	16800.00
0005433867911	14478	Economy	16800.00
0005433868029	14478	Economy	16800.00
0005433867861	14478	Economy	16800.00
0005435860476	14478	Economy	16800.00
0005435860479	14478	Economy	16800.00
0005433867862	14478	Economy	16800.00
0005433867806	14478	Economy	16800.00
0005433867993	14478	Economy	16800.00
0005433868093	14478	Economy	16800.00
0005433867949	14478	Economy	16800.00
0005433867908	14478	Economy	16800.00
0005435860477	14478	Economy	16800.00
0005433867912	14478	Economy	16800.00
0005435860475	14478	Economy	16800.00
0005433867756	14478	Economy	16800.00
0005433867867	14478	Economy	16800.00
0005433867887	14478	Economy	16800.00
0005433867959	14478	Economy	16800.00
0005433868004	14478	Economy	16800.00
0005433867907	14478	Economy	16800.00
0005433867757	14478	Economy	16800.00
0005433867947	14478	Economy	16800.00
0005433867924	14478	Economy	16800.00
0005433868012	14478	Economy	16800.00
0005433867981	14478	Economy	16800.00
0005435860480	14478	Economy	16800.00
0005433867972	14478	Economy	16800.00
0005433867855	14478	Economy	16800.00
0005435860478	14478	Economy	16800.00
0005433867895	14478	Economy	16800.00
0005433868092	14478	Economy	16800.00
0005433867869	14478	Economy	16800.00
0005433867868	14478	Economy	16800.00
0005433868234	32684	Economy	18500.00
0005433868254	32684	Economy	18500.00
0005433868241	32684	Economy	16800.00
0005433868242	32684	Economy	16800.00
0005433868252	32684	Economy	16800.00
0005433868229	32684	Economy	16800.00
0005433868223	32684	Economy	16800.00
0005435860441	32684	Economy	16800.00
0005433868261	32684	Economy	16800.00
0005433868258	32684	Economy	16800.00
0005433868226	32684	Economy	16800.00
0005433868232	32684	Economy	16800.00
0005433868245	32684	Economy	16800.00
0005433868248	32684	Economy	16800.00
0005433868251	32684	Economy	16800.00
0005433868257	32684	Economy	16800.00
0005433868244	32684	Economy	16800.00
0005433868237	32684	Economy	16800.00
0005433868256	32684	Economy	16800.00
0005433868259	32684	Economy	16800.00
0005433868231	32684	Economy	16800.00
0005433868243	32684	Economy	16800.00
0005433868235	32684	Economy	16800.00
0005433868249	32684	Economy	16800.00
0005433868221	32684	Economy	16800.00
0005433868233	32684	Economy	16800.00
0005433868238	32684	Economy	16800.00
0005433868250	32684	Economy	16800.00
0005435860440	32684	Economy	16800.00
0005433868253	32684	Economy	16800.00
0005433868224	32684	Economy	16800.00
0005433868260	32684	Economy	16800.00
0005433868228	32684	Economy	16800.00
0005433868262	32684	Economy	16800.00
0005433868227	32684	Economy	16800.00
0005433868239	32684	Economy	16800.00
0005433868240	32684	Economy	16800.00
0005433868222	32684	Economy	16800.00
0005435860438	32684	Economy	16800.00
0005433868236	32684	Economy	16800.00
0005433868230	32684	Economy	16800.00
0005433868247	32684	Economy	16800.00
0005433868225	32684	Economy	16800.00
0005433868255	32684	Economy	16800.00
0005433868246	32684	Economy	16800.00
0005432799112	12146	Economy	4900.00
0005432799191	12146	Economy	4900.00
0005432799015	12146	Economy	4900.00
0005432799093	12146	Economy	4900.00
0005432799071	12146	Economy	4400.00
0005432799124	12146	Economy	4400.00
0005432799017	12146	Economy	4400.00
0005432799190	12146	Economy	4400.00
0005432799140	12146	Economy	4400.00
0005432799003	12146	Economy	4400.00
0005432799220	12146	Economy	4400.00
0005432799144	12146	Economy	4400.00
0005432799145	12146	Economy	4400.00
0005432799102	12146	Economy	4400.00
0005432799141	12146	Economy	4400.00
0005432799187	12146	Economy	4400.00
0005432799053	12146	Economy	4400.00
0005432799032	12146	Economy	4400.00
0005432799125	12146	Economy	4400.00
0005432799095	12146	Economy	4400.00
0005432799081	12146	Economy	4400.00
0005432799103	12146	Economy	4400.00
0005432799096	12146	Economy	4400.00
0005432799018	12146	Economy	4400.00
0005432799100	12146	Economy	4400.00
0005432799143	12146	Economy	4400.00
0005432799142	12146	Economy	4400.00
0005432799020	12146	Economy	4400.00
0005432799113	12146	Economy	4400.00
0005432799212	12146	Economy	4400.00
0005432799019	12146	Economy	4400.00
0005432799033	12146	Economy	4400.00
0005432799122	12146	Economy	4400.00
0005432799315	14812	Economy	4900.00
0005432799305	14812	Economy	4900.00
0005432799311	14812	Economy	4900.00
0005432799309	14812	Economy	4400.00
0005432799324	14812	Economy	4400.00
0005432799318	14812	Economy	4400.00
0005432799319	14812	Economy	4400.00
0005432799308	14812	Economy	4400.00
0005432799310	14812	Economy	4400.00
0005432799323	14812	Economy	4400.00
0005432799306	14812	Economy	4400.00
0005432799325	14812	Economy	4400.00
0005432799302	14812	Economy	4400.00
0005432799317	14812	Economy	4400.00
0005432799312	14812	Economy	4400.00
0005432799316	14812	Economy	4400.00
0005432799321	14812	Economy	4400.00
0005432799313	14812	Economy	4400.00
0005432799307	14812	Economy	4400.00
0005432799314	14812	Economy	4400.00
0005432799328	14812	Economy	4400.00
0005432799327	14812	Economy	4400.00
0005432799326	14812	Economy	4400.00
0005432799322	14812	Economy	4400.00
0005432799304	14812	Economy	4400.00
0005432799320	14812	Economy	4400.00
0005432799303	14812	Economy	4400.00
0005434299472	7040	Business	49100.00
0005435310874	7040	Business	49100.00
0005434407523	7040	Business	49100.00
0005434407478	7040	Business	49100.00
0005434407510	7040	Business	49100.00
0005434407509	7040	Business	49100.00
0005435310920	7040	Business	49100.00
0005434299460	7040	Business	49100.00
0005434407517	7040	Business	49100.00
0005434407488	7040	Business	49100.00
0005434407499	7040	Business	49100.00
0005434407494	7040	Business	49100.00
0005434407534	7040	Economy	16400.00
0005434407502	7040	Economy	16400.00
0005434407540	7040	Economy	16400.00
0005434407526	7040	Economy	16400.00
0005435310868	7040	Economy	16400.00
0005435293059	7040	Economy	16400.00
0005434299464	7040	Economy	16400.00
0005434407515	7040	Economy	16400.00
0005434407498	7040	Economy	16400.00
0005434407529	7040	Economy	16400.00
0005435293086	7040	Economy	16400.00
0005434407528	7040	Economy	16400.00
0005435310839	7040	Economy	16400.00
0005434407508	7040	Economy	16400.00
0005434407487	7040	Economy	16400.00
0005434407518	7040	Economy	16400.00
0005434407537	7040	Economy	16400.00
0005434299466	7040	Economy	16400.00
0005434407531	7040	Economy	16400.00
0005435310910	7040	Economy	16400.00
0005435293128	7040	Economy	16400.00
0005434299471	7040	Economy	16400.00
0005434407504	7040	Economy	16400.00
0005434407493	7040	Economy	16400.00
0005434407536	7040	Economy	16400.00
0005434407507	7040	Economy	16400.00
0005435293105	7040	Economy	16400.00
0005434299477	7040	Economy	16400.00
0005434407482	7040	Economy	16400.00
0005435310875	7040	Economy	16400.00
0005434407481	7040	Economy	16400.00
0005432108239	7040	Economy	16400.00
0005434407484	7040	Economy	16400.00
0005432153910	7040	Economy	16400.00
0005434407519	7040	Economy	16400.00
0005434299456	7040	Economy	16400.00
0005435310883	7040	Economy	16400.00
0005434407505	7040	Economy	16400.00
0005435310908	7040	Economy	16400.00
0005434407485	7040	Economy	18000.00
0005434407503	7040	Economy	18000.00
0005434407516	7040	Economy	18000.00
0005434407489	7040	Economy	18000.00
0005435293099	7040	Economy	18000.00
0005435310901	7040	Economy	16400.00
0005434407500	7040	Economy	16400.00
0005434407532	7040	Economy	16400.00
0005434299458	7040	Economy	16400.00
0005434299474	7040	Economy	16400.00
0005434299459	7040	Economy	16400.00
0005432153909	7040	Economy	16400.00
0005434407483	7040	Economy	16400.00
0005434299467	7040	Economy	16400.00
0005432153907	7040	Economy	16400.00
0005434299469	7040	Economy	16400.00
0005434407524	7040	Economy	16400.00
0005434299457	7040	Economy	16400.00
0005434407490	7040	Economy	16400.00
0005435310909	7040	Economy	16400.00
0005434407480	7040	Economy	16400.00
0005434407491	7040	Economy	16400.00
0005432108240	7040	Economy	16400.00
0005434407512	7040	Economy	16400.00
0005434407495	7040	Economy	16400.00
0005434407486	7040	Economy	16400.00
0005435310890	7040	Economy	16400.00
0005434299462	7040	Economy	16400.00
0005435310921	7040	Economy	16400.00
0005434407497	7040	Economy	16400.00
0005434407506	7040	Economy	16400.00
0005432153908	7040	Economy	16400.00
0005435293078	7040	Economy	16400.00
0005435293114	7040	Economy	16400.00
0005434407522	7040	Economy	16400.00
0005435293082	7040	Economy	16400.00
0005435310866	7040	Economy	16400.00
0005434407501	7040	Economy	16400.00
0005434407513	7040	Economy	16400.00
0005434299476	7040	Economy	16400.00
0005434407492	7040	Economy	16400.00
0005434407538	7040	Economy	16400.00
0005435293058	7040	Economy	16400.00
0005434407530	7040	Economy	16400.00
0005434407477	7040	Economy	16400.00
0005434407496	7040	Economy	16400.00
0005434407514	7040	Economy	16400.00
0005435310900	7040	Economy	16400.00
0005434299475	7040	Economy	16400.00
0005434407527	7040	Economy	16400.00
0005434299478	7040	Economy	16400.00
0005434407535	7040	Economy	16400.00
0005435310906	7040	Economy	16400.00
0005434299461	7040	Economy	16400.00
0005432153911	7040	Economy	16400.00
0005434407533	7040	Economy	16400.00
0005434299463	7040	Economy	16400.00
0005434407521	7040	Economy	16400.00
0005434299473	7040	Economy	16400.00
0005434407511	7040	Economy	16400.00
0005432153906	7040	Economy	16400.00
0005435310877	7040	Economy	16400.00
0005434407525	7040	Economy	16400.00
0005434299470	7040	Economy	16400.00
0005432153912	7040	Economy	16400.00
0005434407479	7040	Economy	16400.00
0005434407539	7040	Economy	16400.00
0005434299468	7040	Economy	16400.00
0005434407520	7040	Economy	16400.00
0005434299465	7040	Economy	16400.00
0005435310886	7040	Economy	16400.00
0005434299356	26912	Business	49100.00
0005435311015	26912	Business	49100.00
0005434406911	26912	Business	49100.00
0005434406945	26912	Business	49100.00
0005434406909	26912	Business	49100.00
0005434406710	26912	Business	49100.00
0005434406711	26912	Business	49100.00
0005435311017	26912	Business	49100.00
0005434406983	26912	Business	49100.00
0005435311019	26912	Business	49100.00
0005434299339	26912	Economy	16400.00
0005434406826	26912	Economy	16400.00
0005434406929	26912	Economy	16400.00
0005435293201	26912	Economy	16400.00
0005434406896	26912	Economy	16400.00
0005434406734	26912	Economy	16400.00
0005434406872	26912	Economy	16400.00
0005434406875	26912	Economy	16400.00
0005434407014	26912	Economy	16400.00
0005434406741	26912	Economy	16400.00
0005434406879	26912	Economy	16400.00
0005434406763	26912	Economy	16400.00
0005434407005	26912	Economy	16400.00
0005434407065	26912	Economy	16400.00
0005434406775	26912	Economy	16400.00
0005434406712	26912	Economy	16400.00
0005434299306	26912	Economy	16400.00
0005435293200	26912	Economy	16400.00
0005434406916	26912	Economy	16400.00
0005434406740	26912	Economy	16400.00
0005435311016	26912	Economy	16400.00
0005432058361	26912	Economy	16400.00
0005435293202	26912	Economy	16400.00
0005435293204	26912	Economy	16400.00
0005434406876	26912	Economy	16400.00
0005434406771	26912	Economy	16400.00
0005435293199	26912	Economy	16400.00
0005434406910	26912	Economy	16400.00
0005432058362	26912	Economy	16400.00
0005434299355	26912	Economy	16400.00
0005434406888	26912	Economy	16400.00
0005434406965	26912	Economy	16400.00
0005434407004	26912	Economy	16400.00
0005432058360	26912	Economy	18000.00
0005434406923	26912	Economy	18000.00
0005434407145	26912	Economy	18000.00
0005434406934	26912	Economy	18000.00
0005434406835	26912	Economy	16400.00
0005434406887	26912	Economy	16400.00
0005434406992	26912	Economy	16400.00
0005434299239	26912	Economy	16400.00
0005434407056	26912	Economy	16400.00
0005434406643	26912	Economy	16400.00
0005434406769	26912	Economy	16400.00
0005435311023	26912	Economy	16400.00
0005434407110	26912	Economy	16400.00
0005435293198	26912	Economy	16400.00
0005435311025	26912	Economy	16400.00
0005434299335	26912	Economy	16400.00
0005434406871	26912	Economy	16400.00
0005434407165	26912	Economy	16400.00
0005434406772	26912	Economy	16400.00
0005434406897	26912	Economy	16400.00
0005434406644	26912	Economy	16400.00
0005434407144	26912	Economy	16400.00
0005434406801	26912	Economy	16400.00
0005434406924	26912	Economy	16400.00
0005435293203	26912	Economy	16400.00
0005435311020	26912	Economy	16400.00
0005434406878	26912	Economy	16400.00
0005434299250	26912	Economy	16400.00
0005434406900	26912	Economy	16400.00
0005434406830	26912	Economy	16400.00
0005434406793	26912	Economy	16400.00
0005435311022	26912	Economy	16400.00
0005434406867	26912	Economy	16400.00
0005434406735	26912	Economy	16400.00
0005434299229	26912	Economy	16400.00
0005434406765	26912	Economy	16400.00
0005434406846	26912	Economy	16400.00
0005434299325	26912	Economy	16400.00
0005434406736	26912	Economy	16400.00
0005434406653	26912	Economy	16400.00
0005434406652	26912	Economy	16400.00
0005434406838	26912	Economy	16400.00
0005435293197	26912	Economy	16400.00
0005435293205	26912	Economy	16400.00
0005434299180	26912	Economy	16400.00
0005434407143	26912	Economy	16400.00
0005434406692	26912	Economy	16400.00
0005434407013	26912	Economy	16400.00
0005435293196	26912	Economy	16400.00
0005434299230	26912	Economy	16400.00
0005432058363	26912	Economy	16400.00
0005434407064	26912	Economy	16400.00
0005435293207	26912	Economy	16400.00
0005434406898	26912	Economy	16400.00
0005435293206	26912	Economy	16400.00
0005434406719	26912	Economy	16400.00
0005435311024	26912	Economy	16400.00
0005435311018	26912	Economy	16400.00
0005434406873	26912	Economy	16400.00
0005434406786	26912	Economy	16400.00
0005434406847	26912	Economy	16400.00
0005434407109	26912	Economy	16400.00
0005434299251	26912	Economy	16400.00
0005434407019	26912	Economy	16400.00
0005434406829	26912	Economy	16400.00
0005435293195	26912	Economy	16400.00
0005435311021	26912	Economy	16400.00
0005434406886	26912	Economy	16400.00
0005434406832	26912	Economy	16400.00
0005434406828	26912	Economy	16400.00
0005434406950	26912	Economy	16400.00
0005434512095	6479	Economy	16500.00
0005432604195	6479	Economy	16500.00
0005432604206	6479	Economy	16500.00
0005434512094	6479	Economy	15000.00
0005432604209	6479	Economy	15000.00
0005432604191	6479	Economy	15000.00
0005432604203	6479	Economy	15000.00
0005432604199	6479	Economy	15000.00
0005432604178	6479	Economy	15000.00
0005432604180	6479	Economy	15000.00
0005432604169	6479	Economy	15000.00
0005432604205	6479	Economy	15000.00
0005434512096	6479	Economy	15000.00
0005432604172	6479	Economy	15000.00
0005432604176	6479	Economy	15000.00
0005432604177	6479	Economy	15000.00
0005432604207	6479	Economy	15000.00
0005432604187	6479	Economy	15000.00
0005432604194	6479	Economy	15000.00
0005432604196	6479	Economy	15000.00
0005432604190	6479	Economy	15000.00
0005432604184	6479	Economy	15000.00
0005432604175	6479	Economy	15000.00
0005432604193	6479	Economy	15000.00
0005432604192	6479	Economy	15000.00
0005432604173	6479	Economy	15000.00
0005432604200	6479	Economy	15000.00
0005432604197	6479	Economy	15000.00
0005432604174	6479	Economy	15000.00
0005432604189	6479	Economy	15000.00
0005432604188	6479	Economy	15000.00
0005432604183	6479	Economy	15000.00
0005432604186	6479	Economy	15000.00
0005432604198	6479	Economy	15000.00
0005434512097	6479	Economy	15000.00
0005432604202	6479	Economy	15000.00
0005432604182	6479	Economy	15000.00
0005432604204	6479	Economy	15000.00
0005432604208	6479	Economy	15000.00
0005432604170	6479	Economy	15000.00
0005434512098	6479	Economy	15000.00
0005432604185	6479	Economy	15000.00
0005432604201	6479	Economy	15000.00
0005432604171	6479	Economy	15000.00
0005432604179	6479	Economy	15000.00
0005432604181	6479	Economy	15000.00
0005434512099	6479	Economy	15000.00
0005432603824	21367	Economy	16500.00
0005432603822	21367	Economy	16500.00
0005432603903	21367	Economy	16500.00
0005432603798	21367	Economy	16500.00
0005432603779	21367	Economy	15000.00
0005432603868	21367	Economy	15000.00
0005434512053	21367	Economy	15000.00
0005432603839	21367	Economy	15000.00
0005432603746	21367	Economy	15000.00
0005434512062	21367	Economy	15000.00
0005432603860	21367	Economy	15000.00
0005432603825	21367	Economy	15000.00
0005432603804	21367	Economy	15000.00
0005432603840	21367	Economy	15000.00
0005432603875	21367	Economy	15000.00
0005432603838	21367	Economy	15000.00
0005432603892	21367	Economy	15000.00
0005432603757	21367	Economy	15000.00
0005432603810	21367	Economy	15000.00
0005432603806	21367	Economy	15000.00
0005434512045	21367	Economy	15000.00
0005432603662	21367	Economy	15000.00
0005432603901	21367	Economy	15000.00
0005432603775	21367	Economy	15000.00
0005434512051	21367	Economy	15000.00
0005432603771	21367	Economy	15000.00
0005432603823	21367	Economy	15000.00
0005432603865	21367	Economy	15000.00
0005432603693	21367	Economy	15000.00
0005434512049	21367	Economy	15000.00
0005432603805	21367	Economy	15000.00
0005432603796	21367	Economy	15000.00
0005432603843	21367	Economy	15000.00
0005432603700	21367	Economy	15000.00
0005434512044	21367	Economy	15000.00
0005432603786	21367	Economy	15000.00
0005432603769	21367	Economy	15000.00
0005432603946	21367	Economy	15000.00
0005432603745	21367	Economy	15000.00
0005432603809	21367	Economy	15000.00
0005432603770	21367	Economy	15000.00
0005432603778	21367	Economy	15000.00
0005432603834	21367	Economy	15000.00
0005432603747	21367	Economy	15000.00
0005432603881	21367	Economy	15000.00
0005432603748	21367	Economy	15000.00
0005432603863	21367	Economy	15000.00
0005434512048	21367	Economy	15000.00
0005432603951	21367	Economy	15000.00
0005432603859	21367	Economy	15000.00
0005434906809	14972	Business	18900.00
0005433251359	14972	Business	18900.00
0005433251338	14972	Business	18900.00
0005434906746	14972	Business	18900.00
0005434906405	14972	Business	18900.00
0005434906379	14972	Business	18900.00
0005434906810	14972	Business	18900.00
0005434906794	14972	Business	18900.00
0005433251352	14972	Business	18900.00
0005433251347	14972	Business	18900.00
0005433251343	14972	Business	18900.00
0005434906564	14972	Economy	6300.00
0005434906596	14972	Economy	6300.00
0005433251354	14972	Economy	6300.00
0005433251360	14972	Economy	6300.00
0005434906651	14972	Economy	6300.00
0005434906531	14972	Economy	6300.00
0005434906819	14972	Economy	6300.00
0005434906793	14972	Economy	6300.00
0005434906483	14972	Economy	6300.00
0005434906652	14972	Economy	6300.00
0005434906747	14972	Economy	6900.00
0005434906618	14972	Economy	6900.00
0005433251363	14972	Economy	6900.00
0005433251362	14972	Economy	6900.00
0005433251345	14972	Economy	6300.00
0005433251361	14972	Economy	6300.00
0005434906574	14972	Economy	6300.00
0005434906779	14972	Economy	6300.00
0005434906611	14972	Economy	6300.00
0005434906430	14972	Economy	6300.00
0005434906406	14972	Economy	6300.00
0005433251365	14972	Economy	6300.00
0005434906489	14972	Economy	6300.00
0005434906756	14972	Economy	6300.00
0005434906665	14972	Economy	6300.00
0005434906504	14972	Economy	6300.00
0005433251364	14972	Economy	6300.00
0005434906728	14972	Economy	6300.00
0005434906571	14972	Economy	6300.00
0005434906623	14972	Economy	6300.00
0005434906722	14972	Economy	6300.00
0005433251340	14972	Economy	6300.00
0005433251357	14972	Economy	6300.00
0005434906639	14972	Economy	6300.00
0005433251367	14972	Economy	6300.00
0005434906579	14972	Economy	6300.00
0005433251348	14972	Economy	6300.00
0005434906745	14972	Economy	6300.00
0005433251369	14972	Economy	6300.00
0005433251353	14972	Economy	6300.00
0005434906488	14972	Economy	6300.00
0005434906501	14972	Economy	6300.00
0005434906617	14972	Economy	6300.00
0005433251358	14972	Economy	6300.00
0005434906679	14972	Economy	6300.00
0005434906408	14972	Economy	6300.00
0005433251350	14972	Economy	6300.00
0005434906638	14972	Economy	6300.00
0005433251346	14972	Economy	6300.00
0005433251339	14972	Economy	6300.00
0005434906494	14972	Economy	6300.00
0005434906780	14972	Economy	6300.00
0005434906680	14972	Economy	6300.00
0005433251356	14972	Economy	6300.00
0005434906361	14972	Economy	6300.00
0005434906404	14972	Economy	6300.00
0005433251366	14972	Economy	6300.00
0005434906729	14972	Economy	6300.00
0005433251344	14972	Economy	6300.00
0005434906678	14972	Economy	6300.00
0005433251370	14972	Economy	6300.00
0005434906362	14972	Economy	6300.00
0005433251341	14972	Economy	6300.00
0005433251368	14972	Economy	6300.00
0005433251355	14972	Economy	6300.00
0005434906557	14972	Economy	6300.00
0005434906616	14972	Economy	6300.00
0005434906799	14972	Economy	6300.00
0005433251342	14972	Economy	6300.00
0005434906380	14972	Economy	6300.00
0005433251349	14972	Economy	6300.00
0005434906580	14972	Economy	6300.00
0005434906561	14972	Economy	6300.00
0005433251351	14972	Economy	6300.00
0005434906487	14972	Economy	6300.00
0005434906429	14972	Economy	6300.00
0005434906578	14972	Economy	6300.00
0005434907046	25867	Business	18900.00
0005434907023	25867	Business	18900.00
0005434907031	25867	Business	18900.00
0005433251027	25867	Business	18900.00
0005434907011	25867	Business	18900.00
0005434907033	25867	Business	18900.00
0005433251042	25867	Business	18900.00
0005434907044	25867	Business	18900.00
0005433251085	25867	Business	18900.00
0005434907029	25867	Business	18900.00
0005434907043	25867	Business	18900.00
0005433251079	25867	Economy	6300.00
0005434907036	25867	Economy	6300.00
0005434907025	25867	Economy	6300.00
0005434907021	25867	Economy	6300.00
0005434907049	25867	Economy	6300.00
0005433251175	25867	Economy	6300.00
0005433251134	25867	Economy	6300.00
0005434907014	25867	Economy	6300.00
0005433251156	25867	Economy	6300.00
0005434907019	25867	Economy	6900.00
0005434907018	25867	Economy	6900.00
0005434907052	25867	Economy	6900.00
0005434907035	25867	Economy	6900.00
0005434907040	25867	Economy	6900.00
0005434907032	25867	Economy	6300.00
0005433251198	25867	Economy	6300.00
0005434907013	25867	Economy	6300.00
0005434907024	25867	Economy	6300.00
0005434907048	25867	Economy	6300.00
0005434907028	25867	Economy	6300.00
0005433251199	25867	Economy	6300.00
0005434907042	25867	Economy	6300.00
0005434907038	25867	Economy	6300.00
0005434907034	25867	Economy	6300.00
0005433250940	25867	Economy	6300.00
0005433251152	25867	Economy	6300.00
0005434907050	25867	Economy	6300.00
0005433251197	25867	Economy	6300.00
0005434907039	25867	Economy	6300.00
0005434907012	25867	Economy	6300.00
0005433251127	25867	Economy	6300.00
0005434907020	25867	Economy	6300.00
0005433251090	25867	Economy	6300.00
0005433250968	25867	Economy	6300.00
0005433251077	25867	Economy	6300.00
0005434907053	25867	Economy	6300.00
0005433251123	25867	Economy	6300.00
0005434907051	25867	Economy	6300.00
0005433251115	25867	Economy	6300.00
0005433251056	25867	Economy	6300.00
0005433251025	25867	Economy	6300.00
0005434907041	25867	Economy	6300.00
0005434907015	25867	Economy	6300.00
0005433251078	25867	Economy	6300.00
0005434907037	25867	Economy	6300.00
0005433251060	25867	Economy	6300.00
0005434907026	25867	Economy	6300.00
0005434907045	25867	Economy	6300.00
0005434907017	25867	Economy	6300.00
0005433251026	25867	Economy	6300.00
0005433251176	25867	Economy	6300.00
0005434907016	25867	Economy	6300.00
0005434907030	25867	Economy	6300.00
0005434907022	25867	Economy	6300.00
0005433251097	25867	Economy	6300.00
0005434907027	25867	Economy	6300.00
0005433251023	25867	Economy	6300.00
0005433251094	25867	Economy	6300.00
0005433251107	25867	Economy	6300.00
0005433251102	25867	Economy	6300.00
0005433251108	25867	Economy	6300.00
0005433251057	25867	Economy	6300.00
0005433251114	25867	Economy	6300.00
0005434907047	25867	Economy	6300.00
0005433251089	25867	Economy	6300.00
0005433251028	25867	Economy	6300.00
0005433251131	25867	Economy	6300.00
0005433251155	25867	Economy	6300.00
0005433251055	25867	Economy	6300.00
0005433251024	25867	Economy	6300.00
0005433250994	25867	Economy	6300.00
0005433251151	25867	Economy	6300.00
0005433251006	25867	Economy	6300.00
0005433251208	25867	Economy	6300.00
0005433251109	25867	Economy	6300.00
0005433008458	14160	Business	52300.00
0005433810489	14160	Business	52300.00
0005433008466	14160	Business	52300.00
0005433008432	14160	Business	52300.00
0005433008431	14160	Business	52300.00
0005433008462	14160	Business	52300.00
0005433008453	14160	Economy	17400.00
0005433008467	14160	Economy	17400.00
0005433008441	14160	Economy	17400.00
0005433008444	14160	Economy	17400.00
0005433008470	14160	Economy	17400.00
0005433008430	14160	Economy	17400.00
0005433008461	14160	Economy	17400.00
0005433008454	14160	Economy	19200.00
0005433008433	14160	Economy	19200.00
0005433008452	14160	Economy	19200.00
0005433008448	14160	Economy	19200.00
0005433008425	14160	Economy	17400.00
0005433008446	14160	Economy	17400.00
0005433008445	14160	Economy	17400.00
0005433008471	14160	Economy	17400.00
0005433008438	14160	Economy	17400.00
0005433008464	14160	Economy	17400.00
0005433008429	14160	Economy	17400.00
0005433008459	14160	Economy	17400.00
0005433008451	14160	Economy	17400.00
0005433008443	14160	Economy	17400.00
0005433008442	14160	Economy	17400.00
0005433008463	14160	Economy	17400.00
0005433008427	14160	Economy	17400.00
0005433008436	14160	Economy	17400.00
0005433008460	14160	Economy	17400.00
0005433008440	14160	Economy	17400.00
0005433008435	14160	Economy	17400.00
0005433008439	14160	Economy	17400.00
0005433008469	14160	Economy	17400.00
0005433008456	14160	Economy	17400.00
0005433008434	14160	Economy	17400.00
0005433008437	14160	Economy	17400.00
0005433008450	14160	Economy	17400.00
0005433008428	14160	Economy	17400.00
0005433008468	14160	Economy	17400.00
0005433008465	14160	Economy	17400.00
0005433810493	14160	Economy	17400.00
0005433008457	14160	Economy	17400.00
0005433008455	14160	Economy	17400.00
0005433008426	14160	Economy	17400.00
0005433008447	14160	Economy	17400.00
0005433008449	14160	Economy	17400.00
0005433810522	22834	Business	52300.00
0005433008056	22834	Business	52300.00
0005433008080	22834	Business	52300.00
0005433007999	22834	Business	52300.00
0005433007965	22834	Economy	17400.00
0005433008120	22834	Economy	17400.00
0005433007995	22834	Economy	17400.00
0005433008162	22834	Economy	17400.00
0005433007865	22834	Economy	17400.00
0005433810523	22834	Economy	17400.00
0005433007945	22834	Economy	17400.00
0005433008214	22834	Economy	17400.00
0005433007907	22834	Economy	17400.00
0005433007966	22834	Economy	17400.00
0005433008054	22834	Economy	17400.00
0005433008142	22834	Economy	17400.00
0005433007864	22834	Economy	17400.00
0005433007978	22834	Economy	17400.00
0005433007994	22834	Economy	17400.00
0005433007845	22834	Economy	17400.00
0005433008009	22834	Economy	17400.00
0005433008053	22834	Economy	17400.00
0005433008107	22834	Economy	17400.00
0005433810521	22834	Economy	17400.00
0005433007867	22834	Economy	17400.00
0005433008081	22834	Economy	17400.00
0005433007940	22834	Economy	17400.00
0005433007846	22834	Economy	17400.00
0005433008173	22834	Economy	17400.00
0005433007896	22834	Economy	17400.00
0005433007866	22834	Economy	17400.00
0005433007963	22834	Economy	17400.00
0005433008062	22834	Economy	17400.00
0005433008213	22834	Economy	17400.00
0005433007906	22834	Economy	17400.00
0005433007937	22834	Economy	17400.00
0005433008161	22834	Economy	17400.00
0005433008089	22834	Economy	17400.00
0005433007998	22834	Economy	17400.00
0005433008008	22834	Economy	17400.00
0005433008088	22834	Economy	17400.00
0005434925334	14919	Business	22900.00
0005434925288	14919	Business	22900.00
0005434925322	14919	Business	22900.00
0005434925255	14919	Business	22900.00
0005434925323	14919	Business	22900.00
0005434925287	14919	Economy	7600.00
0005434925251	14919	Economy	7600.00
0005434925318	14919	Economy	8400.00
0005434925256	14919	Economy	7600.00
0005434925297	14919	Economy	7600.00
0005434925342	14919	Economy	7600.00
0005434925289	14919	Economy	7600.00
0005434925346	14919	Economy	7600.00
0005434925258	14919	Economy	7600.00
0005434925352	14919	Economy	7600.00
0005434925316	14919	Economy	7600.00
0005434925294	14919	Economy	7600.00
0005434925259	14919	Economy	7600.00
0005434925333	14919	Economy	7600.00
0005434925298	14919	Economy	7600.00
0005434925345	14919	Economy	7600.00
0005434925662	20529	Business	22900.00
0005434925658	20529	Business	22900.00
0005434925656	20529	Economy	7600.00
0005434925661	20529	Economy	7600.00
0005434925668	20529	Economy	8400.00
0005434925663	20529	Economy	8400.00
0005434925655	20529	Economy	8400.00
0005434925674	20529	Economy	7600.00
0005434925657	20529	Economy	7600.00
0005434925667	20529	Economy	7600.00
0005434925670	20529	Economy	7600.00
0005434925652	20529	Economy	7600.00
0005434925672	20529	Economy	7600.00
0005434925673	20529	Economy	7600.00
0005434925669	20529	Economy	7600.00
0005434925660	20529	Economy	7600.00
0005434925653	20529	Economy	7600.00
0005434925666	20529	Economy	7600.00
0005434925654	20529	Economy	7600.00
0005434925671	20529	Economy	7600.00
0005434925659	20529	Economy	7600.00
0005434925664	20529	Economy	7600.00
0005434925665	20529	Economy	7600.00
0005434925676	20529	Economy	7600.00
0005434925675	20529	Economy	7600.00
0005434925677	20529	Economy	7600.00
0005435487760	15825	Economy	8900.00
0005435487761	15825	Economy	8900.00
0005435999009	15825	Economy	8900.00
0005435487756	15825	Economy	8900.00
0005435487747	15825	Economy	8100.00
0005435998978	15825	Economy	8100.00
0005435999000	15825	Economy	8100.00
0005435487755	15825	Economy	8100.00
0005435487752	15825	Economy	8100.00
0005435487759	15825	Economy	8100.00
0005435999013	15825	Economy	8100.00
0005435999028	15825	Economy	8100.00
0005435999008	15825	Economy	8100.00
0005435999041	15825	Economy	8100.00
0005435998970	15825	Economy	8100.00
0005435487754	15825	Economy	8100.00
0005435487746	15825	Economy	8100.00
0005435487741	15825	Economy	8100.00
0005435487763	15825	Economy	8100.00
0005435999004	15825	Economy	8100.00
0005435999023	15825	Economy	8100.00
0005435999002	15825	Economy	8100.00
0005435487748	15825	Economy	8100.00
0005435487762	15825	Economy	8100.00
0005435487744	15825	Economy	8100.00
0005435999031	15825	Economy	8100.00
0005435487743	15825	Economy	8100.00
0005435487753	15825	Economy	8100.00
0005435998980	15825	Economy	8100.00
0005435487757	15825	Economy	8100.00
0005435998982	15825	Economy	8100.00
0005435487750	15825	Economy	8100.00
0005435487749	15825	Economy	8100.00
0005435487751	15825	Economy	8100.00
0005435487745	15825	Economy	8100.00
0005435999032	15825	Economy	8100.00
0005435487758	15825	Economy	8100.00
0005435999027	15825	Economy	8100.00
0005435999024	15825	Economy	8100.00
0005435999003	15825	Economy	8100.00
0005435487742	15825	Economy	8100.00
0005435487548	19690	Economy	8900.00
0005435487560	19690	Economy	8900.00
0005435487570	19690	Economy	8900.00
0005435487509	19690	Economy	8900.00
0005435487531	19690	Economy	8100.00
0005435487558	19690	Economy	8100.00
0005435487470	19690	Economy	8100.00
0005435487584	19690	Economy	8100.00
0005435487543	19690	Economy	8100.00
0005435487526	19690	Economy	8100.00
0005435487585	19690	Economy	8100.00
0005435487563	19690	Economy	8100.00
0005435999177	19690	Economy	8100.00
0005435487528	19690	Economy	8100.00
0005435999173	19690	Economy	8100.00
0005435487522	19690	Economy	8100.00
0005435487598	19690	Economy	8100.00
0005435999174	19690	Economy	8100.00
0005435487491	19690	Economy	8100.00
0005435999181	19690	Economy	8100.00
0005435487576	19690	Economy	8100.00
0005435487571	19690	Economy	8100.00
0005435487500	19690	Economy	8100.00
0005435487597	19690	Economy	8100.00
0005435999178	19690	Economy	8100.00
0005435487575	19690	Economy	8100.00
0005435487476	19690	Economy	8100.00
0005435487527	19690	Economy	8100.00
0005435999175	19690	Economy	8100.00
0005435487499	19690	Economy	8100.00
0005435999176	19690	Economy	8100.00
0005435487620	19690	Economy	8100.00
0005435487544	19690	Economy	8100.00
0005435487492	19690	Economy	8100.00
0005435999179	19690	Economy	8100.00
0005435999180	19690	Economy	8100.00
0005435487547	19690	Economy	8100.00
0005435487574	19690	Economy	8100.00
0005435487490	19690	Economy	8100.00
0005435487498	19690	Economy	8100.00
0005435839345	6006	Business	199300.00
0005432660811	6006	Business	199300.00
0005435839342	6006	Business	199300.00
0005435839356	6006	Business	199300.00
0005435839334	6006	Economy	66400.00
0005432658584	6006	Economy	66400.00
0005435839348	6006	Economy	66400.00
0005435839339	6006	Economy	66400.00
0005435839354	6006	Economy	66400.00
0005435839355	6006	Economy	66400.00
0005432658583	6006	Economy	66400.00
0005432537028	6006	Economy	66400.00
0005435839336	6006	Economy	73100.00
0005435472600	6006	Economy	66400.00
0005435472550	6006	Economy	73100.00
0005435472575	6006	Economy	66400.00
0005435472590	6006	Economy	66400.00
0005435472526	6006	Economy	66400.00
0005435839350	6006	Economy	66400.00
0005432142239	6006	Economy	66400.00
0005432659700	6006	Economy	66400.00
0005432537029	6006	Economy	66400.00
0005432142240	6006	Economy	66400.00
0005435839332	6006	Economy	66400.00
0005435839352	6006	Economy	66400.00
0005435839351	6006	Economy	66400.00
0005435839353	6006	Economy	66400.00
0005435472596	6006	Economy	66400.00
0005435839357	6006	Economy	66400.00
0005435472568	6006	Economy	66400.00
0005435839335	6006	Economy	66400.00
0005435472597	6006	Economy	66400.00
0005435839341	6006	Economy	66400.00
0005435839347	6006	Economy	66400.00
0005432659699	6006	Economy	66400.00
0005435839346	6006	Economy	66400.00
0005435839349	6006	Economy	66400.00
0005435839340	6006	Economy	66400.00
0005432142238	6006	Economy	66400.00
0005435839359	6006	Economy	66400.00
0005435472612	6006	Economy	66400.00
0005435472544	6006	Economy	66400.00
0005435472574	6006	Economy	66400.00
0005435839337	6006	Economy	66400.00
0005432142241	6006	Economy	66400.00
0005435839360	6006	Economy	66400.00
0005435839333	6006	Economy	66400.00
0005435839343	6006	Economy	66400.00
0005435839338	6006	Economy	66400.00
0005435839358	6006	Economy	66400.00
0005435472585	6006	Economy	66400.00
0005435839344	6006	Economy	66400.00
0005435472658	6006	Economy	66400.00
0005435472651	6006	Economy	66400.00
0005435472659	6006	Economy	66400.00
0005435839099	18034	Business	199300.00
0005435472741	18034	Business	199300.00
0005435839166	18034	Business	199300.00
0005435472747	18034	Business	199300.00
0005435472734	18034	Business	199300.00
0005435839125	18034	Business	199300.00
0005435472735	18034	Business	199300.00
0005435472746	18034	Economy	66400.00
0005435839172	18034	Economy	66400.00
0005435472738	18034	Economy	66400.00
0005435839059	18034	Economy	66400.00
0005435839130	18034	Economy	66400.00
0005432667421	18034	Economy	66400.00
0005435839031	18034	Economy	73100.00
0005435839103	18034	Economy	66400.00
0005432667418	18034	Economy	66400.00
0005435839129	18034	Economy	66400.00
0005435839096	18034	Economy	66400.00
0005435839134	18034	Economy	66400.00
0005435472740	18034	Economy	66400.00
0005435839028	18034	Economy	66400.00
0005432667422	18034	Economy	66400.00
0005435839095	18034	Economy	66400.00
0005435839167	18034	Economy	66400.00
0005435839138	18034	Economy	66400.00
0005435839121	18034	Economy	66400.00
0005435839137	18034	Economy	66400.00
0005435839007	18034	Economy	66400.00
0005435472739	18034	Economy	66400.00
0005435472742	18034	Economy	66400.00
0005435472743	18034	Economy	66400.00
0005435839094	18034	Economy	66400.00
0005435838958	18034	Economy	66400.00
0005435472733	18034	Economy	66400.00
0005435472732	18034	Economy	66400.00
0005435839029	18034	Economy	66400.00
0005432537052	18034	Economy	66400.00
0005435839097	18034	Economy	66400.00
0005435472736	18034	Economy	66400.00
0005432537051	18034	Economy	66400.00
0005435839100	18034	Economy	66400.00
0005435839084	18034	Economy	66400.00
0005435472737	18034	Economy	66400.00
0005435839085	18034	Economy	66400.00
0005435839030	18034	Economy	66400.00
0005435472745	18034	Economy	66400.00
0005435472744	18034	Economy	66400.00
0005435839205	18034	Economy	66400.00
0005435839209	18034	Economy	66400.00
0005433284913	23010	Business	15700.00
0005433284992	23010	Business	15700.00
0005433284935	23010	Business	15700.00
0005435103890	23010	Business	15700.00
0005433284991	23010	Business	15700.00
0005433284912	23010	Business	15700.00
0005435103888	23010	Economy	5200.00
0005435103892	23010	Economy	5200.00
0005435103893	23010	Economy	5200.00
0005433284954	23010	Economy	5200.00
0005433284777	23010	Economy	5200.00
0005435103900	23010	Economy	5200.00
0005435103889	23010	Economy	5200.00
0005433284955	23010	Economy	5200.00
0005433285029	23010	Economy	5200.00
0005433284904	23010	Economy	5200.00
0005435103886	23010	Economy	5200.00
0005433284928	23010	Economy	5200.00
0005433284905	23010	Economy	5700.00
0005435103894	23010	Economy	5200.00
0005433284956	23010	Economy	5200.00
0005435103891	23010	Economy	5200.00
0005435103901	23010	Economy	5200.00
0005435103898	23010	Economy	5200.00
0005435103899	23010	Economy	5200.00
0005433284973	23010	Economy	5200.00
0005433284822	23010	Economy	5200.00
0005433284911	23010	Economy	5200.00
0005435103896	23010	Economy	5200.00
0005433284821	23010	Economy	5200.00
0005435103887	23010	Economy	5200.00
0005435103895	23010	Economy	5200.00
0005435103897	23010	Economy	5200.00
0005433284888	23010	Economy	5200.00
0005433285195	32070	Business	15700.00
0005433285176	32070	Business	15700.00
0005433285197	32070	Business	15700.00
0005435103819	32070	Economy	5200.00
0005433285167	32070	Economy	5200.00
0005433285194	32070	Economy	5200.00
0005433285186	32070	Economy	5200.00
0005433285168	32070	Economy	5200.00
0005435103812	32070	Economy	5200.00
0005435103807	32070	Economy	5200.00
0005433285169	32070	Economy	5200.00
0005433285179	32070	Economy	5200.00
0005435103820	32070	Economy	5200.00
0005433285173	32070	Economy	5200.00
0005433285198	32070	Economy	5700.00
0005433285180	32070	Economy	5200.00
0005433285185	32070	Economy	5200.00
0005433285177	32070	Economy	5200.00
0005435103813	32070	Economy	5200.00
0005433285181	32070	Economy	5200.00
0005433285182	32070	Economy	5200.00
0005435103808	32070	Economy	5200.00
0005433285193	32070	Economy	5200.00
0005433285171	32070	Economy	5200.00
0005433285183	32070	Economy	5200.00
0005433285191	32070	Economy	5200.00
0005433285189	32070	Economy	5200.00
0005433285192	32070	Economy	5200.00
0005433285175	32070	Economy	5200.00
0005433285187	32070	Economy	5200.00
0005433285178	32070	Economy	5200.00
0005433285196	32070	Economy	5200.00
0005433285170	32070	Economy	5200.00
0005433285190	32070	Economy	5200.00
0005435103815	32070	Economy	5200.00
0005433285184	32070	Economy	5200.00
0005433285172	32070	Economy	5200.00
0005435103814	32070	Economy	5200.00
0005433285174	32070	Economy	5200.00
0005433285188	32070	Economy	5200.00
0005432526445	30592	Business	42100.00
0005432526498	30592	Business	42100.00
0005432526457	30592	Business	42100.00
0005432526108	30592	Business	42100.00
0005435213354	30592	Business	42100.00
0005432527192	30592	Business	42100.00
0005435213355	30592	Business	42100.00
0005435213320	30592	Business	42100.00
0005432526620	30592	Business	42100.00
0005435213339	30592	Business	42100.00
0005435213367	30592	Business	42100.00
0005434066474	30592	Business	42100.00
0005432211479	30592	Business	42100.00
0005435213315	30592	Business	42100.00
0005432526902	30592	Business	42100.00
0005432526864	30592	Business	42100.00
0005432211474	30592	Business	42100.00
0005434066364	30592	Business	42100.00
0005432526398	30592	Business	42100.00
0005435213311	30592	Business	42100.00
0005435630957	30592	Business	42100.00
0005432526508	30592	Business	42100.00
0005432159844	30592	Business	42100.00
0005432526253	30592	Business	42100.00
0005432526223	30592	Comfort	23900.00
0005435725584	30592	Comfort	23900.00
0005432526911	30592	Comfort	23900.00
0005435213350	30592	Comfort	23900.00
0005432526681	30592	Comfort	23900.00
0005432526468	30592	Comfort	23900.00
0005432526565	30592	Comfort	23900.00
0005432526295	30592	Comfort	23900.00
0005435213347	30592	Comfort	23900.00
0005432159841	30592	Comfort	23900.00
0005434066637	30592	Comfort	23900.00
0005435213348	30592	Comfort	23900.00
0005435213303	30592	Comfort	23900.00
0005434066752	30592	Comfort	23900.00
0005434066542	30592	Comfort	23900.00
0005435213319	30592	Comfort	23900.00
0005432526892	30592	Comfort	23900.00
0005432526787	30592	Comfort	23900.00
0005434066737	30592	Comfort	23900.00
0005434066849	30592	Comfort	23900.00
0005434066499	30592	Comfort	23900.00
0005432525829	30592	Comfort	23900.00
0005435213359	30592	Comfort	23900.00
0005432526274	30592	Comfort	23900.00
0005434066338	30592	Comfort	23900.00
0005434066577	30592	Comfort	23900.00
0005435213331	30592	Comfort	23900.00
0005435213341	30592	Comfort	23900.00
0005432526663	30592	Comfort	23900.00
0005432533252	30592	Comfort	23900.00
0005435213324	30592	Comfort	23900.00
0005432159842	30592	Comfort	23900.00
0005435213300	30592	Comfort	23900.00
0005434066329	30592	Comfort	23900.00
0005435213305	30592	Comfort	23900.00
0005434066648	30592	Comfort	23900.00
0005432526102	30592	Comfort	23900.00
0005432526551	30592	Comfort	23900.00
0005434066711	30592	Comfort	23900.00
0005432526694	30592	Comfort	23900.00
0005434066583	30592	Comfort	23900.00
0005432526769	30592	Economy	14000.00
0005432525960	30592	Comfort	23900.00
0005432537036	30592	Economy	14000.00
0005432526585	30592	Economy	14000.00
0005435213316	30592	Economy	14000.00
0005435725588	30592	Economy	14000.00
0005432526711	30592	Economy	14000.00
0005435213334	30592	Economy	14000.00
0005432525830	30592	Economy	14000.00
0005432526693	30592	Economy	14000.00
0005432526250	30592	Economy	14000.00
0005435213314	30592	Economy	14000.00
0005432537032	30592	Economy	14000.00
0005434066543	30592	Economy	14000.00
0005432211473	30592	Economy	14000.00
0005432526493	30592	Economy	14000.00
0005434066842	30592	Economy	14000.00
0005432159843	30592	Economy	14000.00
0005432526392	30592	Economy	14000.00
0005434066684	30592	Economy	14000.00
0005432526654	30592	Economy	14000.00
0005434066325	30592	Economy	14000.00
0005432526607	30592	Economy	14000.00
0005432526675	30592	Economy	14000.00
0005432526252	30592	Economy	14000.00
0005435213352	30592	Economy	14000.00
0005435213304	30592	Economy	14000.00
0005434066740	30592	Economy	14000.00
0005434066467	30592	Economy	14000.00
0005434066966	30592	Economy	14000.00
0005434066808	30592	Economy	14000.00
0005432526292	30592	Economy	14000.00
0005435213365	30592	Economy	14000.00
0005432527065	30592	Economy	14000.00
0005435213312	30592	Economy	14000.00
0005434066736	30592	Economy	14000.00
0005434066663	30592	Economy	14000.00
0005435213364	30592	Economy	14000.00
0005435213340	30592	Economy	14000.00
0005435213344	30592	Economy	14000.00
0005432526541	30592	Economy	14000.00
0005432526181	30592	Economy	14000.00
0005434066700	30592	Economy	14000.00
0005432526569	30592	Economy	14000.00
0005432526895	30592	Economy	14000.00
0005432526249	30592	Economy	14000.00
0005435213328	30592	Economy	14000.00
0005432525739	30592	Economy	14000.00
0005434066683	30592	Economy	14000.00
0005434066850	30592	Economy	14000.00
0005435630959	30592	Economy	14000.00
0005434066459	30592	Economy	14000.00
0005435213353	30592	Economy	14000.00
0005434066744	30592	Economy	14000.00
0005432526191	30592	Economy	14000.00
0005432526494	30592	Economy	14000.00
0005432535778	30592	Economy	14000.00
0005432537031	30592	Economy	14000.00
0005435725586	30592	Economy	14000.00
0005435213362	30592	Economy	14000.00
0005435213345	30592	Economy	15400.00
0005432211480	30592	Economy	14000.00
0005432526535	30592	Economy	15400.00
0005434066460	30592	Economy	14000.00
0005432527064	30592	Economy	14000.00
0005432526606	30592	Economy	14000.00
0005435213317	30592	Economy	15400.00
0005434066654	30592	Economy	15400.00
0005435725583	30592	Economy	14000.00
0005432526661	30592	Economy	14000.00
0005432537024	30592	Economy	14000.00
0005432428898	30592	Economy	14000.00
0005435213356	30592	Economy	14000.00
0005434066498	30592	Economy	14000.00
0005432526788	30592	Economy	14000.00
0005434066860	30592	Economy	14000.00
0005435213337	30592	Economy	14000.00
0005432526891	30592	Economy	14000.00
0005435213336	30592	Economy	14000.00
0005432526621	30592	Economy	14000.00
0005432526975	30592	Economy	14000.00
0005435213299	30592	Economy	14000.00
0005432527051	30592	Economy	14000.00
0005434066395	30592	Economy	14000.00
0005434066776	30592	Economy	14000.00
0005434066859	30592	Economy	14000.00
0005435213329	30592	Economy	14000.00
0005432526929	30592	Economy	14000.00
0005432525936	30592	Economy	14000.00
0005435213357	30592	Economy	14000.00
0005432525842	30592	Economy	14000.00
0005432526617	30592	Economy	14000.00
0005432526243	30592	Economy	14000.00
0005432526090	30592	Economy	14000.00
0005432526608	30592	Economy	14000.00
0005432211478	30592	Economy	14000.00
0005432526424	30592	Economy	14000.00
0005434066516	30592	Economy	14000.00
0005432527035	30592	Economy	14000.00
0005432537023	30592	Economy	14000.00
0005432526284	30592	Economy	14000.00
0005432535788	30592	Economy	14000.00
0005433656662	30592	Economy	14000.00
0005432526941	30592	Economy	14000.00
0005435213309	30592	Economy	14000.00
0005435213361	30592	Economy	14000.00
0005432533246	30592	Economy	14000.00
0005435213332	30592	Economy	14000.00
0005432525909	30592	Economy	14000.00
0005435725585	30592	Economy	14000.00
0005435213306	30592	Economy	14000.00
0005432533253	30592	Economy	14000.00
0005432525961	30592	Economy	14000.00
0005435213321	30592	Economy	14000.00
0005434066758	30592	Economy	14000.00
0005432526662	30592	Economy	14000.00
0005434066647	30592	Economy	14000.00
0005434066646	30592	Economy	14000.00
0005432526342	30592	Economy	14000.00
0005432526124	30592	Economy	14000.00
0005435213322	30592	Economy	14000.00
0005433656659	30592	Economy	14000.00
0005434066804	30592	Economy	14000.00
0005432525978	30592	Economy	14000.00
0005433656660	30592	Economy	14000.00
0005432526064	30592	Economy	14000.00
0005432535759	30592	Economy	14000.00
0005435213363	30592	Economy	14000.00
0005432526235	30592	Economy	14000.00
0005432526968	30592	Economy	14000.00
0005432526409	30592	Economy	14000.00
0005432526107	30592	Economy	14000.00
0005434066367	30592	Economy	14000.00
0005432526497	30592	Economy	14000.00
0005434066515	30592	Economy	14000.00
0005435213330	30592	Economy	14000.00
0005434066576	30592	Economy	14000.00
0005432526669	30592	Economy	14000.00
0005432526018	30592	Economy	14000.00
0005435213360	30592	Economy	14000.00
0005432526161	30592	Economy	14000.00
0005435725587	30592	Economy	14000.00
0005435213308	30592	Economy	14000.00
0005434066544	30592	Economy	14000.00
0005432526969	30592	Economy	14000.00
0005433656661	30592	Economy	14000.00
0005435213351	30592	Economy	14000.00
0005434066634	30592	Economy	14000.00
0005432526103	30592	Economy	14000.00
0005434066756	30592	Economy	14000.00
0005435213342	30592	Economy	14000.00
0005432526973	30592	Economy	14000.00
0005432526349	30592	Economy	14000.00
0005432526246	30592	Economy	14000.00
0005432526660	30592	Economy	14000.00
0005432526520	30592	Economy	14000.00
0005435213313	30592	Economy	14000.00
0005432526942	30592	Economy	14000.00
0005434066476	30592	Economy	14000.00
0005434066805	30592	Economy	15400.00
0005434066753	30592	Economy	14000.00
0005435213318	30592	Economy	15400.00
0005432526540	30592	Economy	15400.00
0005432526584	30592	Economy	15400.00
0005432428874	30592	Economy	15400.00
0005435213301	30592	Economy	14000.00
0005435213323	30592	Economy	14000.00
0005432526285	30592	Economy	14000.00
0005435213343	30592	Economy	14000.00
0005434066670	30592	Economy	14000.00
0005432526373	30592	Economy	14000.00
0005434066733	30592	Economy	14000.00
0005435213302	30592	Economy	14000.00
0005432526959	30592	Economy	14000.00
0005435630958	30592	Economy	14000.00
0005432526198	30592	Economy	14000.00
0005435213335	30592	Economy	14000.00
0005434066861	30592	Economy	14000.00
0005434066426	30592	Economy	14000.00
0005434066722	30592	Economy	14000.00
0005434066743	30592	Economy	14000.00
0005432526469	30592	Economy	14000.00
0005432211475	30592	Economy	14000.00
0005432533266	30592	Economy	14000.00
0005432526777	30592	Economy	14000.00
0005432526227	30592	Economy	14000.00
0005432526076	30592	Economy	14000.00
0005432526451	30592	Economy	14000.00
0005435213307	30592	Economy	14000.00
0005434066725	30592	Economy	14000.00
0005432526960	30592	Economy	14000.00
0005432211476	30592	Economy	14000.00
0005432526277	30592	Economy	14000.00
0005432526218	30592	Economy	14000.00
0005434066645	30592	Economy	14000.00
0005432211477	30592	Economy	14000.00
0005432526863	30592	Economy	14000.00
0005435213310	30592	Economy	14000.00
0005432526499	30592	Economy	14000.00
0005432537037	30592	Economy	14000.00
0005435213327	30592	Economy	14000.00
0005435213326	30592	Economy	14000.00
0005434066757	30592	Economy	14000.00
0005435213333	30592	Economy	14000.00
0005432526974	30592	Economy	14000.00
0005432526487	30592	Economy	14000.00
0005432526275	30592	Economy	14000.00
0005432526348	30592	Economy	14000.00
0005434066671	30592	Economy	14000.00
0005432526519	30592	Economy	14000.00
0005435213346	30592	Economy	14000.00
0005432526063	30592	Economy	14000.00
0005434066930	30592	Economy	14000.00
0005432526134	30592	Economy	14000.00
0005432526317	30592	Economy	14000.00
0005432526549	30592	Economy	14000.00
0005432527224	30592	Economy	14000.00
0005432526144	30592	Economy	14000.00
0005434066721	30592	Economy	14000.00
0005432526668	30592	Economy	14000.00
0005435213325	30592	Economy	14000.00
0005435213349	30592	Economy	14000.00
0005434066497	30592	Economy	14000.00
0005434066809	30592	Economy	14000.00
0005434066952	30592	Economy	14000.00
0005432526778	30592	Economy	14000.00
0005432525841	30592	Economy	14000.00
0005432526393	30592	Economy	14000.00
0005434066774	30592	Economy	14000.00
0005434066745	30592	Economy	14000.00
0005432526217	30592	Economy	14000.00
0005435725589	30592	Economy	14000.00
0005432526695	30592	Economy	14000.00
0005435213338	30592	Economy	14000.00
0005434066633	30592	Economy	14000.00
0005432526180	30592	Economy	14000.00
0005434066529	30592	Economy	14000.00
0005432526539	30592	Economy	14000.00
0005435213366	30592	Economy	14000.00
0005432526682	30592	Economy	14000.00
0005434066732	30592	Economy	14000.00
0005432526785	30592	Economy	14000.00
0005432526605	30592	Economy	14000.00
0005432533245	30592	Economy	14000.00
0005434066677	30592	Economy	14000.00
0005434066775	30592	Economy	14000.00
0005434066575	30592	Economy	14000.00
0005432526065	30592	Economy	14000.00
0005432526408	30592	Economy	14000.00
0005434066528	30592	Economy	14000.00
0005432525725	30592	Economy	14000.00
0005434066662	30592	Economy	14000.00
0005435213358	30592	Economy	14000.00
0005432526786	30592	Economy	14000.00
0005433367758	24844	Business	9800.00
0005435652510	24844	Business	9800.00
0005435652390	24844	Business	9800.00
0005433367785	24844	Business	9800.00
0005433367783	24844	Business	9800.00
0005435652428	24844	Business	9800.00
0005433367761	24844	Business	9800.00
0005435652608	24844	Business	9800.00
0005433367782	24844	Business	9800.00
0005435652582	24844	Business	9800.00
0005433367769	24844	Business	9800.00
0005435652505	24844	Business	9800.00
0005433367778	24844	Economy	3300.00
0005435652485	24844	Economy	3300.00
0005435652391	24844	Economy	3300.00
0005435652365	24844	Economy	3300.00
0005435652389	24844	Economy	3300.00
0005433367774	24844	Economy	3300.00
0005435652421	24844	Economy	3300.00
0005435652422	24844	Economy	3300.00
0005435652490	24844	Economy	3300.00
0005433367764	24844	Economy	3600.00
0005435652439	24844	Economy	3600.00
0005435652423	24844	Economy	3600.00
0005435652370	24844	Economy	3600.00
0005433367788	24844	Economy	3600.00
0005433367791	24844	Economy	3300.00
0005435652431	24844	Economy	3300.00
0005435652307	24844	Economy	3300.00
0005435652597	24844	Economy	3300.00
0005433367771	24844	Economy	3300.00
0005433367760	24844	Economy	3300.00
0005433367784	24844	Economy	3300.00
0005435652584	24844	Economy	3300.00
0005433367756	24844	Economy	3300.00
0005435652589	24844	Economy	3300.00
0005435652591	24844	Economy	3300.00
0005433367787	24844	Economy	3300.00
0005435652532	24844	Economy	3300.00
0005433367773	24844	Economy	3300.00
0005433367776	24844	Economy	3300.00
0005435652609	24844	Economy	3300.00
0005435652465	24844	Economy	3300.00
0005435652583	24844	Economy	3300.00
0005435652560	24844	Economy	3300.00
0005435652429	24844	Economy	3300.00
0005435652606	24844	Economy	3300.00
0005435652515	24844	Economy	3300.00
0005433367766	24844	Economy	3300.00
0005435652546	24844	Economy	3300.00
0005433367765	24844	Economy	3300.00
0005435652379	24844	Economy	3300.00
0005433367792	24844	Economy	3300.00
0005433367757	24844	Economy	3300.00
0005433367759	24844	Economy	3300.00
0005435652509	24844	Economy	3300.00
0005435652508	24844	Economy	3300.00
0005435652426	24844	Economy	3300.00
0005433367780	24844	Economy	3300.00
0005433367763	24844	Economy	3300.00
0005433367781	24844	Economy	3300.00
0005433367767	24844	Economy	3300.00
0005435652598	24844	Economy	3300.00
0005435652432	24844	Economy	3300.00
0005433367777	24844	Economy	3300.00
0005435652551	24844	Economy	3300.00
0005433367762	24844	Economy	3300.00
0005435652424	24844	Economy	3300.00
0005433367775	24844	Economy	3300.00
0005435652605	24844	Economy	3300.00
0005435652462	24844	Economy	3300.00
0005433367768	24844	Economy	3300.00
0005435652547	24844	Economy	3300.00
0005433367789	24844	Economy	3300.00
0005433367770	24844	Economy	3300.00
0005435652618	24844	Economy	3300.00
0005433367793	24844	Economy	3300.00
0005435652306	24844	Economy	3300.00
0005433367786	24844	Economy	3300.00
0005433367772	24844	Economy	3300.00
0005435652258	24844	Economy	3300.00
0005433367779	24844	Economy	3300.00
0005433367790	24844	Economy	3300.00
0005435949751	23309	Economy	20600.00
0005435949745	23309	Economy	18700.00
0005435949749	23309	Economy	18700.00
0005435949740	23309	Economy	18700.00
0005435949735	23309	Economy	18700.00
0005435949741	23309	Economy	18700.00
0005435949739	23309	Economy	18700.00
0005434979713	2069	Economy	10500.00
0005434979698	2069	Economy	10500.00
0005434979699	2069	Economy	10500.00
0005434979692	2069	Economy	9500.00
0005434979683	2069	Economy	9500.00
0005434979684	2069	Economy	9500.00
0005434979712	2069	Economy	9500.00
0005434979687	2069	Economy	9500.00
0005434979696	2069	Economy	9500.00
0005435801685	2069	Economy	9500.00
0005434979707	2069	Economy	9500.00
0005434979710	2069	Economy	9500.00
0005434979694	2069	Economy	9500.00
0005434979709	2069	Economy	9500.00
0005434979706	2069	Economy	9500.00
0005434979686	2069	Economy	9500.00
0005434979700	2069	Economy	9500.00
0005434979689	2069	Economy	9500.00
0005434979697	2069	Economy	9500.00
0005434979705	2069	Economy	9500.00
0005434979685	2069	Economy	9500.00
0005435801687	2069	Economy	9500.00
0005434979711	2069	Economy	9500.00
0005434979701	2069	Economy	9500.00
0005434979691	2069	Economy	9500.00
0005434979708	2069	Economy	9500.00
0005434979695	2069	Economy	9500.00
0005434979703	2069	Economy	9500.00
0005434979690	2069	Economy	9500.00
0005435801686	2069	Economy	9500.00
0005434979693	2069	Economy	9500.00
0005434979702	2069	Economy	9500.00
0005434979688	2069	Economy	9500.00
0005434979704	2069	Economy	9500.00
0005434979329	23570	Economy	10500.00
0005434979415	23570	Economy	10500.00
0005434979315	23570	Economy	10500.00
0005434979460	23570	Economy	10500.00
0005434979404	23570	Economy	9500.00
0005434979409	23570	Economy	9500.00
0005434979401	23570	Economy	9500.00
0005434979346	23570	Economy	9500.00
0005435801662	23570	Economy	9500.00
0005434979408	23570	Economy	9500.00
0005434979394	23570	Economy	9500.00
0005434979339	23570	Economy	9500.00
0005434979386	23570	Economy	9500.00
0005434979304	23570	Economy	9500.00
0005435801657	23570	Economy	9500.00
0005434979326	23570	Economy	9500.00
0005434979406	23570	Economy	9500.00
0005434979429	23570	Economy	9500.00
0005434979332	23570	Economy	9500.00
0005434979361	23570	Economy	9500.00
0005434979453	23570	Economy	9500.00
0005434979385	23570	Economy	9500.00
0005434979364	23570	Economy	9500.00
0005434979316	23570	Economy	9500.00
0005434979444	23570	Economy	9500.00
0005435801656	23570	Economy	9500.00
0005434979402	23570	Economy	9500.00
0005434979405	23570	Economy	9500.00
0005434979371	23570	Economy	9500.00
0005434979400	23570	Economy	9500.00
0005434979277	23570	Economy	9500.00
0005434979461	23570	Economy	9500.00
0005434979292	23570	Economy	9500.00
0005434979387	23570	Economy	9500.00
0005434979333	23570	Economy	9500.00
0005434979467	23570	Economy	9500.00
0005434979340	23570	Economy	9500.00
0005435801663	23570	Economy	9500.00
0005434979324	23570	Economy	9500.00
0005434979414	23570	Economy	9500.00
0005434952520	2638	Economy	5300.00
0005434952521	2638	Economy	5300.00
0005434952518	2638	Economy	5300.00
0005434952519	2638	Economy	5300.00
0005434952492	28219	Economy	5300.00
0005433256414	28219	Economy	5300.00
0005434952496	28219	Economy	5300.00
0005433256415	28219	Economy	5300.00
0005433111500	19776	Economy	8700.00
0005433111499	19776	Economy	8700.00
0005433111501	19776	Economy	8700.00
0005434136995	11965	Business	9700.00
0005434137050	11965	Business	9700.00
0005434137031	11965	Business	9700.00
0005434136903	11965	Business	9700.00
0005434137147	11965	Business	9700.00
0005434136869	11965	Business	9700.00
0005434137138	11965	Business	9700.00
0005434137205	11965	Business	9700.00
0005434137369	11965	Business	9700.00
0005434137366	11965	Business	9700.00
0005434136788	11965	Economy	3200.00
0005434137054	11965	Economy	3200.00
0005434137040	11965	Economy	3200.00
0005434137264	11965	Economy	3200.00
0005434137220	11965	Economy	3200.00
0005434137132	11965	Economy	3200.00
0005434136981	11965	Economy	3200.00
0005434137228	11965	Economy	3200.00
0005434136994	11965	Economy	3200.00
0005434137275	11965	Economy	3200.00
0005434137039	11965	Economy	3500.00
0005434136855	11965	Economy	3500.00
0005434136957	11965	Economy	3500.00
0005434137257	11965	Economy	3500.00
0005434137265	11965	Economy	3200.00
0005434137009	11965	Economy	3200.00
0005434137480	11965	Economy	3200.00
0005434137077	11965	Economy	3200.00
0005434137049	11965	Economy	3200.00
0005434137164	11965	Economy	3200.00
0005434137368	11965	Economy	3200.00
0005434137365	11965	Economy	3200.00
0005434137187	11965	Economy	3200.00
0005434137139	11965	Economy	3200.00
0005434137170	11965	Economy	3200.00
0005434137364	11965	Economy	3200.00
0005434137221	11965	Economy	3200.00
0005434137076	11965	Economy	3200.00
0005434137148	11965	Economy	3200.00
0005434136757	11965	Economy	3200.00
0005434137250	11965	Economy	3200.00
0005434137527	11965	Economy	3200.00
0005434136902	11965	Economy	3200.00
0005434137274	11965	Economy	3200.00
0005434137078	11965	Economy	3200.00
0005434137157	11965	Economy	3200.00
0005434136883	11965	Economy	3200.00
0005434137204	11965	Economy	3200.00
0005434137372	11965	Economy	3200.00
0005434136868	11965	Economy	3200.00
0005434137370	11965	Economy	3200.00
0005434137024	11965	Economy	3200.00
0005434137149	11965	Economy	3200.00
0005434137158	11965	Economy	3200.00
0005434137229	11965	Economy	3200.00
0005434137325	11965	Economy	3200.00
0005434137401	11965	Economy	3200.00
0005434136859	11965	Economy	3200.00
0005434137159	11965	Economy	3200.00
0005434137270	11965	Economy	3200.00
0005434137417	11965	Economy	3200.00
0005434137036	11965	Economy	3200.00
0005434137300	11965	Economy	3200.00
0005434137048	11965	Economy	3200.00
0005434137114	11965	Economy	3200.00
0005434137189	11965	Economy	3200.00
0005434136854	11965	Economy	3200.00
0005434137273	11965	Economy	3200.00
0005434137530	11965	Economy	3200.00
0005434137105	11965	Economy	3200.00
0005434137121	11965	Economy	3200.00
0005434137100	11965	Economy	3200.00
0005434137106	11965	Economy	3200.00
0005434137133	11965	Economy	3200.00
0005434137266	11965	Economy	3200.00
0005434136860	11965	Economy	3200.00
0005434137004	11965	Economy	3200.00
0005434136870	11965	Economy	3200.00
0005434137203	11965	Economy	3200.00
0005434137003	11965	Economy	3200.00
0005434137400	11965	Economy	3200.00
0005434137218	11965	Economy	3200.00
0005434136955	11965	Economy	3200.00
0005434137822	28759	Business	9700.00
0005434137858	28759	Business	9700.00
0005434137829	28759	Business	9700.00
0005434137816	28759	Business	9700.00
0005434137844	28759	Business	9700.00
0005434137838	28759	Business	9700.00
0005434137796	28759	Business	9700.00
0005434137803	28759	Business	9700.00
0005434137827	28759	Business	9700.00
0005434137798	28759	Business	9700.00
0005434137853	28759	Economy	3200.00
0005434137800	28759	Economy	3200.00
0005434137789	28759	Economy	3200.00
0005434137861	28759	Economy	3200.00
0005434137866	28759	Economy	3200.00
0005434137806	28759	Economy	3200.00
0005434137819	28759	Economy	3200.00
0005434137821	28759	Economy	3200.00
0005434137834	28759	Economy	3500.00
0005434137817	28759	Economy	3500.00
0005434137859	28759	Economy	3500.00
0005434137825	28759	Economy	3500.00
0005434137837	28759	Economy	3200.00
0005434137809	28759	Economy	3200.00
0005434137835	28759	Economy	3200.00
0005434137847	28759	Economy	3200.00
0005434137852	28759	Economy	3200.00
0005434137788	28759	Economy	3200.00
0005434137787	28759	Economy	3200.00
0005434137856	28759	Economy	3200.00
0005434137842	28759	Economy	3200.00
0005434137850	28759	Economy	3200.00
0005434137799	28759	Economy	3200.00
0005434137839	28759	Economy	3200.00
0005434137823	28759	Economy	3200.00
0005434137864	28759	Economy	3200.00
0005434137828	28759	Economy	3200.00
0005434137855	28759	Economy	3200.00
0005434137846	28759	Economy	3200.00
0005434137865	28759	Economy	3200.00
0005434137795	28759	Economy	3200.00
0005434137792	28759	Economy	3200.00
0005434137785	28759	Economy	3200.00
0005434137841	28759	Economy	3200.00
0005434137863	28759	Economy	3200.00
0005434137849	28759	Economy	3200.00
0005434137818	28759	Economy	3200.00
0005434137851	28759	Economy	3200.00
0005434137848	28759	Economy	3200.00
0005434137868	28759	Economy	3200.00
0005434137805	28759	Economy	3200.00
0005434137840	28759	Economy	3200.00
0005434137854	28759	Economy	3200.00
0005434137860	28759	Economy	3200.00
0005434137826	28759	Economy	3200.00
0005434137810	28759	Economy	3200.00
0005434137801	28759	Economy	3200.00
0005434137833	28759	Economy	3200.00
0005434137870	28759	Economy	3200.00
0005434137791	28759	Economy	3200.00
0005434137869	28759	Economy	3200.00
0005434137793	28759	Economy	3200.00
0005434137814	28759	Economy	3200.00
0005434137802	28759	Economy	3200.00
0005434137820	28759	Economy	3200.00
0005434137831	28759	Economy	3200.00
0005434137804	28759	Economy	3200.00
0005434137813	28759	Economy	3200.00
0005434137845	28759	Economy	3200.00
0005434137807	28759	Economy	3200.00
0005434137830	28759	Economy	3200.00
0005434137824	28759	Economy	3200.00
0005434137811	28759	Economy	3200.00
0005434137812	28759	Economy	3200.00
0005434137843	28759	Economy	3200.00
0005434137832	28759	Economy	3200.00
0005434137786	28759	Economy	3200.00
0005434137857	28759	Economy	3200.00
0005434137867	28759	Economy	3200.00
0005434137808	28759	Economy	3200.00
0005434137815	28759	Economy	3200.00
0005434137790	28759	Economy	3200.00
0005434137862	28759	Economy	3200.00
0005434137794	28759	Economy	3200.00
0005434137797	28759	Economy	3200.00
0005434137836	28759	Economy	3200.00
0005434513544	19095	Economy	26000.00
0005434516048	19095	Economy	23600.00
0005434516043	19095	Economy	23600.00
0005434190394	19095	Economy	23600.00
0005434516054	19095	Economy	23600.00
0005434190399	19095	Economy	23600.00
0005434513541	19095	Economy	23600.00
0005434513549	19095	Economy	23600.00
0005434190393	19095	Economy	23600.00
0005434513548	19095	Economy	23600.00
0005434190395	19095	Economy	23600.00
0005434190396	19095	Economy	23600.00
0005434516045	19095	Economy	23600.00
0005434190398	19095	Economy	23600.00
0005434516046	19095	Economy	23600.00
0005434516053	19095	Economy	23600.00
0005434190397	19095	Economy	23600.00
0005434513540	19095	Economy	23600.00
0005434516044	19095	Economy	23600.00
0005434513550	19095	Economy	23600.00
0005433534491	6805	Economy	9900.00
0005433538841	6805	Economy	9900.00
0005433538845	6805	Economy	9900.00
0005433538847	6805	Economy	9900.00
0005433534492	6805	Economy	9900.00
0005433538846	6805	Economy	9900.00
0005433538842	6805	Economy	9900.00
0005433538843	6805	Economy	9900.00
0005433538844	6805	Economy	9900.00
0005433538840	6805	Economy	9900.00
0005435259713	6805	Economy	9900.00
0005433538786	25015	Economy	10900.00
0005433538755	25015	Economy	9900.00
0005433538767	25015	Economy	9900.00
0005433538768	25015	Economy	9900.00
0005435259741	25015	Economy	9900.00
0005433538756	25015	Economy	9900.00
0005435259744	25015	Economy	9900.00
0005433534470	25015	Economy	9900.00
0005433538764	25015	Economy	9900.00
0005435259745	25015	Economy	9900.00
0005435259743	25015	Economy	9900.00
0005433538763	25015	Economy	9900.00
0005433534477	25015	Economy	9900.00
0005433538766	25015	Economy	9900.00
0005433534473	25015	Economy	9900.00
0005435259742	25015	Economy	9900.00
0005433538762	25015	Economy	9900.00
0005433534471	25015	Economy	9900.00
0005432922478	797	Economy	16100.00
0005432922463	797	Economy	14600.00
0005432922480	797	Economy	14600.00
0005433511928	797	Economy	14600.00
0005433511923	797	Economy	14600.00
0005433511924	797	Economy	14600.00
0005433511925	797	Economy	14600.00
0005432922479	797	Economy	14600.00
0005433511922	797	Economy	14600.00
0005433511927	797	Economy	14600.00
0005433511926	797	Economy	14600.00
0005433511921	797	Economy	14600.00
0005433511929	797	Economy	14600.00
0005433511863	16177	Economy	16100.00
0005433511862	16177	Economy	16100.00
0005432922512	16177	Economy	14600.00
0005432922513	16177	Economy	14600.00
0005433511899	16177	Economy	14600.00
0005433511884	16177	Economy	14600.00
0005433511879	16177	Economy	14600.00
0005432922514	16177	Economy	14600.00
0005433511880	16177	Economy	14600.00
0005432922511	16177	Economy	14600.00
0005433511866	16177	Economy	14600.00
0005435852541	4033	Economy	13500.00
0005435852538	4033	Economy	12300.00
0005435852537	4033	Economy	12300.00
0005433475696	4033	Economy	12300.00
0005433475693	4033	Economy	12300.00
0005435852550	4033	Economy	12300.00
0005433475689	4033	Economy	12300.00
0005435852534	4033	Economy	12300.00
0005435852539	4033	Economy	12300.00
0005433475697	4033	Economy	12300.00
0005433475694	4033	Economy	12300.00
0005433475690	4033	Economy	12300.00
0005435852552	4033	Economy	12300.00
0005435852536	4033	Economy	12300.00
0005433475691	4033	Economy	12300.00
0005433475692	4033	Economy	12300.00
0005435852535	4033	Economy	12300.00
0005435852540	4033	Economy	12300.00
0005433475695	4033	Economy	12300.00
0005435852551	4033	Economy	12300.00
0005435916135	3680	Economy	7900.00
0005435697269	3680	Economy	7900.00
0005435697263	3680	Economy	7900.00
0005434950517	3680	Economy	7200.00
0005435697253	3680	Economy	7200.00
0005435916143	3680	Economy	7200.00
0005435697256	3680	Economy	7200.00
0005435935013	3680	Economy	7200.00
0005435697274	3680	Economy	7200.00
0005435934998	3680	Economy	7200.00
0005434950514	3680	Economy	7200.00
0005435935012	3680	Economy	7200.00
0005435697258	3680	Economy	7200.00
0005435697260	3680	Economy	7200.00
0005435697252	3680	Economy	7200.00
0005435697254	3680	Economy	7200.00
0005435697266	3680	Economy	7200.00
0005435697273	3680	Economy	7200.00
0005435935011	3680	Economy	7200.00
0005435697268	3680	Economy	7200.00
0005435697246	3680	Economy	7200.00
0005435697249	3680	Economy	7200.00
0005435916134	3680	Economy	7200.00
0005435697245	3680	Economy	7200.00
0005435697261	3680	Economy	7200.00
0005435697257	3680	Economy	7200.00
0005435697272	3680	Economy	7200.00
0005435697267	3680	Economy	7200.00
0005435697251	3680	Economy	7200.00
0005435697262	3680	Economy	7200.00
0005435935014	3680	Economy	7200.00
0005435697248	3680	Economy	7200.00
0005435697271	3680	Economy	7200.00
0005435697264	3680	Economy	7200.00
0005435697250	3680	Economy	7200.00
0005435935015	3680	Economy	7200.00
0005434950516	3680	Economy	7200.00
0005435697259	3680	Economy	7200.00
0005434950515	3680	Economy	7200.00
0005435697270	3680	Economy	7200.00
0005435697247	3680	Economy	7200.00
0005435697265	3680	Economy	7200.00
0005435697255	3680	Economy	7200.00
0005435697006	16263	Economy	7900.00
0005434950466	16263	Economy	7900.00
0005435697109	16263	Economy	7200.00
0005435696980	16263	Economy	7200.00
0005435696979	16263	Economy	7200.00
0005435935031	16263	Economy	7200.00
0005435696929	16263	Economy	7200.00
0005435697075	16263	Economy	7200.00
0005435916160	16263	Economy	7200.00
0005435697086	16263	Economy	7200.00
0005435697110	16263	Economy	7200.00
0005435916159	16263	Economy	7200.00
0005435916158	16263	Economy	7200.00
0005434950455	16263	Economy	7200.00
0005435697067	16263	Economy	7200.00
0005435697091	16263	Economy	7200.00
0005435696917	16263	Economy	7200.00
0005435696981	16263	Economy	7200.00
0005435697076	16263	Economy	7200.00
0005435696971	16263	Economy	7200.00
0005434950480	16263	Economy	7200.00
0005435935032	16263	Economy	7200.00
0005435696901	16263	Economy	7200.00
0005435696972	16263	Economy	7200.00
0005434950467	16263	Economy	7200.00
0005435935030	16263	Economy	7200.00
0005435696863	16263	Economy	7200.00
0005435696862	16263	Economy	7200.00
0005435697083	16263	Economy	7200.00
0005435696939	16263	Economy	7200.00
0005435696982	16263	Economy	7200.00
0005434604887	3942	Economy	21300.00
0005435841464	3942	Economy	19300.00
0005432607554	3942	Economy	19300.00
0005432609717	3942	Economy	19300.00
0005432609719	3942	Economy	19300.00
0005432607553	3942	Economy	19300.00
0005434604886	3942	Economy	19300.00
0005432609718	3942	Economy	19300.00
0005434606820	3942	Economy	19300.00
0005433519444	3942	Economy	19300.00
0005433519442	3942	Economy	19300.00
0005433519443	3942	Economy	19300.00
0005434606819	3942	Economy	19300.00
0005432609720	3942	Economy	19300.00
0005432607555	3942	Economy	19300.00
0005433519446	3942	Economy	19300.00
0005433519445	3942	Economy	19300.00
0005435853598	3942	Economy	19300.00
0005434606782	22067	Economy	19300.00
0005433519405	22067	Economy	19300.00
0005433519395	22067	Economy	19300.00
0005435853607	22067	Economy	19300.00
0005434606783	22067	Economy	19300.00
0005433519422	22067	Economy	19300.00
0005435853608	22067	Economy	19300.00
0005433519406	22067	Economy	19300.00
0005434606775	22067	Economy	19300.00
0005433348916	695	Economy	3700.00
0005433348911	695	Economy	3700.00
0005435628715	695	Economy	3700.00
0005433348936	695	Economy	3700.00
0005433348910	695	Economy	3700.00
0005435628713	695	Economy	3700.00
0005435628716	695	Economy	3700.00
0005433348891	695	Economy	3700.00
0005435628714	695	Economy	3700.00
0005433348925	695	Economy	3700.00
0005433348937	695	Economy	3700.00
0005433348973	15941	Economy	3700.00
0005435628677	15941	Economy	3700.00
0005435628678	15941	Economy	3700.00
0005433348974	15941	Economy	3700.00
0005433348970	15941	Economy	3700.00
0005433348972	15941	Economy	3700.00
0005433348971	15941	Economy	3700.00
0005433348976	15941	Economy	3700.00
0005433348975	15941	Economy	3700.00
0005433159276	17157	Economy	7100.00
0005434445238	17157	Economy	7100.00
0005433158096	17157	Economy	7100.00
0005434445239	17157	Economy	7100.00
0005433158098	17157	Economy	7100.00
0005433159275	17157	Economy	7100.00
0005433158105	17157	Economy	7100.00
0005433158097	17157	Economy	7100.00
0005433158104	17157	Economy	7100.00
0005433159307	17653	Economy	7100.00
0005433159306	17653	Economy	7100.00
0005434445215	17653	Economy	7100.00
0005435132846	7916	Economy	5900.00
0005435132853	7916	Economy	5400.00
0005435132855	7916	Economy	5400.00
0005435383071	7916	Economy	5400.00
0005435132847	7916	Economy	5400.00
0005435132851	7916	Economy	5400.00
0005435383106	7916	Economy	5400.00
0005435132848	7916	Economy	5400.00
0005435132854	7916	Economy	5400.00
0005435132852	7916	Economy	5400.00
0005435132850	7916	Economy	5400.00
0005435132849	7916	Economy	5400.00
0005435383107	7916	Economy	5400.00
0005435383133	33088	Economy	5900.00
0005435132807	33088	Economy	5400.00
0005435132730	33088	Economy	5400.00
0005435383132	33088	Economy	5400.00
0005435132762	33088	Economy	5400.00
0005435132761	33088	Economy	5400.00
0005435132785	33088	Economy	5400.00
0005435132786	33088	Economy	5400.00
0005435383134	33088	Economy	5400.00
0005435132801	33088	Economy	5400.00
0005435132779	33088	Economy	5400.00
0005435132793	33088	Economy	5400.00
0005435132808	33088	Economy	5400.00
0005435132757	33088	Economy	5400.00
0005435383135	33088	Economy	5400.00
0005435383136	33088	Economy	5400.00
0005435132790	33088	Economy	5400.00
0005435132796	33088	Economy	5400.00
0005435132754	33088	Economy	5400.00
0005435132795	33088	Economy	5400.00
0005435132797	33088	Economy	5400.00
0005435132716	33088	Economy	5400.00
0005435132756	33088	Economy	5400.00
0005435132791	33088	Economy	5400.00
0005435132778	33088	Economy	5400.00
0005435160268	7491	Economy	12500.00
0005435160272	7491	Economy	12500.00
0005435160273	7491	Economy	12500.00
0005435160265	7491	Economy	12500.00
0005435160266	7491	Economy	12500.00
0005435160270	7491	Economy	12500.00
0005435160271	7491	Economy	12500.00
0005435390157	7491	Economy	12500.00
0005435160269	7491	Economy	12500.00
0005435160267	7491	Economy	12500.00
0005435160274	7491	Economy	12500.00
0005435160275	7491	Economy	12500.00
0005435390142	7491	Economy	12500.00
0005435160264	7491	Economy	12500.00
0005435390220	29531	Economy	12500.00
0005435160230	29531	Economy	12500.00
0005435390217	29531	Economy	12500.00
0005435160179	29531	Economy	12500.00
0005435160195	29531	Economy	12500.00
0005435390219	29531	Economy	12500.00
0005435160169	29531	Economy	12500.00
0005435160194	29531	Economy	12500.00
0005435390218	29531	Economy	12500.00
0005435390221	29531	Economy	12500.00
0005435390222	29531	Economy	12500.00
0005435160170	29531	Economy	12500.00
0005435390216	29531	Economy	12500.00
0005435160171	29531	Economy	12500.00
0005432394038	18430	Economy	4900.00
0005432394064	18430	Economy	4900.00
0005432398148	18430	Economy	4900.00
0005432394051	18430	Economy	4900.00
0005432394062	18430	Economy	4900.00
0005435178492	18430	Economy	4900.00
0005432394063	18430	Economy	4900.00
0005432398147	18430	Economy	4900.00
0005435178491	18430	Economy	4900.00
0005432394052	18430	Economy	4900.00
0005432394037	18430	Economy	4900.00
0005432400106	27163	Economy	4900.00
0005432400107	27163	Economy	4900.00
0005432398185	27163	Economy	4900.00
0005435178470	27163	Economy	4900.00
0005432400109	27163	Economy	4900.00
0005432398182	27163	Economy	4900.00
0005432398184	27163	Economy	4900.00
0005432400105	27163	Economy	4900.00
0005432400108	27163	Economy	4900.00
0005432398180	27163	Economy	4900.00
0005432398183	27163	Economy	4900.00
0005432398181	27163	Economy	4900.00
0005434191255	9772	Economy	4400.00
0005434191254	9772	Economy	4400.00
0005434191258	9772	Economy	4400.00
0005434504056	6557	Business	48400.00
0005434504046	6557	Business	48400.00
0005434504026	6557	Business	48400.00
0005434504054	6557	Business	48400.00
0005434504028	6557	Business	48400.00
0005434504048	6557	Business	48400.00
0005434504034	6557	Economy	16100.00
0005434504059	6557	Economy	16100.00
0005434504033	6557	Economy	16100.00
0005434504050	6557	Economy	16100.00
0005434504032	6557	Economy	16100.00
0005434504061	6557	Economy	16100.00
0005434504053	6557	Economy	16100.00
0005434504035	6557	Economy	16100.00
0005434504023	6557	Economy	16100.00
0005434504027	6557	Economy	16100.00
0005434504044	6557	Economy	16100.00
0005434504038	6557	Economy	16100.00
0005434504039	6557	Economy	16100.00
0005434504029	6557	Economy	16100.00
0005434504043	6557	Economy	16100.00
0005434504051	6557	Economy	16100.00
0005434504052	6557	Economy	16100.00
0005434504041	6557	Economy	16100.00
0005434504024	6557	Economy	16100.00
0005434504042	6557	Economy	16100.00
0005434504057	6557	Economy	16100.00
0005434504031	6557	Economy	16100.00
0005434504036	6557	Economy	16100.00
0005434504030	6557	Economy	16100.00
0005434504055	6557	Economy	16100.00
0005434504025	6557	Economy	16100.00
0005434504045	6557	Economy	16100.00
0005434504037	6557	Economy	16100.00
0005434504022	6557	Economy	16100.00
0005434504047	6557	Economy	16100.00
0005434504049	6557	Economy	16100.00
0005434504040	6557	Economy	16100.00
0005434504058	6557	Economy	16100.00
0005434504060	6557	Economy	16100.00
0005434503707	22678	Business	48400.00
0005434503510	22678	Business	48400.00
0005434503588	22678	Business	48400.00
0005434503518	22678	Business	48400.00
0005434503519	22678	Business	48400.00
0005434503553	22678	Business	48400.00
0005434503459	22678	Economy	16100.00
0005434503600	22678	Economy	16100.00
0005434503785	22678	Economy	16100.00
0005434503695	22678	Economy	16100.00
0005434503692	22678	Economy	16100.00
0005434503688	22678	Economy	16100.00
0005434503637	22678	Economy	16100.00
0005434503764	22678	Economy	17800.00
0005434503468	22678	Economy	17800.00
0005434503762	22678	Economy	16100.00
0005434503642	22678	Economy	16100.00
0005434503664	22678	Economy	16100.00
0005434503648	22678	Economy	16100.00
0005434503590	22678	Economy	16100.00
0005434503467	22678	Economy	16100.00
0005434503672	22678	Economy	16100.00
0005435103820	22678	Economy	16100.00
0005434503671	22678	Economy	16100.00
0005434503599	22678	Economy	16100.00
0005435103813	22678	Economy	16100.00
0005434503618	22678	Economy	16100.00
0005434503484	22678	Economy	16100.00
0005434503861	22678	Economy	16100.00
0005434503480	22678	Economy	16100.00
0005434503721	22678	Economy	16100.00
0005434503641	22678	Economy	16100.00
0005434503474	22678	Economy	16100.00
0005435103808	22678	Economy	16100.00
0005434503511	22678	Economy	16100.00
0005435103807	22678	Economy	16100.00
0005434503612	22678	Economy	16100.00
0005435103819	22678	Economy	16100.00
0005434503596	22678	Economy	16100.00
0005435103815	22678	Economy	16100.00
0005434503621	22678	Economy	16100.00
0005435103812	22678	Economy	16100.00
0005434503567	22678	Economy	16100.00
0005434503552	22678	Economy	16100.00
0005434503860	22678	Economy	16100.00
0005434503626	22678	Economy	16100.00
0005434503475	22678	Economy	16100.00
0005434503765	22678	Economy	16100.00
0005435103814	22678	Economy	16100.00
0005434503601	22678	Economy	16100.00
0005434503722	22678	Economy	16100.00
0005434503460	22678	Economy	16100.00
0005434503479	22678	Economy	16100.00
0005434503481	22678	Economy	16100.00
0005434503602	22678	Economy	16100.00
0005435652946	1647	Business	50000.00
0005433367500	1647	Business	50000.00
0005435652936	1647	Business	50000.00
0005435652929	1647	Business	50000.00
0005435652953	1647	Business	50000.00
0005435652923	1647	Business	50000.00
0005435652948	1647	Business	50000.00
0005433367495	1647	Business	50000.00
0005433367449	1647	Economy	16700.00
0005433367499	1647	Economy	16700.00
0005435652917	1647	Economy	16700.00
0005433367621	1647	Economy	16700.00
0005435652942	1647	Economy	16700.00
0005435652920	1647	Economy	16700.00
0005433367498	1647	Economy	16700.00
0005435652931	1647	Economy	18300.00
0005433367390	1647	Economy	18300.00
0005435652918	1647	Economy	18300.00
0005433367419	1647	Economy	16700.00
0005433367565	1647	Economy	16700.00
0005433367365	1647	Economy	16700.00
0005433367475	1647	Economy	16700.00
0005435652922	1647	Economy	16700.00
0005435652945	1647	Economy	16700.00
0005435652930	1647	Economy	16700.00
0005433367539	1647	Economy	16700.00
0005435652932	1647	Economy	16700.00
0005435652952	1647	Economy	16700.00
0005433367376	1647	Economy	16700.00
0005435652934	1647	Economy	16700.00
0005435652928	1647	Economy	16700.00
0005435652943	1647	Economy	16700.00
0005433367540	1647	Economy	16700.00
0005435652919	1647	Economy	16700.00
0005435652940	1647	Economy	16700.00
0005433367515	1647	Economy	16700.00
0005433367465	1647	Economy	16700.00
0005433367381	1647	Economy	16700.00
0005433367450	1647	Economy	16700.00
0005435652950	1647	Economy	16700.00
0005435652933	1647	Economy	16700.00
0005433367496	1647	Economy	16700.00
0005433367497	1647	Economy	16700.00
0005435652949	1647	Economy	16700.00
0005435652927	1647	Economy	16700.00
0005435652926	1647	Economy	16700.00
0005433367563	1647	Economy	16700.00
0005433367296	1647	Economy	16700.00
0005433367488	1647	Economy	16700.00
0005435652937	1647	Economy	16700.00
0005433367620	1647	Economy	16700.00
0005435652951	1647	Economy	16700.00
0005433367418	1647	Economy	16700.00
0005433367476	1647	Economy	16700.00
0005433367411	1647	Economy	16700.00
0005435652954	1647	Economy	16700.00
0005433367452	1647	Economy	16700.00
0005433367375	1647	Economy	16700.00
0005435652947	1647	Economy	16700.00
0005435652939	1647	Economy	16700.00
0005433367466	1647	Economy	16700.00
0005433367448	1647	Economy	16700.00
0005435652944	1647	Economy	16700.00
0005433367333	1647	Economy	16700.00
0005435652924	1647	Economy	16700.00
0005433367410	1647	Economy	16700.00
0005435652935	1647	Economy	16700.00
0005435652938	1647	Economy	16700.00
0005433367451	1647	Economy	16700.00
0005435652921	1647	Economy	16700.00
0005435652941	1647	Economy	16700.00
0005435652925	1647	Economy	16700.00
0005433367417	1647	Economy	16700.00
0005433367538	1647	Economy	16700.00
0005433367640	1647	Economy	16700.00
0005435652370	21676	Business	50000.00
0005435652421	21676	Business	50000.00
0005433367775	21676	Business	50000.00
0005435652389	21676	Business	50000.00
0005433367778	21676	Business	50000.00
0005435652597	21676	Business	50000.00
0005433367762	21676	Business	50000.00
0005433367789	21676	Business	50000.00
0005435652379	21676	Business	50000.00
0005433367785	21676	Business	50000.00
0005435652515	21676	Business	50000.00
0005435652365	21676	Business	50000.00
0005433367767	21676	Economy	16700.00
0005435652391	21676	Economy	16700.00
0005433367787	21676	Economy	16700.00
0005433367781	21676	Economy	16700.00
0005435652582	21676	Economy	16700.00
0005433367759	21676	Economy	16700.00
0005435652423	21676	Economy	16700.00
0005435652608	21676	Economy	16700.00
0005435652560	21676	Economy	16700.00
0005433367788	21676	Economy	16700.00
0005435652591	21676	Economy	18300.00
0005435652429	21676	Economy	18300.00
0005433367769	21676	Economy	18300.00
0005435652307	21676	Economy	18300.00
0005435652306	21676	Economy	16700.00
0005433367773	21676	Economy	16700.00
0005435652618	21676	Economy	16700.00
0005433367786	21676	Economy	16700.00
0005433367791	21676	Economy	16700.00
0005433367777	21676	Economy	16700.00
0005433367756	21676	Economy	16700.00
0005435652584	21676	Economy	16700.00
0005435652589	21676	Economy	16700.00
0005433367792	21676	Economy	16700.00
0005433367761	21676	Economy	16700.00
0005433367770	21676	Economy	16700.00
0005435652532	21676	Economy	16700.00
0005433367764	21676	Economy	16700.00
0005435652485	21676	Economy	16700.00
0005435652390	21676	Economy	16700.00
0005435652258	21676	Economy	16700.00
0005433367758	21676	Economy	16700.00
0005435652462	21676	Economy	16700.00
0005433367771	21676	Economy	16700.00
0005435652505	21676	Economy	16700.00
0005433367763	21676	Economy	16700.00
0005433367776	21676	Economy	16700.00
0005435652551	21676	Economy	16700.00
0005433367765	21676	Economy	16700.00
0005435652598	21676	Economy	16700.00
0005433367757	21676	Economy	16700.00
0005435652605	21676	Economy	16700.00
0005435652428	21676	Economy	16700.00
0005435652490	21676	Economy	16700.00
0005435652546	21676	Economy	16700.00
0005435652606	21676	Economy	16700.00
0005433367780	21676	Economy	16700.00
0005433367782	21676	Economy	16700.00
0005435652509	21676	Economy	16700.00
0005435652431	21676	Economy	16700.00
0005433367766	21676	Economy	16700.00
0005435652547	21676	Economy	16700.00
0005433367772	21676	Economy	16700.00
0005435652465	21676	Economy	16700.00
0005433367760	21676	Economy	16700.00
0005435652422	21676	Economy	16700.00
0005435652508	21676	Economy	16700.00
0005435652609	21676	Economy	16700.00
0005435652426	21676	Economy	16700.00
0005433367779	21676	Economy	16700.00
0005433367783	21676	Economy	16700.00
0005433367774	21676	Economy	16700.00
0005435652439	21676	Economy	16700.00
0005433367790	21676	Economy	16700.00
0005435652583	21676	Economy	16700.00
0005433367793	21676	Economy	16700.00
0005433367784	21676	Economy	16700.00
0005435652432	21676	Economy	16700.00
0005433367768	21676	Economy	16700.00
0005435652510	21676	Economy	16700.00
0005435652424	21676	Economy	16700.00
0005435627117	12271	Economy	11200.00
0005435627116	12271	Economy	11200.00
0005433985800	4148	Business	21500.00
0005433985821	4148	Business	21500.00
0005435788764	4148	Business	21500.00
0005433985819	4148	Business	21500.00
0005433985837	4148	Business	21500.00
0005433985810	4148	Economy	7200.00
0005433985803	4148	Economy	7200.00
0005433985799	4148	Economy	7200.00
0005433985796	4148	Economy	7200.00
0005433985808	4148	Economy	7200.00
0005433985830	4148	Economy	7200.00
0005433985811	4148	Economy	7200.00
0005433985833	4148	Economy	7900.00
0005433985824	4148	Economy	7900.00
0005433985802	4148	Economy	7900.00
0005433985792	4148	Economy	7200.00
0005433985839	4148	Economy	7200.00
0005433985832	4148	Economy	7200.00
0005433985827	4148	Economy	7200.00
0005433985806	4148	Economy	7200.00
0005433985807	4148	Economy	7200.00
0005433985826	4148	Economy	7200.00
0005433985816	4148	Economy	7200.00
0005433985822	4148	Economy	7200.00
0005433985809	4148	Economy	7200.00
0005433985825	4148	Economy	7200.00
0005433985828	4148	Economy	7200.00
0005433985797	4148	Economy	7200.00
0005433985791	4148	Economy	7200.00
0005433985829	4148	Economy	7200.00
0005433985818	4148	Economy	7200.00
0005433985836	4148	Economy	7200.00
0005433985801	4148	Economy	7200.00
0005433985805	4148	Economy	7200.00
0005433985814	4148	Economy	7200.00
0005433985812	4148	Economy	7200.00
0005435788763	4148	Economy	7200.00
0005433985795	4148	Economy	7200.00
0005433985794	4148	Economy	7200.00
0005433985813	4148	Economy	7200.00
0005433985815	4148	Economy	7200.00
0005433985831	4148	Economy	7200.00
0005433985793	4148	Economy	7200.00
0005433985834	4148	Economy	7200.00
0005433985823	4148	Economy	7200.00
0005433985835	4148	Economy	7200.00
0005433985804	4148	Economy	7200.00
0005433985817	4148	Economy	7200.00
0005433985820	4148	Economy	7200.00
0005433985798	4148	Economy	7200.00
0005433985838	4148	Economy	7200.00
0005433985361	25648	Business	21500.00
0005433985439	25648	Business	21500.00
0005433985395	25648	Business	21500.00
0005433985413	25648	Business	21500.00
0005435788737	25648	Business	21500.00
0005433985252	25648	Business	21500.00
0005433985407	25648	Business	21500.00
0005433985331	25648	Business	21500.00
0005433985340	25648	Economy	7200.00
0005433985330	25648	Economy	7200.00
0005433985545	25648	Economy	7200.00
0005433985415	25648	Economy	7200.00
0005433985393	25648	Economy	7200.00
0005433985504	25648	Economy	7200.00
0005433985342	25648	Economy	7200.00
0005433985181	25648	Economy	7900.00
0005433985414	25648	Economy	7900.00
0005433985508	25648	Economy	7900.00
0005433985515	25648	Economy	7200.00
0005435788752	25648	Economy	7200.00
0005433985211	25648	Economy	7200.00
0005433985308	25648	Economy	7200.00
0005433985528	25648	Economy	7200.00
0005433985372	25648	Economy	7200.00
0005433985290	25648	Economy	7200.00
0005433985460	25648	Economy	7200.00
0005433985546	25648	Economy	7200.00
0005433985284	25648	Economy	7200.00
0005433985341	25648	Economy	7200.00
0005433985210	25648	Economy	7200.00
0005433985235	25648	Economy	7200.00
0005433985251	25648	Economy	7200.00
0005433985554	25648	Economy	7200.00
0005433985539	25648	Economy	7200.00
0005433985474	25648	Economy	7200.00
0005433985450	25648	Economy	7200.00
0005433985289	25648	Economy	7200.00
0005433985367	25648	Economy	7200.00
0005435788735	25648	Economy	7200.00
0005433985392	25648	Economy	7200.00
0005433985213	25648	Economy	7200.00
0005433985366	25648	Economy	7200.00
0005433985263	25648	Economy	7200.00
0005433985326	25648	Economy	7200.00
0005433985182	25648	Economy	7200.00
0005433985219	25648	Economy	7200.00
0005433985352	25648	Economy	7200.00
0005433985320	25648	Economy	7200.00
0005433985179	25648	Economy	7200.00
0005433985510	25648	Economy	7200.00
0005433985473	25648	Economy	7200.00
0005433985279	25648	Economy	7200.00
0005433985516	25648	Economy	7200.00
0005433985363	25648	Economy	7200.00
0005433985305	25648	Economy	7200.00
0005433985291	25648	Economy	7200.00
0005433985368	25648	Economy	7200.00
0005433985264	25648	Economy	7200.00
0005433985438	25648	Economy	7200.00
0005433985437	25648	Economy	7200.00
0005433985561	25648	Economy	7200.00
0005433985394	25648	Economy	7200.00
0005433985218	25648	Economy	7200.00
0005433985491	25648	Economy	7200.00
0005433985540	25648	Economy	7200.00
0005433461570	20240	Business	201300.00
0005433460415	20240	Business	201300.00
0005433461579	20240	Business	201300.00
0005433461571	20240	Business	201300.00
0005433460418	20240	Economy	73800.00
0005433461572	20240	Economy	67100.00
0005433461567	20240	Economy	67100.00
0005433460419	20240	Economy	67100.00
0005433461578	20240	Economy	67100.00
0005433460426	20240	Economy	67100.00
0005433461566	20240	Economy	67100.00
0005433461580	20240	Economy	67100.00
0005433461575	20240	Economy	67100.00
0005433460420	20240	Economy	67100.00
0005433461569	20240	Economy	67100.00
0005433461574	20240	Economy	67100.00
0005433460423	20240	Economy	67100.00
0005433461576	20240	Economy	67100.00
0005433461577	20240	Economy	67100.00
0005433461573	20240	Economy	67100.00
0005433460425	20240	Economy	67100.00
0005433460428	20240	Economy	67100.00
0005433460422	20240	Economy	67100.00
0005433460427	20240	Economy	67100.00
0005433460414	20240	Economy	67100.00
0005433460416	20240	Economy	67100.00
0005433460424	20240	Economy	67100.00
0005433460417	20240	Economy	67100.00
0005433460421	20240	Economy	67100.00
0005433460413	20240	Economy	67100.00
0005433461568	20240	Economy	67100.00
0005433461565	20240	Economy	67100.00
0005435719565	24753	Economy	9400.00
0005433168361	21319	Economy	15500.00
0005433168359	21319	Economy	15500.00
0005434509054	21319	Economy	15500.00
0005434509064	21319	Economy	15500.00
0005434509066	21319	Economy	15500.00
0005434509065	21319	Economy	15500.00
0005434509073	21319	Economy	15500.00
0005434509069	21319	Economy	15500.00
0005433168357	21319	Economy	15500.00
0005433168362	21319	Economy	15500.00
0005433168356	21319	Economy	15500.00
0005434509070	21319	Economy	15500.00
0005433168363	21319	Economy	15500.00
0005434509074	21319	Economy	15500.00
0005434509061	21319	Economy	15500.00
0005434509072	21319	Economy	15500.00
0005434509067	21319	Economy	15500.00
0005434509076	21319	Economy	15500.00
0005433168358	21319	Economy	15500.00
0005434509043	21319	Economy	15500.00
0005434509044	21319	Economy	15500.00
0005434509060	21319	Economy	15500.00
0005433168360	21319	Economy	15500.00
0005434509055	21319	Economy	15500.00
0005432655434	17873	Business	18000.00
0005432658564	17873	Business	18000.00
0005434151698	17873	Business	18000.00
0005432665247	17873	Business	18000.00
0005432655333	17873	Business	18000.00
0005432869509	17873	Economy	6000.00
0005432665246	17873	Economy	6600.00
0005432655391	17873	Economy	6000.00
0005432655332	17873	Economy	6000.00
0005432667430	17873	Economy	6000.00
0005432658562	17873	Economy	6000.00
0005432869511	17873	Economy	6000.00
0005432869508	17873	Economy	6000.00
0005432657402	17873	Economy	6000.00
0005432665248	17873	Economy	6000.00
0005432655377	17873	Economy	6000.00
0005432655380	17873	Economy	6000.00
0005432869510	17873	Economy	6000.00
0005432869507	17873	Economy	6000.00
0005432655433	17873	Economy	6000.00
0005432665251	17873	Economy	6000.00
0005432657395	17873	Economy	6000.00
0005432655378	17873	Economy	6000.00
0005432657421	17873	Economy	6000.00
0005432655429	17873	Economy	6000.00
0005432667431	17873	Economy	6000.00
0005432657403	17873	Economy	6000.00
0005432660794	17873	Economy	6000.00
0005432655435	17873	Economy	6000.00
0005432655475	26286	Business	18000.00
0005432659697	26286	Business	18000.00
0005432655480	26286	Business	18000.00
0005432657435	26286	Business	18000.00
0005432657437	26286	Business	18000.00
0005432658582	26286	Business	18000.00
0005434151675	26286	Economy	6000.00
0005432869459	26286	Economy	6000.00
0005432655481	26286	Economy	6000.00
0005432869414	26286	Economy	6000.00
0005432660810	26286	Economy	6600.00
0005432657436	26286	Economy	6000.00
0005432655478	26286	Economy	6000.00
0005432660809	26286	Economy	6000.00
0005432869460	26286	Economy	6000.00
0005432665266	26286	Economy	6000.00
0005432869428	26286	Economy	6000.00
0005432660808	26286	Economy	6000.00
0005432655482	26286	Economy	6000.00
0005432655472	26286	Economy	6000.00
0005432659698	26286	Economy	6000.00
0005432655474	26286	Economy	6000.00
0005432869455	26286	Economy	6000.00
0005432655473	26286	Economy	6000.00
0005434151670	26286	Economy	6000.00
0005432869435	26286	Economy	6000.00
0005432667446	26286	Economy	6000.00
0005432655476	26286	Economy	6000.00
0005432655483	26286	Economy	6000.00
0005432665265	26286	Economy	6000.00
0005432666379	26286	Economy	6000.00
0005432666380	26286	Economy	6000.00
0005432655484	26286	Economy	6000.00
0005432655477	26286	Economy	6000.00
0005432667445	26286	Economy	6000.00
0005432667444	26286	Economy	6000.00
0005432655479	26286	Economy	6000.00
0005434151671	26286	Economy	6000.00
0005434151674	26286	Economy	6000.00
0005432328550	3072	Business	16100.00
0005432328560	3072	Business	16100.00
0005433438857	3072	Business	16100.00
0005432328573	3072	Business	16100.00
0005432328565	3072	Business	16100.00
0005432287174	3072	Business	16100.00
0005432328558	3072	Business	16100.00
0005432328569	3072	Business	16100.00
0005432328552	3072	Economy	5400.00
0005432328581	3072	Economy	5400.00
0005432287177	3072	Economy	5400.00
0005433438858	3072	Economy	5400.00
0005432328592	3072	Economy	5400.00
0005432905088	3072	Economy	5400.00
0005432328577	3072	Economy	5400.00
0005432848836	3072	Economy	5400.00
0005433438851	3072	Economy	5900.00
0005432328572	3072	Economy	5900.00
0005432328582	3072	Economy	5900.00
0005432328563	3072	Economy	5900.00
0005432328562	3072	Economy	5400.00
0005432328587	3072	Economy	5400.00
0005432328556	3072	Economy	5400.00
0005433438849	3072	Economy	5400.00
0005433438855	3072	Economy	5400.00
0005432328553	3072	Economy	5400.00
0005432328554	3072	Economy	5400.00
0005432328589	3072	Economy	5400.00
0005432328575	3072	Economy	5400.00
0005432905090	3072	Economy	5400.00
0005432328551	3072	Economy	5400.00
0005432905053	3072	Economy	5400.00
0005432328586	3072	Economy	5400.00
0005432328567	3072	Economy	5400.00
0005432328564	3072	Economy	5400.00
0005432328580	3072	Economy	5400.00
0005433438854	3072	Economy	5400.00
0005432328591	3072	Economy	5400.00
0005432328588	3072	Economy	5400.00
0005433438850	3072	Economy	5400.00
0005432328594	3072	Economy	5400.00
0005432328576	3072	Economy	5400.00
0005432328583	3072	Economy	5400.00
0005432328584	3072	Economy	5400.00
0005432328574	3072	Economy	5400.00
0005432328570	3072	Economy	5400.00
0005432328593	3072	Economy	5400.00
0005432328559	3072	Economy	5400.00
0005433438856	3072	Economy	5400.00
0005432328590	3072	Economy	5400.00
0005432328579	3072	Economy	5400.00
0005432328585	3072	Economy	5400.00
0005432287176	3072	Economy	5400.00
0005432328555	3072	Economy	5400.00
0005432287173	3072	Economy	5400.00
0005432328571	3072	Economy	5400.00
0005432287175	3072	Economy	5400.00
0005432328578	3072	Economy	5400.00
0005433438852	3072	Economy	5400.00
0005432328568	3072	Economy	5400.00
0005432287172	3072	Economy	5400.00
0005432905089	3072	Economy	5400.00
0005432328561	3072	Economy	5400.00
0005432328566	3072	Economy	5400.00
0005433438853	3072	Economy	5400.00
0005432328557	3072	Economy	5400.00
0005432328093	31099	Business	16100.00
0005432328114	31099	Business	16100.00
0005432054294	31099	Business	16100.00
0005432328098	31099	Business	16100.00
0005432328246	31099	Economy	5400.00
0005432327942	31099	Economy	5400.00
0005432328115	31099	Economy	5400.00
0005433438806	31099	Economy	5400.00
0005432328037	31099	Economy	5400.00
0005432328125	31099	Economy	5400.00
0005432328295	31099	Economy	5400.00
0005432905113	31099	Economy	5900.00
0005433438810	31099	Economy	5900.00
0005432328038	31099	Economy	5900.00
0005432328059	31099	Economy	5400.00
0005432328245	31099	Economy	5400.00
0005432328250	31099	Economy	5400.00
0005432905111	31099	Economy	5400.00
0005432905112	31099	Economy	5400.00
0005432328069	31099	Economy	5400.00
0005432328148	31099	Economy	5400.00
0005432328248	31099	Economy	5400.00
0005432328163	31099	Economy	5400.00
0005432327947	31099	Economy	5400.00
0005432905109	31099	Economy	5400.00
0005432328367	31099	Economy	5400.00
0005432328249	31099	Economy	5400.00
0005432054295	31099	Economy	5400.00
0005432905110	31099	Economy	5400.00
0005432328182	31099	Economy	5400.00
0005432328127	31099	Economy	5400.00
0005432328141	31099	Economy	5400.00
0005432328142	31099	Economy	5400.00
0005432328145	31099	Economy	5400.00
0005432327985	31099	Economy	5400.00
0005432328068	31099	Economy	5400.00
0005432328087	31099	Economy	5400.00
0005433438804	31099	Economy	5400.00
0005433438809	31099	Economy	5400.00
0005432905114	31099	Economy	5400.00
0005432328150	31099	Economy	5400.00
0005432328085	31099	Economy	5400.00
0005433438796	31099	Economy	5400.00
0005432328309	31099	Economy	5400.00
0005432328144	31099	Economy	5400.00
0005432327943	31099	Economy	5400.00
0005432328211	31099	Economy	5400.00
0005432328149	31099	Economy	5400.00
0005432328316	31099	Economy	5400.00
0005432328269	31099	Economy	5400.00
0005432327996	31099	Economy	5400.00
0005432054296	31099	Economy	5400.00
0005433438779	31099	Economy	5400.00
0005432328126	31099	Economy	5400.00
0005432328099	31099	Economy	5400.00
0005432328218	31099	Economy	5400.00
0005435999207	6228	Business	124600.00
0005435999201	6228	Business	124600.00
0005434309709	6228	Business	124600.00
0005435487634	6228	Business	124600.00
0005435487495	6228	Business	124600.00
0005435296989	6228	Business	124600.00
0005435487637	6228	Economy	41500.00
0005435999217	6228	Economy	41500.00
0005435999208	6228	Economy	41500.00
0005435487550	6228	Economy	41500.00
0005435999199	6228	Economy	41500.00
0005432146193	6228	Economy	41500.00
0005435296988	6228	Economy	41500.00
0005435487577	6228	Economy	41500.00
0005435999210	6228	Economy	41500.00
0005435487520	6228	Economy	41500.00
0005435999209	6228	Economy	41500.00
0005434309707	6228	Economy	41500.00
0005435999214	6228	Economy	41500.00
0005435999212	6228	Economy	41500.00
0005435487501	6228	Economy	41500.00
0005435999196	6228	Economy	41500.00
0005435487538	6228	Economy	41500.00
0005434309702	6228	Economy	41500.00
0005435296973	6228	Economy	41500.00
0005434309697	6228	Economy	41500.00
0005432146192	6228	Economy	45700.00
0005435296965	6228	Economy	45700.00
0005435487557	6228	Economy	45700.00
0005435487564	6228	Economy	45700.00
0005435296985	6228	Economy	41500.00
0005435999200	6228	Economy	41500.00
0005434309706	6228	Economy	41500.00
0005434309703	6228	Economy	41500.00
0005435487516	6228	Economy	41500.00
0005435487565	6228	Economy	41500.00
0005435487619	6228	Economy	41500.00
0005435999213	6228	Economy	41500.00
0005434309701	6228	Economy	41500.00
0005435487540	6228	Economy	41500.00
0005435487549	6228	Economy	41500.00
0005435487539	6228	Economy	41500.00
0005434309698	6228	Economy	41500.00
0005435487494	6228	Economy	41500.00
0005434309705	6228	Economy	41500.00
0005435487578	6228	Economy	41500.00
0005434309700	6228	Economy	41500.00
0005435999205	6228	Economy	41500.00
0005434309708	6228	Economy	41500.00
0005435999216	6228	Economy	41500.00
0005435999215	6228	Economy	41500.00
0005435999211	6228	Economy	41500.00
0005434309696	6228	Economy	41500.00
0005435296986	6228	Economy	41500.00
0005435487469	6228	Economy	41500.00
0005435999202	6228	Economy	41500.00
0005435999206	6228	Economy	41500.00
0005435999197	6228	Economy	41500.00
0005435296974	6228	Economy	41500.00
0005435999204	6228	Economy	41500.00
0005435296975	6228	Economy	41500.00
0005435999198	6228	Economy	41500.00
0005435296966	6228	Economy	41500.00
0005434309699	6228	Economy	41500.00
0005432146194	6228	Economy	41500.00
0005435487568	6228	Economy	41500.00
0005435999203	6228	Economy	41500.00
0005434309704	6228	Economy	41500.00
0005435487502	6228	Economy	41500.00
0005435999000	19578	Business	124600.00
0005435999004	19578	Business	124600.00
0005435487747	19578	Business	124600.00
0005435487763	19578	Business	124600.00
0005434309575	19578	Business	124600.00
0005435297036	19578	Business	124600.00
0005435487752	19578	Business	124600.00
0005434309547	19578	Business	124600.00
0005435487754	19578	Economy	41500.00
0005435999041	19578	Economy	41500.00
0005434309576	19578	Economy	41500.00
0005435999027	19578	Economy	41500.00
0005435487745	19578	Economy	41500.00
0005435999009	19578	Economy	41500.00
0005435297038	19578	Economy	41500.00
0005434309607	19578	Economy	41500.00
0005434309545	19578	Economy	41500.00
0005434309602	19578	Economy	41500.00
0005435487757	19578	Economy	41500.00
0005435998970	19578	Economy	41500.00
0005435487746	19578	Economy	41500.00
0005434309618	19578	Economy	41500.00
0005435487761	19578	Economy	41500.00
0005434309560	19578	Economy	41500.00
0005434309581	19578	Economy	41500.00
0005434309610	19578	Economy	41500.00
0005435487759	19578	Economy	45700.00
0005434309611	19578	Economy	45700.00
0005434309571	19578	Economy	41500.00
0005434309546	19578	Economy	41500.00
0005435297041	19578	Economy	41500.00
0005435487758	19578	Economy	41500.00
0005435487762	19578	Economy	41500.00
0005435998982	19578	Economy	41500.00
0005435487743	19578	Economy	41500.00
0005434309577	19578	Economy	41500.00
0005435487744	19578	Economy	41500.00
0005435297039	19578	Economy	41500.00
0005435487742	19578	Economy	41500.00
0005434309629	19578	Economy	41500.00
0005435998980	19578	Economy	41500.00
0005435487753	19578	Economy	41500.00
0005435487751	19578	Economy	41500.00
0005435297040	19578	Economy	41500.00
0005435999002	19578	Economy	41500.00
0005435998978	19578	Economy	41500.00
0005435297042	19578	Economy	41500.00
0005435999008	19578	Economy	41500.00
0005434309572	19578	Economy	41500.00
0005435999032	19578	Economy	41500.00
0005435999023	19578	Economy	41500.00
0005435999028	19578	Economy	41500.00
0005435999031	19578	Economy	41500.00
0005435487748	19578	Economy	41500.00
0005435487741	19578	Economy	41500.00
0005435999003	19578	Economy	41500.00
0005435487756	19578	Economy	41500.00
0005435999013	19578	Economy	41500.00
0005435487750	19578	Economy	41500.00
0005434309530	19578	Economy	41500.00
0005435999024	19578	Economy	41500.00
0005434309636	19578	Economy	41500.00
0005435297037	19578	Economy	41500.00
0005435487760	19578	Economy	41500.00
0005435487755	19578	Economy	41500.00
0005435487749	19578	Economy	41500.00
0005433158123	17558	Economy	13600.00
0005434446495	17558	Economy	13600.00
0005433158120	17558	Economy	12300.00
0005433158124	17558	Economy	12300.00
0005433158125	17558	Economy	12300.00
0005434446485	17558	Economy	12300.00
0005434446491	17558	Economy	12300.00
0005434446488	17558	Economy	12300.00
0005433158122	17558	Economy	12300.00
0005434446486	17558	Economy	12300.00
0005433158121	17558	Economy	12300.00
0005433158126	17558	Economy	12300.00
0005434446487	17558	Economy	12300.00
0005433158127	17558	Economy	12300.00
0005435508330	1592	Business	86000.00
0005434565871	1592	Business	86000.00
0005432291924	1592	Business	86000.00
0005435517857	1592	Business	86000.00
0005435502249	1592	Business	86000.00
0005435508325	1592	Business	86000.00
0005435502246	1592	Business	86000.00
0005435508323	1592	Business	86000.00
0005435502250	1592	Business	86000.00
0005435502251	1592	Business	86000.00
0005434565876	1592	Business	86000.00
0005435502264	1592	Business	86000.00
0005435508324	1592	Economy	28700.00
0005434565875	1592	Economy	28700.00
0005435517856	1592	Economy	28700.00
0005434565884	1592	Economy	28700.00
0005435502261	1592	Economy	28700.00
0005435508329	1592	Economy	28700.00
0005435517852	1592	Economy	28700.00
0005435517865	1592	Economy	31500.00
0005433186028	1592	Economy	31500.00
0005435502257	1592	Economy	31500.00
0005434565879	1592	Economy	31500.00
0005433186004	1592	Economy	31500.00
0005435517858	1592	Economy	28700.00
0005435502245	1592	Economy	28700.00
0005434565874	1592	Economy	28700.00
0005435517868	1592	Economy	28700.00
0005435517859	1592	Economy	28700.00
0005435502258	1592	Economy	28700.00
0005435502248	1592	Economy	28700.00
0005435517854	1592	Economy	28700.00
0005435517872	1592	Economy	28700.00
0005435502263	1592	Economy	28700.00
0005435517862	1592	Economy	28700.00
0005435517861	1592	Economy	28700.00
0005434565878	1592	Economy	28700.00
0005434565881	1592	Economy	28700.00
0005435502253	1592	Economy	28700.00
0005432291922	1592	Economy	28700.00
0005435508333	1592	Economy	28700.00
0005435508327	1592	Economy	28700.00
0005434565883	1592	Economy	28700.00
0005435502255	1592	Economy	28700.00
0005435502262	1592	Economy	28700.00
0005434565877	1592	Economy	28700.00
0005435517860	1592	Economy	28700.00
0005435502243	1592	Economy	28700.00
0005435508336	1592	Economy	28700.00
0005434565882	1592	Economy	28700.00
0005435502247	1592	Economy	28700.00
0005435502254	1592	Economy	28700.00
0005435508331	1592	Economy	28700.00
0005435508335	1592	Economy	28700.00
0005435517855	1592	Economy	28700.00
0005435502256	1592	Economy	28700.00
0005435508326	1592	Economy	28700.00
0005435517864	1592	Economy	28700.00
0005434565880	1592	Economy	28700.00
0005432291923	1592	Economy	28700.00
0005435502252	1592	Economy	28700.00
0005435508328	1592	Economy	28700.00
0005435517871	1592	Economy	28700.00
0005435517853	1592	Economy	28700.00
0005435502259	1592	Economy	28700.00
0005435508332	1592	Economy	28700.00
0005435517869	1592	Economy	28700.00
0005435517867	1592	Economy	28700.00
0005434565872	1592	Economy	28700.00
0005433186029	1592	Economy	28700.00
0005435502260	1592	Economy	28700.00
0005435508334	1592	Economy	28700.00
0005433186015	1592	Economy	28700.00
0005435517866	1592	Economy	28700.00
0005433186036	1592	Economy	28700.00
0005435517863	1592	Economy	28700.00
0005435517870	1592	Economy	28700.00
0005435502244	1592	Economy	28700.00
0005434565873	1592	Economy	28700.00
0005435502125	20842	Business	86000.00
0005433186099	20842	Business	86000.00
0005434565769	20842	Business	86000.00
0005435528926	20842	Business	86000.00
0005433186094	20842	Business	86000.00
0005434565736	20842	Business	86000.00
0005435501982	20842	Business	86000.00
0005435528997	20842	Business	86000.00
0005433186090	20842	Business	86000.00
0005435528975	20842	Business	86000.00
0005434565715	20842	Economy	28700.00
0005435502126	20842	Economy	28700.00
0005435528927	20842	Economy	28700.00
0005435528993	20842	Economy	28700.00
0005435502099	20842	Economy	28700.00
0005435545642	20842	Economy	28700.00
0005435529015	20842	Economy	28700.00
0005435501988	20842	Economy	28700.00
0005433186093	20842	Economy	28700.00
0005434565735	20842	Economy	31500.00
0005435545617	20842	Economy	31500.00
0005434565717	20842	Economy	31500.00
0005435528917	20842	Economy	31500.00
0005435545620	20842	Economy	28700.00
0005435502133	20842	Economy	28700.00
0005435529043	20842	Economy	28700.00
0005435528955	20842	Economy	28700.00
0005435502140	20842	Economy	28700.00
0005435502010	20842	Economy	28700.00
0005434565756	20842	Economy	28700.00
0005435528953	20842	Economy	28700.00
0005435529017	20842	Economy	28700.00
0005435528890	20842	Economy	28700.00
0005434565716	20842	Economy	28700.00
0005435528956	20842	Economy	28700.00
0005435528891	20842	Economy	28700.00
0005434565721	20842	Economy	28700.00
0005435502084	20842	Economy	28700.00
0005435501999	20842	Economy	28700.00
0005435528989	20842	Economy	28700.00
0005435528968	20842	Economy	28700.00
0005435528974	20842	Economy	28700.00
0005434565718	20842	Economy	28700.00
0005435502141	20842	Economy	28700.00
0005435528935	20842	Economy	28700.00
0005435528910	20842	Economy	28700.00
0005435502023	20842	Economy	28700.00
0005435528925	20842	Economy	28700.00
0005435528971	20842	Economy	28700.00
0005435502008	20842	Economy	28700.00
0005434565775	20842	Economy	28700.00
0005433186095	20842	Economy	28700.00
0005435501952	20842	Economy	28700.00
0005435502011	20842	Economy	28700.00
0005435528996	20842	Economy	28700.00
0005434565768	20842	Economy	28700.00
0005434565709	20842	Economy	28700.00
0005434565762	20842	Economy	28700.00
0005435502007	20842	Economy	28700.00
0005433186092	20842	Economy	28700.00
0005435545623	20842	Economy	28700.00
0005433186097	20842	Economy	28700.00
0005434565742	20842	Economy	28700.00
0005433186091	20842	Economy	28700.00
0005433186096	20842	Economy	28700.00
0005435502111	20842	Economy	28700.00
0005433186098	20842	Economy	28700.00
0005435502029	20842	Economy	28700.00
0005434565759	20842	Economy	28700.00
0005435545613	20842	Economy	28700.00
0005434565708	20842	Economy	28700.00
0005435529010	20842	Economy	28700.00
0005434565719	20842	Economy	28700.00
0005435501987	20842	Economy	28700.00
0005435529018	20842	Economy	28700.00
0005435501998	20842	Economy	28700.00
0005435545622	20842	Economy	28700.00
0005435529044	20842	Economy	28700.00
0005435501983	20842	Economy	28700.00
0005435153725	3932	Economy	21600.00
0005435153723	3932	Economy	19700.00
0005435931562	3932	Economy	19700.00
0005435153724	3932	Economy	19700.00
0005435931564	3932	Economy	19700.00
0005435153726	3932	Economy	19700.00
0005435931563	3932	Economy	19700.00
0005435931561	3932	Economy	19700.00
0005435153687	21862	Economy	19700.00
0005435931591	21862	Economy	19700.00
0005435931589	21862	Economy	19700.00
0005435153661	21862	Economy	19700.00
0005435153686	21862	Economy	19700.00
0005435931590	21862	Economy	19700.00
0005435153667	21862	Economy	19700.00
0005435931592	21862	Economy	19700.00
0005435225478	7212	Economy	14300.00
0005432628809	7212	Economy	14300.00
0005432628811	7212	Economy	13000.00
0005432628812	7212	Economy	13000.00
0005435225486	7212	Economy	13000.00
0005432628804	7212	Economy	13000.00
0005435225533	7212	Economy	13000.00
0005432628807	7212	Economy	13000.00
0005432628802	7212	Economy	13000.00
0005435225534	7212	Economy	13000.00
0005432628801	7212	Economy	13000.00
0005432628813	7212	Economy	13000.00
0005435225532	7212	Economy	13000.00
0005432628808	7212	Economy	13000.00
0005432628798	7212	Economy	13000.00
0005432628803	7212	Economy	13000.00
0005432628800	7212	Economy	13000.00
0005435225506	7212	Economy	13000.00
0005432628805	7212	Economy	13000.00
0005435225502	7212	Economy	13000.00
0005432628799	7212	Economy	13000.00
0005432628806	7212	Economy	13000.00
0005432628810	7212	Economy	13000.00
0005435225485	7212	Economy	13000.00
0005432628667	28092	Economy	14300.00
0005432628745	28092	Economy	14300.00
0005435225559	28092	Economy	13000.00
0005432628658	28092	Economy	13000.00
0005435225562	28092	Economy	13000.00
0005435225563	28092	Economy	13000.00
0005432628641	28092	Economy	13000.00
0005432628700	28092	Economy	13000.00
0005432628722	28092	Economy	13000.00
0005432628612	28092	Economy	13000.00
0005432628694	28092	Economy	13000.00
0005432628688	28092	Economy	13000.00
0005435225565	28092	Economy	13000.00
0005432628723	28092	Economy	13000.00
0005432628746	28092	Economy	13000.00
0005435225561	28092	Economy	13000.00
0005435225560	28092	Economy	13000.00
0005435225566	28092	Economy	13000.00
0005432628659	28092	Economy	13000.00
0005432628611	28092	Economy	13000.00
0005432628695	28092	Economy	13000.00
0005435225564	28092	Economy	13000.00
0005432628627	28092	Economy	13000.00
0005432628689	28092	Economy	13000.00
0005432628708	28092	Economy	13000.00
0005434267905	8734	Economy	11500.00
0005435960039	8734	Economy	11500.00
0005434267909	8734	Economy	10500.00
0005435960040	8734	Economy	10500.00
0005434267910	8734	Economy	10500.00
0005434267919	8734	Economy	10500.00
0005434267904	8734	Economy	10500.00
0005435960037	8734	Economy	10500.00
0005435960038	8734	Economy	10500.00
0005434267901	8734	Economy	10500.00
0005435960026	15263	Economy	11500.00
0005434267937	15263	Economy	10500.00
0005434267938	15263	Economy	10500.00
0005434267940	15263	Economy	10500.00
0005434267939	15263	Economy	10500.00
0005432692968	1220	Business	115000.00
0005432675096	1220	Business	115000.00
0005432692956	1220	Business	115000.00
0005432873201	1220	Business	115000.00
0005432675081	1220	Business	115000.00
0005432692947	1220	Business	115000.00
0005432873211	1220	Business	115000.00
0005432692943	1220	Business	115000.00
0005432692962	1220	Business	115000.00
0005432873195	1220	Business	115000.00
0005432692951	1220	Business	115000.00
0005432873191	1220	Business	115000.00
0005432675082	1220	Business	115000.00
0005432692960	1220	Business	115000.00
0005432675085	1220	Economy	38300.00
0005432675083	1220	Business	115000.00
0005432692953	1220	Economy	38300.00
0005432692944	1220	Economy	38300.00
0005432692958	1220	Economy	38300.00
0005432675088	1220	Economy	38300.00
0005432692966	1220	Economy	38300.00
0005432675080	1220	Economy	38300.00
0005432692950	1220	Economy	42200.00
0005432675084	1220	Economy	42200.00
0005432677557	1220	Economy	38300.00
0005432675095	1220	Economy	38300.00
0005432677556	1220	Economy	38300.00
0005432692952	1220	Economy	38300.00
0005432692965	1220	Economy	38300.00
0005432873210	1220	Economy	38300.00
0005432692940	1220	Economy	38300.00
0005432692967	1220	Economy	38300.00
0005432675094	1220	Economy	38300.00
0005432692939	1220	Economy	38300.00
0005432675091	1220	Economy	38300.00
0005432692961	1220	Economy	38300.00
0005432873215	1220	Economy	38300.00
0005432873194	1220	Economy	38300.00
0005432675086	1220	Economy	38300.00
0005432692946	1220	Economy	38300.00
0005432692964	1220	Economy	38300.00
0005432692949	1220	Economy	38300.00
0005432873203	1220	Economy	38300.00
0005432677559	1220	Economy	38300.00
0005432692957	1220	Economy	38300.00
0005432692955	1220	Economy	38300.00
0005432677558	1220	Economy	38300.00
0005432675092	1220	Economy	38300.00
0005432675087	1220	Economy	38300.00
0005432675089	1220	Economy	38300.00
0005432692959	1220	Economy	38300.00
0005432692941	1220	Economy	38300.00
0005432692954	1220	Economy	38300.00
0005432692942	1220	Economy	38300.00
0005432692945	1220	Economy	38300.00
0005432692938	1220	Economy	38300.00
0005432692963	1220	Economy	38300.00
0005432692948	1220	Economy	38300.00
0005432873202	1220	Economy	38300.00
0005432675093	1220	Economy	38300.00
0005432692937	1220	Economy	38300.00
0005432675090	1220	Economy	38300.00
0005432692665	17474	Business	115000.00
0005432692605	17474	Business	115000.00
0005432675021	17474	Business	115000.00
0005432692743	17474	Business	115000.00
0005432692651	17474	Business	115000.00
0005432692613	17474	Business	115000.00
0005432692716	17474	Business	115000.00
0005432677527	17474	Business	115000.00
0005432674913	17474	Business	115000.00
0005432677526	17474	Business	115000.00
0005432677542	17474	Business	115000.00
0005432692698	17474	Business	115000.00
0005432873273	17474	Business	115000.00
0005432692775	17474	Business	115000.00
0005432692724	17474	Business	115000.00
0005432873272	17474	Economy	38300.00
0005432692662	17474	Economy	38300.00
0005432674914	17474	Economy	38300.00
0005432692739	17474	Economy	38300.00
0005432692862	17474	Economy	38300.00
0005432692661	17474	Economy	38300.00
0005432692585	17474	Economy	42200.00
0005432873270	17474	Economy	42200.00
0005432692685	17474	Economy	42200.00
0005432677517	17474	Economy	42200.00
0005432692751	17474	Economy	38300.00
0005432692686	17474	Economy	38300.00
0005432692738	17474	Economy	38300.00
0005432692756	17474	Economy	38300.00
0005432692753	17474	Economy	38300.00
0005432873274	17474	Economy	38300.00
0005432692714	17474	Economy	38300.00
0005432692777	17474	Economy	38300.00
0005432692752	17474	Economy	38300.00
0005432674893	17474	Economy	38300.00
0005432674920	17474	Economy	38300.00
0005432675000	17474	Economy	38300.00
0005432692577	17474	Economy	38300.00
0005432692606	17474	Economy	38300.00
0005432692583	17474	Economy	38300.00
0005432692684	17474	Economy	38300.00
0005432674921	17474	Economy	38300.00
0005432692607	17474	Economy	38300.00
0005432692601	17474	Economy	38300.00
0005432692576	17474	Economy	38300.00
0005432692744	17474	Economy	38300.00
0005432692681	17474	Economy	38300.00
0005432692612	17474	Economy	38300.00
0005432692586	17474	Economy	38300.00
0005432674974	17474	Economy	38300.00
0005432692640	17474	Economy	38300.00
0005432873269	17474	Economy	38300.00
0005432674905	17474	Economy	38300.00
0005432873268	17474	Economy	38300.00
0005432677543	17474	Economy	38300.00
0005432692659	17474	Economy	38300.00
0005432692680	17474	Economy	38300.00
0005432692584	17474	Economy	38300.00
0005432692778	17474	Economy	38300.00
0005432674975	17474	Economy	38300.00
0005432674904	17474	Economy	38300.00
0005432692863	17474	Economy	38300.00
0005432692660	17474	Economy	38300.00
0005432873271	17474	Economy	38300.00
0005434435129	1130	Economy	13900.00
0005434435140	1130	Economy	13900.00
0005433156615	1130	Economy	13900.00
0005433156683	1130	Economy	13900.00
0005433156656	1130	Economy	13900.00
0005434435137	1130	Economy	13900.00
0005434435143	1130	Economy	13900.00
0005433156616	1130	Economy	13900.00
0005433156613	1130	Economy	13900.00
0005434435134	1130	Economy	13900.00
0005433156652	1130	Economy	13900.00
0005434435131	1130	Economy	13900.00
0005434435144	1130	Economy	13900.00
0005434435138	1130	Economy	13900.00
0005433156642	1130	Economy	13900.00
0005434435133	1130	Economy	13900.00
0005433156668	1130	Economy	13900.00
0005433156681	1130	Economy	13900.00
0005433156662	1130	Economy	13900.00
0005433156684	1130	Economy	13900.00
0005433156643	1130	Economy	13900.00
0005434435141	1130	Economy	13900.00
0005434435139	1130	Economy	13900.00
0005434435142	1130	Economy	13900.00
0005433156669	1130	Economy	13900.00
0005434435130	1130	Economy	13900.00
0005433156690	1130	Economy	13900.00
0005433156680	1130	Economy	13900.00
0005434435135	1130	Economy	13900.00
0005433156622	1130	Economy	13900.00
0005434435136	1130	Economy	13900.00
0005434435132	1130	Economy	13900.00
0005434435017	17308	Economy	15200.00
0005433156728	17308	Economy	13900.00
0005433156723	17308	Economy	13900.00
0005434434941	17308	Economy	13900.00
0005433156724	17308	Economy	13900.00
0005434435016	17308	Economy	13900.00
0005434434950	17308	Economy	13900.00
0005433156722	17308	Economy	13900.00
0005433156725	17308	Economy	13900.00
0005433156727	17308	Economy	13900.00
0005434434949	17308	Economy	13900.00
0005434434942	17308	Economy	13900.00
0005434434995	17308	Economy	13900.00
0005433156726	17308	Economy	13900.00
0005434435045	17308	Economy	13900.00
0005433156721	17308	Economy	13900.00
0005433156720	17308	Economy	13900.00
0005435086809	4049	Economy	7500.00
0005435928080	4049	Economy	7500.00
0005435928081	4049	Economy	7500.00
0005435928092	4049	Economy	7500.00
0005435928089	4049	Economy	7500.00
0005435086811	4049	Economy	7500.00
0005435086815	4049	Economy	7500.00
0005435086812	4049	Economy	7500.00
0005435928086	4049	Economy	7500.00
0005435928084	4049	Economy	7500.00
0005435086813	4049	Economy	7500.00
0005435928085	4049	Economy	7500.00
0005435086814	4049	Economy	7500.00
0005435928093	4049	Economy	7500.00
0005435086810	4049	Economy	7500.00
0005435086770	24385	Economy	8200.00
0005435086760	24385	Economy	8200.00
0005435928127	24385	Economy	7500.00
0005435086756	24385	Economy	7500.00
0005435928131	24385	Economy	7500.00
0005435928126	24385	Economy	7500.00
0005435086748	24385	Economy	7500.00
0005435928128	24385	Economy	7500.00
0005435086714	24385	Economy	7500.00
0005435928130	24385	Economy	7500.00
0005435086753	24385	Economy	7500.00
0005435928129	24385	Economy	7500.00
0005435086754	24385	Economy	7500.00
0005435086737	24385	Economy	7500.00
0005435086747	24385	Economy	7500.00
0005435086715	24385	Economy	7500.00
0005435551578	17016	Business	144300.00
0005435098549	17016	Business	144300.00
0005435551571	17016	Economy	52900.00
0005435551573	17016	Economy	48100.00
0005435551561	17016	Economy	48100.00
0005435551572	17016	Economy	48100.00
0005435551576	17016	Economy	48100.00
0005435551562	17016	Economy	48100.00
0005435551567	17016	Economy	48100.00
0005435098547	17016	Economy	48100.00
0005435551563	17016	Economy	48100.00
0005435551558	17016	Economy	48100.00
0005435098546	17016	Economy	48100.00
0005435098550	17016	Economy	48100.00
0005435098545	17016	Economy	48100.00
0005435551560	17016	Economy	48100.00
0005435098551	17016	Economy	48100.00
0005435551569	17016	Economy	48100.00
0005435551556	17016	Economy	48100.00
0005435551575	17016	Economy	48100.00
0005435098544	17016	Economy	48100.00
0005435551577	17016	Economy	48100.00
0005435098548	17016	Economy	48100.00
0005435551574	17016	Economy	48100.00
0005435551568	17016	Economy	48100.00
0005435551557	17016	Economy	48100.00
0005435551570	17016	Economy	48100.00
0005435551565	17016	Economy	48100.00
0005435551566	17016	Economy	48100.00
0005435551564	17016	Economy	48100.00
0005435551559	17016	Economy	48100.00
0005434625932	4854	Business	44200.00
0005435907443	4854	Business	44200.00
0005434625933	4854	Business	44200.00
0005434625931	4854	Economy	16200.00
0005435907442	4854	Economy	14700.00
0005434625936	4854	Economy	14700.00
0005434625938	4854	Economy	14700.00
0005434625930	4854	Economy	14700.00
0005435907441	4854	Economy	14700.00
0005434625934	4854	Economy	14700.00
0005434625935	4854	Economy	14700.00
0005434625937	4854	Economy	14700.00
0005435907494	32890	Business	44200.00
0005435907492	32890	Business	44200.00
0005434625873	32890	Business	44200.00
0005433194854	32890	Economy	14700.00
0005433194852	32890	Economy	14700.00
0005435907495	32890	Economy	14700.00
0005434625893	32890	Economy	14700.00
0005435907491	32890	Economy	14700.00
0005433194851	32890	Economy	14700.00
0005434625841	32890	Economy	14700.00
0005434625910	32890	Economy	14700.00
0005434625891	32890	Economy	14700.00
0005434625869	32890	Economy	14700.00
0005433194855	32890	Economy	14700.00
0005433194853	32890	Economy	14700.00
0005434625842	32890	Economy	14700.00
0005435907493	32890	Economy	14700.00
0005435784784	13786	Economy	3400.00
0005435784803	13786	Economy	3400.00
0005435784948	13786	Economy	3400.00
0005432195687	13786	Economy	3400.00
0005435784897	13786	Economy	3100.00
0005435784973	13786	Economy	3100.00
0005435784845	13786	Economy	3100.00
0005435785028	13786	Economy	3100.00
0005435785000	13786	Economy	3100.00
0005435784898	13786	Economy	3100.00
0005435784908	13786	Economy	3100.00
0005435784894	13786	Economy	3100.00
0005435784816	13786	Economy	3100.00
0005435784924	13786	Economy	3100.00
0005435784933	13786	Economy	3100.00
0005435784969	13786	Economy	3100.00
0005435784968	13786	Economy	3100.00
0005435784921	13786	Economy	3100.00
0005435784854	13786	Economy	3100.00
0005435784804	13786	Economy	3100.00
0005435784802	13786	Economy	3100.00
0005435784983	13786	Economy	3100.00
0005435784846	13786	Economy	3100.00
0005435784893	13786	Economy	3100.00
0005435784872	13786	Economy	3100.00
0005432195686	13786	Economy	3100.00
0005435784880	13786	Economy	3100.00
0005435784907	13786	Economy	3100.00
0005435784906	13786	Economy	3100.00
0005435785097	13786	Economy	3100.00
0005435784987	13786	Economy	3100.00
0005435784857	13786	Economy	3100.00
0005435784988	13786	Economy	3100.00
0005435784913	13786	Economy	3100.00
0005435784909	13786	Economy	3100.00
0005435784950	13786	Economy	3100.00
0005435784881	13786	Economy	3100.00
0005435785032	13786	Economy	3100.00
0005435784891	13786	Economy	3100.00
0005435784971	13786	Economy	3100.00
0005435784932	13786	Economy	3100.00
0005435784972	13786	Economy	3100.00
0005435785004	13786	Economy	3100.00
0005435784947	13786	Economy	3100.00
0005435784896	13786	Economy	3100.00
0005435784936	13786	Economy	3100.00
0005435784960	13786	Economy	3100.00
0005435784954	13786	Economy	3100.00
0005435784953	13786	Economy	3100.00
0005435785197	27439	Economy	3400.00
0005435785193	27439	Economy	3400.00
0005435785192	27439	Economy	3400.00
0005435785202	27439	Economy	3400.00
0005435937315	27439	Economy	3100.00
0005435785219	27439	Economy	3100.00
0005435785221	27439	Economy	3100.00
0005435785211	27439	Economy	3100.00
0005435785215	27439	Economy	3100.00
0005435785201	27439	Economy	3100.00
0005435785199	27439	Economy	3100.00
0005435785212	27439	Economy	3100.00
0005435785210	27439	Economy	3100.00
0005435785187	27439	Economy	3100.00
0005435787345	27439	Economy	3100.00
0005435785194	27439	Economy	3100.00
0005435785207	27439	Economy	3100.00
0005435785220	27439	Economy	3100.00
0005435785206	27439	Economy	3100.00
0005435785222	27439	Economy	3100.00
0005435785214	27439	Economy	3100.00
0005435787344	27439	Economy	3100.00
0005435937314	27439	Economy	3100.00
0005435785213	27439	Economy	3100.00
0005435785204	27439	Economy	3100.00
0005435785190	27439	Economy	3100.00
0005435785191	27439	Economy	3100.00
0005432190614	27439	Economy	3100.00
0005435785209	27439	Economy	3100.00
0005435785189	27439	Economy	3100.00
0005435785200	27439	Economy	3100.00
0005435785195	27439	Economy	3100.00
0005435937313	27439	Economy	3100.00
0005435937325	27439	Economy	3100.00
0005435785196	27439	Economy	3100.00
0005435785205	27439	Economy	3100.00
0005435785208	27439	Economy	3100.00
0005435937326	27439	Economy	3100.00
0005435785198	27439	Economy	3100.00
0005435785216	27439	Economy	3100.00
0005435785218	27439	Economy	3100.00
0005435785188	27439	Economy	3100.00
0005435785203	27439	Economy	3100.00
0005435785217	27439	Economy	3100.00
0005432190613	27439	Economy	3100.00
0005432190612	27439	Economy	3100.00
0005432058369	20287	Business	12000.00
0005434407161	20287	Business	12000.00
0005434406956	20287	Business	12000.00
0005434407149	20287	Business	12000.00
0005434406837	20287	Business	12000.00
0005434406789	20287	Business	12000.00
0005434407003	20287	Business	12000.00
0005434407177	20287	Business	12000.00
0005432058370	20287	Business	12000.00
0005434407021	20287	Economy	4000.00
0005434406988	20287	Economy	4000.00
0005434407229	20287	Economy	4000.00
0005434406857	20287	Economy	4000.00
0005434406884	20287	Economy	4000.00
0005434406955	20287	Economy	4000.00
0005432058371	20287	Economy	4000.00
0005434407106	20287	Economy	4000.00
0005434406987	20287	Economy	4400.00
0005434407200	20287	Economy	4400.00
0005434407201	20287	Economy	4400.00
0005434407270	20287	Economy	4400.00
0005434407105	20287	Economy	4000.00
0005434406863	20287	Economy	4000.00
0005434407008	20287	Economy	4000.00
0005434407111	20287	Economy	4000.00
0005434406912	20287	Economy	4000.00
0005434407112	20287	Economy	4000.00
0005434407179	20287	Economy	4000.00
0005432058368	20287	Economy	4000.00
0005434407093	20287	Economy	4000.00
0005434406885	20287	Economy	4000.00
0005434407199	20287	Economy	4000.00
0005434406927	20287	Economy	4000.00
0005434407060	20287	Economy	4000.00
0005434406870	20287	Economy	4000.00
0005434406864	20287	Economy	4000.00
0005434407167	20287	Economy	4000.00
0005434406939	20287	Economy	4000.00
0005434407134	20287	Economy	4000.00
0005435311035	20287	Economy	4000.00
0005434406938	20287	Economy	4000.00
0005434407107	20287	Economy	4000.00
0005434406861	20287	Economy	4000.00
0005434407103	20287	Economy	4000.00
0005434406788	20287	Economy	4000.00
0005434407180	20287	Economy	4000.00
0005434407198	20287	Economy	4000.00
0005434407077	20287	Economy	4000.00
0005434406903	20287	Economy	4000.00
0005434406902	20287	Economy	4000.00
0005434407117	20287	Economy	4000.00
0005434407125	20287	Economy	4000.00
0005434407101	20287	Economy	4000.00
0005434407058	20287	Economy	4000.00
0005434406858	20287	Economy	4000.00
0005434407271	20287	Economy	4000.00
0005434406926	20287	Economy	4000.00
0005434407222	20287	Economy	4000.00
0005434407269	20287	Economy	4000.00
0005434406946	20287	Economy	4000.00
0005434407038	20287	Economy	4000.00
0005434407305	20287	Economy	4000.00
0005434407094	20287	Economy	4000.00
0005434407160	20287	Economy	4000.00
0005434406928	20287	Economy	4000.00
0005434407051	20287	Economy	4000.00
0005434407148	20287	Economy	4000.00
0005434406972	20287	Economy	4000.00
0005434406957	20287	Economy	4000.00
0005434406990	20287	Economy	4000.00
0005434407181	20287	Economy	4000.00
0005434406996	20287	Economy	4000.00
0005434406995	20287	Economy	4000.00
0005434407569	26986	Business	12000.00
0005434407581	26986	Business	12000.00
0005434407584	26986	Business	12000.00
0005434407585	26986	Business	12000.00
0005434407568	26986	Business	12000.00
0005434407603	26986	Business	12000.00
0005434407546	26986	Business	12000.00
0005434407574	26986	Business	12000.00
0005434407557	26986	Business	12000.00
0005434407593	26986	Economy	4000.00
0005434407575	26986	Economy	4000.00
0005434407544	26986	Economy	4000.00
0005434407599	26986	Economy	4000.00
0005434407560	26986	Economy	4000.00
0005434407596	26986	Economy	4000.00
0005434407567	26986	Economy	4000.00
0005434407549	26986	Economy	4000.00
0005434407600	26986	Economy	4000.00
0005434407573	26986	Economy	4400.00
0005434407583	26986	Economy	4400.00
0005432153918	26986	Economy	4400.00
0005435310854	26986	Economy	4400.00
0005434407591	26986	Economy	4400.00
0005434407551	26986	Economy	4000.00
0005435310902	26986	Economy	4000.00
0005434407545	26986	Economy	4000.00
0005432153913	26986	Economy	4000.00
0005434407556	26986	Economy	4000.00
0005434407586	26986	Economy	4000.00
0005435310893	26986	Economy	4000.00
0005432153914	26986	Economy	4000.00
0005434407547	26986	Economy	4000.00
0005435310897	26986	Economy	4000.00
0005435310898	26986	Economy	4000.00
0005434407579	26986	Economy	4000.00
0005435310903	26986	Economy	4000.00
0005434407576	26986	Economy	4000.00
0005434407588	26986	Economy	4000.00
0005434407570	26986	Economy	4000.00
0005434407589	26986	Economy	4000.00
0005434407565	26986	Economy	4000.00
0005434407572	26986	Economy	4000.00
0005434407571	26986	Economy	4000.00
0005434407563	26986	Economy	4000.00
0005434407564	26986	Economy	4000.00
0005434407582	26986	Economy	4000.00
0005434407587	26986	Economy	4000.00
0005432153916	26986	Economy	4000.00
0005434407542	26986	Economy	4000.00
0005432153919	26986	Economy	4000.00
0005434407601	26986	Economy	4000.00
0005435310896	26986	Economy	4000.00
0005434407597	26986	Economy	4000.00
0005435310843	26986	Economy	4000.00
0005434407590	26986	Economy	4000.00
0005434407550	26986	Economy	4000.00
0005434407604	26986	Economy	4000.00
0005432153920	26986	Economy	4000.00
0005434407555	26986	Economy	4000.00
0005434407595	26986	Economy	4000.00
0005434407554	26986	Economy	4000.00
0005434407553	26986	Economy	4000.00
0005435310904	26986	Economy	4000.00
0005434407562	26986	Economy	4000.00
0005434407559	26986	Economy	4000.00
0005432153915	26986	Economy	4000.00
0005434407541	26986	Economy	4000.00
0005434407602	26986	Economy	4000.00
0005434407577	26986	Economy	4000.00
0005435310914	26986	Economy	4000.00
0005434407594	26986	Economy	4000.00
0005434407558	26986	Economy	4000.00
0005434407578	26986	Economy	4000.00
0005434407592	26986	Economy	4000.00
0005434407561	26986	Economy	4000.00
0005434407598	26986	Economy	4000.00
0005434407552	26986	Economy	4000.00
0005434407548	26986	Economy	4000.00
0005434407566	26986	Economy	4000.00
0005435310844	26986	Economy	4000.00
0005434407543	26986	Economy	4000.00
0005434407605	26986	Economy	4000.00
0005432153917	26986	Economy	4000.00
0005434407580	26986	Economy	4000.00
0005433123767	5669	Business	43300.00
0005433123706	5669	Business	43300.00
0005433123707	5669	Business	43300.00
0005432109696	5669	Business	43300.00
0005434319351	5669	Economy	14400.00
0005434319344	5669	Economy	14400.00
0005433123661	5669	Economy	14400.00
0005433123697	5669	Economy	14400.00
0005434319358	5669	Economy	14400.00
0005433123588	5669	Economy	14400.00
0005434319346	5669	Economy	15900.00
0005434319363	5669	Economy	15900.00
0005433123636	5669	Economy	14400.00
0005433123671	5669	Economy	14400.00
0005432109695	5669	Economy	14400.00
0005434319348	5669	Economy	14400.00
0005434319359	5669	Economy	14400.00
0005434319349	5669	Economy	14400.00
0005433123724	5669	Economy	14400.00
0005434319350	5669	Economy	14400.00
0005434311213	5669	Economy	14400.00
0005434319362	5669	Economy	14400.00
0005432109694	5669	Economy	14400.00
0005433123725	5669	Economy	14400.00
0005434319360	5669	Economy	14400.00
0005434319347	5669	Economy	14400.00
0005433123670	5669	Economy	14400.00
0005434319356	5669	Economy	14400.00
0005433123654	5669	Economy	14400.00
0005434319345	5669	Economy	14400.00
0005434319355	5669	Economy	14400.00
0005433123695	5669	Economy	14400.00
0005433123683	5669	Economy	14400.00
0005434319361	5669	Economy	14400.00
0005433123698	5669	Economy	14400.00
0005434319357	5669	Economy	14400.00
0005434319354	5669	Economy	14400.00
0005433123696	5669	Economy	14400.00
0005433123693	5669	Economy	14400.00
0005434319352	5669	Economy	14400.00
0005434319343	5669	Economy	14400.00
0005433123653	5669	Economy	14400.00
0005434319353	5669	Economy	14400.00
0005434311212	5669	Economy	14400.00
0005433123879	15708	Business	43300.00
0005434319161	15708	Business	43300.00
0005433123878	15708	Business	43300.00
0005433123871	15708	Business	43300.00
0005433123880	15708	Economy	14400.00
0005433123877	15708	Economy	15900.00
0005433123887	15708	Economy	15900.00
0005433123883	15708	Economy	15900.00
0005433123873	15708	Economy	14400.00
0005434312292	15708	Economy	14400.00
0005434319162	15708	Economy	14400.00
0005434319160	15708	Economy	14400.00
0005433123881	15708	Economy	14400.00
0005433123875	15708	Economy	14400.00
0005433123886	15708	Economy	14400.00
0005433123876	15708	Economy	14400.00
0005433123882	15708	Economy	14400.00
0005434319199	15708	Economy	14400.00
0005434319188	15708	Economy	14400.00
0005433123885	15708	Economy	14400.00
0005433123866	15708	Economy	14400.00
0005433123870	15708	Economy	14400.00
0005433123874	15708	Economy	14400.00
0005433123872	15708	Economy	14400.00
0005433123867	15708	Economy	14400.00
0005434319200	15708	Economy	14400.00
0005433123884	15708	Economy	14400.00
0005433123869	15708	Economy	14400.00
0005434319179	15708	Economy	14400.00
0005433123868	15708	Economy	14400.00
0005434311202	15708	Economy	14400.00
0005435220312	31741	Economy	15500.00
0005435220314	31741	Economy	15500.00
0005435219192	31741	Economy	15500.00
0005435220311	31741	Economy	15500.00
0005435219194	31741	Economy	15500.00
0005435220313	31741	Economy	15500.00
0005435219196	31741	Economy	15500.00
0005435220315	31741	Economy	15500.00
0005435219195	31741	Economy	15500.00
0005435219193	31741	Economy	15500.00
0005435220490	31741	Economy	15500.00
0005434189095	9012	Economy	27400.00
0005434484330	9012	Economy	24900.00
0005434484325	9012	Economy	24900.00
0005434484331	9012	Economy	24900.00
0005434484326	9012	Economy	24900.00
0005434484328	9012	Economy	24900.00
0005434484327	9012	Economy	24900.00
0005434189146	9012	Economy	24900.00
0005434189104	9012	Economy	24900.00
0005434484329	9012	Economy	24900.00
0005434189160	16660	Economy	24900.00
0005434484271	16660	Economy	24900.00
0005434189162	16660	Economy	24900.00
0005434484299	16660	Economy	24900.00
0005434484298	16660	Economy	24900.00
0005434484265	16660	Economy	24900.00
0005434189163	16660	Economy	24900.00
0005434189159	16660	Economy	24900.00
0005434484258	16660	Economy	24900.00
0005434484242	16660	Economy	24900.00
0005434189161	16660	Economy	24900.00
0005434189164	16660	Economy	24900.00
0005433123868	7694	Business	11100.00
0005433123869	7694	Business	11100.00
0005433722126	7694	Business	11100.00
0005433722129	7694	Business	11100.00
0005433123872	7694	Business	11100.00
0005433722104	7694	Economy	3700.00
0005433722119	7694	Economy	3700.00
0005433123887	7694	Economy	3700.00
0005433123867	7694	Economy	3700.00
0005433722141	7694	Economy	4100.00
0005433722127	7694	Economy	4100.00
0005433722125	7694	Economy	3700.00
0005433722143	7694	Economy	3700.00
0005433722144	7694	Economy	3700.00
0005433722163	7694	Economy	3700.00
0005433722118	7694	Economy	3700.00
0005433123880	7694	Economy	3700.00
0005433123871	7694	Economy	3700.00
0005433123875	7694	Economy	3700.00
0005433123877	7694	Economy	3700.00
0005433123876	7694	Economy	3700.00
0005433123882	7694	Economy	3700.00
0005433123873	7694	Economy	3700.00
0005433123886	7694	Economy	3700.00
0005433123866	7694	Economy	3700.00
0005433123884	7694	Economy	3700.00
0005433722142	7694	Economy	3700.00
0005433123881	7694	Economy	3700.00
0005433722140	7694	Economy	3700.00
0005433722146	7694	Economy	3700.00
0005433123874	7694	Economy	3700.00
0005433123883	7694	Economy	3700.00
0005433123878	7694	Economy	3700.00
0005433123885	7694	Economy	3700.00
0005433123870	7694	Economy	3700.00
0005433722145	7694	Economy	3700.00
0005433123879	7694	Economy	3700.00
0005433449911	7695	Business	11100.00
0005432720818	7695	Business	11100.00
0005432720834	7695	Business	11100.00
0005432692994	7695	Business	11100.00
0005432692996	7695	Business	11100.00
0005433449897	7695	Business	11100.00
0005432692970	7695	Business	11100.00
0005432720831	7695	Business	11100.00
0005432692997	7695	Business	11100.00
0005432071565	7695	Business	11100.00
0005432720826	7695	Business	11100.00
0005432720822	7695	Economy	3700.00
0005432692975	7695	Economy	3700.00
0005432692982	7695	Economy	3700.00
0005432692973	7695	Economy	3700.00
0005432692972	7695	Economy	3700.00
0005432720838	7695	Economy	3700.00
0005432692971	7695	Economy	3700.00
0005432692985	7695	Economy	4100.00
0005432692983	7695	Economy	4100.00
0005432692979	7695	Economy	4100.00
0005433449916	7695	Economy	4100.00
0005432692978	7695	Economy	3700.00
0005433449905	7695	Economy	3700.00
0005432720832	7695	Economy	3700.00
0005432720817	7695	Economy	3700.00
0005432692981	7695	Economy	3700.00
0005432720827	7695	Economy	3700.00
0005432720820	7695	Economy	3700.00
0005433449895	7695	Economy	3700.00
0005432692974	7695	Economy	3700.00
0005432720830	7695	Economy	3700.00
0005432720821	7695	Economy	3700.00
0005432720823	7695	Economy	3700.00
0005433449910	7695	Economy	3700.00
0005433449914	7695	Economy	3700.00
0005432720835	7695	Economy	3700.00
0005432692988	7695	Economy	3700.00
0005432693000	7695	Economy	3700.00
0005432692995	7695	Economy	3700.00
0005433449899	7695	Economy	3700.00
0005432720833	7695	Economy	3700.00
0005432720813	7695	Economy	3700.00
0005433449912	7695	Economy	3700.00
0005432692993	7695	Economy	3700.00
0005433449906	7695	Economy	3700.00
0005433449902	7695	Economy	3700.00
0005433449901	7695	Economy	3700.00
0005432692969	7695	Economy	3700.00
0005432720816	7695	Economy	3700.00
0005432071563	7695	Economy	3700.00
0005432692977	7695	Economy	3700.00
0005432720824	7695	Economy	3700.00
0005432720829	7695	Economy	3700.00
0005433449903	7695	Economy	3700.00
0005432692976	7695	Economy	3700.00
0005432692991	7695	Economy	3700.00
0005432692984	7695	Economy	3700.00
0005432692987	7695	Economy	3700.00
0005432720837	7695	Economy	3700.00
0005432692998	7695	Economy	3700.00
0005433449908	7695	Economy	3700.00
0005432720814	7695	Economy	3700.00
0005432692999	7695	Economy	3700.00
0005432720839	7695	Economy	3700.00
0005432692990	7695	Economy	3700.00
0005433449900	7695	Economy	3700.00
0005432692986	7695	Economy	3700.00
0005433449898	7695	Economy	3700.00
0005433449907	7695	Economy	3700.00
0005433449913	7695	Economy	3700.00
0005433449915	7695	Economy	3700.00
0005432071564	7695	Economy	3700.00
0005433449909	7695	Economy	3700.00
0005432720819	7695	Economy	3700.00
0005432692989	7695	Economy	3700.00
0005432720836	7695	Economy	3700.00
0005432692980	7695	Economy	3700.00
0005432720828	7695	Economy	3700.00
0005432692992	7695	Economy	3700.00
0005433449917	7695	Economy	3700.00
0005432720815	7695	Economy	3700.00
0005433449896	7695	Economy	3700.00
0005432720825	7695	Economy	3700.00
0005433449904	7695	Economy	3700.00
0005433449681	30332	Business	11100.00
0005432692601	30332	Business	11100.00
0005432692744	30332	Business	11100.00
0005432692585	30332	Business	11100.00
0005432692686	30332	Business	11100.00
0005432692778	30332	Business	11100.00
0005432692681	30332	Economy	3700.00
0005432692738	30332	Economy	3700.00
0005432692576	30332	Economy	3700.00
0005432692680	30332	Economy	3700.00
0005433449811	30332	Economy	3700.00
0005432692659	30332	Economy	3700.00
0005432692605	30332	Economy	4100.00
0005432692665	30332	Economy	4100.00
0005432692862	30332	Economy	4100.00
0005432692662	30332	Economy	3700.00
0005432692651	30332	Economy	3700.00
0005433449682	30332	Economy	3700.00
0005432692753	30332	Economy	3700.00
0005432692577	30332	Economy	3700.00
0005432692714	30332	Economy	3700.00
0005433449743	30332	Economy	3700.00
0005432692661	30332	Economy	3700.00
0005432692752	30332	Economy	3700.00
0005433449744	30332	Economy	3700.00
0005432692698	30332	Economy	3700.00
0005432692613	30332	Economy	3700.00
0005432692716	30332	Economy	3700.00
0005432692685	30332	Economy	3700.00
0005432692756	30332	Economy	3700.00
0005432692863	30332	Economy	3700.00
0005432692584	30332	Economy	3700.00
0005433449738	30332	Economy	3700.00
0005432692660	30332	Economy	3700.00
0005432692612	30332	Economy	3700.00
0005432692684	30332	Economy	3700.00
0005433449787	30332	Economy	3700.00
0005433449724	30332	Economy	3700.00
0005433449696	30332	Economy	3700.00
0005433449816	30332	Economy	3700.00
0005432692777	30332	Economy	3700.00
0005433449665	30332	Economy	3700.00
0005433449707	30332	Economy	3700.00
0005433449737	30332	Economy	3700.00
0005432692586	30332	Economy	3700.00
0005432692739	30332	Economy	3700.00
0005432692606	30332	Economy	3700.00
0005432692724	30332	Economy	3700.00
0005432692751	30332	Economy	3700.00
0005432692583	30332	Economy	3700.00
0005433449721	30332	Economy	3700.00
0005432692607	30332	Economy	3700.00
0005432692640	30332	Economy	3700.00
0005432692743	30332	Economy	3700.00
0005432692775	30332	Economy	3700.00
0005433449652	30332	Economy	3700.00
0005432720718	30331	Business	11100.00
0005433722208	30331	Business	11100.00
0005433722204	30331	Business	11100.00
0005433722200	30331	Business	11100.00
0005432720629	30331	Business	11100.00
0005432720658	30331	Business	11100.00
0005433123695	30331	Business	11100.00
0005432720657	30331	Business	11100.00
0005432720635	30331	Business	11100.00
0005432720623	30331	Economy	3700.00
0005432720617	30331	Economy	3700.00
0005432720643	30331	Economy	3700.00
0005432720611	30331	Economy	3700.00
0005432720616	30331	Economy	3700.00
0005433722201	30331	Economy	4100.00
0005432720713	30331	Economy	4100.00
0005433722206	30331	Economy	4100.00
0005433123654	30331	Economy	4100.00
0005432720676	30331	Economy	3700.00
0005433123670	30331	Economy	3700.00
0005432720652	30331	Economy	3700.00
0005432720672	30331	Economy	3700.00
0005432720553	30331	Economy	3700.00
0005432720535	30331	Economy	3700.00
0005432720518	30331	Economy	3700.00
0005432720496	30331	Economy	3700.00
0005433123725	30331	Economy	3700.00
0005432720717	30331	Economy	3700.00
0005433123588	30331	Economy	3700.00
0005433123707	30331	Economy	3700.00
0005433722205	30331	Economy	3700.00
0005432720615	30331	Economy	3700.00
0005433123636	30331	Economy	3700.00
0005433123698	30331	Economy	3700.00
0005433123696	30331	Economy	3700.00
0005433123724	30331	Economy	3700.00
0005432720592	30331	Economy	3700.00
0005432720517	30331	Economy	3700.00
0005432720719	30331	Economy	3700.00
0005432720641	30331	Economy	3700.00
0005432720638	30331	Economy	3700.00
0005432720495	30331	Economy	3700.00
0005433722202	30331	Economy	3700.00
0005432720516	30331	Economy	3700.00
0005432720613	30331	Economy	3700.00
0005432720642	30331	Economy	3700.00
0005432720650	30331	Economy	3700.00
0005432720604	30331	Economy	3700.00
0005432720624	30331	Economy	3700.00
0005433123767	30331	Economy	3700.00
0005432720612	30331	Economy	3700.00
0005432720636	30331	Economy	3700.00
0005433123706	30331	Economy	3700.00
0005432720534	30331	Economy	3700.00
0005433722207	30331	Economy	3700.00
0005433123653	30331	Economy	3700.00
0005432720603	30331	Economy	3700.00
0005432720716	30331	Economy	3700.00
0005433123661	30331	Economy	3700.00
0005432720673	30331	Economy	3700.00
0005433123671	30331	Economy	3700.00
0005433123693	30331	Economy	3700.00
0005432720549	30331	Economy	3700.00
0005433123683	30331	Economy	3700.00
0005432720550	30331	Economy	3700.00
0005432720552	30331	Economy	3700.00
0005432720712	30331	Economy	3700.00
0005433722203	30331	Economy	3700.00
0005433123697	30331	Economy	3700.00
0005432720683	30331	Economy	3700.00
0005433525005	1374	Business	70400.00
0005434586549	1374	Business	70400.00
0005433192881	1374	Business	70400.00
0005432927908	1374	Business	70400.00
0005434586531	1374	Business	70400.00
0005434586538	1374	Business	70400.00
0005434586542	1374	Business	70400.00
0005433724792	1374	Economy	23500.00
0005433192882	1374	Economy	23500.00
0005433724793	1374	Economy	23500.00
0005434586529	1374	Economy	23500.00
0005434586548	1374	Economy	23500.00
0005433192883	1374	Economy	23500.00
0005434513573	1374	Economy	23500.00
0005433525010	1374	Economy	23500.00
0005434586551	1374	Economy	25800.00
0005434586540	1374	Economy	25800.00
0005433192898	1374	Economy	25800.00
0005433192904	1374	Economy	25800.00
0005433525013	1374	Economy	25800.00
0005434514960	1374	Economy	23500.00
0005433192934	1374	Economy	23500.00
0005434514961	1374	Economy	23500.00
0005434586550	1374	Economy	23500.00
0005433192869	1374	Economy	23500.00
0005434586526	1374	Economy	23500.00
0005434586541	1374	Economy	23500.00
0005433192935	1374	Economy	23500.00
0005433192923	1374	Economy	23500.00
0005434586530	1374	Economy	23500.00
0005434586545	1374	Economy	23500.00
0005433525006	1374	Economy	23500.00
0005434586543	1374	Economy	23500.00
0005433192899	1374	Economy	23500.00
0005434586534	1374	Economy	23500.00
0005433525011	1374	Economy	23500.00
0005433192903	1374	Economy	23500.00
0005433525004	1374	Economy	23500.00
0005434586533	1374	Economy	23500.00
0005434586537	1374	Economy	23500.00
0005434586532	1374	Economy	23500.00
0005434586539	1374	Economy	23500.00
0005433724794	1374	Economy	23500.00
0005433525008	1374	Economy	23500.00
0005434514959	1374	Economy	23500.00
0005433525012	1374	Economy	23500.00
0005434513572	1374	Economy	23500.00
0005433724795	1374	Economy	23500.00
0005432270995	1374	Economy	23500.00
0005434513571	1374	Economy	23500.00
0005433525003	1374	Economy	23500.00
0005434586546	1374	Economy	23500.00
0005432927907	1374	Economy	23500.00
0005432968814	1374	Economy	23500.00
0005434586536	1374	Economy	23500.00
0005434586527	1374	Economy	23500.00
0005433192936	1374	Economy	23500.00
0005433525007	1374	Economy	23500.00
0005434586547	1374	Economy	23500.00
0005433525009	1374	Economy	23500.00
0005434586535	1374	Economy	23500.00
0005434586544	1374	Economy	23500.00
0005432270996	1374	Economy	23500.00
0005432968813	1374	Economy	23500.00
0005434586528	1374	Economy	23500.00
0005433724753	18546	Business	70400.00
0005433724751	18546	Business	70400.00
0005433193004	18546	Business	70400.00
0005433193009	18546	Business	70400.00
0005432927963	18546	Business	70400.00
0005432968832	18546	Business	70400.00
0005433193006	18546	Business	70400.00
0005433524865	18546	Business	70400.00
0005433193002	18546	Economy	23500.00
0005433193013	18546	Economy	23500.00
0005434586355	18546	Economy	23500.00
0005434586359	18546	Economy	23500.00
0005434586296	18546	Economy	23500.00
0005433524864	18546	Economy	23500.00
0005433724754	18546	Economy	25800.00
0005433524898	18546	Economy	23500.00
0005434514933	18546	Economy	23500.00
0005433524883	18546	Economy	23500.00
0005434586295	18546	Economy	23500.00
0005434586209	18546	Economy	23500.00
0005434586400	18546	Economy	23500.00
0005434514930	18546	Economy	23500.00
0005434586271	18546	Economy	23500.00
0005434586367	18546	Economy	23500.00
0005432968833	18546	Economy	23500.00
0005434586309	18546	Economy	23500.00
0005433193011	18546	Economy	23500.00
0005434514948	18546	Economy	23500.00
0005432927964	18546	Economy	23500.00
0005433724731	18546	Economy	23500.00
0005433193007	18546	Economy	23500.00
0005433193003	18546	Economy	23500.00
0005433193010	18546	Economy	23500.00
0005433524884	18546	Economy	23500.00
0005434586332	18546	Economy	23500.00
0005433193012	18546	Economy	23500.00
0005434586294	18546	Economy	23500.00
0005433193000	18546	Economy	23500.00
0005434586311	18546	Economy	23500.00
0005434586351	18546	Economy	23500.00
0005432927965	18546	Economy	23500.00
0005432927960	18546	Economy	23500.00
0005434586213	18546	Economy	23500.00
0005433193001	18546	Economy	23500.00
0005434586214	18546	Economy	23500.00
0005434586365	18546	Economy	23500.00
0005434514942	18546	Economy	23500.00
0005434586270	18546	Economy	23500.00
0005434586333	18546	Economy	23500.00
0005433524913	18546	Economy	23500.00
0005432927962	18546	Economy	23500.00
0005434514932	18546	Economy	23500.00
0005433193008	18546	Economy	23500.00
0005433524899	18546	Economy	23500.00
0005433193005	18546	Economy	23500.00
0005432927961	18546	Economy	23500.00
0005433724752	18546	Economy	23500.00
0005434586268	18546	Economy	23500.00
0005434586366	18546	Economy	23500.00
0005434586293	18546	Economy	23500.00
0005434586267	18546	Economy	23500.00
0005434344096	11463	Economy	4300.00
0005434344092	11463	Economy	4300.00
0005434344078	11463	Economy	4300.00
0005434344093	11463	Economy	4300.00
0005434344076	11463	Economy	4000.00
0005434344064	11463	Economy	4000.00
0005434142598	11463	Economy	4000.00
0005434344070	11463	Economy	4000.00
0005434344095	11463	Economy	4000.00
0005434344062	11463	Economy	4000.00
0005435302135	11463	Economy	4000.00
0005434344084	11463	Economy	4000.00
0005434344067	11463	Economy	4000.00
0005434344077	11463	Economy	4000.00
0005434344089	11463	Economy	4000.00
0005434344079	11463	Economy	4000.00
0005434344088	11463	Economy	4000.00
0005435304995	11463	Economy	4000.00
0005434344091	11463	Economy	4000.00
0005434344063	11463	Economy	4000.00
0005434344097	11463	Economy	4000.00
0005434344086	11463	Economy	4000.00
0005434142599	11463	Economy	4000.00
0005434344068	11463	Economy	4000.00
0005434344075	11463	Economy	4000.00
0005434142597	11463	Economy	4000.00
0005434344071	11463	Economy	4000.00
0005434344066	11463	Economy	4000.00
0005434344090	11463	Economy	4000.00
0005434344065	11463	Economy	4000.00
0005434344061	11463	Economy	4000.00
0005434344069	11463	Economy	4000.00
0005434344098	11463	Economy	4000.00
0005434344094	11463	Economy	4000.00
0005434344080	11463	Economy	4000.00
0005434344087	11463	Economy	4000.00
0005434344072	11463	Economy	4000.00
0005434344083	11463	Economy	4000.00
0005434344073	11463	Economy	4000.00
0005434142600	11463	Economy	4000.00
0005434344082	11463	Economy	4000.00
0005434344081	11463	Economy	4000.00
0005434142602	11463	Economy	4000.00
0005435302134	11463	Economy	4000.00
0005434142601	11463	Economy	4000.00
0005434344085	11463	Economy	4000.00
0005435302133	11463	Economy	4000.00
0005434344074	11463	Economy	4000.00
0005434343660	29773	Economy	4300.00
0005434142547	29773	Economy	4300.00
0005434343652	29773	Economy	4300.00
0005434343629	29773	Economy	4300.00
0005434343755	29773	Economy	4000.00
0005434343845	29773	Economy	4000.00
0005434343749	29773	Economy	4000.00
0005435305011	29773	Economy	4000.00
0005434343952	29773	Economy	4000.00
0005434343849	29773	Economy	4000.00
0005434343848	29773	Economy	4000.00
0005435304146	29773	Economy	4000.00
0005434343887	29773	Economy	4000.00
0005435304147	29773	Economy	4000.00
0005434343863	29773	Economy	4000.00
0005434343719	29773	Economy	4000.00
0005434142565	29773	Economy	4000.00
0005434343951	29773	Economy	4000.00
0005434343718	29773	Economy	4000.00
0005434142572	29773	Economy	4000.00
0005434343694	29773	Economy	4000.00
0005434343846	29773	Economy	4000.00
0005434343677	29773	Economy	4000.00
0005434343982	29773	Economy	4000.00
0005434343734	29773	Economy	4000.00
0005434142561	29773	Economy	4000.00
0005435305010	29773	Economy	4000.00
0005434343659	29773	Economy	4000.00
0005434343704	29773	Economy	4000.00
0005434343662	29773	Economy	4000.00
0005434343787	29773	Economy	4000.00
0005434343800	29773	Economy	4000.00
0005434343983	29773	Economy	4000.00
0005435304145	29773	Economy	4000.00
0005434343870	29773	Economy	4000.00
0005434343809	29773	Economy	4000.00
0005434343871	29773	Economy	4000.00
0005434343738	29773	Economy	4000.00
0005434343739	29773	Economy	4000.00
0005434343754	29773	Economy	4000.00
0005434343788	29773	Economy	4000.00
0005434343735	29773	Economy	4000.00
0005434343839	29773	Economy	4000.00
0005434343818	29773	Economy	4000.00
0005434343693	29773	Economy	4000.00
0005434343669	29773	Economy	4000.00
0005434343864	29773	Economy	4000.00
0005434142573	29773	Economy	4000.00
0005433415462	1284	Business	199800.00
0005435824558	1284	Business	199800.00
0005433415488	1284	Business	199800.00
0005432284548	1284	Business	199800.00
0005433415550	1284	Business	199800.00
0005433415437	1284	Business	199800.00
0005433415461	1284	Economy	66600.00
0005435824541	1284	Economy	66600.00
0005435824556	1284	Economy	66600.00
0005435824549	1284	Economy	66600.00
0005435824560	1284	Economy	66600.00
0005435824552	1284	Economy	66600.00
0005435824544	1284	Economy	66600.00
0005433415521	1284	Economy	66600.00
0005433415460	1284	Economy	73200.00
0005435824537	1284	Economy	66600.00
0005433415487	1284	Economy	66600.00
0005435824545	1284	Economy	66600.00
0005433415491	1284	Economy	66600.00
0005433415551	1284	Economy	66600.00
0005435824553	1284	Economy	66600.00
0005435824538	1284	Economy	66600.00
0005433415510	1284	Economy	66600.00
0005432284550	1284	Economy	66600.00
0005435824536	1284	Economy	66600.00
0005435824562	1284	Economy	66600.00
0005433415511	1284	Economy	66600.00
0005433415526	1284	Economy	66600.00
0005435824557	1284	Economy	66600.00
0005435824546	1284	Economy	66600.00
0005435824551	1284	Economy	66600.00
0005433415486	1284	Economy	66600.00
0005435824542	1284	Economy	66600.00
0005433415497	1284	Economy	66600.00
0005435824548	1284	Economy	66600.00
0005435824543	1284	Economy	66600.00
0005433415495	1284	Economy	66600.00
0005435824550	1284	Economy	66600.00
0005435824540	1284	Economy	66600.00
0005432284549	1284	Economy	66600.00
0005435824561	1284	Economy	66600.00
0005435824539	1284	Economy	66600.00
0005435824554	1284	Economy	66600.00
0005435824555	1284	Economy	66600.00
0005433415476	1284	Economy	66600.00
0005433415527	1284	Economy	66600.00
0005435824547	1284	Economy	66600.00
0005435824559	1284	Economy	66600.00
0005433415438	1284	Economy	66600.00
0005433415453	1284	Economy	66600.00
0005435824391	17991	Business	199800.00
0005435824373	17991	Business	199800.00
0005435824344	17991	Business	199800.00
0005435824341	17991	Business	199800.00
0005433415616	17991	Business	199800.00
0005433415619	17991	Business	199800.00
0005435824298	17991	Business	199800.00
0005435824398	17991	Business	199800.00
0005435824292	17991	Business	199800.00
0005435824277	17991	Economy	66600.00
0005435824289	17991	Economy	66600.00
0005435824328	17991	Economy	73200.00
0005435824340	17991	Economy	66600.00
0005433415611	17991	Economy	66600.00
0005433415622	17991	Economy	66600.00
0005435824291	17991	Economy	66600.00
0005433415615	17991	Economy	66600.00
0005435824374	17991	Economy	66600.00
0005433415610	17991	Economy	66600.00
0005433415617	17991	Economy	66600.00
0005435824399	17991	Economy	66600.00
0005433415612	17991	Economy	66600.00
0005435824322	17991	Economy	66600.00
0005433415618	17991	Economy	66600.00
0005433415607	17991	Economy	66600.00
0005435824404	17991	Economy	66600.00
0005433415608	17991	Economy	66600.00
0005433415614	17991	Economy	66600.00
0005433415613	17991	Economy	66600.00
0005433415606	17991	Economy	66600.00
0005433415609	17991	Economy	66600.00
0005433415620	17991	Economy	66600.00
0005433415621	17991	Economy	66600.00
0005435824278	17991	Economy	66600.00
0005435824392	17991	Economy	66600.00
0005435824343	17991	Economy	66600.00
0005435824397	17991	Economy	66600.00
0005435824323	17991	Economy	66600.00
0005432783648	5643	Business	27800.00
0005435476689	5643	Business	27800.00
0005435242479	5643	Business	27800.00
0005435242436	5643	Business	27800.00
0005435476657	5643	Business	27800.00
0005435242525	5643	Business	27800.00
0005432783645	5643	Business	27800.00
0005432783651	5643	Business	27800.00
0005435242423	5643	Business	27800.00
0005435242566	5643	Business	27800.00
0005435242440	5643	Business	27800.00
0005432783650	5643	Business	27800.00
0005432783625	5643	Economy	9300.00
0005435476662	5643	Economy	9300.00
0005432783610	5643	Economy	9300.00
0005435242503	5643	Economy	9300.00
0005432783611	5643	Economy	9300.00
0005435242569	5643	Economy	9300.00
0005432783663	5643	Economy	9300.00
0005432143979	5643	Economy	9300.00
0005432783619	5643	Economy	9300.00
0005432783634	5643	Economy	9300.00
0005432783655	5643	Economy	10200.00
0005435476649	5643	Economy	10200.00
0005432783656	5643	Economy	10200.00
0005435242493	5643	Economy	10200.00
0005432783616	5643	Economy	10200.00
0005435242531	5643	Economy	9300.00
0005432783609	5643	Economy	9300.00
0005432783637	5643	Economy	9300.00
0005435476669	5643	Economy	9300.00
0005435242504	5643	Economy	9300.00
0005432783643	5643	Economy	9300.00
0005432143976	5643	Economy	9300.00
0005432783654	5643	Economy	9300.00
0005432783620	5643	Economy	9300.00
0005435242519	5643	Economy	9300.00
0005432783631	5643	Economy	9300.00
0005432783649	5643	Economy	9300.00
0005435476656	5643	Economy	9300.00
0005432783662	5643	Economy	9300.00
0005432783614	5643	Economy	9300.00
0005435242532	5643	Economy	9300.00
0005435476652	5643	Economy	9300.00
0005435476661	5643	Economy	9300.00
0005432783639	5643	Economy	9300.00
0005432783623	5643	Economy	9300.00
0005432783612	5643	Economy	9300.00
0005432783627	5643	Economy	9300.00
0005432783652	5643	Economy	9300.00
0005432143977	5643	Economy	9300.00
0005435242482	5643	Economy	9300.00
0005432783638	5643	Economy	9300.00
0005435242563	5643	Economy	9300.00
0005435242435	5643	Economy	9300.00
0005432783647	5643	Economy	9300.00
0005435242422	5643	Economy	9300.00
0005432783660	5643	Economy	9300.00
0005432783657	5643	Economy	9300.00
0005432783636	5643	Economy	9300.00
0005435242570	5643	Economy	9300.00
0005435242465	5643	Economy	9300.00
0005432783635	5643	Economy	9300.00
0005432783653	5643	Economy	9300.00
0005435242564	5643	Economy	9300.00
0005432783633	5643	Economy	9300.00
0005432783664	5643	Economy	9300.00
0005432783646	5643	Economy	9300.00
0005435476653	5643	Economy	9300.00
0005432783640	5643	Economy	9300.00
0005435242565	5643	Economy	9300.00
0005432783613	5643	Economy	9300.00
0005432783632	5643	Economy	9300.00
0005432783630	5643	Economy	9300.00
0005432783642	5643	Economy	9300.00
0005432783641	5643	Economy	9300.00
0005432783644	5643	Economy	9300.00
0005435242526	5643	Economy	9300.00
0005432783621	5643	Economy	9300.00
0005432783659	5643	Economy	9300.00
0005435476671	5643	Economy	9300.00
0005432783624	5643	Economy	9300.00
0005435476683	5643	Economy	9300.00
0005435476670	5643	Economy	9300.00
0005432783626	5643	Economy	9300.00
0005435242568	5643	Economy	9300.00
0005432143978	5643	Economy	9300.00
0005432783628	5643	Economy	9300.00
0005432783618	5643	Economy	9300.00
0005435242449	5643	Economy	9300.00
0005435242518	5643	Economy	9300.00
0005432783629	5643	Economy	9300.00
0005432783661	5643	Economy	9300.00
0005432783617	5643	Economy	9300.00
0005432783615	5643	Economy	9300.00
0005432783658	5643	Economy	9300.00
0005432783622	5643	Economy	9300.00
0005432783159	15385	Business	27800.00
0005432783050	15385	Business	27800.00
0005435476735	15385	Business	27800.00
0005435242748	15385	Business	27800.00
0005432783056	15385	Business	27800.00
0005432783127	15385	Business	27800.00
0005435242747	15385	Business	27800.00
0005432782878	15385	Business	27800.00
0005432782932	15385	Business	27800.00
0005432783109	15385	Business	27800.00
0005435242768	15385	Business	27800.00
0005432783209	15385	Business	27800.00
0005435242754	15385	Economy	9300.00
0005432783275	15385	Economy	9300.00
0005432783181	15385	Economy	9300.00
0005432783049	15385	Economy	9300.00
0005432783281	15385	Economy	9300.00
0005435476733	15385	Economy	9300.00
0005432782958	15385	Economy	9300.00
0005435242751	15385	Economy	9300.00
0005432783280	15385	Economy	9300.00
0005432783067	15385	Economy	9300.00
0005432783028	15385	Economy	10200.00
0005432783140	15385	Economy	10200.00
0005432783186	15385	Economy	10200.00
0005432783268	15385	Economy	10200.00
0005432783210	15385	Economy	9300.00
0005432783007	15385	Economy	9300.00
0005432782978	15385	Economy	9300.00
0005435242745	15385	Economy	9300.00
0005432782980	15385	Economy	9300.00
0005432782996	15385	Economy	9300.00
0005435242750	15385	Economy	9300.00
0005432783008	15385	Economy	9300.00
0005432783157	15385	Economy	9300.00
0005432783058	15385	Economy	9300.00
0005435242746	15385	Economy	9300.00
0005432783150	15385	Economy	9300.00
0005435242752	15385	Economy	9300.00
0005432783115	15385	Economy	9300.00
0005435242760	15385	Economy	9300.00
0005432783180	15385	Economy	9300.00
0005432783199	15385	Economy	9300.00
0005435242762	15385	Economy	9300.00
0005432783267	15385	Economy	9300.00
0005435476732	15385	Economy	9300.00
0005432783203	15385	Economy	9300.00
0005432783030	15385	Economy	9300.00
0005435242742	15385	Economy	9300.00
0005432783230	15385	Economy	9300.00
0005432783000	15385	Economy	9300.00
0005432783043	15385	Economy	9300.00
0005435476734	15385	Economy	9300.00
0005432783158	15385	Economy	9300.00
0005432783034	15385	Economy	9300.00
0005432783208	15385	Economy	9300.00
0005435242766	15385	Economy	9300.00
0005435242756	15385	Economy	9300.00
0005435242767	15385	Economy	9300.00
0005432782999	15385	Economy	9300.00
0005432783211	15385	Economy	9300.00
0005435242764	15385	Economy	9300.00
0005435242769	15385	Economy	9300.00
0005432783161	15385	Economy	9300.00
0005432783120	15385	Economy	9300.00
0005432782979	15385	Economy	9300.00
0005432783128	15385	Economy	9300.00
0005432782985	15385	Economy	9300.00
0005432783148	15385	Economy	9300.00
0005435242757	15385	Economy	9300.00
0005432783325	15385	Economy	9300.00
0005432782933	15385	Economy	9300.00
0005432783146	15385	Economy	9300.00
0005432783346	15385	Economy	9300.00
0005435242743	15385	Economy	9300.00
0005432783149	15385	Economy	9300.00
0005432783163	15385	Economy	9300.00
0005432783147	15385	Economy	9300.00
0005435242759	15385	Economy	9300.00
0005432783540	15385	Economy	9300.00
0005432783377	15385	Economy	9300.00
0005435242763	15385	Economy	9300.00
0005435242758	15385	Economy	9300.00
0005435242761	15385	Economy	9300.00
0005432782935	15385	Economy	9300.00
0005435242749	15385	Economy	9300.00
0005432783029	15385	Economy	9300.00
0005435242753	15385	Economy	9300.00
0005432783020	15385	Economy	9300.00
0005432783086	15385	Economy	9300.00
0005432783541	15385	Economy	9300.00
0005435242765	15385	Economy	9300.00
0005435242744	15385	Economy	9300.00
0005432783085	15385	Economy	9300.00
0005435242755	15385	Economy	9300.00
0005435850797	4390	Economy	7000.00
0005432848273	4390	Economy	7000.00
0005432848274	4390	Economy	6300.00
0005435850811	4390	Economy	6300.00
0005432848277	4390	Economy	6300.00
0005432848265	4390	Economy	6300.00
0005432848267	4390	Economy	6300.00
0005432848271	4390	Economy	6300.00
0005432848275	4390	Economy	6300.00
0005432848266	4390	Economy	6300.00
0005432848270	4390	Economy	6300.00
0005432848276	4390	Economy	6300.00
0005434462783	4390	Economy	6300.00
0005432848264	4390	Economy	6300.00
0005432848272	4390	Economy	6300.00
0005432848268	4390	Economy	6300.00
0005435850801	4390	Economy	6300.00
0005435850800	4390	Economy	6300.00
0005435850836	4390	Economy	6300.00
0005434463922	4390	Economy	6300.00
0005434463923	4390	Economy	6300.00
0005435850799	4390	Economy	6300.00
0005434462784	4390	Economy	6300.00
0005435850826	4390	Economy	6300.00
0005435850839	4390	Economy	6300.00
0005435850806	4390	Economy	6300.00
0005432848269	4390	Economy	6300.00
0005432848133	28869	Economy	7000.00
0005434463908	28869	Economy	6300.00
0005435850884	28869	Economy	6300.00
0005432848122	28869	Economy	6300.00
0005435850882	28869	Economy	6300.00
0005432848121	28869	Economy	6300.00
0005432848171	28869	Economy	6300.00
0005432848132	28869	Economy	6300.00
0005435850887	28869	Economy	6300.00
0005435850886	28869	Economy	6300.00
0005435850883	28869	Economy	6300.00
0005432848166	28869	Economy	6300.00
0005435850881	28869	Economy	6300.00
0005432848143	28869	Economy	6300.00
0005435850885	28869	Economy	6300.00
0005434443660	6342	Business	11900.00
0005433496888	6342	Business	11900.00
0005434925728	6342	Business	11900.00
0005434925720	6342	Business	11900.00
0005434443661	6342	Business	11900.00
0005433496898	6342	Business	11900.00
0005434925736	6342	Business	11900.00
0005434925740	6342	Business	11900.00
0005434925723	6342	Business	11900.00
0005433496871	6342	Business	11900.00
0005433496867	6342	Economy	4000.00
0005433496884	6342	Economy	4000.00
0005434925745	6342	Economy	4000.00
0005433496877	6342	Economy	4000.00
0005434925734	6342	Economy	4000.00
0005432075220	6342	Economy	4000.00
0005433496881	6342	Economy	4000.00
0005433496891	6342	Economy	4000.00
0005433496866	6342	Economy	4000.00
0005434925724	6342	Economy	4400.00
0005434925748	6342	Economy	4400.00
0005433496893	6342	Economy	4400.00
0005434925733	6342	Economy	4000.00
0005434925739	6342	Economy	4000.00
0005432075219	6342	Economy	4000.00
0005434925746	6342	Economy	4000.00
0005434925732	6342	Economy	4000.00
0005433496896	6342	Economy	4000.00
0005433496885	6342	Economy	4000.00
0005432075221	6342	Economy	4000.00
0005434443670	6342	Economy	4000.00
0005434925721	6342	Economy	4000.00
0005433496894	6342	Economy	4000.00
0005433496879	6342	Economy	4000.00
0005434925731	6342	Economy	4000.00
0005434925737	6342	Economy	4000.00
0005434925729	6342	Economy	4000.00
0005433496876	6342	Economy	4000.00
0005433496880	6342	Economy	4000.00
0005434443669	6342	Economy	4000.00
0005433496889	6342	Economy	4000.00
0005434925725	6342	Economy	4000.00
0005434925747	6342	Economy	4000.00
0005433496874	6342	Economy	4000.00
0005433496872	6342	Economy	4000.00
0005434443665	6342	Economy	4000.00
0005433496895	6342	Economy	4000.00
0005434925726	6342	Economy	4000.00
0005434443657	6342	Economy	4000.00
0005433496869	6342	Economy	4000.00
0005433496887	6342	Economy	4000.00
0005434443667	6342	Economy	4000.00
0005434443662	6342	Economy	4000.00
0005434925719	6342	Economy	4000.00
0005434443664	6342	Economy	4000.00
0005434925738	6342	Economy	4000.00
0005433496897	6342	Economy	4000.00
0005434925717	6342	Economy	4000.00
0005433496868	6342	Economy	4000.00
0005434925744	6342	Economy	4000.00
0005433496873	6342	Economy	4000.00
0005434443668	6342	Economy	4000.00
0005434925735	6342	Economy	4000.00
0005434443659	6342	Economy	4000.00
0005434443666	6342	Economy	4000.00
0005433496886	6342	Economy	4000.00
0005433496878	6342	Economy	4000.00
0005433496870	6342	Economy	4000.00
0005434925722	6342	Economy	4000.00
0005433496892	6342	Economy	4000.00
0005434925749	6342	Economy	4000.00
0005433496890	6342	Economy	4000.00
0005434443656	6342	Economy	4000.00
0005434925727	6342	Economy	4000.00
0005434925742	6342	Economy	4000.00
0005434925730	6342	Economy	4000.00
0005434925741	6342	Economy	4000.00
0005433496883	6342	Economy	4000.00
0005434443663	6342	Economy	4000.00
0005433496882	6342	Economy	4000.00
0005434925718	6342	Economy	4000.00
0005434925743	6342	Economy	4000.00
0005434443655	6342	Economy	4000.00
0005434443658	6342	Economy	4000.00
0005433496875	6342	Economy	4000.00
0005433496549	20389	Business	11900.00
0005433496612	20389	Business	11900.00
0005434925444	20389	Business	11900.00
0005434925248	20389	Business	11900.00
0005433496709	20389	Business	11900.00
0005433496729	20389	Business	11900.00
0005434443542	20389	Business	11900.00
0005434925300	20389	Business	11900.00
0005434925467	20389	Business	11900.00
0005433496548	20389	Business	11900.00
0005433496577	20389	Economy	4000.00
0005434443483	20389	Economy	4000.00
0005434925371	20389	Economy	4000.00
0005434925421	20389	Economy	4000.00
0005434925383	20389	Economy	4000.00
0005433496779	20389	Economy	4000.00
0005433496583	20389	Economy	4000.00
0005433496701	20389	Economy	4000.00
0005434925391	20389	Economy	4000.00
0005433496731	20389	Economy	4400.00
0005434925402	20389	Economy	4400.00
0005434925449	20389	Economy	4400.00
0005433496691	20389	Economy	4000.00
0005434443502	20389	Economy	4000.00
0005434443524	20389	Economy	4000.00
0005433496609	20389	Economy	4000.00
0005434443496	20389	Economy	4000.00
0005434925423	20389	Economy	4000.00
0005434925388	20389	Economy	4000.00
0005433496642	20389	Economy	4000.00
0005434443484	20389	Economy	4000.00
0005433496735	20389	Economy	4000.00
0005434925466	20389	Economy	4000.00
0005434925433	20389	Economy	4000.00
0005434443481	20389	Economy	4000.00
0005434443567	20389	Economy	4000.00
0005433496700	20389	Economy	4000.00
0005433496595	20389	Economy	4000.00
0005434443510	20389	Economy	4000.00
0005434925418	20389	Economy	4000.00
0005433496611	20389	Economy	4000.00
0005434443562	20389	Economy	4000.00
0005433496730	20389	Economy	4000.00
0005434443521	20389	Economy	4000.00
0005433496649	20389	Economy	4000.00
0005433496756	20389	Economy	4000.00
0005433496576	20389	Economy	4000.00
0005433496792	20389	Economy	4000.00
0005434443568	20389	Economy	4000.00
0005434925370	20389	Economy	4000.00
0005434925461	20389	Economy	4000.00
0005433496575	20389	Economy	4000.00
0005434925264	20389	Economy	4000.00
0005434925403	20389	Economy	4000.00
0005434925451	20389	Economy	4000.00
0005434925452	20389	Economy	4000.00
0005434925293	20389	Economy	4000.00
0005433496643	20389	Economy	4000.00
0005434925462	20389	Economy	4000.00
0005433496619	20389	Economy	4000.00
0005434925369	20389	Economy	4000.00
0005433496710	20389	Economy	4000.00
0005433496620	20389	Economy	4000.00
0005434925273	20389	Economy	4000.00
0005434925453	20389	Economy	4000.00
0005434925455	20389	Economy	4000.00
0005433496530	20389	Economy	4000.00
0005433496832	20389	Economy	4000.00
0005433496648	20389	Economy	4000.00
0005433496610	20389	Economy	4000.00
0005433496656	20389	Economy	4000.00
0005434443574	20389	Economy	4000.00
0005433496596	20389	Economy	4000.00
0005434925443	20389	Economy	4000.00
0005434925424	20389	Economy	4000.00
0005434925344	20389	Economy	4000.00
0005434925299	20389	Economy	4000.00
0005434925425	20389	Economy	4000.00
0005432783418	12189	Business	41200.00
0005432783333	12189	Business	41200.00
0005432783272	12189	Business	41200.00
0005435242795	12189	Business	41200.00
0005432783279	12189	Business	41200.00
0005432783274	12189	Business	41200.00
0005432783078	12189	Business	41200.00
0005432783144	12189	Business	41200.00
0005435242773	12189	Business	41200.00
0005435242787	12189	Business	41200.00
0005432783114	12189	Business	41200.00
0005435242781	12189	Economy	13700.00
0005432783111	12189	Economy	13700.00
0005432783123	12189	Economy	13700.00
0005432783250	12189	Economy	13700.00
0005432783145	12189	Economy	13700.00
0005435242780	12189	Economy	13700.00
0005432783191	12189	Economy	13700.00
0005432783382	12189	Economy	13700.00
0005432783343	12189	Economy	13700.00
0005435242789	12189	Economy	13700.00
0005435242784	12189	Economy	15100.00
0005432783341	12189	Economy	15100.00
0005432783342	12189	Economy	15100.00
0005432783334	12189	Economy	15100.00
0005432782971	12189	Economy	15100.00
0005435242785	12189	Economy	13700.00
0005435242775	12189	Economy	13700.00
0005435242796	12189	Economy	13700.00
0005435242778	12189	Economy	13700.00
0005432783380	12189	Economy	13700.00
0005432783215	12189	Economy	13700.00
0005432783340	12189	Economy	13700.00
0005432783321	12189	Economy	13700.00
0005432783204	12189	Economy	13700.00
0005432783012	12189	Economy	13700.00
0005435242771	12189	Economy	13700.00
0005435242783	12189	Economy	13700.00
0005432783355	12189	Economy	13700.00
0005432783433	12189	Economy	13700.00
0005435242786	12189	Economy	13700.00
0005432783236	12189	Economy	13700.00
0005435242792	12189	Economy	13700.00
0005435242788	12189	Economy	13700.00
0005435242770	12189	Economy	13700.00
0005432783287	12189	Economy	13700.00
0005432783372	12189	Economy	13700.00
0005432783205	12189	Economy	13700.00
0005435242790	12189	Economy	13700.00
0005435242779	12189	Economy	13700.00
0005432783101	12189	Economy	13700.00
0005432783286	12189	Economy	13700.00
0005435242774	12189	Economy	13700.00
0005432783100	12189	Economy	13700.00
0005432783124	12189	Economy	13700.00
0005432783076	12189	Economy	13700.00
0005432783027	12189	Economy	13700.00
0005432783383	12189	Economy	13700.00
0005432783235	12189	Economy	13700.00
0005432783278	12189	Economy	13700.00
0005435242794	12189	Economy	13700.00
0005432783206	12189	Economy	13700.00
0005432783258	12189	Economy	13700.00
0005432783216	12189	Economy	13700.00
0005432783179	12189	Economy	13700.00
0005435242777	12189	Economy	13700.00
0005432783266	12189	Economy	13700.00
0005432783122	12189	Economy	13700.00
0005435242791	12189	Economy	13700.00
0005435242776	12189	Economy	13700.00
0005432783113	12189	Economy	13700.00
0005435242772	12189	Economy	13700.00
0005432783381	12189	Economy	13700.00
0005432783273	12189	Economy	13700.00
0005435242793	12189	Economy	13700.00
0005435242782	12189	Economy	13700.00
0005432783075	12189	Economy	13700.00
0005432783021	12189	Economy	13700.00
0005432783088	12189	Economy	13700.00
0005432783557	15418	Business	41200.00
0005435242502	15418	Business	41200.00
0005432783571	15418	Business	41200.00
0005432783598	15418	Business	41200.00
0005432783556	15418	Business	41200.00
0005432783595	15418	Business	41200.00
0005432783577	15418	Business	41200.00
0005435242447	15418	Business	41200.00
0005432783574	15418	Business	41200.00
0005432783563	15418	Business	41200.00
0005435242528	15418	Business	41200.00
0005432783590	15418	Economy	13700.00
0005432783599	15418	Economy	13700.00
0005432783604	15418	Economy	13700.00
0005432783591	15418	Economy	13700.00
0005432783575	15418	Economy	13700.00
0005432783581	15418	Economy	13700.00
0005435242537	15418	Economy	13700.00
0005435242473	15418	Economy	13700.00
0005432783565	15418	Economy	13700.00
0005432783603	15418	Economy	13700.00
0005435242515	15418	Economy	15100.00
0005432783584	15418	Economy	15100.00
0005435242574	15418	Economy	15100.00
0005432783570	15418	Economy	15100.00
0005435242461	15418	Economy	15100.00
0005432783607	15418	Economy	13700.00
0005435242560	15418	Economy	13700.00
0005435242460	15418	Economy	13700.00
0005432783597	15418	Economy	13700.00
0005432783555	15418	Economy	13700.00
0005432783554	15418	Economy	13700.00
0005432783586	15418	Economy	13700.00
0005432783606	15418	Economy	13700.00
0005432783560	15418	Economy	13700.00
0005432783601	15418	Economy	13700.00
0005432783605	15418	Economy	13700.00
0005432783569	15418	Economy	13700.00
0005432783559	15418	Economy	13700.00
0005435242498	15418	Economy	13700.00
0005435242463	15418	Economy	13700.00
0005432783573	15418	Economy	13700.00
0005435242491	15418	Economy	13700.00
0005435242625	15418	Economy	13700.00
0005432783564	15418	Economy	13700.00
0005432783587	15418	Economy	13700.00
0005432783592	15418	Economy	13700.00
0005432783583	15418	Economy	13700.00
0005432783588	15418	Economy	13700.00
0005432783567	15418	Economy	13700.00
0005432783593	15418	Economy	13700.00
0005432783562	15418	Economy	13700.00
0005432783602	15418	Economy	13700.00
0005432783558	15418	Economy	13700.00
0005435242562	15418	Economy	13700.00
0005432783594	15418	Economy	13700.00
0005432783578	15418	Economy	13700.00
0005435242439	15418	Economy	13700.00
0005432783585	15418	Economy	13700.00
0005435242492	15418	Economy	13700.00
0005432783600	15418	Economy	13700.00
0005435242516	15418	Economy	13700.00
0005432783582	15418	Economy	13700.00
0005432783580	15418	Economy	13700.00
0005435242427	15418	Economy	13700.00
0005432783579	15418	Economy	13700.00
0005435242417	15418	Economy	13700.00
0005432783566	15418	Economy	13700.00
0005432783561	15418	Economy	13700.00
0005432783589	15418	Economy	13700.00
0005432783608	15418	Economy	13700.00
0005432783568	15418	Economy	13700.00
0005435242538	15418	Economy	13700.00
0005435242474	15418	Economy	13700.00
0005435242514	15418	Economy	13700.00
0005432783576	15418	Economy	13700.00
0005432783596	15418	Economy	13700.00
0005432783572	15418	Economy	13700.00
0005435242561	15418	Economy	13700.00
0005435242462	15418	Economy	13700.00
0005434877094	10070	Business	49700.00
0005434910102	10070	Business	49700.00
0005434877212	10070	Business	49700.00
0005434877286	10070	Business	49700.00
0005434876990	10070	Business	49700.00
0005434877391	10070	Business	49700.00
0005434877116	10070	Business	49700.00
0005434877245	10070	Business	49700.00
0005434877603	10070	Business	49700.00
0005434877096	10070	Business	49700.00
0005434877296	10070	Business	49700.00
0005434876919	10070	Business	49700.00
0005434877236	10070	Business	49700.00
0005434877233	10070	Business	49700.00
0005434877022	10070	Business	49700.00
0005434877047	10070	Business	49700.00
0005434877157	10070	Business	49700.00
0005434877051	10070	Business	49700.00
0005434876906	10070	Business	49700.00
0005434877270	10070	Economy	16600.00
0005434876882	10070	Economy	16600.00
0005434877121	10070	Economy	16600.00
0005434877655	10070	Economy	16600.00
0005434877290	10070	Economy	16600.00
0005434877091	10070	Economy	16600.00
0005434877175	10070	Economy	16600.00
0005434877427	10070	Economy	16600.00
0005434877439	10070	Economy	16600.00
0005434877295	10070	Economy	16600.00
0005434877176	10070	Economy	16600.00
0005434877225	10070	Economy	16600.00
0005434876832	10070	Economy	16600.00
0005434877406	10070	Economy	18200.00
0005434877291	10070	Economy	18200.00
0005434876808	10070	Economy	18200.00
0005434877168	10070	Economy	16600.00
0005434910103	10070	Economy	18200.00
0005434876795	10070	Economy	16600.00
0005434877160	10070	Economy	16600.00
0005434877008	10070	Economy	16600.00
0005434876871	10070	Economy	16600.00
0005434877321	10070	Economy	16600.00
0005434877267	10070	Economy	16600.00
0005434877106	10070	Economy	16600.00
0005434877161	10070	Economy	16600.00
0005434876770	10070	Economy	16600.00
0005434876859	10070	Economy	16600.00
0005434877062	10070	Economy	16600.00
0005434876988	10070	Economy	16600.00
0005434877390	10070	Economy	16600.00
0005434877266	10070	Economy	16600.00
0005434876881	10070	Economy	16600.00
0005434876848	10070	Economy	16600.00
0005434877320	10070	Economy	16600.00
0005434876847	10070	Economy	16600.00
0005435913929	10070	Economy	16600.00
0005434877063	10070	Economy	16600.00
0005434876874	10070	Economy	16600.00
0005434877288	10070	Economy	16600.00
0005434876833	10070	Economy	16600.00
0005434877120	10070	Economy	16600.00
0005434877467	10070	Economy	16600.00
0005434877677	10070	Economy	16600.00
0005434876989	10070	Economy	16600.00
0005434877174	10070	Economy	16600.00
0005434877424	10070	Economy	16600.00
0005434876950	10070	Economy	16600.00
0005434877463	10070	Economy	16600.00
0005434877037	10070	Economy	16600.00
0005434877311	10070	Economy	16600.00
0005434877090	10070	Economy	16600.00
0005434758871	10070	Economy	16600.00
0005434877334	10070	Economy	16600.00
0005434877264	10070	Economy	16600.00
0005434877088	10070	Economy	16600.00
0005434876945	10070	Economy	16600.00
0005434910104	10070	Economy	16600.00
0005434877415	10070	Economy	16600.00
0005434877099	10070	Economy	16600.00
0005434877111	10070	Economy	16600.00
0005434876831	10070	Economy	16600.00
0005434758870	10070	Economy	16600.00
0005434758869	10070	Economy	16600.00
0005434877414	10070	Economy	16600.00
0005435913928	10070	Economy	16600.00
0005434876849	10070	Economy	16600.00
0005434877038	10070	Economy	16600.00
0005434876771	10070	Economy	16600.00
0005434876880	10070	Economy	16600.00
0005434876982	10070	Economy	16600.00
0005434877374	10070	Economy	16600.00
0005434876858	10070	Economy	16600.00
0005434877110	10070	Economy	16600.00
0005434877107	10070	Economy	16600.00
0005434877095	10070	Economy	16600.00
0005434877009	10070	Economy	16600.00
0005434877100	10070	Economy	16600.00
0005434877615	10070	Economy	16600.00
0005434877200	10070	Economy	16600.00
0005434877215	10070	Economy	16600.00
0005434877285	10070	Economy	16600.00
0005434877271	10070	Economy	16600.00
0005434877287	10070	Economy	16600.00
0005434876905	10070	Economy	16600.00
0005434877226	10070	Economy	16600.00
0005434877404	10070	Economy	16600.00
0005434877105	10070	Economy	16600.00
0005434877071	10070	Economy	16600.00
0005434877234	10070	Economy	16600.00
0005434876902	10070	Economy	16600.00
0005434877214	10070	Economy	16600.00
0005434878007	14641	Business	49700.00
0005434910090	14641	Business	49700.00
0005434877996	14641	Business	49700.00
0005434878000	14641	Business	49700.00
0005434877942	14641	Business	49700.00
0005435913862	14641	Business	49700.00
0005434877982	14641	Business	49700.00
0005434877962	14641	Business	49700.00
0005435913873	14641	Business	49700.00
0005434878005	14641	Business	49700.00
0005434877912	14641	Business	49700.00
0005434877955	14641	Business	49700.00
0005434758887	14641	Business	49700.00
0005434877984	14641	Business	49700.00
0005435913884	14641	Business	49700.00
0005434877972	14641	Business	49700.00
0005434877997	14641	Business	49700.00
0005434877931	14641	Business	49700.00
0005434877930	14641	Business	49700.00
0005434878001	14641	Business	49700.00
0005434877968	14641	Economy	16600.00
0005434877943	14641	Economy	16600.00
0005434877925	14641	Economy	16600.00
0005434877914	14641	Economy	16600.00
0005434877935	14641	Economy	16600.00
0005434877995	14641	Economy	16600.00
0005434877988	14641	Economy	16600.00
0005434877969	14641	Economy	16600.00
0005434877922	14641	Economy	16600.00
0005434877963	14641	Economy	16600.00
0005434877957	14641	Economy	16600.00
0005434877966	14641	Economy	16600.00
0005434877975	14641	Economy	18200.00
0005434877924	14641	Economy	18200.00
0005435913859	14641	Economy	18200.00
0005434878003	14641	Economy	18200.00
0005434910076	14641	Economy	16600.00
0005434877998	14641	Economy	16600.00
0005434877999	14641	Economy	16600.00
0005434877956	14641	Economy	16600.00
0005434877944	14641	Economy	16600.00
0005434877976	14641	Economy	16600.00
0005434877952	14641	Economy	16600.00
0005434877954	14641	Economy	16600.00
0005434877932	14641	Economy	16600.00
0005434877938	14641	Economy	16600.00
0005434877964	14641	Economy	16600.00
0005434877933	14641	Economy	16600.00
0005434877992	14641	Economy	16600.00
0005434877970	14641	Economy	16600.00
0005435913869	14641	Economy	16600.00
0005434878002	14641	Economy	16600.00
0005434877971	14641	Economy	16600.00
0005435913879	14641	Economy	16600.00
0005434877911	14641	Economy	16600.00
0005435913860	14641	Economy	16600.00
0005434877927	14641	Economy	16600.00
0005434878004	14641	Economy	16600.00
0005434877989	14641	Economy	16600.00
0005434877965	14641	Economy	16600.00
0005434877917	14641	Economy	16600.00
0005434877916	14641	Economy	16600.00
0005434877946	14641	Economy	16600.00
0005434877947	14641	Economy	16600.00
0005434758886	14641	Economy	16600.00
0005434877994	14641	Economy	16600.00
0005434877960	14641	Economy	16600.00
0005434878006	14641	Economy	16600.00
0005434877973	14641	Economy	16600.00
0005434877977	14641	Economy	16600.00
0005435913883	14641	Economy	16600.00
0005434877936	14641	Economy	16600.00
0005434877961	14641	Economy	16600.00
0005434877978	14641	Economy	16600.00
0005434877991	14641	Economy	16600.00
0005435913861	14641	Economy	16600.00
0005434877990	14641	Economy	16600.00
0005434877950	14641	Economy	16600.00
0005434877958	14641	Economy	16600.00
0005434877921	14641	Economy	16600.00
0005434877918	14641	Economy	16600.00
0005434877945	14641	Economy	16600.00
0005434877967	14641	Economy	16600.00
0005434877928	14641	Economy	16600.00
0005434877980	14641	Economy	16600.00
0005434877974	14641	Economy	16600.00
0005434758885	14641	Economy	16600.00
0005434877987	14641	Economy	16600.00
0005434877951	14641	Economy	16600.00
0005434877949	14641	Economy	16600.00
0005434877981	14641	Economy	16600.00
0005434877919	14641	Economy	16600.00
0005434877979	14641	Economy	16600.00
0005434877915	14641	Economy	16600.00
0005435913876	14641	Economy	16600.00
0005434877986	14641	Economy	16600.00
0005434877926	14641	Economy	16600.00
0005434877937	14641	Economy	16600.00
0005434877920	14641	Economy	16600.00
0005434877940	14641	Economy	16600.00
0005434877953	14641	Economy	16600.00
0005434877913	14641	Economy	16600.00
0005434877959	14641	Economy	16600.00
0005435913882	14641	Economy	16600.00
0005434877923	14641	Economy	16600.00
0005434877929	14641	Economy	16600.00
0005434877983	14641	Economy	16600.00
0005434877993	14641	Economy	16600.00
0005434877934	14641	Economy	16600.00
0005434877939	14641	Economy	16600.00
0005434877985	14641	Economy	16600.00
0005434877948	14641	Economy	16600.00
0005434877941	14641	Economy	16600.00
0005434251843	9253	Economy	22400.00
0005434251872	9253	Economy	22400.00
0005435660104	9253	Economy	22400.00
0005435660102	9253	Economy	20300.00
0005434251813	9253	Economy	20300.00
0005435660103	9253	Economy	20300.00
0005435660105	9253	Economy	20300.00
0005434251841	9253	Economy	20300.00
0005434251818	9253	Economy	20300.00
0005435660110	9253	Economy	20300.00
0005434251848	9253	Economy	20300.00
0005435660101	9253	Economy	20300.00
0005435660107	9253	Economy	20300.00
0005435660106	9253	Economy	20300.00
0005434251881	9253	Economy	20300.00
0005435660108	9253	Economy	20300.00
0005434251800	9253	Economy	20300.00
0005434251801	9253	Economy	20300.00
0005435660099	9253	Economy	20300.00
0005435660109	9253	Economy	20300.00
0005434251871	9253	Economy	20300.00
0005435660100	9253	Economy	20300.00
0005434251857	9253	Economy	20300.00
0005435660098	9253	Economy	20300.00
0005434251870	9253	Economy	20300.00
0005435660012	24630	Economy	22400.00
0005434251934	24630	Economy	22400.00
0005434251933	24630	Economy	20300.00
0005435659970	24630	Economy	20300.00
0005435660006	24630	Economy	20300.00
0005434251935	24630	Economy	20300.00
0005434251932	24630	Economy	20300.00
0005435660021	24630	Economy	20300.00
0005435659963	24630	Economy	20300.00
0005435660050	24630	Economy	20300.00
0005435660037	24630	Economy	20300.00
0005435660014	24630	Economy	20300.00
0005435660020	24630	Economy	20300.00
0005434251939	24630	Economy	20300.00
0005434251937	24630	Economy	20300.00
0005435659989	24630	Economy	20300.00
0005435659964	24630	Economy	20300.00
0005435659988	24630	Economy	20300.00
0005435660051	24630	Economy	20300.00
0005434251940	24630	Economy	20300.00
0005434251941	24630	Economy	20300.00
0005435659996	24630	Economy	20300.00
0005435660019	24630	Economy	20300.00
0005434251938	24630	Economy	20300.00
0005435660013	24630	Economy	20300.00
0005435659974	24630	Economy	20300.00
0005435660015	24630	Economy	20300.00
0005434251936	24630	Economy	20300.00
0005433680408	2807	Business	33000.00
0005432966605	2807	Business	33000.00
0005432966694	2807	Business	33000.00
0005432966675	2807	Business	33000.00
0005432222769	2807	Business	33000.00
0005433680412	2807	Business	33000.00
0005433680424	2807	Business	33000.00
0005432966696	2807	Business	33000.00
0005432966539	2807	Business	33000.00
0005433684413	2807	Business	33000.00
0005433680413	2807	Business	33000.00
0005432966507	2807	Economy	11000.00
0005433680393	2807	Economy	11000.00
0005432966663	2807	Economy	11000.00
0005433680422	2807	Economy	11000.00
0005433680436	2807	Economy	11000.00
0005433680420	2807	Economy	11000.00
0005433680441	2807	Economy	11000.00
0005432966701	2807	Economy	11000.00
0005433680431	2807	Economy	11000.00
0005433680394	2807	Economy	12100.00
0005432966670	2807	Economy	12100.00
0005432966588	2807	Economy	12100.00
0005433680417	2807	Economy	12100.00
0005432222765	2807	Economy	12100.00
0005432222766	2807	Economy	11000.00
0005432966591	2807	Economy	11000.00
0005433680427	2807	Economy	11000.00
0005432966668	2807	Economy	11000.00
0005432222767	2807	Economy	11000.00
0005433680438	2807	Economy	11000.00
0005433680428	2807	Economy	11000.00
0005432966679	2807	Economy	11000.00
0005433680429	2807	Economy	11000.00
0005432966695	2807	Economy	11000.00
0005432966657	2807	Economy	11000.00
0005433680405	2807	Economy	11000.00
0005432222768	2807	Economy	11000.00
0005432966660	2807	Economy	11000.00
0005432966677	2807	Economy	11000.00
0005432966607	2807	Economy	11000.00
0005433680399	2807	Economy	11000.00
0005433680423	2807	Economy	11000.00
0005433680433	2807	Economy	11000.00
0005432966554	2807	Economy	11000.00
0005433680439	2807	Economy	11000.00
0005433680416	2807	Economy	11000.00
0005432966642	2807	Economy	11000.00
0005433680418	2807	Economy	11000.00
0005433680409	2807	Economy	11000.00
0005433680421	2807	Economy	11000.00
0005433680419	2807	Economy	11000.00
0005433680411	2807	Economy	11000.00
0005433680437	2807	Economy	11000.00
0005433680398	2807	Economy	11000.00
0005432966658	2807	Economy	11000.00
0005433680396	2807	Economy	11000.00
0005433680432	2807	Economy	11000.00
0005433680415	2807	Economy	11000.00
0005433680403	2807	Economy	11000.00
0005432966693	2807	Economy	11000.00
0005433680397	2807	Economy	11000.00
0005433680426	2807	Economy	11000.00
0005432966664	2807	Economy	11000.00
0005433680435	2807	Economy	11000.00
0005432966659	2807	Economy	11000.00
0005433680395	2807	Economy	11000.00
0005433680434	2807	Economy	11000.00
0005433680410	2807	Economy	11000.00
0005433680401	2807	Economy	11000.00
0005432966529	2807	Economy	11000.00
0005432966669	2807	Economy	11000.00
0005432966645	2807	Economy	11000.00
0005432966574	2807	Economy	11000.00
0005432966700	2807	Economy	11000.00
0005433680404	2807	Economy	11000.00
0005432966582	2807	Economy	11000.00
0005433680402	2807	Economy	11000.00
0005433680407	2807	Economy	11000.00
0005432966581	2807	Economy	11000.00
0005432966540	2807	Economy	11000.00
0005433680414	2807	Economy	11000.00
0005432966678	2807	Economy	11000.00
0005433680400	2807	Economy	11000.00
0005432966702	2807	Economy	11000.00
0005432966768	2807	Economy	11000.00
0005433680430	2807	Economy	11000.00
0005433680440	2807	Economy	11000.00
0005433680425	2807	Economy	11000.00
0005433680406	2807	Economy	11000.00
0005433680010	29149	Business	33000.00
0005432966855	29149	Business	33000.00
0005433680051	29149	Business	33000.00
0005432966845	29149	Business	33000.00
0005433687680	29149	Business	33000.00
0005432966850	29149	Business	33000.00
0005432966861	29149	Business	33000.00
0005432966852	29149	Business	33000.00
0005433679996	29149	Economy	11000.00
0005433679968	29149	Economy	11000.00
0005433680021	29149	Economy	11000.00
0005432966869	29149	Economy	11000.00
0005432966868	29149	Economy	11000.00
0005432966860	29149	Economy	11000.00
0005433679954	29149	Economy	11000.00
0005432966859	29149	Economy	11000.00
0005433679997	29149	Economy	11000.00
0005432966867	29149	Economy	11000.00
0005433680131	29149	Economy	12100.00
0005433680029	29149	Economy	12100.00
0005432966848	29149	Economy	12100.00
0005432005204	29149	Economy	11000.00
0005433680064	29149	Economy	11000.00
0005433680121	29149	Economy	11000.00
0005433680145	29149	Economy	11000.00
0005433680087	29149	Economy	11000.00
0005433680030	29149	Economy	11000.00
0005432966849	29149	Economy	11000.00
0005432966853	29149	Economy	11000.00
0005433684391	29149	Economy	11000.00
0005432966865	29149	Economy	11000.00
0005432005203	29149	Economy	11000.00
0005433679951	29149	Economy	11000.00
0005433680123	29149	Economy	11000.00
0005432966846	29149	Economy	11000.00
0005433679964	29149	Economy	11000.00
0005433679999	29149	Economy	11000.00
0005433680050	29149	Economy	11000.00
0005433680022	29149	Economy	11000.00
0005432005206	29149	Economy	11000.00
0005433680012	29149	Economy	11000.00
0005433679994	29149	Economy	11000.00
0005433680086	29149	Economy	11000.00
0005433679948	29149	Economy	11000.00
0005432966851	29149	Economy	11000.00
0005433680147	29149	Economy	11000.00
0005433680111	29149	Economy	11000.00
0005433680260	29149	Economy	11000.00
0005433680096	29149	Economy	11000.00
0005433680009	29149	Economy	11000.00
0005433679972	29149	Economy	11000.00
0005433680130	29149	Economy	11000.00
0005433680097	29149	Economy	11000.00
0005433680168	29149	Economy	11000.00
0005433680218	29149	Economy	11000.00
0005433680144	29149	Economy	11000.00
0005433680190	29149	Economy	11000.00
0005433679995	29149	Economy	11000.00
0005432966870	29149	Economy	11000.00
0005433679947	29149	Economy	11000.00
0005433680122	29149	Economy	11000.00
0005433690906	29149	Economy	11000.00
0005432966847	29149	Economy	11000.00
0005433679971	29149	Economy	11000.00
0005433690903	29149	Economy	11000.00
0005432966866	29149	Economy	11000.00
0005433680167	29149	Economy	11000.00
0005432005205	29149	Economy	11000.00
0005433680112	29149	Economy	11000.00
0005432966864	29149	Economy	11000.00
0005433680011	29149	Economy	11000.00
0005433680194	29149	Economy	11000.00
0005433680124	29149	Economy	11000.00
0005433687688	29149	Economy	11000.00
0005433679910	29149	Economy	11000.00
0005433679998	29149	Economy	11000.00
0005432966856	29149	Economy	11000.00
0005432966858	29149	Economy	11000.00
0005433680201	29149	Economy	11000.00
0005432966863	29149	Economy	11000.00
0005433680184	29149	Economy	11000.00
0005432966862	29149	Economy	11000.00
0005432966854	29149	Economy	11000.00
0005432966857	29149	Economy	11000.00
0005433614362	9295	Business	132900.00
0005433614411	9295	Business	132900.00
0005433614379	9295	Business	132900.00
0005433614427	9295	Business	132900.00
0005433614430	9295	Business	132900.00
0005433614403	9295	Business	132900.00
0005434153523	9295	Business	132900.00
0005433614361	9295	Business	132900.00
0005433614423	9295	Business	132900.00
0005433633680	9295	Business	132900.00
0005433614425	9295	Business	132900.00
0005433614413	9295	Business	132900.00
0005433614409	9295	Business	132900.00
0005433614408	9295	Business	132900.00
0005434272165	9295	Business	132900.00
0005433614399	9295	Business	132900.00
0005433633679	9295	Business	132900.00
0005434152756	9295	Business	132900.00
0005433614366	9295	Business	132900.00
0005433633672	9295	Business	132900.00
0005433633677	9295	Business	132900.00
0005434163501	9295	Business	132900.00
0005432756836	9295	Business	132900.00
0005433633669	9295	Business	132900.00
0005433633675	9295	Business	132900.00
0005434163460	9295	Business	132900.00
0005433633701	9295	Economy	48700.00
0005434163531	9295	Economy	48700.00
0005433577759	9295	Economy	48700.00
0005433614378	9295	Economy	48700.00
0005433614432	9295	Economy	48700.00
0005433614400	9295	Economy	44300.00
0005433577761	9295	Economy	44300.00
0005433614394	9295	Economy	44300.00
0005433614404	9295	Economy	44300.00
0005433633700	9295	Economy	44300.00
0005433614429	9295	Economy	44300.00
0005433614415	9295	Economy	44300.00
0005433614407	9295	Economy	44300.00
0005433614368	9295	Economy	44300.00
0005433614375	9295	Economy	44300.00
0005433633678	9295	Economy	44300.00
0005434272175	9295	Economy	44300.00
0005433614385	9295	Economy	44300.00
0005433614414	9295	Economy	44300.00
0005433614386	9295	Economy	44300.00
0005433633686	9295	Economy	44300.00
0005434272174	9295	Economy	44300.00
0005433614380	9295	Economy	44300.00
0005434152764	9295	Economy	44300.00
0005433633667	9295	Economy	44300.00
0005433577764	9295	Economy	44300.00
0005433614422	9295	Economy	44300.00
0005433633683	9295	Economy	44300.00
0005433633694	9295	Economy	44300.00
0005433633695	9295	Economy	44300.00
0005433633699	9295	Economy	44300.00
0005433614391	9295	Economy	44300.00
0005433633689	9295	Economy	44300.00
0005433614424	9295	Economy	44300.00
0005433633696	9295	Economy	44300.00
0005433614401	9295	Economy	44300.00
0005433614384	9295	Economy	44300.00
0005432756838	9295	Economy	44300.00
0005433614360	9295	Economy	44300.00
0005433614398	9295	Economy	44300.00
0005433577762	9295	Economy	44300.00
0005434163458	9295	Economy	44300.00
0005433614359	9295	Economy	44300.00
0005433614383	9295	Economy	44300.00
0005433614433	9295	Economy	44300.00
0005433614393	9295	Economy	44300.00
0005433614390	9295	Economy	44300.00
0005433614406	9295	Economy	44300.00
0005433633671	9295	Economy	44300.00
0005433633685	9295	Economy	44300.00
0005433633668	9295	Economy	44300.00
0005433614363	9295	Economy	44300.00
0005432756837	9295	Economy	44300.00
0005433614374	9295	Economy	44300.00
0005433614381	9295	Economy	44300.00
0005433614412	9295	Economy	44300.00
0005433633687	9295	Economy	44300.00
0005433633692	9295	Economy	44300.00
0005433614392	9295	Economy	44300.00
0005433614410	9295	Economy	44300.00
0005433577767	9295	Economy	48700.00
0005433614417	9295	Economy	48700.00
0005433577758	9295	Economy	48700.00
0005433577756	9295	Economy	48700.00
0005433577766	9295	Economy	48700.00
0005432755064	9295	Economy	44300.00
0005433614426	9295	Economy	44300.00
0005433614370	9295	Economy	44300.00
0005433633670	9295	Economy	44300.00
0005433614402	9295	Economy	48700.00
0005432755065	9295	Economy	44300.00
0005433633674	9295	Economy	44300.00
0005434163500	9295	Economy	44300.00
0005434152763	9295	Economy	44300.00
0005433633688	9295	Economy	44300.00
0005433614365	9295	Economy	44300.00
0005433614387	9295	Economy	44300.00
0005433614421	9295	Economy	44300.00
0005433614372	9295	Economy	44300.00
0005434163535	9295	Economy	44300.00
0005433614405	9295	Economy	44300.00
0005433614419	9295	Economy	44300.00
0005433614382	9295	Economy	44300.00
0005434163502	9295	Economy	44300.00
0005433614420	9295	Economy	44300.00
0005433614395	9295	Economy	44300.00
0005432756835	9295	Economy	44300.00
0005433614396	9295	Economy	44300.00
0005433614369	9295	Economy	44300.00
0005433633697	9295	Economy	44300.00
0005433633673	9295	Economy	44300.00
0005433614397	9295	Economy	44300.00
0005433633681	9295	Economy	44300.00
0005434163522	9295	Economy	44300.00
0005433633690	9295	Economy	44300.00
0005434152757	9295	Economy	44300.00
0005433633691	9295	Economy	44300.00
0005433614373	9295	Economy	44300.00
0005433614364	9295	Economy	44300.00
0005433633684	9295	Economy	44300.00
0005433614389	9295	Economy	44300.00
0005433577757	9295	Economy	44300.00
0005433633698	9295	Economy	44300.00
0005433633693	9295	Economy	44300.00
0005433614418	9295	Economy	44300.00
0005433577763	9295	Economy	44300.00
0005433614371	9295	Economy	44300.00
0005433577768	9295	Economy	44300.00
0005434163546	9295	Economy	44300.00
0005433614428	9295	Economy	44300.00
0005433614367	9295	Economy	44300.00
0005433614416	9295	Economy	44300.00
0005434153516	9295	Economy	44300.00
0005434163525	9295	Economy	44300.00
0005434163474	9295	Economy	44300.00
0005433614377	9295	Economy	44300.00
0005433577760	9295	Economy	44300.00
0005433633682	9295	Economy	44300.00
0005434152767	9295	Economy	44300.00
0005434163495	9295	Economy	44300.00
0005433614388	9295	Economy	44300.00
0005434153519	9295	Economy	44300.00
0005434152766	9295	Economy	44300.00
0005433577765	9295	Economy	44300.00
0005432756839	9295	Economy	44300.00
0005433614431	9295	Economy	44300.00
0005434272172	9295	Economy	44300.00
0005434163545	9295	Economy	44300.00
0005433633676	9295	Economy	44300.00
0005433614376	9295	Economy	44300.00
0005433633345	25234	Business	132900.00
0005432751475	25234	Business	132900.00
0005433614024	25234	Business	132900.00
0005433613842	25234	Business	132900.00
0005432751480	25234	Business	132900.00
0005433577661	25234	Business	132900.00
0005433633287	25234	Business	132900.00
0005433613583	25234	Business	132900.00
0005433613911	25234	Business	132900.00
0005433633253	25234	Business	132900.00
0005433613838	25234	Business	132900.00
0005433613612	25234	Business	132900.00
0005432755017	25234	Business	132900.00
0005433577636	25234	Business	132900.00
0005432755016	25234	Business	132900.00
0005433613844	25234	Business	132900.00
0005432751474	25234	Business	132900.00
0005433613811	25234	Business	132900.00
0005433613802	25234	Business	132900.00
0005433613927	25234	Business	132900.00
0005432751476	25234	Business	132900.00
0005433613867	25234	Business	132900.00
0005433613977	25234	Business	132900.00
0005433613739	25234	Economy	48700.00
0005433613675	25234	Economy	48700.00
0005433633474	25234	Economy	48700.00
0005433613928	25234	Economy	48700.00
0005433633252	25234	Economy	48700.00
0005433613554	25234	Economy	44300.00
0005433613761	25234	Economy	44300.00
0005433633452	25234	Economy	44300.00
0005433633357	25234	Economy	44300.00
0005433613436	25234	Economy	44300.00
0005433633301	25234	Economy	44300.00
0005433633288	25234	Economy	44300.00
0005433613478	25234	Economy	44300.00
0005433613963	25234	Economy	44300.00
0005433613745	25234	Economy	44300.00
0005433633291	25234	Economy	44300.00
0005433614025	25234	Economy	44300.00
0005433613729	25234	Economy	44300.00
0005433633218	25234	Economy	44300.00
0005433633479	25234	Economy	44300.00
0005433633313	25234	Economy	44300.00
0005433613600	25234	Economy	44300.00
0005433613944	25234	Economy	44300.00
0005432751472	25234	Economy	44300.00
0005433633270	25234	Economy	44300.00
0005433577620	25234	Economy	44300.00
0005433577628	25234	Economy	44300.00
0005433613631	25234	Economy	44300.00
0005433633415	25234	Economy	44300.00
0005433613935	25234	Economy	44300.00
0005433613934	25234	Economy	44300.00
0005433613812	25234	Economy	44300.00
0005433613544	25234	Economy	44300.00
0005433613805	25234	Economy	44300.00
0005433633473	25234	Economy	44300.00
0005433613728	25234	Economy	44300.00
0005432751493	25234	Economy	44300.00
0005433613969	25234	Economy	44300.00
0005433613571	25234	Economy	44300.00
0005433613785	25234	Economy	44300.00
0005433577675	25234	Economy	44300.00
0005433613758	25234	Economy	44300.00
0005433613589	25234	Economy	44300.00
0005433613764	25234	Economy	44300.00
0005433633347	25234	Economy	44300.00
0005433613978	25234	Economy	44300.00
0005433613661	25234	Economy	44300.00
0005433613813	25234	Economy	44300.00
0005432751471	25234	Economy	44300.00
0005433613801	25234	Economy	44300.00
0005433613870	25234	Economy	44300.00
0005432751479	25234	Economy	44300.00
0005432751470	25234	Economy	44300.00
0005433577634	25234	Economy	44300.00
0005433614020	25234	Economy	44300.00
0005433633510	25234	Economy	44300.00
0005433577676	25234	Economy	44300.00
0005432751482	25234	Economy	44300.00
0005432755030	25234	Economy	48700.00
0005433613837	25234	Economy	48700.00
0005433613845	25234	Economy	48700.00
0005433613810	25234	Economy	48700.00
0005433633324	25234	Economy	44300.00
0005433577666	25234	Economy	48700.00
0005433613831	25234	Economy	44300.00
0005433633342	25234	Economy	44300.00
0005433613820	25234	Economy	44300.00
0005433614098	25234	Economy	48700.00
0005433613828	25234	Economy	44300.00
0005433633396	25234	Economy	44300.00
0005433614026	25234	Economy	44300.00
0005432755020	25234	Economy	44300.00
0005433613936	25234	Economy	44300.00
0005433613570	25234	Economy	44300.00
0005433633219	25234	Economy	44300.00
0005432751477	25234	Economy	44300.00
0005433577662	25234	Economy	44300.00
0005433613889	25234	Economy	44300.00
0005433633480	25234	Economy	44300.00
0005433613738	25234	Economy	44300.00
0005433633346	25234	Economy	44300.00
0005433613611	25234	Economy	44300.00
0005433614033	25234	Economy	44300.00
0005433613599	25234	Economy	44300.00
0005433614134	25234	Economy	44300.00
0005433613526	25234	Economy	44300.00
0005433633374	25234	Economy	44300.00
0005433614133	25234	Economy	44300.00
0005433613671	25234	Economy	44300.00
0005433613839	25234	Economy	44300.00
0005433613962	25234	Economy	44300.00
0005433613410	25234	Economy	44300.00
0005433613868	25234	Economy	44300.00
0005432755023	25234	Economy	44300.00
0005433633444	25234	Economy	44300.00
0005432755024	25234	Economy	44300.00
0005433577691	25234	Economy	44300.00
0005433633413	25234	Economy	44300.00
0005433577619	25234	Economy	44300.00
0005433613674	25234	Economy	44300.00
0005433633269	25234	Economy	44300.00
0005433577642	25234	Economy	44300.00
0005432755025	25234	Economy	44300.00
0005433613467	25234	Economy	44300.00
0005433613879	25234	Economy	44300.00
0005433577654	25234	Economy	44300.00
0005433614032	25234	Economy	44300.00
0005433577645	25234	Economy	44300.00
0005433613668	25234	Economy	44300.00
0005433633414	25234	Economy	44300.00
0005433613590	25234	Economy	44300.00
0005433613632	25234	Economy	44300.00
0005433613740	25234	Economy	44300.00
0005433613878	25234	Economy	44300.00
0005433613818	25234	Economy	44300.00
0005433613616	25234	Economy	44300.00
0005432751473	25234	Economy	44300.00
0005433613886	25234	Economy	44300.00
0005433633344	25234	Economy	44300.00
0005433613617	25234	Economy	44300.00
0005433633312	25234	Economy	44300.00
0005433633455	25234	Economy	44300.00
0005433613926	25234	Economy	44300.00
0005433613691	25234	Economy	44300.00
0005433614097	25234	Economy	44300.00
0005433613743	25234	Economy	44300.00
0005435856163	4206	Business	193100.00
0005435947126	4206	Business	193100.00
0005432184941	4206	Business	193100.00
0005435947110	4206	Business	193100.00
0005435947108	4206	Economy	70800.00
0005435856149	4206	Economy	70800.00
0005435856155	4206	Economy	64400.00
0005435856157	4206	Economy	64400.00
0005435856168	4206	Economy	64400.00
0005435947077	4206	Economy	64400.00
0005435856135	4206	Economy	64400.00
0005435947027	4206	Economy	64400.00
0005435947090	4206	Economy	64400.00
0005435947079	4206	Economy	64400.00
0005432571278	4206	Economy	64400.00
0005435947109	4206	Economy	70800.00
0005435947111	4206	Economy	64400.00
0005435856156	4206	Economy	64400.00
0005435947067	4206	Economy	64400.00
0005432184942	4206	Economy	64400.00
0005435854047	4206	Economy	64400.00
0005435947043	4206	Economy	64400.00
0005435947060	4206	Economy	64400.00
0005435947073	4206	Economy	64400.00
0005435947127	4206	Economy	64400.00
0005435856132	4206	Economy	64400.00
0005435947066	4206	Economy	64400.00
0005435856164	4206	Economy	64400.00
0005435856160	4206	Economy	64400.00
0005435947104	4206	Economy	64400.00
0005435947061	4206	Economy	64400.00
0005435856165	4206	Economy	64400.00
0005435947212	26573	Business	193100.00
0005435986671	26573	Business	193100.00
0005435947208	26573	Economy	64400.00
0005435947207	26573	Economy	64400.00
0005435947209	26573	Economy	64400.00
0005435787349	26573	Economy	64400.00
0005432571313	26573	Economy	64400.00
0005435947206	26573	Economy	64400.00
0005435947215	26573	Economy	64400.00
0005435947211	26573	Economy	64400.00
0005435856191	26573	Economy	64400.00
0005435947216	26573	Economy	64400.00
0005435856192	26573	Economy	64400.00
0005432571314	26573	Economy	64400.00
0005435986677	26573	Economy	64400.00
0005435856190	26573	Economy	64400.00
0005432571312	26573	Economy	64400.00
0005435947210	26573	Economy	64400.00
0005432571315	26573	Economy	64400.00
0005435947217	26573	Economy	64400.00
0005435947214	26573	Economy	64400.00
0005435986673	26573	Economy	64400.00
0005435947213	26573	Economy	64400.00
0005435947219	26573	Economy	64400.00
0005435947205	26573	Economy	64400.00
0005435947218	26573	Economy	64400.00
0005435856193	26573	Economy	64400.00
0005433568878	321	Business	21500.00
0005433568927	321	Business	21500.00
0005433568917	321	Business	21500.00
0005433568891	321	Business	21500.00
0005433568898	321	Business	21500.00
0005432948065	321	Business	21500.00
0005433074385	321	Business	21500.00
0005433568873	321	Business	21500.00
0005433568935	321	Business	21500.00
0005433568902	321	Business	21500.00
0005433074346	321	Business	21500.00
0005432947987	321	Business	21500.00
0005433074520	321	Business	21500.00
0005433568928	321	Business	21500.00
0005433074419	321	Business	21500.00
0005433568931	321	Business	21500.00
0005432948084	321	Business	21500.00
0005432947943	321	Business	21500.00
0005432947893	321	Business	21500.00
0005433129229	321	Business	21500.00
0005433568895	321	Business	21500.00
0005433568922	321	Business	21500.00
0005433568942	321	Business	21500.00
0005432947792	321	Business	21500.00
0005432947837	321	Business	21500.00
0005433568894	321	Business	21500.00
0005433568945	321	Business	21500.00
0005433074259	321	Business	21500.00
0005433074423	321	Economy	7900.00
0005432238922	321	Economy	7900.00
0005433568884	321	Economy	7900.00
0005432238916	321	Economy	7900.00
0005433568937	321	Economy	7900.00
0005433568883	321	Economy	7900.00
0005433568924	321	Economy	7200.00
0005433568932	321	Economy	7200.00
0005433568916	321	Economy	7200.00
0005433568905	321	Economy	7200.00
0005432948060	321	Economy	7200.00
0005432947927	321	Economy	7200.00
0005433568874	321	Economy	7200.00
0005432238918	321	Economy	7200.00
0005433074418	321	Economy	7200.00
0005433568881	321	Economy	7200.00
0005433074490	321	Economy	7200.00
0005433568869	321	Economy	7200.00
0005433568896	321	Economy	7200.00
0005433134079	321	Economy	7200.00
0005433568900	321	Economy	7200.00
0005432947789	321	Economy	7200.00
0005433074339	321	Economy	7200.00
0005433074521	321	Economy	7200.00
0005432238919	321	Economy	7200.00
0005433568879	321	Economy	7200.00
0005433568936	321	Economy	7200.00
0005432948064	321	Economy	7200.00
0005432948119	321	Economy	7200.00
0005433568930	321	Economy	7200.00
0005433568908	321	Economy	7200.00
0005433568877	321	Economy	7200.00
0005433129233	321	Economy	7200.00
0005433568910	321	Economy	7200.00
0005432238920	321	Economy	7200.00
0005432238921	321	Economy	7200.00
0005432948059	321	Economy	7200.00
0005432947980	321	Economy	7200.00
0005433568926	321	Economy	7200.00
0005433568872	321	Economy	7200.00
0005433568920	321	Economy	7200.00
0005433568892	321	Economy	7200.00
0005433568933	321	Economy	7200.00
0005433129232	321	Economy	7200.00
0005433568912	321	Economy	7200.00
0005433568875	321	Economy	7200.00
0005433568921	321	Economy	7200.00
0005432947847	321	Economy	7200.00
0005433568888	321	Economy	7200.00
0005433568904	321	Economy	7200.00
0005433568903	321	Economy	7200.00
0005433568887	321	Economy	7200.00
0005433568934	321	Economy	7200.00
0005433568897	321	Economy	7200.00
0005433074424	321	Economy	7200.00
0005433568939	321	Economy	7200.00
0005432947846	321	Economy	7200.00
0005433074235	321	Economy	7900.00
0005432947920	321	Economy	7900.00
0005433568940	321	Economy	7900.00
0005432947926	321	Economy	7900.00
0005432948014	321	Economy	7200.00
0005432948039	321	Economy	7200.00
0005433568870	321	Economy	7200.00
0005432238917	321	Economy	7900.00
0005433074422	321	Economy	7200.00
0005432947788	321	Economy	7200.00
0005432948013	321	Economy	7200.00
0005433134081	321	Economy	7200.00
0005433568880	321	Economy	7200.00
0005433568893	321	Economy	7200.00
0005433568889	321	Economy	7200.00
0005433074437	321	Economy	7200.00
0005433568923	321	Economy	7200.00
0005433129219	321	Economy	7200.00
0005433568886	321	Economy	7200.00
0005433568907	321	Economy	7200.00
0005433568943	321	Economy	7200.00
0005433568941	321	Economy	7200.00
0005433074436	321	Economy	7200.00
0005433074425	321	Economy	7200.00
0005433074258	321	Economy	7200.00
0005433568906	321	Economy	7200.00
0005433074290	321	Economy	7200.00
0005433568899	321	Economy	7200.00
0005433074347	321	Economy	7200.00
0005432947981	321	Economy	7200.00
0005433568919	321	Economy	7200.00
0005433568918	321	Economy	7200.00
0005433568909	321	Economy	7200.00
0005433074397	321	Economy	7200.00
0005433568913	321	Economy	7200.00
0005433568929	321	Economy	7200.00
0005432947986	321	Economy	7200.00
0005433568914	321	Economy	7200.00
0005433074375	321	Economy	7200.00
0005433074247	321	Economy	7200.00
0005433074276	321	Economy	7200.00
0005433568938	321	Economy	7200.00
0005433568925	321	Economy	7200.00
0005433129202	321	Economy	7200.00
0005432238915	321	Economy	7200.00
0005433074443	321	Economy	7200.00
0005432947908	321	Economy	7200.00
0005433568890	321	Economy	7200.00
0005433074321	321	Economy	7200.00
0005433568944	321	Economy	7200.00
0005433568871	321	Economy	7200.00
0005433134070	321	Economy	7200.00
0005433568901	321	Economy	7200.00
0005433568915	321	Economy	7200.00
0005433568911	321	Economy	7200.00
0005432947907	321	Economy	7200.00
0005433074444	321	Economy	7200.00
0005433568876	321	Economy	7200.00
0005433568885	321	Economy	7200.00
0005432947978	321	Economy	7200.00
0005432947985	321	Economy	7200.00
0005433568882	321	Economy	7200.00
0005433568360	11580	Business	21500.00
0005433568261	11580	Business	21500.00
0005433568314	11580	Business	21500.00
0005433568202	11580	Business	21500.00
0005432948318	11580	Business	21500.00
0005432948311	11580	Business	21500.00
0005433568250	11580	Business	21500.00
0005433074618	11580	Business	21500.00
0005432948314	11580	Business	21500.00
0005433074617	11580	Business	21500.00
0005432192310	11580	Business	21500.00
0005433568143	11580	Business	21500.00
0005433568284	11580	Business	21500.00
0005433568304	11580	Business	21500.00
0005433568035	11580	Business	21500.00
0005432948322	11580	Business	21500.00
0005433568294	11580	Business	21500.00
0005433568197	11580	Business	21500.00
0005433568270	11580	Business	21500.00
0005433568109	11580	Business	21500.00
0005433074622	11580	Business	21500.00
0005433074620	11580	Business	21500.00
0005433568252	11580	Business	21500.00
0005433074615	11580	Economy	7900.00
0005433568126	11580	Economy	7900.00
0005432948325	11580	Economy	7900.00
0005433568196	11580	Economy	7900.00
0005433074609	11580	Economy	7900.00
0005433074632	11580	Economy	7200.00
0005432948334	11580	Economy	7200.00
0005433074629	11580	Economy	7200.00
0005433074623	11580	Economy	7200.00
0005433074619	11580	Economy	7200.00
0005432948339	11580	Economy	7200.00
0005433568195	11580	Economy	7200.00
0005433568355	11580	Economy	7200.00
0005433568312	11580	Economy	7200.00
0005432948327	11580	Economy	7200.00
0005433568251	11580	Economy	7200.00
0005432948343	11580	Economy	7200.00
0005433568358	11580	Economy	7200.00
0005433074608	11580	Economy	7200.00
0005433074613	11580	Economy	7200.00
0005433568130	11580	Economy	7200.00
0005432948321	11580	Economy	7200.00
0005433074624	11580	Economy	7200.00
0005432948313	11580	Economy	7200.00
0005433074611	11580	Economy	7200.00
0005433568240	11580	Economy	7200.00
0005432948330	11580	Economy	7200.00
0005432948326	11580	Economy	7200.00
0005433568230	11580	Economy	7200.00
0005433074605	11580	Economy	7200.00
0005432948338	11580	Economy	7200.00
0005432948333	11580	Economy	7200.00
0005433568237	11580	Economy	7200.00
0005433568020	11580	Economy	7200.00
0005432948324	11580	Economy	7200.00
0005433074612	11580	Economy	7200.00
0005433568201	11580	Economy	7200.00
0005433568200	11580	Economy	7200.00
0005433568231	11580	Economy	7200.00
0005433131693	11580	Economy	7200.00
0005433568211	11580	Economy	7200.00
0005433074626	11580	Economy	7200.00
0005433568361	11580	Economy	7200.00
0005433568249	11580	Economy	7200.00
0005433074607	11580	Economy	7200.00
0005433568342	11580	Economy	7200.00
0005433131695	11580	Economy	7200.00
0005433131694	11580	Economy	7200.00
0005433568287	11580	Economy	7200.00
0005432948329	11580	Economy	7200.00
0005433074630	11580	Economy	7200.00
0005433568286	11580	Economy	7200.00
0005433568296	11580	Economy	7200.00
0005433568295	11580	Economy	7200.00
0005433568093	11580	Economy	7200.00
0005433568305	11580	Economy	7200.00
0005433568122	11580	Economy	7200.00
0005432948346	11580	Economy	7200.00
0005433131692	11580	Economy	7200.00
0005432948340	11580	Economy	7200.00
0005433568289	11580	Economy	7900.00
0005433074625	11580	Economy	7900.00
0005432948344	11580	Economy	7900.00
0005432948306	11580	Economy	7900.00
0005433568348	11580	Economy	7200.00
0005433074631	11580	Economy	7200.00
0005433568288	11580	Economy	7200.00
0005433568131	11580	Economy	7200.00
0005432948335	11580	Economy	7200.00
0005433568205	11580	Economy	7200.00
0005432192311	11580	Economy	7200.00
0005432948342	11580	Economy	7200.00
0005432948328	11580	Economy	7200.00
0005432948312	11580	Economy	7200.00
0005432948323	11580	Economy	7200.00
0005432948309	11580	Economy	7200.00
0005432948316	11580	Economy	7200.00
0005432948308	11580	Economy	7200.00
0005432948315	11580	Economy	7200.00
0005433568259	11580	Economy	7200.00
0005433568091	11580	Economy	7200.00
0005433568341	11580	Economy	7200.00
0005433074627	11580	Economy	7200.00
0005433568123	11580	Economy	7200.00
0005433568293	11580	Economy	7200.00
0005433074616	11580	Economy	7200.00
0005433568280	11580	Economy	7200.00
0005433074621	11580	Economy	7200.00
0005433568260	11580	Economy	7200.00
0005432948320	11580	Economy	7200.00
0005433134124	11580	Economy	7200.00
0005433074633	11580	Economy	7200.00
0005432948319	11580	Economy	7200.00
0005433134125	11580	Economy	7200.00
0005433074606	11580	Economy	7200.00
0005433134123	11580	Economy	7200.00
0005433568210	11580	Economy	7200.00
0005433568165	11580	Economy	7200.00
0005432948305	11580	Economy	7200.00
0005433568283	11580	Economy	7200.00
0005433074610	11580	Economy	7200.00
0005432948341	11580	Economy	7200.00
0005432948336	11580	Economy	7200.00
0005432948337	11580	Economy	7200.00
0005433568142	11580	Economy	7200.00
0005432948307	11580	Economy	7200.00
0005433568074	11580	Economy	7200.00
0005433568313	11580	Economy	7200.00
0005433568075	11580	Economy	7200.00
0005433568110	11580	Economy	7200.00
0005433074614	11580	Economy	7200.00
0005433568236	11580	Economy	7200.00
0005432948331	11580	Economy	7200.00
0005433074628	11580	Economy	7200.00
0005433134122	11580	Economy	7200.00
0005433568092	11580	Economy	7200.00
0005432948332	11580	Economy	7200.00
0005433568199	11580	Economy	7200.00
0005433568036	11580	Economy	7200.00
0005432948345	11580	Economy	7200.00
0005432948310	11580	Economy	7200.00
0005433568056	11580	Economy	7200.00
0005433568285	11580	Economy	7200.00
0005432948317	11580	Economy	7200.00
0005433817458	10040	Economy	6300.00
0005434732937	10040	Economy	6300.00
0005434732938	10040	Economy	6300.00
0005433817459	10040	Economy	6300.00
0005434732941	10040	Economy	6300.00
0005433817460	10040	Economy	6300.00
0005434732936	10040	Economy	6300.00
0005434732921	10040	Economy	6300.00
0005434732950	10040	Economy	6300.00
0005434732946	10040	Economy	6300.00
0005434732969	13964	Economy	6300.00
0005434732971	13964	Economy	6300.00
0005433817433	13964	Economy	6300.00
0005434732972	13964	Economy	6300.00
0005433817434	13964	Economy	6300.00
0005433817414	13964	Economy	6300.00
0005433817435	13964	Economy	6300.00
0005434732970	13964	Economy	6300.00
0005432984664	2349	Business	184500.00
0005433434323	2349	Business	184500.00
0005433754042	2349	Business	184500.00
0005432984719	2349	Business	184500.00
0005433434274	2349	Business	184500.00
0005432655498	2349	Business	184500.00
0005435982148	2349	Business	184500.00
0005432984745	2349	Business	184500.00
0005433434337	2349	Business	184500.00
0005433754072	2349	Business	184500.00
0005434731127	2349	Business	184500.00
0005433434368	2349	Business	184500.00
0005433434248	2349	Business	184500.00
0005432869462	2349	Business	184500.00
0005433434324	2349	Business	184500.00
0005433754038	2349	Business	184500.00
0005433754065	2349	Business	184500.00
0005433754052	2349	Business	184500.00
0005435982183	2349	Business	184500.00
0005433434273	2349	Business	184500.00
0005432300249	2349	Business	184500.00
0005433754067	2349	Business	184500.00
0005432655505	2349	Business	184500.00
0005433754081	2349	Business	184500.00
0005433754074	2349	Business	184500.00
0005433754053	2349	Business	184500.00
0005433766628	2349	Economy	67700.00
0005432984717	2349	Economy	67700.00
0005432226037	2349	Economy	67700.00
0005435982147	2349	Economy	67700.00
0005433754040	2349	Economy	61500.00
0005433434212	2349	Economy	61500.00
0005433754064	2349	Economy	61500.00
0005433754037	2349	Economy	61500.00
0005433754071	2349	Economy	61500.00
0005433754062	2349	Economy	61500.00
0005434731138	2349	Economy	61500.00
0005432655507	2349	Economy	61500.00
0005435982172	2349	Economy	61500.00
0005435982157	2349	Economy	61500.00
0005434731118	2349	Economy	61500.00
0005433754082	2349	Economy	61500.00
0005435982193	2349	Economy	61500.00
0005434731107	2349	Economy	61500.00
0005433434400	2349	Economy	61500.00
0005433764674	2349	Economy	61500.00
0005435982180	2349	Economy	61500.00
0005433434303	2349	Economy	61500.00
0005432984665	2349	Economy	61500.00
0005432655504	2349	Economy	61500.00
0005433434343	2349	Economy	61500.00
0005435982141	2349	Economy	61500.00
0005433754051	2349	Economy	61500.00
0005435982154	2349	Economy	61500.00
0005433754041	2349	Economy	61500.00
0005435982174	2349	Economy	61500.00
0005432226036	2349	Economy	61500.00
0005433434304	2349	Economy	61500.00
0005433754073	2349	Economy	61500.00
0005432984736	2349	Economy	61500.00
0005432226038	2349	Economy	61500.00
0005435982150	2349	Economy	61500.00
0005433754054	2349	Economy	61500.00
0005432226040	2349	Economy	61500.00
0005433754055	2349	Economy	61500.00
0005433754028	2349	Economy	61500.00
0005434731126	2349	Economy	61500.00
0005435982195	2349	Economy	61500.00
0005435982169	2349	Economy	61500.00
0005432984666	2349	Economy	61500.00
0005432226035	2349	Economy	61500.00
0005432300247	2349	Economy	61500.00
0005432655502	2349	Economy	61500.00
0005432984574	2349	Economy	61500.00
0005435982143	2349	Economy	61500.00
0005435982151	2349	Economy	61500.00
0005435982166	2349	Economy	61500.00
0005435982189	2349	Economy	61500.00
0005432984706	2349	Economy	61500.00
0005432984731	2349	Economy	61500.00
0005433754076	2349	Economy	61500.00
0005433766630	2349	Economy	61500.00
0005432984519	2349	Economy	61500.00
0005432869463	2349	Economy	61500.00
0005433754080	2349	Economy	61500.00
0005433754033	2349	Economy	61500.00
0005433754039	2349	Economy	61500.00
0005432984718	2349	Economy	61500.00
0005435982191	2349	Economy	61500.00
0005433754043	2349	Economy	61500.00
0005435982173	2349	Economy	61500.00
0005432984648	2349	Economy	61500.00
0005432869426	2349	Economy	61500.00
0005433434342	2349	Economy	61500.00
0005432226041	2349	Economy	61500.00
0005433434451	2349	Economy	61500.00
0005433754061	2349	Economy	61500.00
0005433434334	2349	Economy	61500.00
0005433754083	2349	Economy	61500.00
0005432869448	2349	Economy	61500.00
0005433434399	2349	Economy	61500.00
0005432984651	2349	Economy	61500.00
0005433754079	2349	Economy	61500.00
0005432984691	2349	Economy	61500.00
0005435982187	2349	Economy	61500.00
0005435982163	2349	Economy	61500.00
0005435982175	2349	Economy	61500.00
0005433754036	2349	Economy	61500.00
0005432300245	2349	Economy	61500.00
0005433754050	2349	Economy	61500.00
0005433754068	2349	Economy	61500.00
0005432869452	2349	Economy	61500.00
0005432655508	2349	Economy	61500.00
0005433754048	2349	Economy	61500.00
0005435982167	2349	Economy	61500.00
0005432300248	2349	Economy	61500.00
0005433754075	2349	Economy	61500.00
0005435982153	2349	Economy	61500.00
0005432984634	2349	Economy	61500.00
0005432984772	2349	Economy	61500.00
0005433754031	2349	Economy	61500.00
0005432984694	2349	Economy	61500.00
0005434731125	2349	Economy	61500.00
0005435982178	2349	Economy	61500.00
0005433754070	2349	Economy	61500.00
0005432984789	2349	Economy	67700.00
0005435982190	2349	Economy	61500.00
0005433754060	2349	Economy	67700.00
0005432984707	2349	Economy	61500.00
0005435982192	2349	Economy	61500.00
0005435982156	2349	Economy	67700.00
0005433434369	2349	Economy	61500.00
0005435982159	2349	Economy	61500.00
0005433754032	2349	Economy	61500.00
0005432869447	2349	Economy	61500.00
0005435982158	2349	Economy	61500.00
0005432984690	2349	Economy	61500.00
0005435982171	2349	Economy	61500.00
0005433754056	2349	Economy	61500.00
0005433754078	2349	Economy	61500.00
0005435982142	2349	Economy	61500.00
0005433766629	2349	Economy	61500.00
0005433754063	2349	Economy	61500.00
0005435982165	2349	Economy	61500.00
0005433754029	2349	Economy	61500.00
0005432655506	2349	Economy	61500.00
0005435982194	2349	Economy	61500.00
0005433434388	2349	Economy	61500.00
0005435982161	2349	Economy	61500.00
0005435982186	2349	Economy	61500.00
0005433754077	2349	Economy	61500.00
0005435982146	2349	Economy	61500.00
0005433754034	2349	Economy	61500.00
0005433754049	2349	Economy	61500.00
0005435982149	2349	Economy	61500.00
0005435982184	2349	Economy	61500.00
0005435982162	2349	Economy	61500.00
0005432655500	2349	Economy	61500.00
0005433754035	2349	Economy	61500.00
0005432984729	2349	Economy	61500.00
0005433754059	2349	Economy	61500.00
0005432984698	2349	Economy	61500.00
0005432984728	2349	Economy	61500.00
0005432984621	2349	Economy	61500.00
0005435982168	2349	Economy	61500.00
0005435982176	2349	Economy	61500.00
0005435982145	2349	Economy	61500.00
0005433754066	2349	Economy	61500.00
0005435982188	2349	Economy	61500.00
0005433754045	2349	Economy	61500.00
0005433754058	2349	Economy	61500.00
0005432984824	2349	Economy	61500.00
0005432226039	2349	Economy	61500.00
0005433754030	2349	Economy	61500.00
0005432300246	2349	Economy	61500.00
0005435982182	2349	Economy	61500.00
0005435982160	2349	Economy	61500.00
0005435982164	2349	Economy	61500.00
0005433754044	2349	Economy	61500.00
0005433754057	2349	Economy	61500.00
0005433434345	2349	Economy	61500.00
0005433754047	2349	Economy	61500.00
0005435982144	2349	Economy	61500.00
0005433434349	2349	Economy	61500.00
0005435982170	2349	Economy	61500.00
0005432984689	2349	Economy	61500.00
0005432655497	2349	Economy	61500.00
0005433754027	2349	Economy	61500.00
0005432300244	2349	Economy	61500.00
0005433434401	2349	Economy	61500.00
0005432869461	2349	Economy	61500.00
0005435982177	2349	Economy	61500.00
0005433434389	2349	Economy	61500.00
0005433754046	2349	Economy	61500.00
0005435982155	2349	Economy	61500.00
0005432655503	2349	Economy	61500.00
0005434731122	2349	Economy	61500.00
0005432655501	2349	Economy	61500.00
0005435982181	2349	Economy	61500.00
0005435982152	2349	Economy	61500.00
0005435982185	2349	Economy	61500.00
0005432984692	2349	Economy	61500.00
0005433754069	2349	Economy	61500.00
0005432655499	2349	Economy	61500.00
0005435982179	2349	Economy	61500.00
0005435981795	26200	Business	184500.00
0005433434610	26200	Business	184500.00
0005432984979	26200	Business	184500.00
0005433766614	26200	Business	184500.00
0005433434590	26200	Business	184500.00
0005432984992	26200	Business	184500.00
0005435981852	26200	Business	184500.00
0005432051118	26200	Business	184500.00
0005433753292	26200	Business	184500.00
0005435981804	26200	Business	184500.00
0005433434592	26200	Business	184500.00
0005435981836	26200	Business	184500.00
0005432655381	26200	Business	184500.00
0005432984991	26200	Business	184500.00
0005432869500	26200	Business	184500.00
0005433764654	26200	Business	184500.00
0005435981851	26200	Business	184500.00
0005433753642	26200	Business	184500.00
0005432869502	26200	Business	184500.00
0005433434595	26200	Business	184500.00
0005432984985	26200	Business	184500.00
0005433764666	26200	Business	184500.00
0005433434606	26200	Business	184500.00
0005432984997	26200	Business	184500.00
0005432984972	26200	Business	184500.00
0005433753359	26200	Business	184500.00
0005432869499	26200	Business	184500.00
0005433753575	26200	Business	184500.00
0005432984966	26200	Business	184500.00
0005435981775	26200	Economy	67700.00
0005432049453	26200	Economy	67700.00
0005434731158	26200	Economy	67700.00
0005433753577	26200	Economy	61500.00
0005433753893	26200	Economy	61500.00
0005433753866	26200	Economy	61500.00
0005435981702	26200	Economy	61500.00
0005435981776	26200	Economy	61500.00
0005433753353	26200	Economy	61500.00
0005433434593	26200	Economy	61500.00
0005433753476	26200	Economy	61500.00
0005432984976	26200	Economy	61500.00
0005433434608	26200	Economy	61500.00
0005433753291	26200	Economy	61500.00
0005433753452	26200	Economy	61500.00
0005433753362	26200	Economy	61500.00
0005433434602	26200	Economy	61500.00
0005432984996	26200	Economy	61500.00
0005433753576	26200	Economy	61500.00
0005433753559	26200	Economy	61500.00
0005433753700	26200	Economy	61500.00
0005433753504	26200	Economy	61500.00
0005432869501	26200	Economy	61500.00
0005433753413	26200	Economy	61500.00
0005435981880	26200	Economy	61500.00
0005433434583	26200	Economy	61500.00
0005435981805	26200	Economy	61500.00
0005433753641	26200	Economy	61500.00
0005434731160	26200	Economy	61500.00
0005433753633	26200	Economy	61500.00
0005435981770	26200	Economy	61500.00
0005433753608	26200	Economy	61500.00
0005432984971	26200	Economy	61500.00
0005435981911	26200	Economy	61500.00
0005435981682	26200	Economy	61500.00
0005435981796	26200	Economy	61500.00
0005433753377	26200	Economy	61500.00
0005432984990	26200	Economy	61500.00
0005433753423	26200	Economy	61500.00
0005433753435	26200	Economy	61500.00
0005433434594	26200	Economy	61500.00
0005433753352	26200	Economy	61500.00
0005432984975	26200	Economy	61500.00
0005433434584	26200	Economy	61500.00
0005432984984	26200	Economy	61500.00
0005433753477	26200	Economy	61500.00
0005433434589	26200	Economy	61500.00
0005433764663	26200	Economy	61500.00
0005435981633	26200	Economy	61500.00
0005433434604	26200	Economy	61500.00
0005433753865	26200	Economy	61500.00
0005433766602	26200	Economy	61500.00
0005435981902	26200	Economy	61500.00
0005435981634	26200	Economy	61500.00
0005433753628	26200	Economy	61500.00
0005433434586	26200	Economy	61500.00
0005432984973	26200	Economy	61500.00
0005433753376	26200	Economy	61500.00
0005433434599	26200	Economy	61500.00
0005435981643	26200	Economy	61500.00
0005434731157	26200	Economy	61500.00
0005432984969	26200	Economy	61500.00
0005432869504	26200	Economy	61500.00
0005435981764	26200	Economy	61500.00
0005433753471	26200	Economy	61500.00
0005432869506	26200	Economy	61500.00
0005432984974	26200	Economy	61500.00
0005433434600	26200	Economy	61500.00
0005432984968	26200	Economy	61500.00
0005433753627	26200	Economy	61500.00
0005435981737	26200	Economy	61500.00
0005433753730	26200	Economy	61500.00
0005433753699	26200	Economy	61500.00
0005433766593	26200	Economy	61500.00
0005433753688	26200	Economy	61500.00
0005432984987	26200	Economy	61500.00
0005432984989	26200	Economy	61500.00
0005433434611	26200	Economy	61500.00
0005432655374	26200	Economy	61500.00
0005433434587	26200	Economy	61500.00
0005432655395	26200	Economy	61500.00
0005433753610	26200	Economy	61500.00
0005432869503	26200	Economy	61500.00
0005433753626	26200	Economy	61500.00
0005435981644	26200	Economy	61500.00
0005432049451	26200	Economy	61500.00
0005433434596	26200	Economy	61500.00
0005432984995	26200	Economy	61500.00
0005432051120	26200	Economy	61500.00
0005433753607	26200	Economy	67700.00
0005433753485	26200	Economy	61500.00
0005433753361	26200	Economy	61500.00
0005432655355	26200	Economy	67700.00
0005435981624	26200	Economy	61500.00
0005433753360	26200	Economy	61500.00
0005432984967	26200	Economy	67700.00
0005433434603	26200	Economy	67700.00
0005432049454	26200	Economy	61500.00
0005433753541	26200	Economy	61500.00
0005432984978	26200	Economy	61500.00
0005433766618	26200	Economy	61500.00
0005432049455	26200	Economy	61500.00
0005433754011	26200	Economy	61500.00
0005432655379	26200	Economy	61500.00
0005435981897	26200	Economy	61500.00
0005432984981	26200	Economy	61500.00
0005433753422	26200	Economy	61500.00
0005433434605	26200	Economy	61500.00
0005433434585	26200	Economy	61500.00
0005432984977	26200	Economy	61500.00
0005432984965	26200	Economy	61500.00
0005434731156	26200	Economy	61500.00
0005435981722	26200	Economy	61500.00
0005433753581	26200	Economy	61500.00
0005432984986	26200	Economy	61500.00
0005432984983	26200	Economy	61500.00
0005432984970	26200	Economy	61500.00
0005432984993	26200	Economy	61500.00
0005433764665	26200	Economy	61500.00
0005435981828	26200	Economy	61500.00
0005433753550	26200	Economy	61500.00
0005432984988	26200	Economy	61500.00
0005433753588	26200	Economy	61500.00
0005435981769	26200	Economy	61500.00
0005433753436	26200	Economy	61500.00
0005435981766	26200	Economy	61500.00
0005432984994	26200	Economy	61500.00
0005435981748	26200	Economy	61500.00
0005433434591	26200	Economy	61500.00
0005433434601	26200	Economy	61500.00
0005433753644	26200	Economy	61500.00
0005433753441	26200	Economy	61500.00
0005433753551	26200	Economy	61500.00
0005435981723	26200	Economy	61500.00
0005435981767	26200	Economy	61500.00
0005435981706	26200	Economy	61500.00
0005435981635	26200	Economy	61500.00
0005433753549	26200	Economy	61500.00
0005432869505	26200	Economy	61500.00
0005435981692	26200	Economy	61500.00
0005433753582	26200	Economy	61500.00
0005432049452	26200	Economy	61500.00
0005433434609	26200	Economy	61500.00
0005433753689	26200	Economy	61500.00
0005432655349	26200	Economy	61500.00
0005432051119	26200	Economy	61500.00
0005433753414	26200	Economy	61500.00
0005433434607	26200	Economy	61500.00
0005432984980	26200	Economy	61500.00
0005435981803	26200	Economy	61500.00
0005433434588	26200	Economy	61500.00
0005435981736	26200	Economy	61500.00
0005433753592	26200	Economy	61500.00
0005435981879	26200	Economy	61500.00
0005435981765	26200	Economy	61500.00
0005435981652	26200	Economy	61500.00
0005433753557	26200	Economy	61500.00
0005433753490	26200	Economy	61500.00
0005432655389	26200	Economy	61500.00
0005433753624	26200	Economy	61500.00
0005432984982	26200	Economy	61500.00
0005435981898	26200	Economy	61500.00
0005434731159	26200	Economy	61500.00
0005433434597	26200	Economy	61500.00
0005433434598	26200	Economy	61500.00
0005433753591	26200	Economy	61500.00
0005433753650	26200	Economy	61500.00
0005432655356	26200	Economy	61500.00
0005433753333	26200	Economy	61500.00
0005434374545	1539	Business	38900.00
0005434374541	1539	Business	38900.00
0005434374546	1539	Business	38900.00
0005434374524	1539	Business	38900.00
0005434374511	1539	Business	38900.00
0005434374529	1539	Business	38900.00
0005432267874	1539	Business	38900.00
0005433764652	1539	Business	38900.00
0005433151110	1539	Economy	13000.00
0005433151172	1539	Economy	13000.00
0005433460429	1539	Economy	13000.00
0005434374514	1539	Economy	13000.00
0005434374563	1539	Economy	13000.00
0005434374521	1539	Economy	13000.00
0005434374554	1539	Economy	13000.00
0005432267879	1539	Economy	13000.00
0005433151007	1539	Economy	13000.00
0005434374555	1539	Economy	13000.00
0005434374522	1539	Economy	13000.00
0005433151173	1539	Economy	13000.00
0005434374562	1539	Economy	13000.00
0005434374558	1539	Economy	13000.00
0005434374544	1539	Economy	13000.00
0005433151051	1539	Economy	13000.00
0005434374512	1539	Economy	13000.00
0005434374549	1539	Economy	13000.00
0005433151060	1539	Economy	13000.00
0005434374518	1539	Economy	13000.00
0005434374530	1539	Economy	13000.00
0005433151105	1539	Economy	13000.00
0005434374540	1539	Economy	13000.00
0005434374520	1539	Economy	13000.00
0005433151067	1539	Economy	13000.00
0005433151106	1539	Economy	13000.00
0005434374557	1539	Economy	13000.00
0005432267875	1539	Economy	13000.00
0005433151052	1539	Economy	13000.00
0005433151064	1539	Economy	13000.00
0005433151118	1539	Economy	13000.00
0005432267878	1539	Economy	13000.00
0005434374552	1539	Economy	14300.00
0005433151103	1539	Economy	14300.00
0005433151008	1539	Economy	14300.00
0005433150967	1539	Economy	14300.00
0005433151056	1539	Economy	14300.00
0005434374536	1539	Economy	13000.00
0005433151061	1539	Economy	13000.00
0005434374559	1539	Economy	13000.00
0005434374566	1539	Economy	13000.00
0005434374553	1539	Economy	13000.00
0005434374527	1539	Economy	13000.00
0005433151055	1539	Economy	13000.00
0005434374510	1539	Economy	13000.00
0005433461581	1539	Economy	13000.00
0005432267872	1539	Economy	13000.00
0005433151031	1539	Economy	13000.00
0005432267877	1539	Economy	13000.00
0005434374534	1539	Economy	13000.00
0005434374537	1539	Economy	13000.00
0005433461582	1539	Economy	13000.00
0005434374517	1539	Economy	13000.00
0005434374526	1539	Economy	13000.00
0005434374513	1539	Economy	13000.00
0005434374535	1539	Economy	13000.00
0005433151009	1539	Economy	13000.00
0005434374528	1539	Economy	13000.00
0005433150851	1539	Economy	13000.00
0005434374565	1539	Economy	13000.00
0005434374525	1539	Economy	13000.00
0005434374538	1539	Economy	13000.00
0005433150919	1539	Economy	13000.00
0005433151078	1539	Economy	13000.00
0005432267876	1539	Economy	13000.00
0005433151074	1539	Economy	13000.00
0005433150987	1539	Economy	13000.00
0005434374560	1539	Economy	13000.00
0005434374519	1539	Economy	13000.00
0005433151006	1539	Economy	13000.00
0005434374539	1539	Economy	13000.00
0005434374516	1539	Economy	13000.00
0005433764658	1539	Economy	13000.00
0005434374533	1539	Economy	13000.00
0005433764653	1539	Economy	13000.00
0005434374523	1539	Economy	13000.00
0005434374542	1539	Economy	13000.00
0005434374515	1539	Economy	13000.00
0005434374564	1539	Economy	13000.00
0005434374543	1539	Economy	13000.00
0005433151035	1539	Economy	13000.00
0005434374548	1539	Economy	13000.00
0005433150913	1539	Economy	13000.00
0005434374550	1539	Economy	13000.00
0005434374561	1539	Economy	13000.00
0005433460430	1539	Economy	13000.00
0005434374551	1539	Economy	13000.00
0005432267873	1539	Economy	13000.00
0005433151057	1539	Economy	13000.00
0005434374531	1539	Economy	13000.00
0005434374556	1539	Economy	13000.00
0005434374547	1539	Economy	13000.00
0005433151171	1539	Economy	13000.00
0005434374532	1539	Economy	13000.00
0005434374085	20160	Business	38900.00
0005433764674	20160	Business	38900.00
0005433931459	20160	Business	38900.00
0005434374025	20160	Business	38900.00
0005433151320	20160	Business	38900.00
0005434374249	20160	Business	38900.00
0005433151304	20160	Business	38900.00
0005434374304	20160	Business	38900.00
0005433931456	20160	Business	38900.00
0005434373910	20160	Business	38900.00
0005434374106	20160	Economy	13000.00
0005433931457	20160	Economy	13000.00
0005434374152	20160	Economy	13000.00
0005433151313	20160	Economy	13000.00
0005434374196	20160	Economy	13000.00
0005434374224	20160	Economy	13000.00
0005433151319	20160	Economy	13000.00
0005434374248	20160	Economy	13000.00
0005434373935	20160	Economy	13000.00
0005434374156	20160	Economy	13000.00
0005434373909	20160	Economy	13000.00
0005433151314	20160	Economy	13000.00
0005434374100	20160	Economy	13000.00
0005434374099	20160	Economy	13000.00
0005433151292	20160	Economy	13000.00
0005434374246	20160	Economy	13000.00
0005434374061	20160	Economy	13000.00
0005434374329	20160	Economy	13000.00
0005433151290	20160	Economy	13000.00
0005434374116	20160	Economy	13000.00
0005434374144	20160	Economy	13000.00
0005433151296	20160	Economy	13000.00
0005434374247	20160	Economy	13000.00
0005433151294	20160	Economy	13000.00
0005434374093	20160	Economy	13000.00
0005432056288	20160	Economy	13000.00
0005433151302	20160	Economy	13000.00
0005433151293	20160	Economy	13000.00
0005434374105	20160	Economy	13000.00
0005433151300	20160	Economy	13000.00
0005433151286	20160	Economy	13000.00
0005434374131	20160	Economy	13000.00
0005433151289	20160	Economy	13000.00
0005433151310	20160	Economy	13000.00
0005433151312	20160	Economy	13000.00
0005434374083	20160	Economy	14300.00
0005434374157	20160	Economy	14300.00
0005432056289	20160	Economy	14300.00
0005434029649	20160	Economy	13000.00
0005434374305	20160	Economy	13000.00
0005434373959	20160	Economy	13000.00
0005434374111	20160	Economy	13000.00
0005433151307	20160	Economy	13000.00
0005433931458	20160	Economy	13000.00
0005434373956	20160	Economy	13000.00
0005433151303	20160	Economy	13000.00
0005433151291	20160	Economy	13000.00
0005434373908	20160	Economy	13000.00
0005434374023	20160	Economy	13000.00
0005434374227	20160	Economy	13000.00
0005434373955	20160	Economy	13000.00
0005433151297	20160	Economy	13000.00
0005434374419	20160	Economy	13000.00
0005433151299	20160	Economy	13000.00
0005434373888	20160	Economy	13000.00
0005433151306	20160	Economy	13000.00
0005434374296	20160	Economy	13000.00
0005433151308	20160	Economy	13000.00
0005433151287	20160	Economy	13000.00
0005434374112	20160	Economy	13000.00
0005433151315	20160	Economy	13000.00
0005434374113	20160	Economy	13000.00
0005433151298	20160	Economy	13000.00
0005434374297	20160	Economy	13000.00
0005433151311	20160	Economy	13000.00
0005434374240	20160	Economy	13000.00
0005434374174	20160	Economy	13000.00
0005434374137	20160	Economy	13000.00
0005433151295	20160	Economy	13000.00
0005433151305	20160	Economy	13000.00
0005434373981	20160	Economy	13000.00
0005433151318	20160	Economy	13000.00
0005434374062	20160	Economy	13000.00
0005434374214	20160	Economy	13000.00
0005432056290	20160	Economy	13000.00
0005433151288	20160	Economy	13000.00
0005434374086	20160	Economy	13000.00
0005434374115	20160	Economy	13000.00
0005434373996	20160	Economy	13000.00
0005434374223	20160	Economy	13000.00
0005433151309	20160	Economy	13000.00
0005433151301	20160	Economy	13000.00
0005434374215	20160	Economy	13000.00
0005434374082	20160	Economy	13000.00
0005434029650	20160	Economy	13000.00
0005433151316	20160	Economy	13000.00
0005434374306	20160	Economy	13000.00
0005433151317	20160	Economy	13000.00
0005432424275	526	Business	27500.00
0005432424294	526	Business	27500.00
0005432424292	526	Business	27500.00
0005432424287	526	Business	27500.00
0005432424273	526	Business	27500.00
0005432424290	526	Business	27500.00
0005432424304	526	Business	27500.00
0005432424303	526	Business	27500.00
0005432424297	526	Business	27500.00
0005432424269	526	Business	27500.00
0005432424318	526	Business	27500.00
0005432424315	526	Business	27500.00
0005432424288	526	Business	27500.00
0005432424317	526	Business	27500.00
0005432424281	526	Business	27500.00
0005432424323	526	Business	27500.00
0005432282842	526	Business	27500.00
0005432282841	526	Economy	10100.00
0005432424316	526	Economy	10100.00
0005432424289	526	Economy	9200.00
0005432424295	526	Economy	9200.00
0005432424305	526	Economy	9200.00
0005432282845	526	Economy	9200.00
0005432424311	526	Economy	9200.00
0005432424308	526	Economy	9200.00
0005432424282	526	Economy	9200.00
0005432424271	526	Economy	9200.00
0005432424285	526	Economy	9200.00
0005432424314	526	Economy	9200.00
0005432424299	526	Economy	9200.00
0005432424319	526	Economy	9200.00
0005432424302	526	Economy	9200.00
0005432424283	526	Economy	9200.00
0005432424274	526	Economy	9200.00
0005432424270	526	Economy	9200.00
0005432424279	526	Economy	9200.00
0005432424307	526	Economy	9200.00
0005432424322	526	Economy	9200.00
0005432424280	526	Economy	9200.00
0005432424301	526	Economy	10100.00
0005432424272	526	Economy	10100.00
0005432424277	526	Economy	10100.00
0005432424313	526	Economy	9200.00
0005432282847	526	Economy	10100.00
0005432424312	526	Economy	9200.00
0005432424320	526	Economy	9200.00
0005432424296	526	Economy	9200.00
0005432424309	526	Economy	9200.00
0005432424286	526	Economy	9200.00
0005432424300	526	Economy	9200.00
0005432424293	526	Economy	9200.00
0005432282844	526	Economy	9200.00
0005432424284	526	Economy	9200.00
0005432424306	526	Economy	9200.00
0005432424310	526	Economy	9200.00
0005432282843	526	Economy	9200.00
0005432424276	526	Economy	9200.00
0005432424321	526	Economy	9200.00
0005432282846	526	Economy	9200.00
0005432424291	526	Economy	9200.00
0005432424278	526	Economy	9200.00
0005432424298	526	Economy	9200.00
0005434446491	12885	Business	27500.00
0005434446495	12885	Business	27500.00
0005433158123	12885	Business	27500.00
0005433158124	12885	Economy	10100.00
0005432302321	12885	Economy	9200.00
0005434446487	12885	Economy	9200.00
0005433158120	12885	Economy	9200.00
0005433158127	12885	Economy	9200.00
0005432302319	12885	Economy	9200.00
0005433158121	12885	Economy	9200.00
0005432302318	12885	Economy	9200.00
0005433158122	12885	Economy	9200.00
0005433158126	12885	Economy	10100.00
0005434446485	12885	Economy	9200.00
0005434446488	12885	Economy	9200.00
0005433158125	12885	Economy	9200.00
0005432302320	12885	Economy	9200.00
0005434446486	12885	Economy	9200.00
0005432423913	12874	Business	27500.00
0005432423867	12874	Business	27500.00
0005432423848	12874	Business	27500.00
0005432423835	12874	Business	27500.00
0005432423849	12874	Business	27500.00
0005432423883	12874	Business	27500.00
0005432423889	12874	Business	27500.00
0005432423885	12874	Business	27500.00
0005432423924	12874	Business	27500.00
0005432423793	12874	Economy	10100.00
0005432423839	12874	Economy	10100.00
0005432423906	12874	Economy	10100.00
0005432423905	12874	Economy	9200.00
0005432423886	12874	Economy	9200.00
0005432423890	12874	Economy	9200.00
0005432423925	12874	Economy	9200.00
0005432423829	12874	Economy	9200.00
0005432423847	12874	Economy	9200.00
0005432423887	12874	Economy	9200.00
0005432423676	12874	Economy	9200.00
0005432423841	12874	Economy	9200.00
0005432423888	12874	Economy	9200.00
0005432423807	12874	Economy	9200.00
0005432423862	12874	Economy	9200.00
0005432423891	12874	Economy	9200.00
0005432423931	12874	Economy	9200.00
0005432423926	12874	Economy	9200.00
0005432423882	12874	Economy	9200.00
0005432423834	12874	Economy	9200.00
0005432423868	12874	Economy	9200.00
0005432423935	12874	Economy	9200.00
0005432423923	12874	Economy	10100.00
0005432423948	12874	Economy	10100.00
0005432423830	12874	Economy	9200.00
0005432423820	12874	Economy	9200.00
0005432423806	12874	Economy	9200.00
0005432423842	12874	Economy	9200.00
0005432423821	12874	Economy	9200.00
0005432423840	12874	Economy	9200.00
0005432423825	12874	Economy	9200.00
0005432423685	12874	Economy	9200.00
0005432423927	12874	Economy	9200.00
0005432423794	12874	Economy	9200.00
0005432423742	12874	Economy	9200.00
0005432423792	12874	Economy	9200.00
0005432423715	12874	Economy	9200.00
0005432423704	12874	Economy	9200.00
0005432423822	12874	Economy	9200.00
0005432423823	12874	Economy	9200.00
0005432423904	12874	Economy	9200.00
0005432423797	12874	Economy	9200.00
0005432423892	12874	Economy	9200.00
0005432423907	12874	Economy	9200.00
0005432423863	12874	Economy	9200.00
0005434023523	476	Business	24500.00
0005434735625	476	Business	24500.00
0005433057529	476	Business	24500.00
0005433057493	476	Business	24500.00
0005434029646	476	Business	24500.00
0005434023480	476	Business	24500.00
0005433057451	476	Business	24500.00
0005434023490	476	Business	24500.00
0005434029647	476	Business	24500.00
0005433057456	476	Business	24500.00
0005434023471	476	Business	24500.00
0005434023500	476	Business	24500.00
0005434029645	476	Business	24500.00
0005434023534	476	Business	24500.00
0005432045607	476	Business	24500.00
0005433057370	476	Business	24500.00
0005434023516	476	Business	24500.00
0005434023499	476	Business	24500.00
0005432235614	476	Economy	9000.00
0005433057351	476	Economy	9000.00
0005434023530	476	Economy	9000.00
0005433057339	476	Economy	9000.00
0005432045605	476	Economy	8200.00
0005433057475	476	Economy	8200.00
0005434023483	476	Economy	8200.00
0005434023484	476	Economy	8200.00
0005434023507	476	Economy	8200.00
0005433057334	476	Economy	8200.00
0005434023498	476	Economy	8200.00
0005434023492	476	Economy	8200.00
0005432235619	476	Economy	8200.00
0005434023518	476	Economy	8200.00
0005433057454	476	Economy	8200.00
0005433057263	476	Economy	8200.00
0005433684397	476	Economy	8200.00
0005433929561	476	Economy	8200.00
0005432045606	476	Economy	8200.00
0005434023535	476	Economy	8200.00
0005434032008	476	Economy	8200.00
0005434023531	476	Economy	8200.00
0005434023526	476	Economy	8200.00
0005434032004	476	Economy	8200.00
0005434023519	476	Economy	8200.00
0005433057508	476	Economy	8200.00
0005434023482	476	Economy	8200.00
0005434023474	476	Economy	8200.00
0005434023514	476	Economy	8200.00
0005433057474	476	Economy	8200.00
0005434023487	476	Economy	8200.00
0005434023486	476	Economy	8200.00
0005432235616	476	Economy	8200.00
0005434023540	476	Economy	8200.00
0005434023524	476	Economy	8200.00
0005434023538	476	Economy	8200.00
0005433057429	476	Economy	8200.00
0005434023528	476	Economy	8200.00
0005433057403	476	Economy	8200.00
0005433057460	476	Economy	8200.00
0005434023502	476	Economy	8200.00
0005433057292	476	Economy	8200.00
0005434023506	476	Economy	8200.00
0005434023489	476	Economy	8200.00
0005434032007	476	Economy	8200.00
0005433057392	476	Economy	8200.00
0005434735636	476	Economy	8200.00
0005434023503	476	Economy	8200.00
0005434023520	476	Economy	8200.00
0005433684398	476	Economy	8200.00
0005433057265	476	Economy	8200.00
0005434735624	476	Economy	8200.00
0005434735626	476	Economy	8200.00
0005434023495	476	Economy	8200.00
0005434023478	476	Economy	8200.00
0005433057472	476	Economy	8200.00
0005434023536	476	Economy	8200.00
0005432235617	476	Economy	8200.00
0005434023533	476	Economy	8200.00
0005432235620	476	Economy	8200.00
0005434023473	476	Economy	8200.00
0005434023477	476	Economy	8200.00
0005434023532	476	Economy	8200.00
0005434023479	476	Economy	8200.00
0005434023539	476	Economy	8200.00
0005434023508	476	Economy	8200.00
0005434023510	476	Economy	8200.00
0005433057264	476	Economy	8200.00
0005433684393	476	Economy	8200.00
0005434023505	476	Economy	8200.00
0005434023522	476	Economy	9000.00
0005433057410	476	Economy	9000.00
0005432235618	476	Economy	8200.00
0005432235613	476	Economy	9000.00
0005433057360	476	Economy	8200.00
0005433057338	476	Economy	8200.00
0005434023491	476	Economy	8200.00
0005434023485	476	Economy	8200.00
0005434735637	476	Economy	8200.00
0005433057335	476	Economy	8200.00
0005433057398	476	Economy	8200.00
0005434023525	476	Economy	8200.00
0005432235612	476	Economy	8200.00
0005434023493	476	Economy	8200.00
0005434023513	476	Economy	8200.00
0005434023521	476	Economy	8200.00
0005434032006	476	Economy	8200.00
0005434023517	476	Economy	8200.00
0005433057409	476	Economy	8200.00
0005434023494	476	Economy	8200.00
0005433057333	476	Economy	8200.00
0005433057453	476	Economy	8200.00
0005434032005	476	Economy	8200.00
0005434023476	476	Economy	8200.00
0005433929560	476	Economy	8200.00
0005433057354	476	Economy	8200.00
0005433929569	476	Economy	8200.00
0005434023497	476	Economy	8200.00
0005433057479	476	Economy	8200.00
0005433057498	476	Economy	8200.00
0005434023529	476	Economy	8200.00
0005434023509	476	Economy	8200.00
0005433057452	476	Economy	8200.00
0005433057482	476	Economy	8200.00
0005434023501	476	Economy	8200.00
0005434023511	476	Economy	8200.00
0005434023504	476	Economy	8200.00
0005434023475	476	Economy	8200.00
0005433929563	476	Economy	8200.00
0005433057471	476	Economy	8200.00
0005434029648	476	Economy	8200.00
0005434023527	476	Economy	8200.00
0005434023488	476	Economy	8200.00
0005433057497	476	Economy	8200.00
0005434023515	476	Economy	8200.00
0005434023472	476	Economy	8200.00
0005433929564	476	Economy	8200.00
0005434023496	476	Economy	8200.00
0005434735638	476	Economy	8200.00
0005433057404	476	Economy	8200.00
0005433057549	476	Economy	8200.00
0005433057344	476	Economy	8200.00
0005434032009	476	Economy	8200.00
0005433929547	476	Economy	8200.00
0005434023512	476	Economy	8200.00
0005433057337	476	Economy	8200.00
0005434023537	476	Economy	8200.00
0005432235615	476	Economy	8200.00
0005434023481	476	Economy	8200.00
0005434022764	12692	Business	24500.00
0005433057747	12692	Business	24500.00
0005434022857	12692	Business	24500.00
0005434023063	12692	Business	24500.00
0005434022891	12692	Business	24500.00
0005433057763	12692	Business	24500.00
0005434023004	12692	Business	24500.00
0005434022767	12692	Business	24500.00
0005433057753	12692	Business	24500.00
0005434023112	12692	Business	24500.00
0005433057751	12692	Business	24500.00
0005434022916	12692	Business	24500.00
0005434023199	12692	Business	24500.00
0005434735677	12692	Business	24500.00
0005434735676	12692	Business	24500.00
0005433057768	12692	Business	24500.00
0005434023070	12692	Business	24500.00
0005434735674	12692	Economy	9000.00
0005434031950	12692	Economy	8200.00
0005433057746	12692	Economy	8200.00
0005434023088	12692	Economy	8200.00
0005434022774	12692	Economy	8200.00
0005434023208	12692	Economy	8200.00
0005433057745	12692	Economy	8200.00
0005433057777	12692	Economy	8200.00
0005432156353	12692	Economy	8200.00
0005433057775	12692	Economy	8200.00
0005434022994	12692	Economy	8200.00
0005433057758	12692	Economy	8200.00
0005434022780	12692	Economy	8200.00
0005434022915	12692	Economy	8200.00
0005434735675	12692	Economy	8200.00
0005433057769	12692	Economy	8200.00
0005433057765	12692	Economy	8200.00
0005434023069	12692	Economy	8200.00
0005433057783	12692	Economy	8200.00
0005434022910	12692	Economy	8200.00
0005433057774	12692	Economy	8200.00
0005433057760	12692	Economy	8200.00
0005434022943	12692	Economy	8200.00
0005434023080	12692	Economy	8200.00
0005434023075	12692	Economy	8200.00
0005434022839	12692	Economy	8200.00
0005434022775	12692	Economy	8200.00
0005434022856	12692	Economy	8200.00
0005433057782	12692	Economy	8200.00
0005434023229	12692	Economy	8200.00
0005434028274	12692	Economy	8200.00
0005433057748	12692	Economy	8200.00
0005434022949	12692	Economy	8200.00
0005434023005	12692	Economy	8200.00
0005434022858	12692	Economy	8200.00
0005434023064	12692	Economy	8200.00
0005434023087	12692	Economy	8200.00
0005434022962	12692	Economy	8200.00
0005434031985	12692	Economy	8200.00
0005433057778	12692	Economy	8200.00
0005433057771	12692	Economy	8200.00
0005434023009	12692	Economy	8200.00
0005434023198	12692	Economy	8200.00
0005433057756	12692	Economy	8200.00
0005433057759	12692	Economy	8200.00
0005434022812	12692	Economy	8200.00
0005434023045	12692	Economy	8200.00
0005433057754	12692	Economy	8200.00
0005433057776	12692	Economy	8200.00
0005433057761	12692	Economy	8200.00
0005434023233	12692	Economy	8200.00
0005434022688	12692	Economy	8200.00
0005433057781	12692	Economy	8200.00
0005433057752	12692	Economy	9000.00
0005433929602	12692	Economy	8200.00
0005434022920	12692	Economy	8200.00
0005433057757	12692	Economy	8200.00
0005433057755	12692	Economy	9000.00
0005433057773	12692	Economy	9000.00
0005434022787	12692	Economy	8200.00
0005433929601	12692	Economy	8200.00
0005433057767	12692	Economy	8200.00
0005434022979	12692	Economy	8200.00
0005433057749	12692	Economy	8200.00
0005433057780	12692	Economy	8200.00
0005434022892	12692	Economy	8200.00
0005432156354	12692	Economy	8200.00
0005434023032	12692	Economy	8200.00
0005434022760	12692	Economy	8200.00
0005433057779	12692	Economy	8200.00
0005434022687	12692	Economy	8200.00
0005434022963	12692	Economy	8200.00
0005434023232	12692	Economy	8200.00
0005434022782	12692	Economy	8200.00
0005432156351	12692	Economy	8200.00
0005434023081	12692	Economy	8200.00
0005434022656	12692	Economy	8200.00
0005434735672	12692	Economy	8200.00
0005433057770	12692	Economy	8200.00
0005433057772	12692	Economy	8200.00
0005434735673	12692	Economy	8200.00
0005434022986	12692	Economy	8200.00
0005433929600	12692	Economy	8200.00
0005434022840	12692	Economy	8200.00
0005434028262	12692	Economy	8200.00
0005432157486	12692	Economy	8200.00
0005433684414	12692	Economy	8200.00
0005433057764	12692	Economy	8200.00
0005432156350	12692	Economy	8200.00
0005432156352	12692	Economy	8200.00
0005433057766	12692	Economy	8200.00
0005433684415	12692	Economy	8200.00
0005434022923	12692	Economy	8200.00
0005433057762	12692	Economy	8200.00
0005433057743	12692	Economy	8200.00
0005434022781	12692	Economy	8200.00
0005433057744	12692	Economy	8200.00
0005434023021	12692	Economy	8200.00
0005434023197	12692	Economy	8200.00
0005434028273	12692	Economy	8200.00
0005433057750	12692	Economy	8200.00
0005433529260	13814	Business	111600.00
0005433529252	13814	Business	111600.00
0005433529253	13814	Business	111600.00
0005433527244	13814	Business	111600.00
0005433529255	13814	Economy	37200.00
0005433527247	13814	Economy	37200.00
0005433527253	13814	Economy	37200.00
0005433527251	13814	Economy	40900.00
0005433527241	13814	Economy	40900.00
0005433527242	13814	Economy	37200.00
0005433527243	13814	Economy	37200.00
0005433527252	13814	Economy	37200.00
0005433529261	13814	Economy	37200.00
0005433529262	13814	Economy	37200.00
0005433529257	13814	Economy	37200.00
0005433529250	13814	Economy	37200.00
0005433529263	13814	Economy	37200.00
0005433529249	13814	Economy	37200.00
0005433527249	13814	Economy	37200.00
0005433529264	13814	Economy	37200.00
0005433527250	13814	Economy	37200.00
0005433527239	13814	Economy	37200.00
0005433529254	13814	Economy	37200.00
0005433529258	13814	Economy	37200.00
0005433527246	13814	Economy	37200.00
0005433529259	13814	Economy	37200.00
0005433527240	13814	Economy	37200.00
0005433527248	13814	Economy	37200.00
0005433529251	13814	Economy	37200.00
0005433529256	13814	Economy	37200.00
0005433527245	13814	Economy	37200.00
0005433529220	32448	Business	111600.00
0005433533275	32448	Business	111600.00
0005433529219	32448	Economy	37200.00
0005433533248	32448	Economy	37200.00
0005433529213	32448	Economy	37200.00
0005433529222	32448	Economy	40900.00
0005433529227	32448	Economy	40900.00
0005433533249	32448	Economy	40900.00
0005433529226	32448	Economy	37200.00
0005433533270	32448	Economy	37200.00
0005433529211	32448	Economy	37200.00
0005433533274	32448	Economy	37200.00
0005433529221	32448	Economy	37200.00
0005433533261	32448	Economy	37200.00
0005433529214	32448	Economy	37200.00
0005433529218	32448	Economy	37200.00
0005433529212	32448	Economy	37200.00
0005433529244	32448	Economy	37200.00
0005433533250	32448	Economy	37200.00
0005433529217	32448	Economy	37200.00
0005433533254	32448	Economy	37200.00
0005433533247	32448	Economy	37200.00
0005433533260	32448	Economy	37200.00
0005433533251	32448	Economy	37200.00
0005433533253	32448	Economy	37200.00
0005433533252	32448	Economy	37200.00
0005433533262	32448	Economy	37200.00
0005433923009	2130	Business	34700.00
0005433922997	2130	Business	34700.00
0005433923022	2130	Business	34700.00
0005433035631	2130	Business	34700.00
0005433035672	2130	Business	34700.00
0005433923025	2130	Business	34700.00
0005433923039	2130	Business	34700.00
0005433922999	2130	Business	34700.00
0005433922963	2130	Business	34700.00
0005433923042	2130	Business	34700.00
0005433922974	2130	Business	34700.00
0005433929600	2130	Business	34700.00
0005433923008	2130	Business	34700.00
0005432231530	2130	Business	34700.00
0005433922996	2130	Business	34700.00
0005434028274	2130	Business	34700.00
0005433923053	2130	Business	34700.00
0005433923019	2130	Business	34700.00
0005433923018	2130	Business	34700.00
0005433922984	2130	Business	34700.00
0005433923021	2130	Economy	12700.00
0005433922983	2130	Economy	12700.00
0005433922986	2130	Economy	12700.00
0005432044516	2130	Economy	12700.00
0005432231528	2130	Economy	11600.00
0005433922981	2130	Economy	11600.00
0005433923027	2130	Economy	11600.00
0005433923052	2130	Economy	11600.00
0005433923012	2130	Economy	11600.00
0005433929601	2130	Economy	11600.00
0005433923010	2130	Economy	11600.00
0005433035632	2130	Economy	11600.00
0005433035635	2130	Economy	11600.00
0005433922994	2130	Economy	11600.00
0005433929602	2130	Economy	11600.00
0005433035792	2130	Economy	11600.00
0005433922966	2130	Economy	11600.00
0005433922967	2130	Economy	11600.00
0005433035677	2130	Economy	11600.00
0005433923055	2130	Economy	11600.00
0005433035710	2130	Economy	11600.00
0005433923034	2130	Economy	11600.00
0005433931458	2130	Economy	11600.00
0005433922992	2130	Economy	11600.00
0005432231527	2130	Economy	11600.00
0005433923013	2130	Economy	11600.00
0005433922995	2130	Economy	11600.00
0005433923037	2130	Economy	11600.00
0005433923028	2130	Economy	11600.00
0005433035475	2130	Economy	11600.00
0005432044517	2130	Economy	11600.00
0005433922989	2130	Economy	11600.00
0005433923007	2130	Economy	11600.00
0005433923035	2130	Economy	11600.00
0005433923056	2130	Economy	11600.00
0005433923003	2130	Economy	11600.00
0005433035694	2130	Economy	11600.00
0005433923029	2130	Economy	11600.00
0005433035720	2130	Economy	11600.00
0005433922975	2130	Economy	11600.00
0005433922998	2130	Economy	11600.00
0005433035896	2130	Economy	11600.00
0005433035681	2130	Economy	11600.00
0005432231534	2130	Economy	11600.00
0005433922987	2130	Economy	11600.00
0005433931457	2130	Economy	11600.00
0005433923014	2130	Economy	11600.00
0005433923033	2130	Economy	11600.00
0005433923006	2130	Economy	11600.00
0005433923001	2130	Economy	11600.00
0005433923016	2130	Economy	11600.00
0005433922982	2130	Economy	11600.00
0005433923048	2130	Economy	11600.00
0005433035634	2130	Economy	11600.00
0005433923054	2130	Economy	11600.00
0005433923041	2130	Economy	11600.00
0005433923049	2130	Economy	11600.00
0005433035879	2130	Economy	11600.00
0005433922973	2130	Economy	11600.00
0005433923017	2130	Economy	11600.00
0005433035556	2130	Economy	11600.00
0005433035671	2130	Economy	11600.00
0005433923036	2130	Economy	11600.00
0005433923059	2130	Economy	11600.00
0005433035778	2130	Economy	11600.00
0005433922978	2130	Economy	11600.00
0005433922964	2130	Economy	11600.00
0005433035713	2130	Economy	11600.00
0005432231531	2130	Economy	11600.00
0005432231535	2130	Economy	11600.00
0005433922971	2130	Economy	11600.00
0005433035702	2130	Economy	11600.00
0005433923038	2130	Economy	11600.00
0005433875371	2130	Economy	11600.00
0005432044515	2130	Economy	11600.00
0005433035730	2130	Economy	11600.00
0005433923044	2130	Economy	11600.00
0005433923015	2130	Economy	11600.00
0005433923046	2130	Economy	11600.00
0005433035739	2130	Economy	11600.00
0005433035878	2130	Economy	11600.00
0005433922969	2130	Economy	12700.00
0005433035895	2130	Economy	11600.00
0005433922988	2130	Economy	12700.00
0005433923032	2130	Economy	11600.00
0005433922970	2130	Economy	11600.00
0005433923020	2130	Economy	11600.00
0005433035370	2130	Economy	11600.00
0005433923058	2130	Economy	11600.00
0005433035590	2130	Economy	11600.00
0005433931456	2130	Economy	11600.00
0005433922980	2130	Economy	11600.00
0005433922993	2130	Economy	11600.00
0005434028273	2130	Economy	11600.00
0005433923040	2130	Economy	11600.00
0005433922991	2130	Economy	11600.00
0005432231532	2130	Economy	11600.00
0005432749755	2130	Economy	11600.00
0005433923023	2130	Economy	11600.00
0005433922968	2130	Economy	11600.00
0005433923045	2130	Economy	11600.00
0005433035371	2130	Economy	11600.00
0005433922962	2130	Economy	11600.00
0005433923031	2130	Economy	11600.00
0005433035692	2130	Economy	11600.00
0005433931459	2130	Economy	11600.00
0005433922965	2130	Economy	11600.00
0005433035700	2130	Economy	11600.00
0005433035712	2130	Economy	11600.00
0005433923051	2130	Economy	11600.00
0005433922972	2130	Economy	11600.00
0005433923002	2130	Economy	11600.00
0005433035633	2130	Economy	11600.00
0005432749756	2130	Economy	11600.00
0005433035777	2130	Economy	11600.00
0005432231536	2130	Economy	11600.00
0005432749759	2130	Economy	11600.00
0005433923004	2130	Economy	11600.00
0005433922990	2130	Economy	11600.00
0005433035693	2130	Economy	11600.00
0005433922976	2130	Economy	11600.00
0005433035731	2130	Economy	11600.00
0005433923047	2130	Economy	11600.00
0005433923050	2130	Economy	11600.00
0005433923030	2130	Economy	11600.00
0005433923024	2130	Economy	11600.00
0005433922979	2130	Economy	11600.00
0005433922985	2130	Economy	11600.00
0005433035369	2130	Economy	11600.00
0005433923000	2130	Economy	11600.00
0005432749751	2130	Economy	11600.00
0005433923011	2130	Economy	11600.00
0005433035701	2130	Economy	11600.00
0005432231529	2130	Economy	11600.00
0005433035622	2130	Economy	11600.00
0005433923043	2130	Economy	11600.00
0005433922977	2130	Economy	11600.00
0005434028262	2130	Economy	11600.00
0005433035538	2130	Economy	11600.00
0005433035690	2130	Economy	11600.00
0005433923057	2130	Economy	11600.00
0005433923026	2130	Economy	11600.00
0005433923005	2130	Economy	11600.00
0005432231533	2130	Economy	11600.00
0005433036114	24086	Business	34700.00
0005433036127	24086	Business	34700.00
0005432206181	24086	Business	34700.00
0005433036160	24086	Business	34700.00
0005433036119	24086	Business	34700.00
0005433922032	24086	Business	34700.00
0005433922291	24086	Business	34700.00
0005433922543	24086	Business	34700.00
0005433922061	24086	Business	34700.00
0005433036152	24086	Business	34700.00
0005433922607	24086	Business	34700.00
0005433036146	24086	Business	34700.00
0005433922129	24086	Business	34700.00
0005433922134	24086	Business	34700.00
0005433036139	24086	Business	34700.00
0005433921799	24086	Business	34700.00
0005433922055	24086	Business	34700.00
0005433922268	24086	Business	34700.00
0005433922359	24086	Economy	12700.00
0005433036143	24086	Economy	12700.00
0005433922457	24086	Economy	12700.00
0005433921798	24086	Economy	12700.00
0005433921923	24086	Economy	11600.00
0005433922254	24086	Economy	11600.00
0005433036163	24086	Economy	11600.00
0005433922324	24086	Economy	11600.00
0005432206182	24086	Economy	11600.00
0005433036162	24086	Economy	11600.00
0005433922423	24086	Economy	11600.00
0005433921998	24086	Economy	11600.00
0005433036122	24086	Economy	11600.00
0005433036154	24086	Economy	11600.00
0005434028289	24086	Economy	11600.00
0005433036155	24086	Economy	11600.00
0005433922256	24086	Economy	11600.00
0005433922358	24086	Economy	11600.00
0005433921758	24086	Economy	11600.00
0005433922058	24086	Economy	11600.00
0005433922200	24086	Economy	11600.00
0005433036150	24086	Economy	11600.00
0005433922489	24086	Economy	11600.00
0005434028288	24086	Economy	11600.00
0005433922133	24086	Economy	11600.00
0005433036149	24086	Economy	11600.00
0005433922255	24086	Economy	11600.00
0005432206177	24086	Economy	11600.00
0005433922231	24086	Economy	11600.00
0005433922164	24086	Economy	11600.00
0005433036142	24086	Economy	11600.00
0005433036131	24086	Economy	11600.00
0005433922162	24086	Economy	11600.00
0005433036159	24086	Economy	11600.00
0005433929555	24086	Economy	11600.00
0005434028290	24086	Economy	11600.00
0005433921955	24086	Economy	11600.00
0005433036121	24086	Economy	11600.00
0005433922347	24086	Economy	11600.00
0005432749778	24086	Economy	11600.00
0005433036140	24086	Economy	11600.00
0005433922353	24086	Economy	11600.00
0005433922045	24086	Economy	11600.00
0005433922416	24086	Economy	11600.00
0005433922203	24086	Economy	11600.00
0005433036164	24086	Economy	11600.00
0005433922015	24086	Economy	11600.00
0005433922053	24086	Economy	11600.00
0005433921922	24086	Economy	11600.00
0005433922204	24086	Economy	11600.00
0005433036145	24086	Economy	11600.00
0005433922577	24086	Economy	11600.00
0005433922233	24086	Economy	11600.00
0005433036151	24086	Economy	11600.00
0005433922079	24086	Economy	11600.00
0005433922541	24086	Economy	11600.00
0005433921999	24086	Economy	11600.00
0005433921743	24086	Economy	11600.00
0005433922183	24086	Economy	11600.00
0005433922711	24086	Economy	11600.00
0005433922014	24086	Economy	11600.00
0005432206176	24086	Economy	11600.00
0005433036148	24086	Economy	11600.00
0005432207654	24086	Economy	11600.00
0005433036165	24086	Economy	11600.00
0005433922046	24086	Economy	11600.00
0005433922160	24086	Economy	11600.00
0005434028291	24086	Economy	11600.00
0005433922132	24086	Economy	11600.00
0005432206178	24086	Economy	11600.00
0005433036153	24086	Economy	11600.00
0005433922163	24086	Economy	11600.00
0005432206179	24086	Economy	11600.00
0005433922212	24086	Economy	11600.00
0005433922604	24086	Economy	11600.00
0005433036126	24086	Economy	11600.00
0005432206180	24086	Economy	11600.00
0005432207656	24086	Economy	11600.00
0005433036120	24086	Economy	11600.00
0005433922516	24086	Economy	11600.00
0005433922135	24086	Economy	11600.00
0005433922080	24086	Economy	11600.00
0005433922346	24086	Economy	11600.00
0005433875358	24086	Economy	11600.00
0005433036117	24086	Economy	11600.00
0005433922232	24086	Economy	11600.00
0005433036156	24086	Economy	12700.00
0005433922257	24086	Economy	11600.00
0005432749780	24086	Economy	12700.00
0005433922182	24086	Economy	11600.00
0005433036147	24086	Economy	11600.00
0005433036125	24086	Economy	11600.00
0005433922427	24086	Economy	11600.00
0005433922426	24086	Economy	11600.00
0005433922060	24086	Economy	11600.00
0005433922235	24086	Economy	11600.00
0005432207655	24086	Economy	11600.00
0005433036138	24086	Economy	11600.00
0005433922000	24086	Economy	11600.00
0005433922205	24086	Economy	11600.00
0005433036129	24086	Economy	11600.00
0005433922146	24086	Economy	11600.00
0005433922542	24086	Economy	11600.00
0005433922236	24086	Economy	11600.00
0005433922189	24086	Economy	11600.00
0005433036135	24086	Economy	11600.00
0005433036123	24086	Economy	11600.00
0005433921718	24086	Economy	11600.00
0005433921927	24086	Economy	11600.00
0005433922344	24086	Economy	11600.00
0005433036128	24086	Economy	11600.00
0005433922224	24086	Economy	11600.00
0005433922275	24086	Economy	11600.00
0005433875360	24086	Economy	11600.00
0005433921831	24086	Economy	11600.00
0005433922415	24086	Economy	11600.00
0005433921685	24086	Economy	11600.00
0005433036137	24086	Economy	11600.00
0005433922029	24086	Economy	11600.00
0005433036157	24086	Economy	11600.00
0005433922104	24086	Economy	11600.00
0005433036136	24086	Economy	11600.00
0005433921924	24086	Economy	11600.00
0005433922130	24086	Economy	11600.00
0005433036134	24086	Economy	11600.00
0005433922167	24086	Economy	11600.00
0005433922230	24086	Economy	11600.00
0005433921834	24086	Economy	11600.00
0005433922031	24086	Economy	11600.00
0005433036118	24086	Economy	11600.00
0005433922458	24086	Economy	11600.00
0005433036144	24086	Economy	11600.00
0005433921941	24086	Economy	11600.00
0005433922030	24086	Economy	11600.00
0005433922412	24086	Economy	11600.00
0005433922305	24086	Economy	11600.00
0005433036133	24086	Economy	11600.00
0005433922084	24086	Economy	11600.00
0005433036158	24086	Economy	11600.00
0005433036124	24086	Economy	11600.00
0005433036141	24086	Economy	11600.00
0005433922201	24086	Economy	11600.00
0005433036130	24086	Economy	11600.00
0005433922515	24086	Economy	11600.00
0005433036115	24086	Economy	11600.00
0005432749779	24086	Economy	11600.00
0005433921930	24086	Economy	11600.00
0005433036132	24086	Economy	11600.00
0005433922161	24086	Economy	11600.00
0005433922578	24086	Economy	11600.00
0005433036161	24086	Economy	11600.00
0005433036116	24086	Economy	11600.00
0005433922234	24086	Economy	11600.00
0005433233218	282	Business	83700.00
0005434725077	282	Business	83700.00
0005434725105	282	Business	83700.00
0005433233566	282	Business	83700.00
0005434725145	282	Business	83700.00
0005433180800	282	Business	83700.00
0005434725060	282	Business	83700.00
0005434725164	282	Business	83700.00
0005434302861	282	Business	83700.00
0005433766592	282	Business	83700.00
0005433233351	282	Business	83700.00
0005433233660	282	Business	83700.00
0005432277763	282	Business	83700.00
0005435142531	282	Business	83700.00
0005433233228	282	Business	83700.00
0005434725146	282	Business	83700.00
0005434725084	282	Business	83700.00
0005434725144	282	Business	83700.00
0005432277772	282	Business	83700.00
0005434551055	282	Business	83700.00
0005434735671	282	Business	83700.00
0005434551057	282	Business	83700.00
0005433233510	282	Business	83700.00
0005433233365	282	Business	83700.00
0005434725117	282	Business	83700.00
0005434725121	282	Business	83700.00
0005434551093	282	Comfort	47400.00
0005434725062	282	Comfort	47400.00
0005434725135	282	Comfort	47400.00
0005433113505	282	Comfort	47400.00
0005433180880	282	Comfort	47400.00
0005433180852	282	Comfort	47400.00
0005434725111	282	Comfort	47400.00
0005434725101	282	Comfort	47400.00
0005434302445	282	Comfort	47400.00
0005433233258	282	Comfort	47400.00
0005434725054	282	Comfort	47400.00
0005433233556	282	Comfort	47400.00
0005433289786	282	Comfort	47400.00
0005433233360	282	Comfort	47400.00
0005433766596	282	Comfort	47400.00
0005434551061	282	Comfort	47400.00
0005434551069	282	Comfort	47400.00
0005434725074	282	Comfort	47400.00
0005435142539	282	Comfort	47400.00
0005434551074	282	Comfort	47400.00
0005433180858	282	Comfort	47400.00
0005435142542	282	Comfort	47400.00
0005434725113	282	Comfort	47400.00
0005435142538	282	Comfort	47400.00
0005434725048	282	Comfort	47400.00
0005433289776	282	Comfort	47400.00
0005432277771	282	Comfort	47400.00
0005434725100	282	Comfort	47400.00
0005433233430	282	Comfort	47400.00
0005434551050	282	Comfort	47400.00
0005434725081	282	Comfort	47400.00
0005433180792	282	Comfort	47400.00
0005433180730	282	Comfort	47400.00
0005434725158	282	Comfort	47400.00
0005432277764	282	Comfort	47400.00
0005433131628	282	Comfort	47400.00
0005434725096	282	Comfort	47400.00
0005432277769	282	Comfort	47400.00
0005434551051	282	Comfort	47400.00
0005433180783	282	Comfort	47400.00
0005433233222	282	Comfort	47400.00
0005434725123	282	Comfort	47400.00
0005433233839	282	Economy	27900.00
0005434725140	282	Economy	27900.00
0005434725057	282	Economy	27900.00
0005434551068	282	Economy	27900.00
0005434725147	282	Economy	27900.00
0005433233405	282	Economy	27900.00
0005434735669	282	Economy	27900.00
0005434551092	282	Economy	27900.00
0005434725139	282	Economy	27900.00
0005434725045	282	Economy	27900.00
0005432277762	282	Economy	27900.00
0005433233688	282	Economy	27900.00
0005433233219	282	Economy	27900.00
0005434725136	282	Economy	27900.00
0005434725093	282	Economy	27900.00
0005434725076	282	Economy	27900.00
0005433766599	282	Economy	27900.00
0005435142532	282	Economy	27900.00
0005434725114	282	Economy	27900.00
0005434551076	282	Economy	27900.00
0005433233428	282	Economy	27900.00
0005434725090	282	Economy	27900.00
0005434551073	282	Economy	27900.00
0005433233602	282	Economy	27900.00
0005434725131	282	Economy	27900.00
0005434302862	282	Economy	27900.00
0005434725166	282	Economy	27900.00
0005433180723	282	Economy	27900.00
0005434725051	282	Economy	27900.00
0005434551045	282	Economy	27900.00
0005434031967	282	Economy	27900.00
0005433233285	282	Economy	27900.00
0005434031961	282	Economy	27900.00
0005433180780	282	Economy	27900.00
0005434725127	282	Economy	27900.00
0005434725159	282	Economy	27900.00
0005434725075	282	Economy	27900.00
0005434725167	282	Economy	27900.00
0005434551067	282	Economy	27900.00
0005433233672	282	Economy	27900.00
0005434725132	282	Economy	27900.00
0005434725089	282	Economy	27900.00
0005434551047	282	Economy	27900.00
0005433233163	282	Economy	27900.00
0005434551059	282	Economy	27900.00
0005434302444	282	Economy	27900.00
0005433113500	282	Economy	27900.00
0005434725141	282	Economy	27900.00
0005434725129	282	Economy	27900.00
0005434725110	282	Economy	27900.00
0005434551071	282	Economy	27900.00
0005433233590	282	Economy	27900.00
0005434725160	282	Economy	27900.00
0005434725118	282	Economy	27900.00
0005434725155	282	Economy	27900.00
0005434725154	282	Economy	27900.00
0005433180749	282	Economy	27900.00
0005433233396	282	Economy	27900.00
0005434551083	282	Economy	27900.00
0005434735667	282	Economy	27900.00
0005433233568	282	Economy	27900.00
0005434725052	282	Economy	27900.00
0005434725072	282	Economy	27900.00
0005434725092	282	Economy	27900.00
0005434725082	282	Economy	27900.00
0005434725163	282	Economy	30700.00
0005434731155	282	Economy	27900.00
0005433233678	282	Economy	30700.00
0005434551095	282	Economy	30700.00
0005434725149	282	Economy	27900.00
0005434725098	282	Economy	27900.00
0005434725079	282	Economy	27900.00
0005434725085	282	Economy	27900.00
0005434551052	282	Economy	30700.00
0005433233709	282	Economy	30700.00
0005433233401	282	Economy	30700.00
0005434725161	282	Economy	27900.00
0005434725128	282	Economy	27900.00
0005434725112	282	Economy	27900.00
0005433233354	282	Economy	27900.00
0005433233419	282	Economy	27900.00
0005433233340	282	Economy	27900.00
0005433233129	282	Economy	27900.00
0005433233397	282	Economy	27900.00
0005433233350	282	Economy	27900.00
0005433180782	282	Economy	27900.00
0005433233589	282	Economy	27900.00
0005433233435	282	Economy	27900.00
0005434551072	282	Economy	27900.00
0005433233229	282	Economy	27900.00
0005432277766	282	Economy	27900.00
0005432277775	282	Economy	27900.00
0005434725087	282	Economy	27900.00
0005434725086	282	Economy	27900.00
0005432277770	282	Economy	27900.00
0005434735666	282	Economy	27900.00
0005434725137	282	Economy	27900.00
0005434551064	282	Economy	27900.00
0005433180850	282	Economy	27900.00
0005433126779	282	Economy	27900.00
0005434725130	282	Economy	27900.00
0005433180849	282	Economy	27900.00
0005434302860	282	Economy	27900.00
0005433126791	282	Economy	27900.00
0005433126787	282	Economy	27900.00
0005434725142	282	Economy	27900.00
0005434725156	282	Economy	27900.00
0005434725094	282	Economy	27900.00
0005433233220	282	Economy	27900.00
0005434551066	282	Economy	27900.00
0005433131646	282	Economy	27900.00
0005432277768	282	Economy	27900.00
0005434735668	282	Economy	27900.00
0005434551098	282	Economy	27900.00
0005433233420	282	Economy	27900.00
0005434551049	282	Economy	27900.00
0005433233286	282	Economy	27900.00
0005434725115	282	Economy	27900.00
0005434725065	282	Economy	27900.00
0005433111482	282	Economy	27900.00
0005434725050	282	Economy	27900.00
0005433233522	282	Economy	27900.00
0005433289756	282	Economy	27900.00
0005434551058	282	Economy	27900.00
0005434551075	282	Economy	27900.00
0005434725133	282	Economy	27900.00
0005433131647	282	Economy	27900.00
0005433233353	282	Economy	27900.00
0005434551085	282	Economy	27900.00
0005433233551	282	Economy	27900.00
0005434731152	282	Economy	27900.00
0005433233356	282	Economy	27900.00
0005434725124	282	Economy	27900.00
0005433233710	282	Economy	27900.00
0005433180801	282	Economy	27900.00
0005434551048	282	Economy	27900.00
0005434551060	282	Economy	27900.00
0005433766598	282	Economy	27900.00
0005433113507	282	Economy	27900.00
0005434551080	282	Economy	27900.00
0005434031969	282	Economy	27900.00
0005434725157	282	Economy	27900.00
0005433180882	282	Economy	27900.00
0005434725168	282	Economy	27900.00
0005433233260	282	Economy	27900.00
0005434551046	282	Economy	27900.00
0005433233357	282	Economy	27900.00
0005434551089	282	Economy	27900.00
0005434551053	282	Economy	27900.00
0005432277765	282	Economy	27900.00
0005434551063	282	Economy	27900.00
0005433233257	282	Economy	27900.00
0005434725069	282	Economy	27900.00
0005433180816	282	Economy	27900.00
0005433126778	282	Economy	27900.00
0005433233427	282	Economy	27900.00
0005434725083	282	Economy	27900.00
0005433233458	282	Economy	27900.00
0005434551056	282	Economy	27900.00
0005434725116	282	Economy	27900.00
0005433233352	282	Economy	27900.00
0005432277767	282	Economy	27900.00
0005434551044	282	Economy	27900.00
0005435142540	282	Economy	27900.00
0005434725106	282	Economy	27900.00
0005433233567	282	Economy	27900.00
0005434725152	282	Economy	27900.00
0005434551070	282	Economy	27900.00
0005434031971	282	Economy	27900.00
0005433180898	282	Economy	27900.00
0005435142536	282	Economy	27900.00
0005434551077	282	Economy	27900.00
0005434725063	282	Economy	27900.00
0005433233341	282	Economy	27900.00
0005434725150	282	Economy	27900.00
0005434725047	282	Economy	27900.00
0005434725125	282	Economy	27900.00
0005434551062	282	Economy	27900.00
0005433180851	282	Economy	27900.00
0005433233547	282	Economy	27900.00
0005434551082	282	Economy	30700.00
0005434725103	282	Economy	30700.00
0005434551065	282	Economy	30700.00
0005434725104	282	Economy	30700.00
0005433233402	282	Economy	30700.00
0005433233509	282	Economy	30700.00
0005434725046	282	Economy	27900.00
0005435142537	282	Economy	27900.00
0005433131648	282	Economy	27900.00
0005433180779	282	Economy	27900.00
0005434551097	282	Economy	27900.00
0005433233596	282	Economy	27900.00
0005434725097	282	Economy	27900.00
0005435142533	282	Economy	27900.00
0005434725091	282	Economy	27900.00
0005434031957	282	Economy	27900.00
0005434725058	282	Economy	27900.00
0005433180853	282	Economy	27900.00
0005434725134	282	Economy	27900.00
0005433233281	282	Economy	27900.00
0005434725109	282	Economy	27900.00
0005434725070	282	Economy	27900.00
0005434551088	282	Economy	27900.00
0005434725102	282	Economy	27900.00
0005434302447	282	Economy	27900.00
0005433180881	282	Economy	27900.00
0005432277761	282	Economy	27900.00
0005434725151	282	Economy	27900.00
0005434725068	282	Economy	27900.00
0005434725143	282	Economy	27900.00
0005434725153	282	Economy	27900.00
0005434725099	282	Economy	27900.00
0005434551091	282	Economy	27900.00
0005433766591	282	Economy	27900.00
0005433180899	282	Economy	27900.00
0005434551096	282	Economy	27900.00
0005434725073	282	Economy	27900.00
0005434725064	282	Economy	27900.00
0005434725122	282	Economy	27900.00
0005434725148	282	Economy	27900.00
0005433233687	282	Economy	27900.00
0005434725126	282	Economy	27900.00
0005433233221	282	Economy	27900.00
0005432277774	282	Economy	27900.00
0005435142530	282	Economy	27900.00
0005434725053	282	Economy	27900.00
0005434725120	282	Economy	27900.00
0005434725119	282	Economy	27900.00
0005433180833	282	Economy	27900.00
0005433233174	282	Economy	27900.00
0005434725071	282	Economy	27900.00
0005434725078	282	Economy	27900.00
0005434725095	282	Economy	27900.00
0005434731154	282	Economy	27900.00
0005433233603	282	Economy	27900.00
0005434725055	282	Economy	27900.00
0005433233261	282	Economy	27900.00
0005434725138	282	Economy	27900.00
0005435142534	282	Economy	27900.00
0005434725049	282	Economy	27900.00
0005434725066	282	Economy	27900.00
0005434725108	282	Economy	27900.00
0005434551054	282	Economy	27900.00
0005433233318	282	Economy	27900.00
0005434725107	282	Economy	27900.00
0005433180750	282	Economy	27900.00
0005433233198	282	Economy	27900.00
0005434551094	282	Economy	27900.00
0005434551078	282	Economy	27900.00
0005434725080	282	Economy	27900.00
0005433126801	282	Economy	27900.00
0005434551086	282	Economy	27900.00
0005433289777	282	Economy	27900.00
0005433126786	282	Economy	27900.00
0005434725162	282	Economy	27900.00
0005434731153	282	Economy	27900.00
0005433233423	282	Economy	27900.00
0005434725067	282	Economy	27900.00
0005433180857	282	Economy	27900.00
0005434302446	282	Economy	27900.00
0005433233364	282	Economy	27900.00
0005434725056	282	Economy	27900.00
0005434725165	282	Economy	27900.00
0005435142541	282	Economy	27900.00
0005434551084	282	Economy	27900.00
0005433233595	282	Economy	27900.00
0005434735670	282	Economy	27900.00
0005433233276	282	Economy	27900.00
0005435142535	282	Economy	27900.00
0005434551079	282	Economy	27900.00
0005433233588	282	Economy	27900.00
0005433233359	282	Economy	27900.00
0005433233456	282	Economy	27900.00
0005433233355	282	Economy	27900.00
0005432277773	282	Economy	27900.00
0005434551081	282	Economy	27900.00
0005434551087	282	Economy	27900.00
0005434725061	282	Economy	27900.00
0005434551090	282	Economy	27900.00
0005433126800	282	Economy	27900.00
0005433233838	282	Economy	27900.00
0005434725059	282	Economy	27900.00
0005433233462	282	Economy	27900.00
0005434725088	282	Economy	27900.00
0005433233406	282	Economy	27900.00
0005434302859	282	Economy	27900.00
0005433113506	282	Economy	27900.00
0005434550442	9862	Business	83700.00
0005435142427	9862	Business	83700.00
0005434724175	9862	Business	83700.00
0005434723989	9862	Business	83700.00
0005433233995	9862	Business	83700.00
0005434723720	9862	Business	83700.00
0005434724531	9862	Business	83700.00
0005433234038	9862	Business	83700.00
0005433233997	9862	Business	83700.00
0005434724377	9862	Business	83700.00
0005434724028	9862	Business	83700.00
0005433234009	9862	Business	83700.00
0005434731107	9862	Business	83700.00
0005434550594	9862	Business	83700.00
0005433234000	9862	Business	83700.00
0005434731122	9862	Business	83700.00
0005433234024	9862	Business	83700.00
0005433181017	9862	Business	83700.00
0005433289821	9862	Business	83700.00
0005434731125	9862	Business	83700.00
0005433181023	9862	Business	83700.00
0005434724490	9862	Business	83700.00
0005433233998	9862	Business	83700.00
0005434550548	9862	Comfort	47400.00
0005434550755	9862	Comfort	47400.00
0005434724208	9862	Comfort	47400.00
0005433234008	9862	Comfort	47400.00
0005433234017	9862	Comfort	47400.00
0005434550541	9862	Comfort	47400.00
0005433234015	9862	Comfort	47400.00
0005433233989	9862	Comfort	47400.00
0005434550611	9862	Comfort	47400.00
0005433234006	9862	Comfort	47400.00
0005433126830	9862	Comfort	47400.00
0005434550727	9862	Comfort	47400.00
0005433181025	9862	Comfort	47400.00
0005434723994	9862	Comfort	47400.00
0005435142402	9862	Comfort	47400.00
0005433181035	9862	Comfort	47400.00
0005434550402	9862	Comfort	47400.00
0005433234007	9862	Comfort	47400.00
0005434724062	9862	Comfort	47400.00
0005433234020	9862	Comfort	47400.00
0005433233985	9862	Comfort	47400.00
0005434723545	9862	Comfort	47400.00
0005434724155	9862	Comfort	47400.00
0005433233983	9862	Comfort	47400.00
0005433289825	9862	Comfort	47400.00
0005434302403	9862	Comfort	47400.00
0005433289820	9862	Comfort	47400.00
0005432199224	9862	Comfort	47400.00
0005434724259	9862	Comfort	47400.00
0005434723623	9862	Comfort	47400.00
0005433181012	9862	Economy	27900.00
0005434724040	9862	Economy	27900.00
0005433234002	9862	Economy	27900.00
0005434724218	9862	Economy	27900.00
0005434724278	9862	Economy	27900.00
0005434723408	9862	Economy	27900.00
0005433181020	9862	Economy	27900.00
0005433181013	9862	Economy	27900.00
0005434724203	9862	Economy	27900.00
0005434724170	9862	Economy	27900.00
0005433181015	9862	Economy	27900.00
0005434724346	9862	Economy	27900.00
0005434724137	9862	Economy	27900.00
0005433129262	9862	Economy	27900.00
0005434723648	9862	Economy	27900.00
0005434550453	9862	Economy	27900.00
0005434723991	9862	Economy	27900.00
0005434724057	9862	Economy	27900.00
0005434724177	9862	Economy	27900.00
0005433233991	9862	Economy	27900.00
0005434724285	9862	Economy	27900.00
0005434724336	9862	Economy	27900.00
0005434724239	9862	Economy	27900.00
0005434550425	9862	Economy	27900.00
0005433233996	9862	Economy	27900.00
0005433181033	9862	Economy	27900.00
0005433233990	9862	Economy	27900.00
0005434550706	9862	Economy	27900.00
0005433289823	9862	Economy	27900.00
0005433181029	9862	Economy	27900.00
0005433126833	9862	Economy	27900.00
0005434723885	9862	Economy	27900.00
0005435142384	9862	Economy	27900.00
0005433234018	9862	Economy	27900.00
0005433289826	9862	Economy	27900.00
0005434724240	9862	Economy	27900.00
0005434032010	9862	Economy	27900.00
0005434550873	9862	Economy	27900.00
0005434735629	9862	Economy	27900.00
0005434723911	9862	Economy	27900.00
0005433233993	9862	Economy	27900.00
0005434723888	9862	Economy	27900.00
0005434550551	9862	Economy	27900.00
0005433181027	9862	Economy	27900.00
0005434724012	9862	Economy	27900.00
0005434550609	9862	Economy	27900.00
0005434724139	9862	Economy	27900.00
0005434724128	9862	Economy	27900.00
0005433234031	9862	Economy	27900.00
0005433234044	9862	Economy	27900.00
0005433181026	9862	Economy	27900.00
0005433181028	9862	Economy	27900.00
0005434550651	9862	Economy	27900.00
0005434550695	9862	Economy	27900.00
0005434724484	9862	Economy	27900.00
0005434723917	9862	Economy	27900.00
0005434723600	9862	Economy	27900.00
0005433233999	9862	Economy	27900.00
0005434731118	9862	Economy	30700.00
0005433289827	9862	Economy	30700.00
0005433234030	9862	Economy	27900.00
0005433181021	9862	Economy	27900.00
0005434032013	9862	Economy	30700.00
0005434550440	9862	Economy	27900.00
0005433234001	9862	Economy	30700.00
0005433234025	9862	Economy	27900.00
0005433234042	9862	Economy	27900.00
0005434550385	9862	Economy	27900.00
0005435142369	9862	Economy	27900.00
0005433126834	9862	Economy	27900.00
0005434735631	9862	Economy	27900.00
0005434550610	9862	Economy	27900.00
0005434723948	9862	Economy	27900.00
0005433233988	9862	Economy	27900.00
0005434550636	9862	Economy	27900.00
0005433234040	9862	Economy	27900.00
0005434724206	9862	Economy	27900.00
0005434550489	9862	Economy	27900.00
0005433234034	9862	Economy	27900.00
0005434724173	9862	Economy	27900.00
0005433234013	9862	Economy	27900.00
0005434724277	9862	Economy	27900.00
0005434723828	9862	Economy	27900.00
0005433234021	9862	Economy	27900.00
0005434724174	9862	Economy	27900.00
0005433181014	9862	Economy	27900.00
0005434735602	9862	Economy	27900.00
0005433234028	9862	Economy	27900.00
0005434724138	9862	Economy	27900.00
0005433766630	9862	Economy	27900.00
0005434550534	9862	Economy	27900.00
0005434731126	9862	Economy	27900.00
0005434724286	9862	Economy	27900.00
0005434550356	9862	Economy	27900.00
0005434724607	9862	Economy	27900.00
0005434724396	9862	Economy	27900.00
0005434550705	9862	Economy	27900.00
0005434723621	9862	Economy	27900.00
0005434550533	9862	Economy	27900.00
0005434550452	9862	Economy	27900.00
0005433234026	9862	Economy	27900.00
0005434724004	9862	Economy	27900.00
0005434550650	9862	Economy	27900.00
0005434723967	9862	Economy	27900.00
0005433234033	9862	Economy	27900.00
0005434723972	9862	Economy	27900.00
0005433234029	9862	Economy	27900.00
0005432199225	9862	Economy	27900.00
0005434724179	9862	Economy	27900.00
0005434724089	9862	Economy	27900.00
0005434724470	9862	Economy	27900.00
0005434724236	9862	Economy	27900.00
0005434724258	9862	Economy	27900.00
0005434731138	9862	Economy	27900.00
0005433234005	9862	Economy	27900.00
0005434724467	9862	Economy	27900.00
0005434724445	9862	Economy	27900.00
0005435142426	9862	Economy	27900.00
0005433181019	9862	Economy	27900.00
0005434723771	9862	Economy	27900.00
0005434550696	9862	Economy	27900.00
0005434723620	9862	Economy	27900.00
0005434724204	9862	Economy	27900.00
0005434723854	9862	Economy	27900.00
0005434724599	9862	Economy	27900.00
0005434550437	9862	Economy	27900.00
0005434550726	9862	Economy	27900.00
0005433234016	9862	Economy	27900.00
0005434723566	9862	Economy	27900.00
0005434723999	9862	Economy	27900.00
0005434723546	9862	Economy	27900.00
0005433181022	9862	Economy	27900.00
0005434724337	9862	Economy	27900.00
0005433126829	9862	Economy	27900.00
0005433766629	9862	Economy	27900.00
0005434723804	9862	Economy	27900.00
0005433234011	9862	Economy	27900.00
0005434723889	9862	Economy	27900.00
0005433233987	9862	Economy	27900.00
0005433233986	9862	Economy	27900.00
0005433234010	9862	Economy	27900.00
0005433234035	9862	Economy	27900.00
0005434723910	9862	Economy	27900.00
0005434550704	9862	Economy	27900.00
0005433129260	9862	Economy	27900.00
0005434302402	9862	Economy	27900.00
0005434550436	9862	Economy	27900.00
0005433234023	9862	Economy	27900.00
0005433234045	9862	Economy	27900.00
0005434723998	9862	Economy	27900.00
0005434723844	9862	Economy	27900.00
0005434550545	9862	Economy	27900.00
0005434723715	9862	Economy	27900.00
0005434302400	9862	Economy	27900.00
0005434724241	9862	Economy	27900.00
0005434723624	9862	Economy	27900.00
0005433234039	9862	Economy	27900.00
0005434302399	9862	Economy	27900.00
0005434723873	9862	Economy	27900.00
0005434550454	9862	Economy	30700.00
0005433181024	9862	Economy	27900.00
0005434550467	9862	Economy	30700.00
0005434032012	9862	Economy	30700.00
0005434550546	9862	Economy	30700.00
0005433234012	9862	Economy	27900.00
0005434550475	9862	Economy	27900.00
0005433234037	9862	Economy	27900.00
0005434724257	9862	Economy	27900.00
0005433129261	9862	Economy	27900.00
0005434724207	9862	Economy	27900.00
0005434723837	9862	Economy	27900.00
0005434723599	9862	Economy	27900.00
0005434724148	9862	Economy	27900.00
0005433234036	9862	Economy	27900.00
0005433181031	9862	Economy	27900.00
0005434724172	9862	Economy	27900.00
0005434032011	9862	Economy	27900.00
0005434302381	9862	Economy	27900.00
0005434723532	9862	Economy	27900.00
0005435142432	9862	Economy	27900.00
0005434723976	9862	Economy	27900.00
0005433129263	9862	Economy	27900.00
0005434731127	9862	Economy	27900.00
0005434735632	9862	Economy	27900.00
0005434723973	9862	Economy	27900.00
0005434550649	9862	Economy	27900.00
0005435142392	9862	Economy	27900.00
0005432199229	9862	Economy	27900.00
0005433181018	9862	Economy	27900.00
0005434550535	9862	Economy	27900.00
0005433234004	9862	Economy	27900.00
0005433181011	9862	Economy	27900.00
0005433234043	9862	Economy	27900.00
0005434723587	9862	Economy	27900.00
0005434550593	9862	Economy	27900.00
0005432199226	9862	Economy	27900.00
0005433234041	9862	Economy	27900.00
0005434724345	9862	Economy	27900.00
0005434550431	9862	Economy	27900.00
0005433766628	9862	Economy	27900.00
0005433234014	9862	Economy	27900.00
0005434550466	9862	Economy	27900.00
0005433181034	9862	Economy	27900.00
0005433126832	9862	Economy	27900.00
0005433289822	9862	Economy	27900.00
0005434550679	9862	Economy	27900.00
0005433233994	9862	Economy	27900.00
0005434723886	9862	Economy	27900.00
0005434550510	9862	Economy	27900.00
0005434550741	9862	Economy	27900.00
0005433233984	9862	Economy	27900.00
0005433181032	9862	Economy	27900.00
0005434724661	9862	Economy	27900.00
0005434724145	9862	Economy	27900.00
0005433126831	9862	Economy	27900.00
0005434724397	9862	Economy	27900.00
0005435142357	9862	Economy	27900.00
0005432199223	9862	Economy	27900.00
0005434724176	9862	Economy	27900.00
0005433289824	9862	Economy	27900.00
0005433234027	9862	Economy	27900.00
0005433234022	9862	Economy	27900.00
0005435142364	9862	Economy	27900.00
0005434550441	9862	Economy	27900.00
0005434723698	9862	Economy	27900.00
0005434723988	9862	Economy	27900.00
0005434724378	9862	Economy	27900.00
0005434724008	9862	Economy	27900.00
0005434724662	9862	Economy	27900.00
0005434724573	9862	Economy	27900.00
0005432199228	9862	Economy	27900.00
0005433234046	9862	Economy	27900.00
0005433234003	9862	Economy	27900.00
0005434724314	9862	Economy	27900.00
0005434723872	9862	Economy	27900.00
0005433234019	9862	Economy	27900.00
0005434550433	9862	Economy	27900.00
0005432199227	9862	Economy	27900.00
0005434550403	9862	Economy	27900.00
0005433181016	9862	Economy	27900.00
0005434723753	9862	Economy	27900.00
0005433113529	9862	Economy	27900.00
0005435142393	9862	Economy	27900.00
0005434723853	9862	Economy	27900.00
0005434724379	9862	Economy	27900.00
0005433233992	9862	Economy	27900.00
0005435142412	9862	Economy	27900.00
0005433181030	9862	Economy	27900.00
0005434550487	9862	Economy	27900.00
0005434550540	9862	Economy	27900.00
0005433234032	9862	Economy	27900.00
0005434724280	9862	Economy	27900.00
0005434550604	9862	Economy	27900.00
0005435725545	7769	Business	42100.00
0005434067321	7769	Business	42100.00
0005432527643	7769	Business	42100.00
0005432527590	7769	Business	42100.00
0005432527600	7769	Business	42100.00
0005435212469	7769	Business	42100.00
0005435212716	7769	Business	42100.00
0005434067328	7769	Business	42100.00
0005432527596	7769	Business	42100.00
0005432527541	7769	Business	42100.00
0005432527540	7769	Business	42100.00
0005432527606	7769	Business	42100.00
0005432527551	7769	Business	42100.00
0005434067366	7769	Business	42100.00
0005434067322	7769	Business	42100.00
0005432527529	7769	Business	42100.00
0005432527537	7769	Business	42100.00
0005435212677	7769	Business	42100.00
0005434067312	7769	Business	42100.00
0005432527571	7769	Business	42100.00
0005434067341	7769	Business	42100.00
0005435212840	7769	Business	42100.00
0005435213151	7769	Comfort	23900.00
0005432527602	7769	Comfort	23900.00
0005435213005	7769	Comfort	23900.00
0005434067334	7769	Comfort	23900.00
0005432527538	7769	Comfort	23900.00
0005432069612	7769	Comfort	23900.00
0005434067325	7769	Comfort	23900.00
0005432527545	7769	Comfort	23900.00
0005432527615	7769	Comfort	23900.00
0005432527638	7769	Comfort	23900.00
0005434067365	7769	Comfort	23900.00
0005435212720	7769	Comfort	23900.00
0005432527539	7769	Comfort	23900.00
0005432527526	7769	Comfort	23900.00
0005432527562	7769	Comfort	23900.00
0005432527593	7769	Comfort	23900.00
0005434067332	7769	Comfort	23900.00
0005434067352	7769	Comfort	23900.00
0005434067329	7769	Comfort	23900.00
0005435212820	7769	Comfort	23900.00
0005432535818	7769	Comfort	23900.00
0005434067380	7769	Comfort	23900.00
0005434067330	7769	Comfort	23900.00
0005432527574	7769	Comfort	23900.00
0005434067353	7769	Comfort	23900.00
0005432535820	7769	Comfort	23900.00
0005435212893	7769	Comfort	23900.00
0005434067317	7769	Comfort	23900.00
0005434067344	7769	Comfort	23900.00
0005432527635	7769	Comfort	23900.00
0005432527565	7769	Comfort	23900.00
0005432527560	7769	Comfort	23900.00
0005434067315	7769	Comfort	23900.00
0005435725522	7769	Comfort	23900.00
0005435212807	7769	Comfort	23900.00
0005434067348	7769	Comfort	23900.00
0005434067331	7769	Comfort	23900.00
0005432527613	7769	Comfort	23900.00
0005435630932	7769	Comfort	23900.00
0005432527575	7769	Comfort	23900.00
0005432533284	7769	Economy	14000.00
0005435212749	7769	Economy	14000.00
0005432527522	7769	Economy	14000.00
0005435212741	7769	Economy	14000.00
0005434067333	7769	Economy	14000.00
0005434067357	7769	Economy	14000.00
0005435212454	7769	Economy	14000.00
0005435212499	7769	Economy	14000.00
0005432535821	7769	Economy	14000.00
0005432527616	7769	Economy	14000.00
0005432527644	7769	Economy	14000.00
0005434067360	7769	Economy	14000.00
0005432150168	7769	Economy	14000.00
0005435212721	7769	Economy	14000.00
0005432527548	7769	Economy	14000.00
0005435212631	7769	Economy	14000.00
0005434067375	7769	Economy	14000.00
0005432069610	7769	Economy	14000.00
0005432527612	7769	Economy	14000.00
0005434067374	7769	Economy	14000.00
0005434067316	7769	Economy	14000.00
0005434067356	7769	Economy	14000.00
0005432527557	7769	Economy	14000.00
0005435212915	7769	Economy	14000.00
0005435212616	7769	Economy	14000.00
0005432527516	7769	Economy	14000.00
0005432069608	7769	Economy	14000.00
0005432527520	7769	Economy	14000.00
0005432527561	7769	Economy	14000.00
0005432527598	7769	Economy	14000.00
0005432527605	7769	Economy	14000.00
0005432527618	7769	Economy	14000.00
0005434067338	7769	Economy	14000.00
0005432527597	7769	Economy	14000.00
0005432527589	7769	Economy	14000.00
0005432527599	7769	Economy	14000.00
0005434067355	7769	Economy	14000.00
0005432069614	7769	Economy	14000.00
0005434067358	7769	Economy	14000.00
0005432527519	7769	Economy	14000.00
0005434067363	7769	Economy	14000.00
0005432527634	7769	Economy	14000.00
0005432527591	7769	Economy	14000.00
0005432527611	7769	Economy	14000.00
0005435212632	7769	Economy	14000.00
0005435630930	7769	Economy	14000.00
0005432527514	7769	Economy	14000.00
0005432527534	7769	Economy	14000.00
0005432527627	7769	Economy	14000.00
0005435212570	7769	Economy	14000.00
0005432527633	7769	Economy	14000.00
0005432527521	7769	Economy	14000.00
0005435630931	7769	Economy	14000.00
0005434067340	7769	Economy	14000.00
0005434067351	7769	Economy	14000.00
0005432527576	7769	Economy	14000.00
0005432537052	7769	Economy	14000.00
0005435212748	7769	Economy	15400.00
0005434067349	7769	Economy	15400.00
0005432533282	7769	Economy	15400.00
0005432527536	7769	Economy	14000.00
0005432527604	7769	Economy	15400.00
0005432527553	7769	Economy	14000.00
0005432527566	7769	Economy	14000.00
0005432069611	7769	Economy	14000.00
0005432527573	7769	Economy	14000.00
0005432527595	7769	Economy	14000.00
0005432150169	7769	Economy	14000.00
0005432527577	7769	Economy	14000.00
0005435212455	7769	Economy	14000.00
0005432537051	7769	Economy	14000.00
0005434067350	7769	Economy	14000.00
0005434067311	7769	Economy	14000.00
0005435212742	7769	Economy	14000.00
0005432527586	7769	Economy	14000.00
0005435212615	7769	Economy	14000.00
0005435212949	7769	Economy	14000.00
0005434067370	7769	Economy	14000.00
0005434067347	7769	Economy	14000.00
0005432527547	7769	Economy	14000.00
0005435212795	7769	Economy	14000.00
0005435725525	7769	Economy	14000.00
0005432527631	7769	Economy	14000.00
0005435212806	7769	Economy	14000.00
0005432527552	7769	Economy	14000.00
0005434067382	7769	Economy	14000.00
0005432527609	7769	Economy	14000.00
0005432527625	7769	Economy	14000.00
0005432527531	7769	Economy	14000.00
0005432527601	7769	Economy	14000.00
0005432428919	7769	Economy	14000.00
0005432527583	7769	Economy	14000.00
0005433656624	7769	Economy	14000.00
0005432527617	7769	Economy	14000.00
0005432527549	7769	Economy	14000.00
0005432527581	7769	Economy	14000.00
0005432150167	7769	Economy	14000.00
0005435212848	7769	Economy	14000.00
0005434067314	7769	Economy	14000.00
0005432527630	7769	Economy	14000.00
0005432150173	7769	Economy	14000.00
0005435212809	7769	Economy	14000.00
0005432527542	7769	Economy	14000.00
0005435212651	7769	Economy	14000.00
0005432527568	7769	Economy	14000.00
0005435212690	7769	Economy	14000.00
0005435212783	7769	Economy	14000.00
0005434067371	7769	Economy	14000.00
0005432069615	7769	Economy	14000.00
0005435212494	7769	Economy	14000.00
0005435212739	7769	Economy	14000.00
0005434067369	7769	Economy	14000.00
0005434067368	7769	Economy	14000.00
0005435212506	7769	Economy	14000.00
0005435212811	7769	Economy	14000.00
0005435212682	7769	Economy	14000.00
0005432527523	7769	Economy	14000.00
0005432527528	7769	Economy	14000.00
0005434067367	7769	Economy	14000.00
0005432527624	7769	Economy	14000.00
0005432527620	7769	Economy	14000.00
0005435212495	7769	Economy	14000.00
0005432527642	7769	Economy	14000.00
0005435212885	7769	Economy	14000.00
0005432069603	7769	Economy	14000.00
0005432428918	7769	Economy	14000.00
0005434067354	7769	Economy	14000.00
0005432527515	7769	Economy	14000.00
0005435212654	7769	Economy	14000.00
0005432527550	7769	Economy	14000.00
0005435212850	7769	Economy	14000.00
0005432527628	7769	Economy	14000.00
0005432069613	7769	Economy	14000.00
0005432527544	7769	Economy	14000.00
0005432527632	7769	Economy	14000.00
0005432527546	7769	Economy	14000.00
0005432527636	7769	Economy	14000.00
0005432069606	7769	Economy	14000.00
0005435212765	7769	Economy	14000.00
0005432527559	7769	Economy	14000.00
0005435212545	7769	Economy	14000.00
0005432527556	7769	Economy	14000.00
0005432527543	7769	Economy	14000.00
0005434067339	7769	Economy	14000.00
0005432527530	7769	Economy	14000.00
0005432527570	7769	Economy	14000.00
0005434067318	7769	Economy	14000.00
0005432527579	7769	Economy	14000.00
0005434067335	7769	Economy	14000.00
0005432527645	7769	Economy	14000.00
0005432527641	7769	Economy	14000.00
0005432527558	7769	Economy	14000.00
0005434067359	7769	Economy	14000.00
0005435212802	7769	Economy	14000.00
0005432535817	7769	Economy	14000.00
0005432527585	7769	Economy	15400.00
0005435212505	7769	Economy	15400.00
0005435212425	7769	Economy	15400.00
0005432069605	7769	Economy	15400.00
0005435212740	7769	Economy	15400.00
0005432533283	7769	Economy	15400.00
0005432527587	7769	Economy	14000.00
0005434067336	7769	Economy	14000.00
0005435212789	7769	Economy	14000.00
0005434067361	7769	Economy	14000.00
0005435212546	7769	Economy	14000.00
0005432150174	7769	Economy	14000.00
0005432527588	7769	Economy	14000.00
0005432527564	7769	Economy	14000.00
0005435212948	7769	Economy	14000.00
0005435725546	7769	Economy	14000.00
0005435212808	7769	Economy	14000.00
0005435212569	7769	Economy	14000.00
0005434067323	7769	Economy	14000.00
0005435212849	7769	Economy	14000.00
0005432527608	7769	Economy	14000.00
0005435725526	7769	Economy	14000.00
0005434067377	7769	Economy	14000.00
0005432527619	7769	Economy	14000.00
0005434067313	7769	Economy	14000.00
0005432527535	7769	Economy	14000.00
0005434067362	7769	Economy	14000.00
0005432150166	7769	Economy	14000.00
0005432527582	7769	Economy	14000.00
0005434067383	7769	Economy	14000.00
0005434067327	7769	Economy	14000.00
0005434067324	7769	Economy	14000.00
0005432527572	7769	Economy	14000.00
0005434067364	7769	Economy	14000.00
0005432527555	7769	Economy	14000.00
0005434067372	7769	Economy	14000.00
0005435630943	7769	Economy	14000.00
0005434067345	7769	Economy	14000.00
0005434067379	7769	Economy	14000.00
0005432069604	7769	Economy	14000.00
0005432069609	7769	Economy	14000.00
0005435212424	7769	Economy	14000.00
0005432150171	7769	Economy	14000.00
0005434067346	7769	Economy	14000.00
0005435212764	7769	Economy	14000.00
0005435212426	7769	Economy	14000.00
0005432527640	7769	Economy	14000.00
0005434067320	7769	Economy	14000.00
0005435213101	7769	Economy	14000.00
0005432527626	7769	Economy	14000.00
0005434067343	7769	Economy	14000.00
0005432527563	7769	Economy	14000.00
0005432527532	7769	Economy	14000.00
0005432527594	7769	Economy	14000.00
0005432527629	7769	Economy	14000.00
0005432527603	7769	Economy	14000.00
0005432527637	7769	Economy	14000.00
0005432527584	7769	Economy	14000.00
0005432428916	7769	Economy	14000.00
0005435630919	7769	Economy	14000.00
0005432527622	7769	Economy	14000.00
0005434067373	7769	Economy	14000.00
0005432527623	7769	Economy	14000.00
0005432527621	7769	Economy	14000.00
0005432527554	7769	Economy	14000.00
0005432527607	7769	Economy	14000.00
0005432527518	7769	Economy	14000.00
0005432069617	7769	Economy	14000.00
0005432535819	7769	Economy	14000.00
0005432527592	7769	Economy	14000.00
0005434067342	7769	Economy	14000.00
0005435212468	7769	Economy	14000.00
0005434067319	7769	Economy	14000.00
0005432527533	7769	Economy	14000.00
0005432428917	7769	Economy	14000.00
0005432527525	7769	Economy	14000.00
0005434067326	7769	Economy	14000.00
0005432527639	7769	Economy	14000.00
0005432527517	7769	Economy	14000.00
0005435212678	7769	Economy	14000.00
0005434067378	7769	Economy	14000.00
0005432069607	7769	Economy	14000.00
0005434067337	7769	Economy	14000.00
0005432069616	7769	Economy	14000.00
0005432150170	7769	Economy	14000.00
0005432527524	7769	Economy	14000.00
0005432527513	7769	Economy	14000.00
0005435212763	7769	Economy	14000.00
0005432527578	7769	Economy	14000.00
0005432527527	7769	Economy	14000.00
0005435212983	7769	Economy	14000.00
0005432527567	7769	Economy	14000.00
0005435212738	7769	Economy	14000.00
0005432527580	7769	Economy	14000.00
0005432150172	7769	Economy	14000.00
0005432527610	7769	Economy	14000.00
0005434067381	7769	Economy	14000.00
0005435212878	7769	Economy	14000.00
0005434067376	7769	Economy	14000.00
0005432527569	7769	Economy	14000.00
0005432527614	7769	Economy	14000.00
0005432363380	5356	Business	43100.00
0005435423944	5356	Business	43100.00
0005434344106	5356	Business	43100.00
0005434344103	5356	Business	43100.00
0005434573315	5356	Business	43100.00
0005435613268	5356	Business	43100.00
0005434344120	5356	Business	43100.00
0005435613272	5356	Business	43100.00
0005435424182	5356	Business	43100.00
0005435613300	5356	Business	43100.00
0005432133170	5356	Business	43100.00
0005435555362	5356	Business	43100.00
0005435613351	5356	Business	43100.00
0005435613366	5356	Business	43100.00
0005435613313	5356	Business	43100.00
0005435613273	5356	Business	43100.00
0005432133158	5356	Business	43100.00
0005435613345	5356	Business	43100.00
0005435302163	5356	Business	43100.00
0005432047537	5356	Business	43100.00
0005434344117	5356	Business	43100.00
0005434344101	5356	Business	43100.00
0005435613357	5356	Business	43100.00
0005435319501	5356	Business	43100.00
0005435424096	5356	Business	43100.00
0005434573308	5356	Business	43100.00
0005435613317	5356	Business	43100.00
0005434244595	5356	Business	43100.00
0005434344116	5356	Comfort	24400.00
0005435613270	5356	Business	43100.00
0005435613323	5356	Comfort	24400.00
0005434344104	5356	Comfort	24400.00
0005435423959	5356	Comfort	24400.00
0005435613304	5356	Comfort	24400.00
0005435613286	5356	Comfort	24400.00
0005434656537	5356	Comfort	24400.00
0005434244628	5356	Comfort	24400.00
0005434244565	5356	Comfort	24400.00
0005435613294	5356	Comfort	24400.00
0005435613353	5356	Comfort	24400.00
0005435613285	5356	Comfort	24400.00
0005434573317	5356	Comfort	24400.00
0005433719092	5356	Comfort	24400.00
0005434656535	5356	Comfort	24400.00
0005435302162	5356	Comfort	24400.00
0005434344130	5356	Comfort	24400.00
0005435613314	5356	Comfort	24400.00
0005435424055	5356	Comfort	24400.00
0005435424082	5356	Comfort	24400.00
0005435613335	5356	Comfort	24400.00
0005435613275	5356	Comfort	24400.00
0005432133173	5356	Comfort	24400.00
0005435613336	5356	Comfort	24400.00
0005435424383	5356	Comfort	24400.00
0005435613258	5356	Comfort	24400.00
0005435613292	5356	Comfort	24400.00
0005435613289	5356	Comfort	24400.00
0005435613348	5356	Comfort	24400.00
0005435613309	5356	Comfort	24400.00
0005435319490	5356	Comfort	24400.00
0005434344110	5356	Comfort	24400.00
0005432133161	5356	Comfort	24400.00
0005435424079	5356	Comfort	24400.00
0005432047541	5356	Comfort	24400.00
0005435097176	5356	Comfort	24400.00
0005435097175	5356	Comfort	24400.00
0005434344123	5356	Comfort	24400.00
0005434244641	5356	Comfort	24400.00
0005432133169	5356	Comfort	24400.00
0005435613341	5356	Comfort	24400.00
0005435613261	5356	Comfort	24400.00
0005435613338	5356	Economy	14400.00
0005435424382	5356	Economy	14400.00
0005435423957	5356	Economy	14400.00
0005435380256	5356	Economy	14400.00
0005435613355	5356	Economy	14400.00
0005433719084	5356	Economy	14400.00
0005434244759	5356	Economy	14400.00
0005434244644	5356	Economy	14400.00
0005435319437	5356	Economy	14400.00
0005434344126	5356	Economy	14400.00
0005435424454	5356	Economy	14400.00
0005435423962	5356	Economy	14400.00
0005435380239	5356	Economy	14400.00
0005435490216	5356	Economy	14400.00
0005435424150	5356	Economy	14400.00
0005435613260	5356	Economy	14400.00
0005435613344	5356	Economy	14400.00
0005432840989	5356	Economy	14400.00
0005435423993	5356	Economy	14400.00
0005435613361	5356	Economy	14400.00
0005432840990	5356	Economy	14400.00
0005435424025	5356	Economy	14400.00
0005435613277	5356	Economy	14400.00
0005434344099	5356	Economy	14400.00
0005435613274	5356	Economy	14400.00
0005435423832	5356	Economy	14400.00
0005435424188	5356	Economy	14400.00
0005435613346	5356	Economy	14400.00
0005435613278	5356	Economy	14400.00
0005435613282	5356	Economy	14400.00
0005435424015	5356	Economy	14400.00
0005432133163	5356	Economy	14400.00
0005435424259	5356	Economy	14400.00
0005434244760	5356	Economy	14400.00
0005435613310	5356	Economy	14400.00
0005435613329	5356	Economy	14400.00
0005435319469	5356	Economy	14400.00
0005433719110	5356	Economy	14400.00
0005435613297	5356	Economy	14400.00
0005435613298	5356	Economy	14400.00
0005434244723	5356	Economy	14400.00
0005432363376	5356	Economy	14400.00
0005435613354	5356	Economy	14400.00
0005435423928	5356	Economy	14400.00
0005435097172	5356	Economy	14400.00
0005435424044	5356	Economy	14400.00
0005434344119	5356	Economy	14400.00
0005434656536	5356	Economy	14400.00
0005435097178	5356	Economy	14400.00
0005435424371	5356	Economy	14400.00
0005434244772	5356	Economy	14400.00
0005435424196	5356	Economy	14400.00
0005434244630	5356	Economy	14400.00
0005435613307	5356	Economy	14400.00
0005435423949	5356	Economy	14400.00
0005434344127	5356	Economy	14400.00
0005434344124	5356	Economy	14400.00
0005435097177	5356	Economy	14400.00
0005432133165	5356	Economy	14400.00
0005435613372	5356	Economy	14400.00
0005434573304	5356	Economy	14400.00
0005432047542	5356	Economy	14400.00
0005435613290	5356	Economy	14400.00
0005435613271	5356	Economy	14400.00
0005435613362	5356	Economy	15800.00
0005435424463	5356	Economy	15800.00
0005435613365	5356	Economy	15800.00
0005434344131	5356	Economy	14400.00
0005434573307	5356	Economy	14400.00
0005434244629	5356	Economy	14400.00
0005434244585	5356	Economy	15800.00
0005435613259	5356	Economy	14400.00
0005435613305	5356	Economy	15800.00
0005432047538	5356	Economy	14400.00
0005435613267	5356	Economy	15800.00
0005434573311	5356	Economy	14400.00
0005435613358	5356	Economy	14400.00
0005434344111	5356	Economy	14400.00
0005434344135	5356	Economy	14400.00
0005434244533	5356	Economy	14400.00
0005435613319	5356	Economy	14400.00
0005434244499	5356	Economy	14400.00
0005435424230	5356	Economy	14400.00
0005435613320	5356	Economy	14400.00
0005435613343	5356	Economy	14400.00
0005434244596	5356	Economy	14400.00
0005435423882	5356	Economy	14400.00
0005435423871	5356	Economy	14400.00
0005435613308	5356	Economy	14400.00
0005435613303	5356	Economy	14400.00
0005432133172	5356	Economy	14400.00
0005434573306	5356	Economy	14400.00
0005435613359	5356	Economy	14400.00
0005435424396	5356	Economy	14400.00
0005435613279	5356	Economy	14400.00
0005435613333	5356	Economy	14400.00
0005435302137	5356	Economy	14400.00
0005432133168	5356	Economy	14400.00
0005435613302	5356	Economy	14400.00
0005435424099	5356	Economy	14400.00
0005432047540	5356	Economy	14400.00
0005434573309	5356	Economy	14400.00
0005434244688	5356	Economy	14400.00
0005435613364	5356	Economy	14400.00
0005435423777	5356	Economy	14400.00
0005435424059	5356	Economy	14400.00
0005434573314	5356	Economy	14400.00
0005435302149	5356	Economy	14400.00
0005435423961	5356	Economy	14400.00
0005434244587	5356	Economy	14400.00
0005434244724	5356	Economy	14400.00
0005434244655	5356	Economy	14400.00
0005435613371	5356	Economy	14400.00
0005434344112	5356	Economy	14400.00
0005435613360	5356	Economy	14400.00
0005434244773	5356	Economy	14400.00
0005434244505	5356	Economy	14400.00
0005434344121	5356	Economy	14400.00
0005435423607	5356	Economy	14400.00
0005435613291	5356	Economy	14400.00
0005434244591	5356	Economy	14400.00
0005435424125	5356	Economy	14400.00
0005435613340	5356	Economy	14400.00
0005435613296	5356	Economy	14400.00
0005434344128	5356	Economy	14400.00
0005432133171	5356	Economy	14400.00
0005435423958	5356	Economy	14400.00
0005435613315	5356	Economy	14400.00
0005435424014	5356	Economy	14400.00
0005434244761	5356	Economy	14400.00
0005435613265	5356	Economy	14400.00
0005435424081	5356	Economy	14400.00
0005435613306	5356	Economy	14400.00
0005435424232	5356	Economy	14400.00
0005435424058	5356	Economy	14400.00
0005434573310	5356	Economy	14400.00
0005435613266	5356	Economy	14400.00
0005432133157	5356	Economy	14400.00
0005435424129	5356	Economy	14400.00
0005434344113	5356	Economy	14400.00
0005434344133	5356	Economy	14400.00
0005434244506	5356	Economy	14400.00
0005435613311	5356	Economy	14400.00
0005435613368	5356	Economy	14400.00
0005435424142	5356	Economy	14400.00
0005434344100	5356	Economy	14400.00
0005435613283	5356	Economy	14400.00
0005435613332	5356	Economy	14400.00
0005434244642	5356	Economy	14400.00
0005435613264	5356	Economy	14400.00
0005433719108	5356	Economy	14400.00
0005435613325	5356	Economy	14400.00
0005432133167	5356	Economy	14400.00
0005434244654	5356	Economy	14400.00
0005435302140	5356	Economy	14400.00
0005434344108	5356	Economy	14400.00
0005435613367	5356	Economy	14400.00
0005434344118	5356	Economy	14400.00
0005434573313	5356	Economy	14400.00
0005435319436	5356	Economy	14400.00
0005435424395	5356	Economy	14400.00
0005432363382	5356	Economy	14400.00
0005435423675	5356	Economy	14400.00
0005435613326	5356	Economy	14400.00
0005435613293	5356	Economy	14400.00
0005434344107	5356	Economy	14400.00
0005435424203	5356	Economy	14400.00
0005435613263	5356	Economy	14400.00
0005435424302	5356	Economy	14400.00
0005435613349	5356	Economy	14400.00
0005435613356	5356	Economy	14400.00
0005435424095	5356	Economy	14400.00
0005435613280	5356	Economy	15800.00
0005434573312	5356	Economy	15800.00
0005433719094	5356	Economy	15800.00
0005434344129	5356	Economy	15800.00
0005432047539	5356	Economy	15800.00
0005435613331	5356	Economy	14400.00
0005434344125	5356	Economy	15800.00
0005435613321	5356	Economy	14400.00
0005435613276	5356	Economy	14400.00
0005435424128	5356	Economy	14400.00
0005435613350	5356	Economy	14400.00
0005435613301	5356	Economy	14400.00
0005435424080	5356	Economy	14400.00
0005435424141	5356	Economy	14400.00
0005435424189	5356	Economy	14400.00
0005435613288	5356	Economy	14400.00
0005435613299	5356	Economy	14400.00
0005435097174	5356	Economy	14400.00
0005434244600	5356	Economy	14400.00
0005433719093	5356	Economy	14400.00
0005434344114	5356	Economy	14400.00
0005435380255	5356	Economy	14400.00
0005435613328	5356	Economy	14400.00
0005434244631	5356	Economy	14400.00
0005435302152	5356	Economy	14400.00
0005434656526	5356	Economy	14400.00
0005435424204	5356	Economy	14400.00
0005434244689	5356	Economy	14400.00
0005435613281	5356	Economy	14400.00
0005434244771	5356	Economy	14400.00
0005435423994	5356	Economy	14400.00
0005435424370	5356	Economy	14400.00
0005435097173	5356	Economy	14400.00
0005435424271	5356	Economy	14400.00
0005435613337	5356	Economy	14400.00
0005435613295	5356	Economy	14400.00
0005435423792	5356	Economy	14400.00
0005435424086	5356	Economy	14400.00
0005432133159	5356	Economy	14400.00
0005434244532	5356	Economy	14400.00
0005432133166	5356	Economy	14400.00
0005434244504	5356	Economy	14400.00
0005435424303	5356	Economy	14400.00
0005435424169	5356	Economy	14400.00
0005435302139	5356	Economy	14400.00
0005434344109	5356	Economy	14400.00
0005435423770	5356	Economy	14400.00
0005435491433	5356	Economy	14400.00
0005435613269	5356	Economy	14400.00
0005434344105	5356	Economy	14400.00
0005435424026	5356	Economy	14400.00
0005435491434	5356	Economy	14400.00
0005434344115	5356	Economy	14400.00
0005435319441	5356	Economy	14400.00
0005434573305	5356	Economy	14400.00
0005432133160	5356	Economy	14400.00
0005435613262	5356	Economy	14400.00
0005435424153	5356	Economy	14400.00
0005434344122	5356	Economy	14400.00
0005435613352	5356	Economy	14400.00
0005435613342	5356	Economy	14400.00
0005435613363	5356	Economy	14400.00
0005432133162	5356	Economy	14400.00
0005435423915	5356	Economy	14400.00
0005435613334	5356	Economy	14400.00
0005433719103	5356	Economy	14400.00
0005434656534	5356	Economy	14400.00
0005435424455	5356	Economy	14400.00
0005435097180	5356	Economy	14400.00
0005434244605	5356	Economy	14400.00
0005435613327	5356	Economy	14400.00
0005435613318	5356	Economy	14400.00
0005435302161	5356	Economy	14400.00
0005435423881	5356	Economy	14400.00
0005435424231	5356	Economy	14400.00
0005434344132	5356	Economy	14400.00
0005435490217	5356	Economy	14400.00
0005435613322	5356	Economy	14400.00
0005435302141	5356	Economy	14400.00
0005435613287	5356	Economy	14400.00
0005434344134	5356	Economy	14400.00
0005435613370	5356	Economy	14400.00
0005432363381	5356	Economy	14400.00
0005434573316	5356	Economy	14400.00
0005435613316	5356	Economy	14400.00
0005435424181	5356	Economy	14400.00
0005435613324	5356	Economy	14400.00
0005435097179	5356	Economy	14400.00
0005432133164	5356	Economy	14400.00
0005435613312	5356	Economy	14400.00
0005435424183	5356	Economy	14400.00
0005434344102	5356	Economy	14400.00
0005435613330	5356	Economy	14400.00
0005435613284	5356	Economy	14400.00
0005435613339	5356	Economy	14400.00
0005433719109	5356	Economy	14400.00
0005435423956	5356	Economy	14400.00
0005435613347	5356	Economy	14400.00
0005434244780	5356	Economy	14400.00
0005434244621	5356	Economy	14400.00
0005435613369	5356	Economy	14400.00
0005432363406	10929	Business	43100.00
0005435305009	10929	Business	43100.00
0005435612127	10929	Business	43100.00
0005435611910	10929	Business	43100.00
0005435424576	10929	Business	43100.00
0005435424612	10929	Business	43100.00
0005435424584	10929	Business	43100.00
0005435612582	10929	Business	43100.00
0005434244886	10929	Business	43100.00
0005434244889	10929	Business	43100.00
0005435612724	10929	Business	43100.00
0005435612155	10929	Business	43100.00
0005435380280	10929	Business	43100.00
0005435612318	10929	Business	43100.00
0005435424606	10929	Business	43100.00
0005434244897	10929	Business	43100.00
0005435612505	10929	Business	43100.00
0005435612333	10929	Business	43100.00
0005435612179	10929	Business	43100.00
0005435424597	10929	Business	43100.00
0005435424570	10929	Business	43100.00
0005435612591	10929	Business	43100.00
0005435424567	10929	Business	43100.00
0005435490180	10929	Business	43100.00
0005433719131	10929	Business	43100.00
0005435424596	10929	Comfort	24400.00
0005435612478	10929	Business	43100.00
0005435490179	10929	Comfort	24400.00
0005435380275	10929	Comfort	24400.00
0005434343668	10929	Comfort	24400.00
0005435424581	10929	Comfort	24400.00
0005435319549	10929	Comfort	24400.00
0005434343869	10929	Comfort	24400.00
0005435424564	10929	Comfort	24400.00
0005435611797	10929	Comfort	24400.00
0005435490188	10929	Comfort	24400.00
0005434244877	10929	Comfort	24400.00
0005435612670	10929	Comfort	24400.00
0005435097110	10929	Comfort	24400.00
0005434343758	10929	Comfort	24400.00
0005435424568	10929	Comfort	24400.00
0005435424607	10929	Comfort	24400.00
0005434244900	10929	Comfort	24400.00
0005435612178	10929	Comfort	24400.00
0005434343618	10929	Comfort	24400.00
0005435612364	10929	Comfort	24400.00
0005435424587	10929	Comfort	24400.00
0005434244876	10929	Comfort	24400.00
0005435612286	10929	Comfort	24400.00
0005435611782	10929	Comfort	24400.00
0005435612189	10929	Comfort	24400.00
0005434573202	10929	Comfort	24400.00
0005432165016	10929	Comfort	24400.00
0005435612397	10929	Comfort	24400.00
0005435424627	10929	Comfort	24400.00
0005435042850	10929	Comfort	24400.00
0005435424580	10929	Comfort	24400.00
0005432841008	10929	Comfort	24400.00
0005434343895	10929	Comfort	24400.00
0005435612507	10929	Comfort	24400.00
0005434343759	10929	Comfort	24400.00
0005435612112	10929	Comfort	24400.00
0005434244883	10929	Comfort	24400.00
0005435097095	10929	Comfort	24400.00
0005432363407	10929	Economy	14400.00
0005435424566	10929	Economy	14400.00
0005432841006	10929	Economy	14400.00
0005435424594	10929	Economy	14400.00
0005434244881	10929	Economy	14400.00
0005435612510	10929	Economy	14400.00
0005435319548	10929	Economy	14400.00
0005434244895	10929	Economy	14400.00
0005435424590	10929	Economy	14400.00
0005434244894	10929	Economy	14400.00
0005432166891	10929	Economy	14400.00
0005435424578	10929	Economy	14400.00
0005435424632	10929	Economy	14400.00
0005435612204	10929	Economy	14400.00
0005435612566	10929	Economy	14400.00
0005435424614	10929	Economy	14400.00
0005435424609	10929	Economy	14400.00
0005435424572	10929	Economy	14400.00
0005435424600	10929	Economy	14400.00
0005435424575	10929	Economy	14400.00
0005434573152	10929	Economy	14400.00
0005435555348	10929	Economy	14400.00
0005433719133	10929	Economy	14400.00
0005434244901	10929	Economy	14400.00
0005435611956	10929	Economy	14400.00
0005434573137	10929	Economy	14400.00
0005435424602	10929	Economy	14400.00
0005435424608	10929	Economy	14400.00
0005435612180	10929	Economy	14400.00
0005435612402	10929	Economy	14400.00
0005434343765	10929	Economy	14400.00
0005435424563	10929	Economy	14400.00
0005434244899	10929	Economy	14400.00
0005435424573	10929	Economy	14400.00
0005434656549	10929	Economy	14400.00
0005435612534	10929	Economy	14400.00
0005435612366	10929	Economy	14400.00
0005435612165	10929	Economy	14400.00
0005435424623	10929	Economy	14400.00
0005435612527	10929	Economy	14400.00
0005435424595	10929	Economy	14400.00
0005434343713	10929	Economy	14400.00
0005435612469	10929	Economy	14400.00
0005435612416	10929	Economy	14400.00
0005435612053	10929	Economy	14400.00
0005434244887	10929	Economy	14400.00
0005434573149	10929	Economy	14400.00
0005434244882	10929	Economy	14400.00
0005435424574	10929	Economy	14400.00
0005435612186	10929	Economy	14400.00
0005434244879	10929	Economy	14400.00
0005432165015	10929	Economy	14400.00
0005432165014	10929	Economy	14400.00
0005435612037	10929	Economy	14400.00
0005435612464	10929	Economy	14400.00
0005435612462	10929	Economy	14400.00
0005434244905	10929	Economy	14400.00
0005435612301	10929	Economy	14400.00
0005435424626	10929	Economy	14400.00
0005435612063	10929	Economy	14400.00
0005435424622	10929	Economy	14400.00
0005435612188	10929	Economy	14400.00
0005435304142	10929	Economy	14400.00
0005435612403	10929	Economy	14400.00
0005435424613	10929	Economy	15800.00
0005435424617	10929	Economy	14400.00
0005435424611	10929	Economy	14400.00
0005435304139	10929	Economy	15800.00
0005435612338	10929	Economy	14400.00
0005435612384	10929	Economy	14400.00
0005434343726	10929	Economy	14400.00
0005435612705	10929	Economy	15800.00
0005435424583	10929	Economy	15800.00
0005435612192	10929	Economy	15800.00
0005434244891	10929	Economy	14400.00
0005435042848	10929	Economy	14400.00
0005434244898	10929	Economy	14400.00
0005435424631	10929	Economy	14400.00
0005435424621	10929	Economy	14400.00
0005435612358	10929	Economy	14400.00
0005435612281	10929	Economy	14400.00
0005435319543	10929	Economy	14400.00
0005435424625	10929	Economy	14400.00
0005434244878	10929	Economy	14400.00
0005435424629	10929	Economy	14400.00
0005434343712	10929	Economy	14400.00
0005434343751	10929	Economy	14400.00
0005435424562	10929	Economy	14400.00
0005435611947	10929	Economy	14400.00
0005435612036	10929	Economy	14400.00
0005435612413	10929	Economy	14400.00
0005434244884	10929	Economy	14400.00
0005434244875	10929	Economy	14400.00
0005434573182	10929	Economy	14400.00
0005435319542	10929	Economy	14400.00
0005435612443	10929	Economy	14400.00
0005435612114	10929	Economy	14400.00
0005434244903	10929	Economy	14400.00
0005435490178	10929	Economy	14400.00
0005435319546	10929	Economy	14400.00
0005435319547	10929	Economy	14400.00
0005435612528	10929	Economy	14400.00
0005435380277	10929	Economy	14400.00
0005435612422	10929	Economy	14400.00
0005434343807	10929	Economy	14400.00
0005435612592	10929	Economy	14400.00
0005434343781	10929	Economy	14400.00
0005435612439	10929	Economy	14400.00
0005435612111	10929	Economy	14400.00
0005435612062	10929	Economy	14400.00
0005435304143	10929	Economy	14400.00
0005434244896	10929	Economy	14400.00
0005435612725	10929	Economy	14400.00
0005435612581	10929	Economy	14400.00
0005435612317	10929	Economy	14400.00
0005432166890	10929	Economy	14400.00
0005435611733	10929	Economy	14400.00
0005434573233	10929	Economy	14400.00
0005435424598	10929	Economy	14400.00
0005435491415	10929	Economy	14400.00
0005433719129	10929	Economy	14400.00
0005434244880	10929	Economy	14400.00
0005434244902	10929	Economy	14400.00
0005434573227	10929	Economy	14400.00
0005434343733	10929	Economy	14400.00
0005435612061	10929	Economy	14400.00
0005434573142	10929	Economy	14400.00
0005435612113	10929	Economy	14400.00
0005435380279	10929	Economy	14400.00
0005435305007	10929	Economy	14400.00
0005435612154	10929	Economy	14400.00
0005435491419	10929	Economy	14400.00
0005435612460	10929	Economy	14400.00
0005435612530	10929	Economy	14400.00
0005432165013	10929	Economy	14400.00
0005434573138	10929	Economy	14400.00
0005434573169	10929	Economy	14400.00
0005435305008	10929	Economy	14400.00
0005434343778	10929	Economy	14400.00
0005435612782	10929	Economy	14400.00
0005435612618	10929	Economy	14400.00
0005435612533	10929	Economy	14400.00
0005435612457	10929	Economy	14400.00
0005435097050	10929	Economy	14400.00
0005434343867	10929	Economy	14400.00
0005434573228	10929	Economy	14400.00
0005435424615	10929	Economy	14400.00
0005435612349	10929	Economy	14400.00
0005435424571	10929	Economy	14400.00
0005435612444	10929	Economy	14400.00
0005434343811	10929	Economy	14400.00
0005435319541	10929	Economy	14400.00
0005434343725	10929	Economy	14400.00
0005435612704	10929	Economy	14400.00
0005435612128	10929	Economy	14400.00
0005435612463	10929	Economy	14400.00
0005434573143	10929	Economy	14400.00
0005435612404	10929	Economy	14400.00
0005435304144	10929	Economy	14400.00
0005435424585	10929	Economy	14400.00
0005433719132	10929	Economy	14400.00
0005435424630	10929	Economy	14400.00
0005435424593	10929	Economy	14400.00
0005435612243	10929	Economy	14400.00
0005434656551	10929	Economy	14400.00
0005435612304	10929	Economy	14400.00
0005434343796	10929	Economy	14400.00
0005435424586	10929	Economy	15800.00
0005435612197	10929	Economy	15800.00
0005435380278	10929	Economy	15800.00
0005435424616	10929	Economy	14400.00
0005435612390	10929	Economy	14400.00
0005435424610	10929	Economy	14400.00
0005435612365	10929	Economy	14400.00
0005435042851	10929	Economy	14400.00
0005435612565	10929	Economy	14400.00
0005435424601	10929	Economy	14400.00
0005435611983	10929	Economy	14400.00
0005435612511	10929	Economy	14400.00
0005435319545	10929	Economy	14400.00
0005434244893	10929	Economy	14400.00
0005432166892	10929	Economy	14400.00
0005435424619	10929	Economy	14400.00
0005435424589	10929	Economy	14400.00
0005434244892	10929	Economy	14400.00
0005432841007	10929	Economy	14400.00
0005435612298	10929	Economy	14400.00
0005434343868	10929	Economy	14400.00
0005435612445	10929	Economy	14400.00
0005435097111	10929	Economy	14400.00
0005435612334	10929	Economy	14400.00
0005435424582	10929	Economy	14400.00
0005434343661	10929	Economy	14400.00
0005435319544	10929	Economy	14400.00
0005435612448	10929	Economy	14400.00
0005435424618	10929	Economy	14400.00
0005435612008	10929	Economy	14400.00
0005435612691	10929	Economy	14400.00
0005435612535	10929	Economy	14400.00
0005434244904	10929	Economy	14400.00
0005435424565	10929	Economy	14400.00
0005435612129	10929	Economy	14400.00
0005434343817	10929	Economy	14400.00
0005435612242	10929	Economy	14400.00
0005435612451	10929	Economy	14400.00
0005435424605	10929	Economy	14400.00
0005435612564	10929	Economy	14400.00
0005434656550	10929	Economy	14400.00
0005435424588	10929	Economy	14400.00
0005434573146	10929	Economy	14400.00
0005435424579	10929	Economy	14400.00
0005434343810	10929	Economy	14400.00
0005434343698	10929	Economy	14400.00
0005435612150	10929	Economy	14400.00
0005435424628	10929	Economy	14400.00
0005435424569	10929	Economy	14400.00
0005434343816	10929	Economy	14400.00
0005435042849	10929	Economy	14400.00
0005435612282	10929	Economy	14400.00
0005434573201	10929	Economy	14400.00
0005435612421	10929	Economy	14400.00
0005435612160	10929	Economy	14400.00
0005435612051	10929	Economy	14400.00
0005434343808	10929	Economy	14400.00
0005435380276	10929	Economy	14400.00
0005435304141	10929	Economy	14400.00
0005434343601	10929	Economy	14400.00
0005434573181	10929	Economy	14400.00
0005435097043	10929	Economy	14400.00
0005434244890	10929	Economy	14400.00
0005435612763	10929	Economy	14400.00
0005435611906	10929	Economy	14400.00
0005432363405	10929	Economy	14400.00
0005435612575	10929	Economy	14400.00
0005434244885	10929	Economy	14400.00
0005435612244	10929	Economy	14400.00
0005434244888	10929	Economy	14400.00
0005435424577	10929	Economy	14400.00
0005435490183	10929	Economy	14400.00
0005435304140	10929	Economy	14400.00
0005435612264	10929	Economy	14400.00
0005435424599	10929	Economy	14400.00
0005435612611	10929	Economy	14400.00
0005433719130	10929	Economy	14400.00
0005432165012	10929	Economy	14400.00
0005435424591	10929	Economy	14400.00
0005435424604	10929	Economy	14400.00
0005435424603	10929	Economy	14400.00
0005435424592	10929	Economy	14400.00
0005435612420	10929	Economy	14400.00
0005435424620	10929	Economy	14400.00
0005434343797	10929	Economy	14400.00
0005432165017	10929	Economy	14400.00
0005435612337	10929	Economy	14400.00
0005435612551	10929	Economy	14400.00
0005434343731	10929	Economy	14400.00
0005434573150	10929	Economy	14400.00
0005432363408	10929	Economy	14400.00
0005435612219	10929	Economy	14400.00
0005435424624	10929	Economy	14400.00
0005433805266	3358	Business	18800.00
0005432459249	3358	Business	18800.00
0005432459261	3358	Business	18800.00
0005433805259	3358	Business	18800.00
0005433633716	3358	Business	18800.00
0005432181639	3358	Business	18800.00
0005433805274	3358	Business	18800.00
0005433507134	3358	Business	18800.00
0005433805252	3358	Business	18800.00
0005433507119	3358	Business	18800.00
0005432459432	3358	Business	18800.00
0005432459089	3358	Business	18800.00
0005432459235	3358	Business	18800.00
0005433805264	3358	Business	18800.00
0005432459229	3358	Business	18800.00
0005432459458	3358	Business	18800.00
0005432459323	3358	Business	18800.00
0005433805269	3358	Business	18800.00
0005433507126	3358	Business	18800.00
0005433633723	3358	Business	18800.00
0005432459349	3358	Business	18800.00
0005433633710	3358	Business	18800.00
0005432459244	3358	Business	18800.00
0005432459219	3358	Business	18800.00
0005432459350	3358	Business	18800.00
0005432459338	3358	Business	18800.00
0005433633736	3358	Business	18800.00
0005433507123	3358	Business	18800.00
0005433633735	3358	Economy	6900.00
0005433633702	3358	Economy	6900.00
0005432459314	3358	Economy	6900.00
0005433805272	3358	Economy	6900.00
0005432181659	3358	Economy	6900.00
0005433805276	3358	Economy	6900.00
0005432459457	3358	Economy	6300.00
0005432181657	3358	Economy	6300.00
0005433633712	3358	Economy	6300.00
0005432181644	3358	Economy	6300.00
0005432181647	3358	Economy	6300.00
0005433633720	3358	Economy	6300.00
0005432459079	3358	Economy	6300.00
0005432459116	3358	Economy	6300.00
0005433633732	3358	Economy	6300.00
0005433633724	3358	Economy	6300.00
0005433805257	3358	Economy	6300.00
0005433805267	3358	Economy	6300.00
0005433507128	3358	Economy	6300.00
0005433633726	3358	Economy	6300.00
0005432181654	3358	Economy	6300.00
0005432459236	3358	Economy	6300.00
0005433805280	3358	Economy	6300.00
0005432181648	3358	Economy	6300.00
0005432181641	3358	Economy	6300.00
0005432459117	3358	Economy	6300.00
0005433633730	3358	Economy	6300.00
0005433805255	3358	Economy	6300.00
0005433507118	3358	Economy	6300.00
0005433633707	3358	Economy	6300.00
0005433805271	3358	Economy	6300.00
0005433633722	3358	Economy	6300.00
0005432181656	3358	Economy	6300.00
0005432459319	3358	Economy	6300.00
0005433633705	3358	Economy	6300.00
0005433507121	3358	Economy	6300.00
0005432459013	3358	Economy	6300.00
0005433633703	3358	Economy	6300.00
0005433805251	3358	Economy	6300.00
0005433805283	3358	Economy	6300.00
0005432459298	3358	Economy	6300.00
0005433805265	3358	Economy	6300.00
0005432181661	3358	Economy	6300.00
0005433507124	3358	Economy	6300.00
0005433633714	3358	Economy	6300.00
0005433805249	3358	Economy	6300.00
0005433633709	3358	Economy	6300.00
0005432181645	3358	Economy	6300.00
0005433805253	3358	Economy	6300.00
0005432181643	3358	Economy	6300.00
0005432181655	3358	Economy	6300.00
0005432181658	3358	Economy	6300.00
0005433507135	3358	Economy	6300.00
0005433507139	3358	Economy	6300.00
0005432459245	3358	Economy	6300.00
0005433805258	3358	Economy	6300.00
0005432459252	3358	Economy	6300.00
0005432459337	3358	Economy	6300.00
0005433633733	3358	Economy	6300.00
0005433633731	3358	Economy	6300.00
0005433633711	3358	Economy	6300.00
0005432459168	3358	Economy	6300.00
0005432459195	3358	Economy	6300.00
0005433507129	3358	Economy	6300.00
0005432458975	3358	Economy	6300.00
0005433633727	3358	Economy	6300.00
0005433805281	3358	Economy	6900.00
0005433805248	3358	Economy	6900.00
0005433633725	3358	Economy	6900.00
0005433805282	3358	Economy	6900.00
0005433805260	3358	Economy	6900.00
0005433805285	3358	Economy	6300.00
0005432459344	3358	Economy	6300.00
0005433805250	3358	Economy	6300.00
0005432459313	3358	Economy	6300.00
0005432459231	3358	Economy	6300.00
0005432459248	3358	Economy	6900.00
0005433633729	3358	Economy	6300.00
0005433805277	3358	Economy	6300.00
0005433633708	3358	Economy	6300.00
0005432181640	3358	Economy	6300.00
0005433633717	3358	Economy	6300.00
0005433633715	3358	Economy	6300.00
0005432181646	3358	Economy	6300.00
0005433633706	3358	Economy	6300.00
0005433805270	3358	Economy	6300.00
0005433805256	3358	Economy	6300.00
0005433805247	3358	Economy	6300.00
0005433805263	3358	Economy	6300.00
0005433633721	3358	Economy	6300.00
0005433805262	3358	Economy	6300.00
0005433507122	3358	Economy	6300.00
0005433805278	3358	Economy	6300.00
0005433633704	3358	Economy	6300.00
0005432181653	3358	Economy	6300.00
0005433805254	3358	Economy	6300.00
0005433633713	3358	Economy	6300.00
0005433805273	3358	Economy	6300.00
0005433507127	3358	Economy	6300.00
0005433805261	3358	Economy	6300.00
0005433507120	3358	Economy	6300.00
0005433633719	3358	Economy	6300.00
0005432459294	3358	Economy	6300.00
0005432181660	3358	Economy	6300.00
0005432181642	3358	Economy	6300.00
0005433805284	3358	Economy	6300.00
0005433507130	3358	Economy	6300.00
0005433507136	3358	Economy	6300.00
0005433805279	3358	Economy	6300.00
0005432181638	3358	Economy	6300.00
0005432181652	3358	Economy	6300.00
0005432459102	3358	Economy	6300.00
0005433805246	3358	Economy	6300.00
0005432459228	3358	Economy	6300.00
0005432459456	3358	Economy	6300.00
0005432459306	3358	Economy	6300.00
0005433805275	3358	Economy	6300.00
0005432459204	3358	Economy	6300.00
0005432459485	3358	Economy	6300.00
0005433633728	3358	Economy	6300.00
0005432459343	3358	Economy	6300.00
0005432459203	3358	Economy	6300.00
0005432459264	3358	Economy	6300.00
0005432459307	3358	Economy	6300.00
0005432181651	3358	Economy	6300.00
0005433507133	3358	Economy	6300.00
0005433507138	3358	Economy	6300.00
0005433507125	3358	Economy	6300.00
0005432181650	3358	Economy	6300.00
0005433507137	3358	Economy	6300.00
0005433507140	3358	Economy	6300.00
0005433805268	3358	Economy	6300.00
0005433507132	3358	Economy	6300.00
0005433507131	3358	Economy	6300.00
0005432459250	3358	Economy	6300.00
0005432459251	3358	Economy	6300.00
0005432459196	3358	Economy	6300.00
0005432459433	3358	Economy	6300.00
0005432181649	3358	Economy	6300.00
0005433633718	3358	Economy	6300.00
0005432459351	3358	Economy	6300.00
0005433633734	3358	Economy	6300.00
0005435884802	3357	Business	18800.00
0005435884782	3357	Business	18800.00
0005435884725	3357	Business	18800.00
0005435884726	3357	Business	18800.00
0005435884746	3357	Business	18800.00
0005435884386	3357	Business	18800.00
0005435884611	3357	Business	18800.00
0005435884764	3357	Business	18800.00
0005435884803	3357	Business	18800.00
0005435884918	3357	Business	18800.00
0005435884749	3357	Business	18800.00
0005435884628	3357	Economy	6900.00
0005435884939	3357	Economy	6300.00
0005435884741	3357	Economy	6300.00
0005435884933	3357	Economy	6300.00
0005435884806	3357	Economy	6300.00
0005435884835	3357	Economy	6300.00
0005435884591	3357	Economy	6300.00
0005435884831	3357	Economy	6300.00
0005435884688	3357	Economy	6300.00
0005435884582	3357	Economy	6300.00
0005435884724	3357	Economy	6300.00
0005435884747	3357	Economy	6300.00
0005435884681	3357	Economy	6300.00
0005435884836	3357	Economy	6300.00
0005435884813	3357	Economy	6300.00
0005435884811	3357	Economy	6300.00
0005435884819	3357	Economy	6900.00
0005435884622	3357	Economy	6300.00
0005435884592	3357	Economy	6300.00
0005435884583	3357	Economy	6300.00
0005435884934	3357	Economy	6300.00
0005435884758	3357	Economy	6300.00
0005435884940	3357	Economy	6300.00
0005435884402	3357	Economy	6300.00
0005435884932	3357	Economy	6300.00
0005435884770	3357	Economy	6300.00
0005435884757	3357	Economy	6300.00
0005435884692	3357	Economy	6300.00
0005435884673	3357	Economy	6300.00
0005435884766	3357	Economy	6300.00
0005435884780	3357	Economy	6300.00
0005435884783	3357	Economy	6300.00
0005435884938	3357	Economy	6300.00
0005435884842	3357	Economy	6300.00
0005433506936	8335	Business	18800.00
0005432042669	8335	Business	18800.00
0005432459741	8335	Business	18800.00
0005433506950	8335	Business	18800.00
0005432459704	8335	Business	18800.00
0005435885078	8335	Business	18800.00
0005435885102	8335	Business	18800.00
0005435885100	8335	Business	18800.00
0005435885124	8335	Business	18800.00
0005435885093	8335	Business	18800.00
0005435885094	8335	Business	18800.00
0005432459732	8335	Business	18800.00
0005435885098	8335	Business	18800.00
0005432459706	8335	Business	18800.00
0005435885074	8335	Business	18800.00
0005435885075	8335	Business	18800.00
0005432459752	8335	Business	18800.00
0005435885111	8335	Business	18800.00
0005432042679	8335	Business	18800.00
0005432042678	8335	Business	18800.00
0005432459744	8335	Business	18800.00
0005435885106	8335	Business	18800.00
0005435885118	8335	Business	18800.00
0005432459708	8335	Business	18800.00
0005432459757	8335	Economy	6900.00
0005432042667	8335	Economy	6900.00
0005432459739	8335	Economy	6900.00
0005432459731	8335	Economy	6900.00
0005433506937	8335	Economy	6900.00
0005433506967	8335	Economy	6900.00
0005433506957	8335	Economy	6300.00
0005432042670	8335	Economy	6300.00
0005435885108	8335	Economy	6300.00
0005432459735	8335	Economy	6300.00
0005433507014	8335	Economy	6300.00
0005432459736	8335	Economy	6300.00
0005435885087	8335	Economy	6300.00
0005435885107	8335	Economy	6300.00
0005432459755	8335	Economy	6300.00
0005432459747	8335	Economy	6300.00
0005435885072	8335	Economy	6300.00
0005435885091	8335	Economy	6300.00
0005432459753	8335	Economy	6300.00
0005432459726	8335	Economy	6300.00
0005432042677	8335	Economy	6300.00
0005432459724	8335	Economy	6300.00
0005435885079	8335	Economy	6300.00
0005433507069	8335	Economy	6300.00
0005432459707	8335	Economy	6300.00
0005435885116	8335	Economy	6300.00
0005432459714	8335	Economy	6300.00
0005432459746	8335	Economy	6300.00
0005435885113	8335	Economy	6300.00
0005435885104	8335	Economy	6300.00
0005432459727	8335	Economy	6300.00
0005432459709	8335	Economy	6300.00
0005432459750	8335	Economy	6300.00
0005432459711	8335	Economy	6300.00
0005435885090	8335	Economy	6300.00
0005432459722	8335	Economy	6300.00
0005435885085	8335	Economy	6300.00
0005435885084	8335	Economy	6300.00
0005435885117	8335	Economy	6300.00
0005435885083	8335	Economy	6300.00
0005432459734	8335	Economy	6300.00
0005435885082	8335	Economy	6300.00
0005432459705	8335	Economy	6300.00
0005435885086	8335	Economy	6300.00
0005433506875	8335	Economy	6300.00
0005432042676	8335	Economy	6300.00
0005435885105	8335	Economy	6300.00
0005432459745	8335	Economy	6300.00
0005432459720	8335	Economy	6300.00
0005435885120	8335	Economy	6300.00
0005435885112	8335	Economy	6300.00
0005435885081	8335	Economy	6300.00
0005433506960	8335	Economy	6300.00
0005435885097	8335	Economy	6300.00
0005435885099	8335	Economy	6300.00
0005432459737	8335	Economy	6300.00
0005432459712	8335	Economy	6300.00
0005435885096	8335	Economy	6900.00
0005433507068	8335	Economy	6900.00
0005432459733	8335	Economy	6300.00
0005432459717	8335	Economy	6300.00
0005432459729	8335	Economy	6300.00
0005435885076	8335	Economy	6900.00
0005433506885	8335	Economy	6300.00
0005432459751	8335	Economy	6300.00
0005435885115	8335	Economy	6300.00
0005432459723	8335	Economy	6300.00
0005435885080	8335	Economy	6300.00
0005435885125	8335	Economy	6300.00
0005432459754	8335	Economy	6300.00
0005433506926	8335	Economy	6300.00
0005432042671	8335	Economy	6300.00
0005432459710	8335	Economy	6300.00
0005432459743	8335	Economy	6300.00
0005435885114	8335	Economy	6300.00
0005433506900	8335	Economy	6300.00
0005435885101	8335	Economy	6300.00
0005432042672	8335	Economy	6300.00
0005435885092	8335	Economy	6300.00
0005432042675	8335	Economy	6300.00
0005432042674	8335	Economy	6300.00
0005432042680	8335	Economy	6300.00
0005432459716	8335	Economy	6300.00
0005435885077	8335	Economy	6300.00
0005432459713	8335	Economy	6300.00
0005435885119	8335	Economy	6300.00
0005433506899	8335	Economy	6300.00
0005432459719	8335	Economy	6300.00
0005432042668	8335	Economy	6300.00
0005435885123	8335	Economy	6300.00
0005433506913	8335	Economy	6300.00
0005432459756	8335	Economy	6300.00
0005432459749	8335	Economy	6300.00
0005432042673	8335	Economy	6300.00
0005435885109	8335	Economy	6300.00
0005434312314	8335	Economy	6300.00
0005432459721	8335	Economy	6300.00
0005435885089	8335	Economy	6300.00
0005435885103	8335	Economy	6300.00
0005433506995	8335	Economy	6300.00
0005435885122	8335	Economy	6300.00
0005433506951	8335	Economy	6300.00
0005432459728	8335	Economy	6300.00
0005435885110	8335	Economy	6300.00
0005432459742	8335	Economy	6300.00
0005432459715	8335	Economy	6300.00
0005432459730	8335	Economy	6300.00
0005432459738	8335	Economy	6300.00
0005432459718	8335	Economy	6300.00
0005434312315	8335	Economy	6300.00
0005435885121	8335	Economy	6300.00
0005435885088	8335	Economy	6300.00
0005433507001	8335	Economy	6300.00
0005435885095	8335	Economy	6300.00
0005433506914	8335	Economy	6300.00
0005432459748	8335	Economy	6300.00
0005432459725	8335	Economy	6300.00
0005433506954	8335	Economy	6300.00
0005435885073	8335	Economy	6300.00
0005433506898	8335	Economy	6300.00
0005433506956	8335	Economy	6300.00
0005433506966	8335	Economy	6300.00
0005432459740	8335	Economy	6300.00
0005433633415	8255	Business	18800.00
0005433633269	8255	Business	18800.00
0005433805098	8255	Business	18800.00
0005433804870	8255	Business	18800.00
0005433633479	8255	Business	18800.00
0005433633474	8255	Business	18800.00
0005434143704	8255	Business	18800.00
0005433805060	8255	Business	18800.00
0005433805008	8255	Business	18800.00
0005433804935	8255	Business	18800.00
0005433805046	8255	Business	18800.00
0005433633357	8255	Business	18800.00
0005433805097	8255	Business	18800.00
0005433804906	8255	Economy	6900.00
0005433633347	8255	Economy	6900.00
0005433805130	8255	Economy	6900.00
0005433633510	8255	Economy	6900.00
0005433633444	8255	Economy	6900.00
0005433633312	8255	Economy	6300.00
0005433633301	8255	Economy	6300.00
0005433804916	8255	Economy	6300.00
0005433633219	8255	Economy	6300.00
0005433633473	8255	Economy	6300.00
0005433804989	8255	Economy	6300.00
0005433633313	8255	Economy	6300.00
0005433633324	8255	Economy	6300.00
0005433633253	8255	Economy	6300.00
0005433804908	8255	Economy	6300.00
0005433805077	8255	Economy	6300.00
0005433805059	8255	Economy	6300.00
0005433805029	8255	Economy	6300.00
0005433805041	8255	Economy	6300.00
0005433633413	8255	Economy	6300.00
0005434143705	8255	Economy	6300.00
0005433804912	8255	Economy	6300.00
0005433804924	8255	Economy	6300.00
0005433804934	8255	Economy	6300.00
0005434271286	8255	Economy	6300.00
0005433633288	8255	Economy	6300.00
0005433633344	8255	Economy	6300.00
0005433804990	8255	Economy	6300.00
0005433805026	8255	Economy	6900.00
0005433804907	8255	Economy	6900.00
0005433633291	8255	Economy	6300.00
0005433804985	8255	Economy	6300.00
0005433633342	8255	Economy	6300.00
0005433804865	8255	Economy	6300.00
0005433804994	8255	Economy	6300.00
0005434271290	8255	Economy	6300.00
0005433633414	8255	Economy	6300.00
0005433804947	8255	Economy	6300.00
0005433633374	8255	Economy	6300.00
0005433805025	8255	Economy	6300.00
0005433804940	8255	Economy	6300.00
0005433805007	8255	Economy	6300.00
0005433804957	8255	Economy	6300.00
0005433804986	8255	Economy	6300.00
0005433805074	8255	Economy	6300.00
0005433804956	8255	Economy	6300.00
0005433633455	8255	Economy	6300.00
0005433633270	8255	Economy	6300.00
0005433804871	8255	Economy	6300.00
0005433805024	8255	Economy	6300.00
0005433633396	8255	Economy	6300.00
0005433804984	8255	Economy	6300.00
0005433804869	8255	Economy	6300.00
0005433633287	8255	Economy	6300.00
0005433804995	8255	Economy	6300.00
0005433633480	8255	Economy	6300.00
0005433804948	8255	Economy	6300.00
0005433633252	8255	Economy	6300.00
0005433633345	8255	Economy	6300.00
0005433633218	8255	Economy	6300.00
0005433805028	8255	Economy	6300.00
0005433633452	8255	Economy	6300.00
0005433804911	8255	Economy	6300.00
0005434143703	8255	Economy	6300.00
0005433805045	8255	Economy	6300.00
0005433804796	8255	Economy	6300.00
0005433633346	8255	Economy	6300.00
0005432383075	4517	Business	9900.00
0005432383089	4517	Business	9900.00
0005432727902	4517	Business	9900.00
0005432727903	4517	Business	9900.00
0005432383094	4517	Business	9900.00
0005432383086	4517	Business	9900.00
0005432727897	4517	Business	9900.00
0005432383074	4517	Business	9900.00
0005432727901	4517	Business	9900.00
0005432383088	4517	Business	9900.00
0005432727896	4517	Economy	3300.00
0005432383066	4517	Economy	3300.00
0005432383079	4517	Economy	3300.00
0005432383072	4517	Economy	3300.00
0005432383073	4517	Economy	3300.00
0005432383059	4517	Economy	3600.00
0005432727907	4517	Economy	3600.00
0005432383063	4517	Economy	3600.00
0005432383076	4517	Economy	3600.00
0005432383061	4517	Economy	3300.00
0005432727904	4517	Economy	3300.00
0005432383084	4517	Economy	3300.00
0005432383067	4517	Economy	3300.00
0005432383057	4517	Economy	3300.00
0005433722206	4517	Economy	3300.00
0005432727906	4517	Economy	3300.00
0005432383064	4517	Economy	3300.00
0005432383082	4517	Economy	3300.00
0005432383068	4517	Economy	3300.00
0005432727905	4517	Economy	3300.00
0005433722203	4517	Economy	3300.00
0005433722204	4517	Economy	3300.00
0005432383078	4517	Economy	3300.00
0005432383070	4517	Economy	3300.00
0005432383081	4517	Economy	3300.00
0005432383091	4517	Economy	3300.00
0005432383065	4517	Economy	3300.00
0005433722208	4517	Economy	3300.00
0005432383092	4517	Economy	3300.00
0005433722202	4517	Economy	3300.00
0005432383077	4517	Economy	3300.00
0005432383093	4517	Economy	3300.00
0005432383085	4517	Economy	3300.00
0005433722200	4517	Economy	3300.00
0005432383080	4517	Economy	3300.00
0005432383060	4517	Economy	3300.00
0005433453758	4517	Economy	3300.00
0005432383071	4517	Economy	3300.00
0005432727900	4517	Economy	3300.00
0005432383087	4517	Economy	3300.00
0005432383083	4517	Economy	3300.00
0005433722207	4517	Economy	3300.00
0005432727898	4517	Economy	3300.00
0005432727899	4517	Economy	3300.00
0005432727895	4517	Economy	3300.00
0005432383090	4517	Economy	3300.00
0005433722201	4517	Economy	3300.00
0005432383058	4517	Economy	3300.00
0005433722205	4517	Economy	3300.00
0005432383062	4517	Economy	3300.00
0005432383069	4517	Economy	3300.00
0005432382784	30094	Business	9900.00
0005432727801	30094	Business	9900.00
0005432727812	30094	Business	9900.00
0005432382535	30094	Business	9900.00
0005432382661	30094	Business	9900.00
0005432382595	30094	Business	9900.00
0005432382495	30094	Business	9900.00
0005432382534	30094	Economy	3300.00
0005432382579	30094	Economy	3300.00
0005432382712	30094	Economy	3300.00
0005432382601	30094	Economy	3300.00
0005432382738	30094	Economy	3300.00
0005432382637	30094	Economy	3300.00
0005432382657	30094	Economy	3300.00
0005433722114	30094	Economy	3300.00
0005432382625	30094	Economy	3600.00
0005432382651	30094	Economy	3600.00
0005432727771	30094	Economy	3600.00
0005432382708	30094	Economy	3300.00
0005432382662	30094	Economy	3300.00
0005432382624	30094	Economy	3300.00
0005433451594	30094	Economy	3300.00
0005432382644	30094	Economy	3300.00
0005432382711	30094	Economy	3300.00
0005432727821	30094	Economy	3300.00
0005432382673	30094	Economy	3300.00
0005432382681	30094	Economy	3300.00
0005432382629	30094	Economy	3300.00
0005432382614	30094	Economy	3300.00
0005432382505	30094	Economy	3300.00
0005432382776	30094	Economy	3300.00
0005432382654	30094	Economy	3300.00
0005432382496	30094	Economy	3300.00
0005432382523	30094	Economy	3300.00
0005432382680	30094	Economy	3300.00
0005432727853	30094	Economy	3300.00
0005433451596	30094	Economy	3300.00
0005432382619	30094	Economy	3300.00
0005432382580	30094	Economy	3300.00
0005432727772	30094	Economy	3300.00
0005432382656	30094	Economy	3300.00
0005432727832	30094	Economy	3300.00
0005432727802	30094	Economy	3300.00
0005433453735	30094	Economy	3300.00
0005432382645	30094	Economy	3300.00
0005432382613	30094	Economy	3300.00
0005432382618	30094	Economy	3300.00
0005432382600	30094	Economy	3300.00
0005432382899	30094	Economy	3300.00
0005432727773	30094	Economy	3300.00
0005432382636	30094	Economy	3300.00
0005433453734	30094	Economy	3300.00
0005432727788	30094	Economy	3300.00
0005433453733	30094	Economy	3300.00
0005432382655	30094	Economy	3300.00
0005432382596	30094	Economy	3300.00
0005432382500	30094	Economy	3300.00
0005433722108	30094	Economy	3300.00
0005433451595	30094	Economy	3300.00
0005432382898	30094	Economy	3300.00
0005433722113	30094	Economy	3300.00
0005432382525	30094	Economy	3300.00
0005435529206	1741	Business	57200.00
0005435529204	1741	Business	57200.00
0005435529191	1741	Business	57200.00
0005435529196	1741	Business	57200.00
0005435529210	1741	Business	57200.00
0005433516860	1741	Business	57200.00
0005435540945	1741	Business	57200.00
0005435529209	1741	Business	57200.00
0005433516855	1741	Economy	19100.00
0005435540941	1741	Economy	19100.00
0005435540954	1741	Economy	19100.00
0005435540953	1741	Economy	19100.00
0005435540937	1741	Economy	19100.00
0005435529198	1741	Economy	19100.00
0005435529201	1741	Economy	19100.00
0005435529193	1741	Economy	21000.00
0005435529197	1741	Economy	21000.00
0005435529199	1741	Economy	21000.00
0005435540952	1741	Economy	19100.00
0005432924968	1741	Economy	19100.00
0005435540935	1741	Economy	19100.00
0005433516859	1741	Economy	19100.00
0005435540934	1741	Economy	19100.00
0005435529192	1741	Economy	19100.00
0005435540940	1741	Economy	19100.00
0005435529205	1741	Economy	19100.00
0005432924981	1741	Economy	19100.00
0005435529208	1741	Economy	19100.00
0005433516856	1741	Economy	19100.00
0005435529189	1741	Economy	19100.00
0005433516858	1741	Economy	19100.00
0005435540950	1741	Economy	19100.00
0005435540946	1741	Economy	19100.00
0005435540948	1741	Economy	19100.00
0005433516862	1741	Economy	19100.00
0005433516857	1741	Economy	19100.00
0005435529207	1741	Economy	19100.00
0005435540949	1741	Economy	19100.00
0005433516863	1741	Economy	19100.00
0005432294479	1741	Economy	19100.00
0005435540938	1741	Economy	19100.00
0005435529202	1741	Economy	19100.00
0005435540936	1741	Economy	19100.00
0005435529203	1741	Economy	19100.00
0005435540944	1741	Economy	19100.00
0005435529195	1741	Economy	19100.00
0005435540942	1741	Economy	19100.00
0005432294480	1741	Economy	19100.00
0005435540947	1741	Economy	19100.00
0005432294481	1741	Economy	19100.00
0005432924969	1741	Economy	19100.00
0005435540933	1741	Economy	19100.00
0005435540939	1741	Economy	19100.00
0005432924980	1741	Economy	19100.00
0005435529190	1741	Economy	19100.00
0005435529200	1741	Economy	19100.00
0005433516861	1741	Economy	19100.00
0005435529194	1741	Economy	19100.00
0005435540943	1741	Economy	19100.00
0005435540951	1741	Economy	19100.00
0005432925023	21991	Business	57200.00
0005435540742	21991	Business	57200.00
0005435517665	21991	Business	57200.00
0005435517689	21991	Business	57200.00
0005435540678	21991	Business	57200.00
0005435540849	21991	Business	57200.00
0005435540679	21991	Economy	19100.00
0005435540740	21991	Economy	19100.00
0005432925021	21991	Economy	19100.00
0005435517749	21991	Economy	19100.00
0005433516792	21991	Economy	21000.00
0005435540634	21991	Economy	19100.00
0005432925022	21991	Economy	19100.00
0005433516791	21991	Economy	19100.00
0005435540850	21991	Economy	19100.00
0005435517724	21991	Economy	19100.00
0005435517624	21991	Economy	19100.00
0005433516766	21991	Economy	19100.00
0005435517746	21991	Economy	19100.00
0005435540677	21991	Economy	19100.00
0005435517683	21991	Economy	19100.00
0005435517711	21991	Economy	19100.00
0005435517764	21991	Economy	19100.00
0005435540732	21991	Economy	19100.00
0005435517664	21991	Economy	19100.00
0005435540774	21991	Economy	19100.00
0005435540727	21991	Economy	19100.00
0005435517677	21991	Economy	19100.00
0005435517765	21991	Economy	19100.00
0005435540739	21991	Economy	19100.00
0005435517732	21991	Economy	19100.00
0005435517712	21991	Economy	19100.00
0005435517788	21991	Economy	19100.00
0005433516758	21991	Economy	19100.00
0005435540738	21991	Economy	19100.00
0005435517676	21991	Economy	19100.00
0005435540696	21991	Economy	19100.00
0005435540756	21991	Economy	19100.00
0005435517623	21991	Economy	19100.00
0005432925024	21991	Economy	19100.00
0005435540815	21991	Economy	19100.00
0005432925020	21991	Economy	19100.00
0005435540768	21991	Economy	19100.00
0005435540633	21991	Economy	19100.00
0005435540733	21991	Economy	19100.00
0005433516771	21991	Economy	19100.00
0005435540635	21991	Economy	19100.00
0005433516767	21991	Economy	19100.00
0005434458749	7372	Business	18500.00
0005435252460	7372	Business	18500.00
0005432823444	7372	Business	18500.00
0005434458739	7372	Business	18500.00
0005432838937	7372	Business	18500.00
0005432838944	7372	Business	18500.00
0005435252445	7372	Business	18500.00
0005434458747	7372	Business	18500.00
0005432838953	7372	Business	18500.00
0005435252510	7372	Business	18500.00
0005432838938	7372	Business	18500.00
0005435252509	7372	Business	18500.00
0005432838936	7372	Economy	6200.00
0005435252383	7372	Economy	6200.00
0005432838946	7372	Economy	6200.00
0005432838943	7372	Economy	6200.00
0005432073381	7372	Economy	6200.00
0005432838958	7372	Economy	6200.00
0005432838931	7372	Economy	6200.00
0005435252582	7372	Economy	6200.00
0005434458748	7372	Economy	6200.00
0005432838927	7372	Economy	6200.00
0005434458732	7372	Economy	6800.00
0005435252494	7372	Economy	6800.00
0005435252384	7372	Economy	6800.00
0005435252525	7372	Economy	6800.00
0005435252400	7372	Economy	6800.00
0005435252583	7372	Economy	6200.00
0005432823441	7372	Economy	6200.00
0005435252444	7372	Economy	6200.00
0005432838933	7372	Economy	6200.00
0005434458746	7372	Economy	6200.00
0005432838929	7372	Economy	6200.00
0005434458736	7372	Economy	6200.00
0005435252526	7372	Economy	6200.00
0005432838930	7372	Economy	6200.00
0005434458737	7372	Economy	6200.00
0005432838951	7372	Economy	6200.00
0005435252503	7372	Economy	6200.00
0005435252459	7372	Economy	6200.00
0005432823442	7372	Economy	6200.00
0005432838926	7372	Economy	6200.00
0005432073379	7372	Economy	6200.00
0005434458750	7372	Economy	6200.00
0005434458742	7372	Economy	6200.00
0005435252495	7372	Economy	6200.00
0005432838952	7372	Economy	6200.00
0005435252452	7372	Economy	6200.00
0005434458744	7372	Economy	6200.00
0005434458751	7372	Economy	6200.00
0005432838957	7372	Economy	6200.00
0005432838939	7372	Economy	6200.00
0005435252496	7372	Economy	6200.00
0005435252476	7372	Economy	6200.00
0005432838948	7372	Economy	6200.00
0005434458743	7372	Economy	6200.00
0005432838950	7372	Economy	6200.00
0005434458734	7372	Economy	6200.00
0005432838941	7372	Economy	6200.00
0005434458731	7372	Economy	6200.00
0005432838955	7372	Economy	6200.00
0005435252560	7372	Economy	6200.00
0005435252497	7372	Economy	6200.00
0005432841004	7372	Economy	6200.00
0005435252539	7372	Economy	6200.00
0005432838940	7372	Economy	6200.00
0005432838956	7372	Economy	6200.00
0005435252563	7372	Economy	6200.00
0005435252581	7372	Economy	6200.00
0005432838949	7372	Economy	6200.00
0005435491405	7372	Economy	6200.00
0005434664925	7372	Economy	6200.00
0005435252538	7372	Economy	6200.00
0005434458745	7372	Economy	6200.00
0005434458740	7372	Economy	6200.00
0005432841005	7372	Economy	6200.00
0005434458752	7372	Economy	6200.00
0005434458738	7372	Economy	6200.00
0005432838928	7372	Economy	6200.00
0005435252537	7372	Economy	6200.00
0005432838934	7372	Economy	6200.00
0005434458733	7372	Economy	6200.00
0005434458735	7372	Economy	6200.00
0005432838947	7372	Economy	6200.00
0005432838945	7372	Economy	6200.00
0005435252502	7372	Economy	6200.00
0005432073380	7372	Economy	6200.00
0005432823443	7372	Economy	6200.00
0005435252461	7372	Economy	6200.00
0005432838935	7372	Economy	6200.00
0005435252492	7372	Economy	6200.00
0005432838954	7372	Economy	6200.00
0005432838932	7372	Economy	6200.00
0005432838942	7372	Economy	6200.00
0005434458741	7372	Economy	6200.00
0005434458555	28919	Business	18500.00
0005434458478	28919	Business	18500.00
0005432838748	28919	Business	18500.00
0005432838611	28919	Business	18500.00
0005435491435	28919	Business	18500.00
0005432838888	28919	Business	18500.00
0005432838711	28919	Business	18500.00
0005432001016	28919	Business	18500.00
0005435252650	28919	Business	18500.00
0005435491437	28919	Business	18500.00
0005432840992	28919	Economy	6200.00
0005434458575	28919	Economy	6200.00
0005434458557	28919	Economy	6200.00
0005435252642	28919	Economy	6200.00
0005432838739	28919	Economy	6200.00
0005434458589	28919	Economy	6200.00
0005434458573	28919	Economy	6200.00
0005432838671	28919	Economy	6200.00
0005435252645	28919	Economy	6200.00
0005432838724	28919	Economy	6800.00
0005432838710	28919	Economy	6800.00
0005432838712	28919	Economy	6800.00
0005434458511	28919	Economy	6200.00
0005432838635	28919	Economy	6200.00
0005434458510	28919	Economy	6200.00
0005434458615	28919	Economy	6200.00
0005435252646	28919	Economy	6200.00
0005432838727	28919	Economy	6200.00
0005432838703	28919	Economy	6200.00
0005432838623	28919	Economy	6200.00
0005432838586	28919	Economy	6200.00
0005435252657	28919	Economy	6200.00
0005434458550	28919	Economy	6200.00
0005435252643	28919	Economy	6200.00
0005432838687	28919	Economy	6200.00
0005432838646	28919	Economy	6200.00
0005434458512	28919	Economy	6200.00
0005432838747	28919	Economy	6200.00
0005432838670	28919	Economy	6200.00
0005434458606	28919	Economy	6200.00
0005435252648	28919	Economy	6200.00
0005432838721	28919	Economy	6200.00
0005432838889	28919	Economy	6200.00
0005434458520	28919	Economy	6200.00
0005432838698	28919	Economy	6200.00
0005432838669	28919	Economy	6200.00
0005435252652	28919	Economy	6200.00
0005434458556	28919	Economy	6200.00
0005432823433	28919	Economy	6200.00
0005432838738	28919	Economy	6200.00
0005435252656	28919	Economy	6200.00
0005435252651	28919	Economy	6200.00
0005435252655	28919	Economy	6200.00
0005435252653	28919	Economy	6200.00
0005435252644	28919	Economy	6200.00
0005432838650	28919	Economy	6200.00
0005432838728	28919	Economy	6200.00
0005432838686	28919	Economy	6200.00
0005432838763	28919	Economy	6200.00
0005432838609	28919	Economy	6200.00
0005432838598	28919	Economy	6200.00
0005435252647	28919	Economy	6200.00
0005432838706	28919	Economy	6200.00
0005435491438	28919	Economy	6200.00
0005432838585	28919	Economy	6200.00
0005432838651	28919	Economy	6200.00
0005434458551	28919	Economy	6200.00
0005434458572	28919	Economy	6200.00
0005434458599	28919	Economy	6200.00
0005434458519	28919	Economy	6200.00
0005435252649	28919	Economy	6200.00
0005432838610	28919	Economy	6200.00
0005434458600	28919	Economy	6200.00
0005432001017	28919	Economy	6200.00
0005434664953	28919	Economy	6200.00
0005435252654	28919	Economy	6200.00
0005435491436	28919	Economy	6200.00
0005434664952	28919	Economy	6200.00
0005432838675	28919	Economy	6200.00
0005432838624	28919	Economy	6200.00
0005434458658	28919	Economy	6200.00
0005435252658	28919	Economy	6200.00
0005432838761	28919	Economy	6200.00
0005432838625	28919	Economy	6200.00
0005434275955	8807	Business	145300.00
0005435990605	8807	Economy	48400.00
0005434275977	8807	Economy	48400.00
0005435990602	8807	Economy	48400.00
0005435990603	8807	Economy	48400.00
0005434275954	8807	Economy	48400.00
0005434275978	8807	Economy	48400.00
0005435990599	8807	Economy	48400.00
0005435990604	8807	Economy	48400.00
0005435990600	8807	Economy	48400.00
0005435990601	8807	Economy	48400.00
0005434275953	8807	Economy	48400.00
0005434275984	8807	Economy	48400.00
0005435990552	15737	Business	145300.00
0005435990534	15737	Business	145300.00
0005434276012	15737	Business	145300.00
0005435990565	15737	Business	145300.00
0005435990562	15737	Economy	48400.00
0005435990551	15737	Economy	48400.00
0005434276007	15737	Economy	48400.00
0005435990553	15737	Economy	53300.00
0005434276010	15737	Economy	48400.00
0005435990535	15737	Economy	48400.00
0005435990545	15737	Economy	48400.00
0005434276008	15737	Economy	48400.00
0005434276009	15737	Economy	48400.00
0005435990544	15737	Economy	48400.00
0005435990561	15737	Economy	48400.00
0005434276013	15737	Economy	48400.00
0005435990559	15737	Economy	48400.00
0005435990560	15737	Economy	48400.00
0005435990533	15737	Economy	48400.00
0005435990539	15737	Economy	48400.00
0005434276011	15737	Economy	48400.00
0005433468305	2098	Economy	13300.00
0005432909218	2098	Economy	13300.00
0005433468308	2098	Economy	13300.00
0005432909217	2098	Economy	12100.00
0005432909204	2098	Economy	12100.00
0005432909224	2098	Economy	12100.00
0005433468302	2098	Economy	12100.00
0005433468314	2098	Economy	12100.00
0005433468307	2098	Economy	12100.00
0005433468312	2098	Economy	12100.00
0005433468303	2098	Economy	12100.00
0005433468300	2098	Economy	12100.00
0005432909212	2098	Economy	12100.00
0005433468306	2098	Economy	12100.00
0005433468310	2098	Economy	12100.00
0005432909193	2098	Economy	12100.00
0005433468299	2098	Economy	12100.00
0005433468304	2098	Economy	12100.00
0005433468311	2098	Economy	12100.00
0005432909238	2098	Economy	12100.00
0005433468315	2098	Economy	12100.00
0005432909213	2098	Economy	12100.00
0005432909194	2098	Economy	12100.00
0005433468313	2098	Economy	12100.00
0005433468309	2098	Economy	12100.00
0005432909225	2098	Economy	12100.00
0005433468316	2098	Economy	12100.00
0005433468298	2098	Economy	12100.00
0005432909230	2098	Economy	12100.00
0005432909223	2098	Economy	12100.00
0005432909222	2098	Economy	12100.00
0005433468301	2098	Economy	12100.00
0005432335995	6417	Business	36600.00
0005432360198	6417	Business	36600.00
0005432360207	6417	Business	36600.00
0005432336000	6417	Business	36600.00
0005434149591	6417	Business	36600.00
0005435176736	6417	Business	36600.00
0005435176768	6417	Business	36600.00
0005434149604	6417	Business	36600.00
0005432360233	6417	Business	36600.00
0005432360227	6417	Business	36600.00
0005432360216	6417	Business	36600.00
0005432360202	6417	Business	36600.00
0005435176766	6417	Economy	12200.00
0005434149608	6417	Economy	12200.00
0005432360225	6417	Economy	12200.00
0005435176677	6417	Economy	12200.00
0005432360228	6417	Economy	12200.00
0005434149647	6417	Economy	12200.00
0005435176787	6417	Economy	12200.00
0005435176737	6417	Economy	12200.00
0005435176893	6417	Economy	12200.00
0005432360245	6417	Economy	12200.00
0005435176678	6417	Economy	12200.00
0005432360197	6417	Economy	12200.00
0005435176782	6417	Economy	12200.00
0005432335997	6417	Economy	12200.00
0005435723028	6417	Economy	12200.00
0005435490183	6417	Economy	12200.00
0005432360205	6417	Economy	12200.00
0005432360221	6417	Economy	12200.00
0005432360232	6417	Economy	12200.00
0005434149601	6417	Economy	12200.00
0005432360212	6417	Economy	12200.00
0005432336001	6417	Economy	12200.00
0005432360218	6417	Economy	12200.00
0005435176796	6417	Economy	12200.00
0005432363406	6417	Economy	12200.00
0005435176760	6417	Economy	12200.00
0005435176761	6417	Economy	12200.00
0005432062211	6417	Economy	12200.00
0005432360242	6417	Economy	12200.00
0005432363405	6417	Economy	12200.00
0005432360226	6417	Economy	12200.00
0005432360223	6417	Economy	12200.00
0005435176889	6417	Economy	12200.00
0005432360240	6417	Economy	12200.00
0005432360214	6417	Economy	12200.00
0005435176676	6417	Economy	12200.00
0005432363408	6417	Economy	12200.00
0005432360209	6417	Economy	13400.00
0005432360215	6417	Economy	13400.00
0005434149570	6417	Economy	13400.00
0005435723029	6417	Economy	13400.00
0005435176797	6417	Economy	13400.00
0005432360239	6417	Economy	13400.00
0005435176811	6417	Economy	12200.00
0005435723013	6417	Economy	12200.00
0005432360235	6417	Economy	12200.00
0005432360195	6417	Economy	12200.00
0005432360204	6417	Economy	12200.00
0005435176842	6417	Economy	12200.00
0005432336003	6417	Economy	12200.00
0005432360217	6417	Economy	12200.00
0005435176781	6417	Economy	12200.00
0005432360241	6417	Economy	12200.00
0005432062212	6417	Economy	12200.00
0005432360236	6417	Economy	12200.00
0005435490178	6417	Economy	12200.00
0005432360201	6417	Economy	12200.00
0005432360230	6417	Economy	12200.00
0005432360238	6417	Economy	12200.00
0005435176847	6417	Economy	12200.00
0005435176851	6417	Economy	12200.00
0005432336002	6417	Economy	12200.00
0005432360210	6417	Economy	12200.00
0005434149544	6417	Economy	12200.00
0005432360243	6417	Economy	12200.00
0005435176652	6417	Economy	12200.00
0005432336004	6417	Economy	12200.00
0005432360208	6417	Economy	12200.00
0005432360234	6417	Economy	12200.00
0005435176767	6417	Economy	12200.00
0005432363407	6417	Economy	12200.00
0005432360231	6417	Economy	12200.00
0005432360222	6417	Economy	12200.00
0005435490180	6417	Economy	12200.00
0005435176827	6417	Economy	12200.00
0005432360206	6417	Economy	12200.00
0005432360237	6417	Economy	12200.00
0005432360244	6417	Economy	12200.00
0005435490179	6417	Economy	12200.00
0005432360229	6417	Economy	12200.00
0005432360220	6417	Economy	12200.00
0005432360224	6417	Economy	12200.00
0005435176738	6417	Economy	12200.00
0005432062210	6417	Economy	12200.00
0005434149631	6417	Economy	12200.00
0005432360219	6417	Economy	12200.00
0005432360203	6417	Economy	12200.00
0005435176812	6417	Economy	12200.00
0005435176790	6417	Economy	12200.00
0005432360200	6417	Economy	12200.00
0005432335994	6417	Economy	12200.00
0005432360211	6417	Economy	12200.00
0005432335996	6417	Economy	12200.00
0005435176841	6417	Economy	12200.00
0005432360196	6417	Economy	12200.00
0005432062213	6417	Economy	12200.00
0005432360199	6417	Economy	12200.00
0005432062214	6417	Economy	12200.00
0005434149546	6417	Economy	12200.00
0005435490188	6417	Economy	12200.00
0005434149545	6417	Economy	12200.00
0005432335999	6417	Economy	12200.00
0005432360213	6417	Economy	12200.00
0005434149602	6417	Economy	12200.00
0005432335998	6417	Economy	12200.00
0005434149554	6417	Economy	12200.00
0005435176855	6417	Economy	12200.00
0005434149592	6417	Economy	12200.00
0005432363367	21028	Business	36600.00
0005432359686	21028	Business	36600.00
0005432359745	21028	Business	36600.00
0005435723039	21028	Business	36600.00
0005432359854	21028	Business	36600.00
0005432052739	21028	Business	36600.00
0005435176990	21028	Business	36600.00
0005432359640	21028	Business	36600.00
0005432359882	21028	Business	36600.00
0005435176985	21028	Business	36600.00
0005432359893	21028	Business	36600.00
0005435176995	21028	Business	36600.00
0005435176982	21028	Economy	12200.00
0005432359911	21028	Economy	12200.00
0005432359891	21028	Economy	12200.00
0005434149697	21028	Economy	12200.00
0005432359937	21028	Economy	12200.00
0005432359875	21028	Economy	12200.00
0005435176981	21028	Economy	12200.00
0005432359796	21028	Economy	12200.00
0005432335903	21028	Economy	12200.00
0005432335921	21028	Economy	12200.00
0005432052738	21028	Economy	12200.00
0005432359767	21028	Economy	12200.00
0005435177007	21028	Economy	12200.00
0005435177006	21028	Economy	12200.00
0005432359683	21028	Economy	12200.00
0005432359874	21028	Economy	12200.00
0005432359800	21028	Economy	12200.00
0005435176994	21028	Economy	12200.00
0005432359992	21028	Economy	12200.00
0005435723040	21028	Economy	12200.00
0005434149700	21028	Economy	12200.00
0005435176996	21028	Economy	12200.00
0005432359847	21028	Economy	12200.00
0005435176991	21028	Economy	12200.00
0005435177005	21028	Economy	12200.00
0005432359869	21028	Economy	12200.00
0005432359616	21028	Economy	12200.00
0005432360004	21028	Economy	12200.00
0005432335934	21028	Economy	12200.00
0005432335933	21028	Economy	12200.00
0005432359615	21028	Economy	12200.00
0005432359980	21028	Economy	12200.00
0005432359780	21028	Economy	12200.00
0005432363385	21028	Economy	12200.00
0005434149691	21028	Economy	12200.00
0005435176984	21028	Economy	12200.00
0005435177003	21028	Economy	12200.00
0005435176993	21028	Economy	12200.00
0005432359597	21028	Economy	13400.00
0005432359786	21028	Economy	13400.00
0005432335884	21028	Economy	13400.00
0005432335904	21028	Economy	13400.00
0005432363378	21028	Economy	12200.00
0005434149696	21028	Economy	12200.00
0005432359799	21028	Economy	12200.00
0005432359681	21028	Economy	12200.00
0005434149692	21028	Economy	12200.00
0005432359819	21028	Economy	12200.00
0005432359807	21028	Economy	12200.00
0005432359835	21028	Economy	12200.00
0005435176983	21028	Economy	12200.00
0005434149699	21028	Economy	12200.00
0005432359766	21028	Economy	12200.00
0005432359731	21028	Economy	12200.00
0005432359881	21028	Economy	12200.00
0005435176987	21028	Economy	12200.00
0005435176988	21028	Economy	12200.00
0005432359746	21028	Economy	12200.00
0005435176998	21028	Economy	12200.00
0005432359823	21028	Economy	12200.00
0005435177004	21028	Economy	12200.00
0005434149698	21028	Economy	12200.00
0005432359782	21028	Economy	12200.00
0005432359836	21028	Economy	12200.00
0005432359556	21028	Economy	12200.00
0005432359677	21028	Economy	12200.00
0005432359913	21028	Economy	12200.00
0005432359818	21028	Economy	12200.00
0005432359768	21028	Economy	12200.00
0005432052737	21028	Economy	12200.00
0005432360005	21028	Economy	12200.00
0005434149689	21028	Economy	12200.00
0005432359846	21028	Economy	12200.00
0005432359672	21028	Economy	12200.00
0005435176992	21028	Economy	12200.00
0005432359912	21028	Economy	12200.00
0005434149694	21028	Economy	12200.00
0005435176980	21028	Economy	12200.00
0005434149693	21028	Economy	12200.00
0005432359870	21028	Economy	12200.00
0005435176997	21028	Economy	12200.00
0005432052736	21028	Economy	12200.00
0005432359682	21028	Economy	12200.00
0005432359691	21028	Economy	12200.00
0005432359845	21028	Economy	12200.00
0005435176989	21028	Economy	12200.00
0005432359822	21028	Economy	12200.00
0005435490218	21028	Economy	12200.00
0005435177001	21028	Economy	12200.00
0005435490221	21028	Economy	12200.00
0005432359806	21028	Economy	12200.00
0005432335922	21028	Economy	12200.00
0005432359654	21028	Economy	12200.00
0005435177002	21028	Economy	12200.00
0005435490220	21028	Economy	12200.00
0005432359747	21028	Economy	12200.00
0005432359692	21028	Economy	12200.00
0005434149695	21028	Economy	12200.00
0005432359700	21028	Economy	12200.00
0005432335932	21028	Economy	12200.00
0005435177000	21028	Economy	12200.00
0005432359757	21028	Economy	12200.00
0005432359798	21028	Economy	12200.00
0005432359795	21028	Economy	12200.00
0005432359783	21028	Economy	12200.00
0005432335902	21028	Economy	12200.00
0005432359758	21028	Economy	12200.00
0005435490219	21028	Economy	12200.00
0005434149690	21028	Economy	12200.00
0005432335862	21028	Economy	12200.00
0005435176986	21028	Economy	12200.00
0005435176999	21028	Economy	12200.00
0005434458612	17718	Economy	3400.00
0005434448283	17718	Economy	3400.00
0005434458639	17718	Economy	3400.00
0005434458621	17718	Economy	3100.00
0005434458559	17718	Economy	3100.00
0005434458614	17718	Economy	3100.00
0005434458492	17718	Economy	3100.00
0005434458648	17718	Economy	3100.00
0005434458607	17718	Economy	3100.00
0005434458554	17718	Economy	3100.00
0005434458524	17718	Economy	3100.00
0005434458622	17718	Economy	3100.00
0005434458602	17718	Economy	3100.00
0005434458613	17718	Economy	3100.00
0005434458567	17718	Economy	3100.00
0005434186190	17718	Economy	3100.00
0005434458625	17718	Economy	3100.00
0005434458493	17718	Economy	3100.00
0005434458558	17718	Economy	3100.00
0005434458545	17718	Economy	3100.00
0005434458543	17718	Economy	3100.00
0005434458577	17718	Economy	3100.00
0005434458514	17718	Economy	3100.00
0005434458562	17718	Economy	3100.00
0005434186189	17718	Economy	3100.00
0005434458544	17718	Economy	3100.00
0005434458601	17718	Economy	3100.00
0005434458552	17718	Economy	3100.00
0005434186191	17718	Economy	3100.00
0005434458610	17718	Economy	3100.00
0005434458576	17718	Economy	3100.00
0005434458603	17718	Economy	3100.00
0005434458751	29135	Economy	3400.00
0005434186167	29135	Economy	3400.00
0005434448303	29135	Economy	3100.00
0005434458733	29135	Economy	3100.00
0005434458738	29135	Economy	3100.00
0005434458750	29135	Economy	3100.00
0005434458739	29135	Economy	3100.00
0005434458749	29135	Economy	3100.00
0005434458752	29135	Economy	3100.00
0005434463921	29135	Economy	3100.00
0005434458731	29135	Economy	3100.00
0005434462782	29135	Economy	3100.00
0005434458748	29135	Economy	3100.00
0005434186165	29135	Economy	3100.00
0005434463920	29135	Economy	3100.00
0005434462781	29135	Economy	3100.00
0005434448299	29135	Economy	3100.00
0005434458746	29135	Economy	3100.00
0005434458740	29135	Economy	3100.00
0005434458743	29135	Economy	3100.00
0005434458737	29135	Economy	3100.00
0005434458747	29135	Economy	3100.00
0005434186166	29135	Economy	3100.00
0005434458742	29135	Economy	3100.00
0005434458741	29135	Economy	3100.00
0005434458745	29135	Economy	3100.00
0005434458735	29135	Economy	3100.00
0005434458736	29135	Economy	3100.00
0005434448301	29135	Economy	3100.00
0005434458734	29135	Economy	3100.00
0005434458732	29135	Economy	3100.00
0005434458744	29135	Economy	3100.00
0005434448302	29135	Economy	3100.00
0005434448300	29135	Economy	3100.00
0005432604197	21457	Economy	7300.00
0005432604177	21457	Economy	7300.00
0005432604202	21457	Economy	7300.00
0005432604182	21457	Economy	7300.00
0005432604189	21457	Economy	6600.00
0005432604206	21457	Economy	6600.00
0005432604194	21457	Economy	6600.00
0005432604179	21457	Economy	6600.00
0005432604203	21457	Economy	6600.00
0005432604191	21457	Economy	6600.00
0005432604207	21457	Economy	6600.00
0005432604200	21457	Economy	6600.00
0005432604180	21457	Economy	6600.00
0005432604169	21457	Economy	6600.00
0005432604188	21457	Economy	6600.00
0005432604184	21457	Economy	6600.00
0005432604196	21457	Economy	6600.00
0005432604173	21457	Economy	6600.00
0005432604187	21457	Economy	6600.00
0005432604198	21457	Economy	6600.00
0005432604178	21457	Economy	6600.00
0005432604201	21457	Economy	6600.00
0005432604176	21457	Economy	6600.00
0005432604199	21457	Economy	6600.00
0005432604186	21457	Economy	6600.00
0005432604209	21457	Economy	6600.00
0005432604208	21457	Economy	6600.00
0005432604192	21457	Economy	6600.00
0005432604195	21457	Economy	6600.00
0005432604172	21457	Economy	6600.00
0005432604190	21457	Economy	6600.00
0005432604171	21457	Economy	6600.00
0005432604204	21457	Economy	6600.00
0005432604174	21457	Economy	6600.00
0005432604205	21457	Economy	6600.00
0005432604181	21457	Economy	6600.00
0005432604175	21457	Economy	6600.00
0005432604183	21457	Economy	6600.00
0005432604193	21457	Economy	6600.00
0005432604170	21457	Economy	6600.00
0005432604185	21457	Economy	6600.00
0005432603795	31684	Economy	7300.00
0005432603782	31684	Economy	7300.00
0005432603726	31684	Economy	6600.00
0005432603923	31684	Economy	6600.00
0005432603780	31684	Economy	6600.00
0005432603753	31684	Economy	6600.00
0005432603857	31684	Economy	6600.00
0005432603751	31684	Economy	6600.00
0005432603787	31684	Economy	6600.00
0005432603971	31684	Economy	6600.00
0005432603758	31684	Economy	6600.00
0005432603791	31684	Economy	6600.00
0005432603816	31684	Economy	6600.00
0005432603902	31684	Economy	6600.00
0005432603811	31684	Economy	6600.00
0005432603725	31684	Economy	6600.00
0005432603989	31684	Economy	6600.00
0005432603788	31684	Economy	6600.00
0005432603928	31684	Economy	6600.00
0005432603929	31684	Economy	6600.00
0005432603754	31684	Economy	6600.00
0005432604000	31684	Economy	6600.00
0005432603999	31684	Economy	6600.00
0005432603835	31684	Economy	6600.00
0005432603836	31684	Economy	6600.00
0005432603858	31684	Economy	6600.00
0005432603917	31684	Economy	6600.00
0005432603724	31684	Economy	6600.00
0005432603842	31684	Economy	6600.00
0005432603844	31684	Economy	6600.00
0005432603898	31684	Economy	6600.00
0005432603744	31684	Economy	6600.00
0005432603820	31684	Economy	6600.00
0005432603790	31684	Economy	6600.00
0005432603910	31684	Economy	6600.00
0005432603879	31684	Economy	6600.00
0005432603880	31684	Economy	6600.00
0005432603990	31684	Economy	6600.00
0005432603864	31684	Economy	6600.00
0005433293233	29606	Economy	19500.00
0005433293228	29606	Economy	19500.00
0005433293227	29606	Economy	17800.00
0005433293232	29606	Economy	17800.00
0005433293230	29606	Economy	17800.00
0005433293225	29606	Economy	17800.00
0005433293234	29606	Economy	17800.00
0005433293235	29606	Economy	17800.00
0005433293238	29606	Economy	17800.00
0005433293240	29606	Economy	17800.00
0005433293229	29606	Economy	17800.00
0005433293226	29606	Economy	17800.00
0005433293239	29606	Economy	17800.00
0005433293231	29606	Economy	17800.00
0005433293224	29606	Economy	17800.00
0005433293236	29606	Economy	17800.00
0005433293237	29606	Economy	17800.00
0005433473224	6696	Economy	14000.00
0005435257168	6696	Economy	14000.00
0005435257159	6696	Economy	14000.00
0005435257173	6696	Economy	14000.00
0005435257187	6696	Economy	12700.00
0005433473231	6696	Economy	12700.00
0005433473219	6696	Economy	12700.00
0005433473241	6696	Economy	12700.00
0005433473235	6696	Economy	12700.00
0005433473230	6696	Economy	12700.00
0005433473222	6696	Economy	12700.00
0005433473237	6696	Economy	12700.00
0005433473228	6696	Economy	12700.00
0005433473229	6696	Economy	12700.00
0005433473233	6696	Economy	12700.00
0005435257145	6696	Economy	12700.00
0005435257177	6696	Economy	12700.00
0005433473239	6696	Economy	12700.00
0005433473232	6696	Economy	12700.00
0005433473240	6696	Economy	12700.00
0005435257178	6696	Economy	12700.00
0005433473227	6696	Economy	12700.00
0005433473214	6696	Economy	12700.00
0005433473234	6696	Economy	12700.00
0005433473221	6696	Economy	12700.00
0005435257185	6696	Economy	12700.00
0005435257176	6696	Economy	12700.00
0005435257161	6696	Economy	12700.00
0005435257172	6696	Economy	12700.00
0005435257188	6696	Economy	12700.00
0005433473213	6696	Economy	12700.00
0005435257160	6696	Economy	12700.00
0005435257171	6696	Economy	12700.00
0005433473218	6696	Economy	12700.00
0005435257152	6696	Economy	12700.00
0005435257194	6696	Economy	12700.00
0005433473226	6696	Economy	12700.00
0005433473220	6696	Economy	12700.00
0005433473236	6696	Economy	12700.00
0005433473225	6696	Economy	12700.00
0005435257158	6696	Economy	12700.00
0005433473238	6696	Economy	12700.00
0005433473217	6696	Economy	12700.00
0005433473223	6696	Economy	12700.00
0005433473215	6696	Economy	12700.00
0005433473216	6696	Economy	12700.00
0005434606763	18906	Economy	6600.00
0005434606762	18906	Economy	6600.00
0005434606764	18906	Economy	6600.00
0005434606765	18906	Economy	6600.00
0005434606817	22285	Economy	6600.00
0005434604884	22285	Economy	6600.00
0005434604882	22285	Economy	6600.00
0005434606816	22285	Economy	6600.00
0005434606818	22285	Economy	6600.00
0005434604885	22285	Economy	6600.00
0005434604883	22285	Economy	6600.00
0005434606815	22285	Economy	6600.00
0005432747443	414	Business	44500.00
0005432747441	414	Business	44500.00
0005432747434	414	Business	44500.00
0005432747437	414	Business	44500.00
0005432890800	414	Business	44500.00
0005432890834	414	Business	44500.00
0005432747452	414	Economy	14800.00
0005432747438	414	Economy	14800.00
0005432747422	414	Economy	14800.00
0005432747429	414	Economy	14800.00
0005432747453	414	Economy	14800.00
0005432749777	414	Economy	14800.00
0005432747436	414	Economy	14800.00
0005432753289	414	Economy	14800.00
0005433293175	414	Economy	14800.00
0005432890698	414	Economy	16300.00
0005432890798	414	Economy	16300.00
0005432747449	414	Economy	16300.00
0005432747421	414	Economy	16300.00
0005432747450	414	Economy	16300.00
0005432890743	414	Economy	14800.00
0005432747435	414	Economy	14800.00
0005432890767	414	Economy	14800.00
0005432747426	414	Economy	14800.00
0005432747448	414	Economy	14800.00
0005432747442	414	Economy	14800.00
0005432747451	414	Economy	14800.00
0005432890848	414	Economy	14800.00
0005432747428	414	Economy	14800.00
0005432219987	414	Economy	14800.00
0005432747424	414	Economy	14800.00
0005432749775	414	Economy	14800.00
0005432747431	414	Economy	14800.00
0005432747447	414	Economy	14800.00
0005432753287	414	Economy	14800.00
0005432747445	414	Economy	14800.00
0005433875357	414	Economy	14800.00
0005432747416	414	Economy	14800.00
0005433293154	414	Economy	14800.00
0005432890766	414	Economy	14800.00
0005432753286	414	Economy	14800.00
0005432890815	414	Economy	14800.00
0005432747446	414	Economy	14800.00
0005432747423	414	Economy	14800.00
0005432890880	414	Economy	14800.00
0005432751512	414	Economy	14800.00
0005432747420	414	Economy	14800.00
0005432890830	414	Economy	14800.00
0005432890796	414	Economy	14800.00
0005432219989	414	Economy	14800.00
0005432747433	414	Economy	14800.00
0005432747439	414	Economy	14800.00
0005432219990	414	Economy	14800.00
0005432751513	414	Economy	14800.00
0005432747430	414	Economy	14800.00
0005432890729	414	Economy	14800.00
0005432747440	414	Economy	14800.00
0005432890768	414	Economy	14800.00
0005432890847	414	Economy	14800.00
0005432890846	414	Economy	14800.00
0005432890699	414	Economy	14800.00
0005432747417	414	Economy	14800.00
0005432747425	414	Economy	14800.00
0005432890797	414	Economy	14800.00
0005432753288	414	Economy	14800.00
0005432890810	414	Economy	14800.00
0005432890814	414	Economy	14800.00
0005433293176	414	Economy	14800.00
0005432219988	414	Economy	14800.00
0005433293177	414	Economy	14800.00
0005432747427	414	Economy	14800.00
0005432747455	414	Economy	14800.00
0005432747444	414	Economy	14800.00
0005432751514	414	Economy	14800.00
0005432747418	414	Economy	14800.00
0005432747454	414	Economy	14800.00
0005432747419	414	Economy	14800.00
0005432890809	414	Economy	14800.00
0005432747432	414	Economy	14800.00
0005432749776	414	Economy	14800.00
0005432749763	12080	Business	44500.00
0005432747220	12080	Business	44500.00
0005432890963	12080	Business	44500.00
0005432890966	12080	Business	44500.00
0005432747087	12080	Business	44500.00
0005432746989	12080	Business	44500.00
0005432746997	12080	Business	44500.00
0005432747034	12080	Business	44500.00
0005432747208	12080	Economy	14800.00
0005432746988	12080	Economy	14800.00
0005432753248	12080	Economy	14800.00
0005432890968	12080	Economy	14800.00
0005432890956	12080	Economy	14800.00
0005432747171	12080	Economy	14800.00
0005432890951	12080	Economy	14800.00
0005432747207	12080	Economy	14800.00
0005432747214	12080	Economy	16300.00
0005432747035	12080	Economy	16300.00
0005432756787	12080	Economy	16300.00
0005432890965	12080	Economy	14800.00
0005432747339	12080	Economy	14800.00
0005432890953	12080	Economy	14800.00
0005432890960	12080	Economy	14800.00
0005434153528	12080	Economy	14800.00
0005432749765	12080	Economy	14800.00
0005432753249	12080	Economy	14800.00
0005432747225	12080	Economy	14800.00
0005432890954	12080	Economy	14800.00
0005432749766	12080	Economy	14800.00
0005432747223	12080	Economy	14800.00
0005432890950	12080	Economy	14800.00
0005432890957	12080	Economy	14800.00
0005432890969	12080	Economy	14800.00
0005432746963	12080	Economy	14800.00
0005432753246	12080	Economy	14800.00
0005432890955	12080	Economy	14800.00
0005434153529	12080	Economy	14800.00
0005432890967	12080	Economy	14800.00
0005432747334	12080	Economy	14800.00
0005432890970	12080	Economy	14800.00
0005433875372	12080	Economy	14800.00
0005432747175	12080	Economy	14800.00
0005432747185	12080	Economy	14800.00
0005432890961	12080	Economy	14800.00
0005432890952	12080	Economy	14800.00
0005432747036	12080	Economy	14800.00
0005432747160	12080	Economy	14800.00
0005433875373	12080	Economy	14800.00
0005432747276	12080	Economy	14800.00
0005432747063	12080	Economy	14800.00
0005432747086	12080	Economy	14800.00
0005432747176	12080	Economy	14800.00
0005432746983	12080	Economy	14800.00
0005432890962	12080	Economy	14800.00
0005432747186	12080	Economy	14800.00
0005432747166	12080	Economy	14800.00
0005432747226	12080	Economy	14800.00
0005432214797	12080	Economy	14800.00
0005432756800	12080	Economy	14800.00
0005432747068	12080	Economy	14800.00
0005432747221	12080	Economy	14800.00
0005432214796	12080	Economy	14800.00
0005432747172	12080	Economy	14800.00
0005434153530	12080	Economy	14800.00
0005432890959	12080	Economy	14800.00
0005432753263	12080	Economy	14800.00
0005432753247	12080	Economy	14800.00
0005432890958	12080	Economy	14800.00
0005432890964	12080	Economy	14800.00
0005432747045	12080	Economy	14800.00
0005432749764	12080	Economy	14800.00
0005433531279	18942	Economy	28200.00
0005433524997	18942	Economy	28200.00
0005433524999	18942	Economy	25700.00
0005433533291	18942	Economy	25700.00
0005433524991	18942	Economy	25700.00
0005433533294	18942	Economy	25700.00
0005432927898	18942	Economy	25700.00
0005433525000	18942	Economy	25700.00
0005433533295	18942	Economy	25700.00
0005433524994	18942	Economy	25700.00
0005433525002	18942	Economy	25700.00
0005433524998	18942	Economy	25700.00
0005433524993	18942	Economy	25700.00
0005433525001	18942	Economy	25700.00
0005433524996	18942	Economy	25700.00
0005433533293	18942	Economy	25700.00
0005432927904	18942	Economy	25700.00
0005432927911	18942	Economy	25700.00
0005433524995	18942	Economy	25700.00
0005433524992	18942	Economy	25700.00
0005432927905	18942	Economy	25700.00
0005433531278	18942	Economy	25700.00
0005433533292	18942	Economy	25700.00
0005433524889	32515	Economy	28200.00
0005433527211	32515	Economy	28200.00
0005433524887	32515	Economy	25700.00
0005432927971	32515	Economy	25700.00
0005433524929	32515	Economy	25700.00
0005433531251	32515	Economy	25700.00
0005432927969	32515	Economy	25700.00
0005433524888	32515	Economy	25700.00
0005433527200	32515	Economy	25700.00
0005432927968	32515	Economy	25700.00
0005433524924	32515	Economy	25700.00
0005432927966	32515	Economy	25700.00
0005433524914	32515	Economy	25700.00
0005433524915	32515	Economy	25700.00
0005433527199	32515	Economy	25700.00
0005433527213	32515	Economy	25700.00
0005433524938	32515	Economy	25700.00
0005433527217	32515	Economy	25700.00
0005432927967	32515	Economy	25700.00
0005433524923	32515	Economy	25700.00
0005433527212	32515	Economy	25700.00
0005433524916	32515	Economy	25700.00
0005433524937	32515	Economy	25700.00
0005433527218	32515	Economy	25700.00
0005432927970	32515	Economy	25700.00
0005433524932	32515	Economy	25700.00
0005433524910	32515	Economy	25700.00
0005433524911	32515	Economy	25700.00
0005435372582	5270	Business	84000.00
0005434823190	5270	Business	84000.00
0005432121284	5270	Business	84000.00
0005432121296	5270	Business	84000.00
0005434823185	5270	Business	84000.00
0005435372370	5270	Business	84000.00
0005434823130	5270	Business	84000.00
0005435372580	5270	Business	84000.00
0005435386534	5270	Business	84000.00
0005434823233	5270	Business	84000.00
0005434823182	5270	Business	84000.00
0005434823175	5270	Business	84000.00
0005434558234	5270	Business	84000.00
0005434823179	5270	Business	84000.00
0005432121291	5270	Business	84000.00
0005435372411	5270	Business	84000.00
0005434823220	5270	Business	84000.00
0005434823141	5270	Business	84000.00
0005435735072	5270	Business	84000.00
0005432121287	5270	Business	84000.00
0005432121295	5270	Business	84000.00
0005434823138	5270	Business	84000.00
0005434823253	5270	Business	84000.00
0005435149989	5270	Business	84000.00
0005434823229	5270	Business	84000.00
0005435372410	5270	Business	84000.00
0005432396232	5270	Comfort	47600.00
0005432823424	5270	Comfort	47600.00
0005434823129	5270	Comfort	47600.00
0005434823198	5270	Comfort	47600.00
0005434823221	5270	Comfort	47600.00
0005434823132	5270	Comfort	47600.00
0005434823231	5270	Comfort	47600.00
0005435372526	5270	Comfort	47600.00
0005434823214	5270	Comfort	47600.00
0005434558239	5270	Comfort	47600.00
0005435372484	5270	Comfort	47600.00
0005434823211	5270	Comfort	47600.00
0005434823257	5270	Comfort	47600.00
0005435386508	5270	Comfort	47600.00
0005435372391	5270	Comfort	47600.00
0005435149984	5270	Comfort	47600.00
0005434823236	5270	Comfort	47600.00
0005434558237	5270	Comfort	47600.00
0005434823173	5270	Comfort	47600.00
0005434823222	5270	Comfort	47600.00
0005434823212	5270	Comfort	47600.00
0005434823234	5270	Comfort	47600.00
0005434823227	5270	Comfort	47600.00
0005435372352	5270	Comfort	47600.00
0005434823197	5270	Comfort	47600.00
0005435661899	5270	Comfort	47600.00
0005435149979	5270	Comfort	47600.00
0005435299713	5270	Comfort	47600.00
0005435372476	5270	Comfort	47600.00
0005434823204	5270	Comfort	47600.00
0005435304114	5270	Comfort	47600.00
0005435372267	5270	Comfort	47600.00
0005432823425	5270	Comfort	47600.00
0005435372610	5270	Comfort	47600.00
0005434823162	5270	Comfort	47600.00
0005434823215	5270	Economy	28000.00
0005435372165	5270	Economy	28000.00
0005434823154	5270	Economy	28000.00
0005435372733	5270	Economy	28000.00
0005434823238	5270	Economy	28000.00
0005434823142	5270	Economy	28000.00
0005434823250	5270	Economy	28000.00
0005432121294	5270	Economy	28000.00
0005434823161	5270	Economy	28000.00
0005435372463	5270	Economy	28000.00
0005434823225	5270	Economy	28000.00
0005434823163	5270	Economy	28000.00
0005434823202	5270	Economy	28000.00
0005434823210	5270	Economy	28000.00
0005432121292	5270	Economy	28000.00
0005435372611	5270	Economy	28000.00
0005434823217	5270	Economy	28000.00
0005434823251	5270	Economy	28000.00
0005434823207	5270	Economy	28000.00
0005434823258	5270	Economy	28000.00
0005434823177	5270	Economy	28000.00
0005434823174	5270	Economy	28000.00
0005432121285	5270	Economy	28000.00
0005434823131	5270	Economy	28000.00
0005432396230	5270	Economy	28000.00
0005435372386	5270	Economy	28000.00
0005435149991	5270	Economy	28000.00
0005432121297	5270	Economy	28000.00
0005434823139	5270	Economy	28000.00
0005435299712	5270	Economy	28000.00
0005434823167	5270	Economy	28000.00
0005434823228	5270	Economy	28000.00
0005435149985	5270	Economy	28000.00
0005435735087	5270	Economy	28000.00
0005435372095	5270	Economy	28000.00
0005434828686	5270	Economy	28000.00
0005435372543	5270	Economy	28000.00
0005434831133	5270	Economy	28000.00
0005435149987	5270	Economy	28000.00
0005435372404	5270	Economy	28000.00
0005432394091	5270	Economy	28000.00
0005432394092	5270	Economy	28000.00
0005435372456	5270	Economy	28000.00
0005435372394	5270	Economy	28000.00
0005434823242	5270	Economy	28000.00
0005434823203	5270	Economy	28000.00
0005435372367	5270	Economy	30800.00
0005435372429	5270	Economy	28000.00
0005434823199	5270	Economy	30800.00
0005434558240	5270	Economy	30800.00
0005434823241	5270	Economy	30800.00
0005434831131	5270	Economy	28000.00
0005435304113	5270	Economy	28000.00
0005434823152	5270	Economy	28000.00
0005435149993	5270	Economy	28000.00
0005434823223	5270	Economy	28000.00
0005434823209	5270	Economy	28000.00
0005434823193	5270	Economy	28000.00
0005434823159	5270	Economy	28000.00
0005434823194	5270	Economy	28000.00
0005435661898	5270	Economy	28000.00
0005435372306	5270	Economy	28000.00
0005435372333	5270	Economy	28000.00
0005435372421	5270	Economy	28000.00
0005434823216	5270	Economy	28000.00
0005434823148	5270	Economy	28000.00
0005434828687	5270	Economy	28000.00
0005435372351	5270	Economy	28000.00
0005435372508	5270	Economy	28000.00
0005434558235	5270	Economy	28000.00
0005435372288	5270	Economy	28000.00
0005435372405	5270	Economy	28000.00
0005434823235	5270	Economy	28000.00
0005435372440	5270	Economy	28000.00
0005434823186	5270	Economy	28000.00
0005434823232	5270	Economy	28000.00
0005435372308	5270	Economy	28000.00
0005434823147	5270	Economy	28000.00
0005434823181	5270	Economy	28000.00
0005435372425	5270	Economy	28000.00
0005434823237	5270	Economy	28000.00
0005434823168	5270	Economy	28000.00
0005434823200	5270	Economy	28000.00
0005435149992	5270	Economy	28000.00
0005434831129	5270	Economy	28000.00
0005432396229	5270	Economy	28000.00
0005435372507	5270	Economy	28000.00
0005432396231	5270	Economy	28000.00
0005434823136	5270	Economy	28000.00
0005435372296	5270	Economy	28000.00
0005434558236	5270	Economy	28000.00
0005435372309	5270	Economy	28000.00
0005435372277	5270	Economy	28000.00
0005434823243	5270	Economy	28000.00
0005435372366	5270	Economy	28000.00
0005435372338	5270	Economy	28000.00
0005435372259	5270	Economy	28000.00
0005435372266	5270	Economy	28000.00
0005435735079	5270	Economy	28000.00
0005434823143	5270	Economy	28000.00
0005434823213	5270	Economy	28000.00
0005434558241	5270	Economy	28000.00
0005434823149	5270	Economy	28000.00
0005435372231	5270	Economy	28000.00
0005434823240	5270	Economy	28000.00
0005435372310	5270	Economy	28000.00
0005434823244	5270	Economy	28000.00
0005434823247	5270	Economy	28000.00
0005434823165	5270	Economy	28000.00
0005434823176	5270	Economy	28000.00
0005435372424	5270	Economy	28000.00
0005434823192	5270	Economy	28000.00
0005434823160	5270	Economy	28000.00
0005435386510	5270	Economy	28000.00
0005434823191	5270	Economy	28000.00
0005434664951	5270	Economy	28000.00
0005434823188	5270	Economy	28000.00
0005435149982	5270	Economy	28000.00
0005434823172	5270	Economy	28000.00
0005434823157	5270	Economy	28000.00
0005434823189	5270	Economy	28000.00
0005434823205	5270	Economy	28000.00
0005434823206	5270	Economy	28000.00
0005434823169	5270	Economy	28000.00
0005434823178	5270	Economy	28000.00
0005434823195	5270	Economy	28000.00
0005434823208	5270	Economy	28000.00
0005434823260	5270	Economy	28000.00
0005434823219	5270	Economy	28000.00
0005434823150	5270	Economy	28000.00
0005435372243	5270	Economy	28000.00
0005435372594	5270	Economy	28000.00
0005435372515	5270	Economy	30800.00
0005434823135	5270	Economy	30800.00
0005434823249	5270	Economy	28000.00
0005434823224	5270	Economy	28000.00
0005435372533	5270	Economy	28000.00
0005435372614	5270	Economy	28000.00
0005434823252	5270	Economy	28000.00
0005435386465	5270	Economy	28000.00
0005434823183	5270	Economy	28000.00
0005434823246	5270	Economy	28000.00
0005435372823	5270	Economy	28000.00
0005435386481	5270	Economy	28000.00
0005434823239	5270	Economy	28000.00
0005434831132	5270	Economy	28000.00
0005435372354	5270	Economy	28000.00
0005435149981	5270	Economy	28000.00
0005434558242	5270	Economy	28000.00
0005435372477	5270	Economy	28000.00
0005434823230	5270	Economy	28000.00
0005432121286	5270	Economy	28000.00
0005435372542	5270	Economy	28000.00
0005435299714	5270	Economy	28000.00
0005434823187	5270	Economy	28000.00
0005435149980	5270	Economy	28000.00
0005435372669	5270	Economy	28000.00
0005434823196	5270	Economy	28000.00
0005434828685	5270	Economy	28000.00
0005435372576	5270	Economy	28000.00
0005435372675	5270	Economy	28000.00
0005435372581	5270	Economy	28000.00
0005435149983	5270	Economy	28000.00
0005434823180	5270	Economy	28000.00
0005432121289	5270	Economy	28000.00
0005435372591	5270	Economy	28000.00
0005434558243	5270	Economy	28000.00
0005432121288	5270	Economy	28000.00
0005434823144	5270	Economy	28000.00
0005434823153	5270	Economy	28000.00
0005434823255	5270	Economy	28000.00
0005435372278	5270	Economy	28000.00
0005432394093	5270	Economy	28000.00
0005435149990	5270	Economy	28000.00
0005434823134	5270	Economy	28000.00
0005434823201	5270	Economy	28000.00
0005434823171	5270	Economy	28000.00
0005435735070	5270	Economy	28000.00
0005435149988	5270	Economy	28000.00
0005435372337	5270	Economy	28000.00
0005435372713	5270	Economy	28000.00
0005435372419	5270	Economy	28000.00
0005435735080	5270	Economy	28000.00
0005434823245	5270	Economy	28000.00
0005432121293	5270	Economy	28000.00
0005434823146	5270	Economy	28000.00
0005434831130	5270	Economy	28000.00
0005432121290	5270	Economy	28000.00
0005434823170	5270	Economy	28000.00
0005434823133	5270	Economy	28000.00
0005434823218	5270	Economy	28000.00
0005432394090	5270	Economy	28000.00
0005434823156	5270	Economy	28000.00
0005435299715	5270	Economy	28000.00
0005434823254	5270	Economy	28000.00
0005434823184	5270	Economy	28000.00
0005435372289	5270	Economy	28000.00
0005434823155	5270	Economy	28000.00
0005434823145	5270	Economy	28000.00
0005434823248	5270	Economy	28000.00
0005434823256	5270	Economy	28000.00
0005434558238	5270	Economy	28000.00
0005435735073	5270	Economy	28000.00
0005434823137	5270	Economy	28000.00
0005435372478	5270	Economy	28000.00
0005434823151	5270	Economy	28000.00
0005434558233	5270	Economy	28000.00
0005434823140	5270	Economy	28000.00
0005435372307	5270	Economy	28000.00
0005435372457	5270	Economy	28000.00
0005434823259	5270	Economy	28000.00
0005434823226	5270	Economy	28000.00
0005434823158	5270	Economy	28000.00
0005435149986	5270	Economy	28000.00
0005435372420	5270	Economy	28000.00
0005435386509	5270	Economy	28000.00
0005434823164	5270	Economy	28000.00
0005434823166	5270	Economy	28000.00
0005435372620	5270	Economy	28000.00
0005435386559	9889	Business	84000.00
0005435299762	9889	Business	84000.00
0005434822109	9889	Business	84000.00
0005434821944	9889	Business	84000.00
0005434822155	9889	Business	84000.00
0005434822039	9889	Business	84000.00
0005434822093	9889	Business	84000.00
0005435373086	9889	Business	84000.00
0005435373042	9889	Business	84000.00
0005434822188	9889	Business	84000.00
0005434821979	9889	Business	84000.00
0005434558154	9889	Business	84000.00
0005435373083	9889	Business	84000.00
0005435735127	9889	Business	84000.00
0005435373032	9889	Business	84000.00
0005434821703	9889	Business	84000.00
0005434822044	9889	Business	84000.00
0005434821709	9889	Comfort	47600.00
0005435373061	9889	Business	84000.00
0005435373035	9889	Comfort	47600.00
0005434821929	9889	Comfort	47600.00
0005435373041	9889	Comfort	47600.00
0005435386561	9889	Comfort	47600.00
0005434822110	9889	Comfort	47600.00
0005434822250	9889	Comfort	47600.00
0005434821849	9889	Comfort	47600.00
0005434822078	9889	Comfort	47600.00
0005434828660	9889	Comfort	47600.00
0005434822030	9889	Comfort	47600.00
0005435661923	9889	Comfort	47600.00
0005434821839	9889	Comfort	47600.00
0005435373076	9889	Comfort	47600.00
0005434828658	9889	Comfort	47600.00
0005434822495	9889	Comfort	47600.00
0005434828665	9889	Comfort	47600.00
0005435373047	9889	Comfort	47600.00
0005434822282	9889	Comfort	47600.00
0005435373074	9889	Comfort	47600.00
0005435149900	9889	Comfort	47600.00
0005432203037	9889	Comfort	47600.00
0005434822013	9889	Comfort	47600.00
0005434822029	9889	Comfort	47600.00
0005435735128	9889	Comfort	47600.00
0005435373094	9889	Comfort	47600.00
0005434822099	9889	Comfort	47600.00
0005435179691	9889	Comfort	47600.00
0005434822325	9889	Comfort	47600.00
0005434822153	9889	Comfort	47600.00
0005435373039	9889	Comfort	47600.00
0005434822265	9889	Comfort	47600.00
0005434822450	9889	Comfort	47600.00
0005434821819	9889	Economy	28000.00
0005434821701	9889	Economy	28000.00
0005434821900	9889	Economy	28000.00
0005434822464	9889	Economy	28000.00
0005435386558	9889	Economy	28000.00
0005435373070	9889	Economy	28000.00
0005434822106	9889	Economy	28000.00
0005434664935	9889	Economy	28000.00
0005435302188	9889	Economy	28000.00
0005435373052	9889	Economy	28000.00
0005434822053	9889	Economy	28000.00
0005434558153	9889	Economy	28000.00
0005434822646	9889	Economy	28000.00
0005434828657	9889	Economy	28000.00
0005435373030	9889	Economy	28000.00
0005434822645	9889	Economy	28000.00
0005434821660	9889	Economy	28000.00
0005434822281	9889	Economy	28000.00
0005435299760	9889	Economy	28000.00
0005434822105	9889	Economy	28000.00
0005434822045	9889	Economy	28000.00
0005434821921	9889	Economy	28000.00
0005434822376	9889	Economy	28000.00
0005435373077	9889	Economy	28000.00
0005435373088	9889	Economy	28000.00
0005435373081	9889	Economy	28000.00
0005434822113	9889	Economy	28000.00
0005434821584	9889	Economy	28000.00
0005435373080	9889	Economy	28000.00
0005435373040	9889	Economy	28000.00
0005434821978	9889	Economy	28000.00
0005435386560	9889	Economy	28000.00
0005434831082	9889	Economy	28000.00
0005434821770	9889	Economy	28000.00
0005434822114	9889	Economy	28000.00
0005434822299	9889	Economy	28000.00
0005434828659	9889	Economy	28000.00
0005434822448	9889	Economy	28000.00
0005435149873	9889	Economy	28000.00
0005434822022	9889	Economy	28000.00
0005435373072	9889	Economy	28000.00
0005434822283	9889	Economy	28000.00
0005435299763	9889	Economy	28000.00
0005434821713	9889	Economy	28000.00
0005435373034	9889	Economy	28000.00
0005435149868	9889	Economy	28000.00
0005435149869	9889	Economy	28000.00
0005434822098	9889	Economy	28000.00
0005434558172	9889	Economy	28000.00
0005434822167	9889	Economy	28000.00
0005434822440	9889	Economy	28000.00
0005435373053	9889	Economy	28000.00
0005435149811	9889	Economy	28000.00
0005435373043	9889	Economy	30800.00
0005434821561	9889	Economy	28000.00
0005435299759	9889	Economy	30800.00
0005434822095	9889	Economy	28000.00
0005435373045	9889	Economy	30800.00
0005434821835	9889	Economy	28000.00
0005434822266	9889	Economy	30800.00
0005435373082	9889	Economy	30800.00
0005435373048	9889	Economy	28000.00
0005434822354	9889	Economy	28000.00
0005435373029	9889	Economy	28000.00
0005434822478	9889	Economy	28000.00
0005434822112	9889	Economy	28000.00
0005434821811	9889	Economy	28000.00
0005435735129	9889	Economy	28000.00
0005434821919	9889	Economy	28000.00
0005434822076	9889	Economy	28000.00
0005434831090	9889	Economy	28000.00
0005435373091	9889	Economy	28000.00
0005434822324	9889	Economy	28000.00
0005434558162	9889	Economy	28000.00
0005432400065	9889	Economy	28000.00
0005435373084	9889	Economy	28000.00
0005435373067	9889	Economy	28000.00
0005432203040	9889	Economy	28000.00
0005435373071	9889	Economy	28000.00
0005434828655	9889	Economy	28000.00
0005435373092	9889	Economy	28000.00
0005434821836	9889	Economy	28000.00
0005434822014	9889	Economy	28000.00
0005434822284	9889	Economy	28000.00
0005434821782	9889	Economy	28000.00
0005434821467	9889	Economy	28000.00
0005434821613	9889	Economy	28000.00
0005432203038	9889	Economy	28000.00
0005434831083	9889	Economy	28000.00
0005434822577	9889	Economy	28000.00
0005434822158	9889	Economy	28000.00
0005434822209	9889	Economy	28000.00
0005434822122	9889	Economy	28000.00
0005435373059	9889	Economy	28000.00
0005435149812	9889	Economy	28000.00
0005435373064	9889	Economy	28000.00
0005435373062	9889	Economy	28000.00
0005434822292	9889	Economy	28000.00
0005435302185	9889	Economy	28000.00
0005434664922	9889	Economy	28000.00
0005435735126	9889	Economy	28000.00
0005434821750	9889	Economy	28000.00
0005434831099	9889	Economy	28000.00
0005434822205	9889	Economy	28000.00
0005432203044	9889	Economy	28000.00
0005434822486	9889	Economy	28000.00
0005434822092	9889	Economy	28000.00
0005435373057	9889	Economy	28000.00
0005434558173	9889	Economy	28000.00
0005432396201	9889	Economy	28000.00
0005435373073	9889	Economy	28000.00
0005434831098	9889	Economy	28000.00
0005434822362	9889	Economy	28000.00
0005434822249	9889	Economy	28000.00
0005432203043	9889	Economy	28000.00
0005435386556	9889	Economy	28000.00
0005435373069	9889	Economy	28000.00
0005434821840	9889	Economy	28000.00
0005435149882	9889	Economy	28000.00
0005434822077	9889	Economy	28000.00
0005435373028	9889	Economy	28000.00
0005434822177	9889	Economy	28000.00
0005434821975	9889	Economy	28000.00
0005435735130	9889	Economy	28000.00
0005434822108	9889	Economy	28000.00
0005434558187	9889	Economy	28000.00
0005434821710	9889	Economy	28000.00
0005434822291	9889	Economy	28000.00
0005434821564	9889	Economy	28000.00
0005435373068	9889	Economy	28000.00
0005434821989	9889	Economy	28000.00
0005434822062	9889	Economy	28000.00
0005434822121	9889	Economy	28000.00
0005435386555	9889	Economy	28000.00
0005435373049	9889	Economy	28000.00
0005434828662	9889	Economy	28000.00
0005434821841	9889	Economy	28000.00
0005434822166	9889	Economy	28000.00
0005435373089	9889	Economy	28000.00
0005435373066	9889	Economy	28000.00
0005435373044	9889	Economy	28000.00
0005435373036	9889	Economy	28000.00
0005434822159	9889	Economy	28000.00
0005434822479	9889	Economy	28000.00
0005434821363	9889	Economy	28000.00
0005434822701	9889	Economy	28000.00
0005435373079	9889	Economy	28000.00
0005435373055	9889	Economy	28000.00
0005435373037	9889	Economy	28000.00
0005434558182	9889	Economy	30800.00
0005434822246	9889	Economy	30800.00
0005435373046	9889	Economy	30800.00
0005434821947	9889	Economy	30800.00
0005434822247	9889	Economy	28000.00
0005434828656	9889	Economy	28000.00
0005434558146	9889	Economy	28000.00
0005435373058	9889	Economy	28000.00
0005434821812	9889	Economy	28000.00
0005435373054	9889	Economy	28000.00
0005434821737	9889	Economy	28000.00
0005434821920	9889	Economy	28000.00
0005435149855	9889	Economy	28000.00
0005435373065	9889	Economy	28000.00
0005435661922	9889	Economy	28000.00
0005434822278	9889	Economy	28000.00
0005434821818	9889	Economy	28000.00
0005435299761	9889	Economy	28000.00
0005435373078	9889	Economy	28000.00
0005434822494	9889	Economy	28000.00
0005434822377	9889	Economy	28000.00
0005434822447	9889	Economy	28000.00
0005434821583	9889	Economy	28000.00
0005435373033	9889	Economy	28000.00
0005434822115	9889	Economy	28000.00
0005434558163	9889	Economy	28000.00
0005435373051	9889	Economy	28000.00
0005435661921	9889	Economy	28000.00
0005435302187	9889	Economy	28000.00
0005434821943	9889	Economy	28000.00
0005434821930	9889	Economy	28000.00
0005434822063	9889	Economy	28000.00
0005434822061	9889	Economy	28000.00
0005432203042	9889	Economy	28000.00
0005434828654	9889	Economy	28000.00
0005435302186	9889	Economy	28000.00
0005434822361	9889	Economy	28000.00
0005435373063	9889	Economy	28000.00
0005434664932	9889	Economy	28000.00
0005435373031	9889	Economy	28000.00
0005435373038	9889	Economy	28000.00
0005435149785	9889	Economy	28000.00
0005434822715	9889	Economy	28000.00
0005434822248	9889	Economy	28000.00
0005434822508	9889	Economy	28000.00
0005435373060	9889	Economy	28000.00
0005434821562	9889	Economy	28000.00
0005434822714	9889	Economy	28000.00
0005434821738	9889	Economy	28000.00
0005435373056	9889	Economy	28000.00
0005435373075	9889	Economy	28000.00
0005432203041	9889	Economy	28000.00
0005434821899	9889	Economy	28000.00
0005435386557	9889	Economy	28000.00
0005435149786	9889	Economy	28000.00
0005432203039	9889	Economy	28000.00
0005434822088	9889	Economy	28000.00
0005434821803	9889	Economy	28000.00
0005434821977	9889	Economy	28000.00
0005435373093	9889	Economy	28000.00
0005434822465	9889	Economy	28000.00
0005435373085	9889	Economy	28000.00
0005435373050	9889	Economy	28000.00
0005435735125	9889	Economy	28000.00
0005434821853	9889	Economy	28000.00
0005434822154	9889	Economy	28000.00
0005434821714	9889	Economy	28000.00
0005435373087	9889	Economy	28000.00
0005434822485	9889	Economy	28000.00
0005434822449	9889	Economy	28000.00
0005435373090	9889	Economy	28000.00
0005434821702	9889	Economy	28000.00
0005435386554	9889	Economy	28000.00
0005435373027	9889	Economy	28000.00
0005434821901	9889	Economy	28000.00
0005434821781	9889	Economy	28000.00
0005434822100	9889	Economy	28000.00
0005434821834	9889	Economy	28000.00
0005434558171	9889	Economy	28000.00
0005435082768	6987	Economy	7400.00
0005435790297	6987	Economy	7400.00
0005435082765	6987	Economy	7400.00
0005435082766	6987	Economy	7400.00
0005435082767	6987	Economy	7400.00
0005435082764	6987	Economy	7400.00
0005435082770	6987	Economy	7400.00
0005435790298	6987	Economy	7400.00
0005435790296	6987	Economy	7400.00
0005435082769	6987	Economy	7400.00
0005435082692	25989	Economy	8200.00
0005435082702	25989	Economy	7400.00
0005435082703	25989	Economy	7400.00
0005435082679	25989	Economy	7400.00
0005435082691	25989	Economy	7400.00
0005435082701	25989	Economy	7400.00
0005435082693	25989	Economy	7400.00
0005435082690	25989	Economy	7400.00
0005435082678	25989	Economy	7400.00
0005434213899	9559	Business	32800.00
0005434213885	9559	Business	32800.00
0005434756308	9559	Business	32800.00
0005434756311	9559	Business	32800.00
0005434756292	9559	Business	32800.00
0005434213985	9559	Business	32800.00
0005434756324	9559	Business	32800.00
0005434756306	9559	Business	32800.00
0005434756295	9559	Business	32800.00
0005434213889	9559	Business	32800.00
0005434213907	9559	Business	32800.00
0005434756319	9559	Business	32800.00
0005434756312	9559	Economy	10900.00
0005434213817	9559	Economy	10900.00
0005434756328	9559	Economy	10900.00
0005434214036	9559	Economy	10900.00
0005434213833	9559	Economy	10900.00
0005434213984	9559	Economy	10900.00
0005434756325	9559	Economy	10900.00
0005434756322	9559	Economy	10900.00
0005434756310	9559	Economy	10900.00
0005434756299	9559	Economy	10900.00
0005434213862	9559	Economy	12000.00
0005434756304	9559	Economy	12000.00
0005434213942	9559	Economy	12000.00
0005434213824	9559	Economy	12000.00
0005434214104	9559	Economy	10900.00
0005434756291	9559	Economy	10900.00
0005434756293	9559	Economy	10900.00
0005434756318	9559	Economy	10900.00
0005434756313	9559	Economy	10900.00
0005434213935	9559	Economy	10900.00
0005434756289	9559	Economy	10900.00
0005434756300	9559	Economy	10900.00
0005434756309	9559	Economy	10900.00
0005434213914	9559	Economy	10900.00
0005434213878	9559	Economy	10900.00
0005434214019	9559	Economy	10900.00
0005434213988	9559	Economy	10900.00
0005434214057	9559	Economy	10900.00
0005434213834	9559	Economy	10900.00
0005434214025	9559	Economy	10900.00
0005434756290	9559	Economy	10900.00
0005434756288	9559	Economy	10900.00
0005434213994	9559	Economy	10900.00
0005434756307	9559	Economy	10900.00
0005434213943	9559	Economy	10900.00
0005434756298	9559	Economy	10900.00
0005434213932	9559	Economy	10900.00
0005434756321	9559	Economy	10900.00
0005434213782	9559	Economy	10900.00
0005434213957	9559	Economy	10900.00
0005434214004	9559	Economy	10900.00
0005434756315	9559	Economy	10900.00
0005434756287	9559	Economy	10900.00
0005434213971	9559	Economy	10900.00
0005434756327	9559	Economy	10900.00
0005434756317	9559	Economy	10900.00
0005434756316	9559	Economy	10900.00
0005434213955	9559	Economy	10900.00
0005434213848	9559	Economy	10900.00
0005434213931	9559	Economy	10900.00
0005434213986	9559	Economy	10900.00
0005434213781	9559	Economy	10900.00
0005434214047	9559	Economy	10900.00
0005434213924	9559	Economy	10900.00
0005434213852	9559	Economy	10900.00
0005434213915	9559	Economy	10900.00
0005434756296	9559	Economy	10900.00
0005434213939	9559	Economy	10900.00
0005434213987	9559	Economy	10900.00
0005434213954	9559	Economy	10900.00
0005434756314	9559	Economy	10900.00
0005434756320	9559	Economy	10900.00
0005434756305	9559	Economy	10900.00
0005434214109	9559	Economy	10900.00
0005434756303	9559	Economy	10900.00
0005434213823	9559	Economy	10900.00
0005434213995	9559	Economy	10900.00
0005434756326	9559	Economy	10900.00
0005434214046	9559	Economy	10900.00
0005434213830	9559	Economy	10900.00
0005434756301	9559	Economy	10900.00
0005434756297	9559	Economy	10900.00
0005434756294	9559	Economy	10900.00
0005434214059	9559	Economy	10900.00
0005434214029	9559	Economy	10900.00
0005434756323	9559	Economy	10900.00
0005434213956	9559	Economy	10900.00
0005434213944	9559	Economy	10900.00
0005434756302	9559	Economy	10900.00
0005434214108	9559	Economy	10900.00
0005434213993	9559	Economy	10900.00
0005434755789	28595	Business	32800.00
0005434755847	28595	Business	32800.00
0005434755851	28595	Business	32800.00
0005434755999	28595	Business	32800.00
0005434755751	28595	Business	32800.00
0005434214359	28595	Business	32800.00
0005434214347	28595	Business	32800.00
0005434214348	28595	Business	32800.00
0005434755715	28595	Business	32800.00
0005434756015	28595	Business	32800.00
0005434756019	28595	Business	32800.00
0005434755901	28595	Business	32800.00
0005434755775	28595	Economy	10900.00
0005434214327	28595	Economy	10900.00
0005434755805	28595	Economy	10900.00
0005434214346	28595	Economy	10900.00
0005434214340	28595	Economy	10900.00
0005434755995	28595	Economy	10900.00
0005434755965	28595	Economy	10900.00
0005434214342	28595	Economy	10900.00
0005434755827	28595	Economy	10900.00
0005434214337	28595	Economy	10900.00
0005434214336	28595	Economy	12000.00
0005434755821	28595	Economy	12000.00
0005434755986	28595	Economy	12000.00
0005434214354	28595	Economy	12000.00
0005434214335	28595	Economy	12000.00
0005434214344	28595	Economy	10900.00
0005434755918	28595	Economy	10900.00
0005434755842	28595	Economy	10900.00
0005434755745	28595	Economy	10900.00
0005434755826	28595	Economy	10900.00
0005434755716	28595	Economy	10900.00
0005434214351	28595	Economy	10900.00
0005434214332	28595	Economy	10900.00
0005434214333	28595	Economy	10900.00
0005434755788	28595	Economy	10900.00
0005434214324	28595	Economy	10900.00
0005434214352	28595	Economy	10900.00
0005434755957	28595	Economy	10900.00
0005434755804	28595	Economy	10900.00
0005434214322	28595	Economy	10900.00
0005434214363	28595	Economy	10900.00
0005434755713	28595	Economy	10900.00
0005434214343	28595	Economy	10900.00
0005434214353	28595	Economy	10900.00
0005434214338	28595	Economy	10900.00
0005434214330	28595	Economy	10900.00
0005434214356	28595	Economy	10900.00
0005434755832	28595	Economy	10900.00
0005434755935	28595	Economy	10900.00
0005434214349	28595	Economy	10900.00
0005434755744	28595	Economy	10900.00
0005434214345	28595	Economy	10900.00
0005434755885	28595	Economy	10900.00
0005434214325	28595	Economy	10900.00
0005434214318	28595	Economy	10900.00
0005434214329	28595	Economy	10900.00
0005434755714	28595	Economy	10900.00
0005434755998	28595	Economy	10900.00
0005434755828	28595	Economy	10900.00
0005434755867	28595	Economy	10900.00
0005434214358	28595	Economy	10900.00
0005434755936	28595	Economy	10900.00
0005434755848	28595	Economy	10900.00
0005434756018	28595	Economy	10900.00
0005434755785	28595	Economy	10900.00
0005434214362	28595	Economy	10900.00
0005434214360	28595	Economy	10900.00
0005434755877	28595	Economy	10900.00
0005434214326	28595	Economy	10900.00
0005434214331	28595	Economy	10900.00
0005434214357	28595	Economy	10900.00
0005434755917	28595	Economy	10900.00
0005434755841	28595	Economy	10900.00
0005434214355	28595	Economy	10900.00
0005434755911	28595	Economy	10900.00
0005434214341	28595	Economy	10900.00
0005434756028	28595	Economy	10900.00
0005434755784	28595	Economy	10900.00
0005434214339	28595	Economy	10900.00
0005434214317	28595	Economy	10900.00
0005434214319	28595	Economy	10900.00
0005434755774	28595	Economy	10900.00
0005434214323	28595	Economy	10900.00
0005434755886	28595	Economy	10900.00
0005434214334	28595	Economy	10900.00
0005434214321	28595	Economy	10900.00
0005434214350	28595	Economy	10900.00
0005434214320	28595	Economy	10900.00
0005434214361	28595	Economy	10900.00
0005434214328	28595	Economy	10900.00
0005435100113	10813	Economy	9800.00
0005435100114	10813	Economy	9800.00
0005434760162	10813	Economy	8900.00
0005435100112	10813	Economy	8900.00
0005434760161	10813	Economy	8900.00
0005434760171	10813	Economy	8900.00
0005435100093	31797	Economy	8900.00
0005434760189	31797	Economy	8900.00
0005435100074	31797	Economy	8900.00
0005435100096	31797	Economy	8900.00
0005434760188	31797	Economy	8900.00
0005435100094	31797	Economy	8900.00
0005434760190	31797	Economy	8900.00
0005434639258	1976	Economy	20900.00
0005434639264	1976	Economy	20900.00
0005433202240	1976	Economy	20900.00
0005433202219	1976	Economy	19000.00
0005434639248	1976	Economy	19000.00
0005433202141	1976	Economy	19000.00
0005434639259	1976	Economy	19000.00
0005433202221	1976	Economy	19000.00
0005434639246	1976	Economy	19000.00
0005434639261	1976	Economy	19000.00
0005433202164	1976	Economy	19000.00
0005434639263	1976	Economy	19000.00
0005434639250	1976	Economy	19000.00
0005432290625	1976	Economy	19000.00
0005432290624	1976	Economy	19000.00
0005435948325	1976	Economy	19000.00
0005432290623	1976	Economy	19000.00
0005433202156	1976	Economy	19000.00
0005434639241	1976	Economy	19000.00
0005433202205	1976	Economy	19000.00
0005434639256	1976	Economy	19000.00
0005434639262	1976	Economy	19000.00
0005434639244	1976	Economy	19000.00
0005434639255	1976	Economy	19000.00
0005434639254	1976	Economy	19000.00
0005434639247	1976	Economy	19000.00
0005434639240	1976	Economy	19000.00
0005433202202	1976	Economy	19000.00
0005434639251	1976	Economy	19000.00
0005433202182	1976	Economy	19000.00
0005434639242	1976	Economy	19000.00
0005434639260	1976	Economy	19000.00
0005433202142	1976	Economy	19000.00
0005434639245	1976	Economy	19000.00
0005433202220	1976	Economy	19000.00
0005434639257	1976	Economy	19000.00
0005434639252	1976	Economy	19000.00
0005434639253	1976	Economy	19000.00
0005435948326	1976	Economy	19000.00
0005434639243	1976	Economy	19000.00
0005434639249	1976	Economy	19000.00
0005434639238	1976	Economy	19000.00
0005434639239	1976	Economy	19000.00
0005433202203	1976	Economy	19000.00
0005433202204	1976	Economy	19000.00
0005433202300	23304	Economy	20900.00
0005434639033	23304	Economy	20900.00
0005433202301	23304	Economy	20900.00
0005434638985	23304	Economy	20900.00
0005434639031	23304	Economy	19000.00
0005434638958	23304	Economy	19000.00
0005433202310	23304	Economy	19000.00
0005433202311	23304	Economy	19000.00
0005434638938	23304	Economy	19000.00
0005434638975	23304	Economy	19000.00
0005433202307	23304	Economy	19000.00
0005434639038	23304	Economy	19000.00
0005434638954	23304	Economy	19000.00
0005434639029	23304	Economy	19000.00
0005434638909	23304	Economy	19000.00
0005434638995	23304	Economy	19000.00
0005434638907	23304	Economy	19000.00
0005434639073	23304	Economy	19000.00
0005434638996	23304	Economy	19000.00
0005434639013	23304	Economy	19000.00
0005433202309	23304	Economy	19000.00
0005433202305	23304	Economy	19000.00
0005434638910	23304	Economy	19000.00
0005434638937	23304	Economy	19000.00
0005434638926	23304	Economy	19000.00
0005434638957	23304	Economy	19000.00
0005434638919	23304	Economy	19000.00
0005434638921	23304	Economy	19000.00
0005434639015	23304	Economy	19000.00
0005434639030	23304	Economy	19000.00
0005434639032	23304	Economy	19000.00
0005434638959	23304	Economy	19000.00
0005433202298	23304	Economy	19000.00
0005433202312	23304	Economy	19000.00
0005434638981	23304	Economy	19000.00
0005434639014	23304	Economy	19000.00
0005433202302	23304	Economy	19000.00
0005434638939	23304	Economy	19000.00
0005433202299	23304	Economy	19000.00
0005434638920	23304	Economy	19000.00
0005434639064	23304	Economy	19000.00
0005433202308	23304	Economy	19000.00
0005433202303	23304	Economy	19000.00
0005434639003	23304	Economy	19000.00
0005433202306	23304	Economy	19000.00
0005434638961	23304	Economy	19000.00
0005433202304	23304	Economy	19000.00
0005434638960	23304	Economy	19000.00
0005435326583	6065	Business	69700.00
0005435326553	6065	Business	69700.00
0005434600739	6065	Business	69700.00
0005434600727	6065	Business	69700.00
0005434600730	6065	Business	69700.00
0005434600732	6065	Business	69700.00
0005435326585	6065	Economy	23200.00
0005434600721	6065	Economy	23200.00
0005433533299	6065	Economy	23200.00
0005433531281	6065	Economy	23200.00
0005433531283	6065	Economy	23200.00
0005434600724	6065	Economy	23200.00
0005435326575	6065	Economy	25600.00
0005432111270	6065	Economy	25600.00
0005434600722	6065	Economy	25600.00
0005434600740	6065	Economy	23200.00
0005434600734	6065	Economy	23200.00
0005434600713	6065	Economy	23200.00
0005434600714	6065	Economy	23200.00
0005434600737	6065	Economy	23200.00
0005434600738	6065	Economy	23200.00
0005435326591	6065	Economy	23200.00
0005434600731	6065	Economy	23200.00
0005434600735	6065	Economy	23200.00
0005435326609	6065	Economy	23200.00
0005434600718	6065	Economy	23200.00
0005432111269	6065	Economy	23200.00
0005435326560	6065	Economy	23200.00
0005434600736	6065	Economy	23200.00
0005434600719	6065	Economy	23200.00
0005434600723	6065	Economy	23200.00
0005433533296	6065	Economy	23200.00
0005435326579	6065	Economy	23200.00
0005435326584	6065	Economy	23200.00
0005433533298	6065	Economy	23200.00
0005435326599	6065	Economy	23200.00
0005435326578	6065	Economy	23200.00
0005433531282	6065	Economy	23200.00
0005435326590	6065	Economy	23200.00
0005433531280	6065	Economy	23200.00
0005434600733	6065	Economy	23200.00
0005433533297	6065	Economy	23200.00
0005434600725	6065	Economy	23200.00
0005434600726	6065	Economy	23200.00
0005434600728	6065	Economy	23200.00
0005432111268	6065	Economy	23200.00
0005435326561	6065	Economy	23200.00
0005434600729	6065	Economy	23200.00
0005434600720	6065	Economy	23200.00
0005434600715	6065	Economy	23200.00
0005434600716	6065	Economy	23200.00
0005435326623	6065	Economy	23200.00
0005434600717	6065	Economy	23200.00
0005435326699	18594	Business	69700.00
0005434600522	18594	Business	69700.00
0005433531262	18594	Business	69700.00
0005434600392	18594	Business	69700.00
0005435326704	18594	Business	69700.00
0005435326698	18594	Business	69700.00
0005435326700	18594	Business	69700.00
0005435326696	18594	Economy	23200.00
0005434600437	18594	Economy	23200.00
0005434600556	18594	Economy	23200.00
0005434600530	18594	Economy	25600.00
0005434600557	18594	Economy	25600.00
0005434600504	18594	Economy	25600.00
0005435326707	18594	Economy	23200.00
0005435326702	18594	Economy	23200.00
0005434600555	18594	Economy	23200.00
0005434600532	18594	Economy	23200.00
0005434600327	18594	Economy	23200.00
0005434600453	18594	Economy	23200.00
0005434600561	18594	Economy	23200.00
0005434600406	18594	Economy	23200.00
0005434600562	18594	Economy	23200.00
0005435326701	18594	Economy	23200.00
0005433531261	18594	Economy	23200.00
0005435326697	18594	Economy	23200.00
0005434600508	18594	Economy	23200.00
0005434600537	18594	Economy	23200.00
0005435326706	18594	Economy	23200.00
0005434600494	18594	Economy	23200.00
0005434600328	18594	Economy	23200.00
0005434600476	18594	Economy	23200.00
0005434600489	18594	Economy	23200.00
0005434600526	18594	Economy	23200.00
0005434600563	18594	Economy	23200.00
0005434600478	18594	Economy	23200.00
0005435326708	18594	Economy	23200.00
0005435326709	18594	Economy	23200.00
0005435326705	18594	Economy	23200.00
0005434600568	18594	Economy	23200.00
0005435326703	18594	Economy	23200.00
0005434600486	18594	Economy	23200.00
0005434600487	18594	Economy	23200.00
0005434600490	18594	Economy	23200.00
0005434600517	18594	Economy	23200.00
0005434600497	18594	Economy	23200.00
0005433527221	18594	Economy	23200.00
0005435326710	18594	Economy	23200.00
0005434600488	18594	Economy	23200.00
0005434600461	18594	Economy	23200.00
0005434600531	18594	Economy	23200.00
0005434600535	18594	Economy	23200.00
0005433531238	18594	Economy	23200.00
0005434551024	10662	Business	9100.00
0005434551025	10662	Business	9100.00
0005434558230	10662	Business	9100.00
0005433180872	10662	Business	9100.00
0005434551034	10662	Business	9100.00
0005434550991	10662	Business	9100.00
0005434550988	10662	Business	9100.00
0005434551042	10662	Business	9100.00
0005434550987	10662	Business	9100.00
0005434550993	10662	Business	9100.00
0005433180667	10662	Business	9100.00
0005433180781	10662	Business	9100.00
0005434551003	10662	Economy	3000.00
0005434551016	10662	Economy	3000.00
0005433180825	10662	Economy	3000.00
0005434550989	10662	Economy	3000.00
0005434550996	10662	Economy	3000.00
0005434554058	10662	Economy	3000.00
0005433180876	10662	Economy	3000.00
0005434551017	10662	Economy	3000.00
0005433180765	10662	Economy	3000.00
0005434551002	10662	Economy	3000.00
0005433180731	10662	Economy	3300.00
0005434551018	10662	Economy	3300.00
0005434551007	10662	Economy	3300.00
0005433180934	10662	Economy	3300.00
0005433180764	10662	Economy	3300.00
0005433180897	10662	Economy	3000.00
0005434551022	10662	Economy	3000.00
0005433180813	10662	Economy	3000.00
0005433180803	10662	Economy	3000.00
0005433180704	10662	Economy	3000.00
0005433180935	10662	Economy	3000.00
0005434550990	10662	Economy	3000.00
0005434551000	10662	Economy	3000.00
0005434558231	10662	Economy	3000.00
0005434551021	10662	Economy	3000.00
0005434551020	10662	Economy	3000.00
0005434551030	10662	Economy	3000.00
0005434550997	10662	Economy	3000.00
0005434551015	10662	Economy	3000.00
0005434551001	10662	Economy	3000.00
0005434551032	10662	Economy	3000.00
0005434551038	10662	Economy	3000.00
0005434551028	10662	Economy	3000.00
0005434558229	10662	Economy	3000.00
0005434550994	10662	Economy	3000.00
0005434550995	10662	Economy	3000.00
0005433180839	10662	Economy	3000.00
0005434551023	10662	Economy	3000.00
0005433180701	10662	Economy	3000.00
0005434550999	10662	Economy	3000.00
0005434551040	10662	Economy	3000.00
0005433180758	10662	Economy	3000.00
0005434550992	10662	Economy	3000.00
0005433180785	10662	Economy	3000.00
0005433180826	10662	Economy	3000.00
0005434551029	10662	Economy	3000.00
0005433180703	10662	Economy	3000.00
0005433180759	10662	Economy	3000.00
0005434551013	10662	Economy	3000.00
0005434551012	10662	Economy	3000.00
0005433180873	10662	Economy	3000.00
0005434551004	10662	Economy	3000.00
0005434551019	10662	Economy	3000.00
0005434551008	10662	Economy	3000.00
0005434558232	10662	Economy	3000.00
0005433180838	10662	Economy	3000.00
0005433180771	10662	Economy	3000.00
0005434551031	10662	Economy	3000.00
0005434551014	10662	Economy	3000.00
0005434551041	10662	Economy	3000.00
0005433180752	10662	Economy	3000.00
0005434551035	10662	Economy	3000.00
0005434551026	10662	Economy	3000.00
0005434551037	10662	Economy	3000.00
0005434551010	10662	Economy	3000.00
0005434551033	10662	Economy	3000.00
0005433180786	10662	Economy	3000.00
0005434550998	10662	Economy	3000.00
0005433180821	10662	Economy	3000.00
0005434551039	10662	Economy	3000.00
0005433180772	10662	Economy	3000.00
0005434551005	10662	Economy	3000.00
0005433180753	10662	Economy	3000.00
0005434551006	10662	Economy	3000.00
0005434551027	10662	Economy	3000.00
0005434551036	10662	Economy	3000.00
0005434551043	10662	Economy	3000.00
0005434551009	10662	Economy	3000.00
0005434551011	10662	Economy	3000.00
0005433180827	10662	Economy	3000.00
0005433181020	27752	Business	9100.00
0005433181035	27752	Economy	3000.00
0005433181029	27752	Economy	3000.00
0005433181013	27752	Economy	3000.00
0005433181015	27752	Economy	3300.00
0005433181030	27752	Economy	3300.00
0005433181026	27752	Economy	3000.00
0005433181022	27752	Economy	3000.00
0005433181028	27752	Economy	3000.00
0005433181024	27752	Economy	3000.00
0005433181016	27752	Economy	3000.00
0005433181031	27752	Economy	3000.00
0005433181032	27752	Economy	3000.00
0005433181025	27752	Economy	3000.00
0005433181033	27752	Economy	3000.00
0005433181018	27752	Economy	3000.00
0005433181027	27752	Economy	3000.00
0005433181019	27752	Economy	3000.00
0005433181017	27752	Economy	3000.00
0005433181023	27752	Economy	3000.00
0005433181011	27752	Economy	3000.00
0005433181021	27752	Economy	3000.00
0005433181014	27752	Economy	3000.00
0005433181034	27752	Economy	3000.00
0005433181012	27752	Economy	3000.00
0005434550626	27751	Business	9100.00
0005434550663	27751	Business	9100.00
0005434558183	27751	Business	9100.00
0005434550791	27751	Business	9100.00
0005434550752	27751	Business	9100.00
0005434550673	27751	Business	9100.00
0005434550555	27751	Business	9100.00
0005434550801	27751	Business	9100.00
0005434550607	27751	Business	9100.00
0005434550556	27751	Economy	3000.00
0005434550720	27751	Economy	3000.00
0005434550669	27751	Economy	3000.00
0005434554034	27751	Economy	3000.00
0005434550536	27751	Economy	3000.00
0005434550657	27751	Economy	3000.00
0005434550722	27751	Economy	3000.00
0005434550455	27751	Economy	3300.00
0005434550585	27751	Economy	3300.00
0005434550625	27751	Economy	3300.00
0005434550574	27751	Economy	3000.00
0005434554046	27751	Economy	3000.00
0005434550671	27751	Economy	3000.00
0005434550597	27751	Economy	3000.00
0005434550754	27751	Economy	3000.00
0005434550608	27751	Economy	3000.00
0005434558178	27751	Economy	3000.00
0005434550465	27751	Economy	3000.00
0005434550338	27751	Economy	3000.00
0005434558161	27751	Economy	3000.00
0005434554045	27751	Economy	3000.00
0005434550499	27751	Economy	3000.00
0005434550521	27751	Economy	3000.00
0005434550751	27751	Economy	3000.00
0005434550756	27751	Economy	3000.00
0005434550490	27751	Economy	3000.00
0005434550662	27751	Economy	3000.00
0005434558176	27751	Economy	3000.00
0005434550656	27751	Economy	3000.00
0005434550456	27751	Economy	3000.00
0005434558160	27751	Economy	3000.00
0005434554035	27751	Economy	3000.00
0005434558141	27751	Economy	3000.00
0005434550287	27751	Economy	3000.00
0005434550595	27751	Economy	3000.00
0005434550633	27751	Economy	3000.00
0005434550476	27751	Economy	3000.00
0005434558179	27751	Economy	3000.00
0005434550464	27751	Economy	3000.00
0005434550538	27751	Economy	3000.00
0005434550286	27751	Economy	3000.00
0005434550426	27751	Economy	3000.00
0005434550552	27751	Economy	3000.00
0005434550659	27751	Economy	3000.00
0005434550600	27751	Economy	3000.00
0005434558170	27751	Economy	3000.00
0005434550537	27751	Economy	3000.00
0005434550721	27751	Economy	3000.00
0005434550497	27751	Economy	3000.00
0005434550750	27751	Economy	3000.00
0005434550719	27751	Economy	3000.00
0005434550716	27751	Economy	3000.00
0005434558174	27751	Economy	3000.00
0005434558177	27751	Economy	3000.00
0005434550670	27751	Economy	3000.00
0005434550601	27751	Economy	3000.00
0005434550745	27751	Economy	3000.00
0005434550674	27751	Economy	3000.00
0005434554039	27751	Economy	3000.00
0005434550596	27751	Economy	3000.00
0005434550582	27751	Economy	3000.00
0005434550539	27751	Economy	3000.00
0005434550496	27751	Economy	3000.00
0005433459208	6124	Economy	11700.00
0005435254449	6124	Economy	11700.00
0005435254444	6124	Economy	11700.00
0005433459204	6124	Economy	11700.00
0005435254448	6124	Economy	11700.00
0005435254450	6124	Economy	11700.00
0005433459205	6124	Economy	11700.00
0005435254443	6124	Economy	11700.00
0005433459206	6124	Economy	11700.00
0005435254442	6124	Economy	11700.00
0005433459207	6124	Economy	11700.00
0005435254467	19292	Economy	11700.00
0005433459188	19292	Economy	11700.00
0005433459165	19292	Economy	11700.00
0005433459187	19292	Economy	11700.00
0005433459189	19292	Economy	11700.00
0005435254466	19292	Economy	11700.00
0005433459166	19292	Economy	11700.00
0005433459170	19292	Economy	11700.00
0005433459169	19292	Economy	11700.00
0005432533260	6758	Business	51100.00
0005432533264	6758	Business	51100.00
0005435437781	6758	Business	51100.00
0005435719566	6758	Business	51100.00
0005435681986	6758	Business	51100.00
0005435681980	6758	Business	51100.00
0005435682026	6758	Business	51100.00
0005435682022	6758	Business	51100.00
0005435437821	6758	Business	51100.00
0005434828648	6758	Business	51100.00
0005435681983	6758	Business	51100.00
0005435720130	6758	Business	51100.00
0005435682017	6758	Economy	17000.00
0005435437773	6758	Economy	17000.00
0005435661918	6758	Economy	17000.00
0005435437794	6758	Economy	17000.00
0005435681997	6758	Economy	17000.00
0005435682005	6758	Economy	17000.00
0005435681990	6758	Economy	17000.00
0005435681982	6758	Economy	17000.00
0005435682007	6758	Economy	17000.00
0005435437738	6758	Economy	17000.00
0005435682000	6758	Economy	18700.00
0005432136154	6758	Economy	18700.00
0005435437657	6758	Economy	18700.00
0005435217685	6758	Economy	18700.00
0005435681992	6758	Economy	18700.00
0005435681993	6758	Economy	17000.00
0005435437815	6758	Economy	17000.00
0005435437662	6758	Economy	17000.00
0005435681995	6758	Economy	17000.00
0005435682016	6758	Economy	17000.00
0005435681994	6758	Economy	17000.00
0005435437585	6758	Economy	17000.00
0005435719568	6758	Economy	17000.00
0005435437793	6758	Economy	17000.00
0005435682006	6758	Economy	17000.00
0005435437685	6758	Economy	17000.00
0005435682018	6758	Economy	17000.00
0005432136153	6758	Economy	17000.00
0005435437599	6758	Economy	17000.00
0005435437814	6758	Economy	17000.00
0005435682009	6758	Economy	17000.00
0005435437740	6758	Economy	17000.00
0005435437709	6758	Economy	17000.00
0005435682012	6758	Economy	17000.00
0005435682015	6758	Economy	17000.00
0005435437689	6758	Economy	17000.00
0005435682004	6758	Economy	17000.00
0005435682011	6758	Economy	17000.00
0005435720131	6758	Economy	17000.00
0005435682002	6758	Economy	17000.00
0005435682025	6758	Economy	17000.00
0005435437731	6758	Economy	17000.00
0005435682013	6758	Economy	17000.00
0005435682001	6758	Economy	17000.00
0005435437779	6758	Economy	17000.00
0005435681999	6758	Economy	17000.00
0005435437643	6758	Economy	17000.00
0005435682014	6758	Economy	17000.00
0005435437688	6758	Economy	17000.00
0005432136151	6758	Economy	17000.00
0005435681985	6758	Economy	17000.00
0005435437660	6758	Economy	17000.00
0005435437661	6758	Economy	17000.00
0005432533265	6758	Economy	17000.00
0005435682019	6758	Economy	17000.00
0005435437780	6758	Economy	17000.00
0005435682023	6758	Economy	17000.00
0005435681998	6758	Economy	17000.00
0005435682003	6758	Economy	17000.00
0005435719567	6758	Economy	17000.00
0005435437584	6758	Economy	17000.00
0005435682010	6758	Economy	17000.00
0005435630956	6758	Economy	17000.00
0005435661919	6758	Economy	17000.00
0005435220288	6758	Economy	17000.00
0005435681996	6758	Economy	17000.00
0005435630955	6758	Economy	17000.00
0005435681988	6758	Economy	17000.00
0005435681981	6758	Economy	17000.00
0005435681991	6758	Economy	17000.00
0005435682021	6758	Economy	17000.00
0005435682008	6758	Economy	17000.00
0005432136152	6758	Economy	17000.00
0005435682024	6758	Economy	17000.00
0005435661920	6758	Economy	17000.00
0005435437710	6758	Economy	17000.00
0005435437732	6758	Economy	17000.00
0005435681989	6758	Economy	17000.00
0005435682020	6758	Economy	17000.00
0005435437620	6758	Economy	17000.00
0005435437663	6758	Economy	17000.00
0005435681984	6758	Economy	17000.00
0005435220286	6758	Economy	17000.00
0005435681987	6758	Economy	17000.00
0005435220287	6758	Economy	17000.00
0005435681776	24568	Business	51100.00
0005434828690	24568	Business	51100.00
0005435681560	24568	Business	51100.00
0005435681766	24568	Business	51100.00
0005435437883	24568	Business	51100.00
0005435437887	24568	Business	51100.00
0005435681586	24568	Business	51100.00
0005435681565	24568	Business	51100.00
0005435437875	24568	Business	51100.00
0005435681652	24568	Business	51100.00
0005435661896	24568	Business	51100.00
0005435437871	24568	Economy	17000.00
0005435681581	24568	Economy	17000.00
0005435681726	24568	Economy	17000.00
0005432305741	24568	Economy	17000.00
0005435437892	24568	Economy	17000.00
0005435437882	24568	Economy	17000.00
0005435681561	24568	Economy	17000.00
0005435681753	24568	Economy	17000.00
0005435437872	24568	Economy	17000.00
0005435681790	24568	Economy	17000.00
0005435437877	24568	Economy	18700.00
0005435681696	24568	Economy	18700.00
0005435681460	24568	Economy	18700.00
0005435437890	24568	Economy	18700.00
0005434828689	24568	Economy	18700.00
0005435661882	24568	Economy	17000.00
0005435630932	24568	Economy	17000.00
0005435437876	24568	Economy	17000.00
0005435720811	24568	Economy	17000.00
0005435437870	24568	Economy	17000.00
0005435437889	24568	Economy	17000.00
0005435630919	24568	Economy	17000.00
0005435681716	24568	Economy	17000.00
0005435681651	24568	Economy	17000.00
0005435661892	24568	Economy	17000.00
0005435661893	24568	Economy	17000.00
0005435681679	24568	Economy	17000.00
0005435719550	24568	Economy	17000.00
0005435630930	24568	Economy	17000.00
0005435681562	24568	Economy	17000.00
0005435437886	24568	Economy	17000.00
0005435437880	24568	Economy	17000.00
0005432305742	24568	Economy	17000.00
0005435681667	24568	Economy	17000.00
0005435437874	24568	Economy	17000.00
0005435681678	24568	Economy	17000.00
0005432533284	24568	Economy	17000.00
0005435681645	24568	Economy	17000.00
0005435661883	24568	Economy	17000.00
0005435681459	24568	Economy	17000.00
0005435630931	24568	Economy	17000.00
0005435681742	24568	Economy	17000.00
0005435681653	24568	Economy	17000.00
0005435681666	24568	Economy	17000.00
0005435437891	24568	Economy	17000.00
0005432533283	24568	Economy	17000.00
0005434828688	24568	Economy	17000.00
0005435681525	24568	Economy	17000.00
0005435437878	24568	Economy	17000.00
0005435681764	24568	Economy	17000.00
0005435719551	24568	Economy	17000.00
0005435681824	24568	Economy	17000.00
0005435681566	24568	Economy	17000.00
0005435437885	24568	Economy	17000.00
0005435681697	24568	Economy	17000.00
0005435681723	24568	Economy	17000.00
0005435630943	24568	Economy	17000.00
0005435437879	24568	Economy	17000.00
0005435681680	24568	Economy	17000.00
0005435681743	24568	Economy	17000.00
0005435681664	24568	Economy	17000.00
0005432305740	24568	Economy	17000.00
0005435437888	24568	Economy	17000.00
0005435681636	24568	Economy	17000.00
0005435681543	24568	Economy	17000.00
0005435437873	24568	Economy	17000.00
0005435681765	24568	Economy	17000.00
0005435437881	24568	Economy	17000.00
0005435681665	24568	Economy	17000.00
0005435681821	24568	Economy	17000.00
0005435681686	24568	Economy	17000.00
0005432533282	24568	Economy	17000.00
0005435681559	24568	Economy	17000.00
0005435437884	24568	Economy	17000.00
0005435681593	24568	Economy	17000.00
0005435720812	24568	Economy	17000.00
0005435681626	24568	Economy	17000.00
0005435681860	24568	Economy	17000.00
0005435681475	24568	Economy	17000.00
0005435126191	11536	Business	26400.00
0005435126208	11536	Business	26400.00
0005435126204	11536	Business	26400.00
0005435126193	11536	Business	26400.00
0005435126223	11536	Business	26400.00
0005435126192	11536	Economy	8800.00
0005435126195	11536	Economy	8800.00
0005435126188	11536	Economy	8800.00
0005435126189	11536	Economy	8800.00
0005435126218	11536	Economy	9700.00
0005435126207	11536	Economy	9700.00
0005435126205	11536	Economy	9700.00
0005435126213	11536	Economy	8800.00
0005435126226	11536	Economy	8800.00
0005435126211	11536	Economy	8800.00
0005435126209	11536	Economy	8800.00
0005435126199	11536	Economy	8800.00
0005435558054	11536	Economy	8800.00
0005435126215	11536	Economy	8800.00
0005435126202	11536	Economy	8800.00
0005435126219	11536	Economy	8800.00
0005435126201	11536	Economy	8800.00
0005435126222	11536	Economy	8800.00
0005435126216	11536	Economy	8800.00
0005435126206	11536	Economy	8800.00
0005435126190	11536	Economy	8800.00
0005435126220	11536	Economy	8800.00
0005435126197	11536	Economy	8800.00
0005435126203	11536	Economy	8800.00
0005435126214	11536	Economy	8800.00
0005435126212	11536	Economy	8800.00
0005435126230	11536	Economy	8800.00
0005435126228	11536	Economy	8800.00
0005435126227	11536	Economy	8800.00
0005435126217	11536	Economy	8800.00
0005435126224	11536	Economy	8800.00
0005435126210	11536	Economy	8800.00
0005435126200	11536	Economy	8800.00
0005435126221	11536	Economy	8800.00
0005435126196	11536	Economy	8800.00
0005435105970	11536	Economy	8800.00
0005435126229	11536	Economy	8800.00
0005435126225	11536	Economy	8800.00
0005435558043	11536	Economy	8800.00
0005435126194	11536	Economy	8800.00
0005435105968	11536	Economy	8800.00
0005435105969	11536	Economy	8800.00
0005435126198	11536	Economy	8800.00
0005435125901	31862	Business	26400.00
0005435125732	31862	Business	26400.00
0005435126005	31862	Business	26400.00
0005435125822	31862	Business	26400.00
0005435125871	31862	Business	26400.00
0005435125832	31862	Business	26400.00
0005435125843	31862	Business	26400.00
0005435125861	31862	Business	26400.00
0005435125810	31862	Business	26400.00
0005435125972	31862	Business	26400.00
0005435125779	31862	Business	26400.00
0005435125900	31862	Economy	8800.00
0005435125904	31862	Economy	8800.00
0005435125730	31862	Economy	8800.00
0005435125957	31862	Economy	8800.00
0005435126007	31862	Economy	8800.00
0005435125947	31862	Economy	9700.00
0005435125797	31862	Economy	9700.00
0005435125862	31862	Economy	8800.00
0005435105942	31862	Economy	8800.00
0005435125745	31862	Economy	8800.00
0005435126077	31862	Economy	8800.00
0005435125731	31862	Economy	8800.00
0005435125930	31862	Economy	8800.00
0005435558080	31862	Economy	8800.00
0005435125973	31862	Economy	8800.00
0005435125815	31862	Economy	8800.00
0005435125878	31862	Economy	8800.00
0005435126033	31862	Economy	8800.00
0005435125938	31862	Economy	8800.00
0005435125780	31862	Economy	8800.00
0005435125873	31862	Economy	8800.00
0005435105938	31862	Economy	8800.00
0005435125992	31862	Economy	8800.00
0005435126006	31862	Economy	8800.00
0005435125769	31862	Economy	8800.00
0005435126042	31862	Economy	8800.00
0005435105941	31862	Economy	8800.00
0005435558078	31862	Economy	8800.00
0005435098527	31862	Economy	8800.00
0005435125823	31862	Economy	8800.00
0005435125811	31862	Economy	8800.00
0005435126076	31862	Economy	8800.00
0005435125921	31862	Economy	8800.00
0005435126004	31862	Economy	8800.00
0005435125874	31862	Economy	8800.00
0005435125927	31862	Economy	8800.00
0005435125959	31862	Economy	8800.00
0005435105943	31862	Economy	8800.00
0005435125703	31862	Economy	8800.00
0005435125958	31862	Economy	8800.00
0005435125791	31862	Economy	8800.00
0005435125872	31862	Economy	8800.00
0005435098531	31862	Economy	8800.00
0005435126034	31862	Economy	8800.00
0005435558079	31862	Economy	8800.00
0005435098534	31862	Economy	8800.00
0005435125755	31862	Economy	8800.00
0005435125786	31862	Economy	8800.00
0005435732211	13531	Business	36600.00
0005433397909	13531	Business	36600.00
0005433397889	13531	Business	36600.00
0005433397899	13531	Business	36600.00
0005433397916	13531	Business	36600.00
0005433397923	13531	Business	36600.00
0005433397877	13531	Economy	12200.00
0005435732168	13531	Economy	12200.00
0005435732270	13531	Economy	12200.00
0005435732162	13531	Economy	12200.00
0005433397875	13531	Economy	12200.00
0005433397911	13531	Economy	12200.00
0005435732216	13531	Economy	12200.00
0005433397913	13531	Economy	12200.00
0005433397893	13531	Economy	12200.00
0005433397879	13531	Economy	13400.00
0005435732169	13531	Economy	13400.00
0005433397919	13531	Economy	13400.00
0005433397914	13531	Economy	12200.00
0005435732222	13531	Economy	12200.00
0005433397912	13531	Economy	12200.00
0005435732205	13531	Economy	12200.00
0005433397908	13531	Economy	12200.00
0005435732166	13531	Economy	12200.00
0005433397876	13531	Economy	12200.00
0005435732220	13531	Economy	12200.00
0005433397901	13531	Economy	12200.00
0005433397904	13531	Economy	12200.00
0005435732197	13531	Economy	12200.00
0005433397918	13531	Economy	12200.00
0005433397878	13531	Economy	12200.00
0005433397924	13531	Economy	12200.00
0005433397891	13531	Economy	12200.00
0005433397882	13531	Economy	12200.00
0005433397895	13531	Economy	12200.00
0005433397917	13531	Economy	12200.00
0005433397883	13531	Economy	12200.00
0005433397903	13531	Economy	12200.00
0005433397922	13531	Economy	12200.00
0005433397885	13531	Economy	12200.00
0005433397881	13531	Economy	12200.00
0005433397890	13531	Economy	12200.00
0005433397910	13531	Economy	12200.00
0005435732163	13531	Economy	12200.00
0005433397902	13531	Economy	12200.00
0005433397894	13531	Economy	12200.00
0005435732208	13531	Economy	12200.00
0005433397892	13531	Economy	12200.00
0005433397898	13531	Economy	12200.00
0005433397880	13531	Economy	12200.00
0005433397920	13531	Economy	12200.00
0005435732167	13531	Economy	12200.00
0005433397897	13531	Economy	12200.00
0005433397888	13531	Economy	12200.00
0005433397884	13531	Economy	12200.00
0005433397921	13531	Economy	12200.00
0005433397874	13531	Economy	12200.00
0005433397896	13531	Economy	12200.00
0005433397907	13531	Economy	12200.00
0005433397905	13531	Economy	12200.00
0005433397886	13531	Economy	12200.00
0005433397900	13531	Economy	12200.00
0005433397915	13531	Economy	12200.00
0005435732207	13531	Economy	12200.00
0005433397906	13531	Economy	12200.00
0005433397887	13531	Economy	12200.00
0005433397486	19405	Business	36600.00
0005433397402	19405	Business	36600.00
0005433397460	19405	Business	36600.00
0005433397515	19405	Business	36600.00
0005433397438	19405	Business	36600.00
0005433397587	19405	Business	36600.00
0005433397249	19405	Business	36600.00
0005433397602	19405	Economy	12200.00
0005433397601	19405	Economy	12200.00
0005433397597	19405	Economy	12200.00
0005433397391	19405	Economy	12200.00
0005433397216	19405	Economy	12200.00
0005433397404	19405	Economy	12200.00
0005433397736	19405	Economy	13400.00
0005433397637	19405	Economy	13400.00
0005433397584	19405	Economy	13400.00
0005433397385	19405	Economy	12200.00
0005433397588	19405	Economy	12200.00
0005433397346	19405	Economy	12200.00
0005433397583	19405	Economy	12200.00
0005433397386	19405	Economy	12200.00
0005433397314	19405	Economy	12200.00
0005433397439	19405	Economy	12200.00
0005433397452	19405	Economy	12200.00
0005433397713	19405	Economy	12200.00
0005432297268	19405	Economy	12200.00
0005433397423	19405	Economy	12200.00
0005433397461	19405	Economy	12200.00
0005433397680	19405	Economy	12200.00
0005433397636	19405	Economy	12200.00
0005433397462	19405	Economy	12200.00
0005433397440	19405	Economy	12200.00
0005433397556	19405	Economy	12200.00
0005433397479	19405	Economy	12200.00
0005433397279	19405	Economy	12200.00
0005433397679	19405	Economy	12200.00
0005433397341	19405	Economy	12200.00
0005433397424	19405	Economy	12200.00
0005433397525	19405	Economy	12200.00
0005432297270	19405	Economy	12200.00
0005433397478	19405	Economy	12200.00
0005433397315	19405	Economy	12200.00
0005433397570	19405	Economy	12200.00
0005433397516	19405	Economy	12200.00
0005433397340	19405	Economy	12200.00
0005433397482	19405	Economy	12200.00
0005433397543	19405	Economy	12200.00
0005433397401	19405	Economy	12200.00
0005433397670	19405	Economy	12200.00
0005433397278	19405	Economy	12200.00
0005433397678	19405	Economy	12200.00
0005432297269	19405	Economy	12200.00
0005433397471	19405	Economy	12200.00
0005433397345	19405	Economy	12200.00
0005433397470	19405	Economy	12200.00
0005433397494	19405	Economy	12200.00
0005433397480	19405	Economy	12200.00
0005433397444	19405	Economy	12200.00
0005433397524	19405	Economy	12200.00
0005433397316	19405	Economy	12200.00
0005433397582	19405	Economy	12200.00
0005433397384	19405	Economy	12200.00
0005433397581	19405	Economy	12200.00
0005435925262	13170	Business	11300.00
0005435068480	13170	Business	11300.00
0005435925247	13170	Business	11300.00
0005435068474	13170	Business	11300.00
0005435068341	13170	Business	11300.00
0005435068492	13170	Business	11300.00
0005435068183	13170	Business	11300.00
0005435925266	13170	Business	11300.00
0005435925265	13170	Economy	3800.00
0005435925253	13170	Economy	3800.00
0005435068359	13170	Economy	3800.00
0005435068430	13170	Economy	3800.00
0005435068683	13170	Economy	3800.00
0005435068216	13170	Economy	3800.00
0005435068472	13170	Economy	3800.00
0005435068228	13170	Economy	3800.00
0005435068473	13170	Economy	4100.00
0005435068370	13170	Economy	4100.00
0005435925261	13170	Economy	4100.00
0005435925263	13170	Economy	4100.00
0005435068233	13170	Economy	3800.00
0005435925268	13170	Economy	3800.00
0005435068374	13170	Economy	3800.00
0005435068408	13170	Economy	3800.00
0005435068351	13170	Economy	3800.00
0005435925259	13170	Economy	3800.00
0005435925248	13170	Economy	3800.00
0005435925267	13170	Economy	3800.00
0005435925255	13170	Economy	3800.00
0005435925264	13170	Economy	3800.00
0005435925251	13170	Economy	3800.00
0005435925260	13170	Economy	3800.00
0005435068610	13170	Economy	3800.00
0005435068420	13170	Economy	3800.00
0005435068292	13170	Economy	3800.00
0005435068531	13170	Economy	3800.00
0005435068340	13170	Economy	3800.00
0005435925250	13170	Economy	3800.00
0005435068609	13170	Economy	3800.00
0005435068373	13170	Economy	3800.00
0005435068487	13170	Economy	3800.00
0005435068558	13170	Economy	3800.00
0005435068421	13170	Economy	3800.00
0005435925258	13170	Economy	3800.00
0005435068419	13170	Economy	3800.00
0005435068542	13170	Economy	3800.00
0005435925252	13170	Economy	3800.00
0005435068369	13170	Economy	3800.00
0005435068422	13170	Economy	3800.00
0005435925256	13170	Economy	3800.00
0005435925246	13170	Economy	3800.00
0005435068401	13170	Economy	3800.00
0005435068684	13170	Economy	3800.00
0005435068229	13170	Economy	3800.00
0005435068541	13170	Economy	3800.00
0005435068599	13170	Economy	3800.00
0005435068456	13170	Economy	3800.00
0005435925244	13170	Economy	3800.00
0005435068284	13170	Economy	3800.00
0005435925257	13170	Economy	3800.00
0005435925249	13170	Economy	3800.00
0005435068518	13170	Economy	3800.00
0005435068441	13170	Economy	3800.00
0005435068232	13170	Economy	3800.00
0005435925254	13170	Economy	3800.00
0005435068455	13170	Economy	3800.00
0005435925245	13170	Economy	3800.00
0005435068214	13170	Economy	3800.00
0005435068847	15495	Business	11300.00
0005435068896	15495	Business	11300.00
0005435068899	15495	Business	11300.00
0005435068860	15495	Business	11300.00
0005435068881	15495	Business	11300.00
0005435068900	15495	Business	11300.00
0005435068875	15495	Business	11300.00
0005435068895	15495	Economy	3800.00
0005435925065	15495	Economy	3800.00
0005435068868	15495	Economy	3800.00
0005435925104	15495	Economy	3800.00
0005435068889	15495	Economy	3800.00
0005435068861	15495	Economy	3800.00
0005435925103	15495	Economy	3800.00
0005435068883	15495	Economy	4100.00
0005435068879	15495	Economy	4100.00
0005435068893	15495	Economy	3800.00
0005435068878	15495	Economy	3800.00
0005435068891	15495	Economy	3800.00
0005435925080	15495	Economy	3800.00
0005435068898	15495	Economy	3800.00
0005435068865	15495	Economy	3800.00
0005435068884	15495	Economy	3800.00
0005435068886	15495	Economy	3800.00
0005435068866	15495	Economy	3800.00
0005435068892	15495	Economy	3800.00
0005435068870	15495	Economy	3800.00
0005435068858	15495	Economy	3800.00
0005435068885	15495	Economy	3800.00
0005435068877	15495	Economy	3800.00
0005435068855	15495	Economy	3800.00
0005435068863	15495	Economy	3800.00
0005435925097	15495	Economy	3800.00
0005435068867	15495	Economy	3800.00
0005435068873	15495	Economy	3800.00
0005435068882	15495	Economy	3800.00
0005435068887	15495	Economy	3800.00
0005435068848	15495	Economy	3800.00
0005435068874	15495	Economy	3800.00
0005435068888	15495	Economy	3800.00
0005435068851	15495	Economy	3800.00
0005435925062	15495	Economy	3800.00
0005435068869	15495	Economy	3800.00
0005435068852	15495	Economy	3800.00
0005435925107	15495	Economy	3800.00
0005435068894	15495	Economy	3800.00
0005435925095	15495	Economy	3800.00
0005435068854	15495	Economy	3800.00
0005435068849	15495	Economy	3800.00
0005435068862	15495	Economy	3800.00
0005435068856	15495	Economy	3800.00
0005435068850	15495	Economy	3800.00
0005435068876	15495	Economy	3800.00
0005435068871	15495	Economy	3800.00
0005435925106	15495	Economy	3800.00
0005435068872	15495	Economy	3800.00
0005435068859	15495	Economy	3800.00
0005435068890	15495	Economy	3800.00
0005435068880	15495	Economy	3800.00
0005435925102	15495	Economy	3800.00
0005435068853	15495	Economy	3800.00
0005435068864	15495	Economy	3800.00
0005435068897	15495	Economy	3800.00
0005435068857	15495	Economy	3800.00
0005435925101	15495	Economy	3800.00
0005435808075	29483	Economy	27100.00
0005433407554	29483	Economy	27100.00
0005435808130	29483	Economy	27100.00
0005435808081	29483	Economy	27100.00
0005435808110	29483	Economy	24700.00
0005433407544	29483	Economy	24700.00
0005435808098	29483	Economy	24700.00
0005435808106	29483	Economy	24700.00
0005433407549	29483	Economy	24700.00
0005433407548	29483	Economy	24700.00
0005435808108	29483	Economy	24700.00
0005435808074	29483	Economy	24700.00
0005435808134	29483	Economy	24700.00
0005433407552	29483	Economy	24700.00
0005433407551	29483	Economy	24700.00
0005435808109	29483	Economy	24700.00
0005433407543	29483	Economy	24700.00
0005435808135	29483	Economy	24700.00
0005435808103	29483	Economy	24700.00
0005433407542	29483	Economy	24700.00
0005435808105	29483	Economy	24700.00
0005435808155	29483	Economy	24700.00
0005433407541	29483	Economy	24700.00
0005435808101	29483	Economy	24700.00
0005433407539	29483	Economy	24700.00
0005435808086	29483	Economy	24700.00
0005435808125	29483	Economy	24700.00
0005435808078	29483	Economy	24700.00
0005435808154	29483	Economy	24700.00
0005435808080	29483	Economy	24700.00
0005435808107	29483	Economy	24700.00
0005433407546	29483	Economy	24700.00
0005433407547	29483	Economy	24700.00
0005433407553	29483	Economy	24700.00
0005433407550	29483	Economy	24700.00
0005433407545	29483	Economy	24700.00
0005435808049	29483	Economy	24700.00
0005435808129	29483	Economy	24700.00
0005435808112	29483	Economy	24700.00
0005435808133	29483	Economy	24700.00
0005435808079	29483	Economy	24700.00
0005433407540	29483	Economy	24700.00
0005435808095	29483	Economy	24700.00
0005435808068	29483	Economy	24700.00
0005435808124	29483	Economy	24700.00
0005434214409	10725	Business	61300.00
0005434756062	10725	Business	61300.00
0005434214389	10725	Business	61300.00
0005434214402	10725	Business	61300.00
0005434214410	10725	Business	61300.00
0005434755859	10725	Business	61300.00
0005434755963	10725	Business	61300.00
0005434214393	10725	Business	61300.00
0005434755944	10725	Business	61300.00
0005434214399	10725	Business	61300.00
0005434214387	10725	Business	61300.00
0005434755904	10725	Economy	20400.00
0005434214376	10725	Economy	20400.00
0005434755902	10725	Economy	20400.00
0005434755915	10725	Economy	20400.00
0005434755768	10725	Economy	20400.00
0005434214367	10725	Economy	20400.00
0005434214408	10725	Economy	20400.00
0005434214411	10725	Economy	20400.00
0005434214394	10725	Economy	20400.00
0005434755943	10725	Economy	20400.00
0005434214371	10725	Economy	22500.00
0005434755987	10725	Economy	22500.00
0005434755930	10725	Economy	22500.00
0005434214404	10725	Economy	22500.00
0005434214377	10725	Economy	20400.00
0005434756035	10725	Economy	20400.00
0005434214378	10725	Economy	20400.00
0005434214395	10725	Economy	20400.00
0005434214379	10725	Economy	20400.00
0005434214386	10725	Economy	20400.00
0005434214374	10725	Economy	20400.00
0005434755940	10725	Economy	20400.00
0005434755829	10725	Economy	20400.00
0005434214380	10725	Economy	20400.00
0005434214401	10725	Economy	20400.00
0005434214365	10725	Economy	20400.00
0005434214364	10725	Economy	20400.00
0005434214375	10725	Economy	20400.00
0005434214385	10725	Economy	20400.00
0005434755812	10725	Economy	20400.00
0005434214388	10725	Economy	20400.00
0005434755817	10725	Economy	20400.00
0005434755884	10725	Economy	20400.00
0005434214373	10725	Economy	20400.00
0005434755989	10725	Economy	20400.00
0005434214370	10725	Economy	20400.00
0005434214405	10725	Economy	20400.00
0005434755820	10725	Economy	20400.00
0005434756049	10725	Economy	20400.00
0005434214398	10725	Economy	20400.00
0005434755860	10725	Economy	20400.00
0005434756034	10725	Economy	20400.00
0005434214372	10725	Economy	20400.00
0005434756020	10725	Economy	20400.00
0005434214366	10725	Economy	20400.00
0005434214406	10725	Economy	20400.00
0005434755747	10725	Economy	20400.00
0005434756050	10725	Economy	20400.00
0005434214368	10725	Economy	20400.00
0005434214392	10725	Economy	20400.00
0005434214382	10725	Economy	20400.00
0005434755931	10725	Economy	20400.00
0005434756012	10725	Economy	20400.00
0005434755914	10725	Economy	20400.00
0005434755941	10725	Economy	20400.00
0005434214369	10725	Economy	20400.00
0005434214412	10725	Economy	20400.00
0005434755951	10725	Economy	20400.00
0005434755952	10725	Economy	20400.00
0005434214384	10725	Economy	20400.00
0005434214407	10725	Economy	20400.00
0005434756036	10725	Economy	20400.00
0005434755929	10725	Economy	20400.00
0005434755937	10725	Economy	20400.00
0005434214400	10725	Economy	20400.00
0005434755953	10725	Economy	20400.00
0005434214397	10725	Economy	20400.00
0005434214390	10725	Economy	20400.00
0005434214403	10725	Economy	20400.00
0005434755878	10725	Economy	20400.00
0005434756030	10725	Economy	20400.00
0005434214381	10725	Economy	20400.00
0005434214396	10725	Economy	20400.00
0005434214383	10725	Economy	20400.00
0005434755798	10725	Economy	20400.00
0005434755819	10725	Economy	20400.00
0005434756063	10725	Economy	20400.00
0005434756021	10725	Economy	20400.00
0005434214391	10725	Economy	20400.00
0005434756263	28668	Business	61300.00
0005434756253	28668	Business	61300.00
0005434756280	28668	Business	61300.00
0005434213976	28668	Business	61300.00
0005434756252	28668	Business	61300.00
0005434756282	28668	Business	61300.00
0005434756278	28668	Business	61300.00
0005434756265	28668	Business	61300.00
0005434756238	28668	Business	61300.00
0005434756241	28668	Business	61300.00
0005434756272	28668	Business	61300.00
0005434756242	28668	Business	61300.00
0005434756256	28668	Economy	20400.00
0005434213831	28668	Economy	20400.00
0005434214032	28668	Economy	20400.00
0005434756261	28668	Economy	20400.00
0005434214142	28668	Economy	20400.00
0005434213929	28668	Economy	20400.00
0005434213974	28668	Economy	20400.00
0005434213908	28668	Economy	20400.00
0005434213940	28668	Economy	20400.00
0005434213941	28668	Economy	20400.00
0005434756285	28668	Economy	22500.00
0005434756270	28668	Economy	22500.00
0005434756235	28668	Economy	22500.00
0005434756251	28668	Economy	22500.00
0005434756250	28668	Economy	20400.00
0005434213733	28668	Economy	20400.00
0005434214055	28668	Economy	20400.00
0005434756244	28668	Economy	20400.00
0005434756243	28668	Economy	20400.00
0005434213968	28668	Economy	20400.00
0005434756271	28668	Economy	20400.00
0005434756267	28668	Economy	20400.00
0005434213912	28668	Economy	20400.00
0005434213970	28668	Economy	20400.00
0005434214021	28668	Economy	20400.00
0005434756234	28668	Economy	20400.00
0005434756266	28668	Economy	20400.00
0005434756245	28668	Economy	20400.00
0005434756257	28668	Economy	20400.00
0005434756255	28668	Economy	20400.00
0005434214088	28668	Economy	20400.00
0005434214077	28668	Economy	20400.00
0005434756248	28668	Economy	20400.00
0005434214006	28668	Economy	20400.00
0005434213902	28668	Economy	20400.00
0005434756279	28668	Economy	20400.00
0005434756274	28668	Economy	20400.00
0005434213801	28668	Economy	20400.00
0005434756283	28668	Economy	20400.00
0005434213853	28668	Economy	20400.00
0005434756262	28668	Economy	20400.00
0005434214056	28668	Economy	20400.00
0005434213913	28668	Economy	20400.00
0005434213748	28668	Economy	20400.00
0005434213836	28668	Economy	20400.00
0005434756239	28668	Economy	20400.00
0005434756240	28668	Economy	20400.00
0005434756246	28668	Economy	20400.00
0005434213945	28668	Economy	20400.00
0005434213989	28668	Economy	20400.00
0005434756254	28668	Economy	20400.00
0005434756247	28668	Economy	20400.00
0005434756284	28668	Economy	20400.00
0005434213937	28668	Economy	20400.00
0005434756273	28668	Economy	20400.00
0005434214023	28668	Economy	20400.00
0005434756281	28668	Economy	20400.00
0005434213888	28668	Economy	20400.00
0005434756264	28668	Economy	20400.00
0005434756276	28668	Economy	20400.00
0005434756236	28668	Economy	20400.00
0005434756277	28668	Economy	20400.00
0005434756258	28668	Economy	20400.00
0005434756249	28668	Economy	20400.00
0005434756268	28668	Economy	20400.00
0005434214031	28668	Economy	20400.00
0005434213816	28668	Economy	20400.00
0005434756286	28668	Economy	20400.00
0005434213928	28668	Economy	20400.00
0005434214022	28668	Economy	20400.00
0005434213825	28668	Economy	20400.00
0005434756259	28668	Economy	20400.00
0005434756269	28668	Economy	20400.00
0005434214024	28668	Economy	20400.00
0005434214065	28668	Economy	20400.00
0005434213887	28668	Economy	20400.00
0005434756260	28668	Economy	20400.00
0005434213845	28668	Economy	20400.00
0005434213794	28668	Economy	20400.00
0005434756275	28668	Economy	20400.00
0005434213975	28668	Economy	20400.00
0005434756237	28668	Economy	20400.00
0005435039565	5428	Business	29500.00
0005435006952	5428	Business	29500.00
0005435039556	5428	Business	29500.00
0005435039577	5428	Business	29500.00
0005435039542	5428	Business	29500.00
0005435006962	5428	Business	29500.00
0005435039535	5428	Business	29500.00
0005434229068	5428	Business	29500.00
0005435039534	5428	Business	29500.00
0005435006946	5428	Business	29500.00
0005435039558	5428	Business	29500.00
0005435039566	5428	Business	29500.00
0005435039549	5428	Economy	9800.00
0005435042849	5428	Economy	9800.00
0005435039557	5428	Economy	9800.00
0005435039540	5428	Economy	9800.00
0005435039594	5428	Economy	9800.00
0005435039533	5428	Economy	9800.00
0005435039563	5428	Economy	9800.00
0005435039579	5428	Economy	9800.00
0005435039551	5428	Economy	9800.00
0005432125425	5428	Economy	9800.00
0005435006964	5428	Economy	9800.00
0005434229117	5428	Economy	9800.00
0005435039541	5428	Economy	9800.00
0005435039545	5428	Economy	9800.00
0005432125424	5428	Economy	9800.00
0005435006947	5428	Economy	9800.00
0005434229127	5428	Economy	9800.00
0005435039572	5428	Economy	9800.00
0005435039575	5428	Economy	9800.00
0005435039537	5428	Economy	9800.00
0005435006957	5428	Economy	9800.00
0005435006955	5428	Economy	9800.00
0005435042848	5428	Economy	9800.00
0005435039586	5428	Economy	9800.00
0005432125431	5428	Economy	9800.00
0005434229085	5428	Economy	9800.00
0005435039559	5428	Economy	9800.00
0005434229195	5428	Economy	9800.00
0005434229051	5428	Economy	9800.00
0005432125426	5428	Economy	9800.00
0005435006950	5428	Economy	9800.00
0005435039585	5428	Economy	9800.00
0005435039554	5428	Economy	9800.00
0005435039588	5428	Economy	9800.00
0005435006963	5428	Economy	9800.00
0005435006944	5428	Economy	9800.00
0005435039546	5428	Economy	9800.00
0005435039584	5428	Economy	9800.00
0005434229019	5428	Economy	9800.00
0005435039560	5428	Economy	10800.00
0005435039599	5428	Economy	10800.00
0005435039582	5428	Economy	10800.00
0005435039562	5428	Economy	10800.00
0005435039550	5428	Economy	10800.00
0005434229150	5428	Economy	10800.00
0005435039597	5428	Economy	9800.00
0005435039583	5428	Economy	9800.00
0005434229084	5428	Economy	9800.00
0005434229086	5428	Economy	9800.00
0005434229050	5428	Economy	9800.00
0005435006961	5428	Economy	9800.00
0005435039574	5428	Economy	9800.00
0005435039532	5428	Economy	9800.00
0005435006951	5428	Economy	9800.00
0005435039543	5428	Economy	9800.00
0005435039547	5428	Economy	9800.00
0005435039590	5428	Economy	9800.00
0005435039548	5428	Economy	9800.00
0005435039569	5428	Economy	9800.00
0005435006965	5428	Economy	9800.00
0005435006958	5428	Economy	9800.00
0005434229098	5428	Economy	9800.00
0005435039587	5428	Economy	9800.00
0005435006966	5428	Economy	9800.00
0005434229116	5428	Economy	9800.00
0005434229017	5428	Economy	9800.00
0005435039536	5428	Economy	9800.00
0005435006945	5428	Economy	9800.00
0005435039596	5428	Economy	9800.00
0005434229112	5428	Economy	9800.00
0005435039553	5428	Economy	9800.00
0005435006949	5428	Economy	9800.00
0005435039580	5428	Economy	9800.00
0005435039568	5428	Economy	9800.00
0005434229018	5428	Economy	9800.00
0005434229059	5428	Economy	9800.00
0005435006954	5428	Economy	9800.00
0005432125428	5428	Economy	9800.00
0005435039598	5428	Economy	9800.00
0005435042850	5428	Economy	9800.00
0005435006956	5428	Economy	9800.00
0005435039561	5428	Economy	9800.00
0005432125429	5428	Economy	9800.00
0005435039571	5428	Economy	9800.00
0005435039552	5428	Economy	9800.00
0005435006959	5428	Economy	9800.00
0005435039578	5428	Economy	9800.00
0005435006967	5428	Economy	9800.00
0005435006960	5428	Economy	9800.00
0005435039591	5428	Economy	9800.00
0005435039589	5428	Economy	9800.00
0005435039538	5428	Economy	9800.00
0005435039539	5428	Economy	9800.00
0005435039592	5428	Economy	9800.00
0005434229132	5428	Economy	9800.00
0005435042851	5428	Economy	9800.00
0005432125430	5428	Economy	9800.00
0005434229105	5428	Economy	9800.00
0005434229099	5428	Economy	9800.00
0005435006948	5428	Economy	9800.00
0005435039593	5428	Economy	9800.00
0005435039567	5428	Economy	9800.00
0005435039570	5428	Economy	9800.00
0005434229111	5428	Economy	9800.00
0005435039564	5428	Economy	9800.00
0005435039595	5428	Economy	9800.00
0005435039576	5428	Economy	9800.00
0005435006953	5428	Economy	9800.00
0005435006968	5428	Economy	9800.00
0005435043284	5428	Economy	9800.00
0005435039581	5428	Economy	9800.00
0005435039544	5428	Economy	9800.00
0005435039555	5428	Economy	9800.00
0005435039573	5428	Economy	9800.00
0005432125427	5428	Economy	9800.00
0005435039122	13005	Business	29500.00
0005435038989	13005	Business	29500.00
0005435038977	13005	Business	29500.00
0005435038811	13005	Business	29500.00
0005435006673	13005	Business	29500.00
0005432304384	13005	Business	29500.00
0005435006735	13005	Business	29500.00
0005435038846	13005	Business	29500.00
0005435039147	13005	Business	29500.00
0005435006771	13005	Business	29500.00
0005435038986	13005	Business	29500.00
0005434229298	13005	Business	29500.00
0005435038845	13005	Economy	9800.00
0005435038898	13005	Economy	9800.00
0005435038901	13005	Economy	9800.00
0005434229308	13005	Economy	9800.00
0005434229299	13005	Economy	9800.00
0005435006715	13005	Economy	9800.00
0005435039028	13005	Economy	9800.00
0005435039055	13005	Economy	9800.00
0005435038976	13005	Economy	9800.00
0005435006840	13005	Economy	9800.00
0005435038816	13005	Economy	9800.00
0005435038949	13005	Economy	9800.00
0005435006889	13005	Economy	9800.00
0005435039004	13005	Economy	9800.00
0005435038859	13005	Economy	9800.00
0005435038948	13005	Economy	9800.00
0005435038903	13005	Economy	9800.00
0005435039019	13005	Economy	9800.00
0005435006783	13005	Economy	9800.00
0005435038802	13005	Economy	9800.00
0005435039213	13005	Economy	9800.00
0005435006790	13005	Economy	9800.00
0005435039047	13005	Economy	9800.00
0005435006616	13005	Economy	9800.00
0005435039159	13005	Economy	9800.00
0005435039005	13005	Economy	9800.00
0005435038921	13005	Economy	9800.00
0005435038856	13005	Economy	9800.00
0005435038729	13005	Economy	9800.00
0005435039300	13005	Economy	9800.00
0005435006770	13005	Economy	9800.00
0005435038855	13005	Economy	9800.00
0005434229297	13005	Economy	9800.00
0005435006785	13005	Economy	9800.00
0005434229290	13005	Economy	9800.00
0005435038813	13005	Economy	9800.00
0005435006733	13005	Economy	9800.00
0005435038988	13005	Economy	9800.00
0005434229294	13005	Economy	10800.00
0005435038922	13005	Economy	10800.00
0005434229307	13005	Economy	10800.00
0005434229303	13005	Economy	10800.00
0005434229291	13005	Economy	10800.00
0005434229309	13005	Economy	9800.00
0005435038812	13005	Economy	9800.00
0005435039015	13005	Economy	9800.00
0005435039097	13005	Economy	9800.00
0005435006841	13005	Economy	9800.00
0005435006736	13005	Economy	9800.00
0005435038858	13005	Economy	9800.00
0005435006734	13005	Economy	9800.00
0005435006751	13005	Economy	9800.00
0005435038937	13005	Economy	9800.00
0005435006846	13005	Economy	9800.00
0005435038730	13005	Economy	9800.00
0005435039003	13005	Economy	9800.00
0005434229293	13005	Economy	9800.00
0005435039104	13005	Economy	9800.00
0005434229302	13005	Economy	9800.00
0005435006732	13005	Economy	9800.00
0005435038982	13005	Economy	9800.00
0005435006617	13005	Economy	9800.00
0005434229311	13005	Economy	9800.00
0005435038914	13005	Economy	9800.00
0005435006707	13005	Economy	9800.00
0005434229305	13005	Economy	9800.00
0005435006711	13005	Economy	9800.00
0005435039023	13005	Economy	9800.00
0005435039027	13005	Economy	9800.00
0005432304385	13005	Economy	9800.00
0005434229310	13005	Economy	9800.00
0005435038934	13005	Economy	9800.00
0005435006763	13005	Economy	9800.00
0005434229295	13005	Economy	9800.00
0005435038700	13005	Economy	9800.00
0005434229296	13005	Economy	9800.00
0005434229306	13005	Economy	9800.00
0005435038990	13005	Economy	9800.00
0005435038713	13005	Economy	9800.00
0005435038701	13005	Economy	9800.00
0005435038810	13005	Economy	9800.00
0005435006687	13005	Economy	9800.00
0005435039072	13005	Economy	9800.00
0005435006731	13005	Economy	9800.00
0005435039046	13005	Economy	9800.00
0005435039148	13005	Economy	9800.00
0005435038902	13005	Economy	9800.00
0005435006791	13005	Economy	9800.00
0005435039124	13005	Economy	9800.00
0005435006716	13005	Economy	9800.00
0005435039071	13005	Economy	9800.00
0005435038809	13005	Economy	9800.00
0005432304386	13005	Economy	9800.00
0005434229312	13005	Economy	9800.00
0005432304387	13005	Economy	9800.00
0005435006786	13005	Economy	9800.00
0005435039024	13005	Economy	9800.00
0005435039030	13005	Economy	9800.00
0005434229289	13005	Economy	9800.00
0005434229301	13005	Economy	9800.00
0005434229300	13005	Economy	9800.00
0005435039010	13005	Economy	9800.00
0005434229304	13005	Economy	9800.00
0005435039066	13005	Economy	9800.00
0005434229292	13005	Economy	9800.00
0005435038857	13005	Economy	9800.00
0005435902467	14869	Business	52900.00
0005435902386	14869	Business	52900.00
0005435902406	14869	Business	52900.00
0005435902440	14869	Business	52900.00
0005434426481	14869	Business	52900.00
0005434426487	14869	Business	52900.00
0005434426489	14869	Business	52900.00
0005434411762	14869	Business	52900.00
0005434426499	14869	Business	52900.00
0005435902449	14869	Business	52900.00
0005435902512	14869	Economy	17600.00
0005435554129	14869	Economy	17600.00
0005434426498	14869	Economy	17600.00
0005434426486	14869	Economy	17600.00
0005434426483	14869	Economy	17600.00
0005434426501	14869	Economy	17600.00
0005434426492	14869	Economy	19400.00
0005435902503	14869	Economy	19400.00
0005435902466	14869	Economy	19400.00
0005434426482	14869	Economy	19400.00
0005435902546	14869	Economy	17600.00
0005434426490	14869	Economy	17600.00
0005434426500	14869	Economy	17600.00
0005434411760	14869	Economy	17600.00
0005434411761	14869	Economy	17600.00
0005434426480	14869	Economy	17600.00
0005434426484	14869	Economy	17600.00
0005435902516	14869	Economy	17600.00
0005434426477	14869	Economy	17600.00
0005435554130	14869	Economy	17600.00
0005435902387	14869	Economy	17600.00
0005434426505	14869	Economy	17600.00
0005432188594	14869	Economy	17600.00
0005435902429	14869	Economy	17600.00
0005432188597	14869	Economy	17600.00
0005434426479	14869	Economy	17600.00
0005434426494	14869	Economy	17600.00
0005434426503	14869	Economy	17600.00
0005435554125	14869	Economy	17600.00
0005434426495	14869	Economy	17600.00
0005435902542	14869	Economy	17600.00
0005434426502	14869	Economy	17600.00
0005435554124	14869	Economy	17600.00
0005435902464	14869	Economy	17600.00
0005434426476	14869	Economy	17600.00
0005434426504	14869	Economy	17600.00
0005434426491	14869	Economy	17600.00
0005434426493	14869	Economy	17600.00
0005434426478	14869	Economy	17600.00
0005435554121	14869	Economy	17600.00
0005434426497	14869	Economy	17600.00
0005434426496	14869	Economy	17600.00
0005432188595	14869	Economy	17600.00
0005434411763	14869	Economy	17600.00
0005435902543	14869	Economy	17600.00
0005434426485	14869	Economy	17600.00
0005435902491	14869	Economy	17600.00
0005435902389	14869	Economy	17600.00
0005435902504	14869	Economy	17600.00
0005435554126	14869	Economy	17600.00
0005432188596	14869	Economy	17600.00
0005434426488	14869	Economy	17600.00
0005435902388	14869	Economy	17600.00
0005435902492	14869	Economy	17600.00
0005435902441	14869	Economy	17600.00
0005434426256	20225	Business	52900.00
0005434426148	20225	Business	52900.00
0005434426264	20225	Business	52900.00
0005435902647	20225	Business	52900.00
0005434411724	20225	Business	52900.00
0005434411719	20225	Business	52900.00
0005434426189	20225	Economy	17600.00
0005434411707	20225	Economy	17600.00
0005434426402	20225	Economy	17600.00
0005434426261	20225	Economy	17600.00
0005434426216	20225	Economy	17600.00
0005435902651	20225	Economy	17600.00
0005435554175	20225	Economy	19400.00
0005435902641	20225	Economy	19400.00
0005435902654	20225	Economy	19400.00
0005434426295	20225	Economy	19400.00
0005434426280	20225	Economy	19400.00
0005435554173	20225	Economy	17600.00
0005434426332	20225	Economy	17600.00
0005434426293	20225	Economy	17600.00
0005434426149	20225	Economy	17600.00
0005435902643	20225	Economy	17600.00
0005434426285	20225	Economy	17600.00
0005434426342	20225	Economy	17600.00
0005434426277	20225	Economy	17600.00
0005435902646	20225	Economy	17600.00
0005434426147	20225	Economy	17600.00
0005434426240	20225	Economy	17600.00
0005435902655	20225	Economy	17600.00
0005434426263	20225	Economy	17600.00
0005434426331	20225	Economy	17600.00
0005434426262	20225	Economy	17600.00
0005434426199	20225	Economy	17600.00
0005434426323	20225	Economy	17600.00
0005435902640	20225	Economy	17600.00
0005434426302	20225	Economy	17600.00
0005434426178	20225	Economy	17600.00
0005435554176	20225	Economy	17600.00
0005435902649	20225	Economy	17600.00
0005435902652	20225	Economy	17600.00
0005434411721	20225	Economy	17600.00
0005434426201	20225	Economy	17600.00
0005432059497	20225	Economy	17600.00
0005434411720	20225	Economy	17600.00
0005435902645	20225	Economy	17600.00
0005434426124	20225	Economy	17600.00
0005434426200	20225	Economy	17600.00
0005434426249	20225	Economy	17600.00
0005434426294	20225	Economy	17600.00
0005434426318	20225	Economy	17600.00
0005435554174	20225	Economy	17600.00
0005434426179	20225	Economy	17600.00
0005435902639	20225	Economy	17600.00
0005435902642	20225	Economy	17600.00
0005432059498	20225	Economy	17600.00
0005434426163	20225	Economy	17600.00
0005435902653	20225	Economy	17600.00
0005434426217	20225	Economy	17600.00
0005434426301	20225	Economy	17600.00
0005435902650	20225	Economy	17600.00
0005434426271	20225	Economy	17600.00
0005434426202	20225	Economy	17600.00
0005435902644	20225	Economy	17600.00
0005434426190	20225	Economy	17600.00
0005434426401	20225	Economy	17600.00
0005435902656	20225	Economy	17600.00
0005435902648	20225	Economy	17600.00
0005433434278	26544	Business	18500.00
0005435982128	26544	Business	18500.00
0005435982125	26544	Business	18500.00
0005432300241	26544	Business	18500.00
0005433434354	26544	Business	18500.00
0005433434352	26544	Business	18500.00
0005435982138	26544	Business	18500.00
0005433434328	26544	Business	18500.00
0005433434407	26544	Business	18500.00
0005433434406	26544	Business	18500.00
0005435982131	26544	Business	18500.00
0005433434353	26544	Business	18500.00
0005433434279	26544	Economy	6200.00
0005435982120	26544	Economy	6200.00
0005435982123	26544	Economy	6200.00
0005433434268	26544	Economy	6200.00
0005433434408	26544	Economy	6200.00
0005435982112	26544	Economy	6200.00
0005435982126	26544	Economy	6200.00
0005435982101	26544	Economy	6200.00
0005433434391	26544	Economy	6200.00
0005432300238	26544	Economy	6200.00
0005435982118	26544	Economy	6800.00
0005435982098	26544	Economy	6800.00
0005433434377	26544	Economy	6800.00
0005435982134	26544	Economy	6800.00
0005435982097	26544	Economy	6200.00
0005435982122	26544	Economy	6200.00
0005435982111	26544	Economy	6200.00
0005434273060	26544	Economy	6200.00
0005435982106	26544	Economy	6200.00
0005435982116	26544	Economy	6200.00
0005433434329	26544	Economy	6200.00
0005433434378	26544	Economy	6200.00
0005435982132	26544	Economy	6200.00
0005435982096	26544	Economy	6200.00
0005433434365	26544	Economy	6200.00
0005433434299	26544	Economy	6200.00
0005432300243	26544	Economy	6200.00
0005435982117	26544	Economy	6200.00
0005435982114	26544	Economy	6200.00
0005433434285	26544	Economy	6200.00
0005435982110	26544	Economy	6200.00
0005435982113	26544	Economy	6200.00
0005435982109	26544	Economy	6200.00
0005433434280	26544	Economy	6200.00
0005435982136	26544	Economy	6200.00
0005433434344	26544	Economy	6200.00
0005435982102	26544	Economy	6200.00
0005432300242	26544	Economy	6200.00
0005435982133	26544	Economy	6200.00
0005435982137	26544	Economy	6200.00
0005432300239	26544	Economy	6200.00
0005433434403	26544	Economy	6200.00
0005435982119	26544	Economy	6200.00
0005433434397	26544	Economy	6200.00
0005433434340	26544	Economy	6200.00
0005434273048	26544	Economy	6200.00
0005435982121	26544	Economy	6200.00
0005433434418	26544	Economy	6200.00
0005435982124	26544	Economy	6200.00
0005435982139	26544	Economy	6200.00
0005435982130	26544	Economy	6200.00
0005433434302	26544	Economy	6200.00
0005434273061	26544	Economy	6200.00
0005435982107	26544	Economy	6200.00
0005435982099	26544	Economy	6200.00
0005435982108	26544	Economy	6200.00
0005432300240	26544	Economy	6200.00
0005435982127	26544	Economy	6200.00
0005435982103	26544	Economy	6200.00
0005435982140	26544	Economy	6200.00
0005435982100	26544	Economy	6200.00
0005433434405	26544	Economy	6200.00
0005435982115	26544	Economy	6200.00
0005433434217	26544	Economy	6200.00
0005434273049	26544	Economy	6200.00
0005433434376	26544	Economy	6200.00
0005433434318	26544	Economy	6200.00
0005433434364	26544	Economy	6200.00
0005433434409	26544	Economy	6200.00
0005433434392	26544	Economy	6200.00
0005435982105	26544	Economy	6200.00
0005435982135	26544	Economy	6200.00
0005433434355	26544	Economy	6200.00
0005434270181	26544	Economy	6200.00
0005435982104	26544	Economy	6200.00
0005435982129	26544	Economy	6200.00
0005433434402	26544	Economy	6200.00
0005433434396	26544	Economy	6200.00
0005433434609	26717	Business	18500.00
0005435981635	26717	Business	18500.00
0005435981775	26717	Business	18500.00
0005434271305	26717	Business	18500.00
0005432051118	26717	Business	18500.00
0005435981898	26717	Business	18500.00
0005435981643	26717	Business	18500.00
0005432051119	26717	Business	18500.00
0005435981828	26717	Business	18500.00
0005435981765	26717	Business	18500.00
0005435981769	26717	Economy	6200.00
0005435981804	26717	Economy	6200.00
0005435981624	26717	Economy	6200.00
0005433434608	26717	Economy	6200.00
0005433434604	26717	Economy	6200.00
0005433434592	26717	Economy	6200.00
0005433434600	26717	Economy	6800.00
0005435981652	26717	Economy	6800.00
0005434271306	26717	Economy	6800.00
0005435981836	26717	Economy	6800.00
0005434269098	26717	Economy	6800.00
0005435981723	26717	Economy	6200.00
0005435981770	26717	Economy	6200.00
0005435981737	26717	Economy	6200.00
0005433434594	26717	Economy	6200.00
0005435981692	26717	Economy	6200.00
0005433434591	26717	Economy	6200.00
0005435981722	26717	Economy	6200.00
0005435981634	26717	Economy	6200.00
0005433434599	26717	Economy	6200.00
0005433434585	26717	Economy	6200.00
0005435981706	26717	Economy	6200.00
0005433434590	26717	Economy	6200.00
0005435981702	26717	Economy	6200.00
0005435981767	26717	Economy	6200.00
0005433434611	26717	Economy	6200.00
0005433434589	26717	Economy	6200.00
0005435981803	26717	Economy	6200.00
0005434270199	26717	Economy	6200.00
0005435981644	26717	Economy	6200.00
0005435981766	26717	Economy	6200.00
0005432051120	26717	Economy	6200.00
0005433434610	26717	Economy	6200.00
0005434269097	26717	Economy	6200.00
0005435981851	26717	Economy	6200.00
0005435981879	26717	Economy	6200.00
0005435981902	26717	Economy	6200.00
0005433434596	26717	Economy	6200.00
0005433434598	26717	Economy	6200.00
0005435981633	26717	Economy	6200.00
0005433434602	26717	Economy	6200.00
0005434269096	26717	Economy	6200.00
0005433434603	26717	Economy	6200.00
0005433434583	26717	Economy	6200.00
0005434270202	26717	Economy	6200.00
0005433434597	26717	Economy	6200.00
0005433434607	26717	Economy	6200.00
0005435981897	26717	Economy	6200.00
0005435981805	26717	Economy	6200.00
0005435981764	26717	Economy	6200.00
0005434270200	26717	Economy	6200.00
0005435981880	26717	Economy	6200.00
0005435981776	26717	Economy	6200.00
0005433434605	26717	Economy	6200.00
0005433434586	26717	Economy	6200.00
0005435981911	26717	Economy	6200.00
0005435981736	26717	Economy	6200.00
0005435981795	26717	Economy	6200.00
0005433434606	26717	Economy	6200.00
0005433434601	26717	Economy	6200.00
0005433434595	26717	Economy	6200.00
0005435981796	26717	Economy	6200.00
0005433434588	26717	Economy	6200.00
0005433434593	26717	Economy	6200.00
0005435981682	26717	Economy	6200.00
0005433434587	26717	Economy	6200.00
0005435981852	26717	Economy	6200.00
0005435981748	26717	Economy	6200.00
0005434270201	26717	Economy	6200.00
0005433434584	26717	Economy	6200.00
0005433687689	19511	Economy	21000.00
0005433685514	19511	Economy	21000.00
0005433687696	19511	Economy	21000.00
0005433687703	19511	Economy	21000.00
0005433687690	19511	Economy	19100.00
0005433686621	19511	Economy	19100.00
0005433685518	19511	Economy	19100.00
0005433686625	19511	Economy	19100.00
0005433687695	19511	Economy	19100.00
0005433686629	19511	Economy	19100.00
0005433686617	19511	Economy	19100.00
0005433685513	19511	Economy	19100.00
0005433686623	19511	Economy	19100.00
0005433685516	19511	Economy	19100.00
0005433687697	19511	Economy	19100.00
0005433687691	19511	Economy	19100.00
0005433685509	19511	Economy	19100.00
0005433687700	19511	Economy	19100.00
0005433687694	19511	Economy	19100.00
0005433687701	19511	Economy	19100.00
0005433686618	19511	Economy	19100.00
0005433687698	19511	Economy	19100.00
0005433687699	19511	Economy	19100.00
0005433686619	19511	Economy	19100.00
0005433686620	19511	Economy	19100.00
0005433685517	19511	Economy	19100.00
0005433685507	19511	Economy	19100.00
0005433686626	19511	Economy	19100.00
0005433685508	19511	Economy	19100.00
0005433685511	19511	Economy	19100.00
0005433687702	19511	Economy	19100.00
0005433685512	19511	Economy	19100.00
0005433685515	19511	Economy	19100.00
0005433686628	19511	Economy	19100.00
0005433685519	19511	Economy	19100.00
0005433686622	19511	Economy	19100.00
0005433686624	19511	Economy	19100.00
0005433687692	19511	Economy	19100.00
0005433686627	19511	Economy	19100.00
0005433686630	19511	Economy	19100.00
0005433685510	19511	Economy	19100.00
0005433687693	19511	Economy	19100.00
0005433685520	19511	Economy	19100.00
0005432583957	3148	Economy	11100.00
0005432857935	3148	Economy	11100.00
0005432583952	3148	Economy	11100.00
0005432583947	3148	Economy	10100.00
0005432583959	3148	Economy	10100.00
0005432583968	3148	Economy	10100.00
0005432583950	3148	Economy	10100.00
0005432857933	3148	Economy	10100.00
0005432583965	3148	Economy	10100.00
0005432583967	3148	Economy	10100.00
0005432583964	3148	Economy	10100.00
0005432583961	3148	Economy	10100.00
0005432583958	3148	Economy	10100.00
0005432857904	3148	Economy	10100.00
0005432583943	3148	Economy	10100.00
0005432583954	3148	Economy	10100.00
0005432583953	3148	Economy	10100.00
0005432583951	3148	Economy	10100.00
0005432583944	3148	Economy	10100.00
0005432857934	3148	Economy	10100.00
0005432583962	3148	Economy	10100.00
0005432583945	3148	Economy	10100.00
0005432216263	3148	Economy	10100.00
0005432583946	3148	Economy	10100.00
0005432857874	3148	Economy	10100.00
0005432583960	3148	Economy	10100.00
0005432583949	3148	Economy	10100.00
0005432583948	3148	Economy	10100.00
0005432583966	3148	Economy	10100.00
0005432583956	3148	Economy	10100.00
0005432857922	3148	Economy	10100.00
0005432216264	3148	Economy	10100.00
0005432216262	3148	Economy	10100.00
0005432857875	3148	Economy	10100.00
0005432857960	3148	Economy	10100.00
0005432583955	3148	Economy	10100.00
0005432583963	3148	Economy	10100.00
0005432857910	3148	Economy	10100.00
0005432583683	31493	Economy	11100.00
0005432583788	31493	Economy	11100.00
0005432858025	31493	Economy	10100.00
0005432583759	31493	Economy	10100.00
0005432858031	31493	Economy	10100.00
0005432583819	31493	Economy	10100.00
0005432583817	31493	Economy	10100.00
0005432583772	31493	Economy	10100.00
0005432858026	31493	Economy	10100.00
0005432583712	31493	Economy	10100.00
0005432858023	31493	Economy	10100.00
0005432583653	31493	Economy	10100.00
0005432583827	31493	Economy	10100.00
0005432583742	31493	Economy	10100.00
0005432583783	31493	Economy	10100.00
0005432583812	31493	Economy	10100.00
0005432583721	31493	Economy	10100.00
0005432858030	31493	Economy	10100.00
0005432583760	31493	Economy	10100.00
0005432583784	31493	Economy	10100.00
0005432583744	31493	Economy	10100.00
0005432583809	31493	Economy	10100.00
0005432583694	31493	Economy	10100.00
0005432858027	31493	Economy	10100.00
0005432858034	31493	Economy	10100.00
0005432583743	31493	Economy	10100.00
0005432858035	31493	Economy	10100.00
0005432858032	31493	Economy	10100.00
0005432583771	31493	Economy	10100.00
0005432583818	31493	Economy	10100.00
0005432858029	31493	Economy	10100.00
0005432583781	31493	Economy	10100.00
0005432858028	31493	Economy	10100.00
0005432583720	31493	Economy	10100.00
0005432583782	31493	Economy	10100.00
0005432583774	31493	Economy	10100.00
0005432583764	31493	Economy	10100.00
0005432858024	31493	Economy	10100.00
0005432858033	31493	Economy	10100.00
0005432583761	31493	Economy	10100.00
0005433255038	910	Economy	8300.00
0005433255070	910	Economy	7500.00
0005433255046	910	Economy	7500.00
0005434943318	910	Economy	7500.00
0005434943326	910	Economy	7500.00
0005434943321	910	Economy	7500.00
0005433255053	910	Economy	7500.00
0005433255045	910	Economy	7500.00
0005434943319	910	Economy	7500.00
0005433255052	910	Economy	7500.00
0005434943322	910	Economy	7500.00
0005433255071	910	Economy	7500.00
0005434943324	910	Economy	7500.00
0005433255063	910	Economy	7500.00
0005433255048	910	Economy	7500.00
0005434943320	910	Economy	7500.00
0005434943325	910	Economy	7500.00
0005434943323	910	Economy	7500.00
0005434943317	910	Economy	7500.00
0005434943228	16208	Economy	7500.00
0005434943199	16208	Economy	7500.00
0005434943254	16208	Economy	7500.00
0005433255103	16208	Economy	7500.00
0005433255102	16208	Economy	7500.00
0005434943246	16208	Economy	7500.00
0005433255100	16208	Economy	7500.00
0005433255099	16208	Economy	7500.00
0005434943229	16208	Economy	7500.00
0005433255101	16208	Economy	7500.00
0005434943226	16208	Economy	7500.00
0005434943255	16208	Economy	7500.00
0005434943247	16208	Economy	7500.00
0005433255104	16208	Economy	7500.00
0005434943227	16208	Economy	7500.00
0005433654742	4327	Business	90500.00
0005433654749	4327	Business	90500.00
0005435858513	4327	Business	90500.00
0005433654755	4327	Business	90500.00
0005435858499	4327	Business	90500.00
0005433654745	4327	Business	90500.00
0005433654741	4327	Business	90500.00
0005435858494	4327	Economy	30200.00
0005433654753	4327	Economy	30200.00
0005433654746	4327	Economy	30200.00
0005435858514	4327	Economy	30200.00
0005433654747	4327	Economy	30200.00
0005435858509	4327	Economy	30200.00
0005435858512	4327	Economy	33200.00
0005435858504	4327	Economy	30200.00
0005435858515	4327	Economy	30200.00
0005433654757	4327	Economy	30200.00
0005433654737	4327	Economy	30200.00
0005433654756	4327	Economy	30200.00
0005433654751	4327	Economy	30200.00
0005433654739	4327	Economy	30200.00
0005433654748	4327	Economy	30200.00
0005433654752	4327	Economy	30200.00
0005433654754	4327	Economy	30200.00
0005435858511	4327	Economy	30200.00
0005433654743	4327	Economy	30200.00
0005435858506	4327	Economy	30200.00
0005433654758	4327	Economy	30200.00
0005433654738	4327	Economy	30200.00
0005433654759	4327	Economy	30200.00
0005433654744	4327	Economy	30200.00
0005435858505	4327	Economy	30200.00
0005433654740	4327	Economy	30200.00
0005433654750	4327	Economy	30200.00
0005433811613	14399	Economy	4400.00
0005433811612	14399	Economy	4400.00
0005433811614	14399	Economy	4400.00
0005433811628	27871	Economy	4400.00
0005433811629	27871	Economy	4400.00
0005433811631	27871	Economy	4400.00
0005433811630	27871	Economy	4400.00
0005433811625	27871	Economy	4400.00
0005433811632	27871	Economy	4400.00
0005433811627	27871	Economy	4400.00
0005433811626	27871	Economy	4400.00
0005433811621	27871	Economy	4400.00
0005433811624	27871	Economy	4400.00
0005433811623	27871	Economy	4400.00
0005433811622	27871	Economy	4400.00
0005433367549	21730	Business	9800.00
0005433367218	21730	Business	9800.00
0005435652905	21730	Business	9800.00
0005435652888	21730	Business	9800.00
0005433367504	21730	Business	9800.00
0005433367637	21730	Business	9800.00
0005435652896	21730	Business	9800.00
0005433367344	21730	Business	9800.00
0005433367479	21730	Business	9800.00
0005435652910	21730	Business	9800.00
0005433367429	21730	Business	9800.00
0005435652906	21730	Business	9800.00
0005433367420	21730	Economy	3300.00
0005433367593	21730	Economy	3300.00
0005435652901	21730	Economy	3300.00
0005433367269	21730	Economy	3300.00
0005433367305	21730	Economy	3300.00
0005435652916	21730	Economy	3300.00
0005433367401	21730	Economy	3300.00
0005435652894	21730	Economy	3300.00
0005435652887	21730	Economy	3300.00
0005433367268	21730	Economy	3300.00
0005433367482	21730	Economy	3600.00
0005433367518	21730	Economy	3600.00
0005435652903	21730	Economy	3600.00
0005435652899	21730	Economy	3300.00
0005433367430	21730	Economy	3300.00
0005433367388	21730	Economy	3300.00
0005433367326	21730	Economy	3300.00
0005433367369	21730	Economy	3300.00
0005433367343	21730	Economy	3300.00
0005435652884	21730	Economy	3300.00
0005435652881	21730	Economy	3300.00
0005433367224	21730	Economy	3300.00
0005433367335	21730	Economy	3300.00
0005433367325	21730	Economy	3300.00
0005433367592	21730	Economy	3300.00
0005435652882	21730	Economy	3300.00
0005433367486	21730	Economy	3300.00
0005433367334	21730	Economy	3300.00
0005435652895	21730	Economy	3300.00
0005435652902	21730	Economy	3300.00
0005435652893	21730	Economy	3300.00
0005435652880	21730	Economy	3300.00
0005433367435	21730	Economy	3300.00
0005433367379	21730	Economy	3300.00
0005435652891	21730	Economy	3300.00
0005433367444	21730	Economy	3300.00
0005435652914	21730	Economy	3300.00
0005435652909	21730	Economy	3300.00
0005435652886	21730	Economy	3300.00
0005433367595	21730	Economy	3300.00
0005435652898	21730	Economy	3300.00
0005433367579	21730	Economy	3300.00
0005433367550	21730	Economy	3300.00
0005433367384	21730	Economy	3300.00
0005435652900	21730	Economy	3300.00
0005433367353	21730	Economy	3300.00
0005435652908	21730	Economy	3300.00
0005433367594	21730	Economy	3300.00
0005433367336	21730	Economy	3300.00
0005433367524	21730	Economy	3300.00
0005435652907	21730	Economy	3300.00
0005433367295	21730	Economy	3300.00
0005433367478	21730	Economy	3300.00
0005433367503	21730	Economy	3300.00
0005435652883	21730	Economy	3300.00
0005435652904	21730	Economy	3300.00
0005435652912	21730	Economy	3300.00
0005433367416	21730	Economy	3300.00
0005435652890	21730	Economy	3300.00
0005435652878	21730	Economy	3300.00
0005435652897	21730	Economy	3300.00
0005435652885	21730	Economy	3300.00
0005435652915	21730	Economy	3300.00
0005435652911	21730	Economy	3300.00
0005435652889	21730	Economy	3300.00
0005433367551	21730	Economy	3300.00
0005435652913	21730	Economy	3300.00
0005435652879	21730	Economy	3300.00
0005435652892	21730	Economy	3300.00
0005433367591	21730	Economy	3300.00
0005433784833	9388	Business	186200.00
0005434170901	9388	Business	186200.00
0005433805252	9388	Business	186200.00
0005433784837	9388	Business	186200.00
0005432657438	9388	Business	186200.00
0005434170900	9388	Business	186200.00
0005433784841	9388	Business	186200.00
0005433805269	9388	Business	186200.00
0005433805276	9388	Business	186200.00
0005433784845	9388	Business	186200.00
0005433763160	9388	Business	186200.00
0005433784832	9388	Business	186200.00
0005433784836	9388	Business	186200.00
0005434170845	9388	Business	186200.00
0005433805275	9388	Business	186200.00
0005433805277	9388	Business	186200.00
0005433805249	9388	Business	186200.00
0005434170871	9388	Business	186200.00
0005433805279	9388	Business	186200.00
0005433784827	9388	Business	186200.00
0005435269648	9388	Business	186200.00
0005433784821	9388	Economy	68300.00
0005434170933	9388	Economy	62100.00
0005433805246	9388	Economy	62100.00
0005433784850	9388	Economy	62100.00
0005433805266	9388	Economy	62100.00
0005433763158	9388	Economy	62100.00
0005435269663	9388	Economy	62100.00
0005433784847	9388	Economy	62100.00
0005434170941	9388	Economy	62100.00
0005433763157	9388	Economy	62100.00
0005433784831	9388	Economy	62100.00
0005433805260	9388	Economy	62100.00
0005432666382	9388	Economy	62100.00
0005433805265	9388	Economy	62100.00
0005433763159	9388	Economy	62100.00
0005434170886	9388	Economy	62100.00
0005433805257	9388	Economy	62100.00
0005433784814	9388	Economy	62100.00
0005435269653	9388	Economy	62100.00
0005433784823	9388	Economy	62100.00
0005435269664	9388	Economy	62100.00
0005433805267	9388	Economy	62100.00
0005433805278	9388	Economy	62100.00
0005434170911	9388	Economy	62100.00
0005432657439	9388	Economy	62100.00
0005433805268	9388	Economy	62100.00
0005434170876	9388	Economy	62100.00
0005433805274	9388	Economy	62100.00
0005433784825	9388	Economy	62100.00
0005433805280	9388	Economy	62100.00
0005432665267	9388	Economy	62100.00
0005433805250	9388	Economy	62100.00
0005435269635	9388	Economy	62100.00
0005433805254	9388	Economy	62100.00
0005433763163	9388	Economy	62100.00
0005433784839	9388	Economy	62100.00
0005433805281	9388	Economy	62100.00
0005433763156	9388	Economy	62100.00
0005435269634	9388	Economy	62100.00
0005433784843	9388	Economy	62100.00
0005433805258	9388	Economy	62100.00
0005433784828	9388	Economy	62100.00
0005433784826	9388	Economy	62100.00
0005433805282	9388	Economy	62100.00
0005433763152	9388	Economy	62100.00
0005433763161	9388	Economy	62100.00
0005433784829	9388	Economy	62100.00
0005433805271	9388	Economy	62100.00
0005435269649	9388	Economy	62100.00
0005433784842	9388	Economy	62100.00
0005433805285	9388	Economy	62100.00
0005434170877	9388	Economy	62100.00
0005433784822	9388	Economy	62100.00
0005433784834	9388	Economy	62100.00
0005433784819	9388	Economy	62100.00
0005433784844	9388	Economy	62100.00
0005433805262	9388	Economy	62100.00
0005433763164	9388	Economy	62100.00
0005433805248	9388	Economy	62100.00
0005435269639	9388	Economy	62100.00
0005433805284	9388	Economy	68300.00
0005434151684	9388	Economy	68300.00
0005433784816	9388	Economy	62100.00
0005433784830	9388	Economy	62100.00
0005433805259	9388	Economy	62100.00
0005433763165	9388	Economy	62100.00
0005432667447	9388	Economy	62100.00
0005433805272	9388	Economy	62100.00
0005433805273	9388	Economy	62100.00
0005433805255	9388	Economy	62100.00
0005433784815	9388	Economy	62100.00
0005433784835	9388	Economy	62100.00
0005433784824	9388	Economy	62100.00
0005433784838	9388	Economy	62100.00
0005433805270	9388	Economy	62100.00
0005433784818	9388	Economy	62100.00
0005434170912	9388	Economy	62100.00
0005434170902	9388	Economy	62100.00
0005433805263	9388	Economy	62100.00
0005433784820	9388	Economy	62100.00
0005435269658	9388	Economy	62100.00
0005435269645	9388	Economy	62100.00
0005433763166	9388	Economy	62100.00
0005433784817	9388	Economy	62100.00
0005433763155	9388	Economy	62100.00
0005433805247	9388	Economy	62100.00
0005433805253	9388	Economy	62100.00
0005433763154	9388	Economy	62100.00
0005435269646	9388	Economy	62100.00
0005433805264	9388	Economy	62100.00
0005434170927	9388	Economy	62100.00
0005434170870	9388	Economy	62100.00
0005433805283	9388	Economy	62100.00
0005434170940	9388	Economy	62100.00
0005435269655	9388	Economy	62100.00
0005432666381	9388	Economy	62100.00
0005433784849	9388	Economy	62100.00
0005435269661	9388	Economy	62100.00
0005434170885	9388	Economy	62100.00
0005433805261	9388	Economy	62100.00
0005433784846	9388	Economy	62100.00
0005433763153	9388	Economy	62100.00
0005433805251	9388	Economy	62100.00
0005434170931	9388	Economy	62100.00
0005432657440	9388	Economy	62100.00
0005435269662	9388	Economy	62100.00
0005433784840	9388	Economy	62100.00
0005435269654	9388	Economy	62100.00
0005433805256	9388	Economy	62100.00
0005433763162	9388	Economy	62100.00
0005435269636	9388	Economy	62100.00
0005433784848	9388	Economy	62100.00
0005432665268	9388	Economy	62100.00
0005434170942	9388	Economy	62100.00
0005433805046	26249	Business	186200.00
0005433784518	26249	Business	186200.00
0005433784460	26249	Business	186200.00
0005435269743	26249	Business	186200.00
0005433784468	26249	Business	186200.00
0005433784662	26249	Business	186200.00
0005433763102	26249	Business	186200.00
0005433784554	26249	Business	186200.00
0005433763065	26249	Business	186200.00
0005433805028	26249	Business	186200.00
0005432659673	26249	Business	186200.00
0005433805041	26249	Business	186200.00
0005433784631	26249	Business	186200.00
0005435269745	26249	Business	186200.00
0005433763039	26249	Business	186200.00
0005435269738	26249	Business	186200.00
0005433784620	26249	Business	186200.00
0005433804947	26249	Business	186200.00
0005433763101	26249	Business	186200.00
0005433805025	26249	Business	186200.00
0005433763053	26249	Economy	68300.00
0005434151696	26249	Economy	68300.00
0005433784571	26249	Economy	68300.00
0005433763020	26249	Economy	68300.00
0005433804907	26249	Economy	62100.00
0005433805060	26249	Economy	62100.00
0005432659676	26249	Economy	62100.00
0005434171007	26249	Economy	62100.00
0005433805007	26249	Economy	62100.00
0005435269739	26249	Economy	62100.00
0005433784622	26249	Economy	62100.00
0005435269736	26249	Economy	62100.00
0005433763040	26249	Economy	62100.00
0005433805026	26249	Economy	62100.00
0005433763058	26249	Economy	62100.00
0005433784467	26249	Economy	62100.00
0005433784621	26249	Economy	62100.00
0005433784451	26249	Economy	62100.00
0005433784697	26249	Economy	62100.00
0005433784466	26249	Economy	62100.00
0005433804906	26249	Economy	62100.00
0005433784533	26249	Economy	62100.00
0005433784639	26249	Economy	62100.00
0005434171009	26249	Economy	62100.00
0005433804796	26249	Economy	62100.00
0005433784471	26249	Economy	62100.00
0005434171002	26249	Economy	62100.00
0005433804990	26249	Economy	62100.00
0005433804957	26249	Economy	62100.00
0005434171006	26249	Economy	62100.00
0005434151693	26249	Economy	62100.00
0005434171005	26249	Economy	62100.00
0005433804985	26249	Economy	62100.00
0005433784542	26249	Economy	62100.00
0005434269094	26249	Economy	62100.00
0005433784520	26249	Economy	62100.00
0005435269742	26249	Economy	62100.00
0005433804870	26249	Economy	62100.00
0005432657406	26249	Economy	62100.00
0005435269744	26249	Economy	62100.00
0005433784529	26249	Economy	62100.00
0005434271304	26249	Economy	62100.00
0005433762974	26249	Economy	62100.00
0005434171003	26249	Economy	62100.00
0005433804948	26249	Economy	62100.00
0005433784519	26249	Economy	62100.00
0005433805130	26249	Economy	62100.00
0005433763031	26249	Economy	62100.00
0005433763032	26249	Economy	62100.00
0005433784399	26249	Economy	62100.00
0005433784499	26249	Economy	62100.00
0005434151695	26249	Economy	62100.00
0005433762957	26249	Economy	62100.00
0005434151697	26249	Economy	62100.00
0005433784567	26249	Economy	62100.00
0005433804869	26249	Economy	62100.00
0005433763087	26249	Economy	62100.00
0005432659681	26249	Economy	62100.00
0005433784576	26249	Economy	62100.00
0005433805029	26249	Economy	62100.00
0005433784556	26249	Economy	62100.00
0005434171016	26249	Economy	62100.00
0005433784661	26249	Economy	62100.00
0005433805097	26249	Economy	62100.00
0005435269740	26249	Economy	62100.00
0005433784566	26249	Economy	62100.00
0005433805098	26249	Economy	62100.00
0005435269737	26249	Economy	62100.00
0005433804956	26249	Economy	62100.00
0005432659675	26249	Economy	62100.00
0005433784484	26249	Economy	62100.00
0005432657422	26249	Economy	62100.00
0005433804995	26249	Economy	62100.00
0005433805059	26249	Economy	62100.00
0005433784469	26249	Economy	68300.00
0005433804940	26249	Economy	68300.00
0005435269741	26249	Economy	62100.00
0005433784638	26249	Economy	62100.00
0005433784406	26249	Economy	62100.00
0005433804908	26249	Economy	68300.00
0005434151694	26249	Economy	62100.00
0005433784503	26249	Economy	68300.00
0005433804984	26249	Economy	62100.00
0005433784605	26249	Economy	62100.00
0005433762973	26249	Economy	62100.00
0005433784528	26249	Economy	62100.00
0005433804989	26249	Economy	62100.00
0005433784461	26249	Economy	62100.00
0005434171012	26249	Economy	62100.00
0005433804994	26249	Economy	62100.00
0005434171011	26249	Economy	62100.00
0005433784568	26249	Economy	62100.00
0005433763017	26249	Economy	62100.00
0005433805045	26249	Economy	62100.00
0005434269095	26249	Economy	62100.00
0005434171010	26249	Economy	62100.00
0005433804986	26249	Economy	62100.00
0005433804911	26249	Economy	62100.00
0005432657408	26249	Economy	62100.00
0005434171015	26249	Economy	62100.00
0005433804916	26249	Economy	62100.00
0005433784477	26249	Economy	62100.00
0005433804934	26249	Economy	62100.00
0005433784551	26249	Economy	62100.00
0005433784581	26249	Economy	62100.00
0005434171014	26249	Economy	62100.00
0005433805074	26249	Economy	62100.00
0005433763092	26249	Economy	62100.00
0005433804935	26249	Economy	62100.00
0005434171004	26249	Economy	62100.00
0005434171013	26249	Economy	62100.00
0005432659680	26249	Economy	62100.00
0005433784572	26249	Economy	62100.00
0005433804912	26249	Economy	62100.00
0005433784340	26249	Economy	62100.00
0005432657405	26249	Economy	62100.00
0005433784573	26249	Economy	62100.00
0005433784630	26249	Economy	62100.00
0005433763060	26249	Economy	62100.00
0005433804924	26249	Economy	62100.00
0005433804871	26249	Economy	62100.00
0005433805077	26249	Economy	62100.00
0005433805008	26249	Economy	62100.00
0005433763033	26249	Economy	62100.00
0005433763059	26249	Economy	62100.00
0005433805024	26249	Economy	62100.00
0005433763010	26249	Economy	62100.00
0005433804865	26249	Economy	62100.00
0005433784428	26249	Economy	62100.00
0005433763043	26249	Economy	62100.00
0005434171008	26249	Economy	62100.00
0005435929614	4903	Economy	5900.00
0005435929617	4903	Economy	5300.00
0005435135653	4903	Economy	5300.00
0005435135654	4903	Economy	5300.00
0005435929607	4903	Economy	5300.00
0005435135655	4903	Economy	5300.00
0005435135652	4903	Economy	5300.00
0005435135656	4903	Economy	5300.00
0005435929603	4903	Economy	5300.00
0005435929606	4903	Economy	5300.00
0005435135603	33005	Economy	5900.00
0005435135602	33005	Economy	5300.00
0005435929634	33005	Economy	5300.00
0005435929637	33005	Economy	5300.00
0005435135598	33005	Economy	5300.00
0005435929636	33005	Economy	5300.00
0005435929635	33005	Economy	5300.00
0005434983270	9493	Economy	17900.00
0005434983271	9493	Economy	17900.00
0005434983272	9493	Economy	17900.00
0005434983268	9493	Economy	17900.00
0005434983269	9493	Economy	17900.00
0005434217925	9493	Economy	17900.00
0005434217902	9493	Economy	17900.00
0005434983239	27363	Economy	19700.00
0005434217953	27363	Economy	17900.00
0005434983226	27363	Economy	17900.00
0005434217954	27363	Economy	17900.00
0005434217955	27363	Economy	17900.00
0005434217956	27363	Economy	17900.00
0005434983215	27363	Economy	17900.00
0005434983225	27363	Economy	17900.00
0005433960116	24288	Business	36400.00
0005433985392	24288	Business	36400.00
0005433960141	24288	Business	36400.00
0005433985460	24288	Business	36400.00
0005433985252	24288	Business	36400.00
0005433960043	24288	Business	36400.00
0005433985407	24288	Business	36400.00
0005433985393	24288	Business	36400.00
0005433959926	24288	Business	36400.00
0005433985366	24288	Business	36400.00
0005433960080	24288	Business	36400.00
0005433960011	24288	Business	36400.00
0005433960177	24288	Business	36400.00
0005433960074	24288	Economy	13400.00
0005433985510	24288	Economy	13400.00
0005433985320	24288	Economy	13400.00
0005433985284	24288	Economy	12100.00
0005433985361	24288	Economy	12100.00
0005433985235	24288	Economy	12100.00
0005433985363	24288	Economy	12100.00
0005433985368	24288	Economy	12100.00
0005433985372	24288	Economy	12100.00
0005433960140	24288	Economy	12100.00
0005433960053	24288	Economy	12100.00
0005433985540	24288	Economy	12100.00
0005433960096	24288	Economy	12100.00
0005433985181	24288	Economy	12100.00
0005433960191	24288	Economy	12100.00
0005433960118	24288	Economy	12100.00
0005433960090	24288	Economy	12100.00
0005433959988	24288	Economy	12100.00
0005433985218	24288	Economy	12100.00
0005433960101	24288	Economy	12100.00
0005433985554	24288	Economy	12100.00
0005433985210	24288	Economy	12100.00
0005433985474	24288	Economy	12100.00
0005433985291	24288	Economy	12100.00
0005433985539	24288	Economy	12100.00
0005433985415	24288	Economy	12100.00
0005433985326	24288	Economy	12100.00
0005433960235	24288	Economy	12100.00
0005433985289	24288	Economy	12100.00
0005433985491	24288	Economy	12100.00
0005433985352	24288	Economy	12100.00
0005433985394	24288	Economy	12100.00
0005433985561	24288	Economy	12100.00
0005433985546	24288	Economy	12100.00
0005433985263	24288	Economy	12100.00
0005433960212	24288	Economy	12100.00
0005433960128	24288	Economy	12100.00
0005433960234	24288	Economy	12100.00
0005433959972	24288	Economy	12100.00
0005433985439	24288	Economy	12100.00
0005433960233	24288	Economy	12100.00
0005433960102	24288	Economy	12100.00
0005433960015	24288	Economy	12100.00
0005433985264	24288	Economy	12100.00
0005433960041	24288	Economy	12100.00
0005433985414	24288	Economy	12100.00
0005433959989	24288	Economy	12100.00
0005433985515	24288	Economy	12100.00
0005433985290	24288	Economy	12100.00
0005433985395	24288	Economy	12100.00
0005433960223	24288	Economy	12100.00
0005433985504	24288	Economy	12100.00
0005433960095	24288	Economy	12100.00
0005433960089	24288	Economy	12100.00
0005433985179	24288	Economy	12100.00
0005433985219	24288	Economy	12100.00
0005433960213	24288	Economy	12100.00
0005433960180	24288	Economy	13400.00
0005433960013	24288	Economy	12100.00
0005433960204	24288	Economy	12100.00
0005433960192	24288	Economy	12100.00
0005433985545	24288	Economy	12100.00
0005433985331	24288	Economy	12100.00
0005433985516	24288	Economy	12100.00
0005433960122	24288	Economy	12100.00
0005433985413	24288	Economy	12100.00
0005433985340	24288	Economy	12100.00
0005433985528	24288	Economy	12100.00
0005433960114	24288	Economy	12100.00
0005433960042	24288	Economy	12100.00
0005433985211	24288	Economy	12100.00
0005433959948	24288	Economy	12100.00
0005433985450	24288	Economy	12100.00
0005433985438	24288	Economy	12100.00
0005433985341	24288	Economy	12100.00
0005433959942	24288	Economy	12100.00
0005433985367	24288	Economy	12100.00
0005433960267	24288	Economy	12100.00
0005433985182	24288	Economy	12100.00
0005433985213	24288	Economy	12100.00
0005433985279	24288	Economy	12100.00
0005433985342	24288	Economy	12100.00
0005433960012	24288	Economy	12100.00
0005433959949	24288	Economy	12100.00
0005433985437	24288	Economy	12100.00
0005433960121	24288	Economy	12100.00
0005433960237	24288	Economy	12100.00
0005433985308	24288	Economy	12100.00
0005433960227	24288	Economy	12100.00
0005433985473	24288	Economy	12100.00
0005433985330	24288	Economy	12100.00
0005433985305	24288	Economy	12100.00
0005433960176	24288	Economy	12100.00
0005433960240	24288	Economy	12100.00
0005433985508	24288	Economy	12100.00
0005433960243	24288	Economy	12100.00
0005433960115	24288	Economy	12100.00
0005433985251	24288	Economy	12100.00
0005433960656	25944	Business	36400.00
0005433985785	25944	Business	36400.00
0005433960652	25944	Business	36400.00
0005433960672	25944	Business	36400.00
0005433985761	25944	Business	36400.00
0005433960653	25944	Business	36400.00
0005433985769	25944	Business	36400.00
0005433960636	25944	Business	36400.00
0005433960674	25944	Business	36400.00
0005433985790	25944	Business	36400.00
0005433985743	25944	Business	36400.00
0005433985752	25944	Economy	13400.00
0005433985755	25944	Economy	13400.00
0005433985780	25944	Economy	12100.00
0005433960635	25944	Economy	12100.00
0005433985745	25944	Economy	12100.00
0005433985778	25944	Economy	12100.00
0005433985748	25944	Economy	12100.00
0005433985787	25944	Economy	12100.00
0005433960642	25944	Economy	12100.00
0005433960643	25944	Economy	12100.00
0005433960644	25944	Economy	12100.00
0005433985760	25944	Economy	12100.00
0005433985754	25944	Economy	12100.00
0005433960651	25944	Economy	12100.00
0005433960630	25944	Economy	12100.00
0005433985770	25944	Economy	12100.00
0005433960655	25944	Economy	12100.00
0005433960663	25944	Economy	12100.00
0005433985749	25944	Economy	12100.00
0005433985775	25944	Economy	12100.00
0005433985765	25944	Economy	12100.00
0005433985779	25944	Economy	12100.00
0005433985763	25944	Economy	12100.00
0005433960657	25944	Economy	12100.00
0005433985766	25944	Economy	12100.00
0005433960641	25944	Economy	12100.00
0005433985744	25944	Economy	12100.00
0005433985742	25944	Economy	12100.00
0005433985747	25944	Economy	12100.00
0005433985772	25944	Economy	12100.00
0005433960669	25944	Economy	12100.00
0005433985771	25944	Economy	12100.00
0005433960666	25944	Economy	12100.00
0005433985750	25944	Economy	12100.00
0005433985776	25944	Economy	12100.00
0005433985753	25944	Economy	12100.00
0005433960645	25944	Economy	12100.00
0005433985739	25944	Economy	12100.00
0005433960670	25944	Economy	12100.00
0005433985759	25944	Economy	12100.00
0005433960647	25944	Economy	12100.00
0005433960654	25944	Economy	12100.00
0005433985767	25944	Economy	12100.00
0005433960639	25944	Economy	12100.00
0005433985782	25944	Economy	12100.00
0005433960665	25944	Economy	13400.00
0005433960658	25944	Economy	13400.00
0005433960664	25944	Economy	12100.00
0005433985746	25944	Economy	12100.00
0005433960660	25944	Economy	12100.00
0005433985777	25944	Economy	12100.00
0005433960632	25944	Economy	12100.00
0005433985756	25944	Economy	12100.00
0005433985781	25944	Economy	12100.00
0005433985788	25944	Economy	12100.00
0005433985751	25944	Economy	12100.00
0005433985762	25944	Economy	12100.00
0005433960633	25944	Economy	12100.00
0005433960650	25944	Economy	12100.00
0005433960668	25944	Economy	12100.00
0005433985757	25944	Economy	12100.00
0005433985764	25944	Economy	12100.00
0005433985783	25944	Economy	12100.00
0005433985786	25944	Economy	12100.00
0005433960634	25944	Economy	12100.00
0005433985740	25944	Economy	12100.00
0005433960673	25944	Economy	12100.00
0005433960659	25944	Economy	12100.00
0005433960646	25944	Economy	12100.00
0005433960667	25944	Economy	12100.00
0005433960637	25944	Economy	12100.00
0005433960638	25944	Economy	12100.00
0005433985774	25944	Economy	12100.00
0005433960648	25944	Economy	12100.00
0005433960662	25944	Economy	12100.00
0005433960671	25944	Economy	12100.00
0005433960631	25944	Economy	12100.00
0005433985768	25944	Economy	12100.00
0005433985758	25944	Economy	12100.00
0005433960629	25944	Economy	12100.00
0005433985784	25944	Economy	12100.00
0005433985773	25944	Economy	12100.00
0005433960640	25944	Economy	12100.00
0005433960661	25944	Economy	12100.00
0005433960649	25944	Economy	12100.00
0005433985789	25944	Economy	12100.00
0005433985741	25944	Economy	12100.00
0005432269485	966	Economy	25400.00
0005434480238	966	Economy	25400.00
0005434480256	966	Economy	25400.00
0005434480246	966	Economy	25400.00
0005434480248	966	Economy	23100.00
0005434480244	966	Economy	23100.00
0005433165746	966	Economy	23100.00
0005434480252	966	Economy	23100.00
0005434480242	966	Economy	23100.00
0005432269486	966	Economy	23100.00
0005434480247	966	Economy	23100.00
0005434480258	966	Economy	23100.00
0005434480254	966	Economy	23100.00
0005434480253	966	Economy	23100.00
0005434480237	966	Economy	23100.00
0005434480250	966	Economy	23100.00
0005433165750	966	Economy	23100.00
0005434480241	966	Economy	23100.00
0005433165738	966	Economy	23100.00
0005433165704	966	Economy	23100.00
0005434480257	966	Economy	23100.00
0005434480239	966	Economy	23100.00
0005433165744	966	Economy	23100.00
0005434480251	966	Economy	23100.00
0005433165751	966	Economy	23100.00
0005433165756	966	Economy	23100.00
0005433165774	966	Economy	23100.00
0005433165737	966	Economy	23100.00
0005434480249	966	Economy	23100.00
0005434480261	966	Economy	23100.00
0005432269487	966	Economy	23100.00
0005434480243	966	Economy	23100.00
0005433165743	966	Economy	23100.00
0005434480240	966	Economy	23100.00
0005434480255	966	Economy	23100.00
0005433165755	966	Economy	23100.00
0005434480245	966	Economy	23100.00
0005433165745	966	Economy	23100.00
0005433165775	966	Economy	23100.00
0005434480259	966	Economy	23100.00
0005434480262	966	Economy	23100.00
0005434480260	966	Economy	23100.00
0005433165793	966	Economy	23100.00
0005433165815	966	Economy	23100.00
0005434479949	16554	Economy	25400.00
0005434479959	16554	Economy	25400.00
0005433165864	16554	Economy	25400.00
0005433165862	16554	Economy	23100.00
0005434479962	16554	Economy	23100.00
0005434479993	16554	Economy	23100.00
0005433165869	16554	Economy	23100.00
0005434480065	16554	Economy	23100.00
0005433165857	16554	Economy	23100.00
0005433165868	16554	Economy	23100.00
0005434480024	16554	Economy	23100.00
0005433165863	16554	Economy	23100.00
0005433165859	16554	Economy	23100.00
0005434480085	16554	Economy	23100.00
0005434480036	16554	Economy	23100.00
0005434479998	16554	Economy	23100.00
0005434480035	16554	Economy	23100.00
0005434480087	16554	Economy	23100.00
0005434479948	16554	Economy	23100.00
0005434480049	16554	Economy	23100.00
0005434479956	16554	Economy	23100.00
0005433165867	16554	Economy	23100.00
0005434479945	16554	Economy	23100.00
0005434479918	16554	Economy	23100.00
0005434479961	16554	Economy	23100.00
0005434480076	16554	Economy	23100.00
0005433165860	16554	Economy	23100.00
0005434479955	16554	Economy	23100.00
0005433165858	16554	Economy	23100.00
0005434480037	16554	Economy	23100.00
0005434479994	16554	Economy	23100.00
0005434480050	16554	Economy	23100.00
0005433165866	16554	Economy	23100.00
0005434479957	16554	Economy	23100.00
0005433165861	16554	Economy	23100.00
0005433165865	16554	Economy	23100.00
0005433872471	3217	Economy	17200.00
0005433872472	3217	Economy	17200.00
0005433872473	3217	Economy	17200.00
0005433872467	3217	Economy	17200.00
0005433872475	3217	Economy	17200.00
0005433872474	3217	Economy	17200.00
0005433872477	3217	Economy	17200.00
0005433872468	3217	Economy	17200.00
0005433872476	3217	Economy	17200.00
0005433872469	3217	Economy	17200.00
0005433872470	3217	Economy	17200.00
0005433872455	32539	Economy	19000.00
0005433872454	32539	Economy	19000.00
0005433872437	32539	Economy	17200.00
0005433872440	32539	Economy	17200.00
0005433872433	32539	Economy	17200.00
0005433872443	32539	Economy	17200.00
0005433872436	32539	Economy	17200.00
0005433872429	32539	Economy	17200.00
0005433872448	32539	Economy	17200.00
0005433872432	32539	Economy	17200.00
0005433872441	32539	Economy	17200.00
0005433872449	32539	Economy	17200.00
0005435142522	10345	Economy	17000.00
0005433289774	10345	Economy	17000.00
0005435149966	10345	Economy	17000.00
0005435149975	10345	Economy	17000.00
0005435386486	10345	Economy	15400.00
0005435149976	10345	Economy	15400.00
0005433289775	10345	Economy	15400.00
0005435142524	10345	Economy	15400.00
0005435142518	10345	Economy	15400.00
0005435149967	10345	Economy	15400.00
0005435149968	10345	Economy	15400.00
0005435142520	10345	Economy	15400.00
0005435142517	10345	Economy	15400.00
0005435386458	10345	Economy	15400.00
0005435386515	10345	Economy	15400.00
0005433289745	10345	Economy	15400.00
0005435149964	10345	Economy	15400.00
0005435386472	10345	Economy	15400.00
0005433289758	10345	Economy	15400.00
0005435386514	10345	Economy	15400.00
0005435142523	10345	Economy	15400.00
0005435386459	10345	Economy	15400.00
0005435142516	10345	Economy	15400.00
0005435149974	10345	Economy	15400.00
0005435386513	10345	Economy	15400.00
0005433289757	10345	Economy	15400.00
0005435149971	10345	Economy	15400.00
0005435149977	10345	Economy	15400.00
0005435386484	10345	Economy	15400.00
0005435149965	10345	Economy	15400.00
0005435142519	10345	Economy	15400.00
0005435386493	10345	Economy	15400.00
0005435149978	10345	Economy	15400.00
0005435386475	10345	Economy	15400.00
0005433289746	10345	Economy	15400.00
0005435149972	10345	Economy	15400.00
0005435142521	10345	Economy	15400.00
0005435142529	10345	Economy	15400.00
0005435142525	10345	Economy	15400.00
0005435142515	10345	Economy	15400.00
0005435142527	10345	Economy	15400.00
0005433289750	10345	Economy	15400.00
0005435149969	10345	Economy	15400.00
0005435386474	10345	Economy	15400.00
0005435386492	10345	Economy	15400.00
0005435142526	10345	Economy	15400.00
0005435149973	10345	Economy	15400.00
0005435149970	10345	Economy	15400.00
0005435386460	10345	Economy	15400.00
0005435142528	10345	Economy	15400.00
0005435142398	21939	Economy	17000.00
0005435149868	21939	Economy	17000.00
0005433289830	21939	Economy	17000.00
0005435386554	21939	Economy	17000.00
0005435149869	21939	Economy	15400.00
0005435386560	21939	Economy	15400.00
0005433289834	21939	Economy	15400.00
0005435142376	21939	Economy	15400.00
0005435149812	21939	Economy	15400.00
0005435386557	21939	Economy	15400.00
0005435386558	21939	Economy	15400.00
0005435142395	21939	Economy	15400.00
0005433289828	21939	Economy	15400.00
0005435142456	21939	Economy	15400.00
0005435386561	21939	Economy	15400.00
0005435142396	21939	Economy	15400.00
0005435386559	21939	Economy	15400.00
0005435149873	21939	Economy	15400.00
0005435142349	21939	Economy	15400.00
0005435142423	21939	Economy	15400.00
0005435142434	21939	Economy	15400.00
0005435149811	21939	Economy	15400.00
0005435142451	21939	Economy	15400.00
0005435149786	21939	Economy	15400.00
0005435142424	21939	Economy	15400.00
0005435142391	21939	Economy	15400.00
0005435142419	21939	Economy	15400.00
0005435142390	21939	Economy	15400.00
0005433289833	21939	Economy	15400.00
0005435386555	21939	Economy	15400.00
0005435142370	21939	Economy	15400.00
0005435149900	21939	Economy	15400.00
0005435142350	21939	Economy	15400.00
0005435386556	21939	Economy	15400.00
0005435142418	21939	Economy	15400.00
0005433289829	21939	Economy	15400.00
0005435149785	21939	Economy	15400.00
0005433289831	21939	Economy	15400.00
0005435149882	21939	Economy	15400.00
0005433289832	21939	Economy	15400.00
0005435142383	21939	Economy	15400.00
0005435142371	21939	Economy	15400.00
0005435149855	21939	Economy	15400.00
0005435142375	21939	Economy	15400.00
0005435142382	21939	Economy	15400.00
0005434573291	11191	Business	57200.00
0005435502044	11191	Business	57200.00
0005435545637	11191	Business	57200.00
0005435529032	11191	Business	57200.00
0005435529030	11191	Business	57200.00
0005434573293	11191	Business	57200.00
0005435502139	11191	Business	57200.00
0005435319493	11191	Business	57200.00
0005435502097	11191	Business	57200.00
0005434573299	11191	Business	57200.00
0005434573294	11191	Economy	19100.00
0005435502027	11191	Economy	19100.00
0005435502120	11191	Economy	21000.00
0005435502074	11191	Economy	21000.00
0005435528940	11191	Economy	21000.00
0005435545633	11191	Economy	19100.00
0005435501944	11191	Economy	19100.00
0005435319491	11191	Economy	19100.00
0005435529079	11191	Economy	19100.00
0005434573300	11191	Economy	19100.00
0005435502075	11191	Economy	19100.00
0005435529005	11191	Economy	19100.00
0005435502061	11191	Economy	19100.00
0005435528907	11191	Economy	19100.00
0005435319426	11191	Economy	19100.00
0005435529033	11191	Economy	19100.00
0005435502005	11191	Economy	19100.00
0005435529003	11191	Economy	19100.00
0005435529021	11191	Economy	19100.00
0005435502138	11191	Economy	19100.00
0005435528895	11191	Economy	19100.00
0005435319473	11191	Economy	19100.00
0005435529020	11191	Economy	19100.00
0005435319472	11191	Economy	19100.00
0005434573289	11191	Economy	19100.00
0005435502079	11191	Economy	19100.00
0005435319451	11191	Economy	19100.00
0005435502026	11191	Economy	19100.00
0005435502022	11191	Economy	19100.00
0005434573295	11191	Economy	19100.00
0005435529078	11191	Economy	19100.00
0005435502025	11191	Economy	19100.00
0005435502043	11191	Economy	19100.00
0005435502085	11191	Economy	19100.00
0005434573298	11191	Economy	19100.00
0005435502137	11191	Economy	19100.00
0005435502051	11191	Economy	19100.00
0005434573303	11191	Economy	19100.00
0005435502045	11191	Economy	19100.00
0005435545627	11191	Economy	19100.00
0005434573302	11191	Economy	19100.00
0005435529004	11191	Economy	19100.00
0005435545626	11191	Economy	19100.00
0005434573296	11191	Economy	19100.00
0005435528901	11191	Economy	19100.00
0005435545636	11191	Economy	19100.00
0005435502096	11191	Economy	19100.00
0005435319492	11191	Economy	19100.00
0005435319452	11191	Economy	19100.00
0005435502042	11191	Economy	19100.00
0005434573292	11191	Economy	19100.00
0005434573290	11191	Economy	19100.00
0005434573301	11191	Economy	19100.00
0005435502006	11191	Economy	19100.00
0005435502050	11191	Economy	19100.00
0005435529027	11191	Economy	19100.00
0005435502024	11191	Economy	19100.00
0005435502121	11191	Economy	19100.00
0005434573297	11191	Economy	19100.00
0005435502221	20957	Business	57200.00
0005435517851	20957	Business	57200.00
0005434573216	20957	Business	57200.00
0005434573131	20957	Business	57200.00
0005435508311	20957	Business	57200.00
0005435502224	20957	Business	57200.00
0005434573230	20957	Business	57200.00
0005434573190	20957	Business	57200.00
0005435517849	20957	Business	57200.00
0005434573231	20957	Business	57200.00
0005435502236	20957	Business	57200.00
0005435508314	20957	Economy	19100.00
0005435508319	20957	Economy	19100.00
0005435508312	20957	Economy	19100.00
0005434573188	20957	Economy	19100.00
0005435508310	20957	Economy	19100.00
0005435502233	20957	Economy	19100.00
0005435517847	20957	Economy	19100.00
0005435517843	20957	Economy	19100.00
0005435517838	20957	Economy	19100.00
0005435508309	20957	Economy	19100.00
0005435517848	20957	Economy	21000.00
0005435502241	20957	Economy	21000.00
0005434573176	20957	Economy	21000.00
0005435502220	20957	Economy	21000.00
0005435502228	20957	Economy	21000.00
0005434573132	20957	Economy	19100.00
0005434573179	20957	Economy	19100.00
0005434573144	20957	Economy	19100.00
0005435502239	20957	Economy	19100.00
0005435502232	20957	Economy	19100.00
0005435502225	20957	Economy	19100.00
0005435502235	20957	Economy	19100.00
0005435508322	20957	Economy	19100.00
0005435508313	20957	Economy	19100.00
0005435502229	20957	Economy	19100.00
0005435502237	20957	Economy	19100.00
0005434573162	20957	Economy	19100.00
0005435319551	20957	Economy	19100.00
0005434573177	20957	Economy	19100.00
0005435502242	20957	Economy	19100.00
0005432291921	20957	Economy	19100.00
0005435319555	20957	Economy	19100.00
0005435502231	20957	Economy	19100.00
0005435502234	20957	Economy	19100.00
0005435517850	20957	Economy	19100.00
0005435517842	20957	Economy	19100.00
0005435517844	20957	Economy	19100.00
0005434573207	20957	Economy	19100.00
0005435319557	20957	Economy	19100.00
0005435502226	20957	Economy	19100.00
0005435517837	20957	Economy	19100.00
0005435502223	20957	Economy	19100.00
0005435508321	20957	Economy	19100.00
0005435517839	20957	Economy	19100.00
0005435502227	20957	Economy	19100.00
0005435502240	20957	Economy	19100.00
0005435502238	20957	Economy	19100.00
0005435508315	20957	Economy	19100.00
0005434573186	20957	Economy	19100.00
0005435319556	20957	Economy	19100.00
0005435319554	20957	Economy	19100.00
0005435517840	20957	Economy	19100.00
0005435502222	20957	Economy	19100.00
0005435508316	20957	Economy	19100.00
0005434573192	20957	Economy	19100.00
0005435517841	20957	Economy	19100.00
0005435502230	20957	Economy	19100.00
0005435319553	20957	Economy	19100.00
0005435508317	20957	Economy	19100.00
0005434573189	20957	Economy	19100.00
0005434573197	20957	Economy	19100.00
0005435502219	20957	Economy	19100.00
0005435508318	20957	Economy	19100.00
0005435319558	20957	Economy	19100.00
0005434573191	20957	Economy	19100.00
0005435319552	20957	Economy	19100.00
0005435517846	20957	Economy	19100.00
0005435517845	20957	Economy	19100.00
0005434573178	20957	Economy	19100.00
0005435319550	20957	Economy	19100.00
0005435508320	20957	Economy	19100.00
0005433683330	24313	Economy	17100.00
0005433927399	24313	Economy	17100.00
0005433927416	24313	Economy	17100.00
0005433683320	24313	Economy	17100.00
0005433927405	24313	Economy	17100.00
0005433927404	24313	Economy	17100.00
0005433927410	24313	Economy	17100.00
0005433683325	24313	Economy	17100.00
0005433927398	24313	Economy	17100.00
0005433683324	24313	Economy	17100.00
0005433683329	24313	Economy	17100.00
0005433683326	24313	Economy	17100.00
0005433683331	24313	Economy	17100.00
0005433683328	24313	Economy	17100.00
0005433927402	24313	Economy	17100.00
0005433683327	24313	Economy	17100.00
0005433683323	24313	Economy	17100.00
0005433683321	24313	Economy	17100.00
0005433683322	24313	Economy	17100.00
0005433683294	29276	Economy	17100.00
0005433683295	29276	Economy	17100.00
0005433927432	29276	Economy	17100.00
0005433927425	29276	Economy	17100.00
0005433683315	29276	Economy	17100.00
0005433683305	29276	Economy	17100.00
0005433683311	29276	Economy	17100.00
0005433683306	29276	Economy	17100.00
0005433927426	29276	Economy	17100.00
0005433927429	29276	Economy	17100.00
0005433927433	29276	Economy	17100.00
0005433683309	29276	Economy	17100.00
0005433927427	29276	Economy	17100.00
0005433927431	29276	Economy	17100.00
0005433683310	29276	Economy	17100.00
0005433683302	29276	Economy	17100.00
0005433683308	29276	Economy	17100.00
0005433927430	29276	Economy	17100.00
0005433927428	29276	Economy	17100.00
0005433683297	29276	Economy	17100.00
0005433927434	29276	Economy	17100.00
0005433683296	29276	Economy	17100.00
0005432692756	3059	Business	10300.00
0005432692698	3059	Business	10300.00
0005432692577	3059	Business	10300.00
0005432692605	3059	Business	10300.00
0005432692684	3059	Business	10300.00
0005432692777	3059	Business	10300.00
0005432692661	3059	Business	10300.00
0005432692862	3059	Business	10300.00
0005432692662	3059	Economy	3400.00
0005432692585	3059	Economy	3400.00
0005432692576	3059	Economy	3400.00
0005432692685	3059	Economy	3800.00
0005432692640	3059	Economy	3800.00
0005432692607	3059	Economy	3800.00
0005432692753	3059	Economy	3400.00
0005432692612	3059	Economy	3400.00
0005432692665	3059	Economy	3400.00
0005432692724	3059	Economy	3400.00
0005432692586	3059	Economy	3400.00
0005432692775	3059	Economy	3400.00
0005432692752	3059	Economy	3400.00
0005432692680	3059	Economy	3400.00
0005432692601	3059	Economy	3400.00
0005432692584	3059	Economy	3400.00
0005432692681	3059	Economy	3400.00
0005432692738	3059	Economy	3400.00
0005432692716	3059	Economy	3400.00
0005432692606	3059	Economy	3400.00
0005432692651	3059	Economy	3400.00
0005432692686	3059	Economy	3400.00
0005432692739	3059	Economy	3400.00
0005432692659	3059	Economy	3400.00
0005432692660	3059	Economy	3400.00
0005432692863	3059	Economy	3400.00
0005432692751	3059	Economy	3400.00
0005432692714	3059	Economy	3400.00
0005432692583	3059	Economy	3400.00
0005432692613	3059	Economy	3400.00
0005432692743	3059	Economy	3400.00
0005432692778	3059	Economy	3400.00
0005432692744	3059	Economy	3400.00
0005432217768	3058	Business	10300.00
0005433123588	3058	Business	10300.00
0005432706683	3058	Business	10300.00
0005433123707	3058	Business	10300.00
0005432706692	3058	Business	10300.00
0005432706696	3058	Business	10300.00
0005432880593	3058	Business	10300.00
0005432880605	3058	Business	10300.00
0005432706694	3058	Economy	3400.00
0005433194826	3058	Economy	3400.00
0005432706684	3058	Economy	3400.00
0005432706698	3058	Economy	3400.00
0005432706697	3058	Economy	3400.00
0005432217766	3058	Economy	3400.00
0005432706682	3058	Economy	3800.00
0005432880607	3058	Economy	3800.00
0005432880618	3058	Economy	3800.00
0005432217767	3058	Economy	3800.00
0005432880630	3058	Economy	3400.00
0005433123695	3058	Economy	3400.00
0005432706675	3058	Economy	3400.00
0005433123636	3058	Economy	3400.00
0005432880655	3058	Economy	3400.00
0005432706677	3058	Economy	3400.00
0005432706687	3058	Economy	3400.00
0005432880604	3058	Economy	3400.00
0005432706690	3058	Economy	3400.00
0005432706695	3058	Economy	3400.00
0005433123670	3058	Economy	3400.00
0005433123653	3058	Economy	3400.00
0005432880654	3058	Economy	3400.00
0005432880651	3058	Economy	3400.00
0005433123706	3058	Economy	3400.00
0005432706680	3058	Economy	3400.00
0005432706686	3058	Economy	3400.00
0005432706679	3058	Economy	3400.00
0005432706681	3058	Economy	3400.00
0005432706693	3058	Economy	3400.00
0005432706689	3058	Economy	3400.00
0005432706685	3058	Economy	3400.00
0005433123671	3058	Economy	3400.00
0005432880647	3058	Economy	3400.00
0005433123654	3058	Economy	3400.00
0005432880619	3058	Economy	3400.00
0005433194835	3058	Economy	3400.00
0005433123696	3058	Economy	3400.00
0005433123724	3058	Economy	3400.00
0005432706691	3058	Economy	3400.00
0005432880699	3058	Economy	3400.00
0005433123693	3058	Economy	3400.00
0005433123725	3058	Economy	3400.00
0005433123767	3058	Economy	3400.00
0005433123697	3058	Economy	3400.00
0005432880631	3058	Economy	3400.00
0005433123698	3058	Economy	3400.00
0005432880632	3058	Economy	3400.00
0005432880700	3058	Economy	3400.00
0005433123683	3058	Economy	3400.00
0005432880653	3058	Economy	3400.00
0005432706699	3058	Economy	3400.00
0005433123661	3058	Economy	3400.00
0005432706688	3058	Economy	3400.00
0005432706678	3058	Economy	3400.00
0005432706676	3058	Economy	3400.00
0005432706515	29914	Business	10300.00
0005433123854	29914	Business	10300.00
0005433123861	29914	Business	10300.00
0005432706551	29914	Business	10300.00
0005432706514	29914	Business	10300.00
0005432706438	29914	Business	10300.00
0005433123851	29914	Business	10300.00
0005432692989	29914	Business	10300.00
0005433123844	29914	Business	10300.00
0005433123846	29914	Business	10300.00
0005432706513	29914	Business	10300.00
0005432692975	29914	Business	10300.00
0005432692993	29914	Economy	3400.00
0005433123855	29914	Economy	3400.00
0005433123860	29914	Economy	3400.00
0005432706516	29914	Economy	3400.00
0005432692998	29914	Economy	3400.00
0005432880775	29914	Economy	3400.00
0005433123850	29914	Economy	3400.00
0005432880767	29914	Economy	3400.00
0005432706411	29914	Economy	3400.00
0005432706416	29914	Economy	3400.00
0005432692988	29914	Economy	3800.00
0005432692986	29914	Economy	3800.00
0005432880761	29914	Economy	3800.00
0005433123862	29914	Economy	3800.00
0005432692990	29914	Economy	3800.00
0005433123845	29914	Economy	3400.00
0005432706370	29914	Economy	3400.00
0005432692970	29914	Economy	3400.00
0005432692978	29914	Economy	3400.00
0005432880769	29914	Economy	3400.00
0005432693000	29914	Economy	3400.00
0005433123859	29914	Economy	3400.00
0005433123848	29914	Economy	3400.00
0005432692995	29914	Economy	3400.00
0005432880771	29914	Economy	3400.00
0005432706391	29914	Economy	3400.00
0005432706428	29914	Economy	3400.00
0005432692994	29914	Economy	3400.00
0005432706405	29914	Economy	3400.00
0005432706504	29914	Economy	3400.00
0005432692999	29914	Economy	3400.00
0005432880770	29914	Economy	3400.00
0005432706578	29914	Economy	3400.00
0005432706495	29914	Economy	3400.00
0005433123852	29914	Economy	3400.00
0005432706406	29914	Economy	3400.00
0005432692984	29914	Economy	3400.00
0005432692974	29914	Economy	3400.00
0005432692979	29914	Economy	3400.00
0005432880772	29914	Economy	3400.00
0005432692997	29914	Economy	3400.00
0005432880768	29914	Economy	3400.00
0005432706371	29914	Economy	3400.00
0005432692972	29914	Economy	3400.00
0005432706364	29914	Economy	3400.00
0005432706376	29914	Economy	3400.00
0005433123856	29914	Economy	3400.00
0005432706445	29914	Economy	3400.00
0005432692973	29914	Economy	3400.00
0005432706517	29914	Economy	3400.00
0005432692996	29914	Economy	3400.00
0005432880765	29914	Economy	3400.00
0005433123858	29914	Economy	3400.00
0005432880762	29914	Economy	3400.00
0005433123865	29914	Economy	3400.00
0005432692991	29914	Economy	3400.00
0005433123853	29914	Economy	3400.00
0005433123864	29914	Economy	3400.00
0005432692969	29914	Economy	3400.00
0005432692980	29914	Economy	3400.00
0005432706392	29914	Economy	3400.00
0005433123847	29914	Economy	3400.00
0005432706465	29914	Economy	3400.00
0005433123849	29914	Economy	3400.00
0005433123857	29914	Economy	3400.00
0005432692983	29914	Economy	3400.00
0005432692982	29914	Economy	3400.00
0005432692992	29914	Economy	3400.00
0005432692971	29914	Economy	3400.00
0005432692976	29914	Economy	3400.00
0005432880763	29914	Economy	3400.00
0005432706451	29914	Economy	3400.00
0005432706482	29914	Economy	3400.00
0005432880766	29914	Economy	3400.00
0005432880773	29914	Economy	3400.00
0005432692987	29914	Economy	3400.00
0005432706377	29914	Economy	3400.00
0005432706414	29914	Economy	3400.00
0005432692977	29914	Economy	3400.00
0005433123863	29914	Economy	3400.00
0005432880764	29914	Economy	3400.00
0005432880774	29914	Economy	3400.00
0005432692985	29914	Economy	3400.00
0005432692981	29914	Economy	3400.00
0005432706499	29914	Economy	3400.00
0005434979679	23661	Economy	4000.00
0005434988698	23661	Economy	4000.00
0005434988694	23661	Economy	4000.00
0005434979676	23661	Economy	3600.00
0005434979674	23661	Economy	3600.00
0005434979671	23661	Economy	3600.00
0005434979659	23661	Economy	3600.00
0005434979658	23661	Economy	3600.00
0005434979652	23661	Economy	3600.00
0005434988692	23661	Economy	3600.00
0005434979668	23661	Economy	3600.00
0005434979666	23661	Economy	3600.00
0005434988690	23661	Economy	3600.00
0005434979673	23661	Economy	3600.00
0005434988701	23661	Economy	3600.00
0005434979667	23661	Economy	3600.00
0005434988699	23661	Economy	3600.00
0005434979656	23661	Economy	3600.00
0005434979654	23661	Economy	3600.00
0005434979663	23661	Economy	3600.00
0005434988700	23661	Economy	3600.00
0005434979665	23661	Economy	3600.00
0005434979680	23661	Economy	3600.00
0005434979670	23661	Economy	3600.00
0005434979657	23661	Economy	3600.00
0005434979662	23661	Economy	3600.00
0005434979681	23661	Economy	3600.00
0005434988691	23661	Economy	3600.00
0005434979660	23661	Economy	3600.00
0005434979664	23661	Economy	3600.00
0005434988695	23661	Economy	3600.00
0005434979675	23661	Economy	3600.00
0005434979672	23661	Economy	3600.00
0005434979661	23661	Economy	3600.00
0005434988693	23661	Economy	3600.00
0005434979678	23661	Economy	3600.00
0005434988696	23661	Economy	3600.00
0005434979655	23661	Economy	3600.00
0005434979682	23661	Economy	3600.00
0005434979669	23661	Economy	3600.00
0005434979653	23661	Economy	3600.00
0005434979677	23661	Economy	3600.00
0005434988697	23661	Economy	3600.00
0005434988591	27544	Economy	4000.00
0005434988599	27544	Economy	4000.00
0005434988555	27544	Economy	4000.00
0005434979344	27544	Economy	4000.00
0005434979375	27544	Economy	3600.00
0005434988601	27544	Economy	3600.00
0005434979274	27544	Economy	3600.00
0005434979482	27544	Economy	3600.00
0005434988592	27544	Economy	3600.00
0005434979438	27544	Economy	3600.00
0005434979378	27544	Economy	3600.00
0005434979347	27544	Economy	3600.00
0005434979392	27544	Economy	3600.00
0005434979270	27544	Economy	3600.00
0005434979411	27544	Economy	3600.00
0005434988600	27544	Economy	3600.00
0005434979317	27544	Economy	3600.00
0005434979445	27544	Economy	3600.00
0005434979417	27544	Economy	3600.00
0005434979432	27544	Economy	3600.00
0005434988574	27544	Economy	3600.00
0005434988590	27544	Economy	3600.00
0005434979343	27544	Economy	3600.00
0005434979275	27544	Economy	3600.00
0005434979327	27544	Economy	3600.00
0005434979412	27544	Economy	3600.00
0005434979379	27544	Economy	3600.00
0005434979437	27544	Economy	3600.00
0005434979425	27544	Economy	3600.00
0005434979487	27544	Economy	3600.00
0005434979418	27544	Economy	3600.00
0005434979484	27544	Economy	3600.00
0005434979446	27544	Economy	3600.00
0005434988593	27544	Economy	3600.00
0005434979354	27544	Economy	3600.00
0005434979353	27544	Economy	3600.00
0005434979483	27544	Economy	3600.00
0005434979303	27544	Economy	3600.00
0005434979281	27544	Economy	3600.00
0005434979424	27544	Economy	3600.00
0005434979397	27544	Economy	3600.00
0005434979433	27544	Economy	3600.00
0005434988602	27544	Economy	3600.00
0005434988573	27544	Economy	3600.00
0005434302858	10304	Economy	19700.00
0005434302440	10304	Economy	19700.00
0005434302443	10304	Economy	19700.00
0005434302442	10304	Economy	19700.00
0005434302439	10304	Economy	19700.00
0005434302441	10304	Economy	19700.00
0005433113509	10304	Economy	19700.00
0005433113508	10304	Economy	19700.00
0005433113512	10304	Economy	19700.00
0005434302857	10304	Economy	19700.00
0005433113529	19601	Economy	19700.00
0005434302399	19601	Economy	19700.00
0005434302381	19601	Economy	19700.00
0005434302400	19601	Economy	19700.00
0005434302402	19601	Economy	19700.00
0005434302403	19601	Economy	19700.00
0005435925114	3529	Business	26900.00
0005435068932	3529	Business	26900.00
0005435068945	3529	Business	26900.00
0005435068901	3529	Business	26900.00
0005435068931	3529	Business	26900.00
0005435068924	3529	Business	26900.00
0005435925109	3529	Business	26900.00
0005435068934	3529	Economy	9000.00
0005435068918	3529	Economy	9000.00
0005435068949	3529	Economy	9000.00
0005435068941	3529	Economy	9000.00
0005435068910	3529	Economy	9000.00
0005435068920	3529	Economy	9000.00
0005435925126	3529	Economy	9000.00
0005435068917	3529	Economy	9000.00
0005435068940	3529	Economy	9900.00
0005435068904	3529	Economy	9900.00
0005435068937	3529	Economy	9900.00
0005435068921	3529	Economy	9000.00
0005435939865	3529	Economy	9000.00
0005435068926	3529	Economy	9000.00
0005435068948	3529	Economy	9000.00
0005435068936	3529	Economy	9000.00
0005435068928	3529	Economy	9000.00
0005435068913	3529	Economy	9000.00
0005435068902	3529	Economy	9000.00
0005435068915	3529	Economy	9000.00
0005435068933	3529	Economy	9000.00
0005435068938	3529	Economy	9000.00
0005435068943	3529	Economy	9000.00
0005435925169	3529	Economy	9000.00
0005435068912	3529	Economy	9000.00
0005435068906	3529	Economy	9000.00
0005435925146	3529	Economy	9000.00
0005435068919	3529	Economy	9000.00
0005435068950	3529	Economy	9000.00
0005435068923	3529	Economy	9000.00
0005435939862	3529	Economy	9000.00
0005435068903	3529	Economy	9000.00
0005435925073	3529	Economy	9000.00
0005435068935	3529	Economy	9000.00
0005435068907	3529	Economy	9000.00
0005435068922	3529	Economy	9000.00
0005435068951	3529	Economy	9000.00
0005435068927	3529	Economy	9000.00
0005435068939	3529	Economy	9000.00
0005435068942	3529	Economy	9000.00
0005435068908	3529	Economy	9000.00
0005435068914	3529	Economy	9000.00
0005435068944	3529	Economy	9000.00
0005435068905	3529	Economy	9000.00
0005435068952	3529	Economy	9000.00
0005435925061	3529	Economy	9000.00
0005435068946	3529	Economy	9000.00
0005435068916	3529	Economy	9000.00
0005435068947	3529	Economy	9000.00
0005435068925	3529	Economy	9000.00
0005435925148	3529	Economy	9000.00
0005435925147	3529	Economy	9000.00
0005435925142	3529	Economy	9000.00
0005435925127	3529	Economy	9000.00
0005435068930	3529	Economy	9000.00
0005435068929	3529	Economy	9000.00
0005435068911	3529	Economy	9000.00
0005435068909	3529	Economy	9000.00
0005435925264	15286	Business	26900.00
0005435068441	15286	Business	26900.00
0005435068542	15286	Business	26900.00
0005435068473	15286	Business	26900.00
0005435068455	15286	Business	26900.00
0005435068599	15286	Business	26900.00
0005435068374	15286	Business	26900.00
0005435068401	15286	Business	26900.00
0005435925248	15286	Business	26900.00
0005435068531	15286	Business	26900.00
0005435068609	15286	Economy	9000.00
0005435068228	15286	Economy	9000.00
0005435925267	15286	Economy	9000.00
0005435068480	15286	Economy	9000.00
0005435068373	15286	Economy	9000.00
0005435068359	15286	Economy	9000.00
0005435068232	15286	Economy	9000.00
0005435068340	15286	Economy	9000.00
0005435068214	15286	Economy	9900.00
0005435925261	15286	Economy	9900.00
0005435068420	15286	Economy	9900.00
0005435925262	15286	Economy	9900.00
0005435925250	15286	Economy	9900.00
0005435068421	15286	Economy	9000.00
0005435925245	15286	Economy	9000.00
0005435068369	15286	Economy	9000.00
0005435939876	15286	Economy	9000.00
0005435925259	15286	Economy	9000.00
0005435925252	15286	Economy	9000.00
0005435925244	15286	Economy	9000.00
0005435068610	15286	Economy	9000.00
0005435068474	15286	Economy	9000.00
0005435925263	15286	Economy	9000.00
0005435068292	15286	Economy	9000.00
0005435925258	15286	Economy	9000.00
0005435068487	15286	Economy	9000.00
0005435068408	15286	Economy	9000.00
0005435068183	15286	Economy	9000.00
0005435925249	15286	Economy	9000.00
0005435939875	15286	Economy	9000.00
0005435925256	15286	Economy	9000.00
0005435068430	15286	Economy	9000.00
0005435068216	15286	Economy	9000.00
0005435068456	15286	Economy	9000.00
0005435068541	15286	Economy	9000.00
0005435925266	15286	Economy	9000.00
0005435925255	15286	Economy	9000.00
0005435068684	15286	Economy	9000.00
0005435925246	15286	Economy	9000.00
0005435925265	15286	Economy	9000.00
0005435068472	15286	Economy	9000.00
0005435068492	15286	Economy	9000.00
0005435925251	15286	Economy	9000.00
0005435068233	15286	Economy	9000.00
0005435925268	15286	Economy	9000.00
0005435068370	15286	Economy	9000.00
0005435068351	15286	Economy	9000.00
0005435068683	15286	Economy	9000.00
0005435068422	15286	Economy	9000.00
0005435068229	15286	Economy	9000.00
0005435925257	15286	Economy	9000.00
0005435068341	15286	Economy	9000.00
0005435925247	15286	Economy	9000.00
0005435068558	15286	Economy	9000.00
0005435925260	15286	Economy	9000.00
0005435068284	15286	Economy	9000.00
0005435068518	15286	Economy	9000.00
0005435925254	15286	Economy	9000.00
0005435925253	15286	Economy	9000.00
0005435068419	15286	Economy	9000.00
0005432658583	18142	Economy	5900.00
0005432658584	18142	Economy	5900.00
0005432659699	18142	Economy	5900.00
0005432660811	18142	Economy	5900.00
0005432659700	18142	Economy	5900.00
0005432667423	26384	Economy	5900.00
0005432667424	26384	Economy	5900.00
0005432660784	26384	Economy	5900.00
0005432660785	26384	Economy	5900.00
0005432667425	26384	Economy	5900.00
0005432660792	26384	Economy	5900.00
0005432660791	26384	Economy	5900.00
0005432919598	141	Business	20000.00
0005433101448	141	Business	20000.00
0005432919558	141	Business	20000.00
0005433101579	141	Business	20000.00
0005433101394	141	Business	20000.00
0005432919705	141	Business	20000.00
0005433101337	141	Business	20000.00
0005432391964	141	Business	20000.00
0005432677517	141	Business	20000.00
0005432391945	141	Business	20000.00
0005432919582	141	Business	20000.00
0005432919626	141	Business	20000.00
0005432919636	141	Business	20000.00
0005433101542	141	Business	20000.00
0005433101476	141	Business	20000.00
0005432919580	141	Business	20000.00
0005432919640	141	Business	20000.00
0005432901405	141	Business	20000.00
0005433101493	141	Business	20000.00
0005433101338	141	Business	20000.00
0005432919689	141	Business	20000.00
0005433101424	141	Economy	7300.00
0005433101453	141	Economy	7300.00
0005432391957	141	Economy	7300.00
0005432919680	141	Economy	6700.00
0005432391954	141	Economy	6700.00
0005433101505	141	Economy	6700.00
0005433101213	141	Economy	6700.00
0005432901431	141	Economy	6700.00
0005433101393	141	Economy	6700.00
0005432919604	141	Economy	6700.00
0005432901437	141	Economy	6700.00
0005433101317	141	Economy	6700.00
0005432391955	141	Economy	6700.00
0005432919581	141	Economy	6700.00
0005432919627	141	Economy	6700.00
0005432919612	141	Economy	6700.00
0005433101318	141	Economy	6700.00
0005432901383	141	Economy	6700.00
0005433101432	141	Economy	6700.00
0005433101508	141	Economy	6700.00
0005432919639	141	Economy	6700.00
0005433101581	141	Economy	6700.00
0005432677527	141	Economy	6700.00
0005433101431	141	Economy	6700.00
0005433101527	141	Economy	6700.00
0005433101462	141	Economy	6700.00
0005433101447	141	Economy	6700.00
0005432391948	141	Economy	6700.00
0005432677526	141	Economy	6700.00
0005433101495	141	Economy	6700.00
0005433101586	141	Economy	6700.00
0005432391952	141	Economy	6700.00
0005432901411	141	Economy	6700.00
0005432677542	141	Economy	6700.00
0005432919611	141	Economy	6700.00
0005432901382	141	Economy	6700.00
0005433101572	141	Economy	6700.00
0005432901439	141	Economy	6700.00
0005433101366	141	Economy	6700.00
0005432919560	141	Economy	6700.00
0005432919610	141	Economy	6700.00
0005432901390	141	Economy	6700.00
0005432919579	141	Economy	7300.00
0005432391949	141	Economy	7300.00
0005433101463	141	Economy	6700.00
0005433101502	141	Economy	7300.00
0005433101450	141	Economy	6700.00
0005433101541	141	Economy	7300.00
0005432919679	141	Economy	6700.00
0005432391953	141	Economy	6700.00
0005432901438	141	Economy	6700.00
0005433101543	141	Economy	6700.00
0005432677543	141	Economy	6700.00
0005432919635	141	Economy	6700.00
0005433101293	141	Economy	6700.00
0005433101461	141	Economy	6700.00
0005432901432	141	Economy	6700.00
0005433101566	141	Economy	6700.00
0005433101378	141	Economy	6700.00
0005432919660	141	Economy	6700.00
0005433101411	141	Economy	6700.00
0005432391958	141	Economy	6700.00
0005432391962	141	Economy	6700.00
0005433101486	141	Economy	6700.00
0005432919678	141	Economy	6700.00
0005432919599	141	Economy	6700.00
0005433101286	141	Economy	6700.00
0005432919559	141	Economy	6700.00
0005432919575	141	Economy	6700.00
0005432919685	141	Economy	6700.00
0005433101544	141	Economy	6700.00
0005432919681	141	Economy	6700.00
0005433101507	141	Economy	6700.00
0005433101429	141	Economy	6700.00
0005433101449	141	Economy	6700.00
0005433101451	141	Economy	6700.00
0005432391961	141	Economy	6700.00
0005432901365	141	Economy	6700.00
0005433101478	141	Economy	6700.00
0005433101567	141	Economy	6700.00
0005432157486	141	Economy	6700.00
0005432901421	141	Economy	6700.00
0005433101506	141	Economy	6700.00
0005433101580	141	Economy	6700.00
0005433101392	141	Economy	6700.00
0005433101323	141	Economy	6700.00
0005432919634	141	Economy	6700.00
0005432391963	141	Economy	6700.00
0005433101364	141	Economy	6700.00
0005432919597	141	Economy	6700.00
0005432919718	141	Economy	6700.00
0005433101549	141	Economy	6700.00
0005432817376	142	Business	20000.00
0005432817385	142	Business	20000.00
0005432261756	142	Business	20000.00
0005432261770	142	Business	20000.00
0005432817382	142	Business	20000.00
0005432261760	142	Business	20000.00
0005432817368	142	Business	20000.00
0005432261774	142	Business	20000.00
0005432261753	142	Business	20000.00
0005432817369	142	Business	20000.00
0005432261769	142	Business	20000.00
0005432756809	142	Economy	7300.00
0005432261766	142	Economy	7300.00
0005432261754	142	Economy	7300.00
0005432261768	142	Economy	7300.00
0005432753261	142	Economy	6700.00
0005432261785	142	Economy	6700.00
0005432288975	142	Economy	6700.00
0005432261762	142	Economy	6700.00
0005432261750	142	Economy	6700.00
0005432261773	142	Economy	6700.00
0005432261749	142	Economy	6700.00
0005432817389	142	Economy	6700.00
0005432817363	142	Economy	6700.00
0005432261761	142	Economy	6700.00
0005432261751	142	Economy	6700.00
0005432817379	142	Economy	6700.00
0005432817374	142	Economy	6700.00
0005432817364	142	Economy	6700.00
0005432753256	142	Economy	6700.00
0005432817393	142	Economy	6700.00
0005432261744	142	Economy	6700.00
0005432817392	142	Economy	6700.00
0005433687686	142	Economy	6700.00
0005432207652	142	Economy	6700.00
0005432261755	142	Economy	6700.00
0005433690905	142	Economy	6700.00
0005432261765	142	Economy	6700.00
0005432817386	142	Economy	6700.00
0005432261775	142	Economy	6700.00
0005432753250	142	Economy	6700.00
0005432261777	142	Economy	6700.00
0005432817372	142	Economy	6700.00
0005432817378	142	Economy	6700.00
0005432817381	142	Economy	6700.00
0005432261776	142	Economy	6700.00
0005432817373	142	Economy	6700.00
0005432817387	142	Economy	6700.00
0005432261763	142	Economy	6700.00
0005432756805	142	Economy	6700.00
0005432817380	142	Economy	6700.00
0005432817377	142	Economy	6700.00
0005432756806	142	Economy	7300.00
0005432261780	142	Economy	7300.00
0005432817388	142	Economy	6700.00
0005432207653	142	Economy	6700.00
0005432817383	142	Economy	6700.00
0005432261782	142	Economy	6700.00
0005432261772	142	Economy	6700.00
0005432261771	142	Economy	6700.00
0005432817391	142	Economy	6700.00
0005432288977	142	Economy	6700.00
0005432261788	142	Economy	6700.00
0005432288978	142	Economy	6700.00
0005432261767	142	Economy	6700.00
0005432261784	142	Economy	6700.00
0005432817365	142	Economy	6700.00
0005432261752	142	Economy	6700.00
0005432261758	142	Economy	6700.00
0005432261783	142	Economy	6700.00
0005432817375	142	Economy	6700.00
0005432817384	142	Economy	6700.00
0005432261779	142	Economy	6700.00
0005432817366	142	Economy	6700.00
0005432288974	142	Economy	6700.00
0005433687687	142	Economy	6700.00
0005432261789	142	Economy	6700.00
0005432261781	142	Economy	6700.00
0005432261748	142	Economy	6700.00
0005433690902	142	Economy	6700.00
0005432288976	142	Economy	6700.00
0005432261747	142	Economy	6700.00
0005432753257	142	Economy	6700.00
0005432817390	142	Economy	6700.00
0005432817367	142	Economy	6700.00
0005432817371	142	Economy	6700.00
0005432261787	142	Economy	6700.00
0005432261743	142	Economy	6700.00
0005432261746	142	Economy	6700.00
0005433690901	142	Economy	6700.00
0005432261786	142	Economy	6700.00
0005432261745	142	Economy	6700.00
0005432817370	142	Economy	6700.00
0005432261764	142	Economy	6700.00
0005432261759	142	Economy	6700.00
0005432261757	142	Economy	6700.00
0005432261778	142	Economy	6700.00
0005433101993	7935	Business	20000.00
0005432919781	7935	Business	20000.00
0005432753290	7935	Business	20000.00
0005432020181	7935	Business	20000.00
0005432919788	7935	Business	20000.00
0005433102014	7935	Business	20000.00
0005433102007	7935	Business	20000.00
0005432751517	7935	Business	20000.00
0005433101968	7935	Business	20000.00
0005433101991	7935	Business	20000.00
0005433101985	7935	Business	20000.00
0005432045609	7935	Business	20000.00
0005433101967	7935	Business	20000.00
0005432919785	7935	Business	20000.00
0005432044517	7935	Business	20000.00
0005433101966	7935	Business	20000.00
0005432020172	7935	Business	20000.00
0005432020180	7935	Business	20000.00
0005432020184	7935	Business	20000.00
0005432919800	7935	Business	20000.00
0005432919794	7935	Economy	7300.00
0005432919782	7935	Economy	7300.00
0005433101978	7935	Economy	7300.00
0005433102003	7935	Economy	7300.00
0005433101988	7935	Economy	6700.00
0005432919784	7935	Economy	6700.00
0005433102002	7935	Economy	6700.00
0005432919795	7935	Economy	6700.00
0005433101986	7935	Economy	6700.00
0005433102009	7935	Economy	6700.00
0005432020178	7935	Economy	6700.00
0005433101999	7935	Economy	6700.00
0005432020174	7935	Economy	6700.00
0005432020179	7935	Economy	6700.00
0005432391989	7935	Economy	6700.00
0005432020177	7935	Economy	6700.00
0005432919790	7935	Economy	6700.00
0005433101973	7935	Economy	6700.00
0005433101976	7935	Economy	6700.00
0005432020170	7935	Economy	6700.00
0005432919797	7935	Economy	6700.00
0005432919796	7935	Economy	6700.00
0005432919793	7935	Economy	6700.00
0005433101977	7935	Economy	6700.00
0005433102013	7935	Economy	6700.00
0005432020173	7935	Economy	6700.00
0005432020186	7935	Economy	6700.00
0005432751515	7935	Economy	6700.00
0005432020176	7935	Economy	6700.00
0005432020175	7935	Economy	6700.00
0005432020167	7935	Economy	6700.00
0005432020189	7935	Economy	6700.00
0005432919792	7935	Economy	6700.00
0005433101969	7935	Economy	6700.00
0005432020164	7935	Economy	6700.00
0005432020169	7935	Economy	6700.00
0005432020163	7935	Economy	6700.00
0005432919787	7935	Economy	6700.00
0005432677560	7935	Economy	6700.00
0005433101981	7935	Economy	6700.00
0005432919789	7935	Economy	6700.00
0005433101997	7935	Economy	6700.00
0005432020168	7935	Economy	6700.00
0005433101998	7935	Economy	6700.00
0005433101992	7935	Economy	6700.00
0005433102015	7935	Economy	6700.00
0005433101974	7935	Economy	6700.00
0005432677563	7935	Economy	7300.00
0005432919791	7935	Economy	7300.00
0005433101983	7935	Economy	6700.00
0005432753291	7935	Economy	6700.00
0005432919798	7935	Economy	6700.00
0005433101970	7935	Economy	6700.00
0005433102001	7935	Economy	6700.00
0005432919801	7935	Economy	6700.00
0005433101980	7935	Economy	6700.00
0005433101995	7935	Economy	6700.00
0005432020166	7935	Economy	6700.00
0005433101990	7935	Economy	6700.00
0005432919783	7935	Economy	6700.00
0005432919786	7935	Economy	6700.00
0005433102011	7935	Economy	6700.00
0005432753292	7935	Economy	6700.00
0005433101994	7935	Economy	6700.00
0005433101984	7935	Economy	6700.00
0005432020171	7935	Economy	6700.00
0005433102000	7935	Economy	6700.00
0005432020165	7935	Economy	6700.00
0005433101979	7935	Economy	6700.00
0005432677562	7935	Economy	6700.00
0005433101971	7935	Economy	6700.00
0005433101996	7935	Economy	6700.00
0005432044515	7935	Economy	6700.00
0005433101972	7935	Economy	6700.00
0005433101975	7935	Economy	6700.00
0005433101965	7935	Economy	6700.00
0005432020185	7935	Economy	6700.00
0005433102006	7935	Economy	6700.00
0005433102010	7935	Economy	6700.00
0005433101987	7935	Economy	6700.00
0005433101989	7935	Economy	6700.00
0005432391991	7935	Economy	6700.00
0005432919799	7935	Economy	6700.00
0005432020188	7935	Economy	6700.00
0005432391990	7935	Economy	6700.00
0005432044516	7935	Economy	6700.00
0005433102005	7935	Economy	6700.00
0005433101982	7935	Economy	6700.00
0005433102012	7935	Economy	6700.00
0005432020182	7935	Economy	6700.00
0005433102004	7935	Economy	6700.00
0005432677561	7935	Economy	6700.00
0005432020187	7935	Economy	6700.00
0005432045608	7935	Economy	6700.00
0005432020183	7935	Economy	6700.00
0005433102008	7935	Economy	6700.00
0005432751516	7935	Economy	6700.00
0005432817089	7936	Business	20000.00
0005432901551	7936	Business	20000.00
0005432817219	7936	Business	20000.00
0005432817101	7936	Business	20000.00
0005432817110	7936	Business	20000.00
0005432817197	7936	Business	20000.00
0005432817273	7936	Business	20000.00
0005432002069	7936	Business	20000.00
0005432817077	7936	Business	20000.00
0005432901561	7936	Economy	7300.00
0005432901556	7936	Economy	7300.00
0005432817080	7936	Economy	7300.00
0005432817105	7936	Economy	7300.00
0005432817075	7936	Economy	6700.00
0005432901560	7936	Economy	6700.00
0005432901562	7936	Economy	6700.00
0005432817076	7936	Economy	6700.00
0005432817198	7936	Economy	6700.00
0005432817245	7936	Economy	6700.00
0005434513544	7936	Economy	6700.00
0005432901548	7936	Economy	6700.00
0005434513541	7936	Economy	6700.00
0005432817274	7936	Economy	6700.00
0005432901552	7936	Economy	6700.00
0005432817246	7936	Economy	6700.00
0005432817113	7936	Economy	6700.00
0005432817119	7936	Economy	6700.00
0005432901557	7936	Economy	6700.00
0005432817036	7936	Economy	6700.00
0005432901554	7936	Economy	6700.00
0005432817244	7936	Economy	6700.00
0005432817074	7936	Economy	6700.00
0005432817078	7936	Economy	6700.00
0005432817117	7936	Economy	6700.00
0005434513540	7936	Economy	7300.00
0005432002068	7936	Economy	6700.00
0005432901549	7936	Economy	6700.00
0005432901553	7936	Economy	6700.00
0005432901559	7936	Economy	6700.00
0005432002070	7936	Economy	6700.00
0005432901547	7936	Economy	6700.00
0005434513549	7936	Economy	6700.00
0005432901555	7936	Economy	6700.00
0005432901546	7936	Economy	6700.00
0005432817103	7936	Economy	6700.00
0005432901558	7936	Economy	6700.00
0005432817079	7936	Economy	6700.00
0005434513548	7936	Economy	6700.00
0005434513550	7936	Economy	6700.00
0005432817106	7936	Economy	6700.00
0005432901563	7936	Economy	6700.00
0005432817138	7936	Economy	6700.00
0005432817102	7936	Economy	6700.00
0005432901550	7936	Economy	6700.00
0005433870723	9679	Economy	6900.00
0005433870724	9679	Economy	6900.00
0005434175688	9679	Economy	6900.00
0005434175714	9679	Economy	6900.00
0005433870705	32359	Economy	6900.00
0005433870706	32359	Economy	6900.00
0005434175737	32359	Economy	6900.00
0005433870710	32359	Economy	6900.00
0005434175739	32359	Economy	6900.00
0005434175738	32359	Economy	6900.00
0005434175740	32359	Economy	6900.00
0005434175741	32359	Economy	6900.00
0005434938088	3496	Business	35000.00
0005434877951	3496	Business	35000.00
0005434877926	3496	Business	35000.00
0005434877966	3496	Business	35000.00
0005434877954	3496	Business	35000.00
0005432611699	3496	Business	35000.00
0005434426514	3496	Business	35000.00
0005434426506	3496	Business	35000.00
0005435626134	3496	Business	35000.00
0005434877914	3496	Business	35000.00
0005435626132	3496	Business	35000.00
0005435126259	3496	Business	35000.00
0005432183461	3496	Business	35000.00
0005434877929	3496	Business	35000.00
0005434938083	3496	Comfort	19900.00
0005434878005	3496	Comfort	19900.00
0005434877996	3496	Comfort	19900.00
0005434877952	3496	Comfort	19900.00
0005434877978	3496	Comfort	19900.00
0005434877927	3496	Comfort	19900.00
0005434877983	3496	Comfort	19900.00
0005434938092	3496	Comfort	19900.00
0005434877938	3496	Comfort	19900.00
0005435913884	3496	Comfort	19900.00
0005432799366	3496	Comfort	19900.00
0005435126254	3496	Comfort	19900.00
0005435126238	3496	Comfort	19900.00
0005435626124	3496	Comfort	19900.00
0005434426525	3496	Comfort	19900.00
0005434877919	3496	Comfort	19900.00
0005435126253	3496	Comfort	19900.00
0005434877936	3496	Comfort	19900.00
0005435902526	3496	Comfort	19900.00
0005434426512	3496	Comfort	19900.00
0005434877917	3496	Comfort	19900.00
0005434426528	3496	Comfort	19900.00
0005435626110	3496	Comfort	19900.00
0005434426513	3496	Comfort	19900.00
0005435126270	3496	Comfort	19900.00
0005432799362	3496	Comfort	19900.00
0005434938078	3496	Comfort	19900.00
0005435902485	3496	Comfort	19900.00
0005434877955	3496	Comfort	19900.00
0005434426533	3496	Comfort	19900.00
0005435902513	3496	Comfort	19900.00
0005435126241	3496	Comfort	19900.00
0005434877974	3496	Comfort	19900.00
0005434877911	3496	Comfort	19900.00
0005434938086	3496	Comfort	19900.00
0005435913859	3496	Comfort	19900.00
0005435126235	3496	Comfort	19900.00
0005434938073	3496	Economy	11700.00
0005434877963	3496	Economy	11700.00
0005432799361	3496	Economy	11700.00
0005434877959	3496	Economy	11700.00
0005434426523	3496	Economy	11700.00
0005434877915	3496	Economy	11700.00
0005432799358	3496	Economy	11700.00
0005434877995	3496	Economy	11700.00
0005434877947	3496	Economy	11700.00
0005435126265	3496	Economy	11700.00
0005434877962	3496	Economy	11700.00
0005434877933	3496	Economy	11700.00
0005432799375	3496	Economy	11700.00
0005435902450	3496	Economy	11700.00
0005432799359	3496	Economy	11700.00
0005432799386	3496	Economy	11700.00
0005434938090	3496	Economy	11700.00
0005434877992	3496	Economy	11700.00
0005435626120	3496	Economy	11700.00
0005434877979	3496	Economy	11700.00
0005434878007	3496	Economy	11700.00
0005434426508	3496	Economy	11700.00
0005432799384	3496	Economy	11700.00
0005434877922	3496	Economy	11700.00
0005432613847	3496	Economy	11700.00
0005434426517	3496	Economy	11700.00
0005435126266	3496	Economy	11700.00
0005434877999	3496	Economy	11700.00
0005434878004	3496	Economy	11700.00
0005434426509	3496	Economy	11700.00
0005434938089	3496	Economy	11700.00
0005435913879	3496	Economy	11700.00
0005434877976	3496	Economy	11700.00
0005435126250	3496	Economy	11700.00
0005435626127	3496	Economy	11700.00
0005435626114	3496	Economy	11700.00
0005434877975	3496	Economy	11700.00
0005435126248	3496	Economy	11700.00
0005434938082	3496	Economy	11700.00
0005435902497	3496	Economy	11700.00
0005432799368	3496	Economy	11700.00
0005434877918	3496	Economy	11700.00
0005434877985	3496	Economy	11700.00
0005435626128	3496	Economy	11700.00
0005434877971	3496	Economy	11700.00
0005434426530	3496	Economy	11700.00
0005435126255	3496	Economy	11700.00
0005434877930	3496	Economy	11700.00
0005434877945	3496	Economy	11700.00
0005435902514	3496	Economy	11700.00
0005435126245	3496	Economy	11700.00
0005434426515	3496	Economy	12800.00
0005434938084	3496	Economy	11700.00
0005434426518	3496	Economy	11700.00
0005432799374	3496	Economy	12800.00
0005435126237	3496	Economy	11700.00
0005432799376	3496	Economy	11700.00
0005435126231	3496	Economy	11700.00
0005435902525	3496	Economy	11700.00
0005434877931	3496	Economy	11700.00
0005434877970	3496	Economy	11700.00
0005434877934	3496	Economy	11700.00
0005434426519	3496	Economy	11700.00
0005434877935	3496	Economy	11700.00
0005432799382	3496	Economy	11700.00
0005432188599	3496	Economy	11700.00
0005432799372	3496	Economy	11700.00
0005434938074	3496	Economy	11700.00
0005435126247	3496	Economy	11700.00
0005435126261	3496	Economy	11700.00
0005434426531	3496	Economy	11700.00
0005434877997	3496	Economy	11700.00
0005434878000	3496	Economy	11700.00
0005434877950	3496	Economy	11700.00
0005432799364	3496	Economy	11700.00
0005435902465	3496	Economy	11700.00
0005432188598	3496	Economy	11700.00
0005435126251	3496	Economy	11700.00
0005434877967	3496	Economy	11700.00
0005435626121	3496	Economy	11700.00
0005435626136	3496	Economy	11700.00
0005434877994	3496	Economy	11700.00
0005435126252	3496	Economy	11700.00
0005432799373	3496	Economy	11700.00
0005435126263	3496	Economy	11700.00
0005434877925	3496	Economy	11700.00
0005435626126	3496	Economy	11700.00
0005432799367	3496	Economy	11700.00
0005434877973	3496	Economy	11700.00
0005434877987	3496	Economy	11700.00
0005432799383	3496	Economy	11700.00
0005432611698	3496	Economy	11700.00
0005435626125	3496	Economy	11700.00
0005434426516	3496	Economy	11700.00
0005435626111	3496	Economy	11700.00
0005434877965	3496	Economy	11700.00
0005434877953	3496	Economy	11700.00
0005435902479	3496	Economy	11700.00
0005435126256	3496	Economy	11700.00
0005434426527	3496	Economy	11700.00
0005432799379	3496	Economy	11700.00
0005435626137	3496	Economy	11700.00
0005435626113	3496	Economy	11700.00
0005434426526	3496	Economy	11700.00
0005435126264	3496	Economy	11700.00
0005435126260	3496	Economy	11700.00
0005432799385	3496	Economy	11700.00
0005434877921	3496	Economy	11700.00
0005435626118	3496	Economy	11700.00
0005434877980	3496	Economy	11700.00
0005435126257	3496	Economy	11700.00
0005434877912	3496	Economy	11700.00
0005434877923	3496	Economy	11700.00
0005432613850	3496	Economy	11700.00
0005434877958	3496	Economy	11700.00
0005435913862	3496	Economy	11700.00
0005435913860	3496	Economy	11700.00
0005435626117	3496	Economy	11700.00
0005435626116	3496	Economy	11700.00
0005434877960	3496	Economy	11700.00
0005432799369	3496	Economy	11700.00
0005435126262	3496	Economy	11700.00
0005434426521	3496	Economy	11700.00
0005435126243	3496	Economy	11700.00
0005435126271	3496	Economy	11700.00
0005434938087	3496	Economy	11700.00
0005434877990	3496	Economy	11700.00
0005434877932	3496	Economy	11700.00
0005434877969	3496	Economy	11700.00
0005432799377	3496	Economy	11700.00
0005435126244	3496	Economy	11700.00
0005434877939	3496	Economy	11700.00
0005435626131	3496	Economy	11700.00
0005434878006	3496	Economy	11700.00
0005435902478	3496	Economy	11700.00
0005434426535	3496	Economy	11700.00
0005435913861	3496	Economy	11700.00
0005434426510	3496	Economy	11700.00
0005432613849	3496	Economy	11700.00
0005434877977	3496	Economy	11700.00
0005434877988	3496	Economy	11700.00
0005435626119	3496	Economy	11700.00
0005432799378	3496	Economy	11700.00
0005435126258	3496	Economy	11700.00
0005435902490	3496	Economy	11700.00
0005432799370	3496	Economy	11700.00
0005435126242	3496	Economy	11700.00
0005435626122	3496	Economy	11700.00
0005434877940	3496	Economy	12800.00
0005435126239	3496	Economy	12800.00
0005434426536	3496	Economy	12800.00
0005434426537	3496	Economy	11700.00
0005434938085	3496	Economy	12800.00
0005434877924	3496	Economy	11700.00
0005435626135	3496	Economy	11700.00
0005434877948	3496	Economy	11700.00
0005434877986	3496	Economy	11700.00
0005434877968	3496	Economy	11700.00
0005434877982	3496	Economy	11700.00
0005435126249	3496	Economy	11700.00
0005434877998	3496	Economy	11700.00
0005432799363	3496	Economy	11700.00
0005434877946	3496	Economy	11700.00
0005434877913	3496	Economy	11700.00
0005434426511	3496	Economy	11700.00
0005435913873	3496	Economy	11700.00
0005435626115	3496	Economy	11700.00
0005435902494	3496	Economy	11700.00
0005434877957	3496	Economy	11700.00
0005432183459	3496	Economy	11700.00
0005434877956	3496	Economy	11700.00
0005434426532	3496	Economy	11700.00
0005435126233	3496	Economy	11700.00
0005434938081	3496	Economy	11700.00
0005434877944	3496	Economy	11700.00
0005435126232	3496	Economy	11700.00
0005435902527	3496	Economy	11700.00
0005434426520	3496	Economy	11700.00
0005435913869	3496	Economy	11700.00
0005434877961	3496	Economy	11700.00
0005435626123	3496	Economy	11700.00
0005434877984	3496	Economy	11700.00
0005434877981	3496	Economy	11700.00
0005434877964	3496	Economy	11700.00
0005432799381	3496	Economy	11700.00
0005432183460	3496	Economy	11700.00
0005434426507	3496	Economy	11700.00
0005434877993	3496	Economy	11700.00
0005434877920	3496	Economy	11700.00
0005435902518	3496	Economy	11700.00
0005434878003	3496	Economy	11700.00
0005434877949	3496	Economy	11700.00
0005435902496	3496	Economy	11700.00
0005434938075	3496	Economy	11700.00
0005435626130	3496	Economy	11700.00
0005432611696	3496	Economy	11700.00
0005435913882	3496	Economy	11700.00
0005434877972	3496	Economy	11700.00
0005432799360	3496	Economy	11700.00
0005434877942	3496	Economy	11700.00
0005435126267	3496	Economy	11700.00
0005435126269	3496	Economy	11700.00
0005435626133	3496	Economy	11700.00
0005435626112	3496	Economy	11700.00
0005432799371	3496	Economy	11700.00
0005435902509	3496	Economy	11700.00
0005435126236	3496	Economy	11700.00
0005435126246	3496	Economy	11700.00
0005432799365	3496	Economy	11700.00
0005435126234	3496	Economy	11700.00
0005434426522	3496	Economy	11700.00
0005434877916	3496	Economy	11700.00
0005434877941	3496	Economy	11700.00
0005434426529	3496	Economy	11700.00
0005434938079	3496	Economy	11700.00
0005434426534	3496	Economy	11700.00
0005435126240	3496	Economy	11700.00
0005434877937	3496	Economy	11700.00
0005435902511	3496	Economy	11700.00
0005434938080	3496	Economy	11700.00
0005434878001	3496	Economy	11700.00
0005434938077	3496	Economy	11700.00
0005435913883	3496	Economy	11700.00
0005434877989	3496	Economy	11700.00
0005432613848	3496	Economy	11700.00
0005434877991	3496	Economy	11700.00
0005432611697	3496	Economy	11700.00
0005435902510	3496	Economy	11700.00
0005434938091	3496	Economy	11700.00
0005434877928	3496	Economy	11700.00
0005434426524	3496	Economy	11700.00
0005435913876	3496	Economy	11700.00
0005434938076	3496	Economy	11700.00
0005434877943	3496	Economy	11700.00
0005435626129	3496	Economy	11700.00
0005435126268	3496	Economy	11700.00
0005432799380	3496	Economy	11700.00
0005434878002	3496	Economy	11700.00
0005432799076	14581	Business	35000.00
0005434937926	14581	Business	35000.00
0005434877677	14581	Business	35000.00
0005434426148	14581	Business	35000.00
0005435125854	14581	Business	35000.00
0005435902643	14581	Business	35000.00
0005434426202	14581	Business	35000.00
0005434877088	14581	Business	35000.00
0005434426295	14581	Business	35000.00
0005434937940	14581	Business	35000.00
0005434426323	14581	Business	35000.00
0005432607521	14581	Business	35000.00
0005432799162	14581	Business	35000.00
0005434877334	14581	Business	35000.00
0005434937914	14581	Business	35000.00
0005434877288	14581	Business	35000.00
0005435902652	14581	Business	35000.00
0005434937943	14581	Business	35000.00
0005432607518	14581	Comfort	19900.00
0005432799089	14581	Comfort	19900.00
0005434426318	14581	Comfort	19900.00
0005434877174	14581	Comfort	19900.00
0005434877099	14581	Comfort	19900.00
0005434877047	14581	Comfort	19900.00
0005434426189	14581	Comfort	19900.00
0005434937927	14581	Comfort	19900.00
0005435902651	14581	Comfort	19900.00
0005434877038	14581	Comfort	19900.00
0005435625959	14581	Comfort	19900.00
0005435625978	14581	Comfort	19900.00
0005434877071	14581	Comfort	19900.00
0005435125845	14581	Comfort	19900.00
0005434877091	14581	Comfort	19900.00
0005432799092	14581	Comfort	19900.00
0005434876770	14581	Comfort	19900.00
0005432799147	14581	Comfort	19900.00
0005432799062	14581	Comfort	19900.00
0005435902654	14581	Comfort	19900.00
0005432799218	14581	Comfort	19900.00
0005434877390	14581	Comfort	19900.00
0005434877271	14581	Comfort	19900.00
0005434426256	14581	Comfort	19900.00
0005435125991	14581	Comfort	19900.00
0005434426149	14581	Comfort	19900.00
0005434877374	14581	Comfort	19900.00
0005434426200	14581	Comfort	19900.00
0005435625927	14581	Comfort	19900.00
0005432799012	14581	Comfort	19900.00
0005434877090	14581	Comfort	19900.00
0005434877266	14581	Comfort	19900.00
0005434877245	14581	Comfort	19900.00
0005432059497	14581	Comfort	19900.00
0005434876832	14581	Economy	11700.00
0005432611688	14581	Economy	11700.00
0005434877404	14581	Economy	11700.00
0005434426179	14581	Economy	11700.00
0005434877311	14581	Economy	11700.00
0005434876858	14581	Economy	11700.00
0005435902645	14581	Economy	11700.00
0005434426331	14581	Economy	11700.00
0005434877022	14581	Economy	11700.00
0005434877295	14581	Economy	11700.00
0005434877094	14581	Economy	11700.00
0005435125857	14581	Economy	11700.00
0005434877655	14581	Economy	11700.00
0005434877467	14581	Economy	11700.00
0005434877226	14581	Economy	11700.00
0005434877107	14581	Economy	11700.00
0005434877414	14581	Economy	11700.00
0005434876831	14581	Economy	11700.00
0005434426190	14581	Economy	11700.00
0005435125929	14581	Economy	11700.00
0005434877161	14581	Economy	11700.00
0005434876989	14581	Economy	11700.00
0005434877110	14581	Economy	11700.00
0005434426178	14581	Economy	11700.00
0005434877427	14581	Economy	11700.00
0005435125909	14581	Economy	11700.00
0005435902648	14581	Economy	11700.00
0005434876881	14581	Economy	11700.00
0005434877121	14581	Economy	11700.00
0005434877175	14581	Economy	11700.00
0005434877615	14581	Economy	11700.00
0005432799204	14581	Economy	11700.00
0005434937913	14581	Economy	11700.00
0005434937909	14581	Economy	11700.00
0005435914694	14581	Economy	11700.00
0005432799061	14581	Economy	11700.00
0005434877264	14581	Economy	11700.00
0005435625957	14581	Economy	11700.00
0005435625965	14581	Economy	11700.00
0005435625910	14581	Economy	11700.00
0005434426201	14581	Economy	11700.00
0005434877234	14581	Economy	12800.00
0005432799118	14581	Economy	12800.00
0005434426342	14581	Economy	11700.00
0005434937941	14581	Economy	11700.00
0005434877120	14581	Economy	12800.00
0005435625962	14581	Economy	11700.00
0005434426301	14581	Economy	12800.00
0005434876906	14581	Economy	12800.00
0005435125915	14581	Economy	11700.00
0005435125840	14581	Economy	11700.00
0005432799073	14581	Economy	11700.00
0005432799099	14581	Economy	11700.00
0005434877168	14581	Economy	11700.00
0005434877233	14581	Economy	11700.00
0005432607507	14581	Economy	11700.00
0005432799114	14581	Economy	11700.00
0005434876847	14581	Economy	11700.00
0005434876859	14581	Economy	11700.00
0005434877100	14581	Economy	11700.00
0005432611657	14581	Economy	11700.00
0005435625909	14581	Economy	11700.00
0005434876871	14581	Economy	11700.00
0005434877270	14581	Economy	11700.00
0005434876988	14581	Economy	11700.00
0005434937955	14581	Economy	11700.00
0005435902644	14581	Economy	11700.00
0005435125879	14581	Economy	11700.00
0005434877200	14581	Economy	11700.00
0005435625923	14581	Economy	11700.00
0005434426240	14581	Economy	11700.00
0005434877037	14581	Economy	11700.00
0005434876945	14581	Economy	11700.00
0005434877415	14581	Economy	11700.00
0005434877111	14581	Economy	11700.00
0005434877463	14581	Economy	11700.00
0005435125833	14581	Economy	11700.00
0005432611659	14581	Economy	11700.00
0005434876833	14581	Economy	11700.00
0005434426147	14581	Economy	11700.00
0005434877291	14581	Economy	11700.00
0005435125889	14581	Economy	11700.00
0005435625922	14581	Economy	11700.00
0005434937899	14581	Economy	11700.00
0005434877391	14581	Economy	11700.00
0005434877236	14581	Economy	11700.00
0005434877267	14581	Economy	11700.00
0005434426302	14581	Economy	11700.00
0005434876990	14581	Economy	11700.00
0005434937942	14581	Economy	11700.00
0005434426294	14581	Economy	11700.00
0005432799160	14581	Economy	11700.00
0005434426285	14581	Economy	11700.00
0005434426280	14581	Economy	11700.00
0005435125881	14581	Economy	11700.00
0005432799164	14581	Economy	11700.00
0005435902655	14581	Economy	11700.00
0005435902640	14581	Economy	11700.00
0005434426261	14581	Economy	11700.00
0005434877157	14581	Economy	11700.00
0005434876902	14581	Economy	11700.00
0005435625956	14581	Economy	11700.00
0005434877320	14581	Economy	11700.00
0005434876808	14581	Economy	11700.00
0005434426293	14581	Economy	11700.00
0005434877286	14581	Economy	11700.00
0005434876982	14581	Economy	11700.00
0005435902649	14581	Economy	11700.00
0005434877116	14581	Economy	11700.00
0005432799192	14581	Economy	11700.00
0005434937933	14581	Economy	11700.00
0005432611673	14581	Economy	11700.00
0005435125714	14581	Economy	11700.00
0005434877603	14581	Economy	11700.00
0005434426124	14581	Economy	11700.00
0005434937915	14581	Economy	11700.00
0005435902653	14581	Economy	11700.00
0005434877095	14581	Economy	11700.00
0005434876848	14581	Economy	11700.00
0005434876905	14581	Economy	11700.00
0005434877439	14581	Economy	11700.00
0005434876919	14581	Economy	11700.00
0005432799088	14581	Economy	12800.00
0005435125855	14581	Economy	12800.00
0005435625977	14581	Economy	12800.00
0005435125890	14581	Economy	11700.00
0005435125853	14581	Economy	11700.00
0005435902641	14581	Economy	11700.00
0005434877214	14581	Economy	11700.00
0005434876880	14581	Economy	11700.00
0005434876849	14581	Economy	11700.00
0005434877176	14581	Economy	11700.00
0005432059498	14581	Economy	11700.00
0005432611660	14581	Economy	11700.00
0005434426249	14581	Economy	11700.00
0005432607508	14581	Economy	11700.00
0005435902647	14581	Economy	11700.00
0005434877009	14581	Economy	11700.00
0005435913929	14581	Economy	11700.00
0005435125886	14581	Economy	11700.00
0005434876882	14581	Economy	11700.00
0005435125812	14581	Economy	11700.00
0005432799193	14581	Economy	11700.00
0005435125887	14581	Economy	11700.00
0005434877105	14581	Economy	11700.00
0005434877215	14581	Economy	11700.00
0005434426163	14581	Economy	11700.00
0005435125914	14581	Economy	11700.00
0005434877212	14581	Economy	11700.00
0005432799146	14581	Economy	11700.00
0005434877225	14581	Economy	11700.00
0005435126021	14581	Economy	11700.00
0005435902650	14581	Economy	11700.00
0005434426199	14581	Economy	11700.00
0005434877106	14581	Economy	11700.00
0005432611674	14581	Economy	11700.00
0005435902639	14581	Economy	11700.00
0005435125908	14581	Economy	11700.00
0005435902642	14581	Economy	11700.00
0005434426402	14581	Economy	11700.00
0005434877062	14581	Economy	11700.00
0005435125856	14581	Economy	11700.00
0005432611654	14581	Economy	11700.00
0005435125839	14581	Economy	11700.00
0005435913928	14581	Economy	11700.00
0005434426262	14581	Economy	11700.00
0005434877160	14581	Economy	11700.00
0005434876874	14581	Economy	11700.00
0005435902646	14581	Economy	11700.00
0005434426263	14581	Economy	11700.00
0005434877296	14581	Economy	11700.00
0005435125813	14581	Economy	11700.00
0005434426332	14581	Economy	11700.00
0005434426277	14581	Economy	11700.00
0005434877290	14581	Economy	11700.00
0005435625952	14581	Economy	11700.00
0005432607509	14581	Economy	11700.00
0005434426271	14581	Economy	11700.00
0005435625908	14581	Economy	11700.00
0005434877406	14581	Economy	11700.00
0005434876950	14581	Economy	11700.00
0005432799038	14581	Economy	11700.00
0005434877287	14581	Economy	11700.00
0005434877096	14581	Economy	11700.00
0005434877424	14581	Economy	11700.00
0005434426216	14581	Economy	11700.00
0005432799121	14581	Economy	11700.00
0005434877321	14581	Economy	11700.00
0005434877008	14581	Economy	11700.00
0005434876795	14581	Economy	11700.00
0005434937904	14581	Economy	11700.00
0005434876771	14581	Economy	11700.00
0005434426401	14581	Economy	11700.00
0005434877063	14581	Economy	11700.00
0005435125790	14581	Economy	11700.00
0005434426264	14581	Economy	11700.00
0005434426217	14581	Economy	11700.00
0005434877051	14581	Economy	11700.00
0005432799085	14581	Economy	11700.00
0005434877285	14581	Economy	11700.00
0005435902656	14581	Economy	11700.00
0005434937928	14581	Economy	11700.00
0005434325612	3613	Economy	14800.00
0005435889809	3613	Economy	14800.00
0005434325613	3613	Economy	14800.00
0005434325616	3613	Economy	14800.00
0005434325618	3613	Economy	14800.00
0005435889803	3613	Economy	14800.00
0005434312313	3613	Economy	14800.00
0005435889828	3613	Economy	14800.00
0005434312312	3613	Economy	14800.00
0005434325610	3613	Economy	14800.00
0005435889816	3613	Economy	14800.00
0005434325614	3613	Economy	14800.00
0005434325617	3613	Economy	14800.00
0005435889810	3613	Economy	14800.00
0005434325609	3613	Economy	14800.00
0005434325619	3613	Economy	14800.00
0005434325611	3613	Economy	14800.00
0005434325615	3613	Economy	14800.00
0005434325496	15632	Economy	16300.00
0005434325508	15632	Economy	14800.00
0005434325481	15632	Economy	14800.00
0005435889877	15632	Economy	14800.00
0005434325519	15632	Economy	14800.00
0005434325523	15632	Economy	14800.00
0005435889879	15632	Economy	14800.00
0005434325520	15632	Economy	14800.00
0005435889878	15632	Economy	14800.00
0005434325551	15632	Economy	14800.00
0005435889880	15632	Economy	14800.00
0005435889876	15632	Economy	14800.00
0005434325509	15632	Economy	14800.00
0005434325517	15632	Economy	14800.00
0005434325560	15632	Economy	14800.00
0005434325497	15632	Economy	14800.00
0005434325470	15632	Economy	14800.00
0005435957654	623	Economy	4100.00
0005435957664	623	Economy	4100.00
0005435957657	623	Economy	4100.00
0005435957662	623	Economy	4100.00
0005433420284	623	Economy	4100.00
0005435957651	623	Economy	4100.00
0005433420297	623	Economy	4100.00
0005435957652	623	Economy	4100.00
0005435957660	623	Economy	4100.00
0005435957650	623	Economy	4100.00
0005435957661	623	Economy	4100.00
0005435957663	623	Economy	4100.00
0005433420313	623	Economy	4100.00
0005435957658	623	Economy	4100.00
0005435957659	623	Economy	4100.00
0005433420302	623	Economy	4100.00
0005433420301	623	Economy	4100.00
0005435957656	623	Economy	4100.00
0005433420317	623	Economy	4100.00
0005433420283	623	Economy	4100.00
0005433420298	623	Economy	4100.00
0005435957653	623	Economy	4100.00
0005435957655	623	Economy	4100.00
0005435957549	15195	Economy	4500.00
0005433420376	15195	Economy	4500.00
0005435957554	15195	Economy	4100.00
0005433420374	15195	Economy	4100.00
0005435957536	15195	Economy	4100.00
0005433420378	15195	Economy	4100.00
0005433420372	15195	Economy	4100.00
0005433420377	15195	Economy	4100.00
0005433420373	15195	Economy	4100.00
0005435957577	15195	Economy	4100.00
0005435957584	15195	Economy	4100.00
0005435957525	15195	Economy	4100.00
0005433420379	15195	Economy	4100.00
0005435957531	15195	Economy	4100.00
0005435957476	15195	Economy	4100.00
0005435957474	15195	Economy	4100.00
0005433420375	15195	Economy	4100.00
0005435957532	15195	Economy	4100.00
0005435957551	15195	Economy	4100.00
0005435957583	15195	Economy	4100.00
0005435957475	15195	Economy	4100.00
0005435957473	15195	Economy	4100.00
0005435219174	27262	Economy	25500.00
0005435216566	27262	Economy	25500.00
0005435216553	27262	Economy	25500.00
0005435216564	27262	Economy	25500.00
0005435219180	27262	Economy	25500.00
0005435216558	27262	Economy	25500.00
0005435216555	27262	Economy	25500.00
0005435219169	27262	Economy	25500.00
0005435216554	27262	Economy	25500.00
0005435219167	27262	Economy	25500.00
0005435216559	27262	Economy	25500.00
0005435216565	27262	Economy	25500.00
0005435216578	31778	Economy	25500.00
0005435217706	31778	Economy	25500.00
0005435217705	31778	Economy	25500.00
0005435217701	31778	Economy	25500.00
0005435216576	31778	Economy	25500.00
0005435217703	31778	Economy	25500.00
0005435216580	31778	Economy	25500.00
0005435218111	31778	Economy	25500.00
0005435217708	31778	Economy	25500.00
0005435217704	31778	Economy	25500.00
0005435216581	31778	Economy	25500.00
0005435218110	31778	Economy	25500.00
0005435217702	31778	Economy	25500.00
0005435217707	31778	Economy	25500.00
0005435217700	31778	Economy	25500.00
0005435216584	31778	Economy	25500.00
0005435218112	31778	Economy	25500.00
0005435216583	31778	Economy	25500.00
0005435216577	31778	Economy	25500.00
0005435216579	31778	Economy	25500.00
0005435216582	31778	Economy	25500.00
0005435629401	8881	Economy	10400.00
0005435629400	8881	Economy	10400.00
0005434247140	16029	Economy	10400.00
0005434247139	16029	Economy	10400.00
0005434467753	4019	Economy	23400.00
0005434467751	4019	Economy	21200.00
0005434467757	4019	Economy	21200.00
0005434467752	4019	Economy	21200.00
0005434467749	4019	Economy	21200.00
0005434467755	4019	Economy	21200.00
0005434467750	4019	Economy	21200.00
0005434467756	4019	Economy	21200.00
0005434467754	4019	Economy	21200.00
0005434467728	23206	Economy	21200.00
0005434467725	23206	Economy	21200.00
0005434467731	23206	Economy	21200.00
0005434467726	23206	Economy	21200.00
0005434467727	23206	Economy	21200.00
0005434467736	23206	Economy	21200.00
0005434467730	23206	Economy	21200.00
0005434467729	23206	Economy	21200.00
0005435933404	4439	Economy	13400.00
0005435163207	4439	Economy	13400.00
0005435933407	4439	Economy	12200.00
0005435163219	4439	Economy	12200.00
0005435933427	4439	Economy	12200.00
0005435163209	4439	Economy	12200.00
0005435933418	4439	Economy	12200.00
0005435163208	4439	Economy	12200.00
0005435933409	4439	Economy	12200.00
0005435933416	4439	Economy	12200.00
0005435933417	4439	Economy	12200.00
0005435933414	4439	Economy	12200.00
0005435933415	4439	Economy	12200.00
0005435163212	4439	Economy	12200.00
0005435933405	4439	Economy	12200.00
0005435163210	4439	Economy	12200.00
0005435163217	4439	Economy	12200.00
0005435933408	4439	Economy	12200.00
0005435163218	4439	Economy	12200.00
0005435163205	4439	Economy	12200.00
0005435163216	4439	Economy	12200.00
0005435163206	4439	Economy	12200.00
0005435933406	4439	Economy	12200.00
0005435163213	4439	Economy	12200.00
0005435163211	4439	Economy	12200.00
0005435163215	4439	Economy	12200.00
0005435163214	4439	Economy	12200.00
0005435163157	29516	Economy	12200.00
0005435163177	29516	Economy	12200.00
0005435163190	29516	Economy	12200.00
0005435163152	29516	Economy	12200.00
0005435933439	29516	Economy	12200.00
0005435163191	29516	Economy	12200.00
0005435933441	29516	Economy	12200.00
0005435163167	29516	Economy	12200.00
0005435933445	29516	Economy	12200.00
0005435163176	29516	Economy	12200.00
0005435933442	29516	Economy	12200.00
0005435933444	29516	Economy	12200.00
0005435163154	29516	Economy	12200.00
0005435933443	29516	Economy	12200.00
0005435933440	29516	Economy	12200.00
0005435163158	29516	Economy	12200.00
0005432645943	6830	Business	87700.00
0005432645949	6830	Business	87700.00
0005432645955	6830	Business	87700.00
0005432645946	6830	Business	87700.00
0005432645948	6830	Business	87700.00
0005432645914	6830	Business	87700.00
0005435229316	6830	Business	87700.00
0005435229315	6830	Business	87700.00
0005435229306	6830	Business	87700.00
0005432645907	6830	Business	87700.00
0005432645906	6830	Economy	29200.00
0005432645957	6830	Economy	29200.00
0005435229328	6830	Economy	29200.00
0005432645930	6830	Economy	29200.00
0005432645934	6830	Economy	29200.00
0005432645919	6830	Economy	29200.00
0005435229337	6830	Economy	29200.00
0005435229327	6830	Economy	29200.00
0005432645922	6830	Economy	29200.00
0005432645952	6830	Economy	32200.00
0005435229338	6830	Economy	32200.00
0005432645910	6830	Economy	32200.00
0005432645921	6830	Economy	32200.00
0005432645945	6830	Economy	29200.00
0005435229320	6830	Economy	29200.00
0005432645939	6830	Economy	29200.00
0005432645956	6830	Economy	29200.00
0005432645932	6830	Economy	29200.00
0005432645928	6830	Economy	29200.00
0005432645916	6830	Economy	29200.00
0005432645933	6830	Economy	29200.00
0005432645911	6830	Economy	29200.00
0005432645947	6830	Economy	29200.00
0005432645929	6830	Economy	29200.00
0005432645936	6830	Economy	29200.00
0005435229304	6830	Economy	29200.00
0005432645912	6830	Economy	29200.00
0005432645926	6830	Economy	29200.00
0005435229333	6830	Economy	29200.00
0005432645944	6830	Economy	29200.00
0005432645920	6830	Economy	29200.00
0005432645935	6830	Economy	29200.00
0005432645950	6830	Economy	29200.00
0005432645927	6830	Economy	29200.00
0005432645937	6830	Economy	29200.00
0005432645931	6830	Economy	29200.00
0005432645951	6830	Economy	29200.00
0005432645908	6830	Economy	29200.00
0005435229302	6830	Economy	29200.00
0005435229317	6830	Economy	29200.00
0005432645925	6830	Economy	29200.00
0005435229334	6830	Economy	29200.00
0005432645924	6830	Economy	29200.00
0005435229335	6830	Economy	29200.00
0005432645958	6830	Economy	29200.00
0005435229329	6830	Economy	29200.00
0005432645941	6830	Economy	29200.00
0005432645938	6830	Economy	29200.00
0005432645923	6830	Economy	29200.00
0005435229347	6830	Economy	29200.00
0005432645953	6830	Economy	29200.00
0005435229313	6830	Economy	29200.00
0005432645917	6830	Economy	29200.00
0005432645913	6830	Economy	29200.00
0005435229312	6830	Economy	29200.00
0005435229311	6830	Economy	29200.00
0005435229351	6830	Economy	29200.00
0005435229301	6830	Economy	29200.00
0005432645915	6830	Economy	29200.00
0005432645940	6830	Economy	29200.00
0005432645909	6830	Economy	29200.00
0005435229314	6830	Economy	29200.00
0005432645954	6830	Economy	29200.00
0005435229340	6830	Economy	29200.00
0005435229336	6830	Economy	29200.00
0005432645918	6830	Economy	29200.00
0005432645942	6830	Economy	29200.00
0005433404710	2876	Business	12600.00
0005435797432	2876	Business	12600.00
0005435797427	2876	Business	12600.00
0005433404696	2876	Business	12600.00
0005433404717	2876	Economy	4200.00
0005435797439	2876	Economy	4200.00
0005435797437	2876	Economy	4200.00
0005435797425	2876	Economy	4600.00
0005433404711	2876	Economy	4200.00
0005435797435	2876	Economy	4200.00
0005435797426	2876	Economy	4200.00
0005435797428	2876	Economy	4200.00
0005433404728	2876	Economy	4200.00
0005435797433	2876	Economy	4200.00
0005433404695	2876	Economy	4200.00
0005435797429	2876	Economy	4200.00
0005433404718	2876	Economy	4200.00
0005435797431	2876	Economy	4200.00
0005435797438	2876	Economy	4200.00
0005435797436	2876	Economy	4200.00
0005435797430	2876	Economy	4200.00
0005433404705	2876	Economy	4200.00
0005435797434	2876	Economy	4200.00
0005435797311	29331	Business	12600.00
0005435797299	29331	Business	12600.00
0005433404790	29331	Business	12600.00
0005435797318	29331	Business	12600.00
0005435797319	29331	Business	12600.00
0005435797360	29331	Business	12600.00
0005435797317	29331	Economy	4200.00
0005435797361	29331	Economy	4200.00
0005433404791	29331	Economy	4600.00
0005435797345	29331	Economy	4600.00
0005435797374	29331	Economy	4600.00
0005433404786	29331	Economy	4200.00
0005435797373	29331	Economy	4200.00
0005433404788	29331	Economy	4200.00
0005433404787	29331	Economy	4200.00
0005435797312	29331	Economy	4200.00
0005435797327	29331	Economy	4200.00
0005435797307	29331	Economy	4200.00
0005435797270	29331	Economy	4200.00
0005435797349	29331	Economy	4200.00
0005435797269	29331	Economy	4200.00
0005435797310	29331	Economy	4200.00
0005435797316	29331	Economy	4200.00
0005433404785	29331	Economy	4200.00
0005435797326	29331	Economy	4200.00
0005435797387	29331	Economy	4200.00
0005435797344	29331	Economy	4200.00
0005435797255	29331	Economy	4200.00
0005433404784	29331	Economy	4200.00
0005435797388	29331	Economy	4200.00
0005435797309	29331	Economy	4200.00
0005433404789	29331	Economy	4200.00
0005435797306	29331	Economy	4200.00
0005435797254	29331	Economy	4200.00
0005435376328	5761	Economy	6800.00
0005434947992	5767	Economy	6800.00
0005434947994	5767	Economy	6800.00
0005434947996	5767	Economy	6800.00
0005434947993	5767	Economy	6800.00
0005434947997	5767	Economy	6800.00
0005434947999	5767	Economy	6800.00
0005434947995	5767	Economy	6800.00
0005434947998	5767	Economy	6800.00
0005434947934	16371	Economy	6800.00
0005434947928	16371	Economy	6800.00
0005434947907	16371	Economy	6800.00
0005434947936	16371	Economy	6800.00
0005434947930	16371	Economy	6800.00
0005434947926	16371	Economy	6800.00
0005434947869	16371	Economy	6800.00
0005434947940	16371	Economy	6800.00
0005434947908	16371	Economy	6800.00
0005434947913	16371	Economy	6800.00
0005434947929	16371	Economy	6800.00
0005434947935	16371	Economy	6800.00
0005433960733	6883	Business	21400.00
0005433960705	6883	Business	21400.00
0005433960677	6883	Business	21400.00
0005433960732	6883	Business	21400.00
0005433960723	6883	Business	21400.00
0005433960704	6883	Business	21400.00
0005433960690	6883	Business	21400.00
0005433960692	6883	Business	21400.00
0005433960722	6883	Economy	7100.00
0005433960711	6883	Economy	7100.00
0005433960709	6883	Economy	7100.00
0005433960721	6883	Economy	7100.00
0005433960680	6883	Economy	7100.00
0005433960702	6883	Economy	7100.00
0005433960736	6883	Economy	7800.00
0005433960694	6883	Economy	7800.00
0005433960738	6883	Economy	7800.00
0005433960712	6883	Economy	7800.00
0005433960725	6883	Economy	7100.00
0005433960707	6883	Economy	7100.00
0005433960700	6883	Economy	7100.00
0005433960718	6883	Economy	7100.00
0005433960730	6883	Economy	7100.00
0005433960731	6883	Economy	7100.00
0005433960695	6883	Economy	7100.00
0005433960717	6883	Economy	7100.00
0005433960683	6883	Economy	7100.00
0005433960701	6883	Economy	7100.00
0005433960685	6883	Economy	7100.00
0005433960713	6883	Economy	7100.00
0005433960678	6883	Economy	7100.00
0005433960698	6883	Economy	7100.00
0005433960708	6883	Economy	7100.00
0005433960724	6883	Economy	7100.00
0005433960726	6883	Economy	7100.00
0005433960729	6883	Economy	7100.00
0005433960684	6883	Economy	7100.00
0005433960716	6883	Economy	7100.00
0005433960679	6883	Economy	7100.00
0005433960735	6883	Economy	7100.00
0005433960737	6883	Economy	7100.00
0005433960714	6883	Economy	7100.00
0005433960715	6883	Economy	7100.00
0005433960706	6883	Economy	7100.00
0005433960689	6883	Economy	7100.00
0005433960681	6883	Economy	7100.00
0005433960688	6883	Economy	7100.00
0005433960734	6883	Economy	7100.00
0005433960719	6883	Economy	7100.00
0005433960728	6883	Economy	7100.00
0005433960687	6883	Economy	7100.00
0005433960693	6883	Economy	7100.00
0005433960675	6883	Economy	7100.00
0005433960676	6883	Economy	7100.00
0005433960699	6883	Economy	7100.00
0005433960710	6883	Economy	7100.00
0005433960682	6883	Economy	7100.00
0005433960691	6883	Economy	7100.00
0005433960720	6883	Economy	7100.00
0005433960696	6883	Economy	7100.00
0005433960703	6883	Economy	7100.00
0005433960727	6883	Economy	7100.00
0005433960697	6883	Economy	7100.00
0005433960686	6883	Economy	7100.00
0005433960106	25753	Business	21400.00
0005433960007	25753	Business	21400.00
0005433960056	25753	Business	21400.00
0005433959980	25753	Business	21400.00
0005433960018	25753	Business	21400.00
0005433959984	25753	Business	21400.00
0005433959928	25753	Business	21400.00
0005433960077	25753	Economy	7100.00
0005433960044	25753	Economy	7100.00
0005433960112	25753	Economy	7100.00
0005433959896	25753	Economy	7100.00
0005433959936	25753	Economy	7800.00
0005433960137	25753	Economy	7800.00
0005433960083	25753	Economy	7800.00
0005433960035	25753	Economy	7100.00
0005433959985	25753	Economy	7100.00
0005433959902	25753	Economy	7100.00
0005433960087	25753	Economy	7100.00
0005433960050	25753	Economy	7100.00
0005433959860	25753	Economy	7100.00
0005433959968	25753	Economy	7100.00
0005433960135	25753	Economy	7100.00
0005433959903	25753	Economy	7100.00
0005433959958	25753	Economy	7100.00
0005433960059	25753	Economy	7100.00
0005433959990	25753	Economy	7100.00
0005433960136	25753	Economy	7100.00
0005433960060	25753	Economy	7100.00
0005433960025	25753	Economy	7100.00
0005433960023	25753	Economy	7100.00
0005433959992	25753	Economy	7100.00
0005433960026	25753	Economy	7100.00
0005433959884	25753	Economy	7100.00
0005433959911	25753	Economy	7100.00
0005433960131	25753	Economy	7100.00
0005433960107	25753	Economy	7100.00
0005433960010	25753	Economy	7100.00
0005433960016	25753	Economy	7100.00
0005433960113	25753	Economy	7100.00
0005433960105	25753	Economy	7100.00
0005433959935	25753	Economy	7100.00
0005433959859	25753	Economy	7100.00
0005433960119	25753	Economy	7100.00
0005433959888	25753	Economy	7100.00
0005433960057	25753	Economy	7100.00
0005433959885	25753	Economy	7100.00
0005433959937	25753	Economy	7100.00
0005433960005	25753	Economy	7100.00
0005433959901	25753	Economy	7100.00
0005433959941	25753	Economy	7100.00
0005433959882	25753	Economy	7100.00
0005433959883	25753	Economy	7100.00
0005433959929	25753	Economy	7100.00
0005433960027	25753	Economy	7100.00
0005433960124	25753	Economy	7100.00
0005433960108	25753	Economy	7100.00
0005433960017	25753	Economy	7100.00
0005433960024	25753	Economy	7100.00
0005435082691	24560	Economy	3900.00
0005435082703	24560	Economy	3900.00
0005435082693	24560	Economy	3900.00
0005435082702	24560	Economy	3900.00
0005435082692	24560	Economy	3900.00
0005435082701	24560	Economy	3900.00
0005435082690	24560	Economy	3900.00
0005435082678	24560	Economy	3900.00
0005435082679	24560	Economy	3900.00
0005435082755	26049	Economy	3900.00
0005435082761	26049	Economy	3900.00
0005435082757	26049	Economy	3900.00
0005435082752	26049	Economy	3900.00
0005435082759	26049	Economy	3900.00
0005435082758	26049	Economy	3900.00
0005435082762	26049	Economy	3900.00
0005435082753	26049	Economy	3900.00
0005435082760	26049	Economy	3900.00
0005435082754	26049	Economy	3900.00
0005435082763	26049	Economy	3900.00
0005435082756	26049	Economy	3900.00
0005434244901	4961	Business	18000.00
0005434244884	4961	Economy	6600.00
0005432166892	4961	Business	18000.00
0005434244880	4961	Economy	6600.00
0005435286565	4961	Economy	6600.00
0005435286564	4961	Economy	6000.00
0005434244891	4961	Economy	6000.00
0005434244893	4961	Economy	6000.00
0005434244881	4961	Economy	6000.00
0005434244897	4961	Economy	6000.00
0005434244882	4961	Economy	6000.00
0005434244905	4961	Economy	6000.00
0005434244875	4961	Economy	6000.00
0005434244886	4961	Economy	6000.00
0005434244887	4961	Economy	6000.00
0005434244883	4961	Economy	6000.00
0005434244904	4961	Economy	6000.00
0005434244903	4961	Economy	6000.00
0005434244890	4961	Economy	6000.00
0005434244885	4961	Economy	6000.00
0005432166890	4961	Economy	6600.00
0005434244894	4961	Economy	6600.00
0005433534473	4961	Economy	6000.00
0005434244900	4961	Economy	6000.00
0005434244898	4961	Economy	6000.00
0005434244878	4961	Economy	6000.00
0005434244879	4961	Economy	6000.00
0005434244895	4961	Economy	6000.00
0005434244902	4961	Economy	6000.00
0005434244892	4961	Economy	6000.00
0005432166891	4961	Economy	6000.00
0005434244889	4961	Economy	6000.00
0005434244899	4961	Economy	6000.00
0005433534471	4961	Economy	6000.00
0005433534477	4961	Economy	6000.00
0005434244877	4961	Economy	6000.00
0005433534470	4961	Economy	6000.00
0005434244896	4961	Economy	6000.00
0005434244876	4961	Economy	6000.00
0005434244888	4961	Economy	6000.00
0005433614475	4962	Business	18000.00
0005433614454	4962	Business	18000.00
0005433784849	4962	Business	18000.00
0005433614462	4962	Business	18000.00
0005433784822	4962	Business	18000.00
0005433614447	4962	Business	18000.00
0005432105443	4962	Business	18000.00
0005432105413	4962	Business	18000.00
0005432105434	4962	Business	18000.00
0005433614495	4962	Business	18000.00
0005433614466	4962	Business	18000.00
0005432667447	4962	Business	18000.00
0005433614501	4962	Business	18000.00
0005433784840	4962	Business	18000.00
0005433614445	4962	Business	18000.00
0005433784821	4962	Business	18000.00
0005432105404	4962	Business	18000.00
0005433784843	4962	Business	18000.00
0005432105444	4962	Business	18000.00
0005433614504	4962	Business	18000.00
0005432105425	4962	Business	18000.00
0005433784830	4962	Business	18000.00
0005433784831	4962	Business	18000.00
0005433614458	4962	Business	18000.00
0005433614485	4962	Business	18000.00
0005432145105	4962	Business	18000.00
0005433784826	4962	Business	18000.00
0005432105418	4962	Business	18000.00
0005433614491	4962	Economy	6600.00
0005432105405	4962	Economy	6600.00
0005432105431	4962	Economy	6600.00
0005433614455	4962	Economy	6600.00
0005433614500	4962	Economy	6600.00
0005433614481	4962	Economy	6600.00
0005433614483	4962	Economy	6000.00
0005433784825	4962	Economy	6000.00
0005433784817	4962	Economy	6000.00
0005433784835	4962	Economy	6000.00
0005433614497	4962	Economy	6000.00
0005433614438	4962	Economy	6000.00
0005432145104	4962	Economy	6000.00
0005433614459	4962	Economy	6000.00
0005433784827	4962	Economy	6000.00
0005433784823	4962	Economy	6000.00
0005433614465	4962	Economy	6000.00
0005433614496	4962	Economy	6000.00
0005432105446	4962	Economy	6000.00
0005433614437	4962	Economy	6000.00
0005433784820	4962	Economy	6000.00
0005433784841	4962	Economy	6000.00
0005433614469	4962	Economy	6000.00
0005432105398	4962	Economy	6000.00
0005432105410	4962	Economy	6000.00
0005433614479	4962	Economy	6000.00
0005433614443	4962	Economy	6000.00
0005432105438	4962	Economy	6000.00
0005432105409	4962	Economy	6000.00
0005433784828	4962	Economy	6000.00
0005432105436	4962	Economy	6000.00
0005432665268	4962	Economy	6000.00
0005433614449	4962	Economy	6000.00
0005433614471	4962	Economy	6000.00
0005432105406	4962	Economy	6000.00
0005433614482	4962	Economy	6000.00
0005433784845	4962	Economy	6000.00
0005433614441	4962	Economy	6000.00
0005433784838	4962	Economy	6000.00
0005432105430	4962	Economy	6000.00
0005432105435	4962	Economy	6000.00
0005433784836	4962	Economy	6000.00
0005432105415	4962	Economy	6000.00
0005432105401	4962	Economy	6000.00
0005433784818	4962	Economy	6000.00
0005433614507	4962	Economy	6000.00
0005433614440	4962	Economy	6000.00
0005432105403	4962	Economy	6000.00
0005433784816	4962	Economy	6000.00
0005433784837	4962	Economy	6000.00
0005432105407	4962	Economy	6000.00
0005432105437	4962	Economy	6000.00
0005433614480	4962	Economy	6000.00
0005433784814	4962	Economy	6000.00
0005433614486	4962	Economy	6000.00
0005432105412	4962	Economy	6000.00
0005433614463	4962	Economy	6000.00
0005433614499	4962	Economy	6000.00
0005433614457	4962	Economy	6000.00
0005433614435	4962	Economy	6000.00
0005433614448	4962	Economy	6000.00
0005432105411	4962	Economy	6000.00
0005433784819	4962	Economy	6000.00
0005432105422	4962	Economy	6000.00
0005433614464	4962	Economy	6000.00
0005433784832	4962	Economy	6000.00
0005432105423	4962	Economy	6600.00
0005433614450	4962	Economy	6600.00
0005433614442	4962	Economy	6600.00
0005432105428	4962	Economy	6600.00
0005433614444	4962	Economy	6600.00
0005433614488	4962	Economy	6000.00
0005433614493	4962	Economy	6000.00
0005432105419	4962	Economy	6000.00
0005432105439	4962	Economy	6000.00
0005433614468	4962	Economy	6600.00
0005433614492	4962	Economy	6000.00
0005433614506	4962	Economy	6000.00
0005433614505	4962	Economy	6000.00
0005433614461	4962	Economy	6000.00
0005433614439	4962	Economy	6000.00
0005432105433	4962	Economy	6000.00
0005432105420	4962	Economy	6000.00
0005432105429	4962	Economy	6000.00
0005433614456	4962	Economy	6000.00
0005433614478	4962	Economy	6000.00
0005432105424	4962	Economy	6000.00
0005432105421	4962	Economy	6000.00
0005432105408	4962	Economy	6000.00
0005432105427	4962	Economy	6000.00
0005432105397	4962	Economy	6000.00
0005432105441	4962	Economy	6000.00
0005433614446	4962	Economy	6000.00
0005433784833	4962	Economy	6000.00
0005432665267	4962	Economy	6000.00
0005432105400	4962	Economy	6000.00
0005432105442	4962	Economy	6000.00
0005433614476	4962	Economy	6000.00
0005433784850	4962	Economy	6000.00
0005433784848	4962	Economy	6000.00
0005432105402	4962	Economy	6000.00
0005432105440	4962	Economy	6000.00
0005433784829	4962	Economy	6000.00
0005433614452	4962	Economy	6000.00
0005433614474	4962	Economy	6000.00
0005433614508	4962	Economy	6000.00
0005433614489	4962	Economy	6000.00
0005433614490	4962	Economy	6000.00
0005432105426	4962	Economy	6000.00
0005433784842	4962	Economy	6000.00
0005433614453	4962	Economy	6000.00
0005433614467	4962	Economy	6000.00
0005432105416	4962	Economy	6000.00
0005432105414	4962	Economy	6000.00
0005433784846	4962	Economy	6000.00
0005432105399	4962	Economy	6000.00
0005432145106	4962	Economy	6000.00
0005433784815	4962	Economy	6000.00
0005433614451	4962	Economy	6000.00
0005433784834	4962	Economy	6000.00
0005432105417	4962	Economy	6000.00
0005432105432	4962	Economy	6000.00
0005433614460	4962	Economy	6000.00
0005433784847	4962	Economy	6000.00
0005433614472	4962	Economy	6000.00
0005433614436	4962	Economy	6000.00
0005433614470	4962	Economy	6000.00
0005433614503	4962	Economy	6000.00
0005433614487	4962	Economy	6000.00
0005433784824	4962	Economy	6000.00
0005433614498	4962	Economy	6000.00
0005432105445	4962	Economy	6000.00
0005433614434	4962	Economy	6000.00
0005433614477	4962	Economy	6000.00
0005433614494	4962	Economy	6000.00
0005433614473	4962	Economy	6000.00
0005433784839	4962	Economy	6000.00
0005433784844	4962	Economy	6000.00
0005432666381	4962	Economy	6000.00
0005433614484	4962	Economy	6000.00
0005432666382	4962	Economy	6000.00
0005433614502	4962	Economy	6000.00
0005434265049	4964	Business	18000.00
0005434149700	4964	Business	18000.00
0005435006731	4964	Business	18000.00
0005434229295	4964	Business	18000.00
0005435006770	4964	Business	18000.00
0005434265072	4964	Business	18000.00
0005435006687	4964	Business	18000.00
0005434149695	4964	Business	18000.00
0005434229297	4964	Business	18000.00
0005432335921	4964	Business	18000.00
0005435269656	4964	Business	18000.00
0005435269652	4964	Business	18000.00
0005434265053	4964	Business	18000.00
0005435006846	4964	Business	18000.00
0005434265047	4964	Business	18000.00
0005434265061	4964	Business	18000.00
0005435006790	4964	Business	18000.00
0005434149693	4964	Business	18000.00
0005435269670	4964	Business	18000.00
0005435006786	4964	Business	18000.00
0005434265064	4964	Economy	6600.00
0005434265046	4964	Economy	6600.00
0005434265062	4964	Economy	6600.00
0005432335922	4964	Economy	6600.00
0005432335932	4964	Economy	6600.00
0005434229309	4964	Economy	6000.00
0005433688782	4964	Economy	6000.00
0005434229296	4964	Economy	6000.00
0005434149689	4964	Economy	6000.00
0005435006707	4964	Economy	6000.00
0005434265068	4964	Economy	6000.00
0005434229307	4964	Economy	6000.00
0005434265055	4964	Economy	6000.00
0005434265059	4964	Economy	6000.00
0005434265057	4964	Economy	6000.00
0005435006715	4964	Economy	6000.00
0005432335904	4964	Economy	6000.00
0005435006791	4964	Economy	6000.00
0005434265054	4964	Economy	6000.00
0005434149697	4964	Economy	6000.00
0005434229293	4964	Economy	6000.00
0005434149694	4964	Economy	6000.00
0005434173508	4964	Economy	6000.00
0005434229292	4964	Economy	6000.00
0005434265048	4964	Economy	6000.00
0005434229310	4964	Economy	6000.00
0005434229290	4964	Economy	6000.00
0005434265045	4964	Economy	6000.00
0005434149699	4964	Economy	6000.00
0005434265070	4964	Economy	6000.00
0005434173509	4964	Economy	6000.00
0005435269669	4964	Economy	6000.00
0005432335934	4964	Economy	6000.00
0005434265065	4964	Economy	6000.00
0005434149690	4964	Economy	6000.00
0005434265056	4964	Economy	6000.00
0005434265071	4964	Economy	6000.00
0005435006673	4964	Economy	6000.00
0005434311202	4964	Economy	6000.00
0005433685498	4964	Economy	6000.00
0005435006735	4964	Economy	6000.00
0005435269657	4964	Economy	6000.00
0005432335902	4964	Economy	6000.00
0005435006733	4964	Economy	6000.00
0005434229301	4964	Economy	6000.00
0005434149698	4964	Economy	6000.00
0005435006763	4964	Economy	6000.00
0005434229305	4964	Economy	6000.00
0005434265069	4964	Economy	6000.00
0005433688783	4964	Economy	6600.00
0005434265050	4964	Economy	6600.00
0005433685493	4964	Economy	6600.00
0005432335862	4964	Economy	6600.00
0005434265058	4964	Economy	6600.00
0005434229300	4964	Economy	6000.00
0005435006783	4964	Economy	6000.00
0005434229289	4964	Economy	6000.00
0005434312292	4964	Economy	6600.00
0005434229311	4964	Economy	6000.00
0005432335903	4964	Economy	6000.00
0005435006771	4964	Economy	6000.00
0005434229302	4964	Economy	6000.00
0005435006751	4964	Economy	6000.00
0005434149691	4964	Economy	6000.00
0005434229291	4964	Economy	6000.00
0005434173506	4964	Economy	6000.00
0005435006617	4964	Economy	6000.00
0005434149692	4964	Economy	6000.00
0005435006785	4964	Economy	6000.00
0005434173507	4964	Economy	6000.00
0005433815346	4964	Economy	6000.00
0005434149696	4964	Economy	6000.00
0005434229308	4964	Economy	6000.00
0005435006736	4964	Economy	6000.00
0005434229312	4964	Economy	6000.00
0005433815345	4964	Economy	6000.00
0005434229306	4964	Economy	6000.00
0005435006732	4964	Economy	6000.00
0005435006616	4964	Economy	6000.00
0005435006716	4964	Economy	6000.00
0005434265060	4964	Economy	6000.00
0005435006841	4964	Economy	6000.00
0005432335933	4964	Economy	6000.00
0005434265051	4964	Economy	6000.00
0005434229303	4964	Economy	6000.00
0005434265052	4964	Economy	6000.00
0005432335884	4964	Economy	6000.00
0005434229299	4964	Economy	6000.00
0005434265063	4964	Economy	6000.00
0005434229298	4964	Economy	6000.00
0005433685499	4964	Economy	6000.00
0005434229294	4964	Economy	6000.00
0005434229304	4964	Economy	6000.00
0005435006840	4964	Economy	6000.00
0005434265066	4964	Economy	6000.00
0005435006711	4964	Economy	6000.00
0005435006734	4964	Economy	6000.00
0005435006889	4964	Economy	6000.00
0005434265067	4964	Economy	6000.00
0005434244582	8415	Business	18000.00
0005434244617	8415	Business	18000.00
0005434244680	8415	Business	18000.00
0005435269740	8415	Business	18000.00
0005433784573	8415	Business	18000.00
0005433784340	8415	Business	18000.00
0005433784556	8415	Business	18000.00
0005432659673	8415	Business	18000.00
0005434244782	8415	Business	18000.00
0005433784621	8415	Business	18000.00
0005433784529	8415	Business	18000.00
0005433784528	8415	Business	18000.00
0005433784622	8415	Business	18000.00
0005434244632	8415	Business	18000.00
0005433784567	8415	Business	18000.00
0005434244722	8415	Business	18000.00
0005433784571	8415	Economy	6600.00
0005433784542	8415	Economy	6600.00
0005433784639	8415	Economy	6600.00
0005434244530	8415	Economy	6000.00
0005433784451	8415	Economy	6000.00
0005435269742	8415	Economy	6000.00
0005434244651	8415	Economy	6000.00
0005434244700	8415	Economy	6000.00
0005433784568	8415	Economy	6000.00
0005433784467	8415	Economy	6000.00
0005432659681	8415	Economy	6000.00
0005434244590	8415	Economy	6000.00
0005433784638	8415	Economy	6000.00
0005434244503	8415	Economy	6000.00
0005434244677	8415	Economy	6000.00
0005434244813	8415	Economy	6000.00
0005434244781	8415	Economy	6000.00
0005433784399	8415	Economy	6000.00
0005433784551	8415	Economy	6000.00
0005435269736	8415	Economy	6000.00
0005433784499	8415	Economy	6000.00
0005433784566	8415	Economy	6000.00
0005433784662	8415	Economy	6000.00
0005433784697	8415	Economy	6000.00
0005433784468	8415	Economy	6000.00
0005433784518	8415	Economy	6000.00
0005435269744	8415	Economy	6000.00
0005434244570	8415	Economy	6000.00
0005433784630	8415	Economy	6000.00
0005434244656	8415	Economy	6000.00
0005433784460	8415	Economy	6000.00
0005432659680	8415	Economy	6000.00
0005433784661	8415	Economy	6000.00
0005433784461	8415	Economy	6000.00
0005433784503	8415	Economy	6600.00
0005433784520	8415	Economy	6600.00
0005434244616	8415	Economy	6600.00
0005435269741	8415	Economy	6600.00
0005433784519	8415	Economy	6000.00
0005434244559	8415	Economy	6000.00
0005435269743	8415	Economy	6600.00
0005434244787	8415	Economy	6000.00
0005432659676	8415	Economy	6000.00
0005433784477	8415	Economy	6000.00
0005434244774	8415	Economy	6000.00
0005433784406	8415	Economy	6000.00
0005434244665	8415	Economy	6000.00
0005434244611	8415	Economy	6000.00
0005433784484	8415	Economy	6000.00
0005434244618	8415	Economy	6000.00
0005435269739	8415	Economy	6000.00
0005433784466	8415	Economy	6000.00
0005434244610	8415	Economy	6000.00
0005434244646	8415	Economy	6000.00
0005433784620	8415	Economy	6000.00
0005435269738	8415	Economy	6000.00
0005433784576	8415	Economy	6000.00
0005433784533	8415	Economy	6000.00
0005434244712	8415	Economy	6000.00
0005433784631	8415	Economy	6000.00
0005433784572	8415	Economy	6000.00
0005434244721	8415	Economy	6000.00
0005435269745	8415	Economy	6000.00
0005433784428	8415	Economy	6000.00
0005433784581	8415	Economy	6000.00
0005434244786	8415	Economy	6000.00
0005434244627	8415	Economy	6000.00
0005434244699	8415	Economy	6000.00
0005433784605	8415	Economy	6000.00
0005433784554	8415	Economy	6000.00
0005435269737	8415	Economy	6000.00
0005433784469	8415	Economy	6000.00
0005432659675	8415	Economy	6000.00
0005433784471	8415	Economy	6000.00
0005433613600	8416	Business	18000.00
0005433613870	8416	Business	18000.00
0005433614020	8416	Business	18000.00
0005433613526	8416	Business	18000.00
0005433613879	8416	Business	18000.00
0005433613738	8416	Business	18000.00
0005433614098	8416	Business	18000.00
0005433613889	8416	Business	18000.00
0005433613963	8416	Business	18000.00
0005433613810	8416	Business	18000.00
0005433613743	8416	Business	18000.00
0005433613962	8416	Business	18000.00
0005433613544	8416	Business	18000.00
0005433613934	8416	Business	18000.00
0005433613729	8416	Business	18000.00
0005433613675	8416	Business	18000.00
0005433613831	8416	Economy	6600.00
0005433613927	8416	Business	18000.00
0005433613878	8416	Economy	6600.00
0005433614133	8416	Economy	6600.00
0005433613668	8416	Economy	6600.00
0005433613764	8416	Economy	6600.00
0005433613758	8416	Economy	6000.00
0005433613812	8416	Economy	6000.00
0005433613599	8416	Economy	6000.00
0005433613944	8416	Economy	6000.00
0005433613745	8416	Economy	6000.00
0005433613837	8416	Economy	6000.00
0005433613936	8416	Economy	6000.00
0005433613867	8416	Economy	6000.00
0005433613838	8416	Economy	6000.00
0005433613839	8416	Economy	6000.00
0005433613811	8416	Economy	6000.00
0005433613805	8416	Economy	6000.00
0005433613467	8416	Economy	6000.00
0005433613818	8416	Economy	6000.00
0005433613820	8416	Economy	6000.00
0005433613661	8416	Economy	6000.00
0005433613978	8416	Economy	6000.00
0005433614024	8416	Economy	6000.00
0005433613977	8416	Economy	6000.00
0005433613583	8416	Economy	6000.00
0005433613631	8416	Economy	6000.00
0005433613886	8416	Economy	6000.00
0005433613570	8416	Economy	6000.00
0005433614134	8416	Economy	6000.00
0005433613969	8416	Economy	6000.00
0005433613589	8416	Economy	6000.00
0005433613868	8416	Economy	6000.00
0005433614026	8416	Economy	6000.00
0005433613478	8416	Economy	6000.00
0005433613436	8416	Economy	6600.00
0005433614025	8416	Economy	6600.00
0005433613616	8416	Economy	6600.00
0005433613554	8416	Economy	6000.00
0005433613828	8416	Economy	6600.00
0005433613617	8416	Economy	6000.00
0005433613590	8416	Economy	6000.00
0005433613802	8416	Economy	6000.00
0005433613739	8416	Economy	6000.00
0005433613612	8416	Economy	6000.00
0005433613813	8416	Economy	6000.00
0005433613761	8416	Economy	6000.00
0005433614033	8416	Economy	6000.00
0005433613674	8416	Economy	6000.00
0005433613671	8416	Economy	6000.00
0005433614032	8416	Economy	6000.00
0005433613785	8416	Economy	6000.00
0005433613410	8416	Economy	6000.00
0005433613801	8416	Economy	6000.00
0005433613842	8416	Economy	6000.00
0005433613844	8416	Economy	6000.00
0005433613728	8416	Economy	6000.00
0005433613571	8416	Economy	6000.00
0005433613611	8416	Economy	6000.00
0005433613935	8416	Economy	6000.00
0005433613911	8416	Economy	6000.00
0005433613632	8416	Economy	6000.00
0005433613926	8416	Economy	6000.00
0005433613928	8416	Economy	6000.00
0005433613845	8416	Economy	6000.00
0005433614097	8416	Economy	6000.00
0005433613740	8416	Economy	6000.00
0005433613691	8416	Economy	6000.00
0005432034872	8417	Business	18000.00
0005434264868	8417	Business	18000.00
0005434229017	8417	Business	18000.00
0005434149546	8417	Business	18000.00
0005434173465	8417	Business	18000.00
0005435006955	8417	Business	18000.00
0005432047538	8417	Business	18000.00
0005434264886	8417	Business	18000.00
0005432034870	8417	Business	18000.00
0005434264854	8417	Business	18000.00
0005432034861	8417	Business	18000.00
0005434229116	8417	Business	18000.00
0005432047542	8417	Business	18000.00
0005435006967	8417	Business	18000.00
0005434264763	8417	Business	18000.00
0005434229099	8417	Business	18000.00
0005432047539	8417	Business	18000.00
0005434149601	8417	Business	18000.00
0005435006962	8417	Business	18000.00
0005435006957	8417	Business	18000.00
0005432034853	8417	Business	18000.00
0005434229059	8417	Business	18000.00
0005432034859	8417	Business	18000.00
0005434149647	8417	Business	18000.00
0005435006953	8417	Business	18000.00
0005433688802	8417	Economy	6600.00
0005434229084	8417	Economy	6600.00
0005435286609	8417	Economy	6600.00
0005435006952	8417	Economy	6600.00
0005434229086	8417	Economy	6600.00
0005434229018	8417	Economy	6000.00
0005432034855	8417	Economy	6000.00
0005433689905	8417	Economy	6000.00
0005432034854	8417	Economy	6000.00
0005435006960	8417	Economy	6000.00
0005434264790	8417	Economy	6000.00
0005435006945	8417	Economy	6000.00
0005434229117	8417	Economy	6000.00
0005434264747	8417	Economy	6000.00
0005435006961	8417	Economy	6000.00
0005434264824	8417	Economy	6000.00
0005432034871	8417	Economy	6000.00
0005434264899	8417	Economy	6000.00
0005432034868	8417	Economy	6000.00
0005434149604	8417	Economy	6000.00
0005434229112	8417	Economy	6000.00
0005435006964	8417	Economy	6000.00
0005432034873	8417	Economy	6000.00
0005432336004	8417	Economy	6000.00
0005434229132	8417	Economy	6000.00
0005435006965	8417	Economy	6000.00
0005433815370	8417	Economy	6000.00
0005434264883	8417	Economy	6000.00
0005434229068	8417	Economy	6000.00
0005435006947	8417	Economy	6000.00
0005434264855	8417	Economy	6000.00
0005432034850	8417	Economy	6000.00
0005434229111	8417	Economy	6000.00
0005434173461	8417	Economy	6000.00
0005432047540	8417	Economy	6000.00
0005434264874	8417	Economy	6000.00
0005435006950	8417	Economy	6000.00
0005434229085	8417	Economy	6000.00
0005434264820	8417	Economy	6000.00
0005432034862	8417	Economy	6000.00
0005432335996	8417	Economy	6000.00
0005434149592	8417	Economy	6000.00
0005432034857	8417	Economy	6000.00
0005432047537	8417	Economy	6000.00
0005433815372	8417	Economy	6000.00
0005435006951	8417	Economy	6000.00
0005434264832	8417	Economy	6000.00
0005432336001	8417	Economy	6000.00
0005434173474	8417	Economy	6000.00
0005432034852	8417	Economy	6000.00
0005434264799	8417	Economy	6000.00
0005434264844	8417	Economy	6000.00
0005433688803	8417	Economy	6000.00
0005434264800	8417	Economy	6000.00
0005435006946	8417	Economy	6000.00
0005434149554	8417	Economy	6000.00
0005434264885	8417	Economy	6000.00
0005434149591	8417	Economy	6600.00
0005434149570	8417	Economy	6600.00
0005435286608	8417	Economy	6600.00
0005433815371	8417	Economy	6000.00
0005432034851	8417	Economy	6000.00
0005434149602	8417	Economy	6000.00
0005434229098	8417	Economy	6000.00
0005432335998	8417	Economy	6600.00
0005434149545	8417	Economy	6000.00
0005432034860	8417	Economy	6000.00
0005432336002	8417	Economy	6000.00
0005434149631	8417	Economy	6000.00
0005435286611	8417	Economy	6000.00
0005434264823	8417	Economy	6000.00
0005435006958	8417	Economy	6000.00
0005435006949	8417	Economy	6000.00
0005432335999	8417	Economy	6000.00
0005435286606	8417	Economy	6000.00
0005434229050	8417	Economy	6000.00
0005435006948	8417	Economy	6000.00
0005432034864	8417	Economy	6000.00
0005434229127	8417	Economy	6000.00
0005432034856	8417	Economy	6000.00
0005435286614	8417	Economy	6000.00
0005435006959	8417	Economy	6000.00
0005434229105	8417	Economy	6000.00
0005434229051	8417	Economy	6000.00
0005432335994	8417	Economy	6000.00
0005434229150	8417	Economy	6000.00
0005434264889	8417	Economy	6000.00
0005432034875	8417	Economy	6000.00
0005435006966	8417	Economy	6000.00
0005432034867	8417	Economy	6000.00
0005434311212	8417	Economy	6000.00
0005434149544	8417	Economy	6000.00
0005435286613	8417	Economy	6000.00
0005432034863	8417	Economy	6000.00
0005432047541	8417	Economy	6000.00
0005435286607	8417	Economy	6000.00
0005434229195	8417	Economy	6000.00
0005432034858	8417	Economy	6000.00
0005435006963	8417	Economy	6000.00
0005432335995	8417	Economy	6000.00
0005435286612	8417	Economy	6000.00
0005435006954	8417	Economy	6000.00
0005434229019	8417	Economy	6000.00
0005434264869	8417	Economy	6000.00
0005435006956	8417	Economy	6000.00
0005432336003	8417	Economy	6000.00
0005434173460	8417	Economy	6000.00
0005434311213	8417	Economy	6000.00
0005433815373	8417	Economy	6000.00
0005432034865	8417	Economy	6000.00
0005435286610	8417	Economy	6000.00
0005435006944	8417	Economy	6000.00
0005433534492	8417	Economy	6000.00
0005434264907	8417	Economy	6000.00
0005434264826	8417	Economy	6000.00
0005432335997	8417	Economy	6000.00
0005433534491	8417	Economy	6000.00
0005432034866	8417	Economy	6000.00
0005432336000	8417	Economy	6000.00
0005432034874	8417	Economy	6000.00
0005434149608	8417	Economy	6000.00
0005432034869	8417	Economy	6000.00
0005435006968	8417	Economy	6000.00
0005435286605	8417	Economy	6000.00
0005434173466	8417	Economy	6000.00
0005433202325	12620	Economy	16200.00
0005434638928	12620	Economy	16200.00
0005434638986	12620	Economy	16200.00
0005434639000	12620	Economy	14800.00
0005434638993	12620	Economy	14800.00
0005433202320	12620	Economy	14800.00
0005434638987	12620	Economy	14800.00
0005434639066	12620	Economy	14800.00
0005433202321	12620	Economy	14800.00
0005434638990	12620	Economy	14800.00
0005434639072	12620	Economy	14800.00
0005434638942	12620	Economy	14800.00
0005434638946	12620	Economy	14800.00
0005434639065	12620	Economy	14800.00
0005433202316	12620	Economy	14800.00
0005433202322	12620	Economy	14800.00
0005433202318	12620	Economy	14800.00
0005434638979	12620	Economy	14800.00
0005434638889	12620	Economy	14800.00
0005434638943	12620	Economy	14800.00
0005434638978	12620	Economy	14800.00
0005434639001	12620	Economy	14800.00
0005434639099	12620	Economy	14800.00
0005433202328	12620	Economy	14800.00
0005434638929	12620	Economy	14800.00
0005434639119	12620	Economy	14800.00
0005433202313	12620	Economy	14800.00
0005434639057	12620	Economy	14800.00
0005434639019	12620	Economy	14800.00
0005434639034	12620	Economy	14800.00
0005433202319	12620	Economy	14800.00
0005434639010	12620	Economy	14800.00
0005433202324	12620	Economy	14800.00
0005433202326	12620	Economy	14800.00
0005433202323	12620	Economy	14800.00
0005434639027	12620	Economy	14800.00
0005433202327	12620	Economy	14800.00
0005433202317	12620	Economy	14800.00
0005433202315	12620	Economy	14800.00
0005434639120	12620	Economy	14800.00
0005433202314	12620	Economy	14800.00
0005434639049	12620	Economy	14800.00
0005434639234	23398	Economy	16200.00
0005433202154	23398	Economy	16200.00
0005433202162	23398	Economy	16200.00
0005434639215	23398	Economy	16200.00
0005434639223	23398	Economy	14800.00
0005434639227	23398	Economy	14800.00
0005433202213	23398	Economy	14800.00
0005434639213	23398	Economy	14800.00
0005432290621	23398	Economy	14800.00
0005434639218	23398	Economy	14800.00
0005433202188	23398	Economy	14800.00
0005434639236	23398	Economy	14800.00
0005433202147	23398	Economy	14800.00
0005434639231	23398	Economy	14800.00
0005433202187	23398	Economy	14800.00
0005433202215	23398	Economy	14800.00
0005434639217	23398	Economy	14800.00
0005434639224	23398	Economy	14800.00
0005434639214	23398	Economy	14800.00
0005434639219	23398	Economy	14800.00
0005432290622	23398	Economy	14800.00
0005433202155	23398	Economy	14800.00
0005434639233	23398	Economy	14800.00
0005434639225	23398	Economy	14800.00
0005434639221	23398	Economy	14800.00
0005434639229	23398	Economy	14800.00
0005434639235	23398	Economy	14800.00
0005433202144	23398	Economy	14800.00
0005432290620	23398	Economy	14800.00
0005434639237	23398	Economy	14800.00
0005434639228	23398	Economy	14800.00
0005433202189	23398	Economy	14800.00
0005434639232	23398	Economy	14800.00
0005433202238	23398	Economy	14800.00
0005433202206	23398	Economy	14800.00
0005434639211	23398	Economy	14800.00
0005434639226	23398	Economy	14800.00
0005433202237	23398	Economy	14800.00
0005434639230	23398	Economy	14800.00
0005433202170	23398	Economy	14800.00
0005433202211	23398	Economy	14800.00
0005434639222	23398	Economy	14800.00
0005433202212	23398	Economy	14800.00
0005434639220	23398	Economy	14800.00
0005433202148	23398	Economy	14800.00
0005434639216	23398	Economy	14800.00
0005433202145	23398	Economy	14800.00
0005433202161	23398	Economy	14800.00
0005434639212	23398	Economy	14800.00
0005432327985	21057	Business	18900.00
0005432328218	21057	Business	18900.00
0005432382574	21057	Business	18900.00
0005432328142	21057	Business	18900.00
0005432382841	21057	Business	18900.00
0005432328127	21057	Business	18900.00
0005432382701	21057	Business	18900.00
0005432328295	21057	Business	18900.00
0005432382569	21057	Business	18900.00
0005432328367	21057	Business	18900.00
0005432382604	21057	Business	18900.00
0005432328087	21057	Economy	6300.00
0005432382659	21057	Economy	6300.00
0005432328145	21057	Economy	6300.00
0005432382554	21057	Economy	6300.00
0005432382737	21057	Economy	6300.00
0005432054295	21057	Economy	6300.00
0005432382819	21057	Economy	6300.00
0005432382552	21057	Economy	6300.00
0005432382723	21057	Economy	6300.00
0005432328316	21057	Economy	6300.00
0005432328269	21057	Economy	6900.00
0005432328125	21057	Economy	6900.00
0005432382630	21057	Economy	6900.00
0005432382716	21057	Economy	6900.00
0005432328037	21057	Economy	6900.00
0005432327943	21057	Economy	6300.00
0005432328093	21057	Economy	6300.00
0005432328038	21057	Economy	6300.00
0005432382660	21057	Economy	6300.00
0005432382542	21057	Economy	6300.00
0005432382553	21057	Economy	6300.00
0005432382717	21057	Economy	6300.00
0005432328059	21057	Economy	6300.00
0005432328211	21057	Economy	6300.00
0005432328115	21057	Economy	6300.00
0005432328309	21057	Economy	6300.00
0005432054294	21057	Economy	6300.00
0005432382758	21057	Economy	6300.00
0005432328085	21057	Economy	6300.00
0005432328250	21057	Economy	6300.00
0005432382623	21057	Economy	6300.00
0005432382840	21057	Economy	6300.00
0005432382675	21057	Economy	6300.00
0005432382839	21057	Economy	6300.00
0005432382679	21057	Economy	6300.00
0005432382674	21057	Economy	6300.00
0005432382627	21057	Economy	6300.00
0005432328069	21057	Economy	6300.00
0005432328150	21057	Economy	6300.00
0005432382836	21057	Economy	6300.00
0005432382632	21057	Economy	6300.00
0005432328098	21057	Economy	6300.00
0005432328068	21057	Economy	6300.00
0005432328248	21057	Economy	6300.00
0005432328126	21057	Economy	6300.00
0005432382650	21057	Economy	6300.00
0005432328148	21057	Economy	6300.00
0005432382727	21057	Economy	6300.00
0005432327996	21057	Economy	6300.00
0005432382774	21057	Economy	6300.00
0005432382631	21057	Economy	6300.00
0005432382543	21057	Economy	6300.00
0005432328163	21057	Economy	6300.00
0005432382871	21057	Economy	6300.00
0005432328149	21057	Economy	6300.00
0005432054296	21057	Economy	6300.00
0005432328182	21057	Economy	6300.00
0005432382658	21057	Economy	6300.00
0005432382686	21057	Economy	6300.00
0005432328246	21057	Economy	6300.00
0005432328245	21057	Economy	6300.00
0005432382540	21057	Economy	6300.00
0005432382703	21057	Economy	6300.00
0005432328114	21057	Economy	6300.00
0005432382685	21057	Economy	6300.00
0005432382568	21057	Economy	6300.00
0005432327942	21057	Economy	6300.00
0005432382697	21057	Economy	6300.00
0005432382603	21057	Economy	6300.00
0005432382608	21057	Economy	6300.00
0005432382704	21057	Economy	6300.00
0005432328144	21057	Economy	6300.00
0005432382602	21057	Economy	6300.00
0005432328099	21057	Economy	6300.00
0005432328141	21057	Economy	6300.00
0005432327947	21057	Economy	6300.00
0005432382628	21057	Economy	6300.00
0005432382705	21057	Economy	6300.00
0005432328249	21057	Economy	6300.00
0005432328504	31241	Business	18900.00
0005432383028	31241	Business	18900.00
0005432383048	31241	Business	18900.00
0005432383044	31241	Business	18900.00
0005432383042	31241	Business	18900.00
0005432328542	31241	Business	18900.00
0005432383017	31241	Business	18900.00
0005432328543	31241	Business	18900.00
0005432328518	31241	Business	18900.00
0005432328514	31241	Business	18900.00
0005432383029	31241	Business	18900.00
0005432328531	31241	Business	18900.00
0005432383050	31241	Economy	6300.00
0005432328524	31241	Economy	6300.00
0005432328527	31241	Economy	6300.00
0005432328544	31241	Economy	6300.00
0005432328517	31241	Economy	6300.00
0005432328526	31241	Economy	6300.00
0005432383019	31241	Economy	6300.00
0005432328511	31241	Economy	6300.00
0005432328536	31241	Economy	6300.00
0005432328523	31241	Economy	6300.00
0005432328509	31241	Economy	6900.00
0005432328530	31241	Economy	6900.00
0005432287171	31241	Economy	6900.00
0005432383052	31241	Economy	6900.00
0005432287170	31241	Economy	6900.00
0005432328503	31241	Economy	6300.00
0005432328529	31241	Economy	6300.00
0005432328501	31241	Economy	6300.00
0005432328548	31241	Economy	6300.00
0005432383013	31241	Economy	6300.00
0005432383025	31241	Economy	6300.00
0005432383024	31241	Economy	6300.00
0005432328535	31241	Economy	6300.00
0005432328513	31241	Economy	6300.00
0005432383056	31241	Economy	6300.00
0005432383016	31241	Economy	6300.00
0005432383040	31241	Economy	6300.00
0005432328515	31241	Economy	6300.00
0005432383047	31241	Economy	6300.00
0005432328521	31241	Economy	6300.00
0005432328505	31241	Economy	6300.00
0005432328547	31241	Economy	6300.00
0005432328528	31241	Economy	6300.00
0005432383053	31241	Economy	6300.00
0005432383035	31241	Economy	6300.00
0005432328520	31241	Economy	6300.00
0005432328533	31241	Economy	6300.00
0005432383037	31241	Economy	6300.00
0005432328510	31241	Economy	6300.00
0005432383027	31241	Economy	6300.00
0005432383045	31241	Economy	6300.00
0005432328532	31241	Economy	6300.00
0005432328537	31241	Economy	6300.00
0005432383034	31241	Economy	6300.00
0005432383033	31241	Economy	6300.00
0005432383036	31241	Economy	6300.00
0005432287168	31241	Economy	6300.00
0005432383026	31241	Economy	6300.00
0005432328540	31241	Economy	6300.00
0005432383023	31241	Economy	6300.00
0005432328541	31241	Economy	6300.00
0005432383038	31241	Economy	6300.00
0005432383046	31241	Economy	6300.00
0005432383051	31241	Economy	6300.00
0005432383041	31241	Economy	6300.00
0005432383022	31241	Economy	6300.00
0005432328516	31241	Economy	6300.00
0005432328519	31241	Economy	6300.00
0005432328507	31241	Economy	6300.00
0005432383043	31241	Economy	6300.00
0005432328506	31241	Economy	6300.00
0005432383054	31241	Economy	6300.00
0005432383039	31241	Economy	6300.00
0005432383055	31241	Economy	6300.00
0005432383049	31241	Economy	6300.00
0005432383031	31241	Economy	6300.00
0005432287169	31241	Economy	6300.00
0005432328525	31241	Economy	6300.00
0005432383032	31241	Economy	6300.00
0005432328546	31241	Economy	6300.00
0005432383030	31241	Economy	6300.00
0005432328522	31241	Economy	6300.00
0005432328534	31241	Economy	6300.00
0005432328508	31241	Economy	6300.00
0005432383020	31241	Economy	6300.00
0005432328549	31241	Economy	6300.00
0005432328545	31241	Economy	6300.00
0005432383014	31241	Economy	6300.00
0005432383018	31241	Economy	6300.00
0005432328502	31241	Economy	6300.00
0005432383015	31241	Economy	6300.00
0005432328512	31241	Economy	6300.00
0005432328538	31241	Economy	6300.00
0005432328539	31241	Economy	6300.00
0005432383021	31241	Economy	6300.00
0005433642279	2479	Business	89600.00
0005433642286	2479	Business	89600.00
0005432953840	2479	Business	89600.00
0005433642275	2479	Business	89600.00
0005433642265	2479	Business	89600.00
0005433642291	2479	Economy	29900.00
0005433642273	2479	Economy	29900.00
0005433642276	2479	Economy	29900.00
0005433642267	2479	Economy	29900.00
0005432953863	2479	Economy	29900.00
0005433642274	2479	Economy	29900.00
0005433642294	2479	Economy	32800.00
0005433642295	2479	Economy	32800.00
0005433642302	2479	Economy	32800.00
0005433642280	2479	Economy	29900.00
0005432953827	2479	Economy	29900.00
0005433642290	2479	Economy	29900.00
0005433642293	2479	Economy	29900.00
0005432953822	2479	Economy	29900.00
0005433642297	2479	Economy	29900.00
0005433642287	2479	Economy	29900.00
0005432953862	2479	Economy	29900.00
0005433642260	2479	Economy	29900.00
0005433642269	2479	Economy	29900.00
0005433642261	2479	Economy	29900.00
0005432953830	2479	Economy	29900.00
0005433642300	2479	Economy	29900.00
0005433642292	2479	Economy	29900.00
0005433642284	2479	Economy	29900.00
0005432953823	2479	Economy	29900.00
0005433642282	2479	Economy	29900.00
0005433642289	2479	Economy	29900.00
0005432953841	2479	Economy	29900.00
0005433642278	2479	Economy	29900.00
0005433642271	2479	Economy	29900.00
0005432953836	2479	Economy	29900.00
0005433642283	2479	Economy	29900.00
0005433642301	2479	Economy	29900.00
0005433642296	2479	Economy	29900.00
0005432953834	2479	Economy	29900.00
0005432953829	2479	Economy	29900.00
0005433642303	2479	Economy	29900.00
0005432953832	2479	Economy	29900.00
0005433642285	2479	Economy	29900.00
0005433642264	2479	Economy	29900.00
0005433642270	2479	Economy	29900.00
0005432953818	2479	Economy	29900.00
0005433642268	2479	Economy	29900.00
0005432953835	2479	Economy	29900.00
0005433642299	2479	Economy	29900.00
0005433642277	2479	Economy	29900.00
0005433642258	2479	Economy	29900.00
0005432953828	2479	Economy	29900.00
0005432953821	2479	Economy	29900.00
0005433642266	2479	Economy	29900.00
0005433642263	2479	Economy	29900.00
0005432953849	2479	Economy	29900.00
0005433642281	2479	Economy	29900.00
0005433642288	2479	Economy	29900.00
0005433642272	2479	Economy	29900.00
0005433642262	2479	Economy	29900.00
0005433642298	2479	Economy	29900.00
0005433642259	2479	Economy	29900.00
0005432424263	13277	Business	12700.00
0005432424235	13277	Business	12700.00
0005432424232	13277	Business	12700.00
0005432424250	13277	Business	12700.00
0005432424234	13277	Business	12700.00
0005432424268	13277	Business	12700.00
0005432424237	13277	Economy	4200.00
0005432424242	13277	Economy	4200.00
0005432424245	13277	Economy	4700.00
0005432424258	13277	Economy	4700.00
0005432424248	13277	Economy	4200.00
0005432424261	13277	Economy	4200.00
0005432424255	13277	Economy	4200.00
0005432424256	13277	Economy	4200.00
0005432424231	13277	Economy	4200.00
0005432424247	13277	Economy	4200.00
0005432424238	13277	Economy	4200.00
0005432424241	13277	Economy	4200.00
0005432424260	13277	Economy	4200.00
0005432424252	13277	Economy	4200.00
0005432424239	13277	Economy	4200.00
0005432424251	13277	Economy	4200.00
0005432424253	13277	Economy	4200.00
0005432424266	13277	Economy	4200.00
0005432424265	13277	Economy	4200.00
0005432424262	13277	Economy	4200.00
0005432424233	13277	Economy	4200.00
0005432424243	13277	Economy	4200.00
0005432424249	13277	Economy	4200.00
0005432424244	13277	Economy	4200.00
0005432424259	13277	Economy	4200.00
0005432424236	13277	Economy	4200.00
0005432424267	13277	Economy	4200.00
0005432424246	13277	Economy	4200.00
0005432424264	13277	Economy	4200.00
0005432424257	13277	Economy	4200.00
0005432424240	13277	Economy	4200.00
0005432424254	13277	Economy	4200.00
0005432423923	30756	Business	12700.00
0005432423841	30756	Business	12700.00
0005432423825	30756	Business	12700.00
0005432423839	30756	Business	12700.00
0005432423792	30756	Business	12700.00
0005432423849	30756	Business	12700.00
0005432423742	30756	Business	12700.00
0005432423887	30756	Business	12700.00
0005432423797	30756	Economy	4200.00
0005432423847	30756	Economy	4200.00
0005432423890	30756	Economy	4200.00
0005432423891	30756	Economy	4200.00
0005432423913	30756	Economy	4200.00
0005432423715	30756	Economy	4200.00
0005432423927	30756	Economy	4200.00
0005432423882	30756	Economy	4200.00
0005432423842	30756	Economy	4700.00
0005432423886	30756	Economy	4700.00
0005432423888	30756	Economy	4700.00
0005432423862	30756	Economy	4700.00
0005432423821	30756	Economy	4200.00
0005432423806	30756	Economy	4200.00
0005432423793	30756	Economy	4200.00
0005432423840	30756	Economy	4200.00
0005432423676	30756	Economy	4200.00
0005432423868	30756	Economy	4200.00
0005432423835	30756	Economy	4200.00
0005432423935	30756	Economy	4200.00
0005432423848	30756	Economy	4200.00
0005432423867	30756	Economy	4200.00
0005432423822	30756	Economy	4200.00
0005432423834	30756	Economy	4200.00
0005432423892	30756	Economy	4200.00
0005432423820	30756	Economy	4200.00
0005432423905	30756	Economy	4200.00
0005432423807	30756	Economy	4200.00
0005432423823	30756	Economy	4200.00
0005432423794	30756	Economy	4200.00
0005432423685	30756	Economy	4200.00
0005432423907	30756	Economy	4200.00
0005432423924	30756	Economy	4200.00
0005432423830	30756	Economy	4200.00
0005432423926	30756	Economy	4200.00
0005432423889	30756	Economy	4200.00
0005432423863	30756	Economy	4200.00
0005432423704	30756	Economy	4200.00
0005432423883	30756	Economy	4200.00
0005432423948	30756	Economy	4200.00
0005432423925	30756	Economy	4200.00
0005432423904	30756	Economy	4200.00
0005432423931	30756	Economy	4200.00
0005432423906	30756	Economy	4200.00
0005432423829	30756	Economy	4200.00
0005432423885	30756	Economy	4200.00
0005434157367	9580	Business	32600.00
0005432901410	9580	Business	32600.00
0005432901353	9580	Business	32600.00
0005432817364	9580	Business	32600.00
0005432817372	9580	Business	32600.00
0005432817379	9580	Business	32600.00
0005432822181	9580	Business	32600.00
0005432817384	9580	Business	32600.00
0005432288976	9580	Business	32600.00
0005434157420	9580	Economy	10900.00
0005434186168	9580	Economy	10900.00
0005434448305	9580	Economy	10900.00
0005432817381	9580	Economy	10900.00
0005432822177	9580	Economy	10900.00
0005434157365	9580	Economy	10900.00
0005432822182	9580	Economy	10900.00
0005432817369	9580	Economy	10900.00
0005432901501	9580	Economy	10900.00
0005432817378	9580	Economy	10900.00
0005432817374	9580	Economy	10900.00
0005432901407	9580	Economy	10900.00
0005434448306	9580	Economy	10900.00
0005432817392	9580	Economy	10900.00
0005432817393	9580	Economy	10900.00
0005432817375	9580	Economy	10900.00
0005432817377	9580	Economy	10900.00
0005432288978	9580	Economy	10900.00
0005434157391	9580	Economy	10900.00
0005432817385	9580	Economy	10900.00
0005432817386	9580	Economy	10900.00
0005432288974	9580	Economy	10900.00
0005432817387	9580	Economy	10900.00
0005432817388	9580	Economy	10900.00
0005432817363	9580	Economy	10900.00
0005432817383	9580	Economy	10900.00
0005434157387	9580	Economy	10900.00
0005432288975	9580	Economy	10900.00
0005432817391	9580	Economy	10900.00
0005432817365	9580	Economy	10900.00
0005432822176	9580	Economy	10900.00
0005434157375	9580	Economy	10900.00
0005432817390	9580	Economy	10900.00
0005432288977	9580	Economy	10900.00
0005432817368	9580	Economy	10900.00
0005432901373	9580	Economy	10900.00
0005432817380	9580	Economy	10900.00
0005432822179	9580	Economy	10900.00
0005432822180	9580	Economy	10900.00
0005432817367	9580	Economy	10900.00
0005434157390	9580	Economy	10900.00
0005432901463	9580	Economy	10900.00
0005432901417	9580	Economy	10900.00
0005434157366	9580	Economy	10900.00
0005432817376	9580	Economy	10900.00
0005432901406	9580	Economy	10900.00
0005432901379	9580	Economy	10900.00
0005432817382	9580	Economy	10900.00
0005434157398	9580	Economy	10900.00
0005432901403	9580	Economy	10900.00
0005432901418	9580	Economy	10900.00
0005432817373	9580	Economy	10900.00
0005432901366	9580	Economy	10900.00
0005432822178	9580	Economy	10900.00
0005432817371	9580	Economy	10900.00
0005432817370	9580	Economy	10900.00
0005432817389	9580	Economy	10900.00
0005434448304	9580	Economy	10900.00
0005432817366	9580	Economy	10900.00
0005434157460	28990	Business	32600.00
0005432822095	28990	Business	32600.00
0005434186188	28990	Business	32600.00
0005432817244	28990	Business	32600.00
0005432817274	28990	Business	32600.00
0005432901547	28990	Business	32600.00
0005432817077	28990	Business	32600.00
0005434157459	28990	Economy	10900.00
0005432817079	28990	Economy	10900.00
0005432817089	28990	Economy	10900.00
0005432817102	28990	Economy	10900.00
0005432901557	28990	Economy	10900.00
0005432901553	28990	Economy	10900.00
0005432901554	28990	Economy	10900.00
0005434157454	28990	Economy	10900.00
0005434157456	28990	Economy	10900.00
0005432817273	28990	Economy	11900.00
0005432901562	28990	Economy	11900.00
0005432817080	28990	Economy	11900.00
0005434157453	28990	Economy	10900.00
0005432817110	28990	Economy	10900.00
0005432817101	28990	Economy	10900.00
0005432002068	28990	Economy	10900.00
0005432817036	28990	Economy	10900.00
0005432901560	28990	Economy	10900.00
0005432901548	28990	Economy	10900.00
0005432822111	28990	Economy	10900.00
0005432817197	28990	Economy	10900.00
0005434448285	28990	Economy	10900.00
0005432822108	28990	Economy	10900.00
0005432822112	28990	Economy	10900.00
0005432817117	28990	Economy	10900.00
0005432817198	28990	Economy	10900.00
0005432817106	28990	Economy	10900.00
0005432817246	28990	Economy	10900.00
0005432817219	28990	Economy	10900.00
0005434157457	28990	Economy	10900.00
0005432901551	28990	Economy	10900.00
0005434157458	28990	Economy	10900.00
0005432822130	28990	Economy	10900.00
0005432817076	28990	Economy	10900.00
0005432901550	28990	Economy	10900.00
0005432817138	28990	Economy	10900.00
0005432817105	28990	Economy	10900.00
0005432817075	28990	Economy	10900.00
0005432901559	28990	Economy	10900.00
0005432822097	28990	Economy	10900.00
0005432817119	28990	Economy	10900.00
0005432817245	28990	Economy	10900.00
0005432002069	28990	Economy	10900.00
0005434448266	28990	Economy	10900.00
0005432822096	28990	Economy	10900.00
0005434186187	28990	Economy	10900.00
0005432817074	28990	Economy	10900.00
0005432901563	28990	Economy	10900.00
0005434448275	28990	Economy	10900.00
0005432822114	28990	Economy	10900.00
0005434157455	28990	Economy	10900.00
0005432901552	28990	Economy	10900.00
0005434157452	28990	Economy	10900.00
0005432901561	28990	Economy	10900.00
0005432901549	28990	Economy	10900.00
0005432901558	28990	Economy	10900.00
0005432901546	28990	Economy	10900.00
0005434448273	28990	Economy	10900.00
0005434448276	28990	Economy	10900.00
0005432822113	28990	Economy	10900.00
0005434448286	28990	Economy	10900.00
0005432901555	28990	Economy	10900.00
0005432901556	28990	Economy	10900.00
0005432822140	28990	Economy	10900.00
0005432822080	28990	Economy	10900.00
0005432822115	28990	Economy	10900.00
0005432002070	28990	Economy	10900.00
0005434448274	28990	Economy	10900.00
0005432817103	28990	Economy	10900.00
0005432817113	28990	Economy	10900.00
0005432817078	28990	Economy	10900.00
0005432822116	28990	Economy	10900.00
0005432611697	15089	Economy	11000.00
0005432611699	15089	Economy	11000.00
0005432611696	15089	Economy	11000.00
0005432613848	15089	Economy	11000.00
0005432613849	15089	Economy	11000.00
0005432611698	15089	Economy	11000.00
0005432613847	15089	Economy	11000.00
0005432613850	15089	Economy	11000.00
0005432611674	31618	Economy	11000.00
0005432607508	31618	Economy	11000.00
0005432611660	31618	Economy	11000.00
0005432611654	31618	Economy	11000.00
0005432611673	31618	Economy	11000.00
0005432607521	31618	Economy	11000.00
0005432607518	31618	Economy	11000.00
0005432611657	31618	Economy	11000.00
0005432607509	31618	Economy	11000.00
0005432607507	31618	Economy	11000.00
0005432611688	31618	Economy	11000.00
0005432611659	31618	Economy	11000.00
0005433568848	11877	Business	105900.00
0005433568809	11877	Business	105900.00
0005432947945	11877	Business	105900.00
0005433568847	11877	Business	105900.00
0005433568866	11877	Business	105900.00
0005433568836	11877	Business	105900.00
0005433568867	11877	Business	105900.00
0005433568857	11877	Business	105900.00
0005433568807	11877	Business	105900.00
0005433568859	11877	Business	105900.00
0005433568821	11877	Business	105900.00
0005433568808	11877	Business	105900.00
0005432947897	11877	Business	105900.00
0005433568823	11877	Business	105900.00
0005432948131	11877	Business	105900.00
0005433568863	11877	Business	105900.00
0005433568840	11877	Business	105900.00
0005432947944	11877	Business	105900.00
0005432947982	11877	Business	105900.00
0005433568814	11877	Economy	35300.00
0005433568829	11877	Economy	35300.00
0005433568819	11877	Economy	35300.00
0005433568851	11877	Economy	35300.00
0005432948066	11877	Economy	35300.00
0005432948031	11877	Economy	35300.00
0005433568854	11877	Economy	35300.00
0005432947898	11877	Economy	35300.00
0005433568835	11877	Economy	35300.00
0005432948087	11877	Economy	35300.00
0005433568838	11877	Economy	35300.00
0005432947809	11877	Economy	35300.00
0005432947964	11877	Economy	38800.00
0005433568844	11877	Economy	38800.00
0005433568842	11877	Economy	38800.00
0005432947877	11877	Economy	35300.00
0005433568813	11877	Economy	35300.00
0005432947872	11877	Economy	35300.00
0005433568864	11877	Economy	35300.00
0005433568817	11877	Economy	35300.00
0005433568810	11877	Economy	35300.00
0005433568826	11877	Economy	35300.00
0005433568815	11877	Economy	35300.00
0005433568803	11877	Economy	35300.00
0005432947965	11877	Economy	35300.00
0005433568856	11877	Economy	35300.00
0005433568849	11877	Economy	35300.00
0005432947843	11877	Economy	35300.00
0005433568839	11877	Economy	35300.00
0005432947977	11877	Economy	35300.00
0005433568811	11877	Economy	35300.00
0005433568828	11877	Economy	35300.00
0005433568827	11877	Economy	35300.00
0005432948012	11877	Economy	35300.00
0005433568834	11877	Economy	35300.00
0005433568846	11877	Economy	35300.00
0005433568850	11877	Economy	35300.00
0005433568806	11877	Economy	35300.00
0005433568862	11877	Economy	35300.00
0005433568861	11877	Economy	35300.00
0005433568832	11877	Economy	35300.00
0005432947876	11877	Economy	35300.00
0005432947862	11877	Economy	35300.00
0005433568858	11877	Economy	35300.00
0005432947810	11877	Economy	35300.00
0005433568818	11877	Economy	35300.00
0005432947883	11877	Economy	35300.00
0005433568852	11877	Economy	35300.00
0005432947867	11877	Economy	35300.00
0005433568833	11877	Economy	35300.00
0005433568822	11877	Economy	35300.00
0005433568845	11877	Economy	35300.00
0005432948011	11877	Economy	35300.00
0005433568831	11877	Economy	35300.00
0005433568853	11877	Economy	35300.00
0005432947988	11877	Economy	35300.00
0005432948029	11877	Economy	35300.00
0005432947925	11877	Economy	35300.00
0005432947833	11877	Economy	35300.00
0005433568824	11877	Economy	35300.00
0005433568841	11877	Economy	35300.00
0005433568855	11877	Economy	35300.00
0005432947811	11877	Economy	35300.00
0005433568860	11877	Economy	35300.00
0005432948067	11877	Economy	35300.00
0005433568865	11877	Economy	35300.00
0005433568816	11877	Economy	35300.00
0005432948032	11877	Economy	35300.00
0005433568820	11877	Economy	35300.00
0005433568804	11877	Economy	35300.00
0005432947971	11877	Economy	35300.00
0005433568825	11877	Economy	35300.00
0005432947785	11877	Economy	35300.00
0005433568830	11877	Economy	35300.00
0005432947884	11877	Economy	35300.00
0005433568805	11877	Economy	35300.00
0005433568843	11877	Economy	35300.00
0005433568837	11877	Economy	35300.00
0005433568868	11877	Economy	35300.00
0005432947995	11877	Economy	35300.00
0005433568812	11877	Economy	35300.00
0005432948352	25295	Business	105900.00
0005432948367	25295	Business	105900.00
0005433568377	25295	Business	105900.00
0005433568233	25295	Business	105900.00
0005433568405	25295	Business	105900.00
0005432948363	25295	Business	105900.00
0005433568366	25295	Business	105900.00
0005433568243	25295	Business	105900.00
0005433568234	25295	Business	105900.00
0005433568235	25295	Business	105900.00
0005433568040	25295	Business	105900.00
0005433568345	25295	Business	105900.00
0005432948376	25295	Business	105900.00
0005432948387	25295	Business	105900.00
0005433568418	25295	Business	105900.00
0005432948382	25295	Business	105900.00
0005432948373	25295	Economy	35300.00
0005433568133	25295	Economy	35300.00
0005432948347	25295	Economy	35300.00
0005433568430	25295	Economy	35300.00
0005432948364	25295	Economy	35300.00
0005432948388	25295	Economy	35300.00
0005433568085	25295	Economy	35300.00
0005432948366	25295	Economy	35300.00
0005433568353	25295	Economy	35300.00
0005433568374	25295	Economy	35300.00
0005432948385	25295	Economy	38800.00
0005432948369	25295	Economy	38800.00
0005433568370	25295	Economy	38800.00
0005433568378	25295	Economy	35300.00
0005432948351	25295	Economy	38800.00
0005432948348	25295	Economy	35300.00
0005433568253	25295	Economy	35300.00
0005432948365	25295	Economy	35300.00
0005433568316	25295	Economy	35300.00
0005432948356	25295	Economy	35300.00
0005432948354	25295	Economy	35300.00
0005433568483	25295	Economy	35300.00
0005433568420	25295	Economy	35300.00
0005433568060	25295	Economy	35300.00
0005433568338	25295	Economy	35300.00
0005433568292	25295	Economy	35300.00
0005432948355	25295	Economy	35300.00
0005433568187	25295	Economy	35300.00
0005433568044	25295	Economy	35300.00
0005433568402	25295	Economy	35300.00
0005433568262	25295	Economy	35300.00
0005433568365	25295	Economy	35300.00
0005432948371	25295	Economy	35300.00
0005432948375	25295	Economy	35300.00
0005432948368	25295	Economy	35300.00
0005433568181	25295	Economy	35300.00
0005432948358	25295	Economy	35300.00
0005433568163	25295	Economy	35300.00
0005433568448	25295	Economy	35300.00
0005433568298	25295	Economy	35300.00
0005433568476	25295	Economy	35300.00
0005433568478	25295	Economy	35300.00
0005432948350	25295	Economy	35300.00
0005433568371	25295	Economy	35300.00
0005432948359	25295	Economy	35300.00
0005432948384	25295	Economy	35300.00
0005433568521	25295	Economy	35300.00
0005432948374	25295	Economy	35300.00
0005433568043	25295	Economy	35300.00
0005433568335	25295	Economy	35300.00
0005433568364	25295	Economy	35300.00
0005433568350	25295	Economy	35300.00
0005432948370	25295	Economy	35300.00
0005433568446	25295	Economy	35300.00
0005432948380	25295	Economy	35300.00
0005433568401	25295	Economy	35300.00
0005432948381	25295	Economy	35300.00
0005432948353	25295	Economy	35300.00
0005432948357	25295	Economy	35300.00
0005432948386	25295	Economy	35300.00
0005432948361	25295	Economy	35300.00
0005433568447	25295	Economy	35300.00
0005433568464	25295	Economy	35300.00
0005432948377	25295	Economy	35300.00
0005433568336	25295	Economy	35300.00
0005432948362	25295	Economy	35300.00
0005432948379	25295	Economy	35300.00
0005432948360	25295	Economy	35300.00
0005432948349	25295	Economy	35300.00
0005432948372	25295	Economy	35300.00
0005433568167	25295	Economy	35300.00
0005433568429	25295	Economy	35300.00
0005432948378	25295	Economy	35300.00
0005433568461	25295	Economy	35300.00
0005433568337	25295	Economy	35300.00
0005433568533	25295	Economy	35300.00
0005433568135	25295	Economy	35300.00
0005433568367	25295	Economy	35300.00
0005433568150	25295	Economy	35300.00
0005432948383	25295	Economy	35300.00
0005433568421	25295	Economy	35300.00
0005433568297	25295	Economy	35300.00
0005433808326	14460	Business	117400.00
0005432430851	14460	Business	117400.00
0005433812870	14460	Business	117400.00
0005432430855	14460	Business	117400.00
0005432430847	14460	Business	117400.00
0005432430846	14460	Business	117400.00
0005433812871	14460	Business	117400.00
0005433808320	14460	Economy	39100.00
0005433808329	14460	Economy	39100.00
0005434026696	14460	Economy	39100.00
0005433812869	14460	Economy	39100.00
0005434026699	14460	Economy	39100.00
0005433808312	14460	Economy	43000.00
0005433808335	14460	Economy	43000.00
0005432430856	14460	Economy	39100.00
0005432430852	14460	Economy	39100.00
0005432430850	14460	Economy	39100.00
0005433812863	14460	Economy	39100.00
0005434026700	14460	Economy	39100.00
0005434026698	14460	Economy	39100.00
0005433808316	14460	Economy	39100.00
0005432430849	14460	Economy	39100.00
0005433808334	14460	Economy	39100.00
0005432430848	14460	Economy	39100.00
0005434026695	14460	Economy	39100.00
0005432430845	14460	Economy	39100.00
0005433808315	14460	Economy	39100.00
0005433812862	14460	Economy	39100.00
0005433808314	14460	Economy	39100.00
0005433808327	14460	Economy	39100.00
0005432430853	14460	Economy	39100.00
0005433808323	14460	Economy	39100.00
0005433812866	14460	Economy	39100.00
0005433812868	14460	Economy	39100.00
0005434026697	14460	Economy	39100.00
0005432430854	14460	Economy	39100.00
0005433808313	14460	Economy	39100.00
0005433812881	30827	Business	117400.00
0005432430829	30827	Business	117400.00
0005434026675	30827	Business	117400.00
0005433808358	30827	Business	117400.00
0005433808359	30827	Business	117400.00
0005433812891	30827	Business	117400.00
0005432430805	30827	Business	117400.00
0005432430817	30827	Business	117400.00
0005432430800	30827	Business	117400.00
0005432430825	30827	Economy	39100.00
0005433812885	30827	Economy	39100.00
0005432430810	30827	Economy	39100.00
0005432430815	30827	Economy	39100.00
0005432430806	30827	Economy	39100.00
0005432430818	30827	Economy	43000.00
0005433808363	30827	Economy	39100.00
0005432430804	30827	Economy	39100.00
0005433808348	30827	Economy	39100.00
0005433812890	30827	Economy	39100.00
0005433808351	30827	Economy	39100.00
0005433808353	30827	Economy	39100.00
0005433808357	30827	Economy	39100.00
0005433812887	30827	Economy	39100.00
0005432430811	30827	Economy	39100.00
0005432430812	30827	Economy	39100.00
0005433808362	30827	Economy	39100.00
0005432430824	30827	Economy	39100.00
0005433808356	30827	Economy	39100.00
0005433812888	30827	Economy	39100.00
0005432430801	30827	Economy	39100.00
0005433812886	30827	Economy	39100.00
0005434026674	30827	Economy	39100.00
0005433808352	30827	Economy	39100.00
0005434026676	30827	Economy	39100.00
0005433812884	30827	Economy	39100.00
0005433812882	30827	Economy	39100.00
0005432430842	30827	Economy	39100.00
0005433812883	30827	Economy	39100.00
0005433812889	30827	Economy	39100.00
0005433808360	30827	Economy	39100.00
0005433808349	30827	Economy	39100.00
0005432430814	30827	Economy	39100.00
0005433808354	30827	Economy	39100.00
0005432430822	30827	Economy	39100.00
0005433808355	30827	Economy	39100.00
0005433808350	30827	Economy	39100.00
0005434026679	30827	Economy	39100.00
0005432430816	30827	Economy	39100.00
0005433808361	30827	Economy	39100.00
0005434026680	30827	Economy	39100.00
0005432430823	30827	Economy	39100.00
0005435340057	5423	Business	67200.00
0005434654607	5423	Business	67200.00
0005434654605	5423	Business	67200.00
0005432114194	5423	Business	67200.00
0005434654608	5423	Business	67200.00
0005434654595	5423	Business	67200.00
0005434654604	5423	Business	67200.00
0005435340058	5423	Business	67200.00
0005434654594	5423	Business	67200.00
0005435340036	5423	Economy	22400.00
0005435555348	5423	Economy	22400.00
0005434654598	5423	Economy	22400.00
0005434654582	5423	Economy	24600.00
0005434656549	5423	Economy	24600.00
0005434654602	5423	Economy	24600.00
0005434654583	5423	Economy	22400.00
0005434654578	5423	Economy	22400.00
0005434654592	5423	Economy	22400.00
0005435340085	5423	Economy	22400.00
0005435340056	5423	Economy	22400.00
0005434654580	5423	Economy	22400.00
0005434654603	5423	Economy	22400.00
0005434654600	5423	Economy	22400.00
0005435340084	5423	Economy	22400.00
0005434654581	5423	Economy	22400.00
0005435340054	5423	Economy	22400.00
0005434656551	5423	Economy	22400.00
0005434654585	5423	Economy	22400.00
0005434654591	5423	Economy	22400.00
0005434654588	5423	Economy	22400.00
0005434654584	5423	Economy	22400.00
0005434654596	5423	Economy	22400.00
0005432114193	5423	Economy	22400.00
0005434654601	5423	Economy	22400.00
0005435340037	5423	Economy	22400.00
0005434654599	5423	Economy	22400.00
0005434654590	5423	Economy	22400.00
0005434656550	5423	Economy	22400.00
0005435340088	5423	Economy	22400.00
0005434654597	5423	Economy	22400.00
0005434654606	5423	Economy	22400.00
0005434654589	5423	Economy	22400.00
0005434654587	5423	Economy	22400.00
0005435340086	5423	Economy	22400.00
0005435340089	5423	Economy	22400.00
0005432114191	5423	Economy	22400.00
0005434654579	5423	Economy	22400.00
0005434654586	5423	Economy	22400.00
0005435340096	5423	Economy	22400.00
0005435340074	5423	Economy	22400.00
0005434654593	5423	Economy	22400.00
0005432114192	5423	Economy	22400.00
0005435340070	5423	Economy	22400.00
0005435340207	12543	Business	67200.00
0005435340214	12543	Business	67200.00
0005435340217	12543	Business	67200.00
0005434654221	12543	Business	67200.00
0005434654364	12543	Business	67200.00
0005434654463	12543	Economy	22400.00
0005434654249	12543	Economy	22400.00
0005434654378	12543	Economy	22400.00
0005434654309	12543	Economy	22400.00
0005435340220	12543	Economy	22400.00
0005434654293	12543	Economy	22400.00
0005434654446	12543	Economy	24600.00
0005434654311	12543	Economy	22400.00
0005435340218	12543	Economy	22400.00
0005435340210	12543	Economy	22400.00
0005434654250	12543	Economy	22400.00
0005434654310	12543	Economy	22400.00
0005434654286	12543	Economy	22400.00
0005435340213	12543	Economy	22400.00
0005434654375	12543	Economy	22400.00
0005434654426	12543	Economy	22400.00
0005435340208	12543	Economy	22400.00
0005435555364	12543	Economy	22400.00
0005435340221	12543	Economy	22400.00
0005434654367	12543	Economy	22400.00
0005434654266	12543	Economy	22400.00
0005435340209	12543	Economy	22400.00
0005434654303	12543	Economy	22400.00
0005435340215	12543	Economy	22400.00
0005435340216	12543	Economy	22400.00
0005434654239	12543	Economy	22400.00
0005434654234	12543	Economy	22400.00
0005434654294	12543	Economy	22400.00
0005434654516	12543	Economy	22400.00
0005434654374	12543	Economy	22400.00
0005435340212	12543	Economy	22400.00
0005434654344	12543	Economy	22400.00
0005435555363	12543	Economy	22400.00
0005434654481	12543	Economy	22400.00
0005434654379	12543	Economy	22400.00
0005435340211	12543	Economy	22400.00
0005435340222	12543	Economy	22400.00
0005435340219	12543	Economy	22400.00
0005434654312	12543	Economy	22400.00
0005433715817	7430	Business	32000.00
0005433690917	7430	Business	32000.00
0005435266079	7430	Business	32000.00
0005433715784	7430	Business	32000.00
0005433656656	7430	Business	32000.00
0005433715789	7430	Business	32000.00
0005433690920	7430	Business	32000.00
0005433722197	7430	Business	32000.00
0005433715820	7430	Business	32000.00
0005433715796	7430	Economy	10700.00
0005433719128	7430	Economy	10700.00
0005433715829	7430	Economy	10700.00
0005433715816	7430	Economy	10700.00
0005433656658	7430	Economy	10700.00
0005433715788	7430	Economy	10700.00
0005433715783	7430	Economy	10700.00
0005435266088	7430	Economy	10700.00
0005435266094	7430	Economy	10700.00
0005433715826	7430	Economy	10700.00
0005433715791	7430	Economy	10700.00
0005433715797	7430	Economy	10700.00
0005433715825	7430	Economy	10700.00
0005433715821	7430	Economy	10700.00
0005433715827	7430	Economy	10700.00
0005433715807	7430	Economy	10700.00
0005433715832	7430	Economy	10700.00
0005433688800	7430	Economy	10700.00
0005433715782	7430	Economy	10700.00
0005433715811	7430	Economy	10700.00
0005433715810	7430	Economy	10700.00
0005433689902	7430	Economy	10700.00
0005433715814	7430	Economy	10700.00
0005433715819	7430	Economy	10700.00
0005435266086	7430	Economy	10700.00
0005433715822	7430	Economy	10700.00
0005433722198	7430	Economy	10700.00
0005433715833	7430	Economy	10700.00
0005433688801	7430	Economy	10700.00
0005433715793	7430	Economy	11700.00
0005432078092	7430	Economy	11700.00
0005433715785	7430	Economy	10700.00
0005433715831	7430	Economy	10700.00
0005433715800	7430	Economy	10700.00
0005433715790	7430	Economy	10700.00
0005435266076	7430	Economy	10700.00
0005433715809	7430	Economy	10700.00
0005433690921	7430	Economy	10700.00
0005433715808	7430	Economy	10700.00
0005433722199	7430	Economy	10700.00
0005433715802	7430	Economy	10700.00
0005433656657	7430	Economy	10700.00
0005435266080	7430	Economy	10700.00
0005433715813	7430	Economy	10700.00
0005433689904	7430	Economy	10700.00
0005432078090	7430	Economy	10700.00
0005435266087	7430	Economy	10700.00
0005433690918	7430	Economy	10700.00
0005433715805	7430	Economy	10700.00
0005433715806	7430	Economy	10700.00
0005433715787	7430	Economy	10700.00
0005433715799	7430	Economy	10700.00
0005433715798	7430	Economy	10700.00
0005433715795	7430	Economy	10700.00
0005435266085	7430	Economy	10700.00
0005435266077	7430	Economy	10700.00
0005432078089	7430	Economy	10700.00
0005433715794	7430	Economy	10700.00
0005433715818	7430	Economy	10700.00
0005433715815	7430	Economy	10700.00
0005433715824	7430	Economy	10700.00
0005433719127	7430	Economy	10700.00
0005433690919	7430	Economy	10700.00
0005433715801	7430	Economy	10700.00
0005433715828	7430	Economy	10700.00
0005433689903	7430	Economy	10700.00
0005433715804	7430	Economy	10700.00
0005433715830	7430	Economy	10700.00
0005435266081	7430	Economy	10700.00
0005433715803	7430	Economy	10700.00
0005433715786	7430	Economy	10700.00
0005433715823	7430	Economy	10700.00
0005432078091	7430	Economy	10700.00
0005432428884	7430	Economy	10700.00
0005433715792	7430	Economy	10700.00
0005433715812	7430	Economy	10700.00
0005435266096	7430	Economy	10700.00
0005433715426	29221	Business	32000.00
0005433715379	29221	Business	32000.00
0005433715370	29221	Business	32000.00
0005433722125	29221	Business	32000.00
0005432006751	29221	Business	32000.00
0005433715286	29221	Business	32000.00
0005432428916	29221	Business	32000.00
0005433722118	29221	Business	32000.00
0005433685498	29221	Business	32000.00
0005433688782	29221	Economy	10700.00
0005433715338	29221	Economy	10700.00
0005433715293	29221	Economy	10700.00
0005435266136	29221	Economy	10700.00
0005433688783	29221	Economy	10700.00
0005433715292	29221	Economy	10700.00
0005433715413	29221	Economy	10700.00
0005433685499	29221	Economy	10700.00
0005433715420	29221	Economy	10700.00
0005433715500	29221	Economy	10700.00
0005433715454	29221	Economy	10700.00
0005433715351	29221	Economy	10700.00
0005432428918	29221	Economy	10700.00
0005433715343	29221	Economy	10700.00
0005433685493	29221	Economy	10700.00
0005433715256	29221	Economy	10700.00
0005433715342	29221	Economy	10700.00
0005433722142	29221	Economy	10700.00
0005433715243	29221	Economy	10700.00
0005433715389	29221	Economy	10700.00
0005433722145	29221	Economy	10700.00
0005432428917	29221	Economy	10700.00
0005433722127	29221	Economy	10700.00
0005433715459	29221	Economy	10700.00
0005433715540	29221	Economy	10700.00
0005435266137	29221	Economy	10700.00
0005433715344	29221	Economy	10700.00
0005433722129	29221	Economy	10700.00
0005433715322	29221	Economy	11700.00
0005433715542	29221	Economy	11700.00
0005432006750	29221	Economy	11700.00
0005435266139	29221	Economy	11700.00
0005433715202	29221	Economy	11700.00
0005433715233	29221	Economy	10700.00
0005433715352	29221	Economy	10700.00
0005433715390	29221	Economy	10700.00
0005433715237	29221	Economy	10700.00
0005433715307	29221	Economy	10700.00
0005433715328	29221	Economy	10700.00
0005433715460	29221	Economy	10700.00
0005433722140	29221	Economy	10700.00
0005435266140	29221	Economy	10700.00
0005433715280	29221	Economy	10700.00
0005433722119	29221	Economy	10700.00
0005433722146	29221	Economy	10700.00
0005433715251	29221	Economy	10700.00
0005433715455	29221	Economy	10700.00
0005433715387	29221	Economy	10700.00
0005433715391	29221	Economy	10700.00
0005433719088	29221	Economy	10700.00
0005433656624	29221	Economy	10700.00
0005433715562	29221	Economy	10700.00
0005433715399	29221	Economy	10700.00
0005433715239	29221	Economy	10700.00
0005433722143	29221	Economy	10700.00
0005433715376	29221	Economy	10700.00
0005433715341	29221	Economy	10700.00
0005433715388	29221	Economy	10700.00
0005433715315	29221	Economy	10700.00
0005433715421	29221	Economy	10700.00
0005433715252	29221	Economy	10700.00
0005433715257	29221	Economy	10700.00
0005433722141	29221	Economy	10700.00
0005432006752	29221	Economy	10700.00
0005433722144	29221	Economy	10700.00
0005433715339	29221	Economy	10700.00
0005433715541	29221	Economy	10700.00
0005433715340	29221	Economy	10700.00
0005435266138	29221	Economy	10700.00
0005433715234	29221	Economy	10700.00
0005433722126	29221	Economy	10700.00
0005433722163	29221	Economy	10700.00
0005433715502	29221	Economy	10700.00
0005432428919	29221	Economy	10700.00
0005433722104	29221	Economy	10700.00
0005433715546	29221	Economy	10700.00
0005433715314	29221	Economy	10700.00
0005433715323	29221	Economy	10700.00
0005433715236	29221	Economy	10700.00
0005433715273	29221	Economy	10700.00
0005433715499	29221	Economy	10700.00
0005433715367	29221	Economy	10700.00
0005434095222	8690	Business	36500.00
0005434095232	8690	Business	36500.00
0005434182072	8690	Business	36500.00
0005434095231	8690	Business	36500.00
0005434095228	8690	Business	36500.00
0005434095236	8690	Business	36500.00
0005434182054	8690	Economy	12200.00
0005434095233	8690	Economy	12200.00
0005434182025	8690	Economy	12200.00
0005434095226	8690	Economy	12200.00
0005434182024	8690	Economy	12200.00
0005434182044	8690	Economy	12200.00
0005434184639	8690	Economy	13400.00
0005434182081	8690	Economy	13400.00
0005434184637	8690	Economy	13400.00
0005434182071	8690	Economy	12200.00
0005434182080	8690	Economy	12200.00
0005434182070	8690	Economy	12200.00
0005434184640	8690	Economy	12200.00
0005434181975	8690	Economy	12200.00
0005434095229	8690	Economy	12200.00
0005434095224	8690	Economy	12200.00
0005434182053	8690	Economy	12200.00
0005434182031	8690	Economy	12200.00
0005434182079	8690	Economy	12200.00
0005434184650	8690	Economy	12200.00
0005434182075	8690	Economy	12200.00
0005434182073	8690	Economy	12200.00
0005434182030	8690	Economy	12200.00
0005434095234	8690	Economy	12200.00
0005434095230	8690	Economy	12200.00
0005434182084	8690	Economy	12200.00
0005434182043	8690	Economy	12200.00
0005434182068	8690	Economy	12200.00
0005434095235	8690	Economy	12200.00
0005434095223	8690	Economy	12200.00
0005434182032	8690	Economy	12200.00
0005434095227	8690	Economy	12200.00
0005434182018	8690	Economy	12200.00
0005434095225	8690	Economy	12200.00
0005434184651	8690	Economy	12200.00
0005434095237	8690	Economy	12200.00
0005434182095	8690	Economy	12200.00
0005434184638	8690	Economy	12200.00
0005434182074	8690	Economy	12200.00
0005434095145	11661	Business	36500.00
0005434095124	11661	Business	36500.00
0005434182148	11661	Business	36500.00
0005434095092	11661	Economy	12200.00
0005434182149	11661	Economy	12200.00
0005434095080	11661	Economy	12200.00
0005434095100	11661	Economy	12200.00
0005434182142	11661	Economy	12200.00
0005434095094	11661	Economy	13400.00
0005434183571	11661	Economy	13400.00
0005434143704	11661	Economy	12200.00
0005434184657	11661	Economy	12200.00
0005434182141	11661	Economy	12200.00
0005434095047	11661	Economy	12200.00
0005434095102	11661	Economy	12200.00
0005434095057	11661	Economy	12200.00
0005434182144	11661	Economy	12200.00
0005434095081	11661	Economy	12200.00
0005434095091	11661	Economy	12200.00
0005434095104	11661	Economy	12200.00
0005434143703	11661	Economy	12200.00
0005434183572	11661	Economy	12200.00
0005434182146	11661	Economy	12200.00
0005434182139	11661	Economy	12200.00
0005434095171	11661	Economy	12200.00
0005434182140	11661	Economy	12200.00
0005434182145	11661	Economy	12200.00
0005434095056	11661	Economy	12200.00
0005434095045	11661	Economy	12200.00
0005434182137	11661	Economy	12200.00
0005434095120	11661	Economy	12200.00
0005434184658	11661	Economy	12200.00
0005434095101	11661	Economy	12200.00
0005434095127	11661	Economy	12200.00
0005434095099	11661	Economy	12200.00
0005434182138	11661	Economy	12200.00
0005434095082	11661	Economy	12200.00
0005434143705	11661	Economy	12200.00
0005434184656	11661	Economy	12200.00
0005434182143	11661	Economy	12200.00
0005434182147	11661	Economy	12200.00
0005434095055	11661	Economy	12200.00
0005433397670	1442	Business	33000.00
0005433397478	1442	Business	33000.00
0005433397587	1442	Business	33000.00
0005433456955	1442	Business	33000.00
0005432297268	1442	Business	33000.00
0005433397736	1442	Business	33000.00
0005433397461	1442	Business	33000.00
0005433397680	1442	Business	33000.00
0005433397386	1442	Business	33000.00
0005433397452	1442	Economy	11000.00
0005432906507	1442	Economy	11000.00
0005433397479	1442	Economy	11000.00
0005433397581	1442	Economy	11000.00
0005433397543	1442	Economy	11000.00
0005433397384	1442	Economy	11000.00
0005433397470	1442	Economy	12100.00
0005433397316	1442	Economy	12100.00
0005433397460	1442	Economy	11000.00
0005433397391	1442	Economy	11000.00
0005433397346	1442	Economy	11000.00
0005432906512	1442	Economy	11000.00
0005433397385	1442	Economy	11000.00
0005433397486	1442	Economy	11000.00
0005433397515	1442	Economy	11000.00
0005433397524	1442	Economy	11000.00
0005433397345	1442	Economy	11000.00
0005433397480	1442	Economy	11000.00
0005433397439	1442	Economy	11000.00
0005433397278	1442	Economy	11000.00
0005433397556	1442	Economy	11000.00
0005433397462	1442	Economy	11000.00
0005433456957	1442	Economy	11000.00
0005433397315	1442	Economy	11000.00
0005433397601	1442	Economy	11000.00
0005433397314	1442	Economy	11000.00
0005433397249	1442	Economy	11000.00
0005433397424	1442	Economy	11000.00
0005433397713	1442	Economy	11000.00
0005433397401	1442	Economy	11000.00
0005432297270	1442	Economy	11000.00
0005433397494	1442	Economy	11000.00
0005433397279	1442	Economy	11000.00
0005433397516	1442	Economy	11000.00
0005433397582	1442	Economy	11000.00
0005433456956	1442	Economy	11000.00
0005433397679	1442	Economy	11000.00
0005433397588	1442	Economy	11000.00
0005433397597	1442	Economy	11000.00
0005432906504	1442	Economy	11000.00
0005433397341	1442	Economy	11000.00
0005433456954	1442	Economy	11000.00
0005432297269	1442	Economy	11000.00
0005433397583	1442	Economy	11000.00
0005433397471	1442	Economy	11000.00
0005433397438	1442	Economy	11000.00
0005432906500	1442	Economy	11000.00
0005433397636	1442	Economy	11000.00
0005433397584	1442	Economy	11000.00
0005433397678	1442	Economy	11000.00
0005432906510	1442	Economy	11000.00
0005433397570	1442	Economy	11000.00
0005433397482	1442	Economy	11000.00
0005433397440	1442	Economy	11000.00
0005433397444	1442	Economy	11000.00
0005433397525	1442	Economy	11000.00
0005433397340	1442	Economy	11000.00
0005433397404	1442	Economy	11000.00
0005433397602	1442	Economy	11000.00
0005433397216	1442	Economy	11000.00
0005433397637	1442	Economy	11000.00
0005433397402	1442	Economy	11000.00
0005433397423	1442	Economy	11000.00
0005433397875	19241	Business	33000.00
0005435732222	19241	Business	33000.00
0005433397898	19241	Business	33000.00
0005433397894	19241	Business	33000.00
0005433397913	19241	Business	33000.00
0005433397921	19241	Business	33000.00
0005435732167	19241	Business	33000.00
0005433397903	19241	Business	33000.00
0005433397892	19241	Business	33000.00
0005433397889	19241	Economy	11000.00
0005433397907	19241	Economy	11000.00
0005432906527	19241	Economy	11000.00
0005435732207	19241	Economy	11000.00
0005433397888	19241	Economy	11000.00
0005433397908	19241	Economy	11000.00
0005433456929	19241	Economy	11000.00
0005433397897	19241	Economy	11000.00
0005433397902	19241	Economy	11000.00
0005433397884	19241	Economy	12100.00
0005432906528	19241	Economy	12100.00
0005435732162	19241	Economy	11000.00
0005433456914	19241	Economy	11000.00
0005433397890	19241	Economy	11000.00
0005435732168	19241	Economy	11000.00
0005433397895	19241	Economy	11000.00
0005433397916	19241	Economy	11000.00
0005433456944	19241	Economy	11000.00
0005435732270	19241	Economy	11000.00
0005433397906	19241	Economy	11000.00
0005433397891	19241	Economy	11000.00
0005433397881	19241	Economy	11000.00
0005433456930	19241	Economy	11000.00
0005433397904	19241	Economy	11000.00
0005433397874	19241	Economy	11000.00
0005433397880	19241	Economy	11000.00
0005433397879	19241	Economy	11000.00
0005433397911	19241	Economy	11000.00
0005433397878	19241	Economy	11000.00
0005433397887	19241	Economy	11000.00
0005433397877	19241	Economy	11000.00
0005433397918	19241	Economy	11000.00
0005435732208	19241	Economy	11000.00
0005435732211	19241	Economy	11000.00
0005433397920	19241	Economy	11000.00
0005433397886	19241	Economy	11000.00
0005433397914	19241	Economy	11000.00
0005433397912	19241	Economy	11000.00
0005433397882	19241	Economy	11000.00
0005433397910	19241	Economy	11000.00
0005435732163	19241	Economy	11000.00
0005433397893	19241	Economy	11000.00
0005433456932	19241	Economy	11000.00
0005435732220	19241	Economy	11000.00
0005433397901	19241	Economy	11000.00
0005435732205	19241	Economy	11000.00
0005433397883	19241	Economy	11000.00
0005433397909	19241	Economy	11000.00
0005433397876	19241	Economy	11000.00
0005435732169	19241	Economy	11000.00
0005433397923	19241	Economy	11000.00
0005433397905	19241	Economy	11000.00
0005433397917	19241	Economy	11000.00
0005433397915	19241	Economy	11000.00
0005433397919	19241	Economy	11000.00
0005433397896	19241	Economy	11000.00
0005435732216	19241	Economy	11000.00
0005433397924	19241	Economy	11000.00
0005433397900	19241	Economy	11000.00
0005433397885	19241	Economy	11000.00
0005433397922	19241	Economy	11000.00
0005435732197	19241	Economy	11000.00
0005433397899	19241	Economy	11000.00
0005435732166	19241	Economy	11000.00
0005434443524	17393	Economy	15600.00
0005434443481	17393	Economy	14100.00
0005434443542	17393	Economy	14100.00
0005434443502	17393	Economy	14100.00
0005434443567	17393	Economy	14100.00
0005434443496	17393	Economy	14100.00
0005434443510	17393	Economy	14100.00
0005434443574	17393	Economy	14100.00
0005434443484	17393	Economy	14100.00
0005434443521	17393	Economy	14100.00
0005434443483	17393	Economy	14100.00
0005434443568	17393	Economy	14100.00
0005434443562	17393	Economy	14100.00
0005434443641	20579	Economy	15600.00
0005434443640	20579	Economy	15600.00
0005434443638	20579	Economy	14100.00
0005434443649	20579	Economy	14100.00
0005434443648	20579	Economy	14100.00
0005434443644	20579	Economy	14100.00
0005434443653	20579	Economy	14100.00
0005434443651	20579	Economy	14100.00
0005434443639	20579	Economy	14100.00
0005434443654	20579	Economy	14100.00
0005434443643	20579	Economy	14100.00
0005434443645	20579	Economy	14100.00
0005434443646	20579	Economy	14100.00
0005434443647	20579	Economy	14100.00
0005434443650	20579	Economy	14100.00
0005434443642	20579	Economy	14100.00
0005434443652	20579	Economy	14100.00
0005434954597	7257	Economy	5800.00
0005434954596	7257	Economy	5800.00
0005434954594	7257	Economy	5800.00
0005434954595	7257	Economy	5800.00
0005435377554	7257	Economy	5800.00
0005434954561	28313	Economy	5800.00
0005435377572	28313	Economy	5800.00
0005435377573	28313	Economy	5800.00
0005434954565	28313	Economy	5800.00
0005435893563	4472	Economy	15400.00
0005434351654	4472	Economy	15400.00
0005435893546	4472	Economy	14000.00
0005435893543	4472	Economy	14000.00
0005435893554	4472	Economy	14000.00
0005434351659	4472	Economy	14000.00
0005434183555	4472	Economy	14000.00
0005434351653	4472	Economy	14000.00
0005435893544	4472	Economy	14000.00
0005434351658	4472	Economy	14000.00
0005434351649	4472	Economy	14000.00
0005434351656	4472	Economy	14000.00
0005434351655	4472	Economy	14000.00
0005434351650	4472	Economy	14000.00
0005435893545	4472	Economy	14000.00
0005435893562	4472	Economy	14000.00
0005434351657	4472	Economy	14000.00
0005434351648	4472	Economy	14000.00
0005434351647	4472	Economy	14000.00
0005434351651	4472	Economy	14000.00
0005434351652	4472	Economy	14000.00
0005434351485	29626	Economy	15400.00
0005434351523	29626	Economy	14000.00
0005435893611	29626	Economy	14000.00
0005434351569	29626	Economy	14000.00
0005434351517	29626	Economy	14000.00
0005434351522	29626	Economy	14000.00
0005434351516	29626	Economy	14000.00
0005435893605	29626	Economy	14000.00
0005435893610	29626	Economy	14000.00
0005435893607	29626	Economy	14000.00
0005434351524	29626	Economy	14000.00
0005435893612	29626	Economy	14000.00
0005435893609	29626	Economy	14000.00
0005434351511	29626	Economy	14000.00
0005434351502	29626	Economy	14000.00
0005435893608	29626	Economy	14000.00
0005434351534	29626	Economy	14000.00
0005435893606	29626	Economy	14000.00
0005435092044	1045	Business	30600.00
0005433341946	1045	Business	30600.00
0005433341673	1045	Business	30600.00
0005435545715	1045	Business	30600.00
0005433342029	1045	Business	30600.00
0005433341578	1045	Business	30600.00
0005433341470	1045	Business	30600.00
0005433342102	1045	Business	30600.00
0005435545719	1045	Business	30600.00
0005433341852	1045	Business	30600.00
0005433342026	1045	Business	30600.00
0005433269652	1045	Business	30600.00
0005435545721	1045	Business	30600.00
0005433159287	1045	Business	30600.00
0005433269642	1045	Business	30600.00
0005433342485	1045	Business	30600.00
0005433342004	1045	Business	30600.00
0005433342205	1045	Business	30600.00
0005433462741	1045	Business	30600.00
0005433269665	1045	Business	30600.00
0005433342012	1045	Business	30600.00
0005433341760	1045	Business	30600.00
0005433341656	1045	Business	30600.00
0005435545716	1045	Economy	11200.00
0005433341647	1045	Business	30600.00
0005433341536	1045	Economy	11200.00
0005433341786	1045	Economy	11200.00
0005433341646	1045	Economy	11200.00
0005433341618	1045	Economy	10200.00
0005433341899	1045	Economy	10200.00
0005433341856	1045	Economy	10200.00
0005433159288	1045	Economy	10200.00
0005433269648	1045	Economy	10200.00
0005433341987	1045	Economy	10200.00
0005433341945	1045	Economy	10200.00
0005435092037	1045	Economy	10200.00
0005433341602	1045	Economy	10200.00
0005433341665	1045	Economy	10200.00
0005433342080	1045	Economy	10200.00
0005433341743	1045	Economy	10200.00
0005433159292	1045	Economy	10200.00
0005434445242	1045	Economy	10200.00
0005433342074	1045	Economy	10200.00
0005433341992	1045	Economy	10200.00
0005433341948	1045	Economy	10200.00
0005433341988	1045	Economy	10200.00
0005433342339	1045	Economy	10200.00
0005434446512	1045	Economy	10200.00
0005433342158	1045	Economy	10200.00
0005433341872	1045	Economy	10200.00
0005434445240	1045	Economy	10200.00
0005433463894	1045	Economy	10200.00
0005433342222	1045	Economy	10200.00
0005433341825	1045	Economy	10200.00
0005432293200	1045	Economy	10200.00
0005433269625	1045	Economy	10200.00
0005433342385	1045	Economy	10200.00
0005435092040	1045	Economy	10200.00
0005433341702	1045	Economy	10200.00
0005433341471	1045	Economy	10200.00
0005433341679	1045	Economy	10200.00
0005435092039	1045	Economy	10200.00
0005433341983	1045	Economy	10200.00
0005433462740	1045	Economy	10200.00
0005433341818	1045	Economy	10200.00
0005433342221	1045	Economy	10200.00
0005433341785	1045	Economy	10200.00
0005433342036	1045	Economy	10200.00
0005433341604	1045	Economy	10200.00
0005433463893	1045	Economy	10200.00
0005433342055	1045	Economy	10200.00
0005433341808	1045	Economy	10200.00
0005435092045	1045	Economy	10200.00
0005433341484	1045	Economy	10200.00
0005433341692	1045	Economy	10200.00
0005433342076	1045	Economy	10200.00
0005433341661	1045	Economy	10200.00
0005433342254	1045	Economy	10200.00
0005433341971	1045	Economy	10200.00
0005433342294	1045	Economy	10200.00
0005435092041	1045	Economy	10200.00
0005433342057	1045	Economy	10200.00
0005433341917	1045	Economy	10200.00
0005433159278	1045	Economy	10200.00
0005433342079	1045	Economy	10200.00
0005433342056	1045	Economy	10200.00
0005433341731	1045	Economy	10200.00
0005433341664	1045	Economy	10200.00
0005433342081	1045	Economy	10200.00
0005433342175	1045	Economy	10200.00
0005433341566	1045	Economy	10200.00
0005433342338	1045	Economy	11200.00
0005433342486	1045	Economy	10200.00
0005433342103	1045	Economy	11200.00
0005435092042	1045	Economy	10200.00
0005433342193	1045	Economy	10200.00
0005435545720	1045	Economy	10200.00
0005433342024	1045	Economy	10200.00
0005433342439	1045	Economy	10200.00
0005433341719	1045	Economy	10200.00
0005434445241	1045	Economy	10200.00
0005435092043	1045	Economy	10200.00
0005435545722	1045	Economy	10200.00
0005433158095	1045	Economy	10200.00
0005435092038	1045	Economy	10200.00
0005433269661	1045	Economy	10200.00
0005433341974	1045	Economy	10200.00
0005433341938	1045	Economy	10200.00
0005433341807	1045	Economy	10200.00
0005433341790	1045	Economy	10200.00
0005433269641	1045	Economy	10200.00
0005433341861	1045	Economy	10200.00
0005433269662	1045	Economy	10200.00
0005434446513	1045	Economy	10200.00
0005433342046	1045	Economy	10200.00
0005433158106	1045	Economy	10200.00
0005433341900	1045	Economy	10200.00
0005433341630	1045	Economy	10200.00
0005435545718	1045	Economy	10200.00
0005433342438	1045	Economy	10200.00
0005433342194	1045	Economy	10200.00
0005433341605	1045	Economy	10200.00
0005433341577	1045	Economy	10200.00
0005433341469	1045	Economy	10200.00
0005433341693	1045	Economy	10200.00
0005433341810	1045	Economy	10200.00
0005433341826	1045	Economy	10200.00
0005433342096	1045	Economy	10200.00
0005433341485	1045	Economy	10200.00
0005433341537	1045	Economy	10200.00
0005433341720	1045	Economy	10200.00
0005432293201	1045	Economy	10200.00
0005435545717	1045	Economy	10200.00
0005433341871	1045	Economy	10200.00
0005433341619	1045	Economy	10200.00
0005433341855	1045	Economy	10200.00
0005433341969	1045	Economy	10200.00
0005433269640	1045	Economy	10200.00
0005433341691	1045	Economy	10200.00
0005435092036	1045	Economy	10200.00
0005433342011	1045	Economy	10200.00
0005433341414	1045	Economy	10200.00
0005433341550	1045	Economy	10200.00
0005433342462	1045	Economy	10200.00
0005433341634	1045	Economy	10200.00
0005433341730	1045	Economy	10200.00
0005433342721	17062	Business	30600.00
0005433342710	17062	Business	30600.00
0005433342730	17062	Business	30600.00
0005433342791	17062	Business	30600.00
0005433342739	17062	Business	30600.00
0005433342787	17062	Business	30600.00
0005433342802	17062	Business	30600.00
0005433342705	17062	Business	30600.00
0005433342751	17062	Business	30600.00
0005433342768	17062	Business	30600.00
0005433342745	17062	Business	30600.00
0005433342717	17062	Business	30600.00
0005433342742	17062	Business	30600.00
0005433342723	17062	Business	30600.00
0005433342738	17062	Business	30600.00
0005433342763	17062	Business	30600.00
0005433342736	17062	Economy	11200.00
0005435508200	17062	Economy	11200.00
0005433342767	17062	Economy	10200.00
0005435092016	17062	Economy	10200.00
0005433342804	17062	Economy	10200.00
0005433342780	17062	Economy	10200.00
0005433342750	17062	Economy	10200.00
0005433342778	17062	Economy	10200.00
0005433342770	17062	Economy	10200.00
0005433342703	17062	Economy	10200.00
0005433342772	17062	Economy	10200.00
0005433342775	17062	Economy	10200.00
0005433269700	17062	Economy	10200.00
0005433342792	17062	Economy	10200.00
0005433342803	17062	Economy	10200.00
0005433342735	17062	Economy	10200.00
0005433342756	17062	Economy	10200.00
0005433342707	17062	Economy	10200.00
0005433342733	17062	Economy	10200.00
0005433342771	17062	Economy	10200.00
0005433342711	17062	Economy	10200.00
0005433342795	17062	Economy	10200.00
0005435091941	17062	Economy	10200.00
0005433342741	17062	Economy	10200.00
0005433342704	17062	Economy	10200.00
0005433342757	17062	Economy	10200.00
0005433342719	17062	Economy	10200.00
0005433269699	17062	Economy	10200.00
0005433159304	17062	Economy	10200.00
0005433342788	17062	Economy	10200.00
0005433342713	17062	Economy	10200.00
0005433342790	17062	Economy	10200.00
0005435091960	17062	Economy	10200.00
0005433342754	17062	Economy	10200.00
0005435091969	17062	Economy	10200.00
0005433342765	17062	Economy	10200.00
0005433342725	17062	Economy	10200.00
0005433342744	17062	Economy	10200.00
0005433342758	17062	Economy	10200.00
0005433342728	17062	Economy	10200.00
0005433342715	17062	Economy	10200.00
0005433342762	17062	Economy	10200.00
0005433342743	17062	Economy	10200.00
0005433342726	17062	Economy	10200.00
0005433342794	17062	Economy	10200.00
0005433342801	17062	Economy	10200.00
0005433342755	17062	Economy	10200.00
0005433342714	17062	Economy	10200.00
0005433269701	17062	Economy	10200.00
0005433342781	17062	Economy	10200.00
0005433342793	17062	Economy	10200.00
0005433342747	17062	Economy	10200.00
0005433342784	17062	Economy	10200.00
0005433342776	17062	Economy	10200.00
0005433342796	17062	Economy	10200.00
0005435508206	17062	Economy	10200.00
0005433342785	17062	Economy	10200.00
0005433342708	17062	Economy	10200.00
0005433342798	17062	Economy	10200.00
0005433342769	17062	Economy	10200.00
0005433342722	17062	Economy	11200.00
0005433342782	17062	Economy	11200.00
0005433342727	17062	Economy	10200.00
0005435508205	17062	Economy	10200.00
0005435508207	17062	Economy	10200.00
0005433342764	17062	Economy	10200.00
0005433342799	17062	Economy	10200.00
0005435508203	17062	Economy	10200.00
0005433342752	17062	Economy	10200.00
0005433342732	17062	Economy	10200.00
0005433342731	17062	Economy	10200.00
0005433342759	17062	Economy	10200.00
0005435092017	17062	Economy	10200.00
0005433342749	17062	Economy	10200.00
0005435091942	17062	Economy	10200.00
0005433342718	17062	Economy	10200.00
0005433342706	17062	Economy	10200.00
0005435508210	17062	Economy	10200.00
0005433342709	17062	Economy	10200.00
0005433342760	17062	Economy	10200.00
0005433342766	17062	Economy	10200.00
0005433342746	17062	Economy	10200.00
0005433342777	17062	Economy	10200.00
0005433342702	17062	Economy	10200.00
0005433342786	17062	Economy	10200.00
0005433342712	17062	Economy	10200.00
0005433342716	17062	Economy	10200.00
0005433342800	17062	Economy	10200.00
0005433342789	17062	Economy	10200.00
0005433159305	17062	Economy	10200.00
0005433342748	17062	Economy	10200.00
0005433342729	17062	Economy	10200.00
0005433269702	17062	Economy	10200.00
0005433342797	17062	Economy	10200.00
0005433342737	17062	Economy	10200.00
0005433342761	17062	Economy	10200.00
0005433342779	17062	Economy	10200.00
0005433342783	17062	Economy	10200.00
0005433342773	17062	Economy	10200.00
0005433342734	17062	Economy	10200.00
0005433342724	17062	Economy	10200.00
0005433269698	17062	Economy	10200.00
0005433342753	17062	Economy	10200.00
0005433342720	17062	Economy	10200.00
0005435508180	17062	Economy	10200.00
0005435091961	17062	Economy	10200.00
0005433342740	17062	Economy	10200.00
0005435508199	17062	Economy	10200.00
0005433342774	17062	Economy	10200.00
0005432851899	18270	Business	101000.00
0005432851906	18270	Business	101000.00
0005432389979	18270	Business	101000.00
0005432851885	18270	Business	101000.00
0005432390007	18270	Business	101000.00
0005432391945	18270	Business	101000.00
0005432389992	18270	Business	101000.00
0005432390009	18270	Business	101000.00
0005432389990	18270	Business	101000.00
0005432851894	18270	Business	101000.00
0005432389962	18270	Business	101000.00
0005432390004	18270	Economy	33700.00
0005432391963	18270	Economy	33700.00
0005432389942	18270	Economy	33700.00
0005432389998	18270	Economy	33700.00
0005432391958	18270	Economy	33700.00
0005432389989	18270	Economy	33700.00
0005432389953	18270	Economy	33700.00
0005432389999	18270	Economy	33700.00
0005432391949	18270	Economy	33700.00
0005432389958	18270	Economy	33700.00
0005432389964	18270	Economy	37000.00
0005432389948	18270	Economy	37000.00
0005432851901	18270	Economy	37000.00
0005432389987	18270	Economy	33700.00
0005432851904	18270	Economy	37000.00
0005432851905	18270	Economy	33700.00
0005432390051	18270	Economy	33700.00
0005432389944	18270	Economy	33700.00
0005432390003	18270	Economy	33700.00
0005432851887	18270	Economy	33700.00
0005432389994	18270	Economy	33700.00
0005432389959	18270	Economy	33700.00
0005432389982	18270	Economy	33700.00
0005432851890	18270	Economy	33700.00
0005432389981	18270	Economy	33700.00
0005432391955	18270	Economy	33700.00
0005432851886	18270	Economy	33700.00
0005432391948	18270	Economy	33700.00
0005432390010	18270	Economy	33700.00
0005432389997	18270	Economy	33700.00
0005432389965	18270	Economy	33700.00
0005432851895	18270	Economy	33700.00
0005432851896	18270	Economy	33700.00
0005432391954	18270	Economy	33700.00
0005432851902	18270	Economy	33700.00
0005432390026	18270	Economy	33700.00
0005432389985	18270	Economy	33700.00
0005432389966	18270	Economy	33700.00
0005432389970	18270	Economy	33700.00
0005432851891	18270	Economy	33700.00
0005432389988	18270	Economy	33700.00
0005432851884	18270	Economy	33700.00
0005432851883	18270	Economy	33700.00
0005432390025	18270	Economy	33700.00
0005432391952	18270	Economy	33700.00
0005432389995	18270	Economy	33700.00
0005432389986	18270	Economy	33700.00
0005432389949	18270	Economy	33700.00
0005432389996	18270	Economy	33700.00
0005432390029	18270	Economy	33700.00
0005432391961	18270	Economy	33700.00
0005432851893	18270	Economy	33700.00
0005432391964	18270	Economy	33700.00
0005432851897	18270	Economy	33700.00
0005432389938	18270	Economy	33700.00
0005432390002	18270	Economy	33700.00
0005432389983	18270	Economy	33700.00
0005432389957	18270	Economy	33700.00
0005432851889	18270	Economy	33700.00
0005432851903	18270	Economy	33700.00
0005432391953	18270	Economy	33700.00
0005432389967	18270	Economy	33700.00
0005432389956	18270	Economy	33700.00
0005432390006	18270	Economy	33700.00
0005432851888	18270	Economy	33700.00
0005432851898	18270	Economy	33700.00
0005432389969	18270	Economy	33700.00
0005432389993	18270	Economy	33700.00
0005432390008	18270	Economy	33700.00
0005432391957	18270	Economy	33700.00
0005432851892	18270	Economy	33700.00
0005432851900	18270	Economy	33700.00
0005432391962	18270	Economy	33700.00
0005434066528	12778	Business	40300.00
0005434066804	12778	Business	40300.00
0005432159842	12778	Business	40300.00
0005434066460	12778	Business	40300.00
0005434066637	12778	Business	40300.00
0005434081547	12778	Business	40300.00
0005434066663	12778	Business	40300.00
0005434066737	12778	Business	40300.00
0005433989715	12778	Business	40300.00
0005434066544	12778	Business	40300.00
0005432433660	12778	Economy	13400.00
0005434081624	12778	Economy	13400.00
0005433812893	12778	Economy	13400.00
0005434081673	12778	Economy	13400.00
0005432161144	12778	Economy	13400.00
0005434066809	12778	Economy	13400.00
0005434066654	12778	Economy	13400.00
0005434066645	12778	Economy	13400.00
0005434081528	12778	Economy	13400.00
0005434081546	12778	Economy	13400.00
0005434066861	12778	Economy	13400.00
0005434066732	12778	Economy	13400.00
0005432433659	12778	Economy	13400.00
0005434066774	12778	Economy	13400.00
0005434066543	12778	Economy	13400.00
0005434066842	12778	Economy	13400.00
0005434081556	12778	Economy	13400.00
0005432161145	12778	Economy	13400.00
0005434066671	12778	Economy	13400.00
0005434066338	12778	Economy	13400.00
0005434066733	12778	Economy	13400.00
0005434066662	12778	Economy	13400.00
0005434066367	12778	Economy	13400.00
0005432433662	12778	Economy	13400.00
0005434081552	12778	Economy	13400.00
0005434066966	12778	Economy	13400.00
0005434066325	12778	Economy	13400.00
0005434066426	12778	Economy	13400.00
0005433989710	12778	Economy	13400.00
0005434066808	12778	Economy	13400.00
0005434066849	12778	Economy	13400.00
0005434081588	12778	Economy	13400.00
0005434066670	12778	Economy	13400.00
0005434066516	12778	Economy	13400.00
0005432433663	12778	Economy	13400.00
0005434066725	12778	Economy	14800.00
0005434066499	12778	Economy	14800.00
0005434066740	12778	Economy	14800.00
0005434066721	12778	Economy	14800.00
0005434066395	12778	Economy	14800.00
0005434066859	12778	Economy	14800.00
0005434081625	12778	Economy	13400.00
0005434066529	12778	Economy	13400.00
0005434066476	12778	Economy	13400.00
0005434066542	12778	Economy	13400.00
0005434066683	12778	Economy	13400.00
0005432433664	12778	Economy	13400.00
0005434066757	12778	Economy	13400.00
0005434066722	12778	Economy	13400.00
0005434081488	12778	Economy	13400.00
0005434066329	12778	Economy	13400.00
0005434066677	12778	Economy	13400.00
0005434066647	12778	Economy	13400.00
0005432159844	12778	Economy	13400.00
0005434066583	12778	Economy	13400.00
0005434066648	12778	Economy	13400.00
0005434081644	12778	Economy	13400.00
0005434081522	12778	Economy	13400.00
0005434066515	12778	Economy	13400.00
0005434066634	12778	Economy	13400.00
0005434066930	12778	Economy	13400.00
0005434066711	12778	Economy	13400.00
0005434066467	12778	Economy	13400.00
0005434066498	12778	Economy	13400.00
0005434066805	12778	Economy	13400.00
0005434066633	12778	Economy	13400.00
0005434066576	12778	Economy	13400.00
0005434066776	12778	Economy	13400.00
0005434066646	12778	Economy	13400.00
0005434081589	12778	Economy	13400.00
0005432433661	12778	Economy	13400.00
0005434066744	12778	Economy	13400.00
0005434066459	12778	Economy	13400.00
0005434066474	12778	Economy	13400.00
0005434066700	12778	Economy	13400.00
0005434066775	12778	Economy	13400.00
0005434066758	12778	Economy	13400.00
0005434026673	12778	Economy	13400.00
0005434066497	12778	Economy	13400.00
0005433989701	12778	Economy	13400.00
0005434066745	12778	Economy	13400.00
0005434081617	12778	Economy	13400.00
0005434066952	12778	Economy	13400.00
0005434066743	12778	Economy	13400.00
0005433989699	12778	Economy	13400.00
0005434066684	12778	Economy	13400.00
0005432159841	12778	Economy	13400.00
0005434066753	12778	Economy	13400.00
0005432433665	12778	Economy	13400.00
0005434081618	12778	Economy	13400.00
0005434066752	12778	Economy	13400.00
0005434066860	12778	Economy	13400.00
0005434066756	12778	Economy	13400.00
0005434066736	12778	Economy	13400.00
0005434066577	12778	Economy	13400.00
0005434066850	12778	Economy	13400.00
0005434066364	12778	Economy	13400.00
0005432159843	12778	Economy	13400.00
0005434066575	12778	Economy	13400.00
0005434081600	12778	Economy	13400.00
0005434081523	12778	Economy	13400.00
0005433812892	12778	Economy	13400.00
0005434081586	12778	Economy	13400.00
0005434081587	12778	Economy	13400.00
0005434067306	30649	Business	40300.00
0005434081804	30649	Business	40300.00
0005434067241	30649	Business	40300.00
0005434067263	30649	Business	40300.00
0005432186854	30649	Business	40300.00
0005434067285	30649	Business	40300.00
0005434067250	30649	Business	40300.00
0005434067297	30649	Business	40300.00
0005434081805	30649	Business	40300.00
0005434081806	30649	Economy	13400.00
0005434067242	30649	Economy	13400.00
0005434067272	30649	Economy	13400.00
0005434067277	30649	Economy	13400.00
0005434081794	30649	Economy	13400.00
0005434081816	30649	Economy	13400.00
0005434067255	30649	Economy	13400.00
0005434067298	30649	Economy	13400.00
0005434067269	30649	Economy	13400.00
0005434067264	30649	Economy	13400.00
0005434081807	30649	Economy	13400.00
0005434081808	30649	Economy	13400.00
0005434081818	30649	Economy	13400.00
0005432150165	30649	Economy	13400.00
0005434067244	30649	Economy	13400.00
0005432186852	30649	Economy	13400.00
0005432150160	30649	Economy	13400.00
0005434067248	30649	Economy	13400.00
0005434067290	30649	Economy	13400.00
0005434081799	30649	Economy	13400.00
0005434067275	30649	Economy	13400.00
0005434067247	30649	Economy	13400.00
0005434067309	30649	Economy	13400.00
0005434081801	30649	Economy	13400.00
0005434067303	30649	Economy	13400.00
0005434067257	30649	Economy	13400.00
0005434067270	30649	Economy	13400.00
0005434067261	30649	Economy	13400.00
0005434067295	30649	Economy	13400.00
0005432433640	30649	Economy	13400.00
0005434081815	30649	Economy	13400.00
0005434081803	30649	Economy	13400.00
0005434067249	30649	Economy	13400.00
0005434067308	30649	Economy	13400.00
0005434067293	30649	Economy	13400.00
0005434081812	30649	Economy	13400.00
0005433989753	30649	Economy	14800.00
0005432150164	30649	Economy	14800.00
0005432150159	30649	Economy	14800.00
0005434067305	30649	Economy	14800.00
0005434067296	30649	Economy	14800.00
0005434067278	30649	Economy	14800.00
0005434067256	30649	Economy	13400.00
0005434067258	30649	Economy	13400.00
0005434067291	30649	Economy	13400.00
0005434067271	30649	Economy	13400.00
0005434067273	30649	Economy	13400.00
0005434067254	30649	Economy	13400.00
0005432150162	30649	Economy	13400.00
0005433989752	30649	Economy	13400.00
0005434067300	30649	Economy	13400.00
0005434067284	30649	Economy	13400.00
0005432186853	30649	Economy	13400.00
0005432186855	30649	Economy	13400.00
0005434067253	30649	Economy	13400.00
0005434081790	30649	Economy	13400.00
0005434067267	30649	Economy	13400.00
0005434067301	30649	Economy	13400.00
0005434081798	30649	Economy	13400.00
0005434067251	30649	Economy	13400.00
0005434067302	30649	Economy	13400.00
0005434067283	30649	Economy	13400.00
0005434067260	30649	Economy	13400.00
0005434067292	30649	Economy	13400.00
0005434067279	30649	Economy	13400.00
0005432150163	30649	Economy	13400.00
0005434067286	30649	Economy	13400.00
0005434081810	30649	Economy	13400.00
0005434067268	30649	Economy	13400.00
0005434067246	30649	Economy	13400.00
0005434067245	30649	Economy	13400.00
0005434067307	30649	Economy	13400.00
0005434081795	30649	Economy	13400.00
0005434081802	30649	Economy	13400.00
0005433989751	30649	Economy	13400.00
0005434081813	30649	Economy	13400.00
0005434067266	30649	Economy	13400.00
0005434081792	30649	Economy	13400.00
0005434081809	30649	Economy	13400.00
0005434067280	30649	Economy	13400.00
0005434081811	30649	Economy	13400.00
0005434081817	30649	Economy	13400.00
0005434067304	30649	Economy	13400.00
0005434067287	30649	Economy	13400.00
0005434067299	30649	Economy	13400.00
0005434067239	30649	Economy	13400.00
0005434067262	30649	Economy	13400.00
0005434067240	30649	Economy	13400.00
0005434081793	30649	Economy	13400.00
0005434067252	30649	Economy	13400.00
0005434081797	30649	Economy	13400.00
0005433989754	30649	Economy	13400.00
0005434081800	30649	Economy	13400.00
0005434067265	30649	Economy	13400.00
0005434067276	30649	Economy	13400.00
0005434081791	30649	Economy	13400.00
0005434067259	30649	Economy	13400.00
0005434067310	30649	Economy	13400.00
0005433989750	30649	Economy	13400.00
0005434081814	30649	Economy	13400.00
0005434067289	30649	Economy	13400.00
0005434067288	30649	Economy	13400.00
0005434067274	30649	Economy	13400.00
0005434067282	30649	Economy	13400.00
0005434081796	30649	Economy	13400.00
0005434067281	30649	Economy	13400.00
0005434067243	30649	Economy	13400.00
0005432150161	30649	Economy	13400.00
0005434067294	30649	Economy	13400.00
0005433689887	19362	Economy	17600.00
0005433686614	19362	Economy	17600.00
0005433689888	19362	Economy	17600.00
0005433689876	19362	Economy	17600.00
0005433686609	19362	Economy	17600.00
0005435722046	5492	Business	35300.00
0005432140420	5492	Business	35300.00
0005435461989	5492	Business	35300.00
0005433527257	5492	Business	35300.00
0005435766033	5492	Business	35300.00
0005435725579	5492	Business	35300.00
0005434264913	5492	Business	35300.00
0005432140423	5492	Business	35300.00
0005435735122	5492	Business	35300.00
0005435766063	5492	Business	35300.00
0005435766046	5492	Business	35300.00
0005435766029	5492	Business	35300.00
0005435461957	5492	Business	35300.00
0005435766038	5492	Business	35300.00
0005434264840	5492	Business	35300.00
0005435461875	5492	Business	35300.00
0005434264872	5492	Business	35300.00
0005435766064	5492	Business	35300.00
0005435766024	5492	Business	35300.00
0005435766044	5492	Business	35300.00
0005434264850	5492	Business	35300.00
0005432140417	5492	Business	35300.00
0005435462026	5492	Economy	12900.00
0005435766032	5492	Economy	12900.00
0005435461876	5492	Economy	12900.00
0005433527259	5492	Economy	11800.00
0005435766052	5492	Economy	11800.00
0005435766040	5492	Economy	11800.00
0005434831080	5492	Economy	11800.00
0005435766020	5492	Economy	11800.00
0005435766048	5492	Economy	11800.00
0005434264858	5492	Economy	11800.00
0005434264849	5492	Economy	11800.00
0005434264757	5492	Economy	11800.00
0005435766059	5492	Economy	11800.00
0005434264887	5492	Economy	11800.00
0005434831106	5492	Economy	11800.00
0005435766067	5492	Economy	11800.00
0005435462058	5492	Economy	11800.00
0005435461805	5492	Economy	11800.00
0005435766071	5492	Economy	11800.00
0005435766016	5492	Economy	11800.00
0005433529265	5492	Economy	11800.00
0005435766013	5492	Economy	11800.00
0005435725578	5492	Economy	11800.00
0005434264798	5492	Economy	11800.00
0005435462001	5492	Economy	11800.00
0005433529267	5492	Economy	11800.00
0005434264727	5492	Economy	11800.00
0005432140419	5492	Economy	11800.00
0005434264873	5492	Economy	11800.00
0005432140418	5492	Economy	11800.00
0005434831081	5492	Economy	11800.00
0005435766066	5492	Economy	11800.00
0005435725580	5492	Economy	11800.00
0005435462059	5492	Economy	11800.00
0005432535773	5492	Economy	11800.00
0005435735120	5492	Economy	11800.00
0005435766050	5492	Economy	11800.00
0005432535772	5492	Economy	11800.00
0005435461954	5492	Economy	11800.00
0005435766049	5492	Economy	11800.00
0005435461963	5492	Economy	11800.00
0005435462042	5492	Economy	11800.00
0005435462043	5492	Economy	11800.00
0005435766023	5492	Economy	11800.00
0005435461960	5492	Economy	11800.00
0005434264782	5492	Economy	11800.00
0005435766045	5492	Economy	11800.00
0005435766035	5492	Economy	11800.00
0005435461988	5492	Economy	11800.00
0005433527254	5492	Economy	11800.00
0005434264792	5492	Economy	11800.00
0005433527256	5492	Economy	11800.00
0005434264856	5492	Economy	11800.00
0005435462197	5492	Economy	11800.00
0005435766027	5492	Economy	11800.00
0005434264912	5492	Economy	11800.00
0005435461831	5492	Economy	11800.00
0005435461877	5492	Economy	11800.00
0005435766018	5492	Economy	11800.00
0005435766056	5492	Economy	11800.00
0005435766015	5492	Economy	11800.00
0005435766014	5492	Economy	11800.00
0005435461874	5492	Economy	11800.00
0005435766065	5492	Economy	11800.00
0005435462025	5492	Economy	11800.00
0005435766037	5492	Economy	11800.00
0005434831113	5492	Economy	11800.00
0005435462050	5492	Economy	11800.00
0005435766061	5492	Economy	11800.00
0005432140416	5492	Economy	11800.00
0005435461864	5492	Economy	11800.00
0005435043275	5492	Economy	11800.00
0005435766042	5492	Economy	11800.00
0005432535780	5492	Economy	11800.00
0005435723038	5492	Economy	11800.00
0005435766026	5492	Economy	11800.00
0005435766025	5492	Economy	11800.00
0005435766031	5492	Economy	11800.00
0005435766070	5492	Economy	11800.00
0005435766034	5492	Economy	11800.00
0005432140424	5492	Economy	11800.00
0005433527258	5492	Economy	12900.00
0005435735121	5492	Economy	11800.00
0005435461900	5492	Economy	11800.00
0005435766009	5492	Economy	11800.00
0005435766041	5492	Economy	11800.00
0005435462053	5492	Economy	12900.00
0005432140421	5492	Economy	11800.00
0005435461911	5492	Economy	11800.00
0005435766062	5492	Economy	11800.00
0005435766051	5492	Economy	11800.00
0005435766039	5492	Economy	11800.00
0005435725582	5492	Economy	11800.00
0005435462017	5492	Economy	11800.00
0005434264857	5492	Economy	11800.00
0005435766012	5492	Economy	11800.00
0005435766069	5492	Economy	11800.00
0005435722048	5492	Economy	11800.00
0005435766055	5492	Economy	11800.00
0005435766017	5492	Economy	11800.00
0005435766030	5492	Economy	11800.00
0005435766060	5492	Economy	11800.00
0005435722047	5492	Economy	11800.00
0005435766058	5492	Economy	11800.00
0005432140422	5492	Economy	11800.00
0005435766021	5492	Economy	11800.00
0005432535758	5492	Economy	11800.00
0005435461932	5492	Economy	11800.00
0005435461894	5492	Economy	11800.00
0005435461991	5492	Economy	11800.00
0005434264861	5492	Economy	11800.00
0005434264941	5492	Economy	11800.00
0005435766028	5492	Economy	11800.00
0005435735124	5492	Economy	11800.00
0005433527255	5492	Economy	11800.00
0005435766008	5492	Economy	11800.00
0005435766043	5492	Economy	11800.00
0005435766036	5492	Economy	11800.00
0005435461945	5492	Economy	11800.00
0005435766022	5492	Economy	11800.00
0005435462045	5492	Economy	11800.00
0005435766019	5492	Economy	11800.00
0005435462110	5492	Economy	11800.00
0005435461955	5492	Economy	11800.00
0005435766047	5492	Economy	11800.00
0005435461944	5492	Economy	11800.00
0005435723037	5492	Economy	11800.00
0005435766072	5492	Economy	11800.00
0005434264848	5492	Economy	11800.00
0005435766053	5492	Economy	11800.00
0005435766057	5492	Economy	11800.00
0005435766054	5492	Economy	11800.00
0005433529268	5492	Economy	11800.00
0005435461899	5492	Economy	11800.00
0005435725581	5492	Economy	11800.00
0005435735123	5492	Economy	11800.00
0005434264893	5492	Economy	11800.00
0005434264839	5492	Economy	11800.00
0005435766010	5492	Economy	11800.00
0005434264758	5492	Economy	11800.00
0005435461832	5492	Economy	11800.00
0005433529266	5492	Economy	11800.00
0005435461846	5492	Economy	11800.00
0005435766068	5492	Economy	11800.00
0005432535774	5492	Economy	11800.00
0005434264875	5492	Economy	11800.00
0005435766011	5492	Economy	11800.00
0005435461870	5492	Economy	11800.00
0005435735078	13491	Business	35300.00
0005435462303	13491	Business	35300.00
0005435765474	13491	Business	35300.00
0005435462316	13491	Business	35300.00
0005435765296	13491	Business	35300.00
0005434265050	13491	Business	35300.00
0005435462332	13491	Business	35300.00
0005432194496	13491	Business	35300.00
0005435765306	13491	Business	35300.00
0005434265069	13491	Business	35300.00
0005435765612	13491	Business	35300.00
0005435765563	13491	Business	35300.00
0005435765613	13491	Business	35300.00
0005434265048	13491	Business	35300.00
0005434831134	13491	Business	35300.00
0005434265067	13491	Business	35300.00
0005435765626	13491	Business	35300.00
0005435765358	13491	Business	35300.00
0005434265062	13491	Business	35300.00
0005435043284	13491	Business	35300.00
0005434265072	13491	Business	35300.00
0005435462297	13491	Business	35300.00
0005435765680	13491	Business	35300.00
0005435765426	13491	Business	35300.00
0005435725546	13491	Business	35300.00
0005434265058	13491	Business	35300.00
0005435462319	13491	Economy	12900.00
0005435462311	13491	Economy	12900.00
0005434831135	13491	Economy	12900.00
0005435725526	13491	Economy	11800.00
0005434265046	13491	Economy	11800.00
0005435462325	13491	Economy	11800.00
0005435735069	13491	Economy	11800.00
0005434265055	13491	Economy	11800.00
0005435462307	13491	Economy	11800.00
0005434265060	13491	Economy	11800.00
0005435765472	13491	Economy	11800.00
0005435765450	13491	Economy	11800.00
0005435765260	13491	Economy	11800.00
0005435765401	13491	Economy	11800.00
0005435765653	13491	Economy	11800.00
0005434265051	13491	Economy	11800.00
0005435765291	13491	Economy	11800.00
0005434831138	13491	Economy	11800.00
0005435462328	13491	Economy	11800.00
0005435765339	13491	Economy	11800.00
0005435765354	13491	Economy	11800.00
0005435765505	13491	Economy	11800.00
0005434265063	13491	Economy	11800.00
0005435765504	13491	Economy	11800.00
0005435462298	13491	Economy	11800.00
0005435765471	13491	Economy	11800.00
0005434831137	13491	Economy	11800.00
0005435765387	13491	Economy	11800.00
0005435462318	13491	Economy	11800.00
0005435765386	13491	Economy	11800.00
0005434265064	13491	Economy	11800.00
0005435462309	13491	Economy	11800.00
0005435722014	13491	Economy	11800.00
0005434265070	13491	Economy	11800.00
0005435462333	13491	Economy	11800.00
0005435462323	13491	Economy	11800.00
0005435723013	13491	Economy	11800.00
0005434265066	13491	Economy	11800.00
0005435765485	13491	Economy	11800.00
0005435723028	13491	Economy	11800.00
0005435462324	13491	Economy	11800.00
0005435765402	13491	Economy	11800.00
0005435765753	13491	Economy	11800.00
0005435765353	13491	Economy	11800.00
0005435765625	13491	Economy	11800.00
0005434265045	13491	Economy	11800.00
0005435765729	13491	Economy	11800.00
0005435765524	13491	Economy	11800.00
0005435765307	13491	Economy	11800.00
0005435765581	13491	Economy	11800.00
0005435462315	13491	Economy	11800.00
0005435765796	13491	Economy	11800.00
0005435765425	13491	Economy	11800.00
0005435462331	13491	Economy	11800.00
0005435765585	13491	Economy	11800.00
0005435462329	13491	Economy	11800.00
0005435735068	13491	Economy	11800.00
0005435723029	13491	Economy	11800.00
0005435462299	13491	Economy	11800.00
0005435765196	13491	Economy	11800.00
0005435765437	13491	Economy	11800.00
0005434265052	13491	Economy	11800.00
0005434265047	13491	Economy	11800.00
0005435462321	13491	Economy	11800.00
0005435765681	13491	Economy	11800.00
0005435765627	13491	Economy	11800.00
0005435765486	13491	Economy	11800.00
0005435735091	13491	Economy	11800.00
0005435765442	13491	Economy	11800.00
0005435765439	13491	Economy	11800.00
0005432535821	13491	Economy	11800.00
0005435725525	13491	Economy	11800.00
0005435765487	13491	Economy	11800.00
0005435765511	13491	Economy	11800.00
0005435462300	13491	Economy	11800.00
0005435462330	13491	Economy	11800.00
0005435765197	13491	Economy	11800.00
0005434265059	13491	Economy	12900.00
0005435462327	13491	Economy	12900.00
0005435720122	13491	Economy	11800.00
0005435765599	13491	Economy	12900.00
0005432194497	13491	Economy	11800.00
0005434265053	13491	Economy	12900.00
0005434265071	13491	Economy	11800.00
0005435462308	13491	Economy	11800.00
0005434265065	13491	Economy	11800.00
0005435462302	13491	Economy	11800.00
0005432535819	13491	Economy	11800.00
0005435765407	13491	Economy	11800.00
0005435765438	13491	Economy	11800.00
0005435765577	13491	Economy	11800.00
0005435462317	13491	Economy	11800.00
0005435462313	13491	Economy	11800.00
0005435765453	13491	Economy	11800.00
0005432535820	13491	Economy	11800.00
0005435462320	13491	Economy	11800.00
0005435765441	13491	Economy	11800.00
0005435735076	13491	Economy	11800.00
0005435462335	13491	Economy	11800.00
0005435462310	13491	Economy	11800.00
0005435765575	13491	Economy	11800.00
0005435720123	13491	Economy	11800.00
0005435765589	13491	Economy	11800.00
0005435765357	13491	Economy	11800.00
0005435765338	13491	Economy	11800.00
0005432194498	13491	Economy	11800.00
0005435462304	13491	Economy	11800.00
0005435765418	13491	Economy	11800.00
0005435765388	13491	Economy	11800.00
0005435462301	13491	Economy	11800.00
0005434265049	13491	Economy	11800.00
0005435725545	13491	Economy	11800.00
0005435462312	13491	Economy	11800.00
0005432194495	13491	Economy	11800.00
0005435765403	13491	Economy	11800.00
0005435765582	13491	Economy	11800.00
0005435765728	13491	Economy	11800.00
0005435765309	13491	Economy	11800.00
0005432535817	13491	Economy	11800.00
0005434265061	13491	Economy	11800.00
0005435765576	13491	Economy	11800.00
0005435765652	13491	Economy	11800.00
0005434265057	13491	Economy	11800.00
0005435462305	13491	Economy	11800.00
0005435735101	13491	Economy	11800.00
0005435462334	13491	Economy	11800.00
0005435765580	13491	Economy	11800.00
0005435735075	13491	Economy	11800.00
0005435765752	13491	Economy	11800.00
0005434265054	13491	Economy	11800.00
0005435765421	13491	Economy	11800.00
0005435765492	13491	Economy	11800.00
0005434265056	13491	Economy	11800.00
0005435462314	13491	Economy	11800.00
0005432535818	13491	Economy	11800.00
0005435725522	13491	Economy	11800.00
0005434265068	13491	Economy	11800.00
0005434831136	13491	Economy	11800.00
0005435462306	13491	Economy	11800.00
0005435462322	13491	Economy	11800.00
0005435462326	13491	Economy	11800.00
0005434602868	18748	Economy	3300.00
0005434602869	18748	Economy	3300.00
0005434514957	18677	Economy	3300.00
0005434604857	18677	Economy	3300.00
0005434514958	18677	Economy	3300.00
0005434604858	18677	Economy	3300.00
0005434513569	18677	Economy	3300.00
0005434513570	18677	Economy	3300.00
0005434604856	18677	Economy	3300.00
0005434602888	19107	Economy	3300.00
0005434602887	19107	Economy	3300.00
0005434602892	19107	Economy	3300.00
0005434602886	19107	Economy	3300.00
0005434602891	19107	Economy	3300.00
0005434603019	19107	Economy	3300.00
0005434602889	19107	Economy	3300.00
0005434602893	19107	Economy	3300.00
0005434602890	19107	Economy	3300.00
0005434603020	19107	Economy	3300.00
0005432649321	25087	Business	88300.00
0005435844305	25087	Business	88300.00
0005435844302	25087	Business	88300.00
0005435846237	25087	Business	88300.00
0005435844308	25087	Business	88300.00
0005432649311	25087	Economy	29400.00
0005432649340	25087	Economy	29400.00
0005432649316	25087	Economy	29400.00
0005432632654	25087	Economy	29400.00
0005432649331	25087	Economy	29400.00
0005435844303	25087	Economy	29400.00
0005435844309	25087	Economy	32400.00
0005432632637	25087	Economy	29400.00
0005435846239	25087	Economy	29400.00
0005432649341	25087	Economy	29400.00
0005435844301	25087	Economy	29400.00
0005435846242	25087	Economy	29400.00
0005435844304	25087	Economy	29400.00
0005432649324	25087	Economy	29400.00
0005432632625	25087	Economy	29400.00
0005435844306	25087	Economy	29400.00
0005432649317	25087	Economy	29400.00
0005435846241	25087	Economy	29400.00
0005432632638	25087	Economy	29400.00
0005432632628	25087	Economy	29400.00
0005432649339	25087	Economy	29400.00
0005432632646	25087	Economy	29400.00
0005432632626	25087	Economy	29400.00
0005435844299	25087	Economy	29400.00
0005435846243	25087	Economy	29400.00
0005432649313	25087	Economy	29400.00
0005435846236	25087	Economy	29400.00
0005432632645	25087	Economy	29400.00
0005435844311	25087	Economy	29400.00
0005432649314	25087	Economy	29400.00
0005432649318	25087	Economy	29400.00
0005432632621	25087	Economy	29400.00
0005432632639	25087	Economy	29400.00
0005435846240	25087	Economy	29400.00
0005435844312	25087	Economy	29400.00
0005432649336	25087	Economy	29400.00
0005432649332	25087	Economy	29400.00
0005432632653	25087	Economy	29400.00
0005432649312	25087	Economy	29400.00
0005432632622	25087	Economy	29400.00
0005435844300	25087	Economy	29400.00
0005435844310	25087	Economy	29400.00
0005432632630	25087	Economy	29400.00
0005432649315	25087	Economy	29400.00
0005432649322	25087	Economy	29400.00
0005432649329	25087	Economy	29400.00
0005435846238	25087	Economy	29400.00
0005432649325	25087	Economy	29400.00
0005435844307	25087	Economy	29400.00
0005432632642	25087	Economy	29400.00
0005432649309	25087	Economy	29400.00
0005432649343	25087	Economy	29400.00
0005433284958	1793	Business	48700.00
0005433284961	1793	Business	48700.00
0005433008186	1793	Business	48700.00
0005433008102	1793	Business	48700.00
0005433008103	1793	Business	48700.00
0005433284950	1793	Business	48700.00
0005433008234	1793	Business	48700.00
0005433284947	1793	Business	48700.00
0005432295872	1793	Business	48700.00
0005433008092	1793	Business	48700.00
0005433008015	1793	Business	48700.00
0005433008138	1793	Economy	16200.00
0005433810530	1793	Economy	16200.00
0005433008136	1793	Economy	16200.00
0005433008117	1793	Economy	16200.00
0005433008004	1793	Economy	16200.00
0005433285014	1793	Economy	17900.00
0005433284866	1793	Economy	17900.00
0005433008224	1793	Economy	17900.00
0005433284914	1793	Economy	17900.00
0005433284967	1793	Economy	17900.00
0005433008145	1793	Economy	16200.00
0005433008005	1793	Economy	16200.00
0005433008140	1793	Economy	16200.00
0005433008139	1793	Economy	16200.00
0005433284949	1793	Economy	16200.00
0005433284930	1793	Economy	16200.00
0005433008021	1793	Economy	16200.00
0005433284781	1793	Economy	16200.00
0005433008183	1793	Economy	16200.00
0005433008078	1793	Economy	16200.00
0005433008087	1793	Economy	16200.00
0005433008091	1793	Economy	16200.00
0005433285003	1793	Economy	16200.00
0005433284925	1793	Economy	16200.00
0005433284966	1793	Economy	16200.00
0005433008211	1793	Economy	16200.00
0005433008100	1793	Economy	16200.00
0005433284945	1793	Economy	16200.00
0005433285061	1793	Economy	16200.00
0005433008024	1793	Economy	16200.00
0005433008014	1793	Economy	16200.00
0005433008210	1793	Economy	16200.00
0005433810533	1793	Economy	16200.00
0005433008123	1793	Economy	16200.00
0005433810529	1793	Economy	16200.00
0005433285036	1793	Economy	16200.00
0005433008134	1793	Economy	16200.00
0005433284923	1793	Economy	16200.00
0005433008141	1793	Economy	16200.00
0005433810531	1793	Economy	16200.00
0005433008217	1793	Economy	16200.00
0005432295870	1793	Economy	16200.00
0005433008242	1793	Economy	16200.00
0005433284933	1793	Economy	16200.00
0005433284924	1793	Economy	16200.00
0005433285060	1793	Economy	16200.00
0005433008219	1793	Economy	16200.00
0005433008184	1793	Economy	16200.00
0005433285030	1793	Economy	16200.00
0005433284780	1793	Economy	16200.00
0005433285035	1793	Economy	16200.00
0005433285062	1793	Economy	16200.00
0005433008101	1793	Economy	16200.00
0005433008203	1793	Economy	16200.00
0005433284946	1793	Economy	16200.00
0005433810532	1793	Economy	16200.00
0005432295871	1793	Economy	16200.00
0005433008135	1793	Economy	16200.00
0005433008104	1793	Economy	16200.00
0005433008124	1793	Economy	16200.00
0005433008003	1793	Economy	16200.00
0005433008002	1793	Economy	16200.00
0005433008146	1793	Economy	16200.00
0005433284944	1793	Economy	16200.00
0005433285015	1793	Economy	16200.00
0005433008055	1793	Economy	16200.00
0005433008233	1793	Economy	16200.00
0005433810534	1793	Economy	16200.00
0005433285197	22564	Business	48700.00
0005433008462	22564	Business	48700.00
0005433008451	22564	Business	48700.00
0005433008439	22564	Business	48700.00
0005433285192	22564	Business	48700.00
0005433285169	22564	Business	48700.00
0005433008443	22564	Business	48700.00
0005433285196	22564	Business	48700.00
0005433008435	22564	Business	48700.00
0005433008463	22564	Business	48700.00
0005433008446	22564	Economy	16200.00
0005433008442	22564	Economy	16200.00
0005433008425	22564	Economy	16200.00
0005433285187	22564	Economy	16200.00
0005433285167	22564	Economy	16200.00
0005433008426	22564	Economy	16200.00
0005433008458	22564	Economy	16200.00
0005433285168	22564	Economy	16200.00
0005433008471	22564	Economy	17900.00
0005433008445	22564	Economy	17900.00
0005433285182	22564	Economy	17900.00
0005433285191	22564	Economy	17900.00
0005433008434	22564	Economy	16200.00
0005433285198	22564	Economy	16200.00
0005433008448	22564	Economy	16200.00
0005433285177	22564	Economy	16200.00
0005433008438	22564	Economy	16200.00
0005433008457	22564	Economy	16200.00
0005433008456	22564	Economy	16200.00
0005433008440	22564	Economy	16200.00
0005433008436	22564	Economy	16200.00
0005433285180	22564	Economy	16200.00
0005433008450	22564	Economy	16200.00
0005433285178	22564	Economy	16200.00
0005433285189	22564	Economy	16200.00
0005433008464	22564	Economy	16200.00
0005433285183	22564	Economy	16200.00
0005433810493	22564	Economy	16200.00
0005433285181	22564	Economy	16200.00
0005433008444	22564	Economy	16200.00
0005433285190	22564	Economy	16200.00
0005433285194	22564	Economy	16200.00
0005433008431	22564	Economy	16200.00
0005433285170	22564	Economy	16200.00
0005433285172	22564	Economy	16200.00
0005433008430	22564	Economy	16200.00
0005433285186	22564	Economy	16200.00
0005433008452	22564	Economy	16200.00
0005433008437	22564	Economy	16200.00
0005433810489	22564	Economy	16200.00
0005433008469	22564	Economy	16200.00
0005433008429	22564	Economy	16200.00
0005433008433	22564	Economy	16200.00
0005433008449	22564	Economy	16200.00
0005433285171	22564	Economy	16200.00
0005433285195	22564	Economy	16200.00
0005433008468	22564	Economy	16200.00
0005433008466	22564	Economy	16200.00
0005433285173	22564	Economy	16200.00
0005433285174	22564	Economy	16200.00
0005433008460	22564	Economy	16200.00
0005433008454	22564	Economy	16200.00
0005433285184	22564	Economy	16200.00
0005433008447	22564	Economy	16200.00
0005433008467	22564	Economy	16200.00
0005433285179	22564	Economy	16200.00
0005433008432	22564	Economy	16200.00
0005433285188	22564	Economy	16200.00
0005433285175	22564	Economy	16200.00
0005433285185	22564	Economy	16200.00
0005433008427	22564	Economy	16200.00
0005433008461	22564	Economy	16200.00
0005433285193	22564	Economy	16200.00
0005433008455	22564	Economy	16200.00
0005433008470	22564	Economy	16200.00
0005433008441	22564	Economy	16200.00
0005433008465	22564	Economy	16200.00
0005433008459	22564	Economy	16200.00
0005433285176	22564	Economy	16200.00
0005433008453	22564	Economy	16200.00
0005433008428	22564	Economy	16200.00
0005432756829	25346	Business	83800.00
0005434152752	25346	Business	83800.00
0005432756826	25346	Business	83800.00
0005432755063	25346	Business	83800.00
0005434153517	25346	Business	83800.00
0005432755051	25346	Economy	27900.00
0005434153515	25346	Economy	27900.00
0005434152771	25346	Economy	27900.00
0005432756827	25346	Economy	27900.00
0005432756834	25346	Economy	30700.00
0005432755059	25346	Economy	30700.00
0005432755060	25346	Economy	27900.00
0005432756832	25346	Economy	27900.00
0005432755057	25346	Economy	27900.00
0005432755058	25346	Economy	27900.00
0005432756830	25346	Economy	27900.00
0005432756822	25346	Economy	27900.00
0005432755062	25346	Economy	27900.00
0005432756824	25346	Economy	27900.00
0005432755054	25346	Economy	27900.00
0005432756821	25346	Economy	27900.00
0005432755052	25346	Economy	27900.00
0005434153526	25346	Economy	27900.00
0005434152754	25346	Economy	27900.00
0005432755056	25346	Economy	27900.00
0005434152753	25346	Economy	27900.00
0005434152759	25346	Economy	27900.00
0005432756825	25346	Economy	27900.00
0005432756828	25346	Economy	27900.00
0005434152765	25346	Economy	27900.00
0005432755049	25346	Economy	27900.00
0005432756831	25346	Economy	27900.00
0005432755055	25346	Economy	27900.00
0005434152751	25346	Economy	27900.00
0005434152758	25346	Economy	27900.00
0005432755053	25346	Economy	27900.00
0005432755061	25346	Economy	27900.00
0005432755050	25346	Economy	27900.00
0005432756823	25346	Economy	27900.00
0005432756833	25346	Economy	27900.00
0005433846534	5574	Business	99800.00
0005433846548	5574	Business	99800.00
0005432081489	5574	Business	99800.00
0005433846537	5574	Business	99800.00
0005433846518	5574	Business	99800.00
0005433846539	5574	Business	99800.00
0005433846555	5574	Business	99800.00
0005433846535	5574	Business	99800.00
0005433846500	5574	Business	99800.00
0005433846501	5574	Business	99800.00
0005433846558	5574	Business	99800.00
0005433815369	5574	Business	99800.00
0005433846503	5574	Business	99800.00
0005434173468	5574	Business	99800.00
0005432081490	5574	Business	99800.00
0005433846551	5574	Business	99800.00
0005433846510	5574	Economy	33300.00
0005435282303	5574	Business	99800.00
0005435282290	5574	Economy	33300.00
0005433846516	5574	Economy	33300.00
0005433846532	5574	Economy	33300.00
0005433846526	5574	Economy	33300.00
0005433846521	5574	Economy	33300.00
0005433846517	5574	Economy	33300.00
0005434173480	5574	Economy	33300.00
0005433846547	5574	Economy	33300.00
0005434173457	5574	Economy	33300.00
0005433846550	5574	Economy	33300.00
0005433846506	5574	Economy	36600.00
0005435282137	5574	Economy	36600.00
0005433846524	5574	Economy	36600.00
0005434173469	5574	Economy	36600.00
0005433846540	5574	Economy	33300.00
0005433846515	5574	Economy	33300.00
0005435282206	5574	Economy	33300.00
0005433815366	5574	Economy	33300.00
0005433815368	5574	Economy	33300.00
0005433846504	5574	Economy	33300.00
0005435282279	5574	Economy	33300.00
0005435282273	5574	Economy	33300.00
0005435282150	5574	Economy	33300.00
0005432081492	5574	Economy	33300.00
0005433815364	5574	Economy	33300.00
0005435282178	5574	Economy	33300.00
0005432081488	5574	Economy	33300.00
0005435282136	5574	Economy	33300.00
0005432081491	5574	Economy	33300.00
0005433846559	5574	Economy	33300.00
0005433846511	5574	Economy	33300.00
0005433846507	5574	Economy	33300.00
0005433846523	5574	Economy	33300.00
0005435282135	5574	Economy	33300.00
0005435282199	5574	Economy	33300.00
0005433846525	5574	Economy	33300.00
0005433846546	5574	Economy	33300.00
0005433815365	5574	Economy	33300.00
0005433815367	5574	Economy	33300.00
0005433846543	5574	Economy	33300.00
0005433846553	5574	Economy	33300.00
0005433846522	5574	Economy	33300.00
0005433846552	5574	Economy	33300.00
0005433846512	5574	Economy	33300.00
0005435282139	5574	Economy	33300.00
0005433846536	5574	Economy	33300.00
0005433846545	5574	Economy	33300.00
0005433846502	5574	Economy	33300.00
0005435282245	5574	Economy	33300.00
0005433846554	5574	Economy	33300.00
0005433846531	5574	Economy	33300.00
0005433846529	5574	Economy	33300.00
0005435282265	5574	Economy	33300.00
0005435282227	5574	Economy	33300.00
0005435282207	5574	Economy	33300.00
0005433846527	5574	Economy	33300.00
0005435282272	5574	Economy	33300.00
0005433846557	5574	Economy	33300.00
0005433846505	5574	Economy	33300.00
0005435282302	5574	Economy	33300.00
0005435282177	5574	Economy	33300.00
0005433846542	5574	Economy	33300.00
0005433846520	5574	Economy	33300.00
0005433846508	5574	Economy	33300.00
0005433846519	5574	Economy	33300.00
0005433846530	5574	Economy	33300.00
0005435282214	5574	Economy	33300.00
0005435282198	5574	Economy	33300.00
0005433846513	5574	Economy	33300.00
0005432081487	5574	Economy	33300.00
0005433846549	5574	Economy	33300.00
0005433846514	5574	Economy	33300.00
0005433846538	5574	Economy	33300.00
0005435282162	5574	Economy	33300.00
0005433846528	5574	Economy	33300.00
0005435282247	5574	Economy	33300.00
0005433846509	5574	Economy	33300.00
0005433846556	5574	Economy	33300.00
0005433846533	5574	Economy	33300.00
0005433846541	5574	Economy	33300.00
0005435282289	5574	Economy	33300.00
0005433846544	5574	Economy	33300.00
0005433846027	13875	Business	99800.00
0005433845917	13875	Business	99800.00
0005432003690	13875	Business	99800.00
0005432003691	13875	Business	99800.00
0005435282428	13875	Business	99800.00
0005433846011	13875	Business	99800.00
0005433845932	13875	Business	99800.00
0005435282448	13875	Business	99800.00
0005433846119	13875	Business	99800.00
0005435282425	13875	Business	99800.00
0005433846176	13875	Business	99800.00
0005435282436	13875	Business	99800.00
0005435282432	13875	Business	99800.00
0005433846044	13875	Business	99800.00
0005434173506	13875	Business	99800.00
0005433846037	13875	Business	99800.00
0005433815346	13875	Business	99800.00
0005433845962	13875	Business	99800.00
0005433846082	13875	Economy	33300.00
0005433845905	13875	Business	99800.00
0005435282434	13875	Economy	33300.00
0005433845948	13875	Economy	33300.00
0005433846068	13875	Economy	33300.00
0005435282422	13875	Economy	33300.00
0005433845690	13875	Economy	33300.00
0005433846015	13875	Economy	33300.00
0005433846178	13875	Economy	33300.00
0005433845844	13875	Economy	33300.00
0005433845936	13875	Economy	33300.00
0005433845684	13875	Economy	33300.00
0005433846247	13875	Economy	36600.00
0005433846071	13875	Economy	36600.00
0005433845887	13875	Economy	33300.00
0005434173508	13875	Economy	36600.00
0005435282423	13875	Economy	33300.00
0005433845691	13875	Economy	33300.00
0005435282444	13875	Economy	33300.00
0005433845692	13875	Economy	33300.00
0005433845933	13875	Economy	33300.00
0005435282438	13875	Economy	33300.00
0005433845913	13875	Economy	33300.00
0005435282435	13875	Economy	33300.00
0005433845682	13875	Economy	33300.00
0005433846061	13875	Economy	33300.00
0005433845906	13875	Economy	33300.00
0005435282443	13875	Economy	33300.00
0005433845717	13875	Economy	33300.00
0005435282442	13875	Economy	33300.00
0005433846146	13875	Economy	33300.00
0005432003692	13875	Economy	33300.00
0005435282431	13875	Economy	33300.00
0005435282433	13875	Economy	33300.00
0005433846159	13875	Economy	33300.00
0005433846050	13875	Economy	33300.00
0005433845843	13875	Economy	33300.00
0005433846103	13875	Economy	33300.00
0005435282427	13875	Economy	33300.00
0005433846194	13875	Economy	33300.00
0005435282447	13875	Economy	33300.00
0005435282437	13875	Economy	33300.00
0005435282445	13875	Economy	33300.00
0005433845773	13875	Economy	33300.00
0005433846235	13875	Economy	33300.00
0005433846120	13875	Economy	33300.00
0005433845940	13875	Economy	33300.00
0005433846239	13875	Economy	33300.00
0005433845888	13875	Economy	33300.00
0005435282426	13875	Economy	33300.00
0005433845716	13875	Economy	33300.00
0005435282429	13875	Economy	33300.00
0005433815345	13875	Economy	33300.00
0005433846229	13875	Economy	33300.00
0005435282439	13875	Economy	33300.00
0005434173509	13875	Economy	33300.00
0005434173507	13875	Economy	33300.00
0005433846099	13875	Economy	33300.00
0005433846069	13875	Economy	33300.00
0005433846287	13875	Economy	33300.00
0005435282421	13875	Economy	33300.00
0005433846046	13875	Economy	33300.00
0005433845693	13875	Economy	33300.00
0005435282446	13875	Economy	33300.00
0005433845968	13875	Economy	33300.00
0005435282430	13875	Economy	33300.00
0005433846177	13875	Economy	33300.00
0005433846079	13875	Economy	33300.00
0005433845799	13875	Economy	33300.00
0005433846023	13875	Economy	33300.00
0005433846195	13875	Economy	33300.00
0005433846038	13875	Economy	33300.00
0005433846126	13875	Economy	33300.00
0005433845685	13875	Economy	33300.00
0005433846045	13875	Economy	33300.00
0005433846016	13875	Economy	33300.00
0005433846127	13875	Economy	33300.00
0005433846145	13875	Economy	33300.00
0005433845964	13875	Economy	33300.00
0005433846196	13875	Economy	33300.00
0005433846197	13875	Economy	33300.00
0005435282440	13875	Economy	33300.00
0005433845886	13875	Economy	33300.00
0005433846062	13875	Economy	33300.00
0005433846028	13875	Economy	33300.00
0005435282441	13875	Economy	33300.00
0005435282424	13875	Economy	33300.00
0005435332260	7837	Economy	16600.00
0005435332231	7837	Economy	16600.00
0005432112507	7837	Economy	16600.00
0005434620533	7837	Economy	16600.00
0005434620520	7837	Economy	15100.00
0005434620537	7837	Economy	15100.00
0005434620517	7837	Economy	15100.00
0005434620518	7837	Economy	15100.00
0005434620523	7837	Economy	15100.00
0005434620528	7837	Economy	15100.00
0005434620535	7837	Economy	15100.00
0005434620524	7837	Economy	15100.00
0005435332216	7837	Economy	15100.00
0005434620519	7837	Economy	15100.00
0005435332194	7837	Economy	15100.00
0005434620529	7837	Economy	15100.00
0005435332244	7837	Economy	15100.00
0005434620521	7837	Economy	15100.00
0005434620522	7837	Economy	15100.00
0005434620516	7837	Economy	15100.00
0005434620531	7837	Economy	15100.00
0005435332243	7837	Economy	15100.00
0005432112509	7837	Economy	15100.00
0005434620530	7837	Economy	15100.00
0005434620525	7837	Economy	15100.00
0005432112508	7837	Economy	15100.00
0005434620532	7837	Economy	15100.00
0005434620526	7837	Economy	15100.00
0005434620527	7837	Economy	15100.00
0005435332229	7837	Economy	15100.00
0005435332225	7837	Economy	15100.00
0005435332242	7837	Economy	15100.00
0005435332183	7837	Economy	15100.00
0005434620536	7837	Economy	15100.00
0005435332217	7837	Economy	15100.00
0005434620534	7837	Economy	15100.00
0005435332193	7837	Economy	15100.00
0005435332178	7837	Economy	15100.00
0005435332299	32980	Economy	16600.00
0005434620370	32980	Economy	16600.00
0005434620271	32980	Economy	15100.00
0005434620349	32980	Economy	15100.00
0005434620384	32980	Economy	15100.00
0005435332298	32980	Economy	15100.00
0005435332306	32980	Economy	15100.00
0005435332300	32980	Economy	15100.00
0005435332304	32980	Economy	15100.00
0005435332295	32980	Economy	15100.00
0005434620328	32980	Economy	15100.00
0005434620332	32980	Economy	15100.00
0005434620379	32980	Economy	15100.00
0005435332296	32980	Economy	15100.00
0005434620374	32980	Economy	15100.00
0005434620351	32980	Economy	15100.00
0005434620348	32980	Economy	15100.00
0005434620368	32980	Economy	15100.00
0005435332303	32980	Economy	15100.00
0005434620369	32980	Economy	15100.00
0005435332305	32980	Economy	15100.00
0005435332302	32980	Economy	15100.00
0005434620355	32980	Economy	15100.00
0005434620378	32980	Economy	15100.00
0005434620306	32980	Economy	15100.00
0005435332297	32980	Economy	15100.00
0005434620307	32980	Economy	15100.00
0005435332301	32980	Economy	15100.00
0005434620385	32980	Economy	15100.00
0005434620364	32980	Economy	15100.00
0005434993993	4298	Business	38000.00
0005435918606	4298	Business	38000.00
0005435785232	4298	Business	38000.00
0005435785228	4298	Business	38000.00
0005434993994	4298	Business	38000.00
0005435785254	4298	Business	38000.00
0005435918605	4298	Business	38000.00
0005435785253	4298	Economy	12700.00
0005435785248	4298	Economy	12700.00
0005435787346	4298	Economy	12700.00
0005435785250	4298	Economy	12700.00
0005434993996	4298	Economy	12700.00
0005435785257	4298	Economy	12700.00
0005432190615	4298	Economy	12700.00
0005434993988	4298	Economy	13900.00
0005435785225	4298	Economy	13900.00
0005435937318	4298	Economy	13900.00
0005434993987	4298	Economy	13900.00
0005435785226	4298	Economy	12700.00
0005435785239	4298	Economy	12700.00
0005435785247	4298	Economy	12700.00
0005434993989	4298	Economy	12700.00
0005435785258	4298	Economy	12700.00
0005435785234	4298	Economy	12700.00
0005435785249	4298	Economy	12700.00
0005435785235	4298	Economy	12700.00
0005435785241	4298	Economy	12700.00
0005435785242	4298	Economy	12700.00
0005434993990	4298	Economy	12700.00
0005432190617	4298	Economy	12700.00
0005435785230	4298	Economy	12700.00
0005435785240	4298	Economy	12700.00
0005435787347	4298	Economy	12700.00
0005435785251	4298	Economy	12700.00
0005434993992	4298	Economy	12700.00
0005435785236	4298	Economy	12700.00
0005434993991	4298	Economy	12700.00
0005435785244	4298	Economy	12700.00
0005435785237	4298	Economy	12700.00
0005435785229	4298	Economy	12700.00
0005435785233	4298	Economy	12700.00
0005434993995	4298	Economy	12700.00
0005432190616	4298	Economy	12700.00
0005435785252	4298	Economy	12700.00
0005435937328	4298	Economy	12700.00
0005435785238	4298	Economy	12700.00
0005435785245	4298	Economy	12700.00
0005435785231	4298	Economy	12700.00
0005435785256	4298	Economy	12700.00
0005435785223	4298	Economy	12700.00
0005435918600	4298	Economy	12700.00
0005435787348	4298	Economy	12700.00
0005435918599	4298	Economy	12700.00
0005434993985	4298	Economy	12700.00
0005435918614	4298	Economy	12700.00
0005435785224	4298	Economy	12700.00
0005432190618	4298	Economy	12700.00
0005435785243	4298	Economy	12700.00
0005435785255	4298	Economy	12700.00
0005435785246	4298	Economy	12700.00
0005435785227	4298	Economy	12700.00
0005434993986	4298	Economy	12700.00
0005435937372	27308	Business	38000.00
0005435784741	27308	Business	38000.00
0005435937374	27308	Business	38000.00
0005435784915	27308	Business	38000.00
0005434993893	27308	Business	38000.00
0005435918639	27308	Business	38000.00
0005432195684	27308	Business	38000.00
0005434993894	27308	Business	38000.00
0005435784946	27308	Business	38000.00
0005435784796	27308	Business	38000.00
0005435937367	27308	Economy	12700.00
0005435784884	27308	Economy	12700.00
0005435785005	27308	Economy	12700.00
0005434993897	27308	Economy	12700.00
0005434993908	27308	Economy	12700.00
0005434993913	27308	Economy	12700.00
0005435937370	27308	Economy	13900.00
0005435784905	27308	Economy	13900.00
0005435784965	27308	Economy	13900.00
0005435784887	27308	Economy	12700.00
0005435784923	27308	Economy	12700.00
0005435918640	27308	Economy	12700.00
0005435784842	27308	Economy	12700.00
0005435937369	27308	Economy	12700.00
0005435784962	27308	Economy	12700.00
0005435785007	27308	Economy	12700.00
0005435937368	27308	Economy	12700.00
0005434993912	27308	Economy	12700.00
0005434993907	27308	Economy	12700.00
0005435784966	27308	Economy	12700.00
0005435784883	27308	Economy	12700.00
0005435784967	27308	Economy	12700.00
0005435937371	27308	Economy	12700.00
0005435784964	27308	Economy	12700.00
0005435918638	27308	Economy	12700.00
0005435784786	27308	Economy	12700.00
0005434993915	27308	Economy	12700.00
0005435784994	27308	Economy	12700.00
0005435784861	27308	Economy	12700.00
0005435784934	27308	Economy	12700.00
0005432195685	27308	Economy	12700.00
0005435784928	27308	Economy	12700.00
0005434993940	27308	Economy	12700.00
0005434993896	27308	Economy	12700.00
0005434993917	27308	Economy	12700.00
0005434993880	27308	Economy	12700.00
0005435785006	27308	Economy	12700.00
0005435784935	27308	Economy	12700.00
0005435784751	27308	Economy	12700.00
0005435784910	27308	Economy	12700.00
0005435937373	27308	Economy	12700.00
0005435784862	27308	Economy	12700.00
0005435918641	27308	Economy	12700.00
0005435784752	27308	Economy	12700.00
0005435784869	27308	Economy	12700.00
0005435784914	27308	Economy	12700.00
0005435784999	27308	Economy	12700.00
0005432146191	19875	Economy	14000.00
0005432567440	4727	Business	40900.00
0005432459671	4727	Business	40900.00
0005432459687	4727	Business	40900.00
0005432567452	4727	Business	40900.00
0005432567451	4727	Business	40900.00
0005434081830	4727	Business	40900.00
0005432459672	4727	Business	40900.00
0005432459688	4727	Business	40900.00
0005432567435	4727	Business	40900.00
0005432459700	4727	Business	40900.00
0005432567433	4727	Business	40900.00
0005432459693	4727	Business	40900.00
0005432459663	4727	Business	40900.00
0005432567425	4727	Business	40900.00
0005432567461	4727	Business	40900.00
0005432567424	4727	Business	40900.00
0005432459702	4727	Business	40900.00
0005432459660	4727	Business	40900.00
0005433451615	4727	Business	40900.00
0005432567419	4727	Business	40900.00
0005432571310	4727	Economy	15000.00
0005432459662	4727	Economy	15000.00
0005432567408	4727	Economy	15000.00
0005432567421	4727	Economy	13600.00
0005432571311	4727	Economy	13600.00
0005432459678	4727	Economy	13600.00
0005432459670	4727	Economy	13600.00
0005432567459	4727	Economy	13600.00
0005432567414	4727	Economy	13600.00
0005432459685	4727	Economy	13600.00
0005432567409	4727	Economy	13600.00
0005432567402	4727	Economy	13600.00
0005432567436	4727	Economy	13600.00
0005432459690	4727	Economy	13600.00
0005432567437	4727	Economy	13600.00
0005432567462	4727	Economy	13600.00
0005433726095	4727	Economy	13600.00
0005432459697	4727	Economy	13600.00
0005432567443	4727	Economy	13600.00
0005432571309	4727	Economy	13600.00
0005434081827	4727	Economy	13600.00
0005433726097	4727	Economy	13600.00
0005432567411	4727	Economy	13600.00
0005432459683	4727	Economy	13600.00
0005434081834	4727	Economy	13600.00
0005432567427	4727	Economy	13600.00
0005432170362	4727	Economy	13600.00
0005432459666	4727	Economy	13600.00
0005432567448	4727	Economy	13600.00
0005432567441	4727	Economy	13600.00
0005432459691	4727	Economy	13600.00
0005432571308	4727	Economy	13600.00
0005432459676	4727	Economy	13600.00
0005432567401	4727	Economy	13600.00
0005432567412	4727	Economy	13600.00
0005432186857	4727	Economy	13600.00
0005432567463	4727	Economy	13600.00
0005432459667	4727	Economy	13600.00
0005432459698	4727	Economy	13600.00
0005432459669	4727	Economy	13600.00
0005432459701	4727	Economy	13600.00
0005432459658	4727	Economy	13600.00
0005433452734	4727	Economy	13600.00
0005432459661	4727	Economy	13600.00
0005434081836	4727	Economy	13600.00
0005432567434	4727	Economy	13600.00
0005432459692	4727	Economy	13600.00
0005432170369	4727	Economy	13600.00
0005432459689	4727	Economy	13600.00
0005434081829	4727	Economy	13600.00
0005433452733	4727	Economy	13600.00
0005432567418	4727	Economy	13600.00
0005432459677	4727	Economy	13600.00
0005432567429	4727	Economy	13600.00
0005432567428	4727	Economy	13600.00
0005432459673	4727	Economy	13600.00
0005434081823	4727	Economy	13600.00
0005432567426	4727	Economy	13600.00
0005434081826	4727	Economy	13600.00
0005433451614	4727	Economy	13600.00
0005432567455	4727	Economy	13600.00
0005432567456	4727	Economy	13600.00
0005432459659	4727	Economy	13600.00
0005432186859	4727	Economy	13600.00
0005432170368	4727	Economy	13600.00
0005432459653	4727	Economy	13600.00
0005434081822	4727	Economy	13600.00
0005432567404	4727	Economy	13600.00
0005432567442	4727	Economy	13600.00
0005432459694	4727	Economy	13600.00
0005432459681	4727	Economy	13600.00
0005432567405	4727	Economy	13600.00
0005432459655	4727	Economy	13600.00
0005432459696	4727	Economy	13600.00
0005434081824	4727	Economy	13600.00
0005432567460	4727	Economy	15000.00
0005432186858	4727	Economy	13600.00
0005432567432	4727	Economy	13600.00
0005434081833	4727	Economy	13600.00
0005432459686	4727	Economy	15000.00
0005432567417	4727	Economy	15000.00
0005432459656	4727	Economy	13600.00
0005432459703	4727	Economy	13600.00
0005432567454	4727	Economy	13600.00
0005432459652	4727	Economy	13600.00
0005432567439	4727	Economy	13600.00
0005432459679	4727	Economy	13600.00
0005434081825	4727	Economy	13600.00
0005432567420	4727	Economy	13600.00
0005432459654	4727	Economy	13600.00
0005432170365	4727	Economy	13600.00
0005432170367	4727	Economy	13600.00
0005432170366	4727	Economy	13600.00
0005434081821	4727	Economy	13600.00
0005432459668	4727	Economy	13600.00
0005432170364	4727	Economy	13600.00
0005432459651	4727	Economy	13600.00
0005432567403	4727	Economy	13600.00
0005432567406	4727	Economy	13600.00
0005432459695	4727	Economy	13600.00
0005432567416	4727	Economy	13600.00
0005432459665	4727	Economy	13600.00
0005432567431	4727	Economy	13600.00
0005432567422	4727	Economy	13600.00
0005432459699	4727	Economy	13600.00
0005434081832	4727	Economy	13600.00
0005432459682	4727	Economy	13600.00
0005434081819	4727	Economy	13600.00
0005433451613	4727	Economy	13600.00
0005432567450	4727	Economy	13600.00
0005432459657	4727	Economy	13600.00
0005434081820	4727	Economy	13600.00
0005432170363	4727	Economy	13600.00
0005432567438	4727	Economy	13600.00
0005432567453	4727	Economy	13600.00
0005432567458	4727	Economy	13600.00
0005432567447	4727	Economy	13600.00
0005434081835	4727	Economy	13600.00
0005432567457	4727	Economy	13600.00
0005432459664	4727	Economy	13600.00
0005432459674	4727	Economy	13600.00
0005432459684	4727	Economy	13600.00
0005432567446	4727	Economy	13600.00
0005432567407	4727	Economy	13600.00
0005434081831	4727	Economy	13600.00
0005432567413	4727	Economy	13600.00
0005432459680	4727	Economy	13600.00
0005432567445	4727	Economy	13600.00
0005432567410	4727	Economy	13600.00
0005432186856	4727	Economy	13600.00
0005432567423	4727	Economy	13600.00
0005432567430	4727	Economy	13600.00
0005434081828	4727	Economy	13600.00
0005432567415	4727	Economy	13600.00
0005432567444	4727	Economy	13600.00
0005432459675	4727	Economy	13600.00
0005433726096	4727	Economy	13600.00
0005432567449	4727	Economy	13600.00
0005434081522	30543	Business	40900.00
0005432567138	30543	Business	40900.00
0005432459014	30543	Business	40900.00
0005434081586	30543	Business	40900.00
0005432566627	30543	Business	40900.00
0005434081547	30543	Business	40900.00
0005432459289	30543	Business	40900.00
0005432571267	30543	Business	40900.00
0005432213596	30543	Business	40900.00
0005432566922	30543	Business	40900.00
0005432459171	30543	Business	40900.00
0005432213594	30543	Business	40900.00
0005432459125	30543	Business	40900.00
0005432567214	30543	Business	40900.00
0005432571285	30543	Business	40900.00
0005432459126	30543	Business	40900.00
0005434081617	30543	Business	40900.00
0005434081624	30543	Business	40900.00
0005432566807	30543	Business	40900.00
0005432459210	30543	Economy	15000.00
0005432566853	30543	Economy	15000.00
0005432459309	30543	Economy	15000.00
0005432566952	30543	Economy	13600.00
0005432459436	30543	Economy	13600.00
0005432459191	30543	Economy	13600.00
0005432459341	30543	Economy	13600.00
0005432213592	30543	Economy	13600.00
0005432566644	30543	Economy	13600.00
0005432459484	30543	Economy	13600.00
0005432459198	30543	Economy	13600.00
0005432567084	30543	Economy	13600.00
0005432567141	30543	Economy	13600.00
0005434081644	30543	Economy	13600.00
0005432459253	30543	Economy	13600.00
0005432459161	30543	Economy	13600.00
0005432459162	30543	Economy	13600.00
0005432161144	30543	Economy	13600.00
0005432566754	30543	Economy	13600.00
0005432566973	30543	Economy	13600.00
0005434081556	30543	Economy	13600.00
0005432571286	30543	Economy	13600.00
0005432459209	30543	Economy	13600.00
0005432566975	30543	Economy	13600.00
0005434081523	30543	Economy	13600.00
0005432459291	30543	Economy	13600.00
0005432566962	30543	Economy	13600.00
0005432566978	30543	Economy	13600.00
0005432567119	30543	Economy	13600.00
0005432566710	30543	Economy	13600.00
0005432566794	30543	Economy	13600.00
0005433452720	30543	Economy	13600.00
0005432566926	30543	Economy	13600.00
0005432459325	30543	Economy	13600.00
0005432213595	30543	Economy	13600.00
0005432567137	30543	Economy	13600.00
0005434081589	30543	Economy	13600.00
0005432459278	30543	Economy	13600.00
0005432567048	30543	Economy	13600.00
0005432459145	30543	Economy	13600.00
0005432566854	30543	Economy	13600.00
0005432566963	30543	Economy	13600.00
0005432213593	30543	Economy	13600.00
0005432566792	30543	Economy	13600.00
0005432459277	30543	Economy	13600.00
0005432567096	30543	Economy	13600.00
0005432459373	30543	Economy	13600.00
0005432459299	30543	Economy	13600.00
0005432566658	30543	Economy	13600.00
0005432566753	30543	Economy	13600.00
0005432459290	30543	Economy	13600.00
0005432459435	30543	Economy	13600.00
0005432566598	30543	Economy	13600.00
0005432459267	30543	Economy	13600.00
0005432459465	30543	Economy	13600.00
0005432566953	30543	Economy	13600.00
0005432567139	30543	Economy	13600.00
0005434081552	30543	Economy	13600.00
0005432459469	30543	Economy	13600.00
0005432459374	30543	Economy	13600.00
0005434081600	30543	Economy	13600.00
0005432459190	30543	Economy	13600.00
0005432567083	30543	Economy	13600.00
0005432566927	30543	Economy	13600.00
0005432566866	30543	Economy	13600.00
0005432566958	30543	Economy	13600.00
0005432567147	30543	Economy	13600.00
0005432459119	30543	Economy	13600.00
0005432567040	30543	Economy	13600.00
0005432567172	30543	Economy	15000.00
0005432459308	30543	Economy	13600.00
0005432459380	30543	Economy	15000.00
0005432567110	30543	Economy	13600.00
0005434081587	30543	Economy	15000.00
0005432566904	30543	Economy	13600.00
0005432459329	30543	Economy	13600.00
0005433452714	30543	Economy	13600.00
0005432459262	30543	Economy	13600.00
0005432566961	30543	Economy	13600.00
0005432567105	30543	Economy	13600.00
0005432459368	30543	Economy	13600.00
0005432566965	30543	Economy	13600.00
0005432567111	30543	Economy	13600.00
0005432566791	30543	Economy	13600.00
0005432566790	30543	Economy	13600.00
0005432567022	30543	Economy	13600.00
0005432459340	30543	Economy	13600.00
0005432566988	30543	Economy	13600.00
0005432567037	30543	Economy	13600.00
0005432567016	30543	Economy	13600.00
0005434081528	30543	Economy	13600.00
0005432571279	30543	Economy	13600.00
0005432567144	30543	Economy	13600.00
0005432566956	30543	Economy	13600.00
0005432566950	30543	Economy	13600.00
0005432459263	30543	Economy	13600.00
0005434081618	30543	Economy	13600.00
0005432459372	30543	Economy	13600.00
0005432459496	30543	Economy	13600.00
0005432566883	30543	Economy	13600.00
0005432459470	30543	Economy	13600.00
0005432459208	30543	Economy	13600.00
0005434081625	30543	Economy	13600.00
0005432161145	30543	Economy	13600.00
0005434081673	30543	Economy	13600.00
0005432566898	30543	Economy	13600.00
0005432566957	30543	Economy	13600.00
0005432566969	30543	Economy	13600.00
0005432566709	30543	Economy	13600.00
0005432459326	30543	Economy	13600.00
0005432571281	30543	Economy	13600.00
0005432459331	30543	Economy	13600.00
0005432571282	30543	Economy	13600.00
0005432459072	30543	Economy	13600.00
0005434081546	30543	Economy	13600.00
0005434081588	30543	Economy	13600.00
0005434081488	30543	Economy	13600.00
0005432459335	30543	Economy	13600.00
0005432566897	30543	Economy	13600.00
0005432459318	30543	Economy	13600.00
0005432566999	30543	Economy	13600.00
0005432566974	30543	Economy	13600.00
0005432459124	30543	Economy	13600.00
0005432566928	30543	Economy	13600.00
0005432459254	30543	Economy	13600.00
0005432567118	30543	Economy	13600.00
0005432567164	30543	Economy	13600.00
0005432567005	30543	Economy	13600.00
0005432567140	30543	Economy	13600.00
0005432459381	30543	Economy	13600.00
0005435722048	13576	Economy	9900.00
0005435722046	13576	Economy	9900.00
0005435722047	13576	Economy	9900.00
0005435722025	21122	Economy	9900.00
0005435722024	21122	Economy	9900.00
0005435722029	21122	Economy	9900.00
0005435722012	21122	Economy	9900.00
0005432295871	22758	Economy	8800.00
0005432295870	22758	Economy	8800.00
0005432295872	22758	Economy	8800.00
0005433342899	11103	Business	23600.00
0005433342874	11103	Business	23600.00
0005433342900	11103	Business	23600.00
0005433342842	11103	Business	23600.00
0005433342875	11103	Business	23600.00
0005433342857	11103	Business	23600.00
0005433342814	11103	Business	23600.00
0005433342907	11103	Business	23600.00
0005433342823	11103	Business	23600.00
0005433342830	11103	Business	23600.00
0005435097168	11103	Business	23600.00
0005433342894	11103	Business	23600.00
0005433342854	11103	Economy	7900.00
0005433342821	11103	Economy	7900.00
0005433342877	11103	Economy	7900.00
0005433342859	11103	Economy	7900.00
0005433342885	11103	Economy	7900.00
0005433342850	11103	Economy	7900.00
0005433342848	11103	Economy	7900.00
0005433342846	11103	Economy	7900.00
0005435380243	11103	Economy	7900.00
0005435508224	11103	Economy	7900.00
0005433342906	11103	Economy	7900.00
0005433342904	11103	Economy	7900.00
0005433342887	11103	Economy	7900.00
0005433342896	11103	Economy	7900.00
0005433342825	11103	Economy	7900.00
0005433342892	11103	Economy	7900.00
0005433342832	11103	Economy	7900.00
0005433342805	11103	Economy	7900.00
0005435097170	11103	Economy	7900.00
0005433342836	11103	Economy	7900.00
0005433342867	11103	Economy	7900.00
0005433342843	11103	Economy	7900.00
0005435508191	11103	Economy	7900.00
0005433342837	11103	Economy	7900.00
0005433342868	11103	Economy	7900.00
0005433342898	11103	Economy	7900.00
0005433342905	11103	Economy	7900.00
0005433342839	11103	Economy	7900.00
0005433342886	11103	Economy	7900.00
0005433342807	11103	Economy	7900.00
0005433342889	11103	Economy	7900.00
0005433342826	11103	Economy	7900.00
0005433342851	11103	Economy	7900.00
0005433342852	11103	Economy	7900.00
0005433342828	11103	Economy	8600.00
0005433342806	11103	Economy	7900.00
0005433342864	11103	Economy	8600.00
0005433342880	11103	Economy	8600.00
0005433342847	11103	Economy	8600.00
0005433342845	11103	Economy	8600.00
0005433342869	11103	Economy	8600.00
0005433342865	11103	Economy	7900.00
0005433342871	11103	Economy	7900.00
0005433342833	11103	Economy	7900.00
0005433342827	11103	Economy	7900.00
0005433342882	11103	Economy	7900.00
0005433342809	11103	Economy	7900.00
0005433342831	11103	Economy	7900.00
0005433342844	11103	Economy	7900.00
0005433342891	11103	Economy	7900.00
0005435380251	11103	Economy	7900.00
0005433342819	11103	Economy	7900.00
0005433342902	11103	Economy	7900.00
0005433342893	11103	Economy	7900.00
0005433342872	11103	Economy	7900.00
0005433342873	11103	Economy	7900.00
0005433342856	11103	Economy	7900.00
0005433342870	11103	Economy	7900.00
0005433342841	11103	Economy	7900.00
0005433342824	11103	Economy	7900.00
0005433342838	11103	Economy	7900.00
0005435097166	11103	Economy	7900.00
0005435380241	11103	Economy	7900.00
0005433342903	11103	Economy	7900.00
0005433342860	11103	Economy	7900.00
0005433342876	11103	Economy	7900.00
0005433342878	11103	Economy	7900.00
0005433342895	11103	Economy	7900.00
0005433342866	11103	Economy	7900.00
0005433342820	11103	Economy	7900.00
0005435097171	11103	Economy	7900.00
0005433342816	11103	Economy	7900.00
0005433342881	11103	Economy	7900.00
0005433342888	11103	Economy	7900.00
0005433342858	11103	Economy	7900.00
0005433342863	11103	Economy	7900.00
0005433342861	11103	Economy	7900.00
0005433342813	11103	Economy	7900.00
0005433342901	11103	Economy	7900.00
0005433342883	11103	Economy	7900.00
0005435380242	11103	Economy	7900.00
0005433342811	11103	Economy	7900.00
0005433342890	11103	Economy	7900.00
0005433342834	11103	Economy	7900.00
0005435097167	11103	Economy	7900.00
0005433342853	11103	Economy	7900.00
0005433342884	11103	Economy	7900.00
0005433342810	11103	Economy	7900.00
0005433342822	11103	Economy	7900.00
0005433342862	11103	Economy	7900.00
0005435508223	11103	Economy	7900.00
0005435380240	11103	Economy	7900.00
0005433342817	11103	Economy	7900.00
0005433342812	11103	Economy	7900.00
0005433342835	11103	Economy	7900.00
0005435097169	11103	Economy	7900.00
0005433342879	11103	Economy	7900.00
0005435380244	11103	Economy	7900.00
0005435508211	11103	Economy	7900.00
0005433342855	11103	Economy	7900.00
0005435508222	11103	Economy	7900.00
0005435508219	11103	Economy	7900.00
0005435508216	11103	Economy	7900.00
0005433342840	11103	Economy	7900.00
0005435508221	11103	Economy	7900.00
0005433342815	11103	Economy	7900.00
0005433342897	11103	Economy	7900.00
0005433342849	11103	Economy	7900.00
0005433342808	11103	Economy	7900.00
0005433342829	11103	Economy	7900.00
0005433342818	11103	Economy	7900.00
0005433341484	17122	Business	23600.00
0005433341790	17122	Business	23600.00
0005435380281	17122	Business	23600.00
0005433341856	17122	Business	23600.00
0005435545721	17122	Business	23600.00
0005435545717	17122	Business	23600.00
0005433341945	17122	Business	23600.00
0005433341786	17122	Business	23600.00
0005433341619	17122	Business	23600.00
0005433342076	17122	Business	23600.00
0005433341485	17122	Economy	7900.00
0005433341414	17122	Economy	7900.00
0005433341988	17122	Economy	7900.00
0005433342294	17122	Economy	7900.00
0005433341855	17122	Economy	7900.00
0005435545719	17122	Economy	7900.00
0005433342102	17122	Economy	7900.00
0005433341702	17122	Economy	7900.00
0005433341992	17122	Economy	7900.00
0005433341471	17122	Economy	7900.00
0005433342029	17122	Economy	7900.00
0005433342221	17122	Economy	7900.00
0005433342011	17122	Economy	7900.00
0005433342096	17122	Economy	7900.00
0005433341673	17122	Economy	7900.00
0005433341647	17122	Economy	7900.00
0005433342194	17122	Economy	7900.00
0005433341917	17122	Economy	7900.00
0005435380282	17122	Economy	7900.00
0005433341808	17122	Economy	7900.00
0005433341826	17122	Economy	7900.00
0005433341578	17122	Economy	7900.00
0005433342103	17122	Economy	7900.00
0005435545720	17122	Economy	7900.00
0005433341679	17122	Economy	7900.00
0005433341948	17122	Economy	7900.00
0005433341810	17122	Economy	7900.00
0005433341537	17122	Economy	7900.00
0005433342004	17122	Economy	7900.00
0005433341899	17122	Economy	7900.00
0005433341872	17122	Economy	7900.00
0005433342057	17122	Economy	7900.00
0005433341646	17122	Economy	7900.00
0005433342056	17122	Economy	7900.00
0005433342081	17122	Economy	7900.00
0005433341987	17122	Economy	7900.00
0005433341825	17122	Economy	7900.00
0005433341719	17122	Economy	7900.00
0005433342036	17122	Economy	8600.00
0005433342438	17122	Economy	8600.00
0005435545722	17122	Economy	8600.00
0005433341536	17122	Economy	8600.00
0005433341983	17122	Economy	8600.00
0005433341731	17122	Economy	8600.00
0005433341861	17122	Economy	7900.00
0005435097078	17122	Economy	7900.00
0005433342026	17122	Economy	7900.00
0005433342485	17122	Economy	7900.00
0005433341785	17122	Economy	7900.00
0005433341743	17122	Economy	7900.00
0005433341760	17122	Economy	7900.00
0005433342012	17122	Economy	7900.00
0005433341946	17122	Economy	7900.00
0005433342024	17122	Economy	7900.00
0005433342339	17122	Economy	7900.00
0005433341692	17122	Economy	7900.00
0005433341818	17122	Economy	7900.00
0005433342439	17122	Economy	7900.00
0005432293201	17122	Economy	7900.00
0005433341720	17122	Economy	7900.00
0005433341630	17122	Economy	7900.00
0005433341634	17122	Economy	7900.00
0005433342046	17122	Economy	7900.00
0005433341577	17122	Economy	7900.00
0005433342158	17122	Economy	7900.00
0005433341807	17122	Economy	7900.00
0005435097109	17122	Economy	7900.00
0005433342074	17122	Economy	7900.00
0005433341852	17122	Economy	7900.00
0005435380284	17122	Economy	7900.00
0005433342222	17122	Economy	7900.00
0005433341604	17122	Economy	7900.00
0005433341871	17122	Economy	7900.00
0005435380283	17122	Economy	7900.00
0005435097053	17122	Economy	7900.00
0005435545716	17122	Economy	7900.00
0005433342205	17122	Economy	7900.00
0005435097064	17122	Economy	7900.00
0005435380287	17122	Economy	7900.00
0005435380285	17122	Economy	7900.00
0005435545718	17122	Economy	7900.00
0005435545715	17122	Economy	7900.00
0005435097070	17122	Economy	7900.00
0005433341566	17122	Economy	7900.00
0005433342193	17122	Economy	7900.00
0005433341469	17122	Economy	7900.00
0005433342462	17122	Economy	7900.00
0005435380286	17122	Economy	7900.00
0005433341971	17122	Economy	7900.00
0005433342055	17122	Economy	7900.00
0005433341693	17122	Economy	7900.00
0005433341969	17122	Economy	7900.00
0005433341691	17122	Economy	7900.00
0005432293200	17122	Economy	7900.00
0005433342486	17122	Economy	7900.00
0005433341974	17122	Economy	7900.00
0005433341900	17122	Economy	7900.00
0005435097052	17122	Economy	7900.00
0005433341656	17122	Economy	7900.00
0005433341665	17122	Economy	7900.00
0005433342338	17122	Economy	7900.00
0005433342254	17122	Economy	7900.00
0005433341470	17122	Economy	7900.00
0005433341602	17122	Economy	7900.00
0005433341605	17122	Economy	7900.00
0005433341938	17122	Economy	7900.00
0005433341664	17122	Economy	7900.00
0005433342385	17122	Economy	7900.00
0005433341618	17122	Economy	7900.00
0005433342079	17122	Economy	7900.00
0005433342175	17122	Economy	7900.00
0005433341550	17122	Economy	7900.00
0005433342080	17122	Economy	7900.00
0005433341661	17122	Economy	7900.00
0005435097071	17122	Economy	7900.00
0005433341730	17122	Economy	7900.00
0005433507122	9063	Business	26600.00
0005433507139	9063	Business	26600.00
0005432919615	9063	Business	26600.00
0005432919530	9063	Business	26600.00
0005433507136	9063	Business	26600.00
0005434158953	9063	Business	26600.00
0005433481141	9063	Economy	8900.00
0005433507127	9063	Economy	8900.00
0005434158958	9063	Economy	8900.00
0005433507134	9063	Economy	8900.00
0005433507138	9063	Economy	9800.00
0005433507135	9063	Economy	9800.00
0005433481143	9063	Economy	8900.00
0005432919591	9063	Economy	8900.00
0005433507125	9063	Economy	8900.00
0005433507119	9063	Economy	8900.00
0005433507129	9063	Economy	8900.00
0005433507126	9063	Economy	8900.00
0005432919578	9063	Economy	8900.00
0005432919654	9063	Economy	8900.00
0005433507124	9063	Economy	8900.00
0005432919617	9063	Economy	8900.00
0005433507130	9063	Economy	8900.00
0005432919616	9063	Economy	8900.00
0005433481140	9063	Economy	8900.00
0005432919546	9063	Economy	8900.00
0005433507123	9063	Economy	8900.00
0005432919590	9063	Economy	8900.00
0005433507131	9063	Economy	8900.00
0005433507128	9063	Economy	8900.00
0005432919577	9063	Economy	8900.00
0005433507140	9063	Economy	8900.00
0005432919549	9063	Economy	8900.00
0005432919711	9063	Economy	8900.00
0005432919669	9063	Economy	8900.00
0005433507133	9063	Economy	8900.00
0005433481146	9063	Economy	8900.00
0005434158951	9063	Economy	8900.00
0005432919628	9063	Economy	8900.00
0005432919614	9063	Economy	8900.00
0005432919643	9063	Economy	8900.00
0005433507121	9063	Economy	8900.00
0005433481145	9063	Economy	8900.00
0005433481144	9063	Economy	8900.00
0005433481142	9063	Economy	8900.00
0005433507118	9063	Economy	8900.00
0005432919644	9063	Economy	8900.00
0005433507137	9063	Economy	8900.00
0005433507120	9063	Economy	8900.00
0005433507132	9063	Economy	8900.00
0005432919710	9063	Economy	8900.00
0005432919655	9063	Economy	8900.00
0005432919539	9063	Economy	8900.00
0005432919808	20454	Business	26600.00
0005432919821	20454	Business	26600.00
0005433507037	20454	Business	26600.00
0005432919819	20454	Economy	8900.00
0005432919818	20454	Economy	8900.00
0005432919822	20454	Economy	8900.00
0005432919807	20454	Economy	8900.00
0005433481061	20454	Economy	8900.00
0005433506944	20454	Economy	8900.00
0005432919806	20454	Economy	8900.00
0005433506958	20454	Economy	8900.00
0005433506949	20454	Economy	8900.00
0005433507019	20454	Economy	8900.00
0005432919820	20454	Economy	8900.00
0005432919811	20454	Economy	8900.00
0005433507045	20454	Economy	8900.00
0005432919813	20454	Economy	8900.00
0005432919802	20454	Economy	8900.00
0005433507020	20454	Economy	8900.00
0005432919817	20454	Economy	8900.00
0005432919804	20454	Economy	8900.00
0005432919823	20454	Economy	8900.00
0005433507035	20454	Economy	8900.00
0005432919812	20454	Economy	8900.00
0005433506994	20454	Economy	8900.00
0005432919809	20454	Economy	8900.00
0005433481072	20454	Economy	8900.00
0005432919816	20454	Economy	8900.00
0005433481060	20454	Economy	8900.00
0005433506977	20454	Economy	8900.00
0005433506997	20454	Economy	8900.00
0005432919805	20454	Economy	8900.00
0005432919810	20454	Economy	8900.00
0005433506998	20454	Economy	8900.00
0005433506996	20454	Economy	8900.00
0005432919814	20454	Economy	8900.00
0005432919803	20454	Economy	8900.00
0005432919815	20454	Economy	8900.00
0005432396225	10190	Economy	5800.00
0005432394085	10190	Economy	5800.00
0005432394087	10190	Economy	5800.00
0005435178982	10190	Economy	5800.00
0005432396226	10190	Economy	5800.00
0005432394086	10190	Economy	5800.00
0005432394089	10190	Economy	5800.00
0005432394088	10190	Economy	5800.00
0005435178981	10190	Economy	5800.00
0005432396227	10190	Economy	5800.00
0005432396228	10190	Economy	5800.00
0005432396224	10190	Economy	5800.00
0005432396201	18395	Economy	5800.00
0005432400065	18395	Economy	5800.00
0005435179691	18395	Economy	5800.00
0005435554108	11029	Business	9500.00
0005435556665	11029	Business	9500.00
0005435554107	11029	Business	9500.00
0005435125915	11029	Business	9500.00
0005435125889	11029	Business	9500.00
0005435554119	11029	Business	9500.00
0005435125840	11029	Business	9500.00
0005435554120	11029	Economy	3200.00
0005435556663	11029	Economy	3200.00
0005434928290	11029	Economy	3200.00
0005435125855	11029	Economy	3200.00
0005434411764	11029	Economy	3200.00
0005435125839	11029	Economy	3200.00
0005434411766	11029	Economy	3500.00
0005435125881	11029	Economy	3500.00
0005435625952	11029	Economy	3500.00
0005434928291	11029	Economy	3200.00
0005435125886	11029	Economy	3200.00
0005434411765	11029	Economy	3200.00
0005435625977	11029	Economy	3200.00
0005435625908	11029	Economy	3200.00
0005435125790	11029	Economy	3200.00
0005435554135	11029	Economy	3200.00
0005434411767	11029	Economy	3200.00
0005435554113	11029	Economy	3200.00
0005435625959	11029	Economy	3200.00
0005435625962	11029	Economy	3200.00
0005435125813	11029	Economy	3200.00
0005435625910	11029	Economy	3200.00
0005435125857	11029	Economy	3200.00
0005435125914	11029	Economy	3200.00
0005435125856	11029	Economy	3200.00
0005435125908	11029	Economy	3200.00
0005435625956	11029	Economy	3200.00
0005434928289	11029	Economy	3200.00
0005435125929	11029	Economy	3200.00
0005435554106	11029	Economy	3200.00
0005435556664	11029	Economy	3200.00
0005435125812	11029	Economy	3200.00
0005435625923	11029	Economy	3200.00
0005435554131	11029	Economy	3200.00
0005435125845	11029	Economy	3200.00
0005435125991	11029	Economy	3200.00
0005435625957	11029	Economy	3200.00
0005435625922	11029	Economy	3200.00
0005435125909	11029	Economy	3200.00
0005435625965	11029	Economy	3200.00
0005435125890	11029	Economy	3200.00
0005435125879	11029	Economy	3200.00
0005435125833	11029	Economy	3200.00
0005435625909	11029	Economy	3200.00
0005435125853	11029	Economy	3200.00
0005435625927	11029	Economy	3200.00
0005435125854	11029	Economy	3200.00
0005435126021	11029	Economy	3200.00
0005435125887	11029	Economy	3200.00
0005435125714	11029	Economy	3200.00
0005435625978	11029	Economy	3200.00
0005435126253	14657	Business	9500.00
0005435626110	14657	Business	9500.00
0005435126238	14657	Business	9500.00
0005434928268	14657	Business	9500.00
0005435126232	14657	Business	9500.00
0005435126261	14657	Business	9500.00
0005435626118	14657	Business	9500.00
0005435626128	14657	Business	9500.00
0005435626126	14657	Business	9500.00
0005435126257	14657	Business	9500.00
0005435554172	14657	Business	9500.00
0005435126252	14657	Economy	3200.00
0005435126245	14657	Economy	3200.00
0005434411729	14657	Economy	3200.00
0005435626119	14657	Economy	3200.00
0005435626132	14657	Economy	3200.00
0005435626114	14657	Economy	3200.00
0005435554171	14657	Economy	3200.00
0005435126265	14657	Economy	3200.00
0005435626135	14657	Economy	3200.00
0005435126254	14657	Economy	3200.00
0005435126259	14657	Economy	3500.00
0005435554167	14657	Economy	3500.00
0005435126251	14657	Economy	3500.00
0005435126241	14657	Economy	3500.00
0005435626127	14657	Economy	3500.00
0005435126248	14657	Economy	3200.00
0005435126233	14657	Economy	3200.00
0005435126269	14657	Economy	3200.00
0005435554170	14657	Economy	3200.00
0005435626111	14657	Economy	3200.00
0005435126256	14657	Economy	3200.00
0005435126240	14657	Economy	3200.00
0005435626125	14657	Economy	3200.00
0005434411717	14657	Economy	3200.00
0005435626131	14657	Economy	3200.00
0005435126258	14657	Economy	3200.00
0005435626123	14657	Economy	3200.00
0005435126237	14657	Economy	3200.00
0005435126247	14657	Economy	3200.00
0005435626136	14657	Economy	3200.00
0005435554168	14657	Economy	3200.00
0005435626120	14657	Economy	3200.00
0005435126267	14657	Economy	3200.00
0005434411745	14657	Economy	3200.00
0005435126264	14657	Economy	3200.00
0005435556684	14657	Economy	3200.00
0005435556685	14657	Economy	3200.00
0005434411742	14657	Economy	3200.00
0005435126231	14657	Economy	3200.00
0005435126239	14657	Economy	3200.00
0005435626112	14657	Economy	3200.00
0005435126263	14657	Economy	3200.00
0005435126260	14657	Economy	3200.00
0005435626116	14657	Economy	3200.00
0005435626133	14657	Economy	3200.00
0005435126243	14657	Economy	3200.00
0005435626137	14657	Economy	3200.00
0005435126244	14657	Economy	3200.00
0005435126270	14657	Economy	3200.00
0005435626129	14657	Economy	3200.00
0005435126235	14657	Economy	3200.00
0005435126266	14657	Economy	3200.00
0005435126262	14657	Economy	3200.00
0005435626121	14657	Economy	3200.00
0005434411728	14657	Economy	3200.00
0005435126255	14657	Economy	3200.00
0005435126271	14657	Economy	3200.00
0005435126268	14657	Economy	3200.00
0005435126234	14657	Economy	3200.00
0005435626130	14657	Economy	3200.00
0005435626117	14657	Economy	3200.00
0005435126250	14657	Economy	3200.00
0005435626134	14657	Economy	3200.00
0005435554169	14657	Economy	3200.00
0005434411716	14657	Economy	3200.00
0005435626122	14657	Economy	3200.00
0005435126236	14657	Economy	3200.00
0005434411730	14657	Economy	3200.00
0005435626113	14657	Economy	3200.00
0005435126242	14657	Economy	3200.00
0005435126249	14657	Economy	3200.00
0005435626124	14657	Economy	3200.00
0005435626115	14657	Economy	3200.00
0005435126246	14657	Economy	3200.00
0005434928280	14656	Economy	3200.00
0005434928281	14656	Economy	3200.00
0005432400112	7120	Business	86900.00
0005432400113	7120	Business	86900.00
0005435216555	7120	Business	86900.00
0005435715409	7120	Business	86900.00
0005435443191	7120	Business	86900.00
0005435715407	7120	Business	86900.00
0005435443212	7120	Economy	29000.00
0005435178475	7120	Economy	29000.00
0005435715411	7120	Economy	29000.00
0005432400110	7120	Economy	29000.00
0005432398186	7120	Economy	29000.00
0005435715416	7120	Economy	29000.00
0005435443195	7120	Economy	29000.00
0005435715413	7120	Economy	29000.00
0005432398187	7120	Economy	29000.00
0005435178474	7120	Economy	29000.00
0005435715410	7120	Economy	29000.00
0005435715412	7120	Economy	29000.00
0005435178479	7120	Economy	29000.00
0005435443183	7120	Economy	29000.00
0005435443194	7120	Economy	29000.00
0005435443174	7120	Economy	29000.00
0005435715421	7120	Economy	29000.00
0005435715408	7120	Economy	29000.00
0005435715418	7120	Economy	29000.00
0005435715415	7120	Economy	29000.00
0005435443176	7120	Economy	29000.00
0005435443211	7120	Economy	29000.00
0005435443197	7120	Economy	29000.00
0005432400111	7120	Economy	29000.00
0005435443218	7120	Economy	29000.00
0005435715420	7120	Economy	29000.00
0005435715419	7120	Economy	29000.00
0005435178478	7120	Economy	29000.00
0005435715417	7120	Economy	29000.00
0005435715406	7120	Economy	29000.00
0005435443196	7120	Economy	29000.00
0005435443210	7120	Economy	29000.00
0005435715414	7120	Economy	29000.00
0005435715422	7120	Economy	29000.00
0005435715260	27051	Business	86900.00
0005435443285	27051	Business	86900.00
0005432398133	27051	Business	86900.00
0005435443286	27051	Economy	29000.00
0005435715280	27051	Economy	29000.00
0005432394040	27051	Economy	29000.00
0005432398138	27051	Economy	29000.00
0005435715225	27051	Economy	29000.00
0005435443283	27051	Economy	31900.00
0005435715254	27051	Economy	29000.00
0005435715323	27051	Economy	29000.00
0005435715224	27051	Economy	29000.00
0005432394050	27051	Economy	29000.00
0005435715314	27051	Economy	29000.00
0005435443279	27051	Economy	29000.00
0005435715315	27051	Economy	29000.00
0005435443289	27051	Economy	29000.00
0005435715228	27051	Economy	29000.00
0005435443281	27051	Economy	29000.00
0005435715281	27051	Economy	29000.00
0005435715292	27051	Economy	29000.00
0005435715269	27051	Economy	29000.00
0005435443280	27051	Economy	29000.00
0005435443287	27051	Economy	29000.00
0005432394049	27051	Economy	29000.00
0005432398152	27051	Economy	29000.00
0005435715294	27051	Economy	29000.00
0005432398137	27051	Economy	29000.00
0005435443284	27051	Economy	29000.00
0005432394065	27051	Economy	29000.00
0005435443282	27051	Economy	29000.00
0005432394054	27051	Economy	29000.00
0005435715306	27051	Economy	29000.00
0005435715293	27051	Economy	29000.00
0005432398134	27051	Economy	29000.00
0005435715307	27051	Economy	29000.00
0005432398130	27051	Economy	29000.00
0005432398129	27051	Economy	29000.00
0005435443288	27051	Economy	29000.00
0005433060382	2753	Economy	7700.00
0005433060371	2753	Economy	7700.00
0005433060380	2753	Economy	7700.00
0005433060387	2753	Economy	7700.00
0005434084916	2753	Economy	7700.00
0005434084915	2753	Economy	7700.00
0005434084917	2753	Economy	7700.00
0005433060381	2753	Economy	7700.00
0005434084882	28495	Economy	7700.00
0005433060404	28495	Economy	7700.00
0005433060406	28495	Economy	7700.00
0005433060403	28495	Economy	7700.00
0005434084861	28495	Economy	7700.00
0005434084883	28495	Economy	7700.00
0005434084909	28495	Economy	7700.00
0005434084870	28495	Economy	7700.00
0005433060405	28495	Economy	7700.00
0005434084908	28495	Economy	7700.00
0005435517785	11367	Business	20200.00
0005435540776	11367	Business	20200.00
0005435540755	11367	Business	20200.00
0005435517678	11367	Business	20200.00
0005435540834	11367	Business	20200.00
0005435540725	11367	Economy	6700.00
0005435517739	11367	Economy	6700.00
0005435517729	11367	Economy	6700.00
0005435517784	11367	Economy	7400.00
0005435517704	11367	Economy	7400.00
0005435540709	11367	Economy	7400.00
0005435540777	11367	Economy	6700.00
0005435540797	11367	Economy	6700.00
0005435540754	11367	Economy	6700.00
0005435540746	11367	Economy	6700.00
0005435540761	11367	Economy	6700.00
0005435540724	11367	Economy	6700.00
0005435540778	11367	Economy	6700.00
0005435517646	11367	Economy	6700.00
0005435540707	11367	Economy	6700.00
0005435540775	11367	Economy	6700.00
0005435517747	11367	Economy	6700.00
0005435540743	11367	Economy	6700.00
0005435540762	11367	Economy	6700.00
0005435517632	11367	Economy	6700.00
0005435517800	11367	Economy	6700.00
0005435540716	11367	Economy	6700.00
0005435517754	11367	Economy	6700.00
0005435540708	11367	Economy	6700.00
0005435517705	11367	Economy	6700.00
0005435540827	11367	Economy	6700.00
0005435517647	11367	Economy	6700.00
0005435540717	11367	Economy	6700.00
0005435517733	11367	Economy	6700.00
0005435540766	11367	Economy	6700.00
0005435517706	11367	Economy	6700.00
0005435540670	11367	Economy	6700.00
0005435540706	11367	Economy	6700.00
0005435540918	22223	Business	20200.00
0005435529173	22223	Business	20200.00
0005435540931	22223	Business	20200.00
0005435540927	22223	Business	20200.00
0005435529171	22223	Business	20200.00
0005435540928	22223	Business	20200.00
0005435540932	22223	Business	20200.00
0005435529172	22223	Economy	6700.00
0005435529186	22223	Economy	6700.00
0005435529187	22223	Economy	6700.00
0005435529184	22223	Economy	6700.00
0005435540915	22223	Economy	7400.00
0005432294478	22223	Economy	7400.00
0005435540920	22223	Economy	6700.00
0005435529177	22223	Economy	6700.00
0005435529183	22223	Economy	6700.00
0005435540924	22223	Economy	6700.00
0005435529180	22223	Economy	6700.00
0005435540914	22223	Economy	6700.00
0005435529185	22223	Economy	6700.00
0005435540922	22223	Economy	6700.00
0005435540923	22223	Economy	6700.00
0005435529178	22223	Economy	6700.00
0005435540919	22223	Economy	6700.00
0005435529179	22223	Economy	6700.00
0005435529176	22223	Economy	6700.00
0005435529188	22223	Economy	6700.00
0005435540917	22223	Economy	6700.00
0005435540921	22223	Economy	6700.00
0005435529181	22223	Economy	6700.00
0005435540913	22223	Economy	6700.00
0005435529182	22223	Economy	6700.00
0005435540926	22223	Economy	6700.00
0005432294477	22223	Economy	6700.00
0005435529169	22223	Economy	6700.00
0005435529170	22223	Economy	6700.00
0005435529168	22223	Economy	6700.00
0005435540930	22223	Economy	6700.00
0005435540911	22223	Economy	6700.00
0005435540916	22223	Economy	6700.00
0005435540925	22223	Economy	6700.00
0005435529174	22223	Economy	6700.00
0005435529175	22223	Economy	6700.00
0005435529167	22223	Economy	6700.00
0005435540912	22223	Economy	6700.00
0005435540929	22223	Economy	6700.00
0005434907122	2300	Business	20200.00
0005434907135	2300	Business	20200.00
0005434907153	2300	Business	20200.00
0005434907144	2300	Business	20200.00
0005433251163	2300	Business	20200.00
0005434907139	2300	Business	20200.00
0005434907132	2300	Business	20200.00
0005434907151	2300	Business	20200.00
0005434907126	2300	Business	20200.00
0005433400956	2300	Business	20200.00
0005434907155	2300	Business	20200.00
0005434907160	2300	Economy	6700.00
0005433251173	2300	Economy	6700.00
0005433251162	2300	Economy	6700.00
0005434907118	2300	Economy	6700.00
0005433251037	2300	Economy	6700.00
0005433251164	2300	Economy	6700.00
0005434907148	2300	Economy	6700.00
0005434907136	2300	Economy	6700.00
0005433400951	2300	Economy	6700.00
0005433251132	2300	Economy	7400.00
0005433251153	2300	Economy	7400.00
0005434907129	2300	Economy	7400.00
0005433251165	2300	Economy	7400.00
0005434907137	2300	Economy	6700.00
0005434907104	2300	Economy	6700.00
0005434907140	2300	Economy	6700.00
0005434907154	2300	Economy	6700.00
0005433400958	2300	Economy	6700.00
0005433251133	2300	Economy	6700.00
0005433251146	2300	Economy	6700.00
0005434907138	2300	Economy	6700.00
0005433400957	2300	Economy	6700.00
0005433251255	2300	Economy	6700.00
0005434907146	2300	Economy	6700.00
0005434907116	2300	Economy	6700.00
0005434907107	2300	Economy	6700.00
0005434907119	2300	Economy	6700.00
0005434907128	2300	Economy	6700.00
0005434907143	2300	Economy	6700.00
0005434907141	2300	Economy	6700.00
0005434907133	2300	Economy	6700.00
0005434907110	2300	Economy	6700.00
0005434907114	2300	Economy	6700.00
0005434907150	2300	Economy	6700.00
0005434907123	2300	Economy	6700.00
0005434907115	2300	Economy	6700.00
0005434907158	2300	Economy	6700.00
0005434907111	2300	Economy	6700.00
0005434907157	2300	Economy	6700.00
0005434907106	2300	Economy	6700.00
0005433251174	2300	Economy	6700.00
0005433251036	2300	Economy	6700.00
0005433251256	2300	Economy	6700.00
0005434907112	2300	Economy	6700.00
0005434907159	2300	Economy	6700.00
0005433251082	2300	Economy	6700.00
0005434907121	2300	Economy	6700.00
0005434907147	2300	Economy	6700.00
0005434907124	2300	Economy	6700.00
0005434907127	2300	Economy	6700.00
0005434907152	2300	Economy	6700.00
0005434907142	2300	Economy	6700.00
0005434907149	2300	Economy	6700.00
0005433400955	2300	Economy	6700.00
0005434907105	2300	Economy	6700.00
0005434907109	2300	Economy	6700.00
0005433251254	2300	Economy	6700.00
0005433251081	2300	Economy	6700.00
0005433251154	2300	Economy	6700.00
0005434907130	2300	Economy	6700.00
0005434907131	2300	Economy	6700.00
0005434907125	2300	Economy	6700.00
0005434907134	2300	Economy	6700.00
0005434907108	2300	Economy	6700.00
0005434907113	2300	Economy	6700.00
0005433251080	2300	Economy	6700.00
0005434907120	2300	Economy	6700.00
0005434907117	2300	Economy	6700.00
0005434907156	2300	Economy	6700.00
0005434907145	2300	Economy	6700.00
0005434906630	25601	Business	20200.00
0005434906424	25601	Business	20200.00
0005433251399	25601	Business	20200.00
0005433251395	25601	Business	20200.00
0005434906786	25601	Business	20200.00
0005434906581	25601	Business	20200.00
0005433251400	25601	Business	20200.00
0005434906685	25601	Business	20200.00
0005434906637	25601	Business	20200.00
0005434906629	25601	Business	20200.00
0005434906570	25601	Economy	6700.00
0005433251393	25601	Economy	6700.00
0005434906569	25601	Economy	6700.00
0005433251379	25601	Economy	6700.00
0005434906565	25601	Economy	6700.00
0005433251394	25601	Economy	6700.00
0005433251390	25601	Economy	6700.00
0005433251388	25601	Economy	6700.00
0005434906751	25601	Economy	6700.00
0005434906657	25601	Economy	6700.00
0005434906394	25601	Economy	7400.00
0005433251375	25601	Economy	7400.00
0005434906712	25601	Economy	7400.00
0005434906615	25601	Economy	7400.00
0005434906567	25601	Economy	7400.00
0005434906765	25601	Economy	6700.00
0005434906568	25601	Economy	6700.00
0005434906457	25601	Economy	6700.00
0005434906566	25601	Economy	6700.00
0005433251378	25601	Economy	6700.00
0005434906584	25601	Economy	6700.00
0005433251391	25601	Economy	6700.00
0005433251371	25601	Economy	6700.00
0005434906667	25601	Economy	6700.00
0005434906492	25601	Economy	6700.00
0005433251383	25601	Economy	6700.00
0005434906715	25601	Economy	6700.00
0005434906711	25601	Economy	6700.00
0005434906750	25601	Economy	6700.00
0005433251380	25601	Economy	6700.00
0005434906486	25601	Economy	6700.00
0005433251392	25601	Economy	6700.00
0005434906601	25601	Economy	6700.00
0005433251382	25601	Economy	6700.00
0005433251384	25601	Economy	6700.00
0005433251381	25601	Economy	6700.00
0005434906572	25601	Economy	6700.00
0005433251372	25601	Economy	6700.00
0005434906628	25601	Economy	6700.00
0005433251397	25601	Economy	6700.00
0005434906702	25601	Economy	6700.00
0005434906704	25601	Economy	6700.00
0005434906454	25601	Economy	6700.00
0005433251386	25601	Economy	6700.00
0005433251387	25601	Economy	6700.00
0005434906418	25601	Economy	6700.00
0005433251389	25601	Economy	6700.00
0005434906648	25601	Economy	6700.00
0005433400973	25601	Economy	6700.00
0005433400974	25601	Economy	6700.00
0005434906726	25601	Economy	6700.00
0005433251385	25601	Economy	6700.00
0005433251374	25601	Economy	6700.00
0005433251398	25601	Economy	6700.00
0005434906463	25601	Economy	6700.00
0005434906703	25601	Economy	6700.00
0005434906787	25601	Economy	6700.00
0005434906683	25601	Economy	6700.00
0005434906502	25601	Economy	6700.00
0005434906552	25601	Economy	6700.00
0005434906684	25601	Economy	6700.00
0005434906727	25601	Economy	6700.00
0005434906693	25601	Economy	6700.00
0005434906658	25601	Economy	6700.00
0005433251396	25601	Economy	6700.00
0005434906549	25601	Economy	6700.00
0005434906655	25601	Economy	6700.00
0005433251377	25601	Economy	6700.00
0005433251373	25601	Economy	6700.00
0005434906695	25601	Economy	6700.00
0005434906587	25601	Economy	6700.00
0005434906462	25601	Economy	6700.00
0005433400975	25601	Economy	6700.00
0005434906456	25601	Economy	6700.00
0005434906425	25601	Economy	6700.00
0005433251376	25601	Economy	6700.00
0005434906826	25601	Economy	6700.00
0005434906473	25601	Economy	6700.00
0005434906511	25601	Economy	6700.00
0005434906694	25601	Economy	6700.00
0005432621002	2534	Economy	13600.00
0005432862229	2534	Economy	12400.00
0005432620997	2534	Economy	12400.00
0005432620998	2534	Economy	12400.00
0005432862220	2534	Economy	12400.00
0005432620992	2534	Economy	12400.00
0005432862194	2534	Economy	12400.00
0005432620991	2534	Economy	12400.00
0005432620993	2534	Economy	12400.00
0005432862246	2534	Economy	12400.00
0005432862221	2534	Economy	12400.00
0005432862187	2534	Economy	12400.00
0005432862231	2534	Economy	12400.00
0005432621000	2534	Economy	12400.00
0005432620999	2534	Economy	12400.00
0005432621001	2534	Economy	12400.00
0005432862193	2534	Economy	12400.00
0005432862233	2534	Economy	12400.00
0005432620990	2534	Economy	12400.00
0005432862230	2534	Economy	12400.00
0005432862210	2534	Economy	12400.00
0005432862201	2534	Economy	12400.00
0005432620996	2534	Economy	12400.00
0005432620994	2534	Economy	12400.00
0005432620995	2534	Economy	12400.00
0005432620989	2534	Economy	12400.00
0005432862219	2534	Economy	12400.00
0005432862274	28061	Economy	12400.00
0005432862276	28061	Economy	12400.00
0005432620891	28061	Economy	12400.00
0005432862279	28061	Economy	12400.00
0005432620900	28061	Economy	12400.00
0005432862278	28061	Economy	12400.00
0005432862275	28061	Economy	12400.00
0005432862280	28061	Economy	12400.00
0005432620915	28061	Economy	12400.00
0005432620863	28061	Economy	12400.00
0005432620925	28061	Economy	12400.00
0005432862277	28061	Economy	12400.00
0005432862282	28061	Economy	12400.00
0005432620794	28061	Economy	12400.00
0005432862281	28061	Economy	12400.00
0005432862283	28061	Economy	12400.00
0005434097464	11685	Economy	11300.00
0005434097472	13079	Economy	11300.00
0005434097473	13079	Economy	11300.00
0005434191252	32874	Economy	29900.00
0005434191261	32874	Economy	29900.00
0005434191260	32874	Economy	29900.00
0005434191253	32874	Economy	29900.00
0005434191251	32874	Economy	29900.00
0005434191256	32874	Economy	29900.00
0005434191257	32874	Economy	29900.00
0005433451613	31004	Economy	8400.00
0005433452734	31004	Economy	8400.00
0005433451614	31004	Economy	8400.00
0005433451615	31004	Economy	8400.00
0005433452733	31004	Economy	8400.00
0005433452720	31383	Economy	8400.00
0005433452714	31383	Economy	8400.00
0005433134081	12024	Economy	7200.00
0005434142569	12024	Economy	7200.00
0005434184649	12024	Economy	6600.00
0005434142570	12024	Economy	6600.00
0005434142555	12024	Economy	6600.00
0005434142563	12024	Economy	6600.00
0005433129202	12024	Economy	6600.00
0005433129232	12024	Economy	6600.00
0005434142567	12024	Economy	6600.00
0005434142576	12024	Economy	6600.00
0005433129219	12024	Economy	6600.00
0005434184641	12024	Economy	6600.00
0005433129229	12024	Economy	6600.00
0005434142562	12024	Economy	6600.00
0005434142560	12024	Economy	6600.00
0005434142554	12024	Economy	6600.00
0005433134070	12024	Economy	6600.00
0005434184642	12024	Economy	6600.00
0005434142564	12024	Economy	6600.00
0005434142559	12024	Economy	6600.00
0005433134079	12024	Economy	6600.00
0005433129233	12024	Economy	6600.00
0005434142558	12024	Economy	6600.00
0005433134122	29862	Economy	6600.00
0005434183575	29862	Economy	6600.00
0005434326265	29862	Economy	6600.00
0005433131695	29862	Economy	6600.00
0005434142594	29862	Economy	6600.00
0005434142596	29862	Economy	6600.00
0005433134124	29862	Economy	6600.00
0005434183574	29862	Economy	6600.00
0005434326261	29862	Economy	6600.00
0005433134123	29862	Economy	6600.00
0005434183573	29862	Economy	6600.00
0005434326264	29862	Economy	6600.00
0005433131693	29862	Economy	6600.00
0005434142593	29862	Economy	6600.00
0005434184659	29862	Economy	6600.00
0005434142595	29862	Economy	6600.00
0005433131692	29862	Economy	6600.00
0005433131694	29862	Economy	6600.00
0005433134125	29862	Economy	6600.00
0005435798936	1605	Economy	17200.00
0005435798943	1605	Economy	15700.00
0005435798932	1605	Economy	15700.00
0005435798942	1605	Economy	15700.00
0005435798944	1605	Economy	15700.00
0005435798945	1605	Economy	15700.00
0005435798934	1605	Economy	15700.00
0005435798938	1605	Economy	15700.00
0005435798939	1605	Economy	15700.00
0005435798937	1605	Economy	15700.00
0005435798941	1605	Economy	15700.00
0005435798931	1605	Economy	15700.00
0005435798933	1605	Economy	15700.00
0005435798935	1605	Economy	15700.00
0005435798940	1605	Economy	15700.00
0005435697224	16492	Economy	19900.00
0005435697242	16492	Economy	19900.00
0005435697244	16492	Economy	19900.00
0005435697240	16492	Economy	18100.00
0005435697229	16492	Economy	18100.00
0005435697222	16492	Economy	18100.00
0005435697228	16492	Economy	18100.00
0005435697230	16492	Economy	18100.00
0005435697220	16492	Economy	18100.00
0005435697232	16492	Economy	18100.00
0005435697241	16492	Economy	18100.00
0005435697226	16492	Economy	18100.00
0005435697233	16492	Economy	18100.00
0005435697237	16492	Economy	18100.00
0005435697238	16492	Economy	18100.00
0005435697218	16492	Economy	18100.00
0005435697219	16492	Economy	18100.00
0005435697217	16492	Economy	18100.00
0005435697227	16492	Economy	18100.00
0005435697225	16492	Economy	18100.00
0005435697221	16492	Economy	18100.00
0005435697231	16492	Economy	18100.00
0005435697243	16492	Economy	18100.00
0005435697235	16492	Economy	18100.00
0005435697223	16492	Economy	18100.00
0005435935000	16492	Economy	18100.00
0005435697239	16492	Economy	18100.00
0005435697236	16492	Economy	18100.00
0005435697234	16492	Economy	18100.00
0005435697035	24703	Economy	19900.00
0005435697020	24703	Economy	18100.00
0005435697021	24703	Economy	18100.00
0005435697071	24703	Economy	18100.00
0005435697066	24703	Economy	18100.00
0005435696923	24703	Economy	18100.00
0005435696990	24703	Economy	18100.00
0005435935037	24703	Economy	18100.00
0005435697059	24703	Economy	18100.00
0005435697099	24703	Economy	18100.00
0005435696988	24703	Economy	18100.00
0005435696914	24703	Economy	18100.00
0005435697028	24703	Economy	18100.00
0005435697065	24703	Economy	18100.00
0005435935033	24703	Economy	18100.00
0005435935036	24703	Economy	18100.00
0005435697072	24703	Economy	18100.00
0005435697012	24703	Economy	18100.00
0005435935035	24703	Economy	18100.00
0005435697098	24703	Economy	18100.00
0005435696989	24703	Economy	18100.00
0005435697061	24703	Economy	18100.00
0005435696996	24703	Economy	18100.00
0005435697015	24703	Economy	18100.00
0005435696995	24703	Economy	18100.00
0005435696919	24703	Economy	18100.00
0005435697034	24703	Economy	18100.00
0005435696953	24703	Economy	18100.00
0005435696964	24703	Economy	18100.00
0005435696974	24703	Economy	18100.00
0005435696954	24703	Economy	18100.00
0005435935034	24703	Economy	18100.00
0005433724790	18798	Economy	4400.00
0005433724789	18798	Economy	4400.00
0005433724791	18798	Economy	4400.00
0005433724788	18798	Economy	4400.00
0005432968819	18798	Economy	4400.00
0005432968815	18798	Economy	4400.00
0005433724787	18798	Economy	4400.00
0005433724744	21646	Economy	4400.00
0005433724767	21646	Economy	4400.00
0005432968835	21646	Economy	4400.00
0005433724781	21646	Economy	4400.00
0005433724762	21646	Economy	4400.00
0005433724746	21646	Economy	4400.00
0005432968834	21646	Economy	4400.00
0005433724761	21646	Economy	4400.00
0005433724766	21646	Economy	4400.00
0005433724745	21646	Economy	4400.00
0005432968836	21646	Economy	4400.00
0005434137934	7331	Business	23100.00
0005434137903	7331	Business	23100.00
0005434137923	7331	Business	23100.00
0005434137949	7331	Business	23100.00
0005434137945	7331	Business	23100.00
0005434137896	7331	Business	23100.00
0005434137902	7331	Business	23100.00
0005434137904	7331	Business	23100.00
0005434137931	7331	Business	23100.00
0005434137950	7331	Business	23100.00
0005434137940	7331	Economy	7700.00
0005434137935	7331	Economy	7700.00
0005434137917	7331	Economy	7700.00
0005434137906	7331	Economy	7700.00
0005434137893	7331	Economy	7700.00
0005434137947	7331	Economy	7700.00
0005434137912	7331	Economy	7700.00
0005434087498	7331	Economy	7700.00
0005434137891	7331	Economy	7700.00
0005434137938	7331	Economy	7700.00
0005434137890	7331	Economy	8500.00
0005434137886	7331	Economy	8500.00
0005434137901	7331	Economy	8500.00
0005434137924	7331	Economy	8500.00
0005434137930	7331	Economy	8500.00
0005434137919	7331	Economy	7700.00
0005434137898	7331	Economy	7700.00
0005434137918	7331	Economy	7700.00
0005434137905	7331	Economy	7700.00
0005434137942	7331	Economy	7700.00
0005434137926	7331	Economy	7700.00
0005434137921	7331	Economy	7700.00
0005434137887	7331	Economy	7700.00
0005434137871	7331	Economy	7700.00
0005434137911	7331	Economy	7700.00
0005434137881	7331	Economy	7700.00
0005434137914	7331	Economy	7700.00
0005434137875	7331	Economy	7700.00
0005434137908	7331	Economy	7700.00
0005434137878	7331	Economy	7700.00
0005434137907	7331	Economy	7700.00
0005434137874	7331	Economy	7700.00
0005434137876	7331	Economy	7700.00
0005434137915	7331	Economy	7700.00
0005434137895	7331	Economy	7700.00
0005434137927	7331	Economy	7700.00
0005434137939	7331	Economy	7700.00
0005434137885	7331	Economy	7700.00
0005434087500	7331	Economy	7700.00
0005434137943	7331	Economy	7700.00
0005434137913	7331	Economy	7700.00
0005434137882	7331	Economy	7700.00
0005434137877	7331	Economy	7700.00
0005434137894	7331	Economy	7700.00
0005434137872	7331	Economy	7700.00
0005434137880	7331	Economy	7700.00
0005434137946	7331	Economy	7700.00
0005434137899	7331	Economy	7700.00
0005434137873	7331	Economy	7700.00
0005434137929	7331	Economy	7700.00
0005434137937	7331	Economy	7700.00
0005434137892	7331	Economy	7700.00
0005434137948	7331	Economy	7700.00
0005434087499	7331	Economy	7700.00
0005434137941	7331	Economy	7700.00
0005434137884	7331	Economy	7700.00
0005434137920	7331	Economy	7700.00
0005434137909	7331	Economy	7700.00
0005434137951	7331	Economy	7700.00
0005434137883	7331	Economy	7700.00
0005434137888	7331	Economy	7700.00
0005434087497	7331	Economy	7700.00
0005434137916	7331	Economy	7700.00
0005434087496	7331	Economy	7700.00
0005434137910	7331	Economy	7700.00
0005434137900	7331	Economy	7700.00
0005434137932	7331	Economy	7700.00
0005434137897	7331	Economy	7700.00
0005434137928	7331	Economy	7700.00
0005434137879	7331	Economy	7700.00
0005434137952	7331	Economy	7700.00
0005434137889	7331	Economy	7700.00
0005434137933	7331	Economy	7700.00
0005434137922	7331	Economy	7700.00
0005434137936	7331	Economy	7700.00
0005434137944	7331	Economy	7700.00
0005434137925	7331	Economy	7700.00
0005434136945	28563	Business	23100.00
0005434137320	28563	Business	23100.00
0005434137355	28563	Business	23100.00
0005434137356	28563	Business	23100.00
0005434137224	28563	Business	23100.00
0005434137404	28563	Business	23100.00
0005434136740	28563	Business	23100.00
0005434087458	28563	Business	23100.00
0005434137062	28563	Business	23100.00
0005434136768	28563	Business	23100.00
0005434136943	28563	Business	23100.00
0005434137277	28563	Business	23100.00
0005434137208	28563	Economy	7700.00
0005434136741	28563	Economy	7700.00
0005434136999	28563	Economy	7700.00
0005434137166	28563	Economy	7700.00
0005434137146	28563	Economy	7700.00
0005434136895	28563	Economy	7700.00
0005434137319	28563	Economy	7700.00
0005434137115	28563	Economy	7700.00
0005434137363	28563	Economy	8500.00
0005434136963	28563	Economy	8500.00
0005434137099	28563	Economy	8500.00
0005434137142	28563	Economy	7700.00
0005434137058	28563	Economy	7700.00
0005434137280	28563	Economy	7700.00
0005434137329	28563	Economy	7700.00
0005434137090	28563	Economy	7700.00
0005434137413	28563	Economy	7700.00
0005434136812	28563	Economy	7700.00
0005434137111	28563	Economy	7700.00
0005434137088	28563	Economy	7700.00
0005434137192	28563	Economy	7700.00
0005434137130	28563	Economy	7700.00
0005434137141	28563	Economy	7700.00
0005434137191	28563	Economy	7700.00
0005434137014	28563	Economy	7700.00
0005434137286	28563	Economy	7700.00
0005434137129	28563	Economy	7700.00
0005434137278	28563	Economy	7700.00
0005434136896	28563	Economy	7700.00
0005434137285	28563	Economy	7700.00
0005434137318	28563	Economy	7700.00
0005434137017	28563	Economy	7700.00
0005434137150	28563	Economy	7700.00
0005434136770	28563	Economy	7700.00
0005434137202	28563	Economy	7700.00
0005434137509	28563	Economy	7700.00
0005434137143	28563	Economy	7700.00
0005434137371	28563	Economy	7700.00
0005434137089	28563	Economy	7700.00
0005434137382	28563	Economy	7700.00
0005434136944	28563	Economy	7700.00
0005434137454	28563	Economy	7700.00
0005434137276	28563	Economy	7700.00
0005434137072	28563	Economy	7700.00
0005434137066	28563	Economy	7700.00
0005434137001	28563	Economy	7700.00
0005434137067	28563	Economy	7700.00
0005434137249	28563	Economy	7700.00
0005434137063	28563	Economy	7700.00
0005434137116	28563	Economy	7700.00
0005434137217	28563	Economy	7700.00
0005434137223	28563	Economy	7700.00
0005434137248	28563	Economy	7700.00
0005434137065	28563	Economy	7700.00
0005434136962	28563	Economy	7700.00
0005434137260	28563	Economy	7700.00
0005434137373	28563	Economy	7700.00
0005434137015	28563	Economy	7700.00
0005434137414	28563	Economy	7700.00
0005434137383	28563	Economy	7700.00
0005434136961	28563	Economy	7700.00
0005434137362	28563	Economy	7700.00
0005434137091	28563	Economy	7700.00
0005434136964	28563	Economy	7700.00
0005434137053	28563	Economy	7700.00
0005434137194	28563	Economy	7700.00
0005434136769	28563	Economy	7700.00
0005434137038	28563	Economy	7700.00
0005434137328	28563	Economy	7700.00
0005434137405	28563	Economy	7700.00
0005434137590	28563	Economy	7700.00
0005434137000	28563	Economy	7700.00
0005434137068	28563	Economy	7700.00
0005435808205	1928	Economy	21700.00
0005433407496	1928	Economy	21700.00
0005435808203	1928	Economy	21700.00
0005435808204	1928	Economy	21700.00
0005434610219	1928	Economy	21700.00
0005435808206	1928	Economy	21700.00
0005434610218	1928	Economy	21700.00
0005433407505	1928	Economy	21700.00
0005435808200	1928	Economy	21700.00
0005435808207	1928	Economy	21700.00
0005433407506	1928	Economy	21700.00
0005433407495	1928	Economy	21700.00
0005435808201	1928	Economy	21700.00
0005434610216	1928	Economy	21700.00
0005435808208	1928	Economy	21700.00
0005434610217	1928	Economy	21700.00
0005435808202	1928	Economy	21700.00
0005434610184	23104	Economy	21700.00
0005434610198	23104	Economy	21700.00
0005434503754	16717	Economy	7600.00
0005434503665	16717	Economy	7600.00
0005434503585	16717	Economy	6900.00
0005434503680	16717	Economy	6900.00
0005434503773	16717	Economy	6900.00
0005434503775	16717	Economy	6900.00
0005434503625	16717	Economy	6900.00
0005434503705	16717	Economy	6900.00
0005434503543	16717	Economy	6900.00
0005434503537	16717	Economy	6900.00
0005434503755	16717	Economy	6900.00
0005434503780	16717	Economy	6900.00
0005434503669	16717	Economy	6900.00
0005434503673	16717	Economy	6900.00
0005434503717	16717	Economy	6900.00
0005434503679	16717	Economy	6900.00
0005434503677	16717	Economy	6900.00
0005434503779	16717	Economy	6900.00
0005434503736	16717	Economy	6900.00
0005434503589	16717	Economy	6900.00
0005434503766	16717	Economy	6900.00
0005434503515	16717	Economy	6900.00
0005434503778	16717	Economy	6900.00
0005434503636	16717	Economy	6900.00
0005434503683	16717	Economy	6900.00
0005434503716	16717	Economy	6900.00
0005434503516	16717	Economy	6900.00
0005434504021	22934	Economy	7600.00
0005434504014	22934	Economy	7600.00
0005434504004	22934	Economy	6900.00
0005434504001	22934	Economy	6900.00
0005434503990	22934	Economy	6900.00
0005434503983	22934	Economy	6900.00
0005434504008	22934	Economy	6900.00
0005434504000	22934	Economy	6900.00
0005434503986	22934	Economy	6900.00
0005434503982	22934	Economy	6900.00
0005434504015	22934	Economy	6900.00
0005434504011	22934	Economy	6900.00
0005434503987	22934	Economy	6900.00
0005434503994	22934	Economy	6900.00
0005434503998	22934	Economy	6900.00
0005434504019	22934	Economy	6900.00
0005434503995	22934	Economy	6900.00
0005434503989	22934	Economy	6900.00
0005434504013	22934	Economy	6900.00
0005434504002	22934	Economy	6900.00
0005434503997	22934	Economy	6900.00
0005434503985	22934	Economy	6900.00
0005434504018	22934	Economy	6900.00
0005434503988	22934	Economy	6900.00
0005434504017	22934	Economy	6900.00
0005434504012	22934	Economy	6900.00
0005434504005	22934	Economy	6900.00
0005434504020	22934	Economy	6900.00
0005434503996	22934	Economy	6900.00
0005434503999	22934	Economy	6900.00
0005434503992	22934	Economy	6900.00
0005434504010	22934	Economy	6900.00
0005434504003	22934	Economy	6900.00
0005434504009	22934	Economy	6900.00
0005434504007	22934	Economy	6900.00
0005434503991	22934	Economy	6900.00
0005434503984	22934	Economy	6900.00
0005434504016	22934	Economy	6900.00
0005434503993	22934	Economy	6900.00
0005434504006	22934	Economy	6900.00
0005434608300	6497	Economy	17300.00
0005434608316	6497	Economy	17300.00
0005434608306	6497	Economy	17300.00
0005434608309	6497	Economy	17300.00
0005434608314	6497	Economy	17300.00
0005434608305	6497	Economy	17300.00
0005434608302	6497	Economy	17300.00
0005434608310	6497	Economy	17300.00
0005434608311	6497	Economy	17300.00
0005434608312	6497	Economy	17300.00
0005434608313	6497	Economy	17300.00
0005434608317	6497	Economy	17300.00
0005434608307	6497	Economy	17300.00
0005434608304	6497	Economy	17300.00
0005434608303	6497	Economy	17300.00
0005434608299	6497	Economy	17300.00
0005434608301	6497	Economy	17300.00
0005434608315	6497	Economy	17300.00
0005434608308	6497	Economy	17300.00
0005434608277	22498	Economy	17300.00
0005434608278	22498	Economy	17300.00
0005434608294	22498	Economy	17300.00
0005434608287	22498	Economy	17300.00
0005434608280	22498	Economy	17300.00
0005434608276	22498	Economy	17300.00
0005434608279	22498	Economy	17300.00
0005434608286	22498	Economy	17300.00
0005433266641	2201	Economy	7700.00
0005433266608	2201	Economy	7700.00
0005433266631	2201	Economy	7000.00
0005435078294	2201	Economy	7000.00
0005435078299	2201	Economy	7000.00
0005433266632	2201	Economy	7000.00
0005435078287	2201	Economy	7000.00
0005435078288	2201	Economy	7000.00
0005433266593	2201	Economy	7000.00
0005435078290	2201	Economy	7000.00
0005435078289	2201	Economy	7000.00
0005435078295	2201	Economy	7000.00
0005435078303	2201	Economy	7000.00
0005435078292	2201	Economy	7000.00
0005435078302	2201	Economy	7000.00
0005435078301	2201	Economy	7000.00
0005433266612	2201	Economy	7000.00
0005435078298	2201	Economy	7000.00
0005435078291	2201	Economy	7000.00
0005433266595	2201	Economy	7000.00
0005435078300	2201	Economy	7000.00
0005433266639	2201	Economy	7000.00
0005435078293	2201	Economy	7000.00
0005433266613	2201	Economy	7000.00
0005435078297	2201	Economy	7000.00
0005435078296	2201	Economy	7000.00
0005433266698	24352	Economy	7700.00
0005435078155	24352	Economy	7700.00
0005435078151	24352	Economy	7700.00
0005433266692	24352	Economy	7700.00
0005435078121	24352	Economy	7000.00
0005435078130	24352	Economy	7000.00
0005435078076	24352	Economy	7000.00
0005435078179	24352	Economy	7000.00
0005435078120	24352	Economy	7000.00
0005435078171	24352	Economy	7000.00
0005433266700	24352	Economy	7000.00
0005435078170	24352	Economy	7000.00
0005433266690	24352	Economy	7000.00
0005433266694	24352	Economy	7000.00
0005435078178	24352	Economy	7000.00
0005435078212	24352	Economy	7000.00
0005435078131	24352	Economy	7000.00
0005433266695	24352	Economy	7000.00
0005433266699	24352	Economy	7000.00
0005433266691	24352	Economy	7000.00
0005435078203	24352	Economy	7000.00
0005433266693	24352	Economy	7000.00
0005433266697	24352	Economy	7000.00
0005435078077	24352	Economy	7000.00
0005433266696	24352	Economy	7000.00
0005435464491	6668	Economy	10800.00
0005435464490	6668	Economy	10800.00
0005434988705	6668	Economy	9800.00
0005434988708	6668	Economy	9800.00
0005434988707	6668	Economy	9800.00
0005434988706	6668	Economy	9800.00
0005435464482	6668	Economy	9800.00
0005435803257	6668	Economy	9800.00
0005434988704	6668	Economy	9800.00
0005434988703	6668	Economy	9800.00
0005435464489	6668	Economy	9800.00
0005435803256	6668	Economy	9800.00
0005434988702	6668	Economy	9800.00
0005434988709	6668	Economy	9800.00
0005435803255	6668	Economy	9800.00
0005435803254	6668	Economy	9800.00
0005434988581	23637	Economy	9800.00
0005435803235	23637	Economy	9800.00
0005434988568	23637	Economy	9800.00
0005434988579	23637	Economy	9800.00
0005435803230	23637	Economy	9800.00
0005435803233	23637	Economy	9800.00
0005434988558	23637	Economy	9800.00
0005434988580	23637	Economy	9800.00
0005435803234	23637	Economy	9800.00
0005434988578	23637	Economy	9800.00
0005435464501	23637	Economy	9800.00
0005434988577	23637	Economy	9800.00
0005434988567	23637	Economy	9800.00
0005432383080	30472	Business	9900.00
0005432383062	30472	Business	9900.00
0005433449900	30472	Business	9900.00
0005433449896	30472	Business	9900.00
0005432383057	30472	Business	9900.00
0005432383091	30472	Business	9900.00
0005432383079	30472	Business	9900.00
0005432383066	30472	Business	9900.00
0005433449906	30472	Economy	3300.00
0005432383068	30472	Economy	3300.00
0005432383076	30472	Economy	3300.00
0005433449917	30472	Economy	3300.00
0005432383073	30472	Economy	3300.00
0005433449907	30472	Economy	3300.00
0005433449897	30472	Economy	3300.00
0005432383063	30472	Economy	3300.00
0005432383078	30472	Economy	3600.00
0005432383094	30472	Economy	3600.00
0005432383090	30472	Economy	3600.00
0005432383085	30472	Economy	3300.00
0005433453758	30472	Economy	3300.00
0005432383064	30472	Economy	3300.00
0005433449905	30472	Economy	3300.00
0005433449895	30472	Economy	3300.00
0005433449901	30472	Economy	3300.00
0005432383086	30472	Economy	3300.00
0005432383060	30472	Economy	3300.00
0005432383077	30472	Economy	3300.00
0005432383069	30472	Economy	3300.00
0005433449904	30472	Economy	3300.00
0005433449915	30472	Economy	3300.00
0005433449913	30472	Economy	3300.00
0005433449912	30472	Economy	3300.00
0005432383058	30472	Economy	3300.00
0005433449899	30472	Economy	3300.00
0005432383074	30472	Economy	3300.00
0005433449909	30472	Economy	3300.00
0005432383071	30472	Economy	3300.00
0005432383081	30472	Economy	3300.00
0005433449908	30472	Economy	3300.00
0005432383089	30472	Economy	3300.00
0005432383075	30472	Economy	3300.00
0005433449914	30472	Economy	3300.00
0005432383059	30472	Economy	3300.00
0005432383070	30472	Economy	3300.00
0005432383087	30472	Economy	3300.00
0005433449898	30472	Economy	3300.00
0005433449910	30472	Economy	3300.00
0005432383072	30472	Economy	3300.00
0005432383088	30472	Economy	3300.00
0005432383082	30472	Economy	3300.00
0005432383067	30472	Economy	3300.00
0005433449903	30472	Economy	3300.00
0005433449902	30472	Economy	3300.00
0005433449911	30472	Economy	3300.00
0005432383065	30472	Economy	3300.00
0005432383093	30472	Economy	3300.00
0005432383083	30472	Economy	3300.00
0005433449916	30472	Economy	3300.00
0005432383061	30472	Economy	3300.00
0005432383092	30472	Economy	3300.00
0005432383084	30472	Economy	3300.00
0005433451587	31285	Business	9900.00
0005433449707	31285	Business	9900.00
0005432382663	31285	Business	9900.00
0005432382691	31285	Business	9900.00
0005432382653	31285	Business	9900.00
0005432382640	31285	Business	9900.00
0005432382565	31285	Economy	3300.00
0005432382566	31285	Economy	3300.00
0005432382760	31285	Economy	3300.00
0005432382642	31285	Economy	3300.00
0005432382753	31285	Economy	3300.00
0005433449665	31285	Economy	3300.00
0005432382690	31285	Economy	3300.00
0005433449787	31285	Economy	3600.00
0005433451600	31285	Economy	3300.00
0005432382714	31285	Economy	3300.00
0005432382797	31285	Economy	3300.00
0005433449811	31285	Economy	3300.00
0005433449743	31285	Economy	3300.00
0005433449696	31285	Economy	3300.00
0005432382720	31285	Economy	3300.00
0005432382578	31285	Economy	3300.00
0005432382800	31285	Economy	3300.00
0005433449682	31285	Economy	3300.00
0005433449738	31285	Economy	3300.00
0005432382726	31285	Economy	3300.00
0005432382752	31285	Economy	3300.00
0005432382670	31285	Economy	3300.00
0005432382638	31285	Economy	3300.00
0005433449721	31285	Economy	3300.00
0005432382698	31285	Economy	3300.00
0005433449652	31285	Economy	3300.00
0005432382700	31285	Economy	3300.00
0005433449744	31285	Economy	3300.00
0005432382639	31285	Economy	3300.00
0005433449681	31285	Economy	3300.00
0005433449724	31285	Economy	3300.00
0005432382715	31285	Economy	3300.00
0005433449737	31285	Economy	3300.00
0005432382732	31285	Economy	3300.00
0005432382641	31285	Economy	3300.00
0005432382664	31285	Economy	3300.00
0005432382746	31285	Economy	3300.00
0005432382801	31285	Economy	3300.00
0005433449816	31285	Economy	3300.00
0005432382626	31285	Economy	3300.00
0005433788181	20820	Economy	26200.00
0005435548435	20820	Economy	26200.00
0005435548422	20820	Economy	23800.00
0005433788180	20820	Economy	23800.00
0005433788188	20820	Economy	23800.00
0005433788185	20820	Economy	23800.00
0005433788187	20820	Economy	23800.00
0005435548423	20820	Economy	23800.00
0005433788182	20820	Economy	23800.00
0005435548436	20820	Economy	23800.00
0005435548434	20820	Economy	23800.00
0005433788186	20820	Economy	23800.00
0005435548433	20820	Economy	23800.00
0005433788179	20820	Economy	23800.00
0005433788183	20820	Economy	23800.00
0005433788178	20820	Economy	23800.00
0005433788189	20820	Economy	23800.00
0005433788184	20820	Economy	23800.00
0005433131649	10799	Economy	17100.00
0005435299727	10799	Economy	15600.00
0005435299728	10799	Economy	15600.00
0005435299729	10799	Economy	15600.00
0005433126785	10799	Economy	15600.00
0005435304115	10799	Economy	15600.00
0005435304110	10799	Economy	15600.00
0005433131643	10799	Economy	15600.00
0005433126812	10799	Economy	15600.00
0005433131650	10799	Economy	15600.00
0005435304109	10799	Economy	15600.00
0005435304112	10799	Economy	15600.00
0005433131653	10799	Economy	15600.00
0005433129265	29733	Economy	17100.00
0005433126836	29733	Economy	17100.00
0005433126835	29733	Economy	15600.00
0005435302190	29733	Economy	15600.00
0005433129267	29733	Economy	15600.00
0005435299767	29733	Economy	15600.00
0005435299766	29733	Economy	15600.00
0005433129266	29733	Economy	15600.00
0005435299765	29733	Economy	15600.00
0005435302189	29733	Economy	15600.00
0005435299764	29733	Economy	15600.00
0005433129264	29733	Economy	15600.00
0005434287233	2404	Economy	17200.00
0005434287224	2404	Economy	17200.00
0005434287227	2404	Economy	17200.00
0005432264468	2404	Economy	15700.00
0005434287217	2404	Economy	15700.00
0005432264467	2404	Economy	15700.00
0005433109967	2404	Economy	15700.00
0005434287223	2404	Economy	15700.00
0005434287231	2404	Economy	15700.00
0005434287215	2404	Economy	15700.00
0005434287229	2404	Economy	15700.00
0005434287214	2404	Economy	15700.00
0005434287216	2404	Economy	15700.00
0005434287230	2404	Economy	15700.00
0005434287220	2404	Economy	15700.00
0005434287225	2404	Economy	15700.00
0005434287218	2404	Economy	15700.00
0005433109941	2404	Economy	15700.00
0005434287228	2404	Economy	15700.00
0005434287211	2404	Economy	15700.00
0005434287213	2404	Economy	15700.00
0005433109929	2404	Economy	15700.00
0005434287212	2404	Economy	15700.00
0005434287226	2404	Economy	15700.00
0005434287232	2404	Economy	15700.00
0005434287222	2404	Economy	15700.00
0005434287221	2404	Economy	15700.00
0005434287219	2404	Economy	15700.00
0005433109930	2404	Economy	15700.00
0005434286973	26861	Economy	17200.00
0005434287045	26861	Economy	17200.00
0005433110011	26861	Economy	15700.00
0005433110021	26861	Economy	15700.00
0005434287044	26861	Economy	15700.00
0005434287029	26861	Economy	15700.00
0005434287039	26861	Economy	15700.00
0005434287064	26861	Economy	15700.00
0005433110019	26861	Economy	15700.00
0005433110012	26861	Economy	15700.00
0005433110016	26861	Economy	15700.00
0005434287105	26861	Economy	15700.00
0005433110014	26861	Economy	15700.00
0005434287104	26861	Economy	15700.00
0005433110015	26861	Economy	15700.00
0005433110022	26861	Economy	15700.00
0005433110020	26861	Economy	15700.00
0005434286974	26861	Economy	15700.00
0005434286926	26861	Economy	15700.00
0005433110017	26861	Economy	15700.00
0005434286998	26861	Economy	15700.00
0005434286927	26861	Economy	15700.00
0005433110018	26861	Economy	15700.00
0005434287026	26861	Economy	15700.00
0005433110013	26861	Economy	15700.00
0005434287043	26861	Economy	15700.00
0005434286940	26861	Economy	15700.00
0005435856191	25467	Economy	25000.00
0005435856192	25467	Economy	22800.00
0005435856193	25467	Economy	22800.00
0005435856190	25467	Economy	22800.00
0005434272188	26678	Economy	22800.00
0005435856146	26678	Economy	22800.00
0005435856159	26678	Economy	22800.00
0005434273071	26678	Economy	22800.00
0005435856150	26678	Economy	22800.00
0005435856152	26678	Economy	22800.00
0005434272187	26678	Economy	22800.00
0005435854044	26678	Economy	22800.00
0005434273073	26678	Economy	22800.00
0005435854041	26678	Economy	22800.00
0005434273072	26678	Economy	22800.00
0005434520163	19082	Economy	24600.00
0005435314815	19082	Economy	24600.00
0005435314818	19082	Economy	22300.00
0005434520130	19082	Economy	22300.00
0005434520158	19082	Economy	22300.00
0005435314824	19082	Economy	22300.00
0005435314822	19082	Economy	22300.00
0005434520202	19082	Economy	22300.00
0005434520143	19082	Economy	22300.00
0005434520152	19082	Economy	22300.00
0005434520176	19082	Economy	22300.00
0005434520177	19082	Economy	22300.00
0005435314826	19082	Economy	22300.00
0005434520180	19082	Economy	22300.00
0005435314820	19082	Economy	22300.00
0005435314821	19082	Economy	22300.00
0005435314819	19082	Economy	22300.00
0005434520175	19082	Economy	22300.00
0005434520206	19082	Economy	22300.00
0005434520159	19082	Economy	22300.00
0005434520184	19082	Economy	22300.00
0005435314827	19082	Economy	22300.00
0005434520154	19082	Economy	22300.00
0005435314823	19082	Economy	22300.00
0005435314816	19082	Economy	22300.00
0005434520164	19082	Economy	22300.00
0005435314828	19082	Economy	22300.00
0005434520171	19082	Economy	22300.00
0005434520207	19082	Economy	22300.00
0005435314825	19082	Economy	22300.00
0005434520185	19082	Economy	22300.00
0005434520135	19082	Economy	22300.00
0005435314817	19082	Economy	22300.00
0005434520153	19082	Economy	22300.00
0005433874335	7779	Economy	17400.00
0005433874337	7779	Economy	17400.00
0005433874341	7779	Economy	17400.00
0005433874338	7779	Economy	17400.00
0005433874336	7779	Economy	17400.00
0005433874339	7779	Economy	17400.00
0005433874342	7779	Economy	17400.00
0005433874343	7779	Economy	17400.00
0005433874340	7779	Economy	17400.00
0005433874301	32624	Economy	19200.00
0005433874315	32624	Economy	17400.00
0005433874317	32624	Economy	17400.00
0005433874296	32624	Economy	17400.00
0005433874300	32624	Economy	17400.00
0005433874316	32624	Economy	17400.00
0005433874299	32624	Economy	17400.00
0005433868312	4778	Economy	19400.00
0005433868322	4778	Economy	19400.00
0005433868328	4778	Economy	19400.00
0005433868330	4778	Economy	19400.00
0005435860442	4778	Economy	17600.00
0005433868306	4778	Economy	17600.00
0005433868345	4778	Economy	17600.00
0005433868341	4778	Economy	17600.00
0005433868315	4778	Economy	17600.00
0005433868326	4778	Economy	17600.00
0005433868310	4778	Economy	17600.00
0005433868325	4778	Economy	17600.00
0005433868319	4778	Economy	17600.00
0005433868338	4778	Economy	17600.00
0005433868305	4778	Economy	17600.00
0005433868314	4778	Economy	17600.00
0005433868313	4778	Economy	17600.00
0005435860444	4778	Economy	17600.00
0005433868332	4778	Economy	17600.00
0005433868320	4778	Economy	17600.00
0005433868329	4778	Economy	17600.00
0005433868335	4778	Economy	17600.00
0005433868344	4778	Economy	17600.00
0005433868317	4778	Economy	17600.00
0005433868340	4778	Economy	17600.00
0005433868342	4778	Economy	17600.00
0005433868334	4778	Economy	17600.00
0005433868316	4778	Economy	17600.00
0005433868333	4778	Economy	17600.00
0005433868308	4778	Economy	17600.00
0005433868307	4778	Economy	17600.00
0005433868309	4778	Economy	17600.00
0005433868339	4778	Economy	17600.00
0005435860443	4778	Economy	17600.00
0005433868321	4778	Economy	17600.00
0005433868324	4778	Economy	17600.00
0005433868323	4778	Economy	17600.00
0005433868311	4778	Economy	17600.00
0005433868327	4778	Economy	17600.00
0005433868331	4778	Economy	17600.00
0005433868336	4778	Economy	17600.00
0005433868318	4778	Economy	17600.00
0005433868343	4778	Economy	17600.00
0005433868337	4778	Economy	17600.00
0005433867866	32605	Economy	19400.00
0005433867814	32605	Economy	19400.00
0005433867834	32605	Economy	19400.00
0005433867961	32605	Economy	19400.00
0005433868188	32605	Economy	17600.00
0005433867980	32605	Economy	17600.00
0005433867979	32605	Economy	17600.00
0005433867809	32605	Economy	17600.00
0005433868086	32605	Economy	17600.00
0005433867796	32605	Economy	17600.00
0005433867956	32605	Economy	17600.00
0005433867774	32605	Economy	17600.00
0005433867997	32605	Economy	17600.00
0005433868037	32605	Economy	17600.00
0005433868065	32605	Economy	17600.00
0005433867882	32605	Economy	17600.00
0005433867905	32605	Economy	17600.00
0005433867942	32605	Economy	17600.00
0005433867853	32605	Economy	17600.00
0005433867797	32605	Economy	17600.00
0005433867833	32605	Economy	17600.00
0005433867957	32605	Economy	17600.00
0005433867881	32605	Economy	17600.00
0005433867953	32605	Economy	17600.00
0005433867865	32605	Economy	17600.00
0005433867864	32605	Economy	17600.00
0005433867958	32605	Economy	17600.00
0005433867747	32605	Economy	17600.00
0005433868022	32605	Economy	17600.00
0005433867748	32605	Economy	17600.00
0005433867948	32605	Economy	17600.00
0005433867919	32605	Economy	17600.00
0005433867906	32605	Economy	17600.00
0005433868091	32605	Economy	17600.00
0005433867886	32605	Economy	17600.00
0005433867803	32605	Economy	17600.00
0005433867931	32605	Economy	17600.00
0005433867891	32605	Economy	17600.00
0005433868081	32605	Economy	17600.00
0005433867863	32605	Economy	17600.00
0005433867815	32605	Economy	17600.00
0005433867918	32605	Economy	17600.00
0005433867941	32605	Economy	17600.00
0005433867983	32605	Economy	17600.00
0005433867775	32605	Economy	17600.00
0005433867982	32605	Economy	17600.00
0005433867848	32605	Economy	17600.00
0005434663362	3444	Economy	24800.00
0005434461641	3444	Economy	22600.00
0005435911334	3444	Economy	22600.00
0005435911348	3444	Economy	22600.00
0005435911359	3444	Economy	22600.00
0005434663372	3444	Economy	22600.00
0005435911384	3444	Economy	22600.00
0005434663363	3444	Economy	22600.00
0005435911349	3444	Economy	22600.00
0005434460498	3444	Economy	22600.00
0005435911383	3444	Economy	22600.00
0005434663374	3444	Economy	22600.00
0005434663370	3444	Economy	22600.00
0005434663364	3444	Economy	22600.00
0005434461640	3444	Economy	22600.00
0005434663361	3444	Economy	22600.00
0005434663371	3444	Economy	22600.00
0005434663375	3444	Economy	22600.00
0005434663360	3444	Economy	22600.00
0005434460499	3444	Economy	22600.00
0005435911369	3444	Economy	22600.00
0005435911360	3444	Economy	22600.00
0005434663366	3444	Economy	22600.00
0005434663368	3444	Economy	22600.00
0005434663367	3444	Economy	22600.00
0005434663365	3444	Economy	22600.00
0005434663369	3444	Economy	22600.00
0005434663373	3444	Economy	22600.00
0005434460471	12482	Economy	24800.00
0005434460475	12482	Economy	24800.00
0005434460478	12482	Economy	24800.00
0005434462755	12482	Economy	24800.00
0005434663281	12482	Economy	22600.00
0005434663166	12482	Economy	22600.00
0005434460474	12482	Economy	22600.00
0005435911430	12482	Economy	22600.00
0005434663252	12482	Economy	22600.00
0005434663282	12482	Economy	22600.00
0005434663221	12482	Economy	22600.00
0005434460480	12482	Economy	22600.00
0005434462753	12482	Economy	22600.00
0005434462756	12482	Economy	22600.00
0005434663276	12482	Economy	22600.00
0005434462759	12482	Economy	22600.00
0005435911428	12482	Economy	22600.00
0005434663265	12482	Economy	22600.00
0005434462754	12482	Economy	22600.00
0005435911427	12482	Economy	22600.00
0005435911431	12482	Economy	22600.00
0005434462758	12482	Economy	22600.00
0005434462760	12482	Economy	22600.00
0005434460482	12482	Economy	22600.00
0005434462765	12482	Economy	22600.00
0005434462764	12482	Economy	22600.00
0005434663220	12482	Economy	22600.00
0005434663213	12482	Economy	22600.00
0005434460483	12482	Economy	22600.00
0005434663259	12482	Economy	22600.00
0005434663240	12482	Economy	22600.00
0005434663261	12482	Economy	22600.00
0005434663226	12482	Economy	22600.00
0005435911429	12482	Economy	22600.00
0005434663264	12482	Economy	22600.00
0005434663225	12482	Economy	22600.00
0005434663239	12482	Economy	22600.00
0005434663277	12482	Economy	22600.00
0005434663283	12482	Economy	22600.00
0005434460481	12482	Economy	22600.00
0005435911426	12482	Economy	22600.00
0005435911432	12482	Economy	22600.00
0005433868037	14521	Economy	18500.00
0005433867942	14521	Economy	18500.00
0005433867980	14521	Economy	18500.00
0005433867886	14521	Economy	16800.00
0005433867905	14521	Economy	16800.00
0005433868188	14521	Economy	16800.00
0005433867881	14521	Economy	16800.00
0005433868081	14521	Economy	16800.00
0005433867961	14521	Economy	16800.00
0005433867882	14521	Economy	16800.00
0005433867815	14521	Economy	16800.00
0005433868065	14521	Economy	16800.00
0005433867956	14521	Economy	16800.00
0005433867953	14521	Economy	16800.00
0005433867834	14521	Economy	16800.00
0005433867931	14521	Economy	16800.00
0005433867948	14521	Economy	16800.00
0005433867833	14521	Economy	16800.00
0005433868086	14521	Economy	16800.00
0005433868022	14521	Economy	16800.00
0005433867983	14521	Economy	16800.00
0005433867919	14521	Economy	16800.00
0005433867774	14521	Economy	16800.00
0005433867747	14521	Economy	16800.00
0005433867906	14521	Economy	16800.00
0005433868091	14521	Economy	16800.00
0005433867982	14521	Economy	16800.00
0005433867796	14521	Economy	16800.00
0005433867866	14521	Economy	16800.00
0005433867918	14521	Economy	16800.00
0005433867957	14521	Economy	16800.00
0005433867891	14521	Economy	16800.00
0005433867814	14521	Economy	16800.00
0005433867997	14521	Economy	16800.00
0005433867941	14521	Economy	16800.00
0005433867863	14521	Economy	16800.00
0005433867775	14521	Economy	16800.00
0005433867958	14521	Economy	16800.00
0005433867979	14521	Economy	16800.00
0005433867864	14521	Economy	16800.00
0005433867797	14521	Economy	16800.00
0005433867748	14521	Economy	16800.00
0005433867809	14521	Economy	16800.00
0005433867803	14521	Economy	16800.00
0005433867853	14521	Economy	16800.00
0005433867848	14521	Economy	16800.00
0005433867865	14521	Economy	16800.00
0005433868289	32689	Economy	18500.00
0005433868279	32689	Economy	18500.00
0005433868280	32689	Economy	16800.00
0005433868286	32689	Economy	16800.00
0005433868290	32689	Economy	16800.00
0005433868273	32689	Economy	16800.00
0005433868301	32689	Economy	16800.00
0005433868295	32689	Economy	16800.00
0005433868287	32689	Economy	16800.00
0005433868268	32689	Economy	16800.00
0005433868265	32689	Economy	16800.00
0005433868285	32689	Economy	16800.00
0005433868284	32689	Economy	16800.00
0005433868276	32689	Economy	16800.00
0005433868288	32689	Economy	16800.00
0005433868293	32689	Economy	16800.00
0005433868278	32689	Economy	16800.00
0005433868264	32689	Economy	16800.00
0005433868304	32689	Economy	16800.00
0005433868272	32689	Economy	16800.00
0005433868303	32689	Economy	16800.00
0005433868291	32689	Economy	16800.00
0005433868269	32689	Economy	16800.00
0005433868281	32689	Economy	16800.00
0005433868270	32689	Economy	16800.00
0005433868297	32689	Economy	16800.00
0005433868302	32689	Economy	16800.00
0005433868283	32689	Economy	16800.00
0005433868292	32689	Economy	16800.00
0005433868294	32689	Economy	16800.00
0005433868263	32689	Economy	16800.00
0005433868266	32689	Economy	16800.00
0005433868271	32689	Economy	16800.00
0005433868277	32689	Economy	16800.00
0005433868298	32689	Economy	16800.00
0005433868299	32689	Economy	16800.00
0005433868274	32689	Economy	16800.00
0005433868300	32689	Economy	16800.00
0005433868275	32689	Economy	16800.00
0005433868282	32689	Economy	16800.00
0005433868296	32689	Economy	16800.00
0005433868267	32689	Economy	16800.00
0005432799012	12137	Economy	4900.00
0005432799147	12137	Economy	4400.00
0005432799118	12137	Economy	4400.00
0005432799162	12137	Economy	4400.00
0005432799099	12137	Economy	4400.00
0005432799164	12137	Economy	4400.00
0005432799114	12137	Economy	4400.00
0005432799038	12137	Economy	4400.00
0005432799121	12137	Economy	4400.00
0005432799062	12137	Economy	4400.00
0005432799076	12137	Economy	4400.00
0005432799204	12137	Economy	4400.00
0005432799092	12137	Economy	4400.00
0005432799218	12137	Economy	4400.00
0005432799193	12137	Economy	4400.00
0005432799088	12137	Economy	4400.00
0005432799146	12137	Economy	4400.00
0005432799073	12137	Economy	4400.00
0005432799160	12137	Economy	4400.00
0005432799061	12137	Economy	4400.00
0005432799085	12137	Economy	4400.00
0005432799089	12137	Economy	4400.00
0005432799192	12137	Economy	4400.00
0005432799355	14818	Economy	4900.00
0005432799330	14818	Economy	4900.00
0005432799331	14818	Economy	4900.00
0005432799335	14818	Economy	4400.00
0005432799341	14818	Economy	4400.00
0005432799333	14818	Economy	4400.00
0005432799339	14818	Economy	4400.00
0005432799334	14818	Economy	4400.00
0005432799356	14818	Economy	4400.00
0005432799354	14818	Economy	4400.00
0005432799351	14818	Economy	4400.00
0005432799348	14818	Economy	4400.00
0005432799349	14818	Economy	4400.00
0005432799346	14818	Economy	4400.00
0005432799353	14818	Economy	4400.00
0005432799350	14818	Economy	4400.00
0005432799352	14818	Economy	4400.00
0005432799337	14818	Economy	4400.00
0005432799357	14818	Economy	4400.00
0005432799344	14818	Economy	4400.00
0005432799336	14818	Economy	4400.00
0005432799347	14818	Economy	4400.00
0005432799345	14818	Economy	4400.00
0005432799338	14818	Economy	4400.00
0005432799342	14818	Economy	4400.00
0005432799340	14818	Economy	4400.00
0005432799343	14818	Economy	4400.00
0005432799332	14818	Economy	4400.00
0005432799329	14818	Economy	4400.00
0005435293137	7078	Business	49100.00
0005434407588	7078	Business	49100.00
0005434299494	7078	Business	49100.00
0005434407589	7078	Business	49100.00
0005434407583	7078	Business	49100.00
0005434299498	7078	Business	49100.00
0005435293091	7078	Business	49100.00
0005435310902	7078	Business	49100.00
0005434299501	7078	Business	49100.00
0005434407564	7078	Business	49100.00
0005434407559	7078	Business	49100.00
0005434407561	7078	Business	49100.00
0005432153914	7078	Economy	16400.00
0005434407584	7078	Economy	16400.00
0005434407549	7078	Economy	16400.00
0005435293053	7078	Economy	16400.00
0005434407594	7078	Economy	16400.00
0005434407604	7078	Economy	16400.00
0005435310898	7078	Economy	16400.00
0005434299492	7078	Economy	16400.00
0005434407596	7078	Economy	16400.00
0005434407544	7078	Economy	16400.00
0005434407558	7078	Economy	16400.00
0005434299491	7078	Economy	16400.00
0005434407585	7078	Economy	16400.00
0005434407576	7078	Economy	16400.00
0005434299484	7078	Economy	16400.00
0005434407548	7078	Economy	16400.00
0005432153919	7078	Economy	16400.00
0005434299500	7078	Economy	16400.00
0005434299487	7078	Economy	16400.00
0005434407566	7078	Economy	16400.00
0005434299486	7078	Economy	16400.00
0005434299490	7078	Economy	16400.00
0005434407545	7078	Economy	16400.00
0005435310893	7078	Economy	16400.00
0005434407599	7078	Economy	16400.00
0005434407562	7078	Economy	16400.00
0005434407556	7078	Economy	16400.00
0005432153918	7078	Economy	16400.00
0005434407542	7078	Economy	16400.00
0005434407551	7078	Economy	16400.00
0005434407572	7078	Economy	16400.00
0005434299495	7078	Economy	16400.00
0005432153920	7078	Economy	16400.00
0005434299489	7078	Economy	16400.00
0005435293051	7078	Economy	16400.00
0005434407602	7078	Economy	16400.00
0005432108242	7078	Economy	16400.00
0005435310844	7078	Economy	16400.00
0005434299496	7078	Economy	18000.00
0005434299502	7078	Economy	18000.00
0005434407595	7078	Economy	18000.00
0005434407574	7078	Economy	18000.00
0005434407571	7078	Economy	18000.00
0005432153915	7078	Economy	18000.00
0005434299483	7078	Economy	16400.00
0005434407575	7078	Economy	16400.00
0005435310903	7078	Economy	16400.00
0005435310854	7078	Economy	16400.00
0005434407546	7078	Economy	16400.00
0005434407591	7078	Economy	16400.00
0005434299485	7078	Economy	16400.00
0005432108243	7078	Economy	16400.00
0005434407590	7078	Economy	16400.00
0005435310896	7078	Economy	16400.00
0005434407579	7078	Economy	16400.00
0005434407587	7078	Economy	16400.00
0005435293052	7078	Economy	16400.00
0005434299497	7078	Economy	16400.00
0005434407543	7078	Economy	16400.00
0005435293108	7078	Economy	16400.00
0005434407557	7078	Economy	16400.00
0005434407554	7078	Economy	16400.00
0005435310897	7078	Economy	16400.00
0005434407552	7078	Economy	16400.00
0005434407567	7078	Economy	16400.00
0005434407582	7078	Economy	16400.00
0005434299493	7078	Economy	16400.00
0005435293120	7078	Economy	16400.00
0005432153916	7078	Economy	16400.00
0005435293104	7078	Economy	16400.00
0005434407568	7078	Economy	16400.00
0005434407577	7078	Economy	16400.00
0005434407578	7078	Economy	16400.00
0005435293136	7078	Economy	16400.00
0005435293113	7078	Economy	16400.00
0005434407593	7078	Economy	16400.00
0005434407586	7078	Economy	16400.00
0005434407555	7078	Economy	16400.00
0005434299480	7078	Economy	16400.00
0005434407605	7078	Economy	16400.00
0005434407560	7078	Economy	16400.00
0005434407603	7078	Economy	16400.00
0005434299481	7078	Economy	16400.00
0005434299499	7078	Economy	16400.00
0005432153913	7078	Economy	16400.00
0005434407592	7078	Economy	16400.00
0005434407550	7078	Economy	16400.00
0005434407581	7078	Economy	16400.00
0005434407580	7078	Economy	16400.00
0005435310843	7078	Economy	16400.00
0005435293134	7078	Economy	16400.00
0005435293067	7078	Economy	16400.00
0005435293129	7078	Economy	16400.00
0005434407541	7078	Economy	16400.00
0005434299482	7078	Economy	16400.00
0005435293090	7078	Economy	16400.00
0005432153917	7078	Economy	16400.00
0005434407570	7078	Economy	16400.00
0005434407547	7078	Economy	16400.00
0005434407553	7078	Economy	16400.00
0005434299479	7078	Economy	16400.00
0005434407600	7078	Economy	16400.00
0005434407563	7078	Economy	16400.00
0005434407569	7078	Economy	16400.00
0005435293066	7078	Economy	16400.00
0005434407565	7078	Economy	16400.00
0005432108241	7078	Economy	16400.00
0005435310904	7078	Economy	16400.00
0005434407597	7078	Economy	16400.00
0005434407598	7078	Economy	16400.00
0005435310914	7078	Economy	16400.00
0005434407601	7078	Economy	16400.00
0005434299488	7078	Economy	16400.00
0005434407573	7078	Economy	16400.00
0005435293213	26939	Business	49100.00
0005434407162	26939	Business	49100.00
0005434406791	26939	Business	49100.00
0005434406815	26939	Business	49100.00
0005434299343	26939	Business	49100.00
0005434407001	26939	Business	49100.00
0005434299328	26939	Business	49100.00
0005435311028	26939	Business	49100.00
0005435293209	26939	Business	49100.00
0005434407323	26939	Business	49100.00
0005434407043	26939	Business	49100.00
0005434407188	26939	Economy	16400.00
0005434407012	26939	Economy	16400.00
0005434406966	26939	Economy	16400.00
0005434406759	26939	Economy	16400.00
0005434407189	26939	Economy	16400.00
0005435293210	26939	Economy	16400.00
0005432058364	26939	Economy	16400.00
0005434299228	26939	Economy	16400.00
0005434406836	26939	Economy	16400.00
0005434406790	26939	Economy	16400.00
0005434406840	26939	Economy	16400.00
0005434406941	26939	Economy	16400.00
0005434406831	26939	Economy	16400.00
0005434406758	26939	Economy	16400.00
0005435311026	26939	Economy	16400.00
0005434299299	26939	Economy	16400.00
0005434406944	26939	Economy	16400.00
0005434407239	26939	Economy	16400.00
0005434299350	26939	Economy	16400.00
0005434407102	26939	Economy	16400.00
0005434299362	26939	Economy	16400.00
0005432058365	26939	Economy	16400.00
0005432058367	26939	Economy	16400.00
0005434406854	26939	Economy	16400.00
0005434406856	26939	Economy	16400.00
0005434406947	26939	Economy	16400.00
0005434406997	26939	Economy	16400.00
0005434299341	26939	Economy	16400.00
0005434406942	26939	Economy	16400.00
0005434407324	26939	Economy	16400.00
0005434407133	26939	Economy	16400.00
0005434299211	26939	Economy	16400.00
0005435293220	26939	Economy	16400.00
0005434299289	26939	Economy	16400.00
0005435311032	26939	Economy	16400.00
0005434406720	26939	Economy	16400.00
0005434406813	26939	Economy	18000.00
0005434299321	26939	Economy	18000.00
0005434406705	26939	Economy	18000.00
0005434299263	26939	Economy	18000.00
0005434407042	26939	Economy	18000.00
0005434406976	26939	Economy	18000.00
0005434406798	26939	Economy	16400.00
0005434406792	26939	Economy	16400.00
0005434406849	26939	Economy	16400.00
0005435293212	26939	Economy	16400.00
0005434407146	26939	Economy	16400.00
0005434299298	26939	Economy	16400.00
0005434406839	26939	Economy	16400.00
0005434407027	26939	Economy	16400.00
0005434406714	26939	Economy	16400.00
0005434407128	26939	Economy	16400.00
0005434407044	26939	Economy	16400.00
0005434406970	26939	Economy	16400.00
0005434407280	26939	Economy	16400.00
0005435293219	26939	Economy	16400.00
0005435311029	26939	Economy	16400.00
0005434299379	26939	Economy	16400.00
0005434299242	26939	Economy	16400.00
0005434299349	26939	Economy	16400.00
0005435293215	26939	Economy	16400.00
0005434406979	26939	Economy	16400.00
0005434407024	26939	Economy	16400.00
0005434406904	26939	Economy	16400.00
0005434406841	26939	Economy	16400.00
0005434406721	26939	Economy	16400.00
0005434406980	26939	Economy	16400.00
0005434406913	26939	Economy	16400.00
0005434299378	26939	Economy	16400.00
0005435311033	26939	Economy	16400.00
0005434407002	26939	Economy	16400.00
0005434407023	26939	Economy	16400.00
0005434407028	26939	Economy	16400.00
0005434299290	26939	Economy	16400.00
0005435311027	26939	Economy	16400.00
0005434407022	26939	Economy	16400.00
0005435293216	26939	Economy	16400.00
0005432058366	26939	Economy	16400.00
0005435311034	26939	Economy	16400.00
0005434406964	26939	Economy	16400.00
0005435293221	26939	Economy	16400.00
0005435311031	26939	Economy	16400.00
0005434406905	26939	Economy	16400.00
0005435293214	26939	Economy	16400.00
0005434406974	26939	Economy	16400.00
0005434406937	26939	Economy	16400.00
0005435293217	26939	Economy	16400.00
0005435311030	26939	Economy	16400.00
0005434299342	26939	Economy	16400.00
0005434407202	26939	Economy	16400.00
0005435293211	26939	Economy	16400.00
0005434406981	26939	Economy	16400.00
0005434406865	26939	Economy	16400.00
0005434406715	26939	Economy	16400.00
0005434406726	26939	Economy	16400.00
0005435293208	26939	Economy	16400.00
0005434299243	26939	Economy	16400.00
0005435293218	26939	Economy	16400.00
0005434406940	26939	Economy	16400.00
0005434406925	26939	Economy	16400.00
0005432604247	6441	Economy	16500.00
0005432604237	6441	Economy	16500.00
0005432604230	6441	Economy	16500.00
0005432604227	6441	Economy	16500.00
0005432604218	6441	Economy	15000.00
0005432604231	6441	Economy	15000.00
0005432604248	6441	Economy	15000.00
0005432604243	6441	Economy	15000.00
0005432604238	6441	Economy	15000.00
0005432604224	6441	Economy	15000.00
0005432604229	6441	Economy	15000.00
0005432604222	6441	Economy	15000.00
0005432604244	6441	Economy	15000.00
0005434512100	6441	Economy	15000.00
0005432604226	6441	Economy	15000.00
0005432604212	6441	Economy	15000.00
0005434512102	6441	Economy	15000.00
0005432604220	6441	Economy	15000.00
0005432604236	6441	Economy	15000.00
0005434512103	6441	Economy	15000.00
0005432604225	6441	Economy	15000.00
0005432604216	6441	Economy	15000.00
0005432604210	6441	Economy	15000.00
0005432604213	6441	Economy	15000.00
0005432604240	6441	Economy	15000.00
0005432604246	6441	Economy	15000.00
0005432604217	6441	Economy	15000.00
0005432604239	6441	Economy	15000.00
0005432604245	6441	Economy	15000.00
0005432604215	6441	Economy	15000.00
0005432604223	6441	Economy	15000.00
0005432604234	6441	Economy	15000.00
0005432604235	6441	Economy	15000.00
0005435218103	6441	Economy	15000.00
0005432604228	6441	Economy	15000.00
0005435220488	6441	Economy	15000.00
0005432604241	6441	Economy	15000.00
0005432604249	6441	Economy	15000.00
0005432604233	6441	Economy	15000.00
0005432604219	6441	Economy	15000.00
0005432604242	6441	Economy	15000.00
0005432604221	6441	Economy	15000.00
0005434512101	6441	Economy	15000.00
0005432604214	6441	Economy	15000.00
0005432604211	6441	Economy	15000.00
0005432604232	6441	Economy	15000.00
0005435218107	6441	Economy	15000.00
0005434512054	21393	Economy	16500.00
0005432603910	21393	Economy	16500.00
0005432603780	21393	Economy	16500.00
0005432603820	21393	Economy	16500.00
0005432603917	21393	Economy	15000.00
0005432603990	21393	Economy	15000.00
0005432603835	21393	Economy	15000.00
0005432603864	21393	Economy	15000.00
0005432603787	21393	Economy	15000.00
0005432603726	21393	Economy	15000.00
0005432603923	21393	Economy	15000.00
0005434512055	21393	Economy	15000.00
0005434512052	21393	Economy	15000.00
0005432603858	21393	Economy	15000.00
0005432603811	21393	Economy	15000.00
0005432603795	21393	Economy	15000.00
0005432603754	21393	Economy	15000.00
0005432603842	21393	Economy	15000.00
0005432604000	21393	Economy	15000.00
0005432603928	21393	Economy	15000.00
0005432603879	21393	Economy	15000.00
0005432603753	21393	Economy	15000.00
0005432603880	21393	Economy	15000.00
0005434512066	21393	Economy	15000.00
0005432603791	21393	Economy	15000.00
0005432603836	21393	Economy	15000.00
0005432603724	21393	Economy	15000.00
0005432603989	21393	Economy	15000.00
0005432603744	21393	Economy	15000.00
0005432603758	21393	Economy	15000.00
0005434512065	21393	Economy	15000.00
0005432603782	21393	Economy	15000.00
0005432603902	21393	Economy	15000.00
0005432603790	21393	Economy	15000.00
0005432603844	21393	Economy	15000.00
0005432603929	21393	Economy	15000.00
0005432603725	21393	Economy	15000.00
0005434512071	21393	Economy	15000.00
0005432603788	21393	Economy	15000.00
0005432603971	21393	Economy	15000.00
0005434512064	21393	Economy	15000.00
0005432603898	21393	Economy	15000.00
0005432603999	21393	Economy	15000.00
0005432603751	21393	Economy	15000.00
0005432603816	21393	Economy	15000.00
0005432603857	21393	Economy	15000.00
0005434906601	14994	Business	18900.00
0005434906454	14994	Business	18900.00
0005434906572	14994	Business	18900.00
0005434906463	14994	Business	18900.00
0005434906667	14994	Business	18900.00
0005433251385	14994	Business	18900.00
0005433251377	14994	Business	18900.00
0005434906418	14994	Business	18900.00
0005434906492	14994	Business	18900.00
0005433251375	14994	Economy	6300.00
0005434906567	14994	Economy	6300.00
0005433251396	14994	Economy	6300.00
0005434906424	14994	Economy	6300.00
0005434906569	14994	Economy	6300.00
0005434906787	14994	Economy	6300.00
0005434906683	14994	Economy	6300.00
0005434906655	14994	Economy	6300.00
0005433251394	14994	Economy	6300.00
0005433251392	14994	Economy	6300.00
0005434906715	14994	Economy	6900.00
0005434906726	14994	Economy	6900.00
0005434906702	14994	Economy	6900.00
0005434906457	14994	Economy	6900.00
0005433251389	14994	Economy	6900.00
0005434906637	14994	Economy	6300.00
0005434906566	14994	Economy	6300.00
0005433251379	14994	Economy	6300.00
0005433251391	14994	Economy	6300.00
0005434906685	14994	Economy	6300.00
0005433251381	14994	Economy	6300.00
0005434906456	14994	Economy	6300.00
0005434906648	14994	Economy	6300.00
0005434906565	14994	Economy	6300.00
0005433251373	14994	Economy	6300.00
0005433251380	14994	Economy	6300.00
0005434906826	14994	Economy	6300.00
0005434906549	14994	Economy	6300.00
0005433251390	14994	Economy	6300.00
0005434906473	14994	Economy	6300.00
0005434906552	14994	Economy	6300.00
0005433251397	14994	Economy	6300.00
0005433251388	14994	Economy	6300.00
0005434906628	14994	Economy	6300.00
0005434906502	14994	Economy	6300.00
0005433251393	14994	Economy	6300.00
0005434906694	14994	Economy	6300.00
0005434906695	14994	Economy	6300.00
0005434906658	14994	Economy	6300.00
0005433251378	14994	Economy	6300.00
0005434906703	14994	Economy	6300.00
0005433251382	14994	Economy	6300.00
0005434906630	14994	Economy	6300.00
0005434906568	14994	Economy	6300.00
0005434906581	14994	Economy	6300.00
0005433251387	14994	Economy	6300.00
0005433251398	14994	Economy	6300.00
0005434906587	14994	Economy	6300.00
0005434906570	14994	Economy	6300.00
0005434906425	14994	Economy	6300.00
0005433251400	14994	Economy	6300.00
0005434906394	14994	Economy	6300.00
0005433251384	14994	Economy	6300.00
0005434906751	14994	Economy	6300.00
0005434906727	14994	Economy	6300.00
0005434906486	14994	Economy	6300.00
0005434906704	14994	Economy	6300.00
0005434906712	14994	Economy	6300.00
0005434906584	14994	Economy	6300.00
0005434906693	14994	Economy	6300.00
0005434906462	14994	Economy	6300.00
0005433251372	14994	Economy	6300.00
0005433251399	14994	Economy	6300.00
0005434906711	14994	Economy	6300.00
0005434906511	14994	Economy	6300.00
0005434906765	14994	Economy	6300.00
0005434906657	14994	Economy	6300.00
0005434906615	14994	Economy	6300.00
0005433251383	14994	Economy	6300.00
0005433251376	14994	Economy	6300.00
0005434906629	14994	Economy	6300.00
0005433251395	14994	Economy	6300.00
0005433251386	14994	Economy	6300.00
0005433251371	14994	Economy	6300.00
0005434906750	14994	Economy	6300.00
0005434906684	14994	Economy	6300.00
0005433251374	14994	Economy	6300.00
0005434906786	14994	Economy	6300.00
0005433251034	25840	Business	18900.00
0005433251148	25840	Business	18900.00
0005434907103	25840	Business	18900.00
0005434907082	25840	Business	18900.00
0005433250960	25840	Business	18900.00
0005433250948	25840	Business	18900.00
0005434907096	25840	Business	18900.00
0005434907074	25840	Business	18900.00
0005433250961	25840	Business	18900.00
0005434907098	25840	Business	18900.00
0005434907101	25840	Business	18900.00
0005434907062	25840	Economy	6300.00
0005434907055	25840	Economy	6300.00
0005433251168	25840	Economy	6300.00
0005434907061	25840	Economy	6300.00
0005433251273	25840	Economy	6300.00
0005434907067	25840	Economy	6300.00
0005434907078	25840	Economy	6300.00
0005433251099	25840	Economy	6300.00
0005434907079	25840	Economy	6900.00
0005434907077	25840	Economy	6900.00
0005434907085	25840	Economy	6900.00
0005434907094	25840	Economy	6900.00
0005434907054	25840	Economy	6900.00
0005434907070	25840	Economy	6300.00
0005434907066	25840	Economy	6300.00
0005433251177	25840	Economy	6300.00
0005434907075	25840	Economy	6300.00
0005433251178	25840	Economy	6300.00
0005434907072	25840	Economy	6300.00
0005434907080	25840	Economy	6300.00
0005433251207	25840	Economy	6300.00
0005433251101	25840	Economy	6300.00
0005434907071	25840	Economy	6300.00
0005434907093	25840	Economy	6300.00
0005434907090	25840	Economy	6300.00
0005433251017	25840	Economy	6300.00
0005433251137	25840	Economy	6300.00
0005434907102	25840	Economy	6300.00
0005433250946	25840	Economy	6300.00
0005434907092	25840	Economy	6300.00
0005433251147	25840	Economy	6300.00
0005434907087	25840	Economy	6300.00
0005433251112	25840	Economy	6300.00
0005433251092	25840	Economy	6300.00
0005434907057	25840	Economy	6300.00
0005434907073	25840	Economy	6300.00
0005434907099	25840	Economy	6300.00
0005434907091	25840	Economy	6300.00
0005434907084	25840	Economy	6300.00
0005433250947	25840	Economy	6300.00
0005434907056	25840	Economy	6300.00
0005433251035	25840	Economy	6300.00
0005434907065	25840	Economy	6300.00
0005434907076	25840	Economy	6300.00
0005433251203	25840	Economy	6300.00
0005433251100	25840	Economy	6300.00
0005433251106	25840	Economy	6300.00
0005433250945	25840	Economy	6300.00
0005433251121	25840	Economy	6300.00
0005434907089	25840	Economy	6300.00
0005433251196	25840	Economy	6300.00
0005434907064	25840	Economy	6300.00
0005434907069	25840	Economy	6300.00
0005434907083	25840	Economy	6300.00
0005434907097	25840	Economy	6300.00
0005434907068	25840	Economy	6300.00
0005433251195	25840	Economy	6300.00
0005434907100	25840	Economy	6300.00
0005434907063	25840	Economy	6300.00
0005434907060	25840	Economy	6300.00
0005434907058	25840	Economy	6300.00
0005433251113	25840	Economy	6300.00
0005434907059	25840	Economy	6300.00
0005434907081	25840	Economy	6300.00
0005434907095	25840	Economy	6300.00
0005434907088	25840	Economy	6300.00
0005433251046	25840	Economy	6300.00
0005433251169	25840	Economy	6300.00
0005434907086	25840	Economy	6300.00
0005432609713	22482	Economy	16400.00
0005432607542	22482	Economy	16400.00
0005432607548	22482	Economy	16400.00
0005435842318	22482	Economy	14900.00
0005432607547	22482	Economy	14900.00
0005432609716	22482	Economy	14900.00
0005432607537	22482	Economy	14900.00
0005432607552	22482	Economy	14900.00
0005432609711	22482	Economy	14900.00
0005432607551	22482	Economy	14900.00
0005432609704	22482	Economy	14900.00
0005432607550	22482	Economy	14900.00
0005432607543	22482	Economy	14900.00
0005432609714	22482	Economy	14900.00
0005432607546	22482	Economy	14900.00
0005432607549	22482	Economy	14900.00
0005432607535	22482	Economy	14900.00
0005432609703	22482	Economy	14900.00
0005432607540	22482	Economy	14900.00
0005432609712	22482	Economy	14900.00
0005432607536	22482	Economy	14900.00
0005432609707	22482	Economy	14900.00
0005432609706	22482	Economy	14900.00
0005432607541	22482	Economy	14900.00
0005432609710	22482	Economy	14900.00
0005435842314	22482	Economy	14900.00
0005432609715	22482	Economy	14900.00
0005432609708	22482	Economy	14900.00
0005432607545	22482	Economy	14900.00
0005432609705	22482	Economy	14900.00
0005435841463	22482	Economy	14900.00
0005432609709	22482	Economy	14900.00
0005432607539	22482	Economy	14900.00
0005432607544	22482	Economy	14900.00
0005435842319	22482	Economy	14900.00
0005432607538	22482	Economy	14900.00
0005432609702	22482	Economy	14900.00
0005432609669	31722	Economy	16400.00
0005432609681	31722	Economy	16400.00
0005432609677	31722	Economy	14900.00
0005432609661	31722	Economy	14900.00
0005432613791	31722	Economy	14900.00
0005432613824	31722	Economy	14900.00
0005432609674	31722	Economy	14900.00
0005432613802	31722	Economy	14900.00
0005432613811	31722	Economy	14900.00
0005432609675	31722	Economy	14900.00
0005432609660	31722	Economy	14900.00
0005432613806	31722	Economy	14900.00
0005432613793	31722	Economy	14900.00
0005432609676	31722	Economy	14900.00
0005432613792	31722	Economy	14900.00
0005432609670	31722	Economy	14900.00
0005432613809	31722	Economy	14900.00
0005432613810	31722	Economy	14900.00
0005432613801	31722	Economy	14900.00
0005432613814	31722	Economy	14900.00
0005432613803	31722	Economy	14900.00
0005432613831	31722	Economy	14900.00
0005432613805	31722	Economy	14900.00
0005432613815	31722	Economy	14900.00
0005432613804	31722	Economy	14900.00
0005432609692	31722	Economy	14900.00
0005432613813	31722	Economy	14900.00
0005432613832	31722	Economy	14900.00
0005432609671	31722	Economy	14900.00
0005435841093	31722	Economy	14900.00
0005432609659	31722	Economy	14900.00
0005432613798	31722	Economy	14900.00
0005432613790	31722	Economy	14900.00
0005432609658	31722	Economy	14900.00
0005432613812	31722	Economy	14900.00
0005433008475	14207	Business	52300.00
0005433008490	14207	Business	52300.00
0005433008487	14207	Business	52300.00
0005433008517	14207	Business	52300.00
0005433008507	14207	Business	52300.00
0005433810492	14207	Business	52300.00
0005433008480	14207	Business	52300.00
0005433008489	14207	Economy	17400.00
0005433008481	14207	Economy	17400.00
0005433008502	14207	Economy	17400.00
0005433008488	14207	Economy	17400.00
0005433008516	14207	Economy	17400.00
0005433008495	14207	Economy	19200.00
0005433008497	14207	Economy	19200.00
0005433008494	14207	Economy	17400.00
0005433008474	14207	Economy	17400.00
0005433008483	14207	Economy	17400.00
0005433008505	14207	Economy	17400.00
0005433008514	14207	Economy	17400.00
0005433008478	14207	Economy	17400.00
0005433008477	14207	Economy	17400.00
0005433008492	14207	Economy	17400.00
0005433008472	14207	Economy	17400.00
0005433008515	14207	Economy	17400.00
0005433008485	14207	Economy	17400.00
0005433008479	14207	Economy	17400.00
0005433008509	14207	Economy	17400.00
0005433008501	14207	Economy	17400.00
0005433008493	14207	Economy	17400.00
0005433008500	14207	Economy	17400.00
0005433008503	14207	Economy	17400.00
0005433008486	14207	Economy	17400.00
0005433008512	14207	Economy	17400.00
0005433008484	14207	Economy	17400.00
0005433008498	14207	Economy	17400.00
0005433008510	14207	Economy	17400.00
0005433810491	14207	Economy	17400.00
0005433008504	14207	Economy	17400.00
0005433008473	14207	Economy	17400.00
0005433008496	14207	Economy	17400.00
0005433008506	14207	Economy	17400.00
0005433008482	14207	Economy	17400.00
0005433008508	14207	Economy	17400.00
0005433008476	14207	Economy	17400.00
0005433008513	14207	Economy	17400.00
0005433008491	14207	Economy	17400.00
0005433008499	14207	Economy	17400.00
0005433008511	14207	Economy	17400.00
0005433810527	22846	Business	52300.00
0005433008127	22846	Business	52300.00
0005433008051	22846	Business	52300.00
0005433810526	22846	Business	52300.00
0005433008083	22846	Business	52300.00
0005433810525	22846	Business	52300.00
0005433008057	22846	Business	52300.00
0005433007957	22846	Economy	17400.00
0005433008059	22846	Economy	17400.00
0005433008012	22846	Economy	17400.00
0005433008040	22846	Economy	17400.00
0005433007942	22846	Economy	17400.00
0005433008058	22846	Economy	19200.00
0005433008189	22846	Economy	19200.00
0005433008026	22846	Economy	17400.00
0005433007926	22846	Economy	17400.00
0005433008067	22846	Economy	17400.00
0005433008222	22846	Economy	17400.00
0005433008052	22846	Economy	17400.00
0005433008137	22846	Economy	17400.00
0005433008179	22846	Economy	17400.00
0005433008082	22846	Economy	17400.00
0005433008064	22846	Economy	17400.00
0005433008093	22846	Economy	17400.00
0005433008070	22846	Economy	17400.00
0005433007922	22846	Economy	17400.00
0005433008086	22846	Economy	17400.00
0005433008177	22846	Economy	17400.00
0005433008066	22846	Economy	17400.00
0005433008007	22846	Economy	17400.00
0005433008010	22846	Economy	17400.00
0005433008190	22846	Economy	17400.00
0005433007941	22846	Economy	17400.00
0005433008090	22846	Economy	17400.00
0005433008180	22846	Economy	17400.00
0005433810524	22846	Economy	17400.00
0005433008020	22846	Economy	17400.00
0005433008065	22846	Economy	17400.00
0005433007984	22846	Economy	17400.00
0005433007927	22846	Economy	17400.00
0005433007902	22846	Economy	17400.00
0005433008191	22846	Economy	17400.00
0005433008011	22846	Economy	17400.00
0005433007903	22846	Economy	17400.00
0005433007955	22846	Economy	17400.00
0005433008167	22846	Economy	17400.00
0005433007993	22846	Economy	17400.00
0005433008105	22846	Economy	17400.00
0005433007996	22846	Economy	17400.00
0005433008075	22846	Economy	17400.00
0005433008084	22846	Economy	17400.00
0005433008254	22846	Economy	17400.00
0005433810528	22846	Economy	17400.00
0005433007956	22846	Economy	17400.00
0005434925248	14932	Business	22900.00
0005434925466	14932	Business	22900.00
0005434925391	14932	Economy	7600.00
0005434925370	14932	Economy	7600.00
0005434925403	14932	Economy	7600.00
0005434925424	14932	Economy	7600.00
0005434925461	14932	Economy	7600.00
0005434925452	14932	Economy	7600.00
0005434925273	14932	Economy	7600.00
0005434925451	14932	Economy	7600.00
0005434925421	14932	Economy	7600.00
0005434925299	14932	Economy	7600.00
0005434925455	14932	Economy	7600.00
0005434925444	14932	Economy	7600.00
0005434925344	14932	Economy	7600.00
0005434925369	14932	Economy	7600.00
0005434925433	14932	Economy	7600.00
0005434925418	14932	Economy	7600.00
0005434925462	14932	Economy	7600.00
0005434925449	14932	Economy	7600.00
0005434925425	14932	Economy	7600.00
0005434925453	14932	Economy	7600.00
0005434925300	14932	Economy	7600.00
0005434925383	14932	Economy	7600.00
0005434925293	14932	Economy	7600.00
0005434925388	14932	Economy	7600.00
0005434925423	14932	Economy	7600.00
0005434925402	14932	Economy	7600.00
0005434925371	14932	Economy	7600.00
0005434925467	14932	Economy	7600.00
0005434925443	14932	Economy	7600.00
0005434925264	14932	Economy	7600.00
0005434925679	20505	Business	22900.00
0005434925697	20505	Business	22900.00
0005434925678	20505	Business	22900.00
0005434925702	20505	Business	22900.00
0005434925708	20505	Business	22900.00
0005434925703	20505	Economy	7600.00
0005434925698	20505	Economy	7600.00
0005434925701	20505	Economy	7600.00
0005434925713	20505	Economy	8400.00
0005434925690	20505	Economy	8400.00
0005434925716	20505	Economy	7600.00
0005434925689	20505	Economy	7600.00
0005434925700	20505	Economy	7600.00
0005434925714	20505	Economy	7600.00
0005434925687	20505	Economy	7600.00
0005434925680	20505	Economy	7600.00
0005434925709	20505	Economy	7600.00
0005434925693	20505	Economy	7600.00
0005434925705	20505	Economy	7600.00
0005434925696	20505	Economy	7600.00
0005434925694	20505	Economy	7600.00
0005434925682	20505	Economy	7600.00
0005434925711	20505	Economy	7600.00
0005434925692	20505	Economy	7600.00
0005434925715	20505	Economy	7600.00
0005434925710	20505	Economy	7600.00
0005434925688	20505	Economy	7600.00
0005434925691	20505	Economy	7600.00
0005434925686	20505	Economy	7600.00
0005434925712	20505	Economy	7600.00
0005434925681	20505	Economy	7600.00
0005434925684	20505	Economy	7600.00
0005434925707	20505	Economy	7600.00
0005434925685	20505	Economy	7600.00
0005434925699	20505	Economy	7600.00
0005434925683	20505	Economy	7600.00
0005434925704	20505	Economy	7600.00
0005434925706	20505	Economy	7600.00
0005434925695	20505	Economy	7600.00
0005435998971	15789	Economy	8900.00
0005435487776	15789	Economy	8900.00
0005435487773	15789	Economy	8900.00
0005435487785	15789	Economy	8900.00
0005435487768	15789	Economy	8100.00
0005435999047	15789	Economy	8100.00
0005435487783	15789	Economy	8100.00
0005435999048	15789	Economy	8100.00
0005435999018	15789	Economy	8100.00
0005435999052	15789	Economy	8100.00
0005435487784	15789	Economy	8100.00
0005435999021	15789	Economy	8100.00
0005435999053	15789	Economy	8100.00
0005435487774	15789	Economy	8100.00
0005435999083	15789	Economy	8100.00
0005435487766	15789	Economy	8100.00
0005435999088	15789	Economy	8100.00
0005435999036	15789	Economy	8100.00
0005435999066	15789	Economy	8100.00
0005435999063	15789	Economy	8100.00
0005435999067	15789	Economy	8100.00
0005435999059	15789	Economy	8100.00
0005435999077	15789	Economy	8100.00
0005435487765	15789	Economy	8100.00
0005435999050	15789	Economy	8100.00
0005435999001	15789	Economy	8100.00
0005435999049	15789	Economy	8100.00
0005435487770	15789	Economy	8100.00
0005435998988	15789	Economy	8100.00
0005435487779	15789	Economy	8100.00
0005435487782	15789	Economy	8100.00
0005435487764	15789	Economy	8100.00
0005435999070	15789	Economy	8100.00
0005435487769	15789	Economy	8100.00
0005435999058	15789	Economy	8100.00
0005435999064	15789	Economy	8100.00
0005435487778	15789	Economy	8100.00
0005435999022	15789	Economy	8100.00
0005435487781	15789	Economy	8100.00
0005435487777	15789	Economy	8100.00
0005435487780	15789	Economy	8100.00
0005435487771	15789	Economy	8100.00
0005435487772	15789	Economy	8100.00
0005435998972	15789	Economy	8100.00
0005435999019	15789	Economy	8100.00
0005435999020	15789	Economy	8100.00
0005435487767	15789	Economy	8100.00
0005435487775	15789	Economy	8100.00
0005435487517	19670	Economy	8900.00
0005435487551	19670	Economy	8900.00
0005435487530	19670	Economy	8900.00
0005435487519	19670	Economy	8100.00
0005435487567	19670	Economy	8100.00
0005435487518	19670	Economy	8100.00
0005435999184	19670	Economy	8100.00
0005435999190	19670	Economy	8100.00
0005435999186	19670	Economy	8100.00
0005435487614	19670	Economy	8100.00
0005435487638	19670	Economy	8100.00
0005435487607	19670	Economy	8100.00
0005435487474	19670	Economy	8100.00
0005435487481	19670	Economy	8100.00
0005435487613	19670	Economy	8100.00
0005435999194	19670	Economy	8100.00
0005435487608	19670	Economy	8100.00
0005435487562	19670	Economy	8100.00
0005435999183	19670	Economy	8100.00
0005435999188	19670	Economy	8100.00
0005435999193	19670	Economy	8100.00
0005435487595	19670	Economy	8100.00
0005435999187	19670	Economy	8100.00
0005435999191	19670	Economy	8100.00
0005435999192	19670	Economy	8100.00
0005435999189	19670	Economy	8100.00
0005435999182	19670	Economy	8100.00
0005435487553	19670	Economy	8100.00
0005435999195	19670	Economy	8100.00
0005435487566	19670	Economy	8100.00
0005435487473	19670	Economy	8100.00
0005435487583	19670	Economy	8100.00
0005435999185	19670	Economy	8100.00
0005435487596	19670	Economy	8100.00
0005435487606	19670	Economy	8100.00
0005435839367	5979	Business	199300.00
0005435839380	5979	Business	199300.00
0005435839371	5979	Business	199300.00
0005435472593	5979	Business	199300.00
0005435472620	5979	Business	199300.00
0005432537026	5979	Business	199300.00
0005435472607	5979	Business	199300.00
0005435839381	5979	Business	199300.00
0005432537027	5979	Business	199300.00
0005435839365	5979	Business	199300.00
0005435839363	5979	Business	199300.00
0005435839370	5979	Economy	66400.00
0005435839383	5979	Economy	66400.00
0005435472576	5979	Economy	66400.00
0005432658587	5979	Economy	66400.00
0005432142244	5979	Economy	66400.00
0005432660813	5979	Economy	66400.00
0005435839377	5979	Economy	66400.00
0005435839387	5979	Economy	73100.00
0005435472614	5979	Economy	73100.00
0005432658585	5979	Economy	73100.00
0005432660814	5979	Economy	66400.00
0005432142243	5979	Economy	66400.00
0005435839388	5979	Economy	66400.00
0005435472609	5979	Economy	66400.00
0005432142242	5979	Economy	66400.00
0005435839385	5979	Economy	66400.00
0005435472650	5979	Economy	66400.00
0005435839364	5979	Economy	66400.00
0005435839369	5979	Economy	66400.00
0005432659701	5979	Economy	66400.00
0005435472656	5979	Economy	66400.00
0005435839389	5979	Economy	66400.00
0005432537025	5979	Economy	66400.00
0005435472643	5979	Economy	66400.00
0005435839372	5979	Economy	66400.00
0005435839373	5979	Economy	66400.00
0005435472615	5979	Economy	66400.00
0005435839386	5979	Economy	66400.00
0005435839366	5979	Economy	66400.00
0005435839368	5979	Economy	66400.00
0005435839382	5979	Economy	66400.00
0005432659702	5979	Economy	66400.00
0005435839374	5979	Economy	66400.00
0005435839362	5979	Economy	66400.00
0005435839361	5979	Economy	66400.00
0005435472577	5979	Economy	66400.00
0005432660812	5979	Economy	66400.00
0005435839384	5979	Economy	66400.00
0005435472649	5979	Economy	66400.00
0005435472644	5979	Economy	66400.00
0005435839379	5979	Economy	66400.00
0005435472608	5979	Economy	66400.00
0005435839378	5979	Economy	66400.00
0005435472598	5979	Economy	66400.00
0005435839376	5979	Economy	66400.00
0005435472642	5979	Economy	66400.00
0005435839375	5979	Economy	66400.00
0005432658586	5979	Economy	66400.00
0005435472748	18066	Business	199300.00
0005435839216	18066	Business	199300.00
0005435839164	18066	Business	199300.00
0005435472764	18066	Business	199300.00
0005435839162	18066	Business	199300.00
0005435839182	18066	Business	199300.00
0005432667428	18066	Economy	66400.00
0005435839066	18066	Economy	66400.00
0005435472759	18066	Economy	66400.00
0005435472763	18066	Economy	66400.00
0005435839142	18066	Economy	66400.00
0005435472758	18066	Economy	66400.00
0005432660788	18066	Economy	66400.00
0005435472753	18066	Economy	73100.00
0005435472756	18066	Economy	66400.00
0005435839052	18066	Economy	66400.00
0005435472755	18066	Economy	66400.00
0005435839082	18066	Economy	66400.00
0005435839255	18066	Economy	66400.00
0005435839004	18066	Economy	66400.00
0005435839151	18066	Economy	66400.00
0005435839005	18066	Economy	66400.00
0005435839133	18066	Economy	66400.00
0005432537053	18066	Economy	66400.00
0005432660789	18066	Economy	66400.00
0005435472760	18066	Economy	66400.00
0005435839062	18066	Economy	66400.00
0005432660790	18066	Economy	66400.00
0005435839143	18066	Economy	66400.00
0005435839063	18066	Economy	66400.00
0005435472761	18066	Economy	66400.00
0005435472762	18066	Economy	66400.00
0005435839148	18066	Economy	66400.00
0005435839217	18066	Economy	66400.00
0005435839144	18066	Economy	66400.00
0005435839163	18066	Economy	66400.00
0005435472754	18066	Economy	66400.00
0005435839190	18066	Economy	66400.00
0005435472751	18066	Economy	66400.00
0005435472757	18066	Economy	66400.00
0005435839147	18066	Economy	66400.00
0005435839083	18066	Economy	66400.00
0005435839169	18066	Economy	66400.00
0005435839127	18066	Economy	66400.00
0005432667427	18066	Economy	66400.00
0005435839081	18066	Economy	66400.00
0005435839170	18066	Economy	66400.00
0005432667426	18066	Economy	66400.00
0005435839065	18066	Economy	66400.00
0005435839145	18066	Economy	66400.00
0005435472749	18066	Economy	66400.00
0005435839161	18066	Economy	66400.00
0005435472750	18066	Economy	66400.00
0005435472752	18066	Economy	66400.00
0005433462733	17266	Business	146400.00
0005433462735	17266	Business	146400.00
0005433463884	17266	Business	146400.00
0005433462731	17266	Economy	53700.00
0005433462736	17266	Economy	48800.00
0005433463894	17266	Economy	48800.00
0005433463882	17266	Economy	48800.00
0005433463892	17266	Economy	48800.00
0005433463885	17266	Economy	48800.00
0005433463888	17266	Economy	48800.00
0005433462725	17266	Economy	48800.00
0005433463891	17266	Economy	48800.00
0005433462739	17266	Economy	48800.00
0005433462734	17266	Economy	48800.00
0005433462729	17266	Economy	48800.00
0005433462730	17266	Economy	48800.00
0005433463881	17266	Economy	48800.00
0005433463887	17266	Economy	48800.00
0005433463893	17266	Economy	48800.00
0005433463883	17266	Economy	48800.00
0005433462732	17266	Economy	48800.00
0005433463889	17266	Economy	48800.00
0005433462737	17266	Economy	48800.00
0005433462741	17266	Economy	48800.00
0005433463890	17266	Economy	48800.00
0005433463886	17266	Economy	48800.00
0005433462738	17266	Economy	48800.00
0005433462727	17266	Economy	48800.00
0005433462740	17266	Economy	48800.00
0005433462728	17266	Economy	48800.00
0005433463880	17266	Economy	48800.00
0005433462726	17266	Economy	48800.00
0005433463879	17266	Economy	48800.00
0005433284780	23046	Business	15700.00
0005433284947	23046	Economy	5200.00
0005433284946	23046	Economy	5200.00
0005433285030	23046	Economy	5200.00
0005435103905	23046	Economy	5200.00
0005433284944	23046	Economy	5200.00
0005433284923	23046	Economy	5200.00
0005433285015	23046	Economy	5200.00
0005435103904	23046	Economy	5700.00
0005433284967	23046	Economy	5700.00
0005433285062	23046	Economy	5200.00
0005433285035	23046	Economy	5200.00
0005433284958	23046	Economy	5200.00
0005433285003	23046	Economy	5200.00
0005433285036	23046	Economy	5200.00
0005435103908	23046	Economy	5200.00
0005433284961	23046	Economy	5200.00
0005435103907	23046	Economy	5200.00
0005433284950	23046	Economy	5200.00
0005433284866	23046	Economy	5200.00
0005433284914	23046	Economy	5200.00
0005433285014	23046	Economy	5200.00
0005435103906	23046	Economy	5200.00
0005433284945	23046	Economy	5200.00
0005433284925	23046	Economy	5200.00
0005433285060	23046	Economy	5200.00
0005433284781	23046	Economy	5200.00
0005433284966	23046	Economy	5200.00
0005433284924	23046	Economy	5200.00
0005433284930	23046	Economy	5200.00
0005435103903	23046	Economy	5200.00
0005433284933	23046	Economy	5200.00
0005433284949	23046	Economy	5200.00
0005435103902	23046	Economy	5200.00
0005433285061	23046	Economy	5200.00
0005433285223	32063	Business	15700.00
0005435103822	32063	Business	15700.00
0005433285230	32063	Economy	5200.00
0005433285226	32063	Economy	5200.00
0005435103798	32063	Economy	5200.00
0005433285218	32063	Economy	5200.00
0005433285221	32063	Economy	5200.00
0005433285209	32063	Economy	5200.00
0005433285204	32063	Economy	5200.00
0005433285215	32063	Economy	5200.00
0005435103801	32063	Economy	5200.00
0005433285216	32063	Economy	5200.00
0005433285229	32063	Economy	5200.00
0005433285231	32063	Economy	5700.00
0005433285222	32063	Economy	5700.00
0005433285225	32063	Economy	5200.00
0005433285212	32063	Economy	5200.00
0005433285203	32063	Economy	5200.00
0005433285205	32063	Economy	5200.00
0005433285206	32063	Economy	5200.00
0005433285224	32063	Economy	5200.00
0005433285211	32063	Economy	5200.00
0005433285219	32063	Economy	5200.00
0005433285217	32063	Economy	5200.00
0005435103805	32063	Economy	5200.00
0005433285227	32063	Economy	5200.00
0005435103821	32063	Economy	5200.00
0005435103824	32063	Economy	5200.00
0005433285213	32063	Economy	5200.00
0005433285202	32063	Economy	5200.00
0005433285207	32063	Economy	5200.00
0005433285210	32063	Economy	5200.00
0005435103804	32063	Economy	5200.00
0005433285199	32063	Economy	5200.00
0005435103825	32063	Economy	5200.00
0005433285208	32063	Economy	5200.00
0005433285214	32063	Economy	5200.00
0005433285201	32063	Economy	5200.00
0005433285220	32063	Economy	5200.00
0005433285228	32063	Economy	5200.00
0005433285200	32063	Economy	5200.00
0005433656665	30628	Business	42100.00
0005432533262	30628	Business	42100.00
0005435213430	30628	Business	42100.00
0005435213411	30628	Business	42100.00
0005432527033	30628	Business	42100.00
0005435213373	30628	Business	42100.00
0005432525772	30628	Business	42100.00
0005435725592	30628	Business	42100.00
0005432526649	30628	Business	42100.00
0005432526685	30628	Business	42100.00
0005432526074	30628	Business	42100.00
0005432526950	30628	Business	42100.00
0005432526546	30628	Business	42100.00
0005432526242	30628	Business	42100.00
0005434066591	30628	Business	42100.00
0005432525876	30628	Business	42100.00
0005432526583	30628	Business	42100.00
0005432526655	30628	Business	42100.00
0005432526431	30628	Business	42100.00
0005432526751	30628	Business	42100.00
0005432526211	30628	Business	42100.00
0005432428895	30628	Business	42100.00
0005432211486	30628	Business	42100.00
0005432526053	30628	Comfort	23900.00
0005435213422	30628	Comfort	23900.00
0005434066618	30628	Comfort	23900.00
0005434066540	30628	Comfort	23900.00
0005435213369	30628	Comfort	23900.00
0005432526045	30628	Comfort	23900.00
0005434066982	30628	Comfort	23900.00
0005432526534	30628	Comfort	23900.00
0005435213421	30628	Comfort	23900.00
0005435213418	30628	Comfort	23900.00
0005432526435	30628	Comfort	23900.00
0005435213385	30628	Comfort	23900.00
0005432428888	30628	Comfort	23900.00
0005434066944	30628	Comfort	23900.00
0005435213396	30628	Comfort	23900.00
0005432525998	30628	Comfort	23900.00
0005434066661	30628	Comfort	23900.00
0005432526803	30628	Comfort	23900.00
0005434066874	30628	Comfort	23900.00
0005432526793	30628	Comfort	23900.00
0005434066834	30628	Comfort	23900.00
0005434066942	30628	Comfort	23900.00
0005435283408	30628	Comfort	23900.00
0005432211487	30628	Comfort	23900.00
0005434066500	30628	Comfort	23900.00
0005432526471	30628	Comfort	23900.00
0005432526923	30628	Comfort	23900.00
0005434066643	30628	Comfort	23900.00
0005434066841	30628	Comfort	23900.00
0005435213432	30628	Comfort	23900.00
0005432428889	30628	Comfort	23900.00
0005435213427	30628	Comfort	23900.00
0005432526715	30628	Comfort	23900.00
0005435213402	30628	Comfort	23900.00
0005435213372	30628	Economy	14000.00
0005432535787	30628	Economy	14000.00
0005432526133	30628	Economy	14000.00
0005435213391	30628	Economy	14000.00
0005434066975	30628	Economy	14000.00
0005432527242	30628	Economy	14000.00
0005432526790	30628	Economy	14000.00
0005435213383	30628	Economy	14000.00
0005434066727	30628	Economy	14000.00
0005432526475	30628	Economy	14000.00
0005432526160	30628	Economy	14000.00
0005434066479	30628	Economy	14000.00
0005432526412	30628	Economy	14000.00
0005435213413	30628	Economy	14000.00
0005432526210	30628	Economy	14000.00
0005432525983	30628	Economy	14000.00
0005432526310	30628	Economy	14000.00
0005435213420	30628	Economy	14000.00
0005432526326	30628	Economy	14000.00
0005434066666	30628	Economy	14000.00
0005434066924	30628	Economy	14000.00
0005435213368	30628	Economy	14000.00
0005432527288	30628	Economy	14000.00
0005432537030	30628	Economy	14000.00
0005435213415	30628	Economy	14000.00
0005434066578	30628	Economy	14000.00
0005432526548	30628	Economy	14000.00
0005435213436	30628	Economy	14000.00
0005435213410	30628	Economy	14000.00
0005434066457	30628	Economy	14000.00
0005432526330	30628	Economy	14000.00
0005435213425	30628	Economy	14000.00
0005434066943	30628	Economy	14000.00
0005432526840	30628	Economy	14000.00
0005435213400	30628	Economy	14000.00
0005434066765	30628	Economy	14000.00
0005435213433	30628	Economy	14000.00
0005435630962	30628	Economy	14000.00
0005432526656	30628	Economy	14000.00
0005434066754	30628	Economy	14000.00
0005434066555	30628	Economy	14000.00
0005434066511	30628	Economy	14000.00
0005432526527	30628	Economy	14000.00
0005435213387	30628	Economy	14000.00
0005432526634	30628	Economy	14000.00
0005434066719	30628	Economy	14000.00
0005435213412	30628	Economy	14000.00
0005435213416	30628	Economy	14000.00
0005432526635	30628	Economy	14000.00
0005432526533	30628	Economy	14000.00
0005432526735	30628	Economy	14000.00
0005435213401	30628	Economy	14000.00
0005432159850	30628	Economy	15400.00
0005432535760	30628	Economy	14000.00
0005432526269	30628	Economy	15400.00
0005432527054	30628	Economy	14000.00
0005434066590	30628	Economy	15400.00
0005432526516	30628	Economy	14000.00
0005435213408	30628	Economy	14000.00
0005435213395	30628	Economy	15400.00
0005432526479	30628	Economy	15400.00
0005434066522	30628	Economy	15400.00
0005432526322	30628	Economy	14000.00
0005435213379	30628	Economy	14000.00
0005432526932	30628	Economy	14000.00
0005435213404	30628	Economy	14000.00
0005432211488	30628	Economy	14000.00
0005435213394	30628	Economy	14000.00
0005432527218	30628	Economy	14000.00
0005432526562	30628	Economy	14000.00
0005435213438	30628	Economy	14000.00
0005434066723	30628	Economy	14000.00
0005432526046	30628	Economy	14000.00
0005434066561	30628	Economy	14000.00
0005432526492	30628	Economy	14000.00
0005432211482	30628	Economy	14000.00
0005435213389	30628	Economy	14000.00
0005434066560	30628	Economy	14000.00
0005435213382	30628	Economy	14000.00
0005432535775	30628	Economy	14000.00
0005435213388	30628	Economy	14000.00
0005435213429	30628	Economy	14000.00
0005432533259	30628	Economy	14000.00
0005434066763	30628	Economy	14000.00
0005432526722	30628	Economy	14000.00
0005432526429	30628	Economy	14000.00
0005432526272	30628	Economy	14000.00
0005432526671	30628	Economy	14000.00
0005435213370	30628	Economy	14000.00
0005434066851	30628	Economy	14000.00
0005432428899	30628	Economy	14000.00
0005435213390	30628	Economy	14000.00
0005432526993	30628	Economy	14000.00
0005435213384	30628	Economy	14000.00
0005432527043	30628	Economy	14000.00
0005435213380	30628	Economy	14000.00
0005432526949	30628	Economy	14000.00
0005435630961	30628	Economy	14000.00
0005434066456	30628	Economy	14000.00
0005434066875	30628	Economy	14000.00
0005435725591	30628	Economy	14000.00
0005432211481	30628	Economy	14000.00
0005432535761	30628	Economy	14000.00
0005432526517	30628	Economy	14000.00
0005432526704	30628	Economy	14000.00
0005432526419	30628	Economy	14000.00
0005434066649	30628	Economy	14000.00
0005434066726	30628	Economy	14000.00
0005432526506	30628	Economy	14000.00
0005432526532	30628	Economy	14000.00
0005435213398	30628	Economy	14000.00
0005435213409	30628	Economy	14000.00
0005434066644	30628	Economy	14000.00
0005434066667	30628	Economy	14000.00
0005433656663	30628	Economy	14000.00
0005432526731	30628	Economy	14000.00
0005435213419	30628	Economy	14000.00
0005435213424	30628	Economy	14000.00
0005434066995	30628	Economy	14000.00
0005435213393	30628	Economy	14000.00
0005432526705	30628	Economy	14000.00
0005434066588	30628	Economy	14000.00
0005434066604	30628	Economy	14000.00
0005432526346	30628	Economy	14000.00
0005434066835	30628	Economy	14000.00
0005432527053	30628	Economy	14000.00
0005432525773	30628	Economy	14000.00
0005434066673	30628	Economy	14000.00
0005435213426	30628	Economy	14000.00
0005432527044	30628	Economy	14000.00
0005435213371	30628	Economy	14000.00
0005432526268	30628	Economy	14000.00
0005432526701	30628	Economy	14000.00
0005434066710	30628	Economy	14000.00
0005435213381	30628	Economy	14000.00
0005432526740	30628	Economy	14000.00
0005432159846	30628	Economy	14000.00
0005435213417	30628	Economy	14000.00
0005432159845	30628	Economy	14000.00
0005434066672	30628	Economy	14000.00
0005432526260	30628	Economy	14000.00
0005432527034	30628	Economy	14000.00
0005432526645	30628	Economy	14000.00
0005432211485	30628	Economy	14000.00
0005432526738	30628	Economy	14000.00
0005432527095	30628	Economy	14000.00
0005432526831	30628	Economy	14000.00
0005434066918	30628	Economy	14000.00
0005432211483	30628	Economy	14000.00
0005432526599	30628	Economy	14000.00
0005432526464	30628	Economy	14000.00
0005432526062	30628	Economy	14000.00
0005432159849	30628	Economy	14000.00
0005432526730	30628	Economy	14000.00
0005435213423	30628	Economy	14000.00
0005432526905	30628	Economy	14000.00
0005434066685	30628	Economy	15400.00
0005435213397	30628	Economy	14000.00
0005434066406	30628	Economy	15400.00
0005432525814	30628	Economy	15400.00
0005432159847	30628	Economy	15400.00
0005434066928	30628	Economy	15400.00
0005434066523	30628	Economy	14000.00
0005432527098	30628	Economy	15400.00
0005434066407	30628	Economy	14000.00
0005432428883	30628	Economy	14000.00
0005435213375	30628	Economy	14000.00
0005432527219	30628	Economy	14000.00
0005432526723	30628	Economy	14000.00
0005434066833	30628	Economy	14000.00
0005432526271	30628	Economy	14000.00
0005434066626	30628	Economy	14000.00
0005432526323	30628	Economy	14000.00
0005435213399	30628	Economy	14000.00
0005432526588	30628	Economy	14000.00
0005435213378	30628	Economy	14000.00
0005432526893	30628	Economy	14000.00
0005432526558	30628	Economy	14000.00
0005434066840	30628	Economy	14000.00
0005432525934	30628	Economy	14000.00
0005432526825	30628	Economy	14000.00
0005434066884	30628	Economy	14000.00
0005432526610	30628	Economy	14000.00
0005432526430	30628	Economy	14000.00
0005432526518	30628	Economy	14000.00
0005434066764	30628	Economy	14000.00
0005435213406	30628	Economy	14000.00
0005434066463	30628	Economy	14000.00
0005432526600	30628	Economy	14000.00
0005434066858	30628	Economy	14000.00
0005432526371	30628	Economy	14000.00
0005432527197	30628	Economy	14000.00
0005434067015	30628	Economy	14000.00
0005435213405	30628	Economy	14000.00
0005434066759	30628	Economy	14000.00
0005434066613	30628	Economy	14000.00
0005432526564	30628	Economy	14000.00
0005432159848	30628	Economy	14000.00
0005432526258	30628	Economy	14000.00
0005434066807	30628	Economy	14000.00
0005434066755	30628	Economy	14000.00
0005432533261	30628	Economy	14000.00
0005432526680	30628	Economy	14000.00
0005435630960	30628	Economy	14000.00
0005432527094	30628	Economy	14000.00
0005432526706	30628	Economy	14000.00
0005435725590	30628	Economy	14000.00
0005432526214	30628	Economy	14000.00
0005432526670	30628	Economy	14000.00
0005435213377	30628	Economy	14000.00
0005434066959	30628	Economy	14000.00
0005432526311	30628	Economy	14000.00
0005432526734	30628	Economy	14000.00
0005433656666	30628	Economy	14000.00
0005435213428	30628	Economy	14000.00
0005432526052	30628	Economy	14000.00
0005432526261	30628	Economy	14000.00
0005432535786	30628	Economy	14000.00
0005434067086	30628	Economy	14000.00
0005435213376	30628	Economy	14000.00
0005434066589	30628	Economy	14000.00
0005432525813	30628	Economy	14000.00
0005432535793	30628	Economy	14000.00
0005432526789	30628	Economy	14000.00
0005435213414	30628	Economy	14000.00
0005432527196	30628	Economy	14000.00
0005435213431	30628	Economy	14000.00
0005432526707	30628	Economy	14000.00
0005433656664	30628	Economy	14000.00
0005434066655	30628	Economy	14000.00
0005435213407	30628	Economy	14000.00
0005432527078	30628	Economy	14000.00
0005435213392	30628	Economy	14000.00
0005432526763	30628	Economy	14000.00
0005435213437	30628	Economy	14000.00
0005432526082	30628	Economy	14000.00
0005432526528	30628	Economy	14000.00
0005435213435	30628	Economy	14000.00
0005432527050	30628	Economy	14000.00
0005432526774	30628	Economy	14000.00
0005435213403	30628	Economy	14000.00
0005434066521	30628	Economy	14000.00
0005432526266	30628	Economy	14000.00
0005435213434	30628	Economy	14000.00
0005434066921	30628	Economy	14000.00
0005432526837	30628	Economy	14000.00
0005434066606	30628	Economy	14000.00
0005435213386	30628	Economy	14000.00
0005432526633	30628	Economy	14000.00
0005432526594	30628	Economy	14000.00
0005434066724	30628	Economy	14000.00
0005432211484	30628	Economy	14000.00
0005432526951	30628	Economy	14000.00
0005432527287	30628	Economy	14000.00
0005432526826	30628	Economy	14000.00
0005432526636	30628	Economy	14000.00
0005435213374	30628	Economy	14000.00
0005435652592	24859	Business	9800.00
0005433367816	24859	Business	9800.00
0005433367823	24859	Business	9800.00
0005433367796	24859	Business	9800.00
0005433367799	24859	Business	9800.00
0005435652430	24859	Business	9800.00
0005435652528	24859	Business	9800.00
0005433367801	24859	Business	9800.00
0005433367800	24859	Business	9800.00
0005435652629	24859	Business	9800.00
0005433367815	24859	Business	9800.00
0005435652542	24859	Economy	3300.00
0005433367827	24859	Economy	3300.00
0005433367805	24859	Economy	3300.00
0005435652400	24859	Economy	3300.00
0005435652489	24859	Economy	3300.00
0005435652661	24859	Economy	3300.00
0005435652396	24859	Economy	3300.00
0005433367794	24859	Economy	3600.00
0005433367831	24859	Economy	3600.00
0005435652620	24859	Economy	3600.00
0005435652539	24859	Economy	3600.00
0005435652537	24859	Economy	3300.00
0005435652443	24859	Economy	3300.00
0005435652531	24859	Economy	3300.00
0005435652533	24859	Economy	3300.00
0005433367811	24859	Economy	3300.00
0005433367826	24859	Economy	3300.00
0005435652562	24859	Economy	3300.00
0005435652493	24859	Economy	3300.00
0005435652529	24859	Economy	3300.00
0005433367828	24859	Economy	3300.00
0005433367813	24859	Economy	3300.00
0005433367817	24859	Economy	3300.00
0005435652662	24859	Economy	3300.00
0005435652607	24859	Economy	3300.00
0005433367824	24859	Economy	3300.00
0005435652484	24859	Economy	3300.00
0005435652385	24859	Economy	3300.00
0005435652630	24859	Economy	3300.00
0005435652541	24859	Economy	3300.00
0005435652447	24859	Economy	3300.00
0005435652548	24859	Economy	3300.00
0005435652555	24859	Economy	3300.00
0005433367832	24859	Economy	3300.00
0005433367814	24859	Economy	3300.00
0005433367806	24859	Economy	3300.00
0005433367802	24859	Economy	3300.00
0005433367818	24859	Economy	3300.00
0005433367795	24859	Economy	3300.00
0005433367830	24859	Economy	3300.00
0005435652459	24859	Economy	3300.00
0005433367804	24859	Economy	3300.00
0005433367822	24859	Economy	3300.00
0005433367808	24859	Economy	3300.00
0005435652471	24859	Economy	3300.00
0005433367820	24859	Economy	3300.00
0005435652448	24859	Economy	3300.00
0005435652497	24859	Economy	3300.00
0005433367819	24859	Economy	3300.00
0005433367821	24859	Economy	3300.00
0005435652563	24859	Economy	3300.00
0005435652517	24859	Economy	3300.00
0005433367807	24859	Economy	3300.00
0005433367810	24859	Economy	3300.00
0005433367829	24859	Economy	3300.00
0005435652492	24859	Economy	3300.00
0005435652360	24859	Economy	3300.00
0005433367797	24859	Economy	3300.00
0005433367809	24859	Economy	3300.00
0005435652534	24859	Economy	3300.00
0005433367798	24859	Economy	3300.00
0005435652483	24859	Economy	3300.00
0005433367812	24859	Economy	3300.00
0005435652660	24859	Economy	3300.00
0005435652458	24859	Economy	3300.00
0005435652359	24859	Economy	3300.00
0005435652554	24859	Economy	3300.00
0005433367825	24859	Economy	3300.00
0005435652516	24859	Economy	3300.00
0005435652518	24859	Economy	3300.00
0005435652395	24859	Economy	3300.00
0005433367803	24859	Economy	3300.00
0005434979733	2072	Economy	10500.00
0005434979729	2072	Economy	10500.00
0005434979718	2072	Economy	10500.00
0005434979741	2072	Economy	10500.00
0005434979726	2072	Economy	9500.00
0005434979737	2072	Economy	9500.00
0005434979716	2072	Economy	9500.00
0005435801690	2072	Economy	9500.00
0005434979724	2072	Economy	9500.00
0005434979743	2072	Economy	9500.00
0005434979734	2072	Economy	9500.00
0005434979714	2072	Economy	9500.00
0005434979720	2072	Economy	9500.00
0005434979742	2072	Economy	9500.00
0005434979722	2072	Economy	9500.00
0005434979731	2072	Economy	9500.00
0005434979715	2072	Economy	9500.00
0005434979723	2072	Economy	9500.00
0005434979721	2072	Economy	9500.00
0005434979717	2072	Economy	9500.00
0005434979739	2072	Economy	9500.00
0005434979738	2072	Economy	9500.00
0005434979736	2072	Economy	9500.00
0005434979735	2072	Economy	9500.00
0005434979740	2072	Economy	9500.00
0005434979730	2072	Economy	9500.00
0005435801688	2072	Economy	9500.00
0005435801689	2072	Economy	9500.00
0005434979725	2072	Economy	9500.00
0005434979727	2072	Economy	9500.00
0005434979728	2072	Economy	9500.00
0005434979732	2072	Economy	9500.00
0005434979719	2072	Economy	9500.00
0005434979411	23568	Economy	10500.00
0005434979438	23568	Economy	10500.00
0005434979487	23568	Economy	10500.00
0005434979354	23568	Economy	10500.00
0005434979425	23568	Economy	9500.00
0005434979484	23568	Economy	9500.00
0005434979446	23568	Economy	9500.00
0005434979275	23568	Economy	9500.00
0005435801672	23568	Economy	9500.00
0005434979417	23568	Economy	9500.00
0005434979379	23568	Economy	9500.00
0005434979412	23568	Economy	9500.00
0005434979270	23568	Economy	9500.00
0005434979418	23568	Economy	9500.00
0005434979317	23568	Economy	9500.00
0005434979353	23568	Economy	9500.00
0005435801673	23568	Economy	9500.00
0005434979303	23568	Economy	9500.00
0005434979432	23568	Economy	9500.00
0005434979375	23568	Economy	9500.00
0005434979343	23568	Economy	9500.00
0005434979327	23568	Economy	9500.00
0005434979392	23568	Economy	9500.00
0005435801658	23568	Economy	9500.00
0005434979483	23568	Economy	9500.00
0005434979344	23568	Economy	9500.00
0005434979424	23568	Economy	9500.00
0005434979445	23568	Economy	9500.00
0005434979347	23568	Economy	9500.00
0005434979482	23568	Economy	9500.00
0005434979274	23568	Economy	9500.00
0005434979397	23568	Economy	9500.00
0005434979378	23568	Economy	9500.00
0005434979281	23568	Economy	9500.00
0005434979433	23568	Economy	9500.00
0005435801659	23568	Economy	9500.00
0005434979437	23568	Economy	9500.00
0005434952525	2557	Economy	5300.00
0005434952524	2557	Economy	5300.00
0005434952522	2557	Economy	5300.00
0005434952523	2557	Economy	5300.00
0005434952526	2557	Economy	5300.00
0005433256402	2558	Economy	5300.00
0005433256409	2558	Economy	5300.00
0005433256408	2558	Economy	5300.00
0005433256416	28197	Economy	5300.00
0005434952480	28197	Economy	5300.00
0005433256417	28197	Economy	5300.00
0005434952494	28197	Economy	5300.00
0005434952493	28197	Economy	5300.00
0005433112370	19772	Economy	8700.00
0005433112369	19772	Economy	8700.00
0005433111502	19772	Economy	8700.00
0005434137402	11943	Business	9700.00
0005434137438	11943	Business	9700.00
0005434137181	11943	Business	9700.00
0005434137526	11943	Business	9700.00
0005434137392	11943	Business	9700.00
0005434137059	11943	Business	9700.00
0005434137537	11943	Business	9700.00
0005434137185	11943	Business	9700.00
0005434137177	11943	Economy	3200.00
0005434137529	11943	Economy	3200.00
0005434137466	11943	Economy	3200.00
0005434137227	11943	Economy	3200.00
0005434137351	11943	Economy	3200.00
0005434137287	11943	Economy	3200.00
0005434137005	11943	Economy	3200.00
0005434137256	11943	Economy	3200.00
0005434137239	11943	Economy	3500.00
0005434137152	11943	Economy	3500.00
0005434137597	11943	Economy	3500.00
0005434136969	11943	Economy	3500.00
0005434137354	11943	Economy	3200.00
0005434137579	11943	Economy	3200.00
0005434137197	11943	Economy	3200.00
0005434137151	11943	Economy	3200.00
0005434137118	11943	Economy	3200.00
0005434137350	11943	Economy	3200.00
0005434137233	11943	Economy	3200.00
0005434137472	11943	Economy	3200.00
0005434137439	11943	Economy	3200.00
0005434137353	11943	Economy	3200.00
0005434137403	11943	Economy	3200.00
0005434136970	11943	Economy	3200.00
0005434137408	11943	Economy	3200.00
0005434137346	11943	Economy	3200.00
0005434137347	11943	Economy	3200.00
0005434137178	11943	Economy	3200.00
0005434137591	11943	Economy	3200.00
0005434137279	11943	Economy	3200.00
0005434137117	11943	Economy	3200.00
0005434137490	11943	Economy	3200.00
0005434137155	11943	Economy	3200.00
0005434137240	11943	Economy	3200.00
0005434137512	11943	Economy	3200.00
0005434136873	11943	Economy	3200.00
0005434136777	11943	Economy	3200.00
0005434137349	11943	Economy	3200.00
0005434137539	11943	Economy	3200.00
0005434137238	11943	Economy	3200.00
0005434137437	11943	Economy	3200.00
0005434137738	11943	Economy	3200.00
0005434137144	11943	Economy	3200.00
0005434137391	11943	Economy	3200.00
0005434137426	11943	Economy	3200.00
0005434137520	11943	Economy	3200.00
0005434137230	11943	Economy	3200.00
0005434137196	11943	Economy	3200.00
0005434137473	11943	Economy	3200.00
0005434137225	11943	Economy	3200.00
0005434137195	11943	Economy	3200.00
0005434137528	11943	Economy	3200.00
0005434137589	11943	Economy	3200.00
0005434137398	11943	Economy	3200.00
0005434137471	11943	Economy	3200.00
0005434137231	11943	Economy	3200.00
0005434137536	11943	Economy	3200.00
0005434137553	11943	Economy	3200.00
0005434137182	11943	Economy	3200.00
0005434137491	11943	Economy	3200.00
0005434137222	11943	Economy	3200.00
0005434137198	11943	Economy	3200.00
0005434136942	11943	Economy	3200.00
0005434137525	11943	Economy	3200.00
0005434137407	11943	Economy	3200.00
0005434137255	11943	Economy	3200.00
0005434137673	11943	Economy	3200.00
0005434136840	11943	Economy	3200.00
0005434137422	11943	Economy	3200.00
0005434137057	11943	Economy	3200.00
0005434137596	11943	Economy	3200.00
0005434137737	11943	Economy	3200.00
0005434137554	11943	Economy	3200.00
0005434137330	11943	Economy	3200.00
0005434137226	11943	Economy	3200.00
0005434137492	11943	Economy	3200.00
0005434137033	11943	Economy	3200.00
0005434137915	28744	Business	9700.00
0005434137921	28744	Business	9700.00
0005434137911	28744	Business	9700.00
0005434137906	28744	Business	9700.00
0005434137924	28744	Business	9700.00
0005434137903	28744	Business	9700.00
0005434137893	28744	Business	9700.00
0005434137894	28744	Business	9700.00
0005434137885	28744	Business	9700.00
0005434137923	28744	Business	9700.00
0005434137933	28744	Economy	3200.00
0005434137897	28744	Economy	3200.00
0005434137886	28744	Economy	3200.00
0005434137908	28744	Economy	3200.00
0005434137937	28744	Economy	3200.00
0005434137905	28744	Economy	3200.00
0005434137891	28744	Economy	3200.00
0005434137880	28744	Economy	3200.00
0005434137887	28744	Economy	3500.00
0005434137948	28744	Economy	3500.00
0005434137930	28744	Economy	3500.00
0005434137878	28744	Economy	3500.00
0005434137936	28744	Economy	3500.00
0005434137890	28744	Economy	3200.00
0005434137940	28744	Economy	3200.00
0005434137879	28744	Economy	3200.00
0005434137895	28744	Economy	3200.00
0005434137952	28744	Economy	3200.00
0005434137872	28744	Economy	3200.00
0005434137950	28744	Economy	3200.00
0005434137938	28744	Economy	3200.00
0005434137896	28744	Economy	3200.00
0005434137909	28744	Economy	3200.00
0005434137901	28744	Economy	3200.00
0005434137913	28744	Economy	3200.00
0005434137902	28744	Economy	3200.00
0005434137931	28744	Economy	3200.00
0005434137926	28744	Economy	3200.00
0005434137934	28744	Economy	3200.00
0005434137946	28744	Economy	3200.00
0005434137883	28744	Economy	3200.00
0005434137928	28744	Economy	3200.00
0005434137917	28744	Economy	3200.00
0005434137939	28744	Economy	3200.00
0005434137945	28744	Economy	3200.00
0005434137892	28744	Economy	3200.00
0005434137919	28744	Economy	3200.00
0005434137907	28744	Economy	3200.00
0005434137874	28744	Economy	3200.00
0005434137927	28744	Economy	3200.00
0005434137910	28744	Economy	3200.00
0005434137947	28744	Economy	3200.00
0005434137904	28744	Economy	3200.00
0005434137912	28744	Economy	3200.00
0005434137925	28744	Economy	3200.00
0005434137932	28744	Economy	3200.00
0005434137875	28744	Economy	3200.00
0005434137899	28744	Economy	3200.00
0005434137914	28744	Economy	3200.00
0005434137944	28744	Economy	3200.00
0005434137900	28744	Economy	3200.00
0005434137881	28744	Economy	3200.00
0005434137951	28744	Economy	3200.00
0005434137949	28744	Economy	3200.00
0005434137877	28744	Economy	3200.00
0005434137941	28744	Economy	3200.00
0005434137898	28744	Economy	3200.00
0005434137942	28744	Economy	3200.00
0005434137922	28744	Economy	3200.00
0005434137935	28744	Economy	3200.00
0005434137871	28744	Economy	3200.00
0005434137882	28744	Economy	3200.00
0005434137873	28744	Economy	3200.00
0005434137876	28744	Economy	3200.00
0005434137920	28744	Economy	3200.00
0005434137888	28744	Economy	3200.00
0005434137889	28744	Economy	3200.00
0005434137918	28744	Economy	3200.00
0005434137929	28744	Economy	3200.00
0005434137943	28744	Economy	3200.00
0005434137884	28744	Economy	3200.00
0005434137916	28744	Economy	3200.00
0005433538852	6827	Economy	9900.00
0005433538851	6827	Economy	9900.00
0005433538854	6827	Economy	9900.00
0005435259703	6827	Economy	9900.00
0005433538848	6827	Economy	9900.00
0005433538853	6827	Economy	9900.00
0005433534494	6827	Economy	9900.00
0005433538855	6827	Economy	9900.00
0005435259709	6827	Economy	9900.00
0005433538849	6827	Economy	9900.00
0005435259702	6827	Economy	9900.00
0005433538856	6827	Economy	9900.00
0005435259688	6827	Economy	9900.00
0005433538850	6827	Economy	9900.00
0005433534493	6827	Economy	9900.00
0005435259714	6827	Economy	9900.00
0005435259749	24997	Economy	10900.00
0005435259748	24997	Economy	9900.00
0005433534479	24997	Economy	9900.00
0005435259747	24997	Economy	9900.00
0005433538771	24997	Economy	9900.00
0005433538775	24997	Economy	9900.00
0005433534480	24997	Economy	9900.00
0005433538745	24997	Economy	9900.00
0005433538796	24997	Economy	9900.00
0005435259746	24997	Economy	9900.00
0005433538795	24997	Economy	9900.00
0005433538780	24997	Economy	9900.00
0005433538797	24997	Economy	9900.00
0005433538781	24997	Economy	9900.00
0005433538744	24997	Economy	9900.00
0005433538785	24997	Economy	9900.00
0005433534478	24997	Economy	9900.00
0005433511932	840	Economy	16100.00
0005432922465	840	Economy	14600.00
0005433511933	840	Economy	14600.00
0005432922471	840	Economy	14600.00
0005433511934	840	Economy	14600.00
0005433511936	840	Economy	14600.00
0005433511937	840	Economy	14600.00
0005433511931	840	Economy	14600.00
0005433511938	840	Economy	14600.00
0005433511935	840	Economy	14600.00
0005432922481	840	Economy	14600.00
0005432922470	840	Economy	14600.00
0005432922491	840	Economy	14600.00
0005433511930	840	Economy	14600.00
0005432922474	840	Economy	14600.00
0005432922492	840	Economy	14600.00
0005433511939	840	Economy	14600.00
0005433511882	16163	Economy	16100.00
0005433511842	16163	Economy	16100.00
0005433511878	16163	Economy	14600.00
0005432922516	16163	Economy	14600.00
0005432922517	16163	Economy	14600.00
0005433511856	16163	Economy	14600.00
0005432922519	16163	Economy	14600.00
0005432922515	16163	Economy	14600.00
0005433511854	16163	Economy	14600.00
0005433511865	16163	Economy	14600.00
0005433511859	16163	Economy	14600.00
0005433511855	16163	Economy	14600.00
0005433511888	16163	Economy	14600.00
0005433511853	16163	Economy	14600.00
0005433511875	16163	Economy	14600.00
0005433511864	16163	Economy	14600.00
0005432922518	16163	Economy	14600.00
0005433511843	16163	Economy	14600.00
0005433511881	16163	Economy	14600.00
0005433511860	16163	Economy	14600.00
0005435697300	3705	Economy	7900.00
0005435697287	3705	Economy	7900.00
0005435697276	3705	Economy	7200.00
0005435935017	3705	Economy	7200.00
0005435697284	3705	Economy	7200.00
0005434950519	3705	Economy	7200.00
0005435697288	3705	Economy	7200.00
0005435697282	3705	Economy	7200.00
0005435697295	3705	Economy	7200.00
0005435697302	3705	Economy	7200.00
0005435697289	3705	Economy	7200.00
0005435697279	3705	Economy	7200.00
0005435935010	3705	Economy	7200.00
0005435697294	3705	Economy	7200.00
0005435697298	3705	Economy	7200.00
0005435916132	3705	Economy	7200.00
0005435697301	3705	Economy	7200.00
0005435697292	3705	Economy	7200.00
0005435697283	3705	Economy	7200.00
0005435697280	3705	Economy	7200.00
0005435697299	3705	Economy	7200.00
0005435697286	3705	Economy	7200.00
0005435916133	3705	Economy	7200.00
0005434950522	3705	Economy	7200.00
0005435697277	3705	Economy	7200.00
0005434950520	3705	Economy	7200.00
0005435697290	3705	Economy	7200.00
0005435697296	3705	Economy	7200.00
0005435697293	3705	Economy	7200.00
0005434950518	3705	Economy	7200.00
0005435697297	3705	Economy	7200.00
0005435697275	3705	Economy	7200.00
0005435697285	3705	Economy	7200.00
0005435697281	3705	Economy	7200.00
0005434950521	3705	Economy	7200.00
0005435697291	3705	Economy	7200.00
0005435697278	3705	Economy	7200.00
0005435696996	16277	Economy	7900.00
0005435696914	16277	Economy	7900.00
0005435697034	16277	Economy	7900.00
0005435697072	16277	Economy	7200.00
0005435696953	16277	Economy	7200.00
0005435916162	16277	Economy	7200.00
0005434950464	16277	Economy	7200.00
0005435935035	16277	Economy	7200.00
0005435696989	16277	Economy	7200.00
0005435697061	16277	Economy	7200.00
0005435697028	16277	Economy	7200.00
0005435697035	16277	Economy	7200.00
0005435916163	16277	Economy	7200.00
0005435935033	16277	Economy	7200.00
0005435696954	16277	Economy	7200.00
0005434950495	16277	Economy	7200.00
0005435697020	16277	Economy	7200.00
0005434950474	16277	Economy	7200.00
0005435935036	16277	Economy	7200.00
0005435696988	16277	Economy	7200.00
0005435696923	16277	Economy	7200.00
0005435696919	16277	Economy	7200.00
0005435696974	16277	Economy	7200.00
0005435697066	16277	Economy	7200.00
0005435697071	16277	Economy	7200.00
0005435697065	16277	Economy	7200.00
0005435697015	16277	Economy	7200.00
0005435935034	16277	Economy	7200.00
0005434950471	16277	Economy	7200.00
0005435916161	16277	Economy	7200.00
0005435696990	16277	Economy	7200.00
0005435696964	16277	Economy	7200.00
0005435697012	16277	Economy	7200.00
0005435697098	16277	Economy	7200.00
0005435696995	16277	Economy	7200.00
0005435935037	16277	Economy	7200.00
0005435697059	16277	Economy	7200.00
0005435697099	16277	Economy	7200.00
0005435697021	16277	Economy	7200.00
0005434604891	3986	Economy	21300.00
0005433519447	3986	Economy	19300.00
0005432607557	3986	Economy	19300.00
0005432609723	3986	Economy	19300.00
0005432609725	3986	Economy	19300.00
0005432609724	3986	Economy	19300.00
0005434604888	3986	Economy	19300.00
0005434604889	3986	Economy	19300.00
0005432609721	3986	Economy	19300.00
0005434606821	3986	Economy	19300.00
0005433519450	3986	Economy	19300.00
0005432607560	3986	Economy	19300.00
0005434604890	3986	Economy	19300.00
0005433519448	3986	Economy	19300.00
0005432607556	3986	Economy	19300.00
0005433519449	3986	Economy	19300.00
0005434606822	3986	Economy	19300.00
0005432607558	3986	Economy	19300.00
0005432607559	3986	Economy	19300.00
0005432609722	3986	Economy	19300.00
0005432613824	22075	Economy	21300.00
0005434606762	22075	Economy	21300.00
0005433519411	22075	Economy	21300.00
0005432613803	22075	Economy	21300.00
0005432613832	22075	Economy	19300.00
0005432613792	22075	Economy	19300.00
0005432609677	22075	Economy	19300.00
0005432609658	22075	Economy	19300.00
0005433519407	22075	Economy	19300.00
0005432609661	22075	Economy	19300.00
0005432613815	22075	Economy	19300.00
0005432613810	22075	Economy	19300.00
0005433519404	22075	Economy	19300.00
0005432609676	22075	Economy	19300.00
0005432613793	22075	Economy	19300.00
0005432613809	22075	Economy	19300.00
0005432613831	22075	Economy	19300.00
0005434606765	22075	Economy	19300.00
0005432609659	22075	Economy	19300.00
0005433519419	22075	Economy	19300.00
0005432613813	22075	Economy	19300.00
0005432609675	22075	Economy	19300.00
0005432613798	22075	Economy	19300.00
0005432613811	22075	Economy	19300.00
0005432613805	22075	Economy	19300.00
0005433519408	22075	Economy	19300.00
0005432609669	22075	Economy	19300.00
0005432613804	22075	Economy	19300.00
0005432609692	22075	Economy	19300.00
0005434606764	22075	Economy	19300.00
0005433519403	22075	Economy	19300.00
0005432613814	22075	Economy	19300.00
0005432613791	22075	Economy	19300.00
0005435841093	22075	Economy	19300.00
0005433519425	22075	Economy	19300.00
0005432609681	22075	Economy	19300.00
0005432613802	22075	Economy	19300.00
0005432609660	22075	Economy	19300.00
0005432613812	22075	Economy	19300.00
0005432613801	22075	Economy	19300.00
0005432609670	22075	Economy	19300.00
0005432613806	22075	Economy	19300.00
0005432609674	22075	Economy	19300.00
0005433519426	22075	Economy	19300.00
0005432609671	22075	Economy	19300.00
0005432613790	22075	Economy	19300.00
0005434606763	22075	Economy	19300.00
0005433348963	737	Economy	3700.00
0005433348939	737	Economy	3700.00
0005433348935	737	Economy	3700.00
0005433348921	737	Economy	3700.00
0005435628717	737	Economy	3700.00
0005433348962	737	Economy	3700.00
0005433348924	737	Economy	3700.00
0005433348922	737	Economy	3700.00
0005433348941	737	Economy	3700.00
0005433348931	737	Economy	3700.00
0005433348940	737	Economy	3700.00
0005433348979	15969	Economy	3700.00
0005435628704	15969	Economy	3700.00
0005433348978	15969	Economy	3700.00
0005435628699	15969	Economy	3700.00
0005433348980	15969	Economy	3700.00
0005433348981	15969	Economy	3700.00
0005435628691	15969	Economy	3700.00
0005433348977	15969	Economy	3700.00
0005435628696	15969	Economy	3700.00
0005433159278	17166	Economy	7100.00
0005433158106	17166	Economy	7100.00
0005434445242	17166	Economy	7100.00
0005433159292	17166	Economy	7100.00
0005433159288	17166	Economy	7100.00
0005434446512	17166	Economy	7100.00
0005434445240	17166	Economy	7100.00
0005434446513	17166	Economy	7100.00
0005433159287	17166	Economy	7100.00
0005433158095	17166	Economy	7100.00
0005434445241	17166	Economy	7100.00
0005433159308	17634	Economy	7100.00
0005434445218	17634	Economy	7100.00
0005433159309	17634	Economy	7100.00
0005434445214	17634	Economy	7100.00
0005434445223	17634	Economy	7100.00
0005434445217	17634	Economy	7100.00
0005435132861	7887	Economy	5900.00
0005435383103	7887	Economy	5400.00
0005435132862	7887	Economy	5400.00
0005435383082	7887	Economy	5400.00
0005435132865	7887	Economy	5400.00
0005435132863	7887	Economy	5400.00
0005435383084	7887	Economy	5400.00
0005435132866	7887	Economy	5400.00
0005435132859	7887	Economy	5400.00
0005435132864	7887	Economy	5400.00
0005435132858	7887	Economy	5400.00
0005435132857	7887	Economy	5400.00
0005435132856	7887	Economy	5400.00
0005435383083	7887	Economy	5400.00
0005435132860	7887	Economy	5400.00
0005435383091	7887	Economy	5400.00
0005435383094	7887	Economy	5400.00
0005435383095	7887	Economy	5400.00
0005435383092	7887	Economy	5400.00
0005435383137	33089	Economy	5900.00
0005435132822	33089	Economy	5400.00
0005435132789	33089	Economy	5400.00
0005435383142	33089	Economy	5400.00
0005435383139	33089	Economy	5400.00
0005435132821	33089	Economy	5400.00
0005435383138	33089	Economy	5400.00
0005435383140	33089	Economy	5400.00
0005435383141	33089	Economy	5400.00
0005435132774	33089	Economy	5400.00
0005435132811	33089	Economy	5400.00
0005435132773	33089	Economy	5400.00
0005435811068	4421	Business	133200.00
0005435938859	4421	Business	133200.00
0005435938849	4421	Business	133200.00
0005435811063	4421	Business	133200.00
0005435811058	4421	Economy	44400.00
0005435938862	4421	Economy	48800.00
0005435938850	4421	Economy	48800.00
0005435938858	4421	Economy	44400.00
0005435938854	4421	Economy	44400.00
0005435938856	4421	Economy	44400.00
0005435811061	4421	Economy	44400.00
0005435938853	4421	Economy	44400.00
0005435938852	4421	Economy	44400.00
0005435811067	4421	Economy	44400.00
0005435811059	4421	Economy	44400.00
0005435811064	4421	Economy	44400.00
0005435938861	4421	Economy	44400.00
0005435811065	4421	Economy	44400.00
0005435938848	4421	Economy	44400.00
0005435811060	4421	Economy	44400.00
0005435811062	4421	Economy	44400.00
0005435811066	4421	Economy	44400.00
0005435938882	29436	Economy	44400.00
0005435811019	29436	Economy	44400.00
0005435811006	29436	Economy	44400.00
0005435811036	29436	Economy	48800.00
0005435811035	29436	Economy	44400.00
0005435938883	29436	Economy	44400.00
0005435811018	29436	Economy	44400.00
0005435938879	29436	Economy	44400.00
0005435938881	29436	Economy	44400.00
0005435811037	29436	Economy	44400.00
0005435938884	29436	Economy	44400.00
0005435938880	29436	Economy	44400.00
0005435811015	29436	Economy	44400.00
0005435160277	7475	Economy	12500.00
0005435160281	7475	Economy	12500.00
0005435160285	7475	Economy	12500.00
0005435160282	7475	Economy	12500.00
0005435160280	7475	Economy	12500.00
0005435160276	7475	Economy	12500.00
0005435160283	7475	Economy	12500.00
0005435390199	7475	Economy	12500.00
0005435160284	7475	Economy	12500.00
0005435390148	7475	Economy	12500.00
0005435390165	7475	Economy	12500.00
0005435390166	7475	Economy	12500.00
0005435390196	7475	Economy	12500.00
0005435160279	7475	Economy	12500.00
0005435390164	7475	Economy	12500.00
0005435160278	7475	Economy	12500.00
0005435390227	29566	Economy	13800.00
0005435390225	29566	Economy	12500.00
0005435160204	29566	Economy	12500.00
0005435160215	29566	Economy	12500.00
0005435160207	29566	Economy	12500.00
0005435390223	29566	Economy	12500.00
0005435160180	29566	Economy	12500.00
0005435390226	29566	Economy	12500.00
0005435160165	29566	Economy	12500.00
0005435390229	29566	Economy	12500.00
0005435160152	29566	Economy	12500.00
0005435160216	29566	Economy	12500.00
0005435160176	29566	Economy	12500.00
0005435160155	29566	Economy	12500.00
0005435160138	29566	Economy	12500.00
0005435390228	29566	Economy	12500.00
0005435390224	29566	Economy	12500.00
0005435160175	29566	Economy	12500.00
0005435160167	29566	Economy	12500.00
0005435160206	29566	Economy	12500.00
0005435160239	29566	Economy	12500.00
0005432398166	18433	Economy	4900.00
0005432398159	18433	Economy	4900.00
0005432398158	18433	Economy	4900.00
0005432394060	18433	Economy	4900.00
0005432398153	18433	Economy	4900.00
0005432394061	18433	Economy	4900.00
0005435178991	18433	Economy	4900.00
0005432398167	18433	Economy	4900.00
0005435178493	18433	Economy	4900.00
0005432398150	18433	Economy	4900.00
0005432400112	27124	Economy	4900.00
0005432398187	27124	Economy	4900.00
0005435178474	27124	Economy	4900.00
0005432400111	27124	Economy	4900.00
0005435178479	27124	Economy	4900.00
0005435178475	27124	Economy	4900.00
0005432400113	27124	Economy	4900.00
0005432398186	27124	Economy	4900.00
0005435178478	27124	Economy	4900.00
0005432400110	27124	Economy	4900.00
0005434504098	6511	Business	48400.00
0005434504062	6511	Business	48400.00
0005434504064	6511	Business	48400.00
0005434504082	6511	Business	48400.00
0005434504099	6511	Business	48400.00
0005434504075	6511	Business	48400.00
0005434504103	6511	Business	48400.00
0005434504084	6511	Economy	16100.00
0005434504066	6511	Economy	16100.00
0005434504095	6511	Economy	16100.00
0005435103919	6511	Economy	16100.00
0005435103910	6511	Economy	16100.00
0005434504080	6511	Economy	17800.00
0005434504076	6511	Economy	17800.00
0005434504074	6511	Economy	16100.00
0005434504067	6511	Economy	16100.00
0005434504097	6511	Economy	16100.00
0005435103916	6511	Economy	16100.00
0005434504083	6511	Economy	16100.00
0005434504087	6511	Economy	16100.00
0005434504070	6511	Economy	16100.00
0005434504073	6511	Economy	16100.00
0005434504100	6511	Economy	16100.00
0005434504102	6511	Economy	16100.00
0005435103914	6511	Economy	16100.00
0005434504094	6511	Economy	16100.00
0005434504090	6511	Economy	16100.00
0005434504089	6511	Economy	16100.00
0005434504071	6511	Economy	16100.00
0005435103911	6511	Economy	16100.00
0005434504086	6511	Economy	16100.00
0005434504065	6511	Economy	16100.00
0005435103918	6511	Economy	16100.00
0005435103917	6511	Economy	16100.00
0005434504078	6511	Economy	16100.00
0005434504091	6511	Economy	16100.00
0005435103912	6511	Economy	16100.00
0005434504096	6511	Economy	16100.00
0005434504068	6511	Economy	16100.00
0005434504079	6511	Economy	16100.00
0005435103921	6511	Economy	16100.00
0005434504101	6511	Economy	16100.00
0005434504077	6511	Economy	16100.00
0005434504069	6511	Economy	16100.00
0005434504088	6511	Economy	16100.00
0005434504093	6511	Economy	16100.00
0005434504081	6511	Economy	16100.00
0005435103913	6511	Economy	16100.00
0005434504063	6511	Economy	16100.00
0005434504072	6511	Economy	16100.00
0005435103915	6511	Economy	16100.00
0005434504092	6511	Economy	16100.00
0005435103909	6511	Economy	16100.00
0005434504085	6511	Economy	16100.00
0005435103920	6511	Economy	16100.00
0005434503673	22656	Business	48400.00
0005435103798	22656	Business	48400.00
0005434503680	22656	Business	48400.00
0005434503669	22656	Economy	16100.00
0005435103824	22656	Economy	16100.00
0005435103821	22656	Economy	16100.00
0005434503636	22656	Economy	17800.00
0005434503543	22656	Economy	17800.00
0005434503516	22656	Economy	16100.00
0005434503589	22656	Economy	16100.00
0005434503665	22656	Economy	16100.00
0005434503755	22656	Economy	16100.00
0005434503736	22656	Economy	16100.00
0005434503515	22656	Economy	16100.00
0005434503679	22656	Economy	16100.00
0005434503705	22656	Economy	16100.00
0005434503773	22656	Economy	16100.00
0005434503677	22656	Economy	16100.00
0005435103804	22656	Economy	16100.00
0005434503717	22656	Economy	16100.00
0005434503683	22656	Economy	16100.00
0005434503780	22656	Economy	16100.00
0005434503625	22656	Economy	16100.00
0005434503778	22656	Economy	16100.00
0005434503779	22656	Economy	16100.00
0005435103825	22656	Economy	16100.00
0005434503537	22656	Economy	16100.00
0005435103801	22656	Economy	16100.00
0005434503754	22656	Economy	16100.00
0005434503716	22656	Economy	16100.00
0005434503585	22656	Economy	16100.00
0005434503775	22656	Economy	16100.00
0005435103822	22656	Economy	16100.00
0005435103805	22656	Economy	16100.00
0005434503766	22656	Economy	16100.00
0005435800089	21311	Economy	15300.00
0005435800080	21311	Economy	15300.00
0005435800087	21311	Economy	15300.00
0005435800088	21311	Economy	15300.00
0005435800079	21311	Economy	15300.00
0005435652988	1656	Business	50000.00
0005433367636	1656	Business	50000.00
0005433367421	1656	Business	50000.00
0005433367454	1656	Business	50000.00
0005435652980	1656	Business	50000.00
0005435652973	1656	Business	50000.00
0005435652966	1656	Business	50000.00
0005435652976	1656	Business	50000.00
0005433367380	1656	Business	50000.00
0005433367414	1656	Business	50000.00
0005435652984	1656	Business	50000.00
0005433367307	1656	Business	50000.00
0005433367541	1656	Economy	16700.00
0005435652962	1656	Economy	16700.00
0005433367453	1656	Economy	16700.00
0005433367442	1656	Economy	16700.00
0005433367342	1656	Economy	16700.00
0005435652956	1656	Economy	16700.00
0005435652961	1656	Economy	16700.00
0005433367394	1656	Economy	16700.00
0005433367616	1656	Economy	18300.00
0005433367512	1656	Economy	18300.00
0005435652983	1656	Economy	18300.00
0005433367531	1656	Economy	18300.00
0005435652991	1656	Economy	16700.00
0005435652957	1656	Economy	16700.00
0005435652987	1656	Economy	16700.00
0005433367575	1656	Economy	16700.00
0005435652990	1656	Economy	16700.00
0005433367426	1656	Economy	16700.00
0005433367457	1656	Economy	16700.00
0005433367519	1656	Economy	16700.00
0005433367653	1656	Economy	16700.00
0005435652974	1656	Economy	16700.00
0005435652989	1656	Economy	16700.00
0005435652960	1656	Economy	16700.00
0005433367510	1656	Economy	16700.00
0005433367437	1656	Economy	16700.00
0005435652982	1656	Economy	16700.00
0005435652986	1656	Economy	16700.00
0005435652971	1656	Economy	16700.00
0005435652969	1656	Economy	16700.00
0005435652978	1656	Economy	16700.00
0005433367441	1656	Economy	16700.00
0005435652958	1656	Economy	16700.00
0005433367462	1656	Economy	16700.00
0005433367275	1656	Economy	16700.00
0005435652975	1656	Economy	16700.00
0005433367485	1656	Economy	16700.00
0005435652965	1656	Economy	16700.00
0005433367308	1656	Economy	16700.00
0005433367525	1656	Economy	16700.00
0005433367511	1656	Economy	16700.00
0005433367464	1656	Economy	16700.00
0005435652959	1656	Economy	16700.00
0005433367484	1656	Economy	16700.00
0005435652967	1656	Economy	16700.00
0005433367460	1656	Economy	16700.00
0005435652970	1656	Economy	16700.00
0005433367570	1656	Economy	16700.00
0005435652981	1656	Economy	16700.00
0005433367470	1656	Economy	16700.00
0005435652955	1656	Economy	16700.00
0005433367590	1656	Economy	16700.00
0005435652964	1656	Economy	16700.00
0005433367413	1656	Economy	16700.00
0005433367523	1656	Economy	16700.00
0005435652979	1656	Economy	16700.00
0005433367654	1656	Economy	16700.00
0005433367584	1656	Economy	16700.00
0005435652977	1656	Economy	16700.00
0005433367527	1656	Economy	16700.00
0005435652972	1656	Economy	16700.00
0005433367374	1656	Economy	16700.00
0005433367373	1656	Economy	16700.00
0005435652963	1656	Economy	16700.00
0005433367530	1656	Economy	16700.00
0005433367436	1656	Economy	16700.00
0005433367425	1656	Economy	16700.00
0005433367415	1656	Economy	16700.00
0005435652968	1656	Economy	16700.00
0005433367463	1656	Economy	16700.00
0005435652985	1656	Economy	16700.00
0005433367404	1656	Economy	16700.00
0005433367461	1656	Economy	16700.00
0005433367655	1656	Economy	16700.00
0005433367445	1656	Economy	16700.00
0005433367507	1656	Economy	16700.00
0005433367443	1656	Economy	16700.00
0005435652483	21686	Business	50000.00
0005433367830	21686	Business	50000.00
0005435652489	21686	Business	50000.00
0005433367807	21686	Business	50000.00
0005433367796	21686	Business	50000.00
0005433367826	21686	Business	50000.00
0005433367794	21686	Business	50000.00
0005433367813	21686	Business	50000.00
0005433367819	21686	Business	50000.00
0005435652497	21686	Business	50000.00
0005433367798	21686	Economy	16700.00
0005435652459	21686	Economy	16700.00
0005435652396	21686	Economy	16700.00
0005435652629	21686	Economy	16700.00
0005433367828	21686	Economy	16700.00
0005433367802	21686	Economy	16700.00
0005433367816	21686	Economy	16700.00
0005433367809	21686	Economy	16700.00
0005433367822	21686	Economy	16700.00
0005433367831	21686	Economy	18300.00
0005435652548	21686	Economy	18300.00
0005435652484	21686	Economy	18300.00
0005435652359	21686	Economy	18300.00
0005433367821	21686	Economy	16700.00
0005435652555	21686	Economy	16700.00
0005433367804	21686	Economy	16700.00
0005435652554	21686	Economy	16700.00
0005435652516	21686	Economy	16700.00
0005433367803	21686	Economy	16700.00
0005433367827	21686	Economy	16700.00
0005435652493	21686	Economy	16700.00
0005433367829	21686	Economy	16700.00
0005435652607	21686	Economy	16700.00
0005433367805	21686	Economy	16700.00
0005433367815	21686	Economy	16700.00
0005433367825	21686	Economy	16700.00
0005433367810	21686	Economy	16700.00
0005435652443	21686	Economy	16700.00
0005433367823	21686	Economy	16700.00
0005435652448	21686	Economy	16700.00
0005435652400	21686	Economy	16700.00
0005435652660	21686	Economy	16700.00
0005435652395	21686	Economy	16700.00
0005435652539	21686	Economy	16700.00
0005433367797	21686	Economy	16700.00
0005435652517	21686	Economy	16700.00
0005435652529	21686	Economy	16700.00
0005433367801	21686	Economy	16700.00
0005435652492	21686	Economy	16700.00
0005433367820	21686	Economy	16700.00
0005435652542	21686	Economy	16700.00
0005435652662	21686	Economy	16700.00
0005435652385	21686	Economy	16700.00
0005433367817	21686	Economy	16700.00
0005433367806	21686	Economy	16700.00
0005435652430	21686	Economy	16700.00
0005433367799	21686	Economy	16700.00
0005435652563	21686	Economy	16700.00
0005433367808	21686	Economy	16700.00
0005435652533	21686	Economy	16700.00
0005435652360	21686	Economy	16700.00
0005433367832	21686	Economy	16700.00
0005435652620	21686	Economy	16700.00
0005435652518	21686	Economy	16700.00
0005435652458	21686	Economy	16700.00
0005435652534	21686	Economy	16700.00
0005435652562	21686	Economy	16700.00
0005435652528	21686	Economy	16700.00
0005435652447	21686	Economy	16700.00
0005433367824	21686	Economy	16700.00
0005435652630	21686	Economy	16700.00
0005435652537	21686	Economy	16700.00
0005433367818	21686	Economy	16700.00
0005435652592	21686	Economy	16700.00
0005433367795	21686	Economy	16700.00
0005433367814	21686	Economy	16700.00
0005433367811	21686	Economy	16700.00
0005435652541	21686	Economy	16700.00
0005435652471	21686	Economy	16700.00
0005433367800	21686	Economy	16700.00
0005433367812	21686	Economy	16700.00
0005435652661	21686	Economy	16700.00
0005435652531	21686	Economy	16700.00
0005433985871	4164	Business	21500.00
0005433985872	4164	Business	21500.00
0005433985844	4164	Business	21500.00
0005433985873	4164	Business	21500.00
0005433985876	4164	Business	21500.00
0005433985843	4164	Economy	7200.00
0005433985845	4164	Economy	7200.00
0005433985853	4164	Economy	7200.00
0005433985867	4164	Economy	7200.00
0005433985842	4164	Economy	7200.00
0005433985860	4164	Economy	7200.00
0005433985859	4164	Economy	7200.00
0005433985863	4164	Economy	7900.00
0005433985848	4164	Economy	7900.00
0005433985856	4164	Economy	7900.00
0005435788767	4164	Economy	7900.00
0005433985850	4164	Economy	7200.00
0005433985849	4164	Economy	7200.00
0005433985865	4164	Economy	7200.00
0005433985847	4164	Economy	7200.00
0005433985870	4164	Economy	7200.00
0005433985869	4164	Economy	7200.00
0005433985840	4164	Economy	7200.00
0005433985846	4164	Economy	7200.00
0005433985857	4164	Economy	7200.00
0005433985858	4164	Economy	7200.00
0005433985852	4164	Economy	7200.00
0005435788766	4164	Economy	7200.00
0005433985874	4164	Economy	7200.00
0005433985875	4164	Economy	7200.00
0005433985877	4164	Economy	7200.00
0005433985861	4164	Economy	7200.00
0005433985851	4164	Economy	7200.00
0005433985854	4164	Economy	7200.00
0005435788765	4164	Economy	7200.00
0005433985866	4164	Economy	7200.00
0005433985841	4164	Economy	7200.00
0005433985862	4164	Economy	7200.00
0005433985868	4164	Economy	7200.00
0005433985855	4164	Economy	7200.00
0005433985864	4164	Economy	7200.00
0005433985358	25642	Business	21500.00
0005433985311	25642	Business	21500.00
0005433985405	25642	Business	21500.00
0005433985380	25642	Business	21500.00
0005435788745	25642	Business	21500.00
0005433985417	25642	Business	21500.00
0005433985544	25642	Business	21500.00
0005433985246	25642	Business	21500.00
0005433985378	25642	Business	21500.00
0005433985404	25642	Economy	7200.00
0005433985338	25642	Economy	7200.00
0005433985443	25642	Economy	7200.00
0005433985389	25642	Economy	7900.00
0005433985426	25642	Economy	7200.00
0005433985321	25642	Economy	7200.00
0005433985408	25642	Economy	7200.00
0005435788742	25642	Economy	7200.00
0005433985507	25642	Economy	7200.00
0005433985524	25642	Economy	7200.00
0005433985523	25642	Economy	7200.00
0005433985410	25642	Economy	7200.00
0005433985492	25642	Economy	7200.00
0005433985399	25642	Economy	7200.00
0005433985350	25642	Economy	7200.00
0005433985268	25642	Economy	7200.00
0005433985294	25642	Economy	7200.00
0005433985322	25642	Economy	7200.00
0005433985396	25642	Economy	7200.00
0005433985493	25642	Economy	7200.00
0005433985458	25642	Economy	7200.00
0005433985323	25642	Economy	7200.00
0005433985526	25642	Economy	7200.00
0005433985307	25642	Economy	7200.00
0005435788747	25642	Economy	7200.00
0005435788744	25642	Economy	7200.00
0005433985409	25642	Economy	7200.00
0005433985531	25642	Economy	7200.00
0005435788746	25642	Economy	7200.00
0005433985559	25642	Economy	7200.00
0005433985261	25642	Economy	7200.00
0005433985379	25642	Economy	7200.00
0005433985398	25642	Economy	7200.00
0005433985599	25642	Economy	7200.00
0005433985397	25642	Economy	7200.00
0005433985335	25642	Economy	7200.00
0005433985525	25642	Economy	7200.00
0005433985339	25642	Economy	7200.00
0005433985411	25642	Economy	7200.00
0005433985309	25642	Economy	7200.00
0005433985511	25642	Economy	7200.00
0005433985600	25642	Economy	7200.00
0005435720808	21294	Economy	9400.00
0005435719553	21294	Economy	9400.00
0005435719555	21294	Economy	9400.00
0005435720816	21294	Economy	9400.00
0005435719554	21294	Economy	9400.00
0005435720815	21294	Economy	9400.00
0005435719567	24804	Economy	9400.00
0005435719568	24804	Economy	9400.00
0005435720131	24804	Economy	9400.00
0005435720130	24804	Economy	9400.00
0005435719566	24804	Economy	9400.00
0005433168318	1629	Economy	15500.00
0005434509125	1629	Economy	15500.00
0005433168313	1629	Economy	15500.00
0005434509136	1629	Economy	15500.00
0005434509134	1629	Economy	15500.00
0005434509132	1629	Economy	15500.00
0005434509126	1629	Economy	15500.00
0005434509133	1629	Economy	15500.00
0005434509137	1629	Economy	15500.00
0005434509124	1629	Economy	15500.00
0005433168332	1629	Economy	15500.00
0005434509138	1629	Economy	15500.00
0005433168312	1629	Economy	15500.00
0005434509131	1629	Economy	15500.00
0005433168317	1629	Economy	15500.00
0005434509129	1629	Economy	15500.00
0005434509128	1629	Economy	15500.00
0005434509127	1629	Economy	15500.00
0005434509130	1629	Economy	15500.00
0005433168320	1629	Economy	15500.00
0005434509135	1629	Economy	15500.00
0005433168307	1629	Economy	15500.00
0005432655414	17872	Business	18000.00
0005432657407	17872	Business	18000.00
0005432657413	17872	Business	18000.00
0005432663019	17872	Business	18000.00
0005432655397	17872	Business	18000.00
0005432659686	17872	Business	18000.00
0005432869516	17872	Business	18000.00
0005432657411	17872	Economy	6000.00
0005432659688	17872	Economy	6000.00
0005434151699	17872	Economy	6600.00
0005432659684	17872	Economy	6600.00
0005432657409	17872	Economy	6600.00
0005434151700	17872	Economy	6000.00
0005432667432	17872	Economy	6000.00
0005432655357	17872	Economy	6000.00
0005432869514	17872	Economy	6000.00
0005432655396	17872	Economy	6000.00
0005432655420	17872	Economy	6000.00
0005432657412	17872	Economy	6000.00
0005432655348	17872	Economy	6000.00
0005432657414	17872	Economy	6000.00
0005432869518	17872	Economy	6000.00
0005432658557	17872	Economy	6000.00
0005432869512	17872	Economy	6000.00
0005432869517	17872	Economy	6000.00
0005432667433	17872	Economy	6000.00
0005432659687	17872	Economy	6000.00
0005432660795	17872	Economy	6000.00
0005432666365	17872	Economy	6000.00
0005432657419	17872	Economy	6000.00
0005432665254	17872	Economy	6000.00
0005432655413	17872	Economy	6000.00
0005432655347	17872	Economy	6000.00
0005432665253	17872	Economy	6000.00
0005432655385	17872	Economy	6000.00
0005432655358	17872	Economy	6000.00
0005432869515	17872	Economy	6000.00
0005432657420	17872	Economy	6000.00
0005434151701	17872	Economy	6000.00
0005432869513	17872	Economy	6000.00
0005432655386	17872	Economy	6000.00
0005432655384	17872	Economy	6000.00
0005432869437	26293	Business	18000.00
0005432655488	26293	Business	18000.00
0005432655496	26293	Economy	6000.00
0005432655492	26293	Economy	6000.00
0005432665267	26293	Economy	6000.00
0005432869445	26293	Economy	6000.00
0005432657440	26293	Economy	6000.00
0005432655487	26293	Economy	6000.00
0005432655489	26293	Economy	6600.00
0005432660811	26293	Economy	6600.00
0005432657439	26293	Economy	6000.00
0005432659700	26293	Economy	6000.00
0005432667447	26293	Economy	6000.00
0005432655485	26293	Economy	6000.00
0005432658584	26293	Economy	6000.00
0005432869432	26293	Economy	6000.00
0005432869441	26293	Economy	6000.00
0005432666382	26293	Economy	6000.00
0005432869454	26293	Economy	6000.00
0005432655491	26293	Economy	6000.00
0005432657438	26293	Economy	6000.00
0005432655495	26293	Economy	6000.00
0005432666381	26293	Economy	6000.00
0005434151684	26293	Economy	6000.00
0005432655490	26293	Economy	6000.00
0005432655494	26293	Economy	6000.00
0005432665268	26293	Economy	6000.00
0005432658583	26293	Economy	6000.00
0005432655486	26293	Economy	6000.00
0005432659699	26293	Economy	6000.00
0005432655493	26293	Economy	6000.00
0005432869444	26293	Economy	6000.00
0005432869436	26293	Economy	6000.00
0005432638984	25065	Business	87300.00
0005432638983	25065	Business	87300.00
0005432638945	25065	Business	87300.00
0005432866000	25065	Business	87300.00
0005432638966	25065	Business	87300.00
0005432866003	25065	Economy	29100.00
0005432865995	25065	Economy	29100.00
0005432638987	25065	Economy	29100.00
0005432866002	25065	Economy	29100.00
0005432639008	25065	Economy	29100.00
0005432866005	25065	Economy	29100.00
0005432638986	25065	Economy	29100.00
0005432638921	25065	Economy	29100.00
0005432865997	25065	Economy	32000.00
0005432639010	25065	Economy	32000.00
0005432639054	25065	Economy	29100.00
0005432638923	25065	Economy	29100.00
0005432866004	25065	Economy	29100.00
0005432866008	25065	Economy	29100.00
0005432638931	25065	Economy	29100.00
0005432638967	25065	Economy	29100.00
0005432638924	25065	Economy	29100.00
0005432638982	25065	Economy	29100.00
0005432638999	25065	Economy	29100.00
0005432638925	25065	Economy	29100.00
0005432866007	25065	Economy	29100.00
0005432865999	25065	Economy	29100.00
0005432638980	25065	Economy	29100.00
0005432639033	25065	Economy	29100.00
0005432638981	25065	Economy	29100.00
0005432639045	25065	Economy	29100.00
0005432865994	25065	Economy	29100.00
0005432865998	25065	Economy	29100.00
0005432638929	25065	Economy	29100.00
0005432638970	25065	Economy	29100.00
0005432866006	25065	Economy	29100.00
0005432638985	25065	Economy	29100.00
0005432638922	25065	Economy	29100.00
0005432639053	25065	Economy	29100.00
0005432638946	25065	Economy	29100.00
0005432866001	25065	Economy	29100.00
0005432638996	25065	Economy	29100.00
0005432638960	25065	Economy	29100.00
0005432639001	25065	Economy	29100.00
0005432865996	25065	Economy	29100.00
0005432638932	25065	Economy	29100.00
0005432328638	3076	Business	16100.00
0005433438861	3076	Business	16100.00
0005432328632	3076	Business	16100.00
0005433438870	3076	Business	16100.00
0005432287179	3076	Business	16100.00
0005433438859	3076	Business	16100.00
0005432328627	3076	Business	16100.00
0005432328641	3076	Business	16100.00
0005432328597	3076	Business	16100.00
0005432905052	3076	Economy	5400.00
0005432328629	3076	Economy	5400.00
0005433438860	3076	Economy	5400.00
0005432328603	3076	Economy	5400.00
0005433438867	3076	Economy	5400.00
0005432328608	3076	Economy	5400.00
0005433438868	3076	Economy	5900.00
0005432328614	3076	Economy	5900.00
0005432328619	3076	Economy	5900.00
0005432287183	3076	Economy	5400.00
0005432328625	3076	Economy	5400.00
0005432328640	3076	Economy	5400.00
0005432328617	3076	Economy	5400.00
0005433438866	3076	Economy	5400.00
0005432328599	3076	Economy	5400.00
0005433438862	3076	Economy	5400.00
0005432328607	3076	Economy	5400.00
0005432328596	3076	Economy	5400.00
0005432328618	3076	Economy	5400.00
0005432328606	3076	Economy	5400.00
0005432287180	3076	Economy	5400.00
0005432328609	3076	Economy	5400.00
0005432328634	3076	Economy	5400.00
0005432328611	3076	Economy	5400.00
0005432328621	3076	Economy	5400.00
0005433438863	3076	Economy	5400.00
0005432328601	3076	Economy	5400.00
0005432328635	3076	Economy	5400.00
0005432328620	3076	Economy	5400.00
0005432328626	3076	Economy	5400.00
0005432328610	3076	Economy	5400.00
0005432328637	3076	Economy	5400.00
0005432328623	3076	Economy	5400.00
0005432328622	3076	Economy	5400.00
0005432328602	3076	Economy	5400.00
0005432287178	3076	Economy	5400.00
0005432328639	3076	Economy	5400.00
0005432328613	3076	Economy	5400.00
0005432328612	3076	Economy	5400.00
0005432328605	3076	Economy	5400.00
0005433438864	3076	Economy	5400.00
0005432287181	3076	Economy	5400.00
0005433438865	3076	Economy	5400.00
0005432328630	3076	Economy	5400.00
0005432328616	3076	Economy	5400.00
0005432328628	3076	Economy	5400.00
0005432328631	3076	Economy	5400.00
0005432328624	3076	Economy	5400.00
0005432287182	3076	Economy	5400.00
0005433438869	3076	Economy	5400.00
0005432328633	3076	Economy	5400.00
0005432328615	3076	Economy	5400.00
0005432328598	3076	Economy	5400.00
0005432328595	3076	Economy	5400.00
0005432328604	3076	Economy	5400.00
0005432328636	3076	Economy	5400.00
0005432905048	3076	Economy	5400.00
0005432328600	3076	Economy	5400.00
0005432328179	31121	Business	16100.00
0005432054298	31121	Business	16100.00
0005432328220	31121	Business	16100.00
0005432328120	31121	Business	16100.00
0005432327995	31121	Business	16100.00
0005432328254	31121	Business	16100.00
0005432328067	31121	Business	16100.00
0005432328112	31121	Business	16100.00
0005432328195	31121	Economy	5400.00
0005432328311	31121	Economy	5400.00
0005432328189	31121	Economy	5400.00
0005432054297	31121	Economy	5400.00
0005432328131	31121	Economy	5400.00
0005432328147	31121	Economy	5400.00
0005432327916	31121	Economy	5400.00
0005432328391	31121	Economy	5400.00
0005432328151	31121	Economy	5400.00
0005432328186	31121	Economy	5400.00
0005432328130	31121	Economy	5400.00
0005432328262	31121	Economy	5400.00
0005432328353	31121	Economy	5400.00
0005432328094	31121	Economy	5400.00
0005432328357	31121	Economy	5400.00
0005432328188	31121	Economy	5400.00
0005432328396	31121	Economy	5400.00
0005432328121	31121	Economy	5400.00
0005432328261	31121	Economy	5400.00
0005432328075	31121	Economy	5400.00
0005432054299	31121	Economy	5400.00
0005432328209	31121	Economy	5400.00
0005432328082	31121	Economy	5400.00
0005432328312	31121	Economy	5400.00
0005432328204	31121	Economy	5400.00
0005432905116	31121	Economy	5400.00
0005432328170	31121	Economy	5400.00
0005432328168	31121	Economy	5400.00
0005432905115	31121	Economy	5400.00
0005432328097	31121	Economy	5400.00
0005432328095	31121	Economy	5400.00
0005432328166	31121	Economy	5400.00
0005432328435	31121	Economy	5400.00
0005432328128	31121	Economy	5400.00
0005432328181	31121	Economy	5400.00
0005432328196	31121	Economy	5400.00
0005432328146	31121	Economy	5400.00
0005432328197	31121	Economy	5400.00
0005432328358	31121	Economy	5400.00
0005432328113	31121	Economy	5400.00
0005432328073	31121	Economy	5400.00
0005432328096	31121	Economy	5400.00
0005432328237	31121	Economy	5400.00
0005432328080	31121	Economy	5400.00
0005432328363	31121	Economy	5400.00
0005432328226	31121	Economy	5400.00
0005432328058	31121	Economy	5400.00
0005432328310	31121	Economy	5400.00
0005432328180	31121	Economy	5400.00
0005432328227	31121	Economy	5400.00
0005432328193	31121	Economy	5400.00
0005432328124	31121	Economy	5400.00
0005432328076	31121	Economy	5400.00
0005432328140	31121	Economy	5400.00
0005432327921	31121	Economy	5400.00
0005432328308	31121	Economy	5400.00
0005432328239	31121	Economy	5400.00
0005432328194	31121	Economy	5400.00
0005432328152	31121	Economy	5400.00
0005432328052	31121	Economy	5400.00
0005432327915	31121	Economy	5400.00
0005434309713	6175	Business	124600.00
0005435296961	6175	Business	124600.00
0005435999230	6175	Business	124600.00
0005435296990	6175	Business	124600.00
0005434309710	6175	Business	124600.00
0005435999222	6175	Business	124600.00
0005435487504	6175	Business	124600.00
0005435296995	6175	Economy	41500.00
0005435999218	6175	Economy	41500.00
0005435296947	6175	Economy	41500.00
0005435487533	6175	Economy	41500.00
0005434309719	6175	Economy	41500.00
0005435999234	6175	Economy	41500.00
0005434309722	6175	Economy	41500.00
0005435999221	6175	Economy	41500.00
0005434309718	6175	Economy	41500.00
0005435999219	6175	Economy	41500.00
0005435487714	6175	Economy	41500.00
0005435999224	6175	Economy	41500.00
0005435487482	6175	Economy	41500.00
0005434309714	6175	Economy	41500.00
0005435487642	6175	Economy	41500.00
0005435487621	6175	Economy	41500.00
0005434309724	6175	Economy	45700.00
0005435999228	6175	Economy	45700.00
0005435999229	6175	Economy	45700.00
0005435296960	6175	Economy	45700.00
0005435487559	6175	Economy	41500.00
0005435999233	6175	Economy	41500.00
0005435487523	6175	Economy	41500.00
0005435999232	6175	Economy	41500.00
0005435296991	6175	Economy	41500.00
0005435487534	6175	Economy	41500.00
0005435999225	6175	Economy	41500.00
0005434309716	6175	Economy	41500.00
0005435999223	6175	Economy	41500.00
0005434309720	6175	Economy	41500.00
0005434309711	6175	Economy	41500.00
0005434309723	6175	Economy	41500.00
0005434309712	6175	Economy	41500.00
0005435487671	6175	Economy	41500.00
0005434309721	6175	Economy	41500.00
0005435487643	6175	Economy	41500.00
0005435999226	6175	Economy	41500.00
0005435999220	6175	Economy	41500.00
0005435487510	6175	Economy	41500.00
0005435487609	6175	Economy	41500.00
0005435487622	6175	Economy	41500.00
0005435296954	6175	Economy	41500.00
0005435487529	6175	Economy	41500.00
0005434309717	6175	Economy	41500.00
0005435999231	6175	Economy	41500.00
0005432146195	6175	Economy	41500.00
0005435487699	6175	Economy	41500.00
0005435487700	6175	Economy	41500.00
0005435999227	6175	Economy	41500.00
0005434309715	6175	Economy	41500.00
0005435487610	6175	Economy	41500.00
0005435296996	6175	Economy	41500.00
0005435487588	6175	Economy	41500.00
0005435487503	6175	Economy	41500.00
0005435999235	6175	Economy	41500.00
0005435487649	6175	Economy	41500.00
0005435296942	6175	Economy	41500.00
0005435487636	6175	Economy	41500.00
0005435297046	19571	Business	124600.00
0005435999053	19571	Business	124600.00
0005435487777	19571	Business	124600.00
0005435999077	19571	Business	124600.00
0005435999018	19571	Business	124600.00
0005435487765	19571	Economy	41500.00
0005434309561	19571	Economy	41500.00
0005435487770	19571	Economy	41500.00
0005435297049	19571	Economy	41500.00
0005434309580	19571	Economy	41500.00
0005435487768	19571	Economy	41500.00
0005435487785	19571	Economy	41500.00
0005435487778	19571	Economy	41500.00
0005435998972	19571	Economy	41500.00
0005435999022	19571	Economy	41500.00
0005435999063	19571	Economy	41500.00
0005435487767	19571	Economy	41500.00
0005435999047	19571	Economy	41500.00
0005435999050	19571	Economy	41500.00
0005434309562	19571	Economy	41500.00
0005435999052	19571	Economy	41500.00
0005434309613	19571	Economy	41500.00
0005435999066	19571	Economy	41500.00
0005435999048	19571	Economy	45700.00
0005435297043	19571	Economy	45700.00
0005435487780	19571	Economy	45700.00
0005434309523	19571	Economy	41500.00
0005435297045	19571	Economy	41500.00
0005435999067	19571	Economy	41500.00
0005435487773	19571	Economy	41500.00
0005435999058	19571	Economy	41500.00
0005435487764	19571	Economy	41500.00
0005435487775	19571	Economy	41500.00
0005435297048	19571	Economy	41500.00
0005435487766	19571	Economy	41500.00
0005435487771	19571	Economy	41500.00
0005435487779	19571	Economy	41500.00
0005435999036	19571	Economy	41500.00
0005435999088	19571	Economy	41500.00
0005435999021	19571	Economy	41500.00
0005435999049	19571	Economy	41500.00
0005435487781	19571	Economy	41500.00
0005435999083	19571	Economy	41500.00
0005435999019	19571	Economy	41500.00
0005435487776	19571	Economy	41500.00
0005435487772	19571	Economy	41500.00
0005434309556	19571	Economy	41500.00
0005435998988	19571	Economy	41500.00
0005435999020	19571	Economy	41500.00
0005435999064	19571	Economy	41500.00
0005435999070	19571	Economy	41500.00
0005435998971	19571	Economy	41500.00
0005435999001	19571	Economy	41500.00
0005435999059	19571	Economy	41500.00
0005435487782	19571	Economy	41500.00
0005435487774	19571	Economy	41500.00
0005435487783	19571	Economy	41500.00
0005434309525	19571	Economy	41500.00
0005434309612	19571	Economy	41500.00
0005434309524	19571	Economy	41500.00
0005435487784	19571	Economy	41500.00
0005435297044	19571	Economy	41500.00
0005435487769	19571	Economy	41500.00
0005435297047	19571	Economy	41500.00
0005435502285	1553	Business	86000.00
0005435517887	1553	Business	86000.00
0005435502280	1553	Business	86000.00
0005434565896	1553	Business	86000.00
0005435502271	1553	Business	86000.00
0005435508339	1553	Business	86000.00
0005435517880	1553	Business	86000.00
0005435508342	1553	Business	86000.00
0005435502283	1553	Business	86000.00
0005434565892	1553	Business	86000.00
0005433186017	1553	Business	86000.00
0005435517878	1553	Economy	28700.00
0005432291926	1553	Economy	28700.00
0005435517889	1553	Economy	28700.00
0005435508343	1553	Economy	28700.00
0005435508344	1553	Economy	28700.00
0005434565893	1553	Economy	28700.00
0005435517888	1553	Economy	28700.00
0005435502265	1553	Economy	28700.00
0005435502284	1553	Economy	31500.00
0005434565898	1553	Economy	31500.00
0005435517895	1553	Economy	31500.00
0005435502270	1553	Economy	31500.00
0005432291927	1553	Economy	31500.00
0005435502281	1553	Economy	28700.00
0005435517890	1553	Economy	28700.00
0005435517877	1553	Economy	28700.00
0005435517875	1553	Economy	28700.00
0005434565886	1553	Economy	28700.00
0005434565890	1553	Economy	28700.00
0005435517893	1553	Economy	28700.00
0005435517885	1553	Economy	28700.00
0005435508341	1553	Economy	28700.00
0005435508337	1553	Economy	28700.00
0005435517892	1553	Economy	28700.00
0005435517876	1553	Economy	28700.00
0005435517884	1553	Economy	28700.00
0005433186020	1553	Economy	28700.00
0005432291925	1553	Economy	28700.00
0005433186024	1553	Economy	28700.00
0005435508346	1553	Economy	28700.00
0005435502273	1553	Economy	28700.00
0005435502268	1553	Economy	28700.00
0005433186022	1553	Economy	28700.00
0005435517882	1553	Economy	28700.00
0005433186019	1553	Economy	28700.00
0005435502277	1553	Economy	28700.00
0005435517874	1553	Economy	28700.00
0005434565897	1553	Economy	28700.00
0005433186023	1553	Economy	28700.00
0005435502267	1553	Economy	28700.00
0005435517894	1553	Economy	28700.00
0005434565889	1553	Economy	28700.00
0005435502276	1553	Economy	28700.00
0005435502278	1553	Economy	28700.00
0005435508348	1553	Economy	28700.00
0005435508345	1553	Economy	28700.00
0005434565885	1553	Economy	28700.00
0005435517881	1553	Economy	28700.00
0005435508347	1553	Economy	28700.00
0005434565888	1553	Economy	28700.00
0005435502275	1553	Economy	28700.00
0005435517883	1553	Economy	28700.00
0005434565891	1553	Economy	28700.00
0005435517873	1553	Economy	28700.00
0005435502266	1553	Economy	28700.00
0005435502279	1553	Economy	28700.00
0005434565895	1553	Economy	28700.00
0005435508350	1553	Economy	28700.00
0005435517886	1553	Economy	28700.00
0005435508340	1553	Economy	28700.00
0005435517879	1553	Economy	28700.00
0005435502272	1553	Economy	28700.00
0005435508338	1553	Economy	28700.00
0005435517891	1553	Economy	28700.00
0005434565894	1553	Economy	28700.00
0005435502269	1553	Economy	28700.00
0005434565887	1553	Economy	28700.00
0005435508349	1553	Economy	28700.00
0005435502282	1553	Economy	28700.00
0005435502274	1553	Economy	28700.00
0005435508351	1553	Economy	28700.00
0005435529003	20849	Business	86000.00
0005435502137	20849	Business	86000.00
0005435529032	20849	Business	86000.00
0005435545627	20849	Business	86000.00
0005433186103	20849	Business	86000.00
0005435502044	20849	Business	86000.00
0005433186105	20849	Business	86000.00
0005434565779	20849	Economy	28700.00
0005434565739	20849	Economy	28700.00
0005435502074	20849	Economy	28700.00
0005435502096	20849	Economy	28700.00
0005435529004	20849	Economy	28700.00
0005435529020	20849	Economy	28700.00
0005434565778	20849	Economy	28700.00
0005435502026	20849	Economy	28700.00
0005435502085	20849	Economy	31500.00
0005435528907	20849	Economy	31500.00
0005435529027	20849	Economy	31500.00
0005435502061	20849	Economy	31500.00
0005435502120	20849	Economy	28700.00
0005435502024	20849	Economy	28700.00
0005435502051	20849	Economy	28700.00
0005435502097	20849	Economy	28700.00
0005435502075	20849	Economy	28700.00
0005435502027	20849	Economy	28700.00
0005435529079	20849	Economy	28700.00
0005435502043	20849	Economy	28700.00
0005435545626	20849	Economy	28700.00
0005435502121	20849	Economy	28700.00
0005434565766	20849	Economy	28700.00
0005435502042	20849	Economy	28700.00
0005433186100	20849	Economy	28700.00
0005435545637	20849	Economy	28700.00
0005434565777	20849	Economy	28700.00
0005435502045	20849	Economy	28700.00
0005433186101	20849	Economy	28700.00
0005435502025	20849	Economy	28700.00
0005435529030	20849	Economy	28700.00
0005435502050	20849	Economy	28700.00
0005435502079	20849	Economy	28700.00
0005435529005	20849	Economy	28700.00
0005435502022	20849	Economy	28700.00
0005433186106	20849	Economy	28700.00
0005435501944	20849	Economy	28700.00
0005435545633	20849	Economy	28700.00
0005435529033	20849	Economy	28700.00
0005435502139	20849	Economy	28700.00
0005433186102	20849	Economy	28700.00
0005435529078	20849	Economy	28700.00
0005435528901	20849	Economy	28700.00
0005433186107	20849	Economy	28700.00
0005435502138	20849	Economy	28700.00
0005435502005	20849	Economy	28700.00
0005433186104	20849	Economy	28700.00
0005435528895	20849	Economy	28700.00
0005434565738	20849	Economy	28700.00
0005435528940	20849	Economy	28700.00
0005435502006	20849	Economy	28700.00
0005435529021	20849	Economy	28700.00
0005435545636	20849	Economy	28700.00
0005434565767	20849	Economy	28700.00
0005435153727	3872	Economy	19700.00
0005435153730	3872	Economy	19700.00
0005435931553	3872	Economy	19700.00
0005435153728	3872	Economy	19700.00
0005435931552	3872	Economy	19700.00
0005435153732	3872	Economy	19700.00
0005435931554	3872	Economy	19700.00
0005435153733	3872	Economy	19700.00
0005435153731	3872	Economy	19700.00
0005435153729	3872	Economy	19700.00
0005435153678	21863	Economy	21600.00
0005435153685	21863	Economy	19700.00
0005435153684	21863	Economy	19700.00
0005435153683	21863	Economy	19700.00
0005435153669	21863	Economy	19700.00
0005435153679	21863	Economy	19700.00
0005435931595	21863	Economy	19700.00
0005435931593	21863	Economy	19700.00
0005435153677	21863	Economy	19700.00
0005435931594	21863	Economy	19700.00
0005432628816	7224	Economy	14300.00
0005435225512	7224	Economy	13000.00
0005435225489	7224	Economy	13000.00
0005432628823	7224	Economy	13000.00
0005432628822	7224	Economy	13000.00
0005432628821	7224	Economy	13000.00
0005432628824	7224	Economy	13000.00
0005435225469	7224	Economy	13000.00
0005432628814	7224	Economy	13000.00
0005432628827	7224	Economy	13000.00
0005432628819	7224	Economy	13000.00
0005432628826	7224	Economy	13000.00
0005432628825	7224	Economy	13000.00
0005432628817	7224	Economy	13000.00
0005432628818	7224	Economy	13000.00
0005435225524	7224	Economy	13000.00
0005435225491	7224	Economy	13000.00
0005432628815	7224	Economy	13000.00
0005432628820	7224	Economy	13000.00
0005432628725	28101	Economy	14300.00
0005432628748	28101	Economy	14300.00
0005432628721	28101	Economy	14300.00
0005432628718	28101	Economy	13000.00
0005435225567	28101	Economy	13000.00
0005432628706	28101	Economy	13000.00
0005435225568	28101	Economy	13000.00
0005432628726	28101	Economy	13000.00
0005432628712	28101	Economy	13000.00
0005432628749	28101	Economy	13000.00
0005435225570	28101	Economy	13000.00
0005432628717	28101	Economy	13000.00
0005435225571	28101	Economy	13000.00
0005435225572	28101	Economy	13000.00
0005432628686	28101	Economy	13000.00
0005432628693	28101	Economy	13000.00
0005432628713	28101	Economy	13000.00
0005432628707	28101	Economy	13000.00
0005435225573	28101	Economy	13000.00
0005435225569	28101	Economy	13000.00
0005435960044	8712	Economy	10500.00
0005435960046	8712	Economy	10500.00
0005435960042	8712	Economy	10500.00
0005434267914	8712	Economy	10500.00
0005435960045	8712	Economy	10500.00
0005435960041	8712	Economy	10500.00
0005435960043	8712	Economy	10500.00
0005435960022	15238	Economy	10500.00
0005434267945	15238	Economy	10500.00
0005434267944	15238	Economy	10500.00
0005434267943	15238	Economy	10500.00
0005435959997	15238	Economy	10500.00
0005434267942	15238	Economy	10500.00
0005434267941	15238	Economy	10500.00
0005435960020	15238	Economy	10500.00
0005435959996	15238	Economy	10500.00
0005432675110	1197	Business	115000.00
0005432692991	1197	Business	115000.00
0005432692981	1197	Business	115000.00
0005432675105	1197	Business	115000.00
0005432675103	1197	Business	115000.00
0005432692987	1197	Business	115000.00
0005432692985	1197	Business	115000.00
0005432692971	1197	Business	115000.00
0005432873227	1197	Business	115000.00
0005432692993	1197	Business	115000.00
0005432692989	1197	Business	115000.00
0005432692986	1197	Business	115000.00
0005432692997	1197	Business	115000.00
0005432675100	1197	Economy	38300.00
0005432692979	1197	Economy	38300.00
0005432692974	1197	Economy	38300.00
0005432692976	1197	Economy	38300.00
0005432677560	1197	Economy	38300.00
0005432692996	1197	Economy	38300.00
0005432677561	1197	Economy	42200.00
0005432677563	1197	Economy	38300.00
0005432692984	1197	Economy	38300.00
0005432675104	1197	Economy	38300.00
0005432692975	1197	Economy	38300.00
0005432692992	1197	Economy	38300.00
0005432675099	1197	Economy	38300.00
0005432693000	1197	Economy	38300.00
0005432692983	1197	Economy	38300.00
0005432692969	1197	Economy	38300.00
0005432675109	1197	Economy	38300.00
0005432677562	1197	Economy	38300.00
0005432873192	1197	Economy	38300.00
0005432692990	1197	Economy	38300.00
0005432692982	1197	Economy	38300.00
0005432675108	1197	Economy	38300.00
0005432873225	1197	Economy	38300.00
0005432692994	1197	Economy	38300.00
0005432692970	1197	Economy	38300.00
0005432692998	1197	Economy	38300.00
0005432873229	1197	Economy	38300.00
0005432692972	1197	Economy	38300.00
0005432692988	1197	Economy	38300.00
0005432675097	1197	Economy	38300.00
0005432692995	1197	Economy	38300.00
0005432675106	1197	Economy	38300.00
0005432873193	1197	Economy	38300.00
0005432873226	1197	Economy	38300.00
0005432692978	1197	Economy	38300.00
0005432692980	1197	Economy	38300.00
0005432692999	1197	Economy	38300.00
0005432675102	1197	Economy	38300.00
0005432675098	1197	Economy	38300.00
0005432873224	1197	Economy	38300.00
0005432873222	1197	Economy	38300.00
0005432873223	1197	Economy	38300.00
0005432675107	1197	Economy	38300.00
0005432692977	1197	Economy	38300.00
0005432692973	1197	Economy	38300.00
0005432675101	1197	Economy	38300.00
0005432692808	17498	Business	115000.00
0005432873280	17498	Business	115000.00
0005432674972	17498	Business	115000.00
0005432674959	17498	Business	115000.00
0005432692626	17498	Business	115000.00
0005432873275	17498	Business	115000.00
0005432692637	17498	Business	115000.00
0005432692842	17498	Business	115000.00
0005432692653	17498	Business	115000.00
0005432674989	17498	Business	115000.00
0005432692817	17498	Economy	38300.00
0005432692688	17498	Economy	38300.00
0005432692650	17498	Economy	38300.00
0005432873276	17498	Economy	38300.00
0005432692821	17498	Economy	38300.00
0005432692731	17498	Economy	42200.00
0005432674937	17498	Economy	38300.00
0005432692710	17498	Economy	38300.00
0005432692570	17498	Economy	38300.00
0005432674936	17498	Economy	38300.00
0005432674925	17498	Economy	38300.00
0005432692880	17498	Economy	38300.00
0005432873279	17498	Economy	38300.00
0005432692841	17498	Economy	38300.00
0005432692774	17498	Economy	38300.00
0005432692649	17498	Economy	38300.00
0005432692578	17498	Economy	38300.00
0005432692809	17498	Economy	38300.00
0005432873281	17498	Economy	38300.00
0005432692750	17498	Economy	38300.00
0005432675029	17498	Economy	38300.00
0005432692621	17498	Economy	38300.00
0005432674950	17498	Economy	38300.00
0005432692740	17498	Economy	38300.00
0005432692701	17498	Economy	38300.00
0005432674949	17498	Economy	38300.00
0005432692879	17498	Economy	38300.00
0005432677530	17498	Economy	38300.00
0005432873277	17498	Economy	38300.00
0005432692620	17498	Economy	38300.00
0005432692697	17498	Economy	38300.00
0005432692703	17498	Economy	38300.00
0005432677516	17498	Economy	38300.00
0005432677515	17498	Economy	38300.00
0005432674958	17498	Economy	38300.00
0005432674982	17498	Economy	38300.00
0005432674994	17498	Economy	38300.00
0005432674993	17498	Economy	38300.00
0005432873278	17498	Economy	38300.00
0005432674971	17498	Economy	38300.00
0005432692820	17498	Economy	38300.00
0005432692696	17498	Economy	38300.00
0005432674988	17498	Economy	38300.00
0005432692670	17498	Economy	38300.00
0005433156667	1131	Economy	15200.00
0005433156659	1131	Economy	15200.00
0005434435154	1131	Economy	13900.00
0005433156663	1131	Economy	13900.00
0005434435149	1131	Economy	13900.00
0005434435153	1131	Economy	13900.00
0005433156645	1131	Economy	13900.00
0005434435156	1131	Economy	13900.00
0005434435148	1131	Economy	13900.00
0005434435145	1131	Economy	13900.00
0005434435160	1131	Economy	13900.00
0005434435151	1131	Economy	13900.00
0005433156699	1131	Economy	13900.00
0005433156679	1131	Economy	13900.00
0005434435157	1131	Economy	13900.00
0005433156700	1131	Economy	13900.00
0005434435146	1131	Economy	13900.00
0005434435155	1131	Economy	13900.00
0005434435147	1131	Economy	13900.00
0005434435159	1131	Economy	13900.00
0005434435150	1131	Economy	13900.00
0005434435158	1131	Economy	13900.00
0005433156676	1131	Economy	13900.00
0005434435152	1131	Economy	13900.00
0005434434966	17281	Economy	15200.00
0005434434944	17281	Economy	15200.00
0005433156735	17281	Economy	13900.00
0005433156731	17281	Economy	13900.00
0005433156736	17281	Economy	13900.00
0005434435044	17281	Economy	13900.00
0005434435022	17281	Economy	13900.00
0005433156730	17281	Economy	13900.00
0005433156734	17281	Economy	13900.00
0005434434965	17281	Economy	13900.00
0005434435005	17281	Economy	13900.00
0005433156732	17281	Economy	13900.00
0005434435020	17281	Economy	13900.00
0005434435073	17281	Economy	13900.00
0005433156729	17281	Economy	13900.00
0005434435021	17281	Economy	13900.00
0005434435098	17281	Economy	13900.00
0005434434964	17281	Economy	13900.00
0005434435097	17281	Economy	13900.00
0005433156738	17281	Economy	13900.00
0005433156733	17281	Economy	13900.00
0005433156737	17281	Economy	13900.00
0005435928075	4061	Economy	8200.00
0005435928078	4061	Economy	8200.00
0005435086820	4061	Economy	7500.00
0005435086816	4061	Economy	7500.00
0005435928077	4061	Economy	7500.00
0005435086823	4061	Economy	7500.00
0005435928100	4061	Economy	7500.00
0005435086817	4061	Economy	7500.00
0005435928103	4061	Economy	7500.00
0005435928076	4061	Economy	7500.00
0005435086818	4061	Economy	7500.00
0005435086821	4061	Economy	7500.00
0005435086822	4061	Economy	7500.00
0005435086819	4061	Economy	7500.00
0005435928104	4061	Economy	7500.00
0005435928079	4061	Economy	7500.00
0005435928071	4061	Economy	7500.00
0005435086757	24428	Economy	7500.00
0005435086781	24428	Economy	7500.00
0005435928134	24428	Economy	7500.00
0005435086759	24428	Economy	7500.00
0005435928135	24428	Economy	7500.00
0005435086746	24428	Economy	7500.00
0005435086782	24428	Economy	7500.00
0005435928132	24428	Economy	7500.00
0005435086768	24428	Economy	7500.00
0005435086769	24428	Economy	7500.00
0005435928133	24428	Economy	7500.00
0005432279266	1314	Business	203300.00
0005434964179	1314	Business	203300.00
0005434964193	1314	Business	203300.00
0005434964171	1314	Business	203300.00
0005434964180	1314	Business	203300.00
0005434964176	1314	Business	203300.00
0005433261449	1314	Business	203300.00
0005433261438	1314	Business	203300.00
0005434964199	1314	Economy	74500.00
0005433261461	1314	Business	203300.00
0005434964189	1314	Economy	67800.00
0005434964186	1314	Economy	67800.00
0005433261424	1314	Economy	67800.00
0005434964192	1314	Economy	67800.00
0005434964169	1314	Economy	67800.00
0005434964207	1314	Economy	67800.00
0005432279265	1314	Economy	67800.00
0005434964168	1314	Economy	67800.00
0005434964203	1314	Economy	67800.00
0005434964206	1314	Economy	67800.00
0005433261425	1314	Economy	67800.00
0005434964196	1314	Economy	67800.00
0005434964195	1314	Economy	67800.00
0005434964191	1314	Economy	67800.00
0005434964183	1314	Economy	67800.00
0005433261454	1314	Economy	67800.00
0005434964187	1314	Economy	67800.00
0005432279267	1314	Economy	67800.00
0005434964204	1314	Economy	67800.00
0005434964202	1314	Economy	67800.00
0005433261452	1314	Economy	67800.00
0005433261478	1314	Economy	67800.00
0005433261445	1314	Economy	67800.00
0005434964198	1314	Economy	67800.00
0005433261431	1314	Economy	67800.00
0005434964205	1314	Economy	67800.00
0005434964177	1314	Economy	67800.00
0005434964178	1314	Economy	67800.00
0005434964197	1314	Economy	67800.00
0005433261436	1314	Economy	67800.00
0005433261475	1314	Economy	67800.00
0005434964201	1314	Economy	67800.00
0005434964182	1314	Economy	67800.00
0005434964175	1314	Economy	67800.00
0005434964185	1314	Economy	67800.00
0005434964184	1314	Economy	67800.00
0005434964190	1314	Economy	67800.00
0005434964188	1314	Economy	67800.00
0005434964174	1314	Economy	67800.00
0005433261476	1314	Economy	67800.00
0005433261479	1314	Economy	67800.00
0005434964172	1314	Economy	67800.00
0005433261459	1314	Economy	67800.00
0005433261460	1314	Economy	67800.00
0005433261482	1314	Economy	67800.00
0005434964200	1314	Economy	67800.00
0005434964173	1314	Economy	67800.00
0005434964181	1314	Economy	67800.00
0005434964194	1314	Economy	67800.00
0005433261453	1314	Economy	67800.00
0005434964170	1314	Economy	67800.00
0005432279268	1314	Economy	67800.00
0005433261435	1314	Economy	67800.00
0005434964016	18247	Business	203300.00
0005433261534	18247	Business	203300.00
0005433261546	18247	Business	203300.00
0005433261543	18247	Business	203300.00
0005434964020	18247	Business	203300.00
0005434963976	18247	Business	203300.00
0005434964079	18247	Business	203300.00
0005434963983	18247	Economy	67800.00
0005434963896	18247	Economy	67800.00
0005434964059	18247	Economy	67800.00
0005434963960	18247	Economy	67800.00
0005433261536	18247	Economy	67800.00
0005433261542	18247	Economy	67800.00
0005434964054	18247	Economy	67800.00
0005433261540	18247	Economy	67800.00
0005434964109	18247	Economy	67800.00
0005434963951	18247	Economy	67800.00
0005434963987	18247	Economy	67800.00
0005433261538	18247	Economy	67800.00
0005434964004	18247	Economy	67800.00
0005434964024	18247	Economy	67800.00
0005434964042	18247	Economy	67800.00
0005434963953	18247	Economy	67800.00
0005434963975	18247	Economy	67800.00
0005434963943	18247	Economy	67800.00
0005434964002	18247	Economy	67800.00
0005434964025	18247	Economy	67800.00
0005433261544	18247	Economy	67800.00
0005434964035	18247	Economy	67800.00
0005433261545	18247	Economy	67800.00
0005434963985	18247	Economy	67800.00
0005434964005	18247	Economy	67800.00
0005433261550	18247	Economy	74500.00
0005433261552	18247	Economy	67800.00
0005433261548	18247	Economy	67800.00
0005434964110	18247	Economy	67800.00
0005434964021	18247	Economy	67800.00
0005433261554	18247	Economy	67800.00
0005434964009	18247	Economy	67800.00
0005434963952	18247	Economy	67800.00
0005434963959	18247	Economy	67800.00
0005433261535	18247	Economy	67800.00
0005433261537	18247	Economy	67800.00
0005433261541	18247	Economy	67800.00
0005434964034	18247	Economy	67800.00
0005434964008	18247	Economy	67800.00
0005433261551	18247	Economy	67800.00
0005434963986	18247	Economy	67800.00
0005434963972	18247	Economy	67800.00
0005434964053	18247	Economy	67800.00
0005433261549	18247	Economy	67800.00
0005433261553	18247	Economy	67800.00
0005433261539	18247	Economy	67800.00
0005433261547	18247	Economy	67800.00
0005434625940	4870	Business	44200.00
0005434625939	4870	Economy	14700.00
0005435907465	4870	Economy	14700.00
0005435907450	4870	Economy	16200.00
0005434625942	4870	Economy	14700.00
0005435907463	4870	Economy	14700.00
0005434625941	4870	Economy	14700.00
0005434625944	4870	Economy	14700.00
0005434625947	4870	Economy	14700.00
0005433194835	4870	Economy	14700.00
0005434625946	4870	Economy	14700.00
0005433194826	4870	Economy	14700.00
0005434625948	4870	Economy	14700.00
0005435907464	4870	Economy	14700.00
0005434625945	4870	Economy	14700.00
0005434625943	4870	Economy	14700.00
0005434625843	32918	Business	44200.00
0005435907496	32918	Business	44200.00
0005434625868	32918	Economy	14700.00
0005434625882	32918	Economy	14700.00
0005434625846	32918	Economy	14700.00
0005434625898	32918	Economy	14700.00
0005434625897	32918	Economy	14700.00
0005434625888	32918	Economy	14700.00
0005435907497	32918	Economy	14700.00
0005435907498	32918	Economy	14700.00
0005434625883	32918	Economy	14700.00
0005434625864	32918	Economy	14700.00
0005435907500	32918	Economy	14700.00
0005435907501	32918	Economy	14700.00
0005434625894	32918	Economy	14700.00
0005435907499	32918	Economy	14700.00
0005434625833	32918	Economy	14700.00
0005433194856	32918	Economy	14700.00
0005433194857	32918	Economy	14700.00
0005435784916	13776	Economy	3400.00
0005435784980	13776	Economy	3400.00
0005435784937	13776	Economy	3400.00
0005435784729	13776	Economy	3100.00
0005435785037	13776	Economy	3400.00
0005435785018	13776	Economy	3100.00
0005435784809	13776	Economy	3100.00
0005435784941	13776	Economy	3100.00
0005435937375	13776	Economy	3100.00
0005435937382	13776	Economy	3100.00
0005435937381	13776	Economy	3100.00
0005435784930	13776	Economy	3100.00
0005435784835	13776	Economy	3100.00
0005435784849	13776	Economy	3100.00
0005435785008	13776	Economy	3100.00
0005435784955	13776	Economy	3100.00
0005435784834	13776	Economy	3100.00
0005435784927	13776	Economy	3100.00
0005435784926	13776	Economy	3100.00
0005435784957	13776	Economy	3100.00
0005435784956	13776	Economy	3100.00
0005435937379	13776	Economy	3100.00
0005435784841	13776	Economy	3100.00
0005435784981	13776	Economy	3100.00
0005435937376	13776	Economy	3100.00
0005435784895	13776	Economy	3100.00
0005435937378	13776	Economy	3100.00
0005432195690	13776	Economy	3100.00
0005435784851	13776	Economy	3100.00
0005435784992	13776	Economy	3100.00
0005435784847	13776	Economy	3100.00
0005435937380	13776	Economy	3100.00
0005432195689	13776	Economy	3100.00
0005435784819	13776	Economy	3100.00
0005435785017	13776	Economy	3100.00
0005435784929	13776	Economy	3100.00
0005435785009	13776	Economy	3100.00
0005435784852	13776	Economy	3100.00
0005435785027	13776	Economy	3100.00
0005435785010	13776	Economy	3100.00
0005435784938	13776	Economy	3100.00
0005435784940	13776	Economy	3100.00
0005432195691	13776	Economy	3100.00
0005432195688	13776	Economy	3100.00
0005435784871	13776	Economy	3100.00
0005435937377	13776	Economy	3100.00
0005435784848	13776	Economy	3100.00
0005435785036	13776	Economy	3100.00
0005435785223	27402	Economy	3400.00
0005435785247	27402	Economy	3400.00
0005435785235	27402	Economy	3400.00
0005435785232	27402	Economy	3400.00
0005432190616	27402	Economy	3100.00
0005435785228	27402	Economy	3100.00
0005435785233	27402	Economy	3100.00
0005435785250	27402	Economy	3100.00
0005432190618	27402	Economy	3100.00
0005435937318	27402	Economy	3100.00
0005435785254	27402	Economy	3100.00
0005432190615	27402	Economy	3100.00
0005435785242	27402	Economy	3100.00
0005435785231	27402	Economy	3100.00
0005435785237	27402	Economy	3100.00
0005432190617	27402	Economy	3100.00
0005435785256	27402	Economy	3100.00
0005435785251	27402	Economy	3100.00
0005435785224	27402	Economy	3100.00
0005435785226	27402	Economy	3100.00
0005435785246	27402	Economy	3100.00
0005435785248	27402	Economy	3100.00
0005435785227	27402	Economy	3100.00
0005435785244	27402	Economy	3100.00
0005435785258	27402	Economy	3100.00
0005435787346	27402	Economy	3100.00
0005435785243	27402	Economy	3100.00
0005435785253	27402	Economy	3100.00
0005435937328	27402	Economy	3100.00
0005435785225	27402	Economy	3100.00
0005435787348	27402	Economy	3100.00
0005435785241	27402	Economy	3100.00
0005435785238	27402	Economy	3100.00
0005435785236	27402	Economy	3100.00
0005435785252	27402	Economy	3100.00
0005435785234	27402	Economy	3100.00
0005435785245	27402	Economy	3100.00
0005435785255	27402	Economy	3100.00
0005435787347	27402	Economy	3100.00
0005435785240	27402	Economy	3100.00
0005435785257	27402	Economy	3100.00
0005435785229	27402	Economy	3100.00
0005435785249	27402	Economy	3100.00
0005435785239	27402	Economy	3100.00
0005435785230	27402	Economy	3100.00
0005434407063	20299	Business	12000.00
0005434407223	20299	Business	12000.00
0005435311050	20299	Business	12000.00
0005435311038	20299	Business	12000.00
0005434406951	20299	Business	12000.00
0005434407296	20299	Business	12000.00
0005434406960	20299	Business	12000.00
0005435311043	20299	Business	12000.00
0005434406796	20299	Business	12000.00
0005435311036	20299	Business	12000.00
0005434406999	20299	Business	12000.00
0005434407135	20299	Economy	4000.00
0005434407174	20299	Economy	4000.00
0005434406952	20299	Economy	4000.00
0005434406991	20299	Economy	4000.00
0005434407122	20299	Economy	4000.00
0005434407226	20299	Economy	4000.00
0005434407054	20299	Economy	4000.00
0005434407086	20299	Economy	4000.00
0005435311048	20299	Economy	4000.00
0005434407243	20299	Economy	4400.00
0005434407090	20299	Economy	4400.00
0005434407099	20299	Economy	4400.00
0005434407100	20299	Economy	4400.00
0005434406908	20299	Economy	4400.00
0005434407376	20299	Economy	4000.00
0005434406827	20299	Economy	4000.00
0005432058372	20299	Economy	4000.00
0005434407225	20299	Economy	4000.00
0005434407150	20299	Economy	4000.00
0005434407126	20299	Economy	4000.00
0005435311037	20299	Economy	4000.00
0005432058374	20299	Economy	4000.00
0005434407240	20299	Economy	4000.00
0005434407248	20299	Economy	4000.00
0005434407337	20299	Economy	4000.00
0005435311049	20299	Economy	4000.00
0005434407344	20299	Economy	4000.00
0005434407000	20299	Economy	4000.00
0005434407055	20299	Economy	4000.00
0005434406933	20299	Economy	4000.00
0005434407151	20299	Economy	4000.00
0005435311041	20299	Economy	4000.00
0005435311039	20299	Economy	4000.00
0005434407029	20299	Economy	4000.00
0005432058373	20299	Economy	4000.00
0005435311040	20299	Economy	4000.00
0005435311047	20299	Economy	4000.00
0005434407249	20299	Economy	4000.00
0005434407114	20299	Economy	4000.00
0005434406961	20299	Economy	4000.00
0005434407247	20299	Economy	4000.00
0005435311046	20299	Economy	4000.00
0005434406962	20299	Economy	4000.00
0005434407115	20299	Economy	4000.00
0005434407173	20299	Economy	4000.00
0005435311044	20299	Economy	4000.00
0005434407216	20299	Economy	4000.00
0005434407224	20299	Economy	4000.00
0005434407153	20299	Economy	4000.00
0005435311042	20299	Economy	4000.00
0005434407136	20299	Economy	4000.00
0005434406969	20299	Economy	4000.00
0005435311051	20299	Economy	4000.00
0005434407037	20299	Economy	4000.00
0005434406795	20299	Economy	4000.00
0005434406919	20299	Economy	4000.00
0005434407154	20299	Economy	4000.00
0005434406998	20299	Economy	4000.00
0005434407089	20299	Economy	4000.00
0005434407242	20299	Economy	4000.00
0005434406918	20299	Economy	4000.00
0005434406958	20299	Economy	4000.00
0005434407036	20299	Economy	4000.00
0005434407026	20299	Economy	4000.00
0005434407011	20299	Economy	4000.00
0005435311045	20299	Economy	4000.00
0005432058375	20299	Economy	4000.00
0005434407097	20299	Economy	4000.00
0005434407081	20299	Economy	4000.00
0005434407007	20299	Economy	4000.00
0005434407152	20299	Economy	4000.00
0005434407113	20299	Economy	4000.00
0005434407613	26970	Business	12000.00
0005435310895	26970	Business	12000.00
0005434407609	26970	Business	12000.00
0005434407652	26970	Business	12000.00
0005434407661	26970	Business	12000.00
0005434407660	26970	Business	12000.00
0005434407647	26970	Business	12000.00
0005434407623	26970	Business	12000.00
0005434407621	26970	Business	12000.00
0005434407656	26970	Business	12000.00
0005434407666	26970	Business	12000.00
0005434407663	26970	Economy	4000.00
0005434407622	26970	Economy	4000.00
0005434407634	26970	Economy	4000.00
0005434407648	26970	Economy	4000.00
0005434407620	26970	Economy	4000.00
0005434407654	26970	Economy	4000.00
0005434407664	26970	Economy	4000.00
0005434407651	26970	Economy	4400.00
0005434407644	26970	Economy	4400.00
0005434407640	26970	Economy	4400.00
0005434407670	26970	Economy	4400.00
0005435310923	26970	Economy	4400.00
0005434407610	26970	Economy	4000.00
0005432153924	26970	Economy	4000.00
0005435310865	26970	Economy	4000.00
0005434407669	26970	Economy	4000.00
0005434407639	26970	Economy	4000.00
0005434407632	26970	Economy	4000.00
0005434407637	26970	Economy	4000.00
0005434407617	26970	Economy	4000.00
0005434407614	26970	Economy	4000.00
0005434407641	26970	Economy	4000.00
0005434407650	26970	Economy	4000.00
0005434407659	26970	Economy	4000.00
0005434407625	26970	Economy	4000.00
0005434407665	26970	Economy	4000.00
0005434407607	26970	Economy	4000.00
0005434407611	26970	Economy	4000.00
0005435310916	26970	Economy	4000.00
0005434407624	26970	Economy	4000.00
0005434407635	26970	Economy	4000.00
0005432153927	26970	Economy	4000.00
0005434407615	26970	Economy	4000.00
0005434407658	26970	Economy	4000.00
0005435310907	26970	Economy	4000.00
0005435310918	26970	Economy	4000.00
0005434407630	26970	Economy	4000.00
0005434407667	26970	Economy	4000.00
0005435310925	26970	Economy	4000.00
0005434407671	26970	Economy	4000.00
0005434407636	26970	Economy	4000.00
0005432153922	26970	Economy	4000.00
0005434407616	26970	Economy	4000.00
0005434407629	26970	Economy	4000.00
0005435310915	26970	Economy	4000.00
0005434407649	26970	Economy	4000.00
0005434407618	26970	Economy	4000.00
0005432153926	26970	Economy	4000.00
0005434407646	26970	Economy	4000.00
0005432153921	26970	Economy	4000.00
0005434407662	26970	Economy	4000.00
0005434407642	26970	Economy	4000.00
0005434407657	26970	Economy	4000.00
0005434407631	26970	Economy	4000.00
0005434407627	26970	Economy	4000.00
0005434407628	26970	Economy	4000.00
0005434407606	26970	Economy	4000.00
0005432153925	26970	Economy	4000.00
0005434407655	26970	Economy	4000.00
0005434407626	26970	Economy	4000.00
0005434407643	26970	Economy	4000.00
0005435310930	26970	Economy	4000.00
0005434407633	26970	Economy	4000.00
0005435310864	26970	Economy	4000.00
0005434407653	26970	Economy	4000.00
0005435310929	26970	Economy	4000.00
0005434407668	26970	Economy	4000.00
0005432153923	26970	Economy	4000.00
0005434407608	26970	Economy	4000.00
0005434407638	26970	Economy	4000.00
0005434407645	26970	Economy	4000.00
0005434407619	26970	Economy	4000.00
0005434407612	26970	Economy	4000.00
0005433123714	5701	Business	43300.00
0005433123789	5701	Business	43300.00
0005434319376	5701	Business	43300.00
0005433123692	5701	Business	43300.00
0005433123590	5701	Business	43300.00
0005434319370	5701	Business	43300.00
0005433123591	5701	Business	43300.00
0005434319377	5701	Economy	14400.00
0005432109697	5701	Economy	14400.00
0005433123721	5701	Economy	14400.00
0005433123689	5701	Economy	14400.00
0005433123785	5701	Economy	14400.00
0005433123702	5701	Economy	15900.00
0005433123720	5701	Economy	14400.00
0005433123596	5701	Economy	14400.00
0005433123790	5701	Economy	14400.00
0005432109699	5701	Economy	14400.00
0005434319382	5701	Economy	14400.00
0005434319365	5701	Economy	14400.00
0005434319381	5701	Economy	14400.00
0005432109698	5701	Economy	14400.00
0005434319378	5701	Economy	14400.00
0005434319366	5701	Economy	14400.00
0005433123663	5701	Economy	14400.00
0005434319371	5701	Economy	14400.00
0005434311214	5701	Economy	14400.00
0005434319367	5701	Economy	14400.00
0005434319373	5701	Economy	14400.00
0005434319375	5701	Economy	14400.00
0005434319364	5701	Economy	14400.00
0005434319374	5701	Economy	14400.00
0005433123656	5701	Economy	14400.00
0005433123761	5701	Economy	14400.00
0005433123577	5701	Economy	14400.00
0005434319368	5701	Economy	14400.00
0005434319383	5701	Economy	14400.00
0005434311215	5701	Economy	14400.00
0005434319380	5701	Economy	14400.00
0005434319372	5701	Economy	14400.00
0005434319369	5701	Economy	14400.00
0005433123694	5701	Economy	14400.00
0005434319379	5701	Economy	14400.00
0005434319151	15651	Business	43300.00
0005433123892	15651	Business	43300.00
0005434319251	15651	Business	43300.00
0005433123903	15651	Economy	14400.00
0005433123898	15651	Economy	14400.00
0005434312298	15651	Economy	14400.00
0005433123910	15651	Economy	14400.00
0005433123890	15651	Economy	14400.00
0005434319271	15651	Economy	14400.00
0005433123900	15651	Economy	15900.00
0005434319230	15651	Economy	15900.00
0005433123895	15651	Economy	14400.00
0005433123906	15651	Economy	14400.00
0005433123897	15651	Economy	14400.00
0005433123899	15651	Economy	14400.00
0005433123894	15651	Economy	14400.00
0005433123907	15651	Economy	14400.00
0005434319270	15651	Economy	14400.00
0005433123888	15651	Economy	14400.00
0005434319226	15651	Economy	14400.00
0005433123905	15651	Economy	14400.00
0005434319229	15651	Economy	14400.00
0005433123902	15651	Economy	14400.00
0005434319225	15651	Economy	14400.00
0005434319241	15651	Economy	14400.00
0005433123891	15651	Economy	14400.00
0005433123908	15651	Economy	14400.00
0005434319272	15651	Economy	14400.00
0005433123909	15651	Economy	14400.00
0005433123896	15651	Economy	14400.00
0005434311191	15651	Economy	14400.00
0005434312296	15651	Economy	14400.00
0005433123889	15651	Economy	14400.00
0005433123893	15651	Economy	14400.00
0005434319211	15651	Economy	14400.00
0005433123901	15651	Economy	14400.00
0005433123904	15651	Economy	14400.00
0005434319256	15651	Economy	14400.00
0005435217685	24980	Economy	15500.00
0005435221502	24980	Economy	15500.00
0005435220286	24980	Economy	15500.00
0005435220288	24980	Economy	15500.00
0005435220287	24980	Economy	15500.00
0005435220295	24980	Economy	15500.00
0005435221503	24980	Economy	15500.00
0005435221501	24980	Economy	15500.00
0005434189136	9013	Economy	24900.00
0005434484336	9013	Economy	24900.00
0005434189135	9013	Economy	24900.00
0005434484333	9013	Economy	24900.00
0005434484337	9013	Economy	24900.00
0005434484332	9013	Economy	24900.00
0005434484338	9013	Economy	24900.00
0005434484334	9013	Economy	24900.00
0005434189109	9013	Economy	24900.00
0005434484335	9013	Economy	24900.00
0005434484277	16624	Economy	27400.00
0005434484284	16624	Economy	24900.00
0005434189169	16624	Economy	24900.00
0005434189166	16624	Economy	24900.00
0005434484292	16624	Economy	24900.00
0005434484283	16624	Economy	24900.00
0005434189165	16624	Economy	24900.00
0005434189168	16624	Economy	24900.00
0005434484293	16624	Economy	24900.00
0005434189167	16624	Economy	24900.00
0005433123909	7581	Business	11100.00
0005433123903	7581	Business	11100.00
0005433123898	7581	Business	11100.00
0005433123910	7581	Business	11100.00
0005433123908	7581	Economy	3700.00
0005433123899	7581	Economy	3700.00
0005433123905	7581	Economy	3700.00
0005433123893	7581	Economy	3700.00
0005433722139	7581	Economy	3700.00
0005433123894	7581	Economy	3700.00
0005433722138	7581	Economy	3700.00
0005433123888	7581	Economy	3700.00
0005433123889	7581	Economy	3700.00
0005433123897	7581	Economy	3700.00
0005433123895	7581	Economy	3700.00
0005433123896	7581	Economy	3700.00
0005433123901	7581	Economy	3700.00
0005433123907	7581	Economy	3700.00
0005433123891	7581	Economy	3700.00
0005433722122	7581	Economy	3700.00
0005433123904	7581	Economy	3700.00
0005433123906	7581	Economy	3700.00
0005433722135	7581	Economy	3700.00
0005433722134	7581	Economy	3700.00
0005433722132	7581	Economy	3700.00
0005433123900	7581	Economy	3700.00
0005433722133	7581	Economy	3700.00
0005433123892	7581	Economy	3700.00
0005433722102	7581	Economy	3700.00
0005433123890	7581	Economy	3700.00
0005433123902	7581	Economy	3700.00
0005432693015	7578	Business	11100.00
0005432693029	7578	Business	11100.00
0005432693028	7578	Business	11100.00
0005432720850	7578	Business	11100.00
0005432693031	7578	Business	11100.00
0005432071567	7578	Business	11100.00
0005432720843	7578	Business	11100.00
0005433449932	7578	Business	11100.00
0005433449927	7578	Business	11100.00
0005432693019	7578	Business	11100.00
0005433449930	7578	Business	11100.00
0005432720841	7578	Economy	3700.00
0005433449929	7578	Economy	3700.00
0005432720846	7578	Economy	3700.00
0005432693006	7578	Economy	3700.00
0005433449918	7578	Economy	3700.00
0005432720859	7578	Economy	3700.00
0005433449935	7578	Economy	3700.00
0005433449923	7578	Economy	3700.00
0005432693023	7578	Economy	4100.00
0005433449926	7578	Economy	4100.00
0005432720848	7578	Economy	4100.00
0005433449921	7578	Economy	4100.00
0005432693010	7578	Economy	3700.00
0005433449928	7578	Economy	3700.00
0005432720849	7578	Economy	3700.00
0005432693024	7578	Economy	3700.00
0005432720842	7578	Economy	3700.00
0005432720853	7578	Economy	3700.00
0005432720863	7578	Economy	3700.00
0005432693016	7578	Economy	3700.00
0005432720864	7578	Economy	3700.00
0005432693030	7578	Economy	3700.00
0005432693009	7578	Economy	3700.00
0005433449933	7578	Economy	3700.00
0005433449931	7578	Economy	3700.00
0005432720852	7578	Economy	3700.00
0005432693012	7578	Economy	3700.00
0005432693004	7578	Economy	3700.00
0005432693003	7578	Economy	3700.00
0005432693007	7578	Economy	3700.00
0005432693014	7578	Economy	3700.00
0005433449925	7578	Economy	3700.00
0005432693005	7578	Economy	3700.00
0005432693020	7578	Economy	3700.00
0005433449936	7578	Economy	3700.00
0005433449937	7578	Economy	3700.00
0005432720857	7578	Economy	3700.00
0005432720856	7578	Economy	3700.00
0005432720865	7578	Economy	3700.00
0005432720847	7578	Economy	3700.00
0005432720845	7578	Economy	3700.00
0005432693026	7578	Economy	3700.00
0005432720861	7578	Economy	3700.00
0005433449939	7578	Economy	3700.00
0005432720858	7578	Economy	3700.00
0005432693022	7578	Economy	3700.00
0005432720851	7578	Economy	3700.00
0005432720866	7578	Economy	3700.00
0005432720855	7578	Economy	3700.00
0005432693002	7578	Economy	3700.00
0005432693027	7578	Economy	3700.00
0005432693018	7578	Economy	3700.00
0005432071568	7578	Economy	3700.00
0005432693021	7578	Economy	3700.00
0005432720862	7578	Economy	3700.00
0005432693017	7578	Economy	3700.00
0005432720854	7578	Economy	3700.00
0005433449920	7578	Economy	3700.00
0005432693001	7578	Economy	3700.00
0005432693011	7578	Economy	3700.00
0005432693025	7578	Economy	3700.00
0005432693008	7578	Economy	3700.00
0005433449922	7578	Economy	3700.00
0005433449924	7578	Economy	3700.00
0005433449940	7578	Economy	3700.00
0005432720860	7578	Economy	3700.00
0005433449938	7578	Economy	3700.00
0005432071566	7578	Economy	3700.00
0005432693013	7578	Economy	3700.00
0005432720840	7578	Economy	3700.00
0005433449934	7578	Economy	3700.00
0005433449919	7578	Economy	3700.00
0005432720844	7578	Economy	3700.00
0005432692653	30323	Business	11100.00
0005432692688	30323	Business	11100.00
0005433449728	30323	Business	11100.00
0005432692697	30323	Business	11100.00
0005432692731	30323	Business	11100.00
0005433449729	30323	Economy	3700.00
0005432692880	30323	Economy	3700.00
0005433449768	30323	Economy	3700.00
0005433449609	30323	Economy	3700.00
0005432692620	30323	Economy	3700.00
0005432692670	30323	Economy	3700.00
0005432692750	30323	Economy	4100.00
0005432692821	30323	Economy	4100.00
0005432692696	30323	Economy	4100.00
0005432692703	30323	Economy	4100.00
0005432692879	30323	Economy	3700.00
0005432692626	30323	Economy	3700.00
0005432692570	30323	Economy	3700.00
0005433449748	30323	Economy	3700.00
0005432692774	30323	Economy	3700.00
0005433449635	30323	Economy	3700.00
0005433449619	30323	Economy	3700.00
0005432692701	30323	Economy	3700.00
0005432692621	30323	Economy	3700.00
0005433449733	30323	Economy	3700.00
0005433449747	30323	Economy	3700.00
0005432692809	30323	Economy	3700.00
0005433449754	30323	Economy	3700.00
0005433449637	30323	Economy	3700.00
0005432692740	30323	Economy	3700.00
0005433449777	30323	Economy	3700.00
0005433449770	30323	Economy	3700.00
0005432692817	30323	Economy	3700.00
0005432692820	30323	Economy	3700.00
0005433449844	30323	Economy	3700.00
0005432692649	30323	Economy	3700.00
0005433449683	30323	Economy	3700.00
0005433449634	30323	Economy	3700.00
0005432692841	30323	Economy	3700.00
0005432692710	30323	Economy	3700.00
0005433449794	30323	Economy	3700.00
0005433449758	30323	Economy	3700.00
0005432692842	30323	Economy	3700.00
0005433449769	30323	Economy	3700.00
0005432692578	30323	Economy	3700.00
0005432692637	30323	Economy	3700.00
0005432692808	30323	Economy	3700.00
0005433449797	30323	Economy	3700.00
0005432692650	30323	Economy	3700.00
0005433449618	30323	Economy	3700.00
0005433449753	30323	Economy	3700.00
0005433449636	30323	Economy	3700.00
0005432720494	30322	Business	11100.00
0005432720599	30322	Business	11100.00
0005433123702	30322	Business	11100.00
0005433123694	30322	Business	11100.00
0005433123689	30322	Business	11100.00
0005433722213	30322	Business	11100.00
0005433123714	30322	Business	11100.00
0005433123721	30322	Economy	3700.00
0005433123785	30322	Economy	3700.00
0005432720600	30322	Economy	3700.00
0005433722216	30322	Economy	3700.00
0005433123789	30322	Economy	4100.00
0005432720559	30322	Economy	4100.00
0005432720668	30322	Economy	4100.00
0005432720689	30322	Economy	3700.00
0005432720703	30322	Economy	3700.00
0005432720704	30322	Economy	3700.00
0005433123596	30322	Economy	3700.00
0005432720637	30322	Economy	3700.00
0005433123761	30322	Economy	3700.00
0005433123720	30322	Economy	3700.00
0005432720733	30322	Economy	3700.00
0005433722209	30322	Economy	3700.00
0005433123591	30322	Economy	3700.00
0005433722210	30322	Economy	3700.00
0005432720687	30322	Economy	3700.00
0005432720558	30322	Economy	3700.00
0005432720656	30322	Economy	3700.00
0005433722215	30322	Economy	3700.00
0005432720688	30322	Economy	3700.00
0005432720621	30322	Economy	3700.00
0005432720582	30322	Economy	3700.00
0005433722212	30322	Economy	3700.00
0005432720620	30322	Economy	3700.00
0005432720666	30322	Economy	3700.00
0005433123692	30322	Economy	3700.00
0005433123577	30322	Economy	3700.00
0005432720601	30322	Economy	3700.00
0005432720732	30322	Economy	3700.00
0005432720724	30322	Economy	3700.00
0005433123656	30322	Economy	3700.00
0005433123590	30322	Economy	3700.00
0005433123790	30322	Economy	3700.00
0005432720539	30322	Economy	3700.00
0005433722211	30322	Economy	3700.00
0005432720655	30322	Economy	3700.00
0005432720560	30322	Economy	3700.00
0005433123663	30322	Economy	3700.00
0005433722214	30322	Economy	3700.00
0005432720710	30322	Economy	3700.00
0005433724796	1372	Business	70400.00
0005433192884	1372	Business	70400.00
0005434514962	1372	Business	70400.00
0005433724800	1372	Business	70400.00
0005434586552	1372	Business	70400.00
0005434586560	1372	Business	70400.00
0005433192885	1372	Business	70400.00
0005434586563	1372	Economy	23500.00
0005434514964	1372	Economy	23500.00
0005434586564	1372	Economy	23500.00
0005433192901	1372	Economy	23500.00
0005434586553	1372	Economy	23500.00
0005434586576	1372	Economy	23500.00
0005433525020	1372	Economy	25800.00
0005433724797	1372	Economy	25800.00
0005432968812	1372	Economy	25800.00
0005433525019	1372	Economy	25800.00
0005432270997	1372	Economy	25800.00
0005433192914	1372	Economy	23500.00
0005434514963	1372	Economy	23500.00
0005434586577	1372	Economy	23500.00
0005433724799	1372	Economy	23500.00
0005432927935	1372	Economy	23500.00
0005432270999	1372	Economy	23500.00
0005434586562	1372	Economy	23500.00
0005432927921	1372	Economy	23500.00
0005434586561	1372	Economy	23500.00
0005434586556	1372	Economy	23500.00
0005433192907	1372	Economy	23500.00
0005434513574	1372	Economy	23500.00
0005433525015	1372	Economy	23500.00
0005434586566	1372	Economy	23500.00
0005433192915	1372	Economy	23500.00
0005434586575	1372	Economy	23500.00
0005433525021	1372	Economy	23500.00
0005434586555	1372	Economy	23500.00
0005434586567	1372	Economy	23500.00
0005432270998	1372	Economy	23500.00
0005433192977	1372	Economy	23500.00
0005434586565	1372	Economy	23500.00
0005433192931	1372	Economy	23500.00
0005433192911	1372	Economy	23500.00
0005433724798	1372	Economy	23500.00
0005434586559	1372	Economy	23500.00
0005432927932	1372	Economy	23500.00
0005434586558	1372	Economy	23500.00
0005433192986	1372	Economy	23500.00
0005433192948	1372	Economy	23500.00
0005433192947	1372	Economy	23500.00
0005433192930	1372	Economy	23500.00
0005433192928	1372	Economy	23500.00
0005434586557	1372	Economy	23500.00
0005434586572	1372	Economy	23500.00
0005434586574	1372	Economy	23500.00
0005434586571	1372	Economy	23500.00
0005434586570	1372	Economy	23500.00
0005432927931	1372	Economy	23500.00
0005433525017	1372	Economy	23500.00
0005433525016	1372	Economy	23500.00
0005434586569	1372	Economy	23500.00
0005433192985	1372	Economy	23500.00
0005434586568	1372	Economy	23500.00
0005433192906	1372	Economy	23500.00
0005434586573	1372	Economy	23500.00
0005433525023	1372	Economy	23500.00
0005433724801	1372	Economy	23500.00
0005433525022	1372	Economy	23500.00
0005433525014	1372	Economy	23500.00
0005434586554	1372	Economy	23500.00
0005433525018	1372	Economy	23500.00
0005432968810	1372	Economy	23500.00
0005433192929	1372	Economy	23500.00
0005433192913	1372	Economy	23500.00
0005434513575	1372	Economy	23500.00
0005434586419	18503	Business	70400.00
0005432927971	18503	Business	70400.00
0005434586379	18503	Business	70400.00
0005433193016	18503	Business	70400.00
0005434586392	18503	Business	70400.00
0005433193022	18503	Business	70400.00
0005434586471	18503	Business	70400.00
0005434586477	18503	Business	70400.00
0005433524888	18503	Business	70400.00
0005433524924	18503	Business	70400.00
0005433193023	18503	Economy	23500.00
0005434586279	18503	Economy	23500.00
0005433193014	18503	Economy	23500.00
0005433724746	18503	Economy	23500.00
0005434586346	18503	Economy	23500.00
0005432927970	18503	Economy	23500.00
0005432968836	18503	Economy	23500.00
0005433724781	18503	Economy	23500.00
0005432927968	18503	Economy	25800.00
0005433724744	18503	Economy	25800.00
0005433524923	18503	Economy	25800.00
0005432927969	18503	Economy	25800.00
0005434586182	18503	Economy	23500.00
0005433524916	18503	Economy	23500.00
0005433524911	18503	Economy	23500.00
0005433524938	18503	Economy	23500.00
0005433724767	18503	Economy	23500.00
0005433524932	18503	Economy	23500.00
0005434586394	18503	Economy	23500.00
0005434586393	18503	Economy	23500.00
0005432927967	18503	Economy	23500.00
0005433724745	18503	Economy	23500.00
0005433193026	18503	Economy	23500.00
0005434586239	18503	Economy	23500.00
0005433724761	18503	Economy	23500.00
0005434586287	18503	Economy	23500.00
0005433193019	18503	Economy	23500.00
0005434586371	18503	Economy	23500.00
0005433524915	18503	Economy	23500.00
0005433193027	18503	Economy	23500.00
0005432927966	18503	Economy	23500.00
0005432968834	18503	Economy	23500.00
0005434586325	18503	Economy	23500.00
0005434586397	18503	Economy	23500.00
0005433524910	18503	Economy	23500.00
0005433724766	18503	Economy	23500.00
0005434586312	18503	Economy	23500.00
0005434586300	18503	Economy	23500.00
0005434586364	18503	Economy	23500.00
0005432968835	18503	Economy	23500.00
0005434586240	18503	Economy	23500.00
0005433524937	18503	Economy	23500.00
0005433193020	18503	Economy	23500.00
0005433193017	18503	Economy	23500.00
0005433524889	18503	Economy	23500.00
0005433193021	18503	Economy	23500.00
0005433524887	18503	Economy	23500.00
0005434586303	18503	Economy	23500.00
0005434586378	18503	Economy	23500.00
0005433524914	18503	Economy	23500.00
0005433524929	18503	Economy	23500.00
0005433193024	18503	Economy	23500.00
0005434586352	18503	Economy	23500.00
0005433724762	18503	Economy	23500.00
0005433193018	18503	Economy	23500.00
0005433193015	18503	Economy	23500.00
0005433193025	18503	Economy	23500.00
0005434586411	18503	Economy	23500.00
0005434586315	18503	Economy	23500.00
0005434586286	18503	Economy	23500.00
0005434586262	18503	Economy	23500.00
0005434586336	18503	Economy	23500.00
0005434586420	18503	Economy	23500.00
0005434344103	11443	Economy	4300.00
0005434344107	11443	Economy	4300.00
0005434344114	11443	Economy	4300.00
0005434344113	11443	Economy	4300.00
0005434344110	11443	Economy	4000.00
0005434344122	11443	Economy	4000.00
0005434344118	11443	Economy	4000.00
0005434344131	11443	Economy	4000.00
0005434344104	11443	Economy	4000.00
0005434344126	11443	Economy	4000.00
0005434344119	11443	Economy	4000.00
0005435302139	11443	Economy	4000.00
0005434344102	11443	Economy	4000.00
0005434344127	11443	Economy	4000.00
0005435302149	11443	Economy	4000.00
0005434344099	11443	Economy	4000.00
0005434344106	11443	Economy	4000.00
0005435302161	11443	Economy	4000.00
0005434344124	11443	Economy	4000.00
0005434344108	11443	Economy	4000.00
0005434344120	11443	Economy	4000.00
0005434344129	11443	Economy	4000.00
0005434142603	11443	Economy	4000.00
0005435302141	11443	Economy	4000.00
0005434344116	11443	Economy	4000.00
0005434344134	11443	Economy	4000.00
0005435302140	11443	Economy	4000.00
0005434344101	11443	Economy	4000.00
0005434344133	11443	Economy	4000.00
0005434344109	11443	Economy	4000.00
0005434344123	11443	Economy	4000.00
0005434344130	11443	Economy	4000.00
0005434344121	11443	Economy	4000.00
0005435302137	11443	Economy	4000.00
0005435302162	11443	Economy	4000.00
0005434344125	11443	Economy	4000.00
0005434344117	11443	Economy	4000.00
0005435302163	11443	Economy	4000.00
0005434344105	11443	Economy	4000.00
0005434344111	11443	Economy	4000.00
0005434344112	11443	Economy	4000.00
0005434344132	11443	Economy	4000.00
0005434344128	11443	Economy	4000.00
0005434344115	11443	Economy	4000.00
0005434344100	11443	Economy	4000.00
0005434344135	11443	Economy	4000.00
0005435302152	11443	Economy	4000.00
0005434142604	11443	Economy	4000.00
0005434343769	29791	Economy	4300.00
0005434343753	29791	Economy	4300.00
0005434343666	29791	Economy	4300.00
0005434343892	29791	Economy	4300.00
0005434343795	29791	Economy	4000.00
0005434343812	29791	Economy	4000.00
0005434142555	29791	Economy	4000.00
0005435304148	29791	Economy	4000.00
0005434343793	29791	Economy	4000.00
0005434343803	29791	Economy	4000.00
0005434343838	29791	Economy	4000.00
0005434142560	29791	Economy	4000.00
0005434142558	29791	Economy	4000.00
0005435304149	29791	Economy	4000.00
0005434142559	29791	Economy	4000.00
0005434343722	29791	Economy	4000.00
0005434343770	29791	Economy	4000.00
0005434142567	29791	Economy	4000.00
0005434343813	29791	Economy	4000.00
0005434343651	29791	Economy	4000.00
0005434343894	29791	Economy	4000.00
0005435304154	29791	Economy	4000.00
0005434343893	29791	Economy	4000.00
0005434343802	29791	Economy	4000.00
0005434343688	29791	Economy	4000.00
0005434343840	29791	Economy	4000.00
0005434142576	29791	Economy	4000.00
0005434142563	29791	Economy	4000.00
0005434343756	29791	Economy	4000.00
0005434343909	29791	Economy	4000.00
0005434343689	29791	Economy	4000.00
0005434343910	29791	Economy	4000.00
0005434343821	29791	Economy	4000.00
0005434142570	29791	Economy	4000.00
0005435304153	29791	Economy	4000.00
0005434142564	29791	Economy	4000.00
0005435304152	29791	Economy	4000.00
0005434343768	29791	Economy	4000.00
0005435304150	29791	Economy	4000.00
0005434343794	29791	Economy	4000.00
0005434142554	29791	Economy	4000.00
0005434343904	29791	Economy	4000.00
0005435304151	29791	Economy	4000.00
0005434343906	29791	Economy	4000.00
0005434343667	29791	Economy	4000.00
0005434142562	29791	Economy	4000.00
0005434142569	29791	Economy	4000.00
0005434343866	29791	Economy	4000.00
0005435824575	1262	Business	199800.00
0005435824578	1262	Business	199800.00
0005435824576	1262	Business	199800.00
0005433415501	1262	Business	199800.00
0005435824584	1262	Business	199800.00
0005435824564	1262	Business	199800.00
0005435824582	1262	Business	199800.00
0005433415519	1262	Business	199800.00
0005435824577	1262	Business	199800.00
0005433415520	1262	Business	199800.00
0005432284551	1262	Economy	66600.00
0005435824566	1262	Economy	66600.00
0005435824569	1262	Economy	66600.00
0005433415522	1262	Economy	66600.00
0005433415502	1262	Economy	73200.00
0005435824572	1262	Economy	73200.00
0005435824573	1262	Economy	66600.00
0005433415475	1262	Economy	66600.00
0005435824581	1262	Economy	66600.00
0005435824563	1262	Economy	66600.00
0005435824565	1262	Economy	66600.00
0005433415542	1262	Economy	66600.00
0005435824588	1262	Economy	66600.00
0005433415498	1262	Economy	66600.00
0005433415512	1262	Economy	66600.00
0005435824590	1262	Economy	66600.00
0005435824574	1262	Economy	66600.00
0005435824589	1262	Economy	66600.00
0005433415518	1262	Economy	66600.00
0005435824585	1262	Economy	66600.00
0005435824567	1262	Economy	66600.00
0005435824571	1262	Economy	66600.00
0005432284552	1262	Economy	66600.00
0005435824580	1262	Economy	66600.00
0005435824570	1262	Economy	66600.00
0005435824579	1262	Economy	66600.00
0005433415541	1262	Economy	66600.00
0005435824586	1262	Economy	66600.00
0005435824568	1262	Economy	66600.00
0005433415500	1262	Economy	66600.00
0005435824587	1262	Economy	66600.00
0005432284553	1262	Economy	66600.00
0005435824583	1262	Economy	66600.00
0005433415623	17982	Business	199800.00
0005435824338	17982	Business	199800.00
0005435824279	17982	Business	199800.00
0005433415624	17982	Business	199800.00
0005435824451	17982	Business	199800.00
0005433415628	17982	Business	199800.00
0005435824301	17982	Business	199800.00
0005435824375	17982	Business	199800.00
0005435824353	17982	Business	199800.00
0005435824424	17982	Business	199800.00
0005433415633	17982	Economy	66600.00
0005435824252	17982	Economy	66600.00
0005435824274	17982	Economy	66600.00
0005433415637	17982	Economy	66600.00
0005433415631	17982	Economy	73200.00
0005433415638	17982	Economy	66600.00
0005435824319	17982	Economy	73200.00
0005435824372	17982	Economy	66600.00
0005435824288	17982	Economy	66600.00
0005435824376	17982	Economy	66600.00
0005433415626	17982	Economy	66600.00
0005435824251	17982	Economy	66600.00
0005433415635	17982	Economy	66600.00
0005435824527	17982	Economy	66600.00
0005435824294	17982	Economy	66600.00
0005435824324	17982	Economy	66600.00
0005435824339	17982	Economy	66600.00
0005435824447	17982	Economy	66600.00
0005435824263	17982	Economy	66600.00
0005433415634	17982	Economy	66600.00
0005435824425	17982	Economy	66600.00
0005435824386	17982	Economy	66600.00
0005435824265	17982	Economy	66600.00
0005433415627	17982	Economy	66600.00
0005433415625	17982	Economy	66600.00
0005435824216	17982	Economy	66600.00
0005435824273	17982	Economy	66600.00
0005435824215	17982	Economy	66600.00
0005435824257	17982	Economy	66600.00
0005435824262	17982	Economy	66600.00
0005435824320	17982	Economy	66600.00
0005435824443	17982	Economy	66600.00
0005435824478	17982	Economy	66600.00
0005433415636	17982	Economy	66600.00
0005435824395	17982	Economy	66600.00
0005435824382	17982	Economy	66600.00
0005435824264	17982	Economy	66600.00
0005435824336	17982	Economy	66600.00
0005433415632	17982	Economy	66600.00
0005435824390	17982	Economy	66600.00
0005433415630	17982	Economy	66600.00
0005435824325	17982	Economy	66600.00
0005435824381	17982	Economy	66600.00
0005433415629	17982	Economy	66600.00
0005435824394	17982	Economy	66600.00
0005435824371	17982	Economy	66600.00
0005434461637	12575	Economy	14800.00
0005434460495	12575	Economy	13500.00
0005434461636	12575	Economy	13500.00
0005434460498	12575	Economy	13500.00
0005434461641	12575	Economy	13500.00
0005434461638	12575	Economy	13500.00
0005434460496	12575	Economy	13500.00
0005434460499	12575	Economy	13500.00
0005434461635	12575	Economy	13500.00
0005434460497	12575	Economy	13500.00
0005434461640	12575	Economy	13500.00
0005434461639	12575	Economy	13500.00
0005435242454	5665	Business	27800.00
0005432783689	5665	Business	27800.00
0005432783674	5665	Business	27800.00
0005432783676	5665	Business	27800.00
0005432783672	5665	Business	27800.00
0005432783718	5665	Business	27800.00
0005432783711	5665	Business	27800.00
0005432783714	5665	Business	27800.00
0005432783670	5665	Business	27800.00
0005432783706	5665	Business	27800.00
0005435242543	5665	Business	27800.00
0005432783699	5665	Business	27800.00
0005432143982	5665	Economy	9300.00
0005432783667	5665	Economy	9300.00
0005435242541	5665	Economy	9300.00
0005435242551	5665	Economy	9300.00
0005435242433	5665	Economy	9300.00
0005432783681	5665	Economy	9300.00
0005435242511	5665	Economy	9300.00
0005432783683	5665	Economy	9300.00
0005435242542	5665	Economy	9300.00
0005432783669	5665	Economy	10200.00
0005435242520	5665	Economy	10200.00
0005435242483	5665	Economy	10200.00
0005432783673	5665	Economy	10200.00
0005435242567	5665	Economy	10200.00
0005432783712	5665	Economy	9300.00
0005432783702	5665	Economy	9300.00
0005432783713	5665	Economy	9300.00
0005432783700	5665	Economy	9300.00
0005435242548	5665	Economy	9300.00
0005435242522	5665	Economy	9300.00
0005432783704	5665	Economy	9300.00
0005432783665	5665	Economy	9300.00
0005432783719	5665	Economy	9300.00
0005432783692	5665	Economy	9300.00
0005432783691	5665	Economy	9300.00
0005432143981	5665	Economy	9300.00
0005435242547	5665	Economy	9300.00
0005435476674	5665	Economy	9300.00
0005432783701	5665	Economy	9300.00
0005435242451	5665	Economy	9300.00
0005432783715	5665	Economy	9300.00
0005432143980	5665	Economy	9300.00
0005432783693	5665	Economy	9300.00
0005432783679	5665	Economy	9300.00
0005435242605	5665	Economy	9300.00
0005432783717	5665	Economy	9300.00
0005432783686	5665	Economy	9300.00
0005435242510	5665	Economy	9300.00
0005435242394	5665	Economy	9300.00
0005435242684	5665	Economy	9300.00
0005432783709	5665	Economy	9300.00
0005432783685	5665	Economy	9300.00
0005432783678	5665	Economy	9300.00
0005432783690	5665	Economy	9300.00
0005435242549	5665	Economy	9300.00
0005432783708	5665	Economy	9300.00
0005432783684	5665	Economy	9300.00
0005432783710	5665	Economy	9300.00
0005432783703	5665	Economy	9300.00
0005432783675	5665	Economy	9300.00
0005432783671	5665	Economy	9300.00
0005435242636	5665	Economy	9300.00
0005432783705	5665	Economy	9300.00
0005432783687	5665	Economy	9300.00
0005435242523	5665	Economy	9300.00
0005435476675	5665	Economy	9300.00
0005432783694	5665	Economy	9300.00
0005432783707	5665	Economy	9300.00
0005432143983	5665	Economy	9300.00
0005432783668	5665	Economy	9300.00
0005435476676	5665	Economy	9300.00
0005435242554	5665	Economy	9300.00
0005432783697	5665	Economy	9300.00
0005432783696	5665	Economy	9300.00
0005432783716	5665	Economy	9300.00
0005432783682	5665	Economy	9300.00
0005435242467	5665	Economy	9300.00
0005432783695	5665	Economy	9300.00
0005435242602	5665	Economy	9300.00
0005432783688	5665	Economy	9300.00
0005435476672	5665	Economy	9300.00
0005435242604	5665	Economy	9300.00
0005435476680	5665	Economy	9300.00
0005435242685	5665	Economy	9300.00
0005435242478	5665	Economy	9300.00
0005432783666	5665	Economy	9300.00
0005435476673	5665	Economy	9300.00
0005432783680	5665	Economy	9300.00
0005432783698	5665	Economy	9300.00
0005432783677	5665	Economy	9300.00
0005435242393	5665	Economy	9300.00
0005435242466	5665	Economy	9300.00
0005435242524	5665	Economy	9300.00
0005435476679	5665	Economy	9300.00
0005432783343	15367	Business	27800.00
0005435476745	15367	Business	27800.00
0005435242793	15367	Business	27800.00
0005432783250	15367	Business	27800.00
0005432783258	15367	Business	27800.00
0005432783123	15367	Business	27800.00
0005432783382	15367	Business	27800.00
0005435242771	15367	Business	27800.00
0005432783341	15367	Business	27800.00
0005432783145	15367	Business	27800.00
0005432783433	15367	Business	27800.00
0005432783027	15367	Economy	9300.00
0005435242794	15367	Economy	9300.00
0005432783205	15367	Economy	9300.00
0005435242789	15367	Economy	9300.00
0005432783216	15367	Economy	9300.00
0005432783272	15367	Economy	9300.00
0005432783179	15367	Economy	9300.00
0005432783101	15367	Economy	10200.00
0005432783021	15367	Economy	10200.00
0005435242781	15367	Economy	10200.00
0005435242786	15367	Economy	10200.00
0005435476741	15367	Economy	9300.00
0005432783321	15367	Economy	9300.00
0005435476738	15367	Economy	9300.00
0005432783355	15367	Economy	9300.00
0005432783334	15367	Economy	9300.00
0005435242796	15367	Economy	9300.00
0005435242785	15367	Economy	9300.00
0005435476740	15367	Economy	9300.00
0005435476737	15367	Economy	9300.00
0005435476744	15367	Economy	9300.00
0005435242792	15367	Economy	9300.00
0005432783372	15367	Economy	9300.00
0005432783333	15367	Economy	9300.00
0005435242774	15367	Economy	9300.00
0005435242790	15367	Economy	9300.00
0005432783124	15367	Economy	9300.00
0005432783278	15367	Economy	9300.00
0005435242778	15367	Economy	9300.00
0005435242770	15367	Economy	9300.00
0005432783266	15367	Economy	9300.00
0005432783012	15367	Economy	9300.00
0005435242772	15367	Economy	9300.00
0005435242795	15367	Economy	9300.00
0005432783122	15367	Economy	9300.00
0005432783286	15367	Economy	9300.00
0005432783111	15367	Economy	9300.00
0005432783204	15367	Economy	9300.00
0005432783340	15367	Economy	9300.00
0005432783206	15367	Economy	9300.00
0005435242791	15367	Economy	9300.00
0005432783113	15367	Economy	9300.00
0005432783381	15367	Economy	9300.00
0005432783383	15367	Economy	9300.00
0005432783076	15367	Economy	9300.00
0005435476739	15367	Economy	9300.00
0005435242773	15367	Economy	9300.00
0005432783342	15367	Economy	9300.00
0005435242780	15367	Economy	9300.00
0005435242788	15367	Economy	9300.00
0005432783380	15367	Economy	9300.00
0005432783235	15367	Economy	9300.00
0005435476743	15367	Economy	9300.00
0005432783418	15367	Economy	9300.00
0005432782971	15367	Economy	9300.00
0005432783215	15367	Economy	9300.00
0005435242776	15367	Economy	9300.00
0005435242777	15367	Economy	9300.00
0005432783273	15367	Economy	9300.00
0005435242783	15367	Economy	9300.00
0005435242775	15367	Economy	9300.00
0005435242779	15367	Economy	9300.00
0005435242782	15367	Economy	9300.00
0005432783114	15367	Economy	9300.00
0005432783191	15367	Economy	9300.00
0005435476736	15367	Economy	9300.00
0005432783088	15367	Economy	9300.00
0005435242787	15367	Economy	9300.00
0005432783075	15367	Economy	9300.00
0005432783100	15367	Economy	9300.00
0005432783274	15367	Economy	9300.00
0005435242784	15367	Economy	9300.00
0005435476742	15367	Economy	9300.00
0005432783279	15367	Economy	9300.00
0005432783078	15367	Economy	9300.00
0005432783144	15367	Economy	9300.00
0005432783236	15367	Economy	9300.00
0005432783287	15367	Economy	9300.00
0005432848284	4336	Economy	7000.00
0005432848288	4336	Economy	7000.00
0005435850823	4336	Economy	7000.00
0005432848292	4336	Economy	6300.00
0005432848291	4336	Economy	6300.00
0005435850824	4336	Economy	6300.00
0005435850841	4336	Economy	6300.00
0005432848279	4336	Economy	6300.00
0005432848280	4336	Economy	6300.00
0005434462785	4336	Economy	6300.00
0005432848281	4336	Economy	6300.00
0005435850840	4336	Economy	6300.00
0005435850822	4336	Economy	6300.00
0005435850825	4336	Economy	6300.00
0005434463925	4336	Economy	6300.00
0005432848287	4336	Economy	6300.00
0005432848289	4336	Economy	6300.00
0005435850862	4336	Economy	6300.00
0005434463924	4336	Economy	6300.00
0005432848290	4336	Economy	6300.00
0005432848283	4336	Economy	6300.00
0005432848278	4336	Economy	6300.00
0005435850796	4336	Economy	6300.00
0005435850827	4336	Economy	6300.00
0005435850833	4336	Economy	6300.00
0005435850813	4336	Economy	6300.00
0005435850814	4336	Economy	6300.00
0005435850863	4336	Economy	6300.00
0005432848285	4336	Economy	6300.00
0005432848282	4336	Economy	6300.00
0005434462786	4336	Economy	6300.00
0005432848286	4336	Economy	6300.00
0005435850830	4336	Economy	6300.00
0005435850889	28852	Economy	7000.00
0005432848114	28852	Economy	7000.00
0005432848161	28852	Economy	6300.00
0005432848158	28852	Economy	6300.00
0005435850893	28852	Economy	6300.00
0005432848098	28852	Economy	6300.00
0005432848178	28852	Economy	6300.00
0005432848172	28852	Economy	6300.00
0005432848177	28852	Economy	6300.00
0005432848188	28852	Economy	6300.00
0005432848182	28852	Economy	6300.00
0005435850897	28852	Economy	6300.00
0005435850891	28852	Economy	6300.00
0005432848097	28852	Economy	6300.00
0005432848146	28852	Economy	6300.00
0005432848115	28852	Economy	6300.00
0005432848169	28852	Economy	6300.00
0005432848116	28852	Economy	6300.00
0005435850890	28852	Economy	6300.00
0005432848170	28852	Economy	6300.00
0005435850892	28852	Economy	6300.00
0005435850896	28852	Economy	6300.00
0005432848229	28852	Economy	6300.00
0005432848191	28852	Economy	6300.00
0005435850895	28852	Economy	6300.00
0005432848128	28852	Economy	6300.00
0005435850898	28852	Economy	6300.00
0005435850888	28852	Economy	6300.00
0005435850894	28852	Economy	6300.00
0005434443686	6246	Business	11900.00
0005434925770	6246	Business	11900.00
0005434443674	6246	Business	11900.00
0005434925750	6246	Business	11900.00
0005433496916	6246	Business	11900.00
0005434925760	6246	Business	11900.00
0005433496914	6246	Business	11900.00
0005433496924	6246	Business	11900.00
0005433496912	6246	Economy	4000.00
0005434925773	6246	Economy	4000.00
0005434443680	6246	Economy	4000.00
0005433496909	6246	Economy	4000.00
0005433496911	6246	Economy	4000.00
0005433496923	6246	Economy	4000.00
0005434925772	6246	Economy	4400.00
0005433496917	6246	Economy	4400.00
0005433496907	6246	Economy	4400.00
0005433496928	6246	Economy	4400.00
0005434443675	6246	Economy	4400.00
0005433496915	6246	Economy	4000.00
0005434925753	6246	Economy	4000.00
0005434925755	6246	Economy	4000.00
0005434443679	6246	Economy	4000.00
0005433496904	6246	Economy	4000.00
0005434925754	6246	Economy	4000.00
0005434925775	6246	Economy	4000.00
0005432075225	6246	Economy	4000.00
0005434925757	6246	Economy	4000.00
0005433496910	6246	Economy	4000.00
0005434925767	6246	Economy	4000.00
0005433496921	6246	Economy	4000.00
0005433496927	6246	Economy	4000.00
0005434443681	6246	Economy	4000.00
0005434443676	6246	Economy	4000.00
0005434925758	6246	Economy	4000.00
0005433496925	6246	Economy	4000.00
0005434443684	6246	Economy	4000.00
0005433496900	6246	Economy	4000.00
0005434443685	6246	Economy	4000.00
0005434443683	6246	Economy	4000.00
0005433496908	6246	Economy	4000.00
0005434925764	6246	Economy	4000.00
0005433496899	6246	Economy	4000.00
0005434925774	6246	Economy	4000.00
0005434925762	6246	Economy	4000.00
0005434925751	6246	Economy	4000.00
0005434443682	6246	Economy	4000.00
0005433496929	6246	Economy	4000.00
0005433496919	6246	Economy	4000.00
0005433496902	6246	Economy	4000.00
0005432075222	6246	Economy	4000.00
0005434443687	6246	Economy	4000.00
0005432075224	6246	Economy	4000.00
0005433496906	6246	Economy	4000.00
0005433496922	6246	Economy	4000.00
0005434925769	6246	Economy	4000.00
0005433496903	6246	Economy	4000.00
0005434443671	6246	Economy	4000.00
0005433496905	6246	Economy	4000.00
0005434925752	6246	Economy	4000.00
0005433496913	6246	Economy	4000.00
0005434925765	6246	Economy	4000.00
0005434443673	6246	Economy	4000.00
0005434925768	6246	Economy	4000.00
0005434925756	6246	Economy	4000.00
0005434925763	6246	Economy	4000.00
0005434925771	6246	Economy	4000.00
0005434925766	6246	Economy	4000.00
0005434443677	6246	Economy	4000.00
0005433496920	6246	Economy	4000.00
0005433496901	6246	Economy	4000.00
0005432075223	6246	Economy	4000.00
0005434925761	6246	Economy	4000.00
0005434443678	6246	Economy	4000.00
0005434443672	6246	Economy	4000.00
0005433496926	6246	Economy	4000.00
0005433496918	6246	Economy	4000.00
0005434925759	6246	Economy	4000.00
0005434925529	20362	Business	11900.00
0005433496748	20362	Business	11900.00
0005434925594	20362	Business	11900.00
0005434925448	20362	Business	11900.00
0005433496593	20362	Business	11900.00
0005434925482	20362	Business	11900.00
0005434925355	20362	Business	11900.00
0005434925350	20362	Business	11900.00
0005433496813	20362	Business	11900.00
0005434443554	20362	Business	11900.00
0005434443520	20362	Economy	4000.00
0005434443482	20362	Economy	4000.00
0005434925384	20362	Economy	4000.00
0005433496711	20362	Economy	4000.00
0005434925511	20362	Economy	4000.00
0005434925394	20362	Economy	4000.00
0005433496689	20362	Economy	4000.00
0005434925485	20362	Economy	4000.00
0005434443564	20362	Economy	4400.00
0005433496757	20362	Economy	4400.00
0005433496718	20362	Economy	4400.00
0005433496791	20362	Economy	4400.00
0005434925365	20362	Economy	4400.00
0005434925428	20362	Economy	4000.00
0005434925472	20362	Economy	4000.00
0005434925480	20362	Economy	4000.00
0005434925372	20362	Economy	4000.00
0005434443540	20362	Economy	4000.00
0005434925366	20362	Economy	4000.00
0005434925357	20362	Economy	4000.00
0005434925429	20362	Economy	4000.00
0005433496662	20362	Economy	4000.00
0005433496842	20362	Economy	4000.00
0005433496661	20362	Economy	4000.00
0005434443551	20362	Economy	4000.00
0005433496634	20362	Economy	4000.00
0005433496720	20362	Economy	4000.00
0005434925476	20362	Economy	4000.00
0005434925471	20362	Economy	4000.00
0005434925447	20362	Economy	4000.00
0005434443561	20362	Economy	4000.00
0005434925356	20362	Economy	4000.00
0005433496645	20362	Economy	4000.00
0005434925260	20362	Economy	4000.00
0005434443523	20362	Economy	4000.00
0005433496602	20362	Economy	4000.00
0005434443555	20362	Economy	4000.00
0005434925393	20362	Economy	4000.00
0005434443517	20362	Economy	4000.00
0005434925282	20362	Economy	4000.00
0005433496747	20362	Economy	4000.00
0005434925593	20362	Economy	4000.00
0005434925373	20362	Economy	4000.00
0005434925493	20362	Economy	4000.00
0005433496707	20362	Economy	4000.00
0005434443476	20362	Economy	4000.00
0005434925386	20362	Economy	4000.00
0005434925431	20362	Economy	4000.00
0005434925508	20362	Economy	4000.00
0005434925445	20362	Economy	4000.00
0005433496663	20362	Economy	4000.00
0005433496732	20362	Economy	4000.00
0005434443457	20362	Economy	4000.00
0005434925413	20362	Economy	4000.00
0005433496644	20362	Economy	4000.00
0005434443475	20362	Economy	4000.00
0005434925479	20362	Economy	4000.00
0005433496749	20362	Economy	4000.00
0005434925354	20362	Economy	4000.00
0005434925415	20362	Economy	4000.00
0005434925281	20362	Economy	4000.00
0005433496633	20362	Economy	4000.00
0005433496592	20362	Economy	4000.00
0005434925473	20362	Economy	4000.00
0005434443601	20362	Economy	4000.00
0005433496719	20362	Economy	4000.00
0005434443587	20362	Economy	4000.00
0005434925446	20362	Economy	4000.00
0005432783292	12194	Business	41200.00
0005432783263	12194	Business	41200.00
0005432783252	12194	Business	41200.00
0005432783162	12194	Business	41200.00
0005432783368	12194	Business	41200.00
0005435242806	12194	Business	41200.00
0005432783200	12194	Business	41200.00
0005432783261	12194	Business	41200.00
0005432783194	12194	Business	41200.00
0005435242797	12194	Business	41200.00
0005432783188	12194	Business	41200.00
0005432783151	12194	Business	41200.00
0005435242823	12194	Economy	13700.00
0005432783117	12194	Economy	13700.00
0005432783138	12194	Economy	13700.00
0005435242815	12194	Economy	13700.00
0005432783121	12194	Economy	13700.00
0005432783153	12194	Economy	13700.00
0005435242811	12194	Economy	13700.00
0005435242810	12194	Economy	13700.00
0005435242804	12194	Economy	13700.00
0005435242799	12194	Economy	13700.00
0005432783302	12194	Economy	15100.00
0005432783170	12194	Economy	15100.00
0005435242818	12194	Economy	15100.00
0005432783396	12194	Economy	15100.00
0005432783350	12194	Economy	15100.00
0005435242824	12194	Economy	13700.00
0005432783307	12194	Economy	13700.00
0005432783301	12194	Economy	13700.00
0005432783425	12194	Economy	13700.00
0005432783353	12194	Economy	13700.00
0005432783131	12194	Economy	13700.00
0005432783387	12194	Economy	13700.00
0005435242812	12194	Economy	13700.00
0005432783405	12194	Economy	13700.00
0005435242809	12194	Economy	13700.00
0005435242821	12194	Economy	13700.00
0005432783241	12194	Economy	13700.00
0005435242801	12194	Economy	13700.00
0005435242814	12194	Economy	13700.00
0005432783032	12194	Economy	13700.00
0005432783309	12194	Economy	13700.00
0005435242816	12194	Economy	13700.00
0005435242819	12194	Economy	13700.00
0005432783282	12194	Economy	13700.00
0005435242808	12194	Economy	13700.00
0005432783185	12194	Economy	13700.00
0005435242805	12194	Economy	13700.00
0005432783248	12194	Economy	13700.00
0005432783260	12194	Economy	13700.00
0005432783453	12194	Economy	13700.00
0005432783249	12194	Economy	13700.00
0005435242822	12194	Economy	13700.00
0005432783033	12194	Economy	13700.00
0005432783283	12194	Economy	13700.00
0005432783297	12194	Economy	13700.00
0005435242800	12194	Economy	13700.00
0005432783239	12194	Economy	13700.00
0005432783432	12194	Economy	13700.00
0005432783118	12194	Economy	13700.00
0005432783251	12194	Economy	13700.00
0005432783071	12194	Economy	13700.00
0005435242807	12194	Economy	13700.00
0005432783434	12194	Economy	13700.00
0005432783169	12194	Economy	13700.00
0005432783293	12194	Economy	13700.00
0005432783394	12194	Economy	13700.00
0005432783152	12194	Economy	13700.00
0005432783240	12194	Economy	13700.00
0005432783316	12194	Economy	13700.00
0005435242802	12194	Economy	13700.00
0005432783300	12194	Economy	13700.00
0005432783257	12194	Economy	13700.00
0005432783253	12194	Economy	13700.00
0005432783259	12194	Economy	13700.00
0005435242820	12194	Economy	13700.00
0005432783133	12194	Economy	13700.00
0005432783395	12194	Economy	13700.00
0005432783291	12194	Economy	13700.00
0005432783220	12194	Economy	13700.00
0005435242803	12194	Economy	13700.00
0005432783262	12194	Economy	13700.00
0005435242798	12194	Economy	13700.00
0005432783421	12194	Economy	13700.00
0005435242813	12194	Economy	13700.00
0005432783229	12194	Economy	13700.00
0005432783189	12194	Economy	13700.00
0005432783308	12194	Economy	13700.00
0005432783132	12194	Economy	13700.00
0005432783406	12194	Economy	13700.00
0005432783369	12194	Economy	13700.00
0005435242817	12194	Economy	13700.00
0005432783367	12194	Economy	13700.00
0005435242526	15420	Business	41200.00
0005432783620	15420	Business	41200.00
0005432783613	15420	Business	41200.00
0005432783614	15420	Business	41200.00
0005432783636	15420	Business	41200.00
0005435242422	15420	Business	41200.00
0005432783634	15420	Business	41200.00
0005432783625	15420	Economy	13700.00
0005432783647	15420	Economy	13700.00
0005435242449	15420	Economy	13700.00
0005432783659	15420	Economy	13700.00
0005435242569	15420	Economy	13700.00
0005432783628	15420	Economy	13700.00
0005432783623	15420	Economy	13700.00
0005432783631	15420	Economy	13700.00
0005432783646	15420	Economy	13700.00
0005432783637	15420	Economy	15100.00
0005432783630	15420	Economy	15100.00
0005435242435	15420	Economy	15100.00
0005432783652	15420	Economy	15100.00
0005435242525	15420	Economy	15100.00
0005432783619	15420	Economy	13700.00
0005432783654	15420	Economy	13700.00
0005432783639	15420	Economy	13700.00
0005432783640	15420	Economy	13700.00
0005435242518	15420	Economy	13700.00
0005435242465	15420	Economy	13700.00
0005432783622	15420	Economy	13700.00
0005432783611	15420	Economy	13700.00
0005432783617	15420	Economy	13700.00
0005435242532	15420	Economy	13700.00
0005432783633	15420	Economy	13700.00
0005432783651	15420	Economy	13700.00
0005435242570	15420	Economy	13700.00
0005432783627	15420	Economy	13700.00
0005435242563	15420	Economy	13700.00
0005435242423	15420	Economy	13700.00
0005432783615	15420	Economy	13700.00
0005432783635	15420	Economy	13700.00
0005435242493	15420	Economy	13700.00
0005432783638	15420	Economy	13700.00
0005432783616	15420	Economy	13700.00
0005432783618	15420	Economy	13700.00
0005432783653	15420	Economy	13700.00
0005432783656	15420	Economy	13700.00
0005432783650	15420	Economy	13700.00
0005432783661	15420	Economy	13700.00
0005432783660	15420	Economy	13700.00
0005432783612	15420	Economy	13700.00
0005435242482	15420	Economy	13700.00
0005432783610	15420	Economy	13700.00
0005432783629	15420	Economy	13700.00
0005432783649	15420	Economy	13700.00
0005432783641	15420	Economy	13700.00
0005432783658	15420	Economy	13700.00
0005435242566	15420	Economy	13700.00
0005432783663	15420	Economy	13700.00
0005435242531	15420	Economy	13700.00
0005435242565	15420	Economy	13700.00
0005432783621	15420	Economy	13700.00
0005432783642	15420	Economy	13700.00
0005435242564	15420	Economy	13700.00
0005432783626	15420	Economy	13700.00
0005432783644	15420	Economy	13700.00
0005435242519	15420	Economy	13700.00
0005435242503	15420	Economy	13700.00
0005432783632	15420	Economy	13700.00
0005432783662	15420	Economy	13700.00
0005432783655	15420	Economy	13700.00
0005432783624	15420	Economy	13700.00
0005435242568	15420	Economy	13700.00
0005432783657	15420	Economy	13700.00
0005432783643	15420	Economy	13700.00
0005432783664	15420	Economy	13700.00
0005435242479	15420	Economy	13700.00
0005432783645	15420	Economy	13700.00
0005435242504	15420	Economy	13700.00
0005432783648	15420	Economy	13700.00
0005435242436	15420	Economy	13700.00
0005432783609	15420	Economy	13700.00
0005435242440	15420	Economy	13700.00
0005434877256	10117	Business	49700.00
0005434876951	10117	Business	49700.00
0005434876952	10117	Business	49700.00
0005434876769	10117	Business	49700.00
0005434877419	10117	Business	49700.00
0005434876962	10117	Business	49700.00
0005434877377	10117	Business	49700.00
0005434877297	10117	Business	49700.00
0005434877420	10117	Business	49700.00
0005434876609	10117	Business	49700.00
0005434877060	10117	Business	49700.00
0005434877380	10117	Business	49700.00
0005434877201	10117	Business	49700.00
0005434876970	10117	Business	49700.00
0005434877202	10117	Business	49700.00
0005434877135	10117	Business	49700.00
0005434877108	10117	Business	49700.00
0005434876961	10117	Economy	16600.00
0005434877272	10117	Economy	16600.00
0005434877274	10117	Economy	16600.00
0005434876841	10117	Economy	16600.00
0005434877330	10117	Economy	16600.00
0005434877196	10117	Economy	16600.00
0005434877580	10117	Economy	16600.00
0005434876659	10117	Economy	16600.00
0005434877549	10117	Economy	16600.00
0005434877327	10117	Economy	16600.00
0005434877155	10117	Economy	18200.00
0005434877521	10117	Economy	18200.00
0005434877206	10117	Economy	16600.00
0005434876742	10117	Economy	16600.00
0005434877138	10117	Economy	16600.00
0005434877220	10117	Economy	16600.00
0005434877379	10117	Economy	16600.00
0005434877134	10117	Economy	16600.00
0005434877346	10117	Economy	16600.00
0005434876604	10117	Economy	16600.00
0005434877437	10117	Economy	16600.00
0005434876660	10117	Economy	16600.00
0005434877167	10117	Economy	16600.00
0005434876898	10117	Economy	16600.00
0005434876605	10117	Economy	16600.00
0005434876701	10117	Economy	16600.00
0005434877438	10117	Economy	16600.00
0005434877054	10117	Economy	16600.00
0005434877059	10117	Economy	16600.00
0005434877032	10117	Economy	16600.00
0005434877329	10117	Economy	16600.00
0005434877356	10117	Economy	16600.00
0005434758864	10117	Economy	16600.00
0005434877306	10117	Economy	16600.00
0005434877184	10117	Economy	16600.00
0005434877500	10117	Economy	16600.00
0005434877221	10117	Economy	16600.00
0005434877522	10117	Economy	16600.00
0005434876884	10117	Economy	16600.00
0005434877307	10117	Economy	16600.00
0005434877074	10117	Economy	16600.00
0005434877109	10117	Economy	16600.00
0005434877133	10117	Economy	16600.00
0005434876987	10117	Economy	16600.00
0005434877033	10117	Economy	16600.00
0005434877192	10117	Economy	16600.00
0005434877460	10117	Economy	16600.00
0005434876700	10117	Economy	16600.00
0005434876744	10117	Economy	16600.00
0005434876741	10117	Economy	16600.00
0005434877417	10117	Economy	16600.00
0005434877040	10117	Economy	16600.00
0005434877145	10117	Economy	16600.00
0005434876661	10117	Economy	16600.00
0005434758865	10117	Economy	16600.00
0005434876963	10117	Economy	16600.00
0005434758866	10117	Economy	16600.00
0005434877811	10117	Economy	16600.00
0005434910106	10117	Economy	16600.00
0005434877328	10117	Economy	16600.00
0005434877614	10117	Economy	16600.00
0005434910105	10117	Economy	16600.00
0005434877262	10117	Economy	16600.00
0005434877154	10117	Economy	16600.00
0005434876743	10117	Economy	16600.00
0005434877188	10117	Economy	16600.00
0005434877156	10117	Economy	16600.00
0005434877117	10117	Economy	16600.00
0005434876662	10117	Economy	16600.00
0005434877061	10117	Economy	16600.00
0005434876883	10117	Economy	16600.00
0005434877273	10117	Economy	16600.00
0005434877113	10117	Economy	16600.00
0005434876986	10117	Economy	16600.00
0005434877440	10117	Economy	16600.00
0005434877254	10117	Economy	16600.00
0005434877491	10117	Economy	16600.00
0005434877378	10117	Economy	16600.00
0005434877340	10117	Economy	16600.00
0005434877550	10117	Economy	16600.00
0005434876899	10117	Economy	16600.00
0005434877207	10117	Economy	16600.00
0005434877305	10117	Economy	16600.00
0005434878010	14618	Business	49700.00
0005434878091	14618	Business	49700.00
0005434878097	14618	Business	49700.00
0005434878028	14618	Business	49700.00
0005434878048	14618	Business	49700.00
0005434758889	14618	Business	49700.00
0005434878022	14618	Business	49700.00
0005434878053	14618	Business	49700.00
0005434878027	14618	Business	49700.00
0005434878012	14618	Business	49700.00
0005434878100	14618	Business	49700.00
0005434878073	14618	Business	49700.00
0005434878037	14618	Business	49700.00
0005434878071	14618	Business	49700.00
0005434878093	14618	Business	49700.00
0005434878081	14618	Business	49700.00
0005434878045	14618	Business	49700.00
0005434878095	14618	Business	49700.00
0005434878090	14618	Business	49700.00
0005434878102	14618	Business	49700.00
0005434878087	14618	Economy	16600.00
0005434878098	14618	Economy	16600.00
0005434878105	14618	Economy	16600.00
0005434878059	14618	Economy	16600.00
0005434878078	14618	Economy	16600.00
0005434878009	14618	Economy	16600.00
0005434878084	14618	Economy	16600.00
0005434910075	14618	Economy	16600.00
0005434878031	14618	Economy	16600.00
0005434878029	14618	Economy	16600.00
0005434878086	14618	Economy	18200.00
0005434878047	14618	Economy	18200.00
0005434878065	14618	Economy	16600.00
0005434878076	14618	Economy	18200.00
0005434878026	14618	Economy	16600.00
0005434878046	14618	Economy	16600.00
0005434878079	14618	Economy	16600.00
0005434878013	14618	Economy	16600.00
0005434878040	14618	Economy	16600.00
0005434878099	14618	Economy	16600.00
0005434758890	14618	Economy	16600.00
0005434878089	14618	Economy	16600.00
0005434878017	14618	Economy	16600.00
0005434878060	14618	Economy	16600.00
0005434878085	14618	Economy	16600.00
0005434878069	14618	Economy	16600.00
0005434878044	14618	Economy	16600.00
0005434878075	14618	Economy	16600.00
0005434878082	14618	Economy	16600.00
0005434878080	14618	Economy	16600.00
0005434878072	14618	Economy	16600.00
0005434878043	14618	Economy	16600.00
0005434878014	14618	Economy	16600.00
0005434878023	14618	Economy	16600.00
0005434878042	14618	Economy	16600.00
0005434878092	14618	Economy	16600.00
0005434878077	14618	Economy	16600.00
0005434910083	14618	Economy	16600.00
0005434878057	14618	Economy	16600.00
0005434878025	14618	Economy	16600.00
0005434878030	14618	Economy	16600.00
0005434878019	14618	Economy	16600.00
0005434878070	14618	Economy	16600.00
0005434878101	14618	Economy	16600.00
0005434878096	14618	Economy	16600.00
0005434878021	14618	Economy	16600.00
0005434878062	14618	Economy	16600.00
0005434878041	14618	Economy	16600.00
0005434878033	14618	Economy	16600.00
0005434878052	14618	Economy	16600.00
0005434878066	14618	Economy	16600.00
0005434878055	14618	Economy	16600.00
0005434910082	14618	Economy	16600.00
0005434878074	14618	Economy	16600.00
0005434878103	14618	Economy	16600.00
0005434878063	14618	Economy	16600.00
0005434878061	14618	Economy	16600.00
0005434878067	14618	Economy	16600.00
0005434878008	14618	Economy	16600.00
0005434878054	14618	Economy	16600.00
0005434878051	14618	Economy	16600.00
0005434758888	14618	Economy	16600.00
0005434878049	14618	Economy	16600.00
0005434878094	14618	Economy	16600.00
0005434878035	14618	Economy	16600.00
0005434878032	14618	Economy	16600.00
0005434878018	14618	Economy	16600.00
0005434878039	14618	Economy	16600.00
0005434878068	14618	Economy	16600.00
0005434878016	14618	Economy	16600.00
0005434878064	14618	Economy	16600.00
0005434878058	14618	Economy	16600.00
0005434878036	14618	Economy	16600.00
0005434878038	14618	Economy	16600.00
0005434878015	14618	Economy	16600.00
0005434878083	14618	Economy	16600.00
0005434878104	14618	Economy	16600.00
0005434878011	14618	Economy	16600.00
0005434878020	14618	Economy	16600.00
0005434878050	14618	Economy	16600.00
0005434878024	14618	Economy	16600.00
0005434878034	14618	Economy	16600.00
0005434878088	14618	Economy	16600.00
0005434758891	14618	Economy	16600.00
0005434878056	14618	Economy	16600.00
0005435660114	9258	Economy	22400.00
0005434251835	9258	Economy	22400.00
0005434251852	9258	Economy	20300.00
0005434251890	9258	Economy	20300.00
0005434251886	9258	Economy	20300.00
0005435660112	9258	Economy	20300.00
0005435660116	9258	Economy	20300.00
0005434251889	9258	Economy	20300.00
0005435660113	9258	Economy	20300.00
0005435660119	9258	Economy	20300.00
0005435660120	9258	Economy	20300.00
0005434251891	9258	Economy	20300.00
0005435660117	9258	Economy	20300.00
0005435660115	9258	Economy	20300.00
0005435660111	9258	Economy	20300.00
0005435660118	9258	Economy	20300.00
0005435660045	24655	Economy	22400.00
0005434251949	24655	Economy	22400.00
0005435660044	24655	Economy	20300.00
0005435660010	24655	Economy	20300.00
0005434251943	24655	Economy	20300.00
0005434251950	24655	Economy	20300.00
0005435660070	24655	Economy	20300.00
0005434251946	24655	Economy	20300.00
0005435660069	24655	Economy	20300.00
0005435660011	24655	Economy	20300.00
0005435660066	24655	Economy	20300.00
0005435660023	24655	Economy	20300.00
0005435660022	24655	Economy	20300.00
0005435659977	24655	Economy	20300.00
0005434251947	24655	Economy	20300.00
0005435660067	24655	Economy	20300.00
0005434251945	24655	Economy	20300.00
0005435659993	24655	Economy	20300.00
0005435660024	24655	Economy	20300.00
0005434251948	24655	Economy	20300.00
0005434251951	24655	Economy	20300.00
0005434251944	24655	Economy	20300.00
0005434251942	24655	Economy	20300.00
0005433680469	2770	Business	33000.00
0005433680474	2770	Business	33000.00
0005433680470	2770	Business	33000.00
0005432966637	2770	Business	33000.00
0005433680466	2770	Business	33000.00
0005433680447	2770	Business	33000.00
0005433680452	2770	Business	33000.00
0005432222772	2770	Business	33000.00
0005433680483	2770	Business	33000.00
0005433680468	2770	Business	33000.00
0005433680485	2770	Economy	11000.00
0005432966732	2770	Economy	11000.00
0005433680476	2770	Economy	11000.00
0005433680463	2770	Economy	11000.00
0005433680480	2770	Economy	11000.00
0005432966687	2770	Economy	11000.00
0005433680456	2770	Economy	11000.00
0005432966683	2770	Economy	11000.00
0005433680446	2770	Economy	11000.00
0005433680454	2770	Economy	11000.00
0005432966698	2770	Economy	12100.00
0005433684415	2770	Economy	12100.00
0005433680465	2770	Economy	12100.00
0005433680461	2770	Economy	12100.00
0005433680453	2770	Economy	12100.00
0005432966577	2770	Economy	11000.00
0005432966606	2770	Economy	11000.00
0005432222774	2770	Economy	11000.00
0005433680487	2770	Economy	11000.00
0005432966773	2770	Economy	11000.00
0005432966631	2770	Economy	11000.00
0005432966699	2770	Economy	11000.00
0005432966625	2770	Economy	11000.00
0005433680486	2770	Economy	11000.00
0005432966636	2770	Economy	11000.00
0005433680475	2770	Economy	11000.00
0005433680491	2770	Economy	11000.00
0005433680449	2770	Economy	11000.00
0005432966639	2770	Economy	11000.00
0005433680471	2770	Economy	11000.00
0005432966672	2770	Economy	11000.00
0005433680472	2770	Economy	11000.00
0005433680477	2770	Economy	11000.00
0005433680478	2770	Economy	11000.00
0005433680467	2770	Economy	11000.00
0005433684414	2770	Economy	11000.00
0005433680460	2770	Economy	11000.00
0005432966632	2770	Economy	11000.00
0005432966812	2770	Economy	11000.00
0005432222773	2770	Economy	11000.00
0005432966578	2770	Economy	11000.00
0005433680490	2770	Economy	11000.00
0005433680458	2770	Economy	11000.00
0005433680451	2770	Economy	11000.00
0005433680459	2770	Economy	11000.00
0005433680455	2770	Economy	11000.00
0005433680444	2770	Economy	11000.00
0005432222770	2770	Economy	11000.00
0005433680481	2770	Economy	11000.00
0005432966684	2770	Economy	11000.00
0005432966741	2770	Economy	11000.00
0005433680482	2770	Economy	11000.00
0005433680462	2770	Economy	11000.00
0005433680464	2770	Economy	11000.00
0005433680457	2770	Economy	11000.00
0005432966633	2770	Economy	11000.00
0005432222771	2770	Economy	11000.00
0005433680443	2770	Economy	11000.00
0005432966692	2770	Economy	11000.00
0005432966623	2770	Economy	11000.00
0005433680473	2770	Economy	11000.00
0005433680450	2770	Economy	11000.00
0005433680488	2770	Economy	11000.00
0005433680489	2770	Economy	11000.00
0005432966622	2770	Economy	11000.00
0005433680479	2770	Economy	11000.00
0005433680445	2770	Economy	11000.00
0005432966624	2770	Economy	11000.00
0005432966608	2770	Economy	11000.00
0005432966744	2770	Economy	11000.00
0005433680442	2770	Economy	11000.00
0005433680448	2770	Economy	11000.00
0005433680484	2770	Economy	11000.00
0005433680169	29160	Business	33000.00
0005433679935	29160	Business	33000.00
0005433680165	29160	Business	33000.00
0005432966871	29160	Business	33000.00
0005433680082	29160	Business	33000.00
0005432966894	29160	Business	33000.00
0005433680041	29160	Business	33000.00
0005433680164	29160	Business	33000.00
0005433680153	29160	Business	33000.00
0005433680132	29160	Business	33000.00
0005432966872	29160	Business	33000.00
0005433680286	29160	Economy	11000.00
0005433680040	29160	Economy	11000.00
0005433680163	29160	Economy	11000.00
0005433680083	29160	Economy	11000.00
0005433680383	29160	Economy	11000.00
0005433680143	29160	Economy	11000.00
0005432966884	29160	Economy	12100.00
0005433680220	29160	Economy	12100.00
0005432966886	29160	Economy	12100.00
0005433679827	29160	Economy	12100.00
0005433680162	29160	Economy	11000.00
0005432966882	29160	Economy	11000.00
0005432966888	29160	Economy	11000.00
0005432966873	29160	Economy	11000.00
0005433680025	29160	Economy	11000.00
0005433680068	29160	Economy	11000.00
0005433680211	29160	Economy	11000.00
0005432966889	29160	Economy	11000.00
0005432966890	29160	Economy	11000.00
0005433680098	29160	Economy	11000.00
0005432966875	29160	Economy	11000.00
0005433680166	29160	Economy	11000.00
0005433680038	29160	Economy	11000.00
0005433679967	29160	Economy	11000.00
0005433679946	29160	Economy	11000.00
0005433680219	29160	Economy	11000.00
0005433680039	29160	Economy	11000.00
0005432966893	29160	Economy	11000.00
0005432966895	29160	Economy	11000.00
0005433680210	29160	Economy	11000.00
0005433680099	29160	Economy	11000.00
0005432005207	29160	Economy	11000.00
0005433680084	29160	Economy	11000.00
0005432966883	29160	Economy	11000.00
0005432966892	29160	Economy	11000.00
0005433680196	29160	Economy	11000.00
0005433680272	29160	Economy	11000.00
0005433679934	29160	Economy	11000.00
0005433680240	29160	Economy	11000.00
0005432966896	29160	Economy	11000.00
0005433680271	29160	Economy	11000.00
0005433680241	29160	Economy	11000.00
0005432966879	29160	Economy	11000.00
0005432966881	29160	Economy	11000.00
0005433680287	29160	Economy	11000.00
0005432966885	29160	Economy	11000.00
0005433680242	29160	Economy	11000.00
0005433680195	29160	Economy	11000.00
0005433680037	29160	Economy	11000.00
0005432005208	29160	Economy	11000.00
0005432966876	29160	Economy	11000.00
0005432966874	29160	Economy	11000.00
0005433680170	29160	Economy	11000.00
0005432966878	29160	Economy	11000.00
0005432966877	29160	Economy	11000.00
0005433680095	29160	Economy	11000.00
0005433680106	29160	Economy	11000.00
0005433680091	29160	Economy	11000.00
0005433680032	29160	Economy	11000.00
0005433680070	29160	Economy	11000.00
0005433680107	29160	Economy	11000.00
0005433679815	29160	Economy	11000.00
0005433680198	29160	Economy	11000.00
0005433680015	29160	Economy	11000.00
0005433680094	29160	Economy	11000.00
0005433680274	29160	Economy	11000.00
0005432966891	29160	Economy	11000.00
0005433680071	29160	Economy	11000.00
0005433680275	29160	Economy	11000.00
0005433679892	29160	Economy	11000.00
0005432966880	29160	Economy	11000.00
0005432966887	29160	Economy	11000.00
0005433680069	29160	Economy	11000.00
0005433690908	29160	Economy	11000.00
0005433680226	29160	Economy	11000.00
0005433633714	9310	Business	132900.00
0005433633716	9310	Business	132900.00
0005433577783	9310	Business	132900.00
0005433614436	9310	Business	132900.00
0005433614449	9310	Business	132900.00
0005433614473	9310	Business	132900.00
0005433614481	9310	Business	132900.00
0005434153522	9310	Business	132900.00
0005433577774	9310	Business	132900.00
0005433614434	9310	Business	132900.00
0005433614468	9310	Business	132900.00
0005433633711	9310	Business	132900.00
0005433614462	9310	Business	132900.00
0005433614508	9310	Business	132900.00
0005432755066	9310	Business	132900.00
0005434152768	9310	Business	132900.00
0005433614452	9310	Business	132900.00
0005433614451	9310	Business	132900.00
0005433614447	9310	Business	132900.00
0005433633709	9310	Business	132900.00
0005433614437	9310	Business	132900.00
0005433614480	9310	Business	132900.00
0005433633722	9310	Business	132900.00
0005434269075	9310	Business	132900.00
0005434269076	9310	Business	132900.00
0005433614485	9310	Business	132900.00
0005433614438	9310	Business	132900.00
0005433614448	9310	Economy	48700.00
0005433633704	9310	Economy	48700.00
0005433614492	9310	Economy	48700.00
0005433614498	9310	Economy	48700.00
0005433633720	9310	Economy	48700.00
0005433633707	9310	Economy	44300.00
0005433614460	9310	Economy	44300.00
0005434152760	9310	Economy	44300.00
0005433614478	9310	Economy	44300.00
0005433614483	9310	Economy	44300.00
0005433633727	9310	Economy	44300.00
0005433614455	9310	Economy	44300.00
0005433633731	9310	Economy	44300.00
0005433614472	9310	Economy	44300.00
0005433614463	9310	Economy	44300.00
0005432755069	9310	Economy	44300.00
0005432145104	9310	Economy	44300.00
0005433614442	9310	Economy	44300.00
0005433633719	9310	Economy	44300.00
0005433577773	9310	Economy	44300.00
0005433614504	9310	Economy	44300.00
0005433577780	9310	Economy	44300.00
0005433633702	9310	Economy	44300.00
0005433633712	9310	Economy	44300.00
0005433633726	9310	Economy	44300.00
0005434163544	9310	Economy	44300.00
0005433577771	9310	Economy	44300.00
0005434153518	9310	Economy	44300.00
0005433633708	9310	Economy	44300.00
0005433614464	9310	Economy	44300.00
0005433614489	9310	Economy	44300.00
0005433633734	9310	Economy	44300.00
0005433633732	9310	Economy	44300.00
0005433614502	9310	Economy	44300.00
0005433614476	9310	Economy	44300.00
0005433577779	9310	Economy	44300.00
0005433614475	9310	Economy	44300.00
0005433614441	9310	Economy	44300.00
0005433633729	9310	Economy	44300.00
0005433614450	9310	Economy	44300.00
0005433614497	9310	Economy	44300.00
0005432756840	9310	Economy	44300.00
0005433614507	9310	Economy	44300.00
0005434152769	9310	Economy	44300.00
0005432145105	9310	Economy	44300.00
0005433614453	9310	Economy	44300.00
0005433614474	9310	Economy	44300.00
0005433577778	9310	Economy	44300.00
0005433633735	9310	Economy	44300.00
0005433614496	9310	Economy	44300.00
0005433614500	9310	Economy	44300.00
0005433577772	9310	Economy	44300.00
0005433577777	9310	Economy	44300.00
0005433614506	9310	Economy	44300.00
0005433633725	9310	Economy	44300.00
0005433614484	9310	Economy	44300.00
0005433614467	9310	Economy	44300.00
0005433614494	9310	Economy	44300.00
0005433633710	9310	Economy	48700.00
0005433614505	9310	Economy	48700.00
0005433614479	9310	Economy	48700.00
0005433614444	9310	Economy	48700.00
0005433614486	9310	Economy	48700.00
0005433614439	9310	Economy	44300.00
0005434163530	9310	Economy	44300.00
0005433614501	9310	Economy	44300.00
0005433614461	9310	Economy	44300.00
0005434152770	9310	Economy	48700.00
0005433633713	9310	Economy	44300.00
0005434163529	9310	Economy	44300.00
0005433633721	9310	Economy	44300.00
0005434153521	9310	Economy	44300.00
0005433614446	9310	Economy	44300.00
0005433614491	9310	Economy	44300.00
0005433614454	9310	Economy	44300.00
0005433614469	9310	Economy	44300.00
0005433614456	9310	Economy	44300.00
0005433633728	9310	Economy	44300.00
0005432145106	9310	Economy	44300.00
0005433614440	9310	Economy	44300.00
0005434163514	9310	Economy	44300.00
0005433614435	9310	Economy	44300.00
0005433633718	9310	Economy	44300.00
0005433633703	9310	Economy	44300.00
0005433614495	9310	Economy	44300.00
0005434153520	9310	Economy	44300.00
0005433633733	9310	Economy	44300.00
0005432755070	9310	Economy	44300.00
0005433614443	9310	Economy	44300.00
0005433614499	9310	Economy	44300.00
0005434269074	9310	Economy	44300.00
0005432755067	9310	Economy	44300.00
0005433614470	9310	Economy	44300.00
0005433614488	9310	Economy	44300.00
0005433614459	9310	Economy	44300.00
0005433614471	9310	Economy	44300.00
0005433614482	9310	Economy	44300.00
0005433577782	9310	Economy	44300.00
0005433614457	9310	Economy	44300.00
0005433633730	9310	Economy	44300.00
0005433614466	9310	Economy	44300.00
0005433577769	9310	Economy	44300.00
0005433614445	9310	Economy	44300.00
0005433614493	9310	Economy	44300.00
0005433633705	9310	Economy	44300.00
0005433577770	9310	Economy	44300.00
0005432755068	9310	Economy	44300.00
0005433633736	9310	Economy	44300.00
0005434163528	9310	Economy	44300.00
0005433577781	9310	Economy	44300.00
0005433614465	9310	Economy	44300.00
0005432756841	9310	Economy	44300.00
0005433633715	9310	Economy	44300.00
0005433577776	9310	Economy	44300.00
0005433614490	9310	Economy	44300.00
0005433633717	9310	Economy	44300.00
0005433633724	9310	Economy	44300.00
0005433577775	9310	Economy	44300.00
0005433614477	9310	Economy	44300.00
0005433633706	9310	Economy	44300.00
0005433614503	9310	Economy	44300.00
0005433614458	9310	Economy	44300.00
0005433633723	9310	Economy	44300.00
0005433614487	9310	Economy	44300.00
0005433613609	25212	Business	132900.00
0005433577655	25212	Business	132900.00
0005434163593	25212	Business	132900.00
0005433613693	25212	Business	132900.00
0005433633381	25212	Business	132900.00
0005433613908	25212	Business	132900.00
0005433614057	25212	Business	132900.00
0005433633358	25212	Business	132900.00
0005433633509	25212	Business	132900.00
0005433614035	25212	Business	132900.00
0005433633369	25212	Business	132900.00
0005433613973	25212	Business	132900.00
0005433613730	25212	Business	132900.00
0005433613975	25212	Business	132900.00
0005433614270	25212	Business	132900.00
0005433577660	25212	Business	132900.00
0005433613919	25212	Business	132900.00
0005433613763	25212	Business	132900.00
0005433577659	25212	Business	132900.00
0005433577677	25212	Business	132900.00
0005433633380	25212	Business	132900.00
0005433613954	25212	Business	132900.00
0005433613787	25212	Business	132900.00
0005433577681	25212	Business	132900.00
0005434163604	25212	Economy	48700.00
0005433577736	25212	Economy	48700.00
0005433633395	25212	Economy	48700.00
0005433613997	25212	Economy	48700.00
0005433613953	25212	Economy	48700.00
0005433613780	25212	Economy	48700.00
0005433613807	25212	Economy	44300.00
0005433613829	25212	Economy	44300.00
0005433613651	25212	Economy	44300.00
0005433613582	25212	Economy	44300.00
0005434163597	25212	Economy	44300.00
0005434273073	25212	Economy	44300.00
0005433613551	25212	Economy	44300.00
0005433613716	25212	Economy	44300.00
0005433577651	25212	Economy	44300.00
0005433613808	25212	Economy	44300.00
0005433613665	25212	Economy	44300.00
0005433613881	25212	Economy	44300.00
0005433577650	25212	Economy	44300.00
0005433633483	25212	Economy	44300.00
0005433613998	25212	Economy	44300.00
0005433577615	25212	Economy	44300.00
0005433613856	25212	Economy	44300.00
0005433633390	25212	Economy	44300.00
0005433633629	25212	Economy	44300.00
0005433614036	25212	Economy	44300.00
0005433613645	25212	Economy	44300.00
0005433633405	25212	Economy	44300.00
0005433613666	25212	Economy	44300.00
0005433633518	25212	Economy	44300.00
0005433613741	25212	Economy	44300.00
0005433613891	25212	Economy	44300.00
0005433613980	25212	Economy	44300.00
0005433613719	25212	Economy	44300.00
0005433633408	25212	Economy	44300.00
0005433613817	25212	Economy	44300.00
0005433633476	25212	Economy	44300.00
0005433614123	25212	Economy	44300.00
0005433613782	25212	Economy	44300.00
0005433614021	25212	Economy	44300.00
0005434163599	25212	Economy	44300.00
0005434163595	25212	Economy	44300.00
0005433613852	25212	Economy	44300.00
0005433613789	25212	Economy	44300.00
0005433613486	25212	Economy	44300.00
0005433577663	25212	Economy	44300.00
0005433633404	25212	Economy	44300.00
0005433633393	25212	Economy	44300.00
0005434163594	25212	Economy	44300.00
0005433613846	25212	Economy	44300.00
0005433614068	25212	Economy	44300.00
0005434163601	25212	Economy	44300.00
0005433613909	25212	Economy	44300.00
0005433613917	25212	Economy	44300.00
0005433614242	25212	Economy	44300.00
0005433613809	25212	Economy	44300.00
0005433614037	25212	Economy	44300.00
0005433613981	25212	Economy	44300.00
0005433613830	25212	Economy	44300.00
0005433613945	25212	Economy	44300.00
0005433613853	25212	Economy	44300.00
0005433633529	25212	Economy	48700.00
0005434163602	25212	Economy	48700.00
0005433613731	25212	Economy	48700.00
0005433633392	25212	Economy	48700.00
0005433613646	25212	Economy	48700.00
0005433613573	25212	Economy	44300.00
0005433633528	25212	Economy	44300.00
0005433613796	25212	Economy	48700.00
0005433613888	25212	Economy	44300.00
0005433577690	25212	Economy	44300.00
0005433613700	25212	Economy	44300.00
0005433613762	25212	Economy	44300.00
0005433613920	25212	Economy	44300.00
0005433614072	25212	Economy	44300.00
0005433613900	25212	Economy	44300.00
0005434272187	25212	Economy	44300.00
0005433613432	25212	Economy	44300.00
0005433613890	25212	Economy	44300.00
0005433613910	25212	Economy	44300.00
0005433614073	25212	Economy	44300.00
0005433613781	25212	Economy	44300.00
0005433633341	25212	Economy	44300.00
0005434273071	25212	Economy	44300.00
0005433613855	25212	Economy	44300.00
0005433633302	25212	Economy	44300.00
0005433613950	25212	Economy	44300.00
0005433577688	25212	Economy	44300.00
0005433613742	25212	Economy	44300.00
0005433633355	25212	Economy	44300.00
0005433633391	25212	Economy	44300.00
0005433577667	25212	Economy	44300.00
0005433613880	25212	Economy	44300.00
0005433577680	25212	Economy	44300.00
0005433633420	25212	Economy	44300.00
0005433577683	25212	Economy	44300.00
0005433633628	25212	Economy	44300.00
0005434273072	25212	Economy	44300.00
0005433613676	25212	Economy	44300.00
0005433613734	25212	Economy	44300.00
0005433613797	25212	Economy	44300.00
0005433613779	25212	Economy	44300.00
0005433633368	25212	Economy	44300.00
0005434163600	25212	Economy	44300.00
0005433613833	25212	Economy	44300.00
0005433633535	25212	Economy	44300.00
0005433614271	25212	Economy	44300.00
0005433613608	25212	Economy	44300.00
0005433613786	25212	Economy	44300.00
0005433613692	25212	Economy	44300.00
0005433613834	25212	Economy	44300.00
0005433633403	25212	Economy	44300.00
0005433613770	25212	Economy	44300.00
0005433614124	25212	Economy	44300.00
0005433633519	25212	Economy	44300.00
0005433613918	25212	Economy	44300.00
0005433633409	25212	Economy	44300.00
0005433613790	25212	Economy	44300.00
0005433633544	25212	Economy	44300.00
0005433613696	25212	Economy	44300.00
0005434272188	25212	Economy	44300.00
0005433633536	25212	Economy	44300.00
0005433614058	25212	Economy	44300.00
0005434163603	25212	Economy	44300.00
0005434163598	25212	Economy	44300.00
0005433613647	25212	Economy	44300.00
0005433613736	25212	Economy	44300.00
0005433613876	25212	Economy	44300.00
0005434163596	25212	Economy	44300.00
0005433613720	25212	Economy	44300.00
0005434163605	25212	Economy	44300.00
0005433633410	25212	Economy	44300.00
0005433577664	25212	Economy	44300.00
0005435947085	4213	Business	193100.00
0005435947057	4213	Business	193100.00
0005432571286	4213	Business	193100.00
0005435986742	4213	Business	193100.00
0005435947065	4213	Economy	70800.00
0005435947084	4213	Economy	64400.00
0005435947058	4213	Economy	64400.00
0005435986739	4213	Economy	64400.00
0005435986740	4213	Economy	64400.00
0005432184945	4213	Economy	64400.00
0005435947155	4213	Economy	64400.00
0005434271290	4213	Economy	64400.00
0005435947072	4213	Economy	64400.00
0005435947154	4213	Economy	64400.00
0005432184944	4213	Economy	64400.00
0005432571279	4213	Economy	64400.00
0005435986733	4213	Economy	64400.00
0005435947045	4213	Economy	64400.00
0005432571281	4213	Economy	64400.00
0005432184946	4213	Economy	64400.00
0005435986734	4213	Economy	64400.00
0005435947089	4213	Economy	70800.00
0005435986738	4213	Economy	64400.00
0005432571267	4213	Economy	64400.00
0005432571282	4213	Economy	64400.00
0005435947101	4213	Economy	64400.00
0005434271286	4213	Economy	64400.00
0005435947100	4213	Economy	64400.00
0005435986735	4213	Economy	64400.00
0005435947071	4213	Economy	64400.00
0005432571285	4213	Economy	64400.00
0005432184947	4213	Economy	64400.00
0005435947046	4213	Economy	64400.00
0005435986737	4213	Economy	64400.00
0005435947059	4213	Economy	64400.00
0005435986736	4213	Economy	64400.00
0005432184943	4213	Economy	64400.00
0005435986741	4213	Economy	64400.00
0005435947226	26605	Business	193100.00
0005435947230	26605	Business	193100.00
0005435986687	26605	Business	193100.00
0005435986679	26605	Business	193100.00
0005432571316	26605	Business	193100.00
0005435947225	26605	Business	193100.00
0005435986676	26605	Business	193100.00
0005435787353	26605	Economy	70800.00
0005435947227	26605	Economy	64400.00
0005435986690	26605	Economy	64400.00
0005435856195	26605	Economy	64400.00
0005435986675	26605	Economy	64400.00
0005435947233	26605	Economy	64400.00
0005435947220	26605	Economy	64400.00
0005432571318	26605	Economy	64400.00
0005435947221	26605	Economy	64400.00
0005435856194	26605	Economy	64400.00
0005435986686	26605	Economy	64400.00
0005435947234	26605	Economy	64400.00
0005435947229	26605	Economy	64400.00
0005435947228	26605	Economy	64400.00
0005435947224	26605	Economy	64400.00
0005435986674	26605	Economy	64400.00
0005435856197	26605	Economy	64400.00
0005435947231	26605	Economy	64400.00
0005435986666	26605	Economy	64400.00
0005435947232	26605	Economy	64400.00
0005435986655	26605	Economy	64400.00
0005435856196	26605	Economy	64400.00
0005432571317	26605	Economy	64400.00
0005432571319	26605	Economy	64400.00
0005435947223	26605	Economy	64400.00
0005435986672	26605	Economy	64400.00
0005435787351	26605	Economy	64400.00
0005435787350	26605	Economy	64400.00
0005435787352	26605	Economy	64400.00
0005435947222	26605	Economy	64400.00
0005435986678	26605	Economy	64400.00
0005433568949	324	Business	21500.00
0005433074428	324	Business	21500.00
0005433074360	324	Business	21500.00
0005433568987	324	Business	21500.00
0005432948120	324	Business	21500.00
0005433568971	324	Business	21500.00
0005432238926	324	Business	21500.00
0005432947963	324	Business	21500.00
0005432947888	324	Business	21500.00
0005432238925	324	Business	21500.00
0005432238924	324	Business	21500.00
0005433568981	324	Business	21500.00
0005432948016	324	Business	21500.00
0005433568988	324	Business	21500.00
0005432948100	324	Business	21500.00
0005433129220	324	Business	21500.00
0005433568974	324	Business	21500.00
0005433568991	324	Business	21500.00
0005433568951	324	Business	21500.00
0005433074362	324	Business	21500.00
0005433568980	324	Business	21500.00
0005432948033	324	Business	21500.00
0005433568966	324	Business	21500.00
0005433074261	324	Business	21500.00
0005433568967	324	Business	21500.00
0005432947940	324	Economy	7900.00
0005433568955	324	Economy	7900.00
0005433074386	324	Economy	7900.00
0005432948054	324	Economy	7900.00
0005432948000	324	Economy	7200.00
0005433568972	324	Economy	7200.00
0005432948061	324	Economy	7200.00
0005432947942	324	Economy	7200.00
0005432947770	324	Economy	7200.00
0005433568961	324	Economy	7200.00
0005432948072	324	Economy	7200.00
0005433568986	324	Economy	7200.00
0005432948015	324	Economy	7200.00
0005432947800	324	Economy	7200.00
0005433568975	324	Economy	7200.00
0005432948020	324	Economy	7200.00
0005433129208	324	Economy	7200.00
0005433568989	324	Economy	7200.00
0005433568957	324	Economy	7200.00
0005432947998	324	Economy	7200.00
0005433568977	324	Economy	7200.00
0005432947829	324	Economy	7200.00
0005433074484	324	Economy	7200.00
0005433568978	324	Economy	7200.00
0005433074387	324	Economy	7200.00
0005432947799	324	Economy	7200.00
0005433568950	324	Economy	7200.00
0005433074492	324	Economy	7200.00
0005433568968	324	Economy	7200.00
0005433568983	324	Economy	7200.00
0005432947903	324	Economy	7200.00
0005432947935	324	Economy	7200.00
0005433074396	324	Economy	7200.00
0005432948021	324	Economy	7200.00
0005433074361	324	Economy	7200.00
0005432947859	324	Economy	7200.00
0005433568992	324	Economy	7200.00
0005433134091	324	Economy	7200.00
0005433568952	324	Economy	7200.00
0005433568984	324	Economy	7200.00
0005433568958	324	Economy	7200.00
0005432948022	324	Economy	7200.00
0005433568947	324	Economy	7200.00
0005433568970	324	Economy	7200.00
0005432948056	324	Economy	7200.00
0005433568965	324	Economy	7200.00
0005433568954	324	Economy	7200.00
0005433074341	324	Economy	7900.00
0005432947947	324	Economy	7900.00
0005433074476	324	Economy	7900.00
0005432948062	324	Economy	7900.00
0005432947968	324	Economy	7900.00
0005433074421	324	Economy	7200.00
0005433074315	324	Economy	7200.00
0005433074379	324	Economy	7900.00
0005433568946	324	Economy	7200.00
0005433074391	324	Economy	7200.00
0005432948086	324	Economy	7200.00
0005432947941	324	Economy	7200.00
0005433568993	324	Economy	7200.00
0005432947999	324	Economy	7200.00
0005433074353	324	Economy	7200.00
0005432238927	324	Economy	7200.00
0005433568960	324	Economy	7200.00
0005433568979	324	Economy	7200.00
0005432947858	324	Economy	7200.00
0005433568985	324	Economy	7200.00
0005433568959	324	Economy	7200.00
0005433568964	324	Economy	7200.00
0005433129207	324	Economy	7200.00
0005432948018	324	Economy	7200.00
0005433074493	324	Economy	7200.00
0005433074279	324	Economy	7200.00
0005432948070	324	Economy	7200.00
0005432947939	324	Economy	7200.00
0005433568990	324	Economy	7200.00
0005432947934	324	Economy	7200.00
0005433568982	324	Economy	7200.00
0005433074336	324	Economy	7200.00
0005433074497	324	Economy	7200.00
0005432947997	324	Economy	7200.00
0005432948035	324	Economy	7200.00
0005432238923	324	Economy	7200.00
0005433568962	324	Economy	7200.00
0005432947962	324	Economy	7200.00
0005432947896	324	Economy	7200.00
0005433074483	324	Economy	7200.00
0005433074376	324	Economy	7200.00
0005433568953	324	Economy	7200.00
0005432947771	324	Economy	7200.00
0005433568963	324	Economy	7200.00
0005432948108	324	Economy	7200.00
0005432948030	324	Economy	7200.00
0005432948003	324	Economy	7200.00
0005432948109	324	Economy	7200.00
0005432947804	324	Economy	7200.00
0005432947919	324	Economy	7200.00
0005433568969	324	Economy	7200.00
0005433074477	324	Economy	7200.00
0005432948017	324	Economy	7200.00
0005433568956	324	Economy	7200.00
0005432948044	324	Economy	7200.00
0005432947887	324	Economy	7200.00
0005433568948	324	Economy	7200.00
0005433568973	324	Economy	7200.00
0005433074319	324	Economy	7200.00
0005433568976	324	Economy	7200.00
0005433568243	11616	Business	21500.00
0005433568350	11616	Business	21500.00
0005432948383	11616	Business	21500.00
0005433074663	11616	Business	21500.00
0005433074650	11616	Business	21500.00
0005433568420	11616	Business	21500.00
0005432192314	11616	Business	21500.00
0005433568234	11616	Business	21500.00
0005433568429	11616	Business	21500.00
0005432948378	11616	Business	21500.00
0005433568167	11616	Business	21500.00
0005433074641	11616	Business	21500.00
0005432948375	11616	Business	21500.00
0005433074660	11616	Business	21500.00
0005433074647	11616	Business	21500.00
0005432948351	11616	Business	21500.00
0005433074638	11616	Business	21500.00
0005433131699	11616	Business	21500.00
0005433568364	11616	Business	21500.00
0005433074657	11616	Business	21500.00
0005432948377	11616	Business	21500.00
0005432948360	11616	Business	21500.00
0005432948353	11616	Business	21500.00
0005433568461	11616	Business	21500.00
0005433074635	11616	Business	21500.00
0005432948380	11616	Economy	7900.00
0005433568378	11616	Economy	7900.00
0005432948364	11616	Economy	7900.00
0005433074648	11616	Economy	7900.00
0005432948371	11616	Economy	7900.00
0005433568335	11616	Economy	7900.00
0005433568345	11616	Economy	7200.00
0005432948357	11616	Economy	7200.00
0005432948361	11616	Economy	7200.00
0005433134126	11616	Economy	7200.00
0005432948368	11616	Economy	7200.00
0005433134127	11616	Economy	7200.00
0005433568464	11616	Economy	7200.00
0005432948352	11616	Economy	7200.00
0005433074662	11616	Economy	7200.00
0005433568253	11616	Economy	7200.00
0005432948348	11616	Economy	7200.00
0005433568367	11616	Economy	7200.00
0005432948379	11616	Economy	7200.00
0005433074658	11616	Economy	7200.00
0005433074639	11616	Economy	7200.00
0005433568430	11616	Economy	7200.00
0005433131698	11616	Economy	7200.00
0005433134128	11616	Economy	7200.00
0005433568418	11616	Economy	7200.00
0005432948376	11616	Economy	7200.00
0005433131697	11616	Economy	7200.00
0005433568135	11616	Economy	7200.00
0005433568150	11616	Economy	7200.00
0005433929857	11616	Economy	7200.00
0005433568377	11616	Economy	7200.00
0005433568365	11616	Economy	7200.00
0005432948387	11616	Economy	7200.00
0005433074661	11616	Economy	7200.00
0005433074654	11616	Economy	7200.00
0005432948381	11616	Economy	7200.00
0005433568085	11616	Economy	7200.00
0005433568521	11616	Economy	7200.00
0005432948367	11616	Economy	7200.00
0005432948374	11616	Economy	7200.00
0005433568187	11616	Economy	7200.00
0005433568133	11616	Economy	7200.00
0005433134130	11616	Economy	7200.00
0005433568262	11616	Economy	7200.00
0005433568044	11616	Economy	7200.00
0005433074646	11616	Economy	7200.00
0005433568421	11616	Economy	7200.00
0005432948355	11616	Economy	7200.00
0005433568338	11616	Economy	7200.00
0005433568298	11616	Economy	7200.00
0005433568043	11616	Economy	7200.00
0005433568446	11616	Economy	7200.00
0005433568370	11616	Economy	7200.00
0005433568447	11616	Economy	7200.00
0005433074642	11616	Economy	7200.00
0005433568533	11616	Economy	7200.00
0005433074640	11616	Economy	7900.00
0005432192315	11616	Economy	7900.00
0005432948362	11616	Economy	7900.00
0005433131700	11616	Economy	7900.00
0005432948386	11616	Economy	7200.00
0005433568448	11616	Economy	7900.00
0005433568402	11616	Economy	7200.00
0005432948384	11616	Economy	7200.00
0005433568235	11616	Economy	7900.00
0005432948382	11616	Economy	7200.00
0005433568316	11616	Economy	7200.00
0005433074659	11616	Economy	7200.00
0005433074636	11616	Economy	7200.00
0005433568181	11616	Economy	7200.00
0005432948373	11616	Economy	7200.00
0005433568405	11616	Economy	7200.00
0005432948354	11616	Economy	7200.00
0005433568371	11616	Economy	7200.00
0005433568292	11616	Economy	7200.00
0005433074643	11616	Economy	7200.00
0005433074637	11616	Economy	7200.00
0005433131696	11616	Economy	7200.00
0005433568353	11616	Economy	7200.00
0005432948370	11616	Economy	7200.00
0005433568297	11616	Economy	7200.00
0005432948347	11616	Economy	7200.00
0005433074644	11616	Economy	7200.00
0005433134129	11616	Economy	7200.00
0005433074652	11616	Economy	7200.00
0005433568060	11616	Economy	7200.00
0005432948363	11616	Economy	7200.00
0005432948372	11616	Economy	7200.00
0005432948366	11616	Economy	7200.00
0005433568366	11616	Economy	7200.00
0005433568374	11616	Economy	7200.00
0005433074651	11616	Economy	7200.00
0005433568401	11616	Economy	7200.00
0005433568476	11616	Economy	7200.00
0005432192313	11616	Economy	7200.00
0005433074634	11616	Economy	7200.00
0005432948359	11616	Economy	7200.00
0005433074653	11616	Economy	7200.00
0005433568336	11616	Economy	7200.00
0005433568478	11616	Economy	7200.00
0005433074656	11616	Economy	7200.00
0005432948358	11616	Economy	7200.00
0005432948350	11616	Economy	7200.00
0005433568163	11616	Economy	7200.00
0005433568040	11616	Economy	7200.00
0005432948356	11616	Economy	7200.00
0005432948365	11616	Economy	7200.00
0005433568233	11616	Economy	7200.00
0005432948388	11616	Economy	7200.00
0005433074655	11616	Economy	7200.00
0005432948385	11616	Economy	7200.00
0005433568483	11616	Economy	7200.00
0005432948349	11616	Economy	7200.00
0005432948369	11616	Economy	7200.00
0005433074649	11616	Economy	7200.00
0005432192312	11616	Economy	7200.00
0005433074645	11616	Economy	7200.00
0005433568337	11616	Economy	7200.00
0005434732967	10043	Economy	6300.00
0005433817464	10043	Economy	6300.00
0005433817461	10043	Economy	6300.00
0005433817463	10043	Economy	6300.00
0005433817462	10043	Economy	6300.00
0005434732959	10043	Economy	6300.00
0005434732960	10043	Economy	6300.00
0005434732974	13951	Economy	6300.00
0005434732975	13951	Economy	6300.00
0005434732976	13951	Economy	6300.00
0005434732973	13951	Economy	6300.00
0005435982209	2355	Business	184500.00
0005433754115	2355	Business	184500.00
0005435982208	2355	Business	184500.00
0005435982226	2355	Business	184500.00
0005433754122	2355	Business	184500.00
0005433754134	2355	Business	184500.00
0005432300250	2355	Business	184500.00
0005433754095	2355	Business	184500.00
0005432226046	2355	Business	184500.00
0005434731120	2355	Business	184500.00
0005432984924	2355	Business	184500.00
0005433754100	2355	Business	184500.00
0005432984758	2355	Business	184500.00
0005433754128	2355	Business	184500.00
0005435982230	2355	Business	184500.00
0005432984720	2355	Business	184500.00
0005432984704	2355	Business	184500.00
0005433434374	2355	Business	184500.00
0005432984809	2355	Business	184500.00
0005432300251	2355	Business	184500.00
0005435982228	2355	Business	184500.00
0005433754097	2355	Business	184500.00
0005435982237	2355	Business	184500.00
0005433434351	2355	Business	184500.00
0005433434384	2355	Business	184500.00
0005433754110	2355	Business	184500.00
0005432984739	2355	Economy	67700.00
0005433434359	2355	Economy	67700.00
0005432655519	2355	Economy	67700.00
0005433434390	2355	Economy	67700.00
0005433764675	2355	Economy	61500.00
0005433754125	2355	Economy	61500.00
0005435982227	2355	Economy	61500.00
0005433754120	2355	Economy	61500.00
0005432655516	2355	Economy	61500.00
0005432655514	2355	Economy	61500.00
0005432984674	2355	Economy	61500.00
0005435982229	2355	Economy	61500.00
0005432869418	2355	Economy	61500.00
0005433754109	2355	Economy	61500.00
0005433754111	2355	Economy	61500.00
0005433434415	2355	Economy	61500.00
0005432226043	2355	Economy	61500.00
0005433434306	2355	Economy	61500.00
0005433754133	2355	Economy	61500.00
0005432984705	2355	Economy	61500.00
0005433754087	2355	Economy	61500.00
0005433434469	2355	Economy	61500.00
0005435982217	2355	Economy	61500.00
0005432984703	2355	Economy	61500.00
0005432984781	2355	Economy	61500.00
0005432984681	2355	Economy	61500.00
0005433434305	2355	Economy	61500.00
0005433754141	2355	Economy	61500.00
0005433434385	2355	Economy	61500.00
0005435982211	2355	Economy	61500.00
0005433754104	2355	Economy	61500.00
0005432984792	2355	Economy	61500.00
0005433766634	2355	Economy	61500.00
0005432984777	2355	Economy	61500.00
0005432984760	2355	Economy	61500.00
0005433754106	2355	Economy	61500.00
0005435982234	2355	Economy	61500.00
0005433434438	2355	Economy	61500.00
0005432984816	2355	Economy	61500.00
0005435982210	2355	Economy	61500.00
0005433434484	2355	Economy	61500.00
0005432226045	2355	Economy	61500.00
0005432984783	2355	Economy	61500.00
0005433754138	2355	Economy	61500.00
0005435982214	2355	Economy	61500.00
0005432984610	2355	Economy	61500.00
0005435982196	2355	Economy	61500.00
0005432984746	2355	Economy	61500.00
0005435982201	2355	Economy	61500.00
0005432984676	2355	Economy	61500.00
0005433754140	2355	Economy	61500.00
0005433754139	2355	Economy	61500.00
0005433766631	2355	Economy	61500.00
0005433754118	2355	Economy	61500.00
0005432655517	2355	Economy	61500.00
0005433434489	2355	Economy	61500.00
0005433754085	2355	Economy	61500.00
0005435982238	2355	Economy	61500.00
0005435982213	2355	Economy	61500.00
0005433754116	2355	Economy	61500.00
0005433754113	2355	Economy	61500.00
0005433764676	2355	Economy	61500.00
0005432984793	2355	Economy	61500.00
0005433754089	2355	Economy	61500.00
0005433754103	2355	Economy	61500.00
0005433434271	2355	Economy	61500.00
0005435982207	2355	Economy	61500.00
0005432984823	2355	Economy	61500.00
0005433434398	2355	Economy	61500.00
0005432869449	2355	Economy	61500.00
0005433754132	2355	Economy	61500.00
0005435982216	2355	Economy	61500.00
0005433434437	2355	Economy	61500.00
0005433754129	2355	Economy	61500.00
0005435982240	2355	Economy	61500.00
0005435982198	2355	Economy	61500.00
0005435982220	2355	Economy	61500.00
0005433754137	2355	Economy	61500.00
0005432984921	2355	Economy	61500.00
0005433754127	2355	Economy	61500.00
0005432984815	2355	Economy	61500.00
0005433754086	2355	Economy	61500.00
0005435982199	2355	Economy	61500.00
0005435982239	2355	Economy	61500.00
0005432984765	2355	Economy	61500.00
0005432984802	2355	Economy	61500.00
0005435982212	2355	Economy	61500.00
0005434731121	2355	Economy	61500.00
0005432984808	2355	Economy	61500.00
0005433754130	2355	Economy	61500.00
0005433434393	2355	Economy	61500.00
0005433754117	2355	Economy	61500.00
0005433754084	2355	Economy	61500.00
0005435982200	2355	Economy	61500.00
0005432984804	2355	Economy	61500.00
0005433754123	2355	Economy	61500.00
0005432655510	2355	Economy	61500.00
0005433434488	2355	Economy	61500.00
0005435982225	2355	Economy	61500.00
0005432226042	2355	Economy	61500.00
0005432984723	2355	Economy	67700.00
0005433754099	2355	Economy	61500.00
0005435982215	2355	Economy	67700.00
0005433434473	2355	Economy	61500.00
0005433754093	2355	Economy	61500.00
0005433434472	2355	Economy	67700.00
0005432984764	2355	Economy	67700.00
0005435982236	2355	Economy	61500.00
0005433754092	2355	Economy	61500.00
0005435982206	2355	Economy	61500.00
0005432984782	2355	Economy	61500.00
0005433754126	2355	Economy	61500.00
0005433754135	2355	Economy	61500.00
0005432655518	2355	Economy	61500.00
0005432300252	2355	Economy	61500.00
0005435982232	2355	Economy	61500.00
0005435982224	2355	Economy	61500.00
0005433766633	2355	Economy	61500.00
0005435982197	2355	Economy	61500.00
0005433434456	2355	Economy	61500.00
0005432984810	2355	Economy	61500.00
0005435982222	2355	Economy	61500.00
0005432984794	2355	Economy	61500.00
0005435982231	2355	Economy	61500.00
0005434731140	2355	Economy	61500.00
0005433754101	2355	Economy	61500.00
0005432655520	2355	Economy	61500.00
0005433754088	2355	Economy	61500.00
0005433754131	2355	Economy	61500.00
0005433766632	2355	Economy	61500.00
0005433754090	2355	Economy	61500.00
0005432984713	2355	Economy	61500.00
0005433754108	2355	Economy	61500.00
0005435982233	2355	Economy	61500.00
0005435982205	2355	Economy	61500.00
0005435982223	2355	Economy	61500.00
0005433754121	2355	Economy	61500.00
0005432984737	2355	Economy	61500.00
0005432869451	2355	Economy	61500.00
0005433434435	2355	Economy	61500.00
0005435982235	2355	Economy	61500.00
0005433754119	2355	Economy	61500.00
0005433434307	2355	Economy	61500.00
0005432655515	2355	Economy	61500.00
0005432869450	2355	Economy	61500.00
0005433754107	2355	Economy	61500.00
0005433754102	2355	Economy	61500.00
0005433754096	2355	Economy	61500.00
0005433754091	2355	Economy	61500.00
0005432655513	2355	Economy	61500.00
0005432300254	2355	Economy	61500.00
0005432226044	2355	Economy	61500.00
0005433434457	2355	Economy	61500.00
0005433754136	2355	Economy	61500.00
0005433754112	2355	Economy	61500.00
0005435982203	2355	Economy	61500.00
0005432226047	2355	Economy	61500.00
0005432655511	2355	Economy	61500.00
0005432300253	2355	Economy	61500.00
0005433434358	2355	Economy	61500.00
0005433434416	2355	Economy	61500.00
0005432984637	2355	Economy	61500.00
0005435982218	2355	Economy	61500.00
0005432984773	2355	Economy	61500.00
0005435982202	2355	Economy	61500.00
0005432984750	2355	Economy	61500.00
0005432226048	2355	Economy	61500.00
0005435982219	2355	Economy	61500.00
0005433754114	2355	Economy	61500.00
0005432984778	2355	Economy	61500.00
0005433754124	2355	Economy	61500.00
0005432984803	2355	Economy	61500.00
0005433754098	2355	Economy	61500.00
0005433754094	2355	Economy	61500.00
0005434731119	2355	Economy	61500.00
0005432655509	2355	Economy	61500.00
0005432655512	2355	Economy	61500.00
0005432984738	2355	Economy	61500.00
0005433754105	2355	Economy	61500.00
0005432984763	2355	Economy	61500.00
0005435982204	2355	Economy	61500.00
0005435982221	2355	Economy	61500.00
0005433766604	26172	Business	184500.00
0005433753567	26172	Business	184500.00
0005433434628	26172	Business	184500.00
0005433753682	26172	Business	184500.00
0005433753890	26172	Business	184500.00
0005432985016	26172	Business	184500.00
0005433434619	26172	Business	184500.00
0005433434623	26172	Business	184500.00
0005432655333	26172	Business	184500.00
0005433753687	26172	Business	184500.00
0005435981614	26172	Business	184500.00
0005432985003	26172	Business	184500.00
0005432869508	26172	Business	184500.00
0005433753516	26172	Business	184500.00
0005433753542	26172	Business	184500.00
0005435981872	26172	Business	184500.00
0005433753659	26172	Business	184500.00
0005435981740	26172	Business	184500.00
0005432984999	26172	Business	184500.00
0005432985010	26172	Business	184500.00
0005432869509	26172	Business	184500.00
0005433753851	26172	Business	184500.00
0005432869507	26172	Business	184500.00
0005432985011	26172	Business	184500.00
0005433753566	26172	Business	184500.00
0005432985004	26172	Business	184500.00
0005435981708	26172	Business	184500.00
0005432985018	26172	Economy	67700.00
0005433753616	26172	Economy	67700.00
0005433753392	26172	Economy	67700.00
0005433434633	26172	Economy	61500.00
0005433753762	26172	Economy	61500.00
0005433753670	26172	Economy	61500.00
0005432869510	26172	Economy	61500.00
0005433434621	26172	Economy	61500.00
0005432985007	26172	Economy	61500.00
0005433766579	26172	Economy	61500.00
0005433434627	26172	Economy	61500.00
0005433434617	26172	Economy	61500.00
0005432985008	26172	Economy	61500.00
0005432985014	26172	Economy	61500.00
0005435981801	26172	Economy	61500.00
0005432985005	26172	Economy	61500.00
0005435981790	26172	Economy	61500.00
0005432655435	26172	Economy	61500.00
0005433753661	26172	Economy	61500.00
0005433753634	26172	Economy	61500.00
0005433753605	26172	Economy	61500.00
0005433434614	26172	Economy	61500.00
0005433753702	26172	Economy	61500.00
0005435981847	26172	Economy	61500.00
0005433434613	26172	Economy	61500.00
0005433753543	26172	Economy	61500.00
0005432985017	26172	Economy	61500.00
0005433753693	26172	Economy	61500.00
0005433753465	26172	Economy	61500.00
0005433434637	26172	Economy	61500.00
0005433753583	26172	Economy	61500.00
0005435981716	26172	Economy	61500.00
0005433753666	26172	Economy	61500.00
0005433434639	26172	Economy	61500.00
0005433753635	26172	Economy	61500.00
0005434731161	26172	Economy	61500.00
0005433434624	26172	Economy	61500.00
0005432985000	26172	Economy	61500.00
0005435981778	26172	Economy	61500.00
0005432985027	26172	Economy	61500.00
0005433753555	26172	Economy	61500.00
0005432985020	26172	Economy	61500.00
0005433434634	26172	Economy	61500.00
0005433766581	26172	Economy	61500.00
0005433753676	26172	Economy	61500.00
0005433753556	26172	Economy	61500.00
0005432655380	26172	Economy	61500.00
0005432049456	26172	Economy	61500.00
0005432655433	26172	Economy	61500.00
0005435981870	26172	Economy	61500.00
0005433753780	26172	Economy	61500.00
0005433753736	26172	Economy	61500.00
0005433434626	26172	Economy	61500.00
0005435981610	26172	Economy	61500.00
0005432985025	26172	Economy	61500.00
0005432985009	26172	Economy	61500.00
0005433753466	26172	Economy	61500.00
0005435981789	26172	Economy	61500.00
0005433434620	26172	Economy	61500.00
0005435981712	26172	Economy	61500.00
0005433434631	26172	Economy	61500.00
0005433434635	26172	Economy	61500.00
0005435981798	26172	Economy	61500.00
0005432985002	26172	Economy	61500.00
0005433753573	26172	Economy	61500.00
0005435981741	26172	Economy	61500.00
0005432985019	26172	Economy	61500.00
0005433753525	26172	Economy	61500.00
0005433753483	26172	Economy	61500.00
0005435981754	26172	Economy	61500.00
0005435981613	26172	Economy	61500.00
0005435981822	26172	Economy	61500.00
0005433753655	26172	Economy	61500.00
0005433434638	26172	Economy	61500.00
0005434731165	26172	Economy	61500.00
0005435981690	26172	Economy	61500.00
0005433753617	26172	Economy	61500.00
0005433753373	26172	Economy	61500.00
0005432985024	26172	Economy	61500.00
0005433753590	26172	Economy	61500.00
0005433434622	26172	Economy	61500.00
0005433753606	26172	Economy	61500.00
0005433753690	26172	Economy	61500.00
0005432049458	26172	Economy	61500.00
0005433753660	26172	Economy	61500.00
0005435981840	26172	Economy	61500.00
0005433753403	26172	Economy	61500.00
0005433434612	26172	Economy	61500.00
0005432985030	26172	Economy	61500.00
0005433753665	26172	Economy	61500.00
0005434731163	26172	Economy	61500.00
0005435981802	26172	Economy	61500.00
0005433766603	26172	Economy	61500.00
0005433766595	26172	Economy	61500.00
0005432655391	26172	Economy	61500.00
0005433753574	26172	Economy	61500.00
0005432985012	26172	Economy	61500.00
0005433753698	26172	Economy	61500.00
0005432051121	26172	Economy	61500.00
0005433753763	26172	Economy	61500.00
0005433753727	26172	Economy	67700.00
0005435981779	26172	Economy	61500.00
0005435981823	26172	Economy	61500.00
0005433753620	26172	Economy	67700.00
0005435981786	26172	Economy	61500.00
0005433753772	26172	Economy	67700.00
0005435981877	26172	Economy	61500.00
0005435981726	26172	Economy	67700.00
0005434731164	26172	Economy	61500.00
0005433766605	26172	Economy	61500.00
0005435981825	26172	Economy	61500.00
0005434731162	26172	Economy	61500.00
0005432985006	26172	Economy	61500.00
0005435981794	26172	Economy	61500.00
0005433753808	26172	Economy	61500.00
0005432984998	26172	Economy	61500.00
0005435981780	26172	Economy	61500.00
0005432655429	26172	Economy	61500.00
0005433753456	26172	Economy	61500.00
0005432655378	26172	Economy	61500.00
0005432985015	26172	Economy	61500.00
0005433753532	26172	Economy	61500.00
0005435981777	26172	Economy	61500.00
0005433753457	26172	Economy	61500.00
0005432985028	26172	Economy	61500.00
0005435981871	26172	Economy	61500.00
0005433753526	26172	Economy	61500.00
0005432985023	26172	Economy	61500.00
0005432985021	26172	Economy	61500.00
0005433753649	26172	Economy	61500.00
0005433753701	26172	Economy	61500.00
0005435981742	26172	Economy	61500.00
0005435981839	26172	Economy	61500.00
0005435981782	26172	Economy	61500.00
0005435981653	26172	Economy	61500.00
0005435981824	26172	Economy	61500.00
0005432655377	26172	Economy	61500.00
0005432655434	26172	Economy	61500.00
0005435981665	26172	Economy	61500.00
0005433753798	26172	Economy	61500.00
0005433753462	26172	Economy	61500.00
0005435981664	26172	Economy	61500.00
0005432049457	26172	Economy	61500.00
0005432985026	26172	Economy	61500.00
0005435981711	26172	Economy	61500.00
0005433753501	26172	Economy	61500.00
0005432051122	26172	Economy	61500.00
0005435981791	26172	Economy	61500.00
0005433753529	26172	Economy	61500.00
0005432985022	26172	Economy	61500.00
0005435981674	26172	Economy	61500.00
0005433434615	26172	Economy	61500.00
0005435981729	26172	Economy	61500.00
0005433753534	26172	Economy	61500.00
0005433753733	26172	Economy	61500.00
0005433753602	26172	Economy	61500.00
0005433434629	26172	Economy	61500.00
0005432051123	26172	Economy	61500.00
0005433753603	26172	Economy	61500.00
0005433753544	26172	Economy	61500.00
0005433434630	26172	Economy	61500.00
0005433434616	26172	Economy	61500.00
0005432985029	26172	Economy	61500.00
0005433753664	26172	Economy	61500.00
0005432869511	26172	Economy	61500.00
0005433434618	26172	Economy	61500.00
0005433753694	26172	Economy	61500.00
0005433753891	26172	Economy	61500.00
0005433434636	26172	Economy	61500.00
0005435981785	26172	Economy	61500.00
0005433753672	26172	Economy	61500.00
0005432655332	26172	Economy	61500.00
0005432985001	26172	Economy	61500.00
0005433434625	26172	Economy	61500.00
0005433753734	26172	Economy	61500.00
0005433766580	26172	Economy	61500.00
0005432985013	26172	Economy	61500.00
0005433764659	26172	Economy	61500.00
0005433753395	26172	Economy	61500.00
0005433434632	26172	Economy	61500.00
0005433150917	1540	Business	38900.00
0005433151047	1540	Business	38900.00
0005434374591	1540	Business	38900.00
0005434374599	1540	Business	38900.00
0005433151028	1540	Business	38900.00
0005433151070	1540	Business	38900.00
0005433461583	1540	Business	38900.00
0005434029632	1540	Business	38900.00
0005434374590	1540	Business	38900.00
0005433151145	1540	Business	38900.00
0005433150999	1540	Economy	13000.00
0005434374573	1540	Economy	13000.00
0005433460432	1540	Economy	13000.00
0005434374574	1540	Economy	13000.00
0005433764654	1540	Economy	13000.00
0005433151077	1540	Economy	13000.00
0005433151223	1540	Economy	13000.00
0005434374593	1540	Economy	13000.00
0005433150911	1540	Economy	13000.00
0005433151048	1540	Economy	13000.00
0005434374604	1540	Economy	13000.00
0005433150970	1540	Economy	13000.00
0005433461584	1540	Economy	13000.00
0005433151199	1540	Economy	13000.00
0005433151139	1540	Economy	13000.00
0005434374585	1540	Economy	13000.00
0005433151238	1540	Economy	13000.00
0005434374577	1540	Economy	13000.00
0005434374592	1540	Economy	13000.00
0005433151063	1540	Economy	13000.00
0005434374595	1540	Economy	13000.00
0005433151170	1540	Economy	13000.00
0005432267881	1540	Economy	13000.00
0005433151125	1540	Economy	13000.00
0005434374588	1540	Economy	13000.00
0005434374598	1540	Economy	13000.00
0005433150973	1540	Economy	13000.00
0005434374602	1540	Economy	13000.00
0005434374584	1540	Economy	13000.00
0005432267880	1540	Economy	14300.00
0005434374572	1540	Economy	14300.00
0005433151020	1540	Economy	14300.00
0005434374571	1540	Economy	14300.00
0005432267883	1540	Economy	14300.00
0005433151177	1540	Economy	13000.00
0005433151246	1540	Economy	13000.00
0005433150918	1540	Economy	13000.00
0005434374569	1540	Economy	13000.00
0005434374581	1540	Economy	13000.00
0005434374600	1540	Economy	13000.00
0005434374568	1540	Economy	13000.00
0005434374570	1540	Economy	13000.00
0005433764666	1540	Economy	13000.00
0005433150934	1540	Economy	13000.00
0005434374578	1540	Economy	13000.00
0005434374603	1540	Economy	13000.00
0005434374580	1540	Economy	13000.00
0005433151176	1540	Economy	13000.00
0005434374586	1540	Economy	13000.00
0005433151207	1540	Economy	13000.00
0005433151093	1540	Economy	13000.00
0005434374582	1540	Economy	13000.00
0005433151098	1540	Economy	13000.00
0005432267884	1540	Economy	13000.00
0005433151146	1540	Economy	13000.00
0005432267885	1540	Economy	13000.00
0005433151071	1540	Economy	13000.00
0005433150972	1540	Economy	13000.00
0005433151027	1540	Economy	13000.00
0005434374579	1540	Economy	13000.00
0005432267882	1540	Economy	13000.00
0005434374567	1540	Economy	13000.00
0005433151130	1540	Economy	13000.00
0005433764665	1540	Economy	13000.00
0005433151114	1540	Economy	13000.00
0005433151131	1540	Economy	13000.00
0005434374601	1540	Economy	13000.00
0005433460431	1540	Economy	13000.00
0005433151099	1540	Economy	13000.00
0005433151193	1540	Economy	13000.00
0005434374576	1540	Economy	13000.00
0005433150910	1540	Economy	13000.00
0005434374575	1540	Economy	13000.00
0005433151119	1540	Economy	13000.00
0005434374596	1540	Economy	13000.00
0005433764663	1540	Economy	13000.00
0005433151016	1540	Economy	13000.00
0005433151190	1540	Economy	13000.00
0005433150975	1540	Economy	13000.00
0005433151111	1540	Economy	13000.00
0005433151021	1540	Economy	13000.00
0005433151198	1540	Economy	13000.00
0005434374589	1540	Economy	13000.00
0005434374583	1540	Economy	13000.00
0005434374594	1540	Economy	13000.00
0005434374587	1540	Economy	13000.00
0005434374597	1540	Economy	13000.00
0005433151214	1540	Economy	13000.00
0005433151237	1540	Economy	13000.00
0005433150974	1540	Economy	13000.00
0005433151324	20151	Business	38900.00
0005433151346	20151	Business	38900.00
0005433151355	20151	Business	38900.00
0005434374148	20151	Business	38900.00
0005433151352	20151	Business	38900.00
0005434374107	20151	Business	38900.00
0005434374092	20151	Business	38900.00
0005434374013	20151	Business	38900.00
0005433151321	20151	Economy	13000.00
0005433151322	20151	Economy	13000.00
0005433151356	20151	Economy	13000.00
0005434374028	20151	Economy	13000.00
0005434374165	20151	Economy	13000.00
0005434374133	20151	Economy	13000.00
0005433764676	20151	Economy	13000.00
0005434029652	20151	Economy	13000.00
0005434374118	20151	Economy	13000.00
0005434374125	20151	Economy	13000.00
0005433151342	20151	Economy	13000.00
0005434374135	20151	Economy	13000.00
0005434374121	20151	Economy	13000.00
0005434374241	20151	Economy	13000.00
0005434374181	20151	Economy	13000.00
0005433151347	20151	Economy	13000.00
0005434374375	20151	Economy	13000.00
0005434374124	20151	Economy	13000.00
0005434374160	20151	Economy	13000.00
0005433151349	20151	Economy	13000.00
0005433151326	20151	Economy	13000.00
0005434374077	20151	Economy	13000.00
0005433151329	20151	Economy	13000.00
0005434374153	20151	Economy	13000.00
0005433151323	20151	Economy	13000.00
0005434374162	20151	Economy	13000.00
0005434374068	20151	Economy	13000.00
0005433151328	20151	Economy	14300.00
0005433151341	20151	Economy	14300.00
0005434374087	20151	Economy	14300.00
0005433151340	20151	Economy	14300.00
0005434374281	20151	Economy	14300.00
0005434373883	20151	Economy	13000.00
0005433151327	20151	Economy	13000.00
0005434374070	20151	Economy	13000.00
0005434374134	20151	Economy	13000.00
0005433151350	20151	Economy	13000.00
0005433151331	20151	Economy	13000.00
0005433151338	20151	Economy	13000.00
0005434374091	20151	Economy	13000.00
0005434029651	20151	Economy	13000.00
0005434374355	20151	Economy	13000.00
0005432056292	20151	Economy	13000.00
0005433151337	20151	Economy	13000.00
0005433151348	20151	Economy	13000.00
0005434374198	20151	Economy	13000.00
0005434029653	20151	Economy	13000.00
0005434374089	20151	Economy	13000.00
0005434374239	20151	Economy	13000.00
0005434374317	20151	Economy	13000.00
0005434374182	20151	Economy	13000.00
0005433151354	20151	Economy	13000.00
0005434374161	20151	Economy	13000.00
0005433151344	20151	Economy	13000.00
0005434374088	20151	Economy	13000.00
0005433151339	20151	Economy	13000.00
0005434374164	20151	Economy	13000.00
0005433151336	20151	Economy	13000.00
0005434374340	20151	Economy	13000.00
0005434374073	20151	Economy	13000.00
0005433151335	20151	Economy	13000.00
0005433151345	20151	Economy	13000.00
0005434374193	20151	Economy	13000.00
0005432056291	20151	Economy	13000.00
0005433764675	20151	Economy	13000.00
0005434374208	20151	Economy	13000.00
0005434374147	20151	Economy	13000.00
0005434374238	20151	Economy	13000.00
0005434374258	20151	Economy	13000.00
0005433151343	20151	Economy	13000.00
0005434374069	20151	Economy	13000.00
0005434374349	20151	Economy	13000.00
0005434374291	20151	Economy	13000.00
0005433151332	20151	Economy	13000.00
0005434374180	20151	Economy	13000.00
0005433151333	20151	Economy	13000.00
0005434374357	20151	Economy	13000.00
0005434374197	20151	Economy	13000.00
0005434374103	20151	Economy	13000.00
0005433151334	20151	Economy	13000.00
0005434374146	20151	Economy	13000.00
0005434374442	20151	Economy	13000.00
0005433151330	20151	Economy	13000.00
0005433151353	20151	Economy	13000.00
0005434374114	20151	Economy	13000.00
0005433151351	20151	Economy	13000.00
0005434374356	20151	Economy	13000.00
0005433151325	20151	Economy	13000.00
0005432424359	512	Business	27500.00
0005432424366	512	Business	27500.00
0005432424371	512	Business	27500.00
0005432424369	512	Business	27500.00
0005432282850	512	Business	27500.00
0005432424355	512	Business	27500.00
0005432424337	512	Business	27500.00
0005432282851	512	Business	27500.00
0005432282849	512	Business	27500.00
0005432424346	512	Business	27500.00
0005432424333	512	Business	27500.00
0005432424362	512	Economy	10100.00
0005432424374	512	Economy	10100.00
0005432424357	512	Economy	9200.00
0005432424375	512	Economy	9200.00
0005432424365	512	Economy	9200.00
0005432282848	512	Economy	9200.00
0005432424345	512	Economy	9200.00
0005432424368	512	Economy	9200.00
0005432424324	512	Economy	9200.00
0005432424372	512	Economy	9200.00
0005432424353	512	Economy	9200.00
0005432424373	512	Economy	9200.00
0005432424330	512	Economy	9200.00
0005432424363	512	Economy	9200.00
0005432424342	512	Economy	9200.00
0005432424348	512	Economy	9200.00
0005432282853	512	Economy	9200.00
0005432424339	512	Economy	9200.00
0005432424350	512	Economy	9200.00
0005432424358	512	Economy	9200.00
0005432424370	512	Economy	9200.00
0005432424328	512	Economy	10100.00
0005432424351	512	Economy	9200.00
0005432424338	512	Economy	10100.00
0005432424340	512	Economy	9200.00
0005432424347	512	Economy	9200.00
0005432424349	512	Economy	9200.00
0005432424334	512	Economy	9200.00
0005432424326	512	Economy	9200.00
0005432424360	512	Economy	9200.00
0005432424354	512	Economy	9200.00
0005432424331	512	Economy	9200.00
0005432424352	512	Economy	9200.00
0005432424329	512	Economy	9200.00
0005432424356	512	Economy	9200.00
0005432424335	512	Economy	9200.00
0005432424341	512	Economy	9200.00
0005432424336	512	Economy	9200.00
0005432282852	512	Economy	9200.00
0005432424344	512	Economy	9200.00
0005432424361	512	Economy	9200.00
0005432424332	512	Economy	9200.00
0005432424343	512	Economy	9200.00
0005432424364	512	Economy	9200.00
0005432424325	512	Economy	9200.00
0005432424327	512	Economy	9200.00
0005432424367	512	Economy	9200.00
0005432302322	12940	Economy	10100.00
0005432302323	12940	Economy	9200.00
0005432302324	12940	Economy	9200.00
0005432423912	12895	Business	27500.00
0005432423799	12895	Business	27500.00
0005432423819	12895	Business	27500.00
0005432423915	12895	Business	27500.00
0005432423778	12895	Business	27500.00
0005432423899	12895	Business	27500.00
0005432423769	12895	Business	27500.00
0005432423710	12895	Business	27500.00
0005432423877	12895	Economy	10100.00
0005432423879	12895	Economy	10100.00
0005432423813	12895	Economy	9200.00
0005432423898	12895	Economy	9200.00
0005432423788	12895	Economy	9200.00
0005432423914	12895	Economy	9200.00
0005432423714	12895	Economy	9200.00
0005432423751	12895	Economy	9200.00
0005432423763	12895	Economy	9200.00
0005432423814	12895	Economy	9200.00
0005432423850	12895	Economy	9200.00
0005432423895	12895	Economy	9200.00
0005432423897	12895	Economy	9200.00
0005432423875	12895	Economy	9200.00
0005432423826	12895	Economy	9200.00
0005432423880	12895	Economy	9200.00
0005432423686	12895	Economy	9200.00
0005432423852	12895	Economy	9200.00
0005432423870	12895	Economy	9200.00
0005432423827	12895	Economy	9200.00
0005432423878	12895	Economy	9200.00
0005432423607	12895	Economy	9200.00
0005432423708	12895	Economy	9200.00
0005432423929	12895	Economy	9200.00
0005432423911	12895	Economy	9200.00
0005432423802	12895	Economy	9200.00
0005432423750	12895	Economy	10100.00
0005432423851	12895	Economy	9200.00
0005432423872	12895	Economy	10100.00
0005432423921	12895	Economy	9200.00
0005432423760	12895	Economy	9200.00
0005432423824	12895	Economy	9200.00
0005432423869	12895	Economy	9200.00
0005432423752	12895	Economy	9200.00
0005432423817	12895	Economy	9200.00
0005432423773	12895	Economy	9200.00
0005432423777	12895	Economy	9200.00
0005432423749	12895	Economy	9200.00
0005432423908	12895	Economy	9200.00
0005432423871	12895	Economy	9200.00
0005432423652	12895	Economy	9200.00
0005432423774	12895	Economy	9200.00
0005432423779	12895	Economy	9200.00
0005432423861	12895	Economy	9200.00
0005432423894	12895	Economy	9200.00
0005432423761	12895	Economy	9200.00
0005432423876	12895	Economy	9200.00
0005432423910	12895	Economy	9200.00
0005434028289	430	Business	24500.00
0005434023552	430	Business	24500.00
0005434023593	430	Business	24500.00
0005434023590	430	Business	24500.00
0005432235621	430	Business	24500.00
0005434023587	430	Business	24500.00
0005433057426	430	Business	24500.00
0005434023551	430	Business	24500.00
0005434023609	430	Business	24500.00
0005434028290	430	Business	24500.00
0005434023589	430	Business	24500.00
0005433057574	430	Business	24500.00
0005434023604	430	Business	24500.00
0005433057624	430	Business	24500.00
0005433057427	430	Business	24500.00
0005434023548	430	Business	24500.00
0005434023545	430	Business	24500.00
0005434023559	430	Business	24500.00
0005434032010	430	Economy	9000.00
0005433057541	430	Business	24500.00
0005434028288	430	Economy	9000.00
0005433057332	430	Economy	9000.00
0005434735632	430	Economy	8200.00
0005433057481	430	Economy	8200.00
0005434023598	430	Economy	8200.00
0005433057570	430	Economy	8200.00
0005433057499	430	Economy	8200.00
0005434023576	430	Economy	8200.00
0005434023568	430	Economy	8200.00
0005434023577	430	Economy	8200.00
0005434023547	430	Economy	8200.00
0005434023586	430	Economy	8200.00
0005434028291	430	Economy	8200.00
0005434023546	430	Economy	8200.00
0005433057510	430	Economy	8200.00
0005433057328	430	Economy	8200.00
0005434023572	430	Economy	8200.00
0005433057396	430	Economy	8200.00
0005434735602	430	Economy	8200.00
0005434023571	430	Economy	8200.00
0005433057466	430	Economy	8200.00
0005433057502	430	Economy	8200.00
0005434023553	430	Economy	8200.00
0005433057473	430	Economy	8200.00
0005434032012	430	Economy	8200.00
0005434023608	430	Economy	8200.00
0005434023560	430	Economy	8200.00
0005434023606	430	Economy	8200.00
0005432235624	430	Economy	8200.00
0005433057327	430	Economy	8200.00
0005434023556	430	Economy	8200.00
0005434023600	430	Economy	8200.00
0005434023602	430	Economy	8200.00
0005434023595	430	Economy	8200.00
0005433057566	430	Economy	8200.00
0005434023561	430	Economy	8200.00
0005433057434	430	Economy	8200.00
0005434023542	430	Economy	8200.00
0005434735629	430	Economy	8200.00
0005433057539	430	Economy	8200.00
0005434735631	430	Economy	8200.00
0005433057577	430	Economy	8200.00
0005434023544	430	Economy	8200.00
0005433057514	430	Economy	8200.00
0005433057548	430	Economy	8200.00
0005433929555	430	Economy	8200.00
0005434023596	430	Economy	8200.00
0005434023558	430	Economy	8200.00
0005433057569	430	Economy	8200.00
0005432235622	430	Economy	8200.00
0005434023555	430	Economy	8200.00
0005434029649	430	Economy	8200.00
0005433057621	430	Economy	8200.00
0005433057575	430	Economy	8200.00
0005434023578	430	Economy	8200.00
0005434023579	430	Economy	8200.00
0005434023583	430	Economy	8200.00
0005432235623	430	Economy	8200.00
0005434023584	430	Economy	8200.00
0005433057478	430	Economy	8200.00
0005432235625	430	Economy	8200.00
0005433057622	430	Economy	8200.00
0005433057604	430	Economy	8200.00
0005433057374	430	Economy	8200.00
0005433057576	430	Economy	8200.00
0005434023580	430	Economy	8200.00
0005434023599	430	Economy	8200.00
0005433057601	430	Economy	8200.00
0005433057385	430	Economy	8200.00
0005434023569	430	Economy	8200.00
0005432045609	430	Economy	8200.00
0005434023581	430	Economy	9000.00
0005433057538	430	Economy	8200.00
0005434023567	430	Economy	9000.00
0005434023573	430	Economy	8200.00
0005434023588	430	Economy	8200.00
0005433057572	430	Economy	8200.00
0005433057465	430	Economy	8200.00
0005433057652	430	Economy	8200.00
0005433057627	430	Economy	8200.00
0005434023597	430	Economy	8200.00
0005433057540	430	Economy	8200.00
0005434029650	430	Economy	8200.00
0005434023557	430	Economy	8200.00
0005434023607	430	Economy	8200.00
0005434023574	430	Economy	8200.00
0005433057469	430	Economy	8200.00
0005433057501	430	Economy	8200.00
0005434023601	430	Economy	8200.00
0005433057468	430	Economy	8200.00
0005434023563	430	Economy	8200.00
0005433684391	430	Economy	8200.00
0005432235626	430	Economy	8200.00
0005434023541	430	Economy	8200.00
0005434023570	430	Economy	8200.00
0005434023554	430	Economy	8200.00
0005433057571	430	Economy	8200.00
0005433057525	430	Economy	8200.00
0005433057567	430	Economy	8200.00
0005434023543	430	Economy	8200.00
0005432045608	430	Economy	8200.00
0005434023562	430	Economy	8200.00
0005434023564	430	Economy	8200.00
0005434023566	430	Economy	8200.00
0005433057532	430	Economy	8200.00
0005434023603	430	Economy	8200.00
0005434023575	430	Economy	8200.00
0005434032011	430	Economy	8200.00
0005434023605	430	Economy	8200.00
0005434023585	430	Economy	8200.00
0005434023550	430	Economy	8200.00
0005433057406	430	Economy	8200.00
0005434023594	430	Economy	8200.00
0005434023582	430	Economy	8200.00
0005433057397	430	Economy	8200.00
0005434032013	430	Economy	8200.00
0005434023591	430	Economy	8200.00
0005434023549	430	Economy	8200.00
0005433057607	430	Economy	8200.00
0005434023565	430	Economy	8200.00
0005434023592	430	Economy	8200.00
0005434735678	12642	Business	24500.00
0005434735682	12642	Business	24500.00
0005434023116	12642	Business	24500.00
0005434031978	12642	Business	24500.00
0005434023239	12642	Business	24500.00
0005432157488	12642	Business	24500.00
0005433057796	12642	Business	24500.00
0005433684418	12642	Business	24500.00
0005433057805	12642	Business	24500.00
0005433057803	12642	Business	24500.00
0005434022616	12642	Business	24500.00
0005434022886	12642	Business	24500.00
0005434022811	12642	Business	24500.00
0005433057786	12642	Business	24500.00
0005434022755	12642	Economy	9000.00
0005433057784	12642	Economy	9000.00
0005433929603	12642	Economy	9000.00
0005433057810	12642	Economy	9000.00
0005433057799	12642	Economy	8200.00
0005433057811	12642	Economy	8200.00
0005434022937	12642	Economy	8200.00
0005434023125	12642	Economy	8200.00
0005434022829	12642	Economy	8200.00
0005434023193	12642	Economy	8200.00
0005432156358	12642	Economy	8200.00
0005434031980	12642	Economy	8200.00
0005434023259	12642	Economy	8200.00
0005433057801	12642	Economy	8200.00
0005433057806	12642	Economy	8200.00
0005434022959	12642	Economy	8200.00
0005434022987	12642	Economy	8200.00
0005433057798	12642	Economy	8200.00
0005433057791	12642	Economy	8200.00
0005432156356	12642	Economy	8200.00
0005434735680	12642	Economy	8200.00
0005433057802	12642	Economy	8200.00
0005434022853	12642	Economy	8200.00
0005434022810	12642	Economy	8200.00
0005434023267	12642	Economy	8200.00
0005432156355	12642	Economy	8200.00
0005433057818	12642	Economy	8200.00
0005433929607	12642	Economy	8200.00
0005433057797	12642	Economy	8200.00
0005433057807	12642	Economy	8200.00
0005434031964	12642	Economy	8200.00
0005433057795	12642	Economy	8200.00
0005434735681	12642	Economy	8200.00
0005432157487	12642	Economy	8200.00
0005434023194	12642	Economy	8200.00
0005433057812	12642	Economy	8200.00
0005434023223	12642	Economy	8200.00
0005434022977	12642	Economy	8200.00
0005433929604	12642	Economy	8200.00
0005433057808	12642	Economy	8200.00
0005432156357	12642	Economy	8200.00
0005434022960	12642	Economy	8200.00
0005433057794	12642	Economy	8200.00
0005434022990	12642	Economy	8200.00
0005434023104	12642	Economy	8200.00
0005433057788	12642	Economy	8200.00
0005434029632	12642	Economy	8200.00
0005434023255	12642	Economy	8200.00
0005434022991	12642	Economy	8200.00
0005433684417	12642	Economy	8200.00
0005434023020	12642	Economy	8200.00
0005434022983	12642	Economy	8200.00
0005433057819	12642	Economy	8200.00
0005434022844	12642	Economy	8200.00
0005433057793	12642	Economy	8200.00
0005433057813	12642	Economy	8200.00
0005434023260	12642	Economy	8200.00
0005434023106	12642	Economy	8200.00
0005433057814	12642	Economy	8200.00
0005434023014	12642	Economy	8200.00
0005433057809	12642	Economy	9000.00
0005434023185	12642	Economy	9000.00
0005434023120	12642	Economy	8200.00
0005434023107	12642	Economy	8200.00
0005433057823	12642	Economy	9000.00
0005434023019	12642	Economy	8200.00
0005434022905	12642	Economy	8200.00
0005434023124	12642	Economy	8200.00
0005433057825	12642	Economy	8200.00
0005433057821	12642	Economy	8200.00
0005434022725	12642	Economy	8200.00
0005434023117	12642	Economy	8200.00
0005434023115	12642	Economy	8200.00
0005433057822	12642	Economy	8200.00
0005433057789	12642	Economy	8200.00
0005433057785	12642	Economy	8200.00
0005434735679	12642	Economy	8200.00
0005433057815	12642	Economy	8200.00
0005434022938	12642	Economy	8200.00
0005434022803	12642	Economy	8200.00
0005433929606	12642	Economy	8200.00
0005433057826	12642	Economy	8200.00
0005434023072	12642	Economy	8200.00
0005434022976	12642	Economy	8200.00
0005433057804	12642	Economy	8200.00
0005433057787	12642	Economy	8200.00
0005434022885	12642	Economy	8200.00
0005434022909	12642	Economy	8200.00
0005433057820	12642	Economy	8200.00
0005434031979	12642	Economy	8200.00
0005433057824	12642	Economy	8200.00
0005434023018	12642	Economy	8200.00
0005434023211	12642	Economy	8200.00
0005433057790	12642	Economy	8200.00
0005434023017	12642	Economy	8200.00
0005434022693	12642	Economy	8200.00
0005434023033	12642	Economy	8200.00
0005433057817	12642	Economy	8200.00
0005433057800	12642	Economy	8200.00
0005433057816	12642	Economy	8200.00
0005434022726	12642	Economy	8200.00
0005434022936	12642	Economy	8200.00
0005433057792	12642	Economy	8200.00
0005433929605	12642	Economy	8200.00
0005434022913	12642	Economy	8200.00
0005433684416	12642	Economy	8200.00
0005433035707	2169	Business	34700.00
0005433035689	2169	Business	34700.00
0005433923128	2169	Business	34700.00
0005433035799	2169	Business	34700.00
0005433923118	2169	Business	34700.00
0005433035639	2169	Business	34700.00
0005433035800	2169	Business	34700.00
0005433923143	2169	Business	34700.00
0005433929607	2169	Business	34700.00
0005433035699	2169	Business	34700.00
0005433923112	2169	Business	34700.00
0005433923063	2169	Business	34700.00
0005433923076	2169	Business	34700.00
0005433035665	2169	Business	34700.00
0005432749763	2169	Business	34700.00
0005433923069	2169	Business	34700.00
0005433035688	2169	Business	34700.00
0005433035654	2169	Business	34700.00
0005433923077	2169	Business	34700.00
0005433035715	2169	Business	34700.00
0005433923086	2169	Business	34700.00
0005433923087	2169	Business	34700.00
0005432231547	2169	Business	34700.00
0005433035830	2169	Business	34700.00
0005433923148	2169	Business	34700.00
0005433923136	2169	Business	34700.00
0005433923105	2169	Business	34700.00
0005433923138	2169	Business	34700.00
0005433035696	2169	Business	34700.00
0005433035737	2169	Economy	12700.00
0005433035845	2169	Economy	12700.00
0005432231539	2169	Economy	12700.00
0005433923068	2169	Economy	12700.00
0005433923082	2169	Economy	11600.00
0005432749764	2169	Economy	11600.00
0005433923155	2169	Economy	11600.00
0005433923129	2169	Economy	11600.00
0005433923089	2169	Economy	11600.00
0005433923114	2169	Economy	11600.00
0005433035848	2169	Economy	11600.00
0005433923085	2169	Economy	11600.00
0005433035824	2169	Economy	11600.00
0005433923121	2169	Economy	11600.00
0005433035801	2169	Economy	11600.00
0005433035708	2169	Economy	11600.00
0005432231542	2169	Economy	11600.00
0005433929606	2169	Economy	11600.00
0005433923117	2169	Economy	11600.00
0005433923080	2169	Economy	11600.00
0005433035640	2169	Economy	11600.00
0005433923065	2169	Economy	11600.00
0005433035841	2169	Economy	11600.00
0005433923101	2169	Economy	11600.00
0005433923156	2169	Economy	11600.00
0005433035847	2169	Economy	11600.00
0005433035429	2169	Economy	11600.00
0005433923151	2169	Economy	11600.00
0005433923146	2169	Economy	11600.00
0005433923091	2169	Economy	11600.00
0005433923147	2169	Economy	11600.00
0005433923135	2169	Economy	11600.00
0005433923102	2169	Economy	11600.00
0005433923079	2169	Economy	11600.00
0005433035698	2169	Economy	11600.00
0005433035503	2169	Economy	11600.00
0005433923137	2169	Economy	11600.00
0005433923103	2169	Economy	11600.00
0005433035558	2169	Economy	11600.00
0005433923154	2169	Economy	11600.00
0005433875373	2169	Economy	11600.00
0005433923122	2169	Economy	11600.00
0005433035660	2169	Economy	11600.00
0005433923094	2169	Economy	11600.00
0005433035872	2169	Economy	11600.00
0005433035459	2169	Economy	11600.00
0005433923126	2169	Economy	11600.00
0005433923139	2169	Economy	11600.00
0005433923062	2169	Economy	11600.00
0005433035666	2169	Economy	11600.00
0005433035806	2169	Economy	11600.00
0005433035752	2169	Economy	11600.00
0005433923123	2169	Economy	11600.00
0005433035805	2169	Economy	11600.00
0005433035820	2169	Economy	11600.00
0005433923134	2169	Economy	11600.00
0005433035884	2169	Economy	11600.00
0005433035732	2169	Economy	11600.00
0005433923131	2169	Economy	11600.00
0005433035741	2169	Economy	11600.00
0005433035790	2169	Economy	11600.00
0005433035655	2169	Economy	11600.00
0005433923075	2169	Economy	11600.00
0005433035532	2169	Economy	11600.00
0005433035490	2169	Economy	11600.00
0005433923140	2169	Economy	11600.00
0005432231537	2169	Economy	11600.00
0005433923071	2169	Economy	11600.00
0005433929603	2169	Economy	11600.00
0005433923113	2169	Economy	11600.00
0005433035645	2169	Economy	11600.00
0005433035649	2169	Economy	11600.00
0005433035913	2169	Economy	11600.00
0005433035670	2169	Economy	11600.00
0005433035489	2169	Economy	11600.00
0005433923060	2169	Economy	11600.00
0005433035638	2169	Economy	11600.00
0005433035653	2169	Economy	11600.00
0005433035609	2169	Economy	11600.00
0005433923110	2169	Economy	11600.00
0005433035748	2169	Economy	11600.00
0005433035508	2169	Economy	11600.00
0005432231543	2169	Economy	11600.00
0005433923084	2169	Economy	11600.00
0005432231541	2169	Economy	11600.00
0005433923093	2169	Economy	11600.00
0005432044518	2169	Economy	11600.00
0005433035559	2169	Economy	11600.00
0005433923067	2169	Economy	11600.00
0005433036003	2169	Economy	11600.00
0005433923061	2169	Economy	11600.00
0005433923120	2169	Economy	11600.00
0005433035504	2169	Economy	11600.00
0005432749766	2169	Economy	11600.00
0005433923153	2169	Economy	11600.00
0005432231538	2169	Economy	11600.00
0005433035697	2169	Economy	12700.00
0005433923095	2169	Economy	11600.00
0005433923149	2169	Economy	11600.00
0005433923145	2169	Economy	11600.00
0005433035488	2169	Economy	11600.00
0005433923152	2169	Economy	11600.00
0005433923090	2169	Economy	11600.00
0005433923142	2169	Economy	11600.00
0005433923144	2169	Economy	11600.00
0005433923081	2169	Economy	11600.00
0005433923078	2169	Economy	11600.00
0005433923083	2169	Economy	11600.00
0005433035823	2169	Economy	11600.00
0005433923132	2169	Economy	11600.00
0005433923115	2169	Economy	11600.00
0005433035808	2169	Economy	11600.00
0005433035846	2169	Economy	11600.00
0005433923092	2169	Economy	11600.00
0005433035435	2169	Economy	11600.00
0005432231546	2169	Economy	11600.00
0005432231544	2169	Economy	11600.00
0005433035865	2169	Economy	11600.00
0005433035802	2169	Economy	11600.00
0005433035942	2169	Economy	11600.00
0005433923098	2169	Economy	11600.00
0005433923099	2169	Economy	11600.00
0005433923106	2169	Economy	11600.00
0005433035765	2169	Economy	11600.00
0005433923111	2169	Economy	11600.00
0005433035818	2169	Economy	11600.00
0005433035722	2169	Economy	11600.00
0005433035909	2169	Economy	11600.00
0005433875372	2169	Economy	11600.00
0005433923074	2169	Economy	11600.00
0005433923150	2169	Economy	11600.00
0005433923096	2169	Economy	11600.00
0005432231545	2169	Economy	11600.00
0005433929605	2169	Economy	11600.00
0005433923073	2169	Economy	11600.00
0005433035756	2169	Economy	11600.00
0005433035764	2169	Economy	11600.00
0005433923127	2169	Economy	11600.00
0005433035880	2169	Economy	11600.00
0005433923066	2169	Economy	11600.00
0005433923107	2169	Economy	11600.00
0005433923100	2169	Economy	11600.00
0005433923097	2169	Economy	11600.00
0005432044519	2169	Economy	11600.00
0005433923141	2169	Economy	11600.00
0005432749765	2169	Economy	11600.00
0005433929604	2169	Economy	11600.00
0005433923104	2169	Economy	11600.00
0005433923072	2169	Economy	11600.00
0005433035810	2169	Economy	11600.00
0005433035543	2169	Economy	11600.00
0005433923157	2169	Economy	11600.00
0005433923116	2169	Economy	11600.00
0005433923064	2169	Economy	11600.00
0005433035758	2169	Economy	11600.00
0005432231540	2169	Economy	11600.00
0005433923108	2169	Economy	11600.00
0005433035776	2169	Economy	11600.00
0005433035744	2169	Economy	11600.00
0005433923109	2169	Economy	11600.00
0005433035428	2169	Economy	11600.00
0005433035789	2169	Economy	11600.00
0005433923125	2169	Economy	11600.00
0005433923088	2169	Economy	11600.00
0005433035667	2169	Economy	11600.00
0005433923124	2169	Economy	11600.00
0005433035743	2169	Economy	11600.00
0005433035819	2169	Economy	11600.00
0005433923119	2169	Economy	11600.00
0005433035507	2169	Economy	11600.00
0005433923130	2169	Economy	11600.00
0005433923070	2169	Economy	11600.00
0005433923133	2169	Economy	11600.00
0005433035822	2169	Economy	11600.00
0005432206186	24096	Business	34700.00
0005433036166	24096	Business	34700.00
0005433922096	24096	Business	34700.00
0005433922215	24096	Business	34700.00
0005433922350	24096	Business	34700.00
0005433036200	24096	Business	34700.00
0005433922174	24096	Business	34700.00
0005433922270	24096	Business	34700.00
0005433922165	24096	Business	34700.00
0005433922272	24096	Business	34700.00
0005433036185	24096	Business	34700.00
0005433922342	24096	Business	34700.00
0005433922222	24096	Business	34700.00
0005433922280	24096	Business	34700.00
0005433922396	24096	Business	34700.00
0005433036186	24096	Business	34700.00
0005433922533	24096	Business	34700.00
0005433036199	24096	Business	34700.00
0005433036180	24096	Business	34700.00
0005433922384	24096	Business	34700.00
0005433036215	24096	Business	34700.00
0005433922435	24096	Economy	12700.00
0005433922538	24096	Economy	12700.00
0005433036168	24096	Economy	12700.00
0005433921975	24096	Economy	12700.00
0005433036172	24096	Economy	11600.00
0005433921716	24096	Economy	11600.00
0005433036217	24096	Economy	11600.00
0005433921823	24096	Economy	11600.00
0005433036216	24096	Economy	11600.00
0005433921987	24096	Economy	11600.00
0005433036208	24096	Economy	11600.00
0005433036219	24096	Economy	11600.00
0005433036170	24096	Economy	11600.00
0005433036194	24096	Economy	11600.00
0005433036214	24096	Economy	11600.00
0005433922021	24096	Economy	11600.00
0005433922107	24096	Economy	11600.00
0005433929554	24096	Economy	11600.00
0005433922239	24096	Economy	11600.00
0005433875361	24096	Economy	11600.00
0005433922184	24096	Economy	11600.00
0005433922267	24096	Economy	11600.00
0005433931437	24096	Economy	11600.00
0005433922669	24096	Economy	11600.00
0005433922262	24096	Economy	11600.00
0005433922352	24096	Economy	11600.00
0005433921815	24096	Economy	11600.00
0005433036181	24096	Economy	11600.00
0005432206185	24096	Economy	11600.00
0005433922338	24096	Economy	11600.00
0005433922593	24096	Economy	11600.00
0005433922012	24096	Economy	11600.00
0005433922136	24096	Economy	11600.00
0005433036195	24096	Economy	11600.00
0005433922334	24096	Economy	11600.00
0005433922219	24096	Economy	11600.00
0005434028293	24096	Economy	11600.00
0005433036204	24096	Economy	11600.00
0005433922093	24096	Economy	11600.00
0005433036218	24096	Economy	11600.00
0005433922020	24096	Economy	11600.00
0005433922422	24096	Economy	11600.00
0005433922696	24096	Economy	11600.00
0005433922137	24096	Economy	11600.00
0005433036196	24096	Economy	11600.00
0005433922192	24096	Economy	11600.00
0005433922385	24096	Economy	11600.00
0005433922249	24096	Economy	11600.00
0005433922372	24096	Economy	11600.00
0005433036187	24096	Economy	11600.00
0005433036184	24096	Economy	11600.00
0005433922333	24096	Economy	11600.00
0005433921933	24096	Economy	11600.00
0005433922216	24096	Economy	11600.00
0005433922044	24096	Economy	11600.00
0005433922213	24096	Economy	11600.00
0005433922517	24096	Economy	11600.00
0005433921888	24096	Economy	11600.00
0005433922518	24096	Economy	11600.00
0005433922649	24096	Economy	11600.00
0005433036173	24096	Economy	11600.00
0005433922445	24096	Economy	11600.00
0005433036209	24096	Economy	11600.00
0005433875363	24096	Economy	11600.00
0005433036201	24096	Economy	11600.00
0005433036211	24096	Economy	11600.00
0005433922488	24096	Economy	11600.00
0005433922611	24096	Economy	11600.00
0005433036220	24096	Economy	11600.00
0005433036197	24096	Economy	11600.00
0005433922560	24096	Economy	11600.00
0005432207658	24096	Economy	11600.00
0005433036189	24096	Economy	11600.00
0005433036174	24096	Economy	11600.00
0005433036210	24096	Economy	11600.00
0005433922191	24096	Economy	11600.00
0005433921784	24096	Economy	11600.00
0005433922013	24096	Economy	11600.00
0005433922092	24096	Economy	11600.00
0005433921994	24096	Economy	12700.00
0005433922217	24096	Economy	12700.00
0005433922023	24096	Economy	11600.00
0005433922181	24096	Economy	11600.00
0005433036207	24096	Economy	12700.00
0005433036179	24096	Economy	12700.00
0005433036190	24096	Economy	11600.00
0005433922090	24096	Economy	11600.00
0005433921976	24096	Economy	11600.00
0005433036177	24096	Economy	11600.00
0005433921988	24096	Economy	11600.00
0005433922532	24096	Economy	11600.00
0005433922027	24096	Economy	11600.00
0005433036175	24096	Economy	11600.00
0005433036198	24096	Economy	11600.00
0005433875366	24096	Economy	11600.00
0005433931432	24096	Economy	11600.00
0005433922024	24096	Economy	11600.00
0005433036193	24096	Economy	11600.00
0005433922335	24096	Economy	11600.00
0005433036213	24096	Economy	11600.00
0005433036203	24096	Economy	11600.00
0005433036176	24096	Economy	11600.00
0005433922506	24096	Economy	11600.00
0005433922371	24096	Economy	11600.00
0005432206183	24096	Economy	11600.00
0005433036212	24096	Economy	11600.00
0005433036182	24096	Economy	11600.00
0005432206184	24096	Economy	11600.00
0005433921785	24096	Economy	11600.00
0005434028294	24096	Economy	11600.00
0005433875362	24096	Economy	11600.00
0005433922089	24096	Economy	11600.00
0005433036171	24096	Economy	11600.00
0005433931428	24096	Economy	11600.00
0005433922263	24096	Economy	11600.00
0005433922095	24096	Economy	11600.00
0005433922094	24096	Economy	11600.00
0005433036205	24096	Economy	11600.00
0005433922289	24096	Economy	11600.00
0005433036183	24096	Economy	11600.00
0005433036188	24096	Economy	11600.00
0005433036192	24096	Economy	11600.00
0005433036191	24096	Economy	11600.00
0005433931429	24096	Economy	11600.00
0005433921887	24096	Economy	11600.00
0005433922475	24096	Economy	11600.00
0005433036167	24096	Economy	11600.00
0005433922468	24096	Economy	11600.00
0005433036206	24096	Economy	11600.00
0005433036178	24096	Economy	11600.00
0005432749781	24096	Economy	11600.00
0005433921915	24096	Economy	11600.00
0005433036202	24096	Economy	11600.00
0005433922185	24096	Economy	11600.00
0005433922351	24096	Economy	11600.00
0005433922474	24096	Economy	11600.00
0005433922403	24096	Economy	11600.00
0005433921995	24096	Economy	11600.00
0005433922650	24096	Economy	11600.00
0005433931438	24096	Economy	11600.00
0005433922290	24096	Economy	11600.00
0005434028292	24096	Economy	11600.00
0005433922091	24096	Economy	11600.00
0005432207657	24096	Economy	11600.00
0005433922373	24096	Economy	11600.00
0005433036169	24096	Economy	11600.00
0005434725183	305	Business	83700.00
0005434725235	305	Business	83700.00
0005433180867	305	Business	83700.00
0005433233443	305	Business	83700.00
0005434551132	305	Business	83700.00
0005434735677	305	Business	83700.00
0005435142544	305	Business	83700.00
0005434551145	305	Business	83700.00
0005433180807	305	Business	83700.00
0005434725201	305	Business	83700.00
0005433180928	305	Business	83700.00
0005435142548	305	Business	83700.00
0005433126794	305	Business	83700.00
0005433233526	305	Business	83700.00
0005433289751	305	Business	83700.00
0005434735675	305	Business	83700.00
0005434725285	305	Business	83700.00
0005433111486	305	Business	83700.00
0005434302864	305	Business	83700.00
0005433766618	305	Business	83700.00
0005433180885	305	Business	83700.00
0005434551152	305	Business	83700.00
0005433233555	305	Business	83700.00
0005433233631	305	Business	83700.00
0005434725211	305	Business	83700.00
0005433233630	305	Business	83700.00
0005432277779	305	Business	83700.00
0005434551141	305	Business	83700.00
0005434725232	305	Comfort	47400.00
0005433289764	305	Comfort	47400.00
0005434551125	305	Comfort	47400.00
0005433233525	305	Comfort	47400.00
0005434725243	305	Comfort	47400.00
0005434551112	305	Comfort	47400.00
0005433233629	305	Comfort	47400.00
0005434725238	305	Comfort	47400.00
0005434551139	305	Comfort	47400.00
0005434735676	305	Comfort	47400.00
0005434725220	305	Comfort	47400.00
0005434725254	305	Comfort	47400.00
0005433289795	305	Comfort	47400.00
0005434551114	305	Comfort	47400.00
0005433180794	305	Comfort	47400.00
0005433233470	305	Comfort	47400.00
0005434725263	305	Comfort	47400.00
0005434725271	305	Comfort	47400.00
0005435142553	305	Comfort	47400.00
0005433233572	305	Comfort	47400.00
0005433131682	305	Comfort	47400.00
0005434725229	305	Comfort	47400.00
0005433233302	305	Comfort	47400.00
0005434725221	305	Comfort	47400.00
0005434725269	305	Comfort	47400.00
0005433233425	305	Comfort	47400.00
0005433180747	305	Comfort	47400.00
0005434731159	305	Comfort	47400.00
0005432277783	305	Comfort	47400.00
0005434551126	305	Comfort	47400.00
0005433233689	305	Comfort	47400.00
0005434735672	305	Comfort	47400.00
0005433180856	305	Comfort	47400.00
0005434725198	305	Comfort	47400.00
0005434551118	305	Comfort	47400.00
0005433180889	305	Comfort	47400.00
0005433111485	305	Comfort	47400.00
0005433233658	305	Comfort	47400.00
0005434551130	305	Comfort	47400.00
0005433233956	305	Comfort	47400.00
0005434725249	305	Comfort	47400.00
0005434551129	305	Comfort	47400.00
0005434725213	305	Economy	27900.00
0005435142554	305	Economy	27900.00
0005434551128	305	Economy	27900.00
0005433289788	305	Economy	27900.00
0005433233527	305	Economy	27900.00
0005434725208	305	Economy	27900.00
0005434551137	305	Economy	27900.00
0005433233505	305	Economy	27900.00
0005434725173	305	Economy	27900.00
0005433111476	305	Economy	27900.00
0005433131683	305	Economy	27900.00
0005434551155	305	Economy	27900.00
0005434725233	305	Economy	27900.00
0005433131657	305	Economy	27900.00
0005434551133	305	Economy	27900.00
0005434551113	305	Economy	27900.00
0005434725217	305	Economy	27900.00
0005434725260	305	Economy	27900.00
0005434551135	305	Economy	27900.00
0005432277789	305	Economy	27900.00
0005433131654	305	Economy	27900.00
0005434302863	305	Economy	27900.00
0005433289765	305	Economy	27900.00
0005435142546	305	Economy	27900.00
0005434725256	305	Economy	27900.00
0005433233412	305	Economy	27900.00
0005435142545	305	Economy	27900.00
0005433233464	305	Economy	27900.00
0005433180940	305	Economy	27900.00
0005434725270	305	Economy	27900.00
0005434725283	305	Economy	27900.00
0005433111487	305	Economy	27900.00
0005433233394	305	Economy	27900.00
0005434725196	305	Economy	27900.00
0005434302452	305	Economy	27900.00
0005434725230	305	Economy	27900.00
0005434551138	305	Economy	27900.00
0005434725264	305	Economy	27900.00
0005434725242	305	Economy	27900.00
0005433233714	305	Economy	27900.00
0005433233511	305	Economy	27900.00
0005432277780	305	Economy	27900.00
0005433233413	305	Economy	27900.00
0005434725248	305	Economy	27900.00
0005434551150	305	Economy	27900.00
0005434551105	305	Economy	27900.00
0005433233390	305	Economy	27900.00
0005434551151	305	Economy	27900.00
0005432277778	305	Economy	27900.00
0005434302448	305	Economy	27900.00
0005433233785	305	Economy	27900.00
0005434725265	305	Economy	27900.00
0005433233504	305	Economy	27900.00
0005435142552	305	Economy	27900.00
0005434725227	305	Economy	27900.00
0005434725177	305	Economy	27900.00
0005434725218	305	Economy	27900.00
0005433766614	305	Economy	27900.00
0005433233363	305	Economy	27900.00
0005433233620	305	Economy	27900.00
0005434725178	305	Economy	27900.00
0005433111488	305	Economy	27900.00
0005434551124	305	Economy	27900.00
0005433180746	305	Economy	27900.00
0005434725276	305	Economy	27900.00
0005433289796	305	Economy	30700.00
0005434725292	305	Economy	27900.00
0005434551108	305	Economy	30700.00
0005434725280	305	Economy	27900.00
0005434551131	305	Economy	30700.00
0005434725184	305	Economy	27900.00
0005433180805	305	Economy	30700.00
0005434725180	305	Economy	30700.00
0005434725273	305	Economy	27900.00
0005434551147	305	Economy	30700.00
0005434725279	305	Economy	27900.00
0005434725181	305	Economy	27900.00
0005433233463	305	Economy	27900.00
0005434551146	305	Economy	27900.00
0005433233626	305	Economy	27900.00
0005433233240	305	Economy	27900.00
0005434725245	305	Economy	27900.00
0005434725261	305	Economy	27900.00
0005433180793	305	Economy	27900.00
0005434725189	305	Economy	27900.00
0005433233612	305	Economy	27900.00
0005435142551	305	Economy	27900.00
0005434725257	305	Economy	27900.00
0005434725194	305	Economy	27900.00
0005434725289	305	Economy	27900.00
0005433233615	305	Economy	27900.00
0005434725172	305	Economy	27900.00
0005433233535	305	Economy	27900.00
0005434551100	305	Economy	27900.00
0005434551117	305	Economy	27900.00
0005433233573	305	Economy	27900.00
0005434725237	305	Economy	27900.00
0005433233704	305	Economy	27900.00
0005434725262	305	Economy	27900.00
0005434725250	305	Economy	27900.00
0005433180924	305	Economy	27900.00
0005435142547	305	Economy	27900.00
0005434735673	305	Economy	27900.00
0005433180929	305	Economy	27900.00
0005434302449	305	Economy	27900.00
0005434551136	305	Economy	27900.00
0005434725252	305	Economy	27900.00
0005433233358	305	Economy	27900.00
0005434551107	305	Economy	27900.00
0005434725170	305	Economy	27900.00
0005434725244	305	Economy	27900.00
0005433233245	305	Economy	27900.00
0005434725176	305	Economy	27900.00
0005434725286	305	Economy	27900.00
0005433233275	305	Economy	27900.00
0005433233542	305	Economy	27900.00
0005434031950	305	Economy	27900.00
0005433233482	305	Economy	27900.00
0005433233735	305	Economy	27900.00
0005434551142	305	Economy	27900.00
0005434551122	305	Economy	27900.00
0005434725171	305	Economy	27900.00
0005433233650	305	Economy	27900.00
0005434725169	305	Economy	27900.00
0005434735674	305	Economy	27900.00
0005434725216	305	Economy	27900.00
0005433233316	305	Economy	27900.00
0005434725200	305	Economy	27900.00
0005434725215	305	Economy	27900.00
0005434725190	305	Economy	27900.00
0005434725204	305	Economy	27900.00
0005434725247	305	Economy	27900.00
0005434725188	305	Economy	27900.00
0005432277785	305	Economy	27900.00
0005434551134	305	Economy	27900.00
0005433233387	305	Economy	27900.00
0005434551101	305	Economy	27900.00
0005433233816	305	Economy	27900.00
0005433111478	305	Economy	27900.00
0005434725187	305	Economy	27900.00
0005434725214	305	Economy	27900.00
0005433180855	305	Economy	27900.00
0005433113503	305	Economy	27900.00
0005434551123	305	Economy	27900.00
0005435142543	305	Economy	27900.00
0005434725182	305	Economy	27900.00
0005435142549	305	Economy	27900.00
0005433180868	305	Economy	27900.00
0005434725219	305	Economy	27900.00
0005434725175	305	Economy	27900.00
0005434302866	305	Economy	27900.00
0005434725206	305	Economy	27900.00
0005433233416	305	Economy	27900.00
0005433233513	305	Economy	27900.00
0005434725282	305	Economy	27900.00
0005434725288	305	Economy	27900.00
0005434725193	305	Economy	27900.00
0005434725174	305	Economy	27900.00
0005434725278	305	Economy	27900.00
0005434551148	305	Economy	27900.00
0005434725251	305	Economy	27900.00
0005432277784	305	Economy	27900.00
0005434725240	305	Economy	27900.00
0005432277786	305	Economy	27900.00
0005432277776	305	Economy	27900.00
0005434551110	305	Economy	27900.00
0005434731156	305	Economy	27900.00
0005434725195	305	Economy	27900.00
0005433233455	305	Economy	27900.00
0005433113504	305	Economy	27900.00
0005433131651	305	Economy	27900.00
0005434551121	305	Economy	27900.00
0005434725259	305	Economy	27900.00
0005432277787	305	Economy	27900.00
0005433233317	305	Economy	27900.00
0005433113511	305	Economy	27900.00
0005434725223	305	Economy	27900.00
0005433180814	305	Economy	27900.00
0005433180722	305	Economy	27900.00
0005433233362	305	Economy	27900.00
0005434551116	305	Economy	30700.00
0005434551127	305	Economy	27900.00
0005434725246	305	Economy	30700.00
0005433233659	305	Economy	30700.00
0005434725197	305	Economy	30700.00
0005433233647	305	Economy	30700.00
0005433233493	305	Economy	30700.00
0005434725228	305	Economy	27900.00
0005434725231	305	Economy	27900.00
0005434725239	305	Economy	27900.00
0005434731158	305	Economy	27900.00
0005434302868	305	Economy	27900.00
0005434725281	305	Economy	27900.00
0005434731157	305	Economy	27900.00
0005433233512	305	Economy	27900.00
0005433233389	305	Economy	27900.00
0005432277782	305	Economy	27900.00
0005434725287	305	Economy	27900.00
0005433233543	305	Economy	27900.00
0005434725199	305	Economy	27900.00
0005434725255	305	Economy	27900.00
0005434725234	305	Economy	27900.00
0005434725186	305	Economy	27900.00
0005433233604	305	Economy	27900.00
0005433233619	305	Economy	27900.00
0005432277777	305	Economy	27900.00
0005433180787	305	Economy	27900.00
0005434725222	305	Economy	27900.00
0005434725267	305	Economy	27900.00
0005434725290	305	Economy	27900.00
0005434551143	305	Economy	27900.00
0005434551119	305	Economy	27900.00
0005433233374	305	Economy	27900.00
0005434725291	305	Economy	27900.00
0005433233574	305	Economy	27900.00
0005434551115	305	Economy	27900.00
0005434302451	305	Economy	27900.00
0005434725268	305	Economy	27900.00
0005433131667	305	Economy	27900.00
0005434725209	305	Economy	27900.00
0005434551154	305	Economy	27900.00
0005434725258	305	Economy	27900.00
0005433233521	305	Economy	27900.00
0005434725224	305	Economy	27900.00
0005433233605	305	Economy	27900.00
0005433180847	305	Economy	27900.00
0005434725226	305	Economy	27900.00
0005433233424	305	Economy	27900.00
0005434725185	305	Economy	27900.00
0005433233651	305	Economy	27900.00
0005434725236	305	Economy	27900.00
0005435142555	305	Economy	27900.00
0005434551120	305	Economy	27900.00
0005434551149	305	Economy	27900.00
0005434551104	305	Economy	27900.00
0005434551153	305	Economy	27900.00
0005433289778	305	Economy	27900.00
0005433180930	305	Economy	27900.00
0005434551140	305	Economy	27900.00
0005434302450	305	Economy	27900.00
0005434551144	305	Economy	27900.00
0005433111477	305	Economy	27900.00
0005434725203	305	Economy	27900.00
0005434551109	305	Economy	27900.00
0005433233784	305	Economy	27900.00
0005434302867	305	Economy	27900.00
0005433766602	305	Economy	27900.00
0005435142556	305	Economy	27900.00
0005433233483	305	Economy	27900.00
0005433111481	305	Economy	27900.00
0005434725272	305	Economy	27900.00
0005433180760	305	Economy	27900.00
0005434725192	305	Economy	27900.00
0005434725179	305	Economy	27900.00
0005434725191	305	Economy	27900.00
0005433233552	305	Economy	27900.00
0005435142550	305	Economy	27900.00
0005434551111	305	Economy	27900.00
0005434725210	305	Economy	27900.00
0005434725274	305	Economy	27900.00
0005434031985	305	Economy	27900.00
0005433766593	305	Economy	27900.00
0005433233519	305	Economy	27900.00
0005434551099	305	Economy	27900.00
0005434725277	305	Economy	27900.00
0005434725225	305	Economy	27900.00
0005434725202	305	Economy	27900.00
0005434725212	305	Economy	27900.00
0005433131681	305	Economy	27900.00
0005433233955	305	Economy	27900.00
0005432277781	305	Economy	27900.00
0005433233625	305	Economy	27900.00
0005434725205	305	Economy	27900.00
0005433233241	305	Economy	27900.00
0005433233516	305	Economy	27900.00
0005434551106	305	Economy	27900.00
0005432277788	305	Economy	27900.00
0005433180939	305	Economy	27900.00
0005434302865	305	Economy	27900.00
0005433131652	305	Economy	27900.00
0005433289749	305	Economy	27900.00
0005434551102	305	Economy	27900.00
0005434731160	305	Economy	27900.00
0005434725275	305	Economy	27900.00
0005434551103	305	Economy	27900.00
0005434725207	305	Economy	27900.00
0005434725253	305	Economy	27900.00
0005434725241	305	Economy	27900.00
0005433233613	305	Economy	27900.00
0005433233618	305	Economy	27900.00
0005433180806	305	Economy	27900.00
0005433233541	305	Economy	27900.00
0005433289787	305	Economy	27900.00
0005434725284	305	Economy	27900.00
0005434725266	305	Economy	27900.00
0005435142424	9872	Business	83700.00
0005435142371	9872	Business	83700.00
0005435142456	9872	Business	83700.00
0005434724120	9872	Business	83700.00
0005433181059	9872	Business	83700.00
0005435142423	9872	Business	83700.00
0005434550722	9872	Business	83700.00
0005433126836	9872	Business	83700.00
0005433234058	9872	Business	83700.00
0005434724633	9872	Business	83700.00
0005433234102	9872	Business	83700.00
0005434550752	9872	Business	83700.00
0005434724124	9872	Business	83700.00
0005434735633	9872	Business	83700.00
0005434724058	9872	Business	83700.00
0005433234063	9872	Business	83700.00
0005434724480	9872	Business	83700.00
0005434724641	9872	Business	83700.00
0005432199235	9872	Business	83700.00
0005434724372	9872	Business	83700.00
0005434724370	9872	Business	83700.00
0005433181051	9872	Business	83700.00
0005434550657	9872	Business	83700.00
0005433234104	9872	Business	83700.00
0005434550497	9872	Business	83700.00
0005434550750	9872	Comfort	47400.00
0005434723981	9872	Comfort	47400.00
0005434724153	9872	Comfort	47400.00
0005433234069	9872	Comfort	47400.00
0005433234110	9872	Comfort	47400.00
0005434724212	9872	Comfort	47400.00
0005434724356	9872	Comfort	47400.00
0005434724373	9872	Comfort	47400.00
0005434724534	9872	Comfort	47400.00
0005434550662	9872	Comfort	47400.00
0005434550601	9872	Comfort	47400.00
0005434724583	9872	Comfort	47400.00
0005434724735	9872	Comfort	47400.00
0005435142390	9872	Comfort	47400.00
0005433234080	9872	Comfort	47400.00
0005435142434	9872	Comfort	47400.00
0005432199233	9872	Comfort	47400.00
0005434724460	9872	Comfort	47400.00
0005433234109	9872	Comfort	47400.00
0005434550286	9872	Comfort	47400.00
0005433113531	9872	Comfort	47400.00
0005433289829	9872	Comfort	47400.00
0005433234077	9872	Comfort	47400.00
0005433234068	9872	Comfort	47400.00
0005433234105	9872	Comfort	47400.00
0005433234056	9872	Comfort	47400.00
0005434723902	9872	Comfort	47400.00
0005434724001	9872	Comfort	47400.00
0005435142375	9872	Comfort	47400.00
0005434550669	9872	Comfort	47400.00
0005433289833	9872	Comfort	47400.00
0005434723641	9872	Comfort	47400.00
0005433129266	9872	Comfort	47400.00
0005433234099	9872	Comfort	47400.00
0005434724187	9872	Comfort	47400.00
0005434724210	9872	Comfort	47400.00
0005435142396	9872	Comfort	47400.00
0005434724516	9872	Comfort	47400.00
0005434302431	9872	Comfort	47400.00
0005434724750	9872	Comfort	47400.00
0005434724159	9872	Economy	27900.00
0005434724371	9872	Economy	27900.00
0005434723857	9872	Economy	27900.00
0005434724715	9872	Economy	27900.00
0005434550582	9872	Economy	27900.00
0005434724017	9872	Economy	27900.00
0005434724560	9872	Economy	27900.00
0005434032017	9872	Economy	27900.00
0005434724918	9872	Economy	27900.00
0005433234067	9872	Economy	27900.00
0005434723776	9872	Economy	27900.00
0005433234085	9872	Economy	27900.00
0005433234100	9872	Economy	27900.00
0005433181061	9872	Economy	27900.00
0005433181044	9872	Economy	27900.00
0005433234081	9872	Economy	27900.00
0005434723979	9872	Economy	27900.00
0005434724410	9872	Economy	27900.00
0005433234050	9872	Economy	27900.00
0005434724394	9872	Economy	27900.00
0005434724529	9872	Economy	27900.00
0005434724763	9872	Economy	27900.00
0005434550426	9872	Economy	27900.00
0005432199236	9872	Economy	27900.00
0005433234055	9872	Economy	27900.00
0005434550595	9872	Economy	27900.00
0005434724677	9872	Economy	27900.00
0005434724018	9872	Economy	27900.00
0005433234048	9872	Economy	27900.00
0005434550490	9872	Economy	27900.00
0005433234053	9872	Economy	27900.00
0005434723817	9872	Economy	27900.00
0005434723918	9872	Economy	27900.00
0005434550673	9872	Economy	27900.00
0005433234062	9872	Economy	27900.00
0005434723962	9872	Economy	27900.00
0005434550607	9872	Economy	27900.00
0005433181037	9872	Economy	27900.00
0005434032016	9872	Economy	27900.00
0005434550608	9872	Economy	27900.00
0005434724243	9872	Economy	27900.00
0005433181047	9872	Economy	27900.00
0005434724188	9872	Economy	27900.00
0005433181054	9872	Economy	27900.00
0005434550455	9872	Economy	27900.00
0005435142349	9872	Economy	27900.00
0005434550574	9872	Economy	27900.00
0005435142383	9872	Economy	27900.00
0005433234052	9872	Economy	27900.00
0005435142419	9872	Economy	27900.00
0005433126835	9872	Economy	27900.00
0005434723773	9872	Economy	27900.00
0005434723938	9872	Economy	27900.00
0005433129267	9872	Economy	27900.00
0005432199230	9872	Economy	30700.00
0005434550552	9872	Economy	30700.00
0005433234101	9872	Economy	27900.00
0005433234071	9872	Economy	30700.00
0005434550597	9872	Economy	27900.00
0005433181052	9872	Economy	27900.00
0005434724917	9872	Economy	27900.00
0005434724121	9872	Economy	30700.00
0005434731140	9872	Economy	30700.00
0005434550721	9872	Economy	27900.00
0005434724154	9872	Economy	27900.00
0005434550465	9872	Economy	27900.00
0005434550719	9872	Economy	27900.00
0005435142418	9872	Economy	27900.00
0005433181058	9872	Economy	27900.00
0005432199232	9872	Economy	27900.00
0005434724485	9872	Economy	27900.00
0005435142398	9872	Economy	27900.00
0005434724471	9872	Economy	27900.00
0005434724085	9872	Economy	27900.00
0005434724080	9872	Economy	27900.00
0005434735623	9872	Economy	27900.00
0005433234087	9872	Economy	27900.00
0005434550720	9872	Economy	27900.00
0005434550626	9872	Economy	27900.00
0005434550521	9872	Economy	27900.00
0005434724244	9872	Economy	27900.00
0005434724151	9872	Economy	27900.00
0005434723861	9872	Economy	27900.00
0005433234082	9872	Economy	27900.00
0005434723862	9872	Economy	27900.00
0005434735608	9872	Economy	27900.00
0005434723980	9872	Economy	27900.00
0005433234108	9872	Economy	27900.00
0005433181056	9872	Economy	27900.00
0005434723915	9872	Economy	27900.00
0005434724242	9872	Economy	27900.00
0005433181045	9872	Economy	27900.00
0005434725027	9872	Economy	27900.00
0005434723881	9872	Economy	27900.00
0005434724451	9872	Economy	27900.00
0005434724143	9872	Economy	27900.00
0005434550801	9872	Economy	27900.00
0005433234093	9872	Economy	27900.00
0005434550671	9872	Economy	27900.00
0005434723882	9872	Economy	27900.00
0005434550751	9872	Economy	27900.00
0005433181041	9872	Economy	27900.00
0005434723324	9872	Economy	27900.00
0005433234096	9872	Economy	27900.00
0005433234106	9872	Economy	27900.00
0005434735634	9872	Economy	27900.00
0005434724496	9872	Economy	27900.00
0005433234060	9872	Economy	27900.00
0005435142395	9872	Economy	27900.00
0005434724635	9872	Economy	27900.00
0005434724185	9872	Economy	27900.00
0005434724000	9872	Economy	27900.00
0005433234094	9872	Economy	27900.00
0005433234059	9872	Economy	27900.00
0005433181055	9872	Economy	27900.00
0005434735611	9872	Economy	27900.00
0005433234072	9872	Economy	27900.00
0005434724444	9872	Economy	27900.00
0005433181043	9872	Economy	27900.00
0005434725026	9872	Economy	27900.00
0005434550716	9872	Economy	27900.00
0005433181053	9872	Economy	27900.00
0005434723978	9872	Economy	27900.00
0005433289834	9872	Economy	27900.00
0005435142451	9872	Economy	27900.00
0005434723869	9872	Economy	27900.00
0005434724045	9872	Economy	27900.00
0005435142350	9872	Economy	27900.00
0005433289831	9872	Economy	27900.00
0005434723856	9872	Economy	27900.00
0005435142391	9872	Economy	27900.00
0005433234089	9872	Economy	27900.00
0005433234047	9872	Economy	27900.00
0005434724287	9872	Economy	27900.00
0005434723879	9872	Economy	27900.00
0005434550633	9872	Economy	27900.00
0005433113530	9872	Economy	27900.00
0005433181040	9872	Economy	27900.00
0005434724046	9872	Economy	27900.00
0005434550476	9872	Economy	27900.00
0005434550287	9872	Economy	27900.00
0005434724183	9872	Economy	27900.00
0005433234049	9872	Economy	27900.00
0005434724224	9872	Economy	27900.00
0005434723772	9872	Economy	27900.00
0005434735609	9872	Economy	27900.00
0005434724561	9872	Economy	27900.00
0005433113532	9872	Economy	27900.00
0005434550756	9872	Economy	27900.00
0005434724640	9872	Economy	27900.00
0005433129264	9872	Economy	27900.00
0005434724919	9872	Economy	27900.00
0005433234107	9872	Economy	27900.00
0005433289828	9872	Economy	27900.00
0005433181038	9872	Economy	27900.00
0005435142376	9872	Economy	27900.00
0005433234066	9872	Economy	27900.00
0005434032018	9872	Economy	27900.00
0005434724083	9872	Economy	27900.00
0005434723841	9872	Economy	27900.00
0005434723713	9872	Economy	27900.00
0005433234064	9872	Economy	27900.00
0005434724355	9872	Economy	27900.00
0005433181042	9872	Economy	27900.00
0005434724291	9872	Economy	27900.00
0005434550464	9872	Economy	27900.00
0005433181036	9872	Economy	27900.00
0005434550674	9872	Economy	27900.00
0005434550538	9872	Economy	27900.00
0005434724228	9872	Economy	30700.00
0005434735610	9872	Economy	27900.00
0005435142370	9872	Economy	30700.00
0005433234075	9872	Economy	30700.00
0005433766631	9872	Economy	30700.00
0005434735635	9872	Economy	27900.00
0005434724077	9872	Economy	27900.00
0005433234092	9872	Economy	27900.00
0005434724184	9872	Economy	27900.00
0005434550596	9872	Economy	27900.00
0005434731121	9872	Economy	27900.00
0005433234073	9872	Economy	27900.00
0005433234091	9872	Economy	27900.00
0005433766632	9872	Economy	27900.00
0005434550338	9872	Economy	27900.00
0005434723901	9872	Economy	27900.00
0005434723808	9872	Economy	27900.00
0005434550539	9872	Economy	27900.00
0005434724301	9872	Economy	27900.00
0005433234095	9872	Economy	27900.00
0005434550659	9872	Economy	27900.00
0005434550537	9872	Economy	27900.00
0005434550536	9872	Economy	27900.00
0005434032014	9872	Economy	27900.00
0005434724481	9872	Economy	27900.00
0005433234078	9872	Economy	27900.00
0005433181049	9872	Economy	27900.00
0005434724125	9872	Economy	27900.00
0005434724450	9872	Economy	27900.00
0005434550656	9872	Economy	27900.00
0005433234086	9872	Economy	27900.00
0005434724142	9872	Economy	27900.00
0005433181060	9872	Economy	27900.00
0005434550625	9872	Economy	27900.00
0005434550745	9872	Economy	27900.00
0005434550670	9872	Economy	27900.00
0005434550555	9872	Economy	27900.00
0005434731120	9872	Economy	27900.00
0005434724309	9872	Economy	27900.00
0005434724793	9872	Economy	27900.00
0005434550499	9872	Economy	27900.00
0005434724395	9872	Economy	27900.00
0005434724250	9872	Economy	27900.00
0005433766633	9872	Economy	27900.00
0005434724411	9872	Economy	27900.00
0005434724279	9872	Economy	27900.00
0005433234061	9872	Economy	27900.00
0005432199231	9872	Economy	27900.00
0005433234074	9872	Economy	27900.00
0005434724676	9872	Economy	27900.00
0005433234079	9872	Economy	27900.00
0005434723710	9872	Economy	27900.00
0005434550585	9872	Economy	27900.00
0005433181048	9872	Economy	27900.00
0005432199234	9872	Economy	27900.00
0005434724211	9872	Economy	27900.00
0005433234076	9872	Economy	27900.00
0005433234054	9872	Economy	27900.00
0005434550456	9872	Economy	27900.00
0005433129265	9872	Economy	27900.00
0005433234097	9872	Economy	27900.00
0005433234088	9872	Economy	27900.00
0005433181057	9872	Economy	27900.00
0005434731119	9872	Economy	27900.00
0005433181039	9872	Economy	27900.00
0005434550496	9872	Economy	27900.00
0005434724160	9872	Economy	27900.00
0005434724225	9872	Economy	27900.00
0005434550556	9872	Economy	27900.00
0005434724209	9872	Economy	27900.00
0005434723880	9872	Economy	27900.00
0005434723963	9872	Economy	27900.00
0005434723868	9872	Economy	27900.00
0005433289830	9872	Economy	27900.00
0005433289832	9872	Economy	27900.00
0005434724054	9872	Economy	27900.00
0005434724086	9872	Economy	27900.00
0005434550663	9872	Economy	27900.00
0005435142382	9872	Economy	27900.00
0005434724227	9872	Economy	27900.00
0005433766634	9872	Economy	27900.00
0005434724189	9872	Economy	27900.00
0005433234065	9872	Economy	27900.00
0005433234083	9872	Economy	27900.00
0005433181046	9872	Economy	27900.00
0005434723712	9872	Economy	27900.00
0005433234084	9872	Economy	27900.00
0005433234051	9872	Economy	27900.00
0005434724238	9872	Economy	27900.00
0005433234057	9872	Economy	27900.00
0005434302410	9872	Economy	27900.00
0005433234070	9872	Economy	27900.00
0005433234098	9872	Economy	27900.00
0005434724634	9872	Economy	27900.00
0005434032015	9872	Economy	27900.00
0005434302407	9872	Economy	27900.00
0005434735612	9872	Economy	27900.00
0005434723870	9872	Economy	27900.00
0005433234090	9872	Economy	27900.00
0005434724749	9872	Economy	27900.00
0005434550600	9872	Economy	27900.00
0005433181050	9872	Economy	27900.00
0005434550754	9872	Economy	27900.00
0005434550791	9872	Economy	27900.00
0005433234103	9872	Economy	27900.00
0005435212542	7736	Business	42100.00
0005432527697	7736	Business	42100.00
0005432428922	7736	Business	42100.00
0005434067393	7736	Business	42100.00
0005432069626	7736	Business	42100.00
0005432150176	7736	Business	42100.00
0005433656628	7736	Business	42100.00
0005434067452	7736	Business	42100.00
0005432527653	7736	Business	42100.00
0005432527721	7736	Business	42100.00
0005432527772	7736	Business	42100.00
0005435212831	7736	Business	42100.00
0005432527712	7736	Business	42100.00
0005434067427	7736	Business	42100.00
0005435212777	7736	Business	42100.00
0005432527673	7736	Business	42100.00
0005434067422	7736	Business	42100.00
0005432527656	7736	Business	42100.00
0005435213099	7736	Business	42100.00
0005432527726	7736	Business	42100.00
0005432428921	7736	Business	42100.00
0005432428920	7736	Business	42100.00
0005435213136	7736	Business	42100.00
0005432527757	7736	Business	42100.00
0005432527703	7736	Business	42100.00
0005434067456	7736	Comfort	23900.00
0005435212891	7736	Comfort	23900.00
0005435212548	7736	Comfort	23900.00
0005435212766	7736	Comfort	23900.00
0005435212790	7736	Comfort	23900.00
0005432527749	7736	Comfort	23900.00
0005432527702	7736	Comfort	23900.00
0005432527681	7736	Comfort	23900.00
0005432527707	7736	Comfort	23900.00
0005432527775	7736	Comfort	23900.00
0005435212880	7736	Comfort	23900.00
0005432527746	7736	Comfort	23900.00
0005433656632	7736	Comfort	23900.00
0005432069621	7736	Comfort	23900.00
0005434067390	7736	Comfort	23900.00
0005432535822	7736	Comfort	23900.00
0005435213140	7736	Comfort	23900.00
0005432527738	7736	Comfort	23900.00
0005435212665	7736	Comfort	23900.00
0005435213141	7736	Comfort	23900.00
0005432527668	7736	Comfort	23900.00
0005434067445	7736	Comfort	23900.00
0005432527666	7736	Comfort	23900.00
0005435212681	7736	Comfort	23900.00
0005432527685	7736	Comfort	23900.00
0005433656639	7736	Comfort	23900.00
0005432527737	7736	Comfort	23900.00
0005432527760	7736	Comfort	23900.00
0005434067391	7736	Comfort	23900.00
0005435212995	7736	Comfort	23900.00
0005432527724	7736	Comfort	23900.00
0005432527722	7736	Comfort	23900.00
0005432527670	7736	Comfort	23900.00
0005432527751	7736	Comfort	23900.00
0005432527682	7736	Comfort	23900.00
0005432150175	7736	Comfort	23900.00
0005434067453	7736	Comfort	23900.00
0005434067409	7736	Comfort	23900.00
0005435212827	7736	Comfort	23900.00
0005432527701	7736	Economy	14000.00
0005435212650	7736	Economy	14000.00
0005432527657	7736	Economy	14000.00
0005434067394	7736	Economy	14000.00
0005434067446	7736	Economy	14000.00
0005432527674	7736	Economy	14000.00
0005434067385	7736	Economy	14000.00
0005432527718	7736	Economy	14000.00
0005434067431	7736	Economy	14000.00
0005432527654	7736	Economy	14000.00
0005435212627	7736	Economy	14000.00
0005434067403	7736	Economy	14000.00
0005435212884	7736	Economy	14000.00
0005434067395	7736	Economy	14000.00
0005435213142	7736	Economy	14000.00
0005435212890	7736	Economy	14000.00
0005432527736	7736	Economy	14000.00
0005434067440	7736	Economy	14000.00
0005435212892	7736	Economy	14000.00
0005435212989	7736	Economy	14000.00
0005435630929	7736	Economy	14000.00
0005435212745	7736	Economy	14000.00
0005432527731	7736	Economy	14000.00
0005435212646	7736	Economy	14000.00
0005434067388	7736	Economy	14000.00
0005432527658	7736	Economy	14000.00
0005434067420	7736	Economy	14000.00
0005432527767	7736	Economy	14000.00
0005435212994	7736	Economy	14000.00
0005434067402	7736	Economy	14000.00
0005432527747	7736	Economy	14000.00
0005432069624	7736	Economy	14000.00
0005434067411	7736	Economy	14000.00
0005432527678	7736	Economy	14000.00
0005434067386	7736	Economy	14000.00
0005432527742	7736	Economy	14000.00
0005435213074	7736	Economy	14000.00
0005435212943	7736	Economy	14000.00
0005435212622	7736	Economy	14000.00
0005435212869	7736	Economy	14000.00
0005432069620	7736	Economy	14000.00
0005432527652	7736	Economy	14000.00
0005435212744	7736	Economy	14000.00
0005432527665	7736	Economy	14000.00
0005435212680	7736	Economy	14000.00
0005434067430	7736	Economy	14000.00
0005432527686	7736	Economy	14000.00
0005432527713	7736	Economy	14000.00
0005435212841	7736	Economy	14000.00
0005432527693	7736	Economy	14000.00
0005432150179	7736	Economy	14000.00
0005432527773	7736	Economy	14000.00
0005434067416	7736	Economy	14000.00
0005435212747	7736	Economy	14000.00
0005434067438	7736	Economy	14000.00
0005434067414	7736	Economy	14000.00
0005432527663	7736	Economy	14000.00
0005432069627	7736	Economy	14000.00
0005432527704	7736	Economy	14000.00
0005432527744	7736	Economy	14000.00
0005435212560	7736	Economy	15400.00
0005432150177	7736	Economy	15400.00
0005434067396	7736	Economy	14000.00
0005435212832	7736	Economy	14000.00
0005435212686	7736	Economy	14000.00
0005432527672	7736	Economy	15400.00
0005435212872	7736	Economy	14000.00
0005432527752	7736	Economy	15400.00
0005432527664	7736	Economy	14000.00
0005435212559	7736	Economy	14000.00
0005432527679	7736	Economy	14000.00
0005432527732	7736	Economy	14000.00
0005434067454	7736	Economy	14000.00
0005434067389	7736	Economy	14000.00
0005432069623	7736	Economy	14000.00
0005434067417	7736	Economy	14000.00
0005435212746	7736	Economy	14000.00
0005434067401	7736	Economy	14000.00
0005434067400	7736	Economy	14000.00
0005432527766	7736	Economy	14000.00
0005432069619	7736	Economy	14000.00
0005432527761	7736	Economy	14000.00
0005432527745	7736	Economy	14000.00
0005432527694	7736	Economy	14000.00
0005434067433	7736	Economy	14000.00
0005435212718	7736	Economy	14000.00
0005432527776	7736	Economy	14000.00
0005434067423	7736	Economy	14000.00
0005435212767	7736	Economy	14000.00
0005432527683	7736	Economy	14000.00
0005434067455	7736	Economy	14000.00
0005435212729	7736	Economy	14000.00
0005432535824	7736	Economy	14000.00
0005435212687	7736	Economy	14000.00
0005435213137	7736	Economy	14000.00
0005432527763	7736	Economy	14000.00
0005432527669	7736	Economy	14000.00
0005434067428	7736	Economy	14000.00
0005435212867	7736	Economy	14000.00
0005432150180	7736	Economy	14000.00
0005434067441	7736	Economy	14000.00
0005432527692	7736	Economy	14000.00
0005435212647	7736	Economy	14000.00
0005434067387	7736	Economy	14000.00
0005434067442	7736	Economy	14000.00
0005434067399	7736	Economy	14000.00
0005432527730	7736	Economy	14000.00
0005432527677	7736	Economy	14000.00
0005432527774	7736	Economy	14000.00
0005432527675	7736	Economy	14000.00
0005435212941	7736	Economy	14000.00
0005432069630	7736	Economy	14000.00
0005432527690	7736	Economy	14000.00
0005434067415	7736	Economy	14000.00
0005434067397	7736	Economy	14000.00
0005432527769	7736	Economy	14000.00
0005432527700	7736	Economy	14000.00
0005435212626	7736	Economy	14000.00
0005434067398	7736	Economy	14000.00
0005434067384	7736	Economy	14000.00
0005432527740	7736	Economy	14000.00
0005434067407	7736	Economy	14000.00
0005434067435	7736	Economy	14000.00
0005432527778	7736	Economy	14000.00
0005435212731	7736	Economy	14000.00
0005434067444	7736	Economy	14000.00
0005434067448	7736	Economy	14000.00
0005432069622	7736	Economy	14000.00
0005432527750	7736	Economy	14000.00
0005435212612	7736	Economy	14000.00
0005435212611	7736	Economy	14000.00
0005432527659	7736	Economy	14000.00
0005432527714	7736	Economy	14000.00
0005435212540	7736	Economy	14000.00
0005434067425	7736	Economy	14000.00
0005434067450	7736	Economy	14000.00
0005432527755	7736	Economy	14000.00
0005432527764	7736	Economy	14000.00
0005433656641	7736	Economy	14000.00
0005435212768	7736	Economy	14000.00
0005435212541	7736	Economy	14000.00
0005432150182	7736	Economy	14000.00
0005432535823	7736	Economy	14000.00
0005434067439	7736	Economy	14000.00
0005432527691	7736	Economy	14000.00
0005435212346	7736	Economy	14000.00
0005432527753	7736	Economy	14000.00
0005432527777	7736	Economy	14000.00
0005433656640	7736	Economy	14000.00
0005432527706	7736	Economy	14000.00
0005435212993	7736	Economy	14000.00
0005434067436	7736	Economy	14000.00
0005435212781	7736	Economy	14000.00
0005432069618	7736	Economy	14000.00
0005432527698	7736	Economy	14000.00
0005432527758	7736	Economy	14000.00
0005434067412	7736	Economy	14000.00
0005432527688	7736	Economy	14000.00
0005435212776	7736	Economy	14000.00
0005432069629	7736	Economy	14000.00
0005432527711	7736	Economy	14000.00
0005432527689	7736	Economy	14000.00
0005434067426	7736	Economy	14000.00
0005435212902	7736	Economy	14000.00
0005434067406	7736	Economy	14000.00
0005432527705	7736	Economy	14000.00
0005432527779	7736	Economy	15400.00
0005432527715	7736	Economy	14000.00
0005432527660	7736	Economy	15400.00
0005432527743	7736	Economy	15400.00
0005432527648	7736	Economy	15400.00
0005433656631	7736	Economy	15400.00
0005432527770	7736	Economy	15400.00
0005435212830	7736	Economy	14000.00
0005432527756	7736	Economy	14000.00
0005435212825	7736	Economy	14000.00
0005433656625	7736	Economy	14000.00
0005432527687	7736	Economy	14000.00
0005432527710	7736	Economy	14000.00
0005434067437	7736	Economy	14000.00
0005432527696	7736	Economy	14000.00
0005434067413	7736	Economy	14000.00
0005434067410	7736	Economy	14000.00
0005432533285	7736	Economy	14000.00
0005432527708	7736	Economy	14000.00
0005435212899	7736	Economy	14000.00
0005432527680	7736	Economy	14000.00
0005432069625	7736	Economy	14000.00
0005432527762	7736	Economy	14000.00
0005432527717	7736	Economy	14000.00
0005434067405	7736	Economy	14000.00
0005435212719	7736	Economy	14000.00
0005434067434	7736	Economy	14000.00
0005435212679	7736	Economy	14000.00
0005432527695	7736	Economy	14000.00
0005432527646	7736	Economy	14000.00
0005434067432	7736	Economy	14000.00
0005432527650	7736	Economy	14000.00
0005432527661	7736	Economy	14000.00
0005434067429	7736	Economy	14000.00
0005432527739	7736	Economy	14000.00
0005435212606	7736	Economy	14000.00
0005434067443	7736	Economy	14000.00
0005432527662	7736	Economy	14000.00
0005432527728	7736	Economy	14000.00
0005435213039	7736	Economy	14000.00
0005434067408	7736	Economy	14000.00
0005435212861	7736	Economy	14000.00
0005434067424	7736	Economy	14000.00
0005434067447	7736	Economy	14000.00
0005435212828	7736	Economy	14000.00
0005432527709	7736	Economy	14000.00
0005432527734	7736	Economy	14000.00
0005432527733	7736	Economy	14000.00
0005432527768	7736	Economy	14000.00
0005432527684	7736	Economy	14000.00
0005432533286	7736	Economy	14000.00
0005435212871	7736	Economy	14000.00
0005432527699	7736	Economy	14000.00
0005432527735	7736	Economy	14000.00
0005432527741	7736	Economy	14000.00
0005434067392	7736	Economy	14000.00
0005435212847	7736	Economy	14000.00
0005432527754	7736	Economy	14000.00
0005432527765	7736	Economy	14000.00
0005434067421	7736	Economy	14000.00
0005432069628	7736	Economy	14000.00
0005432150181	7736	Economy	14000.00
0005434067418	7736	Economy	14000.00
0005434067451	7736	Economy	14000.00
0005435212879	7736	Economy	14000.00
0005432527748	7736	Economy	14000.00
0005432527759	7736	Economy	14000.00
0005432537053	7736	Economy	14000.00
0005435212873	7736	Economy	14000.00
0005434067404	7736	Economy	14000.00
0005435212608	7736	Economy	14000.00
0005432527719	7736	Economy	14000.00
0005435212942	7736	Economy	14000.00
0005435212583	7736	Economy	14000.00
0005432535825	7736	Economy	14000.00
0005435212940	7736	Economy	14000.00
0005434067449	7736	Economy	14000.00
0005432527649	7736	Economy	14000.00
0005432527723	7736	Economy	14000.00
0005432527655	7736	Economy	14000.00
0005432527727	7736	Economy	14000.00
0005432150178	7736	Economy	14000.00
0005432527725	7736	Economy	14000.00
0005432527771	7736	Economy	14000.00
0005435212990	7736	Economy	14000.00
0005432527647	7736	Economy	14000.00
0005435212870	7736	Economy	14000.00
0005434067419	7736	Economy	14000.00
0005432069631	7736	Economy	14000.00
0005432527729	7736	Economy	14000.00
0005432535826	7736	Economy	14000.00
0005432527651	7736	Economy	14000.00
0005432527671	7736	Economy	14000.00
0005432527676	7736	Economy	14000.00
0005432527667	7736	Economy	14000.00
0005432527716	7736	Economy	14000.00
0005435212930	7736	Economy	14000.00
0005432527720	7736	Economy	14000.00
0005435212857	7736	Economy	14000.00
0005435319468	5314	Business	43100.00
0005434244616	5314	Business	43100.00
0005435424297	5314	Business	43100.00
0005435613414	5314	Business	43100.00
0005432133177	5314	Business	43100.00
0005435613449	5314	Business	43100.00
0005435613477	5314	Business	43100.00
0005435097187	5314	Business	43100.00
0005435613413	5314	Business	43100.00
0005435613474	5314	Business	43100.00
0005435424442	5314	Business	43100.00
0005435424103	5314	Business	43100.00
0005435613475	5314	Business	43100.00
0005434244610	5314	Business	43100.00
0005435613468	5314	Business	43100.00
0005435423965	5314	Business	43100.00
0005435613415	5314	Business	43100.00
0005435097188	5314	Business	43100.00
0005435613461	5314	Business	43100.00
0005435613471	5314	Business	43100.00
0005435424190	5314	Business	43100.00
0005435302158	5314	Business	43100.00
0005435613464	5314	Business	43100.00
0005435613404	5314	Business	43100.00
0005435613450	5314	Comfort	24400.00
0005432133176	5314	Comfort	24400.00
0005435613476	5314	Comfort	24400.00
0005435424381	5314	Comfort	24400.00
0005432133179	5314	Comfort	24400.00
0005435613427	5314	Comfort	24400.00
0005434573324	5314	Comfort	24400.00
0005435424048	5314	Comfort	24400.00
0005434344168	5314	Comfort	24400.00
0005435613480	5314	Comfort	24400.00
0005434244722	5314	Comfort	24400.00
0005435613463	5314	Comfort	24400.00
0005435613383	5314	Comfort	24400.00
0005435613441	5314	Comfort	24400.00
0005435319488	5314	Comfort	24400.00
0005435613434	5314	Comfort	24400.00
0005435302165	5314	Comfort	24400.00
0005435613408	5314	Comfort	24400.00
0005432363378	5314	Comfort	24400.00
0005435613429	5314	Comfort	24400.00
0005435613444	5314	Comfort	24400.00
0005434344171	5314	Comfort	24400.00
0005435423908	5314	Comfort	24400.00
0005434244774	5314	Comfort	24400.00
0005434344165	5314	Comfort	24400.00
0005435613406	5314	Comfort	24400.00
0005435613447	5314	Comfort	24400.00
0005435424023	5314	Comfort	24400.00
0005434344154	5314	Comfort	24400.00
0005435424050	5314	Comfort	24400.00
0005435423917	5314	Comfort	24400.00
0005434344170	5314	Comfort	24400.00
0005435490219	5314	Comfort	24400.00
0005435423975	5314	Comfort	24400.00
0005435613392	5314	Comfort	24400.00
0005435613405	5314	Comfort	24400.00
0005435424010	5314	Comfort	24400.00
0005435613412	5314	Comfort	24400.00
0005435097186	5314	Comfort	24400.00
0005435613459	5314	Economy	14400.00
0005434244721	5314	Economy	14400.00
0005435613387	5314	Economy	14400.00
0005435613440	5314	Economy	14400.00
0005432133186	5314	Economy	14400.00
0005434344155	5314	Economy	14400.00
0005435613375	5314	Economy	14400.00
0005434344158	5314	Economy	14400.00
0005435555364	5314	Economy	14400.00
0005435097182	5314	Economy	14400.00
0005435097189	5314	Economy	14400.00
0005435613381	5314	Economy	14400.00
0005435613377	5314	Economy	14400.00
0005435613423	5314	Economy	14400.00
0005434244677	5314	Economy	14400.00
0005435423969	5314	Economy	14400.00
0005435613430	5314	Economy	14400.00
0005434573327	5314	Economy	14400.00
0005435491435	5314	Economy	14400.00
0005435424328	5314	Economy	14400.00
0005435613451	5314	Economy	14400.00
0005435613388	5314	Economy	14400.00
0005435613410	5314	Economy	14400.00
0005435424401	5314	Economy	14400.00
0005435424400	5314	Economy	14400.00
0005435613397	5314	Economy	14400.00
0005435613379	5314	Economy	14400.00
0005435491437	5314	Economy	14400.00
0005435613438	5314	Economy	14400.00
0005435424436	5314	Economy	14400.00
0005434344167	5314	Economy	14400.00
0005434344150	5314	Economy	14400.00
0005435613374	5314	Economy	14400.00
0005435613395	5314	Economy	14400.00
0005434244617	5314	Economy	14400.00
0005434573326	5314	Economy	14400.00
0005434244782	5314	Economy	14400.00
0005435613439	5314	Economy	14400.00
0005434344136	5314	Economy	14400.00
0005434244656	5314	Economy	14400.00
0005434244582	5314	Economy	14400.00
0005435424144	5314	Economy	14400.00
0005434344139	5314	Economy	14400.00
0005435613453	5314	Economy	14400.00
0005434573321	5314	Economy	14400.00
0005435613445	5314	Economy	14400.00
0005435319505	5314	Economy	14400.00
0005434244680	5314	Economy	14400.00
0005434244787	5314	Economy	14400.00
0005435613409	5314	Economy	14400.00
0005435613467	5314	Economy	14400.00
0005434344138	5314	Economy	14400.00
0005435302144	5314	Economy	14400.00
0005434244786	5314	Economy	15800.00
0005435424334	5314	Economy	15800.00
0005434244632	5314	Economy	15800.00
0005434244665	5314	Economy	14400.00
0005435319512	5314	Economy	14400.00
0005435613478	5314	Economy	14400.00
0005435613428	5314	Economy	15800.00
0005434244618	5314	Economy	14400.00
0005435424008	5314	Economy	14400.00
0005435380248	5314	Economy	14400.00
0005435613376	5314	Economy	14400.00
0005435613462	5314	Economy	14400.00
0005434244590	5314	Economy	14400.00
0005435613465	5314	Economy	14400.00
0005435424335	5314	Economy	14400.00
0005435613472	5314	Economy	14400.00
0005435613470	5314	Economy	14400.00
0005435424325	5314	Economy	14400.00
0005435424222	5314	Economy	14400.00
0005435490221	5314	Economy	14400.00
0005435423870	5314	Economy	14400.00
0005434573323	5314	Economy	14400.00
0005435613452	5314	Economy	14400.00
0005434344142	5314	Economy	14400.00
0005434244646	5314	Economy	14400.00
0005434344160	5314	Economy	14400.00
0005435613385	5314	Economy	14400.00
0005435424316	5314	Economy	14400.00
0005435613432	5314	Economy	14400.00
0005434244699	5314	Economy	14400.00
0005435613418	5314	Economy	14400.00
0005435319487	5314	Economy	14400.00
0005435424009	5314	Economy	14400.00
0005435423976	5314	Economy	14400.00
0005435423954	5314	Economy	14400.00
0005434344145	5314	Economy	14400.00
0005435319506	5314	Economy	14400.00
0005435613400	5314	Economy	14400.00
0005435304999	5314	Economy	14400.00
0005435319478	5314	Economy	14400.00
0005435424275	5314	Economy	14400.00
0005434344147	5314	Economy	14400.00
0005435613378	5314	Economy	14400.00
0005434244611	5314	Economy	14400.00
0005435424228	5314	Economy	14400.00
0005435424211	5314	Economy	14400.00
0005435613389	5314	Economy	14400.00
0005435613479	5314	Economy	14400.00
0005435424258	5314	Economy	14400.00
0005435097185	5314	Economy	14400.00
0005435555363	5314	Economy	14400.00
0005434344146	5314	Economy	14400.00
0005435613442	5314	Economy	14400.00
0005432840992	5314	Economy	14400.00
0005434344140	5314	Economy	14400.00
0005432133180	5314	Economy	14400.00
0005435424257	5314	Economy	14400.00
0005432133181	5314	Economy	14400.00
0005434344156	5314	Economy	14400.00
0005435613455	5314	Economy	14400.00
0005435423992	5314	Economy	14400.00
0005435319504	5314	Economy	14400.00
0005434344166	5314	Economy	14400.00
0005435613473	5314	Economy	14400.00
0005434244712	5314	Economy	14400.00
0005432133184	5314	Economy	14400.00
0005435424049	5314	Economy	14400.00
0005435613402	5314	Economy	14400.00
0005435097184	5314	Economy	14400.00
0005435613433	5314	Economy	14400.00
0005434244651	5314	Economy	14400.00
0005435613399	5314	Economy	14400.00
0005432133187	5314	Economy	14400.00
0005435613420	5314	Economy	14400.00
0005435613443	5314	Economy	14400.00
0005435613456	5314	Economy	14400.00
0005435613380	5314	Economy	14400.00
0005435613396	5314	Economy	14400.00
0005435423989	5314	Economy	14400.00
0005435613436	5314	Economy	14400.00
0005435613384	5314	Economy	14400.00
0005432047543	5314	Economy	14400.00
0005435613483	5314	Economy	14400.00
0005434244530	5314	Economy	14400.00
0005435424152	5314	Economy	14400.00
0005434244781	5314	Economy	14400.00
0005435613419	5314	Economy	14400.00
0005434344137	5314	Economy	14400.00
0005435613426	5314	Economy	14400.00
0005434244813	5314	Economy	14400.00
0005435424269	5314	Economy	14400.00
0005434344162	5314	Economy	14400.00
0005435613437	5314	Economy	14400.00
0005432133174	5314	Economy	14400.00
0005435424052	5314	Economy	14400.00
0005435097181	5314	Economy	14400.00
0005434344157	5314	Economy	14400.00
0005435424166	5314	Economy	14400.00
0005434573330	5314	Economy	14400.00
0005434344152	5314	Economy	14400.00
0005435613454	5314	Economy	14400.00
0005435424279	5314	Economy	14400.00
0005434573322	5314	Economy	14400.00
0005435319481	5314	Economy	14400.00
0005435613403	5314	Economy	15800.00
0005434344161	5314	Economy	15800.00
0005435380249	5314	Economy	15800.00
0005435613425	5314	Economy	14400.00
0005435613394	5314	Economy	14400.00
0005434344169	5314	Economy	14400.00
0005435319474	5314	Economy	14400.00
0005432133185	5314	Economy	14400.00
0005434244559	5314	Economy	14400.00
0005435424283	5314	Economy	14400.00
0005432133175	5314	Economy	14400.00
0005435424147	5314	Economy	14400.00
0005435613448	5314	Economy	14400.00
0005433719088	5314	Economy	14400.00
0005435424148	5314	Economy	14400.00
0005435424054	5314	Economy	14400.00
0005435613422	5314	Economy	14400.00
0005435613460	5314	Economy	14400.00
0005435613484	5314	Economy	14400.00
0005434344148	5314	Economy	14400.00
0005435613373	5314	Economy	14400.00
0005434344144	5314	Economy	14400.00
0005435304998	5314	Economy	14400.00
0005435613485	5314	Economy	14400.00
0005432363367	5314	Economy	14400.00
0005434344143	5314	Economy	14400.00
0005435490218	5314	Economy	14400.00
0005435613416	5314	Economy	14400.00
0005432133183	5314	Economy	14400.00
0005434344151	5314	Economy	14400.00
0005435613398	5314	Economy	14400.00
0005434573320	5314	Economy	14400.00
0005435613469	5314	Economy	14400.00
0005435424399	5314	Economy	14400.00
0005435424529	5314	Economy	14400.00
0005434344163	5314	Economy	14400.00
0005434344164	5314	Economy	14400.00
0005435613401	5314	Economy	14400.00
0005435613386	5314	Economy	14400.00
0005435613431	5314	Economy	14400.00
0005435097183	5314	Economy	14400.00
0005434573328	5314	Economy	14400.00
0005435613435	5314	Economy	14400.00
0005432133182	5314	Economy	14400.00
0005435424274	5314	Economy	14400.00
0005435613482	5314	Economy	14400.00
0005435613407	5314	Economy	14400.00
0005435613481	5314	Economy	14400.00
0005434244700	5314	Economy	14400.00
0005434344153	5314	Economy	14400.00
0005435613390	5314	Economy	14400.00
0005435319511	5314	Economy	14400.00
0005435613411	5314	Economy	14400.00
0005435613446	5314	Economy	14400.00
0005434573331	5314	Economy	14400.00
0005435424075	5314	Economy	14400.00
0005434244627	5314	Economy	14400.00
0005435424191	5314	Economy	14400.00
0005432363385	5314	Economy	14400.00
0005435613393	5314	Economy	14400.00
0005435491438	5314	Economy	14400.00
0005432047544	5314	Economy	14400.00
0005434344173	5314	Economy	14400.00
0005435424053	5314	Economy	14400.00
0005434344141	5314	Economy	14400.00
0005435613421	5314	Economy	14400.00
0005434573318	5314	Economy	14400.00
0005435613417	5314	Economy	14400.00
0005434573325	5314	Economy	14400.00
0005434344159	5314	Economy	14400.00
0005434244503	5314	Economy	14400.00
0005435423893	5314	Economy	14400.00
0005435613458	5314	Economy	14400.00
0005435490220	5314	Economy	14400.00
0005435613382	5314	Economy	14400.00
0005435424076	5314	Economy	14400.00
0005435491436	5314	Economy	14400.00
0005435613486	5314	Economy	14400.00
0005435424022	5314	Economy	14400.00
0005435424333	5314	Economy	14400.00
0005434344172	5314	Economy	14400.00
0005435613391	5314	Economy	14400.00
0005435424324	5314	Economy	14400.00
0005435613466	5314	Economy	14400.00
0005435424074	5314	Economy	14400.00
0005435423795	5314	Economy	14400.00
0005435613457	5314	Economy	14400.00
0005434244570	5314	Economy	14400.00
0005434573319	5314	Economy	14400.00
0005432133178	5314	Economy	14400.00
0005435302166	5314	Economy	14400.00
0005434344149	5314	Economy	14400.00
0005435613424	5314	Economy	14400.00
0005435424233	5314	Economy	14400.00
0005435424047	5314	Economy	14400.00
0005434573329	5314	Economy	14400.00
0005435380268	5314	Economy	14400.00
0005435424530	5314	Economy	14400.00
0005434244911	10916	Business	43100.00
0005435097071	10916	Business	43100.00
0005435319551	10916	Business	43100.00
0005434343704	10916	Business	43100.00
0005435424701	10916	Business	43100.00
0005435612476	10916	Business	43100.00
0005434244917	10916	Business	43100.00
0005435611978	10916	Business	43100.00
0005435611818	10916	Business	43100.00
0005435612544	10916	Business	43100.00
0005435612770	10916	Business	43100.00
0005434343887	10916	Business	43100.00
0005435319553	10916	Business	43100.00
0005435424691	10916	Business	43100.00
0005435612501	10916	Business	43100.00
0005434343719	10916	Business	43100.00
0005435612638	10916	Business	43100.00
0005432363411	10916	Business	43100.00
0005435424696	10916	Business	43100.00
0005435424680	10916	Business	43100.00
0005434343735	10916	Business	43100.00
0005434244927	10916	Business	43100.00
0005435612819	10916	Business	43100.00
0005435491421	10916	Business	43100.00
0005435424669	10916	Business	43100.00
0005435380281	10916	Business	43100.00
0005435612619	10916	Business	43100.00
0005435611879	10916	Business	43100.00
0005435555347	10916	Business	43100.00
0005434343800	10916	Comfort	24400.00
0005435491420	10916	Comfort	24400.00
0005434244914	10916	Comfort	24400.00
0005435424670	10916	Comfort	24400.00
0005435424676	10916	Comfort	24400.00
0005435612559	10916	Comfort	24400.00
0005434573178	10916	Comfort	24400.00
0005435424653	10916	Comfort	24400.00
0005434343754	10916	Comfort	24400.00
0005434343693	10916	Comfort	24400.00
0005432841009	10916	Comfort	24400.00
0005435612765	10916	Comfort	24400.00
0005435612296	10916	Comfort	24400.00
0005434244925	10916	Comfort	24400.00
0005435612590	10916	Comfort	24400.00
0005435612405	10916	Comfort	24400.00
0005435042854	10916	Comfort	24400.00
0005435612589	10916	Comfort	24400.00
0005435424644	10916	Comfort	24400.00
0005432166895	10916	Comfort	24400.00
0005435424650	10916	Comfort	24400.00
0005435612322	10916	Comfort	24400.00
0005435097078	10916	Comfort	24400.00
0005434343662	10916	Comfort	24400.00
0005435424675	10916	Comfort	24400.00
0005435424662	10916	Comfort	24400.00
0005435612518	10916	Comfort	24400.00
0005435424700	10916	Comfort	24400.00
0005435424666	10916	Comfort	24400.00
0005435380286	10916	Comfort	24400.00
0005435612626	10916	Comfort	24400.00
0005434244908	10916	Comfort	24400.00
0005435612499	10916	Comfort	24400.00
0005435612630	10916	Comfort	24400.00
0005435042852	10916	Comfort	24400.00
0005435424677	10916	Comfort	24400.00
0005435612602	10916	Comfort	24400.00
0005434244926	10916	Comfort	24400.00
0005435612524	10916	Comfort	24400.00
0005435612492	10916	Comfort	24400.00
0005435612480	10916	Comfort	24400.00
0005435424633	10916	Comfort	24400.00
0005434343818	10916	Economy	14400.00
0005434244918	10916	Economy	14400.00
0005435612274	10916	Comfort	24400.00
0005435424688	10916	Economy	14400.00
0005435612675	10916	Economy	14400.00
0005434244920	10916	Economy	14400.00
0005434244923	10916	Economy	14400.00
0005434343951	10916	Economy	14400.00
0005435319555	10916	Economy	14400.00
0005435612385	10916	Economy	14400.00
0005435612328	10916	Economy	14400.00
0005434244909	10916	Economy	14400.00
0005435612721	10916	Economy	14400.00
0005434573192	10916	Economy	14400.00
0005435612733	10916	Economy	14400.00
0005435424684	10916	Economy	14400.00
0005435555345	10916	Economy	14400.00
0005435612452	10916	Economy	14400.00
0005434343848	10916	Economy	14400.00
0005435097053	10916	Economy	14400.00
0005435612525	10916	Economy	14400.00
0005435424656	10916	Economy	14400.00
0005433719134	10916	Economy	14400.00
0005435424643	10916	Economy	14400.00
0005435612449	10916	Economy	14400.00
0005435612732	10916	Economy	14400.00
0005435611963	10916	Economy	14400.00
0005435612751	10916	Economy	14400.00
0005435424672	10916	Economy	14400.00
0005434244928	10916	Economy	14400.00
0005432165025	10916	Economy	14400.00
0005434343659	10916	Economy	14400.00
0005435424673	10916	Economy	14400.00
0005435612456	10916	Economy	14400.00
0005435612515	10916	Economy	14400.00
0005434343738	10916	Economy	14400.00
0005435380283	10916	Economy	14400.00
0005435612560	10916	Economy	14400.00
0005435612502	10916	Economy	14400.00
0005435491422	10916	Economy	14400.00
0005435424667	10916	Economy	14400.00
0005432165023	10916	Economy	14400.00
0005434573144	10916	Economy	14400.00
0005434244922	10916	Economy	14400.00
0005435612382	10916	Economy	14400.00
0005435490192	10916	Economy	14400.00
0005434573176	10916	Economy	14400.00
0005435612585	10916	Economy	14400.00
0005435612671	10916	Economy	14400.00
0005434343846	10916	Economy	14400.00
0005435424641	10916	Economy	14400.00
0005434573207	10916	Economy	14400.00
0005435424651	10916	Economy	14400.00
0005435612812	10916	Economy	14400.00
0005432166897	10916	Economy	14400.00
0005435612558	10916	Economy	14400.00
0005435612395	10916	Economy	14400.00
0005434343669	10916	Economy	14400.00
0005435097109	10916	Economy	14400.00
0005435612400	10916	Economy	14400.00
0005435304146	10916	Economy	14400.00
0005435424652	10916	Economy	15800.00
0005434343694	10916	Economy	15800.00
0005435305011	10916	Economy	15800.00
0005435424697	10916	Economy	14400.00
0005435319556	10916	Economy	14400.00
0005435424637	10916	Economy	15800.00
0005434343755	10916	Economy	14400.00
0005434244919	10916	Economy	15800.00
0005435424663	10916	Economy	15800.00
0005432166896	10916	Economy	14400.00
0005435612424	10916	Economy	14400.00
0005435424664	10916	Economy	14400.00
0005435424659	10916	Economy	14400.00
0005435424683	10916	Economy	14400.00
0005435424692	10916	Economy	14400.00
0005435424634	10916	Economy	14400.00
0005435424661	10916	Economy	14400.00
0005432165024	10916	Economy	14400.00
0005435612203	10916	Economy	14400.00
0005435097064	10916	Economy	14400.00
0005434343660	10916	Economy	14400.00
0005435612603	10916	Economy	14400.00
0005434573132	10916	Economy	14400.00
0005435424665	10916	Economy	14400.00
0005435319558	10916	Economy	14400.00
0005435612500	10916	Economy	14400.00
0005435612047	10916	Economy	14400.00
0005434343788	10916	Economy	14400.00
0005434343734	10916	Economy	14400.00
0005435612628	10916	Economy	14400.00
0005435424682	10916	Economy	14400.00
0005435612579	10916	Economy	14400.00
0005432363409	10916	Economy	14400.00
0005435424689	10916	Economy	14400.00
0005435424686	10916	Economy	14400.00
0005434573162	10916	Economy	14400.00
0005435612386	10916	Economy	14400.00
0005434573131	10916	Economy	14400.00
0005434244912	10916	Economy	14400.00
0005434573190	10916	Economy	14400.00
0005435304147	10916	Economy	14400.00
0005434343809	10916	Economy	14400.00
0005435612669	10916	Economy	14400.00
0005435612684	10916	Economy	14400.00
0005435611880	10916	Economy	14400.00
0005435612361	10916	Economy	14400.00
0005435612430	10916	Economy	14400.00
0005435424648	10916	Economy	14400.00
0005435097052	10916	Economy	14400.00
0005435612543	10916	Economy	14400.00
0005434573177	10916	Economy	14400.00
0005435612011	10916	Economy	14400.00
0005434656553	10916	Economy	14400.00
0005435424679	10916	Economy	14400.00
0005435424654	10916	Economy	14400.00
0005435612622	10916	Economy	14400.00
0005434573186	10916	Economy	14400.00
0005434573189	10916	Economy	14400.00
0005434573231	10916	Economy	14400.00
0005434244906	10916	Economy	14400.00
0005435612567	10916	Economy	14400.00
0005434343629	10916	Economy	14400.00
0005435380284	10916	Economy	14400.00
0005432165019	10916	Economy	14400.00
0005434343787	10916	Economy	14400.00
0005435612177	10916	Economy	14400.00
0005435424646	10916	Economy	14400.00
0005435380282	10916	Economy	14400.00
0005434573230	10916	Economy	14400.00
0005432841010	10916	Economy	14400.00
0005435612201	10916	Economy	14400.00
0005434343839	10916	Economy	14400.00
0005434343982	10916	Economy	14400.00
0005435612393	10916	Economy	14400.00
0005435612813	10916	Economy	14400.00
0005435424693	10916	Economy	14400.00
0005435612666	10916	Economy	14400.00
0005435612398	10916	Economy	14400.00
0005435612606	10916	Economy	14400.00
0005435612529	10916	Economy	14400.00
0005435612516	10916	Economy	14400.00
0005435319554	10916	Economy	14400.00
0005435612655	10916	Economy	14400.00
0005434244907	10916	Economy	14400.00
0005434343749	10916	Economy	14400.00
0005434244916	10916	Economy	14400.00
0005435612627	10916	Economy	14400.00
0005435612336	10916	Economy	14400.00
0005434244931	10916	Economy	14400.00
0005435612459	10916	Economy	14400.00
0005435612307	10916	Economy	14400.00
0005435380285	10916	Economy	14400.00
0005435424658	10916	Economy	14400.00
0005435424636	10916	Economy	14400.00
0005435612629	10916	Economy	14400.00
0005435612454	10916	Economy	14400.00
0005435319550	10916	Economy	14400.00
0005434244915	10916	Economy	14400.00
0005435612514	10916	Economy	14400.00
0005435612256	10916	Economy	14400.00
0005434343849	10916	Economy	14400.00
0005435612388	10916	Economy	14400.00
0005435612587	10916	Economy	14400.00
0005435424674	10916	Economy	14400.00
0005435424681	10916	Economy	14400.00
0005434244913	10916	Economy	14400.00
0005435319557	10916	Economy	14400.00
0005435424635	10916	Economy	14400.00
0005435612569	10916	Economy	15800.00
0005435612048	10916	Economy	15800.00
0005434573197	10916	Economy	15800.00
0005435380287	10916	Economy	15800.00
0005435424698	10916	Economy	14400.00
0005434244910	10916	Economy	15800.00
0005432165022	10916	Economy	14400.00
0005435611878	10916	Economy	14400.00
0005435097070	10916	Economy	14400.00
0005434656554	10916	Economy	14400.00
0005435612672	10916	Economy	14400.00
0005435305010	10916	Economy	14400.00
0005435424685	10916	Economy	14400.00
0005435612202	10916	Economy	14400.00
0005435042855	10916	Economy	14400.00
0005435612253	10916	Economy	14400.00
0005435424647	10916	Economy	14400.00
0005435424657	10916	Economy	14400.00
0005435612321	10916	Economy	14400.00
0005434244929	10916	Economy	14400.00
0005434343845	10916	Economy	14400.00
0005435490181	10916	Economy	14400.00
0005432363410	10916	Economy	14400.00
0005434343983	10916	Economy	14400.00
0005435612216	10916	Economy	14400.00
0005434244921	10916	Economy	14400.00
0005435424687	10916	Economy	14400.00
0005435424690	10916	Economy	14400.00
0005433719135	10916	Economy	14400.00
0005434573188	10916	Economy	14400.00
0005435612257	10916	Economy	14400.00
0005435424699	10916	Economy	14400.00
0005435612578	10916	Economy	14400.00
0005435612667	10916	Economy	14400.00
0005435612191	10916	Economy	14400.00
0005435612654	10916	Economy	14400.00
0005434573191	10916	Economy	14400.00
0005435612458	10916	Economy	14400.00
0005435612479	10916	Economy	14400.00
0005434244930	10916	Economy	14400.00
0005435612485	10916	Economy	14400.00
0005434343952	10916	Economy	14400.00
0005434244932	10916	Economy	14400.00
0005435612557	10916	Economy	14400.00
0005435424645	10916	Economy	14400.00
0005435555346	10916	Economy	14400.00
0005435319552	10916	Economy	14400.00
0005432166894	10916	Economy	14400.00
0005434343718	10916	Economy	14400.00
0005435612453	10916	Economy	14400.00
0005434656552	10916	Economy	14400.00
0005435612158	10916	Economy	14400.00
0005435424695	10916	Economy	14400.00
0005435612513	10916	Economy	14400.00
0005435424649	10916	Economy	14400.00
0005435611962	10916	Economy	14400.00
0005432166893	10916	Economy	14400.00
0005435612637	10916	Economy	14400.00
0005435424668	10916	Economy	14400.00
0005435612377	10916	Economy	14400.00
0005435612512	10916	Economy	14400.00
0005434343864	10916	Economy	14400.00
0005435612752	10916	Economy	14400.00
0005434343652	10916	Economy	14400.00
0005435612043	10916	Economy	14400.00
0005435042853	10916	Economy	14400.00
0005435424671	10916	Economy	14400.00
0005434573216	10916	Economy	14400.00
0005434343863	10916	Economy	14400.00
0005435612690	10916	Economy	14400.00
0005434343870	10916	Economy	14400.00
0005435612699	10916	Economy	14400.00
0005435424660	10916	Economy	14400.00
0005435424642	10916	Economy	14400.00
0005435612604	10916	Economy	14400.00
0005435424702	10916	Economy	14400.00
0005434343871	10916	Economy	14400.00
0005435424694	10916	Economy	14400.00
0005435612650	10916	Economy	14400.00
0005434343677	10916	Economy	14400.00
0005435612745	10916	Economy	14400.00
0005435612252	10916	Economy	14400.00
0005435424678	10916	Economy	14400.00
0005435304145	10916	Economy	14400.00
0005435612387	10916	Economy	14400.00
0005435424640	10916	Economy	14400.00
0005434244933	10916	Economy	14400.00
0005432165018	10916	Economy	14400.00
0005434573179	10916	Economy	14400.00
0005435424639	10916	Economy	14400.00
0005435612615	10916	Economy	14400.00
0005434244934	10916	Economy	14400.00
0005434343739	10916	Economy	14400.00
0005435612722	10916	Economy	14400.00
0005435424638	10916	Economy	14400.00
0005435611909	10916	Economy	14400.00
0005432165020	10916	Economy	14400.00
0005432165021	10916	Economy	14400.00
0005434244924	10916	Economy	14400.00
0005435612477	10916	Economy	14400.00
0005435612561	10916	Economy	14400.00
0005435424655	10916	Economy	14400.00
0005432459263	3349	Business	18800.00
0005432459335	3349	Business	18800.00
0005432181675	3349	Business	18800.00
0005433507151	3349	Business	18800.00
0005433507155	3349	Business	18800.00
0005433633745	3349	Business	18800.00
0005432459209	3349	Business	18800.00
0005432181663	3349	Business	18800.00
0005433805302	3349	Business	18800.00
0005432459435	3349	Business	18800.00
0005433633749	3349	Business	18800.00
0005432459373	3349	Business	18800.00
0005432459208	3349	Business	18800.00
0005433805320	3349	Business	18800.00
0005433633738	3349	Business	18800.00
0005433633762	3349	Business	18800.00
0005433805310	3349	Business	18800.00
0005433805289	3349	Business	18800.00
0005433633758	3349	Business	18800.00
0005433507145	3349	Business	18800.00
0005432459119	3349	Business	18800.00
0005432459368	3349	Business	18800.00
0005433633752	3349	Business	18800.00
0005432459372	3349	Business	18800.00
0005433633754	3349	Business	18800.00
0005432181672	3349	Business	18800.00
0005433805291	3349	Economy	6900.00
0005432459210	3349	Economy	6900.00
0005432181680	3349	Economy	6900.00
0005433805288	3349	Economy	6900.00
0005433507147	3349	Economy	6900.00
0005433633739	3349	Economy	6900.00
0005433633747	3349	Economy	6300.00
0005433633742	3349	Economy	6300.00
0005432459125	3349	Economy	6300.00
0005433633763	3349	Economy	6300.00
0005432459190	3349	Economy	6300.00
0005433805300	3349	Economy	6300.00
0005432459191	3349	Economy	6300.00
0005432181669	3349	Economy	6300.00
0005432459290	3349	Economy	6300.00
0005433633770	3349	Economy	6300.00
0005432459161	3349	Economy	6300.00
0005433805307	3349	Economy	6300.00
0005432459380	3349	Economy	6300.00
0005433633743	3349	Economy	6300.00
0005432181681	3349	Economy	6300.00
0005432459124	3349	Economy	6300.00
0005432459072	3349	Economy	6300.00
0005432459308	3349	Economy	6300.00
0005432181665	3349	Economy	6300.00
0005432459171	3349	Economy	6300.00
0005433805304	3349	Economy	6300.00
0005433633755	3349	Economy	6300.00
0005433633766	3349	Economy	6300.00
0005432459374	3349	Economy	6300.00
0005433805290	3349	Economy	6300.00
0005433805297	3349	Economy	6300.00
0005433805308	3349	Economy	6300.00
0005433805325	3349	Economy	6300.00
0005433805292	3349	Economy	6300.00
0005433633748	3349	Economy	6300.00
0005433633760	3349	Economy	6300.00
0005433805296	3349	Economy	6300.00
0005433805305	3349	Economy	6300.00
0005433507146	3349	Economy	6300.00
0005433633744	3349	Economy	6300.00
0005432459299	3349	Economy	6300.00
0005432459253	3349	Economy	6300.00
0005433805294	3349	Economy	6300.00
0005432459145	3349	Economy	6300.00
0005432181678	3349	Economy	6300.00
0005432459340	3349	Economy	6300.00
0005433805309	3349	Economy	6300.00
0005433805298	3349	Economy	6300.00
0005432181670	3349	Economy	6300.00
0005433805321	3349	Economy	6300.00
0005433633768	3349	Economy	6300.00
0005432459262	3349	Economy	6300.00
0005432181662	3349	Economy	6300.00
0005433805319	3349	Economy	6300.00
0005432459126	3349	Economy	6300.00
0005433805318	3349	Economy	6300.00
0005432459309	3349	Economy	6300.00
0005433633761	3349	Economy	6300.00
0005433507153	3349	Economy	6300.00
0005432459254	3349	Economy	6300.00
0005433805299	3349	Economy	6300.00
0005433633757	3349	Economy	6300.00
0005433633737	3349	Economy	6300.00
0005433507156	3349	Economy	6900.00
0005433633750	3349	Economy	6900.00
0005433507154	3349	Economy	6900.00
0005432459496	3349	Economy	6900.00
0005433507148	3349	Economy	6900.00
0005432181682	3349	Economy	6300.00
0005433633741	3349	Economy	6300.00
0005433805315	3349	Economy	6300.00
0005433805306	3349	Economy	6300.00
0005432459198	3349	Economy	6900.00
0005432181677	3349	Economy	6300.00
0005433633765	3349	Economy	6300.00
0005433633769	3349	Economy	6300.00
0005432459465	3349	Economy	6300.00
0005433805326	3349	Economy	6300.00
0005432459484	3349	Economy	6300.00
0005433805313	3349	Economy	6300.00
0005433805293	3349	Economy	6300.00
0005432181667	3349	Economy	6300.00
0005433805316	3349	Economy	6300.00
0005433633756	3349	Economy	6300.00
0005433805311	3349	Economy	6300.00
0005432459014	3349	Economy	6300.00
0005433507144	3349	Economy	6300.00
0005432459470	3349	Economy	6300.00
0005433633767	3349	Economy	6300.00
0005432459381	3349	Economy	6300.00
0005433507150	3349	Economy	6300.00
0005432181668	3349	Economy	6300.00
0005433805317	3349	Economy	6300.00
0005432459329	3349	Economy	6300.00
0005432181673	3349	Economy	6300.00
0005432459162	3349	Economy	6300.00
0005432459318	3349	Economy	6300.00
0005432459341	3349	Economy	6300.00
0005433805327	3349	Economy	6300.00
0005433633751	3349	Economy	6300.00
0005432459436	3349	Economy	6300.00
0005432181664	3349	Economy	6300.00
0005432459289	3349	Economy	6300.00
0005432181683	3349	Economy	6300.00
0005432459325	3349	Economy	6300.00
0005433633740	3349	Economy	6300.00
0005433805312	3349	Economy	6300.00
0005433507152	3349	Economy	6300.00
0005433805287	3349	Economy	6300.00
0005433507142	3349	Economy	6300.00
0005432459331	3349	Economy	6300.00
0005432181674	3349	Economy	6300.00
0005433805303	3349	Economy	6300.00
0005432181679	3349	Economy	6300.00
0005432459326	3349	Economy	6300.00
0005432181666	3349	Economy	6300.00
0005433507141	3349	Economy	6300.00
0005432181671	3349	Economy	6300.00
0005433507149	3349	Economy	6300.00
0005433633746	3349	Economy	6300.00
0005432459278	3349	Economy	6300.00
0005432459291	3349	Economy	6300.00
0005432459267	3349	Economy	6300.00
0005433633764	3349	Economy	6300.00
0005433633753	3349	Economy	6300.00
0005433805323	3349	Economy	6300.00
0005433805314	3349	Economy	6300.00
0005432181676	3349	Economy	6300.00
0005432459277	3349	Economy	6300.00
0005433805301	3349	Economy	6300.00
0005433805322	3349	Economy	6300.00
0005433805286	3349	Economy	6300.00
0005433805295	3349	Economy	6300.00
0005433805324	3349	Economy	6300.00
0005433507143	3349	Economy	6300.00
0005432459469	3349	Economy	6300.00
0005433633759	3349	Economy	6300.00
0005435884708	3348	Business	18800.00
0005435884904	3348	Business	18800.00
0005435884882	3348	Business	18800.00
0005435884649	3348	Business	18800.00
0005435884787	3348	Business	18800.00
0005435884818	3348	Business	18800.00
0005435884897	3348	Economy	6900.00
0005435884951	3348	Economy	6900.00
0005435884828	3348	Economy	6900.00
0005435884689	3348	Economy	6900.00
0005435884990	3348	Economy	6300.00
0005435884798	3348	Economy	6300.00
0005435884797	3348	Economy	6300.00
0005435884616	3348	Economy	6300.00
0005435884759	3348	Economy	6300.00
0005435884889	3348	Economy	6300.00
0005435884617	3348	Economy	6300.00
0005435884826	3348	Economy	6300.00
0005435884808	3348	Economy	6300.00
0005435884958	3348	Economy	6300.00
0005435884751	3348	Economy	6300.00
0005435884629	3348	Economy	6300.00
0005435884756	3348	Economy	6300.00
0005435884676	3348	Economy	6300.00
0005435884832	3348	Economy	6300.00
0005435884707	3348	Economy	6300.00
0005435884711	3348	Economy	6300.00
0005435884847	3348	Economy	6300.00
0005435884712	3348	Economy	6300.00
0005435884491	3348	Economy	6300.00
0005435884807	3348	Economy	6300.00
0005435884631	3348	Economy	6300.00
0005435884768	3348	Economy	6300.00
0005435884824	3348	Economy	6300.00
0005435884648	3348	Economy	6300.00
0005435884538	3348	Economy	6300.00
0005435884680	3348	Economy	6300.00
0005435884772	3348	Economy	6300.00
0005435884905	3348	Economy	6300.00
0005435884767	3348	Economy	6300.00
0005435884618	3348	Economy	6300.00
0005435884856	3348	Economy	6300.00
0005435884825	3348	Economy	6300.00
0005435884662	3348	Economy	6300.00
0005435884773	3348	Economy	6300.00
0005435884737	3348	Economy	6300.00
0005435884720	3348	Economy	6300.00
0005435884642	3348	Economy	6300.00
0005435884752	3348	Economy	6300.00
0005435884855	3348	Economy	6300.00
0005435884714	3348	Economy	6300.00
0005435884641	3348	Economy	6300.00
0005435884786	3348	Economy	6300.00
0005435884679	3348	Economy	6300.00
0005435884771	3348	Economy	6300.00
0005435884843	3348	Economy	6300.00
0005435884755	3348	Economy	6300.00
0005435884490	3348	Economy	6300.00
0005435884735	3348	Economy	6300.00
0005435885180	8201	Business	18800.00
0005432459792	8201	Business	18800.00
0005432459769	8201	Business	18800.00
0005432459761	8201	Business	18800.00
0005433506996	8201	Business	18800.00
0005435885179	8201	Business	18800.00
0005435885149	8201	Business	18800.00
0005432459801	8201	Business	18800.00
0005433507019	8201	Business	18800.00
0005435885135	8201	Business	18800.00
0005432459762	8201	Business	18800.00
0005432042681	8201	Business	18800.00
0005435885159	8201	Business	18800.00
0005433507045	8201	Business	18800.00
0005435885174	8201	Business	18800.00
0005432459775	8201	Business	18800.00
0005435885137	8201	Business	18800.00
0005434312317	8201	Business	18800.00
0005432459772	8201	Business	18800.00
0005432459791	8201	Business	18800.00
0005432459770	8201	Business	18800.00
0005435885143	8201	Business	18800.00
0005435885126	8201	Business	18800.00
0005435885131	8201	Business	18800.00
0005432459800	8201	Economy	6900.00
0005432459781	8201	Economy	6900.00
0005432459764	8201	Economy	6900.00
0005435885169	8201	Economy	6900.00
0005432459776	8201	Economy	6900.00
0005435885152	8201	Economy	6300.00
0005432459788	8201	Economy	6300.00
0005432459768	8201	Economy	6300.00
0005435885171	8201	Economy	6300.00
0005432459763	8201	Economy	6300.00
0005432459786	8201	Economy	6300.00
0005432042694	8201	Economy	6300.00
0005435885162	8201	Economy	6300.00
0005432042689	8201	Economy	6300.00
0005435885168	8201	Economy	6300.00
0005433507037	8201	Economy	6300.00
0005435885170	8201	Economy	6300.00
0005432459787	8201	Economy	6300.00
0005432459773	8201	Economy	6300.00
0005435885142	8201	Economy	6300.00
0005432042683	8201	Economy	6300.00
0005435885155	8201	Economy	6300.00
0005432459783	8201	Economy	6300.00
0005432042686	8201	Economy	6300.00
0005432459759	8201	Economy	6300.00
0005435885146	8201	Economy	6300.00
0005435885141	8201	Economy	6300.00
0005435885140	8201	Economy	6300.00
0005435885175	8201	Economy	6300.00
0005435885127	8201	Economy	6300.00
0005432459798	8201	Economy	6300.00
0005432459790	8201	Economy	6300.00
0005432459810	8201	Economy	6300.00
0005435885164	8201	Economy	6300.00
0005435885129	8201	Economy	6300.00
0005432459808	8201	Economy	6300.00
0005432459799	8201	Economy	6300.00
0005433506998	8201	Economy	6300.00
0005433506977	8201	Economy	6300.00
0005432042692	8201	Economy	6300.00
0005435885157	8201	Economy	6300.00
0005435885133	8201	Economy	6300.00
0005432459802	8201	Economy	6300.00
0005435885176	8201	Economy	6300.00
0005435885167	8201	Economy	6300.00
0005432459805	8201	Economy	6300.00
0005432459782	8201	Economy	6300.00
0005435885145	8201	Economy	6300.00
0005435885177	8201	Economy	6300.00
0005435885156	8201	Economy	6300.00
0005432459774	8201	Economy	6300.00
0005435885148	8201	Economy	6300.00
0005432042690	8201	Economy	6300.00
0005435885139	8201	Economy	6300.00
0005432042691	8201	Economy	6900.00
0005432459785	8201	Economy	6900.00
0005433506994	8201	Economy	6900.00
0005435885150	8201	Economy	6900.00
0005432459771	8201	Economy	6900.00
0005432042688	8201	Economy	6300.00
0005432459767	8201	Economy	6300.00
0005432459780	8201	Economy	6300.00
0005432459806	8201	Economy	6300.00
0005433506997	8201	Economy	6300.00
0005435885130	8201	Economy	6300.00
0005433507035	8201	Economy	6300.00
0005433506958	8201	Economy	6300.00
0005435885132	8201	Economy	6300.00
0005432459793	8201	Economy	6300.00
0005432459778	8201	Economy	6300.00
0005435885173	8201	Economy	6300.00
0005432459795	8201	Economy	6300.00
0005435885134	8201	Economy	6300.00
0005435885181	8201	Economy	6300.00
0005432459794	8201	Economy	6300.00
0005435885165	8201	Economy	6300.00
0005433506944	8201	Economy	6300.00
0005432042682	8201	Economy	6300.00
0005432042684	8201	Economy	6300.00
0005434312316	8201	Economy	6300.00
0005432042687	8201	Economy	6300.00
0005432459809	8201	Economy	6300.00
0005432042685	8201	Economy	6300.00
0005435885182	8201	Economy	6300.00
0005435885158	8201	Economy	6300.00
0005432459766	8201	Economy	6300.00
0005435885128	8201	Economy	6300.00
0005432459760	8201	Economy	6300.00
0005435885153	8201	Economy	6300.00
0005432459758	8201	Economy	6300.00
0005432459796	8201	Economy	6300.00
0005435885136	8201	Economy	6300.00
0005435885138	8201	Economy	6300.00
0005432459784	8201	Economy	6300.00
0005432459811	8201	Economy	6300.00
0005432459803	8201	Economy	6300.00
0005435885172	8201	Economy	6300.00
0005435885178	8201	Economy	6300.00
0005432042693	8201	Economy	6300.00
0005432459777	8201	Economy	6300.00
0005435885161	8201	Economy	6300.00
0005435885144	8201	Economy	6300.00
0005435885163	8201	Economy	6300.00
0005433507020	8201	Economy	6300.00
0005432459807	8201	Economy	6300.00
0005433506949	8201	Economy	6300.00
0005435885160	8201	Economy	6300.00
0005432459765	8201	Economy	6300.00
0005435885147	8201	Economy	6300.00
0005432459804	8201	Economy	6300.00
0005435885154	8201	Economy	6300.00
0005432459812	8201	Economy	6300.00
0005432459797	8201	Economy	6300.00
0005435885151	8201	Economy	6300.00
0005432459789	8201	Economy	6300.00
0005435885166	8201	Economy	6300.00
0005432459779	8201	Economy	6300.00
0005433805001	8225	Business	18800.00
0005433805076	8225	Business	18800.00
0005433633529	8225	Business	18800.00
0005433804926	8225	Business	18800.00
0005434143702	8225	Business	18800.00
0005433633528	8225	Business	18800.00
0005433804976	8225	Business	18800.00
0005433633483	8225	Economy	6900.00
0005433633420	8225	Economy	6900.00
0005433633408	8225	Economy	6900.00
0005433633518	8225	Economy	6300.00
0005433805071	8225	Economy	6300.00
0005433633476	8225	Economy	6300.00
0005433805106	8225	Economy	6300.00
0005433633393	8225	Economy	6300.00
0005433633395	8225	Economy	6300.00
0005433633509	8225	Economy	6300.00
0005433805032	8225	Economy	6300.00
0005433805070	8225	Economy	6300.00
0005433804939	8225	Economy	6300.00
0005433633409	8225	Economy	6300.00
0005433805017	8225	Economy	6300.00
0005433633403	8225	Economy	6300.00
0005433633410	8225	Economy	6300.00
0005433805086	8225	Economy	6300.00
0005433804978	8225	Economy	6300.00
0005433633404	8225	Economy	6300.00
0005433633519	8225	Economy	6300.00
0005433633368	8225	Economy	6300.00
0005433804967	8225	Economy	6300.00
0005433804977	8225	Economy	6300.00
0005433805099	8225	Economy	6900.00
0005433805047	8225	Economy	6300.00
0005433633628	8225	Economy	6900.00
0005433633358	8225	Economy	6300.00
0005433805069	8225	Economy	6300.00
0005433633390	8225	Economy	6300.00
0005433633341	8225	Economy	6300.00
0005433633380	8225	Economy	6300.00
0005433805016	8225	Economy	6300.00
0005433633392	8225	Economy	6300.00
0005433633535	8225	Economy	6300.00
0005433633405	8225	Economy	6300.00
0005433804965	8225	Economy	6300.00
0005433633536	8225	Economy	6300.00
0005433633369	8225	Economy	6300.00
0005433633355	8225	Economy	6300.00
0005433633544	8225	Economy	6300.00
0005433804991	8225	Economy	6300.00
0005433633381	8225	Economy	6300.00
0005433805013	8225	Economy	6300.00
0005433633391	8225	Economy	6300.00
0005433804927	8225	Economy	6300.00
0005433804966	8225	Economy	6300.00
0005433633302	8225	Economy	6300.00
0005433805012	8225	Economy	6300.00
0005433633629	8225	Economy	6300.00
0005434183563	8301	Economy	6300.00
0005434183553	8301	Economy	6300.00
0005434183554	8301	Economy	6300.00
0005432383100	4580	Business	9900.00
0005432727909	4580	Business	9900.00
0005432727919	4580	Business	9900.00
0005432383103	4580	Business	9900.00
0005433194855	4580	Business	9900.00
0005433722210	4580	Business	9900.00
0005432383116	4580	Business	9900.00
0005432383119	4580	Business	9900.00
0005432383117	4580	Business	9900.00
0005432383098	4580	Business	9900.00
0005432727918	4580	Economy	3300.00
0005432727916	4580	Economy	3300.00
0005432383115	4580	Economy	3300.00
0005432383102	4580	Economy	3300.00
0005433722211	4580	Economy	3300.00
0005432383111	4580	Economy	3300.00
0005432727911	4580	Economy	3300.00
0005433454870	4580	Economy	3300.00
0005432383105	4580	Economy	3300.00
0005432383114	4580	Economy	3300.00
0005433194854	4580	Economy	3600.00
0005433453759	4580	Economy	3600.00
0005432383110	4580	Economy	3300.00
0005433722216	4580	Economy	3300.00
0005433722209	4580	Economy	3300.00
0005432383123	4580	Economy	3300.00
0005433454872	4580	Economy	3300.00
0005432383108	4580	Economy	3300.00
0005432383127	4580	Economy	3300.00
0005432383126	4580	Economy	3300.00
0005432383124	4580	Economy	3300.00
0005432383097	4580	Economy	3300.00
0005432727913	4580	Economy	3300.00
0005433194851	4580	Economy	3300.00
0005432727921	4580	Economy	3300.00
0005432383120	4580	Economy	3300.00
0005432727908	4580	Economy	3300.00
0005432727917	4580	Economy	3300.00
0005432383109	4580	Economy	3300.00
0005432727912	4580	Economy	3300.00
0005432383112	4580	Economy	3300.00
0005433453760	4580	Economy	3300.00
0005432727914	4580	Economy	3300.00
0005432383128	4580	Economy	3300.00
0005432383118	4580	Economy	3300.00
0005432383095	4580	Economy	3300.00
0005433722212	4580	Economy	3300.00
0005432383096	4580	Economy	3300.00
0005432383121	4580	Economy	3300.00
0005433194852	4580	Economy	3300.00
0005433722215	4580	Economy	3300.00
0005433194853	4580	Economy	3300.00
0005433454871	4580	Economy	3300.00
0005432727910	4580	Economy	3300.00
0005432383107	4580	Economy	3300.00
0005432383106	4580	Economy	3300.00
0005432383122	4580	Economy	3300.00
0005432383101	4580	Economy	3300.00
0005432727920	4580	Economy	3300.00
0005433722213	4580	Economy	3300.00
0005433722214	4580	Economy	3300.00
0005432383125	4580	Economy	3300.00
0005432383099	4580	Economy	3300.00
0005432383104	4580	Economy	3300.00
0005432383113	4580	Economy	3300.00
0005432727915	4580	Economy	3300.00
0005432382663	30212	Business	9900.00
0005432727763	30212	Business	9900.00
0005432382642	30212	Business	9900.00
0005432382638	30212	Business	9900.00
0005432382732	30212	Business	9900.00
0005432382578	30212	Business	9900.00
0005433722129	30212	Business	9900.00
0005432727785	30212	Economy	3300.00
0005433722104	30212	Economy	3300.00
0005432382715	30212	Economy	3300.00
0005433722126	30212	Economy	3300.00
0005433722145	30212	Economy	3300.00
0005433722140	30212	Economy	3300.00
0005433722142	30212	Economy	3600.00
0005432382700	30212	Economy	3600.00
0005433722118	30212	Economy	3600.00
0005432382801	30212	Economy	3600.00
0005432382797	30212	Economy	3300.00
0005433194826	30212	Economy	3300.00
0005432727779	30212	Economy	3300.00
0005432382698	30212	Economy	3300.00
0005433722141	30212	Economy	3300.00
0005433451587	30212	Economy	3300.00
0005433722127	30212	Economy	3300.00
0005433722163	30212	Economy	3300.00
0005432727737	30212	Economy	3300.00
0005432382566	30212	Economy	3300.00
0005432727787	30212	Economy	3300.00
0005433722125	30212	Economy	3300.00
0005432382639	30212	Economy	3300.00
0005432727786	30212	Economy	3300.00
0005432382664	30212	Economy	3300.00
0005432382714	30212	Economy	3300.00
0005432382726	30212	Economy	3300.00
0005433451600	30212	Economy	3300.00
0005432382720	30212	Economy	3300.00
0005433194835	30212	Economy	3300.00
0005432382690	30212	Economy	3300.00
0005432382752	30212	Economy	3300.00
0005432382653	30212	Economy	3300.00
0005432382753	30212	Economy	3300.00
0005432382626	30212	Economy	3300.00
0005432382746	30212	Economy	3300.00
0005432382565	30212	Economy	3300.00
0005432727792	30212	Economy	3300.00
0005433722146	30212	Economy	3300.00
0005432382760	30212	Economy	3300.00
0005433722144	30212	Economy	3300.00
0005432382641	30212	Economy	3300.00
0005432382691	30212	Economy	3300.00
0005432727842	30212	Economy	3300.00
0005432382640	30212	Economy	3300.00
0005433722119	30212	Economy	3300.00
0005433722143	30212	Economy	3300.00
0005432382800	30212	Economy	3300.00
0005432727835	30212	Economy	3300.00
0005432382670	30212	Economy	3300.00
0005435540966	1749	Business	57200.00
0005433516872	1749	Business	57200.00
0005435540962	1749	Business	57200.00
0005435529213	1749	Business	57200.00
0005433516871	1749	Business	57200.00
0005435529220	1749	Business	57200.00
0005432925005	1749	Business	57200.00
0005435540970	1749	Business	57200.00
0005433516866	1749	Economy	19100.00
0005432924998	1749	Economy	19100.00
0005435529217	1749	Economy	19100.00
0005435540958	1749	Economy	19100.00
0005435540963	1749	Economy	19100.00
0005435529221	1749	Economy	19100.00
0005435529214	1749	Economy	19100.00
0005435540960	1749	Economy	19100.00
0005435540969	1749	Economy	21000.00
0005435540965	1749	Economy	21000.00
0005435540976	1749	Economy	21000.00
0005435529233	1749	Economy	21000.00
0005435540973	1749	Economy	19100.00
0005435529223	1749	Economy	19100.00
0005432924992	1749	Economy	19100.00
0005433516865	1749	Economy	19100.00
0005432924986	1749	Economy	19100.00
0005433516870	1749	Economy	19100.00
0005432294482	1749	Economy	19100.00
0005435540972	1749	Economy	19100.00
0005435529227	1749	Economy	19100.00
0005435540961	1749	Economy	19100.00
0005433516864	1749	Economy	19100.00
0005435529231	1749	Economy	19100.00
0005435529215	1749	Economy	19100.00
0005435529212	1749	Economy	19100.00
0005435529216	1749	Economy	19100.00
0005435540975	1749	Economy	19100.00
0005435540964	1749	Economy	19100.00
0005433516874	1749	Economy	19100.00
0005432924995	1749	Economy	19100.00
0005433516868	1749	Economy	19100.00
0005432924997	1749	Economy	19100.00
0005435540977	1749	Economy	19100.00
0005435529232	1749	Economy	19100.00
0005435540971	1749	Economy	19100.00
0005433516873	1749	Economy	19100.00
0005435529224	1749	Economy	19100.00
0005435540974	1749	Economy	19100.00
0005432924974	1749	Economy	19100.00
0005432924991	1749	Economy	19100.00
0005435529225	1749	Economy	19100.00
0005435529230	1749	Economy	19100.00
0005435540968	1749	Economy	19100.00
0005433516867	1749	Economy	19100.00
0005435529226	1749	Economy	19100.00
0005432294483	1749	Economy	19100.00
0005435540957	1749	Economy	19100.00
0005435529229	1749	Economy	19100.00
0005435540967	1749	Economy	19100.00
0005435540956	1749	Economy	19100.00
0005432924970	1749	Economy	19100.00
0005435529211	1749	Economy	19100.00
0005432924985	1749	Economy	19100.00
0005435529218	1749	Economy	19100.00
0005432924996	1749	Economy	19100.00
0005435529228	1749	Economy	19100.00
0005435540955	1749	Economy	19100.00
0005435540959	1749	Economy	19100.00
0005435529219	1749	Economy	19100.00
0005433516869	1749	Economy	19100.00
0005435529222	1749	Economy	19100.00
0005432924987	1749	Economy	19100.00
0005435540746	22003	Business	57200.00
0005435540743	22003	Business	57200.00
0005433516807	22003	Business	57200.00
0005432925029	22003	Business	57200.00
0005435540716	22003	Business	57200.00
0005433516813	22003	Business	57200.00
0005432925025	22003	Business	57200.00
0005435540778	22003	Economy	19100.00
0005435517733	22003	Economy	19100.00
0005435517704	22003	Economy	19100.00
0005435517800	22003	Economy	19100.00
0005435540708	22003	Economy	19100.00
0005435540761	22003	Economy	19100.00
0005433516803	22003	Economy	19100.00
0005435540797	22003	Economy	21000.00
0005435540724	22003	Economy	21000.00
0005435540827	22003	Economy	21000.00
0005432925027	22003	Economy	19100.00
0005435517646	22003	Economy	19100.00
0005433516808	22003	Economy	19100.00
0005435517647	22003	Economy	19100.00
0005435540834	22003	Economy	19100.00
0005435540775	22003	Economy	19100.00
0005435540670	22003	Economy	19100.00
0005435517739	22003	Economy	19100.00
0005433516789	22003	Economy	19100.00
0005435540725	22003	Economy	19100.00
0005433516810	22003	Economy	19100.00
0005435540766	22003	Economy	19100.00
0005435517705	22003	Economy	19100.00
0005435540717	22003	Economy	19100.00
0005433516809	22003	Economy	19100.00
0005435540709	22003	Economy	19100.00
0005433516750	22003	Economy	19100.00
0005433516761	22003	Economy	19100.00
0005433516744	22003	Economy	19100.00
0005435517706	22003	Economy	19100.00
0005433516814	22003	Economy	19100.00
0005435540776	22003	Economy	19100.00
0005433516760	22003	Economy	19100.00
0005433516768	22003	Economy	19100.00
0005435540755	22003	Economy	19100.00
0005435540777	22003	Economy	19100.00
0005432925028	22003	Economy	19100.00
0005435540762	22003	Economy	19100.00
0005435540754	22003	Economy	19100.00
0005435517678	22003	Economy	19100.00
0005435517747	22003	Economy	19100.00
0005435540707	22003	Economy	19100.00
0005435517784	22003	Economy	19100.00
0005435517632	22003	Economy	19100.00
0005433516746	22003	Economy	19100.00
0005432925026	22003	Economy	19100.00
0005435517754	22003	Economy	19100.00
0005435517729	22003	Economy	19100.00
0005435540706	22003	Economy	19100.00
0005433516788	22003	Economy	19100.00
0005435517785	22003	Economy	19100.00
0005435252587	7401	Business	18500.00
0005434458762	7401	Business	18500.00
0005434458758	7401	Business	18500.00
0005432838975	7401	Business	18500.00
0005435252505	7401	Business	18500.00
0005432838988	7401	Business	18500.00
0005435252504	7401	Business	18500.00
0005432073386	7401	Business	18500.00
0005432838961	7401	Business	18500.00
0005432838970	7401	Business	18500.00
0005434458754	7401	Economy	6200.00
0005435252456	7401	Economy	6200.00
0005434458764	7401	Economy	6200.00
0005434458769	7401	Economy	6200.00
0005432838965	7401	Economy	6200.00
0005432838982	7401	Economy	6200.00
0005434458768	7401	Economy	6200.00
0005432838962	7401	Economy	6800.00
0005435252470	7401	Economy	6800.00
0005432838985	7401	Economy	6800.00
0005434458766	7401	Economy	6800.00
0005432838986	7401	Economy	6200.00
0005432838981	7401	Economy	6200.00
0005432838977	7401	Economy	6200.00
0005432073385	7401	Economy	6200.00
0005432838980	7401	Economy	6200.00
0005432073384	7401	Economy	6200.00
0005435252455	7401	Economy	6200.00
0005432838964	7401	Economy	6200.00
0005432841007	7401	Economy	6200.00
0005432838976	7401	Economy	6200.00
0005432838987	7401	Economy	6200.00
0005434458767	7401	Economy	6200.00
0005435252522	7401	Economy	6200.00
0005435252506	7401	Economy	6200.00
0005435252478	7401	Economy	6200.00
0005434664932	7401	Economy	6200.00
0005432838972	7401	Economy	6200.00
0005432838969	7401	Economy	6200.00
0005435252513	7401	Economy	6200.00
0005432838984	7401	Economy	6200.00
0005434458755	7401	Economy	6200.00
0005432838971	7401	Economy	6200.00
0005434458770	7401	Economy	6200.00
0005432841008	7401	Economy	6200.00
0005434458759	7401	Economy	6200.00
0005432838978	7401	Economy	6200.00
0005435252521	7401	Economy	6200.00
0005434458765	7401	Economy	6200.00
0005434458761	7401	Economy	6200.00
0005432838968	7401	Economy	6200.00
0005432838967	7401	Economy	6200.00
0005432838974	7401	Economy	6200.00
0005434664922	7401	Economy	6200.00
0005432838983	7401	Economy	6200.00
0005432838966	7401	Economy	6200.00
0005434458756	7401	Economy	6200.00
0005432838960	7401	Economy	6200.00
0005432838989	7401	Economy	6200.00
0005434458757	7401	Economy	6200.00
0005434458771	7401	Economy	6200.00
0005432838979	7401	Economy	6200.00
0005432073383	7401	Economy	6200.00
0005435252435	7401	Economy	6200.00
0005434458773	7401	Economy	6200.00
0005434664935	7401	Economy	6200.00
0005435252436	7401	Economy	6200.00
0005432838973	7401	Economy	6200.00
0005432838959	7401	Economy	6200.00
0005434458772	7401	Economy	6200.00
0005434458753	7401	Economy	6200.00
0005432841006	7401	Economy	6200.00
0005435491419	7401	Economy	6200.00
0005434458763	7401	Economy	6200.00
0005434458760	7401	Economy	6200.00
0005432073382	7401	Economy	6200.00
0005435491415	7401	Economy	6200.00
0005432838963	7401	Economy	6200.00
0005435252491	7401	Economy	6200.00
0005432838567	28940	Business	18500.00
0005434458610	28940	Business	18500.00
0005432838641	28940	Business	18500.00
0005434664954	28940	Business	18500.00
0005434458603	28940	Business	18500.00
0005432838716	28940	Business	18500.00
0005432838684	28940	Business	18500.00
0005434458567	28940	Business	18500.00
0005432838833	28940	Business	18500.00
0005432001019	28940	Business	18500.00
0005432838731	28940	Economy	6200.00
0005432838837	28940	Economy	6200.00
0005434458614	28940	Economy	6200.00
0005432840997	28940	Economy	6200.00
0005434458576	28940	Economy	6200.00
0005432838566	28940	Economy	6200.00
0005432838661	28940	Economy	6200.00
0005434458621	28940	Economy	6200.00
0005434664955	28940	Economy	6200.00
0005435252662	28940	Economy	6200.00
0005435252673	28940	Economy	6800.00
0005432838829	28940	Economy	6800.00
0005435252670	28940	Economy	6800.00
0005435252676	28940	Economy	6800.00
0005434458639	28940	Economy	6800.00
0005432001018	28940	Economy	6200.00
0005434458493	28940	Economy	6200.00
0005435252663	28940	Economy	6200.00
0005432838783	28940	Economy	6200.00
0005435252667	28940	Economy	6200.00
0005432838841	28940	Economy	6200.00
0005432838778	28940	Economy	6200.00
0005434458622	28940	Economy	6200.00
0005434664956	28940	Economy	6200.00
0005432838852	28940	Economy	6200.00
0005434458544	28940	Economy	6200.00
0005434458648	28940	Economy	6200.00
0005434458577	28940	Economy	6200.00
0005435252666	28940	Economy	6200.00
0005434458554	28940	Economy	6200.00
0005434458625	28940	Economy	6200.00
0005434458559	28940	Economy	6200.00
0005435252660	28940	Economy	6200.00
0005432838814	28940	Economy	6200.00
0005432838771	28940	Economy	6200.00
0005435252675	28940	Economy	6200.00
0005435252661	28940	Economy	6200.00
0005434458524	28940	Economy	6200.00
0005432840998	28940	Economy	6200.00
0005432838732	28940	Economy	6200.00
0005435252672	28940	Economy	6200.00
0005435252664	28940	Economy	6200.00
0005434458492	28940	Economy	6200.00
0005434458562	28940	Economy	6200.00
0005435252671	28940	Economy	6200.00
0005432838707	28940	Economy	6200.00
0005432838830	28940	Economy	6200.00
0005434458514	28940	Economy	6200.00
0005434458602	28940	Economy	6200.00
0005434458545	28940	Economy	6200.00
0005435252669	28940	Economy	6200.00
0005435252659	28940	Economy	6200.00
0005432838782	28940	Economy	6200.00
0005432838607	28940	Economy	6200.00
0005432838765	28940	Economy	6200.00
0005432838506	28940	Economy	6200.00
0005432838792	28940	Economy	6200.00
0005435252668	28940	Economy	6200.00
0005434458612	28940	Economy	6200.00
0005435252674	28940	Economy	6200.00
0005434458552	28940	Economy	6200.00
0005432838784	28940	Economy	6200.00
0005432838664	28940	Economy	6200.00
0005434458558	28940	Economy	6200.00
0005434458601	28940	Economy	6200.00
0005434458613	28940	Economy	6200.00
0005434458543	28940	Economy	6200.00
0005435491439	28940	Economy	6200.00
0005435252665	28940	Economy	6200.00
0005432838851	28940	Economy	6200.00
0005434458607	28940	Economy	6200.00
0005434275976	8794	Business	145300.00
0005434275975	8794	Business	145300.00
0005434275981	8794	Economy	48400.00
0005434275973	8794	Economy	48400.00
0005435990612	8794	Economy	53300.00
0005434275970	8794	Economy	48400.00
0005435990609	8794	Economy	48400.00
0005434275963	8794	Economy	48400.00
0005434275982	8794	Economy	48400.00
0005435990611	8794	Economy	48400.00
0005435990607	8794	Economy	48400.00
0005435990608	8794	Economy	48400.00
0005435990606	8794	Economy	48400.00
0005434275974	8794	Economy	48400.00
0005435990610	8794	Economy	48400.00
0005434275994	8794	Economy	48400.00
0005435990590	15724	Business	145300.00
0005435990497	15724	Economy	48400.00
0005435990584	15724	Economy	48400.00
0005434276017	15724	Economy	48400.00
0005434276014	15724	Economy	48400.00
0005435990522	15724	Economy	48400.00
0005435990546	15724	Economy	48400.00
0005435990589	15724	Economy	48400.00
0005435990547	15724	Economy	48400.00
0005435990583	15724	Economy	48400.00
0005435990548	15724	Economy	48400.00
0005434276015	15724	Economy	48400.00
0005435990585	15724	Economy	48400.00
0005434276016	15724	Economy	48400.00
0005432427138	20625	Economy	14500.00
0005432427139	20625	Economy	14500.00
0005432427136	20625	Economy	14500.00
0005433476872	20625	Economy	14500.00
0005432427137	20625	Economy	14500.00
0005433476873	20625	Economy	14500.00
0005433476888	30861	Economy	14500.00
0005433476887	30861	Economy	14500.00
0005433476890	30861	Economy	14500.00
0005433476889	30861	Economy	14500.00
0005433476886	30861	Economy	14500.00
0005432427120	30861	Economy	14500.00
0005432360285	6399	Business	36600.00
0005432360290	6399	Business	36600.00
0005432360287	6399	Business	36600.00
0005435176791	6399	Business	36600.00
0005435176740	6399	Business	36600.00
0005432360247	6399	Business	36600.00
0005434149609	6399	Business	36600.00
0005432360272	6399	Business	36600.00
0005432360261	6399	Business	36600.00
0005432336007	6399	Business	36600.00
0005432363411	6399	Economy	12200.00
0005435176744	6399	Economy	12200.00
0005432062215	6399	Economy	12200.00
0005435176835	6399	Economy	12200.00
0005432062220	6399	Economy	12200.00
0005432336012	6399	Economy	12200.00
0005435176818	6399	Economy	12200.00
0005435176852	6399	Economy	12200.00
0005435176976	6399	Economy	12200.00
0005432360267	6399	Economy	12200.00
0005432363410	6399	Economy	12200.00
0005434149625	6399	Economy	12200.00
0005435176813	6399	Economy	12200.00
0005435176975	6399	Economy	12200.00
0005432062219	6399	Economy	12200.00
0005432336009	6399	Economy	12200.00
0005432360273	6399	Economy	12200.00
0005432360268	6399	Economy	12200.00
0005432360284	6399	Economy	12200.00
0005435490192	6399	Economy	12200.00
0005432336006	6399	Economy	12200.00
0005432360259	6399	Economy	12200.00
0005434149610	6399	Economy	12200.00
0005435176793	6399	Economy	12200.00
0005432360289	6399	Economy	12200.00
0005432360246	6399	Economy	12200.00
0005435176816	6399	Economy	12200.00
0005432062217	6399	Economy	12200.00
0005432360262	6399	Economy	12200.00
0005432360249	6399	Economy	12200.00
0005432360257	6399	Economy	12200.00
0005432336013	6399	Economy	12200.00
0005435176838	6399	Economy	12200.00
0005435176826	6399	Economy	12200.00
0005432360251	6399	Economy	12200.00
0005435176885	6399	Economy	13400.00
0005432360263	6399	Economy	13400.00
0005435176819	6399	Economy	13400.00
0005435176840	6399	Economy	13400.00
0005432360280	6399	Economy	13400.00
0005432336010	6399	Economy	12200.00
0005432360269	6399	Economy	12200.00
0005435176839	6399	Economy	12200.00
0005435176792	6399	Economy	12200.00
0005432360283	6399	Economy	12200.00
0005432360265	6399	Economy	12200.00
0005432360291	6399	Economy	12200.00
0005435176775	6399	Economy	12200.00
0005434149578	6399	Economy	12200.00
0005435176850	6399	Economy	12200.00
0005432062216	6399	Economy	12200.00
0005434149579	6399	Economy	12200.00
0005432360288	6399	Economy	12200.00
0005432360270	6399	Economy	12200.00
0005432360277	6399	Economy	12200.00
0005435176824	6399	Economy	12200.00
0005432360254	6399	Economy	12200.00
0005435176675	6399	Economy	12200.00
0005432360275	6399	Economy	12200.00
0005432360276	6399	Economy	12200.00
0005432360260	6399	Economy	12200.00
0005434149645	6399	Economy	12200.00
0005432360264	6399	Economy	12200.00
0005432360253	6399	Economy	12200.00
0005432360281	6399	Economy	12200.00
0005432360256	6399	Economy	12200.00
0005432360255	6399	Economy	12200.00
0005435176834	6399	Economy	12200.00
0005435176888	6399	Economy	12200.00
0005435176960	6399	Economy	12200.00
0005432360278	6399	Economy	12200.00
0005435176810	6399	Economy	12200.00
0005432336015	6399	Economy	12200.00
0005432360266	6399	Economy	12200.00
0005435176911	6399	Economy	12200.00
0005432062218	6399	Economy	12200.00
0005432360282	6399	Economy	12200.00
0005434149646	6399	Economy	12200.00
0005432363409	6399	Economy	12200.00
0005435176809	6399	Economy	12200.00
0005432336014	6399	Economy	12200.00
0005435176794	6399	Economy	12200.00
0005435490181	6399	Economy	12200.00
0005435176749	6399	Economy	12200.00
0005432336011	6399	Economy	12200.00
0005432336008	6399	Economy	12200.00
0005432360286	6399	Economy	12200.00
0005435176692	6399	Economy	12200.00
0005432336005	6399	Economy	12200.00
0005435176769	6399	Economy	12200.00
0005435176750	6399	Economy	12200.00
0005435176807	6399	Economy	12200.00
0005432360250	6399	Economy	12200.00
0005432360252	6399	Economy	12200.00
0005432360279	6399	Economy	12200.00
0005435176739	6399	Economy	12200.00
0005432360258	6399	Economy	12200.00
0005435176961	6399	Economy	12200.00
0005435176770	6399	Economy	12200.00
0005432360248	6399	Economy	12200.00
0005432360271	6399	Economy	12200.00
0005432360292	6399	Economy	12200.00
0005435176674	6399	Economy	12200.00
0005432360274	6399	Economy	12200.00
0005432359729	21000	Business	36600.00
0005435177009	21000	Business	36600.00
0005435177019	21000	Business	36600.00
0005435177033	21000	Business	36600.00
0005432335940	21000	Business	36600.00
0005432359826	21000	Business	36600.00
0005432359801	21000	Business	36600.00
0005432052740	21000	Business	36600.00
0005432359827	21000	Business	36600.00
0005432363383	21000	Business	36600.00
0005432335941	21000	Business	36600.00
0005435177021	21000	Business	36600.00
0005432359784	21000	Economy	12200.00
0005435177028	21000	Economy	12200.00
0005432359917	21000	Economy	12200.00
0005432359802	21000	Economy	12200.00
0005432359709	21000	Economy	12200.00
0005432335945	21000	Economy	12200.00
0005435490224	21000	Economy	12200.00
0005435177022	21000	Economy	12200.00
0005432359663	21000	Economy	12200.00
0005432335916	21000	Economy	12200.00
0005432359987	21000	Economy	12200.00
0005435723041	21000	Economy	12200.00
0005434149704	21000	Economy	12200.00
0005435177034	21000	Economy	12200.00
0005434149707	21000	Economy	12200.00
0005434149701	21000	Economy	12200.00
0005435177024	21000	Economy	12200.00
0005432359690	21000	Economy	12200.00
0005432363374	21000	Economy	12200.00
0005432360025	21000	Economy	12200.00
0005434149708	21000	Economy	12200.00
0005432359886	21000	Economy	12200.00
0005435177036	21000	Economy	12200.00
0005432335873	21000	Economy	12200.00
0005434149705	21000	Economy	12200.00
0005435177027	21000	Economy	12200.00
0005432359878	21000	Economy	12200.00
0005435177010	21000	Economy	12200.00
0005432359730	21000	Economy	12200.00
0005432359895	21000	Economy	12200.00
0005435177030	21000	Economy	12200.00
0005432359785	21000	Economy	12200.00
0005432359771	21000	Economy	12200.00
0005434149711	21000	Economy	13400.00
0005432359853	21000	Economy	13400.00
0005432335960	21000	Economy	13400.00
0005435177012	21000	Economy	13400.00
0005432359769	21000	Economy	13400.00
0005432360026	21000	Economy	13400.00
0005432363375	21000	Economy	12200.00
0005435177016	21000	Economy	12200.00
0005435490223	21000	Economy	12200.00
0005435177035	21000	Economy	12200.00
0005434149710	21000	Economy	12200.00
0005432359710	21000	Economy	12200.00
0005435490222	21000	Economy	12200.00
0005432335946	21000	Economy	12200.00
0005435177008	21000	Economy	12200.00
0005435177017	21000	Economy	12200.00
0005435177031	21000	Economy	12200.00
0005432335930	21000	Economy	12200.00
0005432360028	21000	Economy	12200.00
0005435177011	21000	Economy	12200.00
0005432359650	21000	Economy	12200.00
0005434149702	21000	Economy	12200.00
0005435177020	21000	Economy	12200.00
0005432359899	21000	Economy	12200.00
0005435177023	21000	Economy	12200.00
0005435177026	21000	Economy	12200.00
0005435490226	21000	Economy	12200.00
0005432359851	21000	Economy	12200.00
0005432335912	21000	Economy	12200.00
0005432359880	21000	Economy	12200.00
0005432359973	21000	Economy	12200.00
0005435723042	21000	Economy	12200.00
0005432359833	21000	Economy	12200.00
0005435177025	21000	Economy	12200.00
0005435177029	21000	Economy	12200.00
0005435177014	21000	Economy	12200.00
0005432359817	21000	Economy	12200.00
0005432359676	21000	Economy	12200.00
0005435490225	21000	Economy	12200.00
0005435177013	21000	Economy	12200.00
0005432359803	21000	Economy	12200.00
0005432335915	21000	Economy	12200.00
0005434149709	21000	Economy	12200.00
0005432335947	21000	Economy	12200.00
0005432359972	21000	Economy	12200.00
0005432359804	21000	Economy	12200.00
0005432359896	21000	Economy	12200.00
0005432359871	21000	Economy	12200.00
0005435177018	21000	Economy	12200.00
0005434149712	21000	Economy	12200.00
0005432359879	21000	Economy	12200.00
0005432359929	21000	Economy	12200.00
0005432359809	21000	Economy	12200.00
0005432359887	21000	Economy	12200.00
0005432359986	21000	Economy	12200.00
0005432359753	21000	Economy	12200.00
0005435177015	21000	Economy	12200.00
0005434149706	21000	Economy	12200.00
0005432359852	21000	Economy	12200.00
0005435177032	21000	Economy	12200.00
0005432052741	21000	Economy	12200.00
0005434149703	21000	Economy	12200.00
0005434458643	17684	Economy	3400.00
0005434458581	17684	Economy	3400.00
0005434458653	17684	Economy	3400.00
0005434458561	17684	Economy	3400.00
0005434186193	17684	Economy	3100.00
0005434186194	17684	Economy	3100.00
0005434448301	17684	Economy	3100.00
0005434458685	17684	Economy	3100.00
0005434458585	17684	Economy	3100.00
0005434458684	17684	Economy	3100.00
0005434458635	17684	Economy	3100.00
0005434458644	17684	Economy	3100.00
0005434458582	17684	Economy	3100.00
0005434458651	17684	Economy	3100.00
0005434458560	17684	Economy	3100.00
0005434458580	17684	Economy	3100.00
0005434463909	17684	Economy	3100.00
0005434461622	17684	Economy	3100.00
0005434458596	17684	Economy	3100.00
0005434458593	17684	Economy	3100.00
0005434461623	17684	Economy	3100.00
0005434458660	17684	Economy	3100.00
0005434458652	17684	Economy	3100.00
0005434448303	17684	Economy	3100.00
0005434458683	17684	Economy	3100.00
0005434186192	17684	Economy	3100.00
0005434458659	17684	Economy	3100.00
0005434458637	17684	Economy	3100.00
0005434186195	17684	Economy	3100.00
0005434448302	17684	Economy	3100.00
0005434458649	17684	Economy	3100.00
0005434458584	17684	Economy	3100.00
0005434458594	17684	Economy	3100.00
0005434463899	17684	Economy	3100.00
0005434463910	17684	Economy	3100.00
0005434458650	17684	Economy	3100.00
0005434458595	17684	Economy	3100.00
0005434458574	17684	Economy	3100.00
0005434458642	17684	Economy	3100.00
0005434458756	29126	Economy	3400.00
0005434458766	29126	Economy	3400.00
0005434448305	29126	Economy	3400.00
0005434463922	29126	Economy	3100.00
0005434458763	29126	Economy	3100.00
0005434458757	29126	Economy	3100.00
0005434458773	29126	Economy	3100.00
0005434462784	29126	Economy	3100.00
0005434186168	29126	Economy	3100.00
0005434458764	29126	Economy	3100.00
0005434458772	29126	Economy	3100.00
0005434458768	29126	Economy	3100.00
0005434463923	29126	Economy	3100.00
0005434458761	29126	Economy	3100.00
0005434458754	29126	Economy	3100.00
0005434458767	29126	Economy	3100.00
0005434458765	29126	Economy	3100.00
0005434458758	29126	Economy	3100.00
0005434458771	29126	Economy	3100.00
0005434462783	29126	Economy	3100.00
0005434458770	29126	Economy	3100.00
0005434458759	29126	Economy	3100.00
0005434448306	29126	Economy	3100.00
0005434458753	29126	Economy	3100.00
0005434458760	29126	Economy	3100.00
0005434458755	29126	Economy	3100.00
0005434458762	29126	Economy	3100.00
0005434448304	29126	Economy	3100.00
0005434458769	29126	Economy	3100.00
0005432604232	21451	Economy	7300.00
0005432604233	21451	Economy	7300.00
0005432604246	21451	Economy	7300.00
0005432604214	21451	Economy	7300.00
0005435220488	21451	Economy	6600.00
0005432604247	21451	Economy	6600.00
0005432604244	21451	Economy	6600.00
0005432604236	21451	Economy	6600.00
0005432604243	21451	Economy	6600.00
0005432604223	21451	Economy	6600.00
0005432604216	21451	Economy	6600.00
0005435218103	21451	Economy	6600.00
0005432604228	21451	Economy	6600.00
0005432604222	21451	Economy	6600.00
0005432604239	21451	Economy	6600.00
0005432604245	21451	Economy	6600.00
0005432604229	21451	Economy	6600.00
0005435218107	21451	Economy	6600.00
0005432604234	21451	Economy	6600.00
0005432604226	21451	Economy	6600.00
0005432604224	21451	Economy	6600.00
0005432604210	21451	Economy	6600.00
0005432604249	21451	Economy	6600.00
0005432604221	21451	Economy	6600.00
0005432604241	21451	Economy	6600.00
0005432604230	21451	Economy	6600.00
0005432604235	21451	Economy	6600.00
0005432604213	21451	Economy	6600.00
0005432604218	21451	Economy	6600.00
0005432604227	21451	Economy	6600.00
0005432604238	21451	Economy	6600.00
0005432604231	21451	Economy	6600.00
0005432604217	21451	Economy	6600.00
0005432604248	21451	Economy	6600.00
0005432604242	21451	Economy	6600.00
0005432604237	21451	Economy	6600.00
0005432604220	21451	Economy	6600.00
0005432604240	21451	Economy	6600.00
0005432604219	21451	Economy	6600.00
0005432604215	21451	Economy	6600.00
0005432604212	21451	Economy	6600.00
0005432604225	21451	Economy	6600.00
0005432604211	21451	Economy	6600.00
0005432603785	31711	Economy	7300.00
0005432603846	31711	Economy	7300.00
0005432603877	31711	Economy	7300.00
0005432604062	31711	Economy	6600.00
0005432603888	31711	Economy	6600.00
0005432603906	31711	Economy	6600.00
0005432604033	31711	Economy	6600.00
0005432603845	31711	Economy	6600.00
0005432603924	31711	Economy	6600.00
0005432603837	31711	Economy	6600.00
0005432603897	31711	Economy	6600.00
0005432604021	31711	Economy	6600.00
0005432603950	31711	Economy	6600.00
0005432603935	31711	Economy	6600.00
0005432603945	31711	Economy	6600.00
0005432603867	31711	Economy	6600.00
0005432603925	31711	Economy	6600.00
0005432603830	31711	Economy	6600.00
0005432604026	31711	Economy	6600.00
0005432604023	31711	Economy	6600.00
0005432604027	31711	Economy	6600.00
0005432604064	31711	Economy	6600.00
0005432603768	31711	Economy	6600.00
0005432603876	31711	Economy	6600.00
0005432603784	31711	Economy	6600.00
0005432603812	31711	Economy	6600.00
0005432604063	31711	Economy	6600.00
0005432604019	31711	Economy	6600.00
0005432603886	31711	Economy	6600.00
0005432603831	31711	Economy	6600.00
0005432603949	31711	Economy	6600.00
0005432604013	31711	Economy	6600.00
0005432603907	31711	Economy	6600.00
0005432603878	31711	Economy	6600.00
0005432603761	31711	Economy	6600.00
0005432604020	31711	Economy	6600.00
0005432604022	31711	Economy	6600.00
0005432604094	31711	Economy	6600.00
0005432603887	31711	Economy	6600.00
0005432603904	31711	Economy	6600.00
0005432603895	31711	Economy	6600.00
0005432603866	31711	Economy	6600.00
0005432603936	31711	Economy	6600.00
0005432603832	31711	Economy	6600.00
0005433293209	12299	Economy	19500.00
0005433293150	12299	Economy	19500.00
0005435154595	12299	Economy	17800.00
0005435154594	12299	Economy	17800.00
0005433293176	12299	Economy	17800.00
0005433293193	12299	Economy	17800.00
0005433293177	12299	Economy	17800.00
0005433293160	12299	Economy	17800.00
0005433293154	12299	Economy	17800.00
0005433293175	12299	Economy	17800.00
0005433293151	12299	Economy	17800.00
0005434606776	18845	Economy	6600.00
0005434606774	18845	Economy	6600.00
0005434606786	18845	Economy	6600.00
0005434606769	18845	Economy	6600.00
0005434606787	18845	Economy	6600.00
0005434606768	18845	Economy	6600.00
0005434606819	22288	Economy	6600.00
0005434604887	22288	Economy	6600.00
0005434604886	22288	Economy	6600.00
0005434606820	22288	Economy	6600.00
0005433293191	412	Business	44500.00
0005432747487	412	Business	44500.00
0005432890817	412	Business	44500.00
0005432890781	412	Business	44500.00
0005432747470	412	Business	44500.00
0005432890804	412	Business	44500.00
0005432890825	412	Business	44500.00
0005432890740	412	Business	44500.00
0005432747476	412	Business	44500.00
0005433293190	412	Business	44500.00
0005432747459	412	Business	44500.00
0005432890806	412	Business	44500.00
0005432747469	412	Economy	14800.00
0005432890803	412	Economy	14800.00
0005432890854	412	Economy	14800.00
0005432890783	412	Economy	14800.00
0005432747471	412	Economy	14800.00
0005432890844	412	Economy	14800.00
0005432747473	412	Economy	14800.00
0005432890821	412	Economy	14800.00
0005432747493	412	Economy	14800.00
0005433875358	412	Economy	16300.00
0005432890835	412	Economy	16300.00
0005432747489	412	Economy	16300.00
0005432749779	412	Economy	16300.00
0005432749778	412	Economy	16300.00
0005432747465	412	Economy	14800.00
0005432747477	412	Economy	14800.00
0005432747479	412	Economy	14800.00
0005432753290	412	Economy	14800.00
0005432747478	412	Economy	14800.00
0005432219994	412	Economy	14800.00
0005432747486	412	Economy	14800.00
0005432890772	412	Economy	14800.00
0005432890735	412	Economy	14800.00
0005432890816	412	Economy	14800.00
0005432219991	412	Economy	14800.00
0005432890820	412	Economy	14800.00
0005432749780	412	Economy	14800.00
0005432747488	412	Economy	14800.00
0005432747460	412	Economy	14800.00
0005432753291	412	Economy	14800.00
0005432890782	412	Economy	14800.00
0005432890761	412	Economy	14800.00
0005432219995	412	Economy	14800.00
0005432747484	412	Economy	14800.00
0005432751515	412	Economy	14800.00
0005432747480	412	Economy	14800.00
0005432747483	412	Economy	14800.00
0005432747464	412	Economy	14800.00
0005432747496	412	Economy	14800.00
0005432753292	412	Economy	14800.00
0005432890807	412	Economy	14800.00
0005432747494	412	Economy	14800.00
0005432751516	412	Economy	14800.00
0005432747458	412	Economy	14800.00
0005432747468	412	Economy	14800.00
0005432747463	412	Economy	14800.00
0005433293180	412	Economy	14800.00
0005432747495	412	Economy	14800.00
0005432890861	412	Economy	14800.00
0005432890824	412	Economy	14800.00
0005432890843	412	Economy	14800.00
0005432747456	412	Economy	14800.00
0005432751517	412	Economy	14800.00
0005433293192	412	Economy	14800.00
0005432890828	412	Economy	14800.00
0005432747474	412	Economy	14800.00
0005432890775	412	Economy	14800.00
0005432890819	412	Economy	14800.00
0005432747457	412	Economy	14800.00
0005432219993	412	Economy	14800.00
0005432747475	412	Economy	14800.00
0005432747481	412	Economy	14800.00
0005432890748	412	Economy	14800.00
0005432890845	412	Economy	14800.00
0005432747490	412	Economy	14800.00
0005432747491	412	Economy	14800.00
0005432890787	412	Economy	14800.00
0005432747492	412	Economy	14800.00
0005432747466	412	Economy	14800.00
0005432747467	412	Economy	14800.00
0005432890904	412	Economy	14800.00
0005432747462	412	Economy	14800.00
0005432747485	412	Economy	14800.00
0005432747461	412	Economy	14800.00
0005432219992	412	Economy	14800.00
0005432747482	412	Economy	14800.00
0005433875360	412	Economy	14800.00
0005432747472	412	Economy	14800.00
0005432890771	412	Economy	14800.00
0005432890736	412	Economy	14800.00
0005432890760	412	Economy	14800.00
0005433293225	12060	Business	44500.00
0005433293237	12060	Business	44500.00
0005432890972	12060	Business	44500.00
0005432890977	12060	Business	44500.00
0005432890986	12060	Business	44500.00
0005433293232	12060	Business	44500.00
0005433293224	12060	Business	44500.00
0005433293239	12060	Business	44500.00
0005432747136	12060	Business	44500.00
0005433293227	12060	Business	44500.00
0005432747163	12060	Business	44500.00
0005432890975	12060	Economy	14800.00
0005432753252	12060	Economy	14800.00
0005432747218	12060	Economy	14800.00
0005432890976	12060	Economy	14800.00
0005432747115	12060	Economy	14800.00
0005433293230	12060	Economy	14800.00
0005432749757	12060	Economy	14800.00
0005432747280	12060	Economy	14800.00
0005432747178	12060	Economy	14800.00
0005432753262	12060	Economy	14800.00
0005432747234	12060	Economy	16300.00
0005432747229	12060	Economy	16300.00
0005432747126	12060	Economy	16300.00
0005432747278	12060	Economy	16300.00
0005432747173	12060	Economy	14800.00
0005432890973	12060	Economy	14800.00
0005433875374	12060	Economy	14800.00
0005433293228	12060	Economy	14800.00
0005432747029	12060	Economy	14800.00
0005432890974	12060	Economy	14800.00
0005432749761	12060	Economy	14800.00
0005432747169	12060	Economy	14800.00
0005432747012	12060	Economy	14800.00
0005433875376	12060	Economy	14800.00
0005432747335	12060	Economy	14800.00
0005432890979	12060	Economy	14800.00
0005432747312	12060	Economy	14800.00
0005433293234	12060	Economy	14800.00
0005432747167	12060	Economy	14800.00
0005433293233	12060	Economy	14800.00
0005433293238	12060	Economy	14800.00
0005432890981	12060	Economy	14800.00
0005432747157	12060	Economy	14800.00
0005432747375	12060	Economy	14800.00
0005432747161	12060	Economy	14800.00
0005432747137	12060	Economy	14800.00
0005432747107	12060	Economy	14800.00
0005432747279	12060	Economy	14800.00
0005433293231	12060	Economy	14800.00
0005432890989	12060	Economy	14800.00
0005433293236	12060	Economy	14800.00
0005432890988	12060	Economy	14800.00
0005432747253	12060	Economy	14800.00
0005432749760	12060	Economy	14800.00
0005432756799	12060	Economy	14800.00
0005433293226	12060	Economy	14800.00
0005432890978	12060	Economy	14800.00
0005432747156	12060	Economy	14800.00
0005432214798	12060	Economy	14800.00
0005433293240	12060	Economy	14800.00
0005432747170	12060	Economy	14800.00
0005432890984	12060	Economy	14800.00
0005432890971	12060	Economy	14800.00
0005432214799	12060	Economy	14800.00
0005432747168	12060	Economy	14800.00
0005432756797	12060	Economy	14800.00
0005433875375	12060	Economy	14800.00
0005432890987	12060	Economy	14800.00
0005432747273	12060	Economy	14800.00
0005432747143	12060	Economy	14800.00
0005432890985	12060	Economy	14800.00
0005432890982	12060	Economy	14800.00
0005432756810	12060	Economy	14800.00
0005432747235	12060	Economy	14800.00
0005432747314	12060	Economy	14800.00
0005432890980	12060	Economy	14800.00
0005432747216	12060	Economy	14800.00
0005432747125	12060	Economy	14800.00
0005432747148	12060	Economy	14800.00
0005432747191	12060	Economy	14800.00
0005433293235	12060	Economy	14800.00
0005432747313	12060	Economy	14800.00
0005433293229	12060	Economy	14800.00
0005432747217	12060	Economy	14800.00
0005432747144	12060	Economy	14800.00
0005432747174	12060	Economy	14800.00
0005432756798	12060	Economy	14800.00
0005432890983	12060	Economy	14800.00
0005432927908	18954	Economy	28200.00
0005433525012	18954	Economy	25700.00
0005432927907	18954	Economy	25700.00
0005433531281	18954	Economy	25700.00
0005433525010	18954	Economy	25700.00
0005433525003	18954	Economy	25700.00
0005433525004	18954	Economy	25700.00
0005433531282	18954	Economy	25700.00
0005433525008	18954	Economy	25700.00
0005433525006	18954	Economy	25700.00
0005433533297	18954	Economy	25700.00
0005433531283	18954	Economy	25700.00
0005433525013	18954	Economy	25700.00
0005433525005	18954	Economy	25700.00
0005433533298	18954	Economy	25700.00
0005433531280	18954	Economy	25700.00
0005433525011	18954	Economy	25700.00
0005433533296	18954	Economy	25700.00
0005433525009	18954	Economy	25700.00
0005433525007	18954	Economy	25700.00
0005433533299	18954	Economy	25700.00
0005433524942	32510	Economy	28200.00
0005433524904	32510	Economy	25700.00
0005433524956	32510	Economy	25700.00
0005433531246	32510	Economy	25700.00
0005432927973	32510	Economy	25700.00
0005433524935	32510	Economy	25700.00
0005432927972	32510	Economy	25700.00
0005433527201	32510	Economy	25700.00
0005433524949	32510	Economy	25700.00
0005433531245	32510	Economy	25700.00
0005432927976	32510	Economy	25700.00
0005432927975	32510	Economy	25700.00
0005433524897	32510	Economy	25700.00
0005433524978	32510	Economy	25700.00
0005432927974	32510	Economy	25700.00
0005433524948	32510	Economy	25700.00
0005433524905	32510	Economy	25700.00
0005433531250	32510	Economy	25700.00
0005433524941	32510	Economy	25700.00
0005433524934	32510	Economy	25700.00
0005433524933	32510	Economy	25700.00
0005433531249	32510	Economy	25700.00
0005432121298	5283	Business	84000.00
0005434823379	5283	Business	84000.00
0005435372522	5283	Business	84000.00
0005434823351	5283	Business	84000.00
0005434823315	5283	Business	84000.00
0005434823377	5283	Business	84000.00
0005434831136	5283	Business	84000.00
0005434823334	5283	Business	84000.00
0005434823350	5283	Business	84000.00
0005432121302	5283	Business	84000.00
0005434823281	5283	Business	84000.00
0005434823358	5283	Business	84000.00
0005435304136	5283	Business	84000.00
0005435372712	5283	Business	84000.00
0005434823308	5283	Business	84000.00
0005435372634	5283	Business	84000.00
0005435372551	5283	Business	84000.00
0005435299750	5283	Business	84000.00
0005435661896	5283	Business	84000.00
0005435299743	5283	Business	84000.00
0005435372569	5283	Business	84000.00
0005435661882	5283	Business	84000.00
0005434823288	5283	Business	84000.00
0005434823383	5283	Comfort	47600.00
0005435299717	5283	Comfort	47600.00
0005434823376	5283	Comfort	47600.00
0005434823387	5283	Comfort	47600.00
0005435372492	5283	Comfort	47600.00
0005432121305	5283	Comfort	47600.00
0005434823290	5283	Comfort	47600.00
0005435150004	5283	Comfort	47600.00
0005434823352	5283	Comfort	47600.00
0005435299716	5283	Comfort	47600.00
0005434823276	5283	Comfort	47600.00
0005435149994	5283	Comfort	47600.00
0005432121311	5283	Comfort	47600.00
0005434823365	5283	Comfort	47600.00
0005434823291	5283	Comfort	47600.00
0005434823307	5283	Comfort	47600.00
0005435661883	5283	Comfort	47600.00
0005434823384	5283	Comfort	47600.00
0005435150001	5283	Comfort	47600.00
0005434823337	5283	Comfort	47600.00
0005434823341	5283	Comfort	47600.00
0005434828688	5283	Comfort	47600.00
0005435372546	5283	Comfort	47600.00
0005434823382	5283	Comfort	47600.00
0005434823374	5283	Comfort	47600.00
0005432394094	5283	Comfort	47600.00
0005435372535	5283	Comfort	47600.00
0005434823345	5283	Comfort	47600.00
0005434823385	5283	Comfort	47600.00
0005434831138	5283	Comfort	47600.00
0005434823305	5283	Comfort	47600.00
0005434823388	5283	Comfort	47600.00
0005434823302	5283	Comfort	47600.00
0005435372780	5283	Comfort	47600.00
0005434823267	5283	Comfort	47600.00
0005434823361	5283	Economy	28000.00
0005432394096	5283	Comfort	47600.00
0005435372455	5283	Economy	28000.00
0005432823433	5283	Economy	28000.00
0005434823344	5283	Economy	28000.00
0005434823363	5283	Economy	28000.00
0005434823293	5283	Economy	28000.00
0005434831137	5283	Economy	28000.00
0005434823321	5283	Economy	28000.00
0005434823311	5283	Economy	28000.00
0005435149997	5283	Economy	28000.00
0005432121300	5283	Economy	28000.00
0005434823355	5283	Economy	28000.00
0005434831134	5283	Economy	28000.00
0005434823326	5283	Economy	28000.00
0005434823348	5283	Economy	28000.00
0005434823380	5283	Economy	28000.00
0005434823313	5283	Economy	28000.00
0005434558248	5283	Economy	28000.00
0005434823356	5283	Economy	28000.00
0005435372454	5283	Economy	28000.00
0005435149999	5283	Economy	28000.00
0005434823347	5283	Economy	28000.00
0005435386503	5283	Economy	28000.00
0005435372568	5283	Economy	28000.00
0005435150000	5283	Economy	28000.00
0005435372447	5283	Economy	28000.00
0005434823304	5283	Economy	28000.00
0005435372570	5283	Economy	28000.00
0005432121310	5283	Economy	28000.00
0005435372822	5283	Economy	28000.00
0005434823295	5283	Economy	28000.00
0005434823318	5283	Economy	28000.00
0005435372559	5283	Economy	28000.00
0005432394097	5283	Economy	28000.00
0005434823357	5283	Economy	28000.00
0005434823282	5283	Economy	28000.00
0005435299730	5283	Economy	28000.00
0005434823303	5283	Economy	28000.00
0005435150005	5283	Economy	28000.00
0005435372639	5283	Economy	28000.00
0005434823289	5283	Economy	28000.00
0005434823306	5283	Economy	28000.00
0005435372285	5283	Economy	30800.00
0005434823359	5283	Economy	28000.00
0005434558253	5283	Economy	30800.00
0005434823320	5283	Economy	30800.00
0005434823268	5283	Economy	28000.00
0005435372371	5283	Economy	28000.00
0005434823323	5283	Economy	28000.00
0005435372536	5283	Economy	30800.00
0005434823378	5283	Economy	30800.00
0005434823324	5283	Economy	28000.00
0005434823312	5283	Economy	30800.00
0005435372488	5283	Economy	28000.00
0005434823297	5283	Economy	28000.00
0005434558249	5283	Economy	28000.00
0005435304135	5283	Economy	28000.00
0005434823261	5283	Economy	28000.00
0005434558254	5283	Economy	28000.00
0005432121308	5283	Economy	28000.00
0005434823367	5283	Economy	28000.00
0005435372514	5283	Economy	28000.00
0005432121304	5283	Economy	28000.00
0005435372689	5283	Economy	28000.00
0005435372709	5283	Economy	28000.00
0005432396234	5283	Economy	28000.00
0005434823298	5283	Economy	28000.00
0005434823286	5283	Economy	28000.00
0005435304104	5283	Economy	28000.00
0005434823287	5283	Economy	28000.00
0005435149995	5283	Economy	28000.00
0005435150002	5283	Economy	28000.00
0005435372589	5283	Economy	28000.00
0005434558246	5283	Economy	28000.00
0005434823275	5283	Economy	28000.00
0005434823389	5283	Economy	28000.00
0005434823330	5283	Economy	28000.00
0005434558247	5283	Economy	28000.00
0005434664952	5283	Economy	28000.00
0005435372550	5283	Economy	28000.00
0005435372821	5283	Economy	28000.00
0005434828689	5283	Economy	28000.00
0005434823309	5283	Economy	28000.00
0005435372445	5283	Economy	28000.00
0005434558255	5283	Economy	28000.00
0005435735075	5283	Economy	28000.00
0005432396235	5283	Economy	28000.00
0005432396236	5283	Economy	28000.00
0005435372372	5283	Economy	28000.00
0005435372555	5283	Economy	28000.00
0005435372500	5283	Economy	28000.00
0005432121309	5283	Economy	28000.00
0005435735076	5283	Economy	28000.00
0005434823299	5283	Economy	28000.00
0005434823375	5283	Economy	28000.00
0005435386502	5283	Economy	28000.00
0005435150007	5283	Economy	28000.00
0005434823317	5283	Economy	28000.00
0005435149996	5283	Economy	28000.00
0005434823333	5283	Economy	28000.00
0005434823278	5283	Economy	28000.00
0005432394095	5283	Economy	28000.00
0005435372487	5283	Economy	28000.00
0005434823271	5283	Economy	28000.00
0005434823274	5283	Economy	28000.00
0005434823327	5283	Economy	28000.00
0005434823292	5283	Economy	28000.00
0005434558244	5283	Economy	28000.00
0005435372779	5283	Economy	28000.00
0005434823381	5283	Economy	28000.00
0005435386537	5283	Economy	28000.00
0005434823316	5283	Economy	28000.00
0005434823272	5283	Economy	28000.00
0005434823284	5283	Economy	28000.00
0005434823329	5283	Economy	28000.00
0005434823266	5283	Economy	28000.00
0005435735091	5283	Economy	28000.00
0005434823279	5283	Economy	28000.00
0005435735068	5283	Economy	28000.00
0005435372567	5283	Economy	28000.00
0005435149998	5283	Economy	28000.00
0005435372446	5283	Economy	28000.00
0005432121303	5283	Economy	28000.00
0005432121299	5283	Economy	28000.00
0005435150003	5283	Economy	28000.00
0005434831135	5283	Economy	28000.00
0005434823360	5283	Economy	28000.00
0005435372511	5283	Economy	28000.00
0005434823386	5283	Economy	28000.00
0005434823263	5283	Economy	28000.00
0005434823285	5283	Economy	28000.00
0005434823346	5283	Economy	28000.00
0005435372373	5283	Economy	28000.00
0005434823335	5283	Economy	28000.00
0005434823264	5283	Economy	28000.00
0005434823336	5283	Economy	28000.00
0005435372778	5283	Economy	28000.00
0005435372430	5283	Economy	28000.00
0005434823262	5283	Economy	28000.00
0005435372448	5283	Economy	28000.00
0005435372601	5283	Economy	30800.00
0005434823362	5283	Economy	28000.00
0005432121306	5283	Economy	30800.00
0005435372618	5283	Economy	30800.00
0005434823371	5283	Economy	30800.00
0005434823343	5283	Economy	30800.00
0005434823353	5283	Economy	30800.00
0005435372676	5283	Economy	28000.00
0005435735078	5283	Economy	28000.00
0005435372633	5283	Economy	28000.00
0005435372499	5283	Economy	28000.00
0005434823301	5283	Economy	28000.00
0005434823340	5283	Economy	28000.00
0005435372452	5283	Economy	28000.00
0005435386538	5283	Economy	28000.00
0005434823310	5283	Economy	28000.00
0005434558245	5283	Economy	28000.00
0005435661892	5283	Economy	28000.00
0005434664953	5283	Economy	28000.00
0005435661893	5283	Economy	28000.00
0005434823342	5283	Economy	28000.00
0005434823294	5283	Economy	28000.00
0005435372548	5283	Economy	28000.00
0005434823364	5283	Economy	28000.00
0005435372286	5283	Economy	28000.00
0005435735101	5283	Economy	28000.00
0005435372493	5283	Economy	28000.00
0005435386473	5283	Economy	28000.00
0005434823369	5283	Economy	28000.00
0005435150006	5283	Economy	28000.00
0005432396233	5283	Economy	28000.00
0005434823332	5283	Economy	28000.00
0005435372549	5283	Economy	28000.00
0005434823283	5283	Economy	28000.00
0005434828690	5283	Economy	28000.00
0005435372579	5283	Economy	28000.00
0005434823319	5283	Economy	28000.00
0005435372512	5283	Economy	28000.00
0005434823368	5283	Economy	28000.00
0005434823314	5283	Economy	28000.00
0005435178977	5283	Economy	28000.00
0005434823372	5283	Economy	28000.00
0005435372501	5283	Economy	28000.00
0005435735069	5283	Economy	28000.00
0005434823328	5283	Economy	28000.00
0005435372590	5283	Economy	28000.00
0005434823265	5283	Economy	28000.00
0005434823339	5283	Economy	28000.00
0005432121312	5283	Economy	28000.00
0005434823338	5283	Economy	28000.00
0005434823325	5283	Economy	28000.00
0005434823270	5283	Economy	28000.00
0005434823366	5283	Economy	28000.00
0005435372434	5283	Economy	28000.00
0005434823277	5283	Economy	28000.00
0005435372648	5283	Economy	28000.00
0005434558250	5283	Economy	28000.00
0005434558256	5283	Economy	28000.00
0005435372640	5283	Economy	28000.00
0005434823300	5283	Economy	28000.00
0005434823373	5283	Economy	28000.00
0005432121307	5283	Economy	28000.00
0005434823280	5283	Economy	28000.00
0005434823273	5283	Economy	28000.00
0005435372584	5283	Economy	28000.00
0005434823354	5283	Economy	28000.00
0005434558257	5283	Economy	28000.00
0005434823331	5283	Economy	28000.00
0005434823370	5283	Economy	28000.00
0005435372431	5283	Economy	28000.00
0005432394098	5283	Economy	28000.00
0005435299720	5283	Economy	28000.00
0005434823322	5283	Economy	28000.00
0005434558251	5283	Economy	28000.00
0005432121301	5283	Economy	28000.00
0005434823269	5283	Economy	28000.00
0005434823349	5283	Economy	28000.00
0005434823296	5283	Economy	28000.00
0005435372422	5283	Economy	28000.00
0005434558252	5283	Economy	28000.00
0005434822343	9932	Business	84000.00
0005435373108	9932	Business	84000.00
0005434558161	9932	Business	84000.00
0005434822305	9932	Business	84000.00
0005435373130	9932	Business	84000.00
0005434821907	9932	Business	84000.00
0005435149871	9932	Business	84000.00
0005432823445	9932	Business	84000.00
0005434821990	9932	Business	84000.00
0005435373149	9932	Business	84000.00
0005432396220	9932	Business	84000.00
0005435373103	9932	Business	84000.00
0005435299767	9932	Business	84000.00
0005434822326	9932	Business	84000.00
0005434822230	9932	Business	84000.00
0005434822573	9932	Business	84000.00
0005435373102	9932	Business	84000.00
0005434822571	9932	Business	84000.00
0005435373123	9932	Business	84000.00
0005434822081	9932	Business	84000.00
0005435149841	9932	Business	84000.00
0005434822327	9932	Comfort	47600.00
0005434558160	9932	Comfort	47600.00
0005434822476	9932	Comfort	47600.00
0005434821972	9932	Comfort	47600.00
0005435373105	9932	Comfort	47600.00
0005434822123	9932	Comfort	47600.00
0005434664931	9932	Comfort	47600.00
0005434822213	9932	Comfort	47600.00
0005434822120	9932	Comfort	47600.00
0005434558177	9932	Comfort	47600.00
0005435373153	9932	Comfort	47600.00
0005435373150	9932	Comfort	47600.00
0005432823447	9932	Comfort	47600.00
0005435373141	9932	Comfort	47600.00
0005432400067	9932	Comfort	47600.00
0005435373160	9932	Comfort	47600.00
0005434821956	9932	Comfort	47600.00
0005434822012	9932	Comfort	47600.00
0005434822519	9932	Comfort	47600.00
0005434821936	9932	Comfort	47600.00
0005434821779	9932	Comfort	47600.00
0005434822442	9932	Comfort	47600.00
0005434822271	9932	Comfort	47600.00
0005434822286	9932	Comfort	47600.00
0005432400074	9932	Comfort	47600.00
0005434822572	9932	Comfort	47600.00
0005434558141	9932	Comfort	47600.00
0005434664930	9932	Comfort	47600.00
0005435149883	9932	Comfort	47600.00
0005435373161	9932	Comfort	47600.00
0005435149832	9932	Comfort	47600.00
0005434822350	9932	Comfort	47600.00
0005434822547	9932	Comfort	47600.00
0005434558176	9932	Comfort	47600.00
0005435373118	9932	Comfort	47600.00
0005435302190	9932	Economy	28000.00
0005434822565	9932	Economy	28000.00
0005434822526	9932	Economy	28000.00
0005434831100	9932	Economy	28000.00
0005434558170	9932	Economy	28000.00
0005434822752	9932	Economy	28000.00
0005434822470	9932	Economy	28000.00
0005432823446	9932	Economy	28000.00
0005435149877	9932	Economy	28000.00
0005434822372	9932	Economy	28000.00
0005434822596	9932	Economy	28000.00
0005434822371	9932	Economy	28000.00
0005435386564	9932	Economy	28000.00
0005435661926	9932	Economy	28000.00
0005435149888	9932	Economy	28000.00
0005435661925	9932	Economy	28000.00
0005435373095	9932	Economy	28000.00
0005432203049	9932	Economy	28000.00
0005432396192	9932	Economy	28000.00
0005432203050	9932	Economy	28000.00
0005434822270	9932	Economy	28000.00
0005435373159	9932	Economy	28000.00
0005434822679	9932	Economy	28000.00
0005434822717	9932	Economy	28000.00
0005435373121	9932	Economy	28000.00
0005435373113	9932	Economy	28000.00
0005434821788	9932	Economy	28000.00
0005434822761	9932	Economy	28000.00
0005435149859	9932	Economy	28000.00
0005435149892	9932	Economy	28000.00
0005434822835	9932	Economy	28000.00
0005434822079	9932	Economy	28000.00
0005432203048	9932	Economy	28000.00
0005435373155	9932	Economy	28000.00
0005434822570	9932	Economy	28000.00
0005434822222	9932	Economy	28000.00
0005434822312	9932	Economy	28000.00
0005434821851	9932	Economy	28000.00
0005435373129	9932	Economy	28000.00
0005434822458	9932	Economy	28000.00
0005435373109	9932	Economy	28000.00
0005435299766	9932	Economy	28000.00
0005435373132	9932	Economy	28000.00
0005434822173	9932	Economy	28000.00
0005435373107	9932	Economy	28000.00
0005434822196	9932	Economy	28000.00
0005432396195	9932	Economy	28000.00
0005435302189	9932	Economy	28000.00
0005434822475	9932	Economy	28000.00
0005435149902	9932	Economy	28000.00
0005434822365	9932	Economy	28000.00
0005434822223	9932	Economy	28000.00
0005434822164	9932	Economy	30800.00
0005435373101	9932	Economy	28000.00
0005434822551	9932	Economy	30800.00
0005435149854	9932	Economy	30800.00
0005434822550	9932	Economy	28000.00
0005434821970	9932	Economy	30800.00
0005434558183	9932	Economy	28000.00
0005435373147	9932	Economy	30800.00
0005435373145	9932	Economy	30800.00
0005435149846	9932	Economy	28000.00
0005435149870	9932	Economy	28000.00
0005434821831	9932	Economy	28000.00
0005432203045	9932	Economy	28000.00
0005434821696	9932	Economy	28000.00
0005434822471	9932	Economy	28000.00
0005435149822	9932	Economy	28000.00
0005435149842	9932	Economy	28000.00
0005434822097	9932	Economy	28000.00
0005434822441	9932	Economy	28000.00
0005435149845	9932	Economy	28000.00
0005435735131	9932	Economy	28000.00
0005435386562	9932	Economy	28000.00
0005434821581	9932	Economy	28000.00
0005432203051	9932	Economy	28000.00
0005435373110	9932	Economy	28000.00
0005435373136	9932	Economy	28000.00
0005434821886	9932	Economy	28000.00
0005434822135	9932	Economy	28000.00
0005434822445	9932	Economy	28000.00
0005434822413	9932	Economy	28000.00
0005435373100	9932	Economy	28000.00
0005434822697	9932	Economy	28000.00
0005434822462	9932	Economy	28000.00
0005434822474	9932	Economy	28000.00
0005434821892	9932	Economy	28000.00
0005434822303	9932	Economy	28000.00
0005434822366	9932	Economy	28000.00
0005434558178	9932	Economy	28000.00
0005434822507	9932	Economy	28000.00
0005435735132	9932	Economy	28000.00
0005435735133	9932	Economy	28000.00
0005432396198	9932	Economy	28000.00
0005435373117	9932	Economy	28000.00
0005435373111	9932	Economy	28000.00
0005434821416	9932	Economy	28000.00
0005435373097	9932	Economy	28000.00
0005435149864	9932	Economy	28000.00
0005434822628	9932	Economy	28000.00
0005435373138	9932	Economy	28000.00
0005434821937	9932	Economy	28000.00
0005434822176	9932	Economy	28000.00
0005435373120	9932	Economy	28000.00
0005434822563	9932	Economy	28000.00
0005432203047	9932	Economy	28000.00
0005435299764	9932	Economy	28000.00
0005434821468	9932	Economy	28000.00
0005434822514	9932	Economy	28000.00
0005434822389	9932	Economy	28000.00
0005432400068	9932	Economy	28000.00
0005435149829	9932	Economy	28000.00
0005435149860	9932	Economy	28000.00
0005435661924	9932	Economy	28000.00
0005434822564	9932	Economy	28000.00
0005435373140	9932	Economy	28000.00
0005434822214	9932	Economy	28000.00
0005434822751	9932	Economy	28000.00
0005435149885	9932	Economy	28000.00
0005435373146	9932	Economy	28000.00
0005434822469	9932	Economy	28000.00
0005435373143	9932	Economy	28000.00
0005432400073	9932	Economy	28000.00
0005435373157	9932	Economy	28000.00
0005434822461	9932	Economy	28000.00
0005435373099	9932	Economy	28000.00
0005435149901	9932	Economy	28000.00
0005434831101	9932	Economy	28000.00
0005435373156	9932	Economy	28000.00
0005435373122	9932	Economy	28000.00
0005435373116	9932	Economy	28000.00
0005435373148	9932	Economy	28000.00
0005434821830	9932	Economy	28000.00
0005435373142	9932	Economy	28000.00
0005435373133	9932	Economy	28000.00
0005435373098	9932	Economy	28000.00
0005434821908	9932	Economy	28000.00
0005434558174	9932	Economy	28000.00
0005434821827	9932	Economy	30800.00
0005434821891	9932	Economy	28000.00
0005434822342	9932	Economy	30800.00
0005435373124	9932	Economy	30800.00
0005435373104	9932	Economy	28000.00
0005434558179	9932	Economy	28000.00
0005432396194	9932	Economy	28000.00
0005432203046	9932	Economy	28000.00
0005434822285	9932	Economy	28000.00
0005434821697	9932	Economy	28000.00
0005434822080	9932	Economy	28000.00
0005435373114	9932	Economy	28000.00
0005435373125	9932	Economy	28000.00
0005434822482	9932	Economy	28000.00
0005435373154	9932	Economy	28000.00
0005434821958	9932	Economy	28000.00
0005435373151	9932	Economy	28000.00
0005434821492	9932	Economy	28000.00
0005435373137	9932	Economy	28000.00
0005435373115	9932	Economy	28000.00
0005434821992	9932	Economy	28000.00
0005434821828	9932	Economy	28000.00
0005434822569	9932	Economy	28000.00
0005434822296	9932	Economy	28000.00
0005434821938	9932	Economy	28000.00
0005434822995	9932	Economy	28000.00
0005434821971	9932	Economy	28000.00
0005434822562	9932	Economy	28000.00
0005435149828	9932	Economy	28000.00
0005435373139	9932	Economy	28000.00
0005434823033	9932	Economy	28000.00
0005434822304	9932	Economy	28000.00
0005434822165	9932	Economy	28000.00
0005434828670	9932	Economy	28000.00
0005434822357	9932	Economy	28000.00
0005435299765	9932	Economy	28000.00
0005434822149	9932	Economy	28000.00
0005435373158	9932	Economy	28000.00
0005435373126	9932	Economy	28000.00
0005435373096	9932	Economy	28000.00
0005434822049	9932	Economy	28000.00
0005435373112	9932	Economy	28000.00
0005434822488	9932	Economy	28000.00
0005434831089	9932	Economy	28000.00
0005435373134	9932	Economy	28000.00
0005434664942	9932	Economy	28000.00
0005435373106	9932	Economy	28000.00
0005434822147	9932	Economy	28000.00
0005435373152	9932	Economy	28000.00
0005435373131	9932	Economy	28000.00
0005435149886	9932	Economy	28000.00
0005434821957	9932	Economy	28000.00
0005434822629	9932	Economy	28000.00
0005434822504	9932	Economy	28000.00
0005435373135	9932	Economy	28000.00
0005434822243	9932	Economy	28000.00
0005435373128	9932	Economy	28000.00
0005434822698	9932	Economy	28000.00
0005435373144	9932	Economy	28000.00
0005435373127	9932	Economy	28000.00
0005435149893	9932	Economy	28000.00
0005434823034	9932	Economy	28000.00
0005434822735	9932	Economy	28000.00
0005435373119	9932	Economy	28000.00
0005434822264	9932	Economy	28000.00
0005435149821	9932	Economy	28000.00
0005434822958	9932	Economy	28000.00
0005434822483	9932	Economy	28000.00
0005434822446	9932	Economy	28000.00
0005434822337	9932	Economy	28000.00
0005435149867	9932	Economy	28000.00
0005435386563	9932	Economy	28000.00
0005434822568	9932	Economy	28000.00
0005434822313	9932	Economy	28000.00
0005434821924	9932	Economy	28000.00
0005434821842	9932	Economy	28000.00
0005434821780	9932	Economy	28000.00
0005434822360	9932	Economy	28000.00
0005435149929	9932	Economy	28000.00
0005434822349	9932	Economy	28000.00
0005434822805	9932	Economy	28000.00
0005434822242	9932	Economy	28000.00
0005435082775	7017	Economy	7400.00
0005435082771	7017	Economy	7400.00
0005435082776	7017	Economy	7400.00
0005435082773	7017	Economy	7400.00
0005435790300	7017	Economy	7400.00
0005435082777	7017	Economy	7400.00
0005435790301	7017	Economy	7400.00
0005435082774	7017	Economy	7400.00
0005435790299	7017	Economy	7400.00
0005435082772	7017	Economy	7400.00
0005435082705	25997	Economy	7400.00
0005435082696	25997	Economy	7400.00
0005435082695	25997	Economy	7400.00
0005435082698	25997	Economy	7400.00
0005435790273	25997	Economy	7400.00
0005435082704	25997	Economy	7400.00
0005435082721	25997	Economy	7400.00
0005435790277	25997	Economy	7400.00
0005434756349	9545	Business	32800.00
0005434756347	9545	Business	32800.00
0005434756339	9545	Business	32800.00
0005434214085	9545	Business	32800.00
0005434213809	9545	Business	32800.00
0005434214000	9545	Business	32800.00
0005434756345	9545	Business	32800.00
0005434756358	9545	Business	32800.00
0005434756354	9545	Business	32800.00
0005434756343	9545	Business	32800.00
0005434213883	9545	Business	32800.00
0005434214114	9545	Business	32800.00
0005434756356	9545	Economy	10900.00
0005434756336	9545	Economy	10900.00
0005434756359	9545	Economy	10900.00
0005434213998	9545	Economy	10900.00
0005434756329	9545	Economy	10900.00
0005434214184	9545	Economy	10900.00
0005434213927	9545	Economy	10900.00
0005434756334	9545	Economy	10900.00
0005434213949	9545	Economy	10900.00
0005434214218	9545	Economy	10900.00
0005434214009	9545	Economy	12000.00
0005434756342	9545	Economy	12000.00
0005434214219	9545	Economy	12000.00
0005434756338	9545	Economy	12000.00
0005434214152	9545	Economy	12000.00
0005434214008	9545	Economy	10900.00
0005434756353	9545	Economy	10900.00
0005434214045	9545	Economy	10900.00
0005434756348	9545	Economy	10900.00
0005434756351	9545	Economy	10900.00
0005434214124	9545	Economy	10900.00
0005434214043	9545	Economy	10900.00
0005434214044	9545	Economy	10900.00
0005434756340	9545	Economy	10900.00
0005434214115	9545	Economy	10900.00
0005434214075	9545	Economy	10900.00
0005434756333	9545	Economy	10900.00
0005434214105	9545	Economy	10900.00
0005434756331	9545	Economy	10900.00
0005434214034	9545	Economy	10900.00
0005434756337	9545	Economy	10900.00
0005434756360	9545	Economy	10900.00
0005434214040	9545	Economy	10900.00
0005434214037	9545	Economy	10900.00
0005434213799	9545	Economy	10900.00
0005434214186	9545	Economy	10900.00
0005434214160	9545	Economy	10900.00
0005434214018	9545	Economy	10900.00
0005434214007	9545	Economy	10900.00
0005434213936	9545	Economy	10900.00
0005434213923	9545	Economy	10900.00
0005434756352	9545	Economy	10900.00
0005434214103	9545	Economy	10900.00
0005434756350	9545	Economy	10900.00
0005434214020	9545	Economy	10900.00
0005434213903	9545	Economy	10900.00
0005434756335	9545	Economy	10900.00
0005434213977	9545	Economy	10900.00
0005434214035	9545	Economy	10900.00
0005434756355	9545	Economy	10900.00
0005434214225	9545	Economy	10900.00
0005434213800	9545	Economy	10900.00
0005434214074	9545	Economy	10900.00
0005434756332	9545	Economy	10900.00
0005434214033	9545	Economy	10900.00
0005434214042	9545	Economy	10900.00
0005434213972	9545	Economy	10900.00
0005434756330	9545	Economy	10900.00
0005434214185	9545	Economy	10900.00
0005434214175	9545	Economy	10900.00
0005434213884	9545	Economy	10900.00
0005434214017	9545	Economy	10900.00
0005434756346	9545	Economy	10900.00
0005434214213	9545	Economy	10900.00
0005434213978	9545	Economy	10900.00
0005434213855	9545	Economy	10900.00
0005434213832	9545	Economy	10900.00
0005434214076	9545	Economy	10900.00
0005434214102	9545	Economy	10900.00
0005434214159	9545	Economy	10900.00
0005434756357	9545	Economy	10900.00
0005434756344	9545	Economy	10900.00
0005434214101	9545	Economy	10900.00
0005434756341	9545	Economy	10900.00
0005434214010	9545	Economy	10900.00
0005434213819	9545	Economy	10900.00
0005434756361	9545	Economy	10900.00
0005434214364	28632	Business	32800.00
0005434214383	28632	Business	32800.00
0005434755929	28632	Business	32800.00
0005434214397	28632	Business	32800.00
0005434755817	28632	Business	32800.00
0005434756062	28632	Business	32800.00
0005434755747	28632	Business	32800.00
0005434214369	28632	Business	32800.00
0005434755963	28632	Business	32800.00
0005434214407	28632	Business	32800.00
0005434214378	28632	Economy	10900.00
0005434755943	28632	Economy	10900.00
0005434214384	28632	Economy	10900.00
0005434755902	28632	Economy	10900.00
0005434755914	28632	Economy	10900.00
0005434214385	28632	Economy	10900.00
0005434755953	28632	Economy	10900.00
0005434214375	28632	Economy	10900.00
0005434756034	28632	Economy	10900.00
0005434755904	28632	Economy	12000.00
0005434214372	28632	Economy	12000.00
0005434756049	28632	Economy	12000.00
0005434755812	28632	Economy	12000.00
0005434755941	28632	Economy	12000.00
0005434214386	28632	Economy	10900.00
0005434214389	28632	Economy	10900.00
0005434214396	28632	Economy	10900.00
0005434214388	28632	Economy	10900.00
0005434756035	28632	Economy	10900.00
0005434756021	28632	Economy	10900.00
0005434214373	28632	Economy	10900.00
0005434214398	28632	Economy	10900.00
0005434214365	28632	Economy	10900.00
0005434755859	28632	Economy	10900.00
0005434755829	28632	Economy	10900.00
0005434214403	28632	Economy	10900.00
0005434755798	28632	Economy	10900.00
0005434755989	28632	Economy	10900.00
0005434755951	28632	Economy	10900.00
0005434755768	28632	Economy	10900.00
0005434214412	28632	Economy	10900.00
0005434755937	28632	Economy	10900.00
0005434214411	28632	Economy	10900.00
0005434756050	28632	Economy	10900.00
0005434755940	28632	Economy	10900.00
0005434214381	28632	Economy	10900.00
0005434755884	28632	Economy	10900.00
0005434214387	28632	Economy	10900.00
0005434214395	28632	Economy	10900.00
0005434214367	28632	Economy	10900.00
0005434214394	28632	Economy	10900.00
0005434756063	28632	Economy	10900.00
0005434214366	28632	Economy	10900.00
0005434214371	28632	Economy	10900.00
0005434214400	28632	Economy	10900.00
0005434755878	28632	Economy	10900.00
0005434755952	28632	Economy	10900.00
0005434214408	28632	Economy	10900.00
0005434755987	28632	Economy	10900.00
0005434755860	28632	Economy	10900.00
0005434214390	28632	Economy	10900.00
0005434214393	28632	Economy	10900.00
0005434214379	28632	Economy	10900.00
0005434755915	28632	Economy	10900.00
0005434756036	28632	Economy	10900.00
0005434214392	28632	Economy	10900.00
0005434214391	28632	Economy	10900.00
0005434214399	28632	Economy	10900.00
0005434214404	28632	Economy	10900.00
0005434214370	28632	Economy	10900.00
0005434755820	28632	Economy	10900.00
0005434756012	28632	Economy	10900.00
0005434214409	28632	Economy	10900.00
0005434755944	28632	Economy	10900.00
0005434214401	28632	Economy	10900.00
0005434756030	28632	Economy	10900.00
0005434214374	28632	Economy	10900.00
0005434214382	28632	Economy	10900.00
0005434755819	28632	Economy	10900.00
0005434214410	28632	Economy	10900.00
0005434214377	28632	Economy	10900.00
0005434214405	28632	Economy	10900.00
0005434214406	28632	Economy	10900.00
0005434214402	28632	Economy	10900.00
0005434756020	28632	Economy	10900.00
0005434214368	28632	Economy	10900.00
0005434214376	28632	Economy	10900.00
0005434755930	28632	Economy	10900.00
0005434755931	28632	Economy	10900.00
0005434214380	28632	Economy	10900.00
0005435100117	10820	Economy	9800.00
0005434760167	10820	Economy	9800.00
0005434760182	10820	Economy	8900.00
0005434760166	10820	Economy	8900.00
0005434760169	10820	Economy	8900.00
0005434760163	10820	Economy	8900.00
0005434760164	10820	Economy	8900.00
0005434760165	10820	Economy	8900.00
0005434760170	10820	Economy	8900.00
0005435100116	10820	Economy	8900.00
0005435100115	10820	Economy	8900.00
0005434760193	31845	Economy	9800.00
0005435100100	31845	Economy	8900.00
0005435100090	31845	Economy	8900.00
0005435100088	31845	Economy	8900.00
0005434760191	31845	Economy	8900.00
0005435100087	31845	Economy	8900.00
0005434760192	31845	Economy	8900.00
0005435100101	31845	Economy	8900.00
0005433202177	2000	Economy	20900.00
0005432290627	2000	Economy	20900.00
0005433202165	2000	Economy	20900.00
0005433202168	2000	Economy	20900.00
0005433202191	2000	Economy	19000.00
0005434639286	2000	Economy	19000.00
0005434639287	2000	Economy	19000.00
0005434639278	2000	Economy	19000.00
0005433202186	2000	Economy	19000.00
0005433202227	2000	Economy	19000.00
0005434639267	2000	Economy	19000.00
0005433202160	2000	Economy	19000.00
0005434639277	2000	Economy	19000.00
0005433202136	2000	Economy	19000.00
0005433202207	2000	Economy	19000.00
0005433202217	2000	Economy	19000.00
0005434639270	2000	Economy	19000.00
0005434639285	2000	Economy	19000.00
0005433202178	2000	Economy	19000.00
0005433202135	2000	Economy	19000.00
0005433202236	2000	Economy	19000.00
0005433202218	2000	Economy	19000.00
0005434639271	2000	Economy	19000.00
0005433202174	2000	Economy	19000.00
0005433202159	2000	Economy	19000.00
0005434639274	2000	Economy	19000.00
0005433202123	2000	Economy	19000.00
0005434639280	2000	Economy	19000.00
0005434639284	2000	Economy	19000.00
0005434639283	2000	Economy	19000.00
0005434639273	2000	Economy	19000.00
0005434639272	2000	Economy	19000.00
0005434639275	2000	Economy	19000.00
0005434639265	2000	Economy	19000.00
0005432290626	2000	Economy	19000.00
0005434639269	2000	Economy	19000.00
0005434639266	2000	Economy	19000.00
0005433202169	2000	Economy	19000.00
0005434639268	2000	Economy	19000.00
0005434639276	2000	Economy	19000.00
0005433202183	2000	Economy	19000.00
0005434639282	2000	Economy	19000.00
0005434639279	2000	Economy	19000.00
0005434639281	2000	Economy	19000.00
0005432290628	2000	Economy	19000.00
0005434639034	23303	Economy	20900.00
0005434639000	23303	Economy	20900.00
0005434639065	23303	Economy	20900.00
0005433202322	23303	Economy	20900.00
0005434638979	23303	Economy	19000.00
0005435948316	23303	Economy	19000.00
0005434638978	23303	Economy	19000.00
0005435948314	23303	Economy	19000.00
0005434638987	23303	Economy	19000.00
0005433202319	23303	Economy	19000.00
0005433202314	23303	Economy	19000.00
0005434638986	23303	Economy	19000.00
0005433202316	23303	Economy	19000.00
0005434639057	23303	Economy	19000.00
0005434639072	23303	Economy	19000.00
0005433202315	23303	Economy	19000.00
0005433202324	23303	Economy	19000.00
0005433202326	23303	Economy	19000.00
0005434638943	23303	Economy	19000.00
0005433202325	23303	Economy	19000.00
0005433202320	23303	Economy	19000.00
0005434639066	23303	Economy	19000.00
0005433202327	23303	Economy	19000.00
0005433202328	23303	Economy	19000.00
0005434638889	23303	Economy	19000.00
0005434638928	23303	Economy	19000.00
0005434639099	23303	Economy	19000.00
0005434639027	23303	Economy	19000.00
0005434638942	23303	Economy	19000.00
0005433202317	23303	Economy	19000.00
0005434639119	23303	Economy	19000.00
0005434638993	23303	Economy	19000.00
0005434639001	23303	Economy	19000.00
0005433202318	23303	Economy	19000.00
0005434639019	23303	Economy	19000.00
0005433202323	23303	Economy	19000.00
0005434639120	23303	Economy	19000.00
0005434639010	23303	Economy	19000.00
0005434639049	23303	Economy	19000.00
0005434638990	23303	Economy	19000.00
0005434638946	23303	Economy	19000.00
0005433202321	23303	Economy	19000.00
0005433202313	23303	Economy	19000.00
0005434638929	23303	Economy	19000.00
0005435948317	23303	Economy	19000.00
0005435326572	6075	Business	69700.00
0005435326570	6075	Business	69700.00
0005434600748	6075	Business	69700.00
0005434600756	6075	Business	69700.00
0005435326603	6075	Business	69700.00
0005434600757	6075	Business	69700.00
0005434600763	6075	Business	69700.00
0005433531286	6075	Economy	23200.00
0005433531284	6075	Economy	23200.00
0005432111273	6075	Economy	23200.00
0005434600749	6075	Economy	23200.00
0005432111271	6075	Economy	23200.00
0005434600761	6075	Economy	23200.00
0005435326652	6075	Economy	23200.00
0005433533300	6075	Economy	23200.00
0005435326518	6075	Economy	23200.00
0005433533302	6075	Economy	23200.00
0005434600760	6075	Economy	23200.00
0005435326566	6075	Economy	23200.00
0005435326565	6075	Economy	23200.00
0005434600742	6075	Economy	23200.00
0005433531285	6075	Economy	23200.00
0005432111274	6075	Economy	23200.00
0005435326653	6075	Economy	23200.00
0005434600758	6075	Economy	23200.00
0005434600764	6075	Economy	23200.00
0005435326622	6075	Economy	23200.00
0005435326661	6075	Economy	23200.00
0005434600759	6075	Economy	23200.00
0005432111272	6075	Economy	23200.00
0005434600741	6075	Economy	23200.00
0005434600751	6075	Economy	23200.00
0005434600767	6075	Economy	23200.00
0005434600754	6075	Economy	23200.00
0005435326571	6075	Economy	23200.00
0005434600765	6075	Economy	23200.00
0005435326644	6075	Economy	23200.00
0005434600744	6075	Economy	23200.00
0005434600766	6075	Economy	23200.00
0005434600750	6075	Economy	23200.00
0005434600747	6075	Economy	23200.00
0005434600745	6075	Economy	23200.00
0005434600752	6075	Economy	23200.00
0005434600746	6075	Economy	23200.00
0005435326639	6075	Economy	23200.00
0005433533301	6075	Economy	23200.00
0005434600762	6075	Economy	23200.00
0005434600755	6075	Economy	23200.00
0005435326638	6075	Economy	23200.00
0005434600743	6075	Economy	23200.00
0005434600753	6075	Economy	23200.00
0005434600482	18589	Business	69700.00
0005434600444	18589	Business	69700.00
0005435326716	18589	Business	69700.00
0005434600493	18589	Business	69700.00
0005434600491	18589	Business	69700.00
0005433527217	18589	Economy	23200.00
0005434600536	18589	Economy	23200.00
0005434600579	18589	Economy	23200.00
0005435326717	18589	Economy	23200.00
0005435326723	18589	Economy	23200.00
0005434600496	18589	Economy	23200.00
0005434600560	18589	Economy	23200.00
0005435326714	18589	Economy	23200.00
0005434600553	18589	Economy	23200.00
0005435326721	18589	Economy	23200.00
0005434600518	18589	Economy	23200.00
0005433527212	18589	Economy	23200.00
0005435326718	18589	Economy	23200.00
0005434600492	18589	Economy	23200.00
0005435326713	18589	Economy	23200.00
0005433527200	18589	Economy	23200.00
0005434600433	18589	Economy	23200.00
0005434600470	18589	Economy	23200.00
0005434600527	18589	Economy	23200.00
0005434600507	18589	Economy	23200.00
0005434600510	18589	Economy	23200.00
0005435326711	18589	Economy	23200.00
0005435326720	18589	Economy	23200.00
0005433531251	18589	Economy	23200.00
0005434600479	18589	Economy	23200.00
0005433527199	18589	Economy	23200.00
0005433527218	18589	Economy	23200.00
0005434600580	18589	Economy	23200.00
0005435326722	18589	Economy	23200.00
0005434600411	18589	Economy	23200.00
0005433527211	18589	Economy	23200.00
0005435326719	18589	Economy	23200.00
0005434600559	18589	Economy	23200.00
0005435326712	18589	Economy	23200.00
0005433527213	18589	Economy	23200.00
0005435326715	18589	Economy	23200.00
0005433180749	10665	Business	9100.00
0005434551064	10665	Business	9100.00
0005434551049	10665	Business	9100.00
0005434551090	10665	Business	9100.00
0005434551082	10665	Business	9100.00
0005433180849	10665	Business	9100.00
0005434551046	10665	Business	9100.00
0005434551084	10665	Business	9100.00
0005433180723	10665	Business	9100.00
0005434551098	10665	Business	9100.00
0005434551055	10665	Business	9100.00
0005433180792	10665	Business	9100.00
0005433180833	10665	Economy	3000.00
0005434551048	10665	Economy	3000.00
0005434551062	10665	Economy	3000.00
0005434558236	10665	Economy	3000.00
0005434551047	10665	Economy	3000.00
0005434551072	10665	Economy	3000.00
0005434551051	10665	Economy	3000.00
0005434551061	10665	Economy	3000.00
0005434551068	10665	Economy	3000.00
0005434551065	10665	Economy	3000.00
0005434551044	10665	Economy	3300.00
0005434551091	10665	Economy	3300.00
0005434551069	10665	Economy	3300.00
0005434551075	10665	Economy	3300.00
0005433180851	10665	Economy	3300.00
0005433180857	10665	Economy	3000.00
0005434558238	10665	Economy	3000.00
0005434551097	10665	Economy	3000.00
0005434551076	10665	Economy	3000.00
0005434551053	10665	Economy	3000.00
0005434551057	10665	Economy	3000.00
0005434558240	10665	Economy	3000.00
0005434551045	10665	Economy	3000.00
0005434558239	10665	Economy	3000.00
0005434551050	10665	Economy	3000.00
0005434551081	10665	Economy	3000.00
0005433180882	10665	Economy	3000.00
0005434551078	10665	Economy	3000.00
0005434558234	10665	Economy	3000.00
0005433180730	10665	Economy	3000.00
0005434551060	10665	Economy	3000.00
0005434551071	10665	Economy	3000.00
0005434551059	10665	Economy	3000.00
0005434551054	10665	Economy	3000.00
0005434558237	10665	Economy	3000.00
0005434551085	10665	Economy	3000.00
0005434551089	10665	Economy	3000.00
0005434551079	10665	Economy	3000.00
0005434551070	10665	Economy	3000.00
0005434551096	10665	Economy	3000.00
0005433180852	10665	Economy	3000.00
0005434558241	10665	Economy	3000.00
0005433180881	10665	Economy	3000.00
0005433180779	10665	Economy	3000.00
0005434558235	10665	Economy	3000.00
0005434554060	10665	Economy	3000.00
0005433180858	10665	Economy	3000.00
0005434551083	10665	Economy	3000.00
0005434551092	10665	Economy	3000.00
0005433180853	10665	Economy	3000.00
0005434551093	10665	Economy	3000.00
0005434551067	10665	Economy	3000.00
0005434551094	10665	Economy	3000.00
0005434554059	10665	Economy	3000.00
0005433180780	10665	Economy	3000.00
0005434551073	10665	Economy	3000.00
0005433180898	10665	Economy	3000.00
0005433180816	10665	Economy	3000.00
0005434551095	10665	Economy	3000.00
0005433180850	10665	Economy	3000.00
0005434551052	10665	Economy	3000.00
0005434551056	10665	Economy	3000.00
0005433180800	10665	Economy	3000.00
0005434558242	10665	Economy	3000.00
0005434551074	10665	Economy	3000.00
0005433180782	10665	Economy	3000.00
0005434551063	10665	Economy	3000.00
0005434558233	10665	Economy	3000.00
0005434551058	10665	Economy	3000.00
0005434551066	10665	Economy	3000.00
0005434551086	10665	Economy	3000.00
0005433180783	10665	Economy	3000.00
0005434551088	10665	Economy	3000.00
0005433180801	10665	Economy	3000.00
0005434558243	10665	Economy	3000.00
0005433180750	10665	Economy	3000.00
0005434551087	10665	Economy	3000.00
0005434551077	10665	Economy	3000.00
0005433180880	10665	Economy	3000.00
0005433180899	10665	Economy	3000.00
0005434551080	10665	Economy	3000.00
0005433181041	27708	Business	9100.00
0005433181058	27708	Business	9100.00
0005433181059	27708	Economy	3000.00
0005433181055	27708	Economy	3000.00
0005433181040	27708	Economy	3300.00
0005433181049	27708	Economy	3300.00
0005433181046	27708	Economy	3000.00
0005433181056	27708	Economy	3000.00
0005433181060	27708	Economy	3000.00
0005433181061	27708	Economy	3000.00
0005433181057	27708	Economy	3000.00
0005433181042	27708	Economy	3000.00
0005433181050	27708	Economy	3000.00
0005433181052	27708	Economy	3000.00
0005433181054	27708	Economy	3000.00
0005433181038	27708	Economy	3000.00
0005433181048	27708	Economy	3000.00
0005433181053	27708	Economy	3000.00
0005433181044	27708	Economy	3000.00
0005433181051	27708	Economy	3000.00
0005433181039	27708	Economy	3000.00
0005433181037	27708	Economy	3000.00
0005433181036	27708	Economy	3000.00
0005433181043	27708	Economy	3000.00
0005433181047	27708	Economy	3000.00
0005433181045	27708	Economy	3000.00
0005434550682	27707	Business	9100.00
0005434558166	27707	Business	9100.00
0005434550612	27707	Business	9100.00
0005434550672	27707	Business	9100.00
0005434550728	27707	Business	9100.00
0005434550847	27707	Business	9100.00
0005434550443	27707	Business	9100.00
0005434550512	27707	Business	9100.00
0005434550780	27707	Business	9100.00
0005434550779	27707	Business	9100.00
0005434550652	27707	Economy	3000.00
0005434550668	27707	Economy	3000.00
0005434558184	27707	Economy	3000.00
0005434550513	27707	Economy	3000.00
0005434550667	27707	Economy	3000.00
0005434550758	27707	Economy	3000.00
0005434550613	27707	Economy	3000.00
0005434554037	27707	Economy	3000.00
0005434550683	27707	Economy	3300.00
0005434550789	27707	Economy	3000.00
0005434554036	27707	Economy	3000.00
0005434550666	27707	Economy	3000.00
0005434550482	27707	Economy	3000.00
0005434554033	27707	Economy	3000.00
0005434550371	27707	Economy	3000.00
0005434550717	27707	Economy	3000.00
0005434550725	27707	Economy	3000.00
0005434550759	27707	Economy	3000.00
0005434554032	27707	Economy	3000.00
0005434550926	27707	Economy	3000.00
0005434550694	27707	Economy	3000.00
0005434550641	27707	Economy	3000.00
0005434550621	27707	Economy	3000.00
0005434550769	27707	Economy	3000.00
0005434550715	27707	Economy	3000.00
0005434554038	27707	Economy	3000.00
0005434550614	27707	Economy	3000.00
0005434550544	27707	Economy	3000.00
0005434550729	27707	Economy	3000.00
0005434550770	27707	Economy	3000.00
0005434558185	27707	Economy	3000.00
0005434558167	27707	Economy	3000.00
0005434550654	27707	Economy	3000.00
0005434550622	27707	Economy	3000.00
0005434550393	27707	Economy	3000.00
0005434550852	27707	Economy	3000.00
0005434550653	27707	Economy	3000.00
0005434550684	27707	Economy	3000.00
0005434550790	27707	Economy	3000.00
0005434550474	27707	Economy	3000.00
0005434550447	27707	Economy	3000.00
0005434550591	27707	Economy	3000.00
0005434550753	27707	Economy	3000.00
0005434550635	27707	Economy	3000.00
0005434550665	27707	Economy	3000.00
0005434550815	27707	Economy	3000.00
0005434558149	27707	Economy	3000.00
0005434550269	27707	Economy	3000.00
0005434550771	27707	Economy	3000.00
0005434550800	27707	Economy	3000.00
0005433459209	6164	Economy	11700.00
0005433459212	6164	Economy	11700.00
0005433459211	6164	Economy	11700.00
0005433459213	6164	Economy	11700.00
0005433459210	6164	Economy	11700.00
0005435254469	19339	Economy	11700.00
0005435254468	19339	Economy	11700.00
0005433459177	19339	Economy	11700.00
0005435254470	19339	Economy	11700.00
0005433459172	19339	Economy	11700.00
0005433459176	19339	Economy	11700.00
0005435437659	6728	Business	51100.00
0005435437772	6728	Business	51100.00
0005432136159	6728	Business	51100.00
0005435437697	6728	Business	51100.00
0005432136158	6728	Business	51100.00
0005435682042	6728	Business	51100.00
0005435217694	6728	Business	51100.00
0005435437719	6728	Business	51100.00
0005435682064	6728	Business	51100.00
0005435682033	6728	Business	51100.00
0005435682061	6728	Economy	17000.00
0005435682055	6728	Economy	17000.00
0005434828660	6728	Economy	17000.00
0005435437673	6728	Economy	17000.00
0005435682035	6728	Economy	17000.00
0005435682062	6728	Economy	17000.00
0005435682048	6728	Economy	17000.00
0005435661922	6728	Economy	17000.00
0005435437674	6728	Economy	17000.00
0005435682058	6728	Economy	18700.00
0005435682038	6728	Economy	18700.00
0005432533245	6728	Economy	18700.00
0005434828657	6728	Economy	18700.00
0005435437726	6728	Economy	18700.00
0005435682063	6728	Economy	17000.00
0005435682043	6728	Economy	17000.00
0005435217681	6728	Economy	17000.00
0005432136155	6728	Economy	17000.00
0005435682059	6728	Economy	17000.00
0005435682053	6728	Economy	17000.00
0005435682041	6728	Economy	17000.00
0005434828662	6728	Economy	17000.00
0005432136157	6728	Economy	17000.00
0005435682037	6728	Economy	17000.00
0005435437708	6728	Economy	17000.00
0005435437722	6728	Economy	17000.00
0005435682044	6728	Economy	17000.00
0005434828656	6728	Economy	17000.00
0005435630957	6728	Economy	17000.00
0005434828665	6728	Economy	17000.00
0005435682027	6728	Economy	17000.00
0005435217679	6728	Economy	17000.00
0005435217693	6728	Economy	17000.00
0005435630958	6728	Economy	17000.00
0005435682036	6728	Economy	17000.00
0005435630959	6728	Economy	17000.00
0005435682039	6728	Economy	17000.00
0005435217680	6728	Economy	17000.00
0005435682056	6728	Economy	17000.00
0005435682045	6728	Economy	17000.00
0005435682034	6728	Economy	17000.00
0005435437721	6728	Economy	17000.00
0005435661921	6728	Economy	17000.00
0005435682032	6728	Economy	17000.00
0005435437703	6728	Economy	17000.00
0005435437723	6728	Economy	17000.00
0005435682030	6728	Economy	17000.00
0005434828655	6728	Economy	17000.00
0005435217692	6728	Economy	17000.00
0005435682031	6728	Economy	17000.00
0005435437777	6728	Economy	17000.00
0005435437783	6728	Economy	17000.00
0005435661923	6728	Economy	17000.00
0005435682049	6728	Economy	17000.00
0005435682046	6728	Economy	17000.00
0005435682057	6728	Economy	17000.00
0005435682028	6728	Economy	17000.00
0005435682047	6728	Economy	17000.00
0005435682029	6728	Economy	17000.00
0005435682040	6728	Economy	17000.00
0005435682060	6728	Economy	17000.00
0005434828658	6728	Economy	17000.00
0005432533252	6728	Economy	17000.00
0005435682050	6728	Economy	17000.00
0005435220292	6728	Economy	17000.00
0005435682054	6728	Economy	17000.00
0005435217691	6728	Economy	17000.00
0005435437778	6728	Economy	17000.00
0005434828659	6728	Economy	17000.00
0005435437720	6728	Economy	17000.00
0005434828654	6728	Economy	17000.00
0005435682051	6728	Economy	17000.00
0005435682052	6728	Economy	17000.00
0005435437693	6728	Economy	17000.00
0005432533266	6728	Economy	17000.00
0005435437698	6728	Economy	17000.00
0005432136156	6728	Economy	17000.00
0005432533246	6728	Economy	17000.00
0005432533253	6728	Economy	17000.00
0005435681452	24573	Business	51100.00
0005435437894	24573	Business	51100.00
0005432305743	24573	Business	51100.00
0005435681749	24573	Business	51100.00
0005435681756	24573	Business	51100.00
0005435661891	24573	Business	51100.00
0005435681780	24573	Business	51100.00
0005435220313	24573	Business	51100.00
0005435219194	24573	Business	51100.00
0005434828692	24573	Business	51100.00
0005435681788	24573	Business	51100.00
0005435220311	24573	Economy	17000.00
0005435681787	24573	Economy	17000.00
0005435681617	24573	Economy	17000.00
0005432533286	24573	Economy	17000.00
0005435437901	24573	Economy	17000.00
0005435681558	24573	Economy	17000.00
0005435681747	24573	Economy	17000.00
0005435681568	24573	Economy	17000.00
0005435681585	24573	Economy	17000.00
0005435681767	24573	Economy	18700.00
0005435437908	24573	Economy	18700.00
0005435681642	24573	Economy	18700.00
0005435437898	24573	Economy	18700.00
0005435437907	24573	Economy	17000.00
0005435437911	24573	Economy	17000.00
0005435219195	24573	Economy	17000.00
0005435437910	24573	Economy	17000.00
0005435681598	24573	Economy	17000.00
0005435437909	24573	Economy	17000.00
0005435681740	24573	Economy	17000.00
0005435437900	24573	Economy	17000.00
0005435681604	24573	Economy	17000.00
0005435681634	24573	Economy	17000.00
0005435681755	24573	Economy	17000.00
0005435681757	24573	Economy	17000.00
0005435630929	24573	Economy	17000.00
0005434828693	24573	Economy	17000.00
0005435681758	24573	Economy	17000.00
0005435220312	24573	Economy	17000.00
0005435437893	24573	Economy	17000.00
0005435437903	24573	Economy	17000.00
0005435220315	24573	Economy	17000.00
0005435681445	24573	Economy	17000.00
0005435681644	24573	Economy	17000.00
0005435681655	24573	Economy	17000.00
0005435681722	24573	Economy	17000.00
0005435219192	24573	Economy	17000.00
0005435220490	24573	Economy	17000.00
0005435437895	24573	Economy	17000.00
0005435681748	24573	Economy	17000.00
0005435681687	24573	Economy	17000.00
0005435681510	24573	Economy	17000.00
0005432533285	24573	Economy	17000.00
0005435681741	24573	Economy	17000.00
0005435681599	24573	Economy	17000.00
0005435437897	24573	Economy	17000.00
0005435681641	24573	Economy	17000.00
0005435681793	24573	Economy	17000.00
0005435437904	24573	Economy	17000.00
0005435681554	24573	Economy	17000.00
0005435681623	24573	Economy	17000.00
0005435681789	24573	Economy	17000.00
0005435437902	24573	Economy	17000.00
0005435437899	24573	Economy	17000.00
0005435681538	24573	Economy	17000.00
0005435437913	24573	Economy	17000.00
0005435681746	24573	Economy	17000.00
0005435437914	24573	Economy	17000.00
0005432305744	24573	Economy	17000.00
0005435661880	24573	Economy	17000.00
0005435219193	24573	Economy	17000.00
0005435681654	24573	Economy	17000.00
0005435681734	24573	Economy	17000.00
0005435437896	24573	Economy	17000.00
0005434828691	24573	Economy	17000.00
0005435681603	24573	Economy	17000.00
0005435220314	24573	Economy	17000.00
0005435681569	24573	Economy	17000.00
0005435437905	24573	Economy	17000.00
0005435681792	24573	Economy	17000.00
0005435681446	24573	Economy	17000.00
0005435681719	24573	Economy	17000.00
0005435437912	24573	Economy	17000.00
0005435681693	24573	Economy	17000.00
0005435681720	24573	Economy	17000.00
0005435681773	24573	Economy	17000.00
0005435437906	24573	Economy	17000.00
0005435219196	24573	Economy	17000.00
0005435126232	11524	Business	26400.00
0005435126240	11524	Business	26400.00
0005435126257	11524	Business	26400.00
0005435126233	11524	Business	26400.00
0005435126261	11524	Business	26400.00
0005435126241	11524	Business	26400.00
0005435126250	11524	Business	26400.00
0005435126243	11524	Economy	8800.00
0005435126269	11524	Economy	8800.00
0005435126231	11524	Economy	8800.00
0005435126265	11524	Economy	8800.00
0005435098547	11524	Economy	8800.00
0005435105971	11524	Economy	9700.00
0005435098548	11524	Economy	9700.00
0005435126239	11524	Economy	9700.00
0005435126259	11524	Economy	9700.00
0005435126238	11524	Economy	8800.00
0005435098544	11524	Economy	8800.00
0005435105974	11524	Economy	8800.00
0005435126242	11524	Economy	8800.00
0005435126256	11524	Economy	8800.00
0005435126264	11524	Economy	8800.00
0005435126236	11524	Economy	8800.00
0005435126235	11524	Economy	8800.00
0005435126263	11524	Economy	8800.00
0005435105972	11524	Economy	8800.00
0005435098545	11524	Economy	8800.00
0005435105973	11524	Economy	8800.00
0005435126270	11524	Economy	8800.00
0005435126255	11524	Economy	8800.00
0005435126247	11524	Economy	8800.00
0005435126237	11524	Economy	8800.00
0005435126262	11524	Economy	8800.00
0005435126245	11524	Economy	8800.00
0005435126248	11524	Economy	8800.00
0005435098551	11524	Economy	8800.00
0005435126244	11524	Economy	8800.00
0005435126251	11524	Economy	8800.00
0005435098546	11524	Economy	8800.00
0005435126246	11524	Economy	8800.00
0005435126268	11524	Economy	8800.00
0005435098550	11524	Economy	8800.00
0005435126266	11524	Economy	8800.00
0005435126234	11524	Economy	8800.00
0005435126252	11524	Economy	8800.00
0005435126254	11524	Economy	8800.00
0005435126271	11524	Economy	8800.00
0005435126260	11524	Economy	8800.00
0005435126267	11524	Economy	8800.00
0005435126258	11524	Economy	8800.00
0005435126249	11524	Economy	8800.00
0005435126253	11524	Economy	8800.00
0005435098549	11524	Economy	8800.00
0005435125838	31855	Business	26400.00
0005435125858	31855	Business	26400.00
0005435125975	31855	Business	26400.00
0005435125951	31855	Business	26400.00
0005435125976	31855	Business	26400.00
0005435098530	31855	Economy	8800.00
0005435126012	31855	Economy	8800.00
0005435125868	31855	Economy	8800.00
0005435126041	31855	Economy	8800.00
0005435126030	31855	Economy	8800.00
0005435125961	31855	Economy	8800.00
0005435126013	31855	Economy	8800.00
0005435125944	31855	Economy	9700.00
0005435125978	31855	Economy	9700.00
0005435126037	31855	Economy	9700.00
0005435125826	31855	Economy	8800.00
0005435126101	31855	Economy	8800.00
0005435126112	31855	Economy	8800.00
0005435125829	31855	Economy	8800.00
0005435125942	31855	Economy	8800.00
0005435125902	31855	Economy	8800.00
0005435558082	31855	Economy	8800.00
0005435125970	31855	Economy	8800.00
0005435125837	31855	Economy	8800.00
0005435125903	31855	Economy	8800.00
0005435126035	31855	Economy	8800.00
0005435125989	31855	Economy	8800.00
0005435126014	31855	Economy	8800.00
0005435125880	31855	Economy	8800.00
0005435125865	31855	Economy	8800.00
0005435125848	31855	Economy	8800.00
0005435125946	31855	Economy	8800.00
0005435125960	31855	Economy	8800.00
0005435125859	31855	Economy	8800.00
0005435125977	31855	Economy	8800.00
0005435126060	31855	Economy	8800.00
0005435098537	31855	Economy	8800.00
0005435126061	31855	Economy	8800.00
0005435126100	31855	Economy	8800.00
0005435125996	31855	Economy	8800.00
0005435126074	31855	Economy	8800.00
0005435126036	31855	Economy	8800.00
0005435098536	31855	Economy	8800.00
0005435125964	31855	Economy	8800.00
0005435126116	31855	Economy	8800.00
0005435126079	31855	Economy	8800.00
0005435125990	31855	Economy	8800.00
0005435126001	31855	Economy	8800.00
0005435558081	31855	Economy	8800.00
0005435125888	31855	Economy	8800.00
0005435125945	31855	Economy	8800.00
0005435126018	31855	Economy	8800.00
0005433397953	13535	Business	36600.00
0005433397931	13535	Business	36600.00
0005433397955	13535	Business	36600.00
0005435732223	13535	Business	36600.00
0005433397928	13535	Business	36600.00
0005435732184	13535	Business	36600.00
0005433397942	13535	Business	36600.00
0005435732183	13535	Business	36600.00
0005433397925	13535	Economy	12200.00
0005433397945	13535	Economy	12200.00
0005433397933	13535	Economy	12200.00
0005433397943	13535	Economy	12200.00
0005433397957	13535	Economy	12200.00
0005433397950	13535	Economy	12200.00
0005435732190	13535	Economy	12200.00
0005433397926	13535	Economy	13400.00
0005433397930	13535	Economy	13400.00
0005433397939	13535	Economy	13400.00
0005433397959	13535	Economy	12200.00
0005433397971	13535	Economy	12200.00
0005433397929	13535	Economy	12200.00
0005435732230	13535	Economy	12200.00
0005433397936	13535	Economy	12200.00
0005433397973	13535	Economy	12200.00
0005433397972	13535	Economy	12200.00
0005433397946	13535	Economy	12200.00
0005433397952	13535	Economy	12200.00
0005433397960	13535	Economy	12200.00
0005433397948	13535	Economy	12200.00
0005433397937	13535	Economy	12200.00
0005433397944	13535	Economy	12200.00
0005435732229	13535	Economy	12200.00
0005433397951	13535	Economy	12200.00
0005433397947	13535	Economy	12200.00
0005433397954	13535	Economy	12200.00
0005433397970	13535	Economy	12200.00
0005433397935	13535	Economy	12200.00
0005433397927	13535	Economy	12200.00
0005435732185	13535	Economy	12200.00
0005433397934	13535	Economy	12200.00
0005433397966	13535	Economy	12200.00
0005433397968	13535	Economy	12200.00
0005435732224	13535	Economy	12200.00
0005433397932	13535	Economy	12200.00
0005433397963	13535	Economy	12200.00
0005435732210	13535	Economy	12200.00
0005433397940	13535	Economy	12200.00
0005433397969	13535	Economy	12200.00
0005433397938	13535	Economy	12200.00
0005433397961	13535	Economy	12200.00
0005433397974	13535	Economy	12200.00
0005435732231	13535	Economy	12200.00
0005433397949	13535	Economy	12200.00
0005433397962	13535	Economy	12200.00
0005433397967	13535	Economy	12200.00
0005433397964	13535	Economy	12200.00
0005435732209	13535	Economy	12200.00
0005433397956	13535	Economy	12200.00
0005433397965	13535	Economy	12200.00
0005433397941	13535	Economy	12200.00
0005433397958	13535	Economy	12200.00
0005433397454	19391	Business	36600.00
0005433397723	19391	Business	36600.00
0005433397606	19391	Business	36600.00
0005435732294	19391	Business	36600.00
0005433397365	19391	Business	36600.00
0005433397475	19391	Business	36600.00
0005435732300	19391	Business	36600.00
0005433397393	19391	Business	36600.00
0005433397484	19391	Business	36600.00
0005433397379	19391	Business	36600.00
0005433397607	19391	Business	36600.00
0005435732295	19391	Economy	12200.00
0005432297273	19391	Economy	12200.00
0005435732301	19391	Economy	12200.00
0005433397449	19391	Economy	12200.00
0005433397310	19391	Economy	12200.00
0005435732298	19391	Economy	12200.00
0005435732310	19391	Economy	13400.00
0005433397561	19391	Economy	13400.00
0005435732299	19391	Economy	13400.00
0005433397392	19391	Economy	12200.00
0005435732293	19391	Economy	12200.00
0005435732311	19391	Economy	12200.00
0005433397412	19391	Economy	12200.00
0005433397649	19391	Economy	12200.00
0005435732314	19391	Economy	12200.00
0005435732296	19391	Economy	12200.00
0005435732297	19391	Economy	12200.00
0005433397513	19391	Economy	12200.00
0005432297272	19391	Economy	12200.00
0005433397615	19391	Economy	12200.00
0005433397711	19391	Economy	12200.00
0005435732313	19391	Economy	12200.00
0005435732303	19391	Economy	12200.00
0005433397710	19391	Economy	12200.00
0005435732302	19391	Economy	12200.00
0005435732315	19391	Economy	12200.00
0005435732308	19391	Economy	12200.00
0005435732305	19391	Economy	12200.00
0005435732312	19391	Economy	12200.00
0005433397451	19391	Economy	12200.00
0005433397499	19391	Economy	12200.00
0005433397464	19391	Economy	12200.00
0005433397483	19391	Economy	12200.00
0005435732309	19391	Economy	12200.00
0005433397406	19391	Economy	12200.00
0005435732307	19391	Economy	12200.00
0005433397560	19391	Economy	12200.00
0005432297271	19391	Economy	12200.00
0005433397599	19391	Economy	12200.00
0005435732304	19391	Economy	12200.00
0005435732316	19391	Economy	12200.00
0005433397358	19391	Economy	12200.00
0005433397442	19391	Economy	12200.00
0005433397538	19391	Economy	12200.00
0005433397364	19391	Economy	12200.00
0005433397616	19391	Economy	12200.00
0005435732306	19391	Economy	12200.00
0005433397559	19391	Economy	12200.00
0005433397450	19391	Economy	12200.00
0005433397409	19391	Economy	12200.00
0005433397549	19391	Economy	12200.00
0005433397463	19391	Economy	12200.00
0005433397514	19391	Economy	12200.00
0005433397712	19391	Economy	12200.00
0005435068469	13178	Business	11300.00
0005435925272	13178	Business	11300.00
0005435068396	13178	Business	11300.00
0005435068625	13178	Business	11300.00
0005435925275	13178	Business	11300.00
0005435068308	13178	Business	11300.00
0005435068573	13178	Business	11300.00
0005435068510	13178	Business	11300.00
0005435925271	13178	Economy	3800.00
0005435068555	13178	Economy	3800.00
0005435068375	13178	Economy	3800.00
0005435068423	13178	Economy	3800.00
0005435068288	13178	Economy	3800.00
0005435068345	13178	Economy	3800.00
0005435068534	13178	Economy	3800.00
0005435068376	13178	Economy	4100.00
0005435925277	13178	Economy	4100.00
0005435068571	13178	Economy	4100.00
0005435925269	13178	Economy	3800.00
0005435068203	13178	Economy	3800.00
0005435068478	13178	Economy	3800.00
0005435068464	13178	Economy	3800.00
0005435068655	13178	Economy	3800.00
0005435068732	13178	Economy	3800.00
0005435068204	13178	Economy	3800.00
0005435068304	13178	Economy	3800.00
0005435068570	13178	Economy	3800.00
0005435068605	13178	Economy	3800.00
0005435068392	13178	Economy	3800.00
0005435068443	13178	Economy	3800.00
0005435068395	13178	Economy	3800.00
0005435068585	13178	Economy	3800.00
0005435068450	13178	Economy	3800.00
0005435068654	13178	Economy	3800.00
0005435068616	13178	Economy	3800.00
0005435068437	13178	Economy	3800.00
0005435068479	13178	Economy	3800.00
0005435068554	13178	Economy	3800.00
0005435068309	13178	Economy	3800.00
0005435068460	13178	Economy	3800.00
0005435068525	13178	Economy	3800.00
0005435068574	13178	Economy	3800.00
0005435068511	13178	Economy	3800.00
0005435068548	13178	Economy	3800.00
0005435068379	13178	Economy	3800.00
0005435068577	13178	Economy	3800.00
0005435068572	13178	Economy	3800.00
0005435068344	13178	Economy	3800.00
0005435068427	13178	Economy	3800.00
0005435925276	13178	Economy	3800.00
0005435068660	13178	Economy	3800.00
0005435068576	13178	Economy	3800.00
0005435925270	13178	Economy	3800.00
0005435068661	13178	Economy	3800.00
0005435068459	13178	Economy	3800.00
0005435068604	13178	Economy	3800.00
0005435925273	13178	Economy	3800.00
0005435068330	13178	Economy	3800.00
0005435068325	13178	Economy	3800.00
0005435068590	13178	Economy	3800.00
0005435068545	13178	Economy	3800.00
0005435068566	13178	Economy	3800.00
0005435068320	13178	Economy	3800.00
0005435068353	13178	Economy	3800.00
0005435925274	13178	Economy	3800.00
0005435068431	13178	Economy	3800.00
0005435068584	13178	Economy	3800.00
0005435068932	15511	Business	11300.00
0005435068918	15511	Business	11300.00
0005435068940	15511	Business	11300.00
0005435925148	15511	Business	11300.00
0005435068927	15511	Business	11300.00
0005435925109	15511	Business	11300.00
0005435068928	15511	Business	11300.00
0005435068916	15511	Economy	3800.00
0005435068933	15511	Economy	3800.00
0005435068939	15511	Economy	3800.00
0005435068944	15511	Economy	3800.00
0005435068917	15511	Economy	3800.00
0005435068921	15511	Economy	3800.00
0005435068906	15511	Economy	3800.00
0005435068929	15511	Economy	4100.00
0005435068934	15511	Economy	4100.00
0005435068952	15511	Economy	4100.00
0005435068931	15511	Economy	3800.00
0005435068913	15511	Economy	3800.00
0005435068946	15511	Economy	3800.00
0005435068951	15511	Economy	3800.00
0005435068920	15511	Economy	3800.00
0005435068949	15511	Economy	3800.00
0005435068945	15511	Economy	3800.00
0005435068907	15511	Economy	3800.00
0005435068903	15511	Economy	3800.00
0005435068926	15511	Economy	3800.00
0005435068915	15511	Economy	3800.00
0005435068948	15511	Economy	3800.00
0005435068909	15511	Economy	3800.00
0005435068910	15511	Economy	3800.00
0005435068950	15511	Economy	3800.00
0005435068914	15511	Economy	3800.00
0005435925147	15511	Economy	3800.00
0005435068901	15511	Economy	3800.00
0005435925073	15511	Economy	3800.00
0005435068935	15511	Economy	3800.00
0005435068923	15511	Economy	3800.00
0005435068919	15511	Economy	3800.00
0005435068922	15511	Economy	3800.00
0005435925142	15511	Economy	3800.00
0005435925126	15511	Economy	3800.00
0005435068908	15511	Economy	3800.00
0005435068942	15511	Economy	3800.00
0005435925146	15511	Economy	3800.00
0005435068941	15511	Economy	3800.00
0005435068925	15511	Economy	3800.00
0005435068936	15511	Economy	3800.00
0005435068905	15511	Economy	3800.00
0005435068938	15511	Economy	3800.00
0005435068912	15511	Economy	3800.00
0005435068924	15511	Economy	3800.00
0005435068902	15511	Economy	3800.00
0005435068904	15511	Economy	3800.00
0005435925114	15511	Economy	3800.00
0005435068911	15511	Economy	3800.00
0005435068930	15511	Economy	3800.00
0005435925169	15511	Economy	3800.00
0005435068943	15511	Economy	3800.00
0005435925127	15511	Economy	3800.00
0005435068947	15511	Economy	3800.00
0005435068937	15511	Economy	3800.00
0005435925061	15511	Economy	3800.00
0005435808194	23188	Economy	27100.00
0005433407491	23188	Economy	27100.00
0005435808208	23188	Economy	24700.00
0005435808203	23188	Economy	24700.00
0005433407505	23188	Economy	24700.00
0005435808201	23188	Economy	24700.00
0005435808205	23188	Economy	24700.00
0005435808190	23188	Economy	24700.00
0005435808189	23188	Economy	24700.00
0005435808200	23188	Economy	24700.00
0005435808188	23188	Economy	24700.00
0005435808207	23188	Economy	24700.00
0005435808191	23188	Economy	24700.00
0005435808195	23188	Economy	24700.00
0005435808197	23188	Economy	24700.00
0005433407506	23188	Economy	24700.00
0005435808192	23188	Economy	24700.00
0005435808193	23188	Economy	24700.00
0005435808206	23188	Economy	24700.00
0005433407496	23188	Economy	24700.00
0005435808199	23188	Economy	24700.00
0005435808202	23188	Economy	24700.00
0005435808204	23188	Economy	24700.00
0005435808196	23188	Economy	24700.00
0005433407482	23188	Economy	24700.00
0005433407495	23188	Economy	24700.00
0005435808198	23188	Economy	24700.00
0005434755920	10703	Business	61300.00
0005434214456	10703	Business	61300.00
0005434755991	10703	Business	61300.00
0005434214447	10703	Business	61300.00
0005434214438	10703	Business	61300.00
0005434755956	10703	Business	61300.00
0005434214437	10703	Business	61300.00
0005434214440	10703	Business	61300.00
0005434755796	10703	Business	61300.00
0005434755855	10703	Business	61300.00
0005434214439	10703	Business	61300.00
0005434755977	10703	Economy	20400.00
0005434214419	10703	Economy	20400.00
0005434214441	10703	Economy	20400.00
0005434214452	10703	Economy	20400.00
0005434214434	10703	Economy	20400.00
0005434755881	10703	Economy	20400.00
0005434214420	10703	Economy	20400.00
0005434214425	10703	Economy	20400.00
0005434214422	10703	Economy	20400.00
0005434214423	10703	Economy	22500.00
0005434755910	10703	Economy	22500.00
0005434214444	10703	Economy	22500.00
0005434755909	10703	Economy	22500.00
0005434755980	10703	Economy	20400.00
0005434755990	10703	Economy	20400.00
0005434214415	10703	Economy	20400.00
0005434214445	10703	Economy	20400.00
0005434214429	10703	Economy	20400.00
0005434755865	10703	Economy	20400.00
0005434755845	10703	Economy	20400.00
0005434214457	10703	Economy	20400.00
0005434755997	10703	Economy	20400.00
0005434214451	10703	Economy	20400.00
0005434214443	10703	Economy	20400.00
0005434214418	10703	Economy	20400.00
0005434755880	10703	Economy	20400.00
0005434214421	10703	Economy	20400.00
0005434214435	10703	Economy	20400.00
0005434214417	10703	Economy	20400.00
0005434214428	10703	Economy	20400.00
0005434755854	10703	Economy	20400.00
0005434755950	10703	Economy	20400.00
0005434214454	10703	Economy	20400.00
0005434755949	10703	Economy	20400.00
0005434214416	10703	Economy	20400.00
0005434755973	10703	Economy	20400.00
0005434755853	10703	Economy	20400.00
0005434755861	10703	Economy	20400.00
0005434214413	10703	Economy	20400.00
0005434214436	10703	Economy	20400.00
0005434755925	10703	Economy	20400.00
0005434214426	10703	Economy	20400.00
0005434755795	10703	Economy	20400.00
0005434755862	10703	Economy	20400.00
0005434214449	10703	Economy	20400.00
0005434214432	10703	Economy	20400.00
0005434755996	10703	Economy	20400.00
0005434756004	10703	Economy	20400.00
0005434214430	10703	Economy	20400.00
0005434214453	10703	Economy	20400.00
0005434214450	10703	Economy	20400.00
0005434755921	10703	Economy	20400.00
0005434755939	10703	Economy	20400.00
0005434214427	10703	Economy	20400.00
0005434755994	10703	Economy	20400.00
0005434755709	10703	Economy	20400.00
0005434214433	10703	Economy	20400.00
0005434755868	10703	Economy	20400.00
0005434214442	10703	Economy	20400.00
0005434755938	10703	Economy	20400.00
0005434755846	10703	Economy	20400.00
0005434214424	10703	Economy	20400.00
0005434755872	10703	Economy	20400.00
0005434214448	10703	Economy	20400.00
0005434214446	10703	Economy	20400.00
0005434214431	10703	Economy	20400.00
0005434756005	10703	Economy	20400.00
0005434756006	10703	Economy	20400.00
0005434214414	10703	Economy	20400.00
0005434755783	10703	Economy	20400.00
0005434755926	10703	Economy	20400.00
0005434755955	10703	Economy	20400.00
0005434214458	10703	Economy	20400.00
0005434755879	10703	Economy	20400.00
0005434755871	10703	Economy	20400.00
0005434755976	10703	Economy	20400.00
0005434755892	10703	Economy	20400.00
0005434755912	10703	Economy	20400.00
0005434755899	10703	Economy	20400.00
0005434214455	10703	Economy	20400.00
0005434755981	10703	Economy	20400.00
0005434213899	28708	Business	61300.00
0005434214059	28708	Business	61300.00
0005434213885	28708	Business	61300.00
0005434213830	28708	Business	61300.00
0005434756299	28708	Business	61300.00
0005434756311	28708	Business	61300.00
0005434756313	28708	Business	61300.00
0005434213833	28708	Business	61300.00
0005434213915	28708	Business	61300.00
0005434756289	28708	Business	61300.00
0005434214047	28708	Business	61300.00
0005434214004	28708	Business	61300.00
0005434756315	28708	Economy	20400.00
0005434756292	28708	Economy	20400.00
0005434214036	28708	Economy	20400.00
0005434756308	28708	Economy	20400.00
0005434756326	28708	Economy	20400.00
0005434213985	28708	Economy	20400.00
0005434213995	28708	Economy	20400.00
0005434214104	28708	Economy	20400.00
0005434756295	28708	Economy	20400.00
0005434756323	28708	Economy	20400.00
0005434756317	28708	Economy	22500.00
0005434756328	28708	Economy	22500.00
0005434214019	28708	Economy	22500.00
0005434213935	28708	Economy	22500.00
0005434213986	28708	Economy	22500.00
0005434756327	28708	Economy	20400.00
0005434213954	28708	Economy	20400.00
0005434213993	28708	Economy	20400.00
0005434756319	28708	Economy	20400.00
0005434756301	28708	Economy	20400.00
0005434756302	28708	Economy	20400.00
0005434756306	28708	Economy	20400.00
0005434756298	28708	Economy	20400.00
0005434756318	28708	Economy	20400.00
0005434756293	28708	Economy	20400.00
0005434213782	28708	Economy	20400.00
0005434213984	28708	Economy	20400.00
0005434213852	28708	Economy	20400.00
0005434213944	28708	Economy	20400.00
0005434756321	28708	Economy	20400.00
0005434756294	28708	Economy	20400.00
0005434213862	28708	Economy	20400.00
0005434213987	28708	Economy	20400.00
0005434756304	28708	Economy	20400.00
0005434213924	28708	Economy	20400.00
0005434756297	28708	Economy	20400.00
0005434756303	28708	Economy	20400.00
0005434213942	28708	Economy	20400.00
0005434756322	28708	Economy	20400.00
0005434213889	28708	Economy	20400.00
0005434214109	28708	Economy	20400.00
0005434756316	28708	Economy	20400.00
0005434756320	28708	Economy	20400.00
0005434213988	28708	Economy	20400.00
0005434213914	28708	Economy	20400.00
0005434214108	28708	Economy	20400.00
0005434213834	28708	Economy	20400.00
0005434756305	28708	Economy	20400.00
0005434213781	28708	Economy	20400.00
0005434756310	28708	Economy	20400.00
0005434213824	28708	Economy	20400.00
0005434213823	28708	Economy	20400.00
0005434756324	28708	Economy	20400.00
0005434756325	28708	Economy	20400.00
0005434756287	28708	Economy	20400.00
0005434756300	28708	Economy	20400.00
0005434213943	28708	Economy	20400.00
0005434214029	28708	Economy	20400.00
0005434213878	28708	Economy	20400.00
0005434756309	28708	Economy	20400.00
0005434756312	28708	Economy	20400.00
0005434213907	28708	Economy	20400.00
0005434756314	28708	Economy	20400.00
0005434213939	28708	Economy	20400.00
0005434213971	28708	Economy	20400.00
0005434213931	28708	Economy	20400.00
0005434756290	28708	Economy	20400.00
0005434214046	28708	Economy	20400.00
0005434213956	28708	Economy	20400.00
0005434756288	28708	Economy	20400.00
0005434756291	28708	Economy	20400.00
0005434213848	28708	Economy	20400.00
0005434213955	28708	Economy	20400.00
0005434756296	28708	Economy	20400.00
0005434756307	28708	Economy	20400.00
0005434213957	28708	Economy	20400.00
0005434214057	28708	Economy	20400.00
0005434214025	28708	Economy	20400.00
0005434213994	28708	Economy	20400.00
0005434213817	28708	Economy	20400.00
0005434213932	28708	Economy	20400.00
0005435039604	5427	Business	29500.00
0005435039627	5427	Business	29500.00
0005435039609	5427	Business	29500.00
0005435006978	5427	Business	29500.00
0005435039606	5427	Business	29500.00
0005435042855	5427	Business	29500.00
0005435039605	5427	Business	29500.00
0005435039641	5427	Business	29500.00
0005435039646	5427	Business	29500.00
0005435039644	5427	Business	29500.00
0005435039658	5427	Economy	9800.00
0005435039600	5427	Economy	9800.00
0005435039614	5427	Economy	9800.00
0005435039659	5427	Economy	9800.00
0005435039653	5427	Economy	9800.00
0005435039610	5427	Economy	9800.00
0005432125438	5427	Economy	9800.00
0005435039620	5427	Economy	9800.00
0005434229151	5427	Economy	9800.00
0005434229088	5427	Economy	9800.00
0005435039639	5427	Economy	9800.00
0005435039602	5427	Economy	9800.00
0005435006980	5427	Economy	9800.00
0005434229089	5427	Economy	9800.00
0005435006985	5427	Economy	9800.00
0005432125434	5427	Economy	9800.00
0005435039636	5427	Economy	9800.00
0005435039626	5427	Economy	9800.00
0005435042853	5427	Economy	9800.00
0005435006975	5427	Economy	9800.00
0005435039603	5427	Economy	9800.00
0005435039632	5427	Economy	9800.00
0005434229115	5427	Economy	9800.00
0005432125437	5427	Economy	9800.00
0005435039628	5427	Economy	9800.00
0005435039608	5427	Economy	9800.00
0005435039635	5427	Economy	9800.00
0005435039650	5427	Economy	9800.00
0005435039655	5427	Economy	9800.00
0005435006990	5427	Economy	9800.00
0005432125435	5427	Economy	9800.00
0005435039652	5427	Economy	9800.00
0005435006989	5427	Economy	9800.00
0005434229181	5427	Economy	9800.00
0005435039645	5427	Economy	9800.00
0005435039657	5427	Economy	9800.00
0005435006974	5427	Economy	9800.00
0005435039622	5427	Economy	9800.00
0005435039647	5427	Economy	10800.00
0005435039630	5427	Economy	10800.00
0005434228993	5427	Economy	10800.00
0005435039617	5427	Economy	10800.00
0005435039623	5427	Economy	10800.00
0005435039667	5427	Economy	9800.00
0005435006994	5427	Economy	10800.00
0005435039634	5427	Economy	9800.00
0005434229137	5427	Economy	9800.00
0005435006984	5427	Economy	9800.00
0005435006969	5427	Economy	9800.00
0005435039662	5427	Economy	9800.00
0005435039668	5427	Economy	9800.00
0005435039624	5427	Economy	9800.00
0005435006976	5427	Economy	9800.00
0005435006982	5427	Economy	9800.00
0005435006987	5427	Economy	9800.00
0005435039607	5427	Economy	9800.00
0005435039642	5427	Economy	9800.00
0005435039663	5427	Economy	9800.00
0005435006992	5427	Economy	9800.00
0005435039615	5427	Economy	9800.00
0005434229152	5427	Economy	9800.00
0005435039612	5427	Economy	9800.00
0005435039665	5427	Economy	9800.00
0005434229066	5427	Economy	9800.00
0005434229110	5427	Economy	9800.00
0005435039618	5427	Economy	9800.00
0005434229081	5427	Economy	9800.00
0005435006973	5427	Economy	9800.00
0005435039651	5427	Economy	9800.00
0005435006979	5427	Economy	9800.00
0005432125436	5427	Economy	9800.00
0005435039616	5427	Economy	9800.00
0005435039633	5427	Economy	9800.00
0005435006986	5427	Economy	9800.00
0005432125432	5427	Economy	9800.00
0005435006981	5427	Economy	9800.00
0005435039654	5427	Economy	9800.00
0005435039643	5427	Economy	9800.00
0005435006983	5427	Economy	9800.00
0005435006977	5427	Economy	9800.00
0005435039613	5427	Economy	9800.00
0005435006993	5427	Economy	9800.00
0005435039649	5427	Economy	9800.00
0005435006972	5427	Economy	9800.00
0005435039666	5427	Economy	9800.00
0005435039625	5427	Economy	9800.00
0005435039601	5427	Economy	9800.00
0005435006970	5427	Economy	9800.00
0005435039660	5427	Economy	9800.00
0005432125433	5427	Economy	9800.00
0005434229216	5427	Economy	9800.00
0005435039631	5427	Economy	9800.00
0005434229125	5427	Economy	9800.00
0005435039621	5427	Economy	9800.00
0005434229189	5427	Economy	9800.00
0005435039664	5427	Economy	9800.00
0005435006991	5427	Economy	9800.00
0005435039638	5427	Economy	9800.00
0005435039656	5427	Economy	9800.00
0005435006988	5427	Economy	9800.00
0005435039629	5427	Economy	9800.00
0005435039640	5427	Economy	9800.00
0005435043285	5427	Economy	9800.00
0005434229160	5427	Economy	9800.00
0005435039637	5427	Economy	9800.00
0005435039611	5427	Economy	9800.00
0005435042852	5427	Economy	9800.00
0005435039661	5427	Economy	9800.00
0005434229103	5427	Economy	9800.00
0005435042854	5427	Economy	9800.00
0005435039648	5427	Economy	9800.00
0005435039619	5427	Economy	9800.00
0005435006971	5427	Economy	9800.00
0005435039377	13007	Business	29500.00
0005435038714	13007	Business	29500.00
0005434229320	13007	Business	29500.00
0005435038791	13007	Business	29500.00
0005435006739	13007	Business	29500.00
0005434229326	13007	Business	29500.00
0005435042833	13007	Business	29500.00
0005435039318	13007	Business	29500.00
0005435042835	13007	Business	29500.00
0005435039002	13007	Economy	9800.00
0005434229321	13007	Economy	9800.00
0005435039248	13007	Economy	9800.00
0005435039077	13007	Economy	9800.00
0005435038946	13007	Economy	9800.00
0005434229324	13007	Economy	9800.00
0005435006852	13007	Economy	9800.00
0005435006776	13007	Economy	9800.00
0005435038972	13007	Economy	9800.00
0005435006738	13007	Economy	9800.00
0005435039078	13007	Economy	9800.00
0005432304391	13007	Economy	9800.00
0005435006798	13007	Economy	9800.00
0005435006815	13007	Economy	9800.00
0005435006737	13007	Economy	9800.00
0005435039168	13007	Economy	9800.00
0005435038885	13007	Economy	9800.00
0005434229327	13007	Economy	9800.00
0005435039076	13007	Economy	9800.00
0005434229334	13007	Economy	9800.00
0005435006723	13007	Economy	9800.00
0005435039110	13007	Economy	9800.00
0005435006705	13007	Economy	9800.00
0005435039059	13007	Economy	9800.00
0005435039026	13007	Economy	9800.00
0005435038790	13007	Economy	9800.00
0005435006823	13007	Economy	9800.00
0005435039063	13007	Economy	9800.00
0005434229325	13007	Economy	9800.00
0005435006794	13007	Economy	9800.00
0005434229316	13007	Economy	9800.00
0005435006753	13007	Economy	9800.00
0005435038892	13007	Economy	10800.00
0005435039279	13007	Economy	10800.00
0005435038924	13007	Economy	10800.00
0005434229332	13007	Economy	10800.00
0005434229336	13007	Economy	10800.00
0005435038928	13007	Economy	9800.00
0005435039061	13007	Economy	9800.00
0005434229313	13007	Economy	9800.00
0005435038985	13007	Economy	9800.00
0005435042826	13007	Economy	9800.00
0005435006726	13007	Economy	9800.00
0005435039117	13007	Economy	9800.00
0005435038956	13007	Economy	9800.00
0005435006818	13007	Economy	9800.00
0005434229328	13007	Economy	9800.00
0005435006730	13007	Economy	9800.00
0005435038827	13007	Economy	9800.00
0005435006745	13007	Economy	9800.00
0005435039297	13007	Economy	9800.00
0005435006799	13007	Economy	9800.00
0005435038792	13007	Economy	9800.00
0005435039084	13007	Economy	9800.00
0005435039167	13007	Economy	9800.00
0005434229317	13007	Economy	9800.00
0005435006752	13007	Economy	9800.00
0005435039109	13007	Economy	9800.00
0005434229333	13007	Economy	9800.00
0005434229315	13007	Economy	9800.00
0005435039118	13007	Economy	9800.00
0005434229330	13007	Economy	9800.00
0005435038994	13007	Economy	9800.00
0005435042828	13007	Economy	9800.00
0005435039116	13007	Economy	9800.00
0005435006706	13007	Economy	9800.00
0005432304389	13007	Economy	9800.00
0005434229335	13007	Economy	9800.00
0005435006816	13007	Economy	9800.00
0005435039237	13007	Economy	9800.00
0005434229318	13007	Economy	9800.00
0005435039062	13007	Economy	9800.00
0005435038935	13007	Economy	9800.00
0005435006750	13007	Economy	9800.00
0005435006800	13007	Economy	9800.00
0005435039079	13007	Economy	9800.00
0005432304390	13007	Economy	9800.00
0005435039323	13007	Economy	9800.00
0005434229323	13007	Economy	9800.00
0005435006740	13007	Economy	9800.00
0005432304388	13007	Economy	9800.00
0005435042836	13007	Economy	9800.00
0005434229329	13007	Economy	9800.00
0005435038894	13007	Economy	9800.00
0005435006725	13007	Economy	9800.00
0005435038999	13007	Economy	9800.00
0005435039317	13007	Economy	9800.00
0005435038938	13007	Economy	9800.00
0005434229331	13007	Economy	9800.00
0005435038907	13007	Economy	9800.00
0005435039081	13007	Economy	9800.00
0005434229319	13007	Economy	9800.00
0005435042827	13007	Economy	9800.00
0005435039080	13007	Economy	9800.00
0005434229314	13007	Economy	9800.00
0005435038995	13007	Economy	9800.00
0005434229322	13007	Economy	9800.00
0005435902497	14868	Business	52900.00
0005434426528	14868	Business	52900.00
0005434426531	14868	Business	52900.00
0005434426512	14868	Business	52900.00
0005435554113	14868	Business	52900.00
0005434426532	14868	Business	52900.00
0005435902478	14868	Business	52900.00
0005434426519	14868	Business	52900.00
0005435902518	14868	Economy	17600.00
0005435554120	14868	Economy	17600.00
0005435902526	14868	Economy	17600.00
0005432188599	14868	Economy	17600.00
0005434426522	14868	Economy	17600.00
0005434426521	14868	Economy	17600.00
0005434411766	14868	Economy	17600.00
0005435902510	14868	Economy	17600.00
0005434426511	14868	Economy	19400.00
0005434426526	14868	Economy	19400.00
0005435902485	14868	Economy	19400.00
0005435902496	14868	Economy	19400.00
0005435554131	14868	Economy	19400.00
0005435902494	14868	Economy	17600.00
0005434426533	14868	Economy	17600.00
0005434426510	14868	Economy	17600.00
0005434426509	14868	Economy	17600.00
0005434426534	14868	Economy	17600.00
0005434426516	14868	Economy	17600.00
0005434426523	14868	Economy	17600.00
0005435554135	14868	Economy	17600.00
0005434426537	14868	Economy	17600.00
0005434426513	14868	Economy	17600.00
0005435902511	14868	Economy	17600.00
0005434426520	14868	Economy	17600.00
0005435902527	14868	Economy	17600.00
0005434411764	14868	Economy	17600.00
0005435554106	14868	Economy	17600.00
0005434426517	14868	Economy	17600.00
0005434426508	14868	Economy	17600.00
0005434426506	14868	Economy	17600.00
0005435902479	14868	Economy	17600.00
0005434426515	14868	Economy	17600.00
0005434411767	14868	Economy	17600.00
0005435554119	14868	Economy	17600.00
0005434426525	14868	Economy	17600.00
0005434426518	14868	Economy	17600.00
0005435902514	14868	Economy	17600.00
0005435902450	14868	Economy	17600.00
0005434426514	14868	Economy	17600.00
0005435902465	14868	Economy	17600.00
0005435902490	14868	Economy	17600.00
0005435902525	14868	Economy	17600.00
0005434426524	14868	Economy	17600.00
0005435554107	14868	Economy	17600.00
0005434426527	14868	Economy	17600.00
0005432188598	14868	Economy	17600.00
0005434426536	14868	Economy	17600.00
0005434426530	14868	Economy	17600.00
0005435554108	14868	Economy	17600.00
0005434426535	14868	Economy	17600.00
0005435902513	14868	Economy	17600.00
0005434426507	14868	Economy	17600.00
0005434426529	14868	Economy	17600.00
0005435902509	14868	Economy	17600.00
0005434411765	14868	Economy	17600.00
0005434426226	20228	Business	52900.00
0005435902661	20228	Business	52900.00
0005432059500	20228	Business	52900.00
0005434426364	20228	Business	52900.00
0005435902673	20228	Business	52900.00
0005434426298	20228	Business	52900.00
0005434426208	20228	Economy	17600.00
0005434426299	20228	Economy	17600.00
0005434426354	20228	Economy	17600.00
0005434411705	20228	Economy	17600.00
0005434426203	20228	Economy	17600.00
0005432059499	20228	Economy	17600.00
0005435554178	20228	Economy	17600.00
0005434426225	20228	Economy	17600.00
0005435902671	20228	Economy	19400.00
0005434426330	20228	Economy	17600.00
0005434411706	20228	Economy	17600.00
0005434426320	20228	Economy	17600.00
0005434426340	20228	Economy	17600.00
0005434411727	20228	Economy	17600.00
0005434426404	20228	Economy	17600.00
0005434426234	20228	Economy	17600.00
0005435902667	20228	Economy	17600.00
0005434426291	20228	Economy	17600.00
0005435902669	20228	Economy	17600.00
0005434426423	20228	Economy	17600.00
0005435902660	20228	Economy	17600.00
0005434426121	20228	Economy	17600.00
0005434426235	20228	Economy	17600.00
0005435902662	20228	Economy	17600.00
0005435902666	20228	Economy	17600.00
0005434426353	20228	Economy	17600.00
0005434411736	20228	Economy	17600.00
0005434426341	20228	Economy	17600.00
0005435902659	20228	Economy	17600.00
0005435902674	20228	Economy	17600.00
0005434426415	20228	Economy	17600.00
0005435554179	20228	Economy	17600.00
0005435902665	20228	Economy	17600.00
0005434426314	20228	Economy	17600.00
0005434426355	20228	Economy	17600.00
0005434426414	20228	Economy	17600.00
0005435902668	20228	Economy	17600.00
0005434426309	20228	Economy	17600.00
0005435902670	20228	Economy	17600.00
0005435902663	20228	Economy	17600.00
0005434426297	20228	Economy	17600.00
0005435902658	20228	Economy	17600.00
0005434426405	20228	Economy	17600.00
0005434411735	20228	Economy	17600.00
0005434411737	20228	Economy	17600.00
0005434426176	20228	Economy	17600.00
0005435554181	20228	Economy	17600.00
0005434426313	20228	Economy	17600.00
0005435902672	20228	Economy	17600.00
0005435554177	20228	Economy	17600.00
0005435902664	20228	Economy	17600.00
0005435554180	20228	Economy	17600.00
0005435902657	20228	Economy	17600.00
0005433726070	21655	Business	91700.00
0005433726072	21655	Economy	30600.00
0005433726069	21655	Economy	30600.00
0005433726066	21655	Economy	30600.00
0005433726067	21655	Economy	30600.00
0005433726071	21655	Economy	30600.00
0005433726063	21655	Economy	30600.00
0005433726068	21655	Economy	30600.00
0005435982187	26522	Business	18500.00
0005435982159	26522	Business	18500.00
0005435982149	26522	Business	18500.00
0005433434212	26522	Business	18500.00
0005433434451	26522	Business	18500.00
0005435982168	26522	Business	18500.00
0005433434401	26522	Business	18500.00
0005435982147	26522	Business	18500.00
0005433434400	26522	Business	18500.00
0005435982146	26522	Business	18500.00
0005435982179	26522	Business	18500.00
0005435982165	26522	Business	18500.00
0005433434349	26522	Economy	6200.00
0005435982167	26522	Economy	6200.00
0005433434369	26522	Economy	6200.00
0005435982184	26522	Economy	6200.00
0005435982182	26522	Economy	6200.00
0005435982186	26522	Economy	6200.00
0005435982183	26522	Economy	6200.00
0005435982155	26522	Economy	6200.00
0005435982188	26522	Economy	6200.00
0005435982157	26522	Economy	6800.00
0005435982142	26522	Economy	6800.00
0005435982152	26522	Economy	6800.00
0005433434274	26522	Economy	6800.00
0005433434273	26522	Economy	6800.00
0005435982177	26522	Economy	6200.00
0005433434324	26522	Economy	6200.00
0005435982174	26522	Economy	6200.00
0005435982141	26522	Economy	6200.00
0005435982176	26522	Economy	6200.00
0005435982148	26522	Economy	6200.00
0005435982164	26522	Economy	6200.00
0005433434337	26522	Economy	6200.00
0005435982170	26522	Economy	6200.00
0005435982145	26522	Economy	6200.00
0005432300248	26522	Economy	6200.00
0005435982163	26522	Economy	6200.00
0005435982172	26522	Economy	6200.00
0005433434388	26522	Economy	6200.00
0005433434334	26522	Economy	6200.00
0005435982175	26522	Economy	6200.00
0005435982166	26522	Economy	6200.00
0005435982178	26522	Economy	6200.00
0005435982173	26522	Economy	6200.00
0005433434343	26522	Economy	6200.00
0005433434368	26522	Economy	6200.00
0005435982160	26522	Economy	6200.00
0005435982169	26522	Economy	6200.00
0005435982180	26522	Economy	6200.00
0005435982153	26522	Economy	6200.00
0005433434345	26522	Economy	6200.00
0005432300244	26522	Economy	6200.00
0005435982162	26522	Economy	6200.00
0005435982194	26522	Economy	6200.00
0005433434248	26522	Economy	6200.00
0005433434303	26522	Economy	6200.00
0005433434323	26522	Economy	6200.00
0005435982181	26522	Economy	6200.00
0005433434399	26522	Economy	6200.00
0005435982161	26522	Economy	6200.00
0005433434304	26522	Economy	6200.00
0005433434389	26522	Economy	6200.00
0005435982150	26522	Economy	6200.00
0005435982158	26522	Economy	6200.00
0005435982156	26522	Economy	6200.00
0005433434342	26522	Economy	6200.00
0005435982189	26522	Economy	6200.00
0005435982190	26522	Economy	6200.00
0005432300245	26522	Economy	6200.00
0005435982192	26522	Economy	6200.00
0005435982151	26522	Economy	6200.00
0005432300246	26522	Economy	6200.00
0005435982185	26522	Economy	6200.00
0005435982143	26522	Economy	6200.00
0005435982171	26522	Economy	6200.00
0005432300247	26522	Economy	6200.00
0005435982144	26522	Economy	6200.00
0005435982193	26522	Economy	6200.00
0005435982191	26522	Economy	6200.00
0005432300249	26522	Economy	6200.00
0005435982195	26522	Economy	6200.00
0005435982154	26522	Economy	6200.00
0005435981653	26722	Business	18500.00
0005435981664	26722	Business	18500.00
0005435981729	26722	Business	18500.00
0005435981780	26722	Business	18500.00
0005433434613	26722	Business	18500.00
0005435981823	26722	Business	18500.00
0005433434637	26722	Business	18500.00
0005435981790	26722	Business	18500.00
0005433434633	26722	Business	18500.00
0005433434616	26722	Business	18500.00
0005432051122	26722	Business	18500.00
0005435981708	26722	Economy	6200.00
0005435981741	26722	Economy	6200.00
0005435981674	26722	Economy	6200.00
0005435981777	26722	Economy	6200.00
0005435981754	26722	Economy	6200.00
0005434271308	26722	Economy	6200.00
0005432051123	26722	Economy	6200.00
0005433434636	26722	Economy	6200.00
0005433434639	26722	Economy	6200.00
0005433434627	26722	Economy	6800.00
0005433434620	26722	Economy	6800.00
0005435981840	26722	Economy	6800.00
0005435981712	26722	Economy	6800.00
0005435981822	26722	Economy	6800.00
0005435981801	26722	Economy	6200.00
0005433434619	26722	Economy	6200.00
0005433434618	26722	Economy	6200.00
0005435981716	26722	Economy	6200.00
0005433434632	26722	Economy	6200.00
0005435981610	26722	Economy	6200.00
0005434271307	26722	Economy	6200.00
0005435981690	26722	Economy	6200.00
0005433434612	26722	Economy	6200.00
0005435981839	26722	Economy	6200.00
0005433434631	26722	Economy	6200.00
0005433434638	26722	Economy	6200.00
0005433434615	26722	Economy	6200.00
0005433434622	26722	Economy	6200.00
0005433434634	26722	Economy	6200.00
0005435981742	26722	Economy	6200.00
0005433434629	26722	Economy	6200.00
0005435981613	26722	Economy	6200.00
0005435981614	26722	Economy	6200.00
0005433434630	26722	Economy	6200.00
0005435981789	26722	Economy	6200.00
0005435981785	26722	Economy	6200.00
0005433434626	26722	Economy	6200.00
0005435981726	26722	Economy	6200.00
0005435981778	26722	Economy	6200.00
0005435981798	26722	Economy	6200.00
0005435981711	26722	Economy	6200.00
0005433434625	26722	Economy	6200.00
0005435981847	26722	Economy	6200.00
0005435981779	26722	Economy	6200.00
0005433434628	26722	Economy	6200.00
0005434269099	26722	Economy	6200.00
0005435981791	26722	Economy	6200.00
0005435981824	26722	Economy	6200.00
0005433434623	26722	Economy	6200.00
0005435981740	26722	Economy	6200.00
0005435981877	26722	Economy	6200.00
0005435981871	26722	Economy	6200.00
0005432051121	26722	Economy	6200.00
0005435981782	26722	Economy	6200.00
0005435981825	26722	Economy	6200.00
0005433434614	26722	Economy	6200.00
0005433434635	26722	Economy	6200.00
0005433434621	26722	Economy	6200.00
0005434270203	26722	Economy	6200.00
0005433434617	26722	Economy	6200.00
0005433434624	26722	Economy	6200.00
0005435981794	26722	Economy	6200.00
0005435981665	26722	Economy	6200.00
0005435981786	26722	Economy	6200.00
0005435981802	26722	Economy	6200.00
0005435981872	26722	Economy	6200.00
0005435981870	26722	Economy	6200.00
0005432857969	3146	Economy	11100.00
0005432583990	3146	Economy	11100.00
0005432583993	3146	Economy	11100.00
0005432857973	3146	Economy	11100.00
0005432857924	3146	Economy	10100.00
0005432583972	3146	Economy	10100.00
0005432583984	3146	Economy	10100.00
0005432583971	3146	Economy	10100.00
0005432583992	3146	Economy	10100.00
0005432857938	3146	Economy	10100.00
0005432857957	3146	Economy	10100.00
0005432216266	3146	Economy	10100.00
0005432583991	3146	Economy	10100.00
0005432857902	3146	Economy	10100.00
0005432857942	3146	Economy	10100.00
0005432583970	3146	Economy	10100.00
0005432583983	3146	Economy	10100.00
0005432583982	3146	Economy	10100.00
0005432857911	3146	Economy	10100.00
0005432216265	3146	Economy	10100.00
0005432583973	3146	Economy	10100.00
0005432583978	3146	Economy	10100.00
0005432583986	3146	Economy	10100.00
0005432857939	3146	Economy	10100.00
0005432583988	3146	Economy	10100.00
0005432583976	3146	Economy	10100.00
0005432583994	3146	Economy	10100.00
0005432583985	3146	Economy	10100.00
0005432583974	3146	Economy	10100.00
0005432857967	3146	Economy	10100.00
0005432857946	3146	Economy	10100.00
0005432857953	3146	Economy	10100.00
0005432583981	3146	Economy	10100.00
0005432857945	3146	Economy	10100.00
0005432583987	3146	Economy	10100.00
0005432583969	3146	Economy	10100.00
0005432857950	3146	Economy	10100.00
0005432216267	3146	Economy	10100.00
0005432857952	3146	Economy	10100.00
0005432583975	3146	Economy	10100.00
0005432583977	3146	Economy	10100.00
0005432857915	3146	Economy	10100.00
0005432583980	3146	Economy	10100.00
0005432583979	3146	Economy	10100.00
0005432857949	3146	Economy	10100.00
0005432857968	3146	Economy	10100.00
0005432583989	3146	Economy	10100.00
0005432857937	3146	Economy	10100.00
0005432583671	31476	Economy	11100.00
0005432583836	31476	Economy	11100.00
0005432858038	31476	Economy	11100.00
0005432583805	31476	Economy	11100.00
0005432858039	31476	Economy	10100.00
0005432583837	31476	Economy	10100.00
0005432858045	31476	Economy	10100.00
0005432583755	31476	Economy	10100.00
0005432583773	31476	Economy	10100.00
0005432583811	31476	Economy	10100.00
0005432858046	31476	Economy	10100.00
0005432858043	31476	Economy	10100.00
0005432583815	31476	Economy	10100.00
0005432583717	31476	Economy	10100.00
0005432583747	31476	Economy	10100.00
0005432583663	31476	Economy	10100.00
0005432583715	31476	Economy	10100.00
0005432583857	31476	Economy	10100.00
0005432583834	31476	Economy	10100.00
0005432583741	31476	Economy	10100.00
0005432583858	31476	Economy	10100.00
0005432583936	31476	Economy	10100.00
0005432858040	31476	Economy	10100.00
0005432858037	31476	Economy	10100.00
0005432583835	31476	Economy	10100.00
0005432583935	31476	Economy	10100.00
0005432858036	31476	Economy	10100.00
0005432583804	31476	Economy	10100.00
0005432583888	31476	Economy	10100.00
0005432583662	31476	Economy	10100.00
0005432858047	31476	Economy	10100.00
0005432858044	31476	Economy	10100.00
0005432583887	31476	Economy	10100.00
0005432583780	31476	Economy	10100.00
0005432583816	31476	Economy	10100.00
0005432858041	31476	Economy	10100.00
0005432583806	31476	Economy	10100.00
0005432583833	31476	Economy	10100.00
0005432583807	31476	Economy	10100.00
0005432858042	31476	Economy	10100.00
0005432583695	31476	Economy	10100.00
0005432583814	31476	Economy	10100.00
0005434943334	893	Economy	8300.00
0005433255074	893	Economy	8300.00
0005433255062	893	Economy	8300.00
0005433255065	893	Economy	7500.00
0005434943327	893	Economy	7500.00
0005434943333	893	Economy	7500.00
0005433255058	893	Economy	7500.00
0005433255073	893	Economy	7500.00
0005434943336	893	Economy	7500.00
0005433255056	893	Economy	7500.00
0005434943331	893	Economy	7500.00
0005433255061	893	Economy	7500.00
0005434943332	893	Economy	7500.00
0005433255067	893	Economy	7500.00
0005433255066	893	Economy	7500.00
0005434943330	893	Economy	7500.00
0005434943329	893	Economy	7500.00
0005433255055	893	Economy	7500.00
0005433255076	893	Economy	7500.00
0005433255064	893	Economy	7500.00
0005433255054	893	Economy	7500.00
0005433255069	893	Economy	7500.00
0005434943328	893	Economy	7500.00
0005433255068	893	Economy	7500.00
0005434943335	893	Economy	7500.00
0005434943233	16248	Economy	8300.00
0005433255108	16248	Economy	8300.00
0005434943269	16248	Economy	7500.00
0005433255105	16248	Economy	7500.00
0005434943252	16248	Economy	7500.00
0005434943291	16248	Economy	7500.00
0005434943232	16248	Economy	7500.00
0005433255109	16248	Economy	7500.00
0005434943242	16248	Economy	7500.00
0005434943234	16248	Economy	7500.00
0005434943223	16248	Economy	7500.00
0005434943222	16248	Economy	7500.00
0005433255107	16248	Economy	7500.00
0005434943290	16248	Economy	7500.00
0005434943273	16248	Economy	7500.00
0005434943292	16248	Economy	7500.00
0005433255106	16248	Economy	7500.00
0005434943224	16248	Economy	7500.00
0005435652937	21752	Business	9800.00
0005433367448	21752	Business	9800.00
0005435652945	21752	Business	9800.00
0005433367499	21752	Business	9800.00
0005435652944	21752	Business	9800.00
0005433367476	21752	Business	9800.00
0005435652939	21752	Economy	3300.00
0005433367496	21752	Economy	3300.00
0005435652933	21752	Economy	3300.00
0005433367475	21752	Economy	3300.00
0005433367565	21752	Economy	3300.00
0005433367418	21752	Economy	3300.00
0005433367465	21752	Economy	3300.00
0005435652930	21752	Economy	3300.00
0005433367539	21752	Economy	3600.00
0005435652952	21752	Economy	3600.00
0005433367488	21752	Economy	3600.00
0005435652924	21752	Economy	3600.00
0005433367452	21752	Economy	3300.00
0005435652954	21752	Economy	3300.00
0005433367620	21752	Economy	3300.00
0005433367417	21752	Economy	3300.00
0005433367451	21752	Economy	3300.00
0005433367540	21752	Economy	3300.00
0005435652938	21752	Economy	3300.00
0005433367449	21752	Economy	3300.00
0005435652921	21752	Economy	3300.00
0005435652928	21752	Economy	3300.00
0005435652948	21752	Economy	3300.00
0005433367375	21752	Economy	3300.00
0005435652920	21752	Economy	3300.00
0005433367563	21752	Economy	3300.00
0005433367296	21752	Economy	3300.00
0005433367515	21752	Economy	3300.00
0005433367640	21752	Economy	3300.00
0005435652951	21752	Economy	3300.00
0005435652943	21752	Economy	3300.00
0005433367498	21752	Economy	3300.00
0005433367365	21752	Economy	3300.00
0005435652917	21752	Economy	3300.00
0005435652950	21752	Economy	3300.00
0005433367500	21752	Economy	3300.00
0005433367466	21752	Economy	3300.00
0005433367495	21752	Economy	3300.00
0005433367376	21752	Economy	3300.00
0005435652934	21752	Economy	3300.00
0005435652926	21752	Economy	3300.00
0005435652947	21752	Economy	3300.00
0005435652925	21752	Economy	3300.00
0005433367381	21752	Economy	3300.00
0005435652940	21752	Economy	3300.00
0005435652927	21752	Economy	3300.00
0005433367621	21752	Economy	3300.00
0005435652941	21752	Economy	3300.00
0005435652953	21752	Economy	3300.00
0005433367419	21752	Economy	3300.00
0005433367450	21752	Economy	3300.00
0005433367333	21752	Economy	3300.00
0005435652932	21752	Economy	3300.00
0005435652929	21752	Economy	3300.00
0005435652946	21752	Economy	3300.00
0005435652936	21752	Economy	3300.00
0005435652931	21752	Economy	3300.00
0005435652949	21752	Economy	3300.00
0005433367410	21752	Economy	3300.00
0005435652935	21752	Economy	3300.00
0005433367497	21752	Economy	3300.00
0005435652923	21752	Economy	3300.00
0005433367390	21752	Economy	3300.00
0005433367538	21752	Economy	3300.00
0005433367411	21752	Economy	3300.00
0005435652919	21752	Economy	3300.00
0005435652942	21752	Economy	3300.00
0005435652918	21752	Economy	3300.00
0005435652922	21752	Economy	3300.00
0005433784873	9333	Business	186200.00
0005433784872	9333	Business	186200.00
0005433784876	9333	Business	186200.00
0005432666383	9333	Business	186200.00
0005434170898	9333	Business	186200.00
0005434170928	9333	Business	186200.00
0005433805313	9333	Business	186200.00
0005434170922	9333	Business	186200.00
0005435269656	9333	Business	186200.00
0005433805293	9333	Business	186200.00
0005434170943	9333	Business	186200.00
0005433805324	9333	Business	186200.00
0005433805287	9333	Business	186200.00
0005432665270	9333	Business	186200.00
0005433805320	9333	Business	186200.00
0005433784854	9333	Business	186200.00
0005434170908	9333	Business	186200.00
0005433805326	9333	Business	186200.00
0005434151672	9333	Business	186200.00
0005433805315	9333	Business	186200.00
0005433784859	9333	Economy	68300.00
0005433763174	9333	Economy	68300.00
0005433784870	9333	Economy	68300.00
0005433784868	9333	Economy	62100.00
0005433763181	9333	Economy	62100.00
0005433805305	9333	Economy	62100.00
0005433805307	9333	Economy	62100.00
0005434170919	9333	Economy	62100.00
0005433784881	9333	Economy	62100.00
0005433784852	9333	Economy	62100.00
0005433784869	9333	Economy	62100.00
0005433784862	9333	Economy	62100.00
0005433784851	9333	Economy	62100.00
0005434170983	9333	Economy	62100.00
0005433784878	9333	Economy	62100.00
0005434170920	9333	Economy	62100.00
0005433784856	9333	Economy	62100.00
0005433805301	9333	Economy	62100.00
0005433805304	9333	Economy	62100.00
0005432666384	9333	Economy	62100.00
0005433805312	9333	Economy	62100.00
0005433784855	9333	Economy	62100.00
0005433805317	9333	Economy	62100.00
0005434151667	9333	Economy	62100.00
0005433763171	9333	Economy	62100.00
0005432657443	9333	Economy	62100.00
0005433784858	9333	Economy	62100.00
0005433805310	9333	Economy	62100.00
0005433805291	9333	Economy	62100.00
0005432665269	9333	Economy	62100.00
0005433763173	9333	Economy	62100.00
0005433784882	9333	Economy	62100.00
0005433763169	9333	Economy	62100.00
0005433784886	9333	Economy	62100.00
0005432657442	9333	Economy	62100.00
0005433784875	9333	Economy	62100.00
0005433805297	9333	Economy	62100.00
0005432667450	9333	Economy	62100.00
0005434273062	9333	Economy	62100.00
0005433763177	9333	Economy	62100.00
0005435269669	9333	Economy	62100.00
0005433784857	9333	Economy	62100.00
0005433784865	9333	Economy	62100.00
0005433784863	9333	Economy	62100.00
0005433805286	9333	Economy	62100.00
0005435269670	9333	Economy	62100.00
0005433784879	9333	Economy	62100.00
0005433805308	9333	Economy	62100.00
0005433784864	9333	Economy	62100.00
0005432665271	9333	Economy	62100.00
0005433763170	9333	Economy	62100.00
0005433763167	9333	Economy	62100.00
0005434151673	9333	Economy	62100.00
0005433784860	9333	Economy	62100.00
0005432667448	9333	Economy	62100.00
0005433763168	9333	Economy	62100.00
0005433805323	9333	Economy	62100.00
0005433805327	9333	Economy	62100.00
0005433805289	9333	Economy	68300.00
0005433805302	9333	Economy	62100.00
0005434170934	9333	Economy	62100.00
0005433805295	9333	Economy	62100.00
0005432657444	9333	Economy	62100.00
0005435269652	9333	Economy	62100.00
0005433805300	9333	Economy	62100.00
0005433784885	9333	Economy	62100.00
0005434170939	9333	Economy	62100.00
0005433805321	9333	Economy	62100.00
0005433805322	9333	Economy	62100.00
0005432667449	9333	Economy	62100.00
0005434170935	9333	Economy	62100.00
0005434170938	9333	Economy	62100.00
0005433805306	9333	Economy	62100.00
0005434170907	9333	Economy	62100.00
0005434170879	9333	Economy	62100.00
0005433763175	9333	Economy	62100.00
0005433805296	9333	Economy	62100.00
0005433805318	9333	Economy	62100.00
0005435269657	9333	Economy	62100.00
0005433784874	9333	Economy	62100.00
0005433805314	9333	Economy	62100.00
0005433784880	9333	Economy	62100.00
0005433805292	9333	Economy	62100.00
0005433763180	9333	Economy	62100.00
0005433784877	9333	Economy	62100.00
0005434170954	9333	Economy	62100.00
0005433784884	9333	Economy	62100.00
0005433805309	9333	Economy	62100.00
0005433784871	9333	Economy	62100.00
0005433784861	9333	Economy	62100.00
0005433763172	9333	Economy	62100.00
0005433763176	9333	Economy	62100.00
0005433805298	9333	Economy	62100.00
0005433805325	9333	Economy	62100.00
0005433784866	9333	Economy	62100.00
0005433763178	9333	Economy	62100.00
0005433805311	9333	Economy	62100.00
0005433805294	9333	Economy	62100.00
0005433763179	9333	Economy	62100.00
0005433784883	9333	Economy	62100.00
0005434170915	9333	Economy	62100.00
0005433784853	9333	Economy	62100.00
0005433805316	9333	Economy	62100.00
0005433805290	9333	Economy	62100.00
0005433784867	9333	Economy	62100.00
0005433805288	9333	Economy	62100.00
0005434170944	9333	Economy	62100.00
0005433805299	9333	Economy	62100.00
0005433805319	9333	Economy	62100.00
0005432657441	9333	Economy	62100.00
0005433805303	9333	Economy	62100.00
0005434170893	9333	Economy	62100.00
0005433784458	26234	Business	186200.00
0005433784504	26234	Business	186200.00
0005433763074	26234	Business	186200.00
0005432657402	26234	Business	186200.00
0005433784560	26234	Business	186200.00
0005433805001	26234	Business	186200.00
0005433805071	26234	Business	186200.00
0005432657395	26234	Business	186200.00
0005434271306	26234	Business	186200.00
0005433784732	26234	Business	186200.00
0005435269746	26234	Business	186200.00
0005434269097	26234	Economy	68300.00
0005433784509	26234	Economy	68300.00
0005433763008	26234	Economy	62100.00
0005433784502	26234	Economy	68300.00
0005434171030	26234	Economy	62100.00
0005433763098	26234	Economy	62100.00
0005433784479	26234	Economy	62100.00
0005433784677	26234	Economy	62100.00
0005433784593	26234	Economy	62100.00
0005433763073	26234	Economy	62100.00
0005434171017	26234	Economy	62100.00
0005434171026	26234	Economy	62100.00
0005433784678	26234	Economy	62100.00
0005433784733	26234	Economy	62100.00
0005434171020	26234	Economy	62100.00
0005434171023	26234	Economy	62100.00
0005433805017	26234	Economy	62100.00
0005433805013	26234	Economy	62100.00
0005433763024	26234	Economy	62100.00
0005433784587	26234	Economy	62100.00
0005433784656	26234	Economy	62100.00
0005433763062	26234	Economy	62100.00
0005434171027	26234	Economy	62100.00
0005433804927	26234	Economy	62100.00
0005433763038	26234	Economy	62100.00
0005432657421	26234	Economy	62100.00
0005433805076	26234	Economy	62100.00
0005434171025	26234	Economy	62100.00
0005433784442	26234	Economy	62100.00
0005434270202	26234	Economy	62100.00
0005433784693	26234	Economy	62100.00
0005434171022	26234	Economy	62100.00
0005433763021	26234	Economy	62100.00
0005433804926	26234	Economy	62100.00
0005433784679	26234	Economy	62100.00
0005434270201	26234	Economy	62100.00
0005433805086	26234	Economy	62100.00
0005433805012	26234	Economy	62100.00
0005433763029	26234	Economy	62100.00
0005433763046	26234	Economy	62100.00
0005433763072	26234	Economy	62100.00
0005433763030	26234	Economy	62100.00
0005433784655	26234	Economy	62100.00
0005433784588	26234	Economy	62100.00
0005433784629	26234	Economy	62100.00
0005433763061	26234	Economy	62100.00
0005433805070	26234	Economy	62100.00
0005433804978	26234	Economy	62100.00
0005433804976	26234	Economy	62100.00
0005433784491	26234	Economy	68300.00
0005433805099	26234	Economy	68300.00
0005434171021	26234	Economy	62100.00
0005434171024	26234	Economy	62100.00
0005434171019	26234	Economy	62100.00
0005432657403	26234	Economy	62100.00
0005434171031	26234	Economy	62100.00
0005433763026	26234	Economy	62100.00
0005433784441	26234	Economy	62100.00
0005433784583	26234	Economy	62100.00
0005433784592	26234	Economy	62100.00
0005433784699	26234	Economy	62100.00
0005433805032	26234	Economy	62100.00
0005434270199	26234	Economy	62100.00
0005434171018	26234	Economy	62100.00
0005433804965	26234	Economy	62100.00
0005434151698	26234	Economy	62100.00
0005433763037	26234	Economy	62100.00
0005434269096	26234	Economy	62100.00
0005433763052	26234	Economy	62100.00
0005433805047	26234	Economy	62100.00
0005433804966	26234	Economy	62100.00
0005433784654	26234	Economy	62100.00
0005433804991	26234	Economy	62100.00
0005434171029	26234	Economy	62100.00
0005434270200	26234	Economy	62100.00
0005433763036	26234	Economy	62100.00
0005434269098	26234	Economy	62100.00
0005433784561	26234	Economy	62100.00
0005434171028	26234	Economy	62100.00
0005435269747	26234	Economy	62100.00
0005434271305	26234	Economy	62100.00
0005433784570	26234	Economy	62100.00
0005433784397	26234	Economy	62100.00
0005433805016	26234	Economy	62100.00
0005433804939	26234	Economy	62100.00
0005433804967	26234	Economy	62100.00
0005433784589	26234	Economy	62100.00
0005433763009	26234	Economy	62100.00
0005433784480	26234	Economy	62100.00
0005433805106	26234	Economy	62100.00
0005433763025	26234	Economy	62100.00
0005433804977	26234	Economy	62100.00
0005433805069	26234	Economy	62100.00
0005433784474	26234	Economy	62100.00
0005435929622	4902	Economy	5300.00
0005435135657	4902	Economy	5300.00
0005435135658	4902	Economy	5300.00
0005435135660	4902	Economy	5300.00
0005435135659	4902	Economy	5300.00
0005435135661	4902	Economy	5300.00
0005435135634	33010	Economy	5300.00
0005435929638	33010	Economy	5300.00
0005435135594	33010	Economy	5300.00
0005435135630	33010	Economy	5300.00
0005435135625	33010	Economy	5300.00
0005434983277	9470	Economy	19700.00
0005434983273	9470	Economy	17900.00
0005434983276	9470	Economy	17900.00
0005434983278	9470	Economy	17900.00
0005434983275	9470	Economy	17900.00
0005434983274	9470	Economy	17900.00
0005434217957	27372	Economy	19700.00
0005434217960	27372	Economy	17900.00
0005434217961	27372	Economy	17900.00
0005434983223	27372	Economy	17900.00
0005434983237	27372	Economy	17900.00
0005434217959	27372	Economy	17900.00
0005434217958	27372	Economy	17900.00
0005434983244	27372	Economy	17900.00
0005433960202	24282	Business	36400.00
0005433960199	24282	Business	36400.00
0005433985408	24282	Business	36400.00
0005433985526	24282	Business	36400.00
0005433985559	24282	Business	36400.00
0005433985511	24282	Business	36400.00
0005433960172	24282	Business	36400.00
0005433985524	24282	Business	36400.00
0005433960117	24282	Business	36400.00
0005433985335	24282	Business	36400.00
0005433960049	24282	Business	36400.00
0005433985339	24282	Business	36400.00
0005433960097	24282	Business	36400.00
0005433960123	24282	Business	36400.00
0005433960082	24282	Business	36400.00
0005433985294	24282	Business	36400.00
0005433985380	24282	Business	36400.00
0005433985378	24282	Economy	13400.00
0005433960218	24282	Economy	13400.00
0005433960091	24282	Economy	13400.00
0005433960194	24282	Economy	12100.00
0005433959983	24282	Economy	12100.00
0005433985358	24282	Economy	12100.00
0005433960133	24282	Economy	12100.00
0005433960098	24282	Economy	12100.00
0005433959892	24282	Economy	12100.00
0005433960174	24282	Economy	12100.00
0005433960100	24282	Economy	12100.00
0005433985379	24282	Economy	12100.00
0005433960052	24282	Economy	12100.00
0005433960164	24282	Economy	12100.00
0005433960181	24282	Economy	12100.00
0005433985309	24282	Economy	12100.00
0005433960065	24282	Economy	12100.00
0005433960139	24282	Economy	12100.00
0005433985268	24282	Economy	12100.00
0005433985600	24282	Economy	12100.00
0005433960205	24282	Economy	12100.00
0005433960196	24282	Economy	12100.00
0005433960126	24282	Economy	12100.00
0005433960047	24282	Economy	12100.00
0005433960085	24282	Economy	12100.00
0005433959998	24282	Economy	12100.00
0005433960062	24282	Economy	12100.00
0005433960162	24282	Economy	12100.00
0005433985396	24282	Economy	12100.00
0005433960203	24282	Economy	12100.00
0005433959857	24282	Economy	12100.00
0005433960081	24282	Economy	12100.00
0005433985398	24282	Economy	12100.00
0005433985544	24282	Economy	12100.00
0005433960222	24282	Economy	12100.00
0005433960134	24282	Economy	12100.00
0005433960127	24282	Economy	12100.00
0005433960064	24282	Economy	12100.00
0005433960168	24282	Economy	12100.00
0005433960211	24282	Economy	12100.00
0005433985404	24282	Economy	12100.00
0005433985410	24282	Economy	12100.00
0005433960008	24282	Economy	12100.00
0005433960198	24282	Economy	12100.00
0005433985523	24282	Economy	12100.00
0005433960048	24282	Economy	12100.00
0005433959991	24282	Economy	12100.00
0005433985411	24282	Economy	12100.00
0005433960153	24282	Economy	12100.00
0005433985426	24282	Economy	12100.00
0005433985261	24282	Economy	12100.00
0005433960173	24282	Economy	12100.00
0005433985323	24282	Economy	12100.00
0005433985417	24282	Economy	12100.00
0005433960193	24282	Economy	12100.00
0005433960178	24282	Economy	12100.00
0005433985458	24282	Economy	12100.00
0005433985492	24282	Economy	13400.00
0005433985307	24282	Economy	13400.00
0005433960086	24282	Economy	12100.00
0005433960120	24282	Economy	12100.00
0005433985397	24282	Economy	12100.00
0005433960184	24282	Economy	12100.00
0005433960132	24282	Economy	12100.00
0005433985311	24282	Economy	12100.00
0005433985322	24282	Economy	12100.00
0005433985338	24282	Economy	12100.00
0005433960055	24282	Economy	12100.00
0005433960088	24282	Economy	12100.00
0005433960029	24282	Economy	12100.00
0005433960161	24282	Economy	12100.00
0005433959997	24282	Economy	12100.00
0005433985599	24282	Economy	12100.00
0005433960054	24282	Economy	12100.00
0005433985399	24282	Economy	12100.00
0005433985525	24282	Economy	12100.00
0005433960099	24282	Economy	12100.00
0005433960175	24282	Economy	12100.00
0005433960169	24282	Economy	12100.00
0005433985389	24282	Economy	12100.00
0005433985507	24282	Economy	12100.00
0005433985246	24282	Economy	12100.00
0005433960183	24282	Economy	12100.00
0005433985350	24282	Economy	12100.00
0005433985405	24282	Economy	12100.00
0005433985531	24282	Economy	12100.00
0005433959856	24282	Economy	12100.00
0005433985493	24282	Economy	12100.00
0005433960221	24282	Economy	12100.00
0005433960179	24282	Economy	12100.00
0005433960207	24282	Economy	12100.00
0005433960154	24282	Economy	12100.00
0005433985409	24282	Economy	12100.00
0005433959858	24282	Economy	12100.00
0005433985443	24282	Economy	12100.00
0005433985321	24282	Economy	12100.00
0005433960206	24282	Economy	12100.00
0005433960067	24282	Economy	12100.00
0005433960700	25922	Business	36400.00
0005433985837	25922	Business	36400.00
0005433960713	25922	Business	36400.00
0005433985820	25922	Business	36400.00
0005433985832	25922	Business	36400.00
0005433985799	25922	Business	36400.00
0005433985834	25922	Business	36400.00
0005433985835	25922	Business	36400.00
0005433960675	25922	Business	36400.00
0005433960734	25922	Business	36400.00
0005433985802	25922	Business	36400.00
0005433985803	25922	Business	36400.00
0005433960694	25922	Business	36400.00
0005433960709	25922	Business	36400.00
0005433960685	25922	Business	36400.00
0005433960695	25922	Business	36400.00
0005433960707	25922	Business	36400.00
0005433985810	25922	Economy	13400.00
0005433985838	25922	Economy	13400.00
0005433960681	25922	Economy	13400.00
0005433960696	25922	Economy	13400.00
0005433985815	25922	Economy	12100.00
0005433985805	25922	Economy	12100.00
0005433960720	25922	Economy	12100.00
0005433960711	25922	Economy	12100.00
0005433985804	25922	Economy	12100.00
0005433985828	25922	Economy	12100.00
0005433960729	25922	Economy	12100.00
0005433960698	25922	Economy	12100.00
0005433960717	25922	Economy	12100.00
0005433960699	25922	Economy	12100.00
0005433960703	25922	Economy	12100.00
0005433960722	25922	Economy	12100.00
0005433960725	25922	Economy	12100.00
0005433985818	25922	Economy	12100.00
0005433985821	25922	Economy	12100.00
0005433985825	25922	Economy	12100.00
0005433960687	25922	Economy	12100.00
0005433960721	25922	Economy	12100.00
0005433960686	25922	Economy	12100.00
0005433985823	25922	Economy	12100.00
0005433960684	25922	Economy	12100.00
0005433960676	25922	Economy	12100.00
0005433985826	25922	Economy	12100.00
0005433985811	25922	Economy	12100.00
0005433985836	25922	Economy	12100.00
0005433960705	25922	Economy	12100.00
0005433960682	25922	Economy	12100.00
0005433985822	25922	Economy	12100.00
0005433960693	25922	Economy	12100.00
0005433960691	25922	Economy	12100.00
0005433985795	25922	Economy	12100.00
0005433960688	25922	Economy	12100.00
0005433960724	25922	Economy	12100.00
0005433960730	25922	Economy	12100.00
0005433960738	25922	Economy	12100.00
0005433960718	25922	Economy	12100.00
0005433960692	25922	Economy	12100.00
0005433985829	25922	Economy	12100.00
0005433960708	25922	Economy	12100.00
0005433960736	25922	Economy	12100.00
0005433985814	25922	Economy	12100.00
0005433985817	25922	Economy	12100.00
0005433960728	25922	Economy	12100.00
0005433960727	25922	Economy	12100.00
0005433960678	25922	Economy	12100.00
0005433985833	25922	Economy	12100.00
0005433960706	25922	Economy	12100.00
0005433960712	25922	Economy	12100.00
0005433985819	25922	Economy	13400.00
0005433985813	25922	Economy	13400.00
0005433960680	25922	Economy	12100.00
0005433985791	25922	Economy	12100.00
0005433960723	25922	Economy	12100.00
0005433960704	25922	Economy	12100.00
0005433960679	25922	Economy	12100.00
0005433960731	25922	Economy	12100.00
0005433985794	25922	Economy	12100.00
0005433985839	25922	Economy	12100.00
0005433985831	25922	Economy	12100.00
0005433985824	25922	Economy	12100.00
0005433960697	25922	Economy	12100.00
0005433985800	25922	Economy	12100.00
0005433985792	25922	Economy	12100.00
0005433985809	25922	Economy	12100.00
0005433960710	25922	Economy	12100.00
0005433985806	25922	Economy	12100.00
0005433985830	25922	Economy	12100.00
0005433960677	25922	Economy	12100.00
0005433960735	25922	Economy	12100.00
0005433985801	25922	Economy	12100.00
0005433985812	25922	Economy	12100.00
0005433960683	25922	Economy	12100.00
0005433985807	25922	Economy	12100.00
0005433960716	25922	Economy	12100.00
0005433985808	25922	Economy	12100.00
0005433960690	25922	Economy	12100.00
0005433985798	25922	Economy	12100.00
0005433960689	25922	Economy	12100.00
0005433960726	25922	Economy	12100.00
0005433985793	25922	Economy	12100.00
0005433960737	25922	Economy	12100.00
0005433960719	25922	Economy	12100.00
0005433960714	25922	Economy	12100.00
0005433960732	25922	Economy	12100.00
0005433985827	25922	Economy	12100.00
0005433960701	25922	Economy	12100.00
0005433985816	25922	Economy	12100.00
0005433985797	25922	Economy	12100.00
0005433960715	25922	Economy	12100.00
0005433985796	25922	Economy	12100.00
0005433960702	25922	Economy	12100.00
0005433960733	25922	Economy	12100.00
0005434480273	943	Economy	25400.00
0005434480274	943	Economy	25400.00
0005433165795	943	Economy	25400.00
0005433165728	943	Economy	25400.00
0005433165735	943	Economy	23100.00
0005434480284	943	Economy	23100.00
0005432269489	943	Economy	23100.00
0005433165758	943	Economy	23100.00
0005434480277	943	Economy	23100.00
0005433165804	943	Economy	23100.00
0005434480271	943	Economy	23100.00
0005434480286	943	Economy	23100.00
0005433165789	943	Economy	23100.00
0005433165790	943	Economy	23100.00
0005434480283	943	Economy	23100.00
0005434480285	943	Economy	23100.00
0005434480267	943	Economy	23100.00
0005434480265	943	Economy	23100.00
0005434480276	943	Economy	23100.00
0005433165772	943	Economy	23100.00
0005433165771	943	Economy	23100.00
0005434480287	943	Economy	23100.00
0005433165760	943	Economy	23100.00
0005434480279	943	Economy	23100.00
0005432269488	943	Economy	23100.00
0005434480288	943	Economy	23100.00
0005434480268	943	Economy	23100.00
0005434480269	943	Economy	23100.00
0005434480280	943	Economy	23100.00
0005434480266	943	Economy	23100.00
0005433165794	943	Economy	23100.00
0005434480270	943	Economy	23100.00
0005434480281	943	Economy	23100.00
0005433165769	943	Economy	23100.00
0005433165784	943	Economy	23100.00
0005433165799	943	Economy	23100.00
0005434480263	943	Economy	23100.00
0005433165739	943	Economy	23100.00
0005433165801	943	Economy	23100.00
0005434480272	943	Economy	23100.00
0005434480278	943	Economy	23100.00
0005433165788	943	Economy	23100.00
0005433165802	943	Economy	23100.00
0005434480264	943	Economy	23100.00
0005433165770	943	Economy	23100.00
0005434480275	943	Economy	23100.00
0005434480282	943	Economy	23100.00
0005433165785	943	Economy	23100.00
0005433165717	943	Economy	23100.00
0005432269490	943	Economy	23100.00
0005434480014	16603	Economy	25400.00
0005434480172	16603	Economy	25400.00
0005434479986	16603	Economy	25400.00
0005434480119	16603	Economy	23100.00
0005434480112	16603	Economy	23100.00
0005434480040	16603	Economy	23100.00
0005433165871	16603	Economy	23100.00
0005434479981	16603	Economy	23100.00
0005433165881	16603	Economy	23100.00
0005434480046	16603	Economy	23100.00
0005434480056	16603	Economy	23100.00
0005434480096	16603	Economy	23100.00
0005434479982	16603	Economy	23100.00
0005434480057	16603	Economy	23100.00
0005433165880	16603	Economy	23100.00
0005433165879	16603	Economy	23100.00
0005433165882	16603	Economy	23100.00
0005434480041	16603	Economy	23100.00
0005434480145	16603	Economy	23100.00
0005434480020	16603	Economy	23100.00
0005434480055	16603	Economy	23100.00
0005434480171	16603	Economy	23100.00
0005433165877	16603	Economy	23100.00
0005434479927	16603	Economy	23100.00
0005434480034	16603	Economy	23100.00
0005433165873	16603	Economy	23100.00
0005434479914	16603	Economy	23100.00
0005433165874	16603	Economy	23100.00
0005434480094	16603	Economy	23100.00
0005434479913	16603	Economy	23100.00
0005433165878	16603	Economy	23100.00
0005434480021	16603	Economy	23100.00
0005434480092	16603	Economy	23100.00
0005434480103	16603	Economy	23100.00
0005433165875	16603	Economy	23100.00
0005433165872	16603	Economy	23100.00
0005434480118	16603	Economy	23100.00
0005434480052	16603	Economy	23100.00
0005433165876	16603	Economy	23100.00
0005433165870	16603	Economy	23100.00
0005434479965	16603	Economy	23100.00
0005433165883	16603	Economy	23100.00
0005434480051	16603	Economy	23100.00
0005435142542	10351	Economy	17000.00
0005435142541	10351	Economy	17000.00
0005435149990	10351	Economy	15400.00
0005435386510	10351	Economy	15400.00
0005435149985	10351	Economy	15400.00
0005435386509	10351	Economy	15400.00
0005435386465	10351	Economy	15400.00
0005435149983	10351	Economy	15400.00
0005435386534	10351	Economy	15400.00
0005435142540	10351	Economy	15400.00
0005435149989	10351	Economy	15400.00
0005435149992	10351	Economy	15400.00
0005433289776	10351	Economy	15400.00
0005435386508	10351	Economy	15400.00
0005435386481	10351	Economy	15400.00
0005435142531	10351	Economy	15400.00
0005435149991	10351	Economy	15400.00
0005435149984	10351	Economy	15400.00
0005435149979	10351	Economy	15400.00
0005435142535	10351	Economy	15400.00
0005435149981	10351	Economy	15400.00
0005433289786	10351	Economy	15400.00
0005435149980	10351	Economy	15400.00
0005433289756	10351	Economy	15400.00
0005435149988	10351	Economy	15400.00
0005435142536	10351	Economy	15400.00
0005435142539	10351	Economy	15400.00
0005435149987	10351	Economy	15400.00
0005435142538	10351	Economy	15400.00
0005435142534	10351	Economy	15400.00
0005435142532	10351	Economy	15400.00
0005435142530	10351	Economy	15400.00
0005435142533	10351	Economy	15400.00
0005435149986	10351	Economy	15400.00
0005433289777	10351	Economy	15400.00
0005435149993	10351	Economy	15400.00
0005435142537	10351	Economy	15400.00
0005435149982	10351	Economy	15400.00
0005435149929	21964	Economy	17000.00
0005435149902	21964	Economy	17000.00
0005435386562	21964	Economy	17000.00
0005435149901	21964	Economy	17000.00
0005433289842	21964	Economy	15400.00
0005433289837	21964	Economy	15400.00
0005435142436	21964	Economy	15400.00
0005433289835	21964	Economy	15400.00
0005435142454	21964	Economy	15400.00
0005435142405	21964	Economy	15400.00
0005435149828	21964	Economy	15400.00
0005433289843	21964	Economy	15400.00
0005433289838	21964	Economy	15400.00
0005435149867	21964	Economy	15400.00
0005433289841	21964	Economy	15400.00
0005435149860	21964	Economy	15400.00
0005435149832	21964	Economy	15400.00
0005435149859	21964	Economy	15400.00
0005435142445	21964	Economy	15400.00
0005435149886	21964	Economy	15400.00
0005435149888	21964	Economy	15400.00
0005435142374	21964	Economy	15400.00
0005435149883	21964	Economy	15400.00
0005435149829	21964	Economy	15400.00
0005435142443	21964	Economy	15400.00
0005435142425	21964	Economy	15400.00
0005435142433	21964	Economy	15400.00
0005435149846	21964	Economy	15400.00
0005435149870	21964	Economy	15400.00
0005433289836	21964	Economy	15400.00
0005435149871	21964	Economy	15400.00
0005435149864	21964	Economy	15400.00
0005435149892	21964	Economy	15400.00
0005435142420	21964	Economy	15400.00
0005433289840	21964	Economy	15400.00
0005433289839	21964	Economy	15400.00
0005435149893	21964	Economy	15400.00
0005435149877	21964	Economy	15400.00
0005435149854	21964	Economy	15400.00
0005435149842	21964	Economy	15400.00
0005435142455	21964	Economy	15400.00
0005435386563	21964	Economy	15400.00
0005435149841	21964	Economy	15400.00
0005435149845	21964	Economy	15400.00
0005435149822	21964	Economy	15400.00
0005435149885	21964	Economy	15400.00
0005435149821	21964	Economy	15400.00
0005435386564	21964	Economy	15400.00
0005435142446	21964	Economy	15400.00
0005435502104	11234	Business	57200.00
0005435545641	11234	Business	57200.00
0005435529024	11234	Business	57200.00
0005435545624	11234	Business	57200.00
0005435502076	11234	Business	57200.00
0005435501994	11234	Business	57200.00
0005435502038	11234	Business	57200.00
0005435502056	11234	Economy	19100.00
0005435529074	11234	Economy	19100.00
0005435319469	11234	Economy	19100.00
0005435528905	11234	Economy	19100.00
0005435501993	11234	Economy	19100.00
0005434573314	11234	Economy	19100.00
0005435502077	11234	Economy	19100.00
0005435502153	11234	Economy	21000.00
0005435502078	11234	Economy	21000.00
0005435319441	11234	Economy	21000.00
0005435502030	11234	Economy	21000.00
0005435502087	11234	Economy	19100.00
0005434573311	11234	Economy	19100.00
0005434573310	11234	Economy	19100.00
0005435529068	11234	Economy	19100.00
0005435502058	11234	Economy	19100.00
0005435319490	11234	Economy	19100.00
0005435502082	11234	Economy	19100.00
0005435502147	11234	Economy	19100.00
0005435529082	11234	Economy	19100.00
0005435502095	11234	Economy	19100.00
0005434573306	11234	Economy	19100.00
0005435528906	11234	Economy	19100.00
0005435502064	11234	Economy	19100.00
0005435502103	11234	Economy	19100.00
0005435529025	11234	Economy	19100.00
0005435529026	11234	Economy	19100.00
0005435502031	11234	Economy	19100.00
0005435502032	11234	Economy	19100.00
0005435319436	11234	Economy	19100.00
0005435528960	11234	Economy	19100.00
0005435528992	11234	Economy	19100.00
0005435502086	11234	Economy	19100.00
0005435502073	11234	Economy	19100.00
0005435529002	11234	Economy	19100.00
0005435528957	11234	Economy	19100.00
0005434573316	11234	Economy	19100.00
0005434573315	11234	Economy	19100.00
0005435529008	11234	Economy	19100.00
0005435502152	11234	Economy	19100.00
0005435502151	11234	Economy	19100.00
0005435528998	11234	Economy	19100.00
0005434573304	11234	Economy	19100.00
0005435502057	11234	Economy	19100.00
0005435502055	11234	Economy	19100.00
0005435528976	11234	Economy	19100.00
0005435319437	11234	Economy	19100.00
0005435528977	11234	Economy	19100.00
0005435529016	11234	Economy	19100.00
0005435319501	11234	Economy	19100.00
0005435528904	11234	Economy	19100.00
0005435502054	11234	Economy	19100.00
0005434573313	11234	Economy	19100.00
0005434573312	11234	Economy	19100.00
0005435545639	11234	Economy	19100.00
0005435545638	11234	Economy	19100.00
0005434573308	11234	Economy	19100.00
0005434573305	11234	Economy	19100.00
0005435502017	11234	Economy	19100.00
0005434573317	11234	Economy	19100.00
0005434573307	11234	Economy	19100.00
0005435502174	11234	Economy	19100.00
0005434573309	11234	Economy	19100.00
0005435502039	11234	Economy	19100.00
0005435517865	20953	Business	57200.00
0005434573236	20953	Business	57200.00
0005435319562	20953	Business	57200.00
0005435319560	20953	Business	57200.00
0005435502262	20953	Business	57200.00
0005432291922	20953	Business	57200.00
0005435319563	20953	Business	57200.00
0005434573145	20953	Business	57200.00
0005435319566	20953	Business	57200.00
0005435517872	20953	Business	57200.00
0005434573206	20953	Business	57200.00
0005435502259	20953	Economy	19100.00
0005435502252	20953	Economy	19100.00
0005434573185	20953	Economy	19100.00
0005435517858	20953	Economy	19100.00
0005435508331	20953	Economy	19100.00
0005434573180	20953	Economy	19100.00
0005434573151	20953	Economy	19100.00
0005434573193	20953	Economy	19100.00
0005435502246	20953	Economy	19100.00
0005434573174	20953	Economy	19100.00
0005434573156	20953	Economy	21000.00
0005432291924	20953	Economy	21000.00
0005435502254	20953	Economy	21000.00
0005435508329	20953	Economy	21000.00
0005435502243	20953	Economy	21000.00
0005435508325	20953	Economy	19100.00
0005435517854	20953	Economy	19100.00
0005435508330	20953	Economy	19100.00
0005435508334	20953	Economy	19100.00
0005435319567	20953	Economy	19100.00
0005435319564	20953	Economy	19100.00
0005435517857	20953	Economy	19100.00
0005435502255	20953	Economy	19100.00
0005434573166	20953	Economy	19100.00
0005435508333	20953	Economy	19100.00
0005434573211	20953	Economy	19100.00
0005435502258	20953	Economy	19100.00
0005435517867	20953	Economy	19100.00
0005435517863	20953	Economy	19100.00
0005435517870	20953	Economy	19100.00
0005435502251	20953	Economy	19100.00
0005435502247	20953	Economy	19100.00
0005435517862	20953	Economy	19100.00
0005435517869	20953	Economy	19100.00
0005435508327	20953	Economy	19100.00
0005435502250	20953	Economy	19100.00
0005434573205	20953	Economy	19100.00
0005435319559	20953	Economy	19100.00
0005435502253	20953	Economy	19100.00
0005435502256	20953	Economy	19100.00
0005434573173	20953	Economy	19100.00
0005435517864	20953	Economy	19100.00
0005435508332	20953	Economy	19100.00
0005435508326	20953	Economy	19100.00
0005435517868	20953	Economy	19100.00
0005435502261	20953	Economy	19100.00
0005435517853	20953	Economy	19100.00
0005435502260	20953	Economy	19100.00
0005435517855	20953	Economy	19100.00
0005435517861	20953	Economy	19100.00
0005435508336	20953	Economy	19100.00
0005435517859	20953	Economy	19100.00
0005435502264	20953	Economy	19100.00
0005435508324	20953	Economy	19100.00
0005435502248	20953	Economy	19100.00
0005435319561	20953	Economy	19100.00
0005435517856	20953	Economy	19100.00
0005435508335	20953	Economy	19100.00
0005434573223	20953	Economy	19100.00
0005435508323	20953	Economy	19100.00
0005435319565	20953	Economy	19100.00
0005435502257	20953	Economy	19100.00
0005434573198	20953	Economy	19100.00
0005434573240	20953	Economy	19100.00
0005435517871	20953	Economy	19100.00
0005435502263	20953	Economy	19100.00
0005432291923	20953	Economy	19100.00
0005435517866	20953	Economy	19100.00
0005435502244	20953	Economy	19100.00
0005434573184	20953	Economy	19100.00
0005435508328	20953	Economy	19100.00
0005434573165	20953	Economy	19100.00
0005435517860	20953	Economy	19100.00
0005435502245	20953	Economy	19100.00
0005435502249	20953	Economy	19100.00
0005435517852	20953	Economy	19100.00
0005432692740	2997	Business	10300.00
0005432692637	2997	Business	10300.00
0005432692820	2997	Business	10300.00
0005432692570	2997	Business	10300.00
0005432692649	2997	Economy	3400.00
0005432692650	2997	Economy	3400.00
0005432692626	2997	Economy	3400.00
0005432692578	2997	Economy	3800.00
0005432692809	2997	Economy	3400.00
0005432692703	2997	Economy	3400.00
0005432692774	2997	Economy	3400.00
0005432692821	2997	Economy	3400.00
0005432692879	2997	Economy	3400.00
0005432692817	2997	Economy	3400.00
0005432692710	2997	Economy	3400.00
0005432692841	2997	Economy	3400.00
0005432692842	2997	Economy	3400.00
0005432692750	2997	Economy	3400.00
0005432692696	2997	Economy	3400.00
0005432692688	2997	Economy	3400.00
0005432692620	2997	Economy	3400.00
0005432692621	2997	Economy	3400.00
0005432692697	2997	Economy	3400.00
0005432692670	2997	Economy	3400.00
0005432692653	2997	Economy	3400.00
0005432692701	2997	Economy	3400.00
0005432692731	2997	Economy	3400.00
0005432692808	2997	Economy	3400.00
0005432692880	2997	Economy	3400.00
0005432706703	2996	Business	10300.00
0005432880670	2996	Business	10300.00
0005432706723	2996	Business	10300.00
0005433123689	2996	Business	10300.00
0005432706709	2996	Business	10300.00
0005432706712	2996	Business	10300.00
0005432880649	2996	Business	10300.00
0005433123714	2996	Economy	3400.00
0005432706721	2996	Economy	3400.00
0005433123721	2996	Economy	3400.00
0005433123702	2996	Economy	3400.00
0005432706708	2996	Economy	3400.00
0005432880705	2996	Economy	3400.00
0005433123590	2996	Economy	3400.00
0005433123694	2996	Economy	3400.00
0005432880640	2996	Economy	3400.00
0005432706715	2996	Economy	3800.00
0005433123663	2996	Economy	3800.00
0005432706701	2996	Economy	3800.00
0005432880581	2996	Economy	3800.00
0005432706705	2996	Economy	3400.00
0005432880669	2996	Economy	3400.00
0005432880574	2996	Economy	3400.00
0005432706714	2996	Economy	3400.00
0005433123789	2996	Economy	3400.00
0005432880735	2996	Economy	3400.00
0005432880673	2996	Economy	3400.00
0005432880685	2996	Economy	3400.00
0005432706710	2996	Economy	3400.00
0005432706704	2996	Economy	3400.00
0005432706718	2996	Economy	3400.00
0005432706713	2996	Economy	3400.00
0005432880668	2996	Economy	3400.00
0005433123692	2996	Economy	3400.00
0005432880614	2996	Economy	3400.00
0005432706711	2996	Economy	3400.00
0005433123656	2996	Economy	3400.00
0005432217769	2996	Economy	3400.00
0005432880675	2996	Economy	3400.00
0005433123790	2996	Economy	3400.00
0005433123761	2996	Economy	3400.00
0005432706726	2996	Economy	3400.00
0005433123591	2996	Economy	3400.00
0005432706702	2996	Economy	3400.00
0005432880706	2996	Economy	3400.00
0005433123785	2996	Economy	3400.00
0005432880583	2996	Economy	3400.00
0005432706700	2996	Economy	3400.00
0005432880641	2996	Economy	3400.00
0005432706724	2996	Economy	3400.00
0005432706720	2996	Economy	3400.00
0005432880612	2996	Economy	3400.00
0005432706707	2996	Economy	3400.00
0005432706717	2996	Economy	3400.00
0005432706706	2996	Economy	3400.00
0005432880613	2996	Economy	3400.00
0005432880584	2996	Economy	3400.00
0005432880594	2996	Economy	3400.00
0005433123720	2996	Economy	3400.00
0005432217770	2996	Economy	3400.00
0005432706722	2996	Economy	3400.00
0005432880582	2996	Economy	3400.00
0005433123577	2996	Economy	3400.00
0005432880642	2996	Economy	3400.00
0005432880648	2996	Economy	3400.00
0005432706725	2996	Economy	3400.00
0005432880634	2996	Economy	3400.00
0005433123596	2996	Economy	3400.00
0005432880650	2996	Economy	3400.00
0005432706716	2996	Economy	3400.00
0005432880723	2996	Economy	3400.00
0005432706719	2996	Economy	3400.00
0005432880674	2996	Economy	3400.00
0005432880661	2996	Economy	3400.00
0005433123870	30017	Business	10300.00
0005432706566	30017	Business	10300.00
0005433123880	30017	Business	10300.00
0005432693018	30017	Business	10300.00
0005432693021	30017	Business	10300.00
0005432693016	30017	Business	10300.00
0005432706421	30017	Business	10300.00
0005432693024	30017	Business	10300.00
0005432706535	30017	Business	10300.00
0005433123879	30017	Business	10300.00
0005433194853	30017	Business	10300.00
0005432693010	30017	Business	10300.00
0005432706360	30017	Economy	3400.00
0005433123878	30017	Economy	3400.00
0005432693029	30017	Economy	3400.00
0005432693004	30017	Economy	3400.00
0005432880778	30017	Economy	3400.00
0005432693026	30017	Economy	3400.00
0005432693011	30017	Economy	3400.00
0005432706555	30017	Economy	3400.00
0005433123869	30017	Economy	3400.00
0005432693023	30017	Economy	3400.00
0005432693027	30017	Economy	3800.00
0005432693017	30017	Economy	3800.00
0005432693006	30017	Economy	3800.00
0005432706533	30017	Economy	3800.00
0005433123882	30017	Economy	3800.00
0005432706523	30017	Economy	3400.00
0005432880790	30017	Economy	3400.00
0005433123873	30017	Economy	3400.00
0005432693022	30017	Economy	3400.00
0005433123866	30017	Economy	3400.00
0005432693009	30017	Economy	3400.00
0005432706560	30017	Economy	3400.00
0005432706590	30017	Economy	3400.00
0005432706567	30017	Economy	3400.00
0005432693003	30017	Economy	3400.00
0005432880782	30017	Economy	3400.00
0005432706519	30017	Economy	3400.00
0005432706424	30017	Economy	3400.00
0005432880780	30017	Economy	3400.00
0005432693002	30017	Economy	3400.00
0005433123887	30017	Economy	3400.00
0005433123881	30017	Economy	3400.00
0005433123884	30017	Economy	3400.00
0005432693025	30017	Economy	3400.00
0005432693007	30017	Economy	3400.00
0005432880781	30017	Economy	3400.00
0005432693012	30017	Economy	3400.00
0005433123874	30017	Economy	3400.00
0005433123885	30017	Economy	3400.00
0005432880784	30017	Economy	3400.00
0005433194854	30017	Economy	3400.00
0005432693005	30017	Economy	3400.00
0005432693014	30017	Economy	3400.00
0005433194852	30017	Economy	3400.00
0005432880788	30017	Economy	3400.00
0005432693019	30017	Economy	3400.00
0005433194855	30017	Economy	3400.00
0005432880785	30017	Economy	3400.00
0005432706542	30017	Economy	3400.00
0005432706561	30017	Economy	3400.00
0005433123876	30017	Economy	3400.00
0005432880786	30017	Economy	3400.00
0005433123871	30017	Economy	3400.00
0005433123883	30017	Economy	3400.00
0005432706603	30017	Economy	3400.00
0005432706423	30017	Economy	3400.00
0005432706521	30017	Economy	3400.00
0005432880779	30017	Economy	3400.00
0005433123867	30017	Economy	3400.00
0005432880783	30017	Economy	3400.00
0005432693001	30017	Economy	3400.00
0005432706313	30017	Economy	3400.00
0005433123886	30017	Economy	3400.00
0005432693031	30017	Economy	3400.00
0005432693028	30017	Economy	3400.00
0005432706467	30017	Economy	3400.00
0005432880789	30017	Economy	3400.00
0005433123872	30017	Economy	3400.00
0005432693015	30017	Economy	3400.00
0005432693008	30017	Economy	3400.00
0005432706518	30017	Economy	3400.00
0005432880776	30017	Economy	3400.00
0005432693030	30017	Economy	3400.00
0005433123868	30017	Economy	3400.00
0005432706524	30017	Economy	3400.00
0005432706466	30017	Economy	3400.00
0005432693013	30017	Economy	3400.00
0005433194851	30017	Economy	3400.00
0005432880777	30017	Economy	3400.00
0005433123877	30017	Economy	3400.00
0005432706534	30017	Economy	3400.00
0005432880787	30017	Economy	3400.00
0005432693020	30017	Economy	3400.00
0005433123875	30017	Economy	3400.00
0005434979698	23662	Economy	4000.00
0005434979696	23662	Economy	4000.00
0005434988704	23662	Economy	4000.00
0005434988707	23662	Economy	4000.00
0005434979685	23662	Economy	3600.00
0005434979700	23662	Economy	3600.00
0005434988705	23662	Economy	3600.00
0005434979693	23662	Economy	3600.00
0005434988702	23662	Economy	3600.00
0005434979692	23662	Economy	3600.00
0005434979710	23662	Economy	3600.00
0005434979697	23662	Economy	3600.00
0005434979703	23662	Economy	3600.00
0005434979690	23662	Economy	3600.00
0005434988708	23662	Economy	3600.00
0005434979687	23662	Economy	3600.00
0005434979707	23662	Economy	3600.00
0005434979686	23662	Economy	3600.00
0005434979683	23662	Economy	3600.00
0005434979694	23662	Economy	3600.00
0005434988703	23662	Economy	3600.00
0005434979695	23662	Economy	3600.00
0005434979709	23662	Economy	3600.00
0005434979691	23662	Economy	3600.00
0005434979699	23662	Economy	3600.00
0005434979705	23662	Economy	3600.00
0005434988706	23662	Economy	3600.00
0005434988709	23662	Economy	3600.00
0005434979688	23662	Economy	3600.00
0005434979704	23662	Economy	3600.00
0005434979711	23662	Economy	3600.00
0005434979713	23662	Economy	3600.00
0005434979702	23662	Economy	3600.00
0005434979712	23662	Economy	3600.00
0005434979701	23662	Economy	3600.00
0005434979706	23662	Economy	3600.00
0005434979708	23662	Economy	3600.00
0005434979684	23662	Economy	3600.00
0005434979689	23662	Economy	3600.00
0005434979373	27545	Economy	4000.00
0005434988612	27545	Economy	4000.00
0005434988605	27545	Economy	4000.00
0005434979485	27545	Economy	3600.00
0005434988651	27545	Economy	3600.00
0005434979426	27545	Economy	3600.00
0005434988614	27545	Economy	3600.00
0005434988638	27545	Economy	3600.00
0005434979416	27545	Economy	3600.00
0005434979475	27545	Economy	3600.00
0005434988606	27545	Economy	3600.00
0005434979358	27545	Economy	3600.00
0005434988609	27545	Economy	3600.00
0005434988652	27545	Economy	3600.00
0005434979410	27545	Economy	3600.00
0005434979374	27545	Economy	3600.00
0005434988610	27545	Economy	3600.00
0005434979413	27545	Economy	3600.00
0005434988595	27545	Economy	3600.00
0005434979559	27545	Economy	3600.00
0005434988611	27545	Economy	3600.00
0005434979421	27545	Economy	3600.00
0005434979567	27545	Economy	3600.00
0005434979474	27545	Economy	3600.00
0005434302860	10250	Economy	21600.00
0005434302445	10250	Economy	21600.00
0005434302861	10250	Economy	19700.00
0005434302862	10250	Economy	19700.00
0005433111482	10250	Economy	19700.00
0005434302447	10250	Economy	19700.00
0005433113506	10250	Economy	19700.00
0005433113500	10250	Economy	19700.00
0005434302446	10250	Economy	19700.00
0005433113507	10250	Economy	19700.00
0005433113505	10250	Economy	19700.00
0005434302444	10250	Economy	19700.00
0005434302859	10250	Economy	19700.00
0005434302410	19600	Economy	19700.00
0005434302407	19600	Economy	19700.00
0005434302431	19600	Economy	19700.00
0005433113530	19600	Economy	19700.00
0005433113532	19600	Economy	19700.00
0005433113531	19600	Economy	19700.00
0005435939861	3581	Business	26900.00
0005435068961	3581	Business	26900.00
0005435068976	3581	Business	26900.00
0005435068985	3581	Business	26900.00
0005435069003	3581	Business	26900.00
0005435068964	3581	Business	26900.00
0005435068974	3581	Business	26900.00
0005435925136	3581	Business	26900.00
0005435718925	3581	Business	26900.00
0005435925152	3581	Economy	9000.00
0005435925139	3581	Economy	9000.00
0005435068967	3581	Economy	9000.00
0005435925129	3581	Economy	9000.00
0005435068953	3581	Economy	9000.00
0005435068988	3581	Economy	9000.00
0005435068987	3581	Economy	9000.00
0005435068995	3581	Economy	9900.00
0005435068993	3581	Economy	9900.00
0005435068984	3581	Economy	9900.00
0005435718921	3581	Economy	9900.00
0005435069000	3581	Economy	9900.00
0005435718927	3581	Economy	9000.00
0005435925144	3581	Economy	9000.00
0005435068972	3581	Economy	9000.00
0005435068963	3581	Economy	9000.00
0005435925121	3581	Economy	9000.00
0005435068966	3581	Economy	9000.00
0005435925124	3581	Economy	9000.00
0005435068983	3581	Economy	9000.00
0005435718923	3581	Economy	9000.00
0005435068971	3581	Economy	9000.00
0005435925145	3581	Economy	9000.00
0005435068959	3581	Economy	9000.00
0005435069004	3581	Economy	9000.00
0005435068965	3581	Economy	9000.00
0005435925125	3581	Economy	9000.00
0005435068968	3581	Economy	9000.00
0005435068981	3581	Economy	9000.00
0005435068962	3581	Economy	9000.00
0005435068999	3581	Economy	9000.00
0005435068997	3581	Economy	9000.00
0005435069005	3581	Economy	9000.00
0005435068969	3581	Economy	9000.00
0005435069002	3581	Economy	9000.00
0005435925123	3581	Economy	9000.00
0005435718922	3581	Economy	9000.00
0005435068955	3581	Economy	9000.00
0005435718924	3581	Economy	9000.00
0005435718926	3581	Economy	9000.00
0005435068980	3581	Economy	9000.00
0005435069006	3581	Economy	9000.00
0005435068991	3581	Economy	9000.00
0005435068982	3581	Economy	9000.00
0005435069001	3581	Economy	9000.00
0005435068956	3581	Economy	9000.00
0005435068958	3581	Economy	9000.00
0005435068990	3581	Economy	9000.00
0005435068994	3581	Economy	9000.00
0005435068954	3581	Economy	9000.00
0005435925140	3581	Economy	9000.00
0005435068992	3581	Economy	9000.00
0005435068957	3581	Economy	9000.00
0005435068977	3581	Economy	9000.00
0005435068960	3581	Economy	9000.00
0005435068975	3581	Economy	9000.00
0005435068970	3581	Economy	9000.00
0005435925141	3581	Economy	9000.00
0005435068996	3581	Economy	9000.00
0005435068978	3581	Economy	9000.00
0005435068986	3581	Economy	9000.00
0005435925143	3581	Economy	9000.00
0005435718928	3581	Economy	9000.00
0005435068989	3581	Economy	9000.00
0005435068979	3581	Economy	9000.00
0005435068998	3581	Economy	9000.00
0005435068973	3581	Economy	9000.00
0005435925100	3581	Economy	9000.00
0005435068570	15284	Business	26900.00
0005435068353	15284	Business	26900.00
0005435068204	15284	Business	26900.00
0005435068308	15284	Business	26900.00
0005435068571	15284	Business	26900.00
0005435068330	15284	Business	26900.00
0005435068574	15284	Business	26900.00
0005435068534	15284	Business	26900.00
0005435068576	15284	Business	26900.00
0005435068654	15284	Economy	9000.00
0005435925269	15284	Economy	9000.00
0005435068427	15284	Economy	9000.00
0005435068660	15284	Economy	9000.00
0005435068573	15284	Economy	9000.00
0005435925276	15284	Economy	9000.00
0005435068376	15284	Economy	9900.00
0005435068320	15284	Economy	9900.00
0005435068655	15284	Economy	9000.00
0005435068304	15284	Economy	9000.00
0005435925275	15284	Economy	9000.00
0005435068584	15284	Economy	9000.00
0005435925270	15284	Economy	9000.00
0005435068309	15284	Economy	9000.00
0005435068392	15284	Economy	9000.00
0005435068464	15284	Economy	9000.00
0005435068437	15284	Economy	9000.00
0005435068459	15284	Economy	9000.00
0005435068423	15284	Economy	9000.00
0005435068443	15284	Economy	9000.00
0005435068431	15284	Economy	9000.00
0005435068548	15284	Economy	9000.00
0005435068555	15284	Economy	9000.00
0005435068510	15284	Economy	9000.00
0005435068661	15284	Economy	9000.00
0005435068525	15284	Economy	9000.00
0005435068572	15284	Economy	9000.00
0005435068566	15284	Economy	9000.00
0005435068396	15284	Economy	9000.00
0005435068625	15284	Economy	9000.00
0005435068203	15284	Economy	9000.00
0005435925271	15284	Economy	9000.00
0005435068511	15284	Economy	9000.00
0005435068478	15284	Economy	9000.00
0005435925277	15284	Economy	9000.00
0005435068585	15284	Economy	9000.00
0005435068450	15284	Economy	9000.00
0005435925274	15284	Economy	9000.00
0005435068460	15284	Economy	9000.00
0005435068732	15284	Economy	9000.00
0005435068344	15284	Economy	9000.00
0005435068469	15284	Economy	9000.00
0005435068545	15284	Economy	9000.00
0005435068479	15284	Economy	9000.00
0005435068379	15284	Economy	9000.00
0005435068395	15284	Economy	9000.00
0005435068325	15284	Economy	9000.00
0005435068345	15284	Economy	9000.00
0005435068375	15284	Economy	9000.00
0005435925272	15284	Economy	9000.00
0005435925273	15284	Economy	9000.00
0005435068616	15284	Economy	9000.00
0005435068605	15284	Economy	9000.00
0005435068590	15284	Economy	9000.00
0005435068288	15284	Economy	9000.00
0005435068604	15284	Economy	9000.00
0005435068577	15284	Economy	9000.00
0005435068554	15284	Economy	9000.00
0005432659702	18132	Economy	5900.00
0005432659701	18132	Economy	5900.00
0005432658586	18132	Economy	5900.00
0005432660812	18132	Economy	5900.00
0005432660814	18132	Economy	5900.00
0005432658585	18132	Economy	5900.00
0005432658587	18132	Economy	5900.00
0005432660813	18132	Economy	5900.00
0005432667430	26396	Economy	5900.00
0005432667431	26396	Economy	5900.00
0005432660794	26396	Economy	5900.00
0005432157488	159	Business	20000.00
0005433101609	159	Business	20000.00
0005432901430	159	Business	20000.00
0005433101485	159	Business	20000.00
0005432919646	159	Business	20000.00
0005432919670	159	Business	20000.00
0005432919713	159	Business	20000.00
0005433101494	159	Business	20000.00
0005433101467	159	Business	20000.00
0005433101573	159	Business	20000.00
0005433101540	159	Business	20000.00
0005433101466	159	Business	20000.00
0005433101601	159	Business	20000.00
0005432919613	159	Business	20000.00
0005432901450	159	Business	20000.00
0005432919630	159	Economy	7300.00
0005432901495	159	Economy	7300.00
0005433101604	159	Economy	7300.00
0005433101523	159	Economy	6700.00
0005433101496	159	Economy	6700.00
0005432901446	159	Economy	6700.00
0005433101344	159	Economy	6700.00
0005432919648	159	Economy	6700.00
0005433101592	159	Economy	6700.00
0005433101562	159	Economy	6700.00
0005433101526	159	Economy	6700.00
0005432919668	159	Economy	6700.00
0005433101539	159	Economy	6700.00
0005432901468	159	Economy	6700.00
0005433101532	159	Economy	6700.00
0005432919682	159	Economy	6700.00
0005432901451	159	Economy	6700.00
0005432901396	159	Economy	6700.00
0005433101404	159	Economy	6700.00
0005433101582	159	Economy	6700.00
0005432901467	159	Economy	6700.00
0005433101603	159	Economy	6700.00
0005432157487	159	Economy	6700.00
0005433101397	159	Economy	6700.00
0005432901493	159	Economy	6700.00
0005432901394	159	Economy	6700.00
0005433101460	159	Economy	6700.00
0005432919649	159	Economy	6700.00
0005432677530	159	Economy	6700.00
0005432919698	159	Economy	6700.00
0005432919574	159	Economy	6700.00
0005432919650	159	Economy	6700.00
0005432919505	159	Economy	6700.00
0005433101521	159	Economy	6700.00
0005432919693	159	Economy	6700.00
0005433101503	159	Economy	6700.00
0005432677516	159	Economy	6700.00
0005433101477	159	Economy	6700.00
0005432919712	159	Economy	7300.00
0005433101418	159	Economy	6700.00
0005432919703	159	Economy	6700.00
0005433101356	159	Economy	6700.00
0005432919651	159	Economy	6700.00
0005432901479	159	Economy	6700.00
0005433101545	159	Economy	6700.00
0005433101499	159	Economy	6700.00
0005432919683	159	Economy	6700.00
0005432901448	159	Economy	6700.00
0005433101552	159	Economy	6700.00
0005432901541	159	Economy	6700.00
0005433101351	159	Economy	6700.00
0005432901461	159	Economy	6700.00
0005433101459	159	Economy	6700.00
0005432901436	159	Economy	6700.00
0005433101468	159	Economy	6700.00
0005432901392	159	Economy	6700.00
0005432901507	159	Economy	6700.00
0005432901464	159	Economy	6700.00
0005433101443	159	Economy	6700.00
0005433101612	159	Economy	6700.00
0005433101613	159	Economy	6700.00
0005433101596	159	Economy	6700.00
0005433101608	159	Economy	6700.00
0005433101377	159	Economy	6700.00
0005432919637	159	Economy	6700.00
0005432901478	159	Economy	6700.00
0005432901435	159	Economy	6700.00
0005432919532	159	Economy	6700.00
0005432677515	159	Economy	6700.00
0005433101410	159	Economy	6700.00
0005433101551	159	Economy	6700.00
0005432901404	159	Economy	6700.00
0005432901449	159	Economy	6700.00
0005433101396	159	Economy	6700.00
0005432919719	159	Economy	6700.00
0005432901447	159	Economy	6700.00
0005432901395	159	Economy	6700.00
0005433101504	159	Economy	6700.00
0005432919706	159	Economy	6700.00
0005432919625	159	Economy	6700.00
0005432919603	159	Economy	6700.00
0005432901458	159	Economy	6700.00
0005432919647	159	Economy	6700.00
0005433101345	159	Economy	6700.00
0005433101533	159	Economy	6700.00
0005432261830	160	Business	20000.00
0005432261802	160	Business	20000.00
0005432817399	160	Business	20000.00
0005432261805	160	Business	20000.00
0005432261806	160	Business	20000.00
0005432817418	160	Business	20000.00
0005432817397	160	Business	20000.00
0005432817400	160	Business	20000.00
0005432753246	160	Business	20000.00
0005432261809	160	Business	20000.00
0005432207656	160	Business	20000.00
0005434153528	160	Business	20000.00
0005432261834	160	Business	20000.00
0005433687680	160	Business	20000.00
0005432261822	160	Business	20000.00
0005432261807	160	Business	20000.00
0005432817419	160	Business	20000.00
0005432753248	160	Business	20000.00
0005432817407	160	Business	20000.00
0005432261791	160	Economy	7300.00
0005432817423	160	Economy	7300.00
0005432261798	160	Economy	7300.00
0005432261829	160	Economy	7300.00
0005432261825	160	Economy	6700.00
0005432261808	160	Economy	6700.00
0005432261821	160	Economy	6700.00
0005432261833	160	Economy	6700.00
0005432261816	160	Economy	6700.00
0005432753249	160	Economy	6700.00
0005432288979	160	Economy	6700.00
0005432261794	160	Economy	6700.00
0005432261804	160	Economy	6700.00
0005432817417	160	Economy	6700.00
0005432261799	160	Economy	6700.00
0005432817401	160	Economy	6700.00
0005432261818	160	Economy	6700.00
0005432261820	160	Economy	6700.00
0005432817422	160	Economy	6700.00
0005432817416	160	Economy	6700.00
0005432261800	160	Economy	6700.00
0005432261801	160	Economy	6700.00
0005432261827	160	Economy	6700.00
0005432261797	160	Economy	6700.00
0005432261828	160	Economy	6700.00
0005432817394	160	Economy	6700.00
0005432261815	160	Economy	6700.00
0005433690906	160	Economy	6700.00
0005434153530	160	Economy	6700.00
0005432261792	160	Economy	6700.00
0005432261832	160	Economy	6700.00
0005432261831	160	Economy	6700.00
0005432207655	160	Economy	6700.00
0005432817420	160	Economy	7300.00
0005432261835	160	Economy	7300.00
0005432817405	160	Economy	6700.00
0005433687688	160	Economy	6700.00
0005433690903	160	Economy	6700.00
0005432817415	160	Economy	6700.00
0005432817404	160	Economy	6700.00
0005432261836	160	Economy	6700.00
0005432261814	160	Economy	6700.00
0005432817406	160	Economy	6700.00
0005432261803	160	Economy	6700.00
0005432261795	160	Economy	6700.00
0005432261796	160	Economy	6700.00
0005432817403	160	Economy	6700.00
0005432817411	160	Economy	6700.00
0005432261826	160	Economy	6700.00
0005432817402	160	Economy	6700.00
0005432817412	160	Economy	6700.00
0005432261819	160	Economy	6700.00
0005432817395	160	Economy	6700.00
0005432288980	160	Economy	6700.00
0005432753247	160	Economy	6700.00
0005432261823	160	Economy	6700.00
0005432261793	160	Economy	6700.00
0005432753263	160	Economy	6700.00
0005432817398	160	Economy	6700.00
0005432261810	160	Economy	6700.00
0005432817396	160	Economy	6700.00
0005432817424	160	Economy	6700.00
0005432261813	160	Economy	6700.00
0005432817408	160	Economy	6700.00
0005432756800	160	Economy	6700.00
0005432817409	160	Economy	6700.00
0005432261817	160	Economy	6700.00
0005432261790	160	Economy	6700.00
0005434153529	160	Economy	6700.00
0005432817410	160	Economy	6700.00
0005432261811	160	Economy	6700.00
0005432817414	160	Economy	6700.00
0005432261812	160	Economy	6700.00
0005432817413	160	Economy	6700.00
0005432817421	160	Economy	6700.00
0005432261824	160	Economy	6700.00
0005432756787	160	Economy	6700.00
0005432207654	160	Economy	6700.00
0005433102023	8128	Business	20000.00
0005432919817	8128	Business	20000.00
0005432020211	8128	Business	20000.00
0005433102045	8128	Business	20000.00
0005432020208	8128	Business	20000.00
0005432020192	8128	Business	20000.00
0005433102040	8128	Business	20000.00
0005432020212	8128	Business	20000.00
0005432919809	8128	Business	20000.00
0005433102017	8128	Business	20000.00
0005432919815	8128	Business	20000.00
0005433102046	8128	Business	20000.00
0005433102044	8128	Business	20000.00
0005432919808	8128	Business	20000.00
0005433102016	8128	Business	20000.00
0005433102029	8128	Business	20000.00
0005433102025	8128	Business	20000.00
0005432751522	8128	Business	20000.00
0005432020216	8128	Business	20000.00
0005432020217	8128	Business	20000.00
0005432020191	8128	Business	20000.00
0005433102056	8128	Business	20000.00
0005432020199	8128	Business	20000.00
0005432020190	8128	Economy	7300.00
0005432020205	8128	Economy	7300.00
0005432020215	8128	Economy	7300.00
0005433102052	8128	Economy	7300.00
0005432919814	8128	Economy	6700.00
0005432919822	8128	Economy	6700.00
0005432020195	8128	Economy	6700.00
0005432919818	8128	Economy	6700.00
0005432020210	8128	Economy	6700.00
0005433102050	8128	Economy	6700.00
0005433102028	8128	Economy	6700.00
0005433102027	8128	Economy	6700.00
0005433102035	8128	Economy	6700.00
0005432020194	8128	Economy	6700.00
0005432919812	8128	Economy	6700.00
0005433102049	8128	Economy	6700.00
0005432919803	8128	Economy	6700.00
0005432919823	8128	Economy	6700.00
0005433102059	8128	Economy	6700.00
0005433102019	8128	Economy	6700.00
0005432919820	8128	Economy	6700.00
0005433102020	8128	Economy	6700.00
0005433102024	8128	Economy	6700.00
0005432020200	8128	Economy	6700.00
0005432020209	8128	Economy	6700.00
0005432919807	8128	Economy	6700.00
0005432919810	8128	Economy	6700.00
0005433102041	8128	Economy	6700.00
0005432751521	8128	Economy	6700.00
0005432020207	8128	Economy	6700.00
0005433102034	8128	Economy	6700.00
0005432391994	8128	Economy	6700.00
0005433102053	8128	Economy	6700.00
0005433102030	8128	Economy	6700.00
0005432677565	8128	Economy	6700.00
0005433102033	8128	Economy	6700.00
0005432919819	8128	Economy	6700.00
0005432753293	8128	Economy	6700.00
0005433102036	8128	Economy	6700.00
0005433102048	8128	Economy	6700.00
0005432391993	8128	Economy	6700.00
0005432677564	8128	Economy	6700.00
0005433102058	8128	Economy	6700.00
0005432020193	8128	Economy	6700.00
0005432677566	8128	Economy	7300.00
0005432020206	8128	Economy	7300.00
0005432020198	8128	Economy	7300.00
0005432020202	8128	Economy	6700.00
0005433102021	8128	Economy	7300.00
0005432044518	8128	Economy	6700.00
0005433102057	8128	Economy	6700.00
0005433102060	8128	Economy	6700.00
0005432751519	8128	Economy	6700.00
0005432020213	8128	Economy	6700.00
0005432919813	8128	Economy	6700.00
0005433102032	8128	Economy	6700.00
0005433102022	8128	Economy	6700.00
0005433102039	8128	Economy	6700.00
0005432020204	8128	Economy	6700.00
0005432919821	8128	Economy	6700.00
0005433102038	8128	Economy	6700.00
0005432020201	8128	Economy	6700.00
0005433102043	8128	Economy	6700.00
0005432045610	8128	Economy	6700.00
0005433102047	8128	Economy	6700.00
0005432919811	8128	Economy	6700.00
0005432751520	8128	Economy	6700.00
0005432919805	8128	Economy	6700.00
0005433102051	8128	Economy	6700.00
0005432753296	8128	Economy	6700.00
0005433102055	8128	Economy	6700.00
0005433102062	8128	Economy	6700.00
0005433102054	8128	Economy	6700.00
0005432751518	8128	Economy	6700.00
0005433102018	8128	Economy	6700.00
0005432020214	8128	Economy	6700.00
0005432753295	8128	Economy	6700.00
0005432919804	8128	Economy	6700.00
0005432919806	8128	Economy	6700.00
0005433102061	8128	Economy	6700.00
0005432020203	8128	Economy	6700.00
0005433102031	8128	Economy	6700.00
0005432391992	8128	Economy	6700.00
0005433102037	8128	Economy	6700.00
0005432919802	8128	Economy	6700.00
0005432753294	8128	Economy	6700.00
0005432677567	8128	Economy	6700.00
0005432020197	8128	Economy	6700.00
0005433102042	8128	Economy	6700.00
0005433102026	8128	Economy	6700.00
0005432020196	8128	Economy	6700.00
0005432044519	8128	Economy	6700.00
0005432919816	8128	Economy	6700.00
0005432817204	8129	Business	20000.00
0005432817237	8129	Business	20000.00
0005432901576	8129	Business	20000.00
0005432901575	8129	Business	20000.00
0005432901566	8129	Business	20000.00
0005432817060	8129	Business	20000.00
0005432817203	8129	Business	20000.00
0005432817189	8129	Business	20000.00
0005432817059	8129	Economy	7300.00
0005432817229	8129	Economy	6700.00
0005432817191	8129	Economy	6700.00
0005432817115	8129	Economy	6700.00
0005432817116	8129	Economy	6700.00
0005432817261	8129	Economy	6700.00
0005432817192	8129	Economy	6700.00
0005432901569	8129	Economy	6700.00
0005432901564	8129	Economy	6700.00
0005432901573	8129	Economy	6700.00
0005432817150	8129	Economy	6700.00
0005432901565	8129	Economy	6700.00
0005432817186	8129	Economy	6700.00
0005432817111	8129	Economy	6700.00
0005432817044	8129	Economy	6700.00
0005432817238	8129	Economy	6700.00
0005432817202	8129	Economy	6700.00
0005432817124	8129	Economy	6700.00
0005432817140	8129	Economy	6700.00
0005432817152	8129	Economy	6700.00
0005432817139	8129	Economy	6700.00
0005432817228	8129	Economy	6700.00
0005432901571	8129	Economy	6700.00
0005432901572	8129	Economy	6700.00
0005432901579	8129	Economy	6700.00
0005432901578	8129	Economy	6700.00
0005432817141	8129	Economy	6700.00
0005432901580	8129	Economy	6700.00
0005432901574	8129	Economy	6700.00
0005432817207	8129	Economy	6700.00
0005432817165	8129	Economy	6700.00
0005432901577	8129	Economy	6700.00
0005432002071	8129	Economy	6700.00
0005432901570	8129	Economy	6700.00
0005432901567	8129	Economy	6700.00
0005432817248	8129	Economy	6700.00
0005432817190	8129	Economy	6700.00
0005432901568	8129	Economy	6700.00
0005432817194	8129	Economy	6700.00
0005433870725	9644	Economy	6900.00
0005434175703	9644	Economy	6900.00
0005434175726	9644	Economy	6900.00
0005433870726	9644	Economy	6900.00
0005434175724	9644	Economy	6900.00
0005434175689	9644	Economy	6900.00
0005434175745	32350	Economy	6900.00
0005434175743	32350	Economy	6900.00
0005433870709	32350	Economy	6900.00
0005433870715	32350	Economy	6900.00
0005434175744	32350	Economy	6900.00
0005433870714	32350	Economy	6900.00
0005434175742	32350	Economy	6900.00
0005434878101	3480	Business	35000.00
0005435126297	3480	Business	35000.00
0005434426565	3480	Business	35000.00
0005434426544	3480	Business	35000.00
0005434878068	3480	Business	35000.00
0005432799388	3480	Business	35000.00
0005434878105	3480	Business	35000.00
0005434878040	3480	Business	35000.00
0005435126290	3480	Business	35000.00
0005435126275	3480	Business	35000.00
0005434878096	3480	Business	35000.00
0005434878008	3480	Business	35000.00
0005434878023	3480	Business	35000.00
0005434878048	3480	Business	35000.00
0005434878097	3480	Business	35000.00
0005434426566	3480	Business	35000.00
0005435126276	3480	Business	35000.00
0005434878044	3480	Business	35000.00
0005434878032	3480	Business	35000.00
0005432799415	3480	Business	35000.00
0005434878064	3480	Business	35000.00
0005434878067	3480	Business	35000.00
0005432799410	3480	Business	35000.00
0005434878016	3480	Comfort	19900.00
0005432799398	3480	Comfort	19900.00
0005434878009	3480	Comfort	19900.00
0005434938109	3480	Comfort	19900.00
0005432799401	3480	Comfort	19900.00
0005432799394	3480	Comfort	19900.00
0005435126289	3480	Comfort	19900.00
0005435902619	3480	Comfort	19900.00
0005434878025	3480	Comfort	19900.00
0005435126305	3480	Comfort	19900.00
0005435126298	3480	Comfort	19900.00
0005434938098	3480	Comfort	19900.00
0005434426538	3480	Comfort	19900.00
0005434938106	3480	Comfort	19900.00
0005432613852	3480	Comfort	19900.00
0005434878091	3480	Comfort	19900.00
0005435126296	3480	Comfort	19900.00
0005434426551	3480	Comfort	19900.00
0005434938105	3480	Comfort	19900.00
0005434878059	3480	Comfort	19900.00
0005432611703	3480	Comfort	19900.00
0005432183462	3480	Comfort	19900.00
0005434878035	3480	Comfort	19900.00
0005432613854	3480	Comfort	19900.00
0005435902471	3480	Comfort	19900.00
0005434878086	3480	Comfort	19900.00
0005434426562	3480	Comfort	19900.00
0005434878058	3480	Comfort	19900.00
0005435126281	3480	Comfort	19900.00
0005434878031	3480	Economy	11700.00
0005435126278	3480	Economy	11700.00
0005434938110	3480	Economy	11700.00
0005434878029	3480	Economy	11700.00
0005434938100	3480	Economy	11700.00
0005432799405	3480	Economy	11700.00
0005434426547	3480	Economy	11700.00
0005434878087	3480	Economy	11700.00
0005434426557	3480	Economy	11700.00
0005432611704	3480	Economy	11700.00
0005434878094	3480	Economy	11700.00
0005434878012	3480	Economy	11700.00
0005434878054	3480	Economy	11700.00
0005435902564	3480	Economy	11700.00
0005434426548	3480	Economy	11700.00
0005434938102	3480	Economy	11700.00
0005435902568	3480	Economy	11700.00
0005432799391	3480	Economy	11700.00
0005435126309	3480	Economy	11700.00
0005434878072	3480	Economy	11700.00
0005434426552	3480	Economy	11700.00
0005434938096	3480	Economy	11700.00
0005432611702	3480	Economy	11700.00
0005435126291	3480	Economy	11700.00
0005432799403	3480	Economy	11700.00
0005434878069	3480	Economy	11700.00
0005434426558	3480	Economy	11700.00
0005432188601	3480	Economy	11700.00
0005435126277	3480	Economy	11700.00
0005435126274	3480	Economy	11700.00
0005434878071	3480	Economy	11700.00
0005434878098	3480	Economy	11700.00
0005434878017	3480	Economy	11700.00
0005434878090	3480	Economy	11700.00
0005434878033	3480	Economy	11700.00
0005434426561	3480	Economy	11700.00
0005434426540	3480	Economy	11700.00
0005434426539	3480	Economy	11700.00
0005435626142	3480	Economy	11700.00
0005434938099	3480	Economy	11700.00
0005434938112	3480	Economy	11700.00
0005434878100	3480	Economy	11700.00
0005435126295	3480	Economy	11700.00
0005434878083	3480	Economy	11700.00
0005434878038	3480	Economy	11700.00
0005434938097	3480	Economy	11700.00
0005434938111	3480	Economy	11700.00
0005435902588	3480	Economy	11700.00
0005434878037	3480	Economy	11700.00
0005435126287	3480	Economy	11700.00
0005434878065	3480	Economy	12800.00
0005432613851	3480	Economy	11700.00
0005432799392	3480	Economy	11700.00
0005434878078	3480	Economy	11700.00
0005435126273	3480	Economy	12800.00
0005434426541	3480	Economy	11700.00
0005434878061	3480	Economy	12800.00
0005435914687	3480	Economy	11700.00
0005434878047	3480	Economy	11700.00
0005434878036	3480	Economy	11700.00
0005434878026	3480	Economy	11700.00
0005435126288	3480	Economy	11700.00
0005435902426	3480	Economy	11700.00
0005434878057	3480	Economy	11700.00
0005434878104	3480	Economy	11700.00
0005432799393	3480	Economy	11700.00
0005435126300	3480	Economy	11700.00
0005435126294	3480	Economy	11700.00
0005435126308	3480	Economy	11700.00
0005434878076	3480	Economy	11700.00
0005434878030	3480	Economy	11700.00
0005435126301	3480	Economy	11700.00
0005432799409	3480	Economy	11700.00
0005432799408	3480	Economy	11700.00
0005434878075	3480	Economy	11700.00
0005432613855	3480	Economy	11700.00
0005434878052	3480	Economy	11700.00
0005432799413	3480	Economy	11700.00
0005432613853	3480	Economy	11700.00
0005435902557	3480	Economy	11700.00
0005434426546	3480	Economy	11700.00
0005434878085	3480	Economy	11700.00
0005435902499	3480	Economy	11700.00
0005435126292	3480	Economy	11700.00
0005432183463	3480	Economy	11700.00
0005434878089	3480	Economy	11700.00
0005434878070	3480	Economy	11700.00
0005432799404	3480	Economy	11700.00
0005434878034	3480	Economy	11700.00
0005432799411	3480	Economy	11700.00
0005434426563	3480	Economy	11700.00
0005432799390	3480	Economy	11700.00
0005435902507	3480	Economy	11700.00
0005435626143	3480	Economy	11700.00
0005434878021	3480	Economy	11700.00
0005434878027	3480	Economy	11700.00
0005434878045	3480	Economy	11700.00
0005432799402	3480	Economy	11700.00
0005434878039	3480	Economy	11700.00
0005434878024	3480	Economy	11700.00
0005434938101	3480	Economy	11700.00
0005434426553	3480	Economy	11700.00
0005432799407	3480	Economy	11700.00
0005435126282	3480	Economy	11700.00
0005435626140	3480	Economy	11700.00
0005432799389	3480	Economy	11700.00
0005435126303	3480	Economy	11700.00
0005434878042	3480	Economy	11700.00
0005435126307	3480	Economy	11700.00
0005434426550	3480	Economy	11700.00
0005434878046	3480	Economy	11700.00
0005435902495	3480	Economy	11700.00
0005432799387	3480	Economy	11700.00
0005435126310	3480	Economy	11700.00
0005435126284	3480	Economy	11700.00
0005434426542	3480	Economy	11700.00
0005434878074	3480	Economy	11700.00
0005434938095	3480	Economy	11700.00
0005432611701	3480	Economy	11700.00
0005434878080	3480	Economy	11700.00
0005434938108	3480	Economy	11700.00
0005434878073	3480	Economy	11700.00
0005434878022	3480	Economy	11700.00
0005434878063	3480	Economy	11700.00
0005434426549	3480	Economy	11700.00
0005435126311	3480	Economy	11700.00
0005434938093	3480	Economy	11700.00
0005434426556	3480	Economy	11700.00
0005435126304	3480	Economy	11700.00
0005434878084	3480	Economy	11700.00
0005435902474	3480	Economy	11700.00
0005434878099	3480	Economy	11700.00
0005434878056	3480	Economy	11700.00
0005432799399	3480	Economy	11700.00
0005432188600	3480	Economy	12800.00
0005434878093	3480	Economy	12800.00
0005435626138	3480	Economy	12800.00
0005434426555	3480	Economy	12800.00
0005434878020	3480	Economy	12800.00
0005434878013	3480	Economy	12800.00
0005435626141	3480	Economy	11700.00
0005432799395	3480	Economy	11700.00
0005435902505	3480	Economy	11700.00
0005434878010	3480	Economy	11700.00
0005432799414	3480	Economy	11700.00
0005434878014	3480	Economy	11700.00
0005434426559	3480	Economy	11700.00
0005432799412	3480	Economy	11700.00
0005434878043	3480	Economy	11700.00
0005434878082	3480	Economy	11700.00
0005434878062	3480	Economy	11700.00
0005434878050	3480	Economy	11700.00
0005432188602	3480	Economy	11700.00
0005434878088	3480	Economy	11700.00
0005434426554	3480	Economy	11700.00
0005434938113	3480	Economy	11700.00
0005432799396	3480	Economy	11700.00
0005435126312	3480	Economy	11700.00
0005435126279	3480	Economy	11700.00
0005435126286	3480	Economy	11700.00
0005435126299	3480	Economy	11700.00
0005435126293	3480	Economy	11700.00
0005434878041	3480	Economy	11700.00
0005432799397	3480	Economy	11700.00
0005434426543	3480	Economy	11700.00
0005435126306	3480	Economy	11700.00
0005434878019	3480	Economy	11700.00
0005434938104	3480	Economy	11700.00
0005434878015	3480	Economy	11700.00
0005434878028	3480	Economy	11700.00
0005434878079	3480	Economy	11700.00
0005434426560	3480	Economy	11700.00
0005435902502	3480	Economy	11700.00
0005435126283	3480	Economy	11700.00
0005434426564	3480	Economy	11700.00
0005434878077	3480	Economy	11700.00
0005435126285	3480	Economy	11700.00
0005434878018	3480	Economy	11700.00
0005434938107	3480	Economy	11700.00
0005434878092	3480	Economy	11700.00
0005434878011	3480	Economy	11700.00
0005434938094	3480	Economy	11700.00
0005434878055	3480	Economy	11700.00
0005434878081	3480	Economy	11700.00
0005434878053	3480	Economy	11700.00
0005435126280	3480	Economy	11700.00
0005435126313	3480	Economy	11700.00
0005435126272	3480	Economy	11700.00
0005434878095	3480	Economy	11700.00
0005432799406	3480	Economy	11700.00
0005435902558	3480	Economy	11700.00
0005435626144	3480	Economy	11700.00
0005434878103	3480	Economy	11700.00
0005435126302	3480	Economy	11700.00
0005435626139	3480	Economy	11700.00
0005434878049	3480	Economy	11700.00
0005432611700	3480	Economy	11700.00
0005434938103	3480	Economy	11700.00
0005434878051	3480	Economy	11700.00
0005434878102	3480	Economy	11700.00
0005434878060	3480	Economy	11700.00
0005434878066	3480	Economy	11700.00
0005434426545	3480	Economy	11700.00
0005432799400	3480	Economy	11700.00
0005434426203	14561	Business	35000.00
0005435902665	14561	Business	35000.00
0005435625907	14561	Business	35000.00
0005432799183	14561	Business	35000.00
0005434876963	14561	Business	35000.00
0005434426234	14561	Business	35000.00
0005432799119	14561	Business	35000.00
0005435125874	14561	Business	35000.00
0005434877550	14561	Business	35000.00
0005434876986	14561	Business	35000.00
0005435625942	14561	Business	35000.00
0005434426404	14561	Business	35000.00
0005434877438	14561	Business	35000.00
0005434877113	14561	Business	35000.00
0005432799079	14561	Business	35000.00
0005435902671	14561	Business	35000.00
0005435126077	14561	Business	35000.00
0005434877155	14561	Business	35000.00
0005434877521	14561	Comfort	19900.00
0005434426423	14561	Comfort	19900.00
0005434877329	14561	Comfort	19900.00
0005434877440	14561	Comfort	19900.00
0005435125811	14561	Comfort	19900.00
0005435125957	14561	Comfort	19900.00
0005434876952	14561	Comfort	19900.00
0005435125872	14561	Comfort	19900.00
0005434877549	14561	Comfort	19900.00
0005435125900	14561	Comfort	19900.00
0005434877167	14561	Comfort	19900.00
0005434877054	14561	Comfort	19900.00
0005434426299	14561	Comfort	19900.00
0005435902662	14561	Comfort	19900.00
0005434877109	14561	Comfort	19900.00
0005434937870	14561	Comfort	19900.00
0005435125992	14561	Comfort	19900.00
0005435842326	14561	Comfort	19900.00
0005435625934	14561	Comfort	19900.00
0005434877307	14561	Comfort	19900.00
0005434937952	14561	Comfort	19900.00
0005434426353	14561	Comfort	19900.00
0005432799115	14561	Comfort	19900.00
0005434937917	14561	Comfort	19900.00
0005435902670	14561	Comfort	19900.00
0005434426354	14561	Comfort	19900.00
0005434877184	14561	Comfort	19900.00
0005435125878	14561	Comfort	19900.00
0005434876898	14561	Comfort	19900.00
0005434877380	14561	Comfort	19900.00
0005434876604	14561	Economy	11700.00
0005434877060	14561	Economy	11700.00
0005434877196	14561	Economy	11700.00
0005434426291	14561	Economy	11700.00
0005434877154	14561	Economy	11700.00
0005435625931	14561	Economy	11700.00
0005434426414	14561	Economy	11700.00
0005434877207	14561	Economy	11700.00
0005434877356	14561	Economy	11700.00
0005434937968	14561	Economy	11700.00
0005434877117	14561	Economy	11700.00
0005434426225	14561	Economy	11700.00
0005435125822	14561	Economy	11700.00
0005434876961	14561	Economy	11700.00
0005434877074	14561	Economy	11700.00
0005434876605	14561	Economy	11700.00
0005434876883	14561	Economy	11700.00
0005434876951	14561	Economy	11700.00
0005432799215	14561	Economy	11700.00
0005434426313	14561	Economy	11700.00
0005432059499	14561	Economy	11700.00
0005435126033	14561	Economy	11700.00
0005434877040	14561	Economy	11700.00
0005434877522	14561	Economy	11700.00
0005434876962	14561	Economy	11700.00
0005435902658	14561	Economy	11700.00
0005435902668	14561	Economy	11700.00
0005435125732	14561	Economy	11700.00
0005435125873	14561	Economy	11700.00
0005432799165	14561	Economy	11700.00
0005432799182	14561	Economy	11700.00
0005434877460	14561	Economy	11700.00
0005432799136	14561	Economy	11700.00
0005435125755	14561	Economy	11700.00
0005435902669	14561	Economy	11700.00
0005435125958	14561	Economy	11700.00
0005435125921	14561	Economy	11700.00
0005434876841	14561	Economy	11700.00
0005434877340	14561	Economy	11700.00
0005435126005	14561	Economy	11700.00
0005435125862	14561	Economy	11700.00
0005434876899	14561	Economy	11700.00
0005435902674	14561	Economy	12800.00
0005434877419	14561	Economy	12800.00
0005435126076	14561	Economy	11700.00
0005434876884	14561	Economy	11700.00
0005435625925	14561	Economy	12800.00
0005432799255	14561	Economy	12800.00
0005434877420	14561	Economy	11700.00
0005434426176	14561	Economy	11700.00
0005434426309	14561	Economy	11700.00
0005434426298	14561	Economy	11700.00
0005434877221	14561	Economy	11700.00
0005435625947	14561	Economy	11700.00
0005434876970	14561	Economy	11700.00
0005434877188	14561	Economy	11700.00
0005434876987	14561	Economy	11700.00
0005434877437	14561	Economy	11700.00
0005434877614	14561	Economy	11700.00
0005434876660	14561	Economy	11700.00
0005434876744	14561	Economy	11700.00
0005435125901	14561	Economy	11700.00
0005435902673	14561	Economy	11700.00
0005435625943	14561	Economy	11700.00
0005434877156	14561	Economy	11700.00
0005435125871	14561	Economy	11700.00
0005434877254	14561	Economy	11700.00
0005434877305	14561	Economy	11700.00
0005434876700	14561	Economy	11700.00
0005434877327	14561	Economy	11700.00
0005434426208	14561	Economy	11700.00
0005435125779	14561	Economy	11700.00
0005434426226	14561	Economy	11700.00
0005435125786	14561	Economy	11700.00
0005434877032	14561	Economy	11700.00
0005435125947	14561	Economy	11700.00
0005434877202	14561	Economy	11700.00
0005435625944	14561	Economy	11700.00
0005435125930	14561	Economy	11700.00
0005435125832	14561	Economy	11700.00
0005434877262	14561	Economy	11700.00
0005432799107	14561	Economy	11700.00
0005435125731	14561	Economy	11700.00
0005435125927	14561	Economy	11700.00
0005435902664	14561	Economy	11700.00
0005434426364	14561	Economy	11700.00
0005434877491	14561	Economy	11700.00
0005434877811	14561	Economy	11700.00
0005435625913	14561	Economy	11700.00
0005435625969	14561	Economy	11700.00
0005435126004	14561	Economy	11700.00
0005432799181	14561	Economy	11700.00
0005434877108	14561	Economy	11700.00
0005434877256	14561	Economy	11700.00
0005435126042	14561	Economy	11700.00
0005432059500	14561	Economy	11700.00
0005434877033	14561	Economy	11700.00
0005434877220	14561	Economy	11700.00
0005435902657	14561	Economy	11700.00
0005434877145	14561	Economy	11700.00
0005434876701	14561	Economy	11700.00
0005435902667	14561	Economy	11700.00
0005435625933	14561	Economy	11700.00
0005434877377	14561	Economy	11700.00
0005434426405	14561	Economy	11700.00
0005434877500	14561	Economy	11700.00
0005434937868	14561	Economy	11700.00
0005435902659	14561	Economy	11700.00
0005434937925	14561	Economy	11700.00
0005434426235	14561	Economy	11700.00
0005434877328	14561	Economy	11700.00
0005435125843	14561	Economy	11700.00
0005434426297	14561	Economy	11700.00
0005435625906	14561	Economy	11700.00
0005434876743	14561	Economy	12800.00
0005434877273	14561	Economy	12800.00
0005435125730	14561	Economy	12800.00
0005434877274	14561	Economy	12800.00
0005434876661	14561	Economy	11700.00
0005435902660	14561	Economy	11700.00
0005435125810	14561	Economy	11700.00
0005434877297	14561	Economy	11700.00
0005435125703	14561	Economy	11700.00
0005434877272	14561	Economy	11700.00
0005432799080	14561	Economy	11700.00
0005434426121	14561	Economy	11700.00
0005435902663	14561	Economy	11700.00
0005435625961	14561	Economy	11700.00
0005434877346	14561	Economy	11700.00
0005435902666	14561	Economy	11700.00
0005434877135	14561	Economy	11700.00
0005434876659	14561	Economy	11700.00
0005434426355	14561	Economy	11700.00
0005434426340	14561	Economy	11700.00
0005432799234	14561	Economy	11700.00
0005434937869	14561	Economy	11700.00
0005435125791	14561	Economy	11700.00
0005435125959	14561	Economy	11700.00
0005434938031	14561	Economy	11700.00
0005434877059	14561	Economy	11700.00
0005432799106	14561	Economy	11700.00
0005432799166	14561	Economy	11700.00
0005435125823	14561	Economy	11700.00
0005432607506	14561	Economy	11700.00
0005434938010	14561	Economy	11700.00
0005435625932	14561	Economy	11700.00
0005432799211	14561	Economy	11700.00
0005434876741	14561	Economy	11700.00
0005434877134	14561	Economy	11700.00
0005435126006	14561	Economy	11700.00
0005435625970	14561	Economy	11700.00
0005434426314	14561	Economy	11700.00
0005435125745	14561	Economy	11700.00
0005434877133	14561	Economy	11700.00
0005435125973	14561	Economy	11700.00
0005435125861	14561	Economy	11700.00
0005435125769	14561	Economy	11700.00
0005432799167	14561	Economy	11700.00
0005435126007	14561	Economy	11700.00
0005434877379	14561	Economy	11700.00
0005434937972	14561	Economy	11700.00
0005434877378	14561	Economy	11700.00
0005435125797	14561	Economy	11700.00
0005435902672	14561	Economy	11700.00
0005434877306	14561	Economy	11700.00
0005434877580	14561	Economy	11700.00
0005434937903	14561	Economy	11700.00
0005434877061	14561	Economy	11700.00
0005434877417	14561	Economy	11700.00
0005434876662	14561	Economy	11700.00
0005434876769	14561	Economy	11700.00
0005435125938	14561	Economy	11700.00
0005435625948	14561	Economy	11700.00
0005434877330	14561	Economy	11700.00
0005434877138	14561	Economy	11700.00
0005434426330	14561	Economy	11700.00
0005435125815	14561	Economy	11700.00
0005434938011	14561	Economy	11700.00
0005435625964	14561	Economy	11700.00
0005432799214	14561	Economy	11700.00
0005434877192	14561	Economy	11700.00
0005432799117	14561	Economy	11700.00
0005434877206	14561	Economy	11700.00
0005434876609	14561	Economy	11700.00
0005434877201	14561	Economy	11700.00
0005434426341	14561	Economy	11700.00
0005432799135	14561	Economy	11700.00
0005435125904	14561	Economy	11700.00
0005435841820	14561	Economy	11700.00
0005434426320	14561	Economy	11700.00
0005435902661	14561	Economy	11700.00
0005435125972	14561	Economy	11700.00
0005435125780	14561	Economy	11700.00
0005434876742	14561	Economy	11700.00
0005434426415	14561	Economy	11700.00
0005435126034	14561	Economy	11700.00
0005435889842	3593	Economy	16300.00
0005434312315	3593	Economy	16300.00
0005435889843	3593	Economy	14800.00
0005435889853	3593	Economy	14800.00
0005435889833	3593	Economy	14800.00
0005435889852	3593	Economy	14800.00
0005435889841	3593	Economy	14800.00
0005434325624	3593	Economy	14800.00
0005434325626	3593	Economy	14800.00
0005434312314	3593	Economy	14800.00
0005434325631	3593	Economy	14800.00
0005434325620	3593	Economy	14800.00
0005434325628	3593	Economy	14800.00
0005434325623	3593	Economy	14800.00
0005434325630	3593	Economy	14800.00
0005434325625	3593	Economy	14800.00
0005434325621	3593	Economy	14800.00
0005434325627	3593	Economy	14800.00
0005434325629	3593	Economy	14800.00
0005435889836	3593	Economy	14800.00
0005434325622	3593	Economy	14800.00
0005434325528	15627	Economy	16300.00
0005435889885	15627	Economy	16300.00
0005434325502	15627	Economy	14800.00
0005434325547	15627	Economy	14800.00
0005435889881	15627	Economy	14800.00
0005434325527	15627	Economy	14800.00
0005434325501	15627	Economy	14800.00
0005434325513	15627	Economy	14800.00
0005434325546	15627	Economy	14800.00
0005434325503	15627	Economy	14800.00
0005434325553	15627	Economy	14800.00
0005435889886	15627	Economy	14800.00
0005434325585	15627	Economy	14800.00
0005435889884	15627	Economy	14800.00
0005435889882	15627	Economy	14800.00
0005435889883	15627	Economy	14800.00
0005435957670	644	Economy	4500.00
0005435957667	644	Economy	4500.00
0005435957674	644	Economy	4100.00
0005433420326	644	Economy	4100.00
0005435957673	644	Economy	4100.00
0005435957669	644	Economy	4100.00
0005435957668	644	Economy	4100.00
0005433420327	644	Economy	4100.00
0005433420346	644	Economy	4100.00
0005435957679	644	Economy	4100.00
0005433420300	644	Economy	4100.00
0005435957665	644	Economy	4100.00
0005435957676	644	Economy	4100.00
0005433420325	644	Economy	4100.00
0005435957677	644	Economy	4100.00
0005435957666	644	Economy	4100.00
0005435957671	644	Economy	4100.00
0005435957675	644	Economy	4100.00
0005435957672	644	Economy	4100.00
0005435957678	644	Economy	4100.00
0005433420380	15152	Economy	4500.00
0005433420388	15152	Economy	4500.00
0005435957576	15152	Economy	4500.00
0005435957487	15152	Economy	4100.00
0005435957597	15152	Economy	4100.00
0005433420381	15152	Economy	4100.00
0005435957627	15152	Economy	4100.00
0005435957626	15152	Economy	4100.00
0005433420382	15152	Economy	4100.00
0005433420387	15152	Economy	4100.00
0005435957488	15152	Economy	4100.00
0005433420386	15152	Economy	4100.00
0005435957544	15152	Economy	4100.00
0005435957598	15152	Economy	4100.00
0005435957546	15152	Economy	4100.00
0005435957599	15152	Economy	4100.00
0005435957617	15152	Economy	4100.00
0005435957530	15152	Economy	4100.00
0005435957575	15152	Economy	4100.00
0005433420385	15152	Economy	4100.00
0005435957491	15152	Economy	4100.00
0005433420383	15152	Economy	4100.00
0005435957604	15152	Economy	4100.00
0005433420384	15152	Economy	4100.00
0005433420389	15152	Economy	4100.00
0005435957600	15152	Economy	4100.00
0005435957601	15152	Economy	4100.00
0005435957529	15152	Economy	4100.00
0005435957545	15152	Economy	4100.00
0005435957628	15152	Economy	4100.00
0005434995277	24003	Business	94000.00
0005434995282	24003	Economy	31300.00
0005434995280	24003	Economy	31300.00
0005434995275	24003	Economy	31300.00
0005434995276	24003	Economy	31300.00
0005434995279	24003	Economy	31300.00
0005434995278	24003	Economy	31300.00
0005434995281	24003	Economy	31300.00
0005434247114	8841	Economy	10400.00
0005434247115	8841	Economy	10400.00
0005435629402	8841	Economy	10400.00
0005434247142	16039	Economy	10400.00
0005434247141	16039	Economy	10400.00
0005433404716	2833	Business	12600.00
0005435797447	2833	Business	12600.00
0005435797450	2833	Economy	4200.00
0005435797440	2833	Economy	4200.00
0005433404715	2833	Economy	4200.00
0005435797446	2833	Economy	4600.00
0005435797444	2833	Economy	4600.00
0005435797449	2833	Economy	4600.00
0005435797443	2833	Economy	4200.00
0005435797445	2833	Economy	4200.00
0005433404719	2833	Economy	4200.00
0005435797441	2833	Economy	4200.00
0005435797451	2833	Economy	4200.00
0005433404727	2833	Economy	4200.00
0005435797452	2833	Economy	4200.00
0005435797448	2833	Economy	4200.00
0005435797442	2833	Economy	4200.00
0005433404723	2833	Economy	4200.00
0005433404726	2833	Economy	4200.00
0005433404704	2833	Economy	4200.00
0005433404712	2833	Economy	4200.00
0005435797313	29299	Business	12600.00
0005435797390	29299	Economy	4200.00
0005433404792	29299	Economy	4200.00
0005433404794	29299	Economy	4200.00
0005433404795	29299	Economy	4200.00
0005435797354	29299	Economy	4200.00
0005435797366	29299	Economy	4200.00
0005435797372	29299	Economy	4200.00
0005433404797	29299	Economy	4200.00
0005435797391	29299	Economy	4200.00
0005435797341	29299	Economy	4200.00
0005433404796	29299	Economy	4200.00
0005435797329	29299	Economy	4200.00
0005433404793	29299	Economy	4200.00
0005435797352	29299	Economy	4200.00
0005435376322	5755	Economy	6800.00
0005435376337	5755	Economy	6800.00
0005435376338	5755	Economy	6800.00
0005435376339	5755	Economy	6800.00
0005434948003	5754	Economy	6800.00
0005434948006	5754	Economy	6800.00
0005434948000	5754	Economy	6800.00
0005434948004	5754	Economy	6800.00
0005434948001	5754	Economy	6800.00
0005434948002	5754	Economy	6800.00
0005434948007	5754	Economy	6800.00
0005434948008	5754	Economy	6800.00
0005434948005	5754	Economy	6800.00
0005435376344	16367	Economy	6800.00
0005434947967	16367	Economy	6800.00
0005435376345	16367	Economy	6800.00
0005434947942	16367	Economy	6800.00
0005435376343	16367	Economy	6800.00
0005434947941	16367	Economy	6800.00
0005435376346	16367	Economy	6800.00
0005435376347	16367	Economy	6800.00
0005434947962	16367	Economy	6800.00
0005433960781	6850	Business	21400.00
0005433960757	6850	Business	21400.00
0005433960758	6850	Business	21400.00
0005433960786	6850	Business	21400.00
0005433960784	6850	Business	21400.00
0005433960742	6850	Economy	7100.00
0005433960777	6850	Economy	7100.00
0005433960775	6850	Economy	7100.00
0005433960746	6850	Economy	7100.00
0005433960751	6850	Economy	7100.00
0005433960778	6850	Economy	7100.00
0005433960765	6850	Economy	7100.00
0005433960779	6850	Economy	7800.00
0005433960771	6850	Economy	7100.00
0005433960782	6850	Economy	7100.00
0005433960761	6850	Economy	7100.00
0005433960743	6850	Economy	7100.00
0005433960750	6850	Economy	7100.00
0005433960755	6850	Economy	7100.00
0005433960790	6850	Economy	7100.00
0005433960767	6850	Economy	7100.00
0005433960766	6850	Economy	7100.00
0005433960744	6850	Economy	7100.00
0005433960762	6850	Economy	7100.00
0005433960760	6850	Economy	7100.00
0005433960740	6850	Economy	7100.00
0005433960752	6850	Economy	7100.00
0005433960745	6850	Economy	7100.00
0005433960788	6850	Economy	7100.00
0005433960774	6850	Economy	7100.00
0005433960763	6850	Economy	7100.00
0005433960749	6850	Economy	7100.00
0005433960748	6850	Economy	7100.00
0005433960764	6850	Economy	7100.00
0005433960792	6850	Economy	7100.00
0005433960756	6850	Economy	7100.00
0005433960768	6850	Economy	7100.00
0005433960739	6850	Economy	7100.00
0005433960770	6850	Economy	7100.00
0005433960785	6850	Economy	7100.00
0005433960780	6850	Economy	7100.00
0005433960759	6850	Economy	7100.00
0005433960783	6850	Economy	7100.00
0005433960754	6850	Economy	7100.00
0005433960787	6850	Economy	7100.00
0005433960791	6850	Economy	7100.00
0005433960769	6850	Economy	7100.00
0005433960747	6850	Economy	7100.00
0005433960772	6850	Economy	7100.00
0005433960741	6850	Economy	7100.00
0005433960776	6850	Economy	7100.00
0005433960789	6850	Economy	7100.00
0005433960773	6850	Economy	7100.00
0005433960753	6850	Economy	7100.00
0005433960191	25708	Business	21400.00
0005433960043	25708	Business	21400.00
0005433960096	25708	Business	21400.00
0005433960227	25708	Business	21400.00
0005433960121	25708	Business	21400.00
0005433960234	25708	Business	21400.00
0005433960101	25708	Economy	7100.00
0005433960118	25708	Economy	7100.00
0005433960180	25708	Economy	7100.00
0005433960235	25708	Economy	7100.00
0005433960267	25708	Economy	7800.00
0005433960140	25708	Economy	7800.00
0005433960114	25708	Economy	7800.00
0005433959972	25708	Economy	7800.00
0005433960141	25708	Economy	7100.00
0005433960223	25708	Economy	7100.00
0005433960122	25708	Economy	7100.00
0005433960204	25708	Economy	7100.00
0005433959926	25708	Economy	7100.00
0005433959948	25708	Economy	7100.00
0005433960116	25708	Economy	7100.00
0005433959988	25708	Economy	7100.00
0005433960102	25708	Economy	7100.00
0005433959942	25708	Economy	7100.00
0005433960177	25708	Economy	7100.00
0005433960192	25708	Economy	7100.00
0005433960042	25708	Economy	7100.00
0005433959949	25708	Economy	7100.00
0005433960011	25708	Economy	7100.00
0005433960013	25708	Economy	7100.00
0005433960212	25708	Economy	7100.00
0005433960041	25708	Economy	7100.00
0005433960080	25708	Economy	7100.00
0005433960243	25708	Economy	7100.00
0005433960115	25708	Economy	7100.00
0005433960090	25708	Economy	7100.00
0005433960237	25708	Economy	7100.00
0005433960240	25708	Economy	7100.00
0005433960128	25708	Economy	7100.00
0005433960233	25708	Economy	7100.00
0005433960176	25708	Economy	7100.00
0005433959989	25708	Economy	7100.00
0005433960012	25708	Economy	7100.00
0005433960015	25708	Economy	7100.00
0005433960213	25708	Economy	7100.00
0005433960074	25708	Economy	7100.00
0005433960095	25708	Economy	7100.00
0005433960089	25708	Economy	7100.00
0005433960053	25708	Economy	7100.00
0005435082696	24548	Economy	3900.00
0005435082705	24548	Economy	3900.00
0005435082695	24548	Economy	3900.00
0005435082704	24548	Economy	3900.00
0005435082721	24548	Economy	3900.00
0005435082698	24548	Economy	3900.00
0005435082770	26144	Economy	3900.00
0005435082766	26144	Economy	3900.00
0005435082767	26144	Economy	3900.00
0005435082764	26144	Economy	3900.00
0005435082769	26144	Economy	3900.00
0005435082768	26144	Economy	3900.00
0005435082765	26144	Economy	3900.00
0005434244911	5052	Business	18000.00
0005433534478	5052	Business	18000.00
0005435286566	5052	Business	18000.00
0005434244926	5052	Business	18000.00
0005434244923	5052	Business	18000.00
0005434244931	5052	Business	18000.00
0005434244919	5052	Economy	6600.00
0005432166894	5052	Economy	6000.00
0005434244934	5052	Economy	6000.00
0005433534480	5052	Economy	6000.00
0005434244913	5052	Economy	6000.00
0005434244928	5052	Economy	6000.00
0005434244924	5052	Economy	6000.00
0005435286560	5052	Economy	6000.00
0005434244918	5052	Economy	6000.00
0005435286567	5052	Economy	6000.00
0005434244912	5052	Economy	6000.00
0005434244930	5052	Economy	6000.00
0005434244927	5052	Economy	6000.00
0005434244929	5052	Economy	6000.00
0005434244921	5052	Economy	6000.00
0005432166896	5052	Economy	6600.00
0005435286561	5052	Economy	6600.00
0005432166895	5052	Economy	6600.00
0005435286569	5052	Economy	6000.00
0005434244908	5052	Economy	6000.00
0005434244933	5052	Economy	6000.00
0005434244910	5052	Economy	6000.00
0005432166897	5052	Economy	6000.00
0005433534479	5052	Economy	6000.00
0005434244909	5052	Economy	6000.00
0005434244925	5052	Economy	6000.00
0005434244916	5052	Economy	6000.00
0005434244920	5052	Economy	6000.00
0005434244915	5052	Economy	6000.00
0005434244907	5052	Economy	6000.00
0005432166893	5052	Economy	6000.00
0005434244917	5052	Economy	6000.00
0005434244932	5052	Economy	6000.00
0005435286553	5052	Economy	6000.00
0005434244906	5052	Economy	6000.00
0005434244914	5052	Economy	6000.00
0005434244922	5052	Economy	6000.00
0005433784856	5053	Business	18000.00
0005433614513	5053	Business	18000.00
0005433784851	5053	Business	18000.00
0005432105488	5053	Business	18000.00
0005433784883	5053	Business	18000.00
0005432105448	5053	Business	18000.00
0005433784882	5053	Business	18000.00
0005433614548	5053	Business	18000.00
0005432105450	5053	Business	18000.00
0005433614577	5053	Business	18000.00
0005432667448	5053	Business	18000.00
0005433614531	5053	Business	18000.00
0005432105491	5053	Business	18000.00
0005432105451	5053	Business	18000.00
0005433614583	5053	Business	18000.00
0005433614560	5053	Business	18000.00
0005432105449	5053	Business	18000.00
0005433614517	5053	Business	18000.00
0005433614575	5053	Business	18000.00
0005432666383	5053	Business	18000.00
0005433614565	5053	Business	18000.00
0005433614522	5053	Business	18000.00
0005432105494	5053	Business	18000.00
0005433784866	5053	Business	18000.00
0005432667449	5053	Business	18000.00
0005433614541	5053	Business	18000.00
0005432105477	5053	Business	18000.00
0005432105486	5053	Business	18000.00
0005433614514	5053	Economy	6600.00
0005433784873	5053	Economy	6600.00
0005433614561	5053	Economy	6600.00
0005432105461	5053	Economy	6600.00
0005432105453	5053	Economy	6600.00
0005432105475	5053	Economy	6600.00
0005432105456	5053	Economy	6000.00
0005433784885	5053	Economy	6000.00
0005433614567	5053	Economy	6000.00
0005432105459	5053	Economy	6000.00
0005433784871	5053	Economy	6000.00
0005433614533	5053	Economy	6000.00
0005432105476	5053	Economy	6000.00
0005433784853	5053	Economy	6000.00
0005432105464	5053	Economy	6000.00
0005433614516	5053	Economy	6000.00
0005432145109	5053	Economy	6000.00
0005432105487	5053	Economy	6000.00
0005433784875	5053	Economy	6000.00
0005433614518	5053	Economy	6000.00
0005433784878	5053	Economy	6000.00
0005433614562	5053	Economy	6000.00
0005432105455	5053	Economy	6000.00
0005433614540	5053	Economy	6000.00
0005432105479	5053	Economy	6000.00
0005433614556	5053	Economy	6000.00
0005433614520	5053	Economy	6000.00
0005433614574	5053	Economy	6000.00
0005433784859	5053	Economy	6000.00
0005432105468	5053	Economy	6000.00
0005433614521	5053	Economy	6000.00
0005433614538	5053	Economy	6000.00
0005433614564	5053	Economy	6000.00
0005433614532	5053	Economy	6000.00
0005432105478	5053	Economy	6000.00
0005433614523	5053	Economy	6000.00
0005433784872	5053	Economy	6000.00
0005433784863	5053	Economy	6000.00
0005433614515	5053	Economy	6000.00
0005432665269	5053	Economy	6000.00
0005433614534	5053	Economy	6000.00
0005433784861	5053	Economy	6000.00
0005433614529	5053	Economy	6000.00
0005433614578	5053	Economy	6000.00
0005433784886	5053	Economy	6000.00
0005432105467	5053	Economy	6000.00
0005433614551	5053	Economy	6000.00
0005433614547	5053	Economy	6000.00
0005433614512	5053	Economy	6000.00
0005432105466	5053	Economy	6000.00
0005432105483	5053	Economy	6000.00
0005433614568	5053	Economy	6000.00
0005432105458	5053	Economy	6000.00
0005433614544	5053	Economy	6000.00
0005433614509	5053	Economy	6000.00
0005432105465	5053	Economy	6000.00
0005433614573	5053	Economy	6000.00
0005433614552	5053	Economy	6000.00
0005433784877	5053	Economy	6000.00
0005433614543	5053	Economy	6000.00
0005433614554	5053	Economy	6000.00
0005432665270	5053	Economy	6000.00
0005432105489	5053	Economy	6000.00
0005433614530	5053	Economy	6000.00
0005433784857	5053	Economy	6000.00
0005433784858	5053	Economy	6000.00
0005432665271	5053	Economy	6600.00
0005432105472	5053	Economy	6600.00
0005433784876	5053	Economy	6600.00
0005433614511	5053	Economy	6600.00
0005433614557	5053	Economy	6600.00
0005432105493	5053	Economy	6000.00
0005433614579	5053	Economy	6000.00
0005433784881	5053	Economy	6000.00
0005433784874	5053	Economy	6000.00
0005432105457	5053	Economy	6600.00
0005433784880	5053	Economy	6000.00
0005433614519	5053	Economy	6000.00
0005432145107	5053	Economy	6000.00
0005433784867	5053	Economy	6000.00
0005432105484	5053	Economy	6000.00
0005433614570	5053	Economy	6000.00
0005433614542	5053	Economy	6000.00
0005433614539	5053	Economy	6000.00
0005433784860	5053	Economy	6000.00
0005432105490	5053	Economy	6000.00
0005433784870	5053	Economy	6000.00
0005432105480	5053	Economy	6000.00
0005432105469	5053	Economy	6000.00
0005432105470	5053	Economy	6000.00
0005432105447	5053	Economy	6000.00
0005432666384	5053	Economy	6000.00
0005433614527	5053	Economy	6000.00
0005433614536	5053	Economy	6000.00
0005433784869	5053	Economy	6000.00
0005433784868	5053	Economy	6000.00
0005432105471	5053	Economy	6000.00
0005433614569	5053	Economy	6000.00
0005433614572	5053	Economy	6000.00
0005432667450	5053	Economy	6000.00
0005433784865	5053	Economy	6000.00
0005433614582	5053	Economy	6000.00
0005433614553	5053	Economy	6000.00
0005433614546	5053	Economy	6000.00
0005432105463	5053	Economy	6000.00
0005433614535	5053	Economy	6000.00
0005433614563	5053	Economy	6000.00
0005433614555	5053	Economy	6000.00
0005433614537	5053	Economy	6000.00
0005433614526	5053	Economy	6000.00
0005432105452	5053	Economy	6000.00
0005433614545	5053	Economy	6000.00
0005433784879	5053	Economy	6000.00
0005432105481	5053	Economy	6000.00
0005432105492	5053	Economy	6000.00
0005432105485	5053	Economy	6000.00
0005433614524	5053	Economy	6000.00
0005432105454	5053	Economy	6000.00
0005432105462	5053	Economy	6000.00
0005433784884	5053	Economy	6000.00
0005433784852	5053	Economy	6000.00
0005433614549	5053	Economy	6000.00
0005433614566	5053	Economy	6000.00
0005433614550	5053	Economy	6000.00
0005433614528	5053	Economy	6000.00
0005432105473	5053	Economy	6000.00
0005432105474	5053	Economy	6000.00
0005433614525	5053	Economy	6000.00
0005433784864	5053	Economy	6000.00
0005433614576	5053	Economy	6000.00
0005433784855	5053	Economy	6000.00
0005432105482	5053	Economy	6000.00
0005433614580	5053	Economy	6000.00
0005433614558	5053	Economy	6000.00
0005433614581	5053	Economy	6000.00
0005433614571	5053	Economy	6000.00
0005433614510	5053	Economy	6000.00
0005433784862	5053	Economy	6000.00
0005432145108	5053	Economy	6000.00
0005433784854	5053	Economy	6000.00
0005433614559	5053	Economy	6000.00
0005432105460	5053	Economy	6000.00
0005435269660	5060	Business	18000.00
0005434312298	5060	Business	18000.00
0005435006800	5060	Business	18000.00
0005434229313	5060	Business	18000.00
0005434265095	5060	Business	18000.00
0005434149704	5060	Business	18000.00
0005434265098	5060	Business	18000.00
0005432335946	5060	Business	18000.00
0005434265081	5060	Business	18000.00
0005435006823	5060	Business	18000.00
0005432335915	5060	Business	18000.00
0005434229322	5060	Business	18000.00
0005435269666	5060	Business	18000.00
0005435006799	5060	Business	18000.00
0005435006798	5060	Business	18000.00
0005434312296	5060	Business	18000.00
0005434265094	5060	Business	18000.00
0005433815328	5060	Business	18000.00
0005435006730	5060	Business	18000.00
0005432335916	5060	Business	18000.00
0005433815336	5060	Business	18000.00
0005434265082	5060	Business	18000.00
0005434173512	5060	Business	18000.00
0005434229325	5060	Economy	6600.00
0005432335930	5060	Economy	6600.00
0005435006753	5060	Economy	6600.00
0005434229314	5060	Economy	6600.00
0005434229334	5060	Economy	6600.00
0005434265093	5060	Economy	6000.00
0005434265089	5060	Economy	6000.00
0005434149707	5060	Economy	6000.00
0005434265077	5060	Economy	6000.00
0005435006815	5060	Economy	6000.00
0005434229332	5060	Economy	6000.00
0005434265075	5060	Economy	6000.00
0005434149710	5060	Economy	6000.00
0005434149708	5060	Economy	6000.00
0005434265078	5060	Economy	6000.00
0005432335960	5060	Economy	6000.00
0005434229330	5060	Economy	6000.00
0005434265080	5060	Economy	6000.00
0005434265079	5060	Economy	6000.00
0005435006852	5060	Economy	6000.00
0005434149712	5060	Economy	6000.00
0005433815335	5060	Economy	6000.00
0005434311191	5060	Economy	6000.00
0005432335947	5060	Economy	6000.00
0005435006706	5060	Economy	6000.00
0005434265085	5060	Economy	6000.00
0005434229318	5060	Economy	6000.00
0005435006725	5060	Economy	6000.00
0005435006816	5060	Economy	6000.00
0005432335940	5060	Economy	6000.00
0005434149701	5060	Economy	6000.00
0005433685492	5060	Economy	6000.00
0005434149711	5060	Economy	6000.00
0005433815333	5060	Economy	6000.00
0005435269650	5060	Economy	6000.00
0005434149705	5060	Economy	6000.00
0005434265073	5060	Economy	6000.00
0005434229335	5060	Economy	6000.00
0005435006794	5060	Economy	6000.00
0005434173510	5060	Economy	6000.00
0005435006818	5060	Economy	6000.00
0005435006738	5060	Economy	6000.00
0005433685500	5060	Economy	6000.00
0005434265096	5060	Economy	6000.00
0005432335945	5060	Economy	6000.00
0005434229333	5060	Economy	6000.00
0005434229326	5060	Economy	6600.00
0005434265086	5060	Economy	6600.00
0005434265088	5060	Economy	6600.00
0005434173511	5060	Economy	6000.00
0005434229328	5060	Economy	6000.00
0005435006705	5060	Economy	6600.00
0005435006739	5060	Economy	6000.00
0005434229324	5060	Economy	6000.00
0005434265087	5060	Economy	6000.00
0005434229327	5060	Economy	6000.00
0005434229315	5060	Economy	6000.00
0005434265097	5060	Economy	6000.00
0005433815334	5060	Economy	6000.00
0005432335912	5060	Economy	6000.00
0005434229316	5060	Economy	6000.00
0005434229331	5060	Economy	6000.00
0005434149703	5060	Economy	6000.00
0005434229336	5060	Economy	6000.00
0005434265092	5060	Economy	6000.00
0005434149709	5060	Economy	6000.00
0005434265076	5060	Economy	6000.00
0005434265083	5060	Economy	6000.00
0005432335873	5060	Economy	6000.00
0005435269671	5060	Economy	6000.00
0005434265090	5060	Economy	6000.00
0005435006726	5060	Economy	6000.00
0005435006752	5060	Economy	6000.00
0005435006723	5060	Economy	6000.00
0005434149702	5060	Economy	6000.00
0005435006776	5060	Economy	6000.00
0005435269651	5060	Economy	6000.00
0005435006750	5060	Economy	6000.00
0005434265084	5060	Economy	6000.00
0005435006740	5060	Economy	6000.00
0005434265074	5060	Economy	6000.00
0005433815327	5060	Economy	6000.00
0005435006745	5060	Economy	6000.00
0005434229321	5060	Economy	6000.00
0005434265091	5060	Economy	6000.00
0005432335941	5060	Economy	6000.00
0005434229329	5060	Economy	6000.00
0005434173513	5060	Economy	6000.00
0005434229320	5060	Economy	6000.00
0005434229323	5060	Economy	6000.00
0005435269665	5060	Economy	6000.00
0005435269659	5060	Economy	6000.00
0005434149706	5060	Economy	6000.00
0005434229319	5060	Economy	6000.00
0005435006737	5060	Economy	6000.00
0005434229317	5060	Economy	6000.00
0005434244807	8430	Business	18000.00
0005433784677	8430	Business	18000.00
0005433784654	8430	Business	18000.00
0005433784593	8430	Business	18000.00
0005433784474	8430	Business	18000.00
0005434244663	8430	Business	18000.00
0005434244752	8430	Business	18000.00
0005433784480	8430	Business	18000.00
0005434244661	8430	Business	18000.00
0005433784441	8430	Economy	6600.00
0005433784491	8430	Business	18000.00
0005434244806	8430	Economy	6600.00
0005434244660	8430	Economy	6600.00
0005433784732	8430	Economy	6600.00
0005433784561	8430	Economy	6000.00
0005434244824	8430	Economy	6000.00
0005434244679	8430	Economy	6000.00
0005433784656	8430	Economy	6000.00
0005434244823	8430	Economy	6000.00
0005433784588	8430	Economy	6000.00
0005433784693	8430	Economy	6000.00
0005433784560	8430	Economy	6000.00
0005433784570	8430	Economy	6000.00
0005434244624	8430	Economy	6000.00
0005434244735	8430	Economy	6000.00
0005433784699	8430	Economy	6000.00
0005435269746	8430	Economy	6000.00
0005433784679	8430	Economy	6000.00
0005435269747	8430	Economy	6000.00
0005434244676	8430	Economy	6000.00
0005433784592	8430	Economy	6000.00
0005433784587	8430	Economy	6000.00
0005434244668	8430	Economy	6000.00
0005433784733	8430	Economy	6000.00
0005433784678	8430	Economy	6000.00
0005434244697	8430	Economy	6000.00
0005434244690	8430	Economy	6000.00
0005434244623	8430	Economy	6000.00
0005433784458	8430	Economy	6000.00
0005433784442	8430	Economy	6000.00
0005434244674	8430	Economy	6600.00
0005434244662	8430	Economy	6000.00
0005433784504	8430	Economy	6000.00
0005434244667	8430	Economy	6000.00
0005434244730	8430	Economy	6000.00
0005434244691	8430	Economy	6000.00
0005434244675	8430	Economy	6000.00
0005433784583	8430	Economy	6000.00
0005433784397	8430	Economy	6000.00
0005434244731	8430	Economy	6000.00
0005433784629	8430	Economy	6000.00
0005433784589	8430	Economy	6000.00
0005434244673	8430	Economy	6000.00
0005433784502	8430	Economy	6000.00
0005434244604	8430	Economy	6000.00
0005433784509	8430	Economy	6000.00
0005434244716	8430	Economy	6000.00
0005434244693	8430	Economy	6000.00
0005434244719	8430	Economy	6000.00
0005433784655	8430	Economy	6000.00
0005433784479	8430	Economy	6000.00
0005434244664	8430	Economy	6000.00
0005434244615	8430	Economy	6000.00
0005434244736	8430	Economy	6000.00
0005433613980	8431	Business	18000.00
0005433614037	8431	Business	18000.00
0005433613716	8431	Business	18000.00
0005433613852	8431	Business	18000.00
0005433613573	8431	Business	18000.00
0005433613981	8431	Business	18000.00
0005433613666	8431	Business	18000.00
0005433613780	8431	Business	18000.00
0005433613954	8431	Business	18000.00
0005433613782	8431	Business	18000.00
0005433614124	8431	Business	18000.00
0005433613808	8431	Business	18000.00
0005433613846	8431	Business	18000.00
0005433613920	8431	Business	18000.00
0005433613609	8431	Business	18000.00
0005433613731	8431	Business	18000.00
0005433614035	8431	Business	18000.00
0005433613646	8431	Economy	6600.00
0005433613779	8431	Economy	6600.00
0005433613736	8431	Economy	6600.00
0005433613796	8431	Economy	6000.00
0005433613762	8431	Economy	6000.00
0005433613953	8431	Economy	6000.00
0005433613742	8431	Economy	6000.00
0005433614068	8431	Economy	6000.00
0005433613608	8431	Economy	6000.00
0005433613830	8431	Economy	6000.00
0005433613647	8431	Economy	6000.00
0005433613770	8431	Economy	6000.00
0005433614073	8431	Economy	6000.00
0005433613696	8431	Economy	6000.00
0005433613918	8431	Economy	6000.00
0005433613807	8431	Economy	6000.00
0005433614271	8431	Economy	6000.00
0005433613880	8431	Economy	6000.00
0005433613693	8431	Economy	6000.00
0005433613876	8431	Economy	6000.00
0005433613486	8431	Economy	6000.00
0005433613856	8431	Economy	6000.00
0005433613975	8431	Economy	6000.00
0005433613719	8431	Economy	6000.00
0005433613432	8431	Economy	6000.00
0005433613973	8431	Economy	6000.00
0005433614057	8431	Economy	6000.00
0005433613781	8431	Economy	6000.00
0005433613582	8431	Economy	6000.00
0005433613881	8431	Economy	6000.00
0005433613829	8431	Economy	6000.00
0005433613790	8431	Economy	6000.00
0005433613786	8431	Economy	6000.00
0005433613910	8431	Economy	6000.00
0005433613645	8431	Economy	6000.00
0005433613817	8431	Economy	6000.00
0005433613908	8431	Economy	6000.00
0005433614242	8431	Economy	6600.00
0005433613651	8431	Economy	6600.00
0005433613834	8431	Economy	6600.00
0005433613692	8431	Economy	6000.00
0005433613855	8431	Economy	6000.00
0005433614058	8431	Economy	6000.00
0005433613998	8431	Economy	6000.00
0005433613797	8431	Economy	6000.00
0005433613888	8431	Economy	6000.00
0005433613665	8431	Economy	6000.00
0005433613891	8431	Economy	6000.00
0005433614036	8431	Economy	6000.00
0005433613917	8431	Economy	6000.00
0005433614021	8431	Economy	6000.00
0005433613909	8431	Economy	6000.00
0005433613787	8431	Economy	6000.00
0005433613919	8431	Economy	6000.00
0005433613734	8431	Economy	6000.00
0005433613676	8431	Economy	6000.00
0005433613853	8431	Economy	6000.00
0005433613763	8431	Economy	6000.00
0005433613700	8431	Economy	6000.00
0005433614270	8431	Economy	6000.00
0005433614072	8431	Economy	6000.00
0005433613730	8431	Economy	6000.00
0005433613720	8431	Economy	6000.00
0005433613997	8431	Economy	6000.00
0005433613809	8431	Economy	6000.00
0005433613945	8431	Economy	6000.00
0005433613950	8431	Economy	6000.00
0005433613890	8431	Economy	6000.00
0005433613551	8431	Economy	6000.00
0005433614123	8431	Economy	6000.00
0005433613833	8431	Economy	6000.00
0005433613789	8431	Economy	6000.00
0005433613741	8431	Economy	6000.00
0005433613900	8431	Economy	6000.00
0005434229137	8432	Business	18000.00
0005434264898	8432	Business	18000.00
0005435286615	8432	Business	18000.00
0005435006991	8432	Business	18000.00
0005432336006	8432	Business	18000.00
0005435006972	8432	Business	18000.00
0005433688806	8432	Business	18000.00
0005435006981	8432	Business	18000.00
0005435286619	8432	Business	18000.00
0005434173473	8432	Business	18000.00
0005433690923	8432	Business	18000.00
0005432034881	8432	Business	18000.00
0005434229066	8432	Business	18000.00
0005435006979	8432	Business	18000.00
0005434149645	8432	Business	18000.00
0005435006987	8432	Business	18000.00
0005435286616	8432	Business	18000.00
0005435006980	8432	Business	18000.00
0005434229160	8432	Business	18000.00
0005433688805	8432	Business	18000.00
0005433690922	8432	Business	18000.00
0005434264796	8432	Business	18000.00
0005432034901	8432	Business	18000.00
0005434264765	8432	Business	18000.00
0005432034902	8432	Economy	6600.00
0005432034896	8432	Economy	6600.00
0005433534494	8432	Economy	6600.00
0005435286623	8432	Economy	6600.00
0005432336007	8432	Economy	6600.00
0005434264862	8432	Economy	6600.00
0005434264846	8432	Economy	6000.00
0005432034900	8432	Economy	6000.00
0005434265027	8432	Economy	6000.00
0005432336009	8432	Economy	6000.00
0005434149579	8432	Economy	6000.00
0005434173471	8432	Economy	6000.00
0005435006969	8432	Economy	6000.00
0005434228993	8432	Economy	6000.00
0005434149610	8432	Economy	6000.00
0005434264810	8432	Economy	6000.00
0005432034878	8432	Economy	6000.00
0005435286617	8432	Economy	6000.00
0005432034890	8432	Economy	6000.00
0005432336005	8432	Economy	6000.00
0005435006977	8432	Economy	6000.00
0005434229216	8432	Economy	6000.00
0005432047543	8432	Economy	6000.00
0005432034892	8432	Economy	6000.00
0005434229088	8432	Economy	6000.00
0005432034876	8432	Economy	6000.00
0005434264940	8432	Economy	6000.00
0005434264863	8432	Economy	6000.00
0005433688804	8432	Economy	6000.00
0005432336008	8432	Economy	6000.00
0005432034884	8432	Economy	6000.00
0005432336012	8432	Economy	6000.00
0005435006994	8432	Economy	6000.00
0005435006974	8432	Economy	6000.00
0005434264847	8432	Economy	6000.00
0005433815379	8432	Economy	6000.00
0005432034888	8432	Economy	6000.00
0005432034894	8432	Economy	6000.00
0005435006971	8432	Economy	6000.00
0005435006976	8432	Economy	6000.00
0005434264845	8432	Economy	6000.00
0005434264807	8432	Economy	6000.00
0005434149578	8432	Economy	6000.00
0005435006982	8432	Economy	6000.00
0005432034885	8432	Economy	6000.00
0005435006978	8432	Economy	6000.00
0005435286618	8432	Economy	6000.00
0005434229089	8432	Economy	6000.00
0005434229189	8432	Economy	6000.00
0005435006983	8432	Economy	6000.00
0005432336010	8432	Economy	6000.00
0005434311214	8432	Economy	6000.00
0005432336011	8432	Economy	6000.00
0005432034899	8432	Economy	6000.00
0005432336014	8432	Economy	6000.00
0005434264829	8432	Economy	6000.00
0005434264771	8432	Economy	6000.00
0005435006992	8432	Economy	6000.00
0005434229151	8432	Economy	6000.00
0005434264916	8432	Economy	6600.00
0005433690924	8432	Economy	6600.00
0005432034903	8432	Economy	6600.00
0005432034891	8432	Economy	6600.00
0005434149625	8432	Economy	6600.00
0005434264806	8432	Economy	6000.00
0005434229181	8432	Economy	6000.00
0005434264920	8432	Economy	6000.00
0005434264772	8432	Economy	6000.00
0005432034895	8432	Economy	6000.00
0005432034904	8432	Economy	6000.00
0005434229152	8432	Economy	6000.00
0005434229110	8432	Economy	6000.00
0005434173470	8432	Economy	6000.00
0005433689906	8432	Economy	6000.00
0005432034880	8432	Economy	6000.00
0005432034898	8432	Economy	6000.00
0005434311215	8432	Economy	6000.00
0005433815375	8432	Economy	6000.00
0005432034877	8432	Economy	6000.00
0005435006989	8432	Economy	6000.00
0005435006988	8432	Economy	6000.00
0005433534493	8432	Economy	6000.00
0005432336013	8432	Economy	6000.00
0005434264804	8432	Economy	6000.00
0005434264867	8432	Economy	6000.00
0005434149646	8432	Economy	6000.00
0005435286622	8432	Economy	6000.00
0005432047544	8432	Economy	6000.00
0005435006985	8432	Economy	6000.00
0005434264791	8432	Economy	6000.00
0005435006986	8432	Economy	6000.00
0005435006970	8432	Economy	6000.00
0005434149609	8432	Economy	6000.00
0005433815374	8432	Economy	6000.00
0005435286620	8432	Economy	6000.00
0005434264809	8432	Economy	6000.00
0005434264769	8432	Economy	6000.00
0005434264939	8432	Economy	6000.00
0005434264764	8432	Economy	6000.00
0005434264814	8432	Economy	6000.00
0005435006990	8432	Economy	6000.00
0005435006975	8432	Economy	6000.00
0005432034879	8432	Economy	6000.00
0005435006993	8432	Economy	6000.00
0005435286621	8432	Economy	6000.00
0005433815378	8432	Economy	6000.00
0005435006973	8432	Economy	6000.00
0005433815376	8432	Economy	6000.00
0005434229081	8432	Economy	6000.00
0005432034897	8432	Economy	6000.00
0005433689907	8432	Economy	6000.00
0005432034882	8432	Economy	6000.00
0005432034887	8432	Economy	6000.00
0005435006984	8432	Economy	6000.00
0005434229115	8432	Economy	6000.00
0005434264805	8432	Economy	6000.00
0005434264830	8432	Economy	6000.00
0005434264774	8432	Economy	6000.00
0005433688807	8432	Economy	6000.00
0005432034889	8432	Economy	6000.00
0005434264926	8432	Economy	6000.00
0005432034893	8432	Economy	6000.00
0005433815377	8432	Economy	6000.00
0005434264986	8432	Economy	6000.00
0005432336015	8432	Economy	6000.00
0005432034883	8432	Economy	6000.00
0005434229103	8432	Economy	6000.00
0005434229125	8432	Economy	6000.00
0005432034886	8432	Economy	6000.00
0005434639091	12621	Economy	16200.00
0005434639105	12621	Economy	16200.00
0005434639108	12621	Economy	16200.00
0005433202332	12621	Economy	16200.00
0005434638930	12621	Economy	14800.00
0005433202331	12621	Economy	14800.00
0005433202333	12621	Economy	14800.00
0005433202338	12621	Economy	14800.00
0005434639095	12621	Economy	14800.00
0005434639063	12621	Economy	14800.00
0005433202329	12621	Economy	14800.00
0005433202337	12621	Economy	14800.00
0005434639020	12621	Economy	14800.00
0005433202340	12621	Economy	14800.00
0005433202342	12621	Economy	14800.00
0005433202339	12621	Economy	14800.00
0005434639012	12621	Economy	14800.00
0005434639040	12621	Economy	14800.00
0005433202334	12621	Economy	14800.00
0005434639039	12621	Economy	14800.00
0005434639086	12621	Economy	14800.00
0005433202336	12621	Economy	14800.00
0005434639079	12621	Economy	14800.00
0005434639045	12621	Economy	14800.00
0005433202330	12621	Economy	14800.00
0005433202341	12621	Economy	14800.00
0005434639097	12621	Economy	14800.00
0005434639026	12621	Economy	14800.00
0005434639112	12621	Economy	14800.00
0005434639025	12621	Economy	14800.00
0005434639087	12621	Economy	14800.00
0005434639096	12621	Economy	14800.00
0005434639107	12621	Economy	14800.00
0005434639106	12621	Economy	14800.00
0005434639022	12621	Economy	14800.00
0005434639113	12621	Economy	14800.00
0005434639080	12621	Economy	14800.00
0005434639044	12621	Economy	14800.00
0005433202335	12621	Economy	14800.00
0005432290625	23378	Economy	16200.00
0005433202141	23378	Economy	16200.00
0005434639243	23378	Economy	16200.00
0005433202164	23378	Economy	14800.00
0005434639248	23378	Economy	14800.00
0005434639238	23378	Economy	14800.00
0005434639260	23378	Economy	14800.00
0005434639261	23378	Economy	14800.00
0005434639245	23378	Economy	14800.00
0005433202156	23378	Economy	14800.00
0005433202219	23378	Economy	14800.00
0005434639262	23378	Economy	14800.00
0005433202221	23378	Economy	14800.00
0005434639241	23378	Economy	14800.00
0005433202202	23378	Economy	14800.00
0005433202240	23378	Economy	14800.00
0005433202203	23378	Economy	14800.00
0005434639250	23378	Economy	14800.00
0005434639251	23378	Economy	14800.00
0005434639255	23378	Economy	14800.00
0005433202142	23378	Economy	14800.00
0005434639247	23378	Economy	14800.00
0005434639242	23378	Economy	14800.00
0005432290624	23378	Economy	14800.00
0005434639252	23378	Economy	14800.00
0005433202204	23378	Economy	14800.00
0005434639258	23378	Economy	14800.00
0005432290623	23378	Economy	14800.00
0005434639259	23378	Economy	14800.00
0005434639263	23378	Economy	14800.00
0005434639254	23378	Economy	14800.00
0005433202205	23378	Economy	14800.00
0005433202182	23378	Economy	14800.00
0005434639240	23378	Economy	14800.00
0005434639244	23378	Economy	14800.00
0005434639257	23378	Economy	14800.00
0005434639253	23378	Economy	14800.00
0005434639249	23378	Economy	14800.00
0005433202220	23378	Economy	14800.00
0005434639246	23378	Economy	14800.00
0005434639264	23378	Economy	14800.00
0005434639256	23378	Economy	14800.00
0005434639239	23378	Economy	14800.00
0005432328193	21060	Business	18900.00
0005432328095	21060	Business	18900.00
0005432382683	21060	Business	18900.00
0005432328204	21060	Business	18900.00
0005432328073	21060	Business	18900.00
0005432328261	21060	Business	18900.00
0005432382751	21060	Business	18900.00
0005432382749	21060	Business	18900.00
0005432328082	21060	Business	18900.00
0005432328194	21060	Business	18900.00
0005432328124	21060	Business	18900.00
0005432054297	21060	Business	18900.00
0005432328075	21060	Economy	6300.00
0005432328151	21060	Economy	6300.00
0005432328140	21060	Economy	6300.00
0005432328168	21060	Economy	6300.00
0005432328196	21060	Economy	6300.00
0005432328052	21060	Economy	6300.00
0005432328121	21060	Economy	6300.00
0005432382750	21060	Economy	6300.00
0005432328130	21060	Economy	6300.00
0005432382526	21060	Economy	6300.00
0005432328113	21060	Economy	6900.00
0005432328396	21060	Economy	6900.00
0005432328435	21060	Economy	6900.00
0005432328076	21060	Economy	6900.00
0005432328067	21060	Economy	6900.00
0005432328353	21060	Economy	6300.00
0005432054299	21060	Economy	6300.00
0005432328308	21060	Economy	6300.00
0005432382616	21060	Economy	6300.00
0005432328195	21060	Economy	6300.00
0005432328146	21060	Economy	6300.00
0005432382687	21060	Economy	6300.00
0005432328262	21060	Economy	6300.00
0005432328120	21060	Economy	6300.00
0005432328181	21060	Economy	6300.00
0005432328179	21060	Economy	6300.00
0005432382676	21060	Economy	6300.00
0005432328186	21060	Economy	6300.00
0005432328128	21060	Economy	6300.00
0005432054298	21060	Economy	6300.00
0005432328131	21060	Economy	6300.00
0005432328391	21060	Economy	6300.00
0005432382589	21060	Economy	6300.00
0005432382672	21060	Economy	6300.00
0005432382606	21060	Economy	6300.00
0005432382576	21060	Economy	6300.00
0005432328188	21060	Economy	6300.00
0005432328254	21060	Economy	6300.00
0005432328166	21060	Economy	6300.00
0005432327921	21060	Economy	6300.00
0005432382722	21060	Economy	6300.00
0005432328189	21060	Economy	6300.00
0005432328358	21060	Economy	6300.00
0005432382621	21060	Economy	6300.00
0005432328220	21060	Economy	6300.00
0005432382587	21060	Economy	6300.00
0005432328363	21060	Economy	6300.00
0005432328112	21060	Economy	6300.00
0005432382689	21060	Economy	6300.00
0005432328096	21060	Economy	6300.00
0005432328058	21060	Economy	6300.00
0005432382652	21060	Economy	6300.00
0005432382677	21060	Economy	6300.00
0005432382671	21060	Economy	6300.00
0005432328226	21060	Economy	6300.00
0005432328094	21060	Economy	6300.00
0005432382649	21060	Economy	6300.00
0005432382688	21060	Economy	6300.00
0005432382615	21060	Economy	6300.00
0005432382742	21060	Economy	6300.00
0005432382721	21060	Economy	6300.00
0005432328239	21060	Economy	6300.00
0005432327916	21060	Economy	6300.00
0005432328180	21060	Economy	6300.00
0005432382611	21060	Economy	6300.00
0005432328357	21060	Economy	6300.00
0005432328310	21060	Economy	6300.00
0005432327995	21060	Economy	6300.00
0005432327915	21060	Economy	6300.00
0005432328209	21060	Economy	6300.00
0005432328152	21060	Economy	6300.00
0005432328237	21060	Economy	6300.00
0005432328147	21060	Economy	6300.00
0005432328227	21060	Economy	6300.00
0005432382682	21060	Economy	6300.00
0005432328311	21060	Economy	6300.00
0005432382588	21060	Economy	6300.00
0005432382684	21060	Economy	6300.00
0005432328312	21060	Economy	6300.00
0005432328080	21060	Economy	6300.00
0005432382577	21060	Economy	6300.00
0005432382748	21060	Economy	6300.00
0005432328170	21060	Economy	6300.00
0005432328097	21060	Economy	6300.00
0005432328197	21060	Economy	6300.00
0005432328590	31224	Business	18900.00
0005432383080	31224	Business	18900.00
0005432383089	31224	Business	18900.00
0005432383085	31224	Business	18900.00
0005432328578	31224	Business	18900.00
0005432383060	31224	Business	18900.00
0005432328567	31224	Business	18900.00
0005432383074	31224	Business	18900.00
0005432328553	31224	Business	18900.00
0005432383071	31224	Business	18900.00
0005432328570	31224	Business	18900.00
0005432328587	31224	Business	18900.00
0005432383091	31224	Economy	6300.00
0005432383087	31224	Economy	6300.00
0005432383082	31224	Economy	6300.00
0005432328592	31224	Economy	6300.00
0005432328584	31224	Economy	6300.00
0005432383076	31224	Economy	6300.00
0005432328582	31224	Economy	6300.00
0005432328591	31224	Economy	6300.00
0005432328589	31224	Economy	6300.00
0005432383066	31224	Economy	6300.00
0005432383065	31224	Economy	6900.00
0005432328594	31224	Economy	6900.00
0005432328566	31224	Economy	6900.00
0005432383093	31224	Economy	6900.00
0005432328576	31224	Economy	6300.00
0005432287177	31224	Economy	6300.00
0005432383090	31224	Economy	6300.00
0005432328557	31224	Economy	6300.00
0005432383063	31224	Economy	6300.00
0005432383057	31224	Economy	6300.00
0005432328574	31224	Economy	6300.00
0005432328559	31224	Economy	6300.00
0005432383058	31224	Economy	6300.00
0005432328558	31224	Economy	6300.00
0005432383075	31224	Economy	6300.00
0005432383068	31224	Economy	6300.00
0005432383062	31224	Economy	6300.00
0005432383083	31224	Economy	6300.00
0005432383070	31224	Economy	6300.00
0005432383081	31224	Economy	6300.00
0005432383078	31224	Economy	6300.00
0005432328585	31224	Economy	6300.00
0005432287172	31224	Economy	6300.00
0005432328551	31224	Economy	6300.00
0005432328550	31224	Economy	6300.00
0005432328552	31224	Economy	6300.00
0005432328583	31224	Economy	6300.00
0005432328563	31224	Economy	6300.00
0005432383086	31224	Economy	6300.00
0005432383092	31224	Economy	6300.00
0005432383084	31224	Economy	6300.00
0005432328586	31224	Economy	6300.00
0005432383077	31224	Economy	6300.00
0005432383064	31224	Economy	6300.00
0005432328556	31224	Economy	6300.00
0005432383069	31224	Economy	6300.00
0005432383088	31224	Economy	6300.00
0005432328581	31224	Economy	6300.00
0005432328579	31224	Economy	6300.00
0005432287173	31224	Economy	6300.00
0005432383061	31224	Economy	6300.00
0005432383067	31224	Economy	6300.00
0005432328577	31224	Economy	6300.00
0005432328554	31224	Economy	6300.00
0005432383059	31224	Economy	6300.00
0005432287175	31224	Economy	6300.00
0005432328555	31224	Economy	6300.00
0005432328580	31224	Economy	6300.00
0005432328565	31224	Economy	6300.00
0005432328571	31224	Economy	6300.00
0005432383073	31224	Economy	6300.00
0005432383079	31224	Economy	6300.00
0005432328572	31224	Economy	6300.00
0005432328573	31224	Economy	6300.00
0005432328588	31224	Economy	6300.00
0005432383072	31224	Economy	6300.00
0005432848836	31224	Economy	6300.00
0005432287176	31224	Economy	6300.00
0005432328562	31224	Economy	6300.00
0005432328575	31224	Economy	6300.00
0005432328564	31224	Economy	6300.00
0005432328569	31224	Economy	6300.00
0005432328593	31224	Economy	6300.00
0005432328568	31224	Economy	6300.00
0005432328561	31224	Economy	6300.00
0005432287174	31224	Economy	6300.00
0005432328560	31224	Economy	6300.00
0005432383094	31224	Economy	6300.00
0005432424295	13298	Business	12700.00
0005432424285	13298	Business	12700.00
0005432424300	13298	Business	12700.00
0005432424273	13298	Business	12700.00
0005432424293	13298	Business	12700.00
0005432424297	13298	Business	12700.00
0005432424296	13298	Business	12700.00
0005432424307	13298	Business	12700.00
0005432424283	13298	Business	12700.00
0005432424308	13298	Economy	4200.00
0005432424312	13298	Economy	4200.00
0005432424291	13298	Economy	4200.00
0005432424305	13298	Economy	4200.00
0005432424317	13298	Economy	4200.00
0005432424279	13298	Economy	4700.00
0005432424276	13298	Economy	4700.00
0005432424303	13298	Economy	4700.00
0005432424311	13298	Economy	4200.00
0005432424294	13298	Economy	4200.00
0005432424302	13298	Economy	4200.00
0005432424320	13298	Economy	4200.00
0005432424292	13298	Economy	4200.00
0005432424316	13298	Economy	4200.00
0005432424277	13298	Economy	4200.00
0005432424280	13298	Economy	4200.00
0005432424275	13298	Economy	4200.00
0005432424284	13298	Economy	4200.00
0005432424289	13298	Economy	4200.00
0005432424319	13298	Economy	4200.00
0005432424287	13298	Economy	4200.00
0005432424274	13298	Economy	4200.00
0005432424269	13298	Economy	4200.00
0005432424270	13298	Economy	4200.00
0005432424313	13298	Economy	4200.00
0005432424310	13298	Economy	4200.00
0005432424306	13298	Economy	4200.00
0005432424309	13298	Economy	4200.00
0005432424271	13298	Economy	4200.00
0005432424299	13298	Economy	4200.00
0005432424286	13298	Economy	4200.00
0005432424314	13298	Economy	4200.00
0005432424288	13298	Economy	4200.00
0005432424282	13298	Economy	4200.00
0005432424281	13298	Economy	4200.00
0005432424272	13298	Economy	4200.00
0005432424278	13298	Economy	4200.00
0005432424323	13298	Economy	4200.00
0005432424321	13298	Economy	4200.00
0005432424298	13298	Economy	4200.00
0005432424301	13298	Economy	4200.00
0005432424304	13298	Economy	4200.00
0005432424290	13298	Economy	4200.00
0005432424318	13298	Economy	4200.00
0005432424315	13298	Economy	4200.00
0005432424322	13298	Economy	4200.00
0005432423751	30700	Business	12700.00
0005432423898	30700	Business	12700.00
0005432423652	30700	Business	12700.00
0005432423878	30700	Business	12700.00
0005432423929	30700	Business	12700.00
0005432423752	30700	Business	12700.00
0005432423779	30700	Business	12700.00
0005432423827	30700	Economy	4200.00
0005432423876	30700	Economy	4200.00
0005432423851	30700	Economy	4200.00
0005432423773	30700	Economy	4200.00
0005432423852	30700	Economy	4200.00
0005432423899	30700	Economy	4200.00
0005432423912	30700	Economy	4200.00
0005432423861	30700	Economy	4200.00
0005432423908	30700	Economy	4700.00
0005432423921	30700	Economy	4700.00
0005432423714	30700	Economy	4200.00
0005432423763	30700	Economy	4200.00
0005432423607	30700	Economy	4200.00
0005432423880	30700	Economy	4200.00
0005432423871	30700	Economy	4200.00
0005432423813	30700	Economy	4200.00
0005432423897	30700	Economy	4200.00
0005432423799	30700	Economy	4200.00
0005432423814	30700	Economy	4200.00
0005432423850	30700	Economy	4200.00
0005432423777	30700	Economy	4200.00
0005432423894	30700	Economy	4200.00
0005432423760	30700	Economy	4200.00
0005432423872	30700	Economy	4200.00
0005432423915	30700	Economy	4200.00
0005432423750	30700	Economy	4200.00
0005432423910	30700	Economy	4200.00
0005432423761	30700	Economy	4200.00
0005432423877	30700	Economy	4200.00
0005432423686	30700	Economy	4200.00
0005432423824	30700	Economy	4200.00
0005432423870	30700	Economy	4200.00
0005432423875	30700	Economy	4200.00
0005432423819	30700	Economy	4200.00
0005432423774	30700	Economy	4200.00
0005432423778	30700	Economy	4200.00
0005432423749	30700	Economy	4200.00
0005432423802	30700	Economy	4200.00
0005432423708	30700	Economy	4200.00
0005432423826	30700	Economy	4200.00
0005432423914	30700	Economy	4200.00
0005432423788	30700	Economy	4200.00
0005432423911	30700	Economy	4200.00
0005432423710	30700	Economy	4200.00
0005432423769	30700	Economy	4200.00
0005432423879	30700	Economy	4200.00
0005432423869	30700	Economy	4200.00
0005432423895	30700	Economy	4200.00
0005432423817	30700	Economy	4200.00
0005432822184	9613	Business	32600.00
0005432901432	9613	Business	32600.00
0005432817407	9613	Business	32600.00
0005434157416	9613	Business	32600.00
0005432817400	9613	Business	32600.00
0005432822186	9613	Business	32600.00
0005432822188	9613	Economy	10900.00
0005432817417	9613	Economy	10900.00
0005432817422	9613	Economy	10900.00
0005432822187	9613	Economy	10900.00
0005432817405	9613	Economy	10900.00
0005432822189	9613	Economy	10900.00
0005432901365	9613	Economy	10900.00
0005434157403	9613	Economy	11900.00
0005432817409	9613	Economy	11900.00
0005432817418	9613	Economy	11900.00
0005432817420	9613	Economy	11900.00
0005432817401	9613	Economy	10900.00
0005434448308	9613	Economy	10900.00
0005432817424	9613	Economy	10900.00
0005432822185	9613	Economy	10900.00
0005432817421	9613	Economy	10900.00
0005432901411	9613	Economy	10900.00
0005432817412	9613	Economy	10900.00
0005434157430	9613	Economy	10900.00
0005432817411	9613	Economy	10900.00
0005432817423	9613	Economy	10900.00
0005432901383	9613	Economy	10900.00
0005432901390	9613	Economy	10900.00
0005432817419	9613	Economy	10900.00
0005434186177	9613	Economy	10900.00
0005432822191	9613	Economy	10900.00
0005434157423	9613	Economy	10900.00
0005432817410	9613	Economy	10900.00
0005432901438	9613	Economy	10900.00
0005432288979	9613	Economy	10900.00
0005432288980	9613	Economy	10900.00
0005432817394	9613	Economy	10900.00
0005434157402	9613	Economy	10900.00
0005432822183	9613	Economy	10900.00
0005432901382	9613	Economy	10900.00
0005434448307	9613	Economy	10900.00
0005432822190	9613	Economy	10900.00
0005434157419	9613	Economy	10900.00
0005432901431	9613	Economy	10900.00
0005432817397	9613	Economy	10900.00
0005432817402	9613	Economy	10900.00
0005432817399	9613	Economy	10900.00
0005432817404	9613	Economy	10900.00
0005432817413	9613	Economy	10900.00
0005432901439	9613	Economy	10900.00
0005432901421	9613	Economy	10900.00
0005432817414	9613	Economy	10900.00
0005432817415	9613	Economy	10900.00
0005432817408	9613	Economy	10900.00
0005432901437	9613	Economy	10900.00
0005432817416	9613	Economy	10900.00
0005432817396	9613	Economy	10900.00
0005432817395	9613	Economy	10900.00
0005434186176	9613	Economy	10900.00
0005432817406	9613	Economy	10900.00
0005432817403	9613	Economy	10900.00
0005432901405	9613	Economy	10900.00
0005432817398	9613	Economy	10900.00
0005434448309	9613	Economy	10900.00
0005432817165	28962	Business	32600.00
0005432901566	28962	Business	32600.00
0005432822142	28962	Business	32600.00
0005434157461	28962	Business	32600.00
0005432817237	28962	Business	32600.00
0005434157465	28962	Business	32600.00
0005432822123	28962	Business	32600.00
0005432817044	28962	Business	32600.00
0005432817186	28962	Economy	10900.00
0005432817203	28962	Economy	10900.00
0005432901568	28962	Economy	10900.00
0005432002071	28962	Economy	10900.00
0005432901574	28962	Economy	10900.00
0005432901573	28962	Economy	10900.00
0005432817116	28962	Economy	10900.00
0005432901577	28962	Economy	11900.00
0005432817152	28962	Economy	11900.00
0005432817060	28962	Economy	11900.00
0005432901565	28962	Economy	11900.00
0005432901579	28962	Economy	11900.00
0005432822122	28962	Economy	10900.00
0005432817111	28962	Economy	10900.00
0005434157462	28962	Economy	10900.00
0005432817140	28962	Economy	10900.00
0005432901580	28962	Economy	10900.00
0005432901564	28962	Economy	10900.00
0005432822087	28962	Economy	10900.00
0005432817228	28962	Economy	10900.00
0005432817059	28962	Economy	10900.00
0005434448283	28962	Economy	10900.00
0005432817190	28962	Economy	10900.00
0005434157463	28962	Economy	10900.00
0005432817248	28962	Economy	10900.00
0005432817191	28962	Economy	10900.00
0005432901569	28962	Economy	10900.00
0005432822091	28962	Economy	10900.00
0005432817115	28962	Economy	10900.00
0005432901572	28962	Economy	10900.00
0005432817150	28962	Economy	10900.00
0005432817141	28962	Economy	10900.00
0005432822107	28962	Economy	10900.00
0005434186190	28962	Economy	10900.00
0005432901571	28962	Economy	10900.00
0005432822082	28962	Economy	10900.00
0005432817192	28962	Economy	10900.00
0005434186189	28962	Economy	10900.00
0005432817202	28962	Economy	10900.00
0005432817189	28962	Economy	10900.00
0005432901575	28962	Economy	10900.00
0005434186191	28962	Economy	10900.00
0005432901570	28962	Economy	10900.00
0005432817207	28962	Economy	10900.00
0005432817261	28962	Economy	10900.00
0005434157464	28962	Economy	10900.00
0005432817204	28962	Economy	10900.00
0005432817238	28962	Economy	10900.00
0005432901578	28962	Economy	10900.00
0005434157466	28962	Economy	10900.00
0005432817194	28962	Economy	10900.00
0005432901576	28962	Economy	10900.00
0005432901567	28962	Economy	10900.00
0005432822092	28962	Economy	10900.00
0005432822098	28962	Economy	10900.00
0005432817229	28962	Economy	10900.00
0005432817124	28962	Economy	10900.00
0005432822106	28962	Economy	10900.00
0005432817139	28962	Economy	10900.00
0005432613853	15124	Economy	11000.00
0005432611702	15124	Economy	11000.00
0005432613855	15124	Economy	11000.00
0005432613852	15124	Economy	11000.00
0005432611701	15124	Economy	11000.00
0005432613854	15124	Economy	11000.00
0005432611704	15124	Economy	11000.00
0005432611703	15124	Economy	11000.00
0005432611700	15124	Economy	11000.00
0005432613851	15124	Economy	11000.00
0005435841820	31561	Economy	11000.00
0005432607506	31561	Economy	11000.00
0005435842326	31561	Economy	11000.00
0005432947920	11865	Business	105900.00
0005433568922	11865	Business	105900.00
0005433568871	11865	Business	105900.00
0005433568935	11865	Business	105900.00
0005433568894	11865	Business	105900.00
0005433568904	11865	Business	105900.00
0005433568880	11865	Business	105900.00
0005433568943	11865	Business	105900.00
0005433568945	11865	Business	105900.00
0005433568905	11865	Business	105900.00
0005432947926	11865	Business	105900.00
0005433568934	11865	Business	105900.00
0005433568944	11865	Business	105900.00
0005432947981	11865	Business	105900.00
0005433568898	11865	Business	105900.00
0005432947927	11865	Business	105900.00
0005433568942	11865	Business	105900.00
0005432948039	11865	Business	105900.00
0005433568878	11865	Economy	35300.00
0005433568917	11865	Business	105900.00
0005432948119	11865	Economy	35300.00
0005433568883	11865	Economy	35300.00
0005433568900	11865	Economy	35300.00
0005432948060	11865	Economy	35300.00
0005433568888	11865	Economy	35300.00
0005433568939	11865	Economy	35300.00
0005432947907	11865	Economy	35300.00
0005433568892	11865	Economy	35300.00
0005433568931	11865	Economy	35300.00
0005432947978	11865	Economy	35300.00
0005433568918	11865	Economy	35300.00
0005433568930	11865	Economy	38800.00
0005433568906	11865	Economy	38800.00
0005432947788	11865	Economy	38800.00
0005433568938	11865	Economy	38800.00
0005433568875	11865	Economy	35300.00
0005433568872	11865	Economy	35300.00
0005433568940	11865	Economy	35300.00
0005433568912	11865	Economy	35300.00
0005433568913	11865	Economy	35300.00
0005433568881	11865	Economy	35300.00
0005433568933	11865	Economy	35300.00
0005433568882	11865	Economy	35300.00
0005432947847	11865	Economy	35300.00
0005432948064	11865	Economy	35300.00
0005433568874	11865	Economy	35300.00
0005433568911	11865	Economy	35300.00
0005432947987	11865	Economy	35300.00
0005433568893	11865	Economy	35300.00
0005433568908	11865	Economy	35300.00
0005432948059	11865	Economy	35300.00
0005433568929	11865	Economy	35300.00
0005432947985	11865	Economy	35300.00
0005433568936	11865	Economy	35300.00
0005432947837	11865	Economy	35300.00
0005433568924	11865	Economy	35300.00
0005433568907	11865	Economy	35300.00
0005432947846	11865	Economy	35300.00
0005433568890	11865	Economy	35300.00
0005432947908	11865	Economy	35300.00
0005433568932	11865	Economy	35300.00
0005433568903	11865	Economy	35300.00
0005433568915	11865	Economy	35300.00
0005433568895	11865	Economy	35300.00
0005433568941	11865	Economy	35300.00
0005433568899	11865	Economy	35300.00
0005432947943	11865	Economy	35300.00
0005433568910	11865	Economy	35300.00
0005433568884	11865	Economy	35300.00
0005433568916	11865	Economy	35300.00
0005432947980	11865	Economy	35300.00
0005433568887	11865	Economy	35300.00
0005433568928	11865	Economy	35300.00
0005433568885	11865	Economy	35300.00
0005433568897	11865	Economy	35300.00
0005433568902	11865	Economy	35300.00
0005433568923	11865	Economy	35300.00
0005433568914	11865	Economy	35300.00
0005433568889	11865	Economy	35300.00
0005433568921	11865	Economy	35300.00
0005433568927	11865	Economy	35300.00
0005432947789	11865	Economy	35300.00
0005433568877	11865	Economy	35300.00
0005432947986	11865	Economy	35300.00
0005432948013	11865	Economy	35300.00
0005433568879	11865	Economy	35300.00
0005433568873	11865	Economy	35300.00
0005433568925	11865	Economy	35300.00
0005433568891	11865	Economy	35300.00
0005432948014	11865	Economy	35300.00
0005433568869	11865	Economy	35300.00
0005432948065	11865	Economy	35300.00
0005432947893	11865	Economy	35300.00
0005433568876	11865	Economy	35300.00
0005432947792	11865	Economy	35300.00
0005433568919	11865	Economy	35300.00
0005432948084	11865	Economy	35300.00
0005433568870	11865	Economy	35300.00
0005433568937	11865	Economy	35300.00
0005433568926	11865	Economy	35300.00
0005433568901	11865	Economy	35300.00
0005433568886	11865	Economy	35300.00
0005433568920	11865	Economy	35300.00
0005433568909	11865	Economy	35300.00
0005433568896	11865	Economy	35300.00
0005432948425	25293	Business	105900.00
0005433568144	25293	Business	105900.00
0005433568388	25293	Business	105900.00
0005432948411	25293	Business	105900.00
0005432948431	25293	Business	105900.00
0005433568411	25293	Business	105900.00
0005432948391	25293	Business	105900.00
0005433568398	25293	Business	105900.00
0005432948407	25293	Business	105900.00
0005432948430	25293	Business	105900.00
0005432948392	25293	Business	105900.00
0005433568408	25293	Business	105900.00
0005433568220	25293	Business	105900.00
0005432948398	25293	Business	105900.00
0005433568409	25293	Business	105900.00
0005433568399	25293	Business	105900.00
0005432948416	25293	Business	105900.00
0005433568309	25293	Business	105900.00
0005432948408	25293	Economy	35300.00
0005432948419	25293	Economy	35300.00
0005433568339	25293	Economy	35300.00
0005433568391	25293	Economy	35300.00
0005433568117	25293	Economy	35300.00
0005432948399	25293	Economy	35300.00
0005433568310	25293	Economy	35300.00
0005432948428	25293	Economy	35300.00
0005433568326	25293	Economy	38800.00
0005432948406	25293	Economy	38800.00
0005432948400	25293	Economy	38800.00
0005433568340	25293	Economy	38800.00
0005433568320	25293	Economy	35300.00
0005433568390	25293	Economy	35300.00
0005432948405	25293	Economy	35300.00
0005433568389	25293	Economy	35300.00
0005432948420	25293	Economy	35300.00
0005433568244	25293	Economy	35300.00
0005433568275	25293	Economy	35300.00
0005432948390	25293	Economy	35300.00
0005433568124	25293	Economy	35300.00
0005433568282	25293	Economy	35300.00
0005432948395	25293	Economy	35300.00
0005432948415	25293	Economy	35300.00
0005433568146	25293	Economy	35300.00
0005432948401	25293	Economy	35300.00
0005433568329	25293	Economy	35300.00
0005432948422	25293	Economy	35300.00
0005433568357	25293	Economy	35300.00
0005432948414	25293	Economy	35300.00
0005433568386	25293	Economy	35300.00
0005433568412	25293	Economy	35300.00
0005433568369	25293	Economy	35300.00
0005432948409	25293	Economy	35300.00
0005432948389	25293	Economy	35300.00
0005433568278	25293	Economy	35300.00
0005433568141	25293	Economy	35300.00
0005433568281	25293	Economy	35300.00
0005433568317	25293	Economy	35300.00
0005433568125	25293	Economy	35300.00
0005433568330	25293	Economy	35300.00
0005432948418	25293	Economy	35300.00
0005432948429	25293	Economy	35300.00
0005433568032	25293	Economy	35300.00
0005432948423	25293	Economy	35300.00
0005433568349	25293	Economy	35300.00
0005432948412	25293	Economy	35300.00
0005432948410	25293	Economy	35300.00
0005433568263	25293	Economy	35300.00
0005432948421	25293	Economy	35300.00
0005432948424	25293	Economy	35300.00
0005433568301	25293	Economy	35300.00
0005432948397	25293	Economy	35300.00
0005433568264	25293	Economy	35300.00
0005432948394	25293	Economy	35300.00
0005433568331	25293	Economy	35300.00
0005432948396	25293	Economy	35300.00
0005432948393	25293	Economy	35300.00
0005433568277	25293	Economy	35300.00
0005433568138	25293	Economy	35300.00
0005433568145	25293	Economy	35300.00
0005432948402	25293	Economy	35300.00
0005432948413	25293	Economy	35300.00
0005433568328	25293	Economy	35300.00
0005433568100	25293	Economy	35300.00
0005433568410	25293	Economy	35300.00
0005433568426	25293	Economy	35300.00
0005433568387	25293	Economy	35300.00
0005432948417	25293	Economy	35300.00
0005432948404	25293	Economy	35300.00
0005433568148	25293	Economy	35300.00
0005432948427	25293	Economy	35300.00
0005432948426	25293	Economy	35300.00
0005433568315	25293	Economy	35300.00
0005433568274	25293	Economy	35300.00
0005433568255	25293	Economy	35300.00
0005433568303	25293	Economy	35300.00
0005432948403	25293	Economy	35300.00
0005433568267	25293	Economy	35300.00
0005433811614	27935	Economy	35100.00
0005433811613	27935	Economy	35100.00
0005433811615	27935	Economy	35100.00
0005433811612	27935	Economy	35100.00
0005433811611	27935	Economy	35100.00
0005433811610	27935	Economy	35100.00
0005434654618	5424	Business	67200.00
0005434654620	5424	Business	67200.00
0005434654622	5424	Business	67200.00
0005434654619	5424	Business	67200.00
0005434654617	5424	Business	67200.00
0005434654633	5424	Business	67200.00
0005434656553	5424	Business	67200.00
0005434654625	5424	Business	67200.00
0005432114197	5424	Economy	22400.00
0005434654609	5424	Economy	22400.00
0005435555347	5424	Economy	22400.00
0005434654614	5424	Economy	22400.00
0005435555346	5424	Economy	22400.00
0005434654626	5424	Economy	22400.00
0005435340164	5424	Economy	22400.00
0005435340051	5424	Economy	24600.00
0005435340106	5424	Economy	24600.00
0005435340153	5424	Economy	22400.00
0005434654627	5424	Economy	22400.00
0005434654631	5424	Economy	22400.00
0005434654621	5424	Economy	22400.00
0005434654632	5424	Economy	22400.00
0005434656552	5424	Economy	22400.00
0005435555345	5424	Economy	22400.00
0005432114195	5424	Economy	22400.00
0005434654629	5424	Economy	22400.00
0005434656554	5424	Economy	22400.00
0005434654612	5424	Economy	22400.00
0005432114196	5424	Economy	22400.00
0005434654630	5424	Economy	22400.00
0005434654615	5424	Economy	22400.00
0005434654636	5424	Economy	22400.00
0005434654635	5424	Economy	22400.00
0005434654610	5424	Economy	22400.00
0005434654639	5424	Economy	22400.00
0005434654637	5424	Economy	22400.00
0005434654624	5424	Economy	22400.00
0005435340105	5424	Economy	22400.00
0005434654638	5424	Economy	22400.00
0005434654611	5424	Economy	22400.00
0005434654640	5424	Economy	22400.00
0005434654613	5424	Economy	22400.00
0005434654616	5424	Economy	22400.00
0005434654623	5424	Economy	22400.00
0005434654634	5424	Economy	22400.00
0005434654628	5424	Economy	22400.00
0005435340113	5424	Economy	22400.00
0005435340170	5424	Economy	22400.00
0005434654334	12547	Business	67200.00
0005434654395	12547	Business	67200.00
0005435340225	12547	Business	67200.00
0005434654289	12547	Business	67200.00
0005434654315	12547	Business	67200.00
0005435340227	12547	Economy	22400.00
0005434654389	12547	Economy	22400.00
0005435340230	12547	Economy	22400.00
0005434654388	12547	Economy	24600.00
0005434654331	12547	Economy	24600.00
0005434654332	12547	Economy	24600.00
0005434654302	12547	Economy	22400.00
0005434654335	12547	Economy	22400.00
0005435340235	12547	Economy	22400.00
0005435340231	12547	Economy	22400.00
0005434654259	12547	Economy	22400.00
0005434654467	12547	Economy	22400.00
0005435340234	12547	Economy	22400.00
0005434654510	12547	Economy	22400.00
0005434654452	12547	Economy	22400.00
0005434656546	12547	Economy	22400.00
0005434654279	12547	Economy	22400.00
0005434654401	12547	Economy	22400.00
0005435555367	12547	Economy	22400.00
0005435340229	12547	Economy	22400.00
0005435340226	12547	Economy	22400.00
0005435340228	12547	Economy	22400.00
0005434654278	12547	Economy	22400.00
0005434654390	12547	Economy	22400.00
0005434654360	12547	Economy	22400.00
0005435340236	12547	Economy	22400.00
0005434654258	12547	Economy	22400.00
0005434654280	12547	Economy	22400.00
0005435555365	12547	Economy	22400.00
0005434656541	12547	Economy	22400.00
0005434654333	12547	Economy	22400.00
0005435340223	12547	Economy	22400.00
0005434654353	12547	Economy	22400.00
0005434654387	12547	Economy	22400.00
0005434654361	12547	Economy	22400.00
0005434654466	12547	Economy	22400.00
0005435340237	12547	Economy	22400.00
0005434654341	12547	Economy	22400.00
0005434654232	12547	Economy	22400.00
0005435340233	12547	Economy	22400.00
0005434654352	12547	Economy	22400.00
0005435340232	12547	Economy	22400.00
0005434654316	12547	Economy	22400.00
0005434654402	12547	Economy	22400.00
0005434654453	12547	Economy	22400.00
0005434654373	12547	Economy	22400.00
0005434654385	12547	Economy	22400.00
0005435340224	12547	Economy	22400.00
0005434654282	12547	Economy	22400.00
0005434654384	12547	Economy	22400.00
0005435555366	12547	Economy	22400.00
0005433656660	7428	Business	32000.00
0005432078097	7428	Business	32000.00
0005432078098	7428	Business	32000.00
0005432078093	7428	Business	32000.00
0005433722207	7428	Business	32000.00
0005433715868	7428	Business	32000.00
0005432428898	7428	Business	32000.00
0005433715850	7428	Business	32000.00
0005433715842	7428	Business	32000.00
0005433715854	7428	Economy	10700.00
0005433719131	7428	Economy	10700.00
0005432428874	7428	Economy	10700.00
0005433715857	7428	Economy	10700.00
0005433722204	7428	Economy	10700.00
0005433715879	7428	Economy	10700.00
0005433715875	7428	Economy	10700.00
0005433715867	7428	Economy	10700.00
0005433715881	7428	Economy	10700.00
0005433656662	7428	Economy	10700.00
0005433715865	7428	Economy	10700.00
0005433715839	7428	Economy	10700.00
0005433689905	7428	Economy	10700.00
0005435266082	7428	Economy	10700.00
0005432078096	7428	Economy	10700.00
0005433715882	7428	Economy	10700.00
0005433722208	7428	Economy	10700.00
0005433715873	7428	Economy	10700.00
0005435266098	7428	Economy	10700.00
0005433715874	7428	Economy	10700.00
0005433715843	7428	Economy	10700.00
0005433656661	7428	Economy	10700.00
0005433722202	7428	Economy	10700.00
0005433715838	7428	Economy	10700.00
0005433715870	7428	Economy	10700.00
0005433715845	7428	Economy	11700.00
0005433715878	7428	Economy	11700.00
0005433715835	7428	Economy	11700.00
0005433722201	7428	Economy	11700.00
0005433715862	7428	Economy	10700.00
0005433715869	7428	Economy	10700.00
0005433715834	7428	Economy	10700.00
0005435266084	7428	Economy	10700.00
0005433715849	7428	Economy	10700.00
0005433715876	7428	Economy	10700.00
0005435266089	7428	Economy	10700.00
0005435266102	7428	Economy	10700.00
0005433722200	7428	Economy	10700.00
0005433715866	7428	Economy	10700.00
0005433715844	7428	Economy	10700.00
0005433715846	7428	Economy	10700.00
0005433722206	7428	Economy	10700.00
0005433715837	7428	Economy	10700.00
0005433715858	7428	Economy	10700.00
0005433715853	7428	Economy	10700.00
0005433715841	7428	Economy	10700.00
0005433715880	7428	Economy	10700.00
0005433715861	7428	Economy	10700.00
0005433715864	7428	Economy	10700.00
0005433715863	7428	Economy	10700.00
0005433719132	7428	Economy	10700.00
0005435266083	7428	Economy	10700.00
0005433715877	7428	Economy	10700.00
0005433715847	7428	Economy	10700.00
0005433715836	7428	Economy	10700.00
0005433688802	7428	Economy	10700.00
0005433688803	7428	Economy	10700.00
0005433715871	7428	Economy	10700.00
0005433715856	7428	Economy	10700.00
0005433715851	7428	Economy	10700.00
0005433722203	7428	Economy	10700.00
0005433715852	7428	Economy	10700.00
0005433715883	7428	Economy	10700.00
0005433719133	7428	Economy	10700.00
0005433715840	7428	Economy	10700.00
0005433656659	7428	Economy	10700.00
0005433722205	7428	Economy	10700.00
0005433715855	7428	Economy	10700.00
0005432078095	7428	Economy	10700.00
0005433715860	7428	Economy	10700.00
0005433719130	7428	Economy	10700.00
0005433715848	7428	Economy	10700.00
0005433719129	7428	Economy	10700.00
0005433715872	7428	Economy	10700.00
0005432078094	7428	Economy	10700.00
0005433715859	7428	Economy	10700.00
0005433715433	29247	Business	32000.00
0005433685500	29247	Business	32000.00
0005433719096	29247	Business	32000.00
0005432428922	29247	Business	32000.00
0005433656639	29247	Business	32000.00
0005433656640	29247	Business	32000.00
0005433715620	29247	Business	32000.00
0005433715290	29247	Economy	10700.00
0005433715329	29247	Economy	10700.00
0005433715521	29247	Economy	10700.00
0005433715378	29247	Economy	10700.00
0005433719106	29247	Economy	10700.00
0005433715355	29247	Economy	10700.00
0005433715333	29247	Economy	10700.00
0005433719104	29247	Economy	10700.00
0005433715565	29247	Economy	10700.00
0005433722135	29247	Economy	10700.00
0005433715558	29247	Economy	10700.00
0005433685492	29247	Economy	10700.00
0005433722134	29247	Economy	10700.00
0005433722102	29247	Economy	10700.00
0005433715380	29247	Economy	10700.00
0005432006753	29247	Economy	10700.00
0005433656625	29247	Economy	10700.00
0005433715072	29247	Economy	10700.00
0005433656641	29247	Economy	10700.00
0005435266141	29247	Economy	10700.00
0005433715466	29247	Economy	10700.00
0005432428921	29247	Economy	10700.00
0005433719095	29247	Economy	11700.00
0005433715353	29247	Economy	11700.00
0005432428920	29247	Economy	11700.00
0005433715354	29247	Economy	10700.00
0005433715666	29247	Economy	10700.00
0005433715291	29247	Economy	10700.00
0005433715621	29247	Economy	10700.00
0005433715403	29247	Economy	10700.00
0005432006754	29247	Economy	10700.00
0005433715369	29247	Economy	10700.00
0005433715515	29247	Economy	10700.00
0005433715465	29247	Economy	10700.00
0005432006755	29247	Economy	10700.00
0005433656632	29247	Economy	10700.00
0005433715514	29247	Economy	10700.00
0005433722133	29247	Economy	10700.00
0005433715327	29247	Economy	10700.00
0005433715442	29247	Economy	10700.00
0005433715609	29247	Economy	10700.00
0005435266143	29247	Economy	10700.00
0005433715332	29247	Economy	10700.00
0005433715309	29247	Economy	10700.00
0005433715073	29247	Economy	10700.00
0005433722139	29247	Economy	10700.00
0005433715366	29247	Economy	10700.00
0005433715443	29247	Economy	10700.00
0005433715665	29247	Economy	10700.00
0005433722138	29247	Economy	10700.00
0005433715358	29247	Economy	10700.00
0005433715622	29247	Economy	10700.00
0005433715238	29247	Economy	10700.00
0005433715431	29247	Economy	10700.00
0005433715519	29247	Economy	10700.00
0005433715441	29247	Economy	10700.00
0005433722122	29247	Economy	10700.00
0005433715330	29247	Economy	10700.00
0005433715528	29247	Economy	10700.00
0005433722132	29247	Economy	10700.00
0005433656628	29247	Economy	10700.00
0005433656631	29247	Economy	10700.00
0005433715402	29247	Economy	10700.00
0005435266142	29247	Economy	10700.00
0005433715554	29247	Economy	10700.00
0005433715444	29247	Economy	10700.00
0005434184644	8707	Business	36500.00
0005434182067	8707	Business	36500.00
0005434182016	8707	Economy	12200.00
0005434182065	8707	Economy	12200.00
0005434095244	8707	Economy	12200.00
0005434095239	8707	Economy	12200.00
0005434095246	8707	Economy	12200.00
0005434182076	8707	Economy	12200.00
0005434095245	8707	Economy	12200.00
0005434095240	8707	Economy	12200.00
0005434095243	8707	Economy	12200.00
0005434095241	8707	Economy	12200.00
0005434095249	8707	Economy	12200.00
0005434095238	8707	Economy	12200.00
0005434182066	8707	Economy	12200.00
0005434095247	8707	Economy	12200.00
0005434095250	8707	Economy	12200.00
0005434095248	8707	Economy	12200.00
0005434184636	8707	Economy	12200.00
0005434182036	8707	Economy	12200.00
0005434181996	8707	Economy	12200.00
0005434182009	8707	Economy	12200.00
0005434182091	8707	Economy	12200.00
0005434095242	8707	Economy	12200.00
0005434184643	8707	Economy	12200.00
0005434182028	8707	Economy	12200.00
0005434183574	11629	Business	36500.00
0005434095161	11629	Business	36500.00
0005434095088	11629	Business	36500.00
0005434095079	11629	Business	36500.00
0005434183575	11629	Business	36500.00
0005434182158	11629	Economy	12200.00
0005434143702	11629	Economy	12200.00
0005434182153	11629	Economy	12200.00
0005434182152	11629	Economy	12200.00
0005434182159	11629	Economy	12200.00
0005434095074	11629	Economy	13400.00
0005434095090	11629	Economy	12200.00
0005434182150	11629	Economy	12200.00
0005434095163	11629	Economy	12200.00
0005434183573	11629	Economy	12200.00
0005434095106	11629	Economy	12200.00
0005434095158	11629	Economy	12200.00
0005434095093	11629	Economy	12200.00
0005434095058	11629	Economy	12200.00
0005434095179	11629	Economy	12200.00
0005434182161	11629	Economy	12200.00
0005434095123	11629	Economy	12200.00
0005434095126	11629	Economy	12200.00
0005434095071	11629	Economy	12200.00
0005434326264	11629	Economy	12200.00
0005434182151	11629	Economy	12200.00
0005434182154	11629	Economy	12200.00
0005434095089	11629	Economy	12200.00
0005434095087	11629	Economy	12200.00
0005434184659	11629	Economy	12200.00
0005434095150	11629	Economy	12200.00
0005434095160	11629	Economy	12200.00
0005434095108	11629	Economy	12200.00
0005434095086	11629	Economy	12200.00
0005434326265	11629	Economy	12200.00
0005434326261	11629	Economy	12200.00
0005434182160	11629	Economy	12200.00
0005434095125	11629	Economy	12200.00
0005434095105	11629	Economy	12200.00
0005434182162	11629	Economy	12200.00
0005434182157	11629	Economy	12200.00
0005434095180	11629	Economy	12200.00
0005434182155	11629	Economy	12200.00
0005434182156	11629	Economy	12200.00
0005434182163	11629	Economy	12200.00
0005433397392	1424	Business	33000.00
0005433397561	1424	Business	33000.00
0005435732294	1424	Business	33000.00
0005433397412	1424	Business	33000.00
0005433397449	1424	Business	33000.00
0005435732308	1424	Business	33000.00
0005435732312	1424	Business	33000.00
0005433397538	1424	Business	33000.00
0005435732304	1424	Business	33000.00
0005435732302	1424	Economy	11000.00
0005433397364	1424	Economy	11000.00
0005433456961	1424	Economy	11000.00
0005433397606	1424	Economy	11000.00
0005435732315	1424	Economy	11000.00
0005433456960	1424	Economy	11000.00
0005433397450	1424	Economy	11000.00
0005433397723	1424	Economy	11000.00
0005433456962	1424	Economy	12100.00
0005433397310	1424	Economy	12100.00
0005433397513	1424	Economy	12100.00
0005433397549	1424	Economy	12100.00
0005435732296	1424	Economy	11000.00
0005433397599	1424	Economy	11000.00
0005433397483	1424	Economy	11000.00
0005433397379	1424	Economy	11000.00
0005433397406	1424	Economy	11000.00
0005435732310	1424	Economy	11000.00
0005435732305	1424	Economy	11000.00
0005435732295	1424	Economy	11000.00
0005433397559	1424	Economy	11000.00
0005433397365	1424	Economy	11000.00
0005432297271	1424	Economy	11000.00
0005433397358	1424	Economy	11000.00
0005433397484	1424	Economy	11000.00
0005435732299	1424	Economy	11000.00
0005435732316	1424	Economy	11000.00
0005435732313	1424	Economy	11000.00
0005433397464	1424	Economy	11000.00
0005433397454	1424	Economy	11000.00
0005433397560	1424	Economy	11000.00
0005433397475	1424	Economy	11000.00
0005435732314	1424	Economy	11000.00
0005433397607	1424	Economy	11000.00
0005435732300	1424	Economy	11000.00
0005435732306	1424	Economy	11000.00
0005433397711	1424	Economy	11000.00
0005435732301	1424	Economy	11000.00
0005433397451	1424	Economy	11000.00
0005432297272	1424	Economy	11000.00
0005433397616	1424	Economy	11000.00
0005435732307	1424	Economy	11000.00
0005435732309	1424	Economy	11000.00
0005432906509	1424	Economy	11000.00
0005435732311	1424	Economy	11000.00
0005435732293	1424	Economy	11000.00
0005432297273	1424	Economy	11000.00
0005433397442	1424	Economy	11000.00
0005433397514	1424	Economy	11000.00
0005433397409	1424	Economy	11000.00
0005435732298	1424	Economy	11000.00
0005433397393	1424	Economy	11000.00
0005435732297	1424	Economy	11000.00
0005435732303	1424	Economy	11000.00
0005433397499	1424	Economy	11000.00
0005433456959	1424	Economy	11000.00
0005433397712	1424	Economy	11000.00
0005433397463	1424	Economy	11000.00
0005432906518	1424	Economy	11000.00
0005433397615	1424	Economy	11000.00
0005433397649	1424	Economy	11000.00
0005433456958	1424	Economy	11000.00
0005433397710	1424	Economy	11000.00
0005433397971	19245	Business	33000.00
0005433397931	19245	Business	33000.00
0005433397964	19245	Business	33000.00
0005433397970	19245	Business	33000.00
0005433397927	19245	Business	33000.00
0005433397974	19245	Business	33000.00
0005435732185	19245	Business	33000.00
0005435732229	19245	Business	33000.00
0005433397960	19245	Business	33000.00
0005433397953	19245	Business	33000.00
0005433397933	19245	Economy	11000.00
0005433397950	19245	Economy	11000.00
0005433397948	19245	Economy	11000.00
0005432906529	19245	Economy	11000.00
0005432906530	19245	Economy	11000.00
0005435732231	19245	Economy	11000.00
0005433397973	19245	Economy	12100.00
0005435732223	19245	Economy	12100.00
0005433397958	19245	Economy	11000.00
0005433397962	19245	Economy	11000.00
0005435732190	19245	Economy	11000.00
0005433397952	19245	Economy	11000.00
0005433397951	19245	Economy	11000.00
0005435732224	19245	Economy	11000.00
0005433456923	19245	Economy	11000.00
0005433456928	19245	Economy	11000.00
0005433397926	19245	Economy	11000.00
0005433397940	19245	Economy	11000.00
0005433397965	19245	Economy	11000.00
0005433397967	19245	Economy	11000.00
0005433397949	19245	Economy	11000.00
0005433397955	19245	Economy	11000.00
0005433397941	19245	Economy	11000.00
0005435732210	19245	Economy	11000.00
0005435732230	19245	Economy	11000.00
0005433397939	19245	Economy	11000.00
0005433397959	19245	Economy	11000.00
0005433397956	19245	Economy	11000.00
0005433397943	19245	Economy	11000.00
0005435732183	19245	Economy	11000.00
0005433397947	19245	Economy	11000.00
0005435732209	19245	Economy	11000.00
0005433397936	19245	Economy	11000.00
0005435732184	19245	Economy	11000.00
0005433397937	19245	Economy	11000.00
0005433397944	19245	Economy	11000.00
0005433397963	19245	Economy	11000.00
0005433397945	19245	Economy	11000.00
0005433397961	19245	Economy	11000.00
0005433397932	19245	Economy	11000.00
0005433397925	19245	Economy	11000.00
0005433397929	19245	Economy	11000.00
0005433397938	19245	Economy	11000.00
0005433397968	19245	Economy	11000.00
0005433397930	19245	Economy	11000.00
0005433397946	19245	Economy	11000.00
0005433397972	19245	Economy	11000.00
0005432906531	19245	Economy	11000.00
0005433397934	19245	Economy	11000.00
0005433397942	19245	Economy	11000.00
0005433397966	19245	Economy	11000.00
0005433397935	19245	Economy	11000.00
0005433397928	19245	Economy	11000.00
0005433397954	19245	Economy	11000.00
0005433397957	19245	Economy	11000.00
0005433397969	19245	Economy	11000.00
0005434443551	17367	Economy	14100.00
0005434443587	17367	Economy	14100.00
0005434443554	17367	Economy	14100.00
0005434443561	17367	Economy	14100.00
0005434443520	17367	Economy	14100.00
0005434443540	17367	Economy	14100.00
0005434443517	17367	Economy	14100.00
0005434443555	17367	Economy	14100.00
0005434443523	17367	Economy	14100.00
0005434443476	17367	Economy	14100.00
0005434443601	17367	Economy	14100.00
0005434443564	17367	Economy	14100.00
0005434443457	17367	Economy	14100.00
0005434443482	17367	Economy	14100.00
0005434443475	17367	Economy	14100.00
0005434443661	20565	Economy	14100.00
0005434443663	20565	Economy	14100.00
0005434443655	20565	Economy	14100.00
0005434443670	20565	Economy	14100.00
0005434443664	20565	Economy	14100.00
0005434443668	20565	Economy	14100.00
0005434443667	20565	Economy	14100.00
0005434443666	20565	Economy	14100.00
0005434443660	20565	Economy	14100.00
0005434443665	20565	Economy	14100.00
0005434443656	20565	Economy	14100.00
0005434443657	20565	Economy	14100.00
0005434443669	20565	Economy	14100.00
0005434443658	20565	Economy	14100.00
0005434443659	20565	Economy	14100.00
0005434443662	20565	Economy	14100.00
0005435377547	7234	Economy	5800.00
0005434954600	7234	Economy	5800.00
0005435377556	7234	Economy	5800.00
0005434954598	7234	Economy	5800.00
0005435377548	7234	Economy	5800.00
0005434954601	7234	Economy	5800.00
0005435377562	7234	Economy	5800.00
0005435377549	7234	Economy	5800.00
0005434954599	7234	Economy	5800.00
0005434954560	28342	Economy	5800.00
0005435377575	28342	Economy	5800.00
0005434954578	28342	Economy	5800.00
0005434954567	28342	Economy	5800.00
0005435377574	28342	Economy	5800.00
0005434954579	28342	Economy	5800.00
0005434954559	28342	Economy	5800.00
0005434351663	4466	Economy	15400.00
0005434351671	4466	Economy	14000.00
0005435893572	4466	Economy	14000.00
0005435893550	4466	Economy	14000.00
0005434351664	4466	Economy	14000.00
0005435893549	4466	Economy	14000.00
0005435893540	4466	Economy	14000.00
0005435893570	4466	Economy	14000.00
0005434351668	4466	Economy	14000.00
0005434351669	4466	Economy	14000.00
0005434351672	4466	Economy	14000.00
0005435893569	4466	Economy	14000.00
0005434351673	4466	Economy	14000.00
0005434351665	4466	Economy	14000.00
0005434351667	4466	Economy	14000.00
0005434351661	4466	Economy	14000.00
0005434351666	4466	Economy	14000.00
0005435893585	4466	Economy	14000.00
0005434351662	4466	Economy	14000.00
0005434351670	4466	Economy	14000.00
0005435893580	4466	Economy	14000.00
0005435893582	4466	Economy	14000.00
0005435893548	4466	Economy	14000.00
0005435893564	4466	Economy	14000.00
0005434351660	4466	Economy	14000.00
0005434351576	29643	Economy	15400.00
0005435893616	29643	Economy	15400.00
0005434351552	29643	Economy	14000.00
0005434351521	29643	Economy	14000.00
0005434351587	29643	Economy	14000.00
0005434351588	29643	Economy	14000.00
0005434351503	29643	Economy	14000.00
0005434351570	29643	Economy	14000.00
0005434351520	29643	Economy	14000.00
0005435893618	29643	Economy	14000.00
0005434351540	29643	Economy	14000.00
0005434351562	29643	Economy	14000.00
0005434351551	29643	Economy	14000.00
0005434351565	29643	Economy	14000.00
0005435893615	29643	Economy	14000.00
0005434351586	29643	Economy	14000.00
0005435893613	29643	Economy	14000.00
0005434351525	29643	Economy	14000.00
0005435893617	29643	Economy	14000.00
0005434351563	29643	Economy	14000.00
0005435893614	29643	Economy	14000.00
0005434351518	29643	Economy	14000.00
0005433341892	1089	Business	30600.00
0005433341832	1089	Business	30600.00
0005433342248	1089	Business	30600.00
0005433341957	1089	Business	30600.00
0005433341891	1089	Business	30600.00
0005433342066	1089	Business	30600.00
0005433342078	1089	Business	30600.00
0005433341860	1089	Business	30600.00
0005435092054	1089	Business	30600.00
0005434446515	1089	Business	30600.00
0005433342048	1089	Business	30600.00
0005433341982	1089	Business	30600.00
0005433342035	1089	Business	30600.00
0005434445243	1089	Business	30600.00
0005433341904	1089	Business	30600.00
0005435092055	1089	Business	30600.00
0005433341863	1089	Business	30600.00
0005433342159	1089	Business	30600.00
0005433341518	1089	Business	30600.00
0005433342020	1089	Economy	11200.00
0005433159285	1089	Economy	10200.00
0005433341915	1089	Economy	10200.00
0005433342034	1089	Economy	10200.00
0005433341858	1089	Economy	10200.00
0005433341460	1089	Economy	10200.00
0005433341905	1089	Economy	10200.00
0005433342065	1089	Economy	10200.00
0005433341627	1089	Economy	10200.00
0005433341994	1089	Economy	10200.00
0005433462742	1089	Economy	10200.00
0005433341866	1089	Economy	10200.00
0005435092051	1089	Economy	10200.00
0005433342236	1089	Economy	10200.00
0005433342032	1089	Economy	10200.00
0005433341828	1089	Economy	10200.00
0005433342271	1089	Economy	10200.00
0005433342061	1089	Economy	10200.00
0005433341869	1089	Economy	10200.00
0005433341963	1089	Economy	10200.00
0005433342087	1089	Economy	10200.00
0005433341996	1089	Economy	10200.00
0005433342042	1089	Economy	10200.00
0005433341850	1089	Economy	10200.00
0005433341796	1089	Economy	10200.00
0005433342384	1089	Economy	10200.00
0005433341774	1089	Economy	10200.00
0005433342141	1089	Economy	10200.00
0005433341895	1089	Economy	10200.00
0005433341990	1089	Economy	10200.00
0005433341833	1089	Economy	10200.00
0005433341749	1089	Economy	10200.00
0005435092053	1089	Economy	10200.00
0005433342028	1089	Economy	10200.00
0005433341880	1089	Economy	10200.00
0005433341859	1089	Economy	10200.00
0005433342214	1089	Economy	10200.00
0005433342100	1089	Economy	10200.00
0005433342280	1089	Economy	10200.00
0005433342185	1089	Economy	10200.00
0005433341975	1089	Economy	10200.00
0005433341993	1089	Economy	10200.00
0005433341997	1089	Economy	10200.00
0005433341964	1089	Economy	10200.00
0005433269670	1089	Economy	10200.00
0005433341943	1089	Economy	10200.00
0005435092050	1089	Economy	10200.00
0005433342195	1089	Economy	10200.00
0005433341961	1089	Economy	10200.00
0005433341628	1089	Economy	10200.00
0005433269669	1089	Economy	10200.00
0005433342249	1089	Economy	10200.00
0005433341991	1089	Economy	10200.00
0005433159283	1089	Economy	10200.00
0005433159284	1089	Economy	10200.00
0005433342025	1089	Economy	10200.00
0005433342129	1089	Economy	10200.00
0005433463896	1089	Economy	10200.00
0005432293203	1089	Economy	10200.00
0005433463895	1089	Economy	10200.00
0005433341897	1089	Economy	10200.00
0005433342115	1089	Economy	10200.00
0005433341814	1089	Economy	10200.00
0005433341773	1089	Economy	10200.00
0005433342033	1089	Economy	10200.00
0005433341629	1089	Economy	10200.00
0005433341721	1089	Economy	10200.00
0005433341827	1089	Economy	10200.00
0005433342353	1089	Economy	10200.00
0005433341558	1089	Economy	10200.00
0005433342067	1089	Economy	11200.00
0005433342130	1089	Economy	10200.00
0005433342052	1089	Economy	10200.00
0005433342245	1089	Economy	10200.00
0005433342131	1089	Economy	10200.00
0005433341929	1089	Economy	10200.00
0005433341896	1089	Economy	10200.00
0005433341792	1089	Economy	10200.00
0005433341756	1089	Economy	10200.00
0005433341959	1089	Economy	10200.00
0005434446514	1089	Economy	10200.00
0005433341962	1089	Economy	10200.00
0005433342334	1089	Economy	10200.00
0005433341989	1089	Economy	10200.00
0005432293202	1089	Economy	10200.00
0005435092046	1089	Economy	10200.00
0005433342150	1089	Economy	10200.00
0005432293204	1089	Economy	10200.00
0005433341877	1089	Economy	10200.00
0005434446516	1089	Economy	10200.00
0005433341967	1089	Economy	10200.00
0005433341401	1089	Economy	10200.00
0005435092047	1089	Economy	10200.00
0005433342060	1089	Economy	10200.00
0005433269666	1089	Economy	10200.00
0005433341776	1089	Economy	10200.00
0005433342041	1089	Economy	10200.00
0005435092052	1089	Economy	10200.00
0005433342244	1089	Economy	10200.00
0005433341787	1089	Economy	10200.00
0005435092048	1089	Economy	10200.00
0005433341977	1089	Economy	10200.00
0005435092049	1089	Economy	10200.00
0005434446517	1089	Economy	10200.00
0005433342086	1089	Economy	10200.00
0005433341976	1089	Economy	10200.00
0005433341968	1089	Economy	10200.00
0005433342040	1089	Economy	10200.00
0005433342049	1089	Economy	10200.00
0005433341901	1089	Economy	10200.00
0005433341876	1089	Economy	10200.00
0005433341890	1089	Economy	10200.00
0005433341791	1089	Economy	10200.00
0005433342073	1089	Economy	10200.00
0005433342499	1089	Economy	10200.00
0005433341643	1089	Economy	10200.00
0005433341851	1089	Economy	10200.00
0005433342199	1089	Economy	10200.00
0005433342110	1089	Economy	10200.00
0005433341811	1089	Economy	10200.00
0005433341793	1089	Economy	10200.00
0005433342383	1089	Economy	10200.00
0005433341958	1089	Economy	10200.00
0005433342857	17044	Business	30600.00
0005435091958	17044	Business	30600.00
0005433342899	17044	Business	30600.00
0005435091980	17044	Business	30600.00
0005433342813	17044	Business	30600.00
0005433342861	17044	Business	30600.00
0005433342887	17044	Business	30600.00
0005433342808	17044	Business	30600.00
0005435091904	17044	Business	30600.00
0005433342886	17044	Business	30600.00
0005433342852	17044	Business	30600.00
0005433342907	17044	Business	30600.00
0005433342832	17044	Business	30600.00
0005433342896	17044	Business	30600.00
0005433342833	17044	Business	30600.00
0005433342878	17044	Economy	11200.00
0005433342831	17044	Economy	11200.00
0005433342884	17044	Economy	10200.00
0005433269703	17044	Economy	10200.00
0005433342894	17044	Economy	10200.00
0005435508211	17044	Economy	10200.00
0005433342817	17044	Economy	10200.00
0005433342876	17044	Economy	10200.00
0005433342836	17044	Economy	10200.00
0005433342898	17044	Economy	10200.00
0005433269704	17044	Economy	10200.00
0005433342890	17044	Economy	10200.00
0005433342824	17044	Economy	10200.00
0005433342901	17044	Economy	10200.00
0005433342826	17044	Economy	10200.00
0005433342868	17044	Economy	10200.00
0005433342851	17044	Economy	10200.00
0005433342897	17044	Economy	10200.00
0005433342850	17044	Economy	10200.00
0005433342875	17044	Economy	10200.00
0005433269705	17044	Economy	10200.00
0005433342838	17044	Economy	10200.00
0005433342825	17044	Economy	10200.00
0005435508219	17044	Economy	10200.00
0005433342860	17044	Economy	10200.00
0005433269708	17044	Economy	10200.00
0005433342880	17044	Economy	10200.00
0005433342820	17044	Economy	10200.00
0005433159306	17044	Economy	10200.00
0005433342835	17044	Economy	10200.00
0005433342828	17044	Economy	10200.00
0005435091957	17044	Economy	10200.00
0005433342854	17044	Economy	10200.00
0005435091985	17044	Economy	10200.00
0005433342811	17044	Economy	10200.00
0005433342882	17044	Economy	10200.00
0005433342842	17044	Economy	10200.00
0005433342902	17044	Economy	10200.00
0005433269707	17044	Economy	10200.00
0005433342862	17044	Economy	10200.00
0005435091931	17044	Economy	10200.00
0005435508222	17044	Economy	10200.00
0005435091984	17044	Economy	10200.00
0005433342863	17044	Economy	10200.00
0005433342904	17044	Economy	10200.00
0005433342885	17044	Economy	10200.00
0005433342849	17044	Economy	10200.00
0005435091966	17044	Economy	10200.00
0005433342809	17044	Economy	10200.00
0005433342874	17044	Economy	10200.00
0005433342879	17044	Economy	10200.00
0005433342853	17044	Economy	10200.00
0005433342867	17044	Economy	10200.00
0005433269706	17044	Economy	10200.00
0005433342858	17044	Economy	10200.00
0005435508223	17044	Economy	10200.00
0005433342892	17044	Economy	10200.00
0005433342843	17044	Economy	10200.00
0005433342805	17044	Economy	10200.00
0005433342827	17044	Economy	10200.00
0005433342893	17044	Economy	10200.00
0005435508224	17044	Economy	10200.00
0005433342871	17044	Economy	10200.00
0005433342845	17044	Economy	10200.00
0005433342869	17044	Economy	10200.00
0005433342877	17044	Economy	10200.00
0005433342903	17044	Economy	10200.00
0005433159307	17044	Economy	11200.00
0005433342818	17044	Economy	10200.00
0005435091934	17044	Economy	10200.00
0005433342906	17044	Economy	10200.00
0005433342848	17044	Economy	11200.00
0005433342866	17044	Economy	11200.00
0005435091965	17044	Economy	10200.00
0005433342823	17044	Economy	10200.00
0005433342900	17044	Economy	10200.00
0005433342891	17044	Economy	10200.00
0005433342822	17044	Economy	10200.00
0005433342883	17044	Economy	10200.00
0005433342895	17044	Economy	10200.00
0005435091983	17044	Economy	10200.00
0005435091978	17044	Economy	10200.00
0005433342847	17044	Economy	10200.00
0005433342834	17044	Economy	10200.00
0005433342816	17044	Economy	10200.00
0005435508216	17044	Economy	10200.00
0005433342814	17044	Economy	10200.00
0005433342905	17044	Economy	10200.00
0005433342837	17044	Economy	10200.00
0005433342810	17044	Economy	10200.00
0005433342839	17044	Economy	10200.00
0005435091967	17044	Economy	10200.00
0005433342855	17044	Economy	10200.00
0005433342873	17044	Economy	10200.00
0005433342840	17044	Economy	10200.00
0005433342844	17044	Economy	10200.00
0005433342856	17044	Economy	10200.00
0005433342870	17044	Economy	10200.00
0005433342806	17044	Economy	10200.00
0005433342872	17044	Economy	10200.00
0005433342865	17044	Economy	10200.00
0005433342859	17044	Economy	10200.00
0005433342881	17044	Economy	10200.00
0005433342821	17044	Economy	10200.00
0005433342812	17044	Economy	10200.00
0005433342846	17044	Economy	10200.00
0005435508191	17044	Economy	10200.00
0005433342819	17044	Economy	10200.00
0005433342841	17044	Economy	10200.00
0005435091930	17044	Economy	10200.00
0005435091979	17044	Economy	10200.00
0005435091959	17044	Economy	10200.00
0005435091955	17044	Economy	10200.00
0005433342830	17044	Economy	10200.00
0005434445215	17044	Economy	10200.00
0005435508221	17044	Economy	10200.00
0005433342815	17044	Economy	10200.00
0005433342864	17044	Economy	10200.00
0005433342829	17044	Economy	10200.00
0005433342888	17044	Economy	10200.00
0005435091991	17044	Economy	10200.00
0005433342807	17044	Economy	10200.00
0005433342889	17044	Economy	10200.00
0005432433667	12813	Business	40300.00
0005434066928	12813	Business	40300.00
0005433812895	12813	Business	40300.00
0005434066521	12813	Business	40300.00
0005434081633	12813	Business	40300.00
0005434081691	12813	Business	40300.00
0005434066710	12813	Business	40300.00
0005434081662	12813	Business	40300.00
0005434066807	12813	Business	40300.00
0005434081568	12813	Business	40300.00
0005434081651	12813	Economy	13400.00
0005434066858	12813	Economy	13400.00
0005434066456	12813	Economy	13400.00
0005432159850	12813	Economy	13400.00
0005434066841	12813	Economy	13400.00
0005434081496	12813	Economy	13400.00
0005434066764	12813	Economy	13400.00
0005434066643	12813	Economy	13400.00
0005434081634	12813	Economy	13400.00
0005434081614	12813	Economy	13400.00
0005434066924	12813	Economy	13400.00
0005434066588	12813	Economy	13400.00
0005432433666	12813	Economy	13400.00
0005435283408	12813	Economy	13400.00
0005434081567	12813	Economy	13400.00
0005432159847	12813	Economy	13400.00
0005434066944	12813	Economy	13400.00
0005434066626	12813	Economy	13400.00
0005434081599	12813	Economy	13400.00
0005434066959	12813	Economy	13400.00
0005434066560	12813	Economy	13400.00
0005434081720	12813	Economy	13400.00
0005434066613	12813	Economy	13400.00
0005434066759	12813	Economy	13400.00
0005434081663	12813	Economy	13400.00
0005434066457	12813	Economy	13400.00
0005434066666	12813	Economy	13400.00
0005434066765	12813	Economy	13400.00
0005434066921	12813	Economy	13400.00
0005432161148	12813	Economy	13400.00
0005434066463	12813	Economy	13400.00
0005434066511	12813	Economy	13400.00
0005434066840	12813	Economy	13400.00
0005434081612	12813	Economy	13400.00
0005434081613	12813	Economy	13400.00
0005434066618	12813	Economy	13400.00
0005434066591	12813	Economy	13400.00
0005434066523	12813	Economy	14800.00
0005434081747	12813	Economy	14800.00
0005434081620	12813	Economy	14800.00
0005434066540	12813	Economy	13400.00
0005434066975	12813	Economy	14800.00
0005434081562	12813	Economy	13400.00
0005432161147	12813	Economy	13400.00
0005434066589	12813	Economy	13400.00
0005434066918	12813	Economy	13400.00
0005434067086	12813	Economy	13400.00
0005434066555	12813	Economy	13400.00
0005434066942	12813	Economy	13400.00
0005434081566	12813	Economy	13400.00
0005434066649	12813	Economy	13400.00
0005434066754	12813	Economy	13400.00
0005434026681	12813	Economy	13400.00
0005434066943	12813	Economy	13400.00
0005432433669	12813	Economy	13400.00
0005434066407	12813	Economy	13400.00
0005434081563	12813	Economy	13400.00
0005434066500	12813	Economy	13400.00
0005434081646	12813	Economy	13400.00
0005434066685	12813	Economy	13400.00
0005434066982	12813	Economy	13400.00
0005434066406	12813	Economy	13400.00
0005434066995	12813	Economy	13400.00
0005432159845	12813	Economy	13400.00
0005434081647	12813	Economy	13400.00
0005434026672	12813	Economy	13400.00
0005434066727	12813	Economy	13400.00
0005434066763	12813	Economy	13400.00
0005434066884	12813	Economy	13400.00
0005432161146	12813	Economy	13400.00
0005434066673	12813	Economy	13400.00
0005434066726	12813	Economy	13400.00
0005434066672	12813	Economy	13400.00
0005434066522	12813	Economy	13400.00
0005434066851	12813	Economy	13400.00
0005434081661	12813	Economy	13400.00
0005434066644	12813	Economy	13400.00
0005434081621	12813	Economy	13400.00
0005434066834	12813	Economy	13400.00
0005434066578	12813	Economy	13400.00
0005432159849	12813	Economy	13400.00
0005434066719	12813	Economy	13400.00
0005434066661	12813	Economy	13400.00
0005434081746	12813	Economy	13400.00
0005434081721	12813	Economy	13400.00
0005434026682	12813	Economy	13400.00
0005434066755	12813	Economy	13400.00
0005434081650	12813	Economy	13400.00
0005432159846	12813	Economy	13400.00
0005434066606	12813	Economy	13400.00
0005434066874	12813	Economy	13400.00
0005432159848	12813	Economy	13400.00
0005434067015	12813	Economy	13400.00
0005434066724	12813	Economy	13400.00
0005432433668	12813	Economy	13400.00
0005434066655	12813	Economy	13400.00
0005433812894	12813	Economy	13400.00
0005434066561	12813	Economy	13400.00
0005434066723	12813	Economy	13400.00
0005434066667	12813	Economy	13400.00
0005434081641	12813	Economy	13400.00
0005434066833	12813	Economy	13400.00
0005434066590	12813	Economy	13400.00
0005434066479	12813	Economy	13400.00
0005434066875	12813	Economy	13400.00
0005434066835	12813	Economy	13400.00
0005434066604	12813	Economy	13400.00
0005434081822	30681	Business	40300.00
0005433989755	30681	Business	40300.00
0005434067352	30681	Business	40300.00
0005434067340	30681	Business	40300.00
0005434067327	30681	Business	40300.00
0005434067350	30681	Business	40300.00
0005433989758	30681	Business	40300.00
0005433989757	30681	Business	40300.00
0005432433625	30681	Business	40300.00
0005434067376	30681	Business	40300.00
0005432186858	30681	Business	40300.00
0005434026700	30681	Business	40300.00
0005434081825	30681	Economy	13400.00
0005434067364	30681	Economy	13400.00
0005434067315	30681	Economy	13400.00
0005434067332	30681	Economy	13400.00
0005434081829	30681	Economy	13400.00
0005434026699	30681	Economy	13400.00
0005434067359	30681	Economy	13400.00
0005434067345	30681	Economy	13400.00
0005434067366	30681	Economy	13400.00
0005432433630	30681	Economy	13400.00
0005433812868	30681	Economy	13400.00
0005434026697	30681	Economy	13400.00
0005434067372	30681	Economy	13400.00
0005433989756	30681	Economy	13400.00
0005434067357	30681	Economy	13400.00
0005434067343	30681	Economy	13400.00
0005434067346	30681	Economy	13400.00
0005434067311	30681	Economy	13400.00
0005432186859	30681	Economy	13400.00
0005434067333	30681	Economy	13400.00
0005433812870	30681	Economy	13400.00
0005434067368	30681	Economy	13400.00
0005434081833	30681	Economy	13400.00
0005432150167	30681	Economy	13400.00
0005432433638	30681	Economy	13400.00
0005434081820	30681	Economy	13400.00
0005434067377	30681	Economy	13400.00
0005432186857	30681	Economy	13400.00
0005434067378	30681	Economy	13400.00
0005434067318	30681	Economy	13400.00
0005434067341	30681	Economy	13400.00
0005434067328	30681	Economy	13400.00
0005434067374	30681	Economy	13400.00
0005434081824	30681	Economy	13400.00
0005434067382	30681	Economy	13400.00
0005434026695	30681	Economy	13400.00
0005434067363	30681	Economy	13400.00
0005432150173	30681	Economy	13400.00
0005433812866	30681	Economy	14800.00
0005434067317	30681	Economy	14800.00
0005434067381	30681	Economy	14800.00
0005434067365	30681	Economy	14800.00
0005433812869	30681	Economy	14800.00
0005434067337	30681	Economy	14800.00
0005432433620	30681	Economy	13400.00
0005432150171	30681	Economy	13400.00
0005434026698	30681	Economy	13400.00
0005434067361	30681	Economy	13400.00
0005434067344	30681	Economy	13400.00
0005434067313	30681	Economy	13400.00
0005434067316	30681	Economy	13400.00
0005434067314	30681	Economy	13400.00
0005432150166	30681	Economy	13400.00
0005434081827	30681	Economy	13400.00
0005434067324	30681	Economy	13400.00
0005434067347	30681	Economy	13400.00
0005434081836	30681	Economy	13400.00
0005434067334	30681	Economy	13400.00
0005434067349	30681	Economy	13400.00
0005434067380	30681	Economy	13400.00
0005434067373	30681	Economy	13400.00
0005434067331	30681	Economy	13400.00
0005433812863	30681	Economy	13400.00
0005434067369	30681	Economy	13400.00
0005434067358	30681	Economy	13400.00
0005434067330	30681	Economy	13400.00
0005434081828	30681	Economy	13400.00
0005434067342	30681	Economy	13400.00
0005433812862	30681	Economy	13400.00
0005432186856	30681	Economy	13400.00
0005434067353	30681	Economy	13400.00
0005432150172	30681	Economy	13400.00
0005434067383	30681	Economy	13400.00
0005434067351	30681	Economy	13400.00
0005434067335	30681	Economy	13400.00
0005434067367	30681	Economy	13400.00
0005434081830	30681	Economy	13400.00
0005434067339	30681	Economy	13400.00
0005434081821	30681	Economy	13400.00
0005433812871	30681	Economy	13400.00
0005434067326	30681	Economy	13400.00
0005434081823	30681	Economy	13400.00
0005434067370	30681	Economy	13400.00
0005434067321	30681	Economy	13400.00
0005434067338	30681	Economy	13400.00
0005434067336	30681	Economy	13400.00
0005434081832	30681	Economy	13400.00
0005434067323	30681	Economy	13400.00
0005434026696	30681	Economy	13400.00
0005434081826	30681	Economy	13400.00
0005434067356	30681	Economy	13400.00
0005434067348	30681	Economy	13400.00
0005434081834	30681	Economy	13400.00
0005434081819	30681	Economy	13400.00
0005432150168	30681	Economy	13400.00
0005434067312	30681	Economy	13400.00
0005434067320	30681	Economy	13400.00
0005434067362	30681	Economy	13400.00
0005434067355	30681	Economy	13400.00
0005432433634	30681	Economy	13400.00
0005434067360	30681	Economy	13400.00
0005434067322	30681	Economy	13400.00
0005434081831	30681	Economy	13400.00
0005432150170	30681	Economy	13400.00
0005434067325	30681	Economy	13400.00
0005434067319	30681	Economy	13400.00
0005434067375	30681	Economy	13400.00
0005434067379	30681	Economy	13400.00
0005432433637	30681	Economy	13400.00
0005434067329	30681	Economy	13400.00
0005434067371	30681	Economy	13400.00
0005432150174	30681	Economy	13400.00
0005434081835	30681	Economy	13400.00
0005434067354	30681	Economy	13400.00
0005432150169	30681	Economy	13400.00
0005435735126	5514	Business	35300.00
0005435461940	5514	Business	35300.00
0005432140431	5514	Business	35300.00
0005435462079	5514	Business	35300.00
0005435766094	5514	Business	35300.00
0005435766075	5514	Business	35300.00
0005435462090	5514	Business	35300.00
0005434831082	5514	Business	35300.00
0005435725585	5514	Business	35300.00
0005434264800	5514	Business	35300.00
0005435720820	5514	Business	35300.00
0005434831083	5514	Business	35300.00
0005435725586	5514	Business	35300.00
0005434831090	5514	Business	35300.00
0005432140430	5514	Business	35300.00
0005435766077	5514	Business	35300.00
0005435766105	5514	Business	35300.00
0005435766102	5514	Business	35300.00
0005435723040	5514	Business	35300.00
0005435766128	5514	Business	35300.00
0005435462012	5514	Business	35300.00
0005435461980	5514	Business	35300.00
0005435462075	5514	Business	35300.00
0005435462119	5514	Business	35300.00
0005432535759	5514	Economy	12900.00
0005435735125	5514	Economy	12900.00
0005432140432	5514	Economy	12900.00
0005434264874	5514	Economy	11800.00
0005435462092	5514	Economy	11800.00
0005435766090	5514	Economy	11800.00
0005435461987	5514	Economy	11800.00
0005435462085	5514	Economy	11800.00
0005435766109	5514	Economy	11800.00
0005435766073	5514	Economy	11800.00
0005435461986	5514	Economy	11800.00
0005435766134	5514	Economy	11800.00
0005432140425	5514	Economy	11800.00
0005435766088	5514	Economy	11800.00
0005435766138	5514	Economy	11800.00
0005435462175	5514	Economy	11800.00
0005435766086	5514	Economy	11800.00
0005435461982	5514	Economy	11800.00
0005434831099	5514	Economy	11800.00
0005435766112	5514	Economy	11800.00
0005435462047	5514	Economy	11800.00
0005435766087	5514	Economy	11800.00
0005435766121	5514	Economy	11800.00
0005434264885	5514	Economy	11800.00
0005435766091	5514	Economy	11800.00
0005435461862	5514	Economy	11800.00
0005433529270	5514	Economy	11800.00
0005435766113	5514	Economy	11800.00
0005435766116	5514	Economy	11800.00
0005434264747	5514	Economy	11800.00
0005434264889	5514	Economy	11800.00
0005435725587	5514	Economy	11800.00
0005435462118	5514	Economy	11800.00
0005435725588	5514	Economy	11800.00
0005435766107	5514	Economy	11800.00
0005435461928	5514	Economy	11800.00
0005434264763	5514	Economy	11800.00
0005435462051	5514	Economy	11800.00
0005435766103	5514	Economy	11800.00
0005435462018	5514	Economy	11800.00
0005435766130	5514	Economy	11800.00
0005435766118	5514	Economy	11800.00
0005432140426	5514	Economy	11800.00
0005435461981	5514	Economy	11800.00
0005435766076	5514	Economy	11800.00
0005435720821	5514	Economy	11800.00
0005435462164	5514	Economy	11800.00
0005435766133	5514	Economy	11800.00
0005435766119	5514	Economy	11800.00
0005434264790	5514	Economy	11800.00
0005435766093	5514	Economy	11800.00
0005435461848	5514	Economy	11800.00
0005435461999	5514	Economy	11800.00
0005435722049	5514	Economy	11800.00
0005433529271	5514	Economy	11800.00
0005435723039	5514	Economy	11800.00
0005434264886	5514	Economy	11800.00
0005432140427	5514	Economy	11800.00
0005434264883	5514	Economy	11800.00
0005435766089	5514	Economy	11800.00
0005435766124	5514	Economy	11800.00
0005435766083	5514	Economy	11800.00
0005435766120	5514	Economy	11800.00
0005435766100	5514	Economy	11800.00
0005434264832	5514	Economy	11800.00
0005435735127	5514	Economy	11800.00
0005435766123	5514	Economy	11800.00
0005435462136	5514	Economy	11800.00
0005435766099	5514	Economy	11800.00
0005435735128	5514	Economy	11800.00
0005435461855	5514	Economy	11800.00
0005432535778	5514	Economy	11800.00
0005435766096	5514	Economy	11800.00
0005435766135	5514	Economy	11800.00
0005435462091	5514	Economy	11800.00
0005433527260	5514	Economy	11800.00
0005434831098	5514	Economy	11800.00
0005435766114	5514	Economy	11800.00
0005435766084	5514	Economy	11800.00
0005435766122	5514	Economy	11800.00
0005435766136	5514	Economy	11800.00
0005434264820	5514	Economy	11800.00
0005435461950	5514	Economy	11800.00
0005435462135	5514	Economy	11800.00
0005435735130	5514	Economy	11800.00
0005435462080	5514	Economy	12900.00
0005435766127	5514	Economy	11800.00
0005435766080	5514	Economy	12900.00
0005435462095	5514	Economy	11800.00
0005435766137	5514	Economy	12900.00
0005435461985	5514	Economy	12900.00
0005435462011	5514	Economy	11800.00
0005435766131	5514	Economy	11800.00
0005435766126	5514	Economy	11800.00
0005435461967	5514	Economy	11800.00
0005435462174	5514	Economy	11800.00
0005434264799	5514	Economy	11800.00
0005435462069	5514	Economy	11800.00
0005435766106	5514	Economy	11800.00
0005435766125	5514	Economy	11800.00
0005435461949	5514	Economy	11800.00
0005434264855	5514	Economy	11800.00
0005435766095	5514	Economy	11800.00
0005434264844	5514	Economy	11800.00
0005432140429	5514	Economy	11800.00
0005434264823	5514	Economy	11800.00
0005435766097	5514	Economy	11800.00
0005435462052	5514	Economy	11800.00
0005435462062	5514	Economy	11800.00
0005435462063	5514	Economy	11800.00
0005435462289	5514	Economy	11800.00
0005435462010	5514	Economy	11800.00
0005435766081	5514	Economy	11800.00
0005432535788	5514	Economy	11800.00
0005435766078	5514	Economy	11800.00
0005435462046	5514	Economy	11800.00
0005432140428	5514	Economy	11800.00
0005434264854	5514	Economy	11800.00
0005435462048	5514	Economy	11800.00
0005434264899	5514	Economy	11800.00
0005435462070	5514	Economy	11800.00
0005435766111	5514	Economy	11800.00
0005435462076	5514	Economy	11800.00
0005435766110	5514	Economy	11800.00
0005435766132	5514	Economy	11800.00
0005435462057	5514	Economy	11800.00
0005434264869	5514	Economy	11800.00
0005435766101	5514	Economy	11800.00
0005435766079	5514	Economy	11800.00
0005435766085	5514	Economy	11800.00
0005435766098	5514	Economy	11800.00
0005435725583	5514	Economy	11800.00
0005434264824	5514	Economy	11800.00
0005435766092	5514	Economy	11800.00
0005435766082	5514	Economy	11800.00
0005435725589	5514	Economy	11800.00
0005435766074	5514	Economy	11800.00
0005435722050	5514	Economy	11800.00
0005435766108	5514	Economy	11800.00
0005434264826	5514	Economy	11800.00
0005435766117	5514	Economy	11800.00
0005435735129	5514	Economy	11800.00
0005434264868	5514	Economy	11800.00
0005435766115	5514	Economy	11800.00
0005435766129	5514	Economy	11800.00
0005435725584	5514	Economy	11800.00
0005434264907	5514	Economy	11800.00
0005433529269	5514	Economy	11800.00
0005435766104	5514	Economy	11800.00
0005435765639	13464	Business	35300.00
0005435462373	13464	Business	35300.00
0005432194499	13464	Business	35300.00
0005433533270	13464	Business	35300.00
0005434265096	13464	Business	35300.00
0005435735108	13464	Business	35300.00
0005435765643	13464	Business	35300.00
0005435765518	13464	Business	35300.00
0005434265088	13464	Business	35300.00
0005435765615	13464	Business	35300.00
0005435765409	13464	Business	35300.00
0005432194503	13464	Business	35300.00
0005435765391	13464	Business	35300.00
0005434265080	13464	Business	35300.00
0005435765521	13464	Business	35300.00
0005434265089	13464	Business	35300.00
0005432194501	13464	Business	35300.00
0005435462344	13464	Business	35300.00
0005435462338	13464	Business	35300.00
0005435765561	13464	Business	35300.00
0005432535824	13464	Business	35300.00
0005435765467	13464	Business	35300.00
0005432535822	13464	Business	35300.00
0005433529244	13464	Business	35300.00
0005435462360	13464	Economy	12900.00
0005435765566	13464	Economy	12900.00
0005434265092	13464	Economy	11800.00
0005433533247	13464	Economy	11800.00
0005434265078	13464	Economy	11800.00
0005434265087	13464	Economy	11800.00
0005434265073	13464	Economy	11800.00
0005435462336	13464	Economy	11800.00
0005435462351	13464	Economy	11800.00
0005433533262	13464	Economy	11800.00
0005433533249	13464	Economy	11800.00
0005433533250	13464	Economy	11800.00
0005435462364	13464	Economy	11800.00
0005432194504	13464	Economy	11800.00
0005433529213	13464	Economy	11800.00
0005433533252	13464	Economy	11800.00
0005434265082	13464	Economy	11800.00
0005435722025	13464	Economy	11800.00
0005435462368	13464	Economy	11800.00
0005434265079	13464	Economy	11800.00
0005435462361	13464	Economy	11800.00
0005435765659	13464	Economy	11800.00
0005435765661	13464	Economy	11800.00
0005435462352	13464	Economy	11800.00
0005435765449	13464	Economy	11800.00
0005432535826	13464	Economy	11800.00
0005435735109	13464	Economy	11800.00
0005435765364	13464	Economy	11800.00
0005433533260	13464	Economy	11800.00
0005435722024	13464	Economy	11800.00
0005434265085	13464	Economy	11800.00
0005435462337	13464	Economy	11800.00
0005433529211	13464	Economy	11800.00
0005433529217	13464	Economy	11800.00
0005435462370	13464	Economy	11800.00
0005435735077	13464	Economy	11800.00
0005435462355	13464	Economy	11800.00
0005432194502	13464	Economy	11800.00
0005435765657	13464	Economy	11800.00
0005435765645	13464	Economy	11800.00
0005435462359	13464	Economy	11800.00
0005434831142	13464	Economy	11800.00
0005433533248	13464	Economy	11800.00
0005433529226	13464	Economy	11800.00
0005435765644	13464	Economy	11800.00
0005434265093	13464	Economy	11800.00
0005433533251	13464	Economy	11800.00
0005435765573	13464	Economy	11800.00
0005435462345	13464	Economy	11800.00
0005435765470	13464	Economy	11800.00
0005434831143	13464	Economy	11800.00
0005434265083	13464	Economy	11800.00
0005435765410	13464	Economy	11800.00
0005433533274	13464	Economy	11800.00
0005433533275	13464	Economy	11800.00
0005433529221	13464	Economy	11800.00
0005432535823	13464	Economy	11800.00
0005435462372	13464	Economy	11800.00
0005435462366	13464	Economy	11800.00
0005435462341	13464	Economy	11800.00
0005435765520	13464	Economy	11800.00
0005435462339	13464	Economy	11800.00
0005435765638	13464	Economy	11800.00
0005435462349	13464	Economy	11800.00
0005435765319	13464	Economy	11800.00
0005435765515	13464	Economy	11800.00
0005434265075	13464	Economy	11800.00
0005435765519	13464	Economy	11800.00
0005435765348	13464	Economy	11800.00
0005434265084	13464	Economy	11800.00
0005435462348	13464	Economy	11800.00
0005435765601	13464	Economy	11800.00
0005435462353	13464	Economy	11800.00
0005435462354	13464	Economy	11800.00
0005435462371	13464	Economy	11800.00
0005434265077	13464	Economy	11800.00
0005435765516	13464	Economy	11800.00
0005435765595	13464	Economy	11800.00
0005435462346	13464	Economy	11800.00
0005435765567	13464	Economy	11800.00
0005435765320	13464	Economy	11800.00
0005435765422	13464	Economy	11800.00
0005435765616	13464	Economy	12900.00
0005435765423	13464	Economy	11800.00
0005433529212	13464	Economy	12900.00
0005434265074	13464	Economy	11800.00
0005435462374	13464	Economy	11800.00
0005433529220	13464	Economy	11800.00
0005435462365	13464	Economy	11800.00
0005435462350	13464	Economy	11800.00
0005434265086	13464	Economy	11800.00
0005435765572	13464	Economy	11800.00
0005434265091	13464	Economy	11800.00
0005435765444	13464	Economy	11800.00
0005434265081	13464	Economy	11800.00
0005435765562	13464	Economy	11800.00
0005434265076	13464	Economy	11800.00
0005435765483	13464	Economy	11800.00
0005433533253	13464	Economy	11800.00
0005433533261	13464	Economy	11800.00
0005433529222	13464	Economy	11800.00
0005434831139	13464	Economy	11800.00
0005434265090	13464	Economy	11800.00
0005435765560	13464	Economy	11800.00
0005435462357	13464	Economy	11800.00
0005435765660	13464	Economy	11800.00
0005434265094	13464	Economy	11800.00
0005435765514	13464	Economy	11800.00
0005435462369	13464	Economy	11800.00
0005435765482	13464	Economy	11800.00
0005433529227	13464	Economy	11800.00
0005435765596	13464	Economy	11800.00
0005433529214	13464	Economy	11800.00
0005435765617	13464	Economy	11800.00
0005435765443	13464	Economy	11800.00
0005435462367	13464	Economy	11800.00
0005435462358	13464	Economy	11800.00
0005434831140	13464	Economy	11800.00
0005434831141	13464	Economy	11800.00
0005435765466	13464	Economy	11800.00
0005435462363	13464	Economy	11800.00
0005432535825	13464	Economy	11800.00
0005433529219	13464	Economy	11800.00
0005435462340	13464	Economy	11800.00
0005433529218	13464	Economy	11800.00
0005435735074	13464	Economy	11800.00
0005435462347	13464	Economy	11800.00
0005432194500	13464	Economy	11800.00
0005435462356	13464	Economy	11800.00
0005435765232	13464	Economy	11800.00
0005435722029	13464	Economy	11800.00
0005433533254	13464	Economy	11800.00
0005434265098	13464	Economy	11800.00
0005435462343	13464	Economy	11800.00
0005434265097	13464	Economy	11800.00
0005434265095	13464	Economy	11800.00
0005435043285	13464	Economy	11800.00
0005435765213	13464	Economy	11800.00
0005435765397	13464	Economy	11800.00
0005435462362	13464	Economy	11800.00
0005435462342	13464	Economy	11800.00
0005435722012	13464	Economy	11800.00
0005434602871	18675	Economy	3300.00
0005434602870	18675	Economy	3300.00
0005434514960	18676	Economy	3300.00
0005434604843	18676	Economy	3300.00
0005434513571	18676	Economy	3300.00
0005434604859	18676	Economy	3300.00
0005434514961	18676	Economy	3300.00
0005434513573	18676	Economy	3300.00
0005434513572	18676	Economy	3300.00
0005434514959	18676	Economy	3300.00
0005434604849	18676	Economy	3300.00
0005434604850	18676	Economy	3300.00
0005434604844	18676	Economy	3300.00
0005434604863	18676	Economy	3300.00
0005434514939	19117	Economy	3300.00
0005434514943	19117	Economy	3300.00
0005434514937	19117	Economy	3300.00
0005434514938	19117	Economy	3300.00
0005434514950	19117	Economy	3300.00
0005435846211	4114	Business	88300.00
0005432632731	4114	Business	88300.00
0005432649388	4114	Business	88300.00
0005435844282	4114	Business	88300.00
0005435846212	4114	Economy	29400.00
0005432649392	4114	Economy	29400.00
0005432632729	4114	Economy	32400.00
0005435844267	4114	Economy	32400.00
0005432649386	4114	Economy	29400.00
0005432649385	4114	Economy	29400.00
0005432632725	4114	Economy	29400.00
0005432632730	4114	Economy	29400.00
0005432649394	4114	Economy	29400.00
0005435846192	4114	Economy	29400.00
0005435844263	4114	Economy	29400.00
0005432649389	4114	Economy	29400.00
0005432649391	4114	Economy	29400.00
0005432632724	4114	Economy	29400.00
0005435846202	4114	Economy	29400.00
0005435844273	4114	Economy	29400.00
0005432632732	4114	Economy	29400.00
0005432649387	4114	Economy	29400.00
0005435846221	4114	Economy	29400.00
0005432632722	4114	Economy	29400.00
0005432632721	4114	Economy	29400.00
0005432632720	4114	Economy	29400.00
0005435846219	4114	Economy	29400.00
0005435846210	4114	Economy	29400.00
0005432632728	4114	Economy	29400.00
0005432632723	4114	Economy	29400.00
0005432649384	4114	Economy	29400.00
0005432649383	4114	Economy	29400.00
0005432632727	4114	Economy	29400.00
0005435844272	4114	Economy	29400.00
0005435844268	4114	Economy	29400.00
0005432632726	4114	Economy	29400.00
0005432649390	4114	Economy	29400.00
0005432649393	4114	Economy	29400.00
0005433008061	1884	Business	48700.00
0005433285004	1884	Business	48700.00
0005433008125	1884	Business	48700.00
0005433008128	1884	Business	48700.00
0005433810537	1884	Business	48700.00
0005433284820	1884	Business	48700.00
0005433284994	1884	Business	48700.00
0005433284978	1884	Business	48700.00
0005433284906	1884	Business	48700.00
0005433285107	1884	Business	48700.00
0005433284957	1884	Economy	16200.00
0005433284931	1884	Economy	16200.00
0005432295873	1884	Economy	16200.00
0005433810536	1884	Economy	16200.00
0005433008235	1884	Economy	16200.00
0005433285069	1884	Economy	16200.00
0005433285034	1884	Economy	16200.00
0005433008274	1884	Economy	16200.00
0005433008185	1884	Economy	16200.00
0005433284995	1884	Economy	17900.00
0005433285109	1884	Economy	17900.00
0005433284879	1884	Economy	17900.00
0005433008060	1884	Economy	16200.00
0005432295874	1884	Economy	16200.00
0005433008039	1884	Economy	16200.00
0005433284907	1884	Economy	16200.00
0005433285051	1884	Economy	16200.00
0005433008258	1884	Economy	16200.00
0005433285005	1884	Economy	16200.00
0005433285118	1884	Economy	16200.00
0005433008209	1884	Economy	16200.00
0005433008108	1884	Economy	16200.00
0005433285050	1884	Economy	16200.00
0005433285021	1884	Economy	16200.00
0005433008225	1884	Economy	16200.00
0005433008169	1884	Economy	16200.00
0005433284996	1884	Economy	16200.00
0005433285027	1884	Economy	16200.00
0005433284963	1884	Economy	16200.00
0005433284902	1884	Economy	16200.00
0005433284976	1884	Economy	16200.00
0005433284929	1884	Economy	16200.00
0005433285059	1884	Economy	16200.00
0005433285006	1884	Economy	16200.00
0005433285108	1884	Economy	16200.00
0005433284977	1884	Economy	16200.00
0005433008240	1884	Economy	16200.00
0005433008229	1884	Economy	16200.00
0005433008230	1884	Economy	16200.00
0005433285002	1884	Economy	16200.00
0005433007962	1884	Economy	16200.00
0005433285009	1884	Economy	16200.00
0005433008228	1884	Economy	16200.00
0005433285161	1884	Economy	16200.00
0005433285162	1884	Economy	16200.00
0005433284986	1884	Economy	16200.00
0005433285022	1884	Economy	16200.00
0005433284916	1884	Economy	16200.00
0005433284899	1884	Economy	16200.00
0005433285073	1884	Economy	16200.00
0005433008259	1884	Economy	16200.00
0005433008182	1884	Economy	16200.00
0005433284893	1884	Economy	16200.00
0005433008170	1884	Economy	16200.00
0005433008359	1884	Economy	16200.00
0005433008025	1884	Economy	16200.00
0005433008126	1884	Economy	16200.00
0005433285001	1884	Economy	16200.00
0005433284962	1884	Economy	16200.00
0005433008168	1884	Economy	16200.00
0005433008226	1884	Economy	16200.00
0005433008227	1884	Economy	16200.00
0005433285017	1884	Economy	16200.00
0005433284838	1884	Economy	16200.00
0005433008110	1884	Economy	16200.00
0005433285137	1884	Economy	16200.00
0005433284932	1884	Economy	16200.00
0005433284979	1884	Economy	16200.00
0005433284886	1884	Economy	16200.00
0005433284942	1884	Economy	16200.00
0005433284964	1884	Economy	16200.00
0005433284918	1884	Economy	16200.00
0005433285013	1884	Economy	16200.00
0005433810535	1884	Economy	16200.00
0005433007961	1884	Economy	16200.00
0005433008505	22560	Business	48700.00
0005433285221	22560	Business	48700.00
0005433285211	22560	Business	48700.00
0005433008499	22560	Business	48700.00
0005433285219	22560	Business	48700.00
0005433008485	22560	Business	48700.00
0005433008501	22560	Business	48700.00
0005433008476	22560	Business	48700.00
0005433285217	22560	Business	48700.00
0005433008504	22560	Business	48700.00
0005433008516	22560	Economy	16200.00
0005433008473	22560	Economy	16200.00
0005433285203	22560	Economy	16200.00
0005433008509	22560	Economy	16200.00
0005433008513	22560	Economy	16200.00
0005433008483	22560	Economy	16200.00
0005433008510	22560	Economy	16200.00
0005433008475	22560	Economy	17900.00
0005433008492	22560	Economy	17900.00
0005433008493	22560	Economy	17900.00
0005433008479	22560	Economy	17900.00
0005433008500	22560	Economy	17900.00
0005433008490	22560	Economy	16200.00
0005433008502	22560	Economy	16200.00
0005433008497	22560	Economy	16200.00
0005433285226	22560	Economy	16200.00
0005433008482	22560	Economy	16200.00
0005433285227	22560	Economy	16200.00
0005433285216	22560	Economy	16200.00
0005433008494	22560	Economy	16200.00
0005433285199	22560	Economy	16200.00
0005433008474	22560	Economy	16200.00
0005433008498	22560	Economy	16200.00
0005433810491	22560	Economy	16200.00
0005433008491	22560	Economy	16200.00
0005433285207	22560	Economy	16200.00
0005433285214	22560	Economy	16200.00
0005433285212	22560	Economy	16200.00
0005433285231	22560	Economy	16200.00
0005433008486	22560	Economy	16200.00
0005433008507	22560	Economy	16200.00
0005433008488	22560	Economy	16200.00
0005433008481	22560	Economy	16200.00
0005433285205	22560	Economy	16200.00
0005433285228	22560	Economy	16200.00
0005433008489	22560	Economy	16200.00
0005433285210	22560	Economy	16200.00
0005433008512	22560	Economy	16200.00
0005433008517	22560	Economy	16200.00
0005433285230	22560	Economy	16200.00
0005433285215	22560	Economy	16200.00
0005433008478	22560	Economy	16200.00
0005433285223	22560	Economy	16200.00
0005433008487	22560	Economy	16200.00
0005433810492	22560	Economy	16200.00
0005433008503	22560	Economy	16200.00
0005433008514	22560	Economy	16200.00
0005433008495	22560	Economy	16200.00
0005433008484	22560	Economy	16200.00
0005433285200	22560	Economy	16200.00
0005433285209	22560	Economy	16200.00
0005433008477	22560	Economy	16200.00
0005433008472	22560	Economy	16200.00
0005433285202	22560	Economy	16200.00
0005433008515	22560	Economy	16200.00
0005433285218	22560	Economy	16200.00
0005433008511	22560	Economy	16200.00
0005433008506	22560	Economy	16200.00
0005433285229	22560	Economy	16200.00
0005433285220	22560	Economy	16200.00
0005433285201	22560	Economy	16200.00
0005433285206	22560	Economy	16200.00
0005433285222	22560	Economy	16200.00
0005433008480	22560	Economy	16200.00
0005433285208	22560	Economy	16200.00
0005433008496	22560	Economy	16200.00
0005433285225	22560	Economy	16200.00
0005433285204	22560	Economy	16200.00
0005433285213	22560	Economy	16200.00
0005433285224	22560	Economy	16200.00
0005433008508	22560	Economy	16200.00
0005433846602	5595	Business	99800.00
0005433846572	5595	Business	99800.00
0005433846580	5595	Business	99800.00
0005433846569	5595	Business	99800.00
0005433846614	5595	Business	99800.00
0005435282267	5595	Business	99800.00
0005433846599	5595	Business	99800.00
0005435282276	5595	Business	99800.00
0005433846613	5595	Business	99800.00
0005435282191	5595	Business	99800.00
0005433846608	5595	Business	99800.00
0005433846592	5595	Business	99800.00
0005435282210	5595	Business	99800.00
0005433846579	5595	Business	99800.00
0005435282266	5595	Business	99800.00
0005433846584	5595	Business	99800.00
0005433846586	5595	Business	99800.00
0005433846576	5595	Business	99800.00
0005433846604	5595	Economy	33300.00
0005433846574	5595	Economy	33300.00
0005433846566	5595	Economy	33300.00
0005433846596	5595	Economy	33300.00
0005433846588	5595	Economy	33300.00
0005432081493	5595	Economy	33300.00
0005433846607	5595	Economy	33300.00
0005433846587	5595	Economy	33300.00
0005433846570	5595	Economy	33300.00
0005433846575	5595	Economy	33300.00
0005435282264	5595	Economy	33300.00
0005433846598	5595	Economy	33300.00
0005433846565	5595	Economy	36600.00
0005435282356	5595	Economy	36600.00
0005434173460	5595	Economy	36600.00
0005435282250	5595	Economy	36600.00
0005433846561	5595	Economy	33300.00
0005433846595	5595	Economy	33300.00
0005434173466	5595	Economy	33300.00
0005433846573	5595	Economy	33300.00
0005435282182	5595	Economy	33300.00
0005435282249	5595	Economy	33300.00
0005433846606	5595	Economy	33300.00
0005433846615	5595	Economy	33300.00
0005433815370	5595	Economy	33300.00
0005432081496	5595	Economy	33300.00
0005434173461	5595	Economy	33300.00
0005433815372	5595	Economy	33300.00
0005433846611	5595	Economy	33300.00
0005433846578	5595	Economy	33300.00
0005433846593	5595	Economy	33300.00
0005435282183	5595	Economy	33300.00
0005435282234	5595	Economy	33300.00
0005432081494	5595	Economy	33300.00
0005433846617	5595	Economy	33300.00
0005433846564	5595	Economy	33300.00
0005435282223	5595	Economy	33300.00
0005433846594	5595	Economy	33300.00
0005433846605	5595	Economy	33300.00
0005433846585	5595	Economy	33300.00
0005433846571	5595	Economy	33300.00
0005435282263	5595	Economy	33300.00
0005433846567	5595	Economy	33300.00
0005433846618	5595	Economy	33300.00
0005433815373	5595	Economy	33300.00
0005435282190	5595	Economy	33300.00
0005433846563	5595	Economy	33300.00
0005433846616	5595	Economy	33300.00
0005435282354	5595	Economy	33300.00
0005432081495	5595	Economy	33300.00
0005435282151	5595	Economy	33300.00
0005435282148	5595	Economy	33300.00
0005433846560	5595	Economy	33300.00
0005433846590	5595	Economy	33300.00
0005435282209	5595	Economy	33300.00
0005434173474	5595	Economy	33300.00
0005435282212	5595	Economy	33300.00
0005433846577	5595	Economy	33300.00
0005435282222	5595	Economy	33300.00
0005433846583	5595	Economy	33300.00
0005435282224	5595	Economy	33300.00
0005435282386	5595	Economy	33300.00
0005432081498	5595	Economy	33300.00
0005435282244	5595	Economy	33300.00
0005433846603	5595	Economy	33300.00
0005433846562	5595	Economy	33300.00
0005435282219	5595	Economy	33300.00
0005433846581	5595	Economy	33300.00
0005435282220	5595	Economy	33300.00
0005433846568	5595	Economy	33300.00
0005435282194	5595	Economy	33300.00
0005433846582	5595	Economy	33300.00
0005435282120	5595	Economy	33300.00
0005435282243	5595	Economy	33300.00
0005433846597	5595	Economy	33300.00
0005433846601	5595	Economy	33300.00
0005432081497	5595	Economy	33300.00
0005433846610	5595	Economy	33300.00
0005435282179	5595	Economy	33300.00
0005433815371	5595	Economy	33300.00
0005433846609	5595	Economy	33300.00
0005433846600	5595	Economy	33300.00
0005433846589	5595	Economy	33300.00
0005433846612	5595	Economy	33300.00
0005433846591	5595	Economy	33300.00
0005434173465	5595	Economy	33300.00
0005435282195	5595	Economy	33300.00
0005435282355	5595	Economy	33300.00
0005435282221	5595	Economy	33300.00
0005433846102	13855	Business	99800.00
0005435282454	13855	Business	99800.00
0005433846164	13855	Business	99800.00
0005433845941	13855	Business	99800.00
0005435282469	13855	Business	99800.00
0005432003694	13855	Business	99800.00
0005433846060	13855	Business	99800.00
0005435282459	13855	Business	99800.00
0005434173512	13855	Business	99800.00
0005433845862	13855	Business	99800.00
0005433846133	13855	Business	99800.00
0005433846052	13855	Business	99800.00
0005435282464	13855	Business	99800.00
0005433846123	13855	Business	99800.00
0005433846153	13855	Business	99800.00
0005435282472	13855	Economy	33300.00
0005433846163	13855	Economy	33300.00
0005433846009	13855	Economy	33300.00
0005435282475	13855	Economy	33300.00
0005433846234	13855	Economy	33300.00
0005433845942	13855	Economy	33300.00
0005435282467	13855	Economy	33300.00
0005435282462	13855	Economy	33300.00
0005433846200	13855	Economy	33300.00
0005433846092	13855	Economy	33300.00
0005433845921	13855	Economy	36600.00
0005433846104	13855	Economy	36600.00
0005433815335	13855	Economy	36600.00
0005433846131	13855	Economy	36600.00
0005433846112	13855	Economy	33300.00
0005433815328	13855	Economy	33300.00
0005433846125	13855	Economy	33300.00
0005432003695	13855	Economy	33300.00
0005435282470	13855	Economy	33300.00
0005433846208	13855	Economy	33300.00
0005433846288	13855	Economy	33300.00
0005433845955	13855	Economy	33300.00
0005433846238	13855	Economy	33300.00
0005435282450	13855	Economy	33300.00
0005435282453	13855	Economy	33300.00
0005433846086	13855	Economy	33300.00
0005433846337	13855	Economy	33300.00
0005433846198	13855	Economy	33300.00
0005433846258	13855	Economy	33300.00
0005435282460	13855	Economy	33300.00
0005435282452	13855	Economy	33300.00
0005433815333	13855	Economy	33300.00
0005433846467	13855	Economy	33300.00
0005435282474	13855	Economy	33300.00
0005433845991	13855	Economy	33300.00
0005435282466	13855	Economy	33300.00
0005433846043	13855	Economy	33300.00
0005433846255	13855	Economy	33300.00
0005433845848	13855	Economy	33300.00
0005433846345	13855	Economy	33300.00
0005433815336	13855	Economy	33300.00
0005433846121	13855	Economy	33300.00
0005433845977	13855	Economy	33300.00
0005433845939	13855	Economy	33300.00
0005435282451	13855	Economy	33300.00
0005435282477	13855	Economy	33300.00
0005433846132	13855	Economy	33300.00
0005433845937	13855	Economy	33300.00
0005432003693	13855	Economy	33300.00
0005433846134	13855	Economy	33300.00
0005433846019	13855	Economy	33300.00
0005435282449	13855	Economy	33300.00
0005435282465	13855	Economy	33300.00
0005435282463	13855	Economy	33300.00
0005435282455	13855	Economy	33300.00
0005435282468	13855	Economy	33300.00
0005433846020	13855	Economy	33300.00
0005433846172	13855	Economy	33300.00
0005433845980	13855	Economy	33300.00
0005434173513	13855	Economy	33300.00
0005433846143	13855	Economy	33300.00
0005433845875	13855	Economy	33300.00
0005433846199	13855	Economy	33300.00
0005435282476	13855	Economy	33300.00
0005433846051	13855	Economy	33300.00
0005433815334	13855	Economy	33300.00
0005433846129	13855	Economy	33300.00
0005433846122	13855	Economy	33300.00
0005433845863	13855	Economy	33300.00
0005433845963	13855	Economy	33300.00
0005433846256	13855	Economy	33300.00
0005433846183	13855	Economy	33300.00
0005435282458	13855	Economy	33300.00
0005435282473	13855	Economy	33300.00
0005435282457	13855	Economy	33300.00
0005433846111	13855	Economy	33300.00
0005433846030	13855	Economy	33300.00
0005435282471	13855	Economy	33300.00
0005434173511	13855	Economy	33300.00
0005434173510	13855	Economy	33300.00
0005433846130	13855	Economy	33300.00
0005433815327	13855	Economy	33300.00
0005435282461	13855	Economy	33300.00
0005435282456	13855	Economy	33300.00
0005433846207	13855	Economy	33300.00
0005434620539	7856	Economy	16600.00
0005434620542	7856	Economy	16600.00
0005434620553	7856	Economy	16600.00
0005434620557	7856	Economy	15100.00
0005434620555	7856	Economy	15100.00
0005434620551	7856	Economy	15100.00
0005435332236	7856	Economy	15100.00
0005435332192	7856	Economy	15100.00
0005434620552	7856	Economy	15100.00
0005434620548	7856	Economy	15100.00
0005434620543	7856	Economy	15100.00
0005435332233	7856	Economy	15100.00
0005434620545	7856	Economy	15100.00
0005434620554	7856	Economy	15100.00
0005434620549	7856	Economy	15100.00
0005432112511	7856	Economy	15100.00
0005434620547	7856	Economy	15100.00
0005434620540	7856	Economy	15100.00
0005434620541	7856	Economy	15100.00
0005435332261	7856	Economy	15100.00
0005434620556	7856	Economy	15100.00
0005434620550	7856	Economy	15100.00
0005432112512	7856	Economy	15100.00
0005432112510	7856	Economy	15100.00
0005435332248	7856	Economy	15100.00
0005435332220	7856	Economy	15100.00
0005434620544	7856	Economy	15100.00
0005434620538	7856	Economy	15100.00
0005435332237	7856	Economy	15100.00
0005435332219	7856	Economy	15100.00
0005434620546	7856	Economy	15100.00
0005435332310	32982	Economy	16600.00
0005434620298	32982	Economy	15100.00
0005434620443	32982	Economy	15100.00
0005434620410	32982	Economy	15100.00
0005434620353	32982	Economy	15100.00
0005434620309	32982	Economy	15100.00
0005435332309	32982	Economy	15100.00
0005434620382	32982	Economy	15100.00
0005435332308	32982	Economy	15100.00
0005435332315	32982	Economy	15100.00
0005434620383	32982	Economy	15100.00
0005434620308	32982	Economy	15100.00
0005434620377	32982	Economy	15100.00
0005434620417	32982	Economy	15100.00
0005435332314	32982	Economy	15100.00
0005434620354	32982	Economy	15100.00
0005434620356	32982	Economy	15100.00
0005435332311	32982	Economy	15100.00
0005435332307	32982	Economy	15100.00
0005434620375	32982	Economy	15100.00
0005434620387	32982	Economy	15100.00
0005435332312	32982	Economy	15100.00
0005434620413	32982	Economy	15100.00
0005434620359	32982	Economy	15100.00
0005434620316	32982	Economy	15100.00
0005434620412	32982	Economy	15100.00
0005435332313	32982	Economy	15100.00
0005435785275	4262	Business	38000.00
0005434994001	4262	Business	38000.00
0005435785268	4262	Business	38000.00
0005435785273	4262	Business	38000.00
0005435785288	4262	Business	38000.00
0005435785284	4262	Business	38000.00
0005435785277	4262	Economy	12700.00
0005434993999	4262	Economy	12700.00
0005434993998	4262	Economy	12700.00
0005435785276	4262	Economy	12700.00
0005435785265	4262	Economy	12700.00
0005435785290	4262	Economy	12700.00
0005435785286	4262	Economy	12700.00
0005435785280	4262	Economy	12700.00
0005434994004	4262	Economy	13900.00
0005435785259	4262	Economy	13900.00
0005432190621	4262	Economy	13900.00
0005435918596	4262	Economy	12700.00
0005435785266	4262	Economy	12700.00
0005435785272	4262	Economy	12700.00
0005435785270	4262	Economy	12700.00
0005432190620	4262	Economy	12700.00
0005435785264	4262	Economy	12700.00
0005435785282	4262	Economy	12700.00
0005435918609	4262	Economy	12700.00
0005435918604	4262	Economy	12700.00
0005435785262	4262	Economy	12700.00
0005435918622	4262	Economy	12700.00
0005434994002	4262	Economy	12700.00
0005435785283	4262	Economy	12700.00
0005435785285	4262	Economy	12700.00
0005435785271	4262	Economy	12700.00
0005435785291	4262	Economy	12700.00
0005434994000	4262	Economy	12700.00
0005435785293	4262	Economy	12700.00
0005434993997	4262	Economy	12700.00
0005432190619	4262	Economy	12700.00
0005435785274	4262	Economy	12700.00
0005434994005	4262	Economy	12700.00
0005435785278	4262	Economy	12700.00
0005435785279	4262	Economy	12700.00
0005435785263	4262	Economy	12700.00
0005435785269	4262	Economy	12700.00
0005435785292	4262	Economy	12700.00
0005435785267	4262	Economy	12700.00
0005435785261	4262	Economy	12700.00
0005435785289	4262	Economy	12700.00
0005435785260	4262	Economy	12700.00
0005435918608	4262	Economy	12700.00
0005435918615	4262	Economy	12700.00
0005434994003	4262	Economy	12700.00
0005435785281	4262	Economy	12700.00
0005435787349	4262	Economy	12700.00
0005435918626	4262	Economy	12700.00
0005435918595	4262	Economy	12700.00
0005432190623	4262	Economy	12700.00
0005435785287	4262	Economy	12700.00
0005432190622	4262	Economy	12700.00
0005435784988	27305	Business	38000.00
0005435784898	27305	Business	38000.00
0005435784973	27305	Business	38000.00
0005435785004	27305	Business	38000.00
0005435784891	27305	Business	38000.00
0005435784784	27305	Business	38000.00
0005432195687	27305	Business	38000.00
0005435784960	27305	Business	38000.00
0005435918642	27305	Economy	12700.00
0005435784802	27305	Economy	12700.00
0005435784936	27305	Economy	12700.00
0005434993963	27305	Economy	12700.00
0005435784872	27305	Economy	12700.00
0005435784880	27305	Economy	12700.00
0005434993960	27305	Economy	12700.00
0005435784950	27305	Economy	12700.00
0005434993898	27305	Economy	12700.00
0005435784971	27305	Economy	13900.00
0005435785028	27305	Economy	13900.00
0005435784845	27305	Economy	13900.00
0005435918644	27305	Economy	13900.00
0005435784897	27305	Economy	13900.00
0005435784857	27305	Economy	12700.00
0005435784908	27305	Economy	12700.00
0005435784987	27305	Economy	12700.00
0005435784893	27305	Economy	12700.00
0005434993914	27305	Economy	12700.00
0005435784933	27305	Economy	12700.00
0005435784803	27305	Economy	12700.00
0005435784921	27305	Economy	12700.00
0005435784846	27305	Economy	12700.00
0005435784953	27305	Economy	12700.00
0005434993933	27305	Economy	12700.00
0005435784954	27305	Economy	12700.00
0005435785000	27305	Economy	12700.00
0005434993962	27305	Economy	12700.00
0005432195686	27305	Economy	12700.00
0005434993930	27305	Economy	12700.00
0005435784947	27305	Economy	12700.00
0005435784907	27305	Economy	12700.00
0005434993959	27305	Economy	12700.00
0005435784816	27305	Economy	12700.00
0005435784972	27305	Economy	12700.00
0005435785097	27305	Economy	12700.00
0005435784983	27305	Economy	12700.00
0005435784896	27305	Economy	12700.00
0005435784913	27305	Economy	12700.00
0005435918646	27305	Economy	12700.00
0005435784969	27305	Economy	12700.00
0005434993961	27305	Economy	12700.00
0005435784932	27305	Economy	12700.00
0005434993964	27305	Economy	12700.00
0005435785032	27305	Economy	12700.00
0005435784924	27305	Economy	12700.00
0005435784894	27305	Economy	12700.00
0005435784804	27305	Economy	12700.00
0005435784948	27305	Economy	12700.00
0005435784968	27305	Economy	12700.00
0005435918645	27305	Economy	12700.00
0005435784854	27305	Economy	12700.00
0005435784906	27305	Economy	12700.00
0005435918643	27305	Economy	12700.00
0005434993892	27305	Economy	12700.00
0005435784881	27305	Economy	12700.00
0005435784909	27305	Economy	12700.00
0005432146193	19846	Economy	12800.00
0005432146194	19846	Economy	12800.00
0005432146192	19846	Economy	12800.00
0005434081840	4742	Business	40900.00
0005432170373	4742	Business	40900.00
0005434081852	4742	Business	40900.00
0005432567508	4742	Business	40900.00
0005432567473	4742	Business	40900.00
0005432567472	4742	Business	40900.00
0005432459757	4742	Business	40900.00
0005432567497	4742	Business	40900.00
0005434081845	4742	Business	40900.00
0005434081851	4742	Business	40900.00
0005432459745	4742	Business	40900.00
0005434081853	4742	Business	40900.00
0005432459715	4742	Business	40900.00
0005432186860	4742	Business	40900.00
0005432567471	4742	Business	40900.00
0005432459719	4742	Business	40900.00
0005432459746	4742	Business	40900.00
0005432567501	4742	Business	40900.00
0005432567509	4742	Business	40900.00
0005432459744	4742	Business	40900.00
0005432567488	4742	Economy	15000.00
0005432459743	4742	Business	40900.00
0005432459748	4742	Economy	15000.00
0005432567523	4742	Economy	15000.00
0005434081847	4742	Economy	15000.00
0005432567506	4742	Economy	13600.00
0005432567490	4742	Economy	13600.00
0005432567524	4742	Economy	13600.00
0005432571313	4742	Economy	13600.00
0005432459751	4742	Economy	13600.00
0005432567479	4742	Economy	13600.00
0005432567507	4742	Economy	13600.00
0005432567465	4742	Economy	13600.00
0005432567516	4742	Economy	13600.00
0005434081844	4742	Economy	13600.00
0005434081858	4742	Economy	13600.00
0005432567486	4742	Economy	13600.00
0005432567496	4742	Economy	13600.00
0005433726100	4742	Economy	13600.00
0005432459734	4742	Economy	13600.00
0005432186862	4742	Economy	13600.00
0005434081849	4742	Economy	13600.00
0005432567470	4742	Economy	13600.00
0005432567518	4742	Economy	13600.00
0005432459756	4742	Economy	13600.00
0005434081843	4742	Economy	13600.00
0005433726099	4742	Economy	13600.00
0005432567489	4742	Economy	13600.00
0005432459716	4742	Economy	13600.00
0005432459710	4742	Economy	13600.00
0005432567519	4742	Economy	13600.00
0005432459726	4742	Economy	13600.00
0005432567514	4742	Economy	13600.00
0005432459754	4742	Economy	13600.00
0005432567510	4742	Economy	13600.00
0005432459732	4742	Economy	13600.00
0005432567498	4742	Economy	13600.00
0005432567525	4742	Economy	13600.00
0005432567468	4742	Economy	13600.00
0005432567504	4742	Economy	13600.00
0005434081838	4742	Economy	13600.00
0005432571314	4742	Economy	13600.00
0005432459723	4742	Economy	13600.00
0005434081857	4742	Economy	13600.00
0005432567478	4742	Economy	13600.00
0005432567511	4742	Economy	13600.00
0005432567477	4742	Economy	13600.00
0005432567517	4742	Economy	13600.00
0005432567521	4742	Economy	13600.00
0005432459727	4742	Economy	13600.00
0005432459712	4742	Economy	13600.00
0005432459737	4742	Economy	13600.00
0005432567466	4742	Economy	13600.00
0005432459749	4742	Economy	13600.00
0005432459729	4742	Economy	13600.00
0005432567494	4742	Economy	13600.00
0005432459731	4742	Economy	13600.00
0005432170371	4742	Economy	13600.00
0005432459717	4742	Economy	13600.00
0005433452735	4742	Economy	13600.00
0005432459704	4742	Economy	13600.00
0005432459720	4742	Economy	13600.00
0005432567480	4742	Economy	13600.00
0005432567469	4742	Economy	13600.00
0005432567520	4742	Economy	13600.00
0005432459753	4742	Economy	13600.00
0005432459718	4742	Economy	13600.00
0005432567474	4742	Economy	13600.00
0005434081841	4742	Economy	13600.00
0005432567484	4742	Economy	13600.00
0005432571312	4742	Economy	15000.00
0005432459735	4742	Economy	15000.00
0005432567500	4742	Economy	13600.00
0005432459705	4742	Economy	13600.00
0005434081837	4742	Economy	15000.00
0005432170372	4742	Economy	15000.00
0005432459707	4742	Economy	13600.00
0005432567522	4742	Economy	13600.00
0005432459706	4742	Economy	13600.00
0005432459739	4742	Economy	13600.00
0005432567495	4742	Economy	13600.00
0005432567482	4742	Economy	13600.00
0005432567483	4742	Economy	13600.00
0005434081855	4742	Economy	13600.00
0005434081850	4742	Economy	13600.00
0005432459752	4742	Economy	13600.00
0005432170374	4742	Economy	13600.00
0005432571315	4742	Economy	13600.00
0005432459750	4742	Economy	13600.00
0005432567487	4742	Economy	13600.00
0005432459713	4742	Economy	13600.00
0005432459714	4742	Economy	13600.00
0005432567464	4742	Economy	13600.00
0005432186861	4742	Economy	13600.00
0005432459742	4742	Economy	13600.00
0005432567515	4742	Economy	13600.00
0005432459722	4742	Economy	13600.00
0005432567505	4742	Economy	13600.00
0005432459721	4742	Economy	13600.00
0005432567485	4742	Economy	13600.00
0005432459711	4742	Economy	13600.00
0005434081848	4742	Economy	13600.00
0005432459740	4742	Economy	13600.00
0005432567492	4742	Economy	13600.00
0005434081854	4742	Economy	13600.00
0005432567502	4742	Economy	13600.00
0005434081856	4742	Economy	13600.00
0005432459725	4742	Economy	13600.00
0005432567491	4742	Economy	13600.00
0005432567503	4742	Economy	13600.00
0005432459728	4742	Economy	13600.00
0005432459738	4742	Economy	13600.00
0005432459747	4742	Economy	13600.00
0005432567512	4742	Economy	13600.00
0005434081842	4742	Economy	13600.00
0005432567475	4742	Economy	13600.00
0005432567493	4742	Economy	13600.00
0005432459755	4742	Economy	13600.00
0005432459724	4742	Economy	13600.00
0005433726098	4742	Economy	13600.00
0005432567499	4742	Economy	13600.00
0005432567467	4742	Economy	13600.00
0005432459709	4742	Economy	13600.00
0005432459736	4742	Economy	13600.00
0005432459733	4742	Economy	13600.00
0005432186863	4742	Economy	13600.00
0005432567481	4742	Economy	13600.00
0005432170370	4742	Economy	13600.00
0005432567476	4742	Economy	13600.00
0005432459730	4742	Economy	13600.00
0005434081846	4742	Economy	13600.00
0005434081839	4742	Economy	13600.00
0005432459741	4742	Economy	13600.00
0005432459708	4742	Economy	13600.00
0005432567513	4742	Economy	13600.00
0005432567095	30563	Business	40900.00
0005432571283	30563	Business	40900.00
0005432567061	30563	Business	40900.00
0005432566784	30563	Business	40900.00
0005432459260	30563	Business	40900.00
0005432161148	30563	Business	40900.00
0005432459404	30563	Business	40900.00
0005432566998	30563	Business	40900.00
0005432567015	30563	Business	40900.00
0005432566997	30563	Business	40900.00
0005432459304	30563	Business	40900.00
0005432566921	30563	Business	40900.00
0005432459405	30563	Business	40900.00
0005432566891	30563	Business	40900.00
0005432567158	30563	Business	40900.00
0005434081746	30563	Business	40900.00
0005434081720	30563	Business	40900.00
0005432566859	30563	Business	40900.00
0005432571270	30563	Business	40900.00
0005432459472	30563	Business	40900.00
0005432459136	30563	Business	40900.00
0005434081647	30563	Business	40900.00
0005432459301	30563	Economy	15000.00
0005434081721	30563	Economy	15000.00
0005433454858	30563	Economy	15000.00
0005432567194	30563	Economy	13600.00
0005432566924	30563	Economy	13600.00
0005432571271	30563	Economy	13600.00
0005432459362	30563	Economy	13600.00
0005434081634	30563	Economy	13600.00
0005432567077	30563	Economy	13600.00
0005432459425	30563	Economy	13600.00
0005432459149	30563	Economy	13600.00
0005433452715	30563	Economy	13600.00
0005432459180	30563	Economy	13600.00
0005432566894	30563	Economy	13600.00
0005434081646	30563	Economy	13600.00
0005432459434	30563	Economy	13600.00
0005432459358	30563	Economy	13600.00
0005432459174	30563	Economy	13600.00
0005434081567	30563	Economy	13600.00
0005432567160	30563	Economy	13600.00
0005434081650	30563	Economy	13600.00
0005432459230	30563	Economy	13600.00
0005432459342	30563	Economy	13600.00
0005432567149	30563	Economy	13600.00
0005432161147	30563	Economy	13600.00
0005432567232	30563	Economy	13600.00
0005432459242	30563	Economy	13600.00
0005432566817	30563	Economy	13600.00
0005432566789	30563	Economy	13600.00
0005432459408	30563	Economy	13600.00
0005432567000	30563	Economy	13600.00
0005432567058	30563	Economy	13600.00
0005432459588	30563	Economy	13600.00
0005432459430	30563	Economy	13600.00
0005432567045	30563	Economy	13600.00
0005432567120	30563	Economy	13600.00
0005432459431	30563	Economy	13600.00
0005432459467	30563	Economy	13600.00
0005434081620	30563	Economy	13600.00
0005434081633	30563	Economy	13600.00
0005432459272	30563	Economy	13600.00
0005432566932	30563	Economy	13600.00
0005432566980	30563	Economy	13600.00
0005432567161	30563	Economy	13600.00
0005432459322	30563	Economy	13600.00
0005432459352	30563	Economy	13600.00
0005432567057	30563	Economy	13600.00
0005432567336	30563	Economy	13600.00
0005432571288	30563	Economy	13600.00
0005434081599	30563	Economy	13600.00
0005432566918	30563	Economy	13600.00
0005432567014	30563	Economy	13600.00
0005432567143	30563	Economy	13600.00
0005434081566	30563	Economy	13600.00
0005432459143	30563	Economy	13600.00
0005432567086	30563	Economy	13600.00
0005432459353	30563	Economy	13600.00
0005432567078	30563	Economy	13600.00
0005432566923	30563	Economy	13600.00
0005432459175	30563	Economy	13600.00
0005434081621	30563	Economy	13600.00
0005432459538	30563	Economy	13600.00
0005432459369	30563	Economy	13600.00
0005432566827	30563	Economy	13600.00
0005434081747	30563	Economy	13600.00
0005432213599	30563	Economy	13600.00
0005434081661	30563	Economy	13600.00
0005432459473	30563	Economy	13600.00
0005432566933	30563	Economy	13600.00
0005432566818	30563	Economy	13600.00
0005432567069	30563	Economy	13600.00
0005432567206	30563	Economy	13600.00
0005432459225	30563	Economy	13600.00
0005432459281	30563	Economy	13600.00
0005434081612	30563	Economy	13600.00
0005432567027	30563	Economy	13600.00
0005432566934	30563	Economy	13600.00
0005434081562	30563	Economy	15000.00
0005432566653	30563	Economy	13600.00
0005432567230	30563	Economy	13600.00
0005432566919	30563	Economy	13600.00
0005432459586	30563	Economy	15000.00
0005432459330	30563	Economy	15000.00
0005432566964	30563	Economy	13600.00
0005432161146	30563	Economy	13600.00
0005432566892	30563	Economy	13600.00
0005432566738	30563	Economy	13600.00
0005434081496	30563	Economy	13600.00
0005432459148	30563	Economy	13600.00
0005432459218	30563	Economy	13600.00
0005434081662	30563	Economy	13600.00
0005432459259	30563	Economy	13600.00
0005434081641	30563	Economy	13600.00
0005434081568	30563	Economy	13600.00
0005432567070	30563	Economy	13600.00
0005432566977	30563	Economy	13600.00
0005432459302	30563	Economy	13600.00
0005432459459	30563	Economy	13600.00
0005434081663	30563	Economy	13600.00
0005432459570	30563	Economy	13600.00
0005432567207	30563	Economy	13600.00
0005434081651	30563	Economy	13600.00
0005432567025	30563	Economy	13600.00
0005432567193	30563	Economy	13600.00
0005432459569	30563	Economy	13600.00
0005432459255	30563	Economy	13600.00
0005432567249	30563	Economy	13600.00
0005432459176	30563	Economy	13600.00
0005432567335	30563	Economy	13600.00
0005432566737	30563	Economy	13600.00
0005432459359	30563	Economy	13600.00
0005432459167	30563	Economy	13600.00
0005432459303	30563	Economy	13600.00
0005432566639	30563	Economy	13600.00
0005432459327	30563	Economy	13600.00
0005432459221	30563	Economy	13600.00
0005432213598	30563	Economy	13600.00
0005434081613	30563	Economy	13600.00
0005432459587	30563	Economy	13600.00
0005432459137	30563	Economy	13600.00
0005432567125	30563	Economy	13600.00
0005432571290	30563	Economy	13600.00
0005432459506	30563	Economy	13600.00
0005432566979	30563	Economy	13600.00
0005432459220	30563	Economy	13600.00
0005434081691	30563	Economy	13600.00
0005432566863	30563	Economy	13600.00
0005432213597	30563	Economy	13600.00
0005432459062	30563	Economy	13600.00
0005432567085	30563	Economy	13600.00
0005432567198	30563	Economy	13600.00
0005432459367	30563	Economy	13600.00
0005432459273	30563	Economy	13600.00
0005432459247	30563	Economy	13600.00
0005432566920	30563	Economy	13600.00
0005432459300	30563	Economy	13600.00
0005432567021	30563	Economy	13600.00
0005432459222	30563	Economy	13600.00
0005434081563	30563	Economy	13600.00
0005432567142	30563	Economy	13600.00
0005434081614	30563	Economy	13600.00
0005432459043	30563	Economy	13600.00
0005432459537	30563	Economy	13600.00
0005432567121	30563	Economy	13600.00
0005435722050	13573	Economy	9900.00
0005435720821	13573	Economy	9900.00
0005435720820	13573	Economy	9900.00
0005435722049	13573	Economy	9900.00
0005435722028	21179	Economy	9900.00
0005435722023	21179	Economy	9900.00
0005435722027	21179	Economy	9900.00
0005432295873	22769	Economy	8800.00
0005432295874	22769	Economy	8800.00
0005433342940	11121	Business	23600.00
0005433342967	11121	Business	23600.00
0005433342937	11121	Business	23600.00
0005433342997	11121	Business	23600.00
0005433342953	11121	Business	23600.00
0005435097175	11121	Business	23600.00
0005433342915	11121	Business	23600.00
0005433342963	11121	Business	23600.00
0005435508296	11121	Business	23600.00
0005433342928	11121	Business	23600.00
0005433342976	11121	Business	23600.00
0005433342944	11121	Economy	7900.00
0005433342938	11121	Economy	7900.00
0005433342975	11121	Economy	7900.00
0005433342973	11121	Economy	7900.00
0005433342995	11121	Economy	7900.00
0005433343008	11121	Economy	7900.00
0005433342946	11121	Economy	7900.00
0005435508229	11121	Economy	7900.00
0005433342914	11121	Economy	7900.00
0005433342977	11121	Economy	7900.00
0005433342991	11121	Economy	7900.00
0005433342923	11121	Economy	7900.00
0005433342948	11121	Economy	7900.00
0005435097174	11121	Economy	7900.00
0005433342994	11121	Economy	7900.00
0005433342956	11121	Economy	7900.00
0005433342981	11121	Economy	7900.00
0005435097179	11121	Economy	7900.00
0005435508290	11121	Economy	7900.00
0005433342985	11121	Economy	7900.00
0005435508214	11121	Economy	7900.00
0005435508291	11121	Economy	7900.00
0005433342941	11121	Economy	7900.00
0005435508273	11121	Economy	7900.00
0005435097177	11121	Economy	7900.00
0005433342945	11121	Economy	7900.00
0005433342924	11121	Economy	7900.00
0005433342943	11121	Economy	7900.00
0005435380239	11121	Economy	7900.00
0005433342999	11121	Economy	7900.00
0005433342908	11121	Economy	7900.00
0005435097180	11121	Economy	7900.00
0005433342962	11121	Economy	7900.00
0005433342929	11121	Economy	7900.00
0005433342926	11121	Economy	7900.00
0005435097176	11121	Economy	7900.00
0005433342960	11121	Economy	7900.00
0005435097178	11121	Economy	7900.00
0005435097172	11121	Economy	7900.00
0005433342986	11121	Economy	7900.00
0005433342950	11121	Economy	8600.00
0005433342958	11121	Economy	8600.00
0005433342988	11121	Economy	8600.00
0005435380256	11121	Economy	8600.00
0005433343007	11121	Economy	8600.00
0005433342979	11121	Economy	7900.00
0005433342998	11121	Economy	7900.00
0005433342951	11121	Economy	7900.00
0005433342911	11121	Economy	7900.00
0005433342947	11121	Economy	7900.00
0005433342990	11121	Economy	7900.00
0005433342972	11121	Economy	7900.00
0005435508213	11121	Economy	7900.00
0005433342912	11121	Economy	7900.00
0005433342961	11121	Economy	7900.00
0005433342932	11121	Economy	7900.00
0005435508234	11121	Economy	7900.00
0005433342920	11121	Economy	7900.00
0005433342909	11121	Economy	7900.00
0005433342918	11121	Economy	7900.00
0005433342974	11121	Economy	7900.00
0005433342942	11121	Economy	7900.00
0005433342913	11121	Economy	7900.00
0005433342917	11121	Economy	7900.00
0005433342933	11121	Economy	7900.00
0005433342957	11121	Economy	7900.00
0005435508255	11121	Economy	7900.00
0005435508269	11121	Economy	7900.00
0005433342934	11121	Economy	7900.00
0005433342939	11121	Economy	7900.00
0005433342964	11121	Economy	7900.00
0005433342927	11121	Economy	7900.00
0005433343000	11121	Economy	7900.00
0005433342993	11121	Economy	7900.00
0005435508240	11121	Economy	7900.00
0005435508268	11121	Economy	7900.00
0005433342959	11121	Economy	7900.00
0005433342996	11121	Economy	7900.00
0005433342989	11121	Economy	7900.00
0005433342965	11121	Economy	7900.00
0005433342916	11121	Economy	7900.00
0005433342931	11121	Economy	7900.00
0005433342982	11121	Economy	7900.00
0005433342954	11121	Economy	7900.00
0005433342968	11121	Economy	7900.00
0005433342987	11121	Economy	7900.00
0005433342966	11121	Economy	7900.00
0005433343001	11121	Economy	7900.00
0005433342969	11121	Economy	7900.00
0005433342978	11121	Economy	7900.00
0005433342919	11121	Economy	7900.00
0005433343004	11121	Economy	7900.00
0005433342935	11121	Economy	7900.00
0005435380255	11121	Economy	7900.00
0005433342949	11121	Economy	7900.00
0005433342936	11121	Economy	7900.00
0005433342952	11121	Economy	7900.00
0005433342970	11121	Economy	7900.00
0005433342980	11121	Economy	7900.00
0005433342930	11121	Economy	7900.00
0005433342971	11121	Economy	7900.00
0005433342910	11121	Economy	7900.00
0005433342922	11121	Economy	7900.00
0005433342984	11121	Economy	7900.00
0005433342955	11121	Economy	7900.00
0005435508254	11121	Economy	7900.00
0005433342921	11121	Economy	7900.00
0005433342925	11121	Economy	7900.00
0005433343005	11121	Economy	7900.00
0005433343003	11121	Economy	7900.00
0005435097173	11121	Economy	7900.00
0005433343006	11121	Economy	7900.00
0005433342992	11121	Economy	7900.00
0005433342983	11121	Economy	7900.00
0005433343002	11121	Economy	7900.00
0005435508241	11121	Economy	7900.00
0005433341774	17137	Business	23600.00
0005433341814	17137	Business	23600.00
0005435097046	17137	Business	23600.00
0005433341994	17137	Business	23600.00
0005433341943	17137	Business	23600.00
0005433341962	17137	Business	23600.00
0005433342248	17137	Business	23600.00
0005433342271	17137	Business	23600.00
0005433341891	17137	Business	23600.00
0005433342048	17137	Business	23600.00
0005433342049	17137	Business	23600.00
0005433342236	17137	Business	23600.00
0005433342100	17137	Economy	7900.00
0005433341859	17137	Economy	7900.00
0005433341792	17137	Economy	7900.00
0005433341990	17137	Economy	7900.00
0005433341791	17137	Economy	7900.00
0005433341904	17137	Economy	7900.00
0005433341627	17137	Economy	7900.00
0005433342065	17137	Economy	7900.00
0005433342078	17137	Economy	7900.00
0005433341629	17137	Economy	7900.00
0005433342130	17137	Economy	7900.00
0005433342383	17137	Economy	7900.00
0005433341977	17137	Economy	7900.00
0005433342028	17137	Economy	7900.00
0005433342141	17137	Economy	7900.00
0005433342110	17137	Economy	7900.00
0005433341876	17137	Economy	7900.00
0005433341756	17137	Economy	7900.00
0005433341964	17137	Economy	7900.00
0005433342087	17137	Economy	7900.00
0005433341958	17137	Economy	7900.00
0005432293202	17137	Economy	7900.00
0005433342086	17137	Economy	7900.00
0005433342073	17137	Economy	7900.00
0005433341993	17137	Economy	7900.00
0005433342033	17137	Economy	7900.00
0005433342159	17137	Economy	7900.00
0005433341982	17137	Economy	7900.00
0005433341892	17137	Economy	7900.00
0005435097108	17137	Economy	7900.00
0005433341957	17137	Economy	7900.00
0005433341721	17137	Economy	7900.00
0005433341877	17137	Economy	7900.00
0005435097075	17137	Economy	7900.00
0005435097047	17137	Economy	7900.00
0005433341896	17137	Economy	7900.00
0005433341975	17137	Economy	7900.00
0005433341749	17137	Economy	7900.00
0005433341828	17137	Economy	7900.00
0005433342020	17137	Economy	7900.00
0005433341976	17137	Economy	8600.00
0005433342040	17137	Economy	8600.00
0005433341869	17137	Economy	8600.00
0005435097076	17137	Economy	8600.00
0005433342131	17137	Economy	8600.00
0005433342041	17137	Economy	7900.00
0005433342042	17137	Economy	8600.00
0005433342060	17137	Economy	7900.00
0005433341929	17137	Economy	7900.00
0005433341832	17137	Economy	7900.00
0005433342185	17137	Economy	7900.00
0005433341811	17137	Economy	7900.00
0005433341860	17137	Economy	7900.00
0005433341895	17137	Economy	7900.00
0005433342035	17137	Economy	7900.00
0005433342032	17137	Economy	7900.00
0005433341905	17137	Economy	7900.00
0005433341967	17137	Economy	7900.00
0005433341460	17137	Economy	7900.00
0005433341858	17137	Economy	7900.00
0005433341787	17137	Economy	7900.00
0005433342025	17137	Economy	7900.00
0005433342245	17137	Economy	7900.00
0005433341643	17137	Economy	7900.00
0005433342353	17137	Economy	7900.00
0005433341776	17137	Economy	7900.00
0005433342334	17137	Economy	7900.00
0005433342195	17137	Economy	7900.00
0005435097103	17137	Economy	7900.00
0005432293204	17137	Economy	7900.00
0005432293203	17137	Economy	7900.00
0005433342067	17137	Economy	7900.00
0005433342214	17137	Economy	7900.00
0005433341628	17137	Economy	7900.00
0005433341850	17137	Economy	7900.00
0005433341793	17137	Economy	7900.00
0005433341959	17137	Economy	7900.00
0005435097104	17137	Economy	7900.00
0005433341558	17137	Economy	7900.00
0005433342052	17137	Economy	7900.00
0005433342129	17137	Economy	7900.00
0005433341880	17137	Economy	7900.00
0005433341518	17137	Economy	7900.00
0005433341961	17137	Economy	7900.00
0005433341997	17137	Economy	7900.00
0005433342384	17137	Economy	7900.00
0005433341866	17137	Economy	7900.00
0005433341827	17137	Economy	7900.00
0005433341991	17137	Economy	7900.00
0005433341773	17137	Economy	7900.00
0005433342244	17137	Economy	7900.00
0005435097101	17137	Economy	7900.00
0005433342066	17137	Economy	7900.00
0005433342034	17137	Economy	7900.00
0005433342150	17137	Economy	7900.00
0005433342115	17137	Economy	7900.00
0005433342280	17137	Economy	7900.00
0005433341863	17137	Economy	7900.00
0005433341915	17137	Economy	7900.00
0005433341833	17137	Economy	7900.00
0005433341401	17137	Economy	7900.00
0005433341901	17137	Economy	7900.00
0005433341996	17137	Economy	7900.00
0005435097069	17137	Economy	7900.00
0005433341989	17137	Economy	7900.00
0005433341968	17137	Economy	7900.00
0005433341851	17137	Economy	7900.00
0005433342061	17137	Economy	7900.00
0005435097102	17137	Economy	7900.00
0005433342499	17137	Economy	7900.00
0005433341796	17137	Economy	7900.00
0005433342199	17137	Economy	7900.00
0005433341897	17137	Economy	7900.00
0005433342249	17137	Economy	7900.00
0005433341890	17137	Economy	7900.00
0005433341963	17137	Economy	7900.00
0005432919597	9100	Business	26600.00
0005432919660	9100	Business	26600.00
0005432919558	9100	Business	26600.00
0005433507145	9100	Business	26600.00
0005432919635	9100	Business	26600.00
0005432919598	9100	Business	26600.00
0005433507141	9100	Business	26600.00
0005433481151	9100	Business	26600.00
0005432919689	9100	Economy	8900.00
0005433481149	9100	Economy	8900.00
0005433507144	9100	Economy	8900.00
0005432919610	9100	Economy	8900.00
0005432919681	9100	Economy	8900.00
0005432919679	9100	Economy	8900.00
0005433481147	9100	Economy	8900.00
0005432919599	9100	Economy	9800.00
0005432919559	9100	Economy	9800.00
0005432919612	9100	Economy	9800.00
0005433507147	9100	Economy	8900.00
0005432919581	9100	Economy	8900.00
0005432919626	9100	Economy	8900.00
0005432919611	9100	Economy	8900.00
0005432919640	9100	Economy	8900.00
0005433507146	9100	Economy	8900.00
0005433507142	9100	Economy	8900.00
0005433507152	9100	Economy	8900.00
0005432919604	9100	Economy	8900.00
0005432919678	9100	Economy	8900.00
0005432919582	9100	Economy	8900.00
0005432919580	9100	Economy	8900.00
0005433507155	9100	Economy	8900.00
0005433481154	9100	Economy	8900.00
0005432919634	9100	Economy	8900.00
0005433507143	9100	Economy	8900.00
0005433481150	9100	Economy	8900.00
0005433507156	9100	Economy	8900.00
0005432919685	9100	Economy	8900.00
0005432919560	9100	Economy	8900.00
0005433507149	9100	Economy	8900.00
0005433507154	9100	Economy	8900.00
0005432919639	9100	Economy	8900.00
0005432919718	9100	Economy	8900.00
0005433507150	9100	Economy	8900.00
0005432919627	9100	Economy	8900.00
0005433481148	9100	Economy	8900.00
0005432919579	9100	Economy	8900.00
0005433507153	9100	Economy	8900.00
0005432919636	9100	Economy	8900.00
0005432919680	9100	Economy	8900.00
0005433507148	9100	Economy	8900.00
0005433507151	9100	Economy	8900.00
0005433481152	9100	Economy	8900.00
0005432919705	9100	Economy	8900.00
0005433481153	9100	Economy	8900.00
0005432919575	9100	Economy	8900.00
0005432919841	20458	Business	26600.00
0005432919836	20458	Business	26600.00
0005433481080	20458	Business	26600.00
0005432919826	20458	Business	26600.00
0005433481103	20458	Business	26600.00
0005433506987	20458	Business	26600.00
0005433506999	20458	Business	26600.00
0005432919835	20458	Business	26600.00
0005433506961	20458	Economy	8900.00
0005433506985	20458	Economy	8900.00
0005433506962	20458	Economy	8900.00
0005433481089	20458	Economy	8900.00
0005433506980	20458	Economy	8900.00
0005433507022	20458	Economy	8900.00
0005433506991	20458	Economy	9800.00
0005432919842	20458	Economy	9800.00
0005433481082	20458	Economy	8900.00
0005433481090	20458	Economy	8900.00
0005433481079	20458	Economy	8900.00
0005432919839	20458	Economy	8900.00
0005433506953	20458	Economy	8900.00
0005433507021	20458	Economy	8900.00
0005432919833	20458	Economy	8900.00
0005432919844	20458	Economy	8900.00
0005433506924	20458	Economy	8900.00
0005433481056	20458	Economy	8900.00
0005433506923	20458	Economy	8900.00
0005433481096	20458	Economy	8900.00
0005433481102	20458	Economy	8900.00
0005432919837	20458	Economy	8900.00
0005432919828	20458	Economy	8900.00
0005432919825	20458	Economy	8900.00
0005433506983	20458	Economy	8900.00
0005432919832	20458	Economy	8900.00
0005433506986	20458	Economy	8900.00
0005432919831	20458	Economy	8900.00
0005432919834	20458	Economy	8900.00
0005433507000	20458	Economy	8900.00
0005432919843	20458	Economy	8900.00
0005433481092	20458	Economy	8900.00
0005432919829	20458	Economy	8900.00
0005433506984	20458	Economy	8900.00
0005432919830	20458	Economy	8900.00
0005433506952	20458	Economy	8900.00
0005432919827	20458	Economy	8900.00
0005433506939	20458	Economy	8900.00
0005433481057	20458	Economy	8900.00
0005432919838	20458	Economy	8900.00
0005432919824	20458	Economy	8900.00
0005432919840	20458	Economy	8900.00
0005432396232	10181	Economy	5800.00
0005432394092	10181	Economy	5800.00
0005432394090	10181	Economy	5800.00
0005432396229	10181	Economy	5800.00
0005432394091	10181	Economy	5800.00
0005432396231	10181	Economy	5800.00
0005432394093	10181	Economy	5800.00
0005432396230	10181	Economy	5800.00
0005432396192	18356	Economy	5800.00
0005432400074	18356	Economy	5800.00
0005432396220	18356	Economy	5800.00
0005432396194	18356	Economy	5800.00
0005432396198	18356	Economy	5800.00
0005432400068	18356	Economy	5800.00
0005432400067	18356	Economy	5800.00
0005432396195	18356	Economy	5800.00
0005432400073	18356	Economy	5800.00
0005434411769	10974	Business	9500.00
0005435554127	10974	Business	9500.00
0005435125769	10974	Business	9500.00
0005435125872	10974	Business	9500.00
0005435125947	10974	Business	9500.00
0005435625970	10974	Business	9500.00
0005435125927	10974	Business	9500.00
0005435125730	10974	Business	9500.00
0005435125797	10974	Economy	3200.00
0005435625933	10974	Economy	3200.00
0005435125732	10974	Economy	3200.00
0005435125815	10974	Economy	3200.00
0005435126006	10974	Economy	3200.00
0005435554132	10974	Economy	3200.00
0005435625925	10974	Economy	3200.00
0005434928294	10974	Economy	3200.00
0005434928292	10974	Economy	3500.00
0005435125731	10974	Economy	3500.00
0005434928293	10974	Economy	3500.00
0005435625932	10974	Economy	3500.00
0005435125755	10974	Economy	3200.00
0005435625934	10974	Economy	3200.00
0005435125823	10974	Economy	3200.00
0005435126077	10974	Economy	3200.00
0005435126034	10974	Economy	3200.00
0005435625944	10974	Economy	3200.00
0005435125901	10974	Economy	3200.00
0005435125930	10974	Economy	3200.00
0005435125862	10974	Economy	3200.00
0005435125780	10974	Economy	3200.00
0005434411770	10974	Economy	3200.00
0005435125878	10974	Economy	3200.00
0005435125957	10974	Economy	3200.00
0005435625907	10974	Economy	3200.00
0005435625906	10974	Economy	3200.00
0005435125822	10974	Economy	3200.00
0005435125958	10974	Economy	3200.00
0005435625947	10974	Economy	3200.00
0005435625942	10974	Economy	3200.00
0005435125810	10974	Economy	3200.00
0005435126033	10974	Economy	3200.00
0005435554128	10974	Economy	3200.00
0005434411768	10974	Economy	3200.00
0005434411771	10974	Economy	3200.00
0005435554141	10974	Economy	3200.00
0005435125811	10974	Economy	3200.00
0005435554143	10974	Economy	3200.00
0005435126004	10974	Economy	3200.00
0005435125921	10974	Economy	3200.00
0005435125874	10974	Economy	3200.00
0005435125973	10974	Economy	3200.00
0005435125904	10974	Economy	3200.00
0005435625913	10974	Economy	3200.00
0005435125832	10974	Economy	3200.00
0005435125703	10974	Economy	3200.00
0005435625964	10974	Economy	3200.00
0005435125938	10974	Economy	3200.00
0005435125900	10974	Economy	3200.00
0005435125786	10974	Economy	3200.00
0005435126076	10974	Economy	3200.00
0005435125959	10974	Economy	3200.00
0005435625961	10974	Economy	3200.00
0005435125779	10974	Economy	3200.00
0005435125843	10974	Economy	3200.00
0005435126005	10974	Economy	3200.00
0005435625943	10974	Economy	3200.00
0005435625931	10974	Economy	3200.00
0005435554138	10974	Economy	3200.00
0005435554142	10974	Economy	3200.00
0005435625948	10974	Economy	3200.00
0005435125745	10974	Economy	3200.00
0005435126042	10974	Economy	3200.00
0005435125791	10974	Economy	3200.00
0005435125972	10974	Economy	3200.00
0005435125873	10974	Economy	3200.00
0005435125871	10974	Economy	3200.00
0005435625969	10974	Economy	3200.00
0005435126007	10974	Economy	3200.00
0005435125992	10974	Economy	3200.00
0005435125861	10974	Economy	3200.00
0005435126282	14769	Business	9500.00
0005435126273	14769	Business	9500.00
0005435126275	14769	Business	9500.00
0005435126272	14769	Business	9500.00
0005435554173	14769	Business	9500.00
0005435126296	14769	Business	9500.00
0005435126277	14769	Business	9500.00
0005435126306	14769	Business	9500.00
0005435126278	14769	Economy	3200.00
0005435626144	14769	Economy	3200.00
0005435126307	14769	Economy	3200.00
0005435126285	14769	Economy	3200.00
0005435126292	14769	Economy	3200.00
0005435126291	14769	Economy	3200.00
0005435126301	14769	Economy	3500.00
0005435626142	14769	Economy	3500.00
0005435556686	14769	Economy	3500.00
0005435126294	14769	Economy	3500.00
0005435126304	14769	Economy	3200.00
0005434411724	14769	Economy	3200.00
0005435126305	14769	Economy	3200.00
0005434411719	14769	Economy	3200.00
0005435554176	14769	Economy	3200.00
0005435556687	14769	Economy	3200.00
0005434411720	14769	Economy	3200.00
0005435554174	14769	Economy	3200.00
0005435126274	14769	Economy	3200.00
0005435126279	14769	Economy	3200.00
0005434411721	14769	Economy	3200.00
0005435126295	14769	Economy	3200.00
0005435626138	14769	Economy	3200.00
0005434411707	14769	Economy	3200.00
0005435126281	14769	Economy	3200.00
0005435126308	14769	Economy	3200.00
0005435554175	14769	Economy	3200.00
0005435126313	14769	Economy	3200.00
0005435126309	14769	Economy	3200.00
0005435126283	14769	Economy	3200.00
0005435126310	14769	Economy	3200.00
0005435626143	14769	Economy	3200.00
0005435126311	14769	Economy	3200.00
0005435126297	14769	Economy	3200.00
0005435126288	14769	Economy	3200.00
0005435626139	14769	Economy	3200.00
0005435126303	14769	Economy	3200.00
0005435126302	14769	Economy	3200.00
0005435126289	14769	Economy	3200.00
0005435126276	14769	Economy	3200.00
0005435126298	14769	Economy	3200.00
0005435626140	14769	Economy	3200.00
0005435126290	14769	Economy	3200.00
0005435126312	14769	Economy	3200.00
0005435126280	14769	Economy	3200.00
0005435126293	14769	Economy	3200.00
0005435126284	14769	Economy	3200.00
0005435126287	14769	Economy	3200.00
0005435126286	14769	Economy	3200.00
0005435626141	14769	Economy	3200.00
0005435126300	14769	Economy	3200.00
0005435126299	14769	Economy	3200.00
0005435715430	7110	Business	86900.00
0005435715436	7110	Business	86900.00
0005435216561	7110	Business	86900.00
0005435443214	7110	Business	86900.00
0005435221043	7110	Business	86900.00
0005435715427	7110	Business	86900.00
0005432400115	7110	Economy	29000.00
0005432398190	7110	Economy	29000.00
0005432400117	7110	Economy	29000.00
0005435219166	7110	Economy	29000.00
0005432398188	7110	Economy	31900.00
0005435178477	7110	Economy	31900.00
0005435715431	7110	Economy	31900.00
0005432400116	7110	Economy	29000.00
0005435221041	7110	Economy	29000.00
0005435443185	7110	Economy	29000.00
0005435715429	7110	Economy	29000.00
0005435715438	7110	Economy	29000.00
0005435715426	7110	Economy	29000.00
0005435179386	7110	Economy	29000.00
0005435443213	7110	Economy	29000.00
0005435715424	7110	Economy	29000.00
0005435715434	7110	Economy	29000.00
0005435715439	7110	Economy	29000.00
0005435443209	7110	Economy	29000.00
0005435443207	7110	Economy	29000.00
0005432398191	7110	Economy	29000.00
0005435715435	7110	Economy	29000.00
0005435443182	7110	Economy	29000.00
0005432398189	7110	Economy	29000.00
0005432400114	7110	Economy	29000.00
0005435715433	7110	Economy	29000.00
0005435443208	7110	Economy	29000.00
0005435715440	7110	Economy	29000.00
0005435219170	7110	Economy	29000.00
0005435221042	7110	Economy	29000.00
0005435715437	7110	Economy	29000.00
0005435715423	7110	Economy	29000.00
0005435179385	7110	Economy	29000.00
0005435715432	7110	Economy	29000.00
0005435216562	7110	Economy	29000.00
0005435715428	7110	Economy	29000.00
0005435715425	7110	Economy	29000.00
0005435217705	27064	Business	86900.00
0005435715295	27064	Business	86900.00
0005435217701	27064	Business	86900.00
0005432394063	27064	Business	86900.00
0005435218111	27064	Business	86900.00
0005435217700	27064	Business	86900.00
0005435715321	27064	Business	86900.00
0005435715261	27064	Business	86900.00
0005435217703	27064	Economy	29000.00
0005435216577	27064	Economy	29000.00
0005435216578	27064	Economy	29000.00
0005435217707	27064	Economy	29000.00
0005435216582	27064	Economy	29000.00
0005435218110	27064	Economy	29000.00
0005435715319	27064	Economy	29000.00
0005435715327	27064	Economy	29000.00
0005432394038	27064	Economy	31900.00
0005435443293	27064	Economy	31900.00
0005432394062	27064	Economy	31900.00
0005435715217	27064	Economy	31900.00
0005435715297	27064	Economy	31900.00
0005432398148	27064	Economy	29000.00
0005435218112	27064	Economy	29000.00
0005435178491	27064	Economy	29000.00
0005432394064	27064	Economy	29000.00
0005435217704	27064	Economy	29000.00
0005435443296	27064	Economy	29000.00
0005435216583	27064	Economy	29000.00
0005435715320	27064	Economy	29000.00
0005435715227	27064	Economy	29000.00
0005435216576	27064	Economy	29000.00
0005435443290	27064	Economy	29000.00
0005435443295	27064	Economy	29000.00
0005435443291	27064	Economy	29000.00
0005435715362	27064	Economy	29000.00
0005435715229	27064	Economy	29000.00
0005435443292	27064	Economy	29000.00
0005432398147	27064	Economy	29000.00
0005435715304	27064	Economy	29000.00
0005435715296	27064	Economy	29000.00
0005432394051	27064	Economy	29000.00
0005435715266	27064	Economy	29000.00
0005435217706	27064	Economy	29000.00
0005435443298	27064	Economy	29000.00
0005435216580	27064	Economy	29000.00
0005435216581	27064	Economy	29000.00
0005435217702	27064	Economy	29000.00
0005435178492	27064	Economy	29000.00
0005435443297	27064	Economy	29000.00
0005432394052	27064	Economy	29000.00
0005432394037	27064	Economy	29000.00
0005435715275	27064	Economy	29000.00
0005435216584	27064	Economy	29000.00
0005435217708	27064	Economy	29000.00
0005435715265	27064	Economy	29000.00
0005435443294	27064	Economy	29000.00
0005435715276	27064	Economy	29000.00
0005435715326	27064	Economy	29000.00
0005435216579	27064	Economy	29000.00
0005434084919	2746	Economy	7700.00
0005433060378	2746	Economy	7700.00
0005434084923	2746	Economy	7700.00
0005434084922	2746	Economy	7700.00
0005434084918	2746	Economy	7700.00
0005433060379	2746	Economy	7700.00
0005434084921	2746	Economy	7700.00
0005434084920	2746	Economy	7700.00
0005433060408	28494	Economy	7700.00
0005434084890	28494	Economy	7700.00
0005434084873	28494	Economy	7700.00
0005433060407	28494	Economy	7700.00
0005434084878	28494	Economy	7700.00
0005434084884	28494	Economy	7700.00
0005435548419	11162	Economy	27100.00
0005435548446	11162	Economy	27100.00
0005435548442	11162	Economy	27100.00
0005433788200	11162	Economy	24600.00
0005435548439	11162	Economy	24600.00
0005435548417	11162	Economy	24600.00
0005433788203	11162	Economy	24600.00
0005433788204	11162	Economy	24600.00
0005433788195	11162	Economy	24600.00
0005433788196	11162	Economy	24600.00
0005435548430	11162	Economy	24600.00
0005433788194	11162	Economy	24600.00
0005435548418	11162	Economy	24600.00
0005435548420	11162	Economy	24600.00
0005435548429	11162	Economy	24600.00
0005435548447	11162	Economy	24600.00
0005433788193	11162	Economy	24600.00
0005435548438	11162	Economy	24600.00
0005435548431	11162	Economy	24600.00
0005433788192	11162	Economy	24600.00
0005435548443	11162	Economy	24600.00
0005435548424	11162	Economy	24600.00
0005433788202	11162	Economy	24600.00
0005435548425	11162	Economy	24600.00
0005435548432	11162	Economy	24600.00
0005433788198	11162	Economy	24600.00
0005433788190	11162	Economy	24600.00
0005435548445	11162	Economy	24600.00
0005435548437	11162	Economy	24600.00
0005433788197	11162	Economy	24600.00
0005435548421	11162	Economy	24600.00
0005433788199	11162	Economy	24600.00
0005433788201	11162	Economy	24600.00
0005433788191	11162	Economy	24600.00
0005433788205	11162	Economy	24600.00
0005435548441	11162	Economy	24600.00
0005435548426	11162	Economy	24600.00
0005435548481	20668	Economy	27100.00
0005435548477	20668	Economy	24600.00
0005435548476	20668	Economy	24600.00
0005433788146	20668	Economy	24600.00
0005435548482	20668	Economy	24600.00
0005433788147	20668	Economy	24600.00
0005435548480	20668	Economy	24600.00
0005435548478	20668	Economy	24600.00
0005435548479	20668	Economy	24600.00
0005435548474	20668	Economy	24600.00
0005433788145	20668	Economy	24600.00
0005435548483	20668	Economy	24600.00
0005435548475	20668	Economy	24600.00
0005435517757	11421	Business	20200.00
0005435540878	11421	Business	20200.00
0005435540779	11421	Business	20200.00
0005435517737	11421	Business	20200.00
0005435517730	11421	Business	20200.00
0005435517670	11421	Business	20200.00
0005435540808	11421	Economy	6700.00
0005435517693	11421	Economy	6700.00
0005435517731	11421	Economy	6700.00
0005435517782	11421	Economy	6700.00
0005435540734	11421	Economy	7400.00
0005435517671	11421	Economy	7400.00
0005435517735	11421	Economy	7400.00
0005435517690	11421	Economy	6700.00
0005435540877	11421	Economy	6700.00
0005435540689	11421	Economy	6700.00
0005435517695	11421	Economy	6700.00
0005435540688	11421	Economy	6700.00
0005435540736	11421	Economy	6700.00
0005435540767	11421	Economy	6700.00
0005435540792	11421	Economy	6700.00
0005435517694	11421	Economy	6700.00
0005435540770	11421	Economy	6700.00
0005435517697	11421	Economy	6700.00
0005435540807	11421	Economy	6700.00
0005435540860	11421	Economy	6700.00
0005435540818	11421	Economy	6700.00
0005435540787	11421	Economy	6700.00
0005435540788	11421	Economy	6700.00
0005435540789	11421	Economy	6700.00
0005435540786	11421	Economy	6700.00
0005435540785	11421	Economy	6700.00
0005435517760	11421	Economy	6700.00
0005435517701	11421	Economy	6700.00
0005435540771	11421	Economy	6700.00
0005435517721	11421	Economy	6700.00
0005435517783	11421	Economy	6700.00
0005435517717	11421	Economy	6700.00
0005435540720	11421	Economy	6700.00
0005435540744	11421	Economy	6700.00
0005435517682	11421	Economy	6700.00
0005435517691	11421	Economy	6700.00
0005435540745	11421	Economy	6700.00
0005435517702	11421	Economy	6700.00
0005435517696	11421	Economy	6700.00
0005435517692	11421	Economy	6700.00
0005435540773	11421	Economy	6700.00
0005435540809	11421	Economy	6700.00
0005435540857	11421	Economy	6700.00
0005435517663	11421	Economy	6700.00
0005435529190	22236	Business	20200.00
0005435529191	22236	Business	20200.00
0005435529203	22236	Business	20200.00
0005435540938	22236	Business	20200.00
0005435540943	22236	Business	20200.00
0005435540942	22236	Business	20200.00
0005435529205	22236	Business	20200.00
0005435529204	22236	Economy	6700.00
0005435540940	22236	Economy	6700.00
0005435540950	22236	Economy	6700.00
0005435529210	22236	Economy	7400.00
0005435540951	22236	Economy	7400.00
0005435529202	22236	Economy	7400.00
0005435529193	22236	Economy	7400.00
0005435540954	22236	Economy	6700.00
0005435540946	22236	Economy	6700.00
0005435540937	22236	Economy	6700.00
0005435529200	22236	Economy	6700.00
0005435529207	22236	Economy	6700.00
0005435529199	22236	Economy	6700.00
0005435529197	22236	Economy	6700.00
0005435540949	22236	Economy	6700.00
0005435540941	22236	Economy	6700.00
0005435540935	22236	Economy	6700.00
0005435540953	22236	Economy	6700.00
0005435540948	22236	Economy	6700.00
0005435540945	22236	Economy	6700.00
0005435529201	22236	Economy	6700.00
0005435529195	22236	Economy	6700.00
0005435529189	22236	Economy	6700.00
0005435540939	22236	Economy	6700.00
0005432294480	22236	Economy	6700.00
0005435540934	22236	Economy	6700.00
0005435529206	22236	Economy	6700.00
0005435529198	22236	Economy	6700.00
0005435529194	22236	Economy	6700.00
0005435529208	22236	Economy	6700.00
0005435540947	22236	Economy	6700.00
0005435540933	22236	Economy	6700.00
0005435540952	22236	Economy	6700.00
0005435540936	22236	Economy	6700.00
0005435529209	22236	Economy	6700.00
0005435529196	22236	Economy	6700.00
0005435540944	22236	Economy	6700.00
0005435529192	22236	Economy	6700.00
0005432294479	22236	Economy	6700.00
0005432294481	22236	Economy	6700.00
0005433251224	2283	Business	20200.00
0005434907187	2283	Business	20200.00
0005433251167	2283	Business	20200.00
0005434907186	2283	Business	20200.00
0005434907170	2283	Business	20200.00
0005433251139	2283	Business	20200.00
0005434907199	2283	Business	20200.00
0005433400962	2283	Business	20200.00
0005433251291	2283	Business	20200.00
0005433251022	2283	Business	20200.00
0005434907204	2283	Business	20200.00
0005433251084	2283	Business	20200.00
0005433251271	2283	Economy	6700.00
0005434907177	2283	Economy	6700.00
0005434907195	2283	Economy	6700.00
0005434907168	2283	Economy	6700.00
0005433250981	2283	Economy	6700.00
0005434907178	2283	Economy	6700.00
0005434907188	2283	Economy	6700.00
0005434907189	2283	Economy	6700.00
0005433251159	2283	Economy	6700.00
0005433400959	2283	Economy	7400.00
0005434907181	2283	Economy	7400.00
0005433251262	2283	Economy	7400.00
0005433251231	2283	Economy	7400.00
0005434907164	2283	Economy	7400.00
0005434907167	2283	Economy	6700.00
0005434907180	2283	Economy	6700.00
0005434907202	2283	Economy	6700.00
0005434907193	2283	Economy	6700.00
0005434907165	2283	Economy	6700.00
0005433251188	2283	Economy	6700.00
0005433400961	2283	Economy	6700.00
0005433251166	2283	Economy	6700.00
0005434907209	2283	Economy	6700.00
0005434907207	2283	Economy	6700.00
0005434907173	2283	Economy	6700.00
0005434907171	2283	Economy	6700.00
0005433251110	2283	Economy	6700.00
0005434907197	2283	Economy	6700.00
0005434907179	2283	Economy	6700.00
0005434907203	2283	Economy	6700.00
0005433251232	2283	Economy	6700.00
0005433251194	2283	Economy	6700.00
0005434907213	2283	Economy	6700.00
0005433400933	2283	Economy	6700.00
0005433251223	2283	Economy	6700.00
0005434907172	2283	Economy	6700.00
0005434907192	2283	Economy	6700.00
0005433251212	2283	Economy	6700.00
0005434907191	2283	Economy	6700.00
0005433251187	2283	Economy	6700.00
0005434907206	2283	Economy	6700.00
0005434907208	2283	Economy	6700.00
0005434907201	2283	Economy	6700.00
0005433251242	2283	Economy	6700.00
0005434907162	2283	Economy	6700.00
0005434907196	2283	Economy	6700.00
0005434907190	2283	Economy	6700.00
0005434907166	2283	Economy	6700.00
0005433251136	2283	Economy	6700.00
0005434907211	2283	Economy	6700.00
0005434907183	2283	Economy	6700.00
0005434907176	2283	Economy	6700.00
0005434907212	2283	Economy	6700.00
0005434907184	2283	Economy	6700.00
0005433251200	2283	Economy	6700.00
0005434907194	2283	Economy	6700.00
0005433251257	2283	Economy	6700.00
0005434907163	2283	Economy	6700.00
0005434907169	2283	Economy	6700.00
0005434907174	2283	Economy	6700.00
0005434907182	2283	Economy	6700.00
0005434907175	2283	Economy	6700.00
0005433251189	2283	Economy	6700.00
0005434907205	2283	Economy	6700.00
0005433251135	2283	Economy	6700.00
0005434907185	2283	Economy	6700.00
0005434907161	2283	Economy	6700.00
0005433251122	2283	Economy	6700.00
0005434907210	2283	Economy	6700.00
0005434907198	2283	Economy	6700.00
0005433250980	2283	Economy	6700.00
0005433251119	2283	Economy	6700.00
0005433251261	2283	Economy	6700.00
0005433251111	2283	Economy	6700.00
0005434907200	2283	Economy	6700.00
0005433251118	2283	Economy	6700.00
0005433251423	25576	Business	20200.00
0005434906724	25576	Business	20200.00
0005434906369	25576	Business	20200.00
0005434906507	25576	Business	20200.00
0005434906659	25576	Business	20200.00
0005434906625	25576	Business	20200.00
0005433251408	25576	Business	20200.00
0005434906497	25576	Business	20200.00
0005434906755	25576	Business	20200.00
0005433251421	25576	Business	20200.00
0005433251401	25576	Business	20200.00
0005433251428	25576	Business	20200.00
0005434906513	25576	Economy	6700.00
0005433251402	25576	Economy	6700.00
0005434906737	25576	Economy	6700.00
0005434906595	25576	Economy	6700.00
0005434906664	25576	Economy	6700.00
0005433251422	25576	Economy	6700.00
0005434906386	25576	Economy	6700.00
0005434906650	25576	Economy	6700.00
0005434906634	25576	Economy	6700.00
0005434906620	25576	Economy	7400.00
0005433251429	25576	Economy	7400.00
0005434906631	25576	Economy	7400.00
0005434906686	25576	Economy	7400.00
0005433251404	25576	Economy	7400.00
0005433251409	25576	Economy	6700.00
0005434906547	25576	Economy	6700.00
0005434906656	25576	Economy	6700.00
0005434906610	25576	Economy	6700.00
0005434906719	25576	Economy	6700.00
0005434906761	25576	Economy	6700.00
0005434906649	25576	Economy	6700.00
0005433251417	25576	Economy	6700.00
0005434906385	25576	Economy	6700.00
0005433251403	25576	Economy	6700.00
0005434906720	25576	Economy	6700.00
0005433251418	25576	Economy	6700.00
0005434906642	25576	Economy	6700.00
0005434906662	25576	Economy	6700.00
0005434906537	25576	Economy	6700.00
0005434906589	25576	Economy	6700.00
0005433400978	25576	Economy	6700.00
0005434906527	25576	Economy	6700.00
0005434906672	25576	Economy	6700.00
0005433251426	25576	Economy	6700.00
0005433251419	25576	Economy	6700.00
0005433400977	25576	Economy	6700.00
0005433251415	25576	Economy	6700.00
0005434906475	25576	Economy	6700.00
0005434906498	25576	Economy	6700.00
0005433251407	25576	Economy	6700.00
0005433251405	25576	Economy	6700.00
0005433251427	25576	Economy	6700.00
0005434906661	25576	Economy	6700.00
0005434906714	25576	Economy	6700.00
0005434906641	25576	Economy	6700.00
0005434906660	25576	Economy	6700.00
0005434906593	25576	Economy	6700.00
0005434906608	25576	Economy	6700.00
0005434906627	25576	Economy	6700.00
0005433400976	25576	Economy	6700.00
0005434906723	25576	Economy	6700.00
0005433251424	25576	Economy	6700.00
0005433251431	25576	Economy	6700.00
0005433251406	25576	Economy	6700.00
0005434906626	25576	Economy	6700.00
0005434906499	25576	Economy	6700.00
0005433251432	25576	Economy	6700.00
0005434906588	25576	Economy	6700.00
0005433251412	25576	Economy	6700.00
0005434906806	25576	Economy	6700.00
0005434906609	25576	Economy	6700.00
0005433251420	25576	Economy	6700.00
0005434906546	25576	Economy	6700.00
0005433251410	25576	Economy	6700.00
0005434906594	25576	Economy	6700.00
0005434906713	25576	Economy	6700.00
0005434906548	25576	Economy	6700.00
0005434906710	25576	Economy	6700.00
0005434906500	25576	Economy	6700.00
0005433251416	25576	Economy	6700.00
0005433251425	25576	Economy	6700.00
0005433251414	25576	Economy	6700.00
0005433251430	25576	Economy	6700.00
0005434906813	25576	Economy	6700.00
0005433251411	25576	Economy	6700.00
0005434906622	25576	Economy	6700.00
0005434906485	25576	Economy	6700.00
0005433251413	25576	Economy	6700.00
0005434906801	25576	Economy	6700.00
0005432621010	2500	Economy	13600.00
0005432621016	2500	Economy	12400.00
0005432621015	2500	Economy	12400.00
0005432621006	2500	Economy	12400.00
0005432621009	2500	Economy	12400.00
0005432621008	2500	Economy	12400.00
0005432621003	2500	Economy	12400.00
0005432621013	2500	Economy	12400.00
0005432862215	2500	Economy	12400.00
0005432621011	2500	Economy	12400.00
0005432862214	2500	Economy	12400.00
0005432621007	2500	Economy	12400.00
0005432621012	2500	Economy	12400.00
0005432621005	2500	Economy	12400.00
0005432621004	2500	Economy	12400.00
0005432862241	2500	Economy	12400.00
0005432862240	2500	Economy	12400.00
0005432621014	2500	Economy	12400.00
0005432862284	28082	Economy	13600.00
0005432620927	28082	Economy	13600.00
0005432620838	28082	Economy	13600.00
0005432620950	28082	Economy	12400.00
0005432620916	28082	Economy	12400.00
0005432620860	28082	Economy	12400.00
0005432620980	28082	Economy	12400.00
0005432620874	28082	Economy	12400.00
0005432620868	28082	Economy	12400.00
0005432620866	28082	Economy	12400.00
0005432862288	28082	Economy	12400.00
0005432862287	28082	Economy	12400.00
0005432620873	28082	Economy	12400.00
0005432620928	28082	Economy	12400.00
0005432862286	28082	Economy	12400.00
0005432620859	28082	Economy	12400.00
0005432620906	28082	Economy	12400.00
0005432620837	28082	Economy	12400.00
0005432620917	28082	Economy	12400.00
0005432620869	28082	Economy	12400.00
0005432620849	28082	Economy	12400.00
0005432620897	28082	Economy	12400.00
0005432620949	28082	Economy	12400.00
0005432862285	28082	Economy	12400.00
0005432862289	28082	Economy	12400.00
0005432620896	28082	Economy	12400.00
0005434097460	11694	Economy	11300.00
0005433452735	31086	Economy	8400.00
0005433454858	31403	Economy	8400.00
0005433452715	31403	Economy	8400.00
0005434142566	11983	Economy	7200.00
0005434184639	11983	Economy	6600.00
0005433129220	11983	Economy	6600.00
0005433129207	11983	Economy	6600.00
0005434184637	11983	Economy	6600.00
0005434184640	11983	Economy	6600.00
0005434184651	11983	Economy	6600.00
0005433129208	11983	Economy	6600.00
0005434184650	11983	Economy	6600.00
0005433134091	11983	Economy	6600.00
0005434142568	11983	Economy	6600.00
0005434184638	11983	Economy	6600.00
0005433131697	29811	Economy	7200.00
0005433131699	29811	Economy	7200.00
0005434184660	29811	Economy	7200.00
0005434142602	29811	Economy	6600.00
0005434142599	29811	Economy	6600.00
0005433134126	29811	Economy	6600.00
0005433134130	29811	Economy	6600.00
0005433134128	29811	Economy	6600.00
0005434326263	29811	Economy	6600.00
0005434142601	29811	Economy	6600.00
0005433131696	29811	Economy	6600.00
0005434142597	29811	Economy	6600.00
0005434183576	29811	Economy	6600.00
0005434184661	29811	Economy	6600.00
0005434326262	29811	Economy	6600.00
0005433134127	29811	Economy	6600.00
0005433131698	29811	Economy	6600.00
0005433131700	29811	Economy	6600.00
0005433134129	29811	Economy	6600.00
0005434142600	29811	Economy	6600.00
0005434142598	29811	Economy	6600.00
0005435798922	21299	Economy	15700.00
0005435798925	21299	Economy	15700.00
0005435798927	21299	Economy	15700.00
0005435798919	21299	Economy	15700.00
0005435798926	21299	Economy	15700.00
0005435798930	21299	Economy	15700.00
0005435798923	21299	Economy	15700.00
0005435697258	16486	Economy	19900.00
0005435697263	16486	Economy	19900.00
0005435697260	16486	Economy	19900.00
0005435697274	16486	Economy	18100.00
0005435697264	16486	Economy	18100.00
0005435697247	16486	Economy	18100.00
0005435697267	16486	Economy	18100.00
0005435697261	16486	Economy	18100.00
0005435697254	16486	Economy	18100.00
0005435935012	16486	Economy	18100.00
0005435697251	16486	Economy	18100.00
0005435697273	16486	Economy	18100.00
0005435697270	16486	Economy	18100.00
0005435935015	16486	Economy	18100.00
0005435697253	16486	Economy	18100.00
0005435697266	16486	Economy	18100.00
0005435697245	16486	Economy	18100.00
0005435935014	16486	Economy	18100.00
0005435697255	16486	Economy	18100.00
0005435935013	16486	Economy	18100.00
0005435697252	16486	Economy	18100.00
0005435697272	16486	Economy	18100.00
0005435697268	16486	Economy	18100.00
0005435697256	16486	Economy	18100.00
0005435697249	16486	Economy	18100.00
0005435697262	16486	Economy	18100.00
0005435697269	16486	Economy	18100.00
0005435697248	16486	Economy	18100.00
0005435934998	16486	Economy	18100.00
0005435697246	16486	Economy	18100.00
0005435697271	16486	Economy	18100.00
0005435697265	16486	Economy	18100.00
0005435697250	16486	Economy	18100.00
0005435935011	16486	Economy	18100.00
0005435697259	16486	Economy	18100.00
0005435697257	16486	Economy	18100.00
0005435696994	24735	Economy	19900.00
0005435697068	24735	Economy	19900.00
0005435697193	24735	Economy	19900.00
0005435697069	24735	Economy	18100.00
0005435697017	24735	Economy	18100.00
0005435697118	24735	Economy	18100.00
0005435697143	24735	Economy	18100.00
0005435697057	24735	Economy	18100.00
0005435697055	24735	Economy	18100.00
0005435697175	24735	Economy	18100.00
0005435697002	24735	Economy	18100.00
0005435696993	24735	Economy	18100.00
0005435696921	24735	Economy	18100.00
0005435935039	24735	Economy	18100.00
0005435696879	24735	Economy	18100.00
0005435697039	24735	Economy	18100.00
0005435697001	24735	Economy	18100.00
0005435697103	24735	Economy	18100.00
0005435697054	24735	Economy	18100.00
0005435697056	24735	Economy	18100.00
0005435935040	24735	Economy	18100.00
0005435697194	24735	Economy	18100.00
0005435696944	24735	Economy	18100.00
0005435697158	24735	Economy	18100.00
0005435697070	24735	Economy	18100.00
0005435696920	24735	Economy	18100.00
0005435696878	24735	Economy	18100.00
0005435696986	24735	Economy	18100.00
0005435697022	24735	Economy	18100.00
0005435696991	24735	Economy	18100.00
0005435697018	24735	Economy	18100.00
0005435697121	24735	Economy	18100.00
0005435697176	24735	Economy	18100.00
0005435697116	24735	Economy	18100.00
0005435935038	24735	Economy	18100.00
0005435935041	24735	Economy	18100.00
0005435696938	24735	Economy	18100.00
0005435697016	24735	Economy	18100.00
0005435697119	24735	Economy	18100.00
0005433724792	18785	Economy	4400.00
0005433724795	18785	Economy	4400.00
0005432968813	18785	Economy	4400.00
0005433724793	18785	Economy	4400.00
0005432968814	18785	Economy	4400.00
0005433724794	18785	Economy	4400.00
0005433724741	21632	Economy	4400.00
0005433724748	21632	Economy	4400.00
0005433724742	21632	Economy	4400.00
0005432968838	21632	Economy	4400.00
0005433724757	21632	Economy	4400.00
0005432968837	21632	Economy	4400.00
0005433724758	21632	Economy	4400.00
0005434137988	7291	Business	23100.00
0005434138004	7291	Business	23100.00
0005434137992	7291	Business	23100.00
0005434137987	7291	Business	23100.00
0005434138031	7291	Business	23100.00
0005434087505	7291	Business	23100.00
0005434138034	7291	Business	23100.00
0005434138000	7291	Business	23100.00
0005434137984	7291	Business	23100.00
0005434137980	7291	Business	23100.00
0005434137998	7291	Business	23100.00
0005434138026	7291	Business	23100.00
0005434137965	7291	Economy	7700.00
0005434087502	7291	Economy	7700.00
0005434137983	7291	Economy	7700.00
0005434137961	7291	Economy	7700.00
0005434137994	7291	Economy	7700.00
0005434138016	7291	Economy	7700.00
0005434138011	7291	Economy	7700.00
0005434137972	7291	Economy	8500.00
0005434137955	7291	Economy	8500.00
0005434137971	7291	Economy	8500.00
0005434137966	7291	Economy	8500.00
0005434138015	7291	Economy	8500.00
0005434138024	7291	Economy	7700.00
0005434138001	7291	Economy	7700.00
0005434137970	7291	Economy	7700.00
0005434138029	7291	Economy	7700.00
0005434138010	7291	Economy	7700.00
0005434137995	7291	Economy	7700.00
0005434137982	7291	Economy	7700.00
0005434138023	7291	Economy	7700.00
0005434138021	7291	Economy	7700.00
0005434138032	7291	Economy	7700.00
0005434137989	7291	Economy	7700.00
0005434137973	7291	Economy	7700.00
0005434137997	7291	Economy	7700.00
0005434137985	7291	Economy	7700.00
0005434138017	7291	Economy	7700.00
0005434138009	7291	Economy	7700.00
0005434138014	7291	Economy	7700.00
0005434137954	7291	Economy	7700.00
0005434137976	7291	Economy	7700.00
0005434138013	7291	Economy	7700.00
0005434137957	7291	Economy	7700.00
0005434137990	7291	Economy	7700.00
0005434137964	7291	Economy	7700.00
0005434138019	7291	Economy	7700.00
0005434137960	7291	Economy	7700.00
0005434138012	7291	Economy	7700.00
0005434138007	7291	Economy	7700.00
0005434138006	7291	Economy	7700.00
0005434138005	7291	Economy	7700.00
0005434138027	7291	Economy	7700.00
0005434137977	7291	Economy	7700.00
0005434137968	7291	Economy	7700.00
0005434137993	7291	Economy	7700.00
0005434087501	7291	Economy	7700.00
0005434137953	7291	Economy	7700.00
0005434137991	7291	Economy	7700.00
0005434138008	7291	Economy	7700.00
0005434087504	7291	Economy	7700.00
0005434087503	7291	Economy	7700.00
0005434137975	7291	Economy	7700.00
0005434137978	7291	Economy	7700.00
0005434137986	7291	Economy	7700.00
0005434138018	7291	Economy	7700.00
0005434138030	7291	Economy	7700.00
0005434137996	7291	Economy	7700.00
0005434137999	7291	Economy	7700.00
0005434138020	7291	Economy	7700.00
0005434137956	7291	Economy	7700.00
0005434138025	7291	Economy	7700.00
0005434138002	7291	Economy	7700.00
0005434138033	7291	Economy	7700.00
0005434137981	7291	Economy	7700.00
0005434137979	7291	Economy	7700.00
0005434137974	7291	Economy	7700.00
0005434138028	7291	Economy	7700.00
0005434137962	7291	Economy	7700.00
0005434137969	7291	Economy	7700.00
0005434137963	7291	Economy	7700.00
0005434138022	7291	Economy	7700.00
0005434137959	7291	Economy	7700.00
0005434138003	7291	Economy	7700.00
0005434137967	7291	Economy	7700.00
0005434137958	7291	Economy	7700.00
0005434137257	28557	Business	23100.00
0005434136902	28557	Business	23100.00
0005434137220	28557	Business	23100.00
0005434137265	28557	Business	23100.00
0005434137164	28557	Business	23100.00
0005434137273	28557	Business	23100.00
0005434137048	28557	Business	23100.00
0005434137139	28557	Business	23100.00
0005434137527	28557	Business	23100.00
0005434136981	28557	Business	23100.00
0005434136868	28557	Business	23100.00
0005434136883	28557	Economy	7700.00
0005434136859	28557	Economy	7700.00
0005434136955	28557	Economy	7700.00
0005434137401	28557	Economy	7700.00
0005434136855	28557	Economy	7700.00
0005434137009	28557	Economy	7700.00
0005434136995	28557	Economy	7700.00
0005434137221	28557	Economy	7700.00
0005434137250	28557	Economy	7700.00
0005434137157	28557	Economy	8500.00
0005434137003	28557	Economy	8500.00
0005434136854	28557	Economy	8500.00
0005434136870	28557	Economy	8500.00
0005434137266	28557	Economy	7700.00
0005434137049	28557	Economy	7700.00
0005434136757	28557	Economy	7700.00
0005434137138	28557	Economy	7700.00
0005434137417	28557	Economy	7700.00
0005434137004	28557	Economy	7700.00
0005434137036	28557	Economy	7700.00
0005434137274	28557	Economy	7700.00
0005434137205	28557	Economy	7700.00
0005434087470	28557	Economy	7700.00
0005434137400	28557	Economy	7700.00
0005434137159	28557	Economy	7700.00
0005434137050	28557	Economy	7700.00
0005434137106	28557	Economy	7700.00
0005434137370	28557	Economy	7700.00
0005434137170	28557	Economy	7700.00
0005434137121	28557	Economy	7700.00
0005434136903	28557	Economy	7700.00
0005434087461	28557	Economy	7700.00
0005434087462	28557	Economy	7700.00
0005434137264	28557	Economy	7700.00
0005434136869	28557	Economy	7700.00
0005434087459	28557	Economy	7700.00
0005434137024	28557	Economy	7700.00
0005434137218	28557	Economy	7700.00
0005434137077	28557	Economy	7700.00
0005434137149	28557	Economy	7700.00
0005434137133	28557	Economy	7700.00
0005434137204	28557	Economy	7700.00
0005434137114	28557	Economy	7700.00
0005434137148	28557	Economy	7700.00
0005434137132	28557	Economy	7700.00
0005434137189	28557	Economy	7700.00
0005434137054	28557	Economy	7700.00
0005434137369	28557	Economy	7700.00
0005434137530	28557	Economy	7700.00
0005434137270	28557	Economy	7700.00
0005434137031	28557	Economy	7700.00
0005434136860	28557	Economy	7700.00
0005434137203	28557	Economy	7700.00
0005434137364	28557	Economy	7700.00
0005434137480	28557	Economy	7700.00
0005434137300	28557	Economy	7700.00
0005434087471	28557	Economy	7700.00
0005434087460	28557	Economy	7700.00
0005434137187	28557	Economy	7700.00
0005434137228	28557	Economy	7700.00
0005434137366	28557	Economy	7700.00
0005434137365	28557	Economy	7700.00
0005434137039	28557	Economy	7700.00
0005434137275	28557	Economy	7700.00
0005434137100	28557	Economy	7700.00
0005434137368	28557	Economy	7700.00
0005434137158	28557	Economy	7700.00
0005434137040	28557	Economy	7700.00
0005434136788	28557	Economy	7700.00
0005434137147	28557	Economy	7700.00
0005434137078	28557	Economy	7700.00
0005434137325	28557	Economy	7700.00
0005434137229	28557	Economy	7700.00
0005434137372	28557	Economy	7700.00
0005434136994	28557	Economy	7700.00
0005434137105	28557	Economy	7700.00
0005434136957	28557	Economy	7700.00
0005434137076	28557	Economy	7700.00
0005435808219	1934	Economy	23900.00
0005435808210	1934	Economy	23900.00
0005435808212	1934	Economy	21700.00
0005435808209	1934	Economy	21700.00
0005434610223	1934	Economy	21700.00
0005433407499	1934	Economy	21700.00
0005433407517	1934	Economy	21700.00
0005435808216	1934	Economy	21700.00
0005435808215	1934	Economy	21700.00
0005434610220	1934	Economy	21700.00
0005433407493	1934	Economy	21700.00
0005433407500	1934	Economy	21700.00
0005434610221	1934	Economy	21700.00
0005435808218	1934	Economy	21700.00
0005433407498	1934	Economy	21700.00
0005435808211	1934	Economy	21700.00
0005433407492	1934	Economy	21700.00
0005434610222	1934	Economy	21700.00
0005435808217	1934	Economy	21700.00
0005435808214	1934	Economy	21700.00
0005435808220	1934	Economy	21700.00
0005435808213	1934	Economy	21700.00
0005433407552	23114	Economy	23900.00
0005435808110	23114	Economy	23900.00
0005435808129	23114	Economy	23900.00
0005434610193	23114	Economy	23900.00
0005433407542	23114	Economy	21700.00
0005433407545	23114	Economy	21700.00
0005435808107	23114	Economy	21700.00
0005435808101	23114	Economy	21700.00
0005435808109	23114	Economy	21700.00
0005433407546	23114	Economy	21700.00
0005434610208	23114	Economy	21700.00
0005435808105	23114	Economy	21700.00
0005435808086	23114	Economy	21700.00
0005435808068	23114	Economy	21700.00
0005433407549	23114	Economy	21700.00
0005435808078	23114	Economy	21700.00
0005433407540	23114	Economy	21700.00
0005433407553	23114	Economy	21700.00
0005435808098	23114	Economy	21700.00
0005434610200	23114	Economy	21700.00
0005433407550	23114	Economy	21700.00
0005433407544	23114	Economy	21700.00
0005435808080	23114	Economy	21700.00
0005435808081	23114	Economy	21700.00
0005435808155	23114	Economy	21700.00
0005433407554	23114	Economy	21700.00
0005435808125	23114	Economy	21700.00
0005435808133	23114	Economy	21700.00
0005433407543	23114	Economy	21700.00
0005433407551	23114	Economy	21700.00
0005435808106	23114	Economy	21700.00
0005435808049	23114	Economy	21700.00
0005435808130	23114	Economy	21700.00
0005435808112	23114	Economy	21700.00
0005433407547	23114	Economy	21700.00
0005435808074	23114	Economy	21700.00
0005435808124	23114	Economy	21700.00
0005435808135	23114	Economy	21700.00
0005435808103	23114	Economy	21700.00
0005435808108	23114	Economy	21700.00
0005435808154	23114	Economy	21700.00
0005435808079	23114	Economy	21700.00
0005433407539	23114	Economy	21700.00
0005435808134	23114	Economy	21700.00
0005433407541	23114	Economy	21700.00
0005434610191	23114	Economy	21700.00
0005433407548	23114	Economy	21700.00
0005435808095	23114	Economy	21700.00
0005435808075	23114	Economy	21700.00
0005434503757	16679	Economy	7600.00
0005434503715	16679	Economy	7600.00
0005434503674	16679	Economy	7600.00
0005434503711	16679	Economy	7600.00
0005434503681	16679	Economy	6900.00
0005434503622	16679	Economy	6900.00
0005434503487	16679	Economy	6900.00
0005434503619	16679	Economy	6900.00
0005434503714	16679	Economy	6900.00
0005434503759	16679	Economy	6900.00
0005434503726	16679	Economy	6900.00
0005434503645	16679	Economy	6900.00
0005434503667	16679	Economy	6900.00
0005434503545	16679	Economy	6900.00
0005434503644	16679	Economy	6900.00
0005434503846	16679	Economy	6900.00
0005434503710	16679	Economy	6900.00
0005434503811	16679	Economy	6900.00
0005434503745	16679	Economy	6900.00
0005434503662	16679	Economy	6900.00
0005434503718	16679	Economy	6900.00
0005434503533	16679	Economy	6900.00
0005434503854	16679	Economy	6900.00
0005434503584	16679	Economy	6900.00
0005434503554	16679	Economy	6900.00
0005434503544	16679	Economy	6900.00
0005434503827	16679	Economy	6900.00
0005434503500	16679	Economy	6900.00
0005434503546	16679	Economy	6900.00
0005434503651	16679	Economy	6900.00
0005434503733	16679	Economy	6900.00
0005434503767	16679	Economy	6900.00
0005434503661	16679	Economy	6900.00
0005434503744	16679	Economy	6900.00
0005434503702	16679	Economy	6900.00
0005434503812	16679	Economy	6900.00
0005434503697	16679	Economy	6900.00
0005434503701	16679	Economy	6900.00
0005434503768	16679	Economy	6900.00
0005434503847	16679	Economy	6900.00
0005434503501	16679	Economy	6900.00
0005434503574	16679	Economy	6900.00
0005434503712	16679	Economy	6900.00
0005434503620	16679	Economy	6900.00
0005434503670	16679	Economy	6900.00
0005434503732	16679	Economy	6900.00
0005434504046	22933	Economy	7600.00
0005434504043	22933	Economy	7600.00
0005434504036	22933	Economy	7600.00
0005434504032	22933	Economy	7600.00
0005434504047	22933	Economy	6900.00
0005434504050	22933	Economy	6900.00
0005434504049	22933	Economy	6900.00
0005434504027	22933	Economy	6900.00
0005434504034	22933	Economy	6900.00
0005434504052	22933	Economy	6900.00
0005434504028	22933	Economy	6900.00
0005434504040	22933	Economy	6900.00
0005434504026	22933	Economy	6900.00
0005434504053	22933	Economy	6900.00
0005434504039	22933	Economy	6900.00
0005434504023	22933	Economy	6900.00
0005434504024	22933	Economy	6900.00
0005434504061	22933	Economy	6900.00
0005434504056	22933	Economy	6900.00
0005434504029	22933	Economy	6900.00
0005434504022	22933	Economy	6900.00
0005434504033	22933	Economy	6900.00
0005434504060	22933	Economy	6900.00
0005434504042	22933	Economy	6900.00
0005434504025	22933	Economy	6900.00
0005434504058	22933	Economy	6900.00
0005434504044	22933	Economy	6900.00
0005434504045	22933	Economy	6900.00
0005434504059	22933	Economy	6900.00
0005434504054	22933	Economy	6900.00
0005434504055	22933	Economy	6900.00
0005434504030	22933	Economy	6900.00
0005434504041	22933	Economy	6900.00
0005434504037	22933	Economy	6900.00
0005434504038	22933	Economy	6900.00
0005434504057	22933	Economy	6900.00
0005434504048	22933	Economy	6900.00
0005434504035	22933	Economy	6900.00
0005434504051	22933	Economy	6900.00
0005434504031	22933	Economy	6900.00
0005435078310	2213	Economy	7700.00
0005433266597	2213	Economy	7700.00
0005433266604	2213	Economy	7000.00
0005433266620	2213	Economy	7000.00
0005435078315	2213	Economy	7000.00
0005435078314	2213	Economy	7000.00
0005433266611	2213	Economy	7000.00
0005435078304	2213	Economy	7000.00
0005433266657	2213	Economy	7000.00
0005435078311	2213	Economy	7000.00
0005433266610	2213	Economy	7000.00
0005435078309	2213	Economy	7000.00
0005433266605	2213	Economy	7000.00
0005435078305	2213	Economy	7000.00
0005435078316	2213	Economy	7000.00
0005435078308	2213	Economy	7000.00
0005433266591	2213	Economy	7000.00
0005433266590	2213	Economy	7000.00
0005433266627	2213	Economy	7000.00
0005433266642	2213	Economy	7000.00
0005435078312	2213	Economy	7000.00
0005435078317	2213	Economy	7000.00
0005435078307	2213	Economy	7000.00
0005433266618	2213	Economy	7000.00
0005435078313	2213	Economy	7000.00
0005435078306	2213	Economy	7000.00
0005433266638	2213	Economy	7000.00
0005433266616	2213	Economy	7000.00
0005435078220	24339	Economy	7700.00
0005435078134	24339	Economy	7000.00
0005435078175	24339	Economy	7000.00
0005435078210	24339	Economy	7000.00
0005433266701	24339	Economy	7000.00
0005433266705	24339	Economy	7000.00
0005435078118	24339	Economy	7000.00
0005435078239	24339	Economy	7000.00
0005435078117	24339	Economy	7000.00
0005435078211	24339	Economy	7000.00
0005433266702	24339	Economy	7000.00
0005433266704	24339	Economy	7000.00
0005435078133	24339	Economy	7000.00
0005433266707	24339	Economy	7000.00
0005433266703	24339	Economy	7000.00
0005435078189	24339	Economy	7000.00
0005435078177	24339	Economy	7000.00
0005435078158	24339	Economy	7000.00
0005433266706	24339	Economy	7000.00
0005435078237	24339	Economy	7000.00
0005435078174	24339	Economy	7000.00
0005435078219	24339	Economy	7000.00
0005433266708	24339	Economy	7000.00
0005434988712	6609	Economy	10800.00
0005434988714	6609	Economy	9800.00
0005434988713	6609	Economy	9800.00
0005434988720	6609	Economy	9800.00
0005434988721	6609	Economy	9800.00
0005435464486	6609	Economy	9800.00
0005434988711	6609	Economy	9800.00
0005434988719	6609	Economy	9800.00
0005434988718	6609	Economy	9800.00
0005435464485	6609	Economy	9800.00
0005435803258	6609	Economy	9800.00
0005434988715	6609	Economy	9800.00
0005435464484	6609	Economy	9800.00
0005435803259	6609	Economy	9800.00
0005434988717	6609	Economy	9800.00
0005434988710	6609	Economy	9800.00
0005434988716	6609	Economy	9800.00
0005434988591	23585	Economy	9800.00
0005434988601	23585	Economy	9800.00
0005434988593	23585	Economy	9800.00
0005435464502	23585	Economy	9800.00
0005434988592	23585	Economy	9800.00
0005434988573	23585	Economy	9800.00
0005434988600	23585	Economy	9800.00
0005434988602	23585	Economy	9800.00
0005434988555	23585	Economy	9800.00
0005434988590	23585	Economy	9800.00
0005435464503	23585	Economy	9800.00
0005434988599	23585	Economy	9800.00
0005434988574	23585	Economy	9800.00
0005433449922	30509	Business	9900.00
0005432383097	30509	Business	9900.00
0005433449933	30509	Business	9900.00
0005433449937	30509	Business	9900.00
0005433449923	30509	Business	9900.00
0005432383107	30509	Business	9900.00
0005433449928	30509	Economy	3300.00
0005432383122	30509	Economy	3300.00
0005433454870	30509	Economy	3300.00
0005433449929	30509	Economy	3300.00
0005433449938	30509	Economy	3300.00
0005433449919	30509	Economy	3600.00
0005432383114	30509	Economy	3600.00
0005432383115	30509	Economy	3600.00
0005432383112	30509	Economy	3300.00
0005432383126	30509	Economy	3300.00
0005433449934	30509	Economy	3300.00
0005432383125	30509	Economy	3300.00
0005432383123	30509	Economy	3300.00
0005433453760	30509	Economy	3300.00
0005432383119	30509	Economy	3300.00
0005432383124	30509	Economy	3300.00
0005432383128	30509	Economy	3300.00
0005432383109	30509	Economy	3300.00
0005432383096	30509	Economy	3300.00
0005433449939	30509	Economy	3300.00
0005432383101	30509	Economy	3300.00
0005432383118	30509	Economy	3300.00
0005433449930	30509	Economy	3300.00
0005433449921	30509	Economy	3300.00
0005432383102	30509	Economy	3300.00
0005433449935	30509	Economy	3300.00
0005433449932	30509	Economy	3300.00
0005432383120	30509	Economy	3300.00
0005432383103	30509	Economy	3300.00
0005433449940	30509	Economy	3300.00
0005433454871	30509	Economy	3300.00
0005433449924	30509	Economy	3300.00
0005432383106	30509	Economy	3300.00
0005433449927	30509	Economy	3300.00
0005432383108	30509	Economy	3300.00
0005432383127	30509	Economy	3300.00
0005433449926	30509	Economy	3300.00
0005432383113	30509	Economy	3300.00
0005432383095	30509	Economy	3300.00
0005432383099	30509	Economy	3300.00
0005433449936	30509	Economy	3300.00
0005432383111	30509	Economy	3300.00
0005432383117	30509	Economy	3300.00
0005433453759	30509	Economy	3300.00
0005432383105	30509	Economy	3300.00
0005432383100	30509	Economy	3300.00
0005432383110	30509	Economy	3300.00
0005432383104	30509	Economy	3300.00
0005433449920	30509	Economy	3300.00
0005432383098	30509	Economy	3300.00
0005433454872	30509	Economy	3300.00
0005433449918	30509	Economy	3300.00
0005433449931	30509	Economy	3300.00
0005432383116	30509	Economy	3300.00
0005432383121	30509	Economy	3300.00
0005433449925	30509	Economy	3300.00
0005432382758	31341	Business	9900.00
0005432382554	31341	Business	9900.00
0005432382569	31341	Business	9900.00
0005432382675	31341	Business	9900.00
0005432382727	31341	Business	9900.00
0005432382839	31341	Business	9900.00
0005432382679	31341	Business	9900.00
0005433449635	31341	Business	9900.00
0005432382543	31341	Business	9900.00
0005432382723	31341	Business	9900.00
0005433451597	31341	Economy	3300.00
0005432382623	31341	Economy	3300.00
0005432382650	31341	Economy	3300.00
0005432382540	31341	Economy	3300.00
0005432382608	31341	Economy	3300.00
0005432382685	31341	Economy	3300.00
0005432382697	31341	Economy	3300.00
0005432382703	31341	Economy	3300.00
0005433449844	31341	Economy	3600.00
0005433449683	31341	Economy	3600.00
0005433449733	31341	Economy	3600.00
0005432382659	31341	Economy	3600.00
0005432382674	31341	Economy	3300.00
0005432382628	31341	Economy	3300.00
0005433449758	31341	Economy	3300.00
0005433449753	31341	Economy	3300.00
0005433449794	31341	Economy	3300.00
0005433449770	31341	Economy	3300.00
0005432382553	31341	Economy	3300.00
0005432382836	31341	Economy	3300.00
0005432382841	31341	Economy	3300.00
0005432382630	31341	Economy	3300.00
0005433449777	31341	Economy	3300.00
0005432382632	31341	Economy	3300.00
0005433453737	31341	Economy	3300.00
0005432382660	31341	Economy	3300.00
0005433449769	31341	Economy	3300.00
0005432382701	31341	Economy	3300.00
0005433449729	31341	Economy	3300.00
0005433449619	31341	Economy	3300.00
0005432382840	31341	Economy	3300.00
0005432382631	31341	Economy	3300.00
0005433449637	31341	Economy	3300.00
0005432382603	31341	Economy	3300.00
0005432382704	31341	Economy	3300.00
0005433449618	31341	Economy	3300.00
0005432382716	31341	Economy	3300.00
0005433449634	31341	Economy	3300.00
0005432382627	31341	Economy	3300.00
0005432382568	31341	Economy	3300.00
0005433449754	31341	Economy	3300.00
0005432382819	31341	Economy	3300.00
0005433449636	31341	Economy	3300.00
0005432382871	31341	Economy	3300.00
0005433451589	31341	Economy	3300.00
0005433449728	31341	Economy	3300.00
0005433449748	31341	Economy	3300.00
0005432382542	31341	Economy	3300.00
0005432382658	31341	Economy	3300.00
0005432382552	31341	Economy	3300.00
0005432382705	31341	Economy	3300.00
0005432382574	31341	Economy	3300.00
0005433449768	31341	Economy	3300.00
0005432382717	31341	Economy	3300.00
0005432382737	31341	Economy	3300.00
0005433449747	31341	Economy	3300.00
0005433449609	31341	Economy	3300.00
0005432382774	31341	Economy	3300.00
0005432382604	31341	Economy	3300.00
0005433453746	31341	Economy	3300.00
0005432382686	31341	Economy	3300.00
0005432382602	31341	Economy	3300.00
0005433453745	31341	Economy	3300.00
0005433449797	31341	Economy	3300.00
0005433126791	10791	Economy	17100.00
0005435304114	10791	Economy	15600.00
0005435304113	10791	Economy	15600.00
0005433126779	10791	Economy	15600.00
0005435299714	10791	Economy	15600.00
0005433131646	10791	Economy	15600.00
0005433126787	10791	Economy	15600.00
0005433131628	10791	Economy	15600.00
0005433126800	10791	Economy	15600.00
0005435299712	10791	Economy	15600.00
0005433131648	10791	Economy	15600.00
0005435299715	10791	Economy	15600.00
0005433126801	10791	Economy	15600.00
0005433131647	10791	Economy	15600.00
0005435299713	10791	Economy	15600.00
0005433126778	10791	Economy	15600.00
0005433126786	10791	Economy	15600.00
0005435302191	29721	Economy	17100.00
0005433129269	29721	Economy	17100.00
0005433129270	29721	Economy	17100.00
0005435299768	29721	Economy	15600.00
0005433126841	29721	Economy	15600.00
0005433129272	29721	Economy	15600.00
0005433126839	29721	Economy	15600.00
0005435302192	29721	Economy	15600.00
0005435302194	29721	Economy	15600.00
0005433129268	29721	Economy	15600.00
0005435299772	29721	Economy	15600.00
0005435299770	29721	Economy	15600.00
0005435299769	29721	Economy	15600.00
0005433129271	29721	Economy	15600.00
0005435299773	29721	Economy	15600.00
0005433126837	29721	Economy	15600.00
0005435302193	29721	Economy	15600.00
0005435299771	29721	Economy	15600.00
0005433126840	29721	Economy	15600.00
0005433126838	29721	Economy	15600.00
0005434287250	2420	Economy	17200.00
0005434287239	2420	Economy	17200.00
0005434287254	2420	Economy	17200.00
0005434287242	2420	Economy	15700.00
0005434287236	2420	Economy	15700.00
0005434287243	2420	Economy	15700.00
0005434287255	2420	Economy	15700.00
0005434287252	2420	Economy	15700.00
0005434287247	2420	Economy	15700.00
0005432264470	2420	Economy	15700.00
0005434287235	2420	Economy	15700.00
0005434287241	2420	Economy	15700.00
0005432264469	2420	Economy	15700.00
0005433109958	2420	Economy	15700.00
0005434287244	2420	Economy	15700.00
0005434287246	2420	Economy	15700.00
0005433109952	2420	Economy	15700.00
0005434287251	2420	Economy	15700.00
0005433109963	2420	Economy	15700.00
0005434287237	2420	Economy	15700.00
0005434287234	2420	Economy	15700.00
0005434287253	2420	Economy	15700.00
0005434287238	2420	Economy	15700.00
0005434287249	2420	Economy	15700.00
0005432264471	2420	Economy	15700.00
0005433109953	2420	Economy	15700.00
0005433109962	2420	Economy	15700.00
0005434287248	2420	Economy	15700.00
0005433109933	2420	Economy	15700.00
0005434287245	2420	Economy	15700.00
0005434287240	2420	Economy	15700.00
0005434287050	26841	Economy	17200.00
0005433110024	26841	Economy	17200.00
0005434287115	26841	Economy	17200.00
0005433110027	26841	Economy	15700.00
0005434287033	26841	Economy	15700.00
0005433110032	26841	Economy	15700.00
0005433110031	26841	Economy	15700.00
0005434287009	26841	Economy	15700.00
0005434287084	26841	Economy	15700.00
0005434287052	26841	Economy	15700.00
0005434287054	26841	Economy	15700.00
0005434286991	26841	Economy	15700.00
0005434287137	26841	Economy	15700.00
0005434287060	26841	Economy	15700.00
0005434287007	26841	Economy	15700.00
0005434287056	26841	Economy	15700.00
0005433110028	26841	Economy	15700.00
0005434287015	26841	Economy	15700.00
0005433110026	26841	Economy	15700.00
0005433110025	26841	Economy	15700.00
0005434287136	26841	Economy	15700.00
0005434287095	26841	Economy	15700.00
0005434287068	26841	Economy	15700.00
0005433110029	26841	Economy	15700.00
0005434287108	26841	Economy	15700.00
0005434287008	26841	Economy	15700.00
0005434287138	26841	Economy	15700.00
0005433110034	26841	Economy	15700.00
0005434287030	26841	Economy	15700.00
0005433110023	26841	Economy	15700.00
0005434286983	26841	Economy	15700.00
0005434287049	26841	Economy	15700.00
0005434287089	26841	Economy	15700.00
0005433110030	26841	Economy	15700.00
0005434287061	26841	Economy	15700.00
0005434287051	26841	Economy	15700.00
0005433110033	26841	Economy	15700.00
0005434287053	26841	Economy	15700.00
0005434272175	25477	Economy	25000.00
0005434272165	25477	Economy	22800.00
0005435856194	25477	Economy	22800.00
0005434272174	25477	Economy	22800.00
0005434272172	25477	Economy	22800.00
0005435856195	25477	Economy	22800.00
0005435856196	25477	Economy	22800.00
0005435856197	25477	Economy	22800.00
0005435856148	26629	Economy	22800.00
0005435856147	26629	Economy	22800.00
0005434273074	26629	Economy	22800.00
0005434272190	26629	Economy	22800.00
0005434272191	26629	Economy	22800.00
0005434272189	26629	Economy	22800.00
0005435854042	26629	Economy	22800.00
0005435854043	26629	Economy	22800.00
0005433868378	4770	Economy	19400.00
0005433868366	4770	Economy	19400.00
0005433868368	4770	Economy	19400.00
0005433868346	4770	Economy	17600.00
0005433868347	4770	Economy	17600.00
0005433868349	4770	Economy	17600.00
0005433868358	4770	Economy	17600.00
0005433868361	4770	Economy	17600.00
0005433868381	4770	Economy	17600.00
0005433868365	4770	Economy	17600.00
0005433868370	4770	Economy	17600.00
0005433868357	4770	Economy	17600.00
0005433868384	4770	Economy	17600.00
0005433868375	4770	Economy	17600.00
0005435860449	4770	Economy	17600.00
0005433868387	4770	Economy	17600.00
0005433868350	4770	Economy	17600.00
0005433868353	4770	Economy	17600.00
0005433868380	4770	Economy	17600.00
0005433868383	4770	Economy	17600.00
0005433868385	4770	Economy	17600.00
0005433868374	4770	Economy	17600.00
0005433868351	4770	Economy	17600.00
0005433868371	4770	Economy	17600.00
0005433868372	4770	Economy	17600.00
0005433868355	4770	Economy	17600.00
0005433868354	4770	Economy	17600.00
0005433868386	4770	Economy	17600.00
0005435860448	4770	Economy	17600.00
0005433868364	4770	Economy	17600.00
0005433868382	4770	Economy	17600.00
0005433868348	4770	Economy	17600.00
0005433868379	4770	Economy	17600.00
0005433868376	4770	Economy	17600.00
0005433868360	4770	Economy	17600.00
0005433868363	4770	Economy	17600.00
0005433868367	4770	Economy	17600.00
0005433868369	4770	Economy	17600.00
0005433868359	4770	Economy	17600.00
0005433868356	4770	Economy	17600.00
0005433868362	4770	Economy	17600.00
0005435860447	4770	Economy	17600.00
0005433868352	4770	Economy	17600.00
0005433868377	4770	Economy	17600.00
0005433868373	4770	Economy	17600.00
0005433867892	32621	Economy	19400.00
0005433868100	32621	Economy	19400.00
0005435860482	32621	Economy	19400.00
0005433867976	32621	Economy	19400.00
0005433867903	32621	Economy	17600.00
0005433867933	32621	Economy	17600.00
0005435860483	32621	Economy	17600.00
0005433867987	32621	Economy	17600.00
0005433867936	32621	Economy	17600.00
0005435860485	32621	Economy	17600.00
0005435860481	32621	Economy	17600.00
0005433868098	32621	Economy	17600.00
0005433867904	32621	Economy	17600.00
0005433867793	32621	Economy	17600.00
0005433868162	32621	Economy	17600.00
0005435860484	32621	Economy	17600.00
0005433867898	32621	Economy	17600.00
0005433867991	32621	Economy	17600.00
0005433867858	32621	Economy	17600.00
0005433867930	32621	Economy	17600.00
0005433868164	32621	Economy	17600.00
0005433867893	32621	Economy	17600.00
0005433867992	32621	Economy	17600.00
0005433868094	32621	Economy	17600.00
0005433867989	32621	Economy	17600.00
0005433867910	32621	Economy	17600.00
0005433868123	32621	Economy	17600.00
0005433867988	32621	Economy	17600.00
0005433868099	32621	Economy	17600.00
0005433867921	32621	Economy	17600.00
0005433867986	32621	Economy	17600.00
0005433867962	32621	Economy	17600.00
0005433867902	32621	Economy	17600.00
0005433868059	32621	Economy	17600.00
0005433868163	32621	Economy	17600.00
0005433867937	32621	Economy	17600.00
0005433868060	32621	Economy	17600.00
0005434461643	3458	Economy	24800.00
0005434663378	3458	Economy	24800.00
0005434460503	3458	Economy	22600.00
0005434461644	3458	Economy	22600.00
0005435911385	3458	Economy	22600.00
0005435911368	3458	Economy	22600.00
0005434663377	3458	Economy	22600.00
0005434460501	3458	Economy	22600.00
0005434663379	3458	Economy	22600.00
0005434663383	3458	Economy	22600.00
0005435911396	3458	Economy	22600.00
0005434663382	3458	Economy	22600.00
0005435911356	3458	Economy	22600.00
0005434663387	3458	Economy	22600.00
0005435911354	3458	Economy	22600.00
0005434460500	3458	Economy	22600.00
0005434663386	3458	Economy	22600.00
0005435911374	3458	Economy	22600.00
0005435911324	3458	Economy	22600.00
0005435911364	3458	Economy	22600.00
0005434663376	3458	Economy	22600.00
0005434663381	3458	Economy	22600.00
0005434663384	3458	Economy	22600.00
0005434663380	3458	Economy	22600.00
0005434663385	3458	Economy	22600.00
0005434460502	3458	Economy	22600.00
0005435911375	3458	Economy	22600.00
0005435911355	3458	Economy	22600.00
0005434461642	3458	Economy	22600.00
0005435911376	3458	Economy	22600.00
0005434663201	12447	Economy	24800.00
0005434663272	12447	Economy	24800.00
0005435911438	12447	Economy	22600.00
0005434663269	12447	Economy	22600.00
0005434663271	12447	Economy	22600.00
0005434663279	12447	Economy	22600.00
0005434663270	12447	Economy	22600.00
0005435911435	12447	Economy	22600.00
0005434663278	12447	Economy	22600.00
0005435911439	12447	Economy	22600.00
0005434663200	12447	Economy	22600.00
0005435911437	12447	Economy	22600.00
0005434663257	12447	Economy	22600.00
0005434663234	12447	Economy	22600.00
0005434663224	12447	Economy	22600.00
0005434663268	12447	Economy	22600.00
0005435911436	12447	Economy	22600.00
0005434663300	12447	Economy	22600.00
0005435911433	12447	Economy	22600.00
0005435911434	12447	Economy	22600.00
0005433867936	14491	Economy	18500.00
0005433867910	14491	Economy	18500.00
0005433867962	14491	Economy	18500.00
0005433867987	14491	Economy	18500.00
0005433867893	14491	Economy	16800.00
0005433867986	14491	Economy	16800.00
0005435860481	14491	Economy	16800.00
0005433867991	14491	Economy	16800.00
0005433867793	14491	Economy	16800.00
0005433867921	14491	Economy	16800.00
0005433868094	14491	Economy	16800.00
0005433868123	14491	Economy	16800.00
0005433868060	14491	Economy	16800.00
0005433867892	14491	Economy	16800.00
0005435860483	14491	Economy	16800.00
0005433867976	14491	Economy	16800.00
0005433867988	14491	Economy	16800.00
0005433867992	14491	Economy	16800.00
0005433867858	14491	Economy	16800.00
0005433867989	14491	Economy	16800.00
0005433867903	14491	Economy	16800.00
0005433867902	14491	Economy	16800.00
0005433867930	14491	Economy	16800.00
0005433868164	14491	Economy	16800.00
0005433868163	14491	Economy	16800.00
0005433868098	14491	Economy	16800.00
0005435860485	14491	Economy	16800.00
0005433868059	14491	Economy	16800.00
0005435860482	14491	Economy	16800.00
0005433867937	14491	Economy	16800.00
0005435860484	14491	Economy	16800.00
0005433867933	14491	Economy	16800.00
0005433867904	14491	Economy	16800.00
0005433868162	14491	Economy	16800.00
0005433867898	14491	Economy	16800.00
0005433868099	14491	Economy	16800.00
0005433868100	14491	Economy	16800.00
0005433868322	32642	Economy	18500.00
0005433868321	32642	Economy	18500.00
0005433868337	32642	Economy	18500.00
0005433868331	32642	Economy	16800.00
0005433868310	32642	Economy	16800.00
0005433868328	32642	Economy	16800.00
0005433868335	32642	Economy	16800.00
0005433868309	32642	Economy	16800.00
0005433868314	32642	Economy	16800.00
0005433868344	32642	Economy	16800.00
0005433868340	32642	Economy	16800.00
0005433868339	32642	Economy	16800.00
0005433868318	32642	Economy	16800.00
0005433868319	32642	Economy	16800.00
0005435860443	32642	Economy	16800.00
0005435860444	32642	Economy	16800.00
0005433868315	32642	Economy	16800.00
0005433868316	32642	Economy	16800.00
0005433868326	32642	Economy	16800.00
0005433868313	32642	Economy	16800.00
0005433868317	32642	Economy	16800.00
0005433868341	32642	Economy	16800.00
0005433868308	32642	Economy	16800.00
0005433868329	32642	Economy	16800.00
0005433868311	32642	Economy	16800.00
0005433868327	32642	Economy	16800.00
0005433868336	32642	Economy	16800.00
0005433868323	32642	Economy	16800.00
0005433868343	32642	Economy	16800.00
0005433868307	32642	Economy	16800.00
0005433868324	32642	Economy	16800.00
0005435860442	32642	Economy	16800.00
0005433868305	32642	Economy	16800.00
0005433868330	32642	Economy	16800.00
0005433868332	32642	Economy	16800.00
0005433868338	32642	Economy	16800.00
0005433868342	32642	Economy	16800.00
0005433868334	32642	Economy	16800.00
0005433868345	32642	Economy	16800.00
0005433868320	32642	Economy	16800.00
0005433868325	32642	Economy	16800.00
0005433868312	32642	Economy	16800.00
0005433868306	32642	Economy	16800.00
0005433868333	32642	Economy	16800.00
0005432799166	12132	Economy	4900.00
0005432799115	12132	Economy	4400.00
0005432799167	12132	Economy	4400.00
0005432799215	12132	Economy	4400.00
0005432799080	12132	Economy	4400.00
0005432799136	12132	Economy	4400.00
0005432799135	12132	Economy	4400.00
0005432799211	12132	Economy	4400.00
0005432799255	12132	Economy	4400.00
0005432799106	12132	Economy	4400.00
0005432799117	12132	Economy	4400.00
0005432799214	12132	Economy	4400.00
0005432799079	12132	Economy	4400.00
0005432799119	12132	Economy	4400.00
0005432799107	12132	Economy	4400.00
0005432799182	12132	Economy	4400.00
0005432799165	12132	Economy	4400.00
0005432799234	12132	Economy	4400.00
0005432799183	12132	Economy	4400.00
0005432799181	12132	Economy	4400.00
0005432799371	14830	Economy	4900.00
0005432799360	14830	Economy	4900.00
0005432799374	14830	Economy	4400.00
0005432799386	14830	Economy	4400.00
0005432799381	14830	Economy	4400.00
0005432799379	14830	Economy	4400.00
0005432799378	14830	Economy	4400.00
0005432799359	14830	Economy	4400.00
0005432799366	14830	Economy	4400.00
0005432799384	14830	Economy	4400.00
0005432799365	14830	Economy	4400.00
0005432799377	14830	Economy	4400.00
0005432799383	14830	Economy	4400.00
0005432799368	14830	Economy	4400.00
0005432799385	14830	Economy	4400.00
0005432799375	14830	Economy	4400.00
0005432799380	14830	Economy	4400.00
0005432799369	14830	Economy	4400.00
0005432799364	14830	Economy	4400.00
0005432799361	14830	Economy	4400.00
0005432799373	14830	Economy	4400.00
0005432799370	14830	Economy	4400.00
0005432799358	14830	Economy	4400.00
0005432799362	14830	Economy	4400.00
0005432799363	14830	Economy	4400.00
0005432799382	14830	Economy	4400.00
0005432799367	14830	Economy	4400.00
0005432799376	14830	Economy	4400.00
0005432799372	14830	Economy	4400.00
0005434407634	7034	Business	49100.00
0005434299514	7034	Business	49100.00
0005434407662	7034	Business	49100.00
0005434407638	7034	Business	49100.00
0005434407607	7034	Business	49100.00
0005432153922	7034	Business	49100.00
0005434407665	7034	Business	49100.00
0005434299520	7034	Business	49100.00
0005434407669	7034	Business	49100.00
0005434407627	7034	Business	49100.00
0005434407611	7034	Economy	16400.00
0005434407608	7034	Economy	16400.00
0005432108244	7034	Economy	16400.00
0005434407666	7034	Economy	16400.00
0005434407617	7034	Economy	16400.00
0005434299512	7034	Economy	16400.00
0005432153925	7034	Economy	16400.00
0005434407670	7034	Economy	16400.00
0005434407610	7034	Economy	16400.00
0005435293132	7034	Economy	16400.00
0005432108245	7034	Economy	16400.00
0005435293133	7034	Economy	16400.00
0005434407661	7034	Economy	16400.00
0005434407659	7034	Economy	16400.00
0005434299517	7034	Economy	16400.00
0005434407667	7034	Economy	16400.00
0005435310925	7034	Economy	16400.00
0005434299513	7034	Economy	16400.00
0005434407642	7034	Economy	16400.00
0005434299523	7034	Economy	16400.00
0005434407671	7034	Economy	16400.00
0005434407649	7034	Economy	16400.00
0005434407619	7034	Economy	16400.00
0005434407631	7034	Economy	16400.00
0005434407655	7034	Economy	16400.00
0005432153921	7034	Economy	16400.00
0005434299522	7034	Economy	16400.00
0005434407606	7034	Economy	16400.00
0005434407625	7034	Economy	16400.00
0005432153927	7034	Economy	16400.00
0005434299526	7034	Economy	16400.00
0005434299521	7034	Economy	16400.00
0005435310864	7034	Economy	16400.00
0005434407615	7034	Economy	16400.00
0005434407614	7034	Economy	16400.00
0005435310916	7034	Economy	16400.00
0005434407624	7034	Economy	16400.00
0005435293162	7034	Economy	16400.00
0005435310895	7034	Economy	18000.00
0005434299518	7034	Economy	18000.00
0005435293130	7034	Economy	18000.00
0005434407647	7034	Economy	18000.00
0005432153926	7034	Economy	18000.00
0005434299506	7034	Economy	16400.00
0005434299524	7034	Economy	16400.00
0005434299525	7034	Economy	16400.00
0005434407626	7034	Economy	16400.00
0005434407612	7034	Economy	16400.00
0005434407643	7034	Economy	16400.00
0005434407641	7034	Economy	16400.00
0005434407628	7034	Economy	16400.00
0005434407621	7034	Economy	16400.00
0005434407630	7034	Economy	16400.00
0005435310865	7034	Economy	16400.00
0005434407652	7034	Economy	16400.00
0005434407632	7034	Economy	16400.00
0005435310930	7034	Economy	16400.00
0005434407653	7034	Economy	16400.00
0005435310929	7034	Economy	16400.00
0005432153924	7034	Economy	16400.00
0005434299503	7034	Economy	16400.00
0005434407654	7034	Economy	16400.00
0005434407609	7034	Economy	16400.00
0005434407658	7034	Economy	16400.00
0005432153923	7034	Economy	16400.00
0005434407639	7034	Economy	16400.00
0005434407648	7034	Economy	16400.00
0005434407622	7034	Economy	16400.00
0005435293139	7034	Economy	16400.00
0005435293121	7034	Economy	16400.00
0005434407633	7034	Economy	16400.00
0005434407620	7034	Economy	16400.00
0005434407660	7034	Economy	16400.00
0005434299508	7034	Economy	16400.00
0005435293138	7034	Economy	16400.00
0005434407616	7034	Economy	16400.00
0005434407635	7034	Economy	16400.00
0005434407629	7034	Economy	16400.00
0005434407644	7034	Economy	16400.00
0005434299507	7034	Economy	16400.00
0005434299510	7034	Economy	16400.00
0005434407650	7034	Economy	16400.00
0005434299505	7034	Economy	16400.00
0005434407668	7034	Economy	16400.00
0005435293092	7034	Economy	16400.00
0005434407618	7034	Economy	16400.00
0005434407663	7034	Economy	16400.00
0005434407645	7034	Economy	16400.00
0005434299504	7034	Economy	16400.00
0005434407664	7034	Economy	16400.00
0005434299516	7034	Economy	16400.00
0005434299511	7034	Economy	16400.00
0005434407636	7034	Economy	16400.00
0005434407646	7034	Economy	16400.00
0005434407613	7034	Economy	16400.00
0005434299509	7034	Economy	16400.00
0005434407640	7034	Economy	16400.00
0005434407637	7034	Economy	16400.00
0005434407651	7034	Economy	16400.00
0005435310918	7034	Economy	16400.00
0005435310923	7034	Economy	16400.00
0005435310907	7034	Economy	16400.00
0005434299519	7034	Economy	16400.00
0005435293122	7034	Economy	16400.00
0005434299515	7034	Economy	16400.00
0005434407623	7034	Economy	16400.00
0005435310915	7034	Economy	16400.00
0005434407657	7034	Economy	16400.00
0005434407656	7034	Economy	16400.00
0005435293234	26934	Business	49100.00
0005434407229	26934	Business	49100.00
0005434299273	26934	Business	49100.00
0005434407134	26934	Business	49100.00
0005434299318	26934	Business	49100.00
0005434406926	26934	Business	49100.00
0005434406837	26934	Business	49100.00
0005434299314	26934	Business	49100.00
0005434299331	26934	Business	49100.00
0005434406858	26934	Business	49100.00
0005434299292	26934	Business	49100.00
0005434299323	26934	Business	49100.00
0005434299398	26934	Economy	16400.00
0005434407149	26934	Economy	16400.00
0005434299319	26934	Economy	16400.00
0005434407269	26934	Economy	16400.00
0005434299197	26934	Economy	16400.00
0005434406927	26934	Economy	16400.00
0005435293224	26934	Economy	16400.00
0005434406912	26934	Economy	16400.00
0005434407112	26934	Economy	16400.00
0005434406990	26934	Economy	16400.00
0005434299256	26934	Economy	16400.00
0005434407305	26934	Economy	16400.00
0005434407198	26934	Economy	16400.00
0005432058369	26934	Economy	16400.00
0005434299200	26934	Economy	16400.00
0005432058368	26934	Economy	16400.00
0005432058370	26934	Economy	16400.00
0005434299233	26934	Economy	16400.00
0005434406870	26934	Economy	16400.00
0005434299376	26934	Economy	16400.00
0005434299198	26934	Economy	16400.00
0005434299316	26934	Economy	16400.00
0005434407060	26934	Economy	16400.00
0005434406788	26934	Economy	16400.00
0005434407271	26934	Economy	16400.00
0005434407148	26934	Economy	16400.00
0005434299407	26934	Economy	16400.00
0005434299374	26934	Economy	16400.00
0005434407270	26934	Economy	16400.00
0005434407003	26934	Economy	16400.00
0005434406988	26934	Economy	16400.00
0005435293225	26934	Economy	16400.00
0005434299403	26934	Economy	16400.00
0005434407058	26934	Economy	16400.00
0005434407038	26934	Economy	16400.00
0005434299281	26934	Economy	16400.00
0005434299254	26934	Economy	16400.00
0005434407180	26934	Economy	16400.00
0005434299375	26934	Economy	16400.00
0005434407179	26934	Economy	16400.00
0005434299257	26934	Economy	18000.00
0005434299276	26934	Economy	18000.00
0005434299315	26934	Economy	18000.00
0005434406938	26934	Economy	18000.00
0005434406972	26934	Economy	18000.00
0005434407161	26934	Economy	18000.00
0005434406789	26934	Economy	16400.00
0005434407111	26934	Economy	16400.00
0005435293232	26934	Economy	16400.00
0005434407200	26934	Economy	16400.00
0005434407181	26934	Economy	16400.00
0005434407051	26934	Economy	16400.00
0005432058371	26934	Economy	16400.00
0005434406884	26934	Economy	16400.00
0005434407201	26934	Economy	16400.00
0005434299383	26934	Economy	16400.00
0005435293226	26934	Economy	16400.00
0005434406955	26934	Economy	16400.00
0005434407177	26934	Economy	16400.00
0005434299324	26934	Economy	16400.00
0005435293223	26934	Economy	16400.00
0005434406864	26934	Economy	16400.00
0005434407021	26934	Economy	16400.00
0005434406956	26934	Economy	16400.00
0005434299271	26934	Economy	16400.00
0005434407107	26934	Economy	16400.00
0005435293233	26934	Economy	16400.00
0005434406995	26934	Economy	16400.00
0005435293228	26934	Economy	16400.00
0005434299272	26934	Economy	16400.00
0005434299396	26934	Economy	16400.00
0005434406946	26934	Economy	16400.00
0005434299255	26934	Economy	16400.00
0005434407093	26934	Economy	16400.00
0005434407160	26934	Economy	16400.00
0005434299309	26934	Economy	16400.00
0005435293222	26934	Economy	16400.00
0005435311035	26934	Economy	16400.00
0005435293231	26934	Economy	16400.00
0005434299320	26934	Economy	16400.00
0005435293230	26934	Economy	16400.00
0005434299253	26934	Economy	16400.00
0005435293229	26934	Economy	16400.00
0005434407222	26934	Economy	16400.00
0005434406987	26934	Economy	16400.00
0005434407106	26934	Economy	16400.00
0005434299280	26934	Economy	16400.00
0005434407167	26934	Economy	16400.00
0005434299397	26934	Economy	16400.00
0005434299201	26934	Economy	16400.00
0005434406863	26934	Economy	16400.00
0005434407199	26934	Economy	16400.00
0005434299313	26934	Economy	16400.00
0005434407125	26934	Economy	16400.00
0005434299270	26934	Economy	16400.00
0005434406903	26934	Economy	16400.00
0005434407008	26934	Economy	16400.00
0005434299367	26934	Economy	16400.00
0005434407103	26934	Economy	16400.00
0005434299352	26934	Economy	16400.00
0005434406939	26934	Economy	16400.00
0005434407094	26934	Economy	16400.00
0005435293227	26934	Economy	16400.00
0005434407105	26934	Economy	16400.00
0005434406885	26934	Economy	16400.00
0005434299351	26934	Economy	16400.00
0005434407117	26934	Economy	16400.00
0005434406996	26934	Economy	16400.00
0005434299368	26934	Economy	16400.00
0005434299312	26934	Economy	16400.00
0005434299277	26934	Economy	16400.00
0005434406857	26934	Economy	16400.00
0005434406861	26934	Economy	16400.00
0005434407101	26934	Economy	16400.00
0005434406902	26934	Economy	16400.00
0005434406928	26934	Economy	16400.00
0005434406957	26934	Economy	16400.00
0005434407077	26934	Economy	16400.00
0005432604286	6470	Economy	16500.00
0005432604254	6470	Economy	16500.00
0005432604275	6470	Economy	16500.00
0005432604280	6470	Economy	16500.00
0005432604269	6470	Economy	15000.00
0005432604263	6470	Economy	15000.00
0005432604261	6470	Economy	15000.00
0005434512108	6470	Economy	15000.00
0005432604271	6470	Economy	15000.00
0005432604278	6470	Economy	15000.00
0005432604260	6470	Economy	15000.00
0005432604287	6470	Economy	15000.00
0005432604267	6470	Economy	15000.00
0005432604288	6470	Economy	15000.00
0005434512106	6470	Economy	15000.00
0005432604264	6470	Economy	15000.00
0005432604276	6470	Economy	15000.00
0005432604277	6470	Economy	15000.00
0005432604268	6470	Economy	15000.00
0005432604283	6470	Economy	15000.00
0005432604289	6470	Economy	15000.00
0005432604256	6470	Economy	15000.00
0005432604284	6470	Economy	15000.00
0005432604266	6470	Economy	15000.00
0005432604253	6470	Economy	15000.00
0005434512104	6470	Economy	15000.00
0005434512111	6470	Economy	15000.00
0005432604250	6470	Economy	15000.00
0005432604257	6470	Economy	15000.00
0005432604274	6470	Economy	15000.00
0005432604273	6470	Economy	15000.00
0005432604285	6470	Economy	15000.00
0005432604251	6470	Economy	15000.00
0005434512107	6470	Economy	15000.00
0005432604252	6470	Economy	15000.00
0005432604282	6470	Economy	15000.00
0005434512109	6470	Economy	15000.00
0005432604281	6470	Economy	15000.00
0005432604270	6470	Economy	15000.00
0005432604265	6470	Economy	15000.00
0005432604290	6470	Economy	15000.00
0005434512105	6470	Economy	15000.00
0005432604272	6470	Economy	15000.00
0005432604262	6470	Economy	15000.00
0005432604259	6470	Economy	15000.00
0005432604279	6470	Economy	15000.00
0005432604258	6470	Economy	15000.00
0005434512110	6470	Economy	15000.00
0005432604255	6470	Economy	15000.00
0005432604063	21376	Economy	16500.00
0005432604026	21376	Economy	16500.00
0005432603784	21376	Economy	16500.00
0005432603832	21376	Economy	16500.00
0005432604064	21376	Economy	15000.00
0005432603761	21376	Economy	15000.00
0005432604033	21376	Economy	15000.00
0005432603878	21376	Economy	15000.00
0005432604013	21376	Economy	15000.00
0005432603768	21376	Economy	15000.00
0005434512059	21376	Economy	15000.00
0005432603866	21376	Economy	15000.00
0005432603936	21376	Economy	15000.00
0005434512085	21376	Economy	15000.00
0005432603785	21376	Economy	15000.00
0005432603904	21376	Economy	15000.00
0005432603876	21376	Economy	15000.00
0005432604094	21376	Economy	15000.00
0005432603812	21376	Economy	15000.00
0005432603846	21376	Economy	15000.00
0005432603949	21376	Economy	15000.00
0005432604020	21376	Economy	15000.00
0005432603886	21376	Economy	15000.00
0005432603845	21376	Economy	15000.00
0005432603950	21376	Economy	15000.00
0005432603897	21376	Economy	15000.00
0005432603887	21376	Economy	15000.00
0005432604021	21376	Economy	15000.00
0005432603877	21376	Economy	15000.00
0005432603907	21376	Economy	15000.00
0005432604019	21376	Economy	15000.00
0005432603935	21376	Economy	15000.00
0005432603837	21376	Economy	15000.00
0005432603831	21376	Economy	15000.00
0005432604027	21376	Economy	15000.00
0005432603924	21376	Economy	15000.00
0005432603888	21376	Economy	15000.00
0005432604062	21376	Economy	15000.00
0005434512070	21376	Economy	15000.00
0005432603925	21376	Economy	15000.00
0005434512069	21376	Economy	15000.00
0005434512046	21376	Economy	15000.00
0005432604023	21376	Economy	15000.00
0005432604022	21376	Economy	15000.00
0005432603867	21376	Economy	15000.00
0005432603945	21376	Economy	15000.00
0005432603830	21376	Economy	15000.00
0005432603895	21376	Economy	15000.00
0005434512092	21376	Economy	15000.00
0005432603906	21376	Economy	15000.00
0005434906719	14983	Business	18900.00
0005433251427	14983	Business	18900.00
0005434906650	14983	Business	18900.00
0005433251432	14983	Business	18900.00
0005434906686	14983	Business	18900.00
0005434906813	14983	Business	18900.00
0005433251406	14983	Business	18900.00
0005434906656	14983	Business	18900.00
0005434906594	14983	Business	18900.00
0005433251402	14983	Business	18900.00
0005434906513	14983	Business	18900.00
0005433251411	14983	Business	18900.00
0005434906369	14983	Economy	6300.00
0005433251423	14983	Economy	6300.00
0005434906659	14983	Economy	6300.00
0005434906649	14983	Economy	6300.00
0005434906660	14983	Economy	6300.00
0005434906546	14983	Economy	6300.00
0005433251431	14983	Economy	6300.00
0005433251401	14983	Economy	6300.00
0005434906547	14983	Economy	6300.00
0005433251424	14983	Economy	6900.00
0005434906609	14983	Economy	6900.00
0005433251429	14983	Economy	6900.00
0005433251419	14983	Economy	6900.00
0005434906720	14983	Economy	6300.00
0005434906622	14983	Economy	6300.00
0005433251425	14983	Economy	6300.00
0005433251421	14983	Economy	6300.00
0005433251415	14983	Economy	6300.00
0005434906588	14983	Economy	6300.00
0005434906631	14983	Economy	6300.00
0005434906672	14983	Economy	6300.00
0005434906641	14983	Economy	6300.00
0005434906664	14983	Economy	6300.00
0005433251407	14983	Economy	6300.00
0005434906608	14983	Economy	6300.00
0005434906642	14983	Economy	6300.00
0005433251412	14983	Economy	6300.00
0005434906527	14983	Economy	6300.00
0005434906625	14983	Economy	6300.00
0005434906610	14983	Economy	6300.00
0005434906737	14983	Economy	6300.00
0005434906713	14983	Economy	6300.00
0005433251422	14983	Economy	6300.00
0005433251409	14983	Economy	6300.00
0005433251405	14983	Economy	6300.00
0005433251426	14983	Economy	6300.00
0005434906589	14983	Economy	6300.00
0005434906710	14983	Economy	6300.00
0005434906500	14983	Economy	6300.00
0005434906627	14983	Economy	6300.00
0005434906595	14983	Economy	6300.00
0005433251420	14983	Economy	6300.00
0005433251404	14983	Economy	6300.00
0005433251418	14983	Economy	6300.00
0005434906497	14983	Economy	6300.00
0005433251413	14983	Economy	6300.00
0005434906761	14983	Economy	6300.00
0005433251428	14983	Economy	6300.00
0005434906661	14983	Economy	6300.00
0005433251416	14983	Economy	6300.00
0005433251403	14983	Economy	6300.00
0005434906485	14983	Economy	6300.00
0005434906507	14983	Economy	6300.00
0005434906537	14983	Economy	6300.00
0005434906806	14983	Economy	6300.00
0005434906475	14983	Economy	6300.00
0005434906714	14983	Economy	6300.00
0005433251417	14983	Economy	6300.00
0005434906634	14983	Economy	6300.00
0005434906755	14983	Economy	6300.00
0005434906662	14983	Economy	6300.00
0005434906723	14983	Economy	6300.00
0005434906548	14983	Economy	6300.00
0005434906385	14983	Economy	6300.00
0005433251414	14983	Economy	6300.00
0005434906593	14983	Economy	6300.00
0005433251430	14983	Economy	6300.00
0005433251408	14983	Economy	6300.00
0005433251410	14983	Economy	6300.00
0005434906620	14983	Economy	6300.00
0005434906801	14983	Economy	6300.00
0005434906626	14983	Economy	6300.00
0005434906498	14983	Economy	6300.00
0005434906386	14983	Economy	6300.00
0005434906499	14983	Economy	6300.00
0005434906724	14983	Economy	6300.00
0005433251154	25838	Business	18900.00
0005434907134	25838	Business	18900.00
0005434907120	25838	Business	18900.00
0005434907137	25838	Business	18900.00
0005433251162	25838	Business	18900.00
0005433251081	25838	Business	18900.00
0005434907132	25838	Business	18900.00
0005434907147	25838	Business	18900.00
0005434907107	25838	Business	18900.00
0005434907133	25838	Economy	6300.00
0005433251164	25838	Economy	6300.00
0005434907110	25838	Economy	6300.00
0005434907160	25838	Economy	6300.00
0005433251173	25838	Economy	6300.00
0005433251165	25838	Economy	6300.00
0005434907158	25838	Economy	6300.00
0005434907130	25838	Economy	6300.00
0005433251133	25838	Economy	6300.00
0005433251037	25838	Economy	6900.00
0005434907113	25838	Economy	6900.00
0005434907150	25838	Economy	6900.00
0005434907151	25838	Economy	6900.00
0005434907108	25838	Economy	6900.00
0005434907124	25838	Economy	6300.00
0005434907116	25838	Economy	6300.00
0005434907142	25838	Economy	6300.00
0005433251256	25838	Economy	6300.00
0005433251080	25838	Economy	6300.00
0005434907145	25838	Economy	6300.00
0005433251174	25838	Economy	6300.00
0005434907118	25838	Economy	6300.00
0005434907114	25838	Economy	6300.00
0005434907112	25838	Economy	6300.00
0005434907135	25838	Economy	6300.00
0005434907153	25838	Economy	6300.00
0005434907111	25838	Economy	6300.00
0005434907119	25838	Economy	6300.00
0005434907144	25838	Economy	6300.00
0005434907159	25838	Economy	6300.00
0005434907152	25838	Economy	6300.00
0005434907109	25838	Economy	6300.00
0005434907121	25838	Economy	6300.00
0005434907140	25838	Economy	6300.00
0005434907128	25838	Economy	6300.00
0005434907149	25838	Economy	6300.00
0005434907154	25838	Economy	6300.00
0005433251146	25838	Economy	6300.00
0005434907148	25838	Economy	6300.00
0005433251163	25838	Economy	6300.00
0005434907156	25838	Economy	6300.00
0005434907131	25838	Economy	6300.00
0005434907141	25838	Economy	6300.00
0005433251082	25838	Economy	6300.00
0005434907146	25838	Economy	6300.00
0005434907104	25838	Economy	6300.00
0005434907117	25838	Economy	6300.00
0005434907126	25838	Economy	6300.00
0005434907106	25838	Economy	6300.00
0005434907139	25838	Economy	6300.00
0005434907155	25838	Economy	6300.00
0005434907123	25838	Economy	6300.00
0005433251036	25838	Economy	6300.00
0005434907105	25838	Economy	6300.00
0005434907115	25838	Economy	6300.00
0005434907138	25838	Economy	6300.00
0005434907122	25838	Economy	6300.00
0005434907125	25838	Economy	6300.00
0005433251153	25838	Economy	6300.00
0005433251255	25838	Economy	6300.00
0005434907127	25838	Economy	6300.00
0005434907157	25838	Economy	6300.00
0005433251132	25838	Economy	6300.00
0005433251254	25838	Economy	6300.00
0005434907143	25838	Economy	6300.00
0005434907129	25838	Economy	6300.00
0005434907136	25838	Economy	6300.00
0005433008560	14188	Business	52300.00
0005433810495	14188	Business	52300.00
0005433008530	14188	Business	52300.00
0005433008558	14188	Business	52300.00
0005433008528	14188	Economy	17400.00
0005433008556	14188	Economy	17400.00
0005433008540	14188	Economy	17400.00
0005433008533	14188	Economy	17400.00
0005433008525	14188	Economy	17400.00
0005433008519	14188	Economy	17400.00
0005433008555	14188	Economy	19200.00
0005433008522	14188	Economy	19200.00
0005433008518	14188	Economy	19200.00
0005433008547	14188	Economy	19200.00
0005433008550	14188	Economy	17400.00
0005433008542	14188	Economy	17400.00
0005433008563	14188	Economy	17400.00
0005433008520	14188	Economy	17400.00
0005433008561	14188	Economy	17400.00
0005433008548	14188	Economy	17400.00
0005433008554	14188	Economy	17400.00
0005433008529	14188	Economy	17400.00
0005433008536	14188	Economy	17400.00
0005433810503	14188	Economy	17400.00
0005433008538	14188	Economy	17400.00
0005433008535	14188	Economy	17400.00
0005433008532	14188	Economy	17400.00
0005433008534	14188	Economy	17400.00
0005433008562	14188	Economy	17400.00
0005433008549	14188	Economy	17400.00
0005433008552	14188	Economy	17400.00
0005433008546	14188	Economy	17400.00
0005433008559	14188	Economy	17400.00
0005433008544	14188	Economy	17400.00
0005433008521	14188	Economy	17400.00
0005433008543	14188	Economy	17400.00
0005433008551	14188	Economy	17400.00
0005433008553	14188	Economy	17400.00
0005433008545	14188	Economy	17400.00
0005433008527	14188	Economy	17400.00
0005433008526	14188	Economy	17400.00
0005433008537	14188	Economy	17400.00
0005433008524	14188	Economy	17400.00
0005433008557	14188	Economy	17400.00
0005433008531	14188	Economy	17400.00
0005433008539	14188	Economy	17400.00
0005433008523	14188	Economy	17400.00
0005433008541	14188	Economy	17400.00
0005433810532	22840	Business	52300.00
0005433008117	22840	Business	52300.00
0005433008138	22840	Business	52300.00
0005433008224	22840	Business	52300.00
0005433810530	22840	Business	52300.00
0005433008145	22840	Business	52300.00
0005433008124	22840	Economy	17400.00
0005433008135	22840	Economy	17400.00
0005433008004	22840	Economy	17400.00
0005433008005	22840	Economy	17400.00
0005433008233	22840	Economy	17400.00
0005433810534	22840	Economy	19200.00
0005433008184	22840	Economy	19200.00
0005433008234	22840	Economy	19200.00
0005433008100	22840	Economy	19200.00
0005433008203	22840	Economy	17400.00
0005433008136	22840	Economy	17400.00
0005433008014	22840	Economy	17400.00
0005433008102	22840	Economy	17400.00
0005433008123	22840	Economy	17400.00
0005433810533	22840	Economy	17400.00
0005433008146	22840	Economy	17400.00
0005433008103	22840	Economy	17400.00
0005433008101	22840	Economy	17400.00
0005433008092	22840	Economy	17400.00
0005433810531	22840	Economy	17400.00
0005433008141	22840	Economy	17400.00
0005433008021	22840	Economy	17400.00
0005433008183	22840	Economy	17400.00
0005433008003	22840	Economy	17400.00
0005433008134	22840	Economy	17400.00
0005433008078	22840	Economy	17400.00
0005433008186	22840	Economy	17400.00
0005433008219	22840	Economy	17400.00
0005433008002	22840	Economy	17400.00
0005433008104	22840	Economy	17400.00
0005433008015	22840	Economy	17400.00
0005433008140	22840	Economy	17400.00
0005433008217	22840	Economy	17400.00
0005433008242	22840	Economy	17400.00
0005433008087	22840	Economy	17400.00
0005433008024	22840	Economy	17400.00
0005433008211	22840	Economy	17400.00
0005433810529	22840	Economy	17400.00
0005433008055	22840	Economy	17400.00
0005433008091	22840	Economy	17400.00
0005433008139	22840	Economy	17400.00
0005433008210	22840	Economy	17400.00
0005435718886	15526	Business	85200.00
0005435718891	15526	Business	85200.00
0005435718915	15526	Business	85200.00
0005435718907	15526	Business	85200.00
0005435718903	15526	Economy	28400.00
0005435718917	15526	Economy	28400.00
0005435718918	15526	Economy	28400.00
0005435718888	15526	Economy	31200.00
0005435718901	15526	Economy	28400.00
0005435718906	15526	Economy	28400.00
0005435718902	15526	Economy	28400.00
0005435718894	15526	Economy	28400.00
0005435718896	15526	Economy	28400.00
0005435718909	15526	Economy	28400.00
0005435718885	15526	Economy	28400.00
0005435718897	15526	Economy	28400.00
0005435718916	15526	Economy	28400.00
0005435718900	15526	Economy	28400.00
0005435718895	15526	Economy	28400.00
0005435718892	15526	Economy	28400.00
0005435718893	15526	Economy	28400.00
0005435718890	15526	Economy	28400.00
0005435718899	15526	Economy	28400.00
0005435718912	15526	Economy	28400.00
0005435718904	15526	Economy	28400.00
0005435718898	15526	Economy	28400.00
0005435718887	15526	Economy	28400.00
0005435718910	15526	Economy	28400.00
0005435718905	15526	Economy	28400.00
0005435718914	15526	Economy	28400.00
0005435718913	15526	Economy	28400.00
0005435718911	15526	Economy	28400.00
0005435718919	15526	Economy	28400.00
0005435718889	15526	Economy	28400.00
0005435718920	15526	Economy	28400.00
0005435718908	15526	Economy	28400.00
0005434925429	14966	Business	22900.00
0005434925471	14966	Business	22900.00
0005434925413	14966	Business	22900.00
0005434925511	14966	Business	22900.00
0005434925393	14966	Business	22900.00
0005434925431	14966	Business	22900.00
0005434925445	14966	Economy	7600.00
0005434925447	14966	Economy	7600.00
0005434925386	14966	Economy	7600.00
0005434925394	14966	Economy	8400.00
0005434925281	14966	Economy	8400.00
0005434925485	14966	Economy	7600.00
0005434925365	14966	Economy	7600.00
0005434925357	14966	Economy	7600.00
0005434925356	14966	Economy	7600.00
0005434925373	14966	Economy	7600.00
0005434925479	14966	Economy	7600.00
0005434925482	14966	Economy	7600.00
0005434925372	14966	Economy	7600.00
0005434925480	14966	Economy	7600.00
0005434925472	14966	Economy	7600.00
0005434925476	14966	Economy	7600.00
0005434925415	14966	Economy	7600.00
0005434925282	14966	Economy	7600.00
0005434925594	14966	Economy	7600.00
0005434925384	14966	Economy	7600.00
0005434925593	14966	Economy	7600.00
0005434925493	14966	Economy	7600.00
0005434925448	14966	Economy	7600.00
0005434925529	14966	Economy	7600.00
0005434925260	14966	Economy	7600.00
0005434925355	14966	Economy	7600.00
0005434925354	14966	Economy	7600.00
0005434925508	14966	Economy	7600.00
0005434925473	14966	Economy	7600.00
0005434925350	14966	Economy	7600.00
0005434925428	14966	Economy	7600.00
0005434925366	14966	Economy	7600.00
0005434925446	14966	Economy	7600.00
0005434925735	20501	Business	22900.00
0005434925725	20501	Business	22900.00
0005434925733	20501	Business	22900.00
0005434925736	20501	Business	22900.00
0005434925742	20501	Economy	7600.00
0005434925718	20501	Economy	7600.00
0005434925723	20501	Economy	7600.00
0005434925717	20501	Economy	7600.00
0005434925740	20501	Economy	7600.00
0005434925749	20501	Economy	7600.00
0005434925741	20501	Economy	7600.00
0005434925746	20501	Economy	7600.00
0005434925745	20501	Economy	7600.00
0005434925726	20501	Economy	7600.00
0005434925747	20501	Economy	7600.00
0005434925731	20501	Economy	7600.00
0005434925744	20501	Economy	7600.00
0005434925722	20501	Economy	7600.00
0005434925734	20501	Economy	7600.00
0005434925729	20501	Economy	7600.00
0005434925748	20501	Economy	7600.00
0005434925730	20501	Economy	7600.00
0005434925727	20501	Economy	7600.00
0005434925739	20501	Economy	7600.00
0005434925719	20501	Economy	7600.00
0005434925738	20501	Economy	7600.00
0005434925743	20501	Economy	7600.00
0005434925728	20501	Economy	7600.00
0005434925724	20501	Economy	7600.00
0005434925720	20501	Economy	7600.00
0005434925732	20501	Economy	7600.00
0005434925737	20501	Economy	7600.00
0005434925721	20501	Economy	7600.00
0005435999072	15830	Economy	8900.00
0005435999043	15830	Economy	8900.00
0005435999033	15830	Economy	8900.00
0005435487791	15830	Economy	8100.00
0005435487804	15830	Economy	8100.00
0005435487788	15830	Economy	8100.00
0005435999084	15830	Economy	8100.00
0005435487807	15830	Economy	8100.00
0005435487803	15830	Economy	8100.00
0005435487786	15830	Economy	8100.00
0005435999071	15830	Economy	8100.00
0005435487802	15830	Economy	8100.00
0005435487799	15830	Economy	8100.00
0005435487787	15830	Economy	8100.00
0005435999029	15830	Economy	8100.00
0005435487806	15830	Economy	8100.00
0005435999007	15830	Economy	8100.00
0005435487794	15830	Economy	8100.00
0005435487795	15830	Economy	8100.00
0005435999012	15830	Economy	8100.00
0005435999030	15830	Economy	8100.00
0005435999011	15830	Economy	8100.00
0005435487801	15830	Economy	8100.00
0005435487796	15830	Economy	8100.00
0005435999046	15830	Economy	8100.00
0005435487798	15830	Economy	8100.00
0005435487800	15830	Economy	8100.00
0005435999062	15830	Economy	8100.00
0005435999056	15830	Economy	8100.00
0005435487790	15830	Economy	8100.00
0005435487805	15830	Economy	8100.00
0005435999061	15830	Economy	8100.00
0005435998984	15830	Economy	8100.00
0005435999085	15830	Economy	8100.00
0005435487792	15830	Economy	8100.00
0005435999068	15830	Economy	8100.00
0005435999005	15830	Economy	8100.00
0005435487793	15830	Economy	8100.00
0005435487797	15830	Economy	8100.00
0005435999060	15830	Economy	8100.00
0005435999076	15830	Economy	8100.00
0005435999034	15830	Economy	8100.00
0005435487789	15830	Economy	8100.00
0005435999006	15830	Economy	8100.00
0005435999208	19705	Economy	8900.00
0005435487516	19705	Economy	8900.00
0005435999216	19705	Economy	8900.00
0005435487578	19705	Economy	8100.00
0005435487577	19705	Economy	8100.00
0005435999201	19705	Economy	8100.00
0005435487549	19705	Economy	8100.00
0005435487619	19705	Economy	8100.00
0005435999197	19705	Economy	8100.00
0005435487564	19705	Economy	8100.00
0005435487550	19705	Economy	8100.00
0005435487540	19705	Economy	8100.00
0005435999198	19705	Economy	8100.00
0005435487494	19705	Economy	8100.00
0005435487568	19705	Economy	8100.00
0005435999215	19705	Economy	8100.00
0005435999212	19705	Economy	8100.00
0005435999205	19705	Economy	8100.00
0005435487565	19705	Economy	8100.00
0005435999210	19705	Economy	8100.00
0005435487520	19705	Economy	8100.00
0005435487501	19705	Economy	8100.00
0005435487538	19705	Economy	8100.00
0005435999203	19705	Economy	8100.00
0005435999209	19705	Economy	8100.00
0005435999206	19705	Economy	8100.00
0005435999213	19705	Economy	8100.00
0005435487637	19705	Economy	8100.00
0005435999207	19705	Economy	8100.00
0005435999199	19705	Economy	8100.00
0005435487495	19705	Economy	8100.00
0005435487502	19705	Economy	8100.00
0005435999217	19705	Economy	8100.00
0005435999196	19705	Economy	8100.00
0005435487557	19705	Economy	8100.00
0005435999202	19705	Economy	8100.00
0005435999204	19705	Economy	8100.00
0005435487634	19705	Economy	8100.00
0005435999200	19705	Economy	8100.00
0005435999214	19705	Economy	8100.00
0005435999211	19705	Economy	8100.00
0005435487539	19705	Economy	8100.00
0005435487469	19705	Economy	8100.00
0005435472617	6003	Business	199300.00
0005432537032	6003	Business	199300.00
0005432142247	6003	Business	199300.00
0005432658588	6003	Business	199300.00
0005432142245	6003	Business	199300.00
0005435839408	6003	Business	199300.00
0005435839412	6003	Business	199300.00
0005435472629	6003	Business	199300.00
0005435472591	6003	Economy	66400.00
0005435472653	6003	Economy	66400.00
0005432537023	6003	Economy	66400.00
0005435839405	6003	Economy	66400.00
0005435839409	6003	Economy	66400.00
0005435839395	6003	Economy	66400.00
0005435472628	6003	Economy	66400.00
0005435472639	6003	Economy	66400.00
0005435472622	6003	Economy	66400.00
0005435472701	6003	Economy	66400.00
0005432658589	6003	Economy	66400.00
0005432142246	6003	Economy	73100.00
0005435472641	6003	Economy	73100.00
0005435472621	6003	Economy	73100.00
0005435839413	6003	Economy	66400.00
0005435472640	6003	Economy	66400.00
0005435472630	6003	Economy	66400.00
0005435839398	6003	Economy	66400.00
0005435839392	6003	Economy	66400.00
0005435839393	6003	Economy	66400.00
0005432537031	6003	Economy	66400.00
0005435839415	6003	Economy	66400.00
0005432537036	6003	Economy	66400.00
0005435839399	6003	Economy	66400.00
0005435472700	6003	Economy	66400.00
0005435839416	6003	Economy	66400.00
0005435839397	6003	Economy	66400.00
0005435839406	6003	Economy	66400.00
0005435839414	6003	Economy	66400.00
0005432660815	6003	Economy	66400.00
0005435839391	6003	Economy	66400.00
0005435472652	6003	Economy	66400.00
0005435839417	6003	Economy	66400.00
0005435839390	6003	Economy	66400.00
0005432659704	6003	Economy	66400.00
0005432537024	6003	Economy	66400.00
0005435839407	6003	Economy	66400.00
0005435472627	6003	Economy	66400.00
0005435839394	6003	Economy	66400.00
0005432659703	6003	Economy	66400.00
0005435839402	6003	Economy	66400.00
0005435472586	6003	Economy	66400.00
0005435839410	6003	Economy	66400.00
0005432537037	6003	Economy	66400.00
0005435472592	6003	Economy	66400.00
0005435839400	6003	Economy	66400.00
0005435839403	6003	Economy	66400.00
0005435839396	6003	Economy	66400.00
0005435839404	6003	Economy	66400.00
0005435472654	6003	Economy	66400.00
0005432660816	6003	Economy	66400.00
0005435839401	6003	Economy	66400.00
0005435472616	6003	Economy	66400.00
0005435839411	6003	Economy	66400.00
0005435839185	18038	Business	199300.00
0005435839247	18038	Business	199300.00
0005435839264	18038	Business	199300.00
0005432660791	18038	Business	199300.00
0005435472769	18038	Business	199300.00
0005435839124	18038	Business	199300.00
0005435839109	18038	Business	199300.00
0005435839122	18038	Business	199300.00
0005435839214	18038	Business	199300.00
0005432660784	18038	Business	199300.00
0005435839037	18038	Business	199300.00
0005435472779	18038	Business	199300.00
0005435839299	18038	Business	199300.00
0005435839300	18038	Economy	66400.00
0005435839113	18038	Economy	66400.00
0005435839196	18038	Economy	66400.00
0005435472773	18038	Economy	66400.00
0005435839036	18038	Economy	66400.00
0005435839224	18038	Economy	66400.00
0005435472772	18038	Economy	66400.00
0005435839093	18038	Economy	73100.00
0005435472766	18038	Economy	73100.00
0005435839262	18038	Economy	73100.00
0005435472774	18038	Economy	66400.00
0005435839265	18038	Economy	66400.00
0005432667423	18038	Economy	66400.00
0005435839186	18038	Economy	66400.00
0005435839102	18038	Economy	66400.00
0005435839123	18038	Economy	66400.00
0005435839263	18038	Economy	66400.00
0005432537056	18038	Economy	66400.00
0005435839116	18038	Economy	66400.00
0005435472770	18038	Economy	66400.00
0005435839110	18038	Economy	66400.00
0005435472781	18038	Economy	66400.00
0005435839115	18038	Economy	66400.00
0005435839048	18038	Economy	66400.00
0005435472777	18038	Economy	66400.00
0005435839146	18038	Economy	66400.00
0005435839187	18038	Economy	66400.00
0005435839035	18038	Economy	66400.00
0005435839088	18038	Economy	66400.00
0005432537055	18038	Economy	66400.00
0005435839197	18038	Economy	66400.00
0005435472780	18038	Economy	66400.00
0005435839074	18038	Economy	66400.00
0005435472778	18038	Economy	66400.00
0005435839089	18038	Economy	66400.00
0005435839260	18038	Economy	66400.00
0005432660792	18038	Economy	66400.00
0005435839175	18038	Economy	66400.00
0005435839159	18038	Economy	66400.00
0005435839301	18038	Economy	66400.00
0005435839225	18038	Economy	66400.00
0005435839090	18038	Economy	66400.00
0005435839168	18038	Economy	66400.00
0005435839213	18038	Economy	66400.00
0005435472768	18038	Economy	66400.00
0005435839207	18038	Economy	66400.00
0005435839184	18038	Economy	66400.00
0005435839181	18038	Economy	66400.00
0005435839261	18038	Economy	66400.00
0005432667425	18038	Economy	66400.00
0005435472776	18038	Economy	66400.00
0005435839150	18038	Economy	66400.00
0005435472775	18038	Economy	66400.00
0005432667424	18038	Economy	66400.00
0005432660785	18038	Economy	66400.00
0005435839156	18038	Economy	66400.00
0005435839149	18038	Economy	66400.00
0005435472767	18038	Economy	66400.00
0005435839038	18038	Economy	66400.00
0005432537054	18038	Economy	66400.00
0005435472765	18038	Economy	66400.00
0005435472771	18038	Economy	66400.00
0005433285069	23031	Business	15700.00
0005433285022	23031	Business	15700.00
0005433284931	23031	Business	15700.00
0005433285108	23031	Business	15700.00
0005433284929	23031	Business	15700.00
0005433285137	23031	Economy	5200.00
0005433284918	23031	Economy	5200.00
0005433285001	23031	Economy	5200.00
0005433284899	23031	Economy	5200.00
0005433284886	23031	Economy	5200.00
0005433284957	23031	Economy	5200.00
0005433284932	23031	Economy	5200.00
0005433285017	23031	Economy	5200.00
0005433284994	23031	Economy	5200.00
0005433284964	23031	Economy	5200.00
0005433285162	23031	Economy	5200.00
0005433285021	23031	Economy	5700.00
0005433285059	23031	Economy	5200.00
0005433284916	23031	Economy	5200.00
0005433284979	23031	Economy	5200.00
0005433284820	23031	Economy	5200.00
0005433284906	23031	Economy	5200.00
0005433285009	23031	Economy	5200.00
0005433284962	23031	Economy	5200.00
0005433284978	23031	Economy	5200.00
0005433285109	23031	Economy	5200.00
0005433284976	23031	Economy	5200.00
0005433285006	23031	Economy	5200.00
0005433285027	23031	Economy	5200.00
0005433285034	23031	Economy	5200.00
0005433284838	23031	Economy	5200.00
0005433285073	23031	Economy	5200.00
0005433284942	23031	Economy	5200.00
0005433284879	23031	Economy	5200.00
0005433284977	23031	Economy	5200.00
0005433285107	23031	Economy	5200.00
0005433285002	23031	Economy	5200.00
0005433285013	23031	Economy	5200.00
0005433285118	23031	Economy	5200.00
0005433285004	23031	Economy	5200.00
0005433284996	23031	Economy	5200.00
0005433284893	23031	Economy	5200.00
0005433285050	23031	Economy	5200.00
0005433284963	23031	Economy	5200.00
0005433285005	23031	Economy	5200.00
0005433285051	23031	Economy	5200.00
0005433285161	23031	Economy	5200.00
0005433284995	23031	Economy	5200.00
0005433284907	23031	Economy	5200.00
0005433284986	23031	Economy	5200.00
0005433284902	23031	Economy	5200.00
0005433285244	32097	Business	15700.00
0005433285236	32097	Business	15700.00
0005433285262	32097	Business	15700.00
0005433285253	32097	Business	15700.00
0005433285247	32097	Economy	5200.00
0005433285238	32097	Economy	5200.00
0005433285259	32097	Economy	5200.00
0005433285251	32097	Economy	5200.00
0005433285242	32097	Economy	5200.00
0005433285255	32097	Economy	5200.00
0005433285235	32097	Economy	5200.00
0005433285240	32097	Economy	5200.00
0005433285233	32097	Economy	5200.00
0005433285257	32097	Economy	5200.00
0005433285261	32097	Economy	5200.00
0005433285256	32097	Economy	5200.00
0005433285243	32097	Economy	5200.00
0005433285252	32097	Economy	5200.00
0005433285263	32097	Economy	5200.00
0005433285249	32097	Economy	5200.00
0005433285250	32097	Economy	5200.00
0005433285245	32097	Economy	5200.00
0005433285258	32097	Economy	5200.00
0005433285241	32097	Economy	5200.00
0005433285248	32097	Economy	5200.00
0005433285237	32097	Economy	5200.00
0005433285232	32097	Economy	5200.00
0005433285239	32097	Economy	5200.00
0005433285254	32097	Economy	5200.00
0005433285246	32097	Economy	5200.00
0005433285234	32097	Economy	5200.00
0005433285260	32097	Economy	5200.00
0005432802472	1474	Business	150400.00
0005432802471	1474	Business	150400.00
0005432892729	1474	Business	150400.00
0005432802488	1474	Business	150400.00
0005432802496	1474	Business	150400.00
0005432802479	1474	Business	150400.00
0005432802469	1474	Business	150400.00
0005432802494	1474	Economy	50100.00
0005432802468	1474	Business	150400.00
0005432802493	1474	Economy	50100.00
0005432802485	1474	Economy	50100.00
0005432892721	1474	Economy	55200.00
0005432802487	1474	Economy	50100.00
0005432802473	1474	Economy	50100.00
0005432892725	1474	Economy	50100.00
0005432802476	1474	Economy	50100.00
0005432892722	1474	Economy	50100.00
0005432802470	1474	Economy	50100.00
0005432892723	1474	Economy	50100.00
0005432802477	1474	Economy	50100.00
0005432802475	1474	Economy	50100.00
0005432802492	1474	Economy	50100.00
0005432802499	1474	Economy	50100.00
0005432802478	1474	Economy	50100.00
0005432802489	1474	Economy	50100.00
0005432802484	1474	Economy	50100.00
0005432802500	1474	Economy	50100.00
0005432802490	1474	Economy	50100.00
0005432802480	1474	Economy	50100.00
0005432892720	1474	Economy	50100.00
0005433112350	1474	Economy	50100.00
0005432802491	1474	Economy	50100.00
0005432802474	1474	Economy	50100.00
0005432802497	1474	Economy	50100.00
0005432802495	1474	Economy	50100.00
0005432802486	1474	Economy	50100.00
0005432892724	1474	Economy	50100.00
0005432802498	1474	Economy	50100.00
0005432802481	1474	Economy	50100.00
0005432802483	1474	Economy	50100.00
0005432802482	1474	Economy	50100.00
0005435852566	23862	Economy	13500.00
0005433475666	23862	Economy	12300.00
0005433475650	23862	Economy	12300.00
0005433475661	23862	Economy	12300.00
0005435852571	23862	Economy	12300.00
0005433475644	23862	Economy	12300.00
0005433475651	23862	Economy	12300.00
0005435852567	23862	Economy	12300.00
0005433475645	23862	Economy	12300.00
0005433475654	23862	Economy	12300.00
0005433475662	23862	Economy	12300.00
0005435852568	23862	Economy	12300.00
0005433475672	23862	Economy	12300.00
0005435852573	23862	Economy	12300.00
0005433475678	23862	Economy	12300.00
0005435852564	23862	Economy	12300.00
0005435852565	23862	Economy	12300.00
0005435852569	23862	Economy	12300.00
0005433475646	23862	Economy	12300.00
0005435852570	23862	Economy	12300.00
0005433475655	23862	Economy	12300.00
0005435852572	23862	Economy	12300.00
0005432535771	30631	Business	42100.00
0005432526846	30631	Business	42100.00
0005432535785	30631	Business	42100.00
0005435630966	30631	Business	42100.00
0005432526756	30631	Business	42100.00
0005432535789	30631	Business	42100.00
0005434067181	30631	Business	42100.00
0005432526486	30631	Business	42100.00
0005432526935	30631	Business	42100.00
0005435213451	30631	Business	42100.00
0005432526816	30631	Business	42100.00
0005434066917	30631	Business	42100.00
0005432526501	30631	Business	42100.00
0005435213464	30631	Business	42100.00
0005435213471	30631	Business	42100.00
0005434066597	30631	Business	42100.00
0005435725598	30631	Business	42100.00
0005432526280	30631	Business	42100.00
0005432526720	30631	Business	42100.00
0005432537043	30631	Business	42100.00
0005432526307	30631	Business	42100.00
0005435213447	30631	Business	42100.00
0005435213496	30631	Business	42100.00
0005434066658	30631	Business	42100.00
0005432526209	30631	Comfort	23900.00
0005435213504	30631	Comfort	23900.00
0005432428903	30631	Comfort	23900.00
0005432527216	30631	Comfort	23900.00
0005432527234	30631	Comfort	23900.00
0005434066887	30631	Comfort	23900.00
0005432527354	30631	Comfort	23900.00
0005432527093	30631	Comfort	23900.00
0005432211494	30631	Comfort	23900.00
0005435213501	30631	Comfort	23900.00
0005434066919	30631	Comfort	23900.00
0005434066530	30631	Comfort	23900.00
0005432527235	30631	Comfort	23900.00
0005435213467	30631	Comfort	23900.00
0005432526815	30631	Comfort	23900.00
0005432526567	30631	Comfort	23900.00
0005435213444	30631	Comfort	23900.00
0005435213473	30631	Comfort	23900.00
0005432527082	30631	Comfort	23900.00
0005435213462	30631	Comfort	23900.00
0005434066953	30631	Comfort	23900.00
0005432526256	30631	Comfort	23900.00
0005435213469	30631	Comfort	23900.00
0005434066794	30631	Comfort	23900.00
0005433656667	30631	Comfort	23900.00
0005432526761	30631	Comfort	23900.00
0005435213502	30631	Comfort	23900.00
0005432159853	30631	Comfort	23900.00
0005432526877	30631	Comfort	23900.00
0005432527215	30631	Comfort	23900.00
0005434067054	30631	Comfort	23900.00
0005435213506	30631	Comfort	23900.00
0005434066939	30631	Comfort	23900.00
0005434066797	30631	Comfort	23900.00
0005432526625	30631	Comfort	23900.00
0005434066780	30631	Comfort	23900.00
0005434066624	30631	Comfort	23900.00
0005434067001	30631	Comfort	23900.00
0005432526420	30631	Economy	14000.00
0005434066598	30631	Economy	14000.00
0005432526379	30631	Economy	14000.00
0005435213485	30631	Economy	14000.00
0005435213477	30631	Economy	14000.00
0005432211489	30631	Economy	14000.00
0005432526934	30631	Economy	14000.00
0005432526477	30631	Economy	14000.00
0005432526658	30631	Economy	14000.00
0005434066856	30631	Economy	14000.00
0005432526833	30631	Economy	14000.00
0005432159852	30631	Economy	14000.00
0005432526581	30631	Economy	14000.00
0005434066855	30631	Economy	14000.00
0005435213465	30631	Economy	14000.00
0005432526595	30631	Economy	14000.00
0005432159854	30631	Economy	14000.00
0005432527229	30631	Economy	14000.00
0005432526936	30631	Economy	14000.00
0005432526425	30631	Economy	14000.00
0005434066837	30631	Economy	14000.00
0005432526937	30631	Economy	14000.00
0005432526820	30631	Economy	14000.00
0005432526278	30631	Economy	14000.00
0005435213455	30631	Economy	14000.00
0005434066895	30631	Economy	14000.00
0005432527008	30631	Economy	14000.00
0005434066526	30631	Economy	14000.00
0005435213463	30631	Economy	14000.00
0005434066871	30631	Economy	14000.00
0005432526762	30631	Economy	14000.00
0005434066894	30631	Economy	14000.00
0005435213460	30631	Economy	14000.00
0005434066796	30631	Economy	14000.00
0005432526817	30631	Economy	14000.00
0005432526521	30631	Economy	14000.00
0005434066806	30631	Economy	14000.00
0005434066525	30631	Economy	14000.00
0005435725595	30631	Economy	14000.00
0005434066706	30631	Economy	14000.00
0005435213454	30631	Economy	14000.00
0005435213458	30631	Economy	14000.00
0005435213481	30631	Economy	14000.00
0005434066866	30631	Economy	14000.00
0005434066676	30631	Economy	14000.00
0005432526363	30631	Economy	14000.00
0005434066954	30631	Economy	14000.00
0005434066674	30631	Economy	14000.00
0005435725597	30631	Economy	14000.00
0005435213490	30631	Economy	14000.00
0005435213441	30631	Economy	14000.00
0005434066695	30631	Economy	14000.00
0005432526798	30631	Economy	14000.00
0005435213480	30631	Economy	14000.00
0005434066611	30631	Economy	15400.00
0005434066824	30631	Economy	15400.00
0005432527369	30631	Economy	14000.00
0005432526648	30631	Economy	14000.00
0005432527077	30631	Economy	14000.00
0005432526752	30631	Economy	15400.00
0005435213491	30631	Economy	15400.00
0005434066938	30631	Economy	14000.00
0005432527104	30631	Economy	14000.00
0005432526355	30631	Economy	14000.00
0005432526657	30631	Economy	14000.00
0005432526480	30631	Economy	14000.00
0005434066873	30631	Economy	14000.00
0005435725596	30631	Economy	14000.00
0005435213442	30631	Economy	14000.00
0005435630965	30631	Economy	14000.00
0005432526279	30631	Economy	14000.00
0005435630964	30631	Economy	14000.00
0005432526259	30631	Economy	14000.00
0005435725593	30631	Economy	14000.00
0005432526344	30631	Economy	14000.00
0005432526748	30631	Economy	14000.00
0005434066795	30631	Economy	14000.00
0005435213500	30631	Economy	14000.00
0005432526972	30631	Economy	14000.00
0005432526799	30631	Economy	14000.00
0005432527423	30631	Economy	14000.00
0005432526890	30631	Economy	14000.00
0005432527368	30631	Economy	14000.00
0005435213493	30631	Economy	14000.00
0005432526306	30631	Economy	14000.00
0005434066339	30631	Economy	14000.00
0005433656669	30631	Economy	14000.00
0005435213448	30631	Economy	14000.00
0005434066854	30631	Economy	14000.00
0005434066999	30631	Economy	14000.00
0005435213489	30631	Economy	14000.00
0005432526618	30631	Economy	14000.00
0005432159851	30631	Economy	14000.00
0005432526410	30631	Economy	14000.00
0005434066485	30631	Economy	14000.00
0005432527227	30631	Economy	14000.00
0005434067000	30631	Economy	14000.00
0005432526148	30631	Economy	14000.00
0005432526345	30631	Economy	14000.00
0005435213459	30631	Economy	14000.00
0005434066892	30631	Economy	14000.00
0005432526714	30631	Economy	14000.00
0005432526547	30631	Economy	14000.00
0005434066766	30631	Economy	14000.00
0005435213505	30631	Economy	14000.00
0005434066838	30631	Economy	14000.00
0005432526952	30631	Economy	14000.00
0005435213478	30631	Economy	14000.00
0005434066531	30631	Economy	14000.00
0005435213452	30631	Economy	14000.00
0005435213474	30631	Economy	14000.00
0005432526876	30631	Economy	14000.00
0005434067182	30631	Economy	14000.00
0005434066853	30631	Economy	14000.00
0005432526386	30631	Economy	14000.00
0005434066916	30631	Economy	14000.00
0005432526717	30631	Economy	14000.00
0005435213503	30631	Economy	14000.00
0005435213456	30631	Economy	14000.00
0005432211490	30631	Economy	14000.00
0005434066829	30631	Economy	14000.00
0005434067134	30631	Economy	14000.00
0005435725594	30631	Economy	14000.00
0005434066893	30631	Economy	14000.00
0005432526747	30631	Economy	14000.00
0005435213483	30631	Economy	14000.00
0005432527007	30631	Economy	14000.00
0005432526448	30631	Economy	14000.00
0005432527187	30631	Economy	14000.00
0005432526391	30631	Economy	14000.00
0005432527014	30631	Economy	14000.00
0005432526351	30631	Economy	14000.00
0005432526153	30631	Economy	14000.00
0005435213479	30631	Economy	14000.00
0005432526755	30631	Economy	14000.00
0005432527247	30631	Economy	14000.00
0005435213450	30631	Economy	14000.00
0005434067055	30631	Economy	14000.00
0005435213439	30631	Economy	14000.00
0005432526689	30631	Economy	14000.00
0005435213449	30631	Economy	14000.00
0005432526646	30631	Economy	14000.00
0005434066656	30631	Economy	14000.00
0005435213486	30631	Economy	14000.00
0005434066769	30631	Economy	14000.00
0005432526726	30631	Economy	14000.00
0005432526637	30631	Economy	14000.00
0005435213475	30631	Economy	14000.00
0005432526627	30631	Economy	14000.00
0005435213492	30631	Economy	14000.00
0005435213484	30631	Economy	14000.00
0005432526647	30631	Economy	14000.00
0005434066900	30631	Economy	14000.00
0005432526201	30631	Economy	14000.00
0005432526421	30631	Economy	14000.00
0005434066678	30631	Economy	14000.00
0005434066948	30631	Economy	15400.00
0005435213497	30631	Economy	14000.00
0005435213488	30631	Economy	15400.00
0005432526930	30631	Economy	15400.00
0005434066872	30631	Economy	15400.00
0005435630963	30631	Economy	14000.00
0005435213476	30631	Economy	14000.00
0005432526470	30631	Economy	14000.00
0005432526378	30631	Economy	14000.00
0005432526666	30631	Economy	14000.00
0005432527015	30631	Economy	14000.00
0005435213499	30631	Economy	14000.00
0005435213461	30631	Economy	14000.00
0005435213453	30631	Economy	14000.00
0005432526939	30631	Economy	14000.00
0005433656668	30631	Economy	14000.00
0005434066823	30631	Economy	14000.00
0005434067111	30631	Economy	14000.00
0005435213498	30631	Economy	14000.00
0005432527330	30631	Economy	14000.00
0005434066798	30631	Economy	14000.00
0005432526245	30631	Economy	14000.00
0005434066949	30631	Economy	14000.00
0005432526364	30631	Economy	14000.00
0005434066652	30631	Economy	14000.00
0005435213494	30631	Economy	14000.00
0005432526954	30631	Economy	14000.00
0005432526626	30631	Economy	14000.00
0005432211492	30631	Economy	14000.00
0005432526522	30631	Economy	14000.00
0005432526955	30631	Economy	14000.00
0005432526933	30631	Economy	14000.00
0005434066709	30631	Economy	14000.00
0005432526835	30631	Economy	14000.00
0005432526845	30631	Economy	14000.00
0005432535770	30631	Economy	14000.00
0005432211491	30631	Economy	14000.00
0005432526623	30631	Economy	14000.00
0005432526478	30631	Economy	14000.00
0005432526202	30631	Economy	14000.00
0005434066718	30631	Economy	14000.00
0005432526667	30631	Economy	14000.00
0005432527355	30631	Economy	14000.00
0005435213487	30631	Economy	14000.00
0005435213457	30631	Economy	14000.00
0005432211495	30631	Economy	14000.00
0005435213445	30631	Economy	14000.00
0005434066599	30631	Economy	14000.00
0005432526971	30631	Economy	14000.00
0005434066852	30631	Economy	14000.00
0005434066810	30631	Economy	14000.00
0005432526456	30631	Economy	14000.00
0005435213470	30631	Economy	14000.00
0005434066748	30631	Economy	14000.00
0005435630967	30631	Economy	14000.00
0005435213468	30631	Economy	14000.00
0005434066612	30631	Economy	14000.00
0005435213466	30631	Economy	14000.00
0005432526931	30631	Economy	14000.00
0005432526721	30631	Economy	14000.00
0005432211493	30631	Economy	14000.00
0005432526577	30631	Economy	14000.00
0005435213443	30631	Economy	14000.00
0005432527080	30631	Economy	14000.00
0005434066623	30631	Economy	14000.00
0005434066610	30631	Economy	14000.00
0005435213482	30631	Economy	14000.00
0005432526575	30631	Economy	14000.00
0005432526152	30631	Economy	14000.00
0005432526619	30631	Economy	14000.00
0005435213472	30631	Economy	14000.00
0005432527066	30631	Economy	14000.00
0005432526883	30631	Economy	14000.00
0005432526834	30631	Economy	14000.00
0005432526698	30631	Economy	14000.00
0005434066445	30631	Economy	14000.00
0005432526797	30631	Economy	14000.00
0005432537042	30631	Economy	14000.00
0005435213495	30631	Economy	14000.00
0005432428894	30631	Economy	14000.00
0005434066836	30631	Economy	14000.00
0005432527081	30631	Economy	14000.00
0005435213446	30631	Economy	14000.00
0005432526515	30631	Economy	14000.00
0005432526782	30631	Economy	14000.00
0005432526343	30631	Economy	14000.00
0005432526488	30631	Economy	14000.00
0005432526305	30631	Economy	14000.00
0005435213440	30631	Economy	14000.00
0005432526739	30631	Economy	14000.00
0005432526678	30631	Economy	14000.00
0005432526779	30631	Economy	14000.00
0005432526389	30631	Economy	14000.00
0005434066675	30631	Economy	14000.00
0005435652642	24867	Business	9800.00
0005435652656	24867	Business	9800.00
0005433367863	24867	Business	9800.00
0005433367861	24867	Business	9800.00
0005433367853	24867	Business	9800.00
0005435652569	24867	Business	9800.00
0005435652663	24867	Business	9800.00
0005435652575	24867	Business	9800.00
0005435652639	24867	Business	9800.00
0005435652477	24867	Business	9800.00
0005433367862	24867	Business	9800.00
0005433367843	24867	Economy	3300.00
0005433367839	24867	Economy	3300.00
0005433367867	24867	Economy	3300.00
0005435652487	24867	Economy	3300.00
0005433367840	24867	Economy	3300.00
0005435652640	24867	Economy	3300.00
0005433367868	24867	Economy	3300.00
0005433367849	24867	Economy	3300.00
0005435652549	24867	Economy	3300.00
0005435652438	24867	Economy	3600.00
0005435652638	24867	Economy	3600.00
0005435652451	24867	Economy	3600.00
0005435652527	24867	Economy	3600.00
0005435652407	24867	Economy	3600.00
0005433367860	24867	Economy	3300.00
0005433367870	24867	Economy	3300.00
0005435652511	24867	Economy	3300.00
0005433367846	24867	Economy	3300.00
0005433367858	24867	Economy	3300.00
0005435652406	24867	Economy	3300.00
0005435652486	24867	Economy	3300.00
0005435652494	24867	Economy	3300.00
0005433367864	24867	Economy	3300.00
0005433367845	24867	Economy	3300.00
0005435652572	24867	Economy	3300.00
0005433367844	24867	Economy	3300.00
0005435652617	24867	Economy	3300.00
0005433367850	24867	Economy	3300.00
0005433367836	24867	Economy	3300.00
0005433367852	24867	Economy	3300.00
0005433367842	24867	Economy	3300.00
0005433367859	24867	Economy	3300.00
0005433367851	24867	Economy	3300.00
0005435652476	24867	Economy	3300.00
0005435652658	24867	Economy	3300.00
0005433367838	24867	Economy	3300.00
0005433367835	24867	Economy	3300.00
0005435652576	24867	Economy	3300.00
0005433367865	24867	Economy	3300.00
0005433367834	24867	Economy	3300.00
0005435652498	24867	Economy	3300.00
0005435652496	24867	Economy	3300.00
0005435652503	24867	Economy	3300.00
0005435652512	24867	Economy	3300.00
0005435652402	24867	Economy	3300.00
0005433367833	24867	Economy	3300.00
0005433367869	24867	Economy	3300.00
0005435652499	24867	Economy	3300.00
0005433367856	24867	Economy	3300.00
0005435652603	24867	Economy	3300.00
0005433367857	24867	Economy	3300.00
0005435652568	24867	Economy	3300.00
0005433367855	24867	Economy	3300.00
0005433367847	24867	Economy	3300.00
0005435652502	24867	Economy	3300.00
0005433367866	24867	Economy	3300.00
0005433367854	24867	Economy	3300.00
0005435652504	24867	Economy	3300.00
0005433367848	24867	Economy	3300.00
0005435652671	24867	Economy	3300.00
0005435652530	24867	Economy	3300.00
0005435652604	24867	Economy	3300.00
0005435652500	24867	Economy	3300.00
0005435652522	24867	Economy	3300.00
0005435652587	24867	Economy	3300.00
0005433367841	24867	Economy	3300.00
0005433367837	24867	Economy	3300.00
0005434979744	2016	Economy	10500.00
0005434979746	2016	Economy	10500.00
0005434979765	2016	Economy	10500.00
0005434979766	2016	Economy	10500.00
0005434979767	2016	Economy	9500.00
0005434979754	2016	Economy	9500.00
0005434979762	2016	Economy	9500.00
0005434979751	2016	Economy	9500.00
0005434979755	2016	Economy	9500.00
0005435801691	2016	Economy	9500.00
0005434979750	2016	Economy	9500.00
0005434979772	2016	Economy	9500.00
0005434979774	2016	Economy	9500.00
0005435801692	2016	Economy	9500.00
0005434979771	2016	Economy	9500.00
0005434979760	2016	Economy	9500.00
0005434979761	2016	Economy	9500.00
0005434979752	2016	Economy	9500.00
0005434979745	2016	Economy	9500.00
0005434979763	2016	Economy	9500.00
0005434979757	2016	Economy	9500.00
0005435801693	2016	Economy	9500.00
0005434979768	2016	Economy	9500.00
0005434979764	2016	Economy	9500.00
0005434979759	2016	Economy	9500.00
0005434979756	2016	Economy	9500.00
0005434979749	2016	Economy	9500.00
0005434979753	2016	Economy	9500.00
0005434979748	2016	Economy	9500.00
0005435801694	2016	Economy	9500.00
0005434979747	2016	Economy	9500.00
0005434979773	2016	Economy	9500.00
0005434979770	2016	Economy	9500.00
0005434979758	2016	Economy	9500.00
0005434979769	2016	Economy	9500.00
0005434979559	23567	Economy	9500.00
0005434979485	23567	Economy	9500.00
0005434979416	23567	Economy	9500.00
0005434979410	23567	Economy	9500.00
0005434979421	23567	Economy	9500.00
0005434979474	23567	Economy	9500.00
0005434979374	23567	Economy	9500.00
0005434979426	23567	Economy	9500.00
0005434979475	23567	Economy	9500.00
0005434979373	23567	Economy	9500.00
0005434979358	23567	Economy	9500.00
0005435801664	23567	Economy	9500.00
0005434979567	23567	Economy	9500.00
0005435801661	23567	Economy	9500.00
0005434979413	23567	Economy	9500.00
0005434952528	2613	Economy	5300.00
0005434952527	2613	Economy	5300.00
0005433256407	2614	Economy	5300.00
0005433256411	2614	Economy	5300.00
0005433256406	2614	Economy	5300.00
0005434952495	28259	Economy	5300.00
0005433256418	28259	Economy	5300.00
0005433256419	28259	Economy	5300.00
0005434952513	28259	Economy	5300.00
0005433256420	28259	Economy	5300.00
0005433111504	19766	Economy	8700.00
0005433111503	19766	Economy	8700.00
0005433111505	19766	Economy	8700.00
0005433112371	19766	Economy	8700.00
0005433112372	19766	Economy	8700.00
0005433112350	20029	Economy	8700.00
0005434137167	11916	Business	9700.00
0005434137110	11916	Business	9700.00
0005434136876	11916	Business	9700.00
0005434137010	11916	Business	9700.00
0005434137435	11916	Business	9700.00
0005434137436	11916	Business	9700.00
0005434137104	11916	Business	9700.00
0005434137124	11916	Business	9700.00
0005434137465	11916	Economy	3200.00
0005434137416	11916	Economy	3200.00
0005434137386	11916	Economy	3200.00
0005434137323	11916	Economy	3200.00
0005434137283	11916	Economy	3200.00
0005434137013	11916	Economy	3200.00
0005434137284	11916	Economy	3200.00
0005434137290	11916	Economy	3200.00
0005434137460	11916	Economy	3200.00
0005434137433	11916	Economy	3500.00
0005434137282	11916	Economy	3500.00
0005434137246	11916	Economy	3500.00
0005434137324	11916	Economy	3500.00
0005434137215	11916	Economy	3200.00
0005434137384	11916	Economy	3200.00
0005434137458	11916	Economy	3200.00
0005434137339	11916	Economy	3200.00
0005434137352	11916	Economy	3200.00
0005434137463	11916	Economy	3200.00
0005434137424	11916	Economy	3200.00
0005434137107	11916	Economy	3200.00
0005434137340	11916	Economy	3200.00
0005434137011	11916	Economy	3200.00
0005434137502	11916	Economy	3200.00
0005434137263	11916	Economy	3200.00
0005434137016	11916	Economy	3200.00
0005434137385	11916	Economy	3200.00
0005434137206	11916	Economy	3200.00
0005434137326	11916	Economy	3200.00
0005434137169	11916	Economy	3200.00
0005434137247	11916	Economy	3200.00
0005434137456	11916	Economy	3200.00
0005434137557	11916	Economy	3200.00
0005434137479	11916	Economy	3200.00
0005434137488	11916	Economy	3200.00
0005434137335	11916	Economy	3200.00
0005434137018	11916	Economy	3200.00
0005434137484	11916	Economy	3200.00
0005434136875	11916	Economy	3200.00
0005434137269	11916	Economy	3200.00
0005434137093	11916	Economy	3200.00
0005434137464	11916	Economy	3200.00
0005434137551	11916	Economy	3200.00
0005434137312	11916	Economy	3200.00
0005434137103	11916	Economy	3200.00
0005434137327	11916	Economy	3200.00
0005434137261	11916	Economy	3200.00
0005434137301	11916	Economy	3200.00
0005434137216	11916	Economy	3200.00
0005434137459	11916	Economy	3200.00
0005434137457	11916	Economy	3200.00
0005434137434	11916	Economy	3200.00
0005434137219	11916	Economy	3200.00
0005434137168	11916	Economy	3200.00
0005434137538	11916	Economy	3200.00
0005434137461	11916	Economy	3200.00
0005434137552	11916	Economy	3200.00
0005434137381	11916	Economy	3200.00
0005434137109	11916	Economy	3200.00
0005434137281	11916	Economy	3200.00
0005434137032	11916	Economy	3200.00
0005434137448	11916	Economy	3200.00
0005434137425	11916	Economy	3200.00
0005434137154	11916	Economy	3200.00
0005434137259	11916	Economy	3200.00
0005434137455	11916	Economy	3200.00
0005434137334	11916	Economy	3200.00
0005434137501	11916	Economy	3200.00
0005434137289	11916	Economy	3200.00
0005434137341	11916	Economy	3200.00
0005434137487	11916	Economy	3200.00
0005434137268	11916	Economy	3200.00
0005434137462	11916	Economy	3200.00
0005434137267	11916	Economy	3200.00
0005434137955	28725	Business	9700.00
0005434138021	28725	Business	9700.00
0005434137961	28725	Business	9700.00
0005434137992	28725	Business	9700.00
0005434138033	28725	Business	9700.00
0005434138004	28725	Business	9700.00
0005434138031	28725	Business	9700.00
0005434138017	28725	Business	9700.00
0005434137971	28725	Business	9700.00
0005434138016	28725	Business	9700.00
0005434138026	28725	Economy	3200.00
0005434137974	28725	Economy	3200.00
0005434138034	28725	Economy	3200.00
0005434138028	28725	Economy	3200.00
0005434138029	28725	Economy	3200.00
0005434137988	28725	Economy	3200.00
0005434137993	28725	Economy	3200.00
0005434138018	28725	Economy	3200.00
0005434137999	28725	Economy	3200.00
0005434137962	28725	Economy	3500.00
0005434137970	28725	Economy	3500.00
0005434137994	28725	Economy	3500.00
0005434137958	28725	Economy	3500.00
0005434138030	28725	Economy	3500.00
0005434137996	28725	Economy	3200.00
0005434138027	28725	Economy	3200.00
0005434137997	28725	Economy	3200.00
0005434138032	28725	Economy	3200.00
0005434137989	28725	Economy	3200.00
0005434137965	28725	Economy	3200.00
0005434137985	28725	Economy	3200.00
0005434137959	28725	Economy	3200.00
0005434137960	28725	Economy	3200.00
0005434137978	28725	Economy	3200.00
0005434137973	28725	Economy	3200.00
0005434137981	28725	Economy	3200.00
0005434138013	28725	Economy	3200.00
0005434137969	28725	Economy	3200.00
0005434137990	28725	Economy	3200.00
0005434138011	28725	Economy	3200.00
0005434137954	28725	Economy	3200.00
0005434138003	28725	Economy	3200.00
0005434137976	28725	Economy	3200.00
0005434137977	28725	Economy	3200.00
0005434137987	28725	Economy	3200.00
0005434138012	28725	Economy	3200.00
0005434137983	28725	Economy	3200.00
0005434137967	28725	Economy	3200.00
0005434138002	28725	Economy	3200.00
0005434138000	28725	Economy	3200.00
0005434138022	28725	Economy	3200.00
0005434138007	28725	Economy	3200.00
0005434138025	28725	Economy	3200.00
0005434138001	28725	Economy	3200.00
0005434138020	28725	Economy	3200.00
0005434138014	28725	Economy	3200.00
0005434138008	28725	Economy	3200.00
0005434137975	28725	Economy	3200.00
0005434138010	28725	Economy	3200.00
0005434138015	28725	Economy	3200.00
0005434137972	28725	Economy	3200.00
0005434138019	28725	Economy	3200.00
0005434137982	28725	Economy	3200.00
0005434137963	28725	Economy	3200.00
0005434138023	28725	Economy	3200.00
0005434137979	28725	Economy	3200.00
0005434138005	28725	Economy	3200.00
0005434137956	28725	Economy	3200.00
0005434138024	28725	Economy	3200.00
0005434137953	28725	Economy	3200.00
0005434137966	28725	Economy	3200.00
0005434138009	28725	Economy	3200.00
0005434137964	28725	Economy	3200.00
0005434137998	28725	Economy	3200.00
0005434137957	28725	Economy	3200.00
0005434137991	28725	Economy	3200.00
0005434137968	28725	Economy	3200.00
0005434138006	28725	Economy	3200.00
0005434137984	28725	Economy	3200.00
0005434137986	28725	Economy	3200.00
0005434137980	28725	Economy	3200.00
0005434137995	28725	Economy	3200.00
0005434466450	6573	Economy	23000.00
0005434466447	6573	Economy	23000.00
0005434466451	6573	Economy	20900.00
0005434466443	6573	Economy	20900.00
0005434466446	6573	Economy	20900.00
0005434466449	6573	Economy	20900.00
0005435312780	6573	Economy	20900.00
0005434466454	6573	Economy	20900.00
0005435312785	6573	Economy	20900.00
0005434466452	6573	Economy	20900.00
0005434466457	6573	Economy	20900.00
0005435312772	6573	Economy	20900.00
0005434466455	6573	Economy	20900.00
0005434466444	6573	Economy	20900.00
0005434466456	6573	Economy	20900.00
0005435312783	6573	Economy	20900.00
0005434466453	6573	Economy	20900.00
0005435312777	6573	Economy	20900.00
0005435312773	6573	Economy	20900.00
0005435312784	6573	Economy	20900.00
0005435312781	6573	Economy	20900.00
0005434466448	6573	Economy	20900.00
0005435312782	6573	Economy	20900.00
0005434466445	6573	Economy	20900.00
0005433534496	6826	Economy	10900.00
0005433538864	6826	Economy	10900.00
0005433534495	6826	Economy	9900.00
0005433538863	6826	Economy	9900.00
0005433538857	6826	Economy	9900.00
0005435259725	6826	Economy	9900.00
0005435259724	6826	Economy	9900.00
0005433538865	6826	Economy	9900.00
0005435259715	6826	Economy	9900.00
0005435259720	6826	Economy	9900.00
0005433538859	6826	Economy	9900.00
0005435259716	6826	Economy	9900.00
0005433538862	6826	Economy	9900.00
0005433538860	6826	Economy	9900.00
0005433538858	6826	Economy	9900.00
0005433538861	6826	Economy	9900.00
0005433538806	25012	Economy	10900.00
0005435259752	25012	Economy	9900.00
0005433538779	25012	Economy	9900.00
0005433538778	25012	Economy	9900.00
0005433538807	25012	Economy	9900.00
0005435259751	25012	Economy	9900.00
0005435259750	25012	Economy	9900.00
0005433538818	25012	Economy	9900.00
0005433534485	25012	Economy	9900.00
0005435259753	25012	Economy	9900.00
0005435259754	25012	Economy	9900.00
0005433534472	25012	Economy	9900.00
0005433538794	25012	Economy	9900.00
0005432922472	837	Economy	14600.00
0005433511944	837	Economy	14600.00
0005432922485	837	Economy	14600.00
0005432922486	837	Economy	14600.00
0005433511940	837	Economy	14600.00
0005433511946	837	Economy	14600.00
0005433511943	837	Economy	14600.00
0005432922482	837	Economy	14600.00
0005432922501	837	Economy	14600.00
0005433511945	837	Economy	14600.00
0005433511941	837	Economy	14600.00
0005433511942	837	Economy	14600.00
0005433511868	16166	Economy	14600.00
0005433511873	16166	Economy	14600.00
0005433511891	16166	Economy	14600.00
0005433511867	16166	Economy	14600.00
0005432922520	16166	Economy	14600.00
0005433511872	16166	Economy	14600.00
0005433511886	16166	Economy	14600.00
0005432922522	16166	Economy	14600.00
0005432922521	16166	Economy	14600.00
0005433511871	16166	Economy	14600.00
0005433511903	16166	Economy	14600.00
0005432922523	16166	Economy	14600.00
0005433511885	16166	Economy	14600.00
0005433511883	16166	Economy	14600.00
0005433511897	16166	Economy	14600.00
0005433475701	4025	Economy	13500.00
0005433475703	4025	Economy	13500.00
0005433475705	4025	Economy	12300.00
0005435852546	4025	Economy	12300.00
0005433475704	4025	Economy	12300.00
0005433475706	4025	Economy	12300.00
0005433475699	4025	Economy	12300.00
0005433475698	4025	Economy	12300.00
0005433475702	4025	Economy	12300.00
0005433475700	4025	Economy	12300.00
0005435852544	4025	Economy	12300.00
0005434950525	3682	Economy	7900.00
0005435916141	3682	Economy	7900.00
0005435697312	3682	Economy	7900.00
0005434950524	3682	Economy	7200.00
0005434950527	3682	Economy	7200.00
0005435935019	3682	Economy	7200.00
0005435697324	3682	Economy	7200.00
0005435697311	3682	Economy	7200.00
0005435697310	3682	Economy	7200.00
0005435697318	3682	Economy	7200.00
0005435697319	3682	Economy	7200.00
0005435697327	3682	Economy	7200.00
0005435697303	3682	Economy	7200.00
0005435935024	3682	Economy	7200.00
0005435935023	3682	Economy	7200.00
0005435697330	3682	Economy	7200.00
0005435697306	3682	Economy	7200.00
0005435697321	3682	Economy	7200.00
0005435697305	3682	Economy	7200.00
0005435697328	3682	Economy	7200.00
0005434950526	3682	Economy	7200.00
0005435935031	3682	Economy	7200.00
0005435697316	3682	Economy	7200.00
0005435697308	3682	Economy	7200.00
0005435697313	3682	Economy	7200.00
0005435697326	3682	Economy	7200.00
0005434950523	3682	Economy	7200.00
0005435697315	3682	Economy	7200.00
0005435697314	3682	Economy	7200.00
0005435935022	3682	Economy	7200.00
0005435697307	3682	Economy	7200.00
0005435935032	3682	Economy	7200.00
0005435697325	3682	Economy	7200.00
0005435697322	3682	Economy	7200.00
0005435697317	3682	Economy	7200.00
0005435697304	3682	Economy	7200.00
0005435697323	3682	Economy	7200.00
0005435697320	3682	Economy	7200.00
0005435697309	3682	Economy	7200.00
0005435697329	3682	Economy	7200.00
0005435697068	16278	Economy	7900.00
0005435696878	16278	Economy	7900.00
0005434950473	16278	Economy	7900.00
0005435697057	16278	Economy	7900.00
0005435697158	16278	Economy	7200.00
0005435697119	16278	Economy	7200.00
0005435916165	16278	Economy	7200.00
0005435696991	16278	Economy	7200.00
0005435696920	16278	Economy	7200.00
0005435935039	16278	Economy	7200.00
0005435697016	16278	Economy	7200.00
0005435697001	16278	Economy	7200.00
0005434950472	16278	Economy	7200.00
0005435697039	16278	Economy	7200.00
0005435697175	16278	Economy	7200.00
0005435935038	16278	Economy	7200.00
0005435697018	16278	Economy	7200.00
0005435696921	16278	Economy	7200.00
0005435697069	16278	Economy	7200.00
0005435697143	16278	Economy	7200.00
0005435696879	16278	Economy	7200.00
0005435697055	16278	Economy	7200.00
0005435697116	16278	Economy	7200.00
0005435935040	16278	Economy	7200.00
0005435697103	16278	Economy	7200.00
0005435696986	16278	Economy	7200.00
0005435697022	16278	Economy	7200.00
0005435696993	16278	Economy	7200.00
0005435697176	16278	Economy	7200.00
0005435696994	16278	Economy	7200.00
0005435696938	16278	Economy	7200.00
0005435916166	16278	Economy	7200.00
0005435697054	16278	Economy	7200.00
0005435697121	16278	Economy	7200.00
0005435697070	16278	Economy	7200.00
0005435697194	16278	Economy	7200.00
0005435935041	16278	Economy	7200.00
0005435916164	16278	Economy	7200.00
0005435697118	16278	Economy	7200.00
0005435697193	16278	Economy	7200.00
0005435697017	16278	Economy	7200.00
0005434950500	16278	Economy	7200.00
0005435697056	16278	Economy	7200.00
0005434950488	16278	Economy	7200.00
0005435697002	16278	Economy	7200.00
0005435696944	16278	Economy	7200.00
0005434606823	3934	Economy	21300.00
0005432609728	3934	Economy	21300.00
0005434606825	3934	Economy	21300.00
0005434604892	3934	Economy	21300.00
0005432607561	3934	Economy	19300.00
0005433519453	3934	Economy	19300.00
0005434604895	3934	Economy	19300.00
0005434606824	3934	Economy	19300.00
0005432607564	3934	Economy	19300.00
0005434606827	3934	Economy	19300.00
0005434606826	3934	Economy	19300.00
0005435841470	3934	Economy	19300.00
0005432609729	3934	Economy	19300.00
0005432609726	3934	Economy	19300.00
0005433519455	3934	Economy	19300.00
0005434604896	3934	Economy	19300.00
0005432607562	3934	Economy	19300.00
0005433519452	3934	Economy	19300.00
0005433519454	3934	Economy	19300.00
0005433519451	3934	Economy	19300.00
0005435841461	3934	Economy	19300.00
0005434604893	3934	Economy	19300.00
0005432609727	3934	Economy	19300.00
0005432607565	3934	Economy	19300.00
0005435842317	3934	Economy	19300.00
0005434604894	3934	Economy	19300.00
0005432607563	3934	Economy	19300.00
0005433519402	22049	Economy	21300.00
0005433519424	22049	Economy	19300.00
0005434606774	22049	Economy	19300.00
0005433519410	22049	Economy	19300.00
0005435853610	22049	Economy	19300.00
0005434606787	22049	Economy	19300.00
0005434606768	22049	Economy	19300.00
0005434606786	22049	Economy	19300.00
0005433519409	22049	Economy	19300.00
0005435853609	22049	Economy	19300.00
0005435853611	22049	Economy	19300.00
0005434606769	22049	Economy	19300.00
0005434606776	22049	Economy	19300.00
0005433519401	22049	Economy	19300.00
0005433348926	718	Economy	3700.00
0005435628719	718	Economy	3700.00
0005433348927	718	Economy	3700.00
0005435628723	718	Economy	3700.00
0005433348923	718	Economy	3700.00
0005435628720	718	Economy	3700.00
0005433348942	718	Economy	3700.00
0005435628722	718	Economy	3700.00
0005433348947	718	Economy	3700.00
0005435628721	718	Economy	3700.00
0005435628718	718	Economy	3700.00
0005435628690	15995	Economy	3700.00
0005433348985	15995	Economy	3700.00
0005433348984	15995	Economy	3700.00
0005435628685	15995	Economy	3700.00
0005433348988	15995	Economy	3700.00
0005433348986	15995	Economy	3700.00
0005435628686	15995	Economy	3700.00
0005433348982	15995	Economy	3700.00
0005433348983	15995	Economy	3700.00
0005433348987	15995	Economy	3700.00
0005434446515	17205	Economy	7100.00
0005433159283	17205	Economy	7100.00
0005434446517	17205	Economy	7100.00
0005434445243	17205	Economy	7100.00
0005433159284	17205	Economy	7100.00
0005434446514	17205	Economy	7100.00
0005434446516	17205	Economy	7100.00
0005433159285	17205	Economy	7100.00
0005433159312	17561	Economy	7100.00
0005433159310	17561	Economy	7100.00
0005434445222	17561	Economy	7100.00
0005434445219	17561	Economy	7100.00
0005434445221	17561	Economy	7100.00
0005433159313	17561	Economy	7100.00
0005433159311	17561	Economy	7100.00
0005434445220	17561	Economy	7100.00
0005435383088	7882	Economy	5900.00
0005435383097	7882	Economy	5900.00
0005435132871	7882	Economy	5400.00
0005435132868	7882	Economy	5400.00
0005435383079	7882	Economy	5400.00
0005435132876	7882	Economy	5400.00
0005435383081	7882	Economy	5400.00
0005435383078	7882	Economy	5400.00
0005435132875	7882	Economy	5400.00
0005435383080	7882	Economy	5400.00
0005435132877	7882	Economy	5400.00
0005435383077	7882	Economy	5400.00
0005435383096	7882	Economy	5400.00
0005435132867	7882	Economy	5400.00
0005435132873	7882	Economy	5400.00
0005435132869	7882	Economy	5400.00
0005435383110	7882	Economy	5400.00
0005435383099	7882	Economy	5400.00
0005435132872	7882	Economy	5400.00
0005435383098	7882	Economy	5400.00
0005435132874	7882	Economy	5400.00
0005435383104	7882	Economy	5400.00
0005435132870	7882	Economy	5400.00
0005435383143	33120	Economy	5400.00
0005435132823	33120	Economy	5400.00
0005435132746	33120	Economy	5400.00
0005435132810	33120	Economy	5400.00
0005435132747	33120	Economy	5400.00
0005435132824	33120	Economy	5400.00
0005435132806	33120	Economy	5400.00
0005435383144	33120	Economy	5400.00
0005435383145	33120	Economy	5400.00
0005435383146	33120	Economy	5400.00
0005435383147	33120	Economy	5400.00
0005435132770	33120	Economy	5400.00
0005435132777	33120	Economy	5400.00
0005435160292	7490	Economy	13800.00
0005435160294	7490	Economy	13800.00
0005435390183	7490	Economy	12500.00
0005435390185	7490	Economy	12500.00
0005435160288	7490	Economy	12500.00
0005435160297	7490	Economy	12500.00
0005435390190	7490	Economy	12500.00
0005435160298	7490	Economy	12500.00
0005435160287	7490	Economy	12500.00
0005435160291	7490	Economy	12500.00
0005435160289	7490	Economy	12500.00
0005435160290	7490	Economy	12500.00
0005435390197	7490	Economy	12500.00
0005435160295	7490	Economy	12500.00
0005435390170	7490	Economy	12500.00
0005435390168	7490	Economy	12500.00
0005435160286	7490	Economy	12500.00
0005435160296	7490	Economy	12500.00
0005435390167	7490	Economy	12500.00
0005435160293	7490	Economy	12500.00
0005435390169	7490	Economy	12500.00
0005435160185	29546	Economy	13800.00
0005435390230	29546	Economy	13800.00
0005435390236	29546	Economy	13800.00
0005435160196	29546	Economy	12500.00
0005435160225	29546	Economy	12500.00
0005435390235	29546	Economy	12500.00
0005435160154	29546	Economy	12500.00
0005435160234	29546	Economy	12500.00
0005435390234	29546	Economy	12500.00
0005435160153	29546	Economy	12500.00
0005435160208	29546	Economy	12500.00
0005435390237	29546	Economy	12500.00
0005435160266	29546	Economy	12500.00
0005435390231	29546	Economy	12500.00
0005435160147	29546	Economy	12500.00
0005435160210	29546	Economy	12500.00
0005435160209	29546	Economy	12500.00
0005435160191	29546	Economy	12500.00
0005435160186	29546	Economy	12500.00
0005435160148	29546	Economy	12500.00
0005435160246	29546	Economy	12500.00
0005435160238	29546	Economy	12500.00
0005435390233	29546	Economy	12500.00
0005435390232	29546	Economy	12500.00
0005435160211	29546	Economy	12500.00
0005435160149	29546	Economy	12500.00
0005435178494	18459	Economy	4900.00
0005432398155	18459	Economy	4900.00
0005432398168	18459	Economy	4900.00
0005432398162	18459	Economy	4900.00
0005432394053	18459	Economy	4900.00
0005432398161	18459	Economy	4900.00
0005432398172	18459	Economy	4900.00
0005432398160	18459	Economy	4900.00
0005432394068	18459	Economy	4900.00
0005432398157	18459	Economy	4900.00
0005432398171	18459	Economy	4900.00
0005432398156	18459	Economy	4900.00
0005435179386	27161	Economy	4900.00
0005432400116	27161	Economy	4900.00
0005435179385	27161	Economy	4900.00
0005432398190	27161	Economy	4900.00
0005432398189	27161	Economy	4900.00
0005432400117	27161	Economy	4900.00
0005432400115	27161	Economy	4900.00
0005432398191	27161	Economy	4900.00
0005435178477	27161	Economy	4900.00
0005432400114	27161	Economy	4900.00
0005432398188	27161	Economy	4900.00
0005432639101	2248	Business	87300.00
0005432639099	2248	Business	87300.00
0005432639131	2248	Business	87300.00
0005432639107	2248	Business	87300.00
0005432865916	2248	Business	87300.00
0005432639094	2248	Business	87300.00
0005432639097	2248	Business	87300.00
0005432639096	2248	Business	87300.00
0005432639106	2248	Economy	29100.00
0005432639123	2248	Economy	29100.00
0005432865942	2248	Economy	29100.00
0005432639114	2248	Economy	29100.00
0005432639130	2248	Economy	29100.00
0005432865955	2248	Economy	29100.00
0005432639105	2248	Economy	32000.00
0005432865941	2248	Economy	32000.00
0005432639119	2248	Economy	32000.00
0005432639110	2248	Economy	29100.00
0005432865940	2248	Economy	29100.00
0005432639108	2248	Economy	29100.00
0005432865931	2248	Economy	29100.00
0005432639117	2248	Economy	29100.00
0005432865949	2248	Economy	29100.00
0005432865956	2248	Economy	29100.00
0005432639102	2248	Economy	29100.00
0005432865933	2248	Economy	29100.00
0005432865918	2248	Economy	29100.00
0005432639104	2248	Economy	29100.00
0005432865938	2248	Economy	29100.00
0005432639116	2248	Economy	29100.00
0005432639125	2248	Economy	29100.00
0005432639122	2248	Economy	29100.00
0005432639115	2248	Economy	29100.00
0005432639127	2248	Economy	29100.00
0005432639109	2248	Economy	29100.00
0005432639112	2248	Economy	29100.00
0005432639120	2248	Economy	29100.00
0005432639098	2248	Economy	29100.00
0005432639111	2248	Economy	29100.00
0005432865929	2248	Economy	29100.00
0005432865919	2248	Economy	29100.00
0005432865920	2248	Economy	29100.00
0005432865937	2248	Economy	29100.00
0005432639103	2248	Economy	29100.00
0005432639129	2248	Economy	29100.00
0005432865934	2248	Economy	29100.00
0005432639121	2248	Economy	29100.00
0005432639093	2248	Economy	29100.00
0005432639100	2248	Economy	29100.00
0005432865908	2248	Economy	29100.00
0005432639118	2248	Economy	29100.00
0005432865932	2248	Economy	29100.00
0005432639124	2248	Economy	29100.00
0005432639113	2248	Economy	29100.00
0005432639128	2248	Economy	29100.00
0005432865944	2248	Economy	29100.00
0005432639126	2248	Economy	29100.00
0005432865930	2248	Economy	29100.00
0005432865915	2248	Economy	29100.00
0005432639095	2248	Economy	29100.00
0005432865907	2248	Economy	29100.00
0005432865950	2248	Economy	29100.00
0005434504104	6560	Business	48400.00
0005435103922	6560	Business	48400.00
0005434504108	6560	Business	48400.00
0005434504117	6560	Business	48400.00
0005434504134	6560	Business	48400.00
0005434504143	6560	Economy	16100.00
0005434504105	6560	Economy	16100.00
0005434504124	6560	Economy	16100.00
0005434504133	6560	Economy	16100.00
0005434504137	6560	Economy	16100.00
0005434504123	6560	Economy	16100.00
0005434504106	6560	Economy	17800.00
0005434504125	6560	Economy	17800.00
0005434504116	6560	Economy	17800.00
0005435103931	6560	Economy	16100.00
0005435103930	6560	Economy	16100.00
0005434504109	6560	Economy	16100.00
0005434504135	6560	Economy	16100.00
0005435103929	6560	Economy	16100.00
0005434504113	6560	Economy	16100.00
0005435103928	6560	Economy	16100.00
0005434504111	6560	Economy	16100.00
0005435103925	6560	Economy	16100.00
0005435103927	6560	Economy	16100.00
0005434504128	6560	Economy	16100.00
0005434504132	6560	Economy	16100.00
0005435103923	6560	Economy	16100.00
0005434504136	6560	Economy	16100.00
0005434504138	6560	Economy	16100.00
0005434504129	6560	Economy	16100.00
0005434504130	6560	Economy	16100.00
0005434504141	6560	Economy	16100.00
0005434504118	6560	Economy	16100.00
0005434504120	6560	Economy	16100.00
0005434504140	6560	Economy	16100.00
0005434504131	6560	Economy	16100.00
0005434504127	6560	Economy	16100.00
0005435103932	6560	Economy	16100.00
0005434504107	6560	Economy	16100.00
0005434504142	6560	Economy	16100.00
0005434504121	6560	Economy	16100.00
0005435103926	6560	Economy	16100.00
0005434504139	6560	Economy	16100.00
0005434504122	6560	Economy	16100.00
0005434504126	6560	Economy	16100.00
0005435103924	6560	Economy	16100.00
0005434504119	6560	Economy	16100.00
0005434504112	6560	Economy	16100.00
0005434504114	6560	Economy	16100.00
0005434504115	6560	Economy	16100.00
0005434504110	6560	Economy	16100.00
0005434503662	22679	Economy	16100.00
0005434503701	22679	Economy	16100.00
0005434503715	22679	Economy	16100.00
0005434503554	22679	Economy	16100.00
0005434503745	22679	Economy	16100.00
0005434503847	22679	Economy	17800.00
0005434503714	22679	Economy	16100.00
0005434503711	22679	Economy	16100.00
0005434503712	22679	Economy	16100.00
0005434503546	22679	Economy	16100.00
0005434503726	22679	Economy	16100.00
0005434503674	22679	Economy	16100.00
0005434503768	22679	Economy	16100.00
0005434503544	22679	Economy	16100.00
0005434503812	22679	Economy	16100.00
0005434503622	22679	Economy	16100.00
0005434503584	22679	Economy	16100.00
0005434503733	22679	Economy	16100.00
0005434503767	22679	Economy	16100.00
0005434503681	22679	Economy	16100.00
0005434503545	22679	Economy	16100.00
0005434503854	22679	Economy	16100.00
0005434503667	22679	Economy	16100.00
0005434503574	22679	Economy	16100.00
0005434503644	22679	Economy	16100.00
0005434503811	22679	Economy	16100.00
0005434503759	22679	Economy	16100.00
0005434503619	22679	Economy	16100.00
0005434503500	22679	Economy	16100.00
0005434503702	22679	Economy	16100.00
0005434503651	22679	Economy	16100.00
0005434503533	22679	Economy	16100.00
0005434503827	22679	Economy	16100.00
0005434503645	22679	Economy	16100.00
0005434503744	22679	Economy	16100.00
0005434503620	22679	Economy	16100.00
0005434503718	22679	Economy	16100.00
0005434503501	22679	Economy	16100.00
0005434503757	22679	Economy	16100.00
0005434503846	22679	Economy	16100.00
0005434503710	22679	Economy	16100.00
0005434503670	22679	Economy	16100.00
0005434503697	22679	Economy	16100.00
0005434503487	22679	Economy	16100.00
0005434503661	22679	Economy	16100.00
0005434503732	22679	Economy	16100.00
0005435800098	6422	Economy	16800.00
0005435800105	6422	Economy	15300.00
0005435800099	6422	Economy	15300.00
0005435800102	6422	Economy	15300.00
0005435800111	6422	Economy	15300.00
0005435800101	6422	Economy	15300.00
0005435800106	6422	Economy	15300.00
0005435800110	6422	Economy	15300.00
0005435800108	6422	Economy	15300.00
0005435800103	6422	Economy	15300.00
0005435800100	6422	Economy	15300.00
0005435800107	6422	Economy	15300.00
0005435800112	6422	Economy	15300.00
0005435800109	6422	Economy	15300.00
0005435800104	6422	Economy	15300.00
0005433367542	1641	Business	50000.00
0005433367522	1641	Business	50000.00
0005435653011	1641	Business	50000.00
0005433367490	1641	Business	50000.00
0005435653014	1641	Business	50000.00
0005433367494	1641	Business	50000.00
0005433367639	1641	Business	50000.00
0005435653016	1641	Business	50000.00
0005435653015	1641	Business	50000.00
0005435652995	1641	Business	50000.00
0005433367596	1641	Economy	16700.00
0005435653003	1641	Economy	16700.00
0005435653034	1641	Economy	16700.00
0005433367455	1641	Economy	16700.00
0005435653040	1641	Economy	16700.00
0005435653020	1641	Economy	16700.00
0005435652992	1641	Economy	16700.00
0005435653017	1641	Economy	16700.00
0005433367544	1641	Economy	18300.00
0005435653033	1641	Economy	18300.00
0005435653005	1641	Economy	18300.00
0005435653028	1641	Economy	18300.00
0005435653039	1641	Economy	18300.00
0005435653002	1641	Economy	16700.00
0005433367481	1641	Economy	16700.00
0005433367402	1641	Economy	16700.00
0005435653009	1641	Economy	16700.00
0005435653008	1641	Economy	16700.00
0005433367480	1641	Economy	16700.00
0005435652998	1641	Economy	16700.00
0005433367492	1641	Economy	16700.00
0005435653026	1641	Economy	16700.00
0005433367427	1641	Economy	16700.00
0005433367363	1641	Economy	16700.00
0005433367521	1641	Economy	16700.00
0005433367573	1641	Economy	16700.00
0005433367533	1641	Economy	16700.00
0005433367597	1641	Economy	16700.00
0005433367493	1641	Economy	16700.00
0005433367458	1641	Economy	16700.00
0005435653022	1641	Economy	16700.00
0005433367508	1641	Economy	16700.00
0005435653036	1641	Economy	16700.00
0005435652996	1641	Economy	16700.00
0005435653013	1641	Economy	16700.00
0005433367561	1641	Economy	16700.00
0005433367395	1641	Economy	16700.00
0005433367545	1641	Economy	16700.00
0005433367532	1641	Economy	16700.00
0005433367520	1641	Economy	16700.00
0005435653010	1641	Economy	16700.00
0005435653021	1641	Economy	16700.00
0005433367547	1641	Economy	16700.00
0005433367509	1641	Economy	16700.00
0005435653035	1641	Economy	16700.00
0005433367459	1641	Economy	16700.00
0005435653007	1641	Economy	16700.00
0005433367546	1641	Economy	16700.00
0005435653023	1641	Economy	16700.00
0005435653029	1641	Economy	16700.00
0005435653038	1641	Economy	16700.00
0005433367364	1641	Economy	16700.00
0005435653037	1641	Economy	16700.00
0005433367662	1641	Economy	16700.00
0005433367562	1641	Economy	16700.00
0005433367663	1641	Economy	16700.00
0005435652994	1641	Economy	16700.00
0005435653027	1641	Economy	16700.00
0005435653004	1641	Economy	16700.00
0005435653018	1641	Economy	16700.00
0005435652997	1641	Economy	16700.00
0005435653000	1641	Economy	16700.00
0005433367598	1641	Economy	16700.00
0005435653019	1641	Economy	16700.00
0005435653006	1641	Economy	16700.00
0005433367386	1641	Economy	16700.00
0005433367548	1641	Economy	16700.00
0005435653032	1641	Economy	16700.00
0005435653025	1641	Economy	16700.00
0005435652993	1641	Economy	16700.00
0005435653001	1641	Economy	16700.00
0005435653012	1641	Economy	16700.00
0005435653030	1641	Economy	16700.00
0005435653031	1641	Economy	16700.00
0005433367412	1641	Economy	16700.00
0005435653024	1641	Economy	16700.00
0005433367489	1641	Economy	16700.00
0005435652999	1641	Economy	16700.00
0005433367491	1641	Economy	16700.00
0005435652477	21699	Business	50000.00
0005435652502	21699	Business	50000.00
0005435652604	21699	Business	50000.00
0005435652402	21699	Business	50000.00
0005433367842	21699	Business	50000.00
0005433367850	21699	Business	50000.00
0005433367841	21699	Business	50000.00
0005435652587	21699	Business	50000.00
0005435652572	21699	Business	50000.00
0005433367862	21699	Business	50000.00
0005435652575	21699	Economy	16700.00
0005435652451	21699	Economy	16700.00
0005435652503	21699	Economy	16700.00
0005435652487	21699	Economy	16700.00
0005435652638	21699	Economy	16700.00
0005433367857	21699	Economy	16700.00
0005435652569	21699	Economy	16700.00
0005433367856	21699	Economy	16700.00
0005435652476	21699	Economy	18300.00
0005433367854	21699	Economy	18300.00
0005435652512	21699	Economy	18300.00
0005433367837	21699	Economy	18300.00
0005433367847	21699	Economy	18300.00
0005435652498	21699	Economy	16700.00
0005433367838	21699	Economy	16700.00
0005435652486	21699	Economy	16700.00
0005433367869	21699	Economy	16700.00
0005435652438	21699	Economy	16700.00
0005433367852	21699	Economy	16700.00
0005435652549	21699	Economy	16700.00
0005433367846	21699	Economy	16700.00
0005433367835	21699	Economy	16700.00
0005433367844	21699	Economy	16700.00
0005435652527	21699	Economy	16700.00
0005433367859	21699	Economy	16700.00
0005433367860	21699	Economy	16700.00
0005435652504	21699	Economy	16700.00
0005435652406	21699	Economy	16700.00
0005433367855	21699	Economy	16700.00
0005433367868	21699	Economy	16700.00
0005433367839	21699	Economy	16700.00
0005433367858	21699	Economy	16700.00
0005433367836	21699	Economy	16700.00
0005433367845	21699	Economy	16700.00
0005435652603	21699	Economy	16700.00
0005433367870	21699	Economy	16700.00
0005435652663	21699	Economy	16700.00
0005435652671	21699	Economy	16700.00
0005435652500	21699	Economy	16700.00
0005435652658	21699	Economy	16700.00
0005435652511	21699	Economy	16700.00
0005433367843	21699	Economy	16700.00
0005433367865	21699	Economy	16700.00
0005435652639	21699	Economy	16700.00
0005433367853	21699	Economy	16700.00
0005435652522	21699	Economy	16700.00
0005435652496	21699	Economy	16700.00
0005435652407	21699	Economy	16700.00
0005435652656	21699	Economy	16700.00
0005433367867	21699	Economy	16700.00
0005433367840	21699	Economy	16700.00
0005435652576	21699	Economy	16700.00
0005435652568	21699	Economy	16700.00
0005433367848	21699	Economy	16700.00
0005433367849	21699	Economy	16700.00
0005435652640	21699	Economy	16700.00
0005435652530	21699	Economy	16700.00
0005433367863	21699	Economy	16700.00
0005435652617	21699	Economy	16700.00
0005433367864	21699	Economy	16700.00
0005435652494	21699	Economy	16700.00
0005433367866	21699	Economy	16700.00
0005433367834	21699	Economy	16700.00
0005435652499	21699	Economy	16700.00
0005433367851	21699	Economy	16700.00
0005435652642	21699	Economy	16700.00
0005433367861	21699	Economy	16700.00
0005433367833	21699	Economy	16700.00
0005435627113	23806	Economy	11200.00
0005435312806	23234	Economy	23000.00
0005434466427	23234	Economy	23000.00
0005435312804	23234	Economy	20900.00
0005434466402	23234	Economy	20900.00
0005434466426	23234	Economy	20900.00
0005435312802	23234	Economy	20900.00
0005434466401	23234	Economy	20900.00
0005434466415	23234	Economy	20900.00
0005435312805	23234	Economy	20900.00
0005434466419	23234	Economy	20900.00
0005435312800	23234	Economy	20900.00
0005434466416	23234	Economy	20900.00
0005435312803	23234	Economy	20900.00
0005434466414	23234	Economy	20900.00
0005435312801	23234	Economy	20900.00
0005434466410	23234	Economy	20900.00
0005435312799	23234	Economy	20900.00
0005434466429	23234	Economy	20900.00
0005434466409	23234	Economy	20900.00
0005433985878	4160	Business	21500.00
0005433985909	4160	Business	21500.00
0005433985907	4160	Business	21500.00
0005433985915	4160	Business	21500.00
0005433985895	4160	Business	21500.00
0005433985898	4160	Business	21500.00
0005433985881	4160	Business	21500.00
0005433985890	4160	Business	21500.00
0005433985884	4160	Economy	7200.00
0005433985879	4160	Economy	7200.00
0005433985889	4160	Economy	7200.00
0005433985914	4160	Economy	7200.00
0005433985924	4160	Economy	7200.00
0005433985901	4160	Economy	7200.00
0005433985920	4160	Economy	7200.00
0005433985897	4160	Economy	7200.00
0005433985888	4160	Economy	7200.00
0005435788768	4160	Economy	7900.00
0005433985926	4160	Economy	7900.00
0005433985925	4160	Economy	7900.00
0005433985880	4160	Economy	7200.00
0005433985885	4160	Economy	7200.00
0005433985908	4160	Economy	7200.00
0005433985904	4160	Economy	7200.00
0005433985922	4160	Economy	7200.00
0005433985917	4160	Economy	7200.00
0005433985899	4160	Economy	7200.00
0005433985894	4160	Economy	7200.00
0005433985918	4160	Economy	7200.00
0005433985891	4160	Economy	7200.00
0005433985893	4160	Economy	7200.00
0005433985916	4160	Economy	7200.00
0005433985896	4160	Economy	7200.00
0005433985923	4160	Economy	7200.00
0005433985883	4160	Economy	7200.00
0005433985913	4160	Economy	7200.00
0005433985921	4160	Economy	7200.00
0005433985905	4160	Economy	7200.00
0005433985887	4160	Economy	7200.00
0005433985912	4160	Economy	7200.00
0005433985886	4160	Economy	7200.00
0005433985882	4160	Economy	7200.00
0005435788769	4160	Economy	7200.00
0005433985902	4160	Economy	7200.00
0005433985892	4160	Economy	7200.00
0005433985911	4160	Economy	7200.00
0005433985910	4160	Economy	7200.00
0005433985906	4160	Economy	7200.00
0005433985903	4160	Economy	7200.00
0005433985900	4160	Economy	7200.00
0005433985919	4160	Economy	7200.00
0005433985445	25676	Business	21500.00
0005433985483	25676	Business	21500.00
0005433985480	25676	Business	21500.00
0005433985446	25676	Business	21500.00
0005433985262	25676	Business	21500.00
0005433985436	25676	Business	21500.00
0005433985375	25676	Business	21500.00
0005433985412	25676	Economy	7200.00
0005433985517	25676	Economy	7200.00
0005433985430	25676	Economy	7200.00
0005433985324	25676	Economy	7200.00
0005435788757	25676	Economy	7200.00
0005435788756	25676	Economy	7900.00
0005433985490	25676	Economy	7200.00
0005433985325	25676	Economy	7200.00
0005433985552	25676	Economy	7200.00
0005433985572	25676	Economy	7200.00
0005433985499	25676	Economy	7200.00
0005433985269	25676	Economy	7200.00
0005433985586	25676	Economy	7200.00
0005433985171	25676	Economy	7200.00
0005433985442	25676	Economy	7200.00
0005433985420	25676	Economy	7200.00
0005433985454	25676	Economy	7200.00
0005433985589	25676	Economy	7200.00
0005433985482	25676	Economy	7200.00
0005433985461	25676	Economy	7200.00
0005433985440	25676	Economy	7200.00
0005433985465	25676	Economy	7200.00
0005433985500	25676	Economy	7200.00
0005433985377	25676	Economy	7200.00
0005433985441	25676	Economy	7200.00
0005433985481	25676	Economy	7200.00
0005433985587	25676	Economy	7200.00
0005433985214	25676	Economy	7200.00
0005433985462	25676	Economy	7200.00
0005433985568	25676	Economy	7200.00
0005433985576	25676	Economy	7200.00
0005433985553	25676	Economy	7200.00
0005433985351	25676	Economy	7200.00
0005433985421	25676	Economy	7200.00
0005433985453	25676	Economy	7200.00
0005433985463	25676	Economy	7200.00
0005435788739	25676	Economy	7200.00
0005433985592	25676	Economy	7200.00
0005433985583	25676	Economy	7200.00
0005433985383	25676	Economy	7200.00
0005433985464	25676	Economy	7200.00
0005435788741	25676	Economy	7200.00
0005433168364	21317	Economy	17000.00
0005434509071	21317	Economy	17000.00
0005434509057	21317	Economy	15500.00
0005434509085	21317	Economy	15500.00
0005433168365	21317	Economy	15500.00
0005434509080	21317	Economy	15500.00
0005433168370	21317	Economy	15500.00
0005434509051	21317	Economy	15500.00
0005434509050	21317	Economy	15500.00
0005434509099	21317	Economy	15500.00
0005434509068	21317	Economy	15500.00
0005434509095	21317	Economy	15500.00
0005433168369	21317	Economy	15500.00
0005433168366	21317	Economy	15500.00
0005433168368	21317	Economy	15500.00
0005434509105	21317	Economy	15500.00
0005434509100	21317	Economy	15500.00
0005433168367	21317	Economy	15500.00
0005434509056	21317	Economy	15500.00
0005434509113	21317	Economy	15500.00
0005434509089	21317	Economy	15500.00
0005434509079	21317	Economy	15500.00
0005433168371	21317	Economy	15500.00
0005432658559	17865	Business	18000.00
0005432658569	17865	Business	18000.00
0005434151704	17865	Business	18000.00
0005432661912	17865	Business	18000.00
0005434151706	17865	Business	18000.00
0005432655419	17865	Business	18000.00
0005432660798	17865	Business	18000.00
0005432655418	17865	Business	18000.00
0005432658571	17865	Business	18000.00
0005432655470	17865	Economy	6000.00
0005432655371	17865	Economy	6000.00
0005432655417	17865	Economy	6000.00
0005432869521	17865	Economy	6000.00
0005432663014	17865	Economy	6000.00
0005432655362	17865	Economy	6000.00
0005432655406	17865	Economy	6000.00
0005432665252	17865	Economy	6600.00
0005432655361	17865	Economy	6600.00
0005432664127	17865	Economy	6600.00
0005432655431	17865	Economy	6600.00
0005432655390	17865	Economy	6000.00
0005432869525	17865	Economy	6000.00
0005432655393	17865	Economy	6000.00
0005432665255	17865	Economy	6000.00
0005432658558	17865	Economy	6000.00
0005432663013	17865	Economy	6000.00
0005432665257	17865	Economy	6000.00
0005432658570	17865	Economy	6000.00
0005432655360	17865	Economy	6000.00
0005432655405	17865	Economy	6000.00
0005432655469	17865	Economy	6000.00
0005432658573	17865	Economy	6000.00
0005434151705	17865	Economy	6000.00
0005432869522	17865	Economy	6000.00
0005432666370	17865	Economy	6000.00
0005432658575	17865	Economy	6000.00
0005432655370	17865	Economy	6000.00
0005432869524	17865	Economy	6000.00
0005432869519	17865	Economy	6000.00
0005432658574	17865	Economy	6000.00
0005432655452	17865	Economy	6000.00
0005432667429	17865	Economy	6000.00
0005434151703	17865	Economy	6000.00
0005432664113	17865	Economy	6000.00
0005432661909	17865	Economy	6000.00
0005432665256	17865	Economy	6000.00
0005432666371	17865	Economy	6000.00
0005432869523	17865	Economy	6000.00
0005432655430	17865	Economy	6000.00
0005432655394	17865	Economy	6000.00
0005434151702	17865	Economy	6000.00
0005432869520	17865	Economy	6000.00
0005432655432	17865	Economy	6000.00
0005434151673	26297	Business	18000.00
0005434151672	26297	Business	18000.00
0005432657443	26297	Economy	6000.00
0005432666384	26297	Economy	6000.00
0005432869461	26297	Economy	6000.00
0005432655499	26297	Economy	6000.00
0005432665270	26297	Economy	6000.00
0005434151667	26297	Economy	6000.00
0005432657442	26297	Economy	6600.00
0005432869447	26297	Economy	6600.00
0005432655504	26297	Economy	6600.00
0005432667450	26297	Economy	6600.00
0005432655506	26297	Economy	6000.00
0005432655503	26297	Economy	6000.00
0005432667449	26297	Economy	6000.00
0005432665269	26297	Economy	6000.00
0005432655505	26297	Economy	6000.00
0005432655497	26297	Economy	6000.00
0005432658586	26297	Economy	6000.00
0005432655501	26297	Economy	6000.00
0005432655507	26297	Economy	6000.00
0005432658585	26297	Economy	6000.00
0005432660813	26297	Economy	6000.00
0005432657444	26297	Economy	6000.00
0005432869426	26297	Economy	6000.00
0005432660812	26297	Economy	6000.00
0005432655508	26297	Economy	6000.00
0005432658587	26297	Economy	6000.00
0005432869462	26297	Economy	6000.00
0005432869463	26297	Economy	6000.00
0005432660814	26297	Economy	6000.00
0005432655500	26297	Economy	6000.00
0005432667448	26297	Economy	6000.00
0005432659701	26297	Economy	6000.00
0005432659702	26297	Economy	6000.00
0005432666383	26297	Economy	6000.00
0005432655498	26297	Economy	6000.00
0005432657441	26297	Economy	6000.00
0005432655502	26297	Economy	6000.00
0005432869452	26297	Economy	6000.00
0005432665271	26297	Economy	6000.00
0005432869448	26297	Economy	6000.00
0005432328667	3087	Business	16100.00
0005432328671	3087	Business	16100.00
0005433438874	3087	Business	16100.00
0005432328664	3087	Business	16100.00
0005432287186	3087	Business	16100.00
0005432328642	3087	Business	16100.00
0005433438875	3087	Business	16100.00
0005432905087	3087	Business	16100.00
0005432905092	3087	Economy	5400.00
0005432328643	3087	Economy	5400.00
0005432328666	3087	Economy	5400.00
0005432328668	3087	Economy	5400.00
0005432328660	3087	Economy	5400.00
0005432328682	3087	Economy	5400.00
0005432328678	3087	Economy	5400.00
0005432328654	3087	Economy	5900.00
0005432905069	3087	Economy	5900.00
0005432328674	3087	Economy	5900.00
0005432328677	3087	Economy	5900.00
0005432328645	3087	Economy	5900.00
0005432905040	3087	Economy	5400.00
0005432287185	3087	Economy	5400.00
0005432328657	3087	Economy	5400.00
0005432328665	3087	Economy	5400.00
0005432328679	3087	Economy	5400.00
0005432328655	3087	Economy	5400.00
0005432328662	3087	Economy	5400.00
0005432905055	3087	Economy	5400.00
0005433438877	3087	Economy	5400.00
0005432287184	3087	Economy	5400.00
0005432328652	3087	Economy	5400.00
0005432328644	3087	Economy	5400.00
0005432328670	3087	Economy	5400.00
0005432287187	3087	Economy	5400.00
0005433438871	3087	Economy	5400.00
0005432328683	3087	Economy	5400.00
0005432328663	3087	Economy	5400.00
0005432328681	3087	Economy	5400.00
0005432328651	3087	Economy	5400.00
0005432328656	3087	Economy	5400.00
0005432328686	3087	Economy	5400.00
0005432328661	3087	Economy	5400.00
0005432328687	3087	Economy	5400.00
0005432328647	3087	Economy	5400.00
0005433438873	3087	Economy	5400.00
0005433438876	3087	Economy	5400.00
0005432905068	3087	Economy	5400.00
0005432328653	3087	Economy	5400.00
0005432328649	3087	Economy	5400.00
0005432328675	3087	Economy	5400.00
0005432328646	3087	Economy	5400.00
0005432328648	3087	Economy	5400.00
0005433438872	3087	Economy	5400.00
0005432328673	3087	Economy	5400.00
0005432328676	3087	Economy	5400.00
0005432328680	3087	Economy	5400.00
0005432328672	3087	Economy	5400.00
0005432328650	3087	Economy	5400.00
0005432328669	3087	Economy	5400.00
0005432328684	3087	Economy	5400.00
0005432328659	3087	Economy	5400.00
0005432328688	3087	Economy	5400.00
0005432328685	3087	Economy	5400.00
0005432328658	3087	Economy	5400.00
0005432905091	3087	Economy	5400.00
0005432905118	31123	Business	16100.00
0005432054302	31123	Business	16100.00
0005432328229	31123	Business	16100.00
0005432905124	31123	Business	16100.00
0005433438813	31123	Business	16100.00
0005432328187	31123	Business	16100.00
0005432328306	31123	Business	16100.00
0005432905120	31123	Business	16100.00
0005432905123	31123	Economy	5400.00
0005432905117	31123	Economy	5400.00
0005433438814	31123	Economy	5400.00
0005432328384	31123	Economy	5400.00
0005432905121	31123	Economy	5400.00
0005432328102	31123	Economy	5400.00
0005432328139	31123	Economy	5400.00
0005432328173	31123	Economy	5900.00
0005432328304	31123	Economy	5900.00
0005432328288	31123	Economy	5400.00
0005432328199	31123	Economy	5400.00
0005433438792	31123	Economy	5400.00
0005432328200	31123	Economy	5400.00
0005432054300	31123	Economy	5400.00
0005433438831	31123	Economy	5400.00
0005432328138	31123	Economy	5400.00
0005432328305	31123	Economy	5400.00
0005432328171	31123	Economy	5400.00
0005432905122	31123	Economy	5400.00
0005432328198	31123	Economy	5400.00
0005432054301	31123	Economy	5400.00
0005432328315	31123	Economy	5400.00
0005432328214	31123	Economy	5400.00
0005432328119	31123	Economy	5400.00
0005432328244	31123	Economy	5400.00
0005433438822	31123	Economy	5400.00
0005432328159	31123	Economy	5400.00
0005433438793	31123	Economy	5400.00
0005432328286	31123	Economy	5400.00
0005433438835	31123	Economy	5400.00
0005432328158	31123	Economy	5400.00
0005432328177	31123	Economy	5400.00
0005432328208	31123	Economy	5400.00
0005432328243	31123	Economy	5400.00
0005432328172	31123	Economy	5400.00
0005432328160	31123	Economy	5400.00
0005432328201	31123	Economy	5400.00
0005432328203	31123	Economy	5400.00
0005432328178	31123	Economy	5400.00
0005432328205	31123	Economy	5400.00
0005432328176	31123	Economy	5400.00
0005433438818	31123	Economy	5400.00
0005432328213	31123	Economy	5400.00
0005433438772	31123	Economy	5400.00
0005432328303	31123	Economy	5400.00
0005432328285	31123	Economy	5400.00
0005432905119	31123	Economy	5400.00
0005432328329	31123	Economy	5400.00
0005432327920	31123	Economy	5400.00
0005435487612	6213	Business	124600.00
0005434309731	6213	Business	124600.00
0005435296982	6213	Business	124600.00
0005432146198	6213	Business	124600.00
0005435487590	6213	Business	124600.00
0005434309725	6213	Business	124600.00
0005435999246	6213	Economy	41500.00
0005435487587	6213	Economy	41500.00
0005435487611	6213	Economy	41500.00
0005435487658	6213	Economy	41500.00
0005434309728	6213	Economy	41500.00
0005435999240	6213	Economy	41500.00
0005435487554	6213	Economy	41500.00
0005435487657	6213	Economy	41500.00
0005435487505	6213	Economy	41500.00
0005435487656	6213	Economy	41500.00
0005435487632	6213	Economy	41500.00
0005435487647	6213	Economy	41500.00
0005435296979	6213	Economy	41500.00
0005435296981	6213	Economy	41500.00
0005432146197	6213	Economy	41500.00
0005434309730	6213	Economy	41500.00
0005435999243	6213	Economy	41500.00
0005435487581	6213	Economy	41500.00
0005434309736	6213	Economy	45700.00
0005434309726	6213	Economy	45700.00
0005435999248	6213	Economy	45700.00
0005435297003	6213	Economy	41500.00
0005435999239	6213	Economy	41500.00
0005435487582	6213	Economy	41500.00
0005432146196	6213	Economy	41500.00
0005435487625	6213	Economy	41500.00
0005435487639	6213	Economy	41500.00
0005435487580	6213	Economy	41500.00
0005435487650	6213	Economy	41500.00
0005435487604	6213	Economy	41500.00
0005435999237	6213	Economy	41500.00
0005435487605	6213	Economy	41500.00
0005435487555	6213	Economy	41500.00
0005435296983	6213	Economy	41500.00
0005435999244	6213	Economy	41500.00
0005435999238	6213	Economy	41500.00
0005434309729	6213	Economy	41500.00
0005434309735	6213	Economy	41500.00
0005435487626	6213	Economy	41500.00
0005435297002	6213	Economy	41500.00
0005435487624	6213	Economy	41500.00
0005434309733	6213	Economy	41500.00
0005434309727	6213	Economy	41500.00
0005435999236	6213	Economy	41500.00
0005435487556	6213	Economy	41500.00
0005434309732	6213	Economy	41500.00
0005435487600	6213	Economy	41500.00
0005435999245	6213	Economy	41500.00
0005435999242	6213	Economy	41500.00
0005435487586	6213	Economy	41500.00
0005435487683	6213	Economy	41500.00
0005435487631	6213	Economy	41500.00
0005435999241	6213	Economy	41500.00
0005434309737	6213	Economy	41500.00
0005435487579	6213	Economy	41500.00
0005435487552	6213	Economy	41500.00
0005435999247	6213	Economy	41500.00
0005434309734	6213	Economy	41500.00
0005435999011	19555	Business	124600.00
0005435487789	19555	Business	124600.00
0005435999006	19555	Business	124600.00
0005435999029	19555	Business	124600.00
0005435487802	19555	Business	124600.00
0005435487805	19555	Business	124600.00
0005434309598	19555	Business	124600.00
0005435487804	19555	Business	124600.00
0005435999043	19555	Economy	41500.00
0005434309620	19555	Economy	41500.00
0005435297053	19555	Economy	41500.00
0005435487803	19555	Economy	41500.00
0005435487793	19555	Economy	41500.00
0005435487786	19555	Economy	41500.00
0005435487788	19555	Economy	41500.00
0005435999071	19555	Economy	41500.00
0005434309621	19555	Economy	41500.00
0005434309634	19555	Economy	41500.00
0005434309592	19555	Economy	41500.00
0005435487794	19555	Economy	41500.00
0005435999072	19555	Economy	41500.00
0005435487795	19555	Economy	41500.00
0005435487792	19555	Economy	45700.00
0005435297056	19555	Economy	45700.00
0005435487801	19555	Economy	45700.00
0005435297054	19555	Economy	45700.00
0005434309622	19555	Economy	41500.00
0005435999033	19555	Economy	41500.00
0005435999034	19555	Economy	41500.00
0005435999084	19555	Economy	41500.00
0005435999012	19555	Economy	41500.00
0005435999076	19555	Economy	41500.00
0005435487796	19555	Economy	41500.00
0005435487806	19555	Economy	41500.00
0005435999061	19555	Economy	41500.00
0005435487799	19555	Economy	41500.00
0005434309594	19555	Economy	41500.00
0005435487807	19555	Economy	41500.00
0005435999030	19555	Economy	41500.00
0005435999068	19555	Economy	41500.00
0005434309591	19555	Economy	41500.00
0005435297051	19555	Economy	41500.00
0005435999085	19555	Economy	41500.00
0005435487787	19555	Economy	41500.00
0005434309557	19555	Economy	41500.00
0005435487790	19555	Economy	41500.00
0005435297055	19555	Economy	41500.00
0005435487800	19555	Economy	41500.00
0005435487797	19555	Economy	41500.00
0005435999005	19555	Economy	41500.00
0005435297050	19555	Economy	41500.00
0005435999056	19555	Economy	41500.00
0005435297052	19555	Economy	41500.00
0005435487791	19555	Economy	41500.00
0005435999007	19555	Economy	41500.00
0005435998984	19555	Economy	41500.00
0005434309635	19555	Economy	41500.00
0005435999060	19555	Economy	41500.00
0005434309624	19555	Economy	41500.00
0005434309595	19555	Economy	41500.00
0005435487798	19555	Economy	41500.00
0005434309651	19555	Economy	41500.00
0005435999046	19555	Economy	41500.00
0005434309573	19555	Economy	41500.00
0005435999062	19555	Economy	41500.00
0005433158129	17549	Economy	13600.00
0005433158130	17549	Economy	12300.00
0005434446490	17549	Economy	12300.00
0005434446501	17549	Economy	12300.00
0005433158128	17549	Economy	12300.00
0005435502295	1585	Business	86000.00
0005432291928	1585	Business	86000.00
0005435502301	1585	Business	86000.00
0005435508362	1585	Business	86000.00
0005435517912	1585	Business	86000.00
0005433186046	1585	Business	86000.00
0005433186043	1585	Business	86000.00
0005433186069	1585	Business	86000.00
0005434565904	1585	Business	86000.00
0005435517906	1585	Business	86000.00
0005435517914	1585	Economy	28700.00
0005434565910	1585	Economy	28700.00
0005435502300	1585	Economy	28700.00
0005435502293	1585	Economy	28700.00
0005432291929	1585	Economy	28700.00
0005435508363	1585	Economy	28700.00
0005435508361	1585	Economy	28700.00
0005435502304	1585	Economy	28700.00
0005433186027	1585	Economy	28700.00
0005433186045	1585	Economy	31500.00
0005435502292	1585	Economy	31500.00
0005435502291	1585	Economy	31500.00
0005433186042	1585	Economy	31500.00
0005435508366	1585	Economy	31500.00
0005435502303	1585	Economy	28700.00
0005435508355	1585	Economy	28700.00
0005435517903	1585	Economy	28700.00
0005435508364	1585	Economy	28700.00
0005435517908	1585	Economy	28700.00
0005435517902	1585	Economy	28700.00
0005434565900	1585	Economy	28700.00
0005435502302	1585	Economy	28700.00
0005435508354	1585	Economy	28700.00
0005435517910	1585	Economy	28700.00
0005435517911	1585	Economy	28700.00
0005435502298	1585	Economy	28700.00
0005435517899	1585	Economy	28700.00
0005435502287	1585	Economy	28700.00
0005435517916	1585	Economy	28700.00
0005435517901	1585	Economy	28700.00
0005434565901	1585	Economy	28700.00
0005435502299	1585	Economy	28700.00
0005435508352	1585	Economy	28700.00
0005435517904	1585	Economy	28700.00
0005435508356	1585	Economy	28700.00
0005435502307	1585	Economy	28700.00
0005435508360	1585	Economy	28700.00
0005435508358	1585	Economy	28700.00
0005435517915	1585	Economy	28700.00
0005434565907	1585	Economy	28700.00
0005433186038	1585	Economy	28700.00
0005435502289	1585	Economy	28700.00
0005434565903	1585	Economy	28700.00
0005435517917	1585	Economy	28700.00
0005434565909	1585	Economy	28700.00
0005435517898	1585	Economy	28700.00
0005433186070	1585	Economy	28700.00
0005435502294	1585	Economy	28700.00
0005433186068	1585	Economy	28700.00
0005434565899	1585	Economy	28700.00
0005435508353	1585	Economy	28700.00
0005435502286	1585	Economy	28700.00
0005435502305	1585	Economy	28700.00
0005434565908	1585	Economy	28700.00
0005435517909	1585	Economy	28700.00
0005435508357	1585	Economy	28700.00
0005435508359	1585	Economy	28700.00
0005435517905	1585	Economy	28700.00
0005435517900	1585	Economy	28700.00
0005434565902	1585	Economy	28700.00
0005435517907	1585	Economy	28700.00
0005435502297	1585	Economy	28700.00
0005434565906	1585	Economy	28700.00
0005434565905	1585	Economy	28700.00
0005435508365	1585	Economy	28700.00
0005435502288	1585	Economy	28700.00
0005435502290	1585	Economy	28700.00
0005433186037	1585	Economy	28700.00
0005435517897	1585	Economy	28700.00
0005435517913	1585	Economy	28700.00
0005435502296	1585	Economy	28700.00
0005435502306	1585	Economy	28700.00
0005435517896	1585	Economy	28700.00
0005435528998	20866	Business	86000.00
0005433186111	20866	Business	86000.00
0005435502077	20866	Business	86000.00
0005435501993	20866	Business	86000.00
0005435502104	20866	Business	86000.00
0005435502039	20866	Business	86000.00
0005435501994	20866	Business	86000.00
0005435545641	20866	Business	86000.00
0005434565781	20866	Business	86000.00
0005435502086	20866	Business	86000.00
0005434565816	20866	Economy	28700.00
0005435529002	20866	Economy	28700.00
0005435502058	20866	Economy	28700.00
0005435528992	20866	Economy	28700.00
0005435502082	20866	Economy	28700.00
0005434565817	20866	Economy	28700.00
0005435528905	20866	Economy	28700.00
0005435502174	20866	Economy	28700.00
0005433186116	20866	Economy	31500.00
0005435529016	20866	Economy	31500.00
0005435502073	20866	Economy	31500.00
0005435529026	20866	Economy	31500.00
0005434565774	20866	Economy	28700.00
0005435502076	20866	Economy	28700.00
0005435545639	20866	Economy	28700.00
0005435528960	20866	Economy	28700.00
0005434565815	20866	Economy	28700.00
0005434565833	20866	Economy	28700.00
0005434565818	20866	Economy	28700.00
0005434565773	20866	Economy	28700.00
0005435502055	20866	Economy	28700.00
0005435529025	20866	Economy	28700.00
0005435502038	20866	Economy	28700.00
0005434565839	20866	Economy	28700.00
0005435502147	20866	Economy	28700.00
0005435528976	20866	Economy	28700.00
0005434565771	20866	Economy	28700.00
0005435545624	20866	Economy	28700.00
0005434565782	20866	Economy	28700.00
0005433186112	20866	Economy	28700.00
0005434565834	20866	Economy	28700.00
0005435528957	20866	Economy	28700.00
0005435529082	20866	Economy	28700.00
0005434565854	20866	Economy	28700.00
0005435502032	20866	Economy	28700.00
0005435502152	20866	Economy	28700.00
0005434565820	20866	Economy	28700.00
0005435502054	20866	Economy	28700.00
0005433186113	20866	Economy	28700.00
0005435528906	20866	Economy	28700.00
0005435529068	20866	Economy	28700.00
0005435528904	20866	Economy	28700.00
0005435528977	20866	Economy	28700.00
0005435545638	20866	Economy	28700.00
0005434565734	20866	Economy	28700.00
0005433186114	20866	Economy	28700.00
0005433186115	20866	Economy	28700.00
0005434565780	20866	Economy	28700.00
0005434565754	20866	Economy	28700.00
0005433186110	20866	Economy	28700.00
0005434565792	20866	Economy	28700.00
0005435502030	20866	Economy	28700.00
0005433186109	20866	Economy	28700.00
0005435502017	20866	Economy	28700.00
0005434565800	20866	Economy	28700.00
0005435502095	20866	Economy	28700.00
0005435502103	20866	Economy	28700.00
0005435502031	20866	Economy	28700.00
0005435502151	20866	Economy	28700.00
0005435502064	20866	Economy	28700.00
0005433186108	20866	Economy	28700.00
0005435502087	20866	Economy	28700.00
0005435502078	20866	Economy	28700.00
0005435502153	20866	Economy	28700.00
0005435502056	20866	Economy	28700.00
0005435529024	20866	Economy	28700.00
0005434565791	20866	Economy	28700.00
0005434565819	20866	Economy	28700.00
0005435529074	20866	Economy	28700.00
0005435529008	20866	Economy	28700.00
0005435502057	20866	Economy	28700.00
0005435931571	3897	Economy	21600.00
0005435153736	3897	Economy	19700.00
0005435931572	3897	Economy	19700.00
0005435931577	3897	Economy	19700.00
0005435153739	3897	Economy	19700.00
0005435931576	3897	Economy	19700.00
0005435153737	3897	Economy	19700.00
0005435931556	3897	Economy	19700.00
0005435931569	3897	Economy	19700.00
0005435931570	3897	Economy	19700.00
0005435153735	3897	Economy	19700.00
0005435153734	3897	Economy	19700.00
0005435153738	3897	Economy	19700.00
0005435931575	3897	Economy	19700.00
0005435931599	21864	Economy	19700.00
0005435153676	21864	Economy	19700.00
0005435931596	21864	Economy	19700.00
0005435931597	21864	Economy	19700.00
0005435153671	21864	Economy	19700.00
0005435153674	21864	Economy	19700.00
0005435931598	21864	Economy	19700.00
0005435153701	21864	Economy	19700.00
0005435153680	21864	Economy	19700.00
0005435153665	21864	Economy	19700.00
0005435153675	21864	Economy	19700.00
0005432628838	7227	Economy	14300.00
0005432628829	7227	Economy	14300.00
0005432628832	7227	Economy	14300.00
0005435225520	7227	Economy	13000.00
0005432628830	7227	Economy	13000.00
0005435225550	7227	Economy	13000.00
0005432628834	7227	Economy	13000.00
0005435225501	7227	Economy	13000.00
0005435225500	7227	Economy	13000.00
0005432628833	7227	Economy	13000.00
0005432628841	7227	Economy	13000.00
0005432628835	7227	Economy	13000.00
0005432628837	7227	Economy	13000.00
0005435225482	7227	Economy	13000.00
0005432628836	7227	Economy	13000.00
0005435225528	7227	Economy	13000.00
0005432628840	7227	Economy	13000.00
0005435225488	7227	Economy	13000.00
0005435225513	7227	Economy	13000.00
0005435225503	7227	Economy	13000.00
0005435225523	7227	Economy	13000.00
0005435225494	7227	Economy	13000.00
0005435225519	7227	Economy	13000.00
0005432628842	7227	Economy	13000.00
0005432628828	7227	Economy	13000.00
0005435225551	7227	Economy	13000.00
0005435225552	7227	Economy	13000.00
0005435225484	7227	Economy	13000.00
0005432628831	7227	Economy	13000.00
0005435225527	7227	Economy	13000.00
0005435225522	7227	Economy	13000.00
0005432628843	7227	Economy	13000.00
0005435225497	7227	Economy	13000.00
0005435225515	7227	Economy	13000.00
0005435225495	7227	Economy	13000.00
0005435225504	7227	Economy	13000.00
0005432628839	7227	Economy	13000.00
0005435225580	28123	Economy	14300.00
0005432628767	28123	Economy	13000.00
0005435225579	28123	Economy	13000.00
0005435225577	28123	Economy	13000.00
0005432628685	28123	Economy	13000.00
0005435225576	28123	Economy	13000.00
0005432628702	28123	Economy	13000.00
0005435225575	28123	Economy	13000.00
0005432628679	28123	Economy	13000.00
0005432628768	28123	Economy	13000.00
0005432628744	28123	Economy	13000.00
0005432628703	28123	Economy	13000.00
0005435225578	28123	Economy	13000.00
0005432628743	28123	Economy	13000.00
0005435225574	28123	Economy	13000.00
0005435225581	28123	Economy	13000.00
0005432628687	28123	Economy	13000.00
0005434267903	8755	Economy	11500.00
0005434267926	8755	Economy	10500.00
0005434267911	8755	Economy	10500.00
0005435960047	8755	Economy	10500.00
0005434267893	8755	Economy	10500.00
0005435960048	8755	Economy	10500.00
0005434267927	8755	Economy	10500.00
0005434267902	8755	Economy	10500.00
0005434267912	8755	Economy	10500.00
0005434267947	15239	Economy	11500.00
0005435960023	15239	Economy	10500.00
0005435960017	15239	Economy	10500.00
0005435960018	15239	Economy	10500.00
0005434267946	15239	Economy	10500.00
0005434267948	15239	Economy	10500.00
0005435960010	15239	Economy	10500.00
0005435960024	15239	Economy	10500.00
0005435960019	15239	Economy	10500.00
0005432675123	1182	Business	115000.00
0005432693005	1182	Business	115000.00
0005432873230	1182	Business	115000.00
0005432873232	1182	Business	115000.00
0005432675112	1182	Business	115000.00
0005432693031	1182	Business	115000.00
0005432693006	1182	Business	115000.00
0005432693021	1182	Business	115000.00
0005432693018	1182	Economy	38300.00
0005432693017	1182	Economy	38300.00
0005432675118	1182	Economy	38300.00
0005432693014	1182	Economy	38300.00
0005432675111	1182	Economy	38300.00
0005432675115	1182	Economy	42200.00
0005432675116	1182	Economy	42200.00
0005432693002	1182	Economy	38300.00
0005432693027	1182	Economy	38300.00
0005432873240	1182	Economy	38300.00
0005432675126	1182	Economy	38300.00
0005432693022	1182	Economy	38300.00
0005432675114	1182	Economy	38300.00
0005432693028	1182	Economy	38300.00
0005432675124	1182	Economy	38300.00
0005432873239	1182	Economy	38300.00
0005432677565	1182	Economy	38300.00
0005432675117	1182	Economy	38300.00
0005432693026	1182	Economy	38300.00
0005432873209	1182	Economy	38300.00
0005432693009	1182	Economy	38300.00
0005432677567	1182	Economy	38300.00
0005432677566	1182	Economy	38300.00
0005432693008	1182	Economy	38300.00
0005432693019	1182	Economy	38300.00
0005432675125	1182	Economy	38300.00
0005432693030	1182	Economy	38300.00
0005432693004	1182	Economy	38300.00
0005432693016	1182	Economy	38300.00
0005432693025	1182	Economy	38300.00
0005432693013	1182	Economy	38300.00
0005432693015	1182	Economy	38300.00
0005432675119	1182	Economy	38300.00
0005432693001	1182	Economy	38300.00
0005432693007	1182	Economy	38300.00
0005432693024	1182	Economy	38300.00
0005432675122	1182	Economy	38300.00
0005432693010	1182	Economy	38300.00
0005432693003	1182	Economy	38300.00
0005432693029	1182	Economy	38300.00
0005432873233	1182	Economy	38300.00
0005432693020	1182	Economy	38300.00
0005432675121	1182	Economy	38300.00
0005432675113	1182	Economy	38300.00
0005432693023	1182	Economy	38300.00
0005432675120	1182	Economy	38300.00
0005432693012	1182	Economy	38300.00
0005432677564	1182	Economy	38300.00
0005432693011	1182	Economy	38300.00
0005432692794	17492	Business	115000.00
0005432692804	17492	Business	115000.00
0005432692729	17492	Business	115000.00
0005432677540	17492	Business	115000.00
0005432692755	17492	Business	115000.00
0005432674953	17492	Business	115000.00
0005432692768	17492	Business	115000.00
0005432674969	17492	Business	115000.00
0005432675014	17492	Business	115000.00
0005432692737	17492	Business	115000.00
0005432692734	17492	Economy	38300.00
0005432873289	17492	Economy	38300.00
0005432692836	17492	Economy	38300.00
0005432692847	17492	Economy	38300.00
0005432675008	17492	Economy	42200.00
0005432692759	17492	Economy	38300.00
0005432873284	17492	Economy	38300.00
0005432675013	17492	Economy	38300.00
0005432674968	17492	Economy	38300.00
0005432677534	17492	Economy	38300.00
0005432675012	17492	Economy	38300.00
0005432873288	17492	Economy	38300.00
0005432692718	17492	Economy	38300.00
0005432674947	17492	Economy	38300.00
0005432873286	17492	Economy	38300.00
0005432692793	17492	Economy	38300.00
0005432692695	17492	Economy	38300.00
0005432692741	17492	Economy	38300.00
0005432692726	17492	Economy	38300.00
0005432692730	17492	Economy	38300.00
0005432674932	17492	Economy	38300.00
0005432692792	17492	Economy	38300.00
0005432873282	17492	Economy	38300.00
0005432692868	17492	Economy	38300.00
0005432692770	17492	Economy	38300.00
0005432873290	17492	Economy	38300.00
0005432873285	17492	Economy	38300.00
0005432692760	17492	Economy	38300.00
0005432675009	17492	Economy	38300.00
0005432692776	17492	Economy	38300.00
0005432692772	17492	Economy	38300.00
0005432674927	17492	Economy	38300.00
0005432692810	17492	Economy	38300.00
0005432692869	17492	Economy	38300.00
0005432692671	17492	Economy	38300.00
0005432692727	17492	Economy	38300.00
0005432692757	17492	Economy	38300.00
0005432692788	17492	Economy	38300.00
0005432692754	17492	Economy	38300.00
0005432674952	17492	Economy	38300.00
0005432692767	17492	Economy	38300.00
0005432692687	17492	Economy	38300.00
0005432873287	17492	Economy	38300.00
0005432692769	17492	Economy	38300.00
0005432677541	17492	Economy	38300.00
0005432677520	17492	Economy	38300.00
0005432692771	17492	Economy	38300.00
0005432692725	17492	Economy	38300.00
0005432873283	17492	Economy	38300.00
0005434435175	1147	Economy	15200.00
0005433156672	1147	Economy	13900.00
0005434435161	1147	Economy	13900.00
0005434435174	1147	Economy	13900.00
0005433156671	1147	Economy	13900.00
0005434435167	1147	Economy	13900.00
0005434435168	1147	Economy	13900.00
0005434435162	1147	Economy	13900.00
0005434435171	1147	Economy	13900.00
0005434435173	1147	Economy	13900.00
0005434435166	1147	Economy	13900.00
0005433156677	1147	Economy	13900.00
0005434435164	1147	Economy	13900.00
0005434435165	1147	Economy	13900.00
0005434435163	1147	Economy	13900.00
0005433156675	1147	Economy	13900.00
0005434435170	1147	Economy	13900.00
0005433156670	1147	Economy	13900.00
0005434435169	1147	Economy	13900.00
0005434435172	1147	Economy	13900.00
0005433156707	1147	Economy	13900.00
0005434435176	1147	Economy	13900.00
0005433156692	1147	Economy	13900.00
0005433156741	17292	Economy	15200.00
0005433156744	17292	Economy	13900.00
0005433156742	17292	Economy	13900.00
0005434435039	17292	Economy	13900.00
0005433156739	17292	Economy	13900.00
0005434435040	17292	Economy	13900.00
0005434435035	17292	Economy	13900.00
0005434434992	17292	Economy	13900.00
0005434435041	17292	Economy	13900.00
0005434435036	17292	Economy	13900.00
0005434435054	17292	Economy	13900.00
0005434434993	17292	Economy	13900.00
0005433156746	17292	Economy	13900.00
0005433156740	17292	Economy	13900.00
0005434435059	17292	Economy	13900.00
0005434435033	17292	Economy	13900.00
0005433156745	17292	Economy	13900.00
0005434435050	17292	Economy	13900.00
0005434435049	17292	Economy	13900.00
0005434435056	17292	Economy	13900.00
0005434435055	17292	Economy	13900.00
0005434435037	17292	Economy	13900.00
0005434435062	17292	Economy	13900.00
0005434435064	17292	Economy	13900.00
0005433156743	17292	Economy	13900.00
0005433156747	17292	Economy	13900.00
0005434434991	17292	Economy	13900.00
0005435086824	4055	Economy	8200.00
0005435928108	4055	Economy	7500.00
0005435086826	4055	Economy	7500.00
0005435086831	4055	Economy	7500.00
0005435928109	4055	Economy	7500.00
0005435086830	4055	Economy	7500.00
0005435928094	4055	Economy	7500.00
0005435086829	4055	Economy	7500.00
0005435928110	4055	Economy	7500.00
0005435086828	4055	Economy	7500.00
0005435086825	4055	Economy	7500.00
0005435086827	4055	Economy	7500.00
0005435086755	24392	Economy	8200.00
0005435086773	24392	Economy	7500.00
0005435086772	24392	Economy	7500.00
0005435086731	24392	Economy	7500.00
0005435928136	24392	Economy	7500.00
0005435086732	24392	Economy	7500.00
0005435086765	24392	Economy	7500.00
0005435086736	24392	Economy	7500.00
0005435086758	24392	Economy	7500.00
0005435086764	24392	Economy	7500.00
0005435086741	24392	Economy	7500.00
0005435928137	24392	Economy	7500.00
0005435086740	24392	Economy	7500.00
0005435086735	24392	Economy	7500.00
0005435928139	24392	Economy	7500.00
0005435928138	24392	Economy	7500.00
0005435086787	24392	Economy	7500.00
0005435928140	24392	Economy	7500.00
0005435706362	2448	Business	86800.00
0005433373427	2448	Business	86800.00
0005435706364	2448	Business	86800.00
0005433373459	2448	Business	86800.00
0005433373448	2448	Business	86800.00
0005433373422	2448	Business	86800.00
0005435706359	2448	Business	86800.00
0005435706335	2448	Business	86800.00
0005433373484	2448	Business	86800.00
0005433373430	2448	Business	86800.00
0005435706356	2448	Economy	28900.00
0005435706372	2448	Economy	28900.00
0005435706363	2448	Economy	28900.00
0005433373449	2448	Economy	28900.00
0005433373420	2448	Economy	28900.00
0005435706340	2448	Economy	28900.00
0005433373434	2448	Economy	28900.00
0005435706366	2448	Economy	31800.00
0005435706361	2448	Economy	31800.00
0005435706375	2448	Economy	31800.00
0005435706355	2448	Economy	31800.00
0005435706368	2448	Economy	31800.00
0005433373379	2448	Economy	28900.00
0005435706351	2448	Economy	28900.00
0005435706334	2448	Economy	28900.00
0005435706369	2448	Economy	28900.00
0005433373453	2448	Economy	28900.00
0005435706367	2448	Economy	28900.00
0005435706330	2448	Economy	28900.00
0005435706333	2448	Economy	28900.00
0005435706379	2448	Economy	28900.00
0005435706376	2448	Economy	28900.00
0005435706358	2448	Economy	28900.00
0005433373400	2448	Economy	28900.00
0005435706352	2448	Economy	28900.00
0005435706360	2448	Economy	28900.00
0005435706332	2448	Economy	28900.00
0005433373468	2448	Economy	28900.00
0005433373440	2448	Economy	28900.00
0005435706345	2448	Economy	28900.00
0005433373385	2448	Economy	28900.00
0005435706339	2448	Economy	28900.00
0005435706337	2448	Economy	28900.00
0005433373416	2448	Economy	28900.00
0005435706336	2448	Economy	28900.00
0005435706380	2448	Economy	28900.00
0005435706331	2448	Economy	28900.00
0005435706370	2448	Economy	28900.00
0005435706343	2448	Economy	28900.00
0005435706378	2448	Economy	28900.00
0005435706349	2448	Economy	28900.00
0005435706344	2448	Economy	28900.00
0005433373461	2448	Economy	28900.00
0005435706338	2448	Economy	28900.00
0005435706347	2448	Economy	28900.00
0005435706357	2448	Economy	28900.00
0005433373460	2448	Economy	28900.00
0005433373433	2448	Economy	28900.00
0005433373431	2448	Economy	28900.00
0005435706371	2448	Economy	28900.00
0005433373428	2448	Economy	28900.00
0005433373450	2448	Economy	28900.00
0005435706342	2448	Economy	28900.00
0005435706346	2448	Economy	28900.00
0005433373466	2448	Economy	28900.00
0005433373469	2448	Economy	28900.00
0005435706354	2448	Economy	28900.00
0005435706373	2448	Economy	28900.00
0005435706348	2448	Economy	28900.00
0005433373467	2448	Economy	28900.00
0005433373399	2448	Economy	28900.00
0005433373387	2448	Economy	28900.00
0005433373454	2448	Economy	28900.00
0005433373442	2448	Economy	28900.00
0005435706341	2448	Economy	28900.00
0005435706350	2448	Economy	28900.00
0005433373445	2448	Economy	28900.00
0005435706353	2448	Economy	28900.00
0005433373421	2448	Economy	28900.00
0005435706365	2448	Economy	28900.00
0005435706377	2448	Economy	28900.00
0005435706374	2448	Economy	28900.00
0005433373386	2448	Economy	28900.00
0005433373438	2448	Economy	28900.00
0005435706235	27037	Business	86800.00
0005433373515	27037	Business	86800.00
0005435706161	27037	Business	86800.00
0005435706194	27037	Business	86800.00
0005433373511	27037	Business	86800.00
0005433373524	27037	Business	86800.00
0005435706225	27037	Business	86800.00
0005435706138	27037	Business	86800.00
0005433373513	27037	Business	86800.00
0005435706262	27037	Business	86800.00
0005433373506	27037	Business	86800.00
0005435706239	27037	Economy	28900.00
0005433373505	27037	Economy	28900.00
0005435706222	27037	Economy	28900.00
0005435706174	27037	Economy	28900.00
0005435706215	27037	Economy	28900.00
0005435706157	27037	Economy	28900.00
0005435706249	27037	Economy	28900.00
0005435706227	27037	Economy	28900.00
0005433373529	27037	Economy	28900.00
0005435706213	27037	Economy	31800.00
0005435706185	27037	Economy	31800.00
0005435706203	27037	Economy	31800.00
0005433373530	27037	Economy	28900.00
0005433373531	27037	Economy	28900.00
0005433373508	27037	Economy	28900.00
0005435706256	27037	Economy	28900.00
0005433373509	27037	Economy	28900.00
0005435706224	27037	Economy	28900.00
0005435706199	27037	Economy	28900.00
0005435706173	27037	Economy	28900.00
0005435706214	27037	Economy	28900.00
0005435706188	27037	Economy	28900.00
0005435706148	27037	Economy	28900.00
0005435706238	27037	Economy	28900.00
0005435706250	27037	Economy	28900.00
0005435706226	27037	Economy	28900.00
0005433373527	27037	Economy	28900.00
0005433373516	27037	Economy	28900.00
0005435706158	27037	Economy	28900.00
0005435706206	27037	Economy	28900.00
0005435706176	27037	Economy	28900.00
0005433373504	27037	Economy	28900.00
0005433373528	27037	Economy	28900.00
0005435706160	27037	Economy	28900.00
0005433373512	27037	Economy	28900.00
0005435706236	27037	Economy	28900.00
0005433373518	27037	Economy	28900.00
0005435706163	27037	Economy	28900.00
0005435706184	27037	Economy	28900.00
0005433373520	27037	Economy	28900.00
0005435706192	27037	Economy	28900.00
0005435706197	27037	Economy	28900.00
0005433373523	27037	Economy	28900.00
0005435706202	27037	Economy	28900.00
0005435706255	27037	Economy	28900.00
0005433373507	27037	Economy	28900.00
0005435706149	27037	Economy	28900.00
0005433373510	27037	Economy	28900.00
0005435706283	27037	Economy	28900.00
0005435706164	27037	Economy	28900.00
0005433373514	27037	Economy	28900.00
0005435706198	27037	Economy	28900.00
0005433373519	27037	Economy	28900.00
0005435706159	27037	Economy	28900.00
0005435706207	27037	Economy	28900.00
0005435706196	27037	Economy	28900.00
0005433373526	27037	Economy	28900.00
0005435706183	27037	Economy	28900.00
0005435706210	27037	Economy	28900.00
0005433373517	27037	Economy	28900.00
0005435706247	27037	Economy	28900.00
0005433373521	27037	Economy	28900.00
0005435706212	27037	Economy	28900.00
0005433373522	27037	Economy	28900.00
0005435706223	27037	Economy	28900.00
0005435706162	27037	Economy	28900.00
0005435706201	27037	Economy	28900.00
0005433373525	27037	Economy	28900.00
0005435706204	27037	Economy	28900.00
0005435706167	27037	Economy	28900.00
0005435907461	4842	Business	44200.00
0005435907456	4842	Business	44200.00
0005435907457	4842	Business	44200.00
0005434625952	4842	Business	44200.00
0005435907427	4842	Economy	14700.00
0005434625955	4842	Economy	14700.00
0005434625957	4842	Economy	16200.00
0005435907435	4842	Economy	14700.00
0005434625953	4842	Economy	14700.00
0005434625951	4842	Economy	14700.00
0005435907455	4842	Economy	14700.00
0005435907434	4842	Economy	14700.00
0005434625950	4842	Economy	14700.00
0005435907472	4842	Economy	14700.00
0005435907454	4842	Economy	14700.00
0005434625954	4842	Economy	14700.00
0005435907426	4842	Economy	14700.00
0005434625956	4842	Economy	14700.00
0005434625949	4842	Economy	14700.00
0005435907504	32894	Business	44200.00
0005435907505	32894	Business	44200.00
0005434625876	32894	Business	44200.00
0005434625878	32894	Economy	16200.00
0005435907503	32894	Economy	16200.00
0005434625920	32894	Economy	14700.00
0005434625877	32894	Economy	14700.00
0005434625874	32894	Economy	14700.00
0005434625885	32894	Economy	14700.00
0005434625886	32894	Economy	14700.00
0005435907502	32894	Economy	14700.00
0005434625879	32894	Economy	14700.00
0005434625921	32894	Economy	14700.00
0005435785081	13753	Economy	3400.00
0005435784882	13753	Economy	3400.00
0005435937388	13753	Economy	3400.00
0005435784801	13753	Economy	3100.00
0005435937387	13753	Economy	3100.00
0005435787329	13753	Economy	3100.00
0005435784843	13753	Economy	3100.00
0005435784866	13753	Economy	3100.00
0005435784939	13753	Economy	3100.00
0005435784959	13753	Economy	3100.00
0005435784865	13753	Economy	3100.00
0005435784867	13753	Economy	3100.00
0005435785065	13753	Economy	3100.00
0005435784864	13753	Economy	3100.00
0005435784764	13753	Economy	3100.00
0005435785021	13753	Economy	3100.00
0005435937384	13753	Economy	3100.00
0005435784974	13753	Economy	3100.00
0005435784827	13753	Economy	3100.00
0005435937383	13753	Economy	3100.00
0005435937385	13753	Economy	3100.00
0005435785020	13753	Economy	3100.00
0005435784942	13753	Economy	3100.00
0005435785115	13753	Economy	3100.00
0005435785019	13753	Economy	3100.00
0005435785082	13753	Economy	3100.00
0005435784976	13753	Economy	3100.00
0005435784977	13753	Economy	3100.00
0005435785016	13753	Economy	3100.00
0005435785002	13753	Economy	3100.00
0005435785033	13753	Economy	3100.00
0005435937386	13753	Economy	3100.00
0005435784985	13753	Economy	3100.00
0005435784963	13753	Economy	3100.00
0005435784978	13753	Economy	3100.00
0005435785077	13753	Economy	3100.00
0005435784839	13753	Economy	3100.00
0005435784975	13753	Economy	3100.00
0005435784998	13753	Economy	3100.00
0005435784958	13753	Economy	3100.00
0005435785011	13753	Economy	3100.00
0005435784922	13753	Economy	3100.00
0005435785292	27408	Economy	3400.00
0005435787349	27408	Economy	3400.00
0005435785259	27408	Economy	3400.00
0005435785288	27408	Economy	3100.00
0005435785270	27408	Economy	3100.00
0005435785265	27408	Economy	3100.00
0005435785262	27408	Economy	3100.00
0005432190619	27408	Economy	3100.00
0005435785287	27408	Economy	3100.00
0005435785263	27408	Economy	3100.00
0005432190620	27408	Economy	3100.00
0005435785282	27408	Economy	3100.00
0005435785291	27408	Economy	3100.00
0005435785264	27408	Economy	3100.00
0005435785275	27408	Economy	3100.00
0005435785278	27408	Economy	3100.00
0005435785285	27408	Economy	3100.00
0005432190621	27408	Economy	3100.00
0005435785289	27408	Economy	3100.00
0005435785268	27408	Economy	3100.00
0005435785261	27408	Economy	3100.00
0005435785273	27408	Economy	3100.00
0005435785266	27408	Economy	3100.00
0005435785277	27408	Economy	3100.00
0005435785290	27408	Economy	3100.00
0005435785279	27408	Economy	3100.00
0005435785260	27408	Economy	3100.00
0005435785276	27408	Economy	3100.00
0005435785272	27408	Economy	3100.00
0005435785283	27408	Economy	3100.00
0005435785271	27408	Economy	3100.00
0005435785280	27408	Economy	3100.00
0005435785269	27408	Economy	3100.00
0005435785281	27408	Economy	3100.00
0005435785293	27408	Economy	3100.00
0005432190622	27408	Economy	3100.00
0005435785284	27408	Economy	3100.00
0005432190623	27408	Economy	3100.00
0005435785267	27408	Economy	3100.00
0005435785286	27408	Economy	3100.00
0005435785274	27408	Economy	3100.00
0005435311054	20288	Business	12000.00
0005435311059	20288	Business	12000.00
0005434407183	20288	Business	12000.00
0005434407400	20288	Business	12000.00
0005435311057	20288	Business	12000.00
0005434406850	20288	Business	12000.00
0005434407080	20288	Business	12000.00
0005434407347	20288	Business	12000.00
0005434407277	20288	Business	12000.00
0005434406973	20288	Economy	4000.00
0005434407156	20288	Economy	4000.00
0005435311061	20288	Economy	4000.00
0005434407062	20288	Economy	4000.00
0005434407095	20288	Economy	4000.00
0005434407288	20288	Economy	4000.00
0005434407262	20288	Economy	4400.00
0005434407108	20288	Economy	4400.00
0005434406975	20288	Economy	4400.00
0005434407287	20288	Economy	4400.00
0005434407275	20288	Economy	4400.00
0005434407046	20288	Economy	4000.00
0005434407423	20288	Economy	4000.00
0005434407182	20288	Economy	4000.00
0005432058377	20288	Economy	4000.00
0005434407132	20288	Economy	4000.00
0005434407184	20288	Economy	4000.00
0005434407342	20288	Economy	4000.00
0005434407098	20288	Economy	4000.00
0005434407244	20288	Economy	4000.00
0005434407059	20288	Economy	4000.00
0005435311053	20288	Economy	4000.00
0005434407401	20288	Economy	4000.00
0005434407461	20288	Economy	4000.00
0005434407039	20288	Economy	4000.00
0005435311052	20288	Economy	4000.00
0005434407298	20288	Economy	4000.00
0005434407460	20288	Economy	4000.00
0005434407341	20288	Economy	4000.00
0005435311060	20288	Economy	4000.00
0005434407422	20288	Economy	4000.00
0005434407025	20288	Economy	4000.00
0005434407260	20288	Economy	4000.00
0005435311055	20288	Economy	4000.00
0005434407079	20288	Economy	4000.00
0005435311056	20288	Economy	4000.00
0005434407061	20288	Economy	4000.00
0005434407074	20288	Economy	4000.00
0005435311062	20288	Economy	4000.00
0005435311058	20288	Economy	4000.00
0005434407348	20288	Economy	4000.00
0005434406963	20288	Economy	4000.00
0005434407053	20288	Economy	4000.00
0005434407346	20288	Economy	4000.00
0005434407045	20288	Economy	4000.00
0005432058376	20288	Economy	4000.00
0005434407006	20288	Economy	4000.00
0005434407155	20288	Economy	4000.00
0005434407261	20288	Economy	4000.00
0005434407172	20288	Economy	4000.00
0005434407281	20288	Economy	4000.00
0005434407049	20288	Economy	4000.00
0005434407278	20288	Economy	4000.00
0005432058379	20288	Economy	4000.00
0005434407137	20288	Economy	4000.00
0005434407276	20288	Economy	4000.00
0005432058380	20288	Economy	4000.00
0005432058378	20288	Economy	4000.00
0005434407689	27014	Business	12000.00
0005434407710	27014	Business	12000.00
0005434407705	27014	Business	12000.00
0005434407690	27014	Business	12000.00
0005434407686	27014	Business	12000.00
0005435310870	27014	Business	12000.00
0005434407679	27014	Business	12000.00
0005434407715	27014	Business	12000.00
0005434407721	27014	Business	12000.00
0005434407712	27014	Business	12000.00
0005432153930	27014	Business	12000.00
0005432153933	27014	Economy	4000.00
0005434407691	27014	Economy	4000.00
0005434407719	27014	Economy	4000.00
0005434407708	27014	Economy	4000.00
0005434407709	27014	Economy	4000.00
0005434407724	27014	Economy	4000.00
0005435310931	27014	Economy	4000.00
0005434407672	27014	Economy	4400.00
0005434407722	27014	Economy	4400.00
0005434407692	27014	Economy	4400.00
0005434407682	27014	Economy	4400.00
0005434407676	27014	Economy	4400.00
0005435310937	27014	Economy	4000.00
0005434407717	27014	Economy	4000.00
0005434407699	27014	Economy	4000.00
0005434407687	27014	Economy	4000.00
0005434407729	27014	Economy	4000.00
0005434407683	27014	Economy	4000.00
0005435310938	27014	Economy	4000.00
0005434407726	27014	Economy	4000.00
0005435310917	27014	Economy	4000.00
0005434407727	27014	Economy	4000.00
0005434407704	27014	Economy	4000.00
0005434407700	27014	Economy	4000.00
0005434407698	27014	Economy	4000.00
0005434407688	27014	Economy	4000.00
0005434407718	27014	Economy	4000.00
0005434407731	27014	Economy	4000.00
0005434407713	27014	Economy	4000.00
0005434407695	27014	Economy	4000.00
0005434407707	27014	Economy	4000.00
0005434407702	27014	Economy	4000.00
0005434407735	27014	Economy	4000.00
0005435310887	27014	Economy	4000.00
0005434407677	27014	Economy	4000.00
0005434407734	27014	Economy	4000.00
0005434407716	27014	Economy	4000.00
0005434407732	27014	Economy	4000.00
0005434407675	27014	Economy	4000.00
0005434407728	27014	Economy	4000.00
0005434407733	27014	Economy	4000.00
0005434407714	27014	Economy	4000.00
0005434407711	27014	Economy	4000.00
0005434407730	27014	Economy	4000.00
0005434407696	27014	Economy	4000.00
0005432153929	27014	Economy	4000.00
0005434407693	27014	Economy	4000.00
0005434407720	27014	Economy	4000.00
0005434407703	27014	Economy	4000.00
0005432153928	27014	Economy	4000.00
0005432153934	27014	Economy	4000.00
0005434407706	27014	Economy	4000.00
0005434407680	27014	Economy	4000.00
0005434407697	27014	Economy	4000.00
0005434407694	27014	Economy	4000.00
0005432153931	27014	Economy	4000.00
0005435310919	27014	Economy	4000.00
0005434407701	27014	Economy	4000.00
0005434407674	27014	Economy	4000.00
0005434407673	27014	Economy	4000.00
0005435310891	27014	Economy	4000.00
0005435310871	27014	Economy	4000.00
0005434407725	27014	Economy	4000.00
0005434407678	27014	Economy	4000.00
0005434407684	27014	Economy	4000.00
0005434407685	27014	Economy	4000.00
0005432153932	27014	Economy	4000.00
0005434407723	27014	Economy	4000.00
0005434407681	27014	Economy	4000.00
0005435310892	27014	Economy	4000.00
0005433123682	5703	Business	43300.00
0005434319386	5703	Business	43300.00
0005433123726	5703	Business	43300.00
0005432109701	5703	Business	43300.00
0005433123727	5703	Business	43300.00
0005434319390	5703	Business	43300.00
0005433123792	5703	Business	43300.00
0005433123665	5703	Economy	14400.00
0005433123760	5703	Economy	14400.00
0005432109700	5703	Economy	14400.00
0005433123756	5703	Economy	14400.00
0005434319393	5703	Economy	14400.00
0005434319384	5703	Economy	15900.00
0005433123678	5703	Economy	15900.00
0005434319385	5703	Economy	14400.00
0005434319391	5703	Economy	14400.00
0005433123716	5703	Economy	14400.00
0005433123738	5703	Economy	14400.00
0005433123667	5703	Economy	14400.00
0005433123773	5703	Economy	14400.00
0005434319389	5703	Economy	14400.00
0005433123739	5703	Economy	14400.00
0005433123679	5703	Economy	14400.00
0005433123708	5703	Economy	14400.00
0005433123722	5703	Economy	14400.00
0005434319392	5703	Economy	14400.00
0005433123742	5703	Economy	14400.00
0005433123672	5703	Economy	14400.00
0005433123638	5703	Economy	14400.00
0005434311217	5703	Economy	14400.00
0005433123700	5703	Economy	14400.00
0005433123666	5703	Economy	14400.00
0005434311216	5703	Economy	14400.00
0005433123786	5703	Economy	14400.00
0005434319387	5703	Economy	14400.00
0005433123677	5703	Economy	14400.00
0005433123791	5703	Economy	14400.00
0005434319388	5703	Economy	14400.00
0005433123924	15668	Business	43300.00
0005433123920	15668	Business	43300.00
0005434311201	15668	Business	43300.00
0005433123926	15668	Business	43300.00
0005434319233	15668	Economy	14400.00
0005434311195	15668	Economy	14400.00
0005434319253	15668	Economy	14400.00
0005434319240	15668	Economy	15900.00
0005433123912	15668	Economy	15900.00
0005433123918	15668	Economy	14400.00
0005434319292	15668	Economy	14400.00
0005434319257	15668	Economy	14400.00
0005434319221	15668	Economy	14400.00
0005433123929	15668	Economy	14400.00
0005433123914	15668	Economy	14400.00
0005433123921	15668	Economy	14400.00
0005433123917	15668	Economy	14400.00
0005434319234	15668	Economy	14400.00
0005433123911	15668	Economy	14400.00
0005433123930	15668	Economy	14400.00
0005433123925	15668	Economy	14400.00
0005433123923	15668	Economy	14400.00
0005433123928	15668	Economy	14400.00
0005434319238	15668	Economy	14400.00
0005433123913	15668	Economy	14400.00
0005434319311	15668	Economy	14400.00
0005434319314	15668	Economy	14400.00
0005433123915	15668	Economy	14400.00
0005434319235	15668	Economy	14400.00
0005434319248	15668	Economy	14400.00
0005434319239	15668	Economy	14400.00
0005433123916	15668	Economy	14400.00
0005434319313	15668	Economy	14400.00
0005433123922	15668	Economy	14400.00
0005434311196	15668	Economy	14400.00
0005434319222	15668	Economy	14400.00
0005433123919	15668	Economy	14400.00
0005434319223	15668	Economy	14400.00
0005434319177	15668	Economy	14400.00
0005434319237	15668	Economy	14400.00
0005433123927	15668	Economy	14400.00
0005434319291	15668	Economy	14400.00
0005434311194	15668	Economy	14400.00
0005435220317	31735	Economy	15500.00
0005435219199	31735	Economy	15500.00
0005435219197	31735	Economy	15500.00
0005435220319	31735	Economy	15500.00
0005435220318	31735	Economy	15500.00
0005435219200	31735	Economy	15500.00
0005435220316	31735	Economy	15500.00
0005435219198	31735	Economy	15500.00
0005434484345	8970	Economy	27400.00
0005434484339	8970	Economy	24900.00
0005434484342	8970	Economy	24900.00
0005434189121	8970	Economy	24900.00
0005434189119	8970	Economy	24900.00
0005434484340	8970	Economy	24900.00
0005434189120	8970	Economy	24900.00
0005434484341	8970	Economy	24900.00
0005434484343	8970	Economy	24900.00
0005434484344	8970	Economy	24900.00
0005434484285	16646	Economy	27400.00
0005434484308	16646	Economy	24900.00
0005434189176	16646	Economy	24900.00
0005434189173	16646	Economy	24900.00
0005434189177	16646	Economy	24900.00
0005434189174	16646	Economy	24900.00
0005434484269	16646	Economy	24900.00
0005434484279	16646	Economy	24900.00
0005434189172	16646	Economy	24900.00
0005434484311	16646	Economy	24900.00
0005434189175	16646	Economy	24900.00
0005434484294	16646	Economy	24900.00
0005434484295	16646	Economy	24900.00
0005434189170	16646	Economy	24900.00
0005434189171	16646	Economy	24900.00
0005433123922	7568	Business	11100.00
0005433123924	7568	Business	11100.00
0005433123919	7568	Economy	3700.00
0005433123925	7568	Economy	4100.00
0005433123915	7568	Economy	4100.00
0005433123920	7568	Economy	3700.00
0005433123923	7568	Economy	3700.00
0005433123917	7568	Economy	3700.00
0005433123921	7568	Economy	3700.00
0005433123918	7568	Economy	3700.00
0005433722131	7568	Economy	3700.00
0005433123913	7568	Economy	3700.00
0005433123926	7568	Economy	3700.00
0005433722128	7568	Economy	3700.00
0005433123928	7568	Economy	3700.00
0005433722121	7568	Economy	3700.00
0005433123914	7568	Economy	3700.00
0005433123927	7568	Economy	3700.00
0005433123930	7568	Economy	3700.00
0005433123911	7568	Economy	3700.00
0005433123929	7568	Economy	3700.00
0005433123912	7568	Economy	3700.00
0005433123916	7568	Economy	3700.00
0005432693054	7569	Business	11100.00
0005432693060	7569	Business	11100.00
0005433449951	7569	Business	11100.00
0005433449950	7569	Business	11100.00
0005432720867	7569	Business	11100.00
0005432693036	7569	Business	11100.00
0005432693048	7569	Business	11100.00
0005433449956	7569	Business	11100.00
0005432693043	7569	Business	11100.00
0005432720887	7569	Business	11100.00
0005433449942	7569	Business	11100.00
0005433449954	7569	Economy	3700.00
0005432720893	7569	Economy	3700.00
0005432071571	7569	Economy	3700.00
0005432720892	7569	Economy	3700.00
0005432693047	7569	Economy	3700.00
0005432693034	7569	Economy	3700.00
0005432720873	7569	Economy	3700.00
0005432693063	7569	Economy	3700.00
0005433449946	7569	Economy	3700.00
0005432071569	7569	Economy	3700.00
0005433449952	7569	Economy	4100.00
0005432693057	7569	Economy	4100.00
0005433449943	7569	Economy	4100.00
0005432720894	7569	Economy	4100.00
0005432693053	7569	Economy	3700.00
0005432720872	7569	Economy	3700.00
0005432693039	7569	Economy	3700.00
0005432720876	7569	Economy	3700.00
0005432720884	7569	Economy	3700.00
0005432071570	7569	Economy	3700.00
0005433449945	7569	Economy	3700.00
0005433449953	7569	Economy	3700.00
0005432720868	7569	Economy	3700.00
0005432720890	7569	Economy	3700.00
0005432720871	7569	Economy	3700.00
0005433449955	7569	Economy	3700.00
0005433449941	7569	Economy	3700.00
0005432693051	7569	Economy	3700.00
0005432693050	7569	Economy	3700.00
0005433449961	7569	Economy	3700.00
0005432693052	7569	Economy	3700.00
0005432693038	7569	Economy	3700.00
0005432693032	7569	Economy	3700.00
0005432720885	7569	Economy	3700.00
0005432693046	7569	Economy	3700.00
0005433449959	7569	Economy	3700.00
0005433449948	7569	Economy	3700.00
0005432693041	7569	Economy	3700.00
0005432720869	7569	Economy	3700.00
0005432720886	7569	Economy	3700.00
0005432720875	7569	Economy	3700.00
0005432720880	7569	Economy	3700.00
0005432693058	7569	Economy	3700.00
0005432693044	7569	Economy	3700.00
0005432720874	7569	Economy	3700.00
0005432693042	7569	Economy	3700.00
0005432720878	7569	Economy	3700.00
0005432693055	7569	Economy	3700.00
0005432693059	7569	Economy	3700.00
0005432693037	7569	Economy	3700.00
0005432693049	7569	Economy	3700.00
0005432720879	7569	Economy	3700.00
0005433449957	7569	Economy	3700.00
0005432693061	7569	Economy	3700.00
0005432720877	7569	Economy	3700.00
0005432693045	7569	Economy	3700.00
0005433449947	7569	Economy	3700.00
0005433449949	7569	Economy	3700.00
0005432720883	7569	Economy	3700.00
0005432720881	7569	Economy	3700.00
0005432720888	7569	Economy	3700.00
0005433449960	7569	Economy	3700.00
0005432693062	7569	Economy	3700.00
0005432693035	7569	Economy	3700.00
0005432693056	7569	Economy	3700.00
0005432693033	7569	Economy	3700.00
0005432720870	7569	Economy	3700.00
0005432720891	7569	Economy	3700.00
0005432720889	7569	Economy	3700.00
0005432720882	7569	Economy	3700.00
0005433449944	7569	Economy	3700.00
0005432693040	7569	Economy	3700.00
0005433449958	7569	Economy	3700.00
0005433449687	30314	Business	11100.00
0005433449849	30314	Business	11100.00
0005432692671	30314	Business	11100.00
0005432692769	30314	Business	11100.00
0005432692847	30314	Business	11100.00
0005432692869	30314	Business	11100.00
0005433449711	30314	Business	11100.00
0005432692695	30314	Business	11100.00
0005432692792	30314	Business	11100.00
0005432692687	30314	Business	11100.00
0005432692726	30314	Business	11100.00
0005432692734	30314	Economy	3700.00
0005432692868	30314	Economy	3700.00
0005433449710	30314	Economy	3700.00
0005433449705	30314	Economy	3700.00
0005433449802	30314	Economy	3700.00
0005432692836	30314	Economy	3700.00
0005433449726	30314	Economy	4100.00
0005432692737	30314	Economy	4100.00
0005433449701	30314	Economy	4100.00
0005432692804	30314	Economy	3700.00
0005432692729	30314	Economy	3700.00
0005432692741	30314	Economy	3700.00
0005432692772	30314	Economy	3700.00
0005432692754	30314	Economy	3700.00
0005432692760	30314	Economy	3700.00
0005433449651	30314	Economy	3700.00
0005433449712	30314	Economy	3700.00
0005432692759	30314	Economy	3700.00
0005433449750	30314	Economy	3700.00
0005433449806	30314	Economy	3700.00
0005432692788	30314	Economy	3700.00
0005433449783	30314	Economy	3700.00
0005432692794	30314	Economy	3700.00
0005433449704	30314	Economy	3700.00
0005432692757	30314	Economy	3700.00
0005433449751	30314	Economy	3700.00
0005433449749	30314	Economy	3700.00
0005432692771	30314	Economy	3700.00
0005432692718	30314	Economy	3700.00
0005433449650	30314	Economy	3700.00
0005433449830	30314	Economy	3700.00
0005433449742	30314	Economy	3700.00
0005432692770	30314	Economy	3700.00
0005432692730	30314	Economy	3700.00
0005432692793	30314	Economy	3700.00
0005433449688	30314	Economy	3700.00
0005432692755	30314	Economy	3700.00
0005432692767	30314	Economy	3700.00
0005433449848	30314	Economy	3700.00
0005433449799	30314	Economy	3700.00
0005433449767	30314	Economy	3700.00
0005433449784	30314	Economy	3700.00
0005432692727	30314	Economy	3700.00
0005433449793	30314	Economy	3700.00
0005432692810	30314	Economy	3700.00
0005433449775	30314	Economy	3700.00
0005432692768	30314	Economy	3700.00
0005432692776	30314	Economy	3700.00
0005433449752	30314	Economy	3700.00
0005433449709	30314	Economy	3700.00
0005432692725	30314	Economy	3700.00
0005432720679	30313	Business	11100.00
0005432720738	30313	Business	11100.00
0005433123727	30313	Business	11100.00
0005432720693	30313	Business	11100.00
0005433123672	30313	Economy	3700.00
0005432720665	30313	Economy	3700.00
0005433123773	30313	Economy	3700.00
0005433123722	30313	Economy	3700.00
0005433123786	30313	Economy	3700.00
0005433722224	30313	Economy	4100.00
0005433123700	30313	Economy	4100.00
0005433123638	30313	Economy	3700.00
0005432720767	30313	Economy	3700.00
0005433123679	30313	Economy	3700.00
0005433123742	30313	Economy	3700.00
0005432720800	30313	Economy	3700.00
0005433123738	30313	Economy	3700.00
0005433722218	30313	Economy	3700.00
0005432720574	30313	Economy	3700.00
0005433123760	30313	Economy	3700.00
0005433722219	30313	Economy	3700.00
0005432720631	30313	Economy	3700.00
0005433123667	30313	Economy	3700.00
0005433123739	30313	Economy	3700.00
0005433123666	30313	Economy	3700.00
0005433123665	30313	Economy	3700.00
0005433123677	30313	Economy	3700.00
0005433123682	30313	Economy	3700.00
0005433123791	30313	Economy	3700.00
0005433123756	30313	Economy	3700.00
0005433722223	30313	Economy	3700.00
0005432720715	30313	Economy	3700.00
0005433722221	30313	Economy	3700.00
0005432720573	30313	Economy	3700.00
0005433123716	30313	Economy	3700.00
0005433722220	30313	Economy	3700.00
0005433123708	30313	Economy	3700.00
0005432720737	30313	Economy	3700.00
0005433123792	30313	Economy	3700.00
0005433123726	30313	Economy	3700.00
0005433722217	30313	Economy	3700.00
0005433722222	30313	Economy	3700.00
0005432720768	30313	Economy	3700.00
0005433123678	30313	Economy	3700.00
0005432720622	30313	Economy	3700.00
0005433525030	1409	Business	70400.00
0005434586604	1409	Business	70400.00
0005433192840	1409	Business	70400.00
0005433525024	1409	Business	70400.00
0005433724802	1409	Business	70400.00
0005433192910	1409	Business	70400.00
0005432968824	1409	Business	70400.00
0005433192940	1409	Business	70400.00
0005434586601	1409	Business	70400.00
0005433192950	1409	Business	70400.00
0005433525029	1409	Business	70400.00
0005433525033	1409	Economy	23500.00
0005434514966	1409	Economy	23500.00
0005433724803	1409	Economy	23500.00
0005432927929	1409	Economy	23500.00
0005433192941	1409	Economy	23500.00
0005433724804	1409	Economy	23500.00
0005432968823	1409	Economy	23500.00
0005434586589	1409	Economy	25800.00
0005434586583	1409	Economy	25800.00
0005433192961	1409	Economy	25800.00
0005434586585	1409	Economy	25800.00
0005434513576	1409	Economy	25800.00
0005433525026	1409	Economy	23500.00
0005433192872	1409	Economy	23500.00
0005432271000	1409	Economy	23500.00
0005434586595	1409	Economy	23500.00
0005433724805	1409	Economy	23500.00
0005434514967	1409	Economy	23500.00
0005432271001	1409	Economy	23500.00
0005433192905	1409	Economy	23500.00
0005433525031	1409	Economy	23500.00
0005433192962	1409	Economy	23500.00
0005434586599	1409	Economy	23500.00
0005433192976	1409	Economy	23500.00
0005433192908	1409	Economy	23500.00
0005433525027	1409	Economy	23500.00
0005434586588	1409	Economy	23500.00
0005434513578	1409	Economy	23500.00
0005434586579	1409	Economy	23500.00
0005434586582	1409	Economy	23500.00
0005432271002	1409	Economy	23500.00
0005434586584	1409	Economy	23500.00
0005434586600	1409	Economy	23500.00
0005434586580	1409	Economy	23500.00
0005434586596	1409	Economy	23500.00
0005434586587	1409	Economy	23500.00
0005433192967	1409	Economy	23500.00
0005433525032	1409	Economy	23500.00
0005432927930	1409	Economy	23500.00
0005432927945	1409	Economy	23500.00
0005434586586	1409	Economy	23500.00
0005434586603	1409	Economy	23500.00
0005433192993	1409	Economy	23500.00
0005434513577	1409	Economy	23500.00
0005433192949	1409	Economy	23500.00
0005432968827	1409	Economy	23500.00
0005433192992	1409	Economy	23500.00
0005434586598	1409	Economy	23500.00
0005433192933	1409	Economy	23500.00
0005434514965	1409	Economy	23500.00
0005433192912	1409	Economy	23500.00
0005433525025	1409	Economy	23500.00
0005434586594	1409	Economy	23500.00
0005433525034	1409	Economy	23500.00
0005432927944	1409	Economy	23500.00
0005434586593	1409	Economy	23500.00
0005434586592	1409	Economy	23500.00
0005433192944	1409	Economy	23500.00
0005433192974	1409	Economy	23500.00
0005434586597	1409	Economy	23500.00
0005434586590	1409	Economy	23500.00
0005434586602	1409	Economy	23500.00
0005434586591	1409	Economy	23500.00
0005434586578	1409	Economy	23500.00
0005433192975	1409	Economy	23500.00
0005434586581	1409	Economy	23500.00
0005433525028	1409	Economy	23500.00
0005433193036	18513	Business	70400.00
0005433524897	18513	Business	70400.00
0005434586255	18513	Business	70400.00
0005432927974	18513	Business	70400.00
0005433193032	18513	Business	70400.00
0005433524935	18513	Business	70400.00
0005433193037	18513	Economy	23500.00
0005434586368	18513	Economy	23500.00
0005432927973	18513	Economy	23500.00
0005433193030	18513	Economy	23500.00
0005433524949	18513	Economy	23500.00
0005433193029	18513	Economy	23500.00
0005433193028	18513	Economy	23500.00
0005434514943	18513	Economy	25800.00
0005434586436	18513	Economy	25800.00
0005434586409	18513	Economy	25800.00
0005433524948	18513	Economy	25800.00
0005433724741	18513	Economy	25800.00
0005434586370	18513	Economy	23500.00
0005433724748	18513	Economy	23500.00
0005433524905	18513	Economy	23500.00
0005433724742	18513	Economy	23500.00
0005434586348	18513	Economy	23500.00
0005433724758	18513	Economy	23500.00
0005433193031	18513	Economy	23500.00
0005434586285	18513	Economy	23500.00
0005433524978	18513	Economy	23500.00
0005434586369	18513	Economy	23500.00
0005434586347	18513	Economy	23500.00
0005434514937	18513	Economy	23500.00
0005432968837	18513	Economy	23500.00
0005432927975	18513	Economy	23500.00
0005434586306	18513	Economy	23500.00
0005432968838	18513	Economy	23500.00
0005434586465	18513	Economy	23500.00
0005432927976	18513	Economy	23500.00
0005434586358	18513	Economy	23500.00
0005434586384	18513	Economy	23500.00
0005434514938	18513	Economy	23500.00
0005433524933	18513	Economy	23500.00
0005433193040	18513	Economy	23500.00
0005433193041	18513	Economy	23500.00
0005434586410	18513	Economy	23500.00
0005433524942	18513	Economy	23500.00
0005432927972	18513	Economy	23500.00
0005433524904	18513	Economy	23500.00
0005433724757	18513	Economy	23500.00
0005434586337	18513	Economy	23500.00
0005433524956	18513	Economy	23500.00
0005433193033	18513	Economy	23500.00
0005433524934	18513	Economy	23500.00
0005434586349	18513	Economy	23500.00
0005434586442	18513	Economy	23500.00
0005434586408	18513	Economy	23500.00
0005433193038	18513	Economy	23500.00
0005433524941	18513	Economy	23500.00
0005433193035	18513	Economy	23500.00
0005433193039	18513	Economy	23500.00
0005434586216	18513	Economy	23500.00
0005434514939	18513	Economy	23500.00
0005433193034	18513	Economy	23500.00
0005434514950	18513	Economy	23500.00
0005434344157	11434	Economy	4300.00
0005434344153	11434	Economy	4300.00
0005434344171	11434	Economy	4300.00
0005434142606	11434	Economy	4300.00
0005434344136	11434	Economy	4000.00
0005434344146	11434	Economy	4000.00
0005434344151	11434	Economy	4000.00
0005435304998	11434	Economy	4000.00
0005435302165	11434	Economy	4000.00
0005434344149	11434	Economy	4000.00
0005434142608	11434	Economy	4000.00
0005434344137	11434	Economy	4000.00
0005434344163	11434	Economy	4000.00
0005434344166	11434	Economy	4000.00
0005434344161	11434	Economy	4000.00
0005434344162	11434	Economy	4000.00
0005434344164	11434	Economy	4000.00
0005434344160	11434	Economy	4000.00
0005434344150	11434	Economy	4000.00
0005434344140	11434	Economy	4000.00
0005434344152	11434	Economy	4000.00
0005434344144	11434	Economy	4000.00
0005434344154	11434	Economy	4000.00
0005434142605	11434	Economy	4000.00
0005434344173	11434	Economy	4000.00
0005434344145	11434	Economy	4000.00
0005434344168	11434	Economy	4000.00
0005435302166	11434	Economy	4000.00
0005434344148	11434	Economy	4000.00
0005434344159	11434	Economy	4000.00
0005434344139	11434	Economy	4000.00
0005434344142	11434	Economy	4000.00
0005434344165	11434	Economy	4000.00
0005434344141	11434	Economy	4000.00
0005434344167	11434	Economy	4000.00
0005435302144	11434	Economy	4000.00
0005434344155	11434	Economy	4000.00
0005434142607	11434	Economy	4000.00
0005435304999	11434	Economy	4000.00
0005434344156	11434	Economy	4000.00
0005434344169	11434	Economy	4000.00
0005434344172	11434	Economy	4000.00
0005435302158	11434	Economy	4000.00
0005434344158	11434	Economy	4000.00
0005434344147	11434	Economy	4000.00
0005434344138	11434	Economy	4000.00
0005434344170	11434	Economy	4000.00
0005434344143	11434	Economy	4000.00
0005434343950	29799	Economy	4300.00
0005435305015	29799	Economy	4300.00
0005434343763	29799	Economy	4300.00
0005434343732	29799	Economy	4300.00
0005434343880	29799	Economy	4000.00
0005434142566	29799	Economy	4000.00
0005434343834	29799	Economy	4000.00
0005434343901	29799	Economy	4000.00
0005434343899	29799	Economy	4000.00
0005435304156	29799	Economy	4000.00
0005434343946	29799	Economy	4000.00
0005435304155	29799	Economy	4000.00
0005434343827	29799	Economy	4000.00
0005434343903	29799	Economy	4000.00
0005435305014	29799	Economy	4000.00
0005434142568	29799	Economy	4000.00
0005434343826	29799	Economy	4000.00
0005434343833	29799	Economy	4000.00
0005434343940	29799	Economy	4000.00
0005434343806	29799	Economy	4000.00
0005434343841	29799	Economy	4000.00
0005434343779	29799	Economy	4000.00
0005434343762	29799	Economy	4000.00
0005434343774	29799	Economy	4000.00
0005434343790	29799	Economy	4000.00
0005435305012	29799	Economy	4000.00
0005434343777	29799	Economy	4000.00
0005434343900	29799	Economy	4000.00
0005435304157	29799	Economy	4000.00
0005434343908	29799	Economy	4000.00
0005434343828	29799	Economy	4000.00
0005434343832	29799	Economy	4000.00
0005434343805	29799	Economy	4000.00
0005434343853	29799	Economy	4000.00
0005434343879	29799	Economy	4000.00
0005434343924	29799	Economy	4000.00
0005434343854	29799	Economy	4000.00
0005434343847	29799	Economy	4000.00
0005434344009	29799	Economy	4000.00
0005434343804	29799	Economy	4000.00
0005434343764	29799	Economy	4000.00
0005434343823	29799	Economy	4000.00
0005434343938	29799	Economy	4000.00
0005434343907	29799	Economy	4000.00
0005435305013	29799	Economy	4000.00
0005435824595	1272	Business	199800.00
0005435824606	1272	Business	199800.00
0005433415496	1272	Business	199800.00
0005435824608	1272	Business	199800.00
0005435824593	1272	Business	199800.00
0005435824594	1272	Business	199800.00
0005435824619	1272	Business	199800.00
0005435824600	1272	Business	199800.00
0005433415480	1272	Business	199800.00
0005433415554	1272	Economy	66600.00
0005433415537	1272	Economy	66600.00
0005433415540	1272	Economy	66600.00
0005433415553	1272	Economy	66600.00
0005435824602	1272	Economy	66600.00
0005432284555	1272	Economy	73200.00
0005435824592	1272	Economy	73200.00
0005433415543	1272	Economy	73200.00
0005435824615	1272	Economy	66600.00
0005433415544	1272	Economy	66600.00
0005432284554	1272	Economy	66600.00
0005435824604	1272	Economy	66600.00
0005435824591	1272	Economy	66600.00
0005435824596	1272	Economy	66600.00
0005432284556	1272	Economy	66600.00
0005433415445	1272	Economy	66600.00
0005433415531	1272	Economy	66600.00
0005435824598	1272	Economy	66600.00
0005435824611	1272	Economy	66600.00
0005435824603	1272	Economy	66600.00
0005435824618	1272	Economy	66600.00
0005435824605	1272	Economy	66600.00
0005433415547	1272	Economy	66600.00
0005435824612	1272	Economy	66600.00
0005433415505	1272	Economy	66600.00
0005435824613	1272	Economy	66600.00
0005433415538	1272	Economy	66600.00
0005435824597	1272	Economy	66600.00
0005435824617	1272	Economy	66600.00
0005435824609	1272	Economy	66600.00
0005433415532	1272	Economy	66600.00
0005435824607	1272	Economy	66600.00
0005435824610	1272	Economy	66600.00
0005433415517	1272	Economy	66600.00
0005433415548	1272	Economy	66600.00
0005435824599	1272	Economy	66600.00
0005435824614	1272	Economy	66600.00
0005435824601	1272	Economy	66600.00
0005435824616	1272	Economy	66600.00
0005433415479	1272	Economy	66600.00
0005433415506	1272	Economy	66600.00
0005435824337	17994	Business	199800.00
0005433415639	17994	Business	199800.00
0005433415648	17994	Business	199800.00
0005433415655	17994	Business	199800.00
0005433415647	17994	Economy	66600.00
0005433415651	17994	Economy	66600.00
0005435824354	17994	Economy	73200.00
0005433415641	17994	Economy	73200.00
0005433415654	17994	Economy	66600.00
0005435824342	17994	Economy	66600.00
0005435824283	17994	Economy	66600.00
0005435824420	17994	Economy	66600.00
0005433415640	17994	Economy	66600.00
0005435824369	17994	Economy	66600.00
0005433415646	17994	Economy	66600.00
0005433415652	17994	Economy	66600.00
0005435824471	17994	Economy	66600.00
0005433415645	17994	Economy	66600.00
0005433415653	17994	Economy	66600.00
0005433415649	17994	Economy	66600.00
0005435824355	17994	Economy	66600.00
0005433415650	17994	Economy	66600.00
0005433415643	17994	Economy	66600.00
0005433415644	17994	Economy	66600.00
0005433415642	17994	Economy	66600.00
0005435824293	17994	Economy	66600.00
0005435824470	17994	Economy	66600.00
0005435824368	17994	Economy	66600.00
0005435476699	5664	Business	27800.00
0005435476664	5664	Business	27800.00
0005435242536	5664	Business	27800.00
0005435242621	5664	Business	27800.00
0005435242497	5664	Business	27800.00
0005432783729	5664	Business	27800.00
0005432783769	5664	Business	27800.00
0005432783761	5664	Business	27800.00
0005432783754	5664	Business	27800.00
0005435242748	5664	Business	27800.00
0005435476706	5664	Business	27800.00
0005432783728	5664	Economy	9300.00
0005435242488	5664	Economy	9300.00
0005432783760	5664	Economy	9300.00
0005435242682	5664	Economy	9300.00
0005432783770	5664	Economy	9300.00
0005432783750	5664	Economy	9300.00
0005432783764	5664	Economy	9300.00
0005432783739	5664	Economy	9300.00
0005432783732	5664	Economy	9300.00
0005432783775	5664	Economy	9300.00
0005432783766	5664	Economy	10200.00
0005435242558	5664	Economy	10200.00
0005432143985	5664	Economy	10200.00
0005432783724	5664	Economy	10200.00
0005432783756	5664	Economy	10200.00
0005432783722	5664	Economy	9300.00
0005432783755	5664	Economy	9300.00
0005432783731	5664	Economy	9300.00
0005432783723	5664	Economy	9300.00
0005432783762	5664	Economy	9300.00
0005435242589	5664	Economy	9300.00
0005435242683	5664	Economy	9300.00
0005432783763	5664	Economy	9300.00
0005432783725	5664	Economy	9300.00
0005432783746	5664	Economy	9300.00
0005432783751	5664	Economy	9300.00
0005432783758	5664	Economy	9300.00
0005435242719	5664	Economy	9300.00
0005432143984	5664	Economy	9300.00
0005432783736	5664	Economy	9300.00
0005432783733	5664	Economy	9300.00
0005432783759	5664	Economy	9300.00
0005435242674	5664	Economy	9300.00
0005435476686	5664	Economy	9300.00
0005435476697	5664	Economy	9300.00
0005432783734	5664	Economy	9300.00
0005432783765	5664	Economy	9300.00
0005432783735	5664	Economy	9300.00
0005432783745	5664	Economy	9300.00
0005432783747	5664	Economy	9300.00
0005432783771	5664	Economy	9300.00
0005435242622	5664	Economy	9300.00
0005435476684	5664	Economy	9300.00
0005435242615	5664	Economy	9300.00
0005435242749	5664	Economy	9300.00
0005432783721	5664	Economy	9300.00
0005435242669	5664	Economy	9300.00
0005435242614	5664	Economy	9300.00
0005432783757	5664	Economy	9300.00
0005432783752	5664	Economy	9300.00
0005432783742	5664	Economy	9300.00
0005435242593	5664	Economy	9300.00
0005432783773	5664	Economy	9300.00
0005435242627	5664	Economy	9300.00
0005432783767	5664	Economy	9300.00
0005435242662	5664	Economy	9300.00
0005435476708	5664	Economy	9300.00
0005435242660	5664	Economy	9300.00
0005435242659	5664	Economy	9300.00
0005435476690	5664	Economy	9300.00
0005435242597	5664	Economy	9300.00
0005435242629	5664	Economy	9300.00
0005432783740	5664	Economy	9300.00
0005432783774	5664	Economy	9300.00
0005435242586	5664	Economy	9300.00
0005435242585	5664	Economy	9300.00
0005432783768	5664	Economy	9300.00
0005432783727	5664	Economy	9300.00
0005432783720	5664	Economy	9300.00
0005432783749	5664	Economy	9300.00
0005432783737	5664	Economy	9300.00
0005432783772	5664	Economy	9300.00
0005432783753	5664	Economy	9300.00
0005432783744	5664	Economy	9300.00
0005432783738	5664	Economy	9300.00
0005432783730	5664	Economy	9300.00
0005432783748	5664	Economy	9300.00
0005435242592	5664	Economy	9300.00
0005432783741	5664	Economy	9300.00
0005432783726	5664	Economy	9300.00
0005435476685	5664	Economy	9300.00
0005435476663	5664	Economy	9300.00
0005432783743	5664	Economy	9300.00
0005432783421	15387	Business	27800.00
0005435242822	15387	Business	27800.00
0005435242808	15387	Business	27800.00
0005435242823	15387	Business	27800.00
0005432783252	15387	Business	27800.00
0005432783368	15387	Business	27800.00
0005435476748	15387	Business	27800.00
0005432783153	15387	Business	27800.00
0005435242824	15387	Business	27800.00
0005432783151	15387	Business	27800.00
0005432783249	15387	Business	27800.00
0005432783261	15387	Business	27800.00
0005432783248	15387	Economy	9300.00
0005435242818	15387	Economy	9300.00
0005435242800	15387	Economy	9300.00
0005432783259	15387	Economy	9300.00
0005432783293	15387	Economy	9300.00
0005432783118	15387	Economy	9300.00
0005435242807	15387	Economy	9300.00
0005432783117	15387	Economy	9300.00
0005435242802	15387	Economy	9300.00
0005432783309	15387	Economy	9300.00
0005432783032	15387	Economy	10200.00
0005432783189	15387	Economy	10200.00
0005432783395	15387	Economy	10200.00
0005432783132	15387	Economy	10200.00
0005435242809	15387	Economy	10200.00
0005432783071	15387	Economy	9300.00
0005432783300	15387	Economy	9300.00
0005432783170	15387	Economy	9300.00
0005432783301	15387	Economy	9300.00
0005432783432	15387	Economy	9300.00
0005432783033	15387	Economy	9300.00
0005432783251	15387	Economy	9300.00
0005435242815	15387	Economy	9300.00
0005435242817	15387	Economy	9300.00
0005435242797	15387	Economy	9300.00
0005432783257	15387	Economy	9300.00
0005435242803	15387	Economy	9300.00
0005432783240	15387	Economy	9300.00
0005432783316	15387	Economy	9300.00
0005435242810	15387	Economy	9300.00
0005435242801	15387	Economy	9300.00
0005432783406	15387	Economy	9300.00
0005432783291	15387	Economy	9300.00
0005432783394	15387	Economy	9300.00
0005432783188	15387	Economy	9300.00
0005435242798	15387	Economy	9300.00
0005432783367	15387	Economy	9300.00
0005432783396	15387	Economy	9300.00
0005432783353	15387	Economy	9300.00
0005432783200	15387	Economy	9300.00
0005432783220	15387	Economy	9300.00
0005432783138	15387	Economy	9300.00
0005432783425	15387	Economy	9300.00
0005432783292	15387	Economy	9300.00
0005432783194	15387	Economy	9300.00
0005432783434	15387	Economy	9300.00
0005432783387	15387	Economy	9300.00
0005432783369	15387	Economy	9300.00
0005435242819	15387	Economy	9300.00
0005432783262	15387	Economy	9300.00
0005435242820	15387	Economy	9300.00
0005432783253	15387	Economy	9300.00
0005435242816	15387	Economy	9300.00
0005432783162	15387	Economy	9300.00
0005432783297	15387	Economy	9300.00
0005435242814	15387	Economy	9300.00
0005435242805	15387	Economy	9300.00
0005435242821	15387	Economy	9300.00
0005432783121	15387	Economy	9300.00
0005435476747	15387	Economy	9300.00
0005435242813	15387	Economy	9300.00
0005432783169	15387	Economy	9300.00
0005432783282	15387	Economy	9300.00
0005435242811	15387	Economy	9300.00
0005432783133	15387	Economy	9300.00
0005432783229	15387	Economy	9300.00
0005432783308	15387	Economy	9300.00
0005432783350	15387	Economy	9300.00
0005432783152	15387	Economy	9300.00
0005435476746	15387	Economy	9300.00
0005432783241	15387	Economy	9300.00
0005432783131	15387	Economy	9300.00
0005435242804	15387	Economy	9300.00
0005432783283	15387	Economy	9300.00
0005432783263	15387	Economy	9300.00
0005432783185	15387	Economy	9300.00
0005432783302	15387	Economy	9300.00
0005435242806	15387	Economy	9300.00
0005435242799	15387	Economy	9300.00
0005432783260	15387	Economy	9300.00
0005432783239	15387	Economy	9300.00
0005432783453	15387	Economy	9300.00
0005432783307	15387	Economy	9300.00
0005432783405	15387	Economy	9300.00
0005435242812	15387	Economy	9300.00
0005432848307	4352	Economy	7000.00
0005432848299	4352	Economy	7000.00
0005435850874	4352	Economy	7000.00
0005434463926	4352	Economy	6300.00
0005432848304	4352	Economy	6300.00
0005432848293	4352	Economy	6300.00
0005432848298	4352	Economy	6300.00
0005434463928	4352	Economy	6300.00
0005432848296	4352	Economy	6300.00
0005435850843	4352	Economy	6300.00
0005432848303	4352	Economy	6300.00
0005432848295	4352	Economy	6300.00
0005432848306	4352	Economy	6300.00
0005432848301	4352	Economy	6300.00
0005434463927	4352	Economy	6300.00
0005435850844	4352	Economy	6300.00
0005434462787	4352	Economy	6300.00
0005432848297	4352	Economy	6300.00
0005432848300	4352	Economy	6300.00
0005434462789	4352	Economy	6300.00
0005434462788	4352	Economy	6300.00
0005432848302	4352	Economy	6300.00
0005432848305	4352	Economy	6300.00
0005432848294	4352	Economy	6300.00
0005432848154	28889	Economy	7000.00
0005435850904	28889	Economy	6300.00
0005434461623	28889	Economy	6300.00
0005432848152	28889	Economy	6300.00
0005434463909	28889	Economy	6300.00
0005434463910	28889	Economy	6300.00
0005432848179	28889	Economy	6300.00
0005432848145	28889	Economy	6300.00
0005435850903	28889	Economy	6300.00
0005435850905	28889	Economy	6300.00
0005432848153	28889	Economy	6300.00
0005435850900	28889	Economy	6300.00
0005434463899	28889	Economy	6300.00
0005435850906	28889	Economy	6300.00
0005432848151	28889	Economy	6300.00
0005434461622	28889	Economy	6300.00
0005435850901	28889	Economy	6300.00
0005435850902	28889	Economy	6300.00
0005432848144	28889	Economy	6300.00
0005435850899	28889	Economy	6300.00
0005432848175	28889	Economy	6300.00
0005434925783	6267	Business	11900.00
0005434443699	6267	Business	11900.00
0005433496942	6267	Business	11900.00
0005434443688	6267	Business	11900.00
0005434443690	6267	Business	11900.00
0005434443692	6267	Business	11900.00
0005433496943	6267	Business	11900.00
0005434925794	6267	Business	11900.00
0005434925776	6267	Business	11900.00
0005434443701	6267	Business	11900.00
0005432075226	6267	Economy	4000.00
0005433496953	6267	Economy	4000.00
0005433496954	6267	Economy	4000.00
0005434925786	6267	Economy	4000.00
0005433496947	6267	Economy	4000.00
0005433496957	6267	Economy	4000.00
0005433496951	6267	Economy	4000.00
0005433496930	6267	Economy	4000.00
0005434925795	6267	Economy	4400.00
0005434443700	6267	Economy	4400.00
0005434925790	6267	Economy	4400.00
0005434925793	6267	Economy	4400.00
0005434925792	6267	Economy	4000.00
0005434925780	6267	Economy	4000.00
0005434443698	6267	Economy	4000.00
0005433496941	6267	Economy	4000.00
0005433496961	6267	Economy	4000.00
0005433496935	6267	Economy	4000.00
0005433496958	6267	Economy	4000.00
0005434925782	6267	Economy	4000.00
0005433496944	6267	Economy	4000.00
0005434925798	6267	Economy	4000.00
0005434925799	6267	Economy	4000.00
0005434443702	6267	Economy	4000.00
0005434925797	6267	Economy	4000.00
0005433496949	6267	Economy	4000.00
0005434925778	6267	Economy	4000.00
0005433496955	6267	Economy	4000.00
0005433496938	6267	Economy	4000.00
0005434443695	6267	Economy	4000.00
0005433496931	6267	Economy	4000.00
0005433496948	6267	Economy	4000.00
0005433496933	6267	Economy	4000.00
0005432075227	6267	Economy	4000.00
0005434443703	6267	Economy	4000.00
0005434443696	6267	Economy	4000.00
0005434925796	6267	Economy	4000.00
0005433496960	6267	Economy	4000.00
0005433496945	6267	Economy	4000.00
0005434443691	6267	Economy	4000.00
0005434925785	6267	Economy	4000.00
0005434925789	6267	Economy	4000.00
0005432075228	6267	Economy	4000.00
0005433496939	6267	Economy	4000.00
0005434925779	6267	Economy	4000.00
0005434443704	6267	Economy	4000.00
0005434925788	6267	Economy	4000.00
0005433496959	6267	Economy	4000.00
0005434925791	6267	Economy	4000.00
0005434925777	6267	Economy	4000.00
0005434443694	6267	Economy	4000.00
0005434925781	6267	Economy	4000.00
0005434925787	6267	Economy	4000.00
0005433496956	6267	Economy	4000.00
0005433496940	6267	Economy	4000.00
0005434443697	6267	Economy	4000.00
0005434443693	6267	Economy	4000.00
0005433496952	6267	Economy	4000.00
0005434443689	6267	Economy	4000.00
0005433496937	6267	Economy	4000.00
0005433496934	6267	Economy	4000.00
0005434925784	6267	Economy	4000.00
0005433496932	6267	Economy	4000.00
0005433496950	6267	Economy	4000.00
0005433496946	6267	Economy	4000.00
0005433496936	6267	Economy	4000.00
0005433496622	20323	Business	11900.00
0005433496632	20323	Business	11900.00
0005433496853	20323	Business	11900.00
0005434925395	20323	Business	11900.00
0005433496704	20323	Business	11900.00
0005433496697	20323	Business	11900.00
0005434443604	20323	Business	11900.00
0005433496706	20323	Business	11900.00
0005434925376	20323	Business	11900.00
0005433496741	20323	Business	11900.00
0005433496668	20323	Economy	4000.00
0005434443603	20323	Economy	4000.00
0005433496563	20323	Economy	4000.00
0005434925450	20323	Economy	4000.00
0005434443527	20323	Economy	4000.00
0005433496654	20323	Economy	4000.00
0005434925290	20323	Economy	4000.00
0005434925295	20323	Economy	4000.00
0005434925434	20323	Economy	4400.00
0005434925398	20323	Economy	4400.00
0005434443499	20323	Economy	4400.00
0005434443544	20323	Economy	4000.00
0005434925351	20323	Economy	4000.00
0005433496561	20323	Economy	4000.00
0005433496705	20323	Economy	4000.00
0005433496811	20323	Economy	4000.00
0005433496734	20323	Economy	4000.00
0005434925302	20323	Economy	4000.00
0005434443541	20323	Economy	4000.00
0005434925321	20323	Economy	4000.00
0005433496624	20323	Economy	4000.00
0005434925375	20323	Economy	4000.00
0005434443536	20323	Economy	4000.00
0005434925343	20323	Economy	4000.00
0005433496715	20323	Economy	4000.00
0005434925392	20323	Economy	4000.00
0005433496647	20323	Economy	4000.00
0005434443528	20323	Economy	4000.00
0005433496716	20323	Economy	4000.00
0005434925363	20323	Economy	4000.00
0005434925484	20323	Economy	4000.00
0005434925442	20323	Economy	4000.00
0005434925364	20323	Economy	4000.00
0005433496687	20323	Economy	4000.00
0005433496703	20323	Economy	4000.00
0005434925303	20323	Economy	4000.00
0005434925414	20323	Economy	4000.00
0005434925404	20323	Economy	4000.00
0005433496713	20323	Economy	4000.00
0005433496836	20323	Economy	4000.00
0005434925331	20323	Economy	4000.00
0005434925468	20323	Economy	4000.00
0005433496623	20323	Economy	4000.00
0005434925330	20323	Economy	4000.00
0005433496655	20323	Economy	4000.00
0005434443634	20323	Economy	4000.00
0005434443578	20323	Economy	4000.00
0005434443600	20323	Economy	4000.00
0005433496722	20323	Economy	4000.00
0005434925399	20323	Economy	4000.00
0005434443509	20323	Economy	4000.00
0005434925460	20323	Economy	4000.00
0005433496621	20323	Economy	4000.00
0005434443559	20323	Economy	4000.00
0005433496699	20323	Economy	4000.00
0005433496562	20323	Economy	4000.00
0005433496631	20323	Economy	4000.00
0005434925396	20323	Economy	4000.00
0005433496723	20323	Economy	4000.00
0005433496688	20323	Economy	4000.00
0005433496812	20323	Economy	4000.00
0005434443508	20323	Economy	4000.00
0005433496790	20323	Economy	4000.00
0005434443560	20323	Economy	4000.00
0005432783173	12215	Business	41200.00
0005432783288	12215	Business	41200.00
0005435242839	12215	Business	41200.00
0005435242842	12215	Business	41200.00
0005432783348	12215	Business	41200.00
0005435242850	12215	Business	41200.00
0005432783469	12215	Business	41200.00
0005432783384	12215	Economy	13700.00
0005432783326	12215	Economy	13700.00
0005432783423	12215	Economy	13700.00
0005435242832	12215	Economy	13700.00
0005432783500	12215	Economy	13700.00
0005432783166	12215	Economy	13700.00
0005432782989	12215	Economy	13700.00
0005432783298	12215	Economy	13700.00
0005432783299	12215	Economy	13700.00
0005435242843	12215	Economy	15100.00
0005435242826	12215	Economy	15100.00
0005432783566	12215	Economy	15100.00
0005432783386	12215	Economy	15100.00
0005432783213	12215	Economy	13700.00
0005435242848	12215	Economy	13700.00
0005432783441	12215	Economy	13700.00
0005435242838	12215	Economy	13700.00
0005435242836	12215	Economy	13700.00
0005432783427	12215	Economy	13700.00
0005432783440	12215	Economy	13700.00
0005432783156	12215	Economy	13700.00
0005432783565	12215	Economy	13700.00
0005432783313	12215	Economy	13700.00
0005432783385	12215	Economy	13700.00
0005432783344	12215	Economy	13700.00
0005435242827	12215	Economy	13700.00
0005435242840	12215	Economy	13700.00
0005432783017	12215	Economy	13700.00
0005435242845	12215	Economy	13700.00
0005432783424	12215	Economy	13700.00
0005435242829	12215	Economy	13700.00
0005435242847	12215	Economy	13700.00
0005435242831	12215	Economy	13700.00
0005435242849	12215	Economy	13700.00
0005432783254	12215	Economy	13700.00
0005435242833	12215	Economy	13700.00
0005435242825	12215	Economy	13700.00
0005432783175	12215	Economy	13700.00
0005432783506	12215	Economy	13700.00
0005435242830	12215	Economy	13700.00
0005435242835	12215	Economy	13700.00
0005435242851	12215	Economy	13700.00
0005432783567	12215	Economy	13700.00
0005432783060	12215	Economy	13700.00
0005432783176	12215	Economy	13700.00
0005435242834	12215	Economy	13700.00
0005432783499	12215	Economy	13700.00
0005432783212	12215	Economy	13700.00
0005432783202	12215	Economy	13700.00
0005432783167	12215	Economy	13700.00
0005432783456	12215	Economy	13700.00
0005435242844	12215	Economy	13700.00
0005432783345	12215	Economy	13700.00
0005435242846	12215	Economy	13700.00
0005435242828	12215	Economy	13700.00
0005432783470	12215	Economy	13700.00
0005435242841	12215	Economy	13700.00
0005432783225	12215	Economy	13700.00
0005432783479	12215	Economy	13700.00
0005432783400	12215	Economy	13700.00
0005432783168	12215	Economy	13700.00
0005432783426	12215	Economy	13700.00
0005435242837	12215	Economy	13700.00
0005432783674	15421	Business	41200.00
0005435242466	15421	Business	41200.00
0005432783690	15421	Business	41200.00
0005432783697	15421	Business	41200.00
0005432783717	15421	Business	41200.00
0005432783696	15421	Business	41200.00
0005432783666	15421	Business	41200.00
0005432783670	15421	Business	41200.00
0005432783708	15421	Business	41200.00
0005432783711	15421	Business	41200.00
0005432783671	15421	Economy	13700.00
0005435242394	15421	Economy	13700.00
0005432783679	15421	Economy	13700.00
0005435242685	15421	Economy	13700.00
0005432783677	15421	Economy	13700.00
0005432783707	15421	Economy	13700.00
0005432783692	15421	Economy	13700.00
0005432783688	15421	Economy	13700.00
0005435242542	15421	Economy	13700.00
0005432783703	15421	Economy	15100.00
0005435242547	15421	Economy	15100.00
0005435242636	15421	Economy	15100.00
0005435242523	15421	Economy	15100.00
0005432783678	15421	Economy	13700.00
0005435242567	15421	Economy	13700.00
0005432783682	15421	Economy	13700.00
0005432783695	15421	Economy	13700.00
0005435242543	15421	Economy	13700.00
0005435242393	15421	Economy	13700.00
0005432783667	15421	Economy	13700.00
0005432783683	15421	Economy	13700.00
0005432783684	15421	Economy	13700.00
0005432783706	15421	Economy	13700.00
0005432783705	15421	Economy	13700.00
0005435242604	15421	Economy	13700.00
0005432783669	15421	Economy	13700.00
0005432783681	15421	Economy	13700.00
0005435242467	15421	Economy	13700.00
0005432783718	15421	Economy	13700.00
0005432783716	15421	Economy	13700.00
0005435242548	15421	Economy	13700.00
0005432783691	15421	Economy	13700.00
0005435242522	15421	Economy	13700.00
0005432783675	15421	Economy	13700.00
0005435242433	15421	Economy	13700.00
0005432783665	15421	Economy	13700.00
0005432783676	15421	Economy	13700.00
0005432783713	15421	Economy	13700.00
0005432783686	15421	Economy	13700.00
0005432783712	15421	Economy	13700.00
0005435242684	15421	Economy	13700.00
0005435242520	15421	Economy	13700.00
0005435242483	15421	Economy	13700.00
0005435242510	15421	Economy	13700.00
0005432783699	15421	Economy	13700.00
0005435242524	15421	Economy	13700.00
0005435242549	15421	Economy	13700.00
0005432783700	15421	Economy	13700.00
0005435242554	15421	Economy	13700.00
0005432783701	15421	Economy	13700.00
0005435242605	15421	Economy	13700.00
0005432783719	15421	Economy	13700.00
0005432783698	15421	Economy	13700.00
0005435242478	15421	Economy	13700.00
0005435242454	15421	Economy	13700.00
0005432783685	15421	Economy	13700.00
0005435242541	15421	Economy	13700.00
0005432783673	15421	Economy	13700.00
0005432783704	15421	Economy	13700.00
0005432783715	15421	Economy	13700.00
0005435242451	15421	Economy	13700.00
0005432783710	15421	Economy	13700.00
0005432783689	15421	Economy	13700.00
0005432783668	15421	Economy	13700.00
0005435242511	15421	Economy	13700.00
0005432783693	15421	Economy	13700.00
0005432783680	15421	Economy	13700.00
0005432783694	15421	Economy	13700.00
0005435242602	15421	Economy	13700.00
0005432783687	15421	Economy	13700.00
0005435242551	15421	Economy	13700.00
0005432783714	15421	Economy	13700.00
0005432783672	15421	Economy	13700.00
0005432783702	15421	Economy	13700.00
0005432783709	15421	Economy	13700.00
0005434876666	10087	Business	49700.00
0005434877125	10087	Business	49700.00
0005434877687	10087	Business	49700.00
0005434877158	10087	Business	49700.00
0005434877538	10087	Business	49700.00
0005434877408	10087	Business	49700.00
0005435913931	10087	Business	49700.00
0005434877324	10087	Business	49700.00
0005434877300	10087	Business	49700.00
0005434877562	10087	Business	49700.00
0005434877432	10087	Business	49700.00
0005434877304	10087	Business	49700.00
0005434877042	10087	Business	49700.00
0005434877834	10087	Business	49700.00
0005434877279	10087	Business	49700.00
0005434877124	10087	Business	49700.00
0005434877218	10087	Business	49700.00
0005434877428	10087	Business	49700.00
0005434877808	10087	Economy	16600.00
0005434877310	10087	Economy	16600.00
0005434877224	10087	Economy	16600.00
0005434877382	10087	Economy	16600.00
0005434877588	10087	Economy	16600.00
0005434877187	10087	Economy	16600.00
0005434876960	10087	Economy	16600.00
0005434877701	10087	Economy	16600.00
0005434877657	10087	Economy	16600.00
0005434877638	10087	Economy	16600.00
0005434876976	10087	Economy	16600.00
0005434910107	10087	Economy	16600.00
0005434877509	10087	Economy	16600.00
0005434877011	10087	Economy	18200.00
0005434877516	10087	Economy	18200.00
0005435913930	10087	Economy	18200.00
0005435913932	10087	Economy	18200.00
0005434877639	10087	Economy	16600.00
0005434877640	10087	Economy	16600.00
0005434877457	10087	Economy	16600.00
0005434877411	10087	Economy	16600.00
0005434877431	10087	Economy	16600.00
0005434877235	10087	Economy	16600.00
0005434910109	10087	Economy	16600.00
0005434877261	10087	Economy	16600.00
0005434877488	10087	Economy	16600.00
0005434877833	10087	Economy	16600.00
0005434910110	10087	Economy	16600.00
0005434877303	10087	Economy	16600.00
0005434877325	10087	Economy	16600.00
0005434877217	10087	Economy	16600.00
0005434877093	10087	Economy	16600.00
0005434877179	10087	Economy	16600.00
0005434877013	10087	Economy	16600.00
0005434877494	10087	Economy	16600.00
0005434877298	10087	Economy	16600.00
0005434877126	10087	Economy	16600.00
0005434877281	10087	Economy	16600.00
0005434877388	10087	Economy	16600.00
0005434877456	10087	Economy	16600.00
0005434877675	10087	Economy	16600.00
0005434877351	10087	Economy	16600.00
0005434877459	10087	Economy	16600.00
0005434877247	10087	Economy	16600.00
0005434877809	10087	Economy	16600.00
0005434877376	10087	Economy	16600.00
0005434877519	10087	Economy	16600.00
0005434877473	10087	Economy	16600.00
0005434877352	10087	Economy	16600.00
0005434877517	10087	Economy	16600.00
0005434877472	10087	Economy	16600.00
0005434877702	10087	Economy	16600.00
0005434877606	10087	Economy	16600.00
0005434877539	10087	Economy	16600.00
0005434877389	10087	Economy	16600.00
0005434877309	10087	Economy	16600.00
0005434877508	10087	Economy	16600.00
0005434877832	10087	Economy	16600.00
0005434910108	10087	Economy	16600.00
0005434877510	10087	Economy	16600.00
0005434877314	10087	Economy	16600.00
0005434877418	10087	Economy	16600.00
0005434877566	10087	Economy	16600.00
0005434877710	10087	Economy	16600.00
0005434877223	10087	Economy	16600.00
0005434877331	10087	Economy	16600.00
0005434877246	10087	Economy	16600.00
0005434877479	10087	Economy	16600.00
0005434877674	10087	Economy	16600.00
0005434877724	10087	Economy	16600.00
0005434877333	10087	Economy	16600.00
0005434877518	10087	Economy	16600.00
0005434877442	10087	Economy	16600.00
0005434877219	10087	Economy	16600.00
0005434877082	10087	Economy	16600.00
0005434877186	10087	Economy	16600.00
0005434877490	10087	Economy	16600.00
0005434877216	10087	Economy	16600.00
0005434877012	10087	Economy	16600.00
0005434877030	10087	Economy	16600.00
0005434877403	10087	Economy	16600.00
0005434877375	10087	Economy	16600.00
0005434877688	10087	Economy	16600.00
0005434877222	10087	Economy	16600.00
0005434877616	10087	Economy	16600.00
0005434877280	10087	Economy	16600.00
0005434877092	10087	Economy	16600.00
0005434877398	10087	Economy	16600.00
0005434877041	10087	Economy	16600.00
0005434878131	14625	Business	49700.00
0005434878164	14625	Business	49700.00
0005434878148	14625	Business	49700.00
0005434878195	14625	Business	49700.00
0005434878110	14625	Business	49700.00
0005434878175	14625	Business	49700.00
0005434878190	14625	Business	49700.00
0005434878126	14625	Business	49700.00
0005434878170	14625	Business	49700.00
0005434878154	14625	Business	49700.00
0005434878145	14625	Business	49700.00
0005434878124	14625	Business	49700.00
0005434878200	14625	Business	49700.00
0005434878186	14625	Business	49700.00
0005434910080	14625	Business	49700.00
0005434878181	14625	Business	49700.00
0005434878128	14625	Business	49700.00
0005434878156	14625	Economy	16600.00
0005435913875	14625	Business	49700.00
0005434878144	14625	Economy	16600.00
0005434878166	14625	Economy	16600.00
0005434878178	14625	Economy	16600.00
0005434878113	14625	Economy	16600.00
0005434878118	14625	Economy	16600.00
0005434878159	14625	Economy	16600.00
0005434878116	14625	Economy	16600.00
0005434878169	14625	Economy	16600.00
0005434878123	14625	Economy	16600.00
0005434878134	14625	Economy	16600.00
0005434878125	14625	Economy	16600.00
0005434878160	14625	Economy	16600.00
0005434878133	14625	Economy	18200.00
0005434878114	14625	Economy	18200.00
0005434878108	14625	Economy	18200.00
0005434878149	14625	Economy	16600.00
0005434878172	14625	Economy	16600.00
0005434878137	14625	Economy	16600.00
0005434878106	14625	Economy	16600.00
0005434878191	14625	Economy	16600.00
0005434878121	14625	Economy	16600.00
0005434910084	14625	Economy	16600.00
0005434878119	14625	Economy	16600.00
0005434878130	14625	Economy	16600.00
0005434878199	14625	Economy	16600.00
0005434878151	14625	Economy	16600.00
0005434878179	14625	Economy	16600.00
0005435913870	14625	Economy	16600.00
0005434878147	14625	Economy	16600.00
0005434878171	14625	Economy	16600.00
0005434878168	14625	Economy	16600.00
0005434878182	14625	Economy	16600.00
0005434878173	14625	Economy	16600.00
0005435913889	14625	Economy	16600.00
0005434878180	14625	Economy	16600.00
0005435913877	14625	Economy	16600.00
0005435913878	14625	Economy	16600.00
0005434878196	14625	Economy	16600.00
0005434878142	14625	Economy	16600.00
0005434878129	14625	Economy	16600.00
0005435913890	14625	Economy	16600.00
0005434878155	14625	Economy	16600.00
0005434878115	14625	Economy	16600.00
0005434878109	14625	Economy	16600.00
0005434878111	14625	Economy	16600.00
0005434878162	14625	Economy	16600.00
0005434878174	14625	Economy	16600.00
0005434878127	14625	Economy	16600.00
0005434878152	14625	Economy	16600.00
0005434878187	14625	Economy	16600.00
0005434878136	14625	Economy	16600.00
0005434878197	14625	Economy	16600.00
0005434878146	14625	Economy	16600.00
0005434878135	14625	Economy	16600.00
0005434878185	14625	Economy	16600.00
0005434878177	14625	Economy	16600.00
0005434878153	14625	Economy	16600.00
0005434878122	14625	Economy	16600.00
0005434878112	14625	Economy	16600.00
0005434878189	14625	Economy	16600.00
0005434878198	14625	Economy	16600.00
0005434878161	14625	Economy	16600.00
0005434878158	14625	Economy	16600.00
0005434878163	14625	Economy	16600.00
0005434878140	14625	Economy	16600.00
0005434878188	14625	Economy	16600.00
0005434878139	14625	Economy	16600.00
0005434910085	14625	Economy	16600.00
0005434878132	14625	Economy	16600.00
0005434878150	14625	Economy	16600.00
0005435913871	14625	Economy	16600.00
0005434878138	14625	Economy	16600.00
0005434878120	14625	Economy	16600.00
0005434878165	14625	Economy	16600.00
0005434878157	14625	Economy	16600.00
0005434910081	14625	Economy	16600.00
0005434878183	14625	Economy	16600.00
0005434878184	14625	Economy	16600.00
0005434878141	14625	Economy	16600.00
0005434910079	14625	Economy	16600.00
0005434878167	14625	Economy	16600.00
0005434878107	14625	Economy	16600.00
0005434878192	14625	Economy	16600.00
0005434878176	14625	Economy	16600.00
0005434878143	14625	Economy	16600.00
0005434878117	14625	Economy	16600.00
0005434878201	14625	Economy	16600.00
0005434878194	14625	Economy	16600.00
0005434878193	14625	Economy	16600.00
0005435660127	9239	Economy	22400.00
0005434251878	9239	Economy	22400.00
0005434251821	9239	Economy	20300.00
0005434251880	9239	Economy	20300.00
0005434251819	9239	Economy	20300.00
0005434251862	9239	Economy	20300.00
0005435660130	9239	Economy	20300.00
0005435660122	9239	Economy	20300.00
0005435660123	9239	Economy	20300.00
0005435660121	9239	Economy	20300.00
0005434251879	9239	Economy	20300.00
0005435660131	9239	Economy	20300.00
0005434251820	9239	Economy	20300.00
0005434251826	9239	Economy	20300.00
0005435660128	9239	Economy	20300.00
0005435660125	9239	Economy	20300.00
0005435660126	9239	Economy	20300.00
0005435660124	9239	Economy	20300.00
0005434251911	9239	Economy	20300.00
0005435660129	9239	Economy	20300.00
0005435660132	9239	Economy	20300.00
0005435660049	24642	Economy	22400.00
0005434251960	24642	Economy	20300.00
0005434251954	24642	Economy	20300.00
0005435660027	24642	Economy	20300.00
0005434251955	24642	Economy	20300.00
0005435659987	24642	Economy	20300.00
0005435660032	24642	Economy	20300.00
0005434251956	24642	Economy	20300.00
0005435660026	24642	Economy	20300.00
0005435660043	24642	Economy	20300.00
0005434251953	24642	Economy	20300.00
0005434251952	24642	Economy	20300.00
0005435660002	24642	Economy	20300.00
0005435659986	24642	Economy	20300.00
0005434251959	24642	Economy	20300.00
0005434251958	24642	Economy	20300.00
0005434251957	24642	Economy	20300.00
0005435660025	24642	Economy	20300.00
0005435660028	24642	Economy	20300.00
0005435660033	24642	Economy	20300.00
0005435660062	24642	Economy	20300.00
0005432966745	2792	Business	33000.00
0005433680510	2792	Business	33000.00
0005432966792	2792	Business	33000.00
0005433680524	2792	Business	33000.00
0005433680532	2792	Business	33000.00
0005432966801	2792	Business	33000.00
0005433680501	2792	Business	33000.00
0005433680529	2792	Business	33000.00
0005433680495	2792	Business	33000.00
0005433680507	2792	Business	33000.00
0005432966686	2792	Economy	11000.00
0005433680503	2792	Economy	11000.00
0005433680536	2792	Economy	11000.00
0005432966817	2792	Economy	11000.00
0005433680539	2792	Economy	11000.00
0005433680500	2792	Economy	11000.00
0005433680508	2792	Economy	12100.00
0005432222776	2792	Economy	12100.00
0005432966629	2792	Economy	12100.00
0005433680502	2792	Economy	12100.00
0005433680504	2792	Economy	12100.00
0005433680535	2792	Economy	11000.00
0005433680512	2792	Economy	11000.00
0005433680531	2792	Economy	11000.00
0005433680521	2792	Economy	11000.00
0005432966653	2792	Economy	11000.00
0005433680530	2792	Economy	11000.00
0005433680537	2792	Economy	11000.00
0005433684417	2792	Economy	11000.00
0005433680523	2792	Economy	11000.00
0005432222778	2792	Economy	11000.00
0005433680525	2792	Economy	11000.00
0005433680494	2792	Economy	11000.00
0005433680514	2792	Economy	11000.00
0005433680505	2792	Economy	11000.00
0005433680533	2792	Economy	11000.00
0005432966740	2792	Economy	11000.00
0005433684416	2792	Economy	11000.00
0005433680492	2792	Economy	11000.00
0005433680534	2792	Economy	11000.00
0005433680511	2792	Economy	11000.00
0005432966706	2792	Economy	11000.00
0005432966648	2792	Economy	11000.00
0005433680526	2792	Economy	11000.00
0005432966665	2792	Economy	11000.00
0005433680517	2792	Economy	11000.00
0005433680538	2792	Economy	11000.00
0005432966705	2792	Economy	11000.00
0005433680527	2792	Economy	11000.00
0005433680520	2792	Economy	11000.00
0005433680522	2792	Economy	11000.00
0005433680516	2792	Economy	11000.00
0005433680518	2792	Economy	11000.00
0005433680498	2792	Economy	11000.00
0005432966685	2792	Economy	11000.00
0005432222777	2792	Economy	11000.00
0005433680493	2792	Economy	11000.00
0005432966628	2792	Economy	11000.00
0005433680499	2792	Economy	11000.00
0005432966802	2792	Economy	11000.00
0005432966712	2792	Economy	11000.00
0005433680509	2792	Economy	11000.00
0005433680513	2792	Economy	11000.00
0005433680515	2792	Economy	11000.00
0005433680528	2792	Economy	11000.00
0005432966619	2792	Economy	11000.00
0005432222775	2792	Economy	11000.00
0005433680506	2792	Economy	11000.00
0005433680519	2792	Economy	11000.00
0005432966647	2792	Economy	11000.00
0005432966704	2792	Economy	11000.00
0005433680496	2792	Economy	11000.00
0005432966716	2792	Economy	11000.00
0005433684418	2792	Economy	11000.00
0005433680497	2792	Economy	11000.00
0005432005209	29164	Business	33000.00
0005433680120	29164	Business	33000.00
0005432966906	29164	Business	33000.00
0005432966910	29164	Business	33000.00
0005433680179	29164	Business	33000.00
0005433684400	29164	Business	33000.00
0005432966918	29164	Business	33000.00
0005432966901	29164	Business	33000.00
0005432966897	29164	Business	33000.00
0005432966915	29164	Economy	11000.00
0005432966904	29164	Economy	11000.00
0005433680100	29164	Economy	11000.00
0005432966919	29164	Economy	11000.00
0005432005211	29164	Economy	11000.00
0005433680055	29164	Economy	11000.00
0005432966911	29164	Economy	11000.00
0005433680180	29164	Economy	11000.00
0005433680288	29164	Economy	12100.00
0005433680178	29164	Economy	12100.00
0005433680415	29164	Economy	12100.00
0005433680076	29164	Economy	12100.00
0005433680089	29164	Economy	11000.00
0005433680221	29164	Economy	11000.00
0005433680312	29164	Economy	11000.00
0005433680388	29164	Economy	11000.00
0005433679882	29164	Economy	11000.00
0005433680172	29164	Economy	11000.00
0005433679766	29164	Economy	11000.00
0005432966917	29164	Economy	11000.00
0005432966902	29164	Economy	11000.00
0005433680142	29164	Economy	11000.00
0005433684406	29164	Economy	11000.00
0005432966920	29164	Economy	11000.00
0005433680175	29164	Economy	11000.00
0005433680202	29164	Economy	11000.00
0005433680059	29164	Economy	11000.00
0005432966922	29164	Economy	11000.00
0005432966899	29164	Economy	11000.00
0005433679928	29164	Economy	11000.00
0005432966905	29164	Economy	11000.00
0005433680262	29164	Economy	11000.00
0005433680174	29164	Economy	11000.00
0005433690898	29164	Economy	11000.00
0005432966903	29164	Economy	11000.00
0005433680224	29164	Economy	11000.00
0005433680239	29164	Economy	11000.00
0005433680199	29164	Economy	11000.00
0005432966908	29164	Economy	11000.00
0005433680088	29164	Economy	11000.00
0005433680151	29164	Economy	11000.00
0005433687675	29164	Economy	11000.00
0005433680060	29164	Economy	11000.00
0005432966898	29164	Economy	11000.00
0005432966900	29164	Economy	11000.00
0005433680223	29164	Economy	11000.00
0005433680090	29164	Economy	11000.00
0005433680056	29164	Economy	11000.00
0005433679765	29164	Economy	11000.00
0005432966912	29164	Economy	11000.00
0005432966909	29164	Economy	11000.00
0005433690897	29164	Economy	11000.00
0005433680330	29164	Economy	11000.00
0005432966914	29164	Economy	11000.00
0005432966916	29164	Economy	11000.00
0005432966921	29164	Economy	11000.00
0005433680028	29164	Economy	11000.00
0005433680416	29164	Economy	11000.00
0005432966913	29164	Economy	11000.00
0005432966907	29164	Economy	11000.00
0005433687677	29164	Economy	11000.00
0005433680261	29164	Economy	11000.00
0005433687676	29164	Economy	11000.00
0005433679884	29164	Economy	11000.00
0005433680061	29164	Economy	11000.00
0005433684403	29164	Economy	11000.00
0005432005210	29164	Economy	11000.00
0005432145109	9318	Business	132900.00
0005433614509	9318	Business	132900.00
0005433614544	9318	Business	132900.00
0005433614527	9318	Business	132900.00
0005433614550	9318	Business	132900.00
0005433614571	9318	Business	132900.00
0005433577786	9318	Business	132900.00
0005433614561	9318	Business	132900.00
0005434152762	9318	Business	132900.00
0005433614534	9318	Business	132900.00
0005433614526	9318	Business	132900.00
0005433633740	9318	Business	132900.00
0005433614574	9318	Business	132900.00
0005433577793	9318	Business	132900.00
0005433633764	9318	Business	132900.00
0005433577784	9318	Business	132900.00
0005433633763	9318	Business	132900.00
0005433614515	9318	Business	132900.00
0005434269080	9318	Business	132900.00
0005433633743	9318	Business	132900.00
0005433614535	9318	Business	132900.00
0005434163556	9318	Business	132900.00
0005433614554	9318	Business	132900.00
0005433633751	9318	Business	132900.00
0005433577791	9318	Business	132900.00
0005432755072	9318	Economy	48700.00
0005433614542	9318	Economy	48700.00
0005433614538	9318	Economy	48700.00
0005433614522	9318	Economy	48700.00
0005433614583	9318	Economy	44300.00
0005432756842	9318	Economy	44300.00
0005433633745	9318	Economy	44300.00
0005434272176	9318	Economy	44300.00
0005433614529	9318	Economy	44300.00
0005433614517	9318	Economy	44300.00
0005433577785	9318	Economy	44300.00
0005433614557	9318	Economy	44300.00
0005433614552	9318	Economy	44300.00
0005433614536	9318	Economy	44300.00
0005433614537	9318	Economy	44300.00
0005433614556	9318	Economy	44300.00
0005434163507	9318	Economy	44300.00
0005432756844	9318	Economy	44300.00
0005433633754	9318	Economy	44300.00
0005433614569	9318	Economy	44300.00
0005433614563	9318	Economy	44300.00
0005433633750	9318	Economy	44300.00
0005433577787	9318	Economy	44300.00
0005433614564	9318	Economy	44300.00
0005433614543	9318	Economy	44300.00
0005433614512	9318	Economy	44300.00
0005433577795	9318	Economy	44300.00
0005433614577	9318	Economy	44300.00
0005433633755	9318	Economy	44300.00
0005433614531	9318	Economy	44300.00
0005433614582	9318	Economy	44300.00
0005433614510	9318	Economy	44300.00
0005433614511	9318	Economy	44300.00
0005433614520	9318	Economy	44300.00
0005433633762	9318	Economy	44300.00
0005433614549	9318	Economy	44300.00
0005433614533	9318	Economy	44300.00
0005433614528	9318	Economy	44300.00
0005434269071	9318	Economy	44300.00
0005433614519	9318	Economy	44300.00
0005433614547	9318	Economy	44300.00
0005433577792	9318	Economy	44300.00
0005433614553	9318	Economy	44300.00
0005434163515	9318	Economy	44300.00
0005433633737	9318	Economy	44300.00
0005433577789	9318	Economy	44300.00
0005434163538	9318	Economy	44300.00
0005433577788	9318	Economy	44300.00
0005433633757	9318	Economy	44300.00
0005433614518	9318	Economy	44300.00
0005433614578	9318	Economy	44300.00
0005433614567	9318	Economy	44300.00
0005433614560	9318	Economy	44300.00
0005433633760	9318	Economy	44300.00
0005433614525	9318	Economy	48700.00
0005434269081	9318	Economy	48700.00
0005433614513	9318	Economy	48700.00
0005432145107	9318	Economy	48700.00
0005434269082	9318	Economy	48700.00
0005433633767	9318	Economy	44300.00
0005433614558	9318	Economy	44300.00
0005433614523	9318	Economy	44300.00
0005433633768	9318	Economy	48700.00
0005434163557	9318	Economy	44300.00
0005432755071	9318	Economy	44300.00
0005433633744	9318	Economy	44300.00
0005433633741	9318	Economy	44300.00
0005433633749	9318	Economy	44300.00
0005433614575	9318	Economy	44300.00
0005434163494	9318	Economy	44300.00
0005434272177	9318	Economy	44300.00
0005433614521	9318	Economy	44300.00
0005434163519	9318	Economy	44300.00
0005433633756	9318	Economy	44300.00
0005433633758	9318	Economy	44300.00
0005433614540	9318	Economy	44300.00
0005433614572	9318	Economy	44300.00
0005433633746	9318	Economy	44300.00
0005433614566	9318	Economy	44300.00
0005432756843	9318	Economy	44300.00
0005433614576	9318	Economy	44300.00
0005433614559	9318	Economy	44300.00
0005433633769	9318	Economy	44300.00
0005433577797	9318	Economy	44300.00
0005433614548	9318	Economy	44300.00
0005432145108	9318	Economy	44300.00
0005433614565	9318	Economy	44300.00
0005433614524	9318	Economy	44300.00
0005433614570	9318	Economy	44300.00
0005433614541	9318	Economy	44300.00
0005434163516	9318	Economy	44300.00
0005433633753	9318	Economy	44300.00
0005433633759	9318	Economy	44300.00
0005433614580	9318	Economy	44300.00
0005433633766	9318	Economy	44300.00
0005433577794	9318	Economy	44300.00
0005433633770	9318	Economy	44300.00
0005433614530	9318	Economy	44300.00
0005433614568	9318	Economy	44300.00
0005433614516	9318	Economy	44300.00
0005433614545	9318	Economy	44300.00
0005433633748	9318	Economy	44300.00
0005433614546	9318	Economy	44300.00
0005434152761	9318	Economy	44300.00
0005434269077	9318	Economy	44300.00
0005433633738	9318	Economy	44300.00
0005433633765	9318	Economy	44300.00
0005433614555	9318	Economy	44300.00
0005433614573	9318	Economy	44300.00
0005433577796	9318	Economy	44300.00
0005433614551	9318	Economy	44300.00
0005433633742	9318	Economy	44300.00
0005433633747	9318	Economy	44300.00
0005433614562	9318	Economy	44300.00
0005434163574	9318	Economy	44300.00
0005433614579	9318	Economy	44300.00
0005433614514	9318	Economy	44300.00
0005433614581	9318	Economy	44300.00
0005433614539	9318	Economy	44300.00
0005433633739	9318	Economy	44300.00
0005433633752	9318	Economy	44300.00
0005433633761	9318	Economy	44300.00
0005433614532	9318	Economy	44300.00
0005433577790	9318	Economy	44300.00
0005433613902	25250	Business	132900.00
0005433633377	25250	Business	132900.00
0005433577625	25250	Business	132900.00
0005433614003	25250	Business	132900.00
0005433613901	25250	Business	132900.00
0005434163606	25250	Business	132900.00
0005433633422	25250	Business	132900.00
0005433633460	25250	Business	132900.00
0005434163609	25250	Business	132900.00
0005433614005	25250	Business	132900.00
0005433633376	25250	Business	132900.00
0005433633366	25250	Business	132900.00
0005434163614	25250	Business	132900.00
0005433633461	25250	Business	132900.00
0005433614131	25250	Business	132900.00
0005433614144	25250	Business	132900.00
0005433633482	25250	Business	132900.00
0005433633464	25250	Business	132900.00
0005433614063	25250	Business	132900.00
0005433577726	25250	Business	132900.00
0005433633450	25250	Business	132900.00
0005434163613	25250	Business	132900.00
0005433613951	25250	Business	132900.00
0005433613989	25250	Business	132900.00
0005433613930	25250	Business	132900.00
0005433613591	25250	Economy	48700.00
0005433633512	25250	Economy	48700.00
0005433614056	25250	Economy	48700.00
0005433633309	25250	Economy	48700.00
0005433613899	25250	Economy	48700.00
0005434163615	25250	Economy	48700.00
0005433614126	25250	Economy	44300.00
0005433614042	25250	Economy	44300.00
0005433613614	25250	Economy	44300.00
0005433613638	25250	Economy	44300.00
0005433633515	25250	Economy	44300.00
0005433614010	25250	Economy	44300.00
0005433633419	25250	Economy	44300.00
0005433633597	25250	Economy	44300.00
0005433614199	25250	Economy	44300.00
0005433613613	25250	Economy	44300.00
0005433633468	25250	Economy	44300.00
0005433613706	25250	Economy	44300.00
0005433614426	25250	Economy	44300.00
0005433577729	25250	Economy	44300.00
0005433633323	25250	Economy	44300.00
0005433613626	25250	Economy	44300.00
0005434272191	25250	Economy	44300.00
0005433614145	25250	Economy	44300.00
0005433633471	25250	Economy	44300.00
0005433613903	25250	Economy	44300.00
0005434163610	25250	Economy	44300.00
0005433613847	25250	Economy	44300.00
0005434163611	25250	Economy	44300.00
0005433633491	25250	Economy	44300.00
0005433633379	25250	Economy	44300.00
0005433614043	25250	Economy	44300.00
0005433614004	25250	Economy	44300.00
0005433577641	25250	Economy	44300.00
0005434163607	25250	Economy	44300.00
0005433633592	25250	Economy	44300.00
0005433614009	25250	Economy	44300.00
0005433633522	25250	Economy	44300.00
0005433633292	25250	Economy	44300.00
0005433633546	25250	Economy	44300.00
0005433613938	25250	Economy	44300.00
0005433577734	25250	Economy	44300.00
0005433577709	25250	Economy	44300.00
0005433633443	25250	Economy	44300.00
0005433613929	25250	Economy	44300.00
0005433633451	25250	Economy	44300.00
0005433613874	25250	Economy	44300.00
0005433613794	25250	Economy	44300.00
0005433633436	25250	Economy	44300.00
0005433633367	25250	Economy	44300.00
0005434163612	25250	Economy	44300.00
0005433613987	25250	Economy	44300.00
0005433633416	25250	Economy	44300.00
0005433614173	25250	Economy	44300.00
0005433633446	25250	Economy	44300.00
0005433613984	25250	Economy	44300.00
0005433577665	25250	Economy	48700.00
0005434163608	25250	Economy	48700.00
0005433613940	25250	Economy	48700.00
0005433614016	25250	Economy	48700.00
0005433633469	25250	Economy	44300.00
0005433633421	25250	Economy	44300.00
0005433577698	25250	Economy	48700.00
0005433613869	25250	Economy	44300.00
0005433577725	25250	Economy	44300.00
0005433633554	25250	Economy	44300.00
0005433613798	25250	Economy	44300.00
0005433613819	25250	Economy	44300.00
0005433613922	25250	Economy	44300.00
0005433633316	25250	Economy	44300.00
0005433613859	25250	Economy	44300.00
0005433614146	25250	Economy	44300.00
0005433613912	25250	Economy	44300.00
0005434272190	25250	Economy	44300.00
0005433613913	25250	Economy	44300.00
0005433614172	25250	Economy	44300.00
0005433613939	25250	Economy	44300.00
0005433633591	25250	Economy	44300.00
0005433613627	25250	Economy	44300.00
0005433633596	25250	Economy	44300.00
0005433613748	25250	Economy	44300.00
0005433613407	25250	Economy	44300.00
0005433613444	25250	Economy	44300.00
0005433633365	25250	Economy	44300.00
0005433613835	25250	Economy	44300.00
0005433613747	25250	Economy	44300.00
0005433614114	25250	Economy	44300.00
0005433633472	25250	Economy	44300.00
0005433613887	25250	Economy	44300.00
0005433633481	25250	Economy	44300.00
0005433577724	25250	Economy	44300.00
0005433633547	25250	Economy	44300.00
0005433613443	25250	Economy	44300.00
0005433614054	25250	Economy	44300.00
0005433613840	25250	Economy	44300.00
0005433613958	25250	Economy	44300.00
0005433613898	25250	Economy	44300.00
0005433613937	25250	Economy	44300.00
0005434272189	25250	Economy	44300.00
0005433633433	25250	Economy	44300.00
0005433633598	25250	Economy	44300.00
0005433633445	25250	Economy	44300.00
0005433613854	25250	Economy	44300.00
0005433613776	25250	Economy	44300.00
0005433613960	25250	Economy	44300.00
0005434273074	25250	Economy	44300.00
0005433613952	25250	Economy	44300.00
0005433613746	25250	Economy	44300.00
0005433633378	25250	Economy	44300.00
0005433613875	25250	Economy	44300.00
0005433577697	25250	Economy	44300.00
0005433613955	25250	Economy	44300.00
0005433613637	25250	Economy	44300.00
0005433633417	25250	Economy	44300.00
0005433613885	25250	Economy	44300.00
0005433614044	25250	Economy	44300.00
0005433633303	25250	Economy	44300.00
0005433633511	25250	Economy	44300.00
0005433633498	25250	Economy	44300.00
0005433614110	25250	Economy	44300.00
0005435947116	4222	Business	193100.00
0005435947147	4222	Business	193100.00
0005435947123	4222	Business	193100.00
0005435947135	4222	Economy	70800.00
0005435947176	4222	Economy	64400.00
0005435986743	4222	Economy	64400.00
0005435986752	4222	Economy	64400.00
0005435947096	4222	Economy	64400.00
0005432571283	4222	Economy	64400.00
0005435947146	4222	Economy	64400.00
0005435986756	4222	Economy	64400.00
0005435947132	4222	Economy	64400.00
0005435947117	4222	Economy	64400.00
0005435986747	4222	Economy	64400.00
0005435986749	4222	Economy	64400.00
0005435986745	4222	Economy	64400.00
0005435986744	4222	Economy	64400.00
0005435947141	4222	Economy	64400.00
0005432571270	4222	Economy	64400.00
0005432571290	4222	Economy	64400.00
0005435986755	4222	Economy	70800.00
0005435856161	4222	Economy	64400.00
0005435947097	4222	Economy	64400.00
0005432571271	4222	Economy	64400.00
0005432184948	4222	Economy	64400.00
0005435947080	4222	Economy	64400.00
0005435856182	4222	Economy	64400.00
0005435947115	4222	Economy	64400.00
0005435986757	4222	Economy	64400.00
0005435856162	4222	Economy	64400.00
0005435986750	4222	Economy	64400.00
0005435986753	4222	Economy	64400.00
0005432571288	4222	Economy	64400.00
0005435986748	4222	Economy	64400.00
0005435986751	4222	Economy	64400.00
0005435986746	4222	Economy	64400.00
0005435986754	4222	Economy	64400.00
0005435986758	4222	Economy	64400.00
0005435947081	4222	Economy	64400.00
0005435947082	4222	Economy	64400.00
0005435947243	26614	Business	193100.00
0005435947246	26614	Business	193100.00
0005435986685	26614	Business	193100.00
0005435986694	26614	Business	193100.00
0005435947249	26614	Business	193100.00
0005435947240	26614	Business	193100.00
0005435986699	26614	Business	193100.00
0005435986711	26614	Business	193100.00
0005435947248	26614	Business	193100.00
0005432571322	26614	Economy	64400.00
0005435856199	26614	Economy	64400.00
0005435947250	26614	Economy	64400.00
0005435856200	26614	Economy	64400.00
0005432571321	26614	Economy	64400.00
0005435947244	26614	Economy	64400.00
0005435947236	26614	Economy	64400.00
0005435986681	26614	Economy	64400.00
0005435986693	26614	Economy	64400.00
0005435856203	26614	Economy	64400.00
0005435947245	26614	Economy	64400.00
0005432571323	26614	Economy	64400.00
0005435986710	26614	Economy	64400.00
0005435986691	26614	Economy	64400.00
0005435787354	26614	Economy	64400.00
0005435986682	26614	Economy	64400.00
0005435947241	26614	Economy	64400.00
0005435947247	26614	Economy	64400.00
0005435856198	26614	Economy	70800.00
0005435947242	26614	Economy	64400.00
0005435986670	26614	Economy	64400.00
0005435947238	26614	Economy	64400.00
0005435856201	26614	Economy	64400.00
0005435947237	26614	Economy	64400.00
0005435986703	26614	Economy	64400.00
0005435986695	26614	Economy	64400.00
0005432571324	26614	Economy	64400.00
0005432571320	26614	Economy	64400.00
0005435856202	26614	Economy	64400.00
0005435986692	26614	Economy	64400.00
0005435947239	26614	Economy	64400.00
0005435947235	26614	Economy	64400.00
0005433569048	328	Business	21500.00
0005433074371	328	Business	21500.00
0005433074489	328	Business	21500.00
0005432947994	328	Business	21500.00
0005433569031	328	Business	21500.00
0005433568998	328	Business	21500.00
0005433569030	328	Business	21500.00
0005432947873	328	Business	21500.00
0005432947834	328	Business	21500.00
0005432948002	328	Business	21500.00
0005432948141	328	Business	21500.00
0005432948114	328	Business	21500.00
0005433569005	328	Business	21500.00
0005433074389	328	Business	21500.00
0005432948051	328	Business	21500.00
0005433569038	328	Business	21500.00
0005433074574	328	Business	21500.00
0005433569036	328	Business	21500.00
0005432948034	328	Business	21500.00
0005433569037	328	Business	21500.00
0005432948139	328	Business	21500.00
0005433074307	328	Business	21500.00
0005432948140	328	Business	21500.00
0005432948135	328	Economy	7900.00
0005433569044	328	Economy	7900.00
0005433074417	328	Economy	7900.00
0005432948077	328	Economy	7900.00
0005432947836	328	Economy	7900.00
0005432947912	328	Economy	7200.00
0005433569046	328	Economy	7200.00
0005433074323	328	Economy	7200.00
0005433569020	328	Economy	7200.00
0005433569006	328	Economy	7200.00
0005432948113	328	Economy	7200.00
0005433569040	328	Economy	7200.00
0005433129236	328	Economy	7200.00
0005433569001	328	Economy	7200.00
0005433569025	328	Economy	7200.00
0005433134101	328	Economy	7200.00
0005432948058	328	Economy	7200.00
0005432948101	328	Economy	7200.00
0005432947835	328	Economy	7200.00
0005433074506	328	Economy	7200.00
0005433569027	328	Economy	7200.00
0005433074405	328	Economy	7200.00
0005433569008	328	Economy	7200.00
0005433569032	328	Economy	7200.00
0005432948097	328	Economy	7200.00
0005433074402	328	Economy	7200.00
0005433074488	328	Economy	7200.00
0005433569015	328	Economy	7200.00
0005433569035	328	Economy	7200.00
0005433074445	328	Economy	7200.00
0005433569009	328	Economy	7200.00
0005432947992	328	Economy	7200.00
0005432948184	328	Economy	7200.00
0005433569043	328	Economy	7200.00
0005433569011	328	Economy	7200.00
0005433569007	328	Economy	7200.00
0005433074372	328	Economy	7200.00
0005432948036	328	Economy	7200.00
0005433074533	328	Economy	7200.00
0005432948134	328	Economy	7200.00
0005433134100	328	Economy	7200.00
0005432947841	328	Economy	7200.00
0005432238929	328	Economy	7200.00
0005432948138	328	Economy	7200.00
0005432947993	328	Economy	7200.00
0005433568997	328	Economy	7200.00
0005432238931	328	Economy	7200.00
0005433569000	328	Economy	7200.00
0005433569047	328	Economy	7200.00
0005433569014	328	Economy	7200.00
0005433074373	328	Economy	7200.00
0005433569003	328	Economy	7200.00
0005432948198	328	Economy	7200.00
0005433569021	328	Economy	7200.00
0005433569010	328	Economy	7900.00
0005433569029	328	Economy	7900.00
0005433074478	328	Economy	7900.00
0005432948185	328	Economy	7200.00
0005433568994	328	Economy	7200.00
0005433074447	328	Economy	7200.00
0005433074468	328	Economy	7900.00
0005432948078	328	Economy	7200.00
0005432947946	328	Economy	7200.00
0005433569017	328	Economy	7200.00
0005433569034	328	Economy	7200.00
0005433569042	328	Economy	7200.00
0005432948195	328	Economy	7200.00
0005432947909	328	Economy	7200.00
0005433568999	328	Economy	7200.00
0005432238933	328	Economy	7200.00
0005433074473	328	Economy	7200.00
0005433569028	328	Economy	7200.00
0005433074390	328	Economy	7200.00
0005433074507	328	Economy	7200.00
0005433569022	328	Economy	7200.00
0005433568995	328	Economy	7200.00
0005433569002	328	Economy	7200.00
0005433134102	328	Economy	7200.00
0005433569024	328	Economy	7200.00
0005432948048	328	Economy	7200.00
0005432947874	328	Economy	7200.00
0005433569018	328	Economy	7200.00
0005433569045	328	Economy	7200.00
0005433569026	328	Economy	7200.00
0005433074446	328	Economy	7200.00
0005433074322	328	Economy	7200.00
0005433074308	328	Economy	7200.00
0005433569033	328	Economy	7200.00
0005432948037	328	Economy	7200.00
0005433569019	328	Economy	7200.00
0005433074498	328	Economy	7200.00
0005433074532	328	Economy	7200.00
0005432948041	328	Economy	7200.00
0005432948063	328	Economy	7200.00
0005433074370	328	Economy	7200.00
0005433569023	328	Economy	7200.00
0005433569041	328	Economy	7200.00
0005432948038	328	Economy	7200.00
0005432238930	328	Economy	7200.00
0005433569013	328	Economy	7200.00
0005433569016	328	Economy	7200.00
0005433074491	328	Economy	7200.00
0005432947975	328	Economy	7200.00
0005432947976	328	Economy	7200.00
0005432238928	328	Economy	7200.00
0005432948074	328	Economy	7200.00
0005433569012	328	Economy	7200.00
0005432948047	328	Economy	7200.00
0005433568996	328	Economy	7200.00
0005433569004	328	Economy	7200.00
0005432948112	328	Economy	7200.00
0005432238932	328	Economy	7200.00
0005433569039	328	Economy	7200.00
0005432948075	328	Economy	7200.00
0005433568309	11600	Business	21500.00
0005433568320	11600	Business	21500.00
0005433568412	11600	Business	21500.00
0005433568409	11600	Business	21500.00
0005433074668	11600	Business	21500.00
0005432948395	11600	Business	21500.00
0005433568255	11600	Business	21500.00
0005433134132	11600	Business	21500.00
0005432192316	11600	Business	21500.00
0005432948422	11600	Business	21500.00
0005433568277	11600	Business	21500.00
0005433568317	11600	Business	21500.00
0005433568386	11600	Business	21500.00
0005433568329	11600	Business	21500.00
0005432948429	11600	Business	21500.00
0005433568339	11600	Business	21500.00
0005433568144	11600	Business	21500.00
0005432948409	11600	Business	21500.00
0005433568124	11600	Business	21500.00
0005433568390	11600	Business	21500.00
0005433568138	11600	Economy	7900.00
0005432948394	11600	Economy	7900.00
0005433074679	11600	Economy	7900.00
0005433074689	11600	Economy	7900.00
0005433568349	11600	Economy	7900.00
0005432948391	11600	Economy	7200.00
0005432948408	11600	Economy	7200.00
0005433074671	11600	Economy	7200.00
0005432948400	11600	Economy	7200.00
0005433134135	11600	Economy	7200.00
0005433074664	11600	Economy	7200.00
0005433568330	11600	Economy	7200.00
0005433074688	11600	Economy	7200.00
0005433568331	11600	Economy	7200.00
0005432948420	11600	Economy	7200.00
0005433568032	11600	Economy	7200.00
0005432948406	11600	Economy	7200.00
0005433568244	11600	Economy	7200.00
0005433074681	11600	Economy	7200.00
0005432948389	11600	Economy	7200.00
0005432948418	11600	Economy	7200.00
0005433568369	11600	Economy	7200.00
0005432948419	11600	Economy	7200.00
0005432948390	11600	Economy	7200.00
0005433568100	11600	Economy	7200.00
0005432948407	11600	Economy	7200.00
0005432948405	11600	Economy	7200.00
0005432948416	11600	Economy	7200.00
0005433568389	11600	Economy	7200.00
0005433568399	11600	Economy	7200.00
0005433568141	11600	Economy	7200.00
0005432948431	11600	Economy	7200.00
0005433568303	11600	Economy	7200.00
0005432948414	11600	Economy	7200.00
0005433568145	11600	Economy	7200.00
0005433568282	11600	Economy	7200.00
0005433074667	11600	Economy	7200.00
0005433568410	11600	Economy	7200.00
0005432948417	11600	Economy	7200.00
0005432948397	11600	Economy	7200.00
0005433074672	11600	Economy	7200.00
0005432948424	11600	Economy	7200.00
0005433568387	11600	Economy	7200.00
0005433568264	11600	Economy	7200.00
0005433568340	11600	Economy	7200.00
0005433568391	11600	Economy	7200.00
0005433568148	11600	Economy	7200.00
0005433074677	11600	Economy	7200.00
0005433568326	11600	Economy	7200.00
0005432948393	11600	Economy	7200.00
0005433131705	11600	Economy	7200.00
0005433074684	11600	Economy	7200.00
0005432948415	11600	Economy	7200.00
0005433568267	11600	Economy	7900.00
0005433568117	11600	Economy	7900.00
0005432948410	11600	Economy	7900.00
0005432948396	11600	Economy	7900.00
0005432948430	11600	Economy	7200.00
0005432948401	11600	Economy	7900.00
0005433074678	11600	Economy	7200.00
0005433568310	11600	Economy	7200.00
0005432948428	11600	Economy	7200.00
0005433131703	11600	Economy	7200.00
0005432948399	11600	Economy	7900.00
0005432948412	11600	Economy	7200.00
0005433568315	11600	Economy	7200.00
0005433074669	11600	Economy	7200.00
0005432948413	11600	Economy	7200.00
0005432948425	11600	Economy	7200.00
0005432948403	11600	Economy	7200.00
0005433074680	11600	Economy	7200.00
0005432948402	11600	Economy	7200.00
0005433568388	11600	Economy	7200.00
0005433568328	11600	Economy	7200.00
0005433568411	11600	Economy	7200.00
0005432948392	11600	Economy	7200.00
0005433074670	11600	Economy	7200.00
0005433074676	11600	Economy	7200.00
0005432948426	11600	Economy	7200.00
0005433074682	11600	Economy	7200.00
0005433074673	11600	Economy	7200.00
0005433568357	11600	Economy	7200.00
0005433568398	11600	Economy	7200.00
0005433568408	11600	Economy	7200.00
0005433074687	11600	Economy	7200.00
0005433568274	11600	Economy	7200.00
0005433074686	11600	Economy	7200.00
0005433131702	11600	Economy	7200.00
0005433134133	11600	Economy	7200.00
0005433568281	11600	Economy	7200.00
0005433568301	11600	Economy	7200.00
0005433568278	11600	Economy	7200.00
0005433074685	11600	Economy	7200.00
0005432948421	11600	Economy	7200.00
0005433568263	11600	Economy	7200.00
0005433074690	11600	Economy	7200.00
0005433134131	11600	Economy	7200.00
0005433568220	11600	Economy	7200.00
0005433131704	11600	Economy	7200.00
0005433568275	11600	Economy	7200.00
0005433074675	11600	Economy	7200.00
0005433568426	11600	Economy	7200.00
0005433074665	11600	Economy	7200.00
0005432948427	11600	Economy	7200.00
0005433074683	11600	Economy	7200.00
0005433074674	11600	Economy	7200.00
0005432948423	11600	Economy	7200.00
0005433568125	11600	Economy	7200.00
0005432192318	11600	Economy	7200.00
0005433074666	11600	Economy	7200.00
0005432948404	11600	Economy	7200.00
0005433134134	11600	Economy	7200.00
0005432948398	11600	Economy	7200.00
0005433568146	11600	Economy	7200.00
0005432948411	11600	Economy	7200.00
0005433131701	11600	Economy	7200.00
0005433074691	11600	Economy	7200.00
0005432192317	11600	Economy	7200.00
0005433817468	10004	Economy	6300.00
0005434732954	10004	Economy	6300.00
0005433817466	10004	Economy	6300.00
0005433817465	10004	Economy	6300.00
0005434732956	10004	Economy	6300.00
0005433817469	10004	Economy	6300.00
0005433817467	10004	Economy	6300.00
0005434732978	13985	Economy	6300.00
0005433817422	13985	Economy	6300.00
0005433817450	13985	Economy	6300.00
0005433817451	13985	Economy	6300.00
0005433817432	13985	Economy	6300.00
0005433817428	13985	Economy	6300.00
0005434732979	13985	Economy	6300.00
0005434732977	13985	Economy	6300.00
0005433817431	13985	Economy	6300.00
0005435982243	2338	Business	184500.00
0005433754197	2338	Business	184500.00
0005435982279	2338	Business	184500.00
0005433754183	2338	Business	184500.00
0005434731133	2338	Business	184500.00
0005432300256	2338	Business	184500.00
0005432984862	2338	Business	184500.00
0005432984641	2338	Business	184500.00
0005433434452	2338	Business	184500.00
0005432984672	2338	Business	184500.00
0005433434367	2338	Business	184500.00
0005433754152	2338	Business	184500.00
0005435982287	2338	Business	184500.00
0005435982259	2338	Business	184500.00
0005433754149	2338	Business	184500.00
0005435982290	2338	Business	184500.00
0005433754179	2338	Business	184500.00
0005433434363	2338	Business	184500.00
0005432655525	2338	Business	184500.00
0005432984671	2338	Business	184500.00
0005433754176	2338	Business	184500.00
0005435982269	2338	Business	184500.00
0005433754164	2338	Business	184500.00
0005435982268	2338	Business	184500.00
0005433754182	2338	Business	184500.00
0005432869438	2338	Business	184500.00
0005435982284	2338	Business	184500.00
0005432300258	2338	Business	184500.00
0005435982257	2338	Economy	67700.00
0005432655527	2338	Business	184500.00
0005433434490	2338	Economy	67700.00
0005432869457	2338	Economy	67700.00
0005432869458	2338	Economy	61500.00
0005433764679	2338	Economy	61500.00
0005434731145	2338	Economy	61500.00
0005433434549	2338	Economy	61500.00
0005433754143	2338	Economy	61500.00
0005435982253	2338	Economy	61500.00
0005433434297	2338	Economy	61500.00
0005432655528	2338	Economy	61500.00
0005435982258	2338	Economy	61500.00
0005433434413	2338	Economy	61500.00
0005433754146	2338	Economy	61500.00
0005435982246	2338	Economy	61500.00
0005433754150	2338	Economy	61500.00
0005432226051	2338	Economy	61500.00
0005433434425	2338	Economy	61500.00
0005433434440	2338	Economy	61500.00
0005433754195	2338	Economy	61500.00
0005433754169	2338	Economy	61500.00
0005432300259	2338	Economy	61500.00
0005433434557	2338	Economy	61500.00
0005432869442	2338	Economy	61500.00
0005433434357	2338	Economy	61500.00
0005433754172	2338	Economy	61500.00
0005435982266	2338	Economy	61500.00
0005432984801	2338	Economy	61500.00
0005433754160	2338	Economy	61500.00
0005435982264	2338	Economy	61500.00
0005433754155	2338	Economy	61500.00
0005432655532	2338	Economy	61500.00
0005433754189	2338	Economy	61500.00
0005432655531	2338	Economy	61500.00
0005432655522	2338	Economy	61500.00
0005433754174	2338	Economy	61500.00
0005432226054	2338	Economy	61500.00
0005432984755	2338	Economy	61500.00
0005435982282	2338	Economy	61500.00
0005433754194	2338	Economy	61500.00
0005435982247	2338	Economy	61500.00
0005432226049	2338	Economy	61500.00
0005432655529	2338	Economy	61500.00
0005435982263	2338	Economy	61500.00
0005435982252	2338	Economy	61500.00
0005433754192	2338	Economy	61500.00
0005433764677	2338	Economy	61500.00
0005435982256	2338	Economy	61500.00
0005432984667	2338	Economy	61500.00
0005433434381	2338	Economy	61500.00
0005435982289	2338	Economy	61500.00
0005435982273	2338	Economy	61500.00
0005432869443	2338	Economy	61500.00
0005432984787	2338	Economy	61500.00
0005432984895	2338	Economy	61500.00
0005433764678	2338	Economy	61500.00
0005433754166	2338	Economy	61500.00
0005432300260	2338	Economy	61500.00
0005435982274	2338	Economy	61500.00
0005435982276	2338	Economy	61500.00
0005433434491	2338	Economy	61500.00
0005432226050	2338	Economy	61500.00
0005433754165	2338	Economy	61500.00
0005435982249	2338	Economy	61500.00
0005433434427	2338	Economy	61500.00
0005435982244	2338	Economy	61500.00
0005433754144	2338	Economy	61500.00
0005432984894	2338	Economy	61500.00
0005433754163	2338	Economy	61500.00
0005435982280	2338	Economy	61500.00
0005435982250	2338	Economy	61500.00
0005433766635	2338	Economy	61500.00
0005433754187	2338	Economy	61500.00
0005433754148	2338	Economy	61500.00
0005432300255	2338	Economy	61500.00
0005432655521	2338	Economy	61500.00
0005435982277	2338	Economy	61500.00
0005433754180	2338	Economy	61500.00
0005433434296	2338	Economy	61500.00
0005435982262	2338	Economy	61500.00
0005435982291	2338	Economy	61500.00
0005433754188	2338	Economy	61500.00
0005433434556	2338	Economy	61500.00
0005435982278	2338	Economy	61500.00
0005433754162	2338	Economy	61500.00
0005433434442	2338	Economy	61500.00
0005435982281	2338	Economy	61500.00
0005432655523	2338	Economy	61500.00
0005435982270	2338	Economy	61500.00
0005432869468	2338	Economy	61500.00
0005432300261	2338	Economy	61500.00
0005433754178	2338	Economy	61500.00
0005432984668	2338	Economy	61500.00
0005435982265	2338	Economy	61500.00
0005432655526	2338	Economy	61500.00
0005433754186	2338	Economy	61500.00
0005435982260	2338	Economy	61500.00
0005432984677	2338	Economy	67700.00
0005432300262	2338	Economy	61500.00
0005433754198	2338	Economy	67700.00
0005435982285	2338	Economy	61500.00
0005433754161	2338	Economy	61500.00
0005432984655	2338	Economy	67700.00
0005435982275	2338	Economy	61500.00
0005433434439	2338	Economy	67700.00
0005432984759	2338	Economy	61500.00
0005432984724	2338	Economy	61500.00
0005435982272	2338	Economy	61500.00
0005432869439	2338	Economy	61500.00
0005433754157	2338	Economy	61500.00
0005435982241	2338	Economy	61500.00
0005433754173	2338	Economy	61500.00
0005435982271	2338	Economy	61500.00
0005433434375	2338	Economy	61500.00
0005433434380	2338	Economy	61500.00
0005432655530	2338	Economy	61500.00
0005432869446	2338	Economy	61500.00
0005433754191	2338	Economy	61500.00
0005433754154	2338	Economy	61500.00
0005433434366	2338	Economy	61500.00
0005432984741	2338	Economy	61500.00
0005433754153	2338	Economy	61500.00
0005433754181	2338	Economy	61500.00
0005433754199	2338	Economy	61500.00
0005435982255	2338	Economy	61500.00
0005433434412	2338	Economy	61500.00
0005435982283	2338	Economy	61500.00
0005433434419	2338	Economy	61500.00
0005433754142	2338	Economy	61500.00
0005432984714	2338	Economy	61500.00
0005433754170	2338	Economy	61500.00
0005433754184	2338	Economy	61500.00
0005433434550	2338	Economy	61500.00
0005435982251	2338	Economy	61500.00
0005432300257	2338	Economy	61500.00
0005435982261	2338	Economy	61500.00
0005433434350	2338	Economy	61500.00
0005433766637	2338	Economy	61500.00
0005432984715	2338	Economy	61500.00
0005433754167	2338	Economy	61500.00
0005432226056	2338	Economy	61500.00
0005433434420	2338	Economy	61500.00
0005433434356	2338	Economy	61500.00
0005432869440	2338	Economy	61500.00
0005433754168	2338	Economy	61500.00
0005434731123	2338	Economy	61500.00
0005433434432	2338	Economy	61500.00
0005435982286	2338	Economy	61500.00
0005435982288	2338	Economy	61500.00
0005433754158	2338	Economy	61500.00
0005432226053	2338	Economy	61500.00
0005433766636	2338	Economy	61500.00
0005435982254	2338	Economy	61500.00
0005435982267	2338	Economy	61500.00
0005435982242	2338	Economy	61500.00
0005432984820	2338	Economy	61500.00
0005432984860	2338	Economy	61500.00
0005434731124	2338	Economy	61500.00
0005433754171	2338	Economy	61500.00
0005432226052	2338	Economy	61500.00
0005433754175	2338	Economy	61500.00
0005433754151	2338	Economy	61500.00
0005433754193	2338	Economy	61500.00
0005432226055	2338	Economy	61500.00
0005432984725	2338	Economy	61500.00
0005435982245	2338	Economy	61500.00
0005434731134	2338	Economy	61500.00
0005435982248	2338	Economy	61500.00
0005433754145	2338	Economy	61500.00
0005433754196	2338	Economy	61500.00
0005432655533	2338	Economy	61500.00
0005433754177	2338	Economy	61500.00
0005433754159	2338	Economy	61500.00
0005432655524	2338	Economy	61500.00
0005432984863	2338	Economy	61500.00
0005433754185	2338	Economy	61500.00
0005433434426	2338	Economy	61500.00
0005433754156	2338	Economy	61500.00
0005433754190	2338	Economy	61500.00
0005433754147	2338	Economy	61500.00
0005434731168	26204	Business	184500.00
0005433753753	26204	Business	184500.00
0005433754008	26204	Business	184500.00
0005433753832	26204	Business	184500.00
0005433753475	26204	Business	184500.00
0005432985061	26204	Business	184500.00
0005432655414	26204	Business	184500.00
0005435981944	26204	Business	184500.00
0005435981543	26204	Business	184500.00
0005433434663	26204	Business	184500.00
0005433754007	26204	Business	184500.00
0005433434651	26204	Business	184500.00
0005433753713	26204	Business	184500.00
0005435981868	26204	Business	184500.00
0005435981832	26204	Business	184500.00
0005433753654	26204	Business	184500.00
0005433753522	26204	Business	184500.00
0005432985031	26204	Business	184500.00
0005433764655	26204	Business	184500.00
0005433753671	26204	Business	184500.00
0005432985056	26204	Business	184500.00
0005432985064	26204	Business	184500.00
0005432985054	26204	Business	184500.00
0005433753879	26204	Business	184500.00
0005432655420	26204	Business	184500.00
0005435981874	26204	Business	184500.00
0005435981694	26204	Business	184500.00
0005433753793	26204	Economy	67700.00
0005432655397	26204	Economy	67700.00
0005432655385	26204	Economy	67700.00
0005435981688	26204	Economy	67700.00
0005433753569	26204	Economy	61500.00
0005433434643	26204	Economy	61500.00
0005432869512	26204	Economy	61500.00
0005435981668	26204	Economy	61500.00
0005435981731	26204	Economy	61500.00
0005432655384	26204	Economy	61500.00
0005435981717	26204	Economy	61500.00
0005432985034	26204	Economy	61500.00
0005435981686	26204	Economy	61500.00
0005433434640	26204	Economy	61500.00
0005433753612	26204	Economy	61500.00
0005433753397	26204	Economy	61500.00
0005432051124	26204	Economy	61500.00
0005433753680	26204	Economy	61500.00
0005433434657	26204	Economy	61500.00
0005432985032	26204	Economy	61500.00
0005432985053	26204	Economy	61500.00
0005432869515	26204	Economy	61500.00
0005435981687	26204	Economy	61500.00
0005433753521	26204	Economy	61500.00
0005433753611	26204	Economy	61500.00
0005433753784	26204	Economy	61500.00
0005433753814	26204	Economy	61500.00
0005435981650	26204	Economy	61500.00
0005432985057	26204	Economy	61500.00
0005433753756	26204	Economy	61500.00
0005432869518	26204	Economy	61500.00
0005435981771	26204	Economy	61500.00
0005433434662	26204	Economy	61500.00
0005432869516	26204	Economy	61500.00
0005435981732	26204	Economy	61500.00
0005432985035	26204	Economy	61500.00
0005433434645	26204	Economy	61500.00
0005435981994	26204	Economy	61500.00
0005433434650	26204	Economy	61500.00
0005433753773	26204	Economy	61500.00
0005433753494	26204	Economy	61500.00
0005433753786	26204	Economy	61500.00
0005433434654	26204	Economy	61500.00
0005433434648	26204	Economy	61500.00
0005432985047	26204	Economy	61500.00
0005433753789	26204	Economy	61500.00
0005433434655	26204	Economy	61500.00
0005433753714	26204	Economy	61500.00
0005435981679	26204	Economy	61500.00
0005432049461	26204	Economy	61500.00
0005432051125	26204	Economy	61500.00
0005432655348	26204	Economy	61500.00
0005432655357	26204	Economy	61500.00
0005432985051	26204	Economy	61500.00
0005433434659	26204	Economy	61500.00
0005435981913	26204	Economy	61500.00
0005432985046	26204	Economy	61500.00
0005435981985	26204	Economy	61500.00
0005433753749	26204	Economy	61500.00
0005433434667	26204	Economy	61500.00
0005432985059	26204	Economy	61500.00
0005435981826	26204	Economy	61500.00
0005432869514	26204	Economy	61500.00
0005433753564	26204	Economy	61500.00
0005432655358	26204	Economy	61500.00
0005432985055	26204	Economy	61500.00
0005432985042	26204	Economy	61500.00
0005435981799	26204	Economy	61500.00
0005432869517	26204	Economy	61500.00
0005432985048	26204	Economy	61500.00
0005433434644	26204	Economy	61500.00
0005433753598	26204	Economy	61500.00
0005433753677	26204	Economy	61500.00
0005434731167	26204	Economy	61500.00
0005432049460	26204	Economy	61500.00
0005432051126	26204	Economy	61500.00
0005435981833	26204	Economy	61500.00
0005435981733	26204	Economy	61500.00
0005435981667	26204	Economy	61500.00
0005433753708	26204	Economy	61500.00
0005432655413	26204	Economy	61500.00
0005433434658	26204	Economy	61500.00
0005433434666	26204	Economy	61500.00
0005432985040	26204	Economy	61500.00
0005433434646	26204	Economy	61500.00
0005433753771	26204	Economy	61500.00
0005433753621	26204	Economy	61500.00
0005432869513	26204	Economy	61500.00
0005433753539	26204	Economy	61500.00
0005432985049	26204	Economy	61500.00
0005435981761	26204	Economy	61500.00
0005432985037	26204	Economy	61500.00
0005435981945	26204	Economy	61500.00
0005435981693	26204	Economy	61500.00
0005433753643	26204	Economy	61500.00
0005435981797	26204	Economy	61500.00
0005433753790	26204	Economy	61500.00
0005433753651	26204	Economy	61500.00
0005435981544	26204	Economy	61500.00
0005433753759	26204	Economy	67700.00
0005435981980	26204	Economy	61500.00
0005433434649	26204	Economy	67700.00
0005433753899	26204	Economy	61500.00
0005433434668	26204	Economy	61500.00
0005433434642	26204	Economy	67700.00
0005433434660	26204	Economy	67700.00
0005433434656	26204	Economy	61500.00
0005435981875	26204	Economy	61500.00
0005435981876	26204	Economy	61500.00
0005432985062	26204	Economy	61500.00
0005435981730	26204	Economy	61500.00
0005433753721	26204	Economy	61500.00
0005433753889	26204	Economy	61500.00
0005432985041	26204	Economy	61500.00
0005435981781	26204	Economy	61500.00
0005433753747	26204	Economy	61500.00
0005435981986	26204	Economy	61500.00
0005433753613	26204	Economy	61500.00
0005432985033	26204	Economy	61500.00
0005432985060	26204	Economy	61500.00
0005433753511	26204	Economy	61500.00
0005432985039	26204	Economy	61500.00
0005433434661	26204	Economy	61500.00
0005433753709	26204	Economy	61500.00
0005433753788	26204	Economy	61500.00
0005434731166	26204	Economy	61500.00
0005433434665	26204	Economy	61500.00
0005432985050	26204	Economy	61500.00
0005432985038	26204	Economy	61500.00
0005433434647	26204	Economy	61500.00
0005433753907	26204	Economy	61500.00
0005432655396	26204	Economy	61500.00
0005433753631	26204	Economy	61500.00
0005435981946	26204	Economy	61500.00
0005433753794	26204	Economy	61500.00
0005433753731	26204	Economy	61500.00
0005432985043	26204	Economy	61500.00
0005432655347	26204	Economy	61500.00
0005435981914	26204	Economy	61500.00
0005433434652	26204	Economy	61500.00
0005432985052	26204	Economy	61500.00
0005432985058	26204	Economy	61500.00
0005435981831	26204	Economy	61500.00
0005433753970	26204	Economy	61500.00
0005433434641	26204	Economy	61500.00
0005433753563	26204	Economy	61500.00
0005433753748	26204	Economy	61500.00
0005433753760	26204	Economy	61500.00
0005432985036	26204	Economy	61500.00
0005433753770	26204	Economy	61500.00
0005433753795	26204	Economy	61500.00
0005433753615	26204	Economy	61500.00
0005432655386	26204	Economy	61500.00
0005432049459	26204	Economy	61500.00
0005432985063	26204	Economy	61500.00
0005435981659	26204	Economy	61500.00
0005435981896	26204	Economy	61500.00
0005432985045	26204	Economy	61500.00
0005433753396	26204	Economy	61500.00
0005433753653	26204	Economy	61500.00
0005435981551	26204	Economy	61500.00
0005433753732	26204	Economy	61500.00
0005435981869	26204	Economy	61500.00
0005432985044	26204	Economy	61500.00
0005433753728	26204	Economy	61500.00
0005433753902	26204	Economy	61500.00
0005433753461	26204	Economy	61500.00
0005435981710	26204	Economy	61500.00
0005433753746	26204	Economy	61500.00
0005432985065	26204	Economy	61500.00
0005435981760	26204	Economy	61500.00
0005435981685	26204	Economy	61500.00
0005433753720	26204	Economy	61500.00
0005433434664	26204	Economy	61500.00
0005433753783	26204	Economy	61500.00
0005433753761	26204	Economy	61500.00
0005433434653	26204	Economy	61500.00
0005432267892	1487	Business	38900.00
0005434374632	1487	Business	38900.00
0005434374619	1487	Business	38900.00
0005433151136	1487	Business	38900.00
0005434374631	1487	Business	38900.00
0005434374610	1487	Business	38900.00
0005434374617	1487	Business	38900.00
0005433151221	1487	Business	38900.00
0005434374611	1487	Business	38900.00
0005433151032	1487	Economy	13000.00
0005434374627	1487	Economy	13000.00
0005434374623	1487	Economy	13000.00
0005432267886	1487	Economy	13000.00
0005433151164	1487	Economy	13000.00
0005433151033	1487	Economy	13000.00
0005434374628	1487	Economy	13000.00
0005433151232	1487	Economy	13000.00
0005433461586	1487	Economy	13000.00
0005433151096	1487	Economy	13000.00
0005434374629	1487	Economy	13000.00
0005433151149	1487	Economy	13000.00
0005433151161	1487	Economy	13000.00
0005434374613	1487	Economy	13000.00
0005434029621	1487	Economy	13000.00
0005434374622	1487	Economy	13000.00
0005433931428	1487	Economy	13000.00
0005433151089	1487	Economy	13000.00
0005433151109	1487	Economy	13000.00
0005433151120	1487	Economy	13000.00
0005433151121	1487	Economy	13000.00
0005434374620	1487	Economy	13000.00
0005432267889	1487	Economy	13000.00
0005433931437	1487	Economy	13000.00
0005432267887	1487	Economy	13000.00
0005434374605	1487	Economy	13000.00
0005433151163	1487	Economy	13000.00
0005433151046	1487	Economy	13000.00
0005433151159	1487	Economy	13000.00
0005434374626	1487	Economy	13000.00
0005433461587	1487	Economy	13000.00
0005433151108	1487	Economy	14300.00
0005433151117	1487	Economy	13000.00
0005434374616	1487	Economy	14300.00
0005433460433	1487	Economy	14300.00
0005433151113	1487	Economy	14300.00
0005433151162	1487	Economy	13000.00
0005434374615	1487	Economy	14300.00
0005433151082	1487	Economy	13000.00
0005434374630	1487	Economy	13000.00
0005433151030	1487	Economy	13000.00
0005433151029	1487	Economy	13000.00
0005434029622	1487	Economy	13000.00
0005433151194	1487	Economy	13000.00
0005433151141	1487	Economy	13000.00
0005433151122	1487	Economy	13000.00
0005433931438	1487	Economy	13000.00
0005434029629	1487	Economy	13000.00
0005434374612	1487	Economy	13000.00
0005433151222	1487	Economy	13000.00
0005433151158	1487	Economy	13000.00
0005433151112	1487	Economy	13000.00
0005433151140	1487	Economy	13000.00
0005433151068	1487	Economy	13000.00
0005433151135	1487	Economy	13000.00
0005434374609	1487	Economy	13000.00
0005433151212	1487	Economy	13000.00
0005434374614	1487	Economy	13000.00
0005433151142	1487	Economy	13000.00
0005434374621	1487	Economy	13000.00
0005434374607	1487	Economy	13000.00
0005433151224	1487	Economy	13000.00
0005433151160	1487	Economy	13000.00
0005433151097	1487	Economy	13000.00
0005434029624	1487	Economy	13000.00
0005432267888	1487	Economy	13000.00
0005434374608	1487	Economy	13000.00
0005434374618	1487	Economy	13000.00
0005433764659	1487	Economy	13000.00
0005433151165	1487	Economy	13000.00
0005433151174	1487	Economy	13000.00
0005433151205	1487	Economy	13000.00
0005434374625	1487	Economy	13000.00
0005433151015	1487	Economy	13000.00
0005433461585	1487	Economy	13000.00
0005434374606	1487	Economy	13000.00
0005434374633	1487	Economy	13000.00
0005432267890	1487	Economy	13000.00
0005434029623	1487	Economy	13000.00
0005433151034	1487	Economy	13000.00
0005434374624	1487	Economy	13000.00
0005433151095	1487	Economy	13000.00
0005433931432	1487	Economy	13000.00
0005433460434	1487	Economy	13000.00
0005433151087	1487	Economy	13000.00
0005433151014	1487	Economy	13000.00
0005433151088	1487	Economy	13000.00
0005433151269	1487	Economy	13000.00
0005432267891	1487	Economy	13000.00
0005434029625	1487	Economy	13000.00
0005433931429	1487	Economy	13000.00
0005434029628	1487	Economy	13000.00
0005434374119	20149	Business	38900.00
0005434374045	20149	Business	38900.00
0005433151372	20149	Business	38900.00
0005434374250	20149	Business	38900.00
0005433151389	20149	Business	38900.00
0005434374232	20149	Business	38900.00
0005434374163	20149	Business	38900.00
0005433151357	20149	Business	38900.00
0005434374169	20149	Business	38900.00
0005433151359	20149	Economy	13000.00
0005433151362	20149	Economy	13000.00
0005433151381	20149	Economy	13000.00
0005434374351	20149	Economy	13000.00
0005434374090	20149	Economy	13000.00
0005433151383	20149	Economy	13000.00
0005433151366	20149	Economy	13000.00
0005434374325	20149	Economy	13000.00
0005433151371	20149	Economy	13000.00
0005434374205	20149	Economy	13000.00
0005433151363	20149	Economy	13000.00
0005434374283	20149	Economy	13000.00
0005433931461	20149	Economy	13000.00
0005434374361	20149	Economy	13000.00
0005433931463	20149	Economy	13000.00
0005434374275	20149	Economy	13000.00
0005433151379	20149	Economy	13000.00
0005434029656	20149	Economy	13000.00
0005434374233	20149	Economy	13000.00
0005433151365	20149	Economy	13000.00
0005433151364	20149	Economy	13000.00
0005434374352	20149	Economy	13000.00
0005433151370	20149	Economy	13000.00
0005434374128	20149	Economy	14300.00
0005434374065	20149	Economy	14300.00
0005434374129	20149	Economy	14300.00
0005433151376	20149	Economy	14300.00
0005434374172	20149	Economy	14300.00
0005434374251	20149	Economy	13000.00
0005434374003	20149	Economy	13000.00
0005434374190	20149	Economy	13000.00
0005433151375	20149	Economy	13000.00
0005433151373	20149	Economy	13000.00
0005434374284	20149	Economy	13000.00
0005432056294	20149	Economy	13000.00
0005433151386	20149	Economy	13000.00
0005433931460	20149	Economy	13000.00
0005434374274	20149	Economy	13000.00
0005434374095	20149	Economy	13000.00
0005433151369	20149	Economy	13000.00
0005433151385	20149	Economy	13000.00
0005433151368	20149	Economy	13000.00
0005433764677	20149	Economy	13000.00
0005434374216	20149	Economy	13000.00
0005433151388	20149	Economy	13000.00
0005433151360	20149	Economy	13000.00
0005434029655	20149	Economy	13000.00
0005433151377	20149	Economy	13000.00
0005434374120	20149	Economy	13000.00
0005433151361	20149	Economy	13000.00
0005434374204	20149	Economy	13000.00
0005433764678	20149	Economy	13000.00
0005433151367	20149	Economy	13000.00
0005433151380	20149	Economy	13000.00
0005433151390	20149	Economy	13000.00
0005434029654	20149	Economy	13000.00
0005434374244	20149	Economy	13000.00
0005434374287	20149	Economy	13000.00
0005434374203	20149	Economy	13000.00
0005432056293	20149	Economy	13000.00
0005434374339	20149	Economy	13000.00
0005432056295	20149	Economy	13000.00
0005433764679	20149	Economy	13000.00
0005433151387	20149	Economy	13000.00
0005433151374	20149	Economy	13000.00
0005434374285	20149	Economy	13000.00
0005434374255	20149	Economy	13000.00
0005434374212	20149	Economy	13000.00
0005433151382	20149	Economy	13000.00
0005434374229	20149	Economy	13000.00
0005432056296	20149	Economy	13000.00
0005434374256	20149	Economy	13000.00
0005433151358	20149	Economy	13000.00
0005433151378	20149	Economy	13000.00
0005434374282	20149	Economy	13000.00
0005434374228	20149	Economy	13000.00
0005434374307	20149	Economy	13000.00
0005434374362	20149	Economy	13000.00
0005434374139	20149	Economy	13000.00
0005434374360	20149	Economy	13000.00
0005433151384	20149	Economy	13000.00
0005433931462	20149	Economy	13000.00
0005432424388	491	Business	27500.00
0005432282857	491	Business	27500.00
0005432424380	491	Business	27500.00
0005432424401	491	Business	27500.00
0005432424405	491	Business	27500.00
0005432424404	491	Business	27500.00
0005432424393	491	Business	27500.00
0005432424386	491	Business	27500.00
0005432424398	491	Economy	10100.00
0005432424378	491	Economy	10100.00
0005432424418	491	Economy	10100.00
0005432282860	491	Economy	9200.00
0005432424409	491	Economy	9200.00
0005432424379	491	Economy	9200.00
0005432424383	491	Economy	9200.00
0005432424407	491	Economy	9200.00
0005432282859	491	Economy	9200.00
0005432424419	491	Economy	9200.00
0005432424397	491	Economy	9200.00
0005432424408	491	Economy	9200.00
0005432424390	491	Economy	9200.00
0005432424384	491	Economy	9200.00
0005432424396	491	Economy	9200.00
0005432424410	491	Economy	9200.00
0005432424413	491	Economy	9200.00
0005432282854	491	Economy	9200.00
0005432424402	491	Economy	9200.00
0005432424421	491	Economy	9200.00
0005432424381	491	Economy	9200.00
0005432424416	491	Economy	10100.00
0005432424395	491	Economy	9200.00
0005432424392	491	Economy	10100.00
0005432424377	491	Economy	9200.00
0005432282856	491	Economy	9200.00
0005432424403	491	Economy	9200.00
0005432424406	491	Economy	9200.00
0005432424417	491	Economy	9200.00
0005432424400	491	Economy	9200.00
0005432424411	491	Economy	9200.00
0005432282858	491	Economy	9200.00
0005432424382	491	Economy	9200.00
0005432424414	491	Economy	9200.00
0005432282855	491	Economy	9200.00
0005432424415	491	Economy	9200.00
0005432424420	491	Economy	9200.00
0005432424376	491	Economy	9200.00
0005432424412	491	Economy	9200.00
0005432424385	491	Economy	9200.00
0005432424387	491	Economy	9200.00
0005432424389	491	Economy	9200.00
0005432424394	491	Economy	9200.00
0005432424399	491	Economy	9200.00
0005432424391	491	Economy	9200.00
0005434446501	12845	Business	27500.00
0005432302325	12845	Business	27500.00
0005433158128	12845	Economy	9200.00
0005432302327	12845	Economy	9200.00
0005434446490	12845	Economy	9200.00
0005433158130	12845	Economy	10100.00
0005433158129	12845	Economy	9200.00
0005432302328	12845	Economy	9200.00
0005432302326	12845	Economy	9200.00
0005432423705	12923	Business	27500.00
0005432424024	12923	Business	27500.00
0005432423998	12923	Business	27500.00
0005432423951	12923	Business	27500.00
0005432424001	12923	Business	27500.00
0005432423816	12923	Business	27500.00
0005432423952	12923	Business	27500.00
0005432423969	12923	Economy	10100.00
0005432423930	12923	Economy	10100.00
0005432423845	12923	Economy	9200.00
0005432423997	12923	Economy	9200.00
0005432423881	12923	Economy	9200.00
0005432423831	12923	Economy	9200.00
0005432423990	12923	Economy	9200.00
0005432423843	12923	Economy	9200.00
0005432423954	12923	Economy	9200.00
0005432423746	12923	Economy	9200.00
0005432423950	12923	Economy	9200.00
0005432423946	12923	Economy	9200.00
0005432423784	12923	Economy	9200.00
0005432424002	12923	Economy	9200.00
0005432423864	12923	Economy	9200.00
0005432423719	12923	Economy	9200.00
0005432424003	12923	Economy	9200.00
0005432423928	12923	Economy	9200.00
0005432424010	12923	Economy	9200.00
0005432423953	12923	Economy	9200.00
0005432423936	12923	Economy	9200.00
0005432423854	12923	Economy	9200.00
0005432423770	12923	Economy	9200.00
0005432424009	12923	Economy	9200.00
0005432423860	12923	Economy	9200.00
0005432423755	12923	Economy	9200.00
0005432423949	12923	Economy	9200.00
0005432423944	12923	Economy	9200.00
0005432424007	12923	Economy	10100.00
0005432423893	12923	Economy	10100.00
0005432423747	12923	Economy	9200.00
0005432423783	12923	Economy	9200.00
0005432423945	12923	Economy	9200.00
0005432423844	12923	Economy	9200.00
0005432423965	12923	Economy	9200.00
0005432423940	12923	Economy	9200.00
0005432423976	12923	Economy	9200.00
0005432423745	12923	Economy	9200.00
0005432423720	12923	Economy	9200.00
0005432423987	12923	Economy	9200.00
0005432423884	12923	Economy	9200.00
0005432423980	12923	Economy	9200.00
0005432423966	12923	Economy	9200.00
0005432423941	12923	Economy	9200.00
0005432423999	12923	Economy	9200.00
0005432423717	12923	Economy	9200.00
0005434023624	442	Business	24500.00
0005434023622	442	Business	24500.00
0005434029652	442	Business	24500.00
0005433057711	442	Business	24500.00
0005434023628	442	Business	24500.00
0005434023661	442	Business	24500.00
0005434023648	442	Business	24500.00
0005434023653	442	Business	24500.00
0005434023675	442	Business	24500.00
0005433057312	442	Business	24500.00
0005434032014	442	Business	24500.00
0005434029651	442	Business	24500.00
0005434023634	442	Business	24500.00
0005433057568	442	Business	24500.00
0005434023646	442	Business	24500.00
0005434028293	442	Business	24500.00
0005433057378	442	Business	24500.00
0005434023662	442	Business	24500.00
0005434023614	442	Business	24500.00
0005433057494	442	Business	24500.00
0005433057379	442	Economy	9000.00
0005434023627	442	Economy	9000.00
0005434023641	442	Economy	8200.00
0005433057542	442	Economy	8200.00
0005434023667	442	Economy	8200.00
0005433057589	442	Economy	8200.00
0005432235634	442	Economy	8200.00
0005433057563	442	Economy	8200.00
0005434029653	442	Economy	8200.00
0005433057751	442	Economy	8200.00
0005434023632	442	Economy	8200.00
0005434023636	442	Economy	8200.00
0005433057547	442	Economy	8200.00
0005434023630	442	Economy	8200.00
0005433057435	442	Economy	8200.00
0005434032017	442	Economy	8200.00
0005434023651	442	Economy	8200.00
0005434023647	442	Economy	8200.00
0005434023664	442	Economy	8200.00
0005434023635	442	Economy	8200.00
0005434023658	442	Economy	8200.00
0005434023665	442	Economy	8200.00
0005434023655	442	Economy	8200.00
0005434735611	442	Economy	8200.00
0005433057557	442	Economy	8200.00
0005434023676	442	Economy	8200.00
0005434023629	442	Economy	8200.00
0005433057446	442	Economy	8200.00
0005434023672	442	Economy	8200.00
0005434023652	442	Economy	8200.00
0005432235630	442	Economy	8200.00
0005434023649	442	Economy	8200.00
0005433057710	442	Economy	8200.00
0005434023645	442	Economy	8200.00
0005434735608	442	Economy	8200.00
0005434023621	442	Economy	8200.00
0005434032018	442	Economy	8200.00
0005433057386	442	Economy	8200.00
0005432235631	442	Economy	8200.00
0005434023650	442	Economy	8200.00
0005434023625	442	Economy	8200.00
0005434023679	442	Economy	8200.00
0005433057416	442	Economy	8200.00
0005434023674	442	Economy	8200.00
0005434023615	442	Economy	8200.00
0005433057695	442	Economy	8200.00
0005432235632	442	Economy	8200.00
0005434023659	442	Economy	8200.00
0005434735609	442	Economy	8200.00
0005434032015	442	Economy	8200.00
0005434023678	442	Economy	8200.00
0005434023620	442	Economy	8200.00
0005432235633	442	Economy	8200.00
0005434735633	442	Economy	8200.00
0005434023612	442	Economy	8200.00
0005433057664	442	Economy	8200.00
0005432045610	442	Economy	8200.00
0005433057449	442	Economy	8200.00
0005433057564	442	Economy	8200.00
0005434023610	442	Economy	8200.00
0005434023669	442	Economy	8200.00
0005434023657	442	Economy	8200.00
0005434023638	442	Economy	8200.00
0005433057663	442	Economy	8200.00
0005433929554	442	Economy	8200.00
0005434023626	442	Economy	9000.00
0005433057387	442	Economy	9000.00
0005433057543	442	Economy	8200.00
0005434023670	442	Economy	8200.00
0005433057512	442	Economy	8200.00
0005434023613	442	Economy	9000.00
0005434023660	442	Economy	8200.00
0005433057445	442	Economy	8200.00
0005434023656	442	Economy	8200.00
0005434028292	442	Economy	8200.00
0005433057480	442	Economy	8200.00
0005434735612	442	Economy	8200.00
0005433057588	442	Economy	8200.00
0005434735635	442	Economy	8200.00
0005434023618	442	Economy	8200.00
0005434023654	442	Economy	8200.00
0005432235627	442	Economy	8200.00
0005434023671	442	Economy	8200.00
0005433057593	442	Economy	8200.00
0005434023677	442	Economy	8200.00
0005434023644	442	Economy	8200.00
0005433057752	442	Economy	8200.00
0005434023617	442	Economy	8200.00
0005434023619	442	Economy	8200.00
0005434735623	442	Economy	8200.00
0005434023637	442	Economy	8200.00
0005433057648	442	Economy	8200.00
0005433057647	442	Economy	8200.00
0005433057546	442	Economy	8200.00
0005434023663	442	Economy	8200.00
0005434023616	442	Economy	8200.00
0005434023673	442	Economy	8200.00
0005433057519	442	Economy	8200.00
0005434023642	442	Economy	8200.00
0005434023611	442	Economy	8200.00
0005434735634	442	Economy	8200.00
0005434023643	442	Economy	8200.00
0005433057310	442	Economy	8200.00
0005434023639	442	Economy	8200.00
0005433057595	442	Economy	8200.00
0005434023640	442	Economy	8200.00
0005433057594	442	Economy	8200.00
0005433057520	442	Economy	8200.00
0005434032016	442	Economy	8200.00
0005433057467	442	Economy	8200.00
0005434735610	442	Economy	8200.00
0005434023623	442	Economy	8200.00
0005433057450	442	Economy	8200.00
0005433057628	442	Economy	8200.00
0005433057521	442	Economy	8200.00
0005432235629	442	Economy	8200.00
0005434023631	442	Economy	8200.00
0005434023668	442	Economy	8200.00
0005432235628	442	Economy	8200.00
0005434023633	442	Economy	8200.00
0005434028294	442	Economy	8200.00
0005434023666	442	Economy	8200.00
0005433057565	442	Economy	8200.00
0005434022968	12657	Business	24500.00
0005434023092	12657	Business	24500.00
0005434023270	12657	Business	24500.00
0005434735683	12657	Business	24500.00
0005434023218	12657	Business	24500.00
0005434022961	12657	Business	24500.00
0005433057846	12657	Business	24500.00
0005433057855	12657	Business	24500.00
0005434031986	12657	Business	24500.00
0005434023306	12657	Business	24500.00
0005433929608	12657	Business	24500.00
0005434022950	12657	Business	24500.00
0005434023323	12657	Business	24500.00
0005433057866	12657	Business	24500.00
0005434022899	12657	Business	24500.00
0005434023364	12657	Business	24500.00
0005434023055	12657	Business	24500.00
0005434023048	12657	Business	24500.00
0005434023108	12657	Business	24500.00
0005434031973	12657	Business	24500.00
0005433929610	12657	Business	24500.00
0005434023147	12657	Business	24500.00
0005434023235	12657	Business	24500.00
0005433057851	12657	Business	24500.00
0005433057840	12657	Economy	9000.00
0005434735686	12657	Economy	9000.00
0005434023247	12657	Economy	9000.00
0005434022946	12657	Economy	9000.00
0005434023027	12657	Economy	8200.00
0005434023050	12657	Economy	8200.00
0005434023025	12657	Economy	8200.00
0005433057849	12657	Economy	8200.00
0005434023180	12657	Economy	8200.00
0005434029624	12657	Economy	8200.00
0005434022927	12657	Economy	8200.00
0005434023109	12657	Economy	8200.00
0005434031976	12657	Economy	8200.00
0005434023240	12657	Economy	8200.00
0005434023132	12657	Economy	8200.00
0005433057836	12657	Economy	8200.00
0005434023129	12657	Economy	8200.00
0005434023278	12657	Economy	8200.00
0005434735685	12657	Economy	8200.00
0005433057848	12657	Economy	8200.00
0005434022801	12657	Economy	8200.00
0005434023179	12657	Economy	8200.00
0005434022967	12657	Economy	8200.00
0005434022918	12657	Economy	8200.00
0005434022951	12657	Economy	8200.00
0005434028263	12657	Economy	8200.00
0005434023008	12657	Economy	8200.00
0005433057828	12657	Economy	8200.00
0005434022998	12657	Economy	8200.00
0005434023099	12657	Economy	8200.00
0005433057863	12657	Economy	8200.00
0005433057857	12657	Economy	8200.00
0005434023200	12657	Economy	8200.00
0005434023399	12657	Economy	8200.00
0005433057845	12657	Economy	8200.00
0005434023114	12657	Economy	8200.00
0005433057832	12657	Economy	8200.00
0005434023028	12657	Economy	8200.00
0005434022944	12657	Economy	8200.00
0005434023236	12657	Economy	8200.00
0005434023133	12657	Economy	8200.00
0005434023110	12657	Economy	8200.00
0005434022926	12657	Economy	8200.00
0005434022759	12657	Economy	8200.00
0005434023089	12657	Economy	8200.00
0005434023093	12657	Economy	8200.00
0005434022758	12657	Economy	8200.00
0005434023227	12657	Economy	8200.00
0005434023094	12657	Economy	8200.00
0005433057837	12657	Economy	8200.00
0005434022919	12657	Economy	8200.00
0005433057847	12657	Economy	8200.00
0005433057843	12657	Economy	8200.00
0005434028268	12657	Economy	8200.00
0005434023303	12657	Economy	8200.00
0005433929609	12657	Economy	8200.00
0005433057829	12657	Economy	8200.00
0005434023023	12657	Economy	8200.00
0005434028269	12657	Economy	8200.00
0005433057853	12657	Economy	8200.00
0005434031977	12657	Economy	8200.00
0005434023042	12657	Economy	8200.00
0005432157489	12657	Economy	8200.00
0005434022879	12657	Economy	8200.00
0005434735687	12657	Economy	8200.00
0005434029621	12657	Economy	8200.00
0005433057842	12657	Economy	8200.00
0005432157490	12657	Economy	8200.00
0005432156361	12657	Economy	8200.00
0005433057831	12657	Economy	8200.00
0005434023140	12657	Economy	8200.00
0005433684420	12657	Economy	8200.00
0005433057835	12657	Economy	8200.00
0005434023226	12657	Economy	8200.00
0005434023398	12657	Economy	8200.00
0005434023105	12657	Economy	8200.00
0005434022958	12657	Economy	9000.00
0005434022945	12657	Economy	8200.00
0005433057827	12657	Economy	8200.00
0005433057852	12657	Economy	8200.00
0005434023163	12657	Economy	9000.00
0005434023056	12657	Economy	8200.00
0005432156363	12657	Economy	8200.00
0005434022809	12657	Economy	8200.00
0005434023305	12657	Economy	8200.00
0005433057859	12657	Economy	8200.00
0005434023195	12657	Economy	8200.00
0005434022799	12657	Economy	8200.00
0005434022878	12657	Economy	8200.00
0005432156362	12657	Economy	8200.00
0005433057841	12657	Economy	8200.00
0005434029629	12657	Economy	8200.00
0005433057830	12657	Economy	8200.00
0005434022800	12657	Economy	8200.00
0005433057860	12657	Economy	8200.00
0005433057833	12657	Economy	8200.00
0005433057838	12657	Economy	8200.00
0005434031970	12657	Economy	8200.00
0005434023237	12657	Economy	8200.00
0005434023077	12657	Economy	8200.00
0005432156359	12657	Economy	8200.00
0005434029622	12657	Economy	8200.00
0005433057854	12657	Economy	8200.00
0005434023024	12657	Economy	8200.00
0005434022625	12657	Economy	8200.00
0005434022783	12657	Economy	8200.00
0005434023241	12657	Economy	8200.00
0005434023049	12657	Economy	8200.00
0005434031972	12657	Economy	8200.00
0005434029625	12657	Economy	8200.00
0005433057864	12657	Economy	8200.00
0005434029628	12657	Economy	8200.00
0005434031962	12657	Economy	8200.00
0005433684419	12657	Economy	8200.00
0005433057850	12657	Economy	8200.00
0005434031963	12657	Economy	8200.00
0005434022784	12657	Economy	8200.00
0005433057834	12657	Economy	8200.00
0005433057865	12657	Economy	8200.00
0005434022939	12657	Economy	8200.00
0005434029623	12657	Economy	8200.00
0005433057862	12657	Economy	8200.00
0005434023034	12657	Economy	8200.00
0005434023279	12657	Economy	8200.00
0005434022818	12657	Economy	8200.00
0005434023246	12657	Economy	8200.00
0005434028270	12657	Economy	8200.00
0005432156360	12657	Economy	8200.00
0005433057839	12657	Economy	8200.00
0005433057844	12657	Economy	8200.00
0005434023026	12657	Economy	8200.00
0005434023148	12657	Economy	8200.00
0005434735684	12657	Economy	8200.00
0005434022992	12657	Economy	8200.00
0005434023100	12657	Economy	8200.00
0005433057856	12657	Economy	8200.00
0005434031959	12657	Economy	8200.00
0005434023146	12657	Economy	8200.00
0005434023145	12657	Economy	8200.00
0005433057867	12657	Economy	8200.00
0005433057861	12657	Economy	8200.00
0005433057858	12657	Economy	8200.00
0005433035750	2168	Business	34700.00
0005433923159	2168	Business	34700.00
0005433923174	2168	Business	34700.00
0005433923195	2168	Business	34700.00
0005433923223	2168	Business	34700.00
0005433923243	2168	Business	34700.00
0005433923241	2168	Business	34700.00
0005433035578	2168	Business	34700.00
0005433923247	2168	Business	34700.00
0005432231552	2168	Business	34700.00
0005433923197	2168	Business	34700.00
0005433923235	2168	Business	34700.00
0005433923217	2168	Business	34700.00
0005433923192	2168	Business	34700.00
0005433035719	2168	Business	34700.00
0005433035767	2168	Business	34700.00
0005433035794	2168	Business	34700.00
0005433035979	2168	Business	34700.00
0005433923218	2168	Business	34700.00
0005433035763	2168	Business	34700.00
0005433931462	2168	Business	34700.00
0005433923181	2168	Business	34700.00
0005433035996	2168	Business	34700.00
0005433035766	2168	Business	34700.00
0005433923178	2168	Business	34700.00
0005433923176	2168	Business	34700.00
0005433923163	2168	Economy	12700.00
0005433035772	2168	Economy	12700.00
0005433923175	2168	Economy	12700.00
0005432231550	2168	Economy	12700.00
0005433923171	2168	Economy	11600.00
0005433923216	2168	Economy	11600.00
0005432231555	2168	Economy	11600.00
0005433923188	2168	Economy	11600.00
0005433035843	2168	Economy	11600.00
0005433923252	2168	Economy	11600.00
0005433923189	2168	Economy	11600.00
0005433929609	2168	Economy	11600.00
0005433035709	2168	Economy	11600.00
0005433035760	2168	Economy	11600.00
0005432231557	2168	Economy	11600.00
0005433923211	2168	Economy	11600.00
0005433875374	2168	Economy	11600.00
0005433923201	2168	Economy	11600.00
0005433923215	2168	Economy	11600.00
0005433036019	2168	Economy	11600.00
0005432231548	2168	Economy	11600.00
0005433923224	2168	Economy	11600.00
0005433923209	2168	Economy	11600.00
0005433035798	2168	Economy	11600.00
0005433923182	2168	Economy	11600.00
0005433923203	2168	Economy	11600.00
0005432231559	2168	Economy	11600.00
0005433923239	2168	Economy	11600.00
0005433036020	2168	Economy	11600.00
0005433923242	2168	Economy	11600.00
0005433931461	2168	Economy	11600.00
0005433923158	2168	Economy	11600.00
0005434028270	2168	Economy	11600.00
0005433035729	2168	Economy	11600.00
0005434028268	2168	Economy	11600.00
0005433923212	2168	Economy	11600.00
0005433923199	2168	Economy	11600.00
0005433923236	2168	Economy	11600.00
0005433923214	2168	Economy	11600.00
0005433923226	2168	Economy	11600.00
0005433923190	2168	Economy	11600.00
0005433923177	2168	Economy	11600.00
0005433923238	2168	Economy	11600.00
0005433923196	2168	Economy	11600.00
0005433035833	2168	Economy	11600.00
0005433035815	2168	Economy	11600.00
0005433923254	2168	Economy	11600.00
0005433923250	2168	Economy	11600.00
0005433923164	2168	Economy	11600.00
0005433923173	2168	Economy	11600.00
0005433035644	2168	Economy	11600.00
0005433923167	2168	Economy	11600.00
0005433035813	2168	Economy	11600.00
0005432231549	2168	Economy	11600.00
0005433931463	2168	Economy	11600.00
0005433035796	2168	Economy	11600.00
0005432044521	2168	Economy	11600.00
0005433035890	2168	Economy	11600.00
0005433931460	2168	Economy	11600.00
0005433035652	2168	Economy	11600.00
0005434028269	2168	Economy	11600.00
0005433929857	2168	Economy	11600.00
0005433923244	2168	Economy	11600.00
0005433923245	2168	Economy	11600.00
0005433035751	2168	Economy	11600.00
0005433923183	2168	Economy	11600.00
0005432231556	2168	Economy	11600.00
0005433035934	2168	Economy	11600.00
0005433929610	2168	Economy	11600.00
0005433923210	2168	Economy	11600.00
0005433035642	2168	Economy	11600.00
0005433923185	2168	Economy	11600.00
0005433923230	2168	Economy	11600.00
0005433923207	2168	Economy	11600.00
0005433923255	2168	Economy	11600.00
0005433923253	2168	Economy	11600.00
0005433923234	2168	Economy	11600.00
0005433923198	2168	Economy	11600.00
0005433923172	2168	Economy	11600.00
0005432231551	2168	Economy	11600.00
0005433875376	2168	Economy	11600.00
0005433035831	2168	Economy	11600.00
0005433923219	2168	Economy	11600.00
0005433923162	2168	Economy	11600.00
0005432749760	2168	Economy	11600.00
0005433923200	2168	Economy	11600.00
0005432044522	2168	Economy	11600.00
0005433923240	2168	Economy	11600.00
0005433923246	2168	Economy	11600.00
0005433923233	2168	Economy	11600.00
0005433035783	2168	Economy	11600.00
0005433035811	2168	Economy	12700.00
0005433923229	2168	Economy	12700.00
0005433035761	2168	Economy	11600.00
0005433923161	2168	Economy	11600.00
0005433923204	2168	Economy	11600.00
0005432749757	2168	Economy	12700.00
0005433035935	2168	Economy	12700.00
0005433035836	2168	Economy	11600.00
0005433035579	2168	Economy	11600.00
0005433035773	2168	Economy	11600.00
0005433035795	2168	Economy	11600.00
0005433035742	2168	Economy	11600.00
0005433923160	2168	Economy	11600.00
0005433035620	2168	Economy	11600.00
0005433035787	2168	Economy	11600.00
0005433923168	2168	Economy	11600.00
0005433929608	2168	Economy	11600.00
0005433035684	2168	Economy	11600.00
0005433035723	2168	Economy	11600.00
0005432231558	2168	Economy	11600.00
0005434028263	2168	Economy	11600.00
0005433923225	2168	Economy	11600.00
0005433875375	2168	Economy	11600.00
0005433923170	2168	Economy	11600.00
0005433923231	2168	Economy	11600.00
0005433923187	2168	Economy	11600.00
0005433035866	2168	Economy	11600.00
0005433035814	2168	Economy	11600.00
0005433035869	2168	Economy	11600.00
0005433036070	2168	Economy	11600.00
0005433923249	2168	Economy	11600.00
0005432749761	2168	Economy	11600.00
0005433923205	2168	Economy	11600.00
0005433923179	2168	Economy	11600.00
0005432231553	2168	Economy	11600.00
0005432231554	2168	Economy	11600.00
0005433035721	2168	Economy	11600.00
0005433035870	2168	Economy	11600.00
0005433035812	2168	Economy	11600.00
0005433923220	2168	Economy	11600.00
0005433923221	2168	Economy	11600.00
0005433035619	2168	Economy	11600.00
0005433035992	2168	Economy	11600.00
0005433035724	2168	Economy	11600.00
0005433923213	2168	Economy	11600.00
0005432044520	2168	Economy	11600.00
0005433923186	2168	Economy	11600.00
0005433923237	2168	Economy	11600.00
0005433035857	2168	Economy	11600.00
0005433923193	2168	Economy	11600.00
0005433035781	2168	Economy	11600.00
0005433036105	2168	Economy	11600.00
0005433923166	2168	Economy	11600.00
0005433923208	2168	Economy	11600.00
0005433035643	2168	Economy	11600.00
0005433035825	2168	Economy	11600.00
0005433923180	2168	Economy	11600.00
0005433923191	2168	Economy	11600.00
0005433923222	2168	Economy	11600.00
0005433923251	2168	Economy	11600.00
0005433923228	2168	Economy	11600.00
0005433923165	2168	Economy	11600.00
0005433035871	2168	Economy	11600.00
0005433923227	2168	Economy	11600.00
0005433923194	2168	Economy	11600.00
0005433923206	2168	Economy	11600.00
0005433035832	2168	Economy	11600.00
0005433035829	2168	Economy	11600.00
0005433923202	2168	Economy	11600.00
0005433035641	2168	Economy	11600.00
0005433923232	2168	Economy	11600.00
0005433923184	2168	Economy	11600.00
0005433035683	2168	Economy	11600.00
0005433923169	2168	Economy	11600.00
0005433035914	2168	Economy	11600.00
0005433923248	2168	Economy	11600.00
0005433922169	24103	Business	34700.00
0005433922716	24103	Business	34700.00
0005433036247	24103	Business	34700.00
0005433922499	24103	Business	34700.00
0005433036232	24103	Business	34700.00
0005433036228	24103	Business	34700.00
0005432206191	24103	Business	34700.00
0005433036226	24103	Business	34700.00
0005433036257	24103	Business	34700.00
0005433922897	24103	Business	34700.00
0005433922330	24103	Business	34700.00
0005433922303	24103	Business	34700.00
0005433922444	24103	Business	34700.00
0005432207659	24103	Business	34700.00
0005433922652	24103	Business	34700.00
0005433875369	24103	Business	34700.00
0005432206188	24103	Business	34700.00
0005433922300	24103	Business	34700.00
0005433922740	24103	Business	34700.00
0005433922110	24103	Business	34700.00
0005433036251	24103	Business	34700.00
0005433922627	24103	Business	34700.00
0005433921880	24103	Business	34700.00
0005433922393	24103	Business	34700.00
0005433922600	24103	Business	34700.00
0005433922276	24103	Economy	12700.00
0005433036238	24103	Economy	12700.00
0005433036221	24103	Economy	12700.00
0005433922480	24103	Economy	11600.00
0005433922605	24103	Economy	11600.00
0005433922377	24103	Economy	11600.00
0005433922297	24103	Economy	11600.00
0005433036233	24103	Economy	11600.00
0005433922443	24103	Economy	11600.00
0005433922465	24103	Economy	11600.00
0005433036258	24103	Economy	11600.00
0005433921982	24103	Economy	11600.00
0005433922309	24103	Economy	11600.00
0005433036224	24103	Economy	11600.00
0005433922304	24103	Economy	11600.00
0005433922197	24103	Economy	11600.00
0005433922356	24103	Economy	11600.00
0005433929574	24103	Economy	11600.00
0005433922829	24103	Economy	11600.00
0005432206189	24103	Economy	11600.00
0005433036227	24103	Economy	11600.00
0005433036262	24103	Economy	11600.00
0005433036225	24103	Economy	11600.00
0005433922018	24103	Economy	11600.00
0005433922413	24103	Economy	11600.00
0005433922299	24103	Economy	11600.00
0005433922558	24103	Economy	11600.00
0005433922648	24103	Economy	11600.00
0005433036240	24103	Economy	11600.00
0005433922170	24103	Economy	11600.00
0005433922580	24103	Economy	11600.00
0005433922011	24103	Economy	11600.00
0005433922666	24103	Economy	11600.00
0005433922394	24103	Economy	11600.00
0005433921796	24103	Economy	11600.00
0005433922198	24103	Economy	11600.00
0005432749783	24103	Economy	11600.00
0005433922421	24103	Economy	11600.00
0005433036263	24103	Economy	11600.00
0005433922481	24103	Economy	11600.00
0005432206187	24103	Economy	11600.00
0005433922390	24103	Economy	11600.00
0005433929588	24103	Economy	11600.00
0005433922271	24103	Economy	11600.00
0005433036223	24103	Economy	11600.00
0005433922266	24103	Economy	11600.00
0005433922582	24103	Economy	11600.00
0005433036268	24103	Economy	11600.00
0005433922642	24103	Economy	11600.00
0005433922512	24103	Economy	11600.00
0005433036264	24103	Economy	11600.00
0005433036273	24103	Economy	11600.00
0005433036267	24103	Economy	11600.00
0005433922725	24103	Economy	11600.00
0005433921795	24103	Economy	11600.00
0005433922581	24103	Economy	11600.00
0005433036242	24103	Economy	11600.00
0005433922366	24103	Economy	11600.00
0005433922448	24103	Economy	11600.00
0005432206190	24103	Economy	11600.00
0005433036231	24103	Economy	11600.00
0005432207660	24103	Economy	11600.00
0005433036249	24103	Economy	11600.00
0005433922308	24103	Economy	11600.00
0005433922331	24103	Economy	11600.00
0005433922109	24103	Economy	11600.00
0005433922376	24103	Economy	11600.00
0005433036252	24103	Economy	11600.00
0005433921819	24103	Economy	11600.00
0005433036253	24103	Economy	11600.00
0005433922626	24103	Economy	11600.00
0005433922896	24103	Economy	11600.00
0005433921820	24103	Economy	11600.00
0005432749782	24103	Economy	11600.00
0005433922482	24103	Economy	11600.00
0005433922610	24103	Economy	11600.00
0005433922483	24103	Economy	11600.00
0005433922665	24103	Economy	11600.00
0005433036236	24103	Economy	11600.00
0005433922156	24103	Economy	11600.00
0005433922559	24103	Economy	11600.00
0005433922673	24103	Economy	11600.00
0005433922708	24103	Economy	11600.00
0005433922355	24103	Economy	11600.00
0005433036248	24103	Economy	11600.00
0005433036241	24103	Economy	11600.00
0005433922579	24103	Economy	11600.00
0005433922707	24103	Economy	11600.00
0005433036239	24103	Economy	11600.00
0005433922054	24103	Economy	11600.00
0005433922196	24103	Economy	12700.00
0005433036269	24103	Economy	12700.00
0005433036235	24103	Economy	11600.00
0005433922828	24103	Economy	11600.00
0005433036245	24103	Economy	12700.00
0005433922672	24103	Economy	11600.00
0005433922424	24103	Economy	11600.00
0005433036243	24103	Economy	11600.00
0005433922647	24103	Economy	11600.00
0005433036230	24103	Economy	11600.00
0005433922562	24103	Economy	11600.00
0005433922199	24103	Economy	11600.00
0005433036266	24103	Economy	11600.00
0005433922168	24103	Economy	11600.00
0005433921914	24103	Economy	11600.00
0005433922341	24103	Economy	11600.00
0005433036234	24103	Economy	11600.00
0005433922599	24103	Economy	11600.00
0005433036271	24103	Economy	11600.00
0005433922409	24103	Economy	11600.00
0005433922294	24103	Economy	11600.00
0005433922214	24103	Economy	11600.00
0005433036261	24103	Economy	11600.00
0005433922019	24103	Economy	11600.00
0005433036259	24103	Economy	11600.00
0005433036237	24103	Economy	11600.00
0005433929573	24103	Economy	11600.00
0005433922047	24103	Economy	11600.00
0005433922714	24103	Economy	11600.00
0005433922644	24103	Economy	11600.00
0005433036244	24103	Economy	11600.00
0005433922715	24103	Economy	11600.00
0005433036270	24103	Economy	11600.00
0005433921778	24103	Economy	11600.00
0005433922302	24103	Economy	11600.00
0005433036222	24103	Economy	11600.00
0005433922528	24103	Economy	11600.00
0005433036254	24103	Economy	11600.00
0005433922041	24103	Economy	11600.00
0005433875368	24103	Economy	11600.00
0005433922452	24103	Economy	11600.00
0005433036250	24103	Economy	11600.00
0005433036272	24103	Economy	11600.00
0005433922296	24103	Economy	11600.00
0005433922340	24103	Economy	11600.00
0005433922332	24103	Economy	11600.00
0005433922466	24103	Economy	11600.00
0005433922484	24103	Economy	11600.00
0005433931436	24103	Economy	11600.00
0005433922248	24103	Economy	11600.00
0005433036255	24103	Economy	11600.00
0005433922277	24103	Economy	11600.00
0005433922252	24103	Economy	11600.00
0005432206192	24103	Economy	11600.00
0005433036229	24103	Economy	11600.00
0005433036256	24103	Economy	11600.00
0005433922265	24103	Economy	11600.00
0005433036246	24103	Economy	11600.00
0005433922369	24103	Economy	11600.00
0005433922695	24103	Economy	11600.00
0005433922479	24103	Economy	11600.00
0005433922363	24103	Economy	11600.00
0005433922401	24103	Economy	11600.00
0005433922383	24103	Economy	11600.00
0005433921766	24103	Economy	11600.00
0005433922531	24103	Economy	11600.00
0005433922496	24103	Economy	11600.00
0005433036265	24103	Economy	11600.00
0005433922437	24103	Economy	11600.00
0005433036260	24103	Economy	11600.00
0005433922402	24103	Economy	11600.00
0005433922336	24103	Economy	11600.00
0005433922378	24103	Economy	11600.00
0005433111474	273	Business	83700.00
0005434551176	273	Business	83700.00
0005433233361	273	Business	83700.00
0005433233677	273	Business	83700.00
0005434725395	273	Business	83700.00
0005433233765	273	Business	83700.00
0005433233565	273	Business	83700.00
0005434725374	273	Business	83700.00
0005434725311	273	Business	83700.00
0005433233655	273	Business	83700.00
0005434725386	273	Business	83700.00
0005433180911	273	Business	83700.00
0005434725367	273	Business	83700.00
0005433126788	273	Business	83700.00
0005434725379	273	Business	83700.00
0005433233445	273	Business	83700.00
0005434725318	273	Business	83700.00
0005434725296	273	Business	83700.00
0005434725349	273	Business	83700.00
0005433180820	273	Business	83700.00
0005434725414	273	Business	83700.00
0005435142560	273	Business	83700.00
0005433111475	273	Business	83700.00
0005433233813	273	Business	83700.00
0005434551207	273	Comfort	47400.00
0005434725415	273	Business	83700.00
0005434725335	273	Comfort	47400.00
0005433233644	273	Comfort	47400.00
0005434725305	273	Comfort	47400.00
0005433233422	273	Comfort	47400.00
0005434551182	273	Comfort	47400.00
0005434551194	273	Comfort	47400.00
0005434725371	273	Comfort	47400.00
0005434725327	273	Comfort	47400.00
0005434551156	273	Comfort	47400.00
0005434551192	273	Comfort	47400.00
0005433233779	273	Comfort	47400.00
0005434551169	273	Comfort	47400.00
0005433126772	273	Comfort	47400.00
0005434551197	273	Comfort	47400.00
0005434725389	273	Comfort	47400.00
0005434551191	273	Comfort	47400.00
0005433111480	273	Comfort	47400.00
0005433766580	273	Comfort	47400.00
0005434725322	273	Comfort	47400.00
0005434031978	273	Comfort	47400.00
0005433233172	273	Comfort	47400.00
0005434725337	273	Comfort	47400.00
0005433131678	273	Comfort	47400.00
0005434725397	273	Comfort	47400.00
0005434725364	273	Comfort	47400.00
0005434725294	273	Comfort	47400.00
0005434551178	273	Comfort	47400.00
0005433180804	273	Comfort	47400.00
0005433233778	273	Comfort	47400.00
0005433233691	273	Comfort	47400.00
0005434725406	273	Comfort	47400.00
0005432277792	273	Comfort	47400.00
0005434725336	273	Comfort	47400.00
0005434731164	273	Comfort	47400.00
0005433233494	273	Comfort	47400.00
0005434725340	273	Comfort	47400.00
0005434551208	273	Comfort	47400.00
0005434725295	273	Comfort	47400.00
0005434551203	273	Economy	27900.00
0005434551189	273	Economy	27900.00
0005434725410	273	Economy	27900.00
0005434551211	273	Economy	27900.00
0005433126790	273	Economy	27900.00
0005434735682	273	Economy	27900.00
0005434725383	273	Economy	27900.00
0005434725344	273	Economy	27900.00
0005434551166	273	Economy	27900.00
0005434731162	273	Economy	27900.00
0005433180893	273	Economy	27900.00
0005432277790	273	Economy	27900.00
0005435142559	273	Economy	27900.00
0005434725408	273	Economy	27900.00
0005433180788	273	Economy	27900.00
0005433233569	273	Economy	27900.00
0005434725315	273	Economy	27900.00
0005433233679	273	Economy	27900.00
0005434725307	273	Economy	27900.00
0005433131679	273	Economy	27900.00
0005433233773	273	Economy	27900.00
0005433233656	273	Economy	27900.00
0005434725357	273	Economy	27900.00
0005434551209	273	Economy	27900.00
0005433113510	273	Economy	27900.00
0005432277799	273	Economy	27900.00
0005434725332	273	Economy	27900.00
0005434725323	273	Economy	27900.00
0005434551162	273	Economy	27900.00
0005433233500	273	Economy	27900.00
0005433766595	273	Economy	27900.00
0005434551198	273	Economy	27900.00
0005433180829	273	Economy	27900.00
0005433233594	273	Economy	27900.00
0005433233570	273	Economy	27900.00
0005434725393	273	Economy	27900.00
0005434551186	273	Economy	27900.00
0005434725331	273	Economy	27900.00
0005434725330	273	Economy	27900.00
0005433233531	273	Economy	27900.00
0005434725369	273	Economy	27900.00
0005433180817	273	Economy	27900.00
0005432277791	273	Economy	27900.00
0005434735680	273	Economy	27900.00
0005434725350	273	Economy	27900.00
0005434725366	273	Economy	27900.00
0005434551175	273	Economy	27900.00
0005434551157	273	Economy	27900.00
0005433233496	273	Economy	27900.00
0005432277794	273	Economy	27900.00
0005434735679	273	Economy	27900.00
0005434725301	273	Economy	27900.00
0005435142557	273	Economy	27900.00
0005434725299	273	Economy	27900.00
0005434725302	273	Economy	27900.00
0005433126789	273	Economy	27900.00
0005434731163	273	Economy	27900.00
0005434725400	273	Economy	27900.00
0005434551173	273	Economy	27900.00
0005434725300	273	Economy	27900.00
0005434735678	273	Economy	27900.00
0005434551190	273	Economy	27900.00
0005434725308	273	Economy	27900.00
0005434725298	273	Economy	30700.00
0005434725413	273	Economy	30700.00
0005433180834	273	Economy	27900.00
0005434725319	273	Economy	27900.00
0005434725362	273	Economy	27900.00
0005434725351	273	Economy	30700.00
0005435142568	273	Economy	27900.00
0005434725378	273	Economy	30700.00
0005434725325	273	Economy	27900.00
0005433233418	273	Economy	30700.00
0005434725380	273	Economy	27900.00
0005434725398	273	Economy	27900.00
0005433766604	273	Economy	27900.00
0005434725382	273	Economy	27900.00
0005433180837	273	Economy	27900.00
0005434735681	273	Economy	27900.00
0005434551165	273	Economy	27900.00
0005434551167	273	Economy	27900.00
0005434725358	273	Economy	27900.00
0005434551185	273	Economy	27900.00
0005434031979	273	Economy	27900.00
0005433180894	273	Economy	27900.00
0005432277797	273	Economy	27900.00
0005435142565	273	Economy	27900.00
0005433233499	273	Economy	27900.00
0005433233342	273	Economy	27900.00
0005435142567	273	Economy	27900.00
0005433233536	273	Economy	27900.00
0005434551204	273	Economy	27900.00
0005434725412	273	Economy	27900.00
0005434302869	273	Economy	27900.00
0005433233692	273	Economy	27900.00
0005435142569	273	Economy	27900.00
0005434725297	273	Economy	27900.00
0005434725329	273	Economy	27900.00
0005434725333	273	Economy	27900.00
0005434725338	273	Economy	27900.00
0005433233742	273	Economy	27900.00
0005434551177	273	Economy	27900.00
0005434551205	273	Economy	27900.00
0005433180912	273	Economy	27900.00
0005434302453	273	Economy	27900.00
0005434725399	273	Economy	27900.00
0005433233481	273	Economy	27900.00
0005433233913	273	Economy	27900.00
0005434731161	273	Economy	27900.00
0005434725370	273	Economy	27900.00
0005433233841	273	Economy	27900.00
0005432277802	273	Economy	27900.00
0005433233835	273	Economy	27900.00
0005433233559	273	Economy	27900.00
0005434031964	273	Economy	27900.00
0005434725328	273	Economy	27900.00
0005433233495	273	Economy	27900.00
0005434551159	273	Economy	27900.00
0005434725416	273	Economy	27900.00
0005432277798	273	Economy	27900.00
0005434551206	273	Economy	27900.00
0005434302456	273	Economy	27900.00
0005434725341	273	Economy	27900.00
0005435142558	273	Economy	27900.00
0005433233451	273	Economy	27900.00
0005434551170	273	Economy	27900.00
0005434725403	273	Economy	27900.00
0005432277795	273	Economy	27900.00
0005433180819	273	Economy	27900.00
0005433111479	273	Economy	27900.00
0005433233621	273	Economy	27900.00
0005434551158	273	Economy	27900.00
0005435142561	273	Economy	27900.00
0005433180784	273	Economy	27900.00
0005433766579	273	Economy	27900.00
0005434725377	273	Economy	27900.00
0005433126793	273	Economy	27900.00
0005433126773	273	Economy	27900.00
0005433766603	273	Economy	27900.00
0005435142566	273	Economy	27900.00
0005434725381	273	Economy	27900.00
0005434725347	273	Economy	27900.00
0005433233614	273	Economy	27900.00
0005433233912	273	Economy	27900.00
0005434725372	273	Economy	27900.00
0005434551164	273	Economy	27900.00
0005433233579	273	Economy	27900.00
0005433233645	273	Economy	27900.00
0005434725396	273	Economy	27900.00
0005435142563	273	Economy	27900.00
0005433233586	273	Economy	27900.00
0005434725365	273	Economy	27900.00
0005434551193	273	Economy	27900.00
0005434551200	273	Economy	27900.00
0005434725317	273	Economy	27900.00
0005433233530	273	Economy	27900.00
0005434551184	273	Economy	27900.00
0005434731165	273	Economy	27900.00
0005434725376	273	Economy	27900.00
0005434302872	273	Economy	27900.00
0005434725343	273	Economy	27900.00
0005434302457	273	Economy	27900.00
0005433233741	273	Economy	27900.00
0005434725355	273	Economy	27900.00
0005434725368	273	Economy	27900.00
0005434551199	273	Economy	27900.00
0005434302455	273	Economy	27900.00
0005434725304	273	Economy	27900.00
0005434725404	273	Economy	27900.00
0005434725409	273	Economy	27900.00
0005434551168	273	Economy	27900.00
0005435142570	273	Economy	27900.00
0005434725361	273	Economy	27900.00
0005434725405	273	Economy	27900.00
0005433233632	273	Economy	27900.00
0005433233842	273	Economy	27900.00
0005433233343	273	Economy	27900.00
0005434725401	273	Economy	27900.00
0005434725390	273	Economy	30700.00
0005434725314	273	Economy	30700.00
0005434551196	273	Economy	30700.00
0005434551172	273	Economy	30700.00
0005433180773	273	Economy	30700.00
0005434551180	273	Economy	27900.00
0005433180841	273	Economy	27900.00
0005433126792	273	Economy	27900.00
0005434551161	273	Economy	27900.00
0005434725356	273	Economy	27900.00
0005433233537	273	Economy	27900.00
0005433233508	273	Economy	27900.00
0005433233749	273	Economy	27900.00
0005433233557	273	Economy	27900.00
0005434725342	273	Economy	27900.00
0005434725363	273	Economy	27900.00
0005433233674	273	Economy	27900.00
0005434551163	273	Economy	27900.00
0005434551210	273	Economy	27900.00
0005434551171	273	Economy	27900.00
0005433233639	273	Economy	27900.00
0005434725392	273	Economy	27900.00
0005434725313	273	Economy	27900.00
0005434725384	273	Economy	27900.00
0005434302454	273	Economy	27900.00
0005434725359	273	Economy	27900.00
0005433233379	273	Economy	27900.00
0005434551181	273	Economy	27900.00
0005434551202	273	Economy	27900.00
0005434725321	273	Economy	27900.00
0005432277801	273	Economy	27900.00
0005434725324	273	Economy	27900.00
0005434725303	273	Economy	27900.00
0005434551195	273	Economy	27900.00
0005434725352	273	Economy	27900.00
0005433180818	273	Economy	27900.00
0005433233560	273	Economy	27900.00
0005432277800	273	Economy	27900.00
0005434725310	273	Economy	27900.00
0005434725326	273	Economy	27900.00
0005434302871	273	Economy	27900.00
0005433233638	273	Economy	27900.00
0005434725345	273	Economy	27900.00
0005435142562	273	Economy	27900.00
0005434551174	273	Economy	27900.00
0005432277796	273	Economy	27900.00
0005434031980	273	Economy	27900.00
0005434725346	273	Economy	27900.00
0005434725353	273	Economy	27900.00
0005434725316	273	Economy	27900.00
0005434551188	273	Economy	27900.00
0005433233814	273	Economy	27900.00
0005433180883	273	Economy	27900.00
0005434725388	273	Economy	27900.00
0005434725334	273	Economy	27900.00
0005433766581	273	Economy	27900.00
0005434725387	273	Economy	27900.00
0005433766605	273	Economy	27900.00
0005433233473	273	Economy	27900.00
0005433233705	273	Economy	27900.00
0005434551179	273	Economy	27900.00
0005434725339	273	Economy	27900.00
0005434551201	273	Economy	27900.00
0005434551183	273	Economy	27900.00
0005433180836	273	Economy	27900.00
0005433180886	273	Economy	27900.00
0005434725391	273	Economy	27900.00
0005433180835	273	Economy	27900.00
0005434725312	273	Economy	27900.00
0005433233789	273	Economy	27900.00
0005435142564	273	Economy	27900.00
0005434725385	273	Economy	27900.00
0005433180840	273	Economy	27900.00
0005434725411	273	Economy	27900.00
0005433233558	273	Economy	27900.00
0005434725293	273	Economy	27900.00
0005432277793	273	Economy	27900.00
0005433180799	273	Economy	27900.00
0005434725394	273	Economy	27900.00
0005434725407	273	Economy	27900.00
0005434725360	273	Economy	27900.00
0005434725375	273	Economy	27900.00
0005434725373	273	Economy	27900.00
0005434551187	273	Economy	27900.00
0005434725306	273	Economy	27900.00
0005434551160	273	Economy	27900.00
0005434725402	273	Economy	27900.00
0005434725309	273	Economy	27900.00
0005433131645	273	Economy	27900.00
0005434302870	273	Economy	27900.00
0005434725354	273	Economy	27900.00
0005434725320	273	Economy	27900.00
0005434725348	273	Economy	27900.00
0005433234157	9821	Business	83700.00
0005434550512	9821	Business	83700.00
0005434724092	9821	Business	83700.00
0005434724402	9821	Business	83700.00
0005433234138	9821	Business	83700.00
0005434724351	9821	Business	83700.00
0005433181066	9821	Business	83700.00
0005433181075	9821	Business	83700.00
0005434550779	9821	Business	83700.00
0005434723769	9821	Business	83700.00
0005433234152	9821	Business	83700.00
0005434724626	9821	Business	83700.00
0005434724200	9821	Business	83700.00
0005433181069	9821	Business	83700.00
0005434550770	9821	Business	83700.00
0005434724409	9821	Business	83700.00
0005433289840	9821	Business	83700.00
0005434725012	9821	Business	83700.00
0005433181062	9821	Business	83700.00
0005434724293	9821	Business	83700.00
0005433234129	9821	Business	83700.00
0005434724093	9821	Business	83700.00
0005434735630	9821	Business	83700.00
0005434724071	9821	Business	83700.00
0005433181073	9821	Business	83700.00
0005433234128	9821	Business	83700.00
0005434550789	9821	Business	83700.00
0005434724307	9821	Comfort	47400.00
0005433181081	9821	Comfort	47400.00
0005434724318	9821	Comfort	47400.00
0005434724608	9821	Comfort	47400.00
0005433129268	9821	Comfort	47400.00
0005434550653	9821	Comfort	47400.00
0005434724284	9821	Comfort	47400.00
0005433234113	9821	Comfort	47400.00
0005434724557	9821	Comfort	47400.00
0005433234150	9821	Comfort	47400.00
0005434550847	9821	Comfort	47400.00
0005434724344	9821	Comfort	47400.00
0005434032020	9821	Comfort	47400.00
0005434724268	9821	Comfort	47400.00
0005434723734	9821	Comfort	47400.00
0005435142443	9821	Comfort	47400.00
0005434724146	9821	Comfort	47400.00
0005433766635	9821	Comfort	47400.00
0005434723893	9821	Comfort	47400.00
0005434724059	9821	Comfort	47400.00
0005434724114	9821	Comfort	47400.00
0005434724508	9821	Comfort	47400.00
0005433234162	9821	Comfort	47400.00
0005433234164	9821	Comfort	47400.00
0005434724494	9821	Comfort	47400.00
0005434724720	9821	Comfort	47400.00
0005434724223	9821	Comfort	47400.00
0005434724611	9821	Comfort	47400.00
0005434550443	9821	Comfort	47400.00
0005434724103	9821	Comfort	47400.00
0005433181064	9821	Comfort	47400.00
0005434724754	9821	Comfort	47400.00
0005434550815	9821	Comfort	47400.00
0005434724958	9821	Comfort	47400.00
0005433181076	9821	Comfort	47400.00
0005433234169	9821	Comfort	47400.00
0005433234173	9821	Comfort	47400.00
0005435142446	9821	Comfort	47400.00
0005435142455	9821	Comfort	47400.00
0005434724718	9821	Economy	27900.00
0005433234130	9821	Economy	27900.00
0005434550544	9821	Economy	27900.00
0005433234134	9821	Economy	27900.00
0005434550684	9821	Economy	27900.00
0005434550771	9821	Economy	27900.00
0005433234167	9821	Economy	27900.00
0005433234137	9821	Economy	27900.00
0005433126839	9821	Economy	27900.00
0005433181070	9821	Economy	27900.00
0005433129269	9821	Economy	27900.00
0005434735617	9821	Economy	27900.00
0005434724421	9821	Economy	27900.00
0005434731123	9821	Economy	27900.00
0005434724478	9821	Economy	27900.00
0005435142405	9821	Economy	27900.00
0005434723740	9821	Economy	27900.00
0005434724354	9821	Economy	27900.00
0005434032022	9821	Economy	27900.00
0005434302408	9821	Economy	27900.00
0005434550635	9821	Economy	27900.00
0005434724100	9821	Economy	27900.00
0005434550665	9821	Economy	27900.00
0005434550759	9821	Economy	27900.00
0005434550852	9821	Economy	27900.00
0005434724112	9821	Economy	27900.00
0005433181078	9821	Economy	27900.00
0005433129272	9821	Economy	27900.00
0005433234140	9821	Economy	27900.00
0005434550668	9821	Economy	27900.00
0005434735622	9821	Economy	27900.00
0005434550614	9821	Economy	27900.00
0005434550672	9821	Economy	27900.00
0005434724044	9821	Economy	27900.00
0005433234122	9821	Economy	27900.00
0005434550447	9821	Economy	27900.00
0005434550641	9821	Economy	27900.00
0005434550694	9821	Economy	27900.00
0005434724960	9821	Economy	27900.00
0005434724102	9821	Economy	27900.00
0005434724332	9821	Economy	27900.00
0005434724422	9821	Economy	27900.00
0005434724299	9821	Economy	27900.00
0005434724272	9821	Economy	27900.00
0005434724927	9821	Economy	27900.00
0005435142454	9821	Economy	27900.00
0005434550667	9821	Economy	27900.00
0005433234171	9821	Economy	27900.00
0005433234121	9821	Economy	27900.00
0005434724457	9821	Economy	27900.00
0005434724406	9821	Economy	27900.00
0005434723798	9821	Economy	27900.00
0005435142420	9821	Economy	27900.00
0005432199241	9821	Economy	27900.00
0005434724292	9821	Economy	27900.00
0005434724612	9821	Economy	27900.00
0005434724115	9821	Economy	27900.00
0005434735641	9821	Economy	27900.00
0005433181067	9821	Economy	27900.00
0005434724417	9821	Economy	27900.00
0005434724598	9821	Economy	27900.00
0005432199243	9821	Economy	27900.00
0005434724230	9821	Economy	27900.00
0005434724696	9821	Economy	27900.00
0005434724168	9821	Economy	27900.00
0005433181084	9821	Economy	30700.00
0005434724330	9821	Economy	30700.00
0005432199244	9821	Economy	30700.00
0005434724298	9821	Economy	27900.00
0005433234160	9821	Economy	27900.00
0005433234135	9821	Economy	30700.00
0005432199242	9821	Economy	27900.00
0005435142445	9821	Economy	30700.00
0005434724053	9821	Economy	27900.00
0005432199237	9821	Economy	30700.00
0005433234141	9821	Economy	27900.00
0005434724488	9821	Economy	27900.00
0005434550683	9821	Economy	27900.00
0005433234155	9821	Economy	27900.00
0005434724404	9821	Economy	27900.00
0005433234125	9821	Economy	27900.00
0005433181068	9821	Economy	27900.00
0005434724648	9821	Economy	27900.00
0005434724247	9821	Economy	27900.00
0005434550758	9821	Economy	27900.00
0005433181079	9821	Economy	27900.00
0005433234114	9821	Economy	27900.00
0005434724667	9821	Economy	27900.00
0005434550393	9821	Economy	27900.00
0005434724095	9821	Economy	27900.00
0005433126840	9821	Economy	27900.00
0005434724027	9821	Economy	27900.00
0005434724275	9821	Economy	27900.00
0005434550482	9821	Economy	27900.00
0005434723731	9821	Economy	27900.00
0005433234116	9821	Economy	27900.00
0005432199238	9821	Economy	27900.00
0005433234156	9821	Economy	27900.00
0005434724499	9821	Economy	27900.00
0005434550926	9821	Economy	27900.00
0005433181077	9821	Economy	27900.00
0005433289837	9821	Economy	27900.00
0005433234165	9821	Economy	27900.00
0005434724368	9821	Economy	27900.00
0005433234149	9821	Economy	27900.00
0005433126841	9821	Economy	27900.00
0005433234142	9821	Economy	27900.00
0005434724384	9821	Economy	27900.00
0005433289836	9821	Economy	27900.00
0005434723951	9821	Economy	27900.00
0005433289843	9821	Economy	27900.00
0005434724324	9821	Economy	27900.00
0005434724273	9821	Economy	27900.00
0005434723688	9821	Economy	27900.00
0005434724269	9821	Economy	27900.00
0005433234170	9821	Economy	27900.00
0005434731124	9821	Economy	27900.00
0005433181071	9821	Economy	27900.00
0005434724469	9821	Economy	27900.00
0005433126838	9821	Economy	27900.00
0005434724197	9821	Economy	27900.00
0005433234161	9821	Economy	27900.00
0005434724390	9821	Economy	27900.00
0005434724319	9821	Economy	27900.00
0005434724352	9821	Economy	27900.00
0005434724205	9821	Economy	27900.00
0005434724437	9821	Economy	27900.00
0005434550612	9821	Economy	27900.00
0005434032021	9821	Economy	27900.00
0005433181086	9821	Economy	27900.00
0005434724449	9821	Economy	27900.00
0005433234147	9821	Economy	27900.00
0005434724666	9821	Economy	27900.00
0005433181080	9821	Economy	27900.00
0005432199239	9821	Economy	27900.00
0005433234174	9821	Economy	27900.00
0005434724350	9821	Economy	27900.00
0005433181063	9821	Economy	27900.00
0005434724246	9821	Economy	27900.00
0005433181083	9821	Economy	27900.00
0005434724166	9821	Economy	27900.00
0005434731133	9821	Economy	27900.00
0005433766636	9821	Economy	27900.00
0005433234139	9821	Economy	27900.00
0005433234145	9821	Economy	27900.00
0005434731145	9821	Economy	27900.00
0005434724141	9821	Economy	27900.00
0005434550769	9821	Economy	27900.00
0005433234123	9821	Economy	27900.00
0005433234115	9821	Economy	27900.00
0005434724408	9821	Economy	27900.00
0005434724642	9821	Economy	27900.00
0005434724959	9821	Economy	27900.00
0005434724572	9821	Economy	27900.00
0005433234175	9821	Economy	27900.00
0005434723736	9821	Economy	27900.00
0005434724418	9821	Economy	27900.00
0005434550654	9821	Economy	27900.00
0005434724297	9821	Economy	27900.00
0005434550790	9821	Economy	27900.00
0005434723892	9821	Economy	27900.00
0005434550666	9821	Economy	27900.00
0005434724630	9821	Economy	27900.00
0005434724296	9821	Economy	27900.00
0005434724075	9821	Economy	27900.00
0005433289842	9821	Economy	27900.00
0005433234120	9821	Economy	27900.00
0005433289835	9821	Economy	27900.00
0005434550780	9821	Economy	27900.00
0005433234112	9821	Economy	27900.00
0005434724632	9821	Economy	27900.00
0005433234126	9821	Economy	27900.00
0005433234158	9821	Economy	27900.00
0005434724140	9821	Economy	30700.00
0005434724405	9821	Economy	30700.00
0005434032019	9821	Economy	30700.00
0005435142436	9821	Economy	30700.00
0005434724047	9821	Economy	30700.00
0005434550715	9821	Economy	27900.00
0005433181072	9821	Economy	30700.00
0005434550753	9821	Economy	27900.00
0005433181065	9821	Economy	27900.00
0005434550728	9821	Economy	27900.00
0005434724957	9821	Economy	27900.00
0005434724096	9821	Economy	27900.00
0005433234148	9821	Economy	27900.00
0005433766637	9821	Economy	27900.00
0005434550682	9821	Economy	27900.00
0005433234117	9821	Economy	27900.00
0005434550622	9821	Economy	27900.00
0005434550652	9821	Economy	27900.00
0005433181074	9821	Economy	27900.00
0005434724270	9821	Economy	27900.00
0005433234143	9821	Economy	27900.00
0005433234111	9821	Economy	27900.00
0005434735616	9821	Economy	27900.00
0005433234124	9821	Economy	27900.00
0005433289841	9821	Economy	27900.00
0005434724609	9821	Economy	27900.00
0005434724369	9821	Economy	27900.00
0005434550269	9821	Economy	27900.00
0005433234127	9821	Economy	27900.00
0005434724578	9821	Economy	27900.00
0005434550371	9821	Economy	27900.00
0005432199240	9821	Economy	27900.00
0005434724215	9821	Economy	27900.00
0005433289838	9821	Economy	27900.00
0005434724391	9821	Economy	27900.00
0005434724048	9821	Economy	27900.00
0005434724094	9821	Economy	27900.00
0005434731134	9821	Economy	27900.00
0005433181082	9821	Economy	27900.00
0005433113533	9821	Economy	27900.00
0005433129270	9821	Economy	27900.00
0005434723741	9821	Economy	27900.00
0005434724491	9821	Economy	27900.00
0005434550621	9821	Economy	27900.00
0005434724308	9821	Economy	27900.00
0005434550474	9821	Economy	27900.00
0005435142425	9821	Economy	27900.00
0005434724113	9821	Economy	27900.00
0005434550591	9821	Economy	27900.00
0005433234132	9821	Economy	27900.00
0005433234168	9821	Economy	27900.00
0005434724108	9821	Economy	27900.00
0005434550729	9821	Economy	27900.00
0005433289839	9821	Economy	27900.00
0005434724199	9821	Economy	27900.00
0005433234131	9821	Economy	27900.00
0005433129271	9821	Economy	27900.00
0005435142374	9821	Economy	27900.00
0005434724631	9821	Economy	27900.00
0005434724646	9821	Economy	27900.00
0005433234133	9821	Economy	27900.00
0005434724294	9821	Economy	27900.00
0005435142433	9821	Economy	27900.00
0005434550717	9821	Economy	27900.00
0005433234153	9821	Economy	27900.00
0005434550800	9821	Economy	27900.00
0005434550613	9821	Economy	27900.00
0005433234172	9821	Economy	27900.00
0005433234119	9821	Economy	27900.00
0005434550725	9821	Economy	27900.00
0005434724657	9821	Economy	27900.00
0005434735615	9821	Economy	27900.00
0005434724495	9821	Economy	27900.00
0005433234163	9821	Economy	27900.00
0005434724721	9821	Economy	27900.00
0005434723990	9821	Economy	27900.00
0005433234136	9821	Economy	27900.00
0005434302401	9821	Economy	27900.00
0005434724436	9821	Economy	27900.00
0005433181085	9821	Economy	27900.00
0005434735621	9821	Economy	27900.00
0005434724568	9821	Economy	27900.00
0005434724226	9821	Economy	27900.00
0005434724178	9821	Economy	27900.00
0005434724597	9821	Economy	27900.00
0005433234154	9821	Economy	27900.00
0005434724167	9821	Economy	27900.00
0005433234146	9821	Economy	27900.00
0005433234118	9821	Economy	27900.00
0005434724320	9821	Economy	27900.00
0005434724196	9821	Economy	27900.00
0005434550513	9821	Economy	27900.00
0005433234166	9821	Economy	27900.00
0005434725013	9821	Economy	27900.00
0005434724052	9821	Economy	27900.00
0005434724274	9821	Economy	27900.00
0005434724264	9821	Economy	27900.00
0005434724647	9821	Economy	27900.00
0005434724613	9821	Economy	27900.00
0005433234159	9821	Economy	27900.00
0005433234144	9821	Economy	27900.00
0005433113534	9821	Economy	27900.00
0005434724435	9821	Economy	27900.00
0005433126837	9821	Economy	27900.00
0005434724331	9821	Economy	27900.00
0005433234151	9821	Economy	27900.00
0005435212805	7773	Business	42100.00
0005432527836	7773	Business	42100.00
0005435212843	7773	Business	42100.00
0005435212974	7773	Business	42100.00
0005434067521	7773	Business	42100.00
0005435212914	7773	Business	42100.00
0005434067507	7773	Business	42100.00
0005432533289	7773	Business	42100.00
0005432527812	7773	Business	42100.00
0005434067524	7773	Business	42100.00
0005432527889	7773	Business	42100.00
0005432527893	7773	Business	42100.00
0005432069633	7773	Business	42100.00
0005432527831	7773	Business	42100.00
0005432527787	7773	Business	42100.00
0005434067470	7773	Business	42100.00
0005435212992	7773	Business	42100.00
0005435212788	7773	Business	42100.00
0005434067487	7773	Business	42100.00
0005435212844	7773	Business	42100.00
0005434067504	7773	Comfort	23900.00
0005435212782	7773	Business	42100.00
0005432527826	7773	Comfort	23900.00
0005432527802	7773	Comfort	23900.00
0005435213009	7773	Comfort	23900.00
0005434067499	7773	Comfort	23900.00
0005432150183	7773	Comfort	23900.00
0005434067506	7773	Comfort	23900.00
0005432527870	7773	Comfort	23900.00
0005432527854	7773	Comfort	23900.00
0005435212821	7773	Comfort	23900.00
0005434067460	7773	Comfort	23900.00
0005432527910	7773	Comfort	23900.00
0005432069642	7773	Comfort	23900.00
0005435212755	7773	Comfort	23900.00
0005434067501	7773	Comfort	23900.00
0005432527817	7773	Comfort	23900.00
0005435212913	7773	Comfort	23900.00
0005435725561	7773	Comfort	23900.00
0005435213061	7773	Comfort	23900.00
0005432527861	7773	Comfort	23900.00
0005434067519	7773	Comfort	23900.00
0005432527903	7773	Comfort	23900.00
0005432527900	7773	Comfort	23900.00
0005434067469	7773	Comfort	23900.00
0005434067459	7773	Comfort	23900.00
0005434067472	7773	Comfort	23900.00
0005434067461	7773	Comfort	23900.00
0005435213037	7773	Comfort	23900.00
0005432150185	7773	Comfort	23900.00
0005432527905	7773	Comfort	23900.00
0005434067476	7773	Comfort	23900.00
0005434067473	7773	Comfort	23900.00
0005434067462	7773	Comfort	23900.00
0005435213107	7773	Comfort	23900.00
0005432527842	7773	Comfort	23900.00
0005432069632	7773	Comfort	23900.00
0005432527819	7773	Comfort	23900.00
0005432150187	7773	Comfort	23900.00
0005432527793	7773	Comfort	23900.00
0005434067508	7773	Economy	14000.00
0005435212496	7773	Comfort	23900.00
0005432069636	7773	Economy	14000.00
0005435212854	7773	Economy	14000.00
0005434067495	7773	Economy	14000.00
0005432527782	7773	Economy	14000.00
0005432527803	7773	Economy	14000.00
0005432527828	7773	Economy	14000.00
0005432527912	7773	Economy	14000.00
0005435213046	7773	Economy	14000.00
0005435213225	7773	Economy	14000.00
0005432535830	7773	Economy	14000.00
0005432527901	7773	Economy	14000.00
0005435213108	7773	Economy	14000.00
0005433656629	7773	Economy	14000.00
0005432527868	7773	Economy	14000.00
0005432527823	7773	Economy	14000.00
0005432527852	7773	Economy	14000.00
0005434067477	7773	Economy	14000.00
0005432069638	7773	Economy	14000.00
0005435212497	7773	Economy	14000.00
0005432527884	7773	Economy	14000.00
0005435213068	7773	Economy	14000.00
0005432527791	7773	Economy	14000.00
0005435212845	7773	Economy	14000.00
0005432527838	7773	Economy	14000.00
0005435212896	7773	Economy	14000.00
0005432527863	7773	Economy	14000.00
0005434067468	7773	Economy	14000.00
0005434067496	7773	Economy	14000.00
0005435213191	7773	Economy	14000.00
0005434067525	7773	Economy	14000.00
0005434067498	7773	Economy	14000.00
0005435212804	7773	Economy	14000.00
0005435212618	7773	Economy	14000.00
0005432527805	7773	Economy	14000.00
0005432069643	7773	Economy	14000.00
0005432527849	7773	Economy	14000.00
0005432527816	7773	Economy	14000.00
0005435725532	7773	Economy	14000.00
0005435213150	7773	Economy	14000.00
0005435212696	7773	Economy	14000.00
0005432527873	7773	Economy	14000.00
0005434067474	7773	Economy	14000.00
0005435212836	7773	Economy	14000.00
0005432069635	7773	Economy	14000.00
0005432527797	7773	Economy	14000.00
0005432537055	7773	Economy	14000.00
0005434067518	7773	Economy	14000.00
0005432527913	7773	Economy	14000.00
0005434067467	7773	Economy	14000.00
0005432527847	7773	Economy	14000.00
0005432527890	7773	Economy	14000.00
0005434067486	7773	Economy	14000.00
0005432537056	7773	Economy	14000.00
0005434067520	7773	Economy	15400.00
0005434067493	7773	Economy	15400.00
0005435213154	7773	Economy	15400.00
0005432527810	7773	Economy	14000.00
0005432527850	7773	Economy	14000.00
0005435630926	7773	Economy	14000.00
0005434067494	7773	Economy	15400.00
0005432527825	7773	Economy	14000.00
0005434067515	7773	Economy	15400.00
0005433656648	7773	Economy	14000.00
0005434067503	7773	Economy	14000.00
0005432527897	7773	Economy	14000.00
0005434067527	7773	Economy	14000.00
0005432527855	7773	Economy	14000.00
0005432527796	7773	Economy	14000.00
0005434067517	7773	Economy	14000.00
0005435212823	7773	Economy	14000.00
0005432069634	7773	Economy	14000.00
0005432527902	7773	Economy	14000.00
0005435212796	7773	Economy	14000.00
0005432527909	7773	Economy	14000.00
0005432150189	7773	Economy	14000.00
0005432069646	7773	Economy	14000.00
0005432535827	7773	Economy	14000.00
0005432527786	7773	Economy	14000.00
0005432527869	7773	Economy	14000.00
0005435213066	7773	Economy	14000.00
0005434067490	7773	Economy	14000.00
0005432527874	7773	Economy	14000.00
0005432527785	7773	Economy	14000.00
0005434067483	7773	Economy	14000.00
0005435213125	7773	Economy	14000.00
0005432527906	7773	Economy	14000.00
0005434067502	7773	Economy	14000.00
0005432527891	7773	Economy	14000.00
0005432527871	7773	Economy	14000.00
0005432527837	7773	Economy	14000.00
0005435212750	7773	Economy	14000.00
0005432527814	7773	Economy	14000.00
0005434067522	7773	Economy	14000.00
0005434067500	7773	Economy	14000.00
0005432527806	7773	Economy	14000.00
0005432150184	7773	Economy	14000.00
0005432069639	7773	Economy	14000.00
0005432527887	7773	Economy	14000.00
0005434067484	7773	Economy	14000.00
0005432527911	7773	Economy	14000.00
0005434067466	7773	Economy	14000.00
0005432150190	7773	Economy	14000.00
0005432428924	7773	Economy	14000.00
0005432527859	7773	Economy	14000.00
0005432527820	7773	Economy	14000.00
0005434067516	7773	Economy	14000.00
0005432527907	7773	Economy	14000.00
0005432527856	7773	Economy	14000.00
0005432527875	7773	Economy	14000.00
0005434067491	7773	Economy	14000.00
0005432527866	7773	Economy	14000.00
0005435630941	7773	Economy	14000.00
0005434067510	7773	Economy	14000.00
0005432527800	7773	Economy	14000.00
0005432535829	7773	Economy	14000.00
0005434067509	7773	Economy	14000.00
0005432150186	7773	Economy	14000.00
0005435213018	7773	Economy	14000.00
0005432527899	7773	Economy	14000.00
0005432527886	7773	Economy	14000.00
0005432527846	7773	Economy	14000.00
0005432527824	7773	Economy	14000.00
0005432527862	7773	Economy	14000.00
0005432533288	7773	Economy	14000.00
0005432150188	7773	Economy	14000.00
0005432537054	7773	Economy	14000.00
0005432527841	7773	Economy	14000.00
0005432527857	7773	Economy	14000.00
0005432527807	7773	Economy	14000.00
0005432527872	7773	Economy	14000.00
0005432527798	7773	Economy	14000.00
0005432527829	7773	Economy	14000.00
0005432527848	7773	Economy	14000.00
0005432527843	7773	Economy	14000.00
0005432527881	7773	Economy	14000.00
0005435212932	7773	Economy	14000.00
0005433656630	7773	Economy	14000.00
0005435212756	7773	Economy	14000.00
0005432527801	7773	Economy	14000.00
0005432527784	7773	Economy	14000.00
0005434067480	7773	Economy	14000.00
0005434067481	7773	Economy	14000.00
0005432527839	7773	Economy	14000.00
0005432527815	7773	Economy	14000.00
0005435212695	7773	Economy	14000.00
0005432527809	7773	Economy	14000.00
0005432527864	7773	Economy	14000.00
0005432527876	7773	Economy	14000.00
0005435213156	7773	Economy	14000.00
0005432527808	7773	Economy	14000.00
0005435212709	7773	Economy	14000.00
0005432527830	7773	Economy	14000.00
0005432527858	7773	Economy	14000.00
0005434067526	7773	Economy	14000.00
0005434067511	7773	Economy	14000.00
0005435212952	7773	Economy	15400.00
0005432527821	7773	Economy	14000.00
0005432527898	7773	Economy	15400.00
0005432527867	7773	Economy	15400.00
0005432069640	7773	Economy	15400.00
0005434067475	7773	Economy	14000.00
0005432527878	7773	Economy	14000.00
0005435212754	7773	Economy	14000.00
0005432527895	7773	Economy	14000.00
0005435213112	7773	Economy	14000.00
0005432527794	7773	Economy	14000.00
0005432527790	7773	Economy	14000.00
0005432069645	7773	Economy	14000.00
0005432527894	7773	Economy	14000.00
0005432428923	7773	Economy	14000.00
0005434067471	7773	Economy	14000.00
0005432527865	7773	Economy	14000.00
0005435212708	7773	Economy	14000.00
0005432428926	7773	Economy	14000.00
0005435212730	7773	Economy	14000.00
0005432527888	7773	Economy	14000.00
0005435213167	7773	Economy	14000.00
0005432527781	7773	Economy	14000.00
0005434067488	7773	Economy	14000.00
0005434067528	7773	Economy	14000.00
0005432527879	7773	Economy	14000.00
0005432527896	7773	Economy	14000.00
0005432527883	7773	Economy	14000.00
0005432527853	7773	Economy	14000.00
0005432527880	7773	Economy	14000.00
0005432527827	7773	Economy	14000.00
0005432527851	7773	Economy	14000.00
0005434067497	7773	Economy	14000.00
0005432527904	7773	Economy	14000.00
0005434067463	7773	Economy	14000.00
0005432533290	7773	Economy	14000.00
0005432527780	7773	Economy	14000.00
0005432527860	7773	Economy	14000.00
0005432527885	7773	Economy	14000.00
0005432527788	7773	Economy	14000.00
0005432527795	7773	Economy	14000.00
0005432527818	7773	Economy	14000.00
0005432527844	7773	Economy	14000.00
0005435213166	7773	Economy	14000.00
0005432535828	7773	Economy	14000.00
0005435213100	7773	Economy	14000.00
0005432527845	7773	Economy	14000.00
0005435212881	7773	Economy	14000.00
0005435213155	7773	Economy	14000.00
0005432527908	7773	Economy	14000.00
0005435212855	7773	Economy	14000.00
0005432527804	7773	Economy	14000.00
0005434067478	7773	Economy	14000.00
0005432527882	7773	Economy	14000.00
0005434067482	7773	Economy	14000.00
0005435725542	7773	Economy	14000.00
0005432428925	7773	Economy	14000.00
0005435212697	7773	Economy	14000.00
0005435213019	7773	Economy	14000.00
0005435213062	7773	Economy	14000.00
0005432069647	7773	Economy	14000.00
0005435213067	7773	Economy	14000.00
0005434067514	7773	Economy	14000.00
0005435212837	7773	Economy	14000.00
0005432527832	7773	Economy	14000.00
0005434067513	7773	Economy	14000.00
0005435213126	7773	Economy	14000.00
0005435212933	7773	Economy	14000.00
0005432527833	7773	Economy	14000.00
0005432069637	7773	Economy	14000.00
0005435212842	7773	Economy	14000.00
0005432527835	7773	Economy	14000.00
0005435212778	7773	Economy	14000.00
0005434067457	7773	Economy	14000.00
0005432527834	7773	Economy	14000.00
0005435212956	7773	Economy	14000.00
0005432527822	7773	Economy	14000.00
0005432533287	7773	Economy	14000.00
0005432527783	7773	Economy	14000.00
0005432527811	7773	Economy	14000.00
0005434067512	7773	Economy	14000.00
0005434067492	7773	Economy	14000.00
0005432527792	7773	Economy	14000.00
0005435213026	7773	Economy	14000.00
0005432527799	7773	Economy	14000.00
0005435212824	7773	Economy	14000.00
0005432069641	7773	Economy	14000.00
0005434067523	7773	Economy	14000.00
0005432069644	7773	Economy	14000.00
0005434067465	7773	Economy	14000.00
0005432527789	7773	Economy	14000.00
0005434067479	7773	Economy	14000.00
0005432527813	7773	Economy	14000.00
0005435213047	7773	Economy	14000.00
0005435213038	7773	Economy	14000.00
0005432527840	7773	Economy	14000.00
0005434067489	7773	Economy	14000.00
0005434067485	7773	Economy	14000.00
0005435725533	7773	Economy	14000.00
0005434067458	7773	Economy	14000.00
0005432527892	7773	Economy	14000.00
0005434067464	7773	Economy	14000.00
0005432527877	7773	Economy	14000.00
0005434067505	7773	Economy	14000.00
0005435613499	5317	Business	43100.00
0005435424296	5317	Business	43100.00
0005434244604	5317	Business	43100.00
0005434344201	5317	Business	43100.00
0005435613492	5317	Business	43100.00
0005432133200	5317	Business	43100.00
0005435613536	5317	Business	43100.00
0005435613562	5317	Business	43100.00
0005435424362	5317	Business	43100.00
0005434573343	5317	Business	43100.00
0005435380230	5317	Business	43100.00
0005434344196	5317	Business	43100.00
0005435424064	5317	Business	43100.00
0005435424198	5317	Business	43100.00
0005435613528	5317	Business	43100.00
0005434244660	5317	Business	43100.00
0005432133198	5317	Business	43100.00
0005434244693	5317	Business	43100.00
0005434573338	5317	Business	43100.00
0005435613489	5317	Business	43100.00
0005435490223	5317	Business	43100.00
0005435097195	5317	Business	43100.00
0005435613526	5317	Business	43100.00
0005435613560	5317	Business	43100.00
0005435042828	5317	Comfort	24400.00
0005435424176	5317	Comfort	24400.00
0005434244731	5317	Comfort	24400.00
0005435613520	5317	Comfort	24400.00
0005435424632	5317	Comfort	24400.00
0005435613502	5317	Comfort	24400.00
0005435613551	5317	Comfort	24400.00
0005435424429	5317	Comfort	24400.00
0005435423997	5317	Comfort	24400.00
0005435613507	5317	Comfort	24400.00
0005435097197	5317	Comfort	24400.00
0005432133194	5317	Comfort	24400.00
0005434344183	5317	Comfort	24400.00
0005435424124	5317	Comfort	24400.00
0005432840997	5317	Comfort	24400.00
0005435424315	5317	Comfort	24400.00
0005435613538	5317	Comfort	24400.00
0005434344199	5317	Comfort	24400.00
0005435613575	5317	Comfort	24400.00
0005434244691	5317	Comfort	24400.00
0005433719106	5317	Comfort	24400.00
0005435424199	5317	Comfort	24400.00
0005434244675	5317	Comfort	24400.00
0005435424045	5317	Comfort	24400.00
0005435613516	5317	Comfort	24400.00
0005435424223	5317	Comfort	24400.00
0005435319495	5317	Comfort	24400.00
0005435424487	5317	Comfort	24400.00
0005435424402	5317	Comfort	24400.00
0005435097196	5317	Comfort	24400.00
0005434344197	5317	Comfort	24400.00
0005435613547	5317	Comfort	24400.00
0005434344175	5317	Comfort	24400.00
0005432363383	5317	Comfort	24400.00
0005435424214	5317	Comfort	24400.00
0005435555367	5317	Comfort	24400.00
0005435424139	5317	Comfort	24400.00
0005435613577	5317	Comfort	24400.00
0005435424159	5317	Economy	14400.00
0005435613553	5317	Economy	14400.00
0005434573340	5317	Economy	14400.00
0005435424261	5317	Economy	14400.00
0005435424452	5317	Economy	14400.00
0005434344209	5317	Economy	14400.00
0005435613500	5317	Economy	14400.00
0005435424425	5317	Economy	14400.00
0005432133191	5317	Economy	14400.00
0005435097192	5317	Economy	14400.00
0005435613580	5317	Economy	14400.00
0005435613504	5317	Economy	14400.00
0005435319494	5317	Economy	14400.00
0005435424248	5317	Economy	14400.00
0005435613498	5317	Economy	14400.00
0005435424363	5317	Economy	14400.00
0005434573334	5317	Economy	14400.00
0005434573341	5317	Economy	14400.00
0005435424260	5317	Economy	14400.00
0005435613496	5317	Economy	14400.00
0005435613501	5317	Economy	14400.00
0005435613537	5317	Economy	14400.00
0005435424083	5317	Economy	14400.00
0005435613558	5317	Economy	14400.00
0005435424331	5317	Economy	14400.00
0005435424360	5317	Economy	14400.00
0005435424158	5317	Economy	14400.00
0005434344208	5317	Economy	14400.00
0005435424295	5317	Economy	14400.00
0005434244697	5317	Economy	14400.00
0005435613512	5317	Economy	14400.00
0005435097191	5317	Economy	14400.00
0005435613564	5317	Economy	14400.00
0005435613546	5317	Economy	14400.00
0005435613505	5317	Economy	14400.00
0005435042826	5317	Economy	14400.00
0005435613555	5317	Economy	14400.00
0005435423947	5317	Economy	14400.00
0005435042835	5317	Economy	14400.00
0005435424251	5317	Economy	14400.00
0005434244736	5317	Economy	14400.00
0005435424151	5317	Economy	14400.00
0005435613533	5317	Economy	14400.00
0005435613511	5317	Economy	14400.00
0005435424403	5317	Economy	14400.00
0005435424330	5317	Economy	14400.00
0005435424027	5317	Economy	14400.00
0005434344191	5317	Economy	14400.00
0005434344185	5317	Economy	14400.00
0005434344177	5317	Economy	14400.00
0005432840998	5317	Economy	14400.00
0005434244662	5317	Economy	14400.00
0005435613574	5317	Economy	14400.00
0005434344205	5317	Economy	14400.00
0005434344184	5317	Economy	14400.00
0005435424479	5317	Economy	14400.00
0005432133190	5317	Economy	14400.00
0005435613493	5317	Economy	14400.00
0005434244673	5317	Economy	14400.00
0005434573345	5317	Economy	14400.00
0005433719096	5317	Economy	14400.00
0005435302143	5317	Economy	15800.00
0005435613494	5317	Economy	15800.00
0005434344194	5317	Economy	14400.00
0005434573337	5317	Economy	14400.00
0005434573335	5317	Economy	14400.00
0005435424314	5317	Economy	14400.00
0005435613532	5317	Economy	15800.00
0005433719095	5317	Economy	14400.00
0005434244624	5317	Economy	15800.00
0005435613556	5317	Economy	14400.00
0005434244668	5317	Economy	14400.00
0005435555366	5317	Economy	14400.00
0005435302145	5317	Economy	14400.00
0005434244679	5317	Economy	14400.00
0005435490225	5317	Economy	14400.00
0005435613518	5317	Economy	14400.00
0005433719104	5317	Economy	14400.00
0005434344193	5317	Economy	14400.00
0005435424097	5317	Economy	14400.00
0005435097193	5317	Economy	14400.00
0005432133192	5317	Economy	14400.00
0005435613521	5317	Economy	14400.00
0005434244807	5317	Economy	14400.00
0005435319486	5317	Economy	14400.00
0005432363375	5317	Economy	14400.00
0005434344180	5317	Economy	14400.00
0005434244663	5317	Economy	14400.00
0005435613583	5317	Economy	14400.00
0005435613573	5317	Economy	14400.00
0005435613548	5317	Economy	14400.00
0005435613519	5317	Economy	14400.00
0005435491439	5317	Economy	14400.00
0005435319485	5317	Economy	14400.00
0005435302154	5317	Economy	14400.00
0005435613569	5317	Economy	14400.00
0005435613508	5317	Economy	14400.00
0005434344203	5317	Economy	14400.00
0005435613525	5317	Economy	14400.00
0005434244664	5317	Economy	14400.00
0005434573339	5317	Economy	14400.00
0005432363374	5317	Economy	14400.00
0005435613566	5317	Economy	14400.00
0005435613510	5317	Economy	14400.00
0005432133188	5317	Economy	14400.00
0005435613515	5317	Economy	14400.00
0005435613571	5317	Economy	14400.00
0005435424322	5317	Economy	14400.00
0005435424426	5317	Economy	14400.00
0005434573342	5317	Economy	14400.00
0005435424130	5317	Economy	14400.00
0005435613514	5317	Economy	14400.00
0005434244615	5317	Economy	14400.00
0005435490222	5317	Economy	14400.00
0005434244674	5317	Economy	14400.00
0005434344202	5317	Economy	14400.00
0005435613543	5317	Economy	14400.00
0005435424384	5317	Economy	14400.00
0005435380258	5317	Economy	14400.00
0005435424392	5317	Economy	14400.00
0005435613535	5317	Economy	14400.00
0005432133196	5317	Economy	14400.00
0005435424294	5317	Economy	14400.00
0005435424143	5317	Economy	14400.00
0005435613554	5317	Economy	14400.00
0005435424179	5317	Economy	14400.00
0005435319514	5317	Economy	14400.00
0005432047547	5317	Economy	14400.00
0005435319489	5317	Economy	14400.00
0005434573346	5317	Economy	14400.00
0005435613517	5317	Economy	14400.00
0005435613490	5317	Economy	14400.00
0005434344200	5317	Economy	14400.00
0005434244623	5317	Economy	14400.00
0005434344192	5317	Economy	14400.00
0005434656541	5317	Economy	14400.00
0005432133189	5317	Economy	14400.00
0005434344207	5317	Economy	14400.00
0005435613584	5317	Economy	14400.00
0005435424194	5317	Economy	14400.00
0005435613524	5317	Economy	14400.00
0005435424423	5317	Economy	14400.00
0005435097198	5317	Economy	14400.00
0005435613550	5317	Economy	14400.00
0005434244667	5317	Economy	14400.00
0005434244676	5317	Economy	14400.00
0005434344181	5317	Economy	14400.00
0005435424408	5317	Economy	14400.00
0005435042827	5317	Economy	14400.00
0005435613523	5317	Economy	14400.00
0005435424090	5317	Economy	14400.00
0005435097190	5317	Economy	14400.00
0005435380257	5317	Economy	14400.00
0005432047546	5317	Economy	14400.00
0005435302151	5317	Economy	14400.00
0005435613487	5317	Economy	14400.00
0005434344178	5317	Economy	14400.00
0005435424028	5317	Economy	14400.00
0005435424226	5317	Economy	14400.00
0005435613531	5317	Economy	14400.00
0005434344179	5317	Economy	14400.00
0005435319503	5317	Economy	14400.00
0005434344187	5317	Economy	14400.00
0005434344206	5317	Economy	14400.00
0005435613582	5317	Economy	14400.00
0005435424542	5317	Economy	14400.00
0005435613570	5317	Economy	15800.00
0005435613506	5317	Economy	15800.00
0005435424377	5317	Economy	15800.00
0005434344176	5317	Economy	15800.00
0005434244823	5317	Economy	14400.00
0005434344210	5317	Economy	14400.00
0005435424391	5317	Economy	14400.00
0005435302150	5317	Economy	14400.00
0005435613565	5317	Economy	14400.00
0005435613578	5317	Economy	14400.00
0005434656546	5317	Economy	14400.00
0005435424424	5317	Economy	14400.00
0005434244806	5317	Economy	14400.00
0005434344204	5317	Economy	14400.00
0005435424407	5317	Economy	14400.00
0005435424133	5317	Economy	14400.00
0005434244824	5317	Economy	14400.00
0005435613561	5317	Economy	14400.00
0005435490224	5317	Economy	14400.00
0005434344195	5317	Economy	14400.00
0005435613544	5317	Economy	14400.00
0005432133193	5317	Economy	14400.00
0005434573333	5317	Economy	14400.00
0005432047545	5317	Economy	14400.00
0005434573336	5317	Economy	14400.00
0005435613572	5317	Economy	14400.00
0005435423948	5317	Economy	14400.00
0005435424281	5317	Economy	14400.00
0005435613542	5317	Economy	14400.00
0005434244730	5317	Economy	14400.00
0005434573344	5317	Economy	14400.00
0005432133199	5317	Economy	14400.00
0005432133201	5317	Economy	14400.00
0005435302153	5317	Economy	14400.00
0005435424046	5317	Economy	14400.00
0005434344182	5317	Economy	14400.00
0005434244735	5317	Economy	14400.00
0005435613557	5317	Economy	14400.00
0005435613559	5317	Economy	14400.00
0005435424282	5317	Economy	14400.00
0005435613529	5317	Economy	14400.00
0005435613495	5317	Economy	14400.00
0005435424416	5317	Economy	14400.00
0005435613513	5317	Economy	14400.00
0005434344174	5317	Economy	14400.00
0005435424175	5317	Economy	14400.00
0005435613549	5317	Economy	14400.00
0005435424263	5317	Economy	14400.00
0005432133202	5317	Economy	14400.00
0005435097194	5317	Economy	14400.00
0005435424253	5317	Economy	14400.00
0005434344188	5317	Economy	14400.00
0005435302142	5317	Economy	14400.00
0005435424390	5317	Economy	14400.00
0005435380259	5317	Economy	14400.00
0005435042833	5317	Economy	14400.00
0005434244661	5317	Economy	14400.00
0005435613509	5317	Economy	14400.00
0005435424084	5317	Economy	14400.00
0005435613576	5317	Economy	14400.00
0005435424293	5317	Economy	14400.00
0005435424123	5317	Economy	14400.00
0005435613540	5317	Economy	14400.00
0005435424427	5317	Economy	14400.00
0005435613545	5317	Economy	14400.00
0005435613497	5317	Economy	14400.00
0005435424415	5317	Economy	14400.00
0005435490226	5317	Economy	14400.00
0005435613541	5317	Economy	14400.00
0005435613579	5317	Economy	14400.00
0005435424098	5317	Economy	14400.00
0005435613534	5317	Economy	14400.00
0005434244752	5317	Economy	14400.00
0005432133195	5317	Economy	14400.00
0005435555365	5317	Economy	14400.00
0005434344186	5317	Economy	14400.00
0005435042836	5317	Economy	14400.00
0005435613539	5317	Economy	14400.00
0005434573332	5317	Economy	14400.00
0005435319496	5317	Economy	14400.00
0005435424135	5317	Economy	14400.00
0005435424254	5317	Economy	14400.00
0005435424085	5317	Economy	14400.00
0005434244716	5317	Economy	14400.00
0005435613530	5317	Economy	14400.00
0005435613581	5317	Economy	14400.00
0005435613567	5317	Economy	14400.00
0005435613563	5317	Economy	14400.00
0005435424252	5317	Economy	14400.00
0005434344190	5317	Economy	14400.00
0005435613522	5317	Economy	14400.00
0005435613488	5317	Economy	14400.00
0005435613491	5317	Economy	14400.00
0005434244719	5317	Economy	14400.00
0005434244690	5317	Economy	14400.00
0005435613527	5317	Economy	14400.00
0005435613568	5317	Economy	14400.00
0005432133197	5317	Economy	14400.00
0005434344189	5317	Economy	14400.00
0005435613552	5317	Economy	14400.00
0005435613503	5317	Economy	14400.00
0005434344198	5317	Economy	14400.00
0005432133203	5317	Economy	14400.00
0005435424235	5317	Economy	14400.00
0005435424451	5317	Economy	14400.00
0005435424193	5317	Economy	14400.00
0005435612794	10931	Business	43100.00
0005434244954	10931	Business	43100.00
0005435612409	10931	Business	43100.00
0005435612830	10931	Business	43100.00
0005435424725	10931	Business	43100.00
0005435424707	10931	Business	43100.00
0005435612778	10931	Business	43100.00
0005434343770	10931	Business	43100.00
0005435319565	10931	Business	43100.00
0005435612701	10931	Business	43100.00
0005434244955	10931	Business	43100.00
0005435304148	10931	Business	43100.00
0005435097104	10931	Business	43100.00
0005435612232	10931	Business	43100.00
0005434244959	10931	Business	43100.00
0005432841011	10931	Business	43100.00
0005434244939	10931	Business	43100.00
0005435612702	10931	Business	43100.00
0005435424763	10931	Business	43100.00
0005435491417	10931	Business	43100.00
0005432165029	10931	Business	43100.00
0005435304151	10931	Business	43100.00
0005434244946	10931	Business	43100.00
0005435097075	10931	Comfort	24400.00
0005433719139	10931	Comfort	24400.00
0005435612680	10931	Comfort	24400.00
0005435319560	10931	Comfort	24400.00
0005435612206	10931	Comfort	24400.00
0005435424748	10931	Comfort	24400.00
0005435424757	10931	Comfort	24400.00
0005435612831	10931	Comfort	24400.00
0005435319566	10931	Comfort	24400.00
0005435424751	10931	Comfort	24400.00
0005435304153	10931	Comfort	24400.00
0005435612624	10931	Comfort	24400.00
0005435612865	10931	Comfort	24400.00
0005435612934	10931	Comfort	24400.00
0005435612491	10931	Comfort	24400.00
0005434343753	10931	Comfort	24400.00
0005434244962	10931	Comfort	24400.00
0005435424766	10931	Comfort	24400.00
0005435612889	10931	Comfort	24400.00
0005435042856	10931	Comfort	24400.00
0005435424756	10931	Comfort	24400.00
0005435424743	10931	Comfort	24400.00
0005432165033	10931	Comfort	24400.00
0005435612623	10931	Comfort	24400.00
0005434573205	10931	Comfort	24400.00
0005435612434	10931	Comfort	24400.00
0005435612226	10931	Comfort	24400.00
0005435424709	10931	Comfort	24400.00
0005435612225	10931	Comfort	24400.00
0005434244956	10931	Comfort	24400.00
0005435424759	10931	Comfort	24400.00
0005435424758	10931	Comfort	24400.00
0005435612490	10931	Comfort	24400.00
0005434573236	10931	Comfort	24400.00
0005434244958	10931	Comfort	24400.00
0005435424721	10931	Comfort	24400.00
0005435304150	10931	Economy	14400.00
0005435424746	10931	Economy	14400.00
0005435097047	10931	Economy	14400.00
0005435612900	10931	Economy	14400.00
0005434573184	10931	Economy	14400.00
0005435424745	10931	Economy	14400.00
0005435424723	10931	Economy	14400.00
0005434244947	10931	Economy	14400.00
0005435612521	10931	Economy	14400.00
0005435612562	10931	Economy	14400.00
0005435612509	10931	Economy	14400.00
0005435424735	10931	Economy	14400.00
0005434343894	10931	Economy	14400.00
0005435612536	10931	Economy	14400.00
0005435424772	10931	Economy	14400.00
0005435612071	10931	Economy	14400.00
0005434343838	10931	Economy	14400.00
0005435612376	10931	Economy	14400.00
0005435612653	10931	Economy	14400.00
0005435612522	10931	Economy	14400.00
0005434244952	10931	Economy	14400.00
0005434573193	10931	Economy	14400.00
0005435612647	10931	Economy	14400.00
0005435424730	10931	Economy	14400.00
0005434573151	10931	Economy	14400.00
0005435612549	10931	Economy	14400.00
0005435612700	10931	Economy	14400.00
0005435612572	10931	Economy	14400.00
0005435424750	10931	Economy	14400.00
0005435612419	10931	Economy	14400.00
0005435612824	10931	Economy	14400.00
0005435612311	10931	Economy	14400.00
0005435424753	10931	Economy	14400.00
0005435612886	10931	Economy	14400.00
0005435612841	10931	Economy	14400.00
0005435097102	10931	Economy	14400.00
0005434343756	10931	Economy	14400.00
0005435424760	10931	Economy	14400.00
0005432165026	10931	Economy	14400.00
0005435424720	10931	Economy	14400.00
0005434343793	10931	Economy	14400.00
0005435424729	10931	Economy	14400.00
0005435612646	10931	Economy	14400.00
0005435612389	10931	Economy	14400.00
0005432165027	10931	Economy	14400.00
0005435613020	10931	Economy	14400.00
0005435490189	10931	Economy	14400.00
0005434343769	10931	Economy	14400.00
0005435304154	10931	Economy	14400.00
0005434343802	10931	Economy	14400.00
0005434343892	10931	Economy	14400.00
0005435424761	10931	Economy	14400.00
0005435042857	10931	Economy	14400.00
0005435612496	10931	Economy	14400.00
0005435612251	10931	Economy	14400.00
0005435491425	10931	Economy	14400.00
0005434573165	10931	Economy	15800.00
0005435424765	10931	Economy	14400.00
0005435424715	10931	Economy	15800.00
0005434573198	10931	Economy	15800.00
0005434244949	10931	Economy	14400.00
0005435424736	10931	Economy	14400.00
0005435424770	10931	Economy	15800.00
0005435424755	10931	Economy	15800.00
0005435612935	10931	Economy	14400.00
0005435424716	10931	Economy	15800.00
0005433719137	10931	Economy	14400.00
0005434573206	10931	Economy	14400.00
0005435424724	10931	Economy	14400.00
0005434244951	10931	Economy	14400.00
0005435612215	10931	Economy	14400.00
0005434573174	10931	Economy	14400.00
0005433719138	10931	Economy	14400.00
0005435424754	10931	Economy	14400.00
0005435612532	10931	Economy	14400.00
0005435612861	10931	Economy	14400.00
0005434573173	10931	Economy	14400.00
0005435612956	10931	Economy	14400.00
0005435097103	10931	Economy	14400.00
0005435491418	10931	Economy	14400.00
0005435097046	10931	Economy	14400.00
0005435097076	10931	Economy	14400.00
0005435424732	10931	Economy	14400.00
0005435611819	10931	Economy	14400.00
0005435613010	10931	Economy	14400.00
0005435424726	10931	Economy	14400.00
0005435612550	10931	Economy	14400.00
0005435612890	10931	Economy	14400.00
0005434343795	10931	Economy	14400.00
0005434343667	10931	Economy	14400.00
0005435424767	10931	Economy	14400.00
0005435612417	10931	Economy	14400.00
0005435424718	10931	Economy	14400.00
0005435612583	10931	Economy	14400.00
0005435612883	10931	Economy	14400.00
0005435304149	10931	Economy	14400.00
0005433719136	10931	Economy	14400.00
0005435424734	10931	Economy	14400.00
0005435424710	10931	Economy	14400.00
0005432363413	10931	Economy	14400.00
0005435424740	10931	Economy	14400.00
0005435424719	10931	Economy	14400.00
0005435424768	10931	Economy	14400.00
0005435424771	10931	Economy	14400.00
0005435612205	10931	Economy	14400.00
0005435491423	10931	Economy	14400.00
0005435612470	10931	Economy	14400.00
0005434244963	10931	Economy	14400.00
0005435612605	10931	Economy	14400.00
0005434343688	10931	Economy	14400.00
0005435612976	10931	Economy	14400.00
0005435424738	10931	Economy	14400.00
0005435612375	10931	Economy	14400.00
0005435613008	10931	Economy	14400.00
0005435613021	10931	Economy	14400.00
0005434244960	10931	Economy	14400.00
0005435319559	10931	Economy	14400.00
0005435612823	10931	Economy	14400.00
0005435424711	10931	Economy	14400.00
0005435424752	10931	Economy	14400.00
0005434343813	10931	Economy	14400.00
0005435424713	10931	Economy	14400.00
0005435555340	10931	Economy	14400.00
0005435612632	10931	Economy	14400.00
0005435612789	10931	Economy	14400.00
0005435491424	10931	Economy	14400.00
0005435612370	10931	Economy	14400.00
0005434573211	10931	Economy	14400.00
0005434343906	10931	Economy	14400.00
0005435424712	10931	Economy	14400.00
0005434343666	10931	Economy	14400.00
0005435612804	10931	Economy	14400.00
0005434244953	10931	Economy	14400.00
0005435612369	10931	Economy	14400.00
0005435612973	10931	Economy	14400.00
0005435424747	10931	Economy	14400.00
0005435612960	10931	Economy	14400.00
0005434343803	10931	Economy	14400.00
0005434244942	10931	Economy	14400.00
0005435612884	10931	Economy	14400.00
0005435612004	10931	Economy	14400.00
0005434343910	10931	Economy	14400.00
0005434343840	10931	Economy	14400.00
0005435424722	10931	Economy	14400.00
0005434573180	10931	Economy	14400.00
0005435424744	10931	Economy	14400.00
0005435424717	10931	Economy	14400.00
0005434343893	10931	Economy	14400.00
0005435612531	10931	Economy	14400.00
0005435304152	10931	Economy	14400.00
0005434573240	10931	Economy	14400.00
0005435612410	10931	Economy	14400.00
0005434244937	10931	Economy	14400.00
0005432165031	10931	Economy	14400.00
0005435612199	10931	Economy	14400.00
0005432166899	10931	Economy	14400.00
0005435424737	10931	Economy	14400.00
0005434244957	10931	Economy	14400.00
0005435612648	10931	Economy	14400.00
0005435612207	10931	Economy	14400.00
0005435424706	10931	Economy	14400.00
0005434343909	10931	Economy	14400.00
0005435424727	10931	Economy	14400.00
0005435612866	10931	Economy	15800.00
0005434343904	10931	Economy	15800.00
0005435612633	10931	Economy	15800.00
0005434244938	10931	Economy	15800.00
0005435612190	10931	Economy	15800.00
0005435424708	10931	Economy	15800.00
0005434343722	10931	Economy	14400.00
0005435612601	10931	Economy	14400.00
0005435491409	10931	Economy	14400.00
0005435612977	10931	Economy	14400.00
0005435424764	10931	Economy	14400.00
0005432166898	10931	Economy	14400.00
0005434343866	10931	Economy	14400.00
0005435612497	10931	Economy	14400.00
0005434343768	10931	Economy	14400.00
0005434244945	10931	Economy	14400.00
0005434244940	10931	Economy	14400.00
0005434244943	10931	Economy	14400.00
0005435612437	10931	Economy	14400.00
0005435424705	10931	Economy	14400.00
0005432165032	10931	Economy	14400.00
0005435613054	10931	Economy	14400.00
0005435424749	10931	Economy	14400.00
0005435612436	10931	Economy	14400.00
0005434244936	10931	Economy	14400.00
0005435424774	10931	Economy	14400.00
0005435612808	10931	Economy	14400.00
0005435097069	10931	Economy	14400.00
0005434244961	10931	Economy	14400.00
0005432363412	10931	Economy	14400.00
0005435612953	10931	Economy	14400.00
0005435424769	10931	Economy	14400.00
0005435097108	10931	Economy	14400.00
0005435612133	10931	Economy	14400.00
0005435612584	10931	Economy	14400.00
0005432165030	10931	Economy	14400.00
0005435612832	10931	Economy	14400.00
0005435612263	10931	Economy	14400.00
0005434343689	10931	Economy	14400.00
0005432165028	10931	Economy	14400.00
0005434573185	10931	Economy	14400.00
0005435612955	10931	Economy	14400.00
0005434573166	10931	Economy	14400.00
0005435319564	10931	Economy	14400.00
0005435319563	10931	Economy	14400.00
0005435613053	10931	Economy	14400.00
0005435612614	10931	Economy	14400.00
0005435555339	10931	Economy	14400.00
0005434343821	10931	Economy	14400.00
0005435612438	10931	Economy	14400.00
0005435097101	10931	Economy	14400.00
0005435424742	10931	Economy	14400.00
0005435424762	10931	Economy	14400.00
0005435319562	10931	Economy	14400.00
0005435612423	10931	Economy	14400.00
0005435319567	10931	Economy	14400.00
0005434244950	10931	Economy	14400.00
0005434244941	10931	Economy	14400.00
0005435612222	10931	Economy	14400.00
0005434573145	10931	Economy	14400.00
0005435424703	10931	Economy	14400.00
0005435319561	10931	Economy	14400.00
0005434343812	10931	Economy	14400.00
0005434244944	10931	Economy	14400.00
0005434244964	10931	Economy	14400.00
0005435612345	10931	Economy	14400.00
0005435424733	10931	Economy	14400.00
0005434343651	10931	Economy	14400.00
0005435424731	10931	Economy	14400.00
0005435424773	10931	Economy	14400.00
0005435612371	10931	Economy	14400.00
0005435612795	10931	Economy	14400.00
0005435424739	10931	Economy	14400.00
0005435612132	10931	Economy	14400.00
0005435612250	10931	Economy	14400.00
0005435424741	10931	Economy	14400.00
0005434573156	10931	Economy	14400.00
0005435424714	10931	Economy	14400.00
0005434244948	10931	Economy	14400.00
0005434573223	10931	Economy	14400.00
0005435555349	10931	Economy	14400.00
0005435424775	10931	Economy	14400.00
0005435612687	10931	Economy	14400.00
0005435424704	10931	Economy	14400.00
0005435424728	10931	Economy	14400.00
0005434343794	10931	Economy	14400.00
0005434244935	10931	Economy	14400.00
0005435612649	10931	Economy	14400.00
0005435612952	10931	Economy	14400.00
0005432459137	3334	Business	18800.00
0005433507170	3334	Business	18800.00
0005432459220	3334	Business	18800.00
0005432459327	3334	Business	18800.00
0005432459330	3334	Business	18800.00
0005433633781	3334	Business	18800.00
0005432459149	3334	Business	18800.00
0005432459342	3334	Business	18800.00
0005433633785	3334	Business	18800.00
0005432459222	3334	Business	18800.00
0005432459408	3334	Business	18800.00
0005432181705	3334	Business	18800.00
0005432459569	3334	Business	18800.00
0005433633774	3334	Business	18800.00
0005433633792	3334	Business	18800.00
0005433633798	3334	Business	18800.00
0005433633783	3334	Business	18800.00
0005433507174	3334	Business	18800.00
0005433805349	3334	Business	18800.00
0005433805352	3334	Business	18800.00
0005433507160	3334	Business	18800.00
0005433633803	3334	Business	18800.00
0005433805336	3334	Business	18800.00
0005433805348	3334	Business	18800.00
0005432459467	3334	Business	18800.00
0005432181687	3334	Business	18800.00
0005432459043	3334	Business	18800.00
0005433633777	3334	Economy	6900.00
0005432181685	3334	Economy	6900.00
0005432459358	3334	Economy	6900.00
0005433507157	3334	Economy	6900.00
0005433507171	3334	Economy	6900.00
0005433633790	3334	Economy	6300.00
0005433633776	3334	Economy	6300.00
0005433507172	3334	Economy	6300.00
0005432459367	3334	Economy	6300.00
0005432459167	3334	Economy	6300.00
0005433633791	3334	Economy	6300.00
0005433805356	3334	Economy	6300.00
0005433805350	3334	Economy	6300.00
0005432459148	3334	Economy	6300.00
0005432459304	3334	Economy	6300.00
0005432459218	3334	Economy	6300.00
0005433507165	3334	Economy	6300.00
0005433507168	3334	Economy	6300.00
0005432459588	3334	Economy	6300.00
0005432181692	3334	Economy	6300.00
0005433805340	3334	Economy	6300.00
0005432459255	3334	Economy	6300.00
0005432181703	3334	Economy	6300.00
0005432459259	3334	Economy	6300.00
0005433805334	3334	Economy	6300.00
0005433633801	3334	Economy	6300.00
0005432459221	3334	Economy	6300.00
0005432459174	3334	Economy	6300.00
0005433805343	3334	Economy	6300.00
0005433633793	3334	Economy	6300.00
0005433633782	3334	Economy	6300.00
0005433633775	3334	Economy	6300.00
0005432459434	3334	Economy	6300.00
0005432181690	3334	Economy	6300.00
0005432181689	3334	Economy	6300.00
0005433805342	3334	Economy	6300.00
0005433507173	3334	Economy	6300.00
0005432459281	3334	Economy	6300.00
0005433633779	3334	Economy	6300.00
0005432459175	3334	Economy	6300.00
0005433805331	3334	Economy	6300.00
0005433633795	3334	Economy	6300.00
0005433805333	3334	Economy	6300.00
0005433633799	3334	Economy	6300.00
0005433633800	3334	Economy	6300.00
0005433805347	3334	Economy	6300.00
0005433805338	3334	Economy	6300.00
0005433805337	3334	Economy	6300.00
0005432181688	3334	Economy	6300.00
0005433805329	3334	Economy	6300.00
0005433633796	3334	Economy	6300.00
0005432181696	3334	Economy	6300.00
0005432459352	3334	Economy	6300.00
0005432459369	3334	Economy	6300.00
0005433805346	3334	Economy	6300.00
0005432181695	3334	Economy	6300.00
0005433805354	3334	Economy	6300.00
0005432181701	3334	Economy	6300.00
0005432459570	3334	Economy	6300.00
0005433633797	3334	Economy	6300.00
0005433507175	3334	Economy	6300.00
0005432459353	3334	Economy	6300.00
0005433805345	3334	Economy	6300.00
0005432459362	3334	Economy	6300.00
0005433507163	3334	Economy	6300.00
0005432459303	3334	Economy	6900.00
0005432181698	3334	Economy	6900.00
0005433633805	3334	Economy	6900.00
0005433507159	3334	Economy	6900.00
0005432459322	3334	Economy	6900.00
0005432459472	3334	Economy	6300.00
0005433805330	3334	Economy	6300.00
0005432459431	3334	Economy	6300.00
0005432459587	3334	Economy	6300.00
0005432459176	3334	Economy	6900.00
0005433633778	3334	Economy	6300.00
0005432181700	3334	Economy	6300.00
0005433633784	3334	Economy	6300.00
0005432459062	3334	Economy	6300.00
0005433507158	3334	Economy	6300.00
0005432459260	3334	Economy	6300.00
0005433507169	3334	Economy	6300.00
0005433633787	3334	Economy	6300.00
0005432459404	3334	Economy	6300.00
0005433633804	3334	Economy	6300.00
0005433633789	3334	Economy	6300.00
0005432459430	3334	Economy	6300.00
0005432459538	3334	Economy	6300.00
0005432181686	3334	Economy	6300.00
0005433805341	3334	Economy	6300.00
0005432181694	3334	Economy	6300.00
0005433507162	3334	Economy	6300.00
0005433633780	3334	Economy	6300.00
0005433805355	3334	Economy	6300.00
0005432459586	3334	Economy	6300.00
0005432459180	3334	Economy	6300.00
0005433805353	3334	Economy	6300.00
0005433507164	3334	Economy	6300.00
0005432181691	3334	Economy	6300.00
0005433507167	3334	Economy	6300.00
0005433805335	3334	Economy	6300.00
0005432459247	3334	Economy	6300.00
0005432459242	3334	Economy	6300.00
0005432181702	3334	Economy	6300.00
0005433633806	3334	Economy	6300.00
0005433805351	3334	Economy	6300.00
0005433507166	3334	Economy	6300.00
0005432459136	3334	Economy	6300.00
0005433805344	3334	Economy	6300.00
0005433507176	3334	Economy	6300.00
0005433507161	3334	Economy	6300.00
0005432181704	3334	Economy	6300.00
0005432459143	3334	Economy	6300.00
0005432181697	3334	Economy	6300.00
0005432181693	3334	Economy	6300.00
0005432459300	3334	Economy	6300.00
0005433633794	3334	Economy	6300.00
0005432459459	3334	Economy	6300.00
0005432459425	3334	Economy	6300.00
0005432459405	3334	Economy	6300.00
0005432459230	3334	Economy	6300.00
0005432181699	3334	Economy	6300.00
0005433633771	3334	Economy	6300.00
0005433805339	3334	Economy	6300.00
0005433633786	3334	Economy	6300.00
0005433633788	3334	Economy	6300.00
0005433805332	3334	Economy	6300.00
0005432459273	3334	Economy	6300.00
0005432459473	3334	Economy	6300.00
0005432459302	3334	Economy	6300.00
0005433633802	3334	Economy	6300.00
0005433633773	3334	Economy	6300.00
0005433633772	3334	Economy	6300.00
0005432459225	3334	Economy	6300.00
0005432459272	3334	Economy	6300.00
0005432459301	3334	Economy	6300.00
0005432459537	3334	Economy	6300.00
0005432181684	3334	Economy	6300.00
0005433805328	3334	Economy	6300.00
0005432459506	3334	Economy	6300.00
0005432459359	3334	Economy	6300.00
0005435884903	3333	Business	18800.00
0005435884886	3333	Business	18800.00
0005435884924	3333	Business	18800.00
0005435884775	3333	Business	18800.00
0005435884585	3333	Business	18800.00
0005435884909	3333	Business	18800.00
0005435884893	3333	Business	18800.00
0005435884738	3333	Business	18800.00
0005435884528	3333	Business	18800.00
0005435884586	3333	Economy	6900.00
0005435884880	3333	Economy	6900.00
0005435884858	3333	Economy	6900.00
0005435884584	3333	Economy	6900.00
0005435884899	3333	Economy	6300.00
0005435884817	3333	Economy	6300.00
0005435884922	3333	Economy	6300.00
0005435884964	3333	Economy	6300.00
0005435884910	3333	Economy	6300.00
0005435884875	3333	Economy	6300.00
0005435884594	3333	Economy	6300.00
0005435884598	3333	Economy	6300.00
0005435884722	3333	Economy	6300.00
0005435884809	3333	Economy	6300.00
0005435884838	3333	Economy	6300.00
0005435885130	3333	Economy	6300.00
0005435885000	3333	Economy	6300.00
0005435884853	3333	Economy	6300.00
0005435884776	3333	Economy	6300.00
0005435884863	3333	Economy	6300.00
0005435884979	3333	Economy	6300.00
0005435884778	3333	Economy	6300.00
0005435884900	3333	Economy	6300.00
0005435884943	3333	Economy	6300.00
0005435884881	3333	Economy	6300.00
0005435884920	3333	Economy	6300.00
0005435884721	3333	Economy	6300.00
0005435884777	3333	Economy	6300.00
0005435884562	3333	Economy	6900.00
0005435884750	3333	Economy	6900.00
0005435884908	3333	Economy	6900.00
0005435884669	3333	Economy	6300.00
0005435884686	3333	Economy	6300.00
0005435884877	3333	Economy	6900.00
0005435884461	3333	Economy	6300.00
0005435884862	3333	Economy	6300.00
0005435884854	3333	Economy	6300.00
0005435884861	3333	Economy	6300.00
0005435884930	3333	Economy	6300.00
0005435884684	3333	Economy	6300.00
0005435885016	3333	Economy	6300.00
0005435884931	3333	Economy	6300.00
0005435884869	3333	Economy	6300.00
0005435884885	3333	Economy	6300.00
0005435884950	3333	Economy	6300.00
0005435884774	3333	Economy	6300.00
0005435884723	3333	Economy	6300.00
0005435884857	3333	Economy	6300.00
0005435884923	3333	Economy	6300.00
0005435884921	3333	Economy	6300.00
0005435884942	3333	Economy	6300.00
0005435885001	3333	Economy	6300.00
0005435884870	3333	Economy	6300.00
0005435884685	3333	Economy	6300.00
0005432042697	8218	Business	18800.00
0005435885189	8218	Business	18800.00
0005432459862	8218	Business	18800.00
0005432459819	8218	Business	18800.00
0005435885203	8218	Business	18800.00
0005432459858	8218	Business	18800.00
0005435885238	8218	Business	18800.00
0005435885202	8218	Business	18800.00
0005435885231	8218	Business	18800.00
0005432459851	8218	Business	18800.00
0005432459848	8218	Business	18800.00
0005435885183	8218	Business	18800.00
0005435885209	8218	Business	18800.00
0005432459855	8218	Business	18800.00
0005432459843	8218	Business	18800.00
0005432459817	8218	Business	18800.00
0005432459820	8218	Business	18800.00
0005432459837	8218	Business	18800.00
0005432459844	8218	Business	18800.00
0005435885230	8218	Business	18800.00
0005432459860	8218	Business	18800.00
0005435885193	8218	Business	18800.00
0005432459838	8218	Business	18800.00
0005435885208	8218	Business	18800.00
0005435885190	8218	Business	18800.00
0005433506961	8218	Business	18800.00
0005435885185	8218	Economy	6900.00
0005435885198	8218	Economy	6900.00
0005435885191	8218	Economy	6900.00
0005434312319	8218	Economy	6900.00
0005435885207	8218	Economy	6300.00
0005432459813	8218	Economy	6300.00
0005435885197	8218	Economy	6300.00
0005435885205	8218	Economy	6300.00
0005435885195	8218	Economy	6300.00
0005432459832	8218	Economy	6300.00
0005432459821	8218	Economy	6300.00
0005435885188	8218	Economy	6300.00
0005432459839	8218	Economy	6300.00
0005433506984	8218	Economy	6300.00
0005433506985	8218	Economy	6300.00
0005433507000	8218	Economy	6300.00
0005435885221	8218	Economy	6300.00
0005435885211	8218	Economy	6300.00
0005432459818	8218	Economy	6300.00
0005435885214	8218	Economy	6300.00
0005433506952	8218	Economy	6300.00
0005432042703	8218	Economy	6300.00
0005435885210	8218	Economy	6300.00
0005435885222	8218	Economy	6300.00
0005432459836	8218	Economy	6300.00
0005432459840	8218	Economy	6300.00
0005435885215	8218	Economy	6300.00
0005433506983	8218	Economy	6300.00
0005433506939	8218	Economy	6300.00
0005435885186	8218	Economy	6300.00
0005435885223	8218	Economy	6300.00
0005435885194	8218	Economy	6300.00
0005435885226	8218	Economy	6300.00
0005432459831	8218	Economy	6300.00
0005435885228	8218	Economy	6300.00
0005432459830	8218	Economy	6300.00
0005432459827	8218	Economy	6300.00
0005435885201	8218	Economy	6300.00
0005432459845	8218	Economy	6300.00
0005435885206	8218	Economy	6300.00
0005432042699	8218	Economy	6300.00
0005435885224	8218	Economy	6300.00
0005435885204	8218	Economy	6300.00
0005432042695	8218	Economy	6300.00
0005433506962	8218	Economy	6300.00
0005433506999	8218	Economy	6300.00
0005435885192	8218	Economy	6300.00
0005435885212	8218	Economy	6300.00
0005433506924	8218	Economy	6300.00
0005435885241	8218	Economy	6300.00
0005432459841	8218	Economy	6300.00
0005435885227	8218	Economy	6300.00
0005432459846	8218	Economy	6300.00
0005435885233	8218	Economy	6900.00
0005432042701	8218	Economy	6900.00
0005432459847	8218	Economy	6900.00
0005433506986	8218	Economy	6900.00
0005433506980	8218	Economy	6300.00
0005432459814	8218	Economy	6300.00
0005432459835	8218	Economy	6300.00
0005435885236	8218	Economy	6900.00
0005432459822	8218	Economy	6300.00
0005432459842	8218	Economy	6300.00
0005435885219	8218	Economy	6300.00
0005435885237	8218	Economy	6300.00
0005432459849	8218	Economy	6300.00
0005432459833	8218	Economy	6300.00
0005432042696	8218	Economy	6300.00
0005433506987	8218	Economy	6300.00
0005435885220	8218	Economy	6300.00
0005432459850	8218	Economy	6300.00
0005435885240	8218	Economy	6300.00
0005432042700	8218	Economy	6300.00
0005433507022	8218	Economy	6300.00
0005435885218	8218	Economy	6300.00
0005435885216	8218	Economy	6300.00
0005432459861	8218	Economy	6300.00
0005435885225	8218	Economy	6300.00
0005432459853	8218	Economy	6300.00
0005432459857	8218	Economy	6300.00
0005434312318	8218	Economy	6300.00
0005432459852	8218	Economy	6300.00
0005435885213	8218	Economy	6300.00
0005432459825	8218	Economy	6300.00
0005435885217	8218	Economy	6300.00
0005433506953	8218	Economy	6300.00
0005432042698	8218	Economy	6300.00
0005432042705	8218	Economy	6300.00
0005435885234	8218	Economy	6300.00
0005432459863	8218	Economy	6300.00
0005433506991	8218	Economy	6300.00
0005433507021	8218	Economy	6300.00
0005432042707	8218	Economy	6300.00
0005432459829	8218	Economy	6300.00
0005432459856	8218	Economy	6300.00
0005435885235	8218	Economy	6300.00
0005435885196	8218	Economy	6300.00
0005435885239	8218	Economy	6300.00
0005432459824	8218	Economy	6300.00
0005432459826	8218	Economy	6300.00
0005432042702	8218	Economy	6300.00
0005435885229	8218	Economy	6300.00
0005435885200	8218	Economy	6300.00
0005433506923	8218	Economy	6300.00
0005432459815	8218	Economy	6300.00
0005432459823	8218	Economy	6300.00
0005432459854	8218	Economy	6300.00
0005432459816	8218	Economy	6300.00
0005432042706	8218	Economy	6300.00
0005435885184	8218	Economy	6300.00
0005432459834	8218	Economy	6300.00
0005432042704	8218	Economy	6300.00
0005432459859	8218	Economy	6300.00
0005432459828	8218	Economy	6300.00
0005432042708	8218	Economy	6300.00
0005435885199	8218	Economy	6300.00
0005435885187	8218	Economy	6300.00
0005435885232	8218	Economy	6300.00
0005433804961	8216	Business	18800.00
0005433633445	8216	Business	18800.00
0005433633446	8216	Business	18800.00
0005433805005	8216	Business	18800.00
0005433804958	8216	Business	18800.00
0005433805053	8216	Business	18800.00
0005433633377	8216	Business	18800.00
0005433804981	8216	Economy	6900.00
0005433633522	8216	Economy	6900.00
0005433633460	8216	Economy	6900.00
0005433805020	8216	Economy	6900.00
0005433633546	8216	Economy	6300.00
0005433633421	8216	Economy	6300.00
0005433633419	8216	Economy	6300.00
0005433633554	8216	Economy	6300.00
0005434143712	8216	Economy	6300.00
0005433633376	8216	Economy	6300.00
0005433804980	8216	Economy	6300.00
0005433633443	8216	Economy	6300.00
0005433633316	8216	Economy	6300.00
0005433633596	8216	Economy	6300.00
0005433805055	8216	Economy	6300.00
0005433633592	8216	Economy	6300.00
0005434271292	8216	Economy	6300.00
0005433633436	8216	Economy	6300.00
0005433633498	8216	Economy	6300.00
0005433633468	8216	Economy	6300.00
0005433633481	8216	Economy	6300.00
0005433805049	8216	Economy	6300.00
0005433633450	8216	Economy	6300.00
0005433633464	8216	Economy	6300.00
0005433805056	8216	Economy	6300.00
0005433805067	8216	Economy	6300.00
0005433633482	8216	Economy	6300.00
0005433805068	8216	Economy	6300.00
0005433804919	8216	Economy	6300.00
0005433633303	8216	Economy	6300.00
0005433805066	8216	Economy	6300.00
0005433805078	8216	Economy	6300.00
0005433633365	8216	Economy	6300.00
0005433804960	8216	Economy	6300.00
0005433805021	8216	Economy	6900.00
0005433805035	8216	Economy	6900.00
0005433633461	8216	Economy	6900.00
0005433805104	8216	Economy	6300.00
0005433805052	8216	Economy	6300.00
0005433633491	8216	Economy	6300.00
0005433633292	8216	Economy	6300.00
0005433633472	8216	Economy	6300.00
0005433805036	8216	Economy	6300.00
0005433805114	8216	Economy	6300.00
0005434271289	8216	Economy	6300.00
0005433805117	8216	Economy	6300.00
0005433805010	8216	Economy	6300.00
0005433633309	8216	Economy	6300.00
0005433805118	8216	Economy	6300.00
0005433633422	8216	Economy	6300.00
0005433633378	8216	Economy	6300.00
0005433633512	8216	Economy	6300.00
0005433805116	8216	Economy	6300.00
0005433804959	8216	Economy	6300.00
0005433633598	8216	Economy	6300.00
0005433633366	8216	Economy	6300.00
0005433633591	8216	Economy	6300.00
0005433633515	8216	Economy	6300.00
0005433805048	8216	Economy	6300.00
0005433633379	8216	Economy	6300.00
0005433805004	8216	Economy	6300.00
0005433633451	8216	Economy	6300.00
0005433805065	8216	Economy	6300.00
0005433633367	8216	Economy	6300.00
0005433633433	8216	Economy	6300.00
0005433633469	8216	Economy	6300.00
0005433633471	8216	Economy	6300.00
0005433805131	8216	Economy	6300.00
0005433633323	8216	Economy	6300.00
0005433633597	8216	Economy	6300.00
0005433633511	8216	Economy	6300.00
0005433633547	8216	Economy	6300.00
0005433805137	8216	Economy	6300.00
0005433633416	8216	Economy	6300.00
0005433805009	8216	Economy	6300.00
0005433633417	8216	Economy	6300.00
0005434183561	8213	Economy	6900.00
0005434183562	8213	Economy	6300.00
0005432727926	4618	Business	9900.00
0005432383149	4618	Business	9900.00
0005432727924	4618	Business	9900.00
0005433194857	4618	Business	9900.00
0005433454873	4618	Business	9900.00
0005432727922	4618	Business	9900.00
0005432383131	4618	Business	9900.00
0005433722224	4618	Business	9900.00
0005432383152	4618	Business	9900.00
0005432383133	4618	Economy	3300.00
0005432383144	4618	Economy	3300.00
0005432383135	4618	Economy	3300.00
0005432383151	4618	Economy	3300.00
0005432383156	4618	Economy	3600.00
0005432383146	4618	Economy	3600.00
0005432383160	4618	Economy	3600.00
0005432727929	4618	Economy	3300.00
0005433722221	4618	Economy	3300.00
0005432383148	4618	Economy	3300.00
0005433722220	4618	Economy	3300.00
0005432383137	4618	Economy	3300.00
0005433194856	4618	Economy	3300.00
0005432727925	4618	Economy	3300.00
0005432383154	4618	Economy	3300.00
0005433454874	4618	Economy	3300.00
0005432383158	4618	Economy	3300.00
0005432383129	4618	Economy	3300.00
0005432727930	4618	Economy	3300.00
0005432727932	4618	Economy	3300.00
0005432383141	4618	Economy	3300.00
0005433722217	4618	Economy	3300.00
0005432383155	4618	Economy	3300.00
0005432383159	4618	Economy	3300.00
0005432383166	4618	Economy	3300.00
0005433722219	4618	Economy	3300.00
0005432383157	4618	Economy	3300.00
0005432383145	4618	Economy	3300.00
0005432383136	4618	Economy	3300.00
0005432383138	4618	Economy	3300.00
0005433453761	4618	Economy	3300.00
0005432383163	4618	Economy	3300.00
0005433453763	4618	Economy	3300.00
0005432727923	4618	Economy	3300.00
0005433453762	4618	Economy	3300.00
0005433454875	4618	Economy	3300.00
0005433722218	4618	Economy	3300.00
0005432383139	4618	Economy	3300.00
0005433722222	4618	Economy	3300.00
0005432727931	4618	Economy	3300.00
0005432383161	4618	Economy	3300.00
0005432383134	4618	Economy	3300.00
0005432383140	4618	Economy	3300.00
0005432383132	4618	Economy	3300.00
0005432383153	4618	Economy	3300.00
0005432383165	4618	Economy	3300.00
0005432383147	4618	Economy	3300.00
0005432383130	4618	Economy	3300.00
0005432383150	4618	Economy	3300.00
0005433722223	4618	Economy	3300.00
0005432383162	4618	Economy	3300.00
0005432383143	4618	Economy	3300.00
0005432383142	4618	Economy	3300.00
0005432727927	4618	Economy	3300.00
0005432727928	4618	Economy	3300.00
0005432383164	4618	Economy	3300.00
0005433722132	30158	Business	9900.00
0005432382697	30158	Business	9900.00
0005432727775	30158	Business	9900.00
0005432727799	30158	Business	9900.00
0005432382554	30158	Business	9900.00
0005432382774	30158	Business	9900.00
0005432727856	30158	Business	9900.00
0005433722134	30158	Business	9900.00
0005432382675	30158	Business	9900.00
0005432382705	30158	Business	9900.00
0005432382608	30158	Economy	3300.00
0005432382727	30158	Economy	3300.00
0005432382819	30158	Economy	3300.00
0005432727800	30158	Economy	3300.00
0005433453746	30158	Economy	3300.00
0005433722138	30158	Economy	3300.00
0005432382723	30158	Economy	3600.00
0005432382552	30158	Economy	3600.00
0005432382603	30158	Economy	3600.00
0005432382602	30158	Economy	3600.00
0005432382871	30158	Economy	3600.00
0005433722122	30158	Economy	3300.00
0005432727867	30158	Economy	3300.00
0005432382679	30158	Economy	3300.00
0005432727806	30158	Economy	3300.00
0005432382574	30158	Economy	3300.00
0005433722133	30158	Economy	3300.00
0005432382627	30158	Economy	3300.00
0005432382650	30158	Economy	3300.00
0005432382658	30158	Economy	3300.00
0005432382737	30158	Economy	3300.00
0005432382630	30158	Economy	3300.00
0005432382717	30158	Economy	3300.00
0005433453745	30158	Economy	3300.00
0005432382553	30158	Economy	3300.00
0005432382840	30158	Economy	3300.00
0005432382568	30158	Economy	3300.00
0005432727774	30158	Economy	3300.00
0005432382542	30158	Economy	3300.00
0005432382758	30158	Economy	3300.00
0005432727866	30158	Economy	3300.00
0005432382686	30158	Economy	3300.00
0005432382659	30158	Economy	3300.00
0005433722135	30158	Economy	3300.00
0005433451597	30158	Economy	3300.00
0005432382674	30158	Economy	3300.00
0005432382701	30158	Economy	3300.00
0005433451589	30158	Economy	3300.00
0005432382540	30158	Economy	3300.00
0005432727810	30158	Economy	3300.00
0005432382631	30158	Economy	3300.00
0005432382704	30158	Economy	3300.00
0005432727783	30158	Economy	3300.00
0005432727740	30158	Economy	3300.00
0005432382569	30158	Economy	3300.00
0005433722139	30158	Economy	3300.00
0005432382839	30158	Economy	3300.00
0005432382716	30158	Economy	3300.00
0005432382841	30158	Economy	3300.00
0005432382623	30158	Economy	3300.00
0005432382604	30158	Economy	3300.00
0005432382660	30158	Economy	3300.00
0005432382543	30158	Economy	3300.00
0005432382628	30158	Economy	3300.00
0005432727803	30158	Economy	3300.00
0005432382836	30158	Economy	3300.00
0005432382685	30158	Economy	3300.00
0005432382703	30158	Economy	3300.00
0005433722102	30158	Economy	3300.00
0005432382632	30158	Economy	3300.00
0005433453737	30158	Economy	3300.00
0005433516882	1756	Business	57200.00
0005435540989	1756	Business	57200.00
0005435540995	1756	Business	57200.00
0005435540982	1756	Business	57200.00
0005435529254	1756	Business	57200.00
0005433516877	1756	Business	57200.00
0005435529239	1756	Economy	19100.00
0005435529237	1756	Economy	19100.00
0005435540979	1756	Economy	19100.00
0005435540987	1756	Economy	19100.00
0005432294484	1756	Economy	19100.00
0005433516880	1756	Economy	21000.00
0005435529238	1756	Economy	21000.00
0005435529240	1756	Economy	21000.00
0005435540988	1756	Economy	21000.00
0005435540983	1756	Economy	21000.00
0005435529246	1756	Economy	19100.00
0005435529251	1756	Economy	19100.00
0005433516878	1756	Economy	19100.00
0005435529235	1756	Economy	19100.00
0005435529253	1756	Economy	19100.00
0005433516879	1756	Economy	19100.00
0005435529247	1756	Economy	19100.00
0005435540978	1756	Economy	19100.00
0005432294486	1756	Economy	19100.00
0005433516881	1756	Economy	19100.00
0005435529241	1756	Economy	19100.00
0005435540992	1756	Economy	19100.00
0005432924984	1756	Economy	19100.00
0005435540980	1756	Economy	19100.00
0005432924988	1756	Economy	19100.00
0005433516883	1756	Economy	19100.00
0005432924979	1756	Economy	19100.00
0005432294485	1756	Economy	19100.00
0005435529234	1756	Economy	19100.00
0005435540993	1756	Economy	19100.00
0005435540998	1756	Economy	19100.00
0005435529244	1756	Economy	19100.00
0005435540990	1756	Economy	19100.00
0005433516876	1756	Economy	19100.00
0005435529248	1756	Economy	19100.00
0005435540986	1756	Economy	19100.00
0005435529252	1756	Economy	19100.00
0005435540981	1756	Economy	19100.00
0005435540994	1756	Economy	19100.00
0005435540991	1756	Economy	19100.00
0005435529255	1756	Economy	19100.00
0005435540985	1756	Economy	19100.00
0005435540997	1756	Economy	19100.00
0005435529250	1756	Economy	19100.00
0005435529249	1756	Economy	19100.00
0005435540984	1756	Economy	19100.00
0005435529243	1756	Economy	19100.00
0005435540996	1756	Economy	19100.00
0005433516875	1756	Economy	19100.00
0005435529242	1756	Economy	19100.00
0005435529236	1756	Economy	19100.00
0005435529245	1756	Economy	19100.00
0005435540770	22001	Business	57200.00
0005433516795	22001	Business	57200.00
0005435540792	22001	Business	57200.00
0005435540807	22001	Business	57200.00
0005435517697	22001	Business	57200.00
0005433516753	22001	Business	57200.00
0005433516786	22001	Business	57200.00
0005435517671	22001	Business	57200.00
0005435517693	22001	Business	57200.00
0005433516781	22001	Business	57200.00
0005432925032	22001	Economy	19100.00
0005433516799	22001	Economy	19100.00
0005435517782	22001	Economy	19100.00
0005435540744	22001	Economy	19100.00
0005435517695	22001	Economy	19100.00
0005435517696	22001	Economy	19100.00
0005435517730	22001	Economy	21000.00
0005435517692	22001	Economy	21000.00
0005435540789	22001	Economy	21000.00
0005435517701	22001	Economy	21000.00
0005435517721	22001	Economy	19100.00
0005435517663	22001	Economy	19100.00
0005435540773	22001	Economy	19100.00
0005435540808	22001	Economy	19100.00
0005433516794	22001	Economy	19100.00
0005432925031	22001	Economy	19100.00
0005433516802	22001	Economy	19100.00
0005435540771	22001	Economy	19100.00
0005433516798	22001	Economy	19100.00
0005435517757	22001	Economy	19100.00
0005433516780	22001	Economy	19100.00
0005435517760	22001	Economy	19100.00
0005435517702	22001	Economy	19100.00
0005435540877	22001	Economy	19100.00
0005435517691	22001	Economy	19100.00
0005435540787	22001	Economy	19100.00
0005433516785	22001	Economy	19100.00
0005435517735	22001	Economy	19100.00
0005435540860	22001	Economy	19100.00
0005432925034	22001	Economy	19100.00
0005433516790	22001	Economy	19100.00
0005435517690	22001	Economy	19100.00
0005432925030	22001	Economy	19100.00
0005435517737	22001	Economy	19100.00
0005433516778	22001	Economy	19100.00
0005435517783	22001	Economy	19100.00
0005435517731	22001	Economy	19100.00
0005435540767	22001	Economy	19100.00
0005435517717	22001	Economy	19100.00
0005435540818	22001	Economy	19100.00
0005435540779	22001	Economy	19100.00
0005435517694	22001	Economy	19100.00
0005435540736	22001	Economy	19100.00
0005433516806	22001	Economy	19100.00
0005435540745	22001	Economy	19100.00
0005435540785	22001	Economy	19100.00
0005435540734	22001	Economy	19100.00
0005435540786	22001	Economy	19100.00
0005435540688	22001	Economy	19100.00
0005435517670	22001	Economy	19100.00
0005435540809	22001	Economy	19100.00
0005435540857	22001	Economy	19100.00
0005435540689	22001	Economy	19100.00
0005435540878	22001	Economy	19100.00
0005435517682	22001	Economy	19100.00
0005432925033	22001	Economy	19100.00
0005435540720	22001	Economy	19100.00
0005435540788	22001	Economy	19100.00
0005432838994	7383	Business	18500.00
0005434458792	7383	Business	18500.00
0005432838997	7383	Business	18500.00
0005432839014	7383	Business	18500.00
0005435252571	7383	Business	18500.00
0005434458794	7383	Business	18500.00
0005434458793	7383	Business	18500.00
0005432839003	7383	Business	18500.00
0005434458788	7383	Business	18500.00
0005432838996	7383	Economy	6200.00
0005435252530	7383	Economy	6200.00
0005432839002	7383	Economy	6200.00
0005434458782	7383	Economy	6200.00
0005434458774	7383	Economy	6200.00
0005432839021	7383	Economy	6200.00
0005432839017	7383	Economy	6200.00
0005435252565	7383	Economy	6200.00
0005434458780	7383	Economy	6200.00
0005434458779	7383	Economy	6200.00
0005432839018	7383	Economy	6800.00
0005434664942	7383	Economy	6800.00
0005432839004	7383	Economy	6800.00
0005432839000	7383	Economy	6800.00
0005432073387	7383	Economy	6800.00
0005432073388	7383	Economy	6200.00
0005435252596	7383	Economy	6200.00
0005435252634	7383	Economy	6200.00
0005432839005	7383	Economy	6200.00
0005432841009	7383	Economy	6200.00
0005434458776	7383	Economy	6200.00
0005435252453	7383	Economy	6200.00
0005435491422	7383	Economy	6200.00
0005435252552	7383	Economy	6200.00
0005432838991	7383	Economy	6200.00
0005435252597	7383	Economy	6200.00
0005432838995	7383	Economy	6200.00
0005434458778	7383	Economy	6200.00
0005432839013	7383	Economy	6200.00
0005434458777	7383	Economy	6200.00
0005434458775	7383	Economy	6200.00
0005435252549	7383	Economy	6200.00
0005432839008	7383	Economy	6200.00
0005435252499	7383	Economy	6200.00
0005432839009	7383	Economy	6200.00
0005435252458	7383	Economy	6200.00
0005434458790	7383	Economy	6200.00
0005434458784	7383	Economy	6200.00
0005432839006	7383	Economy	6200.00
0005435252555	7383	Economy	6200.00
0005435252454	7383	Economy	6200.00
0005432839015	7383	Economy	6200.00
0005432839001	7383	Economy	6200.00
0005435491421	7383	Economy	6200.00
0005432839012	7383	Economy	6200.00
0005432838998	7383	Economy	6200.00
0005432823445	7383	Economy	6200.00
0005435491420	7383	Economy	6200.00
0005432841010	7383	Economy	6200.00
0005434664930	7383	Economy	6200.00
0005432839016	7383	Economy	6200.00
0005434664931	7383	Economy	6200.00
0005434458785	7383	Economy	6200.00
0005432839007	7383	Economy	6200.00
0005435252553	7383	Economy	6200.00
0005432839011	7383	Economy	6200.00
0005432839019	7383	Economy	6200.00
0005434458783	7383	Economy	6200.00
0005432838992	7383	Economy	6200.00
0005432823447	7383	Economy	6200.00
0005432839020	7383	Economy	6200.00
0005434458781	7383	Economy	6200.00
0005435252635	7383	Economy	6200.00
0005432838990	7383	Economy	6200.00
0005432823446	7383	Economy	6200.00
0005434458787	7383	Economy	6200.00
0005432838993	7383	Economy	6200.00
0005432839010	7383	Economy	6200.00
0005434458791	7383	Economy	6200.00
0005435252498	7383	Economy	6200.00
0005435252468	7383	Economy	6200.00
0005434458789	7383	Economy	6200.00
0005435252529	7383	Economy	6200.00
0005434458786	7383	Economy	6200.00
0005432838999	7383	Economy	6200.00
0005435252554	7383	Economy	6200.00
0005435252692	28926	Business	18500.00
0005432838854	28926	Business	18500.00
0005432838604	28926	Business	18500.00
0005434458596	28926	Business	18500.00
0005434664959	28926	Business	18500.00
0005432838704	28926	Business	18500.00
0005434458593	28926	Business	18500.00
0005435252686	28926	Business	18500.00
0005432838836	28926	Business	18500.00
0005432838855	28926	Business	18500.00
0005432838807	28926	Business	18500.00
0005434458643	28926	Business	18500.00
0005434458683	28926	Economy	6200.00
0005434458649	28926	Economy	6200.00
0005432838733	28926	Economy	6200.00
0005432838757	28926	Economy	6200.00
0005432838834	28926	Economy	6200.00
0005434458585	28926	Economy	6200.00
0005435252682	28926	Economy	6200.00
0005432838742	28926	Economy	6200.00
0005432838824	28926	Economy	6200.00
0005432838734	28926	Economy	6200.00
0005432001020	28926	Economy	6800.00
0005434458582	28926	Economy	6800.00
0005434458581	28926	Economy	6800.00
0005432838696	28926	Economy	6800.00
0005432838901	28926	Economy	6800.00
0005435252681	28926	Economy	6200.00
0005432838831	28926	Economy	6200.00
0005432838674	28926	Economy	6200.00
0005434458660	28926	Economy	6200.00
0005434458659	28926	Economy	6200.00
0005432838689	28926	Economy	6200.00
0005435252694	28926	Economy	6200.00
0005434458644	28926	Economy	6200.00
0005432838907	28926	Economy	6200.00
0005434458652	28926	Economy	6200.00
0005435252684	28926	Economy	6200.00
0005432838736	28926	Economy	6200.00
0005432001021	28926	Economy	6200.00
0005432838667	28926	Economy	6200.00
0005434458635	28926	Economy	6200.00
0005432838606	28926	Economy	6200.00
0005434458650	28926	Economy	6200.00
0005434458684	28926	Economy	6200.00
0005435252679	28926	Economy	6200.00
0005432838801	28926	Economy	6200.00
0005434458594	28926	Economy	6200.00
0005432838672	28926	Economy	6200.00
0005434458595	28926	Economy	6200.00
0005432838723	28926	Economy	6200.00
0005432838825	28926	Economy	6200.00
0005432838766	28926	Economy	6200.00
0005434458653	28926	Economy	6200.00
0005434458642	28926	Economy	6200.00
0005432838773	28926	Economy	6200.00
0005434458561	28926	Economy	6200.00
0005434458685	28926	Economy	6200.00
0005432838642	28926	Economy	6200.00
0005435252689	28926	Economy	6200.00
0005434458584	28926	Economy	6200.00
0005435252685	28926	Economy	6200.00
0005435252695	28926	Economy	6200.00
0005435252677	28926	Economy	6200.00
0005432838906	28926	Economy	6200.00
0005434664958	28926	Economy	6200.00
0005435252680	28926	Economy	6200.00
0005432838666	28926	Economy	6200.00
0005432838758	28926	Economy	6200.00
0005435252687	28926	Economy	6200.00
0005432838835	28926	Economy	6200.00
0005432838764	28926	Economy	6200.00
0005432838832	28926	Economy	6200.00
0005435252690	28926	Economy	6200.00
0005432838767	28926	Economy	6200.00
0005432838705	28926	Economy	6200.00
0005434458560	28926	Economy	6200.00
0005432838673	28926	Economy	6200.00
0005435252693	28926	Economy	6200.00
0005432840991	28926	Economy	6200.00
0005435252691	28926	Economy	6200.00
0005432838772	28926	Economy	6200.00
0005432838688	28926	Economy	6200.00
0005435252688	28926	Economy	6200.00
0005432838844	28926	Economy	6200.00
0005434458637	28926	Economy	6200.00
0005435252678	28926	Economy	6200.00
0005434458580	28926	Economy	6200.00
0005432840996	28926	Economy	6200.00
0005432838802	28926	Economy	6200.00
0005435252683	28926	Economy	6200.00
0005432838735	28926	Economy	6200.00
0005434458651	28926	Economy	6200.00
0005432838812	28926	Economy	6200.00
0005432838605	28926	Economy	6200.00
0005434664957	28926	Economy	6200.00
0005434458574	28926	Economy	6200.00
0005435990617	8806	Business	145300.00
0005435990619	8806	Business	145300.00
0005435990616	8806	Business	145300.00
0005434275989	8806	Economy	48400.00
0005434275990	8806	Economy	53300.00
0005434275998	8806	Economy	48400.00
0005434275992	8806	Economy	48400.00
0005435990614	8806	Economy	48400.00
0005434275988	8806	Economy	48400.00
0005435990615	8806	Economy	48400.00
0005435990613	8806	Economy	48400.00
0005434275991	8806	Economy	48400.00
0005435990618	8806	Economy	48400.00
0005435990550	15718	Business	145300.00
0005435990542	15718	Business	145300.00
0005434276021	15718	Economy	48400.00
0005434276018	15718	Economy	48400.00
0005435990523	15718	Economy	48400.00
0005434276020	15718	Economy	48400.00
0005434276019	15718	Economy	48400.00
0005435990570	15718	Economy	48400.00
0005435990530	15718	Economy	48400.00
0005434276022	15718	Economy	48400.00
0005434276023	15718	Economy	48400.00
0005434276024	15718	Economy	48400.00
0005435990531	15718	Economy	48400.00
0005435990575	15718	Economy	48400.00
0005433468319	2085	Economy	13300.00
0005432909226	2085	Economy	13300.00
0005433468325	2085	Economy	12100.00
0005433468332	2085	Economy	12100.00
0005433468333	2085	Economy	12100.00
0005433468334	2085	Economy	12100.00
0005433468321	2085	Economy	12100.00
0005432909207	2085	Economy	12100.00
0005432909214	2085	Economy	12100.00
0005432909209	2085	Economy	12100.00
0005433468328	2085	Economy	12100.00
0005433468326	2085	Economy	12100.00
0005433468331	2085	Economy	12100.00
0005432909208	2085	Economy	12100.00
0005432909232	2085	Economy	12100.00
0005432909229	2085	Economy	12100.00
0005433468322	2085	Economy	12100.00
0005433468318	2085	Economy	12100.00
0005433468323	2085	Economy	12100.00
0005433468329	2085	Economy	12100.00
0005433468330	2085	Economy	12100.00
0005432909215	2085	Economy	12100.00
0005433468320	2085	Economy	12100.00
0005433468324	2085	Economy	12100.00
0005433468335	2085	Economy	12100.00
0005433468317	2085	Economy	12100.00
0005433468327	2085	Economy	12100.00
0005433468253	23844	Economy	13300.00
0005433468212	23844	Economy	13300.00
0005432909281	23844	Economy	13300.00
0005433468275	23844	Economy	13300.00
0005433468230	23844	Economy	12100.00
0005433468244	23844	Economy	12100.00
0005433468255	23844	Economy	12100.00
0005432909266	23844	Economy	12100.00
0005433468242	23844	Economy	12100.00
0005433468231	23844	Economy	12100.00
0005433468248	23844	Economy	12100.00
0005433468251	23844	Economy	12100.00
0005432909279	23844	Economy	12100.00
0005432909273	23844	Economy	12100.00
0005433468209	23844	Economy	12100.00
0005433468204	23844	Economy	12100.00
0005432909282	23844	Economy	12100.00
0005433468274	23844	Economy	12100.00
0005433468210	23844	Economy	12100.00
0005433468232	23844	Economy	12100.00
0005433468252	23844	Economy	12100.00
0005432909270	23844	Economy	12100.00
0005433468261	23844	Economy	12100.00
0005433468228	23844	Economy	12100.00
0005433468249	23844	Economy	12100.00
0005432909274	23844	Economy	12100.00
0005432909272	23844	Economy	12100.00
0005433468243	23844	Economy	12100.00
0005432909271	23844	Economy	12100.00
0005433468235	23844	Economy	12100.00
0005433468211	23844	Economy	12100.00
0005433468247	23844	Economy	12100.00
0005433468254	23844	Economy	12100.00
0005433468236	23844	Economy	12100.00
0005433468266	23844	Economy	12100.00
0005433468224	23844	Economy	12100.00
0005432909268	23844	Economy	12100.00
0005433468229	23844	Economy	12100.00
0005432909275	23844	Economy	12100.00
0005433468240	23844	Economy	12100.00
0005432909276	23844	Economy	12100.00
0005432909269	23844	Economy	12100.00
0005433468234	23844	Economy	12100.00
0005433468259	23844	Economy	12100.00
0005432909267	23844	Economy	12100.00
0005432909278	23844	Economy	12100.00
0005432909280	23844	Economy	12100.00
0005432909277	23844	Economy	12100.00
0005435176921	6413	Business	36600.00
0005435176800	6413	Business	36600.00
0005432360329	6413	Business	36600.00
0005432360298	6413	Business	36600.00
0005432360296	6413	Business	36600.00
0005435176788	6413	Business	36600.00
0005435176944	6413	Business	36600.00
0005435176898	6413	Business	36600.00
0005434149618	6413	Business	36600.00
0005435176907	6413	Business	36600.00
0005432336020	6413	Business	36600.00
0005435176846	6413	Business	36600.00
0005435176801	6413	Economy	12200.00
0005432062225	6413	Economy	12200.00
0005432360326	6413	Economy	12200.00
0005432360335	6413	Economy	12200.00
0005432360341	6413	Economy	12200.00
0005432360322	6413	Economy	12200.00
0005432360312	6413	Economy	12200.00
0005432336017	6413	Economy	12200.00
0005432360302	6413	Economy	12200.00
0005434149643	6413	Economy	12200.00
0005434149656	6413	Economy	12200.00
0005435176906	6413	Economy	12200.00
0005432360301	6413	Economy	12200.00
0005435723020	6413	Economy	12200.00
0005432360297	6413	Economy	12200.00
0005435176901	6413	Economy	12200.00
0005435176942	6413	Economy	12200.00
0005432360330	6413	Economy	12200.00
0005432363413	6413	Economy	12200.00
0005432360317	6413	Economy	12200.00
0005434149664	6413	Economy	12200.00
0005432360320	6413	Economy	12200.00
0005432360313	6413	Economy	12200.00
0005435176784	6413	Economy	12200.00
0005435176897	6413	Economy	12200.00
0005432360325	6413	Economy	12200.00
0005432360328	6413	Economy	12200.00
0005432360327	6413	Economy	12200.00
0005432360334	6413	Economy	12200.00
0005432360305	6413	Economy	12200.00
0005432360340	6413	Economy	12200.00
0005432336023	6413	Economy	12200.00
0005432360299	6413	Economy	12200.00
0005435176727	6413	Economy	12200.00
0005435176783	6413	Economy	12200.00
0005434149596	6413	Economy	12200.00
0005432363412	6413	Economy	13400.00
0005432360308	6413	Economy	13400.00
0005432336024	6413	Economy	13400.00
0005434149612	6413	Economy	13400.00
0005435176795	6413	Economy	13400.00
0005432062224	6413	Economy	13400.00
0005432360331	6413	Economy	12200.00
0005432360303	6413	Economy	12200.00
0005432336026	6413	Economy	12200.00
0005434149622	6413	Economy	12200.00
0005432360295	6413	Economy	12200.00
0005435176808	6413	Economy	12200.00
0005432360337	6413	Economy	12200.00
0005432062222	6413	Economy	12200.00
0005432360300	6413	Economy	12200.00
0005432360293	6413	Economy	12200.00
0005432336022	6413	Economy	12200.00
0005434149599	6413	Economy	12200.00
0005435176884	6413	Economy	12200.00
0005434149642	6413	Economy	12200.00
0005434149663	6413	Economy	12200.00
0005432336019	6413	Economy	12200.00
0005432360342	6413	Economy	12200.00
0005432360310	6413	Economy	12200.00
0005435176941	6413	Economy	12200.00
0005435176943	6413	Economy	12200.00
0005432336027	6413	Economy	12200.00
0005432360332	6413	Economy	12200.00
0005434149595	6413	Economy	12200.00
0005432360304	6413	Economy	12200.00
0005435176871	6413	Economy	12200.00
0005432360315	6413	Economy	12200.00
0005432360318	6413	Economy	12200.00
0005435176833	6413	Economy	12200.00
0005435176891	6413	Economy	12200.00
0005435490189	6413	Economy	12200.00
0005432336018	6413	Economy	12200.00
0005435176798	6413	Economy	12200.00
0005432336021	6413	Economy	12200.00
0005432360323	6413	Economy	12200.00
0005432062221	6413	Economy	12200.00
0005432336025	6413	Economy	12200.00
0005432360338	6413	Economy	12200.00
0005435176902	6413	Economy	12200.00
0005435176771	6413	Economy	12200.00
0005432360309	6413	Economy	12200.00
0005435176905	6413	Economy	12200.00
0005432360307	6413	Economy	12200.00
0005434149665	6413	Economy	12200.00
0005432360324	6413	Economy	12200.00
0005435176883	6413	Economy	12200.00
0005432360319	6413	Economy	12200.00
0005432360321	6413	Economy	12200.00
0005432336028	6413	Economy	12200.00
0005432360333	6413	Economy	12200.00
0005432336016	6413	Economy	12200.00
0005434149621	6413	Economy	12200.00
0005432062223	6413	Economy	12200.00
0005435176920	6413	Economy	12200.00
0005432360314	6413	Economy	12200.00
0005432360316	6413	Economy	12200.00
0005432360294	6413	Economy	12200.00
0005435176896	6413	Economy	12200.00
0005432360336	6413	Economy	12200.00
0005432360311	6413	Economy	12200.00
0005432062226	6413	Economy	12200.00
0005435176706	6413	Economy	12200.00
0005432360306	6413	Economy	12200.00
0005432360339	6413	Economy	12200.00
0005435177043	21022	Business	36600.00
0005435177038	21022	Business	36600.00
0005435177050	21022	Business	36600.00
0005432360069	21022	Business	36600.00
0005434149721	21022	Business	36600.00
0005432052742	21022	Business	36600.00
0005432363379	21022	Business	36600.00
0005432359775	21022	Business	36600.00
0005435177055	21022	Business	36600.00
0005432359866	21022	Business	36600.00
0005432359761	21022	Business	36600.00
0005432359857	21022	Business	36600.00
0005432359978	21022	Economy	12200.00
0005432359760	21022	Economy	12200.00
0005432360018	21022	Economy	12200.00
0005435177052	21022	Economy	12200.00
0005432335901	21022	Economy	12200.00
0005432359797	21022	Economy	12200.00
0005435177037	21022	Economy	12200.00
0005432359943	21022	Economy	12200.00
0005435490229	21022	Economy	12200.00
0005432335907	21022	Economy	12200.00
0005432360009	21022	Economy	12200.00
0005435177044	21022	Economy	12200.00
0005432363386	21022	Economy	12200.00
0005432360030	21022	Economy	12200.00
0005432359813	21022	Economy	12200.00
0005432360016	21022	Economy	12200.00
0005435177061	21022	Economy	12200.00
0005435177042	21022	Economy	12200.00
0005432335861	21022	Economy	12200.00
0005432359988	21022	Economy	12200.00
0005435177056	21022	Economy	12200.00
0005432335913	21022	Economy	12200.00
0005432335988	21022	Economy	12200.00
0005432360040	21022	Economy	12200.00
0005432360074	21022	Economy	12200.00
0005435177045	21022	Economy	12200.00
0005432359776	21022	Economy	12200.00
0005432359860	21022	Economy	12200.00
0005435177051	21022	Economy	12200.00
0005435177063	21022	Economy	12200.00
0005432335924	21022	Economy	12200.00
0005432335900	21022	Economy	12200.00
0005432359981	21022	Economy	12200.00
0005432359834	21022	Economy	12200.00
0005432363387	21022	Economy	12200.00
0005432359732	21022	Economy	12200.00
0005432359989	21022	Economy	12200.00
0005432359756	21022	Economy	13400.00
0005432359832	21022	Economy	13400.00
0005435723043	21022	Economy	13400.00
0005435177062	21022	Economy	13400.00
0005435177039	21022	Economy	13400.00
0005432335956	21022	Economy	13400.00
0005432335923	21022	Economy	12200.00
0005435177054	21022	Economy	12200.00
0005435177060	21022	Economy	12200.00
0005432359950	21022	Economy	12200.00
0005432360057	21022	Economy	12200.00
0005432359868	21022	Economy	12200.00
0005434149719	21022	Economy	12200.00
0005434149713	21022	Economy	12200.00
0005432360029	21022	Economy	12200.00
0005435490227	21022	Economy	12200.00
0005432359976	21022	Economy	12200.00
0005432359711	21022	Economy	12200.00
0005434149723	21022	Economy	12200.00
0005432335888	21022	Economy	12200.00
0005434149724	21022	Economy	12200.00
0005432359820	21022	Economy	12200.00
0005435177047	21022	Economy	12200.00
0005432359977	21022	Economy	12200.00
0005435177064	21022	Economy	12200.00
0005432359872	21022	Economy	12200.00
0005432359928	21022	Economy	12200.00
0005432359856	21022	Economy	12200.00
0005432335887	21022	Economy	12200.00
0005435177046	21022	Economy	12200.00
0005432360037	21022	Economy	12200.00
0005434149714	21022	Economy	12200.00
0005432359867	21022	Economy	12200.00
0005432052743	21022	Economy	12200.00
0005435177049	21022	Economy	12200.00
0005432359759	21022	Economy	12200.00
0005434149722	21022	Economy	12200.00
0005435177053	21022	Economy	12200.00
0005432359942	21022	Economy	12200.00
0005432359812	21022	Economy	12200.00
0005434149717	21022	Economy	12200.00
0005432359861	21022	Economy	12200.00
0005432335906	21022	Economy	12200.00
0005434149715	21022	Economy	12200.00
0005432335942	21022	Economy	12200.00
0005432335905	21022	Economy	12200.00
0005434149720	21022	Economy	12200.00
0005432359925	21022	Economy	12200.00
0005435177058	21022	Economy	12200.00
0005434149716	21022	Economy	12200.00
0005432359877	21022	Economy	12200.00
0005435177041	21022	Economy	12200.00
0005432335909	21022	Economy	12200.00
0005432359862	21022	Economy	12200.00
0005432359966	21022	Economy	12200.00
0005432359824	21022	Economy	12200.00
0005432359725	21022	Economy	12200.00
0005435177059	21022	Economy	12200.00
0005434149718	21022	Economy	12200.00
0005435177057	21022	Economy	12200.00
0005432359900	21022	Economy	12200.00
0005435723044	21022	Economy	12200.00
0005435177048	21022	Economy	12200.00
0005432359933	21022	Economy	12200.00
0005432335889	21022	Economy	12200.00
0005435177040	21022	Economy	12200.00
0005432052744	21022	Economy	12200.00
0005432359940	21022	Economy	12200.00
0005432359916	21022	Economy	12200.00
0005432360079	21022	Economy	12200.00
0005435490228	21022	Economy	12200.00
0005432359941	21022	Economy	12200.00
0005432335895	21022	Economy	12200.00
0005432359905	21022	Economy	12200.00
0005432363388	21022	Economy	12200.00
0005432359733	21022	Economy	12200.00
0005432360006	21022	Economy	12200.00
0005434463902	17712	Economy	3400.00
0005434458618	17712	Economy	3400.00
0005434461630	17712	Economy	3400.00
0005434186196	17712	Economy	3100.00
0005434458587	17712	Economy	3100.00
0005434458665	17712	Economy	3100.00
0005434458664	17712	Economy	3100.00
0005434461627	17712	Economy	3100.00
0005434458675	17712	Economy	3100.00
0005434458676	17712	Economy	3100.00
0005434463905	17712	Economy	3100.00
0005434458656	17712	Economy	3100.00
0005434458674	17712	Economy	3100.00
0005434461625	17712	Economy	3100.00
0005434458616	17712	Economy	3100.00
0005434458588	17712	Economy	3100.00
0005434461626	17712	Economy	3100.00
0005434458663	17712	Economy	3100.00
0005434448270	17712	Economy	3100.00
0005434458617	17712	Economy	3100.00
0005434186197	17712	Economy	3100.00
0005434448277	17712	Economy	3100.00
0005434461629	17712	Economy	3100.00
0005434458647	17712	Economy	3100.00
0005434458634	17712	Economy	3100.00
0005434458673	17712	Economy	3100.00
0005434458695	17712	Economy	3100.00
0005434463901	17712	Economy	3100.00
0005434458792	29084	Economy	3400.00
0005434458784	29084	Economy	3100.00
0005434458781	29084	Economy	3100.00
0005434458785	29084	Economy	3100.00
0005434458776	29084	Economy	3100.00
0005434458791	29084	Economy	3100.00
0005434458793	29084	Economy	3100.00
0005434458774	29084	Economy	3100.00
0005434463924	29084	Economy	3100.00
0005434458778	29084	Economy	3100.00
0005434458780	29084	Economy	3100.00
0005434462785	29084	Economy	3100.00
0005434458787	29084	Economy	3100.00
0005434458794	29084	Economy	3100.00
0005434458779	29084	Economy	3100.00
0005434448309	29084	Economy	3100.00
0005434462786	29084	Economy	3100.00
0005434458789	29084	Economy	3100.00
0005434186176	29084	Economy	3100.00
0005434458782	29084	Economy	3100.00
0005434458788	29084	Economy	3100.00
0005434458775	29084	Economy	3100.00
0005434458783	29084	Economy	3100.00
0005434458777	29084	Economy	3100.00
0005434458790	29084	Economy	3100.00
0005434186177	29084	Economy	3100.00
0005434448308	29084	Economy	3100.00
0005434458786	29084	Economy	3100.00
0005434463925	29084	Economy	3100.00
0005434448307	29084	Economy	3100.00
0005432604251	21448	Economy	7300.00
0005432604284	21448	Economy	7300.00
0005432604289	21448	Economy	7300.00
0005432604288	21448	Economy	7300.00
0005432604286	21448	Economy	6600.00
0005432604281	21448	Economy	6600.00
0005432604279	21448	Economy	6600.00
0005432604280	21448	Economy	6600.00
0005432604278	21448	Economy	6600.00
0005432604255	21448	Economy	6600.00
0005432604259	21448	Economy	6600.00
0005432604260	21448	Economy	6600.00
0005432604257	21448	Economy	6600.00
0005432604252	21448	Economy	6600.00
0005432604282	21448	Economy	6600.00
0005432604258	21448	Economy	6600.00
0005432604271	21448	Economy	6600.00
0005432604269	21448	Economy	6600.00
0005432604270	21448	Economy	6600.00
0005432604283	21448	Economy	6600.00
0005432604253	21448	Economy	6600.00
0005432604273	21448	Economy	6600.00
0005432604263	21448	Economy	6600.00
0005432604287	21448	Economy	6600.00
0005432604290	21448	Economy	6600.00
0005432604268	21448	Economy	6600.00
0005432604264	21448	Economy	6600.00
0005432604272	21448	Economy	6600.00
0005432604274	21448	Economy	6600.00
0005432604250	21448	Economy	6600.00
0005432604262	21448	Economy	6600.00
0005432604256	21448	Economy	6600.00
0005432604276	21448	Economy	6600.00
0005432604277	21448	Economy	6600.00
0005432604267	21448	Economy	6600.00
0005432604285	21448	Economy	6600.00
0005432604275	21448	Economy	6600.00
0005432604266	21448	Economy	6600.00
0005432604265	21448	Economy	6600.00
0005432604261	21448	Economy	6600.00
0005432604254	21448	Economy	6600.00
0005432603861	31674	Economy	7300.00
0005432603965	31674	Economy	7300.00
0005432604038	31674	Economy	7300.00
0005432604069	31674	Economy	7300.00
0005432603870	31674	Economy	6600.00
0005432603948	31674	Economy	6600.00
0005432603970	31674	Economy	6600.00
0005432603813	31674	Economy	6600.00
0005432603862	31674	Economy	6600.00
0005432604119	31674	Economy	6600.00
0005432604120	31674	Economy	6600.00
0005432603932	31674	Economy	6600.00
0005432603964	31674	Economy	6600.00
0005432603942	31674	Economy	6600.00
0005432603941	31674	Economy	6600.00
0005432603826	31674	Economy	6600.00
0005432603852	31674	Economy	6600.00
0005432603872	31674	Economy	6600.00
0005432603819	31674	Economy	6600.00
0005432604090	31674	Economy	6600.00
0005432603952	31674	Economy	6600.00
0005432603943	31674	Economy	6600.00
0005432603972	31674	Economy	6600.00
0005432603883	31674	Economy	6600.00
0005432603900	31674	Economy	6600.00
0005432603899	31674	Economy	6600.00
0005432603982	31674	Economy	6600.00
0005432603944	31674	Economy	6600.00
0005432603921	31674	Economy	6600.00
0005432603953	31674	Economy	6600.00
0005432603874	31674	Economy	6600.00
0005432603851	31674	Economy	6600.00
0005432604091	31674	Economy	6600.00
0005432603850	31674	Economy	6600.00
0005432603799	31674	Economy	6600.00
0005432603873	31674	Economy	6600.00
0005432603922	31674	Economy	6600.00
0005432603961	31674	Economy	6600.00
0005432603882	31674	Economy	6600.00
0005432603933	31674	Economy	6600.00
0005432603963	31674	Economy	6600.00
0005432603979	31674	Economy	6600.00
0005432603802	31674	Economy	6600.00
0005432603978	31674	Economy	6600.00
0005432603814	31674	Economy	6600.00
0005432603931	31674	Economy	6600.00
0005432603871	31674	Economy	6600.00
0005435154584	29602	Economy	19500.00
0005433293246	29602	Economy	17800.00
0005433293248	29602	Economy	17800.00
0005435154585	29602	Economy	17800.00
0005435154589	29602	Economy	17800.00
0005433293243	29602	Economy	17800.00
0005435154586	29602	Economy	17800.00
0005433293247	29602	Economy	17800.00
0005433293244	29602	Economy	17800.00
0005433293251	29602	Economy	17800.00
0005435154590	29602	Economy	17800.00
0005433293250	29602	Economy	17800.00
0005435154581	29602	Economy	17800.00
0005433293245	29602	Economy	17800.00
0005433293241	29602	Economy	17800.00
0005435154580	29602	Economy	17800.00
0005435154587	29602	Economy	17800.00
0005433293242	29602	Economy	17800.00
0005433293249	29602	Economy	17800.00
0005435154583	29602	Economy	17800.00
0005435154582	29602	Economy	17800.00
0005435154588	29602	Economy	17800.00
0005433473254	6670	Economy	14000.00
0005433473258	6670	Economy	12700.00
0005435257200	6670	Economy	12700.00
0005433473243	6670	Economy	12700.00
0005433473248	6670	Economy	12700.00
0005435257180	6670	Economy	12700.00
0005435257189	6670	Economy	12700.00
0005433473256	6670	Economy	12700.00
0005433473252	6670	Economy	12700.00
0005435257150	6670	Economy	12700.00
0005433473250	6670	Economy	12700.00
0005433473259	6670	Economy	12700.00
0005433473251	6670	Economy	12700.00
0005433473244	6670	Economy	12700.00
0005435257157	6670	Economy	12700.00
0005435257181	6670	Economy	12700.00
0005433473246	6670	Economy	12700.00
0005433473245	6670	Economy	12700.00
0005435257199	6670	Economy	12700.00
0005433473260	6670	Economy	12700.00
0005433473242	6670	Economy	12700.00
0005433473253	6670	Economy	12700.00
0005435257179	6670	Economy	12700.00
0005433473257	6670	Economy	12700.00
0005433473247	6670	Economy	12700.00
0005433473249	6670	Economy	12700.00
0005435257174	6670	Economy	12700.00
0005435257216	6670	Economy	12700.00
0005433473255	6670	Economy	12700.00
0005433473188	23881	Economy	14000.00
0005435257226	23881	Economy	14000.00
0005435257228	23881	Economy	14000.00
0005435257222	23881	Economy	14000.00
0005433473160	23881	Economy	12700.00
0005435257234	23881	Economy	12700.00
0005435257233	23881	Economy	12700.00
0005435257223	23881	Economy	12700.00
0005435257227	23881	Economy	12700.00
0005433473176	23881	Economy	12700.00
0005433473140	23881	Economy	12700.00
0005433473139	23881	Economy	12700.00
0005433473208	23881	Economy	12700.00
0005433473158	23881	Economy	12700.00
0005433473168	23881	Economy	12700.00
0005433473161	23881	Economy	12700.00
0005433473189	23881	Economy	12700.00
0005433473165	23881	Economy	12700.00
0005433473184	23881	Economy	12700.00
0005435257230	23881	Economy	12700.00
0005433473149	23881	Economy	12700.00
0005433473186	23881	Economy	12700.00
0005435257232	23881	Economy	12700.00
0005433473173	23881	Economy	12700.00
0005433473159	23881	Economy	12700.00
0005435257235	23881	Economy	12700.00
0005435257225	23881	Economy	12700.00
0005435257224	23881	Economy	12700.00
0005433473175	23881	Economy	12700.00
0005433473152	23881	Economy	12700.00
0005433473137	23881	Economy	12700.00
0005433473183	23881	Economy	12700.00
0005435257229	23881	Economy	12700.00
0005433473164	23881	Economy	12700.00
0005433473136	23881	Economy	12700.00
0005433473170	23881	Economy	12700.00
0005433473187	23881	Economy	12700.00
0005435257231	23881	Economy	12700.00
0005433473154	23881	Economy	12700.00
0005433473157	23881	Economy	12700.00
0005433473169	23881	Economy	12700.00
0005433473163	23881	Economy	12700.00
0005434606793	18866	Economy	6600.00
0005434606784	18866	Economy	6600.00
0005434606781	18866	Economy	6600.00
0005434606790	18866	Economy	6600.00
0005434606798	18866	Economy	6600.00
0005434606788	18866	Economy	6600.00
0005434606780	18866	Economy	6600.00
0005434606779	18866	Economy	6600.00
0005434606785	18866	Economy	6600.00
0005434606799	18866	Economy	6600.00
0005434606822	22382	Economy	6600.00
0005434606821	22382	Economy	6600.00
0005434604889	22382	Economy	6600.00
0005434604890	22382	Economy	6600.00
0005434604888	22382	Economy	6600.00
0005434604891	22382	Economy	6600.00
0005434522434	3846	Economy	24900.00
0005434602899	3846	Economy	24900.00
0005434522436	3846	Economy	22600.00
0005435904394	3846	Economy	22600.00
0005434522443	3846	Economy	22600.00
0005434522441	3846	Economy	22600.00
0005435904382	3846	Economy	22600.00
0005434522438	3846	Economy	22600.00
0005435904365	3846	Economy	22600.00
0005435904383	3846	Economy	22600.00
0005434602896	3846	Economy	22600.00
0005435904381	3846	Economy	22600.00
0005435904390	3846	Economy	22600.00
0005434602894	3846	Economy	22600.00
0005434522437	3846	Economy	22600.00
0005434522442	3846	Economy	22600.00
0005434522439	3846	Economy	22600.00
0005434602898	3846	Economy	22600.00
0005434522432	3846	Economy	22600.00
0005434602897	3846	Economy	22600.00
0005435904388	3846	Economy	22600.00
0005434602895	3846	Economy	22600.00
0005434522433	3846	Economy	22600.00
0005434522431	3846	Economy	22600.00
0005435904389	3846	Economy	22600.00
0005434522435	3846	Economy	22600.00
0005434522440	3846	Economy	22600.00
0005434604850	19067	Economy	24900.00
0005434522412	19067	Economy	24900.00
0005434522391	19067	Economy	22600.00
0005434604863	19067	Economy	22600.00
0005434604846	19067	Economy	22600.00
0005435904405	19067	Economy	22600.00
0005434522411	19067	Economy	22600.00
0005434522402	19067	Economy	22600.00
0005435904403	19067	Economy	22600.00
0005434522401	19067	Economy	22600.00
0005434522400	19067	Economy	22600.00
0005434602868	19067	Economy	22600.00
0005434604844	19067	Economy	22600.00
0005434604868	19067	Economy	22600.00
0005434604856	19067	Economy	22600.00
0005434522387	19067	Economy	22600.00
0005434602869	19067	Economy	22600.00
0005434604843	19067	Economy	22600.00
0005434522399	19067	Economy	22600.00
0005434604859	19067	Economy	22600.00
0005434522393	19067	Economy	22600.00
0005434604858	19067	Economy	22600.00
0005435904404	19067	Economy	22600.00
0005435904406	19067	Economy	22600.00
0005434604849	19067	Economy	22600.00
0005434604847	19067	Economy	22600.00
0005434602871	19067	Economy	22600.00
0005435904402	19067	Economy	22600.00
0005434522408	19067	Economy	22600.00
0005434602870	19067	Economy	22600.00
0005434604857	19067	Economy	22600.00
0005434522407	19067	Economy	22600.00
0005434522394	19067	Economy	22600.00
0005434522396	19067	Economy	22600.00
0005435904401	19067	Economy	22600.00
0005432751522	409	Business	44500.00
0005432753293	409	Business	44500.00
0005432747523	409	Business	44500.00
0005433293202	409	Business	44500.00
0005432753295	409	Business	44500.00
0005432747515	409	Business	44500.00
0005432747502	409	Business	44500.00
0005432751519	409	Business	44500.00
0005432753296	409	Business	44500.00
0005432890832	409	Business	44500.00
0005432890805	409	Economy	14800.00
0005432747526	409	Economy	14800.00
0005432890879	409	Economy	14800.00
0005432890878	409	Economy	14800.00
0005432747506	409	Economy	14800.00
0005432890858	409	Economy	14800.00
0005432751518	409	Economy	14800.00
0005432747513	409	Economy	14800.00
0005432747497	409	Economy	14800.00
0005432751520	409	Economy	16300.00
0005433293207	409	Economy	16300.00
0005432890914	409	Economy	16300.00
0005432749781	409	Economy	16300.00
0005433293156	409	Economy	14800.00
0005432890860	409	Economy	14800.00
0005432219996	409	Economy	14800.00
0005432747533	409	Economy	14800.00
0005432751521	409	Economy	14800.00
0005432890831	409	Economy	14800.00
0005432747508	409	Economy	14800.00
0005432747499	409	Economy	14800.00
0005432747504	409	Economy	14800.00
0005432747522	409	Economy	14800.00
0005432747518	409	Economy	14800.00
0005432219997	409	Economy	14800.00
0005433293183	409	Economy	14800.00
0005432747514	409	Economy	14800.00
0005432219998	409	Economy	14800.00
0005433293184	409	Economy	14800.00
0005432747534	409	Economy	14800.00
0005433875361	409	Economy	14800.00
0005432747531	409	Economy	14800.00
0005432747520	409	Economy	14800.00
0005432890776	409	Economy	14800.00
0005432747517	409	Economy	14800.00
0005432747532	409	Economy	14800.00
0005433875363	409	Economy	14800.00
0005433293164	409	Economy	14800.00
0005432747501	409	Economy	14800.00
0005432890859	409	Economy	14800.00
0005433875366	409	Economy	14800.00
0005432890913	409	Economy	14800.00
0005432747511	409	Economy	14800.00
0005432747510	409	Economy	14800.00
0005432747528	409	Economy	14800.00
0005432747525	409	Economy	14800.00
0005432747498	409	Economy	14800.00
0005435627118	409	Economy	14800.00
0005433293188	409	Economy	14800.00
0005432219999	409	Economy	14800.00
0005432747524	409	Economy	14800.00
0005432890799	409	Economy	14800.00
0005432747527	409	Economy	14800.00
0005432753294	409	Economy	14800.00
0005432747507	409	Economy	14800.00
0005432747529	409	Economy	14800.00
0005433293189	409	Economy	14800.00
0005432747519	409	Economy	14800.00
0005432747530	409	Economy	14800.00
0005432747516	409	Economy	14800.00
0005432747500	409	Economy	14800.00
0005432747512	409	Economy	14800.00
0005432747505	409	Economy	14800.00
0005432747503	409	Economy	14800.00
0005432747521	409	Economy	14800.00
0005433875362	409	Economy	14800.00
0005432747509	409	Economy	14800.00
0005432891006	12035	Business	44500.00
0005432747165	12035	Business	44500.00
0005432890997	12035	Business	44500.00
0005432747298	12035	Business	44500.00
0005432747261	12035	Business	44500.00
0005432747202	12035	Business	44500.00
0005432747287	12035	Business	44500.00
0005433875377	12035	Business	44500.00
0005432747198	12035	Business	44500.00
0005432891009	12035	Economy	14800.00
0005432891002	12035	Economy	14800.00
0005432747162	12035	Economy	14800.00
0005432747196	12035	Economy	14800.00
0005432747007	12035	Economy	14800.00
0005432747085	12035	Economy	14800.00
0005432747267	12035	Economy	14800.00
0005432890992	12035	Economy	14800.00
0005432890999	12035	Economy	14800.00
0005432747197	12035	Economy	16300.00
0005432891005	12035	Economy	16300.00
0005435627113	12035	Economy	16300.00
0005432890994	12035	Economy	14800.00
0005432214800	12035	Economy	14800.00
0005432747299	12035	Economy	14800.00
0005432747106	12035	Economy	14800.00
0005432747108	12035	Economy	14800.00
0005432891004	12035	Economy	14800.00
0005432756808	12035	Economy	14800.00
0005432747118	12035	Economy	14800.00
0005432747251	12035	Economy	14800.00
0005432747139	12035	Economy	14800.00
0005432890998	12035	Economy	14800.00
0005432749753	12035	Economy	14800.00
0005432891001	12035	Economy	14800.00
0005434153533	12035	Economy	14800.00
0005434153531	12035	Economy	14800.00
0005432756801	12035	Economy	14800.00
0005432753259	12035	Economy	14800.00
0005432753260	12035	Economy	14800.00
0005432747257	12035	Economy	14800.00
0005432891008	12035	Economy	14800.00
0005434153532	12035	Economy	14800.00
0005432747288	12035	Economy	14800.00
0005432891003	12035	Economy	14800.00
0005432747250	12035	Economy	14800.00
0005432747100	12035	Economy	14800.00
0005432747105	12035	Economy	14800.00
0005432747210	12035	Economy	14800.00
0005432747006	12035	Economy	14800.00
0005432749767	12035	Economy	14800.00
0005434153534	12035	Economy	14800.00
0005432890991	12035	Economy	14800.00
0005432890993	12035	Economy	14800.00
0005432747232	12035	Economy	14800.00
0005432747155	12035	Economy	14800.00
0005432890995	12035	Economy	14800.00
0005432214802	12035	Economy	14800.00
0005432747215	12035	Economy	14800.00
0005432747268	12035	Economy	14800.00
0005432214801	12035	Economy	14800.00
0005432747091	12035	Economy	14800.00
0005432890990	12035	Economy	14800.00
0005432891000	12035	Economy	14800.00
0005432890996	12035	Economy	14800.00
0005432747090	12035	Economy	14800.00
0005432747154	12035	Economy	14800.00
0005432891007	12035	Economy	14800.00
0005432747150	12035	Economy	14800.00
0005432747246	12035	Economy	14800.00
0005433531286	18998	Economy	28200.00
0005433525015	18998	Economy	25700.00
0005432927931	18998	Economy	25700.00
0005433525021	18998	Economy	25700.00
0005433533300	18998	Economy	25700.00
0005433533302	18998	Economy	25700.00
0005433525018	18998	Economy	25700.00
0005433531284	18998	Economy	25700.00
0005433525016	18998	Economy	25700.00
0005433525017	18998	Economy	25700.00
0005432927921	18998	Economy	25700.00
0005433525022	18998	Economy	25700.00
0005433525019	18998	Economy	25700.00
0005433525023	18998	Economy	25700.00
0005432927935	18998	Economy	25700.00
0005433525014	18998	Economy	25700.00
0005433531285	18998	Economy	25700.00
0005432927932	18998	Economy	25700.00
0005433533301	18998	Economy	25700.00
0005433525020	18998	Economy	25700.00
0005432927978	32487	Economy	28200.00
0005433524970	32487	Economy	28200.00
0005433524944	32487	Economy	25700.00
0005433524900	32487	Economy	25700.00
0005433524955	32487	Economy	25700.00
0005433531257	32487	Economy	25700.00
0005432927982	32487	Economy	25700.00
0005433527234	32487	Economy	25700.00
0005433524957	32487	Economy	25700.00
0005433524927	32487	Economy	25700.00
0005432927977	32487	Economy	25700.00
0005433524950	32487	Economy	25700.00
0005433524980	32487	Economy	25700.00
0005433524928	32487	Economy	25700.00
0005433527215	32487	Economy	25700.00
0005433524951	32487	Economy	25700.00
0005433524912	32487	Economy	25700.00
0005432927980	32487	Economy	25700.00
0005432927981	32487	Economy	25700.00
0005432927979	32487	Economy	25700.00
0005433531266	32487	Economy	25700.00
0005432121314	5250	Business	84000.00
0005432121316	5250	Business	84000.00
0005435372735	5250	Business	84000.00
0005434823514	5250	Business	84000.00
0005434823464	5250	Business	84000.00
0005435372677	5250	Business	84000.00
0005434823511	5250	Business	84000.00
0005434823426	5250	Business	84000.00
0005434823466	5250	Business	84000.00
0005434823405	5250	Business	84000.00
0005434823425	5250	Business	84000.00
0005435386529	5250	Business	84000.00
0005434823470	5250	Business	84000.00
0005434823448	5250	Business	84000.00
0005435372587	5250	Business	84000.00
0005435372799	5250	Business	84000.00
0005435386524	5250	Business	84000.00
0005434823491	5250	Business	84000.00
0005434823512	5250	Comfort	47600.00
0005434831140	5250	Comfort	47600.00
0005434823445	5250	Comfort	47600.00
0005435372806	5250	Comfort	47600.00
0005434828693	5250	Comfort	47600.00
0005435372807	5250	Comfort	47600.00
0005434558265	5250	Comfort	47600.00
0005434823497	5250	Comfort	47600.00
0005435150020	5250	Comfort	47600.00
0005435150018	5250	Comfort	47600.00
0005434823488	5250	Comfort	47600.00
0005432121324	5250	Comfort	47600.00
0005434823461	5250	Comfort	47600.00
0005434823398	5250	Comfort	47600.00
0005434823441	5250	Comfort	47600.00
0005434823438	5250	Comfort	47600.00
0005435372644	5250	Comfort	47600.00
0005434823468	5250	Comfort	47600.00
0005435372554	5250	Comfort	47600.00
0005435372510	5250	Comfort	47600.00
0005435372745	5250	Comfort	47600.00
0005434823455	5250	Comfort	47600.00
0005434823407	5250	Comfort	47600.00
0005434823453	5250	Comfort	47600.00
0005435372815	5250	Comfort	47600.00
0005435372656	5250	Comfort	47600.00
0005434823502	5250	Comfort	47600.00
0005432121320	5250	Comfort	47600.00
0005435304122	5250	Comfort	47600.00
0005435372697	5250	Comfort	47600.00
0005434831143	5250	Comfort	47600.00
0005434823499	5250	Comfort	47600.00
0005435372627	5250	Comfort	47600.00
0005434823409	5250	Comfort	47600.00
0005435299726	5250	Comfort	47600.00
0005434558264	5250	Comfort	47600.00
0005435372805	5250	Comfort	47600.00
0005434823476	5250	Economy	28000.00
0005435372379	5250	Economy	28000.00
0005435372670	5250	Economy	28000.00
0005434823462	5250	Economy	28000.00
0005434823508	5250	Economy	28000.00
0005434823505	5250	Economy	28000.00
0005435372465	5250	Economy	28000.00
0005434831141	5250	Economy	28000.00
0005434823391	5250	Economy	28000.00
0005434558266	5250	Economy	28000.00
0005432394099	5250	Economy	28000.00
0005435150014	5250	Economy	28000.00
0005434823518	5250	Economy	28000.00
0005435372693	5250	Economy	28000.00
0005435372344	5250	Economy	28000.00
0005432121318	5250	Economy	28000.00
0005434823427	5250	Economy	28000.00
0005434823506	5250	Economy	28000.00
0005432121321	5250	Economy	28000.00
0005435372247	5250	Economy	28000.00
0005435150016	5250	Economy	28000.00
0005435299736	5250	Economy	28000.00
0005434823477	5250	Economy	28000.00
0005434558260	5250	Economy	28000.00
0005434823474	5250	Economy	28000.00
0005434823509	5250	Economy	28000.00
0005435150009	5250	Economy	28000.00
0005434823454	5250	Economy	28000.00
0005434823489	5250	Economy	28000.00
0005435372736	5250	Economy	28000.00
0005434828691	5250	Economy	28000.00
0005434823501	5250	Economy	28000.00
0005432394101	5250	Economy	28000.00
0005435372766	5250	Economy	28000.00
0005434823510	5250	Economy	28000.00
0005435150011	5250	Economy	28000.00
0005434831139	5250	Economy	28000.00
0005434823481	5250	Economy	28000.00
0005434823483	5250	Economy	28000.00
0005434823399	5250	Economy	28000.00
0005435372475	5250	Economy	28000.00
0005435372650	5250	Economy	28000.00
0005435372519	5250	Economy	28000.00
0005435372346	5250	Economy	28000.00
0005434823434	5250	Economy	28000.00
0005435304129	5250	Economy	28000.00
0005432396238	5250	Economy	28000.00
0005435299723	5250	Economy	28000.00
0005434823395	5250	Economy	28000.00
0005435299724	5250	Economy	28000.00
0005435372468	5250	Economy	30800.00
0005435735109	5250	Economy	30800.00
0005435372556	5250	Economy	30800.00
0005434823479	5250	Economy	28000.00
0005434823410	5250	Economy	28000.00
0005435372643	5250	Economy	30800.00
0005435372541	5250	Economy	30800.00
0005435372577	5250	Economy	28000.00
0005435372744	5250	Economy	28000.00
0005434823471	5250	Economy	28000.00
0005434823515	5250	Economy	28000.00
0005434558258	5250	Economy	28000.00
0005434823516	5250	Economy	28000.00
0005434664955	5250	Economy	28000.00
0005434823390	5250	Economy	28000.00
0005434823519	5250	Economy	28000.00
0005434823419	5250	Economy	28000.00
0005434823463	5250	Economy	28000.00
0005435372870	5250	Economy	28000.00
0005435372469	5250	Economy	28000.00
0005435372691	5250	Economy	28000.00
0005435372798	5250	Economy	28000.00
0005435372816	5250	Economy	28000.00
0005435150019	5250	Economy	28000.00
0005435661880	5250	Economy	28000.00
0005435150008	5250	Economy	28000.00
0005435372665	5250	Economy	28000.00
0005435150010	5250	Economy	28000.00
0005432394100	5250	Economy	28000.00
0005434823447	5250	Economy	28000.00
0005434823449	5250	Economy	28000.00
0005434664956	5250	Economy	28000.00
0005435372345	5250	Economy	28000.00
0005435386523	5250	Economy	28000.00
0005435372527	5250	Economy	28000.00
0005435372626	5250	Economy	28000.00
0005435178983	5250	Economy	28000.00
0005435372537	5250	Economy	28000.00
0005435304103	5250	Economy	28000.00
0005434823496	5250	Economy	28000.00
0005434823443	5250	Economy	28000.00
0005434823403	5250	Economy	28000.00
0005434823459	5250	Economy	28000.00
0005434823418	5250	Economy	28000.00
0005435304123	5250	Economy	28000.00
0005434831142	5250	Economy	28000.00
0005432396240	5250	Economy	28000.00
0005435372772	5250	Economy	28000.00
0005435735077	5250	Economy	28000.00
0005434558259	5250	Economy	28000.00
0005434823393	5250	Economy	28000.00
0005432121315	5250	Economy	28000.00
0005434823406	5250	Economy	28000.00
0005435372892	5250	Economy	28000.00
0005434823493	5250	Economy	28000.00
0005435372759	5250	Economy	28000.00
0005432121313	5250	Economy	28000.00
0005432121323	5250	Economy	28000.00
0005434823450	5250	Economy	28000.00
0005435372839	5250	Economy	28000.00
0005435150017	5250	Economy	28000.00
0005435386504	5250	Economy	28000.00
0005434823408	5250	Economy	28000.00
0005434823440	5250	Economy	28000.00
0005435372625	5250	Economy	28000.00
0005434823480	5250	Economy	28000.00
0005435372613	5250	Economy	28000.00
0005434823469	5250	Economy	28000.00
0005435150012	5250	Economy	28000.00
0005434823411	5250	Economy	28000.00
0005434823486	5250	Economy	28000.00
0005434823392	5250	Economy	28000.00
0005434823423	5250	Economy	28000.00
0005434823475	5250	Economy	28000.00
0005435150021	5250	Economy	28000.00
0005434823394	5250	Economy	28000.00
0005434823442	5250	Economy	28000.00
0005434823504	5250	Economy	28000.00
0005434823451	5250	Economy	28000.00
0005434823485	5250	Economy	28000.00
0005434823415	5250	Economy	28000.00
0005434823487	5250	Economy	28000.00
0005434823433	5250	Economy	28000.00
0005434823495	5250	Economy	28000.00
0005435372436	5250	Economy	28000.00
0005434823424	5250	Economy	28000.00
0005434823467	5250	Economy	28000.00
0005435386498	5250	Economy	28000.00
0005434823420	5250	Economy	28000.00
0005435372437	5250	Economy	28000.00
0005434823414	5250	Economy	28000.00
0005434823498	5250	Economy	28000.00
0005434823478	5250	Economy	28000.00
0005434823400	5250	Economy	28000.00
0005434664954	5250	Economy	30800.00
0005434823444	5250	Economy	30800.00
0005434823422	5250	Economy	30800.00
0005434823452	5250	Economy	30800.00
0005435150015	5250	Economy	28000.00
0005434823404	5250	Economy	28000.00
0005434823413	5250	Economy	28000.00
0005434558263	5250	Economy	28000.00
0005435299738	5250	Economy	28000.00
0005435372534	5250	Economy	28000.00
0005435372604	5250	Economy	28000.00
0005435372792	5250	Economy	28000.00
0005434823484	5250	Economy	28000.00
0005435661891	5250	Economy	28000.00
0005434823436	5250	Economy	28000.00
0005435150013	5250	Economy	28000.00
0005434823402	5250	Economy	28000.00
0005434823437	5250	Economy	28000.00
0005435372624	5250	Economy	28000.00
0005432121326	5250	Economy	28000.00
0005435372724	5250	Economy	28000.00
0005434823500	5250	Economy	28000.00
0005434823396	5250	Economy	28000.00
0005435372605	5250	Economy	28000.00
0005434823492	5250	Economy	28000.00
0005434823432	5250	Economy	28000.00
0005434558261	5250	Economy	28000.00
0005434823456	5250	Economy	28000.00
0005434823473	5250	Economy	28000.00
0005434823513	5250	Economy	28000.00
0005432121325	5250	Economy	28000.00
0005434823517	5250	Economy	28000.00
0005434823465	5250	Economy	28000.00
0005434823429	5250	Economy	28000.00
0005434558262	5250	Economy	28000.00
0005434823435	5250	Economy	28000.00
0005434823457	5250	Economy	28000.00
0005435372383	5250	Economy	28000.00
0005434823482	5250	Economy	28000.00
0005434823430	5250	Economy	28000.00
0005435372692	5250	Economy	28000.00
0005432121317	5250	Economy	28000.00
0005432396241	5250	Economy	28000.00
0005435386490	5250	Economy	28000.00
0005435372722	5250	Economy	28000.00
0005434558267	5250	Economy	28000.00
0005432121319	5250	Economy	28000.00
0005434823417	5250	Economy	28000.00
0005435372871	5250	Economy	28000.00
0005434823431	5250	Economy	28000.00
0005435372573	5250	Economy	28000.00
0005434823439	5250	Economy	28000.00
0005435372647	5250	Economy	28000.00
0005434823416	5250	Economy	28000.00
0005435372380	5250	Economy	28000.00
0005435304119	5250	Economy	28000.00
0005435735074	5250	Economy	28000.00
0005435372838	5250	Economy	28000.00
0005432396239	5250	Economy	28000.00
0005435304128	5250	Economy	28000.00
0005434823458	5250	Economy	28000.00
0005434823421	5250	Economy	28000.00
0005434823397	5250	Economy	28000.00
0005434823507	5250	Economy	28000.00
0005434823494	5250	Economy	28000.00
0005434823428	5250	Economy	28000.00
0005432121322	5250	Economy	28000.00
0005435735108	5250	Economy	28000.00
0005434823460	5250	Economy	28000.00
0005435372575	5250	Economy	28000.00
0005434823446	5250	Economy	28000.00
0005435372621	5250	Economy	28000.00
0005434823490	5250	Economy	28000.00
0005435372615	5250	Economy	28000.00
0005432396237	5250	Economy	28000.00
0005435386491	5250	Economy	28000.00
0005434823412	5250	Economy	28000.00
0005435304111	5250	Economy	28000.00
0005435372530	5250	Economy	28000.00
0005434823503	5250	Economy	28000.00
0005434823401	5250	Economy	28000.00
0005434828692	5250	Economy	28000.00
0005434823472	5250	Economy	28000.00
0005435304132	5250	Economy	28000.00
0005435178984	5250	Economy	28000.00
0005434558167	9917	Business	84000.00
0005434822008	9917	Business	84000.00
0005435299769	9917	Business	84000.00
0005434822690	9917	Business	84000.00
0005432400075	9917	Business	84000.00
0005435373196	9917	Business	84000.00
0005434821593	9917	Business	84000.00
0005434821976	9917	Business	84000.00
0005432203056	9917	Business	84000.00
0005434822734	9917	Business	84000.00
0005434822231	9917	Business	84000.00
0005435373177	9917	Business	84000.00
0005435373185	9917	Business	84000.00
0005435386565	9917	Business	84000.00
0005435373194	9917	Business	84000.00
0005432400095	9917	Business	84000.00
0005435373167	9917	Business	84000.00
0005434822668	9917	Business	84000.00
0005434822439	9917	Business	84000.00
0005435386567	9917	Business	84000.00
0005435179692	9917	Business	84000.00
0005434828661	9917	Business	84000.00
0005435735134	9917	Business	84000.00
0005434831111	9917	Business	84000.00
0005434822434	9917	Comfort	47600.00
0005434823023	9917	Comfort	47600.00
0005434822402	9917	Comfort	47600.00
0005434821994	9917	Comfort	47600.00
0005435373198	9917	Comfort	47600.00
0005435373184	9917	Comfort	47600.00
0005434822226	9917	Comfort	47600.00
0005434822566	9917	Comfort	47600.00
0005435386568	9917	Comfort	47600.00
0005434558185	9917	Comfort	47600.00
0005434822174	9917	Comfort	47600.00
0005435661929	9917	Comfort	47600.00
0005432400091	9917	Comfort	47600.00
0005434822669	9917	Comfort	47600.00
0005434822026	9917	Comfort	47600.00
0005434822346	9917	Comfort	47600.00
0005434822477	9917	Comfort	47600.00
0005432400080	9917	Comfort	47600.00
0005434822241	9917	Comfort	47600.00
0005434822614	9917	Comfort	47600.00
0005434821948	9917	Comfort	47600.00
0005434822328	9917	Comfort	47600.00
0005434822181	9917	Comfort	47600.00
0005435373199	9917	Comfort	47600.00
0005435149931	9917	Comfort	47600.00
0005434822388	9917	Comfort	47600.00
0005435373210	9917	Comfort	47600.00
0005434822227	9917	Comfort	47600.00
0005435373163	9917	Comfort	47600.00
0005434821945	9917	Comfort	47600.00
0005435373197	9917	Comfort	47600.00
0005434822393	9917	Economy	28000.00
0005435373183	9917	Comfort	47600.00
0005435373191	9917	Economy	28000.00
0005435373180	9917	Economy	28000.00
0005435373200	9917	Economy	28000.00
0005434822178	9917	Economy	28000.00
0005434822606	9917	Economy	28000.00
0005435735135	9917	Economy	28000.00
0005432400094	9917	Economy	28000.00
0005434822770	9917	Economy	28000.00
0005434822521	9917	Economy	28000.00
0005434822706	9917	Economy	28000.00
0005435661927	9917	Economy	28000.00
0005435373170	9917	Economy	28000.00
0005435149916	9917	Economy	28000.00
0005435373216	9917	Economy	28000.00
0005435373181	9917	Economy	28000.00
0005435149844	9917	Economy	28000.00
0005434822576	9917	Economy	28000.00
0005432203059	9917	Economy	28000.00
0005434822300	9917	Economy	28000.00
0005434664940	9917	Economy	28000.00
0005435373215	9917	Economy	28000.00
0005434822225	9917	Economy	28000.00
0005434822397	9917	Economy	28000.00
0005434828671	9917	Economy	28000.00
0005434822034	9917	Economy	28000.00
0005432203055	9917	Economy	28000.00
0005434821974	9917	Economy	28000.00
0005434822289	9917	Economy	28000.00
0005434822522	9917	Economy	28000.00
0005434822386	9917	Economy	28000.00
0005432823449	9917	Economy	28000.00
0005434821965	9917	Economy	28000.00
0005435373222	9917	Economy	28000.00
0005435302194	9917	Economy	28000.00
0005434822567	9917	Economy	28000.00
0005434821869	9917	Economy	28000.00
0005435386571	9917	Economy	28000.00
0005435373193	9917	Economy	28000.00
0005435373206	9917	Economy	28000.00
0005434822428	9917	Economy	30800.00
0005435302191	9917	Economy	28000.00
0005435373174	9917	Economy	28000.00
0005434822438	9917	Economy	28000.00
0005435735136	9917	Economy	28000.00
0005434822648	9917	Economy	28000.00
0005434822785	9917	Economy	28000.00
0005435373164	9917	Economy	28000.00
0005434822398	9917	Economy	28000.00
0005432400077	9917	Economy	28000.00
0005434821796	9917	Economy	28000.00
0005435373166	9917	Economy	28000.00
0005434822620	9917	Economy	28000.00
0005434822175	9917	Economy	28000.00
0005434823119	9917	Economy	28000.00
0005432203052	9917	Economy	28000.00
0005434822179	9917	Economy	28000.00
0005434822363	9917	Economy	28000.00
0005434822001	9917	Economy	28000.00
0005434822705	9917	Economy	28000.00
0005434821949	9917	Economy	28000.00
0005434821966	9917	Economy	28000.00
0005435373192	9917	Economy	28000.00
0005434558184	9917	Economy	28000.00
0005432203058	9917	Economy	28000.00
0005435373204	9917	Economy	28000.00
0005434821765	9917	Economy	28000.00
0005434822747	9917	Economy	28000.00
0005435373227	9917	Economy	28000.00
0005434822803	9917	Economy	28000.00
0005434822615	9917	Economy	28000.00
0005434558149	9917	Economy	28000.00
0005434821870	9917	Economy	28000.00
0005434822793	9917	Economy	28000.00
0005434822401	9917	Economy	28000.00
0005434821632	9917	Economy	28000.00
0005434822309	9917	Economy	28000.00
0005435373171	9917	Economy	28000.00
0005434828674	9917	Economy	28000.00
0005435373219	9917	Economy	28000.00
0005434822290	9917	Economy	28000.00
0005434822085	9917	Economy	28000.00
0005434822119	9917	Economy	28000.00
0005434821951	9917	Economy	28000.00
0005434822499	9917	Economy	28000.00
0005435373190	9917	Economy	28000.00
0005434822387	9917	Economy	28000.00
0005435299771	9917	Economy	28000.00
0005435302192	9917	Economy	28000.00
0005435299768	9917	Economy	28000.00
0005435149827	9917	Economy	28000.00
0005435386570	9917	Economy	28000.00
0005435299772	9917	Economy	28000.00
0005435149927	9917	Economy	28000.00
0005432400076	9917	Economy	28000.00
0005435661930	9917	Economy	28000.00
0005435373178	9917	Economy	28000.00
0005435373207	9917	Economy	28000.00
0005434822846	9917	Economy	28000.00
0005435373211	9917	Economy	28000.00
0005434823118	9917	Economy	28000.00
0005435373165	9917	Economy	28000.00
0005435149933	9917	Economy	28000.00
0005434822015	9917	Economy	28000.00
0005434822344	9917	Economy	28000.00
0005434822406	9917	Economy	28000.00
0005434821964	9917	Economy	28000.00
0005432203053	9917	Economy	28000.00
0005432400081	9917	Economy	28000.00
0005435386569	9917	Economy	28000.00
0005434822938	9917	Economy	28000.00
0005434822424	9917	Economy	28000.00
0005434822396	9917	Economy	28000.00
0005434822691	9917	Economy	28000.00
0005434822460	9917	Economy	28000.00
0005435302193	9917	Economy	28000.00
0005434558166	9917	Economy	28000.00
0005434822212	9917	Economy	28000.00
0005434823022	9917	Economy	28000.00
0005435386566	9917	Economy	28000.00
0005434821931	9917	Economy	28000.00
0005434822523	9917	Economy	28000.00
0005435373223	9917	Economy	28000.00
0005434664939	9917	Economy	28000.00
0005434822301	9917	Economy	28000.00
0005434822007	9917	Economy	28000.00
0005434822804	9917	Economy	28000.00
0005434821950	9917	Economy	28000.00
0005434821913	9917	Economy	28000.00
0005435373182	9917	Economy	30800.00
0005434822687	9917	Economy	30800.00
0005432203057	9917	Economy	28000.00
0005434822587	9917	Economy	28000.00
0005434822385	9917	Economy	28000.00
0005435299773	9917	Economy	28000.00
0005435373203	9917	Economy	28000.00
0005434822647	9917	Economy	28000.00
0005434822511	9917	Economy	28000.00
0005434822407	9917	Economy	28000.00
0005435373173	9917	Economy	28000.00
0005434822308	9917	Economy	28000.00
0005434822939	9917	Economy	28000.00
0005434828672	9917	Economy	28000.00
0005435373202	9917	Economy	28000.00
0005434822170	9917	Economy	28000.00
0005434828675	9917	Economy	28000.00
0005435373224	9917	Economy	28000.00
0005432400093	9917	Economy	28000.00
0005435373205	9917	Economy	28000.00
0005435373209	9917	Economy	28000.00
0005435373226	9917	Economy	28000.00
0005434822195	9917	Economy	28000.00
0005434822316	9917	Economy	28000.00
0005434822718	9917	Economy	28000.00
0005434822676	9917	Economy	28000.00
0005435373188	9917	Economy	28000.00
0005434822588	9917	Economy	28000.00
0005434822684	9917	Economy	28000.00
0005434822435	9917	Economy	28000.00
0005435149911	9917	Economy	28000.00
0005434822345	9917	Economy	28000.00
0005434822487	9917	Economy	28000.00
0005434822111	9917	Economy	28000.00
0005434822194	9917	Economy	28000.00
0005435373225	9917	Economy	28000.00
0005435373221	9917	Economy	28000.00
0005434822027	9917	Economy	28000.00
0005434822530	9917	Economy	28000.00
0005435373212	9917	Economy	28000.00
0005434822353	9917	Economy	28000.00
0005434822847	9917	Economy	28000.00
0005434822219	9917	Economy	28000.00
0005434822297	9917	Economy	28000.00
0005432823448	9917	Economy	28000.00
0005435373168	9917	Economy	28000.00
0005434822400	9917	Economy	28000.00
0005434822145	9917	Economy	28000.00
0005434822187	9917	Economy	28000.00
0005435373172	9917	Economy	28000.00
0005435373208	9917	Economy	28000.00
0005435373189	9917	Economy	28000.00
0005434822667	9917	Economy	28000.00
0005435373220	9917	Economy	28000.00
0005435373186	9917	Economy	28000.00
0005435373214	9917	Economy	28000.00
0005435373179	9917	Economy	28000.00
0005435373169	9917	Economy	28000.00
0005435373201	9917	Economy	28000.00
0005434831092	9917	Economy	28000.00
0005434822921	9917	Economy	28000.00
0005435373187	9917	Economy	28000.00
0005434822059	9917	Economy	28000.00
0005435149914	9917	Economy	28000.00
0005435373162	9917	Economy	28000.00
0005435373175	9917	Economy	28000.00
0005434822699	9917	Economy	28000.00
0005432203054	9917	Economy	28000.00
0005434828673	9917	Economy	28000.00
0005435299770	9917	Economy	28000.00
0005435373213	9917	Economy	28000.00
0005434822748	9917	Economy	28000.00
0005435661928	9917	Economy	28000.00
0005435373195	9917	Economy	28000.00
0005435373176	9917	Economy	28000.00
0005434822459	9917	Economy	28000.00
0005435373217	9917	Economy	28000.00
0005434822364	9917	Economy	28000.00
0005435373218	9917	Economy	28000.00
0005435082778	7022	Economy	8200.00
0005435082783	7022	Economy	8200.00
0005435082781	7022	Economy	7400.00
0005435790302	7022	Economy	7400.00
0005435082779	7022	Economy	7400.00
0005435790303	7022	Economy	7400.00
0005435082782	7022	Economy	7400.00
0005435082780	7022	Economy	7400.00
0005435790304	7022	Economy	7400.00
0005435082688	26016	Economy	7400.00
0005435082714	26016	Economy	7400.00
0005435082708	26016	Economy	7400.00
0005435790279	26016	Economy	7400.00
0005435790285	26016	Economy	7400.00
0005435082706	26016	Economy	7400.00
0005435082689	26016	Economy	7400.00
0005435790280	26016	Economy	7400.00
0005435082707	26016	Economy	7400.00
0005435790284	26016	Economy	7400.00
0005435082722	26016	Economy	7400.00
0005435790276	26016	Economy	7400.00
0005435082684	26016	Economy	7400.00
0005435790286	26016	Economy	7400.00
0005434756375	9519	Business	32800.00
0005434214098	9519	Business	32800.00
0005434756392	9519	Business	32800.00
0005434214209	9519	Business	32800.00
0005434756378	9519	Business	32800.00
0005434756362	9519	Business	32800.00
0005434213873	9519	Business	32800.00
0005434213881	9519	Business	32800.00
0005434756406	9519	Business	32800.00
0005434756366	9519	Business	32800.00
0005434214053	9519	Business	32800.00
0005434214145	9519	Business	32800.00
0005434756386	9519	Economy	10900.00
0005434756399	9519	Economy	10900.00
0005434213990	9519	Economy	10900.00
0005434214090	9519	Economy	10900.00
0005434213973	9519	Economy	10900.00
0005434756371	9519	Economy	10900.00
0005434756364	9519	Economy	10900.00
0005434756389	9519	Economy	10900.00
0005434213930	9519	Economy	10900.00
0005434756370	9519	Economy	12000.00
0005434214253	9519	Economy	12000.00
0005434214091	9519	Economy	12000.00
0005434756395	9519	Economy	10900.00
0005434214146	9519	Economy	10900.00
0005434756384	9519	Economy	10900.00
0005434214207	9519	Economy	10900.00
0005434756365	9519	Economy	10900.00
0005434756380	9519	Economy	10900.00
0005434213886	9519	Economy	10900.00
0005434756407	9519	Economy	10900.00
0005434213967	9519	Economy	10900.00
0005434214070	9519	Economy	10900.00
0005434756373	9519	Economy	10900.00
0005434756367	9519	Economy	10900.00
0005434214252	9519	Economy	10900.00
0005434756402	9519	Economy	10900.00
0005434214260	9519	Economy	10900.00
0005434214148	9519	Economy	10900.00
0005434213892	9519	Economy	10900.00
0005434756396	9519	Economy	10900.00
0005434756397	9519	Economy	10900.00
0005434756393	9519	Economy	10900.00
0005434756369	9519	Economy	10900.00
0005434756381	9519	Economy	10900.00
0005434213882	9519	Economy	10900.00
0005434213920	9519	Economy	10900.00
0005434756374	9519	Economy	10900.00
0005434214100	9519	Economy	10900.00
0005434213890	9519	Economy	10900.00
0005434213901	9519	Economy	10900.00
0005434756403	9519	Economy	10900.00
0005434756400	9519	Economy	10900.00
0005434214144	9519	Economy	10900.00
0005434214210	9519	Economy	10900.00
0005434756388	9519	Economy	10900.00
0005434756390	9519	Economy	10900.00
0005434213891	9519	Economy	10900.00
0005434214028	9519	Economy	10900.00
0005434756379	9519	Economy	10900.00
0005434756394	9519	Economy	10900.00
0005434214261	9519	Economy	10900.00
0005434756382	9519	Economy	10900.00
0005434756376	9519	Economy	10900.00
0005434213983	9519	Economy	10900.00
0005434214094	9519	Economy	10900.00
0005434213857	9519	Economy	10900.00
0005434756383	9519	Economy	10900.00
0005434756401	9519	Economy	10900.00
0005434756404	9519	Economy	10900.00
0005434213906	9519	Economy	10900.00
0005434756372	9519	Economy	10900.00
0005434213851	9519	Economy	10900.00
0005434214149	9519	Economy	10900.00
0005434214137	9519	Economy	10900.00
0005434756387	9519	Economy	10900.00
0005434756398	9519	Economy	10900.00
0005434756368	9519	Economy	10900.00
0005434214095	9519	Economy	10900.00
0005434756385	9519	Economy	10900.00
0005434756391	9519	Economy	10900.00
0005434213991	9519	Economy	10900.00
0005434756377	9519	Economy	10900.00
0005434756405	9519	Economy	10900.00
0005434214049	9519	Economy	10900.00
0005434214208	9519	Economy	10900.00
0005434756363	9519	Economy	10900.00
0005434214005	9519	Economy	10900.00
0005434213900	9519	Economy	10900.00
0005434214426	28626	Business	32800.00
0005434214448	28626	Business	32800.00
0005434214444	28626	Business	32800.00
0005434755976	28626	Business	32800.00
0005434755709	28626	Business	32800.00
0005434214419	28626	Business	32800.00
0005434214423	28626	Business	32800.00
0005434214415	28626	Business	32800.00
0005434755862	28626	Business	32800.00
0005434214450	28626	Business	32800.00
0005434214442	28626	Business	32800.00
0005434755910	28626	Economy	10900.00
0005434755899	28626	Economy	10900.00
0005434755939	28626	Economy	10900.00
0005434214458	28626	Economy	10900.00
0005434214453	28626	Economy	10900.00
0005434755990	28626	Economy	10900.00
0005434214457	28626	Economy	10900.00
0005434214413	28626	Economy	10900.00
0005434214422	28626	Economy	10900.00
0005434214431	28626	Economy	12000.00
0005434755868	28626	Economy	12000.00
0005434755892	28626	Economy	12000.00
0005434214443	28626	Economy	12000.00
0005434755865	28626	Economy	12000.00
0005434214433	28626	Economy	10900.00
0005434755981	28626	Economy	10900.00
0005434755881	28626	Economy	10900.00
0005434755950	28626	Economy	10900.00
0005434755994	28626	Economy	10900.00
0005434214439	28626	Economy	10900.00
0005434755783	28626	Economy	10900.00
0005434214437	28626	Economy	10900.00
0005434214429	28626	Economy	10900.00
0005434214432	28626	Economy	10900.00
0005434755973	28626	Economy	10900.00
0005434755854	28626	Economy	10900.00
0005434755977	28626	Economy	10900.00
0005434214455	28626	Economy	10900.00
0005434755861	28626	Economy	10900.00
0005434214451	28626	Economy	10900.00
0005434214424	28626	Economy	10900.00
0005434756004	28626	Economy	10900.00
0005434755853	28626	Economy	10900.00
0005434214449	28626	Economy	10900.00
0005434214420	28626	Economy	10900.00
0005434756005	28626	Economy	10900.00
0005434755909	28626	Economy	10900.00
0005434755846	28626	Economy	10900.00
0005434755955	28626	Economy	10900.00
0005434214441	28626	Economy	10900.00
0005434755921	28626	Economy	10900.00
0005434214440	28626	Economy	10900.00
0005434214436	28626	Economy	10900.00
0005434755872	28626	Economy	10900.00
0005434214427	28626	Economy	10900.00
0005434214425	28626	Economy	10900.00
0005434755796	28626	Economy	10900.00
0005434755845	28626	Economy	10900.00
0005434214418	28626	Economy	10900.00
0005434755879	28626	Economy	10900.00
0005434214447	28626	Economy	10900.00
0005434214416	28626	Economy	10900.00
0005434755795	28626	Economy	10900.00
0005434214417	28626	Economy	10900.00
0005434214446	28626	Economy	10900.00
0005434214445	28626	Economy	10900.00
0005434755938	28626	Economy	10900.00
0005434756006	28626	Economy	10900.00
0005434214428	28626	Economy	10900.00
0005434755920	28626	Economy	10900.00
0005434214452	28626	Economy	10900.00
0005434755871	28626	Economy	10900.00
0005434214438	28626	Economy	10900.00
0005434755949	28626	Economy	10900.00
0005434214456	28626	Economy	10900.00
0005434214421	28626	Economy	10900.00
0005434755925	28626	Economy	10900.00
0005434755980	28626	Economy	10900.00
0005434214434	28626	Economy	10900.00
0005434755912	28626	Economy	10900.00
0005434755855	28626	Economy	10900.00
0005434214414	28626	Economy	10900.00
0005434214454	28626	Economy	10900.00
0005434755991	28626	Economy	10900.00
0005434755997	28626	Economy	10900.00
0005434755956	28626	Economy	10900.00
0005434214435	28626	Economy	10900.00
0005434214430	28626	Economy	10900.00
0005434755996	28626	Economy	10900.00
0005434755926	28626	Economy	10900.00
0005434755880	28626	Economy	10900.00
0005435100119	10835	Economy	8900.00
0005435100118	10835	Economy	8900.00
0005435100120	10835	Economy	8900.00
0005435100085	31800	Economy	8900.00
0005435100091	31800	Economy	8900.00
0005435100080	31800	Economy	8900.00
0005434760195	31800	Economy	8900.00
0005434760194	31800	Economy	8900.00
0005434760196	31800	Economy	8900.00
0005435100092	31800	Economy	8900.00
0005433202244	1986	Economy	20900.00
0005433202251	1986	Economy	20900.00
0005433202180	1986	Economy	20900.00
0005434639306	1986	Economy	20900.00
0005432290630	1986	Economy	19000.00
0005434639289	1986	Economy	19000.00
0005434639288	1986	Economy	19000.00
0005434639309	1986	Economy	19000.00
0005433202112	1986	Economy	19000.00
0005433202179	1986	Economy	19000.00
0005434639291	1986	Economy	19000.00
0005433202234	1986	Economy	19000.00
0005432290632	1986	Economy	19000.00
0005433202252	1986	Economy	19000.00
0005434639307	1986	Economy	19000.00
0005433202200	1986	Economy	19000.00
0005434639290	1986	Economy	19000.00
0005434639301	1986	Economy	19000.00
0005433202235	1986	Economy	19000.00
0005433202250	1986	Economy	19000.00
0005433202242	1986	Economy	19000.00
0005432290629	1986	Economy	19000.00
0005434639303	1986	Economy	19000.00
0005434639304	1986	Economy	19000.00
0005433202233	1986	Economy	19000.00
0005434639293	1986	Economy	19000.00
0005434639308	1986	Economy	19000.00
0005432290631	1986	Economy	19000.00
0005434639294	1986	Economy	19000.00
0005433202275	1986	Economy	19000.00
0005434639302	1986	Economy	19000.00
0005434639297	1986	Economy	19000.00
0005433202247	1986	Economy	19000.00
0005433202249	1986	Economy	19000.00
0005433202222	1986	Economy	19000.00
0005434639300	1986	Economy	19000.00
0005434639305	1986	Economy	19000.00
0005433202199	1986	Economy	19000.00
0005433202246	1986	Economy	19000.00
0005433202143	1986	Economy	19000.00
0005433202243	1986	Economy	19000.00
0005434639299	1986	Economy	19000.00
0005434639298	1986	Economy	19000.00
0005434639292	1986	Economy	19000.00
0005433202224	1986	Economy	19000.00
0005433202158	1986	Economy	19000.00
0005434639296	1986	Economy	19000.00
0005433202297	1986	Economy	19000.00
0005434639295	1986	Economy	19000.00
0005433202296	1986	Economy	19000.00
0005434639022	23258	Economy	20900.00
0005434639106	23258	Economy	20900.00
0005433202342	23258	Economy	20900.00
0005434639045	23258	Economy	19000.00
0005434639112	23258	Economy	19000.00
0005434639025	23258	Economy	19000.00
0005433202337	23258	Economy	19000.00
0005433202338	23258	Economy	19000.00
0005434639020	23258	Economy	19000.00
0005433202336	23258	Economy	19000.00
0005434639091	23258	Economy	19000.00
0005433202341	23258	Economy	19000.00
0005434639105	23258	Economy	19000.00
0005434639044	23258	Economy	19000.00
0005434639080	23258	Economy	19000.00
0005433202333	23258	Economy	19000.00
0005434639026	23258	Economy	19000.00
0005434639097	23258	Economy	19000.00
0005434639086	23258	Economy	19000.00
0005433202330	23258	Economy	19000.00
0005434639012	23258	Economy	19000.00
0005433202335	23258	Economy	19000.00
0005433202334	23258	Economy	19000.00
0005434639040	23258	Economy	19000.00
0005434638930	23258	Economy	19000.00
0005433202331	23258	Economy	19000.00
0005434639108	23258	Economy	19000.00
0005434639063	23258	Economy	19000.00
0005434639039	23258	Economy	19000.00
0005433202340	23258	Economy	19000.00
0005434639107	23258	Economy	19000.00
0005434639113	23258	Economy	19000.00
0005434639087	23258	Economy	19000.00
0005434639095	23258	Economy	19000.00
0005434639079	23258	Economy	19000.00
0005433202329	23258	Economy	19000.00
0005433202339	23258	Economy	19000.00
0005433202332	23258	Economy	19000.00
0005434639096	23258	Economy	19000.00
0005435326569	6047	Business	69700.00
0005435326616	6047	Business	69700.00
0005433533304	6047	Business	69700.00
0005434600789	6047	Business	69700.00
0005434600772	6047	Business	69700.00
0005435326605	6047	Business	69700.00
0005434600771	6047	Economy	23200.00
0005433531288	6047	Economy	23200.00
0005433531290	6047	Economy	23200.00
0005434600790	6047	Economy	23200.00
0005434600768	6047	Economy	25600.00
0005433531287	6047	Economy	25600.00
0005434600794	6047	Economy	25600.00
0005432111277	6047	Economy	23200.00
0005435326635	6047	Economy	23200.00
0005435326634	6047	Economy	23200.00
0005435326657	6047	Economy	23200.00
0005433531289	6047	Economy	23200.00
0005434600776	6047	Economy	23200.00
0005434600779	6047	Economy	23200.00
0005435326624	6047	Economy	23200.00
0005435326615	6047	Economy	23200.00
0005434600769	6047	Economy	23200.00
0005435326627	6047	Economy	23200.00
0005433533305	6047	Economy	23200.00
0005432111275	6047	Economy	23200.00
0005433533306	6047	Economy	23200.00
0005434600792	6047	Economy	23200.00
0005434600775	6047	Economy	23200.00
0005434600773	6047	Economy	23200.00
0005434600791	6047	Economy	23200.00
0005434600793	6047	Economy	23200.00
0005434600795	6047	Economy	23200.00
0005434600784	6047	Economy	23200.00
0005434600786	6047	Economy	23200.00
0005434600774	6047	Economy	23200.00
0005434600770	6047	Economy	23200.00
0005433533303	6047	Economy	23200.00
0005434600781	6047	Economy	23200.00
0005435326629	6047	Economy	23200.00
0005435326568	6047	Economy	23200.00
0005434600778	6047	Economy	23200.00
0005434600782	6047	Economy	23200.00
0005434600783	6047	Economy	23200.00
0005435326628	6047	Economy	23200.00
0005434600777	6047	Economy	23200.00
0005434600787	6047	Economy	23200.00
0005432111276	6047	Economy	23200.00
0005434600785	6047	Economy	23200.00
0005434600788	6047	Economy	23200.00
0005434600780	6047	Economy	23200.00
0005435326732	18587	Business	69700.00
0005434600538	18587	Business	69700.00
0005434600631	18587	Business	69700.00
0005434600623	18587	Business	69700.00
0005434600613	18587	Business	69700.00
0005435326728	18587	Business	69700.00
0005434600614	18587	Business	69700.00
0005434600473	18587	Economy	23200.00
0005434600528	18587	Economy	23200.00
0005434600632	18587	Economy	23200.00
0005434600619	18587	Economy	25600.00
0005434600495	18587	Economy	25600.00
0005434600456	18587	Economy	23200.00
0005434600472	18587	Economy	23200.00
0005435326731	18587	Economy	23200.00
0005434600464	18587	Economy	23200.00
0005434600448	18587	Economy	23200.00
0005434600612	18587	Economy	23200.00
0005433531246	18587	Economy	23200.00
0005435326729	18587	Economy	23200.00
0005434600595	18587	Economy	23200.00
0005434600539	18587	Economy	23200.00
0005435326734	18587	Economy	23200.00
0005434600523	18587	Economy	23200.00
0005434600474	18587	Economy	23200.00
0005435326735	18587	Economy	23200.00
0005434600657	18587	Economy	23200.00
0005434600615	18587	Economy	23200.00
0005435326725	18587	Economy	23200.00
0005434600529	18587	Economy	23200.00
0005435326733	18587	Economy	23200.00
0005433531249	18587	Economy	23200.00
0005435326730	18587	Economy	23200.00
0005434600550	18587	Economy	23200.00
0005435326726	18587	Economy	23200.00
0005435326727	18587	Economy	23200.00
0005435326736	18587	Economy	23200.00
0005434600646	18587	Economy	23200.00
0005435326737	18587	Economy	23200.00
0005433527201	18587	Economy	23200.00
0005434600449	18587	Economy	23200.00
0005433531245	18587	Economy	23200.00
0005435326724	18587	Economy	23200.00
0005433531250	18587	Economy	23200.00
0005434551146	10588	Business	9100.00
0005434551113	10588	Business	9100.00
0005434551124	10588	Business	9100.00
0005434558254	10588	Business	9100.00
0005433180787	10588	Business	9100.00
0005434551133	10588	Business	9100.00
0005434551105	10588	Business	9100.00
0005433180939	10588	Business	9100.00
0005434551129	10588	Business	9100.00
0005434551137	10588	Business	9100.00
0005434551136	10588	Business	9100.00
0005434551119	10588	Business	9100.00
0005433180746	10588	Economy	3000.00
0005434551123	10588	Economy	3000.00
0005434558251	10588	Economy	3000.00
0005434558246	10588	Economy	3000.00
0005434551108	10588	Economy	3000.00
0005433180814	10588	Economy	3000.00
0005433180929	10588	Economy	3000.00
0005434554062	10588	Economy	3000.00
0005434551103	10588	Economy	3000.00
0005434551107	10588	Economy	3000.00
0005433180868	10588	Economy	3300.00
0005433180867	10588	Economy	3300.00
0005434551143	10588	Economy	3300.00
0005434558249	10588	Economy	3300.00
0005433180747	10588	Economy	3300.00
0005434551153	10588	Economy	3000.00
0005434551127	10588	Economy	3000.00
0005433180928	10588	Economy	3000.00
0005434551147	10588	Economy	3000.00
0005433180807	10588	Economy	3000.00
0005434551135	10588	Economy	3000.00
0005434551131	10588	Economy	3000.00
0005434551142	10588	Economy	3000.00
0005433180924	10588	Economy	3000.00
0005433180930	10588	Economy	3000.00
0005434551155	10588	Economy	3000.00
0005434558245	10588	Economy	3000.00
0005434551104	10588	Economy	3000.00
0005433180889	10588	Economy	3000.00
0005434551144	10588	Economy	3000.00
0005434558244	10588	Economy	3000.00
0005434551116	10588	Economy	3000.00
0005434551110	10588	Economy	3000.00
0005434551138	10588	Economy	3000.00
0005434551125	10588	Economy	3000.00
0005434551106	10588	Economy	3000.00
0005434551100	10588	Economy	3000.00
0005434551139	10588	Economy	3000.00
0005434558252	10588	Economy	3000.00
0005433180855	10588	Economy	3000.00
0005434551132	10588	Economy	3000.00
0005434551102	10588	Economy	3000.00
0005433180856	10588	Economy	3000.00
0005434551117	10588	Economy	3000.00
0005434551152	10588	Economy	3000.00
0005434551099	10588	Economy	3000.00
0005434551128	10588	Economy	3000.00
0005433180885	10588	Economy	3000.00
0005434558256	10588	Economy	3000.00
0005434554061	10588	Economy	3000.00
0005434558253	10588	Economy	3000.00
0005434551109	10588	Economy	3000.00
0005433180806	10588	Economy	3000.00
0005433180847	10588	Economy	3000.00
0005434551140	10588	Economy	3000.00
0005434551120	10588	Economy	3000.00
0005434551114	10588	Economy	3000.00
0005433180794	10588	Economy	3000.00
0005434551111	10588	Economy	3000.00
0005434558250	10588	Economy	3000.00
0005433180722	10588	Economy	3000.00
0005434551112	10588	Economy	3000.00
0005433180793	10588	Economy	3000.00
0005434551154	10588	Economy	3000.00
0005434551121	10588	Economy	3000.00
0005434558255	10588	Economy	3000.00
0005434551118	10588	Economy	3000.00
0005434551150	10588	Economy	3000.00
0005434551134	10588	Economy	3000.00
0005434551101	10588	Economy	3000.00
0005433180760	10588	Economy	3000.00
0005434551126	10588	Economy	3000.00
0005434551141	10588	Economy	3000.00
0005434551130	10588	Economy	3000.00
0005434551145	10588	Economy	3000.00
0005434551149	10588	Economy	3000.00
0005434551148	10588	Economy	3000.00
0005434558247	10588	Economy	3000.00
0005434558257	10588	Economy	3000.00
0005434558248	10588	Economy	3000.00
0005434551115	10588	Economy	3000.00
0005434551122	10588	Economy	3000.00
0005433180940	10588	Economy	3000.00
0005434551151	10588	Economy	3000.00
0005433180805	10588	Economy	3000.00
0005433181062	27716	Business	9100.00
0005433181083	27716	Economy	3000.00
0005433181080	27716	Economy	3000.00
0005433181074	27716	Economy	3000.00
0005433181078	27716	Economy	3300.00
0005433181086	27716	Economy	3000.00
0005433181068	27716	Economy	3000.00
0005433181073	27716	Economy	3000.00
0005433181072	27716	Economy	3000.00
0005433181085	27716	Economy	3000.00
0005433181079	27716	Economy	3000.00
0005433181064	27716	Economy	3000.00
0005433181081	27716	Economy	3000.00
0005433181082	27716	Economy	3000.00
0005433181070	27716	Economy	3000.00
0005433181067	27716	Economy	3000.00
0005433181084	27716	Economy	3000.00
0005433181065	27716	Economy	3000.00
0005433181063	27716	Economy	3000.00
0005433181075	27716	Economy	3000.00
0005433181076	27716	Economy	3000.00
0005433181077	27716	Economy	3000.00
0005433181066	27716	Economy	3000.00
0005433181071	27716	Economy	3000.00
0005433181069	27716	Economy	3000.00
0005434550580	27713	Business	9100.00
0005434550874	27713	Business	9100.00
0005434550592	27713	Business	9100.00
0005434550542	27713	Business	9100.00
0005434550853	27713	Business	9100.00
0005434558195	27713	Business	9100.00
0005434550693	27713	Business	9100.00
0005434550786	27713	Business	9100.00
0005434558193	27713	Economy	3000.00
0005434550950	27713	Economy	3000.00
0005434550559	27713	Economy	3000.00
0005434550861	27713	Economy	3000.00
0005434550688	27713	Economy	3000.00
0005434550617	27713	Economy	3000.00
0005434550527	27713	Economy	3000.00
0005434550804	27713	Economy	3300.00
0005434550859	27713	Economy	3300.00
0005434550785	27713	Economy	3300.00
0005434550561	27713	Economy	3300.00
0005434558180	27713	Economy	3300.00
0005434558188	27713	Economy	3000.00
0005434550930	27713	Economy	3000.00
0005434558190	27713	Economy	3000.00
0005434558194	27713	Economy	3000.00
0005434558169	27713	Economy	3000.00
0005434550708	27713	Economy	3000.00
0005434550419	27713	Economy	3000.00
0005434550808	27713	Economy	3000.00
0005434550760	27713	Economy	3000.00
0005434550509	27713	Economy	3000.00
0005434550757	27713	Economy	3000.00
0005434558192	27713	Economy	3000.00
0005434550562	27713	Economy	3000.00
0005434550615	27713	Economy	3000.00
0005434550689	27713	Economy	3000.00
0005434550655	27713	Economy	3000.00
0005434550862	27713	Economy	3000.00
0005434550784	27713	Economy	3000.00
0005434558168	27713	Economy	3000.00
0005434550680	27713	Economy	3000.00
0005434558204	27713	Economy	3000.00
0005434550733	27713	Economy	3000.00
0005434550547	27713	Economy	3000.00
0005434550812	27713	Economy	3000.00
0005434550690	27713	Economy	3000.00
0005434550579	27713	Economy	3000.00
0005434554040	27713	Economy	3000.00
0005434550709	27713	Economy	3000.00
0005434550810	27713	Economy	3000.00
0005434550819	27713	Economy	3000.00
0005434550811	27713	Economy	3000.00
0005434550806	27713	Economy	3000.00
0005434550718	27713	Economy	3000.00
0005434550404	27713	Economy	3000.00
0005434558181	27713	Economy	3000.00
0005434550558	27713	Economy	3000.00
0005434558189	27713	Economy	3000.00
0005434550736	27713	Economy	3000.00
0005434550735	27713	Economy	3000.00
0005434550875	27713	Economy	3000.00
0005434550710	27713	Economy	3000.00
0005434550854	27713	Economy	3000.00
0005434550931	27713	Economy	3000.00
0005434550519	27713	Economy	3000.00
0005434550616	27713	Economy	3000.00
0005434550781	27713	Economy	3000.00
0005434558196	27713	Economy	3000.00
0005434550640	27713	Economy	3000.00
0005433459217	6152	Economy	11700.00
0005433459214	6152	Economy	11700.00
0005433459216	6152	Economy	11700.00
0005433459215	6152	Economy	11700.00
0005435254440	6152	Economy	11700.00
0005433459182	19345	Economy	11700.00
0005433459171	19345	Economy	11700.00
0005433459178	19345	Economy	11700.00
0005433459153	19345	Economy	11700.00
0005435254472	19345	Economy	11700.00
0005433459175	19345	Economy	11700.00
0005435254471	19345	Economy	11700.00
0005433459179	19345	Economy	11700.00
0005435682097	6739	Business	51100.00
0005435682101	6739	Business	51100.00
0005435682083	6739	Business	51100.00
0005435682078	6739	Business	51100.00
0005435682071	6739	Business	51100.00
0005435682069	6739	Business	51100.00
0005435682068	6739	Business	51100.00
0005435682094	6739	Business	51100.00
0005435682093	6739	Business	51100.00
0005435682080	6739	Business	51100.00
0005435661926	6739	Economy	17000.00
0005435682076	6739	Economy	17000.00
0005435682082	6739	Economy	17000.00
0005434828670	6739	Economy	17000.00
0005435682108	6739	Economy	17000.00
0005435682075	6739	Economy	17000.00
0005435437752	6739	Economy	17000.00
0005435437788	6739	Economy	17000.00
0005435437776	6739	Economy	17000.00
0005435630962	6739	Economy	17000.00
0005435682092	6739	Economy	18700.00
0005435682103	6739	Economy	18700.00
0005435682067	6739	Economy	18700.00
0005432533262	6739	Economy	18700.00
0005435437785	6739	Economy	18700.00
0005435682070	6739	Economy	17000.00
0005432136163	6739	Economy	17000.00
0005435682072	6739	Economy	17000.00
0005432136162	6739	Economy	17000.00
0005435437707	6739	Economy	17000.00
0005435682085	6739	Economy	17000.00
0005435682098	6739	Economy	17000.00
0005435437681	6739	Economy	17000.00
0005435437715	6739	Economy	17000.00
0005435682087	6739	Economy	17000.00
0005435220304	6739	Economy	17000.00
0005435437812	6739	Economy	17000.00
0005435437705	6739	Economy	17000.00
0005435437804	6739	Economy	17000.00
0005435437678	6739	Economy	17000.00
0005435682088	6739	Economy	17000.00
0005435682086	6739	Economy	17000.00
0005435437751	6739	Economy	17000.00
0005435217688	6739	Economy	17000.00
0005435217687	6739	Economy	17000.00
0005435437763	6739	Economy	17000.00
0005435437792	6739	Economy	17000.00
0005435661924	6739	Economy	17000.00
0005435682106	6739	Economy	17000.00
0005435437615	6739	Economy	17000.00
0005435682066	6739	Economy	17000.00
0005435437614	6739	Economy	17000.00
0005435682104	6739	Economy	17000.00
0005435630960	6739	Economy	17000.00
0005435437746	6739	Economy	17000.00
0005432533259	6739	Economy	17000.00
0005435437679	6739	Economy	17000.00
0005435437737	6739	Economy	17000.00
0005435682089	6739	Economy	17000.00
0005435682081	6739	Economy	17000.00
0005435661925	6739	Economy	17000.00
0005435437704	6739	Economy	17000.00
0005435437760	6739	Economy	17000.00
0005435682099	6739	Economy	17000.00
0005435630961	6739	Economy	17000.00
0005435437775	6739	Economy	17000.00
0005435437766	6739	Economy	17000.00
0005435682100	6739	Economy	17000.00
0005432136166	6739	Economy	17000.00
0005432533261	6739	Economy	17000.00
0005435682079	6739	Economy	17000.00
0005435682096	6739	Economy	17000.00
0005435437846	6739	Economy	17000.00
0005432136164	6739	Economy	17000.00
0005435682090	6739	Economy	17000.00
0005435682107	6739	Economy	17000.00
0005435682095	6739	Economy	17000.00
0005435682065	6739	Economy	17000.00
0005435437847	6739	Economy	17000.00
0005432136161	6739	Economy	17000.00
0005435217686	6739	Economy	17000.00
0005435437680	6739	Economy	17000.00
0005435682077	6739	Economy	17000.00
0005435682105	6739	Economy	17000.00
0005435682084	6739	Economy	17000.00
0005435437784	6739	Economy	17000.00
0005432136160	6739	Economy	17000.00
0005435682073	6739	Economy	17000.00
0005432136165	6739	Economy	17000.00
0005435682102	6739	Economy	17000.00
0005435682091	6739	Economy	17000.00
0005435682074	6739	Economy	17000.00
0005435437774	6739	Economy	17000.00
0005435437789	6739	Economy	17000.00
0005435437932	24591	Business	51100.00
0005435437916	24591	Business	51100.00
0005435681612	24591	Business	51100.00
0005432533288	24591	Business	51100.00
0005435437934	24591	Business	51100.00
0005435681571	24591	Business	51100.00
0005435437926	24591	Business	51100.00
0005435681700	24591	Business	51100.00
0005435681692	24591	Business	51100.00
0005435681705	24591	Business	51100.00
0005435661910	24591	Economy	17000.00
0005435681691	24591	Economy	17000.00
0005435720808	24591	Economy	17000.00
0005435437915	24591	Economy	17000.00
0005435681709	24591	Economy	17000.00
0005435681632	24591	Economy	17000.00
0005435437936	24591	Economy	17000.00
0005435681516	24591	Economy	17000.00
0005435719554	24591	Economy	17000.00
0005435681735	24591	Economy	18700.00
0005435681884	24591	Economy	18700.00
0005435681650	24591	Economy	18700.00
0005432533290	24591	Economy	18700.00
0005435681694	24591	Economy	17000.00
0005432533287	24591	Economy	17000.00
0005434828695	24591	Economy	17000.00
0005434828694	24591	Economy	17000.00
0005435437924	24591	Economy	17000.00
0005435681739	24591	Economy	17000.00
0005435720815	24591	Economy	17000.00
0005435437933	24591	Economy	17000.00
0005435681683	24591	Economy	17000.00
0005435437928	24591	Economy	17000.00
0005435681729	24591	Economy	17000.00
0005435681823	24591	Economy	17000.00
0005435681695	24591	Economy	17000.00
0005435437931	24591	Economy	17000.00
0005435661911	24591	Economy	17000.00
0005435681847	24591	Economy	17000.00
0005435681828	24591	Economy	17000.00
0005435681704	24591	Economy	17000.00
0005435437925	24591	Economy	17000.00
0005435437927	24591	Economy	17000.00
0005435630941	24591	Economy	17000.00
0005435681557	24591	Economy	17000.00
0005435437930	24591	Economy	17000.00
0005435681798	24591	Economy	17000.00
0005435661912	24591	Economy	17000.00
0005435681728	24591	Economy	17000.00
0005435437935	24591	Economy	17000.00
0005435437937	24591	Economy	17000.00
0005435681699	24591	Economy	17000.00
0005435437919	24591	Economy	17000.00
0005435681661	24591	Economy	17000.00
0005435681572	24591	Economy	17000.00
0005432305746	24591	Economy	17000.00
0005432305745	24591	Economy	17000.00
0005435681589	24591	Economy	17000.00
0005435719553	24591	Economy	17000.00
0005435437922	24591	Economy	17000.00
0005435437920	24591	Economy	17000.00
0005435681660	24591	Economy	17000.00
0005435681830	24591	Economy	17000.00
0005435437918	24591	Economy	17000.00
0005435681682	24591	Economy	17000.00
0005435437917	24591	Economy	17000.00
0005435681542	24591	Economy	17000.00
0005435681867	24591	Economy	17000.00
0005435720816	24591	Economy	17000.00
0005435681727	24591	Economy	17000.00
0005435681846	24591	Economy	17000.00
0005435681844	24591	Economy	17000.00
0005435437921	24591	Economy	17000.00
0005435681698	24591	Economy	17000.00
0005432533289	24591	Economy	17000.00
0005435681903	24591	Economy	17000.00
0005435681797	24591	Economy	17000.00
0005435437929	24591	Economy	17000.00
0005435681754	24591	Economy	17000.00
0005435719555	24591	Economy	17000.00
0005435661905	24591	Economy	17000.00
0005435630926	24591	Economy	17000.00
0005435437923	24591	Economy	17000.00
0005435105976	11560	Business	26400.00
0005435126301	11560	Business	26400.00
0005435126277	11560	Business	26400.00
0005435126298	11560	Business	26400.00
0005435126284	11560	Business	26400.00
0005435126278	11560	Business	26400.00
0005435126292	11560	Business	26400.00
0005435126285	11560	Business	26400.00
0005435126302	11560	Business	26400.00
0005435126304	11560	Economy	8800.00
0005435126307	11560	Economy	8800.00
0005435126274	11560	Economy	8800.00
0005435126280	11560	Economy	8800.00
0005435126311	11560	Economy	8800.00
0005435126296	11560	Economy	9700.00
0005435126289	11560	Economy	9700.00
0005435126308	11560	Economy	9700.00
0005435126294	11560	Economy	8800.00
0005435126297	11560	Economy	8800.00
0005435126276	11560	Economy	8800.00
0005435126300	11560	Economy	8800.00
0005435126272	11560	Economy	8800.00
0005435126306	11560	Economy	8800.00
0005435126290	11560	Economy	8800.00
0005435126275	11560	Economy	8800.00
0005435126293	11560	Economy	8800.00
0005435126303	11560	Economy	8800.00
0005435126299	11560	Economy	8800.00
0005435105975	11560	Economy	8800.00
0005435126281	11560	Economy	8800.00
0005435126273	11560	Economy	8800.00
0005435126286	11560	Economy	8800.00
0005435126288	11560	Economy	8800.00
0005435126305	11560	Economy	8800.00
0005435558060	11560	Economy	8800.00
0005435126291	11560	Economy	8800.00
0005435126287	11560	Economy	8800.00
0005435126313	11560	Economy	8800.00
0005435126295	11560	Economy	8800.00
0005435126282	11560	Economy	8800.00
0005435105977	11560	Economy	8800.00
0005435126310	11560	Economy	8800.00
0005435126309	11560	Economy	8800.00
0005435126312	11560	Economy	8800.00
0005435126283	11560	Economy	8800.00
0005435126279	11560	Economy	8800.00
0005435558083	31875	Business	26400.00
0005435125748	31875	Business	26400.00
0005435105961	31875	Business	26400.00
0005435125932	31875	Business	26400.00
0005435125928	31875	Economy	8800.00
0005435125802	31875	Economy	8800.00
0005435126124	31875	Economy	8800.00
0005435098532	31875	Economy	8800.00
0005435098533	31875	Economy	8800.00
0005435105958	31875	Economy	8800.00
0005435126080	31875	Economy	9700.00
0005435125803	31875	Economy	9700.00
0005435126031	31875	Economy	9700.00
0005435126092	31875	Economy	8800.00
0005435125849	31875	Economy	8800.00
0005435125821	31875	Economy	8800.00
0005435125986	31875	Economy	8800.00
0005435125980	31875	Economy	8800.00
0005435098535	31875	Economy	8800.00
0005435105965	31875	Economy	8800.00
0005435126051	31875	Economy	8800.00
0005435558084	31875	Economy	8800.00
0005435125749	31875	Economy	8800.00
0005435125943	31875	Economy	8800.00
0005435126123	31875	Economy	8800.00
0005435126045	31875	Economy	8800.00
0005435126111	31875	Economy	8800.00
0005435125860	31875	Economy	8800.00
0005435125950	31875	Economy	8800.00
0005435125899	31875	Economy	8800.00
0005435125850	31875	Economy	8800.00
0005435125931	31875	Economy	8800.00
0005435105948	31875	Economy	8800.00
0005435126120	31875	Economy	8800.00
0005435126022	31875	Economy	8800.00
0005435105967	31875	Economy	8800.00
0005435126103	31875	Economy	8800.00
0005435125907	31875	Economy	8800.00
0005435125963	31875	Economy	8800.00
0005435126134	31875	Economy	8800.00
0005435126038	31875	Economy	8800.00
0005435105960	31875	Economy	8800.00
0005435126052	31875	Economy	8800.00
0005435105957	31875	Economy	8800.00
0005435126091	31875	Economy	8800.00
0005435125994	31875	Economy	8800.00
0005435125985	31875	Economy	8800.00
0005435125917	31875	Economy	8800.00
0005435105959	31875	Economy	8800.00
0005435126081	31875	Economy	8800.00
0005435125967	31875	Economy	8800.00
0005435126156	31875	Economy	8800.00
0005435126043	31875	Economy	8800.00
0005435125747	31875	Economy	8800.00
0005435125870	31875	Economy	8800.00
0005435126032	31875	Economy	8800.00
0005435126016	31875	Economy	8800.00
0005435126017	31875	Economy	8800.00
0005435126044	31875	Economy	8800.00
0005435105966	31875	Economy	8800.00
0005433397985	13509	Business	36600.00
0005433398017	13509	Business	36600.00
0005433397995	13509	Business	36600.00
0005435732265	13509	Business	36600.00
0005433398013	13509	Business	36600.00
0005435732266	13509	Business	36600.00
0005435732225	13509	Economy	12200.00
0005433397986	13509	Economy	12200.00
0005433397978	13509	Economy	12200.00
0005433397988	13509	Economy	12200.00
0005435732241	13509	Economy	12200.00
0005433398014	13509	Economy	12200.00
0005433397989	13509	Economy	13400.00
0005433397991	13509	Economy	13400.00
0005433397983	13509	Economy	13400.00
0005433398021	13509	Economy	12200.00
0005433397997	13509	Economy	12200.00
0005433397990	13509	Economy	12200.00
0005433398001	13509	Economy	12200.00
0005433398009	13509	Economy	12200.00
0005433397979	13509	Economy	12200.00
0005433398020	13509	Economy	12200.00
0005433398002	13509	Economy	12200.00
0005433398007	13509	Economy	12200.00
0005433398015	13509	Economy	12200.00
0005433398010	13509	Economy	12200.00
0005433397981	13509	Economy	12200.00
0005433398003	13509	Economy	12200.00
0005435732186	13509	Economy	12200.00
0005433397975	13509	Economy	12200.00
0005433397992	13509	Economy	12200.00
0005435732232	13509	Economy	12200.00
0005433398011	13509	Economy	12200.00
0005433397977	13509	Economy	12200.00
0005435732242	13509	Economy	12200.00
0005433398018	13509	Economy	12200.00
0005433397982	13509	Economy	12200.00
0005435732228	13509	Economy	12200.00
0005433398022	13509	Economy	12200.00
0005433397994	13509	Economy	12200.00
0005433397980	13509	Economy	12200.00
0005433397984	13509	Economy	12200.00
0005433398008	13509	Economy	12200.00
0005433398016	13509	Economy	12200.00
0005433397998	13509	Economy	12200.00
0005433398012	13509	Economy	12200.00
0005433397976	13509	Economy	12200.00
0005433397987	13509	Economy	12200.00
0005433398019	13509	Economy	12200.00
0005433398023	13509	Economy	12200.00
0005433397993	13509	Economy	12200.00
0005435732200	13509	Economy	12200.00
0005433397999	13509	Economy	12200.00
0005433398004	13509	Economy	12200.00
0005433397996	13509	Economy	12200.00
0005435732206	13509	Economy	12200.00
0005433398006	13509	Economy	12200.00
0005433398005	13509	Economy	12200.00
0005433398000	13509	Economy	12200.00
0005433397437	19379	Business	36600.00
0005433397617	19379	Business	36600.00
0005433397589	19379	Business	36600.00
0005433397511	19379	Business	36600.00
0005433397557	19379	Business	36600.00
0005433397677	19379	Business	36600.00
0005433397738	19379	Business	36600.00
0005432297274	19379	Business	36600.00
0005432297275	19379	Economy	12200.00
0005433397852	19379	Economy	12200.00
0005433397247	19379	Economy	12200.00
0005433397429	19379	Economy	12200.00
0005433397510	19379	Economy	12200.00
0005433397664	19379	Economy	12200.00
0005433397698	19379	Economy	12200.00
0005433397619	19379	Economy	12200.00
0005433397575	19379	Economy	13400.00
0005433397665	19379	Economy	12200.00
0005433397433	19379	Economy	12200.00
0005433397473	19379	Economy	12200.00
0005433397640	19379	Economy	12200.00
0005433397839	19379	Economy	12200.00
0005433397574	19379	Economy	12200.00
0005433397624	19379	Economy	12200.00
0005433397603	19379	Economy	12200.00
0005433397503	19379	Economy	12200.00
0005433397661	19379	Economy	12200.00
0005433397689	19379	Economy	12200.00
0005433397717	19379	Economy	12200.00
0005433397629	19379	Economy	12200.00
0005433397614	19379	Economy	12200.00
0005433397576	19379	Economy	12200.00
0005433397755	19379	Economy	12200.00
0005433397436	19379	Economy	12200.00
0005433397432	19379	Economy	12200.00
0005433397555	19379	Economy	12200.00
0005433397403	19379	Economy	12200.00
0005433397595	19379	Economy	12200.00
0005433397620	19379	Economy	12200.00
0005433397806	19379	Economy	12200.00
0005433397453	19379	Economy	12200.00
0005433397585	19379	Economy	12200.00
0005433397613	19379	Economy	12200.00
0005433397542	19379	Economy	12200.00
0005433397571	19379	Economy	12200.00
0005433397591	19379	Economy	12200.00
0005433397623	19379	Economy	12200.00
0005433397434	19379	Economy	12200.00
0005433397739	19379	Economy	12200.00
0005433397631	19379	Economy	12200.00
0005433397477	19379	Economy	12200.00
0005433397526	19379	Economy	12200.00
0005433397592	19379	Economy	12200.00
0005433397641	19379	Economy	12200.00
0005433397666	19379	Economy	12200.00
0005433397630	19379	Economy	12200.00
0005433397604	19379	Economy	12200.00
0005433397718	19379	Economy	12200.00
0005433397722	19379	Economy	12200.00
0005433397435	19379	Economy	12200.00
0005433397554	19379	Economy	12200.00
0005433397491	19379	Economy	12200.00
0005433397558	19379	Economy	12200.00
0005435068668	13132	Business	11300.00
0005435925284	13132	Business	11300.00
0005435068546	13132	Business	11300.00
0005435068611	13132	Business	11300.00
0005435925283	13132	Business	11300.00
0005435068386	13132	Business	11300.00
0005435925294	13132	Business	11300.00
0005435068445	13132	Business	11300.00
0005435068543	13132	Economy	3800.00
0005435068444	13132	Economy	3800.00
0005435068442	13132	Economy	3800.00
0005435068346	13132	Economy	3800.00
0005435068552	13132	Economy	3800.00
0005435068714	13132	Economy	3800.00
0005435068615	13132	Economy	4100.00
0005435068713	13132	Economy	4100.00
0005435068564	13132	Economy	4100.00
0005435068390	13132	Economy	3800.00
0005435925281	13132	Economy	3800.00
0005435925278	13132	Economy	3800.00
0005435068387	13132	Economy	3800.00
0005435068449	13132	Economy	3800.00
0005435925279	13132	Economy	3800.00
0005435068634	13132	Economy	3800.00
0005435068391	13132	Economy	3800.00
0005435068559	13132	Economy	3800.00
0005435068560	13132	Economy	3800.00
0005435925280	13132	Economy	3800.00
0005435068600	13132	Economy	3800.00
0005435925286	13132	Economy	3800.00
0005435068633	13132	Economy	3800.00
0005435068389	13132	Economy	3800.00
0005435925291	13132	Economy	3800.00
0005435068549	13132	Economy	3800.00
0005435068786	13132	Economy	3800.00
0005435925289	13132	Economy	3800.00
0005435068639	13132	Economy	3800.00
0005435068561	13132	Economy	3800.00
0005435068529	13132	Economy	3800.00
0005435068544	13132	Economy	3800.00
0005435068477	13132	Economy	3800.00
0005435068711	13132	Economy	3800.00
0005435068418	13132	Economy	3800.00
0005435068397	13132	Economy	3800.00
0005435068493	13132	Economy	3800.00
0005435925290	13132	Economy	3800.00
0005435068494	13132	Economy	3800.00
0005435068627	13132	Economy	3800.00
0005435068550	13132	Economy	3800.00
0005435925293	13132	Economy	3800.00
0005435068504	13132	Economy	3800.00
0005435925292	13132	Economy	3800.00
0005435068321	13132	Economy	3800.00
0005435068505	13132	Economy	3800.00
0005435068745	13132	Economy	3800.00
0005435068601	13132	Economy	3800.00
0005435068640	13132	Economy	3800.00
0005435925285	13132	Economy	3800.00
0005435068530	13132	Economy	3800.00
0005435068562	13132	Economy	3800.00
0005435068509	13132	Economy	3800.00
0005435068744	13132	Economy	3800.00
0005435068565	13132	Economy	3800.00
0005435068563	13132	Economy	3800.00
0005435925282	13132	Economy	3800.00
0005435068462	13132	Economy	3800.00
0005435068630	13132	Economy	3800.00
0005435068582	13132	Economy	3800.00
0005435925287	13132	Economy	3800.00
0005435068508	13132	Economy	3800.00
0005435925288	13132	Economy	3800.00
0005435068490	13132	Economy	3800.00
0005435068551	13132	Economy	3800.00
0005435068463	13132	Economy	3800.00
0005435068305	13132	Economy	3800.00
0005435068703	13132	Economy	3800.00
0005435068535	13132	Economy	3800.00
0005435925140	15516	Business	11300.00
0005435068970	15516	Business	11300.00
0005435068961	15516	Business	11300.00
0005435068955	15516	Business	11300.00
0005435068957	15516	Business	11300.00
0005435068988	15516	Business	11300.00
0005435925139	15516	Business	11300.00
0005435068971	15516	Business	11300.00
0005435068976	15516	Business	11300.00
0005435068997	15516	Economy	3800.00
0005435925121	15516	Economy	3800.00
0005435068959	15516	Economy	3800.00
0005435069003	15516	Economy	3800.00
0005435068962	15516	Economy	3800.00
0005435925145	15516	Economy	4100.00
0005435925152	15516	Economy	4100.00
0005435069004	15516	Economy	4100.00
0005435068996	15516	Economy	3800.00
0005435068969	15516	Economy	3800.00
0005435068954	15516	Economy	3800.00
0005435068977	15516	Economy	3800.00
0005435068980	15516	Economy	3800.00
0005435068993	15516	Economy	3800.00
0005435068965	15516	Economy	3800.00
0005435068992	15516	Economy	3800.00
0005435068960	15516	Economy	3800.00
0005435068983	15516	Economy	3800.00
0005435068991	15516	Economy	3800.00
0005435069001	15516	Economy	3800.00
0005435068982	15516	Economy	3800.00
0005435068975	15516	Economy	3800.00
0005435068999	15516	Economy	3800.00
0005435925129	15516	Economy	3800.00
0005435925143	15516	Economy	3800.00
0005435068986	15516	Economy	3800.00
0005435068989	15516	Economy	3800.00
0005435068987	15516	Economy	3800.00
0005435925124	15516	Economy	3800.00
0005435069000	15516	Economy	3800.00
0005435925100	15516	Economy	3800.00
0005435925141	15516	Economy	3800.00
0005435068978	15516	Economy	3800.00
0005435068985	15516	Economy	3800.00
0005435068979	15516	Economy	3800.00
0005435069006	15516	Economy	3800.00
0005435068973	15516	Economy	3800.00
0005435925123	15516	Economy	3800.00
0005435068967	15516	Economy	3800.00
0005435925125	15516	Economy	3800.00
0005435068964	15516	Economy	3800.00
0005435068974	15516	Economy	3800.00
0005435068984	15516	Economy	3800.00
0005435068972	15516	Economy	3800.00
0005435069002	15516	Economy	3800.00
0005435069005	15516	Economy	3800.00
0005435068968	15516	Economy	3800.00
0005435068963	15516	Economy	3800.00
0005435925144	15516	Economy	3800.00
0005435068995	15516	Economy	3800.00
0005435068956	15516	Economy	3800.00
0005435068981	15516	Economy	3800.00
0005435068994	15516	Economy	3800.00
0005435068998	15516	Economy	3800.00
0005435068953	15516	Economy	3800.00
0005435068966	15516	Economy	3800.00
0005435068958	15516	Economy	3800.00
0005435925136	15516	Economy	3800.00
0005435068990	15516	Economy	3800.00
0005435808083	29502	Economy	27100.00
0005435808121	29502	Economy	27100.00
0005433407557	29502	Economy	27100.00
0005433407563	29502	Economy	24700.00
0005433407561	29502	Economy	24700.00
0005435808092	29502	Economy	24700.00
0005433407560	29502	Economy	24700.00
0005433407556	29502	Economy	24700.00
0005433407564	29502	Economy	24700.00
0005435808084	29502	Economy	24700.00
0005435808148	29502	Economy	24700.00
0005435808163	29502	Economy	24700.00
0005435808127	29502	Economy	24700.00
0005435808096	29502	Economy	24700.00
0005435808082	29502	Economy	24700.00
0005433407558	29502	Economy	24700.00
0005435808145	29502	Economy	24700.00
0005435808077	29502	Economy	24700.00
0005435808076	29502	Economy	24700.00
0005433407559	29502	Economy	24700.00
0005435808147	29502	Economy	24700.00
0005435808120	29502	Economy	24700.00
0005435808104	29502	Economy	24700.00
0005433407562	29502	Economy	24700.00
0005435808146	29502	Economy	24700.00
0005435808091	29502	Economy	24700.00
0005435808116	29502	Economy	24700.00
0005435808094	29502	Economy	24700.00
0005433407555	29502	Economy	24700.00
0005435808093	29502	Economy	24700.00
0005434755895	10715	Business	61300.00
0005434755934	10715	Business	61300.00
0005434214459	10715	Business	61300.00
0005434756032	10715	Business	61300.00
0005434755923	10715	Business	61300.00
0005434214498	10715	Business	61300.00
0005434214467	10715	Business	61300.00
0005434755896	10715	Business	61300.00
0005434755933	10715	Business	61300.00
0005434755971	10715	Business	61300.00
0005434755978	10715	Economy	20400.00
0005434755900	10715	Economy	20400.00
0005434214486	10715	Economy	20400.00
0005434214502	10715	Economy	20400.00
0005434214501	10715	Economy	20400.00
0005434755882	10715	Economy	20400.00
0005434755894	10715	Economy	20400.00
0005434756075	10715	Economy	20400.00
0005434214461	10715	Economy	20400.00
0005434755979	10715	Economy	20400.00
0005434214466	10715	Economy	22500.00
0005434756076	10715	Economy	22500.00
0005434214474	10715	Economy	22500.00
0005434214484	10715	Economy	22500.00
0005434214476	10715	Economy	22500.00
0005434214499	10715	Economy	20400.00
0005434214496	10715	Economy	20400.00
0005434214468	10715	Economy	20400.00
0005434756064	10715	Economy	20400.00
0005434755889	10715	Economy	20400.00
0005434214494	10715	Economy	20400.00
0005434214472	10715	Economy	20400.00
0005434756000	10715	Economy	20400.00
0005434755781	10715	Economy	20400.00
0005434756059	10715	Economy	20400.00
0005434756065	10715	Economy	20400.00
0005434755992	10715	Economy	20400.00
0005434756040	10715	Economy	20400.00
0005434214479	10715	Economy	20400.00
0005434214487	10715	Economy	20400.00
0005434214507	10715	Economy	20400.00
0005434755814	10715	Economy	20400.00
0005434214500	10715	Economy	20400.00
0005434214506	10715	Economy	20400.00
0005434756008	10715	Economy	20400.00
0005434755786	10715	Economy	20400.00
0005434214470	10715	Economy	20400.00
0005434214478	10715	Economy	20400.00
0005434214480	10715	Economy	20400.00
0005434214481	10715	Economy	20400.00
0005434214483	10715	Economy	20400.00
0005434214462	10715	Economy	20400.00
0005434214491	10715	Economy	20400.00
0005434214490	10715	Economy	20400.00
0005434755969	10715	Economy	20400.00
0005434755833	10715	Economy	20400.00
0005434214504	10715	Economy	20400.00
0005434214471	10715	Economy	20400.00
0005434214492	10715	Economy	20400.00
0005434214475	10715	Economy	20400.00
0005434214477	10715	Economy	20400.00
0005434756072	10715	Economy	20400.00
0005434214473	10715	Economy	20400.00
0005434755970	10715	Economy	20400.00
0005434756013	10715	Economy	20400.00
0005434214503	10715	Economy	20400.00
0005434755972	10715	Economy	20400.00
0005434755813	10715	Economy	20400.00
0005434214505	10715	Economy	20400.00
0005434755834	10715	Economy	20400.00
0005434214493	10715	Economy	20400.00
0005434214497	10715	Economy	20400.00
0005434756061	10715	Economy	20400.00
0005434214463	10715	Economy	20400.00
0005434214469	10715	Economy	20400.00
0005434214485	10715	Economy	20400.00
0005434214464	10715	Economy	20400.00
0005434755924	10715	Economy	20400.00
0005434214482	10715	Economy	20400.00
0005434755983	10715	Economy	20400.00
0005434214489	10715	Economy	20400.00
0005434755932	10715	Economy	20400.00
0005434214465	10715	Economy	20400.00
0005434214460	10715	Economy	20400.00
0005434755893	10715	Economy	20400.00
0005434755888	10715	Economy	20400.00
0005434214495	10715	Economy	20400.00
0005434755836	10715	Economy	20400.00
0005434214488	10715	Economy	20400.00
0005434756031	10715	Economy	20400.00
0005434756060	10715	Economy	20400.00
0005434756345	28661	Business	61300.00
0005434756331	28661	Business	61300.00
0005434214103	28661	Business	61300.00
0005434214159	28661	Business	61300.00
0005434756349	28661	Business	61300.00
0005434213903	28661	Business	61300.00
0005434213972	28661	Business	61300.00
0005434213799	28661	Business	61300.00
0005434214000	28661	Business	61300.00
0005434214076	28661	Business	61300.00
0005434756356	28661	Business	61300.00
0005434214010	28661	Business	61300.00
0005434214114	28661	Economy	20400.00
0005434756343	28661	Economy	20400.00
0005434214160	28661	Economy	20400.00
0005434213800	28661	Economy	20400.00
0005434756339	28661	Economy	20400.00
0005434214115	28661	Economy	20400.00
0005434756361	28661	Economy	20400.00
0005434214105	28661	Economy	20400.00
0005434214101	28661	Economy	20400.00
0005434214044	28661	Economy	20400.00
0005434214218	28661	Economy	22500.00
0005434214040	28661	Economy	22500.00
0005434214152	28661	Economy	22500.00
0005434214085	28661	Economy	20400.00
0005434756344	28661	Economy	20400.00
0005434214018	28661	Economy	20400.00
0005434214009	28661	Economy	20400.00
0005434756360	28661	Economy	20400.00
0005434756336	28661	Economy	20400.00
0005434214213	28661	Economy	20400.00
0005434214033	28661	Economy	20400.00
0005434756341	28661	Economy	20400.00
0005434756340	28661	Economy	20400.00
0005434214225	28661	Economy	20400.00
0005434214186	28661	Economy	20400.00
0005434213855	28661	Economy	20400.00
0005434213923	28661	Economy	20400.00
0005434756342	28661	Economy	20400.00
0005434756352	28661	Economy	20400.00
0005434756358	28661	Economy	20400.00
0005434756348	28661	Economy	20400.00
0005434214124	28661	Economy	20400.00
0005434756354	28661	Economy	20400.00
0005434756337	28661	Economy	20400.00
0005434756334	28661	Economy	20400.00
0005434214175	28661	Economy	20400.00
0005434213883	28661	Economy	20400.00
0005434213936	28661	Economy	20400.00
0005434756355	28661	Economy	20400.00
0005434756357	28661	Economy	20400.00
0005434213809	28661	Economy	20400.00
0005434756350	28661	Economy	20400.00
0005434214219	28661	Economy	20400.00
0005434214184	28661	Economy	20400.00
0005434213978	28661	Economy	20400.00
0005434214017	28661	Economy	20400.00
0005434756346	28661	Economy	20400.00
0005434756338	28661	Economy	20400.00
0005434213927	28661	Economy	20400.00
0005434756353	28661	Economy	20400.00
0005434214102	28661	Economy	20400.00
0005434756351	28661	Economy	20400.00
0005434214020	28661	Economy	20400.00
0005434756333	28661	Economy	20400.00
0005434213998	28661	Economy	20400.00
0005434756332	28661	Economy	20400.00
0005434213832	28661	Economy	20400.00
0005434214185	28661	Economy	20400.00
0005434214075	28661	Economy	20400.00
0005434756359	28661	Economy	20400.00
0005434214007	28661	Economy	20400.00
0005434214034	28661	Economy	20400.00
0005434214037	28661	Economy	20400.00
0005434213884	28661	Economy	20400.00
0005434213949	28661	Economy	20400.00
0005434756329	28661	Economy	20400.00
0005434214042	28661	Economy	20400.00
0005434214045	28661	Economy	20400.00
0005434756330	28661	Economy	20400.00
0005434213819	28661	Economy	20400.00
0005434214074	28661	Economy	20400.00
0005434214035	28661	Economy	20400.00
0005434214008	28661	Economy	20400.00
0005434756335	28661	Economy	20400.00
0005434756347	28661	Economy	20400.00
0005434214043	28661	Economy	20400.00
0005434213977	28661	Economy	20400.00
0005434229136	5470	Business	29500.00
0005435039718	5470	Business	29500.00
0005435039699	5470	Business	29500.00
0005435007019	5470	Business	29500.00
0005434229235	5470	Business	29500.00
0005435039678	5470	Business	29500.00
0005435039727	5470	Business	29500.00
0005435039669	5470	Business	29500.00
0005434229041	5470	Business	29500.00
0005435039723	5470	Business	29500.00
0005435039683	5470	Business	29500.00
0005434229062	5470	Business	29500.00
0005434229170	5470	Economy	9800.00
0005432125444	5470	Economy	9800.00
0005432125439	5470	Economy	9800.00
0005435042857	5470	Economy	9800.00
0005435039709	5470	Economy	9800.00
0005435039716	5470	Economy	9800.00
0005435007014	5470	Economy	9800.00
0005435039674	5470	Economy	9800.00
0005435039721	5470	Economy	9800.00
0005434229191	5470	Economy	9800.00
0005435039708	5470	Economy	9800.00
0005435007005	5470	Economy	9800.00
0005435039710	5470	Economy	9800.00
0005435039733	5470	Economy	9800.00
0005434229162	5470	Economy	9800.00
0005435039685	5470	Economy	9800.00
0005435039714	5470	Economy	9800.00
0005434229149	5470	Economy	9800.00
0005435007013	5470	Economy	9800.00
0005435039735	5470	Economy	9800.00
0005435039691	5470	Economy	9800.00
0005432125443	5470	Economy	9800.00
0005434229042	5470	Economy	9800.00
0005434229172	5470	Economy	9800.00
0005435039715	5470	Economy	9800.00
0005435007006	5470	Economy	9800.00
0005435007008	5470	Economy	9800.00
0005435007007	5470	Economy	9800.00
0005432125445	5470	Economy	9800.00
0005435039704	5470	Economy	9800.00
0005435039698	5470	Economy	9800.00
0005435039697	5470	Economy	9800.00
0005435039696	5470	Economy	9800.00
0005435007000	5470	Economy	9800.00
0005435039732	5470	Economy	9800.00
0005434229130	5470	Economy	9800.00
0005435007012	5470	Economy	9800.00
0005435039720	5470	Economy	9800.00
0005435006999	5470	Economy	9800.00
0005435039689	5470	Economy	9800.00
0005435039712	5470	Economy	10800.00
0005435039706	5470	Economy	10800.00
0005435039688	5470	Economy	10800.00
0005435039679	5470	Economy	10800.00
0005435007004	5470	Economy	9800.00
0005435042856	5470	Economy	9800.00
0005435039690	5470	Economy	9800.00
0005435039681	5470	Economy	9800.00
0005435007003	5470	Economy	9800.00
0005435039694	5470	Economy	9800.00
0005435039731	5470	Economy	9800.00
0005435039703	5470	Economy	9800.00
0005434229208	5470	Economy	9800.00
0005435006995	5470	Economy	9800.00
0005435007015	5470	Economy	9800.00
0005435039670	5470	Economy	9800.00
0005434229155	5470	Economy	9800.00
0005435039717	5470	Economy	9800.00
0005434229260	5470	Economy	9800.00
0005434229173	5470	Economy	9800.00
0005434229148	5470	Economy	9800.00
0005435039713	5470	Economy	9800.00
0005435007016	5470	Economy	9800.00
0005435039707	5470	Economy	9800.00
0005435039705	5470	Economy	9800.00
0005435039676	5470	Economy	9800.00
0005435039682	5470	Economy	9800.00
0005435039728	5470	Economy	9800.00
0005435039671	5470	Economy	9800.00
0005435039734	5470	Economy	9800.00
0005435039702	5470	Economy	9800.00
0005435039673	5470	Economy	9800.00
0005434229108	5470	Economy	9800.00
0005435039725	5470	Economy	9800.00
0005435007001	5470	Economy	9800.00
0005435039724	5470	Economy	9800.00
0005435039675	5470	Economy	9800.00
0005435039722	5470	Economy	9800.00
0005435039695	5470	Economy	9800.00
0005435007011	5470	Economy	9800.00
0005434229156	5470	Economy	9800.00
0005435039680	5470	Economy	9800.00
0005435006997	5470	Economy	9800.00
0005432125446	5470	Economy	9800.00
0005434229186	5470	Economy	9800.00
0005432125447	5470	Economy	9800.00
0005432125441	5470	Economy	9800.00
0005435039684	5470	Economy	9800.00
0005435039686	5470	Economy	9800.00
0005434229259	5470	Economy	9800.00
0005435039672	5470	Economy	9800.00
0005435007002	5470	Economy	9800.00
0005435039693	5470	Economy	9800.00
0005435039730	5470	Economy	9800.00
0005435039700	5470	Economy	9800.00
0005435039711	5470	Economy	9800.00
0005434229121	5470	Economy	9800.00
0005435039677	5470	Economy	9800.00
0005434229157	5470	Economy	9800.00
0005435007017	5470	Economy	9800.00
0005434229203	5470	Economy	9800.00
0005432125442	5470	Economy	9800.00
0005435006998	5470	Economy	9800.00
0005435039719	5470	Economy	9800.00
0005435039687	5470	Economy	9800.00
0005435007009	5470	Economy	9800.00
0005435039701	5470	Economy	9800.00
0005432125440	5470	Economy	9800.00
0005435039729	5470	Economy	9800.00
0005435039726	5470	Economy	9800.00
0005434229159	5470	Economy	9800.00
0005435006996	5470	Economy	9800.00
0005435007010	5470	Economy	9800.00
0005435007020	5470	Economy	9800.00
0005435039692	5470	Economy	9800.00
0005435007018	5470	Economy	9800.00
0005435006934	12977	Business	29500.00
0005435006937	12977	Business	29500.00
0005435006938	12977	Business	29500.00
0005435038837	12977	Business	29500.00
0005435006710	12977	Business	29500.00
0005435039370	12977	Business	29500.00
0005435006742	12977	Business	29500.00
0005435006812	12977	Business	29500.00
0005434229340	12977	Business	29500.00
0005435006747	12977	Business	29500.00
0005435039135	12977	Business	29500.00
0005435006838	12977	Economy	9800.00
0005435039036	12977	Economy	9800.00
0005435006869	12977	Economy	9800.00
0005435006717	12977	Economy	9800.00
0005435038993	12977	Economy	9800.00
0005435006772	12977	Economy	9800.00
0005435006782	12977	Economy	9800.00
0005435039069	12977	Economy	9800.00
0005435038991	12977	Economy	9800.00
0005435006945	12977	Economy	9800.00
0005435039089	12977	Economy	9800.00
0005434229358	12977	Economy	9800.00
0005435039371	12977	Economy	9800.00
0005435039085	12977	Economy	9800.00
0005435038980	12977	Economy	9800.00
0005435039243	12977	Economy	9800.00
0005434229338	12977	Economy	9800.00
0005435039206	12977	Economy	9800.00
0005434229342	12977	Economy	9800.00
0005435006853	12977	Economy	9800.00
0005435006904	12977	Economy	9800.00
0005435039262	12977	Economy	9800.00
0005434229348	12977	Economy	9800.00
0005435006779	12977	Economy	9800.00
0005435039361	12977	Economy	9800.00
0005435038911	12977	Economy	9800.00
0005435006879	12977	Economy	9800.00
0005435039017	12977	Economy	9800.00
0005435039136	12977	Economy	9800.00
0005432304395	12977	Economy	9800.00
0005435038789	12977	Economy	9800.00
0005435039086	12977	Economy	9800.00
0005435006773	12977	Economy	9800.00
0005432304393	12977	Economy	9800.00
0005435038785	12977	Economy	9800.00
0005435039180	12977	Economy	9800.00
0005435039286	12977	Economy	9800.00
0005435039362	12977	Economy	9800.00
0005434229339	12977	Economy	9800.00
0005435039138	12977	Economy	9800.00
0005435039149	12977	Economy	10800.00
0005435039087	12977	Economy	10800.00
0005435006780	12977	Economy	10800.00
0005434229352	12977	Economy	10800.00
0005435039186	12977	Economy	10800.00
0005434229354	12977	Economy	10800.00
0005435038860	12977	Economy	9800.00
0005435039372	12977	Economy	9800.00
0005435039216	12977	Economy	9800.00
0005435039265	12977	Economy	9800.00
0005435039137	12977	Economy	9800.00
0005435038807	12977	Economy	9800.00
0005435039025	12977	Economy	9800.00
0005435039274	12977	Economy	9800.00
0005435006708	12977	Economy	9800.00
0005435039261	12977	Economy	9800.00
0005435039082	12977	Economy	9800.00
0005435006805	12977	Economy	9800.00
0005435038821	12977	Economy	9800.00
0005435039060	12977	Economy	9800.00
0005435039293	12977	Economy	9800.00
0005435039016	12977	Economy	9800.00
0005435038851	12977	Economy	9800.00
0005435039316	12977	Economy	9800.00
0005435006748	12977	Economy	9800.00
0005435006811	12977	Economy	9800.00
0005435039203	12977	Economy	9800.00
0005435038779	12977	Economy	9800.00
0005435006820	12977	Economy	9800.00
0005434229347	12977	Economy	9800.00
0005435039144	12977	Economy	9800.00
0005434229351	12977	Economy	9800.00
0005435039325	12977	Economy	9800.00
0005435039088	12977	Economy	9800.00
0005435039294	12977	Economy	9800.00
0005434229355	12977	Economy	9800.00
0005435038786	12977	Economy	9800.00
0005435039143	12977	Economy	9800.00
0005434229345	12977	Economy	9800.00
0005435006797	12977	Economy	9800.00
0005435039034	12977	Economy	9800.00
0005435039020	12977	Economy	9800.00
0005435039035	12977	Economy	9800.00
0005432304392	12977	Economy	9800.00
0005434229357	12977	Economy	9800.00
0005435039242	12977	Economy	9800.00
0005434229356	12977	Economy	9800.00
0005435006746	12977	Economy	9800.00
0005435006870	12977	Economy	9800.00
0005435039140	12977	Economy	9800.00
0005435039260	12977	Economy	9800.00
0005435039139	12977	Economy	9800.00
0005435006801	12977	Economy	9800.00
0005435039215	12977	Economy	9800.00
0005435038981	12977	Economy	9800.00
0005435006804	12977	Economy	9800.00
0005434229349	12977	Economy	9800.00
0005435039123	12977	Economy	9800.00
0005435006839	12977	Economy	9800.00
0005435006766	12977	Economy	9800.00
0005432304394	12977	Economy	9800.00
0005435039151	12977	Economy	9800.00
0005435006819	12977	Economy	9800.00
0005435006903	12977	Economy	9800.00
0005434229343	12977	Economy	9800.00
0005435039315	12977	Economy	9800.00
0005434229353	12977	Economy	9800.00
0005434229344	12977	Economy	9800.00
0005434229341	12977	Economy	9800.00
0005435039187	12977	Economy	9800.00
0005435038966	12977	Economy	9800.00
0005435039268	12977	Economy	9800.00
0005435039179	12977	Economy	9800.00
0005434229337	12977	Economy	9800.00
0005434229346	12977	Economy	9800.00
0005434229350	12977	Economy	9800.00
0005435038939	12977	Economy	9800.00
0005435039267	12977	Economy	9800.00
0005434426542	14883	Business	52900.00
0005435554143	14883	Business	52900.00
0005434411771	14883	Business	52900.00
0005434426547	14883	Business	52900.00
0005434426561	14883	Business	52900.00
0005435902474	14883	Business	52900.00
0005435902558	14883	Business	52900.00
0005435554128	14883	Business	52900.00
0005435902564	14883	Business	52900.00
0005435554141	14883	Economy	17600.00
0005435554142	14883	Economy	17600.00
0005434426556	14883	Economy	17600.00
0005435902507	14883	Economy	17600.00
0005435902499	14883	Economy	17600.00
0005435554127	14883	Economy	17600.00
0005435554132	14883	Economy	17600.00
0005434426557	14883	Economy	17600.00
0005435554138	14883	Economy	19400.00
0005434426559	14883	Economy	19400.00
0005434426555	14883	Economy	17600.00
0005434426540	14883	Economy	17600.00
0005435902568	14883	Economy	17600.00
0005434426566	14883	Economy	17600.00
0005435902426	14883	Economy	17600.00
0005434426550	14883	Economy	17600.00
0005435902619	14883	Economy	17600.00
0005434426551	14883	Economy	17600.00
0005434426553	14883	Economy	17600.00
0005434426541	14883	Economy	17600.00
0005434426563	14883	Economy	17600.00
0005434426544	14883	Economy	17600.00
0005435902471	14883	Economy	17600.00
0005434411770	14883	Economy	17600.00
0005434426545	14883	Economy	17600.00
0005432188602	14883	Economy	17600.00
0005434426554	14883	Economy	17600.00
0005434411768	14883	Economy	17600.00
0005435902502	14883	Economy	17600.00
0005434426539	14883	Economy	17600.00
0005434426543	14883	Economy	17600.00
0005434426549	14883	Economy	17600.00
0005434426558	14883	Economy	17600.00
0005434426546	14883	Economy	17600.00
0005435902588	14883	Economy	17600.00
0005434426565	14883	Economy	17600.00
0005434426560	14883	Economy	17600.00
0005432188601	14883	Economy	17600.00
0005434426538	14883	Economy	17600.00
0005435902557	14883	Economy	17600.00
0005434411769	14883	Economy	17600.00
0005434426548	14883	Economy	17600.00
0005435902505	14883	Economy	17600.00
0005434426562	14883	Economy	17600.00
0005434426552	14883	Economy	17600.00
0005432188600	14883	Economy	17600.00
0005435902495	14883	Economy	17600.00
0005434426564	14883	Economy	17600.00
0005435554187	20212	Business	52900.00
0005434426162	20212	Business	52900.00
0005435902693	20212	Business	52900.00
0005435902680	20212	Business	52900.00
0005435902687	20212	Business	52900.00
0005434411731	20212	Business	52900.00
0005434426383	20212	Business	52900.00
0005435902686	20212	Economy	17600.00
0005435554185	20212	Economy	17600.00
0005434426327	20212	Economy	17600.00
0005434426300	20212	Economy	17600.00
0005435902685	20212	Economy	17600.00
0005435902676	20212	Economy	17600.00
0005434426466	20212	Economy	17600.00
0005434426338	20212	Economy	17600.00
0005435902691	20212	Economy	17600.00
0005434426290	20212	Economy	19400.00
0005434426393	20212	Economy	19400.00
0005434411734	20212	Economy	19400.00
0005434426410	20212	Economy	19400.00
0005434426236	20212	Economy	17600.00
0005435902683	20212	Economy	17600.00
0005434426284	20212	Economy	17600.00
0005434426386	20212	Economy	17600.00
0005434426321	20212	Economy	17600.00
0005434426326	20212	Economy	17600.00
0005432059503	20212	Economy	17600.00
0005434426230	20212	Economy	17600.00
0005434426387	20212	Economy	17600.00
0005434426344	20212	Economy	17600.00
0005434426394	20212	Economy	17600.00
0005435554186	20212	Economy	17600.00
0005434426367	20212	Economy	17600.00
0005435554184	20212	Economy	17600.00
0005435902684	20212	Economy	17600.00
0005432059501	20212	Economy	17600.00
0005435902689	20212	Economy	17600.00
0005435902692	20212	Economy	17600.00
0005434426419	20212	Economy	17600.00
0005435902679	20212	Economy	17600.00
0005432059502	20212	Economy	17600.00
0005434411740	20212	Economy	17600.00
0005435902688	20212	Economy	17600.00
0005434426406	20212	Economy	17600.00
0005434426281	20212	Economy	17600.00
0005434426347	20212	Economy	17600.00
0005434426346	20212	Economy	17600.00
0005435902681	20212	Economy	17600.00
0005434426381	20212	Economy	17600.00
0005434426205	20212	Economy	17600.00
0005434411746	20212	Economy	17600.00
0005435554182	20212	Economy	17600.00
0005435902682	20212	Economy	17600.00
0005434426283	20212	Economy	17600.00
0005434426420	20212	Economy	17600.00
0005434426427	20212	Economy	17600.00
0005434426311	20212	Economy	17600.00
0005434426307	20212	Economy	17600.00
0005434426270	20212	Economy	17600.00
0005434426365	20212	Economy	17600.00
0005435902690	20212	Economy	17600.00
0005435554183	20212	Economy	17600.00
0005434426228	20212	Economy	17600.00
0005434411743	20212	Economy	17600.00
0005435902675	20212	Economy	17600.00
0005434426418	20212	Economy	17600.00
0005434426411	20212	Economy	17600.00
0005434426310	20212	Economy	17600.00
0005434426206	20212	Economy	17600.00
0005434426282	20212	Economy	17600.00
0005434426308	20212	Economy	17600.00
0005434411739	20212	Economy	17600.00
0005434426368	20212	Economy	17600.00
0005434426207	20212	Economy	17600.00
0005435902677	20212	Economy	17600.00
0005434426380	20212	Economy	17600.00
0005435902678	20212	Economy	17600.00
0005432462507	28020	Economy	35600.00
0005434523741	28020	Economy	35600.00
0005432462513	28020	Economy	35600.00
0005432462511	28020	Economy	35600.00
0005434523738	28020	Economy	35600.00
0005432462509	28020	Economy	39200.00
0005432462510	28020	Economy	35600.00
0005432462512	28020	Economy	35600.00
0005434523734	28020	Economy	35600.00
0005434523745	28020	Economy	35600.00
0005432462508	28020	Economy	35600.00
0005434523746	28020	Economy	35600.00
0005435982240	26556	Business	18500.00
0005435982202	26556	Business	18500.00
0005433434456	26556	Business	18500.00
0005433434472	26556	Business	18500.00
0005435982201	26556	Business	18500.00
0005435982206	26556	Business	18500.00
0005433434307	26556	Business	18500.00
0005435982238	26556	Business	18500.00
0005435982232	26556	Business	18500.00
0005433434271	26556	Business	18500.00
0005435982199	26556	Business	18500.00
0005432300250	26556	Economy	6200.00
0005433434415	26556	Economy	6200.00
0005433434306	26556	Economy	6200.00
0005433434385	26556	Economy	6200.00
0005433434358	26556	Economy	6200.00
0005435982220	26556	Economy	6200.00
0005433434473	26556	Economy	6200.00
0005434273062	26556	Economy	6800.00
0005435982213	26556	Economy	6800.00
0005433434351	26556	Economy	6800.00
0005432300253	26556	Economy	6800.00
0005433434435	26556	Economy	6800.00
0005433434390	26556	Economy	6200.00
0005435982235	26556	Economy	6200.00
0005435982231	26556	Economy	6200.00
0005433434437	26556	Economy	6200.00
0005435982236	26556	Economy	6200.00
0005435982229	26556	Economy	6200.00
0005433434374	26556	Economy	6200.00
0005435982198	26556	Economy	6200.00
0005435982214	26556	Economy	6200.00
0005432300252	26556	Economy	6200.00
0005433434305	26556	Economy	6200.00
0005435982205	26556	Economy	6200.00
0005433434488	26556	Economy	6200.00
0005433434416	26556	Economy	6200.00
0005435982219	26556	Economy	6200.00
0005435982217	26556	Economy	6200.00
0005433434489	26556	Economy	6200.00
0005432300254	26556	Economy	6200.00
0005435982226	26556	Economy	6200.00
0005433434469	26556	Economy	6200.00
0005435982216	26556	Economy	6200.00
0005435982215	26556	Economy	6200.00
0005435982228	26556	Economy	6200.00
0005435982218	26556	Economy	6200.00
0005435982237	26556	Economy	6200.00
0005435982239	26556	Economy	6200.00
0005433434384	26556	Economy	6200.00
0005433434393	26556	Economy	6200.00
0005435982196	26556	Economy	6200.00
0005435982203	26556	Economy	6200.00
0005432300251	26556	Economy	6200.00
0005433434484	26556	Economy	6200.00
0005435982225	26556	Economy	6200.00
0005435982234	26556	Economy	6200.00
0005435982210	26556	Economy	6200.00
0005435982212	26556	Economy	6200.00
0005435982200	26556	Economy	6200.00
0005435982197	26556	Economy	6200.00
0005433434457	26556	Economy	6200.00
0005435982211	26556	Economy	6200.00
0005435982227	26556	Economy	6200.00
0005435982230	26556	Economy	6200.00
0005435982223	26556	Economy	6200.00
0005435982222	26556	Economy	6200.00
0005435982233	26556	Economy	6200.00
0005433434398	26556	Economy	6200.00
0005435982208	26556	Economy	6200.00
0005435982221	26556	Economy	6200.00
0005435982209	26556	Economy	6200.00
0005435982204	26556	Economy	6200.00
0005433434438	26556	Economy	6200.00
0005435982224	26556	Economy	6200.00
0005435982207	26556	Economy	6200.00
0005433434359	26556	Economy	6200.00
0005435981833	26706	Business	18500.00
0005435981731	26706	Business	18500.00
0005433434658	26706	Business	18500.00
0005433434662	26706	Business	18500.00
0005433434652	26706	Business	18500.00
0005435981687	26706	Business	18500.00
0005435981781	26706	Business	18500.00
0005435981826	26706	Business	18500.00
0005435981679	26706	Business	18500.00
0005433434644	26706	Business	18500.00
0005435981688	26706	Economy	6200.00
0005435981551	26706	Economy	6200.00
0005433434668	26706	Economy	6200.00
0005435981650	26706	Economy	6200.00
0005433434646	26706	Economy	6200.00
0005435981543	26706	Economy	6200.00
0005435981875	26706	Economy	6200.00
0005433434653	26706	Economy	6200.00
0005433434650	26706	Economy	6200.00
0005435981913	26706	Economy	6800.00
0005433434660	26706	Economy	6800.00
0005432051125	26706	Economy	6800.00
0005432051124	26706	Economy	6800.00
0005435981946	26706	Economy	6800.00
0005435981668	26706	Economy	6200.00
0005435981944	26706	Economy	6200.00
0005435981799	26706	Economy	6200.00
0005435981659	26706	Economy	6200.00
0005435981686	26706	Economy	6200.00
0005433434656	26706	Economy	6200.00
0005435981685	26706	Economy	6200.00
0005433434647	26706	Economy	6200.00
0005435981914	26706	Economy	6200.00
0005433434661	26706	Economy	6200.00
0005435981667	26706	Economy	6200.00
0005435981874	26706	Economy	6200.00
0005433434659	26706	Economy	6200.00
0005435981732	26706	Economy	6200.00
0005433434648	26706	Economy	6200.00
0005433434641	26706	Economy	6200.00
0005433434642	26706	Economy	6200.00
0005433434643	26706	Economy	6200.00
0005435981761	26706	Economy	6200.00
0005435981710	26706	Economy	6200.00
0005435981869	26706	Economy	6200.00
0005433434665	26706	Economy	6200.00
0005435981760	26706	Economy	6200.00
0005434270204	26706	Economy	6200.00
0005435981832	26706	Economy	6200.00
0005434269101	26706	Economy	6200.00
0005435981986	26706	Economy	6200.00
0005435981945	26706	Economy	6200.00
0005435981985	26706	Economy	6200.00
0005432051126	26706	Economy	6200.00
0005433434655	26706	Economy	6200.00
0005435981876	26706	Economy	6200.00
0005433434640	26706	Economy	6200.00
0005433434657	26706	Economy	6200.00
0005435981771	26706	Economy	6200.00
0005435981733	26706	Economy	6200.00
0005435981980	26706	Economy	6200.00
0005434271310	26706	Economy	6200.00
0005435981717	26706	Economy	6200.00
0005435981896	26706	Economy	6200.00
0005435981868	26706	Economy	6200.00
0005435981693	26706	Economy	6200.00
0005433434649	26706	Economy	6200.00
0005435981797	26706	Economy	6200.00
0005435981730	26706	Economy	6200.00
0005435981544	26706	Economy	6200.00
0005433434666	26706	Economy	6200.00
0005433434645	26706	Economy	6200.00
0005433434663	26706	Economy	6200.00
0005434271309	26706	Economy	6200.00
0005434269100	26706	Economy	6200.00
0005435981831	26706	Economy	6200.00
0005433434664	26706	Economy	6200.00
0005433434651	26706	Economy	6200.00
0005434270205	26706	Economy	6200.00
0005433434654	26706	Economy	6200.00
0005435981994	26706	Economy	6200.00
0005435981694	26706	Economy	6200.00
0005433434667	26706	Economy	6200.00
0005433686604	29262	Economy	21000.00
0005433686605	29262	Economy	19100.00
0005433689889	29262	Economy	19100.00
0005433689885	29262	Economy	19100.00
0005433689886	29262	Economy	19100.00
0005433686606	29262	Economy	19100.00
0005433686602	29262	Economy	19100.00
0005433686607	29262	Economy	19100.00
0005432584013	3176	Economy	11100.00
0005432857878	3176	Economy	11100.00
0005432857914	3176	Economy	11100.00
0005432857965	3176	Economy	11100.00
0005432584005	3176	Economy	10100.00
0005432857956	3176	Economy	10100.00
0005432584016	3176	Economy	10100.00
0005432584006	3176	Economy	10100.00
0005432857961	3176	Economy	10100.00
0005432857877	3176	Economy	10100.00
0005432216270	3176	Economy	10100.00
0005432584002	3176	Economy	10100.00
0005432583996	3176	Economy	10100.00
0005432584000	3176	Economy	10100.00
0005432584012	3176	Economy	10100.00
0005432583998	3176	Economy	10100.00
0005432857981	3176	Economy	10100.00
0005432216269	3176	Economy	10100.00
0005432584003	3176	Economy	10100.00
0005432857963	3176	Economy	10100.00
0005432584019	3176	Economy	10100.00
0005432584015	3176	Economy	10100.00
0005432584014	3176	Economy	10100.00
0005432583997	3176	Economy	10100.00
0005432584009	3176	Economy	10100.00
0005432584007	3176	Economy	10100.00
0005432584008	3176	Economy	10100.00
0005432584011	3176	Economy	10100.00
0005432216268	3176	Economy	10100.00
0005432584010	3176	Economy	10100.00
0005432857991	3176	Economy	10100.00
0005432584018	3176	Economy	10100.00
0005432857962	3176	Economy	10100.00
0005432857955	3176	Economy	10100.00
0005432857974	3176	Economy	10100.00
0005432583999	3176	Economy	10100.00
0005432584004	3176	Economy	10100.00
0005432584017	3176	Economy	10100.00
0005432857964	3176	Economy	10100.00
0005432583995	3176	Economy	10100.00
0005432584020	3176	Economy	10100.00
0005432584001	3176	Economy	10100.00
0005432583850	31499	Economy	11100.00
0005432583787	31499	Economy	11100.00
0005432858048	31499	Economy	11100.00
0005432583864	31499	Economy	11100.00
0005432858058	31499	Economy	10100.00
0005432583776	31499	Economy	10100.00
0005432583785	31499	Economy	10100.00
0005432583839	31499	Economy	10100.00
0005432583775	31499	Economy	10100.00
0005432583878	31499	Economy	10100.00
0005432583777	31499	Economy	10100.00
0005432583789	31499	Economy	10100.00
0005432583838	31499	Economy	10100.00
0005432858050	31499	Economy	10100.00
0005432583823	31499	Economy	10100.00
0005432858057	31499	Economy	10100.00
0005432583863	31499	Economy	10100.00
0005432583792	31499	Economy	10100.00
0005432583797	31499	Economy	10100.00
0005432583791	31499	Economy	10100.00
0005432583786	31499	Economy	10100.00
0005432583750	31499	Economy	10100.00
0005432858051	31499	Economy	10100.00
0005432583751	31499	Economy	10100.00
0005432583822	31499	Economy	10100.00
0005432583873	31499	Economy	10100.00
0005432858054	31499	Economy	10100.00
0005432858049	31499	Economy	10100.00
0005432583795	31499	Economy	10100.00
0005432583849	31499	Economy	10100.00
0005432858053	31499	Economy	10100.00
0005432858059	31499	Economy	10100.00
0005432858055	31499	Economy	10100.00
0005432858052	31499	Economy	10100.00
0005432858056	31499	Economy	10100.00
0005432583768	31499	Economy	10100.00
0005432583790	31499	Economy	10100.00
0005432583796	31499	Economy	10100.00
0005432858060	31499	Economy	10100.00
0005434943340	878	Economy	8300.00
0005433255057	878	Economy	8300.00
0005433255088	878	Economy	7500.00
0005434943345	878	Economy	7500.00
0005434943344	878	Economy	7500.00
0005434943343	878	Economy	7500.00
0005434943338	878	Economy	7500.00
0005434943342	878	Economy	7500.00
0005434943341	878	Economy	7500.00
0005434943337	878	Economy	7500.00
0005434943339	878	Economy	7500.00
0005434943287	16232	Economy	7500.00
0005434943300	16232	Economy	7500.00
0005434943267	16232	Economy	7500.00
0005433255112	16232	Economy	7500.00
0005433255114	16232	Economy	7500.00
0005434943313	16232	Economy	7500.00
0005434943266	16232	Economy	7500.00
0005434943270	16232	Economy	7500.00
0005434943284	16232	Economy	7500.00
0005434943301	16232	Economy	7500.00
0005433255111	16232	Economy	7500.00
0005434943315	16232	Economy	7500.00
0005433255115	16232	Economy	7500.00
0005434943280	16232	Economy	7500.00
0005434943314	16232	Economy	7500.00
0005434943286	16232	Economy	7500.00
0005433255113	16232	Economy	7500.00
0005433255110	16232	Economy	7500.00
0005434943217	16232	Economy	7500.00
0005434943285	16232	Economy	7500.00
0005434943265	16232	Economy	7500.00
0005435652975	21759	Business	9800.00
0005433367655	21759	Business	9800.00
0005433367453	21759	Business	9800.00
0005433367507	21759	Business	9800.00
0005433367414	21759	Business	9800.00
0005433367531	21759	Business	9800.00
0005433367457	21759	Business	9800.00
0005435652972	21759	Business	9800.00
0005435652968	21759	Business	9800.00
0005435652965	21759	Business	9800.00
0005435652960	21759	Business	9800.00
0005433367575	21759	Business	9800.00
0005435652970	21759	Economy	3300.00
0005435652982	21759	Economy	3300.00
0005433367512	21759	Economy	3300.00
0005435652963	21759	Economy	3300.00
0005433367530	21759	Economy	3300.00
0005433367425	21759	Economy	3300.00
0005435652969	21759	Economy	3300.00
0005433367527	21759	Economy	3300.00
0005435652979	21759	Economy	3300.00
0005433367525	21759	Economy	3300.00
0005435652983	21759	Economy	3600.00
0005433367437	21759	Economy	3600.00
0005433367380	21759	Economy	3600.00
0005435652976	21759	Economy	3600.00
0005435652988	21759	Economy	3600.00
0005433367275	21759	Economy	3300.00
0005433367374	21759	Economy	3300.00
0005433367523	21759	Economy	3300.00
0005435652974	21759	Economy	3300.00
0005433367394	21759	Economy	3300.00
0005435652964	21759	Economy	3300.00
0005435652973	21759	Economy	3300.00
0005433367441	21759	Economy	3300.00
0005435652985	21759	Economy	3300.00
0005435652961	21759	Economy	3300.00
0005433367470	21759	Economy	3300.00
0005433367541	21759	Economy	3300.00
0005433367461	21759	Economy	3300.00
0005433367421	21759	Economy	3300.00
0005433367413	21759	Economy	3300.00
0005433367454	21759	Economy	3300.00
0005433367485	21759	Economy	3300.00
0005433367436	21759	Economy	3300.00
0005435652987	21759	Economy	3300.00
0005433367584	21759	Economy	3300.00
0005435652978	21759	Economy	3300.00
0005433367570	21759	Economy	3300.00
0005435652957	21759	Economy	3300.00
0005433367464	21759	Economy	3300.00
0005433367443	21759	Economy	3300.00
0005433367404	21759	Economy	3300.00
0005435652971	21759	Economy	3300.00
0005435652981	21759	Economy	3300.00
0005433367462	21759	Economy	3300.00
0005435652977	21759	Economy	3300.00
0005433367373	21759	Economy	3300.00
0005435652956	21759	Economy	3300.00
0005433367653	21759	Economy	3300.00
0005433367510	21759	Economy	3300.00
0005433367519	21759	Economy	3300.00
0005433367308	21759	Economy	3300.00
0005433367307	21759	Economy	3300.00
0005435652955	21759	Economy	3300.00
0005435652980	21759	Economy	3300.00
0005435652984	21759	Economy	3300.00
0005435652958	21759	Economy	3300.00
0005433367636	21759	Economy	3300.00
0005435652967	21759	Economy	3300.00
0005433367484	21759	Economy	3300.00
0005433367616	21759	Economy	3300.00
0005435652962	21759	Economy	3300.00
0005435652990	21759	Economy	3300.00
0005435652986	21759	Economy	3300.00
0005433367415	21759	Economy	3300.00
0005433367342	21759	Economy	3300.00
0005433367590	21759	Economy	3300.00
0005435652989	21759	Economy	3300.00
0005433367511	21759	Economy	3300.00
0005433367442	21759	Economy	3300.00
0005433367463	21759	Economy	3300.00
0005433367460	21759	Economy	3300.00
0005433367445	21759	Economy	3300.00
0005433367426	21759	Economy	3300.00
0005435652959	21759	Economy	3300.00
0005435652991	21759	Economy	3300.00
0005435652966	21759	Economy	3300.00
0005433367654	21759	Economy	3300.00
0005433805353	9341	Business	186200.00
0005433805336	9341	Business	186200.00
0005433805340	9341	Business	186200.00
0005433784892	9341	Business	186200.00
0005433784917	9341	Business	186200.00
0005433784913	9341	Business	186200.00
0005433763198	9341	Business	186200.00
0005433784897	9341	Business	186200.00
0005433784894	9341	Business	186200.00
0005433805350	9341	Business	186200.00
0005434170896	9341	Business	186200.00
0005433763195	9341	Business	186200.00
0005433784891	9341	Business	186200.00
0005433763197	9341	Business	186200.00
0005433784904	9341	Business	186200.00
0005434170918	9341	Business	186200.00
0005433805341	9341	Economy	68300.00
0005433784896	9341	Economy	68300.00
0005432657445	9341	Economy	62100.00
0005433784916	9341	Economy	62100.00
0005433805348	9341	Economy	62100.00
0005433784902	9341	Economy	62100.00
0005433784893	9341	Economy	62100.00
0005434170926	9341	Economy	62100.00
0005433805342	9341	Economy	62100.00
0005433784905	9341	Economy	62100.00
0005433784923	9341	Economy	62100.00
0005433805346	9341	Economy	62100.00
0005433805343	9341	Economy	62100.00
0005433784910	9341	Economy	62100.00
0005432665272	9341	Economy	62100.00
0005432666387	9341	Economy	62100.00
0005433805339	9341	Economy	62100.00
0005433784915	9341	Economy	62100.00
0005433784900	9341	Economy	62100.00
0005433805355	9341	Economy	62100.00
0005433763196	9341	Economy	62100.00
0005433805331	9341	Economy	62100.00
0005434151677	9341	Economy	62100.00
0005435269659	9341	Economy	62100.00
0005433763192	9341	Economy	62100.00
0005433805335	9341	Economy	62100.00
0005434170936	9341	Economy	62100.00
0005433784888	9341	Economy	62100.00
0005432666386	9341	Economy	62100.00
0005433784890	9341	Economy	62100.00
0005432657446	9341	Economy	62100.00
0005433805344	9341	Economy	62100.00
0005433784901	9341	Economy	62100.00
0005434270188	9341	Economy	62100.00
0005435269660	9341	Economy	62100.00
0005433784920	9341	Economy	62100.00
0005434151681	9341	Economy	62100.00
0005433763185	9341	Economy	62100.00
0005433784914	9341	Economy	62100.00
0005433805330	9341	Economy	62100.00
0005433784921	9341	Economy	62100.00
0005433784911	9341	Economy	62100.00
0005433784906	9341	Economy	62100.00
0005433784909	9341	Economy	62100.00
0005433784903	9341	Economy	62100.00
0005434170897	9341	Economy	62100.00
0005433784918	9341	Economy	62100.00
0005435269665	9341	Economy	62100.00
0005433805356	9341	Economy	62100.00
0005433763188	9341	Economy	62100.00
0005433805349	9341	Economy	62100.00
0005435269650	9341	Economy	62100.00
0005433784889	9341	Economy	62100.00
0005435269651	9341	Economy	62100.00
0005432667451	9341	Economy	62100.00
0005433763194	9341	Economy	68300.00
0005433805328	9341	Economy	68300.00
0005433784895	9341	Economy	62100.00
0005433805334	9341	Economy	62100.00
0005433784908	9341	Economy	62100.00
0005434170888	9341	Economy	62100.00
0005433784919	9341	Economy	62100.00
0005433763189	9341	Economy	62100.00
0005433805352	9341	Economy	62100.00
0005434170921	9341	Economy	62100.00
0005433763186	9341	Economy	62100.00
0005433763182	9341	Economy	62100.00
0005433805345	9341	Economy	62100.00
0005435269666	9341	Economy	62100.00
0005433763191	9341	Economy	62100.00
0005432666385	9341	Economy	62100.00
0005433763183	9341	Economy	62100.00
0005434270187	9341	Economy	62100.00
0005433763193	9341	Economy	62100.00
0005433805337	9341	Economy	62100.00
0005433805347	9341	Economy	62100.00
0005434170949	9341	Economy	62100.00
0005434170866	9341	Economy	62100.00
0005433805329	9341	Economy	62100.00
0005433805332	9341	Economy	62100.00
0005434151680	9341	Economy	62100.00
0005432667452	9341	Economy	62100.00
0005434170937	9341	Economy	62100.00
0005433784912	9341	Economy	62100.00
0005433805351	9341	Economy	62100.00
0005433763190	9341	Economy	62100.00
0005433784922	9341	Economy	62100.00
0005434151682	9341	Economy	62100.00
0005433784907	9341	Economy	62100.00
0005433763187	9341	Economy	62100.00
0005435269671	9341	Economy	62100.00
0005433763184	9341	Economy	62100.00
0005433784887	9341	Economy	62100.00
0005433805338	9341	Economy	62100.00
0005433784898	9341	Economy	62100.00
0005433784899	9341	Economy	62100.00
0005433805354	9341	Economy	62100.00
0005434170947	9341	Economy	62100.00
0005434170865	9341	Economy	62100.00
0005434151676	9341	Economy	62100.00
0005433805333	9341	Economy	62100.00
0005432657413	26226	Business	186200.00
0005433763028	26226	Business	186200.00
0005433784691	26226	Business	186200.00
0005433784700	26226	Business	186200.00
0005433763089	26226	Business	186200.00
0005433805118	26226	Business	186200.00
0005433805114	26226	Business	186200.00
0005433784707	26226	Business	186200.00
0005433805005	26226	Business	186200.00
0005433763067	26226	Business	186200.00
0005433784735	26226	Business	186200.00
0005433805066	26226	Business	186200.00
0005433784609	26226	Business	186200.00
0005433805078	26226	Business	186200.00
0005433763064	26226	Business	186200.00
0005433763130	26226	Business	186200.00
0005434271307	26226	Business	186200.00
0005434171044	26226	Business	186200.00
0005432659687	26226	Business	186200.00
0005433805021	26226	Business	186200.00
0005434171035	26226	Business	186200.00
0005433805052	26226	Economy	68300.00
0005433804960	26226	Economy	68300.00
0005433784530	26226	Economy	62100.00
0005433805137	26226	Economy	62100.00
0005433804980	26226	Economy	62100.00
0005433784591	26226	Economy	62100.00
0005433784579	26226	Economy	62100.00
0005433784658	26226	Economy	62100.00
0005433763071	26226	Economy	62100.00
0005434171033	26226	Economy	62100.00
0005433805055	26226	Economy	62100.00
0005432666365	26226	Economy	62100.00
0005433805049	26226	Economy	62100.00
0005433805048	26226	Economy	62100.00
0005434171037	26226	Economy	62100.00
0005433784553	26226	Economy	62100.00
0005432657409	26226	Economy	62100.00
0005433805020	26226	Economy	62100.00
0005433763027	26226	Economy	62100.00
0005432657411	26226	Economy	62100.00
0005433805068	26226	Economy	62100.00
0005434171043	26226	Economy	62100.00
0005432659686	26226	Economy	62100.00
0005433763068	26226	Economy	62100.00
0005433805053	26226	Economy	62100.00
0005433763069	26226	Economy	62100.00
0005433805010	26226	Economy	62100.00
0005434151701	26226	Economy	62100.00
0005433784582	26226	Economy	62100.00
0005433763048	26226	Economy	62100.00
0005433804919	26226	Economy	62100.00
0005434171036	26226	Economy	62100.00
0005432657407	26226	Economy	62100.00
0005432657419	26226	Economy	62100.00
0005433804981	26226	Economy	62100.00
0005433784736	26226	Economy	62100.00
0005433784637	26226	Economy	62100.00
0005433784626	26226	Economy	62100.00
0005434269099	26226	Economy	62100.00
0005433784562	26226	Economy	62100.00
0005432657412	26226	Economy	62100.00
0005433805116	26226	Economy	62100.00
0005433805067	26226	Economy	62100.00
0005433763047	26226	Economy	62100.00
0005433784613	26226	Economy	62100.00
0005433784731	26226	Economy	62100.00
0005433805036	26226	Economy	62100.00
0005433805035	26226	Economy	62100.00
0005433784563	26226	Economy	62100.00
0005433784488	26226	Economy	62100.00
0005433784600	26226	Economy	62100.00
0005433805009	26226	Economy	62100.00
0005433804958	26226	Economy	62100.00
0005433784497	26226	Economy	62100.00
0005433784508	26226	Economy	62100.00
0005433763049	26226	Economy	62100.00
0005433805004	26226	Economy	62100.00
0005433805065	26226	Economy	62100.00
0005433805104	26226	Economy	62100.00
0005433762977	26226	Economy	62100.00
0005432663019	26226	Economy	62100.00
0005432657414	26226	Economy	62100.00
0005433805117	26226	Economy	68300.00
0005433784594	26226	Economy	62100.00
0005433805131	26226	Economy	68300.00
0005433784485	26226	Economy	62100.00
0005433784642	26226	Economy	62100.00
0005433763080	26226	Economy	62100.00
0005433784706	26226	Economy	62100.00
0005433784456	26226	Economy	62100.00
0005434270203	26226	Economy	62100.00
0005433784607	26226	Economy	62100.00
0005434171041	26226	Economy	62100.00
0005434171034	26226	Economy	62100.00
0005433784595	26226	Economy	62100.00
0005432657420	26226	Economy	62100.00
0005434171040	26226	Economy	62100.00
0005433763070	26226	Economy	62100.00
0005433784608	26226	Economy	62100.00
0005434271308	26226	Economy	62100.00
0005433784690	26226	Economy	62100.00
0005433784507	26226	Economy	62100.00
0005433784739	26226	Economy	62100.00
0005433805056	26226	Economy	62100.00
0005433784506	26226	Economy	62100.00
0005434151700	26226	Economy	62100.00
0005433784577	26226	Economy	62100.00
0005433784584	26226	Economy	62100.00
0005433763088	26226	Economy	62100.00
0005433784671	26226	Economy	62100.00
0005433804959	26226	Economy	62100.00
0005433763079	26226	Economy	62100.00
0005433784734	26226	Economy	62100.00
0005433784531	26226	Economy	62100.00
0005433804961	26226	Economy	62100.00
0005433784657	26226	Economy	62100.00
0005433784643	26226	Economy	62100.00
0005432659684	26226	Economy	62100.00
0005434171032	26226	Economy	62100.00
0005433784659	26226	Economy	62100.00
0005434171045	26226	Economy	62100.00
0005434151699	26226	Economy	62100.00
0005433763078	26226	Economy	62100.00
0005434171038	26226	Economy	62100.00
0005433784580	26226	Economy	62100.00
0005433763095	26226	Economy	62100.00
0005434171039	26226	Economy	62100.00
0005432659688	26226	Economy	62100.00
0005433784606	26226	Economy	62100.00
0005434171042	26226	Economy	62100.00
0005433784692	26226	Economy	62100.00
0005433784664	26226	Economy	62100.00
0005435135664	4887	Economy	5900.00
0005435135663	4887	Economy	5300.00
0005435135662	4887	Economy	5300.00
0005435135666	4887	Economy	5300.00
0005435135665	4887	Economy	5300.00
0005435929611	4887	Economy	5300.00
0005435929641	33031	Economy	5900.00
0005435929639	33031	Economy	5900.00
0005435135619	33031	Economy	5300.00
0005435929640	33031	Economy	5300.00
0005434983279	9490	Economy	17900.00
0005434983280	9490	Economy	17900.00
0005434983281	9490	Economy	17900.00
0005434983283	9490	Economy	17900.00
0005434983282	9490	Economy	17900.00
0005434217927	9490	Economy	17900.00
0005434983260	27392	Economy	19700.00
0005434983221	27392	Economy	17900.00
0005434217963	27392	Economy	17900.00
0005434983222	27392	Economy	17900.00
0005434983242	27392	Economy	17900.00
0005434217964	27392	Economy	17900.00
0005434983243	27392	Economy	17900.00
0005434217962	27392	Economy	17900.00
0005434983256	27392	Economy	17900.00
0005434983247	27392	Economy	17900.00
0005434983234	27392	Economy	17900.00
0005434983240	27392	Economy	17900.00
0005434983241	27392	Economy	17900.00
0005434217965	27392	Economy	17900.00
0005434983233	27392	Economy	17900.00
0005433985500	24251	Business	36400.00
0005433985553	24251	Business	36400.00
0005433985420	24251	Business	36400.00
0005433960147	24251	Business	36400.00
0005433960255	24251	Business	36400.00
0005433985441	24251	Business	36400.00
0005433959908	24251	Business	36400.00
0005433985171	24251	Business	36400.00
0005433959909	24251	Business	36400.00
0005433960216	24251	Business	36400.00
0005433960215	24251	Business	36400.00
0005433960264	24251	Business	36400.00
0005433985583	24251	Business	36400.00
0005433985499	24251	Business	36400.00
0005433960263	24251	Business	36400.00
0005433985552	24251	Business	36400.00
0005433985375	24251	Business	36400.00
0005433985440	24251	Economy	13400.00
0005433985465	24251	Economy	13400.00
0005433960143	24251	Economy	13400.00
0005433960186	24251	Economy	12100.00
0005433985377	24251	Economy	12100.00
0005433985436	24251	Economy	12100.00
0005433985325	24251	Economy	12100.00
0005433985461	24251	Economy	12100.00
0005433960306	24251	Economy	12100.00
0005433960158	24251	Economy	12100.00
0005433985446	24251	Economy	12100.00
0005433960093	24251	Economy	12100.00
0005433960302	24251	Economy	12100.00
0005433960188	24251	Economy	12100.00
0005433960241	24251	Economy	12100.00
0005433985490	24251	Economy	12100.00
0005433960092	24251	Economy	12100.00
0005433985586	24251	Economy	12100.00
0005433960138	24251	Economy	12100.00
0005433985482	24251	Economy	12100.00
0005433985412	24251	Economy	12100.00
0005433960321	24251	Economy	12100.00
0005433960285	24251	Economy	12100.00
0005433960170	24251	Economy	12100.00
0005433960248	24251	Economy	12100.00
0005433960244	24251	Economy	12100.00
0005433985445	24251	Economy	12100.00
0005433960142	24251	Economy	12100.00
0005433960261	24251	Economy	12100.00
0005433960284	24251	Economy	12100.00
0005433960275	24251	Economy	12100.00
0005433960256	24251	Economy	12100.00
0005433960159	24251	Economy	12100.00
0005433960272	24251	Economy	12100.00
0005433960298	24251	Economy	12100.00
0005433960167	24251	Economy	12100.00
0005433960262	24251	Economy	12100.00
0005433985463	24251	Economy	12100.00
0005433985592	24251	Economy	12100.00
0005433960214	24251	Economy	12100.00
0005433960247	24251	Economy	12100.00
0005433960277	24251	Economy	12100.00
0005433985421	24251	Economy	12100.00
0005433960265	24251	Economy	12100.00
0005433985589	24251	Economy	12100.00
0005433960230	24251	Economy	12100.00
0005433985480	24251	Economy	12100.00
0005433960129	24251	Economy	12100.00
0005433960045	24251	Economy	12100.00
0005433960160	24251	Economy	12100.00
0005433959999	24251	Economy	12100.00
0005433985383	24251	Economy	13400.00
0005433985572	24251	Economy	12100.00
0005433985576	24251	Economy	12100.00
0005433960307	24251	Economy	12100.00
0005433960334	24251	Economy	12100.00
0005433960280	24251	Economy	12100.00
0005433960249	24251	Economy	12100.00
0005433960232	24251	Economy	12100.00
0005433960046	24251	Economy	12100.00
0005433985464	24251	Economy	12100.00
0005433960301	24251	Economy	12100.00
0005433985430	24251	Economy	12100.00
0005433960084	24251	Economy	12100.00
0005433985483	24251	Economy	12100.00
0005433985324	24251	Economy	12100.00
0005433960297	24251	Economy	12100.00
0005433960166	24251	Economy	12100.00
0005433960149	24251	Economy	12100.00
0005433985442	24251	Economy	12100.00
0005433985568	24251	Economy	12100.00
0005433960242	24251	Economy	12100.00
0005433985587	24251	Economy	12100.00
0005433960187	24251	Economy	12100.00
0005433960290	24251	Economy	12100.00
0005433985517	24251	Economy	12100.00
0005433960058	24251	Economy	12100.00
0005433960305	24251	Economy	12100.00
0005433960146	24251	Economy	12100.00
0005433960231	24251	Economy	12100.00
0005433960316	24251	Economy	12100.00
0005433960245	24251	Economy	12100.00
0005433960020	24251	Economy	12100.00
0005433985214	24251	Economy	12100.00
0005433985262	24251	Economy	12100.00
0005433985462	24251	Economy	12100.00
0005433960250	24251	Economy	12100.00
0005433985351	24251	Economy	12100.00
0005433985454	24251	Economy	12100.00
0005433960130	24251	Economy	12100.00
0005433985481	24251	Economy	12100.00
0005433960335	24251	Economy	12100.00
0005433960019	24251	Economy	12100.00
0005433985269	24251	Economy	12100.00
0005433985453	24251	Economy	12100.00
0005433960320	24251	Economy	12100.00
0005433960776	25933	Business	36400.00
0005433985857	25933	Business	36400.00
0005433985867	25933	Business	36400.00
0005433960739	25933	Business	36400.00
0005433960754	25933	Business	36400.00
0005433960740	25933	Business	36400.00
0005433960745	25933	Business	36400.00
0005433985853	25933	Business	36400.00
0005433985846	25933	Business	36400.00
0005433985856	25933	Business	36400.00
0005433960774	25933	Business	36400.00
0005433960749	25933	Economy	13400.00
0005433985866	25933	Economy	13400.00
0005433985868	25933	Economy	13400.00
0005433985873	25933	Economy	12100.00
0005433960778	25933	Economy	12100.00
0005433960752	25933	Economy	12100.00
0005433960750	25933	Economy	12100.00
0005433960763	25933	Economy	12100.00
0005433960791	25933	Economy	12100.00
0005433960742	25933	Economy	12100.00
0005433960744	25933	Economy	12100.00
0005433960771	25933	Economy	12100.00
0005433960746	25933	Economy	12100.00
0005433960772	25933	Economy	12100.00
0005433985855	25933	Economy	12100.00
0005433960786	25933	Economy	12100.00
0005433985847	25933	Economy	12100.00
0005433985849	25933	Economy	12100.00
0005433985863	25933	Economy	12100.00
0005433985864	25933	Economy	12100.00
0005433985876	25933	Economy	12100.00
0005433960792	25933	Economy	12100.00
0005433960758	25933	Economy	12100.00
0005433960751	25933	Economy	12100.00
0005433985874	25933	Economy	12100.00
0005433960755	25933	Economy	12100.00
0005433985871	25933	Economy	12100.00
0005433960741	25933	Economy	12100.00
0005433960759	25933	Economy	12100.00
0005433985843	25933	Economy	12100.00
0005433985850	25933	Economy	12100.00
0005433960766	25933	Economy	12100.00
0005433985861	25933	Economy	12100.00
0005433960790	25933	Economy	12100.00
0005433960773	25933	Economy	12100.00
0005433985845	25933	Economy	12100.00
0005433960767	25933	Economy	12100.00
0005433960762	25933	Economy	12100.00
0005433960768	25933	Economy	12100.00
0005433985841	25933	Economy	12100.00
0005433960780	25933	Economy	12100.00
0005433960765	25933	Economy	13400.00
0005433960787	25933	Economy	13400.00
0005433960747	25933	Economy	13400.00
0005433985851	25933	Economy	12100.00
0005433985872	25933	Economy	12100.00
0005433960761	25933	Economy	12100.00
0005433985860	25933	Economy	12100.00
0005433985862	25933	Economy	12100.00
0005433985875	25933	Economy	12100.00
0005433960779	25933	Economy	12100.00
0005433985858	25933	Economy	12100.00
0005433960769	25933	Economy	12100.00
0005433985869	25933	Economy	12100.00
0005433985844	25933	Economy	12100.00
0005433985870	25933	Economy	12100.00
0005433960775	25933	Economy	12100.00
0005433960788	25933	Economy	12100.00
0005433960783	25933	Economy	12100.00
0005433960756	25933	Economy	12100.00
0005433960770	25933	Economy	12100.00
0005433960784	25933	Economy	12100.00
0005433960748	25933	Economy	12100.00
0005433985852	25933	Economy	12100.00
0005433985842	25933	Economy	12100.00
0005433960760	25933	Economy	12100.00
0005433985877	25933	Economy	12100.00
0005433960753	25933	Economy	12100.00
0005433985865	25933	Economy	12100.00
0005433985859	25933	Economy	12100.00
0005433960789	25933	Economy	12100.00
0005433985854	25933	Economy	12100.00
0005433985840	25933	Economy	12100.00
0005433985848	25933	Economy	12100.00
0005433960764	25933	Economy	12100.00
0005433960743	25933	Economy	12100.00
0005433960782	25933	Economy	12100.00
0005433960785	25933	Economy	12100.00
0005433960777	25933	Economy	12100.00
0005433960757	25933	Economy	12100.00
0005433960781	25933	Economy	12100.00
0005433165764	932	Economy	25400.00
0005433165821	932	Economy	25400.00
0005433165742	932	Economy	25400.00
0005434480289	932	Economy	25400.00
0005434480306	932	Economy	23100.00
0005434480305	932	Economy	23100.00
0005434480296	932	Economy	23100.00
0005433165782	932	Economy	23100.00
0005434480300	932	Economy	23100.00
0005434480315	932	Economy	23100.00
0005433165765	932	Economy	23100.00
0005434480294	932	Economy	23100.00
0005433165841	932	Economy	23100.00
0005434480312	932	Economy	23100.00
0005434480307	932	Economy	23100.00
0005434480290	932	Economy	23100.00
0005433165839	932	Economy	23100.00
0005434480297	932	Economy	23100.00
0005434480310	932	Economy	23100.00
0005433165725	932	Economy	23100.00
0005433165783	932	Economy	23100.00
0005434480302	932	Economy	23100.00
0005434480293	932	Economy	23100.00
0005434480298	932	Economy	23100.00
0005434480304	932	Economy	23100.00
0005434480291	932	Economy	23100.00
0005434480314	932	Economy	23100.00
0005434480309	932	Economy	23100.00
0005433165766	932	Economy	23100.00
0005434480311	932	Economy	23100.00
0005433165840	932	Economy	23100.00
0005434480292	932	Economy	23100.00
0005434480301	932	Economy	23100.00
0005433165724	932	Economy	23100.00
0005433165786	932	Economy	23100.00
0005434480299	932	Economy	23100.00
0005434480303	932	Economy	23100.00
0005434480313	932	Economy	23100.00
0005434480308	932	Economy	23100.00
0005432269492	932	Economy	23100.00
0005433165767	932	Economy	23100.00
0005432269491	932	Economy	23100.00
0005432269493	932	Economy	23100.00
0005434480295	932	Economy	23100.00
0005433165730	932	Economy	23100.00
0005433165791	932	Economy	23100.00
0005433165792	932	Economy	23100.00
0005433165787	932	Economy	23100.00
0005433165763	932	Economy	23100.00
0005432269494	932	Economy	23100.00
0005433165889	16597	Economy	25400.00
0005434480077	16597	Economy	25400.00
0005434480067	16597	Economy	25400.00
0005434480179	16597	Economy	25400.00
0005434480206	16597	Economy	23100.00
0005433165884	16597	Economy	23100.00
0005434480152	16597	Economy	23100.00
0005434480071	16597	Economy	23100.00
0005434480148	16597	Economy	23100.00
0005433165886	16597	Economy	23100.00
0005434480064	16597	Economy	23100.00
0005434480113	16597	Economy	23100.00
0005434480007	16597	Economy	23100.00
0005434480090	16597	Economy	23100.00
0005434480008	16597	Economy	23100.00
0005434480183	16597	Economy	23100.00
0005433165887	16597	Economy	23100.00
0005434480151	16597	Economy	23100.00
0005434480097	16597	Economy	23100.00
0005434480032	16597	Economy	23100.00
0005434480066	16597	Economy	23100.00
0005434480167	16597	Economy	23100.00
0005434480006	16597	Economy	23100.00
0005434479934	16597	Economy	23100.00
0005434480091	16597	Economy	23100.00
0005434480048	16597	Economy	23100.00
0005434480120	16597	Economy	23100.00
0005434480031	16597	Economy	23100.00
0005434480033	16597	Economy	23100.00
0005434480137	16597	Economy	23100.00
0005434480136	16597	Economy	23100.00
0005433165893	16597	Economy	23100.00
0005433165892	16597	Economy	23100.00
0005434480135	16597	Economy	23100.00
0005434480078	16597	Economy	23100.00
0005434480072	16597	Economy	23100.00
0005434480168	16597	Economy	23100.00
0005434480047	16597	Economy	23100.00
0005433165890	16597	Economy	23100.00
0005433165888	16597	Economy	23100.00
0005434480106	16597	Economy	23100.00
0005434480058	16597	Economy	23100.00
0005433165894	16597	Economy	23100.00
0005434480123	16597	Economy	23100.00
0005434480147	16597	Economy	23100.00
0005433165885	16597	Economy	23100.00
0005433165895	16597	Economy	23100.00
0005434480105	16597	Economy	23100.00
0005433165891	16597	Economy	23100.00
0005433872481	3215	Economy	19000.00
0005433872482	3215	Economy	17200.00
0005433872479	3215	Economy	17200.00
0005433872480	3215	Economy	17200.00
0005433872483	3215	Economy	17200.00
0005433872478	3215	Economy	17200.00
0005433872452	32562	Economy	17200.00
0005433872450	32562	Economy	17200.00
0005433872451	32562	Economy	17200.00
0005433872453	32562	Economy	17200.00
0005433872444	32562	Economy	17200.00
0005435149995	10324	Economy	17000.00
0005435142550	10324	Economy	17000.00
0005433289751	10324	Economy	17000.00
0005435142549	10324	Economy	15400.00
0005435150002	10324	Economy	15400.00
0005433289764	10324	Economy	15400.00
0005435149999	10324	Economy	15400.00
0005435386538	10324	Economy	15400.00
0005433289788	10324	Economy	15400.00
0005435150006	10324	Economy	15400.00
0005435142544	10324	Economy	15400.00
0005435150001	10324	Economy	15400.00
0005435142554	10324	Economy	15400.00
0005435386537	10324	Economy	15400.00
0005433289795	10324	Economy	15400.00
0005435142543	10324	Economy	15400.00
0005435149994	10324	Economy	15400.00
0005435142546	10324	Economy	15400.00
0005435142553	10324	Economy	15400.00
0005435142547	10324	Economy	15400.00
0005435142548	10324	Economy	15400.00
0005435142551	10324	Economy	15400.00
0005435149997	10324	Economy	15400.00
0005435150007	10324	Economy	15400.00
0005433289749	10324	Economy	15400.00
0005435386502	10324	Economy	15400.00
0005435150005	10324	Economy	15400.00
0005435142545	10324	Economy	15400.00
0005435142556	10324	Economy	15400.00
0005435386473	10324	Economy	15400.00
0005433289787	10324	Economy	15400.00
0005435150003	10324	Economy	15400.00
0005435150004	10324	Economy	15400.00
0005433289778	10324	Economy	15400.00
0005435150000	10324	Economy	15400.00
0005435386503	10324	Economy	15400.00
0005433289765	10324	Economy	15400.00
0005435142555	10324	Economy	15400.00
0005435149996	10324	Economy	15400.00
0005435142552	10324	Economy	15400.00
0005435149998	10324	Economy	15400.00
0005433289796	10324	Economy	15400.00
0005433289844	21959	Economy	17000.00
0005435386570	21959	Economy	17000.00
0005435149931	21959	Economy	17000.00
0005433289848	21959	Economy	15400.00
0005435386565	21959	Economy	15400.00
0005435386569	21959	Economy	15400.00
0005435149827	21959	Economy	15400.00
0005435142431	21959	Economy	15400.00
0005435142368	21959	Economy	15400.00
0005435142400	21959	Economy	15400.00
0005435149844	21959	Economy	15400.00
0005435149914	21959	Economy	15400.00
0005435142492	21959	Economy	15400.00
0005435149927	21959	Economy	15400.00
0005433289847	21959	Economy	15400.00
0005435386566	21959	Economy	15400.00
0005435149916	21959	Economy	15400.00
0005435142367	21959	Economy	15400.00
0005433289845	21959	Economy	15400.00
0005435142399	21959	Economy	15400.00
0005433289846	21959	Economy	15400.00
0005435386568	21959	Economy	15400.00
0005435386567	21959	Economy	15400.00
0005435149911	21959	Economy	15400.00
0005435142450	21959	Economy	15400.00
0005435142449	21959	Economy	15400.00
0005435149933	21959	Economy	15400.00
0005435386571	21959	Economy	15400.00
0005433289849	21959	Economy	15400.00
0005435529041	11206	Business	57200.00
0005435529113	11206	Business	57200.00
0005435545614	11206	Business	57200.00
0005435528985	11206	Business	57200.00
0005435502080	11206	Business	57200.00
0005435529023	11206	Business	57200.00
0005435319504	11206	Business	57200.00
0005435545640	11206	Business	57200.00
0005435529038	11206	Business	57200.00
0005435502105	11206	Business	57200.00
0005435529065	11206	Economy	19100.00
0005435545651	11206	Economy	19100.00
0005434573323	11206	Economy	19100.00
0005435529085	11206	Economy	19100.00
0005435502072	11206	Economy	19100.00
0005435502081	11206	Economy	19100.00
0005435319468	11206	Economy	19100.00
0005435502131	11206	Economy	21000.00
0005435545643	11206	Economy	21000.00
0005435502149	11206	Economy	21000.00
0005434573319	11206	Economy	21000.00
0005435319481	11206	Economy	19100.00
0005435529022	11206	Economy	19100.00
0005435502033	11206	Economy	19100.00
0005435502169	11206	Economy	19100.00
0005435529086	11206	Economy	19100.00
0005435502071	11206	Economy	19100.00
0005435529028	11206	Economy	19100.00
0005435502094	11206	Economy	19100.00
0005435529001	11206	Economy	19100.00
0005434573328	11206	Economy	19100.00
0005435502171	11206	Economy	19100.00
0005435529084	11206	Economy	19100.00
0005435502114	11206	Economy	19100.00
0005435502070	11206	Economy	19100.00
0005434573329	11206	Economy	19100.00
0005435545662	11206	Economy	19100.00
0005435502170	11206	Economy	19100.00
0005435545615	11206	Economy	19100.00
0005435545660	11206	Economy	19100.00
0005434573318	11206	Economy	19100.00
0005435545661	11206	Economy	19100.00
0005435529057	11206	Economy	19100.00
0005435528983	11206	Economy	19100.00
0005435529112	11206	Economy	19100.00
0005435319488	11206	Economy	19100.00
0005435529062	11206	Economy	19100.00
0005435319487	11206	Economy	19100.00
0005435528986	11206	Economy	19100.00
0005434573326	11206	Economy	19100.00
0005435319478	11206	Economy	19100.00
0005435502161	11206	Economy	19100.00
0005434573327	11206	Economy	19100.00
0005435545669	11206	Economy	19100.00
0005435529083	11206	Economy	19100.00
0005435529064	11206	Economy	19100.00
0005435502046	11206	Economy	19100.00
0005434573325	11206	Economy	19100.00
0005435529000	11206	Economy	19100.00
0005434573324	11206	Economy	19100.00
0005435529019	11206	Economy	19100.00
0005435528947	11206	Economy	19100.00
0005434573331	11206	Economy	19100.00
0005434573320	11206	Economy	19100.00
0005435319505	11206	Economy	19100.00
0005435319474	11206	Economy	19100.00
0005435319512	11206	Economy	19100.00
0005435502167	11206	Economy	19100.00
0005435529040	11206	Economy	19100.00
0005434573321	11206	Economy	19100.00
0005435528984	11206	Economy	19100.00
0005435319511	11206	Economy	19100.00
0005434573322	11206	Economy	19100.00
0005435502130	11206	Economy	19100.00
0005434573330	11206	Economy	19100.00
0005435319506	11206	Economy	19100.00
0005435319575	20906	Business	57200.00
0005435502277	20906	Business	57200.00
0005435508349	20906	Business	57200.00
0005434573187	20906	Business	57200.00
0005435502281	20906	Business	57200.00
0005435508337	20906	Business	57200.00
0005435517895	20906	Business	57200.00
0005435517892	20906	Business	57200.00
0005434573253	20906	Business	57200.00
0005435517881	20906	Business	57200.00
0005435517889	20906	Economy	19100.00
0005432291925	20906	Economy	19100.00
0005435517882	20906	Economy	19100.00
0005435319571	20906	Economy	19100.00
0005435517884	20906	Economy	19100.00
0005434573213	20906	Economy	19100.00
0005435508343	20906	Economy	19100.00
0005435508344	20906	Economy	19100.00
0005435502283	20906	Economy	21000.00
0005435502270	20906	Economy	21000.00
0005435502265	20906	Economy	21000.00
0005435517890	20906	Economy	21000.00
0005432291927	20906	Economy	19100.00
0005435517886	20906	Economy	19100.00
0005435502275	20906	Economy	19100.00
0005434573134	20906	Economy	19100.00
0005435508351	20906	Economy	19100.00
0005435508345	20906	Economy	19100.00
0005435502269	20906	Economy	19100.00
0005435319568	20906	Economy	19100.00
0005435508342	20906	Economy	19100.00
0005435502267	20906	Economy	19100.00
0005435508347	20906	Economy	19100.00
0005434573215	20906	Economy	19100.00
0005435517873	20906	Economy	19100.00
0005434573266	20906	Economy	19100.00
0005435502278	20906	Economy	19100.00
0005435517879	20906	Economy	19100.00
0005435517883	20906	Economy	19100.00
0005435319576	20906	Economy	19100.00
0005435517885	20906	Economy	19100.00
0005434573214	20906	Economy	19100.00
0005435508338	20906	Economy	19100.00
0005435502268	20906	Economy	19100.00
0005434573254	20906	Economy	19100.00
0005435319574	20906	Economy	19100.00
0005435517888	20906	Economy	19100.00
0005435517878	20906	Economy	19100.00
0005435319569	20906	Economy	19100.00
0005435319572	20906	Economy	19100.00
0005435508346	20906	Economy	19100.00
0005435508339	20906	Economy	19100.00
0005435517880	20906	Economy	19100.00
0005435517891	20906	Economy	19100.00
0005435502279	20906	Economy	19100.00
0005435502274	20906	Economy	19100.00
0005434573258	20906	Economy	19100.00
0005435502282	20906	Economy	19100.00
0005435517893	20906	Economy	19100.00
0005435502271	20906	Economy	19100.00
0005435502266	20906	Economy	19100.00
0005435319570	20906	Economy	19100.00
0005435517874	20906	Economy	19100.00
0005435502280	20906	Economy	19100.00
0005435502273	20906	Economy	19100.00
0005435508340	20906	Economy	19100.00
0005435517877	20906	Economy	19100.00
0005435517894	20906	Economy	19100.00
0005434573140	20906	Economy	19100.00
0005435502272	20906	Economy	19100.00
0005435502284	20906	Economy	19100.00
0005435508341	20906	Economy	19100.00
0005435502285	20906	Economy	19100.00
0005435517875	20906	Economy	19100.00
0005435502276	20906	Economy	19100.00
0005435508348	20906	Economy	19100.00
0005435508350	20906	Economy	19100.00
0005435319573	20906	Economy	19100.00
0005435517887	20906	Economy	19100.00
0005434573248	20906	Economy	19100.00
0005435517876	20906	Economy	19100.00
0005432291926	20906	Economy	19100.00
0005432692687	3051	Business	10300.00
0005432692757	3051	Business	10300.00
0005432692695	3051	Business	10300.00
0005432692741	3051	Business	10300.00
0005432692869	3051	Business	10300.00
0005432692737	3051	Business	10300.00
0005432692769	3051	Business	10300.00
0005432692760	3051	Economy	3400.00
0005432692771	3051	Economy	3400.00
0005432692868	3051	Economy	3400.00
0005432692770	3051	Economy	3400.00
0005432692729	3051	Economy	3400.00
0005432692847	3051	Economy	3800.00
0005432692776	3051	Economy	3800.00
0005432692767	3051	Economy	3400.00
0005432692759	3051	Economy	3400.00
0005432692755	3051	Economy	3400.00
0005432692792	3051	Economy	3400.00
0005432692794	3051	Economy	3400.00
0005432692772	3051	Economy	3400.00
0005432692718	3051	Economy	3400.00
0005432692730	3051	Economy	3400.00
0005432692836	3051	Economy	3400.00
0005432692754	3051	Economy	3400.00
0005432692725	3051	Economy	3400.00
0005432692726	3051	Economy	3400.00
0005432692671	3051	Economy	3400.00
0005432692727	3051	Economy	3400.00
0005432692804	3051	Economy	3400.00
0005432692793	3051	Economy	3400.00
0005432692768	3051	Economy	3400.00
0005432692734	3051	Economy	3400.00
0005432692810	3051	Economy	3400.00
0005432692788	3051	Economy	3400.00
0005432880667	3056	Business	10300.00
0005432706746	3056	Business	10300.00
0005433123773	3056	Business	10300.00
0005432706734	3056	Business	10300.00
0005433194832	3056	Business	10300.00
0005433194841	3056	Business	10300.00
0005432880681	3056	Business	10300.00
0005433123638	3056	Business	10300.00
0005433123682	3056	Economy	3400.00
0005432706742	3056	Economy	3400.00
0005432880628	3056	Economy	3400.00
0005432217772	3056	Economy	3400.00
0005433123678	3056	Economy	3400.00
0005432706741	3056	Economy	3400.00
0005433123700	3056	Economy	3400.00
0005432217771	3056	Economy	3800.00
0005432706733	3056	Economy	3800.00
0005432706727	3056	Economy	3800.00
0005433123792	3056	Economy	3400.00
0005432706736	3056	Economy	3400.00
0005432706738	3056	Economy	3400.00
0005433123716	3056	Economy	3400.00
0005433123786	3056	Economy	3400.00
0005433123726	3056	Economy	3400.00
0005433123665	3056	Economy	3400.00
0005432706730	3056	Economy	3400.00
0005433123679	3056	Economy	3400.00
0005432706735	3056	Economy	3400.00
0005433123722	3056	Economy	3400.00
0005432880616	3056	Economy	3400.00
0005432880707	3056	Economy	3400.00
0005432880677	3056	Economy	3400.00
0005432706729	3056	Economy	3400.00
0005433123727	3056	Economy	3400.00
0005433123667	3056	Economy	3400.00
0005432880656	3056	Economy	3400.00
0005433123739	3056	Economy	3400.00
0005432217773	3056	Economy	3400.00
0005432880660	3056	Economy	3400.00
0005432706743	3056	Economy	3400.00
0005433123677	3056	Economy	3400.00
0005432706744	3056	Economy	3400.00
0005432880638	3056	Economy	3400.00
0005432706752	3056	Economy	3400.00
0005433123760	3056	Economy	3400.00
0005432706740	3056	Economy	3400.00
0005432880666	3056	Economy	3400.00
0005432706745	3056	Economy	3400.00
0005432706751	3056	Economy	3400.00
0005432880683	3056	Economy	3400.00
0005432706732	3056	Economy	3400.00
0005433123738	3056	Economy	3400.00
0005433194842	3056	Economy	3400.00
0005432880629	3056	Economy	3400.00
0005432706748	3056	Economy	3400.00
0005433123672	3056	Economy	3400.00
0005433123742	3056	Economy	3400.00
0005432706731	3056	Economy	3400.00
0005432706739	3056	Economy	3400.00
0005432706737	3056	Economy	3400.00
0005432706749	3056	Economy	3400.00
0005433123791	3056	Economy	3400.00
0005432706747	3056	Economy	3400.00
0005432880617	3056	Economy	3400.00
0005433123756	3056	Economy	3400.00
0005432217774	3056	Economy	3400.00
0005433123708	3056	Economy	3400.00
0005432706750	3056	Economy	3400.00
0005433123666	3056	Economy	3400.00
0005432706728	3056	Economy	3400.00
0005432880682	3056	Economy	3400.00
0005432880805	30084	Business	10300.00
0005432693039	30084	Business	10300.00
0005432706498	30084	Business	10300.00
0005433123888	30084	Business	10300.00
0005432880796	30084	Business	10300.00
0005433123901	30084	Business	10300.00
0005432693059	30084	Business	10300.00
0005432706490	30084	Business	10300.00
0005432706460	30084	Business	10300.00
0005432706422	30084	Business	10300.00
0005433123894	30084	Business	10300.00
0005432706545	30084	Business	10300.00
0005432693042	30084	Economy	3400.00
0005433123896	30084	Economy	3400.00
0005432693041	30084	Economy	3400.00
0005432706633	30084	Economy	3400.00
0005433123897	30084	Economy	3400.00
0005432693035	30084	Economy	3400.00
0005432880800	30084	Economy	3400.00
0005433123909	30084	Economy	3400.00
0005433123889	30084	Economy	3400.00
0005432706527	30084	Economy	3400.00
0005432706539	30084	Economy	3800.00
0005432693033	30084	Economy	3800.00
0005432706586	30084	Economy	3800.00
0005433123892	30084	Economy	3800.00
0005433123908	30084	Economy	3800.00
0005433194857	30084	Economy	3400.00
0005433123902	30084	Economy	3400.00
0005433123904	30084	Economy	3400.00
0005433123899	30084	Economy	3400.00
0005432706563	30084	Economy	3400.00
0005432706585	30084	Economy	3400.00
0005432880795	30084	Economy	3400.00
0005432706529	30084	Economy	3400.00
0005432693060	30084	Economy	3400.00
0005432706584	30084	Economy	3400.00
0005432693048	30084	Economy	3400.00
0005432706593	30084	Economy	3400.00
0005432880798	30084	Economy	3400.00
0005432706562	30084	Economy	3400.00
0005432693052	30084	Economy	3400.00
0005432880793	30084	Economy	3400.00
0005432693037	30084	Economy	3400.00
0005432706480	30084	Economy	3400.00
0005433123893	30084	Economy	3400.00
0005432693050	30084	Economy	3400.00
0005432880794	30084	Economy	3400.00
0005432693043	30084	Economy	3400.00
0005432693040	30084	Economy	3400.00
0005432693055	30084	Economy	3400.00
0005432693058	30084	Economy	3400.00
0005433123907	30084	Economy	3400.00
0005432693053	30084	Economy	3400.00
0005432880801	30084	Economy	3400.00
0005433123903	30084	Economy	3400.00
0005432880792	30084	Economy	3400.00
0005432706404	30084	Economy	3400.00
0005432693057	30084	Economy	3400.00
0005432880799	30084	Economy	3400.00
0005432706632	30084	Economy	3400.00
0005432693051	30084	Economy	3400.00
0005432693062	30084	Economy	3400.00
0005432706497	30084	Economy	3400.00
0005432693063	30084	Economy	3400.00
0005433123905	30084	Economy	3400.00
0005432706594	30084	Economy	3400.00
0005432693054	30084	Economy	3400.00
0005432693056	30084	Economy	3400.00
0005432693036	30084	Economy	3400.00
0005433194856	30084	Economy	3400.00
0005432693032	30084	Economy	3400.00
0005433123890	30084	Economy	3400.00
0005433123906	30084	Economy	3400.00
0005432880804	30084	Economy	3400.00
0005433123910	30084	Economy	3400.00
0005432706528	30084	Economy	3400.00
0005432693046	30084	Economy	3400.00
0005432693047	30084	Economy	3400.00
0005432706543	30084	Economy	3400.00
0005433123895	30084	Economy	3400.00
0005432693038	30084	Economy	3400.00
0005432706587	30084	Economy	3400.00
0005432880791	30084	Economy	3400.00
0005432693044	30084	Economy	3400.00
0005432693034	30084	Economy	3400.00
0005433123891	30084	Economy	3400.00
0005432693045	30084	Economy	3400.00
0005432880797	30084	Economy	3400.00
0005432880802	30084	Economy	3400.00
0005433123900	30084	Economy	3400.00
0005432706538	30084	Economy	3400.00
0005433123898	30084	Economy	3400.00
0005432880803	30084	Economy	3400.00
0005432706544	30084	Economy	3400.00
0005432693061	30084	Economy	3400.00
0005432693049	30084	Economy	3400.00
0005434979737	23690	Economy	4000.00
0005434979733	23690	Economy	4000.00
0005434979717	23690	Economy	3600.00
0005434988720	23690	Economy	3600.00
0005434979739	23690	Economy	3600.00
0005434979730	23690	Economy	3600.00
0005434979740	23690	Economy	3600.00
0005434979736	23690	Economy	3600.00
0005434988721	23690	Economy	3600.00
0005434979722	23690	Economy	3600.00
0005434979723	23690	Economy	3600.00
0005434988715	23690	Economy	3600.00
0005434979726	23690	Economy	3600.00
0005434979718	23690	Economy	3600.00
0005434979743	23690	Economy	3600.00
0005434988714	23690	Economy	3600.00
0005434988713	23690	Economy	3600.00
0005434979738	23690	Economy	3600.00
0005434979719	23690	Economy	3600.00
0005434988711	23690	Economy	3600.00
0005434979725	23690	Economy	3600.00
0005434979727	23690	Economy	3600.00
0005434979742	23690	Economy	3600.00
0005434979714	23690	Economy	3600.00
0005434988710	23690	Economy	3600.00
0005434988712	23690	Economy	3600.00
0005434979720	23690	Economy	3600.00
0005434979731	23690	Economy	3600.00
0005434988718	23690	Economy	3600.00
0005434979734	23690	Economy	3600.00
0005434979729	23690	Economy	3600.00
0005434979715	23690	Economy	3600.00
0005434979732	23690	Economy	3600.00
0005434988717	23690	Economy	3600.00
0005434979728	23690	Economy	3600.00
0005434988719	23690	Economy	3600.00
0005434979721	23690	Economy	3600.00
0005434979724	23690	Economy	3600.00
0005434979735	23690	Economy	3600.00
0005434988716	23690	Economy	3600.00
0005434979741	23690	Economy	3600.00
0005434979716	23690	Economy	3600.00
0005434979431	27517	Economy	4000.00
0005434979388	27517	Economy	4000.00
0005434979441	27517	Economy	4000.00
0005434988589	27517	Economy	4000.00
0005434979561	27517	Economy	3600.00
0005434979506	27517	Economy	3600.00
0005434988629	27517	Economy	3600.00
0005434979560	27517	Economy	3600.00
0005434988588	27517	Economy	3600.00
0005434979575	27517	Economy	3600.00
0005434988631	27517	Economy	3600.00
0005434979512	27517	Economy	3600.00
0005434988632	27517	Economy	3600.00
0005434979574	27517	Economy	3600.00
0005434979576	27517	Economy	3600.00
0005434979502	27517	Economy	3600.00
0005434979291	27517	Economy	3600.00
0005434979395	27517	Economy	3600.00
0005434979383	27517	Economy	3600.00
0005434988603	27517	Economy	3600.00
0005434979384	27517	Economy	3600.00
0005434979471	27517	Economy	3600.00
0005434988630	27517	Economy	3600.00
0005434979389	27517	Economy	3600.00
0005434988608	27517	Economy	3600.00
0005434979553	27517	Economy	3600.00
0005434988604	27517	Economy	3600.00
0005434988596	27517	Economy	3600.00
0005434979422	27517	Economy	3600.00
0005434979505	27517	Economy	3600.00
0005434979464	27517	Economy	3600.00
0005434979504	27517	Economy	3600.00
0005434979470	27517	Economy	3600.00
0005434979462	27517	Economy	3600.00
0005434979547	27517	Economy	3600.00
0005434979423	27517	Economy	3600.00
0005434988607	27517	Economy	3600.00
0005434979521	27517	Economy	3600.00
0005434979463	27517	Economy	3600.00
0005434979511	27517	Economy	3600.00
0005434979403	27517	Economy	3600.00
0005434979440	27517	Economy	3600.00
0005434302865	10295	Economy	21600.00
0005433113511	10295	Economy	19700.00
0005434302448	10295	Economy	19700.00
0005434302864	10295	Economy	19700.00
0005433111486	10295	Economy	19700.00
0005433113504	10295	Economy	19700.00
0005433111476	10295	Economy	19700.00
0005434302866	10295	Economy	19700.00
0005434302868	10295	Economy	19700.00
0005434302867	10295	Economy	19700.00
0005434302449	10295	Economy	19700.00
0005433111485	10295	Economy	19700.00
0005434302451	10295	Economy	19700.00
0005433111481	10295	Economy	19700.00
0005433111478	10295	Economy	19700.00
0005433111488	10295	Economy	19700.00
0005434302450	10295	Economy	19700.00
0005433111487	10295	Economy	19700.00
0005434302863	10295	Economy	19700.00
0005433111477	10295	Economy	19700.00
0005434302452	10295	Economy	19700.00
0005433113503	10295	Economy	19700.00
0005433113533	19612	Economy	19700.00
0005434302408	19612	Economy	19700.00
0005433113534	19612	Economy	19700.00
0005434302401	19612	Economy	19700.00
0005435069032	3538	Business	26900.00
0005435718935	3538	Business	26900.00
0005435069009	3538	Business	26900.00
0005435069047	3538	Business	26900.00
0005435069023	3538	Business	26900.00
0005435069026	3538	Business	26900.00
0005435925170	3538	Business	26900.00
0005435925130	3538	Business	26900.00
0005435069049	3538	Business	26900.00
0005435925096	3538	Economy	9000.00
0005435069054	3538	Economy	9000.00
0005435069056	3538	Economy	9000.00
0005435069022	3538	Economy	9000.00
0005435069048	3538	Economy	9000.00
0005435069025	3538	Economy	9000.00
0005435069046	3538	Economy	9000.00
0005435069014	3538	Economy	9900.00
0005435069043	3538	Economy	9900.00
0005435069010	3538	Economy	9900.00
0005435069028	3538	Economy	9900.00
0005435069016	3538	Economy	9000.00
0005435069017	3538	Economy	9000.00
0005435925118	3538	Economy	9000.00
0005435069034	3538	Economy	9000.00
0005435069007	3538	Economy	9000.00
0005435069052	3538	Economy	9000.00
0005435925162	3538	Economy	9000.00
0005435069051	3538	Economy	9000.00
0005435069033	3538	Economy	9000.00
0005435069058	3538	Economy	9000.00
0005435069021	3538	Economy	9000.00
0005435069044	3538	Economy	9000.00
0005435069013	3538	Economy	9000.00
0005435069031	3538	Economy	9000.00
0005435925173	3538	Economy	9000.00
0005435925099	3538	Economy	9000.00
0005435925178	3538	Economy	9000.00
0005435925156	3538	Economy	9000.00
0005435069050	3538	Economy	9000.00
0005435925172	3538	Economy	9000.00
0005435069035	3538	Economy	9000.00
0005435069041	3538	Economy	9000.00
0005435069018	3538	Economy	9000.00
0005435069042	3538	Economy	9000.00
0005435718932	3538	Economy	9000.00
0005435925163	3538	Economy	9000.00
0005435718934	3538	Economy	9000.00
0005435069055	3538	Economy	9000.00
0005435718930	3538	Economy	9000.00
0005435069015	3538	Economy	9000.00
0005435069037	3538	Economy	9000.00
0005435925155	3538	Economy	9000.00
0005435069019	3538	Economy	9000.00
0005435069040	3538	Economy	9000.00
0005435069030	3538	Economy	9000.00
0005435069039	3538	Economy	9000.00
0005435069029	3538	Economy	9000.00
0005435069012	3538	Economy	9000.00
0005435069053	3538	Economy	9000.00
0005435069020	3538	Economy	9000.00
0005435069008	3538	Economy	9000.00
0005435925161	3538	Economy	9000.00
0005435069024	3538	Economy	9000.00
0005435925149	3538	Economy	9000.00
0005435925159	3538	Economy	9000.00
0005435069038	3538	Economy	9000.00
0005435069057	3538	Economy	9000.00
0005435718929	3538	Economy	9000.00
0005435069045	3538	Economy	9000.00
0005435925154	3538	Economy	9000.00
0005435718936	3538	Economy	9000.00
0005435718931	3538	Economy	9000.00
0005435718937	3538	Economy	9000.00
0005435069036	3538	Economy	9000.00
0005435069011	3538	Economy	9000.00
0005435718938	3538	Economy	9000.00
0005435069027	3538	Economy	9000.00
0005435718933	3538	Economy	9000.00
0005435925282	15274	Business	26900.00
0005435068391	15274	Business	26900.00
0005435925290	15274	Business	26900.00
0005435068387	15274	Business	26900.00
0005435068551	15274	Business	26900.00
0005435925285	15274	Business	26900.00
0005435925287	15274	Business	26900.00
0005435068559	15274	Business	26900.00
0005435068711	15274	Business	26900.00
0005435068600	15274	Business	26900.00
0005435068493	15274	Economy	9000.00
0005435068529	15274	Economy	9000.00
0005435925281	15274	Economy	9000.00
0005435068508	15274	Economy	9000.00
0005435068530	15274	Economy	9000.00
0005435925279	15274	Economy	9000.00
0005435925293	15274	Economy	9000.00
0005435068477	15274	Economy	9000.00
0005435068535	15274	Economy	9000.00
0005435068639	15274	Economy	9900.00
0005435068389	15274	Economy	9900.00
0005435068565	15274	Economy	9900.00
0005435068640	15274	Economy	9000.00
0005435068745	15274	Economy	9000.00
0005435068615	15274	Economy	9000.00
0005435068549	15274	Economy	9000.00
0005435068346	15274	Economy	9000.00
0005435068509	15274	Economy	9000.00
0005435068490	15274	Economy	9000.00
0005435068504	15274	Economy	9000.00
0005435068582	15274	Economy	9000.00
0005435068668	15274	Economy	9000.00
0005435068305	15274	Economy	9000.00
0005435068544	15274	Economy	9000.00
0005435068703	15274	Economy	9000.00
0005435068633	15274	Economy	9000.00
0005435925291	15274	Economy	9000.00
0005435068449	15274	Economy	9000.00
0005435068552	15274	Economy	9000.00
0005435068505	15274	Economy	9000.00
0005435068444	15274	Economy	9000.00
0005435068321	15274	Economy	9000.00
0005435925283	15274	Economy	9000.00
0005435068561	15274	Economy	9000.00
0005435068601	15274	Economy	9000.00
0005435068390	15274	Economy	9000.00
0005435068550	15274	Economy	9000.00
0005435068445	15274	Economy	9000.00
0005435068714	15274	Economy	9000.00
0005435068462	15274	Economy	9000.00
0005435925294	15274	Economy	9000.00
0005435925284	15274	Economy	9000.00
0005435925292	15274	Economy	9000.00
0005435068713	15274	Economy	9000.00
0005435068543	15274	Economy	9000.00
0005435068463	15274	Economy	9000.00
0005435068611	15274	Economy	9000.00
0005435068442	15274	Economy	9000.00
0005435068560	15274	Economy	9000.00
0005435925288	15274	Economy	9000.00
0005435925286	15274	Economy	9000.00
0005435068630	15274	Economy	9000.00
0005435068627	15274	Economy	9000.00
0005435068564	15274	Economy	9000.00
0005435068563	15274	Economy	9000.00
0005435068386	15274	Economy	9000.00
0005435925289	15274	Economy	9000.00
0005435068397	15274	Economy	9000.00
0005435068634	15274	Economy	9000.00
0005435068744	15274	Economy	9000.00
0005435068546	15274	Economy	9000.00
0005435925280	15274	Economy	9000.00
0005435068494	15274	Economy	9000.00
0005435068562	15274	Economy	9000.00
0005435068418	15274	Economy	9000.00
0005435925278	15274	Economy	9000.00
0005435068786	15274	Economy	9000.00
0005432660815	18180	Economy	5900.00
0005432659704	18180	Economy	5900.00
0005432659703	18180	Economy	5900.00
0005432658588	18180	Economy	5900.00
0005432658589	18180	Economy	5900.00
0005432660816	18180	Economy	5900.00
0005432667433	26394	Economy	5900.00
0005432667432	26394	Economy	5900.00
0005432660795	26394	Economy	5900.00
0005433101561	175	Business	20000.00
0005432919666	175	Business	20000.00
0005433101559	175	Business	20000.00
0005432901440	175	Business	20000.00
0005433101487	175	Business	20000.00
0005432919609	175	Business	20000.00
0005432677520	175	Business	20000.00
0005433101440	175	Business	20000.00
0005433101642	175	Business	20000.00
0005433101621	175	Business	20000.00
0005433101650	175	Business	20000.00
0005432919674	175	Business	20000.00
0005432157489	175	Business	20000.00
0005433101643	175	Business	20000.00
0005432901398	175	Business	20000.00
0005432901531	175	Economy	7300.00
0005432919673	175	Economy	7300.00
0005432919690	175	Economy	6700.00
0005433101560	175	Economy	6700.00
0005432901473	175	Economy	6700.00
0005433101653	175	Economy	6700.00
0005433101428	175	Economy	6700.00
0005433101501	175	Economy	6700.00
0005433101525	175	Economy	6700.00
0005433101531	175	Economy	6700.00
0005433101471	175	Economy	6700.00
0005433101640	175	Economy	6700.00
0005433101557	175	Economy	6700.00
0005432919645	175	Economy	6700.00
0005432901530	175	Economy	6700.00
0005432919593	175	Economy	6700.00
0005433101678	175	Economy	6700.00
0005433101589	175	Economy	6700.00
0005433101623	175	Economy	6700.00
0005433101634	175	Economy	6700.00
0005433101638	175	Economy	6700.00
0005433101667	175	Economy	6700.00
0005433101473	175	Economy	6700.00
0005432901441	175	Economy	6700.00
0005432919700	175	Economy	6700.00
0005433101690	175	Economy	6700.00
0005432901393	175	Economy	6700.00
0005432901535	175	Economy	6700.00
0005433101644	175	Economy	6700.00
0005433101491	175	Economy	6700.00
0005433101691	175	Economy	6700.00
0005433101529	175	Economy	6700.00
0005432157490	175	Economy	6700.00
0005433101588	175	Economy	6700.00
0005433101652	175	Economy	6700.00
0005432901420	175	Economy	6700.00
0005432677540	175	Economy	6700.00
0005433101637	175	Economy	6700.00
0005433101412	175	Economy	6700.00
0005432677541	175	Economy	6700.00
0005433101618	175	Economy	6700.00
0005432919592	175	Economy	6700.00
0005433101649	175	Economy	6700.00
0005433101639	175	Economy	6700.00
0005433101488	175	Economy	6700.00
0005433101677	175	Economy	6700.00
0005433101682	175	Economy	6700.00
0005433101597	175	Economy	7300.00
0005432919727	175	Economy	7300.00
0005432901537	175	Economy	7300.00
0005432919665	175	Economy	7300.00
0005433101624	175	Economy	6700.00
0005432919633	175	Economy	6700.00
0005433101636	175	Economy	6700.00
0005433101668	175	Economy	6700.00
0005433101657	175	Economy	6700.00
0005433101619	175	Economy	6700.00
0005433101693	175	Economy	6700.00
0005432901397	175	Economy	6700.00
0005432919724	175	Economy	6700.00
0005433101669	175	Economy	6700.00
0005433101611	175	Economy	6700.00
0005433101587	175	Economy	6700.00
0005433101656	175	Economy	6700.00
0005432919708	175	Economy	6700.00
0005433101534	175	Economy	6700.00
0005432919697	175	Economy	6700.00
0005433101666	175	Economy	6700.00
0005432919726	175	Economy	6700.00
0005432919699	175	Economy	6700.00
0005433101610	175	Economy	6700.00
0005433101615	175	Economy	6700.00
0005432919691	175	Economy	6700.00
0005432677534	175	Economy	6700.00
0005433101683	175	Economy	6700.00
0005432901472	175	Economy	6700.00
0005433101530	175	Economy	6700.00
0005432919659	175	Economy	6700.00
0005432901456	175	Economy	6700.00
0005433101500	175	Economy	6700.00
0005433101598	175	Economy	6700.00
0005433101550	175	Economy	6700.00
0005433101692	175	Economy	6700.00
0005432901409	175	Economy	6700.00
0005432901457	175	Economy	6700.00
0005432901471	175	Economy	6700.00
0005432919608	175	Economy	6700.00
0005432901434	175	Economy	6700.00
0005432901433	175	Economy	6700.00
0005433101686	175	Economy	6700.00
0005432901492	175	Economy	6700.00
0005432919671	175	Economy	6700.00
0005432901536	175	Economy	6700.00
0005433101620	175	Economy	6700.00
0005432817445	176	Business	20000.00
0005432261872	176	Business	20000.00
0005433690908	176	Business	20000.00
0005432288981	176	Business	20000.00
0005432261868	176	Business	20000.00
0005432261845	176	Business	20000.00
0005432817443	176	Business	20000.00
0005432817430	176	Business	20000.00
0005432261879	176	Business	20000.00
0005432817432	176	Business	20000.00
0005432261842	176	Business	20000.00
0005432261847	176	Business	20000.00
0005432261866	176	Business	20000.00
0005432756797	176	Business	20000.00
0005432261865	176	Business	20000.00
0005432261877	176	Business	20000.00
0005432817449	176	Economy	7300.00
0005432261844	176	Economy	7300.00
0005432261871	176	Economy	6700.00
0005432261876	176	Economy	6700.00
0005432817436	176	Economy	6700.00
0005432261859	176	Economy	6700.00
0005432817446	176	Economy	6700.00
0005432261880	176	Economy	6700.00
0005432261840	176	Economy	6700.00
0005432817426	176	Economy	6700.00
0005432261849	176	Economy	6700.00
0005432817451	176	Economy	6700.00
0005432817448	176	Economy	6700.00
0005432817444	176	Economy	6700.00
0005432261841	176	Economy	6700.00
0005432756798	176	Economy	6700.00
0005432261874	176	Economy	6700.00
0005432817447	176	Economy	6700.00
0005432817427	176	Economy	6700.00
0005432288983	176	Economy	6700.00
0005432261881	176	Economy	6700.00
0005432261838	176	Economy	6700.00
0005432753262	176	Economy	6700.00
0005432261864	176	Economy	6700.00
0005432817425	176	Economy	6700.00
0005432817440	176	Economy	6700.00
0005432261862	176	Economy	6700.00
0005432261873	176	Economy	6700.00
0005432817442	176	Economy	6700.00
0005432261846	176	Economy	6700.00
0005432756810	176	Economy	6700.00
0005432261850	176	Economy	6700.00
0005432261855	176	Economy	7300.00
0005432261837	176	Economy	6700.00
0005432261854	176	Economy	6700.00
0005432261861	176	Economy	6700.00
0005432261851	176	Economy	6700.00
0005432261853	176	Economy	7300.00
0005432261856	176	Economy	6700.00
0005432817452	176	Economy	6700.00
0005432261848	176	Economy	6700.00
0005432261875	176	Economy	6700.00
0005432261858	176	Economy	6700.00
0005432756799	176	Economy	6700.00
0005432817429	176	Economy	6700.00
0005432261839	176	Economy	6700.00
0005432261869	176	Economy	6700.00
0005432207657	176	Economy	6700.00
0005432817453	176	Economy	6700.00
0005432288982	176	Economy	6700.00
0005432207658	176	Economy	6700.00
0005432261867	176	Economy	6700.00
0005432817439	176	Economy	6700.00
0005432817450	176	Economy	6700.00
0005432817428	176	Economy	6700.00
0005432261860	176	Economy	6700.00
0005432261843	176	Economy	6700.00
0005432817431	176	Economy	6700.00
0005432753252	176	Economy	6700.00
0005432261852	176	Economy	6700.00
0005432817441	176	Economy	6700.00
0005432261878	176	Economy	6700.00
0005432817438	176	Economy	6700.00
0005432817435	176	Economy	6700.00
0005432261863	176	Economy	6700.00
0005432817437	176	Economy	6700.00
0005432261857	176	Economy	6700.00
0005432817433	176	Economy	6700.00
0005432261870	176	Economy	6700.00
0005432817434	176	Economy	6700.00
0005433102110	8082	Business	20000.00
0005432020237	8082	Business	20000.00
0005433102108	8082	Business	20000.00
0005433102084	8082	Business	20000.00
0005432020231	8082	Business	20000.00
0005433102063	8082	Business	20000.00
0005433102067	8082	Business	20000.00
0005432919824	8082	Business	20000.00
0005432753299	8082	Business	20000.00
0005432020227	8082	Business	20000.00
0005433102111	8082	Business	20000.00
0005432020222	8082	Business	20000.00
0005432919844	8082	Business	20000.00
0005433102109	8082	Business	20000.00
0005432919830	8082	Business	20000.00
0005433102079	8082	Business	20000.00
0005432020233	8082	Business	20000.00
0005432044520	8082	Business	20000.00
0005432919836	8082	Business	20000.00
0005433102065	8082	Business	20000.00
0005432020228	8082	Business	20000.00
0005432020219	8082	Business	20000.00
0005432919829	8082	Business	20000.00
0005432391995	8082	Economy	7300.00
0005433102114	8082	Economy	7300.00
0005433102089	8082	Economy	7300.00
0005433102104	8082	Economy	6700.00
0005432919842	8082	Economy	6700.00
0005432020243	8082	Economy	6700.00
0005432020229	8082	Economy	6700.00
0005432020234	8082	Economy	6700.00
0005432751523	8082	Economy	6700.00
0005432020244	8082	Economy	6700.00
0005433102118	8082	Economy	6700.00
0005433102121	8082	Economy	6700.00
0005432020236	8082	Economy	6700.00
0005432020240	8082	Economy	6700.00
0005433102074	8082	Economy	6700.00
0005432919841	8082	Economy	6700.00
0005432020225	8082	Economy	6700.00
0005433102082	8082	Economy	6700.00
0005433102099	8082	Economy	6700.00
0005432020218	8082	Economy	6700.00
0005433102070	8082	Economy	6700.00
0005432919835	8082	Economy	6700.00
0005433102105	8082	Economy	6700.00
0005433102088	8082	Economy	6700.00
0005432919826	8082	Economy	6700.00
0005432020232	8082	Economy	6700.00
0005433102117	8082	Economy	6700.00
0005433102086	8082	Economy	6700.00
0005433102073	8082	Economy	6700.00
0005432753300	8082	Economy	6700.00
0005433102077	8082	Economy	6700.00
0005433102066	8082	Economy	6700.00
0005433102092	8082	Economy	6700.00
0005433102081	8082	Economy	6700.00
0005433102097	8082	Economy	6700.00
0005432919840	8082	Economy	6700.00
0005433102103	8082	Economy	6700.00
0005432020239	8082	Economy	6700.00
0005432020221	8082	Economy	6700.00
0005432919827	8082	Economy	6700.00
0005433102078	8082	Economy	6700.00
0005432045611	8082	Economy	6700.00
0005433102123	8082	Economy	6700.00
0005432020230	8082	Economy	6700.00
0005432020238	8082	Economy	6700.00
0005433102096	8082	Economy	6700.00
0005432020241	8082	Economy	6700.00
0005432677568	8082	Economy	7300.00
0005433102102	8082	Economy	7300.00
0005432919843	8082	Economy	7300.00
0005432044521	8082	Economy	6700.00
0005432753297	8082	Economy	7300.00
0005433102076	8082	Economy	6700.00
0005432020220	8082	Economy	6700.00
0005433102101	8082	Economy	6700.00
0005432753298	8082	Economy	7300.00
0005432919839	8082	Economy	6700.00
0005432020224	8082	Economy	6700.00
0005432045612	8082	Economy	6700.00
0005432677570	8082	Economy	6700.00
0005432919837	8082	Economy	6700.00
0005433102072	8082	Economy	6700.00
0005432919828	8082	Economy	6700.00
0005432919834	8082	Economy	6700.00
0005433102119	8082	Economy	6700.00
0005432044522	8082	Economy	6700.00
0005432020226	8082	Economy	6700.00
0005432391997	8082	Economy	6700.00
0005432020235	8082	Economy	6700.00
0005432020242	8082	Economy	6700.00
0005432020223	8082	Economy	6700.00
0005433102069	8082	Economy	6700.00
0005433102120	8082	Economy	6700.00
0005433102071	8082	Economy	6700.00
0005433102093	8082	Economy	6700.00
0005433102098	8082	Economy	6700.00
0005433102083	8082	Economy	6700.00
0005433102116	8082	Economy	6700.00
0005432919825	8082	Economy	6700.00
0005432919833	8082	Economy	6700.00
0005432677569	8082	Economy	6700.00
0005432751524	8082	Economy	6700.00
0005433102113	8082	Economy	6700.00
0005433102115	8082	Economy	6700.00
0005433102087	8082	Economy	6700.00
0005432677571	8082	Economy	6700.00
0005433102068	8082	Economy	6700.00
0005433102124	8082	Economy	6700.00
0005432919832	8082	Economy	6700.00
0005432919831	8082	Economy	6700.00
0005433102090	8082	Economy	6700.00
0005433102107	8082	Economy	6700.00
0005433102091	8082	Economy	6700.00
0005433102064	8082	Economy	6700.00
0005433102122	8082	Economy	6700.00
0005433102075	8082	Economy	6700.00
0005432391996	8082	Economy	6700.00
0005433102095	8082	Economy	6700.00
0005433102080	8082	Economy	6700.00
0005433102112	8082	Economy	6700.00
0005433102100	8082	Economy	6700.00
0005433102085	8082	Economy	6700.00
0005433102106	8082	Economy	6700.00
0005433102094	8082	Economy	6700.00
0005432919838	8082	Economy	6700.00
0005432901593	8081	Business	20000.00
0005432901596	8081	Business	20000.00
0005432817317	8081	Business	20000.00
0005432817218	8081	Business	20000.00
0005432817325	8081	Business	20000.00
0005432901586	8081	Business	20000.00
0005432817263	8081	Business	20000.00
0005432901584	8081	Business	20000.00
0005432817163	8081	Business	20000.00
0005432817258	8081	Business	20000.00
0005432901583	8081	Business	20000.00
0005432901582	8081	Business	20000.00
0005432901585	8081	Economy	7300.00
0005432901589	8081	Economy	7300.00
0005432817201	8081	Economy	7300.00
0005432817299	8081	Economy	6700.00
0005432817227	8081	Economy	6700.00
0005432817217	8081	Economy	6700.00
0005432901592	8081	Economy	6700.00
0005432901587	8081	Economy	6700.00
0005432817226	8081	Economy	6700.00
0005432002073	8081	Economy	6700.00
0005432002074	8081	Economy	6700.00
0005432901591	8081	Economy	6700.00
0005432002072	8081	Economy	6700.00
0005432817132	8081	Economy	6700.00
0005432817212	8081	Economy	6700.00
0005432817173	8081	Economy	6700.00
0005432901598	8081	Economy	6700.00
0005432817235	8081	Economy	6700.00
0005432901588	8081	Economy	6700.00
0005432817184	8081	Economy	6700.00
0005432817086	8081	Economy	6700.00
0005432817176	8081	Economy	7300.00
0005432817123	8081	Economy	7300.00
0005432817174	8081	Economy	6700.00
0005432817188	8081	Economy	6700.00
0005432817066	8081	Economy	6700.00
0005432817068	8081	Economy	6700.00
0005432817178	8081	Economy	6700.00
0005432817175	8081	Economy	6700.00
0005432817200	8081	Economy	6700.00
0005432817108	8081	Economy	6700.00
0005432817316	8081	Economy	6700.00
0005432817136	8081	Economy	6700.00
0005432901597	8081	Economy	6700.00
0005432817224	8081	Economy	6700.00
0005432817234	8081	Economy	6700.00
0005432817090	8081	Economy	6700.00
0005432901590	8081	Economy	6700.00
0005432817131	8081	Economy	6700.00
0005432817164	8081	Economy	6700.00
0005432817243	8081	Economy	6700.00
0005432901581	8081	Economy	6700.00
0005432817107	8081	Economy	6700.00
0005432817264	8081	Economy	6700.00
0005432901595	8081	Economy	6700.00
0005432901594	8081	Economy	6700.00
0005433870729	9685	Economy	6900.00
0005434175708	9685	Economy	6900.00
0005433870730	9685	Economy	6900.00
0005433870727	9685	Economy	6900.00
0005434175695	9685	Economy	6900.00
0005434175709	9685	Economy	6900.00
0005434175713	9685	Economy	6900.00
0005434175712	9685	Economy	6900.00
0005433870728	9685	Economy	6900.00
0005434175702	9685	Economy	6900.00
0005433870712	32332	Economy	6900.00
0005433870707	32332	Economy	6900.00
0005434175747	32332	Economy	6900.00
0005434175748	32332	Economy	6900.00
0005434175749	32332	Economy	6900.00
0005433870711	32332	Economy	6900.00
0005433870708	32332	Economy	6900.00
0005434175746	32332	Economy	6900.00
0005434878136	3502	Business	35000.00
0005432799431	3502	Business	35000.00
0005435902405	3502	Business	35000.00
0005432188605	3502	Business	35000.00
0005435913870	3502	Business	35000.00
0005434878171	3502	Business	35000.00
0005434878191	3502	Business	35000.00
0005432799442	3502	Business	35000.00
0005434878178	3502	Business	35000.00
0005435126353	3502	Business	35000.00
0005434426589	3502	Business	35000.00
0005432799417	3502	Business	35000.00
0005434878193	3502	Business	35000.00
0005435902522	3502	Business	35000.00
0005434878112	3502	Business	35000.00
0005434878133	3502	Business	35000.00
0005434878155	3502	Business	35000.00
0005434878121	3502	Business	35000.00
0005435902541	3502	Business	35000.00
0005434426579	3502	Business	35000.00
0005435902536	3502	Business	35000.00
0005435902573	3502	Business	35000.00
0005434878159	3502	Business	35000.00
0005435626153	3502	Business	35000.00
0005434878177	3502	Business	35000.00
0005435902519	3502	Comfort	19900.00
0005432799430	3502	Comfort	19900.00
0005434878165	3502	Comfort	19900.00
0005432799433	3502	Comfort	19900.00
0005434878197	3502	Comfort	19900.00
0005434878111	3502	Comfort	19900.00
0005435126344	3502	Comfort	19900.00
0005432799440	3502	Comfort	19900.00
0005435126354	3502	Comfort	19900.00
0005434938114	3502	Comfort	19900.00
0005434878189	3502	Comfort	19900.00
0005434426585	3502	Comfort	19900.00
0005435126349	3502	Comfort	19900.00
0005434878137	3502	Comfort	19900.00
0005434878109	3502	Comfort	19900.00
0005434878190	3502	Comfort	19900.00
0005435126341	3502	Comfort	19900.00
0005435902476	3502	Comfort	19900.00
0005435902547	3502	Comfort	19900.00
0005435913875	3502	Comfort	19900.00
0005434878175	3502	Comfort	19900.00
0005435841812	3502	Comfort	19900.00
0005434426571	3502	Comfort	19900.00
0005432799420	3502	Comfort	19900.00
0005435626163	3502	Comfort	19900.00
0005434426577	3502	Comfort	19900.00
0005434426596	3502	Comfort	19900.00
0005435126317	3502	Comfort	19900.00
0005434878156	3502	Comfort	19900.00
0005434878139	3502	Comfort	19900.00
0005434878151	3502	Economy	11700.00
0005434878110	3502	Comfort	19900.00
0005434878142	3502	Economy	11700.00
0005435626148	3502	Economy	11700.00
0005432188603	3502	Economy	11700.00
0005435626157	3502	Economy	11700.00
0005435126330	3502	Economy	11700.00
0005434938130	3502	Economy	11700.00
0005435126350	3502	Economy	11700.00
0005435902553	3502	Economy	11700.00
0005434938132	3502	Economy	11700.00
0005434878141	3502	Economy	11700.00
0005434878154	3502	Economy	11700.00
0005434938123	3502	Economy	11700.00
0005434878115	3502	Economy	11700.00
0005435626146	3502	Economy	11700.00
0005434878140	3502	Economy	11700.00
0005432799436	3502	Economy	11700.00
0005434878114	3502	Economy	11700.00
0005435902462	3502	Economy	11700.00
0005434938115	3502	Economy	11700.00
0005432799428	3502	Economy	11700.00
0005435902552	3502	Economy	11700.00
0005435626160	3502	Economy	11700.00
0005435126336	3502	Economy	11700.00
0005434878153	3502	Economy	11700.00
0005435902459	3502	Economy	11700.00
0005435902550	3502	Economy	11700.00
0005434878122	3502	Economy	11700.00
0005432799421	3502	Economy	11700.00
0005435126316	3502	Economy	11700.00
0005434426595	3502	Economy	11700.00
0005435126326	3502	Economy	11700.00
0005434878172	3502	Economy	11700.00
0005435913877	3502	Economy	11700.00
0005432799427	3502	Economy	11700.00
0005434878150	3502	Economy	11700.00
0005434878123	3502	Economy	11700.00
0005435126351	3502	Economy	11700.00
0005434426593	3502	Economy	11700.00
0005435902404	3502	Economy	11700.00
0005432799424	3502	Economy	11700.00
0005435126331	3502	Economy	11700.00
0005435126342	3502	Economy	11700.00
0005434878173	3502	Economy	11700.00
0005434426567	3502	Economy	11700.00
0005435626161	3502	Economy	11700.00
0005435626159	3502	Economy	11700.00
0005435626145	3502	Economy	11700.00
0005434878146	3502	Economy	11700.00
0005434878166	3502	Economy	11700.00
0005432183466	3502	Economy	11700.00
0005435626164	3502	Economy	11700.00
0005434878130	3502	Economy	12800.00
0005434878179	3502	Economy	11700.00
0005435126345	3502	Economy	11700.00
0005435902500	3502	Economy	11700.00
0005432799435	3502	Economy	12800.00
0005435902574	3502	Economy	12800.00
0005434878148	3502	Economy	11700.00
0005435126319	3502	Economy	12800.00
0005434426581	3502	Economy	11700.00
0005435126325	3502	Economy	11700.00
0005434878161	3502	Economy	11700.00
0005435126348	3502	Economy	11700.00
0005434938126	3502	Economy	11700.00
0005435126320	3502	Economy	11700.00
0005434878199	3502	Economy	11700.00
0005434878116	3502	Economy	11700.00
0005434938127	3502	Economy	11700.00
0005434426582	3502	Economy	11700.00
0005434878135	3502	Economy	11700.00
0005435902508	3502	Economy	11700.00
0005434878188	3502	Economy	11700.00
0005434878198	3502	Economy	11700.00
0005435913878	3502	Economy	11700.00
0005435126332	3502	Economy	11700.00
0005434938129	3502	Economy	11700.00
0005432799418	3502	Economy	11700.00
0005432799443	3502	Economy	11700.00
0005434878160	3502	Economy	11700.00
0005434426575	3502	Economy	11700.00
0005435902475	3502	Economy	11700.00
0005435126334	3502	Economy	11700.00
0005432613858	3502	Economy	11700.00
0005432799426	3502	Economy	11700.00
0005435126352	3502	Economy	11700.00
0005435126339	3502	Economy	11700.00
0005434426584	3502	Economy	11700.00
0005435902545	3502	Economy	11700.00
0005432611707	3502	Economy	11700.00
0005435626162	3502	Economy	11700.00
0005434878180	3502	Economy	11700.00
0005434878174	3502	Economy	11700.00
0005434878113	3502	Economy	11700.00
0005435626152	3502	Economy	11700.00
0005434878107	3502	Economy	11700.00
0005435126321	3502	Economy	11700.00
0005434426580	3502	Economy	11700.00
0005434938124	3502	Economy	11700.00
0005434878125	3502	Economy	11700.00
0005434938117	3502	Economy	11700.00
0005435626156	3502	Economy	11700.00
0005435126343	3502	Economy	11700.00
0005432799432	3502	Economy	11700.00
0005434938131	3502	Economy	11700.00
0005435126335	3502	Economy	11700.00
0005434878152	3502	Economy	11700.00
0005434878163	3502	Economy	11700.00
0005432799416	3502	Economy	11700.00
0005434878194	3502	Economy	11700.00
0005434878128	3502	Economy	11700.00
0005432799429	3502	Economy	11700.00
0005434426569	3502	Economy	11700.00
0005434878170	3502	Economy	11700.00
0005435126315	3502	Economy	11700.00
0005435126333	3502	Economy	11700.00
0005432613857	3502	Economy	11700.00
0005434426592	3502	Economy	11700.00
0005434878192	3502	Economy	11700.00
0005432613856	3502	Economy	11700.00
0005432799438	3502	Economy	11700.00
0005434426597	3502	Economy	11700.00
0005435626147	3502	Economy	11700.00
0005435902457	3502	Economy	11700.00
0005435126340	3502	Economy	11700.00
0005432188604	3502	Economy	11700.00
0005434878127	3502	Economy	11700.00
0005435126328	3502	Economy	11700.00
0005434878129	3502	Economy	11700.00
0005435626155	3502	Economy	11700.00
0005434878126	3502	Economy	11700.00
0005434878119	3502	Economy	11700.00
0005434426573	3502	Economy	11700.00
0005435126329	3502	Economy	11700.00
0005435126338	3502	Economy	11700.00
0005435841092	3502	Economy	11700.00
0005434878184	3502	Economy	11700.00
0005435902585	3502	Economy	11700.00
0005432799437	3502	Economy	11700.00
0005432799425	3502	Economy	11700.00
0005434426576	3502	Economy	11700.00
0005434878164	3502	Economy	11700.00
0005432611706	3502	Economy	11700.00
0005432183465	3502	Economy	11700.00
0005434426578	3502	Economy	11700.00
0005435902477	3502	Economy	11700.00
0005432799422	3502	Economy	12800.00
0005434878143	3502	Economy	12800.00
0005434938122	3502	Economy	12800.00
0005435626158	3502	Economy	12800.00
0005432613859	3502	Economy	11700.00
0005434878181	3502	Economy	11700.00
0005434878176	3502	Economy	11700.00
0005434878120	3502	Economy	11700.00
0005434878147	3502	Economy	11700.00
0005435902586	3502	Economy	11700.00
0005434426570	3502	Economy	11700.00
0005432611705	3502	Economy	11700.00
0005434426583	3502	Economy	11700.00
0005434878157	3502	Economy	11700.00
0005434878106	3502	Economy	11700.00
0005434426594	3502	Economy	11700.00
0005435626151	3502	Economy	11700.00
0005435902458	3502	Economy	11700.00
0005435902544	3502	Economy	11700.00
0005435913889	3502	Economy	11700.00
0005434878149	3502	Economy	11700.00
0005434878169	3502	Economy	11700.00
0005434878167	3502	Economy	11700.00
0005434878196	3502	Economy	11700.00
0005434878118	3502	Economy	11700.00
0005434878108	3502	Economy	11700.00
0005432799434	3502	Economy	11700.00
0005435126318	3502	Economy	11700.00
0005434426590	3502	Economy	11700.00
0005434878132	3502	Economy	11700.00
0005434938125	3502	Economy	11700.00
0005432183464	3502	Economy	11700.00
0005434426574	3502	Economy	11700.00
0005434878124	3502	Economy	11700.00
0005434878183	3502	Economy	11700.00
0005434878145	3502	Economy	11700.00
0005435126323	3502	Economy	11700.00
0005435626149	3502	Economy	11700.00
0005434938120	3502	Economy	11700.00
0005435902528	3502	Economy	11700.00
0005435126346	3502	Economy	11700.00
0005435913890	3502	Economy	11700.00
0005432799423	3502	Economy	11700.00
0005435126327	3502	Economy	11700.00
0005434878162	3502	Economy	11700.00
0005434878187	3502	Economy	11700.00
0005435902493	3502	Economy	11700.00
0005432611708	3502	Economy	11700.00
0005432611709	3502	Economy	11700.00
0005434938116	3502	Economy	11700.00
0005435902572	3502	Economy	11700.00
0005434878131	3502	Economy	11700.00
0005435913871	3502	Economy	11700.00
0005435126314	3502	Economy	11700.00
0005435902548	3502	Economy	11700.00
0005435626154	3502	Economy	11700.00
0005432799439	3502	Economy	11700.00
0005432799441	3502	Economy	11700.00
0005435126322	3502	Economy	11700.00
0005434938118	3502	Economy	11700.00
0005434426591	3502	Economy	11700.00
0005434426568	3502	Economy	11700.00
0005434426587	3502	Economy	11700.00
0005434426572	3502	Economy	11700.00
0005435626150	3502	Economy	11700.00
0005434878186	3502	Economy	11700.00
0005434878195	3502	Economy	11700.00
0005432799419	3502	Economy	11700.00
0005434878138	3502	Economy	11700.00
0005434878117	3502	Economy	11700.00
0005434878144	3502	Economy	11700.00
0005434878200	3502	Economy	11700.00
0005434938119	3502	Economy	11700.00
0005434426588	3502	Economy	11700.00
0005434938121	3502	Economy	11700.00
0005434938128	3502	Economy	11700.00
0005434878201	3502	Economy	11700.00
0005434426586	3502	Economy	11700.00
0005435126337	3502	Economy	11700.00
0005435126324	3502	Economy	11700.00
0005434878168	3502	Economy	11700.00
0005434878158	3502	Economy	11700.00
0005434878134	3502	Economy	11700.00
0005435126347	3502	Economy	11700.00
0005434878185	3502	Economy	11700.00
0005434878182	3502	Economy	11700.00
0005435125942	14559	Business	35000.00
0005434877246	14559	Business	35000.00
0005435902690	14559	Business	35000.00
0005434877833	14559	Business	35000.00
0005432799158	14559	Business	35000.00
0005432799159	14559	Business	35000.00
0005434877418	14559	Business	35000.00
0005434877093	14559	Business	35000.00
0005434877639	14559	Business	35000.00
0005435625949	14559	Business	35000.00
0005434426207	14559	Business	35000.00
0005435125964	14559	Business	35000.00
0005435125961	14559	Business	35000.00
0005434877314	14559	Business	35000.00
0005435125989	14559	Business	35000.00
0005435126035	14559	Business	35000.00
0005434937901	14559	Business	35000.00
0005434426406	14559	Business	35000.00
0005434877092	14559	Business	35000.00
0005435625982	14559	Business	35000.00
0005434937991	14559	Comfort	19900.00
0005435625988	14559	Business	35000.00
0005434426228	14559	Comfort	19900.00
0005434877223	14559	Comfort	19900.00
0005435125946	14559	Comfort	19900.00
0005434877687	14559	Comfort	19900.00
0005434877303	14559	Comfort	19900.00
0005435625963	14559	Comfort	19900.00
0005435625991	14559	Comfort	19900.00
0005435126100	14559	Comfort	19900.00
0005434426420	14559	Comfort	19900.00
0005434877516	14559	Comfort	19900.00
0005434877638	14559	Comfort	19900.00
0005434877562	14559	Comfort	19900.00
0005435625966	14559	Comfort	19900.00
0005432799084	14559	Comfort	19900.00
0005434426311	14559	Comfort	19900.00
0005434937986	14559	Comfort	19900.00
0005434938017	14559	Comfort	19900.00
0005435125944	14559	Comfort	19900.00
0005432799298	14559	Comfort	19900.00
0005435125977	14559	Comfort	19900.00
0005435902678	14559	Comfort	19900.00
0005435902688	14559	Comfort	19900.00
0005434877300	14559	Comfort	19900.00
0005434877012	14559	Comfort	19900.00
0005435125848	14559	Comfort	19900.00
0005434877222	14559	Comfort	19900.00
0005434877082	14559	Comfort	19900.00
0005435125837	14559	Comfort	19900.00
0005434877280	14559	Comfort	19900.00
0005435625955	14559	Comfort	19900.00
0005434877324	14559	Comfort	19900.00
0005435902679	14559	Comfort	19900.00
0005434426368	14559	Comfort	19900.00
0005432799170	14559	Comfort	19900.00
0005432799259	14559	Comfort	19900.00
0005434426307	14559	Comfort	19900.00
0005434426236	14559	Economy	11700.00
0005434877309	14559	Economy	11700.00
0005434877126	14559	Economy	11700.00
0005434426326	14559	Economy	11700.00
0005435126037	14559	Economy	11700.00
0005434937902	14559	Economy	11700.00
0005435125868	14559	Economy	11700.00
0005434877013	14559	Economy	11700.00
0005434877389	14559	Economy	11700.00
0005435125960	14559	Economy	11700.00
0005434877518	14559	Economy	11700.00
0005434877490	14559	Economy	11700.00
0005435125990	14559	Economy	11700.00
0005434877331	14559	Economy	11700.00
0005434877675	14559	Economy	11700.00
0005434877606	14559	Economy	11700.00
0005435126112	14559	Economy	11700.00
0005434877724	14559	Economy	11700.00
0005432611668	14559	Economy	11700.00
0005435126061	14559	Economy	11700.00
0005434937948	14559	Economy	11700.00
0005435125888	14559	Economy	11700.00
0005435913930	14559	Economy	11700.00
0005434877351	14559	Economy	11700.00
0005434426162	14559	Economy	11700.00
0005434877588	14559	Economy	11700.00
0005434937962	14559	Economy	11700.00
0005432611671	14559	Economy	11700.00
0005434937939	14559	Economy	11700.00
0005435902691	14559	Economy	11700.00
0005435902684	14559	Economy	11700.00
0005434877310	14559	Economy	11700.00
0005434426365	14559	Economy	11700.00
0005434877281	14559	Economy	11700.00
0005434877832	14559	Economy	11700.00
0005434877459	14559	Economy	11700.00
0005432611669	14559	Economy	11700.00
0005435902676	14559	Economy	11700.00
0005434877431	14559	Economy	11700.00
0005434938002	14559	Economy	11700.00
0005434426411	14559	Economy	11700.00
0005434877674	14559	Economy	11700.00
0005434426410	14559	Economy	11700.00
0005434426347	14559	Economy	11700.00
0005434426270	14559	Economy	11700.00
0005434877030	14559	Economy	11700.00
0005435625990	14559	Economy	11700.00
0005435902685	14559	Economy	11700.00
0005432799133	14559	Economy	12800.00
0005434426230	14559	Economy	12800.00
0005432611667	14559	Economy	12800.00
0005432799207	14559	Economy	11700.00
0005435126041	14559	Economy	11700.00
0005432607533	14559	Economy	12800.00
0005432799210	14559	Economy	11700.00
0005434877352	14559	Economy	12800.00
0005432799217	14559	Economy	12800.00
0005434426281	14559	Economy	11700.00
0005435902682	14559	Economy	11700.00
0005434426283	14559	Economy	11700.00
0005434877403	14559	Economy	11700.00
0005435625936	14559	Economy	11700.00
0005432059503	14559	Economy	11700.00
0005435902680	14559	Economy	11700.00
0005434877235	14559	Economy	11700.00
0005434937970	14559	Economy	11700.00
0005434877298	14559	Economy	11700.00
0005434937992	14559	Economy	11700.00
0005435126101	14559	Economy	11700.00
0005434877247	14559	Economy	11700.00
0005432799209	14559	Economy	11700.00
0005435125880	14559	Economy	11700.00
0005434877217	14559	Economy	11700.00
0005432607529	14559	Economy	11700.00
0005432607534	14559	Economy	11700.00
0005434877517	14559	Economy	11700.00
0005435902675	14559	Economy	11700.00
0005434877216	14559	Economy	11700.00
0005435625928	14559	Economy	11700.00
0005434876666	14559	Economy	11700.00
0005434877261	14559	Economy	11700.00
0005434426206	14559	Economy	11700.00
0005434877702	14559	Economy	11700.00
0005434426205	14559	Economy	11700.00
0005434877566	14559	Economy	11700.00
0005435126036	14559	Economy	11700.00
0005434877218	14559	Economy	11700.00
0005434877488	14559	Economy	11700.00
0005432799109	14559	Economy	11700.00
0005434937987	14559	Economy	11700.00
0005434877124	14559	Economy	11700.00
0005435125976	14559	Economy	11700.00
0005434426419	14559	Economy	11700.00
0005435902693	14559	Economy	11700.00
0005435902692	14559	Economy	11700.00
0005434877479	14559	Economy	11700.00
0005434877219	14559	Economy	11700.00
0005434877428	14559	Economy	11700.00
0005435625986	14559	Economy	11700.00
0005435902686	14559	Economy	11700.00
0005434426338	14559	Economy	11700.00
0005434937997	14559	Economy	11700.00
0005434937969	14559	Economy	11700.00
0005434426344	14559	Economy	11700.00
0005432799161	14559	Economy	11700.00
0005434877509	14559	Economy	11700.00
0005434877325	14559	Economy	11700.00
0005434877186	14559	Economy	11700.00
0005432799321	14559	Economy	11700.00
0005435625983	14559	Economy	11700.00
0005432611670	14559	Economy	11700.00
0005434877279	14559	Economy	11700.00
0005432799157	14559	Economy	11700.00
0005435625992	14559	Economy	11700.00
0005435125996	14559	Economy	11700.00
0005434937998	14559	Economy	11700.00
0005432799178	14559	Economy	11700.00
0005435913932	14559	Economy	11700.00
0005435126018	14559	Economy	11700.00
0005434426346	14559	Economy	11700.00
0005434426393	14559	Economy	11700.00
0005434877158	14559	Economy	11700.00
0005435126060	14559	Economy	11700.00
0005434426327	14559	Economy	11700.00
0005435126030	14559	Economy	11700.00
0005432799185	14559	Economy	11700.00
0005434426321	14559	Economy	11700.00
0005434426290	14559	Economy	11700.00
0005434426418	14559	Economy	11700.00
0005434426282	14559	Economy	11700.00
0005434877519	14559	Economy	11700.00
0005432607511	14559	Economy	11700.00
0005435126079	14559	Economy	11700.00
0005435125859	14559	Economy	11700.00
0005434877809	14559	Economy	11700.00
0005434426310	14559	Economy	11700.00
0005434877388	14559	Economy	11700.00
0005434877011	14559	Economy	11700.00
0005435842327	14559	Economy	11700.00
0005434877494	14559	Economy	11700.00
0005434938018	14559	Economy	11700.00
0005434876976	14559	Economy	11700.00
0005432799156	14559	Economy	11700.00
0005432799244	14559	Economy	11700.00
0005435625939	14559	Economy	11700.00
0005434937947	14559	Economy	11700.00
0005435125829	14559	Economy	11700.00
0005434877657	14559	Economy	11700.00
0005434877457	14559	Economy	11700.00
0005434426383	14559	Economy	11700.00
0005434937971	14559	Economy	11700.00
0005434937963	14559	Economy	11700.00
0005435126013	14559	Economy	12800.00
0005434877510	14559	Economy	12800.00
0005435902683	14559	Economy	12800.00
0005435125903	14559	Economy	12800.00
0005434426466	14559	Economy	11700.00
0005434937993	14559	Economy	11700.00
0005432799087	14559	Economy	11700.00
0005434877179	14559	Economy	11700.00
0005432799045	14559	Economy	11700.00
0005434877473	14559	Economy	11700.00
0005434938001	14559	Economy	11700.00
0005435125975	14559	Economy	11700.00
0005434877398	14559	Economy	11700.00
0005434877382	14559	Economy	11700.00
0005435902681	14559	Economy	11700.00
0005434877304	14559	Economy	11700.00
0005435902687	14559	Economy	11700.00
0005434877041	14559	Economy	11700.00
0005435625987	14559	Economy	11700.00
0005434877508	14559	Economy	11700.00
0005435625892	14559	Economy	11700.00
0005434877042	14559	Economy	11700.00
0005435126074	14559	Economy	11700.00
0005432799208	14559	Economy	11700.00
0005434938035	14559	Economy	11700.00
0005434426381	14559	Economy	11700.00
0005435625984	14559	Economy	11700.00
0005435125838	14559	Economy	11700.00
0005434426380	14559	Economy	11700.00
0005434877442	14559	Economy	11700.00
0005435625967	14559	Economy	11700.00
0005434877432	14559	Economy	11700.00
0005435126014	14559	Economy	11700.00
0005434877808	14559	Economy	11700.00
0005435902677	14559	Economy	11700.00
0005434877125	14559	Economy	11700.00
0005434877834	14559	Economy	11700.00
0005435125970	14559	Economy	11700.00
0005435125978	14559	Economy	11700.00
0005435913931	14559	Economy	11700.00
0005435125945	14559	Economy	11700.00
0005434426284	14559	Economy	11700.00
0005434877411	14559	Economy	11700.00
0005435125826	14559	Economy	11700.00
0005434877616	14559	Economy	11700.00
0005435625950	14559	Economy	11700.00
0005435625938	14559	Economy	11700.00
0005434937994	14559	Economy	11700.00
0005434876960	14559	Economy	11700.00
0005434877710	14559	Economy	11700.00
0005435125858	14559	Economy	11700.00
0005434877456	14559	Economy	11700.00
0005434877538	14559	Economy	11700.00
0005432607528	14559	Economy	11700.00
0005432799320	14559	Economy	11700.00
0005434877472	14559	Economy	11700.00
0005432059502	14559	Economy	11700.00
0005435126001	14559	Economy	11700.00
0005434426394	14559	Economy	11700.00
0005435126012	14559	Economy	11700.00
0005434877408	14559	Economy	11700.00
0005434426387	14559	Economy	11700.00
0005434426427	14559	Economy	11700.00
0005434877333	14559	Economy	11700.00
0005435125865	14559	Economy	11700.00
0005435125951	14559	Economy	11700.00
0005434877539	14559	Economy	11700.00
0005434426386	14559	Economy	11700.00
0005435126116	14559	Economy	11700.00
0005434426367	14559	Economy	11700.00
0005435125902	14559	Economy	11700.00
0005435625968	14559	Economy	11700.00
0005432059501	14559	Economy	11700.00
0005434877376	14559	Economy	11700.00
0005434877701	14559	Economy	11700.00
0005434877224	14559	Economy	11700.00
0005434426300	14559	Economy	11700.00
0005434877375	14559	Economy	11700.00
0005434937929	14559	Economy	11700.00
0005434877640	14559	Economy	11700.00
0005434877688	14559	Economy	11700.00
0005434877187	14559	Economy	11700.00
0005434426308	14559	Economy	11700.00
0005435902689	14559	Economy	11700.00
0005434325639	3587	Economy	16300.00
0005434312317	3587	Economy	16300.00
0005434312316	3587	Economy	14800.00
0005434325641	3587	Economy	14800.00
0005435889847	3587	Economy	14800.00
0005434325635	3587	Economy	14800.00
0005434325643	3587	Economy	14800.00
0005435889819	3587	Economy	14800.00
0005434325642	3587	Economy	14800.00
0005434325638	3587	Economy	14800.00
0005435889848	3587	Economy	14800.00
0005434325633	3587	Economy	14800.00
0005434325640	3587	Economy	14800.00
0005434325632	3587	Economy	14800.00
0005435889820	3587	Economy	14800.00
0005435889834	3587	Economy	14800.00
0005434325637	3587	Economy	14800.00
0005434325636	3587	Economy	14800.00
0005435889829	3587	Economy	14800.00
0005434325634	3587	Economy	14800.00
0005434325571	15621	Economy	16300.00
0005434325562	15621	Economy	16300.00
0005435889891	15621	Economy	14800.00
0005434325567	15621	Economy	14800.00
0005435889888	15621	Economy	14800.00
0005434325591	15621	Economy	14800.00
0005434325572	15621	Economy	14800.00
0005434325540	15621	Economy	14800.00
0005434325569	15621	Economy	14800.00
0005434325590	15621	Economy	14800.00
0005435889887	15621	Economy	14800.00
0005434325566	15621	Economy	14800.00
0005435889890	15621	Economy	14800.00
0005434325570	15621	Economy	14800.00
0005434325537	15621	Economy	14800.00
0005434325516	15621	Economy	14800.00
0005435889889	15621	Economy	14800.00
0005434325589	15621	Economy	14800.00
0005435889892	15621	Economy	14800.00
0005435957693	625	Economy	4500.00
0005435957687	625	Economy	4500.00
0005433420304	625	Economy	4500.00
0005435957681	625	Economy	4100.00
0005433420342	625	Economy	4100.00
0005433420305	625	Economy	4100.00
0005435957692	625	Economy	4100.00
0005433420350	625	Economy	4100.00
0005435957683	625	Economy	4100.00
0005435957680	625	Economy	4100.00
0005435957686	625	Economy	4100.00
0005435957684	625	Economy	4100.00
0005435957696	625	Economy	4100.00
0005433420348	625	Economy	4100.00
0005435957688	625	Economy	4100.00
0005435957682	625	Economy	4100.00
0005433420287	625	Economy	4100.00
0005433420349	625	Economy	4100.00
0005435957689	625	Economy	4100.00
0005435957690	625	Economy	4100.00
0005435957695	625	Economy	4100.00
0005435957694	625	Economy	4100.00
0005435957685	625	Economy	4100.00
0005435957691	625	Economy	4100.00
0005433420339	625	Economy	4100.00
0005435957500	15201	Economy	4500.00
0005435957538	15201	Economy	4500.00
0005435957605	15201	Economy	4500.00
0005435957550	15201	Economy	4100.00
0005433420396	15201	Economy	4100.00
0005435957533	15201	Economy	4100.00
0005433420392	15201	Economy	4100.00
0005433420395	15201	Economy	4100.00
0005435957606	15201	Economy	4100.00
0005435957564	15201	Economy	4100.00
0005435957578	15201	Economy	4100.00
0005435957552	15201	Economy	4100.00
0005435957603	15201	Economy	4100.00
0005435957528	15201	Economy	4100.00
0005435957522	15201	Economy	4100.00
0005433420391	15201	Economy	4100.00
0005435957541	15201	Economy	4100.00
0005435957614	15201	Economy	4100.00
0005435957634	15201	Economy	4100.00
0005435957557	15201	Economy	4100.00
0005435957566	15201	Economy	4100.00
0005435957527	15201	Economy	4100.00
0005435957499	15201	Economy	4100.00
0005435957558	15201	Economy	4100.00
0005433420394	15201	Economy	4100.00
0005433420397	15201	Economy	4100.00
0005435957556	15201	Economy	4100.00
0005435957501	15201	Economy	4100.00
0005433420393	15201	Economy	4100.00
0005433420390	15201	Economy	4100.00
0005435957602	15201	Economy	4100.00
0005434247118	8851	Economy	10400.00
0005434247116	8851	Economy	10400.00
0005434247119	8851	Economy	10400.00
0005434247144	16050	Economy	10400.00
0005434247145	16050	Economy	10400.00
0005434247143	16050	Economy	10400.00
0005435629397	16050	Economy	10400.00
0005434096719	11822	Economy	14700.00
0005434096724	11822	Economy	13400.00
0005434096714	11822	Economy	13400.00
0005434096711	11822	Economy	13400.00
0005434096720	11822	Economy	13400.00
0005434096718	11822	Economy	13400.00
0005434096715	11822	Economy	13400.00
0005434096710	11822	Economy	13400.00
0005434096709	11822	Economy	13400.00
0005435163224	4443	Economy	13400.00
0005435163229	4443	Economy	12200.00
0005435163230	4443	Economy	12200.00
0005435163225	4443	Economy	12200.00
0005435933411	4443	Economy	12200.00
0005435163227	4443	Economy	12200.00
0005435163228	4443	Economy	12200.00
0005435163226	4443	Economy	12200.00
0005435933428	4443	Economy	12200.00
0005435933420	4443	Economy	12200.00
0005435163220	4443	Economy	12200.00
0005435163222	4443	Economy	12200.00
0005435933426	4443	Economy	12200.00
0005435163223	4443	Economy	12200.00
0005435933412	4443	Economy	12200.00
0005435933413	4443	Economy	12200.00
0005435933419	4443	Economy	12200.00
0005435163221	4443	Economy	12200.00
0005435933432	4443	Economy	12200.00
0005435163168	29525	Economy	13400.00
0005435163163	29525	Economy	13400.00
0005435933450	29525	Economy	12200.00
0005435933453	29525	Economy	12200.00
0005435933449	29525	Economy	12200.00
0005435163172	29525	Economy	12200.00
0005435933447	29525	Economy	12200.00
0005435163170	29525	Economy	12200.00
0005435163184	29525	Economy	12200.00
0005435163199	29525	Economy	12200.00
0005435163175	29525	Economy	12200.00
0005435163192	29525	Economy	12200.00
0005435163193	29525	Economy	12200.00
0005435163189	29525	Economy	12200.00
0005435933446	29525	Economy	12200.00
0005435163162	29525	Economy	12200.00
0005435163173	29525	Economy	12200.00
0005435163174	29525	Economy	12200.00
0005435163171	29525	Economy	12200.00
0005435163169	29525	Economy	12200.00
0005435163181	29525	Economy	12200.00
0005435933452	29525	Economy	12200.00
0005435163180	29525	Economy	12200.00
0005435933451	29525	Economy	12200.00
0005435163198	29525	Economy	12200.00
0005435933448	29525	Economy	12200.00
0005435797463	2884	Business	12600.00
0005433404774	2884	Business	12600.00
0005435797467	2884	Business	12600.00
0005435797453	2884	Business	12600.00
0005435797464	2884	Economy	4200.00
0005433404762	2884	Economy	4200.00
0005435797458	2884	Economy	4600.00
0005435797454	2884	Economy	4200.00
0005435797457	2884	Economy	4200.00
0005433404754	2884	Economy	4200.00
0005433404753	2884	Economy	4200.00
0005435797462	2884	Economy	4200.00
0005435797461	2884	Economy	4200.00
0005433404729	2884	Economy	4200.00
0005435797456	2884	Economy	4200.00
0005435797459	2884	Economy	4200.00
0005435797466	2884	Economy	4200.00
0005435797455	2884	Economy	4200.00
0005433404722	2884	Economy	4200.00
0005435797465	2884	Economy	4200.00
0005435797460	2884	Economy	4200.00
0005435797364	29337	Business	12600.00
0005433404798	29337	Economy	4200.00
0005435797348	29337	Economy	4200.00
0005433404799	29337	Economy	4600.00
0005435797339	29337	Economy	4200.00
0005435797378	29337	Economy	4200.00
0005435797370	29337	Economy	4200.00
0005433404803	29337	Economy	4200.00
0005433404800	29337	Economy	4200.00
0005435797346	29337	Economy	4200.00
0005433404802	29337	Economy	4200.00
0005435797389	29337	Economy	4200.00
0005435797365	29337	Economy	4200.00
0005435797271	29337	Economy	4200.00
0005435797371	29337	Economy	4200.00
0005435797350	29337	Economy	4200.00
0005433404805	29337	Economy	4200.00
0005433404801	29337	Economy	4200.00
0005433404804	29337	Economy	4200.00
0005435797351	29337	Economy	4200.00
0005435376334	5799	Economy	6800.00
0005435376330	5799	Economy	6800.00
0005435376335	5799	Economy	6800.00
0005435376329	5799	Economy	6800.00
0005435376333	5799	Economy	6800.00
0005434948011	5800	Economy	6800.00
0005434948015	5800	Economy	6800.00
0005434948016	5800	Economy	6800.00
0005434948012	5800	Economy	6800.00
0005434948017	5800	Economy	6800.00
0005434948009	5800	Economy	6800.00
0005434948010	5800	Economy	6800.00
0005434948014	5800	Economy	6800.00
0005434948013	5800	Economy	6800.00
0005434948018	5800	Economy	6800.00
0005434947950	16361	Economy	6800.00
0005434947938	16361	Economy	6800.00
0005434947953	16361	Economy	6800.00
0005434947951	16361	Economy	6800.00
0005434947915	16361	Economy	6800.00
0005434947945	16361	Economy	6800.00
0005434947952	16361	Economy	6800.00
0005434947946	16361	Economy	6800.00
0005434947924	16361	Economy	6800.00
0005434947949	16361	Economy	6800.00
0005433960831	6861	Business	21400.00
0005433960813	6861	Business	21400.00
0005433960803	6861	Business	21400.00
0005433960799	6861	Business	21400.00
0005433960842	6861	Business	21400.00
0005433960840	6861	Business	21400.00
0005433960819	6861	Business	21400.00
0005433960795	6861	Business	21400.00
0005433960802	6861	Economy	7100.00
0005433960843	6861	Economy	7100.00
0005433960797	6861	Economy	7100.00
0005433960821	6861	Economy	7100.00
0005433960793	6861	Economy	7100.00
0005433960814	6861	Economy	7100.00
0005433960841	6861	Economy	7800.00
0005433960838	6861	Economy	7800.00
0005433960844	6861	Economy	7800.00
0005433960800	6861	Economy	7100.00
0005433960829	6861	Economy	7100.00
0005433960807	6861	Economy	7100.00
0005433960805	6861	Economy	7100.00
0005433960836	6861	Economy	7100.00
0005433960818	6861	Economy	7100.00
0005433960804	6861	Economy	7100.00
0005433960822	6861	Economy	7100.00
0005433960848	6861	Economy	7100.00
0005433960826	6861	Economy	7100.00
0005433960794	6861	Economy	7100.00
0005433960833	6861	Economy	7100.00
0005433960832	6861	Economy	7100.00
0005433960849	6861	Economy	7100.00
0005433960816	6861	Economy	7100.00
0005433960809	6861	Economy	7100.00
0005433960827	6861	Economy	7100.00
0005433960806	6861	Economy	7100.00
0005433960815	6861	Economy	7100.00
0005433960846	6861	Economy	7100.00
0005433960828	6861	Economy	7100.00
0005433960837	6861	Economy	7100.00
0005433960817	6861	Economy	7100.00
0005433960839	6861	Economy	7100.00
0005433960811	6861	Economy	7100.00
0005433960812	6861	Economy	7100.00
0005433960808	6861	Economy	7100.00
0005433960796	6861	Economy	7100.00
0005433960820	6861	Economy	7100.00
0005433960825	6861	Economy	7100.00
0005433960830	6861	Economy	7100.00
0005433960824	6861	Economy	7100.00
0005433960834	6861	Economy	7100.00
0005433960798	6861	Economy	7100.00
0005433960823	6861	Economy	7100.00
0005433960801	6861	Economy	7100.00
0005433960810	6861	Economy	7100.00
0005433960835	6861	Economy	7100.00
0005433960847	6861	Economy	7100.00
0005433960850	6861	Economy	7100.00
0005433960845	6861	Economy	7100.00
0005433960203	25734	Business	21400.00
0005433960081	25734	Business	21400.00
0005433960194	25734	Business	21400.00
0005433960062	25734	Business	21400.00
0005433960132	25734	Business	21400.00
0005433959856	25734	Business	21400.00
0005433960161	25734	Business	21400.00
0005433959983	25734	Business	21400.00
0005433960064	25734	Economy	7100.00
0005433960065	25734	Economy	7100.00
0005433959998	25734	Economy	7100.00
0005433960097	25734	Economy	7100.00
0005433960175	25734	Economy	7100.00
0005433960047	25734	Economy	7100.00
0005433959858	25734	Economy	7800.00
0005433960169	25734	Economy	7800.00
0005433960052	25734	Economy	7800.00
0005433960221	25734	Economy	7800.00
0005433960126	25734	Economy	7100.00
0005433960184	25734	Economy	7100.00
0005433960218	25734	Economy	7100.00
0005433960207	25734	Economy	7100.00
0005433960181	25734	Economy	7100.00
0005433960164	25734	Economy	7100.00
0005433960133	25734	Economy	7100.00
0005433960205	25734	Economy	7100.00
0005433960154	25734	Economy	7100.00
0005433960202	25734	Economy	7100.00
0005433960008	25734	Economy	7100.00
0005433960183	25734	Economy	7100.00
0005433959991	25734	Economy	7100.00
0005433960029	25734	Economy	7100.00
0005433960048	25734	Economy	7100.00
0005433960123	25734	Economy	7100.00
0005433960085	25734	Economy	7100.00
0005433960206	25734	Economy	7100.00
0005433960091	25734	Economy	7100.00
0005433960086	25734	Economy	7100.00
0005433960049	25734	Economy	7100.00
0005433960198	25734	Economy	7100.00
0005433960099	25734	Economy	7100.00
0005433960174	25734	Economy	7100.00
0005433960098	25734	Economy	7100.00
0005433960139	25734	Economy	7100.00
0005433960067	25734	Economy	7100.00
0005433960054	25734	Economy	7100.00
0005433960088	25734	Economy	7100.00
0005433960127	25734	Economy	7100.00
0005433959997	25734	Economy	7100.00
0005433960196	25734	Economy	7100.00
0005433960100	25734	Economy	7100.00
0005433960153	25734	Economy	7100.00
0005433960178	25734	Economy	7100.00
0005433960117	25734	Economy	7100.00
0005433960199	25734	Economy	7100.00
0005433960211	25734	Economy	7100.00
0005433960055	25734	Economy	7100.00
0005433959857	25734	Economy	7100.00
0005433959892	25734	Economy	7100.00
0005433960193	25734	Economy	7100.00
0005433960173	25734	Economy	7100.00
0005433960120	25734	Economy	7100.00
0005433960082	25734	Economy	7100.00
0005433960172	25734	Economy	7100.00
0005433960168	25734	Economy	7100.00
0005433960179	25734	Economy	7100.00
0005433960162	25734	Economy	7100.00
0005433960222	25734	Economy	7100.00
0005433960134	25734	Economy	7100.00
0005435082714	24524	Economy	3900.00
0005435082684	24524	Economy	3900.00
0005435082688	24524	Economy	3900.00
0005435082689	24524	Economy	3900.00
0005435082708	24524	Economy	3900.00
0005435082722	24524	Economy	3900.00
0005435082706	24524	Economy	3900.00
0005435082707	24524	Economy	3900.00
0005435082774	26066	Economy	3900.00
0005435082777	26066	Economy	3900.00
0005435082772	26066	Economy	3900.00
0005435082773	26066	Economy	3900.00
0005435082771	26066	Economy	3900.00
0005435082776	26066	Economy	3900.00
0005435082775	26066	Economy	3900.00
0005434244946	5143	Business	18000.00
0005434244962	5143	Business	18000.00
0005435286578	5143	Business	18000.00
0005434244942	5143	Business	18000.00
0005434244938	5143	Business	18000.00
0005434244935	5143	Business	18000.00
0005434244944	5143	Economy	6600.00
0005434244952	5143	Economy	6000.00
0005434244964	5143	Economy	6000.00
0005434244958	5143	Economy	6000.00
0005434244936	5143	Economy	6000.00
0005434244950	5143	Economy	6000.00
0005433534472	5143	Economy	6000.00
0005434244945	5143	Economy	6000.00
0005434244940	5143	Economy	6000.00
0005434244954	5143	Economy	6000.00
0005434244953	5143	Economy	6000.00
0005434244939	5143	Economy	6000.00
0005434244960	5143	Economy	6000.00
0005434244955	5143	Economy	6000.00
0005434244948	5143	Economy	6000.00
0005434244943	5143	Economy	6000.00
0005434244956	5143	Economy	6000.00
0005433534485	5143	Economy	6000.00
0005434244941	5143	Economy	6000.00
0005434244947	5143	Economy	6000.00
0005435286572	5143	Economy	6000.00
0005434244951	5143	Economy	6000.00
0005434244963	5143	Economy	6000.00
0005432166899	5143	Economy	6000.00
0005434244961	5143	Economy	6000.00
0005432166898	5143	Economy	6000.00
0005434244937	5143	Economy	6000.00
0005435286571	5143	Economy	6000.00
0005434244957	5143	Economy	6000.00
0005434244959	5143	Economy	6000.00
0005434244949	5143	Economy	6000.00
0005432667451	5146	Business	18000.00
0005432105543	5146	Business	18000.00
0005432105499	5146	Business	18000.00
0005432105501	5146	Business	18000.00
0005433614589	5146	Business	18000.00
0005433614654	5146	Business	18000.00
0005432105530	5146	Business	18000.00
0005433784904	5146	Business	18000.00
0005432105527	5146	Business	18000.00
0005433784901	5146	Business	18000.00
0005433614642	5146	Business	18000.00
0005432105523	5146	Business	18000.00
0005433614626	5146	Business	18000.00
0005433614611	5146	Business	18000.00
0005433614623	5146	Business	18000.00
0005432105503	5146	Business	18000.00
0005433614634	5146	Business	18000.00
0005432105540	5146	Business	18000.00
0005432105537	5146	Business	18000.00
0005433614639	5146	Business	18000.00
0005432105502	5146	Business	18000.00
0005433784921	5146	Business	18000.00
0005433614644	5146	Business	18000.00
0005433614635	5146	Business	18000.00
0005432105519	5146	Business	18000.00
0005433614601	5146	Business	18000.00
0005433614649	5146	Business	18000.00
0005433614641	5146	Business	18000.00
0005433784891	5146	Economy	6600.00
0005432105500	5146	Economy	6600.00
0005433614625	5146	Economy	6600.00
0005433784905	5146	Economy	6600.00
0005433614610	5146	Economy	6600.00
0005433614620	5146	Economy	6600.00
0005433784907	5146	Economy	6000.00
0005432105528	5146	Economy	6000.00
0005433784908	5146	Economy	6000.00
0005432666385	5146	Economy	6000.00
0005433614621	5146	Economy	6000.00
0005432105541	5146	Economy	6000.00
0005432105522	5146	Economy	6000.00
0005432667452	5146	Economy	6000.00
0005432105532	5146	Economy	6000.00
0005433614616	5146	Economy	6000.00
0005433614658	5146	Economy	6000.00
0005433614657	5146	Economy	6000.00
0005433614614	5146	Economy	6000.00
0005433784896	5146	Economy	6000.00
0005432105507	5146	Economy	6000.00
0005432105514	5146	Economy	6000.00
0005432105533	5146	Economy	6000.00
0005433614608	5146	Economy	6000.00
0005433614655	5146	Economy	6000.00
0005433784897	5146	Economy	6000.00
0005433784893	5146	Economy	6000.00
0005433614653	5146	Economy	6000.00
0005433614650	5146	Economy	6000.00
0005433614619	5146	Economy	6000.00
0005432105531	5146	Economy	6000.00
0005433614640	5146	Economy	6000.00
0005433784915	5146	Economy	6000.00
0005433614651	5146	Economy	6000.00
0005433784913	5146	Economy	6000.00
0005432105498	5146	Economy	6000.00
0005433784898	5146	Economy	6000.00
0005433614631	5146	Economy	6000.00
0005432105520	5146	Economy	6000.00
0005433614637	5146	Economy	6000.00
0005432105497	5146	Economy	6000.00
0005433614613	5146	Economy	6000.00
0005433784912	5146	Economy	6000.00
0005433784894	5146	Economy	6000.00
0005432105512	5146	Economy	6000.00
0005432145110	5146	Economy	6000.00
0005432665272	5146	Economy	6000.00
0005433614606	5146	Economy	6000.00
0005433784892	5146	Economy	6000.00
0005433784916	5146	Economy	6000.00
0005433614648	5146	Economy	6000.00
0005433614590	5146	Economy	6000.00
0005433784887	5146	Economy	6000.00
0005433614587	5146	Economy	6000.00
0005433614603	5146	Economy	6000.00
0005433614617	5146	Economy	6000.00
0005432105529	5146	Economy	6000.00
0005433614607	5146	Economy	6000.00
0005433614598	5146	Economy	6000.00
0005432105510	5146	Economy	6000.00
0005433614638	5146	Economy	6000.00
0005433614647	5146	Economy	6000.00
0005433614596	5146	Economy	6000.00
0005433614594	5146	Economy	6000.00
0005432105509	5146	Economy	6000.00
0005432105521	5146	Economy	6000.00
0005433784919	5146	Economy	6600.00
0005432105524	5146	Economy	6600.00
0005433784911	5146	Economy	6600.00
0005433614609	5146	Economy	6600.00
0005433784922	5146	Economy	6000.00
0005433614602	5146	Economy	6600.00
0005433784900	5146	Economy	6000.00
0005432105518	5146	Economy	6000.00
0005432105536	5146	Economy	6000.00
0005432105517	5146	Economy	6600.00
0005432105504	5146	Economy	6000.00
0005433614627	5146	Economy	6000.00
0005433614605	5146	Economy	6000.00
0005432105496	5146	Economy	6000.00
0005433614604	5146	Economy	6000.00
0005432105542	5146	Economy	6000.00
0005433784923	5146	Economy	6000.00
0005433614656	5146	Economy	6000.00
0005432105508	5146	Economy	6000.00
0005432105538	5146	Economy	6000.00
0005432105513	5146	Economy	6000.00
0005433614618	5146	Economy	6000.00
0005433784917	5146	Economy	6000.00
0005433614629	5146	Economy	6000.00
0005433614652	5146	Economy	6000.00
0005432105539	5146	Economy	6000.00
0005433614628	5146	Economy	6000.00
0005433614588	5146	Economy	6000.00
0005433614643	5146	Economy	6000.00
0005433614630	5146	Economy	6000.00
0005433614595	5146	Economy	6000.00
0005432666386	5146	Economy	6000.00
0005433784903	5146	Economy	6000.00
0005432105526	5146	Economy	6000.00
0005433784890	5146	Economy	6000.00
0005433614636	5146	Economy	6000.00
0005433614624	5146	Economy	6000.00
0005433614599	5146	Economy	6000.00
0005433614646	5146	Economy	6000.00
0005433614591	5146	Economy	6000.00
0005433614593	5146	Economy	6000.00
0005432105505	5146	Economy	6000.00
0005433614586	5146	Economy	6000.00
0005432666387	5146	Economy	6000.00
0005433614600	5146	Economy	6000.00
0005433784914	5146	Economy	6000.00
0005433614622	5146	Economy	6000.00
0005433784888	5146	Economy	6000.00
0005432105544	5146	Economy	6000.00
0005433784895	5146	Economy	6000.00
0005432105506	5146	Economy	6000.00
0005433784910	5146	Economy	6000.00
0005433784902	5146	Economy	6000.00
0005433614597	5146	Economy	6000.00
0005433784899	5146	Economy	6000.00
0005433784920	5146	Economy	6000.00
0005433614612	5146	Economy	6000.00
0005432105534	5146	Economy	6000.00
0005433784889	5146	Economy	6000.00
0005432105515	5146	Economy	6000.00
0005433614615	5146	Economy	6000.00
0005433614633	5146	Economy	6000.00
0005432105516	5146	Economy	6000.00
0005433784918	5146	Economy	6000.00
0005433614585	5146	Economy	6000.00
0005433784906	5146	Economy	6000.00
0005432105525	5146	Economy	6000.00
0005433614584	5146	Economy	6000.00
0005433784909	5146	Economy	6000.00
0005432105495	5146	Economy	6000.00
0005432105511	5146	Economy	6000.00
0005433614632	5146	Economy	6000.00
0005433614645	5146	Economy	6000.00
0005433614592	5146	Economy	6000.00
0005432105535	5146	Economy	6000.00
0005435006742	5149	Business	18000.00
0005434265105	5149	Business	18000.00
0005435006773	5149	Business	18000.00
0005434265108	5149	Business	18000.00
0005435006903	5149	Business	18000.00
0005434265118	5149	Business	18000.00
0005434265120	5149	Business	18000.00
0005435006839	5149	Business	18000.00
0005433688794	5149	Business	18000.00
0005435006934	5149	Business	18000.00
0005432335900	5149	Business	18000.00
0005434265112	5149	Business	18000.00
0005434149718	5149	Business	18000.00
0005434229341	5149	Business	18000.00
0005432335907	5149	Business	18000.00
0005435006766	5149	Business	18000.00
0005434149723	5149	Business	18000.00
0005434229353	5149	Business	18000.00
0005435006838	5149	Business	18000.00
0005434265100	5149	Business	18000.00
0005434229340	5149	Business	18000.00
0005434265115	5149	Business	18000.00
0005432335956	5149	Economy	6600.00
0005434173517	5149	Economy	6600.00
0005432335924	5149	Economy	6600.00
0005434229342	5149	Economy	6600.00
0005434311196	5149	Economy	6600.00
0005434229346	5149	Economy	6000.00
0005434229356	5149	Economy	6000.00
0005434229338	5149	Economy	6000.00
0005433688793	5149	Economy	6000.00
0005434265099	5149	Economy	6000.00
0005432335988	5149	Economy	6000.00
0005433815339	5149	Economy	6000.00
0005433688786	5149	Economy	6000.00
0005432335888	5149	Economy	6000.00
0005433685497	5149	Economy	6000.00
0005434229345	5149	Economy	6000.00
0005435006812	5149	Economy	6000.00
0005434265110	5149	Economy	6000.00
0005434229355	5149	Economy	6000.00
0005434311195	5149	Economy	6000.00
0005434149713	5149	Economy	6000.00
0005432335923	5149	Economy	6000.00
0005435006945	5149	Economy	6000.00
0005434229350	5149	Economy	6000.00
0005435006746	5149	Economy	6000.00
0005434265124	5149	Economy	6000.00
0005434265123	5149	Economy	6000.00
0005434149715	5149	Economy	6000.00
0005432335895	5149	Economy	6000.00
0005434149714	5149	Economy	6000.00
0005434265101	5149	Economy	6000.00
0005433685496	5149	Economy	6000.00
0005432335887	5149	Economy	6000.00
0005434265102	5149	Economy	6000.00
0005434229337	5149	Economy	6000.00
0005434265114	5149	Economy	6000.00
0005435006710	5149	Economy	6000.00
0005434173515	5149	Economy	6000.00
0005432335905	5149	Economy	6000.00
0005434149717	5149	Economy	6000.00
0005435006782	5149	Economy	6000.00
0005432335901	5149	Economy	6000.00
0005432335913	5149	Economy	6000.00
0005435006797	5149	Economy	6000.00
0005434149722	5149	Economy	6000.00
0005434265104	5149	Economy	6000.00
0005435006853	5149	Economy	6000.00
0005432335889	5149	Economy	6000.00
0005434265122	5149	Economy	6600.00
0005433815324	5149	Economy	6600.00
0005434265109	5149	Economy	6600.00
0005434229339	5149	Economy	6000.00
0005435006801	5149	Economy	6000.00
0005434229348	5149	Economy	6000.00
0005434229357	5149	Economy	6600.00
0005434229349	5149	Economy	6000.00
0005434229351	5149	Economy	6000.00
0005435006779	5149	Economy	6000.00
0005432335909	5149	Economy	6000.00
0005435006747	5149	Economy	6000.00
0005435006717	5149	Economy	6000.00
0005435006820	5149	Economy	6000.00
0005434229358	5149	Economy	6000.00
0005435006819	5149	Economy	6000.00
0005435006811	5149	Economy	6000.00
0005434265107	5149	Economy	6000.00
0005433688788	5149	Economy	6000.00
0005434265117	5149	Economy	6000.00
0005434265116	5149	Economy	6000.00
0005434265121	5149	Economy	6000.00
0005435006869	5149	Economy	6000.00
0005433815313	5149	Economy	6000.00
0005433688789	5149	Economy	6000.00
0005432335861	5149	Economy	6000.00
0005435006780	5149	Economy	6000.00
0005435006748	5149	Economy	6000.00
0005435006904	5149	Economy	6000.00
0005435006879	5149	Economy	6000.00
0005434229344	5149	Economy	6000.00
0005434149716	5149	Economy	6000.00
0005434265113	5149	Economy	6000.00
0005432335942	5149	Economy	6000.00
0005434149719	5149	Economy	6000.00
0005434149724	5149	Economy	6000.00
0005434229354	5149	Economy	6000.00
0005433685495	5149	Economy	6000.00
0005434173514	5149	Economy	6000.00
0005434229352	5149	Economy	6000.00
0005433815312	5149	Economy	6000.00
0005435006937	5149	Economy	6000.00
0005434311201	5149	Economy	6000.00
0005434265103	5149	Economy	6000.00
0005435006772	5149	Economy	6000.00
0005434229347	5149	Economy	6000.00
0005434149720	5149	Economy	6000.00
0005434173516	5149	Economy	6000.00
0005435006870	5149	Economy	6000.00
0005432335906	5149	Economy	6000.00
0005435006708	5149	Economy	6000.00
0005434229343	5149	Economy	6000.00
0005435006804	5149	Economy	6000.00
0005435006805	5149	Economy	6000.00
0005434311194	5149	Economy	6000.00
0005434265111	5149	Economy	6000.00
0005434265106	5149	Economy	6000.00
0005435006938	5149	Economy	6000.00
0005434149721	5149	Economy	6000.00
0005434265119	5149	Economy	6000.00
0005433784735	8445	Business	18000.00
0005433784497	8445	Business	18000.00
0005433784609	8445	Business	18000.00
0005433784739	8445	Business	18000.00
0005433784657	8445	Business	18000.00
0005433784707	8445	Business	18000.00
0005433784736	8445	Business	18000.00
0005433784594	8445	Business	18000.00
0005433784706	8445	Business	18000.00
0005433784613	8445	Business	18000.00
0005433784690	8445	Business	18000.00
0005434244652	8445	Business	18000.00
0005434244732	8445	Economy	6600.00
0005434244800	8445	Economy	6600.00
0005433784658	8445	Economy	6000.00
0005433784456	8445	Economy	6000.00
0005433784530	8445	Economy	6000.00
0005434244799	8445	Economy	6000.00
0005434244839	8445	Economy	6000.00
0005433784600	8445	Economy	6000.00
0005433784591	8445	Economy	6000.00
0005433784692	8445	Economy	6000.00
0005433784691	8445	Economy	6000.00
0005433784607	8445	Economy	6000.00
0005433784582	8445	Economy	6000.00
0005433784553	8445	Economy	6000.00
0005434244669	8445	Economy	6000.00
0005432663019	8445	Economy	6000.00
0005434244769	8445	Economy	6000.00
0005433784671	8445	Economy	6000.00
0005432659687	8445	Economy	6000.00
0005433784485	8445	Economy	6000.00
0005433784508	8445	Economy	6000.00
0005433784606	8445	Economy	6000.00
0005433784664	8445	Economy	6000.00
0005433784577	8445	Economy	6000.00
0005433784659	8445	Economy	6000.00
0005432659684	8445	Economy	6000.00
0005433784643	8445	Economy	6000.00
0005434244803	8445	Economy	6000.00
0005433784562	8445	Economy	6000.00
0005433784580	8445	Economy	6600.00
0005432659686	8445	Economy	6000.00
0005433784731	8445	Economy	6000.00
0005433784642	8445	Economy	6000.00
0005433784637	8445	Economy	6000.00
0005434244678	8445	Economy	6000.00
0005434244658	8445	Economy	6000.00
0005432659688	8445	Economy	6000.00
0005434244884	8445	Economy	6000.00
0005433784608	8445	Economy	6000.00
0005433784506	8445	Economy	6000.00
0005433784507	8445	Economy	6000.00
0005434244657	8445	Economy	6000.00
0005434244659	8445	Economy	6000.00
0005433784734	8445	Economy	6000.00
0005433784584	8445	Economy	6000.00
0005433784531	8445	Economy	6000.00
0005433784488	8445	Economy	6000.00
0005433784595	8445	Economy	6000.00
0005433784626	8445	Economy	6000.00
0005434244755	8445	Economy	6000.00
0005434244765	8445	Economy	6000.00
0005433784700	8445	Economy	6000.00
0005433784563	8445	Economy	6000.00
0005434244766	8445	Economy	6000.00
0005434244733	8445	Economy	6000.00
0005432666365	8445	Economy	6000.00
0005433784579	8445	Economy	6000.00
0005433613987	8446	Business	18000.00
0005433613937	8446	Business	18000.00
0005433613614	8446	Business	18000.00
0005433613903	8446	Business	18000.00
0005433613637	8446	Business	18000.00
0005433614003	8446	Business	18000.00
0005433613798	8446	Business	18000.00
0005433613747	8446	Business	18000.00
0005433613958	8446	Business	18000.00
0005433614054	8446	Economy	6600.00
0005433614199	8446	Economy	6600.00
0005433613869	8446	Economy	6600.00
0005433613951	8446	Economy	6000.00
0005433613939	8446	Economy	6000.00
0005433614114	8446	Economy	6000.00
0005433614004	8446	Economy	6000.00
0005433613748	8446	Economy	6000.00
0005433613952	8446	Economy	6000.00
0005433613885	8446	Economy	6000.00
0005433613746	8446	Economy	6000.00
0005433613706	8446	Economy	6000.00
0005433613955	8446	Economy	6000.00
0005433614144	8446	Economy	6000.00
0005433613443	8446	Economy	6000.00
0005433614426	8446	Economy	6000.00
0005433614043	8446	Economy	6000.00
0005433614126	8446	Economy	6000.00
0005433613626	8446	Economy	6000.00
0005433614044	8446	Economy	6000.00
0005433613913	8446	Economy	6000.00
0005433613859	8446	Economy	6000.00
0005433613819	8446	Economy	6000.00
0005433613887	8446	Economy	6000.00
0005433613840	8446	Economy	6000.00
0005433613940	8446	Economy	6000.00
0005433613922	8446	Economy	6600.00
0005433614010	8446	Economy	6600.00
0005433613930	8446	Economy	6000.00
0005433613898	8446	Economy	6000.00
0005433613989	8446	Economy	6600.00
0005433613899	8446	Economy	6000.00
0005433613912	8446	Economy	6000.00
0005433613874	8446	Economy	6000.00
0005433614173	8446	Economy	6000.00
0005433614005	8446	Economy	6000.00
0005433613847	8446	Economy	6000.00
0005433613835	8446	Economy	6000.00
0005433613938	8446	Economy	6000.00
0005433613875	8446	Economy	6000.00
0005433614016	8446	Economy	6000.00
0005433614146	8446	Economy	6000.00
0005433613854	8446	Economy	6000.00
0005433613591	8446	Economy	6000.00
0005433613960	8446	Economy	6000.00
0005433614145	8446	Economy	6000.00
0005433614063	8446	Economy	6000.00
0005433613902	8446	Economy	6000.00
0005433613613	8446	Economy	6000.00
0005433614056	8446	Economy	6000.00
0005433614009	8446	Economy	6000.00
0005433613794	8446	Economy	6000.00
0005433613901	8446	Economy	6000.00
0005433614110	8446	Economy	6000.00
0005433613444	8446	Economy	6000.00
0005433613407	8446	Economy	6000.00
0005433614131	8446	Economy	6000.00
0005433613627	8446	Economy	6000.00
0005433614172	8446	Economy	6000.00
0005433613776	8446	Economy	6000.00
0005433613638	8446	Economy	6000.00
0005433613929	8446	Economy	6000.00
0005433614042	8446	Economy	6000.00
0005433613984	8446	Economy	6000.00
0005434264930	8447	Business	18000.00
0005434264906	8447	Business	18000.00
0005432034925	8447	Business	18000.00
0005434149622	8447	Business	18000.00
0005432336018	8447	Business	18000.00
0005432336016	8447	Business	18000.00
0005432034930	8447	Business	18000.00
0005432047547	8447	Business	18000.00
0005435007015	8447	Business	18000.00
0005435007002	8447	Business	18000.00
0005434264853	8447	Business	18000.00
0005435006997	8447	Business	18000.00
0005432336025	8447	Business	18000.00
0005435007012	8447	Business	18000.00
0005434229172	8447	Business	18000.00
0005435007011	8447	Business	18000.00
0005432034931	8447	Business	18000.00
0005434229191	8447	Business	18000.00
0005434173481	8447	Business	18000.00
0005434149612	8447	Business	18000.00
0005432034921	8447	Business	18000.00
0005434229149	8447	Business	18000.00
0005433689909	8447	Business	18000.00
0005435286627	8447	Business	18000.00
0005434229159	8447	Business	18000.00
0005433815383	8447	Economy	6600.00
0005432034917	8447	Economy	6600.00
0005434264881	8447	Economy	6600.00
0005434264882	8447	Economy	6600.00
0005434149621	8447	Economy	6600.00
0005434229148	8447	Economy	6600.00
0005435007014	8447	Economy	6000.00
0005432034922	8447	Economy	6000.00
0005432034906	8447	Economy	6000.00
0005435007004	8447	Economy	6000.00
0005432034907	8447	Economy	6000.00
0005434173484	8447	Economy	6000.00
0005433534495	8447	Economy	6000.00
0005434311217	8447	Economy	6000.00
0005433689908	8447	Economy	6000.00
0005435007017	8447	Economy	6000.00
0005434229162	8447	Economy	6000.00
0005434264786	8447	Economy	6000.00
0005432336026	8447	Economy	6000.00
0005434264921	8447	Economy	6000.00
0005434229186	8447	Economy	6000.00
0005434229108	8447	Economy	6000.00
0005432034929	8447	Economy	6000.00
0005432034927	8447	Economy	6000.00
0005432336020	8447	Economy	6000.00
0005434173467	8447	Economy	6000.00
0005432336022	8447	Economy	6000.00
0005434229203	8447	Economy	6000.00
0005434229136	8447	Economy	6000.00
0005434265007	8447	Economy	6000.00
0005432034915	8447	Economy	6000.00
0005432034918	8447	Economy	6000.00
0005435007018	8447	Economy	6000.00
0005434149664	8447	Economy	6000.00
0005433688808	8447	Economy	6000.00
0005432336017	8447	Economy	6000.00
0005434229157	8447	Economy	6000.00
0005435007006	8447	Economy	6000.00
0005435007001	8447	Economy	6000.00
0005435006996	8447	Economy	6000.00
0005434149595	8447	Economy	6000.00
0005433815382	8447	Economy	6000.00
0005432034912	8447	Economy	6000.00
0005434149643	8447	Economy	6000.00
0005432034926	8447	Economy	6000.00
0005435007008	8447	Economy	6000.00
0005432047545	8447	Economy	6000.00
0005434264755	8447	Economy	6000.00
0005433688809	8447	Economy	6000.00
0005434149663	8447	Economy	6000.00
0005433815380	8447	Economy	6000.00
0005434229208	8447	Economy	6000.00
0005432034910	8447	Economy	6000.00
0005435007013	8447	Economy	6000.00
0005432336021	8447	Economy	6000.00
0005432034916	8447	Economy	6000.00
0005433815381	8447	Economy	6000.00
0005434229062	8447	Economy	6000.00
0005434229155	8447	Economy	6000.00
0005434264901	8447	Economy	6000.00
0005434311216	8447	Economy	6000.00
0005434264902	8447	Economy	6000.00
0005434229173	8447	Economy	6600.00
0005432034905	8447	Economy	6600.00
0005434149618	8447	Economy	6600.00
0005432336023	8447	Economy	6600.00
0005434149656	8447	Economy	6600.00
0005434229130	8447	Economy	6000.00
0005434149599	8447	Economy	6000.00
0005432336027	8447	Economy	6000.00
0005435006998	8447	Economy	6000.00
0005434264825	8447	Economy	6000.00
0005433689910	8447	Economy	6600.00
0005434149665	8447	Economy	6000.00
0005435007003	8447	Economy	6000.00
0005434264836	8447	Economy	6000.00
0005435286625	8447	Economy	6000.00
0005435286626	8447	Economy	6000.00
0005434229121	8447	Economy	6000.00
0005432034909	8447	Economy	6000.00
0005433690926	8447	Economy	6000.00
0005434264905	8447	Economy	6000.00
0005432034919	8447	Economy	6000.00
0005432034924	8447	Economy	6000.00
0005432336019	8447	Economy	6000.00
0005434173482	8447	Economy	6000.00
0005434229156	8447	Economy	6000.00
0005435007019	8447	Economy	6000.00
0005434149642	8447	Economy	6000.00
0005434264955	8447	Economy	6000.00
0005433690925	8447	Economy	6000.00
0005432034928	8447	Economy	6000.00
0005432047546	8447	Economy	6000.00
0005434264851	8447	Economy	6000.00
0005435286624	8447	Economy	6000.00
0005435007010	8447	Economy	6000.00
0005434264904	8447	Economy	6000.00
0005432034923	8447	Economy	6000.00
0005435007016	8447	Economy	6000.00
0005432034908	8447	Economy	6000.00
0005435006999	8447	Economy	6000.00
0005432336024	8447	Economy	6000.00
0005434229041	8447	Economy	6000.00
0005435007007	8447	Economy	6000.00
0005434229260	8447	Economy	6000.00
0005433534496	8447	Economy	6000.00
0005432034913	8447	Economy	6000.00
0005434264917	8447	Economy	6000.00
0005432034911	8447	Economy	6000.00
0005434264852	8447	Economy	6000.00
0005432034920	8447	Economy	6000.00
0005434264931	8447	Economy	6000.00
0005435007000	8447	Economy	6000.00
0005434229259	8447	Economy	6000.00
0005432034914	8447	Economy	6000.00
0005434149596	8447	Economy	6000.00
0005434229170	8447	Economy	6000.00
0005434264922	8447	Economy	6000.00
0005435007009	8447	Economy	6000.00
0005435006995	8447	Economy	6000.00
0005432336028	8447	Economy	6000.00
0005435007020	8447	Economy	6000.00
0005432034933	8447	Economy	6000.00
0005434265008	8447	Economy	6000.00
0005435007005	8447	Economy	6000.00
0005432034932	8447	Economy	6000.00
0005434229042	8447	Economy	6000.00
0005434264831	8447	Economy	6000.00
0005434229235	8447	Economy	6000.00
0005434264866	8447	Economy	6000.00
0005434264934	8447	Economy	6000.00
0005434639161	12641	Economy	16200.00
0005433202351	12641	Economy	16200.00
0005433202348	12641	Economy	16200.00
0005434639048	12641	Economy	14800.00
0005433202346	12641	Economy	14800.00
0005434639041	12641	Economy	14800.00
0005434639042	12641	Economy	14800.00
0005433202352	12641	Economy	14800.00
0005433202347	12641	Economy	14800.00
0005433202354	12641	Economy	14800.00
0005434639009	12641	Economy	14800.00
0005434639160	12641	Economy	14800.00
0005434638974	12641	Economy	14800.00
0005433202349	12641	Economy	14800.00
0005434639182	12641	Economy	14800.00
0005433202357	12641	Economy	14800.00
0005434638955	12641	Economy	14800.00
0005434639002	12641	Economy	14800.00
0005433202344	12641	Economy	14800.00
0005433202345	12641	Economy	14800.00
0005434639133	12641	Economy	14800.00
0005434639006	12641	Economy	14800.00
0005434638994	12641	Economy	14800.00
0005433202356	12641	Economy	14800.00
0005434639150	12641	Economy	14800.00
0005434638972	12641	Economy	14800.00
0005433202350	12641	Economy	14800.00
0005434639043	12641	Economy	14800.00
0005434638941	12641	Economy	14800.00
0005433202343	12641	Economy	14800.00
0005434638999	12641	Economy	14800.00
0005434638906	12641	Economy	14800.00
0005434638973	12641	Economy	14800.00
0005434639085	12641	Economy	14800.00
0005433202353	12641	Economy	14800.00
0005434639151	12641	Economy	14800.00
0005434638890	12641	Economy	14800.00
0005434639050	12641	Economy	14800.00
0005433202355	12641	Economy	14800.00
0005434639287	23351	Economy	16200.00
0005434639284	23351	Economy	16200.00
0005434639270	23351	Economy	16200.00
0005432290627	23351	Economy	14800.00
0005434639285	23351	Economy	14800.00
0005433202135	23351	Economy	14800.00
0005434639282	23351	Economy	14800.00
0005434639267	23351	Economy	14800.00
0005434639266	23351	Economy	14800.00
0005434639272	23351	Economy	14800.00
0005434639269	23351	Economy	14800.00
0005433202218	23351	Economy	14800.00
0005433202183	23351	Economy	14800.00
0005433202159	23351	Economy	14800.00
0005433202217	23351	Economy	14800.00
0005433202178	23351	Economy	14800.00
0005433202174	23351	Economy	14800.00
0005434639273	23351	Economy	14800.00
0005434639283	23351	Economy	14800.00
0005433202123	23351	Economy	14800.00
0005433202168	23351	Economy	14800.00
0005433202236	23351	Economy	14800.00
0005433202207	23351	Economy	14800.00
0005434639271	23351	Economy	14800.00
0005433202186	23351	Economy	14800.00
0005432290628	23351	Economy	14800.00
0005433202227	23351	Economy	14800.00
0005434639274	23351	Economy	14800.00
0005434639275	23351	Economy	14800.00
0005433202169	23351	Economy	14800.00
0005434639278	23351	Economy	14800.00
0005434639265	23351	Economy	14800.00
0005434639268	23351	Economy	14800.00
0005434639276	23351	Economy	14800.00
0005434639279	23351	Economy	14800.00
0005434639286	23351	Economy	14800.00
0005434639281	23351	Economy	14800.00
0005433202177	23351	Economy	14800.00
0005434639280	23351	Economy	14800.00
0005434639277	23351	Economy	14800.00
0005433202191	23351	Economy	14800.00
0005433202160	23351	Economy	14800.00
0005433202165	23351	Economy	14800.00
0005432290626	23351	Economy	14800.00
0005433202136	23351	Economy	14800.00
0005432327920	21067	Business	18900.00
0005432382812	21067	Business	18900.00
0005432382874	21067	Business	18900.00
0005432382876	21067	Business	18900.00
0005432382734	21067	Business	18900.00
0005432328138	21067	Business	18900.00
0005432382702	21067	Business	18900.00
0005432328199	21067	Business	18900.00
0005432382785	21067	Business	18900.00
0005432382719	21067	Business	18900.00
0005432382798	21067	Business	18900.00
0005432328172	21067	Business	18900.00
0005432382695	21067	Economy	6300.00
0005432382792	21067	Economy	6300.00
0005432328214	21067	Economy	6300.00
0005432382794	21067	Economy	6300.00
0005432382713	21067	Economy	6300.00
0005432328315	21067	Economy	6300.00
0005432382878	21067	Economy	6300.00
0005432328243	21067	Economy	6900.00
0005432382782	21067	Economy	6900.00
0005432382880	21067	Economy	6900.00
0005432328306	21067	Economy	6900.00
0005432328159	21067	Economy	6300.00
0005432328305	21067	Economy	6300.00
0005432382815	21067	Economy	6300.00
0005432382811	21067	Economy	6300.00
0005432382783	21067	Economy	6300.00
0005432382718	21067	Economy	6300.00
0005432328208	21067	Economy	6300.00
0005432328304	21067	Economy	6300.00
0005432328205	21067	Economy	6300.00
0005432382799	21067	Economy	6300.00
0005432328171	21067	Economy	6300.00
0005432328176	21067	Economy	6300.00
0005432328286	21067	Economy	6300.00
0005432382910	21067	Economy	6300.00
0005432328158	21067	Economy	6300.00
0005432382875	21067	Economy	6300.00
0005432382666	21067	Economy	6300.00
0005432328173	21067	Economy	6300.00
0005432382906	21067	Economy	6300.00
0005432328285	21067	Economy	6300.00
0005432382837	21067	Economy	6300.00
0005432382786	21067	Economy	6300.00
0005432328119	21067	Economy	6300.00
0005432382709	21067	Economy	6300.00
0005432382793	21067	Economy	6300.00
0005432328303	21067	Economy	6300.00
0005432382757	21067	Economy	6300.00
0005432382710	21067	Economy	6300.00
0005432382694	21067	Economy	6300.00
0005432382865	21067	Economy	6300.00
0005432382647	21067	Economy	6300.00
0005432382696	21067	Economy	6300.00
0005432382741	21067	Economy	6300.00
0005432382877	21067	Economy	6300.00
0005432054302	21067	Economy	6300.00
0005432382584	21067	Economy	6300.00
0005432328200	21067	Economy	6300.00
0005432328244	21067	Economy	6300.00
0005432328288	21067	Economy	6300.00
0005432382735	21067	Economy	6300.00
0005432382646	21067	Economy	6300.00
0005432382665	21067	Economy	6300.00
0005432328229	21067	Economy	6300.00
0005432054300	21067	Economy	6300.00
0005432054301	21067	Economy	6300.00
0005432382818	21067	Economy	6300.00
0005432328177	21067	Economy	6300.00
0005432382740	21067	Economy	6300.00
0005432382767	21067	Economy	6300.00
0005432328139	21067	Economy	6300.00
0005432328160	21067	Economy	6300.00
0005432328384	21067	Economy	6300.00
0005432328178	21067	Economy	6300.00
0005432382731	21067	Economy	6300.00
0005432328213	21067	Economy	6300.00
0005432328198	21067	Economy	6300.00
0005432382739	21067	Economy	6300.00
0005432328329	21067	Economy	6300.00
0005432328187	21067	Economy	6300.00
0005432382857	21067	Economy	6300.00
0005432328201	21067	Economy	6300.00
0005432328102	21067	Economy	6300.00
0005432328203	21067	Economy	6300.00
0005432383124	31237	Business	18900.00
0005432383105	31237	Business	18900.00
0005432328638	31237	Business	18900.00
0005432383117	31237	Business	18900.00
0005432383123	31237	Business	18900.00
0005432328617	31237	Business	18900.00
0005432328608	31237	Business	18900.00
0005432328603	31237	Business	18900.00
0005432383109	31237	Business	18900.00
0005432383102	31237	Economy	6300.00
0005432328598	31237	Economy	6300.00
0005432328627	31237	Economy	6300.00
0005432328602	31237	Economy	6300.00
0005432328630	31237	Economy	6300.00
0005432383098	31237	Economy	6300.00
0005432328614	31237	Economy	6300.00
0005432287181	31237	Economy	6300.00
0005432383114	31237	Economy	6300.00
0005432383106	31237	Economy	6300.00
0005432328609	31237	Economy	6900.00
0005432328625	31237	Economy	6900.00
0005432383115	31237	Economy	6900.00
0005432328641	31237	Economy	6300.00
0005432328619	31237	Economy	6300.00
0005432328624	31237	Economy	6300.00
0005432383127	31237	Economy	6300.00
0005432287179	31237	Economy	6300.00
0005432328632	31237	Economy	6300.00
0005432383120	31237	Economy	6300.00
0005432328636	31237	Economy	6300.00
0005432383126	31237	Economy	6300.00
0005432383122	31237	Economy	6300.00
0005432383096	31237	Economy	6300.00
0005432383112	31237	Economy	6300.00
0005432328596	31237	Economy	6300.00
0005432328597	31237	Economy	6300.00
0005432328611	31237	Economy	6300.00
0005432383118	31237	Economy	6300.00
0005432328623	31237	Economy	6300.00
0005432383103	31237	Economy	6300.00
0005432328595	31237	Economy	6300.00
0005432328634	31237	Economy	6300.00
0005432287182	31237	Economy	6300.00
0005432328600	31237	Economy	6300.00
0005432383099	31237	Economy	6300.00
0005432328640	31237	Economy	6300.00
0005432328616	31237	Economy	6300.00
0005432328612	31237	Economy	6300.00
0005432383128	31237	Economy	6300.00
0005432328613	31237	Economy	6300.00
0005432328605	31237	Economy	6300.00
0005432328604	31237	Economy	6300.00
0005432328618	31237	Economy	6300.00
0005432383104	31237	Economy	6300.00
0005432287183	31237	Economy	6300.00
0005432328610	31237	Economy	6300.00
0005432328639	31237	Economy	6300.00
0005432328635	31237	Economy	6300.00
0005432383116	31237	Economy	6300.00
0005432328606	31237	Economy	6300.00
0005432328599	31237	Economy	6300.00
0005432383095	31237	Economy	6300.00
0005432328620	31237	Economy	6300.00
0005432328637	31237	Economy	6300.00
0005432383121	31237	Economy	6300.00
0005432328631	31237	Economy	6300.00
0005432383125	31237	Economy	6300.00
0005432383113	31237	Economy	6300.00
0005432328622	31237	Economy	6300.00
0005432383119	31237	Economy	6300.00
0005432287180	31237	Economy	6300.00
0005432287178	31237	Economy	6300.00
0005432383111	31237	Economy	6300.00
0005432328633	31237	Economy	6300.00
0005432383100	31237	Economy	6300.00
0005432328628	31237	Economy	6300.00
0005432328601	31237	Economy	6300.00
0005432328629	31237	Economy	6300.00
0005432383107	31237	Economy	6300.00
0005432383101	31237	Economy	6300.00
0005432328626	31237	Economy	6300.00
0005432383110	31237	Economy	6300.00
0005432383097	31237	Economy	6300.00
0005432328615	31237	Economy	6300.00
0005432328621	31237	Economy	6300.00
0005432328607	31237	Economy	6300.00
0005432383108	31237	Economy	6300.00
0005433642308	2477	Business	89600.00
0005433642319	2477	Business	89600.00
0005433642326	2477	Business	89600.00
0005433642306	2477	Business	89600.00
0005432953815	2477	Business	89600.00
0005432953817	2477	Economy	29900.00
0005433642312	2477	Economy	29900.00
0005432953812	2477	Economy	29900.00
0005432953848	2477	Economy	29900.00
0005432953839	2477	Economy	29900.00
0005433642314	2477	Economy	29900.00
0005432953846	2477	Economy	29900.00
0005433642317	2477	Economy	32800.00
0005432953788	2477	Economy	32800.00
0005433642305	2477	Economy	32800.00
0005432953838	2477	Economy	32800.00
0005432953820	2477	Economy	29900.00
0005433642320	2477	Economy	29900.00
0005432953867	2477	Economy	29900.00
0005433642316	2477	Economy	29900.00
0005432953796	2477	Economy	29900.00
0005432953825	2477	Economy	29900.00
0005432953842	2477	Economy	29900.00
0005432953831	2477	Economy	29900.00
0005432953843	2477	Economy	29900.00
0005433642332	2477	Economy	29900.00
0005432953869	2477	Economy	29900.00
0005433642309	2477	Economy	29900.00
0005433642324	2477	Economy	29900.00
0005432953814	2477	Economy	29900.00
0005433642310	2477	Economy	29900.00
0005433642318	2477	Economy	29900.00
0005433642333	2477	Economy	29900.00
0005433642323	2477	Economy	29900.00
0005433642304	2477	Economy	29900.00
0005433642327	2477	Economy	29900.00
0005432953866	2477	Economy	29900.00
0005433642311	2477	Economy	29900.00
0005432953787	2477	Economy	29900.00
0005433642321	2477	Economy	29900.00
0005432953795	2477	Economy	29900.00
0005433642329	2477	Economy	29900.00
0005432953816	2477	Economy	29900.00
0005432953868	2477	Economy	29900.00
0005433642322	2477	Economy	29900.00
0005433642334	2477	Economy	29900.00
0005433642313	2477	Economy	29900.00
0005433642330	2477	Economy	29900.00
0005433642315	2477	Economy	29900.00
0005432953826	2477	Economy	29900.00
0005433642328	2477	Economy	29900.00
0005432953844	2477	Economy	29900.00
0005433642307	2477	Economy	29900.00
0005432953845	2477	Economy	29900.00
0005432953824	2477	Economy	29900.00
0005433642325	2477	Economy	29900.00
0005432953847	2477	Economy	29900.00
0005433642331	2477	Economy	29900.00
0005432953813	2477	Economy	29900.00
0005433642176	27588	Business	89600.00
0005433642122	27588	Business	89600.00
0005433642146	27588	Business	89600.00
0005433642193	27588	Business	89600.00
0005433642154	27588	Business	89600.00
0005433642235	27588	Business	89600.00
0005432953917	27588	Business	89600.00
0005433642195	27588	Business	89600.00
0005433642231	27588	Business	89600.00
0005433642104	27588	Business	89600.00
0005432953912	27588	Business	89600.00
0005433642219	27588	Business	89600.00
0005432953914	27588	Economy	29900.00
0005433642178	27588	Economy	29900.00
0005433642170	27588	Economy	29900.00
0005433642238	27588	Economy	29900.00
0005433642237	27588	Economy	29900.00
0005432953927	27588	Economy	29900.00
0005433642183	27588	Economy	29900.00
0005433642220	27588	Economy	29900.00
0005432953923	27588	Economy	29900.00
0005433642186	27588	Economy	32800.00
0005433642254	27588	Economy	32800.00
0005432953907	27588	Economy	32800.00
0005433642137	27588	Economy	32800.00
0005433642169	27588	Economy	29900.00
0005433642215	27588	Economy	29900.00
0005432953930	27588	Economy	29900.00
0005432953916	27588	Economy	29900.00
0005432953932	27588	Economy	29900.00
0005433642177	27588	Economy	29900.00
0005433642192	27588	Economy	29900.00
0005433642218	27588	Economy	29900.00
0005433642207	27588	Economy	29900.00
0005432953926	27588	Economy	29900.00
0005433642174	27588	Economy	29900.00
0005432953913	27588	Economy	29900.00
0005433642159	27588	Economy	29900.00
0005432953909	27588	Economy	29900.00
0005432953922	27588	Economy	29900.00
0005433642179	27588	Economy	29900.00
0005432953920	27588	Economy	29900.00
0005433642136	27588	Economy	29900.00
0005432953910	27588	Economy	29900.00
0005433642184	27588	Economy	29900.00
0005432953933	27588	Economy	29900.00
0005433642196	27588	Economy	29900.00
0005433642168	27588	Economy	29900.00
0005433642152	27588	Economy	29900.00
0005433642197	27588	Economy	29900.00
0005433642134	27588	Economy	29900.00
0005433642216	27588	Economy	29900.00
0005432953911	27588	Economy	29900.00
0005433642161	27588	Economy	29900.00
0005433642232	27588	Economy	29900.00
0005433642151	27588	Economy	29900.00
0005433642234	27588	Economy	29900.00
0005433642190	27588	Economy	29900.00
0005433642203	27588	Economy	29900.00
0005433642191	27588	Economy	29900.00
0005433642103	27588	Economy	29900.00
0005432953929	27588	Economy	29900.00
0005433642107	27588	Economy	29900.00
0005433642208	27588	Economy	29900.00
0005433642189	27588	Economy	29900.00
0005433642173	27588	Economy	29900.00
0005432953908	27588	Economy	29900.00
0005432953924	27588	Economy	29900.00
0005432953925	27588	Economy	29900.00
0005432953918	27588	Economy	29900.00
0005433642150	27588	Economy	29900.00
0005433642167	27588	Economy	29900.00
0005433642095	27588	Economy	29900.00
0005432953919	27588	Economy	29900.00
0005433642214	27588	Economy	29900.00
0005432953931	27588	Economy	29900.00
0005433642135	27588	Economy	29900.00
0005432953921	27588	Economy	29900.00
0005432953915	27588	Economy	29900.00
0005433642156	27588	Economy	29900.00
0005432953928	27588	Economy	29900.00
0005433642175	27588	Economy	29900.00
0005433642140	27588	Economy	29900.00
0005432424329	13376	Business	12700.00
0005432424332	13376	Business	12700.00
0005432424348	13376	Business	12700.00
0005432424330	13376	Business	12700.00
0005432424363	13376	Business	12700.00
0005432424361	13376	Business	12700.00
0005432424357	13376	Business	12700.00
0005432424331	13376	Business	12700.00
0005432424347	13376	Economy	4200.00
0005432424342	13376	Economy	4200.00
0005432424368	13376	Economy	4200.00
0005432424366	13376	Economy	4200.00
0005432424351	13376	Economy	4700.00
0005432424333	13376	Economy	4200.00
0005432424359	13376	Economy	4200.00
0005432424341	13376	Economy	4200.00
0005432424370	13376	Economy	4200.00
0005432424326	13376	Economy	4200.00
0005432424340	13376	Economy	4200.00
0005432424345	13376	Economy	4200.00
0005432424335	13376	Economy	4200.00
0005432424375	13376	Economy	4200.00
0005432424324	13376	Economy	4200.00
0005432424354	13376	Economy	4200.00
0005432424369	13376	Economy	4200.00
0005432424362	13376	Economy	4200.00
0005432424334	13376	Economy	4200.00
0005432424356	13376	Economy	4200.00
0005432424336	13376	Economy	4200.00
0005432424350	13376	Economy	4200.00
0005432424328	13376	Economy	4200.00
0005432424325	13376	Economy	4200.00
0005432424327	13376	Economy	4200.00
0005432424371	13376	Economy	4200.00
0005432424360	13376	Economy	4200.00
0005432424367	13376	Economy	4200.00
0005432424365	13376	Economy	4200.00
0005432424344	13376	Economy	4200.00
0005432424358	13376	Economy	4200.00
0005432424346	13376	Economy	4200.00
0005432424355	13376	Economy	4200.00
0005432424337	13376	Economy	4200.00
0005432424349	13376	Economy	4200.00
0005432424373	13376	Economy	4200.00
0005432424338	13376	Economy	4200.00
0005432424364	13376	Economy	4200.00
0005432424343	13376	Economy	4200.00
0005432424372	13376	Economy	4200.00
0005432424374	13376	Economy	4200.00
0005432424353	13376	Economy	4200.00
0005432424352	13376	Economy	4200.00
0005432424339	13376	Economy	4200.00
0005432423980	30710	Business	12700.00
0005432423893	30710	Business	12700.00
0005432423884	30710	Business	12700.00
0005432423987	30710	Business	12700.00
0005432423843	30710	Business	12700.00
0005432423946	30710	Economy	4200.00
0005432423945	30710	Economy	4200.00
0005432424024	30710	Economy	4200.00
0005432423941	30710	Economy	4200.00
0005432424002	30710	Economy	4200.00
0005432423770	30710	Economy	4200.00
0005432423864	30710	Economy	4700.00
0005432424001	30710	Economy	4700.00
0005432423966	30710	Economy	4200.00
0005432423717	30710	Economy	4200.00
0005432423940	30710	Economy	4200.00
0005432423783	30710	Economy	4200.00
0005432423954	30710	Economy	4200.00
0005432424003	30710	Economy	4200.00
0005432423953	30710	Economy	4200.00
0005432423747	30710	Economy	4200.00
0005432423950	30710	Economy	4200.00
0005432423949	30710	Economy	4200.00
0005432424007	30710	Economy	4200.00
0005432423745	30710	Economy	4200.00
0005432423965	30710	Economy	4200.00
0005432423952	30710	Economy	4200.00
0005432423784	30710	Economy	4200.00
0005432423816	30710	Economy	4200.00
0005432423999	30710	Economy	4200.00
0005432423928	30710	Economy	4200.00
0005432423976	30710	Economy	4200.00
0005432423944	30710	Economy	4200.00
0005432423831	30710	Economy	4200.00
0005432423951	30710	Economy	4200.00
0005432423930	30710	Economy	4200.00
0005432423997	30710	Economy	4200.00
0005432423854	30710	Economy	4200.00
0005432423705	30710	Economy	4200.00
0005432423844	30710	Economy	4200.00
0005432423998	30710	Economy	4200.00
0005432423746	30710	Economy	4200.00
0005432423845	30710	Economy	4200.00
0005432423990	30710	Economy	4200.00
0005432423755	30710	Economy	4200.00
0005432423719	30710	Economy	4200.00
0005432423881	30710	Economy	4200.00
0005432423860	30710	Economy	4200.00
0005432424010	30710	Economy	4200.00
0005432423720	30710	Economy	4200.00
0005432423936	30710	Economy	4200.00
0005432423969	30710	Economy	4200.00
0005432424009	30710	Economy	4200.00
0005432817433	9615	Business	32600.00
0005434448310	9615	Business	32600.00
0005434157392	9615	Business	32600.00
0005432901458	9615	Business	32600.00
0005432817442	9615	Business	32600.00
0005432817443	9615	Business	32600.00
0005432901446	9615	Business	32600.00
0005432817447	9615	Business	32600.00
0005434186173	9615	Business	32600.00
0005432817429	9615	Economy	10900.00
0005432822193	9615	Economy	10900.00
0005432817436	9615	Economy	10900.00
0005432901447	9615	Economy	10900.00
0005432901478	9615	Economy	10900.00
0005432288982	9615	Economy	10900.00
0005432901448	9615	Economy	10900.00
0005432901464	9615	Economy	10900.00
0005432288981	9615	Economy	11900.00
0005432901495	9615	Economy	11900.00
0005432901394	9615	Economy	11900.00
0005432901451	9615	Economy	10900.00
0005432817440	9615	Economy	10900.00
0005434157401	9615	Economy	10900.00
0005432817432	9615	Economy	10900.00
0005432901468	9615	Economy	10900.00
0005432817426	9615	Economy	10900.00
0005432822192	9615	Economy	10900.00
0005432817427	9615	Economy	10900.00
0005432817453	9615	Economy	10900.00
0005432901507	9615	Economy	10900.00
0005432817445	9615	Economy	10900.00
0005432817441	9615	Economy	10900.00
0005434448311	9615	Economy	10900.00
0005432817438	9615	Economy	10900.00
0005432817448	9615	Economy	10900.00
0005432817431	9615	Economy	10900.00
0005432901479	9615	Economy	10900.00
0005434157418	9615	Economy	10900.00
0005432901467	9615	Economy	10900.00
0005432901541	9615	Economy	10900.00
0005432288983	9615	Economy	10900.00
0005432817446	9615	Economy	10900.00
0005434448312	9615	Economy	10900.00
0005432817428	9615	Economy	10900.00
0005434186171	9615	Economy	10900.00
0005432817452	9615	Economy	10900.00
0005432901430	9615	Economy	10900.00
0005432817439	9615	Economy	10900.00
0005432901461	9615	Economy	10900.00
0005432901493	9615	Economy	10900.00
0005432817450	9615	Economy	10900.00
0005432817451	9615	Economy	10900.00
0005434186170	9615	Economy	10900.00
0005432901392	9615	Economy	10900.00
0005434157409	9615	Economy	10900.00
0005432817444	9615	Economy	10900.00
0005432901404	9615	Economy	10900.00
0005432817434	9615	Economy	10900.00
0005432822197	9615	Economy	10900.00
0005432901395	9615	Economy	10900.00
0005432817437	9615	Economy	10900.00
0005432817449	9615	Economy	10900.00
0005432822195	9615	Economy	10900.00
0005432901436	9615	Economy	10900.00
0005432822196	9615	Economy	10900.00
0005432901450	9615	Economy	10900.00
0005434448313	9615	Economy	10900.00
0005432901435	9615	Economy	10900.00
0005432901396	9615	Economy	10900.00
0005434157417	9615	Economy	10900.00
0005432817425	9615	Economy	10900.00
0005432822198	9615	Economy	10900.00
0005432822194	9615	Economy	10900.00
0005434186174	9615	Economy	10900.00
0005432817430	9615	Economy	10900.00
0005432817435	9615	Economy	10900.00
0005432901449	9615	Economy	10900.00
0005432817299	28985	Business	32600.00
0005432817258	28985	Business	32600.00
0005432817068	28985	Business	32600.00
0005432901583	28985	Business	32600.00
0005432901588	28985	Business	32600.00
0005432817316	28985	Business	32600.00
0005432901592	28985	Business	32600.00
0005434157470	28985	Business	32600.00
0005432817188	28985	Business	32600.00
0005432817090	28985	Economy	10900.00
0005434157474	28985	Economy	10900.00
0005432817163	28985	Economy	10900.00
0005432822148	28985	Economy	10900.00
0005432817108	28985	Economy	10900.00
0005432901593	28985	Economy	10900.00
0005432817178	28985	Economy	10900.00
0005434448301	28985	Economy	10900.00
0005434157472	28985	Economy	10900.00
0005432901589	28985	Economy	11900.00
0005432817212	28985	Economy	11900.00
0005432817174	28985	Economy	11900.00
0005434448303	28985	Economy	11900.00
0005432817175	28985	Economy	11900.00
0005432901595	28985	Economy	10900.00
0005432817136	28985	Economy	10900.00
0005432822136	28985	Economy	10900.00
0005434186194	28985	Economy	10900.00
0005432817243	28985	Economy	10900.00
0005432817184	28985	Economy	10900.00
0005432817235	28985	Economy	10900.00
0005432002074	28985	Economy	10900.00
0005432822147	28985	Economy	10900.00
0005432817200	28985	Economy	10900.00
0005432817066	28985	Economy	10900.00
0005432901590	28985	Economy	10900.00
0005432901591	28985	Economy	10900.00
0005432901597	28985	Economy	10900.00
0005432901582	28985	Economy	10900.00
0005434186195	28985	Economy	10900.00
0005432822146	28985	Economy	10900.00
0005432817218	28985	Economy	10900.00
0005432817317	28985	Economy	10900.00
0005432817176	28985	Economy	10900.00
0005432817234	28985	Economy	10900.00
0005432901585	28985	Economy	10900.00
0005432901594	28985	Economy	10900.00
0005432817217	28985	Economy	10900.00
0005432817224	28985	Economy	10900.00
0005432822135	28985	Economy	10900.00
0005434186193	28985	Economy	10900.00
0005434157473	28985	Economy	10900.00
0005432817086	28985	Economy	10900.00
0005432901584	28985	Economy	10900.00
0005432901596	28985	Economy	10900.00
0005434157469	28985	Economy	10900.00
0005432002072	28985	Economy	10900.00
0005434186192	28985	Economy	10900.00
0005432901598	28985	Economy	10900.00
0005432901586	28985	Economy	10900.00
0005432817226	28985	Economy	10900.00
0005432817325	28985	Economy	10900.00
0005432817201	28985	Economy	10900.00
0005434157468	28985	Economy	10900.00
0005432901581	28985	Economy	10900.00
0005432817132	28985	Economy	10900.00
0005432002073	28985	Economy	10900.00
0005432817164	28985	Economy	10900.00
0005432817123	28985	Economy	10900.00
0005432817263	28985	Economy	10900.00
0005432901587	28985	Economy	10900.00
0005432817173	28985	Economy	10900.00
0005432817107	28985	Economy	10900.00
0005434157467	28985	Economy	10900.00
0005432817264	28985	Economy	10900.00
0005434157471	28985	Economy	10900.00
0005432817131	28985	Economy	10900.00
0005434448302	28985	Economy	10900.00
0005432817227	28985	Economy	10900.00
0005432613859	15143	Economy	11000.00
0005432611707	15143	Economy	11000.00
0005435841812	15143	Economy	11000.00
0005432611706	15143	Economy	11000.00
0005432611705	15143	Economy	11000.00
0005432611709	15143	Economy	11000.00
0005432613856	15143	Economy	11000.00
0005432611708	15143	Economy	11000.00
0005432613858	15143	Economy	11000.00
0005435841092	15143	Economy	11000.00
0005432613857	15143	Economy	11000.00
0005432611667	31576	Economy	11000.00
0005432607511	31576	Economy	11000.00
0005435842327	31576	Economy	11000.00
0005432611669	31576	Economy	11000.00
0005432607533	31576	Economy	11000.00
0005432611670	31576	Economy	11000.00
0005432611671	31576	Economy	11000.00
0005432607528	31576	Economy	11000.00
0005432607534	31576	Economy	11000.00
0005432611668	31576	Economy	11000.00
0005432607529	31576	Economy	11000.00
0005433568976	11874	Business	105900.00
0005433568952	11874	Business	105900.00
0005432948030	11874	Business	105900.00
0005433568964	11874	Business	105900.00
0005433568990	11874	Business	105900.00
0005433568965	11874	Business	105900.00
0005433568980	11874	Business	105900.00
0005433568959	11874	Business	105900.00
0005432947968	11874	Business	105900.00
0005432947829	11874	Business	105900.00
0005432948054	11874	Business	105900.00
0005433568972	11874	Business	105900.00
0005432947799	11874	Business	105900.00
0005432948100	11874	Business	105900.00
0005433568954	11874	Business	105900.00
0005433568961	11874	Business	105900.00
0005433568968	11874	Business	105900.00
0005432947770	11874	Business	105900.00
0005433568948	11874	Economy	35300.00
0005433568981	11874	Business	105900.00
0005432948003	11874	Economy	35300.00
0005433568950	11874	Economy	35300.00
0005433568979	11874	Economy	35300.00
0005433568949	11874	Economy	35300.00
0005432948056	11874	Economy	35300.00
0005432948017	11874	Economy	35300.00
0005432947963	11874	Economy	35300.00
0005432947887	11874	Economy	35300.00
0005433568993	11874	Economy	38800.00
0005432947997	11874	Economy	38800.00
0005432948035	11874	Economy	38800.00
0005433568946	11874	Economy	35300.00
0005432947998	11874	Economy	35300.00
0005432947804	11874	Economy	35300.00
0005432947903	11874	Economy	35300.00
0005433568960	11874	Economy	35300.00
0005432947919	11874	Economy	35300.00
0005432947999	11874	Economy	35300.00
0005432947947	11874	Economy	35300.00
0005432947800	11874	Economy	35300.00
0005433568967	11874	Economy	35300.00
0005432948109	11874	Economy	35300.00
0005433568987	11874	Economy	35300.00
0005433568970	11874	Economy	35300.00
0005432948061	11874	Economy	35300.00
0005433568986	11874	Economy	35300.00
0005432948062	11874	Economy	35300.00
0005432947888	11874	Economy	35300.00
0005432947935	11874	Economy	35300.00
0005432948108	11874	Economy	35300.00
0005432948018	11874	Economy	35300.00
0005433568971	11874	Economy	35300.00
0005432948015	11874	Economy	35300.00
0005432948000	11874	Economy	35300.00
0005433568957	11874	Economy	35300.00
0005433568962	11874	Economy	35300.00
0005433568982	11874	Economy	35300.00
0005432948021	11874	Economy	35300.00
0005433568992	11874	Economy	35300.00
0005432948120	11874	Economy	35300.00
0005432947942	11874	Economy	35300.00
0005432947859	11874	Economy	35300.00
0005432947934	11874	Economy	35300.00
0005432948022	11874	Economy	35300.00
0005433568989	11874	Economy	35300.00
0005432948070	11874	Economy	35300.00
0005432947939	11874	Economy	35300.00
0005433568955	11874	Economy	35300.00
0005432948016	11874	Economy	35300.00
0005433568983	11874	Economy	35300.00
0005432947962	11874	Economy	35300.00
0005432947771	11874	Economy	35300.00
0005432948086	11874	Economy	35300.00
0005433568991	11874	Economy	35300.00
0005432948044	11874	Economy	35300.00
0005433568953	11874	Economy	35300.00
0005432947940	11874	Economy	35300.00
0005433568974	11874	Economy	35300.00
0005433568985	11874	Economy	35300.00
0005433568988	11874	Economy	35300.00
0005432948020	11874	Economy	35300.00
0005433568975	11874	Economy	35300.00
0005432947896	11874	Economy	35300.00
0005433568977	11874	Economy	35300.00
0005433568969	11874	Economy	35300.00
0005433568978	11874	Economy	35300.00
0005432947858	11874	Economy	35300.00
0005433568963	11874	Economy	35300.00
0005433568984	11874	Economy	35300.00
0005433568958	11874	Economy	35300.00
0005432948072	11874	Economy	35300.00
0005433568973	11874	Economy	35300.00
0005433568947	11874	Economy	35300.00
0005433568966	11874	Economy	35300.00
0005432948033	11874	Economy	35300.00
0005432947941	11874	Economy	35300.00
0005433568956	11874	Economy	35300.00
0005433568951	11874	Economy	35300.00
0005433568470	25274	Business	105900.00
0005432948456	25274	Business	105900.00
0005433568591	25274	Business	105900.00
0005433568272	25274	Business	105900.00
0005433568431	25274	Business	105900.00
0005432948436	25274	Business	105900.00
0005432948466	25274	Business	105900.00
0005433568570	25274	Business	105900.00
0005433568463	25274	Business	105900.00
0005433568437	25274	Business	105900.00
0005432948457	25274	Business	105900.00
0005432948461	25274	Business	105900.00
0005432948435	25274	Business	105900.00
0005433568379	25274	Business	105900.00
0005433568517	25274	Business	105900.00
0005433568455	25274	Business	105900.00
0005433568265	25274	Business	105900.00
0005433568504	25274	Business	105900.00
0005433568323	25274	Economy	35300.00
0005433568273	25274	Economy	35300.00
0005433568393	25274	Economy	35300.00
0005433568232	25274	Economy	35300.00
0005433568436	25274	Economy	35300.00
0005433568544	25274	Economy	35300.00
0005432948444	25274	Economy	35300.00
0005432948442	25274	Economy	35300.00
0005432948451	25274	Economy	35300.00
0005433568592	25274	Economy	35300.00
0005432948441	25274	Economy	35300.00
0005433568456	25274	Economy	35300.00
0005433568271	25274	Economy	38800.00
0005432948449	25274	Economy	38800.00
0005432948467	25274	Economy	38800.00
0005432948468	25274	Economy	35300.00
0005433568444	25274	Economy	35300.00
0005432948440	25274	Economy	35300.00
0005433568512	25274	Economy	35300.00
0005432948433	25274	Economy	35300.00
0005432948454	25274	Economy	35300.00
0005432948469	25274	Economy	35300.00
0005433568682	25274	Economy	35300.00
0005433568501	25274	Economy	35300.00
0005433568534	25274	Economy	35300.00
0005433568610	25274	Economy	35300.00
0005433568468	25274	Economy	35300.00
0005432948446	25274	Economy	35300.00
0005432948464	25274	Economy	35300.00
0005433568569	25274	Economy	35300.00
0005433568496	25274	Economy	35300.00
0005433568385	25274	Economy	35300.00
0005433568319	25274	Economy	35300.00
0005433568375	25274	Economy	35300.00
0005433568362	25274	Economy	35300.00
0005432948450	25274	Economy	35300.00
0005433568716	25274	Economy	35300.00
0005433568376	25274	Economy	35300.00
0005433568513	25274	Economy	35300.00
0005433568343	25274	Economy	35300.00
0005433568434	25274	Economy	35300.00
0005433568599	25274	Economy	35300.00
0005433568474	25274	Economy	35300.00
0005432948445	25274	Economy	35300.00
0005432948438	25274	Economy	35300.00
0005432948432	25274	Economy	35300.00
0005432948471	25274	Economy	35300.00
0005432948459	25274	Economy	35300.00
0005433568445	25274	Economy	35300.00
0005433568497	25274	Economy	35300.00
0005433568679	25274	Economy	35300.00
0005432948439	25274	Economy	35300.00
0005433568290	25274	Economy	35300.00
0005433568484	25274	Economy	35300.00
0005433568417	25274	Economy	35300.00
0005432948447	25274	Economy	35300.00
0005433568413	25274	Economy	35300.00
0005433568485	25274	Economy	35300.00
0005433568397	25274	Economy	35300.00
0005433568462	25274	Economy	35300.00
0005432948452	25274	Economy	35300.00
0005433568543	25274	Economy	35300.00
0005432948434	25274	Economy	35300.00
0005433568457	25274	Economy	35300.00
0005432948470	25274	Economy	35300.00
0005433568509	25274	Economy	35300.00
0005433568542	25274	Economy	35300.00
0005433568229	25274	Economy	35300.00
0005432948455	25274	Economy	35300.00
0005433568435	25274	Economy	35300.00
0005432948465	25274	Economy	35300.00
0005432948460	25274	Economy	35300.00
0005432948437	25274	Economy	35300.00
0005432948453	25274	Economy	35300.00
0005433568701	25274	Economy	35300.00
0005432948448	25274	Economy	35300.00
0005433568645	25274	Economy	35300.00
0005432948463	25274	Economy	35300.00
0005433568469	25274	Economy	35300.00
0005432948458	25274	Economy	35300.00
0005433568424	25274	Economy	35300.00
0005433568194	25274	Economy	35300.00
0005433568433	25274	Economy	35300.00
0005433568416	25274	Economy	35300.00
0005432948462	25274	Economy	35300.00
0005432948443	25274	Economy	35300.00
0005433568344	25274	Economy	35300.00
0005435340021	5378	Business	67200.00
0005435340042	5378	Business	67200.00
0005432114198	5378	Business	67200.00
0005434654650	5378	Business	67200.00
0005434654657	5378	Business	67200.00
0005435340154	5378	Business	67200.00
0005434654659	5378	Business	67200.00
0005435340041	5378	Business	67200.00
0005435340022	5378	Economy	22400.00
0005435555339	5378	Economy	22400.00
0005434654665	5378	Economy	22400.00
0005435340040	5378	Economy	22400.00
0005435340063	5378	Economy	22400.00
0005434654662	5378	Economy	24600.00
0005435555349	5378	Economy	24600.00
0005435340094	5378	Economy	24600.00
0005435340148	5378	Economy	24600.00
0005435340076	5378	Economy	22400.00
0005435340126	5378	Economy	22400.00
0005434654642	5378	Economy	22400.00
0005434654649	5378	Economy	22400.00
0005435340162	5378	Economy	22400.00
0005434654648	5378	Economy	22400.00
0005434654647	5378	Economy	22400.00
0005435340043	5378	Economy	22400.00
0005434654643	5378	Economy	22400.00
0005434654653	5378	Economy	22400.00
0005434654646	5378	Economy	22400.00
0005435340123	5378	Economy	22400.00
0005435340047	5378	Economy	22400.00
0005435340110	5378	Economy	22400.00
0005434654663	5378	Economy	22400.00
0005434654652	5378	Economy	22400.00
0005435340163	5378	Economy	22400.00
0005432114199	5378	Economy	22400.00
0005434654644	5378	Economy	22400.00
0005435340131	5378	Economy	22400.00
0005435340132	5378	Economy	22400.00
0005434654664	5378	Economy	22400.00
0005435555340	5378	Economy	22400.00
0005434654645	5378	Economy	22400.00
0005434654658	5378	Economy	22400.00
0005435340119	5378	Economy	22400.00
0005435340136	5378	Economy	22400.00
0005434654661	5378	Economy	22400.00
0005435340109	5378	Economy	22400.00
0005434654656	5378	Economy	22400.00
0005435340167	5378	Economy	22400.00
0005434654654	5378	Economy	22400.00
0005434654651	5378	Economy	22400.00
0005434654660	5378	Economy	22400.00
0005434654655	5378	Economy	22400.00
0005434654641	5378	Economy	22400.00
0005435340095	5378	Economy	22400.00
0005432114200	5378	Economy	22400.00
0005434654667	5378	Economy	22400.00
0005434654666	5378	Economy	22400.00
0005435340100	5378	Economy	22400.00
0005435340250	12539	Business	67200.00
0005434654288	12539	Business	67200.00
0005435340241	12539	Business	67200.00
0005434654381	12539	Business	67200.00
0005434654393	12539	Business	67200.00
0005434654392	12539	Business	67200.00
0005434654441	12539	Business	67200.00
0005434654408	12539	Business	67200.00
0005434654399	12539	Business	67200.00
0005434654433	12539	Economy	22400.00
0005435340239	12539	Economy	22400.00
0005434654339	12539	Economy	22400.00
0005434654456	12539	Economy	22400.00
0005435340249	12539	Economy	22400.00
0005435340253	12539	Economy	24600.00
0005434654320	12539	Economy	24600.00
0005435340246	12539	Economy	22400.00
0005434654454	12539	Economy	22400.00
0005434654369	12539	Economy	22400.00
0005435340252	12539	Economy	22400.00
0005435340240	12539	Economy	22400.00
0005434654425	12539	Economy	22400.00
0005435340247	12539	Economy	22400.00
0005435340244	12539	Economy	22400.00
0005434654514	12539	Economy	22400.00
0005434654380	12539	Economy	22400.00
0005435340238	12539	Economy	22400.00
0005435340242	12539	Economy	22400.00
0005434654355	12539	Economy	22400.00
0005434654354	12539	Economy	22400.00
0005434654405	12539	Economy	22400.00
0005434654415	12539	Economy	22400.00
0005434656538	12539	Economy	22400.00
0005435555369	12539	Economy	22400.00
0005434654330	12539	Economy	22400.00
0005434654370	12539	Economy	22400.00
0005434654432	12539	Economy	22400.00
0005434654457	12539	Economy	22400.00
0005435340248	12539	Economy	22400.00
0005434654513	12539	Economy	22400.00
0005435555368	12539	Economy	22400.00
0005434654455	12539	Economy	22400.00
0005435340243	12539	Economy	22400.00
0005434654391	12539	Economy	22400.00
0005434656539	12539	Economy	22400.00
0005434654406	12539	Economy	22400.00
0005435340251	12539	Economy	22400.00
0005434654386	12539	Economy	22400.00
0005435340245	12539	Economy	22400.00
0005434654427	12539	Economy	22400.00
0005434654209	12539	Economy	22400.00
0005434654515	12539	Economy	22400.00
0005434654470	12539	Economy	22400.00
0005433688806	7449	Business	32000.00
0005432428888	7449	Business	32000.00
0005433715891	7449	Business	32000.00
0005433722213	7449	Business	32000.00
0005433715906	7449	Business	32000.00
0005433715926	7449	Business	32000.00
0005433715929	7449	Business	32000.00
0005433715923	7449	Business	32000.00
0005433722211	7449	Business	32000.00
0005432428889	7449	Economy	10700.00
0005433715912	7449	Economy	10700.00
0005433722214	7449	Economy	10700.00
0005433715925	7449	Economy	10700.00
0005433715908	7449	Economy	10700.00
0005433715934	7449	Economy	10700.00
0005433715887	7449	Economy	10700.00
0005433656666	7449	Economy	10700.00
0005433722216	7449	Economy	10700.00
0005433715901	7449	Economy	10700.00
0005433715896	7449	Economy	10700.00
0005433656663	7449	Economy	10700.00
0005433715917	7449	Economy	10700.00
0005433715892	7449	Economy	10700.00
0005433689907	7449	Economy	10700.00
0005433715921	7449	Economy	10700.00
0005433715907	7449	Economy	10700.00
0005433719135	7449	Economy	10700.00
0005433715904	7449	Economy	10700.00
0005433715895	7449	Economy	10700.00
0005433715903	7449	Economy	10700.00
0005433715890	7449	Economy	10700.00
0005432428883	7449	Economy	10700.00
0005433715893	7449	Economy	10700.00
0005433715915	7449	Economy	10700.00
0005433690924	7449	Economy	11700.00
0005433715933	7449	Economy	11700.00
0005433715902	7449	Economy	11700.00
0005433715918	7449	Economy	10700.00
0005433689906	7449	Economy	10700.00
0005433715884	7449	Economy	10700.00
0005433715898	7449	Economy	10700.00
0005433715927	7449	Economy	10700.00
0005432078099	7449	Economy	10700.00
0005433715928	7449	Economy	10700.00
0005432078103	7449	Economy	10700.00
0005433715914	7449	Economy	10700.00
0005433715894	7449	Economy	10700.00
0005433715931	7449	Economy	10700.00
0005433656664	7449	Economy	10700.00
0005433715888	7449	Economy	10700.00
0005433715909	7449	Economy	10700.00
0005433715910	7449	Economy	10700.00
0005433715889	7449	Economy	10700.00
0005433722215	7449	Economy	10700.00
0005433715922	7449	Economy	10700.00
0005432428895	7449	Economy	10700.00
0005432078105	7449	Economy	10700.00
0005433688804	7449	Economy	10700.00
0005433715930	7449	Economy	10700.00
0005432078104	7449	Economy	10700.00
0005432078100	7449	Economy	10700.00
0005433715899	7449	Economy	10700.00
0005433715886	7449	Economy	10700.00
0005432428899	7449	Economy	10700.00
0005433715905	7449	Economy	10700.00
0005433722212	7449	Economy	10700.00
0005433715919	7449	Economy	10700.00
0005433715932	7449	Economy	10700.00
0005433722209	7449	Economy	10700.00
0005433715897	7449	Economy	10700.00
0005433715900	7449	Economy	10700.00
0005433715920	7449	Economy	10700.00
0005433715911	7449	Economy	10700.00
0005432078102	7449	Economy	10700.00
0005433690922	7449	Economy	10700.00
0005433715885	7449	Economy	10700.00
0005433715935	7449	Economy	10700.00
0005433715924	7449	Economy	10700.00
0005433715916	7449	Economy	10700.00
0005433690923	7449	Economy	10700.00
0005433656665	7449	Economy	10700.00
0005433719134	7449	Economy	10700.00
0005432078101	7449	Economy	10700.00
0005433688807	7449	Economy	10700.00
0005433722210	7449	Economy	10700.00
0005433688805	7449	Economy	10700.00
0005433715913	7449	Economy	10700.00
0005433715491	29208	Business	32000.00
0005433656630	29208	Business	32000.00
0005433715522	29208	Business	32000.00
0005433685496	29208	Business	32000.00
0005433715489	29208	Business	32000.00
0005433688789	29208	Business	32000.00
0005433722128	29208	Business	32000.00
0005433715679	29208	Business	32000.00
0005433715411	29208	Economy	10700.00
0005435266144	29208	Economy	10700.00
0005433715125	29208	Economy	10700.00
0005433715482	29208	Economy	10700.00
0005433722121	29208	Economy	10700.00
0005433715538	29208	Economy	10700.00
0005433685497	29208	Economy	10700.00
0005433719090	29208	Economy	10700.00
0005433715424	29208	Economy	10700.00
0005433719091	29208	Economy	10700.00
0005433715617	29208	Economy	10700.00
0005433656629	29208	Economy	10700.00
0005433715568	29208	Economy	10700.00
0005433688788	29208	Economy	10700.00
0005432428925	29208	Economy	10700.00
0005433715450	29208	Economy	10700.00
0005433715639	29208	Economy	10700.00
0005433715488	29208	Economy	10700.00
0005435266145	29208	Economy	10700.00
0005433715437	29208	Economy	11700.00
0005433715638	29208	Economy	11700.00
0005433715523	29208	Economy	10700.00
0005432428924	29208	Economy	10700.00
0005433715409	29208	Economy	10700.00
0005433715310	29208	Economy	10700.00
0005433715532	29208	Economy	10700.00
0005433715483	29208	Economy	10700.00
0005433715537	29208	Economy	10700.00
0005433688794	29208	Economy	10700.00
0005432006757	29208	Economy	10700.00
0005433715586	29208	Economy	10700.00
0005433722131	29208	Economy	10700.00
0005433715616	29208	Economy	10700.00
0005433715412	29208	Economy	10700.00
0005433715277	29208	Economy	10700.00
0005433715311	29208	Economy	10700.00
0005433715484	29208	Economy	10700.00
0005432428923	29208	Economy	10700.00
0005433715278	29208	Economy	10700.00
0005433715438	29208	Economy	10700.00
0005433715569	29208	Economy	10700.00
0005433715436	29208	Economy	10700.00
0005433715818	29208	Economy	10700.00
0005433715474	29208	Economy	10700.00
0005433715610	29208	Economy	10700.00
0005433685495	29208	Economy	10700.00
0005433715576	29208	Economy	10700.00
0005433715449	29208	Economy	10700.00
0005433688786	29208	Economy	10700.00
0005432428926	29208	Economy	10700.00
0005433715481	29208	Economy	10700.00
0005433715418	29208	Economy	10700.00
0005433715126	29208	Economy	10700.00
0005433715448	29208	Economy	10700.00
0005433715509	29208	Economy	10700.00
0005433715410	29208	Economy	10700.00
0005435266146	29208	Economy	10700.00
0005433688793	29208	Economy	10700.00
0005432006756	29208	Economy	10700.00
0005432006758	29208	Economy	10700.00
0005433715480	29208	Economy	10700.00
0005433719107	29208	Economy	10700.00
0005433715400	29208	Economy	10700.00
0005433656648	29208	Economy	10700.00
0005433715533	29208	Economy	10700.00
0005433715611	29208	Economy	10700.00
0005434095253	8653	Business	36500.00
0005434182097	8653	Business	36500.00
0005434182026	8653	Business	36500.00
0005434182102	8653	Business	36500.00
0005434182060	8653	Business	36500.00
0005434095260	8653	Business	36500.00
0005434095263	8653	Economy	12200.00
0005434095264	8653	Economy	12200.00
0005434095259	8653	Economy	13400.00
0005434095265	8653	Economy	12200.00
0005434095255	8653	Economy	12200.00
0005434095258	8653	Economy	12200.00
0005434182134	8653	Economy	12200.00
0005434184655	8653	Economy	12200.00
0005434182052	8653	Economy	12200.00
0005434095257	8653	Economy	12200.00
0005434095254	8653	Economy	12200.00
0005434182098	8653	Economy	12200.00
0005434184654	8653	Economy	12200.00
0005434095262	8653	Economy	12200.00
0005434182035	8653	Economy	12200.00
0005434182108	8653	Economy	12200.00
0005434182042	8653	Economy	12200.00
0005434095251	8653	Economy	12200.00
0005434182088	8653	Economy	12200.00
0005434095256	8653	Economy	12200.00
0005434095252	8653	Economy	12200.00
0005434095261	8653	Economy	12200.00
0005434182168	11649	Business	36500.00
0005434143712	11649	Business	36500.00
0005434095156	11649	Business	36500.00
0005434326262	11649	Business	36500.00
0005434182176	11649	Economy	12200.00
0005434182164	11649	Economy	12200.00
0005434184661	11649	Economy	12200.00
0005434095154	11649	Economy	12200.00
0005434095146	11649	Economy	12200.00
0005434182170	11649	Economy	12200.00
0005434183576	11649	Economy	12200.00
0005434182172	11649	Economy	12200.00
0005434095153	11649	Economy	12200.00
0005434182175	11649	Economy	12200.00
0005434184660	11649	Economy	12200.00
0005434095134	11649	Economy	12200.00
0005434182169	11649	Economy	12200.00
0005434182165	11649	Economy	12200.00
0005434182174	11649	Economy	12200.00
0005434182171	11649	Economy	12200.00
0005434182167	11649	Economy	12200.00
0005434095122	11649	Economy	12200.00
0005434095135	11649	Economy	12200.00
0005434182166	11649	Economy	12200.00
0005434095155	11649	Economy	12200.00
0005434095097	11649	Economy	12200.00
0005434326263	11649	Economy	12200.00
0005434182173	11649	Economy	12200.00
0005433397664	1451	Business	33000.00
0005433397557	1451	Business	33000.00
0005433397437	1451	Business	33000.00
0005433397491	1451	Business	33000.00
0005433397613	1451	Business	33000.00
0005433456968	1451	Business	33000.00
0005433397433	1451	Business	33000.00
0005433397629	1451	Business	33000.00
0005433456967	1451	Economy	11000.00
0005433397432	1451	Economy	11000.00
0005433397619	1451	Economy	11000.00
0005433397585	1451	Economy	11000.00
0005433397641	1451	Economy	11000.00
0005433456966	1451	Economy	11000.00
0005432906521	1451	Economy	11000.00
0005433397589	1451	Economy	11000.00
0005433397624	1451	Economy	12100.00
0005433397429	1451	Economy	12100.00
0005433397595	1451	Economy	11000.00
0005433397592	1451	Economy	11000.00
0005433397554	1451	Economy	11000.00
0005433397436	1451	Economy	11000.00
0005432906511	1451	Economy	11000.00
0005433397473	1451	Economy	11000.00
0005433397640	1451	Economy	11000.00
0005433397806	1451	Economy	11000.00
0005433397435	1451	Economy	11000.00
0005433397665	1451	Economy	11000.00
0005433397630	1451	Economy	11000.00
0005433397722	1451	Economy	11000.00
0005433397614	1451	Economy	11000.00
0005432906503	1451	Economy	11000.00
0005433397247	1451	Economy	11000.00
0005433397510	1451	Economy	11000.00
0005433397503	1451	Economy	11000.00
0005433397718	1451	Economy	11000.00
0005433397434	1451	Economy	11000.00
0005433397661	1451	Economy	11000.00
0005432906502	1451	Economy	11000.00
0005433397542	1451	Economy	11000.00
0005433397738	1451	Economy	11000.00
0005433397623	1451	Economy	11000.00
0005433397689	1451	Economy	11000.00
0005433397477	1451	Economy	11000.00
0005433397604	1451	Economy	11000.00
0005433397453	1451	Economy	11000.00
0005433456963	1451	Economy	11000.00
0005433397717	1451	Economy	11000.00
0005433397617	1451	Economy	11000.00
0005433397839	1451	Economy	11000.00
0005433397591	1451	Economy	11000.00
0005433397739	1451	Economy	11000.00
0005433456965	1451	Economy	11000.00
0005433397575	1451	Economy	11000.00
0005433397666	1451	Economy	11000.00
0005433397403	1451	Economy	11000.00
0005432297274	1451	Economy	11000.00
0005433397852	1451	Economy	11000.00
0005433397603	1451	Economy	11000.00
0005433397574	1451	Economy	11000.00
0005433397558	1451	Economy	11000.00
0005433397526	1451	Economy	11000.00
0005433397511	1451	Economy	11000.00
0005433397620	1451	Economy	11000.00
0005433456964	1451	Economy	11000.00
0005433397677	1451	Economy	11000.00
0005433397631	1451	Economy	11000.00
0005433397698	1451	Economy	11000.00
0005433397571	1451	Economy	11000.00
0005433397755	1451	Economy	11000.00
0005432297275	1451	Economy	11000.00
0005433397576	1451	Economy	11000.00
0005433397555	1451	Economy	11000.00
0005433397975	19262	Business	33000.00
0005432906532	19262	Business	33000.00
0005433398004	19262	Business	33000.00
0005433398007	19262	Business	33000.00
0005435732241	19262	Business	33000.00
0005433398008	19262	Business	33000.00
0005433398001	19262	Economy	11000.00
0005433397990	19262	Economy	11000.00
0005433397980	19262	Economy	11000.00
0005433398013	19262	Economy	11000.00
0005433397989	19262	Economy	11000.00
0005433397994	19262	Economy	11000.00
0005433397983	19262	Economy	12100.00
0005433398002	19262	Economy	12100.00
0005433397993	19262	Economy	12100.00
0005433397979	19262	Economy	12100.00
0005433456931	19262	Economy	11000.00
0005433398020	19262	Economy	11000.00
0005433397978	19262	Economy	11000.00
0005435732186	19262	Economy	11000.00
0005435732265	19262	Economy	11000.00
0005433398012	19262	Economy	11000.00
0005433397985	19262	Economy	11000.00
0005433397977	19262	Economy	11000.00
0005435732228	19262	Economy	11000.00
0005433397981	19262	Economy	11000.00
0005433456935	19262	Economy	11000.00
0005435732225	19262	Economy	11000.00
0005435732242	19262	Economy	11000.00
0005433398014	19262	Economy	11000.00
0005433397991	19262	Economy	11000.00
0005433398016	19262	Economy	11000.00
0005433397987	19262	Economy	11000.00
0005433397976	19262	Economy	11000.00
0005433398006	19262	Economy	11000.00
0005433398003	19262	Economy	11000.00
0005433398023	19262	Economy	11000.00
0005433398011	19262	Economy	11000.00
0005433398005	19262	Economy	11000.00
0005433398021	19262	Economy	11000.00
0005433397995	19262	Economy	11000.00
0005435732206	19262	Economy	11000.00
0005433398010	19262	Economy	11000.00
0005433398019	19262	Economy	11000.00
0005433397992	19262	Economy	11000.00
0005433398018	19262	Economy	11000.00
0005433397997	19262	Economy	11000.00
0005435732266	19262	Economy	11000.00
0005433397999	19262	Economy	11000.00
0005432906533	19262	Economy	11000.00
0005433397996	19262	Economy	11000.00
0005433398009	19262	Economy	11000.00
0005433397998	19262	Economy	11000.00
0005435732232	19262	Economy	11000.00
0005433397984	19262	Economy	11000.00
0005433397982	19262	Economy	11000.00
0005433398015	19262	Economy	11000.00
0005433398017	19262	Economy	11000.00
0005433397986	19262	Economy	11000.00
0005433398022	19262	Economy	11000.00
0005435732200	19262	Economy	11000.00
0005433398000	19262	Economy	11000.00
0005433397988	19262	Economy	11000.00
0005434443536	17352	Economy	15600.00
0005434443578	17352	Economy	14100.00
0005434443499	17352	Economy	14100.00
0005434443527	17352	Economy	14100.00
0005434443634	17352	Economy	14100.00
0005434443600	17352	Economy	14100.00
0005434443604	17352	Economy	14100.00
0005434443544	17352	Economy	14100.00
0005434443508	17352	Economy	14100.00
0005434443509	17352	Economy	14100.00
0005434443528	17352	Economy	14100.00
0005434443559	17352	Economy	14100.00
0005434443560	17352	Economy	14100.00
0005434443541	17352	Economy	14100.00
0005434443603	17352	Economy	14100.00
0005434443675	20602	Economy	14100.00
0005434443677	20602	Economy	14100.00
0005434443671	20602	Economy	14100.00
0005434443678	20602	Economy	14100.00
0005434443673	20602	Economy	14100.00
0005434443672	20602	Economy	14100.00
0005434443684	20602	Economy	14100.00
0005434443674	20602	Economy	14100.00
0005434443676	20602	Economy	14100.00
0005434443679	20602	Economy	14100.00
0005434443683	20602	Economy	14100.00
0005434443680	20602	Economy	14100.00
0005434443681	20602	Economy	14100.00
0005434443686	20602	Economy	14100.00
0005434443687	20602	Economy	14100.00
0005434443682	20602	Economy	14100.00
0005434443685	20602	Economy	14100.00
0005435377555	7274	Economy	5800.00
0005435377564	7274	Economy	5800.00
0005434954604	7274	Economy	5800.00
0005434954603	7274	Economy	5800.00
0005434954605	7274	Economy	5800.00
0005435377563	7274	Economy	5800.00
0005435377565	7274	Economy	5800.00
0005435377561	7274	Economy	5800.00
0005434954602	7274	Economy	5800.00
0005434954572	28353	Economy	5800.00
0005435377577	28353	Economy	5800.00
0005435377578	28353	Economy	5800.00
0005434954571	28353	Economy	5800.00
0005435377576	28353	Economy	5800.00
0005434183553	4457	Economy	15400.00
0005435893556	4457	Economy	15400.00
0005434351676	4457	Economy	14000.00
0005435893533	4457	Economy	14000.00
0005435893557	4457	Economy	14000.00
0005434351682	4457	Economy	14000.00
0005434351683	4457	Economy	14000.00
0005434183563	4457	Economy	14000.00
0005434351678	4457	Economy	14000.00
0005435893559	4457	Economy	14000.00
0005434351680	4457	Economy	14000.00
0005434351681	4457	Economy	14000.00
0005434351677	4457	Economy	14000.00
0005434351685	4457	Economy	14000.00
0005434351679	4457	Economy	14000.00
0005434351675	4457	Economy	14000.00
0005434351684	4457	Economy	14000.00
0005435893560	4457	Economy	14000.00
0005434351674	4457	Economy	14000.00
0005434183554	4457	Economy	14000.00
0005434351561	29634	Economy	15400.00
0005435893624	29634	Economy	14000.00
0005434351571	29634	Economy	14000.00
0005434351578	29634	Economy	14000.00
0005435893620	29634	Economy	14000.00
0005435893625	29634	Economy	14000.00
0005434351623	29634	Economy	14000.00
0005435893622	29634	Economy	14000.00
0005435893626	29634	Economy	14000.00
0005434351577	29634	Economy	14000.00
0005434351566	29634	Economy	14000.00
0005434351624	29634	Economy	14000.00
0005434351600	29634	Economy	14000.00
0005434351546	29634	Economy	14000.00
0005434351541	29634	Economy	14000.00
0005434351543	29634	Economy	14000.00
0005435893621	29634	Economy	14000.00
0005435893619	29634	Economy	14000.00
0005434351564	29634	Economy	14000.00
0005434351573	29634	Economy	14000.00
0005435893623	29634	Economy	14000.00
0005434351572	29634	Economy	14000.00
0005434351547	29634	Economy	14000.00
0005433342114	1068	Business	30600.00
0005433269682	1068	Business	30600.00
0005433342168	1068	Business	30600.00
0005432293205	1068	Business	30600.00
0005435092063	1068	Business	30600.00
0005433342397	1068	Business	30600.00
0005433342345	1068	Business	30600.00
0005435092060	1068	Business	30600.00
0005435092065	1068	Business	30600.00
0005433341529	1068	Business	30600.00
0005433158108	1068	Business	30600.00
0005435092064	1068	Business	30600.00
0005433341780	1068	Business	30600.00
0005435545735	1068	Business	30600.00
0005433342351	1068	Business	30600.00
0005433341955	1068	Business	30600.00
0005433342147	1068	Economy	11200.00
0005435545732	1068	Business	30600.00
0005433342200	1068	Economy	11200.00
0005435092066	1068	Economy	11200.00
0005433342186	1068	Economy	10200.00
0005433342112	1068	Economy	10200.00
0005435545734	1068	Economy	10200.00
0005433462743	1068	Economy	10200.00
0005433341884	1068	Economy	10200.00
0005433342233	1068	Economy	10200.00
0005433342089	1068	Economy	10200.00
0005433342132	1068	Economy	10200.00
0005435545727	1068	Economy	10200.00
0005433159289	1068	Economy	10200.00
0005433341735	1068	Economy	10200.00
0005433342398	1068	Economy	10200.00
0005433341708	1068	Economy	10200.00
0005435545726	1068	Economy	10200.00
0005433342006	1068	Economy	10200.00
0005433342007	1068	Economy	10200.00
0005433341472	1068	Economy	10200.00
0005433342119	1068	Economy	10200.00
0005433342090	1068	Economy	10200.00
0005435545728	1068	Economy	10200.00
0005433342416	1068	Economy	10200.00
0005433342153	1068	Economy	10200.00
0005433342117	1068	Economy	10200.00
0005433462744	1068	Economy	10200.00
0005433341778	1068	Economy	10200.00
0005433342293	1068	Economy	10200.00
0005433342154	1068	Economy	10200.00
0005435545733	1068	Economy	10200.00
0005433341736	1068	Economy	10200.00
0005435092056	1068	Economy	10200.00
0005433342170	1068	Economy	10200.00
0005433341928	1068	Economy	10200.00
0005433342134	1068	Economy	10200.00
0005433269654	1068	Economy	10200.00
0005433341775	1068	Economy	10200.00
0005433463897	1068	Economy	10200.00
0005433342146	1068	Economy	10200.00
0005433341608	1068	Economy	10200.00
0005433342268	1068	Economy	10200.00
0005433341878	1068	Economy	10200.00
0005433342091	1068	Economy	10200.00
0005433342289	1068	Economy	10200.00
0005435545724	1068	Economy	10200.00
0005433342113	1068	Economy	10200.00
0005433341879	1068	Economy	10200.00
0005433342386	1068	Economy	10200.00
0005432293206	1068	Economy	10200.00
0005433342267	1068	Economy	10200.00
0005435092059	1068	Economy	10200.00
0005433342169	1068	Economy	10200.00
0005433342069	1068	Economy	10200.00
0005433342253	1068	Economy	10200.00
0005433342092	1068	Economy	10200.00
0005433342252	1068	Economy	10200.00
0005433342008	1068	Economy	10200.00
0005433463898	1068	Economy	10200.00
0005435545729	1068	Economy	10200.00
0005435545731	1068	Economy	11200.00
0005433342266	1068	Economy	11200.00
0005435092061	1068	Economy	10200.00
0005433341642	1068	Economy	11200.00
0005433342137	1068	Economy	10200.00
0005433342009	1068	Economy	10200.00
0005433341822	1068	Economy	10200.00
0005434445244	1068	Economy	10200.00
0005433159296	1068	Economy	10200.00
0005433341528	1068	Economy	10200.00
0005433342128	1068	Economy	10200.00
0005433342350	1068	Economy	10200.00
0005435545730	1068	Economy	10200.00
0005433342387	1068	Economy	10200.00
0005433342201	1068	Economy	10200.00
0005435092057	1068	Economy	10200.00
0005433342148	1068	Economy	10200.00
0005434445246	1068	Economy	10200.00
0005433341924	1068	Economy	10200.00
0005433342135	1068	Economy	10200.00
0005433342136	1068	Economy	10200.00
0005433342247	1068	Economy	10200.00
0005433342123	1068	Economy	10200.00
0005433159297	1068	Economy	10200.00
0005433342227	1068	Economy	10200.00
0005433341590	1068	Economy	10200.00
0005433342389	1068	Economy	10200.00
0005433342234	1068	Economy	10200.00
0005435092058	1068	Economy	10200.00
0005434445245	1068	Economy	10200.00
0005433342015	1068	Economy	10200.00
0005433342235	1068	Economy	10200.00
0005433342279	1068	Economy	10200.00
0005433342292	1068	Economy	10200.00
0005433342352	1068	Economy	10200.00
0005434446518	1068	Economy	10200.00
0005433342005	1068	Economy	10200.00
0005433269683	1068	Economy	10200.00
0005435092062	1068	Economy	10200.00
0005433342344	1068	Economy	10200.00
0005435545723	1068	Economy	10200.00
0005435545725	1068	Economy	10200.00
0005433341758	1068	Economy	10200.00
0005433342166	1068	Economy	10200.00
0005433342010	1068	Economy	10200.00
0005433342027	1068	Economy	10200.00
0005433342396	1068	Economy	10200.00
0005433342140	1068	Economy	10200.00
0005433158107	1068	Economy	10200.00
0005433341960	1068	Economy	10200.00
0005435508269	17055	Business	30600.00
0005433342964	17055	Business	30600.00
0005435092018	17055	Business	30600.00
0005433342950	17055	Business	30600.00
0005433342931	17055	Business	30600.00
0005433342989	17055	Business	30600.00
0005433342926	17055	Business	30600.00
0005433342993	17055	Business	30600.00
0005433342985	17055	Business	30600.00
0005433342976	17055	Business	30600.00
0005433342980	17055	Business	30600.00
0005433269713	17055	Business	30600.00
0005433159308	17055	Business	30600.00
0005433342965	17055	Business	30600.00
0005433342974	17055	Business	30600.00
0005433342956	17055	Business	30600.00
0005433342943	17055	Business	30600.00
0005435508213	17055	Business	30600.00
0005435091944	17055	Economy	11200.00
0005434445223	17055	Economy	11200.00
0005433342934	17055	Economy	10200.00
0005433342958	17055	Economy	10200.00
0005433342981	17055	Economy	10200.00
0005433342960	17055	Economy	10200.00
0005433342938	17055	Economy	10200.00
0005433342971	17055	Economy	10200.00
0005435091997	17055	Economy	10200.00
0005433342930	17055	Economy	10200.00
0005433342913	17055	Economy	10200.00
0005433342944	17055	Economy	10200.00
0005435508273	17055	Economy	10200.00
0005435092004	17055	Economy	10200.00
0005434445217	17055	Economy	10200.00
0005433269714	17055	Economy	10200.00
0005435508234	17055	Economy	10200.00
0005435508240	17055	Economy	10200.00
0005433342919	17055	Economy	10200.00
0005433342925	17055	Economy	10200.00
0005433269712	17055	Economy	10200.00
0005433342990	17055	Economy	10200.00
0005433342921	17055	Economy	10200.00
0005435508268	17055	Economy	10200.00
0005433342968	17055	Economy	10200.00
0005435091974	17055	Economy	10200.00
0005433342983	17055	Economy	10200.00
0005433342933	17055	Economy	10200.00
0005433342984	17055	Economy	10200.00
0005433342987	17055	Economy	10200.00
0005433342929	17055	Economy	10200.00
0005433342973	17055	Economy	10200.00
0005433342945	17055	Economy	10200.00
0005433342911	17055	Economy	10200.00
0005435508254	17055	Economy	10200.00
0005433342972	17055	Economy	10200.00
0005433159309	17055	Economy	10200.00
0005433342948	17055	Economy	10200.00
0005433342914	17055	Economy	10200.00
0005433269709	17055	Economy	10200.00
0005433342998	17055	Economy	10200.00
0005433342988	17055	Economy	10200.00
0005433342917	17055	Economy	10200.00
0005433342909	17055	Economy	10200.00
0005433342978	17055	Economy	10200.00
0005433343001	17055	Economy	10200.00
0005433342923	17055	Economy	10200.00
0005435508241	17055	Economy	10200.00
0005433342961	17055	Economy	10200.00
0005433342970	17055	Economy	10200.00
0005435508229	17055	Economy	10200.00
0005433342939	17055	Economy	10200.00
0005433342977	17055	Economy	10200.00
0005435508296	17055	Economy	10200.00
0005433342936	17055	Economy	10200.00
0005435091998	17055	Economy	10200.00
0005433342922	17055	Economy	10200.00
0005435508255	17055	Economy	10200.00
0005434445218	17055	Economy	10200.00
0005433342996	17055	Economy	10200.00
0005433342952	17055	Economy	10200.00
0005433342994	17055	Economy	10200.00
0005433342920	17055	Economy	10200.00
0005435091999	17055	Economy	10200.00
0005433343000	17055	Economy	10200.00
0005433342942	17055	Economy	10200.00
0005433342918	17055	Economy	10200.00
0005433343003	17055	Economy	11200.00
0005433342912	17055	Economy	10200.00
0005433342924	17055	Economy	10200.00
0005435508291	17055	Economy	11200.00
0005433342959	17055	Economy	10200.00
0005433342999	17055	Economy	10200.00
0005433342969	17055	Economy	10200.00
0005435508290	17055	Economy	10200.00
0005433342957	17055	Economy	10200.00
0005433343002	17055	Economy	10200.00
0005433342997	17055	Economy	10200.00
0005433342953	17055	Economy	10200.00
0005433342995	17055	Economy	10200.00
0005433342949	17055	Economy	10200.00
0005433342928	17055	Economy	10200.00
0005433342982	17055	Economy	10200.00
0005433343005	17055	Economy	10200.00
0005433342979	17055	Economy	10200.00
0005433342966	17055	Economy	10200.00
0005433342962	17055	Economy	10200.00
0005435091987	17055	Economy	10200.00
0005433342916	17055	Economy	10200.00
0005434445214	17055	Economy	10200.00
0005433342941	17055	Economy	10200.00
0005433342986	17055	Economy	10200.00
0005435092005	17055	Economy	10200.00
0005433342947	17055	Economy	10200.00
0005433342951	17055	Economy	10200.00
0005433342915	17055	Economy	10200.00
0005435508214	17055	Economy	10200.00
0005433343004	17055	Economy	10200.00
0005433342955	17055	Economy	10200.00
0005433342935	17055	Economy	10200.00
0005433342967	17055	Economy	10200.00
0005433342932	17055	Economy	10200.00
0005433342963	17055	Economy	10200.00
0005433342940	17055	Economy	10200.00
0005433342992	17055	Economy	10200.00
0005433343007	17055	Economy	10200.00
0005433342927	17055	Economy	10200.00
0005433342991	17055	Economy	10200.00
0005433342910	17055	Economy	10200.00
0005433342946	17055	Economy	10200.00
0005433342954	17055	Economy	10200.00
0005433342937	17055	Economy	10200.00
0005433269710	17055	Economy	10200.00
0005433342975	17055	Economy	10200.00
0005433269711	17055	Economy	10200.00
0005433343006	17055	Economy	10200.00
0005433342908	17055	Economy	10200.00
0005433343008	17055	Economy	10200.00
0005432391986	1339	Business	101000.00
0005432390130	1339	Business	101000.00
0005432851859	1339	Business	101000.00
0005432391987	1339	Business	101000.00
0005432851854	1339	Business	101000.00
0005432851852	1339	Business	101000.00
0005432390134	1339	Business	101000.00
0005432390103	1339	Business	101000.00
0005432390106	1339	Business	101000.00
0005432390122	1339	Business	101000.00
0005432390119	1339	Business	101000.00
0005432391989	1339	Business	101000.00
0005432390107	1339	Business	101000.00
0005432390125	1339	Economy	33700.00
0005432851874	1339	Business	101000.00
0005432390126	1339	Economy	33700.00
0005432391992	1339	Economy	33700.00
0005432390101	1339	Economy	33700.00
0005432390127	1339	Economy	33700.00
0005432390099	1339	Economy	33700.00
0005432390118	1339	Economy	37000.00
0005432390129	1339	Economy	37000.00
0005432390133	1339	Economy	33700.00
0005432390108	1339	Economy	33700.00
0005432391991	1339	Economy	33700.00
0005432390104	1339	Economy	33700.00
0005432390121	1339	Economy	33700.00
0005432851840	1339	Economy	33700.00
0005432390112	1339	Economy	33700.00
0005432851851	1339	Economy	33700.00
0005432851849	1339	Economy	33700.00
0005432391994	1339	Economy	33700.00
0005432851841	1339	Economy	33700.00
0005432390116	1339	Economy	33700.00
0005432851839	1339	Economy	33700.00
0005432851853	1339	Economy	33700.00
0005432851824	1339	Economy	33700.00
0005432390117	1339	Economy	33700.00
0005432390113	1339	Economy	33700.00
0005432390115	1339	Economy	33700.00
0005432390100	1339	Economy	33700.00
0005432390120	1339	Economy	33700.00
0005432391990	1339	Economy	33700.00
0005432851875	1339	Economy	33700.00
0005432390124	1339	Economy	33700.00
0005432390109	1339	Economy	33700.00
0005432391988	1339	Economy	33700.00
0005432851857	1339	Economy	33700.00
0005432851850	1339	Economy	33700.00
0005432851855	1339	Economy	33700.00
0005432851873	1339	Economy	33700.00
0005432390114	1339	Economy	33700.00
0005432851872	1339	Economy	33700.00
0005432390131	1339	Economy	33700.00
0005432390128	1339	Economy	33700.00
0005432390123	1339	Economy	33700.00
0005432851860	1339	Economy	33700.00
0005432390132	1339	Economy	33700.00
0005432390102	1339	Economy	33700.00
0005432390110	1339	Economy	33700.00
0005432390111	1339	Economy	33700.00
0005432390105	1339	Economy	33700.00
0005432391993	1339	Economy	33700.00
0005434066900	12814	Business	40300.00
0005434081585	12814	Business	40300.00
0005434081630	12814	Business	40300.00
0005432159851	12814	Business	40300.00
0005434081675	12814	Business	40300.00
0005434066871	12814	Business	40300.00
0005432433676	12814	Business	40300.00
0005434066656	12814	Business	40300.00
0005434081672	12814	Business	40300.00
0005434066794	12814	Business	40300.00
0005434066887	12814	Economy	13400.00
0005434066824	12814	Economy	13400.00
0005432159853	12814	Economy	13400.00
0005434066853	12814	Economy	13400.00
0005432433672	12814	Economy	13400.00
0005433989725	12814	Economy	13400.00
0005434066748	12814	Economy	13400.00
0005434067111	12814	Economy	13400.00
0005434066829	12814	Economy	13400.00
0005434081683	12814	Economy	13400.00
0005434066836	12814	Economy	13400.00
0005434067001	12814	Economy	13400.00
0005432159854	12814	Economy	13400.00
0005433812898	12814	Economy	13400.00
0005432433674	12814	Economy	13400.00
0005434066892	12814	Economy	13400.00
0005434066999	12814	Economy	13400.00
0005434066612	12814	Economy	13400.00
0005434066823	12814	Economy	13400.00
0005434066658	12814	Economy	13400.00
0005432433675	12814	Economy	13400.00
0005434081652	12814	Economy	13400.00
0005434081660	12814	Economy	13400.00
0005434081705	12814	Economy	13400.00
0005434081709	12814	Economy	13400.00
0005434081595	12814	Economy	13400.00
0005434067000	12814	Economy	13400.00
0005434066695	12814	Economy	13400.00
0005434066806	12814	Economy	13400.00
0005433989713	12814	Economy	13400.00
0005434066939	12814	Economy	13400.00
0005434066954	12814	Economy	13400.00
0005434066676	12814	Economy	13400.00
0005434066674	12814	Economy	13400.00
0005434066795	12814	Economy	13400.00
0005434066531	12814	Economy	13400.00
0005432161149	12814	Economy	13400.00
0005434066530	12814	Economy	13400.00
0005434066766	12814	Economy	13400.00
0005434066652	12814	Economy	13400.00
0005434081531	12814	Economy	14800.00
0005434067182	12814	Economy	14800.00
0005434066797	12814	Economy	14800.00
0005434066718	12814	Economy	14800.00
0005434081584	12814	Economy	14800.00
0005434066895	12814	Economy	14800.00
0005434066611	12814	Economy	13400.00
0005434066866	12814	Economy	13400.00
0005432161150	12814	Economy	13400.00
0005434066949	12814	Economy	13400.00
0005434066485	12814	Economy	13400.00
0005434066597	12814	Economy	13400.00
0005434081591	12814	Economy	13400.00
0005433812897	12814	Economy	13400.00
0005432433673	12814	Economy	13400.00
0005434081537	12814	Economy	13400.00
0005434066796	12814	Economy	13400.00
0005434066678	12814	Economy	13400.00
0005434081649	12814	Economy	13400.00
0005434066894	12814	Economy	13400.00
0005434081718	12814	Economy	13400.00
0005434066854	12814	Economy	13400.00
0005434081659	12814	Economy	13400.00
0005434066526	12814	Economy	13400.00
0005434081699	12814	Economy	13400.00
0005434067054	12814	Economy	13400.00
0005434066599	12814	Economy	13400.00
0005434066706	12814	Economy	13400.00
0005434066953	12814	Economy	13400.00
0005434066709	12814	Economy	13400.00
0005434067181	12814	Economy	13400.00
0005432433670	12814	Economy	13400.00
0005434066675	12814	Economy	13400.00
0005434081674	12814	Economy	13400.00
0005434066916	12814	Economy	13400.00
0005432433671	12814	Economy	13400.00
0005434081703	12814	Economy	13400.00
0005434081668	12814	Economy	13400.00
0005434026684	12814	Economy	13400.00
0005434066838	12814	Economy	13400.00
0005434081635	12814	Economy	13400.00
0005434066810	12814	Economy	13400.00
0005434066525	12814	Economy	13400.00
0005433812896	12814	Economy	13400.00
0005434066919	12814	Economy	13400.00
0005434081543	12814	Economy	13400.00
0005434066938	12814	Economy	13400.00
0005434081629	12814	Economy	13400.00
0005434066917	12814	Economy	13400.00
0005434066624	12814	Economy	13400.00
0005434066623	12814	Economy	13400.00
0005434081704	12814	Economy	13400.00
0005434066598	12814	Economy	13400.00
0005434066837	12814	Economy	13400.00
0005434066610	12814	Economy	13400.00
0005434066893	12814	Economy	13400.00
0005434066872	12814	Economy	13400.00
0005434066780	12814	Economy	13400.00
0005434066445	12814	Economy	13400.00
0005434081583	12814	Economy	13400.00
0005434081698	12814	Economy	13400.00
0005434067055	12814	Economy	13400.00
0005434081671	12814	Economy	13400.00
0005434066769	12814	Economy	13400.00
0005434081701	12814	Economy	13400.00
0005434066856	12814	Economy	13400.00
0005434066873	12814	Economy	13400.00
0005434067134	12814	Economy	13400.00
0005432159852	12814	Economy	13400.00
0005434081592	12814	Economy	13400.00
0005434081700	12814	Economy	13400.00
0005434066339	12814	Economy	13400.00
0005434066948	12814	Economy	13400.00
0005434066798	12814	Economy	13400.00
0005433989735	12814	Economy	13400.00
0005434066852	12814	Economy	13400.00
0005434066855	12814	Economy	13400.00
0005434067452	30677	Business	40300.00
0005433989762	30677	Business	40300.00
0005434081849	30677	Business	40300.00
0005433989759	30677	Business	40300.00
0005434067416	30677	Business	40300.00
0005434067437	30677	Business	40300.00
0005432186862	30677	Business	40300.00
0005434081854	30677	Business	40300.00
0005434067448	30677	Business	40300.00
0005432150179	30677	Business	40300.00
0005434081851	30677	Business	40300.00
0005434067447	30677	Business	40300.00
0005434067453	30677	Economy	13400.00
0005434081848	30677	Economy	13400.00
0005434081845	30677	Economy	13400.00
0005432433623	30677	Economy	13400.00
0005434067421	30677	Economy	13400.00
0005434067426	30677	Economy	13400.00
0005432186861	30677	Economy	13400.00
0005434067444	30677	Economy	13400.00
0005434067427	30677	Economy	13400.00
0005434067430	30677	Economy	13400.00
0005434067449	30677	Economy	13400.00
0005434067413	30677	Economy	13400.00
0005434067440	30677	Economy	13400.00
0005434067417	30677	Economy	13400.00
0005434067445	30677	Economy	13400.00
0005434067395	30677	Economy	13400.00
0005434067410	30677	Economy	13400.00
0005434067399	30677	Economy	13400.00
0005434067412	30677	Economy	13400.00
0005434067425	30677	Economy	13400.00
0005434067419	30677	Economy	13400.00
0005434081855	30677	Economy	13400.00
0005434067392	30677	Economy	13400.00
0005434067454	30677	Economy	13400.00
0005434067385	30677	Economy	13400.00
0005434067406	30677	Economy	13400.00
0005432150176	30677	Economy	13400.00
0005434067409	30677	Economy	13400.00
0005434067423	30677	Economy	13400.00
0005434067394	30677	Economy	13400.00
0005434067408	30677	Economy	13400.00
0005434067434	30677	Economy	13400.00
0005434067422	30677	Economy	14800.00
0005434067390	30677	Economy	14800.00
0005434067402	30677	Economy	14800.00
0005434067438	30677	Economy	14800.00
0005432433624	30677	Economy	14800.00
0005434081847	30677	Economy	14800.00
0005434067400	30677	Economy	13400.00
0005434067446	30677	Economy	13400.00
0005434067433	30677	Economy	13400.00
0005432186863	30677	Economy	13400.00
0005434067428	30677	Economy	13400.00
0005432433631	30677	Economy	13400.00
0005432186860	30677	Economy	13400.00
0005434067429	30677	Economy	13400.00
0005434067420	30677	Economy	13400.00
0005434081856	30677	Economy	13400.00
0005434067443	30677	Economy	13400.00
0005434067387	30677	Economy	13400.00
0005434067397	30677	Economy	13400.00
0005434081846	30677	Economy	13400.00
0005432150177	30677	Economy	13400.00
0005434067455	30677	Economy	13400.00
0005432433616	30677	Economy	13400.00
0005434081841	30677	Economy	13400.00
0005434081853	30677	Economy	13400.00
0005434081852	30677	Economy	13400.00
0005432433615	30677	Economy	13400.00
0005434081840	30677	Economy	13400.00
0005434081838	30677	Economy	13400.00
0005434067411	30677	Economy	13400.00
0005434067398	30677	Economy	13400.00
0005434067431	30677	Economy	13400.00
0005434067389	30677	Economy	13400.00
0005434081837	30677	Economy	13400.00
0005434067435	30677	Economy	13400.00
0005434067424	30677	Economy	13400.00
0005434067414	30677	Economy	13400.00
0005434067456	30677	Economy	13400.00
0005433989763	30677	Economy	13400.00
0005434067388	30677	Economy	13400.00
0005432150182	30677	Economy	13400.00
0005434067405	30677	Economy	13400.00
0005434081839	30677	Economy	13400.00
0005434067404	30677	Economy	13400.00
0005433989761	30677	Economy	13400.00
0005434067432	30677	Economy	13400.00
0005434067418	30677	Economy	13400.00
0005434067450	30677	Economy	13400.00
0005434067403	30677	Economy	13400.00
0005434067407	30677	Economy	13400.00
0005434067451	30677	Economy	13400.00
0005434067391	30677	Economy	13400.00
0005434067396	30677	Economy	13400.00
0005434067441	30677	Economy	13400.00
0005434067384	30677	Economy	13400.00
0005434081843	30677	Economy	13400.00
0005434067442	30677	Economy	13400.00
0005434067415	30677	Economy	13400.00
0005434067401	30677	Economy	13400.00
0005434067393	30677	Economy	13400.00
0005434081844	30677	Economy	13400.00
0005432150180	30677	Economy	13400.00
0005432150178	30677	Economy	13400.00
0005432150181	30677	Economy	13400.00
0005434081850	30677	Economy	13400.00
0005434081857	30677	Economy	13400.00
0005433989760	30677	Economy	13400.00
0005434067439	30677	Economy	13400.00
0005434081842	30677	Economy	13400.00
0005432150175	30677	Economy	13400.00
0005434067436	30677	Economy	13400.00
0005434067386	30677	Economy	13400.00
0005434081858	30677	Economy	13400.00
0005435723042	5523	Business	35300.00
0005435461942	5523	Business	35300.00
0005435766173	5523	Business	35300.00
0005435461929	5523	Business	35300.00
0005435462212	5523	Business	35300.00
0005435462019	5523	Business	35300.00
0005435766172	5523	Business	35300.00
0005435723041	5523	Business	35300.00
0005433529275	5523	Business	35300.00
0005435462031	5523	Business	35300.00
0005435462032	5523	Business	35300.00
0005435462003	5523	Business	35300.00
0005435722052	5523	Business	35300.00
0005435766143	5523	Business	35300.00
0005435462016	5523	Business	35300.00
0005435766163	5523	Business	35300.00
0005432535787	5523	Business	35300.00
0005434264926	5523	Business	35300.00
0005435766171	5523	Business	35300.00
0005435735131	5523	Business	35300.00
0005435462082	5523	Business	35300.00
0005435766181	5523	Economy	12900.00
0005435462035	5523	Economy	12900.00
0005433529273	5523	Economy	12900.00
0005433527262	5523	Economy	11800.00
0005432140439	5523	Economy	11800.00
0005435462208	5523	Economy	11800.00
0005435462022	5523	Economy	11800.00
0005434264771	5523	Economy	11800.00
0005433527263	5523	Economy	11800.00
0005435766154	5523	Economy	11800.00
0005435462107	5523	Economy	11800.00
0005435766142	5523	Economy	11800.00
0005434264940	5523	Economy	11800.00
0005435766160	5523	Economy	11800.00
0005433527264	5523	Economy	11800.00
0005432535775	5523	Economy	11800.00
0005434264814	5523	Economy	11800.00
0005435725592	5523	Economy	11800.00
0005435461951	5523	Economy	11800.00
0005435461952	5523	Economy	11800.00
0005435462093	5523	Economy	11800.00
0005432140442	5523	Economy	11800.00
0005433529274	5523	Economy	11800.00
0005435766152	5523	Economy	11800.00
0005434264986	5523	Economy	11800.00
0005435462153	5523	Economy	11800.00
0005435766187	5523	Economy	11800.00
0005435735133	5523	Economy	11800.00
0005435766162	5523	Economy	11800.00
0005435766150	5523	Economy	11800.00
0005434265027	5523	Economy	11800.00
0005432535786	5523	Economy	11800.00
0005435766169	5523	Economy	11800.00
0005434264806	5523	Economy	11800.00
0005435766174	5523	Economy	11800.00
0005434264796	5523	Economy	11800.00
0005435766147	5523	Economy	11800.00
0005435766186	5523	Economy	11800.00
0005435461958	5523	Economy	11800.00
0005435462033	5523	Economy	11800.00
0005434264862	5523	Economy	11800.00
0005435735132	5523	Economy	11800.00
0005434264830	5523	Economy	11800.00
0005434264829	5523	Economy	11800.00
0005435766146	5523	Economy	11800.00
0005435766182	5523	Economy	11800.00
0005434264845	5523	Economy	11800.00
0005435766167	5523	Economy	11800.00
0005433529276	5523	Economy	11800.00
0005435766141	5523	Economy	11800.00
0005434264809	5523	Economy	11800.00
0005435462034	5523	Economy	11800.00
0005433527261	5523	Economy	11800.00
0005432140440	5523	Economy	11800.00
0005435462122	5523	Economy	11800.00
0005434831089	5523	Economy	11800.00
0005432140435	5523	Economy	11800.00
0005435462005	5523	Economy	11800.00
0005435766161	5523	Economy	11800.00
0005435766145	5523	Economy	11800.00
0005434264764	5523	Economy	11800.00
0005435462109	5523	Economy	11800.00
0005435462155	5523	Economy	11800.00
0005434264863	5523	Economy	11800.00
0005434264807	5523	Economy	11800.00
0005432140441	5523	Economy	11800.00
0005432140433	5523	Economy	11800.00
0005435766168	5523	Economy	11800.00
0005435766177	5523	Economy	11800.00
0005435766148	5523	Economy	11800.00
0005435725591	5523	Economy	11800.00
0005435462021	5523	Economy	11800.00
0005435462116	5523	Economy	11800.00
0005435462004	5523	Economy	11800.00
0005434264867	5523	Economy	11800.00
0005435766165	5523	Economy	11800.00
0005432535793	5523	Economy	11800.00
0005435461978	5523	Economy	11800.00
0005434264939	5523	Economy	11800.00
0005435766176	5523	Economy	11800.00
0005435766178	5523	Economy	12900.00
0005435766166	5523	Economy	11800.00
0005435462055	5523	Economy	12900.00
0005432535760	5523	Economy	12900.00
0005435722053	5523	Economy	11800.00
0005435766183	5523	Economy	11800.00
0005435766185	5523	Economy	11800.00
0005435766179	5523	Economy	11800.00
0005435766139	5523	Economy	11800.00
0005435462083	5523	Economy	11800.00
0005435725590	5523	Economy	11800.00
0005432535761	5523	Economy	11800.00
0005434264772	5523	Economy	11800.00
0005435766164	5523	Economy	11800.00
0005432140434	5523	Economy	11800.00
0005435461948	5523	Economy	11800.00
0005435766144	5523	Economy	11800.00
0005435461939	5523	Economy	11800.00
0005434264920	5523	Economy	11800.00
0005435722051	5523	Economy	11800.00
0005435766140	5523	Economy	11800.00
0005435461953	5523	Economy	11800.00
0005434264916	5523	Economy	11800.00
0005435766153	5523	Economy	11800.00
0005435766151	5523	Economy	11800.00
0005435462094	5523	Economy	11800.00
0005434831100	5523	Economy	11800.00
0005435461941	5523	Economy	11800.00
0005435462077	5523	Economy	11800.00
0005435462100	5523	Economy	11800.00
0005435462196	5523	Economy	11800.00
0005435766170	5523	Economy	11800.00
0005435766175	5523	Economy	11800.00
0005435766184	5523	Economy	11800.00
0005434264791	5523	Economy	11800.00
0005435766159	5523	Economy	11800.00
0005435766155	5523	Economy	11800.00
0005435461979	5523	Economy	11800.00
0005434264847	5523	Economy	11800.00
0005435462154	5523	Economy	11800.00
0005435766157	5523	Economy	11800.00
0005432140436	5523	Economy	11800.00
0005434264846	5523	Economy	11800.00
0005435766180	5523	Economy	11800.00
0005435766149	5523	Economy	11800.00
0005435462213	5523	Economy	11800.00
0005433529272	5523	Economy	11800.00
0005435461961	5523	Economy	11800.00
0005434831101	5523	Economy	11800.00
0005434264769	5523	Economy	11800.00
0005434264810	5523	Economy	11800.00
0005435766156	5523	Economy	11800.00
0005435462020	5523	Economy	11800.00
0005432140438	5523	Economy	11800.00
0005434264804	5523	Economy	11800.00
0005435766188	5523	Economy	11800.00
0005434264765	5523	Economy	11800.00
0005435766158	5523	Economy	11800.00
0005435462015	5523	Economy	11800.00
0005435462207	5523	Economy	11800.00
0005434264774	5523	Economy	11800.00
0005434264805	5523	Economy	11800.00
0005432140437	5523	Economy	11800.00
0005434264898	5523	Economy	11800.00
0005435462084	5523	Economy	11800.00
0005435765619	13468	Business	35300.00
0005434831148	13468	Business	35300.00
0005434831145	13468	Business	35300.00
0005435765377	13468	Business	35300.00
0005435462375	13468	Business	35300.00
0005434265100	13468	Business	35300.00
0005435765263	13468	Business	35300.00
0005435765685	13468	Business	35300.00
0005435765436	13468	Business	35300.00
0005435765432	13468	Business	35300.00
0005435462406	13468	Business	35300.00
0005435725532	13468	Business	35300.00
0005434265123	13468	Business	35300.00
0005434265113	13468	Business	35300.00
0005435765720	13468	Business	35300.00
0005435462405	13468	Business	35300.00
0005434265109	13468	Business	35300.00
0005435765604	13468	Business	35300.00
0005435462397	13468	Business	35300.00
0005435462387	13468	Business	35300.00
0005435462411	13468	Business	35300.00
0005434265120	13468	Business	35300.00
0005435725561	13468	Economy	12900.00
0005435765558	13468	Economy	12900.00
0005435617169	13468	Economy	11800.00
0005435765372	13468	Economy	11800.00
0005432535828	13468	Economy	11800.00
0005435462379	13468	Economy	11800.00
0005435765669	13468	Economy	11800.00
0005435765376	13468	Economy	11800.00
0005435765932	13468	Economy	11800.00
0005435765278	13468	Economy	11800.00
0005435462412	13468	Economy	11800.00
0005435462382	13468	Economy	11800.00
0005435765668	13468	Economy	11800.00
0005435765670	13468	Economy	11800.00
0005435765429	13468	Economy	11800.00
0005435765721	13468	Economy	11800.00
0005435462376	13468	Economy	11800.00
0005435765373	13468	Economy	11800.00
0005435765237	13468	Economy	11800.00
0005435765435	13468	Economy	11800.00
0005434265112	13468	Economy	11800.00
0005435765606	13468	Economy	11800.00
0005432194506	13468	Economy	11800.00
0005435765687	13468	Economy	11800.00
0005435765527	13468	Economy	11800.00
0005435462385	13468	Economy	11800.00
0005435765633	13468	Economy	11800.00
0005435462394	13468	Economy	11800.00
0005435765716	13468	Economy	11800.00
0005435462401	13468	Economy	11800.00
0005435765469	13468	Economy	11800.00
0005434265101	13468	Economy	11800.00
0005435462391	13468	Economy	11800.00
0005435765468	13468	Economy	11800.00
0005435765618	13468	Economy	11800.00
0005432535827	13468	Economy	11800.00
0005435765526	13468	Economy	11800.00
0005435765156	13468	Economy	11800.00
0005435462396	13468	Economy	11800.00
0005435462392	13468	Economy	11800.00
0005435462388	13468	Economy	11800.00
0005432194507	13468	Economy	11800.00
0005434265104	13468	Economy	11800.00
0005432535829	13468	Economy	11800.00
0005435765885	13468	Economy	11800.00
0005434831150	13468	Economy	11800.00
0005435765371	13468	Economy	11800.00
0005434265121	13468	Economy	11800.00
0005432194505	13468	Economy	11800.00
0005434831144	13468	Economy	11800.00
0005435765722	13468	Economy	11800.00
0005435735106	13468	Economy	11800.00
0005435765480	13468	Economy	11800.00
0005434265116	13468	Economy	11800.00
0005435462410	13468	Economy	11800.00
0005434831146	13468	Economy	11800.00
0005435722023	13468	Economy	11800.00
0005435765155	13468	Economy	11800.00
0005435765457	13468	Economy	11800.00
0005434265107	13468	Economy	11800.00
0005435765513	13468	Economy	11800.00
0005435462378	13468	Economy	11800.00
0005435765497	13468	Economy	11800.00
0005435765460	13468	Economy	11800.00
0005435765398	13468	Economy	11800.00
0005434265099	13468	Economy	11800.00
0005435617170	13468	Economy	11800.00
0005434265114	13468	Economy	11800.00
0005435765717	13468	Economy	11800.00
0005435462393	13468	Economy	11800.00
0005435462408	13468	Economy	11800.00
0005435723020	13468	Economy	11800.00
0005435765706	13468	Economy	11800.00
0005435765498	13468	Economy	11800.00
0005435462390	13468	Economy	11800.00
0005435765666	13468	Economy	11800.00
0005435765540	13468	Economy	11800.00
0005435462407	13468	Economy	12900.00
0005434831149	13468	Economy	11800.00
0005435462409	13468	Economy	11800.00
0005435765672	13468	Economy	12900.00
0005435765620	13468	Economy	11800.00
0005435765375	13468	Economy	11800.00
0005435765733	13468	Economy	11800.00
0005434265119	13468	Economy	11800.00
0005435765548	13468	Economy	11800.00
0005434265105	13468	Economy	11800.00
0005435765559	13468	Economy	11800.00
0005434265108	13468	Economy	11800.00
0005435765884	13468	Economy	11800.00
0005434265117	13468	Economy	11800.00
0005434831147	13468	Economy	11800.00
0005435735088	13468	Economy	11800.00
0005435462404	13468	Economy	11800.00
0005435462384	13468	Economy	11800.00
0005435722027	13468	Economy	11800.00
0005434265111	13468	Economy	11800.00
0005434265106	13468	Economy	11800.00
0005435765770	13468	Economy	11800.00
0005435462386	13468	Economy	11800.00
0005434265118	13468	Economy	11800.00
0005435765374	13468	Economy	11800.00
0005435765600	13468	Economy	11800.00
0005435462402	13468	Economy	11800.00
0005432535830	13468	Economy	11800.00
0005435765481	13468	Economy	11800.00
0005435765459	13468	Economy	11800.00
0005434265124	13468	Economy	11800.00
0005435462400	13468	Economy	11800.00
0005435765736	13468	Economy	11800.00
0005435462383	13468	Economy	11800.00
0005435462381	13468	Economy	11800.00
0005435765671	13468	Economy	11800.00
0005435462398	13468	Economy	11800.00
0005435765707	13468	Economy	11800.00
0005435462399	13468	Economy	11800.00
0005435765710	13468	Economy	11800.00
0005434265103	13468	Economy	11800.00
0005435765541	13468	Economy	11800.00
0005435735105	13468	Economy	11800.00
0005435462389	13468	Economy	11800.00
0005435765568	13468	Economy	11800.00
0005435765479	13468	Economy	11800.00
0005434265115	13468	Economy	11800.00
0005435725533	13468	Economy	11800.00
0005435462380	13468	Economy	11800.00
0005435462377	13468	Economy	11800.00
0005435462395	13468	Economy	11800.00
0005435765663	13468	Economy	11800.00
0005435735084	13468	Economy	11800.00
0005435765433	13468	Economy	11800.00
0005435722028	13468	Economy	11800.00
0005435765525	13468	Economy	11800.00
0005434265110	13468	Economy	11800.00
0005434265102	13468	Economy	11800.00
0005435462403	13468	Economy	11800.00
0005435735089	13468	Economy	11800.00
0005435765569	13468	Economy	11800.00
0005434265122	13468	Economy	11800.00
0005435735085	13468	Economy	11800.00
0005435725542	13468	Economy	11800.00
0005435735096	13468	Economy	11800.00
0005434513575	18636	Economy	3300.00
0005434513574	18636	Economy	3300.00
0005434604868	18636	Economy	3300.00
0005434514962	18636	Economy	3300.00
0005434514964	18636	Economy	3300.00
0005434604846	18636	Economy	3300.00
0005434604847	18636	Economy	3300.00
0005434514963	18636	Economy	3300.00
0005434514947	19139	Economy	3300.00
0005434514936	19139	Economy	3300.00
0005432649323	25084	Business	88300.00
0005432649382	25084	Business	88300.00
0005432649344	25084	Business	88300.00
0005432649345	25084	Business	88300.00
0005432649349	25084	Economy	29400.00
0005432649320	25084	Economy	29400.00
0005432649319	25084	Economy	29400.00
0005432649346	25084	Economy	29400.00
0005435846247	25084	Economy	29400.00
0005435846245	25084	Economy	29400.00
0005435846249	25084	Economy	29400.00
0005435846244	25084	Economy	29400.00
0005435846250	25084	Economy	29400.00
0005432649327	25084	Economy	29400.00
0005435846248	25084	Economy	29400.00
0005432649333	25084	Economy	29400.00
0005432649381	25084	Economy	29400.00
0005432649334	25084	Economy	29400.00
0005432649335	25084	Economy	29400.00
0005432649363	25084	Economy	29400.00
0005432649328	25084	Economy	29400.00
0005432649330	25084	Economy	29400.00
0005435846246	25084	Economy	29400.00
0005433008201	1814	Business	48700.00
0005433008365	1814	Business	48700.00
0005433285072	1814	Business	48700.00
0005433008047	1814	Business	48700.00
0005433008181	1814	Business	48700.00
0005433008032	1814	Business	48700.00
0005433008122	1814	Business	48700.00
0005433008163	1814	Business	48700.00
0005433008357	1814	Business	48700.00
0005433008031	1814	Business	48700.00
0005433008198	1814	Economy	16200.00
0005432295876	1814	Economy	16200.00
0005433008300	1814	Economy	16200.00
0005433284999	1814	Economy	16200.00
0005433008019	1814	Economy	16200.00
0005433008399	1814	Economy	16200.00
0005432295877	1814	Economy	16200.00
0005433008280	1814	Economy	17900.00
0005433285037	1814	Economy	17900.00
0005433008272	1814	Economy	17900.00
0005433810541	1814	Economy	17900.00
0005433810545	1814	Economy	16200.00
0005433008164	1814	Economy	16200.00
0005433008033	1814	Economy	16200.00
0005433008403	1814	Economy	16200.00
0005433008202	1814	Economy	16200.00
0005433285186	1814	Economy	16200.00
0005433008243	1814	Economy	16200.00
0005433008356	1814	Economy	16200.00
0005433007921	1814	Economy	16200.00
0005433008273	1814	Economy	16200.00
0005433008154	1814	Economy	16200.00
0005433008157	1814	Economy	16200.00
0005433285012	1814	Economy	16200.00
0005433285071	1814	Economy	16200.00
0005433284936	1814	Economy	16200.00
0005432295875	1814	Economy	16200.00
0005433008018	1814	Economy	16200.00
0005433285056	1814	Economy	16200.00
0005433285043	1814	Economy	16200.00
0005433008279	1814	Economy	16200.00
0005433008046	1814	Economy	16200.00
0005433810542	1814	Economy	16200.00
0005433810540	1814	Economy	16200.00
0005433810543	1814	Economy	16200.00
0005433285087	1814	Economy	16200.00
0005433008404	1814	Economy	16200.00
0005433285024	1814	Economy	16200.00
0005433008175	1814	Economy	16200.00
0005433008030	1814	Economy	16200.00
0005433008172	1814	Economy	16200.00
0005433008343	1814	Economy	16200.00
0005433284919	1814	Economy	16200.00
0005433284981	1814	Economy	16200.00
0005433008364	1814	Economy	16200.00
0005433810544	1814	Economy	16200.00
0005433285095	1814	Economy	16200.00
0005433284985	1814	Economy	16200.00
0005433008344	1814	Economy	16200.00
0005433810538	1814	Economy	16200.00
0005433008199	1814	Economy	16200.00
0005433285031	1814	Economy	16200.00
0005433810539	1814	Economy	16200.00
0005433008231	1814	Economy	16200.00
0005433008277	1814	Economy	16200.00
0005433008402	1814	Economy	16200.00
0005433008260	1814	Economy	16200.00
0005433008223	1814	Economy	16200.00
0005433008354	1814	Economy	16200.00
0005433007920	1814	Economy	16200.00
0005433284951	1814	Economy	16200.00
0005433285094	1814	Economy	16200.00
0005433008278	1814	Economy	16200.00
0005433284969	1814	Economy	16200.00
0005433008041	1814	Economy	16200.00
0005433008542	22552	Business	48700.00
0005433008562	22552	Business	48700.00
0005433285238	22552	Business	48700.00
0005433810503	22552	Business	48700.00
0005433285239	22552	Business	48700.00
0005433285258	22552	Business	48700.00
0005433008540	22552	Business	48700.00
0005433008544	22552	Business	48700.00
0005433008538	22552	Business	48700.00
0005433008519	22552	Economy	16200.00
0005433285253	22552	Economy	16200.00
0005433008557	22552	Economy	16200.00
0005433285252	22552	Economy	16200.00
0005433008558	22552	Economy	16200.00
0005433008531	22552	Economy	16200.00
0005433285255	22552	Economy	16200.00
0005433008555	22552	Economy	16200.00
0005433008539	22552	Economy	16200.00
0005433008543	22552	Economy	17900.00
0005433008560	22552	Economy	17900.00
0005433285245	22552	Economy	17900.00
0005433285262	22552	Economy	17900.00
0005433008563	22552	Economy	16200.00
0005433285243	22552	Economy	16200.00
0005433008556	22552	Economy	16200.00
0005433285241	22552	Economy	16200.00
0005433008520	22552	Economy	16200.00
0005433285236	22552	Economy	16200.00
0005433008550	22552	Economy	16200.00
0005433285244	22552	Economy	16200.00
0005433285257	22552	Economy	16200.00
0005433285246	22552	Economy	16200.00
0005433008551	22552	Economy	16200.00
0005433008518	22552	Economy	16200.00
0005433008534	22552	Economy	16200.00
0005433285248	22552	Economy	16200.00
0005433008525	22552	Economy	16200.00
0005433008546	22552	Economy	16200.00
0005433285232	22552	Economy	16200.00
0005433008559	22552	Economy	16200.00
0005433285233	22552	Economy	16200.00
0005433285256	22552	Economy	16200.00
0005433008528	22552	Economy	16200.00
0005433008553	22552	Economy	16200.00
0005433285247	22552	Economy	16200.00
0005433810495	22552	Economy	16200.00
0005433008521	22552	Economy	16200.00
0005433008561	22552	Economy	16200.00
0005433008529	22552	Economy	16200.00
0005433285240	22552	Economy	16200.00
0005433008535	22552	Economy	16200.00
0005433008552	22552	Economy	16200.00
0005433008547	22552	Economy	16200.00
0005433285242	22552	Economy	16200.00
0005433285234	22552	Economy	16200.00
0005433008536	22552	Economy	16200.00
0005433285254	22552	Economy	16200.00
0005433285249	22552	Economy	16200.00
0005433008545	22552	Economy	16200.00
0005433008533	22552	Economy	16200.00
0005433008537	22552	Economy	16200.00
0005433285250	22552	Economy	16200.00
0005433285263	22552	Economy	16200.00
0005433008524	22552	Economy	16200.00
0005433008523	22552	Economy	16200.00
0005433008532	22552	Economy	16200.00
0005433008526	22552	Economy	16200.00
0005433008554	22552	Economy	16200.00
0005433008530	22552	Economy	16200.00
0005433285259	22552	Economy	16200.00
0005433008522	22552	Economy	16200.00
0005433008541	22552	Economy	16200.00
0005433008548	22552	Economy	16200.00
0005433285260	22552	Economy	16200.00
0005433008527	22552	Economy	16200.00
0005433285237	22552	Economy	16200.00
0005433285261	22552	Economy	16200.00
0005433285235	22552	Economy	16200.00
0005433285251	22552	Economy	16200.00
0005433008549	22552	Economy	16200.00
0005432755035	12290	Business	83800.00
0005432751483	12290	Business	83800.00
0005434152781	12290	Business	83800.00
0005432751481	12290	Business	83800.00
0005432755034	12290	Economy	27900.00
0005432755033	12290	Economy	30700.00
0005432751484	12290	Economy	27900.00
0005432755027	12290	Economy	27900.00
0005432751485	12290	Economy	27900.00
0005432751494	12290	Economy	27900.00
0005432751492	12290	Economy	27900.00
0005432751486	12290	Economy	27900.00
0005432751487	12290	Economy	27900.00
0005432755028	12290	Economy	27900.00
0005432755031	12290	Economy	27900.00
0005432755047	12290	Economy	27900.00
0005432751508	12290	Economy	27900.00
0005432755038	12290	Economy	27900.00
0005432751502	12290	Economy	27900.00
0005432751507	12290	Economy	27900.00
0005432755026	12290	Economy	27900.00
0005432751478	12290	Economy	27900.00
0005432755032	12290	Economy	27900.00
0005432751495	12290	Economy	27900.00
0005432755036	12290	Economy	27900.00
0005433846642	5564	Business	99800.00
0005433846673	5564	Business	99800.00
0005433846626	5564	Business	99800.00
0005435282192	5564	Business	99800.00
0005433846638	5564	Business	99800.00
0005435282309	5564	Business	99800.00
0005435282274	5564	Business	99800.00
0005433815378	5564	Business	99800.00
0005434173471	5564	Business	99800.00
0005433846666	5564	Business	99800.00
0005433815379	5564	Business	99800.00
0005433846633	5564	Business	99800.00
0005433846674	5564	Business	99800.00
0005433846635	5564	Business	99800.00
0005433846619	5564	Business	99800.00
0005435282229	5564	Business	99800.00
0005433846624	5564	Business	99800.00
0005435282111	5564	Business	99800.00
0005433815374	5564	Economy	33300.00
0005435282333	5564	Economy	33300.00
0005433846658	5564	Economy	33300.00
0005435282286	5564	Economy	33300.00
0005433846637	5564	Economy	33300.00
0005433846639	5564	Economy	33300.00
0005433846640	5564	Economy	33300.00
0005432081502	5564	Economy	33300.00
0005433846676	5564	Economy	33300.00
0005432081503	5564	Economy	33300.00
0005433846668	5564	Economy	33300.00
0005433846649	5564	Economy	33300.00
0005433846651	5564	Economy	36600.00
0005433846654	5564	Economy	36600.00
0005435282200	5564	Economy	36600.00
0005433846665	5564	Economy	36600.00
0005433846644	5564	Economy	33300.00
0005432081499	5564	Economy	33300.00
0005435282231	5564	Economy	33300.00
0005433846660	5564	Economy	33300.00
0005435282230	5564	Economy	33300.00
0005433846661	5564	Economy	33300.00
0005435282246	5564	Economy	33300.00
0005435282184	5564	Economy	33300.00
0005433846656	5564	Economy	33300.00
0005433846629	5564	Economy	33300.00
0005433846659	5564	Economy	33300.00
0005433846622	5564	Economy	33300.00
0005435282378	5564	Economy	33300.00
0005435282185	5564	Economy	33300.00
0005433846620	5564	Economy	33300.00
0005433846679	5564	Economy	33300.00
0005433846653	5564	Economy	33300.00
0005432081504	5564	Economy	33300.00
0005433846663	5564	Economy	33300.00
0005432081505	5564	Economy	33300.00
0005433846677	5564	Economy	33300.00
0005433846646	5564	Economy	33300.00
0005433846645	5564	Economy	33300.00
0005433846669	5564	Economy	33300.00
0005433846643	5564	Economy	33300.00
0005433846664	5564	Economy	33300.00
0005432081501	5564	Economy	33300.00
0005433846675	5564	Economy	33300.00
0005435282271	5564	Economy	33300.00
0005433846670	5564	Economy	33300.00
0005433846631	5564	Economy	33300.00
0005433846655	5564	Economy	33300.00
0005435282238	5564	Economy	33300.00
0005433846671	5564	Economy	33300.00
0005433846652	5564	Economy	33300.00
0005433846621	5564	Economy	33300.00
0005435282235	5564	Economy	33300.00
0005433846623	5564	Economy	33300.00
0005433846636	5564	Economy	33300.00
0005434173470	5564	Economy	33300.00
0005433846632	5564	Economy	33300.00
0005435282387	5564	Economy	33300.00
0005435282352	5564	Economy	33300.00
0005433846667	5564	Economy	33300.00
0005433846650	5564	Economy	33300.00
0005433846662	5564	Economy	33300.00
0005433846630	5564	Economy	33300.00
0005433846647	5564	Economy	33300.00
0005433846625	5564	Economy	33300.00
0005435282262	5564	Economy	33300.00
0005433846672	5564	Economy	33300.00
0005434173473	5564	Economy	33300.00
0005433846657	5564	Economy	33300.00
0005432081500	5564	Economy	33300.00
0005433846648	5564	Economy	33300.00
0005433815375	5564	Economy	33300.00
0005433846641	5564	Economy	33300.00
0005433846678	5564	Economy	33300.00
0005433846634	5564	Economy	33300.00
0005433846628	5564	Economy	33300.00
0005433815377	5564	Economy	33300.00
0005433815376	5564	Economy	33300.00
0005433846627	5564	Economy	33300.00
0005433845864	13845	Business	99800.00
0005433815312	13845	Business	99800.00
0005433846167	13845	Business	99800.00
0005433846148	13845	Business	99800.00
0005435282493	13845	Business	99800.00
0005433846147	13845	Business	99800.00
0005433846272	13845	Business	99800.00
0005433846466	13845	Business	99800.00
0005433846250	13845	Business	99800.00
0005433845865	13845	Business	99800.00
0005433846047	13845	Business	99800.00
0005433846295	13845	Business	99800.00
0005433846154	13845	Business	99800.00
0005433846034	13845	Business	99800.00
0005433846179	13845	Business	99800.00
0005433845992	13845	Business	99800.00
0005433846320	13845	Economy	33300.00
0005433846033	13845	Business	99800.00
0005433846109	13845	Economy	33300.00
0005433846089	13845	Economy	33300.00
0005433846319	13845	Economy	33300.00
0005433846072	13845	Economy	33300.00
0005433845871	13845	Economy	33300.00
0005435282484	13845	Economy	33300.00
0005433815313	13845	Economy	33300.00
0005435282492	13845	Economy	33300.00
0005433846139	13845	Economy	33300.00
0005433846241	13845	Economy	33300.00
0005435282499	13845	Economy	33300.00
0005435282495	13845	Economy	36600.00
0005433815324	13845	Economy	36600.00
0005433845869	13845	Economy	36600.00
0005435282485	13845	Economy	36600.00
0005435282478	13845	Economy	33300.00
0005433846273	13845	Economy	33300.00
0005433845982	13845	Economy	33300.00
0005433846244	13845	Economy	33300.00
0005432003698	13845	Economy	33300.00
0005432003697	13845	Economy	33300.00
0005433845870	13845	Economy	33300.00
0005433846312	13845	Economy	33300.00
0005433846142	13845	Economy	33300.00
0005433846375	13845	Economy	33300.00
0005435282482	13845	Economy	33300.00
0005433815339	13845	Economy	33300.00
0005435282483	13845	Economy	33300.00
0005435282487	13845	Economy	33300.00
0005435282491	13845	Economy	33300.00
0005433846181	13845	Economy	33300.00
0005433845866	13845	Economy	33300.00
0005433846081	13845	Economy	33300.00
0005433846214	13845	Economy	33300.00
0005433846078	13845	Economy	33300.00
0005433846090	13845	Economy	33300.00
0005433846182	13845	Economy	33300.00
0005433845931	13845	Economy	33300.00
0005434173516	13845	Economy	33300.00
0005435282494	13845	Economy	33300.00
0005434173517	13845	Economy	33300.00
0005433846088	13845	Economy	33300.00
0005433846465	13845	Economy	33300.00
0005435282480	13845	Economy	33300.00
0005434173515	13845	Economy	33300.00
0005435282481	13845	Economy	33300.00
0005433845903	13845	Economy	33300.00
0005433846206	13845	Economy	33300.00
0005435282489	13845	Economy	33300.00
0005432003696	13845	Economy	33300.00
0005433845993	13845	Economy	33300.00
0005433846140	13845	Economy	33300.00
0005435282498	13845	Economy	33300.00
0005433846220	13845	Economy	33300.00
0005433846187	13845	Economy	33300.00
0005435282490	13845	Economy	33300.00
0005433845965	13845	Economy	33300.00
0005433846149	13845	Economy	33300.00
0005433846372	13845	Economy	33300.00
0005433846022	13845	Economy	33300.00
0005433846117	13845	Economy	33300.00
0005435282488	13845	Economy	33300.00
0005435282496	13845	Economy	33300.00
0005433846110	13845	Economy	33300.00
0005433846141	13845	Economy	33300.00
0005433846087	13845	Economy	33300.00
0005435282486	13845	Economy	33300.00
0005435282479	13845	Economy	33300.00
0005433846118	13845	Economy	33300.00
0005433846035	13845	Economy	33300.00
0005433845981	13845	Economy	33300.00
0005433846091	13845	Economy	33300.00
0005433846036	13845	Economy	33300.00
0005433846116	13845	Economy	33300.00
0005435282497	13845	Economy	33300.00
0005433846083	13845	Economy	33300.00
0005433846108	13845	Economy	33300.00
0005433846296	13845	Economy	33300.00
0005433846168	13845	Economy	33300.00
0005434173514	13845	Economy	33300.00
0005433846237	13845	Economy	33300.00
0005433846157	13845	Economy	33300.00
0005433846251	13845	Economy	33300.00
0005433845904	13845	Economy	33300.00
0005434620563	7845	Economy	16600.00
0005435332256	7845	Economy	16600.00
0005434620573	7845	Economy	16600.00
0005434620567	7845	Economy	15100.00
0005435332211	7845	Economy	15100.00
0005434620571	7845	Economy	15100.00
0005434620566	7845	Economy	15100.00
0005434620559	7845	Economy	15100.00
0005434620578	7845	Economy	15100.00
0005432112513	7845	Economy	15100.00
0005434620570	7845	Economy	15100.00
0005434620560	7845	Economy	15100.00
0005434620579	7845	Economy	15100.00
0005435332201	7845	Economy	15100.00
0005434620558	7845	Economy	15100.00
0005434620565	7845	Economy	15100.00
0005435332289	7845	Economy	15100.00
0005434620562	7845	Economy	15100.00
0005434620561	7845	Economy	15100.00
0005435332224	7845	Economy	15100.00
0005435332227	7845	Economy	15100.00
0005435332221	7845	Economy	15100.00
0005434620569	7845	Economy	15100.00
0005434620576	7845	Economy	15100.00
0005434620577	7845	Economy	15100.00
0005435332214	7845	Economy	15100.00
0005434620572	7845	Economy	15100.00
0005434620568	7845	Economy	15100.00
0005434620574	7845	Economy	15100.00
0005434620564	7845	Economy	15100.00
0005434620575	7845	Economy	15100.00
0005435332215	7845	Economy	15100.00
0005434620403	32974	Economy	16600.00
0005434620317	32974	Economy	16600.00
0005434620333	32974	Economy	15100.00
0005434620337	32974	Economy	15100.00
0005434620424	32974	Economy	15100.00
0005434620425	32974	Economy	15100.00
0005434620404	32974	Economy	15100.00
0005435332326	32974	Economy	15100.00
0005435332324	32974	Economy	15100.00
0005435332322	32974	Economy	15100.00
0005434620397	32974	Economy	15100.00
0005435332327	32974	Economy	15100.00
0005435332317	32974	Economy	15100.00
0005434620409	32974	Economy	15100.00
0005434620429	32974	Economy	15100.00
0005435332316	32974	Economy	15100.00
0005434620394	32974	Economy	15100.00
0005434620421	32974	Economy	15100.00
0005434620478	32974	Economy	15100.00
0005435332319	32974	Economy	15100.00
0005434620477	32974	Economy	15100.00
0005434620503	32974	Economy	15100.00
0005434620408	32974	Economy	15100.00
0005435332320	32974	Economy	15100.00
0005434620372	32974	Economy	15100.00
0005434620327	32974	Economy	15100.00
0005434620272	32974	Economy	15100.00
0005435332321	32974	Economy	15100.00
0005435332318	32974	Economy	15100.00
0005434620411	32974	Economy	15100.00
0005434620334	32974	Economy	15100.00
0005434620350	32974	Economy	15100.00
0005434620398	32974	Economy	15100.00
0005435332323	32974	Economy	15100.00
0005434620401	32974	Economy	15100.00
0005435332325	32974	Economy	15100.00
0005434620371	32974	Economy	15100.00
0005435937321	4284	Business	38000.00
0005435785294	4284	Business	38000.00
0005435787352	4284	Business	38000.00
0005434994007	4284	Business	38000.00
0005435785302	4284	Business	38000.00
0005432190624	4284	Business	38000.00
0005435785301	4284	Business	38000.00
0005435785303	4284	Economy	12700.00
0005435785298	4284	Economy	12700.00
0005434994006	4284	Economy	12700.00
0005435785310	4284	Economy	12700.00
0005435785326	4284	Economy	13900.00
0005435785320	4284	Economy	13900.00
0005434994009	4284	Economy	13900.00
0005435785314	4284	Economy	12700.00
0005432190627	4284	Economy	12700.00
0005435785329	4284	Economy	12700.00
0005435918607	4284	Economy	12700.00
0005434994008	4284	Economy	12700.00
0005435785330	4284	Economy	12700.00
0005434994014	4284	Economy	12700.00
0005435785311	4284	Economy	12700.00
0005435787353	4284	Economy	12700.00
0005435785299	4284	Economy	12700.00
0005435785300	4284	Economy	12700.00
0005435785327	4284	Economy	12700.00
0005432190625	4284	Economy	12700.00
0005435787351	4284	Economy	12700.00
0005435785306	4284	Economy	12700.00
0005435785297	4284	Economy	12700.00
0005435785328	4284	Economy	12700.00
0005432190626	4284	Economy	12700.00
0005435937327	4284	Economy	12700.00
0005435785309	4284	Economy	12700.00
0005435785312	4284	Economy	12700.00
0005435785316	4284	Economy	12700.00
0005435785322	4284	Economy	12700.00
0005435785317	4284	Economy	12700.00
0005435937320	4284	Economy	12700.00
0005434994011	4284	Economy	12700.00
0005435785313	4284	Economy	12700.00
0005434994012	4284	Economy	12700.00
0005435785319	4284	Economy	12700.00
0005435785318	4284	Economy	12700.00
0005435785308	4284	Economy	12700.00
0005434994013	4284	Economy	12700.00
0005435785295	4284	Economy	12700.00
0005435785323	4284	Economy	12700.00
0005435785315	4284	Economy	12700.00
0005435785321	4284	Economy	12700.00
0005435785305	4284	Economy	12700.00
0005435785304	4284	Economy	12700.00
0005435785296	4284	Economy	12700.00
0005435785325	4284	Economy	12700.00
0005435787350	4284	Economy	12700.00
0005435785324	4284	Economy	12700.00
0005434994010	4284	Economy	12700.00
0005435785307	4284	Economy	12700.00
0005435784940	27314	Business	38000.00
0005434993942	27314	Business	38000.00
0005435784895	27314	Business	38000.00
0005435784852	27314	Business	38000.00
0005434993943	27314	Business	38000.00
0005435785017	27314	Business	38000.00
0005435784729	27314	Business	38000.00
0005434993931	27314	Economy	12700.00
0005435937379	27314	Economy	12700.00
0005432195688	27314	Economy	12700.00
0005435785010	27314	Economy	12700.00
0005435937382	27314	Economy	12700.00
0005434993945	27314	Economy	12700.00
0005435784941	27314	Economy	12700.00
0005435784841	27314	Economy	12700.00
0005432195689	27314	Economy	12700.00
0005435937381	27314	Economy	13900.00
0005435784851	27314	Economy	13900.00
0005435937377	27314	Economy	13900.00
0005435785027	27314	Economy	13900.00
0005435784926	27314	Economy	13900.00
0005435784849	27314	Economy	12700.00
0005435784916	27314	Economy	12700.00
0005435784955	27314	Economy	12700.00
0005434993916	27314	Economy	12700.00
0005435918648	27314	Economy	12700.00
0005432195691	27314	Economy	12700.00
0005435784956	27314	Economy	12700.00
0005435784834	27314	Economy	12700.00
0005435785009	27314	Economy	12700.00
0005434993932	27314	Economy	12700.00
0005435937380	27314	Economy	12700.00
0005435918649	27314	Economy	12700.00
0005434993944	27314	Economy	12700.00
0005435784981	27314	Economy	12700.00
0005435784930	27314	Economy	12700.00
0005432195690	27314	Economy	12700.00
0005434993918	27314	Economy	12700.00
0005435784835	27314	Economy	12700.00
0005434993949	27314	Economy	12700.00
0005435784847	27314	Economy	12700.00
0005435784809	27314	Economy	12700.00
0005435784848	27314	Economy	12700.00
0005435784929	27314	Economy	12700.00
0005435785018	27314	Economy	12700.00
0005435784957	27314	Economy	12700.00
0005435918650	27314	Economy	12700.00
0005435784927	27314	Economy	12700.00
0005435784980	27314	Economy	12700.00
0005435785037	27314	Economy	12700.00
0005435784819	27314	Economy	12700.00
0005435937378	27314	Economy	12700.00
0005435784992	27314	Economy	12700.00
0005435784938	27314	Economy	12700.00
0005435785036	27314	Economy	12700.00
0005435784871	27314	Economy	12700.00
0005435918651	27314	Economy	12700.00
0005435937376	27314	Economy	12700.00
0005435918647	27314	Economy	12700.00
0005435785008	27314	Economy	12700.00
0005435784937	27314	Economy	12700.00
0005435937375	27314	Economy	12700.00
0005434993925	27314	Economy	12700.00
0005432146195	19890	Economy	12800.00
0005432459772	4723	Business	40900.00
0005432459794	4723	Business	40900.00
0005432567568	4723	Business	40900.00
0005434081888	4723	Business	40900.00
0005432567552	4723	Business	40900.00
0005432567542	4723	Business	40900.00
0005434081879	4723	Business	40900.00
0005434081878	4723	Business	40900.00
0005432567565	4723	Business	40900.00
0005432170375	4723	Business	40900.00
0005432567578	4723	Business	40900.00
0005434081875	4723	Business	40900.00
0005434081887	4723	Business	40900.00
0005432459793	4723	Business	40900.00
0005432567548	4723	Business	40900.00
0005432567589	4723	Business	40900.00
0005434081872	4723	Business	40900.00
0005434081865	4723	Business	40900.00
0005432459800	4723	Business	40900.00
0005434081860	4723	Business	40900.00
0005432459764	4723	Business	40900.00
0005432459758	4723	Business	40900.00
0005432170378	4723	Business	40900.00
0005432459760	4723	Business	40900.00
0005432459765	4723	Business	40900.00
0005434081885	4723	Business	40900.00
0005432459804	4723	Economy	15000.00
0005432571316	4723	Economy	15000.00
0005432459805	4723	Economy	15000.00
0005432459780	4723	Economy	15000.00
0005432459776	4723	Economy	13600.00
0005432567538	4723	Economy	13600.00
0005434081877	4723	Economy	13600.00
0005434081861	4723	Economy	13600.00
0005432567572	4723	Economy	13600.00
0005432459811	4723	Economy	13600.00
0005432567574	4723	Economy	13600.00
0005432567549	4723	Economy	13600.00
0005432170380	4723	Economy	13600.00
0005433451616	4723	Economy	13600.00
0005434081884	4723	Economy	13600.00
0005432459796	4723	Economy	13600.00
0005432567579	4723	Economy	13600.00
0005432567560	4723	Economy	13600.00
0005434081864	4723	Economy	13600.00
0005432186865	4723	Economy	13600.00
0005432567580	4723	Economy	13600.00
0005432567530	4723	Economy	13600.00
0005432567553	4723	Economy	13600.00
0005432459763	4723	Economy	13600.00
0005432567536	4723	Economy	13600.00
0005432459812	4723	Economy	13600.00
0005432567550	4723	Economy	13600.00
0005432571317	4723	Economy	13600.00
0005434081866	4723	Economy	13600.00
0005432459768	4723	Economy	13600.00
0005432567556	4723	Economy	13600.00
0005432567570	4723	Economy	13600.00
0005434081869	4723	Economy	13600.00
0005434081883	4723	Economy	13600.00
0005432459783	4723	Economy	13600.00
0005432170377	4723	Economy	13600.00
0005432459786	4723	Economy	13600.00
0005432459785	4723	Economy	13600.00
0005432459789	4723	Economy	13600.00
0005432567581	4723	Economy	13600.00
0005434081881	4723	Economy	13600.00
0005432567567	4723	Economy	13600.00
0005432567546	4723	Economy	13600.00
0005432459801	4723	Economy	13600.00
0005433726102	4723	Economy	13600.00
0005434081862	4723	Economy	13600.00
0005432186864	4723	Economy	13600.00
0005433451617	4723	Economy	13600.00
0005432459782	4723	Economy	13600.00
0005432459809	4723	Economy	13600.00
0005432459803	4723	Economy	13600.00
0005432459784	4723	Economy	13600.00
0005432459773	4723	Economy	13600.00
0005434081870	4723	Economy	13600.00
0005432170376	4723	Economy	13600.00
0005433452736	4723	Economy	13600.00
0005434081863	4723	Economy	13600.00
0005432571318	4723	Economy	13600.00
0005434081889	4723	Economy	13600.00
0005432567534	4723	Economy	13600.00
0005432459808	4723	Economy	13600.00
0005432567575	4723	Economy	13600.00
0005434081859	4723	Economy	13600.00
0005434081891	4723	Economy	13600.00
0005432459799	4723	Economy	13600.00
0005432567587	4723	Economy	13600.00
0005432567563	4723	Economy	13600.00
0005432459777	4723	Economy	13600.00
0005432459781	4723	Economy	13600.00
0005432459771	4723	Economy	13600.00
0005432567577	4723	Economy	13600.00
0005432571319	4723	Economy	13600.00
0005432459767	4723	Economy	13600.00
0005432567547	4723	Economy	13600.00
0005432567566	4723	Economy	13600.00
0005434081880	4723	Economy	13600.00
0005432567561	4723	Economy	13600.00
0005432567533	4723	Economy	15000.00
0005432186866	4723	Economy	13600.00
0005432567584	4723	Economy	13600.00
0005432459791	4723	Economy	13600.00
0005432567576	4723	Economy	15000.00
0005433452737	4723	Economy	13600.00
0005434081873	4723	Economy	13600.00
0005432459790	4723	Economy	13600.00
0005432567571	4723	Economy	13600.00
0005432567557	4723	Economy	13600.00
0005432567564	4723	Economy	13600.00
0005432567526	4723	Economy	13600.00
0005432567543	4723	Economy	13600.00
0005432459761	4723	Economy	13600.00
0005432459810	4723	Economy	13600.00
0005432567555	4723	Economy	13600.00
0005432567558	4723	Economy	13600.00
0005432567569	4723	Economy	13600.00
0005432459770	4723	Economy	13600.00
0005432567541	4723	Economy	13600.00
0005434081882	4723	Economy	13600.00
0005432567545	4723	Economy	13600.00
0005432459792	4723	Economy	13600.00
0005432459766	4723	Economy	13600.00
0005432567588	4723	Economy	13600.00
0005432567539	4723	Economy	13600.00
0005434081867	4723	Economy	13600.00
0005432567540	4723	Economy	13600.00
0005432459788	4723	Economy	13600.00
0005432567586	4723	Economy	13600.00
0005432459779	4723	Economy	13600.00
0005434081886	4723	Economy	13600.00
0005432459762	4723	Economy	13600.00
0005432567544	4723	Economy	13600.00
0005432567583	4723	Economy	13600.00
0005432170381	4723	Economy	13600.00
0005432567562	4723	Economy	13600.00
0005432459774	4723	Economy	13600.00
0005432567531	4723	Economy	13600.00
0005432567551	4723	Economy	13600.00
0005432567535	4723	Economy	13600.00
0005432459802	4723	Economy	13600.00
0005432459769	4723	Economy	13600.00
0005432459798	4723	Economy	13600.00
0005432459795	4723	Economy	13600.00
0005432567528	4723	Economy	13600.00
0005434081874	4723	Economy	13600.00
0005432459759	4723	Economy	13600.00
0005432459778	4723	Economy	13600.00
0005432567554	4723	Economy	13600.00
0005432567529	4723	Economy	13600.00
0005432567573	4723	Economy	13600.00
0005432459797	4723	Economy	13600.00
0005432459807	4723	Economy	13600.00
0005432459806	4723	Economy	13600.00
0005433726101	4723	Economy	13600.00
0005432567585	4723	Economy	13600.00
0005434081876	4723	Economy	13600.00
0005432459775	4723	Economy	13600.00
0005432567537	4723	Economy	13600.00
0005432459787	4723	Economy	13600.00
0005432567582	4723	Economy	13600.00
0005434081871	4723	Economy	13600.00
0005434081890	4723	Economy	13600.00
0005432170379	4723	Economy	13600.00
0005432567527	4723	Economy	13600.00
0005432567559	4723	Economy	13600.00
0005432567532	4723	Economy	13600.00
0005434081868	4723	Economy	13600.00
0005434081583	30555	Business	40900.00
0005432566941	30555	Business	40900.00
0005432566981	30555	Business	40900.00
0005432567080	30555	Business	40900.00
0005434081592	30555	Business	40900.00
0005432459386	30555	Business	40900.00
0005432459375	30555	Business	40900.00
0005432566971	30555	Business	40900.00
0005432459487	30555	Business	40900.00
0005432567124	30555	Business	40900.00
0005432459258	30555	Business	40900.00
0005432567106	30555	Business	40900.00
0005434081659	30555	Business	40900.00
0005432566976	30555	Business	40900.00
0005434081537	30555	Business	40900.00
0005432567345	30555	Business	40900.00
0005432459134	30555	Business	40900.00
0005432567153	30555	Business	40900.00
0005432567176	30555	Business	40900.00
0005432567100	30555	Business	40900.00
0005434081699	30555	Economy	15000.00
0005432459365	30555	Economy	15000.00
0005432459305	30555	Economy	15000.00
0005432459357	30555	Economy	13600.00
0005433726066	30555	Economy	13600.00
0005434081718	30555	Economy	13600.00
0005432459421	30555	Economy	13600.00
0005432567076	30555	Economy	13600.00
0005432459312	30555	Economy	13600.00
0005432566782	30555	Economy	13600.00
0005432459356	30555	Economy	13600.00
0005434081668	30555	Economy	13600.00
0005432567004	30555	Economy	13600.00
0005432459445	30555	Economy	13600.00
0005432567023	30555	Economy	13600.00
0005432567092	30555	Economy	13600.00
0005432567081	30555	Economy	13600.00
0005432213602	30555	Economy	13600.00
0005432567425	30555	Economy	13600.00
0005434081672	30555	Economy	13600.00
0005433726068	30555	Economy	13600.00
0005432567126	30555	Economy	13600.00
0005434081698	30555	Economy	13600.00
0005432567134	30555	Economy	13600.00
0005432459238	30555	Economy	13600.00
0005432459427	30555	Economy	13600.00
0005432566983	30555	Economy	13600.00
0005434081630	30555	Economy	13600.00
0005432567115	30555	Economy	13600.00
0005433726069	30555	Economy	13600.00
0005432567075	30555	Economy	13600.00
0005432566796	30555	Economy	13600.00
0005432566772	30555	Economy	13600.00
0005434081683	30555	Economy	13600.00
0005434081700	30555	Economy	13600.00
0005432459390	30555	Economy	13600.00
0005434081703	30555	Economy	13600.00
0005432459557	30555	Economy	13600.00
0005432566864	30555	Economy	13600.00
0005432566783	30555	Economy	13600.00
0005432213600	30555	Economy	13600.00
0005432567132	30555	Economy	13600.00
0005432567038	30555	Economy	13600.00
0005432567042	30555	Economy	13600.00
0005432459507	30555	Economy	13600.00
0005432459311	30555	Economy	13600.00
0005432213603	30555	Economy	13600.00
0005432459583	30555	Economy	13600.00
0005432213601	30555	Economy	13600.00
0005432567117	30555	Economy	13600.00
0005434081584	30555	Economy	13600.00
0005432567030	30555	Economy	13600.00
0005432459585	30555	Economy	13600.00
0005432567229	30555	Economy	13600.00
0005432459388	30555	Economy	13600.00
0005432567342	30555	Economy	13600.00
0005432566822	30555	Economy	13600.00
0005434081675	30555	Economy	13600.00
0005432459560	30555	Economy	13600.00
0005434081629	30555	Economy	13600.00
0005433452719	30555	Economy	13600.00
0005434081660	30555	Economy	13600.00
0005432567053	30555	Economy	13600.00
0005432459397	30555	Economy	13600.00
0005432567338	30555	Economy	13600.00
0005432161149	30555	Economy	13600.00
0005432567056	30555	Economy	13600.00
0005434081705	30555	Economy	13600.00
0005432566938	30555	Economy	13600.00
0005432566987	30555	Economy	13600.00
0005432566945	30555	Economy	13600.00
0005434081649	30555	Economy	13600.00
0005432567159	30555	Economy	13600.00
0005432459087	30555	Economy	13600.00
0005432567029	30555	Economy	13600.00
0005432567131	30555	Economy	13600.00
0005432459354	30555	Economy	13600.00
0005432459584	30555	Economy	13600.00
0005432459257	30555	Economy	13600.00
0005432567420	30555	Economy	13600.00
0005432567154	30555	Economy	13600.00
0005432567426	30555	Economy	13600.00
0005432459310	30555	Economy	13600.00
0005432567397	30555	Economy	15000.00
0005432567046	30555	Economy	15000.00
0005434081652	30555	Economy	13600.00
0005432567093	30555	Economy	15000.00
0005432567174	30555	Economy	15000.00
0005434081704	30555	Economy	13600.00
0005433726071	30555	Economy	13600.00
0005434081709	30555	Economy	13600.00
0005432459559	30555	Economy	13600.00
0005432567008	30555	Economy	13600.00
0005433726072	30555	Economy	13600.00
0005432459488	30555	Economy	13600.00
0005432459385	30555	Economy	13600.00
0005432459366	30555	Economy	13600.00
0005432567260	30555	Economy	13600.00
0005432567197	30555	Economy	13600.00
0005433726067	30555	Economy	13600.00
0005432459444	30555	Economy	13600.00
0005434081531	30555	Economy	13600.00
0005432459439	30555	Economy	13600.00
0005432567384	30555	Economy	13600.00
0005432459446	30555	Economy	13600.00
0005433726063	30555	Economy	13600.00
0005432567116	30555	Economy	13600.00
0005432567107	30555	Economy	13600.00
0005432566970	30555	Economy	13600.00
0005432567079	30555	Economy	13600.00
0005432459532	30555	Economy	13600.00
0005432571269	30555	Economy	13600.00
0005432566865	30555	Economy	13600.00
0005433452721	30555	Economy	13600.00
0005433726070	30555	Economy	13600.00
0005432566939	30555	Economy	13600.00
0005432567024	30555	Economy	13600.00
0005432567339	30555	Economy	13600.00
0005434081543	30555	Economy	13600.00
0005432567099	30555	Economy	13600.00
0005432566951	30555	Economy	13600.00
0005434081591	30555	Economy	13600.00
0005432567239	30555	Economy	13600.00
0005432567087	30555	Economy	13600.00
0005432567047	30555	Economy	13600.00
0005432566878	30555	Economy	13600.00
0005432459268	30555	Economy	13600.00
0005432459561	30555	Economy	13600.00
0005434081671	30555	Economy	13600.00
0005434081595	30555	Economy	13600.00
0005432567012	30555	Economy	13600.00
0005434081674	30555	Economy	13600.00
0005432161150	30555	Economy	13600.00
0005432459453	30555	Economy	13600.00
0005432567240	30555	Economy	13600.00
0005432459426	30555	Economy	13600.00
0005434081585	30555	Economy	13600.00
0005432571280	30555	Economy	13600.00
0005434081635	30555	Economy	13600.00
0005432459389	30555	Economy	13600.00
0005432566946	30555	Economy	13600.00
0005432459355	30555	Economy	13600.00
0005432566797	30555	Economy	13600.00
0005432567145	30555	Economy	13600.00
0005432459384	30555	Economy	13600.00
0005432567259	30555	Economy	13600.00
0005432459489	30555	Economy	13600.00
0005434081701	30555	Economy	13600.00
0005432567009	30555	Economy	13600.00
0005432567343	30555	Economy	13600.00
0005432567026	30555	Economy	13600.00
0005435722051	13632	Economy	9900.00
0005435722052	13632	Economy	9900.00
0005435722053	13632	Economy	9900.00
0005435720120	21221	Economy	9900.00
0005435722038	21221	Economy	9900.00
0005432295877	22789	Economy	8800.00
0005432295875	22789	Economy	8800.00
0005432295876	22789	Economy	8800.00
0005433343085	11125	Business	23600.00
0005433343043	11125	Business	23600.00
0005433343057	11125	Business	23600.00
0005435097183	11125	Business	23600.00
0005433343078	11125	Business	23600.00
0005435508239	11125	Business	23600.00
0005433343019	11125	Business	23600.00
0005435508242	11125	Business	23600.00
0005433343016	11125	Business	23600.00
0005433343039	11125	Business	23600.00
0005435508236	11125	Business	23600.00
0005433343106	11125	Business	23600.00
0005433343041	11125	Economy	7900.00
0005433343093	11125	Economy	7900.00
0005435097188	11125	Economy	7900.00
0005433343046	11125	Economy	7900.00
0005433343071	11125	Economy	7900.00
0005433343033	11125	Economy	7900.00
0005435380249	11125	Economy	7900.00
0005433343075	11125	Economy	7900.00
0005433343050	11125	Economy	7900.00
0005433343099	11125	Economy	7900.00
0005433343088	11125	Economy	7900.00
0005433343091	11125	Economy	7900.00
0005433343030	11125	Economy	7900.00
0005433343083	11125	Economy	7900.00
0005433343068	11125	Economy	7900.00
0005433343084	11125	Economy	7900.00
0005433343074	11125	Economy	7900.00
0005435508228	11125	Economy	7900.00
0005433343015	11125	Economy	7900.00
0005433343103	11125	Economy	7900.00
0005433343060	11125	Economy	7900.00
0005433343102	11125	Economy	7900.00
0005433343026	11125	Economy	7900.00
0005433343038	11125	Economy	7900.00
0005433343087	11125	Economy	7900.00
0005433343051	11125	Economy	7900.00
0005433343025	11125	Economy	7900.00
0005433343082	11125	Economy	7900.00
0005435097184	11125	Economy	7900.00
0005433343020	11125	Economy	7900.00
0005433343032	11125	Economy	7900.00
0005433343086	11125	Economy	7900.00
0005433343053	11125	Economy	7900.00
0005435508243	11125	Economy	7900.00
0005435508261	11125	Economy	7900.00
0005435097189	11125	Economy	7900.00
0005433343077	11125	Economy	7900.00
0005433343065	11125	Economy	7900.00
0005433343049	11125	Economy	7900.00
0005435508227	11125	Economy	7900.00
0005433343076	11125	Economy	8600.00
0005433343067	11125	Economy	8600.00
0005433343042	11125	Economy	8600.00
0005433343061	11125	Economy	8600.00
0005433343012	11125	Economy	8600.00
0005433343063	11125	Economy	7900.00
0005433343100	11125	Economy	7900.00
0005433343052	11125	Economy	7900.00
0005435380268	11125	Economy	7900.00
0005433343014	11125	Economy	7900.00
0005433343048	11125	Economy	7900.00
0005433343080	11125	Economy	7900.00
0005435097185	11125	Economy	7900.00
0005433343011	11125	Economy	7900.00
0005433343104	11125	Economy	7900.00
0005433343031	11125	Economy	7900.00
0005433343079	11125	Economy	7900.00
0005433343024	11125	Economy	7900.00
0005433343107	11125	Economy	7900.00
0005433343072	11125	Economy	7900.00
0005433343017	11125	Economy	7900.00
0005435097186	11125	Economy	7900.00
0005433343037	11125	Economy	7900.00
0005433343029	11125	Economy	7900.00
0005433343094	11125	Economy	7900.00
0005433343073	11125	Economy	7900.00
0005433343047	11125	Economy	7900.00
0005433343090	11125	Economy	7900.00
0005435508260	11125	Economy	7900.00
0005435508271	11125	Economy	7900.00
0005433343069	11125	Economy	7900.00
0005433343045	11125	Economy	7900.00
0005433343035	11125	Economy	7900.00
0005433343108	11125	Economy	7900.00
0005433343056	11125	Economy	7900.00
0005435508258	11125	Economy	7900.00
0005433343070	11125	Economy	7900.00
0005433343064	11125	Economy	7900.00
0005433343055	11125	Economy	7900.00
0005433343092	11125	Economy	7900.00
0005433343066	11125	Economy	7900.00
0005433343023	11125	Economy	7900.00
0005435508272	11125	Economy	7900.00
0005435097181	11125	Economy	7900.00
0005433343054	11125	Economy	7900.00
0005433343097	11125	Economy	7900.00
0005433343059	11125	Economy	7900.00
0005433343081	11125	Economy	7900.00
0005433343036	11125	Economy	7900.00
0005433343010	11125	Economy	7900.00
0005433343095	11125	Economy	7900.00
0005433343058	11125	Economy	7900.00
0005433343040	11125	Economy	7900.00
0005433343096	11125	Economy	7900.00
0005433343034	11125	Economy	7900.00
0005433343022	11125	Economy	7900.00
0005433343109	11125	Economy	7900.00
0005433343018	11125	Economy	7900.00
0005435097187	11125	Economy	7900.00
0005433343098	11125	Economy	7900.00
0005433343089	11125	Economy	7900.00
0005435508257	11125	Economy	7900.00
0005433343021	11125	Economy	7900.00
0005433343044	11125	Economy	7900.00
0005433343062	11125	Economy	7900.00
0005435380248	11125	Economy	7900.00
0005433343101	11125	Economy	7900.00
0005433343105	11125	Economy	7900.00
0005433343110	11125	Economy	7900.00
0005433343028	11125	Economy	7900.00
0005433343027	11125	Economy	7900.00
0005435097182	11125	Economy	7900.00
0005433343009	11125	Economy	7900.00
0005433343013	11125	Economy	7900.00
0005435380292	17087	Business	23600.00
0005433342253	17087	Business	23600.00
0005435380289	17087	Business	23600.00
0005433342268	17087	Business	23600.00
0005433342091	17087	Business	23600.00
0005433342005	17087	Business	23600.00
0005433342069	17087	Business	23600.00
0005433342292	17087	Business	23600.00
0005433342345	17087	Business	23600.00
0005433342092	17087	Business	23600.00
0005435097096	17087	Business	23600.00
0005435097074	17087	Business	23600.00
0005433341758	17087	Economy	7900.00
0005435545724	17087	Economy	7900.00
0005435545723	17087	Economy	7900.00
0005435545728	17087	Economy	7900.00
0005433342007	17087	Economy	7900.00
0005433342153	17087	Economy	7900.00
0005435380291	17087	Economy	7900.00
0005435545732	17087	Economy	7900.00
0005433342233	17087	Economy	7900.00
0005433341822	17087	Economy	7900.00
0005433342267	17087	Economy	7900.00
0005433341736	17087	Economy	7900.00
0005433342350	17087	Economy	7900.00
0005435097114	17087	Economy	7900.00
0005433342344	17087	Economy	7900.00
0005433342279	17087	Economy	7900.00
0005433342266	17087	Economy	7900.00
0005433341778	17087	Economy	7900.00
0005433342169	17087	Economy	7900.00
0005433341884	17087	Economy	7900.00
0005433342200	17087	Economy	7900.00
0005433342134	17087	Economy	7900.00
0005433341608	17087	Economy	7900.00
0005433342352	17087	Economy	7900.00
0005433342010	17087	Economy	7900.00
0005433342119	17087	Economy	7900.00
0005433342293	17087	Economy	7900.00
0005433342389	17087	Economy	7900.00
0005433341780	17087	Economy	7900.00
0005433342089	17087	Economy	7900.00
0005435545730	17087	Economy	7900.00
0005435097107	17087	Economy	7900.00
0005433342387	17087	Economy	7900.00
0005433342148	17087	Economy	7900.00
0005435380290	17087	Economy	7900.00
0005433342416	17087	Economy	7900.00
0005435097092	17087	Economy	7900.00
0005435097073	17087	Economy	8600.00
0005435545726	17087	Economy	8600.00
0005435097093	17087	Economy	8600.00
0005433341955	17087	Economy	8600.00
0005433342090	17087	Economy	8600.00
0005433341879	17087	Economy	8600.00
0005433341735	17087	Economy	7900.00
0005433341642	17087	Economy	7900.00
0005435380293	17087	Economy	7900.00
0005433341960	17087	Economy	7900.00
0005433342123	17087	Economy	7900.00
0005433341528	17087	Economy	7900.00
0005433342113	17087	Economy	7900.00
0005433342015	17087	Economy	7900.00
0005433342117	17087	Economy	7900.00
0005435097106	17087	Economy	7900.00
0005433342252	17087	Economy	7900.00
0005433342027	17087	Economy	7900.00
0005433342114	17087	Economy	7900.00
0005433342397	17087	Economy	7900.00
0005433342132	17087	Economy	7900.00
0005433341708	17087	Economy	7900.00
0005435097105	17087	Economy	7900.00
0005433342147	17087	Economy	7900.00
0005433342247	17087	Economy	7900.00
0005433342137	17087	Economy	7900.00
0005433342112	17087	Economy	7900.00
0005435097112	17087	Economy	7900.00
0005433342009	17087	Economy	7900.00
0005433342128	17087	Economy	7900.00
0005433342227	17087	Economy	7900.00
0005433342006	17087	Economy	7900.00
0005435545734	17087	Economy	7900.00
0005433342289	17087	Economy	7900.00
0005433342351	17087	Economy	7900.00
0005435545733	17087	Economy	7900.00
0005433342154	17087	Economy	7900.00
0005435545725	17087	Economy	7900.00
0005433341472	17087	Economy	7900.00
0005435380288	17087	Economy	7900.00
0005433342168	17087	Economy	7900.00
0005433341529	17087	Economy	7900.00
0005433342008	17087	Economy	7900.00
0005432293206	17087	Economy	7900.00
0005435097094	17087	Economy	7900.00
0005433342166	17087	Economy	7900.00
0005433341590	17087	Economy	7900.00
0005435097115	17087	Economy	7900.00
0005433342170	17087	Economy	7900.00
0005433342135	17087	Economy	7900.00
0005435545731	17087	Economy	7900.00
0005433342396	17087	Economy	7900.00
0005433342234	17087	Economy	7900.00
0005433341775	17087	Economy	7900.00
0005435545735	17087	Economy	7900.00
0005433342386	17087	Economy	7900.00
0005433342235	17087	Economy	7900.00
0005433342201	17087	Economy	7900.00
0005433342146	17087	Economy	7900.00
0005433342136	17087	Economy	7900.00
0005433341924	17087	Economy	7900.00
0005435545729	17087	Economy	7900.00
0005432293205	17087	Economy	7900.00
0005433341928	17087	Economy	7900.00
0005433342398	17087	Economy	7900.00
0005435545727	17087	Economy	7900.00
0005433342140	17087	Economy	7900.00
0005433342186	17087	Economy	7900.00
0005435097113	17087	Economy	7900.00
0005433341878	17087	Economy	7900.00
0005433507159	9068	Business	26600.00
0005432919703	9068	Business	26600.00
0005432919505	9068	Business	26600.00
0005432919650	9068	Business	26600.00
0005433507161	9068	Business	26600.00
0005433507170	9068	Business	26600.00
0005433507169	9068	Economy	8900.00
0005432919613	9068	Economy	8900.00
0005433481159	9068	Economy	8900.00
0005433481155	9068	Economy	8900.00
0005433481163	9068	Economy	8900.00
0005433507164	9068	Economy	9800.00
0005433481158	9068	Economy	9800.00
0005433481156	9068	Economy	9800.00
0005432919532	9068	Economy	8900.00
0005433507171	9068	Economy	8900.00
0005433507163	9068	Economy	8900.00
0005433507167	9068	Economy	8900.00
0005432919625	9068	Economy	8900.00
0005433507165	9068	Economy	8900.00
0005433507174	9068	Economy	8900.00
0005432919651	9068	Economy	8900.00
0005432919647	9068	Economy	8900.00
0005433507166	9068	Economy	8900.00
0005433481160	9068	Economy	8900.00
0005432919683	9068	Economy	8900.00
0005433507160	9068	Economy	8900.00
0005432919637	9068	Economy	8900.00
0005432919630	9068	Economy	8900.00
0005432919682	9068	Economy	8900.00
0005432919649	9068	Economy	8900.00
0005432919713	9068	Economy	8900.00
0005433507162	9068	Economy	8900.00
0005433507172	9068	Economy	8900.00
0005432919706	9068	Economy	8900.00
0005433507173	9068	Economy	8900.00
0005432919693	9068	Economy	8900.00
0005433507158	9068	Economy	8900.00
0005432919712	9068	Economy	8900.00
0005432919719	9068	Economy	8900.00
0005433481162	9068	Economy	8900.00
0005432919646	9068	Economy	8900.00
0005432919603	9068	Economy	8900.00
0005433507175	9068	Economy	8900.00
0005432919670	9068	Economy	8900.00
0005433507176	9068	Economy	8900.00
0005432919574	9068	Economy	8900.00
0005432919648	9068	Economy	8900.00
0005432919668	9068	Economy	8900.00
0005433507168	9068	Economy	8900.00
0005433481161	9068	Economy	8900.00
0005433481157	9068	Economy	8900.00
0005433507157	9068	Economy	8900.00
0005432919698	9068	Economy	8900.00
0005433507002	20465	Business	26600.00
0005433506948	20465	Business	26600.00
0005433507003	20465	Business	26600.00
0005432919851	20465	Business	26600.00
0005432919859	20465	Business	26600.00
0005433507041	20465	Business	26600.00
0005433507054	20465	Business	26600.00
0005432919857	20465	Business	26600.00
0005433507042	20465	Economy	8900.00
0005433507040	20465	Economy	8900.00
0005434158973	20465	Economy	8900.00
0005432919856	20465	Economy	8900.00
0005434158974	20465	Economy	8900.00
0005433481094	20465	Economy	9800.00
0005432919863	20465	Economy	9800.00
0005433507015	20465	Economy	9800.00
0005432919865	20465	Economy	9800.00
0005433506968	20465	Economy	9800.00
0005432919850	20465	Economy	8900.00
0005433481121	20465	Economy	8900.00
0005432919866	20465	Economy	8900.00
0005432919855	20465	Economy	8900.00
0005432919845	20465	Economy	8900.00
0005433507016	20465	Economy	8900.00
0005433481106	20465	Economy	8900.00
0005432919867	20465	Economy	8900.00
0005432919854	20465	Economy	8900.00
0005433481114	20465	Economy	8900.00
0005433507026	20465	Economy	8900.00
0005433506940	20465	Economy	8900.00
0005433481105	20465	Economy	8900.00
0005433506945	20465	Economy	8900.00
0005432919852	20465	Economy	8900.00
0005432919847	20465	Economy	8900.00
0005433507071	20465	Economy	8900.00
0005433507072	20465	Economy	8900.00
0005433507053	20465	Economy	8900.00
0005432919862	20465	Economy	8900.00
0005433507004	20465	Economy	8900.00
0005433481088	20465	Economy	8900.00
0005433481126	20465	Economy	8900.00
0005433506941	20465	Economy	8900.00
0005432919849	20465	Economy	8900.00
0005433506946	20465	Economy	8900.00
0005432919861	20465	Economy	8900.00
0005432919848	20465	Economy	8900.00
0005432919860	20465	Economy	8900.00
0005432919858	20465	Economy	8900.00
0005432919846	20465	Economy	8900.00
0005433481104	20465	Economy	8900.00
0005433506978	20465	Economy	8900.00
0005433507025	20465	Economy	8900.00
0005433481113	20465	Economy	8900.00
0005433507058	20465	Economy	8900.00
0005432919853	20465	Economy	8900.00
0005432919864	20465	Economy	8900.00
0005432396233	10212	Economy	5800.00
0005432394097	10212	Economy	5800.00
0005432396236	10212	Economy	5800.00
0005432394096	10212	Economy	5800.00
0005435178977	10212	Economy	5800.00
0005432396234	10212	Economy	5800.00
0005432394095	10212	Economy	5800.00
0005432394094	10212	Economy	5800.00
0005432396235	10212	Economy	5800.00
0005432394098	10212	Economy	5800.00
0005432400076	18312	Economy	5800.00
0005432400081	18312	Economy	5800.00
0005432400094	18312	Economy	5800.00
0005432400091	18312	Economy	5800.00
0005432400093	18312	Economy	5800.00
0005432400077	18312	Economy	5800.00
0005432400080	18312	Economy	5800.00
0005432400075	18312	Economy	5800.00
0005435179692	18312	Economy	5800.00
0005432400095	18312	Economy	5800.00
0005435625988	10934	Business	9500.00
0005435126100	10934	Business	9500.00
0005435126060	10934	Business	9500.00
0005434411775	10934	Business	9500.00
0005435125945	10934	Business	9500.00
0005435125888	10934	Business	9500.00
0005435625949	10934	Business	9500.00
0005435554146	10934	Business	9500.00
0005435125960	10934	Business	9500.00
0005435126061	10934	Business	9500.00
0005435126101	10934	Business	9500.00
0005435625963	10934	Business	9500.00
0005435126014	10934	Economy	3200.00
0005435126035	10934	Economy	3200.00
0005435125961	10934	Economy	3200.00
0005435125975	10934	Economy	3200.00
0005434928298	10934	Economy	3200.00
0005435625928	10934	Economy	3200.00
0005435125902	10934	Economy	3200.00
0005435126018	10934	Economy	3200.00
0005435125944	10934	Economy	3500.00
0005435554139	10934	Economy	3500.00
0005434411774	10934	Economy	3500.00
0005435625983	10934	Economy	3500.00
0005435125951	10934	Economy	3200.00
0005435625955	10934	Economy	3200.00
0005435126013	10934	Economy	3200.00
0005435625967	10934	Economy	3200.00
0005435625982	10934	Economy	3200.00
0005435556667	10934	Economy	3200.00
0005435625939	10934	Economy	3200.00
0005435125848	10934	Economy	3200.00
0005435125996	10934	Economy	3200.00
0005434928295	10934	Economy	3200.00
0005435125826	10934	Economy	3200.00
0005435556666	10934	Economy	3200.00
0005435125942	10934	Economy	3200.00
0005435126037	10934	Economy	3200.00
0005435625992	10934	Economy	3200.00
0005435126030	10934	Economy	3200.00
0005435126041	10934	Economy	3200.00
0005435125977	10934	Economy	3200.00
0005435126074	10934	Economy	3200.00
0005435125838	10934	Economy	3200.00
0005435126012	10934	Economy	3200.00
0005435125865	10934	Economy	3200.00
0005435625991	10934	Economy	3200.00
0005435125868	10934	Economy	3200.00
0005435125946	10934	Economy	3200.00
0005435125859	10934	Economy	3200.00
0005435625990	10934	Economy	3200.00
0005435125964	10934	Economy	3200.00
0005434928296	10934	Economy	3200.00
0005435625950	10934	Economy	3200.00
0005435125989	10934	Economy	3200.00
0005435625968	10934	Economy	3200.00
0005435126036	10934	Economy	3200.00
0005435125903	10934	Economy	3200.00
0005435126001	10934	Economy	3200.00
0005434411772	10934	Economy	3200.00
0005435125829	10934	Economy	3200.00
0005435125976	10934	Economy	3200.00
0005435126079	10934	Economy	3200.00
0005435126112	10934	Economy	3200.00
0005435125858	10934	Economy	3200.00
0005435125990	10934	Economy	3200.00
0005435125880	10934	Economy	3200.00
0005435625936	10934	Economy	3200.00
0005435625892	10934	Economy	3200.00
0005435125978	10934	Economy	3200.00
0005435625966	10934	Economy	3200.00
0005435625938	10934	Economy	3200.00
0005435554134	10934	Economy	3200.00
0005435625984	10934	Economy	3200.00
0005434928299	10934	Economy	3200.00
0005434411773	10934	Economy	3200.00
0005435126116	10934	Economy	3200.00
0005435625987	10934	Economy	3200.00
0005434928297	10934	Economy	3200.00
0005435125837	10934	Economy	3200.00
0005435554133	10934	Economy	3200.00
0005435625986	10934	Economy	3200.00
0005435125970	10934	Economy	3200.00
0005434928272	14688	Business	9500.00
0005435126350	14688	Business	9500.00
0005435126348	14688	Business	9500.00
0005435626154	14688	Business	9500.00
0005435126317	14688	Business	9500.00
0005435626150	14688	Business	9500.00
0005434411706	14688	Business	9500.00
0005434928274	14688	Business	9500.00
0005435626164	14688	Business	9500.00
0005434411727	14688	Business	9500.00
0005435126316	14688	Business	9500.00
0005435626145	14688	Economy	3200.00
0005435626153	14688	Economy	3200.00
0005435126326	14688	Economy	3200.00
0005435126340	14688	Economy	3200.00
0005435126323	14688	Economy	3200.00
0005435126329	14688	Economy	3200.00
0005435126354	14688	Economy	3200.00
0005435626149	14688	Economy	3200.00
0005435556689	14688	Economy	3500.00
0005435626148	14688	Economy	3200.00
0005435126330	14688	Economy	3200.00
0005435126324	14688	Economy	3200.00
0005435126341	14688	Economy	3200.00
0005435626159	14688	Economy	3200.00
0005435126331	14688	Economy	3200.00
0005435626160	14688	Economy	3200.00
0005435126318	14688	Economy	3200.00
0005435626152	14688	Economy	3200.00
0005435126332	14688	Economy	3200.00
0005435126319	14688	Economy	3200.00
0005435126327	14688	Economy	3200.00
0005435126351	14688	Economy	3200.00
0005434411705	14688	Economy	3200.00
0005435626155	14688	Economy	3200.00
0005435626147	14688	Economy	3200.00
0005435126334	14688	Economy	3200.00
0005435554178	14688	Economy	3200.00
0005435126349	14688	Economy	3200.00
0005435126342	14688	Economy	3200.00
0005434928275	14688	Economy	3200.00
0005435126315	14688	Economy	3200.00
0005435126338	14688	Economy	3200.00
0005435126353	14688	Economy	3200.00
0005434928276	14688	Economy	3200.00
0005435556690	14688	Economy	3200.00
0005435126343	14688	Economy	3200.00
0005435626157	14688	Economy	3200.00
0005435554177	14688	Economy	3200.00
0005435126337	14688	Economy	3200.00
0005434411736	14688	Economy	3200.00
0005435126320	14688	Economy	3200.00
0005435126333	14688	Economy	3200.00
0005435126346	14688	Economy	3200.00
0005435126335	14688	Economy	3200.00
0005434411737	14688	Economy	3200.00
0005435626151	14688	Economy	3200.00
0005435554179	14688	Economy	3200.00
0005435626158	14688	Economy	3200.00
0005435126314	14688	Economy	3200.00
0005435626162	14688	Economy	3200.00
0005435626146	14688	Economy	3200.00
0005435626163	14688	Economy	3200.00
0005435554181	14688	Economy	3200.00
0005435126336	14688	Economy	3200.00
0005434928271	14688	Economy	3200.00
0005435626161	14688	Economy	3200.00
0005435556688	14688	Economy	3200.00
0005435126321	14688	Economy	3200.00
0005435126345	14688	Economy	3200.00
0005435126344	14688	Economy	3200.00
0005435126339	14688	Economy	3200.00
0005434411735	14688	Economy	3200.00
0005435126325	14688	Economy	3200.00
0005435126347	14688	Economy	3200.00
0005435126328	14688	Economy	3200.00
0005435626156	14688	Economy	3200.00
0005435554180	14688	Economy	3200.00
0005435126352	14688	Economy	3200.00
0005435126322	14688	Economy	3200.00
0005435715446	7136	Business	86900.00
0005435715447	7136	Business	86900.00
0005435715444	7136	Business	86900.00
0005435216563	7136	Business	86900.00
0005435443255	7136	Business	86900.00
0005432400118	7136	Business	86900.00
0005435715456	7136	Economy	29000.00
0005432400119	7136	Economy	29000.00
0005435221049	7136	Economy	29000.00
0005435443202	7136	Economy	29000.00
0005435219179	7136	Economy	29000.00
0005435216571	7136	Economy	31900.00
0005435715455	7136	Economy	31900.00
0005435715457	7136	Economy	29000.00
0005432398194	7136	Economy	29000.00
0005435715448	7136	Economy	29000.00
0005435715454	7136	Economy	29000.00
0005435715445	7136	Economy	29000.00
0005435443256	7136	Economy	29000.00
0005435221048	7136	Economy	29000.00
0005432400120	7136	Economy	29000.00
0005435443198	7136	Economy	29000.00
0005435715450	7136	Economy	29000.00
0005435216567	7136	Economy	29000.00
0005435715443	7136	Economy	29000.00
0005435443231	7136	Economy	29000.00
0005432400121	7136	Economy	29000.00
0005432398195	7136	Economy	29000.00
0005435443233	7136	Economy	29000.00
0005435179388	7136	Economy	29000.00
0005435715442	7136	Economy	29000.00
0005435443199	7136	Economy	29000.00
0005435443242	7136	Economy	29000.00
0005435715449	7136	Economy	29000.00
0005432398192	7136	Economy	29000.00
0005435715453	7136	Economy	29000.00
0005432398193	7136	Economy	29000.00
0005435216568	7136	Economy	29000.00
0005435443232	7136	Economy	29000.00
0005435178490	7136	Economy	29000.00
0005435178480	7136	Economy	29000.00
0005435715452	7136	Economy	29000.00
0005435715451	7136	Economy	29000.00
0005435715441	7136	Economy	29000.00
0005435715234	27070	Business	86900.00
0005435715282	27070	Business	86900.00
0005432394060	27070	Business	86900.00
0005432398167	27070	Business	86900.00
0005435715257	27070	Economy	29000.00
0005435715359	27070	Economy	29000.00
0005435715368	27070	Economy	29000.00
0005432398159	27070	Economy	29000.00
0005435715290	27070	Economy	29000.00
0005435715334	27070	Economy	29000.00
0005435443307	27070	Economy	29000.00
0005435715358	27070	Economy	29000.00
0005435715283	27070	Economy	31900.00
0005435443302	27070	Economy	31900.00
0005432398166	27070	Economy	31900.00
0005435715333	27070	Economy	31900.00
0005432398150	27070	Economy	31900.00
0005435443304	27070	Economy	29000.00
0005435178991	27070	Economy	29000.00
0005435715236	27070	Economy	29000.00
0005432394061	27070	Economy	29000.00
0005435443303	27070	Economy	29000.00
0005435443301	27070	Economy	29000.00
0005435715403	27070	Economy	29000.00
0005435443299	27070	Economy	29000.00
0005435443300	27070	Economy	29000.00
0005435443306	27070	Economy	29000.00
0005435715332	27070	Economy	29000.00
0005435715369	27070	Economy	29000.00
0005435715308	27070	Economy	29000.00
0005435715235	27070	Economy	29000.00
0005435715233	27070	Economy	29000.00
0005435715347	27070	Economy	29000.00
0005435715252	27070	Economy	29000.00
0005432398158	27070	Economy	29000.00
0005432398153	27070	Economy	29000.00
0005435715404	27070	Economy	29000.00
0005435715402	27070	Economy	29000.00
0005435715291	27070	Economy	29000.00
0005435443305	27070	Economy	29000.00
0005435178493	27070	Economy	29000.00
0005435715356	27070	Economy	29000.00
0005434084926	2705	Economy	7700.00
0005434084925	2705	Economy	7700.00
0005433060393	2705	Economy	7700.00
0005434084927	2705	Economy	7700.00
0005434084924	2705	Economy	7700.00
0005433060391	2705	Economy	7700.00
0005433060392	2705	Economy	7700.00
0005433060411	28481	Economy	7700.00
0005433060410	28481	Economy	7700.00
0005433060409	28481	Economy	7700.00
0005435540731	11365	Business	20200.00
0005435540783	11365	Business	20200.00
0005435517734	11365	Business	20200.00
0005435517723	11365	Business	20200.00
0005435540805	11365	Economy	6700.00
0005435517672	11365	Economy	6700.00
0005435517673	11365	Economy	7400.00
0005435517674	11365	Economy	6700.00
0005435540804	11365	Economy	6700.00
0005435540784	11365	Economy	6700.00
0005435517602	11365	Economy	6700.00
0005435540751	11365	Economy	6700.00
0005435517789	11365	Economy	6700.00
0005435517718	11365	Economy	6700.00
0005435517722	11365	Economy	6700.00
0005435517669	11365	Economy	6700.00
0005435517727	11365	Economy	6700.00
0005435540820	11365	Economy	6700.00
0005435540730	11365	Economy	6700.00
0005435540794	11365	Economy	6700.00
0005435540817	11365	Economy	6700.00
0005435540763	11365	Economy	6700.00
0005435540793	11365	Economy	6700.00
0005435540819	11365	Economy	6700.00
0005435540851	11365	Economy	6700.00
0005435517603	11365	Economy	6700.00
0005435517726	11365	Economy	6700.00
0005435517736	11365	Economy	6700.00
0005435517728	11365	Economy	6700.00
0005435540966	22258	Business	20200.00
0005435529212	22258	Business	20200.00
0005432294483	22258	Business	20200.00
0005435540972	22258	Business	20200.00
0005435529218	22258	Business	20200.00
0005435540968	22258	Economy	6700.00
0005432294482	22258	Economy	6700.00
0005435529213	22258	Economy	6700.00
0005435540975	22258	Economy	6700.00
0005435540971	22258	Economy	6700.00
0005435540974	22258	Economy	7400.00
0005435529223	22258	Economy	7400.00
0005435529231	22258	Economy	6700.00
0005435540961	22258	Economy	6700.00
0005435529229	22258	Economy	6700.00
0005435529215	22258	Economy	6700.00
0005435540960	22258	Economy	6700.00
0005435540962	22258	Economy	6700.00
0005435540956	22258	Economy	6700.00
0005435540976	22258	Economy	6700.00
0005435540973	22258	Economy	6700.00
0005435540967	22258	Economy	6700.00
0005435540970	22258	Economy	6700.00
0005435529232	22258	Economy	6700.00
0005435529224	22258	Economy	6700.00
0005435529211	22258	Economy	6700.00
0005435540957	22258	Economy	6700.00
0005435529220	22258	Economy	6700.00
0005435540965	22258	Economy	6700.00
0005435529217	22258	Economy	6700.00
0005435529228	22258	Economy	6700.00
0005435540964	22258	Economy	6700.00
0005435540959	22258	Economy	6700.00
0005435529222	22258	Economy	6700.00
0005435540963	22258	Economy	6700.00
0005435529233	22258	Economy	6700.00
0005435529216	22258	Economy	6700.00
0005435529230	22258	Economy	6700.00
0005435540977	22258	Economy	6700.00
0005435529227	22258	Economy	6700.00
0005435540955	22258	Economy	6700.00
0005435540969	22258	Economy	6700.00
0005435529221	22258	Economy	6700.00
0005435529226	22258	Economy	6700.00
0005435529214	22258	Economy	6700.00
0005435540958	22258	Economy	6700.00
0005435529225	22258	Economy	6700.00
0005435529219	22258	Economy	6700.00
0005433251145	2265	Business	20200.00
0005434907233	2265	Business	20200.00
0005433251140	2265	Business	20200.00
0005434907262	2265	Business	20200.00
0005434907223	2265	Business	20200.00
0005434907259	2265	Business	20200.00
0005433251191	2265	Business	20200.00
0005434907260	2265	Business	20200.00
0005434907234	2265	Business	20200.00
0005433400967	2265	Business	20200.00
0005434907230	2265	Business	20200.00
0005434907225	2265	Economy	6700.00
0005433251281	2265	Economy	6700.00
0005433251192	2265	Economy	6700.00
0005434907239	2265	Economy	6700.00
0005434907253	2265	Economy	6700.00
0005434907229	2265	Economy	6700.00
0005434907216	2265	Economy	6700.00
0005433251246	2265	Economy	6700.00
0005434907257	2265	Economy	6700.00
0005433251359	2265	Economy	6700.00
0005434907221	2265	Economy	7400.00
0005433251226	2265	Economy	7400.00
0005433251357	2265	Economy	7400.00
0005434907248	2265	Economy	7400.00
0005434907215	2265	Economy	7400.00
0005434907245	2265	Economy	6700.00
0005434907255	2265	Economy	6700.00
0005433251219	2265	Economy	6700.00
0005434907252	2265	Economy	6700.00
0005434907231	2265	Economy	6700.00
0005433251091	2265	Economy	6700.00
0005434907246	2265	Economy	6700.00
0005434907254	2265	Economy	6700.00
0005433251225	2265	Economy	6700.00
0005434907235	2265	Economy	6700.00
0005434907237	2265	Economy	6700.00
0005433251209	2265	Economy	6700.00
0005433251322	2265	Economy	6700.00
0005433400960	2265	Economy	6700.00
0005434907249	2265	Economy	6700.00
0005433251218	2265	Economy	6700.00
0005434907251	2265	Economy	6700.00
0005433251144	2265	Economy	6700.00
0005433400968	2265	Economy	6700.00
0005434907217	2265	Economy	6700.00
0005434907241	2265	Economy	6700.00
0005433251245	2265	Economy	6700.00
0005433251293	2265	Economy	6700.00
0005433251190	2265	Economy	6700.00
0005433251150	2265	Economy	6700.00
0005434907258	2265	Economy	6700.00
0005434907232	2265	Economy	6700.00
0005434907250	2265	Economy	6700.00
0005433251120	2265	Economy	6700.00
0005434907214	2265	Economy	6700.00
0005434907218	2265	Economy	6700.00
0005433251193	2265	Economy	6700.00
0005434907244	2265	Economy	6700.00
0005433251179	2265	Economy	6700.00
0005433251211	2265	Economy	6700.00
0005434907228	2265	Economy	6700.00
0005434907240	2265	Economy	6700.00
0005434907226	2265	Economy	6700.00
0005433251161	2265	Economy	6700.00
0005433251323	2265	Economy	6700.00
0005434907243	2265	Economy	6700.00
0005433251306	2265	Economy	6700.00
0005434907256	2265	Economy	6700.00
0005433251358	2265	Economy	6700.00
0005434907220	2265	Economy	6700.00
0005434907247	2265	Economy	6700.00
0005434907224	2265	Economy	6700.00
0005433251307	2265	Economy	6700.00
0005433251228	2265	Economy	6700.00
0005433251210	2265	Economy	6700.00
0005434907236	2265	Economy	6700.00
0005433251292	2265	Economy	6700.00
0005434907242	2265	Economy	6700.00
0005433251227	2265	Economy	6700.00
0005433251172	2265	Economy	6700.00
0005434907219	2265	Economy	6700.00
0005434907227	2265	Economy	6700.00
0005434907238	2265	Economy	6700.00
0005434907261	2265	Economy	6700.00
0005433251264	2265	Economy	6700.00
0005433251234	2265	Economy	6700.00
0005434907222	2265	Economy	6700.00
0005433251233	2265	Economy	6700.00
0005434906771	25618	Business	20200.00
0005434906792	25618	Business	20200.00
0005433251443	25618	Business	20200.00
0005434906749	25618	Business	20200.00
0005434906705	25618	Business	20200.00
0005433251444	25618	Business	20200.00
0005434906479	25618	Business	20200.00
0005434906624	25618	Business	20200.00
0005434906613	25618	Business	20200.00
0005434906674	25618	Business	20200.00
0005434906470	25618	Business	20200.00
0005433251434	25618	Business	20200.00
0005434906508	25618	Economy	6700.00
0005433251455	25618	Economy	6700.00
0005434906478	25618	Economy	6700.00
0005434906583	25618	Economy	6700.00
0005434906698	25618	Economy	6700.00
0005433251442	25618	Economy	6700.00
0005434906706	25618	Economy	6700.00
0005434906707	25618	Economy	6700.00
0005433251439	25618	Economy	6700.00
0005434906653	25618	Economy	7400.00
0005433251453	25618	Economy	7400.00
0005434906740	25618	Economy	7400.00
0005433251460	25618	Economy	7400.00
0005434906582	25618	Economy	7400.00
0005434906542	25618	Economy	6700.00
0005434906730	25618	Economy	6700.00
0005434906767	25618	Economy	6700.00
0005433251450	25618	Economy	6700.00
0005433400979	25618	Economy	6700.00
0005433251447	25618	Economy	6700.00
0005433251448	25618	Economy	6700.00
0005434906739	25618	Economy	6700.00
0005434906782	25618	Economy	6700.00
0005433400980	25618	Economy	6700.00
0005433251451	25618	Economy	6700.00
0005434906541	25618	Economy	6700.00
0005434906673	25618	Economy	6700.00
0005434906530	25618	Economy	6700.00
0005433251461	25618	Economy	6700.00
0005433251436	25618	Economy	6700.00
0005433251462	25618	Economy	6700.00
0005434906544	25618	Economy	6700.00
0005434906598	25618	Economy	6700.00
0005434906776	25618	Economy	6700.00
0005434906696	25618	Economy	6700.00
0005434906736	25618	Economy	6700.00
0005434906754	25618	Economy	6700.00
0005433251456	25618	Economy	6700.00
0005434906741	25618	Economy	6700.00
0005433251459	25618	Economy	6700.00
0005434906586	25618	Economy	6700.00
0005434906777	25618	Economy	6700.00
0005433251441	25618	Economy	6700.00
0005434906378	25618	Economy	6700.00
0005434906576	25618	Economy	6700.00
0005433251437	25618	Economy	6700.00
0005434906577	25618	Economy	6700.00
0005434906738	25618	Economy	6700.00
0005433251454	25618	Economy	6700.00
0005434906708	25618	Economy	6700.00
0005434906535	25618	Economy	6700.00
0005434906709	25618	Economy	6700.00
0005433251433	25618	Economy	6700.00
0005434906663	25618	Economy	6700.00
0005433251449	25618	Economy	6700.00
0005433251463	25618	Economy	6700.00
0005433251438	25618	Economy	6700.00
0005434906766	25618	Economy	6700.00
0005433251446	25618	Economy	6700.00
0005434906654	25618	Economy	6700.00
0005434906798	25618	Economy	6700.00
0005434906675	25618	Economy	6700.00
0005434906597	25618	Economy	6700.00
0005433251458	25618	Economy	6700.00
0005434906599	25618	Economy	6700.00
0005433251445	25618	Economy	6700.00
0005434906748	25618	Economy	6700.00
0005434906785	25618	Economy	6700.00
0005433400981	25618	Economy	6700.00
0005434906775	25618	Economy	6700.00
0005433251464	25618	Economy	6700.00
0005434906573	25618	Economy	6700.00
0005433251457	25618	Economy	6700.00
0005434906768	25618	Economy	6700.00
0005434906732	25618	Economy	6700.00
0005433251452	25618	Economy	6700.00
0005433251440	25618	Economy	6700.00
0005433251435	25618	Economy	6700.00
0005434906773	25618	Economy	6700.00
0005432621028	2495	Economy	13600.00
0005432862250	2495	Economy	12400.00
0005432621018	2495	Economy	12400.00
0005432621019	2495	Economy	12400.00
0005432621017	2495	Economy	12400.00
0005432862264	2495	Economy	12400.00
0005432621030	2495	Economy	12400.00
0005432621031	2495	Economy	12400.00
0005432621021	2495	Economy	12400.00
0005432621027	2495	Economy	12400.00
0005432621029	2495	Economy	12400.00
0005432862227	2495	Economy	12400.00
0005432621025	2495	Economy	12400.00
0005432862204	2495	Economy	12400.00
0005432621024	2495	Economy	12400.00
0005432621026	2495	Economy	12400.00
0005432621020	2495	Economy	12400.00
0005432621022	2495	Economy	12400.00
0005432621023	2495	Economy	12400.00
0005432620878	28080	Economy	13600.00
0005432862297	28080	Economy	12400.00
0005432620882	28080	Economy	12400.00
0005432862294	28080	Economy	12400.00
0005432620966	28080	Economy	12400.00
0005432620880	28080	Economy	12400.00
0005432862292	28080	Economy	12400.00
0005432620840	28080	Economy	12400.00
0005432862291	28080	Economy	12400.00
0005432620844	28080	Economy	12400.00
0005432862295	28080	Economy	12400.00
0005432620913	28080	Economy	12400.00
0005432862293	28080	Economy	12400.00
0005432620883	28080	Economy	12400.00
0005432862296	28080	Economy	12400.00
0005432620888	28080	Economy	12400.00
0005432620964	28080	Economy	12400.00
0005432620836	28080	Economy	12400.00
0005432620881	28080	Economy	12400.00
0005432620862	28080	Economy	12400.00
0005432620965	28080	Economy	12400.00
0005432620858	28080	Economy	12400.00
0005432620861	28080	Economy	12400.00
0005432620846	28080	Economy	12400.00
0005432862290	28080	Economy	12400.00
0005434097474	13031	Economy	11300.00
0005434097475	13031	Economy	11300.00
0005433451616	31040	Economy	8400.00
0005433452737	31040	Economy	8400.00
0005433451617	31040	Economy	8400.00
0005433452736	31040	Economy	8400.00
0005433452721	31347	Economy	8400.00
0005433452719	31347	Economy	8400.00
0005434184643	11975	Economy	7200.00
0005434142582	11975	Economy	6600.00
0005434142579	11975	Economy	6600.00
0005433134101	11975	Economy	6600.00
0005434142556	11975	Economy	6600.00
0005433129236	11975	Economy	6600.00
0005434184644	11975	Economy	6600.00
0005433134102	11975	Economy	6600.00
0005433134100	11975	Economy	6600.00
0005434142571	11975	Economy	6600.00
0005434184636	11975	Economy	6600.00
0005433134133	29859	Economy	7200.00
0005433134132	29859	Economy	7200.00
0005434142603	29859	Economy	6600.00
0005433134134	29859	Economy	6600.00
0005434183578	29859	Economy	6600.00
0005433134135	29859	Economy	6600.00
0005433131704	29859	Economy	6600.00
0005433131703	29859	Economy	6600.00
0005434183577	29859	Economy	6600.00
0005433131701	29859	Economy	6600.00
0005434184663	29859	Economy	6600.00
0005434184662	29859	Economy	6600.00
0005433131705	29859	Economy	6600.00
0005433131702	29859	Economy	6600.00
0005434326085	29859	Economy	6600.00
0005434142604	29859	Economy	6600.00
0005433134131	29859	Economy	6600.00
0005435697285	16499	Economy	19900.00
0005435697293	16499	Economy	19900.00
0005435697287	16499	Economy	18100.00
0005435697296	16499	Economy	18100.00
0005435697279	16499	Economy	18100.00
0005435697301	16499	Economy	18100.00
0005435697300	16499	Economy	18100.00
0005435697299	16499	Economy	18100.00
0005435697276	16499	Economy	18100.00
0005435697281	16499	Economy	18100.00
0005435697291	16499	Economy	18100.00
0005435697295	16499	Economy	18100.00
0005435697275	16499	Economy	18100.00
0005435697294	16499	Economy	18100.00
0005435697286	16499	Economy	18100.00
0005435697298	16499	Economy	18100.00
0005435697277	16499	Economy	18100.00
0005435697284	16499	Economy	18100.00
0005435697282	16499	Economy	18100.00
0005435697290	16499	Economy	18100.00
0005435697297	16499	Economy	18100.00
0005435697302	16499	Economy	18100.00
0005435697280	16499	Economy	18100.00
0005435697289	16499	Economy	18100.00
0005435935010	16499	Economy	18100.00
0005435697288	16499	Economy	18100.00
0005435935017	16499	Economy	18100.00
0005435697292	16499	Economy	18100.00
0005435697283	16499	Economy	18100.00
0005435697278	16499	Economy	18100.00
0005435935044	24734	Economy	19900.00
0005435697183	24734	Economy	19900.00
0005435697073	24734	Economy	18100.00
0005435697048	24734	Economy	18100.00
0005435697009	24734	Economy	18100.00
0005435697005	24734	Economy	18100.00
0005435697049	24734	Economy	18100.00
0005435697094	24734	Economy	18100.00
0005435935042	24734	Economy	18100.00
0005435697063	24734	Economy	18100.00
0005435697042	24734	Economy	18100.00
0005435697125	24734	Economy	18100.00
0005435697088	24734	Economy	18100.00
0005435697100	24734	Economy	18100.00
0005435935043	24734	Economy	18100.00
0005435697090	24734	Economy	18100.00
0005435697081	24734	Economy	18100.00
0005435697101	24734	Economy	18100.00
0005435697046	24734	Economy	18100.00
0005435696983	24734	Economy	18100.00
0005435697184	24734	Economy	18100.00
0005435697126	24734	Economy	18100.00
0005435697138	24734	Economy	18100.00
0005435697043	24734	Economy	18100.00
0005435697045	24734	Economy	18100.00
0005435697095	24734	Economy	18100.00
0005435696973	24734	Economy	18100.00
0005435697040	24734	Economy	18100.00
0005435697044	24734	Economy	18100.00
0005435697139	24734	Economy	18100.00
0005435697047	24734	Economy	18100.00
0005435696950	24734	Economy	18100.00
0005435697010	24734	Economy	18100.00
0005435697064	24734	Economy	18100.00
0005435696951	24734	Economy	18100.00
0005435697011	24734	Economy	18100.00
0005435697082	24734	Economy	18100.00
0005433724800	18775	Economy	4400.00
0005432968810	18775	Economy	4400.00
0005433724798	18775	Economy	4400.00
0005433724799	18775	Economy	4400.00
0005433724796	18775	Economy	4400.00
0005432968812	18775	Economy	4400.00
0005433724797	18775	Economy	4400.00
0005433724801	18775	Economy	4400.00
0005433724786	21615	Economy	4400.00
0005433724760	21615	Economy	4400.00
0005432968839	21615	Economy	4400.00
0005432968840	21615	Economy	4400.00
0005432968841	21615	Economy	4400.00
0005433724759	21615	Economy	4400.00
0005434138119	7305	Business	23100.00
0005434138080	7305	Business	23100.00
0005434138099	7305	Business	23100.00
0005434138114	7305	Business	23100.00
0005434138116	7305	Business	23100.00
0005434138076	7305	Business	23100.00
0005434138097	7305	Business	23100.00
0005434138060	7305	Business	23100.00
0005434138041	7305	Business	23100.00
0005434138124	7305	Business	23100.00
0005434087509	7305	Business	23100.00
0005434138072	7305	Economy	7700.00
0005434138055	7305	Economy	7700.00
0005434138112	7305	Economy	7700.00
0005434138091	7305	Economy	7700.00
0005434138047	7305	Economy	7700.00
0005434138063	7305	Economy	7700.00
0005434138095	7305	Economy	7700.00
0005434138086	7305	Economy	7700.00
0005434138079	7305	Economy	7700.00
0005434138043	7305	Economy	7700.00
0005434138074	7305	Economy	8500.00
0005434138061	7305	Economy	8500.00
0005434138092	7305	Economy	8500.00
0005434138120	7305	Economy	8500.00
0005434138122	7305	Economy	8500.00
0005434138110	7305	Economy	7700.00
0005434138123	7305	Economy	7700.00
0005434138090	7305	Economy	7700.00
0005434138071	7305	Economy	7700.00
0005434138102	7305	Economy	7700.00
0005434138104	7305	Economy	7700.00
0005434138064	7305	Economy	7700.00
0005434138044	7305	Economy	7700.00
0005434138108	7305	Economy	7700.00
0005434138088	7305	Economy	7700.00
0005434138107	7305	Economy	7700.00
0005434138048	7305	Economy	7700.00
0005434138067	7305	Economy	7700.00
0005434138096	7305	Economy	7700.00
0005434138051	7305	Economy	7700.00
0005434138037	7305	Economy	7700.00
0005434138084	7305	Economy	7700.00
0005434138065	7305	Economy	7700.00
0005434138035	7305	Economy	7700.00
0005434138115	7305	Economy	7700.00
0005434138103	7305	Economy	7700.00
0005434138040	7305	Economy	7700.00
0005434138100	7305	Economy	7700.00
0005434087507	7305	Economy	7700.00
0005434138081	7305	Economy	7700.00
0005434138056	7305	Economy	7700.00
0005434138062	7305	Economy	7700.00
0005434138105	7305	Economy	7700.00
0005434138075	7305	Economy	7700.00
0005434138053	7305	Economy	7700.00
0005434138045	7305	Economy	7700.00
0005434138058	7305	Economy	7700.00
0005434087510	7305	Economy	7700.00
0005434138070	7305	Economy	7700.00
0005434138054	7305	Economy	7700.00
0005434138049	7305	Economy	7700.00
0005434138082	7305	Economy	7700.00
0005434138073	7305	Economy	7700.00
0005434138039	7305	Economy	7700.00
0005434138094	7305	Economy	7700.00
0005434138111	7305	Economy	7700.00
0005434138036	7305	Economy	7700.00
0005434087508	7305	Economy	7700.00
0005434138085	7305	Economy	7700.00
0005434138118	7305	Economy	7700.00
0005434138077	7305	Economy	7700.00
0005434138089	7305	Economy	7700.00
0005434138078	7305	Economy	7700.00
0005434138057	7305	Economy	7700.00
0005434138068	7305	Economy	7700.00
0005434138113	7305	Economy	7700.00
0005434138093	7305	Economy	7700.00
0005434138042	7305	Economy	7700.00
0005434138038	7305	Economy	7700.00
0005434138052	7305	Economy	7700.00
0005434138098	7305	Economy	7700.00
0005434138083	7305	Economy	7700.00
0005434138066	7305	Economy	7700.00
0005434138101	7305	Economy	7700.00
0005434138046	7305	Economy	7700.00
0005434138059	7305	Economy	7700.00
0005434138117	7305	Economy	7700.00
0005434138106	7305	Economy	7700.00
0005434138069	7305	Economy	7700.00
0005434138050	7305	Economy	7700.00
0005434087506	7305	Economy	7700.00
0005434138109	7305	Economy	7700.00
0005434138087	7305	Economy	7700.00
0005434138121	7305	Economy	7700.00
0005434137553	28550	Business	23100.00
0005434137526	28550	Business	23100.00
0005434137398	28550	Business	23100.00
0005434087481	28550	Business	23100.00
0005434136970	28550	Business	23100.00
0005434137520	28550	Business	23100.00
0005434137738	28550	Business	23100.00
0005434137403	28550	Business	23100.00
0005434137182	28550	Business	23100.00
0005434137239	28550	Business	23100.00
0005434137536	28550	Business	23100.00
0005434137539	28550	Business	23100.00
0005434137256	28550	Economy	7700.00
0005434137528	28550	Economy	7700.00
0005434137589	28550	Economy	7700.00
0005434137117	28550	Economy	7700.00
0005434137529	28550	Economy	7700.00
0005434137512	28550	Economy	7700.00
0005434137596	28550	Economy	7700.00
0005434136777	28550	Economy	7700.00
0005434137354	28550	Economy	7700.00
0005434137491	28550	Economy	7700.00
0005434137439	28550	Economy	8500.00
0005434137144	28550	Economy	8500.00
0005434137346	28550	Economy	8500.00
0005434137579	28550	Economy	8500.00
0005434137222	28550	Economy	8500.00
0005434137350	28550	Economy	7700.00
0005434137177	28550	Economy	7700.00
0005434137737	28550	Economy	7700.00
0005434137537	28550	Economy	7700.00
0005434136840	28550	Economy	7700.00
0005434137227	28550	Economy	7700.00
0005434137492	28550	Economy	7700.00
0005434137408	28550	Economy	7700.00
0005434137591	28550	Economy	7700.00
0005434137033	28550	Economy	7700.00
0005434137240	28550	Economy	7700.00
0005434137472	28550	Economy	7700.00
0005434137330	28550	Economy	7700.00
0005434137422	28550	Economy	7700.00
0005434137490	28550	Economy	7700.00
0005434137181	28550	Economy	7700.00
0005434137238	28550	Economy	7700.00
0005434087467	28550	Economy	7700.00
0005434137279	28550	Economy	7700.00
0005434137473	28550	Economy	7700.00
0005434137225	28550	Economy	7700.00
0005434137230	28550	Economy	7700.00
0005434137231	28550	Economy	7700.00
0005434087469	28550	Economy	7700.00
0005434137185	28550	Economy	7700.00
0005434136942	28550	Economy	7700.00
0005434137347	28550	Economy	7700.00
0005434137437	28550	Economy	7700.00
0005434137195	28550	Economy	7700.00
0005434137597	28550	Economy	7700.00
0005434137198	28550	Economy	7700.00
0005434137392	28550	Economy	7700.00
0005434137155	28550	Economy	7700.00
0005434137059	28550	Economy	7700.00
0005434137005	28550	Economy	7700.00
0005434137673	28550	Economy	7700.00
0005434137287	28550	Economy	7700.00
0005434137554	28550	Economy	7700.00
0005434137471	28550	Economy	7700.00
0005434137525	28550	Economy	7700.00
0005434136873	28550	Economy	7700.00
0005434137152	28550	Economy	7700.00
0005434137438	28550	Economy	7700.00
0005434137057	28550	Economy	7700.00
0005434137353	28550	Economy	7700.00
0005434137178	28550	Economy	7700.00
0005434137391	28550	Economy	7700.00
0005434137197	28550	Economy	7700.00
0005434137255	28550	Economy	7700.00
0005434137196	28550	Economy	7700.00
0005434137233	28550	Economy	7700.00
0005434137426	28550	Economy	7700.00
0005434137407	28550	Economy	7700.00
0005434137349	28550	Economy	7700.00
0005434137118	28550	Economy	7700.00
0005434137351	28550	Economy	7700.00
0005434137466	28550	Economy	7700.00
0005434137402	28550	Economy	7700.00
0005434137226	28550	Economy	7700.00
0005434136969	28550	Economy	7700.00
0005434137151	28550	Economy	7700.00
0005434087468	28550	Economy	7700.00
0005435808230	1941	Economy	23900.00
0005435808229	1941	Economy	21700.00
0005435808222	1941	Economy	21700.00
0005433407509	1941	Economy	21700.00
0005435808224	1941	Economy	21700.00
0005433407516	1941	Economy	21700.00
0005435808225	1941	Economy	21700.00
0005433407513	1941	Economy	21700.00
0005435808226	1941	Economy	21700.00
0005435808227	1941	Economy	21700.00
0005435808221	1941	Economy	21700.00
0005434610225	1941	Economy	21700.00
0005434610226	1941	Economy	21700.00
0005435808228	1941	Economy	21700.00
0005434610224	1941	Economy	21700.00
0005433407510	1941	Economy	21700.00
0005435808223	1941	Economy	21700.00
0005434610227	1941	Economy	21700.00
0005433407512	1941	Economy	21700.00
0005434610195	23115	Economy	21700.00
0005434610174	23115	Economy	21700.00
0005434610173	23115	Economy	21700.00
0005434610175	23115	Economy	21700.00
0005434503855	16692	Economy	7600.00
0005434503687	16692	Economy	7600.00
0005434503655	16692	Economy	7600.00
0005434503675	16692	Economy	6900.00
0005434503685	16692	Economy	6900.00
0005434503709	16692	Economy	6900.00
0005434503824	16692	Economy	6900.00
0005434503594	16692	Economy	6900.00
0005434503657	16692	Economy	6900.00
0005434503800	16692	Economy	6900.00
0005434503809	16692	Economy	6900.00
0005434503763	16692	Economy	6900.00
0005434503859	16692	Economy	6900.00
0005434503595	16692	Economy	6900.00
0005434503708	16692	Economy	6900.00
0005434503792	16692	Economy	6900.00
0005434503844	16692	Economy	6900.00
0005434503693	16692	Economy	6900.00
0005434503704	16692	Economy	6900.00
0005434503810	16692	Economy	6900.00
0005434503872	16692	Economy	6900.00
0005434503730	16692	Economy	6900.00
0005434503928	16692	Economy	6900.00
0005434503605	16692	Economy	6900.00
0005434503845	16692	Economy	6900.00
0005434503656	16692	Economy	6900.00
0005434503789	16692	Economy	6900.00
0005434503889	16692	Economy	6900.00
0005434503699	16692	Economy	6900.00
0005434503703	16692	Economy	6900.00
0005434503801	16692	Economy	6900.00
0005434503748	16692	Economy	6900.00
0005434503823	16692	Economy	6900.00
0005434503694	16692	Economy	6900.00
0005434503682	16692	Economy	6900.00
0005434503920	16692	Economy	6900.00
0005434503606	16692	Economy	6900.00
0005434503858	16692	Economy	6900.00
0005434503731	16692	Economy	6900.00
0005434503686	16692	Economy	6900.00
0005434503956	16692	Economy	6900.00
0005434503803	16692	Economy	6900.00
0005434504075	22892	Economy	7600.00
0005434504086	22892	Economy	7600.00
0005434504076	22892	Economy	7600.00
0005434504067	22892	Economy	7600.00
0005434504103	22892	Economy	6900.00
0005434504087	22892	Economy	6900.00
0005434504083	22892	Economy	6900.00
0005434504102	22892	Economy	6900.00
0005434504090	22892	Economy	6900.00
0005434504066	22892	Economy	6900.00
0005434504092	22892	Economy	6900.00
0005434504093	22892	Economy	6900.00
0005434504101	22892	Economy	6900.00
0005434504073	22892	Economy	6900.00
0005434504095	22892	Economy	6900.00
0005434504069	22892	Economy	6900.00
0005434504097	22892	Economy	6900.00
0005434504078	22892	Economy	6900.00
0005434504070	22892	Economy	6900.00
0005434504064	22892	Economy	6900.00
0005434504100	22892	Economy	6900.00
0005434504065	22892	Economy	6900.00
0005434504079	22892	Economy	6900.00
0005434504063	22892	Economy	6900.00
0005434504089	22892	Economy	6900.00
0005434504081	22892	Economy	6900.00
0005434504098	22892	Economy	6900.00
0005434504082	22892	Economy	6900.00
0005434504077	22892	Economy	6900.00
0005434504088	22892	Economy	6900.00
0005434504068	22892	Economy	6900.00
0005434504099	22892	Economy	6900.00
0005434504085	22892	Economy	6900.00
0005434504096	22892	Economy	6900.00
0005434504091	22892	Economy	6900.00
0005434504084	22892	Economy	6900.00
0005434504080	22892	Economy	6900.00
0005434504062	22892	Economy	6900.00
0005434504074	22892	Economy	6900.00
0005434504094	22892	Economy	6900.00
0005434504072	22892	Economy	6900.00
0005434504071	22892	Economy	6900.00
0005435078325	2208	Economy	7700.00
0005435078318	2208	Economy	7000.00
0005435078333	2208	Economy	7000.00
0005433266630	2208	Economy	7000.00
0005435078321	2208	Economy	7000.00
0005435078330	2208	Economy	7000.00
0005433266634	2208	Economy	7000.00
0005435078323	2208	Economy	7000.00
0005433266663	2208	Economy	7000.00
0005435078320	2208	Economy	7000.00
0005435078327	2208	Economy	7000.00
0005435078329	2208	Economy	7000.00
0005433266637	2208	Economy	7000.00
0005433266635	2208	Economy	7000.00
0005435078331	2208	Economy	7000.00
0005435078324	2208	Economy	7000.00
0005435078326	2208	Economy	7000.00
0005433266664	2208	Economy	7000.00
0005435078319	2208	Economy	7000.00
0005433266636	2208	Economy	7000.00
0005435078328	2208	Economy	7000.00
0005435078322	2208	Economy	7000.00
0005433266617	2208	Economy	7000.00
0005435078332	2208	Economy	7000.00
0005433266633	2208	Economy	7000.00
0005433266709	24376	Economy	7700.00
0005433266716	24376	Economy	7700.00
0005435078254	24376	Economy	7000.00
0005435078200	24376	Economy	7000.00
0005435078162	24376	Economy	7000.00
0005433266715	24376	Economy	7000.00
0005433266711	24376	Economy	7000.00
0005435078209	24376	Economy	7000.00
0005433266714	24376	Economy	7000.00
0005435078231	24376	Economy	7000.00
0005435078268	24376	Economy	7000.00
0005435078255	24376	Economy	7000.00
0005435078218	24376	Economy	7000.00
0005435078193	24376	Economy	7000.00
0005435078164	24376	Economy	7000.00
0005435078198	24376	Economy	7000.00
0005435078269	24376	Economy	7000.00
0005433266717	24376	Economy	7000.00
0005433266713	24376	Economy	7000.00
0005435078167	24376	Economy	7000.00
0005435078143	24376	Economy	7000.00
0005435078166	24376	Economy	7000.00
0005435078204	24376	Economy	7000.00
0005435078125	24376	Economy	7000.00
0005435078256	24376	Economy	7000.00
0005433266719	24376	Economy	7000.00
0005435078208	24376	Economy	7000.00
0005433266718	24376	Economy	7000.00
0005433266712	24376	Economy	7000.00
0005435078184	24376	Economy	7000.00
0005435078206	24376	Economy	7000.00
0005435078213	24376	Economy	7000.00
0005433266710	24376	Economy	7000.00
0005435078172	24376	Economy	7000.00
0005435078230	24376	Economy	7000.00
0005435078165	24376	Economy	7000.00
0005435078163	24376	Economy	7000.00
0005435078194	24376	Economy	7000.00
0005434988735	6664	Economy	9800.00
0005434988725	6664	Economy	9800.00
0005434988727	6664	Economy	9800.00
0005434988732	6664	Economy	9800.00
0005434988724	6664	Economy	9800.00
0005435803261	6664	Economy	9800.00
0005434988729	6664	Economy	9800.00
0005435803260	6664	Economy	9800.00
0005434988722	6664	Economy	9800.00
0005434988726	6664	Economy	9800.00
0005434988739	6664	Economy	9800.00
0005434988738	6664	Economy	9800.00
0005434988728	6664	Economy	9800.00
0005434988723	6664	Economy	9800.00
0005434988734	6664	Economy	9800.00
0005435464494	6664	Economy	9800.00
0005434988730	6664	Economy	9800.00
0005434988737	6664	Economy	9800.00
0005434988733	6664	Economy	9800.00
0005434988736	6664	Economy	9800.00
0005434988731	6664	Economy	9800.00
0005434988606	23604	Economy	10800.00
0005435803245	23604	Economy	9800.00
0005435803243	23604	Economy	9800.00
0005435803244	23604	Economy	9800.00
0005435803232	23604	Economy	9800.00
0005434988652	23604	Economy	9800.00
0005434988638	23604	Economy	9800.00
0005434988611	23604	Economy	9800.00
0005434988609	23604	Economy	9800.00
0005435464505	23604	Economy	9800.00
0005434988614	23604	Economy	9800.00
0005434988595	23604	Economy	9800.00
0005434988651	23604	Economy	9800.00
0005434988610	23604	Economy	9800.00
0005435464504	23604	Economy	9800.00
0005434988605	23604	Economy	9800.00
0005434988612	23604	Economy	9800.00
0005432383136	30482	Business	9900.00
0005432383129	30482	Business	9900.00
0005433449950	30482	Business	9900.00
0005433449960	30482	Business	9900.00
0005433449961	30482	Business	9900.00
0005432383143	30482	Business	9900.00
0005432383158	30482	Economy	3300.00
0005432383165	30482	Economy	3300.00
0005432383160	30482	Economy	3300.00
0005432383151	30482	Economy	3300.00
0005433449941	30482	Economy	3300.00
0005432383137	30482	Economy	3300.00
0005433449955	30482	Economy	3300.00
0005433454874	30482	Economy	3600.00
0005433449953	30482	Economy	3600.00
0005433449958	30482	Economy	3600.00
0005432383135	30482	Economy	3300.00
0005433449944	30482	Economy	3300.00
0005432383149	30482	Economy	3300.00
0005432383155	30482	Economy	3300.00
0005432383138	30482	Economy	3300.00
0005433449945	30482	Economy	3300.00
0005432383159	30482	Economy	3300.00
0005432383157	30482	Economy	3300.00
0005432383164	30482	Economy	3300.00
0005433454875	30482	Economy	3300.00
0005433454873	30482	Economy	3300.00
0005432383130	30482	Economy	3300.00
0005432383131	30482	Economy	3300.00
0005432383154	30482	Economy	3300.00
0005433449947	30482	Economy	3300.00
0005433449952	30482	Economy	3300.00
0005433449949	30482	Economy	3300.00
0005432383134	30482	Economy	3300.00
0005433453761	30482	Economy	3300.00
0005432383141	30482	Economy	3300.00
0005433453762	30482	Economy	3300.00
0005432383139	30482	Economy	3300.00
0005433449959	30482	Economy	3300.00
0005432383144	30482	Economy	3300.00
0005433449946	30482	Economy	3300.00
0005433449951	30482	Economy	3300.00
0005432383145	30482	Economy	3300.00
0005432383142	30482	Economy	3300.00
0005432383161	30482	Economy	3300.00
0005432383152	30482	Economy	3300.00
0005432383156	30482	Economy	3300.00
0005432383162	30482	Economy	3300.00
0005433449943	30482	Economy	3300.00
0005432383150	30482	Economy	3300.00
0005433449954	30482	Economy	3300.00
0005433449948	30482	Economy	3300.00
0005432383146	30482	Economy	3300.00
0005433449956	30482	Economy	3300.00
0005432383163	30482	Economy	3300.00
0005433453763	30482	Economy	3300.00
0005432383147	30482	Economy	3300.00
0005432383132	30482	Economy	3300.00
0005433449942	30482	Economy	3300.00
0005433449957	30482	Economy	3300.00
0005432383133	30482	Economy	3300.00
0005432383166	30482	Economy	3300.00
0005432383140	30482	Economy	3300.00
0005432383148	30482	Economy	3300.00
0005432383153	30482	Economy	3300.00
0005433449751	31291	Business	9900.00
0005433449687	31291	Business	9900.00
0005433449705	31291	Business	9900.00
0005432382689	31291	Business	9900.00
0005432382750	31291	Business	9900.00
0005433449830	31291	Business	9900.00
0005433453736	31291	Business	9900.00
0005432382684	31291	Business	9900.00
0005433449742	31291	Economy	3300.00
0005433451590	31291	Economy	3300.00
0005432382722	31291	Economy	3300.00
0005432382683	31291	Economy	3300.00
0005433449775	31291	Economy	3300.00
0005433449799	31291	Economy	3300.00
0005432382676	31291	Economy	3300.00
0005432382751	31291	Economy	3600.00
0005433449767	31291	Economy	3600.00
0005433449651	31291	Economy	3600.00
0005433449802	31291	Economy	3600.00
0005433449688	31291	Economy	3600.00
0005433449726	31291	Economy	3300.00
0005433451605	31291	Economy	3300.00
0005433449849	31291	Economy	3300.00
0005432382672	31291	Economy	3300.00
0005432382721	31291	Economy	3300.00
0005433449750	31291	Economy	3300.00
0005432382616	31291	Economy	3300.00
0005432382587	31291	Economy	3300.00
0005432382749	31291	Economy	3300.00
0005433449752	31291	Economy	3300.00
0005432382742	31291	Economy	3300.00
0005432382576	31291	Economy	3300.00
0005432382606	31291	Economy	3300.00
0005433449793	31291	Economy	3300.00
0005433449784	31291	Economy	3300.00
0005432382671	31291	Economy	3300.00
0005433449701	31291	Economy	3300.00
0005432382526	31291	Economy	3300.00
0005432382588	31291	Economy	3300.00
0005433449711	31291	Economy	3300.00
0005432382682	31291	Economy	3300.00
0005432382615	31291	Economy	3300.00
0005433451601	31291	Economy	3300.00
0005432382652	31291	Economy	3300.00
0005433449704	31291	Economy	3300.00
0005433449749	31291	Economy	3300.00
0005433449710	31291	Economy	3300.00
0005432382748	31291	Economy	3300.00
0005433449848	31291	Economy	3300.00
0005433449650	31291	Economy	3300.00
0005432382621	31291	Economy	3300.00
0005432382649	31291	Economy	3300.00
0005432382577	31291	Economy	3300.00
0005432382589	31291	Economy	3300.00
0005433449783	31291	Economy	3300.00
0005433449806	31291	Economy	3300.00
0005433449712	31291	Economy	3300.00
0005432382688	31291	Economy	3300.00
0005433449709	31291	Economy	3300.00
0005432382677	31291	Economy	3300.00
0005432382687	31291	Economy	3300.00
0005432382611	31291	Economy	3300.00
0005435548426	20810	Economy	26200.00
0005435548443	20810	Economy	26200.00
0005435548447	20810	Economy	26200.00
0005435548446	20810	Economy	23800.00
0005433788205	20810	Economy	23800.00
0005433788201	20810	Economy	23800.00
0005433788194	20810	Economy	23800.00
0005435548419	20810	Economy	23800.00
0005433788190	20810	Economy	23800.00
0005433788197	20810	Economy	23800.00
0005435548432	20810	Economy	23800.00
0005433788196	20810	Economy	23800.00
0005435548441	20810	Economy	23800.00
0005435548442	20810	Economy	23800.00
0005435548445	20810	Economy	23800.00
0005435548425	20810	Economy	23800.00
0005435548424	20810	Economy	23800.00
0005433788204	20810	Economy	23800.00
0005435548420	20810	Economy	23800.00
0005433788193	20810	Economy	23800.00
0005433788200	20810	Economy	23800.00
0005435548430	20810	Economy	23800.00
0005435548418	20810	Economy	23800.00
0005433788191	20810	Economy	23800.00
0005433788192	20810	Economy	23800.00
0005435548438	20810	Economy	23800.00
0005433788202	20810	Economy	23800.00
0005435548417	20810	Economy	23800.00
0005433788198	20810	Economy	23800.00
0005433788203	20810	Economy	23800.00
0005435548421	20810	Economy	23800.00
0005435548431	20810	Economy	23800.00
0005435548437	20810	Economy	23800.00
0005433788199	20810	Economy	23800.00
0005435548429	20810	Economy	23800.00
0005435548439	20810	Economy	23800.00
0005433788195	20810	Economy	23800.00
0005433788168	26474	Economy	26200.00
0005435548485	26474	Economy	23800.00
0005435548492	26474	Economy	23800.00
0005433788174	26474	Economy	23800.00
0005435548490	26474	Economy	23800.00
0005435548488	26474	Economy	23800.00
0005435548489	26474	Economy	23800.00
0005435548484	26474	Economy	23800.00
0005433788172	26474	Economy	23800.00
0005433788149	26474	Economy	23800.00
0005433788151	26474	Economy	23800.00
0005433788140	26474	Economy	23800.00
0005433788160	26474	Economy	23800.00
0005433788167	26474	Economy	23800.00
0005433788157	26474	Economy	23800.00
0005433788175	26474	Economy	23800.00
0005435548486	26474	Economy	23800.00
0005435548493	26474	Economy	23800.00
0005435548487	26474	Economy	23800.00
0005433788177	26474	Economy	23800.00
0005433788152	26474	Economy	23800.00
0005433788150	26474	Economy	23800.00
0005435548491	26474	Economy	23800.00
0005433788165	26474	Economy	23800.00
0005433788159	26474	Economy	23800.00
0005433788153	26474	Economy	23800.00
0005435548495	26474	Economy	23800.00
0005435548494	26474	Economy	23800.00
0005433131657	10781	Economy	17100.00
0005435299743	10781	Economy	17100.00
0005433131654	10781	Economy	15600.00
0005433131652	10781	Economy	15600.00
0005433131683	10781	Economy	15600.00
0005435304136	10781	Economy	15600.00
0005433126794	10781	Economy	15600.00
0005435299730	10781	Economy	15600.00
0005435304104	10781	Economy	15600.00
0005435304135	10781	Economy	15600.00
0005433131667	10781	Economy	15600.00
0005433131681	10781	Economy	15600.00
0005433131682	10781	Economy	15600.00
0005435299720	10781	Economy	15600.00
0005435299750	10781	Economy	15600.00
0005435299716	10781	Economy	15600.00
0005435299717	10781	Economy	15600.00
0005433131651	10781	Economy	15600.00
0005433126846	29690	Economy	17100.00
0005433129277	29690	Economy	17100.00
0005435299777	29690	Economy	17100.00
0005433126843	29690	Economy	15600.00
0005433129274	29690	Economy	15600.00
0005433126842	29690	Economy	15600.00
0005435302199	29690	Economy	15600.00
0005435302196	29690	Economy	15600.00
0005435299774	29690	Economy	15600.00
0005435302195	29690	Economy	15600.00
0005435302200	29690	Economy	15600.00
0005433126847	29690	Economy	15600.00
0005433129275	29690	Economy	15600.00
0005435302197	29690	Economy	15600.00
0005435302201	29690	Economy	15600.00
0005435299776	29690	Economy	15600.00
0005435299775	29690	Economy	15600.00
0005433129273	29690	Economy	15600.00
0005433126844	29690	Economy	15600.00
0005435302198	29690	Economy	15600.00
0005433129276	29690	Economy	15600.00
0005433126845	29690	Economy	15600.00
0005433109932	2429	Economy	17200.00
0005434287269	2429	Economy	17200.00
0005433109924	2429	Economy	17200.00
0005434287270	2429	Economy	15700.00
0005433109925	2429	Economy	15700.00
0005433109914	2429	Economy	15700.00
0005434287268	2429	Economy	15700.00
0005434287276	2429	Economy	15700.00
0005434287277	2429	Economy	15700.00
0005433109982	2429	Economy	15700.00
0005433109935	2429	Economy	15700.00
0005434287258	2429	Economy	15700.00
0005433109948	2429	Economy	15700.00
0005433109943	2429	Economy	15700.00
0005433109942	2429	Economy	15700.00
0005432264474	2429	Economy	15700.00
0005434287272	2429	Economy	15700.00
0005433109979	2429	Economy	15700.00
0005434287273	2429	Economy	15700.00
0005433109983	2429	Economy	15700.00
0005434287264	2429	Economy	15700.00
0005433109955	2429	Economy	15700.00
0005434287275	2429	Economy	15700.00
0005433109966	2429	Economy	15700.00
0005434287257	2429	Economy	15700.00
0005433109950	2429	Economy	15700.00
0005433109909	2429	Economy	15700.00
0005433109939	2429	Economy	15700.00
0005434287261	2429	Economy	15700.00
0005434287266	2429	Economy	15700.00
0005434287267	2429	Economy	15700.00
0005434287260	2429	Economy	15700.00
0005434287256	2429	Economy	15700.00
0005434287274	2429	Economy	15700.00
0005433109947	2429	Economy	15700.00
0005432264473	2429	Economy	15700.00
0005433109915	2429	Economy	15700.00
0005434287259	2429	Economy	15700.00
0005434287271	2429	Economy	15700.00
0005434287265	2429	Economy	15700.00
0005433109949	2429	Economy	15700.00
0005433109954	2429	Economy	15700.00
0005432264472	2429	Economy	15700.00
0005433109940	2429	Economy	15700.00
0005434287262	2429	Economy	15700.00
0005434287278	2429	Economy	15700.00
0005434287263	2429	Economy	15700.00
0005434287093	26872	Economy	17200.00
0005434287063	26872	Economy	15700.00
0005434287123	26872	Economy	15700.00
0005434287022	26872	Economy	15700.00
0005433110036	26872	Economy	15700.00
0005434287077	26872	Economy	15700.00
0005434287165	26872	Economy	15700.00
0005434287128	26872	Economy	15700.00
0005434287099	26872	Economy	15700.00
0005434287101	26872	Economy	15700.00
0005433110047	26872	Economy	15700.00
0005433110042	26872	Economy	15700.00
0005433110038	26872	Economy	15700.00
0005434287118	26872	Economy	15700.00
0005434287000	26872	Economy	15700.00
0005433110037	26872	Economy	15700.00
0005434287071	26872	Economy	15700.00
0005434287076	26872	Economy	15700.00
0005434287028	26872	Economy	15700.00
0005433110044	26872	Economy	15700.00
0005433110039	26872	Economy	15700.00
0005434286999	26872	Economy	15700.00
0005434287085	26872	Economy	15700.00
0005433110043	26872	Economy	15700.00
0005433110040	26872	Economy	15700.00
0005434287106	26872	Economy	15700.00
0005434287150	26872	Economy	15700.00
0005433110035	26872	Economy	15700.00
0005434287047	26872	Economy	15700.00
0005433110045	26872	Economy	15700.00
0005434287129	26872	Economy	15700.00
0005433110046	26872	Economy	15700.00
0005434287117	26872	Economy	15700.00
0005433110041	26872	Economy	15700.00
0005435856200	25454	Economy	25000.00
0005435856201	25454	Economy	25000.00
0005435856203	25454	Economy	22800.00
0005435856199	25454	Economy	22800.00
0005435856198	25454	Economy	22800.00
0005434269075	25454	Economy	22800.00
0005435856202	25454	Economy	22800.00
0005434269074	25454	Economy	22800.00
0005434269076	25454	Economy	22800.00
0005435856160	26637	Economy	25000.00
0005435856132	26637	Economy	22800.00
0005435856156	26637	Economy	22800.00
0005435856135	26637	Economy	22800.00
0005435856164	26637	Economy	22800.00
0005435856163	26637	Economy	22800.00
0005435856165	26637	Economy	22800.00
0005435854047	26637	Economy	22800.00
0005435856168	26637	Economy	22800.00
0005435856157	26637	Economy	22800.00
0005435856155	26637	Economy	22800.00
0005435856149	26637	Economy	22800.00
0005434520258	6105	Economy	24600.00
0005434520251	6105	Economy	24600.00
0005434520255	6105	Economy	24600.00
0005434520248	6105	Economy	22300.00
0005434520249	6105	Economy	22300.00
0005434520256	6105	Economy	22300.00
0005434520252	6105	Economy	22300.00
0005434520257	6105	Economy	22300.00
0005434520247	6105	Economy	22300.00
0005435314795	6105	Economy	22300.00
0005434520269	6105	Economy	22300.00
0005435314797	6105	Economy	22300.00
0005435314796	6105	Economy	22300.00
0005434520245	6105	Economy	22300.00
0005434520268	6105	Economy	22300.00
0005434520250	6105	Economy	22300.00
0005435314790	6105	Economy	22300.00
0005434520263	6105	Economy	22300.00
0005435314793	6105	Economy	22300.00
0005434520246	6105	Economy	22300.00
0005434520262	6105	Economy	22300.00
0005435314778	6105	Economy	22300.00
0005434520254	6105	Economy	22300.00
0005435314799	6105	Economy	22300.00
0005434520264	6105	Economy	22300.00
0005434520266	6105	Economy	22300.00
0005434520259	6105	Economy	22300.00
0005434520265	6105	Economy	22300.00
0005434520261	6105	Economy	22300.00
0005435314798	6105	Economy	22300.00
0005435314791	6105	Economy	22300.00
0005434520260	6105	Economy	22300.00
0005435314771	6105	Economy	22300.00
0005435314794	6105	Economy	22300.00
0005434520267	6105	Economy	22300.00
0005434520253	6105	Economy	22300.00
0005433650603	7156	Business	89800.00
0005435263523	7156	Business	89800.00
0005435263512	7156	Business	89800.00
0005435263552	7156	Business	89800.00
0005435263535	7156	Business	89800.00
0005433650624	7156	Business	89800.00
0005433650595	7156	Business	89800.00
0005433650592	7156	Business	89800.00
0005433650628	7156	Business	89800.00
0005435263543	7156	Business	89800.00
0005433650584	7156	Business	89800.00
0005435263561	7156	Business	89800.00
0005433650629	7156	Economy	29900.00
0005435263494	7156	Economy	29900.00
0005435263560	7156	Economy	29900.00
0005433650611	7156	Economy	29900.00
0005433650637	7156	Economy	29900.00
0005433650600	7156	Economy	29900.00
0005435263521	7156	Economy	29900.00
0005433650635	7156	Economy	29900.00
0005433650593	7156	Economy	29900.00
0005433650618	7156	Economy	29900.00
0005433650587	7156	Economy	32900.00
0005433650636	7156	Economy	32900.00
0005433650631	7156	Economy	32900.00
0005435263532	7156	Economy	32900.00
0005435263555	7156	Economy	32900.00
0005433650589	7156	Economy	29900.00
0005433650634	7156	Economy	29900.00
0005433650621	7156	Economy	29900.00
0005433650633	7156	Economy	29900.00
0005435263506	7156	Economy	29900.00
0005435263556	7156	Economy	29900.00
0005435263519	7156	Economy	29900.00
0005433650602	7156	Economy	29900.00
0005433650616	7156	Economy	29900.00
0005435263509	7156	Economy	29900.00
0005433650594	7156	Economy	29900.00
0005433650630	7156	Economy	29900.00
0005433650604	7156	Economy	29900.00
0005433650577	7156	Economy	29900.00
0005433650578	7156	Economy	29900.00
0005433650627	7156	Economy	29900.00
0005433650613	7156	Economy	29900.00
0005435263559	7156	Economy	29900.00
0005435263524	7156	Economy	29900.00
0005433650625	7156	Economy	29900.00
0005433650609	7156	Economy	29900.00
0005433650612	7156	Economy	29900.00
0005435263493	7156	Economy	29900.00
0005433650614	7156	Economy	29900.00
0005433650606	7156	Economy	29900.00
0005433650598	7156	Economy	29900.00
0005435263510	7156	Economy	29900.00
0005435263508	7156	Economy	29900.00
0005433650576	7156	Economy	29900.00
0005433650581	7156	Economy	29900.00
0005433650590	7156	Economy	29900.00
0005435263544	7156	Economy	29900.00
0005435263518	7156	Economy	29900.00
0005433650619	7156	Economy	29900.00
0005433650626	7156	Economy	29900.00
0005435263533	7156	Economy	29900.00
0005435263557	7156	Economy	29900.00
0005435263520	7156	Economy	29900.00
0005433650638	7156	Economy	29900.00
0005433650596	7156	Economy	29900.00
0005433650585	7156	Economy	29900.00
0005433650615	7156	Economy	29900.00
0005433650620	7156	Economy	29900.00
0005433650608	7156	Economy	29900.00
0005435263526	7156	Economy	29900.00
0005435263515	7156	Economy	29900.00
0005433650591	7156	Economy	29900.00
0005435263498	7156	Economy	29900.00
0005435263537	7156	Economy	29900.00
0005433650601	7156	Economy	29900.00
0005433650582	7156	Economy	29900.00
0005433650610	7156	Economy	29900.00
0005433650607	7156	Economy	29900.00
0005433650597	7156	Economy	29900.00
0005433650617	7156	Economy	29900.00
0005433650580	7156	Economy	29900.00
0005433650599	7156	Economy	29900.00
0005435263505	7156	Economy	29900.00
0005433650623	7156	Economy	29900.00
0005433650583	7156	Economy	29900.00
0005435263525	7156	Economy	29900.00
0005433650622	7156	Economy	29900.00
0005433650588	7156	Economy	29900.00
0005433650586	7156	Economy	29900.00
0005433650605	7156	Economy	29900.00
0005435263522	7156	Economy	29900.00
0005433650632	7156	Economy	29900.00
0005433650579	7156	Economy	29900.00
0005433650468	27624	Business	89800.00
0005435263616	27624	Business	89800.00
0005435263607	27624	Business	89800.00
0005433650489	27624	Business	89800.00
0005433650502	27624	Business	89800.00
0005435263606	27624	Business	89800.00
0005435263615	27624	Business	89800.00
0005433650409	27624	Business	89800.00
0005433650507	27624	Business	89800.00
0005433650433	27624	Business	89800.00
0005433650456	27624	Business	89800.00
0005433650444	27624	Economy	29900.00
0005433650443	27624	Economy	29900.00
0005433650508	27624	Economy	29900.00
0005433650462	27624	Economy	29900.00
0005433650469	27624	Economy	29900.00
0005435263604	27624	Economy	32900.00
0005433650455	27624	Economy	32900.00
0005433650524	27624	Economy	32900.00
0005435263614	27624	Economy	32900.00
0005433650503	27624	Economy	32900.00
0005433650500	27624	Economy	29900.00
0005433650461	27624	Economy	29900.00
0005433650511	27624	Economy	29900.00
0005435263611	27624	Economy	29900.00
0005433650465	27624	Economy	29900.00
0005435263601	27624	Economy	29900.00
0005433650499	27624	Economy	29900.00
0005435263613	27624	Economy	29900.00
0005433650519	27624	Economy	29900.00
0005433650522	27624	Economy	29900.00
0005433650467	27624	Economy	29900.00
0005433650506	27624	Economy	29900.00
0005433650515	27624	Economy	29900.00
0005435263599	27624	Economy	29900.00
0005433650450	27624	Economy	29900.00
0005435263605	27624	Economy	29900.00
0005433650483	27624	Economy	29900.00
0005433650406	27624	Economy	29900.00
0005433650466	27624	Economy	29900.00
0005433650520	27624	Economy	29900.00
0005433650442	27624	Economy	29900.00
0005433650422	27624	Economy	29900.00
0005433650513	27624	Economy	29900.00
0005433650478	27624	Economy	29900.00
0005433650416	27624	Economy	29900.00
0005435263608	27624	Economy	29900.00
0005433650415	27624	Economy	29900.00
0005435263597	27624	Economy	29900.00
0005433650501	27624	Economy	29900.00
0005433650430	27624	Economy	29900.00
0005435263610	27624	Economy	29900.00
0005435263603	27624	Economy	29900.00
0005433650521	27624	Economy	29900.00
0005433650453	27624	Economy	29900.00
0005433650428	27624	Economy	29900.00
0005435263602	27624	Economy	29900.00
0005433650485	27624	Economy	29900.00
0005433650446	27624	Economy	29900.00
0005435263612	27624	Economy	29900.00
0005435263598	27624	Economy	29900.00
0005433650493	27624	Economy	29900.00
0005433650509	27624	Economy	29900.00
0005433650435	27624	Economy	29900.00
0005433650441	27624	Economy	29900.00
0005433650514	27624	Economy	29900.00
0005433650464	27624	Economy	29900.00
0005435263596	27624	Economy	29900.00
0005435263609	27624	Economy	29900.00
0005433650490	27624	Economy	29900.00
0005435263600	27624	Economy	29900.00
0005433650445	27624	Economy	29900.00
0005433868408	4792	Economy	19400.00
0005433868410	4792	Economy	19400.00
0005433868389	4792	Economy	19400.00
0005433868415	4792	Economy	19400.00
0005435860437	4792	Economy	17600.00
0005433868425	4792	Economy	17600.00
0005433868399	4792	Economy	17600.00
0005433868390	4792	Economy	17600.00
0005433868392	4792	Economy	17600.00
0005433868388	4792	Economy	17600.00
0005433868397	4792	Economy	17600.00
0005433868406	4792	Economy	17600.00
0005433868422	4792	Economy	17600.00
0005433868401	4792	Economy	17600.00
0005433868407	4792	Economy	17600.00
0005433868427	4792	Economy	17600.00
0005433868391	4792	Economy	17600.00
0005435860445	4792	Economy	17600.00
0005435860436	4792	Economy	17600.00
0005433868402	4792	Economy	17600.00
0005433868396	4792	Economy	17600.00
0005433868430	4792	Economy	17600.00
0005433868417	4792	Economy	17600.00
0005433868412	4792	Economy	17600.00
0005433868420	4792	Economy	17600.00
0005433868428	4792	Economy	17600.00
0005433868411	4792	Economy	17600.00
0005433868413	4792	Economy	17600.00
0005435860439	4792	Economy	17600.00
0005433868404	4792	Economy	17600.00
0005433868405	4792	Economy	17600.00
0005433868426	4792	Economy	17600.00
0005433868398	4792	Economy	17600.00
0005433868409	4792	Economy	17600.00
0005435860434	4792	Economy	17600.00
0005433868414	4792	Economy	17600.00
0005433868424	4792	Economy	17600.00
0005435860435	4792	Economy	17600.00
0005433868423	4792	Economy	17600.00
0005433868403	4792	Economy	17600.00
0005433868429	4792	Economy	17600.00
0005433868419	4792	Economy	17600.00
0005433868416	4792	Economy	17600.00
0005433868395	4792	Economy	17600.00
0005433868421	4792	Economy	17600.00
0005433868393	4792	Economy	17600.00
0005433868400	4792	Economy	17600.00
0005433868394	4792	Economy	17600.00
0005433868418	4792	Economy	17600.00
0005433868058	32570	Economy	19400.00
0005433868083	32570	Economy	19400.00
0005433868050	32570	Economy	19400.00
0005433867827	32570	Economy	17600.00
0005433867968	32570	Economy	17600.00
0005433868051	32570	Economy	17600.00
0005433868015	32570	Economy	17600.00
0005433867952	32570	Economy	17600.00
0005433867985	32570	Economy	17600.00
0005433867973	32570	Economy	17600.00
0005433868052	32570	Economy	17600.00
0005435860490	32570	Economy	17600.00
0005433867890	32570	Economy	17600.00
0005433868017	32570	Economy	17600.00
0005433868084	32570	Economy	17600.00
0005435860486	32570	Economy	17600.00
0005433867955	32570	Economy	17600.00
0005435860493	32570	Economy	17600.00
0005433868016	32570	Economy	17600.00
0005435860492	32570	Economy	17600.00
0005433868158	32570	Economy	17600.00
0005435860488	32570	Economy	17600.00
0005433868023	32570	Economy	17600.00
0005433868063	32570	Economy	17600.00
0005433867996	32570	Economy	17600.00
0005435860491	32570	Economy	17600.00
0005433867883	32570	Economy	17600.00
0005433868064	32570	Economy	17600.00
0005435860487	32570	Economy	17600.00
0005433868125	32570	Economy	17600.00
0005433868057	32570	Economy	17600.00
0005435860489	32570	Economy	17600.00
0005433868013	32570	Economy	17600.00
0005433868046	32570	Economy	17600.00
0005433868055	32570	Economy	17600.00
0005433868157	32570	Economy	17600.00
0005433868159	32570	Economy	17600.00
0005433867984	32570	Economy	17600.00
0005433868049	32570	Economy	17600.00
0005435911330	3427	Economy	24800.00
0005434663397	3427	Economy	24800.00
0005435911366	3427	Economy	24800.00
0005434663388	3427	Economy	24800.00
0005435911378	3427	Economy	22600.00
0005434461645	3427	Economy	22600.00
0005434663401	3427	Economy	22600.00
0005434663389	3427	Economy	22600.00
0005434663394	3427	Economy	22600.00
0005434460504	3427	Economy	22600.00
0005434663392	3427	Economy	22600.00
0005435911367	3427	Economy	22600.00
0005435911380	3427	Economy	22600.00
0005434663396	3427	Economy	22600.00
0005434663398	3427	Economy	22600.00
0005434663393	3427	Economy	22600.00
0005434663390	3427	Economy	22600.00
0005435911389	3427	Economy	22600.00
0005434663391	3427	Economy	22600.00
0005435911379	3427	Economy	22600.00
0005434663395	3427	Economy	22600.00
0005434663400	3427	Economy	22600.00
0005434663399	3427	Economy	22600.00
0005435911329	3427	Economy	22600.00
0005434663273	12444	Economy	24800.00
0005434663243	12444	Economy	24800.00
0005434663312	12444	Economy	24800.00
0005434663215	12444	Economy	22600.00
0005434663235	12444	Economy	22600.00
0005434663274	12444	Economy	22600.00
0005434663275	12444	Economy	22600.00
0005435911443	12444	Economy	22600.00
0005434663324	12444	Economy	22600.00
0005435911444	12444	Economy	22600.00
0005435911442	12444	Economy	22600.00
0005434663251	12444	Economy	22600.00
0005435911441	12444	Economy	22600.00
0005435911447	12444	Economy	22600.00
0005434663315	12444	Economy	22600.00
0005434663325	12444	Economy	22600.00
0005434663332	12444	Economy	22600.00
0005434663313	12444	Economy	22600.00
0005435911440	12444	Economy	22600.00
0005435911446	12444	Economy	22600.00
0005434663316	12444	Economy	22600.00
0005434663331	12444	Economy	22600.00
0005435911445	12444	Economy	22600.00
0005434663244	12444	Economy	22600.00
0005434663326	12444	Economy	22600.00
0005434663260	12444	Economy	22600.00
0005434663237	12444	Economy	22600.00
0005435860487	14509	Economy	18500.00
0005433868046	14509	Economy	18500.00
0005433867968	14509	Economy	18500.00
0005435860489	14509	Economy	16800.00
0005433868084	14509	Economy	16800.00
0005433868023	14509	Economy	16800.00
0005433867973	14509	Economy	16800.00
0005433868051	14509	Economy	16800.00
0005433868052	14509	Economy	16800.00
0005433867985	14509	Economy	16800.00
0005433867996	14509	Economy	16800.00
0005433868058	14509	Economy	16800.00
0005433867952	14509	Economy	16800.00
0005433868057	14509	Economy	16800.00
0005433868159	14509	Economy	16800.00
0005433868063	14509	Economy	16800.00
0005433868158	14509	Economy	16800.00
0005433867955	14509	Economy	16800.00
0005433868015	14509	Economy	16800.00
0005433868049	14509	Economy	16800.00
0005433868055	14509	Economy	16800.00
0005433868017	14509	Economy	16800.00
0005435860486	14509	Economy	16800.00
0005433867883	14509	Economy	16800.00
0005433868083	14509	Economy	16800.00
0005433868125	14509	Economy	16800.00
0005435860492	14509	Economy	16800.00
0005433868064	14509	Economy	16800.00
0005433868157	14509	Economy	16800.00
0005435860488	14509	Economy	16800.00
0005433868013	14509	Economy	16800.00
0005433868050	14509	Economy	16800.00
0005433867984	14509	Economy	16800.00
0005433868016	14509	Economy	16800.00
0005435860493	14509	Economy	16800.00
0005435860491	14509	Economy	16800.00
0005433867890	14509	Economy	16800.00
0005433867827	14509	Economy	16800.00
0005435860490	14509	Economy	16800.00
0005433868360	32690	Economy	18500.00
0005433868346	32690	Economy	18500.00
0005435860447	32690	Economy	18500.00
0005433868380	32690	Economy	18500.00
0005433868384	32690	Economy	16800.00
0005433868359	32690	Economy	16800.00
0005433868377	32690	Economy	16800.00
0005433868364	32690	Economy	16800.00
0005433868351	32690	Economy	16800.00
0005433868367	32690	Economy	16800.00
0005433868373	32690	Economy	16800.00
0005435860449	32690	Economy	16800.00
0005433868375	32690	Economy	16800.00
0005433868378	32690	Economy	16800.00
0005433868349	32690	Economy	16800.00
0005433868387	32690	Economy	16800.00
0005433868385	32690	Economy	16800.00
0005433868361	32690	Economy	16800.00
0005433868371	32690	Economy	16800.00
0005433868363	32690	Economy	16800.00
0005433868350	32690	Economy	16800.00
0005433868374	32690	Economy	16800.00
0005433868381	32690	Economy	16800.00
0005433868365	32690	Economy	16800.00
0005433868358	32690	Economy	16800.00
0005433868372	32690	Economy	16800.00
0005433868369	32690	Economy	16800.00
0005433868352	32690	Economy	16800.00
0005433868347	32690	Economy	16800.00
0005433868382	32690	Economy	16800.00
0005433868354	32690	Economy	16800.00
0005433868366	32690	Economy	16800.00
0005433868357	32690	Economy	16800.00
0005433868370	32690	Economy	16800.00
0005433868376	32690	Economy	16800.00
0005433868355	32690	Economy	16800.00
0005433868383	32690	Economy	16800.00
0005433868368	32690	Economy	16800.00
0005433868362	32690	Economy	16800.00
0005433868353	32690	Economy	16800.00
0005435860448	32690	Economy	16800.00
0005433868348	32690	Economy	16800.00
0005433868379	32690	Economy	16800.00
0005433868386	32690	Economy	16800.00
0005433868356	32690	Economy	16800.00
0005432799133	12139	Economy	4900.00
0005432799210	12139	Economy	4900.00
0005432799178	12139	Economy	4400.00
0005432799170	12139	Economy	4400.00
0005432799244	12139	Economy	4400.00
0005432799207	12139	Economy	4400.00
0005432799158	12139	Economy	4400.00
0005432799259	12139	Economy	4400.00
0005432799109	12139	Economy	4400.00
0005432799209	12139	Economy	4400.00
0005432799084	12139	Economy	4400.00
0005432799185	12139	Economy	4400.00
0005432799321	12139	Economy	4400.00
0005432799161	12139	Economy	4400.00
0005432799087	12139	Economy	4400.00
0005432799320	12139	Economy	4400.00
0005432799157	12139	Economy	4400.00
0005432799156	12139	Economy	4400.00
0005432799298	12139	Economy	4400.00
0005432799217	12139	Economy	4400.00
0005432799045	12139	Economy	4400.00
0005432799208	12139	Economy	4400.00
0005432799159	12139	Economy	4400.00
0005432799393	14819	Economy	4900.00
0005432799406	14819	Economy	4900.00
0005432799391	14819	Economy	4900.00
0005432799390	14819	Economy	4900.00
0005432799389	14819	Economy	4400.00
0005432799408	14819	Economy	4400.00
0005432799394	14819	Economy	4400.00
0005432799415	14819	Economy	4400.00
0005432799399	14819	Economy	4400.00
0005432799403	14819	Economy	4400.00
0005432799407	14819	Economy	4400.00
0005432799398	14819	Economy	4400.00
0005432799392	14819	Economy	4400.00
0005432799410	14819	Economy	4400.00
0005432799412	14819	Economy	4400.00
0005432799387	14819	Economy	4400.00
0005432799395	14819	Economy	4400.00
0005432799397	14819	Economy	4400.00
0005432799388	14819	Economy	4400.00
0005432799402	14819	Economy	4400.00
0005432799404	14819	Economy	4400.00
0005432799401	14819	Economy	4400.00
0005432799400	14819	Economy	4400.00
0005432799411	14819	Economy	4400.00
0005432799414	14819	Economy	4400.00
0005432799413	14819	Economy	4400.00
0005432799409	14819	Economy	4400.00
0005432799396	14819	Economy	4400.00
0005432799405	14819	Economy	4400.00
0005434407720	7077	Business	49100.00
0005435310931	7077	Business	49100.00
0005432108246	7077	Business	49100.00
0005434299548	7077	Business	49100.00
0005434299533	7077	Business	49100.00
0005434407692	7077	Business	49100.00
0005434407678	7077	Business	49100.00
0005435310891	7077	Business	49100.00
0005434299543	7077	Business	49100.00
0005432108247	7077	Business	49100.00
0005434299541	7077	Business	49100.00
0005434407697	7077	Economy	16400.00
0005434299532	7077	Economy	16400.00
0005434407681	7077	Economy	16400.00
0005434407724	7077	Economy	16400.00
0005434407675	7077	Economy	16400.00
0005434407698	7077	Economy	16400.00
0005434407711	7077	Economy	16400.00
0005434407709	7077	Economy	16400.00
0005434299531	7077	Economy	16400.00
0005434407686	7077	Economy	16400.00
0005435310871	7077	Economy	16400.00
0005435310870	7077	Economy	16400.00
0005434299545	7077	Economy	16400.00
0005434299547	7077	Economy	16400.00
0005434407701	7077	Economy	16400.00
0005434299544	7077	Economy	16400.00
0005435293126	7077	Economy	16400.00
0005434407679	7077	Economy	16400.00
0005432108248	7077	Economy	16400.00
0005434407703	7077	Economy	16400.00
0005434407707	7077	Economy	16400.00
0005435310938	7077	Economy	16400.00
0005432153934	7077	Economy	16400.00
0005435293127	7077	Economy	16400.00
0005434407722	7077	Economy	16400.00
0005434299550	7077	Economy	16400.00
0005434299549	7077	Economy	16400.00
0005434407693	7077	Economy	16400.00
0005434407730	7077	Economy	16400.00
0005434407699	7077	Economy	16400.00
0005434407713	7077	Economy	16400.00
0005432153928	7077	Economy	16400.00
0005432153929	7077	Economy	16400.00
0005434407714	7077	Economy	16400.00
0005434299530	7077	Economy	16400.00
0005434407721	7077	Economy	16400.00
0005434299527	7077	Economy	16400.00
0005434299539	7077	Economy	16400.00
0005435310917	7077	Economy	18000.00
0005432153930	7077	Economy	18000.00
0005432153933	7077	Economy	18000.00
0005434407682	7077	Economy	18000.00
0005434407733	7077	Economy	18000.00
0005434407735	7077	Economy	18000.00
0005434299528	7077	Economy	16400.00
0005434299534	7077	Economy	16400.00
0005434299537	7077	Economy	16400.00
0005434407677	7077	Economy	16400.00
0005434407688	7077	Economy	16400.00
0005434299529	7077	Economy	16400.00
0005434407694	7077	Economy	16400.00
0005435310937	7077	Economy	16400.00
0005434407695	7077	Economy	16400.00
0005435293117	7077	Economy	16400.00
0005434407718	7077	Economy	16400.00
0005434407734	7077	Economy	16400.00
0005434407727	7077	Economy	16400.00
0005434407732	7077	Economy	16400.00
0005434407689	7077	Economy	16400.00
0005434299546	7077	Economy	16400.00
0005435293118	7077	Economy	16400.00
0005435293176	7077	Economy	16400.00
0005434299538	7077	Economy	16400.00
0005434407676	7077	Economy	16400.00
0005435310892	7077	Economy	16400.00
0005434407710	7077	Economy	16400.00
0005434407725	7077	Economy	16400.00
0005434407715	7077	Economy	16400.00
0005434407690	7077	Economy	16400.00
0005435293141	7077	Economy	16400.00
0005434407731	7077	Economy	16400.00
0005434407673	7077	Economy	16400.00
0005434299542	7077	Economy	16400.00
0005434299540	7077	Economy	16400.00
0005434299536	7077	Economy	16400.00
0005434407702	7077	Economy	16400.00
0005434407726	7077	Economy	16400.00
0005434407687	7077	Economy	16400.00
0005434407674	7077	Economy	16400.00
0005434407672	7077	Economy	16400.00
0005435310887	7077	Economy	16400.00
0005432153931	7077	Economy	16400.00
0005435293144	7077	Economy	16400.00
0005434407696	7077	Economy	16400.00
0005434407723	7077	Economy	16400.00
0005435293140	7077	Economy	16400.00
0005435310919	7077	Economy	16400.00
0005434407712	7077	Economy	16400.00
0005434407680	7077	Economy	16400.00
0005434407708	7077	Economy	16400.00
0005434407719	7077	Economy	16400.00
0005434407729	7077	Economy	16400.00
0005434407706	7077	Economy	16400.00
0005434407684	7077	Economy	16400.00
0005434407717	7077	Economy	16400.00
0005432153932	7077	Economy	16400.00
0005434407691	7077	Economy	16400.00
0005434299535	7077	Economy	16400.00
0005434407700	7077	Economy	16400.00
0005434407683	7077	Economy	16400.00
0005434407728	7077	Economy	16400.00
0005435293154	7077	Economy	16400.00
0005434407685	7077	Economy	16400.00
0005434407716	7077	Economy	16400.00
0005434407705	7077	Economy	16400.00
0005434407704	7077	Economy	16400.00
0005435293239	26920	Business	49100.00
0005434407243	26920	Business	49100.00
0005435311049	26920	Business	49100.00
0005434407248	26920	Business	49100.00
0005435311041	26920	Business	49100.00
0005434299391	26920	Business	49100.00
0005434407240	26920	Business	49100.00
0005434299330	26920	Business	49100.00
0005434407114	26920	Business	49100.00
0005434407376	26920	Economy	16400.00
0005435311046	26920	Business	49100.00
0005434407086	26920	Economy	16400.00
0005434299274	26920	Economy	16400.00
0005434299327	26920	Economy	16400.00
0005434407173	26920	Economy	16400.00
0005434299358	26920	Economy	16400.00
0005435293235	26920	Economy	16400.00
0005435311040	26920	Economy	16400.00
0005434406958	26920	Economy	16400.00
0005434299446	26920	Economy	16400.00
0005434299234	26920	Economy	16400.00
0005434406918	26920	Economy	16400.00
0005432058373	26920	Economy	16400.00
0005435311039	26920	Economy	16400.00
0005435311042	26920	Economy	16400.00
0005435293237	26920	Economy	16400.00
0005435311038	26920	Economy	16400.00
0005432058374	26920	Economy	16400.00
0005434407036	26920	Economy	16400.00
0005434406962	26920	Economy	16400.00
0005434407151	26920	Economy	16400.00
0005434299414	26920	Economy	16400.00
0005434299453	26920	Economy	16400.00
0005434406919	26920	Economy	16400.00
0005434407174	26920	Economy	16400.00
0005434407216	26920	Economy	16400.00
0005435311044	26920	Economy	16400.00
0005434407249	26920	Economy	16400.00
0005434407337	26920	Economy	16400.00
0005434407136	26920	Economy	16400.00
0005434407099	26920	Economy	16400.00
0005434407152	26920	Economy	16400.00
0005434406908	26920	Economy	16400.00
0005435293244	26920	Economy	16400.00
0005434407225	26920	Economy	16400.00
0005435293241	26920	Economy	16400.00
0005434299415	26920	Economy	16400.00
0005434406998	26920	Economy	16400.00
0005434406933	26920	Economy	18000.00
0005434407026	26920	Economy	18000.00
0005434407122	26920	Economy	18000.00
0005435293246	26920	Economy	18000.00
0005434406991	26920	Economy	18000.00
0005434299439	26920	Economy	18000.00
0005434407344	26920	Economy	16400.00
0005434406961	26920	Economy	16400.00
0005434406795	26920	Economy	16400.00
0005434407081	26920	Economy	16400.00
0005435293236	26920	Economy	16400.00
0005434407126	26920	Economy	16400.00
0005434299317	26920	Economy	16400.00
0005434299357	26920	Economy	16400.00
0005434407223	26920	Economy	16400.00
0005434406796	26920	Economy	16400.00
0005434407029	26920	Economy	16400.00
0005435293242	26920	Economy	16400.00
0005434407154	26920	Economy	16400.00
0005434299392	26920	Economy	16400.00
0005434299360	26920	Economy	16400.00
0005435311048	26920	Economy	16400.00
0005434299377	26920	Economy	16400.00
0005434299332	26920	Economy	16400.00
0005434406952	26920	Economy	16400.00
0005434407007	26920	Economy	16400.00
0005434299238	26920	Economy	16400.00
0005434406951	26920	Economy	16400.00
0005435311050	26920	Economy	16400.00
0005434299346	26920	Economy	16400.00
0005435293238	26920	Economy	16400.00
0005434407097	26920	Economy	16400.00
0005434407226	26920	Economy	16400.00
0005434299445	26920	Economy	16400.00
0005435311047	26920	Economy	16400.00
0005434299347	26920	Economy	16400.00
0005434407063	26920	Economy	16400.00
0005434299421	26920	Economy	16400.00
0005434406969	26920	Economy	16400.00
0005434407037	26920	Economy	16400.00
0005434407055	26920	Economy	16400.00
0005434299275	26920	Economy	16400.00
0005435311043	26920	Economy	16400.00
0005435311045	26920	Economy	16400.00
0005434407113	26920	Economy	16400.00
0005435311051	26920	Economy	16400.00
0005434407224	26920	Economy	16400.00
0005434407150	26920	Economy	16400.00
0005434299237	26920	Economy	16400.00
0005434407153	26920	Economy	16400.00
0005434406960	26920	Economy	16400.00
0005435293240	26920	Economy	16400.00
0005434299454	26920	Economy	16400.00
0005434407054	26920	Economy	16400.00
0005434407089	26920	Economy	16400.00
0005434407115	26920	Economy	16400.00
0005434406999	26920	Economy	16400.00
0005434407011	26920	Economy	16400.00
0005434407242	26920	Economy	16400.00
0005434407135	26920	Economy	16400.00
0005435311037	26920	Economy	16400.00
0005434406827	26920	Economy	16400.00
0005435311036	26920	Economy	16400.00
0005434407090	26920	Economy	16400.00
0005432058372	26920	Economy	16400.00
0005434407100	26920	Economy	16400.00
0005434299345	26920	Economy	16400.00
0005434407296	26920	Economy	16400.00
0005434299310	26920	Economy	16400.00
0005432058375	26920	Economy	16400.00
0005434407000	26920	Economy	16400.00
0005434407247	26920	Economy	16400.00
0005434299311	26920	Economy	16400.00
0005435293243	26920	Economy	16400.00
0005434299359	26920	Economy	16400.00
0005435293245	26920	Economy	16400.00
0005432604302	6442	Economy	16500.00
0005432604329	6442	Economy	16500.00
0005432604312	6442	Economy	16500.00
0005432604292	6442	Economy	16500.00
0005432604301	6442	Economy	15000.00
0005432604297	6442	Economy	15000.00
0005432604320	6442	Economy	15000.00
0005432604294	6442	Economy	15000.00
0005432604315	6442	Economy	15000.00
0005432604309	6442	Economy	15000.00
0005432604317	6442	Economy	15000.00
0005432604322	6442	Economy	15000.00
0005432604304	6442	Economy	15000.00
0005432604328	6442	Economy	15000.00
0005432604325	6442	Economy	15000.00
0005432604330	6442	Economy	15000.00
0005432604319	6442	Economy	15000.00
0005435218105	6442	Economy	15000.00
0005434512114	6442	Economy	15000.00
0005432604316	6442	Economy	15000.00
0005432604299	6442	Economy	15000.00
0005432604306	6442	Economy	15000.00
0005432604308	6442	Economy	15000.00
0005432604296	6442	Economy	15000.00
0005432604314	6442	Economy	15000.00
0005432604326	6442	Economy	15000.00
0005432604310	6442	Economy	15000.00
0005432604307	6442	Economy	15000.00
0005435218106	6442	Economy	15000.00
0005432604324	6442	Economy	15000.00
0005432604291	6442	Economy	15000.00
0005432604321	6442	Economy	15000.00
0005432604331	6442	Economy	15000.00
0005432604303	6442	Economy	15000.00
0005432604311	6442	Economy	15000.00
0005432604318	6442	Economy	15000.00
0005432604295	6442	Economy	15000.00
0005434512112	6442	Economy	15000.00
0005432604313	6442	Economy	15000.00
0005432604298	6442	Economy	15000.00
0005432604323	6442	Economy	15000.00
0005432604293	6442	Economy	15000.00
0005432604327	6442	Economy	15000.00
0005432604300	6442	Economy	15000.00
0005434512113	6442	Economy	15000.00
0005432604305	6442	Economy	15000.00
0005432603873	21365	Economy	16500.00
0005432604069	21365	Economy	16500.00
0005432603851	21365	Economy	16500.00
0005432603922	21365	Economy	16500.00
0005432603883	21365	Economy	15000.00
0005432603874	21365	Economy	15000.00
0005432603899	21365	Economy	15000.00
0005432603882	21365	Economy	15000.00
0005432603850	21365	Economy	15000.00
0005432603970	21365	Economy	15000.00
0005432604119	21365	Economy	15000.00
0005432603900	21365	Economy	15000.00
0005432603799	21365	Economy	15000.00
0005432603872	21365	Economy	15000.00
0005432603862	21365	Economy	15000.00
0005432603972	21365	Economy	15000.00
0005432604120	21365	Economy	15000.00
0005432603952	21365	Economy	15000.00
0005432603978	21365	Economy	15000.00
0005432603814	21365	Economy	15000.00
0005432603982	21365	Economy	15000.00
0005432603942	21365	Economy	15000.00
0005432603933	21365	Economy	15000.00
0005432603979	21365	Economy	15000.00
0005432603870	21365	Economy	15000.00
0005432603943	21365	Economy	15000.00
0005432603826	21365	Economy	15000.00
0005432604090	21365	Economy	15000.00
0005432603931	21365	Economy	15000.00
0005432603941	21365	Economy	15000.00
0005432603965	21365	Economy	15000.00
0005432603961	21365	Economy	15000.00
0005432603953	21365	Economy	15000.00
0005432603819	21365	Economy	15000.00
0005432603921	21365	Economy	15000.00
0005432604091	21365	Economy	15000.00
0005432603802	21365	Economy	15000.00
0005432603963	21365	Economy	15000.00
0005432603813	21365	Economy	15000.00
0005434512036	21365	Economy	15000.00
0005432603932	21365	Economy	15000.00
0005432603948	21365	Economy	15000.00
0005432603861	21365	Economy	15000.00
0005432603852	21365	Economy	15000.00
0005432604038	21365	Economy	15000.00
0005432603871	21365	Economy	15000.00
0005432603944	21365	Economy	15000.00
0005432603964	21365	Economy	15000.00
0005433251439	14990	Business	18900.00
0005434906706	14990	Business	18900.00
0005434906782	14990	Business	18900.00
0005434906785	14990	Business	18900.00
0005434906696	14990	Business	18900.00
0005434906479	14990	Business	18900.00
0005434906613	14990	Business	18900.00
0005433251456	14990	Business	18900.00
0005434906709	14990	Business	18900.00
0005434906705	14990	Economy	6300.00
0005434906738	14990	Economy	6300.00
0005434906730	14990	Economy	6300.00
0005433251444	14990	Economy	6300.00
0005433251443	14990	Economy	6300.00
0005434906775	14990	Economy	6300.00
0005433251433	14990	Economy	6300.00
0005434906653	14990	Economy	6300.00
0005434906663	14990	Economy	6300.00
0005433251440	14990	Economy	6300.00
0005433251464	14990	Economy	6900.00
0005434906749	14990	Economy	6900.00
0005433251452	14990	Economy	6900.00
0005434906378	14990	Economy	6900.00
0005434906771	14990	Economy	6900.00
0005434906777	14990	Economy	6300.00
0005433251454	14990	Economy	6300.00
0005434906586	14990	Economy	6300.00
0005434906736	14990	Economy	6300.00
0005434906544	14990	Economy	6300.00
0005433251450	14990	Economy	6300.00
0005434906698	14990	Economy	6300.00
0005434906542	14990	Economy	6300.00
0005434906767	14990	Economy	6300.00
0005434906776	14990	Economy	6300.00
0005434906674	14990	Economy	6300.00
0005433251455	14990	Economy	6300.00
0005433251460	14990	Economy	6300.00
0005434906707	14990	Economy	6300.00
0005434906541	14990	Economy	6300.00
0005433251458	14990	Economy	6300.00
0005434906748	14990	Economy	6300.00
0005434906597	14990	Economy	6300.00
0005434906478	14990	Economy	6300.00
0005433251453	14990	Economy	6300.00
0005434906673	14990	Economy	6300.00
0005433251459	14990	Economy	6300.00
0005434906583	14990	Economy	6300.00
0005434906798	14990	Economy	6300.00
0005434906741	14990	Economy	6300.00
0005433251446	14990	Economy	6300.00
0005434906508	14990	Economy	6300.00
0005433251434	14990	Economy	6300.00
0005434906766	14990	Economy	6300.00
0005433251441	14990	Economy	6300.00
0005433251461	14990	Economy	6300.00
0005434906599	14990	Economy	6300.00
0005434906530	14990	Economy	6300.00
0005433251457	14990	Economy	6300.00
0005433251451	14990	Economy	6300.00
0005433251445	14990	Economy	6300.00
0005434906577	14990	Economy	6300.00
0005434906654	14990	Economy	6300.00
0005433251435	14990	Economy	6300.00
0005433251462	14990	Economy	6300.00
0005434906773	14990	Economy	6300.00
0005434906740	14990	Economy	6300.00
0005433251448	14990	Economy	6300.00
0005433251438	14990	Economy	6300.00
0005433251442	14990	Economy	6300.00
0005434906708	14990	Economy	6300.00
0005434906754	14990	Economy	6300.00
0005433251449	14990	Economy	6300.00
0005434906535	14990	Economy	6300.00
0005434906675	14990	Economy	6300.00
0005434906576	14990	Economy	6300.00
0005434906598	14990	Economy	6300.00
0005433251436	14990	Economy	6300.00
0005433251437	14990	Economy	6300.00
0005434906573	14990	Economy	6300.00
0005433251463	14990	Economy	6300.00
0005434906792	14990	Economy	6300.00
0005434906768	14990	Economy	6300.00
0005434906739	14990	Economy	6300.00
0005434906624	14990	Economy	6300.00
0005434906470	14990	Economy	6300.00
0005433251447	14990	Economy	6300.00
0005434906582	14990	Economy	6300.00
0005434906732	14990	Economy	6300.00
0005434907183	25852	Business	18900.00
0005434907171	25852	Business	18900.00
0005433251119	25852	Business	18900.00
0005434907177	25852	Business	18900.00
0005433251136	25852	Business	18900.00
0005434907211	25852	Business	18900.00
0005433251188	25852	Business	18900.00
0005434907175	25852	Business	18900.00
0005433251159	25852	Business	18900.00
0005433251231	25852	Business	18900.00
0005433251110	25852	Business	18900.00
0005434907187	25852	Business	18900.00
0005434907181	25852	Economy	6300.00
0005434907170	25852	Economy	6300.00
0005434907168	25852	Economy	6300.00
0005433251084	25852	Economy	6300.00
0005434907179	25852	Economy	6300.00
0005434907195	25852	Economy	6300.00
0005433251223	25852	Economy	6300.00
0005434907207	25852	Economy	6300.00
0005434907201	25852	Economy	6900.00
0005434907178	25852	Economy	6900.00
0005433251022	25852	Economy	6900.00
0005434907174	25852	Economy	6900.00
0005433251194	25852	Economy	6900.00
0005433251122	25852	Economy	6300.00
0005434907193	25852	Economy	6300.00
0005434907198	25852	Economy	6300.00
0005434907190	25852	Economy	6300.00
0005434907167	25852	Economy	6300.00
0005434907197	25852	Economy	6300.00
0005434907208	25852	Economy	6300.00
0005434907180	25852	Economy	6300.00
0005434907188	25852	Economy	6300.00
0005434907196	25852	Economy	6300.00
0005433251291	25852	Economy	6300.00
0005434907206	25852	Economy	6300.00
0005434907212	25852	Economy	6300.00
0005434907189	25852	Economy	6300.00
0005433251242	25852	Economy	6300.00
0005433251111	25852	Economy	6300.00
0005434907163	25852	Economy	6300.00
0005434907186	25852	Economy	6300.00
0005434907194	25852	Economy	6300.00
0005434907204	25852	Economy	6300.00
0005434907166	25852	Economy	6300.00
0005434907164	25852	Economy	6300.00
0005433251166	25852	Economy	6300.00
0005434907210	25852	Economy	6300.00
0005433250980	25852	Economy	6300.00
0005434907199	25852	Economy	6300.00
0005433251261	25852	Economy	6300.00
0005434907182	25852	Economy	6300.00
0005434907185	25852	Economy	6300.00
0005434907192	25852	Economy	6300.00
0005433251224	25852	Economy	6300.00
0005434907162	25852	Economy	6300.00
0005434907165	25852	Economy	6300.00
0005434907200	25852	Economy	6300.00
0005434907203	25852	Economy	6300.00
0005434907169	25852	Economy	6300.00
0005434907202	25852	Economy	6300.00
0005433251135	25852	Economy	6300.00
0005434907161	25852	Economy	6300.00
0005434907191	25852	Economy	6300.00
0005434907213	25852	Economy	6300.00
0005433250981	25852	Economy	6300.00
0005433251167	25852	Economy	6300.00
0005433251257	25852	Economy	6300.00
0005434907176	25852	Economy	6300.00
0005434907173	25852	Economy	6300.00
0005433251262	25852	Economy	6300.00
0005433251212	25852	Economy	6300.00
0005433251232	25852	Economy	6300.00
0005433251118	25852	Economy	6300.00
0005434907205	25852	Economy	6300.00
0005434907172	25852	Economy	6300.00
0005433251187	25852	Economy	6300.00
0005433251271	25852	Economy	6300.00
0005434907209	25852	Economy	6300.00
0005433251200	25852	Economy	6300.00
0005434907184	25852	Economy	6300.00
0005433251139	25852	Economy	6300.00
0005433251189	25852	Economy	6300.00
0005433810505	14174	Business	52300.00
0005433008583	14174	Business	52300.00
0005433810499	14174	Business	52300.00
0005433008581	14174	Business	52300.00
0005433008589	14174	Business	52300.00
0005433008595	14174	Business	52300.00
0005433008592	14174	Business	52300.00
0005433008608	14174	Business	52300.00
0005433008600	14174	Business	52300.00
0005433810502	14174	Economy	17400.00
0005433008579	14174	Economy	17400.00
0005433008584	14174	Economy	17400.00
0005433810500	14174	Economy	17400.00
0005433008610	14174	Economy	17400.00
0005433008593	14174	Economy	19200.00
0005433008590	14174	Economy	19200.00
0005433008582	14174	Economy	19200.00
0005433008599	14174	Economy	17400.00
0005433008603	14174	Economy	17400.00
0005433008575	14174	Economy	17400.00
0005433008568	14174	Economy	17400.00
0005433008571	14174	Economy	17400.00
0005433008570	14174	Economy	17400.00
0005433008564	14174	Economy	17400.00
0005433810504	14174	Economy	17400.00
0005433810501	14174	Economy	17400.00
0005433008588	14174	Economy	17400.00
0005433008577	14174	Economy	17400.00
0005433008594	14174	Economy	17400.00
0005433008605	14174	Economy	17400.00
0005433008573	14174	Economy	17400.00
0005433008574	14174	Economy	17400.00
0005433008602	14174	Economy	17400.00
0005433008597	14174	Economy	17400.00
0005433008604	14174	Economy	17400.00
0005433008606	14174	Economy	17400.00
0005433008585	14174	Economy	17400.00
0005433008607	14174	Economy	17400.00
0005433008567	14174	Economy	17400.00
0005433008586	14174	Economy	17400.00
0005433008609	14174	Economy	17400.00
0005433008578	14174	Economy	17400.00
0005433008591	14174	Economy	17400.00
0005433008565	14174	Economy	17400.00
0005433008569	14174	Economy	17400.00
0005433008598	14174	Economy	17400.00
0005433008587	14174	Economy	17400.00
0005433008572	14174	Economy	17400.00
0005433008580	14174	Economy	17400.00
0005433008601	14174	Economy	17400.00
0005433810496	14174	Economy	17400.00
0005433008596	14174	Economy	17400.00
0005433008566	14174	Economy	17400.00
0005433008576	14174	Economy	17400.00
0005433008110	22826	Business	52300.00
0005433008258	22826	Business	52300.00
0005433008209	22826	Business	52300.00
0005433007961	22826	Economy	17400.00
0005433008182	22826	Economy	17400.00
0005433008170	22826	Economy	17400.00
0005433008168	22826	Economy	17400.00
0005433008235	22826	Economy	17400.00
0005433008185	22826	Economy	19200.00
0005433810535	22826	Economy	19200.00
0005433008126	22826	Economy	17400.00
0005433008108	22826	Economy	17400.00
0005433008125	22826	Economy	17400.00
0005433008025	22826	Economy	17400.00
0005433810536	22826	Economy	17400.00
0005433008061	22826	Economy	17400.00
0005433008128	22826	Economy	17400.00
0005433008274	22826	Economy	17400.00
0005433008359	22826	Economy	17400.00
0005433007962	22826	Economy	17400.00
0005433810537	22826	Economy	17400.00
0005433008230	22826	Economy	17400.00
0005433008226	22826	Economy	17400.00
0005433008227	22826	Economy	17400.00
0005433008169	22826	Economy	17400.00
0005433008259	22826	Economy	17400.00
0005433008225	22826	Economy	17400.00
0005433008240	22826	Economy	17400.00
0005433008039	22826	Economy	17400.00
0005433008229	22826	Economy	17400.00
0005433008060	22826	Economy	17400.00
0005433008228	22826	Economy	17400.00
0005435718837	27116	Business	85200.00
0005435718863	27116	Business	85200.00
0005435718878	27116	Business	85200.00
0005435718843	27116	Business	85200.00
0005435718836	27116	Business	85200.00
0005435718828	27116	Economy	28400.00
0005435718874	27116	Economy	28400.00
0005435718853	27116	Economy	28400.00
0005435718871	27116	Economy	28400.00
0005435718881	27116	Economy	28400.00
0005435718847	27116	Economy	28400.00
0005435718858	27116	Economy	31200.00
0005435718848	27116	Economy	28400.00
0005435718829	27116	Economy	28400.00
0005435718856	27116	Economy	28400.00
0005435718882	27116	Economy	28400.00
0005435718861	27116	Economy	28400.00
0005435718867	27116	Economy	28400.00
0005435718831	27116	Economy	28400.00
0005435718873	27116	Economy	28400.00
0005435718877	27116	Economy	28400.00
0005435718839	27116	Economy	28400.00
0005435718875	27116	Economy	28400.00
0005435718849	27116	Economy	28400.00
0005435718835	27116	Economy	28400.00
0005435718841	27116	Economy	28400.00
0005435718862	27116	Economy	28400.00
0005435718830	27116	Economy	28400.00
0005435718834	27116	Economy	28400.00
0005435718852	27116	Economy	28400.00
0005435718870	27116	Economy	28400.00
0005435718846	27116	Economy	28400.00
0005435718865	27116	Economy	28400.00
0005435718872	27116	Economy	28400.00
0005435718827	27116	Economy	28400.00
0005435718868	27116	Economy	28400.00
0005435718857	27116	Economy	28400.00
0005435718840	27116	Economy	28400.00
0005435718880	27116	Economy	28400.00
0005435718883	27116	Economy	28400.00
0005435718854	27116	Economy	28400.00
0005435718869	27116	Economy	28400.00
0005435718855	27116	Economy	28400.00
0005434925450	14957	Business	22900.00
0005434925414	14957	Business	22900.00
0005434925376	14957	Business	22900.00
0005434925399	14957	Economy	7600.00
0005434925302	14957	Economy	7600.00
0005434925331	14957	Economy	7600.00
0005434925321	14957	Economy	7600.00
0005434925442	14957	Economy	7600.00
0005434925395	14957	Economy	7600.00
0005434925330	14957	Economy	7600.00
0005434925363	14957	Economy	7600.00
0005434925290	14957	Economy	7600.00
0005434925364	14957	Economy	7600.00
0005434925484	14957	Economy	7600.00
0005434925295	14957	Economy	7600.00
0005434925303	14957	Economy	7600.00
0005434925434	14957	Economy	7600.00
0005434925396	14957	Economy	7600.00
0005434925343	14957	Economy	7600.00
0005434925404	14957	Economy	7600.00
0005434925460	14957	Economy	7600.00
0005434925375	14957	Economy	7600.00
0005434925351	14957	Economy	7600.00
0005434925392	14957	Economy	7600.00
0005434925468	14957	Economy	7600.00
0005434925398	14957	Economy	7600.00
0005434925774	20547	Business	22900.00
0005434925766	20547	Business	22900.00
0005434925775	20547	Business	22900.00
0005434925773	20547	Economy	7600.00
0005434925753	20547	Economy	7600.00
0005434925752	20547	Economy	7600.00
0005434925758	20547	Economy	7600.00
0005434925767	20547	Economy	7600.00
0005434925768	20547	Economy	8400.00
0005434925759	20547	Economy	7600.00
0005434925756	20547	Economy	7600.00
0005434925769	20547	Economy	7600.00
0005434925770	20547	Economy	7600.00
0005434925765	20547	Economy	7600.00
0005434925751	20547	Economy	7600.00
0005434925763	20547	Economy	7600.00
0005434925760	20547	Economy	7600.00
0005434925757	20547	Economy	7600.00
0005434925771	20547	Economy	7600.00
0005434925764	20547	Economy	7600.00
0005434925762	20547	Economy	7600.00
0005434925761	20547	Economy	7600.00
0005434925754	20547	Economy	7600.00
0005434925750	20547	Economy	7600.00
0005434925755	20547	Economy	7600.00
0005434925772	20547	Economy	7600.00
0005435487812	15832	Economy	8900.00
0005435487811	15832	Economy	8900.00
0005435999051	15832	Economy	8900.00
0005435487824	15832	Economy	8100.00
0005435999069	15832	Economy	8100.00
0005435487809	15832	Economy	8100.00
0005435487825	15832	Economy	8100.00
0005435487815	15832	Economy	8100.00
0005435999017	15832	Economy	8100.00
0005435487817	15832	Economy	8100.00
0005435487821	15832	Economy	8100.00
0005435487827	15832	Economy	8100.00
0005435487814	15832	Economy	8100.00
0005435487822	15832	Economy	8100.00
0005435487818	15832	Economy	8100.00
0005435487813	15832	Economy	8100.00
0005435487823	15832	Economy	8100.00
0005435487828	15832	Economy	8100.00
0005435999015	15832	Economy	8100.00
0005435999117	15832	Economy	8100.00
0005435487808	15832	Economy	8100.00
0005435487819	15832	Economy	8100.00
0005435999078	15832	Economy	8100.00
0005435999104	15832	Economy	8100.00
0005435487816	15832	Economy	8100.00
0005435487826	15832	Economy	8100.00
0005435999016	15832	Economy	8100.00
0005435999057	15832	Economy	8100.00
0005435487810	15832	Economy	8100.00
0005435487820	15832	Economy	8100.00
0005435999044	15832	Economy	8100.00
0005435999087	15832	Economy	8100.00
0005435999010	15832	Economy	8100.00
0005435487829	15832	Economy	8100.00
0005435999045	15832	Economy	8100.00
0005435487699	19683	Economy	8900.00
0005435487588	19683	Economy	8900.00
0005435487636	19683	Economy	8900.00
0005435999222	19683	Economy	8100.00
0005435999230	19683	Economy	8100.00
0005435999232	19683	Economy	8100.00
0005435487609	19683	Economy	8100.00
0005435487622	19683	Economy	8100.00
0005435487714	19683	Economy	8100.00
0005435487642	19683	Economy	8100.00
0005435487643	19683	Economy	8100.00
0005435999231	19683	Economy	8100.00
0005435487621	19683	Economy	8100.00
0005435999226	19683	Economy	8100.00
0005435999234	19683	Economy	8100.00
0005435487503	19683	Economy	8100.00
0005435487649	19683	Economy	8100.00
0005435999223	19683	Economy	8100.00
0005435487504	19683	Economy	8100.00
0005435487559	19683	Economy	8100.00
0005435487533	19683	Economy	8100.00
0005435999233	19683	Economy	8100.00
0005435487523	19683	Economy	8100.00
0005435487700	19683	Economy	8100.00
0005435487529	19683	Economy	8100.00
0005435999229	19683	Economy	8100.00
0005435999228	19683	Economy	8100.00
0005435999225	19683	Economy	8100.00
0005435999221	19683	Economy	8100.00
0005435999219	19683	Economy	8100.00
0005435999227	19683	Economy	8100.00
0005435487482	19683	Economy	8100.00
0005435999220	19683	Economy	8100.00
0005435487671	19683	Economy	8100.00
0005435999224	19683	Economy	8100.00
0005435999235	19683	Economy	8100.00
0005435487610	19683	Economy	8100.00
0005435487534	19683	Economy	8100.00
0005435999218	19683	Economy	8100.00
0005435487510	19683	Economy	8100.00
0005435472647	6013	Business	199300.00
0005435472646	6013	Business	199300.00
0005435472613	6013	Business	199300.00
0005435839446	6013	Business	199300.00
0005435839419	6013	Business	199300.00
0005435839421	6013	Business	199300.00
0005435839426	6013	Business	199300.00
0005435472685	6013	Business	199300.00
0005435839434	6013	Business	199300.00
0005435839430	6013	Business	199300.00
0005435839427	6013	Business	199300.00
0005435839422	6013	Business	199300.00
0005435839442	6013	Economy	66400.00
0005435839431	6013	Economy	66400.00
0005435839432	6013	Economy	66400.00
0005432142249	6013	Economy	66400.00
0005435839441	6013	Economy	66400.00
0005435472599	6013	Economy	66400.00
0005432659705	6013	Economy	73100.00
0005435472689	6013	Economy	73100.00
0005432659706	6013	Economy	66400.00
0005435472631	6013	Economy	66400.00
0005435839436	6013	Economy	66400.00
0005435839445	6013	Economy	66400.00
0005435839424	6013	Economy	66400.00
0005432142248	6013	Economy	66400.00
0005432658590	6013	Economy	66400.00
0005435839443	6013	Economy	66400.00
0005435472709	6013	Economy	66400.00
0005432660817	6013	Economy	66400.00
0005435839433	6013	Economy	66400.00
0005432142250	6013	Economy	66400.00
0005435839423	6013	Economy	66400.00
0005435839437	6013	Economy	66400.00
0005435472655	6013	Economy	66400.00
0005435839440	6013	Economy	66400.00
0005435839420	6013	Economy	66400.00
0005435472665	6013	Economy	66400.00
0005435839435	6013	Economy	66400.00
0005435839418	6013	Economy	66400.00
0005435839428	6013	Economy	66400.00
0005435839429	6013	Economy	66400.00
0005432537030	6013	Economy	66400.00
0005435839439	6013	Economy	66400.00
0005435839438	6013	Economy	66400.00
0005435839425	6013	Economy	66400.00
0005432658591	6013	Economy	66400.00
0005432660818	6013	Economy	66400.00
0005435839444	6013	Economy	66400.00
0005435839070	18071	Business	199300.00
0005435472784	18071	Business	199300.00
0005435472786	18071	Business	199300.00
0005435839269	18071	Business	199300.00
0005435472793	18071	Business	199300.00
0005435472783	18071	Business	199300.00
0005435839223	18071	Business	199300.00
0005435839208	18071	Business	199300.00
0005435839160	18071	Business	199300.00
0005432667430	18071	Economy	66400.00
0005435472795	18071	Economy	66400.00
0005435472790	18071	Economy	66400.00
0005435839119	18071	Economy	66400.00
0005435839195	18071	Economy	66400.00
0005435472782	18071	Economy	66400.00
0005435839117	18071	Economy	73100.00
0005435472785	18071	Economy	73100.00
0005435472789	18071	Economy	66400.00
0005432667431	18071	Economy	66400.00
0005435839118	18071	Economy	66400.00
0005435839280	18071	Economy	66400.00
0005432537058	18071	Economy	66400.00
0005435839281	18071	Economy	66400.00
0005432537057	18071	Economy	66400.00
0005435839222	18071	Economy	66400.00
0005432660794	18071	Economy	66400.00
0005435839132	18071	Economy	66400.00
0005435472792	18071	Economy	66400.00
0005435839155	18071	Economy	66400.00
0005435839335	18071	Economy	66400.00
0005435839236	18071	Economy	66400.00
0005435839126	18071	Economy	66400.00
0005435472794	18071	Economy	66400.00
0005435839221	18071	Economy	66400.00
0005435472797	18071	Economy	66400.00
0005435839194	18071	Economy	66400.00
0005435839192	18071	Economy	66400.00
0005435839131	18071	Economy	66400.00
0005435839199	18071	Economy	66400.00
0005435839220	18071	Economy	66400.00
0005435472787	18071	Economy	66400.00
0005435839171	18071	Economy	66400.00
0005435839191	18071	Economy	66400.00
0005435472791	18071	Economy	66400.00
0005435839165	18071	Economy	66400.00
0005435839154	18071	Economy	66400.00
0005435472788	18071	Economy	66400.00
0005435839193	18071	Economy	66400.00
0005435472796	18071	Economy	66400.00
0005433462712	19912	Business	146400.00
0005433460403	19912	Business	146400.00
0005433460406	19912	Business	146400.00
0005433462717	19912	Business	146400.00
0005433462713	19912	Business	146400.00
0005433462711	19912	Business	146400.00
0005433460407	19912	Business	146400.00
0005433460404	19912	Economy	53700.00
0005433460405	19912	Economy	48800.00
0005433462723	19912	Economy	48800.00
0005433460400	19912	Economy	48800.00
0005433460408	19912	Economy	48800.00
0005433460398	19912	Economy	48800.00
0005433462710	19912	Economy	48800.00
0005433462718	19912	Economy	48800.00
0005433460409	19912	Economy	48800.00
0005433462720	19912	Economy	48800.00
0005433460399	19912	Economy	48800.00
0005433462715	19912	Economy	48800.00
0005433462709	19912	Economy	48800.00
0005433460402	19912	Economy	48800.00
0005433462724	19912	Economy	53700.00
0005433462714	19912	Economy	48800.00
0005433462721	19912	Economy	48800.00
0005433460401	19912	Economy	48800.00
0005433460410	19912	Economy	48800.00
0005433462716	19912	Economy	48800.00
0005433460412	19912	Economy	48800.00
0005433462719	19912	Economy	48800.00
0005433284985	23042	Business	15700.00
0005433285094	23042	Business	15700.00
0005433285087	23042	Business	15700.00
0005433284951	23042	Business	15700.00
0005433285037	23042	Economy	5200.00
0005435103921	23042	Economy	5200.00
0005435103916	23042	Economy	5200.00
0005435103917	23042	Economy	5200.00
0005435103913	23042	Economy	5200.00
0005435103915	23042	Economy	5700.00
0005433285186	23042	Economy	5200.00
0005435103912	23042	Economy	5200.00
0005433284999	23042	Economy	5200.00
0005433285095	23042	Economy	5200.00
0005433285072	23042	Economy	5200.00
0005435103919	23042	Economy	5200.00
0005435103911	23042	Economy	5200.00
0005435103910	23042	Economy	5200.00
0005433284981	23042	Economy	5200.00
0005433285071	23042	Economy	5200.00
0005433284936	23042	Economy	5200.00
0005435103909	23042	Economy	5200.00
0005433285024	23042	Economy	5200.00
0005433285043	23042	Economy	5200.00
0005435103914	23042	Economy	5200.00
0005433284919	23042	Economy	5200.00
0005433285012	23042	Economy	5200.00
0005433284969	23042	Economy	5200.00
0005433285056	23042	Economy	5200.00
0005433285031	23042	Economy	5200.00
0005435103920	23042	Economy	5200.00
0005435103918	23042	Economy	5200.00
0005435103828	32092	Business	15700.00
0005435103836	32092	Business	15700.00
0005433285276	32092	Business	15700.00
0005433285278	32092	Economy	5200.00
0005433285264	32092	Economy	5200.00
0005435103830	32092	Economy	5200.00
0005433285294	32092	Economy	5200.00
0005435103832	32092	Economy	5200.00
0005435103831	32092	Economy	5200.00
0005435103829	32092	Economy	5200.00
0005433285277	32092	Economy	5200.00
0005433285290	32092	Economy	5200.00
0005433285286	32092	Economy	5200.00
0005433285282	32092	Economy	5200.00
0005433285293	32092	Economy	5200.00
0005433285268	32092	Economy	5200.00
0005433285266	32092	Economy	5200.00
0005433285279	32092	Economy	5700.00
0005435103837	32092	Economy	5700.00
0005433285280	32092	Economy	5700.00
0005433285281	32092	Economy	5200.00
0005435103847	32092	Economy	5200.00
0005433285270	32092	Economy	5200.00
0005435103823	32092	Economy	5200.00
0005433285292	32092	Economy	5200.00
0005433285267	32092	Economy	5200.00
0005433285291	32092	Economy	5200.00
0005435103840	32092	Economy	5200.00
0005433285272	32092	Economy	5200.00
0005433285285	32092	Economy	5200.00
0005433285273	32092	Economy	5200.00
0005435103846	32092	Economy	5200.00
0005435103848	32092	Economy	5200.00
0005435103838	32092	Economy	5200.00
0005433285275	32092	Economy	5200.00
0005433285288	32092	Economy	5200.00
0005435103849	32092	Economy	5200.00
0005433285274	32092	Economy	5200.00
0005433285289	32092	Economy	5200.00
0005433285287	32092	Economy	5200.00
0005433285269	32092	Economy	5200.00
0005433285283	32092	Economy	5200.00
0005433285284	32092	Economy	5200.00
0005433285265	32092	Economy	5200.00
0005433285271	32092	Economy	5200.00
0005432892751	19950	Business	150400.00
0005432802434	19950	Business	150400.00
0005432802444	19950	Business	150400.00
0005433111501	19950	Business	150400.00
0005432802464	19950	Business	150400.00
0005432802457	19950	Business	150400.00
0005433112370	19950	Business	150400.00
0005432892752	19950	Business	150400.00
0005433112365	19950	Economy	50100.00
0005433111490	19950	Economy	50100.00
0005433111496	19950	Economy	50100.00
0005433111498	19950	Economy	55200.00
0005432802456	19950	Economy	55200.00
0005433111495	19950	Economy	50100.00
0005433111497	19950	Economy	50100.00
0005432892758	19950	Economy	50100.00
0005433111494	19950	Economy	50100.00
0005432892744	19950	Economy	50100.00
0005433112366	19950	Economy	50100.00
0005432802458	19950	Economy	50100.00
0005432892754	19950	Economy	50100.00
0005432892746	19950	Economy	50100.00
0005432802460	19950	Economy	50100.00
0005432892757	19950	Economy	50100.00
0005432892750	19950	Economy	50100.00
0005433112367	19950	Economy	50100.00
0005432892749	19950	Economy	50100.00
0005433112363	19950	Economy	50100.00
0005432892755	19950	Economy	50100.00
0005432892748	19950	Economy	50100.00
0005433111500	19950	Economy	50100.00
0005433111493	19950	Economy	50100.00
0005432802461	19950	Economy	50100.00
0005433111489	19950	Economy	50100.00
0005433112364	19950	Economy	50100.00
0005432892756	19950	Economy	50100.00
0005432892747	19950	Economy	50100.00
0005432802463	19950	Economy	50100.00
0005432802449	19950	Economy	50100.00
0005433112369	19950	Economy	50100.00
0005433112368	19950	Economy	50100.00
0005434302853	19950	Economy	50100.00
0005433112362	19950	Economy	50100.00
0005432802448	19950	Economy	50100.00
0005432802462	19950	Economy	50100.00
0005433111499	19950	Economy	50100.00
0005433111502	19950	Economy	50100.00
0005432892745	19950	Economy	50100.00
0005432892753	19950	Economy	50100.00
0005433111492	19950	Economy	50100.00
0005433111491	19950	Economy	50100.00
0005432526822	30596	Business	42100.00
0005434067179	30596	Business	42100.00
0005432526791	30596	Business	42100.00
0005432535776	30596	Business	42100.00
0005434066620	30596	Business	42100.00
0005432526362	30596	Business	42100.00
0005432527173	30596	Business	42100.00
0005432526758	30596	Business	42100.00
0005432526963	30596	Business	42100.00
0005435213575	30596	Business	42100.00
0005432527055	30596	Business	42100.00
0005435213552	30596	Business	42100.00
0005432527036	30596	Business	42100.00
0005434066927	30596	Business	42100.00
0005435213542	30596	Business	42100.00
0005434066831	30596	Business	42100.00
0005434067075	30596	Business	42100.00
0005432535777	30596	Business	42100.00
0005432527001	30596	Business	42100.00
0005432526962	30596	Business	42100.00
0005432526361	30596	Business	42100.00
0005435213566	30596	Business	42100.00
0005435213573	30596	Business	42100.00
0005432527107	30596	Business	42100.00
0005432526640	30596	Comfort	23900.00
0005435213518	30596	Comfort	23900.00
0005435630968	30596	Comfort	23900.00
0005435213533	30596	Comfort	23900.00
0005432211502	30596	Comfort	23900.00
0005435213545	30596	Comfort	23900.00
0005432526821	30596	Comfort	23900.00
0005432526609	30596	Comfort	23900.00
0005435213531	30596	Comfort	23900.00
0005432527236	30596	Comfort	23900.00
0005432526948	30596	Comfort	23900.00
0005432527198	30596	Comfort	23900.00
0005432527072	30596	Comfort	23900.00
0005435213555	30596	Comfort	23900.00
0005432527179	30596	Comfort	23900.00
0005434066931	30596	Comfort	23900.00
0005432211501	30596	Comfort	23900.00
0005432527019	30596	Comfort	23900.00
0005434066883	30596	Comfort	23900.00
0005432526920	30596	Comfort	23900.00
0005432527362	30596	Comfort	23900.00
0005434066830	30596	Comfort	23900.00
0005432527038	30596	Comfort	23900.00
0005434066665	30596	Comfort	23900.00
0005435213520	30596	Comfort	23900.00
0005432526336	30596	Comfort	23900.00
0005432526643	30596	Comfort	23900.00
0005435213558	30596	Comfort	23900.00
0005432527465	30596	Comfort	23900.00
0005434066702	30596	Comfort	23900.00
0005432526728	30596	Comfort	23900.00
0005434066707	30596	Comfort	23900.00
0005432535784	30596	Comfort	23900.00
0005434067131	30596	Comfort	23900.00
0005435213510	30596	Comfort	23900.00
0005432527002	30596	Comfort	23900.00
0005432428906	30596	Comfort	23900.00
0005435213530	30596	Comfort	23900.00
0005434066937	30596	Economy	14000.00
0005432535779	30596	Economy	14000.00
0005432159855	30596	Economy	14000.00
0005435213535	30596	Economy	14000.00
0005432526745	30596	Economy	14000.00
0005432527096	30596	Economy	14000.00
0005435213528	30596	Economy	14000.00
0005435213526	30596	Economy	14000.00
0005432527337	30596	Economy	14000.00
0005435213570	30596	Economy	14000.00
0005435213522	30596	Economy	14000.00
0005432526889	30596	Economy	14000.00
0005434066977	30596	Economy	14000.00
0005434067005	30596	Economy	14000.00
0005434066890	30596	Economy	14000.00
0005435213550	30596	Economy	14000.00
0005435213540	30596	Economy	14000.00
0005432527174	30596	Economy	14000.00
0005432526509	30596	Economy	14000.00
0005432526729	30596	Economy	14000.00
0005432526360	30596	Economy	14000.00
0005435213549	30596	Economy	14000.00
0005434067132	30596	Economy	14000.00
0005432526347	30596	Economy	14000.00
0005434067159	30596	Economy	14000.00
0005432526965	30596	Economy	14000.00
0005435725600	30596	Economy	14000.00
0005432526690	30596	Economy	14000.00
0005432526818	30596	Economy	14000.00
0005434066913	30596	Economy	14000.00
0005434067036	30596	Economy	14000.00
0005432527020	30596	Economy	14000.00
0005432526586	30596	Economy	14000.00
0005435213511	30596	Economy	14000.00
0005432526641	30596	Economy	14000.00
0005432526981	30596	Economy	14000.00
0005434067006	30596	Economy	14000.00
0005432527157	30596	Economy	14000.00
0005434066907	30596	Economy	14000.00
0005432526719	30596	Economy	14000.00
0005432526514	30596	Economy	14000.00
0005432526672	30596	Economy	14000.00
0005432527246	30596	Economy	14000.00
0005432533263	30596	Economy	14000.00
0005435213512	30596	Economy	14000.00
0005434066946	30596	Economy	14000.00
0005432526906	30596	Economy	14000.00
0005435213532	30596	Economy	14000.00
0005432527037	30596	Economy	14000.00
0005432526718	30596	Economy	14000.00
0005435213571	30596	Economy	14000.00
0005434066697	30596	Economy	14000.00
0005432527558	30596	Economy	14000.00
0005435213560	30596	Economy	14000.00
0005435213561	30596	Economy	15400.00
0005432526615	30596	Economy	15400.00
0005432526443	30596	Economy	15400.00
0005434066691	30596	Economy	14000.00
0005433656670	30596	Economy	14000.00
0005432527307	30596	Economy	15400.00
0005433656672	30596	Economy	15400.00
0005434067002	30596	Economy	14000.00
0005432527220	30596	Economy	14000.00
0005432527361	30596	Economy	14000.00
0005435213557	30596	Economy	14000.00
0005432526703	30596	Economy	14000.00
0005435213554	30596	Economy	14000.00
0005435213508	30596	Economy	14000.00
0005432527209	30596	Economy	14000.00
0005432526885	30596	Economy	14000.00
0005432527154	30596	Economy	14000.00
0005434066799	30596	Economy	14000.00
0005432527367	30596	Economy	14000.00
0005432526449	30596	Economy	14000.00
0005434066708	30596	Economy	14000.00
0005432527041	30596	Economy	14000.00
0005435725602	30596	Economy	14000.00
0005434066785	30596	Economy	14000.00
0005434067070	30596	Economy	14000.00
0005435213524	30596	Economy	14000.00
0005432527108	30596	Economy	14000.00
0005435213534	30596	Economy	14000.00
0005432526867	30596	Economy	14000.00
0005435213563	30596	Economy	14000.00
0005432526743	30596	Economy	14000.00
0005432428905	30596	Economy	14000.00
0005432527312	30596	Economy	14000.00
0005432526927	30596	Economy	14000.00
0005432526691	30596	Economy	14000.00
0005432526614	30596	Economy	14000.00
0005432527000	30596	Economy	14000.00
0005432211497	30596	Economy	14000.00
0005435213569	30596	Economy	14000.00
0005432159856	30596	Economy	14000.00
0005434066701	30596	Economy	14000.00
0005435213519	30596	Economy	14000.00
0005435213559	30596	Economy	14000.00
0005432428896	30596	Economy	14000.00
0005432526613	30596	Economy	14000.00
0005432527029	30596	Economy	14000.00
0005432527056	30596	Economy	14000.00
0005434066955	30596	Economy	14000.00
0005434066985	30596	Economy	14000.00
0005432527119	30596	Economy	14000.00
0005432533258	30596	Economy	14000.00
0005432527030	30596	Economy	14000.00
0005432527103	30596	Economy	14000.00
0005434066832	30596	Economy	14000.00
0005434066925	30596	Economy	14000.00
0005432526612	30596	Economy	14000.00
0005432526802	30596	Economy	14000.00
0005432211503	30596	Economy	14000.00
0005432526879	30596	Economy	14000.00
0005432526611	30596	Economy	14000.00
0005434066947	30596	Economy	14000.00
0005432526513	30596	Economy	14000.00
0005432527158	30596	Economy	14000.00
0005432526692	30596	Economy	14000.00
0005435213541	30596	Economy	14000.00
0005432527045	30596	Economy	14000.00
0005435213553	30596	Economy	14000.00
0005432527083	30596	Economy	14000.00
0005435213539	30596	Economy	14000.00
0005432526773	30596	Economy	14000.00
0005432159857	30596	Economy	14000.00
0005435213521	30596	Economy	14000.00
0005435213546	30596	Economy	14000.00
0005432527137	30596	Economy	14000.00
0005435213543	30596	Economy	14000.00
0005432526510	30596	Economy	14000.00
0005434066912	30596	Economy	14000.00
0005432211496	30596	Economy	14000.00
0005435213536	30596	Economy	14000.00
0005435213547	30596	Economy	14000.00
0005434067064	30596	Economy	14000.00
0005435213538	30596	Economy	14000.00
0005434066926	30596	Economy	14000.00
0005432527123	30596	Economy	14000.00
0005432526523	30596	Economy	14000.00
0005432526578	30596	Economy	14000.00
0005435213556	30596	Economy	14000.00
0005432526676	30596	Economy	14000.00
0005432526710	30596	Economy	14000.00
0005432527003	30596	Economy	14000.00
0005432527023	30596	Economy	14000.00
0005434066951	30596	Economy	14000.00
0005432526759	30596	Economy	14000.00
0005435213515	30596	Economy	14000.00
0005435213517	30596	Economy	14000.00
0005432526733	30596	Economy	14000.00
0005435725599	30596	Economy	14000.00
0005432159858	30596	Economy	14000.00
0005432526771	30596	Economy	14000.00
0005432535791	30596	Economy	14000.00
0005434067011	30596	Economy	14000.00
0005432211500	30596	Economy	15400.00
0005432527466	30596	Economy	14000.00
0005432527136	30596	Economy	15400.00
0005432527031	30596	Economy	15400.00
0005432527356	30596	Economy	15400.00
0005432527241	30596	Economy	15400.00
0005432527239	30596	Economy	14000.00
0005434066786	30596	Economy	14000.00
0005434067163	30596	Economy	14000.00
0005434066699	30596	Economy	14000.00
0005435213523	30596	Economy	14000.00
0005433656671	30596	Economy	14000.00
0005432526966	30596	Economy	14000.00
0005432527092	30596	Economy	14000.00
0005432526642	30596	Economy	14000.00
0005434066800	30596	Economy	14000.00
0005434066664	30596	Economy	14000.00
0005432527166	30596	Economy	14000.00
0005435213568	30596	Economy	14000.00
0005432526830	30596	Economy	14000.00
0005432526800	30596	Economy	14000.00
0005434066932	30596	Economy	14000.00
0005432526511	30596	Economy	14000.00
0005432526772	30596	Economy	14000.00
0005434066717	30596	Economy	14000.00
0005432526616	30596	Economy	14000.00
0005435213525	30596	Economy	14000.00
0005435213544	30596	Economy	14000.00
0005432526964	30596	Economy	14000.00
0005432526115	30596	Economy	14000.00
0005432526742	30596	Economy	14000.00
0005435213565	30596	Economy	14000.00
0005435213529	30596	Economy	14000.00
0005432527132	30596	Economy	14000.00
0005432526732	30596	Economy	14000.00
0005434067230	30596	Economy	14000.00
0005435213562	30596	Economy	14000.00
0005432526921	30596	Economy	14000.00
0005432428897	30596	Economy	14000.00
0005434066819	30596	Economy	14000.00
0005432526938	30596	Economy	14000.00
0005432526770	30596	Economy	14000.00
0005432526907	30596	Economy	14000.00
0005434066898	30596	Economy	14000.00
0005432211499	30596	Economy	14000.00
0005434066888	30596	Economy	14000.00
0005432526644	30596	Economy	14000.00
0005434066692	30596	Economy	14000.00
0005434066906	30596	Economy	14000.00
0005432527109	30596	Economy	14000.00
0005435213516	30596	Economy	14000.00
0005432526500	30596	Economy	14000.00
0005432527070	30596	Economy	14000.00
0005432526712	30596	Economy	14000.00
0005435213574	30596	Economy	14000.00
0005432527308	30596	Economy	14000.00
0005435725601	30596	Economy	14000.00
0005432526922	30596	Economy	14000.00
0005435213551	30596	Economy	14000.00
0005434067071	30596	Economy	14000.00
0005434066690	30596	Economy	14000.00
0005432526727	30596	Economy	14000.00
0005432526744	30596	Economy	14000.00
0005434066698	30596	Economy	14000.00
0005432159859	30596	Economy	14000.00
0005432527042	30596	Economy	14000.00
0005432428904	30596	Economy	14000.00
0005432527106	30596	Economy	14000.00
0005434066965	30596	Economy	14000.00
0005432526504	30596	Economy	14000.00
0005435213509	30596	Economy	14000.00
0005435213527	30596	Economy	14000.00
0005435213567	30596	Economy	14000.00
0005432527199	30596	Economy	14000.00
0005434066882	30596	Economy	14000.00
0005432526882	30596	Economy	14000.00
0005432211498	30596	Economy	14000.00
0005435213564	30596	Economy	14000.00
0005435213548	30596	Economy	14000.00
0005434066784	30596	Economy	14000.00
0005432526314	30596	Economy	14000.00
0005434066950	30596	Economy	14000.00
0005432526638	30596	Economy	14000.00
0005434066889	30596	Economy	14000.00
0005432527364	30596	Economy	14000.00
0005435213513	30596	Economy	14000.00
0005435213572	30596	Economy	14000.00
0005435213514	30596	Economy	14000.00
0005434066716	30596	Economy	14000.00
0005432527467	30596	Economy	14000.00
0005432526886	30596	Economy	14000.00
0005435213537	30596	Economy	14000.00
0005434066619	30596	Economy	14000.00
0005432526450	30596	Economy	14000.00
0005434067063	30596	Economy	14000.00
0005432526819	30596	Economy	14000.00
0005432527165	30596	Economy	14000.00
0005435213507	30596	Economy	14000.00
0005432527018	30596	Economy	14000.00
0005432526505	30596	Economy	14000.00
0005433367885	24856	Business	9800.00
0005435652415	24856	Business	9800.00
0005435652488	24856	Business	9800.00
0005435652474	24856	Business	9800.00
0005433367904	24856	Business	9800.00
0005433367879	24856	Business	9800.00
0005435652631	24856	Business	9800.00
0005435652628	24856	Business	9800.00
0005435652337	24856	Business	9800.00
0005435652626	24856	Business	9800.00
0005435652657	24856	Economy	3300.00
0005433367883	24856	Economy	3300.00
0005435652601	24856	Economy	3300.00
0005433367878	24856	Economy	3300.00
0005435652615	24856	Economy	3300.00
0005433367907	24856	Economy	3300.00
0005433367908	24856	Economy	3600.00
0005433367871	24856	Economy	3600.00
0005435652637	24856	Economy	3600.00
0005433367893	24856	Economy	3600.00
0005435652574	24856	Economy	3600.00
0005433367876	24856	Economy	3300.00
0005435652565	24856	Economy	3300.00
0005435652697	24856	Economy	3300.00
0005433367875	24856	Economy	3300.00
0005435652611	24856	Economy	3300.00
0005435652724	24856	Economy	3300.00
0005435652553	24856	Economy	3300.00
0005435652636	24856	Economy	3300.00
0005435652506	24856	Economy	3300.00
0005435652558	24856	Economy	3300.00
0005433367905	24856	Economy	3300.00
0005435652635	24856	Economy	3300.00
0005433367881	24856	Economy	3300.00
0005433367889	24856	Economy	3300.00
0005433367892	24856	Economy	3300.00
0005435652550	24856	Economy	3300.00
0005433367901	24856	Economy	3300.00
0005435652567	24856	Economy	3300.00
0005435652632	24856	Economy	3300.00
0005433367873	24856	Economy	3300.00
0005435652475	24856	Economy	3300.00
0005433367890	24856	Economy	3300.00
0005433367886	24856	Economy	3300.00
0005433367900	24856	Economy	3300.00
0005433367887	24856	Economy	3300.00
0005435652580	24856	Economy	3300.00
0005435652507	24856	Economy	3300.00
0005433367884	24856	Economy	3300.00
0005433367903	24856	Economy	3300.00
0005433367894	24856	Economy	3300.00
0005433367906	24856	Economy	3300.00
0005435652513	24856	Economy	3300.00
0005435652564	24856	Economy	3300.00
0005433367880	24856	Economy	3300.00
0005435652599	24856	Economy	3300.00
0005435652602	24856	Economy	3300.00
0005435652588	24856	Economy	3300.00
0005435652616	24856	Economy	3300.00
0005435652570	24856	Economy	3300.00
0005433367877	24856	Economy	3300.00
0005435652600	24856	Economy	3300.00
0005433367895	24856	Economy	3300.00
0005433367896	24856	Economy	3300.00
0005435652425	24856	Economy	3300.00
0005433367899	24856	Economy	3300.00
0005435652619	24856	Economy	3300.00
0005435652495	24856	Economy	3300.00
0005433367888	24856	Economy	3300.00
0005433367897	24856	Economy	3300.00
0005433367874	24856	Economy	3300.00
0005433367902	24856	Economy	3300.00
0005435652723	24856	Economy	3300.00
0005435652613	24856	Economy	3300.00
0005433367891	24856	Economy	3300.00
0005435652670	24856	Economy	3300.00
0005435652718	24856	Economy	3300.00
0005433367882	24856	Economy	3300.00
0005435652540	24856	Economy	3300.00
0005433367898	24856	Economy	3300.00
0005435652545	24856	Economy	3300.00
0005435652416	24856	Economy	3300.00
0005433367872	24856	Economy	3300.00
0005435652612	24856	Economy	3300.00
0005435652579	24856	Economy	3300.00
0005435652514	24856	Economy	3300.00
0005435652578	24856	Economy	3300.00
0005435949781	6603	Economy	20600.00
0005435949779	6603	Economy	20600.00
0005435949772	6603	Economy	18700.00
0005435949776	6603	Economy	18700.00
0005435949780	6603	Economy	18700.00
0005435949774	6603	Economy	18700.00
0005435949775	6603	Economy	18700.00
0005435949778	6603	Economy	18700.00
0005435949782	6603	Economy	18700.00
0005435949773	6603	Economy	18700.00
0005435949777	6603	Economy	18700.00
0005434979777	2037	Economy	10500.00
0005434979798	2037	Economy	10500.00
0005434979776	2037	Economy	10500.00
0005434979775	2037	Economy	10500.00
0005434979778	2037	Economy	9500.00
0005434979794	2037	Economy	9500.00
0005434979789	2037	Economy	9500.00
0005434979799	2037	Economy	9500.00
0005434979783	2037	Economy	9500.00
0005434979803	2037	Economy	9500.00
0005434979801	2037	Economy	9500.00
0005434979804	2037	Economy	9500.00
0005434979805	2037	Economy	9500.00
0005434979785	2037	Economy	9500.00
0005434979786	2037	Economy	9500.00
0005434979781	2037	Economy	9500.00
0005434979792	2037	Economy	9500.00
0005434979782	2037	Economy	9500.00
0005434979796	2037	Economy	9500.00
0005434979795	2037	Economy	9500.00
0005434979784	2037	Economy	9500.00
0005434979780	2037	Economy	9500.00
0005434979791	2037	Economy	9500.00
0005434979802	2037	Economy	9500.00
0005435801695	2037	Economy	9500.00
0005434979800	2037	Economy	9500.00
0005434979797	2037	Economy	9500.00
0005435801697	2037	Economy	9500.00
0005434979793	2037	Economy	9500.00
0005434979788	2037	Economy	9500.00
0005435801696	2037	Economy	9500.00
0005434979779	2037	Economy	9500.00
0005434979790	2037	Economy	9500.00
0005434979787	2037	Economy	9500.00
0005434979504	23556	Economy	10500.00
0005434979462	23556	Economy	10500.00
0005434979395	23556	Economy	9500.00
0005434979383	23556	Economy	9500.00
0005434979422	23556	Economy	9500.00
0005434979388	23556	Economy	9500.00
0005434979471	23556	Economy	9500.00
0005435801679	23556	Economy	9500.00
0005434979403	23556	Economy	9500.00
0005434979291	23556	Economy	9500.00
0005434979506	23556	Economy	9500.00
0005434979547	23556	Economy	9500.00
0005434979505	23556	Economy	9500.00
0005435801668	23556	Economy	9500.00
0005434979431	23556	Economy	9500.00
0005435801678	23556	Economy	9500.00
0005434979560	23556	Economy	9500.00
0005434979423	23556	Economy	9500.00
0005434979576	23556	Economy	9500.00
0005434979464	23556	Economy	9500.00
0005434979511	23556	Economy	9500.00
0005434979561	23556	Economy	9500.00
0005434979575	23556	Economy	9500.00
0005434979384	23556	Economy	9500.00
0005434979512	23556	Economy	9500.00
0005434979521	23556	Economy	9500.00
0005434979470	23556	Economy	9500.00
0005434979441	23556	Economy	9500.00
0005434979502	23556	Economy	9500.00
0005434979463	23556	Economy	9500.00
0005434979440	23556	Economy	9500.00
0005434979574	23556	Economy	9500.00
0005434979553	23556	Economy	9500.00
0005434979389	23556	Economy	9500.00
0005434952531	2618	Economy	5300.00
0005434952532	2618	Economy	5300.00
0005434952530	2618	Economy	5300.00
0005434952529	2618	Economy	5300.00
0005433256412	2616	Economy	5300.00
0005433256413	2616	Economy	5300.00
0005433256405	2616	Economy	5300.00
0005434952507	28200	Economy	5300.00
0005434952499	28200	Economy	5300.00
0005434952515	28200	Economy	5300.00
0005433256422	28200	Economy	5300.00
0005434952486	28200	Economy	5300.00
0005434952484	28200	Economy	5300.00
0005433256421	28200	Economy	5300.00
0005434952485	28200	Economy	5300.00
0005434952506	28200	Economy	5300.00
0005433112374	19764	Economy	8700.00
0005433111507	19764	Economy	8700.00
0005433112373	19764	Economy	8700.00
0005433111506	19764	Economy	8700.00
0005434137572	11949	Business	9700.00
0005434137213	11949	Business	9700.00
0005434137298	11949	Business	9700.00
0005434137380	11949	Business	9700.00
0005434137784	11949	Business	9700.00
0005434137367	11949	Business	9700.00
0005434137184	11949	Business	9700.00
0005434137594	11949	Business	9700.00
0005434137852	11949	Business	9700.00
0005434137558	11949	Business	9700.00
0005434137531	11949	Business	9700.00
0005434137571	11949	Economy	3200.00
0005434137450	11949	Economy	3200.00
0005434137432	11949	Economy	3200.00
0005434137544	11949	Economy	3200.00
0005434137595	11949	Economy	3200.00
0005434137397	11949	Economy	3200.00
0005434137561	11949	Economy	3200.00
0005434137396	11949	Economy	3200.00
0005434137670	11949	Economy	3200.00
0005434137431	11949	Economy	3500.00
0005434137603	11949	Economy	3500.00
0005434137853	11949	Economy	3500.00
0005434137532	11949	Economy	3500.00
0005434137605	11949	Economy	3500.00
0005434137657	11949	Economy	3200.00
0005434137428	11949	Economy	3200.00
0005434137235	11949	Economy	3200.00
0005434137421	11949	Economy	3200.00
0005434137613	11949	Economy	3200.00
0005434137494	11949	Economy	3200.00
0005434136872	11949	Economy	3200.00
0005434137656	11949	Economy	3200.00
0005434137534	11949	Economy	3200.00
0005434137214	11949	Economy	3200.00
0005434137698	11949	Economy	3200.00
0005434137493	11949	Economy	3200.00
0005434137112	11949	Economy	3200.00
0005434136890	11949	Economy	3200.00
0005434137156	11949	Economy	3200.00
0005434137569	11949	Economy	3200.00
0005434137474	11949	Economy	3200.00
0005434137302	11949	Economy	3200.00
0005434136973	11949	Economy	3200.00
0005434137411	11949	Economy	3200.00
0005434137655	11949	Economy	3200.00
0005434137420	11949	Economy	3200.00
0005434137357	11949	Economy	3200.00
0005434137451	11949	Economy	3200.00
0005434137441	11949	Economy	3200.00
0005434137741	11949	Economy	3200.00
0005434137212	11949	Economy	3200.00
0005434137234	11949	Economy	3200.00
0005434137271	11949	Economy	3200.00
0005434137430	11949	Economy	3200.00
0005434137344	11949	Economy	3200.00
0005434137123	11949	Economy	3200.00
0005434137135	11949	Economy	3200.00
0005434137299	11949	Economy	3200.00
0005434137854	11949	Economy	3200.00
0005434137427	11949	Economy	3200.00
0005434137134	11949	Economy	3200.00
0005434136950	11949	Economy	3200.00
0005434137361	11949	Economy	3200.00
0005434137476	11949	Economy	3200.00
0005434137188	11949	Economy	3200.00
0005434137303	11949	Economy	3200.00
0005434136778	11949	Economy	3200.00
0005434137489	11949	Economy	3200.00
0005434137309	11949	Economy	3200.00
0005434137791	11949	Economy	3200.00
0005434137514	11949	Economy	3200.00
0005434137311	11949	Economy	3200.00
0005434137237	11949	Economy	3200.00
0005434137272	11949	Economy	3200.00
0005434137440	11949	Economy	3200.00
0005434137860	11949	Economy	3200.00
0005434137757	11949	Economy	3200.00
0005434137533	11949	Economy	3200.00
0005434137648	11949	Economy	3200.00
0005434137389	11949	Economy	3200.00
0005434138082	28745	Business	9700.00
0005434138095	28745	Business	9700.00
0005434138069	28745	Business	9700.00
0005434138066	28745	Business	9700.00
0005434138048	28745	Business	9700.00
0005434138068	28745	Business	9700.00
0005434138038	28745	Business	9700.00
0005434138035	28745	Business	9700.00
0005434138055	28745	Business	9700.00
0005434138075	28745	Business	9700.00
0005434138061	28745	Economy	3200.00
0005434138073	28745	Economy	3200.00
0005434138108	28745	Economy	3200.00
0005434138083	28745	Economy	3200.00
0005434138078	28745	Economy	3200.00
0005434138116	28745	Economy	3200.00
0005434138103	28745	Economy	3200.00
0005434138042	28745	Economy	3200.00
0005434138063	28745	Economy	3200.00
0005434138123	28745	Economy	3200.00
0005434138079	28745	Economy	3500.00
0005434138089	28745	Economy	3500.00
0005434138098	28745	Economy	3500.00
0005434138087	28745	Economy	3500.00
0005434138112	28745	Economy	3200.00
0005434138097	28745	Economy	3200.00
0005434138037	28745	Economy	3200.00
0005434138102	28745	Economy	3200.00
0005434138056	28745	Economy	3200.00
0005434138065	28745	Economy	3200.00
0005434138054	28745	Economy	3200.00
0005434138120	28745	Economy	3200.00
0005434138081	28745	Economy	3200.00
0005434138072	28745	Economy	3200.00
0005434138057	28745	Economy	3200.00
0005434138118	28745	Economy	3200.00
0005434138100	28745	Economy	3200.00
0005434138058	28745	Economy	3200.00
0005434138044	28745	Economy	3200.00
0005434138105	28745	Economy	3200.00
0005434138046	28745	Economy	3200.00
0005434138051	28745	Economy	3200.00
0005434138088	28745	Economy	3200.00
0005434138076	28745	Economy	3200.00
0005434138045	28745	Economy	3200.00
0005434138119	28745	Economy	3200.00
0005434138050	28745	Economy	3200.00
0005434138064	28745	Economy	3200.00
0005434138094	28745	Economy	3200.00
0005434138115	28745	Economy	3200.00
0005434138047	28745	Economy	3200.00
0005434138059	28745	Economy	3200.00
0005434138106	28745	Economy	3200.00
0005434138062	28745	Economy	3200.00
0005434138099	28745	Economy	3200.00
0005434138124	28745	Economy	3200.00
0005434138049	28745	Economy	3200.00
0005434138122	28745	Economy	3200.00
0005434138071	28745	Economy	3200.00
0005434138113	28745	Economy	3200.00
0005434138091	28745	Economy	3200.00
0005434138093	28745	Economy	3200.00
0005434138067	28745	Economy	3200.00
0005434138080	28745	Economy	3200.00
0005434138086	28745	Economy	3200.00
0005434138104	28745	Economy	3200.00
0005434138121	28745	Economy	3200.00
0005434138074	28745	Economy	3200.00
0005434138101	28745	Economy	3200.00
0005434138117	28745	Economy	3200.00
0005434138111	28745	Economy	3200.00
0005434138107	28745	Economy	3200.00
0005434138060	28745	Economy	3200.00
0005434138052	28745	Economy	3200.00
0005434138040	28745	Economy	3200.00
0005434138114	28745	Economy	3200.00
0005434138036	28745	Economy	3200.00
0005434138077	28745	Economy	3200.00
0005434138070	28745	Economy	3200.00
0005434138084	28745	Economy	3200.00
0005434138090	28745	Economy	3200.00
0005434138039	28745	Economy	3200.00
0005434138092	28745	Economy	3200.00
0005434138053	28745	Economy	3200.00
0005434138043	28745	Economy	3200.00
0005434138110	28745	Economy	3200.00
0005434138109	28745	Economy	3200.00
0005434138085	28745	Economy	3200.00
0005434138096	28745	Economy	3200.00
0005434138041	28745	Economy	3200.00
0005433538870	6798	Economy	9900.00
0005435259723	6798	Economy	9900.00
0005433538869	6798	Economy	9900.00
0005435259732	6798	Economy	9900.00
0005433538871	6798	Economy	9900.00
0005435259722	6798	Economy	9900.00
0005433534498	6798	Economy	9900.00
0005433538872	6798	Economy	9900.00
0005433538874	6798	Economy	9900.00
0005433534497	6798	Economy	9900.00
0005433538868	6798	Economy	9900.00
0005433538866	6798	Economy	9900.00
0005433538867	6798	Economy	9900.00
0005433538873	6798	Economy	9900.00
0005433534499	6798	Economy	9900.00
0005435259758	25043	Economy	9900.00
0005435259757	25043	Economy	9900.00
0005433534475	25043	Economy	9900.00
0005433534484	25043	Economy	9900.00
0005435259755	25043	Economy	9900.00
0005433538774	25043	Economy	9900.00
0005433538805	25043	Economy	9900.00
0005433538798	25043	Economy	9900.00
0005433534474	25043	Economy	9900.00
0005433534476	25043	Economy	9900.00
0005435259756	25043	Economy	9900.00
0005433511954	809	Economy	16100.00
0005432922473	809	Economy	14600.00
0005433511953	809	Economy	14600.00
0005433511951	809	Economy	14600.00
0005432922499	809	Economy	14600.00
0005432922503	809	Economy	14600.00
0005433511949	809	Economy	14600.00
0005432922498	809	Economy	14600.00
0005433511952	809	Economy	14600.00
0005432922500	809	Economy	14600.00
0005432922511	809	Economy	14600.00
0005433511955	809	Economy	14600.00
0005433511948	809	Economy	14600.00
0005433511950	809	Economy	14600.00
0005433511947	809	Economy	14600.00
0005432922512	809	Economy	14600.00
0005433511900	16125	Economy	16100.00
0005432922525	16125	Economy	14600.00
0005432922526	16125	Economy	14600.00
0005433511850	16125	Economy	14600.00
0005433511849	16125	Economy	14600.00
0005432922524	16125	Economy	14600.00
0005433511874	16125	Economy	14600.00
0005433511902	16125	Economy	14600.00
0005433511901	16125	Economy	14600.00
0005435916151	3696	Economy	7900.00
0005435697356	3696	Economy	7900.00
0005435697345	3696	Economy	7900.00
0005434950529	3696	Economy	7900.00
0005435697343	3696	Economy	7200.00
0005435697332	3696	Economy	7200.00
0005435697355	3696	Economy	7200.00
0005435697359	3696	Economy	7200.00
0005435697338	3696	Economy	7200.00
0005435697331	3696	Economy	7200.00
0005435697353	3696	Economy	7200.00
0005435697344	3696	Economy	7200.00
0005435697354	3696	Economy	7200.00
0005434950530	3696	Economy	7200.00
0005435697340	3696	Economy	7200.00
0005435697334	3696	Economy	7200.00
0005435697350	3696	Economy	7200.00
0005435697357	3696	Economy	7200.00
0005435697339	3696	Economy	7200.00
0005435916149	3696	Economy	7200.00
0005435697342	3696	Economy	7200.00
0005435697352	3696	Economy	7200.00
0005435697337	3696	Economy	7200.00
0005435697351	3696	Economy	7200.00
0005435916150	3696	Economy	7200.00
0005435697349	3696	Economy	7200.00
0005434950528	3696	Economy	7200.00
0005435697346	3696	Economy	7200.00
0005435697336	3696	Economy	7200.00
0005435697333	3696	Economy	7200.00
0005435935018	3696	Economy	7200.00
0005435697348	3696	Economy	7200.00
0005434950531	3696	Economy	7200.00
0005435697335	3696	Economy	7200.00
0005435697341	3696	Economy	7200.00
0005435697347	3696	Economy	7200.00
0005435697358	3696	Economy	7200.00
0005435697049	16308	Economy	7900.00
0005434950487	16308	Economy	7900.00
0005435935042	16308	Economy	7900.00
0005435697095	16308	Economy	7200.00
0005435697100	16308	Economy	7200.00
0005435696951	16308	Economy	7200.00
0005435697088	16308	Economy	7200.00
0005435697009	16308	Economy	7200.00
0005435697048	16308	Economy	7200.00
0005435697090	16308	Economy	7200.00
0005435697126	16308	Economy	7200.00
0005435697045	16308	Economy	7200.00
0005435697082	16308	Economy	7200.00
0005435935044	16308	Economy	7200.00
0005435697010	16308	Economy	7200.00
0005435697094	16308	Economy	7200.00
0005435697046	16308	Economy	7200.00
0005435697073	16308	Economy	7200.00
0005435935043	16308	Economy	7200.00
0005435697043	16308	Economy	7200.00
0005435696973	16308	Economy	7200.00
0005435697040	16308	Economy	7200.00
0005435697081	16308	Economy	7200.00
0005435697063	16308	Economy	7200.00
0005435916168	16308	Economy	7200.00
0005435916167	16308	Economy	7200.00
0005435697101	16308	Economy	7200.00
0005435696983	16308	Economy	7200.00
0005434950485	16308	Economy	7200.00
0005435697184	16308	Economy	7200.00
0005435916169	16308	Economy	7200.00
0005435697064	16308	Economy	7200.00
0005434950484	16308	Economy	7200.00
0005435697125	16308	Economy	7200.00
0005435697005	16308	Economy	7200.00
0005434950489	16308	Economy	7200.00
0005435697183	16308	Economy	7200.00
0005435697139	16308	Economy	7200.00
0005435696950	16308	Economy	7200.00
0005435697042	16308	Economy	7200.00
0005435697044	16308	Economy	7200.00
0005435697011	16308	Economy	7200.00
0005435697138	16308	Economy	7200.00
0005435697047	16308	Economy	7200.00
0005434606828	3990	Economy	21300.00
0005432607568	3990	Economy	21300.00
0005435842321	3990	Economy	21300.00
0005434606830	3990	Economy	19300.00
0005432609731	3990	Economy	19300.00
0005432607566	3990	Economy	19300.00
0005433519458	3990	Economy	19300.00
0005435904889	3990	Economy	19300.00
0005434604897	3990	Economy	19300.00
0005432609732	3990	Economy	19300.00
0005434604898	3990	Economy	19300.00
0005435842320	3990	Economy	19300.00
0005434606829	3990	Economy	19300.00
0005435904894	3990	Economy	19300.00
0005433519462	3990	Economy	19300.00
0005433519457	3990	Economy	19300.00
0005435842322	3990	Economy	19300.00
0005433519456	3990	Economy	19300.00
0005432609733	3990	Economy	19300.00
0005434604899	3990	Economy	19300.00
0005432607567	3990	Economy	19300.00
0005433519459	3990	Economy	19300.00
0005435853591	3990	Economy	19300.00
0005433519461	3990	Economy	19300.00
0005432609730	3990	Economy	19300.00
0005433519460	3990	Economy	19300.00
0005434606779	22077	Economy	21300.00
0005433519432	22077	Economy	19300.00
0005434606788	22077	Economy	19300.00
0005434606799	22077	Economy	19300.00
0005434606793	22077	Economy	19300.00
0005434606798	22077	Economy	19300.00
0005433519418	22077	Economy	19300.00
0005434606784	22077	Economy	19300.00
0005433519421	22077	Economy	19300.00
0005433519420	22077	Economy	19300.00
0005434606785	22077	Economy	19300.00
0005434606790	22077	Economy	19300.00
0005435853612	22077	Economy	19300.00
0005435853613	22077	Economy	19300.00
0005434606781	22077	Economy	19300.00
0005433519417	22077	Economy	19300.00
0005434606780	22077	Economy	19300.00
0005433519414	22077	Economy	19300.00
0005435628726	735	Economy	3700.00
0005433348934	735	Economy	3700.00
0005433348954	735	Economy	3700.00
0005435628725	735	Economy	3700.00
0005433348944	735	Economy	3700.00
0005435628724	735	Economy	3700.00
0005433348909	735	Economy	3700.00
0005435628700	15894	Economy	3700.00
0005433348989	15894	Economy	3700.00
0005435628708	15894	Economy	3700.00
0005433348990	15894	Economy	3700.00
0005433348992	15894	Economy	3700.00
0005435628695	15894	Economy	3700.00
0005433348991	15894	Economy	3700.00
0005433348993	15894	Economy	3700.00
0005434445244	17233	Economy	7100.00
0005433158108	17233	Economy	7100.00
0005433159289	17233	Economy	7100.00
0005433158107	17233	Economy	7100.00
0005434446518	17233	Economy	7100.00
0005434445245	17233	Economy	7100.00
0005433159296	17233	Economy	7100.00
0005434445246	17233	Economy	7100.00
0005433159297	17233	Economy	7100.00
0005433159316	17614	Economy	7100.00
0005433159315	17614	Economy	7100.00
0005433159314	17614	Economy	7100.00
0005435383101	7891	Economy	5900.00
0005435132885	7891	Economy	5900.00
0005435132878	7891	Economy	5400.00
0005435383105	7891	Economy	5400.00
0005435132884	7891	Economy	5400.00
0005435132888	7891	Economy	5400.00
0005435383108	7891	Economy	5400.00
0005435383100	7891	Economy	5400.00
0005435132883	7891	Economy	5400.00
0005435383090	7891	Economy	5400.00
0005435383122	7891	Economy	5400.00
0005435132882	7891	Economy	5400.00
0005435383123	7891	Economy	5400.00
0005435383089	7891	Economy	5400.00
0005435383119	7891	Economy	5400.00
0005435132881	7891	Economy	5400.00
0005435383109	7891	Economy	5400.00
0005435383117	7891	Economy	5400.00
0005435132887	7891	Economy	5400.00
0005435132886	7891	Economy	5400.00
0005435132879	7891	Economy	5400.00
0005435132880	7891	Economy	5400.00
0005435383151	33117	Economy	5900.00
0005435383152	33117	Economy	5900.00
0005435383148	33117	Economy	5400.00
0005435132781	33117	Economy	5400.00
0005435383153	33117	Economy	5400.00
0005435132813	33117	Economy	5400.00
0005435132812	33117	Economy	5400.00
0005435132760	33117	Economy	5400.00
0005435132782	33117	Economy	5400.00
0005435132784	33117	Economy	5400.00
0005435132783	33117	Economy	5400.00
0005435132814	33117	Economy	5400.00
0005435383150	33117	Economy	5400.00
0005435383149	33117	Economy	5400.00
0005435132788	33117	Economy	5400.00
0005435132815	33117	Economy	5400.00
0005435160304	7519	Economy	13800.00
0005435160299	7519	Economy	13800.00
0005435160305	7519	Economy	13800.00
0005435390178	7519	Economy	12500.00
0005435160306	7519	Economy	12500.00
0005435160302	7519	Economy	12500.00
0005435390172	7519	Economy	12500.00
0005435160300	7519	Economy	12500.00
0005435390182	7519	Economy	12500.00
0005435160308	7519	Economy	12500.00
0005435390179	7519	Economy	12500.00
0005435390155	7519	Economy	12500.00
0005435160301	7519	Economy	12500.00
0005435390175	7519	Economy	12500.00
0005435160303	7519	Economy	12500.00
0005435160307	7519	Economy	12500.00
0005435160183	29561	Economy	13800.00
0005435390238	29561	Economy	12500.00
0005435160163	29561	Economy	12500.00
0005435390243	29561	Economy	12500.00
0005435160218	29561	Economy	12500.00
0005435160164	29561	Economy	12500.00
0005435160205	29561	Economy	12500.00
0005435160203	29561	Economy	12500.00
0005435160233	29561	Economy	12500.00
0005435160228	29561	Economy	12500.00
0005435390239	29561	Economy	12500.00
0005435160184	29561	Economy	12500.00
0005435390244	29561	Economy	12500.00
0005435390240	29561	Economy	12500.00
0005435390241	29561	Economy	12500.00
0005435390242	29561	Economy	12500.00
0005435160187	29561	Economy	12500.00
0005435160202	29561	Economy	12500.00
0005432394075	18483	Economy	4900.00
0005435178992	18483	Economy	4900.00
0005432394055	18483	Economy	4900.00
0005435178496	18483	Economy	4900.00
0005432398170	18483	Economy	4900.00
0005432398169	18483	Economy	4900.00
0005432394057	18483	Economy	4900.00
0005432394058	18483	Economy	4900.00
0005432394056	18483	Economy	4900.00
0005435178495	18483	Economy	4900.00
0005435178497	18483	Economy	4900.00
0005432394076	18483	Economy	4900.00
0005432400121	27160	Economy	4900.00
0005432398193	27160	Economy	4900.00
0005432400119	27160	Economy	4900.00
0005432398192	27160	Economy	4900.00
0005432400120	27160	Economy	4900.00
0005435178480	27160	Economy	4900.00
0005435178490	27160	Economy	4900.00
0005432400118	27160	Economy	4900.00
0005432398194	27160	Economy	4900.00
0005432398195	27160	Economy	4900.00
0005435179388	27160	Economy	4900.00
0005434191266	9795	Economy	4400.00
0005434191259	9795	Economy	4400.00
0005432663037	21843	Business	92200.00
0005432661915	21843	Business	92200.00
0005432664131	21843	Business	92200.00
0005432664128	21843	Business	92200.00
0005432664138	21843	Business	92200.00
0005432663033	21843	Business	92200.00
0005432664130	21843	Business	92200.00
0005432663032	21843	Economy	30700.00
0005432661922	21843	Economy	30700.00
0005432661917	21843	Economy	30700.00
0005432661921	21843	Economy	30700.00
0005432661926	21843	Economy	30700.00
0005432661920	21843	Economy	30700.00
0005432664133	21843	Economy	33800.00
0005432664129	21843	Economy	33800.00
0005432663030	21843	Economy	30700.00
0005432664136	21843	Economy	30700.00
0005432663034	21843	Economy	30700.00
0005432661918	21843	Economy	30700.00
0005432663038	21843	Economy	30700.00
0005432664135	21843	Economy	30700.00
0005432664139	21843	Economy	30700.00
0005432663039	21843	Economy	30700.00
0005432661913	21843	Economy	30700.00
0005432663040	21843	Economy	30700.00
0005432663035	21843	Economy	30700.00
0005432661927	21843	Economy	30700.00
0005432661919	21843	Economy	30700.00
0005432664141	21843	Economy	30700.00
0005432664134	21843	Economy	30700.00
0005432663029	21843	Economy	30700.00
0005432663028	21843	Economy	30700.00
0005432661924	21843	Economy	30700.00
0005432663031	21843	Economy	30700.00
0005432664140	21843	Economy	30700.00
0005432663027	21843	Economy	30700.00
0005432663036	21843	Economy	30700.00
0005432661923	21843	Economy	30700.00
0005432661914	21843	Economy	30700.00
0005432664132	21843	Economy	30700.00
0005432664137	21843	Economy	30700.00
0005432664142	21843	Economy	30700.00
0005432661925	21843	Economy	30700.00
0005432661916	21843	Economy	30700.00
0005434504161	6552	Business	48400.00
0005434504176	6552	Business	48400.00
0005434504177	6552	Business	48400.00
0005434504175	6552	Business	48400.00
0005434504164	6552	Business	48400.00
0005434504170	6552	Business	48400.00
0005435103938	6552	Economy	16100.00
0005434504166	6552	Economy	16100.00
0005434504154	6552	Economy	16100.00
0005434504157	6552	Economy	16100.00
0005434504169	6552	Economy	16100.00
0005435103941	6552	Economy	16100.00
0005434504146	6552	Economy	16100.00
0005434504181	6552	Economy	17800.00
0005434504155	6552	Economy	17800.00
0005434504160	6552	Economy	17800.00
0005434504149	6552	Economy	16100.00
0005434504178	6552	Economy	16100.00
0005434504159	6552	Economy	16100.00
0005435103935	6552	Economy	16100.00
0005434504148	6552	Economy	16100.00
0005434504150	6552	Economy	16100.00
0005434504184	6552	Economy	16100.00
0005434504183	6552	Economy	16100.00
0005434504158	6552	Economy	16100.00
0005434504156	6552	Economy	16100.00
0005434504172	6552	Economy	16100.00
0005434504147	6552	Economy	16100.00
0005434504179	6552	Economy	16100.00
0005434504171	6552	Economy	16100.00
0005434504182	6552	Economy	16100.00
0005435103937	6552	Economy	16100.00
0005434504174	6552	Economy	16100.00
0005434504144	6552	Economy	16100.00
0005434504180	6552	Economy	16100.00
0005435103936	6552	Economy	16100.00
0005435103933	6552	Economy	16100.00
0005434504163	6552	Economy	16100.00
0005435103940	6552	Economy	16100.00
0005435103934	6552	Economy	16100.00
0005434504145	6552	Economy	16100.00
0005435103939	6552	Economy	16100.00
0005434504162	6552	Economy	16100.00
0005434504153	6552	Economy	16100.00
0005434504167	6552	Economy	16100.00
0005434504173	6552	Economy	16100.00
0005434504168	6552	Economy	16100.00
0005434504165	6552	Economy	16100.00
0005434504152	6552	Economy	16100.00
0005434504151	6552	Economy	16100.00
0005434503694	22673	Business	48400.00
0005435103838	22673	Business	48400.00
0005434503655	22673	Business	48400.00
0005434503687	22673	Business	48400.00
0005434503859	22673	Business	48400.00
0005434503693	22673	Business	48400.00
0005434503748	22673	Economy	16100.00
0005434503855	22673	Economy	16100.00
0005434503731	22673	Economy	16100.00
0005435103846	22673	Economy	16100.00
0005434503699	22673	Economy	16100.00
0005434503810	22673	Economy	16100.00
0005434503763	22673	Economy	16100.00
0005435103849	22673	Economy	16100.00
0005435103847	22673	Economy	16100.00
0005435103830	22673	Economy	17800.00
0005434503656	22673	Economy	17800.00
0005434503803	22673	Economy	17800.00
0005434503956	22673	Economy	16100.00
0005435103832	22673	Economy	16100.00
0005435103828	22673	Economy	16100.00
0005434503789	22673	Economy	16100.00
0005434503889	22673	Economy	16100.00
0005434503824	22673	Economy	16100.00
0005434503800	22673	Economy	16100.00
0005434503686	22673	Economy	16100.00
0005434503594	22673	Economy	16100.00
0005435103837	22673	Economy	16100.00
0005434503823	22673	Economy	16100.00
0005434503920	22673	Economy	16100.00
0005434503730	22673	Economy	16100.00
0005434503703	22673	Economy	16100.00
0005435103848	22673	Economy	16100.00
0005435103829	22673	Economy	16100.00
0005434503685	22673	Economy	16100.00
0005434503675	22673	Economy	16100.00
0005434503657	22673	Economy	16100.00
0005434503845	22673	Economy	16100.00
0005435103840	22673	Economy	16100.00
0005434503709	22673	Economy	16100.00
0005434503595	22673	Economy	16100.00
0005434503858	22673	Economy	16100.00
0005435103836	22673	Economy	16100.00
0005434503872	22673	Economy	16100.00
0005434503928	22673	Economy	16100.00
0005434503792	22673	Economy	16100.00
0005434503844	22673	Economy	16100.00
0005434503682	22673	Economy	16100.00
0005434503801	22673	Economy	16100.00
0005434503708	22673	Economy	16100.00
0005435103831	22673	Economy	16100.00
0005434503605	22673	Economy	16100.00
0005434503809	22673	Economy	16100.00
0005434503704	22673	Economy	16100.00
0005434503606	22673	Economy	16100.00
0005435103823	22673	Economy	16100.00
0005435653053	1689	Business	50000.00
0005435653052	1689	Business	50000.00
0005435653089	1689	Business	50000.00
0005435653060	1689	Business	50000.00
0005435653068	1689	Business	50000.00
0005435653050	1689	Business	50000.00
0005435653088	1689	Business	50000.00
0005433367582	1689	Business	50000.00
0005433367778	1689	Business	50000.00
0005435653042	1689	Business	50000.00
0005433367631	1689	Business	50000.00
0005435653082	1689	Economy	16700.00
0005435653046	1689	Economy	16700.00
0005433367567	1689	Economy	16700.00
0005435653071	1689	Economy	16700.00
0005435653067	1689	Economy	16700.00
0005435653085	1689	Economy	16700.00
0005433367422	1689	Economy	16700.00
0005435653062	1689	Economy	16700.00
0005435653066	1689	Economy	16700.00
0005433367581	1689	Economy	16700.00
0005433367447	1689	Economy	18300.00
0005433367566	1689	Economy	18300.00
0005435653072	1689	Economy	18300.00
0005433367569	1689	Economy	18300.00
0005435653077	1689	Economy	18300.00
0005433367469	1689	Economy	16700.00
0005435653047	1689	Economy	16700.00
0005435653054	1689	Economy	16700.00
0005435653075	1689	Economy	16700.00
0005433367829	1689	Economy	16700.00
0005433367580	1689	Economy	16700.00
0005435653083	1689	Economy	16700.00
0005433367737	1689	Economy	16700.00
0005433367583	1689	Economy	16700.00
0005435653069	1689	Economy	16700.00
0005435653063	1689	Economy	16700.00
0005435653059	1689	Economy	16700.00
0005435653093	1689	Economy	16700.00
0005435653079	1689	Economy	16700.00
0005435653092	1689	Economy	16700.00
0005435653086	1689	Economy	16700.00
0005435653045	1689	Economy	16700.00
0005435653056	1689	Economy	16700.00
0005433367630	1689	Economy	16700.00
0005435653070	1689	Economy	16700.00
0005435653080	1689	Economy	16700.00
0005435653044	1689	Economy	16700.00
0005433367577	1689	Economy	16700.00
0005433367517	1689	Economy	16700.00
0005435653091	1689	Economy	16700.00
0005433367777	1689	Economy	16700.00
0005435653087	1689	Economy	16700.00
0005435653084	1689	Economy	16700.00
0005435653061	1689	Economy	16700.00
0005435653090	1689	Economy	16700.00
0005435653057	1689	Economy	16700.00
0005433367578	1689	Economy	16700.00
0005435653041	1689	Economy	16700.00
0005435653064	1689	Economy	16700.00
0005435653058	1689	Economy	16700.00
0005435653065	1689	Economy	16700.00
0005433367632	1689	Economy	16700.00
0005435653049	1689	Economy	16700.00
0005433367629	1689	Economy	16700.00
0005435653081	1689	Economy	16700.00
0005435653078	1689	Economy	16700.00
0005433367564	1689	Economy	16700.00
0005435653076	1689	Economy	16700.00
0005435653073	1689	Economy	16700.00
0005433367399	1689	Economy	16700.00
0005433367526	1689	Economy	16700.00
0005435653055	1689	Economy	16700.00
0005433367828	1689	Economy	16700.00
0005433367625	1689	Economy	16700.00
0005433367638	1689	Economy	16700.00
0005433367513	1689	Economy	16700.00
0005433367622	1689	Economy	16700.00
0005433367477	1689	Economy	16700.00
0005433367514	1689	Economy	16700.00
0005435653051	1689	Economy	16700.00
0005433367736	1689	Economy	16700.00
0005433367626	1689	Economy	16700.00
0005435653074	1689	Economy	16700.00
0005435653043	1689	Economy	16700.00
0005435653048	1689	Economy	16700.00
0005435652619	21697	Business	50000.00
0005433367907	21697	Business	50000.00
0005433367896	21697	Business	50000.00
0005435652415	21697	Business	50000.00
0005433367876	21697	Business	50000.00
0005435652628	21697	Business	50000.00
0005435652545	21697	Business	50000.00
0005435652588	21697	Business	50000.00
0005433367883	21697	Business	50000.00
0005433367890	21697	Business	50000.00
0005435652474	21697	Business	50000.00
0005435652578	21697	Economy	16700.00
0005435652670	21697	Economy	16700.00
0005433367886	21697	Economy	16700.00
0005433367889	21697	Economy	16700.00
0005433367897	21697	Economy	16700.00
0005435652579	21697	Economy	16700.00
0005435652540	21697	Economy	16700.00
0005433367901	21697	Economy	16700.00
0005433367908	21697	Economy	16700.00
0005435652632	21697	Economy	18300.00
0005435652567	21697	Economy	18300.00
0005435652550	21697	Economy	18300.00
0005433367906	21697	Economy	18300.00
0005435652631	21697	Economy	18300.00
0005435652600	21697	Economy	16700.00
0005435652553	21697	Economy	16700.00
0005435652612	21697	Economy	16700.00
0005435652599	21697	Economy	16700.00
0005433367884	21697	Economy	16700.00
0005435652495	21697	Economy	16700.00
0005435652657	21697	Economy	16700.00
0005433367880	21697	Economy	16700.00
0005435652416	21697	Economy	16700.00
0005433367895	21697	Economy	16700.00
0005433367882	21697	Economy	16700.00
0005435652564	21697	Economy	16700.00
0005435652602	21697	Economy	16700.00
0005435652601	21697	Economy	16700.00
0005435652723	21697	Economy	16700.00
0005435652574	21697	Economy	16700.00
0005435652616	21697	Economy	16700.00
0005433367905	21697	Economy	16700.00
0005435652724	21697	Economy	16700.00
0005433367902	21697	Economy	16700.00
0005433367874	21697	Economy	16700.00
0005433367893	21697	Economy	16700.00
0005433367871	21697	Economy	16700.00
0005433367894	21697	Economy	16700.00
0005435652488	21697	Economy	16700.00
0005435652514	21697	Economy	16700.00
0005435652613	21697	Economy	16700.00
0005435652507	21697	Economy	16700.00
0005433367903	21697	Economy	16700.00
0005433367879	21697	Economy	16700.00
0005435652635	21697	Economy	16700.00
0005435652558	21697	Economy	16700.00
0005435652506	21697	Economy	16700.00
0005433367891	21697	Economy	16700.00
0005435652570	21697	Economy	16700.00
0005433367881	21697	Economy	16700.00
0005435652513	21697	Economy	16700.00
0005435652615	21697	Economy	16700.00
0005435652565	21697	Economy	16700.00
0005433367898	21697	Economy	16700.00
0005435652636	21697	Economy	16700.00
0005433367885	21697	Economy	16700.00
0005433367872	21697	Economy	16700.00
0005433367899	21697	Economy	16700.00
0005435652611	21697	Economy	16700.00
0005433367873	21697	Economy	16700.00
0005433367887	21697	Economy	16700.00
0005433367892	21697	Economy	16700.00
0005433367900	21697	Economy	16700.00
0005435652697	21697	Economy	16700.00
0005433367904	21697	Economy	16700.00
0005435652718	21697	Economy	16700.00
0005435652580	21697	Economy	16700.00
0005435652637	21697	Economy	16700.00
0005435652626	21697	Economy	16700.00
0005433367877	21697	Economy	16700.00
0005435652475	21697	Economy	16700.00
0005435652425	21697	Economy	16700.00
0005433367875	21697	Economy	16700.00
0005433367888	21697	Economy	16700.00
0005435652337	21697	Economy	16700.00
0005433367878	21697	Economy	16700.00
0005435627118	12230	Economy	11200.00
0005433985934	4186	Business	21500.00
0005433985950	4186	Business	21500.00
0005435788772	4186	Business	21500.00
0005433985935	4186	Business	21500.00
0005433985965	4186	Business	21500.00
0005433985966	4186	Business	21500.00
0005433985928	4186	Business	21500.00
0005433985981	4186	Business	21500.00
0005433985954	4186	Business	21500.00
0005433985963	4186	Business	21500.00
0005433985958	4186	Economy	7200.00
0005433985944	4186	Economy	7200.00
0005433985983	4186	Economy	7200.00
0005433985979	4186	Economy	7200.00
0005433985974	4186	Economy	7200.00
0005433985970	4186	Economy	7900.00
0005433985957	4186	Economy	7900.00
0005433985977	4186	Economy	7900.00
0005433985971	4186	Economy	7200.00
0005433985969	4186	Economy	7200.00
0005433985951	4186	Economy	7200.00
0005433985960	4186	Economy	7200.00
0005433985939	4186	Economy	7200.00
0005433985964	4186	Economy	7200.00
0005433985961	4186	Economy	7200.00
0005433985942	4186	Economy	7200.00
0005433985949	4186	Economy	7200.00
0005433985933	4186	Economy	7200.00
0005433985931	4186	Economy	7200.00
0005433985943	4186	Economy	7200.00
0005433985945	4186	Economy	7200.00
0005433985952	4186	Economy	7200.00
0005433985938	4186	Economy	7200.00
0005433985948	4186	Economy	7200.00
0005433985972	4186	Economy	7200.00
0005433985967	4186	Economy	7200.00
0005433985937	4186	Economy	7200.00
0005433985941	4186	Economy	7200.00
0005433985976	4186	Economy	7200.00
0005433985968	4186	Economy	7200.00
0005433985982	4186	Economy	7200.00
0005433985936	4186	Economy	7200.00
0005433985932	4186	Economy	7200.00
0005433985955	4186	Economy	7200.00
0005433985930	4186	Economy	7200.00
0005433985956	4186	Economy	7200.00
0005435788771	4186	Economy	7200.00
0005433985947	4186	Economy	7200.00
0005433985940	4186	Economy	7200.00
0005433985978	4186	Economy	7200.00
0005433985927	4186	Economy	7200.00
0005435788770	4186	Economy	7200.00
0005433985980	4186	Economy	7200.00
0005433985973	4186	Economy	7200.00
0005433985953	4186	Economy	7200.00
0005433985975	4186	Economy	7200.00
0005433985959	4186	Economy	7200.00
0005433985929	4186	Economy	7200.00
0005433985962	4186	Economy	7200.00
0005433985946	4186	Economy	7200.00
0005433985353	25661	Business	21500.00
0005433985469	25661	Business	21500.00
0005433985390	25661	Business	21500.00
0005433985447	25661	Business	21500.00
0005433985478	25661	Business	21500.00
0005433985371	25661	Economy	7200.00
0005433985386	25661	Economy	7200.00
0005433985448	25661	Economy	7200.00
0005433985356	25661	Economy	7200.00
0005433985385	25661	Economy	7900.00
0005433985489	25661	Economy	7900.00
0005433985327	25661	Economy	7200.00
0005435788755	25661	Economy	7200.00
0005433985310	25661	Economy	7200.00
0005435788754	25661	Economy	7200.00
0005433985388	25661	Economy	7200.00
0005433985391	25661	Economy	7200.00
0005433985486	25661	Economy	7200.00
0005433985485	25661	Economy	7200.00
0005433985429	25661	Economy	7200.00
0005433985328	25661	Economy	7200.00
0005433985498	25661	Economy	7200.00
0005433985444	25661	Economy	7200.00
0005433985425	25661	Economy	7200.00
0005433985427	25661	Economy	7200.00
0005433985192	25661	Economy	7200.00
0005433985362	25661	Economy	7200.00
0005433985484	25661	Economy	7200.00
0005433985457	25661	Economy	7200.00
0005433985387	25661	Economy	7200.00
0005433985487	25661	Economy	7200.00
0005433985488	25661	Economy	7200.00
0005433985416	25661	Economy	7200.00
0005435788749	25661	Economy	7200.00
0005433985468	25661	Economy	7200.00
0005433985384	25661	Economy	7200.00
0005433985428	25661	Economy	7200.00
0005433985193	25661	Economy	7200.00
0005433985456	25661	Economy	7200.00
0005433985455	25661	Economy	7200.00
0005433985357	25661	Economy	7200.00
0005434190383	9032	Economy	26000.00
0005434516079	9032	Economy	26000.00
0005434516075	9032	Economy	26000.00
0005434190377	9032	Economy	23600.00
0005434516074	9032	Economy	23600.00
0005434190381	9032	Economy	23600.00
0005434516080	9032	Economy	23600.00
0005434516077	9032	Economy	23600.00
0005434516078	9032	Economy	23600.00
0005434190378	9032	Economy	23600.00
0005434190379	9032	Economy	23600.00
0005434516076	9032	Economy	23600.00
0005434190382	9032	Economy	23600.00
0005434190385	9032	Economy	23600.00
0005434190395	9032	Economy	23600.00
0005434190384	9032	Economy	23600.00
0005432663024	17861	Business	18000.00
0005432655404	17861	Business	18000.00
0005432660797	17861	Business	18000.00
0005432869530	17861	Business	18000.00
0005432655388	17861	Business	18000.00
0005432655411	17861	Business	18000.00
0005432666376	17861	Business	18000.00
0005432665259	17861	Business	18000.00
0005432661899	17861	Economy	6000.00
0005432660803	17861	Economy	6000.00
0005432660800	17861	Economy	6000.00
0005432665258	17861	Economy	6000.00
0005432655403	17861	Economy	6000.00
0005432655426	17861	Economy	6000.00
0005432655409	17861	Economy	6600.00
0005432664117	17861	Economy	6600.00
0005432869526	17861	Economy	6600.00
0005432655402	17861	Economy	6600.00
0005432659700	17861	Economy	6000.00
0005432661898	17861	Economy	6000.00
0005432657416	17861	Economy	6000.00
0005432655399	17861	Economy	6000.00
0005432657423	17861	Economy	6000.00
0005432660801	17861	Economy	6000.00
0005432660799	17861	Economy	6000.00
0005432663017	17861	Economy	6000.00
0005432661901	17861	Economy	6000.00
0005432663022	17861	Economy	6000.00
0005432663021	17861	Economy	6000.00
0005432655428	17861	Economy	6000.00
0005432869528	17861	Economy	6000.00
0005432655408	17861	Economy	6000.00
0005432667439	17861	Economy	6000.00
0005432869529	17861	Economy	6000.00
0005434151707	17861	Economy	6000.00
0005432661908	17861	Economy	6000.00
0005432869532	17861	Economy	6000.00
0005432667434	17861	Economy	6000.00
0005432655398	17861	Economy	6000.00
0005432658563	17861	Economy	6000.00
0005432657415	17861	Economy	6000.00
0005432663020	17861	Economy	6000.00
0005432869531	17861	Economy	6000.00
0005432655484	17861	Economy	6000.00
0005432655427	17861	Economy	6000.00
0005432655464	17861	Economy	6000.00
0005432655407	17861	Economy	6000.00
0005432667443	17861	Economy	6000.00
0005432655458	17861	Economy	6000.00
0005432655443	17861	Economy	6000.00
0005432657425	17861	Economy	6000.00
0005432665266	17861	Economy	6000.00
0005432665265	17861	Economy	6000.00
0005432869527	17861	Economy	6000.00
0005432657424	17861	Economy	6000.00
0005432869451	26305	Business	18000.00
0005432869450	26305	Business	18000.00
0005432665272	26305	Business	18000.00
0005432667451	26305	Business	18000.00
0005432655517	26305	Business	18000.00
0005432666386	26305	Economy	6000.00
0005432655512	26305	Economy	6000.00
0005432660815	26305	Economy	6000.00
0005432655515	26305	Economy	6000.00
0005432655518	26305	Economy	6000.00
0005432660816	26305	Economy	6000.00
0005432658588	26305	Economy	6600.00
0005432655516	26305	Economy	6000.00
0005432655511	26305	Economy	6000.00
0005434151681	26305	Economy	6000.00
0005432655509	26305	Economy	6000.00
0005432655520	26305	Economy	6000.00
0005432659703	26305	Economy	6000.00
0005432659704	26305	Economy	6000.00
0005434151682	26305	Economy	6000.00
0005432655514	26305	Economy	6000.00
0005432658589	26305	Economy	6000.00
0005434151677	26305	Economy	6000.00
0005432666385	26305	Economy	6000.00
0005434151676	26305	Economy	6000.00
0005432655519	26305	Economy	6000.00
0005432666387	26305	Economy	6000.00
0005432657446	26305	Economy	6000.00
0005432869449	26305	Economy	6000.00
0005432655513	26305	Economy	6000.00
0005434151680	26305	Economy	6000.00
0005432657445	26305	Economy	6000.00
0005432655510	26305	Economy	6000.00
0005432869418	26305	Economy	6000.00
0005432667452	26305	Economy	6000.00
0005432328690	3111	Business	16100.00
0005432328715	3111	Business	16100.00
0005433438878	3111	Business	16100.00
0005432328695	3111	Business	16100.00
0005432328729	3111	Business	16100.00
0005432328722	3111	Business	16100.00
0005432328723	3111	Business	16100.00
0005432328692	3111	Business	16100.00
0005432328694	3111	Business	16100.00
0005432328732	3111	Business	16100.00
0005432328734	3111	Economy	5400.00
0005432328711	3111	Economy	5400.00
0005432328724	3111	Economy	5400.00
0005432328698	3111	Economy	5400.00
0005432328720	3111	Economy	5400.00
0005432328721	3111	Economy	5400.00
0005432328719	3111	Economy	5400.00
0005433438879	3111	Economy	5900.00
0005432328697	3111	Economy	5900.00
0005432328716	3111	Economy	5900.00
0005432328725	3111	Economy	5400.00
0005432328704	3111	Economy	5400.00
0005432328706	3111	Economy	5400.00
0005432328717	3111	Economy	5400.00
0005432905072	3111	Economy	5400.00
0005432905071	3111	Economy	5400.00
0005432905081	3111	Economy	5400.00
0005432328696	3111	Economy	5400.00
0005432328689	3111	Economy	5400.00
0005432328714	3111	Economy	5400.00
0005432287189	3111	Economy	5400.00
0005432287191	3111	Economy	5400.00
0005432287190	3111	Economy	5400.00
0005432328699	3111	Economy	5400.00
0005432287192	3111	Economy	5400.00
0005433438882	3111	Economy	5400.00
0005432328700	3111	Economy	5400.00
0005432328693	3111	Economy	5400.00
0005433438881	3111	Economy	5400.00
0005432328708	3111	Economy	5400.00
0005432328701	3111	Economy	5400.00
0005432328712	3111	Economy	5400.00
0005432328731	3111	Economy	5400.00
0005432328703	3111	Economy	5400.00
0005432328727	3111	Economy	5400.00
0005433438880	3111	Economy	5400.00
0005432328710	3111	Economy	5400.00
0005432328736	3111	Economy	5400.00
0005432328733	3111	Economy	5400.00
0005432328707	3111	Economy	5400.00
0005432328709	3111	Economy	5400.00
0005432328735	3111	Economy	5400.00
0005432328726	3111	Economy	5400.00
0005432287188	3111	Economy	5400.00
0005432328691	3111	Economy	5400.00
0005432328730	3111	Economy	5400.00
0005432328702	3111	Economy	5400.00
0005432328728	3111	Economy	5400.00
0005432328705	3111	Economy	5400.00
0005433438883	3111	Economy	5400.00
0005432328713	3111	Economy	5400.00
0005432328718	3111	Economy	5400.00
0005432328002	31109	Business	16100.00
0005432328313	31109	Business	16100.00
0005432905127	31109	Business	16100.00
0005432328289	31109	Business	16100.00
0005432328409	31109	Business	16100.00
0005432328260	31109	Business	16100.00
0005432328136	31109	Business	16100.00
0005432328259	31109	Business	16100.00
0005433438824	31109	Business	16100.00
0005432328267	31109	Business	16100.00
0005432327997	31109	Economy	5400.00
0005432328369	31109	Economy	5400.00
0005432328406	31109	Economy	5400.00
0005432328003	31109	Economy	5400.00
0005433438826	31109	Economy	5900.00
0005432054303	31109	Economy	5900.00
0005432327944	31109	Economy	5900.00
0005433438830	31109	Economy	5900.00
0005432328252	31109	Economy	5400.00
0005432328206	31109	Economy	5400.00
0005432328137	31109	Economy	5400.00
0005432328339	31109	Economy	5400.00
0005432328263	31109	Economy	5400.00
0005432328135	31109	Economy	5400.00
0005432328284	31109	Economy	5400.00
0005432328268	31109	Economy	5400.00
0005432328222	31109	Economy	5400.00
0005432328242	31109	Economy	5400.00
0005432328283	31109	Economy	5400.00
0005433438823	31109	Economy	5400.00
0005432054305	31109	Economy	5400.00
0005432054304	31109	Economy	5400.00
0005432328376	31109	Economy	5400.00
0005432328174	31109	Economy	5400.00
0005432328241	31109	Economy	5400.00
0005432328340	31109	Economy	5400.00
0005432328266	31109	Economy	5400.00
0005432905129	31109	Economy	5400.00
0005433438825	31109	Economy	5400.00
0005432328253	31109	Economy	5400.00
0005432328410	31109	Economy	5400.00
0005432328440	31109	Economy	5400.00
0005432328175	31109	Economy	5400.00
0005432905128	31109	Economy	5400.00
0005432328336	31109	Economy	5400.00
0005432328418	31109	Economy	5400.00
0005432328234	31109	Economy	5400.00
0005432328221	31109	Economy	5400.00
0005432328402	31109	Economy	5400.00
0005432905125	31109	Economy	5400.00
0005432905126	31109	Economy	5400.00
0005432328219	31109	Economy	5400.00
0005432328436	31109	Economy	5400.00
0005432328317	31109	Economy	5400.00
0005433438817	31109	Economy	5400.00
0005432328333	31109	Economy	5400.00
0005432328117	31109	Economy	5400.00
0005432328419	31109	Economy	5400.00
0005432328385	31109	Economy	5400.00
0005432328235	31109	Economy	5400.00
0005432328321	31109	Economy	5400.00
0005432328500	31109	Economy	5400.00
0005432328162	31109	Economy	5400.00
0005432146199	6194	Business	124600.00
0005435999256	6194	Business	124600.00
0005435487702	6194	Business	124600.00
0005434309738	6194	Business	124600.00
0005435487617	6194	Business	124600.00
0005435487486	6194	Business	124600.00
0005435999259	6194	Economy	41500.00
0005435999258	6194	Economy	41500.00
0005435999250	6194	Economy	41500.00
0005435999260	6194	Economy	41500.00
0005434309743	6194	Economy	41500.00
0005435487485	6194	Economy	41500.00
0005435296977	6194	Economy	41500.00
0005435487599	6194	Economy	41500.00
0005435297001	6194	Economy	41500.00
0005435487592	6194	Economy	41500.00
0005434309746	6194	Economy	41500.00
0005435487685	6194	Economy	41500.00
0005435999264	6194	Economy	45700.00
0005434309744	6194	Economy	45700.00
0005434309747	6194	Economy	45700.00
0005435999252	6194	Economy	41500.00
0005434309740	6194	Economy	41500.00
0005435999265	6194	Economy	41500.00
0005435999249	6194	Economy	41500.00
0005435487569	6194	Economy	41500.00
0005435297006	6194	Economy	41500.00
0005435999255	6194	Economy	41500.00
0005435487644	6194	Economy	41500.00
0005434309749	6194	Economy	41500.00
0005435999261	6194	Economy	41500.00
0005435999253	6194	Economy	41500.00
0005435487591	6194	Economy	41500.00
0005434309750	6194	Economy	41500.00
0005435487521	6194	Economy	41500.00
0005435999263	6194	Economy	41500.00
0005435487645	6194	Economy	41500.00
0005434309742	6194	Economy	41500.00
0005435999254	6194	Economy	41500.00
0005435487484	6194	Economy	41500.00
0005434309741	6194	Economy	41500.00
0005432146200	6194	Economy	41500.00
0005435487618	6194	Economy	41500.00
0005435487751	6194	Economy	41500.00
0005435297012	6194	Economy	41500.00
0005435487707	6194	Economy	41500.00
0005434309745	6194	Economy	41500.00
0005434309748	6194	Economy	41500.00
0005435487686	6194	Economy	41500.00
0005435487616	6194	Economy	41500.00
0005434309751	6194	Economy	41500.00
0005435999257	6194	Economy	41500.00
0005435999251	6194	Economy	41500.00
0005435487589	6194	Economy	41500.00
0005435999262	6194	Economy	41500.00
0005434309739	6194	Economy	41500.00
0005435296978	6194	Economy	41500.00
0005435487633	6194	Economy	41500.00
0005435487824	19543	Business	124600.00
0005435487828	19543	Business	124600.00
0005434309669	19543	Business	124600.00
0005434309626	19543	Business	124600.00
0005435999017	19543	Economy	41500.00
0005435297058	19543	Economy	41500.00
0005435487816	19543	Economy	41500.00
0005435487811	19543	Economy	41500.00
0005435487813	19543	Economy	41500.00
0005435487822	19543	Economy	41500.00
0005435999078	19543	Economy	41500.00
0005434309625	19543	Economy	41500.00
0005434309665	19543	Economy	41500.00
0005435999087	19543	Economy	41500.00
0005434309666	19543	Economy	41500.00
0005435999051	19543	Economy	41500.00
0005435487817	19543	Economy	41500.00
0005435999104	19543	Economy	41500.00
0005435999117	19543	Economy	41500.00
0005434309569	19543	Economy	41500.00
0005435487826	19543	Economy	41500.00
0005434309589	19543	Economy	45700.00
0005435487808	19543	Economy	41500.00
0005435487818	19543	Economy	41500.00
0005435297059	19543	Economy	41500.00
0005434309638	19543	Economy	41500.00
0005435487820	19543	Economy	41500.00
0005434309667	19543	Economy	41500.00
0005435487823	19543	Economy	41500.00
0005435487809	19543	Economy	41500.00
0005434309603	19543	Economy	41500.00
0005435999069	19543	Economy	41500.00
0005435487810	19543	Economy	41500.00
0005435999044	19543	Economy	41500.00
0005435999057	19543	Economy	41500.00
0005435487814	19543	Economy	41500.00
0005435297057	19543	Economy	41500.00
0005435487821	19543	Economy	41500.00
0005434309637	19543	Economy	41500.00
0005435487827	19543	Economy	41500.00
0005435999016	19543	Economy	41500.00
0005434309643	19543	Economy	41500.00
0005435487815	19543	Economy	41500.00
0005435487829	19543	Economy	41500.00
0005434309668	19543	Economy	41500.00
0005435487812	19543	Economy	41500.00
0005435487819	19543	Economy	41500.00
0005435297061	19543	Economy	41500.00
0005435999010	19543	Economy	41500.00
0005435487825	19543	Economy	41500.00
0005435999015	19543	Economy	41500.00
0005435999045	19543	Economy	41500.00
0005435297063	19543	Economy	41500.00
0005435297060	19543	Economy	41500.00
0005435297062	19543	Economy	41500.00
0005433186077	1550	Business	86000.00
0005435517919	1550	Business	86000.00
0005435502326	1550	Business	86000.00
0005435502309	1550	Business	86000.00
0005434565920	1550	Business	86000.00
0005435502314	1550	Business	86000.00
0005434565917	1550	Business	86000.00
0005434565914	1550	Business	86000.00
0005435502327	1550	Business	86000.00
0005435508374	1550	Business	86000.00
0005435502320	1550	Business	86000.00
0005435508369	1550	Economy	28700.00
0005435517924	1550	Economy	28700.00
0005435502312	1550	Economy	28700.00
0005433186058	1550	Economy	28700.00
0005434565911	1550	Economy	28700.00
0005433186049	1550	Economy	28700.00
0005435517927	1550	Economy	28700.00
0005435517922	1550	Economy	28700.00
0005435502322	1550	Economy	28700.00
0005435502324	1550	Economy	31500.00
0005435517920	1550	Economy	31500.00
0005433186078	1550	Economy	31500.00
0005435508371	1550	Economy	31500.00
0005433186064	1550	Economy	28700.00
0005435508377	1550	Economy	28700.00
0005434565915	1550	Economy	28700.00
0005435502328	1550	Economy	28700.00
0005435508368	1550	Economy	28700.00
0005433186006	1550	Economy	28700.00
0005435517918	1550	Economy	28700.00
0005435502321	1550	Economy	28700.00
0005435508370	1550	Economy	28700.00
0005435508378	1550	Economy	28700.00
0005435502316	1550	Economy	28700.00
0005435508367	1550	Economy	28700.00
0005433186050	1550	Economy	28700.00
0005433186074	1550	Economy	28700.00
0005433186051	1550	Economy	28700.00
0005435502318	1550	Economy	28700.00
0005434565922	1550	Economy	28700.00
0005435502325	1550	Economy	28700.00
0005435517926	1550	Economy	28700.00
0005435502310	1550	Economy	28700.00
0005435502315	1550	Economy	28700.00
0005435508376	1550	Economy	28700.00
0005433186044	1550	Economy	28700.00
0005434565924	1550	Economy	28700.00
0005435502313	1550	Economy	28700.00
0005435508375	1550	Economy	28700.00
0005435502330	1550	Economy	28700.00
0005435517923	1550	Economy	28700.00
0005433186007	1550	Economy	28700.00
0005435502329	1550	Economy	28700.00
0005435508372	1550	Economy	28700.00
0005433186066	1550	Economy	28700.00
0005435502323	1550	Economy	28700.00
0005432291930	1550	Economy	28700.00
0005435502319	1550	Economy	28700.00
0005433186063	1550	Economy	28700.00
0005435508373	1550	Economy	28700.00
0005433186057	1550	Economy	28700.00
0005434565923	1550	Economy	28700.00
0005433186072	1550	Economy	28700.00
0005435502317	1550	Economy	28700.00
0005434565918	1550	Economy	28700.00
0005434565921	1550	Economy	28700.00
0005434565919	1550	Economy	28700.00
0005434565916	1550	Economy	28700.00
0005435502311	1550	Economy	28700.00
0005434565913	1550	Economy	28700.00
0005434565912	1550	Economy	28700.00
0005435502308	1550	Economy	28700.00
0005435517921	1550	Economy	28700.00
0005432291931	1550	Economy	28700.00
0005435517925	1550	Economy	28700.00
0005435529083	20872	Business	86000.00
0005435529057	20872	Business	86000.00
0005434565790	20872	Business	86000.00
0005435529062	20872	Business	86000.00
0005435529085	20872	Business	86000.00
0005433186121	20872	Business	86000.00
0005435529086	20872	Business	86000.00
0005435502171	20872	Business	86000.00
0005434565764	20872	Business	86000.00
0005434565814	20872	Business	86000.00
0005435502046	20872	Economy	28700.00
0005435529019	20872	Economy	28700.00
0005435529023	20872	Economy	28700.00
0005435502114	20872	Economy	28700.00
0005435502149	20872	Economy	28700.00
0005435545640	20872	Economy	28700.00
0005435529038	20872	Economy	28700.00
0005434565852	20872	Economy	31500.00
0005435528985	20872	Economy	31500.00
0005435545662	20872	Economy	28700.00
0005435528983	20872	Economy	28700.00
0005435528984	20872	Economy	28700.00
0005435502169	20872	Economy	28700.00
0005435502080	20872	Economy	28700.00
0005435529113	20872	Economy	28700.00
0005435545643	20872	Economy	28700.00
0005435545669	20872	Economy	28700.00
0005434565772	20872	Economy	28700.00
0005433186118	20872	Economy	28700.00
0005435545651	20872	Economy	28700.00
0005434565853	20872	Economy	28700.00
0005435502105	20872	Economy	28700.00
0005433186124	20872	Economy	28700.00
0005434565776	20872	Economy	28700.00
0005433186117	20872	Economy	28700.00
0005435529040	20872	Economy	28700.00
0005435529112	20872	Economy	28700.00
0005435545661	20872	Economy	28700.00
0005435502161	20872	Economy	28700.00
0005435502094	20872	Economy	28700.00
0005435502070	20872	Economy	28700.00
0005433186122	20872	Economy	28700.00
0005433186123	20872	Economy	28700.00
0005435529084	20872	Economy	28700.00
0005435545615	20872	Economy	28700.00
0005435502081	20872	Economy	28700.00
0005435502033	20872	Economy	28700.00
0005435502071	20872	Economy	28700.00
0005435529028	20872	Economy	28700.00
0005435545614	20872	Economy	28700.00
0005435502170	20872	Economy	28700.00
0005435502167	20872	Economy	28700.00
0005435529000	20872	Economy	28700.00
0005435528947	20872	Economy	28700.00
0005434565878	20872	Economy	28700.00
0005435529065	20872	Economy	28700.00
0005435502131	20872	Economy	28700.00
0005435529041	20872	Economy	28700.00
0005435529001	20872	Economy	28700.00
0005435529064	20872	Economy	28700.00
0005435529022	20872	Economy	28700.00
0005433186119	20872	Economy	28700.00
0005435545660	20872	Economy	28700.00
0005435528986	20872	Economy	28700.00
0005433186120	20872	Economy	28700.00
0005435502130	20872	Economy	28700.00
0005435502072	20872	Economy	28700.00
0005435153745	3882	Economy	21600.00
0005435153746	3882	Economy	21600.00
0005435153743	3882	Economy	19700.00
0005435153744	3882	Economy	19700.00
0005435153742	3882	Economy	19700.00
0005435931581	3882	Economy	19700.00
0005435931559	3882	Economy	19700.00
0005435153747	3882	Economy	19700.00
0005435153740	3882	Economy	19700.00
0005435931582	3882	Economy	19700.00
0005435153741	3882	Economy	19700.00
0005435931578	3882	Economy	19700.00
0005435931580	3882	Economy	19700.00
0005435931568	3882	Economy	19700.00
0005435931565	3882	Economy	19700.00
0005435153673	21865	Economy	21600.00
0005435153690	21865	Economy	19700.00
0005435153689	21865	Economy	19700.00
0005435153670	21865	Economy	19700.00
0005435153691	21865	Economy	19700.00
0005435153693	21865	Economy	19700.00
0005435931603	21865	Economy	19700.00
0005435153692	21865	Economy	19700.00
0005435931602	21865	Economy	19700.00
0005435931601	21865	Economy	19700.00
0005435153688	21865	Economy	19700.00
0005435153672	21865	Economy	19700.00
0005435931600	21865	Economy	19700.00
0005435225514	7223	Economy	14300.00
0005432628850	7223	Economy	14300.00
0005432628853	7223	Economy	13000.00
0005432628845	7223	Economy	13000.00
0005432628851	7223	Economy	13000.00
0005435225510	7223	Economy	13000.00
0005432628852	7223	Economy	13000.00
0005432628857	7223	Economy	13000.00
0005432628854	7223	Economy	13000.00
0005432628856	7223	Economy	13000.00
0005435225499	7223	Economy	13000.00
0005435225509	7223	Economy	13000.00
0005432628846	7223	Economy	13000.00
0005432628849	7223	Economy	13000.00
0005432628847	7223	Economy	13000.00
0005432628855	7223	Economy	13000.00
0005432628844	7223	Economy	13000.00
0005432628848	7223	Economy	13000.00
0005435225498	7223	Economy	13000.00
0005435225507	7223	Economy	13000.00
0005435225508	7223	Economy	13000.00
0005435225505	7223	Economy	13000.00
0005432628711	28103	Economy	14300.00
0005432628729	28103	Economy	14300.00
0005432628661	28103	Economy	14300.00
0005432628734	28103	Economy	14300.00
0005435225589	28103	Economy	13000.00
0005432628761	28103	Economy	13000.00
0005432628752	28103	Economy	13000.00
0005435225585	28103	Economy	13000.00
0005435225586	28103	Economy	13000.00
0005432628720	28103	Economy	13000.00
0005435225590	28103	Economy	13000.00
0005432628763	28103	Economy	13000.00
0005432628704	28103	Economy	13000.00
0005432628790	28103	Economy	13000.00
0005432628728	28103	Economy	13000.00
0005432628753	28103	Economy	13000.00
0005432628716	28103	Economy	13000.00
0005435225583	28103	Economy	13000.00
0005435225582	28103	Economy	13000.00
0005432628782	28103	Economy	13000.00
0005432628705	28103	Economy	13000.00
0005435225584	28103	Economy	13000.00
0005432628735	28103	Economy	13000.00
0005432628755	28103	Economy	13000.00
0005435225587	28103	Economy	13000.00
0005435225588	28103	Economy	13000.00
0005432628783	28103	Economy	13000.00
0005435960049	8763	Economy	10500.00
0005435960051	8763	Economy	10500.00
0005434267906	8763	Economy	10500.00
0005434267915	8763	Economy	10500.00
0005434267907	8763	Economy	10500.00
0005435960050	8763	Economy	10500.00
0005434267895	8763	Economy	10500.00
0005435960052	8763	Economy	10500.00
0005434267916	8763	Economy	10500.00
0005434267917	8763	Economy	10500.00
0005434267952	15224	Economy	10500.00
0005434267949	15224	Economy	10500.00
0005434267950	15224	Economy	10500.00
0005435960008	15224	Economy	10500.00
0005435960004	15224	Economy	10500.00
0005434267951	15224	Economy	10500.00
0005432693044	1168	Business	115000.00
0005432693034	1168	Business	115000.00
0005432675133	1168	Business	115000.00
0005432693039	1168	Business	115000.00
0005432693038	1168	Business	115000.00
0005432693058	1168	Business	115000.00
0005432693032	1168	Business	115000.00
0005432693056	1168	Business	115000.00
0005432675135	1168	Economy	38300.00
0005432693061	1168	Economy	38300.00
0005432677568	1168	Economy	38300.00
0005432693059	1168	Economy	38300.00
0005432693035	1168	Economy	38300.00
0005432675136	1168	Economy	38300.00
0005432693049	1168	Economy	38300.00
0005432873253	1168	Economy	42200.00
0005432873252	1168	Economy	42200.00
0005432675134	1168	Economy	42200.00
0005432675132	1168	Economy	42200.00
0005432873235	1168	Economy	38300.00
0005432693041	1168	Economy	38300.00
0005432677570	1168	Economy	38300.00
0005432873205	1168	Economy	38300.00
0005432873221	1168	Economy	38300.00
0005432693053	1168	Economy	38300.00
0005432693042	1168	Economy	38300.00
0005432675140	1168	Economy	38300.00
0005432693033	1168	Economy	38300.00
0005432677571	1168	Economy	38300.00
0005432873251	1168	Economy	38300.00
0005432675138	1168	Economy	38300.00
0005432693046	1168	Economy	38300.00
0005432675130	1168	Economy	38300.00
0005432873234	1168	Economy	38300.00
0005432693048	1168	Economy	38300.00
0005432693054	1168	Economy	38300.00
0005432675141	1168	Economy	38300.00
0005432693040	1168	Economy	38300.00
0005432693052	1168	Economy	38300.00
0005432693037	1168	Economy	38300.00
0005432693060	1168	Economy	38300.00
0005432693043	1168	Economy	38300.00
0005432675129	1168	Economy	38300.00
0005432677569	1168	Economy	38300.00
0005432675142	1168	Economy	38300.00
0005432693045	1168	Economy	38300.00
0005432693063	1168	Economy	38300.00
0005432693055	1168	Economy	38300.00
0005432675137	1168	Economy	38300.00
0005432675131	1168	Economy	38300.00
0005432693051	1168	Economy	38300.00
0005432693050	1168	Economy	38300.00
0005432873220	1168	Economy	38300.00
0005432675139	1168	Economy	38300.00
0005432693036	1168	Economy	38300.00
0005432675127	1168	Economy	38300.00
0005432693062	1168	Economy	38300.00
0005432693057	1168	Economy	38300.00
0005432693047	1168	Economy	38300.00
0005432675128	1168	Economy	38300.00
0005432692780	17497	Business	115000.00
0005432692742	17497	Business	115000.00
0005432692920	17497	Business	115000.00
0005432692811	17497	Business	115000.00
0005432692669	17497	Business	115000.00
0005432692905	17497	Business	115000.00
0005432692872	17497	Business	115000.00
0005432692807	17497	Business	115000.00
0005432677525	17497	Business	115000.00
0005432692858	17497	Business	115000.00
0005432692834	17497	Business	115000.00
0005432692875	17497	Business	115000.00
0005432677552	17497	Economy	38300.00
0005432873291	17497	Economy	38300.00
0005432675005	17497	Economy	38300.00
0005432692717	17497	Economy	38300.00
0005432675041	17497	Economy	38300.00
0005432674981	17497	Economy	42200.00
0005432873296	17497	Economy	42200.00
0005432692763	17497	Economy	38300.00
0005432692656	17497	Economy	38300.00
0005432674984	17497	Economy	38300.00
0005432674986	17497	Economy	38300.00
0005432692824	17497	Economy	38300.00
0005432674985	17497	Economy	38300.00
0005432692749	17497	Economy	38300.00
0005432692642	17497	Economy	38300.00
0005432873292	17497	Economy	38300.00
0005432674980	17497	Economy	38300.00
0005432692795	17497	Economy	38300.00
0005432674999	17497	Economy	38300.00
0005432675033	17497	Economy	38300.00
0005432677524	17497	Economy	38300.00
0005432677553	17497	Economy	38300.00
0005432692748	17497	Economy	38300.00
0005432692876	17497	Economy	38300.00
0005432692702	17497	Economy	38300.00
0005432692692	17497	Economy	38300.00
0005432675030	17497	Economy	38300.00
0005432692815	17497	Economy	38300.00
0005432692816	17497	Economy	38300.00
0005432674997	17497	Economy	38300.00
0005432675040	17497	Economy	38300.00
0005432873293	17497	Economy	38300.00
0005432692833	17497	Economy	38300.00
0005432675042	17497	Economy	38300.00
0005432873295	17497	Economy	38300.00
0005432674996	17497	Economy	38300.00
0005432692691	17497	Economy	38300.00
0005432692835	17497	Economy	38300.00
0005432873294	17497	Economy	38300.00
0005434435184	1154	Economy	13900.00
0005433156687	1154	Economy	13900.00
0005434435186	1154	Economy	13900.00
0005434435177	1154	Economy	13900.00
0005434435179	1154	Economy	13900.00
0005434435188	1154	Economy	13900.00
0005434435183	1154	Economy	13900.00
0005434435178	1154	Economy	13900.00
0005434435181	1154	Economy	13900.00
0005433156686	1154	Economy	13900.00
0005434435192	1154	Economy	13900.00
0005434435189	1154	Economy	13900.00
0005434435182	1154	Economy	13900.00
0005434435190	1154	Economy	13900.00
0005434435191	1154	Economy	13900.00
0005434435180	1154	Economy	13900.00
0005433156664	1154	Economy	13900.00
0005434435187	1154	Economy	13900.00
0005434435185	1154	Economy	13900.00
0005434435068	17303	Economy	15200.00
0005433156748	17303	Economy	15200.00
0005434435090	17303	Economy	15200.00
0005433156750	17303	Economy	15200.00
0005434435025	17303	Economy	13900.00
0005433156755	17303	Economy	13900.00
0005433156753	17303	Economy	13900.00
0005434435063	17303	Economy	13900.00
0005434435093	17303	Economy	13900.00
0005434435094	17303	Economy	13900.00
0005433156751	17303	Economy	13900.00
0005433156754	17303	Economy	13900.00
0005434434988	17303	Economy	13900.00
0005434435034	17303	Economy	13900.00
0005434435071	17303	Economy	13900.00
0005433156749	17303	Economy	13900.00
0005433156752	17303	Economy	13900.00
0005434435046	17303	Economy	13900.00
0005434435092	17303	Economy	13900.00
0005434434996	17303	Economy	13900.00
0005434435100	17303	Economy	13900.00
0005435928095	4096	Economy	8200.00
0005435086837	4096	Economy	7500.00
0005435086835	4096	Economy	7500.00
0005435928096	4096	Economy	7500.00
0005435086832	4096	Economy	7500.00
0005435928090	4096	Economy	7500.00
0005435086836	4096	Economy	7500.00
0005435086838	4096	Economy	7500.00
0005435086834	4096	Economy	7500.00
0005435086833	4096	Economy	7500.00
0005435928097	4096	Economy	7500.00
0005435086839	4096	Economy	7500.00
0005435086766	24418	Economy	8200.00
0005435928141	24418	Economy	8200.00
0005435086790	24418	Economy	7500.00
0005435928144	24418	Economy	7500.00
0005435086791	24418	Economy	7500.00
0005435086749	24418	Economy	7500.00
0005435928143	24418	Economy	7500.00
0005435928142	24418	Economy	7500.00
0005435086767	24418	Economy	7500.00
0005435928145	24418	Economy	7500.00
0005435928146	24418	Economy	7500.00
0005435098535	11072	Business	144300.00
0005435098536	11072	Business	144300.00
0005435551518	11072	Business	144300.00
0005435098527	11072	Economy	52900.00
0005435551528	11072	Economy	48100.00
0005435551501	11072	Economy	48100.00
0005435098530	11072	Economy	48100.00
0005435551535	11072	Economy	48100.00
0005435098531	11072	Economy	48100.00
0005435551524	11072	Economy	48100.00
0005435551536	11072	Economy	48100.00
0005435551532	11072	Economy	48100.00
0005435098537	11072	Economy	48100.00
0005435098529	11072	Economy	48100.00
0005435551523	11072	Economy	48100.00
0005435551517	11072	Economy	48100.00
0005435098534	11072	Economy	48100.00
0005435551533	11072	Economy	48100.00
0005435098533	11072	Economy	48100.00
0005435098532	11072	Economy	48100.00
0005435551500	11072	Economy	48100.00
0005435551531	11072	Economy	48100.00
0005435551521	11072	Economy	48100.00
0005435551534	11072	Economy	48100.00
0005435551506	11072	Economy	48100.00
0005435551525	11072	Economy	48100.00
0005435551581	17013	Business	144300.00
0005435098557	17013	Economy	52900.00
0005435551586	17013	Economy	48100.00
0005435098556	17013	Economy	48100.00
0005435551597	17013	Economy	48100.00
0005435551579	17013	Economy	48100.00
0005435551588	17013	Economy	48100.00
0005435098555	17013	Economy	48100.00
0005435551591	17013	Economy	48100.00
0005435098559	17013	Economy	48100.00
0005435551585	17013	Economy	48100.00
0005435551589	17013	Economy	48100.00
0005435551594	17013	Economy	48100.00
0005435098558	17013	Economy	48100.00
0005435551582	17013	Economy	52900.00
0005435551583	17013	Economy	48100.00
0005435551596	17013	Economy	48100.00
0005435551595	17013	Economy	48100.00
0005435098552	17013	Economy	48100.00
0005435551593	17013	Economy	48100.00
0005435098553	17013	Economy	48100.00
0005435551584	17013	Economy	48100.00
0005435098554	17013	Economy	48100.00
0005435098560	17013	Economy	48100.00
0005435551592	17013	Economy	48100.00
0005435551580	17013	Economy	48100.00
0005435551587	17013	Economy	48100.00
0005435551590	17013	Economy	48100.00
0005434963996	18243	Business	203300.00
0005433261563	18243	Business	203300.00
0005433261562	18243	Business	203300.00
0005434963994	18243	Business	203300.00
0005434964045	18243	Business	203300.00
0005434964049	18243	Business	203300.00
0005433261556	18243	Business	203300.00
0005434964012	18243	Business	203300.00
0005434964001	18243	Business	203300.00
0005434963958	18243	Business	203300.00
0005433261559	18243	Economy	67800.00
0005434964031	18243	Economy	67800.00
0005434964075	18243	Economy	67800.00
0005434964068	18243	Economy	67800.00
0005434964092	18243	Economy	67800.00
0005434963979	18243	Economy	67800.00
0005434964040	18243	Economy	67800.00
0005433261561	18243	Economy	67800.00
0005433261574	18243	Economy	67800.00
0005434964056	18243	Economy	67800.00
0005433261575	18243	Economy	67800.00
0005434964070	18243	Economy	67800.00
0005433261564	18243	Economy	67800.00
0005433261555	18243	Economy	67800.00
0005434963940	18243	Economy	67800.00
0005433261573	18243	Economy	67800.00
0005434964104	18243	Economy	67800.00
0005434963939	18243	Economy	67800.00
0005433261571	18243	Economy	67800.00
0005434964018	18243	Economy	67800.00
0005434964017	18243	Economy	67800.00
0005434964065	18243	Economy	67800.00
0005434964026	18243	Economy	67800.00
0005434964037	18243	Economy	67800.00
0005434964066	18243	Economy	67800.00
0005433261569	18243	Economy	67800.00
0005434964069	18243	Economy	67800.00
0005433261570	18243	Economy	67800.00
0005434964014	18243	Economy	67800.00
0005433261567	18243	Economy	67800.00
0005434964041	18243	Economy	67800.00
0005434964036	18243	Economy	67800.00
0005434964108	18243	Economy	67800.00
0005434964121	18243	Economy	67800.00
0005433261566	18243	Economy	67800.00
0005433261557	18243	Economy	67800.00
0005434964107	18243	Economy	67800.00
0005434964099	18243	Economy	67800.00
0005434964038	18243	Economy	67800.00
0005434964084	18243	Economy	67800.00
0005434964046	18243	Economy	67800.00
0005434964033	18243	Economy	67800.00
0005434964043	18243	Economy	67800.00
0005434964044	18243	Economy	67800.00
0005434963980	18243	Economy	67800.00
0005434964027	18243	Economy	67800.00
0005433261560	18243	Economy	67800.00
0005434964091	18243	Economy	67800.00
0005434964032	18243	Economy	67800.00
0005433261565	18243	Economy	67800.00
0005434963995	18243	Economy	67800.00
0005433261558	18243	Economy	67800.00
0005434964052	18243	Economy	67800.00
0005433261572	18243	Economy	67800.00
0005434964112	18243	Economy	67800.00
0005434964013	18243	Economy	67800.00
0005433261568	18243	Economy	67800.00
0005434964015	18243	Economy	67800.00
0005434964106	18243	Economy	67800.00
0005434963997	18243	Economy	67800.00
0005434625964	4819	Business	44200.00
0005434625961	4819	Business	44200.00
0005435907471	4819	Economy	14700.00
0005433194842	4819	Economy	14700.00
0005435907447	4819	Economy	14700.00
0005434625959	4819	Economy	14700.00
0005434625966	4819	Economy	14700.00
0005433194841	4819	Economy	14700.00
0005435907474	4819	Economy	14700.00
0005434625963	4819	Economy	14700.00
0005434625960	4819	Economy	14700.00
0005435907462	4819	Economy	14700.00
0005435907446	4819	Economy	14700.00
0005434625967	4819	Economy	14700.00
0005435907477	4819	Economy	14700.00
0005433194832	4819	Economy	14700.00
0005434625958	4819	Economy	14700.00
0005434625962	4819	Economy	14700.00
0005434625965	4819	Economy	14700.00
0005434625948	32886	Business	44200.00
0005435907507	32886	Economy	14700.00
0005434625866	32886	Economy	14700.00
0005433194859	32886	Economy	14700.00
0005434625884	32886	Economy	14700.00
0005433194858	32886	Economy	14700.00
0005434625880	32886	Economy	14700.00
0005434625892	32886	Economy	14700.00
0005435907511	32886	Economy	14700.00
0005434625914	32886	Economy	14700.00
0005434625947	32886	Economy	14700.00
0005434625867	32886	Economy	14700.00
0005433194860	32886	Economy	14700.00
0005435907510	32886	Economy	14700.00
0005435907506	32886	Economy	14700.00
0005434625903	32886	Economy	14700.00
0005434625925	32886	Economy	14700.00
0005434625913	32886	Economy	14700.00
0005435907508	32886	Economy	14700.00
0005434625902	32886	Economy	14700.00
0005434625929	32886	Economy	14700.00
0005435907509	32886	Economy	14700.00
0005434625881	32886	Economy	14700.00
0005435785138	13769	Economy	3400.00
0005435784995	13769	Economy	3400.00
0005435785015	13769	Economy	3400.00
0005435785153	13769	Economy	3400.00
0005435784989	13769	Economy	3100.00
0005435785078	13769	Economy	3100.00
0005435785048	13769	Economy	3100.00
0005435784838	13769	Economy	3100.00
0005435785058	13769	Economy	3100.00
0005435785096	13769	Economy	3100.00
0005435787331	13769	Economy	3100.00
0005435784919	13769	Economy	3100.00
0005435785039	13769	Economy	3100.00
0005435785131	13769	Economy	3100.00
0005432195694	13769	Economy	3100.00
0005435787332	13769	Economy	3100.00
0005435785041	13769	Economy	3100.00
0005435787330	13769	Economy	3100.00
0005435785023	13769	Economy	3100.00
0005435785143	13769	Economy	3100.00
0005435784920	13769	Economy	3100.00
0005435787333	13769	Economy	3100.00
0005435785137	13769	Economy	3100.00
0005432195692	13769	Economy	3100.00
0005435937389	13769	Economy	3100.00
0005435784859	13769	Economy	3100.00
0005435785086	13769	Economy	3100.00
0005435785095	13769	Economy	3100.00
0005435785013	13769	Economy	3100.00
0005435784990	13769	Economy	3100.00
0005435785144	13769	Economy	3100.00
0005432195695	13769	Economy	3100.00
0005435784961	13769	Economy	3100.00
0005435785042	13769	Economy	3100.00
0005435785040	13769	Economy	3100.00
0005435785132	13769	Economy	3100.00
0005432195693	13769	Economy	3100.00
0005435784878	13769	Economy	3100.00
0005435784879	13769	Economy	3100.00
0005435784996	13769	Economy	3100.00
0005435784931	13769	Economy	3100.00
0005435785022	13769	Economy	3100.00
0005435784791	13769	Economy	3100.00
0005435785310	27452	Economy	3400.00
0005435785321	27452	Economy	3400.00
0005435785316	27452	Economy	3400.00
0005435785325	27452	Economy	3400.00
0005435785302	27452	Economy	3100.00
0005432190625	27452	Economy	3100.00
0005435785330	27452	Economy	3100.00
0005435937321	27452	Economy	3100.00
0005435785328	27452	Economy	3100.00
0005435787353	27452	Economy	3100.00
0005435785303	27452	Economy	3100.00
0005435787350	27452	Economy	3100.00
0005435785318	27452	Economy	3100.00
0005435785317	27452	Economy	3100.00
0005435785327	27452	Economy	3100.00
0005432190626	27452	Economy	3100.00
0005435785311	27452	Economy	3100.00
0005435785294	27452	Economy	3100.00
0005435785309	27452	Economy	3100.00
0005435785319	27452	Economy	3100.00
0005435785314	27452	Economy	3100.00
0005435785300	27452	Economy	3100.00
0005435785305	27452	Economy	3100.00
0005435785299	27452	Economy	3100.00
0005435785306	27452	Economy	3100.00
0005435785312	27452	Economy	3100.00
0005435785320	27452	Economy	3100.00
0005435785308	27452	Economy	3100.00
0005435785301	27452	Economy	3100.00
0005435785326	27452	Economy	3100.00
0005435785298	27452	Economy	3100.00
0005435937320	27452	Economy	3100.00
0005435937327	27452	Economy	3100.00
0005435785307	27452	Economy	3100.00
0005432190624	27452	Economy	3100.00
0005435785304	27452	Economy	3100.00
0005435785313	27452	Economy	3100.00
0005435785295	27452	Economy	3100.00
0005435785329	27452	Economy	3100.00
0005432190627	27452	Economy	3100.00
0005435785322	27452	Economy	3100.00
0005435787351	27452	Economy	3100.00
0005435785315	27452	Economy	3100.00
0005435785296	27452	Economy	3100.00
0005435785323	27452	Economy	3100.00
0005435785297	27452	Economy	3100.00
0005435787352	27452	Economy	3100.00
0005435785324	27452	Economy	3100.00
0005434407295	20273	Business	12000.00
0005434407273	20273	Business	12000.00
0005435311063	20273	Business	12000.00
0005435311076	20273	Business	12000.00
0005432058385	20273	Business	12000.00
0005434407228	20273	Business	12000.00
0005434407313	20273	Business	12000.00
0005434407050	20273	Business	12000.00
0005434406899	20273	Business	12000.00
0005434407232	20273	Business	12000.00
0005434407116	20273	Economy	4000.00
0005434407227	20273	Economy	4000.00
0005434407266	20273	Economy	4000.00
0005435311075	20273	Economy	4000.00
0005434407016	20273	Economy	4000.00
0005434406874	20273	Economy	4000.00
0005434407176	20273	Economy	4000.00
0005434407255	20273	Economy	4000.00
0005434407069	20273	Economy	4400.00
0005434407041	20273	Economy	4400.00
0005434407235	20273	Economy	4400.00
0005435311072	20273	Economy	4000.00
0005435311073	20273	Economy	4000.00
0005434407314	20273	Economy	4000.00
0005434407322	20273	Economy	4000.00
0005434407268	20273	Economy	4000.00
0005434407371	20273	Economy	4000.00
0005434407267	20273	Economy	4000.00
0005434406915	20273	Economy	4000.00
0005434407413	20273	Economy	4000.00
0005434407291	20273	Economy	4000.00
0005435311074	20273	Economy	4000.00
0005434407245	20273	Economy	4000.00
0005434406968	20273	Economy	4000.00
0005432058383	20273	Economy	4000.00
0005434407073	20273	Economy	4000.00
0005434407566	20273	Economy	4000.00
0005434407196	20273	Economy	4000.00
0005435311064	20273	Economy	4000.00
0005435311067	20273	Economy	4000.00
0005435311071	20273	Economy	4000.00
0005432058384	20273	Economy	4000.00
0005434407328	20273	Economy	4000.00
0005434407015	20273	Economy	4000.00
0005434407294	20273	Economy	4000.00
0005434407234	20273	Economy	4000.00
0005435311070	20273	Economy	4000.00
0005434407020	20273	Economy	4000.00
0005432058382	20273	Economy	4000.00
0005435311065	20273	Economy	4000.00
0005434407340	20273	Economy	4000.00
0005434407321	20273	Economy	4000.00
0005434407379	20273	Economy	4000.00
0005432058381	20273	Economy	4000.00
0005434407292	20273	Economy	4000.00
0005434407147	20273	Economy	4000.00
0005435311077	20273	Economy	4000.00
0005434407068	20273	Economy	4000.00
0005434407353	20273	Economy	4000.00
0005434407178	20273	Economy	4000.00
0005434406914	20273	Economy	4000.00
0005434407070	20273	Economy	4000.00
0005434407208	20273	Economy	4000.00
0005434407085	20273	Economy	4000.00
0005434407378	20273	Economy	4000.00
0005434406906	20273	Economy	4000.00
0005434407072	20273	Economy	4000.00
0005434407192	20273	Economy	4000.00
0005435311068	20273	Economy	4000.00
0005434407130	20273	Economy	4000.00
0005434407131	20273	Economy	4000.00
0005435311069	20273	Economy	4000.00
0005434407236	20273	Economy	4000.00
0005434407311	20273	Economy	4000.00
0005434407203	20273	Economy	4000.00
0005434406907	20273	Economy	4000.00
0005434407418	20273	Economy	4000.00
0005434407256	20273	Economy	4000.00
0005434407187	20273	Economy	4000.00
0005435311066	20273	Economy	4000.00
0005434407213	20273	Economy	4000.00
0005435310941	27000	Business	12000.00
0005434407759	27000	Business	12000.00
0005434407789	27000	Business	12000.00
0005434407768	27000	Business	12000.00
0005434407782	27000	Business	12000.00
0005434407786	27000	Business	12000.00
0005434407749	27000	Business	12000.00
0005434407766	27000	Business	12000.00
0005434407793	27000	Business	12000.00
0005435310950	27000	Economy	4000.00
0005432153935	27000	Economy	4000.00
0005435310946	27000	Economy	4000.00
0005434407787	27000	Economy	4000.00
0005434407779	27000	Economy	4000.00
0005434407742	27000	Economy	4000.00
0005434407763	27000	Economy	4000.00
0005435310932	27000	Economy	4000.00
0005434407774	27000	Economy	4000.00
0005434407790	27000	Economy	4400.00
0005434407741	27000	Economy	4400.00
0005434407740	27000	Economy	4400.00
0005435310957	27000	Economy	4400.00
0005432153942	27000	Economy	4400.00
0005434407777	27000	Economy	4000.00
0005434407757	27000	Economy	4000.00
0005434407755	27000	Economy	4000.00
0005434407792	27000	Economy	4000.00
0005434407746	27000	Economy	4000.00
0005434407748	27000	Economy	4000.00
0005434407769	27000	Economy	4000.00
0005434407788	27000	Economy	4000.00
0005432153937	27000	Economy	4000.00
0005434407736	27000	Economy	4000.00
0005434407760	27000	Economy	4000.00
0005434407773	27000	Economy	4000.00
0005435310947	27000	Economy	4000.00
0005434407758	27000	Economy	4000.00
0005434407796	27000	Economy	4000.00
0005434407771	27000	Economy	4000.00
0005434407762	27000	Economy	4000.00
0005434407781	27000	Economy	4000.00
0005432153941	27000	Economy	4000.00
0005432153939	27000	Economy	4000.00
0005434407738	27000	Economy	4000.00
0005434407747	27000	Economy	4000.00
0005434407791	27000	Economy	4000.00
0005434407780	27000	Economy	4000.00
0005434407764	27000	Economy	4000.00
0005434407783	27000	Economy	4000.00
0005434407775	27000	Economy	4000.00
0005434407770	27000	Economy	4000.00
0005434407784	27000	Economy	4000.00
0005432153940	27000	Economy	4000.00
0005434407752	27000	Economy	4000.00
0005435310934	27000	Economy	4000.00
0005432153936	27000	Economy	4000.00
0005434407744	27000	Economy	4000.00
0005434407743	27000	Economy	4000.00
0005434407765	27000	Economy	4000.00
0005434407756	27000	Economy	4000.00
0005434407776	27000	Economy	4000.00
0005435310905	27000	Economy	4000.00
0005434407785	27000	Economy	4000.00
0005434407795	27000	Economy	4000.00
0005434407753	27000	Economy	4000.00
0005434407750	27000	Economy	4000.00
0005434407778	27000	Economy	4000.00
0005434407767	27000	Economy	4000.00
0005435310933	27000	Economy	4000.00
0005434407799	27000	Economy	4000.00
0005434407794	27000	Economy	4000.00
0005434407751	27000	Economy	4000.00
0005432153938	27000	Economy	4000.00
0005434407739	27000	Economy	4000.00
0005434407754	27000	Economy	4000.00
0005435310922	27000	Economy	4000.00
0005435310936	27000	Economy	4000.00
0005434407798	27000	Economy	4000.00
0005434407745	27000	Economy	4000.00
0005434407797	27000	Economy	4000.00
0005434407737	27000	Economy	4000.00
0005434407772	27000	Economy	4000.00
0005434407761	27000	Economy	4000.00
0005434311219	5705	Business	43300.00
0005433123800	5705	Business	43300.00
0005434319402	5705	Business	43300.00
0005433123710	5705	Business	43300.00
0005433123771	5705	Business	43300.00
0005434319403	5705	Business	43300.00
0005433123699	5705	Economy	14400.00
0005433123757	5705	Economy	15900.00
0005434319394	5705	Economy	15900.00
0005433123747	5705	Economy	15900.00
0005433123783	5705	Economy	14400.00
0005434311220	5705	Economy	14400.00
0005433123765	5705	Economy	14400.00
0005433123718	5705	Economy	14400.00
0005433123749	5705	Economy	14400.00
0005434319397	5705	Economy	14400.00
0005433123741	5705	Economy	14400.00
0005434319399	5705	Economy	14400.00
0005433123775	5705	Economy	14400.00
0005432109703	5705	Economy	14400.00
0005433123703	5705	Economy	14400.00
0005434311218	5705	Economy	14400.00
0005433123796	5705	Economy	14400.00
0005434319400	5705	Economy	14400.00
0005433123723	5705	Economy	14400.00
0005433123704	5705	Economy	14400.00
0005433123758	5705	Economy	14400.00
0005434319401	5705	Economy	14400.00
0005434319395	5705	Economy	14400.00
0005433123784	5705	Economy	14400.00
0005433123748	5705	Economy	14400.00
0005433123734	5705	Economy	14400.00
0005433123793	5705	Economy	14400.00
0005432109702	5705	Economy	14400.00
0005433123715	5705	Economy	14400.00
0005432109704	5705	Economy	14400.00
0005434319396	5705	Economy	14400.00
0005434319404	5705	Economy	14400.00
0005434319398	5705	Economy	14400.00
0005434319274	15661	Business	43300.00
0005433123938	15661	Business	43300.00
0005433123939	15661	Business	43300.00
0005433123949	15661	Business	43300.00
0005434319273	15661	Business	43300.00
0005433123936	15661	Business	43300.00
0005433123953	15661	Economy	14400.00
0005433123950	15661	Economy	14400.00
0005433123935	15661	Economy	14400.00
0005434312299	15661	Economy	14400.00
0005433123933	15661	Economy	14400.00
0005434319252	15661	Economy	15900.00
0005433123932	15661	Economy	14400.00
0005433123951	15661	Economy	14400.00
0005433123934	15661	Economy	14400.00
0005433123946	15661	Economy	14400.00
0005433123937	15661	Economy	14400.00
0005434319242	15661	Economy	14400.00
0005433123952	15661	Economy	14400.00
0005434319246	15661	Economy	14400.00
0005433123941	15661	Economy	14400.00
0005433123947	15661	Economy	14400.00
0005434319245	15661	Economy	14400.00
0005433123948	15661	Economy	14400.00
0005433123942	15661	Economy	14400.00
0005434319209	15661	Economy	14400.00
0005433123945	15661	Economy	14400.00
0005433123931	15661	Economy	14400.00
0005433123944	15661	Economy	14400.00
0005433123943	15661	Economy	14400.00
0005434319283	15661	Economy	14400.00
0005433123940	15661	Economy	14400.00
0005435220304	24989	Economy	17100.00
0005435217680	24989	Economy	15500.00
0005435217688	24989	Economy	15500.00
0005435217686	24989	Economy	15500.00
0005435217681	24989	Economy	15500.00
0005435217692	24989	Economy	15500.00
0005435217691	24989	Economy	15500.00
0005435217694	24989	Economy	15500.00
0005435220292	24989	Economy	15500.00
0005435217687	24989	Economy	15500.00
0005435217679	24989	Economy	15500.00
0005435217693	24989	Economy	15500.00
0005434484348	8987	Economy	27400.00
0005434484351	8987	Economy	24900.00
0005434484346	8987	Economy	24900.00
0005434189122	8987	Economy	24900.00
0005434189130	8987	Economy	24900.00
0005434189143	8987	Economy	24900.00
0005434189129	8987	Economy	24900.00
0005434484349	8987	Economy	24900.00
0005434484347	8987	Economy	24900.00
0005434484350	8987	Economy	24900.00
0005434484273	16634	Economy	24900.00
0005434189179	16634	Economy	24900.00
0005434484281	16634	Economy	24900.00
0005434484286	16634	Economy	24900.00
0005434484307	16634	Economy	24900.00
0005434484267	16634	Economy	24900.00
0005434189178	16634	Economy	24900.00
0005434484287	16634	Economy	24900.00
0005434484280	16634	Economy	24900.00
0005434484272	16634	Economy	24900.00
0005434189180	16634	Economy	24900.00
0005434189181	16634	Economy	24900.00
0005434484297	16634	Economy	24900.00
0005433123952	7631	Business	11100.00
0005433123940	7631	Business	11100.00
0005433722150	7631	Business	11100.00
0005433123936	7631	Business	11100.00
0005433123944	7631	Economy	3700.00
0005433123953	7631	Economy	3700.00
0005433123937	7631	Economy	3700.00
0005433722123	7631	Economy	4100.00
0005433123943	7631	Economy	3700.00
0005433123939	7631	Economy	3700.00
0005433123935	7631	Economy	3700.00
0005433123931	7631	Economy	3700.00
0005433722149	7631	Economy	3700.00
0005433123933	7631	Economy	3700.00
0005433123949	7631	Economy	3700.00
0005433123932	7631	Economy	3700.00
0005433123941	7631	Economy	3700.00
0005433722153	7631	Economy	3700.00
0005433123948	7631	Economy	3700.00
0005433123946	7631	Economy	3700.00
0005433722137	7631	Economy	3700.00
0005433123947	7631	Economy	3700.00
0005433123938	7631	Economy	3700.00
0005433123934	7631	Economy	3700.00
0005433722152	7631	Economy	3700.00
0005433123945	7631	Economy	3700.00
0005433722136	7631	Economy	3700.00
0005433123942	7631	Economy	3700.00
0005433123950	7631	Economy	3700.00
0005433123951	7631	Economy	3700.00
0005433449974	7632	Business	11100.00
0005433449966	7632	Business	11100.00
0005433449983	7632	Business	11100.00
0005432693066	7632	Business	11100.00
0005432693064	7632	Business	11100.00
0005432720898	7632	Business	11100.00
0005432693067	7632	Business	11100.00
0005432720921	7632	Business	11100.00
0005432693093	7632	Business	11100.00
0005432720918	7632	Business	11100.00
0005432720916	7632	Business	11100.00
0005432693068	7632	Economy	3700.00
0005432720912	7632	Economy	3700.00
0005433449970	7632	Economy	3700.00
0005432720895	7632	Economy	3700.00
0005432720914	7632	Economy	3700.00
0005432720901	7632	Economy	3700.00
0005432693076	7632	Economy	3700.00
0005433449980	7632	Economy	3700.00
0005432720906	7632	Economy	3700.00
0005432693071	7632	Economy	4100.00
0005432693082	7632	Economy	4100.00
0005432720897	7632	Economy	4100.00
0005432720899	7632	Economy	4100.00
0005432693088	7632	Economy	3700.00
0005432693069	7632	Economy	3700.00
0005432693084	7632	Economy	3700.00
0005433449972	7632	Economy	3700.00
0005432720903	7632	Economy	3700.00
0005432720908	7632	Economy	3700.00
0005432693083	7632	Economy	3700.00
0005432720915	7632	Economy	3700.00
0005432071573	7632	Economy	3700.00
0005433449968	7632	Economy	3700.00
0005433449984	7632	Economy	3700.00
0005432720920	7632	Economy	3700.00
0005433449969	7632	Economy	3700.00
0005432720904	7632	Economy	3700.00
0005432693078	7632	Economy	3700.00
0005433449979	7632	Economy	3700.00
0005433449981	7632	Economy	3700.00
0005432693080	7632	Economy	3700.00
0005432693095	7632	Economy	3700.00
0005432693065	7632	Economy	3700.00
0005432720900	7632	Economy	3700.00
0005432720905	7632	Economy	3700.00
0005432720913	7632	Economy	3700.00
0005432720919	7632	Economy	3700.00
0005432720910	7632	Economy	3700.00
0005432720902	7632	Economy	3700.00
0005432693087	7632	Economy	3700.00
0005432720907	7632	Economy	3700.00
0005432720909	7632	Economy	3700.00
0005432693094	7632	Economy	3700.00
0005432693072	7632	Economy	3700.00
0005432071572	7632	Economy	3700.00
0005433449976	7632	Economy	3700.00
0005433449982	7632	Economy	3700.00
0005433449977	7632	Economy	3700.00
0005432693086	7632	Economy	3700.00
0005432720911	7632	Economy	3700.00
0005433449971	7632	Economy	3700.00
0005432693077	7632	Economy	3700.00
0005432693075	7632	Economy	3700.00
0005432693081	7632	Economy	3700.00
0005432071574	7632	Economy	3700.00
0005433449962	7632	Economy	3700.00
0005432720917	7632	Economy	3700.00
0005433449965	7632	Economy	3700.00
0005432693089	7632	Economy	3700.00
0005433449973	7632	Economy	3700.00
0005432720896	7632	Economy	3700.00
0005432693091	7632	Economy	3700.00
0005433449975	7632	Economy	3700.00
0005433449964	7632	Economy	3700.00
0005433449967	7632	Economy	3700.00
0005432693079	7632	Economy	3700.00
0005432693074	7632	Economy	3700.00
0005432693092	7632	Economy	3700.00
0005432693085	7632	Economy	3700.00
0005433449978	7632	Economy	3700.00
0005433449963	7632	Economy	3700.00
0005432693090	7632	Economy	3700.00
0005432693073	7632	Economy	3700.00
0005432693070	7632	Economy	3700.00
0005432692669	30308	Business	11100.00
0005432692656	30308	Business	11100.00
0005433449695	30308	Business	11100.00
0005433449718	30308	Business	11100.00
0005433449720	30308	Business	11100.00
0005433449761	30308	Business	11100.00
0005432692692	30308	Economy	3700.00
0005432692876	30308	Economy	3700.00
0005433449778	30308	Economy	3700.00
0005432692875	30308	Economy	3700.00
0005432692717	30308	Economy	3700.00
0005433449771	30308	Economy	4100.00
0005432692920	30308	Economy	4100.00
0005432692795	30308	Economy	4100.00
0005433449818	30308	Economy	3700.00
0005432692780	30308	Economy	3700.00
0005433449858	30308	Economy	3700.00
0005432692763	30308	Economy	3700.00
0005432692833	30308	Economy	3700.00
0005433449815	30308	Economy	3700.00
0005433449846	30308	Economy	3700.00
0005433449808	30308	Economy	3700.00
0005432692811	30308	Economy	3700.00
0005433449869	30308	Economy	3700.00
0005432692905	30308	Economy	3700.00
0005433449813	30308	Economy	3700.00
0005432692835	30308	Economy	3700.00
0005432692858	30308	Economy	3700.00
0005432692816	30308	Economy	3700.00
0005432692872	30308	Economy	3700.00
0005432692815	30308	Economy	3700.00
0005433449807	30308	Economy	3700.00
0005432692642	30308	Economy	3700.00
0005432692742	30308	Economy	3700.00
0005433449776	30308	Economy	3700.00
0005432692807	30308	Economy	3700.00
0005432692748	30308	Economy	3700.00
0005432692834	30308	Economy	3700.00
0005432692702	30308	Economy	3700.00
0005433449740	30308	Economy	3700.00
0005432692824	30308	Economy	3700.00
0005433449814	30308	Economy	3700.00
0005433449719	30308	Economy	3700.00
0005433449779	30308	Economy	3700.00
0005433449817	30308	Economy	3700.00
0005433449886	30308	Economy	3700.00
0005432692691	30308	Economy	3700.00
0005432692749	30308	Economy	3700.00
0005433123710	30307	Business	11100.00
0005433123784	30307	Business	11100.00
0005433123734	30307	Business	11100.00
0005433123748	30307	Business	11100.00
0005432720548	30307	Business	11100.00
0005433123703	30307	Business	11100.00
0005432720627	30307	Business	11100.00
0005432720805	30307	Economy	3700.00
0005433123747	30307	Economy	3700.00
0005432720731	30307	Economy	3700.00
0005432720653	30307	Economy	3700.00
0005433722227	30307	Economy	4100.00
0005433123704	30307	Economy	4100.00
0005433123775	30307	Economy	4100.00
0005432720584	30307	Economy	3700.00
0005432720583	30307	Economy	3700.00
0005432720581	30307	Economy	3700.00
0005433123796	30307	Economy	3700.00
0005433123718	30307	Economy	3700.00
0005433123723	30307	Economy	3700.00
0005432720580	30307	Economy	3700.00
0005432720602	30307	Economy	3700.00
0005433123741	30307	Economy	3700.00
0005433123757	30307	Economy	3700.00
0005432720651	30307	Economy	3700.00
0005433722226	30307	Economy	3700.00
0005433123749	30307	Economy	3700.00
0005432720783	30307	Economy	3700.00
0005433123715	30307	Economy	3700.00
0005433123800	30307	Economy	3700.00
0005433123699	30307	Economy	3700.00
0005433123771	30307	Economy	3700.00
0005432720730	30307	Economy	3700.00
0005432720626	30307	Economy	3700.00
0005432720628	30307	Economy	3700.00
0005433722225	30307	Economy	3700.00
0005433722229	30307	Economy	3700.00
0005433123765	30307	Economy	3700.00
0005433722228	30307	Economy	3700.00
0005432720776	30307	Economy	3700.00
0005432720678	30307	Economy	3700.00
0005433123758	30307	Economy	3700.00
0005432720681	30307	Economy	3700.00
0005433123793	30307	Economy	3700.00
0005432720794	30307	Economy	3700.00
0005432720796	30307	Economy	3700.00
0005432720797	30307	Economy	3700.00
0005433123783	30307	Economy	3700.00
0005432271005	1375	Business	70400.00
0005433192978	1375	Business	70400.00
0005433525035	1375	Business	70400.00
0005432927946	1375	Business	70400.00
0005433525036	1375	Business	70400.00
0005433192919	1375	Business	70400.00
0005432968825	1375	Business	70400.00
0005434586610	1375	Business	70400.00
0005433724811	1375	Business	70400.00
0005433724809	1375	Business	70400.00
0005434586616	1375	Economy	23500.00
0005434586607	1375	Economy	23500.00
0005433192970	1375	Economy	23500.00
0005434586629	1375	Economy	23500.00
0005434586612	1375	Economy	23500.00
0005434586613	1375	Economy	23500.00
0005433525041	1375	Economy	23500.00
0005434586624	1375	Economy	23500.00
0005433724806	1375	Economy	25800.00
0005434586623	1375	Economy	25800.00
0005434586608	1375	Economy	23500.00
0005433192956	1375	Economy	23500.00
0005432271003	1375	Economy	23500.00
0005433192927	1375	Economy	23500.00
0005434513579	1375	Economy	23500.00
0005432927934	1375	Economy	23500.00
0005434586611	1375	Economy	23500.00
0005433192966	1375	Economy	23500.00
0005432927940	1375	Economy	23500.00
0005432927927	1375	Economy	23500.00
0005433192917	1375	Economy	23500.00
0005433525040	1375	Economy	23500.00
0005434586619	1375	Economy	23500.00
0005433525045	1375	Economy	23500.00
0005434513581	1375	Economy	23500.00
0005433525039	1375	Economy	23500.00
0005434586626	1375	Economy	23500.00
0005433525044	1375	Economy	23500.00
0005434586618	1375	Economy	23500.00
0005432927949	1375	Economy	23500.00
0005433724810	1375	Economy	23500.00
0005432927928	1375	Economy	23500.00
0005434586620	1375	Economy	23500.00
0005434514968	1375	Economy	23500.00
0005433724807	1375	Economy	23500.00
0005434586628	1375	Economy	23500.00
0005434586621	1375	Economy	23500.00
0005434586625	1375	Economy	23500.00
0005434586606	1375	Economy	23500.00
0005434586617	1375	Economy	23500.00
0005433192999	1375	Economy	23500.00
0005432927933	1375	Economy	23500.00
0005433724808	1375	Economy	23500.00
0005434586627	1375	Economy	23500.00
0005434586614	1375	Economy	23500.00
0005432927947	1375	Economy	23500.00
0005433192918	1375	Economy	23500.00
0005433525037	1375	Economy	23500.00
0005432927948	1375	Economy	23500.00
0005433192957	1375	Economy	23500.00
0005434586609	1375	Economy	23500.00
0005434586622	1375	Economy	23500.00
0005433525043	1375	Economy	23500.00
0005432271004	1375	Economy	23500.00
0005434586605	1375	Economy	23500.00
0005433525038	1375	Economy	23500.00
0005434586615	1375	Economy	23500.00
0005433525042	1375	Economy	23500.00
0005432927903	1375	Economy	23500.00
0005434513580	1375	Economy	23500.00
0005434586435	18543	Business	70400.00
0005433524950	18543	Business	70400.00
0005434586281	18543	Business	70400.00
0005434514947	18543	Business	70400.00
0005434586430	18543	Business	70400.00
0005433193045	18543	Business	70400.00
0005433193052	18543	Business	70400.00
0005432927978	18543	Business	70400.00
0005433193053	18543	Business	70400.00
0005434586396	18543	Business	70400.00
0005432927980	18543	Business	70400.00
0005434586463	18543	Economy	23500.00
0005434586407	18543	Economy	23500.00
0005434586376	18543	Economy	23500.00
0005433524900	18543	Economy	23500.00
0005434586450	18543	Economy	23500.00
0005433193042	18543	Economy	23500.00
0005434586446	18543	Economy	23500.00
0005434586390	18543	Economy	25800.00
0005434586493	18543	Economy	25800.00
0005434586383	18543	Economy	25800.00
0005434586440	18543	Economy	25800.00
0005433193054	18543	Economy	23500.00
0005433193056	18543	Economy	23500.00
0005434586503	18543	Economy	23500.00
0005433524927	18543	Economy	23500.00
0005433724760	18543	Economy	23500.00
0005434586415	18543	Economy	23500.00
0005433524970	18543	Economy	23500.00
0005433193048	18543	Economy	23500.00
0005432927979	18543	Economy	23500.00
0005432968840	18543	Economy	23500.00
0005433524957	18543	Economy	23500.00
0005434586401	18543	Economy	23500.00
0005433193051	18543	Economy	23500.00
0005434586403	18543	Economy	23500.00
0005433193049	18543	Economy	23500.00
0005433193055	18543	Economy	23500.00
0005433524928	18543	Economy	23500.00
0005434586402	18543	Economy	23500.00
0005433524944	18543	Economy	23500.00
0005434586280	18543	Economy	23500.00
0005432927977	18543	Economy	23500.00
0005433524980	18543	Economy	23500.00
0005434586495	18543	Economy	23500.00
0005434514936	18543	Economy	23500.00
0005432968839	18543	Economy	23500.00
0005433724759	18543	Economy	23500.00
0005434586335	18543	Economy	23500.00
0005434586434	18543	Economy	23500.00
0005433193046	18543	Economy	23500.00
0005433524912	18543	Economy	23500.00
0005433724786	18543	Economy	23500.00
0005433193050	18543	Economy	23500.00
0005433524955	18543	Economy	23500.00
0005433193047	18543	Economy	23500.00
0005433524951	18543	Economy	23500.00
0005433193044	18543	Economy	23500.00
0005432927982	18543	Economy	23500.00
0005433193043	18543	Economy	23500.00
0005432927981	18543	Economy	23500.00
0005434586504	18543	Economy	23500.00
0005434586494	18543	Economy	23500.00
0005434586445	18543	Economy	23500.00
0005432968841	18543	Economy	23500.00
0005434142609	11437	Economy	4300.00
0005434344186	11437	Economy	4300.00
0005434344177	11437	Economy	4300.00
0005434344188	11437	Economy	4300.00
0005435302150	11437	Economy	4000.00
0005434344205	11437	Economy	4000.00
0005435302142	11437	Economy	4000.00
0005434344191	11437	Economy	4000.00
0005434344181	11437	Economy	4000.00
0005434344199	11437	Economy	4000.00
0005434344187	11437	Economy	4000.00
0005434344195	11437	Economy	4000.00
0005434344198	11437	Economy	4000.00
0005434344192	11437	Economy	4000.00
0005434344189	11437	Economy	4000.00
0005435302151	11437	Economy	4000.00
0005434344178	11437	Economy	4000.00
0005434344204	11437	Economy	4000.00
0005435302145	11437	Economy	4000.00
0005434344210	11437	Economy	4000.00
0005434344182	11437	Economy	4000.00
0005434344180	11437	Economy	4000.00
0005434344190	11437	Economy	4000.00
0005434344201	11437	Economy	4000.00
0005434344194	11437	Economy	4000.00
0005434344203	11437	Economy	4000.00
0005434142610	11437	Economy	4000.00
0005434344197	11437	Economy	4000.00
0005434142612	11437	Economy	4000.00
0005434344206	11437	Economy	4000.00
0005434344179	11437	Economy	4000.00
0005435302154	11437	Economy	4000.00
0005434344196	11437	Economy	4000.00
0005434142611	11437	Economy	4000.00
0005434344209	11437	Economy	4000.00
0005434344184	11437	Economy	4000.00
0005434344202	11437	Economy	4000.00
0005434344185	11437	Economy	4000.00
0005434344175	11437	Economy	4000.00
0005434344200	11437	Economy	4000.00
0005434344176	11437	Economy	4000.00
0005434344174	11437	Economy	4000.00
0005435302143	11437	Economy	4000.00
0005435302153	11437	Economy	4000.00
0005434344183	11437	Economy	4000.00
0005434344193	11437	Economy	4000.00
0005434344208	11437	Economy	4000.00
0005434344207	11437	Economy	4000.00
0005434343986	29797	Economy	4300.00
0005434343742	29797	Economy	4300.00
0005434343915	29797	Economy	4300.00
0005434343730	29797	Economy	4300.00
0005434343933	29797	Economy	4000.00
0005434344041	29797	Economy	4000.00
0005434142582	29797	Economy	4000.00
0005435304158	29797	Economy	4000.00
0005435304163	29797	Economy	4000.00
0005434343914	29797	Economy	4000.00
0005434343851	29797	Economy	4000.00
0005434343784	29797	Economy	4000.00
0005434343820	29797	Economy	4000.00
0005434343985	29797	Economy	4000.00
0005434142579	29797	Economy	4000.00
0005434344005	29797	Economy	4000.00
0005435304159	29797	Economy	4000.00
0005434343843	29797	Economy	4000.00
0005434344023	29797	Economy	4000.00
0005434343717	29797	Economy	4000.00
0005434343819	29797	Economy	4000.00
0005434343767	29797	Economy	4000.00
0005434343865	29797	Economy	4000.00
0005434343916	29797	Economy	4000.00
0005434344004	29797	Economy	4000.00
0005434343979	29797	Economy	4000.00
0005435304162	29797	Economy	4000.00
0005434343970	29797	Economy	4000.00
0005434343912	29797	Economy	4000.00
0005434343844	29797	Economy	4000.00
0005434343975	29797	Economy	4000.00
0005434343776	29797	Economy	4000.00
0005434343824	29797	Economy	4000.00
0005435304161	29797	Economy	4000.00
0005434343801	29797	Economy	4000.00
0005434343799	29797	Economy	4000.00
0005434343966	29797	Economy	4000.00
0005434343766	29797	Economy	4000.00
0005434343882	29797	Economy	4000.00
0005434142571	29797	Economy	4000.00
0005434142556	29797	Economy	4000.00
0005434343913	29797	Economy	4000.00
0005434343881	29797	Economy	4000.00
0005435304160	29797	Economy	4000.00
0005434343987	29797	Economy	4000.00
0005434343852	29797	Economy	4000.00
0005434343782	29797	Economy	4000.00
0005434343785	29797	Economy	4000.00
0005433415478	1277	Business	199800.00
0005435824629	1277	Business	199800.00
0005433415513	1277	Business	199800.00
0005433415566	1277	Business	199800.00
0005435824643	1277	Business	199800.00
0005433415578	1277	Business	199800.00
0005435824627	1277	Business	199800.00
0005435824623	1277	Economy	66600.00
0005435824635	1277	Economy	66600.00
0005435824637	1277	Economy	66600.00
0005433415524	1277	Economy	66600.00
0005435824642	1277	Economy	66600.00
0005435824631	1277	Economy	73200.00
0005435824645	1277	Economy	73200.00
0005435824630	1277	Economy	66600.00
0005435824636	1277	Economy	66600.00
0005432284558	1277	Economy	66600.00
0005435824621	1277	Economy	66600.00
0005433415490	1277	Economy	66600.00
0005435824626	1277	Economy	66600.00
0005435824639	1277	Economy	66600.00
0005435824640	1277	Economy	66600.00
0005432284559	1277	Economy	66600.00
0005435824634	1277	Economy	66600.00
0005433415514	1277	Economy	66600.00
0005435824625	1277	Economy	66600.00
0005435824632	1277	Economy	66600.00
0005435824628	1277	Economy	66600.00
0005435824622	1277	Economy	66600.00
0005435824620	1277	Economy	66600.00
0005435824633	1277	Economy	66600.00
0005435824641	1277	Economy	66600.00
0005435824638	1277	Economy	66600.00
0005432284557	1277	Economy	66600.00
0005433415565	1277	Economy	66600.00
0005435824644	1277	Economy	66600.00
0005433415504	1277	Economy	66600.00
0005433415533	1277	Economy	66600.00
0005435824624	1277	Economy	66600.00
0005433415663	18026	Business	199800.00
0005433415672	18026	Business	199800.00
0005435824401	18026	Business	199800.00
0005433415667	18026	Business	199800.00
0005435824449	18026	Business	199800.00
0005435824383	18026	Business	199800.00
0005435824427	18026	Business	199800.00
0005433415665	18026	Business	199800.00
0005433415658	18026	Business	199800.00
0005433415664	18026	Business	199800.00
0005435824413	18026	Economy	66600.00
0005435824406	18026	Economy	66600.00
0005435824480	18026	Economy	66600.00
0005435824446	18026	Economy	73200.00
0005435824389	18026	Economy	73200.00
0005435824388	18026	Economy	66600.00
0005435824481	18026	Economy	66600.00
0005435824444	18026	Economy	66600.00
0005435824234	18026	Economy	66600.00
0005433415656	18026	Economy	66600.00
0005435824304	18026	Economy	66600.00
0005435824479	18026	Economy	66600.00
0005433415660	18026	Economy	66600.00
0005433415657	18026	Economy	66600.00
0005433415659	18026	Economy	66600.00
0005435824441	18026	Economy	66600.00
0005433415669	18026	Economy	66600.00
0005435824387	18026	Economy	66600.00
0005435824495	18026	Economy	66600.00
0005435824442	18026	Economy	66600.00
0005435824445	18026	Economy	66600.00
0005435824305	18026	Economy	66600.00
0005433415661	18026	Economy	66600.00
0005433415668	18026	Economy	66600.00
0005433415666	18026	Economy	66600.00
0005435824400	18026	Economy	66600.00
0005435824494	18026	Economy	66600.00
0005433415662	18026	Economy	66600.00
0005433415671	18026	Economy	66600.00
0005435824440	18026	Economy	66600.00
0005433415670	18026	Economy	66600.00
0005435824439	18026	Economy	66600.00
0005434462767	17531	Economy	14800.00
0005434462771	17531	Economy	14800.00
0005434462772	17531	Economy	13500.00
0005434462762	17531	Economy	13500.00
0005434460472	17531	Economy	13500.00
0005434460485	17531	Economy	13500.00
0005434460470	17531	Economy	13500.00
0005434462775	17531	Economy	13500.00
0005434460486	17531	Economy	13500.00
0005434462766	17531	Economy	13500.00
0005434460469	17531	Economy	13500.00
0005434462769	17531	Economy	13500.00
0005434462763	17531	Economy	13500.00
0005434460477	17531	Economy	13500.00
0005434462770	17531	Economy	13500.00
0005432783815	5624	Business	27800.00
0005432783786	5624	Business	27800.00
0005432783797	5624	Business	27800.00
0005432143989	5624	Business	27800.00
0005432143987	5624	Business	27800.00
0005435242545	5624	Business	27800.00
0005432783802	5624	Business	27800.00
0005432783817	5624	Business	27800.00
0005432783800	5624	Business	27800.00
0005432783778	5624	Business	27800.00
0005435242666	5624	Business	27800.00
0005435242559	5624	Business	27800.00
0005435242594	5624	Economy	9300.00
0005435242633	5624	Economy	9300.00
0005432783804	5624	Economy	9300.00
0005435242505	5624	Economy	9300.00
0005432783822	5624	Economy	9300.00
0005432783805	5624	Economy	9300.00
0005435242626	5624	Economy	9300.00
0005432783820	5624	Economy	9300.00
0005432783812	5624	Economy	9300.00
0005432783818	5624	Economy	10200.00
0005435242620	5624	Economy	10200.00
0005432783823	5624	Economy	10200.00
0005432783791	5624	Economy	10200.00
0005435242599	5624	Economy	10200.00
0005432783807	5624	Economy	9300.00
0005435242649	5624	Economy	9300.00
0005435242653	5624	Economy	9300.00
0005435242623	5624	Economy	9300.00
0005432783813	5624	Economy	9300.00
0005432783806	5624	Economy	9300.00
0005435242580	5624	Economy	9300.00
0005432783787	5624	Economy	9300.00
0005432783829	5624	Economy	9300.00
0005432783782	5624	Economy	9300.00
0005435242595	5624	Economy	9300.00
0005435242534	5624	Economy	9300.00
0005435242679	5624	Economy	9300.00
0005432783783	5624	Economy	9300.00
0005435242698	5624	Economy	9300.00
0005435242598	5624	Economy	9300.00
0005432783814	5624	Economy	9300.00
0005435242697	5624	Economy	9300.00
0005432783793	5624	Economy	9300.00
0005435242573	5624	Economy	9300.00
0005432783808	5624	Economy	9300.00
0005435242727	5624	Economy	9300.00
0005435242508	5624	Economy	9300.00
0005432783828	5624	Economy	9300.00
0005435242600	5624	Economy	9300.00
0005435242672	5624	Economy	9300.00
0005435242628	5624	Economy	9300.00
0005432783798	5624	Economy	9300.00
0005432783789	5624	Economy	9300.00
0005435242509	5624	Economy	9300.00
0005435242577	5624	Economy	9300.00
0005435242654	5624	Economy	9300.00
0005435242634	5624	Economy	9300.00
0005435242648	5624	Economy	9300.00
0005432783796	5624	Economy	9300.00
0005432783819	5624	Economy	9300.00
0005432783790	5624	Economy	9300.00
0005432783780	5624	Economy	9300.00
0005435242581	5624	Economy	9300.00
0005432783810	5624	Economy	9300.00
0005432783821	5624	Economy	9300.00
0005432783824	5624	Economy	9300.00
0005432783776	5624	Economy	9300.00
0005432783825	5624	Economy	9300.00
0005432143986	5624	Economy	9300.00
0005435242533	5624	Economy	9300.00
0005432143988	5624	Economy	9300.00
0005432783781	5624	Economy	9300.00
0005432783801	5624	Economy	9300.00
0005432783779	5624	Economy	9300.00
0005432783799	5624	Economy	9300.00
0005432783795	5624	Economy	9300.00
0005432783803	5624	Economy	9300.00
0005432783794	5624	Economy	9300.00
0005432783788	5624	Economy	9300.00
0005435242546	5624	Economy	9300.00
0005435242606	5624	Economy	9300.00
0005435242591	5624	Economy	9300.00
0005432783826	5624	Economy	9300.00
0005432783792	5624	Economy	9300.00
0005435242678	5624	Economy	9300.00
0005432783785	5624	Economy	9300.00
0005432783777	5624	Economy	9300.00
0005432783784	5624	Economy	9300.00
0005432783809	5624	Economy	9300.00
0005432783827	5624	Economy	9300.00
0005432783816	5624	Economy	9300.00
0005432783811	5624	Economy	9300.00
0005432783288	15365	Business	27800.00
0005432783166	15365	Business	27800.00
0005432783175	15365	Business	27800.00
0005432783400	15365	Business	27800.00
0005435242836	15365	Business	27800.00
0005432783469	15365	Business	27800.00
0005432783168	15365	Business	27800.00
0005432783426	15365	Economy	9300.00
0005435242850	15365	Economy	9300.00
0005432783506	15365	Economy	9300.00
0005435476753	15365	Economy	9300.00
0005435242838	15365	Economy	9300.00
0005435242833	15365	Economy	9300.00
0005432783202	15365	Economy	9300.00
0005432783424	15365	Economy	9300.00
0005432783225	15365	Economy	9300.00
0005435242841	15365	Economy	10200.00
0005432783213	15365	Economy	10200.00
0005432783299	15365	Economy	10200.00
0005435476750	15365	Economy	10200.00
0005435242840	15365	Economy	9300.00
0005435242849	15365	Economy	9300.00
0005435242851	15365	Economy	9300.00
0005435242839	15365	Economy	9300.00
0005432782989	15365	Economy	9300.00
0005432783313	15365	Economy	9300.00
0005435242831	15365	Economy	9300.00
0005432783479	15365	Economy	9300.00
0005435242848	15365	Economy	9300.00
0005435242826	15365	Economy	9300.00
0005432783298	15365	Economy	9300.00
0005435242845	15365	Economy	9300.00
0005435476751	15365	Economy	9300.00
0005432783176	15365	Economy	9300.00
0005432783427	15365	Economy	9300.00
0005432783345	15365	Economy	9300.00
0005435242842	15365	Economy	9300.00
0005435242827	15365	Economy	9300.00
0005432783441	15365	Economy	9300.00
0005435242837	15365	Economy	9300.00
0005435242835	15365	Economy	9300.00
0005435242829	15365	Economy	9300.00
0005435242843	15365	Economy	9300.00
0005435242844	15365	Economy	9300.00
0005432783167	15365	Economy	9300.00
0005432783566	15365	Economy	9300.00
0005432783060	15365	Economy	9300.00
0005432783384	15365	Economy	9300.00
0005435242846	15365	Economy	9300.00
0005432783254	15365	Economy	9300.00
0005435242832	15365	Economy	9300.00
0005435476752	15365	Economy	9300.00
0005432783499	15365	Economy	9300.00
0005432783470	15365	Economy	9300.00
0005435242830	15365	Economy	9300.00
0005432783456	15365	Economy	9300.00
0005432783440	15365	Economy	9300.00
0005432783567	15365	Economy	9300.00
0005435476749	15365	Economy	9300.00
0005432783500	15365	Economy	9300.00
0005435242828	15365	Economy	9300.00
0005432783565	15365	Economy	9300.00
0005432783326	15365	Economy	9300.00
0005435242834	15365	Economy	9300.00
0005432783017	15365	Economy	9300.00
0005432783423	15365	Economy	9300.00
0005432783344	15365	Economy	9300.00
0005432783156	15365	Economy	9300.00
0005432783348	15365	Economy	9300.00
0005432783385	15365	Economy	9300.00
0005435242847	15365	Economy	9300.00
0005432783173	15365	Economy	9300.00
0005432783212	15365	Economy	9300.00
0005435242825	15365	Economy	9300.00
0005432783386	15365	Economy	9300.00
0005432848313	4386	Economy	7000.00
0005434463930	4386	Economy	7000.00
0005435850864	4386	Economy	7000.00
0005435850861	4386	Economy	6300.00
0005435850848	4386	Economy	6300.00
0005432848321	4386	Economy	6300.00
0005432848312	4386	Economy	6300.00
0005435850847	4386	Economy	6300.00
0005432848308	4386	Economy	6300.00
0005432848310	4386	Economy	6300.00
0005432848317	4386	Economy	6300.00
0005432848319	4386	Economy	6300.00
0005435850855	4386	Economy	6300.00
0005432848311	4386	Economy	6300.00
0005435850850	4386	Economy	6300.00
0005434462791	4386	Economy	6300.00
0005432848314	4386	Economy	6300.00
0005435850890	4386	Economy	6300.00
0005432848309	4386	Economy	6300.00
0005435850842	4386	Economy	6300.00
0005432848320	4386	Economy	6300.00
0005435850846	4386	Economy	6300.00
0005435850856	4386	Economy	6300.00
0005432848318	4386	Economy	6300.00
0005434462790	4386	Economy	6300.00
0005435850845	4386	Economy	6300.00
0005432848316	4386	Economy	6300.00
0005435850851	4386	Economy	6300.00
0005434463929	4386	Economy	6300.00
0005432848315	4386	Economy	6300.00
0005434462792	4386	Economy	6300.00
0005435850910	28839	Economy	7000.00
0005434463905	28839	Economy	6300.00
0005434461629	28839	Economy	6300.00
0005434461625	28839	Economy	6300.00
0005432848129	28839	Economy	6300.00
0005434463902	28839	Economy	6300.00
0005435850917	28839	Economy	6300.00
0005434461626	28839	Economy	6300.00
0005434461630	28839	Economy	6300.00
0005432848235	28839	Economy	6300.00
0005432848234	28839	Economy	6300.00
0005435850915	28839	Economy	6300.00
0005435850912	28839	Economy	6300.00
0005432848183	28839	Economy	6300.00
0005435850907	28839	Economy	6300.00
0005432848162	28839	Economy	6300.00
0005435850913	28839	Economy	6300.00
0005432848163	28839	Economy	6300.00
0005432848176	28839	Economy	6300.00
0005432848193	28839	Economy	6300.00
0005434461627	28839	Economy	6300.00
0005435850909	28839	Economy	6300.00
0005435850916	28839	Economy	6300.00
0005432848168	28839	Economy	6300.00
0005434463901	28839	Economy	6300.00
0005435850911	28839	Economy	6300.00
0005435850914	28839	Economy	6300.00
0005432848192	28839	Economy	6300.00
0005435850908	28839	Economy	6300.00
0005433496982	6291	Business	11900.00
0005433496981	6291	Business	11900.00
0005434925806	6291	Business	11900.00
0005433496964	6291	Business	11900.00
0005434925809	6291	Business	11900.00
0005434443706	6291	Business	11900.00
0005434443718	6291	Business	11900.00
0005434925829	6291	Business	11900.00
0005434443717	6291	Business	11900.00
0005434925822	6291	Business	11900.00
0005434925813	6291	Business	11900.00
0005434443714	6291	Business	11900.00
0005433496966	6291	Economy	4000.00
0005434925816	6291	Economy	4000.00
0005433496971	6291	Economy	4000.00
0005434925821	6291	Economy	4000.00
0005433496974	6291	Economy	4000.00
0005433496973	6291	Economy	4000.00
0005434443707	6291	Economy	4000.00
0005434925831	6291	Economy	4000.00
0005433496984	6291	Economy	4000.00
0005433496979	6291	Economy	4400.00
0005434925808	6291	Economy	4400.00
0005434925810	6291	Economy	4400.00
0005433496980	6291	Economy	4400.00
0005433496965	6291	Economy	4400.00
0005434925826	6291	Economy	4000.00
0005434925820	6291	Economy	4000.00
0005433496993	6291	Economy	4000.00
0005434443708	6291	Economy	4000.00
0005434925802	6291	Economy	4000.00
0005434443705	6291	Economy	4000.00
0005434925823	6291	Economy	4000.00
0005434443712	6291	Economy	4000.00
0005433496967	6291	Economy	4000.00
0005433496992	6291	Economy	4000.00
0005433496968	6291	Economy	4000.00
0005433496991	6291	Economy	4000.00
0005433496977	6291	Economy	4000.00
0005433496985	6291	Economy	4000.00
0005433496969	6291	Economy	4000.00
0005434925830	6291	Economy	4000.00
0005433496988	6291	Economy	4000.00
0005434443720	6291	Economy	4000.00
0005434925817	6291	Economy	4000.00
0005434925828	6291	Economy	4000.00
0005434925801	6291	Economy	4000.00
0005434443711	6291	Economy	4000.00
0005432075230	6291	Economy	4000.00
0005432075229	6291	Economy	4000.00
0005434925814	6291	Economy	4000.00
0005434443716	6291	Economy	4000.00
0005433496970	6291	Economy	4000.00
0005434925819	6291	Economy	4000.00
0005434925827	6291	Economy	4000.00
0005433496989	6291	Economy	4000.00
0005434443713	6291	Economy	4000.00
0005433496990	6291	Economy	4000.00
0005433496972	6291	Economy	4000.00
0005434443715	6291	Economy	4000.00
0005433496962	6291	Economy	4000.00
0005434443719	6291	Economy	4000.00
0005434925804	6291	Economy	4000.00
0005432075232	6291	Economy	4000.00
0005434925815	6291	Economy	4000.00
0005433496976	6291	Economy	4000.00
0005433496975	6291	Economy	4000.00
0005434925818	6291	Economy	4000.00
0005434925811	6291	Economy	4000.00
0005434925800	6291	Economy	4000.00
0005433496983	6291	Economy	4000.00
0005433496987	6291	Economy	4000.00
0005434925805	6291	Economy	4000.00
0005434443710	6291	Economy	4000.00
0005434925812	6291	Economy	4000.00
0005433496963	6291	Economy	4000.00
0005434925824	6291	Economy	4000.00
0005433496986	6291	Economy	4000.00
0005434443709	6291	Economy	4000.00
0005434925807	6291	Economy	4000.00
0005433496978	6291	Economy	4000.00
0005434925803	6291	Economy	4000.00
0005434925825	6291	Economy	4000.00
0005432075231	6291	Economy	4000.00
0005434925495	20316	Business	11900.00
0005433496789	20316	Business	11900.00
0005434925440	20316	Business	11900.00
0005434925498	20316	Business	11900.00
0005434925554	20316	Business	11900.00
0005433496678	20316	Business	11900.00
0005433496850	20316	Business	11900.00
0005434443525	20316	Business	11900.00
0005434443565	20316	Business	11900.00
0005434925314	20316	Business	11900.00
0005433496798	20316	Business	11900.00
0005434925542	20316	Economy	4000.00
0005433496794	20316	Economy	4000.00
0005434925497	20316	Economy	4000.00
0005433496774	20316	Economy	4000.00
0005434443543	20316	Economy	4000.00
0005434925488	20316	Economy	4000.00
0005434925437	20316	Economy	4000.00
0005434925556	20316	Economy	4000.00
0005433496727	20316	Economy	4000.00
0005434925454	20316	Economy	4400.00
0005433496806	20316	Economy	4400.00
0005434443566	20316	Economy	4400.00
0005434443545	20316	Economy	4400.00
0005434443546	20316	Economy	4000.00
0005433496755	20316	Economy	4000.00
0005434925486	20316	Economy	4000.00
0005434925543	20316	Economy	4000.00
0005434925432	20316	Economy	4000.00
0005434925438	20316	Economy	4000.00
0005434443623	20316	Economy	4000.00
0005434925516	20316	Economy	4000.00
0005434925525	20316	Economy	4000.00
0005434443547	20316	Economy	4000.00
0005433496679	20316	Economy	4000.00
0005433496660	20316	Economy	4000.00
0005433496803	20316	Economy	4000.00
0005434443558	20316	Economy	4000.00
0005433496761	20316	Economy	4000.00
0005433496744	20316	Economy	4000.00
0005433496848	20316	Economy	4000.00
0005434925555	20316	Economy	4000.00
0005433496760	20316	Economy	4000.00
0005434925514	20316	Economy	4000.00
0005434925327	20316	Economy	4000.00
0005434925517	20316	Economy	4000.00
0005434925407	20316	Economy	4000.00
0005434925560	20316	Economy	4000.00
0005433496799	20316	Economy	4000.00
0005434925405	20316	Economy	4000.00
0005433496762	20316	Economy	4000.00
0005433496712	20316	Economy	4000.00
0005433496743	20316	Economy	4000.00
0005434925557	20316	Economy	4000.00
0005433496669	20316	Economy	4000.00
0005434925374	20316	Economy	4000.00
0005433496763	20316	Economy	4000.00
0005434925406	20316	Economy	4000.00
0005434925494	20316	Economy	4000.00
0005434925328	20316	Economy	4000.00
0005434925410	20316	Economy	4000.00
0005434443582	20316	Economy	4000.00
0005434925536	20316	Economy	4000.00
0005433496646	20316	Economy	4000.00
0005434443585	20316	Economy	4000.00
0005434925513	20316	Economy	4000.00
0005433496804	20316	Economy	4000.00
0005434925487	20316	Economy	4000.00
0005434443539	20316	Economy	4000.00
0005434925515	20316	Economy	4000.00
0005434925548	20316	Economy	4000.00
0005433496768	20316	Economy	4000.00
0005434925559	20316	Economy	4000.00
0005434925564	20316	Economy	4000.00
0005434925558	20316	Economy	4000.00
0005434925537	20316	Economy	4000.00
0005434925520	20316	Economy	4000.00
0005433496742	20316	Economy	4000.00
0005434925527	20316	Economy	4000.00
0005432783330	12213	Business	41200.00
0005435242879	12213	Business	41200.00
0005432783464	12213	Business	41200.00
0005432783327	12213	Business	41200.00
0005432783255	12213	Business	41200.00
0005432783277	12213	Business	41200.00
0005432783438	12213	Business	41200.00
0005432783228	12213	Business	41200.00
0005432782934	12213	Business	41200.00
0005432783130	12213	Economy	13700.00
0005435242862	12213	Economy	13700.00
0005432783329	12213	Economy	13700.00
0005435242871	12213	Economy	13700.00
0005432783468	12213	Economy	13700.00
0005432783640	12213	Economy	13700.00
0005432783222	12213	Economy	13700.00
0005432783311	12213	Economy	15100.00
0005435242873	12213	Economy	15100.00
0005435242863	12213	Economy	15100.00
0005432783315	12213	Economy	15100.00
0005435242875	12213	Economy	13700.00
0005435242878	12213	Economy	13700.00
0005432783224	12213	Economy	13700.00
0005432783244	12213	Economy	13700.00
0005435242854	12213	Economy	13700.00
0005435242858	12213	Economy	13700.00
0005432783351	12213	Economy	13700.00
0005432783459	12213	Economy	13700.00
0005435242864	12213	Economy	13700.00
0005435242872	12213	Economy	13700.00
0005435242867	12213	Economy	13700.00
0005435242856	12213	Economy	13700.00
0005432783555	12213	Economy	13700.00
0005435242868	12213	Economy	13700.00
0005435242877	12213	Economy	13700.00
0005432783290	12213	Economy	13700.00
0005432783339	12213	Economy	13700.00
0005432783221	12213	Economy	13700.00
0005432783474	12213	Economy	13700.00
0005435242855	12213	Economy	13700.00
0005432783285	12213	Economy	13700.00
0005432783338	12213	Economy	13700.00
0005432783226	12213	Economy	13700.00
0005432783331	12213	Economy	13700.00
0005435242860	12213	Economy	13700.00
0005435242866	12213	Economy	13700.00
0005432783284	12213	Economy	13700.00
0005432783347	12213	Economy	13700.00
0005432783190	12213	Economy	13700.00
0005435242869	12213	Economy	13700.00
0005432783312	12213	Economy	13700.00
0005432783289	12213	Economy	13700.00
0005435242857	12213	Economy	13700.00
0005435242874	12213	Economy	13700.00
0005432783276	12213	Economy	13700.00
0005435242853	12213	Economy	13700.00
0005432783592	12213	Economy	13700.00
0005432783473	12213	Economy	13700.00
0005432783507	12213	Economy	13700.00
0005435242865	12213	Economy	13700.00
0005432783223	12213	Economy	13700.00
0005432783073	12213	Economy	13700.00
0005432783207	12213	Economy	13700.00
0005435242861	12213	Economy	13700.00
0005432783439	12213	Economy	13700.00
0005435242870	12213	Economy	13700.00
0005435242876	12213	Economy	13700.00
0005432783352	12213	Economy	13700.00
0005435242852	12213	Economy	13700.00
0005432783328	12213	Economy	13700.00
0005432783463	12213	Economy	13700.00
0005432783420	12213	Economy	13700.00
0005435242859	12213	Economy	13700.00
0005432783575	12213	Economy	13700.00
0005435242682	15423	Business	41200.00
0005432783765	15423	Business	41200.00
0005432783763	15423	Business	41200.00
0005432783757	15423	Business	41200.00
0005435242659	15423	Business	41200.00
0005432783754	15423	Business	41200.00
0005435242592	15423	Business	41200.00
0005435242629	15423	Business	41200.00
0005432783728	15423	Economy	13700.00
0005432783733	15423	Economy	13700.00
0005432783766	15423	Economy	13700.00
0005435242660	15423	Economy	13700.00
0005435242621	15423	Economy	13700.00
0005432783748	15423	Economy	15100.00
0005432783739	15423	Economy	15100.00
0005432783744	15423	Economy	15100.00
0005435242497	15423	Economy	15100.00
0005435242749	15423	Economy	15100.00
0005435242683	15423	Economy	13700.00
0005435242662	15423	Economy	13700.00
0005432783745	15423	Economy	13700.00
0005432783724	15423	Economy	13700.00
0005432783770	15423	Economy	13700.00
0005435242589	15423	Economy	13700.00
0005432783769	15423	Economy	13700.00
0005435242627	15423	Economy	13700.00
0005435242597	15423	Economy	13700.00
0005432783723	15423	Economy	13700.00
0005432783751	15423	Economy	13700.00
0005432783727	15423	Economy	13700.00
0005435242669	15423	Economy	13700.00
0005432783738	15423	Economy	13700.00
0005432783755	15423	Economy	13700.00
0005432783732	15423	Economy	13700.00
0005435242674	15423	Economy	13700.00
0005432783726	15423	Economy	13700.00
0005432783775	15423	Economy	13700.00
0005432783735	15423	Economy	13700.00
0005432783772	15423	Economy	13700.00
0005435242585	15423	Economy	13700.00
0005432783761	15423	Economy	13700.00
0005432783750	15423	Economy	13700.00
0005432783749	15423	Economy	13700.00
0005432783747	15423	Economy	13700.00
0005432783740	15423	Economy	13700.00
0005432783720	15423	Economy	13700.00
0005432783773	15423	Economy	13700.00
0005432783752	15423	Economy	13700.00
0005432783774	15423	Economy	13700.00
0005432783722	15423	Economy	13700.00
0005432783771	15423	Economy	13700.00
0005435242488	15423	Economy	13700.00
0005432783729	15423	Economy	13700.00
0005432783730	15423	Economy	13700.00
0005435242622	15423	Economy	13700.00
0005432783756	15423	Economy	13700.00
0005432783741	15423	Economy	13700.00
0005432783762	15423	Economy	13700.00
0005432783764	15423	Economy	13700.00
0005432783721	15423	Economy	13700.00
0005435242536	15423	Economy	13700.00
0005435242558	15423	Economy	13700.00
0005435242748	15423	Economy	13700.00
0005432783742	15423	Economy	13700.00
0005432783737	15423	Economy	13700.00
0005435242719	15423	Economy	13700.00
0005432783758	15423	Economy	13700.00
0005435242614	15423	Economy	13700.00
0005432783767	15423	Economy	13700.00
0005432783734	15423	Economy	13700.00
0005432783760	15423	Economy	13700.00
0005435242593	15423	Economy	13700.00
0005432783746	15423	Economy	13700.00
0005435242615	15423	Economy	13700.00
0005432783725	15423	Economy	13700.00
0005432783731	15423	Economy	13700.00
0005432783743	15423	Economy	13700.00
0005435242586	15423	Economy	13700.00
0005432783759	15423	Economy	13700.00
0005432783768	15423	Economy	13700.00
0005432783736	15423	Economy	13700.00
0005432783753	15423	Economy	13700.00
0005434877544	10116	Business	49700.00
0005434876966	10116	Business	49700.00
0005434877515	10116	Business	49700.00
0005434877477	10116	Business	49700.00
0005434877847	10116	Business	49700.00
0005434877276	10116	Business	49700.00
0005434877395	10116	Business	49700.00
0005434877613	10116	Business	49700.00
0005434877366	10116	Business	49700.00
0005434877284	10116	Business	49700.00
0005434910113	10116	Business	49700.00
0005434877777	10116	Business	49700.00
0005434877447	10116	Business	49700.00
0005434877294	10116	Business	49700.00
0005434877769	10116	Business	49700.00
0005434876930	10116	Business	49700.00
0005434877435	10116	Business	49700.00
0005434877878	10116	Economy	16600.00
0005434877623	10116	Business	49700.00
0005434877492	10116	Economy	16600.00
0005434877969	10116	Economy	16600.00
0005434877768	10116	Economy	16600.00
0005434877349	10116	Economy	16600.00
0005434877076	10116	Economy	16600.00
0005434877342	10116	Economy	16600.00
0005434877483	10116	Economy	16600.00
0005434877277	10116	Economy	16600.00
0005434877362	10116	Economy	16600.00
0005434877653	10116	Economy	16600.00
0005434877548	10116	Economy	16600.00
0005434877482	10116	Economy	18200.00
0005434877151	10116	Economy	18200.00
0005434877238	10116	Economy	18200.00
0005434877322	10116	Economy	16600.00
0005434877475	10116	Economy	16600.00
0005435913933	10116	Economy	16600.00
0005434877365	10116	Economy	16600.00
0005434877401	10116	Economy	16600.00
0005434877497	10116	Economy	16600.00
0005434910112	10116	Economy	16600.00
0005434877765	10116	Economy	16600.00
0005434877400	10116	Economy	16600.00
0005435913934	10116	Economy	16600.00
0005434877600	10116	Economy	16600.00
0005434877383	10116	Economy	16600.00
0005434758875	10116	Economy	16600.00
0005434877248	10116	Economy	16600.00
0005434877368	10116	Economy	16600.00
0005434877397	10116	Economy	16600.00
0005434877275	10116	Economy	16600.00
0005434910111	10116	Economy	16600.00
0005434877478	10116	Economy	16600.00
0005434877776	10116	Economy	16600.00
0005434877396	10116	Economy	16600.00
0005434876965	10116	Economy	16600.00
0005434877237	10116	Economy	16600.00
0005434877097	10116	Economy	16600.00
0005434877283	10116	Economy	16600.00
0005434877534	10116	Economy	16600.00
0005434877746	10116	Economy	16600.00
0005434877434	10116	Economy	16600.00
0005434877361	10116	Economy	16600.00
0005434877495	10116	Economy	16600.00
0005434877343	10116	Economy	16600.00
0005434877244	10116	Economy	16600.00
0005434876931	10116	Economy	16600.00
0005434877112	10116	Economy	16600.00
0005434877596	10116	Economy	16600.00
0005434877446	10116	Economy	16600.00
0005434877712	10116	Economy	16600.00
0005434877527	10116	Economy	16600.00
0005434877183	10116	Economy	16600.00
0005434877332	10116	Economy	16600.00
0005434877169	10116	Economy	16600.00
0005434877535	10116	Economy	16600.00
0005434877436	10116	Economy	16600.00
0005434877551	10116	Economy	16600.00
0005434877609	10116	Economy	16600.00
0005434877316	10116	Economy	16600.00
0005434877576	10116	Economy	16600.00
0005434877239	10116	Economy	16600.00
0005434877367	10116	Economy	16600.00
0005434877474	10116	Economy	16600.00
0005434877599	10116	Economy	16600.00
0005434877598	10116	Economy	16600.00
0005435913935	10116	Economy	16600.00
0005434877493	10116	Economy	16600.00
0005434877308	10116	Economy	16600.00
0005434877583	10116	Economy	16600.00
0005434877607	10116	Economy	16600.00
0005434877265	10116	Economy	16600.00
0005435913936	10116	Economy	16600.00
0005434877150	10116	Economy	16600.00
0005434877595	10116	Economy	16600.00
0005434877182	10116	Economy	16600.00
0005434877561	10116	Economy	16600.00
0005434877498	10116	Economy	16600.00
0005434877608	10116	Economy	16600.00
0005434877597	10116	Economy	16600.00
0005434877149	10116	Economy	16600.00
0005434877496	10116	Economy	16600.00
0005434877462	10116	Economy	16600.00
0005434877315	10116	Economy	16600.00
0005434877075	10116	Economy	16600.00
0005434877610	10116	Economy	16600.00
0005434758876	10116	Economy	16600.00
0005434877546	10116	Economy	16600.00
0005434878250	14617	Business	49700.00
0005434910092	14617	Business	49700.00
0005434878276	14617	Business	49700.00
0005434878291	14617	Business	49700.00
0005434878236	14617	Business	49700.00
0005434878238	14617	Business	49700.00
0005434878255	14617	Business	49700.00
0005434878232	14617	Business	49700.00
0005434878267	14617	Business	49700.00
0005434878260	14617	Business	49700.00
0005434878286	14617	Business	49700.00
0005434878265	14617	Business	49700.00
0005434878204	14617	Business	49700.00
0005435913874	14617	Business	49700.00
0005434878287	14617	Business	49700.00
0005434878259	14617	Business	49700.00
0005434878210	14617	Business	49700.00
0005434878203	14617	Business	49700.00
0005434878269	14617	Business	49700.00
0005434878292	14617	Economy	16600.00
0005434878283	14617	Economy	16600.00
0005434758894	14617	Economy	16600.00
0005434878256	14617	Economy	16600.00
0005434878279	14617	Economy	16600.00
0005434878233	14617	Economy	16600.00
0005434878222	14617	Economy	16600.00
0005434910089	14617	Economy	16600.00
0005434878235	14617	Economy	16600.00
0005434878224	14617	Economy	16600.00
0005434878290	14617	Economy	16600.00
0005434878229	14617	Economy	16600.00
0005434878249	14617	Economy	16600.00
0005434878225	14617	Economy	18200.00
0005434878243	14617	Economy	18200.00
0005434878202	14617	Economy	18200.00
0005434878275	14617	Economy	16600.00
0005434878241	14617	Economy	18200.00
0005434878261	14617	Economy	16600.00
0005434758893	14617	Economy	16600.00
0005435913895	14617	Economy	16600.00
0005434878220	14617	Economy	16600.00
0005434878213	14617	Economy	16600.00
0005434878228	14617	Economy	16600.00
0005434878218	14617	Economy	16600.00
0005434878252	14617	Economy	16600.00
0005434878237	14617	Economy	16600.00
0005434878270	14617	Economy	16600.00
0005434878263	14617	Economy	16600.00
0005434878223	14617	Economy	16600.00
0005434878281	14617	Economy	16600.00
0005434878280	14617	Economy	16600.00
0005434878262	14617	Economy	16600.00
0005434878289	14617	Economy	16600.00
0005434878266	14617	Economy	16600.00
0005434878258	14617	Economy	16600.00
0005434878246	14617	Economy	16600.00
0005434878268	14617	Economy	16600.00
0005434878227	14617	Economy	16600.00
0005434878282	14617	Economy	16600.00
0005434878221	14617	Economy	16600.00
0005434878212	14617	Economy	16600.00
0005434878217	14617	Economy	16600.00
0005434878205	14617	Economy	16600.00
0005434878209	14617	Economy	16600.00
0005434878208	14617	Economy	16600.00
0005434878214	14617	Economy	16600.00
0005434878242	14617	Economy	16600.00
0005434878294	14617	Economy	16600.00
0005434878234	14617	Economy	16600.00
0005434878240	14617	Economy	16600.00
0005434878206	14617	Economy	16600.00
0005434878215	14617	Economy	16600.00
0005434878297	14617	Economy	16600.00
0005434878284	14617	Economy	16600.00
0005434878257	14617	Economy	16600.00
0005434878219	14617	Economy	16600.00
0005434878288	14617	Economy	16600.00
0005434878231	14617	Economy	16600.00
0005434878293	14617	Economy	16600.00
0005434878254	14617	Economy	16600.00
0005434878251	14617	Economy	16600.00
0005434878226	14617	Economy	16600.00
0005434878245	14617	Economy	16600.00
0005434878264	14617	Economy	16600.00
0005434878285	14617	Economy	16600.00
0005434878239	14617	Economy	16600.00
0005434878244	14617	Economy	16600.00
0005434878247	14617	Economy	16600.00
0005434878211	14617	Economy	16600.00
0005434910093	14617	Economy	16600.00
0005434878216	14617	Economy	16600.00
0005434878277	14617	Economy	16600.00
0005434878273	14617	Economy	16600.00
0005434910094	14617	Economy	16600.00
0005434910091	14617	Economy	16600.00
0005434878298	14617	Economy	16600.00
0005434878296	14617	Economy	16600.00
0005434878207	14617	Economy	16600.00
0005434878295	14617	Economy	16600.00
0005434878253	14617	Economy	16600.00
0005434878230	14617	Economy	16600.00
0005434878278	14617	Economy	16600.00
0005434878272	14617	Economy	16600.00
0005434878248	14617	Economy	16600.00
0005434878274	14617	Economy	16600.00
0005434758892	14617	Economy	16600.00
0005434878271	14617	Economy	16600.00
0005434251865	9214	Economy	22400.00
0005435660137	9214	Economy	22400.00
0005434251882	9214	Economy	20300.00
0005434251883	9214	Economy	20300.00
0005435660133	9214	Economy	20300.00
0005434251858	9214	Economy	20300.00
0005435660135	9214	Economy	20300.00
0005435660136	9214	Economy	20300.00
0005435660134	9214	Economy	20300.00
0005435660144	9214	Economy	20300.00
0005435660142	9214	Economy	20300.00
0005435660139	9214	Economy	20300.00
0005435660140	9214	Economy	20300.00
0005434251866	9214	Economy	20300.00
0005434251907	9214	Economy	20300.00
0005434251896	9214	Economy	20300.00
0005434251873	9214	Economy	20300.00
0005435660143	9214	Economy	20300.00
0005434251897	9214	Economy	20300.00
0005435660138	9214	Economy	20300.00
0005434251875	9214	Economy	20300.00
0005434251874	9214	Economy	20300.00
0005435660141	9214	Economy	20300.00
0005434251908	9214	Economy	20300.00
0005435660034	24628	Economy	22400.00
0005435659992	24628	Economy	20300.00
0005435660053	24628	Economy	20300.00
0005435660052	24628	Economy	20300.00
0005434251967	24628	Economy	20300.00
0005434251961	24628	Economy	20300.00
0005435660054	24628	Economy	20300.00
0005434251969	24628	Economy	20300.00
0005435660036	24628	Economy	20300.00
0005435660048	24628	Economy	20300.00
0005434251964	24628	Economy	20300.00
0005435660016	24628	Economy	20300.00
0005434251963	24628	Economy	20300.00
0005434251962	24628	Economy	20300.00
0005434251966	24628	Economy	20300.00
0005435660061	24628	Economy	20300.00
0005434251965	24628	Economy	20300.00
0005434251968	24628	Economy	20300.00
0005435660035	24628	Economy	20300.00
0005435660055	24628	Economy	20300.00
0005433680586	2815	Business	33000.00
0005432222780	2815	Business	33000.00
0005433680554	2815	Business	33000.00
0005433680541	2815	Business	33000.00
0005433680548	2815	Business	33000.00
0005432222779	2815	Business	33000.00
0005432966726	2815	Business	33000.00
0005432966644	2815	Business	33000.00
0005432966736	2815	Business	33000.00
0005433684420	2815	Business	33000.00
0005433680551	2815	Economy	11000.00
0005433680565	2815	Economy	11000.00
0005433680542	2815	Economy	11000.00
0005433680571	2815	Economy	11000.00
0005433680546	2815	Economy	11000.00
0005432966682	2815	Economy	11000.00
0005432966592	2815	Economy	12100.00
0005433680573	2815	Economy	11000.00
0005433680575	2815	Economy	12100.00
0005433680544	2815	Economy	12100.00
0005432966681	2815	Economy	12100.00
0005433680585	2815	Economy	11000.00
0005433680553	2815	Economy	11000.00
0005432966676	2815	Economy	11000.00
0005432966710	2815	Economy	11000.00
0005433680549	2815	Economy	11000.00
0005432966593	2815	Economy	11000.00
0005432966734	2815	Economy	11000.00
0005433680577	2815	Economy	11000.00
0005433680563	2815	Economy	11000.00
0005433680581	2815	Economy	11000.00
0005433680557	2815	Economy	11000.00
0005433680574	2815	Economy	11000.00
0005433680587	2815	Economy	11000.00
0005433680558	2815	Economy	11000.00
0005433680572	2815	Economy	11000.00
0005433680569	2815	Economy	11000.00
0005432966789	2815	Economy	11000.00
0005432222785	2815	Economy	11000.00
0005433680556	2815	Economy	11000.00
0005433680550	2815	Economy	11000.00
0005432222783	2815	Economy	11000.00
0005433680555	2815	Economy	11000.00
0005432966770	2815	Economy	11000.00
0005433680583	2815	Economy	11000.00
0005432966680	2815	Economy	11000.00
0005432222782	2815	Economy	11000.00
0005432222784	2815	Economy	11000.00
0005433680547	2815	Economy	11000.00
0005433680540	2815	Economy	11000.00
0005433680564	2815	Economy	11000.00
0005433680566	2815	Economy	11000.00
0005432966735	2815	Economy	11000.00
0005433680588	2815	Economy	11000.00
0005432222781	2815	Economy	11000.00
0005432966594	2815	Economy	11000.00
0005432966788	2815	Economy	11000.00
0005433680562	2815	Economy	11000.00
0005433680576	2815	Economy	11000.00
0005433680570	2815	Economy	11000.00
0005433680560	2815	Economy	11000.00
0005433680582	2815	Economy	11000.00
0005433680580	2815	Economy	11000.00
0005433680568	2815	Economy	11000.00
0005433680579	2815	Economy	11000.00
0005432966769	2815	Economy	11000.00
0005433680567	2815	Economy	11000.00
0005433680559	2815	Economy	11000.00
0005433680552	2815	Economy	11000.00
0005432966731	2815	Economy	11000.00
0005432966758	2815	Economy	11000.00
0005433680561	2815	Economy	11000.00
0005433680545	2815	Economy	11000.00
0005432966656	2815	Economy	11000.00
0005433680578	2815	Economy	11000.00
0005432966671	2815	Economy	11000.00
0005433684419	2815	Economy	11000.00
0005433680543	2815	Economy	11000.00
0005433680584	2815	Economy	11000.00
0005432966643	2815	Economy	11000.00
0005432966787	2815	Economy	11000.00
0005433680250	29163	Business	33000.00
0005433680018	29163	Business	33000.00
0005433680007	29163	Business	33000.00
0005432966923	29163	Business	33000.00
0005433680258	29163	Business	33000.00
0005433690907	29163	Business	33000.00
0005432966929	29163	Business	33000.00
0005433684409	29163	Business	33000.00
0005433680104	29163	Business	33000.00
0005433680270	29163	Business	33000.00
0005433680227	29163	Business	33000.00
0005433680017	29163	Economy	11000.00
0005432966947	29163	Economy	11000.00
0005432966938	29163	Economy	11000.00
0005432966948	29163	Economy	11000.00
0005433680389	29163	Economy	11000.00
0005432966935	29163	Economy	11000.00
0005432966939	29163	Economy	11000.00
0005432966940	29163	Economy	11000.00
0005432966925	29163	Economy	11000.00
0005432966924	29163	Economy	12100.00
0005433680213	29163	Economy	12100.00
0005433680105	29163	Economy	12100.00
0005433690904	29163	Economy	12100.00
0005432966928	29163	Economy	12100.00
0005433680006	29163	Economy	11000.00
0005433680204	29163	Economy	11000.00
0005433680332	29163	Economy	11000.00
0005432966946	29163	Economy	11000.00
0005432966941	29163	Economy	11000.00
0005432966931	29163	Economy	11000.00
0005433680008	29163	Economy	11000.00
0005433679973	29163	Economy	11000.00
0005433680200	29163	Economy	11000.00
0005433690915	29163	Economy	11000.00
0005433684408	29163	Economy	11000.00
0005432966943	29163	Economy	11000.00
0005433680282	29163	Economy	11000.00
0005432966930	29163	Economy	11000.00
0005433684414	29163	Economy	11000.00
0005433680159	29163	Economy	11000.00
0005433680102	29163	Economy	11000.00
0005432966926	29163	Economy	11000.00
0005432966927	29163	Economy	11000.00
0005433680182	29163	Economy	11000.00
0005433680177	29163	Economy	11000.00
0005432966933	29163	Economy	11000.00
0005433680212	29163	Economy	11000.00
0005432966934	29163	Economy	11000.00
0005433679950	29163	Economy	11000.00
0005432005212	29163	Economy	11000.00
0005433690916	29163	Economy	11000.00
0005433680281	29163	Economy	11000.00
0005432005214	29163	Economy	11000.00
0005433680014	29163	Economy	11000.00
0005433680171	29163	Economy	11000.00
0005432966932	29163	Economy	11000.00
0005433680247	29163	Economy	11000.00
0005432966937	29163	Economy	11000.00
0005433680341	29163	Economy	11000.00
0005432966945	29163	Economy	11000.00
0005433680222	29163	Economy	11000.00
0005433679859	29163	Economy	11000.00
0005433690900	29163	Economy	11000.00
0005433680023	29163	Economy	11000.00
0005433680093	29163	Economy	11000.00
0005433680259	29163	Economy	11000.00
0005433680266	29163	Economy	11000.00
0005432005213	29163	Economy	11000.00
0005432966936	29163	Economy	11000.00
0005432966944	29163	Economy	11000.00
0005433680248	29163	Economy	11000.00
0005433680265	29163	Economy	11000.00
0005433680310	29163	Economy	11000.00
0005432966942	29163	Economy	11000.00
0005433680013	29163	Economy	11000.00
0005433680024	29163	Economy	11000.00
0005433680158	29163	Economy	11000.00
0005433680214	29163	Economy	11000.00
0005433680114	29163	Economy	11000.00
0005433680377	29163	Economy	11000.00
0005433680205	29163	Economy	11000.00
0005433680249	29163	Economy	11000.00
0005433680337	29163	Economy	11000.00
0005433679991	29163	Economy	11000.00
0005433690914	29163	Economy	11000.00
0005433680251	29163	Economy	11000.00
0005433633773	9306	Business	132900.00
0005433614592	9306	Business	132900.00
0005433614642	9306	Business	132900.00
0005433614637	9306	Business	132900.00
0005433633776	9306	Business	132900.00
0005433614598	9306	Business	132900.00
0005433633778	9306	Business	132900.00
0005433614630	9306	Business	132900.00
0005432756845	9306	Business	132900.00
0005433614597	9306	Business	132900.00
0005433614617	9306	Business	132900.00
0005433614627	9306	Business	132900.00
0005433614651	9306	Business	132900.00
0005433614612	9306	Business	132900.00
0005433633787	9306	Business	132900.00
0005433577810	9306	Business	132900.00
0005433633784	9306	Business	132900.00
0005434163541	9306	Business	132900.00
0005433577811	9306	Business	132900.00
0005432755074	9306	Business	132900.00
0005434163542	9306	Business	132900.00
0005433614639	9306	Business	132900.00
0005433614610	9306	Economy	48700.00
0005433633781	9306	Economy	48700.00
0005433633792	9306	Economy	48700.00
0005434269086	9306	Economy	48700.00
0005433577799	9306	Economy	44300.00
0005433577798	9306	Economy	44300.00
0005433614604	9306	Economy	44300.00
0005432755075	9306	Economy	44300.00
0005433614589	9306	Economy	44300.00
0005433614652	9306	Economy	44300.00
0005433633797	9306	Economy	44300.00
0005433614636	9306	Economy	44300.00
0005433614649	9306	Economy	44300.00
0005433633777	9306	Economy	44300.00
0005433633789	9306	Economy	44300.00
0005432145110	9306	Economy	44300.00
0005433614593	9306	Economy	44300.00
0005433614622	9306	Economy	44300.00
0005433633793	9306	Economy	44300.00
0005433577805	9306	Economy	44300.00
0005433614648	9306	Economy	44300.00
0005433614628	9306	Economy	44300.00
0005433614644	9306	Economy	44300.00
0005433633796	9306	Economy	44300.00
0005433614646	9306	Economy	44300.00
0005433633780	9306	Economy	44300.00
0005433577800	9306	Economy	44300.00
0005433614650	9306	Economy	44300.00
0005433633786	9306	Economy	44300.00
0005433577806	9306	Economy	44300.00
0005433614613	9306	Economy	44300.00
0005433614618	9306	Economy	44300.00
0005433614643	9306	Economy	44300.00
0005432756848	9306	Economy	44300.00
0005433633791	9306	Economy	44300.00
0005433614602	9306	Economy	44300.00
0005433614654	9306	Economy	44300.00
0005433614614	9306	Economy	44300.00
0005433633802	9306	Economy	44300.00
0005433614599	9306	Economy	44300.00
0005433633785	9306	Economy	44300.00
0005434272181	9306	Economy	44300.00
0005433614585	9306	Economy	44300.00
0005433633774	9306	Economy	44300.00
0005433614609	9306	Economy	44300.00
0005433633788	9306	Economy	44300.00
0005433614638	9306	Economy	44300.00
0005433614631	9306	Economy	44300.00
0005434269090	9306	Economy	44300.00
0005433614658	9306	Economy	44300.00
0005433614584	9306	Economy	44300.00
0005433633771	9306	Economy	44300.00
0005433614647	9306	Economy	44300.00
0005433633794	9306	Economy	44300.00
0005433577802	9306	Economy	48700.00
0005433633779	9306	Economy	48700.00
0005433577801	9306	Economy	48700.00
0005433633783	9306	Economy	48700.00
0005433614623	9306	Economy	48700.00
0005433577803	9306	Economy	44300.00
0005433614606	9306	Economy	44300.00
0005433614624	9306	Economy	48700.00
0005432756846	9306	Economy	44300.00
0005433614603	9306	Economy	44300.00
0005433633798	9306	Economy	44300.00
0005433577809	9306	Economy	44300.00
0005434152779	9306	Economy	44300.00
0005433633801	9306	Economy	44300.00
0005433614634	9306	Economy	44300.00
0005433614596	9306	Economy	44300.00
0005433614587	9306	Economy	44300.00
0005433633775	9306	Economy	44300.00
0005433633795	9306	Economy	44300.00
0005433614616	9306	Economy	44300.00
0005433614641	9306	Economy	44300.00
0005433614588	9306	Economy	44300.00
0005433614615	9306	Economy	44300.00
0005433614656	9306	Economy	44300.00
0005433614586	9306	Economy	44300.00
0005433633806	9306	Economy	44300.00
0005433614591	9306	Economy	44300.00
0005433614611	9306	Economy	44300.00
0005433614655	9306	Economy	44300.00
0005433614626	9306	Economy	44300.00
0005433614607	9306	Economy	44300.00
0005433614635	9306	Economy	44300.00
0005433633803	9306	Economy	44300.00
0005433614608	9306	Economy	44300.00
0005433614640	9306	Economy	44300.00
0005433614600	9306	Economy	44300.00
0005433614605	9306	Economy	44300.00
0005433614621	9306	Economy	44300.00
0005434163537	9306	Economy	44300.00
0005433614594	9306	Economy	44300.00
0005433614595	9306	Economy	44300.00
0005433633772	9306	Economy	44300.00
0005433614632	9306	Economy	44300.00
0005433614633	9306	Economy	44300.00
0005433633790	9306	Economy	44300.00
0005433577807	9306	Economy	44300.00
0005433614645	9306	Economy	44300.00
0005432755073	9306	Economy	44300.00
0005433614653	9306	Economy	44300.00
0005433633805	9306	Economy	44300.00
0005433577808	9306	Economy	44300.00
0005433633800	9306	Economy	44300.00
0005433633782	9306	Economy	44300.00
0005433614590	9306	Economy	44300.00
0005433614601	9306	Economy	44300.00
0005433614620	9306	Economy	44300.00
0005433633799	9306	Economy	44300.00
0005434163543	9306	Economy	44300.00
0005433614619	9306	Economy	44300.00
0005433614629	9306	Economy	44300.00
0005432756847	9306	Economy	44300.00
0005433614657	9306	Economy	44300.00
0005434269091	9306	Economy	44300.00
0005433633804	9306	Economy	44300.00
0005433577804	9306	Economy	44300.00
0005433614625	9306	Economy	44300.00
0005433613865	25256	Business	132900.00
0005433613985	25256	Business	132900.00
0005433577706	25256	Business	132900.00
0005433613629	25256	Business	132900.00
0005433633375	25256	Business	132900.00
0005433633407	25256	Business	132900.00
0005433614358	25256	Business	132900.00
0005433614176	25256	Business	132900.00
0005433633362	25256	Business	132900.00
0005432755028	25256	Business	132900.00
0005433613851	25256	Business	132900.00
0005433613906	25256	Business	132900.00
0005433614000	25256	Business	132900.00
0005433614112	25256	Business	132900.00
0005434152781	25256	Business	132900.00
0005432751485	25256	Business	132900.00
0005433613836	25256	Business	132900.00
0005433613986	25256	Business	132900.00
0005433614066	25256	Business	132900.00
0005433613931	25256	Business	132900.00
0005433633478	25256	Business	132900.00
0005433577679	25256	Business	132900.00
0005433577731	25256	Business	132900.00
0005433633492	25256	Business	132900.00
0005432755033	25256	Business	132900.00
0005433613893	25256	Business	132900.00
0005433633534	25256	Business	132900.00
0005433614263	25256	Business	132900.00
0005433614162	25256	Economy	48700.00
0005433614071	25256	Economy	48700.00
0005433614113	25256	Economy	48700.00
0005433613892	25256	Economy	48700.00
0005433613932	25256	Economy	48700.00
0005432751508	25256	Economy	48700.00
0005433614223	25256	Economy	44300.00
0005433614400	25256	Economy	44300.00
0005433613618	25256	Economy	44300.00
0005432751487	25256	Economy	44300.00
0005433633675	25256	Economy	44300.00
0005432751495	25256	Economy	44300.00
0005433577618	25256	Economy	44300.00
0005433614349	25256	Economy	44300.00
0005433633442	25256	Economy	44300.00
0005433633502	25256	Economy	44300.00
0005433633430	25256	Economy	44300.00
0005432751502	25256	Economy	44300.00
0005433633501	25256	Economy	44300.00
0005433613540	25256	Economy	44300.00
0005433613849	25256	Economy	44300.00
0005433577730	25256	Economy	44300.00
0005433633500	25256	Economy	44300.00
0005433614087	25256	Economy	44300.00
0005433614007	25256	Economy	44300.00
0005432755035	25256	Economy	44300.00
0005433613861	25256	Economy	44300.00
0005433613957	25256	Economy	44300.00
0005433613757	25256	Economy	44300.00
0005433613967	25256	Economy	44300.00
0005433613539	25256	Economy	44300.00
0005433614053	25256	Economy	44300.00
0005433633441	25256	Economy	44300.00
0005433633677	25256	Economy	44300.00
0005433613883	25256	Economy	44300.00
0005432751494	25256	Economy	44300.00
0005433613687	25256	Economy	44300.00
0005433613884	25256	Economy	44300.00
0005433613688	25256	Economy	44300.00
0005432755026	25256	Economy	44300.00
0005432755038	25256	Economy	44300.00
0005433633394	25256	Economy	44300.00
0005432751486	25256	Economy	44300.00
0005433633431	25256	Economy	44300.00
0005433613894	25256	Economy	44300.00
0005433577705	25256	Economy	44300.00
0005433633490	25256	Economy	44300.00
0005433633505	25256	Economy	44300.00
0005433633406	25256	Economy	44300.00
0005433614031	25256	Economy	44300.00
0005433613966	25256	Economy	44300.00
0005433614045	25256	Economy	44300.00
0005432751483	25256	Economy	44300.00
0005433577671	25256	Economy	44300.00
0005433633580	25256	Economy	44300.00
0005433613630	25256	Economy	44300.00
0005433633521	25256	Economy	44300.00
0005433613778	25256	Economy	44300.00
0005433577707	25256	Economy	44300.00
0005432751492	25256	Economy	44300.00
0005433633647	25256	Economy	44300.00
0005433613999	25256	Economy	44300.00
0005433613689	25256	Economy	44300.00
0005433614174	25256	Economy	48700.00
0005433614029	25256	Economy	48700.00
0005433614170	25256	Economy	48700.00
0005433633516	25256	Economy	48700.00
0005433614102	25256	Economy	44300.00
0005433614052	25256	Economy	44300.00
0005433577678	25256	Economy	44300.00
0005433614001	25256	Economy	44300.00
0005433614091	25256	Economy	48700.00
0005433613924	25256	Economy	44300.00
0005432751507	25256	Economy	44300.00
0005433614107	25256	Economy	44300.00
0005433633470	25256	Economy	44300.00
0005433613933	25256	Economy	44300.00
0005432755027	25256	Economy	44300.00
0005433614350	25256	Economy	44300.00
0005433633475	25256	Economy	44300.00
0005433614099	25256	Economy	44300.00
0005433614059	25256	Economy	44300.00
0005433633646	25256	Economy	44300.00
0005433613988	25256	Economy	44300.00
0005433613791	25256	Economy	44300.00
0005433633545	25256	Economy	44300.00
0005433613864	25256	Economy	44300.00
0005433633533	25256	Economy	44300.00
0005433614211	25256	Economy	44300.00
0005433633439	25256	Economy	44300.00
0005433613777	25256	Economy	44300.00
0005433614139	25256	Economy	44300.00
0005433613862	25256	Economy	44300.00
0005433613968	25256	Economy	44300.00
0005433613970	25256	Economy	44300.00
0005432755047	25256	Economy	44300.00
0005433614108	25256	Economy	44300.00
0005432755032	25256	Economy	44300.00
0005433614210	25256	Economy	44300.00
0005433633586	25256	Economy	44300.00
0005432751484	25256	Economy	44300.00
0005432755036	25256	Economy	44300.00
0005433614175	25256	Economy	44300.00
0005433613792	25256	Economy	44300.00
0005433633494	25256	Economy	44300.00
0005433614109	25256	Economy	44300.00
0005433613799	25256	Economy	44300.00
0005433614070	25256	Economy	44300.00
0005433633361	25256	Economy	44300.00
0005432755034	25256	Economy	44300.00
0005432751481	25256	Economy	44300.00
0005433614023	25256	Economy	44300.00
0005432751478	25256	Economy	44300.00
0005433614177	25256	Economy	44300.00
0005433633676	25256	Economy	44300.00
0005433613971	25256	Economy	44300.00
0005433614067	25256	Economy	44300.00
0005433633520	25256	Economy	44300.00
0005432755031	25256	Economy	44300.00
0005433633504	25256	Economy	44300.00
0005433613979	25256	Economy	44300.00
0005433577708	25256	Economy	44300.00
0005433633517	25256	Economy	44300.00
0005433614030	25256	Economy	44300.00
0005433613732	25256	Economy	44300.00
0005433613965	25256	Economy	44300.00
0005433633639	25256	Economy	44300.00
0005433614138	25256	Economy	44300.00
0005433613699	25256	Economy	44300.00
0005433633440	25256	Economy	44300.00
0005433633556	25256	Economy	44300.00
0005433613860	25256	Economy	44300.00
0005432571280	4227	Business	193100.00
0005435986762	4227	Business	193100.00
0005435947142	4227	Economy	70800.00
0005435854051	4227	Economy	64400.00
0005435986768	4227	Economy	64400.00
0005435986761	4227	Economy	64400.00
0005435856176	4227	Economy	64400.00
0005435986763	4227	Economy	64400.00
0005435947106	4227	Economy	64400.00
0005435947095	4227	Economy	64400.00
0005435947170	4227	Economy	64400.00
0005435947113	4227	Economy	64400.00
0005435986759	4227	Economy	64400.00
0005435986766	4227	Economy	64400.00
0005432571269	4227	Economy	64400.00
0005435856169	4227	Economy	64400.00
0005435986760	4227	Economy	64400.00
0005434271292	4227	Economy	64400.00
0005435947075	4227	Economy	64400.00
0005432184951	4227	Economy	64400.00
0005435986765	4227	Economy	64400.00
0005434271289	4227	Economy	64400.00
0005432184950	4227	Economy	64400.00
0005435787329	4227	Economy	64400.00
0005435986767	4227	Economy	64400.00
0005435947112	4227	Economy	64400.00
0005432184949	4227	Economy	64400.00
0005435986770	4227	Economy	64400.00
0005435947143	4227	Economy	64400.00
0005435986769	4227	Economy	64400.00
0005435986764	4227	Economy	64400.00
0005435947184	4227	Economy	64400.00
0005435947257	26591	Business	193100.00
0005435856204	26591	Business	193100.00
0005435947258	26591	Economy	64400.00
0005435947256	26591	Economy	64400.00
0005435986680	26591	Economy	64400.00
0005432571325	26591	Economy	64400.00
0005435856206	26591	Economy	64400.00
0005435947262	26591	Economy	64400.00
0005435787355	26591	Economy	64400.00
0005435947254	26591	Economy	64400.00
0005435947251	26591	Economy	64400.00
0005435986712	26591	Economy	64400.00
0005435947260	26591	Economy	64400.00
0005432571326	26591	Economy	64400.00
0005435947252	26591	Economy	64400.00
0005435856205	26591	Economy	64400.00
0005435986684	26591	Economy	64400.00
0005435947264	26591	Economy	70800.00
0005435947263	26591	Economy	64400.00
0005435856207	26591	Economy	64400.00
0005435947261	26591	Economy	64400.00
0005435947255	26591	Economy	64400.00
0005435947259	26591	Economy	64400.00
0005435787356	26591	Economy	64400.00
0005435947253	26591	Economy	64400.00
0005435986683	26591	Economy	64400.00
0005435986705	26591	Economy	64400.00
0005433569115	332	Business	21500.00
0005433569118	332	Business	21500.00
0005433129243	332	Business	21500.00
0005433134089	332	Business	21500.00
0005433569110	332	Business	21500.00
0005433074433	332	Business	21500.00
0005432948089	332	Business	21500.00
0005433569072	332	Business	21500.00
0005433074559	332	Business	21500.00
0005432238940	332	Business	21500.00
0005432948083	332	Business	21500.00
0005433569100	332	Business	21500.00
0005432948104	332	Business	21500.00
0005432238936	332	Business	21500.00
0005433569061	332	Business	21500.00
0005433569095	332	Business	21500.00
0005433569060	332	Business	21500.00
0005433074466	332	Business	21500.00
0005432948088	332	Business	21500.00
0005432948095	332	Business	21500.00
0005433569070	332	Business	21500.00
0005433074508	332	Economy	7900.00
0005433569062	332	Economy	7900.00
0005432238934	332	Economy	7900.00
0005433074395	332	Economy	7900.00
0005432948188	332	Economy	7900.00
0005433569108	332	Economy	7200.00
0005433569089	332	Economy	7200.00
0005433074479	332	Economy	7200.00
0005433569083	332	Economy	7200.00
0005433074582	332	Economy	7200.00
0005433569116	332	Economy	7200.00
0005432948010	332	Economy	7200.00
0005433569074	332	Economy	7200.00
0005432238935	332	Economy	7200.00
0005433569087	332	Economy	7200.00
0005433569084	332	Economy	7200.00
0005433569101	332	Economy	7200.00
0005433569059	332	Economy	7200.00
0005433074365	332	Economy	7200.00
0005432948069	332	Economy	7200.00
0005432948068	332	Economy	7200.00
0005433569050	332	Economy	7200.00
0005433569120	332	Economy	7200.00
0005432948103	332	Economy	7200.00
0005433074343	332	Economy	7200.00
0005433569063	332	Economy	7200.00
0005433074429	332	Economy	7200.00
0005433569107	332	Economy	7200.00
0005433129231	332	Economy	7200.00
0005433074342	332	Economy	7200.00
0005433569052	332	Economy	7200.00
0005433569049	332	Economy	7200.00
0005433569077	332	Economy	7200.00
0005433569111	332	Economy	7200.00
0005433074568	332	Economy	7200.00
0005433569068	332	Economy	7200.00
0005433569075	332	Economy	7200.00
0005433129224	332	Economy	7200.00
0005433569114	332	Economy	7200.00
0005433074432	332	Economy	7200.00
0005433569109	332	Economy	7200.00
0005433074581	332	Economy	7200.00
0005433569096	332	Economy	7200.00
0005433569117	332	Economy	7200.00
0005433569051	332	Economy	7200.00
0005432947892	332	Economy	7200.00
0005433074326	332	Economy	7200.00
0005433074245	332	Economy	7200.00
0005433129225	332	Economy	7200.00
0005432948094	332	Economy	7200.00
0005433569112	332	Economy	7200.00
0005433074494	332	Economy	7200.00
0005432948045	332	Economy	7200.00
0005433569085	332	Economy	7200.00
0005432948127	332	Economy	7200.00
0005433569121	332	Economy	7200.00
0005433569066	332	Economy	7200.00
0005433129230	332	Economy	7200.00
0005433074467	332	Economy	7200.00
0005433074431	332	Economy	7200.00
0005433569103	332	Economy	7200.00
0005433074394	332	Economy	7900.00
0005433074244	332	Economy	7900.00
0005433569056	332	Economy	7900.00
0005433569076	332	Economy	7900.00
0005433074355	332	Economy	7200.00
0005433074340	332	Economy	7200.00
0005433569058	332	Economy	7200.00
0005433569123	332	Economy	7200.00
0005432948007	332	Economy	7900.00
0005433074327	332	Economy	7200.00
0005432948186	332	Economy	7200.00
0005433569105	332	Economy	7200.00
0005433569088	332	Economy	7200.00
0005433569054	332	Economy	7200.00
0005433569067	332	Economy	7200.00
0005432238939	332	Economy	7200.00
0005433569102	332	Economy	7200.00
0005433569081	332	Economy	7200.00
0005433074525	332	Economy	7200.00
0005432948096	332	Economy	7200.00
0005433569055	332	Economy	7200.00
0005433569094	332	Economy	7200.00
0005432238937	332	Economy	7200.00
0005433569078	332	Economy	7200.00
0005433569073	332	Economy	7200.00
0005433129238	332	Economy	7200.00
0005433569092	332	Economy	7200.00
0005433569065	332	Economy	7200.00
0005433134098	332	Economy	7200.00
0005433569080	332	Economy	7200.00
0005433569057	332	Economy	7200.00
0005433074562	332	Economy	7200.00
0005432948164	332	Economy	7200.00
0005433569122	332	Economy	7200.00
0005433074430	332	Economy	7200.00
0005433569069	332	Economy	7200.00
0005433074575	332	Economy	7200.00
0005433569086	332	Economy	7200.00
0005433569093	332	Economy	7200.00
0005432948052	332	Economy	7200.00
0005433569106	332	Economy	7200.00
0005433569071	332	Economy	7200.00
0005433074412	332	Economy	7200.00
0005432238938	332	Economy	7200.00
0005433569064	332	Economy	7200.00
0005433569082	332	Economy	7200.00
0005433129247	332	Economy	7200.00
0005433129246	332	Economy	7200.00
0005432948028	332	Economy	7200.00
0005433569053	332	Economy	7200.00
0005433569104	332	Economy	7200.00
0005433569119	332	Economy	7200.00
0005433569099	332	Economy	7200.00
0005433074435	332	Economy	7200.00
0005433134090	332	Economy	7200.00
0005432948128	332	Economy	7200.00
0005432948272	332	Economy	7200.00
0005433569113	332	Economy	7200.00
0005433074243	332	Economy	7200.00
0005433569097	332	Economy	7200.00
0005432948046	332	Economy	7200.00
0005432948027	332	Economy	7200.00
0005433074434	332	Economy	7200.00
0005433569091	332	Economy	7200.00
0005433074509	332	Economy	7200.00
0005433569079	332	Economy	7200.00
0005433129223	332	Economy	7200.00
0005433074471	332	Economy	7200.00
0005433569098	332	Economy	7200.00
0005433129248	332	Economy	7200.00
0005433569090	332	Economy	7200.00
0005432948432	11612	Business	21500.00
0005433568645	11612	Business	21500.00
0005433568431	11612	Business	21500.00
0005433568273	11612	Business	21500.00
0005432948443	11612	Business	21500.00
0005433568271	11612	Business	21500.00
0005432948460	11612	Business	21500.00
0005433568376	11612	Business	21500.00
0005433074699	11612	Business	21500.00
0005433568435	11612	Business	21500.00
0005433074701	11612	Business	21500.00
0005433131709	11612	Business	21500.00
0005432948453	11612	Business	21500.00
0005432948439	11612	Business	21500.00
0005433568445	11612	Business	21500.00
0005433568513	11612	Business	21500.00
0005432948435	11612	Business	21500.00
0005433074714	11612	Business	21500.00
0005433074715	11612	Business	21500.00
0005433074711	11612	Business	21500.00
0005433568436	11612	Business	21500.00
0005432192320	11612	Business	21500.00
0005433568474	11612	Economy	7900.00
0005433568229	11612	Economy	7900.00
0005433074706	11612	Economy	7900.00
0005433074716	11612	Economy	7900.00
0005432948466	11612	Economy	7900.00
0005432948434	11612	Economy	7200.00
0005433074720	11612	Economy	7200.00
0005432948456	11612	Economy	7200.00
0005433568485	11612	Economy	7200.00
0005433568701	11612	Economy	7200.00
0005433074694	11612	Economy	7200.00
0005432948458	11612	Economy	7200.00
0005432948462	11612	Economy	7200.00
0005432948457	11612	Economy	7200.00
0005432948454	11612	Economy	7200.00
0005433568682	11612	Economy	7200.00
0005433568434	11612	Economy	7200.00
0005432948446	11612	Economy	7200.00
0005433568544	11612	Economy	7200.00
0005433568393	11612	Economy	7200.00
0005433074719	11612	Economy	7200.00
0005433568570	11612	Economy	7200.00
0005432948438	11612	Economy	7200.00
0005433074705	11612	Economy	7200.00
0005433074707	11612	Economy	7200.00
0005433568504	11612	Economy	7200.00
0005432948450	11612	Economy	7200.00
0005433568501	11612	Economy	7200.00
0005433074712	11612	Economy	7200.00
0005432948467	11612	Economy	7200.00
0005433568344	11612	Economy	7200.00
0005433074703	11612	Economy	7200.00
0005433074709	11612	Economy	7200.00
0005433568484	11612	Economy	7200.00
0005433568194	11612	Economy	7200.00
0005433074696	11612	Economy	7200.00
0005433074710	11612	Economy	7200.00
0005433568534	11612	Economy	7200.00
0005433568569	11612	Economy	7200.00
0005433568542	11612	Economy	7200.00
0005432948464	11612	Economy	7200.00
0005432948449	11612	Economy	7200.00
0005433131710	11612	Economy	7200.00
0005433074692	11612	Economy	7200.00
0005433568444	11612	Economy	7200.00
0005433074704	11612	Economy	7200.00
0005433568455	11612	Economy	7200.00
0005433134136	11612	Economy	7200.00
0005433134139	11612	Economy	7200.00
0005433074708	11612	Economy	7200.00
0005433568343	11612	Economy	7200.00
0005433568437	11612	Economy	7200.00
0005433134138	11612	Economy	7200.00
0005432948441	11612	Economy	7200.00
0005432948452	11612	Economy	7900.00
0005433074702	11612	Economy	7900.00
0005433568517	11612	Economy	7900.00
0005432948436	11612	Economy	7900.00
0005433074697	11612	Economy	7200.00
0005433568457	11612	Economy	7200.00
0005433568512	11612	Economy	7200.00
0005433074700	11612	Economy	7200.00
0005433131707	11612	Economy	7900.00
0005433568323	11612	Economy	7200.00
0005433074717	11612	Economy	7200.00
0005433131706	11612	Economy	7200.00
0005433134137	11612	Economy	7200.00
0005433568375	11612	Economy	7200.00
0005432948437	11612	Economy	7200.00
0005433568416	11612	Economy	7200.00
0005433568413	11612	Economy	7200.00
0005432948465	11612	Economy	7200.00
0005433568497	11612	Economy	7200.00
0005433568496	11612	Economy	7200.00
0005433568469	11612	Economy	7200.00
0005432948445	11612	Economy	7200.00
0005433568468	11612	Economy	7200.00
0005432948433	11612	Economy	7200.00
0005433568319	11612	Economy	7200.00
0005432948470	11612	Economy	7200.00
0005432948459	11612	Economy	7200.00
0005433568592	11612	Economy	7200.00
0005433568265	11612	Economy	7200.00
0005432948461	11612	Economy	7200.00
0005432192319	11612	Economy	7200.00
0005432948440	11612	Economy	7200.00
0005433131708	11612	Economy	7200.00
0005433074695	11612	Economy	7200.00
0005432192321	11612	Economy	7200.00
0005433568543	11612	Economy	7200.00
0005432948463	11612	Economy	7200.00
0005432948448	11612	Economy	7200.00
0005432948451	11612	Economy	7200.00
0005432948471	11612	Economy	7200.00
0005433568379	11612	Economy	7200.00
0005433568610	11612	Economy	7200.00
0005433568417	11612	Economy	7200.00
0005432948444	11612	Economy	7200.00
0005433568433	11612	Economy	7200.00
0005433074718	11612	Economy	7200.00
0005432948442	11612	Economy	7200.00
0005432948468	11612	Economy	7200.00
0005433568470	11612	Economy	7200.00
0005433568679	11612	Economy	7200.00
0005433568456	11612	Economy	7200.00
0005432948447	11612	Economy	7200.00
0005433568290	11612	Economy	7200.00
0005433568232	11612	Economy	7200.00
0005433568591	11612	Economy	7200.00
0005433568362	11612	Economy	7200.00
0005432948455	11612	Economy	7200.00
0005432948469	11612	Economy	7200.00
0005433568397	11612	Economy	7200.00
0005433568272	11612	Economy	7200.00
0005433568599	11612	Economy	7200.00
0005433074713	11612	Economy	7200.00
0005433568463	11612	Economy	7200.00
0005433568424	11612	Economy	7200.00
0005433568716	11612	Economy	7200.00
0005433074698	11612	Economy	7200.00
0005433568385	11612	Economy	7200.00
0005433568462	11612	Economy	7200.00
0005433074693	11612	Economy	7200.00
0005433568509	11612	Economy	7200.00
0005434732948	9964	Economy	6300.00
0005433817471	9964	Economy	6300.00
0005434732966	9964	Economy	6300.00
0005434732949	9964	Economy	6300.00
0005434732934	9964	Economy	6300.00
0005433817472	9964	Economy	6300.00
0005433817470	9964	Economy	6300.00
0005434732952	9964	Economy	6300.00
0005433817462	13970	Economy	6300.00
0005434732981	13970	Economy	6300.00
0005434732982	13970	Economy	6300.00
0005434732980	13970	Economy	6300.00
0005432984732	2319	Business	184500.00
0005433754238	2319	Business	184500.00
0005435982292	2319	Business	184500.00
0005432984742	2319	Business	184500.00
0005435982336	2319	Business	184500.00
0005432226057	2319	Business	184500.00
0005432869477	2319	Business	184500.00
0005432984734	2319	Business	184500.00
0005435982341	2319	Business	184500.00
0005432869479	2319	Business	184500.00
0005435982296	2319	Business	184500.00
0005433754219	2319	Business	184500.00
0005432300267	2319	Business	184500.00
0005432984826	2319	Business	184500.00
0005432984790	2319	Business	184500.00
0005433754231	2319	Business	184500.00
0005432869478	2319	Business	184500.00
0005433764680	2319	Business	184500.00
0005435982320	2319	Business	184500.00
0005435982332	2319	Business	184500.00
0005433434436	2319	Business	184500.00
0005433434455	2319	Business	184500.00
0005432655538	2319	Business	184500.00
0005432984817	2319	Business	184500.00
0005433754251	2319	Business	184500.00
0005432984686	2319	Business	184500.00
0005433754256	2319	Business	184500.00
0005432984650	2319	Business	184500.00
0005432300268	2319	Economy	67700.00
0005433754225	2319	Economy	67700.00
0005435982335	2319	Economy	67700.00
0005433754241	2319	Economy	61500.00
0005433754200	2319	Economy	61500.00
0005433754229	2319	Economy	61500.00
0005433434505	2319	Economy	61500.00
0005433754239	2319	Economy	61500.00
0005435982310	2319	Economy	61500.00
0005433754240	2319	Economy	61500.00
0005433754224	2319	Economy	61500.00
0005433754201	2319	Economy	61500.00
0005432984791	2319	Economy	61500.00
0005433754222	2319	Economy	61500.00
0005433754207	2319	Economy	61500.00
0005432300265	2319	Economy	61500.00
0005432984865	2319	Economy	61500.00
0005432655543	2319	Economy	61500.00
0005432984751	2319	Economy	61500.00
0005432984812	2319	Economy	61500.00
0005432984891	2319	Economy	61500.00
0005432984675	2319	Economy	61500.00
0005435982306	2319	Economy	61500.00
0005433434579	2319	Economy	61500.00
0005433754249	2319	Economy	61500.00
0005433754253	2319	Economy	61500.00
0005433754223	2319	Economy	61500.00
0005433766639	2319	Economy	61500.00
0005435982327	2319	Economy	61500.00
0005433754246	2319	Economy	61500.00
0005433754228	2319	Economy	61500.00
0005435982338	2319	Economy	61500.00
0005432984635	2319	Economy	61500.00
0005435982334	2319	Economy	61500.00
0005435982340	2319	Economy	61500.00
0005433754204	2319	Economy	61500.00
0005435982316	2319	Economy	61500.00
0005433754211	2319	Economy	61500.00
0005435982302	2319	Economy	61500.00
0005435982321	2319	Economy	61500.00
0005432869473	2319	Economy	61500.00
0005435982326	2319	Economy	61500.00
0005433434539	2319	Economy	61500.00
0005435982297	2319	Economy	61500.00
0005432984833	2319	Economy	61500.00
0005433754218	2319	Economy	61500.00
0005432984827	2319	Economy	61500.00
0005435982317	2319	Economy	61500.00
0005433754250	2319	Economy	61500.00
0005432984673	2319	Economy	61500.00
0005432300263	2319	Economy	61500.00
0005432984733	2319	Economy	61500.00
0005433434511	2319	Economy	61500.00
0005433434504	2319	Economy	61500.00
0005433754254	2319	Economy	61500.00
0005432226060	2319	Economy	61500.00
0005432655534	2319	Economy	61500.00
0005435982303	2319	Economy	61500.00
0005433754214	2319	Economy	61500.00
0005432655537	2319	Economy	61500.00
0005433434326	2319	Economy	61500.00
0005432984932	2319	Economy	61500.00
0005435982315	2319	Economy	61500.00
0005432869474	2319	Economy	61500.00
0005432655542	2319	Economy	61500.00
0005432984752	2319	Economy	61500.00
0005435982328	2319	Economy	61500.00
0005433434404	2319	Economy	61500.00
0005433754236	2319	Economy	61500.00
0005432655544	2319	Economy	61500.00
0005432300266	2319	Economy	61500.00
0005433434325	2319	Economy	61500.00
0005435982322	2319	Economy	61500.00
0005433754245	2319	Economy	61500.00
0005435982301	2319	Economy	61500.00
0005433754226	2319	Economy	61500.00
0005433434383	2319	Economy	61500.00
0005433754209	2319	Economy	61500.00
0005433754232	2319	Economy	61500.00
0005435982314	2319	Economy	61500.00
0005435982333	2319	Economy	61500.00
0005433434429	2319	Economy	61500.00
0005432869471	2319	Economy	61500.00
0005433434538	2319	Economy	61500.00
0005432226059	2319	Economy	61500.00
0005435982298	2319	Economy	61500.00
0005432984687	2319	Economy	61500.00
0005435982308	2319	Economy	61500.00
0005432300264	2319	Economy	61500.00
0005433754202	2319	Economy	67700.00
0005432655545	2319	Economy	67700.00
0005433754242	2319	Economy	61500.00
0005433434441	2319	Economy	61500.00
0005435982319	2319	Economy	67700.00
0005433434411	2319	Economy	67700.00
0005435982294	2319	Economy	61500.00
0005433754248	2319	Economy	61500.00
0005435982305	2319	Economy	61500.00
0005432655541	2319	Economy	61500.00
0005435982313	2319	Economy	61500.00
0005433754235	2319	Economy	61500.00
0005435982312	2319	Economy	61500.00
0005432984940	2319	Economy	61500.00
0005433766640	2319	Economy	61500.00
0005433754230	2319	Economy	61500.00
0005435982339	2319	Economy	61500.00
0005433754212	2319	Economy	61500.00
0005433754205	2319	Economy	61500.00
0005433754221	2319	Economy	61500.00
0005435982295	2319	Economy	61500.00
0005432869472	2319	Economy	61500.00
0005433434428	2319	Economy	61500.00
0005435982330	2319	Economy	61500.00
0005432984828	2319	Economy	61500.00
0005432655535	2319	Economy	61500.00
0005433754215	2319	Economy	61500.00
0005435982323	2319	Economy	61500.00
0005433754243	2319	Economy	61500.00
0005433434410	2319	Economy	61500.00
0005433754257	2319	Economy	61500.00
0005433754237	2319	Economy	61500.00
0005435982342	2319	Economy	61500.00
0005435982324	2319	Economy	61500.00
0005433754252	2319	Economy	61500.00
0005435982307	2319	Economy	61500.00
0005435982293	2319	Economy	61500.00
0005433754247	2319	Economy	61500.00
0005433754208	2319	Economy	61500.00
0005433766641	2319	Economy	61500.00
0005433754233	2319	Economy	61500.00
0005435982300	2319	Economy	61500.00
0005433754220	2319	Economy	61500.00
0005432226058	2319	Economy	61500.00
0005435982331	2319	Economy	61500.00
0005432984864	2319	Economy	61500.00
0005433434465	2319	Economy	61500.00
0005432869480	2319	Economy	61500.00
0005433754244	2319	Economy	61500.00
0005432984811	2319	Economy	61500.00
0005433754255	2319	Economy	61500.00
0005433434481	2319	Economy	61500.00
0005433434382	2319	Economy	61500.00
0005433754227	2319	Economy	61500.00
0005433754206	2319	Economy	61500.00
0005435982309	2319	Economy	61500.00
0005432655540	2319	Economy	61500.00
0005433434360	2319	Economy	61500.00
0005433754210	2319	Economy	61500.00
0005433434551	2319	Economy	61500.00
0005435982329	2319	Economy	61500.00
0005433754216	2319	Economy	61500.00
0005432984832	2319	Economy	61500.00
0005432655536	2319	Economy	61500.00
0005435982304	2319	Economy	61500.00
0005435982311	2319	Economy	61500.00
0005433754203	2319	Economy	61500.00
0005432655539	2319	Economy	61500.00
0005435982337	2319	Economy	61500.00
0005435982299	2319	Economy	61500.00
0005435982318	2319	Economy	61500.00
0005435982325	2319	Economy	61500.00
0005432984831	2319	Economy	61500.00
0005433754234	2319	Economy	61500.00
0005433766638	2319	Economy	61500.00
0005433754213	2319	Economy	61500.00
0005433754217	2319	Economy	61500.00
0005433753517	26209	Business	184500.00
0005432655371	26209	Business	184500.00
0005435981884	26209	Business	184500.00
0005435981860	26209	Business	184500.00
0005432655469	26209	Business	184500.00
0005433434671	26209	Business	184500.00
0005435981845	26209	Business	184500.00
0005432655393	26209	Business	184500.00
0005433434669	26209	Business	184500.00
0005433753741	26209	Business	184500.00
0005432985090	26209	Business	184500.00
0005432985069	26209	Business	184500.00
0005433434697	26209	Business	184500.00
0005435981885	26209	Business	184500.00
0005433434676	26209	Business	184500.00
0005433434686	26209	Business	184500.00
0005432869521	26209	Business	184500.00
0005435981867	26209	Business	184500.00
0005435981750	26209	Business	184500.00
0005432985077	26209	Business	184500.00
0005433753842	26209	Business	184500.00
0005435981749	26209	Business	184500.00
0005432049464	26209	Business	184500.00
0005435981882	26209	Business	184500.00
0005433753545	26209	Business	184500.00
0005432985083	26209	Economy	67700.00
0005433434682	26209	Economy	67700.00
0005432655390	26209	Economy	67700.00
0005433753764	26209	Economy	67700.00
0005434731171	26209	Economy	61500.00
0005433434672	26209	Economy	61500.00
0005432655452	26209	Economy	61500.00
0005433434683	26209	Economy	61500.00
0005433753825	26209	Economy	61500.00
0005433753657	26209	Economy	61500.00
0005432655419	26209	Economy	61500.00
0005433434685	26209	Economy	61500.00
0005433753822	26209	Economy	61500.00
0005432985068	26209	Economy	61500.00
0005432985073	26209	Economy	61500.00
0005432985091	26209	Economy	61500.00
0005434731170	26209	Economy	61500.00
0005432655470	26209	Economy	61500.00
0005433753852	26209	Economy	61500.00
0005432985088	26209	Economy	61500.00
0005435981866	26209	Economy	61500.00
0005432655361	26209	Economy	61500.00
0005432869523	26209	Economy	61500.00
0005433753707	26209	Economy	61500.00
0005433753846	26209	Economy	61500.00
0005433753774	26209	Economy	61500.00
0005433753675	26209	Economy	61500.00
0005433753894	26209	Economy	61500.00
0005432985082	26209	Economy	61500.00
0005433753668	26209	Economy	61500.00
0005435981969	26209	Economy	61500.00
0005433753572	26209	Economy	61500.00
0005433753809	26209	Economy	61500.00
0005433753839	26209	Economy	61500.00
0005432655394	26209	Economy	61500.00
0005435981676	26209	Economy	61500.00
0005432985089	26209	Economy	61500.00
0005433753920	26209	Economy	61500.00
0005432985093	26209	Economy	61500.00
0005435981910	26209	Economy	61500.00
0005433434688	26209	Economy	61500.00
0005433753796	26209	Economy	61500.00
0005433434679	26209	Economy	61500.00
0005433434696	26209	Economy	61500.00
0005433753738	26209	Economy	61500.00
0005432985078	26209	Economy	61500.00
0005432051129	26209	Economy	61500.00
0005433754001	26209	Economy	61500.00
0005433434677	26209	Economy	61500.00
0005435981970	26209	Economy	61500.00
0005432985074	26209	Economy	61500.00
0005432869522	26209	Economy	61500.00
0005432985071	26209	Economy	61500.00
0005433753837	26209	Economy	61500.00
0005435981905	26209	Economy	61500.00
0005433434673	26209	Economy	61500.00
0005433753618	26209	Economy	61500.00
0005433753570	26209	Economy	61500.00
0005432049465	26209	Economy	61500.00
0005433764661	26209	Economy	61500.00
0005435981917	26209	Economy	61500.00
0005432051128	26209	Economy	61500.00
0005433753565	26209	Economy	61500.00
0005433753679	26209	Economy	61500.00
0005435981615	26209	Economy	61500.00
0005433434684	26209	Economy	61500.00
0005435981899	26209	Economy	61500.00
0005433434670	26209	Economy	61500.00
0005432985081	26209	Economy	61500.00
0005435982037	26209	Economy	61500.00
0005432655360	26209	Economy	61500.00
0005435982002	26209	Economy	61500.00
0005432655418	26209	Economy	61500.00
0005433753735	26209	Economy	61500.00
0005435981713	26209	Economy	61500.00
0005433753737	26209	Economy	61500.00
0005433753656	26209	Economy	61500.00
0005433434680	26209	Economy	61500.00
0005432985070	26209	Economy	61500.00
0005433434674	26209	Economy	61500.00
0005435981918	26209	Economy	61500.00
0005433753876	26209	Economy	61500.00
0005432869524	26209	Economy	61500.00
0005433753885	26209	Economy	61500.00
0005433753629	26209	Economy	61500.00
0005435981953	26209	Economy	61500.00
0005432985085	26209	Economy	61500.00
0005433753674	26209	Economy	61500.00
0005432869525	26209	Economy	61500.00
0005432655432	26209	Economy	61500.00
0005432985084	26209	Economy	61500.00
0005435981861	26209	Economy	61500.00
0005433753867	26209	Economy	67700.00
0005433753740	26209	Economy	61500.00
0005433753975	26209	Economy	67700.00
0005433434695	26209	Economy	61500.00
0005432655430	26209	Economy	61500.00
0005432985075	26209	Economy	61500.00
0005435981881	26209	Economy	67700.00
0005432869520	26209	Economy	61500.00
0005432049463	26209	Economy	61500.00
0005433434678	26209	Economy	61500.00
0005435981906	26209	Economy	61500.00
0005433434689	26209	Economy	61500.00
0005433434690	26209	Economy	61500.00
0005432985086	26209	Economy	61500.00
0005433753725	26209	Economy	61500.00
0005433753877	26209	Economy	61500.00
0005432655417	26209	Economy	61500.00
0005435981924	26209	Economy	61500.00
0005435981979	26209	Economy	61500.00
0005433766612	26209	Economy	61500.00
0005435981809	26209	Economy	61500.00
0005433434691	26209	Economy	61500.00
0005432051127	26209	Economy	61500.00
0005432985072	26209	Economy	61500.00
0005433753638	26209	Economy	61500.00
0005433753678	26209	Economy	61500.00
0005435981616	26209	Economy	61500.00
0005433753663	26209	Economy	61500.00
0005432985067	26209	Economy	61500.00
0005433753630	26209	Economy	61500.00
0005432655362	26209	Economy	61500.00
0005432985094	26209	Economy	61500.00
0005434731172	26209	Economy	61500.00
0005435981904	26209	Economy	61500.00
0005435981894	26209	Economy	61500.00
0005433753560	26209	Economy	61500.00
0005432985079	26209	Economy	61500.00
0005433434675	26209	Economy	61500.00
0005432655431	26209	Economy	61500.00
0005432985087	26209	Economy	61500.00
0005433434693	26209	Economy	61500.00
0005435981850	26209	Economy	61500.00
0005434731173	26209	Economy	61500.00
0005433434694	26209	Economy	61500.00
0005433434692	26209	Economy	61500.00
0005433764660	26209	Economy	61500.00
0005433753827	26209	Economy	61500.00
0005432985096	26209	Economy	61500.00
0005433753742	26209	Economy	61500.00
0005433753710	26209	Economy	61500.00
0005435981949	26209	Economy	61500.00
0005433753739	26209	Economy	61500.00
0005435981925	26209	Economy	61500.00
0005435981849	26209	Economy	61500.00
0005432655370	26209	Economy	61500.00
0005433753658	26209	Economy	61500.00
0005433434681	26209	Economy	61500.00
0005432985080	26209	Economy	61500.00
0005435981903	26209	Economy	61500.00
0005435981954	26209	Economy	61500.00
0005432985066	26209	Economy	61500.00
0005435981973	26209	Economy	61500.00
0005433753856	26209	Economy	61500.00
0005435981859	26209	Economy	61500.00
0005432655406	26209	Economy	61500.00
0005434731169	26209	Economy	61500.00
0005432049462	26209	Economy	61500.00
0005432655405	26209	Economy	61500.00
0005435981810	26209	Economy	61500.00
0005432869519	26209	Economy	61500.00
0005435981900	26209	Economy	61500.00
0005432985095	26209	Economy	61500.00
0005433434687	26209	Economy	61500.00
0005432985076	26209	Economy	61500.00
0005432985092	26209	Economy	61500.00
0005434374652	1525	Business	38900.00
0005433151167	1525	Business	38900.00
0005434374658	1525	Business	38900.00
0005434374669	1525	Business	38900.00
0005434374664	1525	Business	38900.00
0005434374646	1525	Business	38900.00
0005432267893	1525	Business	38900.00
0005433460437	1525	Business	38900.00
0005434374654	1525	Business	38900.00
0005434374651	1525	Economy	13000.00
0005434374657	1525	Economy	13000.00
0005434374661	1525	Economy	13000.00
0005433151230	1525	Economy	13000.00
0005434374662	1525	Economy	13000.00
0005434374648	1525	Economy	13000.00
0005432267899	1525	Economy	13000.00
0005433151202	1525	Economy	13000.00
0005432267895	1525	Economy	13000.00
0005434374638	1525	Economy	13000.00
0005434374667	1525	Economy	13000.00
0005434029627	1525	Economy	13000.00
0005433461589	1525	Economy	13000.00
0005432267898	1525	Economy	13000.00
0005434374653	1525	Economy	13000.00
0005433150912	1525	Economy	13000.00
0005434374647	1525	Economy	13000.00
0005432267897	1525	Economy	13000.00
0005433931436	1525	Economy	13000.00
0005434029639	1525	Economy	13000.00
0005433151228	1525	Economy	13000.00
0005434374655	1525	Economy	13000.00
0005433151133	1525	Economy	13000.00
0005434374665	1525	Economy	14300.00
0005434029640	1525	Economy	14300.00
0005434374663	1525	Economy	14300.00
0005433151045	1525	Economy	14300.00
0005434374649	1525	Economy	13000.00
0005433461588	1525	Economy	13000.00
0005434374670	1525	Economy	13000.00
0005434374645	1525	Economy	13000.00
0005433764655	1525	Economy	13000.00
0005433460436	1525	Economy	13000.00
0005432267900	1525	Economy	13000.00
0005434374671	1525	Economy	13000.00
0005433151039	1525	Economy	13000.00
0005434374675	1525	Economy	13000.00
0005434374666	1525	Economy	13000.00
0005434374642	1525	Economy	13000.00
0005433151229	1525	Economy	13000.00
0005433151234	1525	Economy	13000.00
0005434374660	1525	Economy	13000.00
0005433151168	1525	Economy	13000.00
0005433151182	1525	Economy	13000.00
0005434376224	1525	Economy	13000.00
0005434374644	1525	Economy	13000.00
0005432267894	1525	Economy	13000.00
0005434374637	1525	Economy	13000.00
0005433461590	1525	Economy	13000.00
0005434374676	1525	Economy	13000.00
0005434374634	1525	Economy	13000.00
0005434029638	1525	Economy	13000.00
0005433151185	1525	Economy	13000.00
0005434374656	1525	Economy	13000.00
0005433151123	1525	Economy	13000.00
0005433151143	1525	Economy	13000.00
0005434374641	1525	Economy	13000.00
0005434374650	1525	Economy	13000.00
0005434374659	1525	Economy	13000.00
0005434374640	1525	Economy	13000.00
0005433151134	1525	Economy	13000.00
0005433151124	1525	Economy	13000.00
0005433460435	1525	Economy	13000.00
0005434374639	1525	Economy	13000.00
0005434374674	1525	Economy	13000.00
0005434374672	1525	Economy	13000.00
0005434374636	1525	Economy	13000.00
0005432267896	1525	Economy	13000.00
0005434374673	1525	Economy	13000.00
0005433151100	1525	Economy	13000.00
0005433151233	1525	Economy	13000.00
0005434376223	1525	Economy	13000.00
0005434374635	1525	Economy	13000.00
0005434374668	1525	Economy	13000.00
0005434374643	1525	Economy	13000.00
0005433151423	20140	Business	38900.00
0005434373970	20140	Business	38900.00
0005434374199	20140	Business	38900.00
0005434374432	20140	Business	38900.00
0005433931465	20140	Business	38900.00
0005434374431	20140	Business	38900.00
0005432056300	20140	Business	38900.00
0005434374302	20140	Business	38900.00
0005433151412	20140	Business	38900.00
0005433151415	20140	Business	38900.00
0005434374414	20140	Economy	13000.00
0005434374422	20140	Economy	13000.00
0005433151409	20140	Economy	13000.00
0005434374403	20140	Economy	13000.00
0005434374267	20140	Economy	13000.00
0005434374200	20140	Economy	13000.00
0005433151397	20140	Economy	13000.00
0005433151399	20140	Economy	13000.00
0005434374210	20140	Economy	13000.00
0005433931467	20140	Economy	13000.00
0005433151408	20140	Economy	13000.00
0005434374201	20140	Economy	13000.00
0005434374434	20140	Economy	13000.00
0005434029657	20140	Economy	13000.00
0005434374336	20140	Economy	13000.00
0005433151406	20140	Economy	13000.00
0005434374270	20140	Economy	13000.00
0005434374202	20140	Economy	13000.00
0005433151413	20140	Economy	13000.00
0005434374142	20140	Economy	13000.00
0005433151419	20140	Economy	13000.00
0005433151418	20140	Economy	13000.00
0005434374237	20140	Economy	13000.00
0005434374433	20140	Economy	13000.00
0005434029658	20140	Economy	13000.00
0005434374173	20140	Economy	13000.00
0005434374399	20140	Economy	13000.00
0005434374301	20140	Economy	13000.00
0005433151402	20140	Economy	13000.00
0005433764680	20140	Economy	13000.00
0005433151410	20140	Economy	13000.00
0005434374335	20140	Economy	14300.00
0005433151421	20140	Economy	14300.00
0005434374221	20140	Economy	14300.00
0005434374110	20140	Economy	14300.00
0005434374209	20140	Economy	14300.00
0005433151391	20140	Economy	14300.00
0005433151416	20140	Economy	13000.00
0005433151401	20140	Economy	13000.00
0005434374220	20140	Economy	13000.00
0005434374185	20140	Economy	13000.00
0005434374421	20140	Economy	13000.00
0005433151417	20140	Economy	13000.00
0005434374385	20140	Economy	13000.00
0005432056297	20140	Economy	13000.00
0005433151407	20140	Economy	13000.00
0005433931464	20140	Economy	13000.00
0005434374288	20140	Economy	13000.00
0005434374179	20140	Economy	13000.00
0005432056299	20140	Economy	13000.00
0005432056298	20140	Economy	13000.00
0005433931466	20140	Economy	13000.00
0005434374271	20140	Economy	13000.00
0005434374143	20140	Economy	13000.00
0005433151393	20140	Economy	13000.00
0005434374266	20140	Economy	13000.00
0005433151424	20140	Economy	13000.00
0005434374257	20140	Economy	13000.00
0005434374430	20140	Economy	13000.00
0005433151392	20140	Economy	13000.00
0005434374435	20140	Economy	13000.00
0005433151405	20140	Economy	13000.00
0005433151394	20140	Economy	13000.00
0005434374368	20140	Economy	13000.00
0005434374389	20140	Economy	13000.00
0005434374243	20140	Economy	13000.00
0005434374236	20140	Economy	13000.00
0005434374141	20140	Economy	13000.00
0005434374390	20140	Economy	13000.00
0005434374337	20140	Economy	13000.00
0005433151425	20140	Economy	13000.00
0005434374122	20140	Economy	13000.00
0005434374436	20140	Economy	13000.00
0005433151396	20140	Economy	13000.00
0005433151400	20140	Economy	13000.00
0005433151398	20140	Economy	13000.00
0005433151404	20140	Economy	13000.00
0005434374273	20140	Economy	13000.00
0005433151395	20140	Economy	13000.00
0005434374213	20140	Economy	13000.00
0005434374123	20140	Economy	13000.00
0005433151403	20140	Economy	13000.00
0005434374269	20140	Economy	13000.00
0005433151420	20140	Economy	13000.00
0005434374140	20140	Economy	13000.00
0005434374268	20140	Economy	13000.00
0005433151414	20140	Economy	13000.00
0005433151411	20140	Economy	13000.00
0005433151422	20140	Economy	13000.00
0005432282868	516	Business	27500.00
0005432424462	516	Business	27500.00
0005432424425	516	Business	27500.00
0005432424443	516	Business	27500.00
0005432424448	516	Business	27500.00
0005432424442	516	Business	27500.00
0005432424445	516	Business	27500.00
0005432424430	516	Economy	10100.00
0005432424457	516	Economy	10100.00
0005432424451	516	Economy	9200.00
0005432424436	516	Economy	9200.00
0005432424431	516	Economy	9200.00
0005432282865	516	Economy	9200.00
0005432424422	516	Economy	9200.00
0005432424452	516	Economy	9200.00
0005432424435	516	Economy	9200.00
0005432424459	516	Economy	9200.00
0005432424453	516	Economy	9200.00
0005432424438	516	Economy	9200.00
0005432424424	516	Economy	9200.00
0005432424440	516	Economy	9200.00
0005432424429	516	Economy	9200.00
0005432282866	516	Economy	9200.00
0005432424460	516	Economy	9200.00
0005432282861	516	Economy	9200.00
0005432424456	516	Economy	9200.00
0005432424428	516	Economy	9200.00
0005432424434	516	Economy	9200.00
0005432424454	516	Economy	9200.00
0005432424427	516	Economy	9200.00
0005432424455	516	Economy	9200.00
0005432424433	516	Economy	9200.00
0005432282864	516	Economy	9200.00
0005432282867	516	Economy	9200.00
0005432424423	516	Economy	9200.00
0005432424446	516	Economy	9200.00
0005432424450	516	Economy	9200.00
0005432424444	516	Economy	9200.00
0005432424426	516	Economy	9200.00
0005432282862	516	Economy	9200.00
0005432424439	516	Economy	9200.00
0005432424432	516	Economy	9200.00
0005432424447	516	Economy	9200.00
0005432424437	516	Economy	9200.00
0005432282863	516	Economy	9200.00
0005432424441	516	Economy	9200.00
0005432424458	516	Economy	9200.00
0005432424461	516	Economy	9200.00
0005432424449	516	Economy	9200.00
0005432302329	12870	Business	27500.00
0005432302331	12870	Business	27500.00
0005432302332	12870	Economy	9200.00
0005432302330	12870	Economy	9200.00
0005432424019	12826	Business	27500.00
0005432423957	12826	Business	27500.00
0005432424040	12826	Business	27500.00
0005432424031	12826	Business	27500.00
0005432423968	12826	Business	27500.00
0005432423983	12826	Business	27500.00
0005432424055	12826	Business	27500.00
0005432424046	12826	Economy	9200.00
0005432423982	12826	Economy	9200.00
0005432423901	12826	Economy	9200.00
0005432423909	12826	Economy	9200.00
0005432424030	12826	Economy	9200.00
0005432424013	12826	Economy	9200.00
0005432423963	12826	Economy	9200.00
0005432423977	12826	Economy	9200.00
0005432424053	12826	Economy	9200.00
0005432423962	12826	Economy	9200.00
0005432423994	12826	Economy	9200.00
0005432424005	12826	Economy	9200.00
0005432423896	12826	Economy	9200.00
0005432423903	12826	Economy	9200.00
0005432423981	12826	Economy	9200.00
0005432424011	12826	Economy	9200.00
0005432424039	12826	Economy	9200.00
0005432423900	12826	Economy	9200.00
0005432423964	12826	Economy	10100.00
0005432423902	12826	Economy	10100.00
0005432424026	12826	Economy	10100.00
0005432424025	12826	Economy	9200.00
0005432423958	12826	Economy	10100.00
0005432423955	12826	Economy	9200.00
0005432424054	12826	Economy	9200.00
0005432424008	12826	Economy	9200.00
0005432424006	12826	Economy	9200.00
0005432423938	12826	Economy	9200.00
0005432423978	12826	Economy	9200.00
0005432423943	12826	Economy	9200.00
0005432424047	12826	Economy	9200.00
0005432424022	12826	Economy	9200.00
0005434735616	434	Business	24500.00
0005432235635	434	Business	24500.00
0005433057504	434	Business	24500.00
0005432045612	434	Business	24500.00
0005434023700	434	Business	24500.00
0005433057599	434	Business	24500.00
0005433057489	434	Business	24500.00
0005434023734	434	Business	24500.00
0005433057610	434	Business	24500.00
0005434023722	434	Business	24500.00
0005434023703	434	Business	24500.00
0005434023749	434	Business	24500.00
0005433057667	434	Business	24500.00
0005434029656	434	Business	24500.00
0005433057637	434	Business	24500.00
0005433057602	434	Business	24500.00
0005433057636	434	Business	24500.00
0005434023729	434	Business	24500.00
0005434023738	434	Business	24500.00
0005434023724	434	Business	24500.00
0005433057631	434	Economy	9000.00
0005434023714	434	Economy	9000.00
0005434023696	434	Economy	9000.00
0005434032020	434	Economy	8200.00
0005433684400	434	Economy	8200.00
0005434023725	434	Economy	8200.00
0005433929573	434	Economy	8200.00
0005433057611	434	Economy	8200.00
0005434023748	434	Economy	8200.00
0005434023715	434	Economy	8200.00
0005434023704	434	Economy	8200.00
0005434029655	434	Economy	8200.00
0005434023728	434	Economy	8200.00
0005434735615	434	Economy	8200.00
0005434023732	434	Economy	8200.00
0005433684406	434	Economy	8200.00
0005434023687	434	Economy	8200.00
0005434023710	434	Economy	8200.00
0005434023680	434	Economy	8200.00
0005434023723	434	Economy	8200.00
0005434023716	434	Economy	8200.00
0005433057531	434	Economy	8200.00
0005434023708	434	Economy	8200.00
0005433057573	434	Economy	8200.00
0005434023731	434	Economy	8200.00
0005434023739	434	Economy	8200.00
0005434023688	434	Economy	8200.00
0005434023695	434	Economy	8200.00
0005433057596	434	Economy	8200.00
0005434023721	434	Economy	8200.00
0005433057436	434	Economy	8200.00
0005433057739	434	Economy	8200.00
0005434023737	434	Economy	8200.00
0005434023744	434	Economy	8200.00
0005433057503	434	Economy	8200.00
0005433057561	434	Economy	8200.00
0005433057674	434	Economy	8200.00
0005434023681	434	Economy	8200.00
0005434023730	434	Economy	8200.00
0005434735630	434	Economy	8200.00
0005433057612	434	Economy	8200.00
0005433057587	434	Economy	8200.00
0005434023705	434	Economy	8200.00
0005434023701	434	Economy	8200.00
0005433057511	434	Economy	8200.00
0005432235640	434	Economy	8200.00
0005434735621	434	Economy	8200.00
0005434023718	434	Economy	8200.00
0005434023746	434	Economy	8200.00
0005434023747	434	Economy	8200.00
0005434023713	434	Economy	8200.00
0005433057372	434	Economy	8200.00
0005434029654	434	Economy	8200.00
0005434023691	434	Economy	8200.00
0005434023743	434	Economy	8200.00
0005434023720	434	Economy	8200.00
0005434023707	434	Economy	8200.00
0005434023726	434	Economy	8200.00
0005434023717	434	Economy	8200.00
0005433057500	434	Economy	8200.00
0005433057530	434	Economy	8200.00
0005434023742	434	Economy	8200.00
0005434735617	434	Economy	8200.00
0005434023682	434	Economy	8200.00
0005433057537	434	Economy	8200.00
0005433057393	434	Economy	9000.00
0005433057485	434	Economy	8200.00
0005434023711	434	Economy	9000.00
0005434023689	434	Economy	8200.00
0005434023684	434	Economy	8200.00
0005434032019	434	Economy	8200.00
0005433057650	434	Economy	8200.00
0005434023690	434	Economy	8200.00
0005434023740	434	Economy	8200.00
0005434023697	434	Economy	8200.00
0005433684403	434	Economy	8200.00
0005434023706	434	Economy	8200.00
0005433057486	434	Economy	8200.00
0005432045611	434	Economy	8200.00
0005434023683	434	Economy	8200.00
0005433057638	434	Economy	8200.00
0005432235636	434	Economy	8200.00
0005434023719	434	Economy	8200.00
0005433057373	434	Economy	8200.00
0005433057524	434	Economy	8200.00
0005434023686	434	Economy	8200.00
0005434735641	434	Economy	8200.00
0005433929574	434	Economy	8200.00
0005433057509	434	Economy	8200.00
0005432235641	434	Economy	8200.00
0005433057507	434	Economy	8200.00
0005433057675	434	Economy	8200.00
0005433057603	434	Economy	8200.00
0005434023727	434	Economy	8200.00
0005434023709	434	Economy	8200.00
0005434023699	434	Economy	8200.00
0005433057598	434	Economy	8200.00
0005432235638	434	Economy	8200.00
0005434032021	434	Economy	8200.00
0005433929588	434	Economy	8200.00
0005434023685	434	Economy	8200.00
0005434023698	434	Economy	8200.00
0005433057562	434	Economy	8200.00
0005434032022	434	Economy	8200.00
0005434023693	434	Economy	8200.00
0005434023692	434	Economy	8200.00
0005432235642	434	Economy	8200.00
0005434023736	434	Economy	8200.00
0005434023745	434	Economy	8200.00
0005434023712	434	Economy	8200.00
0005434023735	434	Economy	8200.00
0005432235639	434	Economy	8200.00
0005434023694	434	Economy	8200.00
0005434023702	434	Economy	8200.00
0005434023741	434	Economy	8200.00
0005432235637	434	Economy	8200.00
0005434735622	434	Economy	8200.00
0005434023733	434	Economy	8200.00
0005434023139	12652	Business	24500.00
0005433057875	12652	Business	24500.00
0005433929614	12652	Business	24500.00
0005434023046	12652	Business	24500.00
0005432156364	12652	Business	24500.00
0005434023037	12652	Business	24500.00
0005434023256	12652	Business	24500.00
0005433057907	12652	Business	24500.00
0005433057906	12652	Business	24500.00
0005433929612	12652	Business	24500.00
0005434031982	12652	Business	24500.00
0005433057893	12652	Business	24500.00
0005434023111	12652	Business	24500.00
0005434022930	12652	Business	24500.00
0005434023155	12652	Economy	9000.00
0005433057888	12652	Economy	9000.00
0005433057897	12652	Economy	9000.00
0005434023022	12652	Economy	8200.00
0005432157492	12652	Economy	8200.00
0005434023066	12652	Economy	8200.00
0005434031983	12652	Economy	8200.00
0005434022898	12652	Economy	8200.00
0005434023251	12652	Economy	8200.00
0005433057891	12652	Economy	8200.00
0005433057881	12652	Economy	8200.00
0005434022980	12652	Economy	8200.00
0005434022954	12652	Economy	8200.00
0005434029640	12652	Economy	8200.00
0005434735689	12652	Economy	8200.00
0005433057884	12652	Economy	8200.00
0005434023307	12652	Economy	8200.00
0005434023156	12652	Economy	8200.00
0005434029638	12652	Economy	8200.00
0005434023178	12652	Economy	8200.00
0005434022831	12652	Economy	8200.00
0005433057885	12652	Economy	8200.00
0005434029639	12652	Economy	8200.00
0005434023031	12652	Economy	8200.00
0005434023053	12652	Economy	8200.00
0005433057901	12652	Economy	8200.00
0005433057896	12652	Economy	8200.00
0005433057899	12652	Economy	8200.00
0005432156366	12652	Economy	8200.00
0005434023313	12652	Economy	8200.00
0005432156365	12652	Economy	8200.00
0005433057870	12652	Economy	8200.00
0005433929615	12652	Economy	8200.00
0005434023266	12652	Economy	8200.00
0005434023169	12652	Economy	8200.00
0005433057903	12652	Economy	8200.00
0005433057877	12652	Economy	8200.00
0005433057900	12652	Economy	8200.00
0005434376223	12652	Economy	8200.00
0005433057886	12652	Economy	8200.00
0005434023225	12652	Economy	8200.00
0005433057902	12652	Economy	8200.00
0005433057898	12652	Economy	8200.00
0005434023143	12652	Economy	8200.00
0005434023394	12652	Economy	8200.00
0005434023057	12652	Economy	8200.00
0005434028275	12652	Economy	8200.00
0005434735688	12652	Economy	8200.00
0005433057879	12652	Economy	8200.00
0005433057874	12652	Economy	8200.00
0005434022955	12652	Economy	8200.00
0005434735691	12652	Economy	8200.00
0005433057905	12652	Economy	8200.00
0005432157491	12652	Economy	8200.00
0005433057873	12652	Economy	8200.00
0005433057876	12652	Economy	8200.00
0005434022932	12652	Economy	8200.00
0005433057887	12652	Economy	8200.00
0005434023095	12652	Economy	8200.00
0005434022999	12652	Economy	8200.00
0005434022978	12652	Economy	8200.00
0005434023190	12652	Economy	8200.00
0005434023297	12652	Economy	8200.00
0005434023065	12652	Economy	9000.00
0005433057869	12652	Economy	8200.00
0005433057882	12652	Economy	8200.00
0005433057878	12652	Economy	8200.00
0005434023395	12652	Economy	8200.00
0005434023149	12652	Economy	8200.00
0005433057883	12652	Economy	8200.00
0005433929611	12652	Economy	8200.00
0005433057889	12652	Economy	8200.00
0005433057872	12652	Economy	8200.00
0005434022988	12652	Economy	8200.00
0005434023191	12652	Economy	8200.00
0005434023052	12652	Economy	8200.00
0005434023308	12652	Economy	8200.00
0005434023103	12652	Economy	8200.00
0005434022917	12652	Economy	8200.00
0005434023047	12652	Economy	8200.00
0005433057895	12652	Economy	8200.00
0005433057894	12652	Economy	8200.00
0005433057871	12652	Economy	8200.00
0005434023153	12652	Economy	8200.00
0005434023054	12652	Economy	8200.00
0005434023447	12652	Economy	8200.00
0005434735690	12652	Economy	8200.00
0005434023213	12652	Economy	8200.00
0005434022928	12652	Economy	8200.00
0005434023296	12652	Economy	8200.00
0005434029627	12652	Economy	8200.00
0005434735692	12652	Economy	8200.00
0005433057880	12652	Economy	8200.00
0005434022850	12652	Economy	8200.00
0005433057892	12652	Economy	8200.00
0005433684421	12652	Economy	8200.00
0005434023113	12652	Economy	8200.00
0005432156367	12652	Economy	8200.00
0005434376224	12652	Economy	8200.00
0005434022931	12652	Economy	8200.00
0005433057890	12652	Economy	8200.00
0005434023067	12652	Economy	8200.00
0005433057904	12652	Economy	8200.00
0005434023257	12652	Economy	8200.00
0005434023192	12652	Economy	8200.00
0005433929613	12652	Economy	8200.00
0005434023304	12652	Economy	8200.00
0005434031981	12652	Economy	8200.00
0005434028261	12652	Economy	8200.00
0005433057868	12652	Economy	8200.00
0005433527263	13811	Business	111600.00
0005433529270	13811	Business	111600.00
0005433529276	13811	Business	111600.00
0005433527262	13811	Business	111600.00
0005433529268	13811	Business	111600.00
0005433527257	13811	Business	111600.00
0005433529271	13811	Economy	37200.00
0005433529265	13811	Economy	37200.00
0005433529275	13811	Economy	37200.00
0005433529267	13811	Economy	37200.00
0005433527264	13811	Economy	37200.00
0005433529272	13811	Economy	37200.00
0005433527256	13811	Economy	37200.00
0005433527255	13811	Economy	37200.00
0005433529266	13811	Economy	37200.00
0005433527254	13811	Economy	37200.00
0005433527259	13811	Economy	37200.00
0005433527258	13811	Economy	37200.00
0005433527261	13811	Economy	37200.00
0005433527260	13811	Economy	37200.00
0005433529274	13811	Economy	37200.00
0005433529273	13811	Economy	37200.00
0005433529269	13811	Economy	37200.00
0005433533288	32440	Business	111600.00
0005433533289	32440	Business	111600.00
0005433529236	32440	Business	111600.00
0005433529229	32440	Economy	37200.00
0005433533263	32440	Economy	37200.00
0005433533267	32440	Economy	37200.00
0005433533271	32440	Economy	37200.00
0005433533269	32440	Economy	37200.00
0005433529239	32440	Economy	37200.00
0005433533281	32440	Economy	37200.00
0005433533256	32440	Economy	37200.00
0005433533264	32440	Economy	37200.00
0005433529228	32440	Economy	37200.00
0005433533282	32440	Economy	37200.00
0005433529223	32440	Economy	37200.00
0005433533266	32440	Economy	37200.00
0005433533268	32440	Economy	37200.00
0005433529231	32440	Economy	37200.00
0005433533255	32440	Economy	37200.00
0005433529240	32440	Economy	37200.00
0005433529235	32440	Economy	37200.00
0005433529241	32440	Economy	37200.00
0005433529224	32440	Economy	37200.00
0005433923319	2126	Business	34700.00
0005432231565	2126	Business	34700.00
0005433923278	2126	Business	34700.00
0005433923283	2126	Business	34700.00
0005433923309	2126	Business	34700.00
0005433923258	2126	Business	34700.00
0005433035628	2126	Business	34700.00
0005433923287	2126	Business	34700.00
0005433923352	2126	Business	34700.00
0005433035856	2126	Business	34700.00
0005433923321	2126	Business	34700.00
0005433035875	2126	Business	34700.00
0005433923337	2126	Business	34700.00
0005433923333	2126	Business	34700.00
0005433923267	2126	Business	34700.00
0005433035754	2126	Business	34700.00
0005433923296	2126	Business	34700.00
0005433923268	2126	Business	34700.00
0005433035908	2126	Business	34700.00
0005432231569	2126	Business	34700.00
0005432044525	2126	Business	34700.00
0005433923346	2126	Business	34700.00
0005433923331	2126	Economy	12700.00
0005433923347	2126	Economy	12700.00
0005433923284	2126	Economy	11600.00
0005433931466	2126	Economy	11600.00
0005433035535	2126	Economy	11600.00
0005433923274	2126	Economy	11600.00
0005433923262	2126	Economy	11600.00
0005433923313	2126	Economy	11600.00
0005433923270	2126	Economy	11600.00
0005433923290	2126	Economy	11600.00
0005433923314	2126	Economy	11600.00
0005433929613	2126	Economy	11600.00
0005433923272	2126	Economy	11600.00
0005433035853	2126	Economy	11600.00
0005433923257	2126	Economy	11600.00
0005433923298	2126	Economy	11600.00
0005432231570	2126	Economy	11600.00
0005433923311	2126	Economy	11600.00
0005432231562	2126	Economy	11600.00
0005433923323	2126	Economy	11600.00
0005432044523	2126	Economy	11600.00
0005433923299	2126	Economy	11600.00
0005433923327	2126	Economy	11600.00
0005433923324	2126	Economy	11600.00
0005433923326	2126	Economy	11600.00
0005433929614	2126	Economy	11600.00
0005433923293	2126	Economy	11600.00
0005433923307	2126	Economy	11600.00
0005433035534	2126	Economy	11600.00
0005433923328	2126	Economy	11600.00
0005433923348	2126	Economy	11600.00
0005433035854	2126	Economy	11600.00
0005433923300	2126	Economy	11600.00
0005433035965	2126	Economy	11600.00
0005433923338	2126	Economy	11600.00
0005433035835	2126	Economy	11600.00
0005433923302	2126	Economy	11600.00
0005433923280	2126	Economy	11600.00
0005433923285	2126	Economy	11600.00
0005433923292	2126	Economy	11600.00
0005432749753	2126	Economy	11600.00
0005433931464	2126	Economy	11600.00
0005433923259	2126	Economy	11600.00
0005432231563	2126	Economy	11600.00
0005433923261	2126	Economy	11600.00
0005433035889	2126	Economy	11600.00
0005433923297	2126	Economy	11600.00
0005433035834	2126	Economy	11600.00
0005433923349	2126	Economy	11600.00
0005433923318	2126	Economy	11600.00
0005433923277	2126	Economy	11600.00
0005432231567	2126	Economy	11600.00
0005433923303	2126	Economy	11600.00
0005433923305	2126	Economy	11600.00
0005433923276	2126	Economy	11600.00
0005432231568	2126	Economy	11600.00
0005433923334	2126	Economy	11600.00
0005432231566	2126	Economy	11600.00
0005433923315	2126	Economy	11600.00
0005433035686	2126	Economy	11600.00
0005433035888	2126	Economy	11600.00
0005433923316	2126	Economy	11600.00
0005433923320	2126	Economy	11600.00
0005433035881	2126	Economy	11600.00
0005433923291	2126	Economy	11600.00
0005433035874	2126	Economy	11600.00
0005433923312	2126	Economy	11600.00
0005433923329	2126	Economy	11600.00
0005433923344	2126	Economy	11600.00
0005433923330	2126	Economy	11600.00
0005433923306	2126	Economy	11600.00
0005433923281	2126	Economy	11600.00
0005433923263	2126	Economy	11600.00
0005433923275	2126	Economy	11600.00
0005433923336	2126	Economy	11600.00
0005433923286	2126	Economy	12700.00
0005433035837	2126	Economy	12700.00
0005432231564	2126	Economy	11600.00
0005433875377	2126	Economy	11600.00
0005433923308	2126	Economy	12700.00
0005433923260	2126	Economy	12700.00
0005433035809	2126	Economy	11600.00
0005434028275	2126	Economy	11600.00
0005433923269	2126	Economy	11600.00
0005433929611	2126	Economy	11600.00
0005433923317	2126	Economy	11600.00
0005433923304	2126	Economy	11600.00
0005432044524	2126	Economy	11600.00
0005433923301	2126	Economy	11600.00
0005433035753	2126	Economy	11600.00
0005433923279	2126	Economy	11600.00
0005433035755	2126	Economy	11600.00
0005433035663	2126	Economy	11600.00
0005432749767	2126	Economy	11600.00
0005433923282	2126	Economy	11600.00
0005433923264	2126	Economy	11600.00
0005433923343	2126	Economy	11600.00
0005433923271	2126	Economy	11600.00
0005433035993	2126	Economy	11600.00
0005433035627	2126	Economy	11600.00
0005433035873	2126	Economy	11600.00
0005433923289	2126	Economy	11600.00
0005433923273	2126	Economy	11600.00
0005433923345	2126	Economy	11600.00
0005433929612	2126	Economy	11600.00
0005433035855	2126	Economy	11600.00
0005433923325	2126	Economy	11600.00
0005433923341	2126	Economy	11600.00
0005433931465	2126	Economy	11600.00
0005433923294	2126	Economy	11600.00
0005433923295	2126	Economy	11600.00
0005434028261	2126	Economy	11600.00
0005433923310	2126	Economy	11600.00
0005433035716	2126	Economy	11600.00
0005433923265	2126	Economy	11600.00
0005433035680	2126	Economy	11600.00
0005433923322	2126	Economy	11600.00
0005433931467	2126	Economy	11600.00
0005433923332	2126	Economy	11600.00
0005433035717	2126	Economy	11600.00
0005433035887	2126	Economy	11600.00
0005433923340	2126	Economy	11600.00
0005432231561	2126	Economy	11600.00
0005433035757	2126	Economy	11600.00
0005432231560	2126	Economy	11600.00
0005433035782	2126	Economy	11600.00
0005433035972	2126	Economy	11600.00
0005433923351	2126	Economy	11600.00
0005433923335	2126	Economy	11600.00
0005433035903	2126	Economy	11600.00
0005433923288	2126	Economy	11600.00
0005433923339	2126	Economy	11600.00
0005433923353	2126	Economy	11600.00
0005433035691	2126	Economy	11600.00
0005433923266	2126	Economy	11600.00
0005433035838	2126	Economy	11600.00
0005433923342	2126	Economy	11600.00
0005433923256	2126	Economy	11600.00
0005433035980	2126	Economy	11600.00
0005433035603	2126	Economy	11600.00
0005433036044	2126	Economy	11600.00
0005433929615	2126	Economy	11600.00
0005433923350	2126	Economy	11600.00
0005433922459	24093	Business	34700.00
0005432749784	24093	Business	34700.00
0005433036314	24093	Business	34700.00
0005433036284	24093	Business	34700.00
0005433036318	24093	Business	34700.00
0005433922349	24093	Business	34700.00
0005433922495	24093	Business	34700.00
0005433922620	24093	Business	34700.00
0005433922492	24093	Business	34700.00
0005433036324	24093	Business	34700.00
0005432749785	24093	Business	34700.00
0005433036325	24093	Business	34700.00
0005432206196	24093	Business	34700.00
0005433922612	24093	Business	34700.00
0005433922187	24093	Business	34700.00
0005433036285	24093	Business	34700.00
0005433922301	24093	Business	34700.00
0005433922867	24093	Business	34700.00
0005433929590	24093	Business	34700.00
0005433036288	24093	Business	34700.00
0005433922789	24093	Business	34700.00
0005433922434	24093	Economy	12700.00
0005433922455	24093	Economy	12700.00
0005432207663	24093	Economy	12700.00
0005432206198	24093	Economy	11600.00
0005433036319	24093	Economy	11600.00
0005433922618	24093	Economy	11600.00
0005433036327	24093	Economy	11600.00
0005433922432	24093	Economy	11600.00
0005433922243	24093	Economy	11600.00
0005433922085	24093	Economy	11600.00
0005433036323	24093	Economy	11600.00
0005433036306	24093	Economy	11600.00
0005433922166	24093	Economy	11600.00
0005434028297	24093	Economy	11600.00
0005433922500	24093	Economy	11600.00
0005433036293	24093	Economy	11600.00
0005432206194	24093	Economy	11600.00
0005433922598	24093	Economy	11600.00
0005433922982	24093	Economy	11600.00
0005433922795	24093	Economy	11600.00
0005433922195	24093	Economy	11600.00
0005433922491	24093	Economy	11600.00
0005433929575	24093	Economy	11600.00
0005433036310	24093	Economy	11600.00
0005433036298	24093	Economy	11600.00
0005433922733	24093	Economy	11600.00
0005434028295	24093	Economy	11600.00
0005433921940	24093	Economy	11600.00
0005433922447	24093	Economy	11600.00
0005433036302	24093	Economy	11600.00
0005433922433	24093	Economy	11600.00
0005433922446	24093	Economy	11600.00
0005433036280	24093	Economy	11600.00
0005433036305	24093	Economy	11600.00
0005433922405	24093	Economy	11600.00
0005433036307	24093	Economy	11600.00
0005433922414	24093	Economy	11600.00
0005433036296	24093	Economy	11600.00
0005433922603	24093	Economy	11600.00
0005433922898	24093	Economy	11600.00
0005433931452	24093	Economy	11600.00
0005433922431	24093	Economy	11600.00
0005433931433	24093	Economy	11600.00
0005433922547	24093	Economy	11600.00
0005433036282	24093	Economy	11600.00
0005433929568	24093	Economy	11600.00
0005433036276	24093	Economy	11600.00
0005433922617	24093	Economy	11600.00
0005433922123	24093	Economy	11600.00
0005433036312	24093	Economy	11600.00
0005433929576	24093	Economy	11600.00
0005433922659	24093	Economy	11600.00
0005433922242	24093	Economy	11600.00
0005433036299	24093	Economy	11600.00
0005433922284	24093	Economy	11600.00
0005433922279	24093	Economy	11600.00
0005433922981	24093	Economy	11600.00
0005433929577	24093	Economy	11600.00
0005434028296	24093	Economy	11600.00
0005433036295	24093	Economy	11600.00
0005433036297	24093	Economy	11600.00
0005433036289	24093	Economy	11600.00
0005433036304	24093	Economy	11600.00
0005433036311	24093	Economy	11600.00
0005433922194	24093	Economy	11600.00
0005433036278	24093	Economy	11600.00
0005433036321	24093	Economy	11600.00
0005432206197	24093	Economy	11600.00
0005433036287	24093	Economy	11600.00
0005433036290	24093	Economy	11600.00
0005433922658	24093	Economy	11600.00
0005433923058	24093	Economy	11600.00
0005433922343	24093	Economy	11600.00
0005433922747	24093	Economy	12700.00
0005433922712	24093	Economy	11600.00
0005433036286	24093	Economy	11600.00
0005433922502	24093	Economy	12700.00
0005433922623	24093	Economy	11600.00
0005433036315	24093	Economy	11600.00
0005433036309	24093	Economy	11600.00
0005433922436	24093	Economy	11600.00
0005433922616	24093	Economy	11600.00
0005433922656	24093	Economy	11600.00
0005433036301	24093	Economy	11600.00
0005433922319	24093	Economy	11600.00
0005433036281	24093	Economy	11600.00
0005433036320	24093	Economy	11600.00
0005433922746	24093	Economy	11600.00
0005433036316	24093	Economy	11600.00
0005433922619	24093	Economy	11600.00
0005433922375	24093	Economy	11600.00
0005433036303	24093	Economy	11600.00
0005432207662	24093	Economy	11600.00
0005433931451	24093	Economy	11600.00
0005432749786	24093	Economy	11600.00
0005433922788	24093	Economy	11600.00
0005433036313	24093	Economy	11600.00
0005433922124	24093	Economy	11600.00
0005433922292	24093	Economy	11600.00
0005433922832	24093	Economy	11600.00
0005433036328	24093	Economy	11600.00
0005433922418	24093	Economy	11600.00
0005433036294	24093	Economy	11600.00
0005433922348	24093	Economy	11600.00
0005433036317	24093	Economy	11600.00
0005432206193	24093	Economy	11600.00
0005433922507	24093	Economy	11600.00
0005433036274	24093	Economy	11600.00
0005433922622	24093	Economy	11600.00
0005433922572	24093	Economy	11600.00
0005433922408	24093	Economy	11600.00
0005432206195	24093	Economy	11600.00
0005433923059	24093	Economy	11600.00
0005433036283	24093	Economy	11600.00
0005433922454	24093	Economy	11600.00
0005433036322	24093	Economy	11600.00
0005433036275	24093	Economy	11600.00
0005433922086	24093	Economy	11600.00
0005433922606	24093	Economy	11600.00
0005433036291	24093	Economy	11600.00
0005433922287	24093	Economy	11600.00
0005433036326	24093	Economy	11600.00
0005433921913	24093	Economy	11600.00
0005433922573	24093	Economy	11600.00
0005433922637	24093	Economy	11600.00
0005433922724	24093	Economy	11600.00
0005433036277	24093	Economy	11600.00
0005433036308	24093	Economy	11600.00
0005433036292	24093	Economy	11600.00
0005433036300	24093	Economy	11600.00
0005433922651	24093	Economy	11600.00
0005433036279	24093	Economy	11600.00
0005433922490	24093	Economy	11600.00
0005433922288	24093	Economy	11600.00
0005432207661	24093	Economy	11600.00
0005433922511	24093	Economy	11600.00
0005434725489	250	Business	83700.00
0005435142579	250	Business	83700.00
0005433233283	250	Business	83700.00
0005433131674	250	Business	83700.00
0005434031962	250	Business	83700.00
0005435142578	250	Business	83700.00
0005434725418	250	Business	83700.00
0005434725527	250	Business	83700.00
0005433289802	250	Business	83700.00
0005434725462	250	Business	83700.00
0005434735684	250	Business	83700.00
0005433233856	250	Business	83700.00
0005434725491	250	Business	83700.00
0005435142571	250	Business	83700.00
0005434551255	250	Business	83700.00
0005433233803	250	Business	83700.00
0005434725485	250	Business	83700.00
0005434725524	250	Business	83700.00
0005434302459	250	Business	83700.00
0005434725514	250	Business	83700.00
0005433233450	250	Business	83700.00
0005434551222	250	Business	83700.00
0005433180871	250	Business	83700.00
0005434302458	250	Business	83700.00
0005434725496	250	Business	83700.00
0005434725530	250	Business	83700.00
0005434725517	250	Comfort	47400.00
0005434725484	250	Comfort	47400.00
0005433180842	250	Comfort	47400.00
0005434725478	250	Comfort	47400.00
0005434551266	250	Comfort	47400.00
0005433233471	250	Comfort	47400.00
0005433126782	250	Comfort	47400.00
0005434551257	250	Comfort	47400.00
0005434735685	250	Comfort	47400.00
0005433180795	250	Comfort	47400.00
0005434725532	250	Comfort	47400.00
0005433126818	250	Comfort	47400.00
0005434551218	250	Comfort	47400.00
0005434551221	250	Comfort	47400.00
0005433233711	250	Comfort	47400.00
0005433180863	250	Comfort	47400.00
0005433111472	250	Comfort	47400.00
0005433233900	250	Comfort	47400.00
0005433180812	250	Comfort	47400.00
0005433233808	250	Comfort	47400.00
0005434725494	250	Comfort	47400.00
0005434725449	250	Comfort	47400.00
0005434725463	250	Comfort	47400.00
0005433233787	250	Comfort	47400.00
0005434551226	250	Comfort	47400.00
0005433233641	250	Comfort	47400.00
0005433233902	250	Comfort	47400.00
0005435142582	250	Comfort	47400.00
0005434725512	250	Comfort	47400.00
0005434725455	250	Comfort	47400.00
0005434725529	250	Comfort	47400.00
0005434725497	250	Comfort	47400.00
0005433113519	250	Comfort	47400.00
0005435142574	250	Comfort	47400.00
0005434725479	250	Comfort	47400.00
0005434725522	250	Comfort	47400.00
0005433131662	250	Comfort	47400.00
0005434725457	250	Comfort	47400.00
0005433131673	250	Comfort	47400.00
0005434551214	250	Comfort	47400.00
0005434031976	250	Comfort	47400.00
0005432277815	250	Comfort	47400.00
0005434551237	250	Comfort	47400.00
0005433180931	250	Comfort	47400.00
0005433233837	250	Comfort	47400.00
0005433289790	250	Economy	27900.00
0005434725516	250	Economy	27900.00
0005434302460	250	Economy	27900.00
0005434725515	250	Economy	27900.00
0005434725487	250	Economy	27900.00
0005434725474	250	Economy	27900.00
0005434725451	250	Economy	27900.00
0005434725505	250	Economy	27900.00
0005434725424	250	Economy	27900.00
0005434725465	250	Economy	27900.00
0005434725521	250	Economy	27900.00
0005433233329	250	Economy	27900.00
0005433289752	250	Economy	27900.00
0005434725538	250	Economy	27900.00
0005434725493	250	Economy	27900.00
0005434551251	250	Economy	27900.00
0005433233760	250	Economy	27900.00
0005434725448	250	Economy	27900.00
0005433180854	250	Economy	27900.00
0005433180815	250	Economy	27900.00
0005434551254	250	Economy	27900.00
0005434725468	250	Economy	27900.00
0005434725536	250	Economy	27900.00
0005433233282	250	Economy	27900.00
0005433131672	250	Economy	27900.00
0005434551259	250	Economy	27900.00
0005433233601	250	Economy	27900.00
0005434735683	250	Economy	27900.00
0005434735686	250	Economy	27900.00
0005433126796	250	Economy	27900.00
0005432277811	250	Economy	27900.00
0005434551267	250	Economy	27900.00
0005434725434	250	Economy	27900.00
0005434551239	250	Economy	27900.00
0005434725452	250	Economy	27900.00
0005434725429	250	Economy	27900.00
0005433233844	250	Economy	27900.00
0005434551260	250	Economy	27900.00
0005432277808	250	Economy	27900.00
0005433180808	250	Economy	27900.00
0005433233452	250	Economy	27900.00
0005434725419	250	Economy	27900.00
0005433233771	250	Economy	27900.00
0005434551265	250	Economy	27900.00
0005434731168	250	Economy	27900.00
0005433180797	250	Economy	27900.00
0005434725483	250	Economy	27900.00
0005434551245	250	Economy	27900.00
0005433233845	250	Economy	27900.00
0005433233592	250	Economy	27900.00
0005434725428	250	Economy	27900.00
0005434551212	250	Economy	27900.00
0005432277809	250	Economy	27900.00
0005434725445	250	Economy	27900.00
0005433233903	250	Economy	27900.00
0005435142577	250	Economy	27900.00
0005433233717	250	Economy	27900.00
0005434725500	250	Economy	27900.00
0005434551235	250	Economy	27900.00
0005434725461	250	Economy	27900.00
0005432277810	250	Economy	27900.00
0005433126798	250	Economy	27900.00
0005434725486	250	Economy	27900.00
0005433233836	250	Economy	27900.00
0005433180757	250	Economy	30700.00
0005433180875	250	Economy	27900.00
0005433126797	250	Economy	30700.00
0005434725441	250	Economy	30700.00
0005434031973	250	Economy	27900.00
0005433233562	250	Economy	27900.00
0005433181017	250	Economy	27900.00
0005434725533	250	Economy	30700.00
0005434725426	250	Economy	30700.00
0005435142576	250	Economy	27900.00
0005433180756	250	Economy	30700.00
0005433131669	250	Economy	27900.00
0005433233895	250	Economy	27900.00
0005435142572	250	Economy	27900.00
0005433289803	250	Economy	27900.00
0005434725476	250	Economy	27900.00
0005434551232	250	Economy	27900.00
0005434725470	250	Economy	27900.00
0005433131676	250	Economy	27900.00
0005433131666	250	Economy	27900.00
0005434725537	250	Economy	27900.00
0005432277807	250	Economy	27900.00
0005434725433	250	Economy	27900.00
0005435142573	250	Economy	27900.00
0005434725458	250	Economy	27900.00
0005434551252	250	Economy	27900.00
0005434725460	250	Economy	27900.00
0005433233772	250	Economy	27900.00
0005434725431	250	Economy	27900.00
0005433131660	250	Economy	27900.00
0005433126795	250	Economy	27900.00
0005434725435	250	Economy	27900.00
0005433233652	250	Economy	27900.00
0005433131661	250	Economy	27900.00
0005433126819	250	Economy	27900.00
0005434551250	250	Economy	27900.00
0005433180877	250	Economy	27900.00
0005433180865	250	Economy	27900.00
0005433113522	250	Economy	27900.00
0005433233881	250	Economy	27900.00
0005433233577	250	Economy	27900.00
0005433233761	250	Economy	27900.00
0005433180796	250	Economy	27900.00
0005434725507	250	Economy	27900.00
0005433233882	250	Economy	27900.00
0005433233561	250	Economy	27900.00
0005434551230	250	Economy	27900.00
0005433233706	250	Economy	27900.00
0005432277803	250	Economy	27900.00
0005433233690	250	Economy	27900.00
0005434551219	250	Economy	27900.00
0005432277812	250	Economy	27900.00
0005432277804	250	Economy	27900.00
0005433233901	250	Economy	27900.00
0005434551213	250	Economy	27900.00
0005434551225	250	Economy	27900.00
0005433233599	250	Economy	27900.00
0005434725472	250	Economy	27900.00
0005433233696	250	Economy	27900.00
0005434725528	250	Economy	27900.00
0005434725501	250	Economy	27900.00
0005434725440	250	Economy	27900.00
0005434551247	250	Economy	27900.00
0005434725437	250	Economy	27900.00
0005434725447	250	Economy	27900.00
0005434725509	250	Economy	27900.00
0005434725423	250	Economy	27900.00
0005433233870	250	Economy	27900.00
0005434725443	250	Economy	27900.00
0005432277806	250	Economy	27900.00
0005433234039	250	Economy	27900.00
0005434725518	250	Economy	27900.00
0005434725488	250	Economy	27900.00
0005433180981	250	Economy	27900.00
0005433233488	250	Economy	27900.00
0005434551223	250	Economy	27900.00
0005434725432	250	Economy	27900.00
0005433126784	250	Economy	27900.00
0005434725420	250	Economy	27900.00
0005434731166	250	Economy	27900.00
0005434551234	250	Economy	27900.00
0005434031986	250	Economy	27900.00
0005434725498	250	Economy	27900.00
0005434551258	250	Economy	27900.00
0005434725475	250	Economy	27900.00
0005434725439	250	Economy	27900.00
0005433131675	250	Economy	27900.00
0005433233545	250	Economy	27900.00
0005433233548	250	Economy	27900.00
0005434725525	250	Economy	27900.00
0005434551220	250	Economy	27900.00
0005433233726	250	Economy	27900.00
0005434725467	250	Economy	27900.00
0005434551224	250	Economy	27900.00
0005434551231	250	Economy	27900.00
0005433233673	250	Economy	27900.00
0005434725503	250	Economy	27900.00
0005433180846	250	Economy	27900.00
0005433180809	250	Economy	27900.00
0005434725539	250	Economy	27900.00
0005433180864	250	Economy	27900.00
0005433233550	250	Economy	27900.00
0005433233634	250	Economy	27900.00
0005433233449	250	Economy	27900.00
0005433233667	250	Economy	27900.00
0005434725473	250	Economy	27900.00
0005434551215	250	Economy	27900.00
0005434725471	250	Economy	27900.00
0005434725510	250	Economy	27900.00
0005434551263	250	Economy	27900.00
0005434551262	250	Economy	27900.00
0005434725508	250	Economy	27900.00
0005434551238	250	Economy	27900.00
0005432277805	250	Economy	27900.00
0005433180932	250	Economy	27900.00
0005433233858	250	Economy	27900.00
0005433233600	250	Economy	27900.00
0005434551217	250	Economy	27900.00
0005432277814	250	Economy	27900.00
0005434725531	250	Economy	30700.00
0005435142584	250	Economy	30700.00
0005434725442	250	Economy	30700.00
0005434725480	250	Economy	30700.00
0005433233591	250	Economy	30700.00
0005434551243	250	Economy	27900.00
0005433233472	250	Economy	27900.00
0005433233782	250	Economy	27900.00
0005433233393	250	Economy	27900.00
0005434725466	250	Economy	27900.00
0005433233892	250	Economy	27900.00
0005434725506	250	Economy	27900.00
0005434551236	250	Economy	27900.00
0005433233251	250	Economy	27900.00
0005434725519	250	Economy	27900.00
0005434725540	250	Economy	27900.00
0005434551253	250	Economy	27900.00
0005435142583	250	Economy	27900.00
0005434725425	250	Economy	27900.00
0005433233664	250	Economy	27900.00
0005433126804	250	Economy	27900.00
0005433113520	250	Economy	27900.00
0005433233695	250	Economy	27900.00
0005434725482	250	Economy	27900.00
0005433289789	250	Economy	27900.00
0005433233746	250	Economy	27900.00
0005434551240	250	Economy	27900.00
0005433233725	250	Economy	27900.00
0005433180862	250	Economy	27900.00
0005435142581	250	Economy	27900.00
0005434725436	250	Economy	27900.00
0005434551227	250	Economy	27900.00
0005433126799	250	Economy	27900.00
0005433233757	250	Economy	27900.00
0005433180874	250	Economy	27900.00
0005434725430	250	Economy	27900.00
0005433233804	250	Economy	27900.00
0005432277816	250	Economy	27900.00
0005434725499	250	Economy	27900.00
0005433233637	250	Economy	27900.00
0005435142580	250	Economy	27900.00
0005434031963	250	Economy	27900.00
0005433131668	250	Economy	27900.00
0005434735687	250	Economy	27900.00
0005434551249	250	Economy	27900.00
0005434725481	250	Economy	27900.00
0005434725513	250	Economy	27900.00
0005433131671	250	Economy	27900.00
0005433289773	250	Economy	27900.00
0005432277813	250	Economy	27900.00
0005434031977	250	Economy	27900.00
0005434725446	250	Economy	27900.00
0005434725511	250	Economy	27900.00
0005433233666	250	Economy	27900.00
0005434725450	250	Economy	27900.00
0005434725469	250	Economy	27900.00
0005434725438	250	Economy	27900.00
0005434725459	250	Economy	27900.00
0005434551246	250	Economy	27900.00
0005433233720	250	Economy	27900.00
0005434725495	250	Economy	27900.00
0005435142575	250	Economy	27900.00
0005434725422	250	Economy	27900.00
0005434725504	250	Economy	27900.00
0005434551216	250	Economy	27900.00
0005433233671	250	Economy	27900.00
0005434725427	250	Economy	27900.00
0005433126783	250	Economy	27900.00
0005434725492	250	Economy	27900.00
0005434725454	250	Economy	27900.00
0005434031959	250	Economy	27900.00
0005434551244	250	Economy	27900.00
0005434551248	250	Economy	27900.00
0005433233685	250	Economy	27900.00
0005434551233	250	Economy	27900.00
0005434725535	250	Economy	27900.00
0005433233549	250	Economy	27900.00
0005433233871	250	Economy	27900.00
0005434551229	250	Economy	27900.00
0005434302461	250	Economy	27900.00
0005434731167	250	Economy	27900.00
0005434551228	250	Economy	27900.00
0005434725444	250	Economy	27900.00
0005434551261	250	Economy	27900.00
0005434551264	250	Economy	27900.00
0005434725421	250	Economy	27900.00
0005433233503	250	Economy	27900.00
0005434551256	250	Economy	27900.00
0005433233807	250	Economy	27900.00
0005434725417	250	Economy	27900.00
0005434725534	250	Economy	27900.00
0005434031970	250	Economy	27900.00
0005434725520	250	Economy	27900.00
0005434725453	250	Economy	27900.00
0005433233328	250	Economy	27900.00
0005433113521	250	Economy	27900.00
0005434725526	250	Economy	27900.00
0005434031972	250	Economy	27900.00
0005433233616	250	Economy	27900.00
0005434725490	250	Economy	27900.00
0005434725456	250	Economy	27900.00
0005434725464	250	Economy	27900.00
0005434551241	250	Economy	27900.00
0005434725523	250	Economy	27900.00
0005434725502	250	Economy	27900.00
0005434551242	250	Economy	27900.00
0005434725477	250	Economy	27900.00
0005434724547	9838	Business	83700.00
0005433234183	9838	Business	83700.00
0005433234219	9838	Business	83700.00
0005433234227	9838	Business	83700.00
0005433234184	9838	Business	83700.00
0005434550736	9838	Business	83700.00
0005433289845	9838	Business	83700.00
0005434724834	9838	Business	83700.00
0005433181094	9838	Business	83700.00
0005434550735	9838	Business	83700.00
0005433234190	9838	Business	83700.00
0005434724414	9838	Business	83700.00
0005434724594	9838	Business	83700.00
0005433181096	9838	Business	83700.00
0005434724060	9838	Business	83700.00
0005434550811	9838	Business	83700.00
0005434724341	9838	Business	83700.00
0005433234200	9838	Business	83700.00
0005432199248	9838	Business	83700.00
0005434550640	9838	Business	83700.00
0005432199252	9838	Business	83700.00
0005433234186	9838	Business	83700.00
0005434724442	9838	Business	83700.00
0005433234187	9838	Business	83700.00
0005434724711	9838	Comfort	47400.00
0005432199246	9838	Comfort	47400.00
0005433181108	9838	Comfort	47400.00
0005432199250	9838	Comfort	47400.00
0005434032027	9838	Comfort	47400.00
0005432199245	9838	Comfort	47400.00
0005434550617	9838	Comfort	47400.00
0005434550810	9838	Comfort	47400.00
0005434302426	9838	Comfort	47400.00
0005434550709	9838	Comfort	47400.00
0005433234181	9838	Comfort	47400.00
0005434723931	9838	Comfort	47400.00
0005434550733	9838	Comfort	47400.00
0005434550592	9838	Comfort	47400.00
0005434724221	9838	Comfort	47400.00
0005433181109	9838	Comfort	47400.00
0005433234210	9838	Comfort	47400.00
0005434724567	9838	Comfort	47400.00
0005434724655	9838	Comfort	47400.00
0005433129274	9838	Comfort	47400.00
0005434724011	9838	Comfort	47400.00
0005433766638	9838	Comfort	47400.00
0005434550542	9838	Comfort	47400.00
0005434032023	9838	Comfort	47400.00
0005435142449	9838	Comfort	47400.00
0005433766641	9838	Comfort	47400.00
0005433234179	9838	Comfort	47400.00
0005434550615	9838	Comfort	47400.00
0005433234220	9838	Comfort	47400.00
0005433129273	9838	Comfort	47400.00
0005433289844	9838	Comfort	47400.00
0005433234218	9838	Comfort	47400.00
0005434724266	9838	Comfort	47400.00
0005434550875	9838	Comfort	47400.00
0005434724620	9838	Comfort	47400.00
0005434724403	9838	Comfort	47400.00
0005434550509	9838	Economy	27900.00
0005433181098	9838	Comfort	47400.00
0005434550616	9838	Economy	27900.00
0005434550558	9838	Economy	27900.00
0005434723993	9838	Economy	27900.00
0005433234221	9838	Economy	27900.00
0005433234199	9838	Economy	27900.00
0005434724689	9838	Economy	27900.00
0005434550689	9838	Economy	27900.00
0005433181092	9838	Economy	27900.00
0005434724680	9838	Economy	27900.00
0005433113536	9838	Economy	27900.00
0005433234232	9838	Economy	27900.00
0005433181112	9838	Economy	27900.00
0005434724334	9838	Economy	27900.00
0005433234176	9838	Economy	27900.00
0005432199249	9838	Economy	27900.00
0005434550690	9838	Economy	27900.00
0005434724150	9838	Economy	27900.00
0005434550760	9838	Economy	27900.00
0005433234188	9838	Economy	27900.00
0005433234211	9838	Economy	27900.00
0005434724386	9838	Economy	27900.00
0005434724736	9838	Economy	27900.00
0005434724759	9838	Economy	27900.00
0005434724078	9838	Economy	27900.00
0005434724546	9838	Economy	27900.00
0005434724530	9838	Economy	27900.00
0005434032026	9838	Economy	27900.00
0005434723875	9838	Economy	27900.00
0005434724545	9838	Economy	27900.00
0005434724441	9838	Economy	27900.00
0005434724687	9838	Economy	27900.00
0005434724316	9838	Economy	27900.00
0005433181100	9838	Economy	27900.00
0005434724400	9838	Economy	27900.00
0005433234207	9838	Economy	27900.00
0005434724315	9838	Economy	27900.00
0005434724519	9838	Economy	27900.00
0005433129276	9838	Economy	27900.00
0005433234225	9838	Economy	27900.00
0005434724401	9838	Economy	27900.00
0005433181106	9838	Economy	27900.00
0005435142368	9838	Economy	27900.00
0005434550655	9838	Economy	27900.00
0005434550874	9838	Economy	27900.00
0005434723642	9838	Economy	27900.00
0005433234202	9838	Economy	27900.00
0005434724859	9838	Economy	27900.00
0005433234231	9838	Economy	27900.00
0005434550757	9838	Economy	27900.00
0005434724532	9838	Economy	27900.00
0005433234209	9838	Economy	27900.00
0005434724971	9838	Economy	27900.00
0005434724313	9838	Economy	27900.00
0005434550718	9838	Economy	27900.00
0005433234192	9838	Economy	27900.00
0005434550559	9838	Economy	27900.00
0005434724290	9838	Economy	27900.00
0005434735653	9838	Economy	27900.00
0005434724216	9838	Economy	30700.00
0005433181090	9838	Economy	27900.00
0005434724357	9838	Economy	30700.00
0005434302395	9838	Economy	30700.00
0005434724353	9838	Economy	27900.00
0005433234234	9838	Economy	27900.00
0005434723958	9838	Economy	30700.00
0005433289848	9838	Economy	27900.00
0005434302413	9838	Economy	30700.00
0005434550785	9838	Economy	27900.00
0005434032025	9838	Economy	27900.00
0005434724333	9838	Economy	27900.00
0005433126846	9838	Economy	27900.00
0005434724217	9838	Economy	27900.00
0005434550580	9838	Economy	27900.00
0005433181110	9838	Economy	27900.00
0005434725037	9838	Economy	27900.00
0005434550680	9838	Economy	27900.00
0005434550708	9838	Economy	27900.00
0005434550693	9838	Economy	27900.00
0005434550859	9838	Economy	27900.00
0005434723825	9838	Economy	27900.00
0005434302414	9838	Economy	27900.00
0005433234205	9838	Economy	27900.00
0005434724746	9838	Economy	27900.00
0005434550781	9838	Economy	27900.00
0005434550862	9838	Economy	27900.00
0005433181105	9838	Economy	27900.00
0005432199247	9838	Economy	27900.00
0005433234229	9838	Economy	27900.00
0005434724638	9838	Economy	27900.00
0005434724327	9838	Economy	27900.00
0005435142492	9838	Economy	27900.00
0005434550786	9838	Economy	27900.00
0005434550688	9838	Economy	27900.00
0005434724571	9838	Economy	27900.00
0005434550931	9838	Economy	27900.00
0005434302420	9838	Economy	27900.00
0005434724830	9838	Economy	27900.00
0005433289847	9838	Economy	27900.00
0005434724752	9838	Economy	27900.00
0005434550806	9838	Economy	27900.00
0005434724585	9838	Economy	27900.00
0005433181093	9838	Economy	27900.00
0005434724468	9838	Economy	27900.00
0005433234195	9838	Economy	27900.00
0005433234217	9838	Economy	27900.00
0005435142399	9838	Economy	27900.00
0005433181087	9838	Economy	27900.00
0005434550808	9838	Economy	27900.00
0005434550819	9838	Economy	27900.00
0005434550562	9838	Economy	27900.00
0005434724558	9838	Economy	27900.00
0005435142450	9838	Economy	27900.00
0005434032024	9838	Economy	27900.00
0005433129275	9838	Economy	27900.00
0005434724512	9838	Economy	27900.00
0005433289849	9838	Economy	27900.00
0005434302412	9838	Economy	27900.00
0005434724603	9838	Economy	27900.00
0005434724580	9838	Economy	27900.00
0005434724688	9838	Economy	27900.00
0005433234208	9838	Economy	27900.00
0005434724760	9838	Economy	27900.00
0005434724520	9838	Economy	27900.00
0005434724605	9838	Economy	27900.00
0005433234235	9838	Economy	27900.00
0005434723977	9838	Economy	27900.00
0005434724538	9838	Economy	27900.00
0005434550784	9838	Economy	27900.00
0005434550812	9838	Economy	27900.00
0005433181111	9838	Economy	27900.00
0005434724931	9838	Economy	27900.00
0005434723835	9838	Economy	27900.00
0005434550853	9838	Economy	27900.00
0005434550854	9838	Economy	27900.00
0005434724782	9838	Economy	27900.00
0005434725076	9838	Economy	27900.00
0005434724415	9838	Economy	27900.00
0005433234214	9838	Economy	27900.00
0005434724741	9838	Economy	27900.00
0005434724262	9838	Economy	27900.00
0005433234226	9838	Economy	27900.00
0005435142400	9838	Economy	27900.00
0005434550804	9838	Economy	27900.00
0005434724090	9838	Economy	27900.00
0005434550950	9838	Economy	27900.00
0005433181102	9838	Economy	27900.00
0005433181107	9838	Economy	27900.00
0005433181101	9838	Economy	27900.00
0005433234216	9838	Economy	27900.00
0005433234197	9838	Economy	27900.00
0005433234206	9838	Economy	27900.00
0005433234213	9838	Economy	27900.00
0005434550710	9838	Economy	27900.00
0005434724665	9838	Economy	27900.00
0005433113535	9838	Economy	27900.00
0005434724366	9838	Economy	27900.00
0005433234182	9838	Economy	27900.00
0005434724392	9838	Economy	30700.00
0005433181103	9838	Economy	30700.00
0005433181099	9838	Economy	30700.00
0005433234223	9838	Economy	30700.00
0005434550527	9838	Economy	30700.00
0005434724903	9838	Economy	27900.00
0005434302404	9838	Economy	27900.00
0005434724621	9838	Economy	27900.00
0005434724709	9838	Economy	27900.00
0005434724123	9838	Economy	27900.00
0005434735644	9838	Economy	27900.00
0005434724761	9838	Economy	27900.00
0005434550547	9838	Economy	27900.00
0005433234237	9838	Economy	27900.00
0005434724443	9838	Economy	27900.00
0005434724954	9838	Economy	27900.00
0005434723626	9838	Economy	27900.00
0005434724237	9838	Economy	27900.00
0005434724548	9838	Economy	27900.00
0005434724697	9838	Economy	27900.00
0005433234178	9838	Economy	27900.00
0005434550519	9838	Economy	27900.00
0005433126844	9838	Economy	27900.00
0005433234230	9838	Economy	27900.00
0005433234228	9838	Economy	27900.00
0005433234198	9838	Economy	27900.00
0005433181088	9838	Economy	27900.00
0005434724579	9838	Economy	27900.00
0005434724413	9838	Economy	27900.00
0005434724234	9838	Economy	27900.00
0005433234212	9838	Economy	27900.00
0005433181104	9838	Economy	27900.00
0005434724256	9838	Economy	27900.00
0005434550579	9838	Economy	27900.00
0005434302415	9838	Economy	27900.00
0005434724387	9838	Economy	27900.00
0005434724476	9838	Economy	27900.00
0005433126843	9838	Economy	27900.00
0005434723830	9838	Economy	27900.00
0005433234180	9838	Economy	27900.00
0005434550561	9838	Economy	27900.00
0005434724826	9838	Economy	27900.00
0005433234203	9838	Economy	27900.00
0005434724953	9838	Economy	27900.00
0005434550404	9838	Economy	27900.00
0005435142431	9838	Economy	27900.00
0005434302409	9838	Economy	27900.00
0005434724426	9838	Economy	27900.00
0005433234204	9838	Economy	27900.00
0005433129277	9838	Economy	27900.00
0005434724563	9838	Economy	27900.00
0005434724487	9838	Economy	27900.00
0005433766639	9838	Economy	27900.00
0005434724233	9838	Economy	27900.00
0005434724753	9838	Economy	27900.00
0005433234238	9838	Economy	27900.00
0005433234191	9838	Economy	27900.00
0005432199251	9838	Economy	27900.00
0005434724533	9838	Economy	27900.00
0005433126845	9838	Economy	27900.00
0005433234233	9838	Economy	27900.00
0005433181095	9838	Economy	27900.00
0005434724482	9838	Economy	27900.00
0005434724738	9838	Economy	27900.00
0005434724222	9838	Economy	27900.00
0005433126842	9838	Economy	27900.00
0005433234239	9838	Economy	27900.00
0005433181097	9838	Economy	27900.00
0005433234224	9838	Economy	27900.00
0005434723874	9838	Economy	27900.00
0005434724564	9838	Economy	27900.00
0005433234185	9838	Economy	27900.00
0005433234222	9838	Economy	27900.00
0005434724714	9838	Economy	27900.00
0005433234196	9838	Economy	27900.00
0005434724423	9838	Economy	27900.00
0005434724311	9838	Economy	27900.00
0005433234194	9838	Economy	27900.00
0005433766640	9838	Economy	27900.00
0005433234189	9838	Economy	27900.00
0005434550861	9838	Economy	27900.00
0005434724690	9838	Economy	27900.00
0005434550419	9838	Economy	27900.00
0005433126847	9838	Economy	27900.00
0005435142367	9838	Economy	27900.00
0005433234236	9838	Economy	27900.00
0005433181089	9838	Economy	27900.00
0005433234215	9838	Economy	27900.00
0005433181091	9838	Economy	27900.00
0005434550930	9838	Economy	27900.00
0005434302425	9838	Economy	27900.00
0005434724393	9838	Economy	27900.00
0005434724061	9838	Economy	27900.00
0005434724737	9838	Economy	27900.00
0005433234201	9838	Economy	27900.00
0005433234177	9838	Economy	27900.00
0005433234193	9838	Economy	27900.00
0005433289846	9838	Economy	27900.00
0005434724592	9838	Economy	27900.00
0005432527932	7741	Business	42100.00
0005434067562	7741	Business	42100.00
0005434067600	7741	Business	42100.00
0005434067595	7741	Business	42100.00
0005434067551	7741	Business	42100.00
0005435212752	7741	Business	42100.00
0005435212862	7741	Business	42100.00
0005432527985	7741	Business	42100.00
0005432527924	7741	Business	42100.00
0005432528035	7741	Business	42100.00
0005435213064	7741	Business	42100.00
0005432527970	7741	Business	42100.00
0005432528015	7741	Business	42100.00
0005434067556	7741	Business	42100.00
0005435213056	7741	Business	42100.00
0005432537057	7741	Business	42100.00
0005432527969	7741	Business	42100.00
0005435212838	7741	Business	42100.00
0005432528041	7741	Business	42100.00
0005432528027	7741	Business	42100.00
0005434067548	7741	Business	42100.00
0005435630944	7741	Business	42100.00
0005435213275	7741	Business	42100.00
0005433656633	7741	Comfort	23900.00
0005432535834	7741	Comfort	23900.00
0005432528024	7741	Comfort	23900.00
0005432527998	7741	Comfort	23900.00
0005432527937	7741	Comfort	23900.00
0005434067588	7741	Comfort	23900.00
0005432527921	7741	Comfort	23900.00
0005434067547	7741	Comfort	23900.00
0005434067560	7741	Comfort	23900.00
0005435212888	7741	Comfort	23900.00
0005432527973	7741	Comfort	23900.00
0005432528033	7741	Comfort	23900.00
0005435212761	7741	Comfort	23900.00
0005432069657	7741	Comfort	23900.00
0005434067555	7741	Comfort	23900.00
0005435213123	7741	Comfort	23900.00
0005432527971	7741	Comfort	23900.00
0005432527967	7741	Comfort	23900.00
0005434067568	7741	Comfort	23900.00
0005434067589	7741	Comfort	23900.00
0005432527991	7741	Comfort	23900.00
0005435212966	7741	Comfort	23900.00
0005432528000	7741	Comfort	23900.00
0005432527942	7741	Comfort	23900.00
0005432527997	7741	Comfort	23900.00
0005435212726	7741	Comfort	23900.00
0005432527920	7741	Comfort	23900.00
0005432528047	7741	Comfort	23900.00
0005432527919	7741	Comfort	23900.00
0005434067545	7741	Comfort	23900.00
0005435630938	7741	Comfort	23900.00
0005434067564	7741	Comfort	23900.00
0005435213124	7741	Comfort	23900.00
0005432527933	7741	Comfort	23900.00
0005435213013	7741	Comfort	23900.00
0005434067578	7741	Comfort	23900.00
0005432527977	7741	Comfort	23900.00
0005432528030	7741	Economy	14000.00
0005432069660	7741	Economy	14000.00
0005434067532	7741	Economy	14000.00
0005432150193	7741	Economy	14000.00
0005432527988	7741	Economy	14000.00
0005432069656	7741	Economy	14000.00
0005434067530	7741	Economy	14000.00
0005432528008	7741	Economy	14000.00
0005432069650	7741	Economy	14000.00
0005435212846	7741	Economy	14000.00
0005432528038	7741	Economy	14000.00
0005435212979	7741	Economy	14000.00
0005434067540	7741	Economy	14000.00
0005434067590	7741	Economy	14000.00
0005432528028	7741	Economy	14000.00
0005432528001	7741	Economy	14000.00
0005432527929	7741	Economy	14000.00
0005432528026	7741	Economy	14000.00
0005432528010	7741	Economy	14000.00
0005434067581	7741	Economy	14000.00
0005432150192	7741	Economy	14000.00
0005432528007	7741	Economy	14000.00
0005432528025	7741	Economy	14000.00
0005432528014	7741	Economy	14000.00
0005432537058	7741	Economy	14000.00
0005434067552	7741	Economy	14000.00
0005435212801	7741	Economy	14000.00
0005435725551	7741	Economy	14000.00
0005432069653	7741	Economy	14000.00
0005434067573	7741	Economy	14000.00
0005432150191	7741	Economy	14000.00
0005435213010	7741	Economy	14000.00
0005434067591	7741	Economy	14000.00
0005432527941	7741	Economy	14000.00
0005435212889	7741	Economy	14000.00
0005434067570	7741	Economy	14000.00
0005432527956	7741	Economy	14000.00
0005435213235	7741	Economy	14000.00
0005435630918	7741	Economy	14000.00
0005434067587	7741	Economy	14000.00
0005434067583	7741	Economy	14000.00
0005435212610	7741	Economy	14000.00
0005432527966	7741	Economy	14000.00
0005435212463	7741	Economy	14000.00
0005432527968	7741	Economy	14000.00
0005432527976	7741	Economy	14000.00
0005435212971	7741	Economy	14000.00
0005433656638	7741	Economy	14000.00
0005432527952	7741	Economy	14000.00
0005435213089	7741	Economy	14000.00
0005434067602	7741	Economy	14000.00
0005432069651	7741	Economy	14000.00
0005432528044	7741	Economy	14000.00
0005434067561	7741	Economy	14000.00
0005432527992	7741	Economy	14000.00
0005432528018	7741	Economy	14000.00
0005432527982	7741	Economy	14000.00
0005432150199	7741	Economy	14000.00
0005435212935	7741	Economy	15400.00
0005432527964	7741	Economy	14000.00
0005434067579	7741	Economy	15400.00
0005435725535	7741	Economy	14000.00
0005432527949	7741	Economy	14000.00
0005434067572	7741	Economy	14000.00
0005434067538	7741	Economy	14000.00
0005434067565	7741	Economy	14000.00
0005435212822	7741	Economy	14000.00
0005432527948	7741	Economy	14000.00
0005432528045	7741	Economy	14000.00
0005435212762	7741	Economy	14000.00
0005432528037	7741	Economy	14000.00
0005435212839	7741	Economy	14000.00
0005432069648	7741	Economy	14000.00
0005435212751	7741	Economy	14000.00
0005432527954	7741	Economy	14000.00
0005432527944	7741	Economy	14000.00
0005434067542	7741	Economy	14000.00
0005432527995	7741	Economy	14000.00
0005432528036	7741	Economy	14000.00
0005434067596	7741	Economy	14000.00
0005432527928	7741	Economy	14000.00
0005432069652	7741	Economy	14000.00
0005432428927	7741	Economy	14000.00
0005432428928	7741	Economy	14000.00
0005432527986	7741	Economy	14000.00
0005435725560	7741	Economy	14000.00
0005432069658	7741	Economy	14000.00
0005434067571	7741	Economy	14000.00
0005432069659	7741	Economy	14000.00
0005435212895	7741	Economy	14000.00
0005434067531	7741	Economy	14000.00
0005435213050	7741	Economy	14000.00
0005432533291	7741	Economy	14000.00
0005432150198	7741	Economy	14000.00
0005432527981	7741	Economy	14000.00
0005432535835	7741	Economy	14000.00
0005432527983	7741	Economy	14000.00
0005432527938	7741	Economy	14000.00
0005432527963	7741	Economy	14000.00
0005435212901	7741	Economy	14000.00
0005432528034	7741	Economy	14000.00
0005435212969	7741	Economy	14000.00
0005432527958	7741	Economy	14000.00
0005434067569	7741	Economy	14000.00
0005435212976	7741	Economy	14000.00
0005432528017	7741	Economy	14000.00
0005432527960	7741	Economy	14000.00
0005435212944	7741	Economy	14000.00
0005432528016	7741	Economy	14000.00
0005434067586	7741	Economy	14000.00
0005435213011	7741	Economy	14000.00
0005435212967	7741	Economy	14000.00
0005432527914	7741	Economy	14000.00
0005434067594	7741	Economy	14000.00
0005432069649	7741	Economy	14000.00
0005434067575	7741	Economy	14000.00
0005432533292	7741	Economy	14000.00
0005432150197	7741	Economy	14000.00
0005432528012	7741	Economy	14000.00
0005435212866	7741	Economy	14000.00
0005434067580	7741	Economy	14000.00
0005435212877	7741	Economy	14000.00
0005434067597	7741	Economy	14000.00
0005435725536	7741	Economy	14000.00
0005432527936	7741	Economy	14000.00
0005435212946	7741	Economy	14000.00
0005432150195	7741	Economy	14000.00
0005432527962	7741	Economy	14000.00
0005435212834	7741	Economy	14000.00
0005432069655	7741	Economy	14000.00
0005432527965	7741	Economy	14000.00
0005432528022	7741	Economy	14000.00
0005435213060	7741	Economy	14000.00
0005432528043	7741	Economy	14000.00
0005432527915	7741	Economy	14000.00
0005432535831	7741	Economy	14000.00
0005432527990	7741	Economy	14000.00
0005434067582	7741	Economy	14000.00
0005434067585	7741	Economy	14000.00
0005435212462	7741	Economy	14000.00
0005434067544	7741	Economy	14000.00
0005432150196	7741	Economy	14000.00
0005432527974	7741	Economy	14000.00
0005432527945	7741	Economy	14000.00
0005434067566	7741	Economy	14000.00
0005435725543	7741	Economy	14000.00
0005434067536	7741	Economy	14000.00
0005432528040	7741	Economy	14000.00
0005435213103	7741	Economy	14000.00
0005432528039	7741	Economy	14000.00
0005434067557	7741	Economy	14000.00
0005432527972	7741	Economy	14000.00
0005432527987	7741	Economy	14000.00
0005434067601	7741	Economy	14000.00
0005434067577	7741	Economy	14000.00
0005432527918	7741	Economy	14000.00
0005432528031	7741	Economy	14000.00
0005432527999	7741	Economy	14000.00
0005432527975	7741	Economy	14000.00
0005432527931	7741	Economy	14000.00
0005432150194	7741	Economy	14000.00
0005432528029	7741	Economy	14000.00
0005435212970	7741	Economy	14000.00
0005432527946	7741	Economy	14000.00
0005432527955	7741	Economy	14000.00
0005434067554	7741	Economy	15400.00
0005432527943	7741	Economy	15400.00
0005432527961	7741	Economy	15400.00
0005434067559	7741	Economy	14000.00
0005432528013	7741	Economy	15400.00
0005432527935	7741	Economy	15400.00
0005432535832	7741	Economy	14000.00
0005432527923	7741	Economy	14000.00
0005432527953	7741	Economy	14000.00
0005432527994	7741	Economy	14000.00
0005432527939	7741	Economy	14000.00
0005435213059	7741	Economy	14000.00
0005432527940	7741	Economy	14000.00
0005435212784	7741	Economy	14000.00
0005434067529	7741	Economy	14000.00
0005432527980	7741	Economy	14000.00
0005433656620	7741	Economy	14000.00
0005432528006	7741	Economy	14000.00
0005434067592	7741	Economy	14000.00
0005434067546	7741	Economy	14000.00
0005432069654	7741	Economy	14000.00
0005432528020	7741	Economy	14000.00
0005435725544	7741	Economy	14000.00
0005432527950	7741	Economy	14000.00
0005435212934	7741	Economy	14000.00
0005432528002	7741	Economy	14000.00
0005434067533	7741	Economy	14000.00
0005432069662	7741	Economy	14000.00
0005432527927	7741	Economy	14000.00
0005432527926	7741	Economy	14000.00
0005434067550	7741	Economy	14000.00
0005435212887	7741	Economy	14000.00
0005432527979	7741	Economy	14000.00
0005432527993	7741	Economy	14000.00
0005432527957	7741	Economy	14000.00
0005434067541	7741	Economy	14000.00
0005434067593	7741	Economy	14000.00
0005434067537	7741	Economy	14000.00
0005432527916	7741	Economy	14000.00
0005435212685	7741	Economy	14000.00
0005432527925	7741	Economy	14000.00
0005434067539	7741	Economy	14000.00
0005434067567	7741	Economy	14000.00
0005432528021	7741	Economy	14000.00
0005435212894	7741	Economy	14000.00
0005432528005	7741	Economy	14000.00
0005432528004	7741	Economy	14000.00
0005432528009	7741	Economy	14000.00
0005432527996	7741	Economy	14000.00
0005434067598	7741	Economy	14000.00
0005432527930	7741	Economy	14000.00
0005435630917	7741	Economy	14000.00
0005432528046	7741	Economy	14000.00
0005435212988	7741	Economy	14000.00
0005434067584	7741	Economy	14000.00
0005432527989	7741	Economy	14000.00
0005434067558	7741	Economy	14000.00
0005432069661	7741	Economy	14000.00
0005435213012	7741	Economy	14000.00
0005435212771	7741	Economy	14000.00
0005435212649	7741	Economy	14000.00
0005435213002	7741	Economy	14000.00
0005434067599	7741	Economy	14000.00
0005432528032	7741	Economy	14000.00
0005432528003	7741	Economy	14000.00
0005434067574	7741	Economy	14000.00
0005435212800	7741	Economy	14000.00
0005433656642	7741	Economy	14000.00
0005432527978	7741	Economy	14000.00
0005435212863	7741	Economy	14000.00
0005434067549	7741	Economy	14000.00
0005432527934	7741	Economy	14000.00
0005432528042	7741	Economy	14000.00
0005435725552	7741	Economy	14000.00
0005432428929	7741	Economy	14000.00
0005435212991	7741	Economy	14000.00
0005432527951	7741	Economy	14000.00
0005434067535	7741	Economy	14000.00
0005432528019	7741	Economy	14000.00
0005432527917	7741	Economy	14000.00
0005432528023	7741	Economy	14000.00
0005435212900	7741	Economy	14000.00
0005434067534	7741	Economy	14000.00
0005432527984	7741	Economy	14000.00
0005435212648	7741	Economy	14000.00
0005435212699	7741	Economy	14000.00
0005432527922	7741	Economy	14000.00
0005434067553	7741	Economy	14000.00
0005432535833	7741	Economy	14000.00
0005435212945	7741	Economy	14000.00
0005432527959	7741	Economy	14000.00
0005432527947	7741	Economy	14000.00
0005434067543	7741	Economy	14000.00
0005434067576	7741	Economy	14000.00
0005432528011	7741	Economy	14000.00
0005434067563	7741	Economy	14000.00
0005435213181	7741	Economy	14000.00
0005435613686	5308	Business	43100.00
0005435424350	5308	Business	43100.00
0005434573355	5308	Business	43100.00
0005435613678	5308	Business	43100.00
0005434344241	5308	Business	43100.00
0005435424197	5308	Business	43100.00
0005435613600	5308	Business	43100.00
0005434244803	5308	Business	43100.00
0005432133208	5308	Business	43100.00
0005435424005	5308	Business	43100.00
0005435380261	5308	Business	43100.00
0005435424178	5308	Business	43100.00
0005435424555	5308	Business	43100.00
0005435613605	5308	Business	43100.00
0005434244659	5308	Business	43100.00
0005432133217	5308	Business	43100.00
0005435613703	5308	Business	43100.00
0005432363388	5308	Business	43100.00
0005435613596	5308	Business	43100.00
0005435424588	5308	Business	43100.00
0005435613695	5308	Business	43100.00
0005434344229	5308	Business	43100.00
0005435613654	5308	Business	43100.00
0005435613634	5308	Business	43100.00
0005435613643	5308	Comfort	24400.00
0005435613608	5308	Comfort	24400.00
0005435613647	5308	Comfort	24400.00
0005435424329	5308	Comfort	24400.00
0005432133205	5308	Comfort	24400.00
0005435319513	5308	Comfort	24400.00
0005435613653	5308	Comfort	24400.00
0005435424239	5308	Comfort	24400.00
0005434573357	5308	Comfort	24400.00
0005435613656	5308	Comfort	24400.00
0005435613619	5308	Comfort	24400.00
0005435613624	5308	Comfort	24400.00
0005435424156	5308	Comfort	24400.00
0005432047548	5308	Comfort	24400.00
0005435380252	5308	Comfort	24400.00
0005435097207	5308	Comfort	24400.00
0005435424288	5308	Comfort	24400.00
0005435097199	5308	Comfort	24400.00
0005435613589	5308	Comfort	24400.00
0005432133211	5308	Comfort	24400.00
0005435424413	5308	Comfort	24400.00
0005435319519	5308	Comfort	24400.00
0005432047549	5308	Comfort	24400.00
0005435613603	5308	Comfort	24400.00
0005435424405	5308	Comfort	24400.00
0005435613598	5308	Comfort	24400.00
0005435424311	5308	Comfort	24400.00
0005435613591	5308	Comfort	24400.00
0005432133210	5308	Comfort	24400.00
0005435613636	5308	Comfort	24400.00
0005435613629	5308	Comfort	24400.00
0005435423942	5308	Comfort	24400.00
0005434344248	5308	Comfort	24400.00
0005434244839	5308	Comfort	24400.00
0005435613684	5308	Comfort	24400.00
0005435097205	5308	Comfort	24400.00
0005435424225	5308	Comfort	24400.00
0005435613689	5308	Economy	14400.00
0005435555368	5308	Economy	14400.00
0005434244732	5308	Economy	14400.00
0005434573350	5308	Economy	14400.00
0005435380238	5308	Economy	14400.00
0005435424457	5308	Economy	14400.00
0005435617170	5308	Economy	14400.00
0005434573352	5308	Economy	14400.00
0005434244669	5308	Economy	14400.00
0005435424280	5308	Economy	14400.00
0005435613706	5308	Economy	14400.00
0005435613622	5308	Economy	14400.00
0005435424108	5308	Economy	14400.00
0005435613592	5308	Economy	14400.00
0005435613668	5308	Economy	14400.00
0005435613687	5308	Economy	14400.00
0005435613607	5308	Economy	14400.00
0005435380262	5308	Economy	14400.00
0005434573358	5308	Economy	14400.00
0005435613665	5308	Economy	14400.00
0005435613594	5308	Economy	14400.00
0005435613692	5308	Economy	14400.00
0005435613588	5308	Economy	14400.00
0005435617169	5308	Economy	14400.00
0005435424538	5308	Economy	14400.00
0005435613696	5308	Economy	14400.00
0005434344219	5308	Economy	14400.00
0005435380250	5308	Economy	14400.00
0005435613613	5308	Economy	14400.00
0005435613639	5308	Economy	14400.00
0005435613697	5308	Economy	14400.00
0005435613669	5308	Economy	14400.00
0005433719091	5308	Economy	14400.00
0005434656539	5308	Economy	14400.00
0005434573347	5308	Economy	14400.00
0005434344239	5308	Economy	14400.00
0005434344222	5308	Economy	14400.00
0005434573360	5308	Economy	14400.00
0005435613610	5308	Economy	14400.00
0005435613638	5308	Economy	14400.00
0005435613642	5308	Economy	14400.00
0005434573351	5308	Economy	14400.00
0005435613628	5308	Economy	14400.00
0005434344217	5308	Economy	14400.00
0005435613620	5308	Economy	14400.00
0005435424389	5308	Economy	14400.00
0005435424244	5308	Economy	14400.00
0005434344246	5308	Economy	14400.00
0005434344226	5308	Economy	14400.00
0005435613664	5308	Economy	14400.00
0005434244766	5308	Economy	14400.00
0005434344242	5308	Economy	14400.00
0005435613590	5308	Economy	14400.00
0005435613612	5308	Economy	14400.00
0005434573359	5308	Economy	14400.00
0005435424165	5308	Economy	14400.00
0005432133207	5308	Economy	15800.00
0005434573356	5308	Economy	14400.00
0005435613626	5308	Economy	15800.00
0005435424379	5308	Economy	14400.00
0005435424063	5308	Economy	14400.00
0005435555369	5308	Economy	14400.00
0005434344221	5308	Economy	15800.00
0005435613693	5308	Economy	15800.00
0005434244657	5308	Economy	14400.00
0005435424323	5308	Economy	15800.00
0005435097203	5308	Economy	14400.00
0005435319526	5308	Economy	14400.00
0005432133218	5308	Economy	14400.00
0005435424287	5308	Economy	14400.00
0005435613606	5308	Economy	14400.00
0005434244799	5308	Economy	14400.00
0005435424364	5308	Economy	14400.00
0005435424177	5308	Economy	14400.00
0005432047551	5308	Economy	14400.00
0005435613640	5308	Economy	14400.00
0005435613602	5308	Economy	14400.00
0005435302174	5308	Economy	14400.00
0005435613641	5308	Economy	14400.00
0005435490229	5308	Economy	14400.00
0005432133215	5308	Economy	14400.00
0005435613651	5308	Economy	14400.00
0005435613690	5308	Economy	14400.00
0005435613609	5308	Economy	14400.00
0005435424406	5308	Economy	14400.00
0005435613631	5308	Economy	14400.00
0005432363387	5308	Economy	14400.00
0005435613655	5308	Economy	14400.00
0005435613688	5308	Economy	14400.00
0005435613698	5308	Economy	14400.00
0005435613618	5308	Economy	14400.00
0005435613623	5308	Economy	14400.00
0005435613616	5308	Economy	14400.00
0005435613615	5308	Economy	14400.00
0005435302138	5308	Economy	14400.00
0005435424359	5308	Economy	14400.00
0005435613621	5308	Economy	14400.00
0005435424164	5308	Economy	14400.00
0005434344227	5308	Economy	14400.00
0005435424358	5308	Economy	14400.00
0005435424073	5308	Economy	14400.00
0005435613635	5308	Economy	14400.00
0005435613682	5308	Economy	14400.00
0005435613658	5308	Economy	14400.00
0005434344233	5308	Economy	14400.00
0005435424186	5308	Economy	14400.00
0005435613691	5308	Economy	14400.00
0005432133216	5308	Economy	14400.00
0005434344247	5308	Economy	14400.00
0005435613585	5308	Economy	14400.00
0005435613681	5308	Economy	14400.00
0005435424337	5308	Economy	14400.00
0005434573349	5308	Economy	14400.00
0005435424356	5308	Economy	14400.00
0005435424513	5308	Economy	14400.00
0005434244765	5308	Economy	14400.00
0005434344220	5308	Economy	14400.00
0005435424154	5308	Economy	14400.00
0005434344230	5308	Economy	14400.00
0005435097201	5308	Economy	14400.00
0005435613662	5308	Economy	14400.00
0005434344231	5308	Economy	14400.00
0005435613646	5308	Economy	14400.00
0005434344224	5308	Economy	14400.00
0005435424306	5308	Economy	14400.00
0005435613627	5308	Economy	14400.00
0005434344245	5308	Economy	14400.00
0005432133204	5308	Economy	14400.00
0005434344244	5308	Economy	14400.00
0005435613685	5308	Economy	14400.00
0005435613663	5308	Economy	14400.00
0005435097200	5308	Economy	14400.00
0005432840991	5308	Economy	14400.00
0005434344237	5308	Economy	14400.00
0005435613673	5308	Economy	14400.00
0005435424537	5308	Economy	14400.00
0005435613694	5308	Economy	14400.00
0005435424240	5308	Economy	14400.00
0005435613648	5308	Economy	14400.00
0005434344214	5308	Economy	14400.00
0005435613630	5308	Economy	14400.00
0005435424515	5308	Economy	14400.00
0005434656538	5308	Economy	14400.00
0005435424357	5308	Economy	14400.00
0005434573354	5308	Economy	14400.00
0005434244800	5308	Economy	14400.00
0005435613660	5308	Economy	14400.00
0005435613657	5308	Economy	14400.00
0005435424062	5308	Economy	14400.00
0005435613702	5308	Economy	14400.00
0005435380253	5308	Economy	14400.00
0005435424219	5308	Economy	14400.00
0005435613674	5308	Economy	14400.00
0005434344240	5308	Economy	14400.00
0005435613675	5308	Economy	14400.00
0005434344236	5308	Economy	14400.00
0005435424220	5308	Economy	14400.00
0005434573353	5308	Economy	14400.00
0005435424344	5308	Economy	14400.00
0005435613676	5308	Economy	15800.00
0005435424136	5308	Economy	15800.00
0005435613595	5308	Economy	15800.00
0005432047550	5308	Economy	15800.00
0005434344232	5308	Economy	15800.00
0005435613599	5308	Economy	15800.00
0005435613680	5308	Economy	14400.00
0005435302176	5308	Economy	14400.00
0005435424493	5308	Economy	14400.00
0005434344212	5308	Economy	14400.00
0005435424187	5308	Economy	14400.00
0005432840996	5308	Economy	14400.00
0005435613666	5308	Economy	14400.00
0005435613672	5308	Economy	14400.00
0005434344235	5308	Economy	14400.00
0005435424270	5308	Economy	14400.00
0005435424116	5308	Economy	14400.00
0005432133206	5308	Economy	14400.00
0005435613645	5308	Economy	14400.00
0005435424448	5308	Economy	14400.00
0005435490227	5308	Economy	14400.00
0005435424298	5308	Economy	14400.00
0005432363379	5308	Economy	14400.00
0005435424291	5308	Economy	14400.00
0005435613601	5308	Economy	14400.00
0005434344215	5308	Economy	14400.00
0005435613659	5308	Economy	14400.00
0005435304997	5308	Economy	14400.00
0005432133212	5308	Economy	14400.00
0005435613699	5308	Economy	14400.00
0005435424310	5308	Economy	14400.00
0005435097202	5308	Economy	14400.00
0005435613611	5308	Economy	14400.00
0005433719107	5308	Economy	14400.00
0005435097204	5308	Economy	14400.00
0005435613683	5308	Economy	14400.00
0005434244733	5308	Economy	14400.00
0005435490228	5308	Economy	14400.00
0005435613593	5308	Economy	14400.00
0005434244769	5308	Economy	14400.00
0005435613652	5308	Economy	14400.00
0005434244884	5308	Economy	14400.00
0005434573348	5308	Economy	14400.00
0005435613705	5308	Economy	14400.00
0005435613604	5308	Economy	14400.00
0005435424414	5308	Economy	14400.00
0005435613597	5308	Economy	14400.00
0005435424527	5308	Economy	14400.00
0005434244652	5308	Economy	14400.00
0005435613701	5308	Economy	14400.00
0005435613633	5308	Economy	14400.00
0005435424117	5308	Economy	14400.00
0005435613632	5308	Economy	14400.00
0005435097206	5308	Economy	14400.00
0005435613587	5308	Economy	14400.00
0005432133209	5308	Economy	14400.00
0005435380269	5308	Economy	14400.00
0005435424284	5308	Economy	14400.00
0005434344225	5308	Economy	14400.00
0005434244658	5308	Economy	14400.00
0005435424107	5308	Economy	14400.00
0005435424118	5308	Economy	14400.00
0005432133214	5308	Economy	14400.00
0005434344213	5308	Economy	14400.00
0005432363386	5308	Economy	14400.00
0005435613667	5308	Economy	14400.00
0005435613625	5308	Economy	14400.00
0005434344223	5308	Economy	14400.00
0005434244755	5308	Economy	14400.00
0005435302146	5308	Economy	14400.00
0005435424221	5308	Economy	14400.00
0005435613614	5308	Economy	14400.00
0005435424140	5308	Economy	14400.00
0005435613670	5308	Economy	14400.00
0005434344234	5308	Economy	14400.00
0005435613679	5308	Economy	14400.00
0005435424514	5308	Economy	14400.00
0005435613617	5308	Economy	14400.00
0005435613637	5308	Economy	14400.00
0005435613644	5308	Economy	14400.00
0005434344216	5308	Economy	14400.00
0005435613677	5308	Economy	14400.00
0005434344211	5308	Economy	14400.00
0005435302175	5308	Economy	14400.00
0005434244678	5308	Economy	14400.00
0005435424338	5308	Economy	14400.00
0005432133213	5308	Economy	14400.00
0005435613704	5308	Economy	14400.00
0005435613661	5308	Economy	14400.00
0005435613586	5308	Economy	14400.00
0005435613671	5308	Economy	14400.00
0005434344218	5308	Economy	14400.00
0005435613649	5308	Economy	14400.00
0005435424033	5308	Economy	14400.00
0005435424326	5308	Economy	14400.00
0005433719090	5308	Economy	14400.00
0005435424155	5308	Economy	14400.00
0005435613700	5308	Economy	14400.00
0005435613650	5308	Economy	14400.00
0005434344228	5308	Economy	14400.00
0005434344243	5308	Economy	14400.00
0005434344238	5308	Economy	14400.00
0005434343847	10874	Business	43100.00
0005435612258	10874	Business	43100.00
0005435555351	10874	Business	43100.00
0005435612284	10874	Business	43100.00
0005434343907	10874	Business	43100.00
0005435490197	10874	Business	43100.00
0005434573248	10874	Business	43100.00
0005435424820	10874	Business	43100.00
0005435612427	10874	Business	43100.00
0005435612759	10874	Business	43100.00
0005434343790	10874	Business	43100.00
0005435612475	10874	Business	43100.00
0005434244987	10874	Business	43100.00
0005435612773	10874	Business	43100.00
0005435424841	10874	Business	43100.00
0005435424783	10874	Business	43100.00
0005435490198	10874	Business	43100.00
0005434343854	10874	Business	43100.00
0005433719140	10874	Business	43100.00
0005435424845	10874	Business	43100.00
0005434343900	10874	Business	43100.00
0005432841013	10874	Business	43100.00
0005435612613	10874	Comfort	24400.00
0005435612473	10874	Comfort	24400.00
0005435319569	10874	Comfort	24400.00
0005435424778	10874	Comfort	24400.00
0005434573215	10874	Comfort	24400.00
0005435612742	10874	Comfort	24400.00
0005435424784	10874	Comfort	24400.00
0005435490185	10874	Comfort	24400.00
0005434244979	10874	Comfort	24400.00
0005435424808	10874	Comfort	24400.00
0005434244981	10874	Comfort	24400.00
0005435612526	10874	Comfort	24400.00
0005434343762	10874	Comfort	24400.00
0005435424816	10874	Comfort	24400.00
0005433719142	10874	Comfort	24400.00
0005432165041	10874	Comfort	24400.00
0005435424831	10874	Comfort	24400.00
0005434343903	10874	Comfort	24400.00
0005435612481	10874	Comfort	24400.00
0005435491428	10874	Comfort	24400.00
0005435424818	10874	Comfort	24400.00
0005434343732	10874	Comfort	24400.00
0005434244988	10874	Comfort	24400.00
0005434244983	10874	Comfort	24400.00
0005435612540	10874	Comfort	24400.00
0005435424828	10874	Comfort	24400.00
0005435097074	10874	Comfort	24400.00
0005435612276	10874	Comfort	24400.00
0005435319570	10874	Comfort	24400.00
0005435305015	10874	Comfort	24400.00
0005435612556	10874	Comfort	24400.00
0005435612659	10874	Comfort	24400.00
0005435424806	10874	Comfort	24400.00
0005435424836	10874	Comfort	24400.00
0005434344009	10874	Comfort	24400.00
0005434244973	10874	Comfort	24400.00
0005434343779	10874	Economy	14400.00
0005432165035	10874	Economy	14400.00
0005434244975	10874	Economy	14400.00
0005434343763	10874	Economy	14400.00
0005432166900	10874	Economy	14400.00
0005432166901	10874	Economy	14400.00
0005435612658	10874	Economy	14400.00
0005434343805	10874	Economy	14400.00
0005434343908	10874	Economy	14400.00
0005435611911	10874	Economy	14400.00
0005435612152	10874	Economy	14400.00
0005435612006	10874	Economy	14400.00
0005434573187	10874	Economy	14400.00
0005435612645	10874	Economy	14400.00
0005435304156	10874	Economy	14400.00
0005434656556	10874	Economy	14400.00
0005435424787	10874	Economy	14400.00
0005434244989	10874	Economy	14400.00
0005435612007	10874	Economy	14400.00
0005434573258	10874	Economy	14400.00
0005435424810	10874	Economy	14400.00
0005435424812	10874	Economy	14400.00
0005435612486	10874	Economy	14400.00
0005435319571	10874	Economy	14400.00
0005435612259	10874	Economy	14400.00
0005435612771	10874	Economy	14400.00
0005435424825	10874	Economy	14400.00
0005435424793	10874	Economy	14400.00
0005435612607	10874	Economy	14400.00
0005434244966	10874	Economy	14400.00
0005435424795	10874	Economy	14400.00
0005435424804	10874	Economy	14400.00
0005435424789	10874	Economy	14400.00
0005435612677	10874	Economy	14400.00
0005434244971	10874	Economy	14400.00
0005434656555	10874	Economy	14400.00
0005435097073	10874	Economy	14400.00
0005434244976	10874	Economy	14400.00
0005435612425	10874	Economy	14400.00
0005435424786	10874	Economy	14400.00
0005435612787	10874	Economy	14400.00
0005435097094	10874	Economy	14400.00
0005435424829	10874	Economy	14400.00
0005432165036	10874	Economy	14400.00
0005435612123	10874	Economy	14400.00
0005435612426	10874	Economy	14400.00
0005435612735	10874	Economy	14400.00
0005435612710	10874	Economy	14400.00
0005435612744	10874	Economy	14400.00
0005435380293	10874	Economy	14400.00
0005434244969	10874	Economy	14400.00
0005432363414	10874	Economy	14400.00
0005434343899	10874	Economy	14400.00
0005435424838	10874	Economy	14400.00
0005435612676	10874	Economy	14400.00
0005435304157	10874	Economy	14400.00
0005435424799	10874	Economy	14400.00
0005435424782	10874	Economy	14400.00
0005432165039	10874	Economy	14400.00
0005435424802	10874	Economy	15800.00
0005434573253	10874	Economy	15800.00
0005435424780	10874	Economy	15800.00
0005434244972	10874	Economy	14400.00
0005435612541	10874	Economy	15800.00
0005435612609	10874	Economy	15800.00
0005435424805	10874	Economy	14400.00
0005435424835	10874	Economy	14400.00
0005435612570	10874	Economy	14400.00
0005435612555	10874	Economy	14400.00
0005434244994	10874	Economy	14400.00
0005434573213	10874	Economy	14400.00
0005435097113	10874	Economy	14400.00
0005435424832	10874	Economy	14400.00
0005435424811	10874	Economy	14400.00
0005435424803	10874	Economy	14400.00
0005435612754	10874	Economy	14400.00
0005434573214	10874	Economy	14400.00
0005432363416	10874	Economy	14400.00
0005435612723	10874	Economy	14400.00
0005434656557	10874	Economy	14400.00
0005435612661	10874	Economy	14400.00
0005434343853	10874	Economy	14400.00
0005435490191	10874	Economy	14400.00
0005434343924	10874	Economy	14400.00
0005435424821	10874	Economy	14400.00
0005435424788	10874	Economy	14400.00
0005435424781	10874	Economy	14400.00
0005434343764	10874	Economy	14400.00
0005435424794	10874	Economy	14400.00
0005435612268	10874	Economy	14400.00
0005434343827	10874	Economy	14400.00
0005435424790	10874	Economy	14400.00
0005434244986	10874	Economy	14400.00
0005435612803	10874	Economy	14400.00
0005434244985	10874	Economy	14400.00
0005435612508	10874	Economy	14400.00
0005435424814	10874	Economy	14400.00
0005435612750	10874	Economy	14400.00
0005434343823	10874	Economy	14400.00
0005432165034	10874	Economy	14400.00
0005435097107	10874	Economy	14400.00
0005435097096	10874	Economy	14400.00
0005434343806	10874	Economy	14400.00
0005435424827	10874	Economy	14400.00
0005435612612	10874	Economy	14400.00
0005434244980	10874	Economy	14400.00
0005435424824	10874	Economy	14400.00
0005435319572	10874	Economy	14400.00
0005432165040	10874	Economy	14400.00
0005434244984	10874	Economy	14400.00
0005435424785	10874	Economy	14400.00
0005435612779	10874	Economy	14400.00
0005435424800	10874	Economy	14400.00
0005432363417	10874	Economy	14400.00
0005435424801	10874	Economy	14400.00
0005435424798	10874	Economy	14400.00
0005434343880	10874	Economy	14400.00
0005435424819	10874	Economy	14400.00
0005435612757	10874	Economy	14400.00
0005434343938	10874	Economy	14400.00
0005435612324	10874	Economy	14400.00
0005434244974	10874	Economy	14400.00
0005434573254	10874	Economy	14400.00
0005434343950	10874	Economy	14400.00
0005435612542	10874	Economy	14400.00
0005435424813	10874	Economy	14400.00
0005435305013	10874	Economy	14400.00
0005435380288	10874	Economy	14400.00
0005435612005	10874	Economy	14400.00
0005432166902	10874	Economy	14400.00
0005435612706	10874	Economy	14400.00
0005434343879	10874	Economy	14400.00
0005435424834	10874	Economy	14400.00
0005435424837	10874	Economy	14400.00
0005435612151	10874	Economy	14400.00
0005435424796	10874	Economy	14400.00
0005434343826	10874	Economy	14400.00
0005434244968	10874	Economy	14400.00
0005435424842	10874	Economy	14400.00
0005432841012	10874	Economy	14400.00
0005435424776	10874	Economy	14400.00
0005435319574	10874	Economy	14400.00
0005435612636	10874	Economy	14400.00
0005435612656	10874	Economy	14400.00
0005434343841	10874	Economy	14400.00
0005435380292	10874	Economy	14400.00
0005435424779	10874	Economy	14400.00
0005434573134	10874	Economy	14400.00
0005435380290	10874	Economy	14400.00
0005435612709	10874	Economy	14400.00
0005435555352	10874	Economy	14400.00
0005434343833	10874	Economy	14400.00
0005435097093	10874	Economy	14400.00
0005435319575	10874	Economy	14400.00
0005435612729	10874	Economy	14400.00
0005435424791	10874	Economy	14400.00
0005435612504	10874	Economy	14400.00
0005434244982	10874	Economy	14400.00
0005435612799	10874	Economy	14400.00
0005435612571	10874	Economy	14400.00
0005435612663	10874	Economy	14400.00
0005435612122	10874	Economy	15800.00
0005435612796	10874	Economy	14400.00
0005435612372	10874	Economy	15800.00
0005435612548	10874	Economy	15800.00
0005435380291	10874	Economy	15800.00
0005433719141	10874	Economy	15800.00
0005432165037	10874	Economy	15800.00
0005435424843	10874	Economy	14400.00
0005434343834	10874	Economy	14400.00
0005434343832	10874	Economy	14400.00
0005435612374	10874	Economy	14400.00
0005435424809	10874	Economy	14400.00
0005435612323	10874	Economy	14400.00
0005435612573	10874	Economy	14400.00
0005434244967	10874	Economy	14400.00
0005435612717	10874	Economy	14400.00
0005435612718	10874	Economy	14400.00
0005435612446	10874	Economy	14400.00
0005435612537	10874	Economy	14400.00
0005435555353	10874	Economy	14400.00
0005434343828	10874	Economy	14400.00
0005432166903	10874	Economy	14400.00
0005435612660	10874	Economy	14400.00
0005434343774	10874	Economy	14400.00
0005435612348	10874	Economy	14400.00
0005435612574	10874	Economy	14400.00
0005435612520	10874	Economy	14400.00
0005435380289	10874	Economy	14400.00
0005435612737	10874	Economy	14400.00
0005434244990	10874	Economy	14400.00
0005434244991	10874	Economy	14400.00
0005435424792	10874	Economy	14400.00
0005435612736	10874	Economy	14400.00
0005435424830	10874	Economy	14400.00
0005435612342	10874	Economy	14400.00
0005435424777	10874	Economy	14400.00
0005435097115	10874	Economy	14400.00
0005435612363	10874	Economy	14400.00
0005435491410	10874	Economy	14400.00
0005435424844	10874	Economy	14400.00
0005435424826	10874	Economy	14400.00
0005435424797	10874	Economy	14400.00
0005434343901	10874	Economy	14400.00
0005435612662	10874	Economy	14400.00
0005435612780	10874	Economy	14400.00
0005435612764	10874	Economy	14400.00
0005435319573	10874	Economy	14400.00
0005435305014	10874	Economy	14400.00
0005435424823	10874	Economy	14400.00
0005435612380	10874	Economy	14400.00
0005435612788	10874	Economy	14400.00
0005435319568	10874	Economy	14400.00
0005434343777	10874	Economy	14400.00
0005434244993	10874	Economy	14400.00
0005434573140	10874	Economy	14400.00
0005435612774	10874	Economy	14400.00
0005435097105	10874	Economy	14400.00
0005435424822	10874	Economy	14400.00
0005434573266	10874	Economy	14400.00
0005435612547	10874	Economy	14400.00
0005434244965	10874	Economy	14400.00
0005434244977	10874	Economy	14400.00
0005435424839	10874	Economy	14400.00
0005435424807	10874	Economy	14400.00
0005435612447	10874	Economy	14400.00
0005434244992	10874	Economy	14400.00
0005435612539	10874	Economy	14400.00
0005435612758	10874	Economy	14400.00
0005435612741	10874	Economy	14400.00
0005435612783	10874	Economy	14400.00
0005435097114	10874	Economy	14400.00
0005434343940	10874	Economy	14400.00
0005435612519	10874	Economy	14400.00
0005435612610	10874	Economy	14400.00
0005435612167	10874	Economy	14400.00
0005435097106	10874	Economy	14400.00
0005435612698	10874	Economy	14400.00
0005435612269	10874	Economy	14400.00
0005432165038	10874	Economy	14400.00
0005435424815	10874	Economy	14400.00
0005435612743	10874	Economy	14400.00
0005434244978	10874	Economy	14400.00
0005435612772	10874	Economy	14400.00
0005435612474	10874	Economy	14400.00
0005435097112	10874	Economy	14400.00
0005434343946	10874	Economy	14400.00
0005435424833	10874	Economy	14400.00
0005434343804	10874	Economy	14400.00
0005435305012	10874	Economy	14400.00
0005435612685	10874	Economy	14400.00
0005434244970	10874	Economy	14400.00
0005435612697	10874	Economy	14400.00
0005435424817	10874	Economy	14400.00
0005435612538	10874	Economy	14400.00
0005435612277	10874	Economy	14400.00
0005432363415	10874	Economy	14400.00
0005435304155	10874	Economy	14400.00
0005435097092	10874	Economy	14400.00
0005435424840	10874	Economy	14400.00
0005435319576	10874	Economy	14400.00
0005433633831	3325	Business	18800.00
0005432459507	3325	Business	18800.00
0005433507185	3325	Business	18800.00
0005433633815	3325	Business	18800.00
0005433507183	3325	Business	18800.00
0005433805377	3325	Business	18800.00
0005432459557	3325	Business	18800.00
0005433633820	3325	Business	18800.00
0005432459385	3325	Business	18800.00
0005432459390	3325	Business	18800.00
0005432459439	3325	Business	18800.00
0005432459421	3325	Business	18800.00
0005433805362	3325	Business	18800.00
0005432181708	3325	Business	18800.00
0005433805385	3325	Business	18800.00
0005433805397	3325	Business	18800.00
0005433805364	3325	Business	18800.00
0005433633826	3325	Business	18800.00
0005433805360	3325	Business	18800.00
0005433805357	3325	Business	18800.00
0005432181725	3325	Business	18800.00
0005433633833	3325	Business	18800.00
0005433805381	3325	Business	18800.00
0005433507186	3325	Economy	6900.00
0005433633827	3325	Business	18800.00
0005433805369	3325	Economy	6900.00
0005433633816	3325	Economy	6900.00
0005432459366	3325	Economy	6900.00
0005432459365	3325	Economy	6900.00
0005432181728	3325	Economy	6900.00
0005432459487	3325	Economy	6300.00
0005433633832	3325	Economy	6300.00
0005432459584	3325	Economy	6300.00
0005432459445	3325	Economy	6300.00
0005432181710	3325	Economy	6300.00
0005433507177	3325	Economy	6300.00
0005432181723	3325	Economy	6300.00
0005433805378	3325	Economy	6300.00
0005433633807	3325	Economy	6300.00
0005432459257	3325	Economy	6300.00
0005432459375	3325	Economy	6300.00
0005432459355	3325	Economy	6300.00
0005432459258	3325	Economy	6300.00
0005433633823	3325	Economy	6300.00
0005433805383	3325	Economy	6300.00
0005433507178	3325	Economy	6300.00
0005433805363	3325	Economy	6300.00
0005432459427	3325	Economy	6300.00
0005433633812	3325	Economy	6300.00
0005433805387	3325	Economy	6300.00
0005432181727	3325	Economy	6300.00
0005432459583	3325	Economy	6300.00
0005433805389	3325	Economy	6300.00
0005432459560	3325	Economy	6300.00
0005433805398	3325	Economy	6300.00
0005432181711	3325	Economy	6300.00
0005433507189	3325	Economy	6300.00
0005432181715	3325	Economy	6300.00
0005432181718	3325	Economy	6300.00
0005433633824	3325	Economy	6300.00
0005432181724	3325	Economy	6300.00
0005432459446	3325	Economy	6300.00
0005432459585	3325	Economy	6300.00
0005432181716	3325	Economy	6300.00
0005433633808	3325	Economy	6300.00
0005433805361	3325	Economy	6300.00
0005432459311	3325	Economy	6300.00
0005432459397	3325	Economy	6300.00
0005433805366	3325	Economy	6300.00
0005432459310	3325	Economy	6300.00
0005432181722	3325	Economy	6300.00
0005432459087	3325	Economy	6300.00
0005433805391	3325	Economy	6300.00
0005433805368	3325	Economy	6300.00
0005433633838	3325	Economy	6300.00
0005433805359	3325	Economy	6300.00
0005432459388	3325	Economy	6300.00
0005433633836	3325	Economy	6300.00
0005433633821	3325	Economy	6300.00
0005433507180	3325	Economy	6300.00
0005432181717	3325	Economy	6300.00
0005432181719	3325	Economy	6300.00
0005432181713	3325	Economy	6300.00
0005433805394	3325	Economy	6300.00
0005433633818	3325	Economy	6300.00
0005433805367	3325	Economy	6300.00
0005432459532	3325	Economy	6300.00
0005433805380	3325	Economy	6900.00
0005433805384	3325	Economy	6900.00
0005432181706	3325	Economy	6900.00
0005433507187	3325	Economy	6900.00
0005433633828	3325	Economy	6900.00
0005433507181	3325	Economy	6300.00
0005432181707	3325	Economy	6300.00
0005432181720	3325	Economy	6300.00
0005432459238	3325	Economy	6300.00
0005432181721	3325	Economy	6900.00
0005433805388	3325	Economy	6300.00
0005432459444	3325	Economy	6300.00
0005433633835	3325	Economy	6300.00
0005433805358	3325	Economy	6300.00
0005433633817	3325	Economy	6300.00
0005433633839	3325	Economy	6300.00
0005433805370	3325	Economy	6300.00
0005433633834	3325	Economy	6300.00
0005433633811	3325	Economy	6300.00
0005432181709	3325	Economy	6300.00
0005432459559	3325	Economy	6300.00
0005433507190	3325	Economy	6300.00
0005432459389	3325	Economy	6300.00
0005432459488	3325	Economy	6300.00
0005433633830	3325	Economy	6300.00
0005432459386	3325	Economy	6300.00
0005432181726	3325	Economy	6300.00
0005433805371	3325	Economy	6300.00
0005433633825	3325	Economy	6300.00
0005433805392	3325	Economy	6300.00
0005432459426	3325	Economy	6300.00
0005433805373	3325	Economy	6300.00
0005432181729	3325	Economy	6300.00
0005433805393	3325	Economy	6300.00
0005432459561	3325	Economy	6300.00
0005432459134	3325	Economy	6300.00
0005432459489	3325	Economy	6300.00
0005433633809	3325	Economy	6300.00
0005433633819	3325	Economy	6300.00
0005433805396	3325	Economy	6300.00
0005432459354	3325	Economy	6300.00
0005433633810	3325	Economy	6300.00
0005433805390	3325	Economy	6300.00
0005433633829	3325	Economy	6300.00
0005433507188	3325	Economy	6300.00
0005433805375	3325	Economy	6300.00
0005432459305	3325	Economy	6300.00
0005433507179	3325	Economy	6300.00
0005433805399	3325	Economy	6300.00
0005433507184	3325	Economy	6300.00
0005433805382	3325	Economy	6300.00
0005433633813	3325	Economy	6300.00
0005432459312	3325	Economy	6300.00
0005433805365	3325	Economy	6300.00
0005433805386	3325	Economy	6300.00
0005433633822	3325	Economy	6300.00
0005433507182	3325	Economy	6300.00
0005432459384	3325	Economy	6300.00
0005432459357	3325	Economy	6300.00
0005432181712	3325	Economy	6300.00
0005433805372	3325	Economy	6300.00
0005433633814	3325	Economy	6300.00
0005433805374	3325	Economy	6300.00
0005433805379	3325	Economy	6300.00
0005432459268	3325	Economy	6300.00
0005433633840	3325	Economy	6300.00
0005432459453	3325	Economy	6300.00
0005433805395	3325	Economy	6300.00
0005433805376	3325	Economy	6300.00
0005433633837	3325	Economy	6300.00
0005432181714	3325	Economy	6300.00
0005432459356	3325	Economy	6300.00
0005435884729	3324	Business	18800.00
0005435884896	3324	Business	18800.00
0005435884865	3324	Business	18800.00
0005435884837	3324	Business	18800.00
0005435884525	3324	Business	18800.00
0005435884796	3324	Business	18800.00
0005435884844	3324	Business	18800.00
0005435884935	3324	Business	18800.00
0005435884946	3324	Economy	6900.00
0005435884883	3324	Economy	6300.00
0005435884762	3324	Economy	6300.00
0005435885030	3324	Economy	6300.00
0005435884761	3324	Economy	6300.00
0005435884866	3324	Economy	6300.00
0005435884794	3324	Economy	6300.00
0005435884793	3324	Economy	6300.00
0005435885018	3324	Economy	6300.00
0005435884730	3324	Economy	6300.00
0005435884949	3324	Economy	6300.00
0005435884850	3324	Economy	6300.00
0005435884845	3324	Economy	6300.00
0005435884608	3324	Economy	6300.00
0005435884985	3324	Economy	6300.00
0005435884947	3324	Economy	6300.00
0005435885007	3324	Economy	6300.00
0005435884779	3324	Economy	6300.00
0005435885037	3324	Economy	6300.00
0005435884969	3324	Economy	6900.00
0005435884753	3324	Economy	6300.00
0005435884846	3324	Economy	6300.00
0005435884864	3324	Economy	6900.00
0005435884840	3324	Economy	6300.00
0005435884987	3324	Economy	6300.00
0005435884683	3324	Economy	6300.00
0005435884868	3324	Economy	6300.00
0005435884945	3324	Economy	6300.00
0005435884986	3324	Economy	6300.00
0005435884661	3324	Economy	6300.00
0005435884830	3324	Economy	6300.00
0005435884760	3324	Economy	6300.00
0005435885019	3324	Economy	6300.00
0005435884801	3324	Economy	6300.00
0005435884876	3324	Economy	6300.00
0005435884609	3324	Economy	6300.00
0005435884839	3324	Economy	6300.00
0005435884599	3324	Economy	6300.00
0005435885263	8236	Business	18800.00
0005432459890	8236	Business	18800.00
0005434312321	8236	Business	18800.00
0005435885262	8236	Business	18800.00
0005433507053	8236	Business	18800.00
0005432459871	8236	Business	18800.00
0005432459915	8236	Business	18800.00
0005433506940	8236	Business	18800.00
0005432459906	8236	Business	18800.00
0005432459898	8236	Business	18800.00
0005432459865	8236	Business	18800.00
0005432042719	8236	Business	18800.00
0005435885243	8236	Business	18800.00
0005432042722	8236	Business	18800.00
0005435885244	8236	Business	18800.00
0005432459886	8236	Business	18800.00
0005433507026	8236	Business	18800.00
0005433507003	8236	Business	18800.00
0005432459888	8236	Business	18800.00
0005433507054	8236	Business	18800.00
0005432459866	8236	Business	18800.00
0005435885252	8236	Business	18800.00
0005432042716	8236	Business	18800.00
0005432459887	8236	Business	18800.00
0005433507072	8236	Economy	6900.00
0005435885266	8236	Economy	6900.00
0005432459909	8236	Economy	6900.00
0005432459901	8236	Economy	6900.00
0005433507071	8236	Economy	6900.00
0005432459881	8236	Economy	6300.00
0005432459895	8236	Economy	6300.00
0005435885267	8236	Economy	6300.00
0005433507042	8236	Economy	6300.00
0005435885270	8236	Economy	6300.00
0005432459878	8236	Economy	6300.00
0005432459874	8236	Economy	6300.00
0005432459883	8236	Economy	6300.00
0005432042715	8236	Economy	6300.00
0005433507004	8236	Economy	6300.00
0005432459893	8236	Economy	6300.00
0005432042720	8236	Economy	6300.00
0005432459896	8236	Economy	6300.00
0005432042710	8236	Economy	6300.00
0005435885259	8236	Economy	6300.00
0005435885269	8236	Economy	6300.00
0005435885275	8236	Economy	6300.00
0005432459880	8236	Economy	6300.00
0005432042714	8236	Economy	6300.00
0005434326270	8236	Economy	6300.00
0005435885242	8236	Economy	6300.00
0005433506948	8236	Economy	6300.00
0005435885248	8236	Economy	6300.00
0005432042721	8236	Economy	6300.00
0005432459885	8236	Economy	6300.00
0005435885274	8236	Economy	6300.00
0005432459894	8236	Economy	6300.00
0005435885246	8236	Economy	6300.00
0005435885276	8236	Economy	6300.00
0005432042717	8236	Economy	6300.00
0005432459897	8236	Economy	6300.00
0005435885272	8236	Economy	6300.00
0005433507025	8236	Economy	6300.00
0005435885253	8236	Economy	6300.00
0005432459867	8236	Economy	6300.00
0005432459869	8236	Economy	6300.00
0005435885256	8236	Economy	6300.00
0005433507040	8236	Economy	6300.00
0005434312320	8236	Economy	6300.00
0005432459916	8236	Economy	6300.00
0005432459908	8236	Economy	6300.00
0005432459913	8236	Economy	6300.00
0005435885249	8236	Economy	6900.00
0005435885261	8236	Economy	6900.00
0005432459891	8236	Economy	6900.00
0005432459873	8236	Economy	6900.00
0005432459882	8236	Economy	6300.00
0005435885265	8236	Economy	6900.00
0005433506946	8236	Economy	6300.00
0005432459917	8236	Economy	6300.00
0005432459876	8236	Economy	6300.00
0005433507015	8236	Economy	6900.00
0005433507002	8236	Economy	6300.00
0005432459899	8236	Economy	6300.00
0005432459902	8236	Economy	6300.00
0005435885257	8236	Economy	6300.00
0005432042713	8236	Economy	6300.00
0005432459910	8236	Economy	6300.00
0005432042712	8236	Economy	6300.00
0005435885250	8236	Economy	6300.00
0005432459892	8236	Economy	6300.00
0005432459907	8236	Economy	6300.00
0005435885245	8236	Economy	6300.00
0005432459864	8236	Economy	6300.00
0005435885277	8236	Economy	6300.00
0005434326271	8236	Economy	6300.00
0005432459879	8236	Economy	6300.00
0005432459900	8236	Economy	6300.00
0005435885255	8236	Economy	6300.00
0005432042718	8236	Economy	6300.00
0005433507058	8236	Economy	6300.00
0005435885251	8236	Economy	6300.00
0005433507016	8236	Economy	6300.00
0005432459872	8236	Economy	6300.00
0005432459868	8236	Economy	6300.00
0005432459884	8236	Economy	6300.00
0005432459875	8236	Economy	6300.00
0005435885264	8236	Economy	6300.00
0005432459889	8236	Economy	6300.00
0005435885271	8236	Economy	6300.00
0005435885273	8236	Economy	6300.00
0005435885254	8236	Economy	6300.00
0005435885260	8236	Economy	6300.00
0005433506968	8236	Economy	6300.00
0005433506941	8236	Economy	6300.00
0005433506945	8236	Economy	6300.00
0005432459903	8236	Economy	6300.00
0005432459904	8236	Economy	6300.00
0005432459877	8236	Economy	6300.00
0005432459914	8236	Economy	6300.00
0005432042711	8236	Economy	6300.00
0005432459905	8236	Economy	6300.00
0005433506978	8236	Economy	6300.00
0005432042723	8236	Economy	6300.00
0005432459870	8236	Economy	6300.00
0005435885247	8236	Economy	6300.00
0005432459912	8236	Economy	6300.00
0005432042709	8236	Economy	6300.00
0005432459911	8236	Economy	6300.00
0005435885268	8236	Economy	6300.00
0005435885258	8236	Economy	6300.00
0005433507041	8236	Economy	6300.00
0005433804914	8235	Business	18800.00
0005433804975	8235	Business	18800.00
0005433805123	8235	Business	18800.00
0005433633494	8235	Business	18800.00
0005433633556	8235	Business	18800.00
0005433633676	8235	Business	18800.00
0005433633520	8235	Business	18800.00
0005433633394	8235	Business	18800.00
0005433805000	8235	Business	18800.00
0005433633490	8235	Business	18800.00
0005433805215	8235	Business	18800.00
0005433804996	8235	Economy	6900.00
0005433633492	8235	Economy	6900.00
0005433805042	8235	Economy	6300.00
0005433633502	8235	Economy	6300.00
0005433804931	8235	Economy	6300.00
0005433633647	8235	Economy	6300.00
0005433633516	8235	Economy	6300.00
0005433633475	8235	Economy	6300.00
0005433805214	8235	Economy	6300.00
0005433804910	8235	Economy	6300.00
0005433805138	8235	Economy	6300.00
0005433633517	8235	Economy	6300.00
0005433805014	8235	Economy	6300.00
0005433804943	8235	Economy	6300.00
0005433633439	8235	Economy	6300.00
0005433633361	8235	Economy	6300.00
0005433804852	8235	Economy	6300.00
0005433805120	8235	Economy	6300.00
0005433804797	8235	Economy	6300.00
0005434271294	8235	Economy	6300.00
0005433633441	8235	Economy	6300.00
0005433633504	8235	Economy	6300.00
0005433804928	8235	Economy	6300.00
0005433804866	8235	Economy	6300.00
0005433633375	8235	Economy	6300.00
0005434143716	8235	Economy	6300.00
0005433633639	8235	Economy	6300.00
0005433805152	8235	Economy	6300.00
0005433804909	8235	Economy	6300.00
0005433633431	8235	Economy	6300.00
0005433633440	8235	Economy	6300.00
0005433633675	8235	Economy	6300.00
0005433633545	8235	Economy	6900.00
0005433805043	8235	Economy	6900.00
0005433804867	8235	Economy	6900.00
0005433633362	8235	Economy	6900.00
0005433633521	8235	Economy	6300.00
0005433805145	8235	Economy	6300.00
0005433805044	8235	Economy	6900.00
0005434271293	8235	Economy	6300.00
0005433805147	8235	Economy	6300.00
0005433633407	8235	Economy	6300.00
0005433633580	8235	Economy	6300.00
0005433633442	8235	Economy	6300.00
0005433805146	8235	Economy	6300.00
0005433804974	8235	Economy	6300.00
0005433633470	8235	Economy	6300.00
0005433805030	8235	Economy	6300.00
0005433805006	8235	Economy	6300.00
0005433804962	8235	Economy	6300.00
0005433633500	8235	Economy	6300.00
0005433633646	8235	Economy	6300.00
0005433805031	8235	Economy	6300.00
0005433633478	8235	Economy	6300.00
0005433633505	8235	Economy	6300.00
0005434143715	8235	Economy	6300.00
0005433804963	8235	Economy	6300.00
0005433804992	8235	Economy	6300.00
0005433633430	8235	Economy	6300.00
0005433633406	8235	Economy	6300.00
0005433633533	8235	Economy	6300.00
0005433633501	8235	Economy	6300.00
0005433633677	8235	Economy	6300.00
0005433633586	8235	Economy	6300.00
0005433633534	8235	Economy	6300.00
0005433805063	8235	Economy	6300.00
0005434183557	8234	Economy	6300.00
0005432727939	4611	Business	9900.00
0005432383194	4611	Business	9900.00
0005432383167	4611	Business	9900.00
0005433454876	4611	Business	9900.00
0005433722228	4611	Business	9900.00
0005432383173	4611	Business	9900.00
0005432383189	4611	Business	9900.00
0005432383188	4611	Business	9900.00
0005432383193	4611	Business	9900.00
0005432383186	4611	Economy	3300.00
0005432727933	4611	Economy	3300.00
0005432727944	4611	Economy	3300.00
0005432383190	4611	Economy	3300.00
0005432727942	4611	Economy	3300.00
0005432383199	4611	Economy	3300.00
0005432383170	4611	Economy	3600.00
0005432383198	4611	Economy	3600.00
0005432383175	4611	Economy	3600.00
0005432727941	4611	Economy	3300.00
0005432727937	4611	Economy	3300.00
0005433722226	4611	Economy	3300.00
0005432727936	4611	Economy	3300.00
0005432383171	4611	Economy	3300.00
0005432383179	4611	Economy	3300.00
0005432383192	4611	Economy	3300.00
0005432383197	4611	Economy	3300.00
0005432727935	4611	Economy	3300.00
0005433722229	4611	Economy	3300.00
0005433722227	4611	Economy	3300.00
0005432383191	4611	Economy	3300.00
0005432383177	4611	Economy	3300.00
0005432727934	4611	Economy	3300.00
0005432383176	4611	Economy	3300.00
0005432383182	4611	Economy	3300.00
0005432383172	4611	Economy	3300.00
0005432727940	4611	Economy	3300.00
0005433722225	4611	Economy	3300.00
0005432383196	4611	Economy	3300.00
0005432383168	4611	Economy	3300.00
0005432383200	4611	Economy	3300.00
0005432383178	4611	Economy	3300.00
0005432727945	4611	Economy	3300.00
0005432727938	4611	Economy	3300.00
0005432383174	4611	Economy	3300.00
0005432383169	4611	Economy	3300.00
0005432383187	4611	Economy	3300.00
0005432383195	4611	Economy	3300.00
0005432383180	4611	Economy	3300.00
0005432727943	4611	Economy	3300.00
0005432383181	4611	Economy	3300.00
0005432383185	4611	Economy	3300.00
0005432383184	4611	Economy	3300.00
0005432383201	4611	Economy	3300.00
0005432383183	4611	Economy	3300.00
0005432382677	30207	Business	9900.00
0005432382676	30207	Business	9900.00
0005432727819	30207	Business	9900.00
0005433194842	30207	Business	9900.00
0005432382749	30207	Business	9900.00
0005432727825	30207	Business	9900.00
0005432727906	30207	Business	9900.00
0005432382606	30207	Business	9900.00
0005432382649	30207	Business	9900.00
0005432382682	30207	Economy	3300.00
0005432727838	30207	Economy	3300.00
0005432382742	30207	Economy	3300.00
0005432382671	30207	Economy	3300.00
0005432382616	30207	Economy	3300.00
0005432382577	30207	Economy	3300.00
0005432727857	30207	Economy	3300.00
0005432727885	30207	Economy	3600.00
0005433722128	30207	Economy	3600.00
0005432382576	30207	Economy	3600.00
0005432382652	30207	Economy	3300.00
0005432382750	30207	Economy	3300.00
0005432382588	30207	Economy	3300.00
0005432382589	30207	Economy	3300.00
0005432382621	30207	Economy	3300.00
0005432727829	30207	Economy	3300.00
0005432382683	30207	Economy	3300.00
0005432382748	30207	Economy	3300.00
0005432727818	30207	Economy	3300.00
0005432727828	30207	Economy	3300.00
0005433722121	30207	Economy	3300.00
0005432382721	30207	Economy	3300.00
0005433451605	30207	Economy	3300.00
0005432727860	30207	Economy	3300.00
0005433194841	30207	Economy	3300.00
0005432382722	30207	Economy	3300.00
0005433194832	30207	Economy	3300.00
0005433451601	30207	Economy	3300.00
0005432727830	30207	Economy	3300.00
0005432382688	30207	Economy	3300.00
0005432382689	30207	Economy	3300.00
0005433453736	30207	Economy	3300.00
0005432382587	30207	Economy	3300.00
0005432727859	30207	Economy	3300.00
0005432382684	30207	Economy	3300.00
0005432382526	30207	Economy	3300.00
0005432382615	30207	Economy	3300.00
0005433722131	30207	Economy	3300.00
0005432382672	30207	Economy	3300.00
0005432727767	30207	Economy	3300.00
0005432382687	30207	Economy	3300.00
0005432382611	30207	Economy	3300.00
0005433451590	30207	Economy	3300.00
0005432727824	30207	Economy	3300.00
0005432382751	30207	Economy	3300.00
0005435541015	1767	Business	57200.00
0005435529263	1767	Business	57200.00
0005435541003	1767	Business	57200.00
0005435529274	1767	Business	57200.00
0005433516884	1767	Business	57200.00
0005435529261	1767	Business	57200.00
0005435529268	1767	Business	57200.00
0005435529266	1767	Economy	19100.00
0005435541000	1767	Economy	19100.00
0005435541017	1767	Economy	19100.00
0005435541020	1767	Economy	19100.00
0005433516891	1767	Economy	21000.00
0005433516890	1767	Economy	21000.00
0005435529258	1767	Economy	21000.00
0005432294488	1767	Economy	19100.00
0005435529256	1767	Economy	19100.00
0005433516886	1767	Economy	19100.00
0005435529272	1767	Economy	19100.00
0005435529273	1767	Economy	19100.00
0005435541002	1767	Economy	19100.00
0005435541012	1767	Economy	19100.00
0005435541004	1767	Economy	19100.00
0005435541014	1767	Economy	19100.00
0005433516885	1767	Economy	19100.00
0005435541009	1767	Economy	19100.00
0005432925001	1767	Economy	19100.00
0005433516888	1767	Economy	19100.00
0005435541008	1767	Economy	19100.00
0005435541018	1767	Economy	19100.00
0005435529265	1767	Economy	19100.00
0005433516889	1767	Economy	19100.00
0005435529269	1767	Economy	19100.00
0005432925007	1767	Economy	19100.00
0005435541016	1767	Economy	19100.00
0005435529264	1767	Economy	19100.00
0005435541006	1767	Economy	19100.00
0005435529267	1767	Economy	19100.00
0005435529271	1767	Economy	19100.00
0005433516892	1767	Economy	19100.00
0005435541011	1767	Economy	19100.00
0005435529257	1767	Economy	19100.00
0005435541019	1767	Economy	19100.00
0005435541007	1767	Economy	19100.00
0005435541010	1767	Economy	19100.00
0005435529276	1767	Economy	19100.00
0005435529270	1767	Economy	19100.00
0005435540999	1767	Economy	19100.00
0005435529275	1767	Economy	19100.00
0005435541013	1767	Economy	19100.00
0005435541022	1767	Economy	19100.00
0005435529259	1767	Economy	19100.00
0005435529260	1767	Economy	19100.00
0005435541021	1767	Economy	19100.00
0005432294487	1767	Economy	19100.00
0005433516887	1767	Economy	19100.00
0005435541001	1767	Economy	19100.00
0005435529262	1767	Economy	19100.00
0005435541005	1767	Economy	19100.00
0005435517602	22022	Business	57200.00
0005435517734	22022	Business	57200.00
0005432925039	22022	Business	57200.00
0005435517673	22022	Business	57200.00
0005435517669	22022	Business	57200.00
0005433516821	22022	Business	57200.00
0005433516836	22022	Economy	19100.00
0005435517723	22022	Economy	19100.00
0005435540731	22022	Economy	19100.00
0005435540820	22022	Economy	21000.00
0005432925035	22022	Economy	21000.00
0005435517736	22022	Economy	19100.00
0005435540783	22022	Economy	19100.00
0005435517718	22022	Economy	19100.00
0005433516823	22022	Economy	19100.00
0005432925038	22022	Economy	19100.00
0005435517674	22022	Economy	19100.00
0005433516787	22022	Economy	19100.00
0005435540851	22022	Economy	19100.00
0005435540730	22022	Economy	19100.00
0005435517672	22022	Economy	19100.00
0005432925036	22022	Economy	19100.00
0005435517726	22022	Economy	19100.00
0005435540817	22022	Economy	19100.00
0005435540793	22022	Economy	19100.00
0005435517789	22022	Economy	19100.00
0005433516819	22022	Economy	19100.00
0005432925037	22022	Economy	19100.00
0005435540763	22022	Economy	19100.00
0005433516756	22022	Economy	19100.00
0005435540751	22022	Economy	19100.00
0005435517603	22022	Economy	19100.00
0005435540804	22022	Economy	19100.00
0005435517727	22022	Economy	19100.00
0005433516804	22022	Economy	19100.00
0005435517728	22022	Economy	19100.00
0005435540819	22022	Economy	19100.00
0005435540794	22022	Economy	19100.00
0005433516820	22022	Economy	19100.00
0005435540784	22022	Economy	19100.00
0005435517722	22022	Economy	19100.00
0005433516822	22022	Economy	19100.00
0005435540805	22022	Economy	19100.00
0005432839048	7402	Business	18500.00
0005435491425	7402	Business	18500.00
0005435491418	7402	Business	18500.00
0005432839051	7402	Business	18500.00
0005432839042	7402	Business	18500.00
0005434458809	7402	Business	18500.00
0005435252564	7402	Business	18500.00
0005435252574	7402	Business	18500.00
0005432839052	7402	Business	18500.00
0005432839027	7402	Business	18500.00
0005432839029	7402	Business	18500.00
0005432839046	7402	Business	18500.00
0005432839032	7402	Economy	6200.00
0005435252518	7402	Economy	6200.00
0005434458803	7402	Economy	6200.00
0005434458799	7402	Economy	6200.00
0005432839022	7402	Economy	6200.00
0005434458814	7402	Economy	6200.00
0005434664939	7402	Economy	6200.00
0005432839031	7402	Economy	6200.00
0005432839043	7402	Economy	6200.00
0005435491417	7402	Economy	6800.00
0005432839041	7402	Economy	6800.00
0005435252637	7402	Economy	6800.00
0005435252550	7402	Economy	6800.00
0005434458796	7402	Economy	6800.00
0005434458801	7402	Economy	6200.00
0005432839047	7402	Economy	6200.00
0005432841011	7402	Economy	6200.00
0005434458807	7402	Economy	6200.00
0005434458800	7402	Economy	6200.00
0005435252600	7402	Economy	6200.00
0005432839030	7402	Economy	6200.00
0005432073391	7402	Economy	6200.00
0005434458816	7402	Economy	6200.00
0005432839038	7402	Economy	6200.00
0005432839037	7402	Economy	6200.00
0005432823448	7402	Economy	6200.00
0005434458815	7402	Economy	6200.00
0005432073389	7402	Economy	6200.00
0005435252493	7402	Economy	6200.00
0005434458804	7402	Economy	6200.00
0005434458813	7402	Economy	6200.00
0005434458795	7402	Economy	6200.00
0005434458812	7402	Economy	6200.00
0005435252559	7402	Economy	6200.00
0005434458797	7402	Economy	6200.00
0005435491424	7402	Economy	6200.00
0005432839033	7402	Economy	6200.00
0005434664940	7402	Economy	6200.00
0005435252561	7402	Economy	6200.00
0005435491423	7402	Economy	6200.00
0005432839025	7402	Economy	6200.00
0005435491409	7402	Economy	6200.00
0005434458806	7402	Economy	6200.00
0005434458810	7402	Economy	6200.00
0005435252638	7402	Economy	6200.00
0005432839050	7402	Economy	6200.00
0005435252557	7402	Economy	6200.00
0005432073392	7402	Economy	6200.00
0005434458802	7402	Economy	6200.00
0005434458798	7402	Economy	6200.00
0005432839045	7402	Economy	6200.00
0005435252527	7402	Economy	6200.00
0005432839044	7402	Economy	6200.00
0005435252528	7402	Economy	6200.00
0005432839039	7402	Economy	6200.00
0005435252541	7402	Economy	6200.00
0005434458811	7402	Economy	6200.00
0005435252558	7402	Economy	6200.00
0005435252543	7402	Economy	6200.00
0005435252542	7402	Economy	6200.00
0005435252477	7402	Economy	6200.00
0005432839024	7402	Economy	6200.00
0005432073390	7402	Economy	6200.00
0005435252520	7402	Economy	6200.00
0005435252519	7402	Economy	6200.00
0005432839028	7402	Economy	6200.00
0005432839036	7402	Economy	6200.00
0005435252562	7402	Economy	6200.00
0005435252616	7402	Economy	6200.00
0005435252551	7402	Economy	6200.00
0005432839040	7402	Economy	6200.00
0005432839023	7402	Economy	6200.00
0005432839035	7402	Economy	6200.00
0005432823449	7402	Economy	6200.00
0005434458808	7402	Economy	6200.00
0005432839049	7402	Economy	6200.00
0005434458805	7402	Economy	6200.00
0005432839026	7402	Economy	6200.00
0005432839034	7402	Economy	6200.00
0005435252712	28943	Business	18500.00
0005432838847	28943	Business	18500.00
0005432838759	28943	Business	18500.00
0005434458647	28943	Business	18500.00
0005434458618	28943	Business	18500.00
0005432838762	28943	Business	18500.00
0005435491441	28943	Business	18500.00
0005434664962	28943	Business	18500.00
0005432838726	28943	Economy	6200.00
0005432838752	28943	Economy	6200.00
0005432838693	28943	Economy	6200.00
0005435252699	28943	Economy	6200.00
0005432823432	28943	Economy	6200.00
0005432838681	28943	Economy	6200.00
0005435491440	28943	Economy	6200.00
0005435252703	28943	Economy	6200.00
0005432838846	28943	Economy	6200.00
0005434458675	28943	Economy	6200.00
0005434458616	28943	Economy	6800.00
0005435252706	28943	Economy	6800.00
0005432838840	28943	Economy	6800.00
0005432838744	28943	Economy	6800.00
0005435252711	28943	Economy	6200.00
0005434458587	28943	Economy	6200.00
0005432001024	28943	Economy	6200.00
0005432838753	28943	Economy	6200.00
0005432838725	28943	Economy	6200.00
0005434458617	28943	Economy	6200.00
0005432838702	28943	Economy	6200.00
0005432001023	28943	Economy	6200.00
0005434458674	28943	Economy	6200.00
0005434458673	28943	Economy	6200.00
0005432823431	28943	Economy	6200.00
0005432838745	28943	Economy	6200.00
0005432838701	28943	Economy	6200.00
0005432838743	28943	Economy	6200.00
0005432838760	28943	Economy	6200.00
0005435252710	28943	Economy	6200.00
0005434458588	28943	Economy	6200.00
0005432838690	28943	Economy	6200.00
0005434458676	28943	Economy	6200.00
0005435252696	28943	Economy	6200.00
0005434458656	28943	Economy	6200.00
0005435252709	28943	Economy	6200.00
0005432840999	28943	Economy	6200.00
0005434458665	28943	Economy	6200.00
0005434458695	28943	Economy	6200.00
0005432840993	28943	Economy	6200.00
0005432838887	28943	Economy	6200.00
0005435252698	28943	Economy	6200.00
0005434664961	28943	Economy	6200.00
0005432838820	28943	Economy	6200.00
0005434458663	28943	Economy	6200.00
0005432838682	28943	Economy	6200.00
0005435491442	28943	Economy	6200.00
0005435252707	28943	Economy	6200.00
0005432838665	28943	Economy	6200.00
0005435252705	28943	Economy	6200.00
0005432838828	28943	Economy	6200.00
0005432840994	28943	Economy	6200.00
0005432838730	28943	Economy	6200.00
0005432001022	28943	Economy	6200.00
0005432838859	28943	Economy	6200.00
0005435252708	28943	Economy	6200.00
0005435252702	28943	Economy	6200.00
0005434664960	28943	Economy	6200.00
0005435252713	28943	Economy	6200.00
0005435252704	28943	Economy	6200.00
0005435252701	28943	Economy	6200.00
0005434458634	28943	Economy	6200.00
0005435252697	28943	Economy	6200.00
0005435252700	28943	Economy	6200.00
0005434458664	28943	Economy	6200.00
0005434275972	8811	Business	145300.00
0005434276001	8811	Business	145300.00
0005434276002	8811	Business	145300.00
0005434275971	8811	Business	145300.00
0005434276000	8811	Economy	48400.00
0005435990625	8811	Economy	48400.00
0005435990627	8811	Economy	48400.00
0005435990623	8811	Economy	48400.00
0005435990621	8811	Economy	48400.00
0005434275979	8811	Economy	48400.00
0005434275997	8811	Economy	48400.00
0005435990622	8811	Economy	48400.00
0005435990624	8811	Economy	48400.00
0005435990626	8811	Economy	48400.00
0005435990628	8811	Economy	48400.00
0005434275996	8811	Economy	48400.00
0005435990620	8811	Economy	48400.00
0005434276026	15764	Business	145300.00
0005435990582	15764	Business	145300.00
0005435990555	15764	Business	145300.00
0005434276025	15764	Business	145300.00
0005435990556	15764	Business	145300.00
0005435990564	15764	Business	145300.00
0005435990574	15764	Economy	48400.00
0005435990566	15764	Economy	48400.00
0005435990563	15764	Economy	48400.00
0005434276027	15764	Economy	48400.00
0005435990581	15764	Economy	48400.00
0005434276028	15764	Economy	48400.00
0005434276029	15764	Economy	48400.00
0005435990549	15764	Economy	48400.00
0005435990573	15764	Economy	48400.00
0005433476880	20633	Economy	14500.00
0005432427142	20633	Economy	14500.00
0005433476871	20633	Economy	14500.00
0005433476879	20633	Economy	14500.00
0005433476868	20633	Economy	14500.00
0005432427141	20633	Economy	14500.00
0005433476878	20633	Economy	14500.00
0005432427140	20633	Economy	14500.00
0005432427143	20633	Economy	14500.00
0005433476869	20633	Economy	14500.00
0005432360344	6390	Business	36600.00
0005432062228	6390	Business	36600.00
0005435176930	6390	Business	36600.00
0005432360347	6390	Business	36600.00
0005434149650	6390	Business	36600.00
0005435176909	6390	Business	36600.00
0005435176874	6390	Business	36600.00
0005432336034	6390	Business	36600.00
0005432360362	6390	Business	36600.00
0005435490198	6390	Business	36600.00
0005432360360	6390	Business	36600.00
0005435723023	6390	Business	36600.00
0005435176937	6390	Economy	12200.00
0005432363414	6390	Economy	12200.00
0005432360382	6390	Economy	12200.00
0005435723024	6390	Economy	12200.00
0005432360345	6390	Economy	12200.00
0005432360356	6390	Economy	12200.00
0005435176872	6390	Economy	12200.00
0005435176917	6390	Economy	12200.00
0005432360352	6390	Economy	12200.00
0005434149590	6390	Economy	12200.00
0005434149593	6390	Economy	12200.00
0005432062229	6390	Economy	12200.00
0005434149594	6390	Economy	12200.00
0005432360376	6390	Economy	12200.00
0005432360350	6390	Economy	12200.00
0005432336040	6390	Economy	12200.00
0005432360374	6390	Economy	12200.00
0005435176802	6390	Economy	12200.00
0005432360372	6390	Economy	12200.00
0005432360349	6390	Economy	12200.00
0005432360383	6390	Economy	12200.00
0005432336038	6390	Economy	12200.00
0005434149626	6390	Economy	12200.00
0005435176913	6390	Economy	12200.00
0005432336037	6390	Economy	12200.00
0005432360358	6390	Economy	12200.00
0005435176854	6390	Economy	12200.00
0005432360343	6390	Economy	12200.00
0005432360359	6390	Economy	12200.00
0005432360351	6390	Economy	12200.00
0005434149651	6390	Economy	12200.00
0005435176924	6390	Economy	12200.00
0005432360370	6390	Economy	12200.00
0005432336039	6390	Economy	12200.00
0005432062231	6390	Economy	12200.00
0005435490197	6390	Economy	12200.00
0005432360365	6390	Economy	13400.00
0005432360380	6390	Economy	13400.00
0005432360384	6390	Economy	13400.00
0005432336036	6390	Economy	13400.00
0005435176923	6390	Economy	12200.00
0005435176858	6390	Economy	13400.00
0005432360348	6390	Economy	12200.00
0005434149589	6390	Economy	12200.00
0005435176857	6390	Economy	12200.00
0005432360390	6390	Economy	12200.00
0005432336031	6390	Economy	12200.00
0005432360367	6390	Economy	12200.00
0005432360368	6390	Economy	12200.00
0005434149624	6390	Economy	12200.00
0005432336032	6390	Economy	12200.00
0005435723030	6390	Economy	12200.00
0005432062230	6390	Economy	12200.00
0005435176892	6390	Economy	12200.00
0005432336035	6390	Economy	12200.00
0005432360389	6390	Economy	12200.00
0005432360361	6390	Economy	12200.00
0005435176859	6390	Economy	12200.00
0005432363417	6390	Economy	12200.00
0005432360379	6390	Economy	12200.00
0005435176875	6390	Economy	12200.00
0005435176934	6390	Economy	12200.00
0005432360375	6390	Economy	12200.00
0005432360364	6390	Economy	12200.00
0005435176785	6390	Economy	12200.00
0005432363416	6390	Economy	12200.00
0005432360354	6390	Economy	12200.00
0005432062232	6390	Economy	12200.00
0005432360355	6390	Economy	12200.00
0005435176873	6390	Economy	12200.00
0005432360387	6390	Economy	12200.00
0005435176832	6390	Economy	12200.00
0005434149617	6390	Economy	12200.00
0005432360386	6390	Economy	12200.00
0005432360353	6390	Economy	12200.00
0005435490191	6390	Economy	12200.00
0005432062227	6390	Economy	12200.00
0005432363415	6390	Economy	12200.00
0005432360366	6390	Economy	12200.00
0005432360346	6390	Economy	12200.00
0005432360385	6390	Economy	12200.00
0005432360363	6390	Economy	12200.00
0005432360369	6390	Economy	12200.00
0005434149623	6390	Economy	12200.00
0005432360357	6390	Economy	12200.00
0005432360371	6390	Economy	12200.00
0005432360381	6390	Economy	12200.00
0005435176957	6390	Economy	12200.00
0005435176772	6390	Economy	12200.00
0005435723032	6390	Economy	12200.00
0005432360377	6390	Economy	12200.00
0005432360373	6390	Economy	12200.00
0005435176786	6390	Economy	12200.00
0005432336033	6390	Economy	12200.00
0005432360388	6390	Economy	12200.00
0005432360391	6390	Economy	12200.00
0005432336030	6390	Economy	12200.00
0005432360378	6390	Economy	12200.00
0005432336029	6390	Economy	12200.00
0005435490185	6390	Economy	12200.00
0005435176908	6390	Economy	12200.00
0005434149677	6390	Economy	12200.00
0005435176803	6390	Economy	12200.00
0005435176958	6390	Economy	12200.00
0005432359897	21012	Business	36600.00
0005435177070	21012	Business	36600.00
0005432359934	21012	Business	36600.00
0005432363395	21012	Business	36600.00
0005432335910	21012	Business	36600.00
0005435177087	21012	Business	36600.00
0005434149733	21012	Business	36600.00
0005432335892	21012	Business	36600.00
0005432359830	21012	Business	36600.00
0005435177078	21012	Economy	12200.00
0005434149725	21012	Economy	12200.00
0005435177071	21012	Economy	12200.00
0005434149734	21012	Economy	12200.00
0005432359889	21012	Economy	12200.00
0005432359779	21012	Economy	12200.00
0005432359991	21012	Economy	12200.00
0005432359963	21012	Economy	12200.00
0005432335926	21012	Economy	12200.00
0005435490231	21012	Economy	12200.00
0005432052747	21012	Economy	12200.00
0005435490230	21012	Economy	12200.00
0005435177068	21012	Economy	12200.00
0005432359974	21012	Economy	12200.00
0005435177069	21012	Economy	12200.00
0005432363373	21012	Economy	12200.00
0005434149732	21012	Economy	12200.00
0005432335936	21012	Economy	12200.00
0005432359998	21012	Economy	12200.00
0005432359816	21012	Economy	12200.00
0005434149728	21012	Economy	12200.00
0005435177086	21012	Economy	12200.00
0005432359932	21012	Economy	12200.00
0005432359946	21012	Economy	12200.00
0005435177072	21012	Economy	12200.00
0005432359931	21012	Economy	12200.00
0005432360091	21012	Economy	12200.00
0005432360152	21012	Economy	12200.00
0005434149736	21012	Economy	12200.00
0005432052748	21012	Economy	12200.00
0005432052745	21012	Economy	12200.00
0005432359955	21012	Economy	12200.00
0005435177067	21012	Economy	12200.00
0005432363400	21012	Economy	12200.00
0005435177083	21012	Economy	12200.00
0005432359944	21012	Economy	12200.00
0005435723046	21012	Economy	13400.00
0005435177075	21012	Economy	13400.00
0005432360092	21012	Economy	13400.00
0005432359842	21012	Economy	13400.00
0005432359762	21012	Economy	13400.00
0005432359960	21012	Economy	13400.00
0005434149731	21012	Economy	12200.00
0005435723045	21012	Economy	12200.00
0005432359792	21012	Economy	12200.00
0005432359945	21012	Economy	12200.00
0005432359938	21012	Economy	12200.00
0005435177065	21012	Economy	12200.00
0005432363390	21012	Economy	12200.00
0005432052746	21012	Economy	12200.00
0005435177073	21012	Economy	12200.00
0005435177080	21012	Economy	12200.00
0005432359894	21012	Economy	12200.00
0005432360001	21012	Economy	12200.00
0005432335935	21012	Economy	12200.00
0005432359914	21012	Economy	12200.00
0005432335899	21012	Economy	12200.00
0005432335964	21012	Economy	12200.00
0005435177074	21012	Economy	12200.00
0005432335898	21012	Economy	12200.00
0005435490232	21012	Economy	12200.00
0005435177089	21012	Economy	12200.00
0005432359843	21012	Economy	12200.00
0005435177081	21012	Economy	12200.00
0005432359999	21012	Economy	12200.00
0005432359791	21012	Economy	12200.00
0005432359939	21012	Economy	12200.00
0005432360027	21012	Economy	12200.00
0005432335943	21012	Economy	12200.00
0005435177091	21012	Economy	12200.00
0005434149726	21012	Economy	12200.00
0005434149735	21012	Economy	12200.00
0005434149729	21012	Economy	12200.00
0005432335978	21012	Economy	12200.00
0005435723047	21012	Economy	12200.00
0005432360020	21012	Economy	12200.00
0005432359990	21012	Economy	12200.00
0005435177082	21012	Economy	12200.00
0005435177079	21012	Economy	12200.00
0005432359778	21012	Economy	12200.00
0005435177090	21012	Economy	12200.00
0005435177076	21012	Economy	12200.00
0005432359684	21012	Economy	12200.00
0005435177066	21012	Economy	12200.00
0005435177077	21012	Economy	12200.00
0005435177084	21012	Economy	12200.00
0005432360039	21012	Economy	12200.00
0005432359876	21012	Economy	12200.00
0005432359927	21012	Economy	12200.00
0005432359975	21012	Economy	12200.00
0005435177088	21012	Economy	12200.00
0005434149727	21012	Economy	12200.00
0005432335937	21012	Economy	12200.00
0005435177085	21012	Economy	12200.00
0005434149730	21012	Economy	12200.00
0005432360019	21012	Economy	12200.00
0005432359947	21012	Economy	12200.00
0005435490233	21012	Economy	12200.00
0005432359828	21012	Economy	12200.00
0005432359888	21012	Economy	12200.00
0005432359926	21012	Economy	12200.00
0005432335911	21012	Economy	12200.00
0005432359890	21012	Economy	12200.00
0005432359956	21012	Economy	12200.00
0005432335944	21012	Economy	12200.00
0005434448279	17701	Economy	3400.00
0005434458597	17701	Economy	3400.00
0005434186199	17701	Economy	3100.00
0005434458624	17701	Economy	3100.00
0005434186198	17701	Economy	3100.00
0005434461632	17701	Economy	3100.00
0005434461633	17701	Economy	3100.00
0005434458626	17701	Economy	3100.00
0005434186200	17701	Economy	3100.00
0005434458608	17701	Economy	3100.00
0005434448268	17701	Economy	3100.00
0005434458638	17701	Economy	3100.00
0005434458627	17701	Economy	3100.00
0005434458641	17701	Economy	3100.00
0005434458640	17701	Economy	3100.00
0005434461624	17701	Economy	3100.00
0005434463913	17701	Economy	3100.00
0005434458670	17701	Economy	3100.00
0005434458654	17701	Economy	3100.00
0005434458694	17701	Economy	3100.00
0005434458655	17701	Economy	3100.00
0005434458749	17701	Economy	3100.00
0005434463903	17701	Economy	3100.00
0005434458609	17701	Economy	3100.00
0005434448284	17701	Economy	3100.00
0005434458598	17701	Economy	3100.00
0005434461611	17701	Economy	3100.00
0005434458568	17701	Economy	3100.00
0005434463911	17701	Economy	3100.00
0005434463912	17701	Economy	3100.00
0005434186171	29131	Economy	3400.00
0005434458809	29131	Economy	3400.00
0005434448313	29131	Economy	3100.00
0005434462789	29131	Economy	3100.00
0005434463928	29131	Economy	3100.00
0005434186170	29131	Economy	3100.00
0005434462788	29131	Economy	3100.00
0005434448312	29131	Economy	3100.00
0005434458804	29131	Economy	3100.00
0005434458813	29131	Economy	3100.00
0005434463926	29131	Economy	3100.00
0005434458803	29131	Economy	3100.00
0005434458796	29131	Economy	3100.00
0005434448310	29131	Economy	3100.00
0005434458810	29131	Economy	3100.00
0005434462787	29131	Economy	3100.00
0005434458795	29131	Economy	3100.00
0005434448311	29131	Economy	3100.00
0005434458797	29131	Economy	3100.00
0005434458811	29131	Economy	3100.00
0005434458806	29131	Economy	3100.00
0005434186174	29131	Economy	3100.00
0005434458800	29131	Economy	3100.00
0005434458805	29131	Economy	3100.00
0005434458799	29131	Economy	3100.00
0005434458807	29131	Economy	3100.00
0005434458801	29131	Economy	3100.00
0005434458814	29131	Economy	3100.00
0005434458815	29131	Economy	3100.00
0005434463927	29131	Economy	3100.00
0005434458802	29131	Economy	3100.00
0005434186173	29131	Economy	3100.00
0005434458798	29131	Economy	3100.00
0005434458812	29131	Economy	3100.00
0005434458808	29131	Economy	3100.00
0005434458816	29131	Economy	3100.00
0005432604323	21410	Economy	7300.00
0005432604294	21410	Economy	7300.00
0005432604310	21410	Economy	7300.00
0005432604325	21410	Economy	6600.00
0005432604306	21410	Economy	6600.00
0005432604330	21410	Economy	6600.00
0005432604313	21410	Economy	6600.00
0005432604303	21410	Economy	6600.00
0005432604311	21410	Economy	6600.00
0005432604324	21410	Economy	6600.00
0005432604304	21410	Economy	6600.00
0005432604301	21410	Economy	6600.00
0005432604300	21410	Economy	6600.00
0005432604295	21410	Economy	6600.00
0005432604321	21410	Economy	6600.00
0005432604297	21410	Economy	6600.00
0005432604292	21410	Economy	6600.00
0005432604316	21410	Economy	6600.00
0005432604293	21410	Economy	6600.00
0005432604319	21410	Economy	6600.00
0005435218105	21410	Economy	6600.00
0005432604315	21410	Economy	6600.00
0005432604326	21410	Economy	6600.00
0005432604322	21410	Economy	6600.00
0005432604291	21410	Economy	6600.00
0005432604308	21410	Economy	6600.00
0005432604309	21410	Economy	6600.00
0005432604298	21410	Economy	6600.00
0005432604317	21410	Economy	6600.00
0005432604314	21410	Economy	6600.00
0005432604302	21410	Economy	6600.00
0005432604299	21410	Economy	6600.00
0005432604327	21410	Economy	6600.00
0005432604296	21410	Economy	6600.00
0005432604331	21410	Economy	6600.00
0005432604312	21410	Economy	6600.00
0005432604307	21410	Economy	6600.00
0005435218106	21410	Economy	6600.00
0005432604320	21410	Economy	6600.00
0005432604329	21410	Economy	6600.00
0005432604318	21410	Economy	6600.00
0005432604328	21410	Economy	6600.00
0005432604305	21410	Economy	6600.00
0005432604081	31666	Economy	7300.00
0005432604036	31666	Economy	7300.00
0005432603998	31666	Economy	7300.00
0005432603884	31666	Economy	6600.00
0005432603828	31666	Economy	6600.00
0005432604110	31666	Economy	6600.00
0005432603893	31666	Economy	6600.00
0005432603909	31666	Economy	6600.00
0005432604078	31666	Economy	6600.00
0005432604070	31666	Economy	6600.00
0005432603896	31666	Economy	6600.00
0005432603894	31666	Economy	6600.00
0005432603969	31666	Economy	6600.00
0005432603927	31666	Economy	6600.00
0005432603908	31666	Economy	6600.00
0005432604001	31666	Economy	6600.00
0005432604006	31666	Economy	6600.00
0005432603962	31666	Economy	6600.00
0005432603937	31666	Economy	6600.00
0005432603995	31666	Economy	6600.00
0005432603827	31666	Economy	6600.00
0005432603919	31666	Economy	6600.00
0005432604068	31666	Economy	6600.00
0005432604007	31666	Economy	6600.00
0005432603848	31666	Economy	6600.00
0005432604008	31666	Economy	6600.00
0005432603800	31666	Economy	6600.00
0005432603918	31666	Economy	6600.00
0005432604072	31666	Economy	6600.00
0005432603678	31666	Economy	6600.00
0005432604002	31666	Economy	6600.00
0005432603792	31666	Economy	6600.00
0005432603749	31666	Economy	6600.00
0005432603934	31666	Economy	6600.00
0005432603947	31666	Economy	6600.00
0005432604053	31666	Economy	6600.00
0005432604044	31666	Economy	6600.00
0005432603956	31666	Economy	6600.00
0005432603847	31666	Economy	6600.00
0005432603920	31666	Economy	6600.00
0005432604080	31666	Economy	6600.00
0005432604073	31666	Economy	6600.00
0005433293190	12296	Economy	17800.00
0005433293188	12296	Economy	17800.00
0005433293207	12296	Economy	17800.00
0005433293189	12296	Economy	17800.00
0005433293183	12296	Economy	17800.00
0005433293192	12296	Economy	17800.00
0005433293164	12296	Economy	17800.00
0005433293202	12296	Economy	17800.00
0005433293180	12296	Economy	17800.00
0005433293156	12296	Economy	17800.00
0005433293191	12296	Economy	17800.00
0005433293184	12296	Economy	17800.00
0005434606792	18898	Economy	6600.00
0005434606826	22367	Economy	6600.00
0005434606823	22367	Economy	6600.00
0005434606827	22367	Economy	6600.00
0005434606824	22367	Economy	6600.00
0005434604892	22367	Economy	6600.00
0005434604896	22367	Economy	6600.00
0005434604893	22367	Economy	6600.00
0005434606825	22367	Economy	6600.00
0005434604895	22367	Economy	6600.00
0005434604894	22367	Economy	6600.00
0005432747547	405	Business	44500.00
0005432747571	405	Business	44500.00
0005432747556	405	Business	44500.00
0005432753297	405	Business	44500.00
0005432890837	405	Business	44500.00
0005432890864	405	Business	44500.00
0005432747537	405	Business	44500.00
0005432890823	405	Business	44500.00
0005432890790	405	Business	44500.00
0005432890793	405	Business	44500.00
0005433293197	405	Economy	14800.00
0005432747560	405	Economy	14800.00
0005432747566	405	Economy	14800.00
0005432747562	405	Economy	14800.00
0005433293178	405	Economy	14800.00
0005432753300	405	Economy	14800.00
0005432747569	405	Economy	14800.00
0005433293170	405	Economy	14800.00
0005432747563	405	Economy	14800.00
0005432747544	405	Economy	14800.00
0005432747565	405	Economy	16300.00
0005432751524	405	Economy	16300.00
0005432747543	405	Economy	16300.00
0005432220001	405	Economy	16300.00
0005432220002	405	Economy	16300.00
0005433875369	405	Economy	14800.00
0005432890836	405	Economy	14800.00
0005432890794	405	Economy	14800.00
0005432747541	405	Economy	14800.00
0005432220003	405	Economy	14800.00
0005433293179	405	Economy	14800.00
0005432747540	405	Economy	14800.00
0005433293172	405	Economy	14800.00
0005432747554	405	Economy	14800.00
0005432747548	405	Economy	14800.00
0005432749782	405	Economy	14800.00
0005432890838	405	Economy	14800.00
0005432747568	405	Economy	14800.00
0005432747536	405	Economy	14800.00
0005432747557	405	Economy	14800.00
0005432890769	405	Economy	14800.00
0005432890944	405	Economy	14800.00
0005432747539	405	Economy	14800.00
0005432890789	405	Economy	14800.00
0005432747559	405	Economy	14800.00
0005432890822	405	Economy	14800.00
0005432753299	405	Economy	14800.00
0005432747573	405	Economy	14800.00
0005432747564	405	Economy	14800.00
0005432890839	405	Economy	14800.00
0005432747538	405	Economy	14800.00
0005435154597	405	Economy	14800.00
0005432747552	405	Economy	14800.00
0005432747570	405	Economy	14800.00
0005432753298	405	Economy	14800.00
0005432747545	405	Economy	14800.00
0005432747551	405	Economy	14800.00
0005432890867	405	Economy	14800.00
0005432220000	405	Economy	14800.00
0005433293218	405	Economy	14800.00
0005432890865	405	Economy	14800.00
0005433875368	405	Economy	14800.00
0005432747561	405	Economy	14800.00
0005432747555	405	Economy	14800.00
0005432747535	405	Economy	14800.00
0005432747549	405	Economy	14800.00
0005432890863	405	Economy	14800.00
0005432890866	405	Economy	14800.00
0005433293217	405	Economy	14800.00
0005432890795	405	Economy	14800.00
0005432747558	405	Economy	14800.00
0005432751523	405	Economy	14800.00
0005433293213	405	Economy	14800.00
0005432890945	405	Economy	14800.00
0005432747553	405	Economy	14800.00
0005432747546	405	Economy	14800.00
0005433293171	405	Economy	14800.00
0005432747542	405	Economy	14800.00
0005435154596	405	Economy	14800.00
0005432747567	405	Economy	14800.00
0005433293196	405	Economy	14800.00
0005433293186	405	Economy	14800.00
0005432747572	405	Economy	14800.00
0005432749783	405	Economy	14800.00
0005432747550	405	Economy	14800.00
0005432891030	12034	Business	44500.00
0005432747323	12034	Business	44500.00
0005432753268	12034	Business	44500.00
0005433293247	12034	Business	44500.00
0005432891021	12034	Business	44500.00
0005432747200	12034	Business	44500.00
0005432891022	12034	Business	44500.00
0005432747352	12034	Business	44500.00
0005432756819	12034	Business	44500.00
0005432891012	12034	Economy	14800.00
0005432891010	12034	Economy	14800.00
0005432747159	12034	Economy	14800.00
0005435154588	12034	Economy	14800.00
0005433293244	12034	Economy	14800.00
0005433293242	12034	Economy	14800.00
0005432747209	12034	Economy	14800.00
0005432747158	12034	Economy	14800.00
0005432747422	12034	Economy	14800.00
0005432891026	12034	Economy	16300.00
0005432891024	12034	Economy	16300.00
0005432756818	12034	Economy	16300.00
0005435154589	12034	Economy	16300.00
0005432756811	12034	Economy	16300.00
0005432747454	12034	Economy	14800.00
0005432747297	12034	Economy	14800.00
0005432747322	12034	Economy	14800.00
0005432891029	12034	Economy	14800.00
0005432747199	12034	Economy	14800.00
0005432747128	12034	Economy	14800.00
0005432891016	12034	Economy	14800.00
0005432753267	12034	Economy	14800.00
0005432891023	12034	Economy	14800.00
0005432747444	12034	Economy	14800.00
0005435154582	12034	Economy	14800.00
0005432753266	12034	Economy	14800.00
0005433293246	12034	Economy	14800.00
0005433875379	12034	Economy	14800.00
0005432891011	12034	Economy	14800.00
0005432891013	12034	Economy	14800.00
0005432891019	12034	Economy	14800.00
0005432756814	12034	Economy	14800.00
0005435154581	12034	Economy	14800.00
0005433293250	12034	Economy	14800.00
0005432747164	12034	Economy	14800.00
0005432747241	12034	Economy	14800.00
0005432891017	12034	Economy	14800.00
0005432747342	12034	Economy	14800.00
0005433293248	12034	Economy	14800.00
0005432891027	12034	Economy	14800.00
0005435154586	12034	Economy	14800.00
0005432747445	12034	Economy	14800.00
0005432747239	12034	Economy	14800.00
0005432891015	12034	Economy	14800.00
0005432891018	12034	Economy	14800.00
0005432891025	12034	Economy	14800.00
0005432214803	12034	Economy	14800.00
0005432747256	12034	Economy	14800.00
0005432747135	12034	Economy	14800.00
0005435154585	12034	Economy	14800.00
0005432747296	12034	Economy	14800.00
0005435154587	12034	Economy	14800.00
0005432747181	12034	Economy	14800.00
0005432891014	12034	Economy	14800.00
0005432747255	12034	Economy	14800.00
0005433293243	12034	Economy	14800.00
0005432747281	12034	Economy	14800.00
0005432747248	12034	Economy	14800.00
0005435154584	12034	Economy	14800.00
0005432891020	12034	Economy	14800.00
0005433293249	12034	Economy	14800.00
0005435154583	12034	Economy	14800.00
0005433293251	12034	Economy	14800.00
0005432756812	12034	Economy	14800.00
0005432891028	12034	Economy	14800.00
0005435154580	12034	Economy	14800.00
0005433875378	12034	Economy	14800.00
0005435154590	12034	Economy	14800.00
0005432747127	12034	Economy	14800.00
0005432747392	12034	Economy	14800.00
0005433293241	12034	Economy	14800.00
0005433293245	12034	Economy	14800.00
0005432747282	12034	Economy	14800.00
0005432753270	12034	Economy	14800.00
0005432747247	12034	Economy	14800.00
0005432753277	12034	Economy	14800.00
0005432753264	12034	Economy	14800.00
0005432747079	12034	Economy	14800.00
0005433531287	18949	Economy	28200.00
0005432927944	18949	Economy	25700.00
0005433533303	18949	Economy	25700.00
0005433525025	18949	Economy	25700.00
0005433531290	18949	Economy	25700.00
0005433525026	18949	Economy	25700.00
0005433525032	18949	Economy	25700.00
0005432927945	18949	Economy	25700.00
0005433531289	18949	Economy	25700.00
0005433525029	18949	Economy	25700.00
0005432927929	18949	Economy	25700.00
0005433525028	18949	Economy	25700.00
0005433531288	18949	Economy	25700.00
0005433525034	18949	Economy	25700.00
0005432927930	18949	Economy	25700.00
0005433525031	18949	Economy	25700.00
0005433533304	18949	Economy	25700.00
0005433525030	18949	Economy	25700.00
0005433525027	18949	Economy	25700.00
0005433525024	18949	Economy	25700.00
0005433525033	18949	Economy	25700.00
0005433533305	18949	Economy	25700.00
0005433533306	18949	Economy	25700.00
0005433524920	32467	Economy	28200.00
0005432927984	32467	Economy	28200.00
0005432927988	32467	Economy	28200.00
0005433524939	32467	Economy	25700.00
0005433524919	32467	Economy	25700.00
0005433527227	32467	Economy	25700.00
0005433527232	32467	Economy	25700.00
0005433524936	32467	Economy	25700.00
0005433527228	32467	Economy	25700.00
0005433524947	32467	Economy	25700.00
0005433524930	32467	Economy	25700.00
0005433527231	32467	Economy	25700.00
0005432927985	32467	Economy	25700.00
0005433524976	32467	Economy	25700.00
0005432927987	32467	Economy	25700.00
0005433524954	32467	Economy	25700.00
0005433524931	32467	Economy	25700.00
0005433531279	32467	Economy	25700.00
0005433527206	32467	Economy	25700.00
0005432927983	32467	Economy	25700.00
0005432927986	32467	Economy	25700.00
0005433524940	32467	Economy	25700.00
0005433524985	32467	Economy	25700.00
0005433527233	32467	Economy	25700.00
0005433527205	32467	Economy	25700.00
0005434823530	5268	Business	84000.00
0005432121328	5268	Business	84000.00
0005434823605	5268	Business	84000.00
0005435372636	5268	Business	84000.00
0005435372616	5268	Business	84000.00
0005435372635	5268	Business	84000.00
0005434823544	5268	Business	84000.00
0005434823596	5268	Business	84000.00
0005434823523	5268	Business	84000.00
0005434823623	5268	Business	84000.00
0005434558272	5268	Business	84000.00
0005432396242	5268	Business	84000.00
0005434823594	5268	Business	84000.00
0005434823597	5268	Business	84000.00
0005434823554	5268	Business	84000.00
0005434823521	5268	Business	84000.00
0005435372959	5268	Business	84000.00
0005435372682	5268	Business	84000.00
0005435372652	5268	Business	84000.00
0005435735105	5268	Business	84000.00
0005434823536	5268	Business	84000.00
0005435386517	5268	Business	84000.00
0005434823646	5268	Business	84000.00
0005434823569	5268	Business	84000.00
0005435372658	5268	Business	84000.00
0005434823581	5268	Comfort	47600.00
0005434823542	5268	Comfort	47600.00
0005434664959	5268	Comfort	47600.00
0005435735106	5268	Comfort	47600.00
0005435299742	5268	Comfort	47600.00
0005432121333	5268	Comfort	47600.00
0005434823572	5268	Comfort	47600.00
0005434823616	5268	Comfort	47600.00
0005434823634	5268	Comfort	47600.00
0005434558279	5268	Comfort	47600.00
0005434558275	5268	Comfort	47600.00
0005435372678	5268	Comfort	47600.00
0005434831146	5268	Comfort	47600.00
0005434823528	5268	Comfort	47600.00
0005434823524	5268	Comfort	47600.00
0005435372486	5268	Comfort	47600.00
0005435372707	5268	Comfort	47600.00
0005435386533	5268	Comfort	47600.00
0005434831150	5268	Comfort	47600.00
0005434823540	5268	Comfort	47600.00
0005432121331	5268	Comfort	47600.00
0005434558271	5268	Comfort	47600.00
0005434823621	5268	Comfort	47600.00
0005434823580	5268	Comfort	47600.00
0005434823631	5268	Comfort	47600.00
0005435372408	5268	Comfort	47600.00
0005435372708	5268	Comfort	47600.00
0005435372954	5268	Comfort	47600.00
0005435372706	5268	Comfort	47600.00
0005434558280	5268	Comfort	47600.00
0005432121334	5268	Comfort	47600.00
0005434823615	5268	Comfort	47600.00
0005434823552	5268	Comfort	47600.00
0005435372679	5268	Comfort	47600.00
0005434823617	5268	Comfort	47600.00
0005435735085	5268	Comfort	47600.00
0005434823527	5268	Comfort	47600.00
0005435150022	5268	Economy	28000.00
0005435372495	5268	Economy	28000.00
0005434823598	5268	Economy	28000.00
0005435372402	5268	Economy	28000.00
0005435372641	5268	Economy	28000.00
0005434823547	5268	Economy	28000.00
0005434823604	5268	Economy	28000.00
0005434823532	5268	Economy	28000.00
0005434823585	5268	Economy	28000.00
0005434823574	5268	Economy	28000.00
0005434823591	5268	Economy	28000.00
0005435661912	5268	Economy	28000.00
0005434823576	5268	Economy	28000.00
0005434823556	5268	Economy	28000.00
0005432121341	5268	Economy	28000.00
0005434823575	5268	Economy	28000.00
0005435299719	5268	Economy	28000.00
0005435372681	5268	Economy	28000.00
0005435372716	5268	Economy	28000.00
0005435372946	5268	Economy	28000.00
0005435150028	5268	Economy	28000.00
0005435150025	5268	Economy	28000.00
0005434831145	5268	Economy	28000.00
0005434823564	5268	Economy	28000.00
0005434823582	5268	Economy	28000.00
0005434823601	5268	Economy	28000.00
0005434558278	5268	Economy	28000.00
0005434823628	5268	Economy	28000.00
0005432396243	5268	Economy	28000.00
0005434664957	5268	Economy	28000.00
0005432121329	5268	Economy	28000.00
0005432394106	5268	Economy	28000.00
0005434823567	5268	Economy	28000.00
0005434823630	5268	Economy	28000.00
0005434664958	5268	Economy	28000.00
0005434823640	5268	Economy	28000.00
0005434823609	5268	Economy	28000.00
0005435150029	5268	Economy	28000.00
0005434823636	5268	Economy	28000.00
0005434558276	5268	Economy	28000.00
0005435179690	5268	Economy	28000.00
0005435372811	5268	Economy	28000.00
0005432394102	5268	Economy	28000.00
0005434823537	5268	Economy	28000.00
0005435661905	5268	Economy	28000.00
0005435372846	5268	Economy	30800.00
0005435386542	5268	Economy	28000.00
0005435372657	5268	Economy	30800.00
0005435150036	5268	Economy	28000.00
0005434823562	5268	Economy	28000.00
0005435386525	5268	Economy	28000.00
0005434823543	5268	Economy	30800.00
0005435372564	5268	Economy	30800.00
0005435372403	5268	Economy	30800.00
0005435304137	5268	Economy	28000.00
0005434823553	5268	Economy	28000.00
0005434823625	5268	Economy	28000.00
0005434823608	5268	Economy	28000.00
0005435372824	5268	Economy	28000.00
0005434823622	5268	Economy	28000.00
0005435372596	5268	Economy	28000.00
0005432394103	5268	Economy	28000.00
0005434823612	5268	Economy	28000.00
0005434823526	5268	Economy	28000.00
0005434823561	5268	Economy	28000.00
0005432394104	5268	Economy	28000.00
0005434823635	5268	Economy	28000.00
0005434823578	5268	Economy	28000.00
0005432121335	5268	Economy	28000.00
0005434823558	5268	Economy	28000.00
0005435372680	5268	Economy	28000.00
0005435661910	5268	Economy	28000.00
0005434823538	5268	Economy	28000.00
0005434823570	5268	Economy	28000.00
0005434823560	5268	Economy	28000.00
0005434831147	5268	Economy	28000.00
0005434823535	5268	Economy	28000.00
0005434823620	5268	Economy	28000.00
0005435372787	5268	Economy	28000.00
0005434823533	5268	Economy	28000.00
0005432121332	5268	Economy	28000.00
0005434823555	5268	Economy	28000.00
0005435150024	5268	Economy	28000.00
0005434823619	5268	Economy	28000.00
0005435372801	5268	Economy	28000.00
0005435299740	5268	Economy	28000.00
0005434558268	5268	Economy	28000.00
0005434823603	5268	Economy	28000.00
0005435372651	5268	Economy	28000.00
0005435372826	5268	Economy	28000.00
0005434823638	5268	Economy	28000.00
0005435372847	5268	Economy	28000.00
0005435372848	5268	Economy	28000.00
0005435299725	5268	Economy	28000.00
0005434823548	5268	Economy	28000.00
0005434823559	5268	Economy	28000.00
0005434823626	5268	Economy	28000.00
0005434823593	5268	Economy	28000.00
0005434823549	5268	Economy	28000.00
0005434823607	5268	Economy	28000.00
0005434823529	5268	Economy	28000.00
0005434823557	5268	Economy	28000.00
0005434823600	5268	Economy	28000.00
0005435372684	5268	Economy	28000.00
0005434823587	5268	Economy	28000.00
0005434828694	5268	Economy	28000.00
0005434823534	5268	Economy	28000.00
0005435661911	5268	Economy	28000.00
0005435372638	5268	Economy	28000.00
0005434823595	5268	Economy	28000.00
0005434558277	5268	Economy	28000.00
0005434823577	5268	Economy	28000.00
0005435299718	5268	Economy	28000.00
0005434823610	5268	Economy	28000.00
0005435372765	5268	Economy	28000.00
0005434823645	5268	Economy	28000.00
0005434823647	5268	Economy	28000.00
0005434823629	5268	Economy	28000.00
0005435372951	5268	Economy	28000.00
0005434823644	5268	Economy	28000.00
0005434823637	5268	Economy	28000.00
0005435386516	5268	Economy	28000.00
0005435735084	5268	Economy	28000.00
0005435372750	5268	Economy	28000.00
0005435372531	5268	Economy	28000.00
0005434823539	5268	Economy	28000.00
0005435150023	5268	Economy	28000.00
0005435386530	5268	Economy	28000.00
0005434823632	5268	Economy	28000.00
0005434823589	5268	Economy	28000.00
0005432121337	5268	Economy	28000.00
0005434823571	5268	Economy	28000.00
0005434823613	5268	Economy	28000.00
0005435372392	5268	Economy	28000.00
0005434828695	5268	Economy	30800.00
0005434823565	5268	Economy	28000.00
0005434823592	5268	Economy	30800.00
0005434823599	5268	Economy	30800.00
0005434823590	5268	Economy	30800.00
0005434823602	5268	Economy	28000.00
0005432394105	5268	Economy	28000.00
0005435372557	5268	Economy	28000.00
0005432121330	5268	Economy	28000.00
0005434823627	5268	Economy	28000.00
0005435372734	5268	Economy	28000.00
0005434823563	5268	Economy	28000.00
0005435386527	5268	Economy	28000.00
0005435150027	5268	Economy	28000.00
0005435372528	5268	Economy	28000.00
0005434823546	5268	Economy	28000.00
0005435372494	5268	Economy	28000.00
0005435386528	5268	Economy	28000.00
0005435735096	5268	Economy	28000.00
0005434831148	5268	Economy	28000.00
0005435150032	5268	Economy	28000.00
0005435386545	5268	Economy	28000.00
0005434823643	5268	Economy	28000.00
0005432121340	5268	Economy	28000.00
0005435386485	5268	Economy	28000.00
0005434823541	5268	Economy	28000.00
0005435735088	5268	Economy	28000.00
0005434558270	5268	Economy	28000.00
0005435150034	5268	Economy	28000.00
0005434823550	5268	Economy	28000.00
0005435299741	5268	Economy	28000.00
0005434823642	5268	Economy	28000.00
0005432121327	5268	Economy	28000.00
0005435372762	5268	Economy	28000.00
0005434823545	5268	Economy	28000.00
0005435372184	5268	Economy	28000.00
0005435372786	5268	Economy	28000.00
0005434831144	5268	Economy	28000.00
0005434823551	5268	Economy	28000.00
0005434823624	5268	Economy	28000.00
0005434823522	5268	Economy	28000.00
0005434823584	5268	Economy	28000.00
0005434823611	5268	Economy	28000.00
0005435372523	5268	Economy	28000.00
0005434558273	5268	Economy	28000.00
0005432121338	5268	Economy	28000.00
0005435372785	5268	Economy	28000.00
0005435372336	5268	Economy	28000.00
0005435372583	5268	Economy	28000.00
0005432121339	5268	Economy	28000.00
0005434823639	5268	Economy	28000.00
0005434558274	5268	Economy	28000.00
0005435304133	5268	Economy	28000.00
0005435372825	5268	Economy	28000.00
0005432396244	5268	Economy	28000.00
0005435150030	5268	Economy	28000.00
0005435372749	5268	Economy	28000.00
0005435304138	5268	Economy	28000.00
0005434558269	5268	Economy	28000.00
0005434823606	5268	Economy	28000.00
0005434823531	5268	Economy	28000.00
0005435150033	5268	Economy	28000.00
0005434823583	5268	Economy	28000.00
0005434823633	5268	Economy	28000.00
0005434823568	5268	Economy	28000.00
0005434823579	5268	Economy	28000.00
0005435372393	5268	Economy	28000.00
0005435372183	5268	Economy	28000.00
0005434823520	5268	Economy	28000.00
0005435372667	5268	Economy	28000.00
0005434823525	5268	Economy	28000.00
0005435735089	5268	Economy	28000.00
0005435150031	5268	Economy	28000.00
0005435150026	5268	Economy	28000.00
0005432121336	5268	Economy	28000.00
0005435372885	5268	Economy	28000.00
0005435372945	5268	Economy	28000.00
0005435372690	5268	Economy	28000.00
0005435372696	5268	Economy	28000.00
0005434823614	5268	Economy	28000.00
0005435372955	5268	Economy	28000.00
0005434823566	5268	Economy	28000.00
0005434823618	5268	Economy	28000.00
0005434831149	5268	Economy	28000.00
0005434823586	5268	Economy	28000.00
0005434823588	5268	Economy	28000.00
0005435150035	5268	Economy	28000.00
0005435372637	5268	Economy	28000.00
0005434823573	5268	Economy	28000.00
0005434823641	5268	Economy	28000.00
0005435373257	9927	Business	84000.00
0005435373252	9927	Business	84000.00
0005434822840	9927	Business	84000.00
0005434822924	9927	Business	84000.00
0005434822832	9927	Business	84000.00
0005432203062	9927	Business	84000.00
0005435299774	9927	Business	84000.00
0005434822798	9927	Business	84000.00
0005434822340	9927	Business	84000.00
0005434822410	9927	Business	84000.00
0005435179394	9927	Business	84000.00
0005434558181	9927	Business	84000.00
0005434822619	9927	Business	84000.00
0005434822557	9927	Business	84000.00
0005435373245	9927	Business	84000.00
0005434831123	9927	Business	84000.00
0005434822603	9927	Business	84000.00
0005434822261	9927	Business	84000.00
0005435149899	9927	Business	84000.00
0005435373231	9927	Business	84000.00
0005434822380	9927	Business	84000.00
0005435302196	9927	Comfort	47600.00
0005435373237	9927	Comfort	47600.00
0005435373229	9927	Comfort	47600.00
0005434822653	9927	Comfort	47600.00
0005434821882	9927	Comfort	47600.00
0005434828669	9927	Comfort	47600.00
0005434822431	9927	Comfort	47600.00
0005434558168	9927	Comfort	47600.00
0005434822627	9927	Comfort	47600.00
0005434558193	9927	Comfort	47600.00
0005435299775	9927	Comfort	47600.00
0005435149891	9927	Comfort	47600.00
0005434822607	9927	Comfort	47600.00
0005434822723	9927	Comfort	47600.00
0005435373255	9927	Comfort	47600.00
0005435373288	9927	Comfort	47600.00
0005435149922	9927	Comfort	47600.00
0005434822815	9927	Comfort	47600.00
0005434822359	9927	Comfort	47600.00
0005434831102	9927	Comfort	47600.00
0005435373282	9927	Comfort	47600.00
0005435373253	9927	Comfort	47600.00
0005435373263	9927	Comfort	47600.00
0005434822075	9927	Comfort	47600.00
0005434558188	9927	Comfort	47600.00
0005434822432	9927	Comfort	47600.00
0005434558190	9927	Comfort	47600.00
0005434822556	9927	Comfort	47600.00
0005435373247	9927	Comfort	47600.00
0005434822664	9927	Economy	28000.00
0005434822524	9927	Comfort	47600.00
0005435373250	9927	Economy	28000.00
0005435373260	9927	Economy	28000.00
0005435373292	9927	Economy	28000.00
0005434822833	9927	Economy	28000.00
0005432396207	9927	Economy	28000.00
0005434822310	9927	Economy	28000.00
0005435373291	9927	Economy	28000.00
0005434822933	9927	Economy	28000.00
0005434822583	9927	Economy	28000.00
0005435373293	9927	Economy	28000.00
0005434822816	9927	Economy	28000.00
0005435373243	9927	Economy	28000.00
0005434558169	9927	Economy	28000.00
0005434822665	9927	Economy	28000.00
0005435149798	9927	Economy	28000.00
0005434822148	9927	Economy	28000.00
0005434822269	9927	Economy	28000.00
0005434822252	9927	Economy	28000.00
0005434822369	9927	Economy	28000.00
0005434822677	9927	Economy	28000.00
0005432203065	9927	Economy	28000.00
0005434823058	9927	Economy	28000.00
0005434822338	9927	Economy	28000.00
0005434822626	9927	Economy	28000.00
0005435735139	9927	Economy	28000.00
0005434822368	9927	Economy	28000.00
0005434822671	9927	Economy	28000.00
0005435179393	9927	Economy	28000.00
0005434822422	9927	Economy	28000.00
0005434822341	9927	Economy	28000.00
0005434822065	9927	Economy	28000.00
0005434558194	9927	Economy	28000.00
0005434822727	9927	Economy	28000.00
0005434822382	9927	Economy	28000.00
0005435373274	9927	Economy	28000.00
0005434822043	9927	Economy	28000.00
0005432396222	9927	Economy	28000.00
0005435373277	9927	Economy	28000.00
0005434822625	9927	Economy	28000.00
0005434822348	9927	Economy	28000.00
0005434822817	9927	Economy	28000.00
0005432400103	9927	Economy	28000.00
0005434822452	9927	Economy	28000.00
0005435373259	9927	Economy	28000.00
0005434822116	9927	Economy	28000.00
0005434831121	9927	Economy	28000.00
0005435661931	9927	Economy	28000.00
0005434822161	9927	Economy	28000.00
0005435149904	9927	Economy	28000.00
0005435373266	9927	Economy	28000.00
0005435373261	9927	Economy	28000.00
0005434822887	9927	Economy	28000.00
0005434821963	9927	Economy	28000.00
0005434558189	9927	Economy	28000.00
0005434822512	9927	Economy	28000.00
0005434822189	9927	Economy	28000.00
0005432823450	9927	Economy	30800.00
0005435373246	9927	Economy	30800.00
0005434828664	9927	Economy	30800.00
0005434822608	9927	Economy	28000.00
0005435373280	9927	Economy	28000.00
0005435373267	9927	Economy	28000.00
0005435373228	9927	Economy	30800.00
0005435149843	9927	Economy	30800.00
0005435149905	9927	Economy	30800.00
0005435373281	9927	Economy	28000.00
0005435373268	9927	Economy	28000.00
0005435302197	9927	Economy	28000.00
0005435373278	9927	Economy	28000.00
0005434822578	9927	Economy	28000.00
0005435149917	9927	Economy	28000.00
0005434822722	9927	Economy	28000.00
0005434822575	9927	Economy	28000.00
0005435373272	9927	Economy	28000.00
0005434822726	9927	Economy	28000.00
0005434822262	9927	Economy	28000.00
0005435373265	9927	Economy	28000.00
0005435302199	9927	Economy	28000.00
0005435735140	9927	Economy	28000.00
0005435299777	9927	Economy	28000.00
0005434822624	9927	Economy	28000.00
0005435149857	9927	Economy	28000.00
0005435373240	9927	Economy	28000.00
0005434822162	9927	Economy	28000.00
0005435373264	9927	Economy	28000.00
0005434831094	9927	Economy	28000.00
0005434822416	9927	Economy	28000.00
0005435373248	9927	Economy	28000.00
0005434822420	9927	Economy	28000.00
0005434822912	9927	Economy	28000.00
0005434821934	9927	Economy	28000.00
0005435149895	9927	Economy	28000.00
0005434822395	9927	Economy	28000.00
0005435373230	9927	Economy	28000.00
0005435179693	9927	Economy	28000.00
0005434822423	9927	Economy	28000.00
0005434822773	9927	Economy	28000.00
0005432203061	9927	Economy	28000.00
0005435149907	9927	Economy	28000.00
0005435373276	9927	Economy	28000.00
0005435302195	9927	Economy	28000.00
0005435373262	9927	Economy	28000.00
0005432203060	9927	Economy	28000.00
0005435149908	9927	Economy	28000.00
0005435373289	9927	Economy	28000.00
0005434822208	9927	Economy	28000.00
0005434822210	9927	Economy	28000.00
0005434822339	9927	Economy	28000.00
0005434822654	9927	Economy	28000.00
0005434822142	9927	Economy	28000.00
0005434821893	9927	Economy	28000.00
0005434828663	9927	Economy	28000.00
0005435373234	9927	Economy	28000.00
0005435373236	9927	Economy	28000.00
0005434822799	9927	Economy	28000.00
0005435149856	9927	Economy	28000.00
0005434822384	9927	Economy	28000.00
0005434822548	9927	Economy	28000.00
0005434558195	9927	Economy	28000.00
0005432203067	9927	Economy	28000.00
0005434822394	9927	Economy	28000.00
0005435373275	9927	Economy	28000.00
0005432396210	9927	Economy	28000.00
0005434558204	9927	Economy	28000.00
0005434822997	9927	Economy	28000.00
0005435373251	9927	Economy	28000.00
0005435373258	9927	Economy	28000.00
0005435373271	9927	Economy	28000.00
0005435179694	9927	Economy	28000.00
0005435302198	9927	Economy	28000.00
0005434822298	9927	Economy	28000.00
0005435373242	9927	Economy	28000.00
0005434822381	9927	Economy	28000.00
0005435149799	9927	Economy	28000.00
0005435373249	9927	Economy	30800.00
0005434828678	9927	Economy	28000.00
0005434822455	9927	Economy	28000.00
0005435149898	9927	Economy	28000.00
0005434822251	9927	Economy	28000.00
0005434558180	9927	Economy	28000.00
0005434822632	9927	Economy	28000.00
0005434822492	9927	Economy	28000.00
0005435373283	9927	Economy	28000.00
0005435179695	9927	Economy	28000.00
0005434821969	9927	Economy	28000.00
0005435302200	9927	Economy	28000.00
0005434822642	9927	Economy	28000.00
0005435299776	9927	Economy	28000.00
0005435373238	9927	Economy	28000.00
0005434828682	9927	Economy	28000.00
0005434822513	9927	Economy	28000.00
0005435373235	9927	Economy	28000.00
0005435373285	9927	Economy	28000.00
0005435373269	9927	Economy	28000.00
0005432823451	9927	Economy	28000.00
0005434831122	9927	Economy	28000.00
0005434822819	9927	Economy	28000.00
0005434822444	9927	Economy	28000.00
0005435373233	9927	Economy	28000.00
0005435373239	9927	Economy	28000.00
0005435373273	9927	Economy	28000.00
0005435373284	9927	Economy	28000.00
0005434822820	9927	Economy	28000.00
0005434822762	9927	Economy	28000.00
0005434822618	9927	Economy	28000.00
0005434822150	9927	Economy	28000.00
0005435373287	9927	Economy	28000.00
0005434558196	9927	Economy	28000.00
0005434822858	9927	Economy	28000.00
0005434822456	9927	Economy	28000.00
0005434822118	9927	Economy	28000.00
0005435373270	9927	Economy	28000.00
0005434821844	9927	Economy	28000.00
0005435735137	9927	Economy	28000.00
0005434822383	9927	Economy	28000.00
0005432203064	9927	Economy	28000.00
0005434822894	9927	Economy	28000.00
0005435373279	9927	Economy	28000.00
0005434822060	9927	Economy	28000.00
0005434822409	9927	Economy	28000.00
0005432823452	9927	Economy	28000.00
0005434821968	9927	Economy	28000.00
0005435373244	9927	Economy	28000.00
0005435373254	9927	Economy	28000.00
0005434822518	9927	Economy	28000.00
0005435735138	9927	Economy	28000.00
0005434822834	9927	Economy	28000.00
0005435373290	9927	Economy	28000.00
0005434822611	9927	Economy	28000.00
0005432203066	9927	Economy	28000.00
0005434822818	9927	Economy	28000.00
0005434822746	9927	Economy	28000.00
0005434823143	9927	Economy	28000.00
0005434822605	9927	Economy	28000.00
0005434831115	9927	Economy	28000.00
0005434822631	9927	Economy	28000.00
0005435373256	9927	Economy	28000.00
0005435149903	9927	Economy	28000.00
0005434822630	9927	Economy	28000.00
0005432400101	9927	Economy	28000.00
0005435373232	9927	Economy	28000.00
0005434828677	9927	Economy	28000.00
0005435149923	9927	Economy	28000.00
0005434822893	9927	Economy	28000.00
0005434822579	9927	Economy	28000.00
0005434822453	9927	Economy	28000.00
0005434822260	9927	Economy	28000.00
0005435373286	9927	Economy	28000.00
0005432400102	9927	Economy	28000.00
0005434822859	9927	Economy	28000.00
0005434558192	9927	Economy	28000.00
0005434822454	9927	Economy	28000.00
0005435661932	9927	Economy	28000.00
0005432203063	9927	Economy	28000.00
0005435373241	9927	Economy	28000.00
0005435302201	9927	Economy	28000.00
0005435790306	7021	Economy	7400.00
0005435790305	7021	Economy	7400.00
0005435082785	7021	Economy	7400.00
0005435082787	7021	Economy	7400.00
0005435790307	7021	Economy	7400.00
0005435082786	7021	Economy	7400.00
0005435082784	7021	Economy	7400.00
0005435082718	25985	Economy	8200.00
0005435082687	25985	Economy	7400.00
0005435082712	25985	Economy	7400.00
0005435082713	25985	Economy	7400.00
0005435790291	25985	Economy	7400.00
0005435082711	25985	Economy	7400.00
0005435082772	25985	Economy	7400.00
0005435790290	25985	Economy	7400.00
0005435790289	25985	Economy	7400.00
0005434756417	9550	Business	32800.00
0005434756426	9550	Business	32800.00
0005434756435	9550	Business	32800.00
0005434756438	9550	Business	32800.00
0005434756442	9550	Business	32800.00
0005434213911	9550	Business	32800.00
0005434756425	9550	Business	32800.00
0005434214259	9550	Business	32800.00
0005434214133	9550	Business	32800.00
0005434756408	9550	Business	32800.00
0005434756429	9550	Economy	10900.00
0005434756412	9550	Economy	10900.00
0005434756415	9550	Economy	10900.00
0005434756434	9550	Economy	10900.00
0005434213980	9550	Economy	10900.00
0005434214110	9550	Economy	10900.00
0005434756416	9550	Economy	12000.00
0005434756445	9550	Economy	12000.00
0005434756439	9550	Economy	12000.00
0005434214275	9550	Economy	12000.00
0005434756430	9550	Economy	12000.00
0005434214051	9550	Economy	10900.00
0005434756436	9550	Economy	10900.00
0005434756423	9550	Economy	10900.00
0005434756410	9550	Economy	10900.00
0005434214173	9550	Economy	10900.00
0005434213938	9550	Economy	10900.00
0005434756419	9550	Economy	10900.00
0005434214229	9550	Economy	10900.00
0005434756413	9550	Economy	10900.00
0005434756432	9550	Economy	10900.00
0005434214078	9550	Economy	10900.00
0005434214162	9550	Economy	10900.00
0005434213960	9550	Economy	10900.00
0005434756437	9550	Economy	10900.00
0005434214178	9550	Economy	10900.00
0005434214060	9550	Economy	10900.00
0005434213946	9550	Economy	10900.00
0005434756427	9550	Economy	10900.00
0005434214131	9550	Economy	10900.00
0005434756440	9550	Economy	10900.00
0005434214073	9550	Economy	10900.00
0005434756424	9550	Economy	10900.00
0005434756422	9550	Economy	10900.00
0005434756421	9550	Economy	10900.00
0005434214050	9550	Economy	10900.00
0005434214156	9550	Economy	10900.00
0005434214158	9550	Economy	10900.00
0005434214092	9550	Economy	10900.00
0005434213947	9550	Economy	10900.00
0005434214161	9550	Economy	10900.00
0005434213835	9550	Economy	10900.00
0005434213897	9550	Economy	10900.00
0005434214062	9550	Economy	10900.00
0005434214287	9550	Economy	10900.00
0005434214172	9550	Economy	10900.00
0005434213876	9550	Economy	10900.00
0005434214038	9550	Economy	10900.00
0005434756418	9550	Economy	10900.00
0005434213850	9550	Economy	10900.00
0005434214039	9550	Economy	10900.00
0005434756414	9550	Economy	10900.00
0005434214002	9550	Economy	10900.00
0005434214139	9550	Economy	10900.00
0005434756433	9550	Economy	10900.00
0005434756441	9550	Economy	10900.00
0005434213849	9550	Economy	10900.00
0005434214083	9550	Economy	10900.00
0005434756443	9550	Economy	10900.00
0005434214202	9550	Economy	10900.00
0005434214093	9550	Economy	10900.00
0005434214132	9550	Economy	10900.00
0005434756428	9550	Economy	10900.00
0005434756431	9550	Economy	10900.00
0005434214157	9550	Economy	10900.00
0005434214226	9550	Economy	10900.00
0005434214203	9550	Economy	10900.00
0005434214264	9550	Economy	10900.00
0005434214052	9550	Economy	10900.00
0005434756444	9550	Economy	10900.00
0005434756409	9550	Economy	10900.00
0005434214011	9550	Economy	10900.00
0005434756420	9550	Economy	10900.00
0005434214001	9550	Economy	10900.00
0005434756411	9550	Economy	10900.00
0005434214495	28598	Business	32800.00
0005434214503	28598	Business	32800.00
0005434214506	28598	Business	32800.00
0005434214484	28598	Business	32800.00
0005434214476	28598	Business	32800.00
0005434214467	28598	Business	32800.00
0005434755895	28598	Business	32800.00
0005434755888	28598	Business	32800.00
0005434756008	28598	Business	32800.00
0005434755933	28598	Business	32800.00
0005434214497	28598	Business	32800.00
0005434214486	28598	Business	32800.00
0005434755971	28598	Economy	10900.00
0005434214504	28598	Economy	10900.00
0005434756013	28598	Economy	10900.00
0005434214500	28598	Economy	10900.00
0005434755834	28598	Economy	10900.00
0005434756031	28598	Economy	10900.00
0005434214461	28598	Economy	10900.00
0005434755833	28598	Economy	10900.00
0005434755969	28598	Economy	10900.00
0005434756032	28598	Economy	12000.00
0005434214482	28598	Economy	12000.00
0005434755894	28598	Economy	12000.00
0005434755836	28598	Economy	12000.00
0005434214507	28598	Economy	12000.00
0005434214501	28598	Economy	10900.00
0005434756060	28598	Economy	10900.00
0005434214494	28598	Economy	10900.00
0005434755970	28598	Economy	10900.00
0005434214485	28598	Economy	10900.00
0005434756072	28598	Economy	10900.00
0005434214463	28598	Economy	10900.00
0005434214491	28598	Economy	10900.00
0005434756000	28598	Economy	10900.00
0005434755882	28598	Economy	10900.00
0005434214505	28598	Economy	10900.00
0005434756040	28598	Economy	10900.00
0005434214465	28598	Economy	10900.00
0005434755814	28598	Economy	10900.00
0005434755972	28598	Economy	10900.00
0005434755781	28598	Economy	10900.00
0005434214475	28598	Economy	10900.00
0005434214481	28598	Economy	10900.00
0005434214474	28598	Economy	10900.00
0005434214480	28598	Economy	10900.00
0005434214477	28598	Economy	10900.00
0005434755992	28598	Economy	10900.00
0005434214479	28598	Economy	10900.00
0005434756061	28598	Economy	10900.00
0005434755923	28598	Economy	10900.00
0005434214470	28598	Economy	10900.00
0005434755983	28598	Economy	10900.00
0005434756075	28598	Economy	10900.00
0005434214488	28598	Economy	10900.00
0005434756076	28598	Economy	10900.00
0005434214499	28598	Economy	10900.00
0005434755900	28598	Economy	10900.00
0005434214469	28598	Economy	10900.00
0005434214466	28598	Economy	10900.00
0005434214498	28598	Economy	10900.00
0005434755979	28598	Economy	10900.00
0005434756065	28598	Economy	10900.00
0005434214468	28598	Economy	10900.00
0005434755896	28598	Economy	10900.00
0005434214464	28598	Economy	10900.00
0005434214492	28598	Economy	10900.00
0005434756059	28598	Economy	10900.00
0005434214478	28598	Economy	10900.00
0005434755932	28598	Economy	10900.00
0005434214460	28598	Economy	10900.00
0005434214462	28598	Economy	10900.00
0005434214473	28598	Economy	10900.00
0005434214471	28598	Economy	10900.00
0005434214483	28598	Economy	10900.00
0005434755893	28598	Economy	10900.00
0005434755924	28598	Economy	10900.00
0005434214490	28598	Economy	10900.00
0005434214496	28598	Economy	10900.00
0005434214502	28598	Economy	10900.00
0005434755934	28598	Economy	10900.00
0005434756064	28598	Economy	10900.00
0005434214487	28598	Economy	10900.00
0005434755813	28598	Economy	10900.00
0005434755786	28598	Economy	10900.00
0005434214489	28598	Economy	10900.00
0005434214493	28598	Economy	10900.00
0005434755889	28598	Economy	10900.00
0005434755978	28598	Economy	10900.00
0005434214472	28598	Economy	10900.00
0005434214459	28598	Economy	10900.00
0005435100123	10858	Economy	8900.00
0005434760176	10858	Economy	8900.00
0005435100121	10858	Economy	8900.00
0005435100125	10858	Economy	8900.00
0005435100122	10858	Economy	8900.00
0005435100124	10858	Economy	8900.00
0005435100105	31799	Economy	8900.00
0005435100103	31799	Economy	8900.00
0005434760199	31799	Economy	8900.00
0005435100104	31799	Economy	8900.00
0005435100099	31799	Economy	8900.00
0005434760198	31799	Economy	8900.00
0005434760197	31799	Economy	8900.00
0005433202241	1959	Economy	20900.00
0005433202231	1959	Economy	20900.00
0005434639319	1959	Economy	20900.00
0005434639316	1959	Economy	19000.00
0005434639330	1959	Economy	19000.00
0005434639320	1959	Economy	19000.00
0005434639314	1959	Economy	19000.00
0005434639312	1959	Economy	19000.00
0005433202282	1959	Economy	19000.00
0005433202230	1959	Economy	19000.00
0005434639332	1959	Economy	19000.00
0005433202232	1959	Economy	19000.00
0005434639329	1959	Economy	19000.00
0005434639311	1959	Economy	19000.00
0005434639315	1959	Economy	19000.00
0005434639318	1959	Economy	19000.00
0005434639337	1959	Economy	19000.00
0005435948328	1959	Economy	19000.00
0005434639313	1959	Economy	19000.00
0005434639325	1959	Economy	19000.00
0005434639336	1959	Economy	19000.00
0005432290634	1959	Economy	19000.00
0005433202228	1959	Economy	19000.00
0005433202185	1959	Economy	19000.00
0005434639326	1959	Economy	19000.00
0005433202184	1959	Economy	19000.00
0005434639310	1959	Economy	19000.00
0005434639331	1959	Economy	19000.00
0005434639321	1959	Economy	19000.00
0005434639317	1959	Economy	19000.00
0005434639334	1959	Economy	19000.00
0005435948327	1959	Economy	19000.00
0005434639324	1959	Economy	19000.00
0005434639322	1959	Economy	19000.00
0005434639323	1959	Economy	19000.00
0005434639335	1959	Economy	19000.00
0005432290633	1959	Economy	19000.00
0005434639328	1959	Economy	19000.00
0005434639327	1959	Economy	19000.00
0005434639333	1959	Economy	19000.00
0005434639338	1959	Economy	19000.00
0005433202198	1959	Economy	19000.00
0005434638999	23263	Economy	20900.00
0005434639043	23263	Economy	20900.00
0005433202352	23263	Economy	20900.00
0005434638890	23263	Economy	20900.00
0005434639151	23263	Economy	19000.00
0005434639133	23263	Economy	19000.00
0005434639150	23263	Economy	19000.00
0005434639041	23263	Economy	19000.00
0005434639006	23263	Economy	19000.00
0005434639085	23263	Economy	19000.00
0005434638973	23263	Economy	19000.00
0005434638955	23263	Economy	19000.00
0005434639050	23263	Economy	19000.00
0005434638974	23263	Economy	19000.00
0005434639002	23263	Economy	19000.00
0005433202353	23263	Economy	19000.00
0005434639161	23263	Economy	19000.00
0005435948311	23263	Economy	19000.00
0005434638972	23263	Economy	19000.00
0005433202343	23263	Economy	19000.00
0005434639160	23263	Economy	19000.00
0005433202357	23263	Economy	19000.00
0005434639048	23263	Economy	19000.00
0005434639042	23263	Economy	19000.00
0005434638941	23263	Economy	19000.00
0005433202355	23263	Economy	19000.00
0005434638906	23263	Economy	19000.00
0005433202349	23263	Economy	19000.00
0005434639182	23263	Economy	19000.00
0005434638994	23263	Economy	19000.00
0005433202345	23263	Economy	19000.00
0005433202354	23263	Economy	19000.00
0005433202344	23263	Economy	19000.00
0005433202347	23263	Economy	19000.00
0005433202350	23263	Economy	19000.00
0005433202346	23263	Economy	19000.00
0005433202348	23263	Economy	19000.00
0005433202356	23263	Economy	19000.00
0005434639009	23263	Economy	19000.00
0005433202351	23263	Economy	19000.00
0005433531294	6083	Business	69700.00
0005433533309	6083	Business	69700.00
0005434600798	6083	Business	69700.00
0005433531291	6083	Business	69700.00
0005434600796	6083	Business	69700.00
0005434600800	6083	Business	69700.00
0005434600808	6083	Business	69700.00
0005435326586	6083	Business	69700.00
0005433533307	6083	Economy	23200.00
0005434600805	6083	Economy	23200.00
0005434600818	6083	Economy	23200.00
0005433531292	6083	Economy	23200.00
0005434600807	6083	Economy	23200.00
0005434600814	6083	Economy	23200.00
0005435326588	6083	Economy	25600.00
0005434600811	6083	Economy	25600.00
0005434600815	6083	Economy	23200.00
0005435326593	6083	Economy	23200.00
0005434600797	6083	Economy	23200.00
0005435326611	6083	Economy	23200.00
0005434600801	6083	Economy	23200.00
0005434600813	6083	Economy	23200.00
0005434600819	6083	Economy	23200.00
0005434600820	6083	Economy	23200.00
0005435326626	6083	Economy	23200.00
0005434600799	6083	Economy	23200.00
0005434600822	6083	Economy	23200.00
0005435326592	6083	Economy	23200.00
0005434600816	6083	Economy	23200.00
0005434600803	6083	Economy	23200.00
0005434600804	6083	Economy	23200.00
0005434600817	6083	Economy	23200.00
0005435326587	6083	Economy	23200.00
0005434600821	6083	Economy	23200.00
0005434600812	6083	Economy	23200.00
0005435326610	6083	Economy	23200.00
0005432111278	6083	Economy	23200.00
0005434600810	6083	Economy	23200.00
0005432111279	6083	Economy	23200.00
0005435326625	6083	Economy	23200.00
0005434600806	6083	Economy	23200.00
0005434600809	6083	Economy	23200.00
0005433533308	6083	Economy	23200.00
0005434600802	6083	Economy	23200.00
0005433531293	6083	Economy	23200.00
0005435326743	18582	Business	69700.00
0005434600654	18582	Business	69700.00
0005434600369	18582	Business	69700.00
0005435326740	18582	Business	69700.00
0005434600368	18582	Economy	23200.00
0005434600469	18582	Economy	23200.00
0005434600676	18582	Economy	23200.00
0005434600331	18582	Economy	23200.00
0005435326746	18582	Economy	23200.00
0005435326750	18582	Economy	23200.00
0005434600598	18582	Economy	25600.00
0005434600540	18582	Economy	25600.00
0005433527215	18582	Economy	23200.00
0005434600594	18582	Economy	23200.00
0005435326748	18582	Economy	23200.00
0005434600649	18582	Economy	23200.00
0005434600589	18582	Economy	23200.00
0005434600669	18582	Economy	23200.00
0005434600597	18582	Economy	23200.00
0005434600593	18582	Economy	23200.00
0005435326738	18582	Economy	23200.00
0005435326745	18582	Economy	23200.00
0005435326749	18582	Economy	23200.00
0005435326741	18582	Economy	23200.00
0005435326742	18582	Economy	23200.00
0005435326739	18582	Economy	23200.00
0005434600700	18582	Economy	23200.00
0005434600639	18582	Economy	23200.00
0005435326744	18582	Economy	23200.00
0005434600468	18582	Economy	23200.00
0005433527234	18582	Economy	23200.00
0005434600644	18582	Economy	23200.00
0005433531257	18582	Economy	23200.00
0005434600677	18582	Economy	23200.00
0005434600600	18582	Economy	23200.00
0005434600570	18582	Economy	23200.00
0005434600599	18582	Economy	23200.00
0005434600590	18582	Economy	23200.00
0005434600648	18582	Economy	23200.00
0005434600699	18582	Economy	23200.00
0005434600569	18582	Economy	23200.00
0005435326747	18582	Economy	23200.00
0005434600515	18582	Economy	23200.00
0005434600592	18582	Economy	23200.00
0005433531266	18582	Economy	23200.00
0005435326751	18582	Economy	23200.00
0005434600585	18582	Economy	23200.00
0005434551184	10593	Business	9100.00
0005433180817	10593	Business	9100.00
0005434551203	10593	Business	9100.00
0005434551162	10593	Business	9100.00
0005434558267	10593	Business	9100.00
0005434551177	10593	Business	9100.00
0005434551190	10593	Business	9100.00
0005434551168	10593	Business	9100.00
0005434558259	10593	Business	9100.00
0005434551185	10593	Business	9100.00
0005433180820	10593	Business	9100.00
0005433180818	10593	Business	9100.00
0005434558261	10593	Economy	3000.00
0005434551206	10593	Economy	3000.00
0005434551183	10593	Economy	3000.00
0005434551173	10593	Economy	3000.00
0005434551174	10593	Economy	3000.00
0005434551193	10593	Economy	3000.00
0005434551178	10593	Economy	3000.00
0005434551176	10593	Economy	3000.00
0005434551166	10593	Economy	3000.00
0005433180911	10593	Economy	3000.00
0005434551186	10593	Economy	3300.00
0005434551167	10593	Economy	3300.00
0005434551194	10593	Economy	3300.00
0005434551157	10593	Economy	3300.00
0005433180835	10593	Economy	3300.00
0005434551197	10593	Economy	3000.00
0005434551202	10593	Economy	3000.00
0005434551182	10593	Economy	3000.00
0005434558263	10593	Economy	3000.00
0005434551181	10593	Economy	3000.00
0005433180834	10593	Economy	3000.00
0005434551175	10593	Economy	3000.00
0005433180784	10593	Economy	3000.00
0005434551161	10593	Economy	3000.00
0005433180883	10593	Economy	3000.00
0005434551192	10593	Economy	3000.00
0005433180912	10593	Economy	3000.00
0005434551169	10593	Economy	3000.00
0005433180836	10593	Economy	3000.00
0005434551172	10593	Economy	3000.00
0005434551171	10593	Economy	3000.00
0005434551189	10593	Economy	3000.00
0005434551209	10593	Economy	3000.00
0005433180804	10593	Economy	3000.00
0005433180886	10593	Economy	3000.00
0005433180837	10593	Economy	3000.00
0005434558265	10593	Economy	3000.00
0005434551188	10593	Economy	3000.00
0005434551210	10593	Economy	3000.00
0005434551179	10593	Economy	3000.00
0005434551199	10593	Economy	3000.00
0005434551198	10593	Economy	3000.00
0005434551211	10593	Economy	3000.00
0005434554064	10593	Economy	3000.00
0005434558264	10593	Economy	3000.00
0005433180893	10593	Economy	3000.00
0005434551207	10593	Economy	3000.00
0005434551170	10593	Economy	3000.00
0005434551159	10593	Economy	3000.00
0005433180819	10593	Economy	3000.00
0005433180788	10593	Economy	3000.00
0005433180773	10593	Economy	3000.00
0005434551164	10593	Economy	3000.00
0005434558258	10593	Economy	3000.00
0005434551208	10593	Economy	3000.00
0005433180841	10593	Economy	3000.00
0005433180894	10593	Economy	3000.00
0005434551200	10593	Economy	3000.00
0005434554065	10593	Economy	3000.00
0005434551205	10593	Economy	3000.00
0005434558262	10593	Economy	3000.00
0005434551158	10593	Economy	3000.00
0005434558260	10593	Economy	3000.00
0005434551204	10593	Economy	3000.00
0005434551163	10593	Economy	3000.00
0005433180840	10593	Economy	3000.00
0005433180829	10593	Economy	3000.00
0005434551180	10593	Economy	3000.00
0005434551201	10593	Economy	3000.00
0005434554063	10593	Economy	3000.00
0005434551156	10593	Economy	3000.00
0005434551187	10593	Economy	3000.00
0005434551196	10593	Economy	3000.00
0005434551165	10593	Economy	3000.00
0005434551191	10593	Economy	3000.00
0005434558266	10593	Economy	3000.00
0005434551160	10593	Economy	3000.00
0005434551195	10593	Economy	3000.00
0005433180799	10593	Economy	3000.00
0005433181087	27724	Business	9100.00
0005433181106	27724	Business	9100.00
0005433181105	27724	Business	9100.00
0005433181111	27724	Economy	3000.00
0005433181094	27724	Economy	3000.00
0005433181103	27724	Economy	3300.00
0005433181096	27724	Economy	3300.00
0005433181088	27724	Economy	3000.00
0005433181098	27724	Economy	3000.00
0005433181100	27724	Economy	3000.00
0005433181099	27724	Economy	3000.00
0005433181097	27724	Economy	3000.00
0005433181090	27724	Economy	3000.00
0005433181101	27724	Economy	3000.00
0005433181095	27724	Economy	3000.00
0005433181093	27724	Economy	3000.00
0005433181108	27724	Economy	3000.00
0005433181107	27724	Economy	3000.00
0005433181089	27724	Economy	3000.00
0005433181091	27724	Economy	3000.00
0005433181112	27724	Economy	3000.00
0005433181110	27724	Economy	3000.00
0005433181104	27724	Economy	3000.00
0005433181092	27724	Economy	3000.00
0005433181102	27724	Economy	3000.00
0005433181109	27724	Economy	3000.00
0005434558210	27725	Business	9100.00
0005434550818	27725	Business	9100.00
0005434550906	27725	Business	9100.00
0005434558201	27725	Business	9100.00
0005434554048	27725	Business	9100.00
0005434550816	27725	Business	9100.00
0005434550841	27725	Business	9100.00
0005434550707	27725	Economy	3000.00
0005434554051	27725	Economy	3000.00
0005434558208	27725	Economy	3000.00
0005434550620	27725	Economy	3000.00
0005434550768	27725	Economy	3000.00
0005434550903	27725	Economy	3000.00
0005434550517	27725	Economy	3000.00
0005434550885	27725	Economy	3300.00
0005434550817	27725	Economy	3300.00
0005434550826	27725	Economy	3000.00
0005434550872	27725	Economy	3000.00
0005434550747	27725	Economy	3000.00
0005434550845	27725	Economy	3000.00
0005434550987	27725	Economy	3000.00
0005434550767	27725	Economy	3000.00
0005434550554	27725	Economy	3000.00
0005434550836	27725	Economy	3000.00
0005434550837	27725	Economy	3000.00
0005434550627	27725	Economy	3000.00
0005434550632	27725	Economy	3000.00
0005434550824	27725	Economy	3000.00
0005434550685	27725	Economy	3000.00
0005434554052	27725	Economy	3000.00
0005434550699	27725	Economy	3000.00
0005434550746	27725	Economy	3000.00
0005434550643	27725	Economy	3000.00
0005434550858	27725	Economy	3000.00
0005434550844	27725	Economy	3000.00
0005434550700	27725	Economy	3000.00
0005434550907	27725	Economy	3000.00
0005434550884	27725	Economy	3000.00
0005434550518	27725	Economy	3000.00
0005434550631	27725	Economy	3000.00
0005434550763	27725	Economy	3000.00
0005434550846	27725	Economy	3000.00
0005434550703	27725	Economy	3000.00
0005434550697	27725	Economy	3000.00
0005434550486	27725	Economy	3000.00
0005434550976	27725	Economy	3000.00
0005434550639	27725	Economy	3000.00
0005434550840	27725	Economy	3000.00
0005434550782	27725	Economy	3000.00
0005434558207	27725	Economy	3000.00
0005434550857	27725	Economy	3000.00
0005434550485	27725	Economy	3000.00
0005434550933	27725	Economy	3000.00
0005434550723	27725	Economy	3000.00
0005434558209	27725	Economy	3000.00
0005434550805	27725	Economy	3000.00
0005434550860	27725	Economy	3000.00
0005434550619	27725	Economy	3000.00
0005434554053	27725	Economy	3000.00
0005434550661	27725	Economy	3000.00
0005434550776	27725	Economy	3000.00
0005434550530	27725	Economy	3000.00
0005434550531	27725	Economy	3000.00
0005434550825	27725	Economy	3000.00
0005434554054	27725	Economy	3000.00
0005434558202	27725	Economy	3000.00
0005433459218	6130	Economy	11700.00
0005433459219	6130	Economy	11700.00
0005433459221	6130	Economy	11700.00
0005433459220	6130	Economy	11700.00
0005433459186	19314	Economy	11700.00
0005435254473	19314	Economy	11700.00
0005433459191	19314	Economy	11700.00
0005435254474	19314	Economy	11700.00
0005433459185	19314	Economy	11700.00
0005435254475	19314	Economy	11700.00
0005433459198	19314	Economy	11700.00
0005433459190	19314	Economy	11700.00
0005433459159	19314	Economy	11700.00
0005435437823	6712	Business	51100.00
0005435682150	6712	Business	51100.00
0005435437811	6712	Business	51100.00
0005435682136	6712	Business	51100.00
0005435437765	6712	Business	51100.00
0005435682114	6712	Business	51100.00
0005432136170	6712	Business	51100.00
0005435682144	6712	Business	51100.00
0005435682125	6712	Business	51100.00
0005435682111	6712	Business	51100.00
0005435682115	6712	Business	51100.00
0005435682131	6712	Economy	17000.00
0005435682141	6712	Economy	17000.00
0005435437791	6712	Economy	17000.00
0005435682149	6712	Economy	17000.00
0005435630963	6712	Economy	17000.00
0005435437842	6712	Economy	17000.00
0005435682122	6712	Economy	17000.00
0005435437747	6712	Economy	17000.00
0005435217699	6712	Economy	17000.00
0005435437868	6712	Economy	17000.00
0005435682152	6712	Economy	18700.00
0005435682128	6712	Economy	18700.00
0005435437654	6712	Economy	18700.00
0005432136168	6712	Economy	18700.00
0005435682139	6712	Economy	18700.00
0005435661927	6712	Economy	17000.00
0005435682138	6712	Economy	17000.00
0005435682142	6712	Economy	17000.00
0005435682113	6712	Economy	17000.00
0005435682151	6712	Economy	17000.00
0005435661930	6712	Economy	17000.00
0005435682148	6712	Economy	17000.00
0005435682135	6712	Economy	17000.00
0005432136167	6712	Economy	17000.00
0005435630964	6712	Economy	17000.00
0005435682132	6712	Economy	17000.00
0005435682109	6712	Economy	17000.00
0005432136169	6712	Economy	17000.00
0005435682129	6712	Economy	17000.00
0005435682130	6712	Economy	17000.00
0005435437771	6712	Economy	17000.00
0005435437836	6712	Economy	17000.00
0005432136171	6712	Economy	17000.00
0005434828671	6712	Economy	17000.00
0005435682154	6712	Economy	17000.00
0005435217696	6712	Economy	17000.00
0005435682120	6712	Economy	17000.00
0005434828672	6712	Economy	17000.00
0005435682117	6712	Economy	17000.00
0005435437756	6712	Economy	17000.00
0005435437837	6712	Economy	17000.00
0005435682127	6712	Economy	17000.00
0005435437754	6712	Economy	17000.00
0005435437667	6712	Economy	17000.00
0005435682121	6712	Economy	17000.00
0005435682145	6712	Economy	17000.00
0005435682110	6712	Economy	17000.00
0005435682119	6712	Economy	17000.00
0005435630965	6712	Economy	17000.00
0005435630966	6712	Economy	17000.00
0005435682112	6712	Economy	17000.00
0005435437822	6712	Economy	17000.00
0005434828661	6712	Economy	17000.00
0005434828675	6712	Economy	17000.00
0005435682140	6712	Economy	17000.00
0005435682116	6712	Economy	17000.00
0005435217698	6712	Economy	17000.00
0005434828673	6712	Economy	17000.00
0005435437820	6712	Economy	17000.00
0005435437764	6712	Economy	17000.00
0005435682143	6712	Economy	17000.00
0005435437690	6712	Economy	17000.00
0005435437755	6712	Economy	17000.00
0005435682134	6712	Economy	17000.00
0005435682118	6712	Economy	17000.00
0005435682126	6712	Economy	17000.00
0005435682124	6712	Economy	17000.00
0005434828674	6712	Economy	17000.00
0005435682147	6712	Economy	17000.00
0005435630967	6712	Economy	17000.00
0005435682123	6712	Economy	17000.00
0005435682137	6712	Economy	17000.00
0005435682153	6712	Economy	17000.00
0005435437753	6712	Economy	17000.00
0005435682133	6712	Economy	17000.00
0005435217697	6712	Economy	17000.00
0005435437819	6712	Economy	17000.00
0005435661929	6712	Economy	17000.00
0005435661928	6712	Economy	17000.00
0005435437867	6712	Economy	17000.00
0005435220300	6712	Economy	17000.00
0005435682146	6712	Economy	17000.00
0005435681802	24600	Business	51100.00
0005435437946	24600	Business	51100.00
0005435681795	24600	Business	51100.00
0005435681553	24600	Business	51100.00
0005435681761	24600	Business	51100.00
0005435681759	24600	Business	51100.00
0005435220316	24600	Business	51100.00
0005435630917	24600	Business	51100.00
0005435219197	24600	Business	51100.00
0005435437943	24600	Business	51100.00
0005435661902	24600	Business	51100.00
0005435681670	24600	Economy	17000.00
0005435681640	24600	Economy	17000.00
0005435437954	24600	Economy	17000.00
0005435437948	24600	Economy	17000.00
0005435437957	24600	Economy	17000.00
0005435681779	24600	Economy	17000.00
0005435437956	24600	Economy	17000.00
0005435681799	24600	Economy	17000.00
0005435661908	24600	Economy	17000.00
0005435220317	24600	Economy	18700.00
0005435681760	24600	Economy	18700.00
0005435630918	24600	Economy	18700.00
0005435630938	24600	Economy	18700.00
0005435437947	24600	Economy	18700.00
0005435437939	24600	Economy	17000.00
0005435681902	24600	Economy	17000.00
0005435661909	24600	Economy	17000.00
0005434828699	24600	Economy	17000.00
0005432305747	24600	Economy	17000.00
0005432305748	24600	Economy	17000.00
0005435681840	24600	Economy	17000.00
0005435219198	24600	Economy	17000.00
0005435681809	24600	Economy	17000.00
0005432533291	24600	Economy	17000.00
0005435681977	24600	Economy	17000.00
0005435219200	24600	Economy	17000.00
0005435437945	24600	Economy	17000.00
0005435437953	24600	Economy	17000.00
0005434828696	24600	Economy	17000.00
0005435681621	24600	Economy	17000.00
0005434828698	24600	Economy	17000.00
0005435681841	24600	Economy	17000.00
0005435681671	24600	Economy	17000.00
0005435437952	24600	Economy	17000.00
0005435219199	24600	Economy	17000.00
0005432305749	24600	Economy	17000.00
0005435437960	24600	Economy	17000.00
0005435681639	24600	Economy	17000.00
0005435681708	24600	Economy	17000.00
0005435681848	24600	Economy	17000.00
0005435661901	24600	Economy	17000.00
0005434828697	24600	Economy	17000.00
0005435681886	24600	Economy	17000.00
0005435437944	24600	Economy	17000.00
0005435681833	24600	Economy	17000.00
0005435437942	24600	Economy	17000.00
0005435681849	24600	Economy	17000.00
0005435681685	24600	Economy	17000.00
0005435681817	24600	Economy	17000.00
0005435681647	24600	Economy	17000.00
0005435220319	24600	Economy	17000.00
0005435681672	24600	Economy	17000.00
0005435681688	24600	Economy	17000.00
0005435437938	24600	Economy	17000.00
0005435437940	24600	Economy	17000.00
0005435437955	24600	Economy	17000.00
0005435681768	24600	Economy	17000.00
0005435681803	24600	Economy	17000.00
0005435437950	24600	Economy	17000.00
0005435437958	24600	Economy	17000.00
0005435630944	24600	Economy	17000.00
0005435220318	24600	Economy	17000.00
0005435681715	24600	Economy	17000.00
0005435681784	24600	Economy	17000.00
0005432533292	24600	Economy	17000.00
0005435437941	24600	Economy	17000.00
0005435681751	24600	Economy	17000.00
0005435681752	24600	Economy	17000.00
0005435681631	24600	Economy	17000.00
0005435681622	24600	Economy	17000.00
0005435437949	24600	Economy	17000.00
0005435437951	24600	Economy	17000.00
0005435681778	24600	Economy	17000.00
0005435661900	24600	Economy	17000.00
0005435681932	24600	Economy	17000.00
0005435437959	24600	Economy	17000.00
0005435681916	24600	Economy	17000.00
0005435681794	24600	Economy	17000.00
0005435126346	11553	Business	26400.00
0005435126325	11553	Business	26400.00
0005435126332	11553	Business	26400.00
0005435126337	11553	Business	26400.00
0005435126326	11553	Business	26400.00
0005435126341	11553	Business	26400.00
0005435126331	11553	Business	26400.00
0005435126349	11553	Business	26400.00
0005435126354	11553	Business	26400.00
0005435126329	11553	Economy	8800.00
0005435126347	11553	Economy	8800.00
0005435126348	11553	Economy	8800.00
0005435126314	11553	Economy	8800.00
0005435558059	11553	Economy	8800.00
0005435126315	11553	Economy	8800.00
0005435126321	11553	Economy	8800.00
0005435126338	11553	Economy	9700.00
0005435126324	11553	Economy	9700.00
0005435126352	11553	Economy	8800.00
0005435126345	11553	Economy	8800.00
0005435126334	11553	Economy	8800.00
0005435105978	11553	Economy	8800.00
0005435126350	11553	Economy	8800.00
0005435126351	11553	Economy	8800.00
0005435558062	11553	Economy	8800.00
0005435126344	11553	Economy	8800.00
0005435126320	11553	Economy	8800.00
0005435558065	11553	Economy	8800.00
0005435126327	11553	Economy	8800.00
0005435558066	11553	Economy	8800.00
0005435126336	11553	Economy	8800.00
0005435105980	11553	Economy	8800.00
0005435126318	11553	Economy	8800.00
0005435558061	11553	Economy	8800.00
0005435558069	11553	Economy	8800.00
0005435126342	11553	Economy	8800.00
0005435126333	11553	Economy	8800.00
0005435126343	11553	Economy	8800.00
0005435126316	11553	Economy	8800.00
0005435126353	11553	Economy	8800.00
0005435126330	11553	Economy	8800.00
0005435126322	11553	Economy	8800.00
0005435126339	11553	Economy	8800.00
0005435105979	11553	Economy	8800.00
0005435126317	11553	Economy	8800.00
0005435126323	11553	Economy	8800.00
0005435126328	11553	Economy	8800.00
0005435126340	11553	Economy	8800.00
0005435126335	11553	Economy	8800.00
0005435126319	11553	Economy	8800.00
0005435125948	31883	Business	26400.00
0005435098540	31883	Business	26400.00
0005435126009	31883	Business	26400.00
0005435558088	31883	Business	26400.00
0005435558086	31883	Business	26400.00
0005435126059	31883	Economy	8800.00
0005435126078	31883	Economy	8800.00
0005435125933	31883	Economy	8800.00
0005435125987	31883	Economy	8800.00
0005435125892	31883	Economy	9700.00
0005435126064	31883	Economy	9700.00
0005435125949	31883	Economy	9700.00
0005435125954	31883	Economy	8800.00
0005435126000	31883	Economy	8800.00
0005435126069	31883	Economy	8800.00
0005435125924	31883	Economy	8800.00
0005435126071	31883	Economy	8800.00
0005435105947	31883	Economy	8800.00
0005435126228	31883	Economy	8800.00
0005435126020	31883	Economy	8800.00
0005435125877	31883	Economy	8800.00
0005435126008	31883	Economy	8800.00
0005435558085	31883	Economy	8800.00
0005435125965	31883	Economy	8800.00
0005435126048	31883	Economy	8800.00
0005435125953	31883	Economy	8800.00
0005435126049	31883	Economy	8800.00
0005435126115	31883	Economy	8800.00
0005435126198	31883	Economy	8800.00
0005435558087	31883	Economy	8800.00
0005435125982	31883	Economy	8800.00
0005435126015	31883	Economy	8800.00
0005435105945	31883	Economy	8800.00
0005435125923	31883	Economy	8800.00
0005435125835	31883	Economy	8800.00
0005435125952	31883	Economy	8800.00
0005435125988	31883	Economy	8800.00
0005435126149	31883	Economy	8800.00
0005435126099	31883	Economy	8800.00
0005435126050	31883	Economy	8800.00
0005435126199	31883	Economy	8800.00
0005435126090	31883	Economy	8800.00
0005435125916	31883	Economy	8800.00
0005435125893	31883	Economy	8800.00
0005435126089	31883	Economy	8800.00
0005435105946	31883	Economy	8800.00
0005435125981	31883	Economy	8800.00
0005435125966	31883	Economy	8800.00
0005435126145	31883	Economy	8800.00
0005435125719	31883	Economy	8800.00
0005435126142	31883	Economy	8800.00
0005433398050	13526	Business	36600.00
0005433398074	13526	Business	36600.00
0005433398025	13526	Business	36600.00
0005433398055	13526	Business	36600.00
0005433398066	13526	Business	36600.00
0005433398046	13526	Business	36600.00
0005433398038	13526	Business	36600.00
0005433398037	13526	Business	36600.00
0005435732288	13526	Economy	12200.00
0005433398040	13526	Economy	12200.00
0005433398042	13526	Economy	12200.00
0005433398039	13526	Economy	12200.00
0005433398035	13526	Economy	12200.00
0005433398067	13526	Economy	12200.00
0005433398024	13526	Economy	12200.00
0005433398062	13526	Economy	13400.00
0005433398069	13526	Economy	13400.00
0005433398033	13526	Economy	13400.00
0005433398043	13526	Economy	13400.00
0005433398065	13526	Economy	12200.00
0005433398034	13526	Economy	12200.00
0005433398056	13526	Economy	12200.00
0005435732235	13526	Economy	12200.00
0005433398032	13526	Economy	12200.00
0005433398058	13526	Economy	12200.00
0005433398026	13526	Economy	12200.00
0005433398053	13526	Economy	12200.00
0005433398052	13526	Economy	12200.00
0005433398060	13526	Economy	12200.00
0005433398064	13526	Economy	12200.00
0005433398071	13526	Economy	12200.00
0005433398044	13526	Economy	12200.00
0005433398049	13526	Economy	12200.00
0005433398027	13526	Economy	12200.00
0005433398045	13526	Economy	12200.00
0005435732217	13526	Economy	12200.00
0005433398059	13526	Economy	12200.00
0005433398041	13526	Economy	12200.00
0005433398030	13526	Economy	12200.00
0005435732174	13526	Economy	12200.00
0005435732287	13526	Economy	12200.00
0005435732203	13526	Economy	12200.00
0005435732219	13526	Economy	12200.00
0005433398061	13526	Economy	12200.00
0005433398051	13526	Economy	12200.00
0005433398054	13526	Economy	12200.00
0005433398036	13526	Economy	12200.00
0005435732173	13526	Economy	12200.00
0005433398028	13526	Economy	12200.00
0005433398068	13526	Economy	12200.00
0005433398029	13526	Economy	12200.00
0005433398057	13526	Economy	12200.00
0005433398047	13526	Economy	12200.00
0005433398048	13526	Economy	12200.00
0005433398073	13526	Economy	12200.00
0005433398072	13526	Economy	12200.00
0005435732202	13526	Economy	12200.00
0005433398031	13526	Economy	12200.00
0005435732180	13526	Economy	12200.00
0005433398063	13526	Economy	12200.00
0005433398070	13526	Economy	12200.00
0005433397632	19371	Business	36600.00
0005433397495	19371	Business	36600.00
0005433397609	19371	Business	36600.00
0005433397720	19371	Business	36600.00
0005435732324	19371	Business	36600.00
0005433397621	19371	Business	36600.00
0005433397596	19371	Business	36600.00
0005433397777	19371	Business	36600.00
0005433397655	19371	Business	36600.00
0005433397418	19371	Economy	12200.00
0005433397500	19371	Economy	12200.00
0005435732322	19371	Economy	12200.00
0005433397823	19371	Economy	12200.00
0005433397580	19371	Economy	12200.00
0005433397788	19371	Economy	12200.00
0005435732317	19371	Economy	12200.00
0005435732325	19371	Economy	13400.00
0005432297276	19371	Economy	13400.00
0005433397794	19371	Economy	13400.00
0005433397776	19371	Economy	12200.00
0005433397730	19371	Economy	12200.00
0005433397605	19371	Economy	12200.00
0005435732320	19371	Economy	12200.00
0005433397600	19371	Economy	12200.00
0005433397714	19371	Economy	12200.00
0005433397668	19371	Economy	12200.00
0005435732323	19371	Economy	12200.00
0005433397447	19371	Economy	12200.00
0005433397594	19371	Economy	12200.00
0005432297277	19371	Economy	12200.00
0005433397695	19371	Economy	12200.00
0005433397667	19371	Economy	12200.00
0005435732326	19371	Economy	12200.00
0005433397745	19371	Economy	12200.00
0005433397622	19371	Economy	12200.00
0005433397746	19371	Economy	12200.00
0005433397733	19371	Economy	12200.00
0005433397818	19371	Economy	12200.00
0005433397540	19371	Economy	12200.00
0005433397775	19371	Economy	12200.00
0005433397628	19371	Economy	12200.00
0005433397642	19371	Economy	12200.00
0005433397612	19371	Economy	12200.00
0005433397577	19371	Economy	12200.00
0005433397643	19371	Economy	12200.00
0005435732321	19371	Economy	12200.00
0005433397633	19371	Economy	12200.00
0005433397512	19371	Economy	12200.00
0005433397826	19371	Economy	12200.00
0005433397734	19371	Economy	12200.00
0005433397527	19371	Economy	12200.00
0005433397729	19371	Economy	12200.00
0005433397333	19371	Economy	12200.00
0005433397481	19371	Economy	12200.00
0005433397822	19371	Economy	12200.00
0005433397719	19371	Economy	12200.00
0005433397639	19371	Economy	12200.00
0005435732319	19371	Economy	12200.00
0005433397744	19371	Economy	12200.00
0005435732318	19371	Economy	12200.00
0005433397528	19371	Economy	12200.00
0005433397539	19371	Economy	12200.00
0005433397663	19371	Economy	12200.00
0005433397709	19371	Economy	12200.00
0005433397417	19371	Economy	12200.00
0005433397532	19371	Economy	12200.00
0005433397669	19371	Economy	12200.00
0005435068457	13172	Business	11300.00
0005435068664	13172	Business	11300.00
0005435068368	13172	Business	11300.00
0005435068579	13172	Business	11300.00
0005435068458	13172	Business	11300.00
0005435068178	13172	Business	11300.00
0005435068631	13172	Economy	3800.00
0005435068593	13172	Economy	3800.00
0005435068632	13172	Economy	3800.00
0005435068591	13172	Economy	3800.00
0005435068618	13172	Economy	4100.00
0005435068693	13172	Economy	4100.00
0005435068617	13172	Economy	3800.00
0005435068645	13172	Economy	3800.00
0005435068589	13172	Economy	3800.00
0005435068700	13172	Economy	3800.00
0005435068578	13172	Economy	3800.00
0005435068777	13172	Economy	3800.00
0005435068602	13172	Economy	3800.00
0005435068657	13172	Economy	3800.00
0005435068569	13172	Economy	3800.00
0005435068580	13172	Economy	3800.00
0005435068583	13172	Economy	3800.00
0005435068809	13172	Economy	3800.00
0005435068557	13172	Economy	3800.00
0005435068547	13172	Economy	3800.00
0005435068644	13172	Economy	3800.00
0005435068413	13172	Economy	3800.00
0005435068699	13172	Economy	3800.00
0005435068603	13172	Economy	3800.00
0005435068588	13172	Economy	3800.00
0005435068491	13172	Economy	3800.00
0005435068434	13172	Economy	3800.00
0005435068774	13172	Economy	3800.00
0005435068666	13172	Economy	3800.00
0005435068788	13172	Economy	3800.00
0005435068834	13172	Economy	3800.00
0005435068556	13172	Economy	3800.00
0005435068415	13172	Economy	3800.00
0005435068568	13172	Economy	3800.00
0005435068414	13172	Economy	3800.00
0005435068673	13172	Economy	3800.00
0005435068685	13172	Economy	3800.00
0005435925162	15467	Business	11300.00
0005435069024	15467	Business	11300.00
0005435069030	15467	Business	11300.00
0005435069033	15467	Business	11300.00
0005435925173	15467	Business	11300.00
0005435069051	15467	Business	11300.00
0005435925118	15467	Business	11300.00
0005435925172	15467	Business	11300.00
0005435069049	15467	Business	11300.00
0005435069045	15467	Economy	3800.00
0005435925159	15467	Economy	3800.00
0005435069007	15467	Economy	3800.00
0005435069036	15467	Economy	3800.00
0005435069017	15467	Economy	3800.00
0005435069019	15467	Economy	4100.00
0005435069016	15467	Economy	4100.00
0005435069057	15467	Economy	4100.00
0005435925154	15467	Economy	3800.00
0005435069031	15467	Economy	3800.00
0005435925096	15467	Economy	3800.00
0005435069009	15467	Economy	3800.00
0005435069011	15467	Economy	3800.00
0005435069044	15467	Economy	3800.00
0005435069027	15467	Economy	3800.00
0005435925130	15467	Economy	3800.00
0005435069050	15467	Economy	3800.00
0005435069041	15467	Economy	3800.00
0005435925161	15467	Economy	3800.00
0005435069055	15467	Economy	3800.00
0005435069046	15467	Economy	3800.00
0005435925099	15467	Economy	3800.00
0005435069048	15467	Economy	3800.00
0005435069021	15467	Economy	3800.00
0005435069038	15467	Economy	3800.00
0005435925149	15467	Economy	3800.00
0005435069010	15467	Economy	3800.00
0005435069043	15467	Economy	3800.00
0005435069028	15467	Economy	3800.00
0005435069025	15467	Economy	3800.00
0005435069034	15467	Economy	3800.00
0005435069042	15467	Economy	3800.00
0005435925163	15467	Economy	3800.00
0005435069037	15467	Economy	3800.00
0005435069008	15467	Economy	3800.00
0005435925170	15467	Economy	3800.00
0005435925178	15467	Economy	3800.00
0005435069047	15467	Economy	3800.00
0005435069032	15467	Economy	3800.00
0005435069052	15467	Economy	3800.00
0005435069026	15467	Economy	3800.00
0005435069054	15467	Economy	3800.00
0005435069022	15467	Economy	3800.00
0005435069012	15467	Economy	3800.00
0005435069018	15467	Economy	3800.00
0005435069015	15467	Economy	3800.00
0005435925155	15467	Economy	3800.00
0005435069014	15467	Economy	3800.00
0005435069053	15467	Economy	3800.00
0005435069013	15467	Economy	3800.00
0005435069039	15467	Economy	3800.00
0005435069040	15467	Economy	3800.00
0005435069056	15467	Economy	3800.00
0005435069020	15467	Economy	3800.00
0005435069035	15467	Economy	3800.00
0005435069029	15467	Economy	3800.00
0005435069058	15467	Economy	3800.00
0005435069023	15467	Economy	3800.00
0005435925156	15467	Economy	3800.00
0005435808226	23182	Economy	27100.00
0005435808224	23182	Economy	27100.00
0005435808221	23182	Economy	24700.00
0005435808219	23182	Economy	24700.00
0005435808213	23182	Economy	24700.00
0005435808215	23182	Economy	24700.00
0005433407517	23182	Economy	24700.00
0005433407516	23182	Economy	24700.00
0005435808222	23182	Economy	24700.00
0005435808217	23182	Economy	24700.00
0005435808209	23182	Economy	24700.00
0005433407513	23182	Economy	24700.00
0005433407500	23182	Economy	24700.00
0005435808218	23182	Economy	24700.00
0005435808229	23182	Economy	24700.00
0005435808216	23182	Economy	24700.00
0005435808228	23182	Economy	24700.00
0005435808227	23182	Economy	24700.00
0005433407512	23182	Economy	24700.00
0005435808212	23182	Economy	24700.00
0005433407492	23182	Economy	24700.00
0005433407509	23182	Economy	24700.00
0005433407510	23182	Economy	24700.00
0005435808220	23182	Economy	24700.00
0005433407493	23182	Economy	24700.00
0005435808225	23182	Economy	24700.00
0005435808211	23182	Economy	24700.00
0005435808210	23182	Economy	24700.00
0005433407499	23182	Economy	24700.00
0005433407498	23182	Economy	24700.00
0005435808223	23182	Economy	24700.00
0005435808214	23182	Economy	24700.00
0005435808230	23182	Economy	24700.00
0005434214512	10681	Business	61300.00
0005434214519	10681	Business	61300.00
0005434756094	10681	Business	61300.00
0005434755982	10681	Business	61300.00
0005434214534	10681	Business	61300.00
0005434214552	10681	Business	61300.00
0005434755897	10681	Business	61300.00
0005434214550	10681	Business	61300.00
0005434755945	10681	Business	61300.00
0005434214514	10681	Business	61300.00
0005434756052	10681	Business	61300.00
0005434214520	10681	Economy	20400.00
0005434214535	10681	Economy	20400.00
0005434756092	10681	Economy	20400.00
0005434214510	10681	Economy	20400.00
0005434214532	10681	Economy	20400.00
0005434756016	10681	Economy	20400.00
0005434214523	10681	Economy	20400.00
0005434214542	10681	Economy	20400.00
0005434756091	10681	Economy	20400.00
0005434756093	10681	Economy	22500.00
0005434214531	10681	Economy	22500.00
0005434756048	10681	Economy	22500.00
0005434214511	10681	Economy	22500.00
0005434214546	10681	Economy	22500.00
0005434756051	10681	Economy	20400.00
0005434214537	10681	Economy	20400.00
0005434756127	10681	Economy	20400.00
0005434214533	10681	Economy	20400.00
0005434214554	10681	Economy	20400.00
0005434214545	10681	Economy	20400.00
0005434756023	10681	Economy	20400.00
0005434214555	10681	Economy	20400.00
0005434214528	10681	Economy	20400.00
0005434755974	10681	Economy	20400.00
0005434756098	10681	Economy	20400.00
0005434214525	10681	Economy	20400.00
0005434214538	10681	Economy	20400.00
0005434214540	10681	Economy	20400.00
0005434756119	10681	Economy	20400.00
0005434214524	10681	Economy	20400.00
0005434214515	10681	Economy	20400.00
0005434756130	10681	Economy	20400.00
0005434214522	10681	Economy	20400.00
0005434756086	10681	Economy	20400.00
0005434755898	10681	Economy	20400.00
0005434755948	10681	Economy	20400.00
0005434755883	10681	Economy	20400.00
0005434214530	10681	Economy	20400.00
0005434756078	10681	Economy	20400.00
0005434755947	10681	Economy	20400.00
0005434755962	10681	Economy	20400.00
0005434756186	10681	Economy	20400.00
0005434756079	10681	Economy	20400.00
0005434214509	10681	Economy	20400.00
0005434214551	10681	Economy	20400.00
0005434214548	10681	Economy	20400.00
0005434214518	10681	Economy	20400.00
0005434214541	10681	Economy	20400.00
0005434756070	10681	Economy	20400.00
0005434214539	10681	Economy	20400.00
0005434756077	10681	Economy	20400.00
0005434756104	10681	Economy	20400.00
0005434214526	10681	Economy	20400.00
0005434214516	10681	Economy	20400.00
0005434756172	10681	Economy	20400.00
0005434214517	10681	Economy	20400.00
0005434214513	10681	Economy	20400.00
0005434756027	10681	Economy	20400.00
0005434755946	10681	Economy	20400.00
0005434214556	10681	Economy	20400.00
0005434214536	10681	Economy	20400.00
0005434756066	10681	Economy	20400.00
0005434214521	10681	Economy	20400.00
0005434755858	10681	Economy	20400.00
0005434756058	10681	Economy	20400.00
0005434756117	10681	Economy	20400.00
0005434755961	10681	Economy	20400.00
0005434755964	10681	Economy	20400.00
0005434214527	10681	Economy	20400.00
0005434214529	10681	Economy	20400.00
0005434756001	10681	Economy	20400.00
0005434214547	10681	Economy	20400.00
0005434214508	10681	Economy	20400.00
0005434756017	10681	Economy	20400.00
0005434214553	10681	Economy	20400.00
0005434214549	10681	Economy	20400.00
0005434214544	10681	Economy	20400.00
0005434756074	10681	Economy	20400.00
0005434756073	10681	Economy	20400.00
0005434214543	10681	Economy	20400.00
0005434756367	28688	Business	61300.00
0005434214053	28688	Business	61300.00
0005434756404	28688	Business	61300.00
0005434213857	28688	Business	61300.00
0005434213851	28688	Business	61300.00
0005434756400	28688	Business	61300.00
0005434756402	28688	Business	61300.00
0005434756373	28688	Business	61300.00
0005434756364	28688	Business	61300.00
0005434756368	28688	Business	61300.00
0005434213991	28688	Business	61300.00
0005434756392	28688	Business	61300.00
0005434756405	28688	Economy	20400.00
0005434756380	28688	Economy	20400.00
0005434213967	28688	Economy	20400.00
0005434214095	28688	Economy	20400.00
0005434214253	28688	Economy	20400.00
0005434756372	28688	Economy	20400.00
0005434213886	28688	Economy	20400.00
0005434214137	28688	Economy	20400.00
0005434756383	28688	Economy	20400.00
0005434756381	28688	Economy	22500.00
0005434756362	28688	Economy	22500.00
0005434214098	28688	Economy	22500.00
0005434214261	28688	Economy	22500.00
0005434756393	28688	Economy	22500.00
0005434214091	28688	Economy	20400.00
0005434213873	28688	Economy	20400.00
0005434756403	28688	Economy	20400.00
0005434214252	28688	Economy	20400.00
0005434756371	28688	Economy	20400.00
0005434756387	28688	Economy	20400.00
0005434213892	28688	Economy	20400.00
0005434756365	28688	Economy	20400.00
0005434213930	28688	Economy	20400.00
0005434756382	28688	Economy	20400.00
0005434756397	28688	Economy	20400.00
0005434214209	28688	Economy	20400.00
0005434214049	28688	Economy	20400.00
0005434756389	28688	Economy	20400.00
0005434756407	28688	Economy	20400.00
0005434756374	28688	Economy	20400.00
0005434756379	28688	Economy	20400.00
0005434214207	28688	Economy	20400.00
0005434756395	28688	Economy	20400.00
0005434756388	28688	Economy	20400.00
0005434756398	28688	Economy	20400.00
0005434213920	28688	Economy	20400.00
0005434214028	28688	Economy	20400.00
0005434214210	28688	Economy	20400.00
0005434756377	28688	Economy	20400.00
0005434756396	28688	Economy	20400.00
0005434756369	28688	Economy	20400.00
0005434213973	28688	Economy	20400.00
0005434213901	28688	Economy	20400.00
0005434213890	28688	Economy	20400.00
0005434214149	28688	Economy	20400.00
0005434756390	28688	Economy	20400.00
0005434756401	28688	Economy	20400.00
0005434756366	28688	Economy	20400.00
0005434214146	28688	Economy	20400.00
0005434756386	28688	Economy	20400.00
0005434214070	28688	Economy	20400.00
0005434213900	28688	Economy	20400.00
0005434756399	28688	Economy	20400.00
0005434756376	28688	Economy	20400.00
0005434214144	28688	Economy	20400.00
0005434214090	28688	Economy	20400.00
0005434213882	28688	Economy	20400.00
0005434213906	28688	Economy	20400.00
0005434756375	28688	Economy	20400.00
0005434214145	28688	Economy	20400.00
0005434213983	28688	Economy	20400.00
0005434756378	28688	Economy	20400.00
0005434756391	28688	Economy	20400.00
0005434756406	28688	Economy	20400.00
0005434214005	28688	Economy	20400.00
0005434756394	28688	Economy	20400.00
0005434214208	28688	Economy	20400.00
0005434213881	28688	Economy	20400.00
0005434214094	28688	Economy	20400.00
0005434756370	28688	Economy	20400.00
0005434213891	28688	Economy	20400.00
0005434214260	28688	Economy	20400.00
0005434756363	28688	Economy	20400.00
0005434756385	28688	Economy	20400.00
0005434214100	28688	Economy	20400.00
0005434756384	28688	Economy	20400.00
0005434213990	28688	Economy	20400.00
0005434214148	28688	Economy	20400.00
0005434229174	5461	Business	29500.00
0005435007026	5461	Business	29500.00
0005435039787	5461	Business	29500.00
0005435039764	5461	Business	29500.00
0005435039796	5461	Business	29500.00
0005434229237	5461	Business	29500.00
0005435039738	5461	Business	29500.00
0005432125449	5461	Business	29500.00
0005435039794	5461	Business	29500.00
0005435039761	5461	Business	29500.00
0005434229131	5461	Business	29500.00
0005434229072	5461	Business	29500.00
0005435039751	5461	Economy	9800.00
0005434229153	5461	Economy	9800.00
0005435039798	5461	Economy	9800.00
0005434229073	5461	Economy	9800.00
0005435039748	5461	Economy	9800.00
0005435039741	5461	Economy	9800.00
0005434229190	5461	Economy	9800.00
0005435039766	5461	Economy	9800.00
0005435007033	5461	Economy	9800.00
0005435039774	5461	Economy	9800.00
0005435039779	5461	Economy	9800.00
0005435007038	5461	Economy	9800.00
0005435007042	5461	Economy	9800.00
0005435039772	5461	Economy	9800.00
0005434229145	5461	Economy	9800.00
0005435007040	5461	Economy	9800.00
0005432125453	5461	Economy	9800.00
0005434229040	5461	Economy	9800.00
0005435039784	5461	Economy	9800.00
0005435007021	5461	Economy	9800.00
0005435039785	5461	Economy	9800.00
0005434229221	5461	Economy	9800.00
0005434229179	5461	Economy	9800.00
0005435039791	5461	Economy	9800.00
0005435007035	5461	Economy	9800.00
0005435007039	5461	Economy	9800.00
0005435007023	5461	Economy	9800.00
0005435007041	5461	Economy	9800.00
0005434229196	5461	Economy	9800.00
0005435007031	5461	Economy	9800.00
0005435039753	5461	Economy	9800.00
0005434229169	5461	Economy	9800.00
0005435039746	5461	Economy	9800.00
0005434229197	5461	Economy	9800.00
0005435007029	5461	Economy	9800.00
0005434229192	5461	Economy	9800.00
0005434229220	5461	Economy	9800.00
0005435039758	5461	Economy	9800.00
0005434229238	5461	Economy	9800.00
0005435039745	5461	Economy	9800.00
0005435039750	5461	Economy	10800.00
0005435039793	5461	Economy	10800.00
0005434229276	5461	Economy	10800.00
0005435039795	5461	Economy	10800.00
0005435039777	5461	Economy	10800.00
0005435039743	5461	Economy	10800.00
0005435039783	5461	Economy	9800.00
0005435039776	5461	Economy	9800.00
0005435007025	5461	Economy	9800.00
0005434229140	5461	Economy	9800.00
0005434229184	5461	Economy	9800.00
0005432125454	5461	Economy	9800.00
0005435039773	5461	Economy	9800.00
0005435039755	5461	Economy	9800.00
0005435039788	5461	Economy	9800.00
0005435039786	5461	Economy	9800.00
0005435007030	5461	Economy	9800.00
0005434229139	5461	Economy	9800.00
0005435007034	5461	Economy	9800.00
0005435039744	5461	Economy	9800.00
0005434229180	5461	Economy	9800.00
0005432125452	5461	Economy	9800.00
0005435039767	5461	Economy	9800.00
0005435007022	5461	Economy	9800.00
0005432125450	5461	Economy	9800.00
0005435039740	5461	Economy	9800.00
0005435039737	5461	Economy	9800.00
0005435039799	5461	Economy	9800.00
0005435039769	5461	Economy	9800.00
0005435039747	5461	Economy	9800.00
0005435039770	5461	Economy	9800.00
0005432125448	5461	Economy	9800.00
0005435007027	5461	Economy	9800.00
0005435039771	5461	Economy	9800.00
0005435039757	5461	Economy	9800.00
0005432125451	5461	Economy	9800.00
0005434229039	5461	Economy	9800.00
0005434229185	5461	Economy	9800.00
0005434229107	5461	Economy	9800.00
0005435007028	5461	Economy	9800.00
0005435039760	5461	Economy	9800.00
0005435039792	5461	Economy	9800.00
0005435039780	5461	Economy	9800.00
0005435039754	5461	Economy	9800.00
0005435039762	5461	Economy	9800.00
0005435039797	5461	Economy	9800.00
0005435039790	5461	Economy	9800.00
0005435039736	5461	Economy	9800.00
0005435039775	5461	Economy	9800.00
0005434229229	5461	Economy	9800.00
0005434229240	5461	Economy	9800.00
0005435039749	5461	Economy	9800.00
0005435039756	5461	Economy	9800.00
0005434229122	5461	Economy	9800.00
0005435039742	5461	Economy	9800.00
0005435007032	5461	Economy	9800.00
0005435039789	5461	Economy	9800.00
0005435039782	5461	Economy	9800.00
0005435039765	5461	Economy	9800.00
0005435039768	5461	Economy	9800.00
0005435007024	5461	Economy	9800.00
0005434229205	5461	Economy	9800.00
0005435007037	5461	Economy	9800.00
0005434229146	5461	Economy	9800.00
0005434229106	5461	Economy	9800.00
0005435039759	5461	Economy	9800.00
0005435039763	5461	Economy	9800.00
0005435007043	5461	Economy	9800.00
0005435039752	5461	Economy	9800.00
0005435007036	5461	Economy	9800.00
0005435039781	5461	Economy	9800.00
0005435039778	5461	Economy	9800.00
0005434229239	5461	Economy	9800.00
0005434229277	5461	Economy	9800.00
0005435039739	5461	Economy	9800.00
0005435039326	12958	Business	29500.00
0005435038961	12958	Business	29500.00
0005435039235	12958	Business	29500.00
0005435039305	12958	Business	29500.00
0005435039112	12958	Business	29500.00
0005435039073	12958	Business	29500.00
0005434229362	12958	Business	29500.00
0005435006807	12958	Business	29500.00
0005434229375	12958	Business	29500.00
0005435038947	12958	Business	29500.00
0005435006883	12958	Business	29500.00
0005435039152	12958	Economy	9800.00
0005435042834	12958	Economy	9800.00
0005432304397	12958	Economy	9800.00
0005435039303	12958	Economy	9800.00
0005435039100	12958	Economy	9800.00
0005435039306	12958	Economy	9800.00
0005435039133	12958	Economy	9800.00
0005435039241	12958	Economy	9800.00
0005435039572	12958	Economy	9800.00
0005435038979	12958	Economy	9800.00
0005434229367	12958	Economy	9800.00
0005435038996	12958	Economy	9800.00
0005435039070	12958	Economy	9800.00
0005435039178	12958	Economy	9800.00
0005435006824	12958	Economy	9800.00
0005435039218	12958	Economy	9800.00
0005435039130	12958	Economy	9800.00
0005435039236	12958	Economy	9800.00
0005435039075	12958	Economy	9800.00
0005434229361	12958	Economy	9800.00
0005435006802	12958	Economy	9800.00
0005435039284	12958	Economy	9800.00
0005435006787	12958	Economy	9800.00
0005435006803	12958	Economy	9800.00
0005434229381	12958	Economy	9800.00
0005435038952	12958	Economy	9800.00
0005435039051	12958	Economy	9800.00
0005432304396	12958	Economy	9800.00
0005435006792	12958	Economy	9800.00
0005435039067	12958	Economy	9800.00
0005435039009	12958	Economy	9800.00
0005435039238	12958	Economy	9800.00
0005434229377	12958	Economy	9800.00
0005435039229	12958	Economy	9800.00
0005435006813	12958	Economy	9800.00
0005435006834	12958	Economy	9800.00
0005434229360	12958	Economy	9800.00
0005435039190	12958	Economy	9800.00
0005435039074	12958	Economy	9800.00
0005435039222	12958	Economy	9800.00
0005435006769	12958	Economy	10800.00
0005435039099	12958	Economy	10800.00
0005434229378	12958	Economy	10800.00
0005435039281	12958	Economy	10800.00
0005435006743	12958	Economy	10800.00
0005435039132	12958	Economy	10800.00
0005435039121	12958	Economy	9800.00
0005435006835	12958	Economy	9800.00
0005435039154	12958	Economy	9800.00
0005435039343	12958	Economy	9800.00
0005434229371	12958	Economy	9800.00
0005435038925	12958	Economy	9800.00
0005435039253	12958	Economy	9800.00
0005435039223	12958	Economy	9800.00
0005435039202	12958	Economy	9800.00
0005435042841	12958	Economy	9800.00
0005435006814	12958	Economy	9800.00
0005435039052	12958	Economy	9800.00
0005432304398	12958	Economy	9800.00
0005434229363	12958	Economy	9800.00
0005435039131	12958	Economy	9800.00
0005434229370	12958	Economy	9800.00
0005435039043	12958	Economy	9800.00
0005435039111	12958	Economy	9800.00
0005435039188	12958	Economy	9800.00
0005435038992	12958	Economy	9800.00
0005434229366	12958	Economy	9800.00
0005435039298	12958	Economy	9800.00
0005435006788	12958	Economy	9800.00
0005435039314	12958	Economy	9800.00
0005435039158	12958	Economy	9800.00
0005435039245	12958	Economy	9800.00
0005435039327	12958	Economy	9800.00
0005435039277	12958	Economy	9800.00
0005434229379	12958	Economy	9800.00
0005435006789	12958	Economy	9800.00
0005435042840	12958	Economy	9800.00
0005435039008	12958	Economy	9800.00
0005435039336	12958	Economy	9800.00
0005434229359	12958	Economy	9800.00
0005435006806	12958	Economy	9800.00
0005435039385	12958	Economy	9800.00
0005435039013	12958	Economy	9800.00
0005432304399	12958	Economy	9800.00
0005434229365	12958	Economy	9800.00
0005435038953	12958	Economy	9800.00
0005435039058	12958	Economy	9800.00
0005435006825	12958	Economy	9800.00
0005435039012	12958	Economy	9800.00
0005435038830	12958	Economy	9800.00
0005435039119	12958	Economy	9800.00
0005435006930	12958	Economy	9800.00
0005435038749	12958	Economy	9800.00
0005434229372	12958	Economy	9800.00
0005434229374	12958	Economy	9800.00
0005435039285	12958	Economy	9800.00
0005434229382	12958	Economy	9800.00
0005435039299	12958	Economy	9800.00
0005435039244	12958	Economy	9800.00
0005435039018	12958	Economy	9800.00
0005435039011	12958	Economy	9800.00
0005435038964	12958	Economy	9800.00
0005434229376	12958	Economy	9800.00
0005435039156	12958	Economy	9800.00
0005434229380	12958	Economy	9800.00
0005435039276	12958	Economy	9800.00
0005435039157	12958	Economy	9800.00
0005434229369	12958	Economy	9800.00
0005435043276	12958	Economy	9800.00
0005435039296	12958	Economy	9800.00
0005434229373	12958	Economy	9800.00
0005435039083	12958	Economy	9800.00
0005435039101	12958	Economy	9800.00
0005434229364	12958	Economy	9800.00
0005434229368	12958	Economy	9800.00
0005435006744	12958	Economy	9800.00
0005434426575	14882	Business	52900.00
0005434426573	14882	Business	52900.00
0005434411772	14882	Business	52900.00
0005435902528	14882	Business	52900.00
0005435902545	14882	Business	52900.00
0005435902547	14882	Business	52900.00
0005435902573	14882	Business	52900.00
0005435902405	14882	Business	52900.00
0005435902553	14882	Economy	17600.00
0005435554146	14882	Economy	17600.00
0005435902536	14882	Economy	17600.00
0005434426568	14882	Economy	17600.00
0005434426585	14882	Economy	17600.00
0005434426578	14882	Economy	17600.00
0005435902522	14882	Economy	17600.00
0005435902476	14882	Economy	19400.00
0005434426587	14882	Economy	19400.00
0005434426580	14882	Economy	19400.00
0005432188603	14882	Economy	19400.00
0005435902500	14882	Economy	19400.00
0005435554139	14882	Economy	17600.00
0005435902459	14882	Economy	17600.00
0005435902475	14882	Economy	17600.00
0005435554133	14882	Economy	17600.00
0005435902585	14882	Economy	17600.00
0005435902477	14882	Economy	17600.00
0005434426593	14882	Economy	17600.00
0005435902574	14882	Economy	17600.00
0005434426579	14882	Economy	17600.00
0005432188604	14882	Economy	17600.00
0005434426581	14882	Economy	17600.00
0005435902457	14882	Economy	17600.00
0005434426591	14882	Economy	17600.00
0005435902544	14882	Economy	17600.00
0005435902548	14882	Economy	17600.00
0005434426588	14882	Economy	17600.00
0005434426569	14882	Economy	17600.00
0005435902462	14882	Economy	17600.00
0005434426567	14882	Economy	17600.00
0005434426590	14882	Economy	17600.00
0005434426570	14882	Economy	17600.00
0005435902404	14882	Economy	17600.00
0005434426577	14882	Economy	17600.00
0005435902508	14882	Economy	17600.00
0005434426596	14882	Economy	17600.00
0005435902541	14882	Economy	17600.00
0005435902572	14882	Economy	17600.00
0005434426597	14882	Economy	17600.00
0005435902586	14882	Economy	17600.00
0005434426586	14882	Economy	17600.00
0005435902552	14882	Economy	17600.00
0005434426592	14882	Economy	17600.00
0005434426589	14882	Economy	17600.00
0005434426595	14882	Economy	17600.00
0005435902550	14882	Economy	17600.00
0005435902493	14882	Economy	17600.00
0005435554134	14882	Economy	17600.00
0005434426594	14882	Economy	17600.00
0005434411773	14882	Economy	17600.00
0005434426571	14882	Economy	17600.00
0005435902519	14882	Economy	17600.00
0005434411775	14882	Economy	17600.00
0005434426583	14882	Economy	17600.00
0005434426572	14882	Economy	17600.00
0005434411774	14882	Economy	17600.00
0005434426576	14882	Economy	17600.00
0005434426582	14882	Economy	17600.00
0005434426574	14882	Economy	17600.00
0005435902458	14882	Economy	17600.00
0005432188605	14882	Economy	17600.00
0005434426584	14882	Economy	17600.00
0005434426329	20219	Business	52900.00
0005435554190	20219	Business	52900.00
0005434426333	20219	Business	52900.00
0005435902701	20219	Business	52900.00
0005435902700	20219	Business	52900.00
0005435902709	20219	Business	52900.00
0005434426272	20219	Business	52900.00
0005434426322	20219	Business	52900.00
0005435902696	20219	Economy	17600.00
0005434426267	20219	Economy	17600.00
0005435902705	20219	Economy	17600.00
0005434426265	20219	Economy	17600.00
0005434426278	20219	Economy	17600.00
0005434426269	20219	Economy	17600.00
0005435554191	20219	Economy	17600.00
0005435902694	20219	Economy	19400.00
0005434411748	20219	Economy	19400.00
0005434426470	20219	Economy	17600.00
0005434426469	20219	Economy	17600.00
0005434426399	20219	Economy	17600.00
0005434426377	20219	Economy	17600.00
0005434426359	20219	Economy	17600.00
0005434426400	20219	Economy	17600.00
0005435902706	20219	Economy	17600.00
0005434426339	20219	Economy	17600.00
0005435902707	20219	Economy	17600.00
0005434426286	20219	Economy	17600.00
0005434426352	20219	Economy	17600.00
0005434426467	20219	Economy	17600.00
0005434426358	20219	Economy	17600.00
0005434426351	20219	Economy	17600.00
0005435902702	20219	Economy	17600.00
0005435902711	20219	Economy	17600.00
0005434426403	20219	Economy	17600.00
0005435902698	20219	Economy	17600.00
0005434426315	20219	Economy	17600.00
0005435902699	20219	Economy	17600.00
0005435554188	20219	Economy	17600.00
0005432059505	20219	Economy	17600.00
0005434426273	20219	Economy	17600.00
0005435554189	20219	Economy	17600.00
0005435902697	20219	Economy	17600.00
0005435902703	20219	Economy	17600.00
0005435902708	20219	Economy	17600.00
0005434426350	20219	Economy	17600.00
0005434426268	20219	Economy	17600.00
0005432059504	20219	Economy	17600.00
0005435902704	20219	Economy	17600.00
0005434426362	20219	Economy	17600.00
0005435902710	20219	Economy	17600.00
0005435902695	20219	Economy	17600.00
0005434411744	20219	Economy	17600.00
0005434411764	20219	Economy	17600.00
0005434426382	20219	Economy	17600.00
0005434426361	20219	Economy	17600.00
0005434426279	20219	Economy	17600.00
0005434426384	20219	Economy	17600.00
0005434523768	30894	Business	106800.00
0005434523770	30894	Economy	35600.00
0005432462483	30894	Economy	35600.00
0005432462498	30894	Economy	35600.00
0005432462484	30894	Economy	35600.00
0005432462496	30894	Economy	35600.00
0005432462482	30894	Economy	35600.00
0005434523773	30894	Economy	39200.00
0005434559095	30894	Economy	35600.00
0005432462497	30894	Economy	35600.00
0005434523775	30894	Economy	35600.00
0005434523767	30894	Economy	35600.00
0005434523772	30894	Economy	35600.00
0005432462488	30894	Economy	35600.00
0005432462480	30894	Economy	35600.00
0005434559094	30894	Economy	35600.00
0005434559092	30894	Economy	35600.00
0005432462492	30894	Economy	35600.00
0005434523774	30894	Economy	35600.00
0005434559093	30894	Economy	35600.00
0005432462499	30894	Economy	35600.00
0005432462485	30894	Economy	35600.00
0005432462493	30894	Economy	35600.00
0005434523769	30894	Economy	35600.00
0005432462486	30894	Economy	35600.00
0005434523771	30894	Economy	35600.00
0005433434439	26511	Business	18500.00
0005435982283	26511	Business	18500.00
0005433434442	26511	Business	18500.00
0005433434297	26511	Business	18500.00
0005435982250	26511	Business	18500.00
0005435982259	26511	Business	18500.00
0005435982264	26511	Business	18500.00
0005433434413	26511	Business	18500.00
0005435982278	26511	Business	18500.00
0005433434375	26511	Business	18500.00
0005435982269	26511	Business	18500.00
0005433434549	26511	Economy	6200.00
0005433434350	26511	Economy	6200.00
0005435982275	26511	Economy	6200.00
0005435982241	26511	Economy	6200.00
0005433434420	26511	Economy	6200.00
0005433434550	26511	Economy	6200.00
0005435982261	26511	Economy	6200.00
0005435982281	26511	Economy	6200.00
0005435982270	26511	Economy	6800.00
0005435982254	26511	Economy	6800.00
0005435982255	26511	Economy	6800.00
0005435982265	26511	Economy	6800.00
0005433434296	26511	Economy	6800.00
0005433434380	26511	Economy	6200.00
0005433434425	26511	Economy	6200.00
0005435982285	26511	Economy	6200.00
0005435982248	26511	Economy	6200.00
0005435982276	26511	Economy	6200.00
0005435982277	26511	Economy	6200.00
0005433434367	26511	Economy	6200.00
0005435982284	26511	Economy	6200.00
0005435982243	26511	Economy	6200.00
0005435982247	26511	Economy	6200.00
0005435982286	26511	Economy	6200.00
0005435982267	26511	Economy	6200.00
0005433434426	26511	Economy	6200.00
0005435982279	26511	Economy	6200.00
0005432300261	26511	Economy	6200.00
0005433434491	26511	Economy	6200.00
0005433434357	26511	Economy	6200.00
0005435982262	26511	Economy	6200.00
0005433434440	26511	Economy	6200.00
0005433434432	26511	Economy	6200.00
0005435982290	26511	Economy	6200.00
0005432300258	26511	Economy	6200.00
0005433434419	26511	Economy	6200.00
0005434270188	26511	Economy	6200.00
0005433434366	26511	Economy	6200.00
0005432300260	26511	Economy	6200.00
0005433434557	26511	Economy	6200.00
0005432300257	26511	Economy	6200.00
0005435982280	26511	Economy	6200.00
0005435982273	26511	Economy	6200.00
0005432300259	26511	Economy	6200.00
0005435982289	26511	Economy	6200.00
0005433434356	26511	Economy	6200.00
0005435982257	26511	Economy	6200.00
0005433434363	26511	Economy	6200.00
0005433434412	26511	Economy	6200.00
0005435982260	26511	Economy	6200.00
0005433434381	26511	Economy	6200.00
0005435982263	26511	Economy	6200.00
0005435982256	26511	Economy	6200.00
0005435982272	26511	Economy	6200.00
0005432300255	26511	Economy	6200.00
0005435982268	26511	Economy	6200.00
0005432300262	26511	Economy	6200.00
0005435982246	26511	Economy	6200.00
0005435982245	26511	Economy	6200.00
0005434270187	26511	Economy	6200.00
0005435982252	26511	Economy	6200.00
0005435982266	26511	Economy	6200.00
0005435982282	26511	Economy	6200.00
0005435982249	26511	Economy	6200.00
0005433434556	26511	Economy	6200.00
0005435982258	26511	Economy	6200.00
0005435982274	26511	Economy	6200.00
0005435982291	26511	Economy	6200.00
0005432300256	26511	Economy	6200.00
0005435982253	26511	Economy	6200.00
0005435982271	26511	Economy	6200.00
0005433434452	26511	Economy	6200.00
0005435982244	26511	Economy	6200.00
0005435982251	26511	Economy	6200.00
0005435982287	26511	Economy	6200.00
0005435982288	26511	Economy	6200.00
0005433434427	26511	Economy	6200.00
0005435982242	26511	Economy	6200.00
0005433434490	26511	Economy	6200.00
0005435981867	26689	Business	18500.00
0005433434676	26689	Business	18500.00
0005435981953	26689	Business	18500.00
0005433434694	26689	Business	18500.00
0005433434669	26689	Business	18500.00
0005435981810	26689	Business	18500.00
0005433434671	26689	Business	18500.00
0005435981969	26689	Business	18500.00
0005434271312	26689	Business	18500.00
0005435981676	26689	Business	18500.00
0005432051128	26689	Economy	6200.00
0005433434684	26689	Economy	6200.00
0005433434692	26689	Economy	6200.00
0005435981924	26689	Economy	6200.00
0005433434690	26689	Economy	6200.00
0005433434678	26689	Economy	6200.00
0005435981903	26689	Economy	6200.00
0005433434674	26689	Economy	6200.00
0005435981615	26689	Economy	6200.00
0005433434683	26689	Economy	6800.00
0005433434686	26689	Economy	6800.00
0005435981894	26689	Economy	6800.00
0005435981979	26689	Economy	6800.00
0005435981973	26689	Economy	6800.00
0005435981925	26689	Economy	6200.00
0005434271311	26689	Economy	6200.00
0005435981899	26689	Economy	6200.00
0005433434685	26689	Economy	6200.00
0005433434691	26689	Economy	6200.00
0005435981917	26689	Economy	6200.00
0005435981860	26689	Economy	6200.00
0005433434695	26689	Economy	6200.00
0005434270207	26689	Economy	6200.00
0005435981905	26689	Economy	6200.00
0005433434682	26689	Economy	6200.00
0005435982002	26689	Economy	6200.00
0005435981970	26689	Economy	6200.00
0005434269102	26689	Economy	6200.00
0005432051129	26689	Economy	6200.00
0005433434696	26689	Economy	6200.00
0005433434677	26689	Economy	6200.00
0005435981749	26689	Economy	6200.00
0005433434672	26689	Economy	6200.00
0005434270206	26689	Economy	6200.00
0005435981866	26689	Economy	6200.00
0005434269104	26689	Economy	6200.00
0005433434680	26689	Economy	6200.00
0005433434689	26689	Economy	6200.00
0005435981849	26689	Economy	6200.00
0005433434670	26689	Economy	6200.00
0005433434693	26689	Economy	6200.00
0005432051127	26689	Economy	6200.00
0005435981918	26689	Economy	6200.00
0005433434688	26689	Economy	6200.00
0005433434673	26689	Economy	6200.00
0005435981882	26689	Economy	6200.00
0005433434679	26689	Economy	6200.00
0005433434687	26689	Economy	6200.00
0005435981713	26689	Economy	6200.00
0005435981845	26689	Economy	6200.00
0005435981900	26689	Economy	6200.00
0005435981850	26689	Economy	6200.00
0005433434681	26689	Economy	6200.00
0005435981859	26689	Economy	6200.00
0005435981884	26689	Economy	6200.00
0005433434675	26689	Economy	6200.00
0005435981750	26689	Economy	6200.00
0005434269103	26689	Economy	6200.00
0005435981881	26689	Economy	6200.00
0005435981906	26689	Economy	6200.00
0005435982037	26689	Economy	6200.00
0005435981861	26689	Economy	6200.00
0005435981809	26689	Economy	6200.00
0005435981904	26689	Economy	6200.00
0005435981616	26689	Economy	6200.00
0005435981954	26689	Economy	6200.00
0005435981910	26689	Economy	6200.00
0005435981949	26689	Economy	6200.00
0005433434697	26689	Economy	6200.00
0005435981885	26689	Economy	6200.00
0005432584041	3162	Economy	11100.00
0005432858009	3162	Economy	11100.00
0005432584037	3162	Economy	11100.00
0005432584044	3162	Economy	10100.00
0005432584025	3162	Economy	10100.00
0005432584039	3162	Economy	10100.00
0005432857976	3162	Economy	10100.00
0005432857972	3162	Economy	10100.00
0005432584023	3162	Economy	10100.00
0005432584040	3162	Economy	10100.00
0005432584032	3162	Economy	10100.00
0005432584024	3162	Economy	10100.00
0005432584036	3162	Economy	10100.00
0005432857975	3162	Economy	10100.00
0005432857926	3162	Economy	10100.00
0005432584028	3162	Economy	10100.00
0005432584035	3162	Economy	10100.00
0005432857916	3162	Economy	10100.00
0005432857959	3162	Economy	10100.00
0005432584027	3162	Economy	10100.00
0005432857919	3162	Economy	10100.00
0005432584022	3162	Economy	10100.00
0005432216272	3162	Economy	10100.00
0005432584030	3162	Economy	10100.00
0005432584045	3162	Economy	10100.00
0005432216271	3162	Economy	10100.00
0005432584031	3162	Economy	10100.00
0005432584042	3162	Economy	10100.00
0005432584043	3162	Economy	10100.00
0005432216273	3162	Economy	10100.00
0005432584026	3162	Economy	10100.00
0005432584029	3162	Economy	10100.00
0005432584034	3162	Economy	10100.00
0005432584021	3162	Economy	10100.00
0005432584033	3162	Economy	10100.00
0005432584038	3162	Economy	10100.00
0005432583898	31488	Economy	11100.00
0005432583890	31488	Economy	11100.00
0005432583820	31488	Economy	11100.00
0005432858064	31488	Economy	11100.00
0005432583687	31488	Economy	10100.00
0005432858071	31488	Economy	10100.00
0005432583885	31488	Economy	10100.00
0005432858068	31488	Economy	10100.00
0005432583753	31488	Economy	10100.00
0005432858067	31488	Economy	10100.00
0005432858066	31488	Economy	10100.00
0005432583907	31488	Economy	10100.00
0005432583748	31488	Economy	10100.00
0005432858065	31488	Economy	10100.00
0005432583847	31488	Economy	10100.00
0005432583870	31488	Economy	10100.00
0005432583886	31488	Economy	10100.00
0005432583902	31488	Economy	10100.00
0005432583843	31488	Economy	10100.00
0005432858062	31488	Economy	10100.00
0005432583859	31488	Economy	10100.00
0005432858070	31488	Economy	10100.00
0005432583848	31488	Economy	10100.00
0005432583749	31488	Economy	10100.00
0005432583862	31488	Economy	10100.00
0005432583865	31488	Economy	10100.00
0005432583831	31488	Economy	10100.00
0005432583845	31488	Economy	10100.00
0005432583844	31488	Economy	10100.00
0005432583832	31488	Economy	10100.00
0005432583821	31488	Economy	10100.00
0005432583752	31488	Economy	10100.00
0005432583851	31488	Economy	10100.00
0005432583686	31488	Economy	10100.00
0005432583889	31488	Economy	10100.00
0005432583710	31488	Economy	10100.00
0005432583830	31488	Economy	10100.00
0005432858063	31488	Economy	10100.00
0005432858072	31488	Economy	10100.00
0005432583846	31488	Economy	10100.00
0005432583861	31488	Economy	10100.00
0005432858069	31488	Economy	10100.00
0005432858061	31488	Economy	10100.00
0005434943350	879	Economy	8300.00
0005434943355	879	Economy	7500.00
0005434943353	879	Economy	7500.00
0005433255072	879	Economy	7500.00
0005433255095	879	Economy	7500.00
0005434943351	879	Economy	7500.00
0005434943348	879	Economy	7500.00
0005434943349	879	Economy	7500.00
0005433255094	879	Economy	7500.00
0005434943352	879	Economy	7500.00
0005433255096	879	Economy	7500.00
0005433255079	879	Economy	7500.00
0005434943347	879	Economy	7500.00
0005433255093	879	Economy	7500.00
0005434943346	879	Economy	7500.00
0005434943354	879	Economy	7500.00
0005433255118	16238	Economy	8300.00
0005434943288	16238	Economy	8300.00
0005434943251	16238	Economy	7500.00
0005434943261	16238	Economy	7500.00
0005433255116	16238	Economy	7500.00
0005434943282	16238	Economy	7500.00
0005434943281	16238	Economy	7500.00
0005434943244	16238	Economy	7500.00
0005433255117	16238	Economy	7500.00
0005434943243	16238	Economy	7500.00
0005433255119	16238	Economy	7500.00
0005434943272	16238	Economy	7500.00
0005434943268	16238	Economy	7500.00
0005434943245	16238	Economy	7500.00
0005433255121	16238	Economy	7500.00
0005433255120	16238	Economy	7500.00
0005435858548	27620	Business	90500.00
0005433654690	27620	Business	90500.00
0005435858558	27620	Business	90500.00
0005435858557	27620	Business	90500.00
0005433654671	27620	Business	90500.00
0005433654672	27620	Business	90500.00
0005433654734	27620	Business	90500.00
0005433654668	27620	Business	90500.00
0005433654687	27620	Business	90500.00
0005433654655	27620	Economy	30200.00
0005433654707	27620	Economy	30200.00
0005433654717	27620	Economy	30200.00
0005435858556	27620	Economy	30200.00
0005433654735	27620	Economy	30200.00
0005433654718	27620	Economy	30200.00
0005435858560	27620	Economy	30200.00
0005433654732	27620	Economy	30200.00
0005435858550	27620	Economy	33200.00
0005433654681	27620	Economy	33200.00
0005433654689	27620	Economy	30200.00
0005433654656	27620	Economy	30200.00
0005433654684	27620	Economy	30200.00
0005435858547	27620	Economy	30200.00
0005433654691	27620	Economy	30200.00
0005433654698	27620	Economy	30200.00
0005433654694	27620	Economy	30200.00
0005435858546	27620	Economy	30200.00
0005435858552	27620	Economy	30200.00
0005433654708	27620	Economy	30200.00
0005433654701	27620	Economy	30200.00
0005433654692	27620	Economy	30200.00
0005433654667	27620	Economy	30200.00
0005433654688	27620	Economy	30200.00
0005433654686	27620	Economy	30200.00
0005433654702	27620	Economy	30200.00
0005433654706	27620	Economy	30200.00
0005435858553	27620	Economy	30200.00
0005433654719	27620	Economy	30200.00
0005435858562	27620	Economy	30200.00
0005435858555	27620	Economy	30200.00
0005433654733	27620	Economy	30200.00
0005435858551	27620	Economy	30200.00
0005433654709	27620	Economy	30200.00
0005433654657	27620	Economy	30200.00
0005433654697	27620	Economy	30200.00
0005435858561	27620	Economy	30200.00
0005435858554	27620	Economy	30200.00
0005435858545	27620	Economy	30200.00
0005435858559	27620	Economy	30200.00
0005433654693	27620	Economy	30200.00
0005435858549	27620	Economy	30200.00
0005433811617	14422	Economy	4400.00
0005435653029	21738	Business	9800.00
0005433367402	21738	Business	9800.00
0005433367545	21738	Business	9800.00
0005435652993	21738	Business	9800.00
0005435653018	21738	Business	9800.00
0005433367508	21738	Business	9800.00
0005435653010	21738	Business	9800.00
0005433367489	21738	Business	9800.00
0005435653012	21738	Business	9800.00
0005433367639	21738	Business	9800.00
0005433367455	21738	Business	9800.00
0005435653019	21738	Economy	3300.00
0005433367596	21738	Economy	3300.00
0005435653003	21738	Economy	3300.00
0005435653021	21738	Economy	3300.00
0005435653002	21738	Economy	3300.00
0005435653031	21738	Economy	3300.00
0005435653035	21738	Economy	3300.00
0005435653013	21738	Economy	3300.00
0005435653015	21738	Economy	3300.00
0005435653032	21738	Economy	3300.00
0005433367491	21738	Economy	3600.00
0005435653011	21738	Economy	3600.00
0005433367494	21738	Economy	3600.00
0005435653023	21738	Economy	3600.00
0005433367533	21738	Economy	3600.00
0005433367662	21738	Economy	3300.00
0005435653017	21738	Economy	3300.00
0005433367481	21738	Economy	3300.00
0005433367395	21738	Economy	3300.00
0005435653016	21738	Economy	3300.00
0005435653008	21738	Economy	3300.00
0005435653026	21738	Economy	3300.00
0005433367522	21738	Economy	3300.00
0005435652994	21738	Economy	3300.00
0005433367548	21738	Economy	3300.00
0005435653000	21738	Economy	3300.00
0005433367562	21738	Economy	3300.00
0005433367363	21738	Economy	3300.00
0005435652992	21738	Economy	3300.00
0005433367597	21738	Economy	3300.00
0005435653007	21738	Economy	3300.00
0005433367509	21738	Economy	3300.00
0005435653039	21738	Economy	3300.00
0005433367480	21738	Economy	3300.00
0005433367459	21738	Economy	3300.00
0005435653005	21738	Economy	3300.00
0005435652999	21738	Economy	3300.00
0005435653022	21738	Economy	3300.00
0005435653027	21738	Economy	3300.00
0005435653030	21738	Economy	3300.00
0005433367492	21738	Economy	3300.00
0005433367364	21738	Economy	3300.00
0005435653038	21738	Economy	3300.00
0005435653037	21738	Economy	3300.00
0005433367412	21738	Economy	3300.00
0005433367663	21738	Economy	3300.00
0005433367520	21738	Economy	3300.00
0005435653009	21738	Economy	3300.00
0005435653014	21738	Economy	3300.00
0005433367542	21738	Economy	3300.00
0005433367427	21738	Economy	3300.00
0005433367493	21738	Economy	3300.00
0005435653034	21738	Economy	3300.00
0005433367521	21738	Economy	3300.00
0005435653036	21738	Economy	3300.00
0005433367561	21738	Economy	3300.00
0005435653028	21738	Economy	3300.00
0005435653004	21738	Economy	3300.00
0005433367573	21738	Economy	3300.00
0005435652995	21738	Economy	3300.00
0005433367544	21738	Economy	3300.00
0005433367458	21738	Economy	3300.00
0005433367546	21738	Economy	3300.00
0005433367598	21738	Economy	3300.00
0005435652996	21738	Economy	3300.00
0005435653001	21738	Economy	3300.00
0005435652997	21738	Economy	3300.00
0005433367547	21738	Economy	3300.00
0005435653040	21738	Economy	3300.00
0005435653006	21738	Economy	3300.00
0005435653020	21738	Economy	3300.00
0005435653033	21738	Economy	3300.00
0005433367532	21738	Economy	3300.00
0005433367490	21738	Economy	3300.00
0005435652998	21738	Economy	3300.00
0005435653024	21738	Economy	3300.00
0005433367386	21738	Economy	3300.00
0005435653025	21738	Economy	3300.00
0005433784924	9354	Business	186200.00
0005433784939	9354	Business	186200.00
0005433805372	9354	Business	186200.00
0005433763207	9354	Business	186200.00
0005433805365	9354	Business	186200.00
0005433784929	9354	Business	186200.00
0005433784949	9354	Business	186200.00
0005432667454	9354	Business	186200.00
0005433784934	9354	Business	186200.00
0005433763211	9354	Business	186200.00
0005433805394	9354	Business	186200.00
0005433805393	9354	Business	186200.00
0005433805369	9354	Business	186200.00
0005433784954	9354	Business	186200.00
0005432657449	9354	Business	186200.00
0005433805371	9354	Business	186200.00
0005433784926	9354	Business	186200.00
0005433784932	9354	Business	186200.00
0005434170982	9354	Business	186200.00
0005433805370	9354	Business	186200.00
0005432666390	9354	Economy	68300.00
0005433805382	9354	Economy	62100.00
0005433805375	9354	Economy	62100.00
0005433763212	9354	Economy	62100.00
0005432666389	9354	Economy	62100.00
0005433805389	9354	Economy	62100.00
0005432665274	9354	Economy	62100.00
0005432657448	9354	Economy	62100.00
0005433784957	9354	Economy	62100.00
0005432666388	9354	Economy	62100.00
0005433763199	9354	Economy	62100.00
0005433763206	9354	Economy	62100.00
0005433763203	9354	Economy	62100.00
0005433784948	9354	Economy	62100.00
0005434170948	9354	Economy	62100.00
0005433784950	9354	Economy	62100.00
0005433805361	9354	Economy	62100.00
0005433805398	9354	Economy	62100.00
0005434170899	9354	Economy	62100.00
0005433805384	9354	Economy	62100.00
0005433784942	9354	Economy	62100.00
0005433805388	9354	Economy	62100.00
0005433805359	9354	Economy	62100.00
0005433784927	9354	Economy	62100.00
0005433784951	9354	Economy	62100.00
0005433784940	9354	Economy	62100.00
0005433805376	9354	Economy	62100.00
0005434170964	9354	Economy	62100.00
0005433805379	9354	Economy	62100.00
0005433805378	9354	Economy	62100.00
0005433805386	9354	Economy	62100.00
0005434170917	9354	Economy	62100.00
0005433805357	9354	Economy	62100.00
0005434170960	9354	Economy	62100.00
0005433805387	9354	Economy	62100.00
0005433784958	9354	Economy	62100.00
0005433805358	9354	Economy	62100.00
0005433805374	9354	Economy	62100.00
0005433784928	9354	Economy	62100.00
0005433784931	9354	Economy	62100.00
0005433805364	9354	Economy	62100.00
0005433763205	9354	Economy	62100.00
0005433805360	9354	Economy	62100.00
0005433805392	9354	Economy	62100.00
0005433805380	9354	Economy	62100.00
0005433805399	9354	Economy	62100.00
0005433763200	9354	Economy	62100.00
0005433784936	9354	Economy	62100.00
0005433805395	9354	Economy	62100.00
0005434170981	9354	Economy	62100.00
0005433805366	9354	Economy	62100.00
0005433763201	9354	Economy	62100.00
0005433784933	9354	Economy	62100.00
0005433805391	9354	Economy	62100.00
0005433784937	9354	Economy	62100.00
0005433784945	9354	Economy	62100.00
0005434170965	9354	Economy	68300.00
0005433805397	9354	Economy	62100.00
0005433784953	9354	Economy	62100.00
0005434170966	9354	Economy	62100.00
0005433805383	9354	Economy	68300.00
0005433784930	9354	Economy	62100.00
0005432665273	9354	Economy	68300.00
0005433784947	9354	Economy	62100.00
0005433805368	9354	Economy	62100.00
0005433805367	9354	Economy	62100.00
0005433784925	9354	Economy	62100.00
0005433805381	9354	Economy	62100.00
0005433805390	9354	Economy	62100.00
0005433784944	9354	Economy	62100.00
0005433763208	9354	Economy	62100.00
0005433784935	9354	Economy	62100.00
0005433763204	9354	Economy	62100.00
0005433763202	9354	Economy	62100.00
0005433805363	9354	Economy	62100.00
0005433784952	9354	Economy	62100.00
0005432665275	9354	Economy	62100.00
0005434270189	9354	Economy	62100.00
0005433805362	9354	Economy	62100.00
0005432667455	9354	Economy	62100.00
0005433763209	9354	Economy	62100.00
0005433805373	9354	Economy	62100.00
0005433784946	9354	Economy	62100.00
0005433805396	9354	Economy	62100.00
0005433784955	9354	Economy	62100.00
0005432667453	9354	Economy	62100.00
0005433784938	9354	Economy	62100.00
0005434170961	9354	Economy	62100.00
0005433763210	9354	Economy	62100.00
0005433784943	9354	Economy	62100.00
0005432657447	9354	Economy	62100.00
0005433784959	9354	Economy	62100.00
0005433805377	9354	Economy	62100.00
0005433805385	9354	Economy	62100.00
0005434170857	9354	Economy	62100.00
0005433784956	9354	Economy	62100.00
0005433784941	9354	Economy	62100.00
0005434171061	26246	Business	186200.00
0005433784716	26246	Business	186200.00
0005432666370	26246	Business	186200.00
0005433763091	26246	Business	186200.00
0005433784752	26246	Business	186200.00
0005433805014	26246	Business	186200.00
0005432663013	26246	Business	186200.00
0005433784711	26246	Business	186200.00
0005434151704	26246	Business	186200.00
0005434271310	26246	Business	186200.00
0005434171058	26246	Business	186200.00
0005433784674	26246	Business	186200.00
0005433805123	26246	Business	186200.00
0005433784457	26246	Business	186200.00
0005433784544	26246	Business	186200.00
0005433763090	26246	Business	186200.00
0005434171048	26246	Business	186200.00
0005433763083	26246	Economy	68300.00
0005434270204	26246	Economy	68300.00
0005433805000	26246	Economy	62100.00
0005433804962	26246	Economy	62100.00
0005433784714	26246	Economy	62100.00
0005433763121	26246	Economy	62100.00
0005434171051	26246	Economy	62100.00
0005434171059	26246	Economy	62100.00
0005433784726	26246	Economy	62100.00
0005434171052	26246	Economy	62100.00
0005434171047	26246	Economy	62100.00
0005433805215	26246	Economy	62100.00
0005433805063	26246	Economy	62100.00
0005434269101	26246	Economy	62100.00
0005434151705	26246	Economy	62100.00
0005433784575	26246	Economy	62100.00
0005433805006	26246	Economy	62100.00
0005434171053	26246	Economy	62100.00
0005433804974	26246	Economy	62100.00
0005433784604	26246	Economy	62100.00
0005433805031	26246	Economy	62100.00
0005434151702	26246	Economy	62100.00
0005433804928	26246	Economy	62100.00
0005433804866	26246	Economy	62100.00
0005433805030	26246	Economy	62100.00
0005433784545	26246	Economy	62100.00
0005433804852	26246	Economy	62100.00
0005433805147	26246	Economy	62100.00
0005433804996	26246	Economy	62100.00
0005434171062	26246	Economy	62100.00
0005433784546	26246	Economy	62100.00
0005433784547	26246	Economy	62100.00
0005433784492	26246	Economy	62100.00
0005434171046	26246	Economy	62100.00
0005433804909	26246	Economy	62100.00
0005434171056	26246	Economy	62100.00
0005433805043	26246	Economy	62100.00
0005433784578	26246	Economy	62100.00
0005433784647	26246	Economy	62100.00
0005433784598	26246	Economy	62100.00
0005433805044	26246	Economy	62100.00
0005434171049	26246	Economy	62100.00
0005433784574	26246	Economy	62100.00
0005433784681	26246	Economy	62100.00
0005433804914	26246	Economy	62100.00
0005433784541	26246	Economy	62100.00
0005434171057	26246	Economy	62100.00
0005432666371	26246	Economy	62100.00
0005433763111	26246	Economy	62100.00
0005433805214	26246	Economy	62100.00
0005433784648	26246	Economy	62100.00
0005435269748	26246	Economy	68300.00
0005433805120	26246	Economy	62100.00
0005433804867	26246	Economy	62100.00
0005434151703	26246	Economy	68300.00
0005433784515	26246	Economy	68300.00
0005433784617	26246	Economy	62100.00
0005434171060	26246	Economy	62100.00
0005433763014	26246	Economy	62100.00
0005433784683	26246	Economy	62100.00
0005433805152	26246	Economy	62100.00
0005433784727	26246	Economy	62100.00
0005434271309	26246	Economy	62100.00
0005433784632	26246	Economy	62100.00
0005433784715	26246	Economy	62100.00
0005433804943	26246	Economy	62100.00
0005434269100	26246	Economy	62100.00
0005434171054	26246	Economy	62100.00
0005433805042	26246	Economy	62100.00
0005433763100	26246	Economy	62100.00
0005433784663	26246	Economy	62100.00
0005433804910	26246	Economy	62100.00
0005433805145	26246	Economy	62100.00
0005433784618	26246	Economy	62100.00
0005433763113	26246	Economy	62100.00
0005433805138	26246	Economy	62100.00
0005433784701	26246	Economy	62100.00
0005433804931	26246	Economy	62100.00
0005432663014	26246	Economy	62100.00
0005434270205	26246	Economy	62100.00
0005433784684	26246	Economy	62100.00
0005433784633	26246	Economy	62100.00
0005433784625	26246	Economy	62100.00
0005433784476	26246	Economy	62100.00
0005433784673	26246	Economy	62100.00
0005433763082	26246	Economy	62100.00
0005433805146	26246	Economy	62100.00
0005433804975	26246	Economy	62100.00
0005433784537	26246	Economy	62100.00
0005433804963	26246	Economy	62100.00
0005433804992	26246	Economy	62100.00
0005433784710	26246	Economy	62100.00
0005433804797	26246	Economy	62100.00
0005434171055	26246	Economy	62100.00
0005433784475	26246	Economy	62100.00
0005433784694	26246	Economy	62100.00
0005434171050	26246	Economy	62100.00
0005434151706	26246	Economy	62100.00
0005435135670	4890	Economy	5900.00
0005435929619	4890	Economy	5300.00
0005435135667	4890	Economy	5300.00
0005435135668	4890	Economy	5300.00
0005435135671	4890	Economy	5300.00
0005435135672	4890	Economy	5300.00
0005435135669	4890	Economy	5300.00
0005435929621	4890	Economy	5300.00
0005435929644	33026	Economy	5900.00
0005435135626	33026	Economy	5300.00
0005435135621	33026	Economy	5300.00
0005435135628	33026	Economy	5300.00
0005435929642	33026	Economy	5300.00
0005435135629	33026	Economy	5300.00
0005435929643	33026	Economy	5300.00
0005435135620	33026	Economy	5300.00
0005434983287	9457	Economy	19700.00
0005434217952	9457	Economy	19700.00
0005434217935	9457	Economy	17900.00
0005434217928	9457	Economy	17900.00
0005434983284	9457	Economy	17900.00
0005434217922	9457	Economy	17900.00
0005434217926	9457	Economy	17900.00
0005434983288	9457	Economy	17900.00
0005434217921	9457	Economy	17900.00
0005434217912	9457	Economy	17900.00
0005434983286	9457	Economy	17900.00
0005434217934	9457	Economy	17900.00
0005434217929	9457	Economy	17900.00
0005434983285	9457	Economy	17900.00
0005434217968	27344	Economy	17900.00
0005434983238	27344	Economy	17900.00
0005434983251	27344	Economy	17900.00
0005434983232	27344	Economy	17900.00
0005434217969	27344	Economy	17900.00
0005434983252	27344	Economy	17900.00
0005434983231	27344	Economy	17900.00
0005434983235	27344	Economy	17900.00
0005434983255	27344	Economy	17900.00
0005434217971	27344	Economy	17900.00
0005434217967	27344	Economy	17900.00
0005434983236	27344	Economy	17900.00
0005434217966	27344	Economy	17900.00
0005434217970	27344	Economy	17900.00
0005433985387	24237	Business	36400.00
0005433960333	24237	Business	36400.00
0005433985384	24237	Business	36400.00
0005433960094	24237	Business	36400.00
0005433960317	24237	Business	36400.00
0005433960189	24237	Business	36400.00
0005433960350	24237	Business	36400.00
0005433960257	24237	Business	36400.00
0005433960270	24237	Business	36400.00
0005433960339	24237	Business	36400.00
0005433960325	24237	Business	36400.00
0005433985484	24237	Business	36400.00
0005433960156	24237	Business	36400.00
0005433960377	24237	Business	36400.00
0005433960190	24237	Business	36400.00
0005433960253	24237	Business	36400.00
0005433960291	24237	Business	36400.00
0005433985416	24237	Business	36400.00
0005433960368	24237	Economy	13400.00
0005433985498	24237	Economy	12100.00
0005433960251	24237	Economy	12100.00
0005433960078	24237	Economy	12100.00
0005433985357	24237	Economy	12100.00
0005433960110	24237	Economy	12100.00
0005433960229	24237	Economy	12100.00
0005433960296	24237	Economy	12100.00
0005433985425	24237	Economy	12100.00
0005433960004	24237	Economy	12100.00
0005433960103	24237	Economy	12100.00
0005433960268	24237	Economy	12100.00
0005433985457	24237	Economy	12100.00
0005433960369	24237	Economy	12100.00
0005433985327	24237	Economy	12100.00
0005433985362	24237	Economy	12100.00
0005433985356	24237	Economy	12100.00
0005433960328	24237	Economy	12100.00
0005433960182	24237	Economy	12100.00
0005433985427	24237	Economy	12100.00
0005433960300	24237	Economy	12100.00
0005433960109	24237	Economy	12100.00
0005433985193	24237	Economy	12100.00
0005433960329	24237	Economy	12100.00
0005433985391	24237	Economy	12100.00
0005433985328	24237	Economy	12100.00
0005433985478	24237	Economy	12100.00
0005433959996	24237	Economy	12100.00
0005433960374	24237	Economy	12100.00
0005433985429	24237	Economy	12100.00
0005433960276	24237	Economy	12100.00
0005433985448	24237	Economy	12100.00
0005433960197	24237	Economy	12100.00
0005433985390	24237	Economy	12100.00
0005433960336	24237	Economy	12100.00
0005433985371	24237	Economy	12100.00
0005433985488	24237	Economy	12100.00
0005433960293	24237	Economy	12100.00
0005433960125	24237	Economy	12100.00
0005433960254	24237	Economy	12100.00
0005433985310	24237	Economy	12100.00
0005433960376	24237	Economy	12100.00
0005433985468	24237	Economy	12100.00
0005433960171	24237	Economy	12100.00
0005433960378	24237	Economy	12100.00
0005433960287	24237	Economy	12100.00
0005433960318	24237	Economy	12100.00
0005433960342	24237	Economy	12100.00
0005433960288	24237	Economy	12100.00
0005433985447	24237	Economy	12100.00
0005433960148	24237	Economy	12100.00
0005433960299	24237	Economy	12100.00
0005433960370	24237	Economy	12100.00
0005433960228	24237	Economy	12100.00
0005433960373	24237	Economy	12100.00
0005433960225	24237	Economy	12100.00
0005433960269	24237	Economy	12100.00
0005433960252	24237	Economy	12100.00
0005433960349	24237	Economy	12100.00
0005433960292	24237	Economy	12100.00
0005433960039	24237	Economy	12100.00
0005433960040	24237	Economy	12100.00
0005433985388	24237	Economy	12100.00
0005433985455	24237	Economy	12100.00
0005433985487	24237	Economy	12100.00
0005433985489	24237	Economy	12100.00
0005433985485	24237	Economy	12100.00
0005433960271	24237	Economy	12100.00
0005433960157	24237	Economy	12100.00
0005433960155	24237	Economy	12100.00
0005433985385	24237	Economy	12100.00
0005433960309	24237	Economy	12100.00
0005433960314	24237	Economy	12100.00
0005433985428	24237	Economy	12100.00
0005433985486	24237	Economy	12100.00
0005433960315	24237	Economy	12100.00
0005433985386	24237	Economy	12100.00
0005433960353	24237	Economy	12100.00
0005433960319	24237	Economy	12100.00
0005433960308	24237	Economy	12100.00
0005433960367	24237	Economy	12100.00
0005433985456	24237	Economy	12100.00
0005433985192	24237	Economy	12100.00
0005433960079	24237	Economy	12100.00
0005433960283	24237	Economy	12100.00
0005433959975	24237	Economy	12100.00
0005433985469	24237	Economy	12100.00
0005433960357	24237	Economy	12100.00
0005433985353	24237	Economy	12100.00
0005433985444	24237	Economy	12100.00
0005433959915	24237	Economy	12100.00
0005433960803	25964	Business	36400.00
0005433960800	25964	Business	36400.00
0005433985880	25964	Business	36400.00
0005433960798	25964	Business	36400.00
0005433985913	25964	Business	36400.00
0005433985882	25964	Business	36400.00
0005433985917	25964	Business	36400.00
0005433960810	25964	Business	36400.00
0005433985898	25964	Business	36400.00
0005433985903	25964	Business	36400.00
0005433985896	25964	Business	36400.00
0005433960801	25964	Business	36400.00
0005433985878	25964	Business	36400.00
0005433985888	25964	Business	36400.00
0005433985925	25964	Economy	13400.00
0005433960806	25964	Economy	13400.00
0005433960828	25964	Economy	13400.00
0005433985884	25964	Economy	12100.00
0005433985918	25964	Economy	12100.00
0005433985906	25964	Economy	12100.00
0005433960802	25964	Economy	12100.00
0005433985921	25964	Economy	12100.00
0005433960825	25964	Economy	12100.00
0005433960822	25964	Economy	12100.00
0005433985893	25964	Economy	12100.00
0005433960799	25964	Economy	12100.00
0005433960844	25964	Economy	12100.00
0005433985916	25964	Economy	12100.00
0005433960836	25964	Economy	12100.00
0005433985895	25964	Economy	12100.00
0005433985890	25964	Economy	12100.00
0005433960832	25964	Economy	12100.00
0005433960807	25964	Economy	12100.00
0005433985914	25964	Economy	12100.00
0005433960794	25964	Economy	12100.00
0005433960846	25964	Economy	12100.00
0005433985923	25964	Economy	12100.00
0005433960805	25964	Economy	12100.00
0005433960797	25964	Economy	12100.00
0005433960847	25964	Economy	12100.00
0005433985924	25964	Economy	12100.00
0005433960833	25964	Economy	12100.00
0005433960795	25964	Economy	12100.00
0005433960813	25964	Economy	12100.00
0005433985883	25964	Economy	12100.00
0005433960819	25964	Economy	12100.00
0005433985905	25964	Economy	12100.00
0005433960829	25964	Economy	12100.00
0005433985908	25964	Economy	12100.00
0005433960793	25964	Economy	12100.00
0005433960796	25964	Economy	12100.00
0005433985891	25964	Economy	12100.00
0005433985910	25964	Economy	12100.00
0005433960845	25964	Economy	12100.00
0005433985899	25964	Economy	12100.00
0005433960817	25964	Economy	12100.00
0005433985879	25964	Economy	12100.00
0005433985901	25964	Economy	12100.00
0005433985920	25964	Economy	12100.00
0005433960823	25964	Economy	12100.00
0005433960840	25964	Economy	12100.00
0005433960821	25964	Economy	12100.00
0005433960843	25964	Economy	12100.00
0005433960834	25964	Economy	12100.00
0005433985915	25964	Economy	12100.00
0005433960831	25964	Economy	12100.00
0005433960824	25964	Economy	12100.00
0005433985900	25964	Economy	12100.00
0005433985912	25964	Economy	12100.00
0005433960837	25964	Economy	12100.00
0005433985892	25964	Economy	12100.00
0005433960848	25964	Economy	12100.00
0005433985889	25964	Economy	12100.00
0005433985885	25964	Economy	12100.00
0005433960827	25964	Economy	12100.00
0005433960815	25964	Economy	12100.00
0005433960849	25964	Economy	12100.00
0005433985897	25964	Economy	12100.00
0005433960812	25964	Economy	12100.00
0005433960808	25964	Economy	12100.00
0005433960841	25964	Economy	12100.00
0005433960816	25964	Economy	12100.00
0005433985926	25964	Economy	12100.00
0005433985909	25964	Economy	12100.00
0005433960826	25964	Economy	12100.00
0005433960842	25964	Economy	12100.00
0005433985902	25964	Economy	12100.00
0005433960835	25964	Economy	12100.00
0005433960830	25964	Economy	12100.00
0005433985887	25964	Economy	12100.00
0005433985907	25964	Economy	12100.00
0005433960809	25964	Economy	12100.00
0005433960818	25964	Economy	12100.00
0005433960804	25964	Economy	12100.00
0005433960820	25964	Economy	12100.00
0005433985881	25964	Economy	12100.00
0005433985904	25964	Economy	12100.00
0005433985919	25964	Economy	12100.00
0005433985886	25964	Economy	12100.00
0005433985911	25964	Economy	12100.00
0005433960850	25964	Economy	12100.00
0005433985894	25964	Economy	12100.00
0005433960814	25964	Economy	12100.00
0005433960839	25964	Economy	12100.00
0005433960811	25964	Economy	12100.00
0005433985922	25964	Economy	12100.00
0005433960838	25964	Economy	12100.00
0005434480327	945	Economy	25400.00
0005434480316	945	Economy	25400.00
0005434480326	945	Economy	25400.00
0005433165824	945	Economy	25400.00
0005434480338	945	Economy	23100.00
0005432269495	945	Economy	23100.00
0005434480321	945	Economy	23100.00
0005434480330	945	Economy	23100.00
0005434480339	945	Economy	23100.00
0005434480319	945	Economy	23100.00
0005433165828	945	Economy	23100.00
0005433165856	945	Economy	23100.00
0005433165855	945	Economy	23100.00
0005434480328	945	Economy	23100.00
0005434480334	945	Economy	23100.00
0005434480337	945	Economy	23100.00
0005434480320	945	Economy	23100.00
0005434480323	945	Economy	23100.00
0005434480333	945	Economy	23100.00
0005434480336	945	Economy	23100.00
0005432269497	945	Economy	23100.00
0005433165816	945	Economy	23100.00
0005432269498	945	Economy	23100.00
0005433165843	945	Economy	23100.00
0005434480332	945	Economy	23100.00
0005434480329	945	Economy	23100.00
0005434480325	945	Economy	23100.00
0005433165777	945	Economy	23100.00
0005433165852	945	Economy	23100.00
0005434480318	945	Economy	23100.00
0005434480331	945	Economy	23100.00
0005434480322	945	Economy	23100.00
0005433165796	945	Economy	23100.00
0005433165818	945	Economy	23100.00
0005434480335	945	Economy	23100.00
0005433165819	945	Economy	23100.00
0005434480317	945	Economy	23100.00
0005434480340	945	Economy	23100.00
0005432269496	945	Economy	23100.00
0005433165827	945	Economy	23100.00
0005434480324	945	Economy	23100.00
0005433165797	945	Economy	23100.00
0005433165820	945	Economy	23100.00
0005433165817	945	Economy	23100.00
0005433165842	945	Economy	23100.00
0005434480159	16563	Economy	25400.00
0005433165900	16563	Economy	25400.00
0005434480131	16563	Economy	25400.00
0005433165906	16563	Economy	25400.00
0005434480194	16563	Economy	23100.00
0005433165896	16563	Economy	23100.00
0005434480282	16563	Economy	23100.00
0005434480054	16563	Economy	23100.00
0005434480283	16563	Economy	23100.00
0005433165904	16563	Economy	23100.00
0005434480132	16563	Economy	23100.00
0005434480116	16563	Economy	23100.00
0005434480099	16563	Economy	23100.00
0005434480111	16563	Economy	23100.00
0005433165897	16563	Economy	23100.00
0005434480155	16563	Economy	23100.00
0005433165899	16563	Economy	23100.00
0005434480060	16563	Economy	23100.00
0005434480158	16563	Economy	23100.00
0005434480061	16563	Economy	23100.00
0005434480081	16563	Economy	23100.00
0005434480038	16563	Economy	23100.00
0005434480115	16563	Economy	23100.00
0005433165903	16563	Economy	23100.00
0005434480079	16563	Economy	23100.00
0005433165907	16563	Economy	23100.00
0005434480129	16563	Economy	23100.00
0005434480130	16563	Economy	23100.00
0005434480205	16563	Economy	23100.00
0005434480217	16563	Economy	23100.00
0005434480098	16563	Economy	23100.00
0005433165902	16563	Economy	23100.00
0005434480200	16563	Economy	23100.00
0005434480080	16563	Economy	23100.00
0005434480204	16563	Economy	23100.00
0005434480218	16563	Economy	23100.00
0005433165901	16563	Economy	23100.00
0005434480114	16563	Economy	23100.00
0005434480203	16563	Economy	23100.00
0005433165905	16563	Economy	23100.00
0005433165908	16563	Economy	23100.00
0005433165898	16563	Economy	23100.00
0005435150018	10316	Economy	17000.00
0005435150019	10316	Economy	17000.00
0005435142566	10316	Economy	17000.00
0005435150021	10316	Economy	17000.00
0005435142558	10316	Economy	15400.00
0005435142569	10316	Economy	15400.00
0005435386490	10316	Economy	15400.00
0005435150020	10316	Economy	15400.00
0005435150015	10316	Economy	15400.00
0005435386529	10316	Economy	15400.00
0005435142560	10316	Economy	15400.00
0005435386523	10316	Economy	15400.00
0005435142562	10316	Economy	15400.00
0005435142570	10316	Economy	15400.00
0005435386524	10316	Economy	15400.00
0005435386498	10316	Economy	15400.00
0005435150010	10316	Economy	15400.00
0005435150012	10316	Economy	15400.00
0005435150017	10316	Economy	15400.00
0005435150009	10316	Economy	15400.00
0005435386504	10316	Economy	15400.00
0005435142557	10316	Economy	15400.00
0005435142568	10316	Economy	15400.00
0005435142561	10316	Economy	15400.00
0005435150013	10316	Economy	15400.00
0005435150008	10316	Economy	15400.00
0005435150016	10316	Economy	15400.00
0005435142564	10316	Economy	15400.00
0005435142567	10316	Economy	15400.00
0005435142563	10316	Economy	15400.00
0005435150011	10316	Economy	15400.00
0005435386491	10316	Economy	15400.00
0005435142559	10316	Economy	15400.00
0005435150014	10316	Economy	15400.00
0005435142565	10316	Economy	15400.00
0005435149895	21914	Economy	17000.00
0005435142500	21914	Economy	17000.00
0005435142459	21914	Economy	17000.00
0005435142490	21914	Economy	17000.00
0005435149857	21914	Economy	15400.00
0005435142411	21914	Economy	15400.00
0005435142475	21914	Economy	15400.00
0005435142410	21914	Economy	15400.00
0005433289852	21914	Economy	15400.00
0005435142496	21914	Economy	15400.00
0005435142435	21914	Economy	15400.00
0005435142452	21914	Economy	15400.00
0005435149904	21914	Economy	15400.00
0005435142453	21914	Economy	15400.00
0005435142447	21914	Economy	15400.00
0005435142442	21914	Economy	15400.00
0005435149899	21914	Economy	15400.00
0005435142409	21914	Economy	15400.00
0005435142415	21914	Economy	15400.00
0005435149799	21914	Economy	15400.00
0005435142444	21914	Economy	15400.00
0005435142474	21914	Economy	15400.00
0005435149923	21914	Economy	15400.00
0005435149905	21914	Economy	15400.00
0005433289858	21914	Economy	15400.00
0005435149922	21914	Economy	15400.00
0005433289851	21914	Economy	15400.00
0005435142489	21914	Economy	15400.00
0005435142477	21914	Economy	15400.00
0005435142491	21914	Economy	15400.00
0005435149908	21914	Economy	15400.00
0005433289855	21914	Economy	15400.00
0005435142457	21914	Economy	15400.00
0005435149907	21914	Economy	15400.00
0005435149917	21914	Economy	15400.00
0005433289853	21914	Economy	15400.00
0005435149891	21914	Economy	15400.00
0005435142476	21914	Economy	15400.00
0005435142441	21914	Economy	15400.00
0005433289857	21914	Economy	15400.00
0005435142458	21914	Economy	15400.00
0005433289854	21914	Economy	15400.00
0005435149843	21914	Economy	15400.00
0005435149898	21914	Economy	15400.00
0005435149903	21914	Economy	15400.00
0005435142414	21914	Economy	15400.00
0005435149856	21914	Economy	15400.00
0005435149798	21914	Economy	15400.00
0005433289856	21914	Economy	15400.00
0005433289850	21914	Economy	15400.00
0005435529046	11180	Business	57200.00
0005434573337	11180	Business	57200.00
0005435319494	11180	Business	57200.00
0005435545663	11180	Business	57200.00
0005435529144	11180	Business	57200.00
0005435545664	11180	Business	57200.00
0005435529092	11180	Business	57200.00
0005435545689	11180	Business	57200.00
0005435529104	11180	Business	57200.00
0005435502231	11180	Business	57200.00
0005435502163	11180	Business	57200.00
0005435502115	11180	Economy	19100.00
0005435529131	11180	Economy	19100.00
0005435529034	11180	Economy	19100.00
0005435529042	11180	Economy	19100.00
0005434573335	11180	Economy	19100.00
0005435319503	11180	Economy	19100.00
0005435529052	11180	Economy	19100.00
0005435502162	11180	Economy	19100.00
0005435502205	11180	Economy	19100.00
0005434573339	11180	Economy	21000.00
0005434573340	11180	Economy	21000.00
0005435529100	11180	Economy	21000.00
0005435529009	11180	Economy	21000.00
0005435529047	11180	Economy	19100.00
0005435502069	11180	Economy	19100.00
0005435529060	11180	Economy	19100.00
0005435319496	11180	Economy	19100.00
0005435545687	11180	Economy	19100.00
0005434573345	11180	Economy	19100.00
0005434573344	11180	Economy	19100.00
0005434573336	11180	Economy	19100.00
0005434573342	11180	Economy	19100.00
0005435545653	11180	Economy	19100.00
0005435529132	11180	Economy	19100.00
0005435545688	11180	Economy	19100.00
0005435545665	11180	Economy	19100.00
0005435319485	11180	Economy	19100.00
0005435502232	11180	Economy	19100.00
0005435502092	11180	Economy	19100.00
0005435319514	11180	Economy	19100.00
0005434573341	11180	Economy	19100.00
0005434573346	11180	Economy	19100.00
0005435502112	11180	Economy	19100.00
0005435529031	11180	Economy	19100.00
0005435502144	11180	Economy	19100.00
0005435545645	11180	Economy	19100.00
0005435529103	11180	Economy	19100.00
0005435502190	11180	Economy	19100.00
0005435529071	11180	Economy	19100.00
0005435545654	11180	Economy	19100.00
0005435502124	11180	Economy	19100.00
0005435545686	11180	Economy	19100.00
0005435529070	11180	Economy	19100.00
0005434573333	11180	Economy	19100.00
0005435529029	11180	Economy	19100.00
0005434573332	11180	Economy	19100.00
0005435502106	11180	Economy	19100.00
0005434573343	11180	Economy	19100.00
0005435545666	11180	Economy	19100.00
0005435502113	11180	Economy	19100.00
0005435545670	11180	Economy	19100.00
0005435529105	11180	Economy	19100.00
0005435319486	11180	Economy	19100.00
0005435545690	11180	Economy	19100.00
0005434573338	11180	Economy	19100.00
0005435528970	11180	Economy	19100.00
0005435502068	11180	Economy	19100.00
0005435529135	11180	Economy	19100.00
0005434573334	11180	Economy	19100.00
0005435502134	11180	Economy	19100.00
0005435545652	11180	Economy	19100.00
0005435319489	11180	Economy	19100.00
0005435529035	11180	Economy	19100.00
0005435529036	11180	Economy	19100.00
0005435319495	11180	Economy	19100.00
0005435529055	11180	Economy	19100.00
0005435502148	11180	Economy	19100.00
0005435502191	11180	Economy	19100.00
0005435517897	20941	Business	57200.00
0005435508364	20941	Business	57200.00
0005435319585	20941	Business	57200.00
0005434573267	20941	Business	57200.00
0005435502304	20941	Business	57200.00
0005435319583	20941	Business	57200.00
0005435508356	20941	Business	57200.00
0005434573221	20941	Business	57200.00
0005435517906	20941	Business	57200.00
0005435517902	20941	Business	57200.00
0005435319584	20941	Business	57200.00
0005435319578	20941	Economy	19100.00
0005435319580	20941	Economy	19100.00
0005435502298	20941	Economy	19100.00
0005435502301	20941	Economy	19100.00
0005435502307	20941	Economy	19100.00
0005435517913	20941	Economy	19100.00
0005435502288	20941	Economy	19100.00
0005435508358	20941	Economy	19100.00
0005435502302	20941	Economy	19100.00
0005434573194	20941	Economy	21000.00
0005435502293	20941	Economy	21000.00
0005435502286	20941	Economy	21000.00
0005435517909	20941	Economy	21000.00
0005435517911	20941	Economy	19100.00
0005435508365	20941	Economy	19100.00
0005435517901	20941	Economy	19100.00
0005435508360	20941	Economy	19100.00
0005435319579	20941	Economy	19100.00
0005435508354	20941	Economy	19100.00
0005434573232	20941	Economy	19100.00
0005435502290	20941	Economy	19100.00
0005435508362	20941	Economy	19100.00
0005434573219	20941	Economy	19100.00
0005435319581	20941	Economy	19100.00
0005435508355	20941	Economy	19100.00
0005434573237	20941	Economy	19100.00
0005434573238	20941	Economy	19100.00
0005435502303	20941	Economy	19100.00
0005435502296	20941	Economy	19100.00
0005435508353	20941	Economy	19100.00
0005435517898	20941	Economy	19100.00
0005435517912	20941	Economy	19100.00
0005435502299	20941	Economy	19100.00
0005435502300	20941	Economy	19100.00
0005432291928	20941	Economy	19100.00
0005435508363	20941	Economy	19100.00
0005435502306	20941	Economy	19100.00
0005435502297	20941	Economy	19100.00
0005435517905	20941	Economy	19100.00
0005435502289	20941	Economy	19100.00
0005435517908	20941	Economy	19100.00
0005435502305	20941	Economy	19100.00
0005435508361	20941	Economy	19100.00
0005434573203	20941	Economy	19100.00
0005435517917	20941	Economy	19100.00
0005435517904	20941	Economy	19100.00
0005434573269	20941	Economy	19100.00
0005435517896	20941	Economy	19100.00
0005434573112	20941	Economy	19100.00
0005432291929	20941	Economy	19100.00
0005435517899	20941	Economy	19100.00
0005435508352	20941	Economy	19100.00
0005435319577	20941	Economy	19100.00
0005435502287	20941	Economy	19100.00
0005435508366	20941	Economy	19100.00
0005435508357	20941	Economy	19100.00
0005435502291	20941	Economy	19100.00
0005435517910	20941	Economy	19100.00
0005434573196	20941	Economy	19100.00
0005435517914	20941	Economy	19100.00
0005435517903	20941	Economy	19100.00
0005435517900	20941	Economy	19100.00
0005434573218	20941	Economy	19100.00
0005434573195	20941	Economy	19100.00
0005435502295	20941	Economy	19100.00
0005435502292	20941	Economy	19100.00
0005435517916	20941	Economy	19100.00
0005435319582	20941	Economy	19100.00
0005435517907	20941	Economy	19100.00
0005434573239	20941	Economy	19100.00
0005435517915	20941	Economy	19100.00
0005435502294	20941	Economy	19100.00
0005435508359	20941	Economy	19100.00
0005433927421	24309	Economy	18800.00
0005433927413	24309	Economy	17100.00
0005433683337	24309	Economy	17100.00
0005433927415	24309	Economy	17100.00
0005433927411	24309	Economy	17100.00
0005433683333	24309	Economy	17100.00
0005433927414	24309	Economy	17100.00
0005433683334	24309	Economy	17100.00
0005433927418	24309	Economy	17100.00
0005433927419	24309	Economy	17100.00
0005433683338	24309	Economy	17100.00
0005433927401	24309	Economy	17100.00
0005433927409	24309	Economy	17100.00
0005433683339	24309	Economy	17100.00
0005433683336	24309	Economy	17100.00
0005433683340	24309	Economy	17100.00
0005433683335	24309	Economy	17100.00
0005433927408	24309	Economy	17100.00
0005433683332	24309	Economy	17100.00
0005433927412	24309	Economy	17100.00
0005433927441	29275	Economy	18800.00
0005433927439	29275	Economy	17100.00
0005433683307	29275	Economy	17100.00
0005433927437	29275	Economy	17100.00
0005433927442	29275	Economy	17100.00
0005433683304	29275	Economy	17100.00
0005433927435	29275	Economy	17100.00
0005433927443	29275	Economy	17100.00
0005433683331	29275	Economy	17100.00
0005433683303	29275	Economy	17100.00
0005433683301	29275	Economy	17100.00
0005433927438	29275	Economy	17100.00
0005433927436	29275	Economy	17100.00
0005433683313	29275	Economy	17100.00
0005433683319	29275	Economy	17100.00
0005433683330	29275	Economy	17100.00
0005433927440	29275	Economy	17100.00
0005432692717	3036	Business	10300.00
0005432692876	3036	Business	10300.00
0005432692795	3036	Business	10300.00
0005432692748	3036	Business	10300.00
0005432692905	3036	Economy	3400.00
0005432692642	3036	Economy	3800.00
0005432692749	3036	Economy	3400.00
0005432692824	3036	Economy	3400.00
0005432692656	3036	Economy	3400.00
0005432692780	3036	Economy	3400.00
0005432692872	3036	Economy	3400.00
0005432692669	3036	Economy	3400.00
0005432692691	3036	Economy	3400.00
0005432692815	3036	Economy	3400.00
0005432692875	3036	Economy	3400.00
0005432692742	3036	Economy	3400.00
0005432692811	3036	Economy	3400.00
0005432692833	3036	Economy	3400.00
0005432692702	3036	Economy	3400.00
0005432692807	3036	Economy	3400.00
0005432692692	3036	Economy	3400.00
0005432692835	3036	Economy	3400.00
0005432692858	3036	Economy	3400.00
0005432692816	3036	Economy	3400.00
0005432692763	3036	Economy	3400.00
0005432692834	3036	Economy	3400.00
0005432692920	3036	Economy	3400.00
0005432217776	3037	Business	10300.00
0005432706763	3037	Business	10300.00
0005433123793	3037	Business	10300.00
0005432706756	3037	Business	10300.00
0005433123699	3037	Business	10300.00
0005432706775	3037	Business	10300.00
0005433123723	3037	Business	10300.00
0005432880695	3037	Business	10300.00
0005433123771	3037	Economy	3400.00
0005432706768	3037	Economy	3400.00
0005432706755	3037	Economy	3400.00
0005432706766	3037	Economy	3400.00
0005432880671	3037	Economy	3400.00
0005433123758	3037	Economy	3400.00
0005433123718	3037	Economy	3400.00
0005432706764	3037	Economy	3400.00
0005432706753	3037	Economy	3800.00
0005432706776	3037	Economy	3800.00
0005432880736	3037	Economy	3800.00
0005432880658	3037	Economy	3400.00
0005433123784	3037	Economy	3400.00
0005432880635	3037	Economy	3400.00
0005432706767	3037	Economy	3400.00
0005433123748	3037	Economy	3400.00
0005433123783	3037	Economy	3400.00
0005432706759	3037	Economy	3400.00
0005432706754	3037	Economy	3400.00
0005433123703	3037	Economy	3400.00
0005432706758	3037	Economy	3400.00
0005432880688	3037	Economy	3400.00
0005432880657	3037	Economy	3400.00
0005432706762	3037	Economy	3400.00
0005433123800	3037	Economy	3400.00
0005432706771	3037	Economy	3400.00
0005432880737	3037	Economy	3400.00
0005433123715	3037	Economy	3400.00
0005432706770	3037	Economy	3400.00
0005432706778	3037	Economy	3400.00
0005433123765	3037	Economy	3400.00
0005433123741	3037	Economy	3400.00
0005432706761	3037	Economy	3400.00
0005432706760	3037	Economy	3400.00
0005433123704	3037	Economy	3400.00
0005432706777	3037	Economy	3400.00
0005432706765	3037	Economy	3400.00
0005432706757	3037	Economy	3400.00
0005432706769	3037	Economy	3400.00
0005432706773	3037	Economy	3400.00
0005433194850	3037	Economy	3400.00
0005433123710	3037	Economy	3400.00
0005433123749	3037	Economy	3400.00
0005433123734	3037	Economy	3400.00
0005432880633	3037	Economy	3400.00
0005432880690	3037	Economy	3400.00
0005433194848	3037	Economy	3400.00
0005433194831	3037	Economy	3400.00
0005432217775	3037	Economy	3400.00
0005432880659	3037	Economy	3400.00
0005433123757	3037	Economy	3400.00
0005432880645	3037	Economy	3400.00
0005432880719	3037	Economy	3400.00
0005433123775	3037	Economy	3400.00
0005433123747	3037	Economy	3400.00
0005433123796	3037	Economy	3400.00
0005432880698	3037	Economy	3400.00
0005432706772	3037	Economy	3400.00
0005433194849	3037	Economy	3400.00
0005432706774	3037	Economy	3400.00
0005432880819	29968	Business	10300.00
0005432706601	29968	Business	10300.00
0005432693080	29968	Business	10300.00
0005433123914	29968	Business	10300.00
0005432706522	29968	Business	10300.00
0005432880818	29968	Business	10300.00
0005432693069	29968	Business	10300.00
0005433123926	29968	Business	10300.00
0005432693074	29968	Business	10300.00
0005432693081	29968	Business	10300.00
0005432706684	29968	Business	10300.00
0005432693091	29968	Business	10300.00
0005432706579	29968	Economy	3400.00
0005433123923	29968	Economy	3400.00
0005432693095	29968	Economy	3400.00
0005432693094	29968	Economy	3400.00
0005432706463	29968	Economy	3400.00
0005433123911	29968	Economy	3400.00
0005432706505	29968	Economy	3400.00
0005432693071	29968	Economy	3400.00
0005432706572	29968	Economy	3400.00
0005433123912	29968	Economy	3400.00
0005432693065	29968	Economy	3800.00
0005432693085	29968	Economy	3800.00
0005432693077	29968	Economy	3800.00
0005432693078	29968	Economy	3800.00
0005432693072	29968	Economy	3800.00
0005433123922	29968	Economy	3400.00
0005432706526	29968	Economy	3400.00
0005432693066	29968	Economy	3400.00
0005433123917	29968	Economy	3400.00
0005432706552	29968	Economy	3400.00
0005432693084	29968	Economy	3400.00
0005432693083	29968	Economy	3400.00
0005432880806	29968	Economy	3400.00
0005432706569	29968	Economy	3400.00
0005432693073	29968	Economy	3400.00
0005432693092	29968	Economy	3400.00
0005432693086	29968	Economy	3400.00
0005433123915	29968	Economy	3400.00
0005433123918	29968	Economy	3400.00
0005432706627	29968	Economy	3400.00
0005432706611	29968	Economy	3400.00
0005432706525	29968	Economy	3400.00
0005432693067	29968	Economy	3400.00
0005433123929	29968	Economy	3400.00
0005433123921	29968	Economy	3400.00
0005432693075	29968	Economy	3400.00
0005432706573	29968	Economy	3400.00
0005432880813	29968	Economy	3400.00
0005432706688	29968	Economy	3400.00
0005432880808	29968	Economy	3400.00
0005432880817	29968	Economy	3400.00
0005433123924	29968	Economy	3400.00
0005432880811	29968	Economy	3400.00
0005432693064	29968	Economy	3400.00
0005432880810	29968	Economy	3400.00
0005432706628	29968	Economy	3400.00
0005432693079	29968	Economy	3400.00
0005432880820	29968	Economy	3400.00
0005432693088	29968	Economy	3400.00
0005432706553	29968	Economy	3400.00
0005432693076	29968	Economy	3400.00
0005432706595	29968	Economy	3400.00
0005433123925	29968	Economy	3400.00
0005433123930	29968	Economy	3400.00
0005432706612	29968	Economy	3400.00
0005433123919	29968	Economy	3400.00
0005432693068	29968	Economy	3400.00
0005432706520	29968	Economy	3400.00
0005432706604	29968	Economy	3400.00
0005432693093	29968	Economy	3400.00
0005432706464	29968	Economy	3400.00
0005432706547	29968	Economy	3400.00
0005432706549	29968	Economy	3400.00
0005432693089	29968	Economy	3400.00
0005432880816	29968	Economy	3400.00
0005432706571	29968	Economy	3400.00
0005433123920	29968	Economy	3400.00
0005432706600	29968	Economy	3400.00
0005432706564	29968	Economy	3400.00
0005432880814	29968	Economy	3400.00
0005432880809	29968	Economy	3400.00
0005432693087	29968	Economy	3400.00
0005432693090	29968	Economy	3400.00
0005433123916	29968	Economy	3400.00
0005432880815	29968	Economy	3400.00
0005432706629	29968	Economy	3400.00
0005433123928	29968	Economy	3400.00
0005433123927	29968	Economy	3400.00
0005432880807	29968	Economy	3400.00
0005432693070	29968	Economy	3400.00
0005432880812	29968	Economy	3400.00
0005432706602	29968	Economy	3400.00
0005433123913	29968	Economy	3400.00
0005432706565	29968	Economy	3400.00
0005432693082	29968	Economy	3400.00
0005434979751	23660	Economy	4000.00
0005434979773	23660	Economy	4000.00
0005434988727	23660	Economy	4000.00
0005434988730	23660	Economy	4000.00
0005434979766	23660	Economy	3600.00
0005434979771	23660	Economy	3600.00
0005434988729	23660	Economy	3600.00
0005434988728	23660	Economy	3600.00
0005434979755	23660	Economy	3600.00
0005434979750	23660	Economy	3600.00
0005434979744	23660	Economy	3600.00
0005434988739	23660	Economy	3600.00
0005434979762	23660	Economy	3600.00
0005434988724	23660	Economy	3600.00
0005434979765	23660	Economy	3600.00
0005434988725	23660	Economy	3600.00
0005434988737	23660	Economy	3600.00
0005434988733	23660	Economy	3600.00
0005434979764	23660	Economy	3600.00
0005434988723	23660	Economy	3600.00
0005434979746	23660	Economy	3600.00
0005434988735	23660	Economy	3600.00
0005434979768	23660	Economy	3600.00
0005434979748	23660	Economy	3600.00
0005434979753	23660	Economy	3600.00
0005434979756	23660	Economy	3600.00
0005434979760	23660	Economy	3600.00
0005434979763	23660	Economy	3600.00
0005434979759	23660	Economy	3600.00
0005434988722	23660	Economy	3600.00
0005434979745	23660	Economy	3600.00
0005434979761	23660	Economy	3600.00
0005434988731	23660	Economy	3600.00
0005434988738	23660	Economy	3600.00
0005434988736	23660	Economy	3600.00
0005434979749	23660	Economy	3600.00
0005434979747	23660	Economy	3600.00
0005434988734	23660	Economy	3600.00
0005434988732	23660	Economy	3600.00
0005434979772	23660	Economy	3600.00
0005434979769	23660	Economy	3600.00
0005434979767	23660	Economy	3600.00
0005434979757	23660	Economy	3600.00
0005434979754	23660	Economy	3600.00
0005434979752	23660	Economy	3600.00
0005434979770	23660	Economy	3600.00
0005434979774	23660	Economy	3600.00
0005434979758	23660	Economy	3600.00
0005434988726	23660	Economy	3600.00
0005434979459	27569	Economy	4000.00
0005434979499	27569	Economy	4000.00
0005434979489	27569	Economy	4000.00
0005434979544	27569	Economy	3600.00
0005434979635	27569	Economy	3600.00
0005434979508	27569	Economy	3600.00
0005434979428	27569	Economy	3600.00
0005434979439	27569	Economy	3600.00
0005434979478	27569	Economy	3600.00
0005434979596	27569	Economy	3600.00
0005434979455	27569	Economy	3600.00
0005434979450	27569	Economy	3600.00
0005434979494	27569	Economy	3600.00
0005434979527	27569	Economy	3600.00
0005434979448	27569	Economy	3600.00
0005434979530	27569	Economy	3600.00
0005434979565	27569	Economy	3600.00
0005434979419	27569	Economy	3600.00
0005434979481	27569	Economy	3600.00
0005434988617	27569	Economy	3600.00
0005434988618	27569	Economy	3600.00
0005434988615	27569	Economy	3600.00
0005434979493	27569	Economy	3600.00
0005434979490	27569	Economy	3600.00
0005434979528	27569	Economy	3600.00
0005434979420	27569	Economy	3600.00
0005434979522	27569	Economy	3600.00
0005434979443	27569	Economy	3600.00
0005434979452	27569	Economy	3600.00
0005434979514	27569	Economy	3600.00
0005434979523	27569	Economy	3600.00
0005434979634	27569	Economy	3600.00
0005434979496	27569	Economy	3600.00
0005434979526	27569	Economy	3600.00
0005434979466	27569	Economy	3600.00
0005434979456	27569	Economy	3600.00
0005434979451	27569	Economy	3600.00
0005434979454	27569	Economy	3600.00
0005434979543	27569	Economy	3600.00
0005434988616	27569	Economy	3600.00
0005434979480	27569	Economy	3600.00
0005434979488	27569	Economy	3600.00
0005434979449	27569	Economy	3600.00
0005434979479	27569	Economy	3600.00
0005434979531	27569	Economy	3600.00
0005434979427	27569	Economy	3600.00
0005434979495	27569	Economy	3600.00
0005434302872	10268	Economy	19700.00
0005433111480	10268	Economy	19700.00
0005434302457	10268	Economy	19700.00
0005433111475	10268	Economy	19700.00
0005433113510	10268	Economy	19700.00
0005434302454	10268	Economy	19700.00
0005434302871	10268	Economy	19700.00
0005434302455	10268	Economy	19700.00
0005433111479	10268	Economy	19700.00
0005434302870	10268	Economy	19700.00
0005434302869	10268	Economy	19700.00
0005433111474	10268	Economy	19700.00
0005434302453	10268	Economy	19700.00
0005434302456	10268	Economy	19700.00
0005433113535	19586	Economy	19700.00
0005433113536	19586	Economy	19700.00
0005434302420	19586	Economy	19700.00
0005434302425	19586	Economy	19700.00
0005434302395	19586	Economy	19700.00
0005434302409	19586	Economy	19700.00
0005434302415	19586	Economy	19700.00
0005434302413	19586	Economy	19700.00
0005434302414	19586	Economy	19700.00
0005434302412	19586	Economy	19700.00
0005434302404	19586	Economy	19700.00
0005434302426	19586	Economy	19700.00
0005435069064	3531	Business	26900.00
0005435925128	3531	Business	26900.00
0005435925185	3531	Business	26900.00
0005435069103	3531	Business	26900.00
0005435925160	3531	Business	26900.00
0005435069088	3531	Business	26900.00
0005435925132	3531	Business	26900.00
0005435925138	3531	Business	26900.00
0005435069087	3531	Business	26900.00
0005435069060	3531	Business	26900.00
0005435069108	3531	Economy	9000.00
0005435925137	3531	Economy	9000.00
0005435925135	3531	Economy	9000.00
0005435718942	3531	Economy	9000.00
0005435069074	3531	Economy	9000.00
0005435925190	3531	Economy	9000.00
0005435069061	3531	Economy	9000.00
0005435925187	3531	Economy	9000.00
0005435069093	3531	Economy	9000.00
0005435069109	3531	Economy	9900.00
0005435069083	3531	Economy	9900.00
0005435925171	3531	Economy	9900.00
0005435925167	3531	Economy	9900.00
0005435069096	3531	Economy	9000.00
0005435718943	3531	Economy	9000.00
0005435069076	3531	Economy	9000.00
0005435069092	3531	Economy	9000.00
0005435069084	3531	Economy	9000.00
0005435069079	3531	Economy	9000.00
0005435925191	3531	Economy	9000.00
0005435069080	3531	Economy	9000.00
0005435718945	3531	Economy	9000.00
0005435069098	3531	Economy	9000.00
0005435718941	3531	Economy	9000.00
0005435069063	3531	Economy	9000.00
0005435069068	3531	Economy	9000.00
0005435925168	3531	Economy	9000.00
0005435069072	3531	Economy	9000.00
0005435069071	3531	Economy	9000.00
0005435069073	3531	Economy	9000.00
0005435069110	3531	Economy	9000.00
0005435069085	3531	Economy	9000.00
0005435069101	3531	Economy	9000.00
0005435069095	3531	Economy	9000.00
0005435069075	3531	Economy	9000.00
0005435069091	3531	Economy	9000.00
0005435069105	3531	Economy	9000.00
0005435069097	3531	Economy	9000.00
0005435069104	3531	Economy	9000.00
0005435718944	3531	Economy	9000.00
0005435069086	3531	Economy	9000.00
0005435069090	3531	Economy	9000.00
0005435925184	3531	Economy	9000.00
0005435069077	3531	Economy	9000.00
0005435718946	3531	Economy	9000.00
0005435069111	3531	Economy	9000.00
0005435925131	3531	Economy	9000.00
0005435069070	3531	Economy	9000.00
0005435925186	3531	Economy	9000.00
0005435925133	3531	Economy	9000.00
0005435069062	3531	Economy	9000.00
0005435718939	3531	Economy	9000.00
0005435069089	3531	Economy	9000.00
0005435069066	3531	Economy	9000.00
0005435069065	3531	Economy	9000.00
0005435069081	3531	Economy	9000.00
0005435069082	3531	Economy	9000.00
0005435069100	3531	Economy	9000.00
0005435069078	3531	Economy	9000.00
0005435069094	3531	Economy	9000.00
0005435069059	3531	Economy	9000.00
0005435069067	3531	Economy	9000.00
0005435069099	3531	Economy	9000.00
0005435069107	3531	Economy	9000.00
0005435069069	3531	Economy	9000.00
0005435718940	3531	Economy	9000.00
0005435069102	3531	Economy	9000.00
0005435069106	3531	Economy	9000.00
0005435718835	15332	Business	26900.00
0005435068834	15332	Business	26900.00
0005435718873	15332	Business	26900.00
0005435068593	15332	Business	26900.00
0005435718848	15332	Business	26900.00
0005435068777	15332	Business	26900.00
0005435718847	15332	Business	26900.00
0005435718883	15332	Business	26900.00
0005435718867	15332	Business	26900.00
0005435718841	15332	Business	26900.00
0005435718878	15332	Business	26900.00
0005435718853	15332	Economy	9000.00
0005435068632	15332	Economy	9000.00
0005435718870	15332	Economy	9000.00
0005435718834	15332	Economy	9000.00
0005435068809	15332	Economy	9000.00
0005435068368	15332	Economy	9000.00
0005435718852	15332	Economy	9000.00
0005435068664	15332	Economy	9000.00
0005435718830	15332	Economy	9900.00
0005435068699	15332	Economy	9900.00
0005435718837	15332	Economy	9900.00
0005435068617	15332	Economy	9900.00
0005435068644	15332	Economy	9900.00
0005435068666	15332	Economy	9000.00
0005435068589	15332	Economy	9000.00
0005435718869	15332	Economy	9000.00
0005435068645	15332	Economy	9000.00
0005435068788	15332	Economy	9000.00
0005435718863	15332	Economy	9000.00
0005435068557	15332	Economy	9000.00
0005435068685	15332	Economy	9000.00
0005435718858	15332	Economy	9000.00
0005435718862	15332	Economy	9000.00
0005435068458	15332	Economy	9000.00
0005435718839	15332	Economy	9000.00
0005435718882	15332	Economy	9000.00
0005435068569	15332	Economy	9000.00
0005435718855	15332	Economy	9000.00
0005435068774	15332	Economy	9000.00
0005435068673	15332	Economy	9000.00
0005435068603	15332	Economy	9000.00
0005435068547	15332	Economy	9000.00
0005435718868	15332	Economy	9000.00
0005435068700	15332	Economy	9000.00
0005435068591	15332	Economy	9000.00
0005435718861	15332	Economy	9000.00
0005435068178	15332	Economy	9000.00
0005435068415	15332	Economy	9000.00
0005435718854	15332	Economy	9000.00
0005435068578	15332	Economy	9000.00
0005435068434	15332	Economy	9000.00
0005435068579	15332	Economy	9000.00
0005435718840	15332	Economy	9000.00
0005435068583	15332	Economy	9000.00
0005435718836	15332	Economy	9000.00
0005435068414	15332	Economy	9000.00
0005435718827	15332	Economy	9000.00
0005435068602	15332	Economy	9000.00
0005435718874	15332	Economy	9000.00
0005435718828	15332	Economy	9000.00
0005435718877	15332	Economy	9000.00
0005435718880	15332	Economy	9000.00
0005435718856	15332	Economy	9000.00
0005435068568	15332	Economy	9000.00
0005435718871	15332	Economy	9000.00
0005435718843	15332	Economy	9000.00
0005435068413	15332	Economy	9000.00
0005435068618	15332	Economy	9000.00
0005435718831	15332	Economy	9000.00
0005435068491	15332	Economy	9000.00
0005435068657	15332	Economy	9000.00
0005435068556	15332	Economy	9000.00
0005435718881	15332	Economy	9000.00
0005435068580	15332	Economy	9000.00
0005435718849	15332	Economy	9000.00
0005435718865	15332	Economy	9000.00
0005435068631	15332	Economy	9000.00
0005435068588	15332	Economy	9000.00
0005435718872	15332	Economy	9000.00
0005435068457	15332	Economy	9000.00
0005435718875	15332	Economy	9000.00
0005435718857	15332	Economy	9000.00
0005435718829	15332	Economy	9000.00
0005435068693	15332	Economy	9000.00
0005435718846	15332	Economy	9000.00
0005432660817	18191	Economy	5900.00
0005432660818	18191	Economy	5900.00
0005432658590	18191	Economy	5900.00
0005432659706	18191	Economy	5900.00
0005432658591	18191	Economy	5900.00
0005432659705	18191	Economy	5900.00
0005432667429	26350	Economy	5900.00
0005432660798	26350	Economy	5900.00
0005432664113	26350	Economy	5900.00
0005432664127	26350	Economy	5900.00
0005432901465	193	Business	20000.00
0005432391965	193	Business	20000.00
0005433101484	193	Business	20000.00
0005432391956	193	Business	20000.00
0005432919663	193	Business	20000.00
0005433101662	193	Business	20000.00
0005432919662	193	Business	20000.00
0005432677552	193	Business	20000.00
0005432157491	193	Business	20000.00
0005433101599	193	Business	20000.00
0005432919728	193	Business	20000.00
0005433101600	193	Business	20000.00
0005433101633	193	Business	20000.00
0005433101595	193	Business	20000.00
0005433101553	193	Business	20000.00
0005432919707	193	Economy	7300.00
0005433101479	193	Economy	7300.00
0005432391972	193	Economy	7300.00
0005433101571	193	Economy	7300.00
0005433101524	193	Economy	7300.00
0005433101685	193	Economy	7300.00
0005433101665	193	Economy	6700.00
0005433101707	193	Economy	6700.00
0005433101695	193	Economy	6700.00
0005432391980	193	Economy	6700.00
0005432677524	193	Economy	6700.00
0005433101663	193	Economy	6700.00
0005432901504	193	Economy	6700.00
0005432919717	193	Economy	6700.00
0005432919722	193	Economy	6700.00
0005433101687	193	Economy	6700.00
0005433101699	193	Economy	6700.00
0005433101717	193	Economy	6700.00
0005432391967	193	Economy	6700.00
0005433101617	193	Economy	6700.00
0005433101721	193	Economy	6700.00
0005432919723	193	Economy	6700.00
0005432901469	193	Economy	6700.00
0005433101554	193	Economy	6700.00
0005433101727	193	Economy	6700.00
0005432919733	193	Economy	6700.00
0005432157492	193	Economy	6700.00
0005432919686	193	Economy	6700.00
0005433101648	193	Economy	6700.00
0005433101594	193	Economy	6700.00
0005432919692	193	Economy	6700.00
0005433101528	193	Economy	6700.00
0005433101465	193	Economy	6700.00
0005432919797	193	Economy	6700.00
0005432919694	193	Economy	6700.00
0005433101698	193	Economy	6700.00
0005433101570	193	Economy	6700.00
0005433101734	193	Economy	6700.00
0005432919798	193	Economy	6700.00
0005433101654	193	Economy	6700.00
0005432391959	193	Economy	6700.00
0005432919684	193	Economy	7300.00
0005432919664	193	Economy	7300.00
0005432391983	193	Economy	7300.00
0005433101569	193	Economy	7300.00
0005432919658	193	Economy	6700.00
0005432901470	193	Economy	6700.00
0005433101641	193	Economy	7300.00
0005432901426	193	Economy	6700.00
0005433101728	193	Economy	6700.00
0005433101518	193	Economy	6700.00
0005433101647	193	Economy	6700.00
0005433101517	193	Economy	6700.00
0005432919769	193	Economy	6700.00
0005432919778	193	Economy	6700.00
0005433101519	193	Economy	6700.00
0005432677553	193	Economy	6700.00
0005433101673	193	Economy	6700.00
0005432919777	193	Economy	6700.00
0005433101716	193	Economy	6700.00
0005432391960	193	Economy	6700.00
0005432901466	193	Economy	6700.00
0005433101664	193	Economy	6700.00
0005433101622	193	Economy	6700.00
0005433101605	193	Economy	6700.00
0005433101715	193	Economy	6700.00
0005432919600	193	Economy	6700.00
0005433101628	193	Economy	6700.00
0005432901460	193	Economy	6700.00
0005432901444	193	Economy	6700.00
0005432391982	193	Economy	6700.00
0005432677525	193	Economy	6700.00
0005432901454	193	Economy	6700.00
0005433101629	193	Economy	6700.00
0005433101732	193	Economy	6700.00
0005433101590	193	Economy	6700.00
0005433101625	193	Economy	6700.00
0005433101703	193	Economy	6700.00
0005432901474	193	Economy	6700.00
0005433101606	193	Economy	6700.00
0005432391966	193	Economy	6700.00
0005433101733	193	Economy	6700.00
0005433101616	193	Economy	6700.00
0005433101706	193	Economy	6700.00
0005432391981	193	Economy	6700.00
0005433101655	193	Economy	6700.00
0005433101602	193	Economy	6700.00
0005433101696	193	Economy	6700.00
0005432261882	194	Business	20000.00
0005432261888	194	Business	20000.00
0005432261901	194	Business	20000.00
0005433690898	194	Business	20000.00
0005432817471	194	Business	20000.00
0005432261916	194	Business	20000.00
0005432817474	194	Business	20000.00
0005432261883	194	Business	20000.00
0005434153534	194	Business	20000.00
0005432261919	194	Business	20000.00
0005432817464	194	Business	20000.00
0005432261894	194	Business	20000.00
0005432261909	194	Business	20000.00
0005432261886	194	Business	20000.00
0005432817469	194	Business	20000.00
0005432288984	194	Business	20000.00
0005432817483	194	Business	20000.00
0005432261889	194	Economy	7300.00
0005432753259	194	Economy	7300.00
0005432261914	194	Economy	7300.00
0005432261923	194	Economy	7300.00
0005432817460	194	Economy	7300.00
0005432817480	194	Economy	6700.00
0005432817481	194	Economy	6700.00
0005432261920	194	Economy	6700.00
0005432261913	194	Economy	6700.00
0005432261898	194	Economy	6700.00
0005432261896	194	Economy	6700.00
0005432817462	194	Economy	6700.00
0005432288986	194	Economy	6700.00
0005432817466	194	Economy	6700.00
0005432753260	194	Economy	6700.00
0005432261921	194	Economy	6700.00
0005433690897	194	Economy	6700.00
0005432261891	194	Economy	6700.00
0005432817457	194	Economy	6700.00
0005432817473	194	Economy	6700.00
0005433687677	194	Economy	6700.00
0005432261926	194	Economy	6700.00
0005432817478	194	Economy	6700.00
0005432817477	194	Economy	6700.00
0005432261899	194	Economy	6700.00
0005432261893	194	Economy	6700.00
0005432817458	194	Economy	6700.00
0005432261928	194	Economy	6700.00
0005432817455	194	Economy	6700.00
0005432261902	194	Economy	6700.00
0005432261907	194	Economy	6700.00
0005432288985	194	Economy	6700.00
0005432261905	194	Economy	6700.00
0005432817461	194	Economy	6700.00
0005433687675	194	Economy	6700.00
0005432817468	194	Economy	6700.00
0005434153533	194	Economy	6700.00
0005432261929	194	Economy	6700.00
0005432817467	194	Economy	6700.00
0005432817482	194	Economy	6700.00
0005432817479	194	Economy	6700.00
0005432817476	194	Economy	7300.00
0005432261900	194	Economy	7300.00
0005432207659	194	Economy	7300.00
0005432207660	194	Economy	6700.00
0005432261918	194	Economy	6700.00
0005432756808	194	Economy	6700.00
0005432261887	194	Economy	6700.00
0005432817463	194	Economy	6700.00
0005434153532	194	Economy	6700.00
0005432261910	194	Economy	6700.00
0005432261915	194	Economy	6700.00
0005432817456	194	Economy	6700.00
0005432261895	194	Economy	6700.00
0005432261903	194	Economy	6700.00
0005432817465	194	Economy	6700.00
0005432261906	194	Economy	6700.00
0005432261911	194	Economy	6700.00
0005432261890	194	Economy	6700.00
0005432261912	194	Economy	6700.00
0005432817459	194	Economy	6700.00
0005434153531	194	Economy	6700.00
0005432817454	194	Economy	6700.00
0005432288987	194	Economy	6700.00
0005433687676	194	Economy	6700.00
0005432817472	194	Economy	6700.00
0005432261922	194	Economy	6700.00
0005432261904	194	Economy	6700.00
0005432261925	194	Economy	6700.00
0005432261884	194	Economy	6700.00
0005432756801	194	Economy	6700.00
0005432261924	194	Economy	6700.00
0005432817470	194	Economy	6700.00
0005432261897	194	Economy	6700.00
0005432261892	194	Economy	6700.00
0005432261927	194	Economy	6700.00
0005432817475	194	Economy	6700.00
0005432261917	194	Economy	6700.00
0005432261908	194	Economy	6700.00
0005432261885	194	Economy	6700.00
0005433102149	7985	Business	20000.00
0005432919850	7985	Business	20000.00
0005432020245	7985	Business	20000.00
0005432919854	7985	Business	20000.00
0005432919863	7985	Business	20000.00
0005432753301	7985	Business	20000.00
0005433102164	7985	Business	20000.00
0005432020260	7985	Business	20000.00
0005433102170	7985	Business	20000.00
0005432751530	7985	Business	20000.00
0005433102168	7985	Business	20000.00
0005432919861	7985	Business	20000.00
0005433102154	7985	Business	20000.00
0005432020259	7985	Business	20000.00
0005433102138	7985	Business	20000.00
0005433102163	7985	Business	20000.00
0005433102144	7985	Business	20000.00
0005432751528	7985	Business	20000.00
0005432677575	7985	Business	20000.00
0005433102152	7985	Economy	7300.00
0005433102151	7985	Economy	7300.00
0005433102133	7985	Economy	7300.00
0005432677574	7985	Economy	7300.00
0005433102165	7985	Economy	7300.00
0005432751525	7985	Economy	6700.00
0005433102162	7985	Economy	6700.00
0005432020257	7985	Economy	6700.00
0005433102135	7985	Economy	6700.00
0005433102143	7985	Economy	6700.00
0005432044523	7985	Economy	6700.00
0005433102145	7985	Economy	6700.00
0005432020255	7985	Economy	6700.00
0005432751526	7985	Economy	6700.00
0005432919852	7985	Economy	6700.00
0005433102160	7985	Economy	6700.00
0005432753302	7985	Economy	6700.00
0005432020256	7985	Economy	6700.00
0005433102126	7985	Economy	6700.00
0005432919858	7985	Economy	6700.00
0005432020252	7985	Economy	6700.00
0005433102130	7985	Economy	6700.00
0005432020268	7985	Economy	6700.00
0005432020254	7985	Economy	6700.00
0005433102156	7985	Economy	6700.00
0005433102158	7985	Economy	6700.00
0005433102153	7985	Economy	6700.00
0005432020265	7985	Economy	6700.00
0005433102150	7985	Economy	6700.00
0005432020249	7985	Economy	6700.00
0005433102167	7985	Economy	6700.00
0005433102142	7985	Economy	6700.00
0005433102147	7985	Economy	6700.00
0005433102127	7985	Economy	6700.00
0005432919859	7985	Economy	6700.00
0005432020258	7985	Economy	6700.00
0005432919862	7985	Economy	6700.00
0005432020250	7985	Economy	6700.00
0005432677573	7985	Economy	6700.00
0005432020262	7985	Economy	6700.00
0005432020247	7985	Economy	6700.00
0005432020266	7985	Economy	6700.00
0005433102136	7985	Economy	6700.00
0005433102166	7985	Economy	6700.00
0005433102141	7985	Economy	6700.00
0005432392000	7985	Economy	6700.00
0005432020269	7985	Economy	6700.00
0005433102125	7985	Economy	6700.00
0005432919848	7985	Economy	6700.00
0005432751529	7985	Economy	6700.00
0005432919855	7985	Economy	6700.00
0005432020261	7985	Economy	7300.00
0005432677572	7985	Economy	7300.00
0005432919847	7985	Economy	7300.00
0005432919851	7985	Economy	6700.00
0005433102171	7985	Economy	6700.00
0005433102134	7985	Economy	6700.00
0005432020246	7985	Economy	6700.00
0005432391998	7985	Economy	6700.00
0005432020270	7985	Economy	7300.00
0005433102132	7985	Economy	6700.00
0005433102161	7985	Economy	6700.00
0005432020253	7985	Economy	6700.00
0005432919846	7985	Economy	6700.00
0005432020264	7985	Economy	6700.00
0005433102169	7985	Economy	6700.00
0005432020271	7985	Economy	6700.00
0005432919849	7985	Economy	6700.00
0005432751527	7985	Economy	6700.00
0005432919860	7985	Economy	6700.00
0005433102148	7985	Economy	6700.00
0005433102131	7985	Economy	6700.00
0005433102157	7985	Economy	6700.00
0005433102128	7985	Economy	6700.00
0005432020248	7985	Economy	6700.00
0005433102155	7985	Economy	6700.00
0005433102146	7985	Economy	6700.00
0005433102139	7985	Economy	6700.00
0005432919864	7985	Economy	6700.00
0005432045613	7985	Economy	6700.00
0005432919853	7985	Economy	6700.00
0005432391999	7985	Economy	6700.00
0005432020267	7985	Economy	6700.00
0005432044525	7985	Economy	6700.00
0005432919856	7985	Economy	6700.00
0005432044524	7985	Economy	6700.00
0005432919865	7985	Economy	6700.00
0005432919857	7985	Economy	6700.00
0005433102159	7985	Economy	6700.00
0005433102140	7985	Economy	6700.00
0005433102129	7985	Economy	6700.00
0005433102137	7985	Economy	6700.00
0005432919866	7985	Economy	6700.00
0005432677576	7985	Economy	6700.00
0005432020251	7985	Economy	6700.00
0005432045614	7985	Economy	6700.00
0005432020272	7985	Economy	6700.00
0005432020263	7985	Economy	6700.00
0005432919867	7985	Economy	6700.00
0005432919845	7985	Economy	6700.00
0005432901601	7984	Business	20000.00
0005432002077	7984	Business	20000.00
0005432901603	7984	Business	20000.00
0005432817099	7984	Business	20000.00
0005432817160	7984	Business	20000.00
0005432002075	7984	Business	20000.00
0005432817159	7984	Business	20000.00
0005432817298	7984	Business	20000.00
0005432901599	7984	Business	20000.00
0005432901614	7984	Economy	7300.00
0005432817233	7984	Economy	7300.00
0005432901600	7984	Economy	6700.00
0005432817053	7984	Economy	6700.00
0005432817232	7984	Economy	6700.00
0005432817054	7984	Economy	6700.00
0005432901605	7984	Economy	6700.00
0005432817348	7984	Economy	6700.00
0005432817158	7984	Economy	6700.00
0005432901607	7984	Economy	6700.00
0005432901604	7984	Economy	6700.00
0005432901615	7984	Economy	6700.00
0005432817179	7984	Economy	6700.00
0005432817255	7984	Economy	6700.00
0005432817095	7984	Economy	7300.00
0005432817262	7984	Economy	7300.00
0005432817166	7984	Economy	6700.00
0005432817098	7984	Economy	6700.00
0005432901616	7984	Economy	6700.00
0005432817346	7984	Economy	6700.00
0005432901613	7984	Economy	6700.00
0005432901606	7984	Economy	6700.00
0005432817216	7984	Economy	6700.00
0005432002078	7984	Economy	6700.00
0005432901611	7984	Economy	6700.00
0005432002076	7984	Economy	6700.00
0005432901602	7984	Economy	6700.00
0005432817272	7984	Economy	6700.00
0005432817271	7984	Economy	6700.00
0005432901609	7984	Economy	6700.00
0005432817347	7984	Economy	6700.00
0005432901610	7984	Economy	6700.00
0005432817259	7984	Economy	6700.00
0005432817326	7984	Economy	6700.00
0005432817199	7984	Economy	6700.00
0005432901612	7984	Economy	6700.00
0005432901608	7984	Economy	6700.00
0005432817249	7984	Economy	6700.00
0005432817094	7984	Economy	6700.00
0005434175711	9690	Economy	6900.00
0005433870731	9690	Economy	6900.00
0005434175754	32338	Economy	6900.00
0005434175751	32338	Economy	6900.00
0005434175752	32338	Economy	6900.00
0005434175753	32338	Economy	6900.00
0005433870716	32338	Economy	6900.00
0005434175750	32338	Economy	6900.00
0005433870713	32338	Economy	6900.00
0005434878283	3466	Business	35000.00
0005432799449	3466	Business	35000.00
0005434878223	3466	Business	35000.00
0005434878231	3466	Business	35000.00
0005434426626	3466	Business	35000.00
0005434878297	3466	Business	35000.00
0005434878294	3466	Business	35000.00
0005435126366	3466	Business	35000.00
0005432799450	3466	Business	35000.00
0005434878220	3466	Business	35000.00
0005434426607	3466	Business	35000.00
0005435126386	3466	Business	35000.00
0005435626168	3466	Business	35000.00
0005435914684	3466	Business	35000.00
0005434878211	3466	Business	35000.00
0005434878252	3466	Business	35000.00
0005434878226	3466	Business	35000.00
0005435902583	3466	Business	35000.00
0005435126367	3466	Business	35000.00
0005434878203	3466	Comfort	19900.00
0005434878255	3466	Comfort	19900.00
0005435626169	3466	Comfort	19900.00
0005434878228	3466	Comfort	19900.00
0005434878272	3466	Comfort	19900.00
0005435126375	3466	Comfort	19900.00
0005432188606	3466	Comfort	19900.00
0005435126368	3466	Comfort	19900.00
0005434878206	3466	Comfort	19900.00
0005435902604	3466	Comfort	19900.00
0005434878298	3466	Comfort	19900.00
0005435126381	3466	Comfort	19900.00
0005434878285	3466	Comfort	19900.00
0005435126388	3466	Comfort	19900.00
0005432188607	3466	Comfort	19900.00
0005434878258	3466	Comfort	19900.00
0005435126369	3466	Comfort	19900.00
0005432799448	3466	Comfort	19900.00
0005434878276	3466	Comfort	19900.00
0005435913874	3466	Comfort	19900.00
0005432799461	3466	Comfort	19900.00
0005434426624	3466	Comfort	19900.00
0005434878214	3466	Comfort	19900.00
0005432611711	3466	Comfort	19900.00
0005434426612	3466	Comfort	19900.00
0005434938138	3466	Comfort	19900.00
0005434426610	3466	Comfort	19900.00
0005434938137	3466	Comfort	19900.00
0005434878224	3466	Comfort	19900.00
0005434878274	3466	Comfort	19900.00
0005432613860	3466	Comfort	19900.00
0005435126361	3466	Comfort	19900.00
0005434938149	3466	Comfort	19900.00
0005434426601	3466	Comfort	19900.00
0005432799469	3466	Comfort	19900.00
0005434426611	3466	Economy	11700.00
0005432799464	3466	Economy	11700.00
0005434878291	3466	Economy	11700.00
0005434878293	3466	Economy	11700.00
0005434878262	3466	Economy	11700.00
0005432799470	3466	Economy	11700.00
0005434878235	3466	Economy	11700.00
0005434878281	3466	Economy	11700.00
0005434426622	3466	Economy	11700.00
0005432188610	3466	Economy	11700.00
0005432613863	3466	Economy	11700.00
0005434878271	3466	Economy	11700.00
0005434878267	3466	Economy	11700.00
0005432799453	3466	Economy	11700.00
0005434938147	3466	Economy	11700.00
0005434878217	3466	Economy	11700.00
0005434426609	3466	Economy	11700.00
0005432799458	3466	Economy	11700.00
0005434878249	3466	Economy	11700.00
0005434878240	3466	Economy	11700.00
0005434878286	3466	Economy	11700.00
0005432799468	3466	Economy	11700.00
0005434878209	3466	Economy	11700.00
0005432613861	3466	Economy	11700.00
0005434426620	3466	Economy	11700.00
0005434938139	3466	Economy	11700.00
0005434878246	3466	Economy	11700.00
0005435914693	3466	Economy	11700.00
0005432611712	3466	Economy	11700.00
0005432799463	3466	Economy	11700.00
0005432799462	3466	Economy	11700.00
0005434938151	3466	Economy	11700.00
0005435126394	3466	Economy	11700.00
0005434878222	3466	Economy	11700.00
0005434878292	3466	Economy	11700.00
0005434426602	3466	Economy	11700.00
0005434426604	3466	Economy	11700.00
0005432799444	3466	Economy	11700.00
0005434878233	3466	Economy	11700.00
0005434878218	3466	Economy	11700.00
0005434426600	3466	Economy	11700.00
0005434878273	3466	Economy	11700.00
0005434878244	3466	Economy	11700.00
0005432188608	3466	Economy	11700.00
0005434426614	3466	Economy	12800.00
0005435841089	3466	Economy	12800.00
0005434938152	3466	Economy	11700.00
0005434878213	3466	Economy	12800.00
0005435914688	3466	Economy	11700.00
0005434878237	3466	Economy	11700.00
0005432799447	3466	Economy	11700.00
0005434878239	3466	Economy	11700.00
0005435126377	3466	Economy	11700.00
0005434878288	3466	Economy	11700.00
0005434878207	3466	Economy	11700.00
0005435126387	3466	Economy	11700.00
0005432183467	3466	Economy	11700.00
0005432613864	3466	Economy	11700.00
0005434938150	3466	Economy	11700.00
0005434878261	3466	Economy	11700.00
0005434938140	3466	Economy	11700.00
0005434878202	3466	Economy	11700.00
0005435902589	3466	Economy	11700.00
0005434426621	3466	Economy	11700.00
0005434878212	3466	Economy	11700.00
0005435914685	3466	Economy	11700.00
0005435126373	3466	Economy	11700.00
0005434878227	3466	Economy	11700.00
0005435902537	3466	Economy	11700.00
0005434878280	3466	Economy	11700.00
0005432799466	3466	Economy	11700.00
0005435126374	3466	Economy	11700.00
0005435126385	3466	Economy	11700.00
0005435126391	3466	Economy	11700.00
0005434938133	3466	Economy	11700.00
0005435126380	3466	Economy	11700.00
0005435902609	3466	Economy	11700.00
0005435126378	3466	Economy	11700.00
0005434878221	3466	Economy	11700.00
0005432799459	3466	Economy	11700.00
0005434878245	3466	Economy	11700.00
0005434878277	3466	Economy	11700.00
0005435126389	3466	Economy	11700.00
0005434426619	3466	Economy	11700.00
0005434878219	3466	Economy	11700.00
0005435626171	3466	Economy	11700.00
0005435126390	3466	Economy	11700.00
0005434878269	3466	Economy	11700.00
0005435902603	3466	Economy	11700.00
0005434878241	3466	Economy	11700.00
0005434878242	3466	Economy	11700.00
0005434426617	3466	Economy	11700.00
0005435913895	3466	Economy	11700.00
0005435126362	3466	Economy	11700.00
0005435902473	3466	Economy	11700.00
0005435914686	3466	Economy	11700.00
0005432188609	3466	Economy	11700.00
0005434426605	3466	Economy	11700.00
0005434878257	3466	Economy	11700.00
0005434426608	3466	Economy	11700.00
0005435914689	3466	Economy	11700.00
0005434878204	3466	Economy	11700.00
0005435626172	3466	Economy	11700.00
0005434878208	3466	Economy	11700.00
0005435126371	3466	Economy	11700.00
0005434426618	3466	Economy	11700.00
0005434878263	3466	Economy	11700.00
0005434878236	3466	Economy	11700.00
0005434878268	3466	Economy	11700.00
0005434426613	3466	Economy	11700.00
0005434426615	3466	Economy	11700.00
0005434878284	3466	Economy	11700.00
0005434878259	3466	Economy	11700.00
0005434426599	3466	Economy	11700.00
0005435126356	3466	Economy	11700.00
0005432799446	3466	Economy	11700.00
0005434878225	3466	Economy	11700.00
0005435914690	3466	Economy	11700.00
0005432799456	3466	Economy	11700.00
0005434878229	3466	Economy	11700.00
0005435902579	3466	Economy	11700.00
0005435626173	3466	Economy	11700.00
0005434878278	3466	Economy	11700.00
0005434878279	3466	Economy	11700.00
0005432799460	3466	Economy	11700.00
0005434878210	3466	Economy	11700.00
0005435126370	3466	Economy	11700.00
0005435126395	3466	Economy	11700.00
0005435626165	3466	Economy	12800.00
0005435626167	3466	Economy	12800.00
0005435126355	3466	Economy	12800.00
0005434426606	3466	Economy	12800.00
0005434878282	3466	Economy	11700.00
0005432799451	3466	Economy	11700.00
0005432799452	3466	Economy	11700.00
0005432799472	3466	Economy	11700.00
0005434938135	3466	Economy	11700.00
0005434878243	3466	Economy	11700.00
0005435126379	3466	Economy	11700.00
0005434878270	3466	Economy	11700.00
0005432799455	3466	Economy	11700.00
0005435626166	3466	Economy	11700.00
0005434878254	3466	Economy	11700.00
0005434878232	3466	Economy	11700.00
0005434878265	3466	Economy	11700.00
0005435126365	3466	Economy	11700.00
0005434426598	3466	Economy	11700.00
0005434878266	3466	Economy	11700.00
0005434938145	3466	Economy	11700.00
0005435126376	3466	Economy	11700.00
0005435626170	3466	Economy	11700.00
0005434878251	3466	Economy	11700.00
0005435126363	3466	Economy	11700.00
0005434938134	3466	Economy	11700.00
0005434878289	3466	Economy	11700.00
0005434938144	3466	Economy	11700.00
0005435902614	3466	Economy	11700.00
0005435902529	3466	Economy	11700.00
0005434878216	3466	Economy	11700.00
0005435126393	3466	Economy	11700.00
0005434878205	3466	Economy	11700.00
0005434878275	3466	Economy	11700.00
0005434426623	3466	Economy	11700.00
0005435126357	3466	Economy	11700.00
0005435126359	3466	Economy	11700.00
0005434938141	3466	Economy	11700.00
0005434426616	3466	Economy	11700.00
0005432611710	3466	Economy	11700.00
0005432799454	3466	Economy	11700.00
0005434938148	3466	Economy	11700.00
0005434878248	3466	Economy	11700.00
0005434878238	3466	Economy	11700.00
0005434878253	3466	Economy	11700.00
0005435902610	3466	Economy	11700.00
0005434938146	3466	Economy	11700.00
0005435126364	3466	Economy	11700.00
0005434878215	3466	Economy	11700.00
0005435126384	3466	Economy	11700.00
0005432799445	3466	Economy	11700.00
0005434878250	3466	Economy	11700.00
0005432799465	3466	Economy	11700.00
0005435126382	3466	Economy	11700.00
0005435126372	3466	Economy	11700.00
0005434878230	3466	Economy	11700.00
0005434426625	3466	Economy	11700.00
0005434878234	3466	Economy	11700.00
0005434938142	3466	Economy	11700.00
0005432613862	3466	Economy	11700.00
0005434878247	3466	Economy	11700.00
0005434878290	3466	Economy	11700.00
0005435126358	3466	Economy	11700.00
0005434878256	3466	Economy	11700.00
0005434938136	3466	Economy	11700.00
0005432799467	3466	Economy	11700.00
0005434426603	3466	Economy	11700.00
0005435126392	3466	Economy	11700.00
0005434878264	3466	Economy	11700.00
0005435841091	3466	Economy	11700.00
0005435126360	3466	Economy	11700.00
0005434878260	3466	Economy	11700.00
0005435126383	3466	Economy	11700.00
0005434878287	3466	Economy	11700.00
0005434938143	3466	Economy	11700.00
0005432799457	3466	Economy	11700.00
0005432799471	3466	Economy	11700.00
0005434878295	3466	Economy	11700.00
0005434878296	3466	Economy	11700.00
0005435126103	14570	Business	35000.00
0005434426362	14570	Business	35000.00
0005434877097	14570	Business	35000.00
0005434426351	14570	Business	35000.00
0005435625971	14570	Business	35000.00
0005434876966	14570	Business	35000.00
0005432607542	14570	Business	35000.00
0005432799291	14570	Business	35000.00
0005434877237	14570	Business	35000.00
0005432799169	14570	Business	35000.00
0005435126022	14570	Business	35000.00
0005435126134	14570	Business	35000.00
0005434877342	14570	Business	35000.00
0005434937923	14570	Business	35000.00
0005432799319	14570	Business	35000.00
0005435125870	14570	Business	35000.00
0005435625994	14570	Business	35000.00
0005434426265	14570	Business	35000.00
0005434877599	14570	Business	35000.00
0005435625951	14570	Business	35000.00
0005435902703	14570	Business	35000.00
0005434937973	14570	Business	35000.00
0005435126038	14570	Business	35000.00
0005434877150	14570	Comfort	19900.00
0005434877239	14570	Comfort	19900.00
0005435126031	14570	Comfort	19900.00
0005435902710	14570	Comfort	19900.00
0005434877383	14570	Comfort	19900.00
0005435625995	14570	Comfort	19900.00
0005434426272	14570	Comfort	19900.00
0005435902698	14570	Comfort	19900.00
0005434877496	14570	Comfort	19900.00
0005434877847	14570	Comfort	19900.00
0005434877609	14570	Comfort	19900.00
0005435125917	14570	Comfort	19900.00
0005435126123	14570	Comfort	19900.00
0005434877600	14570	Comfort	19900.00
0005435913935	14570	Comfort	19900.00
0005434877495	14570	Comfort	19900.00
0005434426339	14570	Comfort	19900.00
0005434426269	14570	Comfort	19900.00
0005432799104	14570	Comfort	19900.00
0005435625979	14570	Comfort	19900.00
0005435841821	14570	Comfort	19900.00
0005434426382	14570	Comfort	19900.00
0005434938006	14570	Comfort	19900.00
0005435125747	14570	Comfort	19900.00
0005432799236	14570	Comfort	19900.00
0005434877477	14570	Comfort	19900.00
0005434877434	14570	Comfort	19900.00
0005434877365	14570	Comfort	19900.00
0005435126017	14570	Comfort	19900.00
0005434426470	14570	Comfort	19900.00
0005435126044	14570	Comfort	19900.00
0005434877475	14570	Comfort	19900.00
0005434877076	14570	Economy	11700.00
0005435913934	14570	Economy	11700.00
0005434877462	14570	Economy	11700.00
0005434877478	14570	Economy	11700.00
0005435126051	14570	Economy	11700.00
0005432607519	14570	Economy	11700.00
0005434877583	14570	Economy	11700.00
0005434877597	14570	Economy	11700.00
0005434877308	14570	Economy	11700.00
0005434877435	14570	Economy	11700.00
0005434426359	14570	Economy	11700.00
0005435902705	14570	Economy	11700.00
0005435125803	14570	Economy	11700.00
0005434877151	14570	Economy	11700.00
0005434877075	14570	Economy	11700.00
0005435125980	14570	Economy	11700.00
0005434877244	14570	Economy	11700.00
0005435125932	14570	Economy	11700.00
0005435902709	14570	Economy	11700.00
0005435625958	14570	Economy	11700.00
0005434877447	14570	Economy	11700.00
0005434877613	14570	Economy	11700.00
0005434877294	14570	Economy	11700.00
0005434937984	14570	Economy	11700.00
0005432799232	14570	Economy	11700.00
0005434426268	14570	Economy	11700.00
0005435125802	14570	Economy	11700.00
0005434877482	14570	Economy	11700.00
0005435126016	14570	Economy	11700.00
0005434877283	14570	Economy	11700.00
0005434938041	14570	Economy	11700.00
0005435125928	14570	Economy	11700.00
0005435902702	14570	Economy	11700.00
0005432799231	14570	Economy	11700.00
0005434877367	14570	Economy	11700.00
0005434877349	14570	Economy	11700.00
0005434877534	14570	Economy	11700.00
0005435626003	14570	Economy	11700.00
0005434426350	14570	Economy	11700.00
0005434877492	14570	Economy	11700.00
0005435125985	14570	Economy	11700.00
0005432611656	14570	Economy	11700.00
0005434877515	14570	Economy	11700.00
0005435626019	14570	Economy	11700.00
0005434937937	14570	Economy	11700.00
0005434877548	14570	Economy	11700.00
0005435126156	14570	Economy	11700.00
0005432799180	14570	Economy	11700.00
0005434877768	14570	Economy	11700.00
0005435625976	14570	Economy	11700.00
0005434938051	14570	Economy	11700.00
0005432611682	14570	Economy	12800.00
0005434877527	14570	Economy	11700.00
0005435126111	14570	Economy	11700.00
0005434937938	14570	Economy	11700.00
0005435126043	14570	Economy	12800.00
0005434877623	14570	Economy	11700.00
0005432607541	14570	Economy	12800.00
0005434877149	14570	Economy	11700.00
0005434877969	14570	Economy	11700.00
0005434938005	14570	Economy	11700.00
0005432607512	14570	Economy	11700.00
0005435902708	14570	Economy	11700.00
0005434877397	14570	Economy	11700.00
0005434877878	14570	Economy	11700.00
0005435902694	14570	Economy	11700.00
0005432799130	14570	Economy	11700.00
0005434426333	14570	Economy	11700.00
0005432799056	14570	Economy	11700.00
0005434877277	14570	Economy	11700.00
0005434937924	14570	Economy	11700.00
0005434877343	14570	Economy	11700.00
0005435625973	14570	Economy	11700.00
0005434877598	14570	Economy	11700.00
0005434426279	14570	Economy	11700.00
0005432799263	14570	Economy	11700.00
0005435626015	14570	Economy	11700.00
0005435125943	14570	Economy	11700.00
0005435626006	14570	Economy	11700.00
0005434937983	14570	Economy	11700.00
0005434877276	14570	Economy	11700.00
0005432611695	14570	Economy	11700.00
0005434426384	14570	Economy	11700.00
0005435902707	14570	Economy	11700.00
0005432059505	14570	Economy	11700.00
0005432607531	14570	Economy	11700.00
0005434877544	14570	Economy	11700.00
0005434877498	14570	Economy	11700.00
0005434877400	14570	Economy	11700.00
0005434877610	14570	Economy	11700.00
0005435902711	14570	Economy	11700.00
0005432799201	14570	Economy	11700.00
0005432799221	14570	Economy	11700.00
0005434877322	14570	Economy	11700.00
0005432799137	14570	Economy	11700.00
0005432799342	14570	Economy	11700.00
0005435125821	14570	Economy	11700.00
0005434937918	14570	Economy	11700.00
0005435626002	14570	Economy	11700.00
0005432799213	14570	Economy	11700.00
0005435125749	14570	Economy	11700.00
0005434877493	14570	Economy	11700.00
0005434877183	14570	Economy	11700.00
0005434426278	14570	Economy	11700.00
0005432799179	14570	Economy	11700.00
0005434877112	14570	Economy	11700.00
0005434426399	14570	Economy	11700.00
0005434937974	14570	Economy	11700.00
0005435126120	14570	Economy	11700.00
0005434877275	14570	Economy	11700.00
0005432607530	14570	Economy	11700.00
0005435902695	14570	Economy	11700.00
0005434426273	14570	Economy	11700.00
0005435125994	14570	Economy	11700.00
0005434937982	14570	Economy	11700.00
0005434877361	14570	Economy	11700.00
0005435125963	14570	Economy	11700.00
0005435126081	14570	Economy	11700.00
0005434877546	14570	Economy	11700.00
0005434877535	14570	Economy	11700.00
0005434426377	14570	Economy	11700.00
0005435913936	14570	Economy	11700.00
0005435625972	14570	Economy	11700.00
0005434938087	14570	Economy	11700.00
0005434877653	14570	Economy	11700.00
0005432799105	14570	Economy	11700.00
0005432799219	14570	Economy	11700.00
0005432799343	14570	Economy	11700.00
0005435125907	14570	Economy	11700.00
0005434877777	14570	Economy	11700.00
0005432799200	14570	Economy	11700.00
0005434877395	14570	Economy	11700.00
0005435126080	14570	Economy	11700.00
0005434877551	14570	Economy	11700.00
0005434877316	14570	Economy	11700.00
0005435126032	14570	Economy	11700.00
0005435902704	14570	Economy	11700.00
0005434426361	14570	Economy	11700.00
0005432799318	14570	Economy	11700.00
0005434426469	14570	Economy	12800.00
0005435902697	14570	Economy	12800.00
0005434877776	14570	Economy	11700.00
0005435913933	14570	Economy	11700.00
0005434426400	14570	Economy	11700.00
0005434876930	14570	Economy	11700.00
0005434877608	14570	Economy	11700.00
0005432799168	14570	Economy	11700.00
0005435625999	14570	Economy	11700.00
0005434938000	14570	Economy	11700.00
0005434877769	14570	Economy	11700.00
0005435626005	14570	Economy	11700.00
0005435902699	14570	Economy	11700.00
0005435902696	14570	Economy	11700.00
0005435125986	14570	Economy	11700.00
0005434426358	14570	Economy	11700.00
0005432799199	14570	Economy	11700.00
0005434938042	14570	Economy	11700.00
0005434426352	14570	Economy	11700.00
0005434877596	14570	Economy	11700.00
0005434877497	14570	Economy	11700.00
0005434877366	14570	Economy	11700.00
0005435125748	14570	Economy	11700.00
0005434938040	14570	Economy	11700.00
0005434877396	14570	Economy	11700.00
0005434877265	14570	Economy	11700.00
0005432059504	14570	Economy	11700.00
0005435125850	14570	Economy	11700.00
0005434426467	14570	Economy	11700.00
0005434877169	14570	Economy	11700.00
0005434426322	14570	Economy	11700.00
0005435126092	14570	Economy	11700.00
0005432799222	14570	Economy	11700.00
0005435625996	14570	Economy	11700.00
0005434937999	14570	Economy	11700.00
0005435625975	14570	Economy	11700.00
0005435625974	14570	Economy	11700.00
0005434938037	14570	Economy	11700.00
0005435126045	14570	Economy	11700.00
0005434877436	14570	Economy	11700.00
0005434877315	14570	Economy	11700.00
0005434877368	14570	Economy	11700.00
0005435625926	14570	Economy	11700.00
0005435125849	14570	Economy	11700.00
0005432799250	14570	Economy	11700.00
0005435125899	14570	Economy	11700.00
0005435126052	14570	Economy	11700.00
0005434877765	14570	Economy	11700.00
0005434877712	14570	Economy	11700.00
0005435902706	14570	Economy	11700.00
0005434877595	14570	Economy	11700.00
0005432799235	14570	Economy	11700.00
0005434877607	14570	Economy	11700.00
0005435902701	14570	Economy	11700.00
0005432611663	14570	Economy	11700.00
0005434426329	14570	Economy	11700.00
0005432799290	14570	Economy	11700.00
0005434876931	14570	Economy	11700.00
0005435125860	14570	Economy	11700.00
0005434876965	14570	Economy	11700.00
0005435126091	14570	Economy	11700.00
0005434877248	14570	Economy	11700.00
0005434937985	14570	Economy	11700.00
0005434877561	14570	Economy	11700.00
0005434877238	14570	Economy	11700.00
0005434426315	14570	Economy	11700.00
0005434877401	14570	Economy	11700.00
0005435125950	14570	Economy	11700.00
0005434877284	14570	Economy	11700.00
0005435625997	14570	Economy	11700.00
0005434426267	14570	Economy	11700.00
0005434877446	14570	Economy	11700.00
0005434426403	14570	Economy	11700.00
0005435125967	14570	Economy	11700.00
0005434426286	14570	Economy	11700.00
0005435626007	14570	Economy	11700.00
0005432799317	14570	Economy	11700.00
0005432611689	14570	Economy	11700.00
0005434877483	14570	Economy	11700.00
0005435125931	14570	Economy	11700.00
0005434877474	14570	Economy	11700.00
0005435126124	14570	Economy	11700.00
0005435902700	14570	Economy	11700.00
0005434938043	14570	Economy	11700.00
0005434877362	14570	Economy	11700.00
0005434938090	14570	Economy	11700.00
0005435625998	14570	Economy	11700.00
0005434877576	14570	Economy	11700.00
0005434877182	14570	Economy	11700.00
0005434877746	14570	Economy	11700.00
0005434877332	14570	Economy	11700.00
0005435889845	3622	Economy	14800.00
0005434325648	3622	Economy	14800.00
0005434325650	3622	Economy	14800.00
0005434312319	3622	Economy	14800.00
0005434325653	3622	Economy	14800.00
0005434325651	3622	Economy	14800.00
0005434325655	3622	Economy	14800.00
0005435889825	3622	Economy	14800.00
0005434325645	3622	Economy	14800.00
0005434325646	3622	Economy	14800.00
0005434312318	3622	Economy	14800.00
0005434325647	3622	Economy	14800.00
0005434325654	3622	Economy	14800.00
0005434325644	3622	Economy	14800.00
0005434325649	3622	Economy	14800.00
0005434325652	3622	Economy	14800.00
0005434325619	15615	Economy	14800.00
0005435889893	15615	Economy	14800.00
0005434325531	15615	Economy	14800.00
0005435889897	15615	Economy	14800.00
0005434325554	15615	Economy	14800.00
0005434325568	15615	Economy	14800.00
0005435889899	15615	Economy	14800.00
0005435889898	15615	Economy	14800.00
0005434325596	15615	Economy	14800.00
0005434325541	15615	Economy	14800.00
0005434325542	15615	Economy	14800.00
0005434325581	15615	Economy	14800.00
0005435889896	15615	Economy	14800.00
0005435889895	15615	Economy	14800.00
0005434325555	15615	Economy	14800.00
0005435889894	15615	Economy	14800.00
0005434325548	15615	Economy	14800.00
0005435957708	668	Economy	4100.00
0005435957697	668	Economy	4100.00
0005433420323	668	Economy	4100.00
0005433420293	668	Economy	4100.00
0005433420334	668	Economy	4100.00
0005435957706	668	Economy	4100.00
0005435957709	668	Economy	4100.00
0005433420315	668	Economy	4100.00
0005433420324	668	Economy	4100.00
0005435957703	668	Economy	4100.00
0005433420316	668	Economy	4100.00
0005435957698	668	Economy	4100.00
0005433420328	668	Economy	4100.00
0005433420310	668	Economy	4100.00
0005433420303	668	Economy	4100.00
0005435957701	668	Economy	4100.00
0005435957705	668	Economy	4100.00
0005433420279	668	Economy	4100.00
0005435957707	668	Economy	4100.00
0005435957699	668	Economy	4100.00
0005435957700	668	Economy	4100.00
0005435957702	668	Economy	4100.00
0005435957704	668	Economy	4100.00
0005435957591	15211	Economy	4500.00
0005435957589	15211	Economy	4500.00
0005433420406	15211	Economy	4100.00
0005433420399	15211	Economy	4100.00
0005433420398	15211	Economy	4100.00
0005435957590	15211	Economy	4100.00
0005433420401	15211	Economy	4100.00
0005435957592	15211	Economy	4100.00
0005435957630	15211	Economy	4100.00
0005433420403	15211	Economy	4100.00
0005433420404	15211	Economy	4100.00
0005435957631	15211	Economy	4100.00
0005433420402	15211	Economy	4100.00
0005433420400	15211	Economy	4100.00
0005435957611	15211	Economy	4100.00
0005435957580	15211	Economy	4100.00
0005433420405	15211	Economy	4100.00
0005435957537	15211	Economy	4100.00
0005435957588	15211	Economy	4100.00
0005435957567	15211	Economy	4100.00
0005435957574	15211	Economy	4100.00
0005435957581	15211	Economy	4100.00
0005435216585	31785	Economy	28100.00
0005435217711	31785	Economy	25500.00
0005435218115	31785	Economy	25500.00
0005435218113	31785	Economy	25500.00
0005435216591	31785	Economy	25500.00
0005435217715	31785	Economy	25500.00
0005435217712	31785	Economy	25500.00
0005435216586	31785	Economy	25500.00
0005435217713	31785	Economy	25500.00
0005435216589	31785	Economy	25500.00
0005435216587	31785	Economy	25500.00
0005435216590	31785	Economy	25500.00
0005435217710	31785	Economy	25500.00
0005435218114	31785	Economy	25500.00
0005435217709	31785	Economy	25500.00
0005435216588	31785	Economy	25500.00
0005435217714	31785	Economy	25500.00
0005434995301	6698	Business	94000.00
0005434995303	6698	Business	94000.00
0005434995306	6698	Economy	31300.00
0005434995307	6698	Economy	31300.00
0005434995298	6698	Economy	34500.00
0005434995299	6698	Economy	31300.00
0005434995309	6698	Economy	31300.00
0005434995302	6698	Economy	31300.00
0005434995300	6698	Economy	31300.00
0005434995297	6698	Economy	31300.00
0005434995304	6698	Economy	31300.00
0005434995308	6698	Economy	31300.00
0005434995305	6698	Economy	31300.00
0005434247128	8869	Economy	10400.00
0005434247129	8869	Economy	10400.00
0005434247124	8869	Economy	10400.00
0005434247125	8869	Economy	10400.00
0005435629393	16064	Economy	10400.00
0005434247149	16064	Economy	10400.00
0005434247150	16064	Economy	10400.00
0005434247147	16064	Economy	10400.00
0005434247148	16064	Economy	10400.00
0005434247146	16064	Economy	10400.00
0005434467760	4012	Economy	21200.00
0005434467764	4012	Economy	21200.00
0005434467761	4012	Economy	21200.00
0005434467763	4012	Economy	21200.00
0005434467758	4012	Economy	21200.00
0005434467759	4012	Economy	21200.00
0005434467762	4012	Economy	21200.00
0005434467732	23214	Economy	21200.00
0005434467743	23214	Economy	21200.00
0005434467734	23214	Economy	21200.00
0005434467739	23214	Economy	21200.00
0005434467741	23214	Economy	21200.00
0005434467746	23214	Economy	21200.00
0005434467737	23214	Economy	21200.00
0005434467735	23214	Economy	21200.00
0005434467738	23214	Economy	21200.00
0005434096740	20171	Economy	14700.00
0005434096738	20171	Economy	13400.00
0005434096736	20171	Economy	13400.00
0005434096744	20171	Economy	13400.00
0005434096737	20171	Economy	13400.00
0005434096739	20171	Economy	13400.00
0005434096743	20171	Economy	13400.00
0005434096742	20171	Economy	13400.00
0005434096741	20171	Economy	13400.00
0005435229400	6832	Business	87700.00
0005432645993	6832	Business	87700.00
0005435229346	6832	Business	87700.00
0005432645966	6832	Business	87700.00
0005432645986	6832	Business	87700.00
0005435229353	6832	Business	87700.00
0005435229383	6832	Business	87700.00
0005435229354	6832	Business	87700.00
0005432645980	6832	Business	87700.00
0005435229375	6832	Economy	29200.00
0005432645983	6832	Economy	29200.00
0005432645984	6832	Economy	29200.00
0005432645992	6832	Economy	29200.00
0005432645976	6832	Economy	29200.00
0005435229382	6832	Economy	29200.00
0005432645977	6832	Economy	29200.00
0005435229399	6832	Economy	29200.00
0005432645982	6832	Economy	32200.00
0005432645990	6832	Economy	32200.00
0005435229341	6832	Economy	29200.00
0005432645987	6832	Economy	29200.00
0005435229370	6832	Economy	29200.00
0005432645967	6832	Economy	29200.00
0005432645979	6832	Economy	29200.00
0005432645960	6832	Economy	29200.00
0005435229364	6832	Economy	29200.00
0005432645974	6832	Economy	29200.00
0005432645998	6832	Economy	29200.00
0005432645962	6832	Economy	29200.00
0005432645988	6832	Economy	29200.00
0005432645994	6832	Economy	29200.00
0005435229355	6832	Economy	29200.00
0005432645970	6832	Economy	29200.00
0005432645969	6832	Economy	29200.00
0005432645961	6832	Economy	29200.00
0005435229330	6832	Economy	29200.00
0005432645978	6832	Economy	29200.00
0005432645985	6832	Economy	29200.00
0005432645981	6832	Economy	29200.00
0005432645995	6832	Economy	29200.00
0005432645971	6832	Economy	29200.00
0005432645991	6832	Economy	29200.00
0005432645997	6832	Economy	29200.00
0005432645989	6832	Economy	29200.00
0005432645996	6832	Economy	29200.00
0005435229349	6832	Economy	29200.00
0005435229348	6832	Economy	29200.00
0005435229339	6832	Economy	29200.00
0005435229344	6832	Economy	29200.00
0005432645965	6832	Economy	29200.00
0005435229331	6832	Economy	29200.00
0005432645972	6832	Economy	29200.00
0005432645963	6832	Economy	29200.00
0005432645968	6832	Economy	29200.00
0005435229360	6832	Economy	29200.00
0005435229361	6832	Economy	29200.00
0005432645959	6832	Economy	29200.00
0005435229342	6832	Economy	29200.00
0005435229332	6832	Economy	29200.00
0005435229343	6832	Economy	29200.00
0005435229381	6832	Economy	29200.00
0005435229352	6832	Economy	29200.00
0005432645964	6832	Economy	29200.00
0005432645975	6832	Economy	29200.00
0005435229345	6832	Economy	29200.00
0005432645973	6832	Economy	29200.00
0005435229420	25103	Business	87700.00
0005432645903	25103	Business	87700.00
0005432645849	25103	Business	87700.00
0005432645897	25103	Business	87700.00
0005432645839	25103	Business	87700.00
0005432645869	25103	Business	87700.00
0005435229424	25103	Business	87700.00
0005435229427	25103	Business	87700.00
0005435229417	25103	Business	87700.00
0005432645772	25103	Economy	29200.00
0005432645881	25103	Economy	29200.00
0005432645817	25103	Economy	29200.00
0005432645902	25103	Economy	29200.00
0005432645855	25103	Economy	29200.00
0005432645864	25103	Economy	29200.00
0005432645815	25103	Economy	29200.00
0005432645863	25103	Economy	29200.00
0005435229410	25103	Economy	29200.00
0005432645852	25103	Economy	32200.00
0005435229414	25103	Economy	32200.00
0005435229409	25103	Economy	32200.00
0005432645853	25103	Economy	29200.00
0005432645865	25103	Economy	29200.00
0005435229431	25103	Economy	29200.00
0005435229430	25103	Economy	29200.00
0005435229432	25103	Economy	29200.00
0005432645845	25103	Economy	29200.00
0005432645797	25103	Economy	29200.00
0005432645901	25103	Economy	29200.00
0005432645899	25103	Economy	29200.00
0005432645813	25103	Economy	29200.00
0005432645850	25103	Economy	29200.00
0005432645814	25103	Economy	29200.00
0005432645830	25103	Economy	29200.00
0005435229412	25103	Economy	29200.00
0005432645821	25103	Economy	29200.00
0005432645825	25103	Economy	29200.00
0005432645874	25103	Economy	29200.00
0005432645831	25103	Economy	29200.00
0005435229423	25103	Economy	29200.00
0005432645819	25103	Economy	29200.00
0005432645888	25103	Economy	29200.00
0005432645857	25103	Economy	29200.00
0005435229418	25103	Economy	29200.00
0005432645848	25103	Economy	29200.00
0005435229413	25103	Economy	29200.00
0005432645867	25103	Economy	29200.00
0005432645816	25103	Economy	29200.00
0005435229425	25103	Economy	29200.00
0005435229422	25103	Economy	29200.00
0005435229415	25103	Economy	29200.00
0005435229416	25103	Economy	29200.00
0005435229419	25103	Economy	29200.00
0005432645822	25103	Economy	29200.00
0005432645847	25103	Economy	29200.00
0005432645868	25103	Economy	29200.00
0005435229421	25103	Economy	29200.00
0005432645832	25103	Economy	29200.00
0005432645887	25103	Economy	29200.00
0005432645783	25103	Economy	29200.00
0005435229426	25103	Economy	29200.00
0005432645827	25103	Economy	29200.00
0005435229411	25103	Economy	29200.00
0005432645877	25103	Economy	29200.00
0005432645773	25103	Economy	29200.00
0005432645843	25103	Economy	29200.00
0005432645866	25103	Economy	29200.00
0005432645894	25103	Economy	29200.00
0005435229407	25103	Economy	29200.00
0005435229434	25103	Economy	29200.00
0005435229429	25103	Economy	29200.00
0005432645844	25103	Economy	29200.00
0005432645861	25103	Economy	29200.00
0005432645856	25103	Economy	29200.00
0005432645876	25103	Economy	29200.00
0005435229408	25103	Economy	29200.00
0005435229433	25103	Economy	29200.00
0005432645898	25103	Economy	29200.00
0005432645820	25103	Economy	29200.00
0005432645818	25103	Economy	29200.00
0005435229428	25103	Economy	29200.00
0005435797471	2852	Business	12600.00
0005435797481	2852	Business	12600.00
0005435797472	2852	Business	12600.00
0005433404683	2852	Economy	4200.00
0005435797477	2852	Economy	4200.00
0005435797480	2852	Economy	4200.00
0005435797474	2852	Economy	4200.00
0005435797475	2852	Economy	4200.00
0005433404743	2852	Economy	4200.00
0005433404770	2852	Economy	4200.00
0005435797473	2852	Economy	4200.00
0005435797469	2852	Economy	4200.00
0005435797479	2852	Economy	4200.00
0005433404755	2852	Economy	4200.00
0005433404742	2852	Economy	4200.00
0005435797478	2852	Economy	4200.00
0005435797470	2852	Economy	4200.00
0005435797468	2852	Economy	4200.00
0005433404740	2852	Economy	4200.00
0005433404724	2852	Economy	4200.00
0005435797476	2852	Economy	4200.00
0005433404682	2852	Economy	4200.00
0005435797380	29294	Business	12600.00
0005435797356	29294	Business	12600.00
0005435797375	29294	Business	12600.00
0005433404812	29294	Economy	4200.00
0005435797396	29294	Economy	4200.00
0005433404806	29294	Economy	4200.00
0005435797355	29294	Economy	4600.00
0005433404808	29294	Economy	4200.00
0005435797382	29294	Economy	4200.00
0005433404813	29294	Economy	4200.00
0005435797357	29294	Economy	4200.00
0005435797376	29294	Economy	4200.00
0005435797381	29294	Economy	4200.00
0005435797458	29294	Economy	4200.00
0005433404810	29294	Economy	4200.00
0005433404807	29294	Economy	4200.00
0005435797282	29294	Economy	4200.00
0005433404811	29294	Economy	4200.00
0005435797283	29294	Economy	4200.00
0005435797342	29294	Economy	4200.00
0005435797394	29294	Economy	4200.00
0005435797395	29294	Economy	4200.00
0005435797347	29294	Economy	4200.00
0005433404809	29294	Economy	4200.00
0005435376323	5851	Economy	6800.00
0005435376324	5851	Economy	6800.00
0005434948024	5827	Economy	6800.00
0005434948026	5827	Economy	6800.00
0005434948025	5827	Economy	6800.00
0005434948022	5827	Economy	6800.00
0005434948021	5827	Economy	6800.00
0005434948023	5827	Economy	6800.00
0005434948019	5827	Economy	6800.00
0005434948020	5827	Economy	6800.00
0005435376354	16359	Economy	6800.00
0005435376352	16359	Economy	6800.00
0005434947923	16359	Economy	6800.00
0005435376349	16359	Economy	6800.00
0005435376351	16359	Economy	6800.00
0005435376350	16359	Economy	6800.00
0005434947998	16359	Economy	6800.00
0005435376353	16359	Economy	6800.00
0005435376348	16359	Economy	6800.00
0005434947960	16359	Economy	6800.00
0005433960909	6880	Business	21400.00
0005433960887	6880	Business	21400.00
0005433960882	6880	Business	21400.00
0005433960912	6880	Business	21400.00
0005433960886	6880	Business	21400.00
0005433960878	6880	Business	21400.00
0005433960868	6880	Economy	7100.00
0005433960892	6880	Economy	7100.00
0005433960906	6880	Economy	7100.00
0005433960874	6880	Economy	7100.00
0005433960852	6880	Economy	7100.00
0005433960884	6880	Economy	7100.00
0005433960894	6880	Economy	7100.00
0005433960867	6880	Economy	7800.00
0005433960876	6880	Economy	7100.00
0005433960859	6880	Economy	7100.00
0005433960903	6880	Economy	7100.00
0005433960861	6880	Economy	7100.00
0005433960871	6880	Economy	7100.00
0005433960865	6880	Economy	7100.00
0005433960864	6880	Economy	7100.00
0005433960870	6880	Economy	7100.00
0005433960907	6880	Economy	7100.00
0005433960904	6880	Economy	7100.00
0005433960888	6880	Economy	7100.00
0005433960851	6880	Economy	7100.00
0005433960898	6880	Economy	7100.00
0005433960900	6880	Economy	7100.00
0005433960875	6880	Economy	7100.00
0005433960885	6880	Economy	7100.00
0005433960899	6880	Economy	7100.00
0005433960858	6880	Economy	7100.00
0005433960856	6880	Economy	7100.00
0005433960857	6880	Economy	7100.00
0005433960866	6880	Economy	7100.00
0005433960897	6880	Economy	7100.00
0005433960889	6880	Economy	7100.00
0005433960893	6880	Economy	7100.00
0005433960877	6880	Economy	7100.00
0005433960869	6880	Economy	7100.00
0005433960896	6880	Economy	7100.00
0005433960862	6880	Economy	7100.00
0005433960872	6880	Economy	7100.00
0005433960901	6880	Economy	7100.00
0005433960883	6880	Economy	7100.00
0005433960902	6880	Economy	7100.00
0005433960890	6880	Economy	7100.00
0005433960910	6880	Economy	7100.00
0005433960863	6880	Economy	7100.00
0005433960891	6880	Economy	7100.00
0005433960880	6880	Economy	7100.00
0005433960854	6880	Economy	7100.00
0005433960879	6880	Economy	7100.00
0005433960881	6880	Economy	7100.00
0005433960905	6880	Economy	7100.00
0005433960911	6880	Economy	7100.00
0005433960860	6880	Economy	7100.00
0005433960895	6880	Economy	7100.00
0005433960855	6880	Economy	7100.00
0005433960908	6880	Economy	7100.00
0005433960853	6880	Economy	7100.00
0005433960873	6880	Economy	7100.00
0005433960092	25765	Business	21400.00
0005433960160	25765	Business	21400.00
0005433960019	25765	Business	21400.00
0005433960214	25765	Business	21400.00
0005433960186	25765	Business	21400.00
0005433960046	25765	Business	21400.00
0005433960320	25765	Economy	7100.00
0005433960301	25765	Economy	7100.00
0005433960188	25765	Economy	7100.00
0005433960159	25765	Economy	7100.00
0005433960138	25765	Economy	7100.00
0005433960335	25765	Economy	7100.00
0005433960261	25765	Economy	7100.00
0005433960166	25765	Economy	7100.00
0005433960045	25765	Economy	7100.00
0005433960146	25765	Economy	7800.00
0005433960263	25765	Economy	7800.00
0005433960149	25765	Economy	7800.00
0005433960241	25765	Economy	7800.00
0005433960306	25765	Economy	7100.00
0005433960255	25765	Economy	7100.00
0005433960307	25765	Economy	7100.00
0005433960167	25765	Economy	7100.00
0005433960129	25765	Economy	7100.00
0005433960130	25765	Economy	7100.00
0005433960215	25765	Economy	7100.00
0005433960316	25765	Economy	7100.00
0005433960230	25765	Economy	7100.00
0005433960305	25765	Economy	7100.00
0005433960170	25765	Economy	7100.00
0005433960084	25765	Economy	7100.00
0005433960280	25765	Economy	7100.00
0005433960250	25765	Economy	7100.00
0005433960058	25765	Economy	7100.00
0005433960265	25765	Economy	7100.00
0005433960284	25765	Economy	7100.00
0005433959909	25765	Economy	7100.00
0005433960298	25765	Economy	7100.00
0005433960277	25765	Economy	7100.00
0005433960285	25765	Economy	7100.00
0005433960187	25765	Economy	7100.00
0005433960093	25765	Economy	7100.00
0005433960147	25765	Economy	7100.00
0005433960256	25765	Economy	7100.00
0005433960262	25765	Economy	7100.00
0005433960249	25765	Economy	7100.00
0005433960334	25765	Economy	7100.00
0005433960142	25765	Economy	7100.00
0005433960247	25765	Economy	7100.00
0005433959908	25765	Economy	7100.00
0005433960264	25765	Economy	7100.00
0005433960232	25765	Economy	7100.00
0005433960143	25765	Economy	7100.00
0005433960297	25765	Economy	7100.00
0005433960275	25765	Economy	7100.00
0005433960321	25765	Economy	7100.00
0005433960244	25765	Economy	7100.00
0005433960272	25765	Economy	7100.00
0005433960231	25765	Economy	7100.00
0005433960245	25765	Economy	7100.00
0005433960248	25765	Economy	7100.00
0005433960158	25765	Economy	7100.00
0005433960302	25765	Economy	7100.00
0005433960290	25765	Economy	7100.00
0005433960020	25765	Economy	7100.00
0005433960216	25765	Economy	7100.00
0005433960242	25765	Economy	7100.00
0005433959999	25765	Economy	7100.00
0005435082711	24507	Economy	3900.00
0005435082712	24507	Economy	3900.00
0005435082687	24507	Economy	3900.00
0005435082713	24507	Economy	3900.00
0005435082772	24507	Economy	3900.00
0005435082718	24507	Economy	3900.00
0005435082779	26107	Economy	3900.00
0005435082781	26107	Economy	3900.00
0005435082782	26107	Economy	3900.00
0005435082780	26107	Economy	3900.00
0005435082783	26107	Economy	3900.00
0005435082778	26107	Economy	3900.00
0005434244967	5195	Business	18000.00
0005434244982	5195	Business	18000.00
0005435286570	5195	Business	18000.00
0005434244969	5195	Business	18000.00
0005434244968	5195	Business	18000.00
0005434244977	5195	Economy	6600.00
0005435286586	5195	Economy	6600.00
0005434244984	5195	Economy	6000.00
0005434244970	5195	Economy	6000.00
0005434244980	5195	Economy	6000.00
0005433534476	5195	Economy	6000.00
0005434244978	5195	Economy	6000.00
0005434244979	5195	Economy	6000.00
0005434244983	5195	Economy	6000.00
0005433534475	5195	Economy	6000.00
0005433534474	5195	Economy	6000.00
0005434244991	5195	Economy	6000.00
0005432166900	5195	Economy	6000.00
0005434244990	5195	Economy	6000.00
0005432166901	5195	Economy	6000.00
0005434244989	5195	Economy	6000.00
0005433534484	5195	Economy	6000.00
0005434244992	5195	Economy	6000.00
0005434244994	5195	Economy	6000.00
0005435286574	5195	Economy	6000.00
0005434244986	5195	Economy	6000.00
0005435286568	5195	Economy	6000.00
0005435286577	5195	Economy	6600.00
0005434244993	5195	Economy	6600.00
0005434244988	5195	Economy	6600.00
0005434244971	5195	Economy	6000.00
0005432166903	5195	Economy	6000.00
0005434244976	5195	Economy	6000.00
0005434244981	5195	Economy	6000.00
0005434244966	5195	Economy	6000.00
0005434244987	5195	Economy	6000.00
0005434244965	5195	Economy	6000.00
0005434244974	5195	Economy	6000.00
0005432166902	5195	Economy	6000.00
0005434244973	5195	Economy	6000.00
0005434244972	5195	Economy	6000.00
0005434244985	5195	Economy	6000.00
0005435286581	5195	Economy	6000.00
0005434244975	5195	Economy	6000.00
0005433614690	5170	Business	18000.00
0005433614679	5170	Business	18000.00
0005432105557	5170	Business	18000.00
0005432666389	5170	Business	18000.00
0005433614660	5170	Business	18000.00
0005432105560	5170	Business	18000.00
0005432105570	5170	Business	18000.00
0005433614661	5170	Business	18000.00
0005433614688	5170	Business	18000.00
0005433614689	5170	Business	18000.00
0005433614706	5170	Business	18000.00
0005432105568	5170	Business	18000.00
0005433614697	5170	Business	18000.00
0005433614717	5170	Business	18000.00
0005432105577	5170	Business	18000.00
0005432105559	5170	Business	18000.00
0005433614728	5170	Business	18000.00
0005433614671	5170	Business	18000.00
0005433614696	5170	Business	18000.00
0005433784943	5170	Business	18000.00
0005433614682	5170	Business	18000.00
0005432105580	5170	Business	18000.00
0005432105549	5170	Business	18000.00
0005433784937	5170	Business	18000.00
0005433784954	5170	Business	18000.00
0005432105558	5170	Business	18000.00
0005433614674	5170	Business	18000.00
0005432105578	5170	Business	18000.00
0005432105585	5170	Economy	6600.00
0005432667454	5170	Economy	6600.00
0005433614694	5170	Economy	6600.00
0005432105569	5170	Economy	6600.00
0005433614729	5170	Economy	6600.00
0005432105581	5170	Economy	6000.00
0005433614704	5170	Economy	6600.00
0005432105551	5170	Economy	6000.00
0005432105572	5170	Economy	6000.00
0005432105545	5170	Economy	6000.00
0005433784958	5170	Economy	6000.00
0005433614662	5170	Economy	6000.00
0005433614719	5170	Economy	6000.00
0005433614672	5170	Economy	6000.00
0005433614727	5170	Economy	6000.00
0005433784935	5170	Economy	6000.00
0005432105582	5170	Economy	6000.00
0005433614677	5170	Economy	6000.00
0005432105576	5170	Economy	6000.00
0005433784953	5170	Economy	6000.00
0005433614664	5170	Economy	6000.00
0005432665275	5170	Economy	6000.00
0005433614681	5170	Economy	6000.00
0005433614707	5170	Economy	6000.00
0005433614675	5170	Economy	6000.00
0005433614692	5170	Economy	6000.00
0005432145111	5170	Economy	6000.00
0005432105583	5170	Economy	6000.00
0005433614702	5170	Economy	6000.00
0005433784930	5170	Economy	6000.00
0005433614709	5170	Economy	6000.00
0005432105561	5170	Economy	6000.00
0005432105547	5170	Economy	6000.00
0005432667455	5170	Economy	6000.00
0005433614683	5170	Economy	6000.00
0005433614687	5170	Economy	6000.00
0005432105563	5170	Economy	6000.00
0005433614703	5170	Economy	6000.00
0005432105565	5170	Economy	6000.00
0005433784933	5170	Economy	6000.00
0005432105562	5170	Economy	6000.00
0005432105574	5170	Economy	6000.00
0005433784944	5170	Economy	6000.00
0005432105571	5170	Economy	6000.00
0005433614668	5170	Economy	6000.00
0005433614676	5170	Economy	6000.00
0005433784924	5170	Economy	6000.00
0005432145112	5170	Economy	6000.00
0005433614686	5170	Economy	6000.00
0005432105584	5170	Economy	6000.00
0005432105590	5170	Economy	6000.00
0005432105552	5170	Economy	6000.00
0005432105553	5170	Economy	6000.00
0005433614730	5170	Economy	6000.00
0005433614680	5170	Economy	6000.00
0005433784936	5170	Economy	6000.00
0005432667453	5170	Economy	6000.00
0005432105566	5170	Economy	6000.00
0005433784949	5170	Economy	6000.00
0005433614700	5170	Economy	6000.00
0005433614699	5170	Economy	6000.00
0005433614669	5170	Economy	6000.00
0005433614663	5170	Economy	6000.00
0005433784942	5170	Economy	6000.00
0005433784928	5170	Economy	6000.00
0005433614659	5170	Economy	6000.00
0005432105546	5170	Economy	6600.00
0005433614693	5170	Economy	6600.00
0005432105567	5170	Economy	6600.00
0005433614722	5170	Economy	6600.00
0005433614715	5170	Economy	6000.00
0005433784938	5170	Economy	6600.00
0005433614708	5170	Economy	6000.00
0005432666390	5170	Economy	6000.00
0005433784945	5170	Economy	6000.00
0005433614710	5170	Economy	6600.00
0005433784951	5170	Economy	6000.00
0005433614665	5170	Economy	6000.00
0005433614732	5170	Economy	6000.00
0005433614684	5170	Economy	6000.00
0005433614698	5170	Economy	6000.00
0005432145113	5170	Economy	6000.00
0005433784932	5170	Economy	6000.00
0005433614701	5170	Economy	6000.00
0005433614721	5170	Economy	6000.00
0005433784925	5170	Economy	6000.00
0005433614723	5170	Economy	6000.00
0005433784926	5170	Economy	6000.00
0005433614720	5170	Economy	6000.00
0005433784948	5170	Economy	6000.00
0005433614718	5170	Economy	6000.00
0005433614726	5170	Economy	6000.00
0005433614733	5170	Economy	6000.00
0005433784959	5170	Economy	6000.00
0005432665274	5170	Economy	6000.00
0005433614711	5170	Economy	6000.00
0005433614673	5170	Economy	6000.00
0005432105579	5170	Economy	6000.00
0005433614725	5170	Economy	6000.00
0005432105575	5170	Economy	6000.00
0005433784927	5170	Economy	6000.00
0005433784934	5170	Economy	6000.00
0005432105556	5170	Economy	6000.00
0005433784940	5170	Economy	6000.00
0005433614685	5170	Economy	6000.00
0005433784931	5170	Economy	6000.00
0005433614691	5170	Economy	6000.00
0005433784950	5170	Economy	6000.00
0005433784955	5170	Economy	6000.00
0005433614705	5170	Economy	6000.00
0005432666388	5170	Economy	6000.00
0005433614666	5170	Economy	6000.00
0005432105589	5170	Economy	6000.00
0005433614731	5170	Economy	6000.00
0005432105591	5170	Economy	6000.00
0005433784946	5170	Economy	6000.00
0005432105548	5170	Economy	6000.00
0005432105586	5170	Economy	6000.00
0005432105550	5170	Economy	6000.00
0005433784939	5170	Economy	6000.00
0005433784941	5170	Economy	6000.00
0005433784947	5170	Economy	6000.00
0005432105588	5170	Economy	6000.00
0005433614714	5170	Economy	6000.00
0005433784952	5170	Economy	6000.00
0005433784929	5170	Economy	6000.00
0005433614678	5170	Economy	6000.00
0005433614695	5170	Economy	6000.00
0005433614713	5170	Economy	6000.00
0005432105573	5170	Economy	6000.00
0005433784957	5170	Economy	6000.00
0005433614724	5170	Economy	6000.00
0005433614670	5170	Economy	6000.00
0005432105587	5170	Economy	6000.00
0005432105555	5170	Economy	6000.00
0005432105564	5170	Economy	6000.00
0005432665273	5170	Economy	6000.00
0005433784956	5170	Economy	6000.00
0005433614712	5170	Economy	6000.00
0005433614667	5170	Economy	6000.00
0005433614716	5170	Economy	6000.00
0005432105554	5170	Economy	6000.00
0005434265133	5145	Business	18000.00
0005434229370	5145	Business	18000.00
0005434149726	5145	Business	18000.00
0005434229375	5145	Business	18000.00
0005432335935	5145	Business	18000.00
0005432335943	5145	Business	18000.00
0005434265136	5145	Business	18000.00
0005434229365	5145	Business	18000.00
0005434229374	5145	Business	18000.00
0005434229369	5145	Business	18000.00
0005433685503	5145	Business	18000.00
0005435006834	5145	Business	18000.00
0005434229360	5145	Business	18000.00
0005435006930	5145	Business	18000.00
0005435006792	5145	Business	18000.00
0005434265137	5145	Business	18000.00
0005434265125	5145	Business	18000.00
0005434229359	5145	Business	18000.00
0005434149732	5145	Business	18000.00
0005434265147	5145	Business	18000.00
0005434149735	5145	Business	18000.00
0005433815321	5145	Economy	6600.00
0005432335898	5145	Economy	6600.00
0005434265135	5145	Economy	6600.00
0005434173518	5145	Economy	6000.00
0005434149730	5145	Economy	6000.00
0005435006789	5145	Economy	6000.00
0005432335911	5145	Economy	6000.00
0005434265144	5145	Economy	6000.00
0005435006788	5145	Economy	6000.00
0005433815323	5145	Economy	6000.00
0005434229368	5145	Economy	6000.00
0005434149734	5145	Economy	6000.00
0005434265145	5145	Economy	6000.00
0005435006883	5145	Economy	6000.00
0005434265138	5145	Economy	6000.00
0005433815353	5145	Economy	6000.00
0005432335899	5145	Economy	6000.00
0005435006825	5145	Economy	6000.00
0005434229376	5145	Economy	6000.00
0005432335937	5145	Economy	6000.00
0005434173520	5145	Economy	6000.00
0005434173519	5145	Economy	6000.00
0005434229367	5145	Economy	6000.00
0005434149731	5145	Economy	6000.00
0005434149733	5145	Economy	6000.00
0005435006802	5145	Economy	6000.00
0005434265150	5145	Economy	6000.00
0005434229363	5145	Economy	6000.00
0005434229362	5145	Economy	6000.00
0005434265134	5145	Economy	6000.00
0005434265131	5145	Economy	6000.00
0005433815349	5145	Economy	6000.00
0005434265127	5145	Economy	6000.00
0005434229364	5145	Economy	6000.00
0005434265128	5145	Economy	6000.00
0005434149736	5145	Economy	6000.00
0005433815331	5145	Economy	6000.00
0005434229378	5145	Economy	6000.00
0005433815350	5145	Economy	6000.00
0005434229379	5145	Economy	6000.00
0005434149728	5145	Economy	6000.00
0005432335964	5145	Economy	6000.00
0005432335910	5145	Economy	6000.00
0005434265130	5145	Economy	6000.00
0005433815320	5145	Economy	6000.00
0005434265146	5145	Economy	6600.00
0005434229372	5145	Economy	6600.00
0005434149725	5145	Economy	6600.00
0005432335926	5145	Economy	6000.00
0005433815332	5145	Economy	6000.00
0005433815322	5145	Economy	6000.00
0005435006744	5145	Economy	6600.00
0005434265139	5145	Economy	6000.00
0005434265129	5145	Economy	6000.00
0005432335936	5145	Economy	6000.00
0005434229381	5145	Economy	6000.00
0005435006824	5145	Economy	6000.00
0005433815337	5145	Economy	6000.00
0005434229366	5145	Economy	6000.00
0005435006743	5145	Economy	6000.00
0005435006807	5145	Economy	6000.00
0005434265148	5145	Economy	6000.00
0005433815355	5145	Economy	6000.00
0005434173521	5145	Economy	6000.00
0005434265149	5145	Economy	6000.00
0005435006803	5145	Economy	6000.00
0005434229373	5145	Economy	6000.00
0005435006835	5145	Economy	6000.00
0005434312299	5145	Economy	6000.00
0005433685504	5145	Economy	6000.00
0005433815352	5145	Economy	6000.00
0005434265141	5145	Economy	6000.00
0005432335944	5145	Economy	6000.00
0005435006769	5145	Economy	6000.00
0005434229382	5145	Economy	6000.00
0005434229380	5145	Economy	6000.00
0005435006806	5145	Economy	6000.00
0005433815344	5145	Economy	6000.00
0005434265126	5145	Economy	6000.00
0005435006813	5145	Economy	6000.00
0005434265142	5145	Economy	6000.00
0005433815330	5145	Economy	6000.00
0005435006787	5145	Economy	6000.00
0005434265143	5145	Economy	6000.00
0005432335978	5145	Economy	6000.00
0005434149729	5145	Economy	6000.00
0005434229377	5145	Economy	6000.00
0005434149727	5145	Economy	6000.00
0005434229361	5145	Economy	6000.00
0005434265140	5145	Economy	6000.00
0005433815310	5145	Economy	6000.00
0005432335892	5145	Economy	6000.00
0005434265132	5145	Economy	6000.00
0005434229371	5145	Economy	6000.00
0005435006814	5145	Economy	6000.00
0005433784598	8460	Business	18000.00
0005434244637	8460	Business	18000.00
0005433784674	8460	Business	18000.00
0005434244703	8460	Business	18000.00
0005434244743	8460	Business	18000.00
0005434244727	8460	Business	18000.00
0005433784492	8460	Business	18000.00
0005433784545	8460	Business	18000.00
0005434244796	8460	Business	18000.00
0005434244767	8460	Business	18000.00
0005434244684	8460	Business	18000.00
0005433784475	8460	Business	18000.00
0005434244797	8460	Business	18000.00
0005433784537	8460	Business	18000.00
0005434244744	8460	Business	18000.00
0005434244694	8460	Economy	6600.00
0005432666370	8460	Economy	6600.00
0005434244636	8460	Economy	6000.00
0005434244747	8460	Economy	6000.00
0005434244708	8460	Economy	6000.00
0005433784701	8460	Economy	6000.00
0005434244790	8460	Economy	6000.00
0005434244737	8460	Economy	6000.00
0005434244778	8460	Economy	6000.00
0005432666371	8460	Economy	6000.00
0005434244860	8460	Economy	6000.00
0005434244770	8460	Economy	6000.00
0005434244713	8460	Economy	6000.00
0005434244683	8460	Economy	6000.00
0005433784683	8460	Economy	6000.00
0005434244795	8460	Economy	6000.00
0005434244695	8460	Economy	6000.00
0005434244647	8460	Economy	6000.00
0005433784617	8460	Economy	6000.00
0005434244768	8460	Economy	6000.00
0005432663013	8460	Economy	6000.00
0005434244777	8460	Economy	6000.00
0005434244798	8460	Economy	6000.00
0005434244706	8460	Economy	6000.00
0005433784711	8460	Economy	6000.00
0005433784476	8460	Economy	6000.00
0005433784681	8460	Economy	6000.00
0005433784673	8460	Economy	6000.00
0005433784547	8460	Economy	6000.00
0005434244725	8460	Economy	6000.00
0005433784578	8460	Economy	6000.00
0005433784694	8460	Economy	6000.00
0005433784541	8460	Economy	6000.00
0005433784715	8460	Economy	6000.00
0005433784714	8460	Economy	6000.00
0005433784710	8460	Economy	6000.00
0005433784648	8460	Economy	6000.00
0005433784544	8460	Economy	6000.00
0005433784752	8460	Economy	6000.00
0005434244696	8460	Economy	6000.00
0005433784726	8460	Economy	6000.00
0005433784716	8460	Economy	6000.00
0005433784546	8460	Economy	6000.00
0005434244707	8460	Economy	6000.00
0005433784618	8460	Economy	6000.00
0005434244749	8460	Economy	6000.00
0005434244726	8460	Economy	6000.00
0005433784625	8460	Economy	6000.00
0005433784633	8460	Economy	6000.00
0005434244816	8460	Economy	6000.00
0005433784515	8460	Economy	6000.00
0005433784663	8460	Economy	6000.00
0005435269748	8460	Economy	6000.00
0005434244763	8460	Economy	6000.00
0005433784457	8460	Economy	6000.00
0005433784727	8460	Economy	6000.00
0005433784647	8460	Economy	6000.00
0005433784575	8460	Economy	6000.00
0005433784604	8460	Economy	6000.00
0005433784574	8460	Economy	6000.00
0005433784632	8460	Economy	6000.00
0005432663014	8460	Economy	6000.00
0005433784684	8460	Economy	6000.00
0005433614066	8461	Business	18000.00
0005433613629	8461	Business	18000.00
0005433613892	8461	Business	18000.00
0005433613778	8461	Business	18000.00
0005433613966	8461	Business	18000.00
0005433613957	8461	Business	18000.00
0005433614102	8461	Business	18000.00
0005433613689	8461	Business	18000.00
0005433613687	8461	Business	18000.00
0005433614099	8461	Business	18000.00
0005433613979	8461	Business	18000.00
0005433613971	8461	Business	18000.00
0005433613906	8461	Business	18000.00
0005433613883	8461	Business	18000.00
0005433613792	8461	Business	18000.00
0005433613999	8461	Business	18000.00
0005433614138	8461	Business	18000.00
0005433613777	8461	Economy	6600.00
0005433613860	8461	Economy	6600.00
0005433614223	8461	Economy	6600.00
0005433613924	8461	Economy	6600.00
0005433614007	8461	Economy	6000.00
0005433614175	8461	Economy	6000.00
0005433613699	8461	Economy	6000.00
0005433613791	8461	Economy	6000.00
0005433614113	8461	Economy	6000.00
0005433613861	8461	Economy	6000.00
0005433614087	8461	Economy	6000.00
0005433613540	8461	Economy	6000.00
0005433614210	8461	Economy	6000.00
0005433614400	8461	Economy	6000.00
0005433613894	8461	Economy	6000.00
0005433614349	8461	Economy	6000.00
0005433613970	8461	Economy	6000.00
0005433614091	8461	Economy	6000.00
0005433614170	8461	Economy	6000.00
0005433614052	8461	Economy	6000.00
0005433614263	8461	Economy	6000.00
0005433614045	8461	Economy	6000.00
0005433613688	8461	Economy	6000.00
0005433614070	8461	Economy	6000.00
0005433614211	8461	Economy	6000.00
0005433614053	8461	Economy	6000.00
0005433614109	8461	Economy	6000.00
0005433614071	8461	Economy	6000.00
0005433613968	8461	Economy	6000.00
0005433613732	8461	Economy	6000.00
0005433613967	8461	Economy	6000.00
0005433613884	8461	Economy	6600.00
0005433614031	8461	Economy	6600.00
0005433613986	8461	Economy	6000.00
0005433613932	8461	Economy	6000.00
0005433614001	8461	Economy	6600.00
0005433613849	8461	Economy	6000.00
0005433613757	8461	Economy	6000.00
0005433613933	8461	Economy	6000.00
0005433613630	8461	Economy	6000.00
0005433614177	8461	Economy	6000.00
0005433613931	8461	Economy	6000.00
0005433614067	8461	Economy	6000.00
0005433614030	8461	Economy	6000.00
0005433614162	8461	Economy	6000.00
0005433614029	8461	Economy	6000.00
0005433613851	8461	Economy	6000.00
0005433614350	8461	Economy	6000.00
0005433614000	8461	Economy	6000.00
0005433613539	8461	Economy	6000.00
0005433614176	8461	Economy	6000.00
0005433613799	8461	Economy	6000.00
0005433613985	8461	Economy	6000.00
0005433614059	8461	Economy	6000.00
0005433614112	8461	Economy	6000.00
0005433613618	8461	Economy	6000.00
0005433613965	8461	Economy	6000.00
0005433613864	8461	Economy	6000.00
0005433614139	8461	Economy	6000.00
0005433613865	8461	Economy	6000.00
0005433614174	8461	Economy	6000.00
0005433614023	8461	Economy	6000.00
0005433613836	8461	Economy	6000.00
0005433614108	8461	Economy	6000.00
0005433613893	8461	Economy	6000.00
0005433613988	8461	Economy	6000.00
0005433614107	8461	Economy	6000.00
0005433614358	8461	Economy	6000.00
0005433613862	8461	Economy	6000.00
0005432336030	8462	Business	18000.00
0005434229179	8462	Business	18000.00
0005432336034	8462	Business	18000.00
0005435007038	8462	Business	18000.00
0005434264842	8462	Business	18000.00
0005434229240	8462	Business	18000.00
0005434229220	8462	Business	18000.00
0005434229237	8462	Business	18000.00
0005434229106	8462	Business	18000.00
0005434229184	8462	Business	18000.00
0005433534499	8462	Business	18000.00
0005434149617	8462	Business	18000.00
0005434311218	8462	Business	18000.00
0005435007030	8462	Business	18000.00
0005434229277	8462	Business	18000.00
0005433690928	8462	Business	18000.00
0005432336036	8462	Business	18000.00
0005432047549	8462	Business	18000.00
0005434149623	8462	Business	18000.00
0005434229107	8462	Business	18000.00
0005432034952	8462	Business	18000.00
0005432034954	8462	Business	18000.00
0005434229276	8462	Business	18000.00
0005435007042	8462	Business	18000.00
0005432034962	8462	Business	18000.00
0005432336029	8462	Economy	6600.00
0005432034934	8462	Business	18000.00
0005434229122	8462	Economy	6600.00
0005434264903	8462	Economy	6600.00
0005432047548	8462	Economy	6600.00
0005434229169	8462	Economy	6600.00
0005435007035	8462	Economy	6000.00
0005434229073	8462	Economy	6000.00
0005434229229	8462	Economy	6000.00
0005434264891	8462	Economy	6000.00
0005434149651	8462	Economy	6000.00
0005435007022	8462	Economy	6000.00
0005433688810	8462	Economy	6000.00
0005434264949	8462	Economy	6000.00
0005434264923	8462	Economy	6000.00
0005434264974	8462	Economy	6000.00
0005434311219	8462	Economy	6000.00
0005432034937	8462	Economy	6000.00
0005432047550	8462	Economy	6000.00
0005434264859	8462	Economy	6000.00
0005432034960	8462	Economy	6000.00
0005433815388	8462	Economy	6000.00
0005432336037	8462	Economy	6000.00
0005434265024	8462	Economy	6000.00
0005434149677	8462	Economy	6000.00
0005435007041	8462	Economy	6000.00
0005432336031	8462	Economy	6000.00
0005434264811	8462	Economy	6000.00
0005435007033	8462	Economy	6000.00
0005435007034	8462	Economy	6000.00
0005433815386	8462	Economy	6000.00
0005434229205	8462	Economy	6000.00
0005433534497	8462	Economy	6000.00
0005432034950	8462	Economy	6000.00
0005434264892	8462	Economy	6000.00
0005434229174	8462	Economy	6000.00
0005434229140	8462	Economy	6000.00
0005435007039	8462	Economy	6000.00
0005432034939	8462	Economy	6000.00
0005434173490	8462	Economy	6000.00
0005434149650	8462	Economy	6000.00
0005432034959	8462	Economy	6000.00
0005432034942	8462	Economy	6000.00
0005432034944	8462	Economy	6000.00
0005432034948	8462	Economy	6000.00
0005433815387	8462	Economy	6000.00
0005432047551	8462	Economy	6000.00
0005435007028	8462	Economy	6000.00
0005433815385	8462	Economy	6000.00
0005434229039	8462	Economy	6000.00
0005432336039	8462	Economy	6000.00
0005432034949	8462	Economy	6000.00
0005433689911	8462	Economy	6000.00
0005434229197	8462	Economy	6000.00
0005432336035	8462	Economy	6000.00
0005434149589	8462	Economy	6000.00
0005434149624	8462	Economy	6000.00
0005434173478	8462	Economy	6000.00
0005434264890	8462	Economy	6000.00
0005434264870	8462	Economy	6000.00
0005435007024	8462	Economy	6000.00
0005434229238	8462	Economy	6600.00
0005434264860	8462	Economy	6600.00
0005434265036	8462	Economy	6600.00
0005434149594	8462	Economy	6600.00
0005432034957	8462	Economy	6600.00
0005434264969	8462	Economy	6000.00
0005435007029	8462	Economy	6000.00
0005432034955	8462	Economy	6000.00
0005434229239	8462	Economy	6600.00
0005434229145	8462	Economy	6000.00
0005434149593	8462	Economy	6000.00
0005435007040	8462	Economy	6000.00
0005435007043	8462	Economy	6000.00
0005432034936	8462	Economy	6000.00
0005434229072	8462	Economy	6000.00
0005432034943	8462	Economy	6000.00
0005434264841	8462	Economy	6000.00
0005434264888	8462	Economy	6000.00
0005434229221	8462	Economy	6000.00
0005435007036	8462	Economy	6000.00
0005434264978	8462	Economy	6000.00
0005434264924	8462	Economy	6000.00
0005432336032	8462	Economy	6000.00
0005435007031	8462	Economy	6000.00
0005434229190	8462	Economy	6000.00
0005433690927	8462	Economy	6000.00
0005432034941	8462	Economy	6000.00
0005432034958	8462	Economy	6000.00
0005434264925	8462	Economy	6000.00
0005433815384	8462	Economy	6000.00
0005435007025	8462	Economy	6000.00
0005434229139	8462	Economy	6000.00
0005432034946	8462	Economy	6000.00
0005434264900	8462	Economy	6000.00
0005432034951	8462	Economy	6000.00
0005434149626	8462	Economy	6000.00
0005434229146	8462	Economy	6000.00
0005435007032	8462	Economy	6000.00
0005434265014	8462	Economy	6000.00
0005434264817	8462	Economy	6000.00
0005432034940	8462	Economy	6000.00
0005434229185	8462	Economy	6000.00
0005434265005	8462	Economy	6000.00
0005435007023	8462	Economy	6000.00
0005434311220	8462	Economy	6000.00
0005432336040	8462	Economy	6000.00
0005434264812	8462	Economy	6000.00
0005434149590	8462	Economy	6000.00
0005432034947	8462	Economy	6000.00
0005432336033	8462	Economy	6000.00
0005433534498	8462	Economy	6000.00
0005432336038	8462	Economy	6000.00
0005435007027	8462	Economy	6000.00
0005434229040	8462	Economy	6000.00
0005435007037	8462	Economy	6000.00
0005434173491	8462	Economy	6000.00
0005434229180	8462	Economy	6000.00
0005435007021	8462	Economy	6000.00
0005434264960	8462	Economy	6000.00
0005432034938	8462	Economy	6000.00
0005432034953	8462	Economy	6000.00
0005432034945	8462	Economy	6000.00
0005434264843	8462	Economy	6000.00
0005434229153	8462	Economy	6000.00
0005434173483	8462	Economy	6000.00
0005432034956	8462	Economy	6000.00
0005432034961	8462	Economy	6000.00
0005434229131	8462	Economy	6000.00
0005434229192	8462	Economy	6000.00
0005434229196	8462	Economy	6000.00
0005432034935	8462	Economy	6000.00
0005435007026	8462	Economy	6000.00
0005433202371	12618	Economy	16200.00
0005434639220	12618	Economy	16200.00
0005434639060	12618	Economy	14800.00
0005434639023	12618	Economy	14800.00
0005434639024	12618	Economy	14800.00
0005433202365	12618	Economy	14800.00
0005434639088	12618	Economy	14800.00
0005433202368	12618	Economy	14800.00
0005433202362	12618	Economy	14800.00
0005434639155	12618	Economy	14800.00
0005433202366	12618	Economy	14800.00
0005433202360	12618	Economy	14800.00
0005434639117	12618	Economy	14800.00
0005434639062	12618	Economy	14800.00
0005433202367	12618	Economy	14800.00
0005434639186	12618	Economy	14800.00
0005433202363	12618	Economy	14800.00
0005434639175	12618	Economy	14800.00
0005433202358	12618	Economy	14800.00
0005434639061	12618	Economy	14800.00
0005434639004	12618	Economy	14800.00
0005433202373	12618	Economy	14800.00
0005434639174	12618	Economy	14800.00
0005433202369	12618	Economy	14800.00
0005434639154	12618	Economy	14800.00
0005434639084	12618	Economy	14800.00
0005434639077	12618	Economy	14800.00
0005434639187	12618	Economy	14800.00
0005433202370	12618	Economy	14800.00
0005434639165	12618	Economy	14800.00
0005433202372	12618	Economy	14800.00
0005433202359	12618	Economy	14800.00
0005434638971	12618	Economy	14800.00
0005434639185	12618	Economy	14800.00
0005433202361	12618	Economy	14800.00
0005434639116	12618	Economy	14800.00
0005433202364	12618	Economy	14800.00
0005434639037	12618	Economy	14800.00
0005434639078	12618	Economy	14800.00
0005434639028	12618	Economy	14800.00
0005434639104	12618	Economy	14800.00
0005433202180	23400	Economy	16200.00
0005433202179	23400	Economy	16200.00
0005433202143	23400	Economy	16200.00
0005432290632	23400	Economy	16200.00
0005434639297	23400	Economy	14800.00
0005433202158	23400	Economy	14800.00
0005434639307	23400	Economy	14800.00
0005434639290	23400	Economy	14800.00
0005433202246	23400	Economy	14800.00
0005433202234	23400	Economy	14800.00
0005434639294	23400	Economy	14800.00
0005434639303	23400	Economy	14800.00
0005433202250	23400	Economy	14800.00
0005434639296	23400	Economy	14800.00
0005434639308	23400	Economy	14800.00
0005434639291	23400	Economy	14800.00
0005434639299	23400	Economy	14800.00
0005433202222	23400	Economy	14800.00
0005434639309	23400	Economy	14800.00
0005434639301	23400	Economy	14800.00
0005433202247	23400	Economy	14800.00
0005433202242	23400	Economy	14800.00
0005433202249	23400	Economy	14800.00
0005434639300	23400	Economy	14800.00
0005432290631	23400	Economy	14800.00
0005433202112	23400	Economy	14800.00
0005434639306	23400	Economy	14800.00
0005433202275	23400	Economy	14800.00
0005432290629	23400	Economy	14800.00
0005432290630	23400	Economy	14800.00
0005433202224	23400	Economy	14800.00
0005433202244	23400	Economy	14800.00
0005434639295	23400	Economy	14800.00
0005433202252	23400	Economy	14800.00
0005433202251	23400	Economy	14800.00
0005433202297	23400	Economy	14800.00
0005434639289	23400	Economy	14800.00
0005433202200	23400	Economy	14800.00
0005434639298	23400	Economy	14800.00
0005434639304	23400	Economy	14800.00
0005433202235	23400	Economy	14800.00
0005433202199	23400	Economy	14800.00
0005433202296	23400	Economy	14800.00
0005433202243	23400	Economy	14800.00
0005433202233	23400	Economy	14800.00
0005434639302	23400	Economy	14800.00
0005434639305	23400	Economy	14800.00
0005434639292	23400	Economy	14800.00
0005434639293	23400	Economy	14800.00
0005434639288	23400	Economy	14800.00
0005432328263	21074	Business	18900.00
0005432328369	21074	Business	18900.00
0005432328317	21074	Business	18900.00
0005432328137	21074	Business	18900.00
0005432328313	21074	Business	18900.00
0005432382744	21074	Business	18900.00
0005432382968	21074	Business	18900.00
0005432328259	21074	Business	18900.00
0005432328003	21074	Business	18900.00
0005432328117	21074	Business	18900.00
0005432382828	21074	Business	18900.00
0005432382804	21074	Business	18900.00
0005432328283	21074	Economy	6300.00
0005432382882	21074	Economy	6300.00
0005432382816	21074	Economy	6300.00
0005432382829	21074	Economy	6300.00
0005432382771	21074	Economy	6300.00
0005432382958	21074	Economy	6300.00
0005432328440	21074	Economy	6300.00
0005432382824	21074	Economy	6300.00
0005432382845	21074	Economy	6300.00
0005432382883	21074	Economy	6300.00
0005432054303	21074	Economy	6900.00
0005432382814	21074	Economy	6900.00
0005432328268	21074	Economy	6900.00
0005432382791	21074	Economy	6900.00
0005432328175	21074	Economy	6900.00
0005432328500	21074	Economy	6300.00
0005432328221	21074	Economy	6300.00
0005432328002	21074	Economy	6300.00
0005432328419	21074	Economy	6300.00
0005432328402	21074	Economy	6300.00
0005432382773	21074	Economy	6300.00
0005432382762	21074	Economy	6300.00
0005432328339	21074	Economy	6300.00
0005432382820	21074	Economy	6300.00
0005432327944	21074	Economy	6300.00
0005432328135	21074	Economy	6300.00
0005432328267	21074	Economy	6300.00
0005432382915	21074	Economy	6300.00
0005432328376	21074	Economy	6300.00
0005432328252	21074	Economy	6300.00
0005432382699	21074	Economy	6300.00
0005432382817	21074	Economy	6300.00
0005432328174	21074	Economy	6300.00
0005432382763	21074	Economy	6300.00
0005432382772	21074	Economy	6300.00
0005432328234	21074	Economy	6300.00
0005432328284	21074	Economy	6300.00
0005432328241	21074	Economy	6300.00
0005432382743	21074	Economy	6300.00
0005432382761	21074	Economy	6300.00
0005432382769	21074	Economy	6300.00
0005432328162	21074	Economy	6300.00
0005432382620	21074	Economy	6300.00
0005432382832	21074	Economy	6300.00
0005432328253	21074	Economy	6300.00
0005432382967	21074	Economy	6300.00
0005432382983	21074	Economy	6300.00
0005432382770	21074	Economy	6300.00
0005432328336	21074	Economy	6300.00
0005432328242	21074	Economy	6300.00
0005432328289	21074	Economy	6300.00
0005432382813	21074	Economy	6300.00
0005432328340	21074	Economy	6300.00
0005432328385	21074	Economy	6300.00
0005432382669	21074	Economy	6300.00
0005432328235	21074	Economy	6300.00
0005432328409	21074	Economy	6300.00
0005432054304	21074	Economy	6300.00
0005432328410	21074	Economy	6300.00
0005432328333	21074	Economy	6300.00
0005432382768	21074	Economy	6300.00
0005432328436	21074	Economy	6300.00
0005432328206	21074	Economy	6300.00
0005432328222	21074	Economy	6300.00
0005432327997	21074	Economy	6300.00
0005432382956	21074	Economy	6300.00
0005432328136	21074	Economy	6300.00
0005432328260	21074	Economy	6300.00
0005432328406	21074	Economy	6300.00
0005432382745	21074	Economy	6300.00
0005432382884	21074	Economy	6300.00
0005432382634	21074	Economy	6300.00
0005432382957	21074	Economy	6300.00
0005432328266	21074	Economy	6300.00
0005432328321	21074	Economy	6300.00
0005432382825	21074	Economy	6300.00
0005432382846	21074	Economy	6300.00
0005432382914	21074	Economy	6300.00
0005432328418	21074	Economy	6300.00
0005432328219	21074	Economy	6300.00
0005432382830	21074	Economy	6300.00
0005432054305	21074	Economy	6300.00
0005432328645	31249	Business	18900.00
0005432383153	31249	Business	18900.00
0005432328688	31249	Business	18900.00
0005432328679	31249	Business	18900.00
0005432328654	31249	Business	18900.00
0005432328678	31249	Business	18900.00
0005432383146	31249	Business	18900.00
0005432328682	31249	Business	18900.00
0005432383155	31249	Business	18900.00
0005432383131	31249	Business	18900.00
0005432328672	31249	Business	18900.00
0005432328677	31249	Economy	6300.00
0005432328656	31249	Economy	6300.00
0005432383159	31249	Economy	6300.00
0005432383149	31249	Economy	6300.00
0005432383148	31249	Economy	6300.00
0005432383134	31249	Economy	6300.00
0005432383160	31249	Economy	6300.00
0005432328667	31249	Economy	6300.00
0005432328662	31249	Economy	6300.00
0005432328643	31249	Economy	6900.00
0005432383133	31249	Economy	6900.00
0005432328648	31249	Economy	6900.00
0005432383143	31249	Economy	6900.00
0005432383141	31249	Economy	6900.00
0005432328653	31249	Economy	6300.00
0005432328646	31249	Economy	6300.00
0005432328659	31249	Economy	6300.00
0005432328668	31249	Economy	6300.00
0005432383150	31249	Economy	6300.00
0005432328647	31249	Economy	6300.00
0005432328650	31249	Economy	6300.00
0005432383154	31249	Economy	6300.00
0005432328657	31249	Economy	6300.00
0005432383166	31249	Economy	6300.00
0005432383162	31249	Economy	6300.00
0005432383129	31249	Economy	6300.00
0005432383138	31249	Economy	6300.00
0005432328660	31249	Economy	6300.00
0005432328649	31249	Economy	6300.00
0005432287185	31249	Economy	6300.00
0005432328655	31249	Economy	6300.00
0005432328665	31249	Economy	6300.00
0005432287186	31249	Economy	6300.00
0005432383130	31249	Economy	6300.00
0005432328673	31249	Economy	6300.00
0005432328669	31249	Economy	6300.00
0005432383144	31249	Economy	6300.00
0005432328642	31249	Economy	6300.00
0005432383158	31249	Economy	6300.00
0005432383164	31249	Economy	6300.00
0005432383140	31249	Economy	6300.00
0005432328676	31249	Economy	6300.00
0005432287184	31249	Economy	6300.00
0005432328652	31249	Economy	6300.00
0005432328675	31249	Economy	6300.00
0005432383161	31249	Economy	6300.00
0005432287187	31249	Economy	6300.00
0005432383152	31249	Economy	6300.00
0005432328663	31249	Economy	6300.00
0005432328651	31249	Economy	6300.00
0005432383157	31249	Economy	6300.00
0005432383156	31249	Economy	6300.00
0005432383147	31249	Economy	6300.00
0005432328681	31249	Economy	6300.00
0005432383163	31249	Economy	6300.00
0005432328684	31249	Economy	6300.00
0005432328686	31249	Economy	6300.00
0005432328687	31249	Economy	6300.00
0005432383151	31249	Economy	6300.00
0005432328644	31249	Economy	6300.00
0005432328661	31249	Economy	6300.00
0005432328666	31249	Economy	6300.00
0005432328685	31249	Economy	6300.00
0005432328658	31249	Economy	6300.00
0005432383132	31249	Economy	6300.00
0005432383137	31249	Economy	6300.00
0005432328670	31249	Economy	6300.00
0005432328680	31249	Economy	6300.00
0005432328683	31249	Economy	6300.00
0005432383142	31249	Economy	6300.00
0005432383135	31249	Economy	6300.00
0005432383139	31249	Economy	6300.00
0005432383165	31249	Economy	6300.00
0005432328671	31249	Economy	6300.00
0005432383145	31249	Economy	6300.00
0005432328674	31249	Economy	6300.00
0005432328664	31249	Economy	6300.00
0005432383136	31249	Economy	6300.00
0005432424417	13280	Business	12700.00
0005432424387	13280	Business	12700.00
0005432424402	13280	Business	12700.00
0005432424401	13280	Business	12700.00
0005432424415	13280	Business	12700.00
0005432424378	13280	Business	12700.00
0005432424406	13280	Business	12700.00
0005432424393	13280	Economy	4200.00
0005432424390	13280	Economy	4200.00
0005432424399	13280	Economy	4200.00
0005432424395	13280	Economy	4200.00
0005432424384	13280	Economy	4200.00
0005432424414	13280	Economy	4200.00
0005432424377	13280	Economy	4700.00
0005432424382	13280	Economy	4700.00
0005432424420	13280	Economy	4700.00
0005432424391	13280	Economy	4200.00
0005432424413	13280	Economy	4200.00
0005432424394	13280	Economy	4200.00
0005432424409	13280	Economy	4200.00
0005432424397	13280	Economy	4200.00
0005432424421	13280	Economy	4200.00
0005432424398	13280	Economy	4200.00
0005432424403	13280	Economy	4200.00
0005432424416	13280	Economy	4200.00
0005432424400	13280	Economy	4200.00
0005432424411	13280	Economy	4200.00
0005432424389	13280	Economy	4200.00
0005432424392	13280	Economy	4200.00
0005432424412	13280	Economy	4200.00
0005432424419	13280	Economy	4200.00
0005432424418	13280	Economy	4200.00
0005432424396	13280	Economy	4200.00
0005432424386	13280	Economy	4200.00
0005432424407	13280	Economy	4200.00
0005432424381	13280	Economy	4200.00
0005432424408	13280	Economy	4200.00
0005432424410	13280	Economy	4200.00
0005432424404	13280	Economy	4200.00
0005432424383	13280	Economy	4200.00
0005432424385	13280	Economy	4200.00
0005432424388	13280	Economy	4200.00
0005432424405	13280	Economy	4200.00
0005432424376	13280	Economy	4200.00
0005432424380	13280	Economy	4200.00
0005432424379	13280	Economy	4200.00
0005432423943	30723	Business	12700.00
0005432423938	30723	Business	12700.00
0005432423964	30723	Business	12700.00
0005432423962	30723	Business	12700.00
0005432424025	30723	Economy	4200.00
0005432424054	30723	Economy	4200.00
0005432424040	30723	Economy	4200.00
0005432423968	30723	Economy	4700.00
0005432424005	30723	Economy	4700.00
0005432423901	30723	Economy	4200.00
0005432424011	30723	Economy	4200.00
0005432423977	30723	Economy	4200.00
0005432423981	30723	Economy	4200.00
0005432424039	30723	Economy	4200.00
0005432423958	30723	Economy	4200.00
0005432423909	30723	Economy	4200.00
0005432423900	30723	Economy	4200.00
0005432424006	30723	Economy	4200.00
0005432423902	30723	Economy	4200.00
0005432423994	30723	Economy	4200.00
0005432424022	30723	Economy	4200.00
0005432424026	30723	Economy	4200.00
0005432423978	30723	Economy	4200.00
0005432423957	30723	Economy	4200.00
0005432424031	30723	Economy	4200.00
0005432424047	30723	Economy	4200.00
0005432423983	30723	Economy	4200.00
0005432424008	30723	Economy	4200.00
0005432424046	30723	Economy	4200.00
0005432423963	30723	Economy	4200.00
0005432423955	30723	Economy	4200.00
0005432424055	30723	Economy	4200.00
0005432424013	30723	Economy	4200.00
0005432424053	30723	Economy	4200.00
0005432423903	30723	Economy	4200.00
0005432423982	30723	Economy	4200.00
0005432424030	30723	Economy	4200.00
0005432423896	30723	Economy	4200.00
0005432424019	30723	Economy	4200.00
0005432901471	9605	Business	32600.00
0005434448316	9605	Business	32600.00
0005432901535	9605	Business	32600.00
0005432817456	9605	Business	32600.00
0005432822205	9605	Business	32600.00
0005432901536	9605	Business	32600.00
0005432901456	9605	Business	32600.00
0005432901398	9605	Business	32600.00
0005432901537	9605	Business	32600.00
0005432817457	9605	Economy	10900.00
0005432822199	9605	Economy	10900.00
0005434157436	9605	Economy	10900.00
0005434157405	9605	Economy	10900.00
0005432817454	9605	Economy	10900.00
0005434448315	9605	Economy	10900.00
0005432901397	9605	Economy	10900.00
0005434157425	9605	Economy	10900.00
0005432817472	9605	Economy	10900.00
0005432901457	9605	Economy	10900.00
0005434157427	9605	Economy	11900.00
0005432817480	9605	Economy	11900.00
0005432817462	9605	Economy	11900.00
0005432901530	9605	Economy	11900.00
0005434157426	9605	Economy	11900.00
0005432822200	9605	Economy	10900.00
0005432817467	9605	Economy	10900.00
0005432817481	9605	Economy	10900.00
0005432901441	9605	Economy	10900.00
0005432817459	9605	Economy	10900.00
0005432817460	9605	Economy	10900.00
0005434157400	9605	Economy	10900.00
0005432817473	9605	Economy	10900.00
0005432901433	9605	Economy	10900.00
0005432901531	9605	Economy	10900.00
0005432817475	9605	Economy	10900.00
0005432817464	9605	Economy	10900.00
0005434157410	9605	Economy	10900.00
0005432901440	9605	Economy	10900.00
0005434448314	9605	Economy	10900.00
0005434157370	9605	Economy	10900.00
0005432901420	9605	Economy	10900.00
0005432901473	9605	Economy	10900.00
0005432901393	9605	Economy	10900.00
0005432901472	9605	Economy	10900.00
0005432817476	9605	Economy	10900.00
0005432288984	9605	Economy	10900.00
0005432822201	9605	Economy	10900.00
0005432817468	9605	Economy	10900.00
0005432817469	9605	Economy	10900.00
0005432901492	9605	Economy	10900.00
0005432901434	9605	Economy	10900.00
0005432288987	9605	Economy	10900.00
0005432817474	9605	Economy	10900.00
0005434157413	9605	Economy	10900.00
0005434157424	9605	Economy	10900.00
0005432288985	9605	Economy	10900.00
0005434157411	9605	Economy	10900.00
0005432817463	9605	Economy	10900.00
0005432817470	9605	Economy	10900.00
0005434157443	9605	Economy	10900.00
0005432817465	9605	Economy	10900.00
0005434157404	9605	Economy	10900.00
0005432817478	9605	Economy	10900.00
0005432288986	9605	Economy	10900.00
0005432822202	9605	Economy	10900.00
0005432817466	9605	Economy	10900.00
0005434157369	9605	Economy	10900.00
0005432817461	9605	Economy	10900.00
0005432817455	9605	Economy	10900.00
0005432817483	9605	Economy	10900.00
0005432817471	9605	Economy	10900.00
0005432822206	9605	Economy	10900.00
0005432901409	9605	Economy	10900.00
0005432817477	9605	Economy	10900.00
0005432822203	9605	Economy	10900.00
0005432817458	9605	Economy	10900.00
0005432822204	9605	Economy	10900.00
0005432817479	9605	Economy	10900.00
0005432817482	9605	Economy	10900.00
0005432901615	29005	Business	32600.00
0005432817259	29005	Business	32600.00
0005432817272	29005	Business	32600.00
0005434157482	29005	Business	32600.00
0005432901613	29005	Business	32600.00
0005432901608	29005	Economy	10900.00
0005432901602	29005	Economy	10900.00
0005432817233	29005	Economy	10900.00
0005434157477	29005	Economy	10900.00
0005432901612	29005	Economy	10900.00
0005432817166	29005	Economy	10900.00
0005432817262	29005	Economy	10900.00
0005432817179	29005	Economy	10900.00
0005432901611	29005	Economy	11900.00
0005434157479	29005	Economy	11900.00
0005432817216	29005	Economy	11900.00
0005434448270	29005	Economy	10900.00
0005432817326	29005	Economy	10900.00
0005432901601	29005	Economy	10900.00
0005432817158	29005	Economy	10900.00
0005432901606	29005	Economy	10900.00
0005432901616	29005	Economy	10900.00
0005432901614	29005	Economy	10900.00
0005432817053	29005	Economy	10900.00
0005432822141	29005	Economy	10900.00
0005432817249	29005	Economy	10900.00
0005432817095	29005	Economy	10900.00
0005434186196	29005	Economy	10900.00
0005432817255	29005	Economy	10900.00
0005432817298	29005	Economy	10900.00
0005434157483	29005	Economy	10900.00
0005432901605	29005	Economy	10900.00
0005432822131	29005	Economy	10900.00
0005432002076	29005	Economy	10900.00
0005432817094	29005	Economy	10900.00
0005432822150	29005	Economy	10900.00
0005432002077	29005	Economy	10900.00
0005434186197	29005	Economy	10900.00
0005432817054	29005	Economy	10900.00
0005432901610	29005	Economy	10900.00
0005432817348	29005	Economy	10900.00
0005432817271	29005	Economy	10900.00
0005434157476	29005	Economy	10900.00
0005432901604	29005	Economy	10900.00
0005432901609	29005	Economy	10900.00
0005432817347	29005	Economy	10900.00
0005432817099	29005	Economy	10900.00
0005432817159	29005	Economy	10900.00
0005434157475	29005	Economy	10900.00
0005434157480	29005	Economy	10900.00
0005432901603	29005	Economy	10900.00
0005434448277	29005	Economy	10900.00
0005432901599	29005	Economy	10900.00
0005434157478	29005	Economy	10900.00
0005432817160	29005	Economy	10900.00
0005432002075	29005	Economy	10900.00
0005432817346	29005	Economy	10900.00
0005432002078	29005	Economy	10900.00
0005432901600	29005	Economy	10900.00
0005432901607	29005	Economy	10900.00
0005434157481	29005	Economy	10900.00
0005432817232	29005	Economy	10900.00
0005432817199	29005	Economy	10900.00
0005432817098	29005	Economy	10900.00
0005435841089	15063	Economy	11000.00
0005432613862	15063	Economy	11000.00
0005435841091	15063	Economy	11000.00
0005432611711	15063	Economy	11000.00
0005432611710	15063	Economy	11000.00
0005432613860	15063	Economy	11000.00
0005432611712	15063	Economy	11000.00
0005432613863	15063	Economy	11000.00
0005432613861	15063	Economy	11000.00
0005432613864	15063	Economy	11000.00
0005432611689	31605	Economy	11000.00
0005432607519	31605	Economy	11000.00
0005432611695	31605	Economy	11000.00
0005432611663	31605	Economy	11000.00
0005432607542	31605	Economy	11000.00
0005432607541	31605	Economy	11000.00
0005432607512	31605	Economy	11000.00
0005432607531	31605	Economy	11000.00
0005432611656	31605	Economy	11000.00
0005432607530	31605	Economy	11000.00
0005432611682	31605	Economy	11000.00
0005435841821	31605	Economy	11000.00
0005433569039	11848	Business	105900.00
0005432947975	11848	Business	105900.00
0005432947976	11848	Business	105900.00
0005433569036	11848	Business	105900.00
0005432948195	11848	Business	105900.00
0005432948112	11848	Business	105900.00
0005432948114	11848	Business	105900.00
0005432947834	11848	Business	105900.00
0005432948074	11848	Business	105900.00
0005432947909	11848	Business	105900.00
0005432948184	11848	Business	105900.00
0005432947835	11848	Business	105900.00
0005433569003	11848	Business	105900.00
0005432948002	11848	Business	105900.00
0005432948185	11848	Business	105900.00
0005433569007	11848	Business	105900.00
0005433569048	11848	Business	105900.00
0005432947841	11848	Business	105900.00
0005432948037	11848	Economy	35300.00
0005432947836	11848	Economy	35300.00
0005433569035	11848	Economy	35300.00
0005432948036	11848	Economy	35300.00
0005432948041	11848	Economy	35300.00
0005433569011	11848	Economy	35300.00
0005432948038	11848	Economy	35300.00
0005433569020	11848	Economy	35300.00
0005432948138	11848	Economy	38800.00
0005433569018	11848	Economy	38800.00
0005432948075	11848	Economy	38800.00
0005433569047	11848	Economy	38800.00
0005433569013	11848	Economy	35300.00
0005433569019	11848	Economy	35300.00
0005433569008	11848	Economy	35300.00
0005433569006	11848	Economy	35300.00
0005433569025	11848	Economy	35300.00
0005432948077	11848	Economy	35300.00
0005433569042	11848	Economy	35300.00
0005433568997	11848	Economy	35300.00
0005433569044	11848	Economy	35300.00
0005433569009	11848	Economy	35300.00
0005433569029	11848	Economy	35300.00
0005432948134	11848	Economy	35300.00
0005433568998	11848	Economy	35300.00
0005433569001	11848	Economy	35300.00
0005432947993	11848	Economy	35300.00
0005432948051	11848	Economy	35300.00
0005433569034	11848	Economy	35300.00
0005432948048	11848	Economy	35300.00
0005433569023	11848	Economy	35300.00
0005433569014	11848	Economy	35300.00
0005432947912	11848	Economy	35300.00
0005433569022	11848	Economy	35300.00
0005432948113	11848	Economy	35300.00
0005433569024	11848	Economy	35300.00
0005433568994	11848	Economy	35300.00
0005432948058	11848	Economy	35300.00
0005433569021	11848	Economy	35300.00
0005432948047	11848	Economy	35300.00
0005432948097	11848	Economy	35300.00
0005432947873	11848	Economy	35300.00
0005433569041	11848	Economy	35300.00
0005433569038	11848	Economy	35300.00
0005432948101	11848	Economy	35300.00
0005432947874	11848	Economy	35300.00
0005432948139	11848	Economy	35300.00
0005433569037	11848	Economy	35300.00
0005432948078	11848	Economy	35300.00
0005433569010	11848	Economy	35300.00
0005433569016	11848	Economy	35300.00
0005433569015	11848	Economy	35300.00
0005433569012	11848	Economy	35300.00
0005432948141	11848	Economy	35300.00
0005433568996	11848	Economy	35300.00
0005433569017	11848	Economy	35300.00
0005432947992	11848	Economy	35300.00
0005432947994	11848	Economy	35300.00
0005433569000	11848	Economy	35300.00
0005433569027	11848	Economy	35300.00
0005432947946	11848	Economy	35300.00
0005433569033	11848	Economy	35300.00
0005433569005	11848	Economy	35300.00
0005433568995	11848	Economy	35300.00
0005432948034	11848	Economy	35300.00
0005433569026	11848	Economy	35300.00
0005433568999	11848	Economy	35300.00
0005433569030	11848	Economy	35300.00
0005433569004	11848	Economy	35300.00
0005433569045	11848	Economy	35300.00
0005433569002	11848	Economy	35300.00
0005433569046	11848	Economy	35300.00
0005432948063	11848	Economy	35300.00
0005433569031	11848	Economy	35300.00
0005433569040	11848	Economy	35300.00
0005433569028	11848	Economy	35300.00
0005432948198	11848	Economy	35300.00
0005433569032	11848	Economy	35300.00
0005433569043	11848	Economy	35300.00
0005432948140	11848	Economy	35300.00
0005432948135	11848	Economy	35300.00
0005433568382	25318	Business	105900.00
0005433568363	25318	Business	105900.00
0005433568557	25318	Business	105900.00
0005433568254	25318	Business	105900.00
0005433568502	25318	Business	105900.00
0005433568545	25318	Business	105900.00
0005432948507	25318	Business	105900.00
0005433568190	25318	Business	105900.00
0005432948490	25318	Business	105900.00
0005433568453	25318	Business	105900.00
0005432948472	25318	Business	105900.00
0005432948480	25318	Business	105900.00
0005432948477	25318	Business	105900.00
0005432948478	25318	Business	105900.00
0005433568322	25318	Business	105900.00
0005433568258	25318	Business	105900.00
0005432948505	25318	Business	105900.00
0005433568617	25318	Business	105900.00
0005433568219	25318	Business	105900.00
0005433568465	25318	Economy	35300.00
0005432948473	25318	Economy	35300.00
0005433568519	25318	Economy	35300.00
0005432948508	25318	Economy	35300.00
0005432948511	25318	Economy	35300.00
0005433568498	25318	Economy	35300.00
0005433568670	25318	Economy	35300.00
0005432948488	25318	Economy	35300.00
0005433568242	25318	Economy	35300.00
0005433568503	25318	Economy	35300.00
0005433568493	25318	Economy	35300.00
0005433568536	25318	Economy	35300.00
0005433568539	25318	Economy	35300.00
0005433568227	25318	Economy	38800.00
0005433568531	25318	Economy	38800.00
0005433568559	25318	Economy	38800.00
0005432948510	25318	Economy	35300.00
0005433568558	25318	Economy	35300.00
0005432948503	25318	Economy	35300.00
0005432948494	25318	Economy	35300.00
0005432948481	25318	Economy	35300.00
0005432948502	25318	Economy	35300.00
0005433568490	25318	Economy	35300.00
0005433568087	25318	Economy	35300.00
0005433568438	25318	Economy	35300.00
0005432948475	25318	Economy	35300.00
0005433568383	25318	Economy	35300.00
0005433568302	25318	Economy	35300.00
0005433568268	25318	Economy	35300.00
0005433568530	25318	Economy	35300.00
0005432948495	25318	Economy	35300.00
0005433568518	25318	Economy	35300.00
0005432948487	25318	Economy	35300.00
0005432948497	25318	Economy	35300.00
0005432948501	25318	Economy	35300.00
0005433568467	25318	Economy	35300.00
0005432948491	25318	Economy	35300.00
0005432948499	25318	Economy	35300.00
0005432948498	25318	Economy	35300.00
0005432948476	25318	Economy	35300.00
0005432948512	25318	Economy	35300.00
0005432948500	25318	Economy	35300.00
0005433568537	25318	Economy	35300.00
0005432948492	25318	Economy	35300.00
0005433568488	25318	Economy	35300.00
0005433568532	25318	Economy	35300.00
0005432948493	25318	Economy	35300.00
0005433568466	25318	Economy	35300.00
0005433568604	25318	Economy	35300.00
0005433568325	25318	Economy	35300.00
0005432948486	25318	Economy	35300.00
0005433568257	25318	Economy	35300.00
0005432948474	25318	Economy	35300.00
0005433568603	25318	Economy	35300.00
0005432948482	25318	Economy	35300.00
0005432948504	25318	Economy	35300.00
0005433568432	25318	Economy	35300.00
0005433568550	25318	Economy	35300.00
0005433568495	25318	Economy	35300.00
0005432948509	25318	Economy	35300.00
0005433568425	25318	Economy	35300.00
0005432948484	25318	Economy	35300.00
0005433568492	25318	Economy	35300.00
0005432948485	25318	Economy	35300.00
0005433568451	25318	Economy	35300.00
0005432948506	25318	Economy	35300.00
0005433568494	25318	Economy	35300.00
0005432948479	25318	Economy	35300.00
0005433568191	25318	Economy	35300.00
0005432948513	25318	Economy	35300.00
0005433568151	25318	Economy	35300.00
0005433568414	25318	Economy	35300.00
0005433568546	25318	Economy	35300.00
0005433568228	25318	Economy	35300.00
0005433568346	25318	Economy	35300.00
0005433568415	25318	Economy	35300.00
0005432948483	25318	Economy	35300.00
0005433568452	25318	Economy	35300.00
0005433568347	25318	Economy	35300.00
0005432948496	25318	Economy	35300.00
0005432948489	25318	Economy	35300.00
0005433568666	25318	Economy	35300.00
0005433568520	25318	Economy	35300.00
0005433568454	25318	Economy	35300.00
0005433808372	30833	Business	117400.00
0005433808367	30833	Business	117400.00
0005433808374	30833	Business	117400.00
0005433808366	30833	Business	117400.00
0005433812898	30833	Business	117400.00
0005432430808	30833	Business	117400.00
0005433808364	30833	Business	117400.00
0005432430830	30833	Economy	39100.00
0005432430820	30833	Economy	39100.00
0005432430819	30833	Economy	39100.00
0005434026672	30833	Economy	43000.00
0005433812897	30833	Economy	39100.00
0005433808376	30833	Economy	39100.00
0005434026682	30833	Economy	39100.00
0005433808370	30833	Economy	39100.00
0005432430809	30833	Economy	39100.00
0005433812893	30833	Economy	39100.00
0005433812892	30833	Economy	39100.00
0005434026681	30833	Economy	39100.00
0005433808375	30833	Economy	39100.00
0005432430833	30833	Economy	39100.00
0005433808371	30833	Economy	39100.00
0005432430821	30833	Economy	39100.00
0005434026673	30833	Economy	39100.00
0005433812895	30833	Economy	39100.00
0005433808365	30833	Economy	39100.00
0005433812894	30833	Economy	39100.00
0005433812896	30833	Economy	39100.00
0005433808369	30833	Economy	39100.00
0005433808373	30833	Economy	39100.00
0005434026684	30833	Economy	39100.00
0005433808368	30833	Economy	39100.00
0005433808378	30833	Economy	39100.00
0005433808377	30833	Economy	39100.00
0005432430826	30833	Economy	39100.00
0005435340168	5411	Business	67200.00
0005435340097	5411	Business	67200.00
0005434654696	5411	Business	67200.00
0005435340186	5411	Business	67200.00
0005434654683	5411	Business	67200.00
0005434654670	5411	Business	67200.00
0005435555352	5411	Economy	22400.00
0005434654680	5411	Economy	22400.00
0005434656556	5411	Economy	22400.00
0005434654695	5411	Economy	22400.00
0005434654682	5411	Economy	22400.00
0005434654677	5411	Economy	24600.00
0005435340115	5411	Economy	24600.00
0005434654681	5411	Economy	22400.00
0005434654684	5411	Economy	22400.00
0005434654676	5411	Economy	22400.00
0005434654689	5411	Economy	22400.00
0005434654673	5411	Economy	22400.00
0005434654694	5411	Economy	22400.00
0005435340160	5411	Economy	22400.00
0005434654679	5411	Economy	22400.00
0005434654671	5411	Economy	22400.00
0005434654686	5411	Economy	22400.00
0005432114205	5411	Economy	22400.00
0005435555353	5411	Economy	22400.00
0005432114203	5411	Economy	22400.00
0005435340116	5411	Economy	22400.00
0005434654697	5411	Economy	22400.00
0005435340213	5411	Economy	22400.00
0005434654687	5411	Economy	22400.00
0005435340078	5411	Economy	22400.00
0005435340092	5411	Economy	22400.00
0005435340117	5411	Economy	22400.00
0005434654688	5411	Economy	22400.00
0005434654672	5411	Economy	22400.00
0005434654690	5411	Economy	22400.00
0005434654674	5411	Economy	22400.00
0005432114204	5411	Economy	22400.00
0005432114201	5411	Economy	22400.00
0005434656557	5411	Economy	22400.00
0005432114202	5411	Economy	22400.00
0005434654685	5411	Economy	22400.00
0005434654693	5411	Economy	22400.00
0005434654678	5411	Economy	22400.00
0005434656555	5411	Economy	22400.00
0005435340046	5411	Economy	22400.00
0005434654691	5411	Economy	22400.00
0005434654668	5411	Economy	22400.00
0005434654669	5411	Economy	22400.00
0005435340098	5411	Economy	22400.00
0005435555351	5411	Economy	22400.00
0005434654675	5411	Economy	22400.00
0005434654692	5411	Economy	22400.00
0005435340266	12529	Business	67200.00
0005434654347	12529	Business	67200.00
0005434654489	12529	Business	67200.00
0005434654517	12529	Business	67200.00
0005434654531	12529	Economy	22400.00
0005434654464	12529	Economy	22400.00
0005434654523	12529	Economy	22400.00
0005434656544	12529	Economy	22400.00
0005435340260	12529	Economy	22400.00
0005434654396	12529	Economy	22400.00
0005434654283	12529	Economy	22400.00
0005434654343	12529	Economy	24600.00
0005435340258	12529	Economy	24600.00
0005435340262	12529	Economy	24600.00
0005434656533	12529	Economy	24600.00
0005435340269	12529	Economy	22400.00
0005434654407	12529	Economy	22400.00
0005434654271	12529	Economy	22400.00
0005434656532	12529	Economy	22400.00
0005434654409	12529	Economy	22400.00
0005435340265	12529	Economy	22400.00
0005434654462	12529	Economy	22400.00
0005434654461	12529	Economy	22400.00
0005435555370	12529	Economy	22400.00
0005434654313	12529	Economy	22400.00
0005434654359	12529	Economy	22400.00
0005434654422	12529	Economy	22400.00
0005434654342	12529	Economy	22400.00
0005434654465	12529	Economy	22400.00
0005435340261	12529	Economy	22400.00
0005435340257	12529	Economy	22400.00
0005435340267	12529	Economy	22400.00
0005435340254	12529	Economy	22400.00
0005434654477	12529	Economy	22400.00
0005434654382	12529	Economy	22400.00
0005435340263	12529	Economy	22400.00
0005435340259	12529	Economy	22400.00
0005435340268	12529	Economy	22400.00
0005434654255	12529	Economy	22400.00
0005434654484	12529	Economy	22400.00
0005435555371	12529	Economy	22400.00
0005434654468	12529	Economy	22400.00
0005434654431	12529	Economy	22400.00
0005435340264	12529	Economy	22400.00
0005434654483	12529	Economy	22400.00
0005434654478	12529	Economy	22400.00
0005435340255	12529	Economy	22400.00
0005434654270	12529	Economy	22400.00
0005434654377	12529	Economy	22400.00
0005435340256	12529	Economy	22400.00
0005433715950	7439	Business	32000.00
0005433715943	7439	Business	32000.00
0005433715968	7439	Business	32000.00
0005433715944	7439	Business	32000.00
0005433719137	7439	Business	32000.00
0005433715948	7439	Business	32000.00
0005433715947	7439	Business	32000.00
0005435266099	7439	Business	32000.00
0005435266104	7439	Business	32000.00
0005433690926	7439	Economy	10700.00
0005433715977	7439	Economy	10700.00
0005433715954	7439	Economy	10700.00
0005433719139	7439	Economy	10700.00
0005433722218	7439	Economy	10700.00
0005433715957	7439	Economy	10700.00
0005432078106	7439	Economy	10700.00
0005433715975	7439	Economy	10700.00
0005433715942	7439	Economy	10700.00
0005433715949	7439	Economy	10700.00
0005433719136	7439	Economy	10700.00
0005433722217	7439	Economy	10700.00
0005433715965	7439	Economy	10700.00
0005433715972	7439	Economy	10700.00
0005433715958	7439	Economy	10700.00
0005433715941	7439	Economy	10700.00
0005435266101	7439	Economy	10700.00
0005435266090	7439	Economy	10700.00
0005433722219	7439	Economy	10700.00
0005433715974	7439	Economy	10700.00
0005433715945	7439	Economy	10700.00
0005433715952	7439	Economy	10700.00
0005433715971	7439	Economy	10700.00
0005433722220	7439	Economy	10700.00
0005433715955	7439	Economy	10700.00
0005433715986	7439	Economy	10700.00
0005433715985	7439	Economy	10700.00
0005433715982	7439	Economy	11700.00
0005433689909	7439	Economy	11700.00
0005433715939	7439	Economy	11700.00
0005432428894	7439	Economy	11700.00
0005433715979	7439	Economy	11700.00
0005433715961	7439	Economy	10700.00
0005433715969	7439	Economy	10700.00
0005433715981	7439	Economy	10700.00
0005433715936	7439	Economy	10700.00
0005435266092	7439	Economy	10700.00
0005432428903	7439	Economy	10700.00
0005433715962	7439	Economy	10700.00
0005432078107	7439	Economy	10700.00
0005433719138	7439	Economy	10700.00
0005433715976	7439	Economy	10700.00
0005432078109	7439	Economy	10700.00
0005433715940	7439	Economy	10700.00
0005435266100	7439	Economy	10700.00
0005433715967	7439	Economy	10700.00
0005435266095	7439	Economy	10700.00
0005433715978	7439	Economy	10700.00
0005433715980	7439	Economy	10700.00
0005433715984	7439	Economy	10700.00
0005433656668	7439	Economy	10700.00
0005432078108	7439	Economy	10700.00
0005433690925	7439	Economy	10700.00
0005435266103	7439	Economy	10700.00
0005433715946	7439	Economy	10700.00
0005433715951	7439	Economy	10700.00
0005433656669	7439	Economy	10700.00
0005433689908	7439	Economy	10700.00
0005433715938	7439	Economy	10700.00
0005433689910	7439	Economy	10700.00
0005433715983	7439	Economy	10700.00
0005433715964	7439	Economy	10700.00
0005433722224	7439	Economy	10700.00
0005433715937	7439	Economy	10700.00
0005433715973	7439	Economy	10700.00
0005433656667	7439	Economy	10700.00
0005433715956	7439	Economy	10700.00
0005433715960	7439	Economy	10700.00
0005433715959	7439	Economy	10700.00
0005433722222	7439	Economy	10700.00
0005433722223	7439	Economy	10700.00
0005433688809	7439	Economy	10700.00
0005433715963	7439	Economy	10700.00
0005435266091	7439	Economy	10700.00
0005433688808	7439	Economy	10700.00
0005433715953	7439	Economy	10700.00
0005433715966	7439	Economy	10700.00
0005433715970	7439	Economy	10700.00
0005433722221	7439	Economy	10700.00
0005433722136	29220	Business	32000.00
0005433715588	29220	Business	32000.00
0005433715477	29220	Business	32000.00
0005433715566	29220	Business	32000.00
0005432428929	29220	Business	32000.00
0005433715326	29220	Business	32000.00
0005433685504	29220	Business	32000.00
0005433715590	29220	Business	32000.00
0005433715698	29220	Economy	10700.00
0005433715365	29220	Economy	10700.00
0005433715452	29220	Economy	10700.00
0005433715556	29220	Economy	10700.00
0005433715493	29220	Economy	10700.00
0005433656620	29220	Economy	10700.00
0005433722153	29220	Economy	10700.00
0005433715485	29220	Economy	10700.00
0005433715453	29220	Economy	10700.00
0005433715398	29220	Economy	10700.00
0005433715518	29220	Economy	10700.00
0005433715600	29220	Economy	10700.00
0005432006762	29220	Economy	10700.00
0005433715550	29220	Economy	10700.00
0005433715551	29220	Economy	10700.00
0005433715603	29220	Economy	10700.00
0005433715624	29220	Economy	10700.00
0005433715524	29220	Economy	10700.00
0005433715657	29220	Economy	10700.00
0005433715534	29220	Economy	10700.00
0005433656638	29220	Economy	10700.00
0005433715564	29220	Economy	10700.00
0005433715592	29220	Economy	10700.00
0005433715517	29220	Economy	10700.00
0005433715567	29220	Economy	10700.00
0005435266147	29220	Economy	10700.00
0005433722149	29220	Economy	11700.00
0005433715598	29220	Economy	11700.00
0005433715220	29220	Economy	11700.00
0005433715674	29220	Economy	10700.00
0005432006760	29220	Economy	10700.00
0005433715601	29220	Economy	10700.00
0005433715593	29220	Economy	10700.00
0005432006763	29220	Economy	10700.00
0005433715529	29220	Economy	10700.00
0005433715677	29220	Economy	10700.00
0005433715427	29220	Economy	10700.00
0005433715656	29220	Economy	10700.00
0005433715479	29220	Economy	10700.00
0005433715604	29220	Economy	10700.00
0005433715425	29220	Economy	10700.00
0005433722150	29220	Economy	10700.00
0005433719124	29220	Economy	10700.00
0005433715305	29220	Economy	10700.00
0005432428928	29220	Economy	10700.00
0005433715661	29220	Economy	10700.00
0005433715771	29220	Economy	10700.00
0005433722137	29220	Economy	10700.00
0005433715304	29220	Economy	10700.00
0005435266148	29220	Economy	10700.00
0005432428927	29220	Economy	10700.00
0005433715446	29220	Economy	10700.00
0005433685503	29220	Economy	10700.00
0005433715393	29220	Economy	10700.00
0005433715678	29220	Economy	10700.00
0005433715699	29220	Economy	10700.00
0005433715392	29220	Economy	10700.00
0005433715486	29220	Economy	10700.00
0005433715655	29220	Economy	10700.00
0005432006761	29220	Economy	10700.00
0005433715478	29220	Economy	10700.00
0005433656642	29220	Economy	10700.00
0005433715559	29220	Economy	10700.00
0005433715632	29220	Economy	10700.00
0005433715589	29220	Economy	10700.00
0005433722152	29220	Economy	10700.00
0005433722123	29220	Economy	10700.00
0005433715704	29220	Economy	10700.00
0005433715539	29220	Economy	10700.00
0005433715602	29220	Economy	10700.00
0005432006759	29220	Economy	10700.00
0005433715535	29220	Economy	10700.00
0005433719115	29220	Economy	10700.00
0005433656633	29220	Economy	10700.00
0005433715428	29220	Economy	10700.00
0005434095273	8692	Business	36500.00
0005434184647	8692	Business	36500.00
0005434184648	8692	Business	36500.00
0005434095280	8692	Economy	12200.00
0005434182109	8692	Economy	12200.00
0005434095279	8692	Economy	12200.00
0005434095270	8692	Economy	12200.00
0005434095268	8692	Economy	13400.00
0005434182083	8692	Economy	12200.00
0005434182046	8692	Economy	12200.00
0005434182047	8692	Economy	12200.00
0005434095275	8692	Economy	12200.00
0005434182140	8692	Economy	12200.00
0005434182062	8692	Economy	12200.00
0005434095274	8692	Economy	12200.00
0005434095276	8692	Economy	12200.00
0005434095269	8692	Economy	12200.00
0005434182064	8692	Economy	12200.00
0005434095272	8692	Economy	12200.00
0005434182086	8692	Economy	12200.00
0005434182063	8692	Economy	12200.00
0005434095267	8692	Economy	12200.00
0005434182082	8692	Economy	12200.00
0005434095278	8692	Economy	12200.00
0005434182117	8692	Economy	12200.00
0005434182041	8692	Economy	12200.00
0005434095277	8692	Economy	12200.00
0005434095266	8692	Economy	12200.00
0005434182110	8692	Economy	12200.00
0005434095271	8692	Economy	12200.00
0005434184662	11623	Business	36500.00
0005434095157	11623	Business	36500.00
0005434095181	11623	Business	36500.00
0005434182184	11623	Business	36500.00
0005434095183	11623	Economy	12200.00
0005434182182	11623	Economy	12200.00
0005434182186	11623	Economy	12200.00
0005434095137	11623	Economy	12200.00
0005434095133	11623	Economy	12200.00
0005434095166	11623	Economy	13400.00
0005434095138	11623	Economy	13400.00
0005434182187	11623	Economy	13400.00
0005434182188	11623	Economy	12200.00
0005434182179	11623	Economy	12200.00
0005434143715	11623	Economy	12200.00
0005434182185	11623	Economy	12200.00
0005434095119	11623	Economy	12200.00
0005434095165	11623	Economy	12200.00
0005434095117	11623	Economy	12200.00
0005434326085	11623	Economy	12200.00
0005434182178	11623	Economy	12200.00
0005434183577	11623	Economy	12200.00
0005434095109	11623	Economy	12200.00
0005434182181	11623	Economy	12200.00
0005434095118	11623	Economy	12200.00
0005434143716	11623	Economy	12200.00
0005434095121	11623	Economy	12200.00
0005434182183	11623	Economy	12200.00
0005434095142	11623	Economy	12200.00
0005434095143	11623	Economy	12200.00
0005434182180	11623	Economy	12200.00
0005434183578	11623	Economy	12200.00
0005434095169	11623	Economy	12200.00
0005434182177	11623	Economy	12200.00
0005434095141	11623	Economy	12200.00
0005434184663	11623	Economy	12200.00
0005435732323	1418	Business	33000.00
0005433397333	1418	Business	33000.00
0005433456969	1418	Business	33000.00
0005433397777	1418	Business	33000.00
0005435732326	1418	Business	33000.00
0005433397596	1418	Business	33000.00
0005433397609	1418	Business	33000.00
0005433397612	1418	Business	33000.00
0005433397730	1418	Business	33000.00
0005433397532	1418	Economy	11000.00
0005433397621	1418	Economy	11000.00
0005433397714	1418	Economy	11000.00
0005433397655	1418	Economy	11000.00
0005433397622	1418	Economy	11000.00
0005433397639	1418	Economy	11000.00
0005433397418	1418	Economy	11000.00
0005433397667	1418	Economy	11000.00
0005432906513	1418	Economy	12100.00
0005432297277	1418	Economy	12100.00
0005435732325	1418	Economy	12100.00
0005433397417	1418	Economy	12100.00
0005433397605	1418	Economy	11000.00
0005433397709	1418	Economy	11000.00
0005433397577	1418	Economy	11000.00
0005435732317	1418	Economy	11000.00
0005433397633	1418	Economy	11000.00
0005433397746	1418	Economy	11000.00
0005433397720	1418	Economy	11000.00
0005433397733	1418	Economy	11000.00
0005433397663	1418	Economy	11000.00
0005433397719	1418	Economy	11000.00
0005433397628	1418	Economy	11000.00
0005433397481	1418	Economy	11000.00
0005433456970	1418	Economy	11000.00
0005435732322	1418	Economy	11000.00
0005433397668	1418	Economy	11000.00
0005435732321	1418	Economy	11000.00
0005435732324	1418	Economy	11000.00
0005433397695	1418	Economy	11000.00
0005433397527	1418	Economy	11000.00
0005433397776	1418	Economy	11000.00
0005433397632	1418	Economy	11000.00
0005433397744	1418	Economy	11000.00
0005433397495	1418	Economy	11000.00
0005433397642	1418	Economy	11000.00
0005433397512	1418	Economy	11000.00
0005433397745	1418	Economy	11000.00
0005433397528	1418	Economy	11000.00
0005433397669	1418	Economy	11000.00
0005433397729	1418	Economy	11000.00
0005432906514	1418	Economy	11000.00
0005432906519	1418	Economy	11000.00
0005433397775	1418	Economy	11000.00
0005433397500	1418	Economy	11000.00
0005433397734	1418	Economy	11000.00
0005433397539	1418	Economy	11000.00
0005433397794	1418	Economy	11000.00
0005435732320	1418	Economy	11000.00
0005433397826	1418	Economy	11000.00
0005433397447	1418	Economy	11000.00
0005433397580	1418	Economy	11000.00
0005433397600	1418	Economy	11000.00
0005435732318	1418	Economy	11000.00
0005433397818	1418	Economy	11000.00
0005433397823	1418	Economy	11000.00
0005433397540	1418	Economy	11000.00
0005435732319	1418	Economy	11000.00
0005432297276	1418	Economy	11000.00
0005433397643	1418	Economy	11000.00
0005432906515	1418	Economy	11000.00
0005433397822	1418	Economy	11000.00
0005433397594	1418	Economy	11000.00
0005433397788	1418	Economy	11000.00
0005433398058	19235	Business	33000.00
0005432906536	19235	Business	33000.00
0005433398039	19235	Business	33000.00
0005435732174	19235	Business	33000.00
0005433398024	19235	Business	33000.00
0005433398069	19235	Business	33000.00
0005435732203	19235	Business	33000.00
0005433398070	19235	Economy	11000.00
0005433398028	19235	Economy	11000.00
0005433398042	19235	Economy	11000.00
0005433398036	19235	Economy	11000.00
0005433398041	19235	Economy	11000.00
0005435732219	19235	Economy	11000.00
0005433456924	19235	Economy	11000.00
0005433398063	19235	Economy	11000.00
0005433398052	19235	Economy	12100.00
0005433398073	19235	Economy	12100.00
0005433456927	19235	Economy	12100.00
0005435732217	19235	Economy	12100.00
0005433398072	19235	Economy	11000.00
0005435732235	19235	Economy	11000.00
0005433398045	19235	Economy	11000.00
0005433398068	19235	Economy	11000.00
0005433456956	19235	Economy	11000.00
0005435732202	19235	Economy	11000.00
0005433398067	19235	Economy	11000.00
0005433398026	19235	Economy	11000.00
0005433398032	19235	Economy	11000.00
0005433456926	19235	Economy	11000.00
0005433398040	19235	Economy	11000.00
0005433398034	19235	Economy	11000.00
0005435732287	19235	Economy	11000.00
0005433456925	19235	Economy	11000.00
0005433398043	19235	Economy	11000.00
0005433398074	19235	Economy	11000.00
0005433398059	19235	Economy	11000.00
0005433398061	19235	Economy	11000.00
0005433398064	19235	Economy	11000.00
0005433398066	19235	Economy	11000.00
0005433398062	19235	Economy	11000.00
0005433398038	19235	Economy	11000.00
0005433398060	19235	Economy	11000.00
0005433398057	19235	Economy	11000.00
0005435732288	19235	Economy	11000.00
0005433398048	19235	Economy	11000.00
0005433456938	19235	Economy	11000.00
0005433398030	19235	Economy	11000.00
0005432906534	19235	Economy	11000.00
0005433398051	19235	Economy	11000.00
0005433398037	19235	Economy	11000.00
0005433398071	19235	Economy	11000.00
0005433398049	19235	Economy	11000.00
0005433398035	19235	Economy	11000.00
0005433398031	19235	Economy	11000.00
0005433398046	19235	Economy	11000.00
0005433398050	19235	Economy	11000.00
0005433398025	19235	Economy	11000.00
0005433398055	19235	Economy	11000.00
0005435732180	19235	Economy	11000.00
0005432906535	19235	Economy	11000.00
0005433398033	19235	Economy	11000.00
0005435732173	19235	Economy	11000.00
0005433398065	19235	Economy	11000.00
0005433398047	19235	Economy	11000.00
0005433398029	19235	Economy	11000.00
0005433398053	19235	Economy	11000.00
0005433398044	19235	Economy	11000.00
0005433398054	19235	Economy	11000.00
0005433398027	19235	Economy	11000.00
0005433398056	19235	Economy	11000.00
0005434443543	17351	Economy	15600.00
0005434443566	17351	Economy	15600.00
0005434443558	17351	Economy	14100.00
0005434443539	17351	Economy	14100.00
0005434443623	17351	Economy	14100.00
0005434443545	17351	Economy	14100.00
0005434443565	17351	Economy	14100.00
0005434443525	17351	Economy	14100.00
0005434443546	17351	Economy	14100.00
0005434443582	17351	Economy	14100.00
0005434443585	17351	Economy	14100.00
0005434443547	17351	Economy	14100.00
0005434443690	20555	Economy	15600.00
0005434443697	20555	Economy	15600.00
0005434443692	20555	Economy	14100.00
0005434443693	20555	Economy	14100.00
0005434443701	20555	Economy	14100.00
0005434443699	20555	Economy	14100.00
0005434443689	20555	Economy	14100.00
0005434443702	20555	Economy	14100.00
0005434443700	20555	Economy	14100.00
0005434443696	20555	Economy	14100.00
0005434443688	20555	Economy	14100.00
0005434443695	20555	Economy	14100.00
0005434443704	20555	Economy	14100.00
0005434443703	20555	Economy	14100.00
0005434443694	20555	Economy	14100.00
0005434443691	20555	Economy	14100.00
0005434443698	20555	Economy	14100.00
0005434954607	7266	Economy	5800.00
0005435377553	7266	Economy	5800.00
0005434954609	7266	Economy	5800.00
0005434954608	7266	Economy	5800.00
0005434954606	7266	Economy	5800.00
0005434954581	28312	Economy	5800.00
0005434954574	28312	Economy	5800.00
0005435377580	28312	Economy	5800.00
0005435377579	28312	Economy	5800.00
0005434954575	28312	Economy	5800.00
0005435893610	4509	Economy	15400.00
0005434351689	4509	Economy	15400.00
0005434351698	4509	Economy	15400.00
0005434351686	4509	Economy	14000.00
0005434183562	4509	Economy	14000.00
0005435893587	4509	Economy	14000.00
0005434351694	4509	Economy	14000.00
0005434351692	4509	Economy	14000.00
0005434351691	4509	Economy	14000.00
0005434326271	4509	Economy	14000.00
0005434351693	4509	Economy	14000.00
0005435893576	4509	Economy	14000.00
0005434351688	4509	Economy	14000.00
0005435893578	4509	Economy	14000.00
0005434351699	4509	Economy	14000.00
0005435893575	4509	Economy	14000.00
0005434183561	4509	Economy	14000.00
0005434351697	4509	Economy	14000.00
0005434351690	4509	Economy	14000.00
0005434326270	4509	Economy	14000.00
0005434351695	4509	Economy	14000.00
0005434351696	4509	Economy	14000.00
0005435893581	4509	Economy	14000.00
0005434351687	4509	Economy	14000.00
0005434351582	29675	Economy	15400.00
0005434351558	29675	Economy	15400.00
0005434351620	29675	Economy	14000.00
0005434351557	29675	Economy	14000.00
0005435893630	29675	Economy	14000.00
0005435893632	29675	Economy	14000.00
0005434351574	29675	Economy	14000.00
0005434351580	29675	Economy	14000.00
0005435893627	29675	Economy	14000.00
0005434351619	29675	Economy	14000.00
0005434351559	29675	Economy	14000.00
0005434351640	29675	Economy	14000.00
0005435893633	29675	Economy	14000.00
0005434351579	29675	Economy	14000.00
0005435893628	29675	Economy	14000.00
0005435893629	29675	Economy	14000.00
0005435893631	29675	Economy	14000.00
0005434351611	29675	Economy	14000.00
0005434351610	29675	Economy	14000.00
0005435893634	29675	Economy	14000.00
0005435893635	29675	Economy	14000.00
0005434351575	29675	Economy	14000.00
0005435092069	1072	Business	30600.00
0005433341922	1072	Business	30600.00
0005435092071	1072	Business	30600.00
0005434445247	1072	Business	30600.00
0005433159298	1072	Business	30600.00
0005433342180	1072	Business	30600.00
0005433342174	1072	Business	30600.00
0005433342230	1072	Business	30600.00
0005433342381	1072	Business	30600.00
0005433342361	1072	Business	30600.00
0005435545739	1072	Business	30600.00
0005433342083	1072	Business	30600.00
0005433342022	1072	Business	30600.00
0005435092074	1072	Business	30600.00
0005433342228	1072	Business	30600.00
0005433342107	1072	Business	30600.00
0005433341798	1072	Business	30600.00
0005433342270	1072	Business	30600.00
0005433158115	1072	Business	30600.00
0005435092067	1072	Business	30600.00
0005433341911	1072	Business	30600.00
0005433342393	1072	Business	30600.00
0005433341779	1072	Economy	11200.00
0005435545738	1072	Economy	10200.00
0005433341481	1072	Economy	10200.00
0005433462746	1072	Economy	10200.00
0005433341617	1072	Economy	10200.00
0005433342372	1072	Economy	10200.00
0005433158112	1072	Economy	10200.00
0005433342493	1072	Economy	10200.00
0005433269675	1072	Economy	10200.00
0005433342219	1072	Economy	10200.00
0005435545737	1072	Economy	10200.00
0005433341622	1072	Economy	10200.00
0005433341933	1072	Economy	10200.00
0005433342204	1072	Economy	10200.00
0005434445248	1072	Economy	10200.00
0005433342326	1072	Economy	10200.00
0005433462745	1072	Economy	10200.00
0005433341916	1072	Economy	10200.00
0005433341882	1072	Economy	10200.00
0005433342475	1072	Economy	10200.00
0005433342118	1072	Economy	10200.00
0005433341932	1072	Economy	10200.00
0005433341868	1072	Economy	10200.00
0005433341930	1072	Economy	10200.00
0005433342105	1072	Economy	10200.00
0005433341999	1072	Economy	10200.00
0005433342238	1072	Economy	10200.00
0005433341923	1072	Economy	10200.00
0005433341894	1072	Economy	10200.00
0005433463899	1072	Economy	10200.00
0005433158113	1072	Economy	10200.00
0005433342298	1072	Economy	10200.00
0005433342142	1072	Economy	10200.00
0005433342265	1072	Economy	10200.00
0005433342405	1072	Economy	10200.00
0005433462747	1072	Economy	10200.00
0005433341978	1072	Economy	10200.00
0005433342327	1072	Economy	10200.00
0005433342192	1072	Economy	10200.00
0005433342374	1072	Economy	10200.00
0005433342297	1072	Economy	10200.00
0005435545736	1072	Economy	10200.00
0005433342274	1072	Economy	10200.00
0005435092070	1072	Economy	10200.00
0005433341931	1072	Economy	10200.00
0005433463901	1072	Economy	10200.00
0005433158114	1072	Economy	10200.00
0005433342718	1072	Economy	10200.00
0005433342526	1072	Economy	10200.00
0005433342209	1072	Economy	10200.00
0005433341980	1072	Economy	10200.00
0005433342016	1072	Economy	10200.00
0005433342364	1072	Economy	10200.00
0005433342273	1072	Economy	10200.00
0005433341979	1072	Economy	10200.00
0005433342218	1072	Economy	10200.00
0005433342440	1072	Economy	10200.00
0005433342000	1072	Economy	10200.00
0005432293207	1072	Economy	10200.00
0005433341913	1072	Economy	10200.00
0005433341621	1072	Economy	10200.00
0005433341614	1072	Economy	10200.00
0005432293208	1072	Economy	10200.00
0005433342106	1072	Economy	10200.00
0005433341952	1072	Economy	10200.00
0005433342240	1072	Economy	10200.00
0005433342197	1072	Economy	10200.00
0005433342369	1072	Economy	10200.00
0005433342375	1072	Economy	10200.00
0005433342459	1072	Economy	10200.00
0005433342514	1072	Economy	11200.00
0005432293209	1072	Economy	11200.00
0005433159290	1072	Economy	10200.00
0005435092076	1072	Economy	10200.00
0005433342210	1072	Economy	10200.00
0005433342196	1072	Economy	10200.00
0005433342124	1072	Economy	10200.00
0005433342155	1072	Economy	10200.00
0005433158118	1072	Economy	10200.00
0005433341809	1072	Economy	10200.00
0005433341799	1072	Economy	10200.00
0005434446519	1072	Economy	10200.00
0005433342373	1072	Economy	10200.00
0005433341902	1072	Economy	10200.00
0005433341973	1072	Economy	10200.00
0005433342296	1072	Economy	10200.00
0005433342077	1072	Economy	10200.00
0005433341944	1072	Economy	10200.00
0005433342527	1072	Economy	10200.00
0005433341940	1072	Economy	10200.00
0005433342237	1072	Economy	10200.00
0005433342229	1072	Economy	10200.00
0005435545740	1072	Economy	10200.00
0005433341613	1072	Economy	10200.00
0005433342378	1072	Economy	10200.00
0005433342370	1072	Economy	10200.00
0005433341883	1072	Economy	10200.00
0005433342260	1072	Economy	10200.00
0005433342239	1072	Economy	10200.00
0005433342534	1072	Economy	10200.00
0005433342563	1072	Economy	10200.00
0005433341912	1072	Economy	10200.00
0005435092073	1072	Economy	10200.00
0005433341881	1072	Economy	10200.00
0005433463900	1072	Economy	10200.00
0005433342232	1072	Economy	10200.00
0005435092072	1072	Economy	10200.00
0005433159281	1072	Economy	10200.00
0005433341914	1072	Economy	10200.00
0005433342412	1072	Economy	10200.00
0005433342432	1072	Economy	10200.00
0005433342213	1072	Economy	10200.00
0005433342515	1072	Economy	10200.00
0005433462748	1072	Economy	10200.00
0005433342181	1072	Economy	10200.00
0005433342023	1072	Economy	10200.00
0005435092075	1072	Economy	10200.00
0005433342330	1072	Economy	10200.00
0005433342109	1072	Economy	10200.00
0005433341480	1072	Economy	10200.00
0005433342413	1072	Economy	10200.00
0005433342165	1072	Economy	10200.00
0005433342058	1072	Economy	10200.00
0005433342088	1072	Economy	10200.00
0005433341616	1072	Economy	10200.00
0005435092068	1072	Economy	10200.00
0005433343051	17030	Business	30600.00
0005433460412	17030	Business	30600.00
0005433343039	17030	Business	30600.00
0005435508260	17030	Business	30600.00
0005433343043	17030	Business	30600.00
0005433269717	17030	Business	30600.00
0005433269716	17030	Business	30600.00
0005433269718	17030	Business	30600.00
0005433343036	17030	Business	30600.00
0005433343108	17030	Business	30600.00
0005433343089	17030	Business	30600.00
0005433460402	17030	Business	30600.00
0005433343012	17030	Business	30600.00
0005433343070	17030	Business	30600.00
0005433343046	17030	Business	30600.00
0005433462721	17030	Business	30600.00
0005433343102	17030	Business	30600.00
0005433343097	17030	Business	30600.00
0005433343045	17030	Business	30600.00
0005433343058	17030	Business	30600.00
0005433343110	17030	Business	30600.00
0005433343093	17030	Business	30600.00
0005433343087	17030	Business	30600.00
0005433462719	17030	Economy	11200.00
0005433343038	17030	Economy	11200.00
0005433343059	17030	Economy	10200.00
0005435508243	17030	Economy	10200.00
0005433460401	17030	Economy	10200.00
0005433343024	17030	Economy	10200.00
0005433343094	17030	Economy	10200.00
0005433343088	17030	Economy	10200.00
0005433462724	17030	Economy	10200.00
0005433460405	17030	Economy	10200.00
0005433343104	17030	Economy	10200.00
0005433343064	17030	Economy	10200.00
0005433462712	17030	Economy	10200.00
0005433343081	17030	Economy	10200.00
0005433343062	17030	Economy	10200.00
0005433343071	17030	Economy	10200.00
0005433343107	17030	Economy	10200.00
0005433343105	17030	Economy	10200.00
0005433343034	17030	Economy	10200.00
0005433462718	17030	Economy	10200.00
0005433343011	17030	Economy	10200.00
0005433343048	17030	Economy	10200.00
0005434445222	17030	Economy	10200.00
0005433462711	17030	Economy	10200.00
0005433343052	17030	Economy	10200.00
0005433343080	17030	Economy	10200.00
0005433343073	17030	Economy	10200.00
0005433343021	17030	Economy	10200.00
0005433343026	17030	Economy	10200.00
0005433159310	17030	Economy	10200.00
0005433343054	17030	Economy	10200.00
0005433343103	17030	Economy	10200.00
0005433343015	17030	Economy	10200.00
0005435508272	17030	Economy	10200.00
0005433343076	17030	Economy	10200.00
0005433343023	17030	Economy	10200.00
0005433343099	17030	Economy	10200.00
0005435508239	17030	Economy	10200.00
0005433460403	17030	Economy	10200.00
0005433343044	17030	Economy	10200.00
0005434445221	17030	Economy	10200.00
0005433343083	17030	Economy	10200.00
0005433343017	17030	Economy	10200.00
0005433343009	17030	Economy	10200.00
0005433343010	17030	Economy	10200.00
0005433343033	17030	Economy	10200.00
0005433159313	17030	Economy	10200.00
0005433343042	17030	Economy	10200.00
0005433462709	17030	Economy	10200.00
0005433343098	17030	Economy	10200.00
0005433462717	17030	Economy	10200.00
0005433343068	17030	Economy	10200.00
0005433343013	17030	Economy	10200.00
0005433343079	17030	Economy	10200.00
0005433343077	17030	Economy	10200.00
0005433343074	17030	Economy	10200.00
0005433269719	17030	Economy	10200.00
0005433460404	17030	Economy	10200.00
0005433462720	17030	Economy	10200.00
0005433343084	17030	Economy	10200.00
0005433462710	17030	Economy	10200.00
0005433343090	17030	Economy	10200.00
0005433460408	17030	Economy	10200.00
0005433343078	17030	Economy	10200.00
0005433343047	17030	Economy	10200.00
0005433343049	17030	Economy	10200.00
0005433269715	17030	Economy	10200.00
0005433343069	17030	Economy	10200.00
0005433460407	17030	Economy	10200.00
0005433462714	17030	Economy	10200.00
0005435508257	17030	Economy	10200.00
0005433462713	17030	Economy	10200.00
0005433343075	17030	Economy	10200.00
0005433460409	17030	Economy	10200.00
0005433343109	17030	Economy	10200.00
0005433343096	17030	Economy	10200.00
0005433343031	17030	Economy	10200.00
0005435508236	17030	Economy	10200.00
0005435091962	17030	Economy	11200.00
0005433343014	17030	Economy	10200.00
0005433343027	17030	Economy	11200.00
0005435091964	17030	Economy	10200.00
0005435091996	17030	Economy	11200.00
0005433343022	17030	Economy	10200.00
0005433462723	17030	Economy	10200.00
0005433343032	17030	Economy	10200.00
0005433343067	17030	Economy	10200.00
0005435091977	17030	Economy	10200.00
0005433343101	17030	Economy	10200.00
0005435508258	17030	Economy	10200.00
0005433343020	17030	Economy	10200.00
0005433343060	17030	Economy	10200.00
0005433343025	17030	Economy	10200.00
0005435091989	17030	Economy	10200.00
0005433343041	17030	Economy	10200.00
0005433460400	17030	Economy	10200.00
0005434445219	17030	Economy	10200.00
0005433343072	17030	Economy	10200.00
0005433343063	17030	Economy	10200.00
0005434445220	17030	Economy	10200.00
0005433343057	17030	Economy	10200.00
0005433343100	17030	Economy	10200.00
0005435508271	17030	Economy	10200.00
0005433460399	17030	Economy	10200.00
0005433343028	17030	Economy	10200.00
0005433343082	17030	Economy	10200.00
0005433343016	17030	Economy	10200.00
0005433343106	17030	Economy	10200.00
0005433343061	17030	Economy	10200.00
0005433343029	17030	Economy	10200.00
0005433343037	17030	Economy	10200.00
0005433343050	17030	Economy	10200.00
0005433343086	17030	Economy	10200.00
0005433343095	17030	Economy	10200.00
0005433343085	17030	Economy	10200.00
0005433343053	17030	Economy	10200.00
0005433460406	17030	Economy	10200.00
0005433343092	17030	Economy	10200.00
0005433343035	17030	Economy	10200.00
0005435091963	17030	Economy	10200.00
0005433159312	17030	Economy	10200.00
0005433343066	17030	Economy	10200.00
0005433460410	17030	Economy	10200.00
0005435508242	17030	Economy	10200.00
0005433343091	17030	Economy	10200.00
0005433159311	17030	Economy	10200.00
0005435508228	17030	Economy	10200.00
0005433462716	17030	Economy	10200.00
0005433460398	17030	Economy	10200.00
0005433343056	17030	Economy	10200.00
0005433343065	17030	Economy	10200.00
0005433343055	17030	Economy	10200.00
0005433343019	17030	Economy	10200.00
0005435508261	17030	Economy	10200.00
0005433462715	17030	Economy	10200.00
0005433343030	17030	Economy	10200.00
0005435508227	17030	Economy	10200.00
0005433343040	17030	Economy	10200.00
0005433343018	17030	Economy	10200.00
0005432389971	18259	Business	101000.00
0005432391982	18259	Business	101000.00
0005432389968	18259	Business	101000.00
0005432389972	18259	Business	101000.00
0005432390015	18259	Business	101000.00
0005432851922	18259	Business	101000.00
0005432390021	18259	Business	101000.00
0005432390033	18259	Business	101000.00
0005432391972	18259	Business	101000.00
0005432389976	18259	Business	101000.00
0005432389978	18259	Business	101000.00
0005432851923	18259	Economy	33700.00
0005432391967	18259	Business	101000.00
0005432390056	18259	Economy	33700.00
0005432390055	18259	Economy	33700.00
0005432390053	18259	Economy	33700.00
0005432851909	18259	Economy	33700.00
0005432851925	18259	Economy	33700.00
0005432851907	18259	Economy	33700.00
0005432851920	18259	Economy	33700.00
0005432390054	18259	Economy	37000.00
0005432391956	18259	Economy	33700.00
0005432851918	18259	Economy	37000.00
0005432851908	18259	Economy	33700.00
0005432851924	18259	Economy	33700.00
0005432390019	18259	Economy	33700.00
0005432390016	18259	Economy	33700.00
0005432390013	18259	Economy	33700.00
0005432390037	18259	Economy	33700.00
0005432851915	18259	Economy	33700.00
0005432390035	18259	Economy	33700.00
0005432390032	18259	Economy	33700.00
0005432390031	18259	Economy	33700.00
0005432390043	18259	Economy	33700.00
0005432390088	18259	Economy	33700.00
0005432389977	18259	Economy	33700.00
0005432851912	18259	Economy	33700.00
0005432391980	18259	Economy	33700.00
0005432391981	18259	Economy	33700.00
0005432390038	18259	Economy	33700.00
0005432390041	18259	Economy	33700.00
0005432390040	18259	Economy	33700.00
0005432851921	18259	Economy	33700.00
0005432389937	18259	Economy	33700.00
0005432851914	18259	Economy	33700.00
0005432851916	18259	Economy	33700.00
0005432389975	18259	Economy	33700.00
0005432851913	18259	Economy	33700.00
0005432390020	18259	Economy	33700.00
0005432389973	18259	Economy	33700.00
0005432391983	18259	Economy	33700.00
0005432851919	18259	Economy	33700.00
0005432390005	18259	Economy	33700.00
0005432390017	18259	Economy	33700.00
0005432851917	18259	Economy	33700.00
0005432391960	18259	Economy	33700.00
0005432390030	18259	Economy	33700.00
0005432851911	18259	Economy	33700.00
0005432391959	18259	Economy	33700.00
0005432389991	18259	Economy	33700.00
0005432851910	18259	Economy	33700.00
0005432391966	18259	Economy	33700.00
0005432390012	18259	Economy	33700.00
0005432391965	18259	Economy	33700.00
0005432390027	18259	Economy	33700.00
0005432390042	18259	Economy	33700.00
0005432390036	18259	Economy	33700.00
0005432390074	18259	Economy	33700.00
0005432390014	18259	Economy	33700.00
0005434066955	12824	Business	40300.00
0005434066819	12824	Business	40300.00
0005434066708	12824	Business	40300.00
0005432433677	12824	Business	40300.00
0005432159856	12824	Business	40300.00
0005434081733	12824	Business	40300.00
0005434066698	12824	Business	40300.00
0005434067179	12824	Business	40300.00
0005434066889	12824	Business	40300.00
0005432161152	12824	Business	40300.00
0005434066664	12824	Economy	13400.00
0005434066927	12824	Economy	13400.00
0005432433680	12824	Economy	13400.00
0005433989729	12824	Economy	13400.00
0005434081694	12824	Economy	13400.00
0005434066931	12824	Economy	13400.00
0005434066784	12824	Economy	13400.00
0005433812899	12824	Economy	13400.00
0005434067011	12824	Economy	13400.00
0005434066831	12824	Economy	13400.00
0005434066620	12824	Economy	13400.00
0005432433678	12824	Economy	13400.00
0005434081707	12824	Economy	13400.00
0005434066707	12824	Economy	13400.00
0005434067075	12824	Economy	13400.00
0005434066619	12824	Economy	13400.00
0005433989720	12824	Economy	13400.00
0005434066702	12824	Economy	13400.00
0005434081636	12824	Economy	13400.00
0005432159859	12824	Economy	13400.00
0005434026677	12824	Economy	13400.00
0005433812900	12824	Economy	13400.00
0005434081638	12824	Economy	13400.00
0005434081719	12824	Economy	13400.00
0005434081603	12824	Economy	13400.00
0005434066716	12824	Economy	13400.00
0005434066947	12824	Economy	13400.00
0005434066882	12824	Economy	13400.00
0005434066906	12824	Economy	13400.00
0005434081678	12824	Economy	13400.00
0005434066799	12824	Economy	13400.00
0005434067006	12824	Economy	13400.00
0005434081573	12824	Economy	14800.00
0005434081679	12824	Economy	14800.00
0005434081654	12824	Economy	14800.00
0005434067131	12824	Economy	14800.00
0005434066785	12824	Economy	13400.00
0005434081656	12824	Economy	13400.00
0005434067132	12824	Economy	13400.00
0005434066691	12824	Economy	13400.00
0005434081626	12824	Economy	13400.00
0005434066932	12824	Economy	13400.00
0005434067163	12824	Economy	13400.00
0005434081723	12824	Economy	13400.00
0005432159858	12824	Economy	13400.00
0005434066925	12824	Economy	13400.00
0005434066950	12824	Economy	13400.00
0005434066965	12824	Economy	13400.00
0005434066832	12824	Economy	13400.00
0005434066883	12824	Economy	13400.00
0005434067230	12824	Economy	13400.00
0005434066985	12824	Economy	13400.00
0005434067002	12824	Economy	13400.00
0005432159857	12824	Economy	13400.00
0005434066907	12824	Economy	13400.00
0005434081653	12824	Economy	13400.00
0005434026686	12824	Economy	13400.00
0005434066951	12824	Economy	13400.00
0005434067036	12824	Economy	13400.00
0005434066692	12824	Economy	13400.00
0005434081722	12824	Economy	13400.00
0005434066977	12824	Economy	13400.00
0005434066697	12824	Economy	13400.00
0005434066946	12824	Economy	13400.00
0005434066665	12824	Economy	13400.00
0005432433679	12824	Economy	13400.00
0005434026685	12824	Economy	13400.00
0005434067070	12824	Economy	13400.00
0005432161151	12824	Economy	13400.00
0005434081697	12824	Economy	13400.00
0005434026678	12824	Economy	13400.00
0005434081744	12824	Economy	13400.00
0005434067005	12824	Economy	13400.00
0005434081695	12824	Economy	13400.00
0005434066830	12824	Economy	13400.00
0005434066786	12824	Economy	13400.00
0005434066690	12824	Economy	13400.00
0005434067063	12824	Economy	13400.00
0005434081604	12824	Economy	13400.00
0005434081664	12824	Economy	13400.00
0005432159855	12824	Economy	13400.00
0005434066913	12824	Economy	13400.00
0005434081680	12824	Economy	13400.00
0005434067064	12824	Economy	13400.00
0005434066888	12824	Economy	13400.00
0005434067071	12824	Economy	13400.00
0005434066699	12824	Economy	13400.00
0005434066717	12824	Economy	13400.00
0005434066800	12824	Economy	13400.00
0005434081602	12824	Economy	13400.00
0005434066701	12824	Economy	13400.00
0005434067159	12824	Economy	13400.00
0005434066937	12824	Economy	13400.00
0005434066890	12824	Economy	13400.00
0005434066926	12824	Economy	13400.00
0005434066898	12824	Economy	13400.00
0005433989728	12824	Economy	13400.00
0005434066912	12824	Economy	13400.00
0005434081869	30653	Business	40300.00
0005434067481	30653	Business	40300.00
0005434067464	30653	Business	40300.00
0005432433621	30653	Business	40300.00
0005434081861	30653	Business	40300.00
0005434081885	30653	Business	40300.00
0005434081868	30653	Business	40300.00
0005434081881	30653	Business	40300.00
0005434067471	30653	Business	40300.00
0005434067461	30653	Business	40300.00
0005434081890	30653	Business	40300.00
0005434067477	30653	Business	40300.00
0005433989765	30653	Economy	13400.00
0005434067519	30653	Economy	13400.00
0005434067509	30653	Economy	13400.00
0005434081879	30653	Economy	13400.00
0005434067473	30653	Economy	13400.00
0005434067485	30653	Economy	13400.00
0005434067513	30653	Economy	13400.00
0005434067457	30653	Economy	13400.00
0005434067503	30653	Economy	13400.00
0005434067493	30653	Economy	13400.00
0005434081888	30653	Economy	13400.00
0005432150189	30653	Economy	13400.00
0005434067504	30653	Economy	13400.00
0005434081866	30653	Economy	13400.00
0005432150188	30653	Economy	13400.00
0005432433645	30653	Economy	13400.00
0005434067523	30653	Economy	13400.00
0005434067460	30653	Economy	13400.00
0005434067521	30653	Economy	13400.00
0005433989768	30653	Economy	13400.00
0005434067499	30653	Economy	13400.00
0005434067506	30653	Economy	13400.00
0005434081887	30653	Economy	13400.00
0005434067496	30653	Economy	13400.00
0005434067514	30653	Economy	13400.00
0005434067465	30653	Economy	13400.00
0005434081871	30653	Economy	13400.00
0005434081877	30653	Economy	13400.00
0005434067466	30653	Economy	13400.00
0005434081860	30653	Economy	13400.00
0005434081872	30653	Economy	13400.00
0005434067511	30653	Economy	13400.00
0005434067518	30653	Economy	13400.00
0005434081862	30653	Economy	13400.00
0005434067505	30653	Economy	13400.00
0005434067517	30653	Economy	13400.00
0005434067488	30653	Economy	13400.00
0005434081878	30653	Economy	13400.00
0005434067468	30653	Economy	13400.00
0005434081874	30653	Economy	14800.00
0005434067492	30653	Economy	14800.00
0005434067494	30653	Economy	14800.00
0005434067515	30653	Economy	14800.00
0005434067484	30653	Economy	14800.00
0005434067472	30653	Economy	14800.00
0005432433642	30653	Economy	13400.00
0005434081875	30653	Economy	13400.00
0005434067475	30653	Economy	13400.00
0005434081882	30653	Economy	13400.00
0005434067478	30653	Economy	13400.00
0005434067482	30653	Economy	13400.00
0005434067520	30653	Economy	13400.00
0005432150187	30653	Economy	13400.00
0005434081883	30653	Economy	13400.00
0005434067502	30653	Economy	13400.00
0005434067490	30653	Economy	13400.00
0005434067470	30653	Economy	13400.00
0005432186865	30653	Economy	13400.00
0005434081884	30653	Economy	13400.00
0005434067483	30653	Economy	13400.00
0005434067497	30653	Economy	13400.00
0005434067524	30653	Economy	13400.00
0005434081864	30653	Economy	13400.00
0005434081863	30653	Economy	13400.00
0005432150186	30653	Economy	13400.00
0005434067525	30653	Economy	13400.00
0005434067491	30653	Economy	13400.00
0005434067459	30653	Economy	13400.00
0005433989766	30653	Economy	13400.00
0005434081867	30653	Economy	13400.00
0005434067463	30653	Economy	13400.00
0005434081891	30653	Economy	13400.00
0005434067528	30653	Economy	13400.00
0005434067486	30653	Economy	13400.00
0005434067476	30653	Economy	13400.00
0005434081886	30653	Economy	13400.00
0005434081873	30653	Economy	13400.00
0005434067507	30653	Economy	13400.00
0005434081880	30653	Economy	13400.00
0005434081870	30653	Economy	13400.00
0005432150185	30653	Economy	13400.00
0005434067479	30653	Economy	13400.00
0005432150190	30653	Economy	13400.00
0005434067480	30653	Economy	13400.00
0005433989767	30653	Economy	13400.00
0005434067501	30653	Economy	13400.00
0005434067474	30653	Economy	13400.00
0005434067458	30653	Economy	13400.00
0005434067495	30653	Economy	13400.00
0005434067467	30653	Economy	13400.00
0005434067508	30653	Economy	13400.00
0005434081876	30653	Economy	13400.00
0005434081865	30653	Economy	13400.00
0005434067469	30653	Economy	13400.00
0005434067527	30653	Economy	13400.00
0005432433622	30653	Economy	13400.00
0005434067489	30653	Economy	13400.00
0005434067510	30653	Economy	13400.00
0005432433633	30653	Economy	13400.00
0005434067516	30653	Economy	13400.00
0005434067512	30653	Economy	13400.00
0005434067522	30653	Economy	13400.00
0005432433639	30653	Economy	13400.00
0005432186866	30653	Economy	13400.00
0005432150184	30653	Economy	13400.00
0005434067500	30653	Economy	13400.00
0005434081859	30653	Economy	13400.00
0005434067462	30653	Economy	13400.00
0005434067498	30653	Economy	13400.00
0005432150183	30653	Economy	13400.00
0005433989764	30653	Economy	13400.00
0005434067526	30653	Economy	13400.00
0005434081889	30653	Economy	13400.00
0005432186864	30653	Economy	13400.00
0005434067487	30653	Economy	13400.00
0005433686633	9036	Economy	19300.00
0005433685523	9036	Economy	17600.00
0005433687704	9036	Economy	17600.00
0005433685521	9036	Economy	17600.00
0005433685522	9036	Economy	17600.00
0005433686631	9036	Economy	17600.00
0005433685527	9036	Economy	17600.00
0005433687711	9036	Economy	17600.00
0005433686635	9036	Economy	17600.00
0005433686637	9036	Economy	17600.00
0005433686632	9036	Economy	17600.00
0005433687705	9036	Economy	17600.00
0005433687706	9036	Economy	17600.00
0005433685525	9036	Economy	17600.00
0005433685526	9036	Economy	17600.00
0005433685524	9036	Economy	17600.00
0005433686638	9036	Economy	17600.00
0005433686636	9036	Economy	17600.00
0005433686640	9036	Economy	17600.00
0005433687709	9036	Economy	17600.00
0005433687710	9036	Economy	17600.00
0005433686639	9036	Economy	17600.00
0005433687712	9036	Economy	17600.00
0005433685528	9036	Economy	17600.00
0005433687708	9036	Economy	17600.00
0005433687707	9036	Economy	17600.00
0005433686634	9036	Economy	17600.00
0005434264902	5504	Business	35300.00
0005434264922	5504	Business	35300.00
0005435766236	5504	Business	35300.00
0005435766243	5504	Business	35300.00
0005435766197	5504	Business	35300.00
0005435766238	5504	Business	35300.00
0005435766217	5504	Business	35300.00
0005435766190	5504	Business	35300.00
0005435766218	5504	Business	35300.00
0005435720823	5504	Business	35300.00
0005435720822	5504	Business	35300.00
0005434264955	5504	Business	35300.00
0005435766215	5504	Business	35300.00
0005435462101	5504	Business	35300.00
0005435462138	5504	Business	35300.00
0005434264882	5504	Business	35300.00
0005432140446	5504	Business	35300.00
0005435766216	5504	Business	35300.00
0005435766212	5504	Business	35300.00
0005435766245	5504	Business	35300.00
0005435766239	5504	Business	35300.00
0005434264852	5504	Business	35300.00
0005435766241	5504	Economy	12900.00
0005435766194	5504	Economy	12900.00
0005435462215	5504	Economy	12900.00
0005435766227	5504	Economy	11800.00
0005435766211	5504	Economy	11800.00
0005435722055	5504	Economy	11800.00
0005434264836	5504	Economy	11800.00
0005434265007	5504	Economy	11800.00
0005434264831	5504	Economy	11800.00
0005435766225	5504	Economy	11800.00
0005435766201	5504	Economy	11800.00
0005435462099	5504	Economy	11800.00
0005435462144	5504	Economy	11800.00
0005434264851	5504	Economy	11800.00
0005435766192	5504	Economy	11800.00
0005435766249	5504	Economy	11800.00
0005435766208	5504	Economy	11800.00
0005435461971	5504	Economy	11800.00
0005435766220	5504	Economy	11800.00
0005435766205	5504	Economy	11800.00
0005435462068	5504	Economy	11800.00
0005435766223	5504	Economy	11800.00
0005435462065	5504	Economy	11800.00
0005433527266	5504	Economy	11800.00
0005435766219	5504	Economy	11800.00
0005432140447	5504	Economy	11800.00
0005435766207	5504	Economy	11800.00
0005435766251	5504	Economy	11800.00
0005435462176	5504	Economy	11800.00
0005434264853	5504	Economy	11800.00
0005435766234	5504	Economy	11800.00
0005435462147	5504	Economy	11800.00
0005434264866	5504	Economy	11800.00
0005435462044	5504	Economy	11800.00
0005434264905	5504	Economy	11800.00
0005435735136	5504	Economy	11800.00
0005435725597	5504	Economy	11800.00
0005435462006	5504	Economy	11800.00
0005435766206	5504	Economy	11800.00
0005435725593	5504	Economy	11800.00
0005435766240	5504	Economy	11800.00
0005435461970	5504	Economy	11800.00
0005435766248	5504	Economy	11800.00
0005432535785	5504	Economy	11800.00
0005435735134	5504	Economy	11800.00
0005435766226	5504	Economy	11800.00
0005435462216	5504	Economy	11800.00
0005435766221	5504	Economy	11800.00
0005435766210	5504	Economy	11800.00
0005433527268	5504	Economy	11800.00
0005435462170	5504	Economy	11800.00
0005432140443	5504	Economy	11800.00
0005435462064	5504	Economy	11800.00
0005435462179	5504	Economy	11800.00
0005434264825	5504	Economy	11800.00
0005435462097	5504	Economy	11800.00
0005434264755	5504	Economy	11800.00
0005435461921	5504	Economy	11800.00
0005435766189	5504	Economy	11800.00
0005435462137	5504	Economy	11800.00
0005434264906	5504	Economy	11800.00
0005435766214	5504	Economy	11800.00
0005435462223	5504	Economy	11800.00
0005435462111	5504	Economy	11800.00
0005435462039	5504	Economy	11800.00
0005435725596	5504	Economy	11800.00
0005435766252	5504	Economy	11800.00
0005435766233	5504	Economy	11800.00
0005435766222	5504	Economy	11800.00
0005434831092	5504	Economy	11800.00
0005435462102	5504	Economy	11800.00
0005435725594	5504	Economy	11800.00
0005432140445	5504	Economy	11800.00
0005435461920	5504	Economy	11800.00
0005435722054	5504	Economy	11800.00
0005434264786	5504	Economy	11800.00
0005434264931	5504	Economy	11800.00
0005433529278	5504	Economy	11800.00
0005433527265	5504	Economy	12900.00
0005435766228	5504	Economy	11800.00
0005435720824	5504	Economy	12900.00
0005435766242	5504	Economy	11800.00
0005432535789	5504	Economy	11800.00
0005435461922	5504	Economy	12900.00
0005435766237	5504	Economy	11800.00
0005435766209	5504	Economy	11800.00
0005434831111	5504	Economy	11800.00
0005433527267	5504	Economy	11800.00
0005435766250	5504	Economy	11800.00
0005434265008	5504	Economy	11800.00
0005432140448	5504	Economy	11800.00
0005435766231	5504	Economy	11800.00
0005434264930	5504	Economy	11800.00
0005434264934	5504	Economy	11800.00
0005435766200	5504	Economy	11800.00
0005434264901	5504	Economy	11800.00
0005434264921	5504	Economy	11800.00
0005435766246	5504	Economy	11800.00
0005435462036	5504	Economy	11800.00
0005435462067	5504	Economy	11800.00
0005434264917	5504	Economy	11800.00
0005432140449	5504	Economy	11800.00
0005435766224	5504	Economy	11800.00
0005433529279	5504	Economy	11800.00
0005435766196	5504	Economy	11800.00
0005435462066	5504	Economy	11800.00
0005433529277	5504	Economy	11800.00
0005434264881	5504	Economy	11800.00
0005435725595	5504	Economy	11800.00
0005435462096	5504	Economy	11800.00
0005435462000	5504	Economy	11800.00
0005435462123	5504	Economy	11800.00
0005435766230	5504	Economy	11800.00
0005435766232	5504	Economy	11800.00
0005435766191	5504	Economy	11800.00
0005435766198	5504	Economy	11800.00
0005432535771	5504	Economy	11800.00
0005435766195	5504	Economy	11800.00
0005432535770	5504	Economy	11800.00
0005435766203	5504	Economy	11800.00
0005435766244	5504	Economy	11800.00
0005435766202	5504	Economy	11800.00
0005435462171	5504	Economy	11800.00
0005435766213	5504	Economy	11800.00
0005435462103	5504	Economy	11800.00
0005435462173	5504	Economy	11800.00
0005435735135	5504	Economy	11800.00
0005435723043	5504	Economy	11800.00
0005432140444	5504	Economy	11800.00
0005435766193	5504	Economy	11800.00
0005435766229	5504	Economy	11800.00
0005434264904	5504	Economy	11800.00
0005435766199	5504	Economy	11800.00
0005435725598	5504	Economy	11800.00
0005435462242	5504	Economy	11800.00
0005435766204	5504	Economy	11800.00
0005435766235	5504	Economy	11800.00
0005435766247	5504	Economy	11800.00
0005435462060	5504	Economy	11800.00
0005435723044	5504	Economy	11800.00
0005432140450	5504	Economy	11800.00
0005435462038	5504	Economy	11800.00
0005435462241	5504	Economy	11800.00
0005434265144	13483	Business	35300.00
0005435462442	13483	Business	35300.00
0005434265149	13483	Business	35300.00
0005435765647	13483	Business	35300.00
0005435765732	13483	Business	35300.00
0005432535831	13483	Business	35300.00
0005435765803	13483	Business	35300.00
0005434265137	13483	Business	35300.00
0005435765533	13483	Business	35300.00
0005432535835	13483	Business	35300.00
0005435765416	13483	Business	35300.00
0005435765417	13483	Business	35300.00
0005435765795	13483	Business	35300.00
0005435462436	13483	Business	35300.00
0005435725560	13483	Business	35300.00
0005434265147	13483	Business	35300.00
0005435462432	13483	Business	35300.00
0005435735081	13483	Business	35300.00
0005435765790	13483	Business	35300.00
0005435765356	13483	Business	35300.00
0005435462451	13483	Business	35300.00
0005434831152	13483	Business	35300.00
0005435765789	13483	Business	35300.00
0005435765735	13483	Business	35300.00
0005435462446	13483	Economy	12900.00
0005434265129	13483	Economy	12900.00
0005435462419	13483	Economy	12900.00
0005435462437	13483	Economy	12900.00
0005434265135	13483	Economy	11800.00
0005435462413	13483	Economy	11800.00
0005435765862	13483	Economy	11800.00
0005435462431	13483	Economy	11800.00
0005435720120	13483	Economy	11800.00
0005435765384	13483	Economy	11800.00
0005435765598	13483	Economy	11800.00
0005435765385	13483	Economy	11800.00
0005434265126	13483	Economy	11800.00
0005435462415	13483	Economy	11800.00
0005434265127	13483	Economy	11800.00
0005435765256	13483	Economy	11800.00
0005435722038	13483	Economy	11800.00
0005435765734	13483	Economy	11800.00
0005435725552	13483	Economy	11800.00
0005435765543	13483	Economy	11800.00
0005435765718	13483	Economy	11800.00
0005435462430	13483	Economy	11800.00
0005435765692	13483	Economy	11800.00
0005435765719	13483	Economy	11800.00
0005435462421	13483	Economy	11800.00
0005435462414	13483	Economy	11800.00
0005435462448	13483	Economy	11800.00
0005435723032	13483	Economy	11800.00
0005434265128	13483	Economy	11800.00
0005434831151	13483	Economy	11800.00
0005435765860	13483	Economy	11800.00
0005435765866	13483	Economy	11800.00
0005435765452	13483	Economy	11800.00
0005435765624	13483	Economy	11800.00
0005435765451	13483	Economy	11800.00
0005432194510	13483	Economy	11800.00
0005435765531	13483	Economy	11800.00
0005435765456	13483	Economy	11800.00
0005434265132	13483	Economy	11800.00
0005435735094	13483	Economy	11800.00
0005435765493	13483	Economy	11800.00
0005434831153	13483	Economy	11800.00
0005435765654	13483	Economy	11800.00
0005434265143	13483	Economy	11800.00
0005435765592	13483	Economy	11800.00
0005435765623	13483	Economy	11800.00
0005435462450	13483	Economy	11800.00
0005435765690	13483	Economy	11800.00
0005435765693	13483	Economy	11800.00
0005432194508	13483	Economy	11800.00
0005434265141	13483	Economy	11800.00
0005435725551	13483	Economy	11800.00
0005435765804	13483	Economy	11800.00
0005435462441	13483	Economy	11800.00
0005432194512	13483	Economy	11800.00
0005432535834	13483	Economy	11800.00
0005435765691	13483	Economy	11800.00
0005434265140	13483	Economy	11800.00
0005435735095	13483	Economy	11800.00
0005434265138	13483	Economy	11800.00
0005435462439	13483	Economy	11800.00
0005435462425	13483	Economy	11800.00
0005435462444	13483	Economy	11800.00
0005435765594	13483	Economy	11800.00
0005435765648	13483	Economy	11800.00
0005435462445	13483	Economy	11800.00
0005435765517	13483	Economy	11800.00
0005435462420	13483	Economy	11800.00
0005435462423	13483	Economy	11800.00
0005435765355	13483	Economy	11800.00
0005434265146	13483	Economy	11800.00
0005435765588	13483	Economy	11800.00
0005435765655	13483	Economy	11800.00
0005435765674	13483	Economy	11800.00
0005432535833	13483	Economy	11800.00
0005435765530	13483	Economy	11800.00
0005435765455	13483	Economy	11800.00
0005435462440	13483	Economy	11800.00
0005435765593	13483	Economy	11800.00
0005435765793	13483	Economy	11800.00
0005435725536	13483	Economy	11800.00
0005435765763	13483	Economy	11800.00
0005435765646	13483	Economy	11800.00
0005435765688	13483	Economy	11800.00
0005435765787	13483	Economy	11800.00
0005435765698	13483	Economy	12900.00
0005435462447	13483	Economy	11800.00
0005435765689	13483	Economy	11800.00
0005435462434	13483	Economy	11800.00
0005434265145	13483	Economy	12900.00
0005435723024	13483	Economy	12900.00
0005435462449	13483	Economy	11800.00
0005434265125	13483	Economy	11800.00
0005435723023	13483	Economy	11800.00
0005435765677	13483	Economy	11800.00
0005435462428	13483	Economy	11800.00
0005435462429	13483	Economy	11800.00
0005435462417	13483	Economy	11800.00
0005435765864	13483	Economy	11800.00
0005435725535	13483	Economy	11800.00
0005434265134	13483	Economy	11800.00
0005435765679	13483	Economy	11800.00
0005434265133	13483	Economy	11800.00
0005432194509	13483	Economy	11800.00
0005434265130	13483	Economy	11800.00
0005435765475	13483	Economy	11800.00
0005435765529	13483	Economy	11800.00
0005435765658	13483	Economy	11800.00
0005432194511	13483	Economy	11800.00
0005434265148	13483	Economy	11800.00
0005434265136	13483	Economy	11800.00
0005434265139	13483	Economy	11800.00
0005435765476	13483	Economy	11800.00
0005435765255	13483	Economy	11800.00
0005435765631	13483	Economy	11800.00
0005435765494	13483	Economy	11800.00
0005435723030	13483	Economy	11800.00
0005435725543	13483	Economy	11800.00
0005435462433	13483	Economy	11800.00
0005435765257	13483	Economy	11800.00
0005435765630	13483	Economy	11800.00
0005435735107	13483	Economy	11800.00
0005435735083	13483	Economy	11800.00
0005434265142	13483	Economy	11800.00
0005435765695	13483	Economy	11800.00
0005435765675	13483	Economy	11800.00
0005435462438	13483	Economy	11800.00
0005435462424	13483	Economy	11800.00
0005435765905	13483	Economy	11800.00
0005434265131	13483	Economy	11800.00
0005435765836	13483	Economy	11800.00
0005435725544	13483	Economy	11800.00
0005435765642	13483	Economy	11800.00
0005435765919	13483	Economy	11800.00
0005435765738	13483	Economy	11800.00
0005432535832	13483	Economy	11800.00
0005435462443	13483	Economy	11800.00
0005435765882	13483	Economy	11800.00
0005435765766	13483	Economy	11800.00
0005435765740	13483	Economy	11800.00
0005435462435	13483	Economy	11800.00
0005434265150	13483	Economy	11800.00
0005435765534	13483	Economy	11800.00
0005435462426	13483	Economy	11800.00
0005435765408	13483	Economy	11800.00
0005434831154	13483	Economy	11800.00
0005435462418	13483	Economy	11800.00
0005435462422	13483	Economy	11800.00
0005435462427	13483	Economy	11800.00
0005435765587	13483	Economy	11800.00
0005435462416	13483	Economy	11800.00
0005435765867	13483	Economy	11800.00
0005434602878	18661	Economy	3300.00
0005434602877	18661	Economy	3300.00
0005434514967	18660	Economy	3300.00
0005434604869	18660	Economy	3300.00
0005434513577	18660	Economy	3300.00
0005434514965	18660	Economy	3300.00
0005434513576	18660	Economy	3300.00
0005434514966	18660	Economy	3300.00
0005434604870	18660	Economy	3300.00
0005435904704	18660	Economy	3300.00
0005434513578	18660	Economy	3300.00
0005434514944	19151	Economy	3300.00
0005434602895	19151	Economy	3300.00
0005434602898	19151	Economy	3300.00
0005434602899	19151	Economy	3300.00
0005434602897	19151	Economy	3300.00
0005434514951	19151	Economy	3300.00
0005434602896	19151	Economy	3300.00
0005434602894	19151	Economy	3300.00
0005433285032	1833	Business	48700.00
0005433810547	1833	Business	48700.00
0005433285120	1833	Business	48700.00
0005433008320	1833	Business	48700.00
0005433008325	1833	Business	48700.00
0005432295880	1833	Business	48700.00
0005433285064	1833	Business	48700.00
0005433008152	1833	Business	48700.00
0005433008174	1833	Business	48700.00
0005433285084	1833	Economy	16200.00
0005433008205	1833	Economy	16200.00
0005433008206	1833	Economy	16200.00
0005433008241	1833	Economy	16200.00
0005433285099	1833	Economy	16200.00
0005433285121	1833	Economy	16200.00
0005433008188	1833	Economy	16200.00
0005433008192	1833	Economy	16200.00
0005433810546	1833	Economy	16200.00
0005433284975	1833	Economy	16200.00
0005432295879	1833	Economy	17900.00
0005433008076	1833	Economy	17900.00
0005433285039	1833	Economy	17900.00
0005433008106	1833	Economy	17900.00
0005432295878	1833	Economy	17900.00
0005433008276	1833	Economy	16200.00
0005433008048	1833	Economy	16200.00
0005433008337	1833	Economy	16200.00
0005433008171	1833	Economy	16200.00
0005433285007	1833	Economy	16200.00
0005433008264	1833	Economy	16200.00
0005433285046	1833	Economy	16200.00
0005433008118	1833	Economy	16200.00
0005433008204	1833	Economy	16200.00
0005433008319	1833	Economy	16200.00
0005433008068	1833	Economy	16200.00
0005433008376	1833	Economy	16200.00
0005433008133	1833	Economy	16200.00
0005433008266	1833	Economy	16200.00
0005433285047	1833	Economy	16200.00
0005433008463	1833	Economy	16200.00
0005433284953	1833	Economy	16200.00
0005433008200	1833	Economy	16200.00
0005433008193	1833	Economy	16200.00
0005433008099	1833	Economy	16200.00
0005433008239	1833	Economy	16200.00
0005433008422	1833	Economy	16200.00
0005433285101	1833	Economy	16200.00
0005433285065	1833	Economy	16200.00
0005433008317	1833	Economy	16200.00
0005433008334	1833	Economy	16200.00
0005433008207	1833	Economy	16200.00
0005433008143	1833	Economy	16200.00
0005433008347	1833	Economy	16200.00
0005433008156	1833	Economy	16200.00
0005433008131	1833	Economy	16200.00
0005433285041	1833	Economy	16200.00
0005433008147	1833	Economy	16200.00
0005433285010	1833	Economy	16200.00
0005433008187	1833	Economy	16200.00
0005433008338	1833	Economy	16200.00
0005433285008	1833	Economy	16200.00
0005433008423	1833	Economy	16200.00
0005433008265	1833	Economy	16200.00
0005433285045	1833	Economy	16200.00
0005433285040	1833	Economy	16200.00
0005433008372	1833	Economy	16200.00
0005433285100	1833	Economy	16200.00
0005433285063	1833	Economy	16200.00
0005433008375	1833	Economy	16200.00
0005433008383	1833	Economy	16200.00
0005433008069	1833	Economy	16200.00
0005433008119	1833	Economy	16200.00
0005433008153	1833	Economy	16200.00
0005433008218	1833	Economy	16200.00
0005433008282	1833	Economy	16200.00
0005433008132	1833	Economy	16200.00
0005433810549	1833	Economy	16200.00
0005433008079	1833	Economy	16200.00
0005433285076	1833	Economy	16200.00
0005433810548	1833	Economy	16200.00
0005433008144	1833	Economy	16200.00
0005433008346	1833	Economy	16200.00
0005433285033	1833	Economy	16200.00
0005433285289	22542	Business	48700.00
0005433285288	22542	Business	48700.00
0005433285270	22542	Business	48700.00
0005433285286	22542	Business	48700.00
0005433008609	22542	Business	48700.00
0005433285279	22542	Business	48700.00
0005433008596	22542	Business	48700.00
0005433008584	22542	Business	48700.00
0005433008593	22542	Business	48700.00
0005433008600	22542	Business	48700.00
0005433285287	22542	Business	48700.00
0005433008605	22542	Economy	16200.00
0005433008587	22542	Economy	16200.00
0005433008564	22542	Economy	16200.00
0005433008592	22542	Economy	16200.00
0005433008583	22542	Economy	16200.00
0005433008573	22542	Economy	16200.00
0005433008568	22542	Economy	16200.00
0005433008588	22542	Economy	16200.00
0005433285282	22542	Economy	16200.00
0005433008585	22542	Economy	17900.00
0005433810496	22542	Economy	17900.00
0005433285276	22542	Economy	17900.00
0005433008577	22542	Economy	17900.00
0005433008589	22542	Economy	16200.00
0005433008580	22542	Economy	16200.00
0005433285275	22542	Economy	16200.00
0005433008582	22542	Economy	16200.00
0005433810500	22542	Economy	16200.00
0005433008597	22542	Economy	16200.00
0005433285274	22542	Economy	16200.00
0005433008602	22542	Economy	16200.00
0005433008603	22542	Economy	16200.00
0005433008606	22542	Economy	16200.00
0005433008572	22542	Economy	16200.00
0005433285268	22542	Economy	16200.00
0005433008565	22542	Economy	16200.00
0005433285294	22542	Economy	16200.00
0005433285271	22542	Economy	16200.00
0005433285284	22542	Economy	16200.00
0005433008581	22542	Economy	16200.00
0005433008567	22542	Economy	16200.00
0005433008598	22542	Economy	16200.00
0005433285278	22542	Economy	16200.00
0005433008575	22542	Economy	16200.00
0005433008604	22542	Economy	16200.00
0005433008608	22542	Economy	16200.00
0005433810499	22542	Economy	16200.00
0005433285272	22542	Economy	16200.00
0005433810502	22542	Economy	16200.00
0005433008571	22542	Economy	16200.00
0005433810501	22542	Economy	16200.00
0005433008569	22542	Economy	16200.00
0005433008594	22542	Economy	16200.00
0005433285290	22542	Economy	16200.00
0005433285291	22542	Economy	16200.00
0005433810504	22542	Economy	16200.00
0005433285264	22542	Economy	16200.00
0005433008579	22542	Economy	16200.00
0005433285269	22542	Economy	16200.00
0005433008595	22542	Economy	16200.00
0005433008601	22542	Economy	16200.00
0005433285266	22542	Economy	16200.00
0005433008574	22542	Economy	16200.00
0005433008576	22542	Economy	16200.00
0005433008591	22542	Economy	16200.00
0005433285267	22542	Economy	16200.00
0005433285292	22542	Economy	16200.00
0005433285273	22542	Economy	16200.00
0005433285283	22542	Economy	16200.00
0005433285293	22542	Economy	16200.00
0005433008586	22542	Economy	16200.00
0005433008599	22542	Economy	16200.00
0005433008570	22542	Economy	16200.00
0005433008610	22542	Economy	16200.00
0005433008566	22542	Economy	16200.00
0005433008607	22542	Economy	16200.00
0005433810505	22542	Economy	16200.00
0005433285285	22542	Economy	16200.00
0005433285265	22542	Economy	16200.00
0005433008578	22542	Economy	16200.00
0005433008590	22542	Economy	16200.00
0005433285281	22542	Economy	16200.00
0005433285277	22542	Economy	16200.00
0005433285280	22542	Economy	16200.00
0005432756840	25330	Business	83800.00
0005432756843	25330	Business	83800.00
0005432755070	25330	Business	83800.00
0005432755066	25330	Business	83800.00
0005434153522	25330	Business	83800.00
0005434153520	25330	Economy	27900.00
0005434153516	25330	Economy	27900.00
0005432755067	25330	Economy	27900.00
0005432755071	25330	Economy	30700.00
0005434152757	25330	Economy	30700.00
0005434153521	25330	Economy	27900.00
0005432756835	25330	Economy	27900.00
0005432756842	25330	Economy	27900.00
0005434152763	25330	Economy	27900.00
0005432755069	25330	Economy	27900.00
0005434152760	25330	Economy	27900.00
0005432755065	25330	Economy	27900.00
0005434152756	25330	Economy	27900.00
0005434153523	25330	Economy	27900.00
0005434152762	25330	Economy	27900.00
0005434152761	25330	Economy	27900.00
0005434153518	25330	Economy	27900.00
0005434153519	25330	Economy	27900.00
0005434152769	25330	Economy	27900.00
0005432755064	25330	Economy	27900.00
0005432756839	25330	Economy	27900.00
0005432756844	25330	Economy	27900.00
0005434152767	25330	Economy	27900.00
0005432756836	25330	Economy	27900.00
0005434152768	25330	Economy	27900.00
0005432756841	25330	Economy	27900.00
0005432756837	25330	Economy	27900.00
0005434152764	25330	Economy	27900.00
0005434152770	25330	Economy	27900.00
0005434152766	25330	Economy	27900.00
0005432756838	25330	Economy	27900.00
0005432755072	25330	Economy	27900.00
0005432755068	25330	Economy	27900.00
0005435282208	5563	Business	99800.00
0005433846731	5563	Business	99800.00
0005435282315	5563	Business	99800.00
0005433846719	5563	Business	99800.00
0005433846710	5563	Business	99800.00
0005433846708	5563	Business	99800.00
0005434173481	5563	Business	99800.00
0005435282314	5563	Business	99800.00
0005433846696	5563	Business	99800.00
0005435282252	5563	Business	99800.00
0005433846687	5563	Business	99800.00
0005433846734	5563	Business	99800.00
0005435282296	5563	Business	99800.00
0005433846735	5563	Business	99800.00
0005433846686	5563	Business	99800.00
0005435282225	5563	Business	99800.00
0005433846720	5563	Business	99800.00
0005433846692	5563	Economy	33300.00
0005435282239	5563	Business	99800.00
0005433815383	5563	Economy	33300.00
0005433815380	5563	Economy	33300.00
0005435282300	5563	Economy	33300.00
0005433846736	5563	Economy	33300.00
0005432081507	5563	Economy	33300.00
0005433846693	5563	Economy	33300.00
0005435282259	5563	Economy	33300.00
0005433846699	5563	Economy	33300.00
0005433846728	5563	Economy	33300.00
0005433846717	5563	Economy	33300.00
0005433846730	5563	Economy	33300.00
0005434173467	5563	Economy	36600.00
0005433846723	5563	Economy	36600.00
0005433846714	5563	Economy	36600.00
0005433846694	5563	Economy	33300.00
0005433846733	5563	Economy	33300.00
0005432081508	5563	Economy	33300.00
0005435282306	5563	Economy	33300.00
0005435282299	5563	Economy	33300.00
0005433846697	5563	Economy	33300.00
0005433846725	5563	Economy	33300.00
0005432081511	5563	Economy	33300.00
0005433846709	5563	Economy	33300.00
0005433846722	5563	Economy	33300.00
0005435282260	5563	Economy	33300.00
0005433815381	5563	Economy	33300.00
0005432081509	5563	Economy	33300.00
0005433815382	5563	Economy	33300.00
0005433846726	5563	Economy	33300.00
0005433846680	5563	Economy	33300.00
0005433846738	5563	Economy	33300.00
0005433846716	5563	Economy	33300.00
0005433846702	5563	Economy	33300.00
0005434173484	5563	Economy	33300.00
0005435282343	5563	Economy	33300.00
0005435282213	5563	Economy	33300.00
0005435282253	5563	Economy	33300.00
0005433846685	5563	Economy	33300.00
0005435282329	5563	Economy	33300.00
0005433846703	5563	Economy	33300.00
0005435282283	5563	Economy	33300.00
0005432081510	5563	Economy	33300.00
0005435282278	5563	Economy	33300.00
0005433846695	5563	Economy	33300.00
0005434173482	5563	Economy	33300.00
0005435282240	5563	Economy	33300.00
0005433846737	5563	Economy	33300.00
0005433846705	5563	Economy	33300.00
0005435282226	5563	Economy	33300.00
0005432081513	5563	Economy	33300.00
0005435282282	5563	Economy	33300.00
0005433846711	5563	Economy	33300.00
0005433846690	5563	Economy	33300.00
0005433846681	5563	Economy	33300.00
0005433846706	5563	Economy	33300.00
0005433846691	5563	Economy	33300.00
0005433846682	5563	Economy	33300.00
0005435282305	5563	Economy	33300.00
0005433846729	5563	Economy	33300.00
0005432081512	5563	Economy	33300.00
0005433846698	5563	Economy	33300.00
0005433846701	5563	Economy	33300.00
0005435282341	5563	Economy	33300.00
0005433846732	5563	Economy	33300.00
0005433846688	5563	Economy	33300.00
0005435282317	5563	Economy	33300.00
0005433846707	5563	Economy	33300.00
0005435282268	5563	Economy	33300.00
0005433846704	5563	Economy	33300.00
0005433846713	5563	Economy	33300.00
0005435282211	5563	Economy	33300.00
0005435282301	5563	Economy	33300.00
0005433846715	5563	Economy	33300.00
0005435282251	5563	Economy	33300.00
0005435282304	5563	Economy	33300.00
0005433846689	5563	Economy	33300.00
0005435282326	5563	Economy	33300.00
0005433846700	5563	Economy	33300.00
0005435282254	5563	Economy	33300.00
0005433846712	5563	Economy	33300.00
0005433846724	5563	Economy	33300.00
0005433846718	5563	Economy	33300.00
0005433846721	5563	Economy	33300.00
0005433846683	5563	Economy	33300.00
0005432081506	5563	Economy	33300.00
0005433846684	5563	Economy	33300.00
0005435282344	5563	Economy	33300.00
0005433846727	5563	Economy	33300.00
0005433846097	13883	Business	99800.00
0005433815352	13883	Business	99800.00
0005433815331	13883	Business	99800.00
0005433846474	13883	Business	99800.00
0005433846180	13883	Business	99800.00
0005433846026	13883	Business	99800.00
0005432003702	13883	Business	99800.00
0005433815344	13883	Business	99800.00
0005433846162	13883	Business	99800.00
0005435282501	13883	Business	99800.00
0005433846096	13883	Business	99800.00
0005433846245	13883	Business	99800.00
0005433846368	13883	Business	99800.00
0005433846067	13883	Business	99800.00
0005433846215	13883	Business	99800.00
0005433846114	13883	Business	99800.00
0005433846170	13883	Business	99800.00
0005433845966	13883	Economy	33300.00
0005433846409	13883	Economy	33300.00
0005435282513	13883	Economy	33300.00
0005433846267	13883	Economy	33300.00
0005435282509	13883	Economy	33300.00
0005433815322	13883	Economy	33300.00
0005433815332	13883	Economy	33300.00
0005435282511	13883	Economy	33300.00
0005433815321	13883	Economy	33300.00
0005435282503	13883	Economy	33300.00
0005433845688	13883	Economy	33300.00
0005435282506	13883	Economy	36600.00
0005433846240	13883	Economy	36600.00
0005433815323	13883	Economy	36600.00
0005433846438	13883	Economy	33300.00
0005432003700	13883	Economy	33300.00
0005433846115	13883	Economy	33300.00
0005433846049	13883	Economy	33300.00
0005433815349	13883	Economy	33300.00
0005433846270	13883	Economy	33300.00
0005433846166	13883	Economy	33300.00
0005433846305	13883	Economy	33300.00
0005433846316	13883	Economy	33300.00
0005433846315	13883	Economy	33300.00
0005433815353	13883	Economy	33300.00
0005433846042	13883	Economy	33300.00
0005433846058	13883	Economy	33300.00
0005433846278	13883	Economy	33300.00
0005433846313	13883	Economy	33300.00
0005435282512	13883	Economy	33300.00
0005433846246	13883	Economy	33300.00
0005435282504	13883	Economy	33300.00
0005433846304	13883	Economy	33300.00
0005433845956	13883	Economy	33300.00
0005433846105	13883	Economy	33300.00
0005433815320	13883	Economy	33300.00
0005433846004	13883	Economy	33300.00
0005433846430	13883	Economy	33300.00
0005433846314	13883	Economy	33300.00
0005433846155	13883	Economy	33300.00
0005433846231	13883	Economy	33300.00
0005433846209	13883	Economy	33300.00
0005432003701	13883	Economy	33300.00
0005433846279	13883	Economy	33300.00
0005434173521	13883	Economy	33300.00
0005435282515	13883	Economy	33300.00
0005433815350	13883	Economy	33300.00
0005433846331	13883	Economy	33300.00
0005433846299	13883	Economy	33300.00
0005434173520	13883	Economy	33300.00
0005433846165	13883	Economy	33300.00
0005435282508	13883	Economy	33300.00
0005433846059	13883	Economy	33300.00
0005432003699	13883	Economy	33300.00
0005433846107	13883	Economy	33300.00
0005433815337	13883	Economy	33300.00
0005433846005	13883	Economy	33300.00
0005435282514	13883	Economy	33300.00
0005433815355	13883	Economy	33300.00
0005435282510	13883	Economy	33300.00
0005433815330	13883	Economy	33300.00
0005433846191	13883	Economy	33300.00
0005433846216	13883	Economy	33300.00
0005433815310	13883	Economy	33300.00
0005433846113	13883	Economy	33300.00
0005433846219	13883	Economy	33300.00
0005433846210	13883	Economy	33300.00
0005434173519	13883	Economy	33300.00
0005433846041	13883	Economy	33300.00
0005434173518	13883	Economy	33300.00
0005433845689	13883	Economy	33300.00
0005433846300	13883	Economy	33300.00
0005433846292	13883	Economy	33300.00
0005433846156	13883	Economy	33300.00
0005433846225	13883	Economy	33300.00
0005433846192	13883	Economy	33300.00
0005433846367	13883	Economy	33300.00
0005435282500	13883	Economy	33300.00
0005433846354	13883	Economy	33300.00
0005435282505	13883	Economy	33300.00
0005433846048	13883	Economy	33300.00
0005433846218	13883	Economy	33300.00
0005435282502	13883	Economy	33300.00
0005435282507	13883	Economy	33300.00
0005435332295	7836	Economy	16600.00
0005434620587	7836	Economy	16600.00
0005435332206	7836	Economy	16600.00
0005435332240	7836	Economy	16600.00
0005434620593	7836	Economy	15100.00
0005434620600	7836	Economy	15100.00
0005432112515	7836	Economy	15100.00
0005434620584	7836	Economy	15100.00
0005435332252	7836	Economy	15100.00
0005435332241	7836	Economy	15100.00
0005434620597	7836	Economy	15100.00
0005434620596	7836	Economy	15100.00
0005432112517	7836	Economy	15100.00
0005435332207	7836	Economy	15100.00
0005435332245	7836	Economy	15100.00
0005435332230	7836	Economy	15100.00
0005435332257	7836	Economy	15100.00
0005435332234	7836	Economy	15100.00
0005435332258	7836	Economy	15100.00
0005434620580	7836	Economy	15100.00
0005434620581	7836	Economy	15100.00
0005432112514	7836	Economy	15100.00
0005434620590	7836	Economy	15100.00
0005434620601	7836	Economy	15100.00
0005434620583	7836	Economy	15100.00
0005435332253	7836	Economy	15100.00
0005435332284	7836	Economy	15100.00
0005434620585	7836	Economy	15100.00
0005434620595	7836	Economy	15100.00
0005434620591	7836	Economy	15100.00
0005434620588	7836	Economy	15100.00
0005434620589	7836	Economy	15100.00
0005434620599	7836	Economy	15100.00
0005435332277	7836	Economy	15100.00
0005434620594	7836	Economy	15100.00
0005434620592	7836	Economy	15100.00
0005435332278	7836	Economy	15100.00
0005434620586	7836	Economy	15100.00
0005434620598	7836	Economy	15100.00
0005435332235	7836	Economy	15100.00
0005435332254	7836	Economy	15100.00
0005435332276	7836	Economy	15100.00
0005432112516	7836	Economy	15100.00
0005434620582	7836	Economy	15100.00
0005435332332	32952	Economy	16600.00
0005434620395	32952	Economy	16600.00
0005435332338	32952	Economy	16600.00
0005435332334	32952	Economy	15100.00
0005434620396	32952	Economy	15100.00
0005434620388	32952	Economy	15100.00
0005435332337	32952	Economy	15100.00
0005435332333	32952	Economy	15100.00
0005434620435	32952	Economy	15100.00
0005434620495	32952	Economy	15100.00
0005434620415	32952	Economy	15100.00
0005435332331	32952	Economy	15100.00
0005434620436	32952	Economy	15100.00
0005434620381	32952	Economy	15100.00
0005434620389	32952	Economy	15100.00
0005434620373	32952	Economy	15100.00
0005434620324	32952	Economy	15100.00
0005435332330	32952	Economy	15100.00
0005434620407	32952	Economy	15100.00
0005435332329	32952	Economy	15100.00
0005434620322	32952	Economy	15100.00
0005434620325	32952	Economy	15100.00
0005434620323	32952	Economy	15100.00
0005435332335	32952	Economy	15100.00
0005435332328	32952	Economy	15100.00
0005434620426	32952	Economy	15100.00
0005434620289	32952	Economy	15100.00
0005434620460	32952	Economy	15100.00
0005435332336	32952	Economy	15100.00
0005434620357	32952	Economy	15100.00
0005434620471	32952	Economy	15100.00
0005434620433	32952	Economy	15100.00
0005435787354	4308	Business	38000.00
0005434994023	4308	Business	38000.00
0005435937343	4308	Business	38000.00
0005435785334	4308	Business	38000.00
0005434994025	4308	Business	38000.00
0005435785357	4308	Business	38000.00
0005435937366	4308	Business	38000.00
0005435785332	4308	Economy	12700.00
0005435785337	4308	Economy	12700.00
0005435785359	4308	Economy	12700.00
0005435918619	4308	Economy	12700.00
0005435785341	4308	Economy	12700.00
0005435785333	4308	Economy	12700.00
0005435785364	4308	Economy	12700.00
0005435785338	4308	Economy	13900.00
0005435937330	4308	Economy	13900.00
0005435785340	4308	Economy	13900.00
0005434994024	4308	Economy	12700.00
0005434994020	4308	Economy	12700.00
0005435937342	4308	Economy	12700.00
0005435785352	4308	Economy	12700.00
0005435785355	4308	Economy	12700.00
0005432190630	4308	Economy	12700.00
0005435785350	4308	Economy	12700.00
0005435785349	4308	Economy	12700.00
0005432190628	4308	Economy	12700.00
0005435785343	4308	Economy	12700.00
0005435785356	4308	Economy	12700.00
0005435785360	4308	Economy	12700.00
0005435785351	4308	Economy	12700.00
0005434994018	4308	Economy	12700.00
0005434994019	4308	Economy	12700.00
0005435937331	4308	Economy	12700.00
0005435785354	4308	Economy	12700.00
0005435785362	4308	Economy	12700.00
0005435785363	4308	Economy	12700.00
0005435918602	4308	Economy	12700.00
0005435918601	4308	Economy	12700.00
0005435785344	4308	Economy	12700.00
0005435785339	4308	Economy	12700.00
0005435785347	4308	Economy	12700.00
0005435785361	4308	Economy	12700.00
0005435785346	4308	Economy	12700.00
0005435785345	4308	Economy	12700.00
0005435785358	4308	Economy	12700.00
0005434994016	4308	Economy	12700.00
0005435785331	4308	Economy	12700.00
0005434994021	4308	Economy	12700.00
0005435785348	4308	Economy	12700.00
0005435785335	4308	Economy	12700.00
0005432190629	4308	Economy	12700.00
0005435785353	4308	Economy	12700.00
0005435918617	4308	Economy	12700.00
0005434994017	4308	Economy	12700.00
0005434994015	4308	Economy	12700.00
0005435785336	4308	Economy	12700.00
0005435785342	4308	Economy	12700.00
0005435937365	4308	Economy	12700.00
0005434994022	4308	Economy	12700.00
0005435785115	27299	Business	38000.00
0005435937384	27299	Business	38000.00
0005435785002	27299	Business	38000.00
0005434993926	27299	Business	38000.00
0005435784975	27299	Business	38000.00
0005435918656	27299	Business	38000.00
0005434993899	27299	Economy	12700.00
0005435784963	27299	Economy	12700.00
0005434993946	27299	Economy	12700.00
0005434993919	27299	Economy	12700.00
0005435784764	27299	Economy	12700.00
0005435784867	27299	Economy	12700.00
0005434993958	27299	Economy	13900.00
0005434993911	27299	Economy	13900.00
0005434993900	27299	Economy	13900.00
0005435784922	27299	Economy	13900.00
0005435785011	27299	Economy	12700.00
0005435784977	27299	Economy	12700.00
0005435937385	27299	Economy	12700.00
0005435784801	27299	Economy	12700.00
0005435785065	27299	Economy	12700.00
0005435784985	27299	Economy	12700.00
0005435785021	27299	Economy	12700.00
0005434993929	27299	Economy	12700.00
0005435785020	27299	Economy	12700.00
0005434993924	27299	Economy	12700.00
0005435784976	27299	Economy	12700.00
0005435784827	27299	Economy	12700.00
0005435785082	27299	Economy	12700.00
0005435784864	27299	Economy	12700.00
0005435784939	27299	Economy	12700.00
0005435784843	27299	Economy	12700.00
0005435784882	27299	Economy	12700.00
0005435785081	27299	Economy	12700.00
0005435937386	27299	Economy	12700.00
0005435784958	27299	Economy	12700.00
0005435785077	27299	Economy	12700.00
0005435785016	27299	Economy	12700.00
0005435784998	27299	Economy	12700.00
0005435937383	27299	Economy	12700.00
0005435937387	27299	Economy	12700.00
0005435937388	27299	Economy	12700.00
0005435784839	27299	Economy	12700.00
0005435785033	27299	Economy	12700.00
0005435918652	27299	Economy	12700.00
0005435784866	27299	Economy	12700.00
0005434993910	27299	Economy	12700.00
0005435918654	27299	Economy	12700.00
0005434993928	27299	Economy	12700.00
0005435784942	27299	Economy	12700.00
0005435784974	27299	Economy	12700.00
0005435784959	27299	Economy	12700.00
0005435784978	27299	Economy	12700.00
0005435918655	27299	Economy	12700.00
0005435785019	27299	Economy	12700.00
0005435787329	27299	Economy	12700.00
0005435918653	27299	Economy	12700.00
0005435784865	27299	Economy	12700.00
0005432146196	19870	Economy	12800.00
0005432146197	19870	Economy	12800.00
0005432146198	19870	Economy	12800.00
0005432459816	4729	Business	40900.00
0005432567600	4729	Business	40900.00
0005432567611	4729	Business	40900.00
0005432170382	4729	Business	40900.00
0005432567594	4729	Business	40900.00
0005432459838	4729	Business	40900.00
0005434081908	4729	Business	40900.00
0005434081907	4729	Business	40900.00
0005432567609	4729	Business	40900.00
0005432567627	4729	Business	40900.00
0005432567635	4729	Business	40900.00
0005432567639	4729	Business	40900.00
0005432567633	4729	Business	40900.00
0005434081898	4729	Business	40900.00
0005432567626	4729	Business	40900.00
0005432567593	4729	Business	40900.00
0005432567643	4729	Business	40900.00
0005432567601	4729	Business	40900.00
0005434081895	4729	Business	40900.00
0005432567649	4729	Business	40900.00
0005432459848	4729	Business	40900.00
0005432567597	4729	Business	40900.00
0005433452738	4729	Economy	15000.00
0005432459826	4729	Economy	15000.00
0005433451620	4729	Economy	15000.00
0005432459836	4729	Economy	13600.00
0005432567641	4729	Economy	13600.00
0005432567642	4729	Economy	13600.00
0005432459852	4729	Economy	13600.00
0005432567590	4729	Economy	13600.00
0005432170388	4729	Economy	13600.00
0005432459843	4729	Economy	13600.00
0005432459845	4729	Economy	13600.00
0005432567608	4729	Economy	13600.00
0005432567648	4729	Economy	13600.00
0005432459824	4729	Economy	13600.00
0005432459817	4729	Economy	13600.00
0005434081910	4729	Economy	13600.00
0005432186869	4729	Economy	13600.00
0005432571324	4729	Economy	13600.00
0005433726103	4729	Economy	13600.00
0005432567634	4729	Economy	13600.00
0005432459858	4729	Economy	13600.00
0005432567645	4729	Economy	13600.00
0005434081904	4729	Economy	13600.00
0005432571321	4729	Economy	13600.00
0005434081913	4729	Economy	13600.00
0005434081902	4729	Economy	13600.00
0005432459847	4729	Economy	13600.00
0005432459829	4729	Economy	13600.00
0005434081916	4729	Economy	13600.00
0005432459823	4729	Economy	13600.00
0005432459837	4729	Economy	13600.00
0005432567618	4729	Economy	13600.00
0005432567646	4729	Economy	13600.00
0005434081903	4729	Economy	13600.00
0005432170386	4729	Economy	13600.00
0005432571323	4729	Economy	13600.00
0005432459849	4729	Economy	13600.00
0005432459820	4729	Economy	13600.00
0005432459830	4729	Economy	13600.00
0005432567636	4729	Economy	13600.00
0005432170383	4729	Economy	13600.00
0005432567630	4729	Economy	13600.00
0005432567620	4729	Economy	13600.00
0005432459862	4729	Economy	13600.00
0005434081901	4729	Economy	13600.00
0005432567598	4729	Economy	13600.00
0005432567603	4729	Economy	13600.00
0005432186868	4729	Economy	13600.00
0005432459840	4729	Economy	13600.00
0005432459853	4729	Economy	13600.00
0005432459857	4729	Economy	13600.00
0005432567631	4729	Economy	13600.00
0005433726104	4729	Economy	13600.00
0005432459813	4729	Economy	13600.00
0005432459822	4729	Economy	13600.00
0005432459844	4729	Economy	13600.00
0005432567638	4729	Economy	13600.00
0005432459819	4729	Economy	13600.00
0005433451619	4729	Economy	13600.00
0005432567602	4729	Economy	13600.00
0005432567637	4729	Economy	13600.00
0005432459851	4729	Economy	13600.00
0005432567612	4729	Economy	13600.00
0005432567595	4729	Economy	13600.00
0005432567604	4729	Economy	13600.00
0005432459835	4729	Economy	13600.00
0005434081912	4729	Economy	13600.00
0005432567615	4729	Economy	13600.00
0005434081905	4729	Economy	13600.00
0005432459834	4729	Economy	13600.00
0005432459821	4729	Economy	13600.00
0005432459827	4729	Economy	13600.00
0005432567606	4729	Economy	13600.00
0005432459814	4729	Economy	13600.00
0005433451618	4729	Economy	13600.00
0005434081896	4729	Economy	13600.00
0005432567591	4729	Economy	13600.00
0005434081917	4729	Economy	13600.00
0005432567640	4729	Economy	15000.00
0005432459855	4729	Economy	13600.00
0005434081894	4729	Economy	15000.00
0005434081900	4729	Economy	13600.00
0005432571320	4729	Economy	13600.00
0005432567614	4729	Economy	13600.00
0005432459828	4729	Economy	13600.00
0005432567610	4729	Economy	13600.00
0005432567619	4729	Economy	13600.00
0005432459846	4729	Economy	13600.00
0005434081899	4729	Economy	13600.00
0005432567647	4729	Economy	13600.00
0005432571322	4729	Economy	13600.00
0005432567623	4729	Economy	13600.00
0005432459842	4729	Economy	13600.00
0005432567629	4729	Economy	13600.00
0005432567622	4729	Economy	13600.00
0005432459850	4729	Economy	13600.00
0005432170387	4729	Economy	13600.00
0005432567632	4729	Economy	13600.00
0005432459856	4729	Economy	13600.00
0005432459854	4729	Economy	13600.00
0005432567628	4729	Economy	13600.00
0005432459818	4729	Economy	13600.00
0005432567605	4729	Economy	13600.00
0005432186870	4729	Economy	13600.00
0005432459861	4729	Economy	13600.00
0005432170385	4729	Economy	13600.00
0005432567616	4729	Economy	13600.00
0005432459859	4729	Economy	13600.00
0005434081892	4729	Economy	13600.00
0005432567607	4729	Economy	13600.00
0005432170384	4729	Economy	13600.00
0005432567599	4729	Economy	13600.00
0005432567625	4729	Economy	13600.00
0005434081915	4729	Economy	13600.00
0005434081909	4729	Economy	13600.00
0005432567592	4729	Economy	13600.00
0005432459833	4729	Economy	13600.00
0005434081914	4729	Economy	13600.00
0005432567650	4729	Economy	13600.00
0005432567596	4729	Economy	13600.00
0005432567613	4729	Economy	13600.00
0005433452739	4729	Economy	13600.00
0005434081906	4729	Economy	13600.00
0005432186867	4729	Economy	13600.00
0005434081897	4729	Economy	13600.00
0005432459832	4729	Economy	13600.00
0005432459860	4729	Economy	13600.00
0005434081911	4729	Economy	13600.00
0005432567644	4729	Economy	13600.00
0005434081893	4729	Economy	13600.00
0005432459831	4729	Economy	13600.00
0005432567624	4729	Economy	13600.00
0005432459825	4729	Economy	13600.00
0005432459863	4729	Economy	13600.00
0005432459841	4729	Economy	13600.00
0005432459815	4729	Economy	13600.00
0005432567621	4729	Economy	13600.00
0005432567617	4729	Economy	13600.00
0005432459839	4729	Economy	13600.00
0005434081697	30527	Business	40900.00
0005432567502	30527	Business	40900.00
0005432567148	30527	Business	40900.00
0005432459339	30527	Business	40900.00
0005432567054	30527	Business	40900.00
0005432567129	30527	Business	40900.00
0005432459409	30527	Business	40900.00
0005432567213	30527	Business	40900.00
0005434081744	30527	Business	40900.00
0005432459393	30527	Business	40900.00
0005432567242	30527	Business	40900.00
0005434081678	30527	Business	40900.00
0005432567379	30527	Business	40900.00
0005434081723	30527	Business	40900.00
0005432566985	30527	Business	40900.00
0005432567031	30527	Business	40900.00
0005432567469	30527	Business	40900.00
0005433454856	30527	Business	40900.00
0005432567109	30527	Economy	15000.00
0005432567036	30527	Economy	15000.00
0005434081680	30527	Economy	15000.00
0005434081604	30527	Economy	13600.00
0005432459328	30527	Economy	13600.00
0005433454852	30527	Economy	13600.00
0005432567244	30527	Economy	13600.00
0005432459383	30527	Economy	13600.00
0005432459602	30527	Economy	13600.00
0005432459232	30527	Economy	13600.00
0005432567328	30527	Economy	13600.00
0005432566929	30527	Economy	13600.00
0005432567017	30527	Economy	13600.00
0005434081695	30527	Economy	13600.00
0005434081679	30527	Economy	13600.00
0005432567226	30527	Economy	13600.00
0005432459542	30527	Economy	13600.00
0005432459240	30527	Economy	13600.00
0005432213605	30527	Economy	13600.00
0005434081719	30527	Economy	13600.00
0005432459730	30527	Economy	13600.00
0005434081653	30527	Economy	13600.00
0005433454857	30527	Economy	13600.00
0005432459414	30527	Economy	13600.00
0005432567162	30527	Economy	13600.00
0005432567163	30527	Economy	13600.00
0005432566930	30527	Economy	13600.00
0005432567304	30527	Economy	13600.00
0005434081664	30527	Economy	13600.00
0005432459447	30527	Economy	13600.00
0005432567130	30527	Economy	13600.00
0005432459422	30527	Economy	13600.00
0005432459580	30527	Economy	13600.00
0005432567102	30527	Economy	13600.00
0005434081602	30527	Economy	13600.00
0005434081638	30527	Economy	13600.00
0005432459512	30527	Economy	13600.00
0005432567074	30527	Economy	13600.00
0005432459501	30527	Economy	13600.00
0005433454853	30527	Economy	13600.00
0005432459417	30527	Economy	13600.00
0005432571295	30527	Economy	13600.00
0005432567503	30527	Economy	13600.00
0005432567218	30527	Economy	13600.00
0005432567202	30527	Economy	13600.00
0005434081707	30527	Economy	13600.00
0005432459499	30527	Economy	13600.00
0005432567101	30527	Economy	13600.00
0005432459296	30527	Economy	13600.00
0005432567089	30527	Economy	13600.00
0005434081722	30527	Economy	13600.00
0005432567225	30527	Economy	13600.00
0005432459256	30527	Economy	13600.00
0005432566876	30527	Economy	13600.00
0005432567224	30527	Economy	13600.00
0005432459295	30527	Economy	13600.00
0005432567177	30527	Economy	13600.00
0005432459410	30527	Economy	13600.00
0005432459448	30527	Economy	13600.00
0005432567071	30527	Economy	13600.00
0005432459418	30527	Economy	13600.00
0005432459604	30527	Economy	13600.00
0005434081656	30527	Economy	13600.00
0005432213604	30527	Economy	13600.00
0005432567082	30527	Economy	13600.00
0005432567254	30527	Economy	13600.00
0005432459324	30527	Economy	13600.00
0005432459423	30527	Economy	13600.00
0005432567173	30527	Economy	13600.00
0005434081573	30527	Economy	13600.00
0005432567064	30527	Economy	13600.00
0005432567222	30527	Economy	13600.00
0005432567286	30527	Economy	13600.00
0005432567266	30527	Economy	13600.00
0005432459394	30527	Economy	13600.00
0005434081654	30527	Economy	15000.00
0005432567094	30527	Economy	13600.00
0005432213606	30527	Economy	15000.00
0005432566880	30527	Economy	13600.00
0005432459403	30527	Economy	15000.00
0005432567043	30527	Economy	13600.00
0005432459415	30527	Economy	13600.00
0005432571302	30527	Economy	13600.00
0005432459123	30527	Economy	13600.00
0005432459412	30527	Economy	13600.00
0005432567305	30527	Economy	13600.00
0005432459603	30527	Economy	13600.00
0005432459440	30527	Economy	13600.00
0005432459477	30527	Economy	13600.00
0005432161151	30527	Economy	13600.00
0005432459520	30527	Economy	13600.00
0005432567331	30527	Economy	13600.00
0005432567358	30527	Economy	13600.00
0005432567052	30527	Economy	13600.00
0005434081636	30527	Economy	13600.00
0005432459416	30527	Economy	13600.00
0005432459460	30527	Economy	13600.00
0005432459451	30527	Economy	13600.00
0005432567295	30527	Economy	13600.00
0005434081694	30527	Economy	13600.00
0005434081626	30527	Economy	13600.00
0005432459519	30527	Economy	13600.00
0005432213607	30527	Economy	13600.00
0005432567180	30527	Economy	13600.00
0005434081733	30527	Economy	13600.00
0005432567223	30527	Economy	13600.00
0005432567243	30527	Economy	13600.00
0005432567175	30527	Economy	13600.00
0005432459317	30527	Economy	13600.00
0005432567208	30527	Economy	13600.00
0005432566984	30527	Economy	13600.00
0005432459282	30527	Economy	13600.00
0005432459476	30527	Economy	13600.00
0005432459513	30527	Economy	13600.00
0005432571277	30527	Economy	13600.00
0005434081603	30527	Economy	13600.00
0005432459332	30527	Economy	13600.00
0005432459481	30527	Economy	13600.00
0005432459400	30527	Economy	13600.00
0005432567018	30527	Economy	13600.00
0005432459419	30527	Economy	13600.00
0005432161152	30527	Economy	13600.00
0005432459424	30527	Economy	13600.00
0005432567010	30527	Economy	13600.00
0005433452723	30527	Economy	13600.00
0005432459360	30527	Economy	13600.00
0005432459500	30527	Economy	13600.00
0005432567051	30527	Economy	13600.00
0005432459361	30527	Economy	13600.00
0005432459371	30527	Economy	13600.00
0005432459239	30527	Economy	13600.00
0005432459452	30527	Economy	13600.00
0005435720824	13673	Economy	9900.00
0005435720822	13673	Economy	9900.00
0005435722054	13673	Economy	9900.00
0005435720823	13673	Economy	9900.00
0005435722055	13673	Economy	9900.00
0005435722036	21133	Economy	9900.00
0005435722037	21133	Economy	9900.00
0005435722022	21133	Economy	9900.00
0005435722031	21133	Economy	9900.00
0005432295880	22757	Economy	9700.00
0005432295879	22757	Economy	8800.00
0005432295878	22757	Economy	8800.00
0005433343161	11090	Business	23600.00
0005433343136	11090	Business	23600.00
0005433343124	11090	Business	23600.00
0005433343135	11090	Business	23600.00
0005433343190	11090	Business	23600.00
0005433343154	11090	Business	23600.00
0005433343168	11090	Business	23600.00
0005433343149	11090	Business	23600.00
0005433343196	11090	Business	23600.00
0005433343210	11090	Business	23600.00
0005435380258	11090	Business	23600.00
0005433343198	11090	Economy	7900.00
0005433343194	11090	Economy	7900.00
0005433343117	11090	Economy	7900.00
0005435097196	11090	Economy	7900.00
0005433343146	11090	Economy	7900.00
0005433343209	11090	Economy	7900.00
0005435097191	11090	Economy	7900.00
0005433343212	11090	Economy	7900.00
0005433343120	11090	Economy	7900.00
0005433343143	11090	Economy	7900.00
0005433343116	11090	Economy	7900.00
0005435508246	11090	Economy	7900.00
0005433343195	11090	Economy	7900.00
0005433343140	11090	Economy	7900.00
0005435508202	11090	Economy	7900.00
0005433343158	11090	Economy	7900.00
0005433343205	11090	Economy	7900.00
0005433343181	11090	Economy	7900.00
0005435508283	11090	Economy	7900.00
0005433343211	11090	Economy	7900.00
0005433343167	11090	Economy	7900.00
0005435508277	11090	Economy	7900.00
0005433343166	11090	Economy	7900.00
0005433343151	11090	Economy	7900.00
0005433343157	11090	Economy	7900.00
0005433343141	11090	Economy	7900.00
0005433343207	11090	Economy	7900.00
0005433343155	11090	Economy	7900.00
0005433343191	11090	Economy	7900.00
0005433343175	11090	Economy	7900.00
0005433343165	11090	Economy	7900.00
0005433343150	11090	Economy	7900.00
0005435508250	11090	Economy	7900.00
0005433343111	11090	Economy	7900.00
0005433343139	11090	Economy	7900.00
0005433343144	11090	Economy	7900.00
0005433343183	11090	Economy	7900.00
0005433343153	11090	Economy	7900.00
0005433343160	11090	Economy	8600.00
0005433343132	11090	Economy	8600.00
0005435097193	11090	Economy	8600.00
0005433343174	11090	Economy	8600.00
0005433343189	11090	Economy	8600.00
0005433343176	11090	Economy	7900.00
0005435097198	11090	Economy	8600.00
0005433343177	11090	Economy	7900.00
0005433343137	11090	Economy	7900.00
0005435508262	11090	Economy	7900.00
0005433343112	11090	Economy	7900.00
0005433343208	11090	Economy	7900.00
0005433343133	11090	Economy	7900.00
0005435097194	11090	Economy	7900.00
0005433343171	11090	Economy	7900.00
0005433343185	11090	Economy	7900.00
0005433343199	11090	Economy	7900.00
0005435508247	11090	Economy	7900.00
0005433343130	11090	Economy	7900.00
0005433343113	11090	Economy	7900.00
0005433343127	11090	Economy	7900.00
0005433343115	11090	Economy	7900.00
0005435097190	11090	Economy	7900.00
0005435380259	11090	Economy	7900.00
0005435097195	11090	Economy	7900.00
0005433343152	11090	Economy	7900.00
0005433343126	11090	Economy	7900.00
0005433343192	11090	Economy	7900.00
0005433343148	11090	Economy	7900.00
0005433343123	11090	Economy	7900.00
0005433343164	11090	Economy	7900.00
0005433343134	11090	Economy	7900.00
0005433343145	11090	Economy	7900.00
0005435380257	11090	Economy	7900.00
0005435097197	11090	Economy	7900.00
0005433343128	11090	Economy	7900.00
0005433343184	11090	Economy	7900.00
0005435508201	11090	Economy	7900.00
0005433343180	11090	Economy	7900.00
0005433343179	11090	Economy	7900.00
0005433343118	11090	Economy	7900.00
0005433343182	11090	Economy	7900.00
0005433343204	11090	Economy	7900.00
0005433343159	11090	Economy	7900.00
0005433343202	11090	Economy	7900.00
0005433343119	11090	Economy	7900.00
0005433343188	11090	Economy	7900.00
0005433343197	11090	Economy	7900.00
0005433343200	11090	Economy	7900.00
0005433343142	11090	Economy	7900.00
0005433343169	11090	Economy	7900.00
0005433343172	11090	Economy	7900.00
0005433343187	11090	Economy	7900.00
0005435508266	11090	Economy	7900.00
0005433343201	11090	Economy	7900.00
0005433343138	11090	Economy	7900.00
0005433343162	11090	Economy	7900.00
0005433343170	11090	Economy	7900.00
0005433343114	11090	Economy	7900.00
0005433343121	11090	Economy	7900.00
0005433343122	11090	Economy	7900.00
0005433343193	11090	Economy	7900.00
0005433343186	11090	Economy	7900.00
0005435508279	11090	Economy	7900.00
0005433343178	11090	Economy	7900.00
0005433343206	11090	Economy	7900.00
0005435097192	11090	Economy	7900.00
0005435380230	11090	Economy	7900.00
0005433343131	11090	Economy	7900.00
0005433343173	11090	Economy	7900.00
0005433343156	11090	Economy	7900.00
0005433343147	11090	Economy	7900.00
0005433343129	11090	Economy	7900.00
0005435508276	11090	Economy	7900.00
0005433343125	11090	Economy	7900.00
0005433343163	11090	Economy	7900.00
0005433343203	11090	Economy	7900.00
0005433342023	17110	Business	23600.00
0005433341912	17110	Business	23600.00
0005433342274	17110	Business	23600.00
0005435545738	17110	Business	23600.00
0005433342270	17110	Business	23600.00
0005433341881	17110	Business	23600.00
0005433342210	17110	Business	23600.00
0005433342297	17110	Business	23600.00
0005433342373	17110	Business	23600.00
0005435097134	17110	Business	23600.00
0005433342196	17110	Business	23600.00
0005433342109	17110	Business	23600.00
0005433342118	17110	Economy	7900.00
0005435545739	17110	Economy	7900.00
0005435097098	17110	Economy	7900.00
0005433341923	17110	Economy	7900.00
0005433342165	17110	Economy	7900.00
0005433341613	17110	Economy	7900.00
0005433342327	17110	Economy	7900.00
0005433342265	17110	Economy	7900.00
0005433342514	17110	Economy	7900.00
0005433341916	17110	Economy	7900.00
0005433342493	17110	Economy	7900.00
0005433342381	17110	Economy	7900.00
0005435380298	17110	Economy	7900.00
0005433341617	17110	Economy	7900.00
0005433342527	17110	Economy	7900.00
0005433341913	17110	Economy	7900.00
0005433341799	17110	Economy	7900.00
0005433341944	17110	Economy	7900.00
0005433341911	17110	Economy	7900.00
0005433342378	17110	Economy	7900.00
0005433342413	17110	Economy	7900.00
0005433342105	17110	Economy	7900.00
0005433341980	17110	Economy	7900.00
0005433342330	17110	Economy	7900.00
0005433342440	17110	Economy	7900.00
0005433342058	17110	Economy	7900.00
0005433342106	17110	Economy	7900.00
0005433341614	17110	Economy	7900.00
0005433341882	17110	Economy	7900.00
0005433342237	17110	Economy	7900.00
0005433341902	17110	Economy	7900.00
0005433342155	17110	Economy	7900.00
0005433342192	17110	Economy	7900.00
0005433341978	17110	Economy	7900.00
0005433342364	17110	Economy	7900.00
0005433341931	17110	Economy	7900.00
0005435097090	17110	Economy	7900.00
0005433342412	17110	Economy	7900.00
0005433341883	17110	Economy	7900.00
0005435380294	17110	Economy	7900.00
0005433342372	17110	Economy	8600.00
0005433342218	17110	Economy	8600.00
0005433341940	17110	Economy	8600.00
0005435380296	17110	Economy	8600.00
0005433342016	17110	Economy	8600.00
0005433341914	17110	Economy	8600.00
0005435380295	17110	Economy	7900.00
0005433342077	17110	Economy	7900.00
0005433342213	17110	Economy	7900.00
0005433342239	17110	Economy	7900.00
0005433342022	17110	Economy	7900.00
0005433342526	17110	Economy	7900.00
0005433342296	17110	Economy	7900.00
0005433341894	17110	Economy	7900.00
0005433342229	17110	Economy	7900.00
0005433342369	17110	Economy	7900.00
0005433342238	17110	Economy	7900.00
0005433342718	17110	Economy	7900.00
0005435545737	17110	Economy	7900.00
0005433342374	17110	Economy	7900.00
0005433342088	17110	Economy	7900.00
0005433342083	17110	Economy	7900.00
0005433342273	17110	Economy	7900.00
0005433342475	17110	Economy	7900.00
0005433341979	17110	Economy	7900.00
0005433342000	17110	Economy	7900.00
0005433342240	17110	Economy	7900.00
0005433342232	17110	Economy	7900.00
0005435097120	17110	Economy	7900.00
0005433342375	17110	Economy	7900.00
0005433341933	17110	Economy	7900.00
0005433342405	17110	Economy	7900.00
0005433342180	17110	Economy	7900.00
0005433342209	17110	Economy	7900.00
0005433342534	17110	Economy	7900.00
0005433342204	17110	Economy	7900.00
0005432293208	17110	Economy	7900.00
0005433341999	17110	Economy	7900.00
0005433341922	17110	Economy	7900.00
0005433341952	17110	Economy	7900.00
0005433341481	17110	Economy	7900.00
0005435097121	17110	Economy	7900.00
0005433341973	17110	Economy	7900.00
0005433342515	17110	Economy	7900.00
0005433342107	17110	Economy	7900.00
0005435545740	17110	Economy	7900.00
0005433342361	17110	Economy	7900.00
0005432293207	17110	Economy	7900.00
0005433342393	17110	Economy	7900.00
0005435380297	17110	Economy	7900.00
0005433342142	17110	Economy	7900.00
0005433342181	17110	Economy	7900.00
0005433341930	17110	Economy	7900.00
0005433341622	17110	Economy	7900.00
0005433342197	17110	Economy	7900.00
0005433341932	17110	Economy	7900.00
0005432293209	17110	Economy	7900.00
0005433342326	17110	Economy	7900.00
0005433341480	17110	Economy	7900.00
0005433341621	17110	Economy	7900.00
0005433341779	17110	Economy	7900.00
0005433341809	17110	Economy	7900.00
0005433342432	17110	Economy	7900.00
0005433342174	17110	Economy	7900.00
0005433342298	17110	Economy	7900.00
0005433341868	17110	Economy	7900.00
0005433341798	17110	Economy	7900.00
0005435545736	17110	Economy	7900.00
0005433342219	17110	Economy	7900.00
0005433342459	17110	Economy	7900.00
0005433342230	17110	Economy	7900.00
0005435097122	17110	Economy	7900.00
0005433342260	17110	Economy	7900.00
0005433341616	17110	Economy	7900.00
0005433342563	17110	Economy	7900.00
0005433342228	17110	Economy	7900.00
0005433342370	17110	Economy	7900.00
0005433342124	17110	Economy	7900.00
0005432919593	9075	Business	26600.00
0005432919724	9075	Business	26600.00
0005432919690	9075	Business	26600.00
0005434158956	9075	Business	26600.00
0005432919727	9075	Business	26600.00
0005432919673	9075	Economy	8900.00
0005432919645	9075	Economy	8900.00
0005433507190	9075	Economy	8900.00
0005433507186	9075	Economy	9800.00
0005433507178	9075	Economy	9800.00
0005433507179	9075	Economy	9800.00
0005433481169	9075	Economy	8900.00
0005432919726	9075	Economy	8900.00
0005432919708	9075	Economy	8900.00
0005433507188	9075	Economy	8900.00
0005433507182	9075	Economy	8900.00
0005434158954	9075	Economy	8900.00
0005433507177	9075	Economy	8900.00
0005433507180	9075	Economy	8900.00
0005433481166	9075	Economy	8900.00
0005432919700	9075	Economy	8900.00
0005432919691	9075	Economy	8900.00
0005432919592	9075	Economy	8900.00
0005433481165	9075	Economy	8900.00
0005432919671	9075	Economy	8900.00
0005433481167	9075	Economy	8900.00
0005432919665	9075	Economy	8900.00
0005433507185	9075	Economy	8900.00
0005432919699	9075	Economy	8900.00
0005434158955	9075	Economy	8900.00
0005433481164	9075	Economy	8900.00
0005433507183	9075	Economy	8900.00
0005432919674	9075	Economy	8900.00
0005432919633	9075	Economy	8900.00
0005433507181	9075	Economy	8900.00
0005433507184	9075	Economy	8900.00
0005433507187	9075	Economy	8900.00
0005432919697	9075	Economy	8900.00
0005432919666	9075	Economy	8900.00
0005434158960	9075	Economy	8900.00
0005433481170	9075	Economy	8900.00
0005432919659	9075	Economy	8900.00
0005432919608	9075	Economy	8900.00
0005433507189	9075	Economy	8900.00
0005433481168	9075	Economy	8900.00
0005432919609	9075	Economy	8900.00
0005433507007	20468	Business	26600.00
0005433507056	20468	Business	26600.00
0005432919868	20468	Business	26600.00
0005432919882	20468	Business	26600.00
0005433507038	20468	Business	26600.00
0005432919887	20468	Business	26600.00
0005433507055	20468	Economy	8900.00
0005433481097	20468	Economy	8900.00
0005432919875	20468	Economy	8900.00
0005433507006	20468	Economy	8900.00
0005433481124	20468	Economy	8900.00
0005433506919	20468	Economy	8900.00
0005432919884	20468	Economy	9800.00
0005433506992	20468	Economy	9800.00
0005433481107	20468	Economy	9800.00
0005432919869	20468	Economy	8900.00
0005433507009	20468	Economy	8900.00
0005432919883	20468	Economy	8900.00
0005433506917	20468	Economy	8900.00
0005433481112	20468	Economy	8900.00
0005432919872	20468	Economy	8900.00
0005432919879	20468	Economy	8900.00
0005432919876	20468	Economy	8900.00
0005433481133	20468	Economy	8900.00
0005433481085	20468	Economy	8900.00
0005433481091	20468	Economy	8900.00
0005433507039	20468	Economy	8900.00
0005433507005	20468	Economy	8900.00
0005432919878	20468	Economy	8900.00
0005432919871	20468	Economy	8900.00
0005433481101	20468	Economy	8900.00
0005432919880	20468	Economy	8900.00
0005433481115	20468	Economy	8900.00
0005432919886	20468	Economy	8900.00
0005432919873	20468	Economy	8900.00
0005433481086	20468	Economy	8900.00
0005433481078	20468	Economy	8900.00
0005432919877	20468	Economy	8900.00
0005432919881	20468	Economy	8900.00
0005433507029	20468	Economy	8900.00
0005433506918	20468	Economy	8900.00
0005432919874	20468	Economy	8900.00
0005432919870	20468	Economy	8900.00
0005433481119	20468	Economy	8900.00
0005433481099	20468	Economy	8900.00
0005433481111	20468	Economy	8900.00
0005433507008	20468	Economy	8900.00
0005432919885	20468	Economy	8900.00
0005433481100	20468	Economy	8900.00
0005433507018	20468	Economy	8900.00
0005433507028	20468	Economy	8900.00
0005433481093	20468	Economy	8900.00
0005433481087	20468	Economy	8900.00
0005433507017	20468	Economy	8900.00
0005432396241	10202	Economy	5800.00
0005432396238	10202	Economy	5800.00
0005435178984	10202	Economy	5800.00
0005432394099	10202	Economy	5800.00
0005432396240	10202	Economy	5800.00
0005432396237	10202	Economy	5800.00
0005432394100	10202	Economy	5800.00
0005432394101	10202	Economy	5800.00
0005432396239	10202	Economy	5800.00
0005435178983	10202	Economy	5800.00
0005432396210	18277	Economy	5800.00
0005435179693	18277	Economy	5800.00
0005432400101	18277	Economy	5800.00
0005435179695	18277	Economy	5800.00
0005435179394	18277	Economy	5800.00
0005432396207	18277	Economy	5800.00
0005435179393	18277	Economy	5800.00
0005432400102	18277	Economy	5800.00
0005435179694	18277	Economy	5800.00
0005432400103	18277	Economy	5800.00
0005432396222	18277	Economy	5800.00
0005435126081	10995	Business	9500.00
0005435125747	10995	Business	9500.00
0005435625958	10995	Business	9500.00
0005434411780	10995	Business	9500.00
0005435625971	10995	Business	9500.00
0005435125980	10995	Business	9500.00
0005435125749	10995	Business	9500.00
0005435125928	10995	Business	9500.00
0005435126045	10995	Business	9500.00
0005435125994	10995	Business	9500.00
0005435126044	10995	Economy	3200.00
0005435125899	10995	Economy	3200.00
0005435126092	10995	Economy	3200.00
0005435625951	10995	Economy	3200.00
0005435625997	10995	Economy	3200.00
0005435126156	10995	Economy	3200.00
0005435125860	10995	Economy	3200.00
0005435625976	10995	Economy	3200.00
0005435126080	10995	Economy	3200.00
0005435625974	10995	Economy	3500.00
0005435126022	10995	Economy	3500.00
0005435125803	10995	Economy	3500.00
0005435625994	10995	Economy	3500.00
0005435125748	10995	Economy	3200.00
0005434411776	10995	Economy	3200.00
0005435126032	10995	Economy	3200.00
0005435625926	10995	Economy	3200.00
0005435126017	10995	Economy	3200.00
0005435125849	10995	Economy	3200.00
0005435125821	10995	Economy	3200.00
0005435125931	10995	Economy	3200.00
0005435125932	10995	Economy	3200.00
0005435126043	10995	Economy	3200.00
0005435126091	10995	Economy	3200.00
0005435126103	10995	Economy	3200.00
0005435625972	10995	Economy	3200.00
0005435126134	10995	Economy	3200.00
0005435626015	10995	Economy	3200.00
0005434411778	10995	Economy	3200.00
0005435626007	10995	Economy	3200.00
0005435626002	10995	Economy	3200.00
0005435625995	10995	Economy	3200.00
0005435556669	10995	Economy	3200.00
0005435125985	10995	Economy	3200.00
0005435625973	10995	Economy	3200.00
0005435125917	10995	Economy	3200.00
0005435126031	10995	Economy	3200.00
0005435125907	10995	Economy	3200.00
0005435126120	10995	Economy	3200.00
0005435126038	10995	Economy	3200.00
0005435625999	10995	Economy	3200.00
0005435625975	10995	Economy	3200.00
0005435125943	10995	Economy	3200.00
0005434411777	10995	Economy	3200.00
0005435125850	10995	Economy	3200.00
0005435556670	10995	Economy	3200.00
0005435625998	10995	Economy	3200.00
0005435626019	10995	Economy	3200.00
0005434928300	10995	Economy	3200.00
0005435125986	10995	Economy	3200.00
0005435625996	10995	Economy	3200.00
0005435125870	10995	Economy	3200.00
0005435126124	10995	Economy	3200.00
0005435125802	10995	Economy	3200.00
0005434411779	10995	Economy	3200.00
0005435625979	10995	Economy	3200.00
0005435626005	10995	Economy	3200.00
0005435626006	10995	Economy	3200.00
0005435126052	10995	Economy	3200.00
0005435125950	10995	Economy	3200.00
0005435126123	10995	Economy	3200.00
0005435125967	10995	Economy	3200.00
0005435126111	10995	Economy	3200.00
0005435126016	10995	Economy	3200.00
0005435125963	10995	Economy	3200.00
0005435626003	10995	Economy	3200.00
0005435126051	10995	Economy	3200.00
0005434928265	14680	Business	9500.00
0005434928277	14680	Business	9500.00
0005435626168	14680	Business	9500.00
0005434411731	14680	Business	9500.00
0005435626170	14680	Business	9500.00
0005435626172	14680	Business	9500.00
0005435126359	14680	Business	9500.00
0005434411740	14680	Business	9500.00
0005435554186	14680	Business	9500.00
0005435554182	14680	Economy	3200.00
0005435126371	14680	Economy	3200.00
0005435126388	14680	Economy	3200.00
0005435126394	14680	Economy	3200.00
0005435556692	14680	Economy	3200.00
0005435126382	14680	Economy	3200.00
0005435126356	14680	Economy	3200.00
0005435126387	14680	Economy	3200.00
0005435556691	14680	Economy	3200.00
0005435554183	14680	Economy	3500.00
0005435126375	14680	Economy	3500.00
0005435126379	14680	Economy	3500.00
0005435126389	14680	Economy	3500.00
0005435126391	14680	Economy	3200.00
0005435126390	14680	Economy	3200.00
0005435626166	14680	Economy	3200.00
0005435126358	14680	Economy	3200.00
0005435126363	14680	Economy	3200.00
0005435126364	14680	Economy	3200.00
0005435126385	14680	Economy	3200.00
0005435126384	14680	Economy	3200.00
0005435126362	14680	Economy	3200.00
0005434411734	14680	Economy	3200.00
0005435126365	14680	Economy	3200.00
0005435626169	14680	Economy	3200.00
0005434411743	14680	Economy	3200.00
0005435554185	14680	Economy	3200.00
0005435126366	14680	Economy	3200.00
0005435126395	14680	Economy	3200.00
0005435626171	14680	Economy	3200.00
0005434411746	14680	Economy	3200.00
0005435554184	14680	Economy	3200.00
0005435126376	14680	Economy	3200.00
0005435554187	14680	Economy	3200.00
0005435126392	14680	Economy	3200.00
0005435126380	14680	Economy	3200.00
0005435126367	14680	Economy	3200.00
0005435126383	14680	Economy	3200.00
0005435126393	14680	Economy	3200.00
0005435126373	14680	Economy	3200.00
0005435126372	14680	Economy	3200.00
0005435126369	14680	Economy	3200.00
0005434928286	14680	Economy	3200.00
0005435126361	14680	Economy	3200.00
0005435126370	14680	Economy	3200.00
0005435626167	14680	Economy	3200.00
0005434928287	14680	Economy	3200.00
0005435126355	14680	Economy	3200.00
0005435126368	14680	Economy	3200.00
0005434411739	14680	Economy	3200.00
0005435126374	14680	Economy	3200.00
0005435126378	14680	Economy	3200.00
0005435126377	14680	Economy	3200.00
0005434928283	14680	Economy	3200.00
0005435626173	14680	Economy	3200.00
0005435126386	14680	Economy	3200.00
0005435626165	14680	Economy	3200.00
0005435126357	14680	Economy	3200.00
0005435126360	14680	Economy	3200.00
0005435126381	14680	Economy	3200.00
0005435443225	7095	Business	86900.00
0005435715475	7095	Business	86900.00
0005435715461	7095	Business	86900.00
0005435715470	7095	Business	86900.00
0005435443224	7095	Business	86900.00
0005435715476	7095	Economy	29000.00
0005435443228	7095	Economy	29000.00
0005435715462	7095	Economy	29000.00
0005435715458	7095	Economy	29000.00
0005435443222	7095	Economy	31900.00
0005435443205	7095	Economy	29000.00
0005435715465	7095	Economy	29000.00
0005435715474	7095	Economy	29000.00
0005435219178	7095	Economy	29000.00
0005435443229	7095	Economy	29000.00
0005435715473	7095	Economy	29000.00
0005432400122	7095	Economy	29000.00
0005435178485	7095	Economy	29000.00
0005435216556	7095	Economy	29000.00
0005432398198	7095	Economy	29000.00
0005432400123	7095	Economy	29000.00
0005435178482	7095	Economy	29000.00
0005435219182	7095	Economy	29000.00
0005435715463	7095	Economy	29000.00
0005432398197	7095	Economy	29000.00
0005435216557	7095	Economy	29000.00
0005435443226	7095	Economy	29000.00
0005435443230	7095	Economy	29000.00
0005435715459	7095	Economy	29000.00
0005435216575	7095	Economy	29000.00
0005435715472	7095	Economy	29000.00
0005435178472	7095	Economy	29000.00
0005435715466	7095	Economy	29000.00
0005432400124	7095	Economy	29000.00
0005435219175	7095	Economy	29000.00
0005435715464	7095	Economy	29000.00
0005432398196	7095	Economy	29000.00
0005435715467	7095	Economy	29000.00
0005435443206	7095	Economy	29000.00
0005435715471	7095	Economy	29000.00
0005435219183	7095	Economy	29000.00
0005435715469	7095	Economy	29000.00
0005432398199	7095	Economy	29000.00
0005435715460	7095	Economy	29000.00
0005435221047	7095	Economy	29000.00
0005432400125	7095	Economy	29000.00
0005435715468	7095	Economy	29000.00
0005435443311	27090	Business	86900.00
0005435443317	27090	Business	86900.00
0005435715335	27090	Business	86900.00
0005432394068	27090	Business	86900.00
0005435715322	27090	Business	86900.00
0005435715311	27090	Business	86900.00
0005435443310	27090	Economy	29000.00
0005432394053	27090	Economy	29000.00
0005435443309	27090	Economy	29000.00
0005435715346	27090	Economy	29000.00
0005435443313	27090	Economy	29000.00
0005432398161	27090	Economy	29000.00
0005435715312	27090	Economy	31900.00
0005435715337	27090	Economy	31900.00
0005432398171	27090	Economy	31900.00
0005435715336	27090	Economy	29000.00
0005435178494	27090	Economy	29000.00
0005435443308	27090	Economy	29000.00
0005432398162	27090	Economy	29000.00
0005435715348	27090	Economy	29000.00
0005435715360	27090	Economy	29000.00
0005435443312	27090	Economy	29000.00
0005435715309	27090	Economy	29000.00
0005435715181	27090	Economy	29000.00
0005432398168	27090	Economy	29000.00
0005435715182	27090	Economy	29000.00
0005432398172	27090	Economy	29000.00
0005435715237	27090	Economy	29000.00
0005432398155	27090	Economy	29000.00
0005435715388	27090	Economy	29000.00
0005435715299	27090	Economy	29000.00
0005432398157	27090	Economy	29000.00
0005435715316	27090	Economy	29000.00
0005435715387	27090	Economy	29000.00
0005435443314	27090	Economy	29000.00
0005435715238	27090	Economy	29000.00
0005435443316	27090	Economy	29000.00
0005435443315	27090	Economy	29000.00
0005435715310	27090	Economy	29000.00
0005432398160	27090	Economy	29000.00
0005435715305	27090	Economy	29000.00
0005435715405	27090	Economy	29000.00
0005432398156	27090	Economy	29000.00
0005435443318	27090	Economy	29000.00
0005434084929	2740	Economy	7700.00
0005434084928	2740	Economy	7700.00
0005434084930	2740	Economy	7700.00
0005434084932	2740	Economy	7700.00
0005433060389	2740	Economy	7700.00
0005434084931	2740	Economy	7700.00
0005434084895	28474	Economy	7700.00
0005434084894	28474	Economy	7700.00
0005434084892	28474	Economy	7700.00
0005434084893	28474	Economy	7700.00
0005433060413	28474	Economy	7700.00
0005434084885	28474	Economy	7700.00
0005434084886	28474	Economy	7700.00
0005434084900	28474	Economy	7700.00
0005433060412	28474	Economy	7700.00
0005434084896	28474	Economy	7700.00
0005432632708	25201	Economy	29000.00
0005432632719	25201	Economy	29000.00
0005432632722	25201	Economy	29000.00
0005432632723	25201	Economy	26400.00
0005432632713	25201	Economy	26400.00
0005432632707	25201	Economy	26400.00
0005435844263	25201	Economy	26400.00
0005432632725	25201	Economy	26400.00
0005435844273	25201	Economy	26400.00
0005432632727	25201	Economy	26400.00
0005435844279	25201	Economy	26400.00
0005432632715	25201	Economy	26400.00
0005432632720	25201	Economy	26400.00
0005435844269	25201	Economy	26400.00
0005435844270	25201	Economy	26400.00
0005432632711	25201	Economy	26400.00
0005432632721	25201	Economy	26400.00
0005435844264	25201	Economy	26400.00
0005435844267	25201	Economy	26400.00
0005432632728	25201	Economy	26400.00
0005432632724	25201	Economy	26400.00
0005435844262	25201	Economy	26400.00
0005432632718	25201	Economy	26400.00
0005435844268	25201	Economy	26400.00
0005435844266	25201	Economy	26400.00
0005432632712	25201	Economy	26400.00
0005432632714	25201	Economy	26400.00
0005432632710	25201	Economy	26400.00
0005432632706	25201	Economy	26400.00
0005435844280	25201	Economy	26400.00
0005435844265	25201	Economy	26400.00
0005432632717	25201	Economy	26400.00
0005432632709	25201	Economy	26400.00
0005432632726	25201	Economy	26400.00
0005432632732	25201	Economy	26400.00
0005432632730	25201	Economy	26400.00
0005435844282	25201	Economy	26400.00
0005432632731	25201	Economy	26400.00
0005432632716	25201	Economy	26400.00
0005432632729	25201	Economy	26400.00
0005435844272	25201	Economy	26400.00
0005435844316	28174	Economy	29000.00
0005432632649	28174	Economy	29000.00
0005432632620	28174	Economy	29000.00
0005435844326	28174	Economy	29000.00
0005435844318	28174	Economy	26400.00
0005432632680	28174	Economy	26400.00
0005432632634	28174	Economy	26400.00
0005432632648	28174	Economy	26400.00
0005432632670	28174	Economy	26400.00
0005432632651	28174	Economy	26400.00
0005435844314	28174	Economy	26400.00
0005435844320	28174	Economy	26400.00
0005432632681	28174	Economy	26400.00
0005435844322	28174	Economy	26400.00
0005432632674	28174	Economy	26400.00
0005432632662	28174	Economy	26400.00
0005432632641	28174	Economy	26400.00
0005435844321	28174	Economy	26400.00
0005432632655	28174	Economy	26400.00
0005432632663	28174	Economy	26400.00
0005432632652	28174	Economy	26400.00
0005435844324	28174	Economy	26400.00
0005432632669	28174	Economy	26400.00
0005432632631	28174	Economy	26400.00
0005432632673	28174	Economy	26400.00
0005432632682	28174	Economy	26400.00
0005432632624	28174	Economy	26400.00
0005432632650	28174	Economy	26400.00
0005432632633	28174	Economy	26400.00
0005432632647	28174	Economy	26400.00
0005432632698	28174	Economy	26400.00
0005432632635	28174	Economy	26400.00
0005432632665	28174	Economy	26400.00
0005432632659	28174	Economy	26400.00
0005435844315	28174	Economy	26400.00
0005432632658	28174	Economy	26400.00
0005435844325	28174	Economy	26400.00
0005432632656	28174	Economy	26400.00
0005432632666	28174	Economy	26400.00
0005435844323	28174	Economy	26400.00
0005435844317	28174	Economy	26400.00
0005432632644	28174	Economy	26400.00
0005432632695	28174	Economy	26400.00
0005432632683	28174	Economy	26400.00
0005432632676	28174	Economy	26400.00
0005432632696	28174	Economy	26400.00
0005432632668	28174	Economy	26400.00
0005435844319	28174	Economy	26400.00
0005435844313	28174	Economy	26400.00
0005435517743	11370	Business	20200.00
0005435517805	11370	Business	20200.00
0005435517744	11370	Economy	6700.00
0005435517795	11370	Economy	6700.00
0005435517811	11370	Economy	6700.00
0005435540854	11370	Economy	6700.00
0005435517720	11370	Economy	7400.00
0005435517755	11370	Economy	7400.00
0005435540866	11370	Economy	7400.00
0005435540811	11370	Economy	6700.00
0005435517738	11370	Economy	6700.00
0005435517796	11370	Economy	6700.00
0005435517719	11370	Economy	6700.00
0005435540800	11370	Economy	6700.00
0005435540801	11370	Economy	6700.00
0005435540813	11370	Economy	6700.00
0005435517761	11370	Economy	6700.00
0005435517751	11370	Economy	6700.00
0005435540812	11370	Economy	6700.00
0005435517650	11370	Economy	6700.00
0005435517769	11370	Economy	6700.00
0005435517798	11370	Economy	6700.00
0005435517708	11370	Economy	6700.00
0005435517756	11370	Economy	6700.00
0005435517745	11370	Economy	6700.00
0005435540836	11370	Economy	6700.00
0005435517772	11370	Economy	6700.00
0005435517793	11370	Economy	6700.00
0005435540798	11370	Economy	6700.00
0005435517768	11370	Economy	6700.00
0005435517750	11370	Economy	6700.00
0005435540864	11370	Economy	6700.00
0005435517794	11370	Economy	6700.00
0005435540863	11370	Economy	6700.00
0005435517762	11370	Economy	6700.00
0005435517797	11370	Economy	6700.00
0005435540880	11370	Economy	6700.00
0005435517834	11370	Economy	6700.00
0005435540868	11370	Economy	6700.00
0005435517742	11370	Economy	6700.00
0005435517651	11370	Economy	6700.00
0005435540799	11370	Economy	6700.00
0005435540984	22237	Business	20200.00
0005432294485	22237	Business	20200.00
0005435540995	22237	Business	20200.00
0005435529250	22237	Economy	6700.00
0005435529247	22237	Economy	6700.00
0005432294486	22237	Economy	6700.00
0005435529240	22237	Economy	6700.00
0005432294484	22237	Economy	6700.00
0005435529248	22237	Economy	6700.00
0005435529239	22237	Economy	7400.00
0005435540997	22237	Economy	7400.00
0005435540986	22237	Economy	7400.00
0005435540989	22237	Economy	7400.00
0005435540994	22237	Economy	6700.00
0005435529236	22237	Economy	6700.00
0005435540993	22237	Economy	6700.00
0005435540992	22237	Economy	6700.00
0005435540990	22237	Economy	6700.00
0005435540987	22237	Economy	6700.00
0005435529235	22237	Economy	6700.00
0005435529234	22237	Economy	6700.00
0005435529243	22237	Economy	6700.00
0005435529244	22237	Economy	6700.00
0005435540978	22237	Economy	6700.00
0005435529237	22237	Economy	6700.00
0005435529253	22237	Economy	6700.00
0005435529242	22237	Economy	6700.00
0005435540985	22237	Economy	6700.00
0005435529251	22237	Economy	6700.00
0005435540996	22237	Economy	6700.00
0005435529246	22237	Economy	6700.00
0005435529241	22237	Economy	6700.00
0005435529255	22237	Economy	6700.00
0005435529238	22237	Economy	6700.00
0005435540982	22237	Economy	6700.00
0005435529249	22237	Economy	6700.00
0005435540981	22237	Economy	6700.00
0005435540980	22237	Economy	6700.00
0005435529254	22237	Economy	6700.00
0005435540983	22237	Economy	6700.00
0005435540998	22237	Economy	6700.00
0005435529252	22237	Economy	6700.00
0005435529245	22237	Economy	6700.00
0005435540991	22237	Economy	6700.00
0005435540979	22237	Economy	6700.00
0005435540988	22237	Economy	6700.00
0005434907287	2291	Business	20200.00
0005434907306	2291	Business	20200.00
0005434907313	2291	Business	20200.00
0005434907263	2291	Business	20200.00
0005434907289	2291	Business	20200.00
0005434907308	2291	Business	20200.00
0005434907292	2291	Business	20200.00
0005433251241	2291	Business	20200.00
0005433251125	2291	Business	20200.00
0005434907283	2291	Business	20200.00
0005434907285	2291	Business	20200.00
0005433251221	2291	Economy	6700.00
0005433251185	2291	Economy	6700.00
0005434907264	2291	Economy	6700.00
0005434907277	2291	Economy	6700.00
0005434907266	2291	Economy	6700.00
0005434907309	2291	Economy	6700.00
0005434907265	2291	Economy	6700.00
0005433251268	2291	Economy	6700.00
0005433251426	2291	Economy	6700.00
0005433251184	2291	Economy	7400.00
0005434907296	2291	Economy	7400.00
0005433251326	2291	Economy	7400.00
0005433251275	2291	Economy	7400.00
0005433251186	2291	Economy	7400.00
0005434907301	2291	Economy	6700.00
0005433251230	2291	Economy	6700.00
0005434907291	2291	Economy	6700.00
0005433251239	2291	Economy	6700.00
0005434907274	2291	Economy	6700.00
0005434907312	2291	Economy	6700.00
0005433251305	2291	Economy	6700.00
0005434907267	2291	Economy	6700.00
0005434907315	2291	Economy	6700.00
0005434907300	2291	Economy	6700.00
0005434907288	2291	Economy	6700.00
0005433251138	2291	Economy	6700.00
0005434907304	2291	Economy	6700.00
0005433251229	2291	Economy	6700.00
0005433251243	2291	Economy	6700.00
0005433251216	2291	Economy	6700.00
0005433251171	2291	Economy	6700.00
0005433251280	2291	Economy	6700.00
0005433400950	2291	Economy	6700.00
0005434907279	2291	Economy	6700.00
0005434907305	2291	Economy	6700.00
0005434907280	2291	Economy	6700.00
0005434907303	2291	Economy	6700.00
0005433251277	2291	Economy	6700.00
0005434907286	2291	Economy	6700.00
0005434907294	2291	Economy	6700.00
0005433251217	2291	Economy	6700.00
0005433251276	2291	Economy	6700.00
0005434907273	2291	Economy	6700.00
0005434907284	2291	Economy	6700.00
0005434907268	2291	Economy	6700.00
0005434907298	2291	Economy	6700.00
0005434907275	2291	Economy	6700.00
0005433251126	2291	Economy	6700.00
0005434907310	2291	Economy	6700.00
0005434907307	2291	Economy	6700.00
0005434907299	2291	Economy	6700.00
0005433251278	2291	Economy	6700.00
0005434907297	2291	Economy	6700.00
0005434907311	2291	Economy	6700.00
0005434907278	2291	Economy	6700.00
0005434907295	2291	Economy	6700.00
0005433251285	2291	Economy	6700.00
0005433251286	2291	Economy	6700.00
0005434907282	2291	Economy	6700.00
0005434907269	2291	Economy	6700.00
0005434907281	2291	Economy	6700.00
0005434907290	2291	Economy	6700.00
0005434907270	2291	Economy	6700.00
0005433251141	2291	Economy	6700.00
0005434907272	2291	Economy	6700.00
0005433251249	2291	Economy	6700.00
0005433251283	2291	Economy	6700.00
0005433251328	2291	Economy	6700.00
0005433251279	2291	Economy	6700.00
0005433251304	2291	Economy	6700.00
0005434907276	2291	Economy	6700.00
0005433251124	2291	Economy	6700.00
0005434907314	2291	Economy	6700.00
0005434907302	2291	Economy	6700.00
0005433251329	2291	Economy	6700.00
0005433251240	2291	Economy	6700.00
0005433251170	2291	Economy	6700.00
0005433251220	2291	Economy	6700.00
0005434907271	2291	Economy	6700.00
0005434907293	2291	Economy	6700.00
0005434906772	25597	Business	20200.00
0005434906844	25597	Business	20200.00
0005433251478	25597	Business	20200.00
0005434906455	25597	Business	20200.00
0005433251474	25597	Business	20200.00
0005433251477	25597	Business	20200.00
0005433251475	25597	Business	20200.00
0005434906795	25597	Business	20200.00
0005434906788	25597	Business	20200.00
0005434906757	25597	Business	20200.00
0005433251467	25597	Economy	6700.00
0005433251490	25597	Economy	6700.00
0005434906692	25597	Economy	6700.00
0005434906734	25597	Economy	6700.00
0005434906717	25597	Economy	6700.00
0005434906644	25597	Economy	6700.00
0005433251489	25597	Economy	6700.00
0005434906647	25597	Economy	6700.00
0005434906699	25597	Economy	6700.00
0005434906643	25597	Economy	6700.00
0005434906893	25597	Economy	7400.00
0005433251465	25597	Economy	7400.00
0005434906752	25597	Economy	7400.00
0005434906721	25597	Economy	7400.00
0005433251480	25597	Economy	7400.00
0005434906831	25597	Economy	6700.00
0005434906881	25597	Economy	6700.00
0005434906825	25597	Economy	6700.00
0005434906733	25597	Economy	6700.00
0005433251485	25597	Economy	6700.00
0005433251468	25597	Economy	6700.00
0005433251466	25597	Economy	6700.00
0005433400983	25597	Economy	6700.00
0005433251476	25597	Economy	6700.00
0005434906880	25597	Economy	6700.00
0005434906835	25597	Economy	6700.00
0005434906700	25597	Economy	6700.00
0005433400982	25597	Economy	6700.00
0005433251484	25597	Economy	6700.00
0005434906621	25597	Economy	6700.00
0005434906876	25597	Economy	6700.00
0005434906829	25597	Economy	6700.00
0005433251470	25597	Economy	6700.00
0005434906820	25597	Economy	6700.00
0005433251471	25597	Economy	6700.00
0005433251494	25597	Economy	6700.00
0005433251488	25597	Economy	6700.00
0005434906852	25597	Economy	6700.00
0005434906605	25597	Economy	6700.00
0005434906646	25597	Economy	6700.00
0005433251479	25597	Economy	6700.00
0005433251482	25597	Economy	6700.00
0005434906843	25597	Economy	6700.00
0005434906718	25597	Economy	6700.00
0005434906836	25597	Economy	6700.00
0005434906889	25597	Economy	6700.00
0005433251495	25597	Economy	6700.00
0005434906691	25597	Economy	6700.00
0005434906645	25597	Economy	6700.00
0005433251483	25597	Economy	6700.00
0005433251486	25597	Economy	6700.00
0005434906839	25597	Economy	6700.00
0005434906892	25597	Economy	6700.00
0005434906827	25597	Economy	6700.00
0005433251472	25597	Economy	6700.00
0005433400984	25597	Economy	6700.00
0005434906789	25597	Economy	6700.00
0005434906853	25597	Economy	6700.00
0005434906539	25597	Economy	6700.00
0005434906701	25597	Economy	6700.00
0005433251492	25597	Economy	6700.00
0005434906742	25597	Economy	6700.00
0005434906834	25597	Economy	6700.00
0005433251487	25597	Economy	6700.00
0005434906898	25597	Economy	6700.00
0005433251481	25597	Economy	6700.00
0005434906731	25597	Economy	6700.00
0005434906725	25597	Economy	6700.00
0005433251473	25597	Economy	6700.00
0005434906790	25597	Economy	6700.00
0005434906830	25597	Economy	6700.00
0005433251491	25597	Economy	6700.00
0005434906716	25597	Economy	6700.00
0005433251469	25597	Economy	6700.00
0005434906607	25597	Economy	6700.00
0005434906828	25597	Economy	6700.00
0005434906543	25597	Economy	6700.00
0005433251493	25597	Economy	6700.00
0005434906821	25597	Economy	6700.00
0005434906814	25597	Economy	6700.00
0005432621045	2497	Economy	13600.00
0005432862251	2497	Economy	13600.00
0005432621042	2497	Economy	12400.00
0005432621032	2497	Economy	12400.00
0005432621041	2497	Economy	12400.00
0005432621038	2497	Economy	12400.00
0005432621033	2497	Economy	12400.00
0005432621034	2497	Economy	12400.00
0005432862200	2497	Economy	12400.00
0005432862217	2497	Economy	12400.00
0005432621044	2497	Economy	12400.00
0005432862239	2497	Economy	12400.00
0005432862249	2497	Economy	12400.00
0005432862216	2497	Economy	12400.00
0005432621043	2497	Economy	12400.00
0005432621036	2497	Economy	12400.00
0005432621040	2497	Economy	12400.00
0005432862252	2497	Economy	12400.00
0005432621035	2497	Economy	12400.00
0005432621037	2497	Economy	12400.00
0005432862243	2497	Economy	12400.00
0005432621039	2497	Economy	12400.00
0005432862218	2497	Economy	12400.00
0005432862248	2497	Economy	12400.00
0005432862244	2497	Economy	12400.00
0005432862301	28054	Economy	13600.00
0005432620920	28054	Economy	13600.00
0005432620951	28054	Economy	12400.00
0005432620973	28054	Economy	12400.00
0005432620902	28054	Economy	12400.00
0005432862303	28054	Economy	12400.00
0005432620941	28054	Economy	12400.00
0005432620991	28054	Economy	12400.00
0005432620939	28054	Economy	12400.00
0005432862299	28054	Economy	12400.00
0005432620940	28054	Economy	12400.00
0005432620944	28054	Economy	12400.00
0005432620901	28054	Economy	12400.00
0005432862305	28054	Economy	12400.00
0005432862302	28054	Economy	12400.00
0005432620912	28054	Economy	12400.00
0005432620978	28054	Economy	12400.00
0005432620872	28054	Economy	12400.00
0005432862300	28054	Economy	12400.00
0005432620875	28054	Economy	12400.00
0005432620960	28054	Economy	12400.00
0005432862304	28054	Economy	12400.00
0005432620938	28054	Economy	12400.00
0005432862298	28054	Economy	12400.00
0005434097467	11775	Economy	11300.00
0005434097476	13063	Economy	11300.00
0005433452738	31071	Economy	8400.00
0005433451619	31071	Economy	8400.00
0005433452739	31071	Economy	8400.00
0005433451618	31071	Economy	8400.00
0005433451620	31071	Economy	8400.00
0005433454856	31376	Economy	8400.00
0005433452723	31376	Economy	8400.00
0005433454853	31376	Economy	8400.00
0005433454857	31376	Economy	8400.00
0005433454852	31376	Economy	8400.00
0005433129238	12013	Economy	7200.00
0005433134089	12013	Economy	7200.00
0005433129225	12013	Economy	6600.00
0005433129231	12013	Economy	6600.00
0005434184654	12013	Economy	6600.00
0005433129246	12013	Economy	6600.00
0005433134098	12013	Economy	6600.00
0005433134090	12013	Economy	6600.00
0005434142578	12013	Economy	6600.00
0005433129224	12013	Economy	6600.00
0005433129243	12013	Economy	6600.00
0005434184655	12013	Economy	6600.00
0005433129223	12013	Economy	6600.00
0005433129230	12013	Economy	6600.00
0005433129248	12013	Economy	6600.00
0005434142577	12013	Economy	6600.00
0005433129247	12013	Economy	6600.00
0005433131707	29822	Economy	7200.00
0005433131708	29822	Economy	7200.00
0005434183580	29822	Economy	7200.00
0005433131710	29822	Economy	6600.00
0005433131706	29822	Economy	6600.00
0005434142607	29822	Economy	6600.00
0005434184666	29822	Economy	6600.00
0005434142605	29822	Economy	6600.00
0005433134138	29822	Economy	6600.00
0005433134139	29822	Economy	6600.00
0005433134136	29822	Economy	6600.00
0005434142608	29822	Economy	6600.00
0005433134137	29822	Economy	6600.00
0005434184664	29822	Economy	6600.00
0005433131709	29822	Economy	6600.00
0005434142606	29822	Economy	6600.00
0005434183579	29822	Economy	6600.00
0005434184665	29822	Economy	6600.00
0005435935023	16503	Economy	19900.00
0005435697321	16503	Economy	19900.00
0005435697307	16503	Economy	18100.00
0005435935032	16503	Economy	18100.00
0005435697308	16503	Economy	18100.00
0005435697316	16503	Economy	18100.00
0005435697306	16503	Economy	18100.00
0005435697312	16503	Economy	18100.00
0005435935019	16503	Economy	18100.00
0005435697324	16503	Economy	18100.00
0005435697319	16503	Economy	18100.00
0005435697328	16503	Economy	18100.00
0005435697314	16503	Economy	18100.00
0005435935024	16503	Economy	18100.00
0005435697311	16503	Economy	18100.00
0005435697310	16503	Economy	18100.00
0005435697326	16503	Economy	18100.00
0005435697317	16503	Economy	18100.00
0005435697305	16503	Economy	18100.00
0005435697322	16503	Economy	18100.00
0005435697329	16503	Economy	18100.00
0005435697323	16503	Economy	18100.00
0005435697327	16503	Economy	18100.00
0005435697313	16503	Economy	18100.00
0005435697304	16503	Economy	18100.00
0005435697303	16503	Economy	18100.00
0005435935031	16503	Economy	18100.00
0005435697309	16503	Economy	18100.00
0005435697320	16503	Economy	18100.00
0005435697318	16503	Economy	18100.00
0005435697325	16503	Economy	18100.00
0005435697330	16503	Economy	18100.00
0005435697315	16503	Economy	18100.00
0005435935022	16503	Economy	18100.00
0005435697189	24730	Economy	19900.00
0005435697114	24730	Economy	19900.00
0005435697062	24730	Economy	18100.00
0005435697041	24730	Economy	18100.00
0005435697029	24730	Economy	18100.00
0005435697085	24730	Economy	18100.00
0005435697097	24730	Economy	18100.00
0005435697096	24730	Economy	18100.00
0005435935047	24730	Economy	18100.00
0005435697084	24730	Economy	18100.00
0005435697030	24730	Economy	18100.00
0005435697115	24730	Economy	18100.00
0005435696976	24730	Economy	18100.00
0005435697142	24730	Economy	18100.00
0005435697000	24730	Economy	18100.00
0005435935045	24730	Economy	18100.00
0005435697187	24730	Economy	18100.00
0005435935046	24730	Economy	18100.00
0005435697036	24730	Economy	18100.00
0005435697186	24730	Economy	18100.00
0005435697120	24730	Economy	18100.00
0005435697173	24730	Economy	18100.00
0005435696918	24730	Economy	18100.00
0005435697077	24730	Economy	18100.00
0005433724802	18789	Economy	4400.00
0005432968823	18789	Economy	4400.00
0005433724803	18789	Economy	4400.00
0005433724804	18789	Economy	4400.00
0005433724805	18789	Economy	4400.00
0005432968824	18789	Economy	4400.00
0005432968827	18789	Economy	4400.00
0005433724750	21649	Economy	4400.00
0005433724768	21649	Economy	4400.00
0005433724764	21649	Economy	4400.00
0005433724749	21649	Economy	4400.00
0005433724770	21649	Economy	4400.00
0005433724763	21649	Economy	4400.00
0005433724769	21649	Economy	4400.00
0005432968842	21649	Economy	4400.00
0005433724771	21649	Economy	4400.00
0005432968843	21649	Economy	4400.00
0005433724765	21649	Economy	4400.00
0005433724773	21649	Economy	4400.00
0005434138203	7312	Business	23100.00
0005434138195	7312	Business	23100.00
0005434138192	7312	Business	23100.00
0005434138177	7312	Business	23100.00
0005434138147	7312	Business	23100.00
0005434138127	7312	Business	23100.00
0005434138196	7312	Business	23100.00
0005434138172	7312	Business	23100.00
0005434138137	7312	Business	23100.00
0005434138201	7312	Business	23100.00
0005434138198	7312	Business	23100.00
0005434138151	7312	Economy	7700.00
0005434138131	7312	Economy	7700.00
0005434138191	7312	Economy	7700.00
0005434138169	7312	Economy	7700.00
0005434138173	7312	Economy	7700.00
0005434138205	7312	Economy	7700.00
0005434138170	7312	Economy	7700.00
0005434138208	7312	Economy	7700.00
0005434138155	7312	Economy	7700.00
0005434138181	7312	Economy	7700.00
0005434138185	7312	Economy	8500.00
0005434138164	7312	Economy	8500.00
0005434138140	7312	Economy	8500.00
0005434138126	7312	Economy	8500.00
0005434138125	7312	Economy	8500.00
0005434138143	7312	Economy	7700.00
0005434138194	7312	Economy	7700.00
0005434138190	7312	Economy	7700.00
0005434087515	7312	Economy	7700.00
0005434138149	7312	Economy	7700.00
0005434138136	7312	Economy	7700.00
0005434138183	7312	Economy	7700.00
0005434138141	7312	Economy	7700.00
0005434138154	7312	Economy	7700.00
0005434138204	7312	Economy	7700.00
0005434138156	7312	Economy	7700.00
0005434138211	7312	Economy	7700.00
0005434138160	7312	Economy	7700.00
0005434087516	7312	Economy	7700.00
0005434138182	7312	Economy	7700.00
0005434138165	7312	Economy	7700.00
0005434138157	7312	Economy	7700.00
0005434087512	7312	Economy	7700.00
0005434138212	7312	Economy	7700.00
0005434138158	7312	Economy	7700.00
0005434138167	7312	Economy	7700.00
0005434087511	7312	Economy	7700.00
0005434138209	7312	Economy	7700.00
0005434138186	7312	Economy	7700.00
0005434138132	7312	Economy	7700.00
0005434138213	7312	Economy	7700.00
0005434138145	7312	Economy	7700.00
0005434138153	7312	Economy	7700.00
0005434138189	7312	Economy	7700.00
0005434138129	7312	Economy	7700.00
0005434138148	7312	Economy	7700.00
0005434087514	7312	Economy	7700.00
0005434138150	7312	Economy	7700.00
0005434138142	7312	Economy	7700.00
0005434138162	7312	Economy	7700.00
0005434138197	7312	Economy	7700.00
0005434138163	7312	Economy	7700.00
0005434138179	7312	Economy	7700.00
0005434138193	7312	Economy	7700.00
0005434138207	7312	Economy	7700.00
0005434138176	7312	Economy	7700.00
0005434138161	7312	Economy	7700.00
0005434138133	7312	Economy	7700.00
0005434138139	7312	Economy	7700.00
0005434138166	7312	Economy	7700.00
0005434138214	7312	Economy	7700.00
0005434138168	7312	Economy	7700.00
0005434138152	7312	Economy	7700.00
0005434138184	7312	Economy	7700.00
0005434087513	7312	Economy	7700.00
0005434138175	7312	Economy	7700.00
0005434138130	7312	Economy	7700.00
0005434138144	7312	Economy	7700.00
0005434138200	7312	Economy	7700.00
0005434138138	7312	Economy	7700.00
0005434138180	7312	Economy	7700.00
0005434138206	7312	Economy	7700.00
0005434138134	7312	Economy	7700.00
0005434138171	7312	Economy	7700.00
0005434138146	7312	Economy	7700.00
0005434138128	7312	Economy	7700.00
0005434138174	7312	Economy	7700.00
0005434138187	7312	Economy	7700.00
0005434138188	7312	Economy	7700.00
0005434138210	7312	Economy	7700.00
0005434138199	7312	Economy	7700.00
0005434138135	7312	Economy	7700.00
0005434138202	7312	Economy	7700.00
0005434138159	7312	Economy	7700.00
0005434138178	7312	Economy	7700.00
0005434087486	28545	Business	23100.00
0005434137107	28545	Business	23100.00
0005434137339	28545	Business	23100.00
0005434137340	28545	Business	23100.00
0005434137448	28545	Business	23100.00
0005434137458	28545	Business	23100.00
0005434137018	28545	Business	23100.00
0005434137455	28545	Business	23100.00
0005434137104	28545	Business	23100.00
0005434137434	28545	Business	23100.00
0005434137169	28545	Economy	7700.00
0005434137324	28545	Economy	7700.00
0005434137334	28545	Economy	7700.00
0005434137032	28545	Economy	7700.00
0005434137384	28545	Economy	7700.00
0005434137323	28545	Economy	7700.00
0005434137215	28545	Economy	7700.00
0005434137284	28545	Economy	7700.00
0005434137016	28545	Economy	7700.00
0005434137381	28545	Economy	7700.00
0005434137263	28545	Economy	8500.00
0005434137416	28545	Economy	8500.00
0005434137551	28545	Economy	8500.00
0005434137341	28545	Economy	8500.00
0005434137110	28545	Economy	8500.00
0005434137462	28545	Economy	7700.00
0005434137312	28545	Economy	7700.00
0005434137103	28545	Economy	7700.00
0005434137289	28545	Economy	7700.00
0005434137484	28545	Economy	7700.00
0005434137435	28545	Economy	7700.00
0005434087472	28545	Economy	7700.00
0005434137011	28545	Economy	7700.00
0005434137502	28545	Economy	7700.00
0005434136875	28545	Economy	7700.00
0005434137457	28545	Economy	7700.00
0005434137282	28545	Economy	7700.00
0005434137267	28545	Economy	7700.00
0005434137109	28545	Economy	7700.00
0005434137352	28545	Economy	7700.00
0005434137327	28545	Economy	7700.00
0005434137386	28545	Economy	7700.00
0005434137290	28545	Economy	7700.00
0005434137124	28545	Economy	7700.00
0005434087490	28545	Economy	7700.00
0005434137488	28545	Economy	7700.00
0005434137219	28545	Economy	7700.00
0005434136876	28545	Economy	7700.00
0005434087477	28545	Economy	7700.00
0005434137261	28545	Economy	7700.00
0005434137013	28545	Economy	7700.00
0005434137424	28545	Economy	7700.00
0005434137301	28545	Economy	7700.00
0005434137154	28545	Economy	7700.00
0005434137093	28545	Economy	7700.00
0005434137246	28545	Economy	7700.00
0005434137216	28545	Economy	7700.00
0005434137464	28545	Economy	7700.00
0005434137283	28545	Economy	7700.00
0005434137247	28545	Economy	7700.00
0005434137259	28545	Economy	7700.00
0005434137465	28545	Economy	7700.00
0005434137281	28545	Economy	7700.00
0005434087485	28545	Economy	7700.00
0005434137168	28545	Economy	7700.00
0005434137010	28545	Economy	7700.00
0005434137557	28545	Economy	7700.00
0005434087484	28545	Economy	7700.00
0005434137268	28545	Economy	7700.00
0005434137463	28545	Economy	7700.00
0005434137436	28545	Economy	7700.00
0005434087478	28545	Economy	7700.00
0005434137326	28545	Economy	7700.00
0005434137335	28545	Economy	7700.00
0005434137269	28545	Economy	7700.00
0005434137460	28545	Economy	7700.00
0005434137461	28545	Economy	7700.00
0005434137433	28545	Economy	7700.00
0005434137459	28545	Economy	7700.00
0005434137385	28545	Economy	7700.00
0005434137206	28545	Economy	7700.00
0005434137487	28545	Economy	7700.00
0005434137479	28545	Economy	7700.00
0005434137456	28545	Economy	7700.00
0005434137425	28545	Economy	7700.00
0005434137538	28545	Economy	7700.00
0005434137552	28545	Economy	7700.00
0005434137167	28545	Economy	7700.00
0005434137501	28545	Economy	7700.00
0005433407534	1940	Economy	23900.00
0005433407504	1940	Economy	21700.00
0005434610229	1940	Economy	21700.00
0005435808234	1940	Economy	21700.00
0005435808231	1940	Economy	21700.00
0005435808237	1940	Economy	21700.00
0005435808232	1940	Economy	21700.00
0005435808236	1940	Economy	21700.00
0005433407503	1940	Economy	21700.00
0005433407533	1940	Economy	21700.00
0005435808240	1940	Economy	21700.00
0005434610228	1940	Economy	21700.00
0005435808239	1940	Economy	21700.00
0005435808233	1940	Economy	21700.00
0005435808235	1940	Economy	21700.00
0005434610230	1940	Economy	21700.00
0005435808238	1940	Economy	21700.00
0005433407558	23074	Economy	23900.00
0005433407556	23074	Economy	23900.00
0005435808096	23074	Economy	23900.00
0005435808094	23074	Economy	23900.00
0005435808093	23074	Economy	21700.00
0005433407561	23074	Economy	21700.00
0005433407562	23074	Economy	21700.00
0005435808148	23074	Economy	21700.00
0005435808146	23074	Economy	21700.00
0005433407564	23074	Economy	21700.00
0005435808145	23074	Economy	21700.00
0005434610194	23074	Economy	21700.00
0005433407555	23074	Economy	21700.00
0005433407559	23074	Economy	21700.00
0005435808163	23074	Economy	21700.00
0005435808091	23074	Economy	21700.00
0005435808076	23074	Economy	21700.00
0005435808120	23074	Economy	21700.00
0005435808147	23074	Economy	21700.00
0005433407560	23074	Economy	21700.00
0005433407557	23074	Economy	21700.00
0005435808104	23074	Economy	21700.00
0005435808121	23074	Economy	21700.00
0005435808082	23074	Economy	21700.00
0005435808083	23074	Economy	21700.00
0005435808084	23074	Economy	21700.00
0005433407563	23074	Economy	21700.00
0005435808092	23074	Economy	21700.00
0005435808077	23074	Economy	21700.00
0005435808116	23074	Economy	21700.00
0005435808127	23074	Economy	21700.00
0005434503660	16710	Economy	7600.00
0005434503629	16710	Economy	7600.00
0005434503719	16710	Economy	7600.00
0005434503791	16710	Economy	7600.00
0005434503840	16710	Economy	6900.00
0005434503649	16710	Economy	6900.00
0005434503868	16710	Economy	6900.00
0005434503826	16710	Economy	6900.00
0005434503774	16710	Economy	6900.00
0005434503873	16710	Economy	6900.00
0005434503696	16710	Economy	6900.00
0005434503839	16710	Economy	6900.00
0005434503689	16710	Economy	6900.00
0005434503753	16710	Economy	6900.00
0005434503746	16710	Economy	6900.00
0005434503815	16710	Economy	6900.00
0005434503772	16710	Economy	6900.00
0005434503836	16710	Economy	6900.00
0005434503864	16710	Economy	6900.00
0005434503751	16710	Economy	6900.00
0005434503729	16710	Economy	6900.00
0005434503690	16710	Economy	6900.00
0005434503638	16710	Economy	6900.00
0005434503727	16710	Economy	6900.00
0005434503639	16710	Economy	6900.00
0005434503752	16710	Economy	6900.00
0005434503724	16710	Economy	6900.00
0005434503691	16710	Economy	6900.00
0005434503760	16710	Economy	6900.00
0005434503666	16710	Economy	6900.00
0005434503650	16710	Economy	6900.00
0005434503627	16710	Economy	6900.00
0005434503776	16710	Economy	6900.00
0005434503869	16710	Economy	6900.00
0005434503725	16710	Economy	6900.00
0005434503758	16710	Economy	6900.00
0005434503816	16710	Economy	6900.00
0005434503806	16710	Economy	6900.00
0005434503713	16710	Economy	6900.00
0005434503790	16710	Economy	6900.00
0005434503747	16710	Economy	6900.00
0005434503663	16710	Economy	6900.00
0005434503818	16710	Economy	6900.00
0005434503817	16710	Economy	6900.00
0005434503628	16710	Economy	6900.00
0005434503807	16710	Economy	6900.00
0005434503808	16710	Economy	6900.00
0005434503728	16710	Economy	6900.00
0005434503750	16710	Economy	6900.00
0005434503749	16710	Economy	6900.00
0005434504120	22889	Economy	7600.00
0005434504118	22889	Economy	7600.00
0005434504108	22889	Economy	7600.00
0005434504122	22889	Economy	7600.00
0005434504114	22889	Economy	6900.00
0005434504127	22889	Economy	6900.00
0005434504119	22889	Economy	6900.00
0005434504143	22889	Economy	6900.00
0005434504117	22889	Economy	6900.00
0005434504133	22889	Economy	6900.00
0005434504112	22889	Economy	6900.00
0005434504107	22889	Economy	6900.00
0005434504139	22889	Economy	6900.00
0005434504138	22889	Economy	6900.00
0005434504131	22889	Economy	6900.00
0005434504140	22889	Economy	6900.00
0005434504109	22889	Economy	6900.00
0005434504137	22889	Economy	6900.00
0005434504123	22889	Economy	6900.00
0005434504116	22889	Economy	6900.00
0005434504130	22889	Economy	6900.00
0005434504132	22889	Economy	6900.00
0005434504106	22889	Economy	6900.00
0005434504124	22889	Economy	6900.00
0005434504136	22889	Economy	6900.00
0005434504142	22889	Economy	6900.00
0005434504105	22889	Economy	6900.00
0005434504134	22889	Economy	6900.00
0005434504128	22889	Economy	6900.00
0005434504104	22889	Economy	6900.00
0005434504113	22889	Economy	6900.00
0005434504111	22889	Economy	6900.00
0005434504126	22889	Economy	6900.00
0005434504135	22889	Economy	6900.00
0005434504141	22889	Economy	6900.00
0005434504121	22889	Economy	6900.00
0005434504115	22889	Economy	6900.00
0005434504110	22889	Economy	6900.00
0005434504125	22889	Economy	6900.00
0005434504129	22889	Economy	6900.00
0005435078342	2205	Economy	7700.00
0005433266624	2205	Economy	7700.00
0005435078341	2205	Economy	7700.00
0005435078335	2205	Economy	7000.00
0005435078337	2205	Economy	7000.00
0005435078347	2205	Economy	7000.00
0005435078344	2205	Economy	7000.00
0005435078336	2205	Economy	7000.00
0005435078340	2205	Economy	7000.00
0005433266648	2205	Economy	7000.00
0005435078334	2205	Economy	7000.00
0005435078339	2205	Economy	7000.00
0005435078345	2205	Economy	7000.00
0005435078338	2205	Economy	7000.00
0005433266647	2205	Economy	7000.00
0005435078349	2205	Economy	7000.00
0005433266649	2205	Economy	7000.00
0005433266658	2205	Economy	7000.00
0005433266640	2205	Economy	7000.00
0005435078343	2205	Economy	7000.00
0005435078348	2205	Economy	7000.00
0005435078346	2205	Economy	7000.00
0005433266646	2205	Economy	7000.00
0005435078207	24325	Economy	7700.00
0005435078188	24325	Economy	7700.00
0005435078245	24325	Economy	7700.00
0005433266725	24325	Economy	7000.00
0005435078135	24325	Economy	7000.00
0005435078186	24325	Economy	7000.00
0005435078229	24325	Economy	7000.00
0005435078217	24325	Economy	7000.00
0005435078266	24325	Economy	7000.00
0005433266720	24325	Economy	7000.00
0005433266728	24325	Economy	7000.00
0005433266726	24325	Economy	7000.00
0005435078199	24325	Economy	7000.00
0005435078160	24325	Economy	7000.00
0005435078185	24325	Economy	7000.00
0005435078267	24325	Economy	7000.00
0005435078227	24325	Economy	7000.00
0005435078180	24325	Economy	7000.00
0005433266721	24325	Economy	7000.00
0005435078187	24325	Economy	7000.00
0005433266727	24325	Economy	7000.00
0005435078182	24325	Economy	7000.00
0005435078183	24325	Economy	7000.00
0005435078228	24325	Economy	7000.00
0005435078136	24325	Economy	7000.00
0005435078181	24325	Economy	7000.00
0005433266723	24325	Economy	7000.00
0005435078161	24325	Economy	7000.00
0005435078205	24325	Economy	7000.00
0005433266724	24325	Economy	7000.00
0005433266722	24325	Economy	7000.00
0005434988744	6631	Economy	10800.00
0005435464497	6631	Economy	10800.00
0005435803266	6631	Economy	9800.00
0005434988749	6631	Economy	9800.00
0005434988747	6631	Economy	9800.00
0005435803263	6631	Economy	9800.00
0005435803264	6631	Economy	9800.00
0005434988746	6631	Economy	9800.00
0005434988741	6631	Economy	9800.00
0005435803262	6631	Economy	9800.00
0005434988751	6631	Economy	9800.00
0005434988743	6631	Economy	9800.00
0005434988745	6631	Economy	9800.00
0005435803265	6631	Economy	9800.00
0005434988742	6631	Economy	9800.00
0005434988748	6631	Economy	9800.00
0005434988750	6631	Economy	9800.00
0005434988740	6631	Economy	9800.00
0005435464496	6631	Economy	9800.00
0005435464508	23603	Economy	10800.00
0005434988632	23603	Economy	10800.00
0005434988631	23603	Economy	9800.00
0005434988607	23603	Economy	9800.00
0005434988629	23603	Economy	9800.00
0005434988603	23603	Economy	9800.00
0005434988596	23603	Economy	9800.00
0005435464506	23603	Economy	9800.00
0005435464507	23603	Economy	9800.00
0005434988630	23603	Economy	9800.00
0005434988608	23603	Economy	9800.00
0005434988589	23603	Economy	9800.00
0005434988588	23603	Economy	9800.00
0005434988604	23603	Economy	9800.00
0005433449969	30502	Business	9900.00
0005432383168	30502	Business	9900.00
0005432383197	30502	Business	9900.00
0005432383175	30502	Business	9900.00
0005432383178	30502	Business	9900.00
0005433449973	30502	Business	9900.00
0005432383177	30502	Business	9900.00
0005432383199	30502	Business	9900.00
0005432383200	30502	Economy	3300.00
0005432383189	30502	Economy	3300.00
0005432383198	30502	Economy	3300.00
0005433449968	30502	Economy	3300.00
0005432383191	30502	Economy	3300.00
0005432383194	30502	Economy	3300.00
0005433449982	30502	Economy	3300.00
0005432383196	30502	Economy	3600.00
0005432383183	30502	Economy	3600.00
0005433449983	30502	Economy	3600.00
0005432383190	30502	Economy	3300.00
0005432383195	30502	Economy	3300.00
0005433449965	30502	Economy	3300.00
0005432383187	30502	Economy	3300.00
0005433449978	30502	Economy	3300.00
0005432383174	30502	Economy	3300.00
0005433449971	30502	Economy	3300.00
0005432383181	30502	Economy	3300.00
0005433449980	30502	Economy	3300.00
0005432383188	30502	Economy	3300.00
0005433449970	30502	Economy	3300.00
0005432383169	30502	Economy	3300.00
0005432383176	30502	Economy	3300.00
0005433449977	30502	Economy	3300.00
0005433449984	30502	Economy	3300.00
0005432383167	30502	Economy	3300.00
0005433449981	30502	Economy	3300.00
0005433449966	30502	Economy	3300.00
0005432383193	30502	Economy	3300.00
0005432383173	30502	Economy	3300.00
0005432383171	30502	Economy	3300.00
0005433449976	30502	Economy	3300.00
0005433449963	30502	Economy	3300.00
0005432383180	30502	Economy	3300.00
0005433449975	30502	Economy	3300.00
0005433449964	30502	Economy	3300.00
0005433449974	30502	Economy	3300.00
0005433454876	30502	Economy	3300.00
0005432383184	30502	Economy	3300.00
0005433449962	30502	Economy	3300.00
0005432383179	30502	Economy	3300.00
0005432383172	30502	Economy	3300.00
0005432383185	30502	Economy	3300.00
0005433449979	30502	Economy	3300.00
0005432383192	30502	Economy	3300.00
0005432383186	30502	Economy	3300.00
0005432383182	30502	Economy	3300.00
0005433449967	30502	Economy	3300.00
0005432383170	30502	Economy	3300.00
0005432383201	30502	Economy	3300.00
0005433449972	30502	Economy	3300.00
0005432382710	31328	Business	9900.00
0005432382767	31328	Business	9900.00
0005432382646	31328	Business	9900.00
0005432382798	31328	Business	9900.00
0005433449808	31328	Business	9900.00
0005432382785	31328	Business	9900.00
0005432382877	31328	Business	9900.00
0005433449779	31328	Business	9900.00
0005433449858	31328	Business	9900.00
0005433451612	31328	Business	9900.00
0005432382812	31328	Economy	3300.00
0005432382695	31328	Economy	3300.00
0005432382757	31328	Economy	3300.00
0005433449815	31328	Economy	3300.00
0005432382799	31328	Economy	3300.00
0005433449740	31328	Economy	3300.00
0005432382719	31328	Economy	3300.00
0005432382734	31328	Economy	3600.00
0005432382786	31328	Economy	3600.00
0005433449807	31328	Economy	3600.00
0005432382731	31328	Economy	3600.00
0005432382837	31328	Economy	3300.00
0005432382647	31328	Economy	3300.00
0005433449846	31328	Economy	3300.00
0005433449818	31328	Economy	3300.00
0005433449720	31328	Economy	3300.00
0005433449776	31328	Economy	3300.00
0005432382709	31328	Economy	3300.00
0005432382665	31328	Economy	3300.00
0005432382818	31328	Economy	3300.00
0005432382815	31328	Economy	3300.00
0005432382811	31328	Economy	3300.00
0005432382865	31328	Economy	3300.00
0005432382857	31328	Economy	3300.00
0005432382910	31328	Economy	3300.00
0005432382584	31328	Economy	3300.00
0005433449813	31328	Economy	3300.00
0005432382740	31328	Economy	3300.00
0005432382878	31328	Economy	3300.00
0005432382783	31328	Economy	3300.00
0005433449869	31328	Economy	3300.00
0005433449695	31328	Economy	3300.00
0005432382906	31328	Economy	3300.00
0005432382718	31328	Economy	3300.00
0005433449814	31328	Economy	3300.00
0005432382792	31328	Economy	3300.00
0005433451611	31328	Economy	3300.00
0005433449886	31328	Economy	3300.00
0005433449719	31328	Economy	3300.00
0005432382741	31328	Economy	3300.00
0005432382782	31328	Economy	3300.00
0005432382794	31328	Economy	3300.00
0005432382880	31328	Economy	3300.00
0005432382666	31328	Economy	3300.00
0005433451598	31328	Economy	3300.00
0005433449817	31328	Economy	3300.00
0005432382696	31328	Economy	3300.00
0005433449778	31328	Economy	3300.00
0005432382875	31328	Economy	3300.00
0005432382713	31328	Economy	3300.00
0005432382874	31328	Economy	3300.00
0005432382876	31328	Economy	3300.00
0005432382739	31328	Economy	3300.00
0005433449718	31328	Economy	3300.00
0005432382702	31328	Economy	3300.00
0005432382735	31328	Economy	3300.00
0005432382793	31328	Economy	3300.00
0005433449771	31328	Economy	3300.00
0005433449761	31328	Economy	3300.00
0005432382694	31328	Economy	3300.00
0005433131679	10788	Economy	17100.00
0005435299738	10788	Economy	17100.00
0005435299736	10788	Economy	17100.00
0005435304111	10788	Economy	15600.00
0005435304128	10788	Economy	15600.00
0005433126788	10788	Economy	15600.00
0005433131678	10788	Economy	15600.00
0005435299723	10788	Economy	15600.00
0005433126773	10788	Economy	15600.00
0005433126793	10788	Economy	15600.00
0005433126772	10788	Economy	15600.00
0005435304123	10788	Economy	15600.00
0005433131645	10788	Economy	15600.00
0005435299726	10788	Economy	15600.00
0005433126789	10788	Economy	15600.00
0005433126792	10788	Economy	15600.00
0005435299724	10788	Economy	15600.00
0005435304103	10788	Economy	15600.00
0005435304132	10788	Economy	15600.00
0005433126790	10788	Economy	15600.00
0005435304122	10788	Economy	15600.00
0005435304129	10788	Economy	15600.00
0005435304119	10788	Economy	15600.00
0005433129281	29747	Economy	15600.00
0005435299781	29747	Economy	15600.00
0005435302204	29747	Economy	15600.00
0005433126850	29747	Economy	15600.00
0005435299779	29747	Economy	15600.00
0005433126849	29747	Economy	15600.00
0005433129280	29747	Economy	15600.00
0005433129279	29747	Economy	15600.00
0005433126851	29747	Economy	15600.00
0005435299782	29747	Economy	15600.00
0005435302203	29747	Economy	15600.00
0005435299778	29747	Economy	15600.00
0005435299780	29747	Economy	15600.00
0005433129278	29747	Economy	15600.00
0005433126848	29747	Economy	15600.00
0005435302202	29747	Economy	15600.00
0005434287285	2399	Economy	17200.00
0005434287282	2399	Economy	17200.00
0005434287281	2399	Economy	17200.00
0005434287280	2399	Economy	17200.00
0005434287283	2399	Economy	15700.00
0005433109956	2399	Economy	15700.00
0005433109993	2399	Economy	15700.00
0005434287289	2399	Economy	15700.00
0005433109946	2399	Economy	15700.00
0005432264476	2399	Economy	15700.00
0005433109957	2399	Economy	15700.00
0005434287290	2399	Economy	15700.00
0005434287294	2399	Economy	15700.00
0005434287296	2399	Economy	15700.00
0005434287297	2399	Economy	15700.00
0005433109980	2399	Economy	15700.00
0005434287292	2399	Economy	15700.00
0005433109981	2399	Economy	15700.00
0005434287288	2399	Economy	15700.00
0005434287299	2399	Economy	15700.00
0005433109971	2399	Economy	15700.00
0005433109969	2399	Economy	15700.00
0005434287284	2399	Economy	15700.00
0005434287302	2399	Economy	15700.00
0005433109945	2399	Economy	15700.00
0005434287279	2399	Economy	15700.00
0005433110001	2399	Economy	15700.00
0005434287291	2399	Economy	15700.00
0005433109919	2399	Economy	15700.00
0005433109923	2399	Economy	15700.00
0005434287287	2399	Economy	15700.00
0005434287298	2399	Economy	15700.00
0005433109970	2399	Economy	15700.00
0005434287286	2399	Economy	15700.00
0005434287293	2399	Economy	15700.00
0005434287295	2399	Economy	15700.00
0005432264475	2399	Economy	15700.00
0005433109899	2399	Economy	15700.00
0005434287301	2399	Economy	15700.00
0005433110000	2399	Economy	15700.00
0005434287300	2399	Economy	15700.00
0005434287072	26850	Economy	17200.00
0005433110059	26850	Economy	17200.00
0005434287130	26850	Economy	15700.00
0005433110049	26850	Economy	15700.00
0005434287197	26850	Economy	15700.00
0005433110052	26850	Economy	15700.00
0005433110058	26850	Economy	15700.00
0005433110053	26850	Economy	15700.00
0005434287013	26850	Economy	15700.00
0005434287196	26850	Economy	15700.00
0005433110050	26850	Economy	15700.00
0005434287055	26850	Economy	15700.00
0005434287124	26850	Economy	15700.00
0005434287153	26850	Economy	15700.00
0005434287092	26850	Economy	15700.00
0005434287066	26850	Economy	15700.00
0005434287090	26850	Economy	15700.00
0005433110051	26850	Economy	15700.00
0005433110048	26850	Economy	15700.00
0005434287103	26850	Economy	15700.00
0005433110055	26850	Economy	15700.00
0005433110054	26850	Economy	15700.00
0005434287073	26850	Economy	15700.00
0005434287113	26850	Economy	15700.00
0005434287184	26850	Economy	15700.00
0005434287074	26850	Economy	15700.00
0005433110060	26850	Economy	15700.00
0005434287114	26850	Economy	15700.00
0005434287091	26850	Economy	15700.00
0005434287075	26850	Economy	15700.00
0005433110057	26850	Economy	15700.00
0005434287125	26850	Economy	15700.00
0005433110056	26850	Economy	15700.00
0005434287067	26850	Economy	15700.00
0005434269071	25489	Economy	25000.00
0005435856205	25489	Economy	22800.00
0005435856206	25489	Economy	22800.00
0005434272176	25489	Economy	22800.00
0005434269081	25489	Economy	22800.00
0005435856204	25489	Economy	22800.00
0005435856207	25489	Economy	22800.00
0005434269082	25489	Economy	22800.00
0005434269080	25489	Economy	22800.00
0005434269077	25489	Economy	22800.00
0005434272177	25489	Economy	22800.00
0005434272192	26647	Economy	22800.00
0005434273075	26647	Economy	22800.00
0005434273076	26647	Economy	22800.00
0005434273077	26647	Economy	22800.00
0005433868460	4795	Economy	19400.00
0005433868446	4795	Economy	19400.00
0005433868467	4795	Economy	19400.00
0005433868438	4795	Economy	17600.00
0005433868449	4795	Economy	17600.00
0005433868471	4795	Economy	17600.00
0005433868436	4795	Economy	17600.00
0005433868463	4795	Economy	17600.00
0005433868432	4795	Economy	17600.00
0005433868440	4795	Economy	17600.00
0005435860450	4795	Economy	17600.00
0005433868452	4795	Economy	17600.00
0005433868447	4795	Economy	17600.00
0005433868457	4795	Economy	17600.00
0005433868458	4795	Economy	17600.00
0005433868439	4795	Economy	17600.00
0005435860451	4795	Economy	17600.00
0005433868464	4795	Economy	17600.00
0005433868469	4795	Economy	17600.00
0005433868433	4795	Economy	17600.00
0005433868468	4795	Economy	17600.00
0005433868462	4795	Economy	17600.00
0005433868450	4795	Economy	17600.00
0005433868431	4795	Economy	17600.00
0005433868448	4795	Economy	17600.00
0005433868451	4795	Economy	17600.00
0005433868456	4795	Economy	17600.00
0005433868444	4795	Economy	17600.00
0005433868445	4795	Economy	17600.00
0005435860452	4795	Economy	17600.00
0005433868454	4795	Economy	17600.00
0005435860446	4795	Economy	17600.00
0005433868453	4795	Economy	17600.00
0005433868441	4795	Economy	17600.00
0005433868435	4795	Economy	17600.00
0005433868434	4795	Economy	17600.00
0005433868442	4795	Economy	17600.00
0005433868437	4795	Economy	17600.00
0005433868455	4795	Economy	17600.00
0005433868466	4795	Economy	17600.00
0005433868443	4795	Economy	17600.00
0005433868470	4795	Economy	17600.00
0005433868461	4795	Economy	17600.00
0005433868472	4795	Economy	17600.00
0005433868459	4795	Economy	17600.00
0005433868465	4795	Economy	17600.00
0005433868187	32618	Economy	19400.00
0005433868078	32618	Economy	19400.00
0005433868168	32618	Economy	19400.00
0005433868002	32618	Economy	19400.00
0005433868119	32618	Economy	17600.00
0005433868167	32618	Economy	17600.00
0005433868053	32618	Economy	17600.00
0005433868207	32618	Economy	17600.00
0005433868026	32618	Economy	17600.00
0005433868082	32618	Economy	17600.00
0005433868003	32618	Economy	17600.00
0005433867916	32618	Economy	17600.00
0005433868035	32618	Economy	17600.00
0005433867917	32618	Economy	17600.00
0005433868000	32618	Economy	17600.00
0005433868177	32618	Economy	17600.00
0005433868113	32618	Economy	17600.00
0005433868011	32618	Economy	17600.00
0005433868209	32618	Economy	17600.00
0005433868041	32618	Economy	17600.00
0005433868097	32618	Economy	17600.00
0005433868020	32618	Economy	17600.00
0005433868176	32618	Economy	17600.00
0005433867935	32618	Economy	17600.00
0005433868005	32618	Economy	17600.00
0005433867874	32618	Economy	17600.00
0005433868036	32618	Economy	17600.00
0005433868208	32618	Economy	17600.00
0005433868001	32618	Economy	17600.00
0005433867901	32618	Economy	17600.00
0005433868042	32618	Economy	17600.00
0005433868250	32618	Economy	17600.00
0005433868096	32618	Economy	17600.00
0005433868198	32618	Economy	17600.00
0005433868118	32618	Economy	17600.00
0005433868178	32618	Economy	17600.00
0005433868021	32618	Economy	17600.00
0005433867897	32618	Economy	17600.00
0005433868249	32618	Economy	17600.00
0005433867896	32618	Economy	17600.00
0005433868045	32618	Economy	17600.00
0005433867971	32618	Economy	17600.00
0005433868039	32618	Economy	17600.00
0005433867960	32618	Economy	17600.00
0005433868141	32618	Economy	17600.00
0005433868172	32618	Economy	17600.00
0005433868114	32618	Economy	17600.00
0005434663403	3418	Economy	24800.00
0005435911370	3418	Economy	24800.00
0005434663412	3418	Economy	22600.00
0005435911400	3418	Economy	22600.00
0005434663410	3418	Economy	22600.00
0005434663409	3418	Economy	22600.00
0005434663413	3418	Economy	22600.00
0005434663408	3418	Economy	22600.00
0005434663405	3418	Economy	22600.00
0005435911393	3418	Economy	22600.00
0005434663415	3418	Economy	22600.00
0005434663414	3418	Economy	22600.00
0005434460505	3418	Economy	22600.00
0005435911395	3418	Economy	22600.00
0005435911409	3418	Economy	22600.00
0005434460507	3418	Economy	22600.00
0005434663406	3418	Economy	22600.00
0005434663407	3418	Economy	22600.00
0005435911408	3418	Economy	22600.00
0005434663402	3418	Economy	22600.00
0005434460506	3418	Economy	22600.00
0005434461646	3418	Economy	22600.00
0005434663416	3418	Economy	22600.00
0005434663411	3418	Economy	22600.00
0005434461647	3418	Economy	22600.00
0005435911392	3418	Economy	22600.00
0005434663404	3418	Economy	22600.00
0005434663211	12481	Economy	24800.00
0005435911451	12481	Economy	22600.00
0005434663337	12481	Economy	22600.00
0005435911454	12481	Economy	22600.00
0005434663329	12481	Economy	22600.00
0005434663310	12481	Economy	22600.00
0005434663342	12481	Economy	22600.00
0005435911448	12481	Economy	22600.00
0005435911455	12481	Economy	22600.00
0005434663294	12481	Economy	22600.00
0005434663303	12481	Economy	22600.00
0005435911453	12481	Economy	22600.00
0005434663307	12481	Economy	22600.00
0005435911450	12481	Economy	22600.00
0005434663311	12481	Economy	22600.00
0005434663330	12481	Economy	22600.00
0005434663284	12481	Economy	22600.00
0005434663308	12481	Economy	22600.00
0005434663238	12481	Economy	22600.00
0005434663253	12481	Economy	22600.00
0005435911452	12481	Economy	22600.00
0005435911449	12481	Economy	22600.00
0005433868176	14518	Economy	18500.00
0005433868035	14518	Economy	18500.00
0005433867897	14518	Economy	18500.00
0005433868036	14518	Economy	18500.00
0005433868045	14518	Economy	16800.00
0005433868020	14518	Economy	16800.00
0005433868249	14518	Economy	16800.00
0005433867896	14518	Economy	16800.00
0005433868001	14518	Economy	16800.00
0005433868000	14518	Economy	16800.00
0005433868207	14518	Economy	16800.00
0005433868250	14518	Economy	16800.00
0005433868118	14518	Economy	16800.00
0005433868011	14518	Economy	16800.00
0005433868003	14518	Economy	16800.00
0005433867960	14518	Economy	16800.00
0005433868167	14518	Economy	16800.00
0005433868208	14518	Economy	16800.00
0005433868113	14518	Economy	16800.00
0005433867971	14518	Economy	16800.00
0005433868114	14518	Economy	16800.00
0005433868178	14518	Economy	16800.00
0005433868078	14518	Economy	16800.00
0005433867874	14518	Economy	16800.00
0005433868005	14518	Economy	16800.00
0005433868026	14518	Economy	16800.00
0005433868172	14518	Economy	16800.00
0005433867917	14518	Economy	16800.00
0005433868042	14518	Economy	16800.00
0005433868096	14518	Economy	16800.00
0005433868177	14518	Economy	16800.00
0005433868141	14518	Economy	16800.00
0005433868039	14518	Economy	16800.00
0005433868041	14518	Economy	16800.00
0005433868002	14518	Economy	16800.00
0005433867901	14518	Economy	16800.00
0005433868053	14518	Economy	16800.00
0005433868119	14518	Economy	16800.00
0005433868097	14518	Economy	16800.00
0005433867916	14518	Economy	16800.00
0005433868209	14518	Economy	16800.00
0005433868021	14518	Economy	16800.00
0005433868168	14518	Economy	16800.00
0005433867935	14518	Economy	16800.00
0005433868198	14518	Economy	16800.00
0005433868082	14518	Economy	16800.00
0005433868187	14518	Economy	16800.00
0005433868419	32669	Economy	18500.00
0005433868393	32669	Economy	18500.00
0005433868406	32669	Economy	18500.00
0005433868402	32669	Economy	18500.00
0005433868424	32669	Economy	16800.00
0005433868427	32669	Economy	16800.00
0005433868409	32669	Economy	16800.00
0005433868397	32669	Economy	16800.00
0005433868422	32669	Economy	16800.00
0005433868416	32669	Economy	16800.00
0005435860434	32669	Economy	16800.00
0005433868400	32669	Economy	16800.00
0005433868391	32669	Economy	16800.00
0005433868407	32669	Economy	16800.00
0005435860436	32669	Economy	16800.00
0005433868411	32669	Economy	16800.00
0005433868414	32669	Economy	16800.00
0005433868396	32669	Economy	16800.00
0005433868410	32669	Economy	16800.00
0005433868430	32669	Economy	16800.00
0005435860437	32669	Economy	16800.00
0005433868388	32669	Economy	16800.00
0005435860435	32669	Economy	16800.00
0005433868390	32669	Economy	16800.00
0005433868423	32669	Economy	16800.00
0005433868426	32669	Economy	16800.00
0005435860445	32669	Economy	16800.00
0005433868405	32669	Economy	16800.00
0005433868398	32669	Economy	16800.00
0005433868399	32669	Economy	16800.00
0005433868403	32669	Economy	16800.00
0005433868415	32669	Economy	16800.00
0005433868425	32669	Economy	16800.00
0005433868392	32669	Economy	16800.00
0005433868394	32669	Economy	16800.00
0005433868417	32669	Economy	16800.00
0005433868408	32669	Economy	16800.00
0005433868428	32669	Economy	16800.00
0005433868418	32669	Economy	16800.00
0005433868413	32669	Economy	16800.00
0005433868401	32669	Economy	16800.00
0005433868404	32669	Economy	16800.00
0005433868421	32669	Economy	16800.00
0005433868395	32669	Economy	16800.00
0005435860439	32669	Economy	16800.00
0005433868412	32669	Economy	16800.00
0005433868429	32669	Economy	16800.00
0005433868389	32669	Economy	16800.00
0005433868420	32669	Economy	16800.00
0005432799236	12106	Economy	4900.00
0005432799104	12106	Economy	4900.00
0005432799219	12106	Economy	4900.00
0005432799201	12106	Economy	4400.00
0005432799343	12106	Economy	4400.00
0005432799199	12106	Economy	4400.00
0005432799180	12106	Economy	4400.00
0005432799291	12106	Economy	4400.00
0005432799231	12106	Economy	4400.00
0005432799290	12106	Economy	4400.00
0005432799318	12106	Economy	4400.00
0005432799169	12106	Economy	4400.00
0005432799222	12106	Economy	4400.00
0005432799179	12106	Economy	4400.00
0005432799319	12106	Economy	4400.00
0005432799342	12106	Economy	4400.00
0005432799130	12106	Economy	4400.00
0005432799200	12106	Economy	4400.00
0005432799250	12106	Economy	4400.00
0005432799235	12106	Economy	4400.00
0005432799317	12106	Economy	4400.00
0005432799263	12106	Economy	4400.00
0005432799168	12106	Economy	4400.00
0005432799137	12106	Economy	4400.00
0005432799105	12106	Economy	4400.00
0005432799232	12106	Economy	4400.00
0005432799056	12106	Economy	4400.00
0005432799221	12106	Economy	4400.00
0005432799213	12106	Economy	4400.00
0005432799435	14809	Economy	4900.00
0005432799428	14809	Economy	4900.00
0005432799424	14809	Economy	4900.00
0005432799432	14809	Economy	4400.00
0005432799443	14809	Economy	4400.00
0005432799419	14809	Economy	4400.00
0005432799418	14809	Economy	4400.00
0005432799433	14809	Economy	4400.00
0005432799440	14809	Economy	4400.00
0005432799439	14809	Economy	4400.00
0005432799437	14809	Economy	4400.00
0005432799423	14809	Economy	4400.00
0005432799438	14809	Economy	4400.00
0005432799420	14809	Economy	4400.00
0005432799441	14809	Economy	4400.00
0005432799442	14809	Economy	4400.00
0005432799429	14809	Economy	4400.00
0005432799434	14809	Economy	4400.00
0005432799436	14809	Economy	4400.00
0005432799426	14809	Economy	4400.00
0005432799417	14809	Economy	4400.00
0005432799421	14809	Economy	4400.00
0005432799430	14809	Economy	4400.00
0005432799422	14809	Economy	4400.00
0005432799427	14809	Economy	4400.00
0005432799425	14809	Economy	4400.00
0005432799416	14809	Economy	4400.00
0005432799431	14809	Economy	4400.00
0005435293170	7059	Business	49100.00
0005435293106	7059	Business	49100.00
0005435310947	7059	Business	49100.00
0005434407771	7059	Business	49100.00
0005434299565	7059	Business	49100.00
0005434407740	7059	Business	49100.00
0005434407796	7059	Business	49100.00
0005434407791	7059	Business	49100.00
0005435293180	7059	Business	49100.00
0005434407747	7059	Business	49100.00
0005435310941	7059	Business	49100.00
0005435293111	7059	Business	49100.00
0005434407792	7059	Economy	16400.00
0005434407758	7059	Economy	16400.00
0005434407744	7059	Economy	16400.00
0005434407760	7059	Economy	16400.00
0005434299561	7059	Economy	16400.00
0005434407788	7059	Economy	16400.00
0005435310932	7059	Economy	16400.00
0005434407739	7059	Economy	16400.00
0005434407762	7059	Economy	16400.00
0005434407768	7059	Economy	16400.00
0005435293143	7059	Economy	16400.00
0005434407764	7059	Economy	16400.00
0005435310905	7059	Economy	16400.00
0005434407793	7059	Economy	16400.00
0005434407765	7059	Economy	16400.00
0005434299574	7059	Economy	16400.00
0005434407776	7059	Economy	16400.00
0005434407767	7059	Economy	16400.00
0005434299554	7059	Economy	16400.00
0005434407769	7059	Economy	16400.00
0005434407755	7059	Economy	16400.00
0005434407772	7059	Economy	16400.00
0005434407766	7059	Economy	16400.00
0005434407774	7059	Economy	16400.00
0005434299562	7059	Economy	16400.00
0005435310946	7059	Economy	16400.00
0005434407798	7059	Economy	16400.00
0005435310922	7059	Economy	16400.00
0005434407743	7059	Economy	16400.00
0005432153941	7059	Economy	16400.00
0005434407787	7059	Economy	16400.00
0005432108251	7059	Economy	16400.00
0005435293155	7059	Economy	16400.00
0005435293142	7059	Economy	16400.00
0005435310957	7059	Economy	16400.00
0005435293125	7059	Economy	16400.00
0005435310950	7059	Economy	16400.00
0005434299556	7059	Economy	16400.00
0005435293146	7059	Economy	16400.00
0005434407746	7059	Economy	18000.00
0005434407775	7059	Economy	16400.00
0005434407759	7059	Economy	18000.00
0005434299552	7059	Economy	18000.00
0005434299572	7059	Economy	18000.00
0005434407778	7059	Economy	18000.00
0005434407737	7059	Economy	18000.00
0005434407763	7059	Economy	16400.00
0005434407789	7059	Economy	16400.00
0005432153936	7059	Economy	16400.00
0005434299557	7059	Economy	16400.00
0005434407742	7059	Economy	16400.00
0005434407784	7059	Economy	16400.00
0005434407748	7059	Economy	16400.00
0005434299573	7059	Economy	16400.00
0005434407741	7059	Economy	16400.00
0005434407773	7059	Economy	16400.00
0005434299571	7059	Economy	16400.00
0005434299551	7059	Economy	16400.00
0005434299567	7059	Economy	16400.00
0005432108250	7059	Economy	16400.00
0005434407754	7059	Economy	16400.00
0005435293145	7059	Economy	16400.00
0005434407797	7059	Economy	16400.00
0005434407783	7059	Economy	16400.00
0005434407738	7059	Economy	16400.00
0005434407799	7059	Economy	16400.00
0005434299555	7059	Economy	16400.00
0005434407786	7059	Economy	16400.00
0005434407795	7059	Economy	16400.00
0005432153942	7059	Economy	16400.00
0005432153939	7059	Economy	16400.00
0005434407736	7059	Economy	16400.00
0005434407753	7059	Economy	16400.00
0005434407777	7059	Economy	16400.00
0005435310934	7059	Economy	16400.00
0005434299566	7059	Economy	16400.00
0005434407770	7059	Economy	16400.00
0005434299568	7059	Economy	16400.00
0005434407745	7059	Economy	16400.00
0005434299553	7059	Economy	16400.00
0005434407751	7059	Economy	16400.00
0005432153940	7059	Economy	16400.00
0005432153938	7059	Economy	16400.00
0005435293163	7059	Economy	16400.00
0005435293107	7059	Economy	16400.00
0005434407781	7059	Economy	16400.00
0005434407779	7059	Economy	16400.00
0005434299569	7059	Economy	16400.00
0005434407761	7059	Economy	16400.00
0005434407757	7059	Economy	16400.00
0005434407750	7059	Economy	16400.00
0005434407756	7059	Economy	16400.00
0005434299570	7059	Economy	16400.00
0005434299560	7059	Economy	16400.00
0005434407782	7059	Economy	16400.00
0005434299559	7059	Economy	16400.00
0005435293181	7059	Economy	16400.00
0005434299563	7059	Economy	16400.00
0005434407780	7059	Economy	16400.00
0005434299564	7059	Economy	16400.00
0005434299558	7059	Economy	16400.00
0005435310936	7059	Economy	16400.00
0005432108249	7059	Economy	16400.00
0005434407790	7059	Economy	16400.00
0005434407752	7059	Economy	16400.00
0005435310933	7059	Economy	16400.00
0005434407785	7059	Economy	16400.00
0005432153935	7059	Economy	16400.00
0005434407794	7059	Economy	16400.00
0005432153937	7059	Economy	16400.00
0005434407749	7059	Economy	16400.00
0005434407423	26883	Business	49100.00
0005434407262	26883	Business	49100.00
0005434407277	26883	Business	49100.00
0005434407184	26883	Business	49100.00
0005434299393	26883	Business	49100.00
0005434407079	26883	Business	49100.00
0005434407080	26883	Business	49100.00
0005434407261	26883	Business	49100.00
0005434407061	26883	Economy	16400.00
0005434299381	26883	Economy	16400.00
0005434407287	26883	Economy	16400.00
0005434407132	26883	Economy	16400.00
0005434407341	26883	Economy	16400.00
0005434407275	26883	Economy	16400.00
0005432058376	26883	Economy	16400.00
0005435293249	26883	Economy	16400.00
0005435293250	26883	Economy	16400.00
0005434407062	26883	Economy	16400.00
0005435311054	26883	Economy	16400.00
0005432058380	26883	Economy	16400.00
0005434407137	26883	Economy	16400.00
0005435311060	26883	Economy	16400.00
0005435293258	26883	Economy	16400.00
0005434407400	26883	Economy	16400.00
0005435311056	26883	Economy	16400.00
0005434407461	26883	Economy	16400.00
0005434299495	26883	Economy	16400.00
0005434407276	26883	Economy	16400.00
0005434406850	26883	Economy	16400.00
0005434299409	26883	Economy	16400.00
0005434407244	26883	Economy	16400.00
0005435311057	26883	Economy	16400.00
0005435293254	26883	Economy	16400.00
0005434299431	26883	Economy	16400.00
0005434407346	26883	Economy	16400.00
0005435293257	26883	Economy	16400.00
0005435293252	26883	Economy	16400.00
0005434299369	26883	Economy	16400.00
0005435311052	26883	Economy	16400.00
0005434299370	26883	Economy	16400.00
0005434407108	26883	Economy	18000.00
0005434406975	26883	Economy	18000.00
0005434406973	26883	Economy	18000.00
0005434407156	26883	Economy	18000.00
0005434407342	26883	Economy	18000.00
0005434299416	26883	Economy	16400.00
0005434299382	26883	Economy	16400.00
0005432058377	26883	Economy	16400.00
0005434299364	26883	Economy	16400.00
0005434299307	26883	Economy	16400.00
0005434407045	26883	Economy	16400.00
0005434299423	26883	Economy	16400.00
0005434299501	26883	Economy	16400.00
0005434299493	26883	Economy	16400.00
0005434407059	26883	Economy	16400.00
0005434407348	26883	Economy	16400.00
0005435311059	26883	Economy	16400.00
0005434407074	26883	Economy	16400.00
0005434299267	26883	Economy	16400.00
0005435293256	26883	Economy	16400.00
0005434407155	26883	Economy	16400.00
0005434299380	26883	Economy	16400.00
0005434407183	26883	Economy	16400.00
0005434299287	26883	Economy	16400.00
0005434299353	26883	Economy	16400.00
0005435293255	26883	Economy	16400.00
0005434407460	26883	Economy	16400.00
0005434407053	26883	Economy	16400.00
0005434407281	26883	Economy	16400.00
0005434299390	26883	Economy	16400.00
0005434407422	26883	Economy	16400.00
0005435293253	26883	Economy	16400.00
0005435293251	26883	Economy	16400.00
0005434407260	26883	Economy	16400.00
0005434299496	26883	Economy	16400.00
0005434299308	26883	Economy	16400.00
0005435311055	26883	Economy	16400.00
0005435293259	26883	Economy	16400.00
0005435293248	26883	Economy	16400.00
0005434407025	26883	Economy	16400.00
0005434299286	26883	Economy	16400.00
0005435293247	26883	Economy	16400.00
0005434407046	26883	Economy	16400.00
0005434407347	26883	Economy	16400.00
0005434407049	26883	Economy	16400.00
0005434407278	26883	Economy	16400.00
0005434407401	26883	Economy	16400.00
0005434299502	26883	Economy	16400.00
0005434407182	26883	Economy	16400.00
0005434406963	26883	Economy	16400.00
0005434407172	26883	Economy	16400.00
0005434299371	26883	Economy	16400.00
0005434407098	26883	Economy	16400.00
0005435311058	26883	Economy	16400.00
0005432058378	26883	Economy	16400.00
0005434407095	26883	Economy	16400.00
0005435311061	26883	Economy	16400.00
0005435311062	26883	Economy	16400.00
0005434299408	26883	Economy	16400.00
0005434407039	26883	Economy	16400.00
0005434407288	26883	Economy	16400.00
0005434407006	26883	Economy	16400.00
0005434299322	26883	Economy	16400.00
0005434407298	26883	Economy	16400.00
0005432058379	26883	Economy	16400.00
0005435311053	26883	Economy	16400.00
0005432604337	6460	Economy	16500.00
0005432604371	6460	Economy	16500.00
0005432604368	6460	Economy	16500.00
0005432604343	6460	Economy	16500.00
0005434512120	6460	Economy	15000.00
0005432604338	6460	Economy	15000.00
0005434512121	6460	Economy	15000.00
0005434512115	6460	Economy	15000.00
0005432604370	6460	Economy	15000.00
0005432604347	6460	Economy	15000.00
0005432604334	6460	Economy	15000.00
0005434512118	6460	Economy	15000.00
0005432604365	6460	Economy	15000.00
0005432604358	6460	Economy	15000.00
0005432604332	6460	Economy	15000.00
0005432604359	6460	Economy	15000.00
0005432604346	6460	Economy	15000.00
0005434512116	6460	Economy	15000.00
0005432604353	6460	Economy	15000.00
0005432604350	6460	Economy	15000.00
0005432604348	6460	Economy	15000.00
0005434512117	6460	Economy	15000.00
0005432604363	6460	Economy	15000.00
0005432604362	6460	Economy	15000.00
0005432604341	6460	Economy	15000.00
0005432604335	6460	Economy	15000.00
0005432604367	6460	Economy	15000.00
0005432604356	6460	Economy	15000.00
0005432604366	6460	Economy	15000.00
0005434512119	6460	Economy	15000.00
0005432604354	6460	Economy	15000.00
0005432604339	6460	Economy	15000.00
0005432604345	6460	Economy	15000.00
0005432604349	6460	Economy	15000.00
0005432604361	6460	Economy	15000.00
0005432604336	6460	Economy	15000.00
0005432604352	6460	Economy	15000.00
0005432604360	6460	Economy	15000.00
0005432604340	6460	Economy	15000.00
0005432604357	6460	Economy	15000.00
0005432604333	6460	Economy	15000.00
0005432604351	6460	Economy	15000.00
0005432604364	6460	Economy	15000.00
0005432604369	6460	Economy	15000.00
0005432604355	6460	Economy	15000.00
0005432604344	6460	Economy	15000.00
0005432604342	6460	Economy	15000.00
0005434512073	21345	Economy	16500.00
0005432603828	21345	Economy	16500.00
0005432604072	21345	Economy	16500.00
0005432603792	21345	Economy	16500.00
0005432603827	21345	Economy	15000.00
0005432603908	21345	Economy	15000.00
0005432604007	21345	Economy	15000.00
0005432603937	21345	Economy	15000.00
0005432604036	21345	Economy	15000.00
0005432603909	21345	Economy	15000.00
0005432603998	21345	Economy	15000.00
0005432604053	21345	Economy	15000.00
0005434512061	21345	Economy	15000.00
0005432603894	21345	Economy	15000.00
0005432603918	21345	Economy	15000.00
0005432603962	21345	Economy	15000.00
0005432604070	21345	Economy	15000.00
0005432603934	21345	Economy	15000.00
0005432603969	21345	Economy	15000.00
0005432604073	21345	Economy	15000.00
0005432603848	21345	Economy	15000.00
0005432603749	21345	Economy	15000.00
0005432604044	21345	Economy	15000.00
0005432603884	21345	Economy	15000.00
0005432603893	21345	Economy	15000.00
0005432604078	21345	Economy	15000.00
0005432603800	21345	Economy	15000.00
0005432603956	21345	Economy	15000.00
0005434512079	21345	Economy	15000.00
0005432604110	21345	Economy	15000.00
0005432604068	21345	Economy	15000.00
0005432604001	21345	Economy	15000.00
0005434512080	21345	Economy	15000.00
0005434512078	21345	Economy	15000.00
0005432603678	21345	Economy	15000.00
0005432604081	21345	Economy	15000.00
0005432603896	21345	Economy	15000.00
0005432603847	21345	Economy	15000.00
0005432604008	21345	Economy	15000.00
0005432604006	21345	Economy	15000.00
0005432603995	21345	Economy	15000.00
0005432603927	21345	Economy	15000.00
0005432603947	21345	Economy	15000.00
0005432604080	21345	Economy	15000.00
0005432603920	21345	Economy	15000.00
0005434512060	21345	Economy	15000.00
0005432603919	21345	Economy	15000.00
0005432604002	21345	Economy	15000.00
0005434906892	15019	Business	18900.00
0005433251467	15019	Business	18900.00
0005434906843	15019	Business	18900.00
0005433251473	15019	Business	18900.00
0005433251478	15019	Business	18900.00
0005434906898	15019	Business	18900.00
0005434906647	15019	Business	18900.00
0005434906831	15019	Business	18900.00
0005433251495	15019	Business	18900.00
0005434906789	15019	Business	18900.00
0005434906725	15019	Economy	6300.00
0005434906646	15019	Economy	6300.00
0005433251477	15019	Economy	6300.00
0005434906643	15019	Economy	6300.00
0005433251474	15019	Economy	6300.00
0005434906731	15019	Economy	6300.00
0005434906701	15019	Economy	6300.00
0005433251482	15019	Economy	6300.00
0005433251481	15019	Economy	6300.00
0005434906607	15019	Economy	6900.00
0005434906828	15019	Economy	6900.00
0005434906543	15019	Economy	6900.00
0005434906825	15019	Economy	6900.00
0005433251470	15019	Economy	6900.00
0005434906835	15019	Economy	6300.00
0005434906621	15019	Economy	6300.00
0005434906881	15019	Economy	6300.00
0005434906757	15019	Economy	6300.00
0005433251475	15019	Economy	6300.00
0005433251488	15019	Economy	6300.00
0005434906889	15019	Economy	6300.00
0005433251491	15019	Economy	6300.00
0005434906718	15019	Economy	6300.00
0005433251493	15019	Economy	6300.00
0005433251489	15019	Economy	6300.00
0005434906880	15019	Economy	6300.00
0005434906692	15019	Economy	6300.00
0005434906876	15019	Economy	6300.00
0005434906795	15019	Economy	6300.00
0005433251480	15019	Economy	6300.00
0005433251494	15019	Economy	6300.00
0005434906821	15019	Economy	6300.00
0005434906827	15019	Economy	6300.00
0005434906814	15019	Economy	6300.00
0005434906539	15019	Economy	6300.00
0005434906844	15019	Economy	6300.00
0005434906700	15019	Economy	6300.00
0005434906716	15019	Economy	6300.00
0005434906829	15019	Economy	6300.00
0005434906455	15019	Economy	6300.00
0005434906752	15019	Economy	6300.00
0005434906721	15019	Economy	6300.00
0005433251490	15019	Economy	6300.00
0005433251484	15019	Economy	6300.00
0005434906605	15019	Economy	6300.00
0005434906644	15019	Economy	6300.00
0005434906830	15019	Economy	6300.00
0005433251466	15019	Economy	6300.00
0005434906836	15019	Economy	6300.00
0005433251471	15019	Economy	6300.00
0005434906733	15019	Economy	6300.00
0005434906839	15019	Economy	6300.00
0005434906834	15019	Economy	6300.00
0005433251483	15019	Economy	6300.00
0005434906788	15019	Economy	6300.00
0005434906790	15019	Economy	6300.00
0005434906699	15019	Economy	6300.00
0005434906645	15019	Economy	6300.00
0005433251492	15019	Economy	6300.00
0005434906853	15019	Economy	6300.00
0005433251465	15019	Economy	6300.00
0005434906772	15019	Economy	6300.00
0005433251469	15019	Economy	6300.00
0005434906734	15019	Economy	6300.00
0005433251476	15019	Economy	6300.00
0005433251487	15019	Economy	6300.00
0005434906691	15019	Economy	6300.00
0005433251468	15019	Economy	6300.00
0005434906742	15019	Economy	6300.00
0005434906893	15019	Economy	6300.00
0005434906852	15019	Economy	6300.00
0005433251485	15019	Economy	6300.00
0005434906820	15019	Economy	6300.00
0005433251486	15019	Economy	6300.00
0005433251472	15019	Economy	6300.00
0005433251479	15019	Economy	6300.00
0005434906717	15019	Economy	6300.00
0005433251193	25864	Business	18900.00
0005434907216	25864	Business	18900.00
0005433251227	25864	Business	18900.00
0005434907261	25864	Business	18900.00
0005434907219	25864	Business	18900.00
0005434907257	25864	Business	18900.00
0005433251145	25864	Business	18900.00
0005434907249	25864	Business	18900.00
0005434907244	25864	Business	18900.00
0005433251091	25864	Economy	6300.00
0005433251172	25864	Economy	6300.00
0005434907246	25864	Economy	6300.00
0005433251179	25864	Economy	6300.00
0005433251210	25864	Economy	6300.00
0005433251264	25864	Economy	6300.00
0005434907228	25864	Economy	6300.00
0005434907245	25864	Economy	6300.00
0005434907252	25864	Economy	6300.00
0005434907243	25864	Economy	6900.00
0005434907236	25864	Economy	6900.00
0005434907240	25864	Economy	6900.00
0005434907242	25864	Economy	6900.00
0005434907214	25864	Economy	6300.00
0005433251307	25864	Economy	6300.00
0005434907217	25864	Economy	6300.00
0005433251246	25864	Economy	6300.00
0005433251281	25864	Economy	6300.00
0005433251322	25864	Economy	6300.00
0005434907237	25864	Economy	6300.00
0005433251218	25864	Economy	6300.00
0005434907241	25864	Economy	6300.00
0005434907223	25864	Economy	6300.00
0005434907224	25864	Economy	6300.00
0005433251144	25864	Economy	6300.00
0005434907251	25864	Economy	6300.00
0005434907250	25864	Economy	6300.00
0005434907225	25864	Economy	6300.00
0005434907234	25864	Economy	6300.00
0005434907247	25864	Economy	6300.00
0005433251293	25864	Economy	6300.00
0005434907253	25864	Economy	6300.00
0005434907227	25864	Economy	6300.00
0005434907256	25864	Economy	6300.00
0005433251161	25864	Economy	6300.00
0005434907258	25864	Economy	6300.00
0005433251358	25864	Economy	6300.00
0005434907230	25864	Economy	6300.00
0005434907260	25864	Economy	6300.00
0005434907255	25864	Economy	6300.00
0005434907248	25864	Economy	6300.00
0005434907220	25864	Economy	6300.00
0005433251226	25864	Economy	6300.00
0005434907233	25864	Economy	6300.00
0005434907259	25864	Economy	6300.00
0005434907215	25864	Economy	6300.00
0005433251192	25864	Economy	6300.00
0005434907226	25864	Economy	6300.00
0005434907235	25864	Economy	6300.00
0005433251233	25864	Economy	6300.00
0005434907218	25864	Economy	6300.00
0005433251306	25864	Economy	6300.00
0005433251323	25864	Economy	6300.00
0005434907254	25864	Economy	6300.00
0005434907262	25864	Economy	6300.00
0005433251219	25864	Economy	6300.00
0005433251359	25864	Economy	6300.00
0005434907221	25864	Economy	6300.00
0005433251209	25864	Economy	6300.00
0005433251150	25864	Economy	6300.00
0005433251211	25864	Economy	6300.00
0005433251191	25864	Economy	6300.00
0005433251234	25864	Economy	6300.00
0005434907231	25864	Economy	6300.00
0005434907238	25864	Economy	6300.00
0005434907232	25864	Economy	6300.00
0005433251292	25864	Economy	6300.00
0005433251228	25864	Economy	6300.00
0005433251120	25864	Economy	6300.00
0005433251225	25864	Economy	6300.00
0005434907222	25864	Economy	6300.00
0005433251140	25864	Economy	6300.00
0005434907239	25864	Economy	6300.00
0005433251357	25864	Economy	6300.00
0005433251245	25864	Economy	6300.00
0005433251190	25864	Economy	6300.00
0005434907229	25864	Economy	6300.00
0005432609720	22480	Economy	16400.00
0005432607553	22480	Economy	16400.00
0005432607555	22480	Economy	14900.00
0005432607563	22480	Economy	14900.00
0005432607556	22480	Economy	14900.00
0005432607564	22480	Economy	14900.00
0005432607562	22480	Economy	14900.00
0005432607565	22480	Economy	14900.00
0005432609721	22480	Economy	14900.00
0005432609728	22480	Economy	14900.00
0005432609722	22480	Economy	14900.00
0005432609725	22480	Economy	14900.00
0005432607554	22480	Economy	14900.00
0005432607557	22480	Economy	14900.00
0005432609719	22480	Economy	14900.00
0005432609724	22480	Economy	14900.00
0005432607559	22480	Economy	14900.00
0005432609727	22480	Economy	14900.00
0005435841464	22480	Economy	14900.00
0005432609729	22480	Economy	14900.00
0005435842317	22480	Economy	14900.00
0005432609718	22480	Economy	14900.00
0005432607561	22480	Economy	14900.00
0005432607560	22480	Economy	14900.00
0005432609723	22480	Economy	14900.00
0005432609717	22480	Economy	14900.00
0005435841470	22480	Economy	14900.00
0005432609726	22480	Economy	14900.00
0005432607558	22480	Economy	14900.00
0005435841461	22480	Economy	14900.00
0005435841095	31721	Economy	16400.00
0005435841473	31721	Economy	16400.00
0005432609695	31721	Economy	16400.00
0005432613830	31721	Economy	14900.00
0005435841472	31721	Economy	14900.00
0005435841094	31721	Economy	14900.00
0005432609673	31721	Economy	14900.00
0005435841475	31721	Economy	14900.00
0005435841098	31721	Economy	14900.00
0005432609691	31721	Economy	14900.00
0005435841097	31721	Economy	14900.00
0005435841471	31721	Economy	14900.00
0005432609696	31721	Economy	14900.00
0005435841474	31721	Economy	14900.00
0005432613800	31721	Economy	14900.00
0005432609690	31721	Economy	14900.00
0005435841096	31721	Economy	14900.00
0005432609687	31721	Economy	14900.00
0005432609672	31721	Economy	14900.00
0005432613829	31721	Economy	14900.00
0005432609688	31721	Economy	14900.00
0005435841476	31721	Economy	14900.00
0005432613807	31721	Economy	14900.00
0005432609698	31721	Economy	14900.00
0005432609684	31721	Economy	14900.00
0005432613823	31721	Economy	14900.00
0005432609697	31721	Economy	14900.00
0005432613808	31721	Economy	14900.00
0005432609689	31721	Economy	14900.00
0005432609693	31721	Economy	14900.00
0005432609685	31721	Economy	14900.00
0005433008653	14153	Business	52300.00
0005433008621	14153	Business	52300.00
0005433008632	14153	Business	52300.00
0005433008626	14153	Business	52300.00
0005433008656	14153	Economy	17400.00
0005433008627	14153	Economy	17400.00
0005433008636	14153	Economy	17400.00
0005433008625	14153	Economy	17400.00
0005433008615	14153	Economy	17400.00
0005433008624	14153	Economy	17400.00
0005433008618	14153	Economy	17400.00
0005433008633	14153	Economy	19200.00
0005433008616	14153	Economy	19200.00
0005433008643	14153	Economy	17400.00
0005433008630	14153	Economy	17400.00
0005433008645	14153	Economy	17400.00
0005433810494	14153	Economy	17400.00
0005433008654	14153	Economy	17400.00
0005433008635	14153	Economy	17400.00
0005433008623	14153	Economy	17400.00
0005433008640	14153	Economy	17400.00
0005433008628	14153	Economy	17400.00
0005433810507	14153	Economy	17400.00
0005433008622	14153	Economy	17400.00
0005433008649	14153	Economy	17400.00
0005433008619	14153	Economy	17400.00
0005433008644	14153	Economy	17400.00
0005433008620	14153	Economy	17400.00
0005433008614	14153	Economy	17400.00
0005433008638	14153	Economy	17400.00
0005433008655	14153	Economy	17400.00
0005433008637	14153	Economy	17400.00
0005433008642	14153	Economy	17400.00
0005433008612	14153	Economy	17400.00
0005433008650	14153	Economy	17400.00
0005433008639	14153	Economy	17400.00
0005433008634	14153	Economy	17400.00
0005433008652	14153	Economy	17400.00
0005433008646	14153	Economy	17400.00
0005433008647	14153	Economy	17400.00
0005433008613	14153	Economy	17400.00
0005433008629	14153	Economy	17400.00
0005433008648	14153	Economy	17400.00
0005433008641	14153	Economy	17400.00
0005433008611	14153	Economy	17400.00
0005433008631	14153	Economy	17400.00
0005433008617	14153	Economy	17400.00
0005433008651	14153	Economy	17400.00
0005433810538	22852	Business	52300.00
0005433007921	22852	Business	52300.00
0005433008046	22852	Business	52300.00
0005433008157	22852	Business	52300.00
0005433008201	22852	Business	52300.00
0005433008164	22852	Business	52300.00
0005433810545	22852	Business	52300.00
0005433008278	22852	Business	52300.00
0005433008231	22852	Economy	17400.00
0005433008300	22852	Economy	17400.00
0005433008175	22852	Economy	17400.00
0005433008031	22852	Economy	17400.00
0005433008202	22852	Economy	17400.00
0005433008047	22852	Economy	19200.00
0005433810540	22852	Economy	19200.00
0005433008198	22852	Economy	17400.00
0005433008402	22852	Economy	17400.00
0005433810543	22852	Economy	17400.00
0005433008280	22852	Economy	17400.00
0005433008181	22852	Economy	17400.00
0005433008364	22852	Economy	17400.00
0005433008163	22852	Economy	17400.00
0005433008272	22852	Economy	17400.00
0005433008199	22852	Economy	17400.00
0005433008399	22852	Economy	17400.00
0005433810542	22852	Economy	17400.00
0005433810544	22852	Economy	17400.00
0005433008273	22852	Economy	17400.00
0005433008356	22852	Economy	17400.00
0005433810539	22852	Economy	17400.00
0005433008243	22852	Economy	17400.00
0005433008030	22852	Economy	17400.00
0005433008404	22852	Economy	17400.00
0005433008343	22852	Economy	17400.00
0005433008277	22852	Economy	17400.00
0005433008260	22852	Economy	17400.00
0005433008018	22852	Economy	17400.00
0005433008365	22852	Economy	17400.00
0005433810541	22852	Economy	17400.00
0005433008033	22852	Economy	17400.00
0005433008122	22852	Economy	17400.00
0005433008041	22852	Economy	17400.00
0005433008154	22852	Economy	17400.00
0005433008279	22852	Economy	17400.00
0005433008357	22852	Economy	17400.00
0005433008223	22852	Economy	17400.00
0005433008172	22852	Economy	17400.00
0005433008344	22852	Economy	17400.00
0005433008019	22852	Economy	17400.00
0005433007920	22852	Economy	17400.00
0005433008403	22852	Economy	17400.00
0005433008032	22852	Economy	17400.00
0005433008354	22852	Economy	17400.00
0005434925513	14938	Business	22900.00
0005434925548	14938	Business	22900.00
0005434925537	14938	Business	22900.00
0005434925555	14938	Business	22900.00
0005434925437	14938	Business	22900.00
0005434925438	14938	Business	22900.00
0005434925440	14938	Economy	7600.00
0005434925327	14938	Economy	7600.00
0005434925559	14938	Economy	7600.00
0005434925536	14938	Economy	7600.00
0005434925407	14938	Economy	8400.00
0005434925487	14938	Economy	7600.00
0005434925560	14938	Economy	7600.00
0005434925554	14938	Economy	7600.00
0005434925564	14938	Economy	7600.00
0005434925527	14938	Economy	7600.00
0005434925542	14938	Economy	7600.00
0005434925410	14938	Economy	7600.00
0005434925515	14938	Economy	7600.00
0005434925495	14938	Economy	7600.00
0005434925486	14938	Economy	7600.00
0005434925405	14938	Economy	7600.00
0005434925514	14938	Economy	7600.00
0005434925494	14938	Economy	7600.00
0005434925328	14938	Economy	7600.00
0005434925516	14938	Economy	7600.00
0005434925556	14938	Economy	7600.00
0005434925374	14938	Economy	7600.00
0005434925498	14938	Economy	7600.00
0005434925454	14938	Economy	7600.00
0005434925558	14938	Economy	7600.00
0005434925543	14938	Economy	7600.00
0005434925314	14938	Economy	7600.00
0005434925520	14938	Economy	7600.00
0005434925488	14938	Economy	7600.00
0005434925517	14938	Economy	7600.00
0005434925406	14938	Economy	7600.00
0005434925432	14938	Economy	7600.00
0005434925497	14938	Economy	7600.00
0005434925525	14938	Economy	7600.00
0005434925557	14938	Economy	7600.00
0005434925791	20524	Business	22900.00
0005434925788	20524	Business	22900.00
0005434925778	20524	Economy	7600.00
0005434925790	20524	Economy	7600.00
0005434925786	20524	Economy	8400.00
0005434925787	20524	Economy	7600.00
0005434925779	20524	Economy	7600.00
0005434925776	20524	Economy	7600.00
0005434925796	20524	Economy	7600.00
0005434925797	20524	Economy	7600.00
0005434925777	20524	Economy	7600.00
0005434925793	20524	Economy	7600.00
0005434925789	20524	Economy	7600.00
0005434925780	20524	Economy	7600.00
0005434925794	20524	Economy	7600.00
0005434925799	20524	Economy	7600.00
0005434925782	20524	Economy	7600.00
0005434925785	20524	Economy	7600.00
0005434925795	20524	Economy	7600.00
0005434925798	20524	Economy	7600.00
0005434925792	20524	Economy	7600.00
0005434925781	20524	Economy	7600.00
0005434925783	20524	Economy	7600.00
0005434925784	20524	Economy	7600.00
0005435999074	15836	Economy	8900.00
0005435999113	15836	Economy	8900.00
0005435999081	15836	Economy	8100.00
0005435487848	15836	Economy	8100.00
0005435487835	15836	Economy	8100.00
0005435999086	15836	Economy	8100.00
0005435487838	15836	Economy	8100.00
0005435487842	15836	Economy	8100.00
0005435999103	15836	Economy	8100.00
0005435487840	15836	Economy	8100.00
0005435487844	15836	Economy	8100.00
0005435999079	15836	Economy	8100.00
0005435487845	15836	Economy	8100.00
0005435487839	15836	Economy	8100.00
0005435999128	15836	Economy	8100.00
0005435487846	15836	Economy	8100.00
0005435487851	15836	Economy	8100.00
0005435487833	15836	Economy	8100.00
0005435487850	15836	Economy	8100.00
0005435999102	15836	Economy	8100.00
0005435487830	15836	Economy	8100.00
0005435487841	15836	Economy	8100.00
0005435487837	15836	Economy	8100.00
0005435999073	15836	Economy	8100.00
0005435999110	15836	Economy	8100.00
0005435999082	15836	Economy	8100.00
0005435999075	15836	Economy	8100.00
0005435487836	15836	Economy	8100.00
0005435487832	15836	Economy	8100.00
0005435487849	15836	Economy	8100.00
0005435487847	15836	Economy	8100.00
0005435487834	15836	Economy	8100.00
0005435487831	15836	Economy	8100.00
0005435487843	15836	Economy	8100.00
0005435999124	15836	Economy	8100.00
0005435999118	15836	Economy	8100.00
0005435999246	19695	Economy	8900.00
0005435487582	19695	Economy	8900.00
0005435999237	19695	Economy	8900.00
0005435487587	19695	Economy	8900.00
0005435999238	19695	Economy	8100.00
0005435487581	19695	Economy	8100.00
0005435487605	19695	Economy	8100.00
0005435487625	19695	Economy	8100.00
0005435487556	19695	Economy	8100.00
0005435999244	19695	Economy	8100.00
0005435999248	19695	Economy	8100.00
0005435487586	19695	Economy	8100.00
0005435487612	19695	Economy	8100.00
0005435487624	19695	Economy	8100.00
0005435487505	19695	Economy	8100.00
0005435487554	19695	Economy	8100.00
0005435487590	19695	Economy	8100.00
0005435487631	19695	Economy	8100.00
0005435487647	19695	Economy	8100.00
0005435487579	19695	Economy	8100.00
0005435999247	19695	Economy	8100.00
0005435999236	19695	Economy	8100.00
0005435999242	19695	Economy	8100.00
0005435999241	19695	Economy	8100.00
0005435999243	19695	Economy	8100.00
0005435487650	19695	Economy	8100.00
0005435487658	19695	Economy	8100.00
0005435999239	19695	Economy	8100.00
0005435487604	19695	Economy	8100.00
0005435487626	19695	Economy	8100.00
0005435487555	19695	Economy	8100.00
0005435487683	19695	Economy	8100.00
0005435487632	19695	Economy	8100.00
0005435999245	19695	Economy	8100.00
0005435487600	19695	Economy	8100.00
0005435487552	19695	Economy	8100.00
0005435487580	19695	Economy	8100.00
0005435487656	19695	Economy	8100.00
0005435487611	19695	Economy	8100.00
0005435487657	19695	Economy	8100.00
0005435999240	19695	Economy	8100.00
0005435487639	19695	Economy	8100.00
0005435839475	6028	Business	199300.00
0005432659708	6028	Business	199300.00
0005435472624	6028	Business	199300.00
0005435839459	6028	Business	199300.00
0005432660820	6028	Business	199300.00
0005435839448	6028	Business	199300.00
0005435839468	6028	Business	199300.00
0005435472737	6028	Business	199300.00
0005432537042	6028	Business	199300.00
0005435839470	6028	Business	199300.00
0005435472738	6028	Economy	66400.00
0005435839456	6028	Economy	66400.00
0005435472625	6028	Economy	66400.00
0005435472645	6028	Economy	66400.00
0005432658592	6028	Economy	66400.00
0005435472722	6028	Economy	66400.00
0005432142253	6028	Economy	66400.00
0005435839454	6028	Economy	66400.00
0005435839447	6028	Economy	66400.00
0005432537043	6028	Economy	66400.00
0005435839469	6028	Economy	66400.00
0005432142251	6028	Economy	66400.00
0005435472661	6028	Economy	66400.00
0005435839457	6028	Economy	66400.00
0005435839474	6028	Economy	66400.00
0005435472677	6028	Economy	66400.00
0005435472626	6028	Economy	66400.00
0005435839460	6028	Economy	66400.00
0005435839472	6028	Economy	66400.00
0005435472730	6028	Economy	66400.00
0005432142254	6028	Economy	66400.00
0005435839452	6028	Economy	66400.00
0005432658594	6028	Economy	66400.00
0005435839466	6028	Economy	66400.00
0005435839453	6028	Economy	66400.00
0005432142252	6028	Economy	66400.00
0005435472657	6028	Economy	66400.00
0005432660819	6028	Economy	66400.00
0005435472731	6028	Economy	66400.00
0005435839467	6028	Economy	66400.00
0005432659707	6028	Economy	66400.00
0005435839471	6028	Economy	66400.00
0005435839464	6028	Economy	66400.00
0005435472721	6028	Economy	66400.00
0005432658593	6028	Economy	66400.00
0005435472638	6028	Economy	66400.00
0005435472678	6028	Economy	66400.00
0005432142255	6028	Economy	66400.00
0005435839461	6028	Economy	66400.00
0005435839451	6028	Economy	66400.00
0005435839449	6028	Economy	66400.00
0005435472664	6028	Economy	66400.00
0005435472637	6028	Economy	66400.00
0005435839465	6028	Economy	66400.00
0005435839462	6028	Economy	66400.00
0005435839463	6028	Economy	66400.00
0005435839458	6028	Economy	66400.00
0005435839473	6028	Economy	66400.00
0005435839455	6028	Economy	66400.00
0005435839450	6028	Economy	66400.00
0005435839077	18035	Business	199300.00
0005435839202	18035	Business	199300.00
0005435839139	18035	Business	199300.00
0005435472799	18035	Business	199300.00
0005435472807	18035	Business	199300.00
0005435839173	18035	Business	199300.00
0005435472803	18035	Business	199300.00
0005435839153	18035	Business	199300.00
0005435839056	18035	Business	199300.00
0005435472810	18035	Business	199300.00
0005435839256	18035	Business	199300.00
0005435839174	18035	Economy	66400.00
0005435839055	18035	Economy	66400.00
0005435472808	18035	Economy	66400.00
0005435839268	18035	Economy	66400.00
0005435839203	18035	Economy	66400.00
0005435839227	18035	Economy	66400.00
0005435839226	18035	Economy	73100.00
0005435839215	18035	Economy	66400.00
0005435839211	18035	Economy	66400.00
0005432660795	18035	Economy	66400.00
0005435839141	18035	Economy	66400.00
0005435472811	18035	Economy	66400.00
0005435839152	18035	Economy	66400.00
0005435472813	18035	Economy	66400.00
0005435839177	18035	Economy	66400.00
0005432537060	18035	Economy	66400.00
0005435839140	18035	Economy	66400.00
0005435839291	18035	Economy	66400.00
0005432667433	18035	Economy	66400.00
0005435472814	18035	Economy	66400.00
0005432537059	18035	Economy	66400.00
0005435839238	18035	Economy	66400.00
0005432667432	18035	Economy	66400.00
0005435472806	18035	Economy	66400.00
0005435839237	18035	Economy	66400.00
0005435472804	18035	Economy	66400.00
0005435472812	18035	Economy	66400.00
0005435839136	18035	Economy	66400.00
0005435472802	18035	Economy	66400.00
0005435472798	18035	Economy	66400.00
0005435839176	18035	Economy	66400.00
0005435472800	18035	Economy	66400.00
0005435839135	18035	Economy	66400.00
0005435839241	18035	Economy	66400.00
0005435472801	18035	Economy	66400.00
0005435472809	18035	Economy	66400.00
0005435839290	18035	Economy	66400.00
0005435839334	18035	Economy	66400.00
0005435472805	18035	Economy	66400.00
0005435839201	18035	Economy	66400.00
0005433284975	23006	Business	15700.00
0005433285101	23006	Economy	5200.00
0005433285064	23006	Economy	5200.00
0005433285100	23006	Economy	5200.00
0005435103930	23006	Economy	5200.00
0005433285045	23006	Economy	5200.00
0005433285063	23006	Economy	5200.00
0005433285120	23006	Economy	5200.00
0005435103923	23006	Economy	5200.00
0005435103927	23006	Economy	5200.00
0005433285008	23006	Economy	5200.00
0005435103926	23006	Economy	5200.00
0005433285039	23006	Economy	5200.00
0005433285007	23006	Economy	5200.00
0005433285084	23006	Economy	5700.00
0005433285041	23006	Economy	5700.00
0005433285010	23006	Economy	5700.00
0005433285121	23006	Economy	5700.00
0005433285033	23006	Economy	5200.00
0005433285032	23006	Economy	5200.00
0005433284953	23006	Economy	5200.00
0005433285099	23006	Economy	5200.00
0005433285047	23006	Economy	5200.00
0005433285046	23006	Economy	5200.00
0005435103922	23006	Economy	5200.00
0005433285076	23006	Economy	5200.00
0005435103928	23006	Economy	5200.00
0005435103931	23006	Economy	5200.00
0005435103924	23006	Economy	5200.00
0005433285065	23006	Economy	5200.00
0005435103929	23006	Economy	5200.00
0005435103925	23006	Economy	5200.00
0005433285040	23006	Economy	5200.00
0005435103932	23006	Economy	5200.00
0005433285314	32076	Business	15700.00
0005433285316	32076	Business	15700.00
0005435103852	32076	Business	15700.00
0005433285311	32076	Economy	5200.00
0005433285323	32076	Economy	5200.00
0005433285324	32076	Economy	5200.00
0005433285299	32076	Economy	5200.00
0005433285295	32076	Economy	5200.00
0005433285305	32076	Economy	5200.00
0005433285317	32076	Economy	5200.00
0005433285319	32076	Economy	5200.00
0005433285322	32076	Economy	5200.00
0005433285296	32076	Economy	5200.00
0005435103853	32076	Economy	5200.00
0005435103833	32076	Economy	5700.00
0005435103826	32076	Economy	5200.00
0005433285318	32076	Economy	5200.00
0005433285309	32076	Economy	5200.00
0005433285315	32076	Economy	5200.00
0005435103841	32076	Economy	5200.00
0005433285313	32076	Economy	5200.00
0005433285312	32076	Economy	5200.00
0005433285307	32076	Economy	5200.00
0005433285304	32076	Economy	5200.00
0005433285298	32076	Economy	5200.00
0005433285297	32076	Economy	5200.00
0005433285310	32076	Economy	5200.00
0005433285302	32076	Economy	5200.00
0005433285320	32076	Economy	5200.00
0005435103827	32076	Economy	5200.00
0005433285321	32076	Economy	5200.00
0005433285303	32076	Economy	5200.00
0005433285300	32076	Economy	5200.00
0005433285326	32076	Economy	5200.00
0005433285306	32076	Economy	5200.00
0005433285301	32076	Economy	5200.00
0005435103844	32076	Economy	5200.00
0005433285308	32076	Economy	5200.00
0005433285325	32076	Economy	5200.00
0005433475663	23870	Economy	13500.00
0005433475660	23870	Economy	13500.00
0005433475647	23870	Economy	12300.00
0005433475665	23870	Economy	12300.00
0005433475673	23870	Economy	12300.00
0005433475669	23870	Economy	12300.00
0005435852575	23870	Economy	12300.00
0005435852576	23870	Economy	12300.00
0005433475664	23870	Economy	12300.00
0005433475682	23870	Economy	12300.00
0005435852577	23870	Economy	12300.00
0005433475648	23870	Economy	12300.00
0005435852574	23870	Economy	12300.00
0005435852578	23870	Economy	12300.00
0005433475649	23870	Economy	12300.00
0005435213628	30582	Business	42100.00
0005435725606	30582	Business	42100.00
0005432527068	30582	Business	42100.00
0005435213609	30582	Business	42100.00
0005432535814	30582	Business	42100.00
0005432526866	30582	Business	42100.00
0005432526865	30582	Business	42100.00
0005432526807	30582	Business	42100.00
0005435213619	30582	Business	42100.00
0005432526489	30582	Business	42100.00
0005435213608	30582	Business	42100.00
0005434066868	30582	Business	42100.00
0005432211511	30582	Business	42100.00
0005432535794	30582	Business	42100.00
0005432526914	30582	Business	42100.00
0005434066713	30582	Business	42100.00
0005432526767	30582	Business	42100.00
0005432527039	30582	Business	42100.00
0005432527321	30582	Business	42100.00
0005435213627	30582	Business	42100.00
0005435213607	30582	Business	42100.00
0005432527193	30582	Business	42100.00
0005435213606	30582	Business	42100.00
0005432526898	30582	Business	42100.00
0005435213622	30582	Comfort	23900.00
0005434066792	30582	Business	42100.00
0005432428908	30582	Comfort	23900.00
0005435213600	30582	Comfort	23900.00
0005435213626	30582	Comfort	23900.00
0005432526318	30582	Comfort	23900.00
0005432526579	30582	Comfort	23900.00
0005435213601	30582	Comfort	23900.00
0005432527138	30582	Comfort	23900.00
0005432526496	30582	Comfort	23900.00
0005432527114	30582	Comfort	23900.00
0005432526576	30582	Comfort	23900.00
0005434066679	30582	Comfort	23900.00
0005435213576	30582	Comfort	23900.00
0005434066967	30582	Comfort	23900.00
0005435630970	30582	Comfort	23900.00
0005435213640	30582	Comfort	23900.00
0005434066739	30582	Comfort	23900.00
0005432527067	30582	Comfort	23900.00
0005434067020	30582	Comfort	23900.00
0005432526926	30582	Comfort	23900.00
0005432527264	30582	Comfort	23900.00
0005432527667	30582	Comfort	23900.00
0005435213605	30582	Comfort	23900.00
0005432527017	30582	Comfort	23900.00
0005432526158	30582	Comfort	23900.00
0005432527213	30582	Comfort	23900.00
0005432527016	30582	Comfort	23900.00
0005435213625	30582	Comfort	23900.00
0005434066815	30582	Comfort	23900.00
0005432526543	30582	Comfort	23900.00
0005432526674	30582	Comfort	23900.00
0005435213621	30582	Comfort	23900.00
0005432526177	30582	Comfort	23900.00
0005432526924	30582	Comfort	23900.00
0005432526768	30582	Comfort	23900.00
0005432527181	30582	Comfort	23900.00
0005432526653	30582	Comfort	23900.00
0005432527325	30582	Comfort	23900.00
0005432527058	30582	Comfort	23900.00
0005434066956	30582	Comfort	23900.00
0005432527668	30582	Comfort	23900.00
0005434067197	30582	Comfort	23900.00
0005432526512	30582	Comfort	23900.00
0005432527222	30582	Comfort	23900.00
0005434066816	30582	Comfort	23900.00
0005434066903	30582	Comfort	23900.00
0005435213644	30582	Economy	14000.00
0005434066920	30582	Economy	14000.00
0005434067026	30582	Economy	14000.00
0005432527116	30582	Economy	14000.00
0005432527316	30582	Economy	14000.00
0005434066964	30582	Economy	14000.00
0005432527212	30582	Economy	14000.00
0005432526587	30582	Economy	14000.00
0005435213598	30582	Economy	14000.00
0005432211505	30582	Economy	14000.00
0005432526716	30582	Economy	14000.00
0005434067196	30582	Economy	14000.00
0005434066867	30582	Economy	14000.00
0005432526570	30582	Economy	14000.00
0005432527343	30582	Economy	14000.00
0005434066827	30582	Economy	14000.00
0005432526724	30582	Economy	14000.00
0005434067022	30582	Economy	14000.00
0005435213614	30582	Economy	14000.00
0005432527283	30582	Economy	14000.00
0005432526832	30582	Economy	14000.00
0005435213617	30582	Economy	14000.00
0005433656673	30582	Economy	14000.00
0005434067018	30582	Economy	14000.00
0005435213604	30582	Economy	14000.00
0005432526812	30582	Economy	14000.00
0005434067248	30582	Economy	14000.00
0005434067027	30582	Economy	14000.00
0005432527233	30582	Economy	14000.00
0005434066793	30582	Economy	14000.00
0005432527105	30582	Economy	14000.00
0005432526996	30582	Economy	14000.00
0005434066963	30582	Economy	14000.00
0005434066734	30582	Economy	14000.00
0005435213641	30582	Economy	14000.00
0005432527603	30582	Economy	14000.00
0005435213587	30582	Economy	14000.00
0005432527214	30582	Economy	14000.00
0005434066936	30582	Economy	14000.00
0005432526978	30582	Economy	14000.00
0005432211512	30582	Economy	14000.00
0005435213596	30582	Economy	14000.00
0005434066844	30582	Economy	14000.00
0005434067076	30582	Economy	14000.00
0005434066996	30582	Economy	14000.00
0005435213629	30582	Economy	14000.00
0005432526857	30582	Economy	14000.00
0005432527146	30582	Economy	14000.00
0005432527279	30582	Economy	14000.00
0005434067113	30582	Economy	14000.00
0005434066870	30582	Economy	14000.00
0005434066957	30582	Economy	14000.00
0005432527101	30582	Economy	14000.00
0005434066715	30582	Economy	14000.00
0005432526559	30582	Economy	14000.00
0005432211509	30582	Economy	14000.00
0005435213634	30582	Economy	14000.00
0005433656676	30582	Economy	14000.00
0005434067204	30582	Economy	14000.00
0005432526880	30582	Economy	14000.00
0005432527069	30582	Economy	14000.00
0005432527260	30582	Economy	15400.00
0005434066826	30582	Economy	14000.00
0005435213645	30582	Economy	15400.00
0005432527477	30582	Economy	14000.00
0005435213630	30582	Economy	14000.00
0005432526897	30582	Economy	14000.00
0005435213631	30582	Economy	14000.00
0005434066980	30582	Economy	15400.00
0005435725607	30582	Economy	14000.00
0005432527319	30582	Economy	14000.00
0005435630971	30582	Economy	14000.00
0005434067004	30582	Economy	14000.00
0005432535808	30582	Economy	14000.00
0005435213636	30582	Economy	14000.00
0005432527273	30582	Economy	14000.00
0005432526900	30582	Economy	14000.00
0005432533271	30582	Economy	14000.00
0005435213613	30582	Economy	14000.00
0005435213602	30582	Economy	14000.00
0005432526859	30582	Economy	14000.00
0005432526904	30582	Economy	14000.00
0005432533278	30582	Economy	14000.00
0005434066812	30582	Economy	14000.00
0005434067069	30582	Economy	14000.00
0005432527634	30582	Economy	14000.00
0005434067021	30582	Economy	14000.00
0005432527221	30582	Economy	14000.00
0005435213615	30582	Economy	14000.00
0005434066773	30582	Economy	14000.00
0005432527032	30582	Economy	14000.00
0005434067360	30582	Economy	14000.00
0005434066879	30582	Economy	14000.00
0005435213594	30582	Economy	14000.00
0005435213638	30582	Economy	14000.00
0005434066881	30582	Economy	14000.00
0005435213612	30582	Economy	14000.00
0005432526601	30582	Economy	14000.00
0005435213637	30582	Economy	14000.00
0005432527223	30582	Economy	14000.00
0005434066777	30582	Economy	14000.00
0005435213586	30582	Economy	14000.00
0005432527320	30582	Economy	14000.00
0005432211508	30582	Economy	14000.00
0005432526856	30582	Economy	14000.00
0005432527232	30582	Economy	14000.00
0005432537040	30582	Economy	14000.00
0005432159861	30582	Economy	14000.00
0005432526377	30582	Economy	14000.00
0005434067090	30582	Economy	14000.00
0005432527359	30582	Economy	14000.00
0005434067114	30582	Economy	14000.00
0005434067189	30582	Economy	14000.00
0005432527125	30582	Economy	14000.00
0005434066820	30582	Economy	14000.00
0005432526580	30582	Economy	14000.00
0005432527162	30582	Economy	14000.00
0005432159863	30582	Economy	14000.00
0005435213599	30582	Economy	14000.00
0005432526980	30582	Economy	14000.00
0005432526178	30582	Economy	14000.00
0005432527021	30582	Economy	14000.00
0005432533277	30582	Economy	14000.00
0005435213611	30582	Economy	14000.00
0005432428907	30582	Economy	14000.00
0005434066998	30582	Economy	14000.00
0005432527284	30582	Economy	14000.00
0005432526560	30582	Economy	14000.00
0005435725603	30582	Economy	14000.00
0005432533270	30582	Economy	14000.00
0005435213595	30582	Economy	14000.00
0005435213583	30582	Economy	14000.00
0005434066790	30582	Economy	14000.00
0005434066741	30582	Economy	14000.00
0005435213633	30582	Economy	14000.00
0005435213643	30582	Economy	14000.00
0005432159862	30582	Economy	14000.00
0005435213632	30582	Economy	14000.00
0005432526673	30582	Economy	14000.00
0005435213610	30582	Economy	14000.00
0005432526664	30582	Economy	14000.00
0005432526836	30582	Economy	14000.00
0005434066997	30582	Economy	14000.00
0005434066789	30582	Economy	14000.00
0005432526813	30582	Economy	14000.00
0005434066828	30582	Economy	14000.00
0005435213580	30582	Economy	14000.00
0005432526388	30582	Economy	14000.00
0005432211504	30582	Economy	14000.00
0005434066988	30582	Economy	14000.00
0005432527147	30582	Economy	14000.00
0005432537041	30582	Economy	14000.00
0005432526481	30582	Economy	14000.00
0005432526507	30582	Economy	14000.00
0005434067013	30582	Economy	14000.00
0005432526561	30582	Economy	14000.00
0005434066899	30582	Economy	14000.00
0005434066972	30582	Economy	14000.00
0005432527057	30582	Economy	14000.00
0005432527177	30582	Economy	14000.00
0005432526991	30582	Economy	14000.00
0005432527100	30582	Economy	14000.00
0005435213635	30582	Economy	14000.00
0005435630969	30582	Economy	14000.00
0005434066886	30582	Economy	14000.00
0005435213591	30582	Economy	14000.00
0005434066908	30582	Economy	14000.00
0005435213581	30582	Economy	15400.00
0005435213589	30582	Economy	14000.00
0005434066782	30582	Economy	15400.00
0005434067043	30582	Economy	15400.00
0005432527358	30582	Economy	15400.00
0005434066969	30582	Economy	15400.00
0005432526665	30582	Economy	14000.00
0005434066689	30582	Economy	14000.00
0005432526808	30582	Economy	14000.00
0005432527085	30582	Economy	14000.00
0005432527011	30582	Economy	14000.00
0005435213585	30582	Economy	14000.00
0005432159860	30582	Economy	14000.00
0005432527315	30582	Economy	14000.00
0005432526987	30582	Economy	14000.00
0005435213642	30582	Economy	14000.00
0005432526172	30582	Economy	14000.00
0005432527318	30582	Economy	14000.00
0005432526925	30582	Economy	14000.00
0005432533279	30582	Economy	14000.00
0005432526387	30582	Economy	14000.00
0005432533267	30582	Economy	14000.00
0005435725605	30582	Economy	14000.00
0005435213582	30582	Economy	14000.00
0005432526979	30582	Economy	14000.00
0005435213624	30582	Economy	14000.00
0005434067030	30582	Economy	14000.00
0005434067017	30582	Economy	14000.00
0005432527145	30582	Economy	14000.00
0005432526858	30582	Economy	14000.00
0005434066813	30582	Economy	14000.00
0005432526913	30582	Economy	14000.00
0005432527141	30582	Economy	14000.00
0005432211510	30582	Economy	14000.00
0005432527336	30582	Economy	14000.00
0005435213579	30582	Economy	14000.00
0005434066742	30582	Economy	14000.00
0005434066843	30582	Economy	14000.00
0005435213590	30582	Economy	14000.00
0005432527360	30582	Economy	14000.00
0005432526811	30582	Economy	14000.00
0005432527285	30582	Economy	14000.00
0005434066714	30582	Economy	14000.00
0005433656674	30582	Economy	14000.00
0005434066880	30582	Economy	14000.00
0005432527226	30582	Economy	14000.00
0005435213592	30582	Economy	14000.00
0005434066749	30582	Economy	14000.00
0005435213603	30582	Economy	14000.00
0005432527424	30582	Economy	14000.00
0005432211507	30582	Economy	14000.00
0005435213618	30582	Economy	14000.00
0005434066791	30582	Economy	14000.00
0005435725608	30582	Economy	14000.00
0005435213597	30582	Economy	14000.00
0005432526967	30582	Economy	14000.00
0005433656675	30582	Economy	14000.00
0005432526490	30582	Economy	14000.00
0005435213593	30582	Economy	14000.00
0005435213577	30582	Economy	14000.00
0005432527342	30582	Economy	14000.00
0005432535807	30582	Economy	14000.00
0005432526542	30582	Economy	14000.00
0005434066891	30582	Economy	14000.00
0005435213578	30582	Economy	14000.00
0005434066783	30582	Economy	14000.00
0005432527164	30582	Economy	14000.00
0005435213616	30582	Economy	14000.00
0005432211506	30582	Economy	14000.00
0005434066772	30582	Economy	14000.00
0005435213588	30582	Economy	14000.00
0005435213623	30582	Economy	14000.00
0005434066902	30582	Economy	14000.00
0005432527148	30582	Economy	14000.00
0005432527168	30582	Economy	14000.00
0005432535790	30582	Economy	14000.00
0005432526753	30582	Economy	14000.00
0005434066781	30582	Economy	14000.00
0005432526912	30582	Economy	14000.00
0005434067047	30582	Economy	14000.00
0005434067249	30582	Economy	14000.00
0005434067067	30582	Economy	14000.00
0005435213584	30582	Economy	14000.00
0005432526881	30582	Economy	14000.00
0005432526901	30582	Economy	14000.00
0005432527115	30582	Economy	14000.00
0005434067250	30582	Economy	14000.00
0005435213620	30582	Economy	14000.00
0005435725604	30582	Economy	14000.00
0005432527084	30582	Economy	14000.00
0005432533269	30582	Economy	14000.00
0005432533268	30582	Economy	14000.00
0005432526766	30582	Economy	14000.00
0005434066968	30582	Economy	14000.00
0005432527341	30582	Economy	14000.00
0005434066973	30582	Economy	14000.00
0005432537045	30582	Economy	14000.00
0005434067212	30582	Economy	14000.00
0005435213639	30582	Economy	14000.00
0005434067237	30582	Economy	14000.00
0005432527471	30582	Economy	14000.00
0005434066778	30582	Economy	14000.00
0005432527263	30582	Economy	14000.00
0005434067012	30582	Economy	14000.00
0005432526754	30582	Economy	14000.00
0005435652647	24828	Business	9800.00
0005435652811	24828	Business	9800.00
0005435652648	24828	Business	9800.00
0005433367927	24828	Business	9800.00
0005433367934	24828	Business	9800.00
0005433367913	24828	Business	9800.00
0005435652659	24828	Business	9800.00
0005435652380	24828	Business	9800.00
0005435652712	24828	Business	9800.00
0005433367928	24828	Business	9800.00
0005433367916	24828	Business	9800.00
0005435652573	24828	Economy	3300.00
0005435652525	24828	Economy	3300.00
0005433367923	24828	Economy	3300.00
0005433367929	24828	Economy	3300.00
0005435652812	24828	Economy	3300.00
0005435652815	24828	Economy	3300.00
0005433367944	24828	Economy	3300.00
0005435652633	24828	Economy	3300.00
0005433367909	24828	Economy	3600.00
0005433367920	24828	Economy	3600.00
0005435652577	24828	Economy	3600.00
0005435652566	24828	Economy	3600.00
0005433367910	24828	Economy	3600.00
0005433367947	24828	Economy	3300.00
0005433367925	24828	Economy	3300.00
0005435652754	24828	Economy	3300.00
0005435652744	24828	Economy	3300.00
0005435652381	24828	Economy	3300.00
0005435652734	24828	Economy	3300.00
0005435652622	24828	Economy	3300.00
0005433367914	24828	Economy	3300.00
0005433367926	24828	Economy	3300.00
0005433367917	24828	Economy	3300.00
0005433367938	24828	Economy	3300.00
0005433367931	24828	Economy	3300.00
0005433367940	24828	Economy	3300.00
0005435652705	24828	Economy	3300.00
0005433367921	24828	Economy	3300.00
0005433367912	24828	Economy	3300.00
0005435652831	24828	Economy	3300.00
0005433367945	24828	Economy	3300.00
0005433367932	24828	Economy	3300.00
0005433367937	24828	Economy	3300.00
0005435652652	24828	Economy	3300.00
0005433367919	24828	Economy	3300.00
0005433367943	24828	Economy	3300.00
0005435652581	24828	Economy	3300.00
0005435652614	24828	Economy	3300.00
0005435652818	24828	Economy	3300.00
0005435652704	24828	Economy	3300.00
0005433367942	24828	Economy	3300.00
0005433367933	24828	Economy	3300.00
0005435652841	24828	Economy	3300.00
0005433367915	24828	Economy	3300.00
0005433367918	24828	Economy	3300.00
0005435652610	24828	Economy	3300.00
0005435652832	24828	Economy	3300.00
0005435652702	24828	Economy	3300.00
0005435652721	24828	Economy	3300.00
0005433367939	24828	Economy	3300.00
0005435652654	24828	Economy	3300.00
0005435652830	24828	Economy	3300.00
0005435652678	24828	Economy	3300.00
0005435652755	24828	Economy	3300.00
0005433367911	24828	Economy	3300.00
0005435652847	24828	Economy	3300.00
0005435652842	24828	Economy	3300.00
0005433367936	24828	Economy	3300.00
0005433367935	24828	Economy	3300.00
0005433367941	24828	Economy	3300.00
0005435652524	24828	Economy	3300.00
0005433367924	24828	Economy	3300.00
0005433367922	24828	Economy	3300.00
0005435652774	24828	Economy	3300.00
0005435652813	24828	Economy	3300.00
0005435652634	24828	Economy	3300.00
0005433367930	24828	Economy	3300.00
0005433367946	24828	Economy	3300.00
0005435652538	24828	Economy	3300.00
0005435652848	24828	Economy	3300.00
0005435652817	24828	Economy	3300.00
0005435652526	24828	Economy	3300.00
0005435949758	23322	Economy	20600.00
0005435949763	23322	Economy	18700.00
0005435949754	23322	Economy	18700.00
0005435949762	23322	Economy	18700.00
0005435949747	23322	Economy	18700.00
0005435949746	23322	Economy	18700.00
0005435949764	23322	Economy	18700.00
0005435949744	23322	Economy	18700.00
0005435949750	23322	Economy	18700.00
0005435949757	23322	Economy	18700.00
0005435949743	23322	Economy	18700.00
0005434979820	2023	Economy	10500.00
0005434979807	2023	Economy	10500.00
0005434979808	2023	Economy	9500.00
0005434979821	2023	Economy	9500.00
0005434979811	2023	Economy	9500.00
0005434979814	2023	Economy	9500.00
0005434979835	2023	Economy	9500.00
0005434979813	2023	Economy	9500.00
0005434979825	2023	Economy	9500.00
0005434979831	2023	Economy	9500.00
0005434979822	2023	Economy	9500.00
0005434979819	2023	Economy	9500.00
0005434979832	2023	Economy	9500.00
0005434979836	2023	Economy	9500.00
0005434979834	2023	Economy	9500.00
0005434979827	2023	Economy	9500.00
0005434979815	2023	Economy	9500.00
0005434979826	2023	Economy	9500.00
0005434979833	2023	Economy	9500.00
0005434979830	2023	Economy	9500.00
0005434979816	2023	Economy	9500.00
0005434979828	2023	Economy	9500.00
0005435801700	2023	Economy	9500.00
0005434979829	2023	Economy	9500.00
0005434979806	2023	Economy	9500.00
0005435801698	2023	Economy	9500.00
0005434979812	2023	Economy	9500.00
0005434979810	2023	Economy	9500.00
0005434979823	2023	Economy	9500.00
0005434979809	2023	Economy	9500.00
0005434979824	2023	Economy	9500.00
0005434979817	2023	Economy	9500.00
0005434979818	2023	Economy	9500.00
0005435801699	2023	Economy	9500.00
0005434979478	23581	Economy	10500.00
0005434979531	23581	Economy	10500.00
0005434979428	23581	Economy	10500.00
0005434979635	23581	Economy	9500.00
0005434979454	23581	Economy	9500.00
0005434979508	23581	Economy	9500.00
0005434979523	23581	Economy	9500.00
0005434979419	23581	Economy	9500.00
0005434979527	23581	Economy	9500.00
0005434979495	23581	Economy	9500.00
0005434979439	23581	Economy	9500.00
0005435801674	23581	Economy	9500.00
0005434979530	23581	Economy	9500.00
0005434979449	23581	Economy	9500.00
0005434979443	23581	Economy	9500.00
0005434979459	23581	Economy	9500.00
0005434979427	23581	Economy	9500.00
0005434979544	23581	Economy	9500.00
0005434979494	23581	Economy	9500.00
0005434979479	23581	Economy	9500.00
0005434979634	23581	Economy	9500.00
0005434979596	23581	Economy	9500.00
0005434979489	23581	Economy	9500.00
0005434979514	23581	Economy	9500.00
0005434979481	23581	Economy	9500.00
0005434979565	23581	Economy	9500.00
0005434979488	23581	Economy	9500.00
0005434979543	23581	Economy	9500.00
0005434979456	23581	Economy	9500.00
0005434979493	23581	Economy	9500.00
0005434979526	23581	Economy	9500.00
0005434979448	23581	Economy	9500.00
0005434979420	23581	Economy	9500.00
0005434979480	23581	Economy	9500.00
0005434979451	23581	Economy	9500.00
0005434979452	23581	Economy	9500.00
0005434979522	23581	Economy	9500.00
0005434979490	23581	Economy	9500.00
0005435801670	23581	Economy	9500.00
0005435801675	23581	Economy	9500.00
0005435801669	23581	Economy	9500.00
0005434979528	23581	Economy	9500.00
0005434979496	23581	Economy	9500.00
0005434979450	23581	Economy	9500.00
0005434979499	23581	Economy	9500.00
0005434979466	23581	Economy	9500.00
0005434979455	23581	Economy	9500.00
0005434952533	2661	Economy	5300.00
0005434952536	2661	Economy	5300.00
0005434952535	2661	Economy	5300.00
0005434952534	2661	Economy	5300.00
0005433256401	2670	Economy	5300.00
0005433256423	28216	Economy	5300.00
0005434952497	28216	Economy	5300.00
0005434952502	28216	Economy	5300.00
0005433256424	28216	Economy	5300.00
0005434952498	28216	Economy	5300.00
0005434952509	28216	Economy	5300.00
0005433112375	19754	Economy	8700.00
0005433111508	19754	Economy	8700.00
0005433111509	19754	Economy	8700.00
0005433112376	19754	Economy	8700.00
0005433112378	19754	Economy	8700.00
0005433112377	19754	Economy	8700.00
0005434137452	11934	Business	9700.00
0005434137636	11934	Business	9700.00
0005434137635	11934	Business	9700.00
0005434137506	11934	Business	9700.00
0005434137388	11934	Business	9700.00
0005434137467	11934	Business	9700.00
0005434137394	11934	Business	9700.00
0005434137581	11934	Business	9700.00
0005434137522	11934	Business	9700.00
0005434137548	11934	Economy	3200.00
0005434137406	11934	Economy	3200.00
0005434137508	11934	Economy	3200.00
0005434137317	11934	Economy	3200.00
0005434137699	11934	Economy	3200.00
0005434137639	11934	Economy	3200.00
0005434137535	11934	Economy	3200.00
0005434137297	11934	Economy	3500.00
0005434137481	11934	Economy	3500.00
0005434137296	11934	Economy	3500.00
0005434137387	11934	Economy	3500.00
0005434137562	11934	Economy	3500.00
0005434137566	11934	Economy	3200.00
0005434137186	11934	Economy	3200.00
0005434137395	11934	Economy	3200.00
0005434137042	11934	Economy	3200.00
0005434137505	11934	Economy	3200.00
0005434137482	11934	Economy	3200.00
0005434137641	11934	Economy	3200.00
0005434137565	11934	Economy	3200.00
0005434137119	11934	Economy	3200.00
0005434137345	11934	Economy	3200.00
0005434137399	11934	Economy	3200.00
0005434137650	11934	Economy	3200.00
0005434137477	11934	Economy	3200.00
0005434137120	11934	Economy	3200.00
0005434137315	11934	Economy	3200.00
0005434137314	11934	Economy	3200.00
0005434137030	11934	Economy	3200.00
0005434137665	11934	Economy	3200.00
0005434137378	11934	Economy	3200.00
0005434137447	11934	Economy	3200.00
0005434137651	11934	Economy	3200.00
0005434137687	11934	Economy	3200.00
0005434137483	11934	Economy	3200.00
0005434137288	11934	Economy	3200.00
0005434137468	11934	Economy	3200.00
0005434137041	11934	Economy	3200.00
0005434137108	11934	Economy	3200.00
0005434137179	11934	Economy	3200.00
0005434137393	11934	Economy	3200.00
0005434137374	11934	Economy	3200.00
0005434137664	11934	Economy	3200.00
0005434137546	11934	Economy	3200.00
0005434137517	11934	Economy	3200.00
0005434137043	11934	Economy	3200.00
0005434137516	11934	Economy	3200.00
0005434137342	11934	Economy	3200.00
0005434137210	11934	Economy	3200.00
0005434137209	11934	Economy	3200.00
0005434137547	11934	Economy	3200.00
0005434137343	11934	Economy	3200.00
0005434137453	11934	Economy	3200.00
0005434137478	11934	Economy	3200.00
0005434137521	11934	Economy	3200.00
0005434137640	11934	Economy	3200.00
0005434137693	11934	Economy	3200.00
0005434137316	11934	Economy	3200.00
0005434137727	11934	Economy	3200.00
0005434137375	11934	Economy	3200.00
0005434137519	11934	Economy	3200.00
0005434137638	11934	Economy	3200.00
0005434137379	11934	Economy	3200.00
0005434137348	11934	Economy	3200.00
0005434137470	11934	Economy	3200.00
0005434137507	11934	Economy	3200.00
0005434137199	11934	Economy	3200.00
0005434137694	11934	Economy	3200.00
0005434137602	11934	Economy	3200.00
0005434137333	11934	Economy	3200.00
0005434137686	11934	Economy	3200.00
0005434137580	11934	Economy	3200.00
0005434137652	11934	Economy	3200.00
0005434137513	11934	Economy	3200.00
0005434138190	28753	Business	9700.00
0005434138153	28753	Business	9700.00
0005434138211	28753	Business	9700.00
0005434138139	28753	Business	9700.00
0005434138127	28753	Business	9700.00
0005434138202	28753	Business	9700.00
0005434138146	28753	Business	9700.00
0005434138163	28753	Business	9700.00
0005434138191	28753	Business	9700.00
0005434138194	28753	Business	9700.00
0005434138143	28753	Economy	3200.00
0005434138152	28753	Economy	3200.00
0005434138181	28753	Economy	3200.00
0005434138198	28753	Economy	3200.00
0005434138166	28753	Economy	3200.00
0005434138188	28753	Economy	3200.00
0005434138149	28753	Economy	3200.00
0005434138203	28753	Economy	3200.00
0005434138167	28753	Economy	3200.00
0005434138172	28753	Economy	3500.00
0005434138159	28753	Economy	3500.00
0005434138160	28753	Economy	3500.00
0005434138137	28753	Economy	3500.00
0005434138212	28753	Economy	3500.00
0005434138196	28753	Economy	3200.00
0005434138140	28753	Economy	3200.00
0005434138206	28753	Economy	3200.00
0005434138214	28753	Economy	3200.00
0005434138170	28753	Economy	3200.00
0005434138133	28753	Economy	3200.00
0005434138156	28753	Economy	3200.00
0005434138204	28753	Economy	3200.00
0005434138177	28753	Economy	3200.00
0005434138210	28753	Economy	3200.00
0005434138145	28753	Economy	3200.00
0005434138208	28753	Economy	3200.00
0005434138201	28753	Economy	3200.00
0005434138189	28753	Economy	3200.00
0005434138126	28753	Economy	3200.00
0005434138164	28753	Economy	3200.00
0005434138155	28753	Economy	3200.00
0005434138141	28753	Economy	3200.00
0005434138179	28753	Economy	3200.00
0005434138182	28753	Economy	3200.00
0005434138173	28753	Economy	3200.00
0005434138213	28753	Economy	3200.00
0005434138169	28753	Economy	3200.00
0005434138135	28753	Economy	3200.00
0005434138150	28753	Economy	3200.00
0005434138165	28753	Economy	3200.00
0005434138175	28753	Economy	3200.00
0005434138197	28753	Economy	3200.00
0005434138131	28753	Economy	3200.00
0005434138144	28753	Economy	3200.00
0005434138138	28753	Economy	3200.00
0005434138195	28753	Economy	3200.00
0005434138142	28753	Economy	3200.00
0005434138154	28753	Economy	3200.00
0005434138161	28753	Economy	3200.00
0005434138209	28753	Economy	3200.00
0005434138171	28753	Economy	3200.00
0005434138134	28753	Economy	3200.00
0005434138205	28753	Economy	3200.00
0005434138186	28753	Economy	3200.00
0005434138157	28753	Economy	3200.00
0005434138151	28753	Economy	3200.00
0005434138129	28753	Economy	3200.00
0005434138125	28753	Economy	3200.00
0005434138176	28753	Economy	3200.00
0005434138183	28753	Economy	3200.00
0005434138174	28753	Economy	3200.00
0005434138200	28753	Economy	3200.00
0005434138185	28753	Economy	3200.00
0005434138148	28753	Economy	3200.00
0005434138193	28753	Economy	3200.00
0005434138162	28753	Economy	3200.00
0005434138132	28753	Economy	3200.00
0005434138207	28753	Economy	3200.00
0005434138199	28753	Economy	3200.00
0005434138130	28753	Economy	3200.00
0005434138178	28753	Economy	3200.00
0005434138158	28753	Economy	3200.00
0005434138147	28753	Economy	3200.00
0005434138187	28753	Economy	3200.00
0005434138168	28753	Economy	3200.00
0005434138192	28753	Economy	3200.00
0005434138128	28753	Economy	3200.00
0005434138136	28753	Economy	3200.00
0005434138180	28753	Economy	3200.00
0005434138184	28753	Economy	3200.00
0005435312786	6589	Economy	23000.00
0005434466467	6589	Economy	23000.00
0005434466468	6589	Economy	20900.00
0005434466464	6589	Economy	20900.00
0005435312774	6589	Economy	20900.00
0005434466465	6589	Economy	20900.00
0005434466462	6589	Economy	20900.00
0005434466466	6589	Economy	20900.00
0005435312787	6589	Economy	20900.00
0005434466460	6589	Economy	20900.00
0005434466459	6589	Economy	20900.00
0005434466461	6589	Economy	20900.00
0005434466463	6589	Economy	20900.00
0005434466458	6589	Economy	20900.00
0005434513573	19087	Economy	26000.00
0005434513556	19087	Economy	23600.00
0005434190402	19087	Economy	23600.00
0005434516057	19087	Economy	23600.00
0005434516051	19087	Economy	23600.00
0005434190400	19087	Economy	23600.00
0005434190406	19087	Economy	23600.00
0005434513554	19087	Economy	23600.00
0005434513557	19087	Economy	23600.00
0005434190401	19087	Economy	23600.00
0005434516059	19087	Economy	23600.00
0005434190407	19087	Economy	23600.00
0005434516058	19087	Economy	23600.00
0005434190403	19087	Economy	23600.00
0005434513552	19087	Economy	23600.00
0005434513553	19087	Economy	23600.00
0005434513547	19087	Economy	23600.00
0005434516064	19087	Economy	23600.00
0005434190408	19087	Economy	23600.00
0005434516052	19087	Economy	23600.00
0005434516055	19087	Economy	23600.00
0005434513558	19087	Economy	23600.00
0005434516060	19087	Economy	23600.00
0005434190404	19087	Economy	23600.00
0005434513551	19087	Economy	23600.00
0005434513555	19087	Economy	23600.00
0005434516062	19087	Economy	23600.00
0005434516056	19087	Economy	23600.00
0005434190405	19087	Economy	23600.00
0005433538877	6795	Economy	9900.00
0005433534500	6795	Economy	9900.00
0005433538875	6795	Economy	9900.00
0005435259740	6795	Economy	9900.00
0005433538881	6795	Economy	9900.00
0005435259726	6795	Economy	9900.00
0005435259727	6795	Economy	9900.00
0005433534501	6795	Economy	9900.00
0005433538880	6795	Economy	9900.00
0005435259712	6795	Economy	9900.00
0005433538879	6795	Economy	9900.00
0005433538876	6795	Economy	9900.00
0005435259710	6795	Economy	9900.00
0005433538883	6795	Economy	9900.00
0005433538882	6795	Economy	9900.00
0005435259733	6795	Economy	9900.00
0005433538878	6795	Economy	9900.00
0005435259711	6795	Economy	9900.00
0005435259761	25022	Economy	9900.00
0005433538825	25022	Economy	9900.00
0005435259760	25022	Economy	9900.00
0005435259763	25022	Economy	9900.00
0005433538803	25022	Economy	9900.00
0005433538802	25022	Economy	9900.00
0005435259762	25022	Economy	9900.00
0005433538759	25022	Economy	9900.00
0005433538788	25022	Economy	9900.00
0005433538824	25022	Economy	9900.00
0005433538843	25022	Economy	9900.00
0005433538812	25022	Economy	9900.00
0005433538809	25022	Economy	9900.00
0005433538808	25022	Economy	9900.00
0005435259759	25022	Economy	9900.00
0005433538811	25022	Economy	9900.00
0005433511964	801	Economy	14600.00
0005433511959	801	Economy	14600.00
0005433511960	801	Economy	14600.00
0005432922496	801	Economy	14600.00
0005433511963	801	Economy	14600.00
0005433511957	801	Economy	14600.00
0005433511966	801	Economy	14600.00
0005432922483	801	Economy	14600.00
0005433511962	801	Economy	14600.00
0005433511961	801	Economy	14600.00
0005433511956	801	Economy	14600.00
0005433511958	801	Economy	14600.00
0005433511965	801	Economy	14600.00
0005432922527	16179	Economy	14600.00
0005432922530	16179	Economy	14600.00
0005433511898	16179	Economy	14600.00
0005432922529	16179	Economy	14600.00
0005432922532	16179	Economy	14600.00
0005432922528	16179	Economy	14600.00
0005433511917	16179	Economy	14600.00
0005432922531	16179	Economy	14600.00
0005435697369	3697	Economy	7900.00
0005435697383	3697	Economy	7900.00
0005435697362	3697	Economy	7900.00
0005435697384	3697	Economy	7900.00
0005434950536	3697	Economy	7200.00
0005435697374	3697	Economy	7200.00
0005435916139	3697	Economy	7200.00
0005435697363	3697	Economy	7200.00
0005434950534	3697	Economy	7200.00
0005435697389	3697	Economy	7200.00
0005435697380	3697	Economy	7200.00
0005435916142	3697	Economy	7200.00
0005434950535	3697	Economy	7200.00
0005435697365	3697	Economy	7200.00
0005435697370	3697	Economy	7200.00
0005435916147	3697	Economy	7200.00
0005435697379	3697	Economy	7200.00
0005435916158	3697	Economy	7200.00
0005435697386	3697	Economy	7200.00
0005435697364	3697	Economy	7200.00
0005434950533	3697	Economy	7200.00
0005435697377	3697	Economy	7200.00
0005435916145	3697	Economy	7200.00
0005435697366	3697	Economy	7200.00
0005435916140	3697	Economy	7200.00
0005435697381	3697	Economy	7200.00
0005435697378	3697	Economy	7200.00
0005435697373	3697	Economy	7200.00
0005435697368	3697	Economy	7200.00
0005434950532	3697	Economy	7200.00
0005435916130	3697	Economy	7200.00
0005435697387	3697	Economy	7200.00
0005435697360	3697	Economy	7200.00
0005435916144	3697	Economy	7200.00
0005435697372	3697	Economy	7200.00
0005435697361	3697	Economy	7200.00
0005435916159	3697	Economy	7200.00
0005435697388	3697	Economy	7200.00
0005435697367	3697	Economy	7200.00
0005435697382	3697	Economy	7200.00
0005435697376	3697	Economy	7200.00
0005435697371	3697	Economy	7200.00
0005435697375	3697	Economy	7200.00
0005435697385	3697	Economy	7200.00
0005435916148	3697	Economy	7200.00
0005435697077	16271	Economy	7900.00
0005434950494	16271	Economy	7200.00
0005435935046	16271	Economy	7200.00
0005434950510	16271	Economy	7200.00
0005435697120	16271	Economy	7200.00
0005435935047	16271	Economy	7200.00
0005435697173	16271	Economy	7200.00
0005435697036	16271	Economy	7200.00
0005434950501	16271	Economy	7200.00
0005435697097	16271	Economy	7200.00
0005434950492	16271	Economy	7200.00
0005435697114	16271	Economy	7200.00
0005435697041	16271	Economy	7200.00
0005435696976	16271	Economy	7200.00
0005435697096	16271	Economy	7200.00
0005435697115	16271	Economy	7200.00
0005434950511	16271	Economy	7200.00
0005435697084	16271	Economy	7200.00
0005434950491	16271	Economy	7200.00
0005435916172	16271	Economy	7200.00
0005435697187	16271	Economy	7200.00
0005434950482	16271	Economy	7200.00
0005435697085	16271	Economy	7200.00
0005435697030	16271	Economy	7200.00
0005434950483	16271	Economy	7200.00
0005435697142	16271	Economy	7200.00
0005435935045	16271	Economy	7200.00
0005435697029	16271	Economy	7200.00
0005434950481	16271	Economy	7200.00
0005435916171	16271	Economy	7200.00
0005435696918	16271	Economy	7200.00
0005435697186	16271	Economy	7200.00
0005435697062	16271	Economy	7200.00
0005435697189	16271	Economy	7200.00
0005434950493	16271	Economy	7200.00
0005435697000	16271	Economy	7200.00
0005435916170	16271	Economy	7200.00
0005435904892	3972	Economy	21300.00
0005432607572	3972	Economy	21300.00
0005434606833	3972	Economy	19300.00
0005434604900	3972	Economy	19300.00
0005434606831	3972	Economy	19300.00
0005434604901	3972	Economy	19300.00
0005433519464	3972	Economy	19300.00
0005435904891	3972	Economy	19300.00
0005434604902	3972	Economy	19300.00
0005435853600	3972	Economy	19300.00
0005432607571	3972	Economy	19300.00
0005432609734	3972	Economy	19300.00
0005435853605	3972	Economy	19300.00
0005435841466	3972	Economy	19300.00
0005432609735	3972	Economy	19300.00
0005433519463	3972	Economy	19300.00
0005435853601	3972	Economy	19300.00
0005434604903	3972	Economy	19300.00
0005432609738	3972	Economy	19300.00
0005434606832	3972	Economy	19300.00
0005432609737	3972	Economy	19300.00
0005432607569	3972	Economy	19300.00
0005432607570	3972	Economy	19300.00
0005435853606	3972	Economy	19300.00
0005432609736	3972	Economy	19300.00
0005435841094	22078	Economy	21300.00
0005433519416	22078	Economy	21300.00
0005434606792	22078	Economy	19300.00
0005433519415	22078	Economy	19300.00
0005432609688	22078	Economy	19300.00
0005432609687	22078	Economy	19300.00
0005432609697	22078	Economy	19300.00
0005433519413	22078	Economy	19300.00
0005435841096	22078	Economy	19300.00
0005432609698	22078	Economy	19300.00
0005432613823	22078	Economy	19300.00
0005432609693	22078	Economy	19300.00
0005432609691	22078	Economy	19300.00
0005432609684	22078	Economy	19300.00
0005435841476	22078	Economy	19300.00
0005432613829	22078	Economy	19300.00
0005435841473	22078	Economy	19300.00
0005432609689	22078	Economy	19300.00
0005432613807	22078	Economy	19300.00
0005435841097	22078	Economy	19300.00
0005433519423	22078	Economy	19300.00
0005435841472	22078	Economy	19300.00
0005432609673	22078	Economy	19300.00
0005432609672	22078	Economy	19300.00
0005435841474	22078	Economy	19300.00
0005435841475	22078	Economy	19300.00
0005432613808	22078	Economy	19300.00
0005435841098	22078	Economy	19300.00
0005432609696	22078	Economy	19300.00
0005432613800	22078	Economy	19300.00
0005435841471	22078	Economy	19300.00
0005433519412	22078	Economy	19300.00
0005435841095	22078	Economy	19300.00
0005432613830	22078	Economy	19300.00
0005432609695	22078	Economy	19300.00
0005432609685	22078	Economy	19300.00
0005432609690	22078	Economy	19300.00
0005433348961	768	Economy	3700.00
0005435628727	768	Economy	3700.00
0005433348960	768	Economy	3700.00
0005433348932	768	Economy	3700.00
0005433348933	768	Economy	3700.00
0005433348928	768	Economy	3700.00
0005433348994	15985	Economy	3700.00
0005435628701	15985	Economy	3700.00
0005435628703	15985	Economy	3700.00
0005433348995	15985	Economy	3700.00
0005433348998	15985	Economy	3700.00
0005435628698	15985	Economy	3700.00
0005433348997	15985	Economy	3700.00
0005435628702	15985	Economy	3700.00
0005433348999	15985	Economy	3700.00
0005433348996	15985	Economy	3700.00
0005433158118	17255	Economy	7100.00
0005433158113	17255	Economy	7100.00
0005433159298	17255	Economy	7100.00
0005434446519	17255	Economy	7100.00
0005433158114	17255	Economy	7100.00
0005433158112	17255	Economy	7100.00
0005433159290	17255	Economy	7100.00
0005434445247	17255	Economy	7100.00
0005433158115	17255	Economy	7100.00
0005434445248	17255	Economy	7100.00
0005433159281	17255	Economy	7100.00
0005434445230	17668	Economy	7100.00
0005434445236	17668	Economy	7100.00
0005434445239	17668	Economy	7100.00
0005434445238	17668	Economy	7100.00
0005434445224	17668	Economy	7100.00
0005435132895	7881	Economy	5900.00
0005435132894	7881	Economy	5400.00
0005435132890	7881	Economy	5400.00
0005435383102	7881	Economy	5400.00
0005435132889	7881	Economy	5400.00
0005435132896	7881	Economy	5400.00
0005435132892	7881	Economy	5400.00
0005435383121	7881	Economy	5400.00
0005435132891	7881	Economy	5400.00
0005435132899	7881	Economy	5400.00
0005435132897	7881	Economy	5400.00
0005435132893	7881	Economy	5400.00
0005435132898	7881	Economy	5400.00
0005435383114	7881	Economy	5400.00
0005435383155	33108	Economy	5900.00
0005435132800	33108	Economy	5400.00
0005435132805	33108	Economy	5400.00
0005435383158	33108	Economy	5400.00
0005435132809	33108	Economy	5400.00
0005435383156	33108	Economy	5400.00
0005435132855	33108	Economy	5400.00
0005435383157	33108	Economy	5400.00
0005435383154	33108	Economy	5400.00
0005435811084	4409	Business	133200.00
0005435811076	4409	Business	133200.00
0005435811072	4409	Business	133200.00
0005435811070	4409	Business	133200.00
0005435811069	4409	Economy	44400.00
0005435811079	4409	Economy	44400.00
0005435938863	4409	Economy	48800.00
0005435811082	4409	Economy	44400.00
0005435811071	4409	Economy	44400.00
0005435811077	4409	Economy	44400.00
0005435938860	4409	Economy	44400.00
0005435938864	4409	Economy	44400.00
0005435811074	4409	Economy	44400.00
0005435938873	4409	Economy	44400.00
0005435811075	4409	Economy	44400.00
0005435811083	4409	Economy	44400.00
0005435938855	4409	Economy	44400.00
0005435811078	4409	Economy	44400.00
0005435811073	4409	Economy	44400.00
0005435811080	4409	Economy	44400.00
0005435811081	4409	Economy	44400.00
0005435938887	29439	Business	133200.00
0005435811031	29439	Business	133200.00
0005435811025	29439	Business	133200.00
0005435811043	29439	Business	133200.00
0005435938886	29439	Business	133200.00
0005435811001	29439	Business	133200.00
0005435811048	29439	Economy	44400.00
0005435811013	29439	Economy	44400.00
0005435811014	29439	Economy	44400.00
0005435811034	29439	Economy	44400.00
0005435811029	29439	Economy	48800.00
0005435811012	29439	Economy	44400.00
0005435811026	29439	Economy	44400.00
0005435811028	29439	Economy	44400.00
0005435938889	29439	Economy	44400.00
0005435811024	29439	Economy	44400.00
0005435811027	29439	Economy	44400.00
0005435811033	29439	Economy	44400.00
0005435811023	29439	Economy	44400.00
0005435811011	29439	Economy	44400.00
0005435938891	29439	Economy	44400.00
0005435811022	29439	Economy	44400.00
0005435938890	29439	Economy	44400.00
0005435938885	29439	Economy	44400.00
0005435938888	29439	Economy	44400.00
0005435160320	7526	Economy	13800.00
0005435390177	7526	Economy	13800.00
0005435390176	7526	Economy	12500.00
0005435390195	7526	Economy	12500.00
0005435160309	7526	Economy	12500.00
0005435160312	7526	Economy	12500.00
0005435160316	7526	Economy	12500.00
0005435390184	7526	Economy	12500.00
0005435390209	7526	Economy	12500.00
0005435390204	7526	Economy	12500.00
0005435390210	7526	Economy	12500.00
0005435160319	7526	Economy	12500.00
0005435160318	7526	Economy	12500.00
0005435160313	7526	Economy	12500.00
0005435160314	7526	Economy	12500.00
0005435160315	7526	Economy	12500.00
0005435160310	7526	Economy	12500.00
0005435390194	7526	Economy	12500.00
0005435390189	7526	Economy	12500.00
0005435160317	7526	Economy	12500.00
0005435160311	7526	Economy	12500.00
0005435160222	29585	Economy	13800.00
0005435160245	29585	Economy	13800.00
0005435160257	29585	Economy	12500.00
0005435160261	29585	Economy	12500.00
0005435390251	29585	Economy	12500.00
0005435160229	29585	Economy	12500.00
0005435390248	29585	Economy	12500.00
0005435160259	29585	Economy	12500.00
0005435160199	29585	Economy	12500.00
0005435160198	29585	Economy	12500.00
0005435390247	29585	Economy	12500.00
0005435390246	29585	Economy	12500.00
0005435390249	29585	Economy	12500.00
0005435160200	29585	Economy	12500.00
0005435160201	29585	Economy	12500.00
0005435390245	29585	Economy	12500.00
0005435160221	29585	Economy	12500.00
0005435160197	29585	Economy	12500.00
0005435160244	29585	Economy	12500.00
0005435160258	29585	Economy	12500.00
0005435390250	29585	Economy	12500.00
0005435178995	18476	Economy	4900.00
0005432398181	18476	Economy	4900.00
0005432394080	18476	Economy	4900.00
0005435178993	18476	Economy	4900.00
0005432398164	18476	Economy	4900.00
0005432394082	18476	Economy	4900.00
0005432394081	18476	Economy	4900.00
0005435178498	18476	Economy	4900.00
0005435178994	18476	Economy	4900.00
0005432400124	27158	Economy	4900.00
0005435178485	27158	Economy	4900.00
0005432398198	27158	Economy	4900.00
0005432398199	27158	Economy	4900.00
0005432400122	27158	Economy	4900.00
0005432400125	27158	Economy	4900.00
0005432398197	27158	Economy	4900.00
0005435178472	27158	Economy	4900.00
0005432400123	27158	Economy	4900.00
0005432398196	27158	Economy	4900.00
0005435178482	27158	Economy	4900.00
0005432639139	2256	Business	87300.00
0005432639152	2256	Business	87300.00
0005432639150	2256	Business	87300.00
0005432639148	2256	Business	87300.00
0005432865945	2256	Business	87300.00
0005432639134	2256	Business	87300.00
0005432865958	2256	Economy	29100.00
0005432865963	2256	Economy	29100.00
0005432865961	2256	Economy	32000.00
0005432639155	2256	Economy	32000.00
0005432639137	2256	Economy	29100.00
0005432865976	2256	Economy	29100.00
0005432639154	2256	Economy	29100.00
0005432865977	2256	Economy	29100.00
0005432639151	2256	Economy	29100.00
0005432639136	2256	Economy	29100.00
0005432639142	2256	Economy	29100.00
0005432865948	2256	Economy	29100.00
0005432639135	2256	Economy	29100.00
0005432639156	2256	Economy	29100.00
0005432865957	2256	Economy	29100.00
0005432639153	2256	Economy	29100.00
0005432639149	2256	Economy	29100.00
0005432865975	2256	Economy	29100.00
0005432639141	2256	Economy	29100.00
0005432639132	2256	Economy	29100.00
0005432639140	2256	Economy	29100.00
0005432865959	2256	Economy	29100.00
0005432639147	2256	Economy	29100.00
0005432639138	2256	Economy	29100.00
0005432639143	2256	Economy	29100.00
0005432639146	2256	Economy	29100.00
0005432639145	2256	Economy	29100.00
0005432639133	2256	Economy	29100.00
0005432639144	2256	Economy	29100.00
0005432865946	2256	Economy	29100.00
0005434191262	9706	Economy	4400.00
0005434191267	9706	Economy	4400.00
0005434504208	6548	Business	48400.00
0005435103942	6548	Business	48400.00
0005435103943	6548	Business	48400.00
0005434504217	6548	Business	48400.00
0005435103944	6548	Business	48400.00
0005434504191	6548	Economy	16100.00
0005434504188	6548	Economy	16100.00
0005434504189	6548	Economy	16100.00
0005434504186	6548	Economy	16100.00
0005434504195	6548	Economy	16100.00
0005434504202	6548	Economy	16100.00
0005435103948	6548	Economy	16100.00
0005434504194	6548	Economy	17800.00
0005434504199	6548	Economy	17800.00
0005434504212	6548	Economy	17800.00
0005434504213	6548	Economy	16100.00
0005434504203	6548	Economy	16100.00
0005434504200	6548	Economy	16100.00
0005434504222	6548	Economy	16100.00
0005435103947	6548	Economy	16100.00
0005434504225	6548	Economy	16100.00
0005434504190	6548	Economy	16100.00
0005434504196	6548	Economy	16100.00
0005434504210	6548	Economy	16100.00
0005435103945	6548	Economy	16100.00
0005434504219	6548	Economy	16100.00
0005434504207	6548	Economy	16100.00
0005434504197	6548	Economy	16100.00
0005434504187	6548	Economy	16100.00
0005434504193	6548	Economy	16100.00
0005434504198	6548	Economy	16100.00
0005434504211	6548	Economy	16100.00
0005435103946	6548	Economy	16100.00
0005434504205	6548	Economy	16100.00
0005434504204	6548	Economy	16100.00
0005434504220	6548	Economy	16100.00
0005434504216	6548	Economy	16100.00
0005434504185	6548	Economy	16100.00
0005434504218	6548	Economy	16100.00
0005434504223	6548	Economy	16100.00
0005434504214	6548	Economy	16100.00
0005434504192	6548	Economy	16100.00
0005434504215	6548	Economy	16100.00
0005434504201	6548	Economy	16100.00
0005434504224	6548	Economy	16100.00
0005434504221	6548	Economy	16100.00
0005435103949	6548	Economy	16100.00
0005434504209	6548	Economy	16100.00
0005434504206	6548	Economy	16100.00
0005434503776	22648	Business	48400.00
0005434503628	22648	Business	48400.00
0005435103844	22648	Business	48400.00
0005434503836	22648	Business	48400.00
0005434503725	22648	Business	48400.00
0005434503807	22648	Business	48400.00
0005434503727	22648	Business	48400.00
0005435103853	22648	Business	48400.00
0005434503691	22648	Economy	16100.00
0005434503817	22648	Economy	16100.00
0005435103841	22648	Economy	16100.00
0005434503815	22648	Economy	16100.00
0005434503772	22648	Economy	16100.00
0005434503752	22648	Economy	16100.00
0005434503873	22648	Economy	16100.00
0005434503749	22648	Economy	17800.00
0005434503750	22648	Economy	17800.00
0005434503806	22648	Economy	17800.00
0005434503753	22648	Economy	17800.00
0005434503818	22648	Economy	16100.00
0005434503790	22648	Economy	16100.00
0005434503839	22648	Economy	16100.00
0005435103827	22648	Economy	16100.00
0005434503751	22648	Economy	16100.00
0005434503666	22648	Economy	16100.00
0005434503639	22648	Economy	16100.00
0005434503869	22648	Economy	16100.00
0005434503791	22648	Economy	16100.00
0005434503660	22648	Economy	16100.00
0005434503649	22648	Economy	16100.00
0005434503724	22648	Economy	16100.00
0005434503747	22648	Economy	16100.00
0005434503663	22648	Economy	16100.00
0005434503826	22648	Economy	16100.00
0005434503808	22648	Economy	16100.00
0005434503758	22648	Economy	16100.00
0005434503627	22648	Economy	16100.00
0005434503689	22648	Economy	16100.00
0005434503728	22648	Economy	16100.00
0005434503774	22648	Economy	16100.00
0005434503650	22648	Economy	16100.00
0005434503629	22648	Economy	16100.00
0005435103833	22648	Economy	16100.00
0005434503713	22648	Economy	16100.00
0005434503864	22648	Economy	16100.00
0005435103852	22648	Economy	16100.00
0005434503816	22648	Economy	16100.00
0005434503746	22648	Economy	16100.00
0005434503638	22648	Economy	16100.00
0005434503760	22648	Economy	16100.00
0005434503840	22648	Economy	16100.00
0005434503690	22648	Economy	16100.00
0005435103826	22648	Economy	16100.00
0005434503696	22648	Economy	16100.00
0005434503719	22648	Economy	16100.00
0005434503729	22648	Economy	16100.00
0005434503868	22648	Economy	16100.00
0005435653129	1653	Business	50000.00
0005435653104	1653	Business	50000.00
0005435653121	1653	Business	50000.00
0005435653103	1653	Business	50000.00
0005433367633	1653	Business	50000.00
0005433367553	1653	Business	50000.00
0005435653097	1653	Business	50000.00
0005433367699	1653	Business	50000.00
0005433367610	1653	Business	50000.00
0005433367624	1653	Economy	16700.00
0005433367715	1653	Economy	16700.00
0005435653102	1653	Economy	16700.00
0005433367648	1653	Economy	16700.00
0005435653095	1653	Economy	16700.00
0005435653101	1653	Economy	16700.00
0005435653119	1653	Economy	16700.00
0005435653133	1653	Economy	16700.00
0005435653131	1653	Economy	16700.00
0005433367440	1653	Economy	16700.00
0005433367647	1653	Economy	18300.00
0005435653098	1653	Economy	18300.00
0005433367644	1653	Economy	18300.00
0005433367589	1653	Economy	16700.00
0005435653136	1653	Economy	16700.00
0005435653105	1653	Economy	16700.00
0005435653117	1653	Economy	16700.00
0005433367609	1653	Economy	16700.00
0005433367623	1653	Economy	16700.00
0005435653120	1653	Economy	16700.00
0005435653138	1653	Economy	16700.00
0005433367568	1653	Economy	16700.00
0005433367614	1653	Economy	16700.00
0005433367671	1653	Economy	16700.00
0005433367439	1653	Economy	16700.00
0005433367587	1653	Economy	16700.00
0005435653107	1653	Economy	16700.00
0005435653134	1653	Economy	16700.00
0005433367716	1653	Economy	16700.00
0005435653130	1653	Economy	16700.00
0005435653100	1653	Economy	16700.00
0005433367697	1653	Economy	16700.00
0005435653108	1653	Economy	16700.00
0005433367780	1653	Economy	16700.00
0005435653127	1653	Economy	16700.00
0005435653099	1653	Economy	16700.00
0005435653122	1653	Economy	16700.00
0005435653096	1653	Economy	16700.00
0005433367585	1653	Economy	16700.00
0005433367433	1653	Economy	16700.00
0005435653115	1653	Economy	16700.00
0005435653106	1653	Economy	16700.00
0005435653125	1653	Economy	16700.00
0005433367438	1653	Economy	16700.00
0005435653112	1653	Economy	16700.00
0005433367674	1653	Economy	16700.00
0005433367431	1653	Economy	16700.00
0005435653110	1653	Economy	16700.00
0005435653109	1653	Economy	16700.00
0005435653124	1653	Economy	16700.00
0005433367612	1653	Economy	16700.00
0005435653113	1653	Economy	16700.00
0005433367473	1653	Economy	16700.00
0005435653123	1653	Economy	16700.00
0005433367608	1653	Economy	16700.00
0005433367588	1653	Economy	16700.00
0005433367552	1653	Economy	16700.00
0005435653128	1653	Economy	16700.00
0005433367576	1653	Economy	16700.00
0005433367781	1653	Economy	16700.00
0005435653094	1653	Economy	16700.00
0005433367556	1653	Economy	16700.00
0005435653135	1653	Economy	16700.00
0005435653126	1653	Economy	16700.00
0005435653132	1653	Economy	16700.00
0005433367615	1653	Economy	16700.00
0005433367474	1653	Economy	16700.00
0005435653137	1653	Economy	16700.00
0005435653118	1653	Economy	16700.00
0005433367432	1653	Economy	16700.00
0005435653111	1653	Economy	16700.00
0005435653116	1653	Economy	16700.00
0005435653114	1653	Economy	16700.00
0005433367911	21684	Business	50000.00
0005433367930	21684	Business	50000.00
0005433367944	21684	Business	50000.00
0005435652704	21684	Business	50000.00
0005433367933	21684	Business	50000.00
0005435652610	21684	Business	50000.00
0005435652526	21684	Business	50000.00
0005433367925	21684	Business	50000.00
0005433367914	21684	Business	50000.00
0005433367917	21684	Economy	16700.00
0005435652577	21684	Economy	16700.00
0005433367941	21684	Economy	16700.00
0005435652755	21684	Economy	16700.00
0005435652633	21684	Economy	16700.00
0005435652712	21684	Economy	16700.00
0005433367923	21684	Economy	16700.00
0005435652817	21684	Economy	16700.00
0005433367927	21684	Economy	18300.00
0005433367924	21684	Economy	18300.00
0005435652832	21684	Economy	18300.00
0005433367932	21684	Economy	18300.00
0005435652831	21684	Economy	18300.00
0005433367935	21684	Economy	16700.00
0005435652812	21684	Economy	16700.00
0005433367939	21684	Economy	16700.00
0005433367909	21684	Economy	16700.00
0005435652754	21684	Economy	16700.00
0005435652654	21684	Economy	16700.00
0005435652847	21684	Economy	16700.00
0005435652678	21684	Economy	16700.00
0005433367940	21684	Economy	16700.00
0005435652525	21684	Economy	16700.00
0005433367947	21684	Economy	16700.00
0005435652622	21684	Economy	16700.00
0005435652652	21684	Economy	16700.00
0005435652573	21684	Economy	16700.00
0005433367912	21684	Economy	16700.00
0005433367926	21684	Economy	16700.00
0005433367920	21684	Economy	16700.00
0005433367913	21684	Economy	16700.00
0005433367942	21684	Economy	16700.00
0005435652524	21684	Economy	16700.00
0005435652647	21684	Economy	16700.00
0005433367946	21684	Economy	16700.00
0005433367931	21684	Economy	16700.00
0005435652380	21684	Economy	16700.00
0005435652538	21684	Economy	16700.00
0005435652581	21684	Economy	16700.00
0005433367945	21684	Economy	16700.00
0005433367936	21684	Economy	16700.00
0005433367919	21684	Economy	16700.00
0005435652813	21684	Economy	16700.00
0005435652848	21684	Economy	16700.00
0005433367915	21684	Economy	16700.00
0005435652648	21684	Economy	16700.00
0005433367943	21684	Economy	16700.00
0005435652811	21684	Economy	16700.00
0005435652830	21684	Economy	16700.00
0005435652744	21684	Economy	16700.00
0005435652659	21684	Economy	16700.00
0005435652815	21684	Economy	16700.00
0005435652818	21684	Economy	16700.00
0005433367929	21684	Economy	16700.00
0005435652702	21684	Economy	16700.00
0005433367928	21684	Economy	16700.00
0005433367918	21684	Economy	16700.00
0005435652705	21684	Economy	16700.00
0005433367910	21684	Economy	16700.00
0005435652774	21684	Economy	16700.00
0005433367921	21684	Economy	16700.00
0005435652381	21684	Economy	16700.00
0005435652566	21684	Economy	16700.00
0005433367916	21684	Economy	16700.00
0005433367937	21684	Economy	16700.00
0005435652721	21684	Economy	16700.00
0005435652842	21684	Economy	16700.00
0005433367934	21684	Economy	16700.00
0005435652841	21684	Economy	16700.00
0005435652614	21684	Economy	16700.00
0005435652734	21684	Economy	16700.00
0005433367938	21684	Economy	16700.00
0005435652634	21684	Economy	16700.00
0005433367922	21684	Economy	16700.00
0005434466413	23230	Economy	23000.00
0005434466441	23230	Economy	23000.00
0005435312811	23230	Economy	20900.00
0005434466405	23230	Economy	20900.00
0005434466423	23230	Economy	20900.00
0005434466406	23230	Economy	20900.00
0005434466417	23230	Economy	20900.00
0005435312810	23230	Economy	20900.00
0005435312809	23230	Economy	20900.00
0005434466425	23230	Economy	20900.00
0005434466436	23230	Economy	20900.00
0005434466418	23230	Economy	20900.00
0005434466412	23230	Economy	20900.00
0005434466438	23230	Economy	20900.00
0005434466442	23230	Economy	20900.00
0005435312808	23230	Economy	20900.00
0005434466422	23230	Economy	20900.00
0005435312807	23230	Economy	20900.00
0005434466411	23230	Economy	20900.00
0005434466424	23230	Economy	20900.00
0005433985987	4149	Business	21500.00
0005433986023	4149	Business	21500.00
0005433985988	4149	Business	21500.00
0005433985992	4149	Business	21500.00
0005433986010	4149	Business	21500.00
0005433986021	4149	Economy	7200.00
0005433986018	4149	Economy	7200.00
0005433986004	4149	Economy	7900.00
0005433986006	4149	Economy	7900.00
0005433986016	4149	Economy	7200.00
0005433986013	4149	Economy	7200.00
0005433985996	4149	Economy	7200.00
0005433986008	4149	Economy	7200.00
0005433986019	4149	Economy	7200.00
0005433985991	4149	Economy	7200.00
0005435788774	4149	Economy	7200.00
0005433986025	4149	Economy	7200.00
0005433985993	4149	Economy	7200.00
0005433985998	4149	Economy	7200.00
0005433986017	4149	Economy	7200.00
0005433986007	4149	Economy	7200.00
0005433986001	4149	Economy	7200.00
0005435788773	4149	Economy	7200.00
0005433986022	4149	Economy	7200.00
0005433986009	4149	Economy	7200.00
0005433985999	4149	Economy	7200.00
0005433985984	4149	Economy	7200.00
0005433986003	4149	Economy	7200.00
0005433986000	4149	Economy	7200.00
0005433986024	4149	Economy	7200.00
0005433986012	4149	Economy	7200.00
0005433985997	4149	Economy	7200.00
0005433986015	4149	Economy	7200.00
0005433985995	4149	Economy	7200.00
0005433986014	4149	Economy	7200.00
0005433985990	4149	Economy	7200.00
0005433986026	4149	Economy	7200.00
0005433985985	4149	Economy	7200.00
0005433986020	4149	Economy	7200.00
0005433985986	4149	Economy	7200.00
0005433986002	4149	Economy	7200.00
0005433986005	4149	Economy	7200.00
0005433985989	4149	Economy	7200.00
0005433985994	4149	Economy	7200.00
0005433986011	4149	Economy	7200.00
0005433985567	25668	Business	21500.00
0005433985382	25668	Business	21500.00
0005433985612	25668	Business	21500.00
0005433985676	25668	Business	21500.00
0005433985226	25668	Business	21500.00
0005433985227	25668	Economy	7200.00
0005433985295	25668	Economy	7200.00
0005433985591	25668	Economy	7200.00
0005435788743	25668	Economy	7200.00
0005433985522	25668	Economy	7900.00
0005433985355	25668	Economy	7900.00
0005433985662	25668	Economy	7200.00
0005433985715	25668	Economy	7200.00
0005433985611	25668	Economy	7200.00
0005433985717	25668	Economy	7200.00
0005433985664	25668	Economy	7200.00
0005433985778	25668	Economy	7200.00
0005433985777	25668	Economy	7200.00
0005433985663	25668	Economy	7200.00
0005433985419	25668	Economy	7200.00
0005435788762	25668	Economy	7200.00
0005433985543	25668	Economy	7200.00
0005433985598	25668	Economy	7200.00
0005433985618	25668	Economy	7200.00
0005433985610	25668	Economy	7200.00
0005433985228	25668	Economy	7200.00
0005435788761	25668	Economy	7200.00
0005433985613	25668	Economy	7200.00
0005433985660	25668	Economy	7200.00
0005433985479	25668	Economy	7200.00
0005433985536	25668	Economy	7200.00
0005433985381	25668	Economy	7200.00
0005433985671	25668	Economy	7200.00
0005433985418	25668	Economy	7200.00
0005433985509	25668	Economy	7200.00
0005433985621	25668	Economy	7200.00
0005433985466	25668	Economy	7200.00
0005433985609	25668	Economy	7200.00
0005435788753	25668	Economy	7200.00
0005433985659	25668	Economy	7200.00
0005433985566	25668	Economy	7200.00
0005433985718	25668	Economy	7200.00
0005433985472	25668	Economy	7200.00
0005433985467	25668	Economy	7200.00
0005433985532	25668	Economy	7200.00
0005433985615	25668	Economy	7200.00
0005433985770	25668	Economy	7200.00
0005433461550	19920	Business	201300.00
0005433461557	19920	Business	201300.00
0005433463874	19920	Business	201300.00
0005433463869	19920	Business	201300.00
0005433461560	19920	Business	201300.00
0005433461553	19920	Economy	73800.00
0005433461556	19920	Economy	67100.00
0005433463877	19920	Economy	67100.00
0005433463866	19920	Economy	67100.00
0005433461580	19920	Economy	67100.00
0005433461554	19920	Economy	67100.00
0005433463865	19920	Economy	67100.00
0005433461559	19920	Economy	67100.00
0005433463875	19920	Economy	67100.00
0005433461561	19920	Economy	67100.00
0005433461552	19920	Economy	67100.00
0005433463870	19920	Economy	67100.00
0005433463873	19920	Economy	67100.00
0005433463868	19920	Economy	67100.00
0005433463864	19920	Economy	67100.00
0005433461562	19920	Economy	67100.00
0005433461551	19920	Economy	67100.00
0005433461558	19920	Economy	67100.00
0005433463878	19920	Economy	67100.00
0005433463876	19920	Economy	67100.00
0005433463871	19920	Economy	67100.00
0005435720818	21275	Economy	9400.00
0005435720819	21275	Economy	9400.00
0005435719557	21275	Economy	9400.00
0005435719556	21275	Economy	9400.00
0005434509151	1631	Economy	17000.00
0005433168337	1631	Economy	17000.00
0005434509157	1631	Economy	17000.00
0005434509156	1631	Economy	17000.00
0005433168334	1631	Economy	15500.00
0005434509147	1631	Economy	15500.00
0005434509152	1631	Economy	15500.00
0005434509139	1631	Economy	15500.00
0005434509150	1631	Economy	15500.00
0005434509140	1631	Economy	15500.00
0005434509154	1631	Economy	15500.00
0005434509161	1631	Economy	15500.00
0005434509149	1631	Economy	15500.00
0005433168325	1631	Economy	15500.00
0005434509144	1631	Economy	15500.00
0005434509143	1631	Economy	15500.00
0005434509141	1631	Economy	15500.00
0005434509158	1631	Economy	15500.00
0005433168327	1631	Economy	15500.00
0005434509155	1631	Economy	15500.00
0005434509146	1631	Economy	15500.00
0005433168348	1631	Economy	15500.00
0005434509160	1631	Economy	15500.00
0005433168314	1631	Economy	15500.00
0005434509159	1631	Economy	15500.00
0005434509142	1631	Economy	15500.00
0005433168341	1631	Economy	15500.00
0005433168326	1631	Economy	15500.00
0005434509162	1631	Economy	15500.00
0005434509153	1631	Economy	15500.00
0005433168336	1631	Economy	15500.00
0005434509148	1631	Economy	15500.00
0005433168329	1631	Economy	15500.00
0005433168335	1631	Economy	15500.00
0005433168338	1631	Economy	15500.00
0005434509145	1631	Economy	15500.00
0005432655415	17853	Business	18000.00
0005434151709	17853	Business	18000.00
0005432664123	17853	Business	18000.00
0005432658576	17853	Business	18000.00
0005432661903	17853	Business	18000.00
0005432655454	17853	Economy	6000.00
0005432869538	17853	Economy	6000.00
0005432664115	17853	Economy	6000.00
0005432655401	17853	Economy	6000.00
0005432667435	17853	Economy	6000.00
0005432660793	17853	Economy	6000.00
0005432659691	17853	Economy	6000.00
0005432667442	17853	Economy	6000.00
0005432659690	17853	Economy	6600.00
0005432869535	17853	Economy	6600.00
0005432659689	17853	Economy	6600.00
0005434151708	17853	Economy	6000.00
0005432659685	17853	Economy	6000.00
0005432661902	17853	Economy	6000.00
0005432657436	17853	Economy	6000.00
0005432658581	17853	Economy	6000.00
0005432655459	17853	Economy	6000.00
0005432666375	17853	Economy	6000.00
0005432869537	17853	Economy	6000.00
0005432663023	17853	Economy	6000.00
0005434151710	17853	Economy	6000.00
0005432658560	17853	Economy	6000.00
0005432655456	17853	Economy	6000.00
0005432664126	17853	Economy	6000.00
0005432869534	17853	Economy	6000.00
0005432655400	17853	Economy	6000.00
0005432657437	17853	Economy	6000.00
0005432869540	17853	Economy	6000.00
0005432655444	17853	Economy	6000.00
0005432869533	17853	Economy	6000.00
0005432661905	17853	Economy	6000.00
0005432657433	17853	Economy	6000.00
0005432664121	17853	Economy	6000.00
0005432658577	17853	Economy	6000.00
0005432869536	17853	Economy	6000.00
0005432667436	17853	Economy	6000.00
0005432869539	17853	Economy	6000.00
0005432666373	17853	Economy	6000.00
0005432657434	17853	Economy	6000.00
0005432655416	17853	Economy	6000.00
0005432661910	17853	Economy	6000.00
0005432665260	17853	Economy	6000.00
0005432664124	17853	Economy	6000.00
0005432658580	17853	Economy	6000.00
0005432665267	17853	Economy	6000.00
0005432664116	17853	Economy	6000.00
0005432661906	17853	Economy	6000.00
0005432663036	26300	Business	18000.00
0005432661913	26300	Business	18000.00
0005432869443	26300	Business	18000.00
0005432655532	26300	Business	18000.00
0005432663035	26300	Business	18000.00
0005432661915	26300	Business	18000.00
0005432666390	26300	Business	18000.00
0005432663040	26300	Business	18000.00
0005432663033	26300	Business	18000.00
0005432869442	26300	Business	18000.00
0005432663027	26300	Business	18000.00
0005432661925	26300	Economy	6000.00
0005432659706	26300	Economy	6000.00
0005432661917	26300	Economy	6000.00
0005432664136	26300	Economy	6000.00
0005432665273	26300	Economy	6000.00
0005432657447	26300	Economy	6000.00
0005432667454	26300	Economy	6000.00
0005432655531	26300	Economy	6000.00
0005432658591	26300	Economy	6000.00
0005432664137	26300	Economy	6600.00
0005432664138	26300	Economy	6600.00
0005432658590	26300	Economy	6600.00
0005432664135	26300	Economy	6600.00
0005432661920	26300	Economy	6000.00
0005432665275	26300	Economy	6000.00
0005432664141	26300	Economy	6000.00
0005432663029	26300	Economy	6000.00
0005432663030	26300	Economy	6000.00
0005432655521	26300	Economy	6000.00
0005432664133	26300	Economy	6000.00
0005432664130	26300	Economy	6000.00
0005432664134	26300	Economy	6000.00
0005432655522	26300	Economy	6000.00
0005432655529	26300	Economy	6000.00
0005432655530	26300	Economy	6000.00
0005432661916	26300	Economy	6000.00
0005432666389	26300	Economy	6000.00
0005432869439	26300	Economy	6000.00
0005432655528	26300	Economy	6000.00
0005432667453	26300	Economy	6000.00
0005432655527	26300	Economy	6000.00
0005432655524	26300	Economy	6000.00
0005432664132	26300	Economy	6000.00
0005432657448	26300	Economy	6000.00
0005432659705	26300	Economy	6000.00
0005432869468	26300	Economy	6000.00
0005432664128	26300	Economy	6000.00
0005432661926	26300	Economy	6000.00
0005432661914	26300	Economy	6000.00
0005432869446	26300	Economy	6000.00
0005432869458	26300	Economy	6000.00
0005432655533	26300	Economy	6000.00
0005432666388	26300	Economy	6000.00
0005432661924	26300	Economy	6000.00
0005432661923	26300	Economy	6000.00
0005432660818	26300	Economy	6000.00
0005432663032	26300	Economy	6000.00
0005432661922	26300	Economy	6000.00
0005432663031	26300	Economy	6000.00
0005432664140	26300	Economy	6000.00
0005432663038	26300	Economy	6000.00
0005432660817	26300	Economy	6000.00
0005432661919	26300	Economy	6000.00
0005432663034	26300	Economy	6000.00
0005432869438	26300	Economy	6000.00
0005432661918	26300	Economy	6000.00
0005432667455	26300	Economy	6000.00
0005432664131	26300	Economy	6000.00
0005432657449	26300	Economy	6000.00
0005432869457	26300	Economy	6000.00
0005432665274	26300	Economy	6000.00
0005432664139	26300	Economy	6000.00
0005432869440	26300	Economy	6000.00
0005432661927	26300	Economy	6000.00
0005432655526	26300	Economy	6000.00
0005432663039	26300	Economy	6000.00
0005432663037	26300	Economy	6000.00
0005432664129	26300	Economy	6000.00
0005432655525	26300	Economy	6000.00
0005432663028	26300	Economy	6000.00
0005432655523	26300	Economy	6000.00
0005432661921	26300	Economy	6000.00
0005432664142	26300	Economy	6000.00
0005432639073	25058	Business	87300.00
0005432639034	25058	Business	87300.00
0005432638937	25058	Business	87300.00
0005432866020	25058	Business	87300.00
0005432639022	25058	Business	87300.00
0005432639050	25058	Business	87300.00
0005432639040	25058	Business	87300.00
0005432866012	25058	Business	87300.00
0005432639038	25058	Economy	29100.00
0005432639004	25058	Economy	29100.00
0005432866027	25058	Economy	29100.00
0005432639027	25058	Economy	29100.00
0005432639012	25058	Economy	29100.00
0005432638988	25058	Economy	29100.00
0005432866010	25058	Economy	29100.00
0005432639049	25058	Economy	32000.00
0005432638994	25058	Economy	32000.00
0005432638965	25058	Economy	29100.00
0005432639037	25058	Economy	29100.00
0005432639052	25058	Economy	29100.00
0005432639023	25058	Economy	29100.00
0005432639051	25058	Economy	29100.00
0005432866029	25058	Economy	29100.00
0005432866014	25058	Economy	29100.00
0005432638995	25058	Economy	29100.00
0005432639091	25058	Economy	29100.00
0005432866028	25058	Economy	29100.00
0005432639013	25058	Economy	29100.00
0005432639014	25058	Economy	29100.00
0005432866025	25058	Economy	29100.00
0005432866009	25058	Economy	29100.00
0005432639024	25058	Economy	29100.00
0005432866015	25058	Economy	29100.00
0005432639084	25058	Economy	29100.00
0005432639030	25058	Economy	29100.00
0005432639011	25058	Economy	29100.00
0005432639036	25058	Economy	29100.00
0005432866021	25058	Economy	29100.00
0005432639090	25058	Economy	29100.00
0005432638993	25058	Economy	29100.00
0005432639028	25058	Economy	29100.00
0005432866017	25058	Economy	29100.00
0005432866018	25058	Economy	29100.00
0005432639074	25058	Economy	29100.00
0005432639009	25058	Economy	29100.00
0005432638964	25058	Economy	29100.00
0005432866026	25058	Economy	29100.00
0005432866019	25058	Economy	29100.00
0005432866016	25058	Economy	29100.00
0005432639003	25058	Economy	29100.00
0005432639041	25058	Economy	29100.00
0005432639039	25058	Economy	29100.00
0005432866023	25058	Economy	29100.00
0005432866022	25058	Economy	29100.00
0005432639061	25058	Economy	29100.00
0005432866013	25058	Economy	29100.00
0005432639044	25058	Economy	29100.00
0005432638989	25058	Economy	29100.00
0005432638991	25058	Economy	29100.00
0005432866024	25058	Economy	29100.00
0005432866011	25058	Economy	29100.00
0005433438888	3124	Business	16100.00
0005432287193	3124	Business	16100.00
0005432328767	3124	Business	16100.00
0005432328749	3124	Business	16100.00
0005433438891	3124	Business	16100.00
0005432328773	3124	Business	16100.00
0005433438892	3124	Business	16100.00
0005432328750	3124	Business	16100.00
0005432328766	3124	Business	16100.00
0005432328768	3124	Business	16100.00
0005432328764	3124	Economy	5400.00
0005432328746	3124	Economy	5400.00
0005432328772	3124	Economy	5400.00
0005432905076	3124	Economy	5400.00
0005432328777	3124	Economy	5400.00
0005432328774	3124	Economy	5400.00
0005433438885	3124	Economy	5400.00
0005432328780	3124	Economy	5900.00
0005432328741	3124	Economy	5900.00
0005432328755	3124	Economy	5900.00
0005432328775	3124	Economy	5400.00
0005432328751	3124	Economy	5400.00
0005432905104	3124	Economy	5400.00
0005433438886	3124	Economy	5400.00
0005433438884	3124	Economy	5400.00
0005432287194	3124	Economy	5400.00
0005432328761	3124	Economy	5400.00
0005432328770	3124	Economy	5400.00
0005432905063	3124	Economy	5400.00
0005432328752	3124	Economy	5400.00
0005432328781	3124	Economy	5400.00
0005432328753	3124	Economy	5400.00
0005432328758	3124	Economy	5400.00
0005432328779	3124	Economy	5400.00
0005432328757	3124	Economy	5400.00
0005433438889	3124	Economy	5400.00
0005432905075	3124	Economy	5400.00
0005432328762	3124	Economy	5400.00
0005433438887	3124	Economy	5400.00
0005432328744	3124	Economy	5400.00
0005432328754	3124	Economy	5400.00
0005432905106	3124	Economy	5400.00
0005432328776	3124	Economy	5400.00
0005432287195	3124	Economy	5400.00
0005432328745	3124	Economy	5400.00
0005432328769	3124	Economy	5400.00
0005432328771	3124	Economy	5400.00
0005432905105	3124	Economy	5400.00
0005433438890	3124	Economy	5400.00
0005432328760	3124	Economy	5400.00
0005432328742	3124	Economy	5400.00
0005432328740	3124	Economy	5400.00
0005432328756	3124	Economy	5400.00
0005432905086	3124	Economy	5400.00
0005432328778	3124	Economy	5400.00
0005432328738	3124	Economy	5400.00
0005432328765	3124	Economy	5400.00
0005432287197	3124	Economy	5400.00
0005432287196	3124	Economy	5400.00
0005432328737	3124	Economy	5400.00
0005432328739	3124	Economy	5400.00
0005432328783	3124	Economy	5400.00
0005432328759	3124	Economy	5400.00
0005432328748	3124	Economy	5400.00
0005432328782	3124	Economy	5400.00
0005432287198	3124	Economy	5400.00
0005432328747	3124	Economy	5400.00
0005432328763	3124	Economy	5400.00
0005432328743	3124	Economy	5400.00
0005432328393	31152	Business	16100.00
0005433438840	31152	Business	16100.00
0005432328399	31152	Business	16100.00
0005432328325	31152	Business	16100.00
0005432328273	31152	Business	16100.00
0005432328088	31152	Business	16100.00
0005432905132	31152	Business	16100.00
0005433438811	31152	Business	16100.00
0005432328355	31152	Business	16100.00
0005432328276	31152	Economy	5400.00
0005432054308	31152	Economy	5400.00
0005432328287	31152	Economy	5400.00
0005432328405	31152	Economy	5400.00
0005432328354	31152	Economy	5400.00
0005432328390	31152	Economy	5400.00
0005432328184	31152	Economy	5900.00
0005433438847	31152	Economy	5900.00
0005432328185	31152	Economy	5400.00
0005432328230	31152	Economy	5400.00
0005433438832	31152	Economy	5400.00
0005432328231	31152	Economy	5400.00
0005432328346	31152	Economy	5400.00
0005432328251	31152	Economy	5400.00
0005432328265	31152	Economy	5400.00
0005432054306	31152	Economy	5400.00
0005432054307	31152	Economy	5400.00
0005432328425	31152	Economy	5400.00
0005432328426	31152	Economy	5400.00
0005432328256	31152	Economy	5400.00
0005432328486	31152	Economy	5400.00
0005432905131	31152	Economy	5400.00
0005432328090	31152	Economy	5400.00
0005432328307	31152	Economy	5400.00
0005432328532	31152	Economy	5400.00
0005432328483	31152	Economy	5400.00
0005432905133	31152	Economy	5400.00
0005433438862	31152	Economy	5400.00
0005432905130	31152	Economy	5400.00
0005432328190	31152	Economy	5400.00
0005432328365	31152	Economy	5400.00
0005432328487	31152	Economy	5400.00
0005432328412	31152	Economy	5400.00
0005432328161	31152	Economy	5400.00
0005432328217	31152	Economy	5400.00
0005432328324	31152	Economy	5400.00
0005432328462	31152	Economy	5400.00
0005432905134	31152	Economy	5400.00
0005432328546	31152	Economy	5400.00
0005433438846	31152	Economy	5400.00
0005432328392	31152	Economy	5400.00
0005432328338	31152	Economy	5400.00
0005432328364	31152	Economy	5400.00
0005432328089	31152	Economy	5400.00
0005434309765	6190	Business	124600.00
0005435296999	6190	Business	124600.00
0005434309759	6190	Business	124600.00
0005435999268	6190	Business	124600.00
0005435487709	6190	Business	124600.00
0005435999278	6190	Economy	41500.00
0005434309763	6190	Economy	41500.00
0005435487628	6190	Economy	41500.00
0005434309752	6190	Economy	41500.00
0005434309760	6190	Economy	41500.00
0005435297046	6190	Economy	41500.00
0005435999266	6190	Economy	41500.00
0005435487684	6190	Economy	41500.00
0005435999274	6190	Economy	41500.00
0005435487602	6190	Economy	41500.00
0005435487629	6190	Economy	41500.00
0005435999269	6190	Economy	41500.00
0005435999273	6190	Economy	41500.00
0005435487641	6190	Economy	41500.00
0005435999276	6190	Economy	41500.00
0005435487667	6190	Economy	41500.00
0005434309754	6190	Economy	41500.00
0005435999277	6190	Economy	45700.00
0005435487601	6190	Economy	45700.00
0005435296998	6190	Economy	41500.00
0005435487677	6190	Economy	41500.00
0005435487627	6190	Economy	41500.00
0005434309764	6190	Economy	41500.00
0005435487691	6190	Economy	41500.00
0005435487708	6190	Economy	41500.00
0005434309761	6190	Economy	41500.00
0005435999270	6190	Economy	41500.00
0005435487651	6190	Economy	41500.00
0005435999271	6190	Economy	41500.00
0005434309755	6190	Economy	41500.00
0005435296946	6190	Economy	41500.00
0005434309753	6190	Economy	41500.00
0005435296994	6190	Economy	41500.00
0005435487603	6190	Economy	41500.00
0005434309758	6190	Economy	41500.00
0005432146201	6190	Economy	41500.00
0005435999272	6190	Economy	41500.00
0005434309762	6190	Economy	41500.00
0005432146202	6190	Economy	41500.00
0005434309756	6190	Economy	41500.00
0005435487663	6190	Economy	41500.00
0005435487561	6190	Economy	41500.00
0005435999275	6190	Economy	41500.00
0005435999279	6190	Economy	41500.00
0005434309757	6190	Economy	41500.00
0005435999267	6190	Economy	41500.00
0005435297067	19530	Business	124600.00
0005435487837	19530	Business	124600.00
0005435297070	19530	Business	124600.00
0005435487844	19530	Business	124600.00
0005435487839	19530	Economy	41500.00
0005435487833	19530	Economy	41500.00
0005435999074	19530	Economy	41500.00
0005435999110	19530	Economy	41500.00
0005435999079	19530	Economy	41500.00
0005434309628	19530	Economy	41500.00
0005435487832	19530	Economy	41500.00
0005435999073	19530	Economy	41500.00
0005435487834	19530	Economy	41500.00
0005435487830	19530	Economy	41500.00
0005435487841	19530	Economy	41500.00
0005435487843	19530	Economy	41500.00
0005435297065	19530	Economy	41500.00
0005435297066	19530	Economy	41500.00
0005435297064	19530	Economy	41500.00
0005435999124	19530	Economy	41500.00
0005435297068	19530	Economy	41500.00
0005435999082	19530	Economy	41500.00
0005434309632	19530	Economy	41500.00
0005434309555	19530	Economy	45700.00
0005434309601	19530	Economy	45700.00
0005435487838	19530	Economy	45700.00
0005435487831	19530	Economy	45700.00
0005434309623	19530	Economy	41500.00
0005435487846	19530	Economy	41500.00
0005435487847	19530	Economy	41500.00
0005434309606	19530	Economy	41500.00
0005435487836	19530	Economy	41500.00
0005434309609	19530	Economy	41500.00
0005435999086	19530	Economy	41500.00
0005435487851	19530	Economy	41500.00
0005434309605	19530	Economy	41500.00
0005435487835	19530	Economy	41500.00
0005435999081	19530	Economy	41500.00
0005435487845	19530	Economy	41500.00
0005434309554	19530	Economy	41500.00
0005434309722	19530	Economy	41500.00
0005435487842	19530	Economy	41500.00
0005435297071	19530	Economy	41500.00
0005435999128	19530	Economy	41500.00
0005434309608	19530	Economy	41500.00
0005434309604	19530	Economy	41500.00
0005435487848	19530	Economy	41500.00
0005435999103	19530	Economy	41500.00
0005435487840	19530	Economy	41500.00
0005435999102	19530	Economy	41500.00
0005435999113	19530	Economy	41500.00
0005435487849	19530	Economy	41500.00
0005434309633	19530	Economy	41500.00
0005434309627	19530	Economy	41500.00
0005435999118	19530	Economy	41500.00
0005434309660	19530	Economy	41500.00
0005435487850	19530	Economy	41500.00
0005435999075	19530	Economy	41500.00
0005435297069	19530	Economy	41500.00
0005434446496	17556	Economy	13600.00
0005433158132	17556	Economy	12300.00
0005434446499	17556	Economy	12300.00
0005434446502	17556	Economy	12300.00
0005433158134	17556	Economy	12300.00
0005433158135	17556	Economy	12300.00
0005433158133	17556	Economy	12300.00
0005433158131	17556	Economy	12300.00
0005434446497	17556	Economy	12300.00
0005434446500	17556	Economy	12300.00
0005433186055	1572	Business	86000.00
0005435517936	1572	Business	86000.00
0005435508382	1572	Business	86000.00
0005435508385	1572	Business	86000.00
0005435517937	1572	Business	86000.00
0005435517929	1572	Business	86000.00
0005432291934	1572	Business	86000.00
0005435508387	1572	Business	86000.00
0005434565932	1572	Economy	28700.00
0005435508383	1572	Economy	28700.00
0005435508384	1572	Economy	28700.00
0005434565935	1572	Economy	28700.00
0005435502331	1572	Economy	28700.00
0005435502339	1572	Economy	28700.00
0005435502346	1572	Economy	28700.00
0005435517943	1572	Economy	31500.00
0005435502336	1572	Economy	31500.00
0005435502340	1572	Economy	31500.00
0005435517942	1572	Economy	31500.00
0005435502343	1572	Economy	31500.00
0005432291932	1572	Economy	28700.00
0005435502333	1572	Economy	28700.00
0005435502347	1572	Economy	28700.00
0005435502332	1572	Economy	28700.00
0005435502344	1572	Economy	28700.00
0005435502350	1572	Economy	28700.00
0005434565928	1572	Economy	28700.00
0005435502345	1572	Economy	28700.00
0005435517928	1572	Economy	28700.00
0005433186025	1572	Economy	28700.00
0005435508391	1572	Economy	28700.00
0005435517940	1572	Economy	28700.00
0005432291933	1572	Economy	28700.00
0005433186026	1572	Economy	28700.00
0005433186062	1572	Economy	28700.00
0005434565936	1572	Economy	28700.00
0005435517931	1572	Economy	28700.00
0005434565930	1572	Economy	28700.00
0005434565938	1572	Economy	28700.00
0005435508389	1572	Economy	28700.00
0005435502351	1572	Economy	28700.00
0005435502337	1572	Economy	28700.00
0005435517934	1572	Economy	28700.00
0005435517938	1572	Economy	28700.00
0005434565925	1572	Economy	28700.00
0005435508390	1572	Economy	28700.00
0005435517935	1572	Economy	28700.00
0005433186065	1572	Economy	28700.00
0005435502335	1572	Economy	28700.00
0005435508380	1572	Economy	28700.00
0005435508386	1572	Economy	28700.00
0005433186040	1572	Economy	28700.00
0005435502334	1572	Economy	28700.00
0005435502341	1572	Economy	28700.00
0005435517932	1572	Economy	28700.00
0005433186039	1572	Economy	28700.00
0005435517933	1572	Economy	28700.00
0005435517939	1572	Economy	28700.00
0005434565937	1572	Economy	28700.00
0005434565927	1572	Economy	28700.00
0005435502338	1572	Economy	28700.00
0005434565926	1572	Economy	28700.00
0005433186079	1572	Economy	28700.00
0005434565933	1572	Economy	28700.00
0005434565934	1572	Economy	28700.00
0005433186061	1572	Economy	28700.00
0005435517930	1572	Economy	28700.00
0005435517945	1572	Economy	28700.00
0005435508379	1572	Economy	28700.00
0005435502342	1572	Economy	28700.00
0005435502349	1572	Economy	28700.00
0005435508381	1572	Economy	28700.00
0005435517944	1572	Economy	28700.00
0005435502348	1572	Economy	28700.00
0005435517941	1572	Economy	28700.00
0005434565929	1572	Economy	28700.00
0005434565931	1572	Economy	28700.00
0005433186048	1572	Economy	28700.00
0005435508388	1572	Economy	28700.00
0005435545688	20874	Business	86000.00
0005435529131	20874	Business	86000.00
0005435502232	20874	Business	86000.00
0005435529009	20874	Business	86000.00
0005435502092	20874	Business	86000.00
0005434565862	20874	Business	86000.00
0005435529070	20874	Business	86000.00
0005435545689	20874	Business	86000.00
0005434565899	20874	Business	86000.00
0005435529092	20874	Business	86000.00
0005433186125	20874	Economy	28700.00
0005435545690	20874	Economy	28700.00
0005435545666	20874	Economy	28700.00
0005435529100	20874	Economy	28700.00
0005435545670	20874	Economy	28700.00
0005435502163	20874	Economy	28700.00
0005435529103	20874	Economy	28700.00
0005435529042	20874	Economy	28700.00
0005435502162	20874	Economy	31500.00
0005435528970	20874	Economy	31500.00
0005434565849	20874	Economy	31500.00
0005434565798	20874	Economy	31500.00
0005435502231	20874	Economy	28700.00
0005434565861	20874	Economy	28700.00
0005435502124	20874	Economy	28700.00
0005435529029	20874	Economy	28700.00
0005433186132	20874	Economy	28700.00
0005434565789	20874	Economy	28700.00
0005435502144	20874	Economy	28700.00
0005433186131	20874	Economy	28700.00
0005435502068	20874	Economy	28700.00
0005435545686	20874	Economy	28700.00
0005433186126	20874	Economy	28700.00
0005433186130	20874	Economy	28700.00
0005435502205	20874	Economy	28700.00
0005435529132	20874	Economy	28700.00
0005435529135	20874	Economy	28700.00
0005434565827	20874	Economy	28700.00
0005434565802	20874	Economy	28700.00
0005435545654	20874	Economy	28700.00
0005435545653	20874	Economy	28700.00
0005435545687	20874	Economy	28700.00
0005433186128	20874	Economy	28700.00
0005434565803	20874	Economy	28700.00
0005435529036	20874	Economy	28700.00
0005435529105	20874	Economy	28700.00
0005435545645	20874	Economy	28700.00
0005435502191	20874	Economy	28700.00
0005435529144	20874	Economy	28700.00
0005435529104	20874	Economy	28700.00
0005435529035	20874	Economy	28700.00
0005434565788	20874	Economy	28700.00
0005435529060	20874	Economy	28700.00
0005433186127	20874	Economy	28700.00
0005435502148	20874	Economy	28700.00
0005433186129	20874	Economy	28700.00
0005435529052	20874	Economy	28700.00
0005435545665	20874	Economy	28700.00
0005435502115	20874	Economy	28700.00
0005435502112	20874	Economy	28700.00
0005435502069	20874	Economy	28700.00
0005435502106	20874	Economy	28700.00
0005435545663	20874	Economy	28700.00
0005435545664	20874	Economy	28700.00
0005435502190	20874	Economy	28700.00
0005435545652	20874	Economy	28700.00
0005435529031	20874	Economy	28700.00
0005435529034	20874	Economy	28700.00
0005434565825	20874	Economy	28700.00
0005433186134	20874	Economy	28700.00
0005435529055	20874	Economy	28700.00
0005435502134	20874	Economy	28700.00
0005435502113	20874	Economy	28700.00
0005435529046	20874	Economy	28700.00
0005435529047	20874	Economy	28700.00
0005435529071	20874	Economy	28700.00
0005433186133	20874	Economy	28700.00
0005435153752	3906	Economy	21600.00
0005435153748	3906	Economy	19700.00
0005435153751	3906	Economy	19700.00
0005435153750	3906	Economy	19700.00
0005435931567	3906	Economy	19700.00
0005435153749	3906	Economy	19700.00
0005435931579	3906	Economy	19700.00
0005435153753	3906	Economy	19700.00
0005435931566	3906	Economy	19700.00
0005435153721	21866	Economy	21600.00
0005435153706	21866	Economy	19700.00
0005435153695	21866	Economy	19700.00
0005435153694	21866	Economy	19700.00
0005435153722	21866	Economy	19700.00
0005435153710	21866	Economy	19700.00
0005435931607	21866	Economy	19700.00
0005435153704	21866	Economy	19700.00
0005435153703	21866	Economy	19700.00
0005435153711	21866	Economy	19700.00
0005435931605	21866	Economy	19700.00
0005435153696	21866	Economy	19700.00
0005435153719	21866	Economy	19700.00
0005435931604	21866	Economy	19700.00
0005435153720	21866	Economy	19700.00
0005435153705	21866	Economy	19700.00
0005435153702	21866	Economy	19700.00
0005435931606	21866	Economy	19700.00
0005435225555	7215	Economy	14300.00
0005432628858	7215	Economy	13000.00
0005432628862	7215	Economy	13000.00
0005432628870	7215	Economy	13000.00
0005432628866	7215	Economy	13000.00
0005432628863	7215	Economy	13000.00
0005435225530	7215	Economy	13000.00
0005435225531	7215	Economy	13000.00
0005432628869	7215	Economy	13000.00
0005432628867	7215	Economy	13000.00
0005432628871	7215	Economy	13000.00
0005432628861	7215	Economy	13000.00
0005432628865	7215	Economy	13000.00
0005432628864	7215	Economy	13000.00
0005432628859	7215	Economy	13000.00
0005432628860	7215	Economy	13000.00
0005432628872	7215	Economy	13000.00
0005432628868	7215	Economy	13000.00
0005432628778	28133	Economy	14300.00
0005435225595	28133	Economy	14300.00
0005432628709	28133	Economy	13000.00
0005432628809	28133	Economy	13000.00
0005435225592	28133	Economy	13000.00
0005432628751	28133	Economy	13000.00
0005435225597	28133	Economy	13000.00
0005435225594	28133	Economy	13000.00
0005432628710	28133	Economy	13000.00
0005432628760	28133	Economy	13000.00
0005432628762	28133	Economy	13000.00
0005432628696	28133	Economy	13000.00
0005432628737	28133	Economy	13000.00
0005435225591	28133	Economy	13000.00
0005432628808	28133	Economy	13000.00
0005432628684	28133	Economy	13000.00
0005432628759	28133	Economy	13000.00
0005432628683	28133	Economy	13000.00
0005435225596	28133	Economy	13000.00
0005432628774	28133	Economy	13000.00
0005435225598	28133	Economy	13000.00
0005435225593	28133	Economy	13000.00
0005432628724	28133	Economy	13000.00
0005434267896	8749	Economy	11500.00
0005435960053	8749	Economy	10500.00
0005434267898	8749	Economy	10500.00
0005435960054	8749	Economy	10500.00
0005435960055	8749	Economy	10500.00
0005434267897	8749	Economy	10500.00
0005434267922	8749	Economy	10500.00
0005435960057	8749	Economy	10500.00
0005434267908	8749	Economy	10500.00
0005435960056	8749	Economy	10500.00
0005434267923	8749	Economy	10500.00
0005434267918	8749	Economy	10500.00
0005434267955	15256	Economy	10500.00
0005434267956	15256	Economy	10500.00
0005434267953	15256	Economy	10500.00
0005434267954	15256	Economy	10500.00
0005432873244	1203	Business	115000.00
0005432693065	1203	Business	115000.00
0005432677574	1203	Business	115000.00
0005432693070	1203	Business	115000.00
0005432675148	1203	Business	115000.00
0005432873243	1203	Business	115000.00
0005432675143	1203	Business	115000.00
0005432693082	1203	Business	115000.00
0005432693079	1203	Business	115000.00
0005432693067	1203	Economy	38300.00
0005432693088	1203	Economy	38300.00
0005432693086	1203	Economy	38300.00
0005432873256	1203	Economy	38300.00
0005432693083	1203	Economy	38300.00
0005432693074	1203	Economy	38300.00
0005432677573	1203	Economy	38300.00
0005432693076	1203	Economy	42200.00
0005432675155	1203	Economy	38300.00
0005432693078	1203	Economy	38300.00
0005432873254	1203	Economy	38300.00
0005432675146	1203	Economy	38300.00
0005432675149	1203	Economy	38300.00
0005432693093	1203	Economy	38300.00
0005432675151	1203	Economy	38300.00
0005432693080	1203	Economy	38300.00
0005432675147	1203	Economy	38300.00
0005432693091	1203	Economy	38300.00
0005432677575	1203	Economy	38300.00
0005432693072	1203	Economy	38300.00
0005432675157	1203	Economy	38300.00
0005432693075	1203	Economy	38300.00
0005432675156	1203	Economy	38300.00
0005432693068	1203	Economy	38300.00
0005432693073	1203	Economy	38300.00
0005432693090	1203	Economy	38300.00
0005432675145	1203	Economy	38300.00
0005432693066	1203	Economy	38300.00
0005432675150	1203	Economy	38300.00
0005432693071	1203	Economy	38300.00
0005432677576	1203	Economy	38300.00
0005432675144	1203	Economy	38300.00
0005432873236	1203	Economy	38300.00
0005432693081	1203	Economy	38300.00
0005432873257	1203	Economy	38300.00
0005432693089	1203	Economy	38300.00
0005432693092	1203	Economy	38300.00
0005432675152	1203	Economy	38300.00
0005432693087	1203	Economy	38300.00
0005432693064	1203	Economy	38300.00
0005432693085	1203	Economy	38300.00
0005432677572	1203	Economy	38300.00
0005432675154	1203	Economy	38300.00
0005432693084	1203	Economy	38300.00
0005432693094	1203	Economy	38300.00
0005432693095	1203	Economy	38300.00
0005432693077	1203	Economy	38300.00
0005432675153	1203	Economy	38300.00
0005432693069	1203	Economy	38300.00
0005432675028	17477	Business	115000.00
0005432677531	17477	Business	115000.00
0005432675011	17477	Business	115000.00
0005432674987	17477	Business	115000.00
0005432675047	17477	Business	115000.00
0005432873303	17477	Business	115000.00
0005432692723	17477	Business	115000.00
0005432675092	17477	Business	115000.00
0005432692796	17477	Business	115000.00
0005432677548	17477	Business	115000.00
0005432674970	17477	Business	115000.00
0005432674948	17477	Business	115000.00
0005432675006	17477	Economy	38300.00
0005432873302	17477	Economy	38300.00
0005432692813	17477	Economy	38300.00
0005432675053	17477	Economy	38300.00
0005432692916	17477	Economy	38300.00
0005432675085	17477	Economy	38300.00
0005432692732	17477	Economy	42200.00
0005432674957	17477	Economy	42200.00
0005432692913	17477	Economy	38300.00
0005432675054	17477	Economy	38300.00
0005432675026	17477	Economy	38300.00
0005432873298	17477	Economy	38300.00
0005432675010	17477	Economy	38300.00
0005432675086	17477	Economy	38300.00
0005432675034	17477	Economy	38300.00
0005432674983	17477	Economy	38300.00
0005432692693	17477	Economy	38300.00
0005432692945	17477	Economy	38300.00
0005432692857	17477	Economy	38300.00
0005432675027	17477	Economy	38300.00
0005432873301	17477	Economy	38300.00
0005432692873	17477	Economy	38300.00
0005432675048	17477	Economy	38300.00
0005432675049	17477	Economy	38300.00
0005432692747	17477	Economy	38300.00
0005432692917	17477	Economy	38300.00
0005432692921	17477	Economy	38300.00
0005432675073	17477	Economy	38300.00
0005432692722	17477	Economy	38300.00
0005432692733	17477	Economy	38300.00
0005432675024	17477	Economy	38300.00
0005432674956	17477	Economy	38300.00
0005432873300	17477	Economy	38300.00
0005432677532	17477	Economy	38300.00
0005432674961	17477	Economy	38300.00
0005432675015	17477	Economy	38300.00
0005432692823	17477	Economy	38300.00
0005432692746	17477	Economy	38300.00
0005432674992	17477	Economy	38300.00
0005432873299	17477	Economy	38300.00
0005432692996	17477	Economy	38300.00
0005432675007	17477	Economy	38300.00
0005432674960	17477	Economy	38300.00
0005432692779	17477	Economy	38300.00
0005432692933	17477	Economy	38300.00
0005432692885	17477	Economy	38300.00
0005432692944	17477	Economy	38300.00
0005432873297	17477	Economy	38300.00
0005432677554	17477	Economy	38300.00
0005432692721	17477	Economy	38300.00
0005432675025	17477	Economy	38300.00
0005432692814	17477	Economy	38300.00
0005433156714	1116	Economy	15200.00
0005433156695	1116	Economy	13900.00
0005434435197	1116	Economy	13900.00
0005434435199	1116	Economy	13900.00
0005434435202	1116	Economy	13900.00
0005434435194	1116	Economy	13900.00
0005434435193	1116	Economy	13900.00
0005433156694	1116	Economy	13900.00
0005434435195	1116	Economy	13900.00
0005434435207	1116	Economy	13900.00
0005434435205	1116	Economy	13900.00
0005434435200	1116	Economy	13900.00
0005434435208	1116	Economy	13900.00
0005434435203	1116	Economy	13900.00
0005434435206	1116	Economy	13900.00
0005434435196	1116	Economy	13900.00
0005434435198	1116	Economy	13900.00
0005434435204	1116	Economy	13900.00
0005434435201	1116	Economy	13900.00
0005433156710	1116	Economy	13900.00
0005433156685	1116	Economy	13900.00
0005433156756	17289	Economy	15200.00
0005434435148	17289	Economy	15200.00
0005434435107	17289	Economy	13900.00
0005434435108	17289	Economy	13900.00
0005433156757	17289	Economy	13900.00
0005434435106	17289	Economy	13900.00
0005433156763	17289	Economy	13900.00
0005434435123	17289	Economy	13900.00
0005433156760	17289	Economy	13900.00
0005433156764	17289	Economy	13900.00
0005434435083	17289	Economy	13900.00
0005433156761	17289	Economy	13900.00
0005434435129	17289	Economy	13900.00
0005434435067	17289	Economy	13900.00
0005434435047	17289	Economy	13900.00
0005434435065	17289	Economy	13900.00
0005434435048	17289	Economy	13900.00
0005433156759	17289	Economy	13900.00
0005434435082	17289	Economy	13900.00
0005433156762	17289	Economy	13900.00
0005434435135	17289	Economy	13900.00
0005433156765	17289	Economy	13900.00
0005434435091	17289	Economy	13900.00
0005434435122	17289	Economy	13900.00
0005433156758	17289	Economy	13900.00
0005434435075	17289	Economy	13900.00
0005435086840	4065	Economy	8200.00
0005435928125	4065	Economy	7500.00
0005435928107	4065	Economy	7500.00
0005435928113	4065	Economy	7500.00
0005435086843	4065	Economy	7500.00
0005435086842	4065	Economy	7500.00
0005435086841	4065	Economy	7500.00
0005435086844	4065	Economy	7500.00
0005435086847	4065	Economy	7500.00
0005435086846	4065	Economy	7500.00
0005435086845	4065	Economy	7500.00
0005435086785	24415	Economy	7500.00
0005435086789	24415	Economy	7500.00
0005435086786	24415	Economy	7500.00
0005435928149	24415	Economy	7500.00
0005435928147	24415	Economy	7500.00
0005435928150	24415	Economy	7500.00
0005435086776	24415	Economy	7500.00
0005435928148	24415	Economy	7500.00
0005435086788	24415	Economy	7500.00
0005435086799	24415	Economy	7500.00
0005435928151	24415	Economy	7500.00
0005435086777	24415	Economy	7500.00
0005435086800	24415	Economy	7500.00
0005435086783	24415	Economy	7500.00
0005435706382	2453	Business	86800.00
0005435706389	2453	Business	86800.00
0005433373443	2453	Business	86800.00
0005435706387	2453	Business	86800.00
0005435706401	2453	Business	86800.00
0005433373455	2453	Business	86800.00
0005435706392	2453	Business	86800.00
0005433373493	2453	Economy	28900.00
0005435706381	2453	Economy	28900.00
0005435706403	2453	Economy	28900.00
0005433373457	2453	Economy	28900.00
0005433373439	2453	Economy	31800.00
0005435706395	2453	Economy	31800.00
0005435706407	2453	Economy	28900.00
0005433373452	2453	Economy	28900.00
0005435706413	2453	Economy	28900.00
0005435706411	2453	Economy	28900.00
0005433373471	2453	Economy	28900.00
0005435706393	2453	Economy	28900.00
0005435706404	2453	Economy	28900.00
0005433373447	2453	Economy	28900.00
0005433373451	2453	Economy	28900.00
0005433373473	2453	Economy	28900.00
0005435706386	2453	Economy	28900.00
0005435706383	2453	Economy	28900.00
0005435706396	2453	Economy	28900.00
0005433373481	2453	Economy	28900.00
0005435706414	2453	Economy	28900.00
0005435706388	2453	Economy	28900.00
0005435706394	2453	Economy	28900.00
0005433373482	2453	Economy	28900.00
0005435706397	2453	Economy	28900.00
0005435706391	2453	Economy	28900.00
0005435706408	2453	Economy	28900.00
0005435706385	2453	Economy	28900.00
0005435706398	2453	Economy	28900.00
0005435706399	2453	Economy	28900.00
0005435706400	2453	Economy	28900.00
0005433373441	2453	Economy	28900.00
0005435706412	2453	Economy	28900.00
0005435706402	2453	Economy	28900.00
0005435706409	2453	Economy	28900.00
0005433373491	2453	Economy	28900.00
0005435706410	2453	Economy	28900.00
0005433373492	2453	Economy	28900.00
0005435706405	2453	Economy	28900.00
0005435706384	2453	Economy	28900.00
0005433373465	2453	Economy	28900.00
0005433373485	2453	Economy	28900.00
0005435706390	2453	Economy	28900.00
0005435706406	2453	Economy	28900.00
0005433373483	2453	Economy	28900.00
0005433373536	27024	Business	86800.00
0005435706182	27024	Business	86800.00
0005433373546	27024	Business	86800.00
0005435706200	27024	Economy	28900.00
0005435706276	27024	Economy	28900.00
0005433373535	27024	Economy	28900.00
0005435706241	27024	Economy	28900.00
0005435706221	27024	Economy	28900.00
0005435706231	27024	Economy	31800.00
0005435706282	27024	Economy	31800.00
0005435706260	27024	Economy	31800.00
0005435706209	27024	Economy	31800.00
0005435706233	27024	Economy	31800.00
0005435706275	27024	Economy	28900.00
0005433373543	27024	Economy	28900.00
0005435706186	27024	Economy	28900.00
0005433373541	27024	Economy	28900.00
0005433373539	27024	Economy	28900.00
0005433373540	27024	Economy	28900.00
0005433373534	27024	Economy	28900.00
0005435706229	27024	Economy	28900.00
0005435706324	27024	Economy	28900.00
0005433373532	27024	Economy	28900.00
0005433373550	27024	Economy	28900.00
0005433373547	27024	Economy	28900.00
0005435706251	27024	Economy	28900.00
0005435706237	27024	Economy	28900.00
0005433373545	27024	Economy	28900.00
0005435706211	27024	Economy	28900.00
0005433373548	27024	Economy	28900.00
0005435706280	27024	Economy	28900.00
0005435706219	27024	Economy	28900.00
0005433373549	27024	Economy	28900.00
0005433373542	27024	Economy	28900.00
0005435706281	27024	Economy	28900.00
0005435706234	27024	Economy	28900.00
0005435706244	27024	Economy	28900.00
0005435706259	27024	Economy	28900.00
0005435706300	27024	Economy	28900.00
0005435706301	27024	Economy	28900.00
0005435706263	27024	Economy	28900.00
0005435706245	27024	Economy	28900.00
0005433373538	27024	Economy	28900.00
0005435706208	27024	Economy	28900.00
0005433373533	27024	Economy	28900.00
0005435706271	27024	Economy	28900.00
0005435706181	27024	Economy	28900.00
0005435706258	27024	Economy	28900.00
0005435706257	27024	Economy	28900.00
0005433373544	27024	Economy	28900.00
0005435706232	27024	Economy	28900.00
0005435706216	27024	Economy	28900.00
0005435706246	27024	Economy	28900.00
0005435706220	27024	Economy	28900.00
0005433373537	27024	Economy	28900.00
0005435706230	27024	Economy	28900.00
0005434964232	1310	Business	203300.00
0005434964222	1310	Business	203300.00
0005434964263	1310	Business	203300.00
0005433261446	1310	Business	203300.00
0005434964218	1310	Business	203300.00
0005434964251	1310	Business	203300.00
0005434964225	1310	Business	203300.00
0005434964257	1310	Business	203300.00
0005434964260	1310	Business	203300.00
0005434964214	1310	Economy	74500.00
0005433261470	1310	Economy	74500.00
0005434964245	1310	Economy	74500.00
0005434964241	1310	Economy	67800.00
0005434964247	1310	Economy	67800.00
0005434964212	1310	Economy	67800.00
0005434964244	1310	Economy	67800.00
0005434964248	1310	Economy	67800.00
0005433261466	1310	Economy	67800.00
0005433261434	1310	Economy	67800.00
0005434964258	1310	Economy	67800.00
0005432279274	1310	Economy	67800.00
0005434964239	1310	Economy	67800.00
0005432279272	1310	Economy	67800.00
0005432279271	1310	Economy	67800.00
0005434964233	1310	Economy	67800.00
0005433261463	1310	Economy	67800.00
0005433261474	1310	Economy	67800.00
0005434964265	1310	Economy	67800.00
0005434964240	1310	Economy	67800.00
0005434964252	1310	Economy	67800.00
0005433261494	1310	Economy	67800.00
0005434964209	1310	Economy	67800.00
0005433261485	1310	Economy	67800.00
0005433261439	1310	Economy	67800.00
0005434964261	1310	Economy	67800.00
0005434964229	1310	Economy	67800.00
0005434964211	1310	Economy	67800.00
0005434964215	1310	Economy	67800.00
0005434964253	1310	Economy	67800.00
0005434964228	1310	Economy	67800.00
0005434964220	1310	Economy	67800.00
0005434964255	1310	Economy	67800.00
0005433261471	1310	Economy	67800.00
0005433261432	1310	Economy	67800.00
0005434964259	1310	Economy	67800.00
0005434964216	1310	Economy	67800.00
0005434964235	1310	Economy	67800.00
0005434964254	1310	Economy	67800.00
0005433261483	1310	Economy	67800.00
0005433261498	1310	Economy	67800.00
0005433261492	1310	Economy	67800.00
0005434964236	1310	Economy	67800.00
0005434964256	1310	Economy	67800.00
0005434964243	1310	Economy	74500.00
0005433261493	1310	Economy	67800.00
0005434964210	1310	Economy	67800.00
0005434964219	1310	Economy	67800.00
0005434964250	1310	Economy	67800.00
0005434964246	1310	Economy	67800.00
0005434964242	1310	Economy	67800.00
0005434964237	1310	Economy	67800.00
0005434964226	1310	Economy	67800.00
0005434964223	1310	Economy	67800.00
0005434964208	1310	Economy	67800.00
0005433261473	1310	Economy	67800.00
0005433261430	1310	Economy	67800.00
0005433261462	1310	Economy	67800.00
0005433261410	1310	Economy	67800.00
0005434964227	1310	Economy	67800.00
0005432279273	1310	Economy	67800.00
0005434964238	1310	Economy	67800.00
0005434964234	1310	Economy	67800.00
0005434964224	1310	Economy	67800.00
0005433261472	1310	Economy	67800.00
0005433261440	1310	Economy	67800.00
0005433261458	1310	Economy	67800.00
0005433261484	1310	Economy	67800.00
0005434964249	1310	Economy	67800.00
0005434964264	1310	Economy	67800.00
0005433261488	1310	Economy	67800.00
0005434964217	1310	Economy	67800.00
0005434964231	1310	Economy	67800.00
0005434964213	1310	Economy	67800.00
0005432279275	1310	Economy	67800.00
0005432279270	1310	Economy	67800.00
0005434964230	1310	Economy	67800.00
0005432279269	1310	Economy	67800.00
0005433261514	1310	Economy	67800.00
0005433261481	1310	Economy	67800.00
0005434964262	1310	Economy	67800.00
0005433261433	1310	Economy	67800.00
0005434964221	1310	Economy	67800.00
0005435907489	4815	Business	44200.00
0005434625970	4815	Economy	14700.00
0005433194849	4815	Economy	16200.00
0005434625968	4815	Economy	14700.00
0005434625973	4815	Economy	14700.00
0005433194831	4815	Economy	14700.00
0005434625976	4815	Economy	14700.00
0005433194850	4815	Economy	14700.00
0005435907488	4815	Economy	14700.00
0005434625972	4815	Economy	14700.00
0005435907475	4815	Economy	14700.00
0005435907470	4815	Economy	14700.00
0005434625974	4815	Economy	14700.00
0005434625969	4815	Economy	14700.00
0005434625975	4815	Economy	14700.00
0005435907490	4815	Economy	14700.00
0005435907453	4815	Economy	14700.00
0005433194848	4815	Economy	14700.00
0005435907476	4815	Economy	14700.00
0005434625971	4815	Economy	14700.00
0005435907516	32931	Economy	14700.00
0005434625917	32931	Economy	16200.00
0005434625899	32931	Economy	14700.00
0005435907515	32931	Economy	14700.00
0005434625905	32931	Economy	14700.00
0005434625944	32931	Economy	14700.00
0005434625926	32931	Economy	14700.00
0005435907513	32931	Economy	14700.00
0005435907512	32931	Economy	14700.00
0005434625916	32931	Economy	14700.00
0005434625927	32931	Economy	14700.00
0005435907514	32931	Economy	14700.00
0005435785049	13804	Economy	3400.00
0005435785129	13804	Economy	3400.00
0005435785092	13804	Economy	3400.00
0005435785171	13804	Economy	3400.00
0005435787328	13804	Economy	3100.00
0005435784951	13804	Economy	3100.00
0005435785127	13804	Economy	3100.00
0005435785057	13804	Economy	3100.00
0005435785050	13804	Economy	3100.00
0005435785135	13804	Economy	3100.00
0005435785172	13804	Economy	3100.00
0005435785034	13804	Economy	3100.00
0005435785112	13804	Economy	3100.00
0005435785128	13804	Economy	3100.00
0005435785091	13804	Economy	3100.00
0005432195696	13804	Economy	3100.00
0005435785101	13804	Economy	3100.00
0005435785055	13804	Economy	3100.00
0005435785035	13804	Economy	3100.00
0005435785047	13804	Economy	3100.00
0005435785056	13804	Economy	3100.00
0005435784943	13804	Economy	3100.00
0005435784970	13804	Economy	3100.00
0005435785089	13804	Economy	3100.00
0005435784944	13804	Economy	3100.00
0005435784952	13804	Economy	3100.00
0005435785114	13804	Economy	3100.00
0005435785170	13804	Economy	3100.00
0005435784984	13804	Economy	3100.00
0005435785062	13804	Economy	3100.00
0005435785169	13804	Economy	3100.00
0005435785052	13804	Economy	3100.00
0005435784997	13804	Economy	3100.00
0005435785051	13804	Economy	3100.00
0005435785046	13804	Economy	3100.00
0005435937390	13804	Economy	3100.00
0005435787346	13804	Economy	3100.00
0005435784945	13804	Economy	3100.00
0005435784986	13804	Economy	3100.00
0005435785173	13804	Economy	3100.00
0005435785045	13804	Economy	3100.00
0005435785343	27431	Economy	3400.00
0005435937343	27431	Economy	3400.00
0005435785336	27431	Economy	3400.00
0005435785360	27431	Economy	3100.00
0005435785351	27431	Economy	3100.00
0005435937331	27431	Economy	3100.00
0005435937365	27431	Economy	3100.00
0005435937330	27431	Economy	3100.00
0005435937366	27431	Economy	3100.00
0005432190630	27431	Economy	3100.00
0005435785341	27431	Economy	3100.00
0005435785340	27431	Economy	3100.00
0005435785357	27431	Economy	3100.00
0005435785355	27431	Economy	3100.00
0005432190628	27431	Economy	3100.00
0005435785337	27431	Economy	3100.00
0005435785333	27431	Economy	3100.00
0005435785342	27431	Economy	3100.00
0005435785350	27431	Economy	3100.00
0005435785363	27431	Economy	3100.00
0005435785356	27431	Economy	3100.00
0005435785359	27431	Economy	3100.00
0005435785344	27431	Economy	3100.00
0005435785349	27431	Economy	3100.00
0005435785352	27431	Economy	3100.00
0005435787354	27431	Economy	3100.00
0005435785347	27431	Economy	3100.00
0005435785335	27431	Economy	3100.00
0005435785346	27431	Economy	3100.00
0005435785353	27431	Economy	3100.00
0005435785334	27431	Economy	3100.00
0005435785345	27431	Economy	3100.00
0005435785362	27431	Economy	3100.00
0005435785332	27431	Economy	3100.00
0005432190629	27431	Economy	3100.00
0005435937342	27431	Economy	3100.00
0005435785338	27431	Economy	3100.00
0005435785361	27431	Economy	3100.00
0005435785331	27431	Economy	3100.00
0005435785348	27431	Economy	3100.00
0005435785354	27431	Economy	3100.00
0005435785339	27431	Economy	3100.00
0005435785364	27431	Economy	3100.00
0005435785358	27431	Economy	3100.00
0005434407254	20255	Business	12000.00
0005434407209	20255	Business	12000.00
0005434407258	20255	Business	12000.00
0005434407214	20255	Business	12000.00
0005434407206	20255	Business	12000.00
0005434407034	20255	Business	12000.00
0005434407129	20255	Business	12000.00
0005434407643	20255	Business	12000.00
0005434406922	20255	Business	12000.00
0005435311081	20255	Business	12000.00
0005434407331	20255	Business	12000.00
0005435311080	20255	Economy	4000.00
0005434407289	20255	Economy	4000.00
0005434407330	20255	Economy	4000.00
0005435311079	20255	Economy	4000.00
0005434407035	20255	Economy	4000.00
0005434407530	20255	Economy	4000.00
0005434407310	20255	Economy	4000.00
0005434407140	20255	Economy	4400.00
0005435311085	20255	Economy	4400.00
0005435311087	20255	Economy	4400.00
0005435311084	20255	Economy	4400.00
0005434407218	20255	Economy	4400.00
0005434407641	20255	Economy	4000.00
0005434407032	20255	Economy	4000.00
0005434407139	20255	Economy	4000.00
0005434407215	20255	Economy	4000.00
0005434407286	20255	Economy	4000.00
0005434407354	20255	Economy	4000.00
0005434407374	20255	Economy	4000.00
0005434407009	20255	Economy	4000.00
0005434407164	20255	Economy	4000.00
0005434407436	20255	Economy	4000.00
0005434407219	20255	Economy	4000.00
0005434407375	20255	Economy	4000.00
0005434407104	20255	Economy	4000.00
0005434407297	20255	Economy	4000.00
0005434407120	20255	Economy	4000.00
0005434407333	20255	Economy	4000.00
0005434407359	20255	Economy	4000.00
0005434407031	20255	Economy	4000.00
0005434407092	20255	Economy	4000.00
0005434407084	20255	Economy	4000.00
0005434407083	20255	Economy	4000.00
0005432058388	20255	Economy	4000.00
0005434407088	20255	Economy	4000.00
0005434407309	20255	Economy	4000.00
0005434407082	20255	Economy	4000.00
0005434407307	20255	Economy	4000.00
0005434407158	20255	Economy	4000.00
0005434407308	20255	Economy	4000.00
0005434407091	20255	Economy	4000.00
0005435311086	20255	Economy	4000.00
0005434406921	20255	Economy	4000.00
0005434407470	20255	Economy	4000.00
0005434407316	20255	Economy	4000.00
0005434407332	20255	Economy	4000.00
0005434407010	20255	Economy	4000.00
0005434407123	20255	Economy	4000.00
0005434407119	20255	Economy	4000.00
0005435311078	20255	Economy	4000.00
0005434407163	20255	Economy	4000.00
0005435311083	20255	Economy	4000.00
0005434407257	20255	Economy	4000.00
0005434407420	20255	Economy	4000.00
0005434407528	20255	Economy	4000.00
0005434407030	20255	Economy	4000.00
0005434407642	20255	Economy	4000.00
0005435311082	20255	Economy	4000.00
0005434407290	20255	Economy	4000.00
0005432058387	20255	Economy	4000.00
0005434407157	20255	Economy	4000.00
0005434407220	20255	Economy	4000.00
0005434407529	20255	Economy	4000.00
0005434407197	20255	Economy	4000.00
0005432058386	20255	Economy	4000.00
0005434407395	20255	Economy	4000.00
0005434407496	20255	Economy	4000.00
0005434407483	20255	Economy	4000.00
0005434407380	20255	Economy	4000.00
0005434407803	26980	Business	12000.00
0005435310912	26980	Business	12000.00
0005434407853	26980	Business	12000.00
0005434407839	26980	Business	12000.00
0005434407855	26980	Business	12000.00
0005434407851	26980	Business	12000.00
0005434407852	26980	Business	12000.00
0005434407835	26980	Business	12000.00
0005434407802	26980	Business	12000.00
0005434407861	26980	Business	12000.00
0005434407826	26980	Business	12000.00
0005434407800	26980	Business	12000.00
0005435310954	26980	Economy	4000.00
0005432153948	26980	Economy	4000.00
0005434407836	26980	Economy	4000.00
0005432153944	26980	Economy	4000.00
0005435310953	26980	Economy	4000.00
0005434407828	26980	Economy	4000.00
0005434407844	26980	Economy	4000.00
0005434407833	26980	Economy	4000.00
0005434407864	26980	Economy	4000.00
0005434407804	26980	Economy	4400.00
0005435310955	26980	Economy	4400.00
0005434407820	26980	Economy	4400.00
0005434407829	26980	Economy	4400.00
0005434407825	26980	Economy	4400.00
0005434407813	26980	Economy	4000.00
0005435310971	26980	Economy	4000.00
0005434407801	26980	Economy	4000.00
0005434407863	26980	Economy	4000.00
0005434407857	26980	Economy	4000.00
0005434407858	26980	Economy	4000.00
0005434407854	26980	Economy	4000.00
0005432153946	26980	Economy	4000.00
0005434407816	26980	Economy	4000.00
0005434407821	26980	Economy	4000.00
0005432153945	26980	Economy	4000.00
0005435310913	26980	Economy	4000.00
0005434407838	26980	Economy	4000.00
0005434407845	26980	Economy	4000.00
0005434407806	26980	Economy	4000.00
0005434407865	26980	Economy	4000.00
0005434407846	26980	Economy	4000.00
0005434407823	26980	Economy	4000.00
0005434407807	26980	Economy	4000.00
0005434407810	26980	Economy	4000.00
0005434407832	26980	Economy	4000.00
0005434407862	26980	Economy	4000.00
0005435310948	26980	Economy	4000.00
0005434407840	26980	Economy	4000.00
0005435310962	26980	Economy	4000.00
0005435310911	26980	Economy	4000.00
0005434407830	26980	Economy	4000.00
0005435310942	26980	Economy	4000.00
0005434407815	26980	Economy	4000.00
0005434407837	26980	Economy	4000.00
0005434407818	26980	Economy	4000.00
0005434407822	26980	Economy	4000.00
0005434407827	26980	Economy	4000.00
0005434407812	26980	Economy	4000.00
0005434407834	26980	Economy	4000.00
0005435310961	26980	Economy	4000.00
0005434407824	26980	Economy	4000.00
0005434407805	26980	Economy	4000.00
0005434407850	26980	Economy	4000.00
0005434407817	26980	Economy	4000.00
0005432153947	26980	Economy	4000.00
0005434407809	26980	Economy	4000.00
0005434407849	26980	Economy	4000.00
0005434407819	26980	Economy	4000.00
0005434407841	26980	Economy	4000.00
0005434407808	26980	Economy	4000.00
0005434407831	26980	Economy	4000.00
0005435310943	26980	Economy	4000.00
0005434407814	26980	Economy	4000.00
0005434407847	26980	Economy	4000.00
0005434407848	26980	Economy	4000.00
0005434407811	26980	Economy	4000.00
0005434407842	26980	Economy	4000.00
0005434407856	26980	Economy	4000.00
0005434407843	26980	Economy	4000.00
0005432153943	26980	Economy	4000.00
0005435310952	26980	Economy	4000.00
0005434407859	26980	Economy	4000.00
0005435310924	26980	Economy	4000.00
0005434407860	26980	Economy	4000.00
0005432109705	5708	Business	43300.00
0005434319406	5708	Business	43300.00
0005433123821	5708	Business	43300.00
0005433123735	5708	Business	43300.00
0005433123728	5708	Business	43300.00
0005433123818	5708	Business	43300.00
0005432109706	5708	Economy	14400.00
0005434319411	5708	Economy	14400.00
0005433123769	5708	Economy	14400.00
0005433123755	5708	Economy	14400.00
0005433123764	5708	Economy	15900.00
0005433123754	5708	Economy	14400.00
0005433123820	5708	Economy	14400.00
0005434319409	5708	Economy	14400.00
0005433123744	5708	Economy	14400.00
0005434311222	5708	Economy	14400.00
0005433123729	5708	Economy	14400.00
0005434319408	5708	Economy	14400.00
0005433123819	5708	Economy	14400.00
0005433123686	5708	Economy	14400.00
0005433123766	5708	Economy	14400.00
0005433123772	5708	Economy	14400.00
0005434319405	5708	Economy	14400.00
0005433123794	5708	Economy	14400.00
0005433123701	5708	Economy	14400.00
0005433123736	5708	Economy	14400.00
0005433123779	5708	Economy	14400.00
0005433123770	5708	Economy	14400.00
0005434311221	5708	Economy	14400.00
0005433123743	5708	Economy	14400.00
0005433123809	5708	Economy	14400.00
0005433123713	5708	Economy	14400.00
0005433123831	5708	Economy	14400.00
0005433123705	5708	Economy	14400.00
0005434319407	5708	Economy	14400.00
0005433123768	5708	Economy	14400.00
0005434319413	5708	Economy	14400.00
0005434319412	5708	Economy	14400.00
0005432109707	5708	Economy	14400.00
0005433123763	5708	Economy	14400.00
0005434319410	5708	Economy	14400.00
0005434319258	15666	Business	43300.00
0005433123969	15666	Business	43300.00
0005434319285	15666	Business	43300.00
0005434319287	15666	Business	43300.00
0005433123962	15666	Business	43300.00
0005434319297	15666	Business	43300.00
0005433123968	15666	Business	43300.00
0005433123967	15666	Business	43300.00
0005434319266	15666	Economy	14400.00
0005434319255	15666	Economy	14400.00
0005434319247	15666	Economy	14400.00
0005433123961	15666	Economy	14400.00
0005434319263	15666	Economy	14400.00
0005433123973	15666	Economy	15900.00
0005433123954	15666	Economy	14400.00
0005433123964	15666	Economy	14400.00
0005434319284	15666	Economy	14400.00
0005434319265	15666	Economy	14400.00
0005434319193	15666	Economy	14400.00
0005434319261	15666	Economy	14400.00
0005433123960	15666	Economy	14400.00
0005434312297	15666	Economy	14400.00
0005433123963	15666	Economy	14400.00
0005433123966	15666	Economy	14400.00
0005433123965	15666	Economy	14400.00
0005434319341	15666	Economy	14400.00
0005433123955	15666	Economy	14400.00
0005434319259	15666	Economy	14400.00
0005434319309	15666	Economy	14400.00
0005433123959	15666	Economy	14400.00
0005434319327	15666	Economy	14400.00
0005434319286	15666	Economy	14400.00
0005434319298	15666	Economy	14400.00
0005434319268	15666	Economy	14400.00
0005434319281	15666	Economy	14400.00
0005433123971	15666	Economy	14400.00
0005434319267	15666	Economy	14400.00
0005433123957	15666	Economy	14400.00
0005433123970	15666	Economy	14400.00
0005433123972	15666	Economy	14400.00
0005433123956	15666	Economy	14400.00
0005434319260	15666	Economy	14400.00
0005434319264	15666	Economy	14400.00
0005433123958	15666	Economy	14400.00
0005435220322	31753	Economy	17100.00
0005435219204	31753	Economy	17100.00
0005435220323	31753	Economy	15500.00
0005435219202	31753	Economy	15500.00
0005435220321	31753	Economy	15500.00
0005435220320	31753	Economy	15500.00
0005435219201	31753	Economy	15500.00
0005435219203	31753	Economy	15500.00
0005434189139	8983	Economy	24900.00
0005434484356	8983	Economy	24900.00
0005434484358	8983	Economy	24900.00
0005434189137	8983	Economy	24900.00
0005434484354	8983	Economy	24900.00
0005434484357	8983	Economy	24900.00
0005434484352	8983	Economy	24900.00
0005434484355	8983	Economy	24900.00
0005434189140	8983	Economy	24900.00
0005434189153	8983	Economy	24900.00
0005434189138	8983	Economy	24900.00
0005434189131	8983	Economy	24900.00
0005434484353	8983	Economy	24900.00
0005434189187	16612	Economy	24900.00
0005434484302	16612	Economy	24900.00
0005434484303	16612	Economy	24900.00
0005434484291	16612	Economy	24900.00
0005434484290	16612	Economy	24900.00
0005434189184	16612	Economy	24900.00
0005434484296	16612	Economy	24900.00
0005434189182	16612	Economy	24900.00
0005434189185	16612	Economy	24900.00
0005434189186	16612	Economy	24900.00
0005434189183	16612	Economy	24900.00
0005433123968	7709	Business	11100.00
0005433123971	7709	Business	11100.00
0005433123954	7709	Business	11100.00
0005433123957	7709	Business	11100.00
0005433123955	7709	Business	11100.00
0005433722151	7709	Economy	3700.00
0005433123963	7709	Economy	3700.00
0005433123964	7709	Economy	3700.00
0005433722166	7709	Economy	4100.00
0005433123973	7709	Economy	3700.00
0005433123967	7709	Economy	3700.00
0005433722116	7709	Economy	3700.00
0005433123965	7709	Economy	3700.00
0005433722155	7709	Economy	3700.00
0005433123969	7709	Economy	3700.00
0005433123970	7709	Economy	3700.00
0005433722147	7709	Economy	3700.00
0005433722148	7709	Economy	3700.00
0005433123960	7709	Economy	3700.00
0005433123958	7709	Economy	3700.00
0005433123972	7709	Economy	3700.00
0005433722162	7709	Economy	3700.00
0005433123966	7709	Economy	3700.00
0005433123956	7709	Economy	3700.00
0005433123962	7709	Economy	3700.00
0005433722161	7709	Economy	3700.00
0005433123959	7709	Economy	3700.00
0005433722160	7709	Economy	3700.00
0005433722154	7709	Economy	3700.00
0005433123961	7709	Economy	3700.00
0005432693097	7710	Business	11100.00
0005433449995	7710	Business	11100.00
0005433450003	7710	Business	11100.00
0005432693114	7710	Business	11100.00
0005433449993	7710	Business	11100.00
0005432720928	7710	Business	11100.00
0005432693123	7710	Business	11100.00
0005432720940	7710	Business	11100.00
0005432720922	7710	Business	11100.00
0005433449994	7710	Economy	3700.00
0005432720945	7710	Economy	3700.00
0005432720943	7710	Economy	3700.00
0005432693122	7710	Economy	3700.00
0005433449997	7710	Economy	3700.00
0005432720936	7710	Economy	3700.00
0005432693120	7710	Economy	3700.00
0005432693106	7710	Economy	4100.00
0005432693112	7710	Economy	4100.00
0005432693103	7710	Economy	4100.00
0005433450002	7710	Economy	4100.00
0005432693121	7710	Economy	4100.00
0005433450001	7710	Economy	3700.00
0005432693105	7710	Economy	3700.00
0005432720939	7710	Economy	3700.00
0005432693110	7710	Economy	3700.00
0005432720946	7710	Economy	3700.00
0005432693119	7710	Economy	3700.00
0005432720949	7710	Economy	3700.00
0005433449990	7710	Economy	3700.00
0005433449987	7710	Economy	3700.00
0005432693115	7710	Economy	3700.00
0005433449992	7710	Economy	3700.00
0005432693111	7710	Economy	3700.00
0005432720944	7710	Economy	3700.00
0005432720933	7710	Economy	3700.00
0005433450004	7710	Economy	3700.00
0005432720934	7710	Economy	3700.00
0005433449996	7710	Economy	3700.00
0005432693113	7710	Economy	3700.00
0005432720923	7710	Economy	3700.00
0005432071575	7710	Economy	3700.00
0005433450006	7710	Economy	3700.00
0005432693098	7710	Economy	3700.00
0005432693107	7710	Economy	3700.00
0005433449999	7710	Economy	3700.00
0005432693109	7710	Economy	3700.00
0005433450005	7710	Economy	3700.00
0005432720926	7710	Economy	3700.00
0005432720941	7710	Economy	3700.00
0005433449989	7710	Economy	3700.00
0005432693096	7710	Economy	3700.00
0005432693117	7710	Economy	3700.00
0005432720948	7710	Economy	3700.00
0005432720947	7710	Economy	3700.00
0005432693124	7710	Economy	3700.00
0005433449998	7710	Economy	3700.00
0005432693102	7710	Economy	3700.00
0005432693118	7710	Economy	3700.00
0005433450000	7710	Economy	3700.00
0005432720938	7710	Economy	3700.00
0005432720930	7710	Economy	3700.00
0005432720929	7710	Economy	3700.00
0005433449988	7710	Economy	3700.00
0005432720924	7710	Economy	3700.00
0005432720925	7710	Economy	3700.00
0005432693101	7710	Economy	3700.00
0005432693125	7710	Economy	3700.00
0005433450007	7710	Economy	3700.00
0005432720937	7710	Economy	3700.00
0005432693126	7710	Economy	3700.00
0005433449985	7710	Economy	3700.00
0005432693099	7710	Economy	3700.00
0005432071577	7710	Economy	3700.00
0005433449991	7710	Economy	3700.00
0005432720931	7710	Economy	3700.00
0005432693116	7710	Economy	3700.00
0005432693100	7710	Economy	3700.00
0005432071576	7710	Economy	3700.00
0005432720935	7710	Economy	3700.00
0005432693108	7710	Economy	3700.00
0005432693104	7710	Economy	3700.00
0005432720932	7710	Economy	3700.00
0005432720942	7710	Economy	3700.00
0005433449986	7710	Economy	3700.00
0005432720927	7710	Economy	3700.00
0005433449917	30296	Business	11100.00
0005433449643	30296	Business	11100.00
0005432692721	30296	Business	11100.00
0005433449786	30296	Business	11100.00
0005433449801	30296	Business	11100.00
0005433449739	30296	Business	11100.00
0005433449821	30296	Business	11100.00
0005432692779	30296	Business	11100.00
0005433449782	30296	Business	11100.00
0005433449833	30296	Economy	3700.00
0005432692823	30296	Economy	3700.00
0005432692996	30296	Economy	3700.00
0005433449829	30296	Economy	3700.00
0005432692746	30296	Economy	3700.00
0005433449857	30296	Economy	3700.00
0005432692814	30296	Economy	4100.00
0005432692921	30296	Economy	4100.00
0005432692733	30296	Economy	4100.00
0005433449932	30296	Economy	3700.00
0005432692944	30296	Economy	3700.00
0005433449890	30296	Economy	3700.00
0005433449897	30296	Economy	3700.00
0005433449790	30296	Economy	3700.00
0005433449822	30296	Economy	3700.00
0005432692933	30296	Economy	3700.00
0005433449861	30296	Economy	3700.00
0005433449760	30296	Economy	3700.00
0005432692722	30296	Economy	3700.00
0005432692913	30296	Economy	3700.00
0005432692693	30296	Economy	3700.00
0005433449812	30296	Economy	3700.00
0005432692732	30296	Economy	3700.00
0005433449868	30296	Economy	3700.00
0005432692917	30296	Economy	3700.00
0005432692723	30296	Economy	3700.00
0005433449785	30296	Economy	3700.00
0005433449773	30296	Economy	3700.00
0005432692813	30296	Economy	3700.00
0005433449789	30296	Economy	3700.00
0005433449828	30296	Economy	3700.00
0005433449856	30296	Economy	3700.00
0005433449843	30296	Economy	3700.00
0005433449834	30296	Economy	3700.00
0005433449772	30296	Economy	3700.00
0005432692885	30296	Economy	3700.00
0005432692796	30296	Economy	3700.00
0005433449759	30296	Economy	3700.00
0005433449781	30296	Economy	3700.00
0005432692747	30296	Economy	3700.00
0005433449791	30296	Economy	3700.00
0005432692916	30296	Economy	3700.00
0005433449757	30296	Economy	3700.00
0005432692945	30296	Economy	3700.00
0005432692873	30296	Economy	3700.00
0005433449884	30296	Economy	3700.00
0005432692857	30296	Economy	3700.00
0005433449839	30296	Economy	3700.00
0005433449774	30296	Economy	3700.00
0005433449741	30296	Economy	3700.00
0005433449916	30296	Economy	3700.00
0005433449792	30296	Economy	3700.00
0005433123831	30295	Business	11100.00
0005432720793	30295	Business	11100.00
0005433123755	30295	Business	11100.00
0005433123794	30295	Business	11100.00
0005432720751	30295	Business	11100.00
0005433123820	30295	Business	11100.00
0005432720664	30295	Business	11100.00
0005433123779	30295	Economy	3700.00
0005432720654	30295	Economy	3700.00
0005432720700	30295	Economy	3700.00
0005433123821	30295	Economy	3700.00
0005432720695	30295	Economy	3700.00
0005432720694	30295	Economy	3700.00
0005433123728	30295	Economy	3700.00
0005432720779	30295	Economy	3700.00
0005433123818	30295	Economy	3700.00
0005433123743	30295	Economy	4100.00
0005432720734	30295	Economy	4100.00
0005433123766	30295	Economy	4100.00
0005432720806	30295	Economy	3700.00
0005432720722	30295	Economy	3700.00
0005432720677	30295	Economy	3700.00
0005432720721	30295	Economy	3700.00
0005433123729	30295	Economy	3700.00
0005433123772	30295	Economy	3700.00
0005432720784	30295	Economy	3700.00
0005433123705	30295	Economy	3700.00
0005433123769	30295	Economy	3700.00
0005433123770	30295	Economy	3700.00
0005433123736	30295	Economy	3700.00
0005433722231	30295	Economy	3700.00
0005432720726	30295	Economy	3700.00
0005433123809	30295	Economy	3700.00
0005432720795	30295	Economy	3700.00
0005432720725	30295	Economy	3700.00
0005432720748	30295	Economy	3700.00
0005433123686	30295	Economy	3700.00
0005432720701	30295	Economy	3700.00
0005432720709	30295	Economy	3700.00
0005433123819	30295	Economy	3700.00
0005432720780	30295	Economy	3700.00
0005433123701	30295	Economy	3700.00
0005432720781	30295	Economy	3700.00
0005432720729	30295	Economy	3700.00
0005432720789	30295	Economy	3700.00
0005433722230	30295	Economy	3700.00
0005432720661	30295	Economy	3700.00
0005433123768	30295	Economy	3700.00
0005433123754	30295	Economy	3700.00
0005433123764	30295	Economy	3700.00
0005433123735	30295	Economy	3700.00
0005432720702	30295	Economy	3700.00
0005433123713	30295	Economy	3700.00
0005433123763	30295	Economy	3700.00
0005433123744	30295	Economy	3700.00
0005433525048	1407	Business	70400.00
0005433192894	1407	Business	70400.00
0005434586641	1407	Business	70400.00
0005433192990	1407	Business	70400.00
0005434586634	1407	Business	70400.00
0005434586650	1407	Business	70400.00
0005434586648	1407	Business	70400.00
0005434586630	1407	Business	70400.00
0005433525053	1407	Business	70400.00
0005433192945	1407	Business	70400.00
0005433525049	1407	Economy	23500.00
0005432968826	1407	Economy	23500.00
0005433192964	1407	Economy	23500.00
0005434586646	1407	Economy	23500.00
0005434513583	1407	Economy	23500.00
0005432927981	1407	Economy	23500.00
0005433724814	1407	Economy	23500.00
0005433525050	1407	Economy	23500.00
0005434586633	1407	Economy	25800.00
0005433192937	1407	Economy	25800.00
0005432968817	1407	Economy	25800.00
0005433192932	1407	Economy	25800.00
0005434514969	1407	Economy	25800.00
0005432927925	1407	Economy	23500.00
0005433192893	1407	Economy	23500.00
0005432968830	1407	Economy	23500.00
0005433525051	1407	Economy	23500.00
0005433192969	1407	Economy	23500.00
0005434586638	1407	Economy	23500.00
0005434586640	1407	Economy	23500.00
0005433525046	1407	Economy	23500.00
0005433192963	1407	Economy	23500.00
0005434586656	1407	Economy	23500.00
0005434586644	1407	Economy	23500.00
0005434586637	1407	Economy	23500.00
0005434514970	1407	Economy	23500.00
0005433525057	1407	Economy	23500.00
0005434586632	1407	Economy	23500.00
0005432968807	1407	Economy	23500.00
0005434586651	1407	Economy	23500.00
0005433525054	1407	Economy	23500.00
0005433724813	1407	Economy	23500.00
0005433192946	1407	Economy	23500.00
0005434586654	1407	Economy	23500.00
0005433525055	1407	Economy	23500.00
0005433724812	1407	Economy	23500.00
0005434586635	1407	Economy	23500.00
0005434586639	1407	Economy	23500.00
0005433192958	1407	Economy	23500.00
0005433525056	1407	Economy	23500.00
0005432968831	1407	Economy	23500.00
0005433525052	1407	Economy	23500.00
0005434586649	1407	Economy	23500.00
0005434586652	1407	Economy	23500.00
0005434586647	1407	Economy	23500.00
0005433192943	1407	Economy	23500.00
0005433192864	1407	Economy	23500.00
0005434514971	1407	Economy	23500.00
0005434586631	1407	Economy	23500.00
0005432968818	1407	Economy	23500.00
0005432271008	1407	Economy	23500.00
0005434513582	1407	Economy	23500.00
0005434586642	1407	Economy	23500.00
0005432927936	1407	Economy	23500.00
0005433193011	1407	Economy	23500.00
0005434586655	1407	Economy	23500.00
0005434586636	1407	Economy	23500.00
0005432968816	1407	Economy	23500.00
0005434586645	1407	Economy	23500.00
0005432271006	1407	Economy	23500.00
0005432271007	1407	Economy	23500.00
0005434586653	1407	Economy	23500.00
0005433525047	1407	Economy	23500.00
0005434586643	1407	Economy	23500.00
0005432271009	1407	Economy	23500.00
0005434586350	18506	Business	70400.00
0005434586508	18506	Business	70400.00
0005433193062	18506	Business	70400.00
0005433724750	18506	Business	70400.00
0005434586329	18506	Business	70400.00
0005433724771	18506	Business	70400.00
0005434586375	18506	Business	70400.00
0005434586443	18506	Business	70400.00
0005434586431	18506	Business	70400.00
0005434586425	18506	Business	70400.00
0005434586372	18506	Economy	23500.00
0005433524919	18506	Economy	23500.00
0005434586362	18506	Economy	23500.00
0005434586485	18506	Economy	23500.00
0005434586391	18506	Economy	23500.00
0005434586518	18506	Economy	23500.00
0005433193058	18506	Economy	23500.00
0005433524936	18506	Economy	23500.00
0005433724764	18506	Economy	25800.00
0005433724773	18506	Economy	25800.00
0005433724768	18506	Economy	25800.00
0005434586454	18506	Economy	23500.00
0005434586317	18506	Economy	23500.00
0005434514951	18506	Economy	23500.00
0005434586423	18506	Economy	23500.00
0005432927987	18506	Economy	23500.00
0005434586334	18506	Economy	23500.00
0005433524939	18506	Economy	23500.00
0005433524954	18506	Economy	23500.00
0005433193064	18506	Economy	23500.00
0005432968842	18506	Economy	23500.00
0005433524920	18506	Economy	23500.00
0005433524931	18506	Economy	23500.00
0005434586462	18506	Economy	23500.00
0005433193059	18506	Economy	23500.00
0005432968843	18506	Economy	23500.00
0005432927988	18506	Economy	23500.00
0005433524930	18506	Economy	23500.00
0005433193063	18506	Economy	23500.00
0005432927986	18506	Economy	23500.00
0005433724770	18506	Economy	23500.00
0005433193066	18506	Economy	23500.00
0005434586377	18506	Economy	23500.00
0005433193068	18506	Economy	23500.00
0005434586509	18506	Economy	23500.00
0005434586515	18506	Economy	23500.00
0005434586476	18506	Economy	23500.00
0005432927983	18506	Economy	23500.00
0005433524985	18506	Economy	23500.00
0005433724765	18506	Economy	23500.00
0005434586363	18506	Economy	23500.00
0005434586428	18506	Economy	23500.00
0005433193060	18506	Economy	23500.00
0005434586424	18506	Economy	23500.00
0005433524947	18506	Economy	23500.00
0005432927984	18506	Economy	23500.00
0005434586453	18506	Economy	23500.00
0005433193065	18506	Economy	23500.00
0005433724749	18506	Economy	23500.00
0005434586432	18506	Economy	23500.00
0005433524976	18506	Economy	23500.00
0005433193061	18506	Economy	23500.00
0005433193067	18506	Economy	23500.00
0005433524940	18506	Economy	23500.00
0005433193057	18506	Economy	23500.00
0005433724769	18506	Economy	23500.00
0005432927985	18506	Economy	23500.00
0005433724763	18506	Economy	23500.00
0005434586475	18506	Economy	23500.00
0005434586361	18506	Economy	23500.00
0005434586316	18506	Economy	23500.00
0005434586517	18506	Economy	23500.00
0005434586427	18506	Economy	23500.00
0005434514944	18506	Economy	23500.00
0005435304997	11427	Economy	4300.00
0005434344213	11427	Economy	4300.00
0005434344231	11427	Economy	4300.00
0005434344217	11427	Economy	4300.00
0005434344220	11427	Economy	4000.00
0005434344234	11427	Economy	4000.00
0005434344225	11427	Economy	4000.00
0005434142616	11427	Economy	4000.00
0005434344224	11427	Economy	4000.00
0005435302175	11427	Economy	4000.00
0005434344241	11427	Economy	4000.00
0005434142615	11427	Economy	4000.00
0005434344219	11427	Economy	4000.00
0005434344221	11427	Economy	4000.00
0005434344218	11427	Economy	4000.00
0005434142613	11427	Economy	4000.00
0005435302146	11427	Economy	4000.00
0005434344230	11427	Economy	4000.00
0005435302174	11427	Economy	4000.00
0005434344233	11427	Economy	4000.00
0005434344226	11427	Economy	4000.00
0005434142614	11427	Economy	4000.00
0005434344214	11427	Economy	4000.00
0005434344237	11427	Economy	4000.00
0005434344242	11427	Economy	4000.00
0005434344232	11427	Economy	4000.00
0005434344215	11427	Economy	4000.00
0005434344246	11427	Economy	4000.00
0005434344235	11427	Economy	4000.00
0005434344227	11427	Economy	4000.00
0005434142617	11427	Economy	4000.00
0005434344247	11427	Economy	4000.00
0005434344239	11427	Economy	4000.00
0005434344240	11427	Economy	4000.00
0005434344223	11427	Economy	4000.00
0005434344229	11427	Economy	4000.00
0005434344211	11427	Economy	4000.00
0005434344245	11427	Economy	4000.00
0005434344222	11427	Economy	4000.00
0005434344236	11427	Economy	4000.00
0005434344228	11427	Economy	4000.00
0005434344244	11427	Economy	4000.00
0005434344216	11427	Economy	4000.00
0005434344248	11427	Economy	4000.00
0005434344238	11427	Economy	4000.00
0005434344243	11427	Economy	4000.00
0005434344212	11427	Economy	4000.00
0005435302176	11427	Economy	4000.00
0005435302138	11427	Economy	4000.00
0005434343856	29768	Economy	4300.00
0005434343850	29768	Economy	4300.00
0005434344021	29768	Economy	4300.00
0005434343890	29768	Economy	4300.00
0005434343959	29768	Economy	4000.00
0005434344002	29768	Economy	4000.00
0005434344045	29768	Economy	4000.00
0005434344078	29768	Economy	4000.00
0005435304166	29768	Economy	4000.00
0005434343780	29768	Economy	4000.00
0005434343945	29768	Economy	4000.00
0005434343886	29768	Economy	4000.00
0005434344077	29768	Economy	4000.00
0005434343996	29768	Economy	4000.00
0005434343956	29768	Economy	4000.00
0005434343737	29768	Economy	4000.00
0005434344050	29768	Economy	4000.00
0005434343700	29768	Economy	4000.00
0005434343898	29768	Economy	4000.00
0005434142578	29768	Economy	4000.00
0005434343941	29768	Economy	4000.00
0005434343891	29768	Economy	4000.00
0005434343884	29768	Economy	4000.00
0005434344061	29768	Economy	4000.00
0005434343991	29768	Economy	4000.00
0005434343911	29768	Economy	4000.00
0005434343707	29768	Economy	4000.00
0005434343885	29768	Economy	4000.00
0005434343949	29768	Economy	4000.00
0005434344003	29768	Economy	4000.00
0005434343905	29768	Economy	4000.00
0005435304167	29768	Economy	4000.00
0005434344097	29768	Economy	4000.00
0005435304165	29768	Economy	4000.00
0005434344127	29768	Economy	4000.00
0005434343876	29768	Economy	4000.00
0005434343825	29768	Economy	4000.00
0005434343830	29768	Economy	4000.00
0005434343829	29768	Economy	4000.00
0005434142577	29768	Economy	4000.00
0005434343960	29768	Economy	4000.00
0005434344049	29768	Economy	4000.00
0005435304164	29768	Economy	4000.00
0005434344031	29768	Economy	4000.00
0005434343993	29768	Economy	4000.00
0005434343955	29768	Economy	4000.00
0005434343958	29768	Economy	4000.00
0005434343925	29768	Economy	4000.00
0005434343992	29768	Economy	4000.00
0005434343942	29768	Economy	4000.00
0005435824651	1260	Business	199800.00
0005435824668	1260	Business	199800.00
0005435824666	1260	Business	199800.00
0005433415552	1260	Business	199800.00
0005435824664	1260	Business	199800.00
0005433415601	1260	Business	199800.00
0005435824660	1260	Business	199800.00
0005433415564	1260	Economy	66600.00
0005433415494	1260	Economy	66600.00
0005435824658	1260	Economy	66600.00
0005433415569	1260	Economy	66600.00
0005433415492	1260	Economy	66600.00
0005435824672	1260	Economy	66600.00
0005435824650	1260	Economy	66600.00
0005432284561	1260	Economy	66600.00
0005435824652	1260	Economy	73200.00
0005433415637	1260	Economy	73200.00
0005435824659	1260	Economy	73200.00
0005435824646	1260	Economy	66600.00
0005433415594	1260	Economy	66600.00
0005435824662	1260	Economy	66600.00
0005435824648	1260	Economy	66600.00
0005435824669	1260	Economy	66600.00
0005432284562	1260	Economy	66600.00
0005433415557	1260	Economy	66600.00
0005435824656	1260	Economy	66600.00
0005433415556	1260	Economy	66600.00
0005432284563	1260	Economy	66600.00
0005435824649	1260	Economy	66600.00
0005435824670	1260	Economy	66600.00
0005435824663	1260	Economy	66600.00
0005435824654	1260	Economy	66600.00
0005432284560	1260	Economy	66600.00
0005433415584	1260	Economy	66600.00
0005435824665	1260	Economy	66600.00
0005433415604	1260	Economy	66600.00
0005435824655	1260	Economy	66600.00
0005433415515	1260	Economy	66600.00
0005433415585	1260	Economy	66600.00
0005433415630	1260	Economy	66600.00
0005435824667	1260	Economy	66600.00
0005433415493	1260	Economy	66600.00
0005435824661	1260	Economy	66600.00
0005435824647	1260	Economy	66600.00
0005435824653	1260	Economy	66600.00
0005433415586	1260	Economy	66600.00
0005435824657	1260	Economy	66600.00
0005435824671	1260	Economy	66600.00
0005435824438	18024	Business	199800.00
0005433415685	18024	Business	199800.00
0005435824296	18024	Business	199800.00
0005433415677	18024	Business	199800.00
0005435824429	18024	Business	199800.00
0005433415679	18024	Business	199800.00
0005433415675	18024	Business	199800.00
0005433415673	18024	Business	199800.00
0005435824385	18024	Business	199800.00
0005435824317	18024	Business	199800.00
0005435824452	18024	Economy	66600.00
0005433415674	18024	Economy	66600.00
0005435824330	18024	Economy	66600.00
0005435824333	18024	Economy	66600.00
0005435824432	18024	Economy	66600.00
0005435824347	18024	Economy	66600.00
0005435824275	18024	Economy	66600.00
0005435824318	18024	Economy	66600.00
0005435824509	18024	Economy	73200.00
0005433415678	18024	Economy	73200.00
0005435824437	18024	Economy	73200.00
0005435824414	18024	Economy	66600.00
0005435824434	18024	Economy	66600.00
0005435824476	18024	Economy	66600.00
0005435824421	18024	Economy	66600.00
0005435824433	18024	Economy	66600.00
0005435824430	18024	Economy	66600.00
0005435824423	18024	Economy	66600.00
0005435824428	18024	Economy	66600.00
0005433415681	18024	Economy	66600.00
0005435824526	18024	Economy	66600.00
0005435824334	18024	Economy	66600.00
0005435824472	18024	Economy	66600.00
0005435824409	18024	Economy	66600.00
0005435824331	18024	Economy	66600.00
0005433415676	18024	Economy	66600.00
0005435824492	18024	Economy	66600.00
0005435824377	18024	Economy	66600.00
0005433415682	18024	Economy	66600.00
0005435824493	18024	Economy	66600.00
0005435824332	18024	Economy	66600.00
0005433415684	18024	Economy	66600.00
0005435824329	18024	Economy	66600.00
0005433415683	18024	Economy	66600.00
0005435824403	18024	Economy	66600.00
0005433415680	18024	Economy	66600.00
0005433415687	18024	Economy	66600.00
0005435824415	18024	Economy	66600.00
0005435824352	18024	Economy	66600.00
0005435824379	18024	Economy	66600.00
0005433415686	18024	Economy	66600.00
0005435824295	18024	Economy	66600.00
0005435824378	18024	Economy	66600.00
0005435824286	18024	Economy	66600.00
0005432143990	5648	Business	27800.00
0005432143992	5648	Business	27800.00
0005435242641	5648	Business	27800.00
0005432783843	5648	Business	27800.00
0005435476687	5648	Business	27800.00
0005432783841	5648	Business	27800.00
0005432783883	5648	Business	27800.00
0005435242575	5648	Business	27800.00
0005435242616	5648	Business	27800.00
0005435242529	5648	Business	27800.00
0005432783858	5648	Business	27800.00
0005432783833	5648	Economy	9300.00
0005432783834	5648	Economy	9300.00
0005432783847	5648	Economy	9300.00
0005432783877	5648	Economy	9300.00
0005435242584	5648	Economy	9300.00
0005432783837	5648	Economy	9300.00
0005432783840	5648	Economy	9300.00
0005435242617	5648	Economy	9300.00
0005432783845	5648	Economy	9300.00
0005432783880	5648	Economy	10200.00
0005432783879	5648	Economy	10200.00
0005432783848	5648	Economy	10200.00
0005432783866	5648	Economy	10200.00
0005432783873	5648	Economy	10200.00
0005432783835	5648	Economy	9300.00
0005432783878	5648	Economy	9300.00
0005432783831	5648	Economy	9300.00
0005432783861	5648	Economy	9300.00
0005432783859	5648	Economy	9300.00
0005432783836	5648	Economy	9300.00
0005435476707	5648	Economy	9300.00
0005432783838	5648	Economy	9300.00
0005435476714	5648	Economy	9300.00
0005432783875	5648	Economy	9300.00
0005432783846	5648	Economy	9300.00
0005432783857	5648	Economy	9300.00
0005432783872	5648	Economy	9300.00
0005435242576	5648	Economy	9300.00
0005432783839	5648	Economy	9300.00
0005435476701	5648	Economy	9300.00
0005435242655	5648	Economy	9300.00
0005432783853	5648	Economy	9300.00
0005435476715	5648	Economy	9300.00
0005432783862	5648	Economy	9300.00
0005432783868	5648	Economy	9300.00
0005432783842	5648	Economy	9300.00
0005435476692	5648	Economy	9300.00
0005435242596	5648	Economy	9300.00
0005432783849	5648	Economy	9300.00
0005435242646	5648	Economy	9300.00
0005432783882	5648	Economy	9300.00
0005432783832	5648	Economy	9300.00
0005432783869	5648	Economy	9300.00
0005432783864	5648	Economy	9300.00
0005432783850	5648	Economy	9300.00
0005435242647	5648	Economy	9300.00
0005435242550	5648	Economy	9300.00
0005435242661	5648	Economy	9300.00
0005432783863	5648	Economy	9300.00
0005432783844	5648	Economy	9300.00
0005432783884	5648	Economy	9300.00
0005435242644	5648	Economy	9300.00
0005435242603	5648	Economy	9300.00
0005432783871	5648	Economy	9300.00
0005432783870	5648	Economy	9300.00
0005435476716	5648	Economy	9300.00
0005435242517	5648	Economy	9300.00
0005435476691	5648	Economy	9300.00
0005432783867	5648	Economy	9300.00
0005435242706	5648	Economy	9300.00
0005432783874	5648	Economy	9300.00
0005432783854	5648	Economy	9300.00
0005435242624	5648	Economy	9300.00
0005435476698	5648	Economy	9300.00
0005435242619	5648	Economy	9300.00
0005432783856	5648	Economy	9300.00
0005435242643	5648	Economy	9300.00
0005432783851	5648	Economy	9300.00
0005432783860	5648	Economy	9300.00
0005432783852	5648	Economy	9300.00
0005432143991	5648	Economy	9300.00
0005432783830	5648	Economy	9300.00
0005435476682	5648	Economy	9300.00
0005432783881	5648	Economy	9300.00
0005435242677	5648	Economy	9300.00
0005435242645	5648	Economy	9300.00
0005435242638	5648	Economy	9300.00
0005432783855	5648	Economy	9300.00
0005432783865	5648	Economy	9300.00
0005435242544	5648	Economy	9300.00
0005435242618	5648	Economy	9300.00
0005432783876	5648	Economy	9300.00
0005435242557	5648	Economy	9300.00
0005435476758	15344	Business	27800.00
0005432783330	15344	Business	27800.00
0005435242857	15344	Business	27800.00
0005435476754	15344	Business	27800.00
0005435242861	15344	Business	27800.00
0005432783226	15344	Business	27800.00
0005432783351	15344	Business	27800.00
0005435476759	15344	Business	27800.00
0005435242865	15344	Business	27800.00
0005432783073	15344	Business	27800.00
0005432783277	15344	Business	27800.00
0005435476760	15344	Economy	9300.00
0005432783190	15344	Economy	9300.00
0005432783473	15344	Economy	9300.00
0005435242866	15344	Economy	9300.00
0005435242864	15344	Economy	9300.00
0005435476756	15344	Economy	9300.00
0005432783555	15344	Economy	9300.00
0005432783339	15344	Economy	9300.00
0005435242859	15344	Economy	9300.00
0005432783352	15344	Economy	9300.00
0005432783255	15344	Economy	10200.00
0005432783289	15344	Economy	10200.00
0005435242856	15344	Economy	10200.00
0005432783207	15344	Economy	10200.00
0005435242871	15344	Economy	9300.00
0005435476761	15344	Economy	9300.00
0005432782934	15344	Economy	9300.00
0005435242863	15344	Economy	9300.00
0005435242878	15344	Economy	9300.00
0005435476762	15344	Economy	9300.00
0005432783315	15344	Economy	9300.00
0005432783464	15344	Economy	9300.00
0005435242877	15344	Economy	9300.00
0005435476757	15344	Economy	9300.00
0005435242853	15344	Economy	9300.00
0005432783312	15344	Economy	9300.00
0005435242868	15344	Economy	9300.00
0005435242876	15344	Economy	9300.00
0005432783575	15344	Economy	9300.00
0005435242869	15344	Economy	9300.00
0005432783276	15344	Economy	9300.00
0005432783468	15344	Economy	9300.00
0005435242874	15344	Economy	9300.00
0005435476755	15344	Economy	9300.00
0005435242879	15344	Economy	9300.00
0005432783420	15344	Economy	9300.00
0005435242873	15344	Economy	9300.00
0005432783327	15344	Economy	9300.00
0005432783640	15344	Economy	9300.00
0005432783329	15344	Economy	9300.00
0005432783463	15344	Economy	9300.00
0005432783438	15344	Economy	9300.00
0005432783311	15344	Economy	9300.00
0005432783592	15344	Economy	9300.00
0005432783222	15344	Economy	9300.00
0005435242872	15344	Economy	9300.00
0005435242854	15344	Economy	9300.00
0005432783221	15344	Economy	9300.00
0005435242870	15344	Economy	9300.00
0005432783439	15344	Economy	9300.00
0005432783328	15344	Economy	9300.00
0005432783507	15344	Economy	9300.00
0005432783459	15344	Economy	9300.00
0005432783223	15344	Economy	9300.00
0005432783130	15344	Economy	9300.00
0005435242862	15344	Economy	9300.00
0005432783228	15344	Economy	9300.00
0005432783474	15344	Economy	9300.00
0005432783244	15344	Economy	9300.00
0005432783338	15344	Economy	9300.00
0005435242855	15344	Economy	9300.00
0005435242852	15344	Economy	9300.00
0005435242860	15344	Economy	9300.00
0005435242875	15344	Economy	9300.00
0005435242858	15344	Economy	9300.00
0005435242867	15344	Economy	9300.00
0005432783224	15344	Economy	9300.00
0005432783347	15344	Economy	9300.00
0005432783285	15344	Economy	9300.00
0005432783290	15344	Economy	9300.00
0005432783331	15344	Economy	9300.00
0005432783284	15344	Economy	9300.00
0005432848322	4354	Economy	7000.00
0005432848335	4354	Economy	6300.00
0005432848325	4354	Economy	6300.00
0005432848324	4354	Economy	6300.00
0005435850838	4354	Economy	6300.00
0005435850866	4354	Economy	6300.00
0005434463931	4354	Economy	6300.00
0005432848332	4354	Economy	6300.00
0005435850880	4354	Economy	6300.00
0005432848336	4354	Economy	6300.00
0005432848330	4354	Economy	6300.00
0005435850835	4354	Economy	6300.00
0005432848326	4354	Economy	6300.00
0005432848323	4354	Economy	6300.00
0005432848328	4354	Economy	6300.00
0005432848327	4354	Economy	6300.00
0005434463932	4354	Economy	6300.00
0005432848333	4354	Economy	6300.00
0005435850832	4354	Economy	6300.00
0005435850867	4354	Economy	6300.00
0005435850905	4354	Economy	6300.00
0005435850879	4354	Economy	6300.00
0005435850834	4354	Economy	6300.00
0005432848334	4354	Economy	6300.00
0005432848331	4354	Economy	6300.00
0005434463933	4354	Economy	6300.00
0005434462793	4354	Economy	6300.00
0005435850878	4354	Economy	6300.00
0005432848329	4354	Economy	6300.00
0005435850920	28857	Economy	7000.00
0005432848228	28857	Economy	7000.00
0005434461633	28857	Economy	7000.00
0005435850923	28857	Economy	6300.00
0005432848211	28857	Economy	6300.00
0005434463913	28857	Economy	6300.00
0005434461624	28857	Economy	6300.00
0005432848216	28857	Economy	6300.00
0005432848160	28857	Economy	6300.00
0005435850921	28857	Economy	6300.00
0005432848256	28857	Economy	6300.00
0005435850925	28857	Economy	6300.00
0005432848203	28857	Economy	6300.00
0005435850924	28857	Economy	6300.00
0005432848222	28857	Economy	6300.00
0005432848215	28857	Economy	6300.00
0005435850919	28857	Economy	6300.00
0005432848199	28857	Economy	6300.00
0005435850918	28857	Economy	6300.00
0005432848227	28857	Economy	6300.00
0005434463903	28857	Economy	6300.00
0005434461632	28857	Economy	6300.00
0005432848202	28857	Economy	6300.00
0005434463912	28857	Economy	6300.00
0005432848139	28857	Economy	6300.00
0005435850922	28857	Economy	6300.00
0005432848230	28857	Economy	6300.00
0005432848221	28857	Economy	6300.00
0005432848167	28857	Economy	6300.00
0005432848212	28857	Economy	6300.00
0005432848137	28857	Economy	6300.00
0005434461611	28857	Economy	6300.00
0005434463911	28857	Economy	6300.00
0005433497002	6343	Business	11900.00
0005434925832	6343	Business	11900.00
0005432075233	6343	Business	11900.00
0005434443735	6343	Business	11900.00
0005433497009	6343	Business	11900.00
0005433497000	6343	Business	11900.00
0005433497013	6343	Business	11900.00
0005434925849	6343	Business	11900.00
0005434443722	6343	Business	11900.00
0005434443733	6343	Business	11900.00
0005433496996	6343	Economy	4000.00
0005433497020	6343	Economy	4000.00
0005434925837	6343	Economy	4000.00
0005432075236	6343	Economy	4000.00
0005434443730	6343	Economy	4000.00
0005434443729	6343	Economy	4000.00
0005434443728	6343	Economy	4000.00
0005434443736	6343	Economy	4000.00
0005434925843	6343	Economy	4400.00
0005433497010	6343	Economy	4400.00
0005433496994	6343	Economy	4400.00
0005433497022	6343	Economy	4400.00
0005434925841	6343	Economy	4000.00
0005433497025	6343	Economy	4000.00
0005433496995	6343	Economy	4000.00
0005434925848	6343	Economy	4000.00
0005434925846	6343	Economy	4000.00
0005434925838	6343	Economy	4000.00
0005433497023	6343	Economy	4000.00
0005434925851	6343	Economy	4000.00
0005434925855	6343	Economy	4000.00
0005433496999	6343	Economy	4000.00
0005433497012	6343	Economy	4000.00
0005433497003	6343	Economy	4000.00
0005434925844	6343	Economy	4000.00
0005434925834	6343	Economy	4000.00
0005433497001	6343	Economy	4000.00
0005434443737	6343	Economy	4000.00
0005434925833	6343	Economy	4000.00
0005434925850	6343	Economy	4000.00
0005434925839	6343	Economy	4000.00
0005433496997	6343	Economy	4000.00
0005433497015	6343	Economy	4000.00
0005434443731	6343	Economy	4000.00
0005433497014	6343	Economy	4000.00
0005434925856	6343	Economy	4000.00
0005432075234	6343	Economy	4000.00
0005434925852	6343	Economy	4000.00
0005434925842	6343	Economy	4000.00
0005432075235	6343	Economy	4000.00
0005433497005	6343	Economy	4000.00
0005434443724	6343	Economy	4000.00
0005433497011	6343	Economy	4000.00
0005434443721	6343	Economy	4000.00
0005433497007	6343	Economy	4000.00
0005434925836	6343	Economy	4000.00
0005434925854	6343	Economy	4000.00
0005433497006	6343	Economy	4000.00
0005434443723	6343	Economy	4000.00
0005433497024	6343	Economy	4000.00
0005434443727	6343	Economy	4000.00
0005433496998	6343	Economy	4000.00
0005433497017	6343	Economy	4000.00
0005434443726	6343	Economy	4000.00
0005433497018	6343	Economy	4000.00
0005434925840	6343	Economy	4000.00
0005433497019	6343	Economy	4000.00
0005434443725	6343	Economy	4000.00
0005433497004	6343	Economy	4000.00
0005433497016	6343	Economy	4000.00
0005434925835	6343	Economy	4000.00
0005434443732	6343	Economy	4000.00
0005433497008	6343	Economy	4000.00
0005434925847	6343	Economy	4000.00
0005434925845	6343	Economy	4000.00
0005433497021	6343	Economy	4000.00
0005434443734	6343	Economy	4000.00
0005434925853	6343	Economy	4000.00
0005434925662	20416	Business	11900.00
0005434925635	20416	Business	11900.00
0005433496515	20416	Business	11900.00
0005433496693	20416	Business	11900.00
0005433496740	20416	Business	11900.00
0005434925577	20416	Business	11900.00
0005434925745	20416	Business	11900.00
0005434443615	20416	Business	11900.00
0005433496814	20416	Business	11900.00
0005434443516	20416	Business	11900.00
0005434925417	20416	Economy	4000.00
0005434925401	20416	Economy	4000.00
0005434925553	20416	Economy	4000.00
0005434925524	20416	Economy	4000.00
0005434925636	20416	Economy	4000.00
0005433496516	20416	Economy	4400.00
0005434925510	20416	Economy	4400.00
0005433496923	20416	Economy	4400.00
0005433496694	20416	Economy	4400.00
0005434443590	20416	Economy	4400.00
0005434925469	20416	Economy	4000.00
0005434925692	20416	Economy	4000.00
0005434443515	20416	Economy	4000.00
0005433496696	20416	Economy	4000.00
0005434925420	20416	Economy	4000.00
0005434925492	20416	Economy	4000.00
0005433496615	20416	Economy	4000.00
0005433496695	20416	Economy	4000.00
0005434443498	20416	Economy	4000.00
0005433496862	20416	Economy	4000.00
0005433496616	20416	Economy	4000.00
0005433496614	20416	Economy	4000.00
0005434925649	20416	Economy	4000.00
0005434925419	20416	Economy	4000.00
0005434925512	20416	Economy	4000.00
0005433496863	20416	Economy	4000.00
0005434443614	20416	Economy	4000.00
0005433496860	20416	Economy	4000.00
0005433496692	20416	Economy	4000.00
0005433496702	20416	Economy	4000.00
0005433496772	20416	Economy	4000.00
0005433496665	20416	Economy	4000.00
0005434925648	20416	Economy	4000.00
0005434925464	20416	Economy	4000.00
0005434925422	20416	Economy	4000.00
0005433496861	20416	Economy	4000.00
0005433496809	20416	Economy	4000.00
0005434925502	20416	Economy	4000.00
0005434925674	20416	Economy	4000.00
0005433496815	20416	Economy	4000.00
0005433496650	20416	Economy	4000.00
0005433496617	20416	Economy	4000.00
0005433496773	20416	Economy	4000.00
0005434443571	20416	Economy	4000.00
0005433496717	20416	Economy	4000.00
0005433496924	20416	Economy	4000.00
0005433496698	20416	Economy	4000.00
0005433496858	20416	Economy	4000.00
0005434925663	20416	Economy	4000.00
0005434925481	20416	Economy	4000.00
0005434925673	20416	Economy	4000.00
0005433496683	20416	Economy	4000.00
0005434925400	20416	Economy	4000.00
0005434443639	20416	Economy	4000.00
0005433496672	20416	Economy	4000.00
0005434443570	20416	Economy	4000.00
0005434925573	20416	Economy	4000.00
0005433496708	20416	Economy	4000.00
0005434925463	20416	Economy	4000.00
0005434925661	20416	Economy	4000.00
0005434925572	20416	Economy	4000.00
0005434443579	20416	Economy	4000.00
0005433496843	20416	Economy	4000.00
0005434925441	20416	Economy	4000.00
0005433496684	20416	Economy	4000.00
0005434925456	20416	Economy	4000.00
0005432783460	12165	Business	41200.00
0005432783397	12165	Business	41200.00
0005432783536	12165	Business	41200.00
0005435242882	12165	Business	41200.00
0005435242902	12165	Business	41200.00
0005432783361	12165	Business	41200.00
0005432783062	12165	Business	41200.00
0005432783376	12165	Business	41200.00
0005432783428	12165	Business	41200.00
0005435242894	12165	Business	41200.00
0005432783271	12165	Business	41200.00
0005432783461	12165	Business	41200.00
0005432783227	12165	Economy	13700.00
0005432783401	12165	Economy	13700.00
0005432783635	12165	Economy	13700.00
0005432783362	12165	Economy	13700.00
0005432783574	12165	Economy	13700.00
0005432783646	12165	Economy	13700.00
0005435242899	12165	Economy	13700.00
0005432783407	12165	Economy	13700.00
0005432783059	12165	Economy	15100.00
0005432783374	12165	Economy	15100.00
0005432783142	12165	Economy	15100.00
0005435242881	12165	Economy	15100.00
0005432783537	12165	Economy	13700.00
0005432783373	12165	Economy	13700.00
0005432783232	12165	Economy	13700.00
0005435242887	12165	Economy	13700.00
0005435242884	12165	Economy	13700.00
0005432783126	12165	Economy	13700.00
0005432783314	12165	Economy	13700.00
0005435242880	12165	Economy	13700.00
0005432783472	12165	Economy	13700.00
0005432783356	12165	Economy	13700.00
0005432783296	12165	Economy	13700.00
0005432783584	12165	Economy	13700.00
0005432783550	12165	Economy	13700.00
0005432783410	12165	Economy	13700.00
0005432783415	12165	Economy	13700.00
0005432783411	12165	Economy	13700.00
0005432783136	12165	Economy	13700.00
0005435242892	12165	Economy	13700.00
0005435242905	12165	Economy	13700.00
0005432783182	12165	Economy	13700.00
0005432783231	12165	Economy	13700.00
0005432783442	12165	Economy	13700.00
0005435242898	12165	Economy	13700.00
0005432783141	12165	Economy	13700.00
0005432783214	12165	Economy	13700.00
0005432783063	12165	Economy	13700.00
0005432783534	12165	Economy	13700.00
0005435242895	12165	Economy	13700.00
0005432783137	12165	Economy	13700.00
0005432783485	12165	Economy	13700.00
0005435242889	12165	Economy	13700.00
0005432783535	12165	Economy	13700.00
0005435242897	12165	Economy	13700.00
0005435242904	12165	Economy	13700.00
0005432783370	12165	Economy	13700.00
0005435242886	12165	Economy	13700.00
0005435242890	12165	Economy	13700.00
0005435242900	12165	Economy	13700.00
0005435242896	12165	Economy	13700.00
0005432783630	12165	Economy	13700.00
0005432783306	12165	Economy	13700.00
0005432783545	12165	Economy	13700.00
0005435242883	12165	Economy	13700.00
0005432783269	12165	Economy	13700.00
0005432783467	12165	Economy	13700.00
0005432783391	12165	Economy	13700.00
0005435242906	12165	Economy	13700.00
0005432783486	12165	Economy	13700.00
0005432783629	12165	Economy	13700.00
0005432783217	12165	Economy	13700.00
0005435242903	12165	Economy	13700.00
0005435242885	12165	Economy	13700.00
0005432783365	12165	Economy	13700.00
0005432783135	12165	Economy	13700.00
0005432783498	12165	Economy	13700.00
0005432783471	12165	Economy	13700.00
0005435242907	12165	Economy	13700.00
0005435242891	12165	Economy	13700.00
0005432783573	12165	Economy	13700.00
0005432783392	12165	Economy	13700.00
0005435242901	12165	Economy	13700.00
0005435242893	12165	Economy	13700.00
0005435242888	12165	Economy	13700.00
0005432783823	15424	Business	41200.00
0005435242545	15424	Business	41200.00
0005432783818	15424	Business	41200.00
0005432783793	15424	Business	41200.00
0005432783781	15424	Business	41200.00
0005435242606	15424	Business	41200.00
0005435242679	15424	Business	41200.00
0005435242678	15424	Business	41200.00
0005435242628	15424	Business	41200.00
0005432783813	15424	Business	41200.00
0005435242577	15424	Business	41200.00
0005435242623	15424	Business	41200.00
0005432783785	15424	Economy	13700.00
0005432783792	15424	Economy	13700.00
0005435242666	15424	Economy	13700.00
0005435242533	15424	Economy	13700.00
0005435242559	15424	Economy	13700.00
0005432783802	15424	Economy	13700.00
0005432783784	15424	Economy	13700.00
0005435242698	15424	Economy	13700.00
0005432783816	15424	Economy	13700.00
0005432783797	15424	Economy	13700.00
0005435242634	15424	Economy	15100.00
0005432783786	15424	Economy	15100.00
0005435242546	15424	Economy	15100.00
0005432783817	15424	Economy	15100.00
0005432783829	15424	Economy	15100.00
0005432783800	15424	Economy	13700.00
0005435242633	15424	Economy	13700.00
0005432783811	15424	Economy	13700.00
0005435242727	15424	Economy	13700.00
0005432783819	15424	Economy	13700.00
0005432783827	15424	Economy	13700.00
0005432783782	15424	Economy	13700.00
0005432783776	15424	Economy	13700.00
0005432783806	15424	Economy	13700.00
0005432783828	15424	Economy	13700.00
0005435242620	15424	Economy	13700.00
0005432783789	15424	Economy	13700.00
0005435242649	15424	Economy	13700.00
0005435242600	15424	Economy	13700.00
0005432783812	15424	Economy	13700.00
0005435242573	15424	Economy	13700.00
0005435242581	15424	Economy	13700.00
0005432783808	15424	Economy	13700.00
0005432783824	15424	Economy	13700.00
0005432783794	15424	Economy	13700.00
0005432783826	15424	Economy	13700.00
0005435242591	15424	Economy	13700.00
0005432783783	15424	Economy	13700.00
0005432783801	15424	Economy	13700.00
0005432783780	15424	Economy	13700.00
0005432783791	15424	Economy	13700.00
0005435242595	15424	Economy	13700.00
0005435242594	15424	Economy	13700.00
0005432783798	15424	Economy	13700.00
0005432783820	15424	Economy	13700.00
0005432783777	15424	Economy	13700.00
0005432783807	15424	Economy	13700.00
0005432783787	15424	Economy	13700.00
0005435242599	15424	Economy	13700.00
0005432783815	15424	Economy	13700.00
0005432783825	15424	Economy	13700.00
0005432783799	15424	Economy	13700.00
0005435242505	15424	Economy	13700.00
0005432783803	15424	Economy	13700.00
0005435242653	15424	Economy	13700.00
0005432783805	15424	Economy	13700.00
0005432783821	15424	Economy	13700.00
0005432783814	15424	Economy	13700.00
0005432783810	15424	Economy	13700.00
0005432783788	15424	Economy	13700.00
0005432783779	15424	Economy	13700.00
0005435242626	15424	Economy	13700.00
0005432783822	15424	Economy	13700.00
0005435242508	15424	Economy	13700.00
0005432783804	15424	Economy	13700.00
0005435242672	15424	Economy	13700.00
0005432783795	15424	Economy	13700.00
0005435242648	15424	Economy	13700.00
0005432783790	15424	Economy	13700.00
0005435242509	15424	Economy	13700.00
0005432783809	15424	Economy	13700.00
0005435242598	15424	Economy	13700.00
0005435242534	15424	Economy	13700.00
0005435242654	15424	Economy	13700.00
0005432783778	15424	Economy	13700.00
0005435242697	15424	Economy	13700.00
0005432783796	15424	Economy	13700.00
0005435242580	15424	Economy	13700.00
0005434877691	10064	Business	49700.00
0005434877636	10064	Business	49700.00
0005434877480	10064	Business	49700.00
0005434877586	10064	Business	49700.00
0005434877337	10064	Business	49700.00
0005434877560	10064	Business	49700.00
0005434877318	10064	Business	49700.00
0005434877476	10064	Business	49700.00
0005434877357	10064	Business	49700.00
0005434877344	10064	Business	49700.00
0005434877718	10064	Business	49700.00
0005434877471	10064	Business	49700.00
0005434877531	10064	Business	49700.00
0005434877144	10064	Business	49700.00
0005434877682	10064	Business	49700.00
0005434877470	10064	Business	49700.00
0005434877231	10064	Business	49700.00
0005434877257	10064	Economy	16600.00
0005434877204	10064	Economy	16600.00
0005434877656	10064	Economy	16600.00
0005434877706	10064	Economy	16600.00
0005435913938	10064	Economy	16600.00
0005434877764	10064	Economy	16600.00
0005434877402	10064	Economy	16600.00
0005434877423	10064	Economy	16600.00
0005434877555	10064	Economy	16600.00
0005434877692	10064	Economy	16600.00
0005434877689	10064	Economy	16600.00
0005434877529	10064	Economy	16600.00
0005434877258	10064	Economy	18200.00
0005434877250	10064	Economy	18200.00
0005434877485	10064	Economy	16600.00
0005434877547	10064	Economy	16600.00
0005434877369	10064	Economy	16600.00
0005434877565	10064	Economy	16600.00
0005434877345	10064	Economy	16600.00
0005434877643	10064	Economy	16600.00
0005434877410	10064	Economy	16600.00
0005434758874	10064	Economy	16600.00
0005434877336	10064	Economy	16600.00
0005434877141	10064	Economy	16600.00
0005434877487	10064	Economy	16600.00
0005434877370	10064	Economy	16600.00
0005434877585	10064	Economy	16600.00
0005434877364	10064	Economy	16600.00
0005435913939	10064	Economy	16600.00
0005434877319	10064	Economy	16600.00
0005434758862	10064	Economy	16600.00
0005434877532	10064	Economy	16600.00
0005434877827	10064	Economy	16600.00
0005435913937	10064	Economy	16600.00
0005434877317	10064	Economy	16600.00
0005434758863	10064	Economy	16600.00
0005434877569	10064	Economy	16600.00
0005434877637	10064	Economy	16600.00
0005434877251	10064	Economy	16600.00
0005434877726	10064	Economy	16600.00
0005434877205	10064	Economy	16600.00
0005434877592	10064	Economy	16600.00
0005434910114	10064	Economy	16600.00
0005434877069	10064	Economy	16600.00
0005434877633	10064	Economy	16600.00
0005434877422	10064	Economy	16600.00
0005434758880	10064	Economy	16600.00
0005434877690	10064	Economy	16600.00
0005434876852	10064	Economy	16600.00
0005434758872	10064	Economy	16600.00
0005434876851	10064	Economy	16600.00
0005434877102	10064	Economy	16600.00
0005434877722	10064	Economy	16600.00
0005434878090	10064	Economy	16600.00
0005434877503	10064	Economy	16600.00
0005434877433	10064	Economy	16600.00
0005434877489	10064	Economy	16600.00
0005434877681	10064	Economy	16600.00
0005434877507	10064	Economy	16600.00
0005434877240	10064	Economy	16600.00
0005434877203	10064	Economy	16600.00
0005434877466	10064	Economy	16600.00
0005434877407	10064	Economy	16600.00
0005434877528	10064	Economy	16600.00
0005434877514	10064	Economy	16600.00
0005434877358	10064	Economy	16600.00
0005434877568	10064	Economy	16600.00
0005434877448	10064	Economy	16600.00
0005434877241	10064	Economy	16600.00
0005434877173	10064	Economy	16600.00
0005434877441	10064	Economy	16600.00
0005434878057	10064	Economy	16600.00
0005434877259	10064	Economy	16600.00
0005434877727	10064	Economy	16600.00
0005434877685	10064	Economy	16600.00
0005434877199	10064	Economy	16600.00
0005434877481	10064	Economy	16600.00
0005434758877	10064	Economy	16600.00
0005434878322	14607	Business	49700.00
0005434878354	14607	Business	49700.00
0005434878363	14607	Business	49700.00
0005434878341	14607	Business	49700.00
0005435913881	14607	Business	49700.00
0005434878304	14607	Business	49700.00
0005434878327	14607	Business	49700.00
0005434878382	14607	Business	49700.00
0005434758898	14607	Business	49700.00
0005434878302	14607	Business	49700.00
0005434878359	14607	Business	49700.00
0005434878321	14607	Business	49700.00
0005434878378	14607	Business	49700.00
0005434878352	14607	Business	49700.00
0005434878373	14607	Business	49700.00
0005434878318	14607	Business	49700.00
0005434878335	14607	Business	49700.00
0005434878301	14607	Economy	16600.00
0005434878329	14607	Economy	16600.00
0005434878344	14607	Economy	16600.00
0005434878368	14607	Economy	16600.00
0005434878336	14607	Economy	16600.00
0005434878343	14607	Economy	16600.00
0005434878366	14607	Economy	16600.00
0005434878351	14607	Economy	16600.00
0005434878383	14607	Economy	16600.00
0005434878361	14607	Economy	16600.00
0005434878331	14607	Economy	16600.00
0005434878338	14607	Economy	16600.00
0005434878334	14607	Economy	16600.00
0005434878367	14607	Economy	18200.00
0005434878333	14607	Economy	18200.00
0005434878349	14607	Economy	16600.00
0005435913886	14607	Economy	18200.00
0005434878314	14607	Economy	16600.00
0005434878388	14607	Economy	16600.00
0005434878308	14607	Economy	16600.00
0005434878305	14607	Economy	16600.00
0005434878369	14607	Economy	16600.00
0005434878387	14607	Economy	16600.00
0005435913888	14607	Economy	16600.00
0005434878375	14607	Economy	16600.00
0005434910088	14607	Economy	16600.00
0005434878386	14607	Economy	16600.00
0005434878347	14607	Economy	16600.00
0005434878362	14607	Economy	16600.00
0005434878325	14607	Economy	16600.00
0005434878340	14607	Economy	16600.00
0005435913880	14607	Economy	16600.00
0005434878360	14607	Economy	16600.00
0005434878330	14607	Economy	16600.00
0005434878311	14607	Economy	16600.00
0005434878310	14607	Economy	16600.00
0005434878374	14607	Economy	16600.00
0005435913872	14607	Economy	16600.00
0005434878339	14607	Economy	16600.00
0005434878320	14607	Economy	16600.00
0005434878376	14607	Economy	16600.00
0005434878299	14607	Economy	16600.00
0005434878319	14607	Economy	16600.00
0005434878345	14607	Economy	16600.00
0005434878300	14607	Economy	16600.00
0005434878379	14607	Economy	16600.00
0005434878309	14607	Economy	16600.00
0005434878356	14607	Economy	16600.00
0005435913887	14607	Economy	16600.00
0005434878328	14607	Economy	16600.00
0005434758896	14607	Economy	16600.00
0005434878372	14607	Economy	16600.00
0005434878337	14607	Economy	16600.00
0005434878365	14607	Economy	16600.00
0005434878346	14607	Economy	16600.00
0005434758895	14607	Economy	16600.00
0005434878384	14607	Economy	16600.00
0005434878312	14607	Economy	16600.00
0005434878317	14607	Economy	16600.00
0005434878313	14607	Economy	16600.00
0005434878385	14607	Economy	16600.00
0005434878353	14607	Economy	16600.00
0005434878357	14607	Economy	16600.00
0005434878355	14607	Economy	16600.00
0005434878315	14607	Economy	16600.00
0005434878371	14607	Economy	16600.00
0005434878380	14607	Economy	16600.00
0005434878326	14607	Economy	16600.00
0005434878324	14607	Economy	16600.00
0005434878381	14607	Economy	16600.00
0005434878307	14607	Economy	16600.00
0005434878377	14607	Economy	16600.00
0005434878316	14607	Economy	16600.00
0005434878342	14607	Economy	16600.00
0005434878323	14607	Economy	16600.00
0005434878364	14607	Economy	16600.00
0005434878332	14607	Economy	16600.00
0005434878303	14607	Economy	16600.00
0005434878358	14607	Economy	16600.00
0005434878389	14607	Economy	16600.00
0005434878306	14607	Economy	16600.00
0005434878350	14607	Economy	16600.00
0005434878348	14607	Economy	16600.00
0005434878370	14607	Economy	16600.00
0005434758897	14607	Economy	16600.00
0005434251930	9230	Economy	22400.00
0005435660145	9230	Economy	22400.00
0005434251931	9230	Economy	20300.00
0005434251894	9230	Economy	20300.00
0005435660150	9230	Economy	20300.00
0005435660147	9230	Economy	20300.00
0005435660151	9230	Economy	20300.00
0005434251895	9230	Economy	20300.00
0005434251892	9230	Economy	20300.00
0005434251887	9230	Economy	20300.00
0005435660149	9230	Economy	20300.00
0005435660146	9230	Economy	20300.00
0005435660152	9230	Economy	20300.00
0005434251867	9230	Economy	20300.00
0005435660154	9230	Economy	20300.00
0005435660148	9230	Economy	20300.00
0005434251904	9230	Economy	20300.00
0005435660155	9230	Economy	20300.00
0005434251868	9230	Economy	20300.00
0005435660153	9230	Economy	20300.00
0005435659998	24639	Economy	22400.00
0005435660081	24639	Economy	22400.00
0005434251970	24639	Economy	20300.00
0005435660082	24639	Economy	20300.00
0005435660074	24639	Economy	20300.00
0005434251972	24639	Economy	20300.00
0005435660038	24639	Economy	20300.00
0005435660018	24639	Economy	20300.00
0005434251979	24639	Economy	20300.00
0005434251973	24639	Economy	20300.00
0005435660075	24639	Economy	20300.00
0005435660087	24639	Economy	20300.00
0005434251977	24639	Economy	20300.00
0005435659997	24639	Economy	20300.00
0005435660079	24639	Economy	20300.00
0005435660017	24639	Economy	20300.00
0005434251971	24639	Economy	20300.00
0005435660040	24639	Economy	20300.00
0005435660060	24639	Economy	20300.00
0005435660080	24639	Economy	20300.00
0005434251974	24639	Economy	20300.00
0005435660072	24639	Economy	20300.00
0005435660073	24639	Economy	20300.00
0005434251978	24639	Economy	20300.00
0005435660071	24639	Economy	20300.00
0005434251976	24639	Economy	20300.00
0005434251975	24639	Economy	20300.00
0005435660039	24639	Economy	20300.00
0005433680599	2816	Business	33000.00
0005433680594	2816	Business	33000.00
0005433680610	2816	Business	33000.00
0005432222789	2816	Business	33000.00
0005432966756	2816	Business	33000.00
0005433680628	2816	Business	33000.00
0005433680607	2816	Business	33000.00
0005433680624	2816	Business	33000.00
0005433680620	2816	Business	33000.00
0005433680618	2816	Business	33000.00
0005432966689	2816	Business	33000.00
0005432222787	2816	Economy	11000.00
0005433680611	2816	Economy	11000.00
0005433680612	2816	Economy	11000.00
0005433680633	2816	Economy	11000.00
0005433680621	2816	Economy	11000.00
0005433680602	2816	Economy	11000.00
0005433680631	2816	Economy	11000.00
0005433680609	2816	Economy	11000.00
0005433680622	2816	Economy	12100.00
0005433680632	2816	Economy	12100.00
0005432966717	2816	Economy	12100.00
0005432966722	2816	Economy	11000.00
0005433680608	2816	Economy	11000.00
0005432966804	2816	Economy	11000.00
0005433680604	2816	Economy	11000.00
0005432966754	2816	Economy	11000.00
0005433680596	2816	Economy	11000.00
0005433680605	2816	Economy	11000.00
0005433680626	2816	Economy	11000.00
0005433680606	2816	Economy	11000.00
0005433680591	2816	Economy	11000.00
0005432966757	2816	Economy	11000.00
0005432222788	2816	Economy	11000.00
0005432966779	2816	Economy	11000.00
0005433680619	2816	Economy	11000.00
0005432966690	2816	Economy	11000.00
0005433680595	2816	Economy	11000.00
0005432222786	2816	Economy	11000.00
0005433680593	2816	Economy	11000.00
0005433680635	2816	Economy	11000.00
0005432966800	2816	Economy	11000.00
0005433680627	2816	Economy	11000.00
0005432966714	2816	Economy	11000.00
0005432966688	2816	Economy	11000.00
0005433680597	2816	Economy	11000.00
0005432966713	2816	Economy	11000.00
0005433680625	2816	Economy	11000.00
0005433680636	2816	Economy	11000.00
0005433680592	2816	Economy	11000.00
0005432966733	2816	Economy	11000.00
0005433680598	2816	Economy	11000.00
0005432966738	2816	Economy	11000.00
0005433680630	2816	Economy	11000.00
0005433680603	2816	Economy	11000.00
0005432966715	2816	Economy	11000.00
0005433680617	2816	Economy	11000.00
0005432966799	2816	Economy	11000.00
0005433680589	2816	Economy	11000.00
0005433680616	2816	Economy	11000.00
0005433680613	2816	Economy	11000.00
0005432966615	2816	Economy	11000.00
0005432966827	2816	Economy	11000.00
0005432966739	2816	Economy	11000.00
0005433680590	2816	Economy	11000.00
0005433680615	2816	Economy	11000.00
0005433680623	2816	Economy	11000.00
0005432966718	2816	Economy	11000.00
0005432966755	2816	Economy	11000.00
0005433680614	2816	Economy	11000.00
0005433684421	2816	Economy	11000.00
0005433680629	2816	Economy	11000.00
0005432966743	2816	Economy	11000.00
0005433680601	2816	Economy	11000.00
0005433680600	2816	Economy	11000.00
0005433680634	2816	Economy	11000.00
0005432966616	2816	Economy	11000.00
0005432966780	2816	Economy	11000.00
0005433680390	29162	Business	33000.00
0005433680263	29162	Business	33000.00
0005432966958	29162	Business	33000.00
0005433680373	29162	Business	33000.00
0005432966957	29162	Business	33000.00
0005432966959	29162	Business	33000.00
0005433680267	29162	Business	33000.00
0005433680189	29162	Business	33000.00
0005433680385	29162	Business	33000.00
0005433680487	29162	Economy	11000.00
0005433680374	29162	Economy	11000.00
0005433680376	29162	Economy	11000.00
0005433680216	29162	Economy	11000.00
0005433680206	29162	Economy	11000.00
0005433680325	29162	Economy	11000.00
0005432966954	29162	Economy	11000.00
0005433680048	29162	Economy	11000.00
0005432966974	29162	Economy	11000.00
0005432966966	29162	Economy	12100.00
0005433679939	29162	Economy	12100.00
0005433680296	29162	Economy	12100.00
0005432966973	29162	Economy	12100.00
0005432966952	29162	Economy	11000.00
0005432966970	29162	Economy	11000.00
0005433680326	29162	Economy	11000.00
0005432966965	29162	Economy	11000.00
0005432966960	29162	Economy	11000.00
0005432005217	29162	Economy	11000.00
0005433687679	29162	Economy	11000.00
0005433680140	29162	Economy	11000.00
0005433684402	29162	Economy	11000.00
0005432005215	29162	Economy	11000.00
0005433680338	29162	Economy	11000.00
0005433680340	29162	Economy	11000.00
0005432966967	29162	Economy	11000.00
0005432966953	29162	Economy	11000.00
0005432966968	29162	Economy	11000.00
0005433680188	29162	Economy	11000.00
0005433680141	29162	Economy	11000.00
0005432966963	29162	Economy	11000.00
0005433684401	29162	Economy	11000.00
0005432005216	29162	Economy	11000.00
0005433684399	29162	Economy	11000.00
0005433680264	29162	Economy	11000.00
0005433687678	29162	Economy	11000.00
0005433680065	29162	Economy	11000.00
0005433684396	29162	Economy	11000.00
0005432966961	29162	Economy	11000.00
0005433680339	29162	Economy	11000.00
0005432966950	29162	Economy	11000.00
0005432966949	29162	Economy	11000.00
0005433679986	29162	Economy	11000.00
0005433680209	29162	Economy	11000.00
0005432966972	29162	Economy	11000.00
0005433680183	29162	Economy	11000.00
0005433680300	29162	Economy	11000.00
0005433680173	29162	Economy	11000.00
0005433680244	29162	Economy	11000.00
0005433680406	29162	Economy	11000.00
0005433680257	29162	Economy	11000.00
0005433680230	29162	Economy	11000.00
0005433679769	29162	Economy	11000.00
0005432966975	29162	Economy	11000.00
0005432966956	29162	Economy	11000.00
0005432966951	29162	Economy	11000.00
0005433680176	29162	Economy	11000.00
0005433680269	29162	Economy	11000.00
0005433680215	29162	Economy	11000.00
0005433680154	29162	Economy	11000.00
0005433680386	29162	Economy	11000.00
0005433684395	29162	Economy	11000.00
0005432966971	29162	Economy	11000.00
0005432966964	29162	Economy	11000.00
0005433680155	29162	Economy	11000.00
0005433680469	29162	Economy	11000.00
0005432966969	29162	Economy	11000.00
0005433680375	29162	Economy	11000.00
0005433680103	29162	Economy	11000.00
0005432966955	29162	Economy	11000.00
0005432966962	29162	Economy	11000.00
0005433614696	9303	Business	132900.00
0005433577814	9303	Business	132900.00
0005433577820	9303	Business	132900.00
0005434163560	9303	Business	132900.00
0005433633833	9303	Business	132900.00
0005433614670	9303	Business	132900.00
0005433633818	9303	Business	132900.00
0005433633834	9303	Business	132900.00
0005433614682	9303	Business	132900.00
0005433614690	9303	Business	132900.00
0005433614721	9303	Business	132900.00
0005433614720	9303	Business	132900.00
0005433633832	9303	Business	132900.00
0005433633817	9303	Business	132900.00
0005433633820	9303	Business	132900.00
0005434152776	9303	Business	132900.00
0005434152778	9303	Business	132900.00
0005433577816	9303	Business	132900.00
0005433614729	9303	Business	132900.00
0005433633830	9303	Business	132900.00
0005433614725	9303	Business	132900.00
0005433614715	9303	Business	132900.00
0005433614701	9303	Business	132900.00
0005433614674	9303	Business	132900.00
0005433614700	9303	Business	132900.00
0005433614667	9303	Economy	48700.00
0005433614663	9303	Economy	48700.00
0005433614714	9303	Economy	48700.00
0005434163584	9303	Economy	48700.00
0005433614723	9303	Economy	48700.00
0005433614726	9303	Economy	48700.00
0005432755077	9303	Economy	44300.00
0005433614666	9303	Economy	44300.00
0005433614680	9303	Economy	44300.00
0005434163564	9303	Economy	44300.00
0005433633839	9303	Economy	44300.00
0005432756849	9303	Economy	44300.00
0005433614716	9303	Economy	44300.00
0005433614677	9303	Economy	44300.00
0005433614698	9303	Economy	44300.00
0005433633827	9303	Economy	44300.00
0005434272173	9303	Economy	44300.00
0005433633840	9303	Economy	44300.00
0005433614727	9303	Economy	44300.00
0005433614685	9303	Economy	44300.00
0005433614718	9303	Economy	44300.00
0005432145111	9303	Economy	44300.00
0005434269085	9303	Economy	44300.00
0005433614684	9303	Economy	44300.00
0005433614733	9303	Economy	44300.00
0005432145112	9303	Economy	44300.00
0005432756850	9303	Economy	44300.00
0005433614661	9303	Economy	44300.00
0005433577824	9303	Economy	44300.00
0005433614703	9303	Economy	44300.00
0005433633835	9303	Economy	44300.00
0005433614712	9303	Economy	44300.00
0005434163585	9303	Economy	44300.00
0005432755079	9303	Economy	44300.00
0005433633812	9303	Economy	44300.00
0005433614681	9303	Economy	44300.00
0005433614708	9303	Economy	44300.00
0005433633838	9303	Economy	44300.00
0005433614731	9303	Economy	44300.00
0005434163576	9303	Economy	44300.00
0005434163534	9303	Economy	44300.00
0005433577815	9303	Economy	44300.00
0005433633829	9303	Economy	44300.00
0005433614711	9303	Economy	44300.00
0005433614717	9303	Economy	44300.00
0005433614697	9303	Economy	44300.00
0005433614660	9303	Economy	44300.00
0005433633836	9303	Economy	44300.00
0005433614694	9303	Economy	44300.00
0005433577818	9303	Economy	44300.00
0005433614722	9303	Economy	44300.00
0005433614699	9303	Economy	44300.00
0005433614659	9303	Economy	44300.00
0005433614705	9303	Economy	44300.00
0005433614692	9303	Economy	44300.00
0005432145113	9303	Economy	44300.00
0005433614665	9303	Economy	44300.00
0005433614719	9303	Economy	44300.00
0005433633825	9303	Economy	44300.00
0005433614693	9303	Economy	48700.00
0005433614704	9303	Economy	48700.00
0005432756851	9303	Economy	48700.00
0005433614671	9303	Economy	48700.00
0005433614669	9303	Economy	44300.00
0005434163536	9303	Economy	44300.00
0005433614676	9303	Economy	44300.00
0005433614707	9303	Economy	48700.00
0005433577822	9303	Economy	44300.00
0005433614702	9303	Economy	44300.00
0005433577821	9303	Economy	44300.00
0005433633814	9303	Economy	44300.00
0005433614732	9303	Economy	44300.00
0005433614689	9303	Economy	44300.00
0005433633816	9303	Economy	44300.00
0005433633828	9303	Economy	44300.00
0005433614675	9303	Economy	44300.00
0005433633823	9303	Economy	44300.00
0005433614709	9303	Economy	44300.00
0005433633809	9303	Economy	44300.00
0005434163583	9303	Economy	44300.00
0005434152774	9303	Economy	44300.00
0005433614730	9303	Economy	44300.00
0005433614683	9303	Economy	44300.00
0005433633821	9303	Economy	44300.00
0005433633837	9303	Economy	44300.00
0005433577812	9303	Economy	44300.00
0005433633826	9303	Economy	44300.00
0005432755076	9303	Economy	44300.00
0005433577813	9303	Economy	44300.00
0005434163573	9303	Economy	44300.00
0005433614679	9303	Economy	44300.00
0005433614686	9303	Economy	44300.00
0005433633815	9303	Economy	44300.00
0005433614688	9303	Economy	44300.00
0005433614713	9303	Economy	44300.00
0005433614662	9303	Economy	44300.00
0005433633810	9303	Economy	44300.00
0005433633824	9303	Economy	44300.00
0005433614724	9303	Economy	44300.00
0005433614695	9303	Economy	44300.00
0005433614706	9303	Economy	44300.00
0005433614673	9303	Economy	44300.00
0005433633807	9303	Economy	44300.00
0005434152777	9303	Economy	44300.00
0005433614691	9303	Economy	44300.00
0005433633831	9303	Economy	44300.00
0005434163582	9303	Economy	44300.00
0005433614678	9303	Economy	44300.00
0005433577819	9303	Economy	44300.00
0005433633811	9303	Economy	44300.00
0005433633808	9303	Economy	44300.00
0005433614710	9303	Economy	44300.00
0005433614672	9303	Economy	44300.00
0005433633813	9303	Economy	44300.00
0005433633819	9303	Economy	44300.00
0005433614664	9303	Economy	44300.00
0005433633822	9303	Economy	44300.00
0005434163563	9303	Economy	44300.00
0005433614687	9303	Economy	44300.00
0005433577817	9303	Economy	44300.00
0005433614668	9303	Economy	44300.00
0005432756852	9303	Economy	44300.00
0005432755078	9303	Economy	44300.00
0005433614728	9303	Economy	44300.00
0005433577823	9303	Economy	44300.00
0005433614002	25208	Business	132900.00
0005433633513	25208	Business	132900.00
0005434163621	25208	Business	132900.00
0005433577649	25208	Business	132900.00
0005433633663	25208	Business	132900.00
0005433633462	25208	Business	132900.00
0005433614006	25208	Business	132900.00
0005433577754	25208	Business	132900.00
0005433613941	25208	Business	132900.00
0005433633423	25208	Business	132900.00
0005433633541	25208	Business	132900.00
0005433613765	25208	Business	132900.00
0005433613896	25208	Business	132900.00
0005433633526	25208	Business	132900.00
0005433577710	25208	Business	132900.00
0005433633624	25208	Business	132900.00
0005434163619	25208	Business	132900.00
0005433614233	25208	Business	132900.00
0005433577741	25208	Business	132900.00
0005433613871	25208	Business	132900.00
0005433633537	25208	Business	132900.00
0005433613994	25208	Business	132900.00
0005433613942	25208	Economy	48700.00
0005433633631	25208	Economy	48700.00
0005433614094	25208	Economy	48700.00
0005433633466	25208	Economy	48700.00
0005433577742	25208	Economy	44300.00
0005433614125	25208	Economy	44300.00
0005433577755	25208	Economy	44300.00
0005433613564	25208	Economy	44300.00
0005433633463	25208	Economy	44300.00
0005434163625	25208	Economy	44300.00
0005433613698	25208	Economy	44300.00
0005433614499	25208	Economy	44300.00
0005434163620	25208	Economy	44300.00
0005433633477	25208	Economy	44300.00
0005433613804	25208	Economy	44300.00
0005433633432	25208	Economy	44300.00
0005433577687	25208	Economy	44300.00
0005433577716	25208	Economy	44300.00
0005433614046	25208	Economy	44300.00
0005433633530	25208	Economy	44300.00
0005433633525	25208	Economy	44300.00
0005433577694	25208	Economy	44300.00
0005434163618	25208	Economy	44300.00
0005433613565	25208	Economy	44300.00
0005433613815	25208	Economy	44300.00
0005433614022	25208	Economy	44300.00
0005435854057	25208	Economy	44300.00
0005433633485	25208	Economy	44300.00
0005433614279	25208	Economy	44300.00
0005433614187	25208	Economy	44300.00
0005433633401	25208	Economy	44300.00
0005434273075	25208	Economy	44300.00
0005433613563	25208	Economy	44300.00
0005433577696	25208	Economy	44300.00
0005433614416	25208	Economy	44300.00
0005433633449	25208	Economy	44300.00
0005433614086	25208	Economy	44300.00
0005433633654	25208	Economy	44300.00
0005435854059	25208	Economy	44300.00
0005434272192	25208	Economy	44300.00
0005433614159	25208	Economy	44300.00
0005434163617	25208	Economy	44300.00
0005433614093	25208	Economy	44300.00
0005433633389	25208	Economy	44300.00
0005433633656	25208	Economy	44300.00
0005433614234	25208	Economy	44300.00
0005433633465	25208	Economy	44300.00
0005433613964	25208	Economy	48700.00
0005433614064	25208	Economy	48700.00
0005433614127	25208	Economy	48700.00
0005433613991	25208	Economy	44300.00
0005433577648	25208	Economy	44300.00
0005433633467	25208	Economy	44300.00
0005434273077	25208	Economy	44300.00
0005433613990	25208	Economy	44300.00
0005433614181	25208	Economy	44300.00
0005433613961	25208	Economy	44300.00
0005433633531	25208	Economy	44300.00
0005433614038	25208	Economy	44300.00
0005433614208	25208	Economy	44300.00
0005433614182	25208	Economy	44300.00
0005433633698	25208	Economy	44300.00
0005433577652	25208	Economy	44300.00
0005434163622	25208	Economy	44300.00
0005434273076	25208	Economy	44300.00
0005433633650	25208	Economy	44300.00
0005434163623	25208	Economy	44300.00
0005433577643	25208	Economy	44300.00
0005433614130	25208	Economy	44300.00
0005433614260	25208	Economy	44300.00
0005435854060	25208	Economy	44300.00
0005434163624	25208	Economy	44300.00
0005433614316	25208	Economy	44300.00
0005433614085	25208	Economy	44300.00
0005433577713	25208	Economy	44300.00
0005433633484	25208	Economy	44300.00
0005433614298	25208	Economy	44300.00
0005433614297	25208	Economy	44300.00
0005433614188	25208	Economy	44300.00
0005433633514	25208	Economy	44300.00
0005433614076	25208	Economy	44300.00
0005433633486	25208	Economy	44300.00
0005433633655	25208	Economy	44300.00
0005433613848	25208	Economy	44300.00
0005433633388	25208	Economy	44300.00
0005433614084	25208	Economy	44300.00
0005433613895	25208	Economy	44300.00
0005433613972	25208	Economy	44300.00
0005433613832	25208	Economy	44300.00
0005433613921	25208	Economy	44300.00
0005435854058	25208	Economy	44300.00
0005433577644	25208	Economy	44300.00
0005433614347	25208	Economy	44300.00
0005434163616	25208	Economy	44300.00
0005433614228	25208	Economy	44300.00
0005433614116	25208	Economy	44300.00
0005433614207	25208	Economy	44300.00
0005433633649	25208	Economy	44300.00
0005433613996	25208	Economy	44300.00
0005433613814	25208	Economy	44300.00
0005433613816	25208	Economy	44300.00
0005433577695	25208	Economy	44300.00
0005435986771	4252	Business	193100.00
0005435986778	4252	Business	193100.00
0005435856166	4252	Business	193100.00
0005434271293	4252	Business	193100.00
0005435947087	4252	Business	193100.00
0005432184954	4252	Business	193100.00
0005435947102	4252	Economy	70800.00
0005435986776	4252	Economy	64400.00
0005432184952	4252	Economy	64400.00
0005435947136	4252	Economy	64400.00
0005435787332	4252	Economy	64400.00
0005435787333	4252	Economy	64400.00
0005435947188	4252	Economy	64400.00
0005435986775	4252	Economy	64400.00
0005435947121	4252	Economy	64400.00
0005435947086	4252	Economy	64400.00
0005435986777	4252	Economy	64400.00
0005435856151	4252	Economy	64400.00
0005435986780	4252	Economy	64400.00
0005435947151	4252	Economy	64400.00
0005435947211	4252	Economy	64400.00
0005435947137	4252	Economy	64400.00
0005435947210	4252	Economy	64400.00
0005435947144	4252	Economy	64400.00
0005435787330	4252	Economy	64400.00
0005432571295	4252	Economy	64400.00
0005434271294	4252	Economy	64400.00
0005435947175	4252	Economy	64400.00
0005435947145	4252	Economy	70800.00
0005435947105	4252	Economy	70800.00
0005435947158	4252	Economy	70800.00
0005435947122	4252	Economy	64400.00
0005435787331	4252	Economy	64400.00
0005435986779	4252	Economy	64400.00
0005432571302	4252	Economy	64400.00
0005435947118	4252	Economy	64400.00
0005435947103	4252	Economy	64400.00
0005432184955	4252	Economy	64400.00
0005435986774	4252	Economy	64400.00
0005435986773	4252	Economy	64400.00
0005432571277	4252	Economy	64400.00
0005435986772	4252	Economy	64400.00
0005435947114	4252	Economy	64400.00
0005435947159	4252	Economy	64400.00
0005432184953	4252	Economy	64400.00
0005435787358	26572	Business	193100.00
0005435856211	26572	Business	193100.00
0005435947270	26572	Economy	64400.00
0005435947269	26572	Economy	64400.00
0005435856208	26572	Economy	64400.00
0005435856209	26572	Economy	64400.00
0005435947266	26572	Economy	64400.00
0005435947273	26572	Economy	64400.00
0005435947274	26572	Economy	64400.00
0005435947277	26572	Economy	64400.00
0005432571328	26572	Economy	64400.00
0005432571330	26572	Economy	64400.00
0005435787359	26572	Economy	64400.00
0005435856212	26572	Economy	64400.00
0005435986696	26572	Economy	64400.00
0005435856210	26572	Economy	64400.00
0005435986702	26572	Economy	64400.00
0005432571327	26572	Economy	64400.00
0005435947272	26572	Economy	70800.00
0005435947276	26572	Economy	64400.00
0005435787357	26572	Economy	70800.00
0005435947265	26572	Economy	64400.00
0005435947267	26572	Economy	64400.00
0005435947268	26572	Economy	64400.00
0005435947271	26572	Economy	64400.00
0005435947275	26572	Economy	64400.00
0005435947279	26572	Economy	64400.00
0005435947278	26572	Economy	64400.00
0005432571329	26572	Economy	64400.00
0005432948255	335	Business	21500.00
0005432948231	335	Business	21500.00
0005432948133	335	Business	21500.00
0005433569150	335	Business	21500.00
0005433134092	335	Business	21500.00
0005433569147	335	Business	21500.00
0005432948183	335	Business	21500.00
0005432948085	335	Business	21500.00
0005433074413	335	Business	21500.00
0005432238943	335	Business	21500.00
0005432948106	335	Business	21500.00
0005433569165	335	Business	21500.00
0005433569169	335	Business	21500.00
0005433074539	335	Business	21500.00
0005433569168	335	Business	21500.00
0005432948122	335	Business	21500.00
0005433569152	335	Business	21500.00
0005433074537	335	Business	21500.00
0005433569174	335	Business	21500.00
0005433569160	335	Business	21500.00
0005433074624	335	Business	21500.00
0005432948107	335	Business	21500.00
0005433569149	335	Business	21500.00
0005432238941	335	Business	21500.00
0005432948050	335	Economy	7900.00
0005433134093	335	Economy	7900.00
0005432948146	335	Economy	7900.00
0005432948019	335	Economy	7900.00
0005433569131	335	Economy	7900.00
0005433569171	335	Economy	7200.00
0005432948172	335	Economy	7200.00
0005433569138	335	Economy	7200.00
0005433569178	335	Economy	7200.00
0005433074538	335	Economy	7200.00
0005433569167	335	Economy	7200.00
0005432948289	335	Economy	7200.00
0005433129245	335	Economy	7200.00
0005433569156	335	Economy	7200.00
0005432947961	335	Economy	7200.00
0005432948232	335	Economy	7200.00
0005432948040	335	Economy	7200.00
0005432948111	335	Economy	7200.00
0005433074406	335	Economy	7200.00
0005433569154	335	Economy	7200.00
0005433569177	335	Economy	7200.00
0005433569163	335	Economy	7200.00
0005433074528	335	Economy	7200.00
0005432947989	335	Economy	7200.00
0005433569166	335	Economy	7200.00
0005432948042	335	Economy	7200.00
0005433074540	335	Economy	7200.00
0005433074623	335	Economy	7200.00
0005433569126	335	Economy	7200.00
0005433074505	335	Economy	7200.00
0005433569133	335	Economy	7200.00
0005433569151	335	Economy	7200.00
0005432238944	335	Economy	7200.00
0005433074530	335	Economy	7200.00
0005433074547	335	Economy	7200.00
0005433569170	335	Economy	7200.00
0005432947827	335	Economy	7200.00
0005433569158	335	Economy	7200.00
0005433569135	335	Economy	7200.00
0005433569129	335	Economy	7200.00
0005433074460	335	Economy	7200.00
0005433569125	335	Economy	7200.00
0005432947974	335	Economy	7200.00
0005433074487	335	Economy	7200.00
0005433569139	335	Economy	7200.00
0005433569176	335	Economy	7200.00
0005433569130	335	Economy	7200.00
0005433569181	335	Economy	7200.00
0005432238942	335	Economy	7200.00
0005433569136	335	Economy	7200.00
0005433074545	335	Economy	7200.00
0005433569137	335	Economy	7200.00
0005433569128	335	Economy	7200.00
0005432948280	335	Economy	7200.00
0005432948225	335	Economy	7200.00
0005433074524	335	Economy	7200.00
0005432948248	335	Economy	7900.00
0005432948216	335	Economy	7900.00
0005432948171	335	Economy	7900.00
0005432238945	335	Economy	7200.00
0005432948262	335	Economy	7200.00
0005433569140	335	Economy	7200.00
0005432947938	335	Economy	7900.00
0005433074514	335	Economy	7200.00
0005433074531	335	Economy	7200.00
0005432948281	335	Economy	7200.00
0005433569161	335	Economy	7200.00
0005433569175	335	Economy	7200.00
0005433074523	335	Economy	7200.00
0005433569162	335	Economy	7200.00
0005432948194	335	Economy	7200.00
0005433134094	335	Economy	7200.00
0005433569148	335	Economy	7200.00
0005433569144	335	Economy	7200.00
0005432948081	335	Economy	7200.00
0005432948250	335	Economy	7200.00
0005432948217	335	Economy	7200.00
0005432948110	335	Economy	7200.00
0005433074407	335	Economy	7200.00
0005433074527	335	Economy	7200.00
0005432948043	335	Economy	7200.00
0005433074409	335	Economy	7200.00
0005433569132	335	Economy	7200.00
0005432948145	335	Economy	7200.00
0005433074599	335	Economy	7200.00
0005433569159	335	Economy	7200.00
0005433134108	335	Economy	7200.00
0005433569155	335	Economy	7200.00
0005433569172	335	Economy	7200.00
0005433129244	335	Economy	7200.00
0005432948073	335	Economy	7200.00
0005433569143	335	Economy	7200.00
0005433569157	335	Economy	7200.00
0005432948121	335	Economy	7200.00
0005432948254	335	Economy	7200.00
0005432947973	335	Economy	7200.00
0005433569146	335	Economy	7200.00
0005433074553	335	Economy	7200.00
0005433569142	335	Economy	7200.00
0005432948177	335	Economy	7200.00
0005432948105	335	Economy	7200.00
0005433074548	335	Economy	7200.00
0005433074526	335	Economy	7200.00
0005433569127	335	Economy	7200.00
0005433569179	335	Economy	7200.00
0005433569153	335	Economy	7200.00
0005433569124	335	Economy	7200.00
0005432947960	335	Economy	7200.00
0005433569173	335	Economy	7200.00
0005433569145	335	Economy	7200.00
0005433569164	335	Economy	7200.00
0005433569141	335	Economy	7200.00
0005433569180	335	Economy	7200.00
0005432948181	335	Economy	7200.00
0005433074513	335	Economy	7200.00
0005432947972	335	Economy	7200.00
0005432948292	335	Economy	7200.00
0005432948182	335	Economy	7200.00
0005433569134	335	Economy	7200.00
0005433568228	11563	Business	21500.00
0005433568492	11563	Business	21500.00
0005433568537	11563	Business	21500.00
0005432192324	11563	Business	21500.00
0005433074742	11563	Business	21500.00
0005433074728	11563	Business	21500.00
0005433074749	11563	Business	21500.00
0005432948495	11563	Business	21500.00
0005433074729	11563	Business	21500.00
0005433134143	11563	Business	21500.00
0005433074731	11563	Business	21500.00
0005432948491	11563	Business	21500.00
0005433074743	11563	Business	21500.00
0005433134140	11563	Business	21500.00
0005433568322	11563	Business	21500.00
0005433074723	11563	Business	21500.00
0005432948494	11563	Business	21500.00
0005433568493	11563	Business	21500.00
0005433568302	11563	Business	21500.00
0005432948489	11563	Business	21500.00
0005432948483	11563	Business	21500.00
0005433568502	11563	Business	21500.00
0005433568466	11563	Business	21500.00
0005433568465	11563	Business	21500.00
0005433568414	11563	Business	21500.00
0005433568425	11563	Economy	7900.00
0005432948481	11563	Economy	7900.00
0005433074736	11563	Economy	7900.00
0005432948509	11563	Economy	7900.00
0005433134141	11563	Economy	7200.00
0005433131712	11563	Economy	7200.00
0005432948504	11563	Economy	7200.00
0005433074751	11563	Economy	7200.00
0005433131713	11563	Economy	7200.00
0005433568191	11563	Economy	7200.00
0005433074732	11563	Economy	7200.00
0005433568546	11563	Economy	7200.00
0005432948480	11563	Economy	7200.00
0005432948485	11563	Economy	7200.00
0005433568151	11563	Economy	7200.00
0005433074737	11563	Economy	7200.00
0005433568488	11563	Economy	7200.00
0005433074724	11563	Economy	7200.00
0005432948478	11563	Economy	7200.00
0005432948513	11563	Economy	7200.00
0005433568558	11563	Economy	7200.00
0005433074727	11563	Economy	7200.00
0005433568467	11563	Economy	7200.00
0005432948511	11563	Economy	7200.00
0005432948476	11563	Economy	7200.00
0005433134144	11563	Economy	7200.00
0005433568268	11563	Economy	7200.00
0005433074748	11563	Economy	7200.00
0005432948484	11563	Economy	7200.00
0005432948503	11563	Economy	7200.00
0005432948488	11563	Economy	7200.00
0005432948499	11563	Economy	7200.00
0005433568531	11563	Economy	7200.00
0005432948497	11563	Economy	7200.00
0005433568451	11563	Economy	7200.00
0005433568254	11563	Economy	7200.00
0005433568503	11563	Economy	7200.00
0005433568520	11563	Economy	7200.00
0005433568363	11563	Economy	7200.00
0005433568438	11563	Economy	7200.00
0005432948479	11563	Economy	7200.00
0005433131714	11563	Economy	7200.00
0005432948472	11563	Economy	7200.00
0005433568519	11563	Economy	7200.00
0005433074730	11563	Economy	7200.00
0005432948474	11563	Economy	7200.00
0005433074733	11563	Economy	7200.00
0005434087918	11563	Economy	7200.00
0005433074734	11563	Economy	7200.00
0005433929858	11563	Economy	7200.00
0005433568603	11563	Economy	7200.00
0005433074722	11563	Economy	7200.00
0005433074739	11563	Economy	7200.00
0005433074738	11563	Economy	7200.00
0005433074726	11563	Economy	7900.00
0005433568382	11563	Economy	7900.00
0005433074740	11563	Economy	7900.00
0005433568494	11563	Economy	7900.00
0005433568532	11563	Economy	7200.00
0005432948477	11563	Economy	7200.00
0005433568604	11563	Economy	7200.00
0005432948507	11563	Economy	7900.00
0005433568258	11563	Economy	7200.00
0005433074746	11563	Economy	7200.00
0005433568190	11563	Economy	7200.00
0005433134142	11563	Economy	7200.00
0005433568530	11563	Economy	7200.00
0005433568518	11563	Economy	7200.00
0005433568432	11563	Economy	7200.00
0005433074725	11563	Economy	7200.00
0005433074744	11563	Economy	7200.00
0005433568346	11563	Economy	7200.00
0005432948512	11563	Economy	7200.00
0005433568550	11563	Economy	7200.00
0005433568325	11563	Economy	7200.00
0005433568545	11563	Economy	7200.00
0005432948498	11563	Economy	7200.00
0005433074750	11563	Economy	7200.00
0005432948496	11563	Economy	7200.00
0005432948501	11563	Economy	7200.00
0005433074741	11563	Economy	7200.00
0005432948490	11563	Economy	7200.00
0005432192322	11563	Economy	7200.00
0005433568498	11563	Economy	7200.00
0005433568347	11563	Economy	7200.00
0005433568452	11563	Economy	7200.00
0005432948493	11563	Economy	7200.00
0005432948505	11563	Economy	7200.00
0005432948502	11563	Economy	7200.00
0005433568453	11563	Economy	7200.00
0005433074735	11563	Economy	7200.00
0005433568383	11563	Economy	7200.00
0005432948508	11563	Economy	7200.00
0005433568415	11563	Economy	7200.00
0005432948475	11563	Economy	7200.00
0005433568257	11563	Economy	7200.00
0005432948487	11563	Economy	7200.00
0005433568617	11563	Economy	7200.00
0005433568559	11563	Economy	7200.00
0005433568454	11563	Economy	7200.00
0005433568490	11563	Economy	7200.00
0005433568495	11563	Economy	7200.00
0005432948506	11563	Economy	7200.00
0005433568666	11563	Economy	7200.00
0005432948473	11563	Economy	7200.00
0005432948486	11563	Economy	7200.00
0005433568087	11563	Economy	7200.00
0005432948482	11563	Economy	7200.00
0005433568536	11563	Economy	7200.00
0005432948492	11563	Economy	7200.00
0005433568557	11563	Economy	7200.00
0005432192323	11563	Economy	7200.00
0005432948500	11563	Economy	7200.00
0005433131711	11563	Economy	7200.00
0005433074745	11563	Economy	7200.00
0005433568539	11563	Economy	7200.00
0005433568219	11563	Economy	7200.00
0005433074747	11563	Economy	7200.00
0005432948510	11563	Economy	7200.00
0005433568670	11563	Economy	7200.00
0005433568242	11563	Economy	7200.00
0005433074721	11563	Economy	7200.00
0005433568227	11563	Economy	7200.00
0005433817473	10056	Economy	6300.00
0005434732955	10056	Economy	6300.00
0005434732957	10056	Economy	6300.00
0005434732958	10056	Economy	6300.00
0005433817475	10056	Economy	6300.00
0005433817474	10056	Economy	6300.00
0005433817476	10056	Economy	6300.00
0005433817477	10056	Economy	6300.00
0005433817442	13924	Economy	6300.00
0005433817421	13924	Economy	6300.00
0005433817453	13924	Economy	6300.00
0005433817452	13924	Economy	6300.00
0005433817419	13924	Economy	6300.00
0005434732984	13924	Economy	6300.00
0005434732983	13924	Economy	6300.00
0005434732985	13924	Economy	6300.00
0005433817420	13924	Economy	6300.00
0005433817440	13924	Economy	6300.00
0005433817454	13924	Economy	6300.00
0005435982359	2332	Business	184500.00
0005435982350	2332	Business	184500.00
0005435982346	2332	Business	184500.00
0005432984854	2332	Business	184500.00
0005433434422	2332	Business	184500.00
0005432984953	2332	Business	184500.00
0005433754282	2332	Business	184500.00
0005433766643	2332	Business	184500.00
0005432655553	2332	Business	184500.00
0005432984753	2332	Business	184500.00
0005432300269	2332	Business	184500.00
0005433764682	2332	Business	184500.00
0005435982385	2332	Business	184500.00
0005433754296	2332	Business	184500.00
0005433754281	2332	Business	184500.00
0005432226064	2332	Business	184500.00
0005435982364	2332	Business	184500.00
0005435982391	2332	Business	184500.00
0005435982368	2332	Business	184500.00
0005435982352	2332	Business	184500.00
0005432984830	2332	Business	184500.00
0005432984870	2332	Business	184500.00
0005433434346	2332	Business	184500.00
0005435982379	2332	Business	184500.00
0005433754305	2332	Business	184500.00
0005433754280	2332	Business	184500.00
0005432984796	2332	Business	184500.00
0005433754291	2332	Business	184500.00
0005433434486	2332	Economy	67700.00
0005432984710	2332	Business	184500.00
0005433754309	2332	Economy	67700.00
0005433754289	2332	Economy	67700.00
0005435982369	2332	Economy	67700.00
0005435982343	2332	Economy	61500.00
0005432984859	2332	Economy	61500.00
0005433434423	2332	Economy	61500.00
0005435982367	2332	Economy	61500.00
0005432655547	2332	Economy	61500.00
0005432655557	2332	Economy	61500.00
0005432300272	2332	Economy	61500.00
0005432984906	2332	Economy	61500.00
0005433754279	2332	Economy	61500.00
0005433434603	2332	Economy	61500.00
0005432984754	2332	Economy	61500.00
0005432984893	2332	Economy	61500.00
0005433434478	2332	Economy	61500.00
0005433754262	2332	Economy	61500.00
0005435982381	2332	Economy	61500.00
0005432226063	2332	Economy	61500.00
0005435982351	2332	Economy	61500.00
0005435982374	2332	Economy	61500.00
0005433754292	2332	Economy	61500.00
0005433766646	2332	Economy	61500.00
0005435982366	2332	Economy	61500.00
0005432984978	2332	Economy	61500.00
0005433764681	2332	Economy	61500.00
0005435982386	2332	Economy	61500.00
0005432226066	2332	Economy	61500.00
0005433754311	2332	Economy	61500.00
0005435982378	2332	Economy	61500.00
0005434731132	2332	Economy	61500.00
0005435982361	2332	Economy	61500.00
0005432984775	2332	Economy	61500.00
0005432984915	2332	Economy	61500.00
0005433754269	2332	Economy	61500.00
0005433434532	2332	Economy	61500.00
0005432984784	2332	Economy	61500.00
0005435982354	2332	Economy	61500.00
0005432984807	2332	Economy	61500.00
0005433754276	2332	Economy	61500.00
0005435982387	2332	Economy	61500.00
0005433754273	2332	Economy	61500.00
0005435982373	2332	Economy	61500.00
0005432984834	2332	Economy	61500.00
0005435982358	2332	Economy	61500.00
0005435982365	2332	Economy	61500.00
0005435982353	2332	Economy	61500.00
0005433754288	2332	Economy	61500.00
0005432984902	2332	Economy	61500.00
0005433434531	2332	Economy	61500.00
0005433754283	2332	Economy	61500.00
0005435982370	2332	Economy	61500.00
0005432655552	2332	Economy	61500.00
0005435982384	2332	Economy	61500.00
0005433766644	2332	Economy	61500.00
0005433754275	2332	Economy	61500.00
0005432984905	2332	Economy	61500.00
0005435982360	2332	Economy	61500.00
0005432655548	2332	Economy	61500.00
0005433754312	2332	Economy	61500.00
0005433434467	2332	Economy	61500.00
0005435982349	2332	Economy	61500.00
0005435982382	2332	Economy	61500.00
0005432226062	2332	Economy	61500.00
0005435982345	2332	Economy	61500.00
0005433754287	2332	Economy	61500.00
0005433434547	2332	Economy	61500.00
0005433754272	2332	Economy	61500.00
0005433766645	2332	Economy	61500.00
0005433434421	2332	Economy	61500.00
0005433754268	2332	Economy	61500.00
0005435982375	2332	Economy	61500.00
0005435982371	2332	Economy	61500.00
0005432984851	2332	Economy	61500.00
0005433754314	2332	Economy	61500.00
0005433434468	2332	Economy	61500.00
0005433754271	2332	Economy	61500.00
0005433434463	2332	Economy	61500.00
0005432984885	2332	Economy	61500.00
0005435982372	2332	Economy	61500.00
0005433434602	2332	Economy	61500.00
0005433434464	2332	Economy	61500.00
0005432984901	2332	Economy	61500.00
0005433754264	2332	Economy	61500.00
0005435982392	2332	Economy	61500.00
0005433434466	2332	Economy	61500.00
0005433754303	2332	Economy	61500.00
0005433754266	2332	Economy	61500.00
0005435982377	2332	Economy	61500.00
0005433434500	2332	Economy	61500.00
0005432300271	2332	Economy	61500.00
0005432869476	2332	Economy	61500.00
0005433754306	2332	Economy	61500.00
0005432869464	2332	Economy	61500.00
0005433754260	2332	Economy	61500.00
0005433754277	2332	Economy	61500.00
0005432984844	2332	Economy	61500.00
0005433434528	2332	Economy	61500.00
0005433754284	2332	Economy	67700.00
0005435982347	2332	Economy	67700.00
0005433434501	2332	Economy	61500.00
0005432984907	2332	Economy	61500.00
0005433754259	2332	Economy	67700.00
0005433434443	2332	Economy	61500.00
0005433754267	2332	Economy	67700.00
0005433434447	2332	Economy	61500.00
0005432655555	2332	Economy	61500.00
0005432984950	2332	Economy	61500.00
0005432655546	2332	Economy	61500.00
0005435982383	2332	Economy	61500.00
0005433434477	2332	Economy	61500.00
0005433754307	2332	Economy	61500.00
0005432984980	2332	Economy	61500.00
0005435982389	2332	Economy	61500.00
0005435982356	2332	Economy	61500.00
0005433754299	2332	Economy	61500.00
0005432869467	2332	Economy	61500.00
0005432984920	2332	Economy	61500.00
0005433754270	2332	Economy	61500.00
0005432300270	2332	Economy	61500.00
0005433434558	2332	Economy	61500.00
0005432984861	2332	Economy	61500.00
0005432984951	2332	Economy	61500.00
0005433754298	2332	Economy	61500.00
0005433754300	2332	Economy	61500.00
0005433434487	2332	Economy	61500.00
0005435982363	2332	Economy	61500.00
0005432869466	2332	Economy	61500.00
0005432869453	2332	Economy	61500.00
0005432655549	2332	Economy	61500.00
0005432226061	2332	Economy	61500.00
0005435982380	2332	Economy	61500.00
0005432984872	2332	Economy	61500.00
0005435982376	2332	Economy	61500.00
0005432984774	2332	Economy	61500.00
0005433754290	2332	Economy	61500.00
0005433754261	2332	Economy	61500.00
0005432984886	2332	Economy	61500.00
0005433754310	2332	Economy	61500.00
0005432984952	2332	Economy	61500.00
0005432984914	2332	Economy	61500.00
0005433754263	2332	Economy	61500.00
0005432984979	2332	Economy	61500.00
0005433754286	2332	Economy	61500.00
0005433754278	2332	Economy	61500.00
0005432655550	2332	Economy	61500.00
0005433754297	2332	Economy	61500.00
0005435982355	2332	Economy	61500.00
0005432984884	2332	Economy	61500.00
0005433434552	2332	Economy	61500.00
0005435982357	2332	Economy	61500.00
0005432655554	2332	Economy	61500.00
0005433434485	2332	Economy	61500.00
0005433754302	2332	Economy	61500.00
0005435982348	2332	Economy	61500.00
0005433754301	2332	Economy	61500.00
0005432984852	2332	Economy	61500.00
0005432984855	2332	Economy	61500.00
0005433754285	2332	Economy	61500.00
0005433754294	2332	Economy	61500.00
0005433754308	2332	Economy	61500.00
0005433754304	2332	Economy	61500.00
0005432869465	2332	Economy	61500.00
0005433754295	2332	Economy	61500.00
0005433754293	2332	Economy	61500.00
0005432984892	2332	Economy	61500.00
0005432984887	2332	Economy	61500.00
0005433754313	2332	Economy	61500.00
0005433434540	2332	Economy	61500.00
0005435982388	2332	Economy	61500.00
0005433754258	2332	Economy	61500.00
0005435982362	2332	Economy	61500.00
0005432655551	2332	Economy	61500.00
0005435982344	2332	Economy	61500.00
0005433766642	2332	Economy	61500.00
0005435982390	2332	Economy	61500.00
0005432226065	2332	Economy	61500.00
0005433754274	2332	Economy	61500.00
0005432655556	2332	Economy	61500.00
0005433434512	2332	Economy	61500.00
0005433754265	2332	Economy	61500.00
0005432051132	26162	Business	184500.00
0005435981855	26162	Business	184500.00
0005433753695	26162	Business	184500.00
0005433753697	26162	Business	184500.00
0005433753715	26162	Business	184500.00
0005432655458	26162	Business	184500.00
0005435981806	26162	Business	184500.00
0005432985123	26162	Business	184500.00
0005433434722	26162	Business	184500.00
0005433753830	26162	Business	184500.00
0005435981834	26162	Business	184500.00
0005435981762	26162	Business	184500.00
0005433753696	26162	Business	184500.00
0005433753800	26162	Business	184500.00
0005432655398	26162	Business	184500.00
0005435981995	26162	Business	184500.00
0005435981853	26162	Business	184500.00
0005432655388	26162	Business	184500.00
0005435981846	26162	Business	184500.00
0005435981763	26162	Business	184500.00
0005433753775	26162	Business	184500.00
0005432985118	26162	Business	184500.00
0005432985128	26162	Business	184500.00
0005433434705	26162	Business	184500.00
0005435981807	26162	Business	184500.00
0005432049469	26162	Business	184500.00
0005433753768	26162	Business	184500.00
0005433753874	26162	Business	184500.00
0005435981873	26162	Economy	67700.00
0005433434703	26162	Economy	67700.00
0005432985116	26162	Economy	67700.00
0005432985106	26162	Economy	67700.00
0005433434720	26162	Economy	61500.00
0005433753593	26162	Economy	61500.00
0005435982015	26162	Economy	61500.00
0005435982008	26162	Economy	61500.00
0005433434709	26162	Economy	61500.00
0005433764668	26162	Economy	61500.00
0005433434699	26162	Economy	61500.00
0005432985111	26162	Economy	61500.00
0005433753797	26162	Economy	61500.00
0005432051131	26162	Economy	61500.00
0005434731177	26162	Economy	61500.00
0005432985114	26162	Economy	61500.00
0005432655404	26162	Economy	61500.00
0005432655399	26162	Economy	61500.00
0005433434708	26162	Economy	61500.00
0005435981920	26162	Economy	61500.00
0005435981645	26162	Economy	61500.00
0005433434712	26162	Economy	61500.00
0005435982005	26162	Economy	61500.00
0005435981655	26162	Economy	61500.00
0005435982014	26162	Economy	61500.00
0005433753683	26162	Economy	61500.00
0005435981933	26162	Economy	61500.00
0005432985108	26162	Economy	61500.00
0005432985125	26162	Economy	61500.00
0005433754018	26162	Economy	61500.00
0005435981800	26162	Economy	61500.00
0005432985120	26162	Economy	61500.00
0005433753769	26162	Economy	61500.00
0005433434725	26162	Economy	61500.00
0005432985104	26162	Economy	61500.00
0005432985129	26162	Economy	61500.00
0005433753820	26162	Economy	61500.00
0005433753600	26162	Economy	61500.00
0005432985117	26162	Economy	61500.00
0005433753801	26162	Economy	61500.00
0005435981960	26162	Economy	61500.00
0005435981932	26162	Economy	61500.00
0005433753745	26162	Economy	61500.00
0005432869529	26162	Economy	61500.00
0005433753706	26162	Economy	61500.00
0005433753779	26162	Economy	61500.00
0005433434718	26162	Economy	61500.00
0005432869528	26162	Economy	61500.00
0005432985131	26162	Economy	61500.00
0005435981854	26162	Economy	61500.00
0005432985115	26162	Economy	61500.00
0005432985097	26162	Economy	61500.00
0005433753712	26162	Economy	61500.00
0005432655409	26162	Economy	61500.00
0005433753704	26162	Economy	61500.00
0005433753791	26162	Economy	61500.00
0005433753777	26162	Economy	61500.00
0005433434723	26162	Economy	61500.00
0005435981952	26162	Economy	61500.00
0005432869532	26162	Economy	61500.00
0005435982000	26162	Economy	61500.00
0005433753892	26162	Economy	61500.00
0005432049468	26162	Economy	61500.00
0005434731174	26162	Economy	61500.00
0005433753900	26162	Economy	61500.00
0005433766594	26162	Economy	61500.00
0005433434721	26162	Economy	61500.00
0005435981895	26162	Economy	61500.00
0005432655402	26162	Economy	61500.00
0005435981908	26162	Economy	61500.00
0005433753724	26162	Economy	61500.00
0005435981934	26162	Economy	61500.00
0005432655464	26162	Economy	61500.00
0005435981999	26162	Economy	61500.00
0005435982028	26162	Economy	61500.00
0005432985119	26162	Economy	61500.00
0005432985124	26162	Economy	61500.00
0005435981921	26162	Economy	61500.00
0005432985100	26162	Economy	61500.00
0005433434713	26162	Economy	61500.00
0005432049470	26162	Economy	61500.00
0005432985105	26162	Economy	61500.00
0005435981815	26162	Economy	61500.00
0005433753819	26162	Economy	61500.00
0005433753579	26162	Economy	61500.00
0005432869531	26162	Economy	61500.00
0005435981922	26162	Economy	61500.00
0005433753831	26162	Economy	61500.00
0005433434707	26162	Economy	61500.00
0005432051130	26162	Economy	61500.00
0005433434698	26162	Economy	61500.00
0005435981759	26162	Economy	61500.00
0005433434724	26162	Economy	61500.00
0005432655443	26162	Economy	61500.00
0005432985101	26162	Economy	61500.00
0005432985103	26162	Economy	61500.00
0005435981998	26162	Economy	61500.00
0005432985110	26162	Economy	61500.00
0005433753778	26162	Economy	61500.00
0005433753875	26162	Economy	61500.00
0005433434726	26162	Economy	61500.00
0005432049467	26162	Economy	67700.00
0005435981739	26162	Economy	67700.00
0005435981738	26162	Economy	61500.00
0005433754019	26162	Economy	61500.00
0005435981936	26162	Economy	61500.00
0005433434710	26162	Economy	67700.00
0005435982009	26162	Economy	67700.00
0005435981961	26162	Economy	61500.00
0005435981808	26162	Economy	61500.00
0005433753956	26162	Economy	61500.00
0005433434714	26162	Economy	61500.00
0005432985130	26162	Economy	61500.00
0005435981838	26162	Economy	61500.00
0005435981835	26162	Economy	61500.00
0005433753776	26162	Economy	61500.00
0005433753849	26162	Economy	61500.00
0005433434711	26162	Economy	61500.00
0005435981956	26162	Economy	61500.00
0005432655403	26162	Economy	61500.00
0005432869527	26162	Economy	61500.00
0005433753813	26162	Economy	61500.00
0005433434702	26162	Economy	61500.00
0005435982006	26162	Economy	61500.00
0005433434700	26162	Economy	61500.00
0005432655411	26162	Economy	61500.00
0005433764667	26162	Economy	61500.00
0005433753857	26162	Economy	61500.00
0005432049466	26162	Economy	61500.00
0005433434716	26162	Economy	61500.00
0005433753585	26162	Economy	61500.00
0005433753785	26162	Economy	61500.00
0005432985098	26162	Economy	61500.00
0005432985126	26162	Economy	61500.00
0005432655407	26162	Economy	61500.00
0005432985113	26162	Economy	61500.00
0005432985109	26162	Economy	61500.00
0005432869530	26162	Economy	61500.00
0005435982004	26162	Economy	61500.00
0005435981984	26162	Economy	61500.00
0005435981955	26162	Economy	61500.00
0005433434715	26162	Economy	61500.00
0005433434719	26162	Economy	61500.00
0005432985102	26162	Economy	61500.00
0005432655427	26162	Economy	61500.00
0005435981856	26162	Economy	61500.00
0005433766600	26162	Economy	61500.00
0005433753705	26162	Economy	61500.00
0005435981758	26162	Economy	61500.00
0005433766610	26162	Economy	61500.00
0005435981930	26162	Economy	61500.00
0005433753703	26162	Economy	61500.00
0005432985122	26162	Economy	61500.00
0005435982019	26162	Economy	61500.00
0005434731175	26162	Economy	61500.00
0005433753684	26162	Economy	61500.00
0005433753850	26162	Economy	61500.00
0005435981646	26162	Economy	61500.00
0005432985112	26162	Economy	61500.00
0005432985121	26162	Economy	61500.00
0005433753594	26162	Economy	61500.00
0005433753726	26162	Economy	61500.00
0005433434717	26162	Economy	61500.00
0005432655484	26162	Economy	61500.00
0005434731176	26162	Economy	61500.00
0005432985099	26162	Economy	61500.00
0005435981965	26162	Economy	61500.00
0005433434704	26162	Economy	61500.00
0005433754013	26162	Economy	61500.00
0005432869526	26162	Economy	61500.00
0005433753584	26162	Economy	61500.00
0005433753821	26162	Economy	61500.00
0005432655428	26162	Economy	61500.00
0005435982016	26162	Economy	61500.00
0005432655408	26162	Economy	61500.00
0005432985127	26162	Economy	61500.00
0005433434706	26162	Economy	61500.00
0005432655426	26162	Economy	61500.00
0005433434701	26162	Economy	61500.00
0005435981931	26162	Economy	61500.00
0005433753792	26162	Economy	61500.00
0005432985107	26162	Economy	61500.00
0005435981878	26162	Economy	61500.00
0005433754012	26162	Economy	61500.00
0005434731178	26162	Economy	61500.00
0005433151203	1490	Business	38900.00
0005434374706	1490	Business	38900.00
0005433151283	1490	Business	38900.00
0005432267903	1490	Business	38900.00
0005433151219	1490	Business	38900.00
0005433151147	1490	Business	38900.00
0005432267902	1490	Economy	13000.00
0005433461592	1490	Economy	13000.00
0005433151189	1490	Economy	13000.00
0005433151299	1490	Economy	13000.00
0005433151300	1490	Economy	13000.00
0005434374678	1490	Economy	13000.00
0005433151058	1490	Economy	13000.00
0005433151204	1490	Economy	13000.00
0005434374702	1490	Economy	13000.00
0005434374708	1490	Economy	13000.00
0005433151137	1490	Economy	13000.00
0005433151187	1490	Economy	13000.00
0005432267901	1490	Economy	13000.00
0005434029637	1490	Economy	13000.00
0005433931433	1490	Economy	13000.00
0005434374692	1490	Economy	13000.00
0005432267904	1490	Economy	13000.00
0005433151144	1490	Economy	13000.00
0005434374681	1490	Economy	13000.00
0005433151240	1490	Economy	13000.00
0005433151247	1490	Economy	13000.00
0005434374686	1490	Economy	13000.00
0005433151132	1490	Economy	13000.00
0005433151285	1490	Economy	13000.00
0005433151127	1490	Economy	13000.00
0005434374699	1490	Economy	13000.00
0005433151220	1490	Economy	13000.00
0005433151080	1490	Economy	13000.00
0005434374700	1490	Economy	13000.00
0005433150997	1490	Economy	13000.00
0005433151251	1490	Economy	14300.00
0005433151126	1490	Economy	14300.00
0005433151206	1490	Economy	14300.00
0005433151278	1490	Economy	14300.00
0005434029633	1490	Economy	13000.00
0005434374689	1490	Economy	13000.00
0005433764661	1490	Economy	13000.00
0005434374693	1490	Economy	13000.00
0005434374690	1490	Economy	13000.00
0005434374694	1490	Economy	13000.00
0005434374698	1490	Economy	13000.00
0005433151179	1490	Economy	13000.00
0005433764660	1490	Economy	13000.00
0005434374691	1490	Economy	13000.00
0005434374684	1490	Economy	13000.00
0005434374682	1490	Economy	13000.00
0005434374696	1490	Economy	13000.00
0005434374709	1490	Economy	13000.00
0005433151178	1490	Economy	13000.00
0005434029630	1490	Economy	13000.00
0005433151065	1490	Economy	13000.00
0005433460438	1490	Economy	13000.00
0005434374697	1490	Economy	13000.00
0005434374703	1490	Economy	13000.00
0005433151314	1490	Economy	13000.00
0005432267905	1490	Economy	13000.00
0005432267906	1490	Economy	13000.00
0005434374683	1490	Economy	13000.00
0005434029634	1490	Economy	13000.00
0005434374701	1490	Economy	13000.00
0005434374705	1490	Economy	13000.00
0005433151073	1490	Economy	13000.00
0005434374704	1490	Economy	13000.00
0005433151298	1490	Economy	13000.00
0005434374707	1490	Economy	13000.00
0005434374679	1490	Economy	13000.00
0005434374677	1490	Economy	13000.00
0005433151079	1490	Economy	13000.00
0005433931452	1490	Economy	13000.00
0005433151059	1490	Economy	13000.00
0005433931451	1490	Economy	13000.00
0005434374688	1490	Economy	13000.00
0005433151284	1490	Economy	13000.00
0005433151188	1490	Economy	13000.00
0005434374695	1490	Economy	13000.00
0005433151379	1490	Economy	13000.00
0005433460439	1490	Economy	13000.00
0005433151236	1490	Economy	13000.00
0005433151169	1490	Economy	13000.00
0005433461591	1490	Economy	13000.00
0005434374680	1490	Economy	13000.00
0005433151066	1490	Economy	13000.00
0005434374687	1490	Economy	13000.00
0005433150989	1490	Economy	13000.00
0005434374685	1490	Economy	13000.00
0005433151426	20132	Business	38900.00
0005434374327	20132	Business	38900.00
0005434374253	20132	Business	38900.00
0005433931470	20132	Business	38900.00
0005434374410	20132	Business	38900.00
0005434374178	20132	Business	38900.00
0005434374326	20132	Business	38900.00
0005434374294	20132	Business	38900.00
0005434374260	20132	Business	38900.00
0005434374159	20132	Economy	13000.00
0005434374242	20132	Economy	13000.00
0005434374396	20132	Economy	13000.00
0005433151444	20132	Economy	13000.00
0005434374177	20132	Economy	13000.00
0005433151428	20132	Economy	13000.00
0005434029659	20132	Economy	13000.00
0005433151452	20132	Economy	13000.00
0005434374186	20132	Economy	13000.00
0005434374394	20132	Economy	13000.00
0005434374447	20132	Economy	13000.00
0005433151435	20132	Economy	13000.00
0005433151432	20132	Economy	13000.00
0005433151438	20132	Economy	13000.00
0005433151431	20132	Economy	13000.00
0005433151440	20132	Economy	13000.00
0005434029660	20132	Economy	13000.00
0005434374102	20132	Economy	13000.00
0005434374388	20132	Economy	13000.00
0005434374328	20132	Economy	13000.00
0005434374417	20132	Economy	13000.00
0005434374231	20132	Economy	13000.00
0005434374309	20132	Economy	13000.00
0005433151439	20132	Economy	13000.00
0005432056304	20132	Economy	13000.00
0005434374427	20132	Economy	13000.00
0005433151446	20132	Economy	13000.00
0005433151447	20132	Economy	13000.00
0005434374383	20132	Economy	13000.00
0005434374449	20132	Economy	13000.00
0005432056301	20132	Economy	14300.00
0005434374101	20132	Economy	14300.00
0005433151441	20132	Economy	14300.00
0005433151453	20132	Economy	14300.00
0005434374211	20132	Economy	14300.00
0005433151459	20132	Economy	13000.00
0005433151443	20132	Economy	13000.00
0005434374320	20132	Economy	13000.00
0005434374222	20132	Economy	13000.00
0005434373904	20132	Economy	13000.00
0005433151437	20132	Economy	13000.00
0005434374448	20132	Economy	13000.00
0005434374415	20132	Economy	13000.00
0005433151429	20132	Economy	13000.00
0005433151454	20132	Economy	13000.00
0005434374455	20132	Economy	13000.00
0005434374319	20132	Economy	13000.00
0005434374395	20132	Economy	13000.00
0005433151449	20132	Economy	13000.00
0005433151458	20132	Economy	13000.00
0005434374454	20132	Economy	13000.00
0005433764681	20132	Economy	13000.00
0005434374289	20132	Economy	13000.00
0005433151433	20132	Economy	13000.00
0005433151451	20132	Economy	13000.00
0005432056302	20132	Economy	13000.00
0005434374409	20132	Economy	13000.00
0005433764682	20132	Economy	13000.00
0005433931469	20132	Economy	13000.00
0005433151434	20132	Economy	13000.00
0005434374183	20132	Economy	13000.00
0005433151457	20132	Economy	13000.00
0005434374293	20132	Economy	13000.00
0005434374265	20132	Economy	13000.00
0005434374158	20132	Economy	13000.00
0005434374184	20132	Economy	13000.00
0005434373903	20132	Economy	13000.00
0005434374235	20132	Economy	13000.00
0005434374254	20132	Economy	13000.00
0005434374310	20132	Economy	13000.00
0005434374312	20132	Economy	13000.00
0005434374230	20132	Economy	13000.00
0005432056303	20132	Economy	13000.00
0005433151460	20132	Economy	13000.00
0005433151436	20132	Economy	13000.00
0005433151455	20132	Economy	13000.00
0005434374295	20132	Economy	13000.00
0005434374437	20132	Economy	13000.00
0005434374276	20132	Economy	13000.00
0005433931471	20132	Economy	13000.00
0005434374043	20132	Economy	13000.00
0005433151448	20132	Economy	13000.00
0005433151456	20132	Economy	13000.00
0005434374350	20132	Economy	13000.00
0005433151430	20132	Economy	13000.00
0005434374277	20132	Economy	13000.00
0005433151427	20132	Economy	13000.00
0005433931468	20132	Economy	13000.00
0005433151445	20132	Economy	13000.00
0005433151450	20132	Economy	13000.00
0005434374308	20132	Economy	13000.00
0005433151442	20132	Economy	13000.00
0005434374286	20132	Economy	13000.00
0005434374279	20132	Economy	13000.00
0005432424484	507	Business	27500.00
0005432424498	507	Business	27500.00
0005432424489	507	Business	27500.00
0005432424475	507	Business	27500.00
0005432282876	507	Business	27500.00
0005432424471	507	Business	27500.00
0005432424509	507	Business	27500.00
0005432282871	507	Business	27500.00
0005432282873	507	Business	27500.00
0005432424487	507	Economy	10100.00
0005432424496	507	Economy	10100.00
0005432424514	507	Economy	9200.00
0005432424469	507	Economy	9200.00
0005432424505	507	Economy	9200.00
0005432424481	507	Economy	9200.00
0005432424502	507	Economy	9200.00
0005432282875	507	Economy	9200.00
0005432282869	507	Economy	9200.00
0005432282874	507	Economy	9200.00
0005432424516	507	Economy	9200.00
0005432424488	507	Economy	9200.00
0005432424519	507	Economy	9200.00
0005432424463	507	Economy	9200.00
0005432424511	507	Economy	9200.00
0005432424499	507	Economy	9200.00
0005432424491	507	Economy	9200.00
0005432424518	507	Economy	9200.00
0005432424483	507	Economy	9200.00
0005432424497	507	Economy	9200.00
0005432424480	507	Economy	9200.00
0005432424472	507	Economy	9200.00
0005432424479	507	Economy	9200.00
0005432424466	507	Economy	9200.00
0005432424513	507	Economy	9200.00
0005432424515	507	Economy	9200.00
0005432424512	507	Economy	10100.00
0005432424506	507	Economy	10100.00
0005432424470	507	Economy	10100.00
0005432424500	507	Economy	9200.00
0005432424492	507	Economy	9200.00
0005432424474	507	Economy	9200.00
0005432424464	507	Economy	9200.00
0005432424473	507	Economy	9200.00
0005432424467	507	Economy	9200.00
0005432424476	507	Economy	9200.00
0005432424468	507	Economy	9200.00
0005432424465	507	Economy	9200.00
0005432424494	507	Economy	9200.00
0005432424504	507	Economy	9200.00
0005432424495	507	Economy	9200.00
0005432424503	507	Economy	9200.00
0005432424493	507	Economy	9200.00
0005432424490	507	Economy	9200.00
0005432424510	507	Economy	9200.00
0005432424485	507	Economy	9200.00
0005432424508	507	Economy	9200.00
0005432282872	507	Economy	9200.00
0005432424517	507	Economy	9200.00
0005432282870	507	Economy	9200.00
0005432424477	507	Economy	9200.00
0005432424478	507	Economy	9200.00
0005432424486	507	Economy	9200.00
0005432424482	507	Economy	9200.00
0005432424507	507	Economy	9200.00
0005432424501	507	Economy	9200.00
0005432302334	12897	Business	27500.00
0005434446500	12897	Business	27500.00
0005433158131	12897	Economy	9200.00
0005434446499	12897	Economy	9200.00
0005433158132	12897	Economy	9200.00
0005433158134	12897	Economy	9200.00
0005433158133	12897	Economy	9200.00
0005432302333	12897	Economy	9200.00
0005434446502	12897	Economy	9200.00
0005432302336	12897	Economy	9200.00
0005434446497	12897	Economy	9200.00
0005432302335	12897	Economy	9200.00
0005434446496	12897	Economy	9200.00
0005433158135	12897	Economy	9200.00
0005432424048	12896	Business	27500.00
0005432423975	12896	Business	27500.00
0005432424021	12896	Business	27500.00
0005432423932	12896	Business	27500.00
0005432423920	12896	Business	27500.00
0005432423846	12896	Business	27500.00
0005432423933	12896	Business	27500.00
0005432423874	12896	Business	27500.00
0005432424090	12896	Business	27500.00
0005432424093	12896	Economy	10100.00
0005432423919	12896	Business	27500.00
0005432424096	12896	Economy	10100.00
0005432424049	12896	Economy	9200.00
0005432423979	12896	Economy	9200.00
0005432424050	12896	Economy	9200.00
0005432424091	12896	Economy	9200.00
0005432423873	12896	Economy	9200.00
0005432424038	12896	Economy	9200.00
0005432423974	12896	Economy	9200.00
0005432423866	12896	Economy	9200.00
0005432423985	12896	Economy	9200.00
0005432424089	12896	Economy	9200.00
0005432423991	12896	Economy	9200.00
0005432423986	12896	Economy	9200.00
0005432424027	12896	Economy	9200.00
0005432424066	12896	Economy	10100.00
0005432424058	12896	Economy	10100.00
0005432424004	12896	Economy	9200.00
0005432423939	12896	Economy	10100.00
0005432423960	12896	Economy	9200.00
0005432423855	12896	Economy	9200.00
0005432423996	12896	Economy	9200.00
0005432423942	12896	Economy	9200.00
0005432423992	12896	Economy	9200.00
0005432424059	12896	Economy	9200.00
0005432424060	12896	Economy	9200.00
0005432424028	12896	Economy	9200.00
0005432423865	12896	Economy	9200.00
0005432424057	12896	Economy	9200.00
0005432424092	12896	Economy	9200.00
0005432423934	12896	Economy	9200.00
0005432424056	12896	Economy	9200.00
0005432424000	12896	Economy	9200.00
0005432424012	12896	Economy	9200.00
0005432423995	12896	Economy	9200.00
0005432423993	12896	Economy	9200.00
0005433057490	482	Business	24500.00
0005434023750	482	Business	24500.00
0005433057554	482	Business	24500.00
0005432235643	482	Business	24500.00
0005434023802	482	Business	24500.00
0005433057727	482	Business	24500.00
0005434023757	482	Business	24500.00
0005434023795	482	Business	24500.00
0005432045613	482	Business	24500.00
0005433057619	482	Business	24500.00
0005432235651	482	Business	24500.00
0005432235648	482	Business	24500.00
0005434023810	482	Business	24500.00
0005433057728	482	Business	24500.00
0005433057685	482	Business	24500.00
0005434028295	482	Business	24500.00
0005434735644	482	Business	24500.00
0005434023766	482	Business	24500.00
0005433057470	482	Business	24500.00
0005434735653	482	Business	24500.00
0005434032025	482	Business	24500.00
0005433929575	482	Business	24500.00
0005434023772	482	Business	24500.00
0005434023765	482	Business	24500.00
0005433057673	482	Economy	9000.00
0005433057747	482	Economy	9000.00
0005434023784	482	Economy	8200.00
0005432235650	482	Economy	8200.00
0005433057733	482	Economy	8200.00
0005434023761	482	Economy	8200.00
0005434023774	482	Economy	8200.00
0005433057734	482	Economy	8200.00
0005434028296	482	Economy	8200.00
0005433929568	482	Economy	8200.00
0005433057748	482	Economy	8200.00
0005433057544	482	Economy	8200.00
0005434029657	482	Economy	8200.00
0005434032026	482	Economy	8200.00
0005434032023	482	Economy	8200.00
0005434023786	482	Economy	8200.00
0005434032027	482	Economy	8200.00
0005434023793	482	Economy	8200.00
0005433057597	482	Economy	8200.00
0005433057731	482	Economy	8200.00
0005432235645	482	Economy	8200.00
0005434023754	482	Economy	8200.00
0005434023801	482	Economy	8200.00
0005434023790	482	Economy	8200.00
0005434023753	482	Economy	8200.00
0005433057774	482	Economy	8200.00
0005434023807	482	Economy	8200.00
0005434023763	482	Economy	8200.00
0005434023809	482	Economy	8200.00
0005433057526	482	Economy	8200.00
0005433684414	482	Economy	8200.00
0005433057812	482	Economy	8200.00
0005433057687	482	Economy	8200.00
0005433057735	482	Economy	8200.00
0005434023806	482	Economy	8200.00
0005434023775	482	Economy	8200.00
0005434023798	482	Economy	8200.00
0005432235647	482	Economy	8200.00
0005434023791	482	Economy	8200.00
0005432235649	482	Economy	8200.00
0005432045614	482	Economy	8200.00
0005434023788	482	Economy	8200.00
0005434023759	482	Economy	8200.00
0005434023813	482	Economy	8200.00
0005434023794	482	Economy	8200.00
0005434023792	482	Economy	8200.00
0005434023777	482	Economy	8200.00
0005434023800	482	Economy	8200.00
0005434023803	482	Economy	8200.00
0005434023778	482	Economy	8200.00
0005434023768	482	Economy	8200.00
0005434023767	482	Economy	8200.00
0005434032024	482	Economy	8200.00
0005434023797	482	Economy	8200.00
0005434023816	482	Economy	8200.00
0005433057757	482	Economy	8200.00
0005433057613	482	Economy	8200.00
0005434023783	482	Economy	8200.00
0005432235644	482	Economy	8200.00
0005434023758	482	Economy	8200.00
0005434023799	482	Economy	8200.00
0005433057491	482	Economy	8200.00
0005434023776	482	Economy	8200.00
0005433684408	482	Economy	8200.00
0005434023764	482	Economy	9000.00
0005434023804	482	Economy	8200.00
0005434023760	482	Economy	8200.00
0005433057492	482	Economy	8200.00
0005434023782	482	Economy	9000.00
0005434023762	482	Economy	8200.00
0005434023814	482	Economy	8200.00
0005434023812	482	Economy	8200.00
0005434023796	482	Economy	8200.00
0005433929576	482	Economy	8200.00
0005434023779	482	Economy	8200.00
0005434023780	482	Economy	8200.00
0005434029658	482	Economy	8200.00
0005433057718	482	Economy	8200.00
0005433057697	482	Economy	8200.00
0005434023808	482	Economy	8200.00
0005433057527	482	Economy	8200.00
0005433057759	482	Economy	8200.00
0005434023787	482	Economy	8200.00
0005433057743	482	Economy	8200.00
0005433057659	482	Economy	8200.00
0005433929577	482	Economy	8200.00
0005434023785	482	Economy	8200.00
0005434023781	482	Economy	8200.00
0005434023773	482	Economy	8200.00
0005433929590	482	Economy	8200.00
0005433057553	482	Economy	8200.00
0005434028297	482	Economy	8200.00
0005434023771	482	Economy	8200.00
0005433684409	482	Economy	8200.00
0005434023817	482	Economy	8200.00
0005434023815	482	Economy	8200.00
0005434023789	482	Economy	8200.00
0005434023752	482	Economy	8200.00
0005434023805	482	Economy	8200.00
0005434023811	482	Economy	8200.00
0005434023751	482	Economy	8200.00
0005434023770	482	Economy	8200.00
0005433057686	482	Economy	8200.00
0005432235646	482	Economy	8200.00
0005434023755	482	Economy	8200.00
0005433057620	482	Economy	8200.00
0005434023769	482	Economy	8200.00
0005434023756	482	Economy	8200.00
0005433057744	482	Economy	8200.00
0005434023084	12646	Business	24500.00
0005434023142	12646	Business	24500.00
0005434023415	12646	Business	24500.00
0005433057928	12646	Business	24500.00
0005433057931	12646	Business	24500.00
0005434735693	12646	Business	24500.00
0005434023331	12646	Business	24500.00
0005433057936	12646	Business	24500.00
0005434023228	12646	Business	24500.00
0005433057916	12646	Business	24500.00
0005434022872	12646	Business	24500.00
0005434023068	12646	Business	24500.00
0005434023234	12646	Business	24500.00
0005432156371	12646	Business	24500.00
0005434023250	12646	Business	24500.00
0005434023167	12646	Business	24500.00
0005433057938	12646	Economy	9000.00
0005434023392	12646	Economy	9000.00
0005434031994	12646	Economy	9000.00
0005434023431	12646	Economy	9000.00
0005434023302	12646	Economy	8200.00
0005433057940	12646	Economy	8200.00
0005434735695	12646	Economy	8200.00
0005434023261	12646	Economy	8200.00
0005434023430	12646	Economy	8200.00
0005434023076	12646	Economy	8200.00
0005434735698	12646	Economy	8200.00
0005432157493	12646	Economy	8200.00
0005433057927	12646	Economy	8200.00
0005433057923	12646	Economy	8200.00
0005434023294	12646	Economy	8200.00
0005433057929	12646	Economy	8200.00
0005434023500	12646	Economy	8200.00
0005434023141	12646	Economy	8200.00
0005434028294	12646	Economy	8200.00
0005433057939	12646	Economy	8200.00
0005434023407	12646	Economy	8200.00
0005434028271	12646	Economy	8200.00
0005434023175	12646	Economy	8200.00
0005433057922	12646	Economy	8200.00
0005434735694	12646	Economy	8200.00
0005434031966	12646	Economy	8200.00
0005434023380	12646	Economy	8200.00
0005434029633	12646	Economy	8200.00
0005433057941	12646	Economy	8200.00
0005433057914	12646	Economy	8200.00
0005434023405	12646	Economy	8200.00
0005434023101	12646	Economy	8200.00
0005434031990	12646	Economy	8200.00
0005434023367	12646	Economy	8200.00
0005434023301	12646	Economy	8200.00
0005434023210	12646	Economy	8200.00
0005434022997	12646	Economy	8200.00
0005434023421	12646	Economy	8200.00
0005434022914	12646	Economy	8200.00
0005433057935	12646	Economy	8200.00
0005433684423	12646	Economy	8200.00
0005434023449	12646	Economy	8200.00
0005434023151	12646	Economy	8200.00
0005434029634	12646	Economy	8200.00
0005434023249	12646	Economy	8200.00
0005434028287	12646	Economy	8200.00
0005433929618	12646	Economy	8200.00
0005434023209	12646	Economy	8200.00
0005434023090	12646	Economy	8200.00
0005433057913	12646	Economy	8200.00
0005433057920	12646	Economy	8200.00
0005434023204	12646	Economy	8200.00
0005434023177	12646	Economy	8200.00
0005433057947	12646	Economy	8200.00
0005434023183	12646	Economy	8200.00
0005433929619	12646	Economy	8200.00
0005433057921	12646	Economy	8200.00
0005433057911	12646	Economy	8200.00
0005433057933	12646	Economy	8200.00
0005434023188	12646	Economy	8200.00
0005434735697	12646	Economy	8200.00
0005434023365	12646	Economy	9000.00
0005434022982	12646	Economy	8200.00
0005433057946	12646	Economy	8200.00
0005433684422	12646	Economy	9000.00
0005432156372	12646	Economy	9000.00
0005433057925	12646	Economy	8200.00
0005433057926	12646	Economy	8200.00
0005434023176	12646	Economy	8200.00
0005433057943	12646	Economy	8200.00
0005433057924	12646	Economy	8200.00
0005434022871	12646	Economy	8200.00
0005433057917	12646	Economy	8200.00
0005434023420	12646	Economy	8200.00
0005433057945	12646	Economy	8200.00
0005434023434	12646	Economy	8200.00
0005433057915	12646	Economy	8200.00
0005432156369	12646	Economy	8200.00
0005434023091	12646	Economy	8200.00
0005434023138	12646	Economy	8200.00
0005433057918	12646	Economy	8200.00
0005434023433	12646	Economy	8200.00
0005433929616	12646	Economy	8200.00
0005434023295	12646	Economy	8200.00
0005433057908	12646	Economy	8200.00
0005432157494	12646	Economy	8200.00
0005434023406	12646	Economy	8200.00
0005434023015	12646	Economy	8200.00
0005433057930	12646	Economy	8200.00
0005433929617	12646	Economy	8200.00
0005434023085	12646	Economy	8200.00
0005433057948	12646	Economy	8200.00
0005434023224	12646	Economy	8200.00
0005432156370	12646	Economy	8200.00
0005434023189	12646	Economy	8200.00
0005433057912	12646	Economy	8200.00
0005433057944	12646	Economy	8200.00
0005434023322	12646	Economy	8200.00
0005433057937	12646	Economy	8200.00
0005434023366	12646	Economy	8200.00
0005434029630	12646	Economy	8200.00
0005434031965	12646	Economy	8200.00
0005433057934	12646	Economy	8200.00
0005434023137	12646	Economy	8200.00
0005434023475	12646	Economy	8200.00
0005434023248	12646	Economy	8200.00
0005434023079	12646	Economy	8200.00
0005434029637	12646	Economy	8200.00
0005434031968	12646	Economy	8200.00
0005433057932	12646	Economy	8200.00
0005433057909	12646	Economy	8200.00
0005434735696	12646	Economy	8200.00
0005433057942	12646	Economy	8200.00
0005434023184	12646	Economy	8200.00
0005432156368	12646	Economy	8200.00
0005433057910	12646	Economy	8200.00
0005433057919	12646	Economy	8200.00
0005433035728	2127	Business	34700.00
0005433036040	2127	Business	34700.00
0005433923384	2127	Business	34700.00
0005433923387	2127	Business	34700.00
0005433923376	2127	Business	34700.00
0005433923363	2127	Business	34700.00
0005432044527	2127	Business	34700.00
0005433923409	2127	Business	34700.00
0005433036143	2127	Business	34700.00
0005433923447	2127	Business	34700.00
0005432044526	2127	Business	34700.00
0005433923451	2127	Business	34700.00
0005433035893	2127	Business	34700.00
0005433923444	2127	Business	34700.00
0005433923400	2127	Business	34700.00
0005433923393	2127	Business	34700.00
0005433035759	2127	Business	34700.00
0005432044528	2127	Business	34700.00
0005434028294	2127	Business	34700.00
0005433923415	2127	Business	34700.00
0005433923425	2127	Business	34700.00
0005433035891	2127	Business	34700.00
0005433923390	2127	Business	34700.00
0005433923431	2127	Business	34700.00
0005433923378	2127	Business	34700.00
0005433923427	2127	Economy	12700.00
0005433923394	2127	Economy	12700.00
0005433035725	2127	Economy	12700.00
0005433035775	2127	Economy	12700.00
0005433923366	2127	Economy	11600.00
0005433035900	2127	Economy	11600.00
0005434028287	2127	Economy	11600.00
0005433035923	2127	Economy	11600.00
0005433923359	2127	Economy	11600.00
0005433923368	2127	Economy	11600.00
0005433923412	2127	Economy	11600.00
0005433923414	2127	Economy	11600.00
0005433035974	2127	Economy	11600.00
0005433931468	2127	Economy	11600.00
0005433923383	2127	Economy	11600.00
0005432231578	2127	Economy	11600.00
0005433036139	2127	Economy	11600.00
0005433035727	2127	Economy	11600.00
0005433875379	2127	Economy	11600.00
0005433923450	2127	Economy	11600.00
0005433923403	2127	Economy	11600.00
0005433923373	2127	Economy	11600.00
0005433923434	2127	Economy	11600.00
0005432231580	2127	Economy	11600.00
0005433035920	2127	Economy	11600.00
0005433035905	2127	Economy	11600.00
0005433035844	2127	Economy	11600.00
0005433923372	2127	Economy	11600.00
0005433036140	2127	Economy	11600.00
0005433923437	2127	Economy	11600.00
0005433923426	2127	Economy	11600.00
0005433035864	2127	Economy	11600.00
0005433923417	2127	Economy	11600.00
0005433036162	2127	Economy	11600.00
0005433035738	2127	Economy	11600.00
0005433923420	2127	Economy	11600.00
0005433923446	2127	Economy	11600.00
0005433035957	2127	Economy	11600.00
0005433923416	2127	Economy	11600.00
0005433923392	2127	Economy	11600.00
0005433929619	2127	Economy	11600.00
0005432231576	2127	Economy	11600.00
0005433923370	2127	Economy	11600.00
0005433923397	2127	Economy	11600.00
0005432231572	2127	Economy	11600.00
0005433923432	2127	Economy	11600.00
0005433923399	2127	Economy	11600.00
0005433923429	2127	Economy	11600.00
0005433923389	2127	Economy	11600.00
0005433923423	2127	Economy	11600.00
0005433923440	2127	Economy	11600.00
0005433923380	2127	Economy	11600.00
0005433923424	2127	Economy	11600.00
0005433923364	2127	Economy	11600.00
0005433036088	2127	Economy	11600.00
0005433923356	2127	Economy	11600.00
0005433923362	2127	Economy	11600.00
0005433923357	2127	Economy	11600.00
0005433035883	2127	Economy	11600.00
0005433035930	2127	Economy	11600.00
0005433923360	2127	Economy	11600.00
0005433923441	2127	Economy	11600.00
0005433929618	2127	Economy	11600.00
0005433036142	2127	Economy	11600.00
0005433923421	2127	Economy	11600.00
0005433036163	2127	Economy	11600.00
0005433036141	2127	Economy	11600.00
0005433035774	2127	Economy	11600.00
0005433923402	2127	Economy	11600.00
0005432231573	2127	Economy	11600.00
0005433923369	2127	Economy	11600.00
0005433035882	2127	Economy	11600.00
0005433923354	2127	Economy	11600.00
0005433035892	2127	Economy	11600.00
0005433035954	2127	Economy	11600.00
0005433035962	2127	Economy	11600.00
0005433035922	2127	Economy	11600.00
0005433923418	2127	Economy	11600.00
0005433035971	2127	Economy	11600.00
0005433035969	2127	Economy	11600.00
0005433036039	2127	Economy	11600.00
0005433923439	2127	Economy	11600.00
0005433036002	2127	Economy	11600.00
0005433923411	2127	Economy	11600.00
0005433923367	2127	Economy	11600.00
0005433923443	2127	Economy	11600.00
0005433923396	2127	Economy	11600.00
0005433035973	2127	Economy	12700.00
0005433035952	2127	Economy	12700.00
0005433923375	2127	Economy	11600.00
0005433923391	2127	Economy	11600.00
0005433931471	2127	Economy	11600.00
0005433923398	2127	Economy	12700.00
0005432231577	2127	Economy	11600.00
0005433923436	2127	Economy	12700.00
0005433035929	2127	Economy	11600.00
0005432231579	2127	Economy	11600.00
0005433923386	2127	Economy	11600.00
0005433036144	2127	Economy	11600.00
0005433035894	2127	Economy	11600.00
0005433923407	2127	Economy	11600.00
0005433923382	2127	Economy	11600.00
0005433923419	2127	Economy	11600.00
0005433035928	2127	Economy	11600.00
0005433923401	2127	Economy	11600.00
0005433923374	2127	Economy	11600.00
0005433923381	2127	Economy	11600.00
0005433035921	2127	Economy	11600.00
0005433923449	2127	Economy	11600.00
0005433035939	2127	Economy	11600.00
0005433923404	2127	Economy	11600.00
0005433923448	2127	Economy	11600.00
0005433035924	2127	Economy	11600.00
0005433923385	2127	Economy	11600.00
0005432231581	2127	Economy	11600.00
0005433923408	2127	Economy	11600.00
0005433035951	2127	Economy	11600.00
0005433931469	2127	Economy	11600.00
0005433923433	2127	Economy	11600.00
0005433923365	2127	Economy	11600.00
0005432231571	2127	Economy	11600.00
0005433923388	2127	Economy	11600.00
0005433923358	2127	Economy	11600.00
0005432231574	2127	Economy	11600.00
0005433036037	2127	Economy	11600.00
0005433036008	2127	Economy	11600.00
0005433035797	2127	Economy	11600.00
0005433036007	2127	Economy	11600.00
0005433929617	2127	Economy	11600.00
0005433036021	2127	Economy	11600.00
0005433923422	2127	Economy	11600.00
0005433875378	2127	Economy	11600.00
0005433923379	2127	Economy	11600.00
0005433923406	2127	Economy	11600.00
0005433923445	2127	Economy	11600.00
0005433036087	2127	Economy	11600.00
0005433035991	2127	Economy	11600.00
0005433923410	2127	Economy	11600.00
0005433036006	2127	Economy	11600.00
0005433923395	2127	Economy	11600.00
0005433923355	2127	Economy	11600.00
0005433923442	2127	Economy	11600.00
0005433035953	2127	Economy	11600.00
0005433923430	2127	Economy	11600.00
0005433036089	2127	Economy	11600.00
0005433035770	2127	Economy	11600.00
0005434028271	2127	Economy	11600.00
0005433923428	2127	Economy	11600.00
0005433036137	2127	Economy	11600.00
0005433923377	2127	Economy	11600.00
0005433923405	2127	Economy	11600.00
0005433035608	2127	Economy	11600.00
0005433035904	2127	Economy	11600.00
0005433036138	2127	Economy	11600.00
0005433923371	2127	Economy	11600.00
0005433923438	2127	Economy	11600.00
0005433931470	2127	Economy	11600.00
0005433923361	2127	Economy	11600.00
0005432231575	2127	Economy	11600.00
0005433923413	2127	Economy	11600.00
0005433929616	2127	Economy	11600.00
0005433923435	2127	Economy	11600.00
0005433035958	2127	Economy	11600.00
0005433922314	24130	Business	34700.00
0005433036335	24130	Business	34700.00
0005433922853	24130	Business	34700.00
0005433922530	24130	Business	34700.00
0005433922323	24130	Business	34700.00
0005433931430	24130	Business	34700.00
0005433036344	24130	Business	34700.00
0005433922310	24130	Business	34700.00
0005433036380	24130	Business	34700.00
0005432206199	24130	Business	34700.00
0005433922553	24130	Business	34700.00
0005433036329	24130	Business	34700.00
0005432206204	24130	Business	34700.00
0005433922929	24130	Business	34700.00
0005433922760	24130	Business	34700.00
0005432749788	24130	Business	34700.00
0005433922536	24130	Business	34700.00
0005433036370	24130	Business	34700.00
0005433922866	24130	Business	34700.00
0005433922928	24130	Business	34700.00
0005433922438	24130	Business	34700.00
0005433922554	24130	Business	34700.00
0005433922609	24130	Business	34700.00
0005433922918	24130	Business	34700.00
0005433036334	24130	Business	34700.00
0005433036374	24130	Business	34700.00
0005433036364	24130	Economy	12700.00
0005433036333	24130	Economy	12700.00
0005433036347	24130	Economy	12700.00
0005433922552	24130	Economy	12700.00
0005433922924	24130	Economy	11600.00
0005433922681	24130	Economy	11600.00
0005433036353	24130	Economy	11600.00
0005433922985	24130	Economy	11600.00
0005433922749	24130	Economy	11600.00
0005432206201	24130	Economy	11600.00
0005433036367	24130	Economy	11600.00
0005433036343	24130	Economy	11600.00
0005433922835	24130	Economy	11600.00
0005433922555	24130	Economy	11600.00
0005433922763	24130	Economy	11600.00
0005433922671	24130	Economy	11600.00
0005433922608	24130	Economy	11600.00
0005433922816	24130	Economy	11600.00
0005433922316	24130	Economy	11600.00
0005433922742	24130	Economy	11600.00
0005433922678	24130	Economy	11600.00
0005433922736	24130	Economy	11600.00
0005433036363	24130	Economy	11600.00
0005433922551	24130	Economy	11600.00
0005433922592	24130	Economy	11600.00
0005433922743	24130	Economy	11600.00
0005433036368	24130	Economy	11600.00
0005433036375	24130	Economy	11600.00
0005433036378	24130	Economy	11600.00
0005433922655	24130	Economy	11600.00
0005433922864	24130	Economy	11600.00
0005433036371	24130	Economy	11600.00
0005433922919	24130	Economy	11600.00
0005433036376	24130	Economy	11600.00
0005433922476	24130	Economy	11600.00
0005433922311	24130	Economy	11600.00
0005433922240	24130	Economy	11600.00
0005433922251	24130	Economy	11600.00
0005433036342	24130	Economy	11600.00
0005433922786	24130	Economy	11600.00
0005432206203	24130	Economy	11600.00
0005433929581	24130	Economy	11600.00
0005432206202	24130	Economy	11600.00
0005433922996	24130	Economy	11600.00
0005433036340	24130	Economy	11600.00
0005432749787	24130	Economy	11600.00
0005433036351	24130	Economy	11600.00
0005433036359	24130	Economy	11600.00
0005433036338	24130	Economy	11600.00
0005433922805	24130	Economy	11600.00
0005433922761	24130	Economy	11600.00
0005433036357	24130	Economy	11600.00
0005433922664	24130	Economy	11600.00
0005433036356	24130	Economy	11600.00
0005433922101	24130	Economy	11600.00
0005433036354	24130	Economy	11600.00
0005433036332	24130	Economy	11600.00
0005433922317	24130	Economy	11600.00
0005433922679	24130	Economy	11600.00
0005433036365	24130	Economy	11600.00
0005433923035	24130	Economy	11600.00
0005433922755	24130	Economy	11600.00
0005433922836	24130	Economy	11600.00
0005433036339	24130	Economy	11600.00
0005433922670	24130	Economy	11600.00
0005433922797	24130	Economy	11600.00
0005433922633	24130	Economy	11600.00
0005433922388	24130	Economy	11600.00
0005433036366	24130	Economy	11600.00
0005432207664	24130	Economy	11600.00
0005433922737	24130	Economy	11600.00
0005433923039	24130	Economy	11600.00
0005433929607	24130	Economy	11600.00
0005433036381	24130	Economy	11600.00
0005433036330	24130	Economy	11600.00
0005433922676	24130	Economy	11600.00
0005433929606	24130	Economy	11600.00
0005433929587	24130	Economy	11600.00
0005433036345	24130	Economy	11600.00
0005433929585	24130	Economy	11600.00
0005433922815	24130	Economy	11600.00
0005433036350	24130	Economy	11600.00
0005433931435	24130	Economy	11600.00
0005433036362	24130	Economy	11600.00
0005433929586	24130	Economy	12700.00
0005433922595	24130	Economy	12700.00
0005433922865	24130	Economy	11600.00
0005433036331	24130	Economy	11600.00
0005433036341	24130	Economy	11600.00
0005433036358	24130	Economy	12700.00
0005433931439	24130	Economy	12700.00
0005433923036	24130	Economy	11600.00
0005433922464	24130	Economy	11600.00
0005434028298	24130	Economy	11600.00
0005433922313	24130	Economy	11600.00
0005433922100	24130	Economy	11600.00
0005433036352	24130	Economy	11600.00
0005433036373	24130	Economy	11600.00
0005433922668	24130	Economy	11600.00
0005433922762	24130	Economy	11600.00
0005433922395	24130	Economy	11600.00
0005433922807	24130	Economy	11600.00
0005433036337	24130	Economy	11600.00
0005433036346	24130	Economy	11600.00
0005433922653	24130	Economy	11600.00
0005433922796	24130	Economy	11600.00
0005433922635	24130	Economy	11600.00
0005434028301	24130	Economy	11600.00
0005432206200	24130	Economy	11600.00
0005433922748	24130	Economy	11600.00
0005433036355	24130	Economy	11600.00
0005433922794	24130	Economy	11600.00
0005433922312	24130	Economy	11600.00
0005433036377	24130	Economy	11600.00
0005433922654	24130	Economy	11600.00
0005433922750	24130	Economy	11600.00
0005433922862	24130	Economy	11600.00
0005433922667	24130	Economy	11600.00
0005433922463	24130	Economy	11600.00
0005433922756	24130	Economy	11600.00
0005434028300	24130	Economy	11600.00
0005434028299	24130	Economy	11600.00
0005433922634	24130	Economy	11600.00
0005433922785	24130	Economy	11600.00
0005433036379	24130	Economy	11600.00
0005433036348	24130	Economy	11600.00
0005432207665	24130	Economy	11600.00
0005433929570	24130	Economy	11600.00
0005433931434	24130	Economy	11600.00
0005433922584	24130	Economy	11600.00
0005433922710	24130	Economy	11600.00
0005433036336	24130	Economy	11600.00
0005433036361	24130	Economy	11600.00
0005433922709	24130	Economy	11600.00
0005433922688	24130	Economy	11600.00
0005433922585	24130	Economy	11600.00
0005433922769	24130	Economy	11600.00
0005433922806	24130	Economy	11600.00
0005433036372	24130	Economy	11600.00
0005433922387	24130	Economy	11600.00
0005433922590	24130	Economy	11600.00
0005433922241	24130	Economy	11600.00
0005433036369	24130	Economy	11600.00
0005433922768	24130	Economy	11600.00
0005433036360	24130	Economy	11600.00
0005433922793	24130	Economy	11600.00
0005433922575	24130	Economy	11600.00
0005433922980	24130	Economy	11600.00
0005433922687	24130	Economy	11600.00
0005433922439	24130	Economy	11600.00
0005433922591	24130	Economy	11600.00
0005433922379	24130	Economy	11600.00
0005433036349	24130	Economy	11600.00
0005433922726	24130	Economy	11600.00
0005433922727	24130	Economy	11600.00
0005434725658	275	Business	83700.00
0005433180919	275	Business	83700.00
0005433233707	275	Business	83700.00
0005433233812	275	Business	83700.00
0005433126807	275	Business	83700.00
0005434725541	275	Business	83700.00
0005433233820	275	Business	83700.00
0005434551321	275	Business	83700.00
0005434725554	275	Business	83700.00
0005433180776	275	Business	83700.00
0005433233825	275	Business	83700.00
0005434725574	275	Business	83700.00
0005434551290	275	Business	83700.00
0005434725559	275	Business	83700.00
0005434725619	275	Business	83700.00
0005433180926	275	Business	83700.00
0005434735689	275	Business	83700.00
0005434725553	275	Business	83700.00
0005433289770	275	Business	83700.00
0005434551306	275	Business	83700.00
0005433234022	275	Business	83700.00
0005432277818	275	Business	83700.00
0005434725549	275	Business	83700.00
0005434725657	275	Business	83700.00
0005433113523	275	Business	83700.00
0005434725583	275	Business	83700.00
0005433113514	275	Comfort	47400.00
0005433180879	275	Comfort	47400.00
0005434725639	275	Comfort	47400.00
0005435142590	275	Comfort	47400.00
0005434725602	275	Comfort	47400.00
0005434551322	275	Comfort	47400.00
0005434551310	275	Comfort	47400.00
0005434731172	275	Comfort	47400.00
0005433233849	275	Comfort	47400.00
0005434551285	275	Comfort	47400.00
0005434725542	275	Comfort	47400.00
0005435142595	275	Comfort	47400.00
0005434725547	275	Comfort	47400.00
0005433180903	275	Comfort	47400.00
0005434725661	275	Comfort	47400.00
0005434551278	275	Comfort	47400.00
0005433233899	275	Comfort	47400.00
0005432277820	275	Comfort	47400.00
0005434302465	275	Comfort	47400.00
0005433233959	275	Comfort	47400.00
0005433233893	275	Comfort	47400.00
0005433233708	275	Comfort	47400.00
0005433233648	275	Comfort	47400.00
0005434551298	275	Comfort	47400.00
0005434725576	275	Comfort	47400.00
0005434551274	275	Comfort	47400.00
0005434725644	275	Comfort	47400.00
0005433289791	275	Comfort	47400.00
0005434725563	275	Comfort	47400.00
0005433233937	275	Comfort	47400.00
0005434725616	275	Comfort	47400.00
0005434725605	275	Comfort	47400.00
0005434725647	275	Comfort	47400.00
0005432277825	275	Comfort	47400.00
0005433233850	275	Comfort	47400.00
0005433233791	275	Comfort	47400.00
0005434551293	275	Comfort	47400.00
0005434725603	275	Comfort	47400.00
0005434725590	275	Comfort	47400.00
0005433233676	275	Economy	27900.00
0005434725650	275	Comfort	47400.00
0005434725585	275	Economy	27900.00
0005433180957	275	Economy	27900.00
0005434551283	275	Economy	27900.00
0005434725663	275	Economy	27900.00
0005434551291	275	Economy	27900.00
0005433233701	275	Economy	27900.00
0005434551303	275	Economy	27900.00
0005434725653	275	Economy	27900.00
0005433233699	275	Economy	27900.00
0005432277821	275	Economy	27900.00
0005433180909	275	Economy	27900.00
0005433233703	275	Economy	27900.00
0005433180942	275	Economy	27900.00
0005432277817	275	Economy	27900.00
0005435142589	275	Economy	27900.00
0005433233378	275	Economy	27900.00
0005433289798	275	Economy	27900.00
0005434725645	275	Economy	27900.00
0005433233377	275	Economy	27900.00
0005433113515	275	Economy	27900.00
0005434725594	275	Economy	27900.00
0005433233698	275	Economy	27900.00
0005434725591	275	Economy	27900.00
0005433233524	275	Economy	27900.00
0005434725625	275	Economy	27900.00
0005434725557	275	Economy	27900.00
0005434725624	275	Economy	27900.00
0005435142585	275	Economy	27900.00
0005435142593	275	Economy	27900.00
0005434551320	275	Economy	27900.00
0005434551319	275	Economy	27900.00
0005434551315	275	Economy	27900.00
0005434725600	275	Economy	27900.00
0005434725604	275	Economy	27900.00
0005433233938	275	Economy	27900.00
0005434725556	275	Economy	27900.00
0005434725551	275	Economy	27900.00
0005434551307	275	Economy	27900.00
0005433766612	275	Economy	27900.00
0005434725656	275	Economy	27900.00
0005433233490	275	Economy	27900.00
0005434725569	275	Economy	27900.00
0005434725648	275	Economy	27900.00
0005433233743	275	Economy	27900.00
0005434302463	275	Economy	27900.00
0005434725633	275	Economy	27900.00
0005434731173	275	Economy	27900.00
0005433233485	275	Economy	27900.00
0005433113516	275	Economy	27900.00
0005433111493	275	Economy	27900.00
0005434551268	275	Economy	27900.00
0005433289769	275	Economy	27900.00
0005434725601	275	Economy	27900.00
0005434725582	275	Economy	30700.00
0005434725620	275	Economy	27900.00
0005434725643	275	Economy	30700.00
0005434725621	275	Economy	30700.00
0005433233694	275	Economy	27900.00
0005433289792	275	Economy	27900.00
0005433233662	275	Economy	30700.00
0005434725567	275	Economy	30700.00
0005434725610	275	Economy	27900.00
0005434551317	275	Economy	27900.00
0005433233738	275	Economy	27900.00
0005434725622	275	Economy	27900.00
0005434725548	275	Economy	27900.00
0005434725614	275	Economy	27900.00
0005434551292	275	Economy	27900.00
0005434551276	275	Economy	27900.00
0005432277829	275	Economy	27900.00
0005433233847	275	Economy	27900.00
0005434725655	275	Economy	27900.00
0005433233797	275	Economy	27900.00
0005434725588	275	Economy	27900.00
0005434302462	275	Economy	27900.00
0005433233775	275	Economy	27900.00
0005434725558	275	Economy	27900.00
0005434551281	275	Economy	27900.00
0005433180987	275	Economy	27900.00
0005434551284	275	Economy	27900.00
0005433234144	275	Economy	27900.00
0005432277822	275	Economy	27900.00
0005434551279	275	Economy	27900.00
0005434725568	275	Economy	27900.00
0005433289801	275	Economy	27900.00
0005434551305	275	Economy	27900.00
0005433233796	275	Economy	27900.00
0005433233204	275	Economy	27900.00
0005433233957	275	Economy	27900.00
0005434725649	275	Economy	27900.00
0005435142587	275	Economy	27900.00
0005433113513	275	Economy	27900.00
0005433233826	275	Economy	27900.00
0005434725546	275	Economy	27900.00
0005434725577	275	Economy	27900.00
0005434725592	275	Economy	27900.00
0005434725662	275	Economy	27900.00
0005434031983	275	Economy	27900.00
0005434725641	275	Economy	27900.00
0005434725637	275	Economy	27900.00
0005434725664	275	Economy	27900.00
0005432277826	275	Economy	27900.00
0005434725595	275	Economy	27900.00
0005434725565	275	Economy	27900.00
0005434551277	275	Economy	27900.00
0005434725640	275	Economy	27900.00
0005434551300	275	Economy	27900.00
0005434551275	275	Economy	27900.00
0005433234038	275	Economy	27900.00
0005434725584	275	Economy	27900.00
0005433180866	275	Economy	27900.00
0005434735691	275	Economy	27900.00
0005433233636	275	Economy	27900.00
0005434725646	275	Economy	27900.00
0005434551273	275	Economy	27900.00
0005434725564	275	Economy	27900.00
0005434725634	275	Economy	27900.00
0005434731169	275	Economy	27900.00
0005434725545	275	Economy	27900.00
0005433234037	275	Economy	27900.00
0005434551304	275	Economy	27900.00
0005432277827	275	Economy	27900.00
0005434725632	275	Economy	27900.00
0005434725571	275	Economy	27900.00
0005434551314	275	Economy	27900.00
0005434725575	275	Economy	27900.00
0005433180887	275	Economy	27900.00
0005432277823	275	Economy	27900.00
0005434551288	275	Economy	27900.00
0005435142591	275	Economy	27900.00
0005434725660	275	Economy	27900.00
0005434725597	275	Economy	27900.00
0005434725608	275	Economy	27900.00
0005434725544	275	Economy	27900.00
0005434551316	275	Economy	27900.00
0005433180980	275	Economy	27900.00
0005434731170	275	Economy	27900.00
0005434551286	275	Economy	27900.00
0005434725615	275	Economy	27900.00
0005434551312	275	Economy	27900.00
0005433233539	275	Economy	27900.00
0005434551289	275	Economy	27900.00
0005434725543	275	Economy	27900.00
0005435142598	275	Economy	27900.00
0005434725578	275	Economy	27900.00
0005433111494	275	Economy	27900.00
0005434725613	275	Economy	27900.00
0005435142592	275	Economy	27900.00
0005434551280	275	Economy	27900.00
0005434725651	275	Economy	27900.00
0005434551297	275	Economy	27900.00
0005433233936	275	Economy	27900.00
0005435142596	275	Economy	27900.00
0005434725606	275	Economy	27900.00
0005433180802	275	Economy	27900.00
0005434725586	275	Economy	27900.00
0005434725555	275	Economy	27900.00
0005433233737	275	Economy	27900.00
0005433180904	275	Economy	27900.00
0005434725607	275	Economy	27900.00
0005434725570	275	Economy	27900.00
0005434551271	275	Economy	27900.00
0005434731171	275	Economy	27900.00
0005433131665	275	Economy	27900.00
0005434551282	275	Economy	27900.00
0005434735690	275	Economy	27900.00
0005433180956	275	Economy	27900.00
0005433180944	275	Economy	30700.00
0005433233744	275	Economy	30700.00
0005434725579	275	Economy	30700.00
0005434551318	275	Economy	30700.00
0005434725617	275	Economy	27900.00
0005433111495	275	Economy	27900.00
0005434725572	275	Economy	27900.00
0005434725580	275	Economy	27900.00
0005433233540	275	Economy	27900.00
0005433233939	275	Economy	27900.00
0005434725552	275	Economy	27900.00
0005434725612	275	Economy	27900.00
0005434725561	275	Economy	27900.00
0005433233663	275	Economy	27900.00
0005435142597	275	Economy	27900.00
0005434725598	275	Economy	27900.00
0005433233758	275	Economy	27900.00
0005434551294	275	Economy	27900.00
0005434725654	275	Economy	27900.00
0005433131664	275	Economy	27900.00
0005433180744	275	Economy	27900.00
0005433233649	275	Economy	27900.00
0005433233675	275	Economy	27900.00
0005434735692	275	Economy	27900.00
0005433233790	275	Economy	27900.00
0005433126813	275	Economy	27900.00
0005432277824	275	Economy	27900.00
0005434725623	275	Economy	27900.00
0005434725599	275	Economy	27900.00
0005434725609	275	Economy	27900.00
0005434725611	275	Economy	27900.00
0005434725630	275	Economy	27900.00
0005435142586	275	Economy	27900.00
0005433233426	275	Economy	27900.00
0005434725560	275	Economy	27900.00
0005434551296	275	Economy	27900.00
0005434302464	275	Economy	27900.00
0005434551269	275	Economy	27900.00
0005434725629	275	Economy	27900.00
0005433233700	275	Economy	27900.00
0005433233819	275	Economy	27900.00
0005434551311	275	Economy	27900.00
0005434725638	275	Economy	27900.00
0005433180947	275	Economy	27900.00
0005434551323	275	Economy	27900.00
0005434031981	275	Economy	27900.00
0005434551299	275	Economy	27900.00
0005434551309	275	Economy	27900.00
0005434725652	275	Economy	27900.00
0005434725589	275	Economy	27900.00
0005434725631	275	Economy	27900.00
0005433180888	275	Economy	27900.00
0005433233523	275	Economy	27900.00
0005433126808	275	Economy	27900.00
0005434031982	275	Economy	27900.00
0005433233489	275	Economy	27900.00
0005434725618	275	Economy	27900.00
0005434725635	275	Economy	27900.00
0005433180745	275	Economy	27900.00
0005433111492	275	Economy	27900.00
0005432277819	275	Economy	27900.00
0005433180902	275	Economy	27900.00
0005434551295	275	Economy	27900.00
0005434725642	275	Economy	27900.00
0005433233958	275	Economy	27900.00
0005433233429	275	Economy	27900.00
0005434725566	275	Economy	27900.00
0005434735688	275	Economy	27900.00
0005434725581	275	Economy	27900.00
0005435142588	275	Economy	27900.00
0005434551287	275	Economy	27900.00
0005433180961	275	Economy	27900.00
0005434551308	275	Economy	27900.00
0005434725628	275	Economy	27900.00
0005434551270	275	Economy	27900.00
0005434725626	275	Economy	27900.00
0005433233693	275	Economy	27900.00
0005434725659	275	Economy	27900.00
0005434725550	275	Economy	27900.00
0005434725627	275	Economy	27900.00
0005434551313	275	Economy	27900.00
0005434725562	275	Economy	27900.00
0005433233846	275	Economy	27900.00
0005432277828	275	Economy	27900.00
0005434725587	275	Economy	27900.00
0005434551272	275	Economy	27900.00
0005435142594	275	Economy	27900.00
0005434551301	275	Economy	27900.00
0005434551302	275	Economy	27900.00
0005434302466	275	Economy	27900.00
0005434725573	275	Economy	27900.00
0005434725636	275	Economy	27900.00
0005434725596	275	Economy	27900.00
0005434725593	275	Economy	27900.00
0005433180848	275	Economy	27900.00
0005434724014	9853	Business	83700.00
0005434724452	9853	Business	83700.00
0005434550619	9853	Business	83700.00
0005434724783	9853	Business	83700.00
0005435142410	9853	Business	83700.00
0005434550632	9853	Business	83700.00
0005434550846	9853	Business	83700.00
0005435142452	9853	Business	83700.00
0005434724628	9853	Business	83700.00
0005434550661	9853	Business	83700.00
0005434724617	9853	Business	83700.00
0005434550782	9853	Business	83700.00
0005434724339	9853	Business	83700.00
0005435142474	9853	Business	83700.00
0005435142409	9853	Business	83700.00
0005433289857	9853	Business	83700.00
0005433181130	9853	Business	83700.00
0005434724728	9853	Business	83700.00
0005434723985	9853	Business	83700.00
0005434724506	9853	Business	83700.00
0005434724466	9853	Business	83700.00
0005434724505	9853	Business	83700.00
0005433181132	9853	Business	83700.00
0005434550485	9853	Business	83700.00
0005432199258	9853	Comfort	47400.00
0005433234251	9853	Comfort	47400.00
0005434550767	9853	Comfort	47400.00
0005434725292	9853	Comfort	47400.00
0005433234301	9853	Comfort	47400.00
0005434550707	9853	Comfort	47400.00
0005433234293	9853	Comfort	47400.00
0005434723986	9853	Comfort	47400.00
0005434302406	9853	Comfort	47400.00
0005434550620	9853	Comfort	47400.00
0005433234276	9853	Comfort	47400.00
0005435142489	9853	Comfort	47400.00
0005433181127	9853	Comfort	47400.00
0005434550840	9853	Comfort	47400.00
0005433234290	9853	Comfort	47400.00
0005433181138	9853	Comfort	47400.00
0005433766645	9853	Comfort	47400.00
0005433234303	9853	Comfort	47400.00
0005434550746	9853	Comfort	47400.00
0005434724644	9853	Comfort	47400.00
0005434724639	9853	Comfort	47400.00
0005433234272	9853	Comfort	47400.00
0005433234296	9853	Comfort	47400.00
0005433234255	9853	Comfort	47400.00
0005434550518	9853	Comfort	47400.00
0005433234273	9853	Comfort	47400.00
0005433234268	9853	Comfort	47400.00
0005433289855	9853	Comfort	47400.00
0005434724300	9853	Comfort	47400.00
0005433181131	9853	Comfort	47400.00
0005434724926	9853	Comfort	47400.00
0005434724474	9853	Comfort	47400.00
0005433234287	9853	Comfort	47400.00
0005433234295	9853	Comfort	47400.00
0005434724329	9853	Comfort	47400.00
0005434550703	9853	Comfort	47400.00
0005434724614	9853	Comfort	47400.00
0005433234289	9853	Economy	27900.00
0005434724428	9853	Economy	27900.00
0005435142500	9853	Economy	27900.00
0005433234288	9853	Economy	27900.00
0005434550933	9853	Economy	27900.00
0005433181122	9853	Economy	27900.00
0005434724747	9853	Economy	27900.00
0005433234244	9853	Economy	27900.00
0005434550858	9853	Economy	27900.00
0005434725018	9853	Economy	27900.00
0005434724606	9853	Economy	27900.00
0005433234298	9853	Economy	27900.00
0005434550826	9853	Economy	27900.00
0005434724180	9853	Economy	27900.00
0005433766642	9853	Economy	27900.00
0005435142411	9853	Economy	27900.00
0005434550836	9853	Economy	27900.00
0005433289852	9853	Economy	27900.00
0005433181123	9853	Economy	27900.00
0005434550844	9853	Economy	27900.00
0005433234300	9853	Economy	27900.00
0005434724088	9853	Economy	27900.00
0005434724888	9853	Economy	27900.00
0005433181115	9853	Economy	27900.00
0005435142444	9853	Economy	27900.00
0005434724786	9853	Economy	27900.00
0005433234302	9853	Economy	27900.00
0005433113537	9853	Economy	27900.00
0005433289853	9853	Economy	27900.00
0005434724846	9853	Economy	27900.00
0005433766644	9853	Economy	27900.00
0005434302411	9853	Economy	27900.00
0005434724636	9853	Economy	27900.00
0005433234252	9853	Economy	27900.00
0005433234260	9853	Economy	27900.00
0005433234270	9853	Economy	27900.00
0005434724501	9853	Economy	27900.00
0005434724692	9853	Economy	27900.00
0005433234284	9853	Economy	27900.00
0005433234281	9853	Economy	27900.00
0005433234243	9853	Economy	27900.00
0005434724475	9853	Economy	27900.00
0005435142459	9853	Economy	27900.00
0005433181118	9853	Economy	27900.00
0005433234292	9853	Economy	27900.00
0005434724473	9853	Economy	27900.00
0005434724535	9853	Economy	27900.00
0005434724845	9853	Economy	27900.00
0005434724527	9853	Economy	27900.00
0005433234258	9853	Economy	27900.00
0005433234297	9853	Economy	27900.00
0005433181129	9853	Economy	27900.00
0005434724338	9853	Economy	27900.00
0005433234245	9853	Economy	27900.00
0005433234278	9853	Economy	27900.00
0005434550747	9853	Economy	27900.00
0005434724493	9853	Economy	30700.00
0005434724465	9853	Economy	27900.00
0005435142458	9853	Economy	30700.00
0005434550976	9853	Economy	27900.00
0005433234294	9853	Economy	27900.00
0005434724425	9853	Economy	27900.00
0005434724596	9853	Economy	30700.00
0005434724743	9853	Economy	30700.00
0005434735645	9853	Economy	30700.00
0005433234279	9853	Economy	27900.00
0005433289856	9853	Economy	27900.00
0005434724248	9853	Economy	27900.00
0005434735619	9853	Economy	27900.00
0005434550818	9853	Economy	27900.00
0005433234240	9853	Economy	27900.00
0005434725019	9853	Economy	27900.00
0005434724796	9853	Economy	27900.00
0005434550763	9853	Economy	27900.00
0005434550817	9853	Economy	27900.00
0005433234275	9853	Economy	27900.00
0005433181125	9853	Economy	27900.00
0005433289854	9853	Economy	27900.00
0005432199253	9853	Economy	27900.00
0005433234242	9853	Economy	27900.00
0005434724764	9853	Economy	27900.00
0005434550531	9853	Economy	27900.00
0005433181119	9853	Economy	27900.00
0005433129281	9853	Economy	27900.00
0005433234266	9853	Economy	27900.00
0005433234263	9853	Economy	27900.00
0005434724755	9853	Economy	27900.00
0005434550837	9853	Economy	27900.00
0005434550906	9853	Economy	27900.00
0005434550627	9853	Economy	27900.00
0005434724656	9853	Economy	27900.00
0005433181113	9853	Economy	27900.00
0005434724388	9853	Economy	27900.00
0005434724716	9853	Economy	27900.00
0005434550841	9853	Economy	27900.00
0005435142496	9853	Economy	27900.00
0005434302405	9853	Economy	27900.00
0005433181126	9853	Economy	27900.00
0005433126849	9853	Economy	27900.00
0005434550872	9853	Economy	27900.00
0005433126850	9853	Economy	27900.00
0005434724317	9853	Economy	27900.00
0005433234256	9853	Economy	27900.00
0005434032028	9853	Economy	27900.00
0005433181133	9853	Economy	27900.00
0005433234254	9853	Economy	27900.00
0005434032029	9853	Economy	27900.00
0005434724249	9853	Economy	27900.00
0005434724477	9853	Economy	27900.00
0005434550554	9853	Economy	27900.00
0005434724502	9853	Economy	27900.00
0005433234283	9853	Economy	27900.00
0005433234250	9853	Economy	27900.00
0005434724590	9853	Economy	27900.00
0005434724453	9853	Economy	27900.00
0005434724553	9853	Economy	27900.00
0005434724164	9853	Economy	27900.00
0005434550699	9853	Economy	27900.00
0005433234246	9853	Economy	27900.00
0005434550643	9853	Economy	27900.00
0005434724774	9853	Economy	27900.00
0005434724768	9853	Economy	27900.00
0005433234248	9853	Economy	27900.00
0005434724013	9853	Economy	27900.00
0005434724542	9853	Economy	27900.00
0005434724419	9853	Economy	27900.00
0005434724797	9853	Economy	27900.00
0005433234257	9853	Economy	27900.00
0005435142447	9853	Economy	27900.00
0005433234274	9853	Economy	27900.00
0005434724757	9853	Economy	27900.00
0005434735639	9853	Economy	27900.00
0005434724595	9853	Economy	27900.00
0005433234262	9853	Economy	27900.00
0005432199254	9853	Economy	27900.00
0005434735618	9853	Economy	27900.00
0005434550824	9853	Economy	27900.00
0005433126851	9853	Economy	27900.00
0005433181121	9853	Economy	27900.00
0005434724693	9853	Economy	27900.00
0005435142435	9853	Economy	27900.00
0005434550697	9853	Economy	27900.00
0005434724522	9853	Economy	27900.00
0005434724584	9853	Economy	27900.00
0005433766646	9853	Economy	27900.00
0005434550631	9853	Economy	27900.00
0005434550903	9853	Economy	27900.00
0005434724748	9853	Economy	27900.00
0005434032031	9853	Economy	27900.00
0005434724434	9853	Economy	27900.00
0005434724769	9853	Economy	27900.00
0005433126848	9853	Economy	27900.00
0005433181116	9853	Economy	27900.00
0005434735640	9853	Economy	27900.00
0005434724727	9853	Economy	27900.00
0005434724433	9853	Economy	27900.00
0005434723961	9853	Economy	27900.00
0005433234259	9853	Economy	27900.00
0005433234277	9853	Economy	27900.00
0005433234267	9853	Economy	27900.00
0005433234291	9853	Economy	27900.00
0005434724511	9853	Economy	27900.00
0005435142414	9853	Economy	27900.00
0005434550860	9853	Economy	27900.00
0005434550907	9853	Economy	27900.00
0005434550639	9853	Economy	27900.00
0005435142477	9853	Economy	27900.00
0005434724781	9853	Economy	27900.00
0005434724744	9853	Economy	27900.00
0005433289851	9853	Economy	27900.00
0005434724785	9853	Economy	30700.00
0005435142441	9853	Economy	30700.00
0005432199257	9853	Economy	30700.00
0005434735646	9853	Economy	27900.00
0005434550486	9853	Economy	30700.00
0005434724429	9853	Economy	30700.00
0005432199256	9853	Economy	27900.00
0005434550530	9853	Economy	27900.00
0005433181128	9853	Economy	27900.00
0005434724758	9853	Economy	27900.00
0005434724424	9853	Economy	27900.00
0005433234271	9853	Economy	27900.00
0005434550825	9853	Economy	27900.00
0005434724668	9853	Economy	27900.00
0005435142442	9853	Economy	27900.00
0005433234253	9853	Economy	27900.00
0005434724116	9853	Economy	27900.00
0005434724295	9853	Economy	27900.00
0005434724645	9853	Economy	27900.00
0005433129280	9853	Economy	27900.00
0005434550517	9853	Economy	27900.00
0005434724604	9853	Economy	27900.00
0005434724865	9853	Economy	27900.00
0005434724821	9853	Economy	27900.00
0005433289858	9853	Economy	27900.00
0005433234247	9853	Economy	27900.00
0005433113538	9853	Economy	27900.00
0005435142415	9853	Economy	27900.00
0005434724554	9853	Economy	27900.00
0005434725161	9853	Economy	27900.00
0005434724822	9853	Economy	27900.00
0005434725025	9853	Economy	27900.00
0005434550884	9853	Economy	27900.00
0005433181120	9853	Economy	27900.00
0005432199255	9853	Economy	27900.00
0005435142491	9853	Economy	27900.00
0005435142476	9853	Economy	27900.00
0005433129279	9853	Economy	27900.00
0005433129278	9853	Economy	27900.00
0005434724835	9853	Economy	27900.00
0005433181117	9853	Economy	27900.00
0005433181114	9853	Economy	27900.00
0005433234282	9853	Economy	27900.00
0005433234286	9853	Economy	27900.00
0005435142490	9853	Economy	27900.00
0005434724343	9853	Economy	27900.00
0005434724726	9853	Economy	27900.00
0005434550857	9853	Economy	27900.00
0005433234269	9853	Economy	27900.00
0005434724022	9853	Economy	27900.00
0005433234241	9853	Economy	27900.00
0005433181124	9853	Economy	27900.00
0005434724947	9853	Economy	27900.00
0005433181134	9853	Economy	27900.00
0005434302432	9853	Economy	27900.00
0005434724492	9853	Economy	27900.00
0005434724271	9853	Economy	27900.00
0005434724407	9853	Economy	27900.00
0005435142457	9853	Economy	27900.00
0005434724775	9853	Economy	27900.00
0005433234299	9853	Economy	27900.00
0005434550885	9853	Economy	27900.00
0005434032030	9853	Economy	27900.00
0005433181137	9853	Economy	27900.00
0005434731132	9853	Economy	27900.00
0005434724878	9853	Economy	27900.00
0005433289850	9853	Economy	27900.00
0005434725011	9853	Economy	27900.00
0005433766643	9853	Economy	27900.00
0005434724618	9853	Economy	27900.00
0005433181136	9853	Economy	27900.00
0005434550805	9853	Economy	27900.00
0005434724866	9853	Economy	27900.00
0005434550700	9853	Economy	27900.00
0005434550987	9853	Economy	27900.00
0005434550723	9853	Economy	27900.00
0005434724507	9853	Economy	27900.00
0005433234265	9853	Economy	27900.00
0005433234280	9853	Economy	27900.00
0005435142475	9853	Economy	27900.00
0005433234249	9853	Economy	27900.00
0005434724328	9853	Economy	27900.00
0005434724528	9853	Economy	27900.00
0005434550816	9853	Economy	27900.00
0005434550685	9853	Economy	27900.00
0005434725038	9853	Economy	27900.00
0005433181135	9853	Economy	27900.00
0005434032032	9853	Economy	27900.00
0005433234285	9853	Economy	27900.00
0005433234264	9853	Economy	27900.00
0005434724707	9853	Economy	27900.00
0005434550768	9853	Economy	27900.00
0005434550776	9853	Economy	27900.00
0005434724235	9853	Economy	27900.00
0005434550845	9853	Economy	27900.00
0005435142453	9853	Economy	27900.00
0005433234261	9853	Economy	27900.00
0005432150206	7772	Business	42100.00
0005435213207	7772	Business	42100.00
0005432528084	7772	Business	42100.00
0005435212908	7772	Business	42100.00
0005432528140	7772	Business	42100.00
0005435630946	7772	Business	42100.00
0005434067619	7772	Business	42100.00
0005434067608	7772	Business	42100.00
0005432528153	7772	Business	42100.00
0005435213058	7772	Business	42100.00
0005432528175	7772	Business	42100.00
0005435212859	7772	Business	42100.00
0005432528072	7772	Business	42100.00
0005434067610	7772	Business	42100.00
0005432528136	7772	Business	42100.00
0005435212968	7772	Business	42100.00
0005434067607	7772	Business	42100.00
0005434067635	7772	Business	42100.00
0005432528139	7772	Business	42100.00
0005432528160	7772	Business	42100.00
0005432528085	7772	Business	42100.00
0005435725548	7772	Business	42100.00
0005432528173	7772	Comfort	23900.00
0005432528088	7772	Comfort	23900.00
0005432528171	7772	Comfort	23900.00
0005435212985	7772	Comfort	23900.00
0005434067647	7772	Comfort	23900.00
0005435213173	7772	Comfort	23900.00
0005434067657	7772	Comfort	23900.00
0005435213121	7772	Comfort	23900.00
0005432528138	7772	Comfort	23900.00
0005435630947	7772	Comfort	23900.00
0005432528125	7772	Comfort	23900.00
0005435212876	7772	Comfort	23900.00
0005435213217	7772	Comfort	23900.00
0005432528081	7772	Comfort	23900.00
0005432528162	7772	Comfort	23900.00
0005435213122	7772	Comfort	23900.00
0005432069667	7772	Comfort	23900.00
0005435212925	7772	Comfort	23900.00
0005432528092	7772	Comfort	23900.00
0005432528181	7772	Comfort	23900.00
0005434067627	7772	Comfort	23900.00
0005432069676	7772	Comfort	23900.00
0005432528051	7772	Comfort	23900.00
0005434067672	7772	Comfort	23900.00
0005435212886	7772	Comfort	23900.00
0005432528070	7772	Comfort	23900.00
0005432150203	7772	Comfort	23900.00
0005435213102	7772	Comfort	23900.00
0005435212875	7772	Comfort	23900.00
0005435725550	7772	Comfort	23900.00
0005434067645	7772	Comfort	23900.00
0005435213170	7772	Comfort	23900.00
0005435213188	7772	Comfort	23900.00
0005434067636	7772	Comfort	23900.00
0005434067646	7772	Comfort	23900.00
0005432528176	7772	Comfort	23900.00
0005432528053	7772	Comfort	23900.00
0005432069665	7772	Comfort	23900.00
0005434067628	7772	Comfort	23900.00
0005434067662	7772	Economy	14000.00
0005435213172	7772	Economy	14000.00
0005432528120	7772	Economy	14000.00
0005434067625	7772	Economy	14000.00
0005434067652	7772	Economy	14000.00
0005432528109	7772	Economy	14000.00
0005434067658	7772	Economy	14000.00
0005434067603	7772	Economy	14000.00
0005432528094	7772	Economy	14000.00
0005435212924	7772	Economy	14000.00
0005432528112	7772	Economy	14000.00
0005432150202	7772	Economy	14000.00
0005432069663	7772	Economy	14000.00
0005432528074	7772	Economy	14000.00
0005434067665	7772	Economy	14000.00
0005432528169	7772	Economy	14000.00
0005434067626	7772	Economy	14000.00
0005434067634	7772	Economy	14000.00
0005434067643	7772	Economy	14000.00
0005432528087	7772	Economy	14000.00
0005432537060	7772	Economy	14000.00
0005432535840	7772	Economy	14000.00
0005434067674	7772	Economy	14000.00
0005432528080	7772	Economy	14000.00
0005434067606	7772	Economy	14000.00
0005432528106	7772	Economy	14000.00
0005435213434	7772	Economy	14000.00
0005434067667	7772	Economy	14000.00
0005435725565	7772	Economy	14000.00
0005434067638	7772	Economy	14000.00
0005434067675	7772	Economy	14000.00
0005432069675	7772	Economy	14000.00
0005435213243	7772	Economy	14000.00
0005432528060	7772	Economy	14000.00
0005435212922	7772	Economy	14000.00
0005434067653	7772	Economy	14000.00
0005432528143	7772	Economy	14000.00
0005432528058	7772	Economy	14000.00
0005434067629	7772	Economy	14000.00
0005432150201	7772	Economy	14000.00
0005432069669	7772	Economy	14000.00
0005435212858	7772	Economy	14000.00
0005435213208	7772	Economy	14000.00
0005432528062	7772	Economy	14000.00
0005434067654	7772	Economy	14000.00
0005432528089	7772	Economy	14000.00
0005435212947	7772	Economy	14000.00
0005435213147	7772	Economy	14000.00
0005434067632	7772	Economy	14000.00
0005434067666	7772	Economy	14000.00
0005432528129	7772	Economy	14000.00
0005432528069	7772	Economy	14000.00
0005435213300	7772	Economy	14000.00
0005435212874	7772	Economy	14000.00
0005432528182	7772	Economy	14000.00
0005435212996	7772	Economy	14000.00
0005432528163	7772	Economy	14000.00
0005432528048	7772	Economy	14000.00
0005432528170	7772	Economy	15400.00
0005432428933	7772	Economy	14000.00
0005432528071	7772	Economy	15400.00
0005434067651	7772	Economy	14000.00
0005432528049	7772	Economy	15400.00
0005435725556	7772	Economy	14000.00
0005432528117	7772	Economy	15400.00
0005432528111	7772	Economy	14000.00
0005434067650	7772	Economy	15400.00
0005434067644	7772	Economy	15400.00
0005432528078	7772	Economy	14000.00
0005432528097	7772	Economy	14000.00
0005432528179	7772	Economy	14000.00
0005432069673	7772	Economy	14000.00
0005432528127	7772	Economy	14000.00
0005434067663	7772	Economy	14000.00
0005432528167	7772	Economy	14000.00
0005432528133	7772	Economy	14000.00
0005434067604	7772	Economy	14000.00
0005432528180	7772	Economy	14000.00
0005434067623	7772	Economy	14000.00
0005432528126	7772	Economy	14000.00
0005432528137	7772	Economy	14000.00
0005435212907	7772	Economy	14000.00
0005432537059	7772	Economy	14000.00
0005432528063	7772	Economy	14000.00
0005432528118	7772	Economy	14000.00
0005434067649	7772	Economy	14000.00
0005432528114	7772	Economy	14000.00
0005435212997	7772	Economy	14000.00
0005432528159	7772	Economy	14000.00
0005432528107	7772	Economy	14000.00
0005432528110	7772	Economy	14000.00
0005434067614	7772	Economy	14000.00
0005435213014	7772	Economy	14000.00
0005432533293	7772	Economy	14000.00
0005432535838	7772	Economy	14000.00
0005432528157	7772	Economy	14000.00
0005433656635	7772	Economy	14000.00
0005432528054	7772	Economy	14000.00
0005435213171	7772	Economy	14000.00
0005432528141	7772	Economy	14000.00
0005434067637	7772	Economy	14000.00
0005432069668	7772	Economy	14000.00
0005434067615	7772	Economy	14000.00
0005432528121	7772	Economy	14000.00
0005432069672	7772	Economy	14000.00
0005435213133	7772	Economy	14000.00
0005432150204	7772	Economy	14000.00
0005434067664	7772	Economy	14000.00
0005432528177	7772	Economy	14000.00
0005432069671	7772	Economy	14000.00
0005432528142	7772	Economy	14000.00
0005432528055	7772	Economy	14000.00
0005432528161	7772	Economy	14000.00
0005435212923	7772	Economy	14000.00
0005432428930	7772	Economy	14000.00
0005432428932	7772	Economy	14000.00
0005432069674	7772	Economy	14000.00
0005432069664	7772	Economy	14000.00
0005432428934	7772	Economy	14000.00
0005432528050	7772	Economy	14000.00
0005432528149	7772	Economy	14000.00
0005434067630	7772	Economy	14000.00
0005432528119	7772	Economy	14000.00
0005433656636	7772	Economy	14000.00
0005435213015	7772	Economy	14000.00
0005435212906	7772	Economy	14000.00
0005432428931	7772	Economy	14000.00
0005432528068	7772	Economy	14000.00
0005432528151	7772	Economy	14000.00
0005432528056	7772	Economy	14000.00
0005432528164	7772	Economy	14000.00
0005432528083	7772	Economy	14000.00
0005432069670	7772	Economy	14000.00
0005435213025	7772	Economy	14000.00
0005434067640	7772	Economy	14000.00
0005432528132	7772	Economy	14000.00
0005435213215	7772	Economy	14000.00
0005434067668	7772	Economy	14000.00
0005435213187	7772	Economy	14000.00
0005432528095	7772	Economy	14000.00
0005432150205	7772	Economy	14000.00
0005432528101	7772	Economy	14000.00
0005432528128	7772	Economy	14000.00
0005434067656	7772	Economy	14000.00
0005434067624	7772	Economy	14000.00
0005432528100	7772	Economy	14000.00
0005435213146	7772	Economy	14000.00
0005432528116	7772	Economy	14000.00
0005435212826	7772	Economy	14000.00
0005432528145	7772	Economy	14000.00
0005434067605	7772	Economy	14000.00
0005432528052	7772	Economy	14000.00
0005434067621	7772	Economy	14000.00
0005432528061	7772	Economy	14000.00
0005434067609	7772	Economy	14000.00
0005432528148	7772	Economy	14000.00
0005434067613	7772	Economy	14000.00
0005434067648	7772	Economy	14000.00
0005434067639	7772	Economy	14000.00
0005432533294	7772	Economy	14000.00
0005432528057	7772	Economy	14000.00
0005432528135	7772	Economy	14000.00
0005434067617	7772	Economy	14000.00
0005432528174	7772	Economy	15400.00
0005432528099	7772	Economy	15400.00
0005432528115	7772	Economy	15400.00
0005432528086	7772	Economy	15400.00
0005432528076	7772	Economy	15400.00
0005432528130	7772	Economy	14000.00
0005432528144	7772	Economy	14000.00
0005432150200	7772	Economy	14000.00
0005434067631	7772	Economy	14000.00
0005434067661	7772	Economy	14000.00
0005435213057	7772	Economy	14000.00
0005435725557	7772	Economy	14000.00
0005435725564	7772	Economy	14000.00
0005435630945	7772	Economy	14000.00
0005432528168	7772	Economy	14000.00
0005432528183	7772	Economy	14000.00
0005432528123	7772	Economy	14000.00
0005432528091	7772	Economy	14000.00
0005434067669	7772	Economy	14000.00
0005435213033	7772	Economy	14000.00
0005435213216	7772	Economy	14000.00
0005432528134	7772	Economy	14000.00
0005434067611	7772	Economy	14000.00
0005432528067	7772	Economy	14000.00
0005432528166	7772	Economy	14000.00
0005432533296	7772	Economy	14000.00
0005435212926	7772	Economy	14000.00
0005435212963	7772	Economy	14000.00
0005432528102	7772	Economy	14000.00
0005435212833	7772	Economy	14000.00
0005434067673	7772	Economy	14000.00
0005434067620	7772	Economy	14000.00
0005435213138	7772	Economy	14000.00
0005432528147	7772	Economy	14000.00
0005432528178	7772	Economy	14000.00
0005432528103	7772	Economy	14000.00
0005435213240	7772	Economy	14000.00
0005435213134	7772	Economy	14000.00
0005434067622	7772	Economy	14000.00
0005434067642	7772	Economy	14000.00
0005432069666	7772	Economy	14000.00
0005435213049	7772	Economy	14000.00
0005432535836	7772	Economy	14000.00
0005435213085	7772	Economy	14000.00
0005432528155	7772	Economy	14000.00
0005434067641	7772	Economy	14000.00
0005432528108	7772	Economy	14000.00
0005435725568	7772	Economy	14000.00
0005432528146	7772	Economy	14000.00
0005432528066	7772	Economy	14000.00
0005435213031	7772	Economy	14000.00
0005432528096	7772	Economy	14000.00
0005435213032	7772	Economy	14000.00
0005432535837	7772	Economy	14000.00
0005432528124	7772	Economy	14000.00
0005432528172	7772	Economy	14000.00
0005432528156	7772	Economy	14000.00
0005435212565	7772	Economy	14000.00
0005432528075	7772	Economy	14000.00
0005432528131	7772	Economy	14000.00
0005434067633	7772	Economy	14000.00
0005432528077	7772	Economy	14000.00
0005434067612	7772	Economy	14000.00
0005432528152	7772	Economy	14000.00
0005434067670	7772	Economy	14000.00
0005435213233	7772	Economy	14000.00
0005432528113	7772	Economy	14000.00
0005432535839	7772	Economy	14000.00
0005435725527	7772	Economy	14000.00
0005432528098	7772	Economy	14000.00
0005435212853	7772	Economy	14000.00
0005432528073	7772	Economy	14000.00
0005432528093	7772	Economy	14000.00
0005432528059	7772	Economy	14000.00
0005434067618	7772	Economy	14000.00
0005434067655	7772	Economy	14000.00
0005432528090	7772	Economy	14000.00
0005434067616	7772	Economy	14000.00
0005432528065	7772	Economy	14000.00
0005434067659	7772	Economy	14000.00
0005432528064	7772	Economy	14000.00
0005432528104	7772	Economy	14000.00
0005432528154	7772	Economy	14000.00
0005432528122	7772	Economy	14000.00
0005432533295	7772	Economy	14000.00
0005432528150	7772	Economy	14000.00
0005432528082	7772	Economy	14000.00
0005434067660	7772	Economy	14000.00
0005432528105	7772	Economy	14000.00
0005435212829	7772	Economy	14000.00
0005435725553	7772	Economy	14000.00
0005435212953	7772	Economy	14000.00
0005432528079	7772	Economy	14000.00
0005434067671	7772	Economy	14000.00
0005432528165	7772	Economy	14000.00
0005432528158	7772	Economy	14000.00
0005435424218	5341	Business	43100.00
0005435424299	5341	Business	43100.00
0005435424471	5341	Business	43100.00
0005435613810	5341	Business	43100.00
0005435613717	5341	Business	43100.00
0005435613765	5341	Business	43100.00
0005432840993	5341	Business	43100.00
0005434344267	5341	Business	43100.00
0005435613771	5341	Business	43100.00
0005435424192	5341	Business	43100.00
0005434244743	5341	Business	43100.00
0005434344278	5341	Business	43100.00
0005434244713	5341	Business	43100.00
0005435424758	5341	Business	43100.00
0005435424207	5341	Business	43100.00
0005435613788	5341	Business	43100.00
0005434244860	5341	Business	43100.00
0005435613743	5341	Business	43100.00
0005435613739	5341	Business	43100.00
0005435613797	5341	Business	43100.00
0005435613747	5341	Business	43100.00
0005435613783	5341	Business	43100.00
0005432133226	5341	Business	43100.00
0005434573369	5341	Comfort	24400.00
0005435042840	5341	Comfort	24400.00
0005435097212	5341	Comfort	24400.00
0005435613781	5341	Comfort	24400.00
0005435613751	5341	Comfort	24400.00
0005435491442	5341	Comfort	24400.00
0005435380260	5341	Comfort	24400.00
0005435424332	5341	Comfort	24400.00
0005435613802	5341	Comfort	24400.00
0005435424163	5341	Comfort	24400.00
0005434244763	5341	Comfort	24400.00
0005434244647	5341	Comfort	24400.00
0005434244795	5341	Comfort	24400.00
0005435424430	5341	Comfort	24400.00
0005435613714	5341	Comfort	24400.00
0005435613755	5341	Comfort	24400.00
0005432363390	5341	Comfort	24400.00
0005434573372	5341	Comfort	24400.00
0005432133227	5341	Comfort	24400.00
0005434344272	5341	Comfort	24400.00
0005435613707	5341	Comfort	24400.00
0005435097209	5341	Comfort	24400.00
0005434244737	5341	Comfort	24400.00
0005435613818	5341	Comfort	24400.00
0005435424534	5341	Comfort	24400.00
0005435613778	5341	Comfort	24400.00
0005435613817	5341	Comfort	24400.00
0005435424596	5341	Comfort	24400.00
0005435380263	5341	Comfort	24400.00
0005434573371	5341	Comfort	24400.00
0005434344273	5341	Comfort	24400.00
0005435491440	5341	Comfort	24400.00
0005435613795	5341	Comfort	24400.00
0005435423900	5341	Comfort	24400.00
0005433719115	5341	Comfort	24400.00
0005435424167	5341	Comfort	24400.00
0005435319510	5341	Comfort	24400.00
0005435613740	5341	Comfort	24400.00
0005435424369	5341	Comfort	24400.00
0005434244816	5341	Comfort	24400.00
0005432133225	5341	Comfort	24400.00
0005434244727	5341	Economy	14400.00
0005435424106	5341	Comfort	24400.00
0005434244694	5341	Economy	14400.00
0005435613761	5341	Economy	14400.00
0005435613726	5341	Economy	14400.00
0005434244703	5341	Economy	14400.00
0005435613724	5341	Economy	14400.00
0005435613728	5341	Economy	14400.00
0005434344253	5341	Economy	14400.00
0005435424069	5341	Economy	14400.00
0005434344255	5341	Economy	14400.00
0005435613722	5341	Economy	14400.00
0005434244790	5341	Economy	14400.00
0005435491441	5341	Economy	14400.00
0005435042834	5341	Economy	14400.00
0005434344259	5341	Economy	14400.00
0005434344279	5341	Economy	14400.00
0005434244706	5341	Economy	14400.00
0005433719124	5341	Economy	14400.00
0005434244683	5341	Economy	14400.00
0005435613720	5341	Economy	14400.00
0005435613712	5341	Economy	14400.00
0005434244707	5341	Economy	14400.00
0005435613770	5341	Economy	14400.00
0005434244726	5341	Economy	14400.00
0005434344257	5341	Economy	14400.00
0005435424300	5341	Economy	14400.00
0005434573363	5341	Economy	14400.00
0005435613806	5341	Economy	14400.00
0005435424309	5341	Economy	14400.00
0005435613813	5341	Economy	14400.00
0005435613760	5341	Economy	14400.00
0005434573362	5341	Economy	14400.00
0005435490233	5341	Economy	14400.00
0005435613809	5341	Economy	14400.00
0005435424229	5341	Economy	14400.00
0005435613777	5341	Economy	14400.00
0005435424375	5341	Economy	14400.00
0005435613735	5341	Economy	14400.00
0005435613816	5341	Economy	14400.00
0005435424472	5341	Economy	14400.00
0005435613748	5341	Economy	14400.00
0005432133223	5341	Economy	14400.00
0005432133220	5341	Economy	14400.00
0005435424042	5341	Economy	14400.00
0005435424398	5341	Economy	14400.00
0005435613789	5341	Economy	14400.00
0005435555370	5341	Economy	14400.00
0005435097208	5341	Economy	14400.00
0005432047553	5341	Economy	14400.00
0005435424273	5341	Economy	14400.00
0005435613805	5341	Economy	14400.00
0005435613736	5341	Economy	14400.00
0005432840999	5341	Economy	14400.00
0005435613798	5341	Economy	14400.00
0005435424105	5341	Economy	14400.00
0005435424535	5341	Economy	14400.00
0005434344266	5341	Economy	14400.00
0005435424476	5341	Economy	14400.00
0005435613710	5341	Economy	14400.00
0005434244637	5341	Economy	14400.00
0005434573373	5341	Economy	15800.00
0005435613772	5341	Economy	14400.00
0005435613746	5341	Economy	15800.00
0005435613744	5341	Economy	15800.00
0005435613793	5341	Economy	14400.00
0005435424386	5341	Economy	14400.00
0005435424238	5341	Economy	14400.00
0005435424474	5341	Economy	14400.00
0005435302156	5341	Economy	15800.00
0005435424475	5341	Economy	14400.00
0005435424342	5341	Economy	15800.00
0005435380266	5341	Economy	14400.00
0005435424227	5341	Economy	14400.00
0005432363395	5341	Economy	14400.00
0005435613759	5341	Economy	14400.00
0005435613787	5341	Economy	14400.00
0005435613814	5341	Economy	14400.00
0005434344284	5341	Economy	14400.00
0005435097210	5341	Economy	14400.00
0005435613776	5341	Economy	14400.00
0005435613753	5341	Economy	14400.00
0005434344282	5341	Economy	14400.00
0005435613786	5341	Economy	14400.00
0005435613785	5341	Economy	14400.00
0005434344286	5341	Economy	14400.00
0005434244744	5341	Economy	14400.00
0005435613769	5341	Economy	14400.00
0005435613792	5341	Economy	14400.00
0005435613749	5341	Economy	14400.00
0005435613729	5341	Economy	14400.00
0005434344254	5341	Economy	14400.00
0005435302155	5341	Economy	14400.00
0005435042841	5341	Economy	14400.00
0005434344250	5341	Economy	14400.00
0005434573364	5341	Economy	14400.00
0005435613767	5341	Economy	14400.00
0005434656532	5341	Economy	14400.00
0005435613737	5341	Economy	14400.00
0005435424610	5341	Economy	14400.00
0005435613774	5341	Economy	14400.00
0005434344274	5341	Economy	14400.00
0005435319530	5341	Economy	14400.00
0005435319552	5341	Economy	14400.00
0005435424104	5341	Economy	14400.00
0005435613738	5341	Economy	14400.00
0005435305002	5341	Economy	14400.00
0005435424346	5341	Economy	14400.00
0005435613764	5341	Economy	14400.00
0005435613745	5341	Economy	14400.00
0005435424397	5341	Economy	14400.00
0005432047554	5341	Economy	14400.00
0005435424361	5341	Economy	14400.00
0005432133222	5341	Economy	14400.00
0005435302172	5341	Economy	14400.00
0005435613791	5341	Economy	14400.00
0005434244636	5341	Economy	14400.00
0005435613754	5341	Economy	14400.00
0005434573370	5341	Economy	14400.00
0005434344275	5341	Economy	14400.00
0005435319545	5341	Economy	14400.00
0005435424502	5341	Economy	14400.00
0005432133234	5341	Economy	14400.00
0005435613757	5341	Economy	14400.00
0005435613709	5341	Economy	14400.00
0005435613807	5341	Economy	14400.00
0005435613819	5341	Economy	14400.00
0005435613719	5341	Economy	14400.00
0005435424556	5341	Economy	14400.00
0005434573365	5341	Economy	14400.00
0005434244696	5341	Economy	14400.00
0005434344280	5341	Economy	14400.00
0005432133231	5341	Economy	14400.00
0005435424466	5341	Economy	14400.00
0005435613808	5341	Economy	14400.00
0005434244796	5341	Economy	14400.00
0005434573368	5341	Economy	14400.00
0005434344263	5341	Economy	14400.00
0005434344260	5341	Economy	14400.00
0005432133233	5341	Economy	14400.00
0005435613758	5341	Economy	14400.00
0005435424180	5341	Economy	14400.00
0005435490230	5341	Economy	14400.00
0005434344277	5341	Economy	14400.00
0005434344285	5341	Economy	14400.00
0005435613721	5341	Economy	14400.00
0005434244778	5341	Economy	14400.00
0005434344271	5341	Economy	14400.00
0005432133232	5341	Economy	14400.00
0005435613815	5341	Economy	14400.00
0005435613773	5341	Economy	14400.00
0005434244770	5341	Economy	14400.00
0005434244797	5341	Economy	14400.00
0005432363373	5341	Economy	14400.00
0005432363400	5341	Economy	14400.00
0005435424041	5341	Economy	14400.00
0005435424757	5341	Economy	14400.00
0005434244767	5341	Economy	14400.00
0005435319508	5341	Economy	14400.00
0005434344261	5341	Economy	14400.00
0005432133221	5341	Economy	14400.00
0005434344249	5341	Economy	14400.00
0005435613731	5341	Economy	14400.00
0005434344262	5341	Economy	14400.00
0005435613784	5341	Economy	14400.00
0005432133229	5341	Economy	14400.00
0005435424419	5341	Economy	14400.00
0005435613801	5341	Economy	14400.00
0005435613711	5341	Economy	14400.00
0005434244768	5341	Economy	14400.00
0005434573367	5341	Economy	14400.00
0005435424341	5341	Economy	14400.00
0005435613742	5341	Economy	14400.00
0005434244749	5341	Economy	15800.00
0005432840994	5341	Economy	15800.00
0005435613741	5341	Economy	15800.00
0005435613790	5341	Economy	15800.00
0005435613715	5341	Economy	15800.00
0005434344265	5341	Economy	14400.00
0005435613796	5341	Economy	14400.00
0005435490232	5341	Economy	14400.00
0005435613794	5341	Economy	14400.00
0005435424352	5341	Economy	14400.00
0005435613718	5341	Economy	14400.00
0005435613727	5341	Economy	14400.00
0005435613763	5341	Economy	14400.00
0005435424217	5341	Economy	14400.00
0005435613766	5341	Economy	14400.00
0005434344264	5341	Economy	14400.00
0005435613734	5341	Economy	14400.00
0005435613800	5341	Economy	14400.00
0005435424531	5341	Economy	14400.00
0005432133228	5341	Economy	14400.00
0005435613708	5341	Economy	14400.00
0005434573374	5341	Economy	14400.00
0005435613811	5341	Economy	14400.00
0005435424345	5341	Economy	14400.00
0005435424264	5341	Economy	14400.00
0005434344252	5341	Economy	14400.00
0005434244747	5341	Economy	14400.00
0005432133230	5341	Economy	14400.00
0005435490231	5341	Economy	14400.00
0005435319515	5341	Economy	14400.00
0005435613716	5341	Economy	14400.00
0005434344256	5341	Economy	14400.00
0005434344283	5341	Economy	14400.00
0005435424351	5341	Economy	14400.00
0005435613762	5341	Economy	14400.00
0005434573366	5341	Economy	14400.00
0005435613799	5341	Economy	14400.00
0005435613812	5341	Economy	14400.00
0005435097213	5341	Economy	14400.00
0005434344251	5341	Economy	14400.00
0005435424340	5341	Economy	14400.00
0005435424276	5341	Economy	14400.00
0005435319531	5341	Economy	14400.00
0005435319509	5341	Economy	14400.00
0005434344270	5341	Economy	14400.00
0005435423886	5341	Economy	14400.00
0005435613750	5341	Economy	14400.00
0005435613723	5341	Economy	14400.00
0005435424336	5341	Economy	14400.00
0005435097211	5341	Economy	14400.00
0005435613713	5341	Economy	14400.00
0005435380267	5341	Economy	14400.00
0005435424277	5341	Economy	14400.00
0005435613779	5341	Economy	14400.00
0005435319497	5341	Economy	14400.00
0005432133224	5341	Economy	14400.00
0005434244695	5341	Economy	14400.00
0005434244708	5341	Economy	14400.00
0005435613768	5341	Economy	14400.00
0005434244684	5341	Economy	14400.00
0005432047555	5341	Economy	14400.00
0005434244777	5341	Economy	14400.00
0005434344281	5341	Economy	14400.00
0005435319551	5341	Economy	14400.00
0005435613733	5341	Economy	14400.00
0005434656533	5341	Economy	14400.00
0005435613725	5341	Economy	14400.00
0005434344276	5341	Economy	14400.00
0005435555371	5341	Economy	14400.00
0005435613732	5341	Economy	14400.00
0005432047552	5341	Economy	14400.00
0005435613780	5341	Economy	14400.00
0005435424278	5341	Economy	14400.00
0005435424245	5341	Economy	14400.00
0005435424301	5341	Economy	14400.00
0005434244725	5341	Economy	14400.00
0005435613752	5341	Economy	14400.00
0005434656544	5341	Economy	14400.00
0005435424246	5341	Economy	14400.00
0005435613803	5341	Economy	14400.00
0005435380254	5341	Economy	14400.00
0005435613775	5341	Economy	14400.00
0005435424195	5341	Economy	14400.00
0005435424202	5341	Economy	14400.00
0005435613782	5341	Economy	14400.00
0005434344258	5341	Economy	14400.00
0005434344268	5341	Economy	14400.00
0005435424516	5341	Economy	14400.00
0005435423887	5341	Economy	14400.00
0005435613756	5341	Economy	14400.00
0005434344269	5341	Economy	14400.00
0005435613804	5341	Economy	14400.00
0005435424559	5341	Economy	14400.00
0005435424185	5341	Economy	14400.00
0005434573361	5341	Economy	14400.00
0005434244798	5341	Economy	14400.00
0005435424372	5341	Economy	14400.00
0005435613730	5341	Economy	14400.00
0005432133219	5341	Economy	14400.00
0005435319498	5341	Economy	14400.00
0005435305001	5341	Economy	14400.00
0005435612825	10903	Business	43100.00
0005435424846	10903	Business	43100.00
0005434573195	10903	Business	43100.00
0005435424881	10903	Business	43100.00
0005435424901	10903	Business	43100.00
0005435424899	10903	Business	43100.00
0005434344023	10903	Business	43100.00
0005435424870	10903	Business	43100.00
0005435612396	10903	Business	43100.00
0005434244999	10903	Business	43100.00
0005435612936	10903	Business	43100.00
0005435424894	10903	Business	43100.00
0005434344041	10903	Business	43100.00
0005435097090	10903	Business	43100.00
0005435424869	10903	Business	43100.00
0005435424849	10903	Business	43100.00
0005434244996	10903	Business	43100.00
0005435612563	10903	Business	43100.00
0005435612329	10903	Business	43100.00
0005435424916	10903	Business	43100.00
0005434245004	10903	Business	43100.00
0005435424878	10903	Business	43100.00
0005434343717	10903	Business	43100.00
0005435612769	10903	Business	43100.00
0005435380298	10903	Business	43100.00
0005435613230	10903	Comfort	24400.00
0005435613006	10903	Business	43100.00
0005435319577	10903	Comfort	24400.00
0005435612881	10903	Comfort	24400.00
0005435613070	10903	Comfort	24400.00
0005434244995	10903	Comfort	24400.00
0005434245008	10903	Comfort	24400.00
0005435612982	10903	Comfort	24400.00
0005435424895	10903	Comfort	24400.00
0005434245021	10903	Comfort	24400.00
0005434343730	10903	Comfort	24400.00
0005435319578	10903	Comfort	24400.00
0005432165049	10903	Comfort	24400.00
0005435424890	10903	Comfort	24400.00
0005435612593	10903	Comfort	24400.00
0005434343987	10903	Comfort	24400.00
0005434245011	10903	Comfort	24400.00
0005435612988	10903	Comfort	24400.00
0005432363419	10903	Comfort	24400.00
0005434343914	10903	Comfort	24400.00
0005435424886	10903	Comfort	24400.00
0005435424904	10903	Comfort	24400.00
0005435424879	10903	Comfort	24400.00
0005434573218	10903	Comfort	24400.00
0005435097122	10903	Comfort	24400.00
0005434343865	10903	Comfort	24400.00
0005435613159	10903	Comfort	24400.00
0005434245022	10903	Comfort	24400.00
0005435490195	10903	Comfort	24400.00
0005432841014	10903	Comfort	24400.00
0005434244998	10903	Comfort	24400.00
0005435612786	10903	Comfort	24400.00
0005435612620	10903	Comfort	24400.00
0005435612433	10903	Comfort	24400.00
0005434343801	10903	Comfort	24400.00
0005435612815	10903	Comfort	24400.00
0005435319583	10903	Comfort	24400.00
0005435424893	10903	Economy	14400.00
0005435613093	10903	Economy	14400.00
0005434573237	10903	Economy	14400.00
0005434573238	10903	Economy	14400.00
0005434573267	10903	Economy	14400.00
0005435612484	10903	Economy	14400.00
0005435424889	10903	Economy	14400.00
0005434245013	10903	Economy	14400.00
0005435612740	10903	Economy	14400.00
0005435424897	10903	Economy	14400.00
0005434573203	10903	Economy	14400.00
0005435612766	10903	Economy	14400.00
0005435424900	10903	Economy	14400.00
0005435612326	10903	Economy	14400.00
0005435613231	10903	Economy	14400.00
0005432165045	10903	Economy	14400.00
0005435612580	10903	Economy	14400.00
0005435424875	10903	Economy	14400.00
0005434245025	10903	Economy	14400.00
0005435424914	10903	Economy	14400.00
0005435424902	10903	Economy	14400.00
0005435380297	10903	Economy	14400.00
0005434343882	10903	Economy	14400.00
0005435424853	10903	Economy	14400.00
0005435424908	10903	Economy	14400.00
0005435612625	10903	Economy	14400.00
0005435491430	10903	Economy	14400.00
0005435612608	10903	Economy	14400.00
0005434244997	10903	Economy	14400.00
0005435424909	10903	Economy	14400.00
0005435612517	10903	Economy	14400.00
0005434343913	10903	Economy	14400.00
0005435304159	10903	Economy	14400.00
0005435613264	10903	Economy	14400.00
0005435612885	10903	Economy	14400.00
0005435424915	10903	Economy	14400.00
0005432165048	10903	Economy	14400.00
0005435612907	10903	Economy	14400.00
0005435424888	10903	Economy	14400.00
0005435424905	10903	Economy	14400.00
0005435612836	10903	Economy	14400.00
0005435612777	10903	Economy	14400.00
0005434343742	10903	Economy	14400.00
0005435613202	10903	Economy	14400.00
0005435612902	10903	Economy	14400.00
0005434343975	10903	Economy	14400.00
0005435612639	10903	Economy	14400.00
0005432363422	10903	Economy	14400.00
0005435424898	10903	Economy	14400.00
0005435612941	10903	Economy	14400.00
0005434343986	10903	Economy	14400.00
0005434343916	10903	Economy	14400.00
0005435424848	10903	Economy	14400.00
0005435612874	10903	Economy	14400.00
0005435613122	10903	Economy	14400.00
0005435319579	10903	Economy	14400.00
0005434245012	10903	Economy	15800.00
0005435304162	10903	Economy	14400.00
0005435424884	10903	Economy	15800.00
0005435319584	10903	Economy	15800.00
0005435424865	10903	Economy	14400.00
0005435424857	10903	Economy	14400.00
0005434343819	10903	Economy	14400.00
0005434343985	10903	Economy	14400.00
0005435613161	10903	Economy	15800.00
0005435613256	10903	Economy	15800.00
0005435304160	10903	Economy	14400.00
0005434343784	10903	Economy	15800.00
0005435424855	10903	Economy	14400.00
0005432165047	10903	Economy	14400.00
0005435424885	10903	Economy	14400.00
0005435304161	10903	Economy	14400.00
0005435612898	10903	Economy	14400.00
0005435613066	10903	Economy	14400.00
0005435424892	10903	Economy	14400.00
0005434343970	10903	Economy	14400.00
0005434343785	10903	Economy	14400.00
0005435612762	10903	Economy	14400.00
0005435612924	10903	Economy	14400.00
0005434245017	10903	Economy	14400.00
0005435319585	10903	Economy	14400.00
0005434343881	10903	Economy	14400.00
0005435612785	10903	Economy	14400.00
0005435612963	10903	Economy	14400.00
0005434573196	10903	Economy	14400.00
0005435612876	10903	Economy	14400.00
0005434245005	10903	Economy	14400.00
0005435424882	10903	Economy	14400.00
0005434245010	10903	Economy	14400.00
0005435097098	10903	Economy	14400.00
0005434344004	10903	Economy	14400.00
0005435612617	10903	Economy	14400.00
0005435380294	10903	Economy	14400.00
0005435424871	10903	Economy	14400.00
0005432841015	10903	Economy	14400.00
0005435490202	10903	Economy	14400.00
0005435612716	10903	Economy	14400.00
0005434573232	10903	Economy	14400.00
0005435612621	10903	Economy	14400.00
0005435613039	10903	Economy	14400.00
0005435424887	10903	Economy	14400.00
0005435304158	10903	Economy	14400.00
0005435613013	10903	Economy	14400.00
0005435424850	10903	Economy	14400.00
0005434343979	10903	Economy	14400.00
0005434343767	10903	Economy	14400.00
0005432165046	10903	Economy	14400.00
0005434343782	10903	Economy	14400.00
0005435612631	10903	Economy	14400.00
0005435424883	10903	Economy	14400.00
0005434245009	10903	Economy	14400.00
0005434245019	10903	Economy	14400.00
0005435424862	10903	Economy	14400.00
0005435424911	10903	Economy	14400.00
0005434343844	10903	Economy	14400.00
0005435612962	10903	Economy	14400.00
0005435424859	10903	Economy	14400.00
0005435424863	10903	Economy	14400.00
0005435380295	10903	Economy	14400.00
0005435424891	10903	Economy	14400.00
0005435424903	10903	Economy	14400.00
0005435319580	10903	Economy	14400.00
0005434245003	10903	Economy	14400.00
0005435424910	10903	Economy	14400.00
0005435424852	10903	Economy	14400.00
0005435380296	10903	Economy	14400.00
0005435424866	10903	Economy	14400.00
0005434245016	10903	Economy	14400.00
0005435424847	10903	Economy	14400.00
0005435612882	10903	Economy	14400.00
0005435612707	10903	Economy	14400.00
0005434573219	10903	Economy	14400.00
0005435613007	10903	Economy	14400.00
0005435613162	10903	Economy	14400.00
0005435612901	10903	Economy	14400.00
0005434245014	10903	Economy	14400.00
0005434245002	10903	Economy	14400.00
0005432841016	10903	Economy	14400.00
0005435613203	10903	Economy	14400.00
0005432166905	10903	Economy	14400.00
0005435612768	10903	Economy	14400.00
0005434343912	10903	Economy	14400.00
0005435319581	10903	Economy	14400.00
0005435612784	10903	Economy	14400.00
0005435424858	10903	Economy	14400.00
0005435424912	10903	Economy	14400.00
0005435612642	10903	Economy	14400.00
0005434656559	10903	Economy	14400.00
0005432363420	10903	Economy	14400.00
0005435612842	10903	Economy	14400.00
0005435612926	10903	Economy	14400.00
0005434343824	10903	Economy	14400.00
0005435612867	10903	Economy	14400.00
0005435612844	10903	Economy	14400.00
0005434245023	10903	Economy	14400.00
0005434343766	10903	Economy	14400.00
0005435097121	10903	Economy	14400.00
0005435612461	10903	Economy	14400.00
0005434573239	10903	Economy	14400.00
0005435613078	10903	Economy	14400.00
0005434573194	10903	Economy	15800.00
0005434573112	10903	Economy	15800.00
0005435613135	10903	Economy	15800.00
0005434245024	10903	Economy	15800.00
0005435319582	10903	Economy	15800.00
0005432165044	10903	Economy	14400.00
0005435424854	10903	Economy	15800.00
0005435424868	10903	Economy	14400.00
0005435424861	10903	Economy	14400.00
0005434343852	10903	Economy	14400.00
0005435613152	10903	Economy	14400.00
0005434573221	10903	Economy	14400.00
0005434343776	10903	Economy	14400.00
0005435612320	10903	Economy	14400.00
0005435424867	10903	Economy	14400.00
0005435424864	10903	Economy	14400.00
0005435612954	10903	Economy	14400.00
0005435612850	10903	Economy	14400.00
0005435612814	10903	Economy	14400.00
0005435424874	10903	Economy	14400.00
0005432363421	10903	Economy	14400.00
0005435424851	10903	Economy	14400.00
0005435612843	10903	Economy	14400.00
0005434245007	10903	Economy	14400.00
0005435424880	10903	Economy	14400.00
0005434245015	10903	Economy	14400.00
0005434245000	10903	Economy	14400.00
0005435612983	10903	Economy	14400.00
0005435612682	10903	Economy	14400.00
0005432166904	10903	Economy	14400.00
0005435304163	10903	Economy	14400.00
0005435612991	10903	Economy	14400.00
0005435424873	10903	Economy	14400.00
0005435555350	10903	Economy	14400.00
0005435612616	10903	Economy	14400.00
0005435612923	10903	Economy	14400.00
0005435612674	10903	Economy	14400.00
0005434343799	10903	Economy	14400.00
0005434343851	10903	Economy	14400.00
0005435612731	10903	Economy	14400.00
0005435611990	10903	Economy	14400.00
0005435490200	10903	Economy	14400.00
0005435612978	10903	Economy	14400.00
0005435613048	10903	Economy	14400.00
0005432363418	10903	Economy	14400.00
0005435612755	10903	Economy	14400.00
0005432165043	10903	Economy	14400.00
0005435613164	10903	Economy	14400.00
0005434343843	10903	Economy	14400.00
0005435612837	10903	Economy	14400.00
0005433719143	10903	Economy	14400.00
0005435612730	10903	Economy	14400.00
0005434245001	10903	Economy	14400.00
0005433719146	10903	Economy	14400.00
0005435424856	10903	Economy	14400.00
0005435612899	10903	Economy	14400.00
0005435612767	10903	Economy	14400.00
0005435612985	10903	Economy	14400.00
0005435424876	10903	Economy	14400.00
0005434245018	10903	Economy	14400.00
0005434656558	10903	Economy	14400.00
0005434245006	10903	Economy	14400.00
0005435424896	10903	Economy	14400.00
0005433719144	10903	Economy	14400.00
0005435613114	10903	Economy	14400.00
0005435611989	10903	Economy	14400.00
0005435613198	10903	Economy	14400.00
0005435097134	10903	Economy	14400.00
0005435555359	10903	Economy	14400.00
0005435612756	10903	Economy	14400.00
0005435424907	10903	Economy	14400.00
0005435555358	10903	Economy	14400.00
0005435424872	10903	Economy	14400.00
0005434343915	10903	Economy	14400.00
0005434343820	10903	Economy	14400.00
0005435612790	10903	Economy	14400.00
0005435490196	10903	Economy	14400.00
0005435424913	10903	Economy	14400.00
0005435612793	10903	Economy	14400.00
0005435490199	10903	Economy	14400.00
0005434245020	10903	Economy	14400.00
0005435424877	10903	Economy	14400.00
0005432165042	10903	Economy	14400.00
0005433719145	10903	Economy	14400.00
0005435097120	10903	Economy	14400.00
0005435612681	10903	Economy	14400.00
0005434344005	10903	Economy	14400.00
0005435424906	10903	Economy	14400.00
0005435612990	10903	Economy	14400.00
0005434343966	10903	Economy	14400.00
0005434343933	10903	Economy	14400.00
0005435612875	10903	Economy	14400.00
0005435424860	10903	Economy	14400.00
0005435612708	10903	Economy	14400.00
0005434573269	10903	Economy	14400.00
0005435612870	10903	Economy	14400.00
0005432181730	3319	Business	18800.00
0005432459730	3319	Business	18800.00
0005433507206	3319	Business	18800.00
0005433633860	3319	Business	18800.00
0005432459448	3319	Business	18800.00
0005432459410	3319	Business	18800.00
0005433633857	3319	Business	18800.00
0005433805427	3319	Business	18800.00
0005433633843	3319	Business	18800.00
0005432459409	3319	Business	18800.00
0005432181746	3319	Business	18800.00
0005432459296	3319	Business	18800.00
0005433805400	3319	Business	18800.00
0005433805431	3319	Business	18800.00
0005432181742	3319	Business	18800.00
0005433805425	3319	Business	18800.00
0005432459424	3319	Business	18800.00
0005433507195	3319	Business	18800.00
0005433805415	3319	Business	18800.00
0005433633851	3319	Business	18800.00
0005433633875	3319	Business	18800.00
0005432459416	3319	Business	18800.00
0005433507199	3319	Business	18800.00
0005433633849	3319	Business	18800.00
0005432459452	3319	Business	18800.00
0005432459282	3319	Business	18800.00
0005433805417	3319	Business	18800.00
0005432181736	3319	Business	18800.00
0005433805424	3319	Economy	6900.00
0005433507211	3319	Economy	6900.00
0005433805421	3319	Economy	6900.00
0005433633866	3319	Economy	6900.00
0005433633863	3319	Economy	6900.00
0005433805406	3319	Economy	6900.00
0005432459412	3319	Economy	6300.00
0005433633872	3319	Economy	6300.00
0005432459414	3319	Economy	6300.00
0005433805430	3319	Economy	6300.00
0005433633855	3319	Economy	6300.00
0005432181744	3319	Economy	6300.00
0005432181740	3319	Economy	6300.00
0005432459603	3319	Economy	6300.00
0005432181745	3319	Economy	6300.00
0005433507210	3319	Economy	6300.00
0005432459415	3319	Economy	6300.00
0005433507196	3319	Economy	6300.00
0005433633856	3319	Economy	6300.00
0005432459542	3319	Economy	6300.00
0005432459400	3319	Economy	6300.00
0005432459447	3319	Economy	6300.00
0005432459419	3319	Economy	6300.00
0005433805435	3319	Economy	6300.00
0005433805407	3319	Economy	6300.00
0005433805420	3319	Economy	6300.00
0005433507203	3319	Economy	6300.00
0005432181735	3319	Economy	6300.00
0005433633858	3319	Economy	6300.00
0005432459422	3319	Economy	6300.00
0005433507200	3319	Economy	6300.00
0005433633845	3319	Economy	6300.00
0005432459339	3319	Economy	6300.00
0005432459383	3319	Economy	6300.00
0005433633853	3319	Economy	6300.00
0005432181733	3319	Economy	6300.00
0005433633876	3319	Economy	6300.00
0005432459123	3319	Economy	6300.00
0005433633848	3319	Economy	6300.00
0005433805418	3319	Economy	6300.00
0005433633864	3319	Economy	6300.00
0005432459512	3319	Economy	6300.00
0005432459440	3319	Economy	6300.00
0005433507194	3319	Economy	6300.00
0005432459423	3319	Economy	6300.00
0005433633861	3319	Economy	6300.00
0005433805410	3319	Economy	6300.00
0005432459501	3319	Economy	6300.00
0005432459499	3319	Economy	6300.00
0005433507192	3319	Economy	6300.00
0005433805429	3319	Economy	6300.00
0005433633852	3319	Economy	6300.00
0005433633841	3319	Economy	6300.00
0005432459500	3319	Economy	6300.00
0005432181739	3319	Economy	6300.00
0005433805432	3319	Economy	6300.00
0005432459295	3319	Economy	6300.00
0005432181731	3319	Economy	6300.00
0005432459513	3319	Economy	6300.00
0005433805408	3319	Economy	6300.00
0005432459239	3319	Economy	6300.00
0005432459393	3319	Economy	6300.00
0005432459451	3319	Economy	6300.00
0005433805419	3319	Economy	6300.00
0005433507197	3319	Economy	6300.00
0005433507191	3319	Economy	6300.00
0005433805422	3319	Economy	6900.00
0005432459604	3319	Economy	6900.00
0005433633870	3319	Economy	6900.00
0005433633847	3319	Economy	6900.00
0005433805412	3319	Economy	6900.00
0005433633862	3319	Economy	6300.00
0005433633842	3319	Economy	6300.00
0005432459256	3319	Economy	6300.00
0005433507209	3319	Economy	6300.00
0005433633859	3319	Economy	6900.00
0005433805409	3319	Economy	6300.00
0005432181737	3319	Economy	6300.00
0005432459520	3319	Economy	6300.00
0005433507208	3319	Economy	6300.00
0005433805411	3319	Economy	6300.00
0005432459580	3319	Economy	6300.00
0005432459328	3319	Economy	6300.00
0005433805423	3319	Economy	6300.00
0005432459418	3319	Economy	6300.00
0005432459232	3319	Economy	6300.00
0005433805434	3319	Economy	6300.00
0005433507207	3319	Economy	6300.00
0005432459360	3319	Economy	6300.00
0005433805402	3319	Economy	6300.00
0005433805404	3319	Economy	6300.00
0005432181748	3319	Economy	6300.00
0005432459371	3319	Economy	6300.00
0005432181738	3319	Economy	6300.00
0005433805405	3319	Economy	6300.00
0005433507202	3319	Economy	6300.00
0005432459460	3319	Economy	6300.00
0005432459332	3319	Economy	6300.00
0005433805414	3319	Economy	6300.00
0005433805433	3319	Economy	6300.00
0005433633844	3319	Economy	6300.00
0005432459519	3319	Economy	6300.00
0005433805428	3319	Economy	6300.00
0005433805413	3319	Economy	6300.00
0005432459602	3319	Economy	6300.00
0005433805403	3319	Economy	6300.00
0005433633873	3319	Economy	6300.00
0005433507193	3319	Economy	6300.00
0005432181732	3319	Economy	6300.00
0005433633854	3319	Economy	6300.00
0005433507205	3319	Economy	6300.00
0005433507201	3319	Economy	6300.00
0005432459324	3319	Economy	6300.00
0005432181743	3319	Economy	6300.00
0005433507204	3319	Economy	6300.00
0005432459481	3319	Economy	6300.00
0005432181751	3319	Economy	6300.00
0005432459394	3319	Economy	6300.00
0005433633846	3319	Economy	6300.00
0005433633869	3319	Economy	6300.00
0005432459317	3319	Economy	6300.00
0005433507198	3319	Economy	6300.00
0005432459476	3319	Economy	6300.00
0005432181747	3319	Economy	6300.00
0005432181749	3319	Economy	6300.00
0005433805416	3319	Economy	6300.00
0005432459477	3319	Economy	6300.00
0005433805426	3319	Economy	6300.00
0005433633871	3319	Economy	6300.00
0005433633865	3319	Economy	6300.00
0005432459403	3319	Economy	6300.00
0005432459361	3319	Economy	6300.00
0005433633867	3319	Economy	6300.00
0005433633868	3319	Economy	6300.00
0005433633850	3319	Economy	6300.00
0005433633874	3319	Economy	6300.00
0005432459240	3319	Economy	6300.00
0005432181741	3319	Economy	6300.00
0005432181734	3319	Economy	6300.00
0005432459417	3319	Economy	6300.00
0005433805401	3319	Economy	6300.00
0005432181750	3319	Economy	6300.00
0005435885081	3318	Business	18800.00
0005435885047	3318	Business	18800.00
0005435884901	3318	Business	18800.00
0005435885060	3318	Business	18800.00
0005435884989	3318	Business	18800.00
0005435884988	3318	Economy	6900.00
0005435884894	3318	Economy	6900.00
0005435884705	3318	Economy	6300.00
0005435885017	3318	Economy	6300.00
0005435884873	3318	Economy	6300.00
0005435884815	3318	Economy	6300.00
0005435884879	3318	Economy	6300.00
0005435884812	3318	Economy	6300.00
0005435885076	3318	Economy	6300.00
0005435884980	3318	Economy	6300.00
0005435884952	3318	Economy	6300.00
0005435885003	3318	Economy	6300.00
0005435884891	3318	Economy	6300.00
0005435885077	3318	Economy	6300.00
0005435885046	3318	Economy	6300.00
0005435885005	3318	Economy	6300.00
0005435885002	3318	Economy	6900.00
0005435884916	3318	Economy	6900.00
0005435884998	3318	Economy	6300.00
0005435884999	3318	Economy	6300.00
0005435885004	3318	Economy	6300.00
0005435884784	3318	Economy	6300.00
0005435884892	3318	Economy	6300.00
0005435884878	3318	Economy	6300.00
0005435884639	3318	Economy	6300.00
0005435884962	3318	Economy	6300.00
0005435884976	3318	Economy	6300.00
0005435884695	3318	Economy	6300.00
0005435885061	3318	Economy	6300.00
0005435885133	3318	Economy	6300.00
0005435885031	3318	Economy	6300.00
0005435884785	3318	Economy	6300.00
0005435884925	3318	Economy	6300.00
0005435884816	3318	Economy	6300.00
0005435884973	3318	Economy	6300.00
0005435885075	3318	Economy	6300.00
0005435885062	3318	Economy	6300.00
0005435884982	3318	Economy	6300.00
0005435884640	3318	Economy	6300.00
0005435885080	3318	Economy	6300.00
0005435884941	3318	Economy	6300.00
0005435885303	8203	Business	18800.00
0005432459926	8203	Business	18800.00
0005433507009	8203	Business	18800.00
0005433507038	8203	Business	18800.00
0005435885311	8203	Business	18800.00
0005432459969	8203	Business	18800.00
0005432459970	8203	Business	18800.00
0005435885308	8203	Business	18800.00
0005432459921	8203	Business	18800.00
0005433507018	8203	Business	18800.00
0005432459929	8203	Business	18800.00
0005435885300	8203	Business	18800.00
0005432459964	8203	Business	18800.00
0005432459962	8203	Business	18800.00
0005433506919	8203	Business	18800.00
0005432042735	8203	Business	18800.00
0005435885317	8203	Business	18800.00
0005432459932	8203	Business	18800.00
0005435885290	8203	Business	18800.00
0005432459946	8203	Business	18800.00
0005432459923	8203	Business	18800.00
0005433506918	8203	Economy	6900.00
0005435885283	8203	Economy	6900.00
0005432459966	8203	Economy	6900.00
0005435885310	8203	Economy	6300.00
0005433507006	8203	Economy	6300.00
0005433507056	8203	Economy	6300.00
0005432459951	8203	Economy	6300.00
0005432042732	8203	Economy	6300.00
0005435885294	8203	Economy	6300.00
0005434312323	8203	Economy	6300.00
0005432459918	8203	Economy	6300.00
0005432459937	8203	Economy	6300.00
0005432459963	8203	Economy	6300.00
0005432459935	8203	Economy	6300.00
0005432459955	8203	Economy	6300.00
0005433507039	8203	Economy	6300.00
0005432459942	8203	Economy	6300.00
0005432042724	8203	Economy	6300.00
0005432459949	8203	Economy	6300.00
0005432459956	8203	Economy	6300.00
0005432042737	8203	Economy	6300.00
0005432042736	8203	Economy	6300.00
0005432459928	8203	Economy	6300.00
0005435885282	8203	Economy	6300.00
0005435885320	8203	Economy	6300.00
0005432459920	8203	Economy	6300.00
0005432042730	8203	Economy	6300.00
0005432459925	8203	Economy	6300.00
0005432042734	8203	Economy	6300.00
0005433506992	8203	Economy	6300.00
0005435885305	8203	Economy	6300.00
0005435885287	8203	Economy	6300.00
0005433507005	8203	Economy	6300.00
0005432459953	8203	Economy	6300.00
0005433507028	8203	Economy	6300.00
0005435885279	8203	Economy	6300.00
0005432459941	8203	Economy	6300.00
0005435885319	8203	Economy	6300.00
0005435885306	8203	Economy	6300.00
0005434312322	8203	Economy	6300.00
0005432042731	8203	Economy	6300.00
0005433507008	8203	Economy	6300.00
0005435885314	8203	Economy	6300.00
0005435885288	8203	Economy	6300.00
0005432042729	8203	Economy	6300.00
0005435885291	8203	Economy	6300.00
0005432459938	8203	Economy	6300.00
0005432459919	8203	Economy	6300.00
0005433507017	8203	Economy	6300.00
0005435885307	8203	Economy	6300.00
0005432459939	8203	Economy	6300.00
0005432459950	8203	Economy	6900.00
0005432459957	8203	Economy	6900.00
0005432459930	8203	Economy	6900.00
0005435885281	8203	Economy	6900.00
0005432459961	8203	Economy	6300.00
0005435885318	8203	Economy	6300.00
0005433506917	8203	Economy	6300.00
0005432459943	8203	Economy	6900.00
0005432459965	8203	Economy	6300.00
0005435885278	8203	Economy	6300.00
0005432459936	8203	Economy	6300.00
0005435885286	8203	Economy	6300.00
0005432459959	8203	Economy	6300.00
0005432459924	8203	Economy	6300.00
0005433507055	8203	Economy	6300.00
0005435885312	8203	Economy	6300.00
0005432459945	8203	Economy	6300.00
0005433507007	8203	Economy	6300.00
0005432459931	8203	Economy	6300.00
0005435885292	8203	Economy	6300.00
0005432042727	8203	Economy	6300.00
0005435885280	8203	Economy	6300.00
0005435885313	8203	Economy	6300.00
0005432459947	8203	Economy	6300.00
0005432459940	8203	Economy	6300.00
0005432459967	8203	Economy	6300.00
0005432459922	8203	Economy	6300.00
0005432459948	8203	Economy	6300.00
0005432459968	8203	Economy	6300.00
0005434312324	8203	Economy	6300.00
0005435885296	8203	Economy	6300.00
0005435885299	8203	Economy	6300.00
0005435885302	8203	Economy	6300.00
0005435885309	8203	Economy	6300.00
0005432459952	8203	Economy	6300.00
0005435885316	8203	Economy	6300.00
0005432042733	8203	Economy	6300.00
0005432459933	8203	Economy	6300.00
0005435885284	8203	Economy	6300.00
0005435885315	8203	Economy	6300.00
0005435885293	8203	Economy	6300.00
0005435885297	8203	Economy	6300.00
0005435885301	8203	Economy	6300.00
0005435885304	8203	Economy	6300.00
0005435885289	8203	Economy	6300.00
0005432459934	8203	Economy	6300.00
0005435885298	8203	Economy	6300.00
0005432459927	8203	Economy	6300.00
0005433507029	8203	Economy	6300.00
0005432042726	8203	Economy	6300.00
0005432459960	8203	Economy	6300.00
0005432042738	8203	Economy	6300.00
0005435885295	8203	Economy	6300.00
0005432459971	8203	Economy	6300.00
0005432042725	8203	Economy	6300.00
0005435885285	8203	Economy	6300.00
0005432042728	8203	Economy	6300.00
0005432459944	8203	Economy	6300.00
0005432459958	8203	Economy	6300.00
0005432459954	8203	Economy	6300.00
0005433633654	8305	Business	18800.00
0005434271301	8305	Business	18800.00
0005433805080	8305	Business	18800.00
0005433633477	8305	Business	18800.00
0005433805027	8305	Business	18800.00
0005433805223	8305	Business	18800.00
0005433633467	8305	Business	18800.00
0005433633513	8305	Business	18800.00
0005433804953	8305	Business	18800.00
0005433633655	8305	Business	18800.00
0005433633432	8305	Business	18800.00
0005434143714	8305	Business	18800.00
0005433633541	8305	Business	18800.00
0005433633388	8305	Business	18800.00
0005433805108	8305	Business	18800.00
0005434143713	8305	Economy	6900.00
0005433633537	8305	Economy	6900.00
0005433633465	8305	Economy	6900.00
0005433633530	8305	Economy	6300.00
0005433805095	8305	Economy	6300.00
0005433633463	8305	Economy	6300.00
0005433805231	8305	Economy	6300.00
0005433805238	8305	Economy	6300.00
0005433633514	8305	Economy	6300.00
0005433633698	8305	Economy	6300.00
0005433633462	8305	Economy	6300.00
0005435854059	8305	Economy	6300.00
0005433805156	8305	Economy	6300.00
0005433633656	8305	Economy	6300.00
0005433805092	8305	Economy	6300.00
0005433805260	8305	Economy	6300.00
0005435854057	8305	Economy	6300.00
0005433805195	8305	Economy	6300.00
0005433805073	8305	Economy	6300.00
0005433633423	8305	Economy	6300.00
0005433805196	8305	Economy	6300.00
0005435854058	8305	Economy	6300.00
0005433805134	8305	Economy	6300.00
0005433805220	8305	Economy	6300.00
0005433805107	8305	Economy	6300.00
0005433805072	8305	Economy	6300.00
0005433633466	8305	Economy	6900.00
0005433633486	8305	Economy	6900.00
0005434271296	8305	Economy	6300.00
0005433805096	8305	Economy	6900.00
0005433633631	8305	Economy	6300.00
0005433633649	8305	Economy	6300.00
0005433805139	8305	Economy	6300.00
0005433633624	8305	Economy	6300.00
0005433633449	8305	Economy	6300.00
0005434271295	8305	Economy	6300.00
0005433805232	8305	Economy	6300.00
0005433633401	8305	Economy	6300.00
0005433805239	8305	Economy	6300.00
0005435854060	8305	Economy	6300.00
0005433633484	8305	Economy	6300.00
0005433805121	8305	Economy	6300.00
0005433805085	8305	Economy	6300.00
0005433633525	8305	Economy	6300.00
0005433633531	8305	Economy	6300.00
0005433633526	8305	Economy	6300.00
0005433805119	8305	Economy	6300.00
0005433633650	8305	Economy	6300.00
0005433633663	8305	Economy	6300.00
0005433805221	8305	Economy	6300.00
0005433804954	8305	Economy	6300.00
0005433805093	8305	Economy	6300.00
0005433633485	8305	Economy	6300.00
0005433805197	8305	Economy	6300.00
0005433633389	8305	Economy	6300.00
0005433805122	8305	Economy	6300.00
0005433805180	8305	Economy	6300.00
0005434183569	8237	Economy	6300.00
0005434183568	8237	Economy	6300.00
0005434183570	8237	Economy	6300.00
0005433453764	4525	Business	9900.00
0005432727955	4525	Business	9900.00
0005433722230	4525	Business	9900.00
0005432383229	4525	Business	9900.00
0005433194858	4525	Business	9900.00
0005432383221	4525	Business	9900.00
0005432383234	4525	Business	9900.00
0005433194859	4525	Economy	3300.00
0005432383230	4525	Economy	3300.00
0005432383203	4525	Economy	3300.00
0005432383219	4525	Economy	3300.00
0005433194860	4525	Economy	3300.00
0005432727953	4525	Economy	3300.00
0005432383202	4525	Economy	3300.00
0005432383217	4525	Economy	3600.00
0005432383216	4525	Economy	3600.00
0005432383208	4525	Economy	3600.00
0005432383214	4525	Economy	3300.00
0005433722231	4525	Economy	3300.00
0005432727948	4525	Economy	3300.00
0005432383212	4525	Economy	3300.00
0005432383226	4525	Economy	3300.00
0005432727949	4525	Economy	3300.00
0005432383237	4525	Economy	3300.00
0005432727957	4525	Economy	3300.00
0005432727951	4525	Economy	3300.00
0005432383223	4525	Economy	3300.00
0005432383213	4525	Economy	3300.00
0005432383215	4525	Economy	3300.00
0005432383236	4525	Economy	3300.00
0005432383231	4525	Economy	3300.00
0005432383211	4525	Economy	3300.00
0005432383220	4525	Economy	3300.00
0005432727947	4525	Economy	3300.00
0005432383218	4525	Economy	3300.00
0005432383206	4525	Economy	3300.00
0005432383205	4525	Economy	3300.00
0005432727946	4525	Economy	3300.00
0005432727950	4525	Economy	3300.00
0005432383210	4525	Economy	3300.00
0005433454878	4525	Economy	3300.00
0005432383232	4525	Economy	3300.00
0005432727952	4525	Economy	3300.00
0005432383224	4525	Economy	3300.00
0005432727954	4525	Economy	3300.00
0005433454877	4525	Economy	3300.00
0005432727956	4525	Economy	3300.00
0005432383235	4525	Economy	3300.00
0005432383209	4525	Economy	3300.00
0005432727958	4525	Economy	3300.00
0005432383228	4525	Economy	3300.00
0005432383225	4525	Economy	3300.00
0005432383207	4525	Economy	3300.00
0005432383204	4525	Economy	3300.00
0005432383233	4525	Economy	3300.00
0005432383222	4525	Economy	3300.00
0005432383227	4525	Economy	3300.00
0005432382767	30186	Business	9900.00
0005432382647	30186	Business	9900.00
0005432382794	30186	Business	9900.00
0005432382718	30186	Business	9900.00
0005432382880	30186	Business	9900.00
0005432382857	30186	Business	9900.00
0005433722136	30186	Business	9900.00
0005432382811	30186	Business	9900.00
0005433194848	30186	Business	9900.00
0005432382584	30186	Business	9900.00
0005432382646	30186	Economy	3300.00
0005432382876	30186	Economy	3300.00
0005432727764	30186	Economy	3300.00
0005432382741	30186	Economy	3300.00
0005433194849	30186	Economy	3300.00
0005432382910	30186	Economy	3300.00
0005432382782	30186	Economy	3300.00
0005432382785	30186	Economy	3300.00
0005432382709	30186	Economy	3600.00
0005432382792	30186	Economy	3300.00
0005433722152	30186	Economy	3600.00
0005433451612	30186	Economy	3600.00
0005432382815	30186	Economy	3600.00
0005432382710	30186	Economy	3300.00
0005432382878	30186	Economy	3300.00
0005432382666	30186	Economy	3300.00
0005432382735	30186	Economy	3300.00
0005433722153	30186	Economy	3300.00
0005432727827	30186	Economy	3300.00
0005432382786	30186	Economy	3300.00
0005433194831	30186	Economy	3300.00
0005432727836	30186	Economy	3300.00
0005432727865	30186	Economy	3300.00
0005432727864	30186	Economy	3300.00
0005432382798	30186	Economy	3300.00
0005432727805	30186	Economy	3300.00
0005432382793	30186	Economy	3300.00
0005433722149	30186	Economy	3300.00
0005432382875	30186	Economy	3300.00
0005432382757	30186	Economy	3300.00
0005433451611	30186	Economy	3300.00
0005433722150	30186	Economy	3300.00
0005433722123	30186	Economy	3300.00
0005432382739	30186	Economy	3300.00
0005432382696	30186	Economy	3300.00
0005432382812	30186	Economy	3300.00
0005432382713	30186	Economy	3300.00
0005432382874	30186	Economy	3300.00
0005432382906	30186	Economy	3300.00
0005432727834	30186	Economy	3300.00
0005432727863	30186	Economy	3300.00
0005432382731	30186	Economy	3300.00
0005432727850	30186	Economy	3300.00
0005433722137	30186	Economy	3300.00
0005432727854	30186	Economy	3300.00
0005432727862	30186	Economy	3300.00
0005432382877	30186	Economy	3300.00
0005432382740	30186	Economy	3300.00
0005432727826	30186	Economy	3300.00
0005433194850	30186	Economy	3300.00
0005432382719	30186	Economy	3300.00
0005432727861	30186	Economy	3300.00
0005432382865	30186	Economy	3300.00
0005432727798	30186	Economy	3300.00
0005432382783	30186	Economy	3300.00
0005432382799	30186	Economy	3300.00
0005432382665	30186	Economy	3300.00
0005432727831	30186	Economy	3300.00
0005432727791	30186	Economy	3300.00
0005432382818	30186	Economy	3300.00
0005432382695	30186	Economy	3300.00
0005433451598	30186	Economy	3300.00
0005432382734	30186	Economy	3300.00
0005432382694	30186	Economy	3300.00
0005432382837	30186	Economy	3300.00
0005432382702	30186	Economy	3300.00
0005432727858	30186	Economy	3300.00
0005432727837	30186	Economy	3300.00
0005435541037	1768	Business	57200.00
0005435529290	1768	Business	57200.00
0005435541024	1768	Business	57200.00
0005435541032	1768	Business	57200.00
0005435529293	1768	Business	57200.00
0005435541036	1768	Business	57200.00
0005432294489	1768	Business	57200.00
0005433516896	1768	Business	57200.00
0005435529296	1768	Business	57200.00
0005435541038	1768	Economy	19100.00
0005433516901	1768	Economy	19100.00
0005435541025	1768	Economy	19100.00
0005433516897	1768	Economy	19100.00
0005433516899	1768	Economy	19100.00
0005435541035	1768	Economy	21000.00
0005435529299	1768	Economy	21000.00
0005435529282	1768	Economy	21000.00
0005432294490	1768	Economy	21000.00
0005432924993	1768	Economy	19100.00
0005435529289	1768	Economy	19100.00
0005433516893	1768	Economy	19100.00
0005435541029	1768	Economy	19100.00
0005435529287	1768	Economy	19100.00
0005435529288	1768	Economy	19100.00
0005435541027	1768	Economy	19100.00
0005435529281	1768	Economy	19100.00
0005435529283	1768	Economy	19100.00
0005435529294	1768	Economy	19100.00
0005435541030	1768	Economy	19100.00
0005435541042	1768	Economy	19100.00
0005432925002	1768	Economy	19100.00
0005435541033	1768	Economy	19100.00
0005432294491	1768	Economy	19100.00
0005435529286	1768	Economy	19100.00
0005435541034	1768	Economy	19100.00
0005435529292	1768	Economy	19100.00
0005435541041	1768	Economy	19100.00
0005435529297	1768	Economy	19100.00
0005435541026	1768	Economy	19100.00
0005433516898	1768	Economy	19100.00
0005435541039	1768	Economy	19100.00
0005433516900	1768	Economy	19100.00
0005432925003	1768	Economy	19100.00
0005433516895	1768	Economy	19100.00
0005435529291	1768	Economy	19100.00
0005435529279	1768	Economy	19100.00
0005435529278	1768	Economy	19100.00
0005435541031	1768	Economy	19100.00
0005435529298	1768	Economy	19100.00
0005435541023	1768	Economy	19100.00
0005435529280	1768	Economy	19100.00
0005435529285	1768	Economy	19100.00
0005432924994	1768	Economy	19100.00
0005433516894	1768	Economy	19100.00
0005435541028	1768	Economy	19100.00
0005435541040	1768	Economy	19100.00
0005435529295	1768	Economy	19100.00
0005433516902	1768	Economy	19100.00
0005435529284	1768	Economy	19100.00
0005435529277	1768	Economy	19100.00
0005433516839	21979	Business	57200.00
0005435517769	21979	Business	57200.00
0005435517772	21979	Business	57200.00
0005435517793	21979	Business	57200.00
0005435517756	21979	Business	57200.00
0005433516770	21979	Business	57200.00
0005435540864	21979	Business	57200.00
0005435540798	21979	Economy	19100.00
0005435517720	21979	Economy	19100.00
0005435517834	21979	Economy	19100.00
0005435517745	21979	Economy	19100.00
0005435517744	21979	Economy	19100.00
0005435517762	21979	Economy	19100.00
0005433516769	21979	Economy	19100.00
0005435540863	21979	Economy	21000.00
0005435517795	21979	Economy	21000.00
0005435540799	21979	Economy	21000.00
0005435540800	21979	Economy	19100.00
0005435517743	21979	Economy	19100.00
0005435517805	21979	Economy	19100.00
0005435517811	21979	Economy	19100.00
0005435517708	21979	Economy	19100.00
0005435517751	21979	Economy	19100.00
0005433516800	21979	Economy	19100.00
0005435540854	21979	Economy	19100.00
0005435517650	21979	Economy	19100.00
0005435517738	21979	Economy	19100.00
0005435540813	21979	Economy	19100.00
0005432925043	21979	Economy	19100.00
0005435517719	21979	Economy	19100.00
0005435540812	21979	Economy	19100.00
0005432925042	21979	Economy	19100.00
0005435517798	21979	Economy	19100.00
0005435517750	21979	Economy	19100.00
0005435540868	21979	Economy	19100.00
0005435540866	21979	Economy	19100.00
0005435517794	21979	Economy	19100.00
0005432925040	21979	Economy	19100.00
0005435540880	21979	Economy	19100.00
0005435540811	21979	Economy	19100.00
0005435517768	21979	Economy	19100.00
0005435540836	21979	Economy	19100.00
0005432925041	21979	Economy	19100.00
0005435517651	21979	Economy	19100.00
0005435517755	21979	Economy	19100.00
0005433516834	21979	Economy	19100.00
0005433516835	21979	Economy	19100.00
0005435540801	21979	Economy	19100.00
0005433516801	21979	Economy	19100.00
0005435517761	21979	Economy	19100.00
0005433516843	21979	Economy	19100.00
0005435517742	21979	Economy	19100.00
0005433516811	21979	Economy	19100.00
0005435517796	21979	Economy	19100.00
0005435517797	21979	Economy	19100.00
0005432839060	7404	Business	18500.00
0005435252577	7404	Business	18500.00
0005432839057	7404	Business	18500.00
0005434458836	7404	Business	18500.00
0005435252556	7404	Business	18500.00
0005434458824	7404	Business	18500.00
0005432839069	7404	Business	18500.00
0005432839062	7404	Business	18500.00
0005432823450	7404	Business	18500.00
0005434458820	7404	Business	18500.00
0005434458830	7404	Economy	6200.00
0005432839066	7404	Economy	6200.00
0005432839053	7404	Economy	6200.00
0005432839061	7404	Economy	6200.00
0005432073393	7404	Economy	6200.00
0005435491410	7404	Economy	6200.00
0005432839072	7404	Economy	6200.00
0005432839056	7404	Economy	6200.00
0005435252567	7404	Economy	6800.00
0005434458829	7404	Economy	6800.00
0005432073395	7404	Economy	6200.00
0005435252548	7404	Economy	6200.00
0005434458819	7404	Economy	6200.00
0005432073394	7404	Economy	6200.00
0005434458817	7404	Economy	6200.00
0005432839059	7404	Economy	6200.00
0005432839081	7404	Economy	6200.00
0005432839080	7404	Economy	6200.00
0005432839070	7404	Economy	6200.00
0005435491428	7404	Economy	6200.00
0005432839076	7404	Economy	6200.00
0005434458835	7404	Economy	6200.00
0005435252568	7404	Economy	6200.00
0005432823452	7404	Economy	6200.00
0005432839064	7404	Economy	6200.00
0005432839074	7404	Economy	6200.00
0005434458818	7404	Economy	6200.00
0005432839083	7404	Economy	6200.00
0005432839058	7404	Economy	6200.00
0005435252573	7404	Economy	6200.00
0005432841012	7404	Economy	6200.00
0005434458833	7404	Economy	6200.00
0005432839065	7404	Economy	6200.00
0005432839084	7404	Economy	6200.00
0005434458832	7404	Economy	6200.00
0005435252591	7404	Economy	6200.00
0005432839068	7404	Economy	6200.00
0005432839078	7404	Economy	6200.00
0005432839077	7404	Economy	6200.00
0005432839075	7404	Economy	6200.00
0005432839071	7404	Economy	6200.00
0005435252531	7404	Economy	6200.00
0005435252598	7404	Economy	6200.00
0005435252578	7404	Economy	6200.00
0005434458834	7404	Economy	6200.00
0005432839082	7404	Economy	6200.00
0005432839055	7404	Economy	6200.00
0005432839054	7404	Economy	6200.00
0005434458825	7404	Economy	6200.00
0005435252576	7404	Economy	6200.00
0005434458823	7404	Economy	6200.00
0005434458837	7404	Economy	6200.00
0005434458821	7404	Economy	6200.00
0005434458828	7404	Economy	6200.00
0005435252569	7404	Economy	6200.00
0005435252532	7404	Economy	6200.00
0005432839073	7404	Economy	6200.00
0005434458822	7404	Economy	6200.00
0005432823451	7404	Economy	6200.00
0005435252566	7404	Economy	6200.00
0005432841013	7404	Economy	6200.00
0005432839063	7404	Economy	6200.00
0005434458827	7404	Economy	6200.00
0005434458826	7404	Economy	6200.00
0005434458831	7404	Economy	6200.00
0005435252655	7404	Economy	6200.00
0005432839067	7404	Economy	6200.00
0005432839079	7404	Economy	6200.00
0005435252579	7404	Economy	6200.00
0005432001025	28934	Business	18500.00
0005434458641	28934	Business	18500.00
0005434458608	28934	Business	18500.00
0005432838863	28934	Business	18500.00
0005434458654	28934	Business	18500.00
0005432838960	28934	Business	18500.00
0005435252723	28934	Business	18500.00
0005434458640	28934	Business	18500.00
0005435252730	28934	Business	18500.00
0005435252715	28934	Business	18500.00
0005434458597	28934	Business	18500.00
0005432838799	28934	Economy	6200.00
0005432838818	28934	Economy	6200.00
0005435252731	28934	Economy	6200.00
0005432838904	28934	Economy	6200.00
0005435252724	28934	Economy	6200.00
0005435252714	28934	Economy	6200.00
0005434458626	28934	Economy	6800.00
0005432838864	28934	Economy	6800.00
0005432841002	28934	Economy	6800.00
0005432838815	28934	Economy	6800.00
0005432838959	28934	Economy	6800.00
0005434664963	28934	Economy	6200.00
0005432838865	28934	Economy	6200.00
0005434664964	28934	Economy	6200.00
0005435491443	28934	Economy	6200.00
0005435252721	28934	Economy	6200.00
0005432838819	28934	Economy	6200.00
0005432838808	28934	Economy	6200.00
0005434458568	28934	Economy	6200.00
0005432838789	28934	Economy	6200.00
0005434458638	28934	Economy	6200.00
0005435252716	28934	Economy	6200.00
0005435252728	28934	Economy	6200.00
0005435252727	28934	Economy	6200.00
0005435252722	28934	Economy	6200.00
0005435252726	28934	Economy	6200.00
0005435252717	28934	Economy	6200.00
0005432838861	28934	Economy	6200.00
0005432838685	28934	Economy	6200.00
0005434458624	28934	Economy	6200.00
0005432838903	28934	Economy	6200.00
0005432838817	28934	Economy	6200.00
0005434458609	28934	Economy	6200.00
0005432838848	28934	Economy	6200.00
0005432838813	28934	Economy	6200.00
0005435252732	28934	Economy	6200.00
0005435252718	28934	Economy	6200.00
0005432838774	28934	Economy	6200.00
0005434458749	28934	Economy	6200.00
0005432838891	28934	Economy	6200.00
0005432838793	28934	Economy	6200.00
0005435252733	28934	Economy	6200.00
0005432838649	28934	Economy	6200.00
0005435491444	28934	Economy	6200.00
0005432838715	28934	Economy	6200.00
0005435252729	28934	Economy	6200.00
0005432838823	28934	Economy	6200.00
0005435252719	28934	Economy	6200.00
0005432838849	28934	Economy	6200.00
0005434458627	28934	Economy	6200.00
0005432838810	28934	Economy	6200.00
0005434458655	28934	Economy	6200.00
0005434458598	28934	Economy	6200.00
0005432838853	28934	Economy	6200.00
0005432838806	28934	Economy	6200.00
0005434458670	28934	Economy	6200.00
0005432838816	28934	Economy	6200.00
0005432838790	28934	Economy	6200.00
0005434458694	28934	Economy	6200.00
0005435252720	28934	Economy	6200.00
0005432838809	28934	Economy	6200.00
0005432838890	28934	Economy	6200.00
0005435252725	28934	Economy	6200.00
0005434275985	8820	Economy	48400.00
0005435990630	8820	Economy	48400.00
0005435990631	8820	Economy	48400.00
0005434275987	8820	Economy	48400.00
0005434275986	8820	Economy	48400.00
0005434275980	8820	Economy	48400.00
0005435990632	8820	Economy	48400.00
0005434275962	8820	Economy	48400.00
0005434275983	8820	Economy	48400.00
0005435990629	8820	Economy	48400.00
0005435990633	8820	Economy	48400.00
0005435990634	8820	Economy	48400.00
0005434276006	8820	Economy	48400.00
0005434276036	15768	Business	145300.00
0005434276031	15768	Economy	48400.00
0005435990569	15768	Economy	48400.00
0005435990567	15768	Economy	48400.00
0005434276032	15768	Economy	48400.00
0005435990604	15768	Economy	48400.00
0005434276030	15768	Economy	48400.00
0005434276033	15768	Economy	48400.00
0005434276035	15768	Economy	48400.00
0005434276034	15768	Economy	48400.00
0005432427129	30854	Economy	15900.00
0005432427124	30854	Economy	14500.00
0005433476894	30854	Economy	14500.00
0005432427121	30854	Economy	14500.00
0005432427119	30854	Economy	14500.00
0005432427128	30854	Economy	14500.00
0005432427127	30854	Economy	14500.00
0005433476891	30854	Economy	14500.00
0005432427122	30854	Economy	14500.00
0005433476893	30854	Economy	14500.00
0005432427123	30854	Economy	14500.00
0005433476895	30854	Economy	14500.00
0005432427115	30854	Economy	14500.00
0005433476892	30854	Economy	14500.00
0005433468280	23837	Economy	13300.00
0005432909287	23837	Economy	12100.00
0005432909292	23837	Economy	12100.00
0005432909291	23837	Economy	12100.00
0005432909288	23837	Economy	12100.00
0005433468278	23837	Economy	12100.00
0005433468215	23837	Economy	12100.00
0005432909283	23837	Economy	12100.00
0005432909293	23837	Economy	12100.00
0005433468268	23837	Economy	12100.00
0005433468279	23837	Economy	12100.00
0005433468223	23837	Economy	12100.00
0005433468293	23837	Economy	12100.00
0005432909284	23837	Economy	12100.00
0005432909286	23837	Economy	12100.00
0005433468237	23837	Economy	12100.00
0005432909289	23837	Economy	12100.00
0005432909290	23837	Economy	12100.00
0005433468241	23837	Economy	12100.00
0005433468214	23837	Economy	12100.00
0005433468286	23837	Economy	12100.00
0005432909285	23837	Economy	12100.00
0005433468290	23837	Economy	12100.00
0005432909294	23837	Economy	12100.00
0005434149634	6360	Business	36600.00
0005432360418	6360	Business	36600.00
0005432336046	6360	Business	36600.00
0005432360417	6360	Business	36600.00
0005432360397	6360	Business	36600.00
0005432360395	6360	Business	36600.00
0005435176998	6360	Business	36600.00
0005432360436	6360	Business	36600.00
0005435176914	6360	Business	36600.00
0005432360434	6360	Business	36600.00
0005435176773	6360	Business	36600.00
0005432336050	6360	Business	36600.00
0005435176869	6360	Economy	12200.00
0005435176950	6360	Economy	12200.00
0005435490200	6360	Economy	12200.00
0005432360411	6360	Economy	12200.00
0005435176936	6360	Economy	12200.00
0005434149655	6360	Economy	12200.00
0005435176915	6360	Economy	12200.00
0005432062237	6360	Economy	12200.00
0005432360410	6360	Economy	12200.00
0005435176870	6360	Economy	12200.00
0005432360423	6360	Economy	12200.00
0005435177057	6360	Economy	12200.00
0005432363419	6360	Economy	12200.00
0005432360420	6360	Economy	12200.00
0005432360406	6360	Economy	12200.00
0005432360435	6360	Economy	12200.00
0005435176973	6360	Economy	12200.00
0005432336049	6360	Economy	12200.00
0005432360408	6360	Economy	12200.00
0005435176774	6360	Economy	12200.00
0005432360402	6360	Economy	12200.00
0005435176820	6360	Economy	12200.00
0005432062236	6360	Economy	12200.00
0005432360409	6360	Economy	12200.00
0005432360419	6360	Economy	12200.00
0005432336052	6360	Economy	12200.00
0005432360432	6360	Economy	12200.00
0005435176878	6360	Economy	12200.00
0005435176966	6360	Economy	12200.00
0005432336045	6360	Economy	12200.00
0005435176825	6360	Economy	12200.00
0005435176880	6360	Economy	12200.00
0005432360398	6360	Economy	12200.00
0005432360422	6360	Economy	12200.00
0005435177000	6360	Economy	13400.00
0005435176940	6360	Economy	13400.00
0005435176881	6360	Economy	13400.00
0005432360437	6360	Economy	13400.00
0005432360394	6360	Economy	13400.00
0005435176953	6360	Economy	13400.00
0005435176991	6360	Economy	12200.00
0005432360427	6360	Economy	12200.00
0005432360392	6360	Economy	12200.00
0005435490199	6360	Economy	12200.00
0005435176916	6360	Economy	12200.00
0005435490196	6360	Economy	12200.00
0005435176845	6360	Economy	12200.00
0005432360413	6360	Economy	12200.00
0005435176830	6360	Economy	12200.00
0005432360428	6360	Economy	12200.00
0005435176904	6360	Economy	12200.00
0005432360416	6360	Economy	12200.00
0005432360433	6360	Economy	12200.00
0005432360440	6360	Economy	12200.00
0005434149637	6360	Economy	12200.00
0005432336044	6360	Economy	12200.00
0005432336048	6360	Economy	12200.00
0005434149667	6360	Economy	12200.00
0005435176817	6360	Economy	12200.00
0005435176877	6360	Economy	12200.00
0005432360426	6360	Economy	12200.00
0005435176879	6360	Economy	12200.00
0005435176903	6360	Economy	12200.00
0005432360430	6360	Economy	12200.00
0005432062233	6360	Economy	12200.00
0005435176974	6360	Economy	12200.00
0005435490202	6360	Economy	12200.00
0005432360399	6360	Economy	12200.00
0005434149616	6360	Economy	12200.00
0005434149654	6360	Economy	12200.00
0005435176999	6360	Economy	12200.00
0005432360396	6360	Economy	12200.00
0005432360403	6360	Economy	12200.00
0005435176900	6360	Economy	12200.00
0005432360415	6360	Economy	12200.00
0005432360439	6360	Economy	12200.00
0005435176899	6360	Economy	12200.00
0005432336043	6360	Economy	12200.00
0005434149636	6360	Economy	12200.00
0005432360431	6360	Economy	12200.00
0005432336042	6360	Economy	12200.00
0005432360400	6360	Economy	12200.00
0005432360412	6360	Economy	12200.00
0005435176882	6360	Economy	12200.00
0005432360421	6360	Economy	12200.00
0005432062235	6360	Economy	12200.00
0005435176965	6360	Economy	12200.00
0005432062234	6360	Economy	12200.00
0005432360401	6360	Economy	12200.00
0005432360425	6360	Economy	12200.00
0005432360424	6360	Economy	12200.00
0005432336041	6360	Economy	12200.00
0005432336051	6360	Economy	12200.00
0005432363418	6360	Economy	12200.00
0005435490195	6360	Economy	12200.00
0005434149628	6360	Economy	12200.00
0005432363422	6360	Economy	12200.00
0005432360407	6360	Economy	12200.00
0005432360429	6360	Economy	12200.00
0005432363420	6360	Economy	12200.00
0005432360405	6360	Economy	12200.00
0005432360404	6360	Economy	12200.00
0005432336047	6360	Economy	12200.00
0005432363421	6360	Economy	12200.00
0005432360438	6360	Economy	12200.00
0005432360393	6360	Economy	12200.00
0005434149666	6360	Economy	12200.00
0005432360414	6360	Economy	12200.00
0005432359885	21019	Business	36600.00
0005432360050	21019	Business	36600.00
0005435490234	21019	Business	36600.00
0005432360011	21019	Business	36600.00
0005432359984	21019	Business	36600.00
0005434149743	21019	Business	36600.00
0005432360078	21019	Business	36600.00
0005435177112	21019	Business	36600.00
0005434149742	21019	Business	36600.00
0005435177115	21019	Economy	12200.00
0005432360049	21019	Economy	12200.00
0005432360084	21019	Economy	12200.00
0005432360086	21019	Economy	12200.00
0005435177113	21019	Economy	12200.00
0005435490235	21019	Economy	12200.00
0005435490236	21019	Economy	12200.00
0005435177103	21019	Economy	12200.00
0005432359873	21019	Economy	12200.00
0005432359962	21019	Economy	12200.00
0005432360044	21019	Economy	12200.00
0005432360113	21019	Economy	12200.00
0005432360051	21019	Economy	12200.00
0005435177104	21019	Economy	12200.00
0005432360038	21019	Economy	12200.00
0005432359865	21019	Economy	12200.00
0005432335983	21019	Economy	12200.00
0005432359839	21019	Economy	12200.00
0005432359864	21019	Economy	12200.00
0005432360059	21019	Economy	12200.00
0005432335859	21019	Economy	12200.00
0005432359954	21019	Economy	12200.00
0005435177111	21019	Economy	12200.00
0005434149738	21019	Economy	12200.00
0005435177105	21019	Economy	12200.00
0005435177097	21019	Economy	12200.00
0005432360043	21019	Economy	12200.00
0005432335920	21019	Economy	12200.00
0005434149748	21019	Economy	12200.00
0005434149737	21019	Economy	12200.00
0005432359754	21019	Economy	12200.00
0005435177119	21019	Economy	12200.00
0005432360145	21019	Economy	13400.00
0005432360008	21019	Economy	13400.00
0005432359949	21019	Economy	13400.00
0005435723048	21019	Economy	13400.00
0005435177107	21019	Economy	12200.00
0005435177118	21019	Economy	12200.00
0005432335963	21019	Economy	12200.00
0005432335858	21019	Economy	12200.00
0005434149740	21019	Economy	12200.00
0005434149746	21019	Economy	12200.00
0005432335982	21019	Economy	12200.00
0005435177114	21019	Economy	12200.00
0005432359924	21019	Economy	12200.00
0005432359983	21019	Economy	12200.00
0005434149745	21019	Economy	12200.00
0005432359969	21019	Economy	12200.00
0005432359918	21019	Economy	12200.00
0005434149747	21019	Economy	12200.00
0005432360041	21019	Economy	12200.00
0005432359968	21019	Economy	12200.00
0005432360007	21019	Economy	12200.00
0005435177092	21019	Economy	12200.00
0005435177106	21019	Economy	12200.00
0005434149744	21019	Economy	12200.00
0005432335980	21019	Economy	12200.00
0005432359907	21019	Economy	12200.00
0005435177098	21019	Economy	12200.00
0005435177094	21019	Economy	12200.00
0005435177093	21019	Economy	12200.00
0005432360055	21019	Economy	12200.00
0005432360056	21019	Economy	12200.00
0005435177099	21019	Economy	12200.00
0005432335925	21019	Economy	12200.00
0005435177110	21019	Economy	12200.00
0005432360014	21019	Economy	12200.00
0005435177102	21019	Economy	12200.00
0005435177117	21019	Economy	12200.00
0005435723049	21019	Economy	12200.00
0005432360042	21019	Economy	12200.00
0005432335962	21019	Economy	12200.00
0005432359755	21019	Economy	12200.00
0005432360101	21019	Economy	12200.00
0005435177101	21019	Economy	12200.00
0005432335954	21019	Economy	12200.00
0005432360112	21019	Economy	12200.00
0005434149739	21019	Economy	12200.00
0005432052750	21019	Economy	12200.00
0005435177108	21019	Economy	12200.00
0005435177095	21019	Economy	12200.00
0005432335981	21019	Economy	12200.00
0005432360114	21019	Economy	12200.00
0005432360012	21019	Economy	12200.00
0005432052749	21019	Economy	12200.00
0005432359979	21019	Economy	12200.00
0005435177096	21019	Economy	12200.00
0005435177100	21019	Economy	12200.00
0005435177109	21019	Economy	12200.00
0005434149741	21019	Economy	12200.00
0005435177116	21019	Economy	12200.00
0005432360088	21019	Economy	12200.00
0005434463907	17717	Economy	3400.00
0005434458711	17717	Economy	3400.00
0005434186203	17717	Economy	3400.00
0005434463922	17717	Economy	3400.00
0005434458669	17717	Economy	3100.00
0005434448290	17717	Economy	3100.00
0005434458677	17717	Economy	3100.00
0005434458710	17717	Economy	3100.00
0005434458499	17717	Economy	3100.00
0005434458628	17717	Economy	3100.00
0005434448278	17717	Economy	3100.00
0005434461621	17717	Economy	3100.00
0005434458667	17717	Economy	3100.00
0005434186201	17717	Economy	3100.00
0005434458586	17717	Economy	3100.00
0005434458680	17717	Economy	3100.00
0005434458709	17717	Economy	3100.00
0005434458699	17717	Economy	3100.00
0005434458700	17717	Economy	3100.00
0005434458727	17717	Economy	3100.00
0005434458636	17717	Economy	3100.00
0005434458688	17717	Economy	3100.00
0005434458689	17717	Economy	3100.00
0005434458631	17717	Economy	3100.00
0005434458611	17717	Economy	3100.00
0005434186202	17717	Economy	3100.00
0005434463923	17717	Economy	3100.00
0005434458583	17717	Economy	3100.00
0005434458678	17717	Economy	3100.00
0005434458619	17717	Economy	3100.00
0005434458827	29122	Economy	3400.00
0005434462790	29122	Economy	3100.00
0005434458822	29122	Economy	3100.00
0005434448315	29122	Economy	3100.00
0005434448316	29122	Economy	3100.00
0005434458828	29122	Economy	3100.00
0005434458824	29122	Economy	3100.00
0005434458818	29122	Economy	3100.00
0005434458823	29122	Economy	3100.00
0005434458819	29122	Economy	3100.00
0005434458835	29122	Economy	3100.00
0005434448314	29122	Economy	3100.00
0005434458833	29122	Economy	3100.00
0005434458817	29122	Economy	3100.00
0005434458836	29122	Economy	3100.00
0005434462792	29122	Economy	3100.00
0005434463929	29122	Economy	3100.00
0005434458829	29122	Economy	3100.00
0005434458832	29122	Economy	3100.00
0005434463930	29122	Economy	3100.00
0005434458834	29122	Economy	3100.00
0005434458831	29122	Economy	3100.00
0005434458825	29122	Economy	3100.00
0005434458830	29122	Economy	3100.00
0005434458821	29122	Economy	3100.00
0005434458837	29122	Economy	3100.00
0005434458826	29122	Economy	3100.00
0005434458820	29122	Economy	3100.00
0005434462791	29122	Economy	3100.00
0005432665242	21837	Business	185300.00
0005432665241	21837	Business	185300.00
0005432658567	21837	Economy	61800.00
0005432665240	21837	Economy	61800.00
0005432665249	21837	Economy	61800.00
0005432658566	21837	Economy	61800.00
0005432665243	21837	Economy	61800.00
0005432665237	21837	Economy	61800.00
0005432658556	21837	Economy	61800.00
0005432658565	21837	Economy	61800.00
0005432665239	21837	Economy	61800.00
0005432665250	21837	Economy	61800.00
0005432665238	21837	Economy	61800.00
0005432658555	21837	Economy	61800.00
0005432665244	21837	Economy	61800.00
0005432658561	21837	Economy	61800.00
0005432665245	21837	Economy	61800.00
0005432604341	21433	Economy	7300.00
0005432604348	21433	Economy	7300.00
0005432604364	21433	Economy	6600.00
0005432604345	21433	Economy	6600.00
0005432604336	21433	Economy	6600.00
0005432604339	21433	Economy	6600.00
0005432604363	21433	Economy	6600.00
0005432604342	21433	Economy	6600.00
0005432604369	21433	Economy	6600.00
0005432604359	21433	Economy	6600.00
0005432604340	21433	Economy	6600.00
0005432604356	21433	Economy	6600.00
0005432604360	21433	Economy	6600.00
0005432604333	21433	Economy	6600.00
0005432604366	21433	Economy	6600.00
0005432604346	21433	Economy	6600.00
0005432604338	21433	Economy	6600.00
0005432604332	21433	Economy	6600.00
0005432604358	21433	Economy	6600.00
0005432604352	21433	Economy	6600.00
0005432604353	21433	Economy	6600.00
0005432604357	21433	Economy	6600.00
0005432604335	21433	Economy	6600.00
0005432604371	21433	Economy	6600.00
0005432604362	21433	Economy	6600.00
0005432604354	21433	Economy	6600.00
0005432604361	21433	Economy	6600.00
0005432604344	21433	Economy	6600.00
0005432604368	21433	Economy	6600.00
0005432604367	21433	Economy	6600.00
0005432604347	21433	Economy	6600.00
0005432604337	21433	Economy	6600.00
0005432604351	21433	Economy	6600.00
0005432604349	21433	Economy	6600.00
0005432604355	21433	Economy	6600.00
0005432604343	21433	Economy	6600.00
0005432604370	21433	Economy	6600.00
0005432604365	21433	Economy	6600.00
0005432604334	21433	Economy	6600.00
0005432604350	21433	Economy	6600.00
0005432604046	31705	Economy	7300.00
0005432603854	31705	Economy	7300.00
0005432603997	31705	Economy	7300.00
0005432603958	31705	Economy	6600.00
0005432603988	31705	Economy	6600.00
0005435221515	31705	Economy	6600.00
0005432603853	31705	Economy	6600.00
0005432604058	31705	Economy	6600.00
0005432604048	31705	Economy	6600.00
0005435221514	31705	Economy	6600.00
0005432604243	31705	Economy	6600.00
0005432604045	31705	Economy	6600.00
0005432604242	31705	Economy	6600.00
0005435221053	31705	Economy	6600.00
0005435221052	31705	Economy	6600.00
0005432604084	31705	Economy	6600.00
0005432603996	31705	Economy	6600.00
0005432603954	31705	Economy	6600.00
0005432603856	31705	Economy	6600.00
0005432604086	31705	Economy	6600.00
0005432603938	31705	Economy	6600.00
0005432603975	31705	Economy	6600.00
0005432604087	31705	Economy	6600.00
0005432603957	31705	Economy	6600.00
0005432604034	31705	Economy	6600.00
0005432604083	31705	Economy	6600.00
0005432603980	31705	Economy	6600.00
0005432603885	31705	Economy	6600.00
0005432604037	31705	Economy	6600.00
0005432603986	31705	Economy	6600.00
0005432604035	31705	Economy	6600.00
0005432603855	31705	Economy	6600.00
0005432603981	31705	Economy	6600.00
0005432603992	31705	Economy	6600.00
0005432603994	31705	Economy	6600.00
0005432604024	31705	Economy	6600.00
0005432603977	31705	Economy	6600.00
0005432604076	31705	Economy	6600.00
0005432603976	31705	Economy	6600.00
0005432603993	31705	Economy	6600.00
0005433293254	29614	Economy	19500.00
0005433293260	29614	Economy	19500.00
0005433293263	29614	Economy	17800.00
0005433293258	29614	Economy	17800.00
0005433293253	29614	Economy	17800.00
0005433293259	29614	Economy	17800.00
0005433293252	29614	Economy	17800.00
0005433293256	29614	Economy	17800.00
0005433293257	29614	Economy	17800.00
0005433293261	29614	Economy	17800.00
0005433293264	29614	Economy	17800.00
0005433293255	29614	Economy	17800.00
0005433293262	29614	Economy	17800.00
0005433473270	6674	Economy	14000.00
0005435257195	6674	Economy	14000.00
0005433473264	6674	Economy	14000.00
0005435257192	6674	Economy	12700.00
0005435257175	6674	Economy	12700.00
0005433473271	6674	Economy	12700.00
0005433473261	6674	Economy	12700.00
0005433473272	6674	Economy	12700.00
0005433473265	6674	Economy	12700.00
0005433473262	6674	Economy	12700.00
0005433473274	6674	Economy	12700.00
0005433473278	6674	Economy	12700.00
0005433473268	6674	Economy	12700.00
0005435257183	6674	Economy	12700.00
0005435257170	6674	Economy	12700.00
0005435257218	6674	Economy	12700.00
0005433473275	6674	Economy	12700.00
0005435257208	6674	Economy	12700.00
0005435257169	6674	Economy	12700.00
0005435257217	6674	Economy	12700.00
0005433473269	6674	Economy	12700.00
0005433473279	6674	Economy	12700.00
0005435257196	6674	Economy	12700.00
0005433473267	6674	Economy	12700.00
0005433473276	6674	Economy	12700.00
0005433473263	6674	Economy	12700.00
0005435257182	6674	Economy	12700.00
0005433473273	6674	Economy	12700.00
0005433473266	6674	Economy	12700.00
0005433473277	6674	Economy	12700.00
0005435257191	6674	Economy	12700.00
0005435257190	6674	Economy	12700.00
0005435257239	23893	Economy	14000.00
0005435257241	23893	Economy	14000.00
0005433473156	23893	Economy	14000.00
0005435257238	23893	Economy	12700.00
0005433473124	23893	Economy	12700.00
0005433473150	23893	Economy	12700.00
0005433473123	23893	Economy	12700.00
0005433473162	23893	Economy	12700.00
0005433473193	23893	Economy	12700.00
0005433473220	23893	Economy	12700.00
0005433473148	23893	Economy	12700.00
0005433473171	23893	Economy	12700.00
0005435257245	23893	Economy	12700.00
0005433473166	23893	Economy	12700.00
0005433473172	23893	Economy	12700.00
0005433473177	23893	Economy	12700.00
0005435257237	23893	Economy	12700.00
0005433473207	23893	Economy	12700.00
0005433473153	23893	Economy	12700.00
0005433473178	23893	Economy	12700.00
0005435257243	23893	Economy	12700.00
0005433473167	23893	Economy	12700.00
0005435257240	23893	Economy	12700.00
0005433473212	23893	Economy	12700.00
0005433473202	23893	Economy	12700.00
0005435257242	23893	Economy	12700.00
0005433473155	23893	Economy	12700.00
0005433473182	23893	Economy	12700.00
0005435257244	23893	Economy	12700.00
0005435257236	23893	Economy	12700.00
0005433473200	23893	Economy	12700.00
0005435904895	18936	Economy	6600.00
0005434606794	18936	Economy	6600.00
0005434606829	22341	Economy	6600.00
0005435904889	22341	Economy	6600.00
0005434604897	22341	Economy	6600.00
0005434604899	22341	Economy	6600.00
0005434604898	22341	Economy	6600.00
0005434606830	22341	Economy	6600.00
0005435904894	22341	Economy	6600.00
0005434606828	22341	Economy	6600.00
0005435904379	3838	Economy	24900.00
0005435904385	3838	Economy	22600.00
0005435904387	3838	Economy	22600.00
0005434522448	3838	Economy	22600.00
0005434522450	3838	Economy	22600.00
0005434522446	3838	Economy	22600.00
0005435904378	3838	Economy	22600.00
0005434602900	3838	Economy	22600.00
0005434522447	3838	Economy	22600.00
0005434522444	3838	Economy	22600.00
0005434522445	3838	Economy	22600.00
0005434522449	3838	Economy	22600.00
0005434602901	3838	Economy	22600.00
0005435904395	3838	Economy	22600.00
0005435904380	3838	Economy	22600.00
0005434602904	3838	Economy	22600.00
0005435904386	3838	Economy	22600.00
0005434602902	3838	Economy	22600.00
0005434602903	3838	Economy	22600.00
0005435904396	3838	Economy	22600.00
0005434604870	19064	Economy	24900.00
0005434602877	19064	Economy	22600.00
0005435904706	19064	Economy	22600.00
0005435904407	19064	Economy	22600.00
0005434522409	19064	Economy	22600.00
0005434522416	19064	Economy	22600.00
0005434602878	19064	Economy	22600.00
0005434522418	19064	Economy	22600.00
0005434604873	19064	Economy	22600.00
0005434522423	19064	Economy	22600.00
0005434604874	19064	Economy	22600.00
0005435904705	19064	Economy	22600.00
0005435904410	19064	Economy	22600.00
0005435904412	19064	Economy	22600.00
0005435904704	19064	Economy	22600.00
0005434522415	19064	Economy	22600.00
0005435904409	19064	Economy	22600.00
0005435904411	19064	Economy	22600.00
0005434522417	19064	Economy	22600.00
0005434604869	19064	Economy	22600.00
0005434604872	19064	Economy	22600.00
0005435904408	19064	Economy	22600.00
0005434522427	19064	Economy	22600.00
0005434604864	19064	Economy	22600.00
0005433293169	403	Business	44500.00
0005432753302	403	Business	44500.00
0005432890896	403	Business	44500.00
0005432751528	403	Business	44500.00
0005433293168	403	Business	44500.00
0005432747580	403	Business	44500.00
0005432751525	403	Business	44500.00
0005435154598	403	Business	44500.00
0005432747593	403	Business	44500.00
0005433293187	403	Business	44500.00
0005432220005	403	Business	44500.00
0005432747592	403	Economy	14800.00
0005432747588	403	Economy	14800.00
0005432220008	403	Economy	14800.00
0005432747577	403	Economy	14800.00
0005432747603	403	Economy	14800.00
0005432890811	403	Economy	14800.00
0005432747594	403	Economy	14800.00
0005432747599	403	Economy	14800.00
0005432747605	403	Economy	16300.00
0005432220006	403	Economy	16300.00
0005432747581	403	Economy	16300.00
0005432749784	403	Economy	16300.00
0005432890737	403	Economy	14800.00
0005432747575	403	Economy	14800.00
0005432890840	403	Economy	14800.00
0005432747589	403	Economy	14800.00
0005433293198	403	Economy	14800.00
0005432890812	403	Economy	14800.00
0005432747585	403	Economy	14800.00
0005432890902	403	Economy	14800.00
0005432747582	403	Economy	14800.00
0005432747609	403	Economy	14800.00
0005432747595	403	Economy	14800.00
0005432751527	403	Economy	14800.00
0005432890841	403	Economy	14800.00
0005432747611	403	Economy	14800.00
0005432890746	403	Economy	14800.00
0005432890912	403	Economy	14800.00
0005433293185	403	Economy	14800.00
0005433293201	403	Economy	14800.00
0005432890791	403	Economy	14800.00
0005432751526	403	Economy	14800.00
0005432747579	403	Economy	14800.00
0005432747597	403	Economy	14800.00
0005432747601	403	Economy	14800.00
0005432890857	403	Economy	14800.00
0005432890895	403	Economy	14800.00
0005432747607	403	Economy	14800.00
0005432747586	403	Economy	14800.00
0005432747583	403	Economy	14800.00
0005433293210	403	Economy	14800.00
0005432749786	403	Economy	14800.00
0005432747587	403	Economy	14800.00
0005432747608	403	Economy	14800.00
0005432747574	403	Economy	14800.00
0005432753301	403	Economy	14800.00
0005432890856	403	Economy	14800.00
0005432747598	403	Economy	14800.00
0005432747591	403	Economy	14800.00
0005432220009	403	Economy	14800.00
0005432747604	403	Economy	14800.00
0005432220007	403	Economy	14800.00
0005432890711	403	Economy	14800.00
0005432747590	403	Economy	14800.00
0005432220004	403	Economy	14800.00
0005432890901	403	Economy	14800.00
0005432890874	403	Economy	14800.00
0005432751530	403	Economy	14800.00
0005432751529	403	Economy	14800.00
0005432747606	403	Economy	14800.00
0005432890833	403	Economy	14800.00
0005432890873	403	Economy	14800.00
0005432749785	403	Economy	14800.00
0005432747576	403	Economy	14800.00
0005432747578	403	Economy	14800.00
0005432747584	403	Economy	14800.00
0005432747613	403	Economy	14800.00
0005433293182	403	Economy	14800.00
0005432747600	403	Economy	14800.00
0005432747596	403	Economy	14800.00
0005432747612	403	Economy	14800.00
0005432747610	403	Economy	14800.00
0005432747602	403	Economy	14800.00
0005433293181	403	Economy	14800.00
0005432747272	12066	Business	44500.00
0005432749768	12066	Business	44500.00
0005432747265	12066	Business	44500.00
0005432747475	12066	Business	44500.00
0005432891031	12066	Business	44500.00
0005432891035	12066	Business	44500.00
0005432891048	12066	Business	44500.00
0005432753273	12066	Business	44500.00
0005432753274	12066	Business	44500.00
0005432214804	12066	Economy	14800.00
0005432747109	12066	Economy	14800.00
0005432891037	12066	Economy	14800.00
0005434153535	12066	Economy	14800.00
0005432747366	12066	Economy	14800.00
0005432747327	12066	Economy	14800.00
0005432747321	12066	Economy	14800.00
0005432747289	12066	Economy	16300.00
0005432753280	12066	Economy	16300.00
0005432747356	12066	Economy	16300.00
0005432756820	12066	Economy	16300.00
0005432747309	12066	Economy	14800.00
0005432891039	12066	Economy	14800.00
0005432891033	12066	Economy	14800.00
0005432747245	12066	Economy	14800.00
0005432747409	12066	Economy	14800.00
0005432747332	12066	Economy	14800.00
0005432747429	12066	Economy	14800.00
0005432747344	12066	Economy	14800.00
0005432749769	12066	Economy	14800.00
0005432747206	12066	Economy	14800.00
0005432747357	12066	Economy	14800.00
0005432747383	12066	Economy	14800.00
0005432891047	12066	Economy	14800.00
0005432747124	12066	Economy	14800.00
0005432891045	12066	Economy	14800.00
0005432747142	12066	Economy	14800.00
0005432891032	12066	Economy	14800.00
0005432747333	12066	Economy	14800.00
0005432214805	12066	Economy	14800.00
0005432891043	12066	Economy	14800.00
0005432747474	12066	Economy	14800.00
0005432747252	12066	Economy	14800.00
0005432747328	12066	Economy	14800.00
0005432747190	12066	Economy	14800.00
0005432891046	12066	Economy	14800.00
0005432214806	12066	Economy	14800.00
0005432891040	12066	Economy	14800.00
0005432891036	12066	Economy	14800.00
0005432891038	12066	Economy	14800.00
0005432747249	12066	Economy	14800.00
0005432753283	12066	Economy	14800.00
0005432891041	12066	Economy	14800.00
0005432747290	12066	Economy	14800.00
0005432747264	12066	Economy	14800.00
0005432747204	12066	Economy	14800.00
0005433875382	12066	Economy	14800.00
0005432747271	12066	Economy	14800.00
0005434153537	12066	Economy	14800.00
0005432747408	12066	Economy	14800.00
0005432891042	12066	Economy	14800.00
0005433875380	12066	Economy	14800.00
0005432753281	12066	Economy	14800.00
0005432747205	12066	Economy	14800.00
0005434153536	12066	Economy	14800.00
0005432747329	12066	Economy	14800.00
0005432747275	12066	Economy	14800.00
0005432747244	12066	Economy	14800.00
0005432747395	12066	Economy	14800.00
0005432753282	12066	Economy	14800.00
0005432891044	12066	Economy	14800.00
0005432891034	12066	Economy	14800.00
0005432891049	12066	Economy	14800.00
0005432747228	12066	Economy	14800.00
0005434153538	12066	Economy	14800.00
0005433875381	12066	Economy	14800.00
0005432747242	12066	Economy	14800.00
0005432747343	12066	Economy	14800.00
0005433533307	18964	Economy	28200.00
0005433525043	18964	Economy	25700.00
0005432927927	18964	Economy	25700.00
0005432927903	18964	Economy	25700.00
0005433525036	18964	Economy	25700.00
0005432927928	18964	Economy	25700.00
0005433533309	18964	Economy	25700.00
0005433525041	18964	Economy	25700.00
0005433525039	18964	Economy	25700.00
0005433525038	18964	Economy	25700.00
0005433525040	18964	Economy	25700.00
0005433525035	18964	Economy	25700.00
0005433525042	18964	Economy	25700.00
0005432927946	18964	Economy	25700.00
0005432927949	18964	Economy	25700.00
0005432927933	18964	Economy	25700.00
0005433531293	18964	Economy	25700.00
0005433533308	18964	Economy	25700.00
0005433525044	18964	Economy	25700.00
0005433531291	18964	Economy	25700.00
0005433531292	18964	Economy	25700.00
0005433531294	18964	Economy	25700.00
0005432927948	18964	Economy	25700.00
0005433525045	18964	Economy	25700.00
0005432927934	18964	Economy	25700.00
0005433525037	18964	Economy	25700.00
0005432927940	18964	Economy	25700.00
0005432927947	18964	Economy	25700.00
0005433531256	32482	Economy	28200.00
0005433527224	32482	Economy	28200.00
0005433527216	32482	Economy	28200.00
0005432927993	32482	Economy	28200.00
0005433531274	32482	Economy	25700.00
0005433531270	32482	Economy	25700.00
0005433524952	32482	Economy	25700.00
0005433531255	32482	Economy	25700.00
0005433527222	32482	Economy	25700.00
0005433531254	32482	Economy	25700.00
0005433524953	32482	Economy	25700.00
0005433524965	32482	Economy	25700.00
0005433531253	32482	Economy	25700.00
0005433531263	32482	Economy	25700.00
0005433527223	32482	Economy	25700.00
0005432927989	32482	Economy	25700.00
0005432927991	32482	Economy	25700.00
0005433531264	32482	Economy	25700.00
0005433524892	32482	Economy	25700.00
0005432927992	32482	Economy	25700.00
0005433524922	32482	Economy	25700.00
0005433524966	32482	Economy	25700.00
0005432927990	32482	Economy	25700.00
0005433524893	32482	Economy	25700.00
0005433531252	32482	Economy	25700.00
0005433531269	32482	Economy	25700.00
0005433524921	32482	Economy	25700.00
0005432927994	32482	Economy	25700.00
0005433524946	32482	Economy	25700.00
0005433527225	32482	Economy	25700.00
0005433524943	32482	Economy	25700.00
0005433524967	32482	Economy	25700.00
0005434558287	5279	Business	84000.00
0005435372578	5279	Business	84000.00
0005434823741	5279	Business	84000.00
0005432121343	5279	Business	84000.00
0005434823686	5279	Business	84000.00
0005435304143	5279	Business	84000.00
0005434823723	5279	Business	84000.00
0005432823431	5279	Business	84000.00
0005435372630	5279	Business	84000.00
0005434823777	5279	Business	84000.00
0005434823725	5279	Business	84000.00
0005435150050	5279	Business	84000.00
0005434823738	5279	Business	84000.00
0005434823658	5279	Business	84000.00
0005435299722	5279	Business	84000.00
0005434823772	5279	Business	84000.00
0005434823715	5279	Business	84000.00
0005435304117	5279	Business	84000.00
0005435372628	5279	Business	84000.00
0005435150049	5279	Business	84000.00
0005435178986	5279	Business	84000.00
0005434823735	5279	Business	84000.00
0005434823655	5279	Business	84000.00
0005434823697	5279	Comfort	47600.00
0005434823660	5279	Comfort	47600.00
0005435304144	5279	Comfort	47600.00
0005435150039	5279	Comfort	47600.00
0005435150048	5279	Comfort	47600.00
0005434823763	5279	Comfort	47600.00
0005435372467	5279	Comfort	47600.00
0005432394107	5279	Comfort	47600.00
0005434823657	5279	Comfort	47600.00
0005434823673	5279	Comfort	47600.00
0005434823737	5279	Comfort	47600.00
0005435372788	5279	Comfort	47600.00
0005432396248	5279	Comfort	47600.00
0005435372754	5279	Comfort	47600.00
0005434823734	5279	Comfort	47600.00
0005434823720	5279	Comfort	47600.00
0005435372903	5279	Comfort	47600.00
0005435372793	5279	Comfort	47600.00
0005434823753	5279	Comfort	47600.00
0005434558288	5279	Comfort	47600.00
0005434823666	5279	Comfort	47600.00
0005435372739	5279	Comfort	47600.00
0005435372875	5279	Comfort	47600.00
0005434823762	5279	Comfort	47600.00
0005434823674	5279	Comfort	47600.00
0005435372818	5279	Comfort	47600.00
0005434823766	5279	Comfort	47600.00
0005435372720	5279	Comfort	47600.00
0005434823765	5279	Comfort	47600.00
0005434823743	5279	Comfort	47600.00
0005435735081	5279	Comfort	47600.00
0005435372782	5279	Comfort	47600.00
0005434823752	5279	Comfort	47600.00
0005434823648	5279	Comfort	47600.00
0005435372991	5279	Comfort	47600.00
0005435372661	5279	Comfort	47600.00
0005432121348	5279	Comfort	47600.00
0005434823669	5279	Comfort	47600.00
0005434823729	5279	Economy	28000.00
0005435372814	5279	Economy	28000.00
0005434823745	5279	Economy	28000.00
0005434828696	5279	Economy	28000.00
0005434823705	5279	Economy	28000.00
0005434558286	5279	Economy	28000.00
0005434823689	5279	Economy	28000.00
0005434823700	5279	Economy	28000.00
0005434823677	5279	Economy	28000.00
0005432121349	5279	Economy	28000.00
0005435661909	5279	Economy	28000.00
0005435372645	5279	Economy	28000.00
0005434823717	5279	Economy	28000.00
0005435735095	5279	Economy	28000.00
0005435372660	5279	Economy	28000.00
0005435661908	5279	Economy	28000.00
0005434828699	5279	Economy	28000.00
0005435372687	5279	Economy	28000.00
0005435372666	5279	Economy	28000.00
0005434823742	5279	Economy	28000.00
0005435372746	5279	Economy	28000.00
0005434823653	5279	Economy	28000.00
0005434558283	5279	Economy	28000.00
0005434823733	5279	Economy	28000.00
0005434823679	5279	Economy	28000.00
0005434823652	5279	Economy	28000.00
0005434823756	5279	Economy	28000.00
0005434823740	5279	Economy	28000.00
0005434823672	5279	Economy	28000.00
0005434823654	5279	Economy	28000.00
0005435386526	5279	Economy	28000.00
0005435386512	5279	Economy	28000.00
0005434823659	5279	Economy	28000.00
0005434558281	5279	Economy	28000.00
0005434823744	5279	Economy	28000.00
0005432121342	5279	Economy	28000.00
0005434823761	5279	Economy	28000.00
0005435372794	5279	Economy	28000.00
0005434823706	5279	Economy	28000.00
0005434664960	5279	Economy	28000.00
0005435373077	5279	Economy	28000.00
0005434823719	5279	Economy	28000.00
0005434823728	5279	Economy	28000.00
0005434823678	5279	Economy	28000.00
0005435372701	5279	Economy	28000.00
0005434823730	5279	Economy	28000.00
0005434823684	5279	Economy	28000.00
0005434823675	5279	Economy	28000.00
0005434823693	5279	Economy	28000.00
0005435150044	5279	Economy	28000.00
0005435372585	5279	Economy	30800.00
0005434823739	5279	Economy	30800.00
0005434823776	5279	Economy	28000.00
0005434823748	5279	Economy	28000.00
0005435372595	5279	Economy	28000.00
0005434823665	5279	Economy	28000.00
0005432121344	5279	Economy	30800.00
0005432823432	5279	Economy	28000.00
0005434823703	5279	Economy	28000.00
0005435372748	5279	Economy	28000.00
0005434823664	5279	Economy	28000.00
0005435372586	5279	Economy	28000.00
0005434823736	5279	Economy	28000.00
0005434823759	5279	Economy	28000.00
0005432121352	5279	Economy	28000.00
0005434823692	5279	Economy	28000.00
0005432121354	5279	Economy	28000.00
0005435373032	5279	Economy	28000.00
0005435372617	5279	Economy	28000.00
0005435150047	5279	Economy	28000.00
0005435304118	5279	Economy	28000.00
0005435150051	5279	Economy	28000.00
0005432396247	5279	Economy	28000.00
0005434823764	5279	Economy	28000.00
0005434823754	5279	Economy	28000.00
0005434823713	5279	Economy	28000.00
0005434823746	5279	Economy	28000.00
0005435372813	5279	Economy	28000.00
0005435372947	5279	Economy	28000.00
0005434823681	5279	Economy	28000.00
0005435373016	5279	Economy	28000.00
0005434823755	5279	Economy	28000.00
0005432121351	5279	Economy	28000.00
0005434823721	5279	Economy	28000.00
0005432396245	5279	Economy	28000.00
0005434823731	5279	Economy	28000.00
0005435372743	5279	Economy	28000.00
0005435150038	5279	Economy	28000.00
0005434823667	5279	Economy	28000.00
0005432121350	5279	Economy	28000.00
0005434823757	5279	Economy	28000.00
0005435372622	5279	Economy	28000.00
0005435372659	5279	Economy	28000.00
0005434823687	5279	Economy	28000.00
0005435372646	5279	Economy	28000.00
0005434831153	5279	Economy	28000.00
0005435150042	5279	Economy	28000.00
0005434823670	5279	Economy	28000.00
0005432121346	5279	Economy	28000.00
0005432394109	5279	Economy	28000.00
0005435386500	5279	Economy	28000.00
0005434823724	5279	Economy	28000.00
0005434823702	5279	Economy	28000.00
0005435735083	5279	Economy	28000.00
0005434823699	5279	Economy	28000.00
0005434823722	5279	Economy	28000.00
0005434823751	5279	Economy	28000.00
0005434823709	5279	Economy	28000.00
0005435372721	5279	Economy	28000.00
0005434823773	5279	Economy	28000.00
0005435150046	5279	Economy	28000.00
0005435372711	5279	Economy	28000.00
0005434831152	5279	Economy	28000.00
0005434823691	5279	Economy	28000.00
0005434823769	5279	Economy	28000.00
0005434823726	5279	Economy	28000.00
0005435372912	5279	Economy	28000.00
0005435735107	5279	Economy	28000.00
0005434823656	5279	Economy	28000.00
0005434831154	5279	Economy	28000.00
0005435372606	5279	Economy	28000.00
0005432396246	5279	Economy	28000.00
0005434823774	5279	Economy	28000.00
0005434823750	5279	Economy	28000.00
0005435304131	5279	Economy	28000.00
0005435372623	5279	Economy	28000.00
0005434823668	5279	Economy	28000.00
0005434823758	5279	Economy	28000.00
0005434828697	5279	Economy	28000.00
0005434823690	5279	Economy	28000.00
0005435372817	5279	Economy	28000.00
0005435386501	5279	Economy	28000.00
0005434823698	5279	Economy	28000.00
0005432121345	5279	Economy	28000.00
0005435372753	5279	Economy	28000.00
0005434823760	5279	Economy	28000.00
0005435372742	5279	Economy	28000.00
0005434823749	5279	Economy	28000.00
0005435372710	5279	Economy	28000.00
0005435150040	5279	Economy	28000.00
0005434823727	5279	Economy	28000.00
0005434823768	5279	Economy	28000.00
0005434823649	5279	Economy	28000.00
0005435372718	5279	Economy	30800.00
0005435372850	5279	Economy	28000.00
0005434823650	5279	Economy	30800.00
0005434823695	5279	Economy	30800.00
0005434823775	5279	Economy	28000.00
0005435372747	5279	Economy	28000.00
0005434823694	5279	Economy	28000.00
0005434823680	5279	Economy	28000.00
0005434823662	5279	Economy	28000.00
0005432121353	5279	Economy	28000.00
0005435373076	5279	Economy	28000.00
0005434823771	5279	Economy	28000.00
0005435372860	5279	Economy	28000.00
0005434823714	5279	Economy	28000.00
0005435372990	5279	Economy	28000.00
0005434823685	5279	Economy	28000.00
0005434823676	5279	Economy	28000.00
0005434664962	5279	Economy	28000.00
0005434823716	5279	Economy	28000.00
0005434558285	5279	Economy	28000.00
0005435372890	5279	Economy	28000.00
0005435372844	5279	Economy	28000.00
0005435372466	5279	Economy	28000.00
0005434828698	5279	Economy	28000.00
0005435372994	5279	Economy	28000.00
0005434831151	5279	Economy	28000.00
0005435150043	5279	Economy	28000.00
0005434823696	5279	Economy	28000.00
0005435372525	5279	Economy	28000.00
0005434558284	5279	Economy	28000.00
0005435661901	5279	Economy	28000.00
0005435304120	5279	Economy	28000.00
0005434823688	5279	Economy	28000.00
0005434823663	5279	Economy	28000.00
0005435372769	5279	Economy	28000.00
0005435372571	5279	Economy	28000.00
0005435386511	5279	Economy	28000.00
0005435372632	5279	Economy	28000.00
0005435372572	5279	Economy	28000.00
0005435150041	5279	Economy	28000.00
0005434823732	5279	Economy	28000.00
0005435150045	5279	Economy	28000.00
0005434558282	5279	Economy	28000.00
0005435372800	5279	Economy	28000.00
0005435304127	5279	Economy	28000.00
0005434823701	5279	Economy	28000.00
0005435372631	5279	Economy	28000.00
0005435661902	5279	Economy	28000.00
0005434823682	5279	Economy	28000.00
0005434823671	5279	Economy	28000.00
0005434664961	5279	Economy	28000.00
0005434823661	5279	Economy	28000.00
0005434823711	5279	Economy	28000.00
0005435735094	5279	Economy	28000.00
0005434823683	5279	Economy	28000.00
0005434823767	5279	Economy	28000.00
0005435372719	5279	Economy	28000.00
0005432121347	5279	Economy	28000.00
0005435372752	5279	Economy	28000.00
0005434823747	5279	Economy	28000.00
0005434823704	5279	Economy	28000.00
0005435150037	5279	Economy	28000.00
0005434823718	5279	Economy	28000.00
0005435372662	5279	Economy	28000.00
0005434823708	5279	Economy	28000.00
0005434823707	5279	Economy	28000.00
0005432121355	5279	Economy	28000.00
0005432394108	5279	Economy	28000.00
0005435304121	5279	Economy	28000.00
0005434823770	5279	Economy	28000.00
0005434823651	5279	Economy	28000.00
0005435661900	5279	Economy	28000.00
0005435373015	5279	Economy	28000.00
0005434823710	5279	Economy	28000.00
0005434823712	5279	Economy	28000.00
0005435373331	9922	Business	84000.00
0005434822367	9922	Business	84000.00
0005434822379	9922	Business	84000.00
0005434822644	9922	Business	84000.00
0005435373351	9922	Business	84000.00
0005432396204	9922	Business	84000.00
0005434822886	9922	Business	84000.00
0005434822375	9922	Business	84000.00
0005434822713	9922	Business	84000.00
0005434822254	9922	Business	84000.00
0005435373322	9922	Business	84000.00
0005434822814	9922	Business	84000.00
0005432396206	9922	Business	84000.00
0005435386572	9922	Business	84000.00
0005435373342	9922	Business	84000.00
0005435149878	9922	Business	84000.00
0005434821905	9922	Comfort	47600.00
0005434822889	9922	Comfort	47600.00
0005434822613	9922	Comfort	47600.00
0005434822686	9922	Comfort	47600.00
0005435373336	9922	Comfort	47600.00
0005432203071	9922	Comfort	47600.00
0005434822612	9922	Comfort	47600.00
0005432400082	9922	Comfort	47600.00
0005435373296	9922	Comfort	47600.00
0005435299782	9922	Comfort	47600.00
0005434823007	9922	Comfort	47600.00
0005434822828	9922	Comfort	47600.00
0005434828668	9922	Comfort	47600.00
0005434822468	9922	Comfort	47600.00
0005435373303	9922	Comfort	47600.00
0005434822590	9922	Comfort	47600.00
0005434822882	9922	Comfort	47600.00
0005434822655	9922	Comfort	47600.00
0005435373312	9922	Comfort	47600.00
0005434822515	9922	Comfort	47600.00
0005434822404	9922	Comfort	47600.00
0005435373335	9922	Comfort	47600.00
0005435735143	9922	Comfort	47600.00
0005434822090	9922	Comfort	47600.00
0005435373302	9922	Comfort	47600.00
0005435661933	9922	Economy	28000.00
0005435386575	9922	Comfort	47600.00
0005434822778	9922	Economy	28000.00
0005435373337	9922	Economy	28000.00
0005435386573	9922	Economy	28000.00
0005434558210	9922	Economy	28000.00
0005435373300	9922	Economy	28000.00
0005434822768	9922	Economy	28000.00
0005432396213	9922	Economy	28000.00
0005432203073	9922	Economy	28000.00
0005435373338	9922	Economy	28000.00
0005435299778	9922	Economy	28000.00
0005434822542	9922	Economy	28000.00
0005435373324	9922	Economy	28000.00
0005435373327	9922	Economy	28000.00
0005434822182	9922	Economy	28000.00
0005434822332	9922	Economy	28000.00
0005435373326	9922	Economy	28000.00
0005432203069	9922	Economy	28000.00
0005434822826	9922	Economy	28000.00
0005434822183	9922	Economy	28000.00
0005435373295	9922	Economy	28000.00
0005434822695	9922	Economy	28000.00
0005434822089	9922	Economy	28000.00
0005434822378	9922	Economy	28000.00
0005435373323	9922	Economy	28000.00
0005434822373	9922	Economy	28000.00
0005434823102	9922	Economy	28000.00
0005435373305	9922	Economy	28000.00
0005434558207	9922	Economy	28000.00
0005434822640	9922	Economy	28000.00
0005435373318	9922	Economy	28000.00
0005435373341	9922	Economy	28000.00
0005435373345	9922	Economy	28000.00
0005435373317	9922	Economy	28000.00
0005432396209	9922	Economy	28000.00
0005434822617	9922	Economy	28000.00
0005434822574	9922	Economy	28000.00
0005434822712	9922	Economy	28000.00
0005434822436	9922	Economy	28000.00
0005435373354	9922	Economy	28000.00
0005435373316	9922	Economy	28000.00
0005434822595	9922	Economy	30800.00
0005435661935	9922	Economy	28000.00
0005434822692	9922	Economy	28000.00
0005434822437	9922	Economy	28000.00
0005434822760	9922	Economy	30800.00
0005435302203	9922	Economy	30800.00
0005435373344	9922	Economy	28000.00
0005434822827	9922	Economy	28000.00
0005435373339	9922	Economy	28000.00
0005434823083	9922	Economy	28000.00
0005435373348	9922	Economy	28000.00
0005434822255	9922	Economy	28000.00
0005435373350	9922	Economy	28000.00
0005435373297	9922	Economy	28000.00
0005435373321	9922	Economy	28000.00
0005434831103	9922	Economy	28000.00
0005435386578	9922	Economy	28000.00
0005432203072	9922	Economy	28000.00
0005434823008	9922	Economy	28000.00
0005435373357	9922	Economy	28000.00
0005434823130	9922	Economy	28000.00
0005434822200	9922	Economy	28000.00
0005435373359	9922	Economy	28000.00
0005434822139	9922	Economy	28000.00
0005435373325	9922	Economy	28000.00
0005435373360	9922	Economy	28000.00
0005434822133	9922	Economy	28000.00
0005434822883	9922	Economy	28000.00
0005434831091	9922	Economy	28000.00
0005435386576	9922	Economy	28000.00
0005434822759	9922	Economy	28000.00
0005434558208	9922	Economy	28000.00
0005435386574	9922	Economy	28000.00
0005434822580	9922	Economy	28000.00
0005435735142	9922	Economy	28000.00
0005435373355	9922	Economy	28000.00
0005434822857	9922	Economy	28000.00
0005432823453	9922	Economy	28000.00
0005432396214	9922	Economy	28000.00
0005434558201	9922	Economy	28000.00
0005435373347	9922	Economy	28000.00
0005435299780	9922	Economy	28000.00
0005435373340	9922	Economy	28000.00
0005434822935	9922	Economy	28000.00
0005435661934	9922	Economy	28000.00
0005434822856	9922	Economy	28000.00
0005434821906	9922	Economy	28000.00
0005434822201	9922	Economy	28000.00
0005434822602	9922	Economy	28000.00
0005434822267	9922	Economy	28000.00
0005435302204	9922	Economy	28000.00
0005434823108	9922	Economy	28000.00
0005434822253	9922	Economy	28000.00
0005435373309	9922	Economy	28000.00
0005432396205	9922	Economy	28000.00
0005434822689	9922	Economy	28000.00
0005432396208	9922	Economy	28000.00
0005435149945	9922	Economy	28000.00
0005435373320	9922	Economy	28000.00
0005434822725	9922	Economy	28000.00
0005435299781	9922	Economy	28000.00
0005435373334	9922	Economy	28000.00
0005434823006	9922	Economy	28000.00
0005434822673	9922	Economy	28000.00
0005435299779	9922	Economy	28000.00
0005435373352	9922	Economy	28000.00
0005435373314	9922	Economy	28000.00
0005434558202	9922	Economy	28000.00
0005432400084	9922	Economy	28000.00
0005434822716	9922	Economy	28000.00
0005432400083	9922	Economy	28000.00
0005434822769	9922	Economy	28000.00
0005435373294	9922	Economy	28000.00
0005434823082	9922	Economy	28000.00
0005432823454	9922	Economy	30800.00
0005434822658	9922	Economy	30800.00
0005435373319	9922	Economy	30800.00
0005434822670	9922	Economy	30800.00
0005434822531	9922	Economy	30800.00
0005435373308	9922	Economy	30800.00
0005435373298	9922	Economy	28000.00
0005434822598	9922	Economy	28000.00
0005435373315	9922	Economy	28000.00
0005434822224	9922	Economy	28000.00
0005434822986	9922	Economy	28000.00
0005434822591	9922	Economy	28000.00
0005434822597	9922	Economy	28000.00
0005434822288	9922	Economy	28000.00
0005432203070	9922	Economy	28000.00
0005434822370	9922	Economy	28000.00
0005434822184	9922	Economy	28000.00
0005434822138	9922	Economy	28000.00
0005435149879	9922	Economy	28000.00
0005435373332	9922	Economy	28000.00
0005434823129	9922	Economy	28000.00
0005435735141	9922	Economy	28000.00
0005434822903	9922	Economy	28000.00
0005435373346	9922	Economy	28000.00
0005435373311	9922	Economy	28000.00
0005435373330	9922	Economy	28000.00
0005434822783	9922	Economy	28000.00
0005434822721	9922	Economy	28000.00
0005434822702	9922	Economy	28000.00
0005434822594	9922	Economy	28000.00
0005434822869	9922	Economy	28000.00
0005435373301	9922	Economy	28000.00
0005434822198	9922	Economy	28000.00
0005435373333	9922	Economy	28000.00
0005434831109	9922	Economy	28000.00
0005434822910	9922	Economy	28000.00
0005434822782	9922	Economy	28000.00
0005435149944	9922	Economy	28000.00
0005434822544	9922	Economy	28000.00
0005434822374	9922	Economy	28000.00
0005432396219	9922	Economy	28000.00
0005435373343	9922	Economy	28000.00
0005434823055	9922	Economy	28000.00
0005435373353	9922	Economy	28000.00
0005435373358	9922	Economy	28000.00
0005434822601	9922	Economy	28000.00
0005435302202	9922	Economy	28000.00
0005435373310	9922	Economy	28000.00
0005435373349	9922	Economy	28000.00
0005434822672	9922	Economy	28000.00
0005434822657	9922	Economy	28000.00
0005434822287	9922	Economy	28000.00
0005434822306	9922	Economy	28000.00
0005435149934	9922	Economy	28000.00
0005434822197	9922	Economy	28000.00
0005434822302	9922	Economy	28000.00
0005435373304	9922	Economy	28000.00
0005435373299	9922	Economy	28000.00
0005434822509	9922	Economy	28000.00
0005434822443	9922	Economy	28000.00
0005434558209	9922	Economy	28000.00
0005435149915	9922	Economy	28000.00
0005434822199	9922	Economy	28000.00
0005435373307	9922	Economy	28000.00
0005434822586	9922	Economy	28000.00
0005434822985	9922	Economy	28000.00
0005435149939	9922	Economy	28000.00
0005432203068	9922	Economy	28000.00
0005435373313	9922	Economy	28000.00
0005435373329	9922	Economy	28000.00
0005434822703	9922	Economy	28000.00
0005434822405	9922	Economy	28000.00
0005434822543	9922	Economy	28000.00
0005434822256	9922	Economy	28000.00
0005434822867	9922	Economy	28000.00
0005434822836	9922	Economy	28000.00
0005434822685	9922	Economy	28000.00
0005434822064	9922	Economy	28000.00
0005434822678	9922	Economy	28000.00
0005435373306	9922	Economy	28000.00
0005435386577	9922	Economy	28000.00
0005435373356	9922	Economy	28000.00
0005435373328	9922	Economy	28000.00
0005435082793	6992	Economy	8200.00
0005435082792	6992	Economy	8200.00
0005435790309	6992	Economy	7400.00
0005435082788	6992	Economy	7400.00
0005435790308	6992	Economy	7400.00
0005435082789	6992	Economy	7400.00
0005435790310	6992	Economy	7400.00
0005435082791	6992	Economy	7400.00
0005435082790	6992	Economy	7400.00
0005435082794	6992	Economy	7400.00
0005435790298	25974	Economy	8200.00
0005435790297	25974	Economy	7400.00
0005435082740	25974	Economy	7400.00
0005435790295	25974	Economy	7400.00
0005435082716	25974	Economy	7400.00
0005435082728	25974	Economy	7400.00
0005435082717	25974	Economy	7400.00
0005435082726	25974	Economy	7400.00
0005435082723	25974	Economy	7400.00
0005435082724	25974	Economy	7400.00
0005435082738	25974	Economy	7400.00
0005435082727	25974	Economy	7400.00
0005434214087	9565	Business	32800.00
0005434756455	9565	Business	32800.00
0005434756465	9565	Business	32800.00
0005434756449	9565	Business	32800.00
0005434756459	9565	Business	32800.00
0005434214123	9565	Business	32800.00
0005434756450	9565	Business	32800.00
0005434756469	9565	Business	32800.00
0005434214150	9565	Business	32800.00
0005434214117	9565	Business	32800.00
0005434756456	9565	Business	32800.00
0005434756454	9565	Business	32800.00
0005434214281	9565	Economy	10900.00
0005434213969	9565	Economy	10900.00
0005434214126	9565	Economy	10900.00
0005434214099	9565	Economy	10900.00
0005434756446	9565	Economy	10900.00
0005434214154	9565	Economy	10900.00
0005434214013	9565	Economy	10900.00
0005434756452	9565	Economy	10900.00
0005434213979	9565	Economy	10900.00
0005434213961	9565	Economy	10900.00
0005434214182	9565	Economy	12000.00
0005434214121	9565	Economy	12000.00
0005434756458	9565	Economy	12000.00
0005434214232	9565	Economy	10900.00
0005434214312	9565	Economy	10900.00
0005434214118	9565	Economy	10900.00
0005434214079	9565	Economy	10900.00
0005434214120	9565	Economy	10900.00
0005434214309	9565	Economy	10900.00
0005434214080	9565	Economy	10900.00
0005434756451	9565	Economy	10900.00
0005434214223	9565	Economy	10900.00
0005434756460	9565	Economy	10900.00
0005434213981	9565	Economy	10900.00
0005434214167	9565	Economy	10900.00
0005434214086	9565	Economy	10900.00
0005434214198	9565	Economy	10900.00
0005434214197	9565	Economy	10900.00
0005434756457	9565	Economy	10900.00
0005434214058	9565	Economy	10900.00
0005434214193	9565	Economy	10900.00
0005434214245	9565	Economy	10900.00
0005434214170	9565	Economy	10900.00
0005434214195	9565	Economy	10900.00
0005434756467	9565	Economy	10900.00
0005434756448	9565	Economy	10900.00
0005434214220	9565	Economy	10900.00
0005434214122	9565	Economy	10900.00
0005434214234	9565	Economy	10900.00
0005434214247	9565	Economy	10900.00
0005434756463	9565	Economy	10900.00
0005434214221	9565	Economy	10900.00
0005434213933	9565	Economy	10900.00
0005434214067	9565	Economy	10900.00
0005434756461	9565	Economy	10900.00
0005434213962	9565	Economy	10900.00
0005434756466	9565	Economy	10900.00
0005434214153	9565	Economy	10900.00
0005434213959	9565	Economy	10900.00
0005434214194	9565	Economy	10900.00
0005434214222	9565	Economy	10900.00
0005434214250	9565	Economy	10900.00
0005434214171	9565	Economy	10900.00
0005434214280	9565	Economy	10900.00
0005434213847	9565	Economy	10900.00
0005434214125	9565	Economy	10900.00
0005434214089	9565	Economy	10900.00
0005434213958	9565	Economy	10900.00
0005434756462	9565	Economy	10900.00
0005434214179	9565	Economy	10900.00
0005434214233	9565	Economy	10900.00
0005434213846	9565	Economy	10900.00
0005434214204	9565	Economy	10900.00
0005434214064	9565	Economy	10900.00
0005434756464	9565	Economy	10900.00
0005434213982	9565	Economy	10900.00
0005434214231	9565	Economy	10900.00
0005434214012	9565	Economy	10900.00
0005434214199	9565	Economy	10900.00
0005434756447	9565	Economy	10900.00
0005434214310	9565	Economy	10900.00
0005434214190	9565	Economy	10900.00
0005434214063	9565	Economy	10900.00
0005434213934	9565	Economy	10900.00
0005434214027	9565	Economy	10900.00
0005434214200	9565	Economy	10900.00
0005434756453	9565	Economy	10900.00
0005434756468	9565	Economy	10900.00
0005434755858	28642	Business	32800.00
0005434756186	28642	Business	32800.00
0005434755947	28642	Business	32800.00
0005434214527	28642	Business	32800.00
0005434214524	28642	Business	32800.00
0005434756098	28642	Business	32800.00
0005434756066	28642	Business	32800.00
0005434214532	28642	Business	32800.00
0005434214536	28642	Business	32800.00
0005434214552	28642	Business	32800.00
0005434214553	28642	Business	32800.00
0005434755964	28642	Economy	10900.00
0005434756127	28642	Economy	10900.00
0005434756094	28642	Economy	10900.00
0005434214547	28642	Economy	10900.00
0005434214528	28642	Economy	10900.00
0005434214516	28642	Economy	10900.00
0005434756058	28642	Economy	10900.00
0005434756093	28642	Economy	10900.00
0005434214521	28642	Economy	10900.00
0005434214512	28642	Economy	10900.00
0005434756023	28642	Economy	12000.00
0005434756052	28642	Economy	12000.00
0005434214551	28642	Economy	12000.00
0005434755974	28642	Economy	12000.00
0005434214539	28642	Economy	12000.00
0005434214514	28642	Economy	10900.00
0005434756016	28642	Economy	10900.00
0005434214549	28642	Economy	10900.00
0005434756077	28642	Economy	10900.00
0005434755945	28642	Economy	10900.00
0005434214541	28642	Economy	10900.00
0005434755962	28642	Economy	10900.00
0005434214534	28642	Economy	10900.00
0005434756074	28642	Economy	10900.00
0005434214515	28642	Economy	10900.00
0005434756078	28642	Economy	10900.00
0005434756104	28642	Economy	10900.00
0005434756073	28642	Economy	10900.00
0005434756117	28642	Economy	10900.00
0005434755898	28642	Economy	10900.00
0005434756086	28642	Economy	10900.00
0005434214531	28642	Economy	10900.00
0005434214529	28642	Economy	10900.00
0005434214545	28642	Economy	10900.00
0005434755946	28642	Economy	10900.00
0005434214508	28642	Economy	10900.00
0005434755897	28642	Economy	10900.00
0005434756172	28642	Economy	10900.00
0005434214533	28642	Economy	10900.00
0005434214544	28642	Economy	10900.00
0005434756079	28642	Economy	10900.00
0005434756091	28642	Economy	10900.00
0005434755948	28642	Economy	10900.00
0005434214555	28642	Economy	10900.00
0005434756119	28642	Economy	10900.00
0005434214542	28642	Economy	10900.00
0005434756130	28642	Economy	10900.00
0005434214517	28642	Economy	10900.00
0005434214546	28642	Economy	10900.00
0005434756070	28642	Economy	10900.00
0005434214526	28642	Economy	10900.00
0005434756001	28642	Economy	10900.00
0005434755982	28642	Economy	10900.00
0005434214537	28642	Economy	10900.00
0005434214550	28642	Economy	10900.00
0005434214518	28642	Economy	10900.00
0005434214510	28642	Economy	10900.00
0005434214535	28642	Economy	10900.00
0005434756027	28642	Economy	10900.00
0005434214554	28642	Economy	10900.00
0005434214525	28642	Economy	10900.00
0005434214519	28642	Economy	10900.00
0005434214556	28642	Economy	10900.00
0005434214543	28642	Economy	10900.00
0005434214509	28642	Economy	10900.00
0005434756092	28642	Economy	10900.00
0005434214538	28642	Economy	10900.00
0005434214513	28642	Economy	10900.00
0005434756051	28642	Economy	10900.00
0005434755883	28642	Economy	10900.00
0005434214540	28642	Economy	10900.00
0005434755961	28642	Economy	10900.00
0005434214530	28642	Economy	10900.00
0005434214520	28642	Economy	10900.00
0005434756017	28642	Economy	10900.00
0005434214523	28642	Economy	10900.00
0005434214522	28642	Economy	10900.00
0005434214511	28642	Economy	10900.00
0005434214548	28642	Economy	10900.00
0005434756048	28642	Economy	10900.00
0005435100127	10830	Economy	9800.00
0005434760172	10830	Economy	8900.00
0005435100126	10830	Economy	8900.00
0005435100098	31821	Economy	8900.00
0005435100112	31821	Economy	8900.00
0005434760200	31821	Economy	8900.00
0005434760201	31821	Economy	8900.00
0005435100102	31821	Economy	8900.00
0005435100113	31821	Economy	8900.00
0005435100097	31821	Economy	8900.00
0005434639343	1956	Economy	20900.00
0005434639361	1956	Economy	20900.00
0005432290637	1956	Economy	20900.00
0005433202263	1956	Economy	19000.00
0005433202257	1956	Economy	19000.00
0005432290635	1956	Economy	19000.00
0005432290638	1956	Economy	19000.00
0005434639344	1956	Economy	19000.00
0005434639353	1956	Economy	19000.00
0005433202267	1956	Economy	19000.00
0005434639348	1956	Economy	19000.00
0005434639357	1956	Economy	19000.00
0005434639345	1956	Economy	19000.00
0005433202226	1956	Economy	19000.00
0005433202194	1956	Economy	19000.00
0005434639352	1956	Economy	19000.00
0005433202197	1956	Economy	19000.00
0005434639355	1956	Economy	19000.00
0005434639366	1956	Economy	19000.00
0005434639360	1956	Economy	19000.00
0005433202193	1956	Economy	19000.00
0005434639341	1956	Economy	19000.00
0005433202201	1956	Economy	19000.00
0005433202273	1956	Economy	19000.00
0005433202196	1956	Economy	19000.00
0005433202280	1956	Economy	19000.00
0005434639354	1956	Economy	19000.00
0005434639363	1956	Economy	19000.00
0005434639342	1956	Economy	19000.00
0005434639350	1956	Economy	19000.00
0005434639346	1956	Economy	19000.00
0005434639362	1956	Economy	19000.00
0005434639339	1956	Economy	19000.00
0005433202293	1956	Economy	19000.00
0005434639351	1956	Economy	19000.00
0005434639356	1956	Economy	19000.00
0005433202260	1956	Economy	19000.00
0005433202216	1956	Economy	19000.00
0005434639347	1956	Economy	19000.00
0005433202261	1956	Economy	19000.00
0005433202192	1956	Economy	19000.00
0005434639349	1956	Economy	19000.00
0005434639340	1956	Economy	19000.00
0005434639358	1956	Economy	19000.00
0005433202262	1956	Economy	19000.00
0005432290636	1956	Economy	19000.00
0005434639365	1956	Economy	19000.00
0005434639364	1956	Economy	19000.00
0005434639359	1956	Economy	19000.00
0005434639028	23277	Economy	20900.00
0005434639174	23277	Economy	20900.00
0005434639023	23277	Economy	20900.00
0005433202362	23277	Economy	20900.00
0005433202367	23277	Economy	19000.00
0005433202365	23277	Economy	19000.00
0005433202359	23277	Economy	19000.00
0005433202369	23277	Economy	19000.00
0005434639186	23277	Economy	19000.00
0005434639175	23277	Economy	19000.00
0005433202360	23277	Economy	19000.00
0005434639037	23277	Economy	19000.00
0005434639187	23277	Economy	19000.00
0005434639078	23277	Economy	19000.00
0005434639061	23277	Economy	19000.00
0005433202366	23277	Economy	19000.00
0005433202358	23277	Economy	19000.00
0005434639220	23277	Economy	19000.00
0005434639077	23277	Economy	19000.00
0005433202371	23277	Economy	19000.00
0005434639062	23277	Economy	19000.00
0005434639165	23277	Economy	19000.00
0005434639155	23277	Economy	19000.00
0005433202361	23277	Economy	19000.00
0005435948313	23277	Economy	19000.00
0005434639116	23277	Economy	19000.00
0005434639185	23277	Economy	19000.00
0005433202372	23277	Economy	19000.00
0005434639084	23277	Economy	19000.00
0005434639004	23277	Economy	19000.00
0005434639117	23277	Economy	19000.00
0005434639104	23277	Economy	19000.00
0005433202364	23277	Economy	19000.00
0005433202373	23277	Economy	19000.00
0005433202363	23277	Economy	19000.00
0005433202368	23277	Economy	19000.00
0005434638971	23277	Economy	19000.00
0005434639154	23277	Economy	19000.00
0005433202370	23277	Economy	19000.00
0005435948312	23277	Economy	19000.00
0005434639024	23277	Economy	19000.00
0005434639088	23277	Economy	19000.00
0005434639060	23277	Economy	19000.00
0005434600827	6078	Business	69700.00
0005434600828	6078	Business	69700.00
0005434600839	6078	Business	69700.00
0005434600838	6078	Business	69700.00
0005433533313	6078	Business	69700.00
0005435326617	6078	Business	69700.00
0005435326708	6078	Business	69700.00
0005433531299	6078	Business	69700.00
0005434600840	6078	Business	69700.00
0005434600830	6078	Economy	23200.00
0005433531296	6078	Economy	23200.00
0005434600831	6078	Economy	23200.00
0005434600836	6078	Economy	23200.00
0005434600846	6078	Economy	23200.00
0005434600849	6078	Economy	23200.00
0005434600832	6078	Economy	25600.00
0005433533312	6078	Economy	23200.00
0005434600850	6078	Economy	23200.00
0005434600829	6078	Economy	23200.00
0005433531300	6078	Economy	23200.00
0005434600843	6078	Economy	23200.00
0005435326654	6078	Economy	23200.00
0005435326594	6078	Economy	23200.00
0005434600848	6078	Economy	23200.00
0005434600837	6078	Economy	23200.00
0005432111280	6078	Economy	23200.00
0005434600833	6078	Economy	23200.00
0005434600824	6078	Economy	23200.00
0005433531297	6078	Economy	23200.00
0005435326619	6078	Economy	23200.00
0005432111283	6078	Economy	23200.00
0005434600847	6078	Economy	23200.00
0005434600842	6078	Economy	23200.00
0005435326681	6078	Economy	23200.00
0005432111281	6078	Economy	23200.00
0005433533310	6078	Economy	23200.00
0005434600845	6078	Economy	23200.00
0005434600844	6078	Economy	23200.00
0005432111282	6078	Economy	23200.00
0005434600834	6078	Economy	23200.00
0005434600835	6078	Economy	23200.00
0005434600823	6078	Economy	23200.00
0005433531298	6078	Economy	23200.00
0005434600825	6078	Economy	23200.00
0005435326648	6078	Economy	23200.00
0005435326618	6078	Economy	23200.00
0005433533311	6078	Economy	23200.00
0005434600826	6078	Economy	23200.00
0005434600841	6078	Economy	23200.00
0005435326649	6078	Economy	23200.00
0005433531295	6078	Economy	23200.00
0005434600549	18577	Business	69700.00
0005434600672	18577	Business	69700.00
0005434600514	18577	Business	69700.00
0005434600602	18577	Business	69700.00
0005434600591	18577	Business	69700.00
0005434600637	18577	Economy	23200.00
0005433527206	18577	Economy	23200.00
0005435326756	18577	Economy	23200.00
0005434600635	18577	Economy	23200.00
0005435326754	18577	Economy	23200.00
0005434600596	18577	Economy	25600.00
0005434600679	18577	Economy	25600.00
0005434600552	18577	Economy	25600.00
0005435326762	18577	Economy	25600.00
0005434600525	18577	Economy	23200.00
0005435326763	18577	Economy	23200.00
0005433527227	18577	Economy	23200.00
0005434600582	18577	Economy	23200.00
0005434600633	18577	Economy	23200.00
0005435326759	18577	Economy	23200.00
0005433527233	18577	Economy	23200.00
0005434600675	18577	Economy	23200.00
0005435326765	18577	Economy	23200.00
0005434600583	18577	Economy	23200.00
0005434600571	18577	Economy	23200.00
0005434600708	18577	Economy	23200.00
0005434600624	18577	Economy	23200.00
0005433527231	18577	Economy	23200.00
0005435326752	18577	Economy	23200.00
0005433527232	18577	Economy	23200.00
0005435326761	18577	Economy	23200.00
0005434600513	18577	Economy	23200.00
0005433527228	18577	Economy	23200.00
0005434600616	18577	Economy	23200.00
0005435326758	18577	Economy	23200.00
0005435326755	18577	Economy	23200.00
0005434600707	18577	Economy	23200.00
0005435326764	18577	Economy	23200.00
0005435326753	18577	Economy	23200.00
0005434600572	18577	Economy	23200.00
0005434600445	18577	Economy	23200.00
0005434600485	18577	Economy	23200.00
0005434600678	18577	Economy	23200.00
0005434600601	18577	Economy	23200.00
0005434600628	18577	Economy	23200.00
0005434600650	18577	Economy	23200.00
0005435326757	18577	Economy	23200.00
0005434600466	18577	Economy	23200.00
0005434600548	18577	Economy	23200.00
0005434600573	18577	Economy	23200.00
0005434600636	18577	Economy	23200.00
0005435326760	18577	Economy	23200.00
0005433527205	18577	Economy	23200.00
0005434600574	18577	Economy	23200.00
0005433531279	18577	Economy	23200.00
0005434551218	10659	Business	9100.00
0005434551250	10659	Business	9100.00
0005434551263	10659	Business	9100.00
0005434551261	10659	Business	9100.00
0005433180871	10659	Business	9100.00
0005434551235	10659	Business	9100.00
0005434551225	10659	Business	9100.00
0005434551245	10659	Business	9100.00
0005434551255	10659	Business	9100.00
0005434551240	10659	Business	9100.00
0005434558278	10659	Business	9100.00
0005433180931	10659	Business	9100.00
0005433180812	10659	Economy	3000.00
0005434551259	10659	Economy	3000.00
0005434558277	10659	Economy	3000.00
0005434558279	10659	Economy	3000.00
0005434551220	10659	Economy	3000.00
0005434551258	10659	Economy	3000.00
0005434558271	10659	Economy	3000.00
0005434558268	10659	Economy	3000.00
0005434551214	10659	Economy	3000.00
0005433180756	10659	Economy	3000.00
0005434551266	10659	Economy	3300.00
0005434551254	10659	Economy	3300.00
0005434558274	10659	Economy	3300.00
0005434551265	10659	Economy	3300.00
0005434551239	10659	Economy	3300.00
0005434551219	10659	Economy	3000.00
0005434551227	10659	Economy	3000.00
0005434551248	10659	Economy	3000.00
0005434558276	10659	Economy	3000.00
0005434554066	10659	Economy	3000.00
0005433180797	10659	Economy	3000.00
0005434551226	10659	Economy	3000.00
0005433180808	10659	Economy	3000.00
0005433180854	10659	Economy	3000.00
0005433180815	10659	Economy	3000.00
0005434551256	10659	Economy	3000.00
0005434551234	10659	Economy	3000.00
0005434551257	10659	Economy	3000.00
0005434551215	10659	Economy	3000.00
0005433180865	10659	Economy	3000.00
0005434558269	10659	Economy	3000.00
0005434551252	10659	Economy	3000.00
0005433180795	10659	Economy	3000.00
0005434551229	10659	Economy	3000.00
0005433180863	10659	Economy	3000.00
0005434551249	10659	Economy	3000.00
0005434551228	10659	Economy	3000.00
0005433180874	10659	Economy	3000.00
0005433180864	10659	Economy	3000.00
0005434551260	10659	Economy	3000.00
0005434551223	10659	Economy	3000.00
0005433180877	10659	Economy	3000.00
0005434551233	10659	Economy	3000.00
0005433180981	10659	Economy	3000.00
0005434558275	10659	Economy	3000.00
0005434551222	10659	Economy	3000.00
0005433180796	10659	Economy	3000.00
0005434551246	10659	Economy	3000.00
0005434551236	10659	Economy	3000.00
0005434558272	10659	Economy	3000.00
0005434551267	10659	Economy	3000.00
0005434551230	10659	Economy	3000.00
0005434551241	10659	Economy	3000.00
0005434558280	10659	Economy	3000.00
0005434551244	10659	Economy	3000.00
0005434551232	10659	Economy	3000.00
0005434558273	10659	Economy	3000.00
0005434551262	10659	Economy	3000.00
0005434551253	10659	Economy	3000.00
0005434551212	10659	Economy	3000.00
0005433180862	10659	Economy	3000.00
0005433180809	10659	Economy	3000.00
0005433180846	10659	Economy	3000.00
0005434558270	10659	Economy	3000.00
0005434551221	10659	Economy	3000.00
0005434554067	10659	Economy	3000.00
0005434551213	10659	Economy	3000.00
0005434551251	10659	Economy	3000.00
0005433180757	10659	Economy	3000.00
0005434551217	10659	Economy	3000.00
0005434551247	10659	Economy	3000.00
0005434551216	10659	Economy	3000.00
0005434551242	10659	Economy	3000.00
0005434551264	10659	Economy	3000.00
0005433181017	10659	Economy	3000.00
0005434551243	10659	Economy	3000.00
0005433180932	10659	Economy	3000.00
0005434551238	10659	Economy	3000.00
0005434551237	10659	Economy	3000.00
0005434551224	10659	Economy	3000.00
0005433180842	10659	Economy	3000.00
0005434551231	10659	Economy	3000.00
0005433180875	10659	Economy	3000.00
0005433181113	27772	Business	9100.00
0005433181125	27772	Business	9100.00
0005433181132	27772	Economy	3000.00
0005433181118	27772	Economy	3000.00
0005433181136	27772	Economy	3300.00
0005433181120	27772	Economy	3000.00
0005433181123	27772	Economy	3000.00
0005433181134	27772	Economy	3000.00
0005433181119	27772	Economy	3000.00
0005433181121	27772	Economy	3000.00
0005433181122	27772	Economy	3000.00
0005433181116	27772	Economy	3000.00
0005433181137	27772	Economy	3000.00
0005433181133	27772	Economy	3000.00
0005433181135	27772	Economy	3000.00
0005433181131	27772	Economy	3000.00
0005433181117	27772	Economy	3000.00
0005433181129	27772	Economy	3000.00
0005433181114	27772	Economy	3000.00
0005433181127	27772	Economy	3000.00
0005433181128	27772	Economy	3000.00
0005433181126	27772	Economy	3000.00
0005433181124	27772	Economy	3000.00
0005433181130	27772	Economy	3000.00
0005433181115	27772	Economy	3000.00
0005433181138	27772	Economy	3000.00
0005434550904	27773	Business	9100.00
0005434558211	27773	Business	9100.00
0005434550692	27773	Business	9100.00
0005434550566	27773	Business	9100.00
0005434550809	27773	Business	9100.00
0005434550401	27773	Business	9100.00
0005434550893	27773	Business	9100.00
0005434550678	27773	Business	9100.00
0005434550877	27773	Business	9100.00
0005434550586	27773	Economy	3000.00
0005434550865	27773	Economy	3000.00
0005434550584	27773	Economy	3000.00
0005434558213	27773	Economy	3000.00
0005434550863	27773	Economy	3000.00
0005434550590	27773	Economy	3000.00
0005434550828	27773	Economy	3000.00
0005434558197	27773	Economy	3300.00
0005434558186	27773	Economy	3300.00
0005434554050	27773	Economy	3300.00
0005434550838	27773	Economy	3300.00
0005434558199	27773	Economy	3000.00
0005434558217	27773	Economy	3000.00
0005434550764	27773	Economy	3000.00
0005434550783	27773	Economy	3000.00
0005434550778	27773	Economy	3000.00
0005434550646	27773	Economy	3000.00
0005434550647	27773	Economy	3000.00
0005434551023	27773	Economy	3000.00
0005434550648	27773	Economy	3000.00
0005434550564	27773	Economy	3000.00
0005434550664	27773	Economy	3000.00
0005434550788	27773	Economy	3000.00
0005434550565	27773	Economy	3000.00
0005434550823	27773	Economy	3000.00
0005434558218	27773	Economy	3000.00
0005434558212	27773	Economy	3000.00
0005434550691	27773	Economy	3000.00
0005434550892	27773	Economy	3000.00
0005434550494	27773	Economy	3000.00
0005434550724	27773	Economy	3000.00
0005434550587	27773	Economy	3000.00
0005434550765	27773	Economy	3000.00
0005434550698	27773	Economy	3000.00
0005434550775	27773	Economy	3000.00
0005434550563	27773	Economy	3000.00
0005434550979	27773	Economy	3000.00
0005434558175	27773	Economy	3000.00
0005434558200	27773	Economy	3000.00
0005434550866	27773	Economy	3000.00
0005434550732	27773	Economy	3000.00
0005434550766	27773	Economy	3000.00
0005434550787	27773	Economy	3000.00
0005434550864	27773	Economy	3000.00
0005434558191	27773	Economy	3000.00
0005434550744	27773	Economy	3000.00
0005434550773	27773	Economy	3000.00
0005434558216	27773	Economy	3000.00
0005434550774	27773	Economy	3000.00
0005434558203	27773	Economy	3000.00
0005435254446	6118	Economy	11700.00
0005435254454	6118	Economy	11700.00
0005435254463	6118	Economy	11700.00
0005433459223	6118	Economy	11700.00
0005433459222	6118	Economy	11700.00
0005433459225	6118	Economy	11700.00
0005435254464	6118	Economy	11700.00
0005435254445	6118	Economy	11700.00
0005433459224	6118	Economy	11700.00
0005435254456	6118	Economy	11700.00
0005435254478	19323	Economy	11700.00
0005433459183	19323	Economy	11700.00
0005433459201	19323	Economy	11700.00
0005433459184	19323	Economy	11700.00
0005435254477	19323	Economy	11700.00
0005435254476	19323	Economy	11700.00
0005433459202	19323	Economy	11700.00
0005435220306	6757	Business	51100.00
0005435682191	6757	Business	51100.00
0005435682156	6757	Business	51100.00
0005432533258	6757	Business	51100.00
0005435682163	6757	Business	51100.00
0005435661931	6757	Business	51100.00
0005435682188	6757	Business	51100.00
0005434828682	6757	Business	51100.00
0005434828677	6757	Business	51100.00
0005435437813	6757	Business	51100.00
0005435437881	6757	Business	51100.00
0005435720132	6757	Economy	17000.00
0005435682197	6757	Economy	17000.00
0005435682168	6757	Economy	17000.00
0005432136175	6757	Economy	17000.00
0005435437824	6757	Economy	17000.00
0005435682190	6757	Economy	17000.00
0005435682173	6757	Economy	17000.00
0005435682169	6757	Economy	17000.00
0005435437810	6757	Economy	17000.00
0005435437782	6757	Economy	18700.00
0005435437879	6757	Economy	18700.00
0005435682182	6757	Economy	18700.00
0005435437733	6757	Economy	18700.00
0005435437734	6757	Economy	18700.00
0005435682195	6757	Economy	17000.00
0005434828678	6757	Economy	17000.00
0005432533263	6757	Economy	17000.00
0005435630968	6757	Economy	17000.00
0005435682171	6757	Economy	17000.00
0005435661932	6757	Economy	17000.00
0005435682155	6757	Economy	17000.00
0005435437809	6757	Economy	17000.00
0005435682160	6757	Economy	17000.00
0005435437931	6757	Economy	17000.00
0005435682170	6757	Economy	17000.00
0005435720134	6757	Economy	17000.00
0005435682183	6757	Economy	17000.00
0005435682162	6757	Economy	17000.00
0005435682172	6757	Economy	17000.00
0005434828663	6757	Economy	17000.00
0005435682192	6757	Economy	17000.00
0005434828664	6757	Economy	17000.00
0005435682181	6757	Economy	17000.00
0005432136172	6757	Economy	17000.00
0005435682179	6757	Economy	17000.00
0005435682186	6757	Economy	17000.00
0005435220301	6757	Economy	17000.00
0005435682178	6757	Economy	17000.00
0005435682157	6757	Economy	17000.00
0005435682167	6757	Economy	17000.00
0005435682177	6757	Economy	17000.00
0005435682158	6757	Economy	17000.00
0005435682161	6757	Economy	17000.00
0005435682165	6757	Economy	17000.00
0005434828669	6757	Economy	17000.00
0005435682194	6757	Economy	17000.00
0005435682166	6757	Economy	17000.00
0005435682196	6757	Economy	17000.00
0005435682189	6757	Economy	17000.00
0005435437930	6757	Economy	17000.00
0005435221504	6757	Economy	17000.00
0005435217695	6757	Economy	17000.00
0005435720133	6757	Economy	17000.00
0005435682174	6757	Economy	17000.00
0005435682185	6757	Economy	17000.00
0005435682187	6757	Economy	17000.00
0005435682184	6757	Economy	17000.00
0005435682193	6757	Economy	17000.00
0005435682164	6757	Economy	17000.00
0005435437880	6757	Economy	17000.00
0005435682176	6757	Economy	17000.00
0005435437770	6757	Economy	17000.00
0005435220302	6757	Economy	17000.00
0005435682175	6757	Economy	17000.00
0005435682180	6757	Economy	17000.00
0005432136173	6757	Economy	17000.00
0005432136174	6757	Economy	17000.00
0005435682159	6757	Economy	17000.00
0005435437975	24590	Business	51100.00
0005435437969	24590	Business	51100.00
0005432533294	24590	Business	51100.00
0005435681730	24590	Business	51100.00
0005435681919	24590	Business	51100.00
0005435681775	24590	Business	51100.00
0005432305750	24590	Business	51100.00
0005435437982	24590	Business	51100.00
0005435681769	24590	Business	51100.00
0005435681912	24590	Economy	17000.00
0005435681956	24590	Economy	17000.00
0005435681857	24590	Economy	17000.00
0005434828701	24590	Economy	17000.00
0005435437981	24590	Economy	17000.00
0005435681810	24590	Economy	17000.00
0005435681864	24590	Economy	18700.00
0005432533296	24590	Economy	18700.00
0005435681839	24590	Economy	18700.00
0005435437972	24590	Economy	17000.00
0005435437967	24590	Economy	17000.00
0005435661904	24590	Economy	17000.00
0005435630947	24590	Economy	17000.00
0005435681875	24590	Economy	17000.00
0005435437973	24590	Economy	17000.00
0005435437961	24590	Economy	17000.00
0005435681777	24590	Economy	17000.00
0005435681710	24590	Economy	17000.00
0005435681643	24590	Economy	17000.00
0005435437979	24590	Economy	17000.00
0005435437978	24590	Economy	17000.00
0005434828700	24590	Economy	17000.00
0005435437977	24590	Economy	17000.00
0005435681806	24590	Economy	17000.00
0005435437963	24590	Economy	17000.00
0005435437971	24590	Economy	17000.00
0005435681930	24590	Economy	17000.00
0005435681703	24590	Economy	17000.00
0005435437974	24590	Economy	17000.00
0005435681711	24590	Economy	17000.00
0005435437965	24590	Economy	17000.00
0005435681774	24590	Economy	17000.00
0005435681745	24590	Economy	17000.00
0005435681731	24590	Economy	17000.00
0005432305751	24590	Economy	17000.00
0005435681944	24590	Economy	17000.00
0005435681804	24590	Economy	17000.00
0005435681762	24590	Economy	17000.00
0005435681763	24590	Economy	17000.00
0005435681781	24590	Economy	17000.00
0005435661903	24590	Economy	17000.00
0005435681888	24590	Economy	17000.00
0005435437968	24590	Economy	17000.00
0005435661897	24590	Economy	17000.00
0005435630945	24590	Economy	17000.00
0005435437976	24590	Economy	17000.00
0005435681712	24590	Economy	17000.00
0005435681721	24590	Economy	17000.00
0005435437966	24590	Economy	17000.00
0005435681811	24590	Economy	17000.00
0005435681913	24590	Economy	17000.00
0005435681878	24590	Economy	17000.00
0005435437980	24590	Economy	17000.00
0005435681782	24590	Economy	17000.00
0005432533293	24590	Economy	17000.00
0005435437970	24590	Economy	17000.00
0005435681865	24590	Economy	17000.00
0005435681744	24590	Economy	17000.00
0005435681732	24590	Economy	17000.00
0005432533295	24590	Economy	17000.00
0005435681630	24590	Economy	17000.00
0005435681668	24590	Economy	17000.00
0005435437962	24590	Economy	17000.00
0005435630946	24590	Economy	17000.00
0005435437964	24590	Economy	17000.00
0005435681955	24590	Economy	17000.00
0005435681951	24590	Economy	17000.00
0005435126376	11544	Business	26400.00
0005435126391	11544	Business	26400.00
0005435126372	11544	Business	26400.00
0005435126355	11544	Business	26400.00
0005435126384	11544	Business	26400.00
0005435098559	11544	Business	26400.00
0005435126373	11544	Business	26400.00
0005435126381	11544	Business	26400.00
0005435126367	11544	Business	26400.00
0005435126379	11544	Economy	8800.00
0005435126371	11544	Economy	8800.00
0005435126361	11544	Economy	8800.00
0005435126365	11544	Economy	8800.00
0005435126388	11544	Economy	8800.00
0005435126375	11544	Economy	8800.00
0005435126364	11544	Economy	9700.00
0005435126357	11544	Economy	9700.00
0005435126387	11544	Economy	8800.00
0005435126370	11544	Economy	8800.00
0005435098553	11544	Economy	8800.00
0005435126395	11544	Economy	8800.00
0005435098555	11544	Economy	8800.00
0005435126363	11544	Economy	8800.00
0005435126360	11544	Economy	8800.00
0005435105982	11544	Economy	8800.00
0005435126390	11544	Economy	8800.00
0005435126393	11544	Economy	8800.00
0005435126359	11544	Economy	8800.00
0005435105983	11544	Economy	8800.00
0005435126392	11544	Economy	8800.00
0005435126356	11544	Economy	8800.00
0005435126383	11544	Economy	8800.00
0005435126374	11544	Economy	8800.00
0005435126368	11544	Economy	8800.00
0005435558051	11544	Economy	8800.00
0005435098556	11544	Economy	8800.00
0005435126380	11544	Economy	8800.00
0005435126386	11544	Economy	8800.00
0005435098557	11544	Economy	8800.00
0005435126385	11544	Economy	8800.00
0005435126358	11544	Economy	8800.00
0005435126369	11544	Economy	8800.00
0005435126378	11544	Economy	8800.00
0005435098554	11544	Economy	8800.00
0005435126389	11544	Economy	8800.00
0005435126362	11544	Economy	8800.00
0005435126394	11544	Economy	8800.00
0005435098558	11544	Economy	8800.00
0005435105981	11544	Economy	8800.00
0005435126377	11544	Economy	8800.00
0005435126382	11544	Economy	8800.00
0005435098552	11544	Economy	8800.00
0005435126366	11544	Economy	8800.00
0005435098560	11544	Economy	8800.00
0005435105953	31859	Business	26400.00
0005435126019	31859	Business	26400.00
0005435126204	31859	Business	26400.00
0005435125852	31859	Business	26400.00
0005435126322	31859	Business	26400.00
0005435126057	31859	Business	26400.00
0005435558089	31859	Business	26400.00
0005435126147	31859	Business	26400.00
0005435125968	31859	Business	26400.00
0005435126182	31859	Economy	8800.00
0005435105971	31859	Economy	8800.00
0005435125906	31859	Economy	8800.00
0005435125997	31859	Economy	9700.00
0005435126040	31859	Economy	9700.00
0005435105949	31859	Economy	9700.00
0005435126137	31859	Economy	8800.00
0005435126160	31859	Economy	8800.00
0005435126206	31859	Economy	8800.00
0005435125979	31859	Economy	8800.00
0005435126230	31859	Economy	8800.00
0005435126146	31859	Economy	8800.00
0005435125919	31859	Economy	8800.00
0005435126067	31859	Economy	8800.00
0005435126180	31859	Economy	8800.00
0005435126148	31859	Economy	8800.00
0005435125969	31859	Economy	8800.00
0005435125905	31859	Economy	8800.00
0005435126205	31859	Economy	8800.00
0005435125918	31859	Economy	8800.00
0005435126028	31859	Economy	8800.00
0005435125999	31859	Economy	8800.00
0005435125898	31859	Economy	8800.00
0005435125993	31859	Economy	8800.00
0005435126138	31859	Economy	8800.00
0005435105963	31859	Economy	8800.00
0005435126055	31859	Economy	8800.00
0005435126253	31859	Economy	8800.00
0005435126058	31859	Economy	8800.00
0005435558090	31859	Economy	8800.00
0005435125851	31859	Economy	8800.00
0005435126181	31859	Economy	8800.00
0005435126161	31859	Economy	8800.00
0005435125974	31859	Economy	8800.00
0005435126066	31859	Economy	8800.00
0005435126104	31859	Economy	8800.00
0005435126159	31859	Economy	8800.00
0005435126068	31859	Economy	8800.00
0005435126098	31859	Economy	8800.00
0005435126229	31859	Economy	8800.00
0005435125962	31859	Economy	8800.00
0005435126187	31859	Economy	8800.00
0005435126173	31859	Economy	8800.00
0005435125998	31859	Economy	8800.00
0005435125920	31859	Economy	8800.00
0005435126207	31859	Economy	8800.00
0005435126070	31859	Economy	8800.00
0005435105950	31859	Economy	8800.00
0005435126105	31859	Economy	8800.00
0005433398108	13549	Business	36600.00
0005433398103	13549	Business	36600.00
0005433398121	13549	Business	36600.00
0005433398088	13549	Business	36600.00
0005433398102	13549	Business	36600.00
0005435732259	13549	Business	36600.00
0005433398096	13549	Business	36600.00
0005433398093	13549	Business	36600.00
0005433398109	13549	Economy	12200.00
0005433398100	13549	Economy	12200.00
0005435732292	13549	Economy	12200.00
0005433398112	13549	Economy	12200.00
0005433398120	13549	Economy	12200.00
0005435732276	13549	Economy	12200.00
0005433398079	13549	Economy	12200.00
0005433398080	13549	Economy	12200.00
0005433398122	13549	Economy	13400.00
0005433398113	13549	Economy	13400.00
0005433398091	13549	Economy	13400.00
0005433398098	13549	Economy	12200.00
0005433398107	13549	Economy	12200.00
0005433398094	13549	Economy	12200.00
0005433398099	13549	Economy	12200.00
0005433398095	13549	Economy	12200.00
0005435732227	13549	Economy	12200.00
0005433398097	13549	Economy	12200.00
0005433398085	13549	Economy	12200.00
0005433398084	13549	Economy	12200.00
0005433398092	13549	Economy	12200.00
0005435732281	13549	Economy	12200.00
0005433398075	13549	Economy	12200.00
0005433398083	13549	Economy	12200.00
0005433398087	13549	Economy	12200.00
0005435732192	13549	Economy	12200.00
0005433398089	13549	Economy	12200.00
0005435732226	13549	Economy	12200.00
0005433398114	13549	Economy	12200.00
0005433398077	13549	Economy	12200.00
0005433398117	13549	Economy	12200.00
0005433398082	13549	Economy	12200.00
0005433398115	13549	Economy	12200.00
0005433398106	13549	Economy	12200.00
0005433398076	13549	Economy	12200.00
0005435732247	13549	Economy	12200.00
0005433398123	13549	Economy	12200.00
0005433398081	13549	Economy	12200.00
0005435732258	13549	Economy	12200.00
0005433398116	13549	Economy	12200.00
0005433398078	13549	Economy	12200.00
0005435732291	13549	Economy	12200.00
0005433398105	13549	Economy	12200.00
0005433398111	13549	Economy	12200.00
0005433398118	13549	Economy	12200.00
0005433398086	13549	Economy	12200.00
0005433398090	13549	Economy	12200.00
0005433398104	13549	Economy	12200.00
0005435732193	13549	Economy	12200.00
0005433398101	13549	Economy	12200.00
0005433398119	13549	Economy	12200.00
0005433398110	13549	Economy	12200.00
0005435732330	19413	Business	36600.00
0005435732327	19413	Business	36600.00
0005433397837	19413	Business	36600.00
0005433397611	19413	Business	36600.00
0005433397786	19413	Business	36600.00
0005435732344	19413	Business	36600.00
0005435732328	19413	Business	36600.00
0005433397792	19413	Business	36600.00
0005433397521	19413	Business	36600.00
0005433397626	19413	Economy	12200.00
0005433397799	19413	Economy	12200.00
0005433397684	19413	Economy	12200.00
0005433397676	19413	Economy	12200.00
0005433397800	19413	Economy	12200.00
0005433397696	19413	Economy	12200.00
0005433397657	19413	Economy	13400.00
0005433397520	19413	Economy	13400.00
0005433397535	19413	Economy	13400.00
0005433397566	19413	Economy	12200.00
0005435732339	19413	Economy	12200.00
0005435732331	19413	Economy	12200.00
0005435732342	19413	Economy	12200.00
0005435732332	19413	Economy	12200.00
0005433397644	19413	Economy	12200.00
0005433397774	19413	Economy	12200.00
0005435732335	19413	Economy	12200.00
0005433397645	19413	Economy	12200.00
0005435732333	19413	Economy	12200.00
0005433397522	19413	Economy	12200.00
0005433397625	19413	Economy	12200.00
0005433397598	19413	Economy	12200.00
0005433397801	19413	Economy	12200.00
0005435732337	19413	Economy	12200.00
0005433397536	19413	Economy	12200.00
0005433397545	19413	Economy	12200.00
0005433397791	19413	Economy	12200.00
0005433397537	19413	Economy	12200.00
0005433397692	19413	Economy	12200.00
0005433397817	19413	Economy	12200.00
0005433397798	19413	Economy	12200.00
0005435732338	19413	Economy	12200.00
0005435732345	19413	Economy	12200.00
0005435732343	19413	Economy	12200.00
0005433397761	19413	Economy	12200.00
0005433397702	19413	Economy	12200.00
0005435732336	19413	Economy	12200.00
0005433397544	19413	Economy	12200.00
0005433397977	19413	Economy	12200.00
0005432297280	19413	Economy	12200.00
0005435732346	19413	Economy	12200.00
0005433397608	19413	Economy	12200.00
0005433397780	19413	Economy	12200.00
0005433397690	19413	Economy	12200.00
0005433397381	19413	Economy	12200.00
0005432297279	19413	Economy	12200.00
0005433397807	19413	Economy	12200.00
0005435732341	19413	Economy	12200.00
0005433397978	19413	Economy	12200.00
0005432297278	19413	Economy	12200.00
0005435732329	19413	Economy	12200.00
0005433397691	19413	Economy	12200.00
0005433397766	19413	Economy	12200.00
0005433397567	19413	Economy	12200.00
0005433397808	19413	Economy	12200.00
0005435732340	19413	Economy	12200.00
0005435732334	19413	Economy	12200.00
0005435068878	13168	Business	11300.00
0005435925296	13168	Business	11300.00
0005435068517	13168	Business	11300.00
0005435068721	13168	Business	11300.00
0005435068484	13168	Business	11300.00
0005435068694	13168	Business	11300.00
0005435068622	13168	Business	11300.00
0005435068461	13168	Business	11300.00
0005435925300	13168	Economy	3800.00
0005435068650	13168	Economy	3800.00
0005435068608	13168	Economy	3800.00
0005435068485	13168	Economy	3800.00
0005435068516	13168	Economy	3800.00
0005435068503	13168	Economy	3800.00
0005435068706	13168	Economy	4100.00
0005435925301	13168	Economy	4100.00
0005435068521	13168	Economy	4100.00
0005435068424	13168	Economy	4100.00
0005435068785	13168	Economy	3800.00
0005435068701	13168	Economy	3800.00
0005435925302	13168	Economy	3800.00
0005435068758	13168	Economy	3800.00
0005435068623	13168	Economy	3800.00
0005435068513	13168	Economy	3800.00
0005435068486	13168	Economy	3800.00
0005435068687	13168	Economy	3800.00
0005435068669	13168	Economy	3800.00
0005435068586	13168	Economy	3800.00
0005435068649	13168	Economy	3800.00
0005435925303	13168	Economy	3800.00
0005435068682	13168	Economy	3800.00
0005435068506	13168	Economy	3800.00
0005435925299	13168	Economy	3800.00
0005435925295	13168	Economy	3800.00
0005435068760	13168	Economy	3800.00
0005435068398	13168	Economy	3800.00
0005435068522	13168	Economy	3800.00
0005435068514	13168	Economy	3800.00
0005435068686	13168	Economy	3800.00
0005435068702	13168	Economy	3800.00
0005435068596	13168	Economy	3800.00
0005435068515	13168	Economy	3800.00
0005435068680	13168	Economy	3800.00
0005435925298	13168	Economy	3800.00
0005435068672	13168	Economy	3800.00
0005435068648	13168	Economy	3800.00
0005435068502	13168	Economy	3800.00
0005435068696	13168	Economy	3800.00
0005435068575	13168	Economy	3800.00
0005435068805	13168	Economy	3800.00
0005435068399	13168	Economy	3800.00
0005435925304	13168	Economy	3800.00
0005435068932	13168	Economy	3800.00
0005435068722	13168	Economy	3800.00
0005435068731	13168	Economy	3800.00
0005435068757	13168	Economy	3800.00
0005435068695	13168	Economy	3800.00
0005435068606	13168	Economy	3800.00
0005435068523	13168	Economy	3800.00
0005435068749	13168	Economy	3800.00
0005435068332	13168	Economy	3800.00
0005435068681	13168	Economy	3800.00
0005435068665	13168	Economy	3800.00
0005435068691	13168	Economy	3800.00
0005435925297	13168	Economy	3800.00
0005435068653	13168	Economy	3800.00
0005435068507	13168	Economy	3800.00
0005435068663	13168	Economy	3800.00
0005435068512	13168	Economy	3800.00
0005435068743	13168	Economy	3800.00
0005435068662	13168	Economy	3800.00
0005435068806	13168	Economy	3800.00
0005435925190	15461	Business	11300.00
0005435069099	15461	Business	11300.00
0005435069089	15461	Business	11300.00
0005435069107	15461	Business	11300.00
0005435069085	15461	Business	11300.00
0005435069104	15461	Business	11300.00
0005435069106	15461	Business	11300.00
0005435069068	15461	Business	11300.00
0005435069076	15461	Business	11300.00
0005435069082	15461	Economy	3800.00
0005435925138	15461	Economy	3800.00
0005435069110	15461	Economy	3800.00
0005435069084	15461	Economy	3800.00
0005435925128	15461	Economy	3800.00
0005435069075	15461	Economy	3800.00
0005435925137	15461	Economy	4100.00
0005435069080	15461	Economy	4100.00
0005435925191	15461	Economy	4100.00
0005435069087	15461	Economy	3800.00
0005435069109	15461	Economy	3800.00
0005435069090	15461	Economy	3800.00
0005435925160	15461	Economy	3800.00
0005435925185	15461	Economy	3800.00
0005435069092	15461	Economy	3800.00
0005435069102	15461	Economy	3800.00
0005435069101	15461	Economy	3800.00
0005435069062	15461	Economy	3800.00
0005435069098	15461	Economy	3800.00
0005435925184	15461	Economy	3800.00
0005435069067	15461	Economy	3800.00
0005435069060	15461	Economy	3800.00
0005435069088	15461	Economy	3800.00
0005435069105	15461	Economy	3800.00
0005435069094	15461	Economy	3800.00
0005435069070	15461	Economy	3800.00
0005435925171	15461	Economy	3800.00
0005435925167	15461	Economy	3800.00
0005435069072	15461	Economy	3800.00
0005435069079	15461	Economy	3800.00
0005435069083	15461	Economy	3800.00
0005435069063	15461	Economy	3800.00
0005435069074	15461	Economy	3800.00
0005435069078	15461	Economy	3800.00
0005435069096	15461	Economy	3800.00
0005435069065	15461	Economy	3800.00
0005435069077	15461	Economy	3800.00
0005435069061	15461	Economy	3800.00
0005435069073	15461	Economy	3800.00
0005435925135	15461	Economy	3800.00
0005435925131	15461	Economy	3800.00
0005435925133	15461	Economy	3800.00
0005435069103	15461	Economy	3800.00
0005435069071	15461	Economy	3800.00
0005435069066	15461	Economy	3800.00
0005435925186	15461	Economy	3800.00
0005435925187	15461	Economy	3800.00
0005435069069	15461	Economy	3800.00
0005435925132	15461	Economy	3800.00
0005435069064	15461	Economy	3800.00
0005435069086	15461	Economy	3800.00
0005435069100	15461	Economy	3800.00
0005435069108	15461	Economy	3800.00
0005435069097	15461	Economy	3800.00
0005435069093	15461	Economy	3800.00
0005435069111	15461	Economy	3800.00
0005435069081	15461	Economy	3800.00
0005435069059	15461	Economy	3800.00
0005435069091	15461	Economy	3800.00
0005435925168	15461	Economy	3800.00
0005435069095	15461	Economy	3800.00
0005433407572	29485	Economy	27100.00
0005435808117	29485	Economy	27100.00
0005435808161	29485	Economy	27100.00
0005433407574	29485	Economy	24700.00
0005433407571	29485	Economy	24700.00
0005435808111	29485	Economy	24700.00
0005435808123	29485	Economy	24700.00
0005435808118	29485	Economy	24700.00
0005433407565	29485	Economy	24700.00
0005435808087	29485	Economy	24700.00
0005435808131	29485	Economy	24700.00
0005435808088	29485	Economy	24700.00
0005435808138	29485	Economy	24700.00
0005435808169	29485	Economy	24700.00
0005433407568	29485	Economy	24700.00
0005435808114	29485	Economy	24700.00
0005435808122	29485	Economy	24700.00
0005433407570	29485	Economy	24700.00
0005433407566	29485	Economy	24700.00
0005435808097	29485	Economy	24700.00
0005433407569	29485	Economy	24700.00
0005435808119	29485	Economy	24700.00
0005435808102	29485	Economy	24700.00
0005433407567	29485	Economy	24700.00
0005435808099	29485	Economy	24700.00
0005435808137	29485	Economy	24700.00
0005435808126	29485	Economy	24700.00
0005435808139	29485	Economy	24700.00
0005435808100	29485	Economy	24700.00
0005435808132	29485	Economy	24700.00
0005435808085	29485	Economy	24700.00
0005433407573	29485	Economy	24700.00
0005435808113	29485	Economy	24700.00
0005434756170	10723	Business	61300.00
0005434214588	10723	Business	61300.00
0005434756128	10723	Business	61300.00
0005434214578	10723	Business	61300.00
0005434214596	10723	Business	61300.00
0005434214587	10723	Business	61300.00
0005434755993	10723	Business	61300.00
0005434214597	10723	Business	61300.00
0005434214568	10723	Business	61300.00
0005434214559	10723	Business	61300.00
0005434756054	10723	Business	61300.00
0005434756112	10723	Business	61300.00
0005434756111	10723	Economy	20400.00
0005434756057	10723	Economy	20400.00
0005434755913	10723	Economy	20400.00
0005434214577	10723	Economy	20400.00
0005434214589	10723	Economy	20400.00
0005434214557	10723	Economy	20400.00
0005434756168	10723	Economy	20400.00
0005434756109	10723	Economy	20400.00
0005434214573	10723	Economy	20400.00
0005434214565	10723	Economy	22500.00
0005434214558	10723	Economy	22500.00
0005434214593	10723	Economy	22500.00
0005434214575	10723	Economy	22500.00
0005434756158	10723	Economy	22500.00
0005434214561	10723	Economy	20400.00
0005434214591	10723	Economy	20400.00
0005434756025	10723	Economy	20400.00
0005434756038	10723	Economy	20400.00
0005434756211	10723	Economy	20400.00
0005434756103	10723	Economy	20400.00
0005434756136	10723	Economy	20400.00
0005434756068	10723	Economy	20400.00
0005434214570	10723	Economy	20400.00
0005434756110	10723	Economy	20400.00
0005434756039	10723	Economy	20400.00
0005434214574	10723	Economy	20400.00
0005434756053	10723	Economy	20400.00
0005434214571	10723	Economy	20400.00
0005434214567	10723	Economy	20400.00
0005434214601	10723	Economy	20400.00
0005434756227	10723	Economy	20400.00
0005434756106	10723	Economy	20400.00
0005434214585	10723	Economy	20400.00
0005434756056	10723	Economy	20400.00
0005434214572	10723	Economy	20400.00
0005434755835	10723	Economy	20400.00
0005434214560	10723	Economy	20400.00
0005434756129	10723	Economy	20400.00
0005434755916	10723	Economy	20400.00
0005434756003	10723	Economy	20400.00
0005434756010	10723	Economy	20400.00
0005434214566	10723	Economy	20400.00
0005434214569	10723	Economy	20400.00
0005434214583	10723	Economy	20400.00
0005434214564	10723	Economy	20400.00
0005434214599	10723	Economy	20400.00
0005434214576	10723	Economy	20400.00
0005434756146	10723	Economy	20400.00
0005434756174	10723	Economy	20400.00
0005434756087	10723	Economy	20400.00
0005434756164	10723	Economy	20400.00
0005434214592	10723	Economy	20400.00
0005434756097	10723	Economy	20400.00
0005434756009	10723	Economy	20400.00
0005434214584	10723	Economy	20400.00
0005434756163	10723	Economy	20400.00
0005434756264	10723	Economy	20400.00
0005434214562	10723	Economy	20400.00
0005434214579	10723	Economy	20400.00
0005434214582	10723	Economy	20400.00
0005434756055	10723	Economy	20400.00
0005434214594	10723	Economy	20400.00
0005434756185	10723	Economy	20400.00
0005434756026	10723	Economy	20400.00
0005434756159	10723	Economy	20400.00
0005434214581	10723	Economy	20400.00
0005434756007	10723	Economy	20400.00
0005434214598	10723	Economy	20400.00
0005434756184	10723	Economy	20400.00
0005434756047	10723	Economy	20400.00
0005434214595	10723	Economy	20400.00
0005434214600	10723	Economy	20400.00
0005434214580	10723	Economy	20400.00
0005434214586	10723	Economy	20400.00
0005434214563	10723	Economy	20400.00
0005434756067	10723	Economy	20400.00
0005434756024	10723	Economy	20400.00
0005434214590	10723	Economy	20400.00
0005434756134	10723	Economy	20400.00
0005434213876	28658	Business	61300.00
0005434756444	28658	Business	61300.00
0005434214051	28658	Business	61300.00
0005434214001	28658	Business	61300.00
0005434214011	28658	Business	61300.00
0005434756420	28658	Business	61300.00
0005434756409	28658	Business	61300.00
0005434213897	28658	Business	61300.00
0005434214259	28658	Business	61300.00
0005434756434	28658	Business	61300.00
0005434214156	28658	Business	61300.00
0005434213947	28658	Business	61300.00
0005434756413	28658	Economy	20400.00
0005434756422	28658	Economy	20400.00
0005434756424	28658	Economy	20400.00
0005434214202	28658	Economy	20400.00
0005434214083	28658	Economy	20400.00
0005434756418	28658	Economy	20400.00
0005434756438	28658	Economy	20400.00
0005434756430	28658	Economy	20400.00
0005434214264	28658	Economy	22500.00
0005434756429	28658	Economy	22500.00
0005434756425	28658	Economy	22500.00
0005434214287	28658	Economy	22500.00
0005434214173	28658	Economy	22500.00
0005434214158	28658	Economy	20400.00
0005434214157	28658	Economy	20400.00
0005434756427	28658	Economy	20400.00
0005434756410	28658	Economy	20400.00
0005434214073	28658	Economy	20400.00
0005434756431	28658	Economy	20400.00
0005434214133	28658	Economy	20400.00
0005434756412	28658	Economy	20400.00
0005434214050	28658	Economy	20400.00
0005434213960	28658	Economy	20400.00
0005434213911	28658	Economy	20400.00
0005434213980	28658	Economy	20400.00
0005434756445	28658	Economy	20400.00
0005434214052	28658	Economy	20400.00
0005434756419	28658	Economy	20400.00
0005434756417	28658	Economy	20400.00
0005434756440	28658	Economy	20400.00
0005434756432	28658	Economy	20400.00
0005434214092	28658	Economy	20400.00
0005434214093	28658	Economy	20400.00
0005434756408	28658	Economy	20400.00
0005434214162	28658	Economy	20400.00
0005434214131	28658	Economy	20400.00
0005434213835	28658	Economy	20400.00
0005434756426	28658	Economy	20400.00
0005434214226	28658	Economy	20400.00
0005434756433	28658	Economy	20400.00
0005434756439	28658	Economy	20400.00
0005434756416	28658	Economy	20400.00
0005434214178	28658	Economy	20400.00
0005434756428	28658	Economy	20400.00
0005434756441	28658	Economy	20400.00
0005434214062	28658	Economy	20400.00
0005434214002	28658	Economy	20400.00
0005434214139	28658	Economy	20400.00
0005434213850	28658	Economy	20400.00
0005434756443	28658	Economy	20400.00
0005434756421	28658	Economy	20400.00
0005434756414	28658	Economy	20400.00
0005434213849	28658	Economy	20400.00
0005434214203	28658	Economy	20400.00
0005434214161	28658	Economy	20400.00
0005434213938	28658	Economy	20400.00
0005434214038	28658	Economy	20400.00
0005434214132	28658	Economy	20400.00
0005434756411	28658	Economy	20400.00
0005434214275	28658	Economy	20400.00
0005434756415	28658	Economy	20400.00
0005434214110	28658	Economy	20400.00
0005434756423	28658	Economy	20400.00
0005434214060	28658	Economy	20400.00
0005434214229	28658	Economy	20400.00
0005434214039	28658	Economy	20400.00
0005434213946	28658	Economy	20400.00
0005434214172	28658	Economy	20400.00
0005434756437	28658	Economy	20400.00
0005434756435	28658	Economy	20400.00
0005434214078	28658	Economy	20400.00
0005434756436	28658	Economy	20400.00
0005434756442	28658	Economy	20400.00
0005435007046	5439	Business	29500.00
0005435039806	5439	Business	29500.00
0005435039853	5439	Business	29500.00
0005432125455	5439	Business	29500.00
0005434229228	5439	Business	29500.00
0005435039850	5439	Business	29500.00
0005435039833	5439	Business	29500.00
0005435039801	5439	Business	29500.00
0005432125457	5439	Business	29500.00
0005435007049	5439	Business	29500.00
0005435039823	5439	Business	29500.00
0005435039828	5439	Business	29500.00
0005434229265	5439	Economy	9800.00
0005435007055	5439	Economy	9800.00
0005435039815	5439	Economy	9800.00
0005435039865	5439	Economy	9800.00
0005435039836	5439	Economy	9800.00
0005435039855	5439	Economy	9800.00
0005435039822	5439	Economy	9800.00
0005435039837	5439	Economy	9800.00
0005435039861	5439	Economy	9800.00
0005435039821	5439	Economy	9800.00
0005435039825	5439	Economy	9800.00
0005432125460	5439	Economy	9800.00
0005435007057	5439	Economy	9800.00
0005434229164	5439	Economy	9800.00
0005434229133	5439	Economy	9800.00
0005434229258	5439	Economy	9800.00
0005435007062	5439	Economy	9800.00
0005435007070	5439	Economy	9800.00
0005435039829	5439	Economy	9800.00
0005435039800	5439	Economy	9800.00
0005435007050	5439	Economy	9800.00
0005435039844	5439	Economy	9800.00
0005435039824	5439	Economy	9800.00
0005435039858	5439	Economy	9800.00
0005434229175	5439	Economy	9800.00
0005434229177	5439	Economy	9800.00
0005435007058	5439	Economy	9800.00
0005435039842	5439	Economy	9800.00
0005435039805	5439	Economy	9800.00
0005435007053	5439	Economy	9800.00
0005435039846	5439	Economy	9800.00
0005435007044	5439	Economy	9800.00
0005435039820	5439	Economy	9800.00
0005435039818	5439	Economy	9800.00
0005434229227	5439	Economy	9800.00
0005435039827	5439	Economy	9800.00
0005435039814	5439	Economy	9800.00
0005435039816	5439	Economy	9800.00
0005434229154	5439	Economy	10800.00
0005435039856	5439	Economy	10800.00
0005435039804	5439	Economy	10800.00
0005432125462	5439	Economy	10800.00
0005435007052	5439	Economy	10800.00
0005435039808	5439	Economy	9800.00
0005435007066	5439	Economy	9800.00
0005435039813	5439	Economy	9800.00
0005435039834	5439	Economy	9800.00
0005435007060	5439	Economy	9800.00
0005432125459	5439	Economy	9800.00
0005435039864	5439	Economy	9800.00
0005434229124	5439	Economy	9800.00
0005435007065	5439	Economy	9800.00
0005434229251	5439	Economy	9800.00
0005435039826	5439	Economy	9800.00
0005435039812	5439	Economy	9800.00
0005435039862	5439	Economy	9800.00
0005434229211	5439	Economy	9800.00
0005434229168	5439	Economy	9800.00
0005435039807	5439	Economy	9800.00
0005435039854	5439	Economy	9800.00
0005435007069	5439	Economy	9800.00
0005432125461	5439	Economy	9800.00
0005432125456	5439	Economy	9800.00
0005435039803	5439	Economy	9800.00
0005435039832	5439	Economy	9800.00
0005435039848	5439	Economy	9800.00
0005435007054	5439	Economy	9800.00
0005435007064	5439	Economy	9800.00
0005434229214	5439	Economy	9800.00
0005435039852	5439	Economy	9800.00
0005434229246	5439	Economy	9800.00
0005435039851	5439	Economy	9800.00
0005435007067	5439	Economy	9800.00
0005435007063	5439	Economy	9800.00
0005435039838	5439	Economy	9800.00
0005435039835	5439	Economy	9800.00
0005434229126	5439	Economy	9800.00
0005435039860	5439	Economy	9800.00
0005435039845	5439	Economy	9800.00
0005434229134	5439	Economy	9800.00
0005435007068	5439	Economy	9800.00
0005434229163	5439	Economy	9800.00
0005434229158	5439	Economy	9800.00
0005435039839	5439	Economy	9800.00
0005435039817	5439	Economy	9800.00
0005435039843	5439	Economy	9800.00
0005435007061	5439	Economy	9800.00
0005435039809	5439	Economy	9800.00
0005434229244	5439	Economy	9800.00
0005434229194	5439	Economy	9800.00
0005435039802	5439	Economy	9800.00
0005435039857	5439	Economy	9800.00
0005435039830	5439	Economy	9800.00
0005435007056	5439	Economy	9800.00
0005435039847	5439	Economy	9800.00
0005434229245	5439	Economy	9800.00
0005432125458	5439	Economy	9800.00
0005435007045	5439	Economy	9800.00
0005435007059	5439	Economy	9800.00
0005435039840	5439	Economy	9800.00
0005435039811	5439	Economy	9800.00
0005435039841	5439	Economy	9800.00
0005435007048	5439	Economy	9800.00
0005435039819	5439	Economy	9800.00
0005434229176	5439	Economy	9800.00
0005435039866	5439	Economy	9800.00
0005435007051	5439	Economy	9800.00
0005435039849	5439	Economy	9800.00
0005435039859	5439	Economy	9800.00
0005435039831	5439	Economy	9800.00
0005435007047	5439	Economy	9800.00
0005434229252	5439	Economy	9800.00
0005435039810	5439	Economy	9800.00
0005435039863	5439	Economy	9800.00
0005435006854	13002	Business	29500.00
0005435039199	13002	Business	29500.00
0005435006837	13002	Business	29500.00
0005435006857	13002	Business	29500.00
0005435039452	13002	Business	29500.00
0005435039200	13002	Business	29500.00
0005435006856	13002	Business	29500.00
0005434229388	13002	Business	29500.00
0005435039564	13002	Business	29500.00
0005435039395	13002	Business	29500.00
0005434229400	13002	Business	29500.00
0005435039183	13002	Business	29500.00
0005435039391	13002	Economy	9800.00
0005435039220	13002	Economy	9800.00
0005435039283	13002	Economy	9800.00
0005435006795	13002	Economy	9800.00
0005435006880	13002	Economy	9800.00
0005432304402	13002	Economy	9800.00
0005435039259	13002	Economy	9800.00
0005435039255	13002	Economy	9800.00
0005434229387	13002	Economy	9800.00
0005435006755	13002	Economy	9800.00
0005434229389	13002	Economy	9800.00
0005435039375	13002	Economy	9800.00
0005434229383	13002	Economy	9800.00
0005435006822	13002	Economy	9800.00
0005435039420	13002	Economy	9800.00
0005435039421	13002	Economy	9800.00
0005435039249	13002	Economy	9800.00
0005435039388	13002	Economy	9800.00
0005435039233	13002	Economy	9800.00
0005435039307	13002	Economy	9800.00
0005435006851	13002	Economy	9800.00
0005435006796	13002	Economy	9800.00
0005435039264	13002	Economy	9800.00
0005435039232	13002	Economy	9800.00
0005435042832	13002	Economy	9800.00
0005435006849	13002	Economy	9800.00
0005434229401	13002	Economy	9800.00
0005434229384	13002	Economy	9800.00
0005435039445	13002	Economy	9800.00
0005435006775	13002	Economy	9800.00
0005435039093	13002	Economy	9800.00
0005435039145	13002	Economy	9800.00
0005435006850	13002	Economy	9800.00
0005435039234	13002	Economy	9800.00
0005435039103	13002	Economy	9800.00
0005435039219	13002	Economy	9800.00
0005435006826	13002	Economy	9800.00
0005435039426	13002	Economy	9800.00
0005435039453	13002	Economy	9800.00
0005434229403	13002	Economy	10800.00
0005435039313	13002	Economy	10800.00
0005435006808	13002	Economy	10800.00
0005434229397	13002	Economy	10800.00
0005435039196	13002	Economy	10800.00
0005435039176	13002	Economy	10800.00
0005435039319	13002	Economy	9800.00
0005435039246	13002	Economy	9800.00
0005435039312	13002	Economy	9800.00
0005435043279	13002	Economy	9800.00
0005434229390	13002	Economy	9800.00
0005435039449	13002	Economy	9800.00
0005435006836	13002	Economy	9800.00
0005434229396	13002	Economy	9800.00
0005435039212	13002	Economy	9800.00
0005435039092	13002	Economy	9800.00
0005435038962	13002	Economy	9800.00
0005435039643	13002	Economy	9800.00
0005435039461	13002	Economy	9800.00
0005435039320	13002	Economy	9800.00
0005435039390	13002	Economy	9800.00
0005434229391	13002	Economy	9800.00
0005435039041	13002	Economy	9800.00
0005435006948	13002	Economy	9800.00
0005435039397	13002	Economy	9800.00
0005432304400	13002	Economy	9800.00
0005435039394	13002	Economy	9800.00
0005435039251	13002	Economy	9800.00
0005435039322	13002	Economy	9800.00
0005435039252	13002	Economy	9800.00
0005435006855	13002	Economy	9800.00
0005434229392	13002	Economy	9800.00
0005435039001	13002	Economy	9800.00
0005435039102	13002	Economy	9800.00
0005435039032	13002	Economy	9800.00
0005435039250	13002	Economy	9800.00
0005435039460	13002	Economy	9800.00
0005435043280	13002	Economy	9800.00
0005435039451	13002	Economy	9800.00
0005435042831	13002	Economy	9800.00
0005432304401	13002	Economy	9800.00
0005435039169	13002	Economy	9800.00
0005435039321	13002	Economy	9800.00
0005434229399	13002	Economy	9800.00
0005434229393	13002	Economy	9800.00
0005435039334	13002	Economy	9800.00
0005435039310	13002	Economy	9800.00
0005435039172	13002	Economy	9800.00
0005434229398	13002	Economy	9800.00
0005435039195	13002	Economy	9800.00
0005435039387	13002	Economy	9800.00
0005435039308	13002	Economy	9800.00
0005435006867	13002	Economy	9800.00
0005435039205	13002	Economy	9800.00
0005435006777	13002	Economy	9800.00
0005434229394	13002	Economy	9800.00
0005434229395	13002	Economy	9800.00
0005435039282	13002	Economy	9800.00
0005434229405	13002	Economy	9800.00
0005434229402	13002	Economy	9800.00
0005435039427	13002	Economy	9800.00
0005435006778	13002	Economy	9800.00
0005435039448	13002	Economy	9800.00
0005434229385	13002	Economy	9800.00
0005435039386	13002	Economy	9800.00
0005435006809	13002	Economy	9800.00
0005435039309	13002	Economy	9800.00
0005435039335	13002	Economy	9800.00
0005434229386	13002	Economy	9800.00
0005434229404	13002	Economy	9800.00
0005435006949	13002	Economy	9800.00
0005435006768	13002	Economy	9800.00
0005435039091	13002	Economy	9800.00
0005435039555	13002	Economy	9800.00
0005435039351	13002	Economy	9800.00
0005432304403	13002	Economy	9800.00
0005435039258	13002	Economy	9800.00
0005435006767	13002	Economy	9800.00
0005434426598	14896	Business	52900.00
0005434426604	14896	Business	52900.00
0005434426610	14896	Business	52900.00
0005434426611	14896	Business	52900.00
0005434426607	14896	Business	52900.00
0005434411777	14896	Business	52900.00
0005432188607	14896	Business	52900.00
0005434426612	14896	Business	52900.00
0005434426613	14896	Business	52900.00
0005434426623	14896	Economy	17600.00
0005434426600	14896	Economy	17600.00
0005435902603	14896	Economy	17600.00
0005434426603	14896	Economy	17600.00
0005434411776	14896	Economy	17600.00
0005434426625	14896	Economy	17600.00
0005435902473	14896	Economy	19400.00
0005434426602	14896	Economy	19400.00
0005435902583	14896	Economy	17600.00
0005435902610	14896	Economy	17600.00
0005434426605	14896	Economy	17600.00
0005435902609	14896	Economy	17600.00
0005434426606	14896	Economy	17600.00
0005434426619	14896	Economy	17600.00
0005434426599	14896	Economy	17600.00
0005434426626	14896	Economy	17600.00
0005434426622	14896	Economy	17600.00
0005434426618	14896	Economy	17600.00
0005435902529	14896	Economy	17600.00
0005434426608	14896	Economy	17600.00
0005435902589	14896	Economy	17600.00
0005432188609	14896	Economy	17600.00
0005435902614	14896	Economy	17600.00
0005432188608	14896	Economy	17600.00
0005434426624	14896	Economy	17600.00
0005434411778	14896	Economy	17600.00
0005435902604	14896	Economy	17600.00
0005434426621	14896	Economy	17600.00
0005432188606	14896	Economy	17600.00
0005432188610	14896	Economy	17600.00
0005434426601	14896	Economy	17600.00
0005434426617	14896	Economy	17600.00
0005434426620	14896	Economy	17600.00
0005434426609	14896	Economy	17600.00
0005434426615	14896	Economy	17600.00
0005435902579	14896	Economy	17600.00
0005435902537	14896	Economy	17600.00
0005434411780	14896	Economy	17600.00
0005434426614	14896	Economy	17600.00
0005434426616	14896	Economy	17600.00
0005434411779	14896	Economy	17600.00
0005434411738	20230	Business	52900.00
0005435554196	20230	Business	52900.00
0005435554194	20230	Business	52900.00
0005434426243	20230	Business	52900.00
0005434426441	20230	Business	52900.00
0005435902725	20230	Business	52900.00
0005435902722	20230	Business	52900.00
0005434426429	20230	Business	52900.00
0005432059507	20230	Economy	17600.00
0005435902720	20230	Economy	17600.00
0005434426461	20230	Economy	17600.00
0005434426319	20230	Economy	17600.00
0005434426465	20230	Economy	17600.00
0005434426356	20230	Economy	19400.00
0005435902717	20230	Economy	19400.00
0005435902716	20230	Economy	19400.00
0005435902726	20230	Economy	17600.00
0005435902714	20230	Economy	17600.00
0005434426442	20230	Economy	17600.00
0005434426289	20230	Economy	17600.00
0005434426335	20230	Economy	17600.00
0005434426443	20230	Economy	17600.00
0005435902729	20230	Economy	17600.00
0005435902715	20230	Economy	17600.00
0005435902727	20230	Economy	17600.00
0005434426396	20230	Economy	17600.00
0005435902718	20230	Economy	17600.00
0005434411732	20230	Economy	17600.00
0005434426431	20230	Economy	17600.00
0005434411756	20230	Economy	17600.00
0005435902712	20230	Economy	17600.00
0005434411733	20230	Economy	17600.00
0005434426439	20230	Economy	17600.00
0005435554197	20230	Economy	17600.00
0005434426397	20230	Economy	17600.00
0005434426212	20230	Economy	17600.00
0005434426503	20230	Economy	17600.00
0005435902719	20230	Economy	17600.00
0005434426407	20230	Economy	17600.00
0005435554195	20230	Economy	17600.00
0005434426385	20230	Economy	17600.00
0005435554193	20230	Economy	17600.00
0005434426501	20230	Economy	17600.00
0005434426360	20230	Economy	17600.00
0005434426409	20230	Economy	17600.00
0005434426413	20230	Economy	17600.00
0005434426337	20230	Economy	17600.00
0005434426369	20230	Economy	17600.00
0005435902713	20230	Economy	17600.00
0005435902724	20230	Economy	17600.00
0005434426244	20230	Economy	17600.00
0005432059506	20230	Economy	17600.00
0005434426357	20230	Economy	17600.00
0005434426457	20230	Economy	17600.00
0005434411726	20230	Economy	17600.00
0005434426211	20230	Economy	17600.00
0005432059508	20230	Economy	17600.00
0005434426446	20230	Economy	17600.00
0005434426215	20230	Economy	17600.00
0005434426430	20230	Economy	17600.00
0005434426447	20230	Economy	17600.00
0005435902721	20230	Economy	17600.00
0005434426379	20230	Economy	17600.00
0005435902728	20230	Economy	17600.00
0005435902723	20230	Economy	17600.00
0005434411755	20230	Economy	17600.00
0005434426336	20230	Economy	17600.00
0005434426445	20230	Economy	17600.00
0005435554192	20230	Economy	17600.00
0005434426242	20230	Economy	17600.00
0005432300263	26550	Business	18500.00
0005435982306	26550	Business	18500.00
0005433434382	26550	Business	18500.00
0005435982332	26550	Business	18500.00
0005433434504	26550	Business	18500.00
0005433434505	26550	Business	18500.00
0005434270189	26550	Business	18500.00
0005432300267	26550	Business	18500.00
0005435982304	26550	Business	18500.00
0005435982297	26550	Business	18500.00
0005435982315	26550	Economy	6200.00
0005435982313	26550	Economy	6200.00
0005435982294	26550	Economy	6200.00
0005435982321	26550	Economy	6200.00
0005435982324	26550	Economy	6200.00
0005435982295	26550	Economy	6200.00
0005432300268	26550	Economy	6200.00
0005433434383	26550	Economy	6200.00
0005433434579	26550	Economy	6800.00
0005435982311	26550	Economy	6800.00
0005435982309	26550	Economy	6800.00
0005435982317	26550	Economy	6800.00
0005435982320	26550	Economy	6800.00
0005433434360	26550	Economy	6200.00
0005433434404	26550	Economy	6200.00
0005432300264	26550	Economy	6200.00
0005435982300	26550	Economy	6200.00
0005435982298	26550	Economy	6200.00
0005435982299	26550	Economy	6200.00
0005435982312	26550	Economy	6200.00
0005435982329	26550	Economy	6200.00
0005433434455	26550	Economy	6200.00
0005435982302	26550	Economy	6200.00
0005435982326	26550	Economy	6200.00
0005435982318	26550	Economy	6200.00
0005433434411	26550	Economy	6200.00
0005433434538	26550	Economy	6200.00
0005435982337	26550	Economy	6200.00
0005435982296	26550	Economy	6200.00
0005433434481	26550	Economy	6200.00
0005435982325	26550	Economy	6200.00
0005435982314	26550	Economy	6200.00
0005435982310	26550	Economy	6200.00
0005435982330	26550	Economy	6200.00
0005435982340	26550	Economy	6200.00
0005435982341	26550	Economy	6200.00
0005435982342	26550	Economy	6200.00
0005435982323	26550	Economy	6200.00
0005435982292	26550	Economy	6200.00
0005433434441	26550	Economy	6200.00
0005435982333	26550	Economy	6200.00
0005435982327	26550	Economy	6200.00
0005435982335	26550	Economy	6200.00
0005433434429	26550	Economy	6200.00
0005433434326	26550	Economy	6200.00
0005433434551	26550	Economy	6200.00
0005435982331	26550	Economy	6200.00
0005433434539	26550	Economy	6200.00
0005435982334	26550	Economy	6200.00
0005435982339	26550	Economy	6200.00
0005435982322	26550	Economy	6200.00
0005433434511	26550	Economy	6200.00
0005435982301	26550	Economy	6200.00
0005435982308	26550	Economy	6200.00
0005435982305	26550	Economy	6200.00
0005435982338	26550	Economy	6200.00
0005433434325	26550	Economy	6200.00
0005435982336	26550	Economy	6200.00
0005435982307	26550	Economy	6200.00
0005435982303	26550	Economy	6200.00
0005435982293	26550	Economy	6200.00
0005432300266	26550	Economy	6200.00
0005435982328	26550	Economy	6200.00
0005435982319	26550	Economy	6200.00
0005435982316	26550	Economy	6200.00
0005432300265	26550	Economy	6200.00
0005433434465	26550	Economy	6200.00
0005433434410	26550	Economy	6200.00
0005433434436	26550	Economy	6200.00
0005433434428	26550	Economy	6200.00
0005432051130	26688	Business	18500.00
0005435981834	26688	Business	18500.00
0005433434701	26688	Business	18500.00
0005435981808	26688	Business	18500.00
0005434270208	26688	Business	18500.00
0005435981807	26688	Business	18500.00
0005433434715	26688	Business	18500.00
0005433434705	26688	Business	18500.00
0005435981645	26688	Business	18500.00
0005435981955	26688	Business	18500.00
0005432051132	26688	Business	18500.00
0005435981998	26688	Business	18500.00
0005433434722	26688	Economy	6200.00
0005435981895	26688	Economy	6200.00
0005433434708	26688	Economy	6200.00
0005433434710	26688	Economy	6200.00
0005435982028	26688	Economy	6200.00
0005435981838	26688	Economy	6200.00
0005435981806	26688	Economy	6200.00
0005435981655	26688	Economy	6200.00
0005433434699	26688	Economy	6200.00
0005433434719	26688	Economy	6200.00
0005434271313	26688	Economy	6800.00
0005433434704	26688	Economy	6800.00
0005435981932	26688	Economy	6800.00
0005434269106	26688	Economy	6800.00
0005435981984	26688	Economy	6800.00
0005435981908	26688	Economy	6200.00
0005435981960	26688	Economy	6200.00
0005435981854	26688	Economy	6200.00
0005435981853	26688	Economy	6200.00
0005435981759	26688	Economy	6200.00
0005435981762	26688	Economy	6200.00
0005435981922	26688	Economy	6200.00
0005433434712	26688	Economy	6200.00
0005435981921	26688	Economy	6200.00
0005433434717	26688	Economy	6200.00
0005435982014	26688	Economy	6200.00
0005435982006	26688	Economy	6200.00
0005435981815	26688	Economy	6200.00
0005435981646	26688	Economy	6200.00
0005433434709	26688	Economy	6200.00
0005433434714	26688	Economy	6200.00
0005433434707	26688	Economy	6200.00
0005435981956	26688	Economy	6200.00
0005435981931	26688	Economy	6200.00
0005435981763	26688	Economy	6200.00
0005435981999	26688	Economy	6200.00
0005433434725	26688	Economy	6200.00
0005434271315	26688	Economy	6200.00
0005435981965	26688	Economy	6200.00
0005433434726	26688	Economy	6200.00
0005432051131	26688	Economy	6200.00
0005435982019	26688	Economy	6200.00
0005435981855	26688	Economy	6200.00
0005435982015	26688	Economy	6200.00
0005435982005	26688	Economy	6200.00
0005435982000	26688	Economy	6200.00
0005434269105	26688	Economy	6200.00
0005435981739	26688	Economy	6200.00
0005433434716	26688	Economy	6200.00
0005434270209	26688	Economy	6200.00
0005433434703	26688	Economy	6200.00
0005435981846	26688	Economy	6200.00
0005435981961	26688	Economy	6200.00
0005433434713	26688	Economy	6200.00
0005435982016	26688	Economy	6200.00
0005435981800	26688	Economy	6200.00
0005433434711	26688	Economy	6200.00
0005433434723	26688	Economy	6200.00
0005435981952	26688	Economy	6200.00
0005435982004	26688	Economy	6200.00
0005435981995	26688	Economy	6200.00
0005433434702	26688	Economy	6200.00
0005433434706	26688	Economy	6200.00
0005435981738	26688	Economy	6200.00
0005435981920	26688	Economy	6200.00
0005435981878	26688	Economy	6200.00
0005433434724	26688	Economy	6200.00
0005435982009	26688	Economy	6200.00
0005435981933	26688	Economy	6200.00
0005433434718	26688	Economy	6200.00
0005435981936	26688	Economy	6200.00
0005435982008	26688	Economy	6200.00
0005433434700	26688	Economy	6200.00
0005435981758	26688	Economy	6200.00
0005435981930	26688	Economy	6200.00
0005433434698	26688	Economy	6200.00
0005433434720	26688	Economy	6200.00
0005435981835	26688	Economy	6200.00
0005433434721	26688	Economy	6200.00
0005435981873	26688	Economy	6200.00
0005435981934	26688	Economy	6200.00
0005435981856	26688	Economy	6200.00
0005434271314	26688	Economy	6200.00
0005432857925	3184	Economy	11100.00
0005432584050	3184	Economy	11100.00
0005432857931	3184	Economy	11100.00
0005432857903	3184	Economy	11100.00
0005432584067	3184	Economy	10100.00
0005432584061	3184	Economy	10100.00
0005432584059	3184	Economy	10100.00
0005432584071	3184	Economy	10100.00
0005432584053	3184	Economy	10100.00
0005432584048	3184	Economy	10100.00
0005432584055	3184	Economy	10100.00
0005432584052	3184	Economy	10100.00
0005432584062	3184	Economy	10100.00
0005432584066	3184	Economy	10100.00
0005432584063	3184	Economy	10100.00
0005432584051	3184	Economy	10100.00
0005432584064	3184	Economy	10100.00
0005432216275	3184	Economy	10100.00
0005432584046	3184	Economy	10100.00
0005432857994	3184	Economy	10100.00
0005432216274	3184	Economy	10100.00
0005432857951	3184	Economy	10100.00
0005432584056	3184	Economy	10100.00
0005432584065	3184	Economy	10100.00
0005432857988	3184	Economy	10100.00
0005432857993	3184	Economy	10100.00
0005432584070	3184	Economy	10100.00
0005432584069	3184	Economy	10100.00
0005432584068	3184	Economy	10100.00
0005432584060	3184	Economy	10100.00
0005432584047	3184	Economy	10100.00
0005432584058	3184	Economy	10100.00
0005432857989	3184	Economy	10100.00
0005432857995	3184	Economy	10100.00
0005432584054	3184	Economy	10100.00
0005432858016	3184	Economy	10100.00
0005432584057	3184	Economy	10100.00
0005432584049	3184	Economy	10100.00
0005432583943	31482	Economy	11100.00
0005432858083	31482	Economy	11100.00
0005432583810	31482	Economy	10100.00
0005432583842	31482	Economy	10100.00
0005432583779	31482	Economy	10100.00
0005432583855	31482	Economy	10100.00
0005432858080	31482	Economy	10100.00
0005432583876	31482	Economy	10100.00
0005432583799	31482	Economy	10100.00
0005432583853	31482	Economy	10100.00
0005432583763	31482	Economy	10100.00
0005432583798	31482	Economy	10100.00
0005432858082	31482	Economy	10100.00
0005432858073	31482	Economy	10100.00
0005432583926	31482	Economy	10100.00
0005432858077	31482	Economy	10100.00
0005432583913	31482	Economy	10100.00
0005432583828	31482	Economy	10100.00
0005432583801	31482	Economy	10100.00
0005432583940	31482	Economy	10100.00
0005432583769	31482	Economy	10100.00
0005432583856	31482	Economy	10100.00
0005432583813	31482	Economy	10100.00
0005432583928	31482	Economy	10100.00
0005432583954	31482	Economy	10100.00
0005432583800	31482	Economy	10100.00
0005432858076	31482	Economy	10100.00
0005432858081	31482	Economy	10100.00
0005432858075	31482	Economy	10100.00
0005432583915	31482	Economy	10100.00
0005432858084	31482	Economy	10100.00
0005432583766	31482	Economy	10100.00
0005432858074	31482	Economy	10100.00
0005432583778	31482	Economy	10100.00
0005432583939	31482	Economy	10100.00
0005432858078	31482	Economy	10100.00
0005432583729	31482	Economy	10100.00
0005432583955	31482	Economy	10100.00
0005432583927	31482	Economy	10100.00
0005432583829	31482	Economy	10100.00
0005432583901	31482	Economy	10100.00
0005432583866	31482	Economy	10100.00
0005432583854	31482	Economy	10100.00
0005432583824	31482	Economy	10100.00
0005432583893	31482	Economy	10100.00
0005432858079	31482	Economy	10100.00
0005434943356	885	Economy	8300.00
0005433255086	885	Economy	8300.00
0005434943364	885	Economy	7500.00
0005434943360	885	Economy	7500.00
0005433255091	885	Economy	7500.00
0005434943358	885	Economy	7500.00
0005434943361	885	Economy	7500.00
0005433255085	885	Economy	7500.00
0005434943359	885	Economy	7500.00
0005434943362	885	Economy	7500.00
0005434943363	885	Economy	7500.00
0005434943357	885	Economy	7500.00
0005433255092	885	Economy	7500.00
0005433255090	885	Economy	7500.00
0005433255122	16209	Economy	8300.00
0005434943275	16209	Economy	8300.00
0005434943294	16209	Economy	7500.00
0005434943289	16209	Economy	7500.00
0005434943324	16209	Economy	7500.00
0005434943311	16209	Economy	7500.00
0005434943296	16209	Economy	7500.00
0005434943295	16209	Economy	7500.00
0005434943283	16209	Economy	7500.00
0005433255125	16209	Economy	7500.00
0005434943277	16209	Economy	7500.00
0005434943274	16209	Economy	7500.00
0005434943278	16209	Economy	7500.00
0005433255123	16209	Economy	7500.00
0005433255126	16209	Economy	7500.00
0005433255124	16209	Economy	7500.00
0005433654789	4324	Business	90500.00
0005433654786	4324	Business	90500.00
0005435858501	4324	Business	90500.00
0005433654760	4324	Business	90500.00
0005433654772	4324	Business	90500.00
0005433654774	4324	Business	90500.00
0005435858542	4324	Economy	30200.00
0005435858500	4324	Economy	30200.00
0005433654782	4324	Economy	30200.00
0005435858524	4324	Economy	30200.00
0005433654767	4324	Economy	30200.00
0005433654781	4324	Economy	30200.00
0005433654768	4324	Economy	30200.00
0005433654766	4324	Economy	30200.00
0005433654770	4324	Economy	33200.00
0005435858522	4324	Economy	30200.00
0005435858517	4324	Economy	30200.00
0005435858534	4324	Economy	30200.00
0005433654762	4324	Economy	30200.00
0005433654777	4324	Economy	30200.00
0005433654771	4324	Economy	30200.00
0005433654761	4324	Economy	30200.00
0005435858541	4324	Economy	30200.00
0005435858523	4324	Economy	30200.00
0005433654769	4324	Economy	30200.00
0005435858510	4324	Economy	30200.00
0005433654779	4324	Economy	30200.00
0005433654785	4324	Economy	30200.00
0005433654783	4324	Economy	30200.00
0005435858507	4324	Economy	30200.00
0005433654773	4324	Economy	30200.00
0005433654788	4324	Economy	30200.00
0005433654775	4324	Economy	30200.00
0005433654765	4324	Economy	30200.00
0005433654787	4324	Economy	30200.00
0005435858486	4324	Economy	30200.00
0005433654776	4324	Economy	30200.00
0005433654763	4324	Economy	30200.00
0005433654780	4324	Economy	30200.00
0005433654784	4324	Economy	30200.00
0005435858526	4324	Economy	30200.00
0005435858521	4324	Economy	30200.00
0005433654764	4324	Economy	30200.00
0005435858493	4324	Economy	30200.00
0005435858503	4324	Economy	30200.00
0005435858502	4324	Economy	30200.00
0005435858508	4324	Economy	30200.00
0005433654778	4324	Economy	30200.00
0005433811618	14392	Economy	4400.00
0005433811616	14392	Economy	4400.00
0005433811620	14392	Economy	4400.00
0005433811619	14392	Economy	4400.00
0005435653043	21754	Business	9800.00
0005435653051	21754	Business	9800.00
0005435653048	21754	Business	9800.00
0005435653052	21754	Business	9800.00
0005435653060	21754	Business	9800.00
0005433367625	21754	Business	9800.00
0005433367526	21754	Business	9800.00
0005433367626	21754	Business	9800.00
0005435653081	21754	Business	9800.00
0005435653078	21754	Business	9800.00
0005435653070	21754	Business	9800.00
0005435653056	21754	Economy	3300.00
0005435653061	21754	Economy	3300.00
0005435653063	21754	Economy	3300.00
0005435653076	21754	Economy	3300.00
0005435653041	21754	Economy	3300.00
0005435653044	21754	Economy	3300.00
0005435653049	21754	Economy	3300.00
0005433367581	21754	Economy	3300.00
0005433367630	21754	Economy	3300.00
0005433367567	21754	Economy	3300.00
0005435653083	21754	Economy	3600.00
0005435653055	21754	Economy	3600.00
0005435653054	21754	Economy	3600.00
0005435653082	21754	Economy	3600.00
0005433367629	21754	Economy	3300.00
0005433367582	21754	Economy	3300.00
0005435653050	21754	Economy	3300.00
0005435653086	21754	Economy	3300.00
0005435653068	21754	Economy	3300.00
0005433367513	21754	Economy	3300.00
0005435653046	21754	Economy	3300.00
0005435653091	21754	Economy	3300.00
0005433367422	21754	Economy	3300.00
0005433367622	21754	Economy	3300.00
0005435653045	21754	Economy	3300.00
0005435653062	21754	Economy	3300.00
0005433367517	21754	Economy	3300.00
0005435653093	21754	Economy	3300.00
0005435653067	21754	Economy	3300.00
0005433367737	21754	Economy	3300.00
0005435653059	21754	Economy	3300.00
0005433367447	21754	Economy	3300.00
0005435653071	21754	Economy	3300.00
0005435653084	21754	Economy	3300.00
0005435653089	21754	Economy	3300.00
0005435653064	21754	Economy	3300.00
0005433367583	21754	Economy	3300.00
0005435653066	21754	Economy	3300.00
0005435653087	21754	Economy	3300.00
0005435653073	21754	Economy	3300.00
0005433367569	21754	Economy	3300.00
0005433367577	21754	Economy	3300.00
0005435653077	21754	Economy	3300.00
0005435653069	21754	Economy	3300.00
0005435653047	21754	Economy	3300.00
0005433367477	21754	Economy	3300.00
0005435653080	21754	Economy	3300.00
0005433367828	21754	Economy	3300.00
0005433367631	21754	Economy	3300.00
0005433367638	21754	Economy	3300.00
0005433367778	21754	Economy	3300.00
0005435653088	21754	Economy	3300.00
0005433367578	21754	Economy	3300.00
0005433367829	21754	Economy	3300.00
0005435653053	21754	Economy	3300.00
0005435653057	21754	Economy	3300.00
0005433367566	21754	Economy	3300.00
0005435653065	21754	Economy	3300.00
0005433367632	21754	Economy	3300.00
0005433367580	21754	Economy	3300.00
0005433367777	21754	Economy	3300.00
0005435653085	21754	Economy	3300.00
0005435653058	21754	Economy	3300.00
0005433367399	21754	Economy	3300.00
0005435653042	21754	Economy	3300.00
0005435653074	21754	Economy	3300.00
0005435653079	21754	Economy	3300.00
0005435653075	21754	Economy	3300.00
0005433367564	21754	Economy	3300.00
0005435653072	21754	Economy	3300.00
0005433367514	21754	Economy	3300.00
0005433367469	21754	Economy	3300.00
0005433367736	21754	Economy	3300.00
0005435653090	21754	Economy	3300.00
0005435653092	21754	Economy	3300.00
0005433784992	9382	Business	186200.00
0005433805400	9382	Business	186200.00
0005433805409	9382	Business	186200.00
0005433805421	9382	Business	186200.00
0005433763225	9382	Business	186200.00
0005434170967	9382	Business	186200.00
0005433784985	9382	Business	186200.00
0005433784983	9382	Business	186200.00
0005433784993	9382	Business	186200.00
0005433763224	9382	Business	186200.00
0005433805422	9382	Business	186200.00
0005433763218	9382	Business	186200.00
0005433784974	9382	Business	186200.00
0005434170971	9382	Business	186200.00
0005433784989	9382	Business	186200.00
0005433784966	9382	Business	186200.00
0005433805433	9382	Economy	68300.00
0005433784975	9382	Economy	68300.00
0005433763219	9382	Economy	68300.00
0005433784976	9382	Economy	62100.00
0005434273059	9382	Economy	62100.00
0005433805417	9382	Economy	62100.00
0005434151685	9382	Economy	62100.00
0005433784965	9382	Economy	62100.00
0005433784996	9382	Economy	62100.00
0005433805424	9382	Economy	62100.00
0005433805429	9382	Economy	62100.00
0005432666391	9382	Economy	62100.00
0005433784997	9382	Economy	62100.00
0005433784969	9382	Economy	62100.00
0005433805435	9382	Economy	62100.00
0005433784988	9382	Economy	62100.00
0005433784972	9382	Economy	62100.00
0005433805412	9382	Economy	62100.00
0005434270192	9382	Economy	62100.00
0005433784984	9382	Economy	62100.00
0005433805428	9382	Economy	62100.00
0005433805427	9382	Economy	62100.00
0005433805420	9382	Economy	62100.00
0005433805425	9382	Economy	62100.00
0005433805415	9382	Economy	62100.00
0005434151694	9382	Economy	62100.00
0005433763216	9382	Economy	62100.00
0005434170986	9382	Economy	62100.00
0005433805406	9382	Economy	62100.00
0005433784967	9382	Economy	62100.00
0005433805411	9382	Economy	62100.00
0005432657450	9382	Economy	62100.00
0005433784973	9382	Economy	62100.00
0005433784970	9382	Economy	62100.00
0005433763215	9382	Economy	62100.00
0005434170946	9382	Economy	62100.00
0005433784964	9382	Economy	62100.00
0005433805414	9382	Economy	62100.00
0005433805423	9382	Economy	62100.00
0005434170959	9382	Economy	62100.00
0005433784968	9382	Economy	62100.00
0005433784998	9382	Economy	62100.00
0005432657452	9382	Economy	62100.00
0005433805403	9382	Economy	62100.00
0005433784991	9382	Economy	62100.00
0005433805432	9382	Economy	62100.00
0005433784987	9382	Economy	62100.00
0005433805426	9382	Economy	62100.00
0005432665277	9382	Economy	62100.00
0005433763220	9382	Economy	62100.00
0005433805401	9382	Economy	62100.00
0005432657451	9382	Economy	62100.00
0005433805431	9382	Economy	62100.00
0005433763222	9382	Economy	62100.00
0005433763223	9382	Economy	62100.00
0005433784963	9382	Economy	62100.00
0005434170991	9382	Economy	62100.00
0005433805402	9382	Economy	68300.00
0005433805430	9382	Economy	68300.00
0005433763217	9382	Economy	62100.00
0005433784971	9382	Economy	62100.00
0005434170924	9382	Economy	62100.00
0005433763213	9382	Economy	62100.00
0005433805407	9382	Economy	62100.00
0005433784990	9382	Economy	62100.00
0005432665276	9382	Economy	62100.00
0005433805413	9382	Economy	62100.00
0005432667456	9382	Economy	62100.00
0005433784995	9382	Economy	62100.00
0005433784982	9382	Economy	62100.00
0005433805434	9382	Economy	62100.00
0005434270194	9382	Economy	62100.00
0005434170945	9382	Economy	62100.00
0005434170992	9382	Economy	62100.00
0005433763221	9382	Economy	62100.00
0005433784980	9382	Economy	62100.00
0005434170952	9382	Economy	62100.00
0005433805416	9382	Economy	62100.00
0005434273063	9382	Economy	62100.00
0005433784962	9382	Economy	62100.00
0005434273064	9382	Economy	62100.00
0005433805418	9382	Economy	62100.00
0005433784977	9382	Economy	62100.00
0005433784960	9382	Economy	62100.00
0005433784981	9382	Economy	62100.00
0005433763226	9382	Economy	62100.00
0005433784978	9382	Economy	62100.00
0005434170962	9382	Economy	62100.00
0005433784979	9382	Economy	62100.00
0005433805404	9382	Economy	62100.00
0005433805405	9382	Economy	62100.00
0005434170996	9382	Economy	62100.00
0005434170997	9382	Economy	62100.00
0005434170925	9382	Economy	62100.00
0005433805408	9382	Economy	62100.00
0005433763214	9382	Economy	62100.00
0005433784961	9382	Economy	62100.00
0005433784986	9382	Economy	62100.00
0005433805410	9382	Economy	62100.00
0005433784994	9382	Economy	62100.00
0005433805419	9382	Economy	62100.00
0005434170932	9382	Economy	62100.00
0005432663022	26227	Business	186200.00
0005433784668	26227	Business	186200.00
0005433805232	26227	Business	186200.00
0005434171075	26227	Business	186200.00
0005434171070	26227	Business	186200.00
0005433784540	26227	Business	186200.00
0005432657424	26227	Business	186200.00
0005434171074	26227	Business	186200.00
0005433804954	26227	Business	186200.00
0005433784670	26227	Business	186200.00
0005432657425	26227	Business	186200.00
0005433784627	26227	Business	186200.00
0005432657423	26227	Economy	68300.00
0005432659700	26227	Economy	68300.00
0005433805180	26227	Economy	68300.00
0005433784521	26227	Economy	62100.00
0005433784522	26227	Economy	62100.00
0005434171073	26227	Economy	62100.00
0005432663017	26227	Economy	62100.00
0005433805238	26227	Economy	62100.00
0005433784623	26227	Economy	62100.00
0005434171068	26227	Economy	62100.00
0005433805239	26227	Economy	62100.00
0005432663024	26227	Economy	62100.00
0005434271311	26227	Economy	62100.00
0005433805108	26227	Economy	62100.00
0005433784669	26227	Economy	62100.00
0005434171071	26227	Economy	62100.00
0005434171065	26227	Economy	62100.00
0005433804953	26227	Economy	62100.00
0005435269750	26227	Economy	62100.00
0005434269103	26227	Economy	62100.00
0005433784763	26227	Economy	62100.00
0005433805121	26227	Economy	62100.00
0005433805196	26227	Economy	62100.00
0005434269102	26227	Economy	62100.00
0005433784597	26227	Economy	62100.00
0005433805096	26227	Economy	62100.00
0005432663021	26227	Economy	62100.00
0005433805231	26227	Economy	62100.00
0005433805195	26227	Economy	62100.00
0005434171069	26227	Economy	62100.00
0005433805085	26227	Economy	62100.00
0005433805134	26227	Economy	62100.00
0005433805072	26227	Economy	62100.00
0005433784603	26227	Economy	62100.00
0005433762992	26227	Economy	62100.00
0005433784687	26227	Economy	62100.00
0005434271312	26227	Economy	62100.00
0005433805073	26227	Economy	62100.00
0005432666376	26227	Economy	62100.00
0005433805092	26227	Economy	62100.00
0005433805223	26227	Economy	62100.00
0005432657415	26227	Economy	62100.00
0005433763108	26227	Economy	62100.00
0005433784810	26227	Economy	62100.00
0005434171064	26227	Economy	62100.00
0005434270207	26227	Economy	62100.00
0005433784596	26227	Economy	62100.00
0005433784599	26227	Economy	68300.00
0005432663020	26227	Economy	62100.00
0005433805080	26227	Economy	62100.00
0005433763084	26227	Economy	62100.00
0005433784612	26227	Economy	62100.00
0005433805197	26227	Economy	62100.00
0005433805122	26227	Economy	62100.00
0005434171063	26227	Economy	62100.00
0005433784586	26227	Economy	62100.00
0005433784602	26227	Economy	62100.00
0005433805119	26227	Economy	62100.00
0005434269104	26227	Economy	62100.00
0005433805221	26227	Economy	62100.00
0005433784611	26227	Economy	62100.00
0005433805260	26227	Economy	62100.00
0005433805107	26227	Economy	62100.00
0005433784585	26227	Economy	62100.00
0005433763066	26227	Economy	62100.00
0005433784764	26227	Economy	62100.00
0005433784709	26227	Economy	62100.00
0005434171066	26227	Economy	62100.00
0005432657416	26227	Economy	62100.00
0005433784742	26227	Economy	62100.00
0005433763105	26227	Economy	62100.00
0005433763120	26227	Economy	62100.00
0005433784527	26227	Economy	62100.00
0005435269749	26227	Economy	62100.00
0005434270206	26227	Economy	62100.00
0005433805095	26227	Economy	62100.00
0005434171067	26227	Economy	62100.00
0005433805027	26227	Economy	62100.00
0005434171072	26227	Economy	62100.00
0005434151707	26227	Economy	62100.00
0005433784741	26227	Economy	62100.00
0005433805156	26227	Economy	62100.00
0005433784610	26227	Economy	62100.00
0005433784743	26227	Economy	62100.00
0005433805139	26227	Economy	62100.00
0005433784523	26227	Economy	62100.00
0005433763099	26227	Economy	62100.00
0005433762993	26227	Economy	62100.00
0005433763077	26227	Economy	62100.00
0005433805220	26227	Economy	62100.00
0005433805093	26227	Economy	62100.00
0005435135674	4893	Economy	5300.00
0005435135673	4893	Economy	5300.00
0005435135675	4893	Economy	5300.00
0005435929634	4893	Economy	5300.00
0005435135676	4893	Economy	5300.00
0005435135623	33044	Economy	5900.00
0005435135663	33044	Economy	5900.00
0005435929647	33044	Economy	5300.00
0005435135622	33044	Economy	5300.00
0005435929648	33044	Economy	5300.00
0005435929645	33044	Economy	5300.00
0005435135648	33044	Economy	5300.00
0005435135664	33044	Economy	5300.00
0005435135645	33044	Economy	5300.00
0005435135647	33044	Economy	5300.00
0005435929646	33044	Economy	5300.00
0005434217947	9494	Economy	17900.00
0005434983289	9494	Economy	17900.00
0005434983293	9494	Economy	17900.00
0005434983292	9494	Economy	17900.00
0005434983294	9494	Economy	17900.00
0005434983291	9494	Economy	17900.00
0005434217946	9494	Economy	17900.00
0005434983290	9494	Economy	17900.00
0005434983264	27354	Economy	17900.00
0005434217972	27354	Economy	17900.00
0005434217974	27354	Economy	17900.00
0005434217973	27354	Economy	17900.00
0005434983263	27354	Economy	17900.00
0005433960344	24273	Business	36400.00
0005433960422	24273	Business	36400.00
0005433960236	24273	Business	36400.00
0005433960398	24273	Business	36400.00
0005433985522	24273	Business	36400.00
0005433985717	24273	Business	36400.00
0005433960379	24273	Business	36400.00
0005433960427	24273	Economy	13400.00
0005433960144	24273	Economy	13400.00
0005433985777	24273	Economy	13400.00
0005433960382	24273	Economy	12100.00
0005433985543	24273	Economy	12100.00
0005433960238	24273	Economy	12100.00
0005433985615	24273	Economy	12100.00
0005433985660	24273	Economy	12100.00
0005433985567	24273	Economy	12100.00
0005433985466	24273	Economy	12100.00
0005433985715	24273	Economy	12100.00
0005433985778	24273	Economy	12100.00
0005433985659	24273	Economy	12100.00
0005433960323	24273	Economy	12100.00
0005433960201	24273	Economy	12100.00
0005433960435	24273	Economy	12100.00
0005433960165	24273	Economy	12100.00
0005433985612	24273	Economy	12100.00
0005433985226	24273	Economy	12100.00
0005433960408	24273	Economy	12100.00
0005433960383	24273	Economy	12100.00
0005433960428	24273	Economy	12100.00
0005433985663	24273	Economy	12100.00
0005433960434	24273	Economy	12100.00
0005433960406	24273	Economy	12100.00
0005433985418	24273	Economy	12100.00
0005433985676	24273	Economy	12100.00
0005433985536	24273	Economy	12100.00
0005433960345	24273	Economy	12100.00
0005433985355	24273	Economy	12100.00
0005433985609	24273	Economy	12100.00
0005433985228	24273	Economy	12100.00
0005433960226	24273	Economy	12100.00
0005433960355	24273	Economy	12100.00
0005433985621	24273	Economy	12100.00
0005433985532	24273	Economy	12100.00
0005433985610	24273	Economy	12100.00
0005433960413	24273	Economy	12100.00
0005433960430	24273	Economy	12100.00
0005433960324	24273	Economy	12100.00
0005433985671	24273	Economy	13400.00
0005433960224	24273	Economy	13400.00
0005433985295	24273	Economy	12100.00
0005433960433	24273	Economy	12100.00
0005433960380	24273	Economy	12100.00
0005433960258	24273	Economy	12100.00
0005433960322	24273	Economy	12100.00
0005433960282	24273	Economy	12100.00
0005433960431	24273	Economy	12100.00
0005433985664	24273	Economy	12100.00
0005433960327	24273	Economy	12100.00
0005433985227	24273	Economy	12100.00
0005433985618	24273	Economy	12100.00
0005433960348	24273	Economy	12100.00
0005433960363	24273	Economy	12100.00
0005433985718	24273	Economy	12100.00
0005433985598	24273	Economy	12100.00
0005433960200	24273	Economy	12100.00
0005433985382	24273	Economy	12100.00
0005433960326	24273	Economy	12100.00
0005433985467	24273	Economy	12100.00
0005433985611	24273	Economy	12100.00
0005433960145	24273	Economy	12100.00
0005433985566	24273	Economy	12100.00
0005433985662	24273	Economy	12100.00
0005433960239	24273	Economy	12100.00
0005433985419	24273	Economy	12100.00
0005433985479	24273	Economy	12100.00
0005433985472	24273	Economy	12100.00
0005433960195	24273	Economy	12100.00
0005433985770	24273	Economy	12100.00
0005433985509	24273	Economy	12100.00
0005433985613	24273	Economy	12100.00
0005433985381	24273	Economy	12100.00
0005433985591	24273	Economy	12100.00
0005433985953	25918	Business	36400.00
0005433960863	25918	Business	36400.00
0005433985935	25918	Business	36400.00
0005433985939	25918	Business	36400.00
0005433985948	25918	Business	36400.00
0005433960903	25918	Business	36400.00
0005433960899	25918	Business	36400.00
0005433960873	25918	Business	36400.00
0005433985973	25918	Business	36400.00
0005433985930	25918	Business	36400.00
0005433985929	25918	Business	36400.00
0005433985977	25918	Business	36400.00
0005433985927	25918	Business	36400.00
0005433985933	25918	Business	36400.00
0005433960854	25918	Business	36400.00
0005433985945	25918	Business	36400.00
0005433985964	25918	Business	36400.00
0005433960908	25918	Economy	13400.00
0005433985983	25918	Economy	12100.00
0005433985971	25918	Economy	12100.00
0005433960867	25918	Economy	12100.00
0005433985961	25918	Economy	12100.00
0005433985975	25918	Economy	12100.00
0005433960891	25918	Economy	12100.00
0005433985970	25918	Economy	12100.00
0005433960853	25918	Economy	12100.00
0005433985957	25918	Economy	12100.00
0005433960910	25918	Economy	12100.00
0005433985962	25918	Economy	12100.00
0005433960870	25918	Economy	12100.00
0005433985982	25918	Economy	12100.00
0005433960901	25918	Economy	12100.00
0005433985969	25918	Economy	12100.00
0005433960897	25918	Economy	12100.00
0005433985928	25918	Economy	12100.00
0005433960866	25918	Economy	12100.00
0005433960909	25918	Economy	12100.00
0005433960900	25918	Economy	12100.00
0005433985947	25918	Economy	12100.00
0005433960893	25918	Economy	12100.00
0005433960898	25918	Economy	12100.00
0005433960869	25918	Economy	12100.00
0005433960886	25918	Economy	12100.00
0005433960883	25918	Economy	12100.00
0005433960877	25918	Economy	12100.00
0005433960865	25918	Economy	12100.00
0005433960851	25918	Economy	12100.00
0005433985944	25918	Economy	12100.00
0005433960892	25918	Economy	12100.00
0005433960861	25918	Economy	12100.00
0005433960906	25918	Economy	12100.00
0005433985938	25918	Economy	12100.00
0005433985940	25918	Economy	12100.00
0005433985954	25918	Economy	12100.00
0005433985936	25918	Economy	12100.00
0005433960857	25918	Economy	12100.00
0005433985980	25918	Economy	12100.00
0005433985979	25918	Economy	12100.00
0005433985972	25918	Economy	12100.00
0005433985960	25918	Economy	12100.00
0005433960879	25918	Economy	12100.00
0005433960864	25918	Economy	12100.00
0005433985941	25918	Economy	12100.00
0005433985952	25918	Economy	12100.00
0005433960885	25918	Economy	12100.00
0005433960855	25918	Economy	12100.00
0005433960860	25918	Economy	12100.00
0005433960880	25918	Economy	12100.00
0005433960902	25918	Economy	12100.00
0005433985934	25918	Economy	13400.00
0005433960896	25918	Economy	13400.00
0005433960905	25918	Economy	12100.00
0005433960907	25918	Economy	12100.00
0005433960912	25918	Economy	12100.00
0005433985942	25918	Economy	12100.00
0005433960881	25918	Economy	12100.00
0005433985967	25918	Economy	12100.00
0005433960894	25918	Economy	12100.00
0005433985950	25918	Economy	12100.00
0005433960889	25918	Economy	12100.00
0005433960858	25918	Economy	12100.00
0005433960888	25918	Economy	12100.00
0005433960874	25918	Economy	12100.00
0005433985932	25918	Economy	12100.00
0005433960871	25918	Economy	12100.00
0005433960890	25918	Economy	12100.00
0005433985966	25918	Economy	12100.00
0005433960904	25918	Economy	12100.00
0005433960884	25918	Economy	12100.00
0005433960859	25918	Economy	12100.00
0005433960875	25918	Economy	12100.00
0005433960868	25918	Economy	12100.00
0005433985937	25918	Economy	12100.00
0005433960852	25918	Economy	12100.00
0005433985978	25918	Economy	12100.00
0005433985974	25918	Economy	12100.00
0005433960878	25918	Economy	12100.00
0005433985958	25918	Economy	12100.00
0005433960895	25918	Economy	12100.00
0005433985959	25918	Economy	12100.00
0005433960911	25918	Economy	12100.00
0005433985976	25918	Economy	12100.00
0005433960856	25918	Economy	12100.00
0005433985963	25918	Economy	12100.00
0005433985956	25918	Economy	12100.00
0005433985946	25918	Economy	12100.00
0005433985981	25918	Economy	12100.00
0005433960876	25918	Economy	12100.00
0005433985968	25918	Economy	12100.00
0005433985949	25918	Economy	12100.00
0005433960887	25918	Economy	12100.00
0005433985943	25918	Economy	12100.00
0005433960872	25918	Economy	12100.00
0005433985955	25918	Economy	12100.00
0005433960882	25918	Economy	12100.00
0005433985965	25918	Economy	12100.00
0005433960862	25918	Economy	12100.00
0005433985951	25918	Economy	12100.00
0005433985931	25918	Economy	12100.00
0005434480354	917	Economy	25400.00
0005433165837	917	Economy	25400.00
0005434480359	917	Economy	23100.00
0005434480364	917	Economy	23100.00
0005434480343	917	Economy	23100.00
0005433165780	917	Economy	23100.00
0005434480341	917	Economy	23100.00
0005433165813	917	Economy	23100.00
0005434480349	917	Economy	23100.00
0005434480356	917	Economy	23100.00
0005434480347	917	Economy	23100.00
0005434480362	917	Economy	23100.00
0005434480345	917	Economy	23100.00
0005433165740	917	Economy	23100.00
0005433165854	917	Economy	23100.00
0005434480358	917	Economy	23100.00
0005434480363	917	Economy	23100.00
0005433165851	917	Economy	23100.00
0005433165814	917	Economy	23100.00
0005434480342	917	Economy	23100.00
0005434480361	917	Economy	23100.00
0005434480353	917	Economy	23100.00
0005434480344	917	Economy	23100.00
0005434480365	917	Economy	23100.00
0005434480350	917	Economy	23100.00
0005432269499	917	Economy	23100.00
0005434480352	917	Economy	23100.00
0005433165838	917	Economy	23100.00
0005433165741	917	Economy	23100.00
0005434480357	917	Economy	23100.00
0005434480348	917	Economy	23100.00
0005434480346	917	Economy	23100.00
0005433165729	917	Economy	23100.00
0005434480360	917	Economy	23100.00
0005433165849	917	Economy	23100.00
0005434480355	917	Economy	23100.00
0005434480351	917	Economy	23100.00
0005433165781	917	Economy	23100.00
0005434480366	917	Economy	23100.00
0005433165916	16586	Economy	25400.00
0005434480220	16586	Economy	25400.00
0005433165919	16586	Economy	25400.00
0005434480177	16586	Economy	25400.00
0005434480162	16586	Economy	23100.00
0005433165917	16586	Economy	23100.00
0005433165920	16586	Economy	23100.00
0005433165913	16586	Economy	23100.00
0005433165912	16586	Economy	23100.00
0005434480149	16586	Economy	23100.00
0005433165921	16586	Economy	23100.00
0005433165922	16586	Economy	23100.00
0005434480150	16586	Economy	23100.00
0005434480156	16586	Economy	23100.00
0005433165914	16586	Economy	23100.00
0005434480223	16586	Economy	23100.00
0005434480086	16586	Economy	23100.00
0005433165911	16586	Economy	23100.00
0005434480104	16586	Economy	23100.00
0005434480224	16586	Economy	23100.00
0005433165923	16586	Economy	23100.00
0005434480093	16586	Economy	23100.00
0005434480088	16586	Economy	23100.00
0005433165910	16586	Economy	23100.00
0005433165915	16586	Economy	23100.00
0005433165918	16586	Economy	23100.00
0005433165909	16586	Economy	23100.00
0005434480184	16586	Economy	23100.00
0005434480102	16586	Economy	23100.00
0005434480196	16586	Economy	23100.00
0005434480185	16586	Economy	23100.00
0005434480157	16586	Economy	23100.00
0005433872490	3191	Economy	17200.00
0005433872486	3191	Economy	17200.00
0005433872485	3191	Economy	17200.00
0005433872487	3191	Economy	17200.00
0005433872484	3191	Economy	17200.00
0005433872488	3191	Economy	17200.00
0005433872489	3191	Economy	17200.00
0005433872456	32559	Economy	17200.00
0005433872475	32559	Economy	17200.00
0005433872457	32559	Economy	17200.00
0005433872447	32559	Economy	17200.00
0005433872476	32559	Economy	17200.00
0005435386530	10371	Economy	17000.00
0005435386545	10371	Economy	17000.00
0005433289802	10371	Economy	17000.00
0005435386485	10371	Economy	17000.00
0005435142583	10371	Economy	15400.00
0005435386516	10371	Economy	15400.00
0005435386517	10371	Economy	15400.00
0005435142574	10371	Economy	15400.00
0005435150026	10371	Economy	15400.00
0005435142580	10371	Economy	15400.00
0005435150023	10371	Economy	15400.00
0005435142572	10371	Economy	15400.00
0005435142584	10371	Economy	15400.00
0005435386527	10371	Economy	15400.00
0005435142582	10371	Economy	15400.00
0005435150024	10371	Economy	15400.00
0005435386525	10371	Economy	15400.00
0005435386533	10371	Economy	15400.00
0005435142571	10371	Economy	15400.00
0005435150035	10371	Economy	15400.00
0005435150033	10371	Economy	15400.00
0005435150030	10371	Economy	15400.00
0005433289773	10371	Economy	15400.00
0005435142573	10371	Economy	15400.00
0005435150034	10371	Economy	15400.00
0005435150032	10371	Economy	15400.00
0005435386528	10371	Economy	15400.00
0005433289790	10371	Economy	15400.00
0005435142581	10371	Economy	15400.00
0005435142577	10371	Economy	15400.00
0005435150029	10371	Economy	15400.00
0005435150022	10371	Economy	15400.00
0005435150028	10371	Economy	15400.00
0005435150027	10371	Economy	15400.00
0005435150031	10371	Economy	15400.00
0005435142579	10371	Economy	15400.00
0005435142578	10371	Economy	15400.00
0005433289803	10371	Economy	15400.00
0005435150036	10371	Economy	15400.00
0005435386542	10371	Economy	15400.00
0005435142575	10371	Economy	15400.00
0005435150025	10371	Economy	15400.00
0005433289789	10371	Economy	15400.00
0005433289752	10371	Economy	15400.00
0005435142576	10371	Economy	15400.00
0005435142499	21932	Economy	17000.00
0005435142401	21932	Economy	17000.00
0005435142462	21932	Economy	17000.00
0005435142437	21932	Economy	15400.00
0005435149944	21932	Economy	15400.00
0005435142467	21932	Economy	15400.00
0005435386575	21932	Economy	15400.00
0005435142493	21932	Economy	15400.00
0005435386573	21932	Economy	15400.00
0005435149939	21932	Economy	15400.00
0005433289862	21932	Economy	15400.00
0005435149878	21932	Economy	15400.00
0005433289859	21932	Economy	15400.00
0005435386577	21932	Economy	15400.00
0005435142460	21932	Economy	15400.00
0005435142487	21932	Economy	15400.00
0005435142438	21932	Economy	15400.00
0005435149934	21932	Economy	15400.00
0005435142481	21932	Economy	15400.00
0005435386578	21932	Economy	15400.00
0005435142461	21932	Economy	15400.00
0005435149915	21932	Economy	15400.00
0005435386576	21932	Economy	15400.00
0005435386574	21932	Economy	15400.00
0005435142494	21932	Economy	15400.00
0005435149945	21932	Economy	15400.00
0005435149879	21932	Economy	15400.00
0005435386572	21932	Economy	15400.00
0005433289864	21932	Economy	15400.00
0005433289861	21932	Economy	15400.00
0005433289860	21932	Economy	15400.00
0005433289863	21932	Economy	15400.00
0005434573350	11210	Business	57200.00
0005435502109	11210	Business	57200.00
0005435529073	11210	Business	57200.00
0005435545656	11210	Business	57200.00
0005435319513	11210	Business	57200.00
0005435502110	11210	Business	57200.00
0005435529153	11210	Business	57200.00
0005435545667	11210	Business	57200.00
0005435529152	11210	Business	57200.00
0005435529099	11210	Business	57200.00
0005434573347	11210	Business	57200.00
0005435528969	11210	Economy	19100.00
0005435502164	11210	Economy	19100.00
0005434573359	11210	Economy	19100.00
0005435529059	11210	Economy	19100.00
0005435529054	11210	Economy	21000.00
0005434573357	11210	Economy	21000.00
0005435529110	11210	Economy	21000.00
0005435502135	11210	Economy	19100.00
0005435529045	11210	Economy	19100.00
0005435529098	11210	Economy	19100.00
0005435529111	11210	Economy	19100.00
0005434573360	11210	Economy	19100.00
0005435319519	11210	Economy	19100.00
0005435529121	11210	Economy	19100.00
0005435502108	11210	Economy	19100.00
0005435502187	11210	Economy	19100.00
0005434573358	11210	Economy	19100.00
0005434573354	11210	Economy	19100.00
0005435529014	11210	Economy	19100.00
0005435545671	11210	Economy	19100.00
0005434573355	11210	Economy	19100.00
0005435529053	11210	Economy	19100.00
0005435502173	11210	Economy	19100.00
0005435528952	11210	Economy	19100.00
0005435502136	11210	Economy	19100.00
0005435545659	11210	Economy	19100.00
0005435502181	11210	Economy	19100.00
0005435529007	11210	Economy	19100.00
0005435502122	11210	Economy	19100.00
0005434573353	11210	Economy	19100.00
0005434573352	11210	Economy	19100.00
0005435502160	11210	Economy	19100.00
0005435529139	11210	Economy	19100.00
0005435529080	11210	Economy	19100.00
0005435529058	11210	Economy	19100.00
0005435502150	11210	Economy	19100.00
0005435529120	11210	Economy	19100.00
0005435529051	11210	Economy	19100.00
0005435502186	11210	Economy	19100.00
0005435528951	11210	Economy	19100.00
0005435319526	11210	Economy	19100.00
0005435502166	11210	Economy	19100.00
0005435545674	11210	Economy	19100.00
0005435529075	11210	Economy	19100.00
0005435502196	11210	Economy	19100.00
0005435545632	11210	Economy	19100.00
0005435529048	11210	Economy	19100.00
0005435529013	11210	Economy	19100.00
0005435502123	11210	Economy	19100.00
0005435545644	11210	Economy	19100.00
0005435529049	11210	Economy	19100.00
0005434573356	11210	Economy	19100.00
0005434573349	11210	Economy	19100.00
0005434573351	11210	Economy	19100.00
0005435502098	11210	Economy	19100.00
0005435529050	11210	Economy	19100.00
0005435529140	11210	Economy	19100.00
0005434573348	11210	Economy	19100.00
0005435502234	11210	Economy	19100.00
0005435502165	11210	Economy	19100.00
0005435502168	11210	Economy	19100.00
0005435529006	11210	Economy	19100.00
0005435529091	11210	Economy	19100.00
0005435502239	11210	Economy	19100.00
0005435545631	11210	Economy	19100.00
0005434573224	20938	Business	57200.00
0005435508378	20938	Business	57200.00
0005435508374	20938	Business	57200.00
0005435502311	20938	Business	57200.00
0005435517918	20938	Business	57200.00
0005435502328	20938	Business	57200.00
0005435502327	20938	Business	57200.00
0005435517920	20938	Business	57200.00
0005435508373	20938	Business	57200.00
0005435502325	20938	Economy	19100.00
0005435502326	20938	Economy	19100.00
0005435517925	20938	Economy	19100.00
0005434573264	20938	Economy	19100.00
0005434573220	20938	Economy	19100.00
0005435319594	20938	Economy	19100.00
0005435508367	20938	Economy	19100.00
0005435508377	20938	Economy	21000.00
0005435508371	20938	Economy	21000.00
0005435508375	20938	Economy	21000.00
0005435508369	20938	Economy	21000.00
0005435502316	20938	Economy	19100.00
0005435319589	20938	Economy	19100.00
0005435502317	20938	Economy	19100.00
0005434573312	20938	Economy	19100.00
0005435502309	20938	Economy	19100.00
0005435508376	20938	Economy	19100.00
0005434573297	20938	Economy	19100.00
0005435502329	20938	Economy	19100.00
0005432291930	20938	Economy	19100.00
0005435508372	20938	Economy	19100.00
0005435319591	20938	Economy	19100.00
0005435319590	20938	Economy	19100.00
0005435517922	20938	Economy	19100.00
0005435319595	20938	Economy	19100.00
0005435319586	20938	Economy	19100.00
0005435517923	20938	Economy	19100.00
0005435502324	20938	Economy	19100.00
0005435502323	20938	Economy	19100.00
0005435502330	20938	Economy	19100.00
0005435502321	20938	Economy	19100.00
0005435502314	20938	Economy	19100.00
0005435517924	20938	Economy	19100.00
0005435508370	20938	Economy	19100.00
0005435517921	20938	Economy	19100.00
0005435508368	20938	Economy	19100.00
0005435502315	20938	Economy	19100.00
0005435502310	20938	Economy	19100.00
0005435517927	20938	Economy	19100.00
0005434573229	20938	Economy	19100.00
0005435517919	20938	Economy	19100.00
0005435502308	20938	Economy	19100.00
0005435502312	20938	Economy	19100.00
0005435319592	20938	Economy	19100.00
0005435319593	20938	Economy	19100.00
0005434573158	20938	Economy	19100.00
0005435502320	20938	Economy	19100.00
0005435502319	20938	Economy	19100.00
0005432291931	20938	Economy	19100.00
0005435502318	20938	Economy	19100.00
0005435319587	20938	Economy	19100.00
0005435517926	20938	Economy	19100.00
0005435502313	20938	Economy	19100.00
0005435319588	20938	Economy	19100.00
0005435502322	20938	Economy	19100.00
0005434573241	20938	Economy	19100.00
0005432692733	3011	Business	10300.00
0005432692996	3011	Business	10300.00
0005432692722	3011	Business	10300.00
0005432692723	3011	Business	10300.00
0005432692814	3011	Business	10300.00
0005432692944	3011	Business	10300.00
0005432692747	3011	Business	10300.00
0005432692693	3011	Economy	3400.00
0005432692721	3011	Economy	3400.00
0005432692873	3011	Economy	3400.00
0005432692746	3011	Economy	3400.00
0005432692857	3011	Economy	3400.00
0005432692916	3011	Economy	3400.00
0005432692796	3011	Economy	3400.00
0005432692921	3011	Economy	3400.00
0005432692933	3011	Economy	3400.00
0005432692732	3011	Economy	3400.00
0005432692813	3011	Economy	3400.00
0005432692945	3011	Economy	3400.00
0005432692917	3011	Economy	3400.00
0005432692823	3011	Economy	3400.00
0005432692913	3011	Economy	3400.00
0005432692885	3011	Economy	3400.00
0005432692779	3011	Economy	3400.00
0005433123820	3010	Business	10300.00
0005432880713	3010	Business	10300.00
0005432880709	3010	Business	10300.00
0005432706787	3010	Business	10300.00
0005432880728	3010	Business	10300.00
0005432706785	3010	Business	10300.00
0005432217779	3010	Business	10300.00
0005433123686	3010	Business	10300.00
0005433123744	3010	Business	10300.00
0005432706803	3010	Economy	3400.00
0005433123809	3010	Economy	3400.00
0005432217778	3010	Economy	3400.00
0005432706804	3010	Economy	3400.00
0005433123705	3010	Economy	3400.00
0005432706788	3010	Economy	3400.00
0005432706786	3010	Economy	3400.00
0005432706783	3010	Economy	3800.00
0005432880764	3010	Economy	3800.00
0005432706797	3010	Economy	3800.00
0005432880652	3010	Economy	3800.00
0005433123729	3010	Economy	3400.00
0005433123701	3010	Economy	3400.00
0005432706781	3010	Economy	3400.00
0005433123713	3010	Economy	3400.00
0005432706798	3010	Economy	3400.00
0005432706795	3010	Economy	3400.00
0005432706779	3010	Economy	3400.00
0005433123736	3010	Economy	3400.00
0005432880721	3010	Economy	3400.00
0005432880663	3010	Economy	3400.00
0005433123779	3010	Economy	3400.00
0005433123818	3010	Economy	3400.00
0005433123764	3010	Economy	3400.00
0005432880729	3010	Economy	3400.00
0005433194844	3010	Economy	3400.00
0005432880680	3010	Economy	3400.00
0005433123763	3010	Economy	3400.00
0005433123755	3010	Economy	3400.00
0005432706793	3010	Economy	3400.00
0005432217777	3010	Economy	3400.00
0005433123831	3010	Economy	3400.00
0005432880703	3010	Economy	3400.00
0005432880697	3010	Economy	3400.00
0005432706799	3010	Economy	3400.00
0005433123794	3010	Economy	3400.00
0005432880734	3010	Economy	3400.00
0005432706794	3010	Economy	3400.00
0005432880711	3010	Economy	3400.00
0005432706789	3010	Economy	3400.00
0005432880727	3010	Economy	3400.00
0005432706791	3010	Economy	3400.00
0005432706792	3010	Economy	3400.00
0005433123735	3010	Economy	3400.00
0005432706790	3010	Economy	3400.00
0005432706796	3010	Economy	3400.00
0005432880710	3010	Economy	3400.00
0005432706801	3010	Economy	3400.00
0005433194838	3010	Economy	3400.00
0005433123754	3010	Economy	3400.00
0005433123821	3010	Economy	3400.00
0005432706802	3010	Economy	3400.00
0005432706780	3010	Economy	3400.00
0005432880708	3010	Economy	3400.00
0005433123766	3010	Economy	3400.00
0005432880664	3010	Economy	3400.00
0005433123769	3010	Economy	3400.00
0005433123819	3010	Economy	3400.00
0005432880696	3010	Economy	3400.00
0005433123770	3010	Economy	3400.00
0005432880678	3010	Economy	3400.00
0005433123728	3010	Economy	3400.00
0005433123772	3010	Economy	3400.00
0005432706784	3010	Economy	3400.00
0005432706800	3010	Economy	3400.00
0005433123768	3010	Economy	3400.00
0005433123743	3010	Economy	3400.00
0005432706782	3010	Economy	3400.00
0005432693110	29998	Business	10300.00
0005432706616	29998	Business	10300.00
0005432706540	29998	Business	10300.00
0005433123948	29998	Business	10300.00
0005433123942	29998	Business	10300.00
0005433123941	29998	Business	10300.00
0005432706558	29998	Business	10300.00
0005433123933	29998	Business	10300.00
0005433194860	29998	Business	10300.00
0005432706470	29998	Business	10300.00
0005432880826	29998	Business	10300.00
0005433123952	29998	Business	10300.00
0005433123940	29998	Economy	3400.00
0005432693118	29998	Economy	3400.00
0005432880834	29998	Economy	3400.00
0005432880830	29998	Economy	3400.00
0005432706433	29998	Economy	3400.00
0005432693111	29998	Economy	3400.00
0005433123936	29998	Economy	3400.00
0005433123953	29998	Economy	3400.00
0005432693104	29998	Economy	3400.00
0005433123935	29998	Economy	3400.00
0005432693100	29998	Economy	3800.00
0005432693099	29998	Economy	3800.00
0005432706656	29998	Economy	3800.00
0005432693126	29998	Economy	3800.00
0005432693108	29998	Economy	3800.00
0005432706646	29998	Economy	3400.00
0005432880828	29998	Economy	3400.00
0005432693122	29998	Economy	3400.00
0005432706596	29998	Economy	3400.00
0005432706622	29998	Economy	3400.00
0005432693097	29998	Economy	3400.00
0005432706471	29998	Economy	3400.00
0005432706532	29998	Economy	3400.00
0005432880827	29998	Economy	3400.00
0005432693116	29998	Economy	3400.00
0005432693119	29998	Economy	3400.00
0005432706588	29998	Economy	3400.00
0005432693121	29998	Economy	3400.00
0005432693103	29998	Economy	3400.00
0005432706621	29998	Economy	3400.00
0005432706559	29998	Economy	3400.00
0005433123945	29998	Economy	3400.00
0005432880823	29998	Economy	3400.00
0005432693125	29998	Economy	3400.00
0005432880821	29998	Economy	3400.00
0005433123932	29998	Economy	3400.00
0005432693102	29998	Economy	3400.00
0005432880824	29998	Economy	3400.00
0005432693109	29998	Economy	3400.00
0005433123938	29998	Economy	3400.00
0005433123937	29998	Economy	3400.00
0005432706720	29998	Economy	3400.00
0005432706554	29998	Economy	3400.00
0005432693115	29998	Economy	3400.00
0005433123949	29998	Economy	3400.00
0005432693114	29998	Economy	3400.00
0005432693120	29998	Economy	3400.00
0005433123947	29998	Economy	3400.00
0005432880835	29998	Economy	3400.00
0005433123939	29998	Economy	3400.00
0005432880825	29998	Economy	3400.00
0005432693112	29998	Economy	3400.00
0005432693098	29998	Economy	3400.00
0005432706546	29998	Economy	3400.00
0005432706645	29998	Economy	3400.00
0005432880831	29998	Economy	3400.00
0005432693101	29998	Economy	3400.00
0005432693123	29998	Economy	3400.00
0005432693117	29998	Economy	3400.00
0005432693113	29998	Economy	3400.00
0005432880822	29998	Economy	3400.00
0005432706581	29998	Economy	3400.00
0005433123931	29998	Economy	3400.00
0005432880832	29998	Economy	3400.00
0005433194859	29998	Economy	3400.00
0005433123943	29998	Economy	3400.00
0005433194858	29998	Economy	3400.00
0005433123944	29998	Economy	3400.00
0005433123950	29998	Economy	3400.00
0005433123951	29998	Economy	3400.00
0005432880833	29998	Economy	3400.00
0005432693106	29998	Economy	3400.00
0005432706541	29998	Economy	3400.00
0005432880829	29998	Economy	3400.00
0005433123946	29998	Economy	3400.00
0005432706589	29998	Economy	3400.00
0005432706574	29998	Economy	3400.00
0005432693124	29998	Economy	3400.00
0005432706625	29998	Economy	3400.00
0005432693105	29998	Economy	3400.00
0005432693107	29998	Economy	3400.00
0005433123934	29998	Economy	3400.00
0005432693096	29998	Economy	3400.00
0005432706550	29998	Economy	3400.00
0005434979785	23681	Economy	4000.00
0005434979791	23681	Economy	4000.00
0005434988743	23681	Economy	4000.00
0005434979783	23681	Economy	3600.00
0005434979792	23681	Economy	3600.00
0005434979786	23681	Economy	3600.00
0005434979778	23681	Economy	3600.00
0005434988741	23681	Economy	3600.00
0005434988750	23681	Economy	3600.00
0005434979776	23681	Economy	3600.00
0005434979782	23681	Economy	3600.00
0005434979795	23681	Economy	3600.00
0005434979777	23681	Economy	3600.00
0005434979803	23681	Economy	3600.00
0005434988744	23681	Economy	3600.00
0005434979787	23681	Economy	3600.00
0005434988745	23681	Economy	3600.00
0005434979790	23681	Economy	3600.00
0005434979775	23681	Economy	3600.00
0005434988746	23681	Economy	3600.00
0005434979781	23681	Economy	3600.00
0005434979788	23681	Economy	3600.00
0005434979793	23681	Economy	3600.00
0005434979799	23681	Economy	3600.00
0005434979794	23681	Economy	3600.00
0005434979800	23681	Economy	3600.00
0005434988751	23681	Economy	3600.00
0005434988742	23681	Economy	3600.00
0005434979779	23681	Economy	3600.00
0005434979798	23681	Economy	3600.00
0005434979780	23681	Economy	3600.00
0005434979789	23681	Economy	3600.00
0005434979805	23681	Economy	3600.00
0005434979784	23681	Economy	3600.00
0005434988747	23681	Economy	3600.00
0005434979801	23681	Economy	3600.00
0005434979802	23681	Economy	3600.00
0005434979797	23681	Economy	3600.00
0005434988748	23681	Economy	3600.00
0005434979796	23681	Economy	3600.00
0005434988740	23681	Economy	3600.00
0005434988749	23681	Economy	3600.00
0005434979804	23681	Economy	3600.00
0005434979582	27555	Economy	4000.00
0005434988626	27555	Economy	4000.00
0005434979595	27555	Economy	3600.00
0005434979612	27555	Economy	3600.00
0005434979492	27555	Economy	3600.00
0005434979570	27555	Economy	3600.00
0005434979515	27555	Economy	3600.00
0005434988625	27555	Economy	3600.00
0005434979510	27555	Economy	3600.00
0005434979555	27555	Economy	3600.00
0005434979573	27555	Economy	3600.00
0005434979557	27555	Economy	3600.00
0005434988645	27555	Economy	3600.00
0005434979587	27555	Economy	3600.00
0005434988633	27555	Economy	3600.00
0005434979501	27555	Economy	3600.00
0005434979621	27555	Economy	3600.00
0005434979545	27555	Economy	3600.00
0005434979608	27555	Economy	3600.00
0005434988643	27555	Economy	3600.00
0005434979500	27555	Economy	3600.00
0005434979586	27555	Economy	3600.00
0005434979491	27555	Economy	3600.00
0005434979525	27555	Economy	3600.00
0005434979376	27555	Economy	3600.00
0005434979293	27555	Economy	3600.00
0005434988636	27555	Economy	3600.00
0005434988644	27555	Economy	3600.00
0005434979606	27555	Economy	3600.00
0005434988619	27555	Economy	3600.00
0005434979516	27555	Economy	3600.00
0005434979507	27555	Economy	3600.00
0005434979556	27555	Economy	3600.00
0005434979620	27555	Economy	3600.00
0005434979584	27555	Economy	3600.00
0005434979546	27555	Economy	3600.00
0005434979583	27555	Economy	3600.00
0005434979554	27555	Economy	3600.00
0005434979585	27555	Economy	3600.00
0005434302460	10266	Economy	19700.00
0005433113520	10266	Economy	19700.00
0005433113522	10266	Economy	19700.00
0005433111472	10266	Economy	19700.00
0005434302461	10266	Economy	19700.00
0005434302459	10266	Economy	19700.00
0005433113519	10266	Economy	19700.00
0005434302458	10266	Economy	19700.00
0005433113521	10266	Economy	19700.00
0005434302432	19644	Economy	19700.00
0005434302405	19644	Economy	19700.00
0005434302411	19644	Economy	19700.00
0005433113538	19644	Economy	19700.00
0005434302406	19644	Economy	19700.00
0005433113537	19644	Economy	19700.00
0005435069145	3545	Business	26900.00
0005435069164	3545	Business	26900.00
0005435069112	3545	Business	26900.00
0005435069148	3545	Business	26900.00
0005435069121	3545	Business	26900.00
0005435925134	3545	Business	26900.00
0005435069122	3545	Business	26900.00
0005435069154	3545	Business	26900.00
0005435069166	3545	Economy	9000.00
0005435069135	3545	Economy	9000.00
0005435718952	3545	Economy	9000.00
0005435925165	3545	Economy	9000.00
0005435069158	3545	Economy	9000.00
0005435069130	3545	Economy	9000.00
0005435925157	3545	Economy	9900.00
0005435718947	3545	Economy	9900.00
0005435069116	3545	Economy	9900.00
0005435069156	3545	Economy	9900.00
0005435069134	3545	Economy	9900.00
0005435069126	3545	Economy	9000.00
0005435925181	3545	Economy	9000.00
0005435925176	3545	Economy	9000.00
0005435069139	3545	Economy	9000.00
0005435069149	3545	Economy	9000.00
0005435718953	3545	Economy	9000.00
0005435925182	3545	Economy	9000.00
0005435069131	3545	Economy	9000.00
0005435069162	3545	Economy	9000.00
0005435069140	3545	Economy	9000.00
0005435069119	3545	Economy	9000.00
0005435069160	3545	Economy	9000.00
0005435925175	3545	Economy	9000.00
0005435069159	3545	Economy	9000.00
0005435069133	3545	Economy	9000.00
0005435718950	3545	Economy	9000.00
0005435069152	3545	Economy	9000.00
0005435069125	3545	Economy	9000.00
0005435069147	3545	Economy	9000.00
0005435069161	3545	Economy	9000.00
0005435069113	3545	Economy	9000.00
0005435069165	3545	Economy	9000.00
0005435069163	3545	Economy	9000.00
0005435925183	3545	Economy	9000.00
0005435925189	3545	Economy	9000.00
0005435069132	3545	Economy	9000.00
0005435069129	3545	Economy	9000.00
0005435069146	3545	Economy	9000.00
0005435069127	3545	Economy	9000.00
0005435069124	3545	Economy	9000.00
0005435069151	3545	Economy	9000.00
0005435069157	3545	Economy	9000.00
0005435069128	3545	Economy	9000.00
0005435069120	3545	Economy	9000.00
0005435925164	3545	Economy	9000.00
0005435718949	3545	Economy	9000.00
0005435925150	3545	Economy	9000.00
0005435069117	3545	Economy	9000.00
0005435069142	3545	Economy	9000.00
0005435925166	3545	Economy	9000.00
0005435069144	3545	Economy	9000.00
0005435069118	3545	Economy	9000.00
0005435069141	3545	Economy	9000.00
0005435718948	3545	Economy	9000.00
0005435069143	3545	Economy	9000.00
0005435069136	3545	Economy	9000.00
0005435069114	3545	Economy	9000.00
0005435069138	3545	Economy	9000.00
0005435069115	3545	Economy	9000.00
0005435069150	3545	Economy	9000.00
0005435718951	3545	Economy	9000.00
0005435069155	3545	Economy	9000.00
0005435069153	3545	Economy	9000.00
0005435925177	3545	Economy	9000.00
0005435069137	3545	Economy	9000.00
0005435069123	3545	Economy	9000.00
0005435068706	15323	Business	26900.00
0005435068702	15323	Business	26900.00
0005435068650	15323	Business	26900.00
0005435068806	15323	Business	26900.00
0005435068731	15323	Business	26900.00
0005435939877	15323	Business	26900.00
0005435068522	15323	Business	26900.00
0005435068502	15323	Business	26900.00
0005435925303	15323	Business	26900.00
0005435068517	15323	Business	26900.00
0005435925302	15323	Economy	9000.00
0005435068669	15323	Economy	9000.00
0005435068622	15323	Economy	9000.00
0005435068648	15323	Economy	9000.00
0005435068701	15323	Economy	9000.00
0005435068760	15323	Economy	9000.00
0005435068721	15323	Economy	9000.00
0005435068694	15323	Economy	9900.00
0005435068681	15323	Economy	9900.00
0005435068398	15323	Economy	9900.00
0005435068653	15323	Economy	9000.00
0005435939878	15323	Economy	9000.00
0005435068672	15323	Economy	9000.00
0005435068516	15323	Economy	9000.00
0005435068722	15323	Economy	9000.00
0005435068399	15323	Economy	9000.00
0005435925299	15323	Economy	9000.00
0005435068514	15323	Economy	9000.00
0005435925301	15323	Economy	9000.00
0005435068523	15323	Economy	9000.00
0005435068695	15323	Economy	9000.00
0005435068932	15323	Economy	9000.00
0005435068665	15323	Economy	9000.00
0005435925295	15323	Economy	9000.00
0005435925300	15323	Economy	9000.00
0005435068506	15323	Economy	9000.00
0005435068332	15323	Economy	9000.00
0005435939880	15323	Economy	9000.00
0005435068649	15323	Economy	9000.00
0005435068606	15323	Economy	9000.00
0005435068507	15323	Economy	9000.00
0005435068521	15323	Economy	9000.00
0005435068687	15323	Economy	9000.00
0005435068512	15323	Economy	9000.00
0005435068513	15323	Economy	9000.00
0005435925297	15323	Economy	9000.00
0005435068691	15323	Economy	9000.00
0005435068461	15323	Economy	9000.00
0005435925296	15323	Economy	9000.00
0005435068757	15323	Economy	9000.00
0005435068749	15323	Economy	9000.00
0005435068686	15323	Economy	9000.00
0005435925304	15323	Economy	9000.00
0005435068486	15323	Economy	9000.00
0005435068515	15323	Economy	9000.00
0005435068485	15323	Economy	9000.00
0005435068503	15323	Economy	9000.00
0005435068696	15323	Economy	9000.00
0005435068663	15323	Economy	9000.00
0005435939881	15323	Economy	9000.00
0005435068596	15323	Economy	9000.00
0005435068424	15323	Economy	9000.00
0005435068680	15323	Economy	9000.00
0005435068758	15323	Economy	9000.00
0005435068785	15323	Economy	9000.00
0005435068608	15323	Economy	9000.00
0005435925298	15323	Economy	9000.00
0005435068805	15323	Economy	9000.00
0005435068743	15323	Economy	9000.00
0005435068662	15323	Economy	9000.00
0005435068575	15323	Economy	9000.00
0005435068623	15323	Economy	9000.00
0005435068484	15323	Economy	9000.00
0005435939879	15323	Economy	9000.00
0005435068878	15323	Economy	9000.00
0005435068586	15323	Economy	9000.00
0005435068682	15323	Economy	9000.00
0005432659708	18111	Economy	5900.00
0005432660819	18111	Economy	5900.00
0005432659707	18111	Economy	5900.00
0005432658593	18111	Economy	5900.00
0005432660820	18111	Economy	5900.00
0005432658594	18111	Economy	5900.00
0005432658592	18111	Economy	5900.00
0005432660797	26425	Economy	5900.00
0005432667443	26425	Economy	5900.00
0005432667434	26425	Economy	5900.00
0005432660799	26425	Economy	5900.00
0005432664117	26425	Economy	5900.00
0005432667439	26425	Economy	5900.00
0005432660803	26425	Economy	5900.00
0005432660801	26425	Economy	5900.00
0005432660800	26425	Economy	5900.00
0005432677531	207	Business	20000.00
0005432919709	207	Business	20000.00
0005433101762	207	Business	20000.00
0005433101817	207	Business	20000.00
0005433101512	207	Business	20000.00
0005433101821	207	Business	20000.00
0005433101759	207	Business	20000.00
0005433101743	207	Business	20000.00
0005433101726	207	Business	20000.00
0005433101835	207	Business	20000.00
0005432919702	207	Business	20000.00
0005432919675	207	Business	20000.00
0005432901489	207	Business	20000.00
0005432919736	207	Business	20000.00
0005433101814	207	Business	20000.00
0005433101781	207	Economy	7300.00
0005433101720	207	Economy	7300.00
0005432919737	207	Economy	7300.00
0005433101772	207	Economy	7300.00
0005433101514	207	Economy	7300.00
0005433101820	207	Economy	6700.00
0005433101815	207	Economy	6700.00
0005433101702	207	Economy	6700.00
0005432901416	207	Economy	6700.00
0005433101626	207	Economy	6700.00
0005432901480	207	Economy	6700.00
0005433101780	207	Economy	6700.00
0005433101811	207	Economy	6700.00
0005433101725	207	Economy	6700.00
0005433101777	207	Economy	6700.00
0005433101776	207	Economy	6700.00
0005432901485	207	Economy	6700.00
0005433101722	207	Economy	6700.00
0005432901423	207	Economy	6700.00
0005433101748	207	Economy	6700.00
0005432901445	207	Economy	6700.00
0005432677548	207	Economy	6700.00
0005433101704	207	Economy	6700.00
0005433101745	207	Economy	6700.00
0005433101464	207	Economy	6700.00
0005432919750	207	Economy	6700.00
0005432901520	207	Economy	6700.00
0005433101578	207	Economy	6700.00
0005433101627	207	Economy	6700.00
0005433101792	207	Economy	6700.00
0005432901452	207	Economy	6700.00
0005433101632	207	Economy	6700.00
0005433101577	207	Economy	6700.00
0005432157493	207	Economy	6700.00
0005432157494	207	Economy	6700.00
0005433101827	207	Economy	6700.00
0005433101741	207	Economy	6700.00
0005433101646	207	Economy	6700.00
0005432901519	207	Economy	6700.00
0005432901453	207	Economy	6700.00
0005432901500	207	Economy	6700.00
0005433101828	207	Economy	6700.00
0005433101538	207	Economy	6700.00
0005432901425	207	Economy	6700.00
0005433101697	207	Economy	6700.00
0005432901499	207	Economy	6700.00
0005432919751	207	Economy	6700.00
0005432919780	207	Economy	7300.00
0005433101630	207	Economy	7300.00
0005432901508	207	Economy	7300.00
0005433101744	207	Economy	7300.00
0005432901415	207	Economy	6700.00
0005432901422	207	Economy	7300.00
0005433101818	207	Economy	6700.00
0005433101841	207	Economy	6700.00
0005433101670	207	Economy	6700.00
0005433101738	207	Economy	6700.00
0005432901429	207	Economy	6700.00
0005432677554	207	Economy	6700.00
0005432901484	207	Economy	6700.00
0005433101513	207	Economy	6700.00
0005432919701	207	Economy	6700.00
0005432901424	207	Economy	6700.00
0005432919677	207	Economy	6700.00
0005432919676	207	Economy	6700.00
0005433101761	207	Economy	6700.00
0005433101760	207	Economy	6700.00
0005432901509	207	Economy	6700.00
0005433101819	207	Economy	6700.00
0005432901551	207	Economy	6700.00
0005433101672	207	Economy	6700.00
0005432901455	207	Economy	6700.00
0005433101631	207	Economy	6700.00
0005433101773	207	Economy	6700.00
0005433101782	207	Economy	6700.00
0005433101537	207	Economy	6700.00
0005433101747	207	Economy	6700.00
0005433101791	207	Economy	6700.00
0005433101746	207	Economy	6700.00
0005433101783	207	Economy	6700.00
0005433101813	207	Economy	6700.00
0005432919734	207	Economy	6700.00
0005433101802	207	Economy	6700.00
0005433101701	207	Economy	6700.00
0005433101769	207	Economy	6700.00
0005433101766	207	Economy	6700.00
0005432901389	207	Economy	6700.00
0005433101724	207	Economy	6700.00
0005433101768	207	Economy	6700.00
0005432919725	207	Economy	6700.00
0005432677532	207	Economy	6700.00
0005432817485	208	Business	20000.00
0005432261933	208	Business	20000.00
0005432817509	208	Business	20000.00
0005433690904	208	Business	20000.00
0005432261975	208	Business	20000.00
0005432288991	208	Business	20000.00
0005432261941	208	Business	20000.00
0005432261974	208	Business	20000.00
0005432817514	208	Business	20000.00
0005432207661	208	Business	20000.00
0005432817511	208	Business	20000.00
0005432756818	208	Business	20000.00
0005432817498	208	Business	20000.00
0005432817489	208	Business	20000.00
0005432753266	208	Business	20000.00
0005432261952	208	Business	20000.00
0005432261948	208	Business	20000.00
0005432261949	208	Business	20000.00
0005432261964	208	Economy	7300.00
0005432261969	208	Economy	7300.00
0005432817493	208	Economy	7300.00
0005433690914	208	Economy	6700.00
0005432817495	208	Economy	6700.00
0005432817510	208	Economy	6700.00
0005432756819	208	Economy	6700.00
0005432261951	208	Economy	6700.00
0005432261966	208	Economy	6700.00
0005432817484	208	Economy	6700.00
0005432261970	208	Economy	6700.00
0005432261972	208	Economy	6700.00
0005432261944	208	Economy	6700.00
0005432261950	208	Economy	6700.00
0005432817492	208	Economy	6700.00
0005432753277	208	Economy	6700.00
0005432817501	208	Economy	6700.00
0005432817503	208	Economy	6700.00
0005432817505	208	Economy	6700.00
0005432817496	208	Economy	6700.00
0005432817513	208	Economy	6700.00
0005432261954	208	Economy	6700.00
0005432261946	208	Economy	6700.00
0005432753264	208	Economy	6700.00
0005432261943	208	Economy	6700.00
0005432261957	208	Economy	6700.00
0005432261961	208	Economy	6700.00
0005432261973	208	Economy	6700.00
0005432261930	208	Economy	6700.00
0005432261955	208	Economy	6700.00
0005432261962	208	Economy	6700.00
0005432817497	208	Economy	6700.00
0005432753270	208	Economy	6700.00
0005432261971	208	Economy	6700.00
0005432817488	208	Economy	6700.00
0005433690907	208	Economy	6700.00
0005432288988	208	Economy	6700.00
0005432261965	208	Economy	6700.00
0005432288990	208	Economy	6700.00
0005432261958	208	Economy	6700.00
0005432261937	208	Economy	6700.00
0005432817499	208	Economy	6700.00
0005432756814	208	Economy	6700.00
0005432817487	208	Economy	7300.00
0005432261953	208	Economy	7300.00
0005432817502	208	Economy	7300.00
0005432817515	208	Economy	7300.00
0005432261967	208	Economy	7300.00
0005432261936	208	Economy	7300.00
0005432817506	208	Economy	6700.00
0005432817507	208	Economy	6700.00
0005432817486	208	Economy	6700.00
0005432261934	208	Economy	6700.00
0005432261959	208	Economy	6700.00
0005433690900	208	Economy	6700.00
0005432261931	208	Economy	6700.00
0005432261956	208	Economy	6700.00
0005432817504	208	Economy	6700.00
0005432817491	208	Economy	6700.00
0005432207662	208	Economy	6700.00
0005432817500	208	Economy	6700.00
0005432753268	208	Economy	6700.00
0005432261940	208	Economy	6700.00
0005432817512	208	Economy	6700.00
0005432261935	208	Economy	6700.00
0005432261938	208	Economy	6700.00
0005433690915	208	Economy	6700.00
0005432261932	208	Economy	6700.00
0005432261968	208	Economy	6700.00
0005432753267	208	Economy	6700.00
0005432817494	208	Economy	6700.00
0005432207663	208	Economy	6700.00
0005432288989	208	Economy	6700.00
0005432261947	208	Economy	6700.00
0005432756812	208	Economy	6700.00
0005432817490	208	Economy	6700.00
0005432817508	208	Economy	6700.00
0005433690916	208	Economy	6700.00
0005432261960	208	Economy	6700.00
0005432756811	208	Economy	6700.00
0005432261939	208	Economy	6700.00
0005432261945	208	Economy	6700.00
0005432261942	208	Economy	6700.00
0005432261963	208	Economy	6700.00
0005433102216	8159	Business	20000.00
0005432919877	8159	Business	20000.00
0005433102173	8159	Business	20000.00
0005432020296	8159	Business	20000.00
0005433102213	8159	Business	20000.00
0005433102239	8159	Business	20000.00
0005432020297	8159	Business	20000.00
0005432045615	8159	Business	20000.00
0005432020284	8159	Business	20000.00
0005433102209	8159	Business	20000.00
0005433102235	8159	Business	20000.00
0005432020282	8159	Business	20000.00
0005433102188	8159	Business	20000.00
0005433102227	8159	Business	20000.00
0005433102176	8159	Business	20000.00
0005433102237	8159	Business	20000.00
0005432044527	8159	Business	20000.00
0005432919874	8159	Business	20000.00
0005432020290	8159	Business	20000.00
0005433102238	8159	Business	20000.00
0005432020285	8159	Economy	7300.00
0005432919883	8159	Economy	7300.00
0005432020286	8159	Economy	6700.00
0005433102218	8159	Economy	6700.00
0005433102186	8159	Economy	6700.00
0005433102199	8159	Economy	6700.00
0005433102189	8159	Economy	6700.00
0005433102180	8159	Economy	6700.00
0005432020273	8159	Economy	6700.00
0005432020294	8159	Economy	6700.00
0005432919881	8159	Economy	6700.00
0005433102195	8159	Economy	6700.00
0005432677578	8159	Economy	6700.00
0005432919885	8159	Economy	6700.00
0005432751531	8159	Economy	6700.00
0005433102193	8159	Economy	6700.00
0005433102229	8159	Economy	6700.00
0005432020276	8159	Economy	6700.00
0005433102224	8159	Economy	6700.00
0005432677579	8159	Economy	6700.00
0005433102222	8159	Economy	6700.00
0005432677580	8159	Economy	6700.00
0005432045616	8159	Economy	6700.00
0005433102204	8159	Economy	6700.00
0005432044528	8159	Economy	6700.00
0005432919876	8159	Economy	6700.00
0005432020295	8159	Economy	6700.00
0005433102232	8159	Economy	6700.00
0005433102198	8159	Economy	6700.00
0005432919873	8159	Economy	6700.00
0005433102228	8159	Economy	6700.00
0005433102225	8159	Economy	6700.00
0005433102200	8159	Economy	6700.00
0005433102202	8159	Economy	6700.00
0005433102230	8159	Economy	6700.00
0005433102182	8159	Economy	6700.00
0005432677577	8159	Economy	6700.00
0005433102231	8159	Economy	6700.00
0005433102223	8159	Economy	6700.00
0005433102226	8159	Economy	6700.00
0005433102217	8159	Economy	6700.00
0005432919869	8159	Economy	6700.00
0005433102190	8159	Economy	6700.00
0005432919871	8159	Economy	6700.00
0005432020274	8159	Economy	6700.00
0005432753305	8159	Economy	6700.00
0005433102233	8159	Economy	6700.00
0005432020283	8159	Economy	6700.00
0005432020281	8159	Economy	7300.00
0005432392003	8159	Economy	6700.00
0005432677581	8159	Economy	7300.00
0005433102212	8159	Economy	7300.00
0005433102219	8159	Economy	7300.00
0005432919870	8159	Economy	7300.00
0005433102177	8159	Economy	6700.00
0005432020299	8159	Economy	6700.00
0005433102206	8159	Economy	6700.00
0005432919880	8159	Economy	7300.00
0005432020298	8159	Economy	6700.00
0005433102181	8159	Economy	6700.00
0005433102215	8159	Economy	6700.00
0005433102236	8159	Economy	6700.00
0005432919878	8159	Economy	6700.00
0005432919884	8159	Economy	6700.00
0005433102208	8159	Economy	6700.00
0005432919868	8159	Economy	6700.00
0005433102175	8159	Economy	6700.00
0005432392002	8159	Economy	6700.00
0005433102210	8159	Economy	6700.00
0005432020289	8159	Economy	6700.00
0005433102183	8159	Economy	6700.00
0005433102205	8159	Economy	6700.00
0005432919886	8159	Economy	6700.00
0005432020278	8159	Economy	6700.00
0005432020275	8159	Economy	6700.00
0005433102194	8159	Economy	6700.00
0005432020291	8159	Economy	6700.00
0005432020288	8159	Economy	6700.00
0005432020293	8159	Economy	6700.00
0005433102220	8159	Economy	6700.00
0005432919887	8159	Economy	6700.00
0005432020287	8159	Economy	6700.00
0005433102172	8159	Economy	6700.00
0005432753303	8159	Economy	6700.00
0005432919879	8159	Economy	6700.00
0005432753306	8159	Economy	6700.00
0005432753304	8159	Economy	6700.00
0005433102197	8159	Economy	6700.00
0005432020277	8159	Economy	6700.00
0005433102178	8159	Economy	6700.00
0005432044526	8159	Economy	6700.00
0005432919875	8159	Economy	6700.00
0005433102185	8159	Economy	6700.00
0005433102192	8159	Economy	6700.00
0005433102179	8159	Economy	6700.00
0005432919872	8159	Economy	6700.00
0005432020280	8159	Economy	6700.00
0005433102207	8159	Economy	6700.00
0005433102234	8159	Economy	6700.00
0005433102214	8159	Economy	6700.00
0005433102187	8159	Economy	6700.00
0005432020292	8159	Economy	6700.00
0005432392004	8159	Economy	6700.00
0005432919882	8159	Economy	6700.00
0005432020279	8159	Economy	6700.00
0005432392001	8159	Economy	6700.00
0005433102191	8159	Economy	6700.00
0005433102174	8159	Economy	6700.00
0005433102211	8159	Economy	6700.00
0005433102201	8159	Economy	6700.00
0005433102184	8159	Economy	6700.00
0005433102203	8159	Economy	6700.00
0005433102221	8159	Economy	6700.00
0005433102196	8159	Economy	6700.00
0005434513557	8160	Business	20000.00
0005432817214	8160	Business	20000.00
0005432817230	8160	Business	20000.00
0005432817127	8160	Business	20000.00
0005432817149	8160	Business	20000.00
0005432901632	8160	Business	20000.00
0005432901622	8160	Business	20000.00
0005434513553	8160	Economy	7300.00
0005432817251	8160	Economy	7300.00
0005434513558	8160	Economy	6700.00
0005432817430	8160	Economy	6700.00
0005432901634	8160	Economy	6700.00
0005432817296	8160	Economy	6700.00
0005432901620	8160	Economy	6700.00
0005432817142	8160	Economy	6700.00
0005432817231	8160	Economy	6700.00
0005432817145	8160	Economy	6700.00
0005432817291	8160	Economy	6700.00
0005432817247	8160	Economy	6700.00
0005432817213	8160	Economy	6700.00
0005434513555	8160	Economy	6700.00
0005432817181	8160	Economy	6700.00
0005434513551	8160	Economy	6700.00
0005432901623	8160	Economy	6700.00
0005432817143	8160	Economy	6700.00
0005432817144	8160	Economy	6700.00
0005432817290	8160	Economy	6700.00
0005432901627	8160	Economy	6700.00
0005432817193	8160	Economy	6700.00
0005432817125	8160	Economy	6700.00
0005432901624	8160	Economy	7300.00
0005432817242	8160	Economy	7300.00
0005432901628	8160	Economy	7300.00
0005434513547	8160	Economy	7300.00
0005432817147	8160	Economy	6700.00
0005432817195	8160	Economy	6700.00
0005432817215	8160	Economy	6700.00
0005432817282	8160	Economy	6700.00
0005432901617	8160	Economy	6700.00
0005434513552	8160	Economy	6700.00
0005432817148	8160	Economy	6700.00
0005432817196	8160	Economy	6700.00
0005432817155	8160	Economy	6700.00
0005432901626	8160	Economy	6700.00
0005432901619	8160	Economy	6700.00
0005432817276	8160	Economy	6700.00
0005432817330	8160	Economy	6700.00
0005432817157	8160	Economy	6700.00
0005432817269	8160	Economy	6700.00
0005432901631	8160	Economy	6700.00
0005432817126	8160	Economy	6700.00
0005434513556	8160	Economy	6700.00
0005432817323	8160	Economy	6700.00
0005432817156	8160	Economy	6700.00
0005432901621	8160	Economy	6700.00
0005432901633	8160	Economy	6700.00
0005434513554	8160	Economy	6700.00
0005432817180	8160	Economy	6700.00
0005432901625	8160	Economy	6700.00
0005432901629	8160	Economy	6700.00
0005432901618	8160	Economy	6700.00
0005432817324	8160	Economy	6700.00
0005432901630	8160	Economy	6700.00
0005434513573	8160	Economy	6700.00
0005432817250	8160	Economy	6700.00
0005433870733	9691	Economy	6900.00
0005434175710	9691	Economy	6900.00
0005434175700	9691	Economy	6900.00
0005434175718	9691	Economy	6900.00
0005434175717	9691	Economy	6900.00
0005434175731	9691	Economy	6900.00
0005433870732	9691	Economy	6900.00
0005434175758	32326	Economy	6900.00
0005434175756	32326	Economy	6900.00
0005433870720	32326	Economy	6900.00
0005434175757	32326	Economy	6900.00
0005434175755	32326	Economy	6900.00
0005432799481	3479	Business	35000.00
0005434878315	3479	Business	35000.00
0005434878379	3479	Business	35000.00
0005434878322	3479	Business	35000.00
0005435126427	3479	Business	35000.00
0005434878347	3479	Business	35000.00
0005434938158	3479	Business	35000.00
0005432799501	3479	Business	35000.00
0005434426631	3479	Business	35000.00
0005435902489	3479	Business	35000.00
0005434878331	3479	Business	35000.00
0005434426641	3479	Business	35000.00
0005434878357	3479	Business	35000.00
0005435126421	3479	Business	35000.00
0005434878387	3479	Business	35000.00
0005434878352	3479	Business	35000.00
0005434878336	3479	Business	35000.00
0005434878348	3479	Business	35000.00
0005435902517	3479	Business	35000.00
0005434878334	3479	Business	35000.00
0005434878313	3479	Business	35000.00
0005435626186	3479	Business	35000.00
0005435902620	3479	Business	35000.00
0005432799500	3479	Business	35000.00
0005434878303	3479	Business	35000.00
0005435902562	3479	Comfort	19900.00
0005435126408	3479	Comfort	19900.00
0005435626188	3479	Comfort	19900.00
0005435126425	3479	Comfort	19900.00
0005435126435	3479	Comfort	19900.00
0005434426649	3479	Comfort	19900.00
0005434426629	3479	Comfort	19900.00
0005434878314	3479	Comfort	19900.00
0005435902598	3479	Comfort	19900.00
0005435913880	3479	Comfort	19900.00
0005435626191	3479	Comfort	19900.00
0005435126405	3479	Comfort	19900.00
0005432613866	3479	Comfort	19900.00
0005434426639	3479	Comfort	19900.00
0005434878321	3479	Comfort	19900.00
0005435626180	3479	Comfort	19900.00
0005434878361	3479	Comfort	19900.00
0005434878301	3479	Comfort	19900.00
0005435902523	3479	Comfort	19900.00
0005434878376	3479	Comfort	19900.00
0005432183470	3479	Comfort	19900.00
0005432799484	3479	Comfort	19900.00
0005434938168	3479	Comfort	19900.00
0005435126397	3479	Comfort	19900.00
0005434878358	3479	Comfort	19900.00
0005435126429	3479	Comfort	19900.00
0005432799475	3479	Comfort	19900.00
0005432799476	3479	Comfort	19900.00
0005435126401	3479	Comfort	19900.00
0005435126403	3479	Comfort	19900.00
0005434426630	3479	Comfort	19900.00
0005435126434	3479	Economy	11700.00
0005434426653	3479	Economy	11700.00
0005435626179	3479	Economy	11700.00
0005434938159	3479	Economy	11700.00
0005435126411	3479	Economy	11700.00
0005434878327	3479	Economy	11700.00
0005432183469	3479	Economy	11700.00
0005434878382	3479	Economy	11700.00
0005435626178	3479	Economy	11700.00
0005434938156	3479	Economy	11700.00
0005434878299	3479	Economy	11700.00
0005434878312	3479	Economy	11700.00
0005434938155	3479	Economy	11700.00
0005434878378	3479	Economy	11700.00
0005434878345	3479	Economy	11700.00
0005435126433	3479	Economy	11700.00
0005432799491	3479	Economy	11700.00
0005435841814	3479	Economy	11700.00
0005432799496	3479	Economy	11700.00
0005434878326	3479	Economy	11700.00
0005434426647	3479	Economy	11700.00
0005432611714	3479	Economy	11700.00
0005435902560	3479	Economy	11700.00
0005434878349	3479	Economy	11700.00
0005434878324	3479	Economy	11700.00
0005435902566	3479	Economy	11700.00
0005434426644	3479	Economy	11700.00
0005434878388	3479	Economy	11700.00
0005432799498	3479	Economy	11700.00
0005435126402	3479	Economy	11700.00
0005434878338	3479	Economy	11700.00
0005434878363	3479	Economy	11700.00
0005432799473	3479	Economy	11700.00
0005432799497	3479	Economy	11700.00
0005434878300	3479	Economy	11700.00
0005434878384	3479	Economy	11700.00
0005434426645	3479	Economy	11700.00
0005435902520	3479	Economy	11700.00
0005435902559	3479	Economy	11700.00
0005434426633	3479	Economy	11700.00
0005432799478	3479	Economy	11700.00
0005434938166	3479	Economy	11700.00
0005435126399	3479	Economy	11700.00
0005434938157	3479	Economy	11700.00
0005435626184	3479	Economy	11700.00
0005435902602	3479	Economy	11700.00
0005435902563	3479	Economy	11700.00
0005434878307	3479	Economy	11700.00
0005432188611	3479	Economy	11700.00
0005435626176	3479	Economy	12800.00
0005435626182	3479	Economy	12800.00
0005434878305	3479	Economy	11700.00
0005434878366	3479	Economy	11700.00
0005434938163	3479	Economy	11700.00
0005432799494	3479	Economy	11700.00
0005434938161	3479	Economy	11700.00
0005434426640	3479	Economy	11700.00
0005434878320	3479	Economy	11700.00
0005435902484	3479	Economy	11700.00
0005435126430	3479	Economy	11700.00
0005434878302	3479	Economy	11700.00
0005435126418	3479	Economy	11700.00
0005434938160	3479	Economy	11700.00
0005434878377	3479	Economy	11700.00
0005434426638	3479	Economy	11700.00
0005432799483	3479	Economy	11700.00
0005435126417	3479	Economy	11700.00
0005435126416	3479	Economy	11700.00
0005434878309	3479	Economy	11700.00
0005435913886	3479	Economy	11700.00
0005435913888	3479	Economy	11700.00
0005434426636	3479	Economy	11700.00
0005434878381	3479	Economy	11700.00
0005435626192	3479	Economy	11700.00
0005434938165	3479	Economy	11700.00
0005434878367	3479	Economy	11700.00
0005435126412	3479	Economy	11700.00
0005434878389	3479	Economy	11700.00
0005434878362	3479	Economy	11700.00
0005434938171	3479	Economy	11700.00
0005434878319	3479	Economy	11700.00
0005434938169	3479	Economy	11700.00
0005434878335	3479	Economy	11700.00
0005435126404	3479	Economy	11700.00
0005435902524	3479	Economy	11700.00
0005432188612	3479	Economy	11700.00
0005434878342	3479	Economy	11700.00
0005435626177	3479	Economy	11700.00
0005434426652	3479	Economy	11700.00
0005434878340	3479	Economy	11700.00
0005435126409	3479	Economy	11700.00
0005435902538	3479	Economy	11700.00
0005434426632	3479	Economy	11700.00
0005434878337	3479	Economy	11700.00
0005434878355	3479	Economy	11700.00
0005434878359	3479	Economy	11700.00
0005435126406	3479	Economy	11700.00
0005434426627	3479	Economy	11700.00
0005434426650	3479	Economy	11700.00
0005435126415	3479	Economy	11700.00
0005432799490	3479	Economy	11700.00
0005432611716	3479	Economy	11700.00
0005435126420	3479	Economy	11700.00
0005434878350	3479	Economy	11700.00
0005435913881	3479	Economy	11700.00
0005435626185	3479	Economy	11700.00
0005435126413	3479	Economy	11700.00
0005435902534	3479	Economy	11700.00
0005434878310	3479	Economy	11700.00
0005434878325	3479	Economy	11700.00
0005432799479	3479	Economy	11700.00
0005434878304	3479	Economy	11700.00
0005434938172	3479	Economy	11700.00
0005432799493	3479	Economy	11700.00
0005432799488	3479	Economy	11700.00
0005434426643	3479	Economy	11700.00
0005435126436	3479	Economy	11700.00
0005432799489	3479	Economy	11700.00
0005432799495	3479	Economy	11700.00
0005434938164	3479	Economy	11700.00
0005434426628	3479	Economy	11700.00
0005434878375	3479	Economy	11700.00
0005434878323	3479	Economy	11700.00
0005434878341	3479	Economy	11700.00
0005435913872	3479	Economy	11700.00
0005434426642	3479	Economy	11700.00
0005435626187	3479	Economy	11700.00
0005434878380	3479	Economy	11700.00
0005435626175	3479	Economy	11700.00
0005432613867	3479	Economy	12800.00
0005435626174	3479	Economy	12800.00
0005435626190	3479	Economy	12800.00
0005435126428	3479	Economy	12800.00
0005434878385	3479	Economy	11700.00
0005435126400	3479	Economy	11700.00
0005432611713	3479	Economy	11700.00
0005432799477	3479	Economy	11700.00
0005434426648	3479	Economy	11700.00
0005432799492	3479	Economy	11700.00
0005434426654	3479	Economy	11700.00
0005434938154	3479	Economy	11700.00
0005435126437	3479	Economy	11700.00
0005434426651	3479	Economy	11700.00
0005434878344	3479	Economy	11700.00
0005432799482	3479	Economy	11700.00
0005434878356	3479	Economy	11700.00
0005434878383	3479	Economy	11700.00
0005434878333	3479	Economy	11700.00
0005432183468	3479	Economy	11700.00
0005434878346	3479	Economy	11700.00
0005434878360	3479	Economy	11700.00
0005434878368	3479	Economy	11700.00
0005434878354	3479	Economy	11700.00
0005434426635	3479	Economy	11700.00
0005434878308	3479	Economy	11700.00
0005435913887	3479	Economy	11700.00
0005434878306	3479	Economy	11700.00
0005434878369	3479	Economy	11700.00
0005434878370	3479	Economy	11700.00
0005434878328	3479	Economy	11700.00
0005434878364	3479	Economy	11700.00
0005434878311	3479	Economy	11700.00
0005432799487	3479	Economy	11700.00
0005434878329	3479	Economy	11700.00
0005435902483	3479	Economy	11700.00
0005434938153	3479	Economy	11700.00
0005434938162	3479	Economy	11700.00
0005434938173	3479	Economy	11700.00
0005434426634	3479	Economy	11700.00
0005435626189	3479	Economy	11700.00
0005434878365	3479	Economy	11700.00
0005435126432	3479	Economy	11700.00
0005435902533	3479	Economy	11700.00
0005434878318	3479	Economy	11700.00
0005435902587	3479	Economy	11700.00
0005435126419	3479	Economy	11700.00
0005434878317	3479	Economy	11700.00
0005432799485	3479	Economy	11700.00
0005434878374	3479	Economy	11700.00
0005435126423	3479	Economy	11700.00
0005434878343	3479	Economy	11700.00
0005435126410	3479	Economy	11700.00
0005434938167	3479	Economy	11700.00
0005435126431	3479	Economy	11700.00
0005434878332	3479	Economy	11700.00
0005432799474	3479	Economy	11700.00
0005434878339	3479	Economy	11700.00
0005435126424	3479	Economy	11700.00
0005435126414	3479	Economy	11700.00
0005434878372	3479	Economy	11700.00
0005434878371	3479	Economy	11700.00
0005435126422	3479	Economy	11700.00
0005435126396	3479	Economy	11700.00
0005434426646	3479	Economy	11700.00
0005434426656	3479	Economy	11700.00
0005434938170	3479	Economy	11700.00
0005434878330	3479	Economy	11700.00
0005434878351	3479	Economy	11700.00
0005432799499	3479	Economy	11700.00
0005432611715	3479	Economy	11700.00
0005434878353	3479	Economy	11700.00
0005434878316	3479	Economy	11700.00
0005432613865	3479	Economy	11700.00
0005432799480	3479	Economy	11700.00
0005435902535	3479	Economy	11700.00
0005434426637	3479	Economy	11700.00
0005435126398	3479	Economy	11700.00
0005435126407	3479	Economy	11700.00
0005435626181	3479	Economy	11700.00
0005434426655	3479	Economy	11700.00
0005434878373	3479	Economy	11700.00
0005432799486	3479	Economy	11700.00
0005435626183	3479	Economy	11700.00
0005434878386	3479	Economy	11700.00
0005435902567	3479	Economy	11700.00
0005435126426	3479	Economy	11700.00
0005435626024	14556	Business	35000.00
0005435626000	14556	Business	35000.00
0005435902718	14556	Business	35000.00
0005432607524	14556	Business	35000.00
0005434877529	14556	Business	35000.00
0005435125719	14556	Business	35000.00
0005432799174	14556	Business	35000.00
0005432799413	14556	Business	35000.00
0005432799289	14556	Business	35000.00
0005434877692	14556	Business	35000.00
0005434877257	14556	Business	35000.00
0005432799270	14556	Business	35000.00
0005432799284	14556	Business	35000.00
0005434426441	14556	Business	35000.00
0005434937922	14556	Business	35000.00
0005435125966	14556	Business	35000.00
0005435125952	14556	Business	35000.00
0005435626001	14556	Business	35000.00
0005435126064	14556	Business	35000.00
0005432799176	14556	Comfort	19900.00
0005434877718	14556	Comfort	19900.00
0005435126015	14556	Comfort	19900.00
0005435902719	14556	Comfort	19900.00
0005435126089	14556	Comfort	19900.00
0005434877141	14556	Comfort	19900.00
0005435126071	14556	Comfort	19900.00
0005432799241	14556	Comfort	19900.00
0005435126199	14556	Comfort	19900.00
0005434878090	14556	Comfort	19900.00
0005434938061	14556	Comfort	19900.00
0005434426385	14556	Comfort	19900.00
0005434877344	14556	Comfort	19900.00
0005434426211	14556	Comfort	19900.00
0005434426439	14556	Comfort	19900.00
0005435126198	14556	Comfort	19900.00
0005434938007	14556	Comfort	19900.00
0005434877532	14556	Comfort	19900.00
0005434877485	14556	Comfort	19900.00
0005432611679	14556	Comfort	19900.00
0005435126145	14556	Comfort	19900.00
0005434877410	14556	Comfort	19900.00
0005435902727	14556	Comfort	19900.00
0005434877471	14556	Comfort	19900.00
0005434877370	14556	Comfort	19900.00
0005434877489	14556	Comfort	19900.00
0005435626022	14556	Comfort	19900.00
0005435902726	14556	Comfort	19900.00
0005432799364	14556	Comfort	19900.00
0005434426379	14556	Comfort	19900.00
0005434877423	14556	Comfort	19900.00
0005434877656	14556	Comfort	19900.00
0005435126048	14556	Comfort	19900.00
0005435125893	14556	Comfort	19900.00
0005435126008	14556	Economy	11700.00
0005432799285	14556	Comfort	19900.00
0005434877144	14556	Economy	11700.00
0005435125954	14556	Economy	11700.00
0005432799228	14556	Economy	11700.00
0005435126009	14556	Economy	11700.00
0005434426430	14556	Economy	11700.00
0005435126000	14556	Economy	11700.00
0005434938023	14556	Economy	11700.00
0005432607513	14556	Economy	11700.00
0005434877102	14556	Economy	11700.00
0005434426397	14556	Economy	11700.00
0005432799276	14556	Economy	11700.00
0005434937930	14556	Economy	11700.00
0005434426445	14556	Economy	11700.00
0005432611661	14556	Economy	11700.00
0005435125953	14556	Economy	11700.00
0005435125877	14556	Economy	11700.00
0005435902725	14556	Economy	11700.00
0005435902712	14556	Economy	11700.00
0005434877637	14556	Economy	11700.00
0005435902720	14556	Economy	11700.00
0005434877487	14556	Economy	11700.00
0005435902716	14556	Economy	11700.00
0005434877337	14556	Economy	11700.00
0005434426447	14556	Economy	11700.00
0005435125924	14556	Economy	11700.00
0005434877240	14556	Economy	11700.00
0005435902715	14556	Economy	11700.00
0005432799309	14556	Economy	11700.00
0005432799307	14556	Economy	11700.00
0005432799184	14556	Economy	11700.00
0005435126069	14556	Economy	11700.00
0005434426442	14556	Economy	11700.00
0005434426461	14556	Economy	11700.00
0005432799310	14556	Economy	11700.00
0005434877433	14556	Economy	11700.00
0005434878057	14556	Economy	11700.00
0005435913937	14556	Economy	11700.00
0005434877364	14556	Economy	11700.00
0005435902717	14556	Economy	11700.00
0005435125981	14556	Economy	11700.00
0005435125948	14556	Economy	11700.00
0005434426243	14556	Economy	11700.00
0005435125835	14556	Economy	11700.00
0005435913939	14556	Economy	11700.00
0005434877481	14556	Economy	11700.00
0005434877204	14556	Economy	11700.00
0005435626023	14556	Economy	11700.00
0005434937976	14556	Economy	11700.00
0005434877681	14556	Economy	11700.00
0005435125916	14556	Economy	11700.00
0005434877448	14556	Economy	11700.00
0005434938004	14556	Economy	11700.00
0005435902713	14556	Economy	11700.00
0005434426443	14556	Economy	12800.00
0005434877422	14556	Economy	11700.00
0005435626010	14556	Economy	12800.00
0005434877402	14556	Economy	11700.00
0005435125949	14556	Economy	12800.00
0005432799306	14556	Economy	11700.00
0005434877203	14556	Economy	12800.00
0005434937977	14556	Economy	12800.00
0005434877689	14556	Economy	11700.00
0005434877690	14556	Economy	11700.00
0005434877726	14556	Economy	11700.00
0005434877345	14556	Economy	11700.00
0005435126020	14556	Economy	11700.00
0005434877466	14556	Economy	11700.00
0005432799365	14556	Economy	11700.00
0005434426503	14556	Economy	11700.00
0005434877507	14556	Economy	11700.00
0005434877636	14556	Economy	11700.00
0005434938008	14556	Economy	11700.00
0005434877319	14556	Economy	11700.00
0005435902724	14556	Economy	11700.00
0005434877706	14556	Economy	11700.00
0005434877568	14556	Economy	11700.00
0005434426409	14556	Economy	11700.00
0005432607523	14556	Economy	11700.00
0005434877336	14556	Economy	11700.00
0005434877586	14556	Economy	11700.00
0005434877241	14556	Economy	11700.00
0005432611680	14556	Economy	11700.00
0005435125923	14556	Economy	11700.00
0005432799186	14556	Economy	11700.00
0005435626025	14556	Economy	11700.00
0005434426336	14556	Economy	11700.00
0005435626030	14556	Economy	11700.00
0005434877407	14556	Economy	11700.00
0005434426244	14556	Economy	11700.00
0005434426319	14556	Economy	11700.00
0005434937979	14556	Economy	11700.00
0005432799347	14556	Economy	11700.00
0005434877317	14556	Economy	11700.00
0005432799412	14556	Economy	11700.00
0005434937980	14556	Economy	11700.00
0005434877727	14556	Economy	11700.00
0005434426407	14556	Economy	11700.00
0005435625980	14556	Economy	11700.00
0005435126059	14556	Economy	11700.00
0005434426335	14556	Economy	11700.00
0005432799294	14556	Economy	11700.00
0005434938025	14556	Economy	11700.00
0005434877480	14556	Economy	11700.00
0005434877173	14556	Economy	11700.00
0005435125892	14556	Economy	11700.00
0005434937978	14556	Economy	11700.00
0005434877357	14556	Economy	11700.00
0005432799275	14556	Economy	11700.00
0005432611664	14556	Economy	11700.00
0005435902722	14556	Economy	11700.00
0005434877592	14556	Economy	11700.00
0005432059506	14556	Economy	11700.00
0005434876851	14556	Economy	11700.00
0005435125965	14556	Economy	11700.00
0005434877560	14556	Economy	11700.00
0005435625989	14556	Economy	11700.00
0005432799260	14556	Economy	11700.00
0005435626020	14556	Economy	11700.00
0005432799268	14556	Economy	11700.00
0005435902714	14556	Economy	11700.00
0005434876852	14556	Economy	11700.00
0005434877369	14556	Economy	11700.00
0005435902728	14556	Economy	11700.00
0005434877199	14556	Economy	11700.00
0005432607514	14556	Economy	11700.00
0005435626014	14556	Economy	11700.00
0005434938050	14556	Economy	11700.00
0005435126115	14556	Economy	11700.00
0005434877569	14556	Economy	11700.00
0005434877691	14556	Economy	11700.00
0005434877503	14556	Economy	11700.00
0005435125988	14556	Economy	11700.00
0005434877531	14556	Economy	11700.00
0005434877722	14556	Economy	11700.00
0005435126050	14556	Economy	11700.00
0005435125933	14556	Economy	11700.00
0005434938024	14556	Economy	11700.00
0005434877685	14556	Economy	11700.00
0005434877231	14556	Economy	11700.00
0005434877555	14556	Economy	11700.00
0005434877514	14556	Economy	11700.00
0005432059508	14556	Economy	12800.00
0005434877205	14556	Economy	11700.00
0005435626018	14556	Economy	12800.00
0005432799245	14556	Economy	12800.00
0005434426396	14556	Economy	12800.00
0005435625917	14556	Economy	12800.00
0005434937975	14556	Economy	11700.00
0005432799366	14556	Economy	11700.00
0005434877585	14556	Economy	11700.00
0005432799281	14556	Economy	11700.00
0005434426369	14556	Economy	11700.00
0005435902721	14556	Economy	11700.00
0005434426356	14556	Economy	11700.00
0005434426429	14556	Economy	11700.00
0005432799374	14556	Economy	11700.00
0005435625953	14556	Economy	11700.00
0005434426457	14556	Economy	11700.00
0005434877633	14556	Economy	11700.00
0005434877565	14556	Economy	11700.00
0005434426357	14556	Economy	11700.00
0005432799269	14556	Economy	11700.00
0005435126099	14556	Economy	11700.00
0005434426212	14556	Economy	11700.00
0005434877069	14556	Economy	11700.00
0005435126149	14556	Economy	11700.00
0005434877764	14556	Economy	11700.00
0005435626011	14556	Economy	11700.00
0005434877251	14556	Economy	11700.00
0005435626036	14556	Economy	11700.00
0005435625993	14556	Economy	11700.00
0005432799367	14556	Economy	11700.00
0005435126090	14556	Economy	11700.00
0005434426446	14556	Economy	11700.00
0005432799198	14556	Economy	11700.00
0005435125987	14556	Economy	11700.00
0005434877643	14556	Economy	11700.00
0005434426242	14556	Economy	11700.00
0005434877827	14556	Economy	11700.00
0005435126078	14556	Economy	11700.00
0005434877441	14556	Economy	11700.00
0005432799177	14556	Economy	11700.00
0005434877258	14556	Economy	11700.00
0005434426215	14556	Economy	11700.00
0005435626016	14556	Economy	11700.00
0005432611662	14556	Economy	11700.00
0005432799175	14556	Economy	11700.00
0005434426413	14556	Economy	11700.00
0005434877476	14556	Economy	11700.00
0005434877682	14556	Economy	11700.00
0005434938009	14556	Economy	11700.00
0005432799055	14556	Economy	11700.00
0005434426465	14556	Economy	11700.00
0005434938003	14556	Economy	11700.00
0005435126142	14556	Economy	11700.00
0005434426337	14556	Economy	11700.00
0005435625981	14556	Economy	11700.00
0005432607532	14556	Economy	11700.00
0005432059507	14556	Economy	11700.00
0005434877358	14556	Economy	11700.00
0005435913938	14556	Economy	11700.00
0005432799242	14556	Economy	11700.00
0005432607535	14556	Economy	11700.00
0005434877470	14556	Economy	11700.00
0005432799134	14556	Economy	11700.00
0005435125982	14556	Economy	11700.00
0005435902729	14556	Economy	11700.00
0005434426431	14556	Economy	11700.00
0005432607550	14556	Economy	11700.00
0005434877528	14556	Economy	11700.00
0005435126228	14556	Economy	11700.00
0005435126049	14556	Economy	11700.00
0005432799411	14556	Economy	11700.00
0005435902723	14556	Economy	11700.00
0005434426289	14556	Economy	11700.00
0005434877318	14556	Economy	11700.00
0005434877250	14556	Economy	11700.00
0005434877547	14556	Economy	11700.00
0005435626021	14556	Economy	11700.00
0005434426360	14556	Economy	11700.00
0005434877259	14556	Economy	11700.00
0005432799246	14556	Economy	11700.00
0005434426501	14556	Economy	11700.00
0005434325664	3595	Economy	14800.00
0005434325666	3595	Economy	14800.00
0005434312320	3595	Economy	14800.00
0005435889835	3595	Economy	14800.00
0005434325656	3595	Economy	14800.00
0005434325662	3595	Economy	14800.00
0005435889862	3595	Economy	14800.00
0005434325658	3595	Economy	14800.00
0005434325665	3595	Economy	14800.00
0005435889863	3595	Economy	14800.00
0005434312321	3595	Economy	14800.00
0005434325661	3595	Economy	14800.00
0005434325659	3595	Economy	14800.00
0005434325667	3595	Economy	14800.00
0005434325660	3595	Economy	14800.00
0005434325663	3595	Economy	14800.00
0005435889861	3595	Economy	14800.00
0005434325657	3595	Economy	14800.00
0005435889868	3595	Economy	14800.00
0005434325573	15611	Economy	16300.00
0005434325578	15611	Economy	16300.00
0005434325597	15611	Economy	14800.00
0005435889903	15611	Economy	14800.00
0005435889902	15611	Economy	14800.00
0005435889905	15611	Economy	14800.00
0005434325600	15611	Economy	14800.00
0005434325611	15611	Economy	14800.00
0005434325485	15611	Economy	14800.00
0005434325610	15611	Economy	14800.00
0005434325538	15611	Economy	14800.00
0005435889901	15611	Economy	14800.00
0005434325582	15611	Economy	14800.00
0005435889900	15611	Economy	14800.00
0005434325484	15611	Economy	14800.00
0005435889904	15611	Economy	14800.00
0005434325545	15611	Economy	14800.00
0005434325483	15611	Economy	14800.00
0005435957723	640	Economy	4500.00
0005433420351	640	Economy	4500.00
0005433420341	640	Economy	4500.00
0005435957717	640	Economy	4100.00
0005433420332	640	Economy	4100.00
0005433420314	640	Economy	4100.00
0005435957710	640	Economy	4100.00
0005435957719	640	Economy	4100.00
0005435957720	640	Economy	4100.00
0005435957725	640	Economy	4100.00
0005433420333	640	Economy	4100.00
0005435957713	640	Economy	4100.00
0005435957714	640	Economy	4100.00
0005435957712	640	Economy	4100.00
0005435957724	640	Economy	4100.00
0005433420347	640	Economy	4100.00
0005435957715	640	Economy	4100.00
0005435957721	640	Economy	4100.00
0005435957711	640	Economy	4100.00
0005435957718	640	Economy	4100.00
0005433420352	640	Economy	4100.00
0005435957722	640	Economy	4100.00
0005433420331	640	Economy	4100.00
0005435957716	640	Economy	4100.00
0005433420414	15197	Economy	4500.00
0005435957573	15197	Economy	4500.00
0005435957594	15197	Economy	4100.00
0005433420408	15197	Economy	4100.00
0005433420407	15197	Economy	4100.00
0005435957519	15197	Economy	4100.00
0005435957629	15197	Economy	4100.00
0005435957572	15197	Economy	4100.00
0005433420410	15197	Economy	4100.00
0005435957654	15197	Economy	4100.00
0005435957625	15197	Economy	4100.00
0005435957656	15197	Economy	4100.00
0005435957596	15197	Economy	4100.00
0005433420413	15197	Economy	4100.00
0005435957621	15197	Economy	4100.00
0005435957655	15197	Economy	4100.00
0005433420411	15197	Economy	4100.00
0005435957624	15197	Economy	4100.00
0005433420412	15197	Economy	4100.00
0005435957595	15197	Economy	4100.00
0005433420409	15197	Economy	4100.00
0005435221047	27267	Economy	28100.00
0005435216568	27267	Economy	28100.00
0005435221042	27267	Economy	28100.00
0005435219179	27267	Economy	25500.00
0005435216562	27267	Economy	25500.00
0005435221041	27267	Economy	25500.00
0005435216561	27267	Economy	25500.00
0005435219183	27267	Economy	25500.00
0005435216571	27267	Economy	25500.00
0005435219188	27267	Economy	25500.00
0005435221044	27267	Economy	25500.00
0005435219182	27267	Economy	25500.00
0005435216567	27267	Economy	25500.00
0005435216575	27267	Economy	25500.00
0005435219178	27267	Economy	25500.00
0005435216556	27267	Economy	25500.00
0005435221043	27267	Economy	25500.00
0005435219175	27267	Economy	25500.00
0005435219170	27267	Economy	25500.00
0005435221048	27267	Economy	25500.00
0005435216557	27267	Economy	25500.00
0005435219166	27267	Economy	25500.00
0005435216574	27267	Economy	25500.00
0005435216563	27267	Economy	25500.00
0005435221045	27267	Economy	25500.00
0005435221049	27267	Economy	25500.00
0005434247130	8897	Economy	10400.00
0005434247135	8897	Economy	10400.00
0005434247117	8897	Economy	10400.00
0005435629403	8897	Economy	10400.00
0005434247127	8897	Economy	10400.00
0005434247131	8897	Economy	10400.00
0005434247123	8897	Economy	10400.00
0005435629396	16073	Economy	10400.00
0005435163237	4426	Economy	13400.00
0005435163233	4426	Economy	12200.00
0005435163238	4426	Economy	12200.00
0005435933436	4426	Economy	12200.00
0005435163236	4426	Economy	12200.00
0005435933443	4426	Economy	12200.00
0005435163234	4426	Economy	12200.00
0005435163240	4426	Economy	12200.00
0005435163239	4426	Economy	12200.00
0005435933425	4426	Economy	12200.00
0005435933424	4426	Economy	12200.00
0005435163232	4426	Economy	12200.00
0005435933433	4426	Economy	12200.00
0005435163235	4426	Economy	12200.00
0005435933442	4426	Economy	12200.00
0005435933430	4426	Economy	12200.00
0005435933435	4426	Economy	12200.00
0005435933434	4426	Economy	12200.00
0005435163231	4426	Economy	12200.00
0005433404759	2878	Business	12600.00
0005433404752	2878	Business	12600.00
0005435797493	2878	Business	12600.00
0005433404756	2878	Business	12600.00
0005433404737	2878	Economy	4200.00
0005435797491	2878	Economy	4200.00
0005433404751	2878	Economy	4200.00
0005433404736	2878	Economy	4200.00
0005433404750	2878	Economy	4200.00
0005435797484	2878	Economy	4200.00
0005433404747	2878	Economy	4200.00
0005435797486	2878	Economy	4200.00
0005435797490	2878	Economy	4200.00
0005433404745	2878	Economy	4200.00
0005435797494	2878	Economy	4200.00
0005435797488	2878	Economy	4200.00
0005433404766	2878	Economy	4200.00
0005435797496	2878	Economy	4200.00
0005435797492	2878	Economy	4200.00
0005435797489	2878	Economy	4200.00
0005433404746	2878	Economy	4200.00
0005433404757	2878	Economy	4200.00
0005435797483	2878	Economy	4200.00
0005433404749	2878	Economy	4200.00
0005433404744	2878	Economy	4200.00
0005433404769	2878	Economy	4200.00
0005433404748	2878	Economy	4200.00
0005435797495	2878	Economy	4200.00
0005433404758	2878	Economy	4200.00
0005435797485	2878	Economy	4200.00
0005435797487	2878	Economy	4200.00
0005435797482	2878	Economy	4200.00
0005435797399	29317	Business	12600.00
0005435797397	29317	Business	12600.00
0005435797422	29317	Business	12600.00
0005435797439	29317	Economy	4200.00
0005435797377	29317	Economy	4200.00
0005435797419	29317	Economy	4200.00
0005435797398	29317	Economy	4200.00
0005435797438	29317	Economy	4200.00
0005435797402	29317	Economy	4200.00
0005433404816	29317	Economy	4200.00
0005435797323	29317	Economy	4200.00
0005435797418	29317	Economy	4200.00
0005433404817	29317	Economy	4200.00
0005433404814	29317	Economy	4200.00
0005433404818	29317	Economy	4200.00
0005435797328	29317	Economy	4200.00
0005433404815	29317	Economy	4200.00
0005433404820	29317	Economy	4200.00
0005433404819	29317	Economy	4200.00
0005435797432	29317	Economy	4200.00
0005435797414	29317	Economy	4200.00
0005435376340	5819	Economy	6800.00
0005435376327	5819	Economy	6800.00
0005435376326	5819	Economy	6800.00
0005434948030	5752	Economy	6800.00
0005434948027	5752	Economy	6800.00
0005434948034	5752	Economy	6800.00
0005434948033	5752	Economy	6800.00
0005434948028	5752	Economy	6800.00
0005434948031	5752	Economy	6800.00
0005434948029	5752	Economy	6800.00
0005434948032	5752	Economy	6800.00
0005434947974	16354	Economy	6800.00
0005434947933	16354	Economy	6800.00
0005434947943	16354	Economy	6800.00
0005434947944	16354	Economy	6800.00
0005434947985	16354	Economy	6800.00
0005434947977	16354	Economy	6800.00
0005434947957	16354	Economy	6800.00
0005434947975	16354	Economy	6800.00
0005434947984	16354	Economy	6800.00
0005434947976	16354	Economy	6800.00
0005434947972	16354	Economy	6800.00
0005434947973	16354	Economy	6800.00
0005433960937	6908	Business	21400.00
0005433960932	6908	Business	21400.00
0005433960933	6908	Business	21400.00
0005433960944	6908	Business	21400.00
0005433960924	6908	Business	21400.00
0005433960948	6908	Business	21400.00
0005433960942	6908	Economy	7100.00
0005433960916	6908	Economy	7100.00
0005433960939	6908	Economy	7100.00
0005433960935	6908	Economy	7100.00
0005433960929	6908	Economy	7100.00
0005433960920	6908	Economy	7100.00
0005433960923	6908	Economy	7800.00
0005433960917	6908	Economy	7800.00
0005433960967	6908	Economy	7100.00
0005433960957	6908	Economy	7100.00
0005433960936	6908	Economy	7100.00
0005433960913	6908	Economy	7100.00
0005433960941	6908	Economy	7100.00
0005433960925	6908	Economy	7100.00
0005433960960	6908	Economy	7100.00
0005433960926	6908	Economy	7100.00
0005433960927	6908	Economy	7100.00
0005433960959	6908	Economy	7100.00
0005433960915	6908	Economy	7100.00
0005433960958	6908	Economy	7100.00
0005433960954	6908	Economy	7100.00
0005433960964	6908	Economy	7100.00
0005433960921	6908	Economy	7100.00
0005433960922	6908	Economy	7100.00
0005433960952	6908	Economy	7100.00
0005433960972	6908	Economy	7100.00
0005433960961	6908	Economy	7100.00
0005433960947	6908	Economy	7100.00
0005433960962	6908	Economy	7100.00
0005433960971	6908	Economy	7100.00
0005433960951	6908	Economy	7100.00
0005433960950	6908	Economy	7100.00
0005433960953	6908	Economy	7100.00
0005433960965	6908	Economy	7100.00
0005433960934	6908	Economy	7100.00
0005433960931	6908	Economy	7100.00
0005433960914	6908	Economy	7100.00
0005433960969	6908	Economy	7100.00
0005433960943	6908	Economy	7100.00
0005433960968	6908	Economy	7100.00
0005433960966	6908	Economy	7100.00
0005433960938	6908	Economy	7100.00
0005433960940	6908	Economy	7100.00
0005433960970	6908	Economy	7100.00
0005433960963	6908	Economy	7100.00
0005433960918	6908	Economy	7100.00
0005433960956	6908	Economy	7100.00
0005433960955	6908	Economy	7100.00
0005433960928	6908	Economy	7100.00
0005433960945	6908	Economy	7100.00
0005433960946	6908	Economy	7100.00
0005433960919	6908	Economy	7100.00
0005433960973	6908	Economy	7100.00
0005433960930	6908	Economy	7100.00
0005433960949	6908	Economy	7100.00
0005433960328	25798	Business	21400.00
0005433960078	25798	Business	21400.00
0005433960125	25798	Business	21400.00
0005433960293	25798	Business	21400.00
0005433960288	25798	Business	21400.00
0005433960171	25798	Business	21400.00
0005433960368	25798	Business	21400.00
0005433960342	25798	Business	21400.00
0005433960189	25798	Business	21400.00
0005433960103	25798	Economy	7100.00
0005433960287	25798	Economy	7100.00
0005433960148	25798	Economy	7100.00
0005433960229	25798	Economy	7100.00
0005433960040	25798	Economy	7100.00
0005433960309	25798	Economy	7100.00
0005433960228	25798	Economy	7100.00
0005433960370	25798	Economy	7800.00
0005433960333	25798	Economy	7800.00
0005433960197	25798	Economy	7800.00
0005433960299	25798	Economy	7800.00
0005433960353	25798	Economy	7100.00
0005433960349	25798	Economy	7100.00
0005433960374	25798	Economy	7100.00
0005433959975	25798	Economy	7100.00
0005433960157	25798	Economy	7100.00
0005433960253	25798	Economy	7100.00
0005433960339	25798	Economy	7100.00
0005433960094	25798	Economy	7100.00
0005433960109	25798	Economy	7100.00
0005433959996	25798	Economy	7100.00
0005433960377	25798	Economy	7100.00
0005433960252	25798	Economy	7100.00
0005433960373	25798	Economy	7100.00
0005433960318	25798	Economy	7100.00
0005433960325	25798	Economy	7100.00
0005433960110	25798	Economy	7100.00
0005433960314	25798	Economy	7100.00
0005433960039	25798	Economy	7100.00
0005433960276	25798	Economy	7100.00
0005433960270	25798	Economy	7100.00
0005433960378	25798	Economy	7100.00
0005433960269	25798	Economy	7100.00
0005433960315	25798	Economy	7100.00
0005433960336	25798	Economy	7100.00
0005433960271	25798	Economy	7100.00
0005433960156	25798	Economy	7100.00
0005433960079	25798	Economy	7100.00
0005433960225	25798	Economy	7100.00
0005433960182	25798	Economy	7100.00
0005433960367	25798	Economy	7100.00
0005433960350	25798	Economy	7100.00
0005433960369	25798	Economy	7100.00
0005433960155	25798	Economy	7100.00
0005433960296	25798	Economy	7100.00
0005433960257	25798	Economy	7100.00
0005433960291	25798	Economy	7100.00
0005433960308	25798	Economy	7100.00
0005433959915	25798	Economy	7100.00
0005433960004	25798	Economy	7100.00
0005433960190	25798	Economy	7100.00
0005433960319	25798	Economy	7100.00
0005433960300	25798	Economy	7100.00
0005433960251	25798	Economy	7100.00
0005433960357	25798	Economy	7100.00
0005433960329	25798	Economy	7100.00
0005433960268	25798	Economy	7100.00
0005433960283	25798	Economy	7100.00
0005433960292	25798	Economy	7100.00
0005433960317	25798	Economy	7100.00
0005433960376	25798	Economy	7100.00
0005433960254	25798	Economy	7100.00
0005435082723	24491	Economy	3900.00
0005435082727	24491	Economy	3900.00
0005435082738	24491	Economy	3900.00
0005435082726	24491	Economy	3900.00
0005435082728	24491	Economy	3900.00
0005435082716	24491	Economy	3900.00
0005435082717	24491	Economy	3900.00
0005435082740	24491	Economy	3900.00
0005435082724	24491	Economy	3900.00
0005435082785	26141	Economy	3900.00
0005435082784	26141	Economy	3900.00
0005435082786	26141	Economy	3900.00
0005435082787	26141	Economy	3900.00
0005434245011	5209	Business	18000.00
0005434245010	5209	Business	18000.00
0005434245014	5209	Business	18000.00
0005434245021	5209	Business	18000.00
0005434245022	5209	Business	18000.00
0005434245001	5209	Business	18000.00
0005432166905	5209	Business	18000.00
0005434245019	5209	Economy	6600.00
0005434245006	5209	Economy	6600.00
0005435286592	5209	Economy	6000.00
0005434245017	5209	Economy	6000.00
0005434244998	5209	Economy	6000.00
0005435286579	5209	Economy	6000.00
0005435286595	5209	Economy	6000.00
0005434245025	5209	Economy	6000.00
0005434245023	5209	Economy	6000.00
0005434245005	5209	Economy	6000.00
0005435286563	5209	Economy	6000.00
0005434245003	5209	Economy	6000.00
0005435286589	5209	Economy	6000.00
0005434245008	5209	Economy	6000.00
0005434245002	5209	Economy	6000.00
0005434245015	5209	Economy	6000.00
0005435286583	5209	Economy	6000.00
0005435286582	5209	Economy	6000.00
0005434245007	5209	Economy	6000.00
0005435286580	5209	Economy	6000.00
0005434245018	5209	Economy	6600.00
0005432166904	5209	Economy	6600.00
0005434245013	5209	Economy	6600.00
0005434244999	5209	Economy	6600.00
0005434245012	5209	Economy	6000.00
0005434244997	5209	Economy	6000.00
0005434245000	5209	Economy	6000.00
0005434245016	5209	Economy	6000.00
0005434245024	5209	Economy	6000.00
0005434245004	5209	Economy	6000.00
0005434244996	5209	Economy	6000.00
0005434245020	5209	Economy	6000.00
0005434244995	5209	Economy	6000.00
0005434245009	5209	Economy	6000.00
0005433784984	5208	Business	18000.00
0005433614807	5208	Business	18000.00
0005433614805	5208	Business	18000.00
0005433784983	5208	Business	18000.00
0005433784998	5208	Business	18000.00
0005432105624	5208	Business	18000.00
0005433614776	5208	Business	18000.00
0005433784973	5208	Business	18000.00
0005433614757	5208	Business	18000.00
0005433614774	5208	Business	18000.00
0005433784977	5208	Business	18000.00
0005432667456	5208	Business	18000.00
0005432105613	5208	Business	18000.00
0005432105596	5208	Business	18000.00
0005433614785	5208	Business	18000.00
0005433784969	5208	Business	18000.00
0005433614734	5208	Business	18000.00
0005433614780	5208	Business	18000.00
0005432105593	5208	Business	18000.00
0005433784996	5208	Business	18000.00
0005432105592	5208	Business	18000.00
0005432105607	5208	Business	18000.00
0005432105612	5208	Business	18000.00
0005432105603	5208	Business	18000.00
0005433784981	5208	Business	18000.00
0005432105605	5208	Business	18000.00
0005433784966	5208	Business	18000.00
0005433614754	5208	Business	18000.00
0005433614806	5208	Economy	6600.00
0005432105636	5208	Economy	6600.00
0005433614758	5208	Economy	6600.00
0005432105639	5208	Economy	6600.00
0005433784961	5208	Economy	6600.00
0005433614782	5208	Economy	6600.00
0005433614737	5208	Economy	6000.00
0005433614755	5208	Economy	6000.00
0005433784974	5208	Economy	6000.00
0005432105615	5208	Economy	6000.00
0005433784989	5208	Economy	6000.00
0005433784995	5208	Economy	6000.00
0005433614779	5208	Economy	6000.00
0005432105629	5208	Economy	6000.00
0005433784976	5208	Economy	6000.00
0005433784962	5208	Economy	6000.00
0005432105634	5208	Economy	6000.00
0005433614793	5208	Economy	6000.00
0005433614744	5208	Economy	6000.00
0005433614762	5208	Economy	6000.00
0005432105625	5208	Economy	6000.00
0005433614796	5208	Economy	6000.00
0005433784994	5208	Economy	6000.00
0005433784972	5208	Economy	6000.00
0005433614804	5208	Economy	6000.00
0005433784967	5208	Economy	6000.00
0005433614764	5208	Economy	6000.00
0005432105628	5208	Economy	6000.00
0005432105622	5208	Economy	6000.00
0005433614797	5208	Economy	6000.00
0005432145115	5208	Economy	6000.00
0005433784993	5208	Economy	6000.00
0005433784985	5208	Economy	6000.00
0005433784982	5208	Economy	6000.00
0005433614742	5208	Economy	6000.00
0005433784960	5208	Economy	6000.00
0005432105611	5208	Economy	6000.00
0005433614783	5208	Economy	6000.00
0005433614740	5208	Economy	6000.00
0005433614746	5208	Economy	6000.00
0005432105623	5208	Economy	6000.00
0005432145114	5208	Economy	6000.00
0005433784988	5208	Economy	6000.00
0005432665277	5208	Economy	6000.00
0005432105602	5208	Economy	6000.00
0005433614765	5208	Economy	6000.00
0005433784978	5208	Economy	6000.00
0005433614784	5208	Economy	6000.00
0005433614743	5208	Economy	6000.00
0005433784990	5208	Economy	6000.00
0005433614751	5208	Economy	6000.00
0005432105600	5208	Economy	6000.00
0005433614786	5208	Economy	6000.00
0005432105617	5208	Economy	6000.00
0005433614803	5208	Economy	6000.00
0005432105604	5208	Economy	6000.00
0005433614808	5208	Economy	6000.00
0005433614790	5208	Economy	6000.00
0005433614771	5208	Economy	6000.00
0005433784965	5208	Economy	6000.00
0005432105616	5208	Economy	6000.00
0005433614801	5208	Economy	6000.00
0005433784992	5208	Economy	6000.00
0005433784968	5208	Economy	6000.00
0005433614768	5208	Economy	6000.00
0005432105627	5208	Economy	6000.00
0005433614747	5208	Economy	6600.00
0005433614778	5208	Economy	6600.00
0005432105619	5208	Economy	6600.00
0005432105599	5208	Economy	6600.00
0005433784970	5208	Economy	6600.00
0005433614798	5208	Economy	6000.00
0005433784997	5208	Economy	6000.00
0005433614736	5208	Economy	6000.00
0005432105638	5208	Economy	6000.00
0005432105640	5208	Economy	6600.00
0005433614735	5208	Economy	6000.00
0005433614787	5208	Economy	6000.00
0005432105630	5208	Economy	6000.00
0005433614760	5208	Economy	6000.00
0005433784979	5208	Economy	6000.00
0005432105609	5208	Economy	6000.00
0005433784991	5208	Economy	6000.00
0005433614794	5208	Economy	6000.00
0005433614799	5208	Economy	6000.00
0005432665276	5208	Economy	6000.00
0005433614789	5208	Economy	6000.00
0005433614802	5208	Economy	6000.00
0005433784980	5208	Economy	6000.00
0005433614772	5208	Economy	6000.00
0005433614761	5208	Economy	6000.00
0005433614756	5208	Economy	6000.00
0005432105595	5208	Economy	6000.00
0005433614739	5208	Economy	6000.00
0005432105635	5208	Economy	6000.00
0005433614741	5208	Economy	6000.00
0005432666391	5208	Economy	6000.00
0005433614792	5208	Economy	6000.00
0005432105610	5208	Economy	6000.00
0005432105620	5208	Economy	6000.00
0005433614759	5208	Economy	6000.00
0005433784971	5208	Economy	6000.00
0005432105597	5208	Economy	6000.00
0005433614777	5208	Economy	6000.00
0005433614800	5208	Economy	6000.00
0005433614773	5208	Economy	6000.00
0005433614763	5208	Economy	6000.00
0005433614749	5208	Economy	6000.00
0005433614795	5208	Economy	6000.00
0005432105618	5208	Economy	6000.00
0005432105606	5208	Economy	6000.00
0005433614767	5208	Economy	6000.00
0005432105637	5208	Economy	6000.00
0005433614766	5208	Economy	6000.00
0005433614750	5208	Economy	6000.00
0005432105601	5208	Economy	6000.00
0005433614738	5208	Economy	6000.00
0005432105614	5208	Economy	6000.00
0005433614753	5208	Economy	6000.00
0005432105633	5208	Economy	6000.00
0005433784964	5208	Economy	6000.00
0005433784986	5208	Economy	6000.00
0005433614770	5208	Economy	6000.00
0005432105608	5208	Economy	6000.00
0005433784963	5208	Economy	6000.00
0005432105631	5208	Economy	6000.00
0005433614752	5208	Economy	6000.00
0005432105598	5208	Economy	6000.00
0005433614775	5208	Economy	6000.00
0005433614745	5208	Economy	6000.00
0005432105626	5208	Economy	6000.00
0005432105621	5208	Economy	6000.00
0005433614791	5208	Economy	6000.00
0005433614769	5208	Economy	6000.00
0005432105632	5208	Economy	6000.00
0005433784975	5208	Economy	6000.00
0005433614781	5208	Economy	6000.00
0005433614748	5208	Economy	6000.00
0005432105594	5208	Economy	6000.00
0005433614788	5208	Economy	6000.00
0005433784987	5208	Economy	6000.00
0005434229402	5203	Business	18000.00
0005434229388	5203	Business	18000.00
0005435006867	5203	Business	18000.00
0005434265162	5203	Business	18000.00
0005434229387	5203	Business	18000.00
0005434173523	5203	Business	18000.00
0005434149740	5203	Business	18000.00
0005434229395	5203	Business	18000.00
0005432335962	5203	Business	18000.00
0005435006822	5203	Business	18000.00
0005435006775	5203	Business	18000.00
0005434229404	5203	Business	18000.00
0005434265158	5203	Business	18000.00
0005435006795	5203	Business	18000.00
0005433685505	5203	Business	18000.00
0005434229384	5203	Business	18000.00
0005434149745	5203	Business	18000.00
0005434229397	5203	Business	18000.00
0005435006880	5203	Business	18000.00
0005434265157	5203	Economy	6600.00
0005434229401	5203	Economy	6600.00
0005433815356	5203	Economy	6000.00
0005432335954	5203	Economy	6000.00
0005434265164	5203	Economy	6000.00
0005434173524	5203	Economy	6000.00
0005434265151	5203	Economy	6000.00
0005432335980	5203	Economy	6000.00
0005435269674	5203	Economy	6000.00
0005435006851	5203	Economy	6000.00
0005434149741	5203	Economy	6000.00
0005434265178	5203	Economy	6000.00
0005435269675	5203	Economy	6000.00
0005434229389	5203	Economy	6000.00
0005435006837	5203	Economy	6000.00
0005435269686	5203	Economy	6000.00
0005433688785	5203	Economy	6000.00
0005434229405	5203	Economy	6000.00
0005434149746	5203	Economy	6000.00
0005434149747	5203	Economy	6000.00
0005434229391	5203	Economy	6000.00
0005435006849	5203	Economy	6000.00
0005434149744	5203	Economy	6000.00
0005434265161	5203	Economy	6000.00
0005435269691	5203	Economy	6000.00
0005434265153	5203	Economy	6000.00
0005434149742	5203	Economy	6000.00
0005434265173	5203	Economy	6000.00
0005434229398	5203	Economy	6000.00
0005434229383	5203	Economy	6000.00
0005432335925	5203	Economy	6000.00
0005434265176	5203	Economy	6000.00
0005435006808	5203	Economy	6000.00
0005432335982	5203	Economy	6000.00
0005433685520	5203	Economy	6000.00
0005434229403	5203	Economy	6000.00
0005434229393	5203	Economy	6000.00
0005434149738	5203	Economy	6000.00
0005434229386	5203	Economy	6000.00
0005434265169	5203	Economy	6000.00
0005434173522	5203	Economy	6000.00
0005435269668	5203	Economy	6000.00
0005435006767	5203	Economy	6000.00
0005433815354	5203	Economy	6000.00
0005435006836	5203	Economy	6000.00
0005434265168	5203	Economy	6000.00
0005435006755	5203	Economy	6000.00
0005434229385	5203	Economy	6000.00
0005434265152	5203	Economy	6600.00
0005432335981	5203	Economy	6600.00
0005434265167	5203	Economy	6600.00
0005433688797	5203	Economy	6600.00
0005435006796	5203	Economy	6600.00
0005435006854	5203	Economy	6000.00
0005434149739	5203	Economy	6000.00
0005435006856	5203	Economy	6000.00
0005432335859	5203	Economy	6000.00
0005432335858	5203	Economy	6000.00
0005435006949	5203	Economy	6000.00
0005434265166	5203	Economy	6000.00
0005434229400	5203	Economy	6000.00
0005434149748	5203	Economy	6000.00
0005434229392	5203	Economy	6000.00
0005434229399	5203	Economy	6000.00
0005434265170	5203	Economy	6000.00
0005434229396	5203	Economy	6000.00
0005433685506	5203	Economy	6000.00
0005434265163	5203	Economy	6000.00
0005433815338	5203	Economy	6000.00
0005435006857	5203	Economy	6000.00
0005435269667	5203	Economy	6000.00
0005434229390	5203	Economy	6000.00
0005434265165	5203	Economy	6000.00
0005432335963	5203	Economy	6000.00
0005435006850	5203	Economy	6000.00
0005434149743	5203	Economy	6000.00
0005434173525	5203	Economy	6000.00
0005434229394	5203	Economy	6000.00
0005435006948	5203	Economy	6000.00
0005435006768	5203	Economy	6000.00
0005435269679	5203	Economy	6000.00
0005434265159	5203	Economy	6000.00
0005434265155	5203	Economy	6000.00
0005435006778	5203	Economy	6000.00
0005435006855	5203	Economy	6000.00
0005434265160	5203	Economy	6000.00
0005434312297	5203	Economy	6000.00
0005435006777	5203	Economy	6000.00
0005434265175	5203	Economy	6000.00
0005434265177	5203	Economy	6000.00
0005433815325	5203	Economy	6000.00
0005435269676	5203	Economy	6000.00
0005434265154	5203	Economy	6000.00
0005435269685	5203	Economy	6000.00
0005435006826	5203	Economy	6000.00
0005432335920	5203	Economy	6000.00
0005434265156	5203	Economy	6000.00
0005434265172	5203	Economy	6000.00
0005432335983	5203	Economy	6000.00
0005433688790	5203	Economy	6000.00
0005434149737	5203	Economy	6000.00
0005433815347	5203	Economy	6000.00
0005435006809	5203	Economy	6000.00
0005434265171	5203	Economy	6000.00
0005434265174	5203	Economy	6000.00
0005433784670	8485	Business	18000.00
0005432659700	8485	Business	18000.00
0005435269749	8485	Business	18000.00
0005433784623	8485	Business	18000.00
0005433784610	8485	Business	18000.00
0005434244840	8485	Business	18000.00
0005433784585	8485	Business	18000.00
0005434244873	8485	Economy	6600.00
0005433784810	8485	Economy	6600.00
0005433784540	8485	Economy	6600.00
0005434244715	8485	Economy	6000.00
0005432663022	8485	Economy	6000.00
0005433784627	8485	Economy	6000.00
0005433784599	8485	Economy	6000.00
0005434244728	8485	Economy	6000.00
0005434244745	8485	Economy	6000.00
0005434244734	8485	Economy	6000.00
0005433784521	8485	Economy	6000.00
0005433784741	8485	Economy	6000.00
0005434244794	8485	Economy	6000.00
0005434244802	8485	Economy	6000.00
0005434244793	8485	Economy	6000.00
0005433784743	8485	Economy	6000.00
0005434244874	8485	Economy	6000.00
0005433784669	8485	Economy	6000.00
0005433784763	8485	Economy	6000.00
0005434244926	8485	Economy	6000.00
0005434244746	8485	Economy	6000.00
0005434244729	8485	Economy	6000.00
0005434244910	8485	Economy	6000.00
0005434244714	8485	Economy	6000.00
0005433784586	8485	Economy	6000.00
0005432666376	8485	Economy	6600.00
0005433784527	8485	Economy	6600.00
0005432663021	8485	Economy	6000.00
0005434244843	8485	Economy	6000.00
0005433784668	8485	Economy	6000.00
0005434244801	8485	Economy	6000.00
0005432663020	8485	Economy	6000.00
0005433784602	8485	Economy	6000.00
0005435269750	8485	Economy	6000.00
0005433784709	8485	Economy	6000.00
0005434244698	8485	Economy	6000.00
0005433784687	8485	Economy	6000.00
0005434244846	8485	Economy	6000.00
0005433784522	8485	Economy	6000.00
0005433784612	8485	Economy	6000.00
0005433784764	8485	Economy	6000.00
0005432663024	8485	Economy	6000.00
0005433784523	8485	Economy	6000.00
0005434244841	8485	Economy	6000.00
0005433784742	8485	Economy	6000.00
0005433784603	8485	Economy	6000.00
0005433784611	8485	Economy	6000.00
0005432663017	8485	Economy	6000.00
0005434244685	8485	Economy	6000.00
0005433784596	8485	Economy	6000.00
0005433784597	8485	Economy	6000.00
0005434244754	8485	Economy	6000.00
0005434244825	8485	Economy	6000.00
0005434244927	8485	Economy	6000.00
0005433613816	8486	Business	18000.00
0005433613996	8486	Business	18000.00
0005433614084	8486	Business	18000.00
0005433614298	8486	Business	18000.00
0005433614279	8486	Business	18000.00
0005433614187	8486	Business	18000.00
0005433614093	8486	Business	18000.00
0005433613765	8486	Business	18000.00
0005433613814	8486	Economy	6600.00
0005433614085	8486	Economy	6000.00
0005433613564	8486	Economy	6000.00
0005433614188	8486	Economy	6000.00
0005433614208	8486	Economy	6000.00
0005433613990	8486	Economy	6000.00
0005433614038	8486	Economy	6000.00
0005433613848	8486	Economy	6000.00
0005433614260	8486	Economy	6000.00
0005433614182	8486	Economy	6000.00
0005433613871	8486	Economy	6000.00
0005433613815	8486	Economy	6000.00
0005433614022	8486	Economy	6000.00
0005433613565	8486	Economy	6000.00
0005433613563	8486	Economy	6000.00
0005433614228	8486	Economy	6000.00
0005433614086	8486	Economy	6000.00
0005433614416	8486	Economy	6000.00
0005433614233	8486	Economy	6000.00
0005433613941	8486	Economy	6000.00
0005433614181	8486	Economy	6000.00
0005433614130	8486	Economy	6000.00
0005433614046	8486	Economy	6000.00
0005433614297	8486	Economy	6000.00
0005433613961	8486	Economy	6600.00
0005433614159	8486	Economy	6600.00
0005433614127	8486	Economy	6000.00
0005433613698	8486	Economy	6000.00
0005433614002	8486	Economy	6600.00
0005433614076	8486	Economy	6000.00
0005433614207	8486	Economy	6000.00
0005433613832	8486	Economy	6000.00
0005433613921	8486	Economy	6000.00
0005433614234	8486	Economy	6000.00
0005433614064	8486	Economy	6000.00
0005433614499	8486	Economy	6000.00
0005433613804	8486	Economy	6000.00
0005433613942	8486	Economy	6000.00
0005433613896	8486	Economy	6000.00
0005433613972	8486	Economy	6000.00
0005433613964	8486	Economy	6000.00
0005433614006	8486	Economy	6000.00
0005433613991	8486	Economy	6000.00
0005433614125	8486	Economy	6000.00
0005433614094	8486	Economy	6000.00
0005433613994	8486	Economy	6000.00
0005433614116	8486	Economy	6000.00
0005433614316	8486	Economy	6000.00
0005433614347	8486	Economy	6000.00
0005433613895	8486	Economy	6000.00
0005434264947	8487	Business	18000.00
0005434265065	8487	Business	18000.00
0005433815391	8487	Business	18000.00
0005433815389	8487	Business	18000.00
0005432047555	8487	Business	18000.00
0005434229175	8487	Business	18000.00
0005434149616	8487	Business	18000.00
0005435007052	8487	Business	18000.00
0005432047553	8487	Business	18000.00
0005434149637	8487	Business	18000.00
0005435007053	8487	Business	18000.00
0005433815393	8487	Business	18000.00
0005435007066	8487	Business	18000.00
0005434173485	8487	Business	18000.00
0005432034967	8487	Business	18000.00
0005434229246	8487	Business	18000.00
0005434264959	8487	Business	18000.00
0005435007057	8487	Business	18000.00
0005434229245	8487	Business	18000.00
0005432034988	8487	Business	18000.00
0005434229251	8487	Business	18000.00
0005433690929	8487	Business	18000.00
0005434264945	8487	Business	18000.00
0005434264897	8487	Business	18000.00
0005435286628	8487	Business	18000.00
0005433689913	8487	Business	18000.00
0005434264946	8487	Business	18000.00
0005435007068	8487	Economy	6600.00
0005435007047	8487	Economy	6600.00
0005434264781	8487	Economy	6600.00
0005433815394	8487	Economy	6600.00
0005435286631	8487	Economy	6000.00
0005434229194	8487	Economy	6000.00
0005434229177	8487	Economy	6000.00
0005434264981	8487	Economy	6000.00
0005432034982	8487	Economy	6000.00
0005432034971	8487	Economy	6000.00
0005432336043	8487	Economy	6000.00
0005432034977	8487	Economy	6000.00
0005435007046	8487	Economy	6000.00
0005433689914	8487	Economy	6000.00
0005434264910	8487	Economy	6000.00
0005435007050	8487	Economy	6000.00
0005433688812	8487	Economy	6000.00
0005434229252	8487	Economy	6000.00
0005435007059	8487	Economy	6000.00
0005434229133	8487	Economy	6000.00
0005434229168	8487	Economy	6000.00
0005434229134	8487	Economy	6000.00
0005432336045	8487	Economy	6000.00
0005435286634	8487	Economy	6000.00
0005435286629	8487	Economy	6000.00
0005435007048	8487	Economy	6000.00
0005434229154	8487	Economy	6000.00
0005432034980	8487	Economy	6000.00
0005433815395	8487	Economy	6000.00
0005435007069	8487	Economy	6000.00
0005432034984	8487	Economy	6000.00
0005434149655	8487	Economy	6000.00
0005434264948	8487	Economy	6000.00
0005435007064	8487	Economy	6000.00
0005432034979	8487	Economy	6000.00
0005434229163	8487	Economy	6000.00
0005434149654	8487	Economy	6000.00
0005434149628	8487	Economy	6000.00
0005434149666	8487	Economy	6000.00
0005434265063	8487	Economy	6000.00
0005433534501	8487	Economy	6000.00
0005434173476	8487	Economy	6000.00
0005432047554	8487	Economy	6000.00
0005432047552	8487	Economy	6000.00
0005435286632	8487	Economy	6000.00
0005434229124	8487	Economy	6000.00
0005432034969	8487	Economy	6000.00
0005432034963	8487	Economy	6000.00
0005432034986	8487	Economy	6000.00
0005435007063	8487	Economy	6000.00
0005434265064	8487	Economy	6000.00
0005432034974	8487	Economy	6000.00
0005433534500	8487	Economy	6000.00
0005434229126	8487	Economy	6000.00
0005435007061	8487	Economy	6000.00
0005435286633	8487	Economy	6000.00
0005434229176	8487	Economy	6000.00
0005432336052	8487	Economy	6000.00
0005434149667	8487	Economy	6000.00
0005435007054	8487	Economy	6600.00
0005435007056	8487	Economy	6600.00
0005434265090	8487	Economy	6600.00
0005435007049	8487	Economy	6000.00
0005433815390	8487	Economy	6000.00
0005432336051	8487	Economy	6000.00
0005432034987	8487	Economy	6000.00
0005435007067	8487	Economy	6600.00
0005434149636	8487	Economy	6000.00
0005434173477	8487	Economy	6000.00
0005435286630	8487	Economy	6000.00
0005432336049	8487	Economy	6000.00
0005432336042	8487	Economy	6000.00
0005432034989	8487	Economy	6000.00
0005432034975	8487	Economy	6000.00
0005434229227	8487	Economy	6000.00
0005435007065	8487	Economy	6000.00
0005432336044	8487	Economy	6000.00
0005434264990	8487	Economy	6000.00
0005434229158	8487	Economy	6000.00
0005435007045	8487	Economy	6000.00
0005432034966	8487	Economy	6000.00
0005432034978	8487	Economy	6000.00
0005433688811	8487	Economy	6000.00
0005434229164	8487	Economy	6000.00
0005434229244	8487	Economy	6000.00
0005434229214	8487	Economy	6000.00
0005434265011	8487	Economy	6000.00
0005432034972	8487	Economy	6000.00
0005432336047	8487	Economy	6000.00
0005434264835	8487	Economy	6000.00
0005432034973	8487	Economy	6000.00
0005435007058	8487	Economy	6000.00
0005434264864	8487	Economy	6000.00
0005432034983	8487	Economy	6000.00
0005432034964	8487	Economy	6000.00
0005432336041	8487	Economy	6000.00
0005434229258	8487	Economy	6000.00
0005435007044	8487	Economy	6000.00
0005433689912	8487	Economy	6000.00
0005434264964	8487	Economy	6000.00
0005435007062	8487	Economy	6000.00
0005434311222	8487	Economy	6000.00
0005434311221	8487	Economy	6000.00
0005432034976	8487	Economy	6000.00
0005434264991	8487	Economy	6000.00
0005433815392	8487	Economy	6000.00
0005435007070	8487	Economy	6000.00
0005434264909	8487	Economy	6000.00
0005432336050	8487	Economy	6000.00
0005434229228	8487	Economy	6000.00
0005433690930	8487	Economy	6000.00
0005434229265	8487	Economy	6000.00
0005435007060	8487	Economy	6000.00
0005432034965	8487	Economy	6000.00
0005432034968	8487	Economy	6000.00
0005432034970	8487	Economy	6000.00
0005432034985	8487	Economy	6000.00
0005434229211	8487	Economy	6000.00
0005432336048	8487	Economy	6000.00
0005435007051	8487	Economy	6000.00
0005432034981	8487	Economy	6000.00
0005434149634	8487	Economy	6000.00
0005432336046	8487	Economy	6000.00
0005435007055	8487	Economy	6000.00
0005432034990	8487	Economy	6000.00
0005434639053	12628	Economy	16200.00
0005433202380	12628	Economy	16200.00
0005434639121	12628	Economy	16200.00
0005434639285	12628	Economy	14800.00
0005433202374	12628	Economy	14800.00
0005434639284	12628	Economy	14800.00
0005434639176	12628	Economy	14800.00
0005434639147	12628	Economy	14800.00
0005434639058	12628	Economy	14800.00
0005433202384	12628	Economy	14800.00
0005434639197	12628	Economy	14800.00
0005433202378	12628	Economy	14800.00
0005434638969	12628	Economy	14800.00
0005433202377	12628	Economy	14800.00
0005434639180	12628	Economy	14800.00
0005434639054	12628	Economy	14800.00
0005434639179	12628	Economy	14800.00
0005434639140	12628	Economy	14800.00
0005433202382	12628	Economy	14800.00
0005433202386	12628	Economy	14800.00
0005433202383	12628	Economy	14800.00
0005434639208	12628	Economy	14800.00
0005434639212	12628	Economy	14800.00
0005433202387	12628	Economy	14800.00
0005433202376	12628	Economy	14800.00
0005434639124	12628	Economy	14800.00
0005434639051	12628	Economy	14800.00
0005433202381	12628	Economy	14800.00
0005433202379	12628	Economy	14800.00
0005434639129	12628	Economy	14800.00
0005434639195	12628	Economy	14800.00
0005433202388	12628	Economy	14800.00
0005434639139	12628	Economy	14800.00
0005434639070	12628	Economy	14800.00
0005434639093	12628	Economy	14800.00
0005434639207	12628	Economy	14800.00
0005434639181	12628	Economy	14800.00
0005434639142	12628	Economy	14800.00
0005433202385	12628	Economy	14800.00
0005434639094	12628	Economy	14800.00
0005433202375	12628	Economy	14800.00
0005434639090	12628	Economy	14800.00
0005433202184	23388	Economy	16200.00
0005434639316	23388	Economy	16200.00
0005434639317	23388	Economy	16200.00
0005434639327	23388	Economy	14800.00
0005432290634	23388	Economy	14800.00
0005433202228	23388	Economy	14800.00
0005434639335	23388	Economy	14800.00
0005434639329	23388	Economy	14800.00
0005434639314	23388	Economy	14800.00
0005434639323	23388	Economy	14800.00
0005434639318	23388	Economy	14800.00
0005434639338	23388	Economy	14800.00
0005434639333	23388	Economy	14800.00
0005434639336	23388	Economy	14800.00
0005434639331	23388	Economy	14800.00
0005434639315	23388	Economy	14800.00
0005434639330	23388	Economy	14800.00
0005433202241	23388	Economy	14800.00
0005434639324	23388	Economy	14800.00
0005434639337	23388	Economy	14800.00
0005434639325	23388	Economy	14800.00
0005433202185	23388	Economy	14800.00
0005434639310	23388	Economy	14800.00
0005434639322	23388	Economy	14800.00
0005432290633	23388	Economy	14800.00
0005434639312	23388	Economy	14800.00
0005434639326	23388	Economy	14800.00
0005433202231	23388	Economy	14800.00
0005434639320	23388	Economy	14800.00
0005434639311	23388	Economy	14800.00
0005433202282	23388	Economy	14800.00
0005433202198	23388	Economy	14800.00
0005434639334	23388	Economy	14800.00
0005434639332	23388	Economy	14800.00
0005434639321	23388	Economy	14800.00
0005433202232	23388	Economy	14800.00
0005434639319	23388	Economy	14800.00
0005434639313	23388	Economy	14800.00
0005433202230	23388	Economy	14800.00
0005434639328	23388	Economy	14800.00
0005432382725	21079	Business	18900.00
0005432328265	21079	Business	18900.00
0005432328273	21079	Business	18900.00
0005432328392	21079	Business	18900.00
0005432382728	21079	Business	18900.00
0005432328276	21079	Business	18900.00
0005432328256	21079	Business	18900.00
0005432382796	21079	Business	18900.00
0005432328307	21079	Business	18900.00
0005432382843	21079	Business	18900.00
0005432328161	21079	Economy	6300.00
0005432382808	21079	Economy	6300.00
0005432382842	21079	Economy	6300.00
0005432054308	21079	Economy	6300.00
0005432328462	21079	Economy	6300.00
0005432328425	21079	Economy	6300.00
0005432382754	21079	Economy	6300.00
0005432382923	21079	Economy	6300.00
0005432382849	21079	Economy	6300.00
0005432382724	21079	Economy	6900.00
0005432382850	21079	Economy	6900.00
0005432328364	21079	Economy	6900.00
0005432328532	21079	Economy	6300.00
0005432328185	21079	Economy	6300.00
0005432328231	21079	Economy	6300.00
0005432328546	21079	Economy	6300.00
0005432382823	21079	Economy	6300.00
0005432328365	21079	Economy	6300.00
0005432328324	21079	Economy	6300.00
0005432382582	21079	Economy	6300.00
0005432328390	21079	Economy	6300.00
0005432328090	21079	Economy	6300.00
0005432328089	21079	Economy	6300.00
0005432382822	21079	Economy	6300.00
0005432328251	21079	Economy	6300.00
0005432382729	21079	Economy	6300.00
0005432382941	21079	Economy	6300.00
0005432382893	21079	Economy	6300.00
0005432382821	21079	Economy	6300.00
0005432382924	21079	Economy	6300.00
0005432328184	21079	Economy	6300.00
0005432328487	21079	Economy	6300.00
0005432382807	21079	Economy	6300.00
0005432382891	21079	Economy	6300.00
0005432382858	21079	Economy	6300.00
0005432328217	21079	Economy	6300.00
0005432328486	21079	Economy	6300.00
0005432328354	21079	Economy	6300.00
0005432328399	21079	Economy	6300.00
0005432328355	21079	Economy	6300.00
0005432328426	21079	Economy	6300.00
0005432383011	21079	Economy	6300.00
0005432382809	21079	Economy	6300.00
0005432382999	21079	Economy	6300.00
0005432382854	21079	Economy	6300.00
0005432382939	21079	Economy	6300.00
0005432328405	21079	Economy	6300.00
0005432328412	21079	Economy	6300.00
0005432054306	21079	Economy	6300.00
0005432382775	21079	Economy	6300.00
0005432328325	21079	Economy	6300.00
0005432382894	21079	Economy	6300.00
0005432328287	21079	Economy	6300.00
0005432328483	21079	Economy	6300.00
0005432382834	21079	Economy	6300.00
0005432382583	21079	Economy	6300.00
0005432382966	21079	Economy	6300.00
0005432328088	21079	Economy	6300.00
0005432328346	21079	Economy	6300.00
0005432328230	21079	Economy	6300.00
0005432382927	21079	Economy	6300.00
0005432328338	21079	Economy	6300.00
0005432382864	21079	Economy	6300.00
0005432382853	21079	Economy	6300.00
0005432328393	21079	Economy	6300.00
0005432328190	21079	Economy	6300.00
0005432054307	21079	Economy	6300.00
0005432382866	21079	Economy	6300.00
0005432328711	31262	Business	18900.00
0005432383180	31262	Business	18900.00
0005432383167	31262	Business	18900.00
0005432328700	31262	Business	18900.00
0005432328734	31262	Business	18900.00
0005432383178	31262	Business	18900.00
0005432328718	31262	Business	18900.00
0005432328716	31262	Business	18900.00
0005432328696	31262	Business	18900.00
0005432328689	31262	Business	18900.00
0005432328719	31262	Economy	6300.00
0005432328722	31262	Economy	6300.00
0005432328691	31262	Economy	6300.00
0005432383184	31262	Economy	6300.00
0005432328736	31262	Economy	6300.00
0005432383171	31262	Economy	6300.00
0005432287188	31262	Economy	6300.00
0005432383174	31262	Economy	6300.00
0005432383176	31262	Economy	6300.00
0005432328701	31262	Economy	6900.00
0005432383197	31262	Economy	6900.00
0005432383175	31262	Economy	6900.00
0005432287192	31262	Economy	6900.00
0005432328720	31262	Economy	6300.00
0005432328723	31262	Economy	6300.00
0005432328699	31262	Economy	6300.00
0005432383168	31262	Economy	6300.00
0005432287189	31262	Economy	6300.00
0005432328721	31262	Economy	6300.00
0005432383189	31262	Economy	6300.00
0005432287191	31262	Economy	6300.00
0005432383183	31262	Economy	6300.00
0005432328731	31262	Economy	6300.00
0005432383177	31262	Economy	6300.00
0005432328690	31262	Economy	6300.00
0005432328729	31262	Economy	6300.00
0005432328733	31262	Economy	6300.00
0005432328730	31262	Economy	6300.00
0005432383199	31262	Economy	6300.00
0005432383192	31262	Economy	6300.00
0005432328715	31262	Economy	6300.00
0005432328710	31262	Economy	6300.00
0005432328727	31262	Economy	6300.00
0005432383195	31262	Economy	6300.00
0005432383185	31262	Economy	6300.00
0005432328702	31262	Economy	6300.00
0005432383169	31262	Economy	6300.00
0005432383194	31262	Economy	6300.00
0005432328728	31262	Economy	6300.00
0005432328706	31262	Economy	6300.00
0005432328703	31262	Economy	6300.00
0005432328697	31262	Economy	6300.00
0005432383193	31262	Economy	6300.00
0005432328704	31262	Economy	6300.00
0005432383198	31262	Economy	6300.00
0005432328726	31262	Economy	6300.00
0005432328714	31262	Economy	6300.00
0005432383196	31262	Economy	6300.00
0005432383182	31262	Economy	6300.00
0005432328694	31262	Economy	6300.00
0005432328708	31262	Economy	6300.00
0005432328693	31262	Economy	6300.00
0005432383181	31262	Economy	6300.00
0005432383200	31262	Economy	6300.00
0005432328713	31262	Economy	6300.00
0005432328709	31262	Economy	6300.00
0005432383170	31262	Economy	6300.00
0005432328698	31262	Economy	6300.00
0005432383190	31262	Economy	6300.00
0005432328735	31262	Economy	6300.00
0005432287190	31262	Economy	6300.00
0005432383172	31262	Economy	6300.00
0005432383173	31262	Economy	6300.00
0005432328725	31262	Economy	6300.00
0005432328695	31262	Economy	6300.00
0005432328732	31262	Economy	6300.00
0005432328707	31262	Economy	6300.00
0005432383186	31262	Economy	6300.00
0005432383201	31262	Economy	6300.00
0005432328692	31262	Economy	6300.00
0005432328705	31262	Economy	6300.00
0005432383191	31262	Economy	6300.00
0005432383187	31262	Economy	6300.00
0005432328712	31262	Economy	6300.00
0005432383179	31262	Economy	6300.00
0005432328724	31262	Economy	6300.00
0005432383188	31262	Economy	6300.00
0005432328717	31262	Economy	6300.00
0005433642360	2490	Business	89600.00
0005433642344	2490	Business	89600.00
0005433642341	2490	Business	89600.00
0005433642357	2490	Economy	29900.00
0005432953875	2490	Economy	29900.00
0005432953873	2490	Economy	29900.00
0005433642336	2490	Economy	29900.00
0005433642366	2490	Economy	32800.00
0005433642340	2490	Economy	32800.00
0005432953876	2490	Economy	32800.00
0005433642347	2490	Economy	32800.00
0005432953837	2490	Economy	29900.00
0005432953854	2490	Economy	29900.00
0005432953861	2490	Economy	29900.00
0005432953833	2490	Economy	29900.00
0005433642358	2490	Economy	29900.00
0005433642339	2490	Economy	29900.00
0005432953871	2490	Economy	29900.00
0005432953874	2490	Economy	29900.00
0005432953860	2490	Economy	29900.00
0005432953883	2490	Economy	29900.00
0005433642345	2490	Economy	29900.00
0005433642354	2490	Economy	29900.00
0005433642343	2490	Economy	29900.00
0005433642337	2490	Economy	29900.00
0005433642355	2490	Economy	29900.00
0005433642351	2490	Economy	29900.00
0005433642359	2490	Economy	29900.00
0005433642335	2490	Economy	29900.00
0005432953872	2490	Economy	29900.00
0005433642356	2490	Economy	29900.00
0005433642361	2490	Economy	29900.00
0005433642365	2490	Economy	29900.00
0005433642352	2490	Economy	29900.00
0005433642362	2490	Economy	29900.00
0005433642353	2490	Economy	29900.00
0005432953859	2490	Economy	29900.00
0005433642349	2490	Economy	29900.00
0005433642350	2490	Economy	29900.00
0005433642338	2490	Economy	29900.00
0005433642346	2490	Economy	29900.00
0005432953870	2490	Economy	29900.00
0005433642364	2490	Economy	29900.00
0005433642342	2490	Economy	29900.00
0005432953858	2490	Economy	29900.00
0005433642348	2490	Economy	29900.00
0005433642363	2490	Economy	29900.00
0005433642245	27583	Business	89600.00
0005433642242	27583	Business	89600.00
0005433642180	27583	Business	89600.00
0005432953936	27583	Business	89600.00
0005433642158	27583	Business	89600.00
0005432953943	27583	Economy	29900.00
0005432953950	27583	Economy	29900.00
0005433642257	27583	Economy	29900.00
0005433642165	27583	Economy	29900.00
0005433642241	27583	Economy	29900.00
0005433642246	27583	Economy	29900.00
0005432953935	27583	Economy	29900.00
0005432953944	27583	Economy	29900.00
0005432953942	27583	Economy	32800.00
0005433642285	27583	Economy	32800.00
0005432953938	27583	Economy	29900.00
0005432953939	27583	Economy	29900.00
0005432953940	27583	Economy	29900.00
0005433642223	27583	Economy	29900.00
0005433642160	27583	Economy	29900.00
0005433642244	27583	Economy	29900.00
0005433642248	27583	Economy	29900.00
0005433642256	27583	Economy	29900.00
0005433642205	27583	Economy	29900.00
0005433642250	27583	Economy	29900.00
0005433642239	27583	Economy	29900.00
0005433642217	27583	Economy	29900.00
0005433642243	27583	Economy	29900.00
0005432953948	27583	Economy	29900.00
0005433642200	27583	Economy	29900.00
0005433642240	27583	Economy	29900.00
0005433642181	27583	Economy	29900.00
0005432953945	27583	Economy	29900.00
0005432953947	27583	Economy	29900.00
0005433642204	27583	Economy	29900.00
0005432953937	27583	Economy	29900.00
0005432953941	27583	Economy	29900.00
0005433642247	27583	Economy	29900.00
0005432953946	27583	Economy	29900.00
0005432953949	27583	Economy	29900.00
0005433642284	27583	Economy	29900.00
0005433642157	27583	Economy	29900.00
0005432953934	27583	Economy	29900.00
0005432424462	13274	Business	12700.00
0005432424433	13274	Business	12700.00
0005432424449	13274	Business	12700.00
0005432424445	13274	Business	12700.00
0005432424431	13274	Economy	4200.00
0005432424425	13274	Economy	4200.00
0005432424450	13274	Economy	4200.00
0005432424435	13274	Economy	4700.00
0005432424452	13274	Economy	4200.00
0005432424454	13274	Economy	4200.00
0005432424437	13274	Economy	4200.00
0005432424457	13274	Economy	4200.00
0005432424458	13274	Economy	4200.00
0005432424423	13274	Economy	4200.00
0005432424456	13274	Economy	4200.00
0005432424455	13274	Economy	4200.00
0005432424453	13274	Economy	4200.00
0005432424439	13274	Economy	4200.00
0005432424438	13274	Economy	4200.00
0005432424432	13274	Economy	4200.00
0005432424428	13274	Economy	4200.00
0005432424436	13274	Economy	4200.00
0005432424461	13274	Economy	4200.00
0005432424448	13274	Economy	4200.00
0005432424434	13274	Economy	4200.00
0005432424447	13274	Economy	4200.00
0005432424446	13274	Economy	4200.00
0005432424460	13274	Economy	4200.00
0005432424440	13274	Economy	4200.00
0005432424429	13274	Economy	4200.00
0005432424424	13274	Economy	4200.00
0005432424427	13274	Economy	4200.00
0005432424444	13274	Economy	4200.00
0005432424430	13274	Economy	4200.00
0005432424443	13274	Economy	4200.00
0005432424422	13274	Economy	4200.00
0005432424451	13274	Economy	4200.00
0005432424441	13274	Economy	4200.00
0005432424442	13274	Economy	4200.00
0005432424459	13274	Economy	4200.00
0005432424426	13274	Economy	4200.00
0005432423933	30792	Business	12700.00
0005432423979	30792	Business	12700.00
0005432424027	30792	Business	12700.00
0005432423934	30792	Business	12700.00
0005432423919	30792	Business	12700.00
0005432424060	30792	Business	12700.00
0005432424048	30792	Economy	4200.00
0005432424004	30792	Economy	4200.00
0005432424059	30792	Economy	4200.00
0005432424038	30792	Economy	4200.00
0005432423855	30792	Economy	4700.00
0005432424057	30792	Economy	4700.00
0005432423991	30792	Economy	4700.00
0005432423993	30792	Economy	4200.00
0005432424049	30792	Economy	4200.00
0005432424090	30792	Economy	4200.00
0005432423865	30792	Economy	4200.00
0005432423942	30792	Economy	4200.00
0005432423992	30792	Economy	4200.00
0005432424096	30792	Economy	4200.00
0005432423866	30792	Economy	4200.00
0005432423920	30792	Economy	4200.00
0005432424056	30792	Economy	4200.00
0005432423985	30792	Economy	4200.00
0005432423975	30792	Economy	4200.00
0005432423974	30792	Economy	4200.00
0005432424021	30792	Economy	4200.00
0005432423960	30792	Economy	4200.00
0005432424089	30792	Economy	4200.00
0005432423873	30792	Economy	4200.00
0005432424091	30792	Economy	4200.00
0005432424000	30792	Economy	4200.00
0005432423939	30792	Economy	4200.00
0005432423986	30792	Economy	4200.00
0005432424066	30792	Economy	4200.00
0005432423995	30792	Economy	4200.00
0005432424058	30792	Economy	4200.00
0005432423846	30792	Economy	4200.00
0005432424050	30792	Economy	4200.00
0005432423874	30792	Economy	4200.00
0005432424093	30792	Economy	4200.00
0005432424092	30792	Economy	4200.00
0005432424028	30792	Economy	4200.00
0005432423996	30792	Economy	4200.00
0005432424012	30792	Economy	4200.00
0005432423932	30792	Economy	4200.00
0005434448317	9583	Business	32600.00
0005434157412	9583	Business	32600.00
0005432822207	9583	Business	32600.00
0005432817504	9583	Business	32600.00
0005434157408	9583	Business	32600.00
0005434186179	9583	Business	32600.00
0005434448318	9583	Business	32600.00
0005434157379	9583	Business	32600.00
0005432901466	9583	Business	32600.00
0005432822212	9583	Business	32600.00
0005432817500	9583	Economy	10900.00
0005434157415	9583	Economy	10900.00
0005432817502	9583	Economy	10900.00
0005432901444	9583	Economy	10900.00
0005432817495	9583	Economy	10900.00
0005432901474	9583	Economy	10900.00
0005432901465	9583	Economy	10900.00
0005432901460	9583	Economy	10900.00
0005432817503	9583	Economy	11900.00
0005432822211	9583	Economy	11900.00
0005434448320	9583	Economy	11900.00
0005434157437	9583	Economy	11900.00
0005434186172	9583	Economy	10900.00
0005432901469	9583	Economy	10900.00
0005432817505	9583	Economy	10900.00
0005432817515	9583	Economy	10900.00
0005432817499	9583	Economy	10900.00
0005432817513	9583	Economy	10900.00
0005432817494	9583	Economy	10900.00
0005432822210	9583	Economy	10900.00
0005432817497	9583	Economy	10900.00
0005432817484	9583	Economy	10900.00
0005432288991	9583	Economy	10900.00
0005432817512	9583	Economy	10900.00
0005434157393	9583	Economy	10900.00
0005432817509	9583	Economy	10900.00
0005432817488	9583	Economy	10900.00
0005432817487	9583	Economy	10900.00
0005432822209	9583	Economy	10900.00
0005432817501	9583	Economy	10900.00
0005432817498	9583	Economy	10900.00
0005432817508	9583	Economy	10900.00
0005432817506	9583	Economy	10900.00
0005432817490	9583	Economy	10900.00
0005434157429	9583	Economy	10900.00
0005432817514	9583	Economy	10900.00
0005432901470	9583	Economy	10900.00
0005432817493	9583	Economy	10900.00
0005432817489	9583	Economy	10900.00
0005432817492	9583	Economy	10900.00
0005432822214	9583	Economy	10900.00
0005432901504	9583	Economy	10900.00
0005432822213	9583	Economy	10900.00
0005432822208	9583	Economy	10900.00
0005432817507	9583	Economy	10900.00
0005432817510	9583	Economy	10900.00
0005432817491	9583	Economy	10900.00
0005432901426	9583	Economy	10900.00
0005432817496	9583	Economy	10900.00
0005434157394	9583	Economy	10900.00
0005432817485	9583	Economy	10900.00
0005434157428	9583	Economy	10900.00
0005434157472	9583	Economy	10900.00
0005432817486	9583	Economy	10900.00
0005432288989	9583	Economy	10900.00
0005432901454	9583	Economy	10900.00
0005432288990	9583	Economy	10900.00
0005434448319	9583	Economy	10900.00
0005432817511	9583	Economy	10900.00
0005434157447	9583	Economy	10900.00
0005432288988	9583	Economy	10900.00
0005432817126	28966	Business	32600.00
0005432822139	28966	Business	32600.00
0005434157488	28966	Business	32600.00
0005432822152	28966	Business	32600.00
0005434157490	28966	Business	32600.00
0005432817430	28966	Business	32600.00
0005432822149	28966	Business	32600.00
0005432901628	28966	Business	32600.00
0005434448284	28966	Business	32600.00
0005434186200	28966	Business	32600.00
0005432901629	28966	Business	32600.00
0005432817156	28966	Economy	10900.00
0005432817149	28966	Economy	10900.00
0005434186199	28966	Economy	10900.00
0005432817144	28966	Economy	10900.00
0005432817142	28966	Economy	10900.00
0005432817147	28966	Economy	10900.00
0005434448279	28966	Economy	10900.00
0005432901630	28966	Economy	10900.00
0005432901633	28966	Economy	11900.00
0005432901618	28966	Economy	11900.00
0005432817291	28966	Economy	11900.00
0005432901627	28966	Economy	10900.00
0005432817157	28966	Economy	10900.00
0005432817276	28966	Economy	10900.00
0005432817282	28966	Economy	10900.00
0005432817214	28966	Economy	10900.00
0005432817290	28966	Economy	10900.00
0005432901625	28966	Economy	10900.00
0005432817180	28966	Economy	10900.00
0005432817247	28966	Economy	10900.00
0005432817323	28966	Economy	10900.00
0005432817143	28966	Economy	10900.00
0005432822145	28966	Economy	10900.00
0005432901617	28966	Economy	10900.00
0005432817251	28966	Economy	10900.00
0005432817196	28966	Economy	10900.00
0005432901626	28966	Economy	10900.00
0005434157484	28966	Economy	10900.00
0005434186198	28966	Economy	10900.00
0005434157486	28966	Economy	10900.00
0005432822151	28966	Economy	10900.00
0005432822126	28966	Economy	10900.00
0005432901620	28966	Economy	10900.00
0005432822137	28966	Economy	10900.00
0005432901632	28966	Economy	10900.00
0005432817242	28966	Economy	10900.00
0005432817296	28966	Economy	10900.00
0005434157487	28966	Economy	10900.00
0005432817145	28966	Economy	10900.00
0005432817230	28966	Economy	10900.00
0005432817250	28966	Economy	10900.00
0005432817324	28966	Economy	10900.00
0005432901631	28966	Economy	10900.00
0005432901622	28966	Economy	10900.00
0005432817330	28966	Economy	10900.00
0005432817231	28966	Economy	10900.00
0005432901624	28966	Economy	10900.00
0005432817193	28966	Economy	10900.00
0005432817213	28966	Economy	10900.00
0005432822144	28966	Economy	10900.00
0005432817148	28966	Economy	10900.00
0005432822125	28966	Economy	10900.00
0005434157485	28966	Economy	10900.00
0005432817127	28966	Economy	10900.00
0005432901634	28966	Economy	10900.00
0005432822172	28966	Economy	10900.00
0005432817125	28966	Economy	10900.00
0005432901623	28966	Economy	10900.00
0005432901621	28966	Economy	10900.00
0005432822138	28966	Economy	10900.00
0005432817155	28966	Economy	10900.00
0005432822124	28966	Economy	10900.00
0005434157489	28966	Economy	10900.00
0005434448268	28966	Economy	10900.00
0005432817195	28966	Economy	10900.00
0005432901619	28966	Economy	10900.00
0005432817269	28966	Economy	10900.00
0005432817215	28966	Economy	10900.00
0005432817181	28966	Economy	10900.00
0005432611715	15044	Economy	11000.00
0005432613867	15044	Economy	11000.00
0005435841814	15044	Economy	11000.00
0005432611713	15044	Economy	11000.00
0005432613866	15044	Economy	11000.00
0005432611714	15044	Economy	11000.00
0005432611716	15044	Economy	11000.00
0005432613865	15044	Economy	11000.00
0005432607513	31635	Economy	11000.00
0005432607524	31635	Economy	11000.00
0005432607535	31635	Economy	11000.00
0005432611664	31635	Economy	11000.00
0005432611679	31635	Economy	11000.00
0005432607550	31635	Economy	11000.00
0005432607532	31635	Economy	11000.00
0005432611661	31635	Economy	11000.00
0005432607514	31635	Economy	11000.00
0005432611680	31635	Economy	11000.00
0005432607523	31635	Economy	11000.00
0005432611662	31635	Economy	11000.00
0005432948103	11837	Business	105900.00
0005433569105	11837	Business	105900.00
0005433569096	11837	Business	105900.00
0005433569051	11837	Business	105900.00
0005433569118	11837	Business	105900.00
0005432948027	11837	Business	105900.00
0005432948186	11837	Business	105900.00
0005432948089	11837	Business	105900.00
0005433569087	11837	Business	105900.00
0005433569090	11837	Business	105900.00
0005433569120	11837	Business	105900.00
0005433569065	11837	Business	105900.00
0005432948028	11837	Business	105900.00
0005432948188	11837	Business	105900.00
0005433569101	11837	Business	105900.00
0005433569059	11837	Business	105900.00
0005432948272	11837	Economy	35300.00
0005433569121	11837	Economy	35300.00
0005433569104	11837	Economy	35300.00
0005433569116	11837	Economy	35300.00
0005433569061	11837	Economy	35300.00
0005433569093	11837	Economy	35300.00
0005433569109	11837	Economy	35300.00
0005433569085	11837	Economy	35300.00
0005433569081	11837	Economy	35300.00
0005432948128	11837	Economy	35300.00
0005433569113	11837	Economy	35300.00
0005433569064	11837	Economy	35300.00
0005432948069	11837	Economy	38800.00
0005433569057	11837	Economy	38800.00
0005432948007	11837	Economy	38800.00
0005433569123	11837	Economy	35300.00
0005433569074	11837	Economy	38800.00
0005433569056	11837	Economy	35300.00
0005433569122	11837	Economy	35300.00
0005432948096	11837	Economy	35300.00
0005433569102	11837	Economy	35300.00
0005432948052	11837	Economy	35300.00
0005433569084	11837	Economy	35300.00
0005433569077	11837	Economy	35300.00
0005433569067	11837	Economy	35300.00
0005432948094	11837	Economy	35300.00
0005433569088	11837	Economy	35300.00
0005433569076	11837	Economy	35300.00
0005433569115	11837	Economy	35300.00
0005433569073	11837	Economy	35300.00
0005433569097	11837	Economy	35300.00
0005433569100	11837	Economy	35300.00
0005433569066	11837	Economy	35300.00
0005433569053	11837	Economy	35300.00
0005433569072	11837	Economy	35300.00
0005433569055	11837	Economy	35300.00
0005432947892	11837	Economy	35300.00
0005432948083	11837	Economy	35300.00
0005433569095	11837	Economy	35300.00
0005432948068	11837	Economy	35300.00
0005433569106	11837	Economy	35300.00
0005433569086	11837	Economy	35300.00
0005433569110	11837	Economy	35300.00
0005433569054	11837	Economy	35300.00
0005433569079	11837	Economy	35300.00
0005432948127	11837	Economy	35300.00
0005433569049	11837	Economy	35300.00
0005433569112	11837	Economy	35300.00
0005433569063	11837	Economy	35300.00
0005433569083	11837	Economy	35300.00
0005433569107	11837	Economy	35300.00
0005433569108	11837	Economy	35300.00
0005433569091	11837	Economy	35300.00
0005432948104	11837	Economy	35300.00
0005433569103	11837	Economy	35300.00
0005432948010	11837	Economy	35300.00
0005432948088	11837	Economy	35300.00
0005432948164	11837	Economy	35300.00
0005433569119	11837	Economy	35300.00
0005433569070	11837	Economy	35300.00
0005433569089	11837	Economy	35300.00
0005433569050	11837	Economy	35300.00
0005433569094	11837	Economy	35300.00
0005433569071	11837	Economy	35300.00
0005433569082	11837	Economy	35300.00
0005433569078	11837	Economy	35300.00
0005433569098	11837	Economy	35300.00
0005433569099	11837	Economy	35300.00
0005433569075	11837	Economy	35300.00
0005433569069	11837	Economy	35300.00
0005433569111	11837	Economy	35300.00
0005433569052	11837	Economy	35300.00
0005433569068	11837	Economy	35300.00
0005433569117	11837	Economy	35300.00
0005433569058	11837	Economy	35300.00
0005432948046	11837	Economy	35300.00
0005433569092	11837	Economy	35300.00
0005433569080	11837	Economy	35300.00
0005432948045	11837	Economy	35300.00
0005433569062	11837	Economy	35300.00
0005433569060	11837	Economy	35300.00
0005433569114	11837	Economy	35300.00
0005432948095	11837	Economy	35300.00
0005433568475	25310	Business	105900.00
0005433568528	25310	Business	105900.00
0005433568564	25310	Business	105900.00
0005432948527	25310	Business	105900.00
0005433568529	25310	Business	105900.00
0005433568403	25310	Business	105900.00
0005432948530	25310	Business	105900.00
0005433568588	25310	Business	105900.00
0005433568577	25310	Business	105900.00
0005433568522	25310	Business	105900.00
0005432948543	25310	Business	105900.00
0005433568178	25310	Business	105900.00
0005432948533	25310	Business	105900.00
0005432948519	25310	Business	105900.00
0005433568553	25310	Business	105900.00
0005432948514	25310	Economy	35300.00
0005432948532	25310	Economy	35300.00
0005432948539	25310	Economy	35300.00
0005432948524	25310	Economy	35300.00
0005433568642	25310	Economy	35300.00
0005432948515	25310	Economy	35300.00
0005433568404	25310	Economy	35300.00
0005433568192	25310	Economy	35300.00
0005432948534	25310	Economy	35300.00
0005432948520	25310	Economy	35300.00
0005432948542	25310	Economy	35300.00
0005433568380	25310	Economy	35300.00
0005433568535	25310	Economy	38800.00
0005433568203	25310	Economy	38800.00
0005433568394	25310	Economy	38800.00
0005433568561	25310	Economy	35300.00
0005433568450	25310	Economy	38800.00
0005432948549	25310	Economy	35300.00
0005433568226	25310	Economy	35300.00
0005433568225	25310	Economy	35300.00
0005433568606	25310	Economy	35300.00
0005433568479	25310	Economy	35300.00
0005433568406	25310	Economy	35300.00
0005432948547	25310	Economy	35300.00
0005432948554	25310	Economy	35300.00
0005432948517	25310	Economy	35300.00
0005433568449	25310	Economy	35300.00
0005432948529	25310	Economy	35300.00
0005433568548	25310	Economy	35300.00
0005433568419	25310	Economy	35300.00
0005432948531	25310	Economy	35300.00
0005432948536	25310	Economy	35300.00
0005433568442	25310	Economy	35300.00
0005433568538	25310	Economy	35300.00
0005433568586	25310	Economy	35300.00
0005433568576	25310	Economy	35300.00
0005432948555	25310	Economy	35300.00
0005432948541	25310	Economy	35300.00
0005432948540	25310	Economy	35300.00
0005432948526	25310	Economy	35300.00
0005433568562	25310	Economy	35300.00
0005432948545	25310	Economy	35300.00
0005432948516	25310	Economy	35300.00
0005432948522	25310	Economy	35300.00
0005432948553	25310	Economy	35300.00
0005433568423	25310	Economy	35300.00
0005433568407	25310	Economy	35300.00
0005433568372	25310	Economy	35300.00
0005432948548	25310	Economy	35300.00
0005433568523	25310	Economy	35300.00
0005433568334	25310	Economy	35300.00
0005432948544	25310	Economy	35300.00
0005433568587	25310	Economy	35300.00
0005433568552	25310	Economy	35300.00
0005433568654	25310	Economy	35300.00
0005432948521	25310	Economy	35300.00
0005433568193	25310	Economy	35300.00
0005433568563	25310	Economy	35300.00
0005433568652	25310	Economy	35300.00
0005432948552	25310	Economy	35300.00
0005433568381	25310	Economy	35300.00
0005432948518	25310	Economy	35300.00
0005433568555	25310	Economy	35300.00
0005433568575	25310	Economy	35300.00
0005433568443	25310	Economy	35300.00
0005433568373	25310	Economy	35300.00
0005433568486	25310	Economy	35300.00
0005432948535	25310	Economy	35300.00
0005432948551	25310	Economy	35300.00
0005432948537	25310	Economy	35300.00
0005433568549	25310	Economy	35300.00
0005433568590	25310	Economy	35300.00
0005433568489	25310	Economy	35300.00
0005433568395	25310	Economy	35300.00
0005432948523	25310	Economy	35300.00
0005432948550	25310	Economy	35300.00
0005432948525	25310	Economy	35300.00
0005432948546	25310	Economy	35300.00
0005433568396	25310	Economy	35300.00
0005433568589	25310	Economy	35300.00
0005433568400	25310	Economy	35300.00
0005433568651	25310	Economy	35300.00
0005433568516	25310	Economy	35300.00
0005433568675	25310	Economy	35300.00
0005433568487	25310	Economy	35300.00
0005433568585	25310	Economy	35300.00
0005432948528	25310	Economy	35300.00
0005432948538	25310	Economy	35300.00
0005433808330	14457	Business	117400.00
0005434026702	14457	Business	117400.00
0005432430860	14457	Business	117400.00
0005433808332	14457	Business	117400.00
0005433808333	14457	Business	117400.00
0005433808344	14457	Business	117400.00
0005433812877	14457	Business	117400.00
0005433812875	14457	Business	117400.00
0005432430871	14457	Economy	39100.00
0005434026707	14457	Economy	39100.00
0005432430862	14457	Economy	39100.00
0005432430859	14457	Economy	39100.00
0005433808324	14457	Economy	39100.00
0005432430866	14457	Economy	39100.00
0005433812867	14457	Economy	39100.00
0005433812865	14457	Economy	39100.00
0005433808321	14457	Economy	39100.00
0005432430861	14457	Economy	39100.00
0005432430863	14457	Economy	39100.00
0005433808347	14457	Economy	39100.00
0005434026708	14457	Economy	39100.00
0005434026704	14457	Economy	39100.00
0005432430868	14457	Economy	39100.00
0005433808328	14457	Economy	39100.00
0005432430867	14457	Economy	39100.00
0005433812873	14457	Economy	39100.00
0005432430857	14457	Economy	39100.00
0005432430865	14457	Economy	39100.00
0005432430870	14457	Economy	39100.00
0005434026703	14457	Economy	39100.00
0005433812874	14457	Economy	39100.00
0005432430858	14457	Economy	39100.00
0005432430864	14457	Economy	39100.00
0005433808322	14457	Economy	39100.00
0005433812864	14457	Economy	39100.00
0005433808345	14457	Economy	39100.00
0005433812876	14457	Economy	39100.00
0005433808325	14457	Economy	39100.00
0005434026706	14457	Economy	39100.00
0005433808310	14457	Economy	39100.00
0005433808331	14457	Economy	39100.00
0005433808346	14457	Economy	39100.00
0005433808343	14457	Economy	39100.00
0005433808342	14457	Economy	39100.00
0005434026705	14457	Economy	39100.00
0005432430869	14457	Economy	39100.00
0005433812872	14457	Economy	39100.00
0005434026701	14457	Economy	39100.00
0005434654722	5364	Business	67200.00
0005432114207	5364	Business	67200.00
0005432114206	5364	Business	67200.00
0005434654702	5364	Business	67200.00
0005434654727	5364	Economy	22400.00
0005435340147	5364	Economy	22400.00
0005434654709	5364	Economy	22400.00
0005434654700	5364	Economy	22400.00
0005435340165	5364	Economy	22400.00
0005435340149	5364	Economy	22400.00
0005434654705	5364	Economy	22400.00
0005434654711	5364	Economy	22400.00
0005432114208	5364	Economy	22400.00
0005434654706	5364	Economy	24600.00
0005434654715	5364	Economy	22400.00
0005435555359	5364	Economy	22400.00
0005435340141	5364	Economy	22400.00
0005434654716	5364	Economy	22400.00
0005435340114	5364	Economy	22400.00
0005435555350	5364	Economy	22400.00
0005435340102	5364	Economy	22400.00
0005435340155	5364	Economy	22400.00
0005434654701	5364	Economy	22400.00
0005434654719	5364	Economy	22400.00
0005434654723	5364	Economy	22400.00
0005434654718	5364	Economy	22400.00
0005434654698	5364	Economy	22400.00
0005435340140	5364	Economy	22400.00
0005434654713	5364	Economy	22400.00
0005435340135	5364	Economy	22400.00
0005434654712	5364	Economy	22400.00
0005435340120	5364	Economy	22400.00
0005434654724	5364	Economy	22400.00
0005434654726	5364	Economy	22400.00
0005434654714	5364	Economy	22400.00
0005435340146	5364	Economy	22400.00
0005435340169	5364	Economy	22400.00
0005435340157	5364	Economy	22400.00
0005434654708	5364	Economy	22400.00
0005435340142	5364	Economy	22400.00
0005435340144	5364	Economy	22400.00
0005434654704	5364	Economy	22400.00
0005434654717	5364	Economy	22400.00
0005435340156	5364	Economy	22400.00
0005434654721	5364	Economy	22400.00
0005434656559	5364	Economy	22400.00
0005434656558	5364	Economy	22400.00
0005435555358	5364	Economy	22400.00
0005434654699	5364	Economy	22400.00
0005434654720	5364	Economy	22400.00
0005434654725	5364	Economy	22400.00
0005434654710	5364	Economy	22400.00
0005434654707	5364	Economy	22400.00
0005434654703	5364	Economy	22400.00
0005434654508	12535	Business	67200.00
0005434654524	12535	Business	67200.00
0005434654417	12535	Business	67200.00
0005435340276	12535	Business	67200.00
0005435340281	12535	Business	67200.00
0005435340273	12535	Economy	22400.00
0005434654416	12535	Economy	22400.00
0005434654509	12535	Economy	24600.00
0005435340270	12535	Economy	24600.00
0005434654546	12535	Economy	22400.00
0005434654486	12535	Economy	22400.00
0005434654488	12535	Economy	22400.00
0005434654487	12535	Economy	22400.00
0005435340271	12535	Economy	22400.00
0005434654414	12535	Economy	22400.00
0005434654542	12535	Economy	22400.00
0005434654479	12535	Economy	22400.00
0005434654579	12535	Economy	22400.00
0005435340280	12535	Economy	22400.00
0005434654543	12535	Economy	22400.00
0005434654626	12535	Economy	22400.00
0005435340277	12535	Economy	22400.00
0005434654548	12535	Economy	22400.00
0005434654376	12535	Economy	22400.00
0005435340278	12535	Economy	22400.00
0005434654480	12535	Economy	22400.00
0005435340275	12535	Economy	22400.00
0005434654578	12535	Economy	22400.00
0005435340285	12535	Economy	22400.00
0005435340274	12535	Economy	22400.00
0005434654547	12535	Economy	22400.00
0005435340284	12535	Economy	22400.00
0005435340283	12535	Economy	22400.00
0005434654413	12535	Economy	22400.00
0005434654636	12535	Economy	22400.00
0005435340272	12535	Economy	22400.00
0005435555373	12535	Economy	22400.00
0005435555372	12535	Economy	22400.00
0005434654429	12535	Economy	22400.00
0005435340286	12535	Economy	22400.00
0005435340282	12535	Economy	22400.00
0005435340279	12535	Economy	22400.00
0005433716035	7446	Business	32000.00
0005433716030	7446	Business	32000.00
0005433715991	7446	Business	32000.00
0005433716011	7446	Business	32000.00
0005435266115	7446	Business	32000.00
0005433715997	7446	Business	32000.00
0005433716019	7446	Business	32000.00
0005433715994	7446	Business	32000.00
0005433715990	7446	Business	32000.00
0005433716027	7446	Business	32000.00
0005435266109	7446	Economy	10700.00
0005433716012	7446	Economy	10700.00
0005432428905	7446	Economy	10700.00
0005433656671	7446	Economy	10700.00
0005433716008	7446	Economy	10700.00
0005433716024	7446	Economy	10700.00
0005433716031	7446	Economy	10700.00
0005433688810	7446	Economy	10700.00
0005433722227	7446	Economy	10700.00
0005433716023	7446	Economy	10700.00
0005433716006	7446	Economy	10700.00
0005433716025	7446	Economy	10700.00
0005433716018	7446	Economy	10700.00
0005432078113	7446	Economy	10700.00
0005433716034	7446	Economy	10700.00
0005433716010	7446	Economy	10700.00
0005433716020	7446	Economy	10700.00
0005433716038	7446	Economy	10700.00
0005433690927	7446	Economy	10700.00
0005433690928	7446	Economy	10700.00
0005433716014	7446	Economy	10700.00
0005432078110	7446	Economy	10700.00
0005435266113	7446	Economy	10700.00
0005433689911	7446	Economy	11700.00
0005433715998	7446	Economy	11700.00
0005432078112	7446	Economy	11700.00
0005433719140	7446	Economy	11700.00
0005433716022	7446	Economy	11700.00
0005433716000	7446	Economy	10700.00
0005435266111	7446	Economy	10700.00
0005432078114	7446	Economy	10700.00
0005433715993	7446	Economy	10700.00
0005435266107	7446	Economy	10700.00
0005433716026	7446	Economy	10700.00
0005433716001	7446	Economy	10700.00
0005435266108	7446	Economy	10700.00
0005432428906	7446	Economy	10700.00
0005433716003	7446	Economy	10700.00
0005433716016	7446	Economy	10700.00
0005433716032	7446	Economy	10700.00
0005433716017	7446	Economy	10700.00
0005433719141	7446	Economy	10700.00
0005433716002	7446	Economy	10700.00
0005433716036	7446	Economy	10700.00
0005433719142	7446	Economy	10700.00
0005432428896	7446	Economy	10700.00
0005435266106	7446	Economy	10700.00
0005433715995	7446	Economy	10700.00
0005433716033	7446	Economy	10700.00
0005433715999	7446	Economy	10700.00
0005433656672	7446	Economy	10700.00
0005435266114	7446	Economy	10700.00
0005433715987	7446	Economy	10700.00
0005433722229	7446	Economy	10700.00
0005433716015	7446	Economy	10700.00
0005433716037	7446	Economy	10700.00
0005433715996	7446	Economy	10700.00
0005433715988	7446	Economy	10700.00
0005433722228	7446	Economy	10700.00
0005433715989	7446	Economy	10700.00
0005433715992	7446	Economy	10700.00
0005433716007	7446	Economy	10700.00
0005432078111	7446	Economy	10700.00
0005433722226	7446	Economy	10700.00
0005433716004	7446	Economy	10700.00
0005432428897	7446	Economy	10700.00
0005433716005	7446	Economy	10700.00
0005432078115	7446	Economy	10700.00
0005433716009	7446	Economy	10700.00
0005433716021	7446	Economy	10700.00
0005433716028	7446	Economy	10700.00
0005432428904	7446	Economy	10700.00
0005433722225	7446	Economy	10700.00
0005433716013	7446	Economy	10700.00
0005433716029	7446	Economy	10700.00
0005433656670	7446	Economy	10700.00
0005433685505	29204	Business	32000.00
0005433719101	29204	Business	32000.00
0005433722151	29204	Business	32000.00
0005432428934	29204	Business	32000.00
0005433715512	29204	Business	32000.00
0005433715561	29204	Business	32000.00
0005433656635	29204	Business	32000.00
0005433722160	29204	Economy	10700.00
0005433715688	29204	Economy	10700.00
0005433715445	29204	Economy	10700.00
0005433715764	29204	Economy	10700.00
0005433715618	29204	Economy	10700.00
0005433719121	29204	Economy	10700.00
0005433688785	29204	Economy	10700.00
0005433722166	29204	Economy	10700.00
0005433715848	29204	Economy	10700.00
0005433715462	29204	Economy	10700.00
0005432428930	29204	Economy	10700.00
0005433715826	29204	Economy	10700.00
0005432428932	29204	Economy	10700.00
0005433715574	29204	Economy	10700.00
0005433715676	29204	Economy	10700.00
0005432428933	29204	Economy	10700.00
0005433722154	29204	Economy	10700.00
0005433715871	29204	Economy	10700.00
0005433685520	29204	Economy	10700.00
0005433715687	29204	Economy	10700.00
0005433719120	29204	Economy	10700.00
0005433656636	29204	Economy	10700.00
0005433722147	29204	Economy	10700.00
0005433715774	29204	Economy	10700.00
0005433715695	29204	Economy	10700.00
0005433715490	29204	Economy	10700.00
0005433715456	29204	Economy	10700.00
0005433715696	29204	Economy	11700.00
0005433715628	29204	Economy	11700.00
0005433715274	29204	Economy	11700.00
0005433715544	29204	Economy	11700.00
0005433722148	29204	Economy	10700.00
0005433715619	29204	Economy	10700.00
0005433715689	29204	Economy	10700.00
0005433719100	29204	Economy	10700.00
0005433715636	29204	Economy	10700.00
0005433715594	29204	Economy	10700.00
0005433715575	29204	Economy	10700.00
0005433715516	29204	Economy	10700.00
0005432006764	29204	Economy	10700.00
0005433688797	29204	Economy	10700.00
0005433722161	29204	Economy	10700.00
0005433722116	29204	Economy	10700.00
0005433715464	29204	Economy	10700.00
0005433715667	29204	Economy	10700.00
0005433715583	29204	Economy	10700.00
0005433715641	29204	Economy	10700.00
0005433715765	29204	Economy	10700.00
0005433715513	29204	Economy	10700.00
0005433715685	29204	Economy	10700.00
0005433715625	29204	Economy	10700.00
0005433715501	29204	Economy	10700.00
0005433715552	29204	Economy	10700.00
0005433715629	29204	Economy	10700.00
0005433715531	29204	Economy	10700.00
0005433688790	29204	Economy	10700.00
0005433715457	29204	Economy	10700.00
0005433715612	29204	Economy	10700.00
0005433715697	29204	Economy	10700.00
0005433715434	29204	Economy	10700.00
0005433715463	29204	Economy	10700.00
0005433715606	29204	Economy	10700.00
0005433685506	29204	Economy	10700.00
0005433719102	29204	Economy	10700.00
0005433715642	29204	Economy	10700.00
0005433719113	29204	Economy	10700.00
0005433715613	29204	Economy	10700.00
0005433715461	29204	Economy	10700.00
0005433715615	29204	Economy	10700.00
0005432428931	29204	Economy	10700.00
0005433715752	29204	Economy	10700.00
0005433722155	29204	Economy	10700.00
0005433722162	29204	Economy	10700.00
0005433715708	29204	Economy	10700.00
0005433715849	29204	Economy	10700.00
0005433715675	29204	Economy	10700.00
0005434184646	8669	Business	36500.00
0005434095282	8669	Business	36500.00
0005434182069	8669	Economy	12200.00
0005434182107	8669	Economy	13400.00
0005434095293	8669	Economy	12200.00
0005434095286	8669	Economy	12200.00
0005434095288	8669	Economy	12200.00
0005434095294	8669	Economy	12200.00
0005434095284	8669	Economy	12200.00
0005434095283	8669	Economy	12200.00
0005434184645	8669	Economy	12200.00
0005434095289	8669	Economy	12200.00
0005434095287	8669	Economy	12200.00
0005434182099	8669	Economy	12200.00
0005434095281	8669	Economy	12200.00
0005434095285	8669	Economy	12200.00
0005434182059	8669	Economy	12200.00
0005434095291	8669	Economy	12200.00
0005434095290	8669	Economy	12200.00
0005434095292	8669	Economy	12200.00
0005434182106	8669	Economy	12200.00
0005434095295	8669	Economy	12200.00
0005434182085	8669	Economy	12200.00
0005434182124	8669	Economy	12200.00
0005434182058	8669	Economy	12200.00
0005434095114	11637	Business	36500.00
0005434095159	11637	Business	36500.00
0005434184665	11637	Business	36500.00
0005434095168	11637	Business	36500.00
0005434182199	11637	Business	36500.00
0005434095164	11637	Economy	12200.00
0005434182193	11637	Economy	12200.00
0005434182200	11637	Economy	12200.00
0005434182194	11637	Economy	12200.00
0005434184666	11637	Economy	13400.00
0005434182201	11637	Economy	13400.00
0005434182196	11637	Economy	12200.00
0005434095244	11637	Economy	12200.00
0005434095147	11637	Economy	12200.00
0005434182189	11637	Economy	12200.00
0005434143714	11637	Economy	12200.00
0005434095167	11637	Economy	12200.00
0005434182197	11637	Economy	12200.00
0005434184664	11637	Economy	12200.00
0005434095103	11637	Economy	12200.00
0005434095184	11637	Economy	12200.00
0005434182192	11637	Economy	12200.00
0005434095191	11637	Economy	12200.00
0005434143713	11637	Economy	12200.00
0005434182198	11637	Economy	12200.00
0005434182190	11637	Economy	12200.00
0005434095107	11637	Economy	12200.00
0005434183580	11637	Economy	12200.00
0005434095170	11637	Economy	12200.00
0005434182191	11637	Economy	12200.00
0005434095187	11637	Economy	12200.00
0005434095174	11637	Economy	12200.00
0005434182195	11637	Economy	12200.00
0005434183579	11637	Economy	12200.00
0005435732339	1466	Business	33000.00
0005433397780	1466	Business	33000.00
0005433397625	1466	Business	33000.00
0005433397690	1466	Business	33000.00
0005433397522	1466	Business	33000.00
0005435732332	1466	Business	33000.00
0005435732343	1466	Business	33000.00
0005435732344	1466	Business	33000.00
0005433397566	1466	Economy	11000.00
0005433397801	1466	Economy	11000.00
0005433397544	1466	Economy	11000.00
0005433397537	1466	Economy	11000.00
0005435732337	1466	Economy	11000.00
0005433397774	1466	Economy	11000.00
0005433397702	1466	Economy	11000.00
0005433397799	1466	Economy	11000.00
0005435732342	1466	Economy	11000.00
0005435732336	1466	Economy	12100.00
0005432297278	1466	Economy	12100.00
0005433397761	1466	Economy	12100.00
0005435732338	1466	Economy	12100.00
0005433397978	1466	Economy	12100.00
0005433397766	1466	Economy	11000.00
0005433456975	1466	Economy	11000.00
0005433397692	1466	Economy	11000.00
0005433397608	1466	Economy	11000.00
0005433397691	1466	Economy	11000.00
0005433397676	1466	Economy	11000.00
0005435732330	1466	Economy	11000.00
0005433397808	1466	Economy	11000.00
0005433397696	1466	Economy	11000.00
0005435732327	1466	Economy	11000.00
0005433456974	1466	Economy	11000.00
0005433397791	1466	Economy	11000.00
0005435732331	1466	Economy	11000.00
0005433397684	1466	Economy	11000.00
0005435732345	1466	Economy	11000.00
0005433397657	1466	Economy	11000.00
0005435732341	1466	Economy	11000.00
0005433456972	1466	Economy	11000.00
0005432297279	1466	Economy	11000.00
0005435732335	1466	Economy	11000.00
0005433397520	1466	Economy	11000.00
0005435732333	1466	Economy	11000.00
0005433397535	1466	Economy	11000.00
0005433397381	1466	Economy	11000.00
0005435732329	1466	Economy	11000.00
0005433397598	1466	Economy	11000.00
0005433397792	1466	Economy	11000.00
0005433397626	1466	Economy	11000.00
0005433397817	1466	Economy	11000.00
0005433397798	1466	Economy	11000.00
0005435732334	1466	Economy	11000.00
0005432906524	1466	Economy	11000.00
0005432906525	1466	Economy	11000.00
0005432297280	1466	Economy	11000.00
0005433397567	1466	Economy	11000.00
0005433397837	1466	Economy	11000.00
0005433397645	1466	Economy	11000.00
0005433397521	1466	Economy	11000.00
0005433456973	1466	Economy	11000.00
0005433397545	1466	Economy	11000.00
0005435732346	1466	Economy	11000.00
0005433397807	1466	Economy	11000.00
0005433397786	1466	Economy	11000.00
0005433397644	1466	Economy	11000.00
0005435732340	1466	Economy	11000.00
0005435732328	1466	Economy	11000.00
0005433397536	1466	Economy	11000.00
0005433397611	1466	Economy	11000.00
0005433456971	1466	Economy	11000.00
0005433397977	1466	Economy	11000.00
0005433397800	1466	Economy	11000.00
0005433398083	19279	Business	33000.00
0005433398109	19279	Business	33000.00
0005433398122	19279	Business	33000.00
0005435732227	19279	Business	33000.00
0005433398120	19279	Business	33000.00
0005433398093	19279	Business	33000.00
0005432906537	19279	Business	33000.00
0005433398104	19279	Business	33000.00
0005433398076	19279	Business	33000.00
0005433398110	19279	Business	33000.00
0005435732226	19279	Business	33000.00
0005433398088	19279	Economy	11000.00
0005435732247	19279	Economy	11000.00
0005433456933	19279	Economy	11000.00
0005433456945	19279	Economy	11000.00
0005433398080	19279	Economy	11000.00
0005432906540	19279	Economy	11000.00
0005433398084	19279	Economy	12100.00
0005435732281	19279	Economy	12100.00
0005433398089	19279	Economy	12100.00
0005435732258	19279	Economy	12100.00
0005432906539	19279	Economy	11000.00
0005433398101	19279	Economy	11000.00
0005433398100	19279	Economy	11000.00
0005433398090	19279	Economy	11000.00
0005432906538	19279	Economy	11000.00
0005433398075	19279	Economy	11000.00
0005433398094	19279	Economy	11000.00
0005433398112	19279	Economy	11000.00
0005433398086	19279	Economy	11000.00
0005433398117	19279	Economy	11000.00
0005433456918	19279	Economy	11000.00
0005433398107	19279	Economy	11000.00
0005433398113	19279	Economy	11000.00
0005433398105	19279	Economy	11000.00
0005435732276	19279	Economy	11000.00
0005435732292	19279	Economy	11000.00
0005433398087	19279	Economy	11000.00
0005435732193	19279	Economy	11000.00
0005433456939	19279	Economy	11000.00
0005433398121	19279	Economy	11000.00
0005433398102	19279	Economy	11000.00
0005433398108	19279	Economy	11000.00
0005433398118	19279	Economy	11000.00
0005433398106	19279	Economy	11000.00
0005433398091	19279	Economy	11000.00
0005433398123	19279	Economy	11000.00
0005433398119	19279	Economy	11000.00
0005433398098	19279	Economy	11000.00
0005435732291	19279	Economy	11000.00
0005433398099	19279	Economy	11000.00
0005433398115	19279	Economy	11000.00
0005433398116	19279	Economy	11000.00
0005433398095	19279	Economy	11000.00
0005433456941	19279	Economy	11000.00
0005433456919	19279	Economy	11000.00
0005433398082	19279	Economy	11000.00
0005433398081	19279	Economy	11000.00
0005433398079	19279	Economy	11000.00
0005433398111	19279	Economy	11000.00
0005433456936	19279	Economy	11000.00
0005435732192	19279	Economy	11000.00
0005433398085	19279	Economy	11000.00
0005433398097	19279	Economy	11000.00
0005433398114	19279	Economy	11000.00
0005433398092	19279	Economy	11000.00
0005433398077	19279	Economy	11000.00
0005435732259	19279	Economy	11000.00
0005433398103	19279	Economy	11000.00
0005433398096	19279	Economy	11000.00
0005433456940	19279	Economy	11000.00
0005433398078	19279	Economy	11000.00
0005434443570	17350	Economy	15600.00
0005434443579	17350	Economy	14100.00
0005434443571	17350	Economy	14100.00
0005434443614	17350	Economy	14100.00
0005434443515	17350	Economy	14100.00
0005434443498	17350	Economy	14100.00
0005434443516	17350	Economy	14100.00
0005434443615	17350	Economy	14100.00
0005434443639	17350	Economy	14100.00
0005434443590	17350	Economy	14100.00
0005434443714	20612	Economy	15600.00
0005434443707	20612	Economy	15600.00
0005434443715	20612	Economy	15600.00
0005434443712	20612	Economy	14100.00
0005434443705	20612	Economy	14100.00
0005434443713	20612	Economy	14100.00
0005434443719	20612	Economy	14100.00
0005434443716	20612	Economy	14100.00
0005434443709	20612	Economy	14100.00
0005434443708	20612	Economy	14100.00
0005434443711	20612	Economy	14100.00
0005434443720	20612	Economy	14100.00
0005434443717	20612	Economy	14100.00
0005434443710	20612	Economy	14100.00
0005434443706	20612	Economy	14100.00
0005434443718	20612	Economy	14100.00
0005434954614	7241	Economy	5800.00
0005434954610	7241	Economy	5800.00
0005434954612	7241	Economy	5800.00
0005434954615	7241	Economy	5800.00
0005434954611	7241	Economy	5800.00
0005434954613	7241	Economy	5800.00
0005435377583	28331	Economy	5800.00
0005435377581	28331	Economy	5800.00
0005435377582	28331	Economy	5800.00
0005434954563	28331	Economy	5800.00
0005434954562	28331	Economy	5800.00
0005434351709	4454	Economy	15400.00
0005434351707	4454	Economy	14000.00
0005435893584	4454	Economy	14000.00
0005435893551	4454	Economy	14000.00
0005434351701	4454	Economy	14000.00
0005434351705	4454	Economy	14000.00
0005435893565	4454	Economy	14000.00
0005434351713	4454	Economy	14000.00
0005434351711	4454	Economy	14000.00
0005434351700	4454	Economy	14000.00
0005434351712	4454	Economy	14000.00
0005435893552	4454	Economy	14000.00
0005434351702	4454	Economy	14000.00
0005434351706	4454	Economy	14000.00
0005435893553	4454	Economy	14000.00
0005434351703	4454	Economy	14000.00
0005435893583	4454	Economy	14000.00
0005434183557	4454	Economy	14000.00
0005434351710	4454	Economy	14000.00
0005434351704	4454	Economy	14000.00
0005434351708	4454	Economy	14000.00
0005434351596	29648	Economy	15400.00
0005434351601	29648	Economy	15400.00
0005434351556	29648	Economy	15400.00
0005434351612	29648	Economy	14000.00
0005434351560	29648	Economy	14000.00
0005435893639	29648	Economy	14000.00
0005434351598	29648	Economy	14000.00
0005435893638	29648	Economy	14000.00
0005435893636	29648	Economy	14000.00
0005434351568	29648	Economy	14000.00
0005434351607	29648	Economy	14000.00
0005434351585	29648	Economy	14000.00
0005434351548	29648	Economy	14000.00
0005435893640	29648	Economy	14000.00
0005435893637	29648	Economy	14000.00
0005434351599	29648	Economy	14000.00
0005434351609	29648	Economy	14000.00
0005434351597	29648	Economy	14000.00
0005434351608	29648	Economy	14000.00
0005434351549	29648	Economy	14000.00
0005434351602	29648	Economy	14000.00
0005433342310	1061	Business	30600.00
0005433341733	1061	Business	30600.00
0005433342258	1061	Business	30600.00
0005433342518	1061	Business	30600.00
0005433342539	1061	Business	30600.00
0005433342095	1061	Business	30600.00
0005433342340	1061	Business	30600.00
0005433342473	1061	Business	30600.00
0005433342305	1061	Business	30600.00
0005433158111	1061	Business	30600.00
0005433342306	1061	Business	30600.00
0005433342444	1061	Business	30600.00
0005433342560	1061	Business	30600.00
0005435545749	1061	Business	30600.00
0005435092086	1061	Business	30600.00
0005433342578	1061	Business	30600.00
0005433342480	1061	Business	30600.00
0005433342161	1061	Business	30600.00
0005433342315	1061	Business	30600.00
0005433342445	1061	Economy	11200.00
0005433342156	1061	Economy	11200.00
0005435545750	1061	Economy	10200.00
0005433269655	1061	Economy	10200.00
0005433342446	1061	Economy	10200.00
0005433341927	1061	Economy	10200.00
0005433341906	1061	Economy	10200.00
0005433159291	1061	Economy	10200.00
0005433342246	1061	Economy	10200.00
0005433342422	1061	Economy	10200.00
0005433269671	1061	Economy	10200.00
0005435092077	1061	Economy	10200.00
0005433462749	1061	Economy	10200.00
0005435092083	1061	Economy	10200.00
0005435545747	1061	Economy	10200.00
0005433341947	1061	Economy	10200.00
0005433341926	1061	Economy	10200.00
0005433341934	1061	Economy	10200.00
0005434446520	1061	Economy	10200.00
0005435092081	1061	Economy	10200.00
0005433342579	1061	Economy	10200.00
0005433269656	1061	Economy	10200.00
0005433342433	1061	Economy	10200.00
0005433342401	1061	Economy	10200.00
0005433342171	1061	Economy	10200.00
0005433342272	1061	Economy	10200.00
0005433341925	1061	Economy	10200.00
0005433342126	1061	Economy	10200.00
0005435545741	1061	Economy	10200.00
0005433342269	1061	Economy	10200.00
0005433342402	1061	Economy	10200.00
0005433342552	1061	Economy	10200.00
0005435545742	1061	Economy	10200.00
0005433342282	1061	Economy	10200.00
0005433341935	1061	Economy	10200.00
0005433159301	1061	Economy	10200.00
0005433342474	1061	Economy	10200.00
0005435092078	1061	Economy	10200.00
0005435092082	1061	Economy	10200.00
0005433342714	1061	Economy	10200.00
0005433342094	1061	Economy	10200.00
0005433342003	1061	Economy	10200.00
0005433342127	1061	Economy	10200.00
0005433269680	1061	Economy	10200.00
0005434445250	1061	Economy	10200.00
0005433342681	1061	Economy	10200.00
0005435545748	1061	Economy	10200.00
0005433342285	1061	Economy	10200.00
0005433341908	1061	Economy	10200.00
0005433342507	1061	Economy	10200.00
0005433342506	1061	Economy	10200.00
0005433342550	1061	Economy	10200.00
0005433342792	1061	Economy	10200.00
0005433342553	1061	Economy	10200.00
0005433341909	1061	Economy	10200.00
0005433341820	1061	Economy	10200.00
0005433342304	1061	Economy	10200.00
0005433342508	1061	Economy	10200.00
0005434445251	1061	Economy	10200.00
0005433342395	1061	Economy	10200.00
0005433158109	1061	Economy	10200.00
0005433342241	1061	Economy	10200.00
0005433342366	1061	Economy	10200.00
0005433342160	1061	Economy	10200.00
0005435092080	1061	Economy	11200.00
0005435545751	1061	Economy	11200.00
0005433342332	1061	Economy	10200.00
0005435092079	1061	Economy	11200.00
0005433342430	1061	Economy	10200.00
0005435545744	1061	Economy	10200.00
0005433342116	1061	Economy	10200.00
0005433342494	1061	Economy	10200.00
0005433342495	1061	Economy	10200.00
0005433342423	1061	Economy	10200.00
0005433463902	1061	Economy	10200.00
0005433341919	1061	Economy	10200.00
0005433342830	1061	Economy	10200.00
0005435545743	1061	Economy	10200.00
0005433342360	1061	Economy	10200.00
0005433341939	1061	Economy	10200.00
0005433342359	1061	Economy	10200.00
0005433342104	1061	Economy	10200.00
0005433342038	1061	Economy	10200.00
0005433342469	1061	Economy	10200.00
0005433342570	1061	Economy	10200.00
0005433342144	1061	Economy	10200.00
0005435545746	1061	Economy	10200.00
0005433342325	1061	Economy	10200.00
0005433342713	1061	Economy	10200.00
0005433158116	1061	Economy	10200.00
0005433158110	1061	Economy	10200.00
0005435092084	1061	Economy	10200.00
0005433341910	1061	Economy	10200.00
0005433342039	1061	Economy	10200.00
0005433342479	1061	Economy	10200.00
0005433341819	1061	Economy	10200.00
0005433341907	1061	Economy	10200.00
0005433342429	1061	Economy	10200.00
0005433342379	1061	Economy	10200.00
0005432293211	1061	Economy	10200.00
0005433342283	1061	Economy	10200.00
0005433342139	1061	Economy	10200.00
0005433342591	1061	Economy	10200.00
0005433342284	1061	Economy	10200.00
0005433342324	1061	Economy	10200.00
0005433342512	1061	Economy	10200.00
0005433342047	1061	Economy	10200.00
0005433342145	1061	Economy	10200.00
0005433342358	1061	Economy	10200.00
0005432293210	1061	Economy	10200.00
0005435545745	1061	Economy	10200.00
0005433342481	1061	Economy	10200.00
0005435092085	1061	Economy	10200.00
0005433463903	1061	Economy	10200.00
0005433269672	1061	Economy	10200.00
0005433342082	1061	Economy	10200.00
0005433342286	1061	Economy	10200.00
0005433342561	1061	Economy	10200.00
0005434445249	1061	Economy	10200.00
0005433342331	1061	Economy	10200.00
0005433343131	17039	Business	30600.00
0005433343146	17039	Business	30600.00
0005433343204	17039	Business	30600.00
0005433343154	17039	Business	30600.00
0005433159315	17039	Business	30600.00
0005435508247	17039	Business	30600.00
0005433343163	17039	Business	30600.00
0005433343197	17039	Business	30600.00
0005433343126	17039	Business	30600.00
0005433343212	17039	Business	30600.00
0005433343201	17039	Business	30600.00
0005435091971	17039	Business	30600.00
0005433343179	17039	Business	30600.00
0005433343184	17039	Business	30600.00
0005433159316	17039	Business	30600.00
0005433343161	17039	Business	30600.00
0005433343147	17039	Business	30600.00
0005433343196	17039	Business	30600.00
0005433343133	17039	Business	30600.00
0005433343186	17039	Business	30600.00
0005433343141	17039	Business	30600.00
0005433343149	17039	Economy	11200.00
0005433343194	17039	Economy	11200.00
0005433343150	17039	Economy	11200.00
0005433269721	17039	Economy	10200.00
0005435508262	17039	Economy	10200.00
0005433343187	17039	Economy	10200.00
0005433343188	17039	Economy	10200.00
0005433269723	17039	Economy	10200.00
0005433343190	17039	Economy	10200.00
0005433343125	17039	Economy	10200.00
0005433343112	17039	Economy	10200.00
0005435092006	17039	Economy	10200.00
0005433343180	17039	Economy	10200.00
0005433343198	17039	Economy	10200.00
0005433343144	17039	Economy	10200.00
0005433343130	17039	Economy	10200.00
0005433343129	17039	Economy	10200.00
0005433343115	17039	Economy	10200.00
0005435508276	17039	Economy	10200.00
0005433343193	17039	Economy	10200.00
0005433343165	17039	Economy	10200.00
0005433343153	17039	Economy	10200.00
0005433343160	17039	Economy	10200.00
0005433343210	17039	Economy	10200.00
0005433343138	17039	Economy	10200.00
0005435508201	17039	Economy	10200.00
0005433343182	17039	Economy	10200.00
0005433343128	17039	Economy	10200.00
0005433343207	17039	Economy	10200.00
0005433343139	17039	Economy	10200.00
0005435091990	17039	Economy	10200.00
0005435091988	17039	Economy	10200.00
0005433343124	17039	Economy	10200.00
0005433343159	17039	Economy	10200.00
0005433269722	17039	Economy	10200.00
0005435092000	17039	Economy	10200.00
0005433343169	17039	Economy	10200.00
0005433343203	17039	Economy	10200.00
0005433343199	17039	Economy	10200.00
0005433343127	17039	Economy	10200.00
0005433343183	17039	Economy	10200.00
0005433343145	17039	Economy	10200.00
0005435508283	17039	Economy	10200.00
0005433343173	17039	Economy	10200.00
0005433343181	17039	Economy	10200.00
0005433343185	17039	Economy	10200.00
0005433343158	17039	Economy	10200.00
0005433343156	17039	Economy	10200.00
0005433343164	17039	Economy	10200.00
0005433343206	17039	Economy	10200.00
0005433343170	17039	Economy	10200.00
0005435092001	17039	Economy	10200.00
0005433343119	17039	Economy	10200.00
0005433343192	17039	Economy	10200.00
0005433343189	17039	Economy	10200.00
0005433343135	17039	Economy	10200.00
0005433343120	17039	Economy	10200.00
0005433343205	17039	Economy	10200.00
0005433343122	17039	Economy	10200.00
0005433343167	17039	Economy	10200.00
0005435092029	17039	Economy	10200.00
0005433343137	17039	Economy	10200.00
0005433343209	17039	Economy	10200.00
0005433343117	17039	Economy	10200.00
0005433269720	17039	Economy	10200.00
0005433343172	17039	Economy	10200.00
0005433343166	17039	Economy	11200.00
0005433343121	17039	Economy	11200.00
0005435508277	17039	Economy	10200.00
0005433343176	17039	Economy	10200.00
0005433343151	17039	Economy	10200.00
0005433343111	17039	Economy	11200.00
0005433343152	17039	Economy	10200.00
0005433343178	17039	Economy	10200.00
0005435508279	17039	Economy	10200.00
0005433269724	17039	Economy	10200.00
0005433343143	17039	Economy	10200.00
0005433343200	17039	Economy	10200.00
0005433343140	17039	Economy	10200.00
0005433343191	17039	Economy	10200.00
0005433343113	17039	Economy	10200.00
0005435091970	17039	Economy	10200.00
0005433343136	17039	Economy	10200.00
0005433343211	17039	Economy	10200.00
0005433343202	17039	Economy	10200.00
0005433343208	17039	Economy	10200.00
0005433343148	17039	Economy	10200.00
0005433343134	17039	Economy	10200.00
0005433343177	17039	Economy	10200.00
0005433343123	17039	Economy	10200.00
0005433343142	17039	Economy	10200.00
0005435508202	17039	Economy	10200.00
0005435508250	17039	Economy	10200.00
0005435092007	17039	Economy	10200.00
0005433269725	17039	Economy	10200.00
0005433343132	17039	Economy	10200.00
0005433343175	17039	Economy	10200.00
0005433343168	17039	Economy	10200.00
0005435508266	17039	Economy	10200.00
0005433343195	17039	Economy	10200.00
0005433343116	17039	Economy	10200.00
0005435508246	17039	Economy	10200.00
0005433159314	17039	Economy	10200.00
0005433343171	17039	Economy	10200.00
0005433343118	17039	Economy	10200.00
0005433343155	17039	Economy	10200.00
0005433343162	17039	Economy	10200.00
0005433343114	17039	Economy	10200.00
0005433343174	17039	Economy	10200.00
0005435092013	17039	Economy	10200.00
0005433343157	17039	Economy	10200.00
0005434067012	12806	Business	40300.00
0005434067020	12806	Business	40300.00
0005432433686	12806	Business	40300.00
0005432159861	12806	Business	40300.00
0005434066880	12806	Business	40300.00
0005434081601	12806	Business	40300.00
0005434066749	12806	Business	40300.00
0005434081669	12806	Business	40300.00
0005434081627	12806	Business	40300.00
0005434081666	12806	Business	40300.00
0005434066879	12806	Business	40300.00
0005434066778	12806	Business	40300.00
0005433812901	12806	Economy	13400.00
0005433989722	12806	Economy	13400.00
0005434066881	12806	Economy	13400.00
0005434066903	12806	Economy	13400.00
0005434066741	12806	Economy	13400.00
0005434066891	12806	Economy	13400.00
0005434066843	12806	Economy	13400.00
0005434066899	12806	Economy	13400.00
0005434067250	12806	Economy	13400.00
0005434067018	12806	Economy	13400.00
0005434066826	12806	Economy	13400.00
0005434066957	12806	Economy	13400.00
0005433989742	12806	Economy	13400.00
0005434066936	12806	Economy	13400.00
0005434067360	12806	Economy	13400.00
0005434066812	12806	Economy	13400.00
0005432159863	12806	Economy	13400.00
0005434081665	12806	Economy	13400.00
0005434067047	12806	Economy	13400.00
0005433812902	12806	Economy	13400.00
0005434067017	12806	Economy	13400.00
0005434066714	12806	Economy	13400.00
0005434081687	12806	Economy	13400.00
0005434066789	12806	Economy	13400.00
0005434067090	12806	Economy	13400.00
0005434081667	12806	Economy	13400.00
0005432433682	12806	Economy	13400.00
0005434081628	12806	Economy	13400.00
0005434066815	12806	Economy	13400.00
0005434067027	12806	Economy	13400.00
0005434066844	12806	Economy	13400.00
0005434066792	12806	Economy	13400.00
0005434081658	12806	Economy	13400.00
0005434066902	12806	Economy	13400.00
0005434066964	12806	Economy	13400.00
0005432161153	12806	Economy	13400.00
0005434067030	12806	Economy	13400.00
0005434067069	12806	Economy	13400.00
0005434066772	12806	Economy	13400.00
0005432433683	12806	Economy	13400.00
0005434067249	12806	Economy	14800.00
0005434066715	12806	Economy	14800.00
0005433989743	12806	Economy	14800.00
0005434066972	12806	Economy	14800.00
0005434066828	12806	Economy	14800.00
0005434066996	12806	Economy	14800.00
0005434066973	12806	Economy	13400.00
0005434066820	12806	Economy	13400.00
0005434066980	12806	Economy	13400.00
0005434066870	12806	Economy	13400.00
0005434081643	12806	Economy	13400.00
0005434081670	12806	Economy	13400.00
0005434081688	12806	Economy	13400.00
0005434067204	12806	Economy	13400.00
0005433989721	12806	Economy	13400.00
0005434067113	12806	Economy	13400.00
0005432433685	12806	Economy	13400.00
0005433989741	12806	Economy	13400.00
0005433812903	12806	Economy	13400.00
0005432159860	12806	Economy	13400.00
0005434067021	12806	Economy	13400.00
0005434081623	12806	Economy	13400.00
0005434066742	12806	Economy	13400.00
0005434067189	12806	Economy	13400.00
0005434066968	12806	Economy	13400.00
0005434067013	12806	Economy	13400.00
0005434081655	12806	Economy	13400.00
0005434066689	12806	Economy	13400.00
0005434066867	12806	Economy	13400.00
0005434067212	12806	Economy	13400.00
0005434067067	12806	Economy	13400.00
0005434066782	12806	Economy	13400.00
0005434067237	12806	Economy	13400.00
0005434026683	12806	Economy	13400.00
0005434066790	12806	Economy	13400.00
0005434066777	12806	Economy	13400.00
0005434081657	12806	Economy	13400.00
0005434066988	12806	Economy	13400.00
0005434066781	12806	Economy	13400.00
0005434066967	12806	Economy	13400.00
0005434066827	12806	Economy	13400.00
0005434066793	12806	Economy	13400.00
0005434066679	12806	Economy	13400.00
0005434066969	12806	Economy	13400.00
0005434067114	12806	Economy	13400.00
0005434026696	12806	Economy	13400.00
0005434067197	12806	Economy	13400.00
0005434067022	12806	Economy	13400.00
0005434066773	12806	Economy	13400.00
0005434066713	12806	Economy	13400.00
0005434066816	12806	Economy	13400.00
0005432433687	12806	Economy	13400.00
0005434066956	12806	Economy	13400.00
0005432161154	12806	Economy	13400.00
0005434081645	12806	Economy	13400.00
0005432433684	12806	Economy	13400.00
0005434067004	12806	Economy	13400.00
0005433989719	12806	Economy	13400.00
0005434066886	12806	Economy	13400.00
0005434066813	12806	Economy	13400.00
0005432433681	12806	Economy	13400.00
0005434066998	12806	Economy	13400.00
0005434066783	12806	Economy	13400.00
0005434067248	12806	Economy	13400.00
0005434066868	12806	Economy	13400.00
0005434066963	12806	Economy	13400.00
0005434066791	12806	Economy	13400.00
0005434066734	12806	Economy	13400.00
0005434066920	12806	Economy	13400.00
0005434067076	12806	Economy	13400.00
0005434067026	12806	Economy	13400.00
0005434066908	12806	Economy	13400.00
0005434067196	12806	Economy	13400.00
0005432159862	12806	Economy	13400.00
0005434066739	12806	Economy	13400.00
0005434067043	12806	Economy	13400.00
0005434066997	12806	Economy	13400.00
0005434081622	12806	Economy	13400.00
0005434067596	30638	Business	40300.00
0005434081894	30638	Business	40300.00
0005434067589	30638	Business	40300.00
0005434067594	30638	Business	40300.00
0005434067579	30638	Business	40300.00
0005434081907	30638	Business	40300.00
0005432186868	30638	Business	40300.00
0005432150196	30638	Business	40300.00
0005432150195	30638	Business	40300.00
0005434081899	30638	Business	40300.00
0005434081902	30638	Business	40300.00
0005432150194	30638	Economy	13400.00
0005434081913	30638	Economy	13400.00
0005434067598	30638	Economy	13400.00
0005434067571	30638	Economy	13400.00
0005434081898	30638	Economy	13400.00
0005432433676	30638	Economy	13400.00
0005432433658	30638	Economy	13400.00
0005434067582	30638	Economy	13400.00
0005433989771	30638	Economy	13400.00
0005434067544	30638	Economy	13400.00
0005434067566	30638	Economy	13400.00
0005434067569	30638	Economy	13400.00
0005434067542	30638	Economy	13400.00
0005434067530	30638	Economy	13400.00
0005432433644	30638	Economy	13400.00
0005434081904	30638	Economy	13400.00
0005433989772	30638	Economy	13400.00
0005434081897	30638	Economy	13400.00
0005434067595	30638	Economy	13400.00
0005434067574	30638	Economy	13400.00
0005433989774	30638	Economy	13400.00
0005434067565	30638	Economy	13400.00
0005434081895	30638	Economy	13400.00
0005434067539	30638	Economy	13400.00
0005434067529	30638	Economy	13400.00
0005434067593	30638	Economy	13400.00
0005434081905	30638	Economy	13400.00
0005434067588	30638	Economy	13400.00
0005434067548	30638	Economy	13400.00
0005432433675	30638	Economy	13400.00
0005433989769	30638	Economy	13400.00
0005434067578	30638	Economy	13400.00
0005434067560	30638	Economy	13400.00
0005434067555	30638	Economy	13400.00
0005433989770	30638	Economy	13400.00
0005434081911	30638	Economy	13400.00
0005434081901	30638	Economy	13400.00
0005434067568	30638	Economy	13400.00
0005434067577	30638	Economy	13400.00
0005434067550	30638	Economy	14800.00
0005434067557	30638	Economy	14800.00
0005434067534	30638	Economy	14800.00
0005434067562	30638	Economy	14800.00
0005434067597	30638	Economy	14800.00
0005434067576	30638	Economy	14800.00
0005434081903	30638	Economy	13400.00
0005434067581	30638	Economy	13400.00
0005434067540	30638	Economy	13400.00
0005434067585	30638	Economy	13400.00
0005434067573	30638	Economy	13400.00
0005432150197	30638	Economy	13400.00
0005434067552	30638	Economy	13400.00
0005434067570	30638	Economy	13400.00
0005434067549	30638	Economy	13400.00
0005433989773	30638	Economy	13400.00
0005434081915	30638	Economy	13400.00
0005434067558	30638	Economy	13400.00
0005432186867	30638	Economy	13400.00
0005434067590	30638	Economy	13400.00
0005434067543	30638	Economy	13400.00
0005434067559	30638	Economy	13400.00
0005434067561	30638	Economy	13400.00
0005434081909	30638	Economy	13400.00
0005432150192	30638	Economy	13400.00
0005432150191	30638	Economy	13400.00
0005434067601	30638	Economy	13400.00
0005434081917	30638	Economy	13400.00
0005434067536	30638	Economy	13400.00
0005434081892	30638	Economy	13400.00
0005434067535	30638	Economy	13400.00
0005434081896	30638	Economy	13400.00
0005434067531	30638	Economy	13400.00
0005434081893	30638	Economy	13400.00
0005434067575	30638	Economy	13400.00
0005434081900	30638	Economy	13400.00
0005434081910	30638	Economy	13400.00
0005434067602	30638	Economy	13400.00
0005434067599	30638	Economy	13400.00
0005434067545	30638	Economy	13400.00
0005434081912	30638	Economy	13400.00
0005432433668	30638	Economy	13400.00
0005432150198	30638	Economy	13400.00
0005434081916	30638	Economy	13400.00
0005434067551	30638	Economy	13400.00
0005434067537	30638	Economy	13400.00
0005434081908	30638	Economy	13400.00
0005432150193	30638	Economy	13400.00
0005434067572	30638	Economy	13400.00
0005434067554	30638	Economy	13400.00
0005432433632	30638	Economy	13400.00
0005434067591	30638	Economy	13400.00
0005432186869	30638	Economy	13400.00
0005434067556	30638	Economy	13400.00
0005434067563	30638	Economy	13400.00
0005434067583	30638	Economy	13400.00
0005434067600	30638	Economy	13400.00
0005434067584	30638	Economy	13400.00
0005434067553	30638	Economy	13400.00
0005432150199	30638	Economy	13400.00
0005434067541	30638	Economy	13400.00
0005434067538	30638	Economy	13400.00
0005434067564	30638	Economy	13400.00
0005434067546	30638	Economy	13400.00
0005434081914	30638	Economy	13400.00
0005434067547	30638	Economy	13400.00
0005434067586	30638	Economy	13400.00
0005434067592	30638	Economy	13400.00
0005434067567	30638	Economy	13400.00
0005434067587	30638	Economy	13400.00
0005434067580	30638	Economy	13400.00
0005434067533	30638	Economy	13400.00
0005432186870	30638	Economy	13400.00
0005432433667	30638	Economy	13400.00
0005434067532	30638	Economy	13400.00
0005434081906	30638	Economy	13400.00
0005433686605	19361	Economy	17600.00
0005433689885	19361	Economy	17600.00
0005433686602	19361	Economy	17600.00
0005433689886	19361	Economy	17600.00
0005433686606	19361	Economy	17600.00
0005433689889	19361	Economy	17600.00
0005433686604	19361	Economy	17600.00
0005433686607	19361	Economy	17600.00
0005435766289	5520	Business	35300.00
0005432535791	5520	Business	35300.00
0005435725599	5520	Business	35300.00
0005435766290	5520	Business	35300.00
0005435462335	5520	Business	35300.00
0005434264841	5520	Business	35300.00
0005434831115	5520	Business	35300.00
0005435766303	5520	Business	35300.00
0005435766271	5520	Business	35300.00
0005435766287	5520	Business	35300.00
0005435766262	5520	Business	35300.00
0005432535779	5520	Business	35300.00
0005435725600	5520	Business	35300.00
0005435461906	5520	Business	35300.00
0005432535777	5520	Business	35300.00
0005435766294	5520	Business	35300.00
0005435766295	5520	Business	35300.00
0005434265005	5520	Business	35300.00
0005435462071	5520	Business	35300.00
0005435766265	5520	Business	35300.00
0005435462189	5520	Business	35300.00
0005433527270	5520	Economy	12900.00
0005435766288	5520	Economy	12900.00
0005435766283	5520	Economy	12900.00
0005434264949	5520	Economy	12900.00
0005434264903	5520	Economy	11800.00
0005435766278	5520	Economy	11800.00
0005435766259	5520	Economy	11800.00
0005434264860	5520	Economy	11800.00
0005434264923	5520	Economy	11800.00
0005435766256	5520	Economy	11800.00
0005435766272	5520	Economy	11800.00
0005435766280	5520	Economy	11800.00
0005435766267	5520	Economy	11800.00
0005432140451	5520	Economy	11800.00
0005435766308	5520	Economy	11800.00
0005435462120	5520	Economy	11800.00
0005435462078	5520	Economy	11800.00
0005435462178	5520	Economy	11800.00
0005434264891	5520	Economy	11800.00
0005435766273	5520	Economy	11800.00
0005435462117	5520	Economy	11800.00
0005432140459	5520	Economy	11800.00
0005432140453	5520	Economy	11800.00
0005435462128	5520	Economy	11800.00
0005434264888	5520	Economy	11800.00
0005434264924	5520	Economy	11800.00
0005435462157	5520	Economy	11800.00
0005435462143	5520	Economy	11800.00
0005435766286	5520	Economy	11800.00
0005435462172	5520	Economy	11800.00
0005434264978	5520	Economy	11800.00
0005435766255	5520	Economy	11800.00
0005435766258	5520	Economy	11800.00
0005434265024	5520	Economy	11800.00
0005434265014	5520	Economy	11800.00
0005435462121	5520	Economy	11800.00
0005435766276	5520	Economy	11800.00
0005435462113	5520	Economy	11800.00
0005435766292	5520	Economy	11800.00
0005434264890	5520	Economy	11800.00
0005434264969	5520	Economy	11800.00
0005435766263	5520	Economy	11800.00
0005435766274	5520	Economy	11800.00
0005435766284	5520	Economy	11800.00
0005435722057	5520	Economy	11800.00
0005435735138	5520	Economy	11800.00
0005434264859	5520	Economy	11800.00
0005432140454	5520	Economy	11800.00
0005434264812	5520	Economy	11800.00
0005435766301	5520	Economy	11800.00
0005435725602	5520	Economy	11800.00
0005435462072	5520	Economy	11800.00
0005435766253	5520	Economy	11800.00
0005435043276	5520	Economy	11800.00
0005435462186	5520	Economy	11800.00
0005435766291	5520	Economy	11800.00
0005435766304	5520	Economy	11800.00
0005435766268	5520	Economy	11800.00
0005435766277	5520	Economy	11800.00
0005435766281	5520	Economy	11800.00
0005435766293	5520	Economy	11800.00
0005432140455	5520	Economy	11800.00
0005435462132	5520	Economy	11800.00
0005433527269	5520	Economy	11800.00
0005432535776	5520	Economy	11800.00
0005435766296	5520	Economy	11800.00
0005435766282	5520	Economy	11800.00
0005435723046	5520	Economy	11800.00
0005435766260	5520	Economy	11800.00
0005435462240	5520	Economy	11800.00
0005434831102	5520	Economy	11800.00
0005435462187	5520	Economy	11800.00
0005435735139	5520	Economy	11800.00
0005435462232	5520	Economy	11800.00
0005435766305	5520	Economy	11800.00
0005435462130	5520	Economy	11800.00
0005435462244	5520	Economy	11800.00
0005432140452	5520	Economy	11800.00
0005435462131	5520	Economy	11800.00
0005435461905	5520	Economy	11800.00
0005434264925	5520	Economy	11800.00
0005432535784	5520	Economy	12900.00
0005435725601	5520	Economy	12900.00
0005434831121	5520	Economy	11800.00
0005435766302	5520	Economy	11800.00
0005435462188	5520	Economy	11800.00
0005434264870	5520	Economy	11800.00
0005433529281	5520	Economy	11800.00
0005435462190	5520	Economy	11800.00
0005434264974	5520	Economy	11800.00
0005435766300	5520	Economy	11800.00
0005435462129	5520	Economy	11800.00
0005435766257	5520	Economy	11800.00
0005435462088	5520	Economy	11800.00
0005435766270	5520	Economy	11800.00
0005435766275	5520	Economy	11800.00
0005433527272	5520	Economy	11800.00
0005434831094	5520	Economy	11800.00
0005435722056	5520	Economy	11800.00
0005435766297	5520	Economy	11800.00
0005435766307	5520	Economy	11800.00
0005432140458	5520	Economy	11800.00
0005435462177	5520	Economy	11800.00
0005434264817	5520	Economy	11800.00
0005435735140	5520	Economy	11800.00
0005432140457	5520	Economy	11800.00
0005433529283	5520	Economy	11800.00
0005435462214	5520	Economy	11800.00
0005435462127	5520	Economy	11800.00
0005434265036	5520	Economy	11800.00
0005435766254	5520	Economy	11800.00
0005435766279	5520	Economy	11800.00
0005435766269	5520	Economy	11800.00
0005435766266	5520	Economy	11800.00
0005435462156	5520	Economy	11800.00
0005435766299	5520	Economy	11800.00
0005434264960	5520	Economy	11800.00
0005434831123	5520	Economy	11800.00
0005434831122	5520	Economy	11800.00
0005433529282	5520	Economy	11800.00
0005435462073	5520	Economy	11800.00
0005434264811	5520	Economy	11800.00
0005435766298	5520	Economy	11800.00
0005433529280	5520	Economy	11800.00
0005435723047	5520	Economy	11800.00
0005435766309	5520	Economy	11800.00
0005434264843	5520	Economy	11800.00
0005435766285	5520	Economy	11800.00
0005435723045	5520	Economy	11800.00
0005435735137	5520	Economy	11800.00
0005435766264	5520	Economy	11800.00
0005433527271	5520	Economy	11800.00
0005432140456	5520	Economy	11800.00
0005435462112	5520	Economy	11800.00
0005435462041	5520	Economy	11800.00
0005434264842	5520	Economy	11800.00
0005435462124	5520	Economy	11800.00
0005435766261	5520	Economy	11800.00
0005434264892	5520	Economy	11800.00
0005435766306	5520	Economy	11800.00
0005435766310	5520	Economy	11800.00
0005434264900	5520	Economy	11800.00
0005435462456	13458	Business	35300.00
0005433529241	13458	Business	35300.00
0005434265164	13458	Business	35300.00
0005435765621	13458	Business	35300.00
0005434265162	13458	Business	35300.00
0005435462472	13458	Business	35300.00
0005435765761	13458	Business	35300.00
0005435462490	13458	Business	35300.00
0005435765745	13458	Business	35300.00
0005434831155	13458	Business	35300.00
0005435765924	13458	Business	35300.00
0005435462473	13458	Business	35300.00
0005435765683	13458	Business	35300.00
0005435462466	13458	Business	35300.00
0005434831158	13458	Business	35300.00
0005435462484	13458	Business	35300.00
0005435765509	13458	Business	35300.00
0005435765855	13458	Business	35300.00
0005434265177	13458	Business	35300.00
0005435765739	13458	Business	35300.00
0005434265154	13458	Business	35300.00
0005433533268	13458	Economy	12900.00
0005434831156	13458	Business	35300.00
0005434265166	13458	Economy	12900.00
0005435765664	13458	Economy	12900.00
0005435765786	13458	Economy	12900.00
0005435765622	13458	Economy	11800.00
0005435462480	13458	Economy	11800.00
0005434265158	13458	Economy	11800.00
0005435617171	13458	Economy	11800.00
0005435765923	13458	Economy	11800.00
0005433533266	13458	Economy	11800.00
0005435765510	13458	Economy	11800.00
0005432194516	13458	Economy	11800.00
0005435462468	13458	Economy	11800.00
0005435765465	13458	Economy	11800.00
0005432535839	13458	Economy	11800.00
0005434265156	13458	Economy	11800.00
0005435765857	13458	Economy	11800.00
0005433533282	13458	Economy	11800.00
0005433529228	13458	Economy	11800.00
0005433533267	13458	Economy	11800.00
0005435765920	13458	Economy	11800.00
0005435765715	13458	Economy	11800.00
0005435462483	13458	Economy	11800.00
0005434265165	13458	Economy	11800.00
0005435765748	13458	Economy	11800.00
0005432535840	13458	Economy	11800.00
0005433529235	13458	Economy	11800.00
0005435462460	13458	Economy	11800.00
0005435765812	13458	Economy	11800.00
0005435765495	13458	Economy	11800.00
0005435765781	13458	Economy	11800.00
0005433533281	13458	Economy	11800.00
0005435462452	13458	Economy	11800.00
0005435765555	13458	Economy	11800.00
0005435725550	13458	Economy	11800.00
0005434265152	13458	Economy	11800.00
0005435722031	13458	Economy	11800.00
0005434265159	13458	Economy	11800.00
0005434265155	13458	Economy	11800.00
0005434265163	13458	Economy	11800.00
0005435765411	13458	Economy	11800.00
0005432194514	13458	Economy	11800.00
0005433529223	13458	Economy	11800.00
0005433533288	13458	Economy	11800.00
0005435462479	13458	Economy	11800.00
0005435722036	13458	Economy	11800.00
0005433533289	13458	Economy	11800.00
0005435462478	13458	Economy	11800.00
0005435765873	13458	Economy	11800.00
0005434265172	13458	Economy	11800.00
0005435765684	13458	Economy	11800.00
0005435765556	13458	Economy	11800.00
0005434265171	13458	Economy	11800.00
0005435722022	13458	Economy	11800.00
0005434265160	13458	Economy	11800.00
0005435765610	13458	Economy	11800.00
0005434265173	13458	Economy	11800.00
0005433529236	13458	Economy	11800.00
0005433533255	13458	Economy	11800.00
0005433529240	13458	Economy	11800.00
0005435765682	13458	Economy	11800.00
0005435765571	13458	Economy	11800.00
0005435765949	13458	Economy	11800.00
0005434265161	13458	Economy	11800.00
0005433533269	13458	Economy	11800.00
0005435722037	13458	Economy	11800.00
0005435765635	13458	Economy	11800.00
0005435765496	13458	Economy	11800.00
0005432194517	13458	Economy	11800.00
0005435765848	13458	Economy	11800.00
0005435462476	13458	Economy	11800.00
0005435765852	13458	Economy	11800.00
0005435462462	13458	Economy	11800.00
0005435765946	13458	Economy	11800.00
0005435765711	13458	Economy	11800.00
0005434265169	13458	Economy	11800.00
0005435462459	13458	Economy	11800.00
0005432194515	13458	Economy	11800.00
0005433529224	13458	Economy	11800.00
0005435765602	13458	Economy	11800.00
0005434265175	13458	Economy	11800.00
0005434265151	13458	Economy	11800.00
0005435725553	13458	Economy	11800.00
0005435462486	13458	Economy	11800.00
0005433533264	13458	Economy	12900.00
0005434265157	13458	Economy	12900.00
0005435765805	13458	Economy	11800.00
0005435765900	13458	Economy	11800.00
0005435725568	13458	Economy	11800.00
0005435725564	13458	Economy	12900.00
0005434831157	13458	Economy	12900.00
0005432535838	13458	Economy	11800.00
0005434265176	13458	Economy	11800.00
0005433529239	13458	Economy	11800.00
0005435765634	13458	Economy	11800.00
0005435462487	13458	Economy	11800.00
0005435765861	13458	Economy	11800.00
0005435765749	13458	Economy	11800.00
0005435765724	13458	Economy	11800.00
0005433533256	13458	Economy	11800.00
0005434831159	13458	Economy	11800.00
0005435462481	13458	Economy	11800.00
0005435462454	13458	Economy	11800.00
0005435462458	13458	Economy	11800.00
0005435462477	13458	Economy	11800.00
0005435765704	13458	Economy	11800.00
0005435765702	13458	Economy	11800.00
0005434265178	13458	Economy	11800.00
0005435765953	13458	Economy	11800.00
0005435462485	13458	Economy	11800.00
0005435725565	13458	Economy	11800.00
0005435462474	13458	Economy	11800.00
0005435462470	13458	Economy	11800.00
0005433533271	13458	Economy	11800.00
0005435462489	13458	Economy	11800.00
0005435765703	13458	Economy	11800.00
0005434265167	13458	Economy	11800.00
0005435462463	13458	Economy	11800.00
0005435725556	13458	Economy	11800.00
0005435462488	13458	Economy	11800.00
0005435725557	13458	Economy	11800.00
0005432535837	13458	Economy	11800.00
0005435765950	13458	Economy	11800.00
0005435462461	13458	Economy	11800.00
0005435462457	13458	Economy	11800.00
0005435735103	13458	Economy	11800.00
0005435765921	13458	Economy	11800.00
0005435462464	13458	Economy	11800.00
0005433529229	13458	Economy	11800.00
0005433529231	13458	Economy	11800.00
0005435617172	13458	Economy	11800.00
0005435462469	13458	Economy	11800.00
0005435725548	13458	Economy	11800.00
0005435462471	13458	Economy	11800.00
0005435462482	13458	Economy	11800.00
0005435765650	13458	Economy	11800.00
0005435725527	13458	Economy	11800.00
0005435765636	13458	Economy	11800.00
0005435735104	13458	Economy	11800.00
0005435765440	13458	Economy	11800.00
0005435765508	13458	Economy	11800.00
0005434265168	13458	Economy	11800.00
0005435765768	13458	Economy	11800.00
0005435462465	13458	Economy	11800.00
0005434265153	13458	Economy	11800.00
0005432194513	13458	Economy	11800.00
0005435462467	13458	Economy	11800.00
0005434265170	13458	Economy	11800.00
0005432535836	13458	Economy	11800.00
0005435765603	13458	Economy	11800.00
0005435765823	13458	Economy	11800.00
0005435462455	13458	Economy	11800.00
0005433533263	13458	Economy	11800.00
0005435462453	13458	Economy	11800.00
0005435765651	13458	Economy	11800.00
0005435462475	13458	Economy	11800.00
0005435765557	13458	Economy	11800.00
0005434265174	13458	Economy	11800.00
0005434602879	18651	Economy	3300.00
0005434602881	18651	Economy	3300.00
0005434602876	18651	Economy	3300.00
0005434602880	18651	Economy	3300.00
0005434602875	18651	Economy	3300.00
0005434602884	18651	Economy	3300.00
0005434604864	18652	Economy	3300.00
0005434604873	18652	Economy	3300.00
0005434513581	18652	Economy	3300.00
0005435904706	18652	Economy	3300.00
0005434513580	18652	Economy	3300.00
0005434513579	18652	Economy	3300.00
0005434604874	18652	Economy	3300.00
0005434604872	18652	Economy	3300.00
0005435904705	18652	Economy	3300.00
0005434514968	18652	Economy	3300.00
0005432649408	4110	Business	88300.00
0005432632740	4110	Business	88300.00
0005432649412	4110	Business	88300.00
0005435844304	4110	Business	88300.00
0005432649399	4110	Business	88300.00
0005432632752	4110	Business	88300.00
0005432632738	4110	Economy	29400.00
0005432632746	4110	Economy	29400.00
0005435846214	4110	Economy	29400.00
0005432649406	4110	Economy	29400.00
0005432649395	4110	Economy	29400.00
0005435846226	4110	Economy	29400.00
0005432632754	4110	Economy	29400.00
0005432649401	4110	Economy	29400.00
0005435846217	4110	Economy	32400.00
0005435844281	4110	Economy	32400.00
0005435844275	4110	Economy	32400.00
0005435844283	4110	Economy	32400.00
0005432632734	4110	Economy	32400.00
0005435846233	4110	Economy	29400.00
0005432632737	4110	Economy	29400.00
0005432649398	4110	Economy	29400.00
0005435844276	4110	Economy	29400.00
0005432649397	4110	Economy	29400.00
0005435846215	4110	Economy	29400.00
0005432632742	4110	Economy	29400.00
0005432649402	4110	Economy	29400.00
0005432649405	4110	Economy	29400.00
0005435846232	4110	Economy	29400.00
0005432649407	4110	Economy	29400.00
0005432632743	4110	Economy	29400.00
0005432632748	4110	Economy	29400.00
0005432649410	4110	Economy	29400.00
0005432632750	4110	Economy	29400.00
0005435844274	4110	Economy	29400.00
0005432649413	4110	Economy	29400.00
0005432649411	4110	Economy	29400.00
0005435846213	4110	Economy	29400.00
0005432632736	4110	Economy	29400.00
0005432632751	4110	Economy	29400.00
0005432649409	4110	Economy	29400.00
0005432632741	4110	Economy	29400.00
0005432649404	4110	Economy	29400.00
0005432649403	4110	Economy	29400.00
0005432632744	4110	Economy	29400.00
0005432632747	4110	Economy	29400.00
0005432632753	4110	Economy	29400.00
0005435844278	4110	Economy	29400.00
0005435846225	4110	Economy	29400.00
0005435844284	4110	Economy	29400.00
0005432649400	4110	Economy	29400.00
0005432632749	4110	Economy	29400.00
0005432632733	4110	Economy	29400.00
0005435846209	4110	Economy	29400.00
0005435844271	4110	Economy	29400.00
0005432632745	4110	Economy	29400.00
0005432649396	4110	Economy	29400.00
0005432632735	4110	Economy	29400.00
0005435846208	4110	Economy	29400.00
0005432632739	4110	Economy	29400.00
0005435844277	4110	Economy	29400.00
0005433008301	1879	Business	48700.00
0005433008111	1879	Business	48700.00
0005433810554	1879	Business	48700.00
0005433008420	1879	Business	48700.00
0005433008471	1879	Business	48700.00
0005433285038	1879	Business	48700.00
0005433285173	1879	Business	48700.00
0005433008197	1879	Business	48700.00
0005433008305	1879	Business	48700.00
0005433008115	1879	Business	48700.00
0005432295882	1879	Business	48700.00
0005433008096	1879	Economy	16200.00
0005433008421	1879	Economy	16200.00
0005433008419	1879	Economy	16200.00
0005433008327	1879	Economy	16200.00
0005433285016	1879	Economy	16200.00
0005433008362	1879	Economy	16200.00
0005433008160	1879	Economy	16200.00
0005433810552	1879	Economy	17900.00
0005433284971	1879	Economy	17900.00
0005433285077	1879	Economy	17900.00
0005433008475	1879	Economy	17900.00
0005433285057	1879	Economy	17900.00
0005433285078	1879	Economy	16200.00
0005433810550	1879	Economy	16200.00
0005433008470	1879	Economy	16200.00
0005433008377	1879	Economy	16200.00
0005433285058	1879	Economy	16200.00
0005433008408	1879	Economy	16200.00
0005433008313	1879	Economy	16200.00
0005433008256	1879	Economy	16200.00
0005433285018	1879	Economy	16200.00
0005433008237	1879	Economy	16200.00
0005433008294	1879	Economy	16200.00
0005433285000	1879	Economy	16200.00
0005433285170	1879	Economy	16200.00
0005433285025	1879	Economy	16200.00
0005433810551	1879	Economy	16200.00
0005433008378	1879	Economy	16200.00
0005433008312	1879	Economy	16200.00
0005433008215	1879	Economy	16200.00
0005433008196	1879	Economy	16200.00
0005433008329	1879	Economy	16200.00
0005433285096	1879	Economy	16200.00
0005433008159	1879	Economy	16200.00
0005433008398	1879	Economy	16200.00
0005432295881	1879	Economy	16200.00
0005433285011	1879	Economy	16200.00
0005433285049	1879	Economy	16200.00
0005433008418	1879	Economy	16200.00
0005433008195	1879	Economy	16200.00
0005433008220	1879	Economy	16200.00
0005433285172	1879	Economy	16200.00
0005433008097	1879	Economy	16200.00
0005433285048	1879	Economy	16200.00
0005433008416	1879	Economy	16200.00
0005433008269	1879	Economy	16200.00
0005433008466	1879	Economy	16200.00
0005433285129	1879	Economy	16200.00
0005433008292	1879	Economy	16200.00
0005433285150	1879	Economy	16200.00
0005433008098	1879	Economy	16200.00
0005433008236	1879	Economy	16200.00
0005433008303	1879	Economy	16200.00
0005433810553	1879	Economy	16200.00
0005433285127	1879	Economy	16200.00
0005433008271	1879	Economy	16200.00
0005433008330	1879	Economy	16200.00
0005433285079	1879	Economy	16200.00
0005433008255	1879	Economy	16200.00
0005433008293	1879	Economy	16200.00
0005433284970	1879	Economy	16200.00
0005433284972	1879	Economy	16200.00
0005433008275	1879	Economy	16200.00
0005433008518	1879	Economy	16200.00
0005433008361	1879	Economy	16200.00
0005433008304	1879	Economy	16200.00
0005433008424	1879	Economy	16200.00
0005433008270	1879	Economy	16200.00
0005433284993	1879	Economy	16200.00
0005433008221	1879	Economy	16200.00
0005433285171	1879	Economy	16200.00
0005433008158	1879	Economy	16200.00
0005433285308	22534	Business	48700.00
0005433008640	22534	Business	48700.00
0005433285303	22534	Business	48700.00
0005433285306	22534	Business	48700.00
0005433285296	22534	Business	48700.00
0005433285295	22534	Business	48700.00
0005433285316	22534	Business	48700.00
0005433008633	22534	Business	48700.00
0005433285307	22534	Business	48700.00
0005433008651	22534	Business	48700.00
0005433008634	22534	Business	48700.00
0005433008643	22534	Economy	16200.00
0005433285299	22534	Economy	16200.00
0005433285312	22534	Economy	16200.00
0005433008619	22534	Economy	16200.00
0005433008638	22534	Economy	16200.00
0005433008654	22534	Economy	16200.00
0005433008637	22534	Economy	16200.00
0005433008622	22534	Economy	16200.00
0005433810494	22534	Economy	17900.00
0005433008629	22534	Economy	17900.00
0005433285310	22534	Economy	17900.00
0005433285300	22534	Economy	17900.00
0005433285324	22534	Economy	16200.00
0005433008625	22534	Economy	16200.00
0005433008621	22534	Economy	16200.00
0005433285301	22534	Economy	16200.00
0005433008655	22534	Economy	16200.00
0005433008656	22534	Economy	16200.00
0005433285298	22534	Economy	16200.00
0005433008648	22534	Economy	16200.00
0005433008645	22534	Economy	16200.00
0005433285302	22534	Economy	16200.00
0005433285321	22534	Economy	16200.00
0005433008613	22534	Economy	16200.00
0005433008623	22534	Economy	16200.00
0005433008653	22534	Economy	16200.00
0005433008639	22534	Economy	16200.00
0005433008628	22534	Economy	16200.00
0005433285319	22534	Economy	16200.00
0005433008627	22534	Economy	16200.00
0005433285305	22534	Economy	16200.00
0005433285326	22534	Economy	16200.00
0005433008615	22534	Economy	16200.00
0005433285314	22534	Economy	16200.00
0005433008636	22534	Economy	16200.00
0005433008618	22534	Economy	16200.00
0005433810507	22534	Economy	16200.00
0005433285315	22534	Economy	16200.00
0005433008652	22534	Economy	16200.00
0005433285309	22534	Economy	16200.00
0005433285318	22534	Economy	16200.00
0005433008624	22534	Economy	16200.00
0005433008631	22534	Economy	16200.00
0005433285323	22534	Economy	16200.00
0005433008642	22534	Economy	16200.00
0005433008611	22534	Economy	16200.00
0005433285311	22534	Economy	16200.00
0005433285325	22534	Economy	16200.00
0005433008635	22534	Economy	16200.00
0005433008649	22534	Economy	16200.00
0005433008650	22534	Economy	16200.00
0005433008647	22534	Economy	16200.00
0005433008617	22534	Economy	16200.00
0005433008646	22534	Economy	16200.00
0005433008620	22534	Economy	16200.00
0005433285317	22534	Economy	16200.00
0005433008632	22534	Economy	16200.00
0005433008630	22534	Economy	16200.00
0005433008612	22534	Economy	16200.00
0005433285297	22534	Economy	16200.00
0005433285322	22534	Economy	16200.00
0005433008616	22534	Economy	16200.00
0005433285320	22534	Economy	16200.00
0005433008644	22534	Economy	16200.00
0005433008626	22534	Economy	16200.00
0005433008614	22534	Economy	16200.00
0005433008641	22534	Economy	16200.00
0005433285313	22534	Economy	16200.00
0005433285304	22534	Economy	16200.00
0005433846778	5558	Business	99800.00
0005433846768	5558	Business	99800.00
0005433846787	5558	Business	99800.00
0005434173483	5558	Business	99800.00
0005433846769	5558	Business	99800.00
0005435282349	5558	Business	99800.00
0005433846762	5558	Business	99800.00
0005433846750	5558	Business	99800.00
0005435282476	5558	Business	99800.00
0005433846746	5558	Business	99800.00
0005433846780	5558	Business	99800.00
0005433846789	5558	Business	99800.00
0005433846794	5558	Business	99800.00
0005433815384	5558	Business	99800.00
0005433846763	5558	Business	99800.00
0005435282338	5558	Business	99800.00
0005435282295	5558	Business	99800.00
0005433846770	5558	Business	99800.00
0005435282291	5558	Business	99800.00
0005432081515	5558	Economy	33300.00
0005435282372	5558	Economy	33300.00
0005433815385	5558	Economy	33300.00
0005435282381	5558	Economy	33300.00
0005433846785	5558	Economy	33300.00
0005433846777	5558	Economy	33300.00
0005433846744	5558	Economy	33300.00
0005433846767	5558	Economy	33300.00
0005433846757	5558	Economy	33300.00
0005433846755	5558	Economy	33300.00
0005433846774	5558	Economy	33300.00
0005435282362	5558	Economy	33300.00
0005433846781	5558	Economy	33300.00
0005433846740	5558	Economy	36600.00
0005432081517	5558	Economy	36600.00
0005433846752	5558	Economy	36600.00
0005432081516	5558	Economy	33300.00
0005433846795	5558	Economy	33300.00
0005433846742	5558	Economy	33300.00
0005435282323	5558	Economy	33300.00
0005433846751	5558	Economy	33300.00
0005433846793	5558	Economy	33300.00
0005435282322	5558	Economy	33300.00
0005433846782	5558	Economy	33300.00
0005433846790	5558	Economy	33300.00
0005433846754	5558	Economy	33300.00
0005433846776	5558	Economy	33300.00
0005433846788	5558	Economy	33300.00
0005434173478	5558	Economy	33300.00
0005433846783	5558	Economy	33300.00
0005433815386	5558	Economy	33300.00
0005435282361	5558	Economy	33300.00
0005433846772	5558	Economy	33300.00
0005433846773	5558	Economy	33300.00
0005435282483	5558	Economy	33300.00
0005433846775	5558	Economy	33300.00
0005434173491	5558	Economy	33300.00
0005433846741	5558	Economy	33300.00
0005435282367	5558	Economy	33300.00
0005435282285	5558	Economy	33300.00
0005433846759	5558	Economy	33300.00
0005435282360	5558	Economy	33300.00
0005433846791	5558	Economy	33300.00
0005433846771	5558	Economy	33300.00
0005435282281	5558	Economy	33300.00
0005435282359	5558	Economy	33300.00
0005433846792	5558	Economy	33300.00
0005433846761	5558	Economy	33300.00
0005433846765	5558	Economy	33300.00
0005433846779	5558	Economy	33300.00
0005435282294	5558	Economy	33300.00
0005435282292	5558	Economy	33300.00
0005435282366	5558	Economy	33300.00
0005435282390	5558	Economy	33300.00
0005435282280	5558	Economy	33300.00
0005432081514	5558	Economy	33300.00
0005433846797	5558	Economy	33300.00
0005433846748	5558	Economy	33300.00
0005433846760	5558	Economy	33300.00
0005433846764	5558	Economy	33300.00
0005432081518	5558	Economy	33300.00
0005435282482	5558	Economy	33300.00
0005434173490	5558	Economy	33300.00
0005435282477	5558	Economy	33300.00
0005435282277	5558	Economy	33300.00
0005433846739	5558	Economy	33300.00
0005433815387	5558	Economy	33300.00
0005433846756	5558	Economy	33300.00
0005433846747	5558	Economy	33300.00
0005433846799	5558	Economy	33300.00
0005433815388	5558	Economy	33300.00
0005433846743	5558	Economy	33300.00
0005435282358	5558	Economy	33300.00
0005433846745	5558	Economy	33300.00
0005433846766	5558	Economy	33300.00
0005433846784	5558	Economy	33300.00
0005433846798	5558	Economy	33300.00
0005435282365	5558	Economy	33300.00
0005433846796	5558	Economy	33300.00
0005433846749	5558	Economy	33300.00
0005433846758	5558	Economy	33300.00
0005435282475	5558	Economy	33300.00
0005433846786	5558	Economy	33300.00
0005433846753	5558	Economy	33300.00
0005433846262	13879	Business	99800.00
0005433846348	13879	Business	99800.00
0005433846189	13879	Business	99800.00
0005433846263	13879	Business	99800.00
0005433815325	13879	Business	99800.00
0005435282542	13879	Business	99800.00
0005432003704	13879	Business	99800.00
0005433846332	13879	Business	99800.00
0005432003705	13879	Business	99800.00
0005435282530	13879	Business	99800.00
0005433846223	13879	Business	99800.00
0005433846144	13879	Business	99800.00
0005433846534	13879	Business	99800.00
0005435282543	13879	Business	99800.00
0005433846381	13879	Business	99800.00
0005434173523	13879	Business	99800.00
0005433845916	13879	Economy	33300.00
0005433846403	13879	Economy	33300.00
0005434173522	13879	Economy	33300.00
0005435282523	13879	Economy	33300.00
0005433815338	13879	Economy	33300.00
0005435282521	13879	Economy	33300.00
0005433846506	13879	Economy	33300.00
0005435282525	13879	Economy	33300.00
0005433846230	13879	Economy	33300.00
0005435282534	13879	Economy	33300.00
0005433846351	13879	Economy	33300.00
0005433846563	13879	Economy	36600.00
0005432003703	13879	Economy	36600.00
0005435282536	13879	Economy	36600.00
0005433846349	13879	Economy	36600.00
0005433846188	13879	Economy	33300.00
0005433846437	13879	Economy	33300.00
0005434173525	13879	Economy	33300.00
0005435282538	13879	Economy	33300.00
0005433846184	13879	Economy	33300.00
0005433846217	13879	Economy	33300.00
0005435282531	13879	Economy	33300.00
0005433846265	13879	Economy	33300.00
0005433846152	13879	Economy	33300.00
0005433846100	13879	Economy	33300.00
0005435282535	13879	Economy	33300.00
0005433846185	13879	Economy	33300.00
0005433846353	13879	Economy	33300.00
0005435282516	13879	Economy	33300.00
0005433815347	13879	Economy	33300.00
0005435282533	13879	Economy	33300.00
0005433846161	13879	Economy	33300.00
0005433846298	13879	Economy	33300.00
0005435282529	13879	Economy	33300.00
0005433815354	13879	Economy	33300.00
0005434173524	13879	Economy	33300.00
0005435282526	13879	Economy	33300.00
0005433846371	13879	Economy	33300.00
0005435282539	13879	Economy	33300.00
0005433846350	13879	Economy	33300.00
0005433846346	13879	Economy	33300.00
0005433846257	13879	Economy	33300.00
0005433846318	13879	Economy	33300.00
0005433846424	13879	Economy	33300.00
0005433846352	13879	Economy	33300.00
0005433846382	13879	Economy	33300.00
0005433846448	13879	Economy	33300.00
0005433846269	13879	Economy	33300.00
0005433846293	13879	Economy	33300.00
0005433846565	13879	Economy	33300.00
0005433846309	13879	Economy	33300.00
0005433846186	13879	Economy	33300.00
0005435282522	13879	Economy	33300.00
0005433846425	13879	Economy	33300.00
0005433846190	13879	Economy	33300.00
0005433846213	13879	Economy	33300.00
0005435282537	13879	Economy	33300.00
0005435282524	13879	Economy	33300.00
0005433846564	13879	Economy	33300.00
0005435282518	13879	Economy	33300.00
0005435282520	13879	Economy	33300.00
0005433846317	13879	Economy	33300.00
0005433846582	13879	Economy	33300.00
0005433846040	13879	Economy	33300.00
0005433846308	13879	Economy	33300.00
0005433846435	13879	Economy	33300.00
0005435282519	13879	Economy	33300.00
0005433846222	13879	Economy	33300.00
0005435282532	13879	Economy	33300.00
0005433846397	13879	Economy	33300.00
0005435282517	13879	Economy	33300.00
0005433846329	13879	Economy	33300.00
0005433846077	13879	Economy	33300.00
0005433846264	13879	Economy	33300.00
0005435282541	13879	Economy	33300.00
0005435282528	13879	Economy	33300.00
0005433846396	13879	Economy	33300.00
0005433846328	13879	Economy	33300.00
0005433846395	13879	Economy	33300.00
0005435282540	13879	Economy	33300.00
0005433846301	13879	Economy	33300.00
0005433846101	13879	Economy	33300.00
0005435282527	13879	Economy	33300.00
0005433846505	13879	Economy	33300.00
0005433815356	13879	Economy	33300.00
0005433846386	13879	Economy	33300.00
0005434620616	7822	Economy	16600.00
0005434620604	7822	Economy	16600.00
0005434620602	7822	Economy	16600.00
0005432112518	7822	Economy	15100.00
0005435332226	7822	Economy	15100.00
0005435332268	7822	Economy	15100.00
0005432112519	7822	Economy	15100.00
0005434620605	7822	Economy	15100.00
0005434620620	7822	Economy	15100.00
0005434620618	7822	Economy	15100.00
0005434620613	7822	Economy	15100.00
0005435332259	7822	Economy	15100.00
0005434620615	7822	Economy	15100.00
0005434620617	7822	Economy	15100.00
0005435332275	7822	Economy	15100.00
0005434620619	7822	Economy	15100.00
0005434620621	7822	Economy	15100.00
0005434620608	7822	Economy	15100.00
0005434620606	7822	Economy	15100.00
0005434620614	7822	Economy	15100.00
0005434620603	7822	Economy	15100.00
0005434620609	7822	Economy	15100.00
0005435332218	7822	Economy	15100.00
0005434620607	7822	Economy	15100.00
0005435332274	7822	Economy	15100.00
0005434620612	7822	Economy	15100.00
0005434620610	7822	Economy	15100.00
0005434620611	7822	Economy	15100.00
0005434620416	32981	Economy	16600.00
0005434620444	32981	Economy	16600.00
0005435332344	32981	Economy	15100.00
0005434620479	32981	Economy	15100.00
0005434620440	32981	Economy	15100.00
0005434620470	32981	Economy	15100.00
0005435332346	32981	Economy	15100.00
0005434620445	32981	Economy	15100.00
0005434620469	32981	Economy	15100.00
0005434620485	32981	Economy	15100.00
0005434620458	32981	Economy	15100.00
0005435332340	32981	Economy	15100.00
0005434620442	32981	Economy	15100.00
0005434620402	32981	Economy	15100.00
0005435332339	32981	Economy	15100.00
0005434620468	32981	Economy	15100.00
0005434620472	32981	Economy	15100.00
0005435332343	32981	Economy	15100.00
0005435332341	32981	Economy	15100.00
0005434620430	32981	Economy	15100.00
0005434620510	32981	Economy	15100.00
0005434620441	32981	Economy	15100.00
0005434620482	32981	Economy	15100.00
0005434620453	32981	Economy	15100.00
0005434620480	32981	Economy	15100.00
0005435332342	32981	Economy	15100.00
0005435332347	32981	Economy	15100.00
0005435332345	32981	Economy	15100.00
0005434994030	4294	Business	38000.00
0005434994031	4294	Business	38000.00
0005435785378	4294	Business	38000.00
0005435785373	4294	Business	38000.00
0005434994028	4294	Business	38000.00
0005435785370	4294	Business	38000.00
0005435937329	4294	Economy	12700.00
0005435787355	4294	Economy	12700.00
0005435785389	4294	Economy	12700.00
0005435785367	4294	Economy	12700.00
0005435918631	4294	Economy	12700.00
0005435787356	4294	Economy	13900.00
0005435785365	4294	Economy	13900.00
0005434994033	4294	Economy	13900.00
0005435918621	4294	Economy	13900.00
0005435785377	4294	Economy	12700.00
0005435937333	4294	Economy	12700.00
0005435785381	4294	Economy	12700.00
0005435785395	4294	Economy	12700.00
0005435785393	4294	Economy	12700.00
0005435918620	4294	Economy	12700.00
0005435785379	4294	Economy	12700.00
0005432190634	4294	Economy	12700.00
0005435785387	4294	Economy	12700.00
0005435918630	4294	Economy	12700.00
0005435785394	4294	Economy	12700.00
0005435785372	4294	Economy	12700.00
0005435785383	4294	Economy	12700.00
0005435937332	4294	Economy	12700.00
0005435785392	4294	Economy	12700.00
0005432190633	4294	Economy	12700.00
0005435785397	4294	Economy	12700.00
0005435785385	4294	Economy	12700.00
0005435785369	4294	Economy	12700.00
0005435785398	4294	Economy	12700.00
0005435785371	4294	Economy	12700.00
0005435785390	4294	Economy	12700.00
0005435937352	4294	Economy	12700.00
0005434994032	4294	Economy	12700.00
0005435785399	4294	Economy	12700.00
0005435785376	4294	Economy	12700.00
0005435785401	4294	Economy	12700.00
0005435785400	4294	Economy	12700.00
0005435785374	4294	Economy	12700.00
0005435785375	4294	Economy	12700.00
0005435785382	4294	Economy	12700.00
0005434994027	4294	Economy	12700.00
0005434994036	4294	Economy	12700.00
0005432190631	4294	Economy	12700.00
0005434994035	4294	Economy	12700.00
0005435785366	4294	Economy	12700.00
0005432190632	4294	Economy	12700.00
0005435918627	4294	Economy	12700.00
0005435785388	4294	Economy	12700.00
0005434994026	4294	Economy	12700.00
0005434994034	4294	Economy	12700.00
0005435785391	4294	Economy	12700.00
0005435785380	4294	Economy	12700.00
0005435937348	4294	Economy	12700.00
0005435937347	4294	Economy	12700.00
0005435785384	4294	Economy	12700.00
0005434994029	4294	Economy	12700.00
0005435785368	4294	Economy	12700.00
0005435785396	4294	Economy	12700.00
0005435785386	4294	Economy	12700.00
0005434993948	27326	Business	38000.00
0005435785058	27326	Business	38000.00
0005435784989	27326	Business	38000.00
0005434993920	27326	Business	38000.00
0005434993967	27326	Business	38000.00
0005435785137	27326	Business	38000.00
0005435785144	27326	Business	38000.00
0005435784919	27326	Economy	12700.00
0005435784920	27326	Economy	12700.00
0005435784878	27326	Economy	12700.00
0005435785153	27326	Economy	12700.00
0005435785086	27326	Economy	12700.00
0005435785048	27326	Economy	13900.00
0005435785131	27326	Economy	13900.00
0005435785039	27326	Economy	13900.00
0005435785095	27326	Economy	12700.00
0005435785015	27326	Economy	12700.00
0005435787331	27326	Economy	12700.00
0005435785023	27326	Economy	12700.00
0005435787332	27326	Economy	12700.00
0005435785138	27326	Economy	12700.00
0005434993974	27326	Economy	12700.00
0005435918661	27326	Economy	12700.00
0005432195694	27326	Economy	12700.00
0005435784996	27326	Economy	12700.00
0005435785041	27326	Economy	12700.00
0005435785042	27326	Economy	12700.00
0005435784859	27326	Economy	12700.00
0005435784961	27326	Economy	12700.00
0005435918660	27326	Economy	12700.00
0005435918659	27326	Economy	12700.00
0005435785132	27326	Economy	12700.00
0005435787330	27326	Economy	12700.00
0005435785143	27326	Economy	12700.00
0005435784931	27326	Economy	12700.00
0005434993947	27326	Economy	12700.00
0005432195695	27326	Economy	12700.00
0005435785078	27326	Economy	12700.00
0005432195693	27326	Economy	12700.00
0005435918657	27326	Economy	12700.00
0005435784995	27326	Economy	12700.00
0005435785013	27326	Economy	12700.00
0005435785022	27326	Economy	12700.00
0005435784838	27326	Economy	12700.00
0005435937389	27326	Economy	12700.00
0005435784990	27326	Economy	12700.00
0005434993966	27326	Economy	12700.00
0005435784879	27326	Economy	12700.00
0005435787333	27326	Economy	12700.00
0005434993957	27326	Economy	12700.00
0005435785096	27326	Economy	12700.00
0005435785040	27326	Economy	12700.00
0005432195692	27326	Economy	12700.00
0005435918658	27326	Economy	12700.00
0005435784791	27326	Economy	12700.00
0005432146200	19850	Economy	12800.00
0005432146199	19850	Economy	12800.00
0005434081924	4725	Business	40900.00
0005432567696	4725	Business	40900.00
0005432567690	4725	Business	40900.00
0005432567685	4725	Business	40900.00
0005432459916	4725	Business	40900.00
0005432459867	4725	Business	40900.00
0005432567691	4725	Business	40900.00
0005432567708	4725	Business	40900.00
0005432567667	4725	Business	40900.00
0005432567710	4725	Business	40900.00
0005433451621	4725	Business	40900.00
0005432567669	4725	Business	40900.00
0005432567659	4725	Business	40900.00
0005432459878	4725	Business	40900.00
0005432459897	4725	Business	40900.00
0005433726105	4725	Business	40900.00
0005432567701	4725	Business	40900.00
0005432567673	4725	Business	40900.00
0005432459864	4725	Business	40900.00
0005432459894	4725	Business	40900.00
0005432170389	4725	Business	40900.00
0005432567711	4725	Business	40900.00
0005432571326	4725	Business	40900.00
0005432567698	4725	Business	40900.00
0005432459884	4725	Business	40900.00
0005432567657	4725	Economy	15000.00
0005432567694	4725	Economy	13600.00
0005432567684	4725	Economy	13600.00
0005432567681	4725	Economy	13600.00
0005432567695	4725	Economy	13600.00
0005432459868	4725	Economy	13600.00
0005432567709	4725	Economy	13600.00
0005432459888	4725	Economy	13600.00
0005432459889	4725	Economy	13600.00
0005434081927	4725	Economy	13600.00
0005432567665	4725	Economy	13600.00
0005434081925	4725	Economy	13600.00
0005432567688	4725	Economy	13600.00
0005432567678	4725	Economy	13600.00
0005432567656	4725	Economy	13600.00
0005432459902	4725	Economy	13600.00
0005432567652	4725	Economy	13600.00
0005432459876	4725	Economy	13600.00
0005432567670	4725	Economy	13600.00
0005432567671	4725	Economy	13600.00
0005434081921	4725	Economy	13600.00
0005434081923	4725	Economy	13600.00
0005432567692	4725	Economy	13600.00
0005432459911	4725	Economy	13600.00
0005432567675	4725	Economy	13600.00
0005432459870	4725	Economy	13600.00
0005432567674	4725	Economy	13600.00
0005432459900	4725	Economy	13600.00
0005432567699	4725	Economy	13600.00
0005432459874	4725	Economy	13600.00
0005432459904	4725	Economy	13600.00
0005432459906	4725	Economy	13600.00
0005432459872	4725	Economy	13600.00
0005432459908	4725	Economy	13600.00
0005432170395	4725	Economy	13600.00
0005432567700	4725	Economy	13600.00
0005432567680	4725	Economy	13600.00
0005432459915	4725	Economy	13600.00
0005432170390	4725	Economy	13600.00
0005432186871	4725	Economy	13600.00
0005432459893	4725	Economy	13600.00
0005432567689	4725	Economy	13600.00
0005432459891	4725	Economy	13600.00
0005432567668	4725	Economy	13600.00
0005432459879	4725	Economy	13600.00
0005432459892	4725	Economy	13600.00
0005432567679	4725	Economy	13600.00
0005432170394	4725	Economy	13600.00
0005434081920	4725	Economy	13600.00
0005432567651	4725	Economy	13600.00
0005432459914	4725	Economy	13600.00
0005432567683	4725	Economy	13600.00
0005432459912	4725	Economy	13600.00
0005432459901	4725	Economy	13600.00
0005432567682	4725	Economy	13600.00
0005432567663	4725	Economy	13600.00
0005432459890	4725	Economy	13600.00
0005432459905	4725	Economy	13600.00
0005434081926	4725	Economy	13600.00
0005434081918	4725	Economy	13600.00
0005432567661	4725	Economy	13600.00
0005432571325	4725	Economy	13600.00
0005434081922	4725	Economy	13600.00
0005433452742	4725	Economy	13600.00
0005432567686	4725	Economy	13600.00
0005432459903	4725	Economy	13600.00
0005432459883	4725	Economy	13600.00
0005432567713	4725	Economy	13600.00
0005432567704	4725	Economy	15000.00
0005432459896	4725	Economy	15000.00
0005432170396	4725	Economy	13600.00
0005432170392	4725	Economy	15000.00
0005432567705	4725	Economy	13600.00
0005432567655	4725	Economy	13600.00
0005432459917	4725	Economy	13600.00
0005432459882	4725	Economy	13600.00
0005432459895	4725	Economy	13600.00
0005432170391	4725	Economy	13600.00
0005432567664	4725	Economy	13600.00
0005432567658	4725	Economy	13600.00
0005432459910	4725	Economy	13600.00
0005433452741	4725	Economy	13600.00
0005434081919	4725	Economy	13600.00
0005432459881	4725	Economy	13600.00
0005432459899	4725	Economy	13600.00
0005432567687	4725	Economy	13600.00
0005432459866	4725	Economy	13600.00
0005432567712	4725	Economy	13600.00
0005432459871	4725	Economy	13600.00
0005433726106	4725	Economy	13600.00
0005432459885	4725	Economy	13600.00
0005432459887	4725	Economy	13600.00
0005432186874	4725	Economy	13600.00
0005432459913	4725	Economy	13600.00
0005432567693	4725	Economy	13600.00
0005432567654	4725	Economy	13600.00
0005432567702	4725	Economy	13600.00
0005434081928	4725	Economy	13600.00
0005432459880	4725	Economy	13600.00
0005432567677	4725	Economy	13600.00
0005432459869	4725	Economy	13600.00
0005432459909	4725	Economy	13600.00
0005432567672	4725	Economy	13600.00
0005432567660	4725	Economy	13600.00
0005432459886	4725	Economy	13600.00
0005432567707	4725	Economy	13600.00
0005432459873	4725	Economy	13600.00
0005432567706	4725	Economy	13600.00
0005432170393	4725	Economy	13600.00
0005432567697	4725	Economy	13600.00
0005432459875	4725	Economy	13600.00
0005432567676	4725	Economy	13600.00
0005432186872	4725	Economy	13600.00
0005432459907	4725	Economy	13600.00
0005432567653	4725	Economy	13600.00
0005432567703	4725	Economy	13600.00
0005432186873	4725	Economy	13600.00
0005432567666	4725	Economy	13600.00
0005432459865	4725	Economy	13600.00
0005433452740	4725	Economy	13600.00
0005432459877	4725	Economy	13600.00
0005432567662	4725	Economy	13600.00
0005432459898	4725	Economy	13600.00
0005432161153	30572	Business	40900.00
0005432459334	30572	Business	40900.00
0005432459363	30572	Business	40900.00
0005432567416	30572	Business	40900.00
0005432567252	30572	Business	40900.00
0005432567317	30572	Business	40900.00
0005432567318	30572	Business	40900.00
0005434081627	30572	Business	40900.00
0005432567033	30572	Business	40900.00
0005432213609	30572	Business	40900.00
0005432567248	30572	Business	40900.00
0005432459668	30572	Business	40900.00
0005432459490	30572	Business	40900.00
0005432567412	30572	Business	40900.00
0005432567171	30572	Business	40900.00
0005432567433	30572	Business	40900.00
0005432459438	30572	Business	40900.00
0005432161154	30572	Business	40900.00
0005432459669	30572	Business	40900.00
0005433452726	30572	Economy	15000.00
0005432567219	30572	Economy	15000.00
0005432459402	30572	Economy	15000.00
0005432566895	30572	Economy	13600.00
0005432567133	30572	Economy	13600.00
0005432567445	30572	Economy	13600.00
0005432566909	30572	Economy	13600.00
0005434081667	30572	Economy	13600.00
0005432567169	30572	Economy	13600.00
0005432567196	30572	Economy	13600.00
0005432567313	30572	Economy	13600.00
0005432459437	30572	Economy	13600.00
0005434081643	30572	Economy	13600.00
0005432567367	30572	Economy	13600.00
0005432459504	30572	Economy	13600.00
0005432567186	30572	Economy	13600.00
0005434081622	30572	Economy	13600.00
0005432459378	30572	Economy	13600.00
0005434081669	30572	Economy	13600.00
0005432459545	30572	Economy	13600.00
0005432459523	30572	Economy	13600.00
0005432459655	30572	Economy	13600.00
0005432459288	30572	Economy	13600.00
0005434081601	30572	Economy	13600.00
0005432459471	30572	Economy	13600.00
0005434081645	30572	Economy	13600.00
0005433452727	30572	Economy	13600.00
0005432459333	30572	Economy	13600.00
0005432567312	30572	Economy	13600.00
0005432213610	30572	Economy	13600.00
0005434081688	30572	Economy	13600.00
0005432571284	30572	Economy	13600.00
0005434081665	30572	Economy	13600.00
0005432567168	30572	Economy	13600.00
0005432567322	30572	Economy	13600.00
0005432213608	30572	Economy	13600.00
0005432567329	30572	Economy	13600.00
0005432459184	30572	Economy	13600.00
0005432567355	30572	Economy	13600.00
0005432459677	30572	Economy	13600.00
0005434081670	30572	Economy	13600.00
0005432567448	30572	Economy	13600.00
0005432567570	30572	Economy	13600.00
0005432567315	30572	Economy	13600.00
0005434081655	30572	Economy	13600.00
0005432459450	30572	Economy	13600.00
0005432459578	30572	Economy	13600.00
0005432571300	30572	Economy	13600.00
0005432567267	30572	Economy	13600.00
0005433452724	30572	Economy	13600.00
0005432567209	30572	Economy	13600.00
0005432567220	30572	Economy	13600.00
0005432459579	30572	Economy	13600.00
0005432459287	30572	Economy	13600.00
0005432459348	30572	Economy	13600.00
0005432567178	30572	Economy	13600.00
0005432459514	30572	Economy	13600.00
0005432567386	30572	Economy	13600.00
0005432567166	30572	Economy	13600.00
0005432459608	30572	Economy	13600.00
0005432459609	30572	Economy	13600.00
0005432459676	30572	Economy	15000.00
0005432567270	30572	Economy	13600.00
0005432567381	30572	Economy	13600.00
0005432567569	30572	Economy	13600.00
0005432459515	30572	Economy	13600.00
0005432567179	30572	Economy	13600.00
0005432567356	30572	Economy	13600.00
0005432459428	30572	Economy	13600.00
0005432459618	30572	Economy	13600.00
0005432459527	30572	Economy	13600.00
0005434081628	30572	Economy	13600.00
0005432459654	30572	Economy	13600.00
0005432459441	30572	Economy	13600.00
0005433454854	30572	Economy	13600.00
0005432567055	30572	Economy	13600.00
0005432567357	30572	Economy	13600.00
0005432567284	30572	Economy	13600.00
0005432459392	30572	Economy	13600.00
0005432459269	30572	Economy	13600.00
0005432567041	30572	Economy	13600.00
0005432567253	30572	Economy	13600.00
0005432459752	30572	Economy	13600.00
0005432567366	30572	Economy	13600.00
0005433452728	30572	Economy	13600.00
0005432566949	30572	Economy	13600.00
0005434081666	30572	Economy	13600.00
0005432567238	30572	Economy	13600.00
0005434081687	30572	Economy	13600.00
0005432459449	30572	Economy	13600.00
0005432571294	30572	Economy	13600.00
0005432459480	30572	Economy	13600.00
0005432571296	30572	Economy	13600.00
0005432567247	30572	Economy	13600.00
0005434081657	30572	Economy	13600.00
0005433454855	30572	Economy	13600.00
0005432459401	30572	Economy	13600.00
0005432567188	30572	Economy	13600.00
0005432459391	30572	Economy	13600.00
0005432567167	30572	Economy	13600.00
0005432459407	30572	Economy	13600.00
0005432567050	30572	Economy	13600.00
0005432567316	30572	Economy	13600.00
0005432459619	30572	Economy	13600.00
0005432459571	30572	Economy	13600.00
0005434081623	30572	Economy	13600.00
0005434081658	30572	Economy	13600.00
0005432567413	30572	Economy	13600.00
0005432567319	30572	Economy	13600.00
0005432567330	30572	Economy	13600.00
0005432459572	30572	Economy	13600.00
0005432566947	30572	Economy	13600.00
0005432567113	30572	Economy	13600.00
0005432566896	30572	Economy	13600.00
0005432566948	30572	Economy	13600.00
0005432567258	30572	Economy	13600.00
0005432567246	30572	Economy	13600.00
0005435722057	13664	Economy	9900.00
0005435722056	13664	Economy	9900.00
0005435720127	21128	Economy	9900.00
0005435720129	21128	Economy	9900.00
0005435722039	21128	Economy	9900.00
0005435720124	21128	Economy	9900.00
0005432295882	22793	Economy	8800.00
0005432295881	22793	Economy	8800.00
0005435508256	11127	Business	23600.00
0005433343305	11127	Business	23600.00
0005433343311	11127	Business	23600.00
0005433343274	11127	Business	23600.00
0005435380262	11127	Business	23600.00
0005433343275	11127	Business	23600.00
0005435508235	11127	Business	23600.00
0005433343251	11127	Business	23600.00
0005435508265	11127	Business	23600.00
0005433343225	11127	Business	23600.00
0005433343237	11127	Business	23600.00
0005433343257	11127	Business	23600.00
0005435380269	11127	Economy	7900.00
0005433343306	11127	Economy	7900.00
0005433343228	11127	Economy	7900.00
0005433343235	11127	Economy	7900.00
0005433343256	11127	Economy	7900.00
0005433343260	11127	Economy	7900.00
0005433343281	11127	Economy	7900.00
0005435380261	11127	Economy	7900.00
0005433343218	11127	Economy	7900.00
0005433343278	11127	Economy	7900.00
0005433343246	11127	Economy	7900.00
0005433343297	11127	Economy	7900.00
0005433343288	11127	Economy	7900.00
0005435097203	11127	Economy	7900.00
0005433343255	11127	Economy	7900.00
0005435097205	11127	Economy	7900.00
0005435097202	11127	Economy	7900.00
0005433343270	11127	Economy	7900.00
0005433343262	11127	Economy	7900.00
0005433343243	11127	Economy	7900.00
0005433343268	11127	Economy	7900.00
0005435380238	11127	Economy	7900.00
0005435097201	11127	Economy	7900.00
0005433343244	11127	Economy	7900.00
0005435097207	11127	Economy	7900.00
0005433343214	11127	Economy	7900.00
0005433343226	11127	Economy	7900.00
0005435508237	11127	Economy	7900.00
0005433343310	11127	Economy	7900.00
0005433343282	11127	Economy	7900.00
0005433343247	11127	Economy	7900.00
0005433343312	11127	Economy	7900.00
0005433343263	11127	Economy	7900.00
0005433343285	11127	Economy	7900.00
0005433343248	11127	Economy	7900.00
0005433343266	11127	Economy	7900.00
0005433343279	11127	Economy	7900.00
0005435380253	11127	Economy	7900.00
0005433343240	11127	Economy	7900.00
0005433343294	11127	Economy	7900.00
0005435508225	11127	Economy	8600.00
0005433343304	11127	Economy	8600.00
0005433343264	11127	Economy	8600.00
0005435097199	11127	Economy	8600.00
0005433343283	11127	Economy	8600.00
0005433343302	11127	Economy	7900.00
0005433343291	11127	Economy	7900.00
0005433343286	11127	Economy	7900.00
0005433343271	11127	Economy	7900.00
0005433343234	11127	Economy	7900.00
0005433343284	11127	Economy	7900.00
0005433343245	11127	Economy	7900.00
0005433343280	11127	Economy	7900.00
0005433343287	11127	Economy	7900.00
0005433343308	11127	Economy	7900.00
0005433343242	11127	Economy	7900.00
0005433343307	11127	Economy	7900.00
0005433343249	11127	Economy	7900.00
0005433343254	11127	Economy	7900.00
0005433343232	11127	Economy	7900.00
0005433343219	11127	Economy	7900.00
0005433343241	11127	Economy	7900.00
0005433343215	11127	Economy	7900.00
0005433343293	11127	Economy	7900.00
0005433343303	11127	Economy	7900.00
0005433343230	11127	Economy	7900.00
0005433343229	11127	Economy	7900.00
0005433343261	11127	Economy	7900.00
0005433343238	11127	Economy	7900.00
0005433343290	11127	Economy	7900.00
0005433343236	11127	Economy	7900.00
0005433343269	11127	Economy	7900.00
0005433343300	11127	Economy	7900.00
0005435508263	11127	Economy	7900.00
0005433343223	11127	Economy	7900.00
0005433343299	11127	Economy	7900.00
0005433343222	11127	Economy	7900.00
0005433343231	11127	Economy	7900.00
0005433343295	11127	Economy	7900.00
0005433343265	11127	Economy	7900.00
0005433343292	11127	Economy	7900.00
0005433343313	11127	Economy	7900.00
0005433343277	11127	Economy	7900.00
0005433343252	11127	Economy	7900.00
0005433343296	11127	Economy	7900.00
0005433343273	11127	Economy	7900.00
0005435097206	11127	Economy	7900.00
0005433343233	11127	Economy	7900.00
0005433343298	11127	Economy	7900.00
0005433343217	11127	Economy	7900.00
0005433343239	11127	Economy	7900.00
0005433343267	11127	Economy	7900.00
0005433343227	11127	Economy	7900.00
0005433343216	11127	Economy	7900.00
0005435508264	11127	Economy	7900.00
0005433343220	11127	Economy	7900.00
0005433343289	11127	Economy	7900.00
0005435508238	11127	Economy	7900.00
0005433343258	11127	Economy	7900.00
0005435508248	11127	Economy	7900.00
0005433343309	11127	Economy	7900.00
0005435097204	11127	Economy	7900.00
0005435380252	11127	Economy	7900.00
0005433343213	11127	Economy	7900.00
0005433343253	11127	Economy	7900.00
0005433343224	11127	Economy	7900.00
0005433343259	11127	Economy	7900.00
0005433343276	11127	Economy	7900.00
0005435380250	11127	Economy	7900.00
0005433343250	11127	Economy	7900.00
0005433343301	11127	Economy	7900.00
0005435508249	11127	Economy	7900.00
0005433343221	11127	Economy	7900.00
0005435097200	11127	Economy	7900.00
0005433343272	11127	Economy	7900.00
0005435508215	11127	Economy	7900.00
0005435545741	17131	Business	23600.00
0005433342366	17131	Business	23600.00
0005433341910	17131	Business	23600.00
0005433342286	17131	Business	23600.00
0005433341919	17131	Business	23600.00
0005435097118	17131	Business	23600.00
0005433342550	17131	Business	23600.00
0005435545747	17131	Business	23600.00
0005435545749	17131	Business	23600.00
0005435545745	17131	Business	23600.00
0005433341927	17131	Business	23600.00
0005435380300	17131	Business	23600.00
0005435545743	17131	Economy	7900.00
0005435380303	17131	Economy	7900.00
0005433341935	17131	Economy	7900.00
0005435545742	17131	Economy	7900.00
0005435097088	17131	Economy	7900.00
0005433342395	17131	Economy	7900.00
0005435380304	17131	Economy	7900.00
0005433342446	17131	Economy	7900.00
0005433342282	17131	Economy	7900.00
0005433342423	17131	Economy	7900.00
0005435545744	17131	Economy	7900.00
0005433342269	17131	Economy	7900.00
0005435380301	17131	Economy	7900.00
0005433342160	17131	Economy	7900.00
0005433342241	17131	Economy	7900.00
0005433342507	17131	Economy	7900.00
0005433342038	17131	Economy	7900.00
0005433341947	17131	Economy	7900.00
0005433342495	17131	Economy	7900.00
0005433341926	17131	Economy	7900.00
0005433342325	17131	Economy	7900.00
0005433342494	17131	Economy	7900.00
0005433342082	17131	Economy	7900.00
0005435097138	17131	Economy	7900.00
0005433342591	17131	Economy	7900.00
0005433342512	17131	Economy	7900.00
0005433342047	17131	Economy	7900.00
0005433342479	17131	Economy	7900.00
0005435380299	17131	Economy	7900.00
0005433342310	17131	Economy	7900.00
0005435545751	17131	Economy	7900.00
0005433342430	17131	Economy	7900.00
0005433342469	17131	Economy	7900.00
0005435097132	17131	Economy	7900.00
0005433342145	17131	Economy	7900.00
0005433342560	17131	Economy	7900.00
0005433342539	17131	Economy	7900.00
0005433342358	17131	Economy	7900.00
0005435097140	17131	Economy	7900.00
0005433342792	17131	Economy	7900.00
0005433342444	17131	Economy	8600.00
0005432293210	17131	Economy	8600.00
0005433342579	17131	Economy	8600.00
0005433341909	17131	Economy	8600.00
0005435097125	17131	Economy	8600.00
0005433342681	17131	Economy	7900.00
0005433342285	17131	Economy	8600.00
0005433342126	17131	Economy	7900.00
0005433342306	17131	Economy	7900.00
0005433341906	17131	Economy	7900.00
0005433341820	17131	Economy	7900.00
0005433341939	17131	Economy	7900.00
0005433342340	17131	Economy	7900.00
0005433342003	17131	Economy	7900.00
0005433341733	17131	Economy	7900.00
0005433342127	17131	Economy	7900.00
0005433342359	17131	Economy	7900.00
0005433342258	17131	Economy	7900.00
0005433342324	17131	Economy	7900.00
0005433342246	17131	Economy	7900.00
0005433342553	17131	Economy	7900.00
0005433342508	17131	Economy	7900.00
0005433342713	17131	Economy	7900.00
0005433341819	17131	Economy	7900.00
0005433342570	17131	Economy	7900.00
0005433342429	17131	Economy	7900.00
0005433342139	17131	Economy	7900.00
0005433342161	17131	Economy	7900.00
0005435097117	17131	Economy	7900.00
0005435380302	17131	Economy	7900.00
0005433342039	17131	Economy	7900.00
0005433342518	17131	Economy	7900.00
0005433342830	17131	Economy	7900.00
0005433342094	17131	Economy	7900.00
0005433342305	17131	Economy	7900.00
0005433342474	17131	Economy	7900.00
0005433342116	17131	Economy	7900.00
0005433342284	17131	Economy	7900.00
0005433342402	17131	Economy	7900.00
0005433342433	17131	Economy	7900.00
0005433342422	17131	Economy	7900.00
0005433342552	17131	Economy	7900.00
0005433342332	17131	Economy	7900.00
0005433341907	17131	Economy	7900.00
0005433342304	17131	Economy	7900.00
0005433342104	17131	Economy	7900.00
0005433342095	17131	Economy	7900.00
0005432293211	17131	Economy	7900.00
0005433342144	17131	Economy	7900.00
0005433342156	17131	Economy	7900.00
0005435097139	17131	Economy	7900.00
0005433342561	17131	Economy	7900.00
0005433342445	17131	Economy	7900.00
0005433342272	17131	Economy	7900.00
0005433342506	17131	Economy	7900.00
0005433342481	17131	Economy	7900.00
0005433342480	17131	Economy	7900.00
0005435545750	17131	Economy	7900.00
0005433342714	17131	Economy	7900.00
0005433341934	17131	Economy	7900.00
0005435097126	17131	Economy	7900.00
0005433342171	17131	Economy	7900.00
0005435545746	17131	Economy	7900.00
0005433342360	17131	Economy	7900.00
0005433342379	17131	Economy	7900.00
0005433342315	17131	Economy	7900.00
0005433342331	17131	Economy	7900.00
0005433342283	17131	Economy	7900.00
0005433342578	17131	Economy	7900.00
0005433341925	17131	Economy	7900.00
0005433342473	17131	Economy	7900.00
0005435097127	17131	Economy	7900.00
0005435545748	17131	Economy	7900.00
0005433342401	17131	Economy	7900.00
0005433341908	17131	Economy	7900.00
0005433507210	9070	Business	26600.00
0005433507203	9070	Business	26600.00
0005433507208	9070	Business	26600.00
0005432919600	9070	Business	26600.00
0005433507204	9070	Business	26600.00
0005433481177	9070	Business	26600.00
0005433507200	9070	Economy	8900.00
0005432919662	9070	Economy	8900.00
0005433481173	9070	Economy	8900.00
0005433507211	9070	Economy	8900.00
0005433481171	9070	Economy	8900.00
0005433507197	9070	Economy	9800.00
0005432919722	9070	Economy	9800.00
0005433481172	9070	Economy	9800.00
0005432919733	9070	Economy	8900.00
0005432919777	9070	Economy	8900.00
0005432919692	9070	Economy	8900.00
0005434158957	9070	Economy	8900.00
0005433507202	9070	Economy	8900.00
0005433507193	9070	Economy	8900.00
0005433507207	9070	Economy	8900.00
0005433507196	9070	Economy	8900.00
0005432919684	9070	Economy	8900.00
0005433507206	9070	Economy	8900.00
0005432919778	9070	Economy	8900.00
0005432919707	9070	Economy	8900.00
0005433481178	9070	Economy	8900.00
0005433481175	9070	Economy	8900.00
0005433481174	9070	Economy	8900.00
0005432919686	9070	Economy	8900.00
0005432919664	9070	Economy	8900.00
0005434158963	9070	Economy	8900.00
0005432919723	9070	Economy	8900.00
0005433507191	9070	Economy	8900.00
0005433507195	9070	Economy	8900.00
0005432919658	9070	Economy	8900.00
0005432919694	9070	Economy	8900.00
0005432919769	9070	Economy	8900.00
0005432919663	9070	Economy	8900.00
0005432919717	9070	Economy	8900.00
0005433507201	9070	Economy	8900.00
0005433507209	9070	Economy	8900.00
0005433507198	9070	Economy	8900.00
0005433507194	9070	Economy	8900.00
0005433507199	9070	Economy	8900.00
0005432919728	9070	Economy	8900.00
0005433481176	9070	Economy	8900.00
0005432919797	9070	Economy	8900.00
0005433507205	9070	Economy	8900.00
0005433507192	9070	Economy	8900.00
0005432919798	9070	Economy	8900.00
0005432919907	20474	Business	26600.00
0005433507023	20474	Business	26600.00
0005433507057	20474	Business	26600.00
0005434158976	20474	Business	26600.00
0005433507084	20474	Business	26600.00
0005432919890	20474	Business	26600.00
0005433507031	20474	Business	26600.00
0005433507110	20474	Business	26600.00
0005433507148	20474	Economy	8900.00
0005432919898	20474	Economy	8900.00
0005432919896	20474	Economy	8900.00
0005433481144	20474	Economy	8900.00
0005433507062	20474	Economy	8900.00
0005432919891	20474	Economy	8900.00
0005434158975	20474	Economy	8900.00
0005434158977	20474	Economy	9800.00
0005432919895	20474	Economy	8900.00
0005433507109	20474	Economy	8900.00
0005433481123	20474	Economy	8900.00
0005433507083	20474	Economy	8900.00
0005432919906	20474	Economy	8900.00
0005433481108	20474	Economy	8900.00
0005433507052	20474	Economy	8900.00
0005433507013	20474	Economy	8900.00
0005432919908	20474	Economy	8900.00
0005433507078	20474	Economy	8900.00
0005432919894	20474	Economy	8900.00
0005432919904	20474	Economy	8900.00
0005432919905	20474	Economy	8900.00
0005433481120	20474	Economy	8900.00
0005432919903	20474	Economy	8900.00
0005433507082	20474	Economy	8900.00
0005432919888	20474	Economy	8900.00
0005432919901	20474	Economy	8900.00
0005433507066	20474	Economy	8900.00
0005433507122	20474	Economy	8900.00
0005433507077	20474	Economy	8900.00
0005433507034	20474	Economy	8900.00
0005433507089	20474	Economy	8900.00
0005432919897	20474	Economy	8900.00
0005432919899	20474	Economy	8900.00
0005433507051	20474	Economy	8900.00
0005433507111	20474	Economy	8900.00
0005433506988	20474	Economy	8900.00
0005433507087	20474	Economy	8900.00
0005432919893	20474	Economy	8900.00
0005432919900	20474	Economy	8900.00
0005433507065	20474	Economy	8900.00
0005432919902	20474	Economy	8900.00
0005432919892	20474	Economy	8900.00
0005432919889	20474	Economy	8900.00
0005433507030	20474	Economy	8900.00
0005433481083	20474	Economy	8900.00
0005432394102	10184	Economy	5800.00
0005432396242	10184	Economy	5800.00
0005432394103	10184	Economy	5800.00
0005432394104	10184	Economy	5800.00
0005435179690	10184	Economy	5800.00
0005432394106	10184	Economy	5800.00
0005432394105	10184	Economy	5800.00
0005432396243	10184	Economy	5800.00
0005432396244	10184	Economy	5800.00
0005432396204	18296	Economy	5800.00
0005432396219	18296	Economy	5800.00
0005432396205	18296	Economy	5800.00
0005432400084	18296	Economy	5800.00
0005432396206	18296	Economy	5800.00
0005432400083	18296	Economy	5800.00
0005432396213	18296	Economy	5800.00
0005432400082	18296	Economy	5800.00
0005432396209	18296	Economy	5800.00
0005432396208	18296	Economy	5800.00
0005432396214	18296	Economy	5800.00
0005435125988	10949	Business	9500.00
0005435626020	10949	Business	9500.00
0005435125981	10949	Business	9500.00
0005435125987	10949	Business	9500.00
0005435126090	10949	Business	9500.00
0005435125924	10949	Business	9500.00
0005435125982	10949	Business	9500.00
0005435126059	10949	Economy	3200.00
0005435626025	10949	Economy	3200.00
0005435125953	10949	Economy	3200.00
0005435626021	10949	Economy	3200.00
0005435626022	10949	Economy	3200.00
0005435126078	10949	Economy	3200.00
0005435126064	10949	Economy	3500.00
0005435625980	10949	Economy	3500.00
0005435126071	10949	Economy	3500.00
0005434928301	10949	Economy	3500.00
0005434411781	10949	Economy	3200.00
0005434411782	10949	Economy	3200.00
0005435625917	10949	Economy	3200.00
0005435625989	10949	Economy	3200.00
0005435125954	10949	Economy	3200.00
0005435126009	10949	Economy	3200.00
0005435626011	10949	Economy	3200.00
0005435126099	10949	Economy	3200.00
0005435126149	10949	Economy	3200.00
0005435126000	10949	Economy	3200.00
0005435626036	10949	Economy	3200.00
0005435125965	10949	Economy	3200.00
0005435554164	10949	Economy	3200.00
0005435126199	10949	Economy	3200.00
0005435126198	10949	Economy	3200.00
0005435626023	10949	Economy	3200.00
0005435626018	10949	Economy	3200.00
0005435125949	10949	Economy	3200.00
0005435626001	10949	Economy	3200.00
0005435125835	10949	Economy	3200.00
0005434928303	10949	Economy	3200.00
0005435126228	10949	Economy	3200.00
0005434928302	10949	Economy	3200.00
0005435126049	10949	Economy	3200.00
0005435625953	10949	Economy	3200.00
0005435126142	10949	Economy	3200.00
0005435626000	10949	Economy	3200.00
0005435125923	10949	Economy	3200.00
0005435126015	10949	Economy	3200.00
0005435126020	10949	Economy	3200.00
0005435125966	10949	Economy	3200.00
0005435125719	10949	Economy	3200.00
0005435556671	10949	Economy	3200.00
0005435626024	10949	Economy	3200.00
0005435126069	10949	Economy	3200.00
0005435125916	10949	Economy	3200.00
0005435125952	10949	Economy	3200.00
0005435126089	10949	Economy	3200.00
0005435126115	10949	Economy	3200.00
0005435626014	10949	Economy	3200.00
0005435126145	10949	Economy	3200.00
0005434411783	10949	Economy	3200.00
0005434928304	10949	Economy	3200.00
0005435126050	10949	Economy	3200.00
0005435626016	10949	Economy	3200.00
0005435125948	10949	Economy	3200.00
0005435125877	10949	Economy	3200.00
0005435625981	10949	Economy	3200.00
0005435126048	10949	Economy	3200.00
0005435125933	10949	Economy	3200.00
0005435626030	10949	Economy	3200.00
0005435125893	10949	Economy	3200.00
0005435626010	10949	Economy	3200.00
0005435625993	10949	Economy	3200.00
0005435125892	10949	Economy	3200.00
0005434411784	10949	Economy	3200.00
0005435554140	10949	Economy	3200.00
0005435126008	10949	Economy	3200.00
0005434411748	14716	Business	9500.00
0005435126423	14716	Business	9500.00
0005435126410	14716	Business	9500.00
0005435126400	14716	Business	9500.00
0005435126403	14716	Business	9500.00
0005435126431	14716	Business	9500.00
0005435126419	14716	Business	9500.00
0005435126435	14716	Business	9500.00
0005434411744	14716	Business	9500.00
0005435126424	14716	Business	9500.00
0005435126433	14716	Business	9500.00
0005435126402	14716	Economy	3200.00
0005435126401	14716	Economy	3200.00
0005435626175	14716	Economy	3200.00
0005435626181	14716	Economy	3200.00
0005435554190	14716	Economy	3200.00
0005435626191	14716	Economy	3200.00
0005435126404	14716	Economy	3200.00
0005435556696	14716	Economy	3500.00
0005435126411	14716	Economy	3500.00
0005435126426	14716	Economy	3500.00
0005435126436	14716	Economy	3500.00
0005435554191	14716	Economy	3200.00
0005434411764	14716	Economy	3200.00
0005435126432	14716	Economy	3200.00
0005435626186	14716	Economy	3200.00
0005435126417	14716	Economy	3200.00
0005435126413	14716	Economy	3200.00
0005435126405	14716	Economy	3200.00
0005435126408	14716	Economy	3200.00
0005435126421	14716	Economy	3200.00
0005435126415	14716	Economy	3200.00
0005435626184	14716	Economy	3200.00
0005435126434	14716	Economy	3200.00
0005435626180	14716	Economy	3200.00
0005435126407	14716	Economy	3200.00
0005435556695	14716	Economy	3200.00
0005435626178	14716	Economy	3200.00
0005435556693	14716	Economy	3200.00
0005435626177	14716	Economy	3200.00
0005435126409	14716	Economy	3200.00
0005435126420	14716	Economy	3200.00
0005435626190	14716	Economy	3200.00
0005435126428	14716	Economy	3200.00
0005435554188	14716	Economy	3200.00
0005435126416	14716	Economy	3200.00
0005435626183	14716	Economy	3200.00
0005435126418	14716	Economy	3200.00
0005435126422	14716	Economy	3200.00
0005435626189	14716	Economy	3200.00
0005435626187	14716	Economy	3200.00
0005435626188	14716	Economy	3200.00
0005435626174	14716	Economy	3200.00
0005435126406	14716	Economy	3200.00
0005435126425	14716	Economy	3200.00
0005435556694	14716	Economy	3200.00
0005435126412	14716	Economy	3200.00
0005435126397	14716	Economy	3200.00
0005435626176	14716	Economy	3200.00
0005435626192	14716	Economy	3200.00
0005435126399	14716	Economy	3200.00
0005435126427	14716	Economy	3200.00
0005435626185	14716	Economy	3200.00
0005435126398	14716	Economy	3200.00
0005435126429	14716	Economy	3200.00
0005435126396	14716	Economy	3200.00
0005435626182	14716	Economy	3200.00
0005435126437	14716	Economy	3200.00
0005435626179	14716	Economy	3200.00
0005435126414	14716	Economy	3200.00
0005435126430	14716	Economy	3200.00
0005435554189	14716	Economy	3200.00
0005434928278	14717	Economy	3200.00
0005434928279	14717	Economy	3200.00
0005435219188	7113	Business	86900.00
0005432400128	7113	Business	86900.00
0005435715484	7113	Business	86900.00
0005435715489	7113	Business	86900.00
0005432400126	7113	Business	86900.00
0005435178483	7113	Business	86900.00
0005435443259	7113	Business	86900.00
0005432398201	7113	Economy	29000.00
0005435443190	7113	Economy	29000.00
0005435715491	7113	Economy	29000.00
0005435715486	7113	Economy	31900.00
0005435221044	7113	Economy	29000.00
0005435715493	7113	Economy	29000.00
0005432398200	7113	Economy	29000.00
0005435216574	7113	Economy	29000.00
0005432398203	7113	Economy	29000.00
0005435715483	7113	Economy	29000.00
0005432400129	7113	Economy	29000.00
0005435443268	7113	Economy	29000.00
0005432398202	7113	Economy	29000.00
0005435715490	7113	Economy	29000.00
0005435443282	7113	Economy	29000.00
0005435715487	7113	Economy	29000.00
0005435715481	7113	Economy	29000.00
0005435715479	7113	Economy	29000.00
0005435715482	7113	Economy	29000.00
0005435443257	7113	Economy	29000.00
0005435715480	7113	Economy	29000.00
0005435715478	7113	Economy	29000.00
0005432400127	7113	Economy	29000.00
0005435443189	7113	Economy	29000.00
0005435221045	7113	Economy	29000.00
0005435443204	7113	Economy	29000.00
0005432400130	7113	Economy	29000.00
0005435715492	7113	Economy	29000.00
0005435715477	7113	Economy	29000.00
0005435715488	7113	Economy	29000.00
0005435715485	7113	Economy	29000.00
0005435178992	27059	Business	86900.00
0005435216587	27059	Business	86900.00
0005432394056	27059	Business	86900.00
0005435217714	27059	Business	86900.00
0005435443327	27059	Business	86900.00
0005435715398	27059	Business	86900.00
0005435715329	27059	Business	86900.00
0005435216590	27059	Economy	29000.00
0005435217712	27059	Economy	29000.00
0005435715298	27059	Economy	29000.00
0005435715343	27059	Economy	29000.00
0005435216585	27059	Economy	29000.00
0005435443323	27059	Economy	31900.00
0005435217709	27059	Economy	31900.00
0005435217711	27059	Economy	29000.00
0005435715349	27059	Economy	29000.00
0005435715363	27059	Economy	29000.00
0005432394058	27059	Economy	29000.00
0005435715301	27059	Economy	29000.00
0005432398170	27059	Economy	29000.00
0005435715351	27059	Economy	29000.00
0005435178497	27059	Economy	29000.00
0005432398169	27059	Economy	29000.00
0005435216591	27059	Economy	29000.00
0005435443321	27059	Economy	29000.00
0005435443325	27059	Economy	29000.00
0005435715353	27059	Economy	29000.00
0005435218113	27059	Economy	29000.00
0005435715278	27059	Economy	29000.00
0005435218115	27059	Economy	29000.00
0005435715355	27059	Economy	29000.00
0005435715345	27059	Economy	29000.00
0005435715367	27059	Economy	29000.00
0005435715330	27059	Economy	29000.00
0005435715344	27059	Economy	29000.00
0005435217715	27059	Economy	29000.00
0005435216589	27059	Economy	29000.00
0005435443326	27059	Economy	29000.00
0005432394076	27059	Economy	29000.00
0005435216586	27059	Economy	29000.00
0005435715300	27059	Economy	29000.00
0005435178495	27059	Economy	29000.00
0005435216588	27059	Economy	29000.00
0005435443320	27059	Economy	29000.00
0005435715277	27059	Economy	29000.00
0005435443319	27059	Economy	29000.00
0005435443324	27059	Economy	29000.00
0005435715352	27059	Economy	29000.00
0005435217713	27059	Economy	29000.00
0005435178496	27059	Economy	29000.00
0005435715279	27059	Economy	29000.00
0005435443322	27059	Economy	29000.00
0005432394055	27059	Economy	29000.00
0005432394075	27059	Economy	29000.00
0005435715324	27059	Economy	29000.00
0005432394057	27059	Economy	29000.00
0005435217710	27059	Economy	29000.00
0005435715328	27059	Economy	29000.00
0005435218114	27059	Economy	29000.00
0005435715361	27059	Economy	29000.00
0005434084934	2748	Economy	7700.00
0005433060390	2748	Economy	7700.00
0005433060384	2748	Economy	7700.00
0005434084935	2748	Economy	7700.00
0005434084936	2748	Economy	7700.00
0005434084933	2748	Economy	7700.00
0005433060396	2748	Economy	7700.00
0005434084887	28487	Economy	7700.00
0005434084877	28487	Economy	7700.00
0005434084891	28487	Economy	7700.00
0005433060415	28487	Economy	7700.00
0005434084888	28487	Economy	7700.00
0005434084902	28487	Economy	7700.00
0005433060416	28487	Economy	7700.00
0005434084875	28487	Economy	7700.00
0005433060417	28487	Economy	7700.00
0005433060414	28487	Economy	7700.00
0005434084901	28487	Economy	7700.00
0005434084876	28487	Economy	7700.00
0005433788216	11167	Economy	27100.00
0005433788210	11167	Economy	24600.00
0005433788208	11167	Economy	24600.00
0005435548427	11167	Economy	24600.00
0005433788207	11167	Economy	24600.00
0005435548440	11167	Economy	24600.00
0005435548452	11167	Economy	24600.00
0005435548449	11167	Economy	24600.00
0005433788215	11167	Economy	24600.00
0005433788213	11167	Economy	24600.00
0005435548467	11167	Economy	24600.00
0005433788206	11167	Economy	24600.00
0005435548453	11167	Economy	24600.00
0005435548464	11167	Economy	24600.00
0005433788209	11167	Economy	24600.00
0005433788211	11167	Economy	24600.00
0005435548428	11167	Economy	24600.00
0005433788214	11167	Economy	24600.00
0005435548454	11167	Economy	24600.00
0005435548444	11167	Economy	24600.00
0005433788212	11167	Economy	24600.00
0005433788218	11167	Economy	24600.00
0005433788217	11167	Economy	24600.00
0005435548448	11167	Economy	24600.00
0005435548460	11167	Economy	24600.00
0005433788153	20679	Economy	27100.00
0005433788149	20679	Economy	27100.00
0005435548490	20679	Economy	27100.00
0005433788184	20679	Economy	27100.00
0005435548497	20679	Economy	24600.00
0005433788159	20679	Economy	24600.00
0005435548496	20679	Economy	24600.00
0005433788151	20679	Economy	24600.00
0005433788175	20679	Economy	24600.00
0005435548489	20679	Economy	24600.00
0005433788170	20679	Economy	24600.00
0005435548487	20679	Economy	24600.00
0005435548501	20679	Economy	24600.00
0005435548488	20679	Economy	24600.00
0005433788173	20679	Economy	24600.00
0005433788168	20679	Economy	24600.00
0005435548503	20679	Economy	24600.00
0005435548500	20679	Economy	24600.00
0005433788157	20679	Economy	24600.00
0005435548504	20679	Economy	24600.00
0005435548499	20679	Economy	24600.00
0005435548491	20679	Economy	24600.00
0005433788177	20679	Economy	24600.00
0005433788150	20679	Economy	24600.00
0005433788165	20679	Economy	24600.00
0005433788155	20679	Economy	24600.00
0005433788156	20679	Economy	24600.00
0005435548492	20679	Economy	24600.00
0005433788172	20679	Economy	24600.00
0005435548486	20679	Economy	24600.00
0005433788152	20679	Economy	24600.00
0005433788140	20679	Economy	24600.00
0005435548484	20679	Economy	24600.00
0005435548502	20679	Economy	24600.00
0005435548494	20679	Economy	24600.00
0005435548485	20679	Economy	24600.00
0005435548495	20679	Economy	24600.00
0005433788183	20679	Economy	24600.00
0005433788174	20679	Economy	24600.00
0005435548498	20679	Economy	24600.00
0005433788160	20679	Economy	24600.00
0005433788167	20679	Economy	24600.00
0005435548493	20679	Economy	24600.00
0005433788171	20679	Economy	24600.00
0005435540713	11376	Business	20200.00
0005435540847	11376	Business	20200.00
0005435540856	11376	Business	20200.00
0005435540782	11376	Business	20200.00
0005435540821	11376	Economy	6700.00
0005435517808	11376	Economy	6700.00
0005435540828	11376	Economy	6700.00
0005435540898	11376	Economy	6700.00
0005435517815	11376	Economy	6700.00
0005435540916	11376	Economy	7400.00
0005435540845	11376	Economy	7400.00
0005435517816	11376	Economy	7400.00
0005435540758	11376	Economy	6700.00
0005435540806	11376	Economy	6700.00
0005435540865	11376	Economy	6700.00
0005435540843	11376	Economy	6700.00
0005435540841	11376	Economy	6700.00
0005435540829	11376	Economy	6700.00
0005435540869	11376	Economy	6700.00
0005435540822	11376	Economy	6700.00
0005435517752	11376	Economy	6700.00
0005435540810	11376	Economy	6700.00
0005435517866	11376	Economy	6700.00
0005435517779	11376	Economy	6700.00
0005435540712	11376	Economy	6700.00
0005435540846	11376	Economy	6700.00
0005435517781	11376	Economy	6700.00
0005435540937	11376	Economy	6700.00
0005435517787	11376	Economy	6700.00
0005435517753	11376	Economy	6700.00
0005435540844	11376	Economy	6700.00
0005435540842	11376	Economy	6700.00
0005435517809	11376	Economy	6700.00
0005435517806	11376	Economy	6700.00
0005435540917	11376	Economy	6700.00
0005435517865	11376	Economy	6700.00
0005435540932	11376	Economy	6700.00
0005435540891	11376	Economy	6700.00
0005435517857	11376	Economy	6700.00
0005435517775	11376	Economy	6700.00
0005435517807	11376	Economy	6700.00
0005435540862	11376	Economy	6700.00
0005435540814	11376	Economy	6700.00
0005435517858	11376	Economy	6700.00
0005435540861	11376	Economy	6700.00
0005435540816	11376	Economy	6700.00
0005435517833	11376	Economy	6700.00
0005435540848	11376	Economy	6700.00
0005435529275	22265	Business	20200.00
0005435541015	22265	Business	20200.00
0005435541020	22265	Business	20200.00
0005435541014	22265	Business	20200.00
0005435541000	22265	Business	20200.00
0005435541002	22265	Business	20200.00
0005435529265	22265	Business	20200.00
0005435529268	22265	Business	20200.00
0005435529267	22265	Business	20200.00
0005435541009	22265	Economy	6700.00
0005435529270	22265	Economy	6700.00
0005435529273	22265	Economy	6700.00
0005435529259	22265	Economy	6700.00
0005435529272	22265	Economy	7400.00
0005435529258	22265	Economy	7400.00
0005435529257	22265	Economy	7400.00
0005435541010	22265	Economy	6700.00
0005435541012	22265	Economy	6700.00
0005432294487	22265	Economy	6700.00
0005435541019	22265	Economy	6700.00
0005435541003	22265	Economy	6700.00
0005435529269	22265	Economy	6700.00
0005432294488	22265	Economy	6700.00
0005435529274	22265	Economy	6700.00
0005435529266	22265	Economy	6700.00
0005435541001	22265	Economy	6700.00
0005435529264	22265	Economy	6700.00
0005435529271	22265	Economy	6700.00
0005435541004	22265	Economy	6700.00
0005435541011	22265	Economy	6700.00
0005435541022	22265	Economy	6700.00
0005435529256	22265	Economy	6700.00
0005435541021	22265	Economy	6700.00
0005435541013	22265	Economy	6700.00
0005435540999	22265	Economy	6700.00
0005435541006	22265	Economy	6700.00
0005435541008	22265	Economy	6700.00
0005435529262	22265	Economy	6700.00
0005435529263	22265	Economy	6700.00
0005435529261	22265	Economy	6700.00
0005435541007	22265	Economy	6700.00
0005435529260	22265	Economy	6700.00
0005435529276	22265	Economy	6700.00
0005435541016	22265	Economy	6700.00
0005435541005	22265	Economy	6700.00
0005435541018	22265	Economy	6700.00
0005435541017	22265	Economy	6700.00
0005433400954	2307	Business	20200.00
0005434907364	2307	Business	20200.00
0005434907336	2307	Business	20200.00
0005434907325	2307	Business	20200.00
0005434907327	2307	Business	20200.00
0005433251348	2307	Business	20200.00
0005434907345	2307	Business	20200.00
0005434907337	2307	Business	20200.00
0005434907328	2307	Business	20200.00
0005433251181	2307	Business	20200.00
0005434907365	2307	Economy	6700.00
0005434907340	2307	Economy	6700.00
0005433251263	2307	Economy	6700.00
0005433251236	2307	Economy	6700.00
0005434907346	2307	Economy	6700.00
0005433251417	2307	Economy	6700.00
0005433251202	2307	Economy	6700.00
0005434907332	2307	Economy	6700.00
0005433251183	2307	Economy	7400.00
0005433251331	2307	Economy	7400.00
0005434907370	2307	Economy	7400.00
0005434907334	2307	Economy	7400.00
0005434907318	2307	Economy	7400.00
0005434907342	2307	Economy	6700.00
0005433251029	2307	Economy	6700.00
0005434907366	2307	Economy	6700.00
0005434907330	2307	Economy	6700.00
0005434907347	2307	Economy	6700.00
0005433251237	2307	Economy	6700.00
0005433251364	2307	Economy	6700.00
0005434907316	2307	Economy	6700.00
0005434907344	2307	Economy	6700.00
0005433251030	2307	Economy	6700.00
0005434907371	2307	Economy	6700.00
0005434907326	2307	Economy	6700.00
0005434907349	2307	Economy	6700.00
0005434907362	2307	Economy	6700.00
0005434907320	2307	Economy	6700.00
0005434907361	2307	Economy	6700.00
0005433251201	2307	Economy	6700.00
0005434907359	2307	Economy	6700.00
0005434907355	2307	Economy	6700.00
0005434907348	2307	Economy	6700.00
0005434907339	2307	Economy	6700.00
0005434907329	2307	Economy	6700.00
0005434907331	2307	Economy	6700.00
0005434907360	2307	Economy	6700.00
0005433251270	2307	Economy	6700.00
0005434907352	2307	Economy	6700.00
0005434907338	2307	Economy	6700.00
0005433251288	2307	Economy	6700.00
0005434907323	2307	Economy	6700.00
0005434907368	2307	Economy	6700.00
0005434907369	2307	Economy	6700.00
0005433251180	2307	Economy	6700.00
0005434907333	2307	Economy	6700.00
0005433251248	2307	Economy	6700.00
0005434907350	2307	Economy	6700.00
0005433251251	2307	Economy	6700.00
0005434907343	2307	Economy	6700.00
0005433251182	2307	Economy	6700.00
0005434907358	2307	Economy	6700.00
0005433251353	2307	Economy	6700.00
0005434907319	2307	Economy	6700.00
0005434907317	2307	Economy	6700.00
0005434907363	2307	Economy	6700.00
0005434907367	2307	Economy	6700.00
0005433251252	2307	Economy	6700.00
0005434907356	2307	Economy	6700.00
0005433251349	2307	Economy	6700.00
0005433251269	2307	Economy	6700.00
0005434907353	2307	Economy	6700.00
0005433251340	2307	Economy	6700.00
0005434907322	2307	Economy	6700.00
0005434907354	2307	Economy	6700.00
0005434907351	2307	Economy	6700.00
0005434907341	2307	Economy	6700.00
0005434907324	2307	Economy	6700.00
0005434907335	2307	Economy	6700.00
0005434907321	2307	Economy	6700.00
0005434907357	2307	Economy	6700.00
0005434906600	25623	Business	20200.00
0005434906670	25623	Business	20200.00
0005434906917	25623	Business	20200.00
0005434906886	25623	Business	20200.00
0005434906791	25623	Business	20200.00
0005434906822	25623	Business	20200.00
0005434906805	25623	Business	20200.00
0005433400986	25623	Business	20200.00
0005434906847	25623	Business	20200.00
0005433251523	25623	Business	20200.00
0005434906697	25623	Business	20200.00
0005433251503	25623	Business	20200.00
0005434906910	25623	Economy	6700.00
0005433400987	25623	Economy	6700.00
0005433251497	25623	Economy	6700.00
0005433251520	25623	Economy	6700.00
0005434906796	25623	Economy	6700.00
0005433251502	25623	Economy	6700.00
0005434906848	25623	Economy	6700.00
0005434906840	25623	Economy	6700.00
0005434906901	25623	Economy	6700.00
0005433251498	25623	Economy	6700.00
0005433251519	25623	Economy	7400.00
0005433251522	25623	Economy	7400.00
0005433251511	25623	Economy	7400.00
0005433251504	25623	Economy	7400.00
0005433251505	25623	Economy	7400.00
0005434906640	25623	Economy	6700.00
0005433251500	25623	Economy	6700.00
0005433251507	25623	Economy	6700.00
0005434906902	25623	Economy	6700.00
0005434906955	25623	Economy	6700.00
0005433251501	25623	Economy	6700.00
0005433251506	25623	Economy	6700.00
0005434907042	25623	Economy	6700.00
0005434906911	25623	Economy	6700.00
0005434906907	25623	Economy	6700.00
0005434906808	25623	Economy	6700.00
0005434906807	25623	Economy	6700.00
0005434906800	25623	Economy	6700.00
0005433251499	25623	Economy	6700.00
0005433251527	25623	Economy	6700.00
0005433251517	25623	Economy	6700.00
0005433251513	25623	Economy	6700.00
0005434906591	25623	Economy	6700.00
0005433251525	25623	Economy	6700.00
0005434907030	25623	Economy	6700.00
0005433400985	25623	Economy	6700.00
0005434906985	25623	Economy	6700.00
0005434906939	25623	Economy	6700.00
0005433251516	25623	Economy	6700.00
0005433251515	25623	Economy	6700.00
0005434906687	25623	Economy	6700.00
0005434907041	25623	Economy	6700.00
0005434906887	25623	Economy	6700.00
0005434906837	25623	Economy	6700.00
0005433251524	25623	Economy	6700.00
0005434906879	25623	Economy	6700.00
0005434906970	25623	Economy	6700.00
0005434906913	25623	Economy	6700.00
0005434906688	25623	Economy	6700.00
0005434906824	25623	Economy	6700.00
0005434906590	25623	Economy	6700.00
0005434906818	25623	Economy	6700.00
0005434906922	25623	Economy	6700.00
0005434906849	25623	Economy	6700.00
0005434906905	25623	Economy	6700.00
0005433251510	25623	Economy	6700.00
0005433251509	25623	Economy	6700.00
0005433251526	25623	Economy	6700.00
0005434906906	25623	Economy	6700.00
0005433400988	25623	Economy	6700.00
0005433251496	25623	Economy	6700.00
0005433251518	25623	Economy	6700.00
0005434906851	25623	Economy	6700.00
0005433251514	25623	Economy	6700.00
0005434907148	25623	Economy	6700.00
0005434906989	25623	Economy	6700.00
0005434906781	25623	Economy	6700.00
0005433251508	25623	Economy	6700.00
0005434907025	25623	Economy	6700.00
0005434906762	25623	Economy	6700.00
0005433251512	25623	Economy	6700.00
0005434906954	25623	Economy	6700.00
0005433251521	25623	Economy	6700.00
0005434907031	25623	Economy	6700.00
0005434906823	25623	Economy	6700.00
0005434906862	25623	Economy	6700.00
0005432862228	2508	Economy	13600.00
0005432862258	2508	Economy	12400.00
0005432862266	2508	Economy	12400.00
0005432862247	2508	Economy	12400.00
0005432862257	2508	Economy	12400.00
0005432621059	2508	Economy	12400.00
0005432621055	2508	Economy	12400.00
0005432621056	2508	Economy	12400.00
0005432621050	2508	Economy	12400.00
0005432621054	2508	Economy	12400.00
0005432621049	2508	Economy	12400.00
0005432621048	2508	Economy	12400.00
0005432621058	2508	Economy	12400.00
0005432862267	2508	Economy	12400.00
0005432621052	2508	Economy	12400.00
0005432621053	2508	Economy	12400.00
0005432621057	2508	Economy	12400.00
0005432621051	2508	Economy	12400.00
0005432621046	2508	Economy	12400.00
0005432862222	2508	Economy	12400.00
0005432862265	2508	Economy	12400.00
0005432862236	2508	Economy	12400.00
0005432621060	2508	Economy	12400.00
0005432621047	2508	Economy	12400.00
0005432621061	2508	Economy	12400.00
0005432862256	2508	Economy	12400.00
0005432862307	28087	Economy	13600.00
0005432620958	28087	Economy	13600.00
0005432620947	28087	Economy	13600.00
0005432620961	28087	Economy	12400.00
0005432620895	28087	Economy	12400.00
0005432620967	28087	Economy	12400.00
0005432620969	28087	Economy	12400.00
0005432862311	28087	Economy	12400.00
0005432862309	28087	Economy	12400.00
0005432620926	28087	Economy	12400.00
0005432862312	28087	Economy	12400.00
0005432862306	28087	Economy	12400.00
0005432862310	28087	Economy	12400.00
0005432620968	28087	Economy	12400.00
0005432620954	28087	Economy	12400.00
0005432620953	28087	Economy	12400.00
0005432620946	28087	Economy	12400.00
0005432620894	28087	Economy	12400.00
0005432862313	28087	Economy	12400.00
0005432620948	28087	Economy	12400.00
0005432620893	28087	Economy	12400.00
0005432620905	28087	Economy	12400.00
0005432620907	28087	Economy	12400.00
0005432620934	28087	Economy	12400.00
0005432620908	28087	Economy	12400.00
0005432862308	28087	Economy	12400.00
0005432620945	28087	Economy	12400.00
0005434097468	11743	Economy	11300.00
0005434097459	11743	Economy	11300.00
0005434097456	11743	Economy	11300.00
0005434097477	13015	Economy	11300.00
0005434097478	13015	Economy	11300.00
0005433451621	31085	Economy	8400.00
0005433452742	31085	Economy	8400.00
0005433452741	31085	Economy	8400.00
0005433452740	31085	Economy	8400.00
0005433454855	31423	Economy	8400.00
0005433452724	31423	Economy	8400.00
0005433452727	31423	Economy	8400.00
0005433452728	31423	Economy	8400.00
0005433454854	31423	Economy	8400.00
0005433452726	31423	Economy	8400.00
0005434142592	11993	Economy	7200.00
0005433129244	11993	Economy	7200.00
0005433134108	11993	Economy	6600.00
0005433134094	11993	Economy	6600.00
0005434142597	11993	Economy	6600.00
0005433134092	11993	Economy	6600.00
0005434142580	11993	Economy	6600.00
0005434184647	11993	Economy	6600.00
0005434142581	11993	Economy	6600.00
0005434184648	11993	Economy	6600.00
0005433134093	11993	Economy	6600.00
0005433129245	11993	Economy	6600.00
0005434142609	29868	Economy	6600.00
0005433131712	29868	Economy	6600.00
0005434142611	29868	Economy	6600.00
0005434183581	29868	Economy	6600.00
0005433134144	29868	Economy	6600.00
0005433134142	29868	Economy	6600.00
0005433134140	29868	Economy	6600.00
0005433134143	29868	Economy	6600.00
0005434184667	29868	Economy	6600.00
0005433131711	29868	Economy	6600.00
0005433131714	29868	Economy	6600.00
0005433131713	29868	Economy	6600.00
0005434142610	29868	Economy	6600.00
0005434183582	29868	Economy	6600.00
0005434142612	29868	Economy	6600.00
0005433134141	29868	Economy	6600.00
0005434183583	29868	Economy	6600.00
0005435697347	16459	Economy	19900.00
0005435697359	16459	Economy	19900.00
0005435697351	16459	Economy	19900.00
0005435697338	16459	Economy	19900.00
0005435697335	16459	Economy	18100.00
0005435697341	16459	Economy	18100.00
0005435935018	16459	Economy	18100.00
0005435697334	16459	Economy	18100.00
0005435697353	16459	Economy	18100.00
0005435697340	16459	Economy	18100.00
0005435697352	16459	Economy	18100.00
0005435697331	16459	Economy	18100.00
0005435697349	16459	Economy	18100.00
0005435697350	16459	Economy	18100.00
0005435697354	16459	Economy	18100.00
0005435697346	16459	Economy	18100.00
0005435697344	16459	Economy	18100.00
0005435697342	16459	Economy	18100.00
0005435697333	16459	Economy	18100.00
0005435697355	16459	Economy	18100.00
0005435697343	16459	Economy	18100.00
0005435697345	16459	Economy	18100.00
0005435697348	16459	Economy	18100.00
0005435697356	16459	Economy	18100.00
0005435697337	16459	Economy	18100.00
0005435697339	16459	Economy	18100.00
0005435697336	16459	Economy	18100.00
0005435697357	16459	Economy	18100.00
0005435697332	16459	Economy	18100.00
0005435697358	16459	Economy	18100.00
0005435697155	24729	Economy	19900.00
0005435696965	24729	Economy	19900.00
0005435697092	24729	Economy	18100.00
0005435935051	24729	Economy	18100.00
0005435697298	24729	Economy	18100.00
0005435697136	24729	Economy	18100.00
0005435697133	24729	Economy	18100.00
0005435697247	24729	Economy	18100.00
0005435697167	24729	Economy	18100.00
0005435697222	24729	Economy	18100.00
0005435697156	24729	Economy	18100.00
0005435935048	24729	Economy	18100.00
0005435697106	24729	Economy	18100.00
0005435697130	24729	Economy	18100.00
0005435697179	24729	Economy	18100.00
0005435697122	24729	Economy	18100.00
0005435697129	24729	Economy	18100.00
0005435697171	24729	Economy	18100.00
0005435697160	24729	Economy	18100.00
0005435697192	24729	Economy	18100.00
0005435697157	24729	Economy	18100.00
0005435697221	24729	Economy	18100.00
0005435697191	24729	Economy	18100.00
0005435697161	24729	Economy	18100.00
0005435697154	24729	Economy	18100.00
0005435697089	24729	Economy	18100.00
0005435697206	24729	Economy	18100.00
0005435697105	24729	Economy	18100.00
0005435697299	24729	Economy	18100.00
0005435697207	24729	Economy	18100.00
0005435697199	24729	Economy	18100.00
0005435935050	24729	Economy	18100.00
0005435697135	24729	Economy	18100.00
0005435697162	24729	Economy	18100.00
0005435697180	24729	Economy	18100.00
0005435697087	24729	Economy	18100.00
0005435935049	24729	Economy	18100.00
0005435697093	24729	Economy	18100.00
0005433724809	18784	Economy	4400.00
0005433724807	18784	Economy	4400.00
0005433724811	18784	Economy	4400.00
0005433724808	18784	Economy	4400.00
0005432968825	18784	Economy	4400.00
0005433724806	18784	Economy	4400.00
0005433724810	18784	Economy	4400.00
0005433724776	21644	Economy	4400.00
0005432968844	21644	Economy	4400.00
0005433724775	21644	Economy	4400.00
0005433724777	21644	Economy	4400.00
0005432968845	21644	Economy	4400.00
0005434138252	7327	Business	23100.00
0005434138300	7327	Business	23100.00
0005434138262	7327	Business	23100.00
0005434138216	7327	Business	23100.00
0005434138255	7327	Business	23100.00
0005434138298	7327	Business	23100.00
0005434138266	7327	Business	23100.00
0005434138222	7327	Business	23100.00
0005434138219	7327	Business	23100.00
0005434138263	7327	Business	23100.00
0005434087517	7327	Business	23100.00
0005434138282	7327	Business	23100.00
0005434138221	7327	Economy	7700.00
0005434138264	7327	Economy	7700.00
0005434138235	7327	Economy	7700.00
0005434138230	7327	Economy	7700.00
0005434138239	7327	Economy	7700.00
0005434138234	7327	Economy	7700.00
0005434138232	7327	Economy	7700.00
0005434138279	7327	Economy	7700.00
0005434138290	7327	Economy	7700.00
0005434087518	7327	Economy	7700.00
0005434138256	7327	Economy	8500.00
0005434138249	7327	Economy	8500.00
0005434138254	7327	Economy	8500.00
0005434138218	7327	Economy	8500.00
0005434138226	7327	Economy	8500.00
0005434138250	7327	Economy	7700.00
0005434138272	7327	Economy	7700.00
0005434138231	7327	Economy	7700.00
0005434138286	7327	Economy	7700.00
0005434138248	7327	Economy	7700.00
0005434138260	7327	Economy	7700.00
0005434138271	7327	Economy	7700.00
0005434138284	7327	Economy	7700.00
0005434138295	7327	Economy	7700.00
0005434138288	7327	Economy	7700.00
0005434138228	7327	Economy	7700.00
0005434138251	7327	Economy	7700.00
0005434138236	7327	Economy	7700.00
0005434138287	7327	Economy	7700.00
0005434138229	7327	Economy	7700.00
0005434138297	7327	Economy	7700.00
0005434138299	7327	Economy	7700.00
0005434138220	7327	Economy	7700.00
0005434138296	7327	Economy	7700.00
0005434138240	7327	Economy	7700.00
0005434138267	7327	Economy	7700.00
0005434138289	7327	Economy	7700.00
0005434138237	7327	Economy	7700.00
0005434138233	7327	Economy	7700.00
0005434138246	7327	Economy	7700.00
0005434138293	7327	Economy	7700.00
0005434138277	7327	Economy	7700.00
0005434138247	7327	Economy	7700.00
0005434138258	7327	Economy	7700.00
0005434138238	7327	Economy	7700.00
0005434138281	7327	Economy	7700.00
0005434138244	7327	Economy	7700.00
0005434138253	7327	Economy	7700.00
0005434138278	7327	Economy	7700.00
0005434138223	7327	Economy	7700.00
0005434138242	7327	Economy	7700.00
0005434087519	7327	Economy	7700.00
0005434138270	7327	Economy	7700.00
0005434138283	7327	Economy	7700.00
0005434138224	7327	Economy	7700.00
0005434138217	7327	Economy	7700.00
0005434138259	7327	Economy	7700.00
0005434138280	7327	Economy	7700.00
0005434138241	7327	Economy	7700.00
0005434138276	7327	Economy	7700.00
0005434138243	7327	Economy	7700.00
0005434138285	7327	Economy	7700.00
0005434087520	7327	Economy	7700.00
0005434087521	7327	Economy	7700.00
0005434138265	7327	Economy	7700.00
0005434138301	7327	Economy	7700.00
0005434138225	7327	Economy	7700.00
0005434138294	7327	Economy	7700.00
0005434138268	7327	Economy	7700.00
0005434138291	7327	Economy	7700.00
0005434138303	7327	Economy	7700.00
0005434138215	7327	Economy	7700.00
0005434138227	7327	Economy	7700.00
0005434138269	7327	Economy	7700.00
0005434138302	7327	Economy	7700.00
0005434138261	7327	Economy	7700.00
0005434138257	7327	Economy	7700.00
0005434138275	7327	Economy	7700.00
0005434138304	7327	Economy	7700.00
0005434138292	7327	Economy	7700.00
0005434138305	7327	Economy	7700.00
0005434138245	7327	Economy	7700.00
0005434138274	7327	Economy	7700.00
0005434138273	7327	Economy	7700.00
0005434137411	28540	Business	23100.00
0005434137441	28540	Business	23100.00
0005434137595	28540	Business	23100.00
0005434137670	28540	Business	23100.00
0005434137428	28540	Business	23100.00
0005434137698	28540	Business	23100.00
0005434136778	28540	Business	23100.00
0005434137303	28540	Business	23100.00
0005434137112	28540	Business	23100.00
0005434137299	28540	Business	23100.00
0005434137272	28540	Business	23100.00
0005434137531	28540	Economy	7700.00
0005434137396	28540	Economy	7700.00
0005434137397	28540	Economy	7700.00
0005434137309	28540	Economy	7700.00
0005434137571	28540	Economy	7700.00
0005434137235	28540	Economy	7700.00
0005434137389	28540	Economy	7700.00
0005434137514	28540	Economy	7700.00
0005434137212	28540	Economy	7700.00
0005434137533	28540	Economy	8500.00
0005434137594	28540	Economy	8500.00
0005434137271	28540	Economy	8500.00
0005434137757	28540	Economy	7700.00
0005434137234	28540	Economy	7700.00
0005434137494	28540	Economy	7700.00
0005434137361	28540	Economy	7700.00
0005434137213	28540	Economy	7700.00
0005434137188	28540	Economy	7700.00
0005434137214	28540	Economy	7700.00
0005434136950	28540	Economy	7700.00
0005434137476	28540	Economy	7700.00
0005434137558	28540	Economy	7700.00
0005434137367	28540	Economy	7700.00
0005434137854	28540	Economy	7700.00
0005434136872	28540	Economy	7700.00
0005434137853	28540	Economy	7700.00
0005434137134	28540	Economy	7700.00
0005434137784	28540	Economy	7700.00
0005434137135	28540	Economy	7700.00
0005434137532	28540	Economy	7700.00
0005434137493	28540	Economy	7700.00
0005434137544	28540	Economy	7700.00
0005434137311	28540	Economy	7700.00
0005434137860	28540	Economy	7700.00
0005434137572	28540	Economy	7700.00
0005434136890	28540	Economy	7700.00
0005434087480	28540	Economy	7700.00
0005434136973	28540	Economy	7700.00
0005434137741	28540	Economy	7700.00
0005434137431	28540	Economy	7700.00
0005434137451	28540	Economy	7700.00
0005434137450	28540	Economy	7700.00
0005434137421	28540	Economy	7700.00
0005434137569	28540	Economy	7700.00
0005434137605	28540	Economy	7700.00
0005434137655	28540	Economy	7700.00
0005434137344	28540	Economy	7700.00
0005434087479	28540	Economy	7700.00
0005434137648	28540	Economy	7700.00
0005434137791	28540	Economy	7700.00
0005434137237	28540	Economy	7700.00
0005434137852	28540	Economy	7700.00
0005434137656	28540	Economy	7700.00
0005434137603	28540	Economy	7700.00
0005434137432	28540	Economy	7700.00
0005434137298	28540	Economy	7700.00
0005434137357	28540	Economy	7700.00
0005434137534	28540	Economy	7700.00
0005434087500	28540	Economy	7700.00
0005434137613	28540	Economy	7700.00
0005434137561	28540	Economy	7700.00
0005434137430	28540	Economy	7700.00
0005434137380	28540	Economy	7700.00
0005434137123	28540	Economy	7700.00
0005434137440	28540	Economy	7700.00
0005434137420	28540	Economy	7700.00
0005434137427	28540	Economy	7700.00
0005434137184	28540	Economy	7700.00
0005434137657	28540	Economy	7700.00
0005434137156	28540	Economy	7700.00
0005434137474	28540	Economy	7700.00
0005434137489	28540	Economy	7700.00
0005434137302	28540	Economy	7700.00
0005433407526	1949	Economy	23900.00
0005434610233	1949	Economy	21700.00
0005435808244	1949	Economy	21700.00
0005433407527	1949	Economy	21700.00
0005434610235	1949	Economy	21700.00
0005433407528	1949	Economy	21700.00
0005434610232	1949	Economy	21700.00
0005435808250	1949	Economy	21700.00
0005435808251	1949	Economy	21700.00
0005433407501	1949	Economy	21700.00
0005435808247	1949	Economy	21700.00
0005434610231	1949	Economy	21700.00
0005435808248	1949	Economy	21700.00
0005435808245	1949	Economy	21700.00
0005435808241	1949	Economy	21700.00
0005434610234	1949	Economy	21700.00
0005435808246	1949	Economy	21700.00
0005435808242	1949	Economy	21700.00
0005435808243	1949	Economy	21700.00
0005433407529	1949	Economy	21700.00
0005435808249	1949	Economy	21700.00
0005433407507	1949	Economy	21700.00
0005433407525	1949	Economy	21700.00
0005434610190	23085	Economy	21700.00
0005434610210	23085	Economy	21700.00
0005434610196	23085	Economy	21700.00
0005434503831	16714	Economy	7600.00
0005434503832	16714	Economy	7600.00
0005434503814	16714	Economy	7600.00
0005434503952	16714	Economy	7600.00
0005434503863	16714	Economy	6900.00
0005434503890	16714	Economy	6900.00
0005434503813	16714	Economy	6900.00
0005434503866	16714	Economy	6900.00
0005434503954	16714	Economy	6900.00
0005434503908	16714	Economy	6900.00
0005434503887	16714	Economy	6900.00
0005434503843	16714	Economy	6900.00
0005434503597	16714	Economy	6900.00
0005434503802	16714	Economy	6900.00
0005434503936	16714	Economy	6900.00
0005434503938	16714	Economy	6900.00
0005434503950	16714	Economy	6900.00
0005434503907	16714	Economy	6900.00
0005434503676	16714	Economy	6900.00
0005434503953	16714	Economy	6900.00
0005434503842	16714	Economy	6900.00
0005434503561	16714	Economy	6900.00
0005434503739	16714	Economy	6900.00
0005434503893	16714	Economy	6900.00
0005434503912	16714	Economy	6900.00
0005434503865	16714	Economy	6900.00
0005434503888	16714	Economy	6900.00
0005434503838	16714	Economy	6900.00
0005434503939	16714	Economy	6900.00
0005434503909	16714	Economy	6900.00
0005434503951	16714	Economy	6900.00
0005434503830	16714	Economy	6900.00
0005434503720	16714	Economy	6900.00
0005434503820	16714	Economy	6900.00
0005434503848	16714	Economy	6900.00
0005434503698	16714	Economy	6900.00
0005434503913	16714	Economy	6900.00
0005434503849	16714	Economy	6900.00
0005434503862	16714	Economy	6900.00
0005434503949	16714	Economy	6900.00
0005434503740	16714	Economy	6900.00
0005434503856	16714	Economy	6900.00
0005434503857	16714	Economy	6900.00
0005434503891	16714	Economy	6900.00
0005434503560	16714	Economy	6900.00
0005434504151	22877	Economy	7600.00
0005434504167	22877	Economy	7600.00
0005434504169	22877	Economy	7600.00
0005434504159	22877	Economy	7600.00
0005434504170	22877	Economy	6900.00
0005434504173	22877	Economy	6900.00
0005434504154	22877	Economy	6900.00
0005434504182	22877	Economy	6900.00
0005434504172	22877	Economy	6900.00
0005434504149	22877	Economy	6900.00
0005434504155	22877	Economy	6900.00
0005434504144	22877	Economy	6900.00
0005434504175	22877	Economy	6900.00
0005434504158	22877	Economy	6900.00
0005434504164	22877	Economy	6900.00
0005434504153	22877	Economy	6900.00
0005434504174	22877	Economy	6900.00
0005434504183	22877	Economy	6900.00
0005434504156	22877	Economy	6900.00
0005434504166	22877	Economy	6900.00
0005434504147	22877	Economy	6900.00
0005434504148	22877	Economy	6900.00
0005434504180	22877	Economy	6900.00
0005434504179	22877	Economy	6900.00
0005434504157	22877	Economy	6900.00
0005434504171	22877	Economy	6900.00
0005434504160	22877	Economy	6900.00
0005434504181	22877	Economy	6900.00
0005434504168	22877	Economy	6900.00
0005434504150	22877	Economy	6900.00
0005434504176	22877	Economy	6900.00
0005434504184	22877	Economy	6900.00
0005434504152	22877	Economy	6900.00
0005434504178	22877	Economy	6900.00
0005434504161	22877	Economy	6900.00
0005434504165	22877	Economy	6900.00
0005434504177	22877	Economy	6900.00
0005434504146	22877	Economy	6900.00
0005434504162	22877	Economy	6900.00
0005434504163	22877	Economy	6900.00
0005434504145	22877	Economy	6900.00
0005433266678	2220	Economy	7700.00
0005435078350	2220	Economy	7700.00
0005435078361	2220	Economy	7000.00
0005435078354	2220	Economy	7000.00
0005433266645	2220	Economy	7000.00
0005433266696	2220	Economy	7000.00
0005435078352	2220	Economy	7000.00
0005435078362	2220	Economy	7000.00
0005435078351	2220	Economy	7000.00
0005435078358	2220	Economy	7000.00
0005435078364	2220	Economy	7000.00
0005435078356	2220	Economy	7000.00
0005435078357	2220	Economy	7000.00
0005433266628	2220	Economy	7000.00
0005435078365	2220	Economy	7000.00
0005433266654	2220	Economy	7000.00
0005433266650	2220	Economy	7000.00
0005433266629	2220	Economy	7000.00
0005435078353	2220	Economy	7000.00
0005435078360	2220	Economy	7000.00
0005435078363	2220	Economy	7000.00
0005433266619	2220	Economy	7000.00
0005435078359	2220	Economy	7000.00
0005435078355	2220	Economy	7000.00
0005433266695	2220	Economy	7000.00
0005433266736	24337	Economy	7700.00
0005435078221	24337	Economy	7000.00
0005433266733	24337	Economy	7000.00
0005435078225	24337	Economy	7000.00
0005435078224	24337	Economy	7000.00
0005433266735	24337	Economy	7000.00
0005433266729	24337	Economy	7000.00
0005435078215	24337	Economy	7000.00
0005433266738	24337	Economy	7000.00
0005433266731	24337	Economy	7000.00
0005435078214	24337	Economy	7000.00
0005433266730	24337	Economy	7000.00
0005435078297	24337	Economy	7000.00
0005435078247	24337	Economy	7000.00
0005435078190	24337	Economy	7000.00
0005435078226	24337	Economy	7000.00
0005435078192	24337	Economy	7000.00
0005435078246	24337	Economy	7000.00
0005435078298	24337	Economy	7000.00
0005435078222	24337	Economy	7000.00
0005433266737	24337	Economy	7000.00
0005433266734	24337	Economy	7000.00
0005433266732	24337	Economy	7000.00
0005435078259	24337	Economy	7000.00
0005435078191	24337	Economy	7000.00
0005434988760	6619	Economy	9800.00
0005434988753	6619	Economy	9800.00
0005434988757	6619	Economy	9800.00
0005434988754	6619	Economy	9800.00
0005435803268	6619	Economy	9800.00
0005434988762	6619	Economy	9800.00
0005434988758	6619	Economy	9800.00
0005434988761	6619	Economy	9800.00
0005434988756	6619	Economy	9800.00
0005435803267	6619	Economy	9800.00
0005434988759	6619	Economy	9800.00
0005434988755	6619	Economy	9800.00
0005434988752	6619	Economy	9800.00
0005434988618	23601	Economy	10800.00
0005434988617	23601	Economy	10800.00
0005434988615	23601	Economy	9800.00
0005435803241	23601	Economy	9800.00
0005435803240	23601	Economy	9800.00
0005435464509	23601	Economy	9800.00
0005435803242	23601	Economy	9800.00
0005434988616	23601	Economy	9800.00
0005432383225	30494	Business	9900.00
0005433449999	30494	Business	9900.00
0005433449989	30494	Business	9900.00
0005432383232	30494	Business	9900.00
0005432383222	30494	Business	9900.00
0005433453764	30494	Business	9900.00
0005432383215	30494	Business	9900.00
0005432383221	30494	Business	9900.00
0005432383203	30494	Business	9900.00
0005433450001	30494	Business	9900.00
0005432383235	30494	Economy	3300.00
0005432383220	30494	Economy	3300.00
0005432383207	30494	Economy	3300.00
0005433450002	30494	Economy	3300.00
0005432383218	30494	Economy	3300.00
0005433449985	30494	Economy	3600.00
0005433450000	30494	Economy	3600.00
0005432383217	30494	Economy	3600.00
0005433450006	30494	Economy	3300.00
0005433449988	30494	Economy	3300.00
0005432383234	30494	Economy	3300.00
0005433449986	30494	Economy	3300.00
0005433449987	30494	Economy	3300.00
0005432383204	30494	Economy	3300.00
0005432383223	30494	Economy	3300.00
0005433454878	30494	Economy	3300.00
0005432383229	30494	Economy	3300.00
0005432383208	30494	Economy	3300.00
0005432383202	30494	Economy	3300.00
0005433449993	30494	Economy	3300.00
0005433449991	30494	Economy	3300.00
0005433449990	30494	Economy	3300.00
0005433450004	30494	Economy	3300.00
0005433450005	30494	Economy	3300.00
0005432383226	30494	Economy	3300.00
0005432383219	30494	Economy	3300.00
0005433449992	30494	Economy	3300.00
0005432383236	30494	Economy	3300.00
0005432383205	30494	Economy	3300.00
0005432383216	30494	Economy	3300.00
0005433449994	30494	Economy	3300.00
0005433454877	30494	Economy	3300.00
0005432383237	30494	Economy	3300.00
0005432383228	30494	Economy	3300.00
0005432383212	30494	Economy	3300.00
0005433450007	30494	Economy	3300.00
0005432383214	30494	Economy	3300.00
0005432383213	30494	Economy	3300.00
0005433449995	30494	Economy	3300.00
0005433449998	30494	Economy	3300.00
0005432383231	30494	Economy	3300.00
0005432383227	30494	Economy	3300.00
0005433449996	30494	Economy	3300.00
0005432383209	30494	Economy	3300.00
0005432383211	30494	Economy	3300.00
0005433449997	30494	Economy	3300.00
0005432383206	30494	Economy	3300.00
0005432383233	30494	Economy	3300.00
0005433450003	30494	Economy	3300.00
0005432383210	30494	Economy	3300.00
0005432383230	30494	Economy	3300.00
0005432383224	30494	Economy	3300.00
0005432382771	31323	Business	9900.00
0005432382768	31323	Business	9900.00
0005433449861	31323	Business	9900.00
0005433449785	31323	Business	9900.00
0005433449916	31323	Business	9900.00
0005432382634	31323	Business	9900.00
0005433449801	31323	Business	9900.00
0005433449843	31323	Business	9900.00
0005432382915	31323	Business	9900.00
0005433449821	31323	Economy	3300.00
0005433449834	31323	Economy	3300.00
0005433449829	31323	Economy	3300.00
0005433449643	31323	Economy	3300.00
0005432382772	31323	Economy	3300.00
0005432382817	31323	Economy	3300.00
0005432382968	31323	Economy	3300.00
0005432382791	31323	Economy	3300.00
0005433451610	31323	Economy	3600.00
0005433449857	31323	Economy	3600.00
0005433449773	31323	Economy	3600.00
0005432382744	31323	Economy	3600.00
0005433449833	31323	Economy	3300.00
0005433449884	31323	Economy	3300.00
0005432382804	31323	Economy	3300.00
0005432382820	31323	Economy	3300.00
0005433449781	31323	Economy	3300.00
0005433449868	31323	Economy	3300.00
0005433449932	31323	Economy	3300.00
0005433449789	31323	Economy	3300.00
0005432382967	31323	Economy	3300.00
0005433451588	31323	Economy	3300.00
0005432382620	31323	Economy	3300.00
0005433449890	31323	Economy	3300.00
0005432382762	31323	Economy	3300.00
0005433449760	31323	Economy	3300.00
0005432382770	31323	Economy	3300.00
0005432382829	31323	Economy	3300.00
0005432382957	31323	Economy	3300.00
0005432382816	31323	Economy	3300.00
0005433449822	31323	Economy	3300.00
0005432382824	31323	Economy	3300.00
0005433449897	31323	Economy	3300.00
0005432382958	31323	Economy	3300.00
0005433449739	31323	Economy	3300.00
0005433449856	31323	Economy	3300.00
0005433449791	31323	Economy	3300.00
0005432382813	31323	Economy	3300.00
0005433449786	31323	Economy	3300.00
0005432382846	31323	Economy	3300.00
0005433449812	31323	Economy	3300.00
0005433449917	31323	Economy	3300.00
0005432382832	31323	Economy	3300.00
0005432382745	31323	Economy	3300.00
0005433449757	31323	Economy	3300.00
0005432382828	31323	Economy	3300.00
0005432382882	31323	Economy	3300.00
0005432382669	31323	Economy	3300.00
0005433449790	31323	Economy	3300.00
0005432382825	31323	Economy	3300.00
0005433449774	31323	Economy	3300.00
0005432382883	31323	Economy	3300.00
0005432382983	31323	Economy	3300.00
0005433449772	31323	Economy	3300.00
0005432382845	31323	Economy	3300.00
0005432382914	31323	Economy	3300.00
0005432382699	31323	Economy	3300.00
0005432382761	31323	Economy	3300.00
0005433449792	31323	Economy	3300.00
0005432382773	31323	Economy	3300.00
0005432382814	31323	Economy	3300.00
0005433453754	31323	Economy	3300.00
0005433453753	31323	Economy	3300.00
0005432382763	31323	Economy	3300.00
0005432382956	31323	Economy	3300.00
0005432382830	31323	Economy	3300.00
0005433449782	31323	Economy	3300.00
0005433449759	31323	Economy	3300.00
0005433449741	31323	Economy	3300.00
0005432382743	31323	Economy	3300.00
0005433449839	31323	Economy	3300.00
0005432382769	31323	Economy	3300.00
0005433449828	31323	Economy	3300.00
0005432382884	31323	Economy	3300.00
0005433788184	26475	Economy	26200.00
0005433788170	26475	Economy	26200.00
0005433788173	26475	Economy	23800.00
0005435548501	26475	Economy	23800.00
0005435548498	26475	Economy	23800.00
0005435548503	26475	Economy	23800.00
0005435548497	26475	Economy	23800.00
0005435548502	26475	Economy	23800.00
0005433788155	26475	Economy	23800.00
0005435548499	26475	Economy	23800.00
0005433788183	26475	Economy	23800.00
0005435548496	26475	Economy	23800.00
0005433788171	26475	Economy	23800.00
0005435548504	26475	Economy	23800.00
0005433788156	26475	Economy	23800.00
0005435548500	26475	Economy	23800.00
0005435299718	10776	Economy	17100.00
0005433131660	10776	Economy	17100.00
0005433126795	10776	Economy	17100.00
0005435304138	10776	Economy	15600.00
0005433131668	10776	Economy	15600.00
0005433126782	10776	Economy	15600.00
0005433131672	10776	Economy	15600.00
0005433131661	10776	Economy	15600.00
0005433126819	10776	Economy	15600.00
0005433131669	10776	Economy	15600.00
0005433131676	10776	Economy	15600.00
0005433126796	10776	Economy	15600.00
0005433131662	10776	Economy	15600.00
0005435299719	10776	Economy	15600.00
0005433131673	10776	Economy	15600.00
0005435304137	10776	Economy	15600.00
0005433131671	10776	Economy	15600.00
0005433126799	10776	Economy	15600.00
0005433131675	10776	Economy	15600.00
0005435299741	10776	Economy	15600.00
0005433126784	10776	Economy	15600.00
0005433126804	10776	Economy	15600.00
0005433131666	10776	Economy	15600.00
0005435304133	10776	Economy	15600.00
0005433126783	10776	Economy	15600.00
0005435299740	10776	Economy	15600.00
0005435299725	10776	Economy	15600.00
0005433126798	10776	Economy	15600.00
0005435299742	10776	Economy	15600.00
0005433126818	10776	Economy	15600.00
0005433131674	10776	Economy	15600.00
0005433126797	10776	Economy	15600.00
0005433126853	29739	Economy	17100.00
0005435299784	29739	Economy	17100.00
0005433126855	29739	Economy	17100.00
0005435299786	29739	Economy	15600.00
0005435299783	29739	Economy	15600.00
0005433126852	29739	Economy	15600.00
0005435299785	29739	Economy	15600.00
0005435302207	29739	Economy	15600.00
0005435302206	29739	Economy	15600.00
0005435302209	29739	Economy	15600.00
0005435302208	29739	Economy	15600.00
0005433126854	29739	Economy	15600.00
0005433129285	29739	Economy	15600.00
0005433129283	29739	Economy	15600.00
0005435299787	29739	Economy	15600.00
0005435302205	29739	Economy	15600.00
0005433129282	29739	Economy	15600.00
0005433129286	29739	Economy	15600.00
0005433129284	29739	Economy	15600.00
0005434287318	2413	Economy	17200.00
0005434287321	2413	Economy	17200.00
0005434287322	2413	Economy	17200.00
0005434287309	2413	Economy	15700.00
0005434287307	2413	Economy	15700.00
0005433109959	2413	Economy	15700.00
0005434287312	2413	Economy	15700.00
0005433109994	2413	Economy	15700.00
0005433109985	2413	Economy	15700.00
0005434287317	2413	Economy	15700.00
0005433109974	2413	Economy	15700.00
0005434287316	2413	Economy	15700.00
0005433109976	2413	Economy	15700.00
0005434287310	2413	Economy	15700.00
0005433110010	2413	Economy	15700.00
0005433109977	2413	Economy	15700.00
0005434287315	2413	Economy	15700.00
0005434287313	2413	Economy	15700.00
0005432264477	2413	Economy	15700.00
0005434287304	2413	Economy	15700.00
0005433109975	2413	Economy	15700.00
0005434287303	2413	Economy	15700.00
0005432264478	2413	Economy	15700.00
0005434287308	2413	Economy	15700.00
0005434287311	2413	Economy	15700.00
0005433109968	2413	Economy	15700.00
0005434287319	2413	Economy	15700.00
0005434287306	2413	Economy	15700.00
0005433109991	2413	Economy	15700.00
0005434287320	2413	Economy	15700.00
0005434287323	2413	Economy	15700.00
0005433109992	2413	Economy	15700.00
0005434287324	2413	Economy	15700.00
0005434287314	2413	Economy	15700.00
0005434287305	2413	Economy	15700.00
0005434287032	26821	Economy	17200.00
0005434287058	26821	Economy	17200.00
0005434287160	26821	Economy	17200.00
0005433110061	26821	Economy	17200.00
0005434287143	26821	Economy	15700.00
0005433110063	26821	Economy	15700.00
0005434287142	26821	Economy	15700.00
0005434287161	26821	Economy	15700.00
0005434287094	26821	Economy	15700.00
0005434287192	26821	Economy	15700.00
0005434287186	26821	Economy	15700.00
0005434287151	26821	Economy	15700.00
0005434287149	26821	Economy	15700.00
0005434287096	26821	Economy	15700.00
0005434287157	26821	Economy	15700.00
0005433110067	26821	Economy	15700.00
0005433110068	26821	Economy	15700.00
0005434287023	26821	Economy	15700.00
0005434287144	26821	Economy	15700.00
0005434287059	26821	Economy	15700.00
0005434287057	26821	Economy	15700.00
0005434287182	26821	Economy	15700.00
0005433110071	26821	Economy	15700.00
0005434287224	26821	Economy	15700.00
0005434287079	26821	Economy	15700.00
0005434287100	26821	Economy	15700.00
0005433110064	26821	Economy	15700.00
0005434287185	26821	Economy	15700.00
0005434287097	26821	Economy	15700.00
0005434287046	26821	Economy	15700.00
0005434286969	26821	Economy	15700.00
0005434287148	26821	Economy	15700.00
0005433110066	26821	Economy	15700.00
0005433110070	26821	Economy	15700.00
0005433110069	26821	Economy	15700.00
0005434287181	26821	Economy	15700.00
0005433110065	26821	Economy	15700.00
0005434287180	26821	Economy	15700.00
0005434287156	26821	Economy	15700.00
0005434286970	26821	Economy	15700.00
0005434287102	26821	Economy	15700.00
0005434286968	26821	Economy	15700.00
0005434287179	26821	Economy	15700.00
0005433110072	26821	Economy	15700.00
0005433110062	26821	Economy	15700.00
0005434287031	26821	Economy	15700.00
0005435856210	25448	Economy	22800.00
0005434269090	25448	Economy	22800.00
0005434269091	25448	Economy	22800.00
0005435856209	25448	Economy	22800.00
0005435856212	25448	Economy	22800.00
0005434269086	25448	Economy	22800.00
0005435856208	25448	Economy	22800.00
0005434272181	25448	Economy	22800.00
0005435856211	25448	Economy	22800.00
0005435856182	26657	Economy	22800.00
0005435856161	26657	Economy	22800.00
0005435856162	26657	Economy	22800.00
0005434273078	26657	Economy	22800.00
0005434273079	26657	Economy	22800.00
0005434272193	26657	Economy	22800.00
0005434272194	26657	Economy	22800.00
0005434520183	19075	Economy	24600.00
0005434520216	19075	Economy	24600.00
0005434520160	19075	Economy	24600.00
0005434520155	19075	Economy	24600.00
0005434520191	19075	Economy	22300.00
0005435314836	19075	Economy	22300.00
0005435314837	19075	Economy	22300.00
0005434520166	19075	Economy	22300.00
0005434520227	19075	Economy	22300.00
0005434520209	19075	Economy	22300.00
0005434520173	19075	Economy	22300.00
0005434520129	19075	Economy	22300.00
0005434520204	19075	Economy	22300.00
0005434520199	19075	Economy	22300.00
0005434520179	19075	Economy	22300.00
0005435314832	19075	Economy	22300.00
0005434520172	19075	Economy	22300.00
0005434520168	19075	Economy	22300.00
0005435314840	19075	Economy	22300.00
0005434520161	19075	Economy	22300.00
0005435314842	19075	Economy	22300.00
0005434520241	19075	Economy	22300.00
0005434520181	19075	Economy	22300.00
0005435314831	19075	Economy	22300.00
0005435314829	19075	Economy	22300.00
0005434520162	19075	Economy	22300.00
0005434520190	19075	Economy	22300.00
0005434520192	19075	Economy	22300.00
0005434520128	19075	Economy	22300.00
0005434520187	19075	Economy	22300.00
0005434520182	19075	Economy	22300.00
0005435314835	19075	Economy	22300.00
0005434520167	19075	Economy	22300.00
0005435314834	19075	Economy	22300.00
0005435314830	19075	Economy	22300.00
0005435314838	19075	Economy	22300.00
0005434520240	19075	Economy	22300.00
0005434520188	19075	Economy	22300.00
0005434520178	19075	Economy	22300.00
0005435314843	19075	Economy	22300.00
0005434520170	19075	Economy	22300.00
0005434520203	19075	Economy	22300.00
0005435314841	19075	Economy	22300.00
0005434520210	19075	Economy	22300.00
0005434520174	19075	Economy	22300.00
0005434520169	19075	Economy	22300.00
0005434520208	19075	Economy	22300.00
0005434520215	19075	Economy	22300.00
0005435314833	19075	Economy	22300.00
0005435314839	19075	Economy	22300.00
0005433874355	7778	Economy	19200.00
0005433874357	7778	Economy	17400.00
0005433874350	7778	Economy	17400.00
0005433874352	7778	Economy	17400.00
0005433874346	7778	Economy	17400.00
0005433874344	7778	Economy	17400.00
0005433874345	7778	Economy	17400.00
0005433874358	7778	Economy	17400.00
0005433874348	7778	Economy	17400.00
0005433874347	7778	Economy	17400.00
0005433874353	7778	Economy	17400.00
0005433874356	7778	Economy	17400.00
0005433874354	7778	Economy	17400.00
0005433874351	7778	Economy	17400.00
0005433874349	7778	Economy	17400.00
0005433874304	32629	Economy	19200.00
0005433874308	32629	Economy	17400.00
0005433874314	32629	Economy	17400.00
0005433874324	32629	Economy	17400.00
0005433874331	32629	Economy	17400.00
0005433874310	32629	Economy	17400.00
0005433874328	32629	Economy	17400.00
0005433874323	32629	Economy	17400.00
0005433874342	32629	Economy	17400.00
0005433874294	32629	Economy	17400.00
0005433874320	32629	Economy	17400.00
0005433874305	32629	Economy	17400.00
0005433874340	32629	Economy	17400.00
0005433874312	32629	Economy	17400.00
0005433874311	32629	Economy	17400.00
0005433874309	32629	Economy	17400.00
0005433874332	32629	Economy	17400.00
0005433874313	32629	Economy	17400.00
0005433874333	32629	Economy	17400.00
0005433874329	32629	Economy	17400.00
0005433874325	32629	Economy	17400.00
0005433874322	32629	Economy	17400.00
0005433874334	32629	Economy	17400.00
0005435860463	4787	Economy	19400.00
0005433868473	4787	Economy	19400.00
0005433868507	4787	Economy	17600.00
0005433868505	4787	Economy	17600.00
0005435860459	4787	Economy	17600.00
0005433868476	4787	Economy	17600.00
0005435860467	4787	Economy	17600.00
0005433868488	4787	Economy	17600.00
0005433868491	4787	Economy	17600.00
0005433868485	4787	Economy	17600.00
0005433868498	4787	Economy	17600.00
0005433868484	4787	Economy	17600.00
0005433868489	4787	Economy	17600.00
0005433868499	4787	Economy	17600.00
0005433868506	4787	Economy	17600.00
0005433868511	4787	Economy	17600.00
0005433868490	4787	Economy	17600.00
0005433868503	4787	Economy	17600.00
0005433868504	4787	Economy	17600.00
0005433868509	4787	Economy	17600.00
0005433868479	4787	Economy	17600.00
0005433868480	4787	Economy	17600.00
0005433868482	4787	Economy	17600.00
0005433868502	4787	Economy	17600.00
0005433868496	4787	Economy	17600.00
0005435860464	4787	Economy	17600.00
0005433868492	4787	Economy	17600.00
0005433868475	4787	Economy	17600.00
0005433868481	4787	Economy	17600.00
0005433868486	4787	Economy	17600.00
0005433868483	4787	Economy	17600.00
0005433868487	4787	Economy	17600.00
0005433868477	4787	Economy	17600.00
0005433868478	4787	Economy	17600.00
0005433868512	4787	Economy	17600.00
0005433868510	4787	Economy	17600.00
0005433868494	4787	Economy	17600.00
0005433868508	4787	Economy	17600.00
0005433868474	4787	Economy	17600.00
0005433868500	4787	Economy	17600.00
0005433868493	4787	Economy	17600.00
0005433868495	4787	Economy	17600.00
0005435860465	4787	Economy	17600.00
0005433868501	4787	Economy	17600.00
0005433868497	4787	Economy	17600.00
0005433868080	32575	Economy	19400.00
0005433868010	32575	Economy	19400.00
0005433867914	32575	Economy	19400.00
0005433868075	32575	Economy	19400.00
0005433868133	32575	Economy	17600.00
0005433868115	32575	Economy	17600.00
0005433868044	32575	Economy	17600.00
0005433868121	32575	Economy	17600.00
0005433868043	32575	Economy	17600.00
0005433868345	32575	Economy	17600.00
0005433868156	32575	Economy	17600.00
0005433868009	32575	Economy	17600.00
0005433868169	32575	Economy	17600.00
0005433868074	32575	Economy	17600.00
0005433868073	32575	Economy	17600.00
0005433868088	32575	Economy	17600.00
0005433868038	32575	Economy	17600.00
0005433868048	32575	Economy	17600.00
0005433868170	32575	Economy	17600.00
0005433868047	32575	Economy	17600.00
0005433868202	32575	Economy	17600.00
0005433868019	32575	Economy	17600.00
0005433868132	32575	Economy	17600.00
0005433868129	32575	Economy	17600.00
0005433868147	32575	Economy	17600.00
0005433868196	32575	Economy	17600.00
0005433868090	32575	Economy	17600.00
0005433868146	32575	Economy	17600.00
0005433867915	32575	Economy	17600.00
0005433868292	32575	Economy	17600.00
0005433867944	32575	Economy	17600.00
0005433868344	32575	Economy	17600.00
0005433868008	32575	Economy	17600.00
0005433867998	32575	Economy	17600.00
0005433868148	32575	Economy	17600.00
0005433868248	32575	Economy	17600.00
0005433868061	32575	Economy	17600.00
0005433867889	32575	Economy	17600.00
0005433868089	32575	Economy	17600.00
0005433868247	32575	Economy	17600.00
0005433868205	32575	Economy	17600.00
0005433868070	32575	Economy	17600.00
0005433868195	32575	Economy	17600.00
0005433868155	32575	Economy	17600.00
0005433868245	32575	Economy	17600.00
0005433868101	32575	Economy	17600.00
0005433868079	32575	Economy	17600.00
0005433867943	32575	Economy	17600.00
0005433868263	32575	Economy	17600.00
0005433868246	32575	Economy	17600.00
0005434663418	3449	Economy	24800.00
0005434663419	3449	Economy	24800.00
0005435911401	3449	Economy	22600.00
0005435911382	3449	Economy	22600.00
0005434460508	3449	Economy	22600.00
0005434663425	3449	Economy	22600.00
0005434663427	3449	Economy	22600.00
0005434663422	3449	Economy	22600.00
0005435911347	3449	Economy	22600.00
0005434663429	3449	Economy	22600.00
0005435911399	3449	Economy	22600.00
0005434461650	3449	Economy	22600.00
0005435911377	3449	Economy	22600.00
0005434461649	3449	Economy	22600.00
0005435911391	3449	Economy	22600.00
0005434461648	3449	Economy	22600.00
0005434663420	3449	Economy	22600.00
0005434663428	3449	Economy	22600.00
0005434663424	3449	Economy	22600.00
0005434663417	3449	Economy	22600.00
0005434663423	3449	Economy	22600.00
0005434663421	3449	Economy	22600.00
0005434663426	3449	Economy	22600.00
0005434663287	12490	Economy	24800.00
0005434462772	12490	Economy	24800.00
0005434663314	12490	Economy	24800.00
0005434460486	12490	Economy	24800.00
0005435911463	12490	Economy	22600.00
0005434462763	12490	Economy	22600.00
0005434460469	12490	Economy	22600.00
0005434663301	12490	Economy	22600.00
0005434663285	12490	Economy	22600.00
0005434462766	12490	Economy	22600.00
0005434663318	12490	Economy	22600.00
0005434460485	12490	Economy	22600.00
0005435911459	12490	Economy	22600.00
0005434663291	12490	Economy	22600.00
0005434663317	12490	Economy	22600.00
0005434663347	12490	Economy	22600.00
0005434460470	12490	Economy	22600.00
0005435911458	12490	Economy	22600.00
0005434663250	12490	Economy	22600.00
0005434663356	12490	Economy	22600.00
0005434663358	12490	Economy	22600.00
0005435911462	12490	Economy	22600.00
0005434462775	12490	Economy	22600.00
0005435911457	12490	Economy	22600.00
0005435911456	12490	Economy	22600.00
0005434462767	12490	Economy	22600.00
0005434460472	12490	Economy	22600.00
0005434462762	12490	Economy	22600.00
0005435911460	12490	Economy	22600.00
0005434663348	12490	Economy	22600.00
0005434462770	12490	Economy	22600.00
0005434460477	12490	Economy	22600.00
0005434663290	12490	Economy	22600.00
0005434663327	12490	Economy	22600.00
0005434663286	12490	Economy	22600.00
0005435911461	12490	Economy	22600.00
0005434462769	12490	Economy	22600.00
0005434663328	12490	Economy	22600.00
0005434462771	12490	Economy	22600.00
0005433868129	14482	Economy	18500.00
0005433868101	14482	Economy	18500.00
0005433868008	14482	Economy	18500.00
0005433867944	14482	Economy	18500.00
0005433868147	14482	Economy	16800.00
0005433868061	14482	Economy	16800.00
0005433868248	14482	Economy	16800.00
0005433868155	14482	Economy	16800.00
0005433868263	14482	Economy	16800.00
0005433868070	14482	Economy	16800.00
0005433868075	14482	Economy	16800.00
0005433868079	14482	Economy	16800.00
0005433868047	14482	Economy	16800.00
0005433868245	14482	Economy	16800.00
0005433867915	14482	Economy	16800.00
0005433868148	14482	Economy	16800.00
0005433867889	14482	Economy	16800.00
0005433868169	14482	Economy	16800.00
0005433868090	14482	Economy	16800.00
0005433868146	14482	Economy	16800.00
0005433868121	14482	Economy	16800.00
0005433868019	14482	Economy	16800.00
0005433867998	14482	Economy	16800.00
0005433868202	14482	Economy	16800.00
0005433868247	14482	Economy	16800.00
0005433868088	14482	Economy	16800.00
0005433868344	14482	Economy	16800.00
0005433868170	14482	Economy	16800.00
0005433868048	14482	Economy	16800.00
0005433868133	14482	Economy	16800.00
0005433868009	14482	Economy	16800.00
0005433867914	14482	Economy	16800.00
0005433868074	14482	Economy	16800.00
0005433868292	14482	Economy	16800.00
0005433868196	14482	Economy	16800.00
0005433868010	14482	Economy	16800.00
0005433868044	14482	Economy	16800.00
0005433868043	14482	Economy	16800.00
0005433868156	14482	Economy	16800.00
0005433868089	14482	Economy	16800.00
0005433868345	14482	Economy	16800.00
0005433868132	14482	Economy	16800.00
0005433868205	14482	Economy	16800.00
0005433868073	14482	Economy	16800.00
0005433868115	14482	Economy	16800.00
0005433868246	14482	Economy	16800.00
0005433868195	14482	Economy	16800.00
0005433868080	14482	Economy	16800.00
0005433867943	14482	Economy	16800.00
0005433868038	14482	Economy	16800.00
0005433868441	32687	Economy	18500.00
0005433868470	32687	Economy	18500.00
0005433868458	32687	Economy	18500.00
0005433868457	32687	Economy	16800.00
0005435860450	32687	Economy	16800.00
0005433868452	32687	Economy	16800.00
0005433868462	32687	Economy	16800.00
0005433868435	32687	Economy	16800.00
0005435860452	32687	Economy	16800.00
0005433868465	32687	Economy	16800.00
0005433868469	32687	Economy	16800.00
0005433868471	32687	Economy	16800.00
0005433868440	32687	Economy	16800.00
0005433868463	32687	Economy	16800.00
0005433868433	32687	Economy	16800.00
0005433868451	32687	Economy	16800.00
0005433868467	32687	Economy	16800.00
0005433868437	32687	Economy	16800.00
0005433868454	32687	Economy	16800.00
0005433868442	32687	Economy	16800.00
0005433868461	32687	Economy	16800.00
0005433868431	32687	Economy	16800.00
0005433868447	32687	Economy	16800.00
0005433868456	32687	Economy	16800.00
0005433868455	32687	Economy	16800.00
0005433868472	32687	Economy	16800.00
0005433868432	32687	Economy	16800.00
0005433868443	32687	Economy	16800.00
0005433868448	32687	Economy	16800.00
0005433868438	32687	Economy	16800.00
0005433868466	32687	Economy	16800.00
0005433868434	32687	Economy	16800.00
0005433868460	32687	Economy	16800.00
0005433868468	32687	Economy	16800.00
0005435860446	32687	Economy	16800.00
0005433868464	32687	Economy	16800.00
0005433868446	32687	Economy	16800.00
0005433868450	32687	Economy	16800.00
0005433868453	32687	Economy	16800.00
0005433868439	32687	Economy	16800.00
0005435860451	32687	Economy	16800.00
0005433868436	32687	Economy	16800.00
0005433868445	32687	Economy	16800.00
0005433868459	32687	Economy	16800.00
0005433868444	32687	Economy	16800.00
0005433868449	32687	Economy	16800.00
0005432799365	12127	Economy	4900.00
0005432799281	12127	Economy	4900.00
0005432799174	12127	Economy	4400.00
0005432799310	12127	Economy	4400.00
0005432799176	12127	Economy	4400.00
0005432799289	12127	Economy	4400.00
0005432799284	12127	Economy	4400.00
0005432799285	12127	Economy	4400.00
0005432799364	12127	Economy	4400.00
0005432799268	12127	Economy	4400.00
0005432799177	12127	Economy	4400.00
0005432799175	12127	Economy	4400.00
0005432799275	12127	Economy	4400.00
0005432799055	12127	Economy	4400.00
0005432799198	12127	Economy	4400.00
0005432799374	12127	Economy	4400.00
0005432799270	12127	Economy	4400.00
0005432799276	12127	Economy	4400.00
0005432799413	12127	Economy	4400.00
0005432799309	12127	Economy	4400.00
0005432799411	12127	Economy	4400.00
0005432799246	12127	Economy	4400.00
0005432799347	12127	Economy	4400.00
0005432799134	12127	Economy	4400.00
0005432799260	12127	Economy	4400.00
0005432799241	12127	Economy	4400.00
0005432799367	12127	Economy	4400.00
0005432799245	12127	Economy	4400.00
0005432799186	12127	Economy	4400.00
0005432799306	12127	Economy	4400.00
0005432799228	12127	Economy	4400.00
0005432799366	12127	Economy	4400.00
0005432799294	12127	Economy	4400.00
0005432799269	12127	Economy	4400.00
0005432799242	12127	Economy	4400.00
0005432799307	12127	Economy	4400.00
0005432799184	12127	Economy	4400.00
0005432799412	12127	Economy	4400.00
0005432799459	14781	Economy	4900.00
0005432799466	14781	Economy	4900.00
0005432799445	14781	Economy	4400.00
0005432799458	14781	Economy	4400.00
0005432799444	14781	Economy	4400.00
0005432799449	14781	Economy	4400.00
0005432799447	14781	Economy	4400.00
0005432799454	14781	Economy	4400.00
0005432799470	14781	Economy	4400.00
0005432799453	14781	Economy	4400.00
0005432799468	14781	Economy	4400.00
0005432799446	14781	Economy	4400.00
0005432799471	14781	Economy	4400.00
0005432799467	14781	Economy	4400.00
0005432799464	14781	Economy	4400.00
0005432799462	14781	Economy	4400.00
0005432799463	14781	Economy	4400.00
0005432799469	14781	Economy	4400.00
0005432799461	14781	Economy	4400.00
0005432799452	14781	Economy	4400.00
0005432799460	14781	Economy	4400.00
0005432799450	14781	Economy	4400.00
0005432799465	14781	Economy	4400.00
0005432799455	14781	Economy	4400.00
0005432799457	14781	Economy	4400.00
0005432799451	14781	Economy	4400.00
0005432799448	14781	Economy	4400.00
0005432799472	14781	Economy	4400.00
0005432799456	14781	Economy	4400.00
0005435293171	7049	Business	49100.00
0005435310954	7049	Business	49100.00
0005434407833	7049	Business	49100.00
0005432153946	7049	Business	49100.00
0005435310952	7049	Business	49100.00
0005434407865	7049	Business	49100.00
0005434299578	7049	Business	49100.00
0005434299589	7049	Business	49100.00
0005434407843	7049	Business	49100.00
0005434407830	7049	Business	49100.00
0005434299590	7049	Business	49100.00
0005434407846	7049	Economy	16400.00
0005434299584	7049	Economy	16400.00
0005434299583	7049	Economy	16400.00
0005434407800	7049	Economy	16400.00
0005434299596	7049	Economy	16400.00
0005434407853	7049	Economy	16400.00
0005432153945	7049	Economy	16400.00
0005435310924	7049	Economy	16400.00
0005434407804	7049	Economy	16400.00
0005434407829	7049	Economy	16400.00
0005434407808	7049	Economy	16400.00
0005434407845	7049	Economy	16400.00
0005434407802	7049	Economy	16400.00
0005434407842	7049	Economy	16400.00
0005434407801	7049	Economy	16400.00
0005434299582	7049	Economy	16400.00
0005434407856	7049	Economy	16400.00
0005434407803	7049	Economy	16400.00
0005434407820	7049	Economy	16400.00
0005434407806	7049	Economy	16400.00
0005434407852	7049	Economy	16400.00
0005435293172	7049	Economy	16400.00
0005434407821	7049	Economy	16400.00
0005434407805	7049	Economy	16400.00
0005434407848	7049	Economy	16400.00
0005434407818	7049	Economy	16400.00
0005434299577	7049	Economy	16400.00
0005434407859	7049	Economy	16400.00
0005434407837	7049	Economy	16400.00
0005435310953	7049	Economy	16400.00
0005435310913	7049	Economy	16400.00
0005434299587	7049	Economy	16400.00
0005434407835	7049	Economy	16400.00
0005432153947	7049	Economy	16400.00
0005434407828	7049	Economy	16400.00
0005434299598	7049	Economy	16400.00
0005434407863	7049	Economy	16400.00
0005435293131	7049	Economy	18000.00
0005435293151	7049	Economy	18000.00
0005434299594	7049	Economy	18000.00
0005434407815	7049	Economy	18000.00
0005434407854	7049	Economy	18000.00
0005432108252	7049	Economy	18000.00
0005434299576	7049	Economy	16400.00
0005434407836	7049	Economy	16400.00
0005434299591	7049	Economy	16400.00
0005434299593	7049	Economy	16400.00
0005434407838	7049	Economy	16400.00
0005434407850	7049	Economy	16400.00
0005435310962	7049	Economy	16400.00
0005434407819	7049	Economy	16400.00
0005435310943	7049	Economy	16400.00
0005435310912	7049	Economy	16400.00
0005432108253	7049	Economy	16400.00
0005434407858	7049	Economy	16400.00
0005434407864	7049	Economy	16400.00
0005434407839	7049	Economy	16400.00
0005434407824	7049	Economy	16400.00
0005434407822	7049	Economy	16400.00
0005435293173	7049	Economy	16400.00
0005434407860	7049	Economy	16400.00
0005434299595	7049	Economy	16400.00
0005434407812	7049	Economy	16400.00
0005434299597	7049	Economy	16400.00
0005434407817	7049	Economy	16400.00
0005434407851	7049	Economy	16400.00
0005435293165	7049	Economy	16400.00
0005435293164	7049	Economy	16400.00
0005434407847	7049	Economy	16400.00
0005434407861	7049	Economy	16400.00
0005434407826	7049	Economy	16400.00
0005435310911	7049	Economy	16400.00
0005434299580	7049	Economy	16400.00
0005434407844	7049	Economy	16400.00
0005434407810	7049	Economy	16400.00
0005434407832	7049	Economy	16400.00
0005432153943	7049	Economy	16400.00
0005434407855	7049	Economy	16400.00
0005435293153	7049	Economy	16400.00
0005435293161	7049	Economy	16400.00
0005434407825	7049	Economy	16400.00
0005434407862	7049	Economy	16400.00
0005434407857	7049	Economy	16400.00
0005434299575	7049	Economy	16400.00
0005434407827	7049	Economy	16400.00
0005434299586	7049	Economy	16400.00
0005435310942	7049	Economy	16400.00
0005432153948	7049	Economy	16400.00
0005435293135	7049	Economy	16400.00
0005434407840	7049	Economy	16400.00
0005434407809	7049	Economy	16400.00
0005434407834	7049	Economy	16400.00
0005432153944	7049	Economy	16400.00
0005434407841	7049	Economy	16400.00
0005434407831	7049	Economy	16400.00
0005434299581	7049	Economy	16400.00
0005434299585	7049	Economy	16400.00
0005434407814	7049	Economy	16400.00
0005434407811	7049	Economy	16400.00
0005435293147	7049	Economy	16400.00
0005434299579	7049	Economy	16400.00
0005435310948	7049	Economy	16400.00
0005434299592	7049	Economy	16400.00
0005434407813	7049	Economy	16400.00
0005434407807	7049	Economy	16400.00
0005434407823	7049	Economy	16400.00
0005434407849	7049	Economy	16400.00
0005434299588	7049	Economy	16400.00
0005435310955	7049	Economy	16400.00
0005435310971	7049	Economy	16400.00
0005434407816	7049	Economy	16400.00
0005435310961	7049	Economy	16400.00
0005435293160	7049	Economy	16400.00
0005434407235	26907	Business	49100.00
0005435311069	26907	Business	49100.00
0005434407267	26907	Business	49100.00
0005435293268	26907	Business	49100.00
0005434407228	26907	Business	49100.00
0005432058384	26907	Business	49100.00
0005434299373	26907	Business	49100.00
0005435293266	26907	Business	49100.00
0005434299389	26907	Business	49100.00
0005434406915	26907	Business	49100.00
0005434407371	26907	Business	49100.00
0005434299366	26907	Economy	16400.00
0005435293262	26907	Economy	16400.00
0005434299394	26907	Economy	16400.00
0005434299365	26907	Economy	16400.00
0005434407041	26907	Economy	16400.00
0005435311067	26907	Economy	16400.00
0005434407418	26907	Economy	16400.00
0005434407234	26907	Economy	16400.00
0005435311074	26907	Economy	16400.00
0005434407268	26907	Economy	16400.00
0005434299478	26907	Economy	16400.00
0005434407203	26907	Economy	16400.00
0005434407227	26907	Economy	16400.00
0005435311077	26907	Economy	16400.00
0005434407245	26907	Economy	16400.00
0005434406874	26907	Economy	16400.00
0005434407050	26907	Economy	16400.00
0005434299451	26907	Economy	16400.00
0005435293272	26907	Economy	16400.00
0005435311065	26907	Economy	16400.00
0005434406899	26907	Economy	16400.00
0005434299428	26907	Economy	16400.00
0005434407016	26907	Economy	16400.00
0005434407192	26907	Economy	16400.00
0005434407353	26907	Economy	16400.00
0005434407068	26907	Economy	16400.00
0005434406907	26907	Economy	16400.00
0005434299334	26907	Economy	16400.00
0005434407294	26907	Economy	16400.00
0005434407273	26907	Economy	16400.00
0005434407176	26907	Economy	16400.00
0005434407378	26907	Economy	16400.00
0005434299411	26907	Economy	16400.00
0005432058382	26907	Economy	16400.00
0005434299506	26907	Economy	16400.00
0005434407130	26907	Economy	16400.00
0005435293265	26907	Economy	16400.00
0005434407291	26907	Economy	16400.00
0005435293261	26907	Economy	18000.00
0005435311070	26907	Economy	18000.00
0005435311076	26907	Economy	18000.00
0005432058383	26907	Economy	18000.00
0005434407232	26907	Economy	18000.00
0005434407340	26907	Economy	18000.00
0005432058381	26907	Economy	16400.00
0005434407314	26907	Economy	16400.00
0005434299452	26907	Economy	16400.00
0005434299361	26907	Economy	16400.00
0005434407131	26907	Economy	16400.00
0005434299458	26907	Economy	16400.00
0005434299340	26907	Economy	16400.00
0005434407196	26907	Economy	16400.00
0005435293271	26907	Economy	16400.00
0005435311066	26907	Economy	16400.00
0005434299405	26907	Economy	16400.00
0005435311064	26907	Economy	16400.00
0005435293260	26907	Economy	16400.00
0005434299468	26907	Economy	16400.00
0005434407322	26907	Economy	16400.00
0005434299384	26907	Economy	16400.00
0005434407413	26907	Economy	16400.00
0005434407566	26907	Economy	16400.00
0005434299492	26907	Economy	16400.00
0005434406906	26907	Economy	16400.00
0005435293270	26907	Economy	16400.00
0005434299372	26907	Economy	16400.00
0005435311071	26907	Economy	16400.00
0005434407321	26907	Economy	16400.00
0005434407328	26907	Economy	16400.00
0005434407236	26907	Economy	16400.00
0005434407255	26907	Economy	16400.00
0005434407311	26907	Economy	16400.00
0005434407313	26907	Economy	16400.00
0005434299348	26907	Economy	16400.00
0005432058385	26907	Economy	16400.00
0005434407073	26907	Economy	16400.00
0005434406968	26907	Economy	16400.00
0005434299429	26907	Economy	16400.00
0005434407295	26907	Economy	16400.00
0005434407116	26907	Economy	16400.00
0005434407266	26907	Economy	16400.00
0005434299399	26907	Economy	16400.00
0005435311072	26907	Economy	16400.00
0005434407256	26907	Economy	16400.00
0005434406914	26907	Economy	16400.00
0005434407187	26907	Economy	16400.00
0005434299388	26907	Economy	16400.00
0005434407072	26907	Economy	16400.00
0005434407208	26907	Economy	16400.00
0005435293273	26907	Economy	16400.00
0005434407178	26907	Economy	16400.00
0005434407147	26907	Economy	16400.00
0005434299404	26907	Economy	16400.00
0005435311073	26907	Economy	16400.00
0005434407292	26907	Economy	16400.00
0005435311075	26907	Economy	16400.00
0005434299444	26907	Economy	16400.00
0005435311063	26907	Economy	16400.00
0005435311068	26907	Economy	16400.00
0005434299387	26907	Economy	16400.00
0005434407070	26907	Economy	16400.00
0005434299419	26907	Economy	16400.00
0005434407213	26907	Economy	16400.00
0005434299456	26907	Economy	16400.00
0005434407015	26907	Economy	16400.00
0005434299333	26907	Economy	16400.00
0005434407020	26907	Economy	16400.00
0005434407085	26907	Economy	16400.00
0005435293269	26907	Economy	16400.00
0005434407069	26907	Economy	16400.00
0005435293267	26907	Economy	16400.00
0005435293264	26907	Economy	16400.00
0005435293263	26907	Economy	16400.00
0005434407379	26907	Economy	16400.00
0005434512125	6472	Economy	16500.00
0005432604381	6472	Economy	16500.00
0005432604372	6472	Economy	16500.00
0005432604378	6472	Economy	15000.00
0005434512126	6472	Economy	15000.00
0005432604373	6472	Economy	15000.00
0005432604394	6472	Economy	15000.00
0005432604390	6472	Economy	15000.00
0005432604391	6472	Economy	15000.00
0005432604388	6472	Economy	15000.00
0005432604406	6472	Economy	15000.00
0005432604384	6472	Economy	15000.00
0005432604398	6472	Economy	15000.00
0005432604395	6472	Economy	15000.00
0005434512124	6472	Economy	15000.00
0005432604376	6472	Economy	15000.00
0005434512123	6472	Economy	15000.00
0005432604396	6472	Economy	15000.00
0005432604387	6472	Economy	15000.00
0005432604385	6472	Economy	15000.00
0005432604404	6472	Economy	15000.00
0005432604377	6472	Economy	15000.00
0005432604401	6472	Economy	15000.00
0005432604389	6472	Economy	15000.00
0005432604403	6472	Economy	15000.00
0005432604410	6472	Economy	15000.00
0005432604392	6472	Economy	15000.00
0005432604393	6472	Economy	15000.00
0005432604397	6472	Economy	15000.00
0005432604386	6472	Economy	15000.00
0005432604399	6472	Economy	15000.00
0005432604375	6472	Economy	15000.00
0005432604400	6472	Economy	15000.00
0005432604411	6472	Economy	15000.00
0005432604402	6472	Economy	15000.00
0005432604383	6472	Economy	15000.00
0005432604382	6472	Economy	15000.00
0005432604380	6472	Economy	15000.00
0005432604408	6472	Economy	15000.00
0005432604374	6472	Economy	15000.00
0005432604407	6472	Economy	15000.00
0005432604379	6472	Economy	15000.00
0005432604409	6472	Economy	15000.00
0005432604405	6472	Economy	15000.00
0005434512122	6472	Economy	15000.00
0005432603853	21341	Economy	16500.00
0005432604035	21341	Economy	16500.00
0005434512090	21341	Economy	16500.00
0005432604045	21341	Economy	16500.00
0005434512095	21341	Economy	15000.00
0005432604083	21341	Economy	15000.00
0005432603958	21341	Economy	15000.00
0005432603980	21341	Economy	15000.00
0005432603975	21341	Economy	15000.00
0005435221514	21341	Economy	15000.00
0005432603981	21341	Economy	15000.00
0005432604087	21341	Economy	15000.00
0005434512094	21341	Economy	15000.00
0005434512075	21341	Economy	15000.00
0005432603954	21341	Economy	15000.00
0005432603938	21341	Economy	15000.00
0005432603994	21341	Economy	15000.00
0005432603996	21341	Economy	15000.00
0005432604242	21341	Economy	15000.00
0005432603988	21341	Economy	15000.00
0005432604058	21341	Economy	15000.00
0005432603855	21341	Economy	15000.00
0005434512068	21341	Economy	15000.00
0005432603885	21341	Economy	15000.00
0005432604243	21341	Economy	15000.00
0005432603997	21341	Economy	15000.00
0005435221053	21341	Economy	15000.00
0005432604037	21341	Economy	15000.00
0005432604076	21341	Economy	15000.00
0005432603986	21341	Economy	15000.00
0005434512076	21341	Economy	15000.00
0005432604034	21341	Economy	15000.00
0005435221515	21341	Economy	15000.00
0005434512067	21341	Economy	15000.00
0005432603976	21341	Economy	15000.00
0005434512086	21341	Economy	15000.00
0005434512077	21341	Economy	15000.00
0005435221052	21341	Economy	15000.00
0005432603854	21341	Economy	15000.00
0005432603957	21341	Economy	15000.00
0005432604046	21341	Economy	15000.00
0005432603977	21341	Economy	15000.00
0005432603992	21341	Economy	15000.00
0005432604086	21341	Economy	15000.00
0005432603993	21341	Economy	15000.00
0005432604048	21341	Economy	15000.00
0005432604084	21341	Economy	15000.00
0005432604024	21341	Economy	15000.00
0005432603856	21341	Economy	15000.00
0005434906837	14988	Business	18900.00
0005433251511	14988	Business	18900.00
0005434906590	14988	Business	18900.00
0005434906985	14988	Business	18900.00
0005434906913	14988	Business	18900.00
0005434906800	14988	Business	18900.00
0005433251519	14988	Business	18900.00
0005434906862	14988	Business	18900.00
0005434906954	14988	Economy	6300.00
0005434906796	14988	Economy	6300.00
0005434906824	14988	Economy	6300.00
0005434906848	14988	Economy	6300.00
0005434906907	14988	Economy	6300.00
0005434906688	14988	Economy	6300.00
0005434906791	14988	Economy	6300.00
0005434906887	14988	Economy	6300.00
0005433251520	14988	Economy	6300.00
0005433251525	14988	Economy	6300.00
0005434906818	14988	Economy	6900.00
0005433251500	14988	Economy	6900.00
0005433251504	14988	Economy	6900.00
0005434906886	14988	Economy	6900.00
0005433251501	14988	Economy	6900.00
0005433251526	14988	Economy	6300.00
0005434906910	14988	Economy	6300.00
0005434906901	14988	Economy	6300.00
0005433251506	14988	Economy	6300.00
0005433251509	14988	Economy	6300.00
0005434907041	14988	Economy	6300.00
0005433251496	14988	Economy	6300.00
0005433251521	14988	Economy	6300.00
0005433251497	14988	Economy	6300.00
0005434906762	14988	Economy	6300.00
0005434906911	14988	Economy	6300.00
0005433251527	14988	Economy	6300.00
0005434906906	14988	Economy	6300.00
0005433251517	14988	Economy	6300.00
0005433251508	14988	Economy	6300.00
0005434906781	14988	Economy	6300.00
0005434907031	14988	Economy	6300.00
0005433251499	14988	Economy	6300.00
0005434906697	14988	Economy	6300.00
0005434906879	14988	Economy	6300.00
0005434906989	14988	Economy	6300.00
0005434906847	14988	Economy	6300.00
0005433251510	14988	Economy	6300.00
0005434906670	14988	Economy	6300.00
0005434906849	14988	Economy	6300.00
0005434906808	14988	Economy	6300.00
0005434907030	14988	Economy	6300.00
0005434907025	14988	Economy	6300.00
0005433251518	14988	Economy	6300.00
0005433251513	14988	Economy	6300.00
0005433251524	14988	Economy	6300.00
0005434906640	14988	Economy	6300.00
0005433251512	14988	Economy	6300.00
0005433251505	14988	Economy	6300.00
0005434906807	14988	Economy	6300.00
0005434906805	14988	Economy	6300.00
0005434906600	14988	Economy	6300.00
0005434907148	14988	Economy	6300.00
0005433251502	14988	Economy	6300.00
0005434906955	14988	Economy	6300.00
0005433251507	14988	Economy	6300.00
0005434906939	14988	Economy	6300.00
0005433251503	14988	Economy	6300.00
0005433251516	14988	Economy	6300.00
0005434906851	14988	Economy	6300.00
0005434906902	14988	Economy	6300.00
0005434906917	14988	Economy	6300.00
0005434906822	14988	Economy	6300.00
0005434906687	14988	Economy	6300.00
0005433251522	14988	Economy	6300.00
0005434906823	14988	Economy	6300.00
0005434906905	14988	Economy	6300.00
0005434906922	14988	Economy	6300.00
0005433251514	14988	Economy	6300.00
0005433251498	14988	Economy	6300.00
0005434906840	14988	Economy	6300.00
0005433251515	14988	Economy	6300.00
0005434906970	14988	Economy	6300.00
0005433251523	14988	Economy	6300.00
0005434906591	14988	Economy	6300.00
0005434907042	14988	Economy	6300.00
0005434907292	25860	Business	18900.00
0005434907300	25860	Business	18900.00
0005434907280	25860	Business	18900.00
0005434907308	25860	Business	18900.00
0005434907297	25860	Business	18900.00
0005433251268	25860	Business	18900.00
0005434907315	25860	Business	18900.00
0005433251304	25860	Business	18900.00
0005433251243	25860	Business	18900.00
0005434907294	25860	Business	18900.00
0005434907268	25860	Business	18900.00
0005434907305	25860	Economy	6300.00
0005434907309	25860	Economy	6300.00
0005434907298	25860	Economy	6300.00
0005433251241	25860	Economy	6300.00
0005434907303	25860	Economy	6300.00
0005434907269	25860	Economy	6300.00
0005434907293	25860	Economy	6300.00
0005433251184	25860	Economy	6300.00
0005434907276	25860	Economy	6300.00
0005434907307	25860	Economy	6300.00
0005434907275	25860	Economy	6900.00
0005433251426	25860	Economy	6900.00
0005433251277	25860	Economy	6900.00
0005434907301	25860	Economy	6900.00
0005433251328	25860	Economy	6900.00
0005433251138	25860	Economy	6300.00
0005433251186	25860	Economy	6300.00
0005433251217	25860	Economy	6300.00
0005433251326	25860	Economy	6300.00
0005434907285	25860	Economy	6300.00
0005434907314	25860	Economy	6300.00
0005434907282	25860	Economy	6300.00
0005433251279	25860	Economy	6300.00
0005434907304	25860	Economy	6300.00
0005433251216	25860	Economy	6300.00
0005433251283	25860	Economy	6300.00
0005433251170	25860	Economy	6300.00
0005434907287	25860	Economy	6300.00
0005434907296	25860	Economy	6300.00
0005434907273	25860	Economy	6300.00
0005433251185	25860	Economy	6300.00
0005434907299	25860	Economy	6300.00
0005433251239	25860	Economy	6300.00
0005433251126	25860	Economy	6300.00
0005434907283	25860	Economy	6300.00
0005434907295	25860	Economy	6300.00
0005434907289	25860	Economy	6300.00
0005433251275	25860	Economy	6300.00
0005434907291	25860	Economy	6300.00
0005434907302	25860	Economy	6300.00
0005433251249	25860	Economy	6300.00
0005434907270	25860	Economy	6300.00
0005433251280	25860	Economy	6300.00
0005433251171	25860	Economy	6300.00
0005434907271	25860	Economy	6300.00
0005433251285	25860	Economy	6300.00
0005433251229	25860	Economy	6300.00
0005434907263	25860	Economy	6300.00
0005434907288	25860	Economy	6300.00
0005434907311	25860	Economy	6300.00
0005434907281	25860	Economy	6300.00
0005433251276	25860	Economy	6300.00
0005434907267	25860	Economy	6300.00
0005433251305	25860	Economy	6300.00
0005434907274	25860	Economy	6300.00
0005434907279	25860	Economy	6300.00
0005433251329	25860	Economy	6300.00
0005434907278	25860	Economy	6300.00
0005434907290	25860	Economy	6300.00
0005433251220	25860	Economy	6300.00
0005434907306	25860	Economy	6300.00
0005434907313	25860	Economy	6300.00
0005434907310	25860	Economy	6300.00
0005434907266	25860	Economy	6300.00
0005434907264	25860	Economy	6300.00
0005434907286	25860	Economy	6300.00
0005433251124	25860	Economy	6300.00
0005434907265	25860	Economy	6300.00
0005433251240	25860	Economy	6300.00
0005434907277	25860	Economy	6300.00
0005433251230	25860	Economy	6300.00
0005433251278	25860	Economy	6300.00
0005434907284	25860	Economy	6300.00
0005433251221	25860	Economy	6300.00
0005434907272	25860	Economy	6300.00
0005433251125	25860	Economy	6300.00
0005433251141	25860	Economy	6300.00
0005434907312	25860	Economy	6300.00
0005433251286	25860	Economy	6300.00
0005433008664	14172	Business	52300.00
0005433008668	14172	Business	52300.00
0005433008685	14172	Business	52300.00
0005433008700	14172	Business	52300.00
0005433008689	14172	Business	52300.00
0005433008678	14172	Economy	17400.00
0005433008665	14172	Economy	17400.00
0005433008659	14172	Economy	17400.00
0005433008697	14172	Economy	17400.00
0005433008660	14172	Economy	17400.00
0005433008670	14172	Economy	19200.00
0005433008696	14172	Economy	19200.00
0005433008690	14172	Economy	17400.00
0005433008663	14172	Economy	17400.00
0005433008672	14172	Economy	17400.00
0005433008679	14172	Economy	17400.00
0005433008680	14172	Economy	17400.00
0005433008692	14172	Economy	17400.00
0005433008669	14172	Economy	17400.00
0005433008691	14172	Economy	17400.00
0005433008658	14172	Economy	17400.00
0005433008701	14172	Economy	17400.00
0005433008695	14172	Economy	17400.00
0005433008683	14172	Economy	17400.00
0005433008667	14172	Economy	17400.00
0005433008686	14172	Economy	17400.00
0005433008682	14172	Economy	17400.00
0005433008684	14172	Economy	17400.00
0005433008673	14172	Economy	17400.00
0005433008693	14172	Economy	17400.00
0005433008666	14172	Economy	17400.00
0005433008688	14172	Economy	17400.00
0005433008702	14172	Economy	17400.00
0005433008694	14172	Economy	17400.00
0005433008674	14172	Economy	17400.00
0005433008676	14172	Economy	17400.00
0005433008687	14172	Economy	17400.00
0005433008699	14172	Economy	17400.00
0005433008662	14172	Economy	17400.00
0005433008671	14172	Economy	17400.00
0005433008661	14172	Economy	17400.00
0005433810506	14172	Economy	17400.00
0005433008698	14172	Economy	17400.00
0005433008677	14172	Economy	17400.00
0005433008681	14172	Economy	17400.00
0005433008675	14172	Economy	17400.00
0005433008657	14172	Economy	17400.00
0005433008334	22870	Business	52300.00
0005433008069	22870	Business	52300.00
0005433810549	22870	Business	52300.00
0005433008132	22870	Business	52300.00
0005433008118	22870	Business	52300.00
0005433008463	22870	Business	52300.00
0005433008320	22870	Business	52300.00
0005433008193	22870	Business	52300.00
0005433008147	22870	Business	52300.00
0005433008076	22870	Economy	17400.00
0005433008319	22870	Economy	17400.00
0005433008347	22870	Economy	17400.00
0005433008206	22870	Economy	17400.00
0005433008156	22870	Economy	17400.00
0005433008276	22870	Economy	17400.00
0005433008317	22870	Economy	17400.00
0005433008205	22870	Economy	19200.00
0005433008375	22870	Economy	19200.00
0005433008241	22870	Economy	17400.00
0005433008192	22870	Economy	17400.00
0005433008325	22870	Economy	17400.00
0005433008282	22870	Economy	17400.00
0005433810546	22870	Economy	17400.00
0005433008133	22870	Economy	17400.00
0005433008422	22870	Economy	17400.00
0005433810547	22870	Economy	17400.00
0005433008099	22870	Economy	17400.00
0005433008346	22870	Economy	17400.00
0005433008372	22870	Economy	17400.00
0005433008153	22870	Economy	17400.00
0005433008383	22870	Economy	17400.00
0005433008106	22870	Economy	17400.00
0005433008152	22870	Economy	17400.00
0005433008264	22870	Economy	17400.00
0005433008187	22870	Economy	17400.00
0005433008174	22870	Economy	17400.00
0005433008200	22870	Economy	17400.00
0005433008144	22870	Economy	17400.00
0005433008131	22870	Economy	17400.00
0005433008423	22870	Economy	17400.00
0005433008266	22870	Economy	17400.00
0005433008204	22870	Economy	17400.00
0005433008338	22870	Economy	17400.00
0005433008171	22870	Economy	17400.00
0005433008119	22870	Economy	17400.00
0005433008079	22870	Economy	17400.00
0005433008376	22870	Economy	17400.00
0005433008068	22870	Economy	17400.00
0005433008218	22870	Economy	17400.00
0005433008337	22870	Economy	17400.00
0005433008048	22870	Economy	17400.00
0005433810548	22870	Economy	17400.00
0005433008207	22870	Economy	17400.00
0005433008188	22870	Economy	17400.00
0005433008143	22870	Economy	17400.00
0005433008239	22870	Economy	17400.00
0005433008265	22870	Economy	17400.00
0005434925492	14948	Business	22900.00
0005434925661	14948	Business	22900.00
0005434925692	14948	Business	22900.00
0005434925420	14948	Business	22900.00
0005434925635	14948	Economy	7600.00
0005434925636	14948	Economy	7600.00
0005434925663	14948	Economy	7600.00
0005434925745	14948	Economy	7600.00
0005434925464	14948	Economy	7600.00
0005434925649	14948	Economy	7600.00
0005434925463	14948	Economy	8400.00
0005434925673	14948	Economy	7600.00
0005434925577	14948	Economy	7600.00
0005434925572	14948	Economy	7600.00
0005434925510	14948	Economy	7600.00
0005434925524	14948	Economy	7600.00
0005434925481	14948	Economy	7600.00
0005434925441	14948	Economy	7600.00
0005434925674	14948	Economy	7600.00
0005434925573	14948	Economy	7600.00
0005434925422	14948	Economy	7600.00
0005434925553	14948	Economy	7600.00
0005434925648	14948	Economy	7600.00
0005434925469	14948	Economy	7600.00
0005434925512	14948	Economy	7600.00
0005434925662	14948	Economy	7600.00
0005434925400	14948	Economy	7600.00
0005434925456	14948	Economy	7600.00
0005434925401	14948	Economy	7600.00
0005434925417	14948	Economy	7600.00
0005434925419	14948	Economy	7600.00
0005434925502	14948	Economy	7600.00
0005434925818	20513	Business	22900.00
0005434925831	20513	Business	22900.00
0005434925817	20513	Economy	7600.00
0005434925821	20513	Economy	7600.00
0005434925819	20513	Economy	7600.00
0005434925811	20513	Economy	8400.00
0005434925816	20513	Economy	8400.00
0005434925813	20513	Economy	7600.00
0005434925806	20513	Economy	7600.00
0005434925810	20513	Economy	7600.00
0005434925814	20513	Economy	7600.00
0005434925801	20513	Economy	7600.00
0005434925828	20513	Economy	7600.00
0005434925822	20513	Economy	7600.00
0005434925825	20513	Economy	7600.00
0005434925808	20513	Economy	7600.00
0005434925830	20513	Economy	7600.00
0005434925820	20513	Economy	7600.00
0005434925815	20513	Economy	7600.00
0005434925826	20513	Economy	7600.00
0005434925802	20513	Economy	7600.00
0005434925809	20513	Economy	7600.00
0005434925803	20513	Economy	7600.00
0005434925805	20513	Economy	7600.00
0005434925804	20513	Economy	7600.00
0005434925812	20513	Economy	7600.00
0005434925827	20513	Economy	7600.00
0005434925800	20513	Economy	7600.00
0005434925824	20513	Economy	7600.00
0005434925807	20513	Economy	7600.00
0005434925823	20513	Economy	7600.00
0005434925829	20513	Economy	7600.00
0005435999055	15837	Economy	8900.00
0005435487870	15837	Economy	8900.00
0005435487853	15837	Economy	8900.00
0005435999111	15837	Economy	8100.00
0005435999116	15837	Economy	8100.00
0005435487857	15837	Economy	8100.00
0005435487868	15837	Economy	8100.00
0005435999093	15837	Economy	8100.00
0005435487858	15837	Economy	8100.00
0005435999054	15837	Economy	8100.00
0005435487873	15837	Economy	8100.00
0005435999092	15837	Economy	8100.00
0005435487867	15837	Economy	8100.00
0005435487854	15837	Economy	8100.00
0005435487863	15837	Economy	8100.00
0005435999161	15837	Economy	8100.00
0005435487852	15837	Economy	8100.00
0005435487872	15837	Economy	8100.00
0005435487856	15837	Economy	8100.00
0005435999112	15837	Economy	8100.00
0005435487866	15837	Economy	8100.00
0005435487862	15837	Economy	8100.00
0005435487859	15837	Economy	8100.00
0005435999089	15837	Economy	8100.00
0005435487864	15837	Economy	8100.00
0005435487860	15837	Economy	8100.00
0005435999095	15837	Economy	8100.00
0005435487855	15837	Economy	8100.00
0005435999106	15837	Economy	8100.00
0005435999065	15837	Economy	8100.00
0005435487861	15837	Economy	8100.00
0005435487865	15837	Economy	8100.00
0005435999164	15837	Economy	8100.00
0005435487871	15837	Economy	8100.00
0005435487869	15837	Economy	8100.00
0005435999107	15837	Economy	8100.00
0005435999159	15837	Economy	8100.00
0005435999160	15837	Economy	8100.00
0005435999120	15837	Economy	8100.00
0005435487589	19681	Economy	8900.00
0005435999256	19681	Economy	8900.00
0005435487751	19681	Economy	8900.00
0005435999251	19681	Economy	8100.00
0005435487618	19681	Economy	8100.00
0005435999250	19681	Economy	8100.00
0005435999264	19681	Economy	8100.00
0005435999253	19681	Economy	8100.00
0005435487633	19681	Economy	8100.00
0005435999257	19681	Economy	8100.00
0005435487592	19681	Economy	8100.00
0005435487486	19681	Economy	8100.00
0005435999255	19681	Economy	8100.00
0005435999258	19681	Economy	8100.00
0005435999261	19681	Economy	8100.00
0005435487702	19681	Economy	8100.00
0005435487599	19681	Economy	8100.00
0005435999252	19681	Economy	8100.00
0005435999249	19681	Economy	8100.00
0005435487569	19681	Economy	8100.00
0005435487685	19681	Economy	8100.00
0005435487521	19681	Economy	8100.00
0005435487591	19681	Economy	8100.00
0005435487686	19681	Economy	8100.00
0005435999254	19681	Economy	8100.00
0005435487617	19681	Economy	8100.00
0005435487484	19681	Economy	8100.00
0005435487644	19681	Economy	8100.00
0005435487645	19681	Economy	8100.00
0005435999262	19681	Economy	8100.00
0005435487616	19681	Economy	8100.00
0005435487707	19681	Economy	8100.00
0005435999265	19681	Economy	8100.00
0005435487485	19681	Economy	8100.00
0005435999263	19681	Economy	8100.00
0005435999260	19681	Economy	8100.00
0005435999259	19681	Economy	8100.00
0005435839502	6016	Business	199300.00
0005435839492	6016	Business	199300.00
0005432142257	6016	Business	199300.00
0005435839490	6016	Business	199300.00
0005435839503	6016	Business	199300.00
0005435839501	6016	Business	199300.00
0005435839500	6016	Business	199300.00
0005435839483	6016	Economy	66400.00
0005435839478	6016	Economy	66400.00
0005435839481	6016	Economy	66400.00
0005435839496	6016	Economy	66400.00
0005435472718	6016	Economy	66400.00
0005435472556	6016	Economy	73100.00
0005435839493	6016	Economy	66400.00
0005435839499	6016	Economy	66400.00
0005435472707	6016	Economy	66400.00
0005435839485	6016	Economy	66400.00
0005435472674	6016	Economy	66400.00
0005435472727	6016	Economy	66400.00
0005435839491	6016	Economy	66400.00
0005432659709	6016	Economy	66400.00
0005432658595	6016	Economy	66400.00
0005435839487	6016	Economy	66400.00
0005435839486	6016	Economy	66400.00
0005432660822	6016	Economy	66400.00
0005435472675	6016	Economy	66400.00
0005435472705	6016	Economy	66400.00
0005435472666	6016	Economy	66400.00
0005435839497	6016	Economy	66400.00
0005435472684	6016	Economy	66400.00
0005435839480	6016	Economy	66400.00
0005432659710	6016	Economy	66400.00
0005435839494	6016	Economy	66400.00
0005435472676	6016	Economy	66400.00
0005435839482	6016	Economy	66400.00
0005432660821	6016	Economy	66400.00
0005435472648	6016	Economy	66400.00
0005435839489	6016	Economy	66400.00
0005435472704	6016	Economy	66400.00
0005435839495	6016	Economy	66400.00
0005435472662	6016	Economy	66400.00
0005435839479	6016	Economy	66400.00
0005435472728	6016	Economy	66400.00
0005432142256	6016	Economy	66400.00
0005435839498	6016	Economy	66400.00
0005435839484	6016	Economy	66400.00
0005435839476	6016	Economy	66400.00
0005435839504	6016	Economy	66400.00
0005435839477	6016	Economy	66400.00
0005435472686	6016	Economy	66400.00
0005435839488	6016	Economy	66400.00
0005435839200	18050	Business	199300.00
0005432537062	18050	Business	199300.00
0005435839229	18050	Business	199300.00
0005435472827	18050	Business	199300.00
0005435472817	18050	Business	199300.00
0005435839347	18050	Business	199300.00
0005435839266	18050	Business	199300.00
0005435839353	18050	Economy	66400.00
0005435472825	18050	Economy	66400.00
0005435617235	18050	Economy	66400.00
0005435472823	18050	Economy	66400.00
0005435839210	18050	Economy	66400.00
0005432664113	18050	Economy	66400.00
0005435472831	18050	Economy	66400.00
0005435839239	18050	Economy	66400.00
0005435839212	18050	Economy	73100.00
0005435839346	18050	Economy	73100.00
0005435472821	18050	Economy	66400.00
0005435472818	18050	Economy	66400.00
0005435839206	18050	Economy	66400.00
0005435839267	18050	Economy	66400.00
0005435839179	18050	Economy	66400.00
0005435472820	18050	Economy	66400.00
0005435839250	18050	Economy	66400.00
0005435839249	18050	Economy	66400.00
0005435839178	18050	Economy	66400.00
0005435472819	18050	Economy	66400.00
0005435839242	18050	Economy	66400.00
0005432660798	18050	Economy	66400.00
0005435617234	18050	Economy	66400.00
0005432537061	18050	Economy	66400.00
0005435839228	18050	Economy	66400.00
0005435472824	18050	Economy	66400.00
0005435839283	18050	Economy	66400.00
0005435472822	18050	Economy	66400.00
0005435472828	18050	Economy	66400.00
0005435472826	18050	Economy	66400.00
0005432667429	18050	Economy	66400.00
0005435472829	18050	Economy	66400.00
0005435839180	18050	Economy	66400.00
0005432664127	18050	Economy	66400.00
0005435472830	18050	Economy	66400.00
0005435472816	18050	Economy	66400.00
0005435472815	18050	Economy	66400.00
0005433285078	23056	Business	15700.00
0005435103936	23056	Business	15700.00
0005435103940	23056	Business	15700.00
0005433285172	23056	Business	15700.00
0005433284993	23056	Economy	5200.00
0005433284971	23056	Economy	5200.00
0005435103934	23056	Economy	5200.00
0005435103935	23056	Economy	5200.00
0005433284972	23056	Economy	5200.00
0005433285079	23056	Economy	5200.00
0005433285016	23056	Economy	5200.00
0005433285049	23056	Economy	5200.00
0005433285096	23056	Economy	5700.00
0005433285173	23056	Economy	5700.00
0005435103938	23056	Economy	5700.00
0005433285057	23056	Economy	5700.00
0005433285129	23056	Economy	5200.00
0005433285127	23056	Economy	5200.00
0005433285171	23056	Economy	5200.00
0005433284970	23056	Economy	5200.00
0005433285018	23056	Economy	5200.00
0005433285058	23056	Economy	5200.00
0005433285025	23056	Economy	5200.00
0005433285077	23056	Economy	5200.00
0005433285150	23056	Economy	5200.00
0005435103933	23056	Economy	5200.00
0005433285000	23056	Economy	5200.00
0005433285011	23056	Economy	5200.00
0005435103941	23056	Economy	5200.00
0005435103939	23056	Economy	5200.00
0005433285170	23056	Economy	5200.00
0005433285038	23056	Economy	5200.00
0005435103937	23056	Economy	5200.00
0005433285048	23056	Economy	5200.00
0005433285337	32087	Business	15700.00
0005433285342	32087	Business	15700.00
0005433285336	32087	Business	15700.00
0005433285343	32087	Business	15700.00
0005433285333	32087	Economy	5200.00
0005433285334	32087	Economy	5200.00
0005433285341	32087	Economy	5200.00
0005433285332	32087	Economy	5200.00
0005433285349	32087	Economy	5200.00
0005433285348	32087	Economy	5200.00
0005433285355	32087	Economy	5200.00
0005433285340	32087	Economy	5200.00
0005433285331	32087	Economy	5200.00
0005433285353	32087	Economy	5200.00
0005433285329	32087	Economy	5200.00
0005433285327	32087	Economy	5200.00
0005435103839	32087	Economy	5700.00
0005433285358	32087	Economy	5700.00
0005433285328	32087	Economy	5200.00
0005433285346	32087	Economy	5200.00
0005433285344	32087	Economy	5200.00
0005433285335	32087	Economy	5200.00
0005433285345	32087	Economy	5200.00
0005433285330	32087	Economy	5200.00
0005433285356	32087	Economy	5200.00
0005433285347	32087	Economy	5200.00
0005433285352	32087	Economy	5200.00
0005433285357	32087	Economy	5200.00
0005433285350	32087	Economy	5200.00
0005433285338	32087	Economy	5200.00
0005433285339	32087	Economy	5200.00
0005433285354	32087	Economy	5200.00
0005433285351	32087	Economy	5200.00
0005435213675	30632	Business	42100.00
0005434067263	30632	Business	42100.00
0005434066615	30632	Business	42100.00
0005435213679	30632	Business	42100.00
0005432527397	30632	Business	42100.00
0005432527557	30632	Business	42100.00
0005432527238	30632	Business	42100.00
0005434067091	30632	Business	42100.00
0005432526875	30632	Business	42100.00
0005434067089	30632	Business	42100.00
0005435213666	30632	Business	42100.00
0005435213667	30632	Business	42100.00
0005432527313	30632	Business	42100.00
0005434066971	30632	Business	42100.00
0005434066817	30632	Business	42100.00
0005435213654	30632	Business	42100.00
0005432527447	30632	Business	42100.00
0005434067254	30632	Business	42100.00
0005432526874	30632	Business	42100.00
0005432526684	30632	Business	42100.00
0005434066822	30632	Business	42100.00
0005432526992	30632	Business	42100.00
0005432526928	30632	Business	42100.00
0005432527203	30632	Business	42100.00
0005435213685	30632	Business	42100.00
0005432526805	30632	Comfort	23900.00
0005432526628	30632	Comfort	23900.00
0005435213688	30632	Comfort	23900.00
0005432428919	30632	Comfort	23900.00
0005432527292	30632	Comfort	23900.00
0005435213713	30632	Comfort	23900.00
0005432526631	30632	Comfort	23900.00
0005434066934	30632	Comfort	23900.00
0005435213689	30632	Comfort	23900.00
0005435213674	30632	Comfort	23900.00
0005434067151	30632	Comfort	23900.00
0005432527333	30632	Comfort	23900.00
0005434066994	30632	Comfort	23900.00
0005434067082	30632	Comfort	23900.00
0005434067019	30632	Comfort	23900.00
0005435725609	30632	Comfort	23900.00
0005432526792	30632	Comfort	23900.00
0005435213659	30632	Comfort	23900.00
0005434067265	30632	Comfort	23900.00
0005435213694	30632	Comfort	23900.00
0005434066933	30632	Comfort	23900.00
0005432526844	30632	Comfort	23900.00
0005435213647	30632	Comfort	23900.00
0005432527102	30632	Comfort	23900.00
0005432526597	30632	Comfort	23900.00
0005434067014	30632	Comfort	23900.00
0005432526461	30632	Comfort	23900.00
0005435213649	30632	Comfort	23900.00
0005434067041	30632	Comfort	23900.00
0005432526995	30632	Comfort	23900.00
0005432527022	30632	Comfort	23900.00
0005432527010	30632	Comfort	23900.00
0005432211518	30632	Comfort	23900.00
0005432526872	30632	Comfort	23900.00
0005435213676	30632	Economy	14000.00
0005435725613	30632	Economy	14000.00
0005434067209	30632	Economy	14000.00
0005433656677	30632	Economy	14000.00
0005432526810	30632	Economy	14000.00
0005432159867	30632	Economy	14000.00
0005432527809	30632	Economy	14000.00
0005432527040	30632	Economy	14000.00
0005432527257	30632	Economy	14000.00
0005432527159	30632	Economy	14000.00
0005435213711	30632	Economy	14000.00
0005432159864	30632	Economy	14000.00
0005432527372	30632	Economy	14000.00
0005435213652	30632	Economy	14000.00
0005434067003	30632	Economy	14000.00
0005432527585	30632	Economy	14000.00
0005432527248	30632	Economy	14000.00
0005432535782	30632	Economy	14000.00
0005435213696	30632	Economy	14000.00
0005434066984	30632	Economy	14000.00
0005432527176	30632	Economy	14000.00
0005435213684	30632	Economy	14000.00
0005432527251	30632	Economy	14000.00
0005432533276	30632	Economy	14000.00
0005432527371	30632	Economy	14000.00
0005434067040	30632	Economy	14000.00
0005434066659	30632	Economy	14000.00
0005435213663	30632	Economy	14000.00
0005434067124	30632	Economy	14000.00
0005432527194	30632	Economy	14000.00
0005432211513	30632	Economy	14000.00
0005434066751	30632	Economy	14000.00
0005434067146	30632	Economy	14000.00
0005432527048	30632	Economy	14000.00
0005434066974	30632	Economy	14000.00
0005432527422	30632	Economy	14000.00
0005435213661	30632	Economy	14000.00
0005434067046	30632	Economy	14000.00
0005435213650	30632	Economy	14000.00
0005432527531	30632	Economy	14000.00
0005435213686	30632	Economy	14000.00
0005434067065	30632	Economy	14000.00
0005432159865	30632	Economy	14000.00
0005433656679	30632	Economy	14000.00
0005432535798	30632	Economy	14000.00
0005434066940	30632	Economy	14000.00
0005432535813	30632	Economy	14000.00
0005432527090	30632	Economy	14000.00
0005434066750	30632	Economy	14000.00
0005432527047	30632	Economy	14000.00
0005435213693	30632	Economy	14000.00
0005434066614	30632	Economy	14000.00
0005435213708	30632	Economy	14000.00
0005435213665	30632	Economy	14000.00
0005432527153	30632	Economy	14000.00
0005435213671	30632	Economy	14000.00
0005432527363	30632	Economy	15400.00
0005432527416	30632	Economy	15400.00
0005432159866	30632	Economy	15400.00
0005435213687	30632	Economy	14000.00
0005432428921	30632	Economy	14000.00
0005434067157	30632	Economy	15400.00
0005434066885	30632	Economy	14000.00
0005434066660	30632	Economy	15400.00
0005434067348	30632	Economy	15400.00
0005434067170	30632	Economy	14000.00
0005432527412	30632	Economy	14000.00
0005432526873	30632	Economy	14000.00
0005432527584	30632	Economy	14000.00
0005432527636	30632	Economy	14000.00
0005435213699	30632	Economy	14000.00
0005435213701	30632	Economy	14000.00
0005434066693	30632	Economy	14000.00
0005432527448	30632	Economy	14000.00
0005434066767	30632	Economy	14000.00
0005432526482	30632	Economy	14000.00
0005434067203	30632	Economy	14000.00
0005435213683	30632	Economy	14000.00
0005434067208	30632	Economy	14000.00
0005432527327	30632	Economy	14000.00
0005432211520	30632	Economy	14000.00
0005432527012	30632	Economy	14000.00
0005432526994	30632	Economy	14000.00
0005434067253	30632	Economy	14000.00
0005432527334	30632	Economy	14000.00
0005432527328	30632	Economy	14000.00
0005435213657	30632	Economy	14000.00
0005434066935	30632	Economy	14000.00
0005432527439	30632	Economy	14000.00
0005433656678	30632	Economy	14000.00
0005435213704	30632	Economy	14000.00
0005435213680	30632	Economy	14000.00
0005432526804	30632	Economy	14000.00
0005435213673	30632	Economy	14000.00
0005432526849	30632	Economy	14000.00
0005432527502	30632	Economy	14000.00
0005432526847	30632	Economy	14000.00
0005432527379	30632	Economy	14000.00
0005435213677	30632	Economy	14000.00
0005435213705	30632	Economy	14000.00
0005435213697	30632	Economy	14000.00
0005434067100	30632	Economy	14000.00
0005435213709	30632	Economy	14000.00
0005432527062	30632	Economy	14000.00
0005432526629	30632	Economy	14000.00
0005434066914	30632	Economy	14000.00
0005435213655	30632	Economy	14000.00
0005434067349	30632	Economy	14000.00
0005432526639	30632	Economy	14000.00
0005435213698	30632	Economy	14000.00
0005432526946	30632	Economy	14000.00
0005432527169	30632	Economy	14000.00
0005432527289	30632	Economy	14000.00
0005432526970	30632	Economy	14000.00
0005434067073	30632	Economy	14000.00
0005434066821	30632	Economy	14000.00
0005432527309	30632	Economy	14000.00
0005432527472	30632	Economy	14000.00
0005432526983	30632	Economy	14000.00
0005435213691	30632	Economy	14000.00
0005435213662	30632	Economy	14000.00
0005434067125	30632	Economy	14000.00
0005434067162	30632	Economy	14000.00
0005432527027	30632	Economy	14000.00
0005435213707	30632	Economy	14000.00
0005432527353	30632	Economy	14000.00
0005435213678	30632	Economy	14000.00
0005432527365	30632	Economy	14000.00
0005432527380	30632	Economy	14000.00
0005434067042	30632	Economy	14000.00
0005434067010	30632	Economy	14000.00
0005434067174	30632	Economy	14000.00
0005432527049	30632	Economy	14000.00
0005434066896	30632	Economy	14000.00
0005434067320	30632	Economy	14000.00
0005435213651	30632	Economy	14000.00
0005432526918	30632	Economy	14000.00
0005432527089	30632	Economy	14000.00
0005432526958	30632	Economy	14000.00
0005432526903	30632	Economy	14000.00
0005432159868	30632	Economy	14000.00
0005432526630	30632	Economy	14000.00
0005432527310	30632	Economy	14000.00
0005432527450	30632	Economy	14000.00
0005434066857	30632	Economy	14000.00
0005435630972	30632	Economy	14000.00
0005434067093	30632	Economy	14000.00
0005435213664	30632	Economy	14000.00
0005432527210	30632	Economy	14000.00
0005434066897	30632	Economy	14000.00
0005432527332	30632	Economy	14000.00
0005435213681	30632	Economy	14000.00
0005434066986	30632	Economy	14000.00
0005435213690	30632	Economy	14000.00
0005435213692	30632	Economy	14000.00
0005432527620	30632	Economy	14000.00
0005432527745	30632	Economy	14000.00
0005432527191	30632	Economy	14000.00
0005432527746	30632	Economy	14000.00
0005435630973	30632	Economy	14000.00
0005432527258	30632	Economy	15400.00
0005435213703	30632	Economy	14000.00
0005432428922	30632	Economy	15400.00
0005435213656	30632	Economy	15400.00
0005435725611	30632	Economy	15400.00
0005434066848	30632	Economy	15400.00
0005435725612	30632	Economy	15400.00
0005432527381	30632	Economy	14000.00
0005432527252	30632	Economy	14000.00
0005432211516	30632	Economy	14000.00
0005435213714	30632	Economy	14000.00
0005435213646	30632	Economy	14000.00
0005432526848	30632	Economy	14000.00
0005432527536	30632	Economy	14000.00
0005432526870	30632	Economy	14000.00
0005432527311	30632	Economy	14000.00
0005432526598	30632	Economy	14000.00
0005432527317	30632	Economy	14000.00
0005432527433	30632	Economy	14000.00
0005432526855	30632	Economy	14000.00
0005432211519	30632	Economy	14000.00
0005432526854	30632	Economy	14000.00
0005434067081	30632	Economy	14000.00
0005432526947	30632	Economy	14000.00
0005432526919	30632	Economy	14000.00
0005432527140	30632	Economy	14000.00
0005434066818	30632	Economy	14000.00
0005432527013	30632	Economy	14000.00
0005432526868	30632	Economy	14000.00
0005432527451	30632	Economy	14000.00
0005432527314	30632	Economy	14000.00
0005434067235	30632	Economy	14000.00
0005432526843	30632	Economy	14000.00
0005432527075	30632	Economy	14000.00
0005432211517	30632	Economy	14000.00
0005435213648	30632	Economy	14000.00
0005435213712	30632	Economy	14000.00
0005434067066	30632	Economy	14000.00
0005435213669	30632	Economy	14000.00
0005432428910	30632	Economy	14000.00
0005432527250	30632	Economy	14000.00
0005434067045	30632	Economy	14000.00
0005435213668	30632	Economy	14000.00
0005432527088	30632	Economy	14000.00
0005432526462	30632	Economy	14000.00
0005432527074	30632	Economy	14000.00
0005432526899	30632	Economy	14000.00
0005432527417	30632	Economy	14000.00
0005432428918	30632	Economy	14000.00
0005432527243	30632	Economy	14000.00
0005432526943	30632	Economy	14000.00
0005434066941	30632	Economy	14000.00
0005432526869	30632	Economy	14000.00
0005434067092	30632	Economy	14000.00
0005432526871	30632	Economy	14000.00
0005432533272	30632	Economy	14000.00
0005435213658	30632	Economy	14000.00
0005432527569	30632	Economy	14000.00
0005432527377	30632	Economy	14000.00
0005435213710	30632	Economy	14000.00
0005435213660	30632	Economy	14000.00
0005432526853	30632	Economy	14000.00
0005432527028	30632	Economy	14000.00
0005432428917	30632	Economy	14000.00
0005432527099	30632	Economy	14000.00
0005435213670	30632	Economy	14000.00
0005432211515	30632	Economy	14000.00
0005435213702	30632	Economy	14000.00
0005432535781	30632	Economy	14000.00
0005435213695	30632	Economy	14000.00
0005432537038	30632	Economy	14000.00
0005432527009	30632	Economy	14000.00
0005434066970	30632	Economy	14000.00
0005434066878	30632	Economy	14000.00
0005434067180	30632	Economy	14000.00
0005435213700	30632	Economy	14000.00
0005432527432	30632	Economy	14000.00
0005432526683	30632	Economy	14000.00
0005432527338	30632	Economy	14000.00
0005435725610	30632	Economy	14000.00
0005435213706	30632	Economy	14000.00
0005432211514	30632	Economy	14000.00
0005434066731	30632	Economy	14000.00
0005432527548	30632	Economy	14000.00
0005432527329	30632	Economy	14000.00
0005434066811	30632	Economy	14000.00
0005432527026	30632	Economy	14000.00
0005434066801	30632	Economy	14000.00
0005434067236	30632	Economy	14000.00
0005435213653	30632	Economy	14000.00
0005432535783	30632	Economy	14000.00
0005432526997	30632	Economy	14000.00
0005435630974	30632	Economy	14000.00
0005435213682	30632	Economy	14000.00
0005432535795	30632	Economy	14000.00
0005435213672	30632	Economy	14000.00
0005432527195	30632	Economy	14000.00
0005432527449	30632	Economy	14000.00
0005434067264	30632	Economy	14000.00
0005434067210	30632	Economy	14000.00
0005432527403	30632	Economy	14000.00
0005435652766	24850	Business	9800.00
0005435652644	24850	Business	9800.00
0005433367958	24850	Business	9800.00
0005435652816	24850	Business	9800.00
0005433367963	24850	Business	9800.00
0005433367948	24850	Business	9800.00
0005435652745	24850	Business	9800.00
0005435652820	24850	Business	9800.00
0005435652777	24850	Business	9800.00
0005435652826	24850	Business	9800.00
0005433367950	24850	Economy	3300.00
0005435652596	24850	Economy	3300.00
0005433367967	24850	Economy	3300.00
0005435652801	24850	Economy	3300.00
0005433367964	24850	Economy	3300.00
0005433367966	24850	Economy	3300.00
0005433367965	24850	Economy	3300.00
0005433367957	24850	Economy	3300.00
0005433367979	24850	Economy	3300.00
0005435652800	24850	Economy	3300.00
0005435652706	24850	Economy	3600.00
0005433367983	24850	Economy	3600.00
0005435652783	24850	Economy	3600.00
0005435652571	24850	Economy	3300.00
0005435652769	24850	Economy	3300.00
0005435652651	24850	Economy	3300.00
0005433367971	24850	Economy	3300.00
0005433367977	24850	Economy	3300.00
0005435652623	24850	Economy	3300.00
0005435652776	24850	Economy	3300.00
0005433367974	24850	Economy	3300.00
0005435652536	24850	Economy	3300.00
0005435652746	24850	Economy	3300.00
0005433367986	24850	Economy	3300.00
0005433367960	24850	Economy	3300.00
0005435652770	24850	Economy	3300.00
0005435652625	24850	Economy	3300.00
0005433367978	24850	Economy	3300.00
0005433367949	24850	Economy	3300.00
0005435652681	24850	Economy	3300.00
0005433367969	24850	Economy	3300.00
0005433367972	24850	Economy	3300.00
0005433367959	24850	Economy	3300.00
0005435652535	24850	Economy	3300.00
0005433367951	24850	Economy	3300.00
0005435652701	24850	Economy	3300.00
0005433367980	24850	Economy	3300.00
0005435652686	24850	Economy	3300.00
0005433367975	24850	Economy	3300.00
0005435652707	24850	Economy	3300.00
0005435652677	24850	Economy	3300.00
0005433367955	24850	Economy	3300.00
0005435652731	24850	Economy	3300.00
0005433367962	24850	Economy	3300.00
0005435652624	24850	Economy	3300.00
0005435652590	24850	Economy	3300.00
0005433367953	24850	Economy	3300.00
0005435652552	24850	Economy	3300.00
0005435652737	24850	Economy	3300.00
0005433367968	24850	Economy	3300.00
0005435652595	24850	Economy	3300.00
0005433367976	24850	Economy	3300.00
0005433367973	24850	Economy	3300.00
0005433367956	24850	Economy	3300.00
0005433367984	24850	Economy	3300.00
0005433367982	24850	Economy	3300.00
0005433367970	24850	Economy	3300.00
0005435652655	24850	Economy	3300.00
0005433367985	24850	Economy	3300.00
0005433367952	24850	Economy	3300.00
0005435652717	24850	Economy	3300.00
0005435652561	24850	Economy	3300.00
0005435652835	24850	Economy	3300.00
0005435652827	24850	Economy	3300.00
0005435652819	24850	Economy	3300.00
0005435652685	24850	Economy	3300.00
0005435652691	24850	Economy	3300.00
0005433367961	24850	Economy	3300.00
0005433367954	24850	Economy	3300.00
0005435652822	24850	Economy	3300.00
0005435652738	24850	Economy	3300.00
0005435652810	24850	Economy	3300.00
0005435652440	24850	Economy	3300.00
0005435652621	24850	Economy	3300.00
0005435652676	24850	Economy	3300.00
0005433367981	24850	Economy	3300.00
0005434979837	2040	Economy	10500.00
0005434979848	2040	Economy	10500.00
0005434979853	2040	Economy	9500.00
0005435801701	2040	Economy	9500.00
0005434979860	2040	Economy	9500.00
0005434979852	2040	Economy	9500.00
0005434979859	2040	Economy	9500.00
0005434979856	2040	Economy	9500.00
0005434979866	2040	Economy	9500.00
0005434979857	2040	Economy	9500.00
0005434979862	2040	Economy	9500.00
0005434979844	2040	Economy	9500.00
0005434979865	2040	Economy	9500.00
0005434979863	2040	Economy	9500.00
0005435801702	2040	Economy	9500.00
0005435801703	2040	Economy	9500.00
0005434979843	2040	Economy	9500.00
0005434979855	2040	Economy	9500.00
0005434979864	2040	Economy	9500.00
0005434979851	2040	Economy	9500.00
0005434979841	2040	Economy	9500.00
0005434979840	2040	Economy	9500.00
0005434979845	2040	Economy	9500.00
0005434979849	2040	Economy	9500.00
0005434979838	2040	Economy	9500.00
0005434979858	2040	Economy	9500.00
0005435801705	2040	Economy	9500.00
0005435801704	2040	Economy	9500.00
0005434979847	2040	Economy	9500.00
0005434979854	2040	Economy	9500.00
0005434979850	2040	Economy	9500.00
0005434979842	2040	Economy	9500.00
0005434979839	2040	Economy	9500.00
0005434979861	2040	Economy	9500.00
0005434979846	2040	Economy	9500.00
0005434979620	23527	Economy	10500.00
0005434979582	23527	Economy	10500.00
0005434979573	23527	Economy	10500.00
0005434979492	23527	Economy	10500.00
0005434979570	23527	Economy	9500.00
0005434979595	23527	Economy	9500.00
0005434979586	23527	Economy	9500.00
0005434979587	23527	Economy	9500.00
0005435801671	23527	Economy	9500.00
0005434979606	23527	Economy	9500.00
0005434979525	23527	Economy	9500.00
0005434979546	23527	Economy	9500.00
0005434979376	23527	Economy	9500.00
0005434979557	23527	Economy	9500.00
0005434979612	23527	Economy	9500.00
0005434979584	23527	Economy	9500.00
0005434979515	23527	Economy	9500.00
0005434979516	23527	Economy	9500.00
0005434979545	23527	Economy	9500.00
0005434979500	23527	Economy	9500.00
0005434979608	23527	Economy	9500.00
0005434979585	23527	Economy	9500.00
0005434979583	23527	Economy	9500.00
0005434979501	23527	Economy	9500.00
0005434979491	23527	Economy	9500.00
0005434979621	23527	Economy	9500.00
0005434979293	23527	Economy	9500.00
0005434979556	23527	Economy	9500.00
0005434979507	23527	Economy	9500.00
0005434979555	23527	Economy	9500.00
0005434979510	23527	Economy	9500.00
0005434979554	23527	Economy	9500.00
0005434952540	2617	Economy	5300.00
0005434952537	2617	Economy	5300.00
0005434952539	2617	Economy	5300.00
0005434952541	2617	Economy	5300.00
0005434952538	2617	Economy	5300.00
0005433256425	28213	Economy	5300.00
0005434952505	28213	Economy	5300.00
0005434952503	28213	Economy	5300.00
0005433256426	28213	Economy	5300.00
0005434952500	28213	Economy	5300.00
0005433256427	28213	Economy	5300.00
0005433111510	19752	Economy	8700.00
0005433111511	19752	Economy	8700.00
0005433112379	19752	Economy	8700.00
0005434137504	11959	Business	9700.00
0005434137600	11959	Business	9700.00
0005434137337	11959	Business	9700.00
0005434137623	11959	Business	9700.00
0005434137764	11959	Business	9700.00
0005434137707	11959	Business	9700.00
0005434137543	11959	Business	9700.00
0005434137575	11959	Business	9700.00
0005434137313	11959	Business	9700.00
0005434137668	11959	Business	9700.00
0005434137510	11959	Business	9700.00
0005434137874	11959	Economy	3200.00
0005434137515	11959	Economy	3200.00
0005434137588	11959	Economy	3200.00
0005434137875	11959	Economy	3200.00
0005434136882	11959	Economy	3200.00
0005434137418	11959	Economy	3200.00
0005434137858	11959	Economy	3200.00
0005434137419	11959	Economy	3200.00
0005434137500	11959	Economy	3200.00
0005434137831	11959	Economy	3500.00
0005434137412	11959	Economy	3500.00
0005434137778	11959	Economy	3500.00
0005434137837	11959	Economy	3500.00
0005434137026	11959	Economy	3500.00
0005434137817	11959	Economy	3200.00
0005434137291	11959	Economy	3200.00
0005434137739	11959	Economy	3200.00
0005434137736	11959	Economy	3200.00
0005434137807	11959	Economy	3200.00
0005434137570	11959	Economy	3200.00
0005434137622	11959	Economy	3200.00
0005434137862	11959	Economy	3200.00
0005434137610	11959	Economy	3200.00
0005434137499	11959	Economy	3200.00
0005434137675	11959	Economy	3200.00
0005434137734	11959	Economy	3200.00
0005434137511	11959	Economy	3200.00
0005434137801	11959	Economy	3200.00
0005434137183	11959	Economy	3200.00
0005434137629	11959	Economy	3200.00
0005434137697	11959	Economy	3200.00
0005434137360	11959	Economy	3200.00
0005434137732	11959	Economy	3200.00
0005434137560	11959	Economy	3200.00
0005434137809	11959	Economy	3200.00
0005434137258	11959	Economy	3200.00
0005434137444	11959	Economy	3200.00
0005434137503	11959	Economy	3200.00
0005434137876	11959	Economy	3200.00
0005434137498	11959	Economy	3200.00
0005434137863	11959	Economy	3200.00
0005434137733	11959	Economy	3200.00
0005434137469	11959	Economy	3200.00
0005434137445	11959	Economy	3200.00
0005434137446	11959	Economy	3200.00
0005434137598	11959	Economy	3200.00
0005434137599	11959	Economy	3200.00
0005434137667	11959	Economy	3200.00
0005434137880	11959	Economy	3200.00
0005434137823	11959	Economy	3200.00
0005434137735	11959	Economy	3200.00
0005434137585	11959	Economy	3200.00
0005434137559	11959	Economy	3200.00
0005434137615	11959	Economy	3200.00
0005434137674	11959	Economy	3200.00
0005434137808	11959	Economy	3200.00
0005434137824	11959	Economy	3200.00
0005434137836	11959	Economy	3200.00
0005434137601	11959	Economy	3200.00
0005434137607	11959	Economy	3200.00
0005434137606	11959	Economy	3200.00
0005434137586	11959	Economy	3200.00
0005434137763	11959	Economy	3200.00
0005434137718	11959	Economy	3200.00
0005434137609	11959	Economy	3200.00
0005434137627	11959	Economy	3200.00
0005434137628	11959	Economy	3200.00
0005434137338	11959	Economy	3200.00
0005434137415	11959	Economy	3200.00
0005434137608	11959	Economy	3200.00
0005434137262	11959	Economy	3200.00
0005434137073	11959	Economy	3200.00
0005434137587	11959	Economy	3200.00
0005434138301	28710	Business	9700.00
0005434138278	28710	Business	9700.00
0005434138292	28710	Business	9700.00
0005434138235	28710	Business	9700.00
0005434138262	28710	Business	9700.00
0005434138269	28710	Business	9700.00
0005434138270	28710	Business	9700.00
0005434138293	28710	Business	9700.00
0005434138247	28710	Business	9700.00
0005434138289	28710	Business	9700.00
0005434138298	28710	Business	9700.00
0005434138260	28710	Economy	3200.00
0005434138219	28710	Economy	3200.00
0005434138238	28710	Economy	3200.00
0005434138251	28710	Economy	3200.00
0005434138229	28710	Economy	3200.00
0005434138224	28710	Economy	3200.00
0005434138245	28710	Economy	3200.00
0005434138239	28710	Economy	3200.00
0005434138252	28710	Economy	3200.00
0005434138281	28710	Economy	3200.00
0005434138261	28710	Economy	3500.00
0005434138275	28710	Economy	3500.00
0005434138256	28710	Economy	3500.00
0005434138273	28710	Economy	3500.00
0005434138220	28710	Economy	3200.00
0005434138225	28710	Economy	3200.00
0005434138258	28710	Economy	3200.00
0005434138243	28710	Economy	3200.00
0005434138299	28710	Economy	3200.00
0005434138255	28710	Economy	3200.00
0005434138303	28710	Economy	3200.00
0005434138300	28710	Economy	3200.00
0005434138296	28710	Economy	3200.00
0005434138249	28710	Economy	3200.00
0005434138271	28710	Economy	3200.00
0005434138287	28710	Economy	3200.00
0005434138241	28710	Economy	3200.00
0005434138236	28710	Economy	3200.00
0005434138226	28710	Economy	3200.00
0005434138230	28710	Economy	3200.00
0005434138284	28710	Economy	3200.00
0005434138279	28710	Economy	3200.00
0005434138297	28710	Economy	3200.00
0005434138268	28710	Economy	3200.00
0005434138295	28710	Economy	3200.00
0005434138263	28710	Economy	3200.00
0005434138216	28710	Economy	3200.00
0005434138265	28710	Economy	3200.00
0005434138302	28710	Economy	3200.00
0005434138283	28710	Economy	3200.00
0005434138266	28710	Economy	3200.00
0005434138231	28710	Economy	3200.00
0005434138215	28710	Economy	3200.00
0005434138228	28710	Economy	3200.00
0005434138232	28710	Economy	3200.00
0005434138221	28710	Economy	3200.00
0005434138294	28710	Economy	3200.00
0005434138242	28710	Economy	3200.00
0005434138248	28710	Economy	3200.00
0005434138253	28710	Economy	3200.00
0005434138222	28710	Economy	3200.00
0005434138254	28710	Economy	3200.00
0005434138290	28710	Economy	3200.00
0005434138267	28710	Economy	3200.00
0005434138246	28710	Economy	3200.00
0005434138259	28710	Economy	3200.00
0005434138264	28710	Economy	3200.00
0005434138304	28710	Economy	3200.00
0005434138272	28710	Economy	3200.00
0005434138233	28710	Economy	3200.00
0005434138282	28710	Economy	3200.00
0005434138285	28710	Economy	3200.00
0005434138227	28710	Economy	3200.00
0005434138305	28710	Economy	3200.00
0005434138240	28710	Economy	3200.00
0005434138257	28710	Economy	3200.00
0005434138277	28710	Economy	3200.00
0005434138234	28710	Economy	3200.00
0005434138250	28710	Economy	3200.00
0005434138218	28710	Economy	3200.00
0005434138217	28710	Economy	3200.00
0005434138286	28710	Economy	3200.00
0005434138276	28710	Economy	3200.00
0005434138288	28710	Economy	3200.00
0005434138223	28710	Economy	3200.00
0005434138291	28710	Economy	3200.00
0005434138237	28710	Economy	3200.00
0005434138244	28710	Economy	3200.00
0005434138280	28710	Economy	3200.00
0005434138274	28710	Economy	3200.00
0005433534503	6792	Economy	9900.00
0005433538885	6792	Economy	9900.00
0005433538891	6792	Economy	9900.00
0005433538892	6792	Economy	9900.00
0005433538889	6792	Economy	9900.00
0005433538890	6792	Economy	9900.00
0005433538888	6792	Economy	9900.00
0005433538887	6792	Economy	9900.00
0005433534502	6792	Economy	9900.00
0005433538884	6792	Economy	9900.00
0005435259738	6792	Economy	9900.00
0005433538886	6792	Economy	9900.00
0005433538817	25019	Economy	9900.00
0005435259767	25019	Economy	9900.00
0005433538792	25019	Economy	9900.00
0005435259766	25019	Economy	9900.00
0005433538820	25019	Economy	9900.00
0005433538816	25019	Economy	9900.00
0005435259764	25019	Economy	9900.00
0005433538793	25019	Economy	9900.00
0005433538822	25019	Economy	9900.00
0005433538821	25019	Economy	9900.00
0005433538783	25019	Economy	9900.00
0005433538777	25019	Economy	9900.00
0005435259765	25019	Economy	9900.00
0005433511967	811	Economy	16100.00
0005433511971	811	Economy	16100.00
0005433511970	811	Economy	14600.00
0005433511972	811	Economy	14600.00
0005432922502	811	Economy	14600.00
0005432922495	811	Economy	14600.00
0005433511968	811	Economy	14600.00
0005432922494	811	Economy	14600.00
0005433511969	811	Economy	14600.00
0005432922490	811	Economy	14600.00
0005433511927	16159	Economy	16100.00
0005432922533	16159	Economy	16100.00
0005433511887	16159	Economy	14600.00
0005433511925	16159	Economy	14600.00
0005433511915	16159	Economy	14600.00
0005433511924	16159	Economy	14600.00
0005433511889	16159	Economy	14600.00
0005433511923	16159	Economy	14600.00
0005432922535	16159	Economy	14600.00
0005432922534	16159	Economy	14600.00
0005435852563	4032	Economy	12300.00
0005433475713	4032	Economy	12300.00
0005433475712	4032	Economy	12300.00
0005433475716	4032	Economy	12300.00
0005433475707	4032	Economy	12300.00
0005435852553	4032	Economy	12300.00
0005435852558	4032	Economy	12300.00
0005435852557	4032	Economy	12300.00
0005433475714	4032	Economy	12300.00
0005433475711	4032	Economy	12300.00
0005435852556	4032	Economy	12300.00
0005435852545	4032	Economy	12300.00
0005435852547	4032	Economy	12300.00
0005435852548	4032	Economy	12300.00
0005433475718	4032	Economy	12300.00
0005433475715	4032	Economy	12300.00
0005435852549	4032	Economy	12300.00
0005433475709	4032	Economy	12300.00
0005433475717	4032	Economy	12300.00
0005435852555	4032	Economy	12300.00
0005433475710	4032	Economy	12300.00
0005433475708	4032	Economy	12300.00
0005435697412	3688	Economy	7900.00
0005435697408	3688	Economy	7900.00
0005435697411	3688	Economy	7900.00
0005435697391	3688	Economy	7200.00
0005435697409	3688	Economy	7200.00
0005435697405	3688	Economy	7200.00
0005434950537	3688	Economy	7200.00
0005435697396	3688	Economy	7200.00
0005435697402	3688	Economy	7200.00
0005435935027	3688	Economy	7200.00
0005435697394	3688	Economy	7200.00
0005435697414	3688	Economy	7200.00
0005435935036	3688	Economy	7200.00
0005434950538	3688	Economy	7200.00
0005435697413	3688	Economy	7200.00
0005435697399	3688	Economy	7200.00
0005435697393	3688	Economy	7200.00
0005435697416	3688	Economy	7200.00
0005435697401	3688	Economy	7200.00
0005435697398	3688	Economy	7200.00
0005435697397	3688	Economy	7200.00
0005435697407	3688	Economy	7200.00
0005435697403	3688	Economy	7200.00
0005435697395	3688	Economy	7200.00
0005434950539	3688	Economy	7200.00
0005435935025	3688	Economy	7200.00
0005435697415	3688	Economy	7200.00
0005435697406	3688	Economy	7200.00
0005435935037	3688	Economy	7200.00
0005435916164	3688	Economy	7200.00
0005435916165	3688	Economy	7200.00
0005435697390	3688	Economy	7200.00
0005435697392	3688	Economy	7200.00
0005435697410	3688	Economy	7200.00
0005435697404	3688	Economy	7200.00
0005435935026	3688	Economy	7200.00
0005435697400	3688	Economy	7200.00
0005434950540	3688	Economy	7200.00
0005435697106	16273	Economy	7900.00
0005435697129	16273	Economy	7900.00
0005435697155	16273	Economy	7900.00
0005435697092	16273	Economy	7200.00
0005435697180	16273	Economy	7200.00
0005435697171	16273	Economy	7200.00
0005435916174	16273	Economy	7200.00
0005435697089	16273	Economy	7200.00
0005435697136	16273	Economy	7200.00
0005435697222	16273	Economy	7200.00
0005435697192	16273	Economy	7200.00
0005435697206	16273	Economy	7200.00
0005435697221	16273	Economy	7200.00
0005435697162	16273	Economy	7200.00
0005435697161	16273	Economy	7200.00
0005434950515	16273	Economy	7200.00
0005435697105	16273	Economy	7200.00
0005435697157	16273	Economy	7200.00
0005435697130	16273	Economy	7200.00
0005435935049	16273	Economy	7200.00
0005435697087	16273	Economy	7200.00
0005435697167	16273	Economy	7200.00
0005435697135	16273	Economy	7200.00
0005435697179	16273	Economy	7200.00
0005435916173	16273	Economy	7200.00
0005435697207	16273	Economy	7200.00
0005435697298	16273	Economy	7200.00
0005435697154	16273	Economy	7200.00
0005435697191	16273	Economy	7200.00
0005434950507	16273	Economy	7200.00
0005435697093	16273	Economy	7200.00
0005435935050	16273	Economy	7200.00
0005435697122	16273	Economy	7200.00
0005435697299	16273	Economy	7200.00
0005435697160	16273	Economy	7200.00
0005435696965	16273	Economy	7200.00
0005435697133	16273	Economy	7200.00
0005435935051	16273	Economy	7200.00
0005435697247	16273	Economy	7200.00
0005435697156	16273	Economy	7200.00
0005435697199	16273	Economy	7200.00
0005435935048	16273	Economy	7200.00
0005432609741	3967	Economy	21300.00
0005433519469	3967	Economy	21300.00
0005433519466	3967	Economy	21300.00
0005435853595	3967	Economy	19300.00
0005434606835	3967	Economy	19300.00
0005433519465	3967	Economy	19300.00
0005433519468	3967	Economy	19300.00
0005434604908	3967	Economy	19300.00
0005432609740	3967	Economy	19300.00
0005435841467	3967	Economy	19300.00
0005434604906	3967	Economy	19300.00
0005435853603	3967	Economy	19300.00
0005432609739	3967	Economy	19300.00
0005435904893	3967	Economy	19300.00
0005435841469	3967	Economy	19300.00
0005435853604	3967	Economy	19300.00
0005432607574	3967	Economy	19300.00
0005434604905	3967	Economy	19300.00
0005434604907	3967	Economy	19300.00
0005434606836	3967	Economy	19300.00
0005433519467	3967	Economy	19300.00
0005434606834	3967	Economy	19300.00
0005435841468	3967	Economy	19300.00
0005432607575	3967	Economy	19300.00
0005432607573	3967	Economy	19300.00
0005434604904	3967	Economy	19300.00
0005432607576	3967	Economy	19300.00
0005435853594	3967	Economy	19300.00
0005433519400	22051	Economy	21300.00
0005435904895	22051	Economy	19300.00
0005435853615	22051	Economy	19300.00
0005434606794	22051	Economy	19300.00
0005435853614	22051	Economy	19300.00
0005433519431	22051	Economy	19300.00
0005433348946	771	Economy	3700.00
0005433348949	771	Economy	3700.00
0005433348976	771	Economy	3700.00
0005433348943	771	Economy	3700.00
0005433348957	771	Economy	3700.00
0005433348945	771	Economy	3700.00
0005433348973	771	Economy	3700.00
0005433348948	771	Economy	3700.00
0005433348955	771	Economy	3700.00
0005433348956	771	Economy	3700.00
0005433348975	771	Economy	3700.00
0005433349001	15967	Economy	3700.00
0005433349002	15967	Economy	3700.00
0005435628705	15967	Economy	3700.00
0005433349000	15967	Economy	3700.00
0005433349003	15967	Economy	3700.00
0005433349004	15967	Economy	3700.00
0005435628706	15967	Economy	3700.00
0005433349005	15967	Economy	3700.00
0005433158110	17236	Economy	7100.00
0005434445250	17236	Economy	7100.00
0005433159301	17236	Economy	7100.00
0005434445249	17236	Economy	7100.00
0005434445251	17236	Economy	7100.00
0005433159291	17236	Economy	7100.00
0005433158116	17236	Economy	7100.00
0005433158109	17236	Economy	7100.00
0005433158111	17236	Economy	7100.00
0005434446520	17236	Economy	7100.00
0005433159317	17617	Economy	7100.00
0005433159319	17617	Economy	7100.00
0005434445225	17617	Economy	7100.00
0005433159318	17617	Economy	7100.00
0005435383112	7901	Economy	5900.00
0005435132908	7901	Economy	5400.00
0005435383116	7901	Economy	5400.00
0005435132907	7901	Economy	5400.00
0005435132902	7901	Economy	5400.00
0005435383115	7901	Economy	5400.00
0005435132910	7901	Economy	5400.00
0005435383113	7901	Economy	5400.00
0005435132903	7901	Economy	5400.00
0005435132905	7901	Economy	5400.00
0005435132900	7901	Economy	5400.00
0005435383111	7901	Economy	5400.00
0005435132901	7901	Economy	5400.00
0005435132909	7901	Economy	5400.00
0005435132904	7901	Economy	5400.00
0005435132906	7901	Economy	5400.00
0005435132798	33072	Economy	5900.00
0005435132742	33072	Economy	5900.00
0005435383161	33072	Economy	5400.00
0005435132818	33072	Economy	5400.00
0005435132772	33072	Economy	5400.00
0005435132828	33072	Economy	5400.00
0005435132799	33072	Economy	5400.00
0005435132829	33072	Economy	5400.00
0005435132804	33072	Economy	5400.00
0005435132830	33072	Economy	5400.00
0005435383163	33072	Economy	5400.00
0005435132743	33072	Economy	5400.00
0005435132839	33072	Economy	5400.00
0005435132835	33072	Economy	5400.00
0005435132803	33072	Economy	5400.00
0005435132819	33072	Economy	5400.00
0005435132817	33072	Economy	5400.00
0005435383160	33072	Economy	5400.00
0005435132771	33072	Economy	5400.00
0005435383162	33072	Economy	5400.00
0005435383159	33072	Economy	5400.00
0005435383164	33072	Economy	5400.00
0005435390198	7481	Economy	13800.00
0005435160329	7481	Economy	13800.00
0005435390186	7481	Economy	12500.00
0005435390162	7481	Economy	12500.00
0005435160327	7481	Economy	12500.00
0005435390163	7481	Economy	12500.00
0005435160326	7481	Economy	12500.00
0005435160322	7481	Economy	12500.00
0005435160324	7481	Economy	12500.00
0005435160332	7481	Economy	12500.00
0005435160323	7481	Economy	12500.00
0005435160330	7481	Economy	12500.00
0005435160325	7481	Economy	12500.00
0005435160328	7481	Economy	12500.00
0005435160331	7481	Economy	12500.00
0005435390231	7481	Economy	12500.00
0005435160321	7481	Economy	12500.00
0005435390156	7481	Economy	12500.00
0005435390258	29584	Economy	13800.00
0005435390254	29584	Economy	12500.00
0005435160243	29584	Economy	12500.00
0005435390255	29584	Economy	12500.00
0005435160254	29584	Economy	12500.00
0005435390257	29584	Economy	12500.00
0005435160224	29584	Economy	12500.00
0005435160231	29584	Economy	12500.00
0005435390253	29584	Economy	12500.00
0005435160252	29584	Economy	12500.00
0005435390256	29584	Economy	12500.00
0005435160226	29584	Economy	12500.00
0005435390252	29584	Economy	12500.00
0005435160276	29584	Economy	12500.00
0005435160253	29584	Economy	12500.00
0005432398175	18484	Economy	4900.00
0005432394072	18484	Economy	4900.00
0005432394091	18484	Economy	4900.00
0005432394069	18484	Economy	4900.00
0005435178499	18484	Economy	4900.00
0005432394066	18484	Economy	4900.00
0005432394090	18484	Economy	4900.00
0005435178500	18484	Economy	4900.00
0005432394070	18484	Economy	4900.00
0005432398174	18484	Economy	4900.00
0005432398188	18484	Economy	4900.00
0005432394071	18484	Economy	4900.00
0005432400128	27157	Economy	4900.00
0005432400130	27157	Economy	4900.00
0005432398202	27157	Economy	4900.00
0005432400126	27157	Economy	4900.00
0005432400129	27157	Economy	4900.00
0005432400127	27157	Economy	4900.00
0005432398201	27157	Economy	4900.00
0005432398203	27157	Economy	4900.00
0005435178483	27157	Economy	4900.00
0005432398200	27157	Economy	4900.00
0005434191269	9726	Economy	4400.00
0005434191272	9726	Economy	4400.00
0005434191270	9726	Economy	4400.00
0005434504243	6525	Business	48400.00
0005434504255	6525	Business	48400.00
0005434504240	6525	Business	48400.00
0005435103950	6525	Business	48400.00
0005434504259	6525	Business	48400.00
0005435103951	6525	Economy	16100.00
0005434504234	6525	Economy	16100.00
0005434504237	6525	Economy	16100.00
0005434504241	6525	Economy	16100.00
0005434504242	6525	Economy	16100.00
0005434504228	6525	Economy	16100.00
0005434504235	6525	Economy	16100.00
0005434504239	6525	Economy	17800.00
0005434504232	6525	Economy	17800.00
0005434504252	6525	Economy	16100.00
0005434504260	6525	Economy	16100.00
0005434504246	6525	Economy	16100.00
0005434504256	6525	Economy	16100.00
0005434504247	6525	Economy	16100.00
0005434504257	6525	Economy	16100.00
0005434504236	6525	Economy	16100.00
0005434504227	6525	Economy	16100.00
0005434504249	6525	Economy	16100.00
0005434504251	6525	Economy	16100.00
0005434504245	6525	Economy	16100.00
0005434504244	6525	Economy	16100.00
0005434504229	6525	Economy	16100.00
0005434504233	6525	Economy	16100.00
0005434504238	6525	Economy	16100.00
0005435103953	6525	Economy	16100.00
0005434504254	6525	Economy	16100.00
0005434504258	6525	Economy	16100.00
0005434504231	6525	Economy	16100.00
0005434504253	6525	Economy	16100.00
0005434504230	6525	Economy	16100.00
0005434504226	6525	Economy	16100.00
0005434504248	6525	Economy	16100.00
0005434504250	6525	Economy	16100.00
0005435103952	6525	Economy	16100.00
0005434503863	22634	Business	48400.00
0005434503813	22634	Business	48400.00
0005434503832	22634	Business	48400.00
0005434503830	22634	Business	48400.00
0005434503888	22634	Business	48400.00
0005434503908	22634	Business	48400.00
0005434503814	22634	Economy	16100.00
0005434503843	22634	Economy	16100.00
0005434503913	22634	Economy	16100.00
0005434503938	22634	Economy	16100.00
0005434503953	22634	Economy	17800.00
0005434503857	22634	Economy	17800.00
0005434503866	22634	Economy	17800.00
0005434503890	22634	Economy	17800.00
0005434503848	22634	Economy	16100.00
0005434503838	22634	Economy	16100.00
0005434503952	22634	Economy	16100.00
0005434503720	22634	Economy	16100.00
0005434503842	22634	Economy	16100.00
0005434503950	22634	Economy	16100.00
0005434503740	22634	Economy	16100.00
0005434503887	22634	Economy	16100.00
0005434503954	22634	Economy	16100.00
0005434503560	22634	Economy	16100.00
0005434503865	22634	Economy	16100.00
0005434503939	22634	Economy	16100.00
0005434503820	22634	Economy	16100.00
0005435103839	22634	Economy	16100.00
0005434503893	22634	Economy	16100.00
0005434503831	22634	Economy	16100.00
0005434503698	22634	Economy	16100.00
0005434503849	22634	Economy	16100.00
0005434503949	22634	Economy	16100.00
0005434503561	22634	Economy	16100.00
0005434503597	22634	Economy	16100.00
0005434503936	22634	Economy	16100.00
0005434503909	22634	Economy	16100.00
0005434503891	22634	Economy	16100.00
0005434503739	22634	Economy	16100.00
0005434503676	22634	Economy	16100.00
0005434503951	22634	Economy	16100.00
0005434503862	22634	Economy	16100.00
0005434503856	22634	Economy	16100.00
0005434503912	22634	Economy	16100.00
0005434503802	22634	Economy	16100.00
0005434503907	22634	Economy	16100.00
0005433367645	1676	Business	50000.00
0005435653141	1676	Business	50000.00
0005435653161	1676	Business	50000.00
0005435653144	1676	Business	50000.00
0005433367535	1676	Business	50000.00
0005435653165	1676	Business	50000.00
0005435653183	1676	Business	50000.00
0005435653187	1676	Business	50000.00
0005435653177	1676	Business	50000.00
0005435653140	1676	Business	50000.00
0005435653143	1676	Business	50000.00
0005435653179	1676	Economy	16700.00
0005433367719	1676	Economy	16700.00
0005433367772	1676	Economy	16700.00
0005433367501	1676	Economy	16700.00
0005435653168	1676	Economy	16700.00
0005435653147	1676	Economy	16700.00
0005433367641	1676	Economy	16700.00
0005435653185	1676	Economy	16700.00
0005435653150	1676	Economy	16700.00
0005433367812	1676	Economy	18300.00
0005435653172	1676	Economy	18300.00
0005433367502	1676	Economy	18300.00
0005433367407	1676	Economy	18300.00
0005433367667	1676	Economy	16700.00
0005435653174	1676	Economy	16700.00
0005433367696	1676	Economy	16700.00
0005433367529	1676	Economy	16700.00
0005435653188	1676	Economy	16700.00
0005435653156	1676	Economy	16700.00
0005435653154	1676	Economy	16700.00
0005435653184	1676	Economy	16700.00
0005433367534	1676	Economy	16700.00
0005433367619	1676	Economy	16700.00
0005435653170	1676	Economy	16700.00
0005435653139	1676	Economy	16700.00
0005435653182	1676	Economy	16700.00
0005435653155	1676	Economy	16700.00
0005433367707	1676	Economy	16700.00
0005435653191	1676	Economy	16700.00
0005435653186	1676	Economy	16700.00
0005433367665	1676	Economy	16700.00
0005433367680	1676	Economy	16700.00
0005435653190	1676	Economy	16700.00
0005433367657	1676	Economy	16700.00
0005435653158	1676	Economy	16700.00
0005435653152	1676	Economy	16700.00
0005435653160	1676	Economy	16700.00
0005435653149	1676	Economy	16700.00
0005435653159	1676	Economy	16700.00
0005435653164	1676	Economy	16700.00
0005435653167	1676	Economy	16700.00
0005435653153	1676	Economy	16700.00
0005435653180	1676	Economy	16700.00
0005435653181	1676	Economy	16700.00
0005433367642	1676	Economy	16700.00
0005435653176	1676	Economy	16700.00
0005435653169	1676	Economy	16700.00
0005435653166	1676	Economy	16700.00
0005435653148	1676	Economy	16700.00
0005433367666	1676	Economy	16700.00
0005435653151	1676	Economy	16700.00
0005435653146	1676	Economy	16700.00
0005433367689	1676	Economy	16700.00
0005435653173	1676	Economy	16700.00
0005433367408	1676	Economy	16700.00
0005433367771	1676	Economy	16700.00
0005433367757	1676	Economy	16700.00
0005433367695	1676	Economy	16700.00
0005433367681	1676	Economy	16700.00
0005433367791	1676	Economy	16700.00
0005433367652	1676	Economy	16700.00
0005433367811	1676	Economy	16700.00
0005435653145	1676	Economy	16700.00
0005435653175	1676	Economy	16700.00
0005433367586	1676	Economy	16700.00
0005435653171	1676	Economy	16700.00
0005435653142	1676	Economy	16700.00
0005435653163	1676	Economy	16700.00
0005433367409	1676	Economy	16700.00
0005435653178	1676	Economy	16700.00
0005433367613	1676	Economy	16700.00
0005435653157	1676	Economy	16700.00
0005435653162	1676	Economy	16700.00
0005435653189	1676	Economy	16700.00
0005433367813	1676	Economy	16700.00
0005433367487	1676	Economy	16700.00
0005433367954	21698	Business	50000.00
0005435652746	21698	Business	50000.00
0005435652822	21698	Business	50000.00
0005435652561	21698	Business	50000.00
0005435652655	21698	Business	50000.00
0005435652596	21698	Business	50000.00
0005433367983	21698	Business	50000.00
0005435652624	21698	Business	50000.00
0005435652777	21698	Business	50000.00
0005435652686	21698	Business	50000.00
0005433367981	21698	Business	50000.00
0005433367969	21698	Business	50000.00
0005433367964	21698	Economy	16700.00
0005433367974	21698	Economy	16700.00
0005433367956	21698	Economy	16700.00
0005433367985	21698	Economy	16700.00
0005435652595	21698	Economy	16700.00
0005435652691	21698	Economy	16700.00
0005433367984	21698	Economy	16700.00
0005435652820	21698	Economy	18300.00
0005435652826	21698	Economy	18300.00
0005433367950	21698	Economy	18300.00
0005433367961	21698	Economy	18300.00
0005433367957	21698	Economy	18300.00
0005433367952	21698	Economy	16700.00
0005435652827	21698	Economy	16700.00
0005435652745	21698	Economy	16700.00
0005433367966	21698	Economy	16700.00
0005435652769	21698	Economy	16700.00
0005435652676	21698	Economy	16700.00
0005435652685	21698	Economy	16700.00
0005435652810	21698	Economy	16700.00
0005433367971	21698	Economy	16700.00
0005435652738	21698	Economy	16700.00
0005435652681	21698	Economy	16700.00
0005435652535	21698	Economy	16700.00
0005433367986	21698	Economy	16700.00
0005435652770	21698	Economy	16700.00
0005433367967	21698	Economy	16700.00
0005433367972	21698	Economy	16700.00
0005433367955	21698	Economy	16700.00
0005433367976	21698	Economy	16700.00
0005435652776	21698	Economy	16700.00
0005435652625	21698	Economy	16700.00
0005435652536	21698	Economy	16700.00
0005435652717	21698	Economy	16700.00
0005433367965	21698	Economy	16700.00
0005433367979	21698	Economy	16700.00
0005435652706	21698	Economy	16700.00
0005433367978	21698	Economy	16700.00
0005435652552	21698	Economy	16700.00
0005433367982	21698	Economy	16700.00
0005433367951	21698	Economy	16700.00
0005435652801	21698	Economy	16700.00
0005433367958	21698	Economy	16700.00
0005433367977	21698	Economy	16700.00
0005433367968	21698	Economy	16700.00
0005433367973	21698	Economy	16700.00
0005433367963	21698	Economy	16700.00
0005435652819	21698	Economy	16700.00
0005435652783	21698	Economy	16700.00
0005435652835	21698	Economy	16700.00
0005433367948	21698	Economy	16700.00
0005435652440	21698	Economy	16700.00
0005433367960	21698	Economy	16700.00
0005433367959	21698	Economy	16700.00
0005433367975	21698	Economy	16700.00
0005435652800	21698	Economy	16700.00
0005433367980	21698	Economy	16700.00
0005435652707	21698	Economy	16700.00
0005433367949	21698	Economy	16700.00
0005435652701	21698	Economy	16700.00
0005435652651	21698	Economy	16700.00
0005435652621	21698	Economy	16700.00
0005435652571	21698	Economy	16700.00
0005435652644	21698	Economy	16700.00
0005435652677	21698	Economy	16700.00
0005433367953	21698	Economy	16700.00
0005433367962	21698	Economy	16700.00
0005435652731	21698	Economy	16700.00
0005435652766	21698	Economy	16700.00
0005435652623	21698	Economy	16700.00
0005435652816	21698	Economy	16700.00
0005435652737	21698	Economy	16700.00
0005435652590	21698	Economy	16700.00
0005433367970	21698	Economy	16700.00
0005433986029	4157	Business	21500.00
0005435788776	4157	Business	21500.00
0005433986070	4157	Business	21500.00
0005433986038	4157	Business	21500.00
0005433986057	4157	Business	21500.00
0005433986049	4157	Business	21500.00
0005433986043	4157	Business	21500.00
0005433986075	4157	Business	21500.00
0005433986064	4157	Business	21500.00
0005433986052	4157	Economy	7200.00
0005435788777	4157	Economy	7200.00
0005435788775	4157	Economy	7900.00
0005433986073	4157	Economy	7900.00
0005433986039	4157	Economy	7200.00
0005433986065	4157	Economy	7200.00
0005433986037	4157	Economy	7200.00
0005433986060	4157	Economy	7200.00
0005433986051	4157	Economy	7200.00
0005435788778	4157	Economy	7200.00
0005433986074	4157	Economy	7200.00
0005433986031	4157	Economy	7200.00
0005433986055	4157	Economy	7200.00
0005433986032	4157	Economy	7200.00
0005433986056	4157	Economy	7200.00
0005433986058	4157	Economy	7200.00
0005433986072	4157	Economy	7200.00
0005433986061	4157	Economy	7200.00
0005433986033	4157	Economy	7200.00
0005433986048	4157	Economy	7200.00
0005433986030	4157	Economy	7200.00
0005433986040	4157	Economy	7200.00
0005433986050	4157	Economy	7200.00
0005433986034	4157	Economy	7200.00
0005433986042	4157	Economy	7200.00
0005433986046	4157	Economy	7200.00
0005433986041	4157	Economy	7200.00
0005433986047	4157	Economy	7200.00
0005433986066	4157	Economy	7200.00
0005433986045	4157	Economy	7200.00
0005433986059	4157	Economy	7200.00
0005433986053	4157	Economy	7200.00
0005433986068	4157	Economy	7200.00
0005433986044	4157	Economy	7200.00
0005433986062	4157	Economy	7200.00
0005433986069	4157	Economy	7200.00
0005433986067	4157	Economy	7200.00
0005433986027	4157	Economy	7200.00
0005433986028	4157	Economy	7200.00
0005433986054	4157	Economy	7200.00
0005433986036	4157	Economy	7200.00
0005433986071	4157	Economy	7200.00
0005433986063	4157	Economy	7200.00
0005433986035	4157	Economy	7200.00
0005433985632	25684	Business	21500.00
0005433985577	25684	Business	21500.00
0005433985605	25684	Business	21500.00
0005433985597	25684	Business	21500.00
0005433985563	25684	Business	21500.00
0005433985582	25684	Economy	7200.00
0005433985640	25684	Economy	7200.00
0005433985538	25684	Economy	7200.00
0005433985276	25684	Economy	7200.00
0005433985617	25684	Economy	7900.00
0005433985564	25684	Economy	7900.00
0005433985506	25684	Economy	7200.00
0005433985521	25684	Economy	7200.00
0005433985625	25684	Economy	7200.00
0005433985496	25684	Economy	7200.00
0005433985548	25684	Economy	7200.00
0005433985557	25684	Economy	7200.00
0005433985565	25684	Economy	7200.00
0005433985595	25684	Economy	7200.00
0005433985451	25684	Economy	7200.00
0005433985643	25684	Economy	7200.00
0005433985639	25684	Economy	7200.00
0005433985495	25684	Economy	7200.00
0005433985520	25684	Economy	7200.00
0005433985471	25684	Economy	7200.00
0005433985470	25684	Economy	7200.00
0005433985581	25684	Economy	7200.00
0005433985562	25684	Economy	7200.00
0005433985616	25684	Economy	7200.00
0005433985573	25684	Economy	7200.00
0005433985606	25684	Economy	7200.00
0005433985527	25684	Economy	7200.00
0005433985277	25684	Economy	7200.00
0005433985537	25684	Economy	7200.00
0005433985594	25684	Economy	7200.00
0005433985494	25684	Economy	7200.00
0005433985477	25684	Economy	7200.00
0005435788759	25684	Economy	7200.00
0005433985571	25684	Economy	7200.00
0005433985347	25684	Economy	7200.00
0005433985627	25684	Economy	7200.00
0005433985570	25684	Economy	7200.00
0005433985403	25684	Economy	7200.00
0005433985614	25684	Economy	7200.00
0005433985558	25684	Economy	7200.00
0005433985626	25684	Economy	7200.00
0005433985459	25684	Economy	7200.00
0005433985452	25684	Economy	7200.00
0005435719558	21285	Economy	9400.00
0005435720817	21285	Economy	9400.00
0005435719564	21285	Economy	9400.00
0005435719560	21285	Economy	9400.00
0005435719559	21285	Economy	9400.00
0005435720133	24747	Economy	9400.00
0005435720132	24747	Economy	9400.00
0005435720134	24747	Economy	9400.00
0005434509077	21335	Economy	17000.00
0005434509088	21335	Economy	17000.00
0005434509081	21335	Economy	15500.00
0005433168380	21335	Economy	15500.00
0005434509106	21335	Economy	15500.00
0005434509094	21335	Economy	15500.00
0005433168372	21335	Economy	15500.00
0005433168378	21335	Economy	15500.00
0005434509102	21335	Economy	15500.00
0005434509116	21335	Economy	15500.00
0005433168377	21335	Economy	15500.00
0005433168373	21335	Economy	15500.00
0005434509104	21335	Economy	15500.00
0005434509107	21335	Economy	15500.00
0005434509086	21335	Economy	15500.00
0005433168382	21335	Economy	15500.00
0005434509098	21335	Economy	15500.00
0005434509122	21335	Economy	15500.00
0005433168383	21335	Economy	15500.00
0005433168375	21335	Economy	15500.00
0005434509096	21335	Economy	15500.00
0005433168374	21335	Economy	15500.00
0005434509092	21335	Economy	15500.00
0005433168381	21335	Economy	15500.00
0005433168379	21335	Economy	15500.00
0005434509078	21335	Economy	15500.00
0005433168376	21335	Economy	15500.00
0005434509103	21335	Economy	15500.00
0005434509119	21335	Economy	15500.00
0005434509091	21335	Economy	15500.00
0005434509082	21335	Economy	15500.00
0005434509118	21335	Economy	15500.00
0005434509090	21335	Economy	15500.00
0005434509101	21335	Economy	15500.00
0005432657439	17848	Business	18000.00
0005434151711	17848	Business	18000.00
0005432869545	17848	Business	18000.00
0005432655441	17848	Business	18000.00
0005432869541	17848	Economy	6000.00
0005432666362	17848	Economy	6000.00
0005432655449	17848	Economy	6000.00
0005432663026	17848	Economy	6000.00
0005432666361	17848	Economy	6600.00
0005432663012	17848	Economy	6000.00
0005432869542	17848	Economy	6000.00
0005432655439	17848	Economy	6000.00
0005432657438	17848	Economy	6000.00
0005432661904	17848	Economy	6000.00
0005434151713	17848	Economy	6000.00
0005432663018	17848	Economy	6000.00
0005432657440	17848	Economy	6000.00
0005432664120	17848	Economy	6000.00
0005432655423	17848	Economy	6000.00
0005432655412	17848	Economy	6000.00
0005432660805	17848	Economy	6000.00
0005432655468	17848	Economy	6000.00
0005432655425	17848	Economy	6000.00
0005432667441	17848	Economy	6000.00
0005432661907	17848	Economy	6000.00
0005432663025	17848	Economy	6000.00
0005432666372	17848	Economy	6000.00
0005432869544	17848	Economy	6000.00
0005432657430	17848	Economy	6000.00
0005432660804	17848	Economy	6000.00
0005432869543	17848	Economy	6000.00
0005432655436	17848	Economy	6000.00
0005432655424	17848	Economy	6000.00
0005432655511	17848	Economy	6000.00
0005434151712	17848	Economy	6000.00
0005432657431	17848	Economy	6000.00
0005432655440	17848	Economy	6000.00
0005432869473	26322	Business	18000.00
0005432869480	26322	Business	18000.00
0005432655541	26322	Business	18000.00
0005432869472	26322	Business	18000.00
0005432655543	26322	Economy	6000.00
0005432869471	26322	Economy	6000.00
0005432655536	26322	Economy	6000.00
0005432869479	26322	Economy	6000.00
0005432655535	26322	Economy	6600.00
0005434151694	26322	Economy	6000.00
0005432657450	26322	Economy	6000.00
0005432658592	26322	Economy	6000.00
0005432655538	26322	Economy	6000.00
0005432869477	26322	Economy	6000.00
0005432667456	26322	Economy	6000.00
0005432665276	26322	Economy	6000.00
0005432655534	26322	Economy	6000.00
0005432869478	26322	Economy	6000.00
0005432655537	26322	Economy	6000.00
0005432655539	26322	Economy	6000.00
0005432655545	26322	Economy	6000.00
0005432665277	26322	Economy	6000.00
0005432659707	26322	Economy	6000.00
0005432657452	26322	Economy	6000.00
0005432657451	26322	Economy	6000.00
0005432659708	26322	Economy	6000.00
0005432655540	26322	Economy	6000.00
0005434151685	26322	Economy	6000.00
0005432655542	26322	Economy	6000.00
0005432658594	26322	Economy	6000.00
0005432658593	26322	Economy	6000.00
0005432660819	26322	Economy	6000.00
0005432655544	26322	Economy	6000.00
0005432869474	26322	Economy	6000.00
0005432666391	26322	Economy	6000.00
0005432660820	26322	Economy	6000.00
0005432328787	3082	Business	16100.00
0005432287199	3082	Business	16100.00
0005432905093	3082	Business	16100.00
0005432328824	3082	Business	16100.00
0005432328829	3082	Business	16100.00
0005432328794	3082	Business	16100.00
0005432328805	3082	Business	16100.00
0005432905094	3082	Business	16100.00
0005433438898	3082	Business	16100.00
0005432328806	3082	Business	16100.00
0005432905078	3082	Business	16100.00
0005432287204	3082	Business	16100.00
0005432328784	3082	Economy	5400.00
0005432328793	3082	Economy	5400.00
0005432328825	3082	Economy	5400.00
0005432328813	3082	Economy	5400.00
0005432328819	3082	Economy	5400.00
0005432328789	3082	Economy	5900.00
0005432328800	3082	Economy	5900.00
0005432328792	3082	Economy	5900.00
0005432905083	3082	Economy	5400.00
0005432328797	3082	Economy	5400.00
0005432328799	3082	Economy	5400.00
0005432328790	3082	Economy	5400.00
0005433438895	3082	Economy	5400.00
0005432328804	3082	Economy	5400.00
0005432328827	3082	Economy	5400.00
0005432328791	3082	Economy	5400.00
0005432328807	3082	Economy	5400.00
0005432328828	3082	Economy	5400.00
0005433438897	3082	Economy	5400.00
0005432328818	3082	Economy	5400.00
0005432905113	3082	Economy	5400.00
0005432328801	3082	Economy	5400.00
0005432328815	3082	Economy	5400.00
0005432328830	3082	Economy	5400.00
0005432328785	3082	Economy	5400.00
0005432287201	3082	Economy	5400.00
0005433438894	3082	Economy	5400.00
0005432328812	3082	Economy	5400.00
0005432328798	3082	Economy	5400.00
0005432905082	3082	Economy	5400.00
0005432328786	3082	Economy	5400.00
0005432328816	3082	Economy	5400.00
0005432905070	3082	Economy	5400.00
0005432328803	3082	Economy	5400.00
0005432328817	3082	Economy	5400.00
0005432328811	3082	Economy	5400.00
0005432328795	3082	Economy	5400.00
0005432328796	3082	Economy	5400.00
0005432328821	3082	Economy	5400.00
0005433438893	3082	Economy	5400.00
0005432328802	3082	Economy	5400.00
0005432328820	3082	Economy	5400.00
0005433438896	3082	Economy	5400.00
0005432328814	3082	Economy	5400.00
0005432328809	3082	Economy	5400.00
0005432328810	3082	Economy	5400.00
0005432328808	3082	Economy	5400.00
0005432328822	3082	Economy	5400.00
0005432328788	3082	Economy	5400.00
0005432287202	3082	Economy	5400.00
0005432328826	3082	Economy	5400.00
0005432905112	3082	Economy	5400.00
0005432287203	3082	Economy	5400.00
0005432287200	3082	Economy	5400.00
0005432328823	3082	Economy	5400.00
0005432905077	3082	Economy	5400.00
0005432328476	31106	Business	16100.00
0005432328275	31106	Business	16100.00
0005432328335	31106	Business	16100.00
0005432328574	31106	Business	16100.00
0005432054309	31106	Business	16100.00
0005432905138	31106	Business	16100.00
0005432328225	31106	Business	16100.00
0005432328381	31106	Business	16100.00
0005432328375	31106	Business	16100.00
0005432328323	31106	Business	16100.00
0005432328272	31106	Economy	5400.00
0005432328264	31106	Economy	5400.00
0005432905140	31106	Economy	5400.00
0005432328350	31106	Economy	5400.00
0005432328429	31106	Economy	5400.00
0005432328282	31106	Economy	5400.00
0005432328423	31106	Economy	5400.00
0005432328297	31106	Economy	5900.00
0005432328291	31106	Economy	5900.00
0005432905137	31106	Economy	5900.00
0005432328351	31106	Economy	5400.00
0005432328223	31106	Economy	5400.00
0005432328270	31106	Economy	5400.00
0005432328659	31106	Economy	5400.00
0005432328349	31106	Economy	5400.00
0005432905136	31106	Economy	5400.00
0005432905142	31106	Economy	5400.00
0005432905139	31106	Economy	5400.00
0005432328233	31106	Economy	5400.00
0005432328379	31106	Economy	5400.00
0005432328344	31106	Economy	5400.00
0005432328330	31106	Economy	5400.00
0005432054313	31106	Economy	5400.00
0005432328322	31106	Economy	5400.00
0005433438799	31106	Economy	5400.00
0005432328352	31106	Economy	5400.00
0005432328274	31106	Economy	5400.00
0005432328430	31106	Economy	5400.00
0005432328224	31106	Economy	5400.00
0005432328281	31106	Economy	5400.00
0005432054312	31106	Economy	5400.00
0005432328360	31106	Economy	5400.00
0005432328320	31106	Economy	5400.00
0005432328236	31106	Economy	5400.00
0005432328232	31106	Economy	5400.00
0005432327992	31106	Economy	5400.00
0005432328290	31106	Economy	5400.00
0005432328445	31106	Economy	5400.00
0005432328382	31106	Economy	5400.00
0005432905141	31106	Economy	5400.00
0005432328332	31106	Economy	5400.00
0005432328342	31106	Economy	5400.00
0005432328278	31106	Economy	5400.00
0005432328279	31106	Economy	5400.00
0005432328516	31106	Economy	5400.00
0005432328431	31106	Economy	5400.00
0005432328345	31106	Economy	5400.00
0005432328424	31106	Economy	5400.00
0005432328292	31106	Economy	5400.00
0005432328319	31106	Economy	5400.00
0005432054311	31106	Economy	5400.00
0005432328444	31106	Economy	5400.00
0005432328356	31106	Economy	5400.00
0005432054310	31106	Economy	5400.00
0005432905135	31106	Economy	5400.00
0005433438808	31106	Economy	5400.00
0005432328343	31106	Economy	5400.00
0005433438807	31106	Economy	5400.00
0005432328660	31106	Economy	5400.00
0005435487672	6180	Business	124600.00
0005435487679	6180	Business	124600.00
0005435487572	6180	Business	124600.00
0005434309777	6180	Business	124600.00
0005435999294	6180	Business	124600.00
0005435487688	6180	Economy	41500.00
0005435297037	6180	Economy	41500.00
0005435487669	6180	Economy	41500.00
0005435297024	6180	Economy	41500.00
0005435487715	6180	Economy	41500.00
0005435487660	6180	Economy	41500.00
0005435999287	6180	Economy	41500.00
0005435999288	6180	Economy	41500.00
0005435999291	6180	Economy	41500.00
0005435487573	6180	Economy	41500.00
0005434309769	6180	Economy	41500.00
0005435487734	6180	Economy	41500.00
0005435487694	6180	Economy	41500.00
0005435297020	6180	Economy	41500.00
0005435297035	6180	Economy	41500.00
0005434309770	6180	Economy	41500.00
0005435999292	6180	Economy	41500.00
0005435999289	6180	Economy	41500.00
0005432146204	6180	Economy	41500.00
0005435999299	6180	Economy	41500.00
0005435487735	6180	Economy	41500.00
0005435999296	6180	Economy	41500.00
0005435487673	6180	Economy	41500.00
0005435999285	6180	Economy	45700.00
0005434309768	6180	Economy	45700.00
0005434309773	6180	Economy	45700.00
0005435487662	6180	Economy	45700.00
0005435999286	6180	Economy	41500.00
0005435999295	6180	Economy	45700.00
0005434309778	6180	Economy	41500.00
0005435999282	6180	Economy	41500.00
0005434309771	6180	Economy	41500.00
0005435487744	6180	Economy	41500.00
0005435296993	6180	Economy	41500.00
0005435999298	6180	Economy	41500.00
0005435999283	6180	Economy	41500.00
0005435487652	6180	Economy	41500.00
0005435487745	6180	Economy	41500.00
0005434309767	6180	Economy	41500.00
0005435999280	6180	Economy	41500.00
0005434309774	6180	Economy	41500.00
0005435487615	6180	Economy	41500.00
0005435487716	6180	Economy	41500.00
0005435999297	6180	Economy	41500.00
0005434309780	6180	Economy	41500.00
0005434309766	6180	Economy	41500.00
0005435487646	6180	Economy	41500.00
0005435297019	6180	Economy	41500.00
0005435487695	6180	Economy	41500.00
0005434309775	6180	Economy	41500.00
0005435999290	6180	Economy	41500.00
0005435999284	6180	Economy	41500.00
0005432146203	6180	Economy	41500.00
0005434309779	6180	Economy	41500.00
0005435297026	6180	Economy	41500.00
0005435487687	6180	Economy	41500.00
0005434309772	6180	Economy	41500.00
0005434309776	6180	Economy	41500.00
0005435999293	6180	Economy	41500.00
0005435297025	6180	Economy	41500.00
0005435297009	6180	Economy	41500.00
0005435487670	6180	Economy	41500.00
0005435999281	6180	Economy	41500.00
0005435487862	19576	Business	124600.00
0005435999161	19576	Business	124600.00
0005435487858	19576	Business	124600.00
0005435487867	19576	Business	124600.00
0005435999159	19576	Economy	41500.00
0005434309654	19576	Economy	41500.00
0005435487855	19576	Economy	41500.00
0005434309600	19576	Economy	41500.00
0005435487859	19576	Economy	41500.00
0005434309615	19576	Economy	41500.00
0005434309639	19576	Economy	41500.00
0005434309653	19576	Economy	41500.00
0005435487857	19576	Economy	41500.00
0005434309655	19576	Economy	41500.00
0005435487854	19576	Economy	41500.00
0005435487865	19576	Economy	41500.00
0005435999054	19576	Economy	41500.00
0005434309614	19576	Economy	41500.00
0005435487856	19576	Economy	41500.00
0005435999107	19576	Economy	41500.00
0005434309652	19576	Economy	41500.00
0005435487860	19576	Economy	41500.00
0005434309642	19576	Economy	41500.00
0005434309599	19576	Economy	41500.00
0005435999065	19576	Economy	41500.00
0005434309640	19576	Economy	41500.00
0005434309616	19576	Economy	45700.00
0005435999089	19576	Economy	45700.00
0005435487871	19576	Economy	45700.00
0005434309726	19576	Economy	41500.00
0005435297077	19576	Economy	41500.00
0005435487869	19576	Economy	41500.00
0005434309564	19576	Economy	41500.00
0005434309617	19576	Economy	41500.00
0005435999116	19576	Economy	41500.00
0005434309657	19576	Economy	41500.00
0005435487872	19576	Economy	41500.00
0005435487866	19576	Economy	41500.00
0005434309707	19576	Economy	41500.00
0005435487861	19576	Economy	41500.00
0005435999120	19576	Economy	41500.00
0005435487853	19576	Economy	41500.00
0005434309641	19576	Economy	41500.00
0005435999092	19576	Economy	41500.00
0005435487863	19576	Economy	41500.00
0005435999093	19576	Economy	41500.00
0005434309705	19576	Economy	41500.00
0005435297074	19576	Economy	41500.00
0005435297075	19576	Economy	41500.00
0005434309656	19576	Economy	41500.00
0005434309731	19576	Economy	41500.00
0005435297076	19576	Economy	41500.00
0005434309675	19576	Economy	41500.00
0005435999112	19576	Economy	41500.00
0005435297073	19576	Economy	41500.00
0005435487864	19576	Economy	41500.00
0005435487868	19576	Economy	41500.00
0005435487873	19576	Economy	41500.00
0005435487870	19576	Economy	41500.00
0005435999160	19576	Economy	41500.00
0005434309706	19576	Economy	41500.00
0005435999055	19576	Economy	41500.00
0005435999095	19576	Economy	41500.00
0005435999106	19576	Economy	41500.00
0005435297072	19576	Economy	41500.00
0005435487852	19576	Economy	41500.00
0005435999164	19576	Economy	41500.00
0005435999111	19576	Economy	41500.00
0005434309704	19576	Economy	41500.00
0005433186088	1546	Business	86000.00
0005435517960	1546	Business	86000.00
0005435517957	1546	Business	86000.00
0005432291936	1546	Business	86000.00
0005435502357	1546	Business	86000.00
0005435517946	1546	Business	86000.00
0005435517948	1546	Business	86000.00
0005435502369	1546	Business	86000.00
0005435502356	1546	Business	86000.00
0005435502359	1546	Economy	28700.00
0005435502373	1546	Economy	28700.00
0005435517959	1546	Economy	28700.00
0005433186035	1546	Economy	28700.00
0005433186086	1546	Economy	28700.00
0005435508393	1546	Economy	28700.00
0005433186054	1546	Economy	31500.00
0005435502366	1546	Economy	31500.00
0005435502353	1546	Economy	31500.00
0005432291935	1546	Economy	31500.00
0005434565941	1546	Economy	28700.00
0005435508394	1546	Economy	28700.00
0005433186041	1546	Economy	28700.00
0005435502374	1546	Economy	28700.00
0005433186094	1546	Economy	28700.00
0005434565944	1546	Economy	28700.00
0005435502362	1546	Economy	28700.00
0005435517951	1546	Economy	28700.00
0005435517955	1546	Economy	28700.00
0005435502352	1546	Economy	28700.00
0005434565943	1546	Economy	28700.00
0005435517949	1546	Economy	28700.00
0005434565940	1546	Economy	28700.00
0005435502358	1546	Economy	28700.00
0005433186093	1546	Economy	28700.00
0005435517952	1546	Economy	28700.00
0005434565947	1546	Economy	28700.00
0005435502367	1546	Economy	28700.00
0005434565951	1546	Economy	28700.00
0005433186052	1546	Economy	28700.00
0005433186071	1546	Economy	28700.00
0005433186087	1546	Economy	28700.00
0005435502370	1546	Economy	28700.00
0005435502355	1546	Economy	28700.00
0005435502364	1546	Economy	28700.00
0005435502372	1546	Economy	28700.00
0005435508392	1546	Economy	28700.00
0005434565950	1546	Economy	28700.00
0005434565945	1546	Economy	28700.00
0005434565949	1546	Economy	28700.00
0005434565939	1546	Economy	28700.00
0005435517953	1546	Economy	28700.00
0005434565948	1546	Economy	28700.00
0005433186047	1546	Economy	28700.00
0005435502371	1546	Economy	28700.00
0005435517956	1546	Economy	28700.00
0005435517947	1546	Economy	28700.00
0005434565946	1546	Economy	28700.00
0005434565952	1546	Economy	28700.00
0005433186034	1546	Economy	28700.00
0005435502354	1546	Economy	28700.00
0005435502365	1546	Economy	28700.00
0005433186053	1546	Economy	28700.00
0005435502360	1546	Economy	28700.00
0005435502361	1546	Economy	28700.00
0005435502368	1546	Economy	28700.00
0005432291937	1546	Economy	28700.00
0005435517950	1546	Economy	28700.00
0005434565942	1546	Economy	28700.00
0005435517954	1546	Economy	28700.00
0005435517958	1546	Economy	28700.00
0005435502363	1546	Economy	28700.00
0005435529048	20843	Business	86000.00
0005435502187	20843	Business	86000.00
0005435502166	20843	Business	86000.00
0005435529054	20843	Business	86000.00
0005433186138	20843	Business	86000.00
0005435502173	20843	Business	86000.00
0005435529053	20843	Business	86000.00
0005435545632	20843	Business	86000.00
0005433186140	20843	Business	86000.00
0005435502181	20843	Business	86000.00
0005435502123	20843	Economy	28700.00
0005435529058	20843	Economy	28700.00
0005435545656	20843	Economy	28700.00
0005435529006	20843	Economy	28700.00
0005435502122	20843	Economy	28700.00
0005433186141	20843	Economy	28700.00
0005435502108	20843	Economy	28700.00
0005435502186	20843	Economy	28700.00
0005435529075	20843	Economy	28700.00
0005435529049	20843	Economy	31500.00
0005435529099	20843	Economy	31500.00
0005435545644	20843	Economy	31500.00
0005435529152	20843	Economy	31500.00
0005435502110	20843	Economy	28700.00
0005435529014	20843	Economy	28700.00
0005435529121	20843	Economy	28700.00
0005435529013	20843	Economy	28700.00
0005435529007	20843	Economy	28700.00
0005435502196	20843	Economy	28700.00
0005435529098	20843	Economy	28700.00
0005435502098	20843	Economy	28700.00
0005435529091	20843	Economy	28700.00
0005433186142	20843	Economy	28700.00
0005435529045	20843	Economy	28700.00
0005433186137	20843	Economy	28700.00
0005435502168	20843	Economy	28700.00
0005435529050	20843	Economy	28700.00
0005435502165	20843	Economy	28700.00
0005433186143	20843	Economy	28700.00
0005435545631	20843	Economy	28700.00
0005435545667	20843	Economy	28700.00
0005434565811	20843	Economy	28700.00
0005435529051	20843	Economy	28700.00
0005435529153	20843	Economy	28700.00
0005435529059	20843	Economy	28700.00
0005434565847	20843	Economy	28700.00
0005435528969	20843	Economy	28700.00
0005434565844	20843	Economy	28700.00
0005435502160	20843	Economy	28700.00
0005435545674	20843	Economy	28700.00
0005435502136	20843	Economy	28700.00
0005434565765	20843	Economy	28700.00
0005435529139	20843	Economy	28700.00
0005435528951	20843	Economy	28700.00
0005435529073	20843	Economy	28700.00
0005433186135	20843	Economy	28700.00
0005435529110	20843	Economy	28700.00
0005435545659	20843	Economy	28700.00
0005435529080	20843	Economy	28700.00
0005435502234	20843	Economy	28700.00
0005433186136	20843	Economy	28700.00
0005435545671	20843	Economy	28700.00
0005435502150	20843	Economy	28700.00
0005434565829	20843	Economy	28700.00
0005434565797	20843	Economy	28700.00
0005434565830	20843	Economy	28700.00
0005434565796	20843	Economy	28700.00
0005435502239	20843	Economy	28700.00
0005435502164	20843	Economy	28700.00
0005435502135	20843	Economy	28700.00
0005435529120	20843	Economy	28700.00
0005434565848	20843	Economy	28700.00
0005433186139	20843	Economy	28700.00
0005435502109	20843	Economy	28700.00
0005435529111	20843	Economy	28700.00
0005435528952	20843	Economy	28700.00
0005435529140	20843	Economy	28700.00
0005435153760	3885	Economy	21600.00
0005435153754	3885	Economy	19700.00
0005435931596	3885	Economy	19700.00
0005435931588	3885	Economy	19700.00
0005435153755	3885	Economy	19700.00
0005435153756	3885	Economy	19700.00
0005435931597	3885	Economy	19700.00
0005435153759	3885	Economy	19700.00
0005435153757	3885	Economy	19700.00
0005435931574	3885	Economy	19700.00
0005435153758	3885	Economy	19700.00
0005435931610	21867	Economy	19700.00
0005435931609	21867	Economy	19700.00
0005435153709	21867	Economy	19700.00
0005435153682	21867	Economy	19700.00
0005435931611	21867	Economy	19700.00
0005435931608	21867	Economy	19700.00
0005435153718	21867	Economy	19700.00
0005432628884	7211	Economy	14300.00
0005432628881	7211	Economy	14300.00
0005435225545	7211	Economy	14300.00
0005432628882	7211	Economy	13000.00
0005435225556	7211	Economy	13000.00
0005432628877	7211	Economy	13000.00
0005432628878	7211	Economy	13000.00
0005432628886	7211	Economy	13000.00
0005432628885	7211	Economy	13000.00
0005435225493	7211	Economy	13000.00
0005432628883	7211	Economy	13000.00
0005435225518	7211	Economy	13000.00
0005432628879	7211	Economy	13000.00
0005432628876	7211	Economy	13000.00
0005432628874	7211	Economy	13000.00
0005435225557	7211	Economy	13000.00
0005432628887	7211	Economy	13000.00
0005432628880	7211	Economy	13000.00
0005435225558	7211	Economy	13000.00
0005432628875	7211	Economy	13000.00
0005435225547	7211	Economy	13000.00
0005432628873	7211	Economy	13000.00
0005435225562	7211	Economy	13000.00
0005432628787	28104	Economy	14300.00
0005432628730	28104	Economy	14300.00
0005432628796	28104	Economy	13000.00
0005432628727	28104	Economy	13000.00
0005432628766	28104	Economy	13000.00
0005435225605	28104	Economy	13000.00
0005435225606	28104	Economy	13000.00
0005435225604	28104	Economy	13000.00
0005432628788	28104	Economy	13000.00
0005432628731	28104	Economy	13000.00
0005435225603	28104	Economy	13000.00
0005432628797	28104	Economy	13000.00
0005432628813	28104	Economy	13000.00
0005435225601	28104	Economy	13000.00
0005435225599	28104	Economy	13000.00
0005432628773	28104	Economy	13000.00
0005432628769	28104	Economy	13000.00
0005432628812	28104	Economy	13000.00
0005435225602	28104	Economy	13000.00
0005432628781	28104	Economy	13000.00
0005435225600	28104	Economy	13000.00
0005435960059	8733	Economy	10500.00
0005434267886	8733	Economy	10500.00
0005434267925	8733	Economy	10500.00
0005435960060	8733	Economy	10500.00
0005434267920	8733	Economy	10500.00
0005435960058	8733	Economy	10500.00
0005434267921	8733	Economy	10500.00
0005435960030	15255	Economy	11500.00
0005435960031	15255	Economy	11500.00
0005434267957	15255	Economy	10500.00
0005434267958	15255	Economy	10500.00
0005434267959	15255	Economy	10500.00
0005435960012	15255	Economy	10500.00
0005435960028	15255	Economy	10500.00
0005435960027	15255	Economy	10500.00
0005435960029	15255	Economy	10500.00
0005435960041	15255	Economy	10500.00
0005435960033	15255	Economy	10500.00
0005432873262	1174	Business	115000.00
0005432693114	1174	Business	115000.00
0005432677581	1174	Business	115000.00
0005432873277	1174	Business	115000.00
0005432693110	1174	Business	115000.00
0005432873245	1174	Business	115000.00
0005432693122	1174	Business	115000.00
0005432693124	1174	Business	115000.00
0005432675174	1174	Business	115000.00
0005432675163	1174	Economy	38300.00
0005432693103	1174	Economy	38300.00
0005432677580	1174	Economy	38300.00
0005432675162	1174	Economy	38300.00
0005432693118	1174	Economy	38300.00
0005432675161	1174	Economy	38300.00
0005432677579	1174	Economy	38300.00
0005432873231	1174	Economy	38300.00
0005432693109	1174	Economy	38300.00
0005432693101	1174	Economy	42200.00
0005432873278	1174	Economy	42200.00
0005432675169	1174	Economy	42200.00
0005432693107	1174	Economy	38300.00
0005432693119	1174	Economy	38300.00
0005432675166	1174	Economy	38300.00
0005432675172	1174	Economy	38300.00
0005432873246	1174	Economy	38300.00
0005432693104	1174	Economy	38300.00
0005432873241	1174	Economy	38300.00
0005432675165	1174	Economy	38300.00
0005432693115	1174	Economy	38300.00
0005432873264	1174	Economy	38300.00
0005432873261	1174	Economy	38300.00
0005432677577	1174	Economy	38300.00
0005432693106	1174	Economy	38300.00
0005432693096	1174	Economy	38300.00
0005432675160	1174	Economy	38300.00
0005432675170	1174	Economy	38300.00
0005432693111	1174	Economy	38300.00
0005432693105	1174	Economy	38300.00
0005432693120	1174	Economy	38300.00
0005432675171	1174	Economy	38300.00
0005432693117	1174	Economy	38300.00
0005432693098	1174	Economy	38300.00
0005432677578	1174	Economy	38300.00
0005432693113	1174	Economy	38300.00
0005432693100	1174	Economy	38300.00
0005432693099	1174	Economy	38300.00
0005432693112	1174	Economy	38300.00
0005432675173	1174	Economy	38300.00
0005432693097	1174	Economy	38300.00
0005432873281	1174	Economy	38300.00
0005432675164	1174	Economy	38300.00
0005432873263	1174	Economy	38300.00
0005432693125	1174	Economy	38300.00
0005432693123	1174	Economy	38300.00
0005432675158	1174	Economy	38300.00
0005432693116	1174	Economy	38300.00
0005432693126	1174	Economy	38300.00
0005432675159	1174	Economy	38300.00
0005432693108	1174	Economy	38300.00
0005432693121	1174	Economy	38300.00
0005432693102	1174	Economy	38300.00
0005432675168	1174	Economy	38300.00
0005432675167	1174	Economy	38300.00
0005432873242	1174	Economy	38300.00
0005432675001	17464	Business	115000.00
0005432677535	17464	Business	115000.00
0005432675044	17464	Business	115000.00
0005432692992	17464	Business	115000.00
0005432873306	17464	Business	115000.00
0005432692877	17464	Business	115000.00
0005432675022	17464	Business	115000.00
0005432692761	17464	Business	115000.00
0005432692781	17464	Business	115000.00
0005432692994	17464	Business	115000.00
0005432675043	17464	Business	115000.00
0005432692884	17464	Business	115000.00
0005432675038	17464	Business	115000.00
0005432873309	17464	Economy	38300.00
0005432692791	17464	Economy	38300.00
0005432692965	17464	Economy	38300.00
0005432692982	17464	Economy	42200.00
0005432675063	17464	Economy	42200.00
0005432692983	17464	Economy	38300.00
0005432692799	17464	Economy	38300.00
0005432675105	17464	Economy	38300.00
0005432692801	17464	Economy	38300.00
0005432692878	17464	Economy	38300.00
0005432677547	17464	Economy	38300.00
0005432675037	17464	Economy	38300.00
0005432692802	17464	Economy	38300.00
0005432692789	17464	Economy	38300.00
0005432873313	17464	Economy	38300.00
0005432873310	17464	Economy	38300.00
0005432692893	17464	Economy	38300.00
0005432692964	17464	Economy	38300.00
0005432692923	17464	Economy	38300.00
0005432692800	17464	Economy	38300.00
0005432677546	17464	Economy	38300.00
0005432692762	17464	Economy	38300.00
0005432675002	17464	Economy	38300.00
0005432675051	17464	Economy	38300.00
0005432675023	17464	Economy	38300.00
0005432692812	17464	Economy	38300.00
0005432675039	17464	Economy	38300.00
0005432675016	17464	Economy	38300.00
0005432692783	17464	Economy	38300.00
0005432873311	17464	Economy	38300.00
0005432692966	17464	Economy	38300.00
0005432692888	17464	Economy	38300.00
0005432692758	17464	Economy	38300.00
0005432675056	17464	Economy	38300.00
0005432873304	17464	Economy	38300.00
0005432692790	17464	Economy	38300.00
0005432675062	17464	Economy	38300.00
0005432873305	17464	Economy	38300.00
0005432692728	17464	Economy	38300.00
0005432692829	17464	Economy	38300.00
0005432692993	17464	Economy	38300.00
0005432677536	17464	Economy	38300.00
0005432873308	17464	Economy	38300.00
0005432692889	17464	Economy	38300.00
0005432873307	17464	Economy	38300.00
0005432873312	17464	Economy	38300.00
0005432692782	17464	Economy	38300.00
0005432692825	17464	Economy	38300.00
0005434435221	1113	Economy	15200.00
0005434435220	1113	Economy	15200.00
0005434435223	1113	Economy	15200.00
0005434435216	1113	Economy	13900.00
0005434435211	1113	Economy	13900.00
0005434435213	1113	Economy	13900.00
0005433156701	1113	Economy	13900.00
0005433156728	1113	Economy	13900.00
0005433156661	1113	Economy	13900.00
0005433156693	1113	Economy	13900.00
0005433156697	1113	Economy	13900.00
0005434435209	1113	Economy	13900.00
0005434435210	1113	Economy	13900.00
0005433156706	1113	Economy	13900.00
0005434435212	1113	Economy	13900.00
0005433156660	1113	Economy	13900.00
0005433156674	1113	Economy	13900.00
0005434435219	1113	Economy	13900.00
0005434435224	1113	Economy	13900.00
0005433156696	1113	Economy	13900.00
0005433156698	1113	Economy	13900.00
0005434435214	1113	Economy	13900.00
0005433156673	1113	Economy	13900.00
0005433156727	1113	Economy	13900.00
0005434435222	1113	Economy	13900.00
0005434435217	1113	Economy	13900.00
0005434435215	1113	Economy	13900.00
0005434435218	1113	Economy	13900.00
0005434435088	17324	Economy	15200.00
0005434435121	17324	Economy	15200.00
0005433156772	17324	Economy	13900.00
0005434435053	17324	Economy	13900.00
0005434435070	17324	Economy	13900.00
0005434435057	17324	Economy	13900.00
0005434435089	17324	Economy	13900.00
0005433156769	17324	Economy	13900.00
0005433156771	17324	Economy	13900.00
0005433156766	17324	Economy	13900.00
0005434435052	17324	Economy	13900.00
0005433156767	17324	Economy	13900.00
0005434435130	17324	Economy	13900.00
0005434435085	17324	Economy	13900.00
0005434435086	17324	Economy	13900.00
0005434435076	17324	Economy	13900.00
0005433156768	17324	Economy	13900.00
0005434435111	17324	Economy	13900.00
0005433156770	17324	Economy	13900.00
0005434434990	17324	Economy	13900.00
0005434435051	17324	Economy	13900.00
0005435086854	4077	Economy	8200.00
0005435928099	4077	Economy	8200.00
0005435928129	4077	Economy	7500.00
0005435086851	4077	Economy	7500.00
0005435928128	4077	Economy	7500.00
0005435086852	4077	Economy	7500.00
0005435086849	4077	Economy	7500.00
0005435086853	4077	Economy	7500.00
0005435928098	4077	Economy	7500.00
0005435086848	4077	Economy	7500.00
0005435928123	4077	Economy	7500.00
0005435086850	4077	Economy	7500.00
0005435086792	24421	Economy	8200.00
0005435086780	24421	Economy	8200.00
0005435086808	24421	Economy	7500.00
0005435086793	24421	Economy	7500.00
0005435086761	24421	Economy	7500.00
0005435928154	24421	Economy	7500.00
0005435086821	24421	Economy	7500.00
0005435086822	24421	Economy	7500.00
0005435928152	24421	Economy	7500.00
0005435086779	24421	Economy	7500.00
0005435928153	24421	Economy	7500.00
0005435928155	24421	Economy	7500.00
0005435086807	24421	Economy	7500.00
0005434625985	4830	Business	44200.00
0005434625979	4830	Business	44200.00
0005434625980	4830	Economy	16200.00
0005434625986	4830	Economy	14700.00
0005434625977	4830	Economy	14700.00
0005435907495	4830	Economy	14700.00
0005433194838	4830	Economy	14700.00
0005434625984	4830	Economy	14700.00
0005435907473	4830	Economy	14700.00
0005434625982	4830	Economy	14700.00
0005434625978	4830	Economy	14700.00
0005434625981	4830	Economy	14700.00
0005433194844	4830	Economy	14700.00
0005434625983	4830	Economy	14700.00
0005435907468	4830	Economy	14700.00
0005434625895	32910	Economy	14700.00
0005434625906	32910	Economy	16200.00
0005434625907	32910	Economy	14700.00
0005434625908	32910	Economy	14700.00
0005434625872	32910	Economy	14700.00
0005434625896	32910	Economy	14700.00
0005435785211	13748	Economy	3400.00
0005435785031	13748	Economy	3400.00
0005435785110	13748	Economy	3400.00
0005435784925	13748	Economy	3100.00
0005435937391	13748	Economy	3100.00
0005435785216	13748	Economy	3100.00
0005435785207	13748	Economy	3100.00
0005435785098	13748	Economy	3100.00
0005435937392	13748	Economy	3100.00
0005435784979	13748	Economy	3100.00
0005435785202	13748	Economy	3100.00
0005435785109	13748	Economy	3100.00
0005435785060	13748	Economy	3100.00
0005435785102	13748	Economy	3100.00
0005435785084	13748	Economy	3100.00
0005435785122	13748	Economy	3100.00
0005435785105	13748	Economy	3100.00
0005435785059	13748	Economy	3100.00
0005432195697	13748	Economy	3100.00
0005435785113	13748	Economy	3100.00
0005435785244	13748	Economy	3100.00
0005432195698	13748	Economy	3100.00
0005435785121	13748	Economy	3100.00
0005435787338	13748	Economy	3100.00
0005435785201	13748	Economy	3100.00
0005435787340	13748	Economy	3100.00
0005435785167	13748	Economy	3100.00
0005435785210	13748	Economy	3100.00
0005435785188	13748	Economy	3100.00
0005435785152	13748	Economy	3100.00
0005435787339	13748	Economy	3100.00
0005435785151	13748	Economy	3100.00
0005435785387	27425	Economy	3400.00
0005435785386	27425	Economy	3400.00
0005435937352	27425	Economy	3400.00
0005435785385	27425	Economy	3400.00
0005435785376	27425	Economy	3100.00
0005435937347	27425	Economy	3100.00
0005435785397	27425	Economy	3100.00
0005435937329	27425	Economy	3100.00
0005435785389	27425	Economy	3100.00
0005432190634	27425	Economy	3100.00
0005432190632	27425	Economy	3100.00
0005435785379	27425	Economy	3100.00
0005435785383	27425	Economy	3100.00
0005435785375	27425	Economy	3100.00
0005435785392	27425	Economy	3100.00
0005435785398	27425	Economy	3100.00
0005435785381	27425	Economy	3100.00
0005435785399	27425	Economy	3100.00
0005435785372	27425	Economy	3100.00
0005435785395	27425	Economy	3100.00
0005435787356	27425	Economy	3100.00
0005435785370	27425	Economy	3100.00
0005435785384	27425	Economy	3100.00
0005435785373	27425	Economy	3100.00
0005435785388	27425	Economy	3100.00
0005435937333	27425	Economy	3100.00
0005435785371	27425	Economy	3100.00
0005435785393	27425	Economy	3100.00
0005432190633	27425	Economy	3100.00
0005435785394	27425	Economy	3100.00
0005435785365	27425	Economy	3100.00
0005435785374	27425	Economy	3100.00
0005435785400	27425	Economy	3100.00
0005435787355	27425	Economy	3100.00
0005435785380	27425	Economy	3100.00
0005435785378	27425	Economy	3100.00
0005435785390	27425	Economy	3100.00
0005435785382	27425	Economy	3100.00
0005435785367	27425	Economy	3100.00
0005435785391	27425	Economy	3100.00
0005435785377	27425	Economy	3100.00
0005435785401	27425	Economy	3100.00
0005435785369	27425	Economy	3100.00
0005435785396	27425	Economy	3100.00
0005435937332	27425	Economy	3100.00
0005435937348	27425	Economy	3100.00
0005435785368	27425	Economy	3100.00
0005432190631	27425	Economy	3100.00
0005435785366	27425	Economy	3100.00
0005432058391	20303	Business	12000.00
0005435311088	20303	Business	12000.00
0005434407383	20303	Business	12000.00
0005434407537	20303	Business	12000.00
0005434406700	20303	Business	12000.00
0005434407351	20303	Business	12000.00
0005434407075	20303	Business	12000.00
0005434407205	20303	Business	12000.00
0005434407595	20303	Business	12000.00
0005434407303	20303	Business	12000.00
0005434407237	20303	Economy	4000.00
0005434407421	20303	Economy	4000.00
0005434407127	20303	Economy	4000.00
0005434407477	20303	Economy	4000.00
0005434407118	20303	Economy	4000.00
0005434407204	20303	Economy	4000.00
0005435311089	20303	Economy	4000.00
0005434407388	20303	Economy	4000.00
0005434407408	20303	Economy	4000.00
0005434407454	20303	Economy	4400.00
0005434407170	20303	Economy	4400.00
0005434407175	20303	Economy	4400.00
0005434407538	20303	Economy	4400.00
0005434407194	20303	Economy	4400.00
0005434407449	20303	Economy	4000.00
0005434406920	20303	Economy	4000.00
0005434407638	20303	Economy	4000.00
0005434407191	20303	Economy	4000.00
0005434407304	20303	Economy	4000.00
0005434407392	20303	Economy	4000.00
0005434407142	20303	Economy	4000.00
0005434407562	20303	Economy	4000.00
0005435311092	20303	Economy	4000.00
0005434407352	20303	Economy	4000.00
0005434407195	20303	Economy	4000.00
0005434407373	20303	Economy	4000.00
0005434407362	20303	Economy	4000.00
0005434407550	20303	Economy	4000.00
0005434407480	20303	Economy	4000.00
0005434407168	20303	Economy	4000.00
0005434407527	20303	Economy	4000.00
0005434407096	20303	Economy	4000.00
0005434407217	20303	Economy	4000.00
0005434407479	20303	Economy	4000.00
0005434407457	20303	Economy	4000.00
0005432058389	20303	Economy	4000.00
0005434407552	20303	Economy	4000.00
0005434407141	20303	Economy	4000.00
0005434407238	20303	Economy	4000.00
0005434407211	20303	Economy	4000.00
0005434407365	20303	Economy	4000.00
0005434407437	20303	Economy	4000.00
0005434407138	20303	Economy	4000.00
0005434407185	20303	Economy	4000.00
0005434407279	20303	Economy	4000.00
0005434407389	20303	Economy	4000.00
0005434407563	20303	Economy	4000.00
0005434407317	20303	Economy	4000.00
0005434407509	20303	Economy	4000.00
0005434407372	20303	Economy	4000.00
0005434407453	20303	Economy	4000.00
0005434407169	20303	Economy	4000.00
0005434407569	20303	Economy	4000.00
0005435311091	20303	Economy	4000.00
0005434407553	20303	Economy	4000.00
0005434407409	20303	Economy	4000.00
0005434407438	20303	Economy	4000.00
0005434407190	20303	Economy	4000.00
0005432058392	20303	Economy	4000.00
0005434407478	20303	Economy	4000.00
0005434407489	20303	Economy	4000.00
0005434407343	20303	Economy	4000.00
0005434407186	20303	Economy	4000.00
0005434407171	20303	Economy	4000.00
0005434407485	20303	Economy	4000.00
0005432058390	20303	Economy	4000.00
0005434407508	20303	Economy	4000.00
0005435311090	20303	Economy	4000.00
0005435311093	20303	Economy	4000.00
0005434407312	20303	Economy	4000.00
0005434407212	20303	Economy	4000.00
0005434407076	20303	Economy	4000.00
0005434407370	20303	Economy	4000.00
0005434407124	20303	Economy	4000.00
0005434407407	20303	Economy	4000.00
0005434407293	20303	Economy	4000.00
0005434407159	20303	Economy	4000.00
0005434407251	20303	Economy	4000.00
0005434407558	20303	Economy	4000.00
0005434407883	26966	Business	12000.00
0005434407887	26966	Business	12000.00
0005434407911	26966	Business	12000.00
0005432153956	26966	Business	12000.00
0005434407869	26966	Business	12000.00
0005434407873	26966	Business	12000.00
0005434407878	26966	Business	12000.00
0005434407891	26966	Business	12000.00
0005434407907	26966	Business	12000.00
0005435310956	26966	Business	12000.00
0005434407868	26966	Business	12000.00
0005434407919	26966	Business	12000.00
0005434407885	26966	Economy	4000.00
0005435310958	26966	Economy	4000.00
0005434407882	26966	Economy	4000.00
0005434407925	26966	Economy	4000.00
0005435310968	26966	Economy	4000.00
0005434407928	26966	Economy	4000.00
0005434407897	26966	Economy	4000.00
0005434407926	26966	Economy	4000.00
0005434407871	26966	Economy	4000.00
0005432153951	26966	Economy	4400.00
0005435310899	26966	Economy	4400.00
0005434407904	26966	Economy	4400.00
0005434407915	26966	Economy	4400.00
0005434407866	26966	Economy	4400.00
0005434407899	26966	Economy	4000.00
0005434407870	26966	Economy	4000.00
0005434407895	26966	Economy	4000.00
0005434407918	26966	Economy	4000.00
0005434407874	26966	Economy	4000.00
0005434407880	26966	Economy	4000.00
0005435310959	26966	Economy	4000.00
0005434407901	26966	Economy	4000.00
0005434407916	26966	Economy	4000.00
0005432153954	26966	Economy	4000.00
0005435310966	26966	Economy	4000.00
0005435310944	26966	Economy	4000.00
0005434407929	26966	Economy	4000.00
0005434407877	26966	Economy	4000.00
0005434407909	26966	Economy	4000.00
0005434407920	26966	Economy	4000.00
0005434407923	26966	Economy	4000.00
0005434407881	26966	Economy	4000.00
0005434407894	26966	Economy	4000.00
0005434407884	26966	Economy	4000.00
0005434407908	26966	Economy	4000.00
0005434407924	26966	Economy	4000.00
0005434407896	26966	Economy	4000.00
0005435310980	26966	Economy	4000.00
0005434407917	26966	Economy	4000.00
0005432153952	26966	Economy	4000.00
0005434407890	26966	Economy	4000.00
0005434407921	26966	Economy	4000.00
0005434407875	26966	Economy	4000.00
0005435310963	26966	Economy	4000.00
0005432153955	26966	Economy	4000.00
0005434407903	26966	Economy	4000.00
0005434407910	26966	Economy	4000.00
0005434407879	26966	Economy	4000.00
0005435310969	26966	Economy	4000.00
0005434407922	26966	Economy	4000.00
0005435310935	26966	Economy	4000.00
0005432153950	26966	Economy	4000.00
0005434407889	26966	Economy	4000.00
0005434407927	26966	Economy	4000.00
0005434407893	26966	Economy	4000.00
0005434407905	26966	Economy	4000.00
0005434407876	26966	Economy	4000.00
0005434407906	26966	Economy	4000.00
0005432153953	26966	Economy	4000.00
0005435310970	26966	Economy	4000.00
0005434407900	26966	Economy	4000.00
0005435310972	26966	Economy	4000.00
0005435310973	26966	Economy	4000.00
0005434407872	26966	Economy	4000.00
0005434407902	26966	Economy	4000.00
0005434407898	26966	Economy	4000.00
0005434407892	26966	Economy	4000.00
0005434407888	26966	Economy	4000.00
0005434407914	26966	Economy	4000.00
0005434407912	26966	Economy	4000.00
0005432153949	26966	Economy	4000.00
0005434407886	26966	Economy	4000.00
0005434407867	26966	Economy	4000.00
0005434407913	26966	Economy	4000.00
0005434319415	5710	Business	43300.00
0005433123780	5710	Business	43300.00
0005433123711	5710	Business	43300.00
0005433123823	5710	Economy	14400.00
0005434319422	5710	Economy	14400.00
0005433123798	5710	Economy	15900.00
0005434319414	5710	Economy	15900.00
0005433123733	5710	Economy	14400.00
0005433123777	5710	Economy	14400.00
0005433123813	5710	Economy	14400.00
0005434319418	5710	Economy	14400.00
0005434311224	5710	Economy	14400.00
0005434311225	5710	Economy	14400.00
0005432109708	5710	Economy	14400.00
0005434319420	5710	Economy	14400.00
0005434311223	5710	Economy	14400.00
0005434319416	5710	Economy	14400.00
0005433123858	5710	Economy	14400.00
0005433123712	5710	Economy	14400.00
0005433123740	5710	Economy	14400.00
0005432109709	5710	Economy	14400.00
0005433123797	5710	Economy	14400.00
0005433123732	5710	Economy	14400.00
0005434319417	5710	Economy	14400.00
0005434319421	5710	Economy	14400.00
0005433123812	5710	Economy	14400.00
0005433123826	5710	Economy	14400.00
0005433123717	5710	Economy	14400.00
0005434319419	5710	Economy	14400.00
0005432109710	5710	Economy	14400.00
0005433123778	5710	Economy	14400.00
0005434312308	15696	Business	43300.00
0005434319365	15696	Business	43300.00
0005434312315	15696	Business	43300.00
0005434319366	15696	Business	43300.00
0005433123978	15696	Business	43300.00
0005434319330	15696	Business	43300.00
0005434312305	15696	Business	43300.00
0005434319275	15696	Economy	14400.00
0005434311203	15696	Economy	14400.00
0005433123974	15696	Economy	15900.00
0005433123986	15696	Economy	14400.00
0005434319364	15696	Economy	14400.00
0005433123989	15696	Economy	14400.00
0005434319360	15696	Economy	14400.00
0005434319315	15696	Economy	14400.00
0005433123983	15696	Economy	14400.00
0005434319269	15696	Economy	14400.00
0005434319316	15696	Economy	14400.00
0005434319361	15696	Economy	14400.00
0005433123975	15696	Economy	14400.00
0005433123977	15696	Economy	14400.00
0005433123982	15696	Economy	14400.00
0005434319333	15696	Economy	14400.00
0005433123987	15696	Economy	14400.00
0005433123979	15696	Economy	14400.00
0005434319289	15696	Economy	14400.00
0005433123981	15696	Economy	14400.00
0005434312307	15696	Economy	14400.00
0005434312306	15696	Economy	14400.00
0005433123984	15696	Economy	14400.00
0005433123988	15696	Economy	14400.00
0005434319332	15696	Economy	14400.00
0005433123985	15696	Economy	14400.00
0005434319328	15696	Economy	14400.00
0005433123980	15696	Economy	14400.00
0005434319331	15696	Economy	14400.00
0005434319310	15696	Economy	14400.00
0005434319335	15696	Economy	14400.00
0005434319334	15696	Economy	14400.00
0005433123976	15696	Economy	14400.00
0005434484359	8990	Economy	24900.00
0005434484364	8990	Economy	24900.00
0005434484363	8990	Economy	24900.00
0005434484360	8990	Economy	24900.00
0005434484365	8990	Economy	24900.00
0005434484362	8990	Economy	24900.00
0005434189156	8990	Economy	24900.00
0005434189127	8990	Economy	24900.00
0005434484361	8990	Economy	24900.00
0005434189126	8990	Economy	24900.00
0005434189189	16632	Economy	27400.00
0005434484322	16632	Economy	24900.00
0005434189191	16632	Economy	24900.00
0005434189190	16632	Economy	24900.00
0005434189193	16632	Economy	24900.00
0005434189192	16632	Economy	24900.00
0005434484327	16632	Economy	24900.00
0005434189188	16632	Economy	24900.00
0005433123982	7669	Business	11100.00
0005433123985	7669	Business	11100.00
0005433123974	7669	Business	11100.00
0005433123978	7669	Economy	3700.00
0005433722167	7669	Economy	3700.00
0005433123975	7669	Economy	3700.00
0005433123981	7669	Economy	3700.00
0005433123977	7669	Economy	3700.00
0005433123980	7669	Economy	3700.00
0005433123983	7669	Economy	3700.00
0005433123979	7669	Economy	3700.00
0005433123976	7669	Economy	3700.00
0005433722169	7669	Economy	3700.00
0005433123986	7669	Economy	3700.00
0005433123984	7669	Economy	3700.00
0005433123987	7669	Economy	3700.00
0005433123989	7669	Economy	3700.00
0005433123988	7669	Economy	3700.00
0005432693135	7668	Business	11100.00
0005432720962	7668	Business	11100.00
0005433450016	7668	Business	11100.00
0005432720960	7668	Business	11100.00
0005432720971	7668	Business	11100.00
0005432693140	7668	Business	11100.00
0005433450012	7668	Business	11100.00
0005432720974	7668	Business	11100.00
0005432693158	7668	Business	11100.00
0005432693141	7668	Business	11100.00
0005432693139	7668	Business	11100.00
0005433450009	7668	Economy	3700.00
0005432720967	7668	Economy	3700.00
0005432693151	7668	Economy	3700.00
0005432720954	7668	Economy	3700.00
0005432720975	7668	Economy	3700.00
0005432693145	7668	Economy	3700.00
0005433450022	7668	Economy	3700.00
0005433450024	7668	Economy	4100.00
0005432693156	7668	Economy	4100.00
0005432693132	7668	Economy	4100.00
0005432693146	7668	Economy	4100.00
0005432071580	7668	Economy	4100.00
0005432071578	7668	Economy	3700.00
0005432720959	7668	Economy	3700.00
0005432693131	7668	Economy	3700.00
0005432693133	7668	Economy	3700.00
0005433450017	7668	Economy	3700.00
0005432071581	7668	Economy	3700.00
0005432720955	7668	Economy	3700.00
0005432693152	7668	Economy	3700.00
0005433450011	7668	Economy	3700.00
0005433450028	7668	Economy	3700.00
0005432720970	7668	Economy	3700.00
0005432693157	7668	Economy	3700.00
0005432720950	7668	Economy	3700.00
0005433450027	7668	Economy	3700.00
0005432693134	7668	Economy	3700.00
0005432720957	7668	Economy	3700.00
0005432693128	7668	Economy	3700.00
0005433450014	7668	Economy	3700.00
0005432693149	7668	Economy	3700.00
0005433450019	7668	Economy	3700.00
0005432720977	7668	Economy	3700.00
0005432720964	7668	Economy	3700.00
0005432720956	7668	Economy	3700.00
0005432693136	7668	Economy	3700.00
0005432693130	7668	Economy	3700.00
0005433450021	7668	Economy	3700.00
0005432720961	7668	Economy	3700.00
0005432720966	7668	Economy	3700.00
0005433450023	7668	Economy	3700.00
0005432693154	7668	Economy	3700.00
0005432720965	7668	Economy	3700.00
0005432693155	7668	Economy	3700.00
0005432720951	7668	Economy	3700.00
0005433450015	7668	Economy	3700.00
0005432693150	7668	Economy	3700.00
0005432720958	7668	Economy	3700.00
0005432693148	7668	Economy	3700.00
0005432693143	7668	Economy	3700.00
0005432720952	7668	Economy	3700.00
0005433450020	7668	Economy	3700.00
0005432720968	7668	Economy	3700.00
0005432693144	7668	Economy	3700.00
0005432693127	7668	Economy	3700.00
0005433450025	7668	Economy	3700.00
0005432720976	7668	Economy	3700.00
0005432071579	7668	Economy	3700.00
0005432720972	7668	Economy	3700.00
0005432693142	7668	Economy	3700.00
0005432720969	7668	Economy	3700.00
0005433450010	7668	Economy	3700.00
0005432693153	7668	Economy	3700.00
0005432720953	7668	Economy	3700.00
0005433450013	7668	Economy	3700.00
0005433450018	7668	Economy	3700.00
0005433450026	7668	Economy	3700.00
0005432720963	7668	Economy	3700.00
0005433450008	7668	Economy	3700.00
0005432720973	7668	Economy	3700.00
0005432693147	7668	Economy	3700.00
0005432693138	7668	Economy	3700.00
0005432693129	7668	Economy	3700.00
0005432693137	7668	Economy	3700.00
0005432692802	30290	Business	11100.00
0005433449922	30290	Business	11100.00
0005432692782	30290	Business	11100.00
0005433449835	30290	Business	11100.00
0005432692877	30290	Business	11100.00
0005432692993	30290	Business	11100.00
0005433449763	30290	Economy	3700.00
0005433449803	30290	Economy	3700.00
0005433449796	30290	Economy	3700.00
0005433449826	30290	Economy	3700.00
0005432692888	30290	Economy	3700.00
0005432692884	30290	Economy	4100.00
0005432692994	30290	Economy	4100.00
0005433449850	30290	Economy	4100.00
0005433449805	30290	Economy	4100.00
0005433449836	30290	Economy	3700.00
0005433449866	30290	Economy	3700.00
0005432692781	30290	Economy	3700.00
0005432692799	30290	Economy	3700.00
0005432692762	30290	Economy	3700.00
0005433449871	30290	Economy	3700.00
0005432692964	30290	Economy	3700.00
0005432692728	30290	Economy	3700.00
0005432692893	30290	Economy	3700.00
0005432692829	30290	Economy	3700.00
0005432692790	30290	Economy	3700.00
0005432692965	30290	Economy	3700.00
0005433449882	30290	Economy	3700.00
0005432692966	30290	Economy	3700.00
0005433449867	30290	Economy	3700.00
0005433449838	30290	Economy	3700.00
0005433449862	30290	Economy	3700.00
0005432692789	30290	Economy	3700.00
0005433449887	30290	Economy	3700.00
0005432692889	30290	Economy	3700.00
0005432692923	30290	Economy	3700.00
0005432692791	30290	Economy	3700.00
0005433449874	30290	Economy	3700.00
0005433449875	30290	Economy	3700.00
0005432692825	30290	Economy	3700.00
0005433449865	30290	Economy	3700.00
0005432692758	30290	Economy	3700.00
0005432692800	30290	Economy	3700.00
0005432692878	30290	Economy	3700.00
0005433449837	30290	Economy	3700.00
0005432692992	30290	Economy	3700.00
0005433449889	30290	Economy	3700.00
0005432692812	30290	Economy	3700.00
0005433449825	30290	Economy	3700.00
0005432692783	30290	Economy	3700.00
0005432692983	30290	Economy	3700.00
0005432692761	30290	Economy	3700.00
0005433449888	30290	Economy	3700.00
0005433449872	30290	Economy	3700.00
0005433449831	30290	Economy	3700.00
0005432692982	30290	Economy	3700.00
0005432692801	30290	Economy	3700.00
0005433449883	30290	Economy	3700.00
0005433449840	30290	Economy	3700.00
0005433449804	30290	Economy	3700.00
0005432720787	30289	Business	11100.00
0005432720692	30289	Business	11100.00
0005432720680	30289	Business	11100.00
0005433123733	30289	Business	11100.00
0005432720746	30289	Business	11100.00
0005432720685	30289	Business	11100.00
0005433123712	30289	Business	11100.00
0005433722233	30289	Economy	3700.00
0005433123823	30289	Economy	3700.00
0005433722236	30289	Economy	3700.00
0005432720669	30289	Economy	3700.00
0005432720792	30289	Economy	3700.00
0005432720706	30289	Economy	3700.00
0005432720817	30289	Economy	4100.00
0005433123812	30289	Economy	4100.00
0005432720670	30289	Economy	4100.00
0005433123732	30289	Economy	3700.00
0005433123711	30289	Economy	3700.00
0005432720786	30289	Economy	3700.00
0005433123813	30289	Economy	3700.00
0005433123740	30289	Economy	3700.00
0005432720762	30289	Economy	3700.00
0005432720707	30289	Economy	3700.00
0005433123797	30289	Economy	3700.00
0005433722234	30289	Economy	3700.00
0005432720810	30289	Economy	3700.00
0005433722232	30289	Economy	3700.00
0005433123777	30289	Economy	3700.00
0005432720761	30289	Economy	3700.00
0005432720684	30289	Economy	3700.00
0005432720791	30289	Economy	3700.00
0005432720782	30289	Economy	3700.00
0005433123778	30289	Economy	3700.00
0005433722235	30289	Economy	3700.00
0005433123780	30289	Economy	3700.00
0005433123798	30289	Economy	3700.00
0005433123858	30289	Economy	3700.00
0005432720785	30289	Economy	3700.00
0005432720815	30289	Economy	3700.00
0005433123717	30289	Economy	3700.00
0005433123826	30289	Economy	3700.00
0005434586666	1401	Business	70400.00
0005432968822	1401	Business	70400.00
0005434586672	1401	Business	70400.00
0005432927954	1401	Business	70400.00
0005434514974	1401	Business	70400.00
0005433192951	1401	Business	70400.00
0005434586680	1401	Business	70400.00
0005434586661	1401	Business	70400.00
0005434586657	1401	Economy	23500.00
0005433192953	1401	Economy	23500.00
0005432927937	1401	Economy	23500.00
0005434514972	1401	Economy	23500.00
0005433192997	1401	Economy	23500.00
0005432968828	1401	Economy	23500.00
0005434586667	1401	Economy	23500.00
0005434513586	1401	Economy	25800.00
0005434586681	1401	Economy	25800.00
0005433525067	1401	Economy	23500.00
0005433724818	1401	Economy	23500.00
0005433724815	1401	Economy	23500.00
0005434586679	1401	Economy	23500.00
0005432271011	1401	Economy	23500.00
0005434586658	1401	Economy	23500.00
0005434586669	1401	Economy	23500.00
0005433192954	1401	Economy	23500.00
0005433525064	1401	Economy	23500.00
0005434586674	1401	Economy	23500.00
0005433192938	1401	Economy	23500.00
0005434513585	1401	Economy	23500.00
0005433724817	1401	Economy	23500.00
0005433724816	1401	Economy	23500.00
0005432968821	1401	Economy	23500.00
0005432271010	1401	Economy	23500.00
0005434586663	1401	Economy	23500.00
0005434586671	1401	Economy	23500.00
0005434586678	1401	Economy	23500.00
0005434513584	1401	Economy	23500.00
0005433192939	1401	Economy	23500.00
0005434586660	1401	Economy	23500.00
0005433525069	1401	Economy	23500.00
0005434586670	1401	Economy	23500.00
0005433525063	1401	Economy	23500.00
0005434586664	1401	Economy	23500.00
0005434586662	1401	Economy	23500.00
0005434586677	1401	Economy	23500.00
0005433192998	1401	Economy	23500.00
0005433192952	1401	Economy	23500.00
0005432968829	1401	Economy	23500.00
0005433193022	1401	Economy	23500.00
0005434586673	1401	Economy	23500.00
0005434586659	1401	Economy	23500.00
0005434586682	1401	Economy	23500.00
0005434586675	1401	Economy	23500.00
0005434514973	1401	Economy	23500.00
0005433525060	1401	Economy	23500.00
0005434586665	1401	Economy	23500.00
0005433525066	1401	Economy	23500.00
0005434586668	1401	Economy	23500.00
0005432927952	1401	Economy	23500.00
0005432968820	1401	Economy	23500.00
0005433525068	1401	Economy	23500.00
0005433525059	1401	Economy	23500.00
0005433525058	1401	Economy	23500.00
0005433525062	1401	Economy	23500.00
0005433525061	1401	Economy	23500.00
0005433192989	1401	Economy	23500.00
0005434586676	1401	Economy	23500.00
0005433525065	1401	Economy	23500.00
0005433192955	1401	Economy	23500.00
0005432927938	1401	Economy	23500.00
0005434513587	1401	Economy	23500.00
0005432927990	18537	Business	70400.00
0005433193069	18537	Business	70400.00
0005434586468	18537	Business	70400.00
0005432927991	18537	Business	70400.00
0005433193077	18537	Business	70400.00
0005434586418	18537	Business	70400.00
0005433524966	18537	Economy	23500.00
0005434586421	18537	Economy	23500.00
0005434586439	18537	Economy	23500.00
0005434586539	18537	Economy	23500.00
0005433724777	18537	Economy	25800.00
0005433193078	18537	Economy	25800.00
0005434586438	18537	Economy	23500.00
0005433524946	18537	Economy	23500.00
0005433193076	18537	Economy	23500.00
0005433193073	18537	Economy	23500.00
0005433193079	18537	Economy	23500.00
0005433524952	18537	Economy	23500.00
0005433524892	18537	Economy	23500.00
0005433193080	18537	Economy	23500.00
0005433193070	18537	Economy	23500.00
0005434586479	18537	Economy	23500.00
0005433193081	18537	Economy	23500.00
0005434586406	18537	Economy	23500.00
0005433193071	18537	Economy	23500.00
0005434586464	18537	Economy	23500.00
0005433524943	18537	Economy	23500.00
0005433524922	18537	Economy	23500.00
0005433724776	18537	Economy	23500.00
0005434586470	18537	Economy	23500.00
0005434586441	18537	Economy	23500.00
0005434586472	18537	Economy	23500.00
0005433524967	18537	Economy	23500.00
0005434586566	18537	Economy	23500.00
0005434586491	18537	Economy	23500.00
0005433724775	18537	Economy	23500.00
0005434586444	18537	Economy	23500.00
0005432927993	18537	Economy	23500.00
0005433524893	18537	Economy	23500.00
0005434586467	18537	Economy	23500.00
0005434586478	18537	Economy	23500.00
0005432968845	18537	Economy	23500.00
0005432927992	18537	Economy	23500.00
0005433524921	18537	Economy	23500.00
0005433193072	18537	Economy	23500.00
0005432927994	18537	Economy	23500.00
0005434586422	18537	Economy	23500.00
0005433524965	18537	Economy	23500.00
0005432968844	18537	Economy	23500.00
0005434586417	18537	Economy	23500.00
0005433193075	18537	Economy	23500.00
0005434586490	18537	Economy	23500.00
0005434586469	18537	Economy	23500.00
0005434586473	18537	Economy	23500.00
0005432927989	18537	Economy	23500.00
0005434586516	18537	Economy	23500.00
0005433524953	18537	Economy	23500.00
0005433193074	18537	Economy	23500.00
0005434344267	11456	Economy	4300.00
0005434344254	11456	Economy	4300.00
0005434344265	11456	Economy	4300.00
0005434344251	11456	Economy	4300.00
0005434344270	11456	Economy	4000.00
0005434344276	11456	Economy	4000.00
0005434344284	11456	Economy	4000.00
0005434344257	11456	Economy	4000.00
0005434344275	11456	Economy	4000.00
0005434344266	11456	Economy	4000.00
0005434344268	11456	Economy	4000.00
0005434344249	11456	Economy	4000.00
0005434344277	11456	Economy	4000.00
0005435305001	11456	Economy	4000.00
0005434344281	11456	Economy	4000.00
0005434344263	11456	Economy	4000.00
0005434344271	11456	Economy	4000.00
0005434142620	11456	Economy	4000.00
0005435305002	11456	Economy	4000.00
0005434344262	11456	Economy	4000.00
0005434344285	11456	Economy	4000.00
0005434142618	11456	Economy	4000.00
0005435302156	11456	Economy	4000.00
0005435302172	11456	Economy	4000.00
0005434344280	11456	Economy	4000.00
0005434344250	11456	Economy	4000.00
0005434344269	11456	Economy	4000.00
0005434142621	11456	Economy	4000.00
0005435302155	11456	Economy	4000.00
0005434344252	11456	Economy	4000.00
0005434344258	11456	Economy	4000.00
0005434344260	11456	Economy	4000.00
0005434344273	11456	Economy	4000.00
0005434344279	11456	Economy	4000.00
0005434344259	11456	Economy	4000.00
0005434344283	11456	Economy	4000.00
0005434344255	11456	Economy	4000.00
0005434344282	11456	Economy	4000.00
0005434344286	11456	Economy	4000.00
0005434142619	11456	Economy	4000.00
0005434344261	11456	Economy	4000.00
0005434344256	11456	Economy	4000.00
0005434344253	11456	Economy	4000.00
0005434344274	11456	Economy	4000.00
0005434344272	11456	Economy	4000.00
0005434344278	11456	Economy	4000.00
0005434344264	11456	Economy	4000.00
0005435304168	29754	Economy	4300.00
0005434343814	29754	Economy	4300.00
0005435304169	29754	Economy	4300.00
0005435304171	29754	Economy	4300.00
0005434343936	29754	Economy	4000.00
0005434343792	29754	Economy	4000.00
0005434343980	29754	Economy	4000.00
0005435304172	29754	Economy	4000.00
0005434343791	29754	Economy	4000.00
0005434344017	29754	Economy	4000.00
0005434343932	29754	Economy	4000.00
0005434343861	29754	Economy	4000.00
0005435304173	29754	Economy	4000.00
0005434343902	29754	Economy	4000.00
0005434343937	29754	Economy	4000.00
0005434142592	29754	Economy	4000.00
0005434343858	29754	Economy	4000.00
0005434344022	29754	Economy	4000.00
0005434343860	29754	Economy	4000.00
0005434344059	29754	Economy	4000.00
0005434344006	29754	Economy	4000.00
0005434343981	29754	Economy	4000.00
0005434142580	29754	Economy	4000.00
0005434344018	29754	Economy	4000.00
0005434343984	29754	Economy	4000.00
0005434343877	29754	Economy	4000.00
0005434343775	29754	Economy	4000.00
0005434142581	29754	Economy	4000.00
0005434343943	29754	Economy	4000.00
0005434343954	29754	Economy	4000.00
0005434344048	29754	Economy	4000.00
0005434343859	29754	Economy	4000.00
0005434343978	29754	Economy	4000.00
0005434343862	29754	Economy	4000.00
0005434344016	29754	Economy	4000.00
0005434344125	29754	Economy	4000.00
0005434142597	29754	Economy	4000.00
0005434343857	29754	Economy	4000.00
0005434343815	29754	Economy	4000.00
0005434343926	29754	Economy	4000.00
0005434343875	29754	Economy	4000.00
0005434343944	29754	Economy	4000.00
0005434343961	29754	Economy	4000.00
0005435304170	29754	Economy	4000.00
0005435824677	1259	Business	199800.00
0005435824697	1259	Business	199800.00
0005432284566	1259	Business	199800.00
0005433415570	1259	Business	199800.00
0005433415572	1259	Business	199800.00
0005433415534	1259	Business	199800.00
0005435824688	1259	Economy	66600.00
0005435824673	1259	Economy	66600.00
0005433415539	1259	Economy	66600.00
0005435824674	1259	Economy	66600.00
0005433415574	1259	Economy	66600.00
0005435824694	1259	Economy	66600.00
0005433415577	1259	Economy	73200.00
0005435824699	1259	Economy	73200.00
0005435824676	1259	Economy	66600.00
0005433415576	1259	Economy	66600.00
0005433415621	1259	Economy	66600.00
0005435824690	1259	Economy	66600.00
0005435824696	1259	Economy	66600.00
0005435824683	1259	Economy	66600.00
0005435824698	1259	Economy	66600.00
0005435824692	1259	Economy	66600.00
0005433415618	1259	Economy	66600.00
0005433415613	1259	Economy	66600.00
0005433415535	1259	Economy	66600.00
0005433415573	1259	Economy	66600.00
0005435824675	1259	Economy	66600.00
0005435824691	1259	Economy	66600.00
0005435824684	1259	Economy	66600.00
0005435824680	1259	Economy	66600.00
0005432284565	1259	Economy	66600.00
0005433415602	1259	Economy	66600.00
0005435824686	1259	Economy	66600.00
0005432284567	1259	Economy	66600.00
0005435824681	1259	Economy	66600.00
0005433415575	1259	Economy	66600.00
0005435824693	1259	Economy	66600.00
0005432284564	1259	Economy	66600.00
0005435824682	1259	Economy	66600.00
0005433415599	1259	Economy	66600.00
0005435824685	1259	Economy	66600.00
0005435824689	1259	Economy	66600.00
0005435824695	1259	Economy	66600.00
0005435824679	1259	Economy	66600.00
0005433415598	1259	Economy	66600.00
0005433415620	1259	Economy	66600.00
0005435824678	1259	Economy	66600.00
0005435824687	1259	Economy	66600.00
0005433415600	1259	Economy	66600.00
0005433415581	1259	Economy	66600.00
0005433415693	18010	Business	199800.00
0005435824469	18010	Business	199800.00
0005433415701	18010	Business	199800.00
0005435824411	18010	Business	199800.00
0005435824500	18010	Business	199800.00
0005433415698	18010	Business	199800.00
0005435824357	18010	Business	199800.00
0005433415692	18010	Economy	66600.00
0005435824285	18010	Economy	66600.00
0005433415702	18010	Economy	66600.00
0005435824512	18010	Economy	66600.00
0005433415700	18010	Economy	66600.00
0005433415696	18010	Economy	66600.00
0005435824422	18010	Economy	66600.00
0005435824346	18010	Economy	66600.00
0005435824402	18010	Economy	66600.00
0005435824467	18010	Economy	66600.00
0005433415699	18010	Economy	66600.00
0005435824508	18010	Economy	66600.00
0005435824356	18010	Economy	66600.00
0005435824419	18010	Economy	66600.00
0005435824552	18010	Economy	66600.00
0005435824345	18010	Economy	66600.00
0005435824515	18010	Economy	66600.00
0005435824405	18010	Economy	66600.00
0005435824431	18010	Economy	66600.00
0005435824474	18010	Economy	66600.00
0005435824358	18010	Economy	66600.00
0005435824335	18010	Economy	66600.00
0005435824284	18010	Economy	66600.00
0005435824460	18010	Economy	66600.00
0005435824516	18010	Economy	66600.00
0005433415691	18010	Economy	66600.00
0005433415694	18010	Economy	66600.00
0005433415690	18010	Economy	66600.00
0005435824448	18010	Economy	66600.00
0005435824498	18010	Economy	66600.00
0005435824507	18010	Economy	66600.00
0005435824468	18010	Economy	66600.00
0005433415697	18010	Economy	66600.00
0005433415689	18010	Economy	66600.00
0005433415703	18010	Economy	66600.00
0005435824511	18010	Economy	66600.00
0005433415695	18010	Economy	66600.00
0005433415688	18010	Economy	66600.00
0005435824586	18010	Economy	66600.00
0005435824359	18010	Economy	66600.00
0005435824412	18010	Economy	66600.00
0005434460504	12577	Economy	14800.00
0005434461643	12577	Economy	14800.00
0005434460505	12577	Economy	14800.00
0005434460508	12577	Economy	13500.00
0005434461648	12577	Economy	13500.00
0005434460501	12577	Economy	13500.00
0005434461649	12577	Economy	13500.00
0005434460506	12577	Economy	13500.00
0005434461645	12577	Economy	13500.00
0005434460503	12577	Economy	13500.00
0005434460500	12577	Economy	13500.00
0005434461642	12577	Economy	13500.00
0005434461644	12577	Economy	13500.00
0005434460507	12577	Economy	13500.00
0005434461646	12577	Economy	13500.00
0005434461650	12577	Economy	13500.00
0005434461647	12577	Economy	13500.00
0005434460502	12577	Economy	13500.00
0005432783905	5628	Business	27800.00
0005432783896	5628	Business	27800.00
0005432783935	5628	Business	27800.00
0005432783903	5628	Business	27800.00
0005432783937	5628	Business	27800.00
0005432783925	5628	Business	27800.00
0005432783919	5628	Business	27800.00
0005435242690	5628	Business	27800.00
0005432783885	5628	Business	27800.00
0005432783927	5628	Business	27800.00
0005435242588	5628	Business	27800.00
0005435242632	5628	Business	27800.00
0005432783906	5628	Economy	9300.00
0005435242572	5628	Economy	9300.00
0005432783912	5628	Economy	9300.00
0005435242671	5628	Economy	9300.00
0005432783922	5628	Economy	9300.00
0005432783886	5628	Economy	9300.00
0005435242722	5628	Economy	9300.00
0005432783939	5628	Economy	9300.00
0005435242630	5628	Economy	9300.00
0005432783917	5628	Economy	9300.00
0005432783936	5628	Economy	10200.00
0005432783889	5628	Economy	10200.00
0005432783929	5628	Economy	10200.00
0005435476695	5628	Economy	10200.00
0005435242631	5628	Economy	10200.00
0005432783932	5628	Economy	9300.00
0005432783908	5628	Economy	9300.00
0005432783928	5628	Economy	9300.00
0005432783921	5628	Economy	9300.00
0005435242663	5628	Economy	9300.00
0005432783923	5628	Economy	9300.00
0005432783914	5628	Economy	9300.00
0005432783895	5628	Economy	9300.00
0005435242785	5628	Economy	9300.00
0005432783893	5628	Economy	9300.00
0005432783926	5628	Economy	9300.00
0005435476744	5628	Economy	9300.00
0005432783888	5628	Economy	9300.00
0005432783892	5628	Economy	9300.00
0005432783904	5628	Economy	9300.00
0005432783898	5628	Economy	9300.00
0005435476730	5628	Economy	9300.00
0005435242724	5628	Economy	9300.00
0005432783916	5628	Economy	9300.00
0005432783902	5628	Economy	9300.00
0005432783887	5628	Economy	9300.00
0005432783900	5628	Economy	9300.00
0005435242670	5628	Economy	9300.00
0005432783918	5628	Economy	9300.00
0005435242657	5628	Economy	9300.00
0005432783897	5628	Economy	9300.00
0005432783934	5628	Economy	9300.00
0005435242673	5628	Economy	9300.00
0005435476731	5628	Economy	9300.00
0005435242786	5628	Economy	9300.00
0005432783924	5628	Economy	9300.00
0005432783901	5628	Economy	9300.00
0005432143995	5628	Economy	9300.00
0005432783890	5628	Economy	9300.00
0005432783915	5628	Economy	9300.00
0005432783891	5628	Economy	9300.00
0005432783909	5628	Economy	9300.00
0005435242694	5628	Economy	9300.00
0005432783911	5628	Economy	9300.00
0005435242760	5628	Economy	9300.00
0005432783933	5628	Economy	9300.00
0005432783907	5628	Economy	9300.00
0005432143994	5628	Economy	9300.00
0005435242571	5628	Economy	9300.00
0005435476711	5628	Economy	9300.00
0005435476696	5628	Economy	9300.00
0005432783920	5628	Economy	9300.00
0005435242555	5628	Economy	9300.00
0005432783894	5628	Economy	9300.00
0005432783930	5628	Economy	9300.00
0005435476710	5628	Economy	9300.00
0005435476709	5628	Economy	9300.00
0005435476713	5628	Economy	9300.00
0005432783899	5628	Economy	9300.00
0005435242611	5628	Economy	9300.00
0005432783931	5628	Economy	9300.00
0005432783913	5628	Economy	9300.00
0005435242787	5628	Economy	9300.00
0005432143993	5628	Economy	9300.00
0005435242612	5628	Economy	9300.00
0005435242587	5628	Economy	9300.00
0005432783910	5628	Economy	9300.00
0005435242658	5628	Economy	9300.00
0005432783938	5628	Economy	9300.00
0005435476705	5628	Economy	9300.00
0005432783401	15382	Business	27800.00
0005432783635	15382	Business	27800.00
0005432783214	15382	Business	27800.00
0005435242896	15382	Business	27800.00
0005432783062	15382	Business	27800.00
0005435242891	15382	Business	27800.00
0005432783296	15382	Business	27800.00
0005432783232	15382	Business	27800.00
0005432783136	15382	Business	27800.00
0005432783231	15382	Business	27800.00
0005435242903	15382	Business	27800.00
0005432783646	15382	Economy	9300.00
0005435242899	15382	Economy	9300.00
0005432783536	15382	Economy	9300.00
0005435242890	15382	Economy	9300.00
0005432783135	15382	Economy	9300.00
0005435242905	15382	Economy	9300.00
0005435242892	15382	Economy	9300.00
0005432783361	15382	Economy	9300.00
0005432783142	15382	Economy	10200.00
0005432783374	15382	Economy	10200.00
0005432783460	15382	Economy	10200.00
0005432783534	15382	Economy	10200.00
0005432783486	15382	Economy	10200.00
0005435242902	15382	Economy	9300.00
0005435242900	15382	Economy	9300.00
0005435242886	15382	Economy	9300.00
0005435242889	15382	Economy	9300.00
0005435242895	15382	Economy	9300.00
0005432783485	15382	Economy	9300.00
0005432783410	15382	Economy	9300.00
0005432783573	15382	Economy	9300.00
0005432783498	15382	Economy	9300.00
0005435242898	15382	Economy	9300.00
0005432783471	15382	Economy	9300.00
0005432783373	15382	Economy	9300.00
0005432783407	15382	Economy	9300.00
0005432783063	15382	Economy	9300.00
0005432783397	15382	Economy	9300.00
0005432783306	15382	Economy	9300.00
0005432783411	15382	Economy	9300.00
0005432783574	15382	Economy	9300.00
0005435242897	15382	Economy	9300.00
0005435476766	15382	Economy	9300.00
0005435242881	15382	Economy	9300.00
0005435242888	15382	Economy	9300.00
0005432783356	15382	Economy	9300.00
0005432783629	15382	Economy	9300.00
0005435242893	15382	Economy	9300.00
0005435242882	15382	Economy	9300.00
0005432783365	15382	Economy	9300.00
0005432783141	15382	Economy	9300.00
0005432783584	15382	Economy	9300.00
0005432783545	15382	Economy	9300.00
0005432783415	15382	Economy	9300.00
0005435476764	15382	Economy	9300.00
0005432783126	15382	Economy	9300.00
0005435242906	15382	Economy	9300.00
0005435476763	15382	Economy	9300.00
0005432783550	15382	Economy	9300.00
0005432783271	15382	Economy	9300.00
0005435242884	15382	Economy	9300.00
0005435242901	15382	Economy	9300.00
0005432783442	15382	Economy	9300.00
0005435242887	15382	Economy	9300.00
0005432783362	15382	Economy	9300.00
0005432783376	15382	Economy	9300.00
0005432783467	15382	Economy	9300.00
0005435242883	15382	Economy	9300.00
0005432783227	15382	Economy	9300.00
0005432783314	15382	Economy	9300.00
0005432783269	15382	Economy	9300.00
0005435242907	15382	Economy	9300.00
0005432783059	15382	Economy	9300.00
0005435242885	15382	Economy	9300.00
0005432783472	15382	Economy	9300.00
0005432783137	15382	Economy	9300.00
0005432783461	15382	Economy	9300.00
0005435242894	15382	Economy	9300.00
0005432783428	15382	Economy	9300.00
0005432783391	15382	Economy	9300.00
0005435242904	15382	Economy	9300.00
0005432783217	15382	Economy	9300.00
0005432783535	15382	Economy	9300.00
0005432783537	15382	Economy	9300.00
0005432783392	15382	Economy	9300.00
0005435242880	15382	Economy	9300.00
0005432783182	15382	Economy	9300.00
0005435476765	15382	Economy	9300.00
0005432783370	15382	Economy	9300.00
0005432783630	15382	Economy	9300.00
0005435476767	15382	Economy	9300.00
0005435850883	4357	Economy	7000.00
0005435850852	4357	Economy	7000.00
0005432848338	4357	Economy	6300.00
0005434463934	4357	Economy	6300.00
0005435850881	4357	Economy	6300.00
0005435850853	4357	Economy	6300.00
0005435850882	4357	Economy	6300.00
0005432848345	4357	Economy	6300.00
0005434462796	4357	Economy	6300.00
0005432848344	4357	Economy	6300.00
0005432848347	4357	Economy	6300.00
0005434463935	4357	Economy	6300.00
0005434462794	4357	Economy	6300.00
0005432848346	4357	Economy	6300.00
0005432848340	4357	Economy	6300.00
0005435850854	4357	Economy	6300.00
0005432848343	4357	Economy	6300.00
0005434462795	4357	Economy	6300.00
0005432848348	4357	Economy	6300.00
0005432848351	4357	Economy	6300.00
0005432848337	4357	Economy	6300.00
0005432848342	4357	Economy	6300.00
0005432848350	4357	Economy	6300.00
0005432848349	4357	Economy	6300.00
0005432848339	4357	Economy	6300.00
0005432848341	4357	Economy	6300.00
0005432848275	28875	Economy	7000.00
0005432848254	28875	Economy	7000.00
0005432848273	28875	Economy	7000.00
0005432848198	28875	Economy	7000.00
0005432848231	28875	Economy	6300.00
0005432848190	28875	Economy	6300.00
0005432848274	28875	Economy	6300.00
0005432848243	28875	Economy	6300.00
0005432848207	28875	Economy	6300.00
0005432848272	28875	Economy	6300.00
0005432848196	28875	Economy	6300.00
0005432848189	28875	Economy	6300.00
0005434463923	28875	Economy	6300.00
0005432848267	28875	Economy	6300.00
0005434463922	28875	Economy	6300.00
0005432848223	28875	Economy	6300.00
0005435850927	28875	Economy	6300.00
0005432848208	28875	Economy	6300.00
0005432848213	28875	Economy	6300.00
0005435850934	28875	Economy	6300.00
0005435850929	28875	Economy	6300.00
0005435850930	28875	Economy	6300.00
0005432848187	28875	Economy	6300.00
0005435850931	28875	Economy	6300.00
0005432848268	28875	Economy	6300.00
0005432848181	28875	Economy	6300.00
0005432848186	28875	Economy	6300.00
0005435850926	28875	Economy	6300.00
0005432848242	28875	Economy	6300.00
0005432848165	28875	Economy	6300.00
0005435850928	28875	Economy	6300.00
0005432848244	28875	Economy	6300.00
0005435850933	28875	Economy	6300.00
0005432848185	28875	Economy	6300.00
0005434463907	28875	Economy	6300.00
0005432848180	28875	Economy	6300.00
0005435850932	28875	Economy	6300.00
0005432848197	28875	Economy	6300.00
0005434461621	28875	Economy	6300.00
0005432848214	28875	Economy	6300.00
0005434925871	6310	Business	11900.00
0005434925857	6310	Business	11900.00
0005433497026	6310	Business	11900.00
0005433497047	6310	Business	11900.00
0005434925870	6310	Business	11900.00
0005433497027	6310	Business	11900.00
0005434925863	6310	Business	11900.00
0005434925878	6310	Business	11900.00
0005434443738	6310	Economy	4000.00
0005433497043	6310	Economy	4000.00
0005433497037	6310	Economy	4000.00
0005434443742	6310	Economy	4000.00
0005433497056	6310	Economy	4000.00
0005434925867	6310	Economy	4000.00
0005433497032	6310	Economy	4000.00
0005433497028	6310	Economy	4000.00
0005434443745	6310	Economy	4000.00
0005433497044	6310	Economy	4000.00
0005432075238	6310	Economy	4400.00
0005433497031	6310	Economy	4400.00
0005433497036	6310	Economy	4000.00
0005434925876	6310	Economy	4000.00
0005433497038	6310	Economy	4000.00
0005432075237	6310	Economy	4000.00
0005434925869	6310	Economy	4000.00
0005433497055	6310	Economy	4000.00
0005433497049	6310	Economy	4000.00
0005434925875	6310	Economy	4000.00
0005433497045	6310	Economy	4000.00
0005433497034	6310	Economy	4000.00
0005433497039	6310	Economy	4000.00
0005434925872	6310	Economy	4000.00
0005434925860	6310	Economy	4000.00
0005433497054	6310	Economy	4000.00
0005434443741	6310	Economy	4000.00
0005434925858	6310	Economy	4000.00
0005434443751	6310	Economy	4000.00
0005434443750	6310	Economy	4000.00
0005434925864	6310	Economy	4000.00
0005434925862	6310	Economy	4000.00
0005434443748	6310	Economy	4000.00
0005433497040	6310	Economy	4000.00
0005434925879	6310	Economy	4000.00
0005434925866	6310	Economy	4000.00
0005434443753	6310	Economy	4000.00
0005434925882	6310	Economy	4000.00
0005434925874	6310	Economy	4000.00
0005434443739	6310	Economy	4000.00
0005434443747	6310	Economy	4000.00
0005434925881	6310	Economy	4000.00
0005433497046	6310	Economy	4000.00
0005434443746	6310	Economy	4000.00
0005434925868	6310	Economy	4000.00
0005432075239	6310	Economy	4000.00
0005434925861	6310	Economy	4000.00
0005433497051	6310	Economy	4000.00
0005434443744	6310	Economy	4000.00
0005433497030	6310	Economy	4000.00
0005434443743	6310	Economy	4000.00
0005433497033	6310	Economy	4000.00
0005433497053	6310	Economy	4000.00
0005434925865	6310	Economy	4000.00
0005433497042	6310	Economy	4000.00
0005434925873	6310	Economy	4000.00
0005433497029	6310	Economy	4000.00
0005434925859	6310	Economy	4000.00
0005434443740	6310	Economy	4000.00
0005434443754	6310	Economy	4000.00
0005434925880	6310	Economy	4000.00
0005433497052	6310	Economy	4000.00
0005433497048	6310	Economy	4000.00
0005433497041	6310	Economy	4000.00
0005434925877	6310	Economy	4000.00
0005434443752	6310	Economy	4000.00
0005433497035	6310	Economy	4000.00
0005433497057	6310	Economy	4000.00
0005433497050	6310	Economy	4000.00
0005434443749	6310	Economy	4000.00
0005433496887	20405	Business	11900.00
0005434443630	20405	Business	11900.00
0005434925501	20405	Business	11900.00
0005433496888	20405	Business	11900.00
0005433496884	20405	Business	11900.00
0005434443631	20405	Business	11900.00
0005434925367	20405	Business	11900.00
0005433496767	20405	Business	11900.00
0005434925505	20405	Business	11900.00
0005434925585	20405	Business	11900.00
0005434925546	20405	Economy	4000.00
0005433496788	20405	Economy	4000.00
0005433496664	20405	Economy	4000.00
0005434925563	20405	Economy	4000.00
0005434925408	20405	Economy	4000.00
0005433496828	20405	Economy	4000.00
0005433496754	20405	Economy	4000.00
0005433496857	20405	Economy	4000.00
0005433496829	20405	Economy	4000.00
0005434925603	20405	Economy	4400.00
0005434925561	20405	Economy	4400.00
0005434925521	20405	Economy	4400.00
0005433496745	20405	Economy	4400.00
0005433496952	20405	Economy	4000.00
0005434925645	20405	Economy	4000.00
0005434925565	20405	Economy	4000.00
0005433496886	20405	Economy	4000.00
0005434925509	20405	Economy	4000.00
0005434925655	20405	Economy	4000.00
0005434925435	20405	Economy	4000.00
0005433496885	20405	Economy	4000.00
0005433496778	20405	Economy	4000.00
0005433496846	20405	Economy	4000.00
0005434925409	20405	Economy	4000.00
0005434925644	20405	Economy	4000.00
0005434925599	20405	Economy	4000.00
0005434925583	20405	Economy	4000.00
0005433496766	20405	Economy	4000.00
0005433496816	20405	Economy	4000.00
0005433496635	20405	Economy	4000.00
0005434925587	20405	Economy	4000.00
0005434443518	20405	Economy	4000.00
0005434925571	20405	Economy	4000.00
0005434925584	20405	Economy	4000.00
0005433496746	20405	Economy	4000.00
0005434925592	20405	Economy	4000.00
0005434925567	20405	Economy	4000.00
0005434925568	20405	Economy	4000.00
0005434443629	20405	Economy	4000.00
0005434925506	20405	Economy	4000.00
0005433496890	20405	Economy	4000.00
0005434925606	20405	Economy	4000.00
0005434443563	20405	Economy	4000.00
0005434925562	20405	Economy	4000.00
0005434925582	20405	Economy	4000.00
0005433496721	20405	Economy	4000.00
0005434925483	20405	Economy	4000.00
0005433496922	20405	Economy	4000.00
0005434925533	20405	Economy	4000.00
0005434925368	20405	Economy	4000.00
0005433496653	20405	Economy	4000.00
0005433496787	20405	Economy	4000.00
0005433496776	20405	Economy	4000.00
0005434925598	20405	Economy	4000.00
0005433496777	20405	Economy	4000.00
0005434925547	20405	Economy	4000.00
0005434925641	20405	Economy	4000.00
0005434925518	20405	Economy	4000.00
0005434925507	20405	Economy	4000.00
0005434925500	20405	Economy	4000.00
0005434925640	20405	Economy	4000.00
0005434443593	20405	Economy	4000.00
0005433496805	20405	Economy	4000.00
0005434925545	20405	Economy	4000.00
0005434925534	20405	Economy	4000.00
0005434925586	20405	Economy	4000.00
0005434925600	20405	Economy	4000.00
0005434925596	20405	Economy	4000.00
0005434925436	20405	Economy	4000.00
0005434925566	20405	Economy	4000.00
0005433496728	20405	Economy	4000.00
0005433496652	20405	Economy	4000.00
0005434925504	20405	Economy	4000.00
0005432783295	12201	Business	41200.00
0005435242921	12201	Business	41200.00
0005432783437	12201	Business	41200.00
0005432783402	12201	Business	41200.00
0005435242909	12201	Business	41200.00
0005432783358	12201	Business	41200.00
0005432783357	12201	Business	41200.00
0005435242914	12201	Business	41200.00
0005435242917	12201	Economy	13700.00
0005435242933	12201	Economy	13700.00
0005435242915	12201	Economy	13700.00
0005432783234	12201	Economy	13700.00
0005432783371	12201	Economy	13700.00
0005435242910	12201	Economy	13700.00
0005435242924	12201	Economy	13700.00
0005435242927	12201	Economy	13700.00
0005432783705	12201	Economy	13700.00
0005435242908	12201	Economy	13700.00
0005432783409	12201	Economy	15100.00
0005432783408	12201	Economy	15100.00
0005432783178	12201	Economy	15100.00
0005432783294	12201	Economy	15100.00
0005432783704	12201	Economy	13700.00
0005435242922	12201	Economy	13700.00
0005432783519	12201	Economy	13700.00
0005435242934	12201	Economy	13700.00
0005432783443	12201	Economy	13700.00
0005432783303	12201	Economy	13700.00
0005435242912	12201	Economy	13700.00
0005432783457	12201	Economy	13700.00
0005432783318	12201	Economy	13700.00
0005432783529	12201	Economy	13700.00
0005435242935	12201	Economy	13700.00
0005432783562	12201	Economy	13700.00
0005432783455	12201	Economy	13700.00
0005432783576	12201	Economy	13700.00
0005432783359	12201	Economy	13700.00
0005432783155	12201	Economy	13700.00
0005435242929	12201	Economy	13700.00
0005432783305	12201	Economy	13700.00
0005432783465	12201	Economy	13700.00
0005432783478	12201	Economy	13700.00
0005432783399	12201	Economy	13700.00
0005435242925	12201	Economy	13700.00
0005435242923	12201	Economy	13700.00
0005432783310	12201	Economy	13700.00
0005435242916	12201	Economy	13700.00
0005432783538	12201	Economy	13700.00
0005432783717	12201	Economy	13700.00
0005432783018	12201	Economy	13700.00
0005435242931	12201	Economy	13700.00
0005435242919	12201	Economy	13700.00
0005435242926	12201	Economy	13700.00
0005432783304	12201	Economy	13700.00
0005435242932	12201	Economy	13700.00
0005432783364	12201	Economy	13700.00
0005435242930	12201	Economy	13700.00
0005435242928	12201	Economy	13700.00
0005432783511	12201	Economy	13700.00
0005435242920	12201	Economy	13700.00
0005432783722	12201	Economy	13700.00
0005432783403	12201	Economy	13700.00
0005432783520	12201	Economy	13700.00
0005432783165	12201	Economy	13700.00
0005432783431	12201	Economy	13700.00
0005432783477	12201	Economy	13700.00
0005432783660	12201	Economy	13700.00
0005432783476	12201	Economy	13700.00
0005432783561	12201	Economy	13700.00
0005435242911	12201	Economy	13700.00
0005432783417	12201	Economy	13700.00
0005432783703	12201	Economy	13700.00
0005432783518	12201	Economy	13700.00
0005435242918	12201	Economy	13700.00
0005432783510	12201	Economy	13700.00
0005435242913	12201	Economy	13700.00
0005432783335	12201	Economy	13700.00
0005432783466	12201	Economy	13700.00
0005432783154	12201	Economy	13700.00
0005432783883	15426	Business	41200.00
0005432783854	15426	Business	41200.00
0005432783832	15426	Business	41200.00
0005432783830	15426	Business	41200.00
0005435242638	15426	Business	41200.00
0005432783843	15426	Business	41200.00
0005435242641	15426	Business	41200.00
0005432783834	15426	Business	41200.00
0005435242544	15426	Business	41200.00
0005432783865	15426	Economy	13700.00
0005432783877	15426	Economy	13700.00
0005432783852	15426	Economy	13700.00
0005432783851	15426	Economy	13700.00
0005435242624	15426	Economy	13700.00
0005435242661	15426	Economy	13700.00
0005432783859	15426	Economy	13700.00
0005432783884	15426	Economy	13700.00
0005435242596	15426	Economy	13700.00
0005435242618	15426	Economy	15100.00
0005432783831	15426	Economy	15100.00
0005432783869	15426	Economy	15100.00
0005432783842	15426	Economy	15100.00
0005432783858	15426	Economy	15100.00
0005435242655	15426	Economy	13700.00
0005432783856	15426	Economy	13700.00
0005432783862	15426	Economy	13700.00
0005432783857	15426	Economy	13700.00
0005432783868	15426	Economy	13700.00
0005435242647	15426	Economy	13700.00
0005435242557	15426	Economy	13700.00
0005432783871	15426	Economy	13700.00
0005432783855	15426	Economy	13700.00
0005435242603	15426	Economy	13700.00
0005432783844	15426	Economy	13700.00
0005432783850	15426	Economy	13700.00
0005432783833	15426	Economy	13700.00
0005432783876	15426	Economy	13700.00
0005435242619	15426	Economy	13700.00
0005432783874	15426	Economy	13700.00
0005435242550	15426	Economy	13700.00
0005435242644	15426	Economy	13700.00
0005432783861	15426	Economy	13700.00
0005432783845	15426	Economy	13700.00
0005435242576	15426	Economy	13700.00
0005432783849	15426	Economy	13700.00
0005432783838	15426	Economy	13700.00
0005435242677	15426	Economy	13700.00
0005432783863	15426	Economy	13700.00
0005432783867	15426	Economy	13700.00
0005435242643	15426	Economy	13700.00
0005432783846	15426	Economy	13700.00
0005432783837	15426	Economy	13700.00
0005435242517	15426	Economy	13700.00
0005432783880	15426	Economy	13700.00
0005435242616	15426	Economy	13700.00
0005435242706	15426	Economy	13700.00
0005432783840	15426	Economy	13700.00
0005432783872	15426	Economy	13700.00
0005432783878	15426	Economy	13700.00
0005432783870	15426	Economy	13700.00
0005432783860	15426	Economy	13700.00
0005432783881	15426	Economy	13700.00
0005432783836	15426	Economy	13700.00
0005432783839	15426	Economy	13700.00
0005435242646	15426	Economy	13700.00
0005435242529	15426	Economy	13700.00
0005435242584	15426	Economy	13700.00
0005432783848	15426	Economy	13700.00
0005432783835	15426	Economy	13700.00
0005432783853	15426	Economy	13700.00
0005432783866	15426	Economy	13700.00
0005432783879	15426	Economy	13700.00
0005432783882	15426	Economy	13700.00
0005432783847	15426	Economy	13700.00
0005435242575	15426	Economy	13700.00
0005435242645	15426	Economy	13700.00
0005435242617	15426	Economy	13700.00
0005432783873	15426	Economy	13700.00
0005432783841	15426	Economy	13700.00
0005432783875	15426	Economy	13700.00
0005432783864	15426	Economy	13700.00
0005434877876	10077	Business	49700.00
0005434877870	10077	Business	49700.00
0005434877730	10077	Business	49700.00
0005434877792	10077	Business	49700.00
0005434877755	10077	Business	49700.00
0005434877621	10077	Business	49700.00
0005434877444	10077	Business	49700.00
0005434877542	10077	Business	49700.00
0005434877461	10077	Business	49700.00
0005434877729	10077	Business	49700.00
0005434877728	10077	Business	49700.00
0005434758888	10077	Business	49700.00
0005434877740	10077	Business	49700.00
0005434877663	10077	Business	49700.00
0005434877875	10077	Business	49700.00
0005434877425	10077	Business	49700.00
0005434877359	10077	Economy	16600.00
0005434877563	10077	Economy	16600.00
0005434877862	10077	Economy	16600.00
0005434877694	10077	Economy	16600.00
0005434877861	10077	Economy	16600.00
0005434877426	10077	Economy	16600.00
0005434877775	10077	Economy	16600.00
0005434877620	10077	Economy	16600.00
0005434877335	10077	Economy	16600.00
0005434877805	10077	Economy	16600.00
0005434877617	10077	Economy	16600.00
0005434877454	10077	Economy	16600.00
0005434877385	10077	Economy	16600.00
0005434877574	10077	Economy	18200.00
0005434877714	10077	Economy	18200.00
0005434877709	10077	Economy	18200.00
0005434877662	10077	Economy	16600.00
0005434877628	10077	Economy	16600.00
0005434877711	10077	Economy	16600.00
0005434877619	10077	Economy	16600.00
0005434877801	10077	Economy	16600.00
0005434877269	10077	Economy	16600.00
0005434910117	10077	Economy	16600.00
0005434877101	10077	Economy	16600.00
0005434877611	10077	Economy	16600.00
0005434877631	10077	Economy	16600.00
0005434877572	10077	Economy	16600.00
0005434877421	10077	Economy	16600.00
0005434877877	10077	Economy	16600.00
0005434910118	10077	Economy	16600.00
0005434877999	10077	Economy	16600.00
0005434877545	10077	Economy	16600.00
0005434877666	10077	Economy	16600.00
0005434877360	10077	Economy	16600.00
0005434877341	10077	Economy	16600.00
0005434877905	10077	Economy	16600.00
0005434877502	10077	Economy	16600.00
0005434877449	10077	Economy	16600.00
0005434877803	10077	Economy	16600.00
0005434877741	10077	Economy	16600.00
0005434877645	10077	Economy	16600.00
0005434877793	10077	Economy	16600.00
0005434877802	10077	Economy	16600.00
0005434877627	10077	Economy	16600.00
0005434877904	10077	Economy	16600.00
0005434877715	10077	Economy	16600.00
0005434877693	10077	Economy	16600.00
0005434877713	10077	Economy	16600.00
0005434877830	10077	Economy	16600.00
0005434877587	10077	Economy	16600.00
0005434877625	10077	Economy	16600.00
0005434877721	10077	Economy	16600.00
0005434877831	10077	Economy	16600.00
0005434877263	10077	Economy	16600.00
0005434877622	10077	Economy	16600.00
0005434877564	10077	Economy	16600.00
0005434910116	10077	Economy	16600.00
0005434877573	10077	Economy	16600.00
0005434877774	10077	Economy	16600.00
0005434877293	10077	Economy	16600.00
0005434877646	10077	Economy	16600.00
0005434877782	10077	Economy	16600.00
0005434877505	10077	Economy	16600.00
0005434877896	10077	Economy	16600.00
0005434877543	10077	Economy	16600.00
0005434877897	10077	Economy	16600.00
0005434877268	10077	Economy	16600.00
0005434877499	10077	Economy	16600.00
0005434877584	10077	Economy	16600.00
0005434878000	10077	Economy	16600.00
0005434877405	10077	Economy	16600.00
0005434877612	10077	Economy	16600.00
0005434877575	10077	Economy	16600.00
0005434877667	10077	Economy	16600.00
0005434877556	10077	Economy	16600.00
0005434910115	10077	Economy	16600.00
0005434877820	10077	Economy	16600.00
0005434877577	10077	Economy	16600.00
0005434877451	10077	Economy	16600.00
0005434877384	10077	Economy	16600.00
0005434877504	10077	Economy	16600.00
0005434877800	10077	Economy	16600.00
0005434877618	10077	Economy	16600.00
0005434878448	14632	Business	49700.00
0005434878470	14632	Business	49700.00
0005434878464	14632	Business	49700.00
0005434878468	14632	Business	49700.00
0005434878432	14632	Business	49700.00
0005435913900	14632	Business	49700.00
0005434878420	14632	Business	49700.00
0005434878429	14632	Business	49700.00
0005434878480	14632	Business	49700.00
0005434878408	14632	Business	49700.00
0005434910095	14632	Business	49700.00
0005434878446	14632	Business	49700.00
0005434878460	14632	Business	49700.00
0005434878476	14632	Business	49700.00
0005434878438	14632	Business	49700.00
0005434878416	14632	Business	49700.00
0005434878473	14632	Business	49700.00
0005434878433	14632	Business	49700.00
0005434878441	14632	Business	49700.00
0005435913885	14632	Economy	16600.00
0005435913899	14632	Business	49700.00
0005434878431	14632	Economy	16600.00
0005434878462	14632	Economy	16600.00
0005434878457	14632	Economy	16600.00
0005435913893	14632	Economy	16600.00
0005434878458	14632	Economy	16600.00
0005434878454	14632	Economy	16600.00
0005434878394	14632	Economy	16600.00
0005434878397	14632	Economy	16600.00
0005434878472	14632	Economy	16600.00
0005434878400	14632	Economy	18200.00
0005434878467	14632	Economy	18200.00
0005434878425	14632	Economy	18200.00
0005434878463	14632	Economy	18200.00
0005434878435	14632	Economy	16600.00
0005434878418	14632	Economy	16600.00
0005434878404	14632	Economy	16600.00
0005434878443	14632	Economy	16600.00
0005435913905	14632	Economy	16600.00
0005434878415	14632	Economy	16600.00
0005434878390	14632	Economy	16600.00
0005434878411	14632	Economy	16600.00
0005434878417	14632	Economy	16600.00
0005434878427	14632	Economy	16600.00
0005434878410	14632	Economy	16600.00
0005434878414	14632	Economy	16600.00
0005434878461	14632	Economy	16600.00
0005434878479	14632	Economy	16600.00
0005435913894	14632	Economy	16600.00
0005434878481	14632	Economy	16600.00
0005434878424	14632	Economy	16600.00
0005434878406	14632	Economy	16600.00
0005434878399	14632	Economy	16600.00
0005434878434	14632	Economy	16600.00
0005434878449	14632	Economy	16600.00
0005434878428	14632	Economy	16600.00
0005435913901	14632	Economy	16600.00
0005434878482	14632	Economy	16600.00
0005434878422	14632	Economy	16600.00
0005434878430	14632	Economy	16600.00
0005434878444	14632	Economy	16600.00
0005434878465	14632	Economy	16600.00
0005434758899	14632	Economy	16600.00
0005434878436	14632	Economy	16600.00
0005434878453	14632	Economy	16600.00
0005434878398	14632	Economy	16600.00
0005434878419	14632	Economy	16600.00
0005434878442	14632	Economy	16600.00
0005434878395	14632	Economy	16600.00
0005434878407	14632	Economy	16600.00
0005434878478	14632	Economy	16600.00
0005434878393	14632	Economy	16600.00
0005434878423	14632	Economy	16600.00
0005434878405	14632	Economy	16600.00
0005434878447	14632	Economy	16600.00
0005434878426	14632	Economy	16600.00
0005434878401	14632	Economy	16600.00
0005434878445	14632	Economy	16600.00
0005434878474	14632	Economy	16600.00
0005435913902	14632	Economy	16600.00
0005434878440	14632	Economy	16600.00
0005434878413	14632	Economy	16600.00
0005434878477	14632	Economy	16600.00
0005434878455	14632	Economy	16600.00
0005434878471	14632	Economy	16600.00
0005434878403	14632	Economy	16600.00
0005434878475	14632	Economy	16600.00
0005434878409	14632	Economy	16600.00
0005434878456	14632	Economy	16600.00
0005435913908	14632	Economy	16600.00
0005434878439	14632	Economy	16600.00
0005434878437	14632	Economy	16600.00
0005434878466	14632	Economy	16600.00
0005434878402	14632	Economy	16600.00
0005434878452	14632	Economy	16600.00
0005434878421	14632	Economy	16600.00
0005434878396	14632	Economy	16600.00
0005434878451	14632	Economy	16600.00
0005434878392	14632	Economy	16600.00
0005434878469	14632	Economy	16600.00
0005434878412	14632	Economy	16600.00
0005434878459	14632	Economy	16600.00
0005434878391	14632	Economy	16600.00
0005434878450	14632	Economy	16600.00
0005434910096	14632	Economy	16600.00
0005434251899	9266	Economy	22400.00
0005435660161	9266	Economy	22400.00
0005435660165	9266	Economy	22400.00
0005435660163	9266	Economy	20300.00
0005434251900	9266	Economy	20300.00
0005434251913	9266	Economy	20300.00
0005435660166	9266	Economy	20300.00
0005435660156	9266	Economy	20300.00
0005435660159	9266	Economy	20300.00
0005434251918	9266	Economy	20300.00
0005435660157	9266	Economy	20300.00
0005434251919	9266	Economy	20300.00
0005435660167	9266	Economy	20300.00
0005435660162	9266	Economy	20300.00
0005435660164	9266	Economy	20300.00
0005434251893	9266	Economy	20300.00
0005434251876	9266	Economy	20300.00
0005435660158	9266	Economy	20300.00
0005434251959	9266	Economy	20300.00
0005435660160	9266	Economy	20300.00
0005434251939	9266	Economy	20300.00
0005434251917	9266	Economy	20300.00
0005434251901	9266	Economy	20300.00
0005435660084	24679	Economy	20300.00
0005434251986	24679	Economy	20300.00
0005434251980	24679	Economy	20300.00
0005435660108	24679	Economy	20300.00
0005435660083	24679	Economy	20300.00
0005434251984	24679	Economy	20300.00
0005435660059	24679	Economy	20300.00
0005434251985	24679	Economy	20300.00
0005434251990	24679	Economy	20300.00
0005434251982	24679	Economy	20300.00
0005435660094	24679	Economy	20300.00
0005434251987	24679	Economy	20300.00
0005434251988	24679	Economy	20300.00
0005435660086	24679	Economy	20300.00
0005434251983	24679	Economy	20300.00
0005434251981	24679	Economy	20300.00
0005434251989	24679	Economy	20300.00
0005433680659	2802	Business	33000.00
0005433680642	2802	Business	33000.00
0005433680647	2802	Business	33000.00
0005433680677	2802	Business	33000.00
0005433680638	2802	Business	33000.00
0005432966822	2802	Business	33000.00
0005433684423	2802	Business	33000.00
0005433680641	2802	Business	33000.00
0005432222791	2802	Business	33000.00
0005433680685	2802	Business	33000.00
0005433680644	2802	Economy	11000.00
0005433680660	2802	Economy	11000.00
0005433680640	2802	Economy	11000.00
0005432222792	2802	Economy	11000.00
0005433680670	2802	Economy	11000.00
0005433680683	2802	Economy	11000.00
0005432966729	2802	Economy	11000.00
0005432222790	2802	Economy	12100.00
0005433680657	2802	Economy	12100.00
0005432966752	2802	Economy	12100.00
0005433684422	2802	Economy	12100.00
0005433680668	2802	Economy	12100.00
0005433680665	2802	Economy	11000.00
0005433680681	2802	Economy	11000.00
0005433680671	2802	Economy	11000.00
0005433680667	2802	Economy	11000.00
0005433680674	2802	Economy	11000.00
0005433680646	2802	Economy	11000.00
0005433680669	2802	Economy	11000.00
0005433680661	2802	Economy	11000.00
0005433680653	2802	Economy	11000.00
0005432966737	2802	Economy	11000.00
0005433680664	2802	Economy	11000.00
0005433680684	2802	Economy	11000.00
0005432966778	2802	Economy	11000.00
0005433680655	2802	Economy	11000.00
0005432966777	2802	Economy	11000.00
0005433680672	2802	Economy	11000.00
0005433680645	2802	Economy	11000.00
0005433680663	2802	Economy	11000.00
0005432966707	2802	Economy	11000.00
0005433680676	2802	Economy	11000.00
0005433680650	2802	Economy	11000.00
0005432966720	2802	Economy	11000.00
0005432966771	2802	Economy	11000.00
0005433680682	2802	Economy	11000.00
0005433680678	2802	Economy	11000.00
0005433680643	2802	Economy	11000.00
0005432966721	2802	Economy	11000.00
0005432966767	2802	Economy	11000.00
0005433680651	2802	Economy	11000.00
0005432966840	2802	Economy	11000.00
0005432222794	2802	Economy	11000.00
0005433680648	2802	Economy	11000.00
0005432966766	2802	Economy	11000.00
0005433680652	2802	Economy	11000.00
0005433680658	2802	Economy	11000.00
0005432966785	2802	Economy	11000.00
0005433680639	2802	Economy	11000.00
0005432222793	2802	Economy	11000.00
0005433680656	2802	Economy	11000.00
0005432222795	2802	Economy	11000.00
0005433680637	2802	Economy	11000.00
0005432966790	2802	Economy	11000.00
0005433680654	2802	Economy	11000.00
0005432966839	2802	Economy	11000.00
0005433680675	2802	Economy	11000.00
0005433680649	2802	Economy	11000.00
0005433680680	2802	Economy	11000.00
0005433680679	2802	Economy	11000.00
0005432966708	2802	Economy	11000.00
0005433680673	2802	Economy	11000.00
0005432966719	2802	Economy	11000.00
0005433680666	2802	Economy	11000.00
0005433680662	2802	Economy	11000.00
0005432966709	2802	Economy	11000.00
0005433680134	29187	Business	33000.00
0005433680360	29187	Business	33000.00
0005433680471	29187	Business	33000.00
0005433680512	29187	Business	33000.00
0005433680228	29187	Business	33000.00
0005432966991	29187	Business	33000.00
0005432966976	29187	Business	33000.00
0005433680085	29187	Business	33000.00
0005433687685	29187	Business	33000.00
0005433680344	29187	Business	33000.00
0005433680299	29187	Business	33000.00
0005433680234	29187	Business	33000.00
0005433680197	29187	Economy	11000.00
0005433680115	29187	Economy	11000.00
0005433680320	29187	Economy	11000.00
0005432966999	29187	Economy	11000.00
0005433680236	29187	Economy	11000.00
0005433680231	29187	Economy	11000.00
0005433680203	29187	Economy	11000.00
0005432966983	29187	Economy	11000.00
0005432966997	29187	Economy	11000.00
0005433684394	29187	Economy	11000.00
0005433680116	29187	Economy	12100.00
0005432966979	29187	Economy	12100.00
0005432966986	29187	Economy	12100.00
0005433680380	29187	Economy	12100.00
0005433684407	29187	Economy	11000.00
0005433684410	29187	Economy	11000.00
0005433680473	29187	Economy	11000.00
0005433680278	29187	Economy	11000.00
0005433680133	29187	Economy	11000.00
0005433690909	29187	Economy	11000.00
0005433680508	29187	Economy	11000.00
0005432966978	29187	Economy	11000.00
0005432966993	29187	Economy	11000.00
0005433690911	29187	Economy	11000.00
0005432966980	29187	Economy	11000.00
0005432966989	29187	Economy	11000.00
0005432966995	29187	Economy	11000.00
0005433680305	29187	Economy	11000.00
0005432967000	29187	Economy	11000.00
0005433680378	29187	Economy	11000.00
0005432005218	29187	Economy	11000.00
0005432966988	29187	Economy	11000.00
0005433680298	29187	Economy	11000.00
0005433680073	29187	Economy	11000.00
0005432966998	29187	Economy	11000.00
0005433680367	29187	Economy	11000.00
0005432966987	29187	Economy	11000.00
0005433680433	29187	Economy	11000.00
0005433687684	29187	Economy	11000.00
0005432005220	29187	Economy	11000.00
0005432966992	29187	Economy	11000.00
0005433680072	29187	Economy	11000.00
0005433680441	29187	Economy	11000.00
0005432966984	29187	Economy	11000.00
0005432966994	29187	Economy	11000.00
0005433680321	29187	Economy	11000.00
0005433680432	29187	Economy	11000.00
0005433680382	29187	Economy	11000.00
0005432966985	29187	Economy	11000.00
0005433680285	29187	Economy	11000.00
0005433687682	29187	Economy	11000.00
0005432966982	29187	Economy	11000.00
0005433690910	29187	Economy	11000.00
0005433687681	29187	Economy	11000.00
0005433680319	29187	Economy	11000.00
0005433680233	29187	Economy	11000.00
0005433680342	29187	Economy	11000.00
0005433680284	29187	Economy	11000.00
0005433680301	29187	Economy	11000.00
0005432966996	29187	Economy	11000.00
0005433684404	29187	Economy	11000.00
0005432966990	29187	Economy	11000.00
0005433680529	29187	Economy	11000.00
0005433680126	29187	Economy	11000.00
0005433680329	29187	Economy	11000.00
0005433680313	29187	Economy	11000.00
0005432967001	29187	Economy	11000.00
0005433680343	29187	Economy	11000.00
0005433680277	29187	Economy	11000.00
0005433680362	29187	Economy	11000.00
0005432966981	29187	Economy	11000.00
0005432966977	29187	Economy	11000.00
0005433680505	29187	Economy	11000.00
0005433679985	29187	Economy	11000.00
0005433680125	29187	Economy	11000.00
0005432005219	29187	Economy	11000.00
0005433684405	29187	Economy	11000.00
0005433633865	9278	Business	132900.00
0005433633863	9278	Business	132900.00
0005433633866	9278	Business	132900.00
0005433614793	9278	Business	132900.00
0005433614777	9278	Business	132900.00
0005433614738	9278	Business	132900.00
0005433614799	9278	Business	132900.00
0005433614770	9278	Business	132900.00
0005433614766	9278	Business	132900.00
0005433614801	9278	Business	132900.00
0005433614742	9278	Business	132900.00
0005434163505	9278	Business	132900.00
0005433614767	9278	Business	132900.00
0005433614753	9278	Business	132900.00
0005433614757	9278	Business	132900.00
0005433614758	9278	Business	132900.00
0005433614736	9278	Business	132900.00
0005433633845	9278	Business	132900.00
0005433614772	9278	Business	132900.00
0005433633861	9278	Business	132900.00
0005433614751	9278	Business	132900.00
0005433633851	9278	Business	132900.00
0005433614756	9278	Business	132900.00
0005432755080	9278	Business	132900.00
0005433614759	9278	Economy	48700.00
0005434163539	9278	Economy	48700.00
0005433614762	9278	Economy	48700.00
0005433577836	9278	Economy	48700.00
0005433614744	9278	Economy	48700.00
0005433614775	9278	Economy	44300.00
0005433633846	9278	Economy	44300.00
0005433577835	9278	Economy	44300.00
0005433614739	9278	Economy	44300.00
0005433577827	9278	Economy	44300.00
0005433633850	9278	Economy	44300.00
0005433633869	9278	Economy	44300.00
0005433633868	9278	Economy	44300.00
0005433614802	9278	Economy	44300.00
0005433633871	9278	Economy	44300.00
0005433614765	9278	Economy	44300.00
0005433614768	9278	Economy	44300.00
0005433614745	9278	Economy	44300.00
0005432755081	9278	Economy	44300.00
0005433614761	9278	Economy	44300.00
0005433614790	9278	Economy	44300.00
0005433614806	9278	Economy	44300.00
0005433614794	9278	Economy	44300.00
0005432756854	9278	Economy	44300.00
0005433633842	9278	Economy	44300.00
0005433614748	9278	Economy	44300.00
0005433577831	9278	Economy	44300.00
0005433633867	9278	Economy	44300.00
0005433633870	9278	Economy	44300.00
0005434152780	9278	Economy	44300.00
0005434269083	9278	Economy	44300.00
0005433614752	9278	Economy	44300.00
0005433614743	9278	Economy	44300.00
0005433614805	9278	Economy	44300.00
0005433614747	9278	Economy	44300.00
0005432756855	9278	Economy	44300.00
0005433614787	9278	Economy	44300.00
0005433633873	9278	Economy	44300.00
0005433633876	9278	Economy	44300.00
0005433633854	9278	Economy	44300.00
0005433614764	9278	Economy	44300.00
0005433614780	9278	Economy	44300.00
0005433614798	9278	Economy	44300.00
0005433614776	9278	Economy	44300.00
0005433614735	9278	Economy	44300.00
0005433614771	9278	Economy	44300.00
0005433614800	9278	Economy	44300.00
0005434163532	9278	Economy	44300.00
0005433633858	9278	Economy	44300.00
0005433633844	9278	Economy	44300.00
0005433614760	9278	Economy	44300.00
0005433614769	9278	Economy	44300.00
0005433614734	9278	Economy	44300.00
0005433577838	9278	Economy	44300.00
0005433614773	9278	Economy	44300.00
0005433614763	9278	Economy	44300.00
0005433614749	9278	Economy	44300.00
0005434269084	9278	Economy	44300.00
0005433614782	9278	Economy	44300.00
0005433633862	9278	Economy	44300.00
0005433614781	9278	Economy	48700.00
0005433614774	9278	Economy	48700.00
0005433577829	9278	Economy	48700.00
0005433614783	9278	Economy	44300.00
0005433633847	9278	Economy	44300.00
0005433614778	9278	Economy	44300.00
0005432756853	9278	Economy	44300.00
0005433577834	9278	Economy	48700.00
0005433614746	9278	Economy	44300.00
0005433633859	9278	Economy	44300.00
0005433614754	9278	Economy	44300.00
0005433614795	9278	Economy	44300.00
0005433633857	9278	Economy	44300.00
0005433633875	9278	Economy	44300.00
0005433633852	9278	Economy	44300.00
0005433614808	9278	Economy	44300.00
0005434163518	9278	Economy	44300.00
0005433633864	9278	Economy	44300.00
0005433614786	9278	Economy	44300.00
0005433614797	9278	Economy	44300.00
0005432755084	9278	Economy	44300.00
0005433614807	9278	Economy	44300.00
0005434163540	9278	Economy	44300.00
0005433577828	9278	Economy	44300.00
0005433577825	9278	Economy	44300.00
0005433614755	9278	Economy	44300.00
0005433633848	9278	Economy	44300.00
0005433577826	9278	Economy	44300.00
0005432756856	9278	Economy	44300.00
0005433633841	9278	Economy	44300.00
0005433614804	9278	Economy	44300.00
0005433633853	9278	Economy	44300.00
0005433614803	9278	Economy	44300.00
0005433614789	9278	Economy	44300.00
0005433614779	9278	Economy	44300.00
0005433633874	9278	Economy	44300.00
0005433633843	9278	Economy	44300.00
0005433614792	9278	Economy	44300.00
0005433577832	9278	Economy	44300.00
0005432145114	9278	Economy	44300.00
0005432145115	9278	Economy	44300.00
0005433577830	9278	Economy	44300.00
0005432755082	9278	Economy	44300.00
0005434163504	9278	Economy	44300.00
0005433614740	9278	Economy	44300.00
0005433614750	9278	Economy	44300.00
0005433614737	9278	Economy	44300.00
0005433633856	9278	Economy	44300.00
0005433614784	9278	Economy	44300.00
0005433614741	9278	Economy	44300.00
0005432755083	9278	Economy	44300.00
0005433633855	9278	Economy	44300.00
0005433614791	9278	Economy	44300.00
0005433633860	9278	Economy	44300.00
0005433614785	9278	Economy	44300.00
0005433633849	9278	Economy	44300.00
0005433577837	9278	Economy	44300.00
0005433633872	9278	Economy	44300.00
0005434163553	9278	Economy	44300.00
0005433614796	9278	Economy	44300.00
0005433577833	9278	Economy	44300.00
0005433614788	9278	Economy	44300.00
0005434163636	25259	Business	132900.00
0005433614111	25259	Business	132900.00
0005433614015	25259	Business	132900.00
0005434163627	25259	Business	132900.00
0005433614336	25259	Business	132900.00
0005433577720	25259	Business	132900.00
0005434163634	25259	Business	132900.00
0005433614353	25259	Business	132900.00
0005433614205	25259	Business	132900.00
0005433614118	25259	Business	132900.00
0005434163635	25259	Business	132900.00
0005433633604	25259	Business	132900.00
0005433614231	25259	Business	132900.00
0005433633488	25259	Business	132900.00
0005434163626	25259	Business	132900.00
0005433577703	25259	Business	132900.00
0005433614186	25259	Business	132900.00
0005433613771	25259	Business	132900.00
0005433614158	25259	Business	132900.00
0005433633508	25259	Business	132900.00
0005433614277	25259	Business	132900.00
0005433633566	25259	Business	132900.00
0005433577717	25259	Business	132900.00
0005433614169	25259	Business	132900.00
0005433633382	25259	Business	132900.00
0005433614062	25259	Business	132900.00
0005433614082	25259	Economy	48700.00
0005433613857	25259	Economy	48700.00
0005433633454	25259	Economy	48700.00
0005433633557	25259	Economy	48700.00
0005433614081	25259	Economy	48700.00
0005433633669	25259	Economy	48700.00
0005433614202	25259	Economy	44300.00
0005433577670	25259	Economy	44300.00
0005433633563	25259	Economy	44300.00
0005433614590	25259	Economy	44300.00
0005433633489	25259	Economy	44300.00
0005434272194	25259	Economy	44300.00
0005433614060	25259	Economy	44300.00
0005433633607	25259	Economy	44300.00
0005433614315	25259	Economy	44300.00
0005433633583	25259	Economy	44300.00
0005433613956	25259	Economy	44300.00
0005433613858	25259	Economy	44300.00
0005433613916	25259	Economy	44300.00
0005433633495	25259	Economy	44300.00
0005433614083	25259	Economy	44300.00
0005433633562	25259	Economy	44300.00
0005433614136	25259	Economy	44300.00
0005433614308	25259	Economy	44300.00
0005433614435	25259	Economy	44300.00
0005433614441	25259	Economy	44300.00
0005433614167	25259	Economy	44300.00
0005433614246	25259	Economy	44300.00
0005433633506	25259	Economy	44300.00
0005433614090	25259	Economy	44300.00
0005433614299	25259	Economy	44300.00
0005433614278	25259	Economy	44300.00
0005433633571	25259	Economy	44300.00
0005433614168	25259	Economy	44300.00
0005433614055	25259	Economy	44300.00
0005433614140	25259	Economy	44300.00
0005433614281	25259	Economy	44300.00
0005433577719	25259	Economy	44300.00
0005433614041	25259	Economy	44300.00
0005433633524	25259	Economy	44300.00
0005433614314	25259	Economy	44300.00
0005434163631	25259	Economy	44300.00
0005433577718	25259	Economy	44300.00
0005433577791	25259	Economy	44300.00
0005433633564	25259	Economy	44300.00
0005433577702	25259	Economy	44300.00
0005433614148	25259	Economy	44300.00
0005433614096	25259	Economy	44300.00
0005433614354	25259	Economy	44300.00
0005433614178	25259	Economy	44300.00
0005433614309	25259	Economy	44300.00
0005433614095	25259	Economy	44300.00
0005433614243	25259	Economy	44300.00
0005434272193	25259	Economy	44300.00
0005433614105	25259	Economy	44300.00
0005433577669	25259	Economy	48700.00
0005433613943	25259	Economy	48700.00
0005433633565	25259	Economy	48700.00
0005433577714	25259	Economy	48700.00
0005433633625	25259	Economy	44300.00
0005433614269	25259	Economy	44300.00
0005434163637	25259	Economy	44300.00
0005433633499	25259	Economy	44300.00
0005433577715	25259	Economy	48700.00
0005433614104	25259	Economy	44300.00
0005433613976	25259	Economy	44300.00
0005434163633	25259	Economy	44300.00
0005434163630	25259	Economy	44300.00
0005433614337	25259	Economy	44300.00
0005433633438	25259	Economy	44300.00
0005433614075	25259	Economy	44300.00
0005433614244	25259	Economy	44300.00
0005434163629	25259	Economy	44300.00
0005433613907	25259	Economy	44300.00
0005433614248	25259	Economy	44300.00
0005433614080	25259	Economy	44300.00
0005433614247	25259	Economy	44300.00
0005433614185	25259	Economy	44300.00
0005433614442	25259	Economy	44300.00
0005433633555	25259	Economy	44300.00
0005433614355	25259	Economy	44300.00
0005434273079	25259	Economy	44300.00
0005433633453	25259	Economy	44300.00
0005433614137	25259	Economy	44300.00
0005433613873	25259	Economy	44300.00
0005433614135	25259	Economy	44300.00
0005433633630	25259	Economy	44300.00
0005433633429	25259	Economy	44300.00
0005433614106	25259	Economy	44300.00
0005434163632	25259	Economy	44300.00
0005433613897	25259	Economy	44300.00
0005433633487	25259	Economy	44300.00
0005433614184	25259	Economy	44300.00
0005433614264	25259	Economy	44300.00
0005433613959	25259	Economy	44300.00
0005433614280	25259	Economy	44300.00
0005433614406	25259	Economy	44300.00
0005433633626	25259	Economy	44300.00
0005433614065	25259	Economy	44300.00
0005433633627	25259	Economy	44300.00
0005433614132	25259	Economy	44300.00
0005433614214	25259	Economy	44300.00
0005433633507	25259	Economy	44300.00
0005433614028	25259	Economy	44300.00
0005433577684	25259	Economy	44300.00
0005433633523	25259	Economy	44300.00
0005433614232	25259	Economy	44300.00
0005433577704	25259	Economy	44300.00
0005433614061	25259	Economy	44300.00
0005433614226	25259	Economy	44300.00
0005433613863	25259	Economy	44300.00
0005433577746	25259	Economy	44300.00
0005433633648	25259	Economy	44300.00
0005434163628	25259	Economy	44300.00
0005434273078	25259	Economy	44300.00
0005433614312	25259	Economy	44300.00
0005434271296	4229	Business	193100.00
0005435856191	4229	Business	193100.00
0005435986781	4229	Business	193100.00
0005434271295	4229	Business	193100.00
0005435856172	4229	Business	193100.00
0005435986783	4229	Economy	64400.00
0005435947187	4229	Economy	64400.00
0005435986793	4229	Economy	64400.00
0005435947164	4229	Economy	64400.00
0005435947149	4229	Economy	64400.00
0005435986792	4229	Economy	64400.00
0005435986785	4229	Economy	64400.00
0005435947153	4229	Economy	64400.00
0005435947148	4229	Economy	64400.00
0005435947166	4229	Economy	64400.00
0005432184957	4229	Economy	64400.00
0005432571294	4229	Economy	64400.00
0005435787346	4229	Economy	64400.00
0005435947128	4229	Economy	64400.00
0005435856178	4229	Economy	64400.00
0005435947130	4229	Economy	64400.00
0005435986791	4229	Economy	64400.00
0005435986789	4229	Economy	64400.00
0005432184956	4229	Economy	64400.00
0005435854045	4229	Economy	64400.00
0005435854048	4229	Economy	64400.00
0005435856171	4229	Economy	64400.00
0005435947119	4229	Economy	70800.00
0005435856186	4229	Economy	70800.00
0005435986782	4229	Economy	64400.00
0005432571300	4229	Economy	64400.00
0005435986784	4229	Economy	64400.00
0005435856177	4229	Economy	64400.00
0005435947186	4229	Economy	64400.00
0005434271301	4229	Economy	64400.00
0005435986787	4229	Economy	64400.00
0005435947129	4229	Economy	64400.00
0005435986786	4229	Economy	64400.00
0005435856179	4229	Economy	64400.00
0005435787328	4229	Economy	64400.00
0005432571284	4229	Economy	64400.00
0005435947185	4229	Economy	64400.00
0005435947167	4229	Economy	64400.00
0005435986790	4229	Economy	64400.00
0005435986788	4229	Economy	64400.00
0005435854046	4229	Economy	64400.00
0005432571296	4229	Economy	64400.00
0005435947131	4229	Economy	64400.00
0005435947165	4229	Economy	64400.00
0005435856180	4229	Economy	64400.00
0005432571332	26610	Business	193100.00
0005435947294	26610	Business	193100.00
0005435947285	26610	Business	193100.00
0005435947289	26610	Business	193100.00
0005435947292	26610	Business	193100.00
0005435947287	26610	Business	193100.00
0005435947286	26610	Economy	64400.00
0005435856215	26610	Economy	64400.00
0005435986698	26610	Economy	64400.00
0005435986688	26610	Economy	64400.00
0005435947291	26610	Economy	64400.00
0005435947290	26610	Economy	64400.00
0005435986689	26610	Economy	64400.00
0005432571331	26610	Economy	64400.00
0005435856214	26610	Economy	64400.00
0005435986704	26610	Economy	64400.00
0005435856213	26610	Economy	64400.00
0005435947280	26610	Economy	64400.00
0005435947282	26610	Economy	64400.00
0005435787360	26610	Economy	64400.00
0005435947283	26610	Economy	64400.00
0005435986706	26610	Economy	64400.00
0005435947284	26610	Economy	64400.00
0005435986697	26610	Economy	64400.00
0005435947288	26610	Economy	64400.00
0005435947281	26610	Economy	64400.00
0005432571333	26610	Economy	64400.00
0005435947293	26610	Economy	64400.00
0005433569229	339	Business	21500.00
0005433569235	339	Business	21500.00
0005432948196	339	Business	21500.00
0005433569196	339	Business	21500.00
0005433569221	339	Business	21500.00
0005432948091	339	Business	21500.00
0005433569208	339	Business	21500.00
0005433569238	339	Business	21500.00
0005433569237	339	Business	21500.00
0005433569212	339	Business	21500.00
0005433569189	339	Business	21500.00
0005433569182	339	Business	21500.00
0005433074408	339	Business	21500.00
0005433569217	339	Business	21500.00
0005433569184	339	Business	21500.00
0005432238950	339	Business	21500.00
0005432948149	339	Business	21500.00
0005432948190	339	Business	21500.00
0005433569220	339	Business	21500.00
0005432948049	339	Business	21500.00
0005432948156	339	Business	21500.00
0005433569226	339	Business	21500.00
0005433074480	339	Business	21500.00
0005433074369	339	Business	21500.00
0005433134104	339	Business	21500.00
0005433074573	339	Economy	7900.00
0005432948191	339	Economy	7900.00
0005433134105	339	Economy	7900.00
0005433074515	339	Economy	7900.00
0005433569195	339	Economy	7900.00
0005432238947	339	Economy	7900.00
0005433074518	339	Economy	7200.00
0005433569185	339	Economy	7200.00
0005433569198	339	Economy	7200.00
0005433569199	339	Economy	7200.00
0005433569188	339	Economy	7200.00
0005433074535	339	Economy	7200.00
0005432948261	339	Economy	7200.00
0005433074534	339	Economy	7200.00
0005432948243	339	Economy	7200.00
0005433569241	339	Economy	7200.00
0005432238951	339	Economy	7200.00
0005433569201	339	Economy	7200.00
0005433134095	339	Economy	7200.00
0005433074366	339	Economy	7200.00
0005432948211	339	Economy	7200.00
0005433074474	339	Economy	7200.00
0005433074472	339	Economy	7200.00
0005432948222	339	Economy	7200.00
0005433569215	339	Economy	7200.00
0005433134112	339	Economy	7200.00
0005432948158	339	Economy	7200.00
0005432948071	339	Economy	7200.00
0005432948300	339	Economy	7200.00
0005432948270	339	Economy	7200.00
0005433569187	339	Economy	7200.00
0005432948092	339	Economy	7200.00
0005432238952	339	Economy	7200.00
0005433074543	339	Economy	7200.00
0005433569211	339	Economy	7200.00
0005432948178	339	Economy	7200.00
0005433569200	339	Economy	7200.00
0005433569230	339	Economy	7200.00
0005433569216	339	Economy	7200.00
0005432948253	339	Economy	7200.00
0005432948159	339	Economy	7200.00
0005433074522	339	Economy	7200.00
0005432948318	339	Economy	7200.00
0005433569231	339	Economy	7200.00
0005433569219	339	Economy	7200.00
0005433569222	339	Economy	7200.00
0005432948244	339	Economy	7200.00
0005433074512	339	Economy	7200.00
0005432948235	339	Economy	7200.00
0005433134109	339	Economy	7200.00
0005433569191	339	Economy	7200.00
0005432948129	339	Economy	7200.00
0005432948279	339	Economy	7200.00
0005433074602	339	Economy	7200.00
0005433569209	339	Economy	7200.00
0005433569236	339	Economy	7200.00
0005433134110	339	Economy	7900.00
0005433569190	339	Economy	7900.00
0005433074542	339	Economy	7900.00
0005433569232	339	Economy	7200.00
0005432948080	339	Economy	7200.00
0005433074544	339	Economy	7200.00
0005433569205	339	Economy	7900.00
0005433074482	339	Economy	7200.00
0005433129255	339	Economy	7200.00
0005432948093	339	Economy	7200.00
0005432948238	339	Economy	7200.00
0005433074475	339	Economy	7200.00
0005433074516	339	Economy	7200.00
0005432948076	339	Economy	7200.00
0005433074453	339	Economy	7200.00
0005433569240	339	Economy	7200.00
0005432948352	339	Economy	7200.00
0005432947936	339	Economy	7200.00
0005433074536	339	Economy	7200.00
0005433569183	339	Economy	7200.00
0005432238949	339	Economy	7200.00
0005433074517	339	Economy	7200.00
0005433569214	339	Economy	7200.00
0005433569233	339	Economy	7200.00
0005433569194	339	Economy	7200.00
0005433569223	339	Economy	7200.00
0005433074465	339	Economy	7200.00
0005433569234	339	Economy	7200.00
0005433569193	339	Economy	7200.00
0005433129261	339	Economy	7200.00
0005433569228	339	Economy	7200.00
0005432948118	339	Economy	7200.00
0005433569218	339	Economy	7200.00
0005432948079	339	Economy	7200.00
0005433569207	339	Economy	7200.00
0005433569206	339	Economy	7200.00
0005433569204	339	Economy	7200.00
0005433074411	339	Economy	7200.00
0005433569197	339	Economy	7200.00
0005433134096	339	Economy	7200.00
0005432948230	339	Economy	7200.00
0005433074541	339	Economy	7200.00
0005433074427	339	Economy	7200.00
0005432947937	339	Economy	7200.00
0005433569227	339	Economy	7200.00
0005433569203	339	Economy	7200.00
0005433569225	339	Economy	7200.00
0005433569210	339	Economy	7200.00
0005433074510	339	Economy	7200.00
0005433569239	339	Economy	7200.00
0005432948117	339	Economy	7200.00
0005432238946	339	Economy	7200.00
0005432948090	339	Economy	7200.00
0005432238948	339	Economy	7200.00
0005433569213	339	Economy	7200.00
0005433074401	339	Economy	7200.00
0005433074572	339	Economy	7200.00
0005433569202	339	Economy	7200.00
0005433569186	339	Economy	7200.00
0005433074481	339	Economy	7200.00
0005433569192	339	Economy	7200.00
0005432948147	339	Economy	7200.00
0005433569224	339	Economy	7200.00
0005433134145	11593	Business	21500.00
0005433568555	11593	Business	21500.00
0005433568654	11593	Business	21500.00
0005432948515	11593	Business	21500.00
0005432948540	11593	Business	21500.00
0005432948545	11593	Business	21500.00
0005433074756	11593	Business	21500.00
0005433074755	11593	Business	21500.00
0005433074765	11593	Business	21500.00
0005433568553	11593	Business	21500.00
0005433131715	11593	Business	21500.00
0005432948519	11593	Business	21500.00
0005432948553	11593	Business	21500.00
0005433074771	11593	Business	21500.00
0005433074758	11593	Business	21500.00
0005433568590	11593	Business	21500.00
0005432948533	11593	Business	21500.00
0005432948555	11593	Business	21500.00
0005432948550	11593	Business	21500.00
0005433074780	11593	Business	21500.00
0005433074761	11593	Business	21500.00
0005433568489	11593	Business	21500.00
0005433074762	11593	Business	21500.00
0005433568203	11593	Business	21500.00
0005433568577	11593	Economy	7900.00
0005433134147	11593	Economy	7900.00
0005432948547	11593	Economy	7900.00
0005433568675	11593	Economy	7900.00
0005433568576	11593	Economy	7200.00
0005433568586	11593	Economy	7200.00
0005433074770	11593	Economy	7200.00
0005432948538	11593	Economy	7200.00
0005433568552	11593	Economy	7200.00
0005433131717	11593	Economy	7200.00
0005433568381	11593	Economy	7200.00
0005433568178	11593	Economy	7200.00
0005433074753	11593	Economy	7200.00
0005432948537	11593	Economy	7200.00
0005433568380	11593	Economy	7200.00
0005432948516	11593	Economy	7200.00
0005432948536	11593	Economy	7200.00
0005432948529	11593	Economy	7200.00
0005433568486	11593	Economy	7200.00
0005433134150	11593	Economy	7200.00
0005433568442	11593	Economy	7200.00
0005432948548	11593	Economy	7200.00
0005432948543	11593	Economy	7200.00
0005432948531	11593	Economy	7200.00
0005432948534	11593	Economy	7200.00
0005433074772	11593	Economy	7200.00
0005433568589	11593	Economy	7200.00
0005433131716	11593	Economy	7200.00
0005432948535	11593	Economy	7200.00
0005432948526	11593	Economy	7200.00
0005433074777	11593	Economy	7200.00
0005432948517	11593	Economy	7200.00
0005432948522	11593	Economy	7200.00
0005433568396	11593	Economy	7200.00
0005433568522	11593	Economy	7200.00
0005433568563	11593	Economy	7200.00
0005433568564	11593	Economy	7200.00
0005433568528	11593	Economy	7200.00
0005433568642	11593	Economy	7200.00
0005433074769	11593	Economy	7200.00
0005432192325	11593	Economy	7200.00
0005433568606	11593	Economy	7200.00
0005433568587	11593	Economy	7200.00
0005432948525	11593	Economy	7200.00
0005433568549	11593	Economy	7200.00
0005433568523	11593	Economy	7200.00
0005432948539	11593	Economy	7200.00
0005433568406	11593	Economy	7200.00
0005433568548	11593	Economy	7200.00
0005433568407	11593	Economy	7200.00
0005433568403	11593	Economy	7200.00
0005433568479	11593	Economy	7200.00
0005432192328	11593	Economy	7200.00
0005433568475	11593	Economy	7200.00
0005433568192	11593	Economy	7200.00
0005433568443	11593	Economy	7900.00
0005433074776	11593	Economy	7900.00
0005432948549	11593	Economy	7900.00
0005433568535	11593	Economy	7900.00
0005433568225	11593	Economy	7200.00
0005433568585	11593	Economy	7200.00
0005433074760	11593	Economy	7200.00
0005433074774	11593	Economy	7200.00
0005433074757	11593	Economy	7200.00
0005433568395	11593	Economy	7200.00
0005432948527	11593	Economy	7200.00
0005432948554	11593	Economy	7200.00
0005433568373	11593	Economy	7200.00
0005432948521	11593	Economy	7200.00
0005433568423	11593	Economy	7200.00
0005433568419	11593	Economy	7200.00
0005433568372	11593	Economy	7200.00
0005432948541	11593	Economy	7200.00
0005433568562	11593	Economy	7200.00
0005433568487	11593	Economy	7200.00
0005433568588	11593	Economy	7200.00
0005433568404	11593	Economy	7200.00
0005432192326	11593	Economy	7200.00
0005432948542	11593	Economy	7200.00
0005432948523	11593	Economy	7200.00
0005433131718	11593	Economy	7200.00
0005433568516	11593	Economy	7200.00
0005433074752	11593	Economy	7200.00
0005432948528	11593	Economy	7200.00
0005432948530	11593	Economy	7200.00
0005433074767	11593	Economy	7200.00
0005432192327	11593	Economy	7200.00
0005433074773	11593	Economy	7200.00
0005433568651	11593	Economy	7200.00
0005432948551	11593	Economy	7200.00
0005432948514	11593	Economy	7200.00
0005433568226	11593	Economy	7200.00
0005432948552	11593	Economy	7200.00
0005433568652	11593	Economy	7200.00
0005433568538	11593	Economy	7200.00
0005433568400	11593	Economy	7200.00
0005432948518	11593	Economy	7200.00
0005433568334	11593	Economy	7200.00
0005433134149	11593	Economy	7200.00
0005432948544	11593	Economy	7200.00
0005433568193	11593	Economy	7200.00
0005433568575	11593	Economy	7200.00
0005433134146	11593	Economy	7200.00
0005433074779	11593	Economy	7200.00
0005433568394	11593	Economy	7200.00
0005433074781	11593	Economy	7200.00
0005433568529	11593	Economy	7200.00
0005433074766	11593	Economy	7200.00
0005432948524	11593	Economy	7200.00
0005433074775	11593	Economy	7200.00
0005433074768	11593	Economy	7200.00
0005433568449	11593	Economy	7200.00
0005432948520	11593	Economy	7200.00
0005433568561	11593	Economy	7200.00
0005433074764	11593	Economy	7200.00
0005433134148	11593	Economy	7200.00
0005433131719	11593	Economy	7200.00
0005433568450	11593	Economy	7200.00
0005432948546	11593	Economy	7200.00
0005433074763	11593	Economy	7200.00
0005432948532	11593	Economy	7200.00
0005433074759	11593	Economy	7200.00
0005433074754	11593	Economy	7200.00
0005433074778	11593	Economy	7200.00
0005433817480	10048	Economy	6300.00
0005433817479	10048	Economy	6300.00
0005433817478	10048	Economy	6300.00
0005434732953	10048	Economy	6300.00
0005434732974	10048	Economy	6300.00
0005434732968	10048	Economy	6300.00
0005434732988	13910	Economy	6300.00
0005433817444	13910	Economy	6300.00
0005433817436	13910	Economy	6300.00
0005434732989	13910	Economy	6300.00
0005434732987	13910	Economy	6300.00
0005433817445	13910	Economy	6300.00
0005433817449	13910	Economy	6300.00
0005434732986	13910	Economy	6300.00
0005433817455	13910	Economy	6300.00
0005433817458	13910	Economy	6300.00
0005433817437	13910	Economy	6300.00
0005432984842	2336	Business	184500.00
0005432655566	2336	Business	184500.00
0005435982414	2336	Business	184500.00
0005435982400	2336	Business	184500.00
0005433754344	2336	Business	184500.00
0005432300276	2336	Business	184500.00
0005433754365	2336	Business	184500.00
0005433754316	2336	Business	184500.00
0005433754367	2336	Business	184500.00
0005432655560	2336	Business	184500.00
0005433754362	2336	Business	184500.00
0005433434622	2336	Business	184500.00
0005435982407	2336	Business	184500.00
0005435982412	2336	Business	184500.00
0005435982435	2336	Business	184500.00
0005433754323	2336	Business	184500.00
0005432984740	2336	Business	184500.00
0005432226068	2336	Business	184500.00
0005432869488	2336	Business	184500.00
0005433754333	2336	Business	184500.00
0005432985053	2336	Business	184500.00
0005435982408	2336	Business	184500.00
0005432985054	2336	Business	184500.00
0005435982431	2336	Business	184500.00
0005435982423	2336	Business	184500.00
0005433434462	2336	Business	184500.00
0005432869470	2336	Business	184500.00
0005433754337	2336	Economy	67700.00
0005433434434	2336	Economy	67700.00
0005433434536	2336	Economy	67700.00
0005435982405	2336	Economy	67700.00
0005435982417	2336	Economy	61500.00
0005432226067	2336	Economy	61500.00
0005433754332	2336	Economy	61500.00
0005435982442	2336	Economy	61500.00
0005432655561	2336	Economy	61500.00
0005433754329	2336	Economy	61500.00
0005433754315	2336	Economy	61500.00
0005433434541	2336	Economy	61500.00
0005435982418	2336	Economy	61500.00
0005433754324	2336	Economy	61500.00
0005433754347	2336	Economy	61500.00
0005433754319	2336	Economy	61500.00
0005433434395	2336	Economy	61500.00
0005433754363	2336	Economy	61500.00
0005433434446	2336	Economy	61500.00
0005435982422	2336	Economy	61500.00
0005433754356	2336	Economy	61500.00
0005433754366	2336	Economy	61500.00
0005432984799	2336	Economy	61500.00
0005435982441	2336	Economy	61500.00
0005435982401	2336	Economy	61500.00
0005433754358	2336	Economy	61500.00
0005432226071	2336	Economy	61500.00
0005435982429	2336	Economy	61500.00
0005433754352	2336	Economy	61500.00
0005433754341	2336	Economy	61500.00
0005432869482	2336	Economy	61500.00
0005435982438	2336	Economy	61500.00
0005433754351	2336	Economy	61500.00
0005435982437	2336	Economy	61500.00
0005435982395	2336	Economy	61500.00
0005435982439	2336	Economy	61500.00
0005433434424	2336	Economy	61500.00
0005435982433	2336	Economy	61500.00
0005433434553	2336	Economy	61500.00
0005433754343	2336	Economy	61500.00
0005433434459	2336	Economy	61500.00
0005434731146	2336	Economy	61500.00
0005435982427	2336	Economy	61500.00
0005433754328	2336	Economy	61500.00
0005432984825	2336	Economy	61500.00
0005432984960	2336	Economy	61500.00
0005432984878	2336	Economy	61500.00
0005432984889	2336	Economy	61500.00
0005433754336	2336	Economy	61500.00
0005433754369	2336	Economy	61500.00
0005432985011	2336	Economy	61500.00
0005432985010	2336	Economy	61500.00
0005432300274	2336	Economy	61500.00
0005432869486	2336	Economy	61500.00
0005433434513	2336	Economy	61500.00
0005435982434	2336	Economy	61500.00
0005435982416	2336	Economy	61500.00
0005433754354	2336	Economy	61500.00
0005433434417	2336	Economy	61500.00
0005433434677	2336	Economy	61500.00
0005433754318	2336	Economy	61500.00
0005433434461	2336	Economy	61500.00
0005432655559	2336	Economy	61500.00
0005433754342	2336	Economy	61500.00
0005433434394	2336	Economy	61500.00
0005434731139	2336	Economy	61500.00
0005433754325	2336	Economy	61500.00
0005435982426	2336	Economy	61500.00
0005435982404	2336	Economy	61500.00
0005433434530	2336	Economy	61500.00
0005432984709	2336	Economy	61500.00
0005435982415	2336	Economy	61500.00
0005432655570	2336	Economy	61500.00
0005433764684	2336	Economy	61500.00
0005433434519	2336	Economy	61500.00
0005433754317	2336	Economy	61500.00
0005432655562	2336	Economy	61500.00
0005433754360	2336	Economy	61500.00
0005433754321	2336	Economy	61500.00
0005432655568	2336	Economy	61500.00
0005435982430	2336	Economy	61500.00
0005433754346	2336	Economy	61500.00
0005432655565	2336	Economy	61500.00
0005433754326	2336	Economy	61500.00
0005432984866	2336	Economy	61500.00
0005433754331	2336	Economy	61500.00
0005433754338	2336	Economy	61500.00
0005432984888	2336	Economy	61500.00
0005432300273	2336	Economy	61500.00
0005433754371	2336	Economy	61500.00
0005433434445	2336	Economy	61500.00
0005432869475	2336	Economy	61500.00
0005433754349	2336	Economy	61500.00
0005433766647	2336	Economy	61500.00
0005433434529	2336	Economy	61500.00
0005432226070	2336	Economy	61500.00
0005435982403	2336	Economy	67700.00
0005435982394	2336	Economy	67700.00
0005435982411	2336	Economy	61500.00
0005433754345	2336	Economy	61500.00
0005432984708	2336	Economy	61500.00
0005432300278	2336	Economy	67700.00
0005433754350	2336	Economy	67700.00
0005432300277	2336	Economy	61500.00
0005432984945	2336	Economy	61500.00
0005432655564	2336	Economy	61500.00
0005435982432	2336	Economy	61500.00
0005432655563	2336	Economy	61500.00
0005432655569	2336	Economy	61500.00
0005433754335	2336	Economy	61500.00
0005433434460	2336	Economy	61500.00
0005432984800	2336	Economy	61500.00
0005433434506	2336	Economy	61500.00
0005435982410	2336	Economy	61500.00
0005433754370	2336	Economy	61500.00
0005433766649	2336	Economy	61500.00
0005433754348	2336	Economy	61500.00
0005432869484	2336	Economy	61500.00
0005435982398	2336	Economy	61500.00
0005433766648	2336	Economy	61500.00
0005433754353	2336	Economy	61500.00
0005432984821	2336	Economy	61500.00
0005435982421	2336	Economy	61500.00
0005432984822	2336	Economy	61500.00
0005432226069	2336	Economy	61500.00
0005433754330	2336	Economy	61500.00
0005432226072	2336	Economy	61500.00
0005435982393	2336	Economy	61500.00
0005432984877	2336	Economy	61500.00
0005435982397	2336	Economy	61500.00
0005432300275	2336	Economy	61500.00
0005432984795	2336	Economy	61500.00
0005435982419	2336	Economy	61500.00
0005433764683	2336	Economy	61500.00
0005432984835	2336	Economy	61500.00
0005435982420	2336	Economy	61500.00
0005435982396	2336	Economy	61500.00
0005434731131	2336	Economy	61500.00
0005433434433	2336	Economy	61500.00
0005432984871	2336	Economy	61500.00
0005433754340	2336	Economy	61500.00
0005435982406	2336	Economy	61500.00
0005433754339	2336	Economy	61500.00
0005433754357	2336	Economy	61500.00
0005433434537	2336	Economy	61500.00
0005435982425	2336	Economy	61500.00
0005433434623	2336	Economy	61500.00
0005432984849	2336	Economy	61500.00
0005432869493	2336	Economy	61500.00
0005435982399	2336	Economy	61500.00
0005432984646	2336	Economy	61500.00
0005432869469	2336	Economy	61500.00
0005435982440	2336	Economy	61500.00
0005435982409	2336	Economy	61500.00
0005433754359	2336	Economy	61500.00
0005433754368	2336	Economy	61500.00
0005432655567	2336	Economy	61500.00
0005432984848	2336	Economy	61500.00
0005435982402	2336	Economy	61500.00
0005432655558	2336	Economy	61500.00
0005435982413	2336	Economy	61500.00
0005435982436	2336	Economy	61500.00
0005432984867	2336	Economy	61500.00
0005433434444	2336	Economy	61500.00
0005433754322	2336	Economy	61500.00
0005433754355	2336	Economy	61500.00
0005433754361	2336	Economy	61500.00
0005433754334	2336	Economy	61500.00
0005435982424	2336	Economy	61500.00
0005432869485	2336	Economy	61500.00
0005433754320	2336	Economy	61500.00
0005432226073	2336	Economy	61500.00
0005433754364	2336	Economy	61500.00
0005435982428	2336	Economy	61500.00
0005433754327	2336	Economy	61500.00
0005433434533	2336	Economy	61500.00
0005432869540	26208	Business	184500.00
0005433753835	26208	Business	184500.00
0005433753758	26208	Business	184500.00
0005433434741	26208	Business	184500.00
0005435981821	26208	Business	184500.00
0005433434736	26208	Business	184500.00
0005433753754	26208	Business	184500.00
0005433754058	26208	Business	184500.00
0005433434752	26208	Business	184500.00
0005435981941	26208	Business	184500.00
0005432985141	26208	Business	184500.00
0005435981957	26208	Business	184500.00
0005433766613	26208	Business	184500.00
0005434731179	26208	Business	184500.00
0005433753942	26208	Business	184500.00
0005432655400	26208	Business	184500.00
0005433753844	26208	Business	184500.00
0005433754034	26208	Business	184500.00
0005433753897	26208	Business	184500.00
0005432985149	26208	Business	184500.00
0005432869533	26208	Business	184500.00
0005433753836	26208	Business	184500.00
0005433753743	26208	Business	184500.00
0005433753908	26208	Business	184500.00
0005432985153	26208	Business	184500.00
0005433754116	26208	Business	184500.00
0005433753823	26208	Business	184500.00
0005432985147	26208	Business	184500.00
0005432985150	26208	Business	184500.00
0005435981773	26208	Economy	67700.00
0005433434730	26208	Economy	67700.00
0005435981816	26208	Economy	67700.00
0005433753829	26208	Economy	67700.00
0005435981926	26208	Economy	61500.00
0005435981996	26208	Economy	61500.00
0005435981909	26208	Economy	61500.00
0005432655444	26208	Economy	61500.00
0005435981997	26208	Economy	61500.00
0005434731181	26208	Economy	61500.00
0005432985133	26208	Economy	61500.00
0005435981907	26208	Economy	61500.00
0005433434745	26208	Economy	61500.00
0005435981938	26208	Economy	61500.00
0005435981948	26208	Economy	61500.00
0005434731182	26208	Economy	61500.00
0005435981958	26208	Economy	61500.00
0005432655459	26208	Economy	61500.00
0005432985139	26208	Economy	61500.00
0005433434734	26208	Economy	61500.00
0005433753868	26208	Economy	61500.00
0005433434732	26208	Economy	61500.00
0005433753744	26208	Economy	61500.00
0005433754020	26208	Economy	61500.00
0005435981942	26208	Economy	61500.00
0005435981943	26208	Economy	61500.00
0005435981886	26208	Economy	61500.00
0005435982039	26208	Economy	61500.00
0005432051133	26208	Economy	61500.00
0005432985137	26208	Economy	61500.00
0005433753932	26208	Economy	61500.00
0005432985159	26208	Economy	61500.00
0005433753645	26208	Economy	61500.00
0005433753939	26208	Economy	61500.00
0005432655416	26208	Economy	61500.00
0005432985151	26208	Economy	61500.00
0005433753911	26208	Economy	61500.00
0005433753859	26208	Economy	61500.00
0005432049473	26208	Economy	61500.00
0005435981912	26208	Economy	61500.00
0005435981951	26208	Economy	61500.00
0005432985140	26208	Economy	61500.00
0005435982040	26208	Economy	61500.00
0005435981993	26208	Economy	61500.00
0005435982115	26208	Economy	61500.00
0005433434740	26208	Economy	61500.00
0005435982029	26208	Economy	61500.00
0005433753826	26208	Economy	61500.00
0005433753940	26208	Economy	61500.00
0005433753901	26208	Economy	61500.00
0005433434755	26208	Economy	61500.00
0005435982030	26208	Economy	61500.00
0005433753961	26208	Economy	61500.00
0005432049472	26208	Economy	61500.00
0005433753843	26208	Economy	61500.00
0005432051135	26208	Economy	61500.00
0005435981827	26208	Economy	61500.00
0005433434742	26208	Economy	61500.00
0005432985134	26208	Economy	61500.00
0005433434750	26208	Economy	61500.00
0005435982172	26208	Economy	61500.00
0005433434754	26208	Economy	61500.00
0005435981893	26208	Economy	61500.00
0005433434749	26208	Economy	61500.00
0005432985163	26208	Economy	61500.00
0005432985164	26208	Economy	61500.00
0005432985158	26208	Economy	61500.00
0005435981888	26208	Economy	61500.00
0005432985146	26208	Economy	61500.00
0005433753845	26208	Economy	61500.00
0005435982012	26208	Economy	61500.00
0005435981991	26208	Economy	61500.00
0005433753841	26208	Economy	61500.00
0005433434727	26208	Economy	61500.00
0005435981947	26208	Economy	61500.00
0005435982010	26208	Economy	61500.00
0005433434743	26208	Economy	61500.00
0005433434731	26208	Economy	61500.00
0005433753853	26208	Economy	61500.00
0005433753637	26208	Economy	61500.00
0005433766623	26208	Economy	61500.00
0005433753978	26208	Economy	61500.00
0005433434744	26208	Economy	61500.00
0005432869534	26208	Economy	61500.00
0005433753861	26208	Economy	61500.00
0005435981959	26208	Economy	61500.00
0005435981887	26208	Economy	61500.00
0005432985154	26208	Economy	61500.00
0005432985135	26208	Economy	61500.00
0005433434733	26208	Economy	61500.00
0005432049471	26208	Economy	61500.00
0005433753673	26208	Economy	61500.00
0005433753818	26208	Economy	61500.00
0005432985161	26208	Economy	67700.00
0005433434737	26208	Economy	67700.00
0005433753828	26208	Economy	61500.00
0005432985160	26208	Economy	61500.00
0005433753858	26208	Economy	61500.00
0005432869536	26208	Economy	67700.00
0005435981858	26208	Economy	67700.00
0005433434739	26208	Economy	61500.00
0005432985144	26208	Economy	61500.00
0005435982114	26208	Economy	61500.00
0005432985156	26208	Economy	61500.00
0005433434735	26208	Economy	61500.00
0005432655454	26208	Economy	61500.00
0005433753904	26208	Economy	61500.00
0005432051134	26208	Economy	61500.00
0005432869535	26208	Economy	61500.00
0005433753824	26208	Economy	61500.00
0005433753924	26208	Economy	61500.00
0005433754032	26208	Economy	61500.00
0005433753903	26208	Economy	61500.00
0005435981939	26208	Economy	61500.00
0005435982078	26208	Economy	61500.00
0005432869537	26208	Economy	61500.00
0005433766609	26208	Economy	61500.00
0005432051136	26208	Economy	61500.00
0005435981820	26208	Economy	61500.00
0005433434729	26208	Economy	61500.00
0005432655415	26208	Economy	61500.00
0005433434753	26208	Economy	61500.00
0005432869538	26208	Economy	61500.00
0005433753881	26208	Economy	61500.00
0005432985157	26208	Economy	61500.00
0005435982011	26208	Economy	61500.00
0005435981812	26208	Economy	61500.00
0005433434738	26208	Economy	61500.00
0005432869539	26208	Economy	61500.00
0005433434747	26208	Economy	61500.00
0005433434751	26208	Economy	61500.00
0005432985136	26208	Economy	61500.00
0005432985143	26208	Economy	61500.00
0005433434728	26208	Economy	61500.00
0005432985162	26208	Economy	61500.00
0005435981967	26208	Economy	61500.00
0005433753943	26208	Economy	61500.00
0005433754033	26208	Economy	61500.00
0005435981983	26208	Economy	61500.00
0005435981966	26208	Economy	61500.00
0005433753880	26208	Economy	61500.00
0005432985145	26208	Economy	61500.00
0005433753632	26208	Economy	61500.00
0005432985155	26208	Economy	61500.00
0005435981968	26208	Economy	61500.00
0005433764662	26208	Economy	61500.00
0005433434746	26208	Economy	61500.00
0005435981837	26208	Economy	61500.00
0005432655401	26208	Economy	61500.00
0005433753931	26208	Economy	61500.00
0005432985138	26208	Economy	61500.00
0005432655456	26208	Economy	61500.00
0005435981976	26208	Economy	61500.00
0005432985142	26208	Economy	61500.00
0005435982007	26208	Economy	61500.00
0005433753755	26208	Economy	61500.00
0005433766611	26208	Economy	61500.00
0005434731183	26208	Economy	61500.00
0005433434748	26208	Economy	61500.00
0005433753722	26208	Economy	61500.00
0005433764664	26208	Economy	61500.00
0005434731180	26208	Economy	61500.00
0005435982038	26208	Economy	61500.00
0005435981819	26208	Economy	61500.00
0005432985132	26208	Economy	61500.00
0005435982050	26208	Economy	61500.00
0005432985152	26208	Economy	61500.00
0005432985148	26208	Economy	61500.00
0005434374724	1498	Business	38900.00
0005434374737	1498	Business	38900.00
0005433151255	1498	Business	38900.00
0005434374722	1498	Business	38900.00
0005434374732	1498	Business	38900.00
0005434374754	1498	Business	38900.00
0005433151086	1498	Business	38900.00
0005433151107	1498	Business	38900.00
0005433151231	1498	Business	38900.00
0005433931434	1498	Economy	13000.00
0005433151227	1498	Economy	13000.00
0005434374734	1498	Economy	13000.00
0005434374738	1498	Economy	13000.00
0005432267910	1498	Economy	13000.00
0005434374740	1498	Economy	13000.00
0005433460440	1498	Economy	13000.00
0005433764667	1498	Economy	13000.00
0005434374748	1498	Economy	13000.00
0005434374714	1498	Economy	13000.00
0005434374733	1498	Economy	13000.00
0005434374720	1498	Economy	13000.00
0005432267907	1498	Economy	13000.00
0005433931435	1498	Economy	13000.00
0005433151085	1498	Economy	13000.00
0005433461593	1498	Economy	13000.00
0005434374751	1498	Economy	13000.00
0005434374717	1498	Economy	13000.00
0005432267909	1498	Economy	13000.00
0005432267911	1498	Economy	13000.00
0005434374726	1498	Economy	13000.00
0005433151215	1498	Economy	14300.00
0005434374739	1498	Economy	14300.00
0005434374736	1498	Economy	14300.00
0005434374755	1498	Economy	13000.00
0005433151309	1498	Economy	13000.00
0005433151094	1498	Economy	13000.00
0005434374728	1498	Economy	13000.00
0005432267913	1498	Economy	13000.00
0005434374711	1498	Economy	13000.00
0005434374745	1498	Economy	13000.00
0005434374725	1498	Economy	13000.00
0005433460442	1498	Economy	13000.00
0005434374743	1498	Economy	13000.00
0005433151256	1498	Economy	13000.00
0005434374721	1498	Economy	13000.00
0005434374712	1498	Economy	13000.00
0005434374730	1498	Economy	13000.00
0005434374744	1498	Economy	13000.00
0005434374735	1498	Economy	13000.00
0005434374758	1498	Economy	13000.00
0005433151225	1498	Economy	13000.00
0005433151267	1498	Economy	13000.00
0005433151253	1498	Economy	13000.00
0005434374747	1498	Economy	13000.00
0005434374741	1498	Economy	13000.00
0005434374752	1498	Economy	13000.00
0005434374742	1498	Economy	13000.00
0005433151209	1498	Economy	13000.00
0005434374710	1498	Economy	13000.00
0005433764668	1498	Economy	13000.00
0005434374731	1498	Economy	13000.00
0005434374753	1498	Economy	13000.00
0005434374757	1498	Economy	13000.00
0005434374719	1498	Economy	13000.00
0005433151208	1498	Economy	13000.00
0005434374716	1498	Economy	13000.00
0005434029649	1498	Economy	13000.00
0005433151254	1498	Economy	13000.00
0005432267912	1498	Economy	13000.00
0005434374727	1498	Economy	13000.00
0005433151166	1498	Economy	13000.00
0005433931439	1498	Economy	13000.00
0005434374756	1498	Economy	13000.00
0005434374729	1498	Economy	13000.00
0005434374750	1498	Economy	13000.00
0005433151293	1498	Economy	13000.00
0005434374713	1498	Economy	13000.00
0005434374715	1498	Economy	13000.00
0005434374718	1498	Economy	13000.00
0005434374749	1498	Economy	13000.00
0005433460441	1498	Economy	13000.00
0005434374723	1498	Economy	13000.00
0005432267908	1498	Economy	13000.00
0005433151266	1498	Economy	13000.00
0005433931430	1498	Economy	13000.00
0005433151367	1498	Economy	13000.00
0005433151216	1498	Economy	13000.00
0005433151268	1498	Economy	13000.00
0005434374746	1498	Economy	13000.00
0005434374386	20126	Business	38900.00
0005433151496	20126	Business	38900.00
0005433764684	20126	Business	38900.00
0005433151477	20126	Business	38900.00
0005433463875	20126	Business	38900.00
0005433151462	20126	Business	38900.00
0005433931472	20126	Business	38900.00
0005434374373	20126	Business	38900.00
0005433151475	20126	Business	38900.00
0005434374187	20126	Economy	13000.00
0005433151479	20126	Economy	13000.00
0005434374155	20126	Economy	13000.00
0005433461561	20126	Economy	13000.00
0005433931473	20126	Economy	13000.00
0005434374342	20126	Economy	13000.00
0005434374387	20126	Economy	13000.00
0005434374303	20126	Economy	13000.00
0005432056305	20126	Economy	13000.00
0005433151463	20126	Economy	13000.00
0005434374278	20126	Economy	13000.00
0005434374280	20126	Economy	13000.00
0005434374217	20126	Economy	13000.00
0005434374348	20126	Economy	13000.00
0005433151476	20126	Economy	13000.00
0005434374188	20126	Economy	13000.00
0005434374372	20126	Economy	13000.00
0005433151461	20126	Economy	13000.00
0005433461551	20126	Economy	13000.00
0005434374391	20126	Economy	13000.00
0005434374343	20126	Economy	13000.00
0005433461553	20126	Economy	13000.00
0005433461556	20126	Economy	13000.00
0005434374290	20126	Economy	13000.00
0005433151466	20126	Economy	13000.00
0005433461580	20126	Economy	13000.00
0005433461550	20126	Economy	13000.00
0005433151492	20126	Economy	13000.00
0005432056309	20126	Economy	13000.00
0005433463864	20126	Economy	13000.00
0005433463870	20126	Economy	13000.00
0005432056306	20126	Economy	13000.00
0005433151490	20126	Economy	13000.00
0005434374170	20126	Economy	13000.00
0005433151472	20126	Economy	13000.00
0005433151468	20126	Economy	14300.00
0005434374333	20126	Economy	14300.00
0005432056307	20126	Economy	14300.00
0005433151470	20126	Economy	13000.00
0005434374171	20126	Economy	13000.00
0005433463868	20126	Economy	13000.00
0005434374311	20126	Economy	13000.00
0005433461558	20126	Economy	13000.00
0005433151493	20126	Economy	13000.00
0005433151464	20126	Economy	13000.00
0005433151482	20126	Economy	13000.00
0005433151474	20126	Economy	13000.00
0005433764683	20126	Economy	13000.00
0005433151480	20126	Economy	13000.00
0005433151467	20126	Economy	13000.00
0005434374380	20126	Economy	13000.00
0005433151478	20126	Economy	13000.00
0005433463878	20126	Economy	13000.00
0005434029661	20126	Economy	13000.00
0005433461562	20126	Economy	13000.00
0005434374104	20126	Economy	13000.00
0005434374097	20126	Economy	13000.00
0005433151495	20126	Economy	13000.00
0005433151473	20126	Economy	13000.00
0005433151487	20126	Economy	13000.00
0005433151483	20126	Economy	13000.00
0005433461560	20126	Economy	13000.00
0005433463877	20126	Economy	13000.00
0005433151486	20126	Economy	13000.00
0005433463876	20126	Economy	13000.00
0005433151485	20126	Economy	13000.00
0005433151488	20126	Economy	13000.00
0005433463865	20126	Economy	13000.00
0005434374359	20126	Economy	13000.00
0005433461557	20126	Economy	13000.00
0005433151491	20126	Economy	13000.00
0005433461554	20126	Economy	13000.00
0005433151494	20126	Economy	13000.00
0005434029662	20126	Economy	13000.00
0005433931474	20126	Economy	13000.00
0005433463871	20126	Economy	13000.00
0005433151481	20126	Economy	13000.00
0005433463873	20126	Economy	13000.00
0005432056308	20126	Economy	13000.00
0005433151469	20126	Economy	13000.00
0005433463874	20126	Economy	13000.00
0005434374225	20126	Economy	13000.00
0005434374330	20126	Economy	13000.00
0005433151484	20126	Economy	13000.00
0005433461552	20126	Economy	13000.00
0005433151465	20126	Economy	13000.00
0005434374416	20126	Economy	13000.00
0005433151489	20126	Economy	13000.00
0005433461559	20126	Economy	13000.00
0005433151471	20126	Economy	13000.00
0005434374218	20126	Economy	13000.00
0005433463869	20126	Economy	13000.00
0005434374358	20126	Economy	13000.00
0005434374392	20126	Economy	13000.00
0005433463866	20126	Economy	13000.00
0005432424532	592	Business	27500.00
0005432424545	592	Business	27500.00
0005432424535	592	Business	27500.00
0005432424544	592	Business	27500.00
0005432424547	592	Business	27500.00
0005432424549	592	Business	27500.00
0005432424554	592	Business	27500.00
0005432282881	592	Business	27500.00
0005432424520	592	Economy	10100.00
0005432424553	592	Economy	9200.00
0005432424542	592	Economy	9200.00
0005432424524	592	Economy	9200.00
0005432424552	592	Economy	9200.00
0005432424555	592	Economy	9200.00
0005432424538	592	Economy	9200.00
0005432282882	592	Economy	9200.00
0005432424570	592	Economy	9200.00
0005432424551	592	Economy	9200.00
0005432424530	592	Economy	9200.00
0005432424526	592	Economy	9200.00
0005432424564	592	Economy	9200.00
0005432424533	592	Economy	9200.00
0005432424527	592	Economy	9200.00
0005432424561	592	Economy	9200.00
0005432424569	592	Economy	9200.00
0005432424540	592	Economy	9200.00
0005432424568	592	Economy	9200.00
0005432282877	592	Economy	9200.00
0005432424536	592	Economy	9200.00
0005432424528	592	Economy	9200.00
0005432424548	592	Economy	9200.00
0005432424546	592	Economy	10100.00
0005432424534	592	Economy	10100.00
0005432424565	592	Economy	9200.00
0005432424560	592	Economy	10100.00
0005432424558	592	Economy	9200.00
0005432424529	592	Economy	9200.00
0005432424521	592	Economy	9200.00
0005432424563	592	Economy	9200.00
0005432424537	592	Economy	9200.00
0005432424559	592	Economy	9200.00
0005432424531	592	Economy	9200.00
0005432424525	592	Economy	9200.00
0005432282878	592	Economy	9200.00
0005432424557	592	Economy	9200.00
0005432424522	592	Economy	9200.00
0005432424543	592	Economy	9200.00
0005432424541	592	Economy	9200.00
0005432424556	592	Economy	9200.00
0005432424562	592	Economy	9200.00
0005432424550	592	Economy	9200.00
0005432282879	592	Economy	9200.00
0005432424539	592	Economy	9200.00
0005432282880	592	Economy	9200.00
0005432424523	592	Economy	9200.00
0005432424566	592	Economy	9200.00
0005432424567	592	Economy	9200.00
0005432302337	12854	Economy	9200.00
0005432302339	12854	Economy	9200.00
0005432302338	12854	Economy	9200.00
0005432302340	12854	Economy	9200.00
0005432423971	12849	Business	27500.00
0005432424052	12849	Business	27500.00
0005432424146	12849	Business	27500.00
0005432424069	12849	Business	27500.00
0005432424074	12849	Economy	10100.00
0005432424073	12849	Economy	10100.00
0005432424016	12849	Economy	10100.00
0005432424157	12849	Economy	10100.00
0005432424061	12849	Economy	10100.00
0005432424119	12849	Economy	9200.00
0005432424075	12849	Economy	9200.00
0005432424120	12849	Economy	9200.00
0005432424156	12849	Economy	9200.00
0005432424015	12849	Economy	9200.00
0005432424122	12849	Economy	9200.00
0005432424076	12849	Economy	9200.00
0005432424133	12849	Economy	9200.00
0005432423916	12849	Economy	9200.00
0005432424149	12849	Economy	9200.00
0005432424081	12849	Economy	9200.00
0005432423917	12849	Economy	9200.00
0005432424161	12849	Economy	9200.00
0005432424097	12849	Economy	9200.00
0005432423918	12849	Economy	9200.00
0005432423970	12849	Economy	9200.00
0005432423922	12849	Economy	9200.00
0005432423972	12849	Economy	10100.00
0005432424029	12849	Economy	9200.00
0005432424077	12849	Economy	9200.00
0005432424068	12849	Economy	9200.00
0005432424063	12849	Economy	9200.00
0005432424080	12849	Economy	9200.00
0005432423959	12849	Economy	9200.00
0005432424072	12849	Economy	9200.00
0005432423973	12849	Economy	9200.00
0005432424084	12849	Economy	9200.00
0005432424102	12849	Economy	9200.00
0005432424143	12849	Economy	9200.00
0005432424018	12849	Economy	9200.00
0005432424105	12849	Economy	9200.00
0005432424017	12849	Economy	9200.00
0005432424051	12849	Economy	9200.00
0005432424134	12849	Economy	9200.00
0005432424062	12849	Economy	9200.00
0005434032030	473	Business	24500.00
0005434735619	473	Business	24500.00
0005434023862	473	Business	24500.00
0005434023884	473	Business	24500.00
0005434023820	473	Business	24500.00
0005434023882	473	Business	24500.00
0005432045616	473	Business	24500.00
0005434028300	473	Business	24500.00
0005433057558	473	Business	24500.00
0005433057608	473	Business	24500.00
0005434032029	473	Business	24500.00
0005434735639	473	Business	24500.00
0005432235657	473	Business	24500.00
0005434023854	473	Business	24500.00
0005434023872	473	Business	24500.00
0005433929586	473	Business	24500.00
0005433057736	473	Business	24500.00
0005433057679	473	Business	24500.00
0005434023840	473	Economy	9000.00
0005434023852	473	Economy	9000.00
0005433057691	473	Economy	8200.00
0005433057671	473	Economy	8200.00
0005433057678	473	Economy	8200.00
0005434023863	473	Economy	8200.00
0005434023883	473	Economy	8200.00
0005432235656	473	Economy	8200.00
0005434023868	473	Economy	8200.00
0005433057626	473	Economy	8200.00
0005433057600	473	Economy	8200.00
0005433057737	473	Economy	8200.00
0005433057700	473	Economy	8200.00
0005434023843	473	Economy	8200.00
0005433057635	473	Economy	8200.00
0005433057725	473	Economy	8200.00
0005434023851	473	Economy	8200.00
0005434023850	473	Economy	8200.00
0005434735646	473	Economy	8200.00
0005434023861	473	Economy	8200.00
0005434032031	473	Economy	8200.00
0005434023860	473	Economy	8200.00
0005433057640	473	Economy	8200.00
0005434023828	473	Economy	8200.00
0005434023887	473	Economy	8200.00
0005434023871	473	Economy	8200.00
0005433684401	473	Economy	8200.00
0005433929581	473	Economy	8200.00
0005434023864	473	Economy	8200.00
0005434023866	473	Economy	8200.00
0005433057766	473	Economy	8200.00
0005433057669	473	Economy	8200.00
0005434029659	473	Economy	8200.00
0005434023824	473	Economy	8200.00
0005434028301	473	Economy	8200.00
0005434023819	473	Economy	8200.00
0005433684396	473	Economy	8200.00
0005433057581	473	Economy	8200.00
0005433057560	473	Economy	8200.00
0005433057684	473	Economy	8200.00
0005433057688	473	Economy	8200.00
0005434023880	473	Economy	8200.00
0005432235653	473	Economy	8200.00
0005434023830	473	Economy	8200.00
0005434023856	473	Economy	8200.00
0005434023842	473	Economy	8200.00
0005434023831	473	Economy	8200.00
0005434023886	473	Economy	8200.00
0005434023881	473	Economy	8200.00
0005434023877	473	Economy	8200.00
0005433684402	473	Economy	8200.00
0005433057694	473	Economy	8200.00
0005433057703	473	Economy	8200.00
0005434032028	473	Economy	8200.00
0005434023876	473	Economy	8200.00
0005434029660	473	Economy	8200.00
0005434023867	473	Economy	8200.00
0005433929587	473	Economy	8200.00
0005434023869	473	Economy	8200.00
0005433057582	473	Economy	8200.00
0005434023885	473	Economy	8200.00
0005434023834	473	Economy	8200.00
0005433929606	473	Economy	8200.00
0005434023821	473	Economy	8200.00
0005434023838	473	Economy	8200.00
0005433057623	473	Economy	8200.00
0005434023849	473	Economy	8200.00
0005434023857	473	Economy	8200.00
0005434023853	473	Economy	8200.00
0005434023855	473	Economy	8200.00
0005433057639	473	Economy	8200.00
0005434023841	473	Economy	8200.00
0005434023825	473	Economy	8200.00
0005433057767	473	Economy	8200.00
0005433057779	473	Economy	8200.00
0005433057690	473	Economy	9000.00
0005433929607	473	Economy	8200.00
0005434023878	473	Economy	8200.00
0005433057720	473	Economy	8200.00
0005433929585	473	Economy	9000.00
0005434028299	473	Economy	9000.00
0005434023875	473	Economy	8200.00
0005434023865	473	Economy	8200.00
0005433057738	473	Economy	8200.00
0005433057764	473	Economy	8200.00
0005434023818	473	Economy	8200.00
0005432045615	473	Economy	8200.00
0005434023837	473	Economy	8200.00
0005434023879	473	Economy	8200.00
0005434023844	473	Economy	8200.00
0005434023848	473	Economy	8200.00
0005434023836	473	Economy	8200.00
0005433057683	473	Economy	8200.00
0005432235654	473	Economy	8200.00
0005434023859	473	Economy	8200.00
0005432235652	473	Economy	8200.00
0005433057726	473	Economy	8200.00
0005434023833	473	Economy	8200.00
0005434023823	473	Economy	8200.00
0005434023847	473	Economy	8200.00
0005433929570	473	Economy	8200.00
0005433057609	473	Economy	8200.00
0005434023870	473	Economy	8200.00
0005434735640	473	Economy	8200.00
0005434023829	473	Economy	8200.00
0005433057689	473	Economy	8200.00
0005433057670	473	Economy	8200.00
0005433684395	473	Economy	8200.00
0005434023874	473	Economy	8200.00
0005433057477	473	Economy	8200.00
0005434023839	473	Economy	8200.00
0005434023826	473	Economy	8200.00
0005434023822	473	Economy	8200.00
0005434032032	473	Economy	8200.00
0005434023873	473	Economy	8200.00
0005433057516	473	Economy	8200.00
0005434023827	473	Economy	8200.00
0005434023832	473	Economy	8200.00
0005433057682	473	Economy	8200.00
0005433057559	473	Economy	8200.00
0005433057476	473	Economy	8200.00
0005434028298	473	Economy	8200.00
0005434023835	473	Economy	8200.00
0005434735645	473	Economy	8200.00
0005433684399	473	Economy	8200.00
0005434023845	473	Economy	8200.00
0005432235655	473	Economy	8200.00
0005434023846	473	Economy	8200.00
0005434735618	473	Economy	8200.00
0005434023858	473	Economy	8200.00
0005434735703	12668	Business	24500.00
0005433057984	12668	Business	24500.00
0005434023096	12668	Business	24500.00
0005433057954	12668	Business	24500.00
0005434023411	12668	Business	24500.00
0005434023207	12668	Business	24500.00
0005433057975	12668	Business	24500.00
0005434031960	12668	Business	24500.00
0005432157495	12668	Business	24500.00
0005433057990	12668	Business	24500.00
0005434023074	12668	Business	24500.00
0005434023073	12668	Business	24500.00
0005434023206	12668	Business	24500.00
0005434023097	12668	Business	24500.00
0005434023274	12668	Business	24500.00
0005433057955	12668	Business	24500.00
0005433057970	12668	Business	24500.00
0005434031988	12668	Business	24500.00
0005434031989	12668	Business	24500.00
0005434032003	12668	Business	24500.00
0005434023358	12668	Business	24500.00
0005433057974	12668	Business	24500.00
0005433057988	12668	Business	24500.00
0005433057957	12668	Business	24500.00
0005434023438	12668	Business	24500.00
0005434032002	12668	Business	24500.00
0005434031997	12668	Economy	9000.00
0005434023128	12668	Economy	9000.00
0005433057973	12668	Economy	8200.00
0005432156374	12668	Economy	8200.00
0005433057971	12668	Economy	8200.00
0005434023368	12668	Economy	8200.00
0005433057981	12668	Economy	8200.00
0005434023402	12668	Economy	8200.00
0005433929623	12668	Economy	8200.00
0005433057949	12668	Economy	8200.00
0005433057965	12668	Economy	8200.00
0005434023435	12668	Economy	8200.00
0005434023602	12668	Economy	8200.00
0005433057956	12668	Economy	8200.00
0005434735701	12668	Economy	8200.00
0005433057977	12668	Economy	8200.00
0005434028280	12668	Economy	8200.00
0005433057989	12668	Economy	8200.00
0005434023369	12668	Economy	8200.00
0005433057969	12668	Economy	8200.00
0005434028281	12668	Economy	8200.00
0005434028265	12668	Economy	8200.00
0005434023238	12668	Economy	8200.00
0005433057951	12668	Economy	8200.00
0005434022900	12668	Economy	8200.00
0005434032008	12668	Economy	8200.00
0005434023327	12668	Economy	8200.00
0005434735700	12668	Economy	8200.00
0005433057950	12668	Economy	8200.00
0005434023450	12668	Economy	8200.00
0005434023119	12668	Economy	8200.00
0005434023465	12668	Economy	8200.00
0005434023040	12668	Economy	8200.00
0005432157496	12668	Economy	8200.00
0005434023060	12668	Economy	8200.00
0005434023448	12668	Economy	8200.00
0005434023423	12668	Economy	8200.00
0005434023328	12668	Economy	8200.00
0005434023451	12668	Economy	8200.00
0005433057961	12668	Economy	8200.00
0005433057986	12668	Economy	8200.00
0005434023436	12668	Economy	8200.00
0005434028277	12668	Economy	8200.00
0005434032005	12668	Economy	8200.00
0005434023265	12668	Economy	8200.00
0005433057959	12668	Economy	8200.00
0005434023586	12668	Economy	8200.00
0005434023205	12668	Economy	8200.00
0005433057964	12668	Economy	8200.00
0005434023388	12668	Economy	8200.00
0005434023166	12668	Economy	8200.00
0005433057958	12668	Economy	8200.00
0005434023562	12668	Economy	8200.00
0005434023035	12668	Economy	8200.00
0005434032009	12668	Economy	8200.00
0005433057962	12668	Economy	8200.00
0005434032006	12668	Economy	8200.00
0005433057967	12668	Economy	8200.00
0005434023071	12668	Economy	8200.00
0005434023319	12668	Economy	8200.00
0005434028264	12668	Economy	8200.00
0005434031984	12668	Economy	8200.00
0005434023536	12668	Economy	8200.00
0005434023039	12668	Economy	8200.00
0005434023254	12668	Economy	8200.00
0005434023437	12668	Economy	9000.00
0005433057968	12668	Economy	9000.00
0005434023150	12668	Economy	8200.00
0005433057980	12668	Economy	8200.00
0005434023381	12668	Economy	8200.00
0005434023439	12668	Economy	8200.00
0005433057987	12668	Economy	8200.00
0005434023144	12668	Economy	8200.00
0005433057979	12668	Economy	8200.00
0005434023476	12668	Economy	8200.00
0005433684426	12668	Economy	8200.00
0005434029649	12668	Economy	8200.00
0005434022989	12668	Economy	8200.00
0005434023601	12668	Economy	8200.00
0005434735699	12668	Economy	8200.00
0005433057972	12668	Economy	8200.00
0005434023288	12668	Economy	8200.00
0005433057966	12668	Economy	8200.00
0005433057952	12668	Economy	8200.00
0005433929620	12668	Economy	8200.00
0005433057976	12668	Economy	8200.00
0005434023038	12668	Economy	8200.00
0005434735702	12668	Economy	8200.00
0005434031996	12668	Economy	8200.00
0005433057978	12668	Economy	8200.00
0005433929621	12668	Economy	8200.00
0005433057953	12668	Economy	8200.00
0005434023118	12668	Economy	8200.00
0005432156375	12668	Economy	8200.00
0005434023320	12668	Economy	8200.00
0005434023686	12668	Economy	8200.00
0005434023336	12668	Economy	8200.00
0005432156376	12668	Economy	8200.00
0005434023173	12668	Economy	8200.00
0005434023136	12668	Economy	8200.00
0005434023162	12668	Economy	8200.00
0005434023464	12668	Economy	8200.00
0005433929622	12668	Economy	8200.00
0005434023253	12668	Economy	8200.00
0005434023393	12668	Economy	8200.00
0005434023154	12668	Economy	8200.00
0005433057982	12668	Economy	8200.00
0005433057985	12668	Economy	8200.00
0005433057991	12668	Economy	8200.00
0005433684425	12668	Economy	8200.00
0005434023324	12668	Economy	8200.00
0005432156373	12668	Economy	8200.00
0005433057983	12668	Economy	8200.00
0005434023271	12668	Economy	8200.00
0005434023051	12668	Economy	8200.00
0005434023187	12668	Economy	8200.00
0005433057963	12668	Economy	8200.00
0005434023003	12668	Economy	8200.00
0005433684424	12668	Economy	8200.00
0005433057960	12668	Economy	8200.00
0005433923453	2160	Business	34700.00
0005434028264	2160	Business	34700.00
0005433923536	2160	Business	34700.00
0005433923469	2160	Business	34700.00
0005433923525	2160	Business	34700.00
0005433923452	2160	Business	34700.00
0005433923531	2160	Business	34700.00
0005433875382	2160	Business	34700.00
0005433929622	2160	Business	34700.00
0005433923455	2160	Business	34700.00
0005433923514	2160	Business	34700.00
0005433923461	2160	Business	34700.00
0005433035995	2160	Business	34700.00
0005433035948	2160	Business	34700.00
0005433923521	2160	Business	34700.00
0005433036015	2160	Business	34700.00
0005433923545	2160	Business	34700.00
0005433036028	2160	Business	34700.00
0005433923483	2160	Business	34700.00
0005433923547	2160	Business	34700.00
0005433923524	2160	Business	34700.00
0005433923480	2160	Business	34700.00
0005433036018	2160	Business	34700.00
0005433923522	2160	Business	34700.00
0005433923495	2160	Economy	12700.00
0005433923470	2160	Economy	12700.00
0005433923489	2160	Economy	12700.00
0005433923456	2160	Economy	11600.00
0005432231586	2160	Economy	11600.00
0005433923530	2160	Economy	11600.00
0005432231589	2160	Economy	11600.00
0005433035897	2160	Economy	11600.00
0005432231587	2160	Economy	11600.00
0005433923507	2160	Economy	11600.00
0005433923468	2160	Economy	11600.00
0005433035932	2160	Economy	11600.00
0005432044531	2160	Economy	11600.00
0005433929620	2160	Economy	11600.00
0005434028277	2160	Economy	11600.00
0005433035849	2160	Economy	11600.00
0005433035804	2160	Economy	11600.00
0005433036077	2160	Economy	11600.00
0005433036069	2160	Economy	11600.00
0005432231582	2160	Economy	11600.00
0005433923546	2160	Economy	11600.00
0005433923490	2160	Economy	11600.00
0005432231584	2160	Economy	11600.00
0005433923532	2160	Economy	11600.00
0005433036082	2160	Economy	11600.00
0005433923542	2160	Economy	11600.00
0005433923510	2160	Economy	11600.00
0005433923494	2160	Economy	11600.00
0005433923504	2160	Economy	11600.00
0005433035918	2160	Economy	11600.00
0005433923502	2160	Economy	11600.00
0005432749768	2160	Economy	11600.00
0005433923476	2160	Economy	11600.00
0005432231588	2160	Economy	11600.00
0005433923485	2160	Economy	11600.00
0005433923535	2160	Economy	11600.00
0005433923537	2160	Economy	11600.00
0005434028280	2160	Economy	11600.00
0005433923491	2160	Economy	11600.00
0005433036101	2160	Economy	11600.00
0005433875381	2160	Economy	11600.00
0005433929858	2160	Economy	11600.00
0005433923519	2160	Economy	11600.00
0005433923466	2160	Economy	11600.00
0005433923527	2160	Economy	11600.00
0005433923529	2160	Economy	11600.00
0005433923549	2160	Economy	11600.00
0005433923528	2160	Economy	11600.00
0005433923500	2160	Economy	11600.00
0005433931474	2160	Economy	11600.00
0005432231590	2160	Economy	11600.00
0005433923487	2160	Economy	11600.00
0005433923523	2160	Economy	11600.00
0005433923503	2160	Economy	11600.00
0005433923533	2160	Economy	11600.00
0005433035703	2160	Economy	11600.00
0005433923458	2160	Economy	11600.00
0005433035803	2160	Economy	11600.00
0005433923493	2160	Economy	11600.00
0005433923520	2160	Economy	11600.00
0005433036108	2160	Economy	11600.00
0005433923541	2160	Economy	11600.00
0005433923548	2160	Economy	11600.00
0005433035885	2160	Economy	11600.00
0005433923534	2160	Economy	11600.00
0005434028281	2160	Economy	11600.00
0005433923508	2160	Economy	11600.00
0005433035876	2160	Economy	11600.00
0005433036109	2160	Economy	11600.00
0005433923486	2160	Economy	11600.00
0005433035745	2160	Economy	11600.00
0005433923467	2160	Economy	11600.00
0005433923465	2160	Economy	11600.00
0005433923499	2160	Economy	11600.00
0005434028265	2160	Economy	11600.00
0005433923478	2160	Economy	11600.00
0005433035807	2160	Economy	11600.00
0005433923473	2160	Economy	12700.00
0005433923492	2160	Economy	12700.00
0005433035960	2160	Economy	11600.00
0005433035990	2160	Economy	12700.00
0005433923475	2160	Economy	12700.00
0005432749769	2160	Economy	11600.00
0005433923477	2160	Economy	11600.00
0005433929621	2160	Economy	11600.00
0005433929623	2160	Economy	11600.00
0005433923479	2160	Economy	11600.00
0005433923496	2160	Economy	11600.00
0005433923515	2160	Economy	11600.00
0005432231583	2160	Economy	11600.00
0005433923509	2160	Economy	11600.00
0005433923472	2160	Economy	11600.00
0005433923550	2160	Economy	11600.00
0005433923511	2160	Economy	11600.00
0005433923551	2160	Economy	11600.00
0005432044529	2160	Economy	11600.00
0005433035850	2160	Economy	11600.00
0005432231585	2160	Economy	11600.00
0005433923512	2160	Economy	11600.00
0005433875380	2160	Economy	11600.00
0005433035912	2160	Economy	11600.00
0005433035886	2160	Economy	11600.00
0005433923484	2160	Economy	11600.00
0005433923513	2160	Economy	11600.00
0005433035859	2160	Economy	11600.00
0005433923501	2160	Economy	11600.00
0005433035946	2160	Economy	11600.00
0005433923459	2160	Economy	11600.00
0005433923517	2160	Economy	11600.00
0005433923488	2160	Economy	11600.00
0005433036060	2160	Economy	11600.00
0005433923481	2160	Economy	11600.00
0005433923526	2160	Economy	11600.00
0005433923497	2160	Economy	11600.00
0005433923454	2160	Economy	11600.00
0005433923482	2160	Economy	11600.00
0005433036150	2160	Economy	11600.00
0005433036094	2160	Economy	11600.00
0005433923460	2160	Economy	11600.00
0005433035961	2160	Economy	11600.00
0005433036032	2160	Economy	11600.00
0005433923543	2160	Economy	11600.00
0005433035926	2160	Economy	11600.00
0005433931473	2160	Economy	11600.00
0005433923540	2160	Economy	11600.00
0005433035911	2160	Economy	11600.00
0005433923471	2160	Economy	11600.00
0005433923506	2160	Economy	11600.00
0005433035917	2160	Economy	11600.00
0005432231592	2160	Economy	11600.00
0005433923505	2160	Economy	11600.00
0005432044530	2160	Economy	11600.00
0005433923544	2160	Economy	11600.00
0005433035860	2160	Economy	11600.00
0005433923539	2160	Economy	11600.00
0005433923498	2160	Economy	11600.00
0005433923516	2160	Economy	11600.00
0005433923463	2160	Economy	11600.00
0005433035898	2160	Economy	11600.00
0005433923474	2160	Economy	11600.00
0005433036076	2160	Economy	11600.00
0005433036133	2160	Economy	11600.00
0005433923457	2160	Economy	11600.00
0005433923518	2160	Economy	11600.00
0005432231591	2160	Economy	11600.00
0005433923538	2160	Economy	11600.00
0005433931472	2160	Economy	11600.00
0005433923464	2160	Economy	11600.00
0005433036151	2160	Economy	11600.00
0005433923462	2160	Economy	11600.00
0005433922208	24126	Business	34700.00
0005432207668	24126	Business	34700.00
0005433922494	24126	Business	34700.00
0005433036422	24126	Business	34700.00
0005433922510	24126	Business	34700.00
0005433036418	24126	Business	34700.00
0005433922787	24126	Business	34700.00
0005433922596	24126	Business	34700.00
0005433036397	24126	Business	34700.00
0005433922419	24126	Business	34700.00
0005434028305	24126	Business	34700.00
0005433922513	24126	Business	34700.00
0005433931447	24126	Business	34700.00
0005433922400	24126	Business	34700.00
0005433036385	24126	Business	34700.00
0005433922442	24126	Business	34700.00
0005433922703	24126	Business	34700.00
0005433036425	24126	Business	34700.00
0005433922856	24126	Business	34700.00
0005433922131	24126	Business	34700.00
0005433036420	24126	Business	34700.00
0005433922509	24126	Business	34700.00
0005433922471	24126	Business	34700.00
0005433875370	24126	Business	34700.00
0005433036412	24126	Business	34700.00
0005432206210	24126	Business	34700.00
0005432749790	24126	Economy	12700.00
0005433922281	24126	Economy	11600.00
0005433922178	24126	Economy	12700.00
0005433922677	24126	Economy	11600.00
0005433922926	24126	Economy	11600.00
0005433036413	24126	Economy	11600.00
0005432206207	24126	Economy	11600.00
0005433922589	24126	Economy	11600.00
0005434028304	24126	Economy	11600.00
0005433922469	24126	Economy	11600.00
0005433036384	24126	Economy	11600.00
0005433922838	24126	Economy	11600.00
0005433922691	24126	Economy	11600.00
0005433036400	24126	Economy	11600.00
0005434028302	24126	Economy	11600.00
0005433036386	24126	Economy	11600.00
0005433922337	24126	Economy	11600.00
0005433922493	24126	Economy	11600.00
0005433036435	24126	Economy	11600.00
0005433036396	24126	Economy	11600.00
0005433922640	24126	Economy	11600.00
0005433922186	24126	Economy	11600.00
0005433922686	24126	Economy	11600.00
0005433922990	24126	Economy	11600.00
0005433922825	24126	Economy	11600.00
0005433922406	24126	Economy	11600.00
0005433922683	24126	Economy	11600.00
0005433929582	24126	Economy	11600.00
0005433922854	24126	Economy	11600.00
0005433036401	24126	Economy	11600.00
0005433036431	24126	Economy	11600.00
0005433922698	24126	Economy	11600.00
0005433036399	24126	Economy	11600.00
0005433922921	24126	Economy	11600.00
0005433922697	24126	Economy	11600.00
0005433922525	24126	Economy	11600.00
0005433929583	24126	Economy	11600.00
0005433929571	24126	Economy	11600.00
0005433922995	24126	Economy	11600.00
0005433036388	24126	Economy	11600.00
0005433922534	24126	Economy	11600.00
0005433036394	24126	Economy	11600.00
0005433036433	24126	Economy	11600.00
0005433922521	24126	Economy	11600.00
0005433922920	24126	Economy	11600.00
0005432749791	24126	Economy	11600.00
0005432207666	24126	Economy	11600.00
0005433036411	24126	Economy	11600.00
0005433922540	24126	Economy	11600.00
0005433922989	24126	Economy	11600.00
0005433036410	24126	Economy	11600.00
0005433036434	24126	Economy	11600.00
0005433922624	24126	Economy	11600.00
0005433929584	24126	Economy	11600.00
0005432206206	24126	Economy	11600.00
0005433036407	24126	Economy	11600.00
0005433036415	24126	Economy	11600.00
0005433036395	24126	Economy	11600.00
0005433922774	24126	Economy	11600.00
0005433036398	24126	Economy	11600.00
0005433036436	24126	Economy	11600.00
0005433922728	24126	Economy	11600.00
0005432206205	24126	Economy	11600.00
0005433931446	24126	Economy	11600.00
0005433036402	24126	Economy	11600.00
0005433922729	24126	Economy	11600.00
0005434028303	24126	Economy	11600.00
0005432206209	24126	Economy	11600.00
0005433036382	24126	Economy	11600.00
0005433922674	24126	Economy	11600.00
0005433036427	24126	Economy	11600.00
0005433036416	24126	Economy	11600.00
0005433922326	24126	Economy	11600.00
0005433931445	24126	Economy	11600.00
0005433929580	24126	Economy	11600.00
0005433922930	24126	Economy	11600.00
0005433923128	24126	Economy	11600.00
0005433922564	24126	Economy	11600.00
0005433922179	24126	Economy	12700.00
0005433922775	24126	Economy	12700.00
0005433036387	24126	Economy	11600.00
0005433922660	24126	Economy	11600.00
0005433036419	24126	Economy	12700.00
0005433922689	24126	Economy	12700.00
0005433922754	24126	Economy	11600.00
0005433923090	24126	Economy	11600.00
0005433036393	24126	Economy	11600.00
0005433922325	24126	Economy	11600.00
0005433922699	24126	Economy	11600.00
0005433922663	24126	Economy	11600.00
0005433036409	24126	Economy	11600.00
0005433922594	24126	Economy	11600.00
0005433922485	24126	Economy	11600.00
0005433036383	24126	Economy	11600.00
0005433922508	24126	Economy	11600.00
0005433922588	24126	Economy	11600.00
0005433922719	24126	Economy	11600.00
0005433929589	24126	Economy	11600.00
0005433036421	24126	Economy	11600.00
0005433036432	24126	Economy	11600.00
0005433922597	24126	Economy	11600.00
0005433922855	24126	Economy	11600.00
0005433036429	24126	Economy	11600.00
0005433931448	24126	Economy	11600.00
0005433036403	24126	Economy	11600.00
0005433922467	24126	Economy	11600.00
0005432207667	24126	Economy	11600.00
0005433931449	24126	Economy	11600.00
0005433922685	24126	Economy	11600.00
0005433922440	24126	Economy	11600.00
0005433036389	24126	Economy	11600.00
0005433922449	24126	Economy	11600.00
0005433036430	24126	Economy	11600.00
0005433923038	24126	Economy	11600.00
0005433922563	24126	Economy	11600.00
0005433929572	24126	Economy	11600.00
0005433922954	24126	Economy	11600.00
0005433923048	24126	Economy	11600.00
0005433036392	24126	Economy	11600.00
0005433922684	24126	Economy	11600.00
0005433036423	24126	Economy	11600.00
0005433036417	24126	Economy	11600.00
0005433922682	24126	Economy	11600.00
0005433922535	24126	Economy	11600.00
0005433922662	24126	Economy	11600.00
0005433036405	24126	Economy	11600.00
0005433036426	24126	Economy	11600.00
0005433922776	24126	Economy	11600.00
0005433922478	24126	Economy	11600.00
0005433922831	24126	Economy	11600.00
0005432206208	24126	Economy	11600.00
0005433922931	24126	Economy	11600.00
0005433036390	24126	Economy	11600.00
0005434028306	24126	Economy	11600.00
0005433922576	24126	Economy	11600.00
0005433036406	24126	Economy	11600.00
0005433922526	24126	Economy	11600.00
0005433922821	24126	Economy	11600.00
0005433875367	24126	Economy	11600.00
0005432749789	24126	Economy	11600.00
0005433036424	24126	Economy	11600.00
0005433922514	24126	Economy	11600.00
0005433036404	24126	Economy	11600.00
0005433922753	24126	Economy	11600.00
0005433036408	24126	Economy	11600.00
0005433036414	24126	Economy	11600.00
0005433922441	24126	Economy	11600.00
0005433923089	24126	Economy	11600.00
0005433036428	24126	Economy	11600.00
0005433036391	24126	Economy	11600.00
0005433922837	24126	Economy	11600.00
0005433922675	24126	Economy	11600.00
0005433233718	286	Business	83700.00
0005434725682	286	Business	83700.00
0005434725778	286	Business	83700.00
0005434725781	286	Business	83700.00
0005434551380	286	Business	83700.00
0005434551364	286	Business	83700.00
0005433234112	286	Business	83700.00
0005434551346	286	Business	83700.00
0005434725721	286	Business	83700.00
0005434725679	286	Business	83700.00
0005434725706	286	Business	83700.00
0005434725736	286	Business	83700.00
0005434551377	286	Business	83700.00
0005434725738	286	Business	83700.00
0005433233817	286	Business	83700.00
0005433180996	286	Business	83700.00
0005433233739	286	Business	83700.00
0005433180970	286	Business	83700.00
0005433233806	286	Business	83700.00
0005432277840	286	Business	83700.00
0005433233731	286	Business	83700.00
0005434551339	286	Business	83700.00
0005434725743	286	Business	83700.00
0005433289797	286	Business	83700.00
0005434551329	286	Business	83700.00
0005433113526	286	Comfort	47400.00
0005434725763	286	Comfort	47400.00
0005434725712	286	Comfort	47400.00
0005434551369	286	Comfort	47400.00
0005433233828	286	Comfort	47400.00
0005432277830	286	Comfort	47400.00
0005433233933	286	Comfort	47400.00
0005433233716	286	Comfort	47400.00
0005434551360	286	Comfort	47400.00
0005434725752	286	Comfort	47400.00
0005432277833	286	Comfort	47400.00
0005434725681	286	Comfort	47400.00
0005434725739	286	Comfort	47400.00
0005434551326	286	Comfort	47400.00
0005434735694	286	Comfort	47400.00
0005434551356	286	Comfort	47400.00
0005434031965	286	Comfort	47400.00
0005434725692	286	Comfort	47400.00
0005434725666	286	Comfort	47400.00
0005434031966	286	Comfort	47400.00
0005432277831	286	Comfort	47400.00
0005434725768	286	Comfort	47400.00
0005434725703	286	Comfort	47400.00
0005434551357	286	Comfort	47400.00
0005433131677	286	Comfort	47400.00
0005433233894	286	Comfort	47400.00
0005434551365	286	Comfort	47400.00
0005434725718	286	Comfort	47400.00
0005434551340	286	Comfort	47400.00
0005433233732	286	Comfort	47400.00
0005433233805	286	Comfort	47400.00
0005433233646	286	Comfort	47400.00
0005434725711	286	Comfort	47400.00
0005434551343	286	Comfort	47400.00
0005434725729	286	Comfort	47400.00
0005432277834	286	Comfort	47400.00
0005434725774	286	Comfort	47400.00
0005432277841	286	Comfort	47400.00
0005433233728	286	Comfort	47400.00
0005434725766	286	Comfort	47400.00
0005433233823	286	Comfort	47400.00
0005433180891	286	Comfort	47400.00
0005434551376	286	Comfort	47400.00
0005433233580	286	Economy	27900.00
0005434725705	286	Economy	27900.00
0005434725674	286	Economy	27900.00
0005434551334	286	Economy	27900.00
0005434302467	286	Economy	27900.00
0005434551349	286	Economy	27900.00
0005435142605	286	Economy	27900.00
0005434725764	286	Economy	27900.00
0005434551368	286	Economy	27900.00
0005433233942	286	Economy	27900.00
0005434551351	286	Economy	27900.00
0005433233554	286	Economy	27900.00
0005433180927	286	Economy	27900.00
0005433180938	286	Economy	27900.00
0005434731178	286	Economy	27900.00
0005434725668	286	Economy	27900.00
0005434551338	286	Economy	27900.00
0005434725737	286	Economy	27900.00
0005434725741	286	Economy	27900.00
0005433233733	286	Economy	27900.00
0005435142608	286	Economy	27900.00
0005434735698	286	Economy	27900.00
0005434725762	286	Economy	27900.00
0005434725748	286	Economy	27900.00
0005434725695	286	Economy	27900.00
0005434551337	286	Economy	27900.00
0005434725680	286	Economy	27900.00
0005433233635	286	Economy	27900.00
0005433233822	286	Economy	27900.00
0005433233768	286	Economy	27900.00
0005434725758	286	Economy	27900.00
0005434551366	286	Economy	27900.00
0005433233553	286	Economy	27900.00
0005434551345	286	Economy	27900.00
0005434725701	286	Economy	27900.00
0005434551353	286	Economy	27900.00
0005433180972	286	Economy	27900.00
0005433233668	286	Economy	27900.00
0005434725740	286	Economy	27900.00
0005434725696	286	Economy	27900.00
0005434551371	286	Economy	27900.00
0005433233697	286	Economy	27900.00
0005435142610	286	Economy	27900.00
0005434725731	286	Economy	27900.00
0005434725767	286	Economy	27900.00
0005434725691	286	Economy	27900.00
0005433233802	286	Economy	27900.00
0005433233582	286	Economy	27900.00
0005433233824	286	Economy	27900.00
0005433113518	286	Economy	27900.00
0005434725756	286	Economy	27900.00
0005434551358	286	Economy	27900.00
0005433233533	286	Economy	27900.00
0005434725726	286	Economy	27900.00
0005434551354	286	Economy	27900.00
0005434551332	286	Economy	27900.00
0005433180995	286	Economy	27900.00
0005434551347	286	Economy	27900.00
0005433289779	286	Economy	27900.00
0005433233517	286	Economy	27900.00
0005433233831	286	Economy	27900.00
0005433233745	286	Economy	30700.00
0005434725734	286	Economy	30700.00
0005433180907	286	Economy	27900.00
0005434551325	286	Economy	27900.00
0005433233564	286	Economy	27900.00
0005433233827	286	Economy	27900.00
0005434725776	286	Economy	30700.00
0005434725742	286	Economy	27900.00
0005434725733	286	Economy	30700.00
0005434725670	286	Economy	27900.00
0005434551359	286	Economy	27900.00
0005434725687	286	Economy	27900.00
0005434725677	286	Economy	27900.00
0005434725746	286	Economy	27900.00
0005434551375	286	Economy	27900.00
0005433233563	286	Economy	27900.00
0005433233992	286	Economy	27900.00
0005434725707	286	Economy	27900.00
0005434725747	286	Economy	27900.00
0005434735695	286	Economy	27900.00
0005435142601	286	Economy	27900.00
0005434725697	286	Economy	27900.00
0005434551344	286	Economy	27900.00
0005433233940	286	Economy	27900.00
0005434302471	286	Economy	27900.00
0005434725722	286	Economy	27900.00
0005433180971	286	Economy	27900.00
0005435142602	286	Economy	27900.00
0005434551330	286	Economy	27900.00
0005433766594	286	Economy	27900.00
0005434725719	286	Economy	27900.00
0005434725749	286	Economy	27900.00
0005433233851	286	Economy	27900.00
0005434725750	286	Economy	27900.00
0005434551367	286	Economy	27900.00
0005434725665	286	Economy	27900.00
0005434551324	286	Economy	27900.00
0005434551341	286	Economy	27900.00
0005434725754	286	Economy	27900.00
0005432277837	286	Economy	27900.00
0005434725700	286	Economy	27900.00
0005434725732	286	Economy	27900.00
0005432277832	286	Economy	27900.00
0005434302468	286	Economy	27900.00
0005434725710	286	Economy	27900.00
0005434725789	286	Economy	27900.00
0005434725769	286	Economy	27900.00
0005433233809	286	Economy	27900.00
0005433234073	286	Economy	27900.00
0005433233766	286	Economy	27900.00
0005433233686	286	Economy	27900.00
0005434551355	286	Economy	27900.00
0005433233781	286	Economy	27900.00
0005434725685	286	Economy	27900.00
0005434551372	286	Economy	27900.00
0005433233767	286	Economy	27900.00
0005435142612	286	Economy	27900.00
0005434725772	286	Economy	27900.00
0005433180950	286	Economy	27900.00
0005433233964	286	Economy	27900.00
0005433233501	286	Economy	27900.00
0005434725716	286	Economy	27900.00
0005434725709	286	Economy	27900.00
0005435142599	286	Economy	27900.00
0005435142603	286	Economy	27900.00
0005433233680	286	Economy	27900.00
0005433233927	286	Economy	27900.00
0005433233821	286	Economy	27900.00
0005435142604	286	Economy	27900.00
0005434725678	286	Economy	27900.00
0005434725760	286	Economy	27900.00
0005433131658	286	Economy	27900.00
0005434725735	286	Economy	27900.00
0005435142606	286	Economy	27900.00
0005434725744	286	Economy	27900.00
0005432277842	286	Economy	27900.00
0005434551336	286	Economy	27900.00
0005433180906	286	Economy	27900.00
0005433180933	286	Economy	27900.00
0005434725717	286	Economy	27900.00
0005434551363	286	Economy	27900.00
0005433233832	286	Economy	27900.00
0005433180810	286	Economy	27900.00
0005434725672	286	Economy	27900.00
0005434551362	286	Economy	27900.00
0005434725753	286	Economy	27900.00
0005434735693	286	Economy	27900.00
0005434725690	286	Economy	27900.00
0005434725708	286	Economy	27900.00
0005434725755	286	Economy	27900.00
0005433180905	286	Economy	27900.00
0005432277836	286	Economy	27900.00
0005434725683	286	Economy	27900.00
0005433233941	286	Economy	27900.00
0005434725724	286	Economy	27900.00
0005434551335	286	Economy	27900.00
0005433233896	286	Economy	27900.00
0005434725771	286	Economy	27900.00
0005433233884	286	Economy	27900.00
0005432277843	286	Economy	27900.00
0005434302470	286	Economy	27900.00
0005433289811	286	Economy	27900.00
0005434731176	286	Economy	27900.00
0005433233740	286	Economy	27900.00
0005435142607	286	Economy	27900.00
0005434551350	286	Economy	30700.00
0005434725693	286	Economy	27900.00
0005434551333	286	Economy	30700.00
0005434725786	286	Economy	30700.00
0005433233610	286	Economy	30700.00
0005434725723	286	Economy	30700.00
0005433233474	286	Economy	30700.00
0005433233681	286	Economy	27900.00
0005433233965	286	Economy	27900.00
0005434725785	286	Economy	27900.00
0005434551378	286	Economy	27900.00
0005433234014	286	Economy	27900.00
0005434725684	286	Economy	27900.00
0005434551379	286	Economy	27900.00
0005434725713	286	Economy	27900.00
0005434725698	286	Economy	27900.00
0005434551374	286	Economy	27900.00
0005434031994	286	Economy	27900.00
0005434302469	286	Economy	27900.00
0005434731175	286	Economy	27900.00
0005433233852	286	Economy	27900.00
0005433233611	286	Economy	27900.00
0005434725757	286	Economy	27900.00
0005434725725	286	Economy	27900.00
0005434725686	286	Economy	27900.00
0005434725751	286	Economy	27900.00
0005434725761	286	Economy	27900.00
0005432277838	286	Economy	27900.00
0005434551327	286	Economy	27900.00
0005434725671	286	Economy	27900.00
0005434725694	286	Economy	27900.00
0005434725720	286	Economy	27900.00
0005434725704	286	Economy	27900.00
0005433180908	286	Economy	27900.00
0005434551328	286	Economy	27900.00
0005433233502	286	Economy	27900.00
0005433113517	286	Economy	27900.00
0005434725715	286	Economy	27900.00
0005434725702	286	Economy	27900.00
0005434725788	286	Economy	27900.00
0005433233715	286	Economy	27900.00
0005434551352	286	Economy	27900.00
0005434725787	286	Economy	27900.00
0005434551373	286	Economy	27900.00
0005433131659	286	Economy	27900.00
0005434725784	286	Economy	27900.00
0005433233829	286	Economy	27900.00
0005434725675	286	Economy	27900.00
0005434551361	286	Economy	27900.00
0005433233801	286	Economy	27900.00
0005434725745	286	Economy	27900.00
0005435142611	286	Economy	27900.00
0005433289812	286	Economy	27900.00
0005433233669	286	Economy	27900.00
0005434031968	286	Economy	27900.00
0005434725669	286	Economy	27900.00
0005434725773	286	Economy	27900.00
0005434731174	286	Economy	27900.00
0005435142609	286	Economy	27900.00
0005434735697	286	Economy	27900.00
0005434725673	286	Economy	27900.00
0005434725779	286	Economy	27900.00
0005434725775	286	Economy	27900.00
0005434725688	286	Economy	27900.00
0005433233880	286	Economy	27900.00
0005433131680	286	Economy	27900.00
0005433289813	286	Economy	27900.00
0005433180986	286	Economy	27900.00
0005434725667	286	Economy	27900.00
0005434551348	286	Economy	27900.00
0005433233993	286	Economy	27900.00
0005434725777	286	Economy	27900.00
0005434725759	286	Economy	27900.00
0005433180916	286	Economy	27900.00
0005434551331	286	Economy	27900.00
0005433233534	286	Economy	27900.00
0005434031990	286	Economy	27900.00
0005434725730	286	Economy	27900.00
0005434735696	286	Economy	27900.00
0005433766610	286	Economy	27900.00
0005433233581	286	Economy	27900.00
0005434725728	286	Economy	27900.00
0005433233926	286	Economy	27900.00
0005435142600	286	Economy	27900.00
0005434725714	286	Economy	27900.00
0005434731177	286	Economy	27900.00
0005434725699	286	Economy	27900.00
0005434725782	286	Economy	27900.00
0005434551342	286	Economy	27900.00
0005434725780	286	Economy	27900.00
0005434725765	286	Economy	27900.00
0005433233730	286	Economy	27900.00
0005433113525	286	Economy	27900.00
0005433180859	286	Economy	27900.00
0005432277839	286	Economy	27900.00
0005433233752	286	Economy	27900.00
0005433289816	286	Economy	27900.00
0005434725727	286	Economy	27900.00
0005434725770	286	Economy	27900.00
0005433766600	286	Economy	27900.00
0005434725676	286	Economy	27900.00
0005434725689	286	Economy	27900.00
0005434725783	286	Economy	27900.00
0005433126802	286	Economy	27900.00
0005433180878	286	Economy	27900.00
0005432277835	286	Economy	27900.00
0005434551370	286	Economy	27900.00
0005433129286	9877	Business	83700.00
0005433234346	9877	Business	83700.00
0005434724700	9877	Business	83700.00
0005433234322	9877	Business	83700.00
0005434735652	9877	Business	83700.00
0005434724837	9877	Business	83700.00
0005434724819	9877	Business	83700.00
0005433234329	9877	Business	83700.00
0005434032035	9877	Business	83700.00
0005434550828	9877	Business	83700.00
0005434724556	9877	Business	83700.00
0005434724820	9877	Business	83700.00
0005434302417	9877	Business	83700.00
0005433126854	9877	Business	83700.00
0005434550823	9877	Business	83700.00
0005432199263	9877	Business	83700.00
0005434302418	9877	Business	83700.00
0005433129282	9877	Business	83700.00
0005434724844	9877	Business	83700.00
0005434724456	9877	Business	83700.00
0005434724385	9877	Business	83700.00
0005434724895	9877	Business	83700.00
0005433234313	9877	Business	83700.00
0005434724740	9877	Comfort	47400.00
0005434725263	9877	Business	83700.00
0005434550892	9877	Comfort	47400.00
0005434724231	9877	Comfort	47400.00
0005433234342	9877	Comfort	47400.00
0005433181155	9877	Comfort	47400.00
0005434302427	9877	Comfort	47400.00
0005434731146	9877	Comfort	47400.00
0005434724463	9877	Comfort	47400.00
0005434724951	9877	Comfort	47400.00
0005434550863	9877	Comfort	47400.00
0005434724884	9877	Comfort	47400.00
0005434302419	9877	Comfort	47400.00
0005434550724	9877	Comfort	47400.00
0005433181151	9877	Comfort	47400.00
0005434724504	9877	Comfort	47400.00
0005434724525	9877	Comfort	47400.00
0005434725229	9877	Comfort	47400.00
0005433289860	9877	Comfort	47400.00
0005433234358	9877	Comfort	47400.00
0005434724303	9877	Comfort	47400.00
0005433234336	9877	Comfort	47400.00
0005434724784	9877	Comfort	47400.00
0005434724891	9877	Comfort	47400.00
0005434724157	9877	Comfort	47400.00
0005434724149	9877	Comfort	47400.00
0005433234356	9877	Comfort	47400.00
0005435142494	9877	Comfort	47400.00
0005433234310	9877	Comfort	47400.00
0005434724988	9877	Comfort	47400.00
0005434724589	9877	Comfort	47400.00
0005434724670	9877	Comfort	47400.00
0005433234365	9877	Comfort	47400.00
0005434550647	9877	Comfort	47400.00
0005434724600	9877	Comfort	47400.00
0005434724968	9877	Comfort	47400.00
0005434724381	9877	Comfort	47400.00
0005433234319	9877	Comfort	47400.00
0005434550494	9877	Comfort	47400.00
0005435142499	9877	Comfort	47400.00
0005433234327	9877	Comfort	47400.00
0005433234359	9877	Economy	27900.00
0005434724575	9877	Economy	27900.00
0005434550664	9877	Economy	27900.00
0005434724848	9877	Economy	27900.00
0005434724732	9877	Economy	27900.00
0005433234321	9877	Economy	27900.00
0005433289864	9877	Economy	27900.00
0005434724967	9877	Economy	27900.00
0005434724840	9877	Economy	27900.00
0005434550765	9877	Economy	27900.00
0005433181142	9877	Economy	27900.00
0005433234326	9877	Economy	27900.00
0005434032034	9877	Economy	27900.00
0005433234340	9877	Economy	27900.00
0005434724515	9877	Economy	27900.00
0005433181143	9877	Economy	27900.00
0005433234366	9877	Economy	27900.00
0005434724358	9877	Economy	27900.00
0005434724382	9877	Economy	27900.00
0005433234337	9877	Economy	27900.00
0005434550775	9877	Economy	27900.00
0005434725007	9877	Economy	27900.00
0005434731131	9877	Economy	27900.00
0005434725207	9877	Economy	27900.00
0005434725109	9877	Economy	27900.00
0005434725256	9877	Economy	27900.00
0005434724733	9877	Economy	27900.00
0005434725199	9877	Economy	27900.00
0005433234311	9877	Economy	27900.00
0005432199260	9877	Economy	27900.00
0005434724857	9877	Economy	27900.00
0005434725155	9877	Economy	27900.00
0005433181149	9877	Economy	27900.00
0005433234341	9877	Economy	27900.00
0005434550864	9877	Economy	27900.00
0005433234364	9877	Economy	27900.00
0005433181160	9877	Economy	27900.00
0005434724812	9877	Economy	27900.00
0005433234367	9877	Economy	27900.00
0005433234333	9877	Economy	27900.00
0005434032037	9877	Economy	27900.00
0005433234357	9877	Economy	27900.00
0005434550648	9877	Economy	27900.00
0005434724577	9877	Economy	27900.00
0005433234320	9877	Economy	27900.00
0005434724439	9877	Economy	27900.00
0005434724447	9877	Economy	27900.00
0005434302416	9877	Economy	27900.00
0005434724937	9877	Economy	27900.00
0005433289859	9877	Economy	27900.00
0005434724136	9877	Economy	27900.00
0005434725102	9877	Economy	27900.00
0005434724963	9877	Economy	27900.00
0005433126855	9877	Economy	27900.00
0005434724440	9877	Economy	27900.00
0005435142461	9877	Economy	27900.00
0005434724762	9877	Economy	27900.00
0005434724135	9877	Economy	27900.00
0005433181154	9877	Economy	27900.00
0005433234352	9877	Economy	27900.00
0005434724503	9877	Economy	27900.00
0005434550732	9877	Economy	27900.00
0005434724831	9877	Economy	27900.00
0005434724335	9877	Economy	30700.00
0005434550904	9877	Economy	27900.00
0005433289863	9877	Economy	27900.00
0005434724739	9877	Economy	27900.00
0005435142460	9877	Economy	27900.00
0005434550678	9877	Economy	30700.00
0005434725103	9877	Economy	27900.00
0005433234343	9877	Economy	27900.00
0005433234339	9877	Economy	27900.00
0005434725114	9877	Economy	27900.00
0005434550590	9877	Economy	27900.00
0005434724539	9877	Economy	27900.00
0005434724486	9877	Economy	27900.00
0005434735648	9877	Economy	27900.00
0005432199265	9877	Economy	27900.00
0005433181152	9877	Economy	27900.00
0005433129284	9877	Economy	27900.00
0005434724455	9877	Economy	27900.00
0005434724882	9877	Economy	27900.00
0005434550646	9877	Economy	27900.00
0005434724907	9877	Economy	27900.00
0005434550774	9877	Economy	27900.00
0005433234308	9877	Economy	27900.00
0005434550401	9877	Economy	27900.00
0005434550692	9877	Economy	27900.00
0005434735651	9877	Economy	27900.00
0005434724691	9877	Economy	27900.00
0005433181145	9877	Economy	27900.00
0005433181158	9877	Economy	27900.00
0005435142481	9877	Economy	27900.00
0005434724698	9877	Economy	27900.00
0005434724625	9877	Economy	27900.00
0005434724581	9877	Economy	27900.00
0005434725198	9877	Economy	27900.00
0005434724742	9877	Economy	27900.00
0005433234361	9877	Economy	27900.00
0005433234345	9877	Economy	27900.00
0005433234331	9877	Economy	27900.00
0005434550893	9877	Economy	27900.00
0005433234323	9877	Economy	27900.00
0005434724649	9877	Economy	27900.00
0005434724751	9877	Economy	27900.00
0005433234309	9877	Economy	27900.00
0005434724549	9877	Economy	27900.00
0005433234334	9877	Economy	27900.00
0005434724734	9877	Economy	27900.00
0005434735649	9877	Economy	27900.00
0005434550865	9877	Economy	27900.00
0005435142467	9877	Economy	27900.00
0005434724574	9877	Economy	27900.00
0005433234347	9877	Economy	27900.00
0005434550783	9877	Economy	27900.00
0005434725101	9877	Economy	27900.00
0005434724832	9877	Economy	27900.00
0005433181161	9877	Economy	27900.00
0005434724582	9877	Economy	27900.00
0005434724795	9877	Economy	27900.00
0005434550788	9877	Economy	27900.00
0005435142487	9877	Economy	27900.00
0005433234353	9877	Economy	27900.00
0005433234318	9877	Economy	27900.00
0005435142462	9877	Economy	27900.00
0005433181146	9877	Economy	27900.00
0005433234363	9877	Economy	27900.00
0005433766648	9877	Economy	27900.00
0005434550698	9877	Economy	27900.00
0005434724526	9877	Economy	27900.00
0005434724383	9877	Economy	27900.00
0005434724881	9877	Economy	27900.00
0005434550587	9877	Economy	27900.00
0005434724349	9877	Economy	27900.00
0005433113539	9877	Economy	27900.00
0005434550773	9877	Economy	27900.00
0005434724838	9877	Economy	27900.00
0005434550866	9877	Economy	27900.00
0005434724986	9877	Economy	27900.00
0005433129285	9877	Economy	27900.00
0005434724588	9877	Economy	27900.00
0005434550744	9877	Economy	27900.00
0005434735647	9877	Economy	27900.00
0005434724643	9877	Economy	27900.00
0005433234349	9877	Economy	27900.00
0005435142493	9877	Economy	27900.00
0005434550564	9877	Economy	27900.00
0005434724660	9877	Economy	27900.00
0005434724513	9877	Economy	27900.00
0005433234355	9877	Economy	27900.00
0005434724362	9877	Economy	27900.00
0005434724181	9877	Economy	27900.00
0005433289862	9877	Economy	27900.00
0005434724869	9877	Economy	27900.00
0005434725006	9877	Economy	27900.00
0005434550787	9877	Economy	27900.00
0005433181162	9877	Economy	27900.00
0005433181144	9877	Economy	27900.00
0005434724555	9877	Economy	27900.00
0005434724890	9877	Economy	30700.00
0005433181157	9877	Economy	27900.00
0005433234317	9877	Economy	30700.00
0005434724158	9877	Economy	30700.00
0005433234316	9877	Economy	30700.00
0005434724706	9877	Economy	30700.00
0005434724156	9877	Economy	27900.00
0005434550979	9877	Economy	27900.00
0005434724847	9877	Economy	27900.00
0005434724347	9877	Economy	27900.00
0005434724856	9877	Economy	27900.00
0005434550809	9877	Economy	27900.00
0005433234315	9877	Economy	27900.00
0005433181147	9877	Economy	27900.00
0005433126853	9877	Economy	27900.00
0005433234307	9877	Economy	27900.00
0005434550778	9877	Economy	27900.00
0005433181159	9877	Economy	27900.00
0005433234324	9877	Economy	27900.00
0005434724985	9877	Economy	27900.00
0005433234325	9877	Economy	27900.00
0005433234354	9877	Economy	27900.00
0005432199262	9877	Economy	27900.00
0005433181139	9877	Economy	27900.00
0005434724874	9877	Economy	27900.00
0005434724669	9877	Economy	27900.00
0005434724987	9877	Economy	27900.00
0005433234362	9877	Economy	27900.00
0005434725152	9877	Economy	27900.00
0005434723636	9877	Economy	27900.00
0005433234306	9877	Economy	27900.00
0005434724340	9877	Economy	27900.00
0005434724375	9877	Economy	27900.00
0005433234328	9877	Economy	27900.00
0005433234305	9877	Economy	27900.00
0005434724416	9877	Economy	27900.00
0005434724673	9877	Economy	27900.00
0005433766647	9877	Economy	27900.00
0005433234360	9877	Economy	27900.00
0005432199259	9877	Economy	27900.00
0005434724672	9877	Economy	27900.00
0005434551023	9877	Economy	27900.00
0005433181150	9877	Economy	27900.00
0005434724650	9877	Economy	27900.00
0005434550563	9877	Economy	27900.00
0005434550565	9877	Economy	27900.00
0005433181156	9877	Economy	27900.00
0005434725134	9877	Economy	27900.00
0005434731139	9877	Economy	27900.00
0005432199261	9877	Economy	27900.00
0005434725005	9877	Economy	27900.00
0005433234304	9877	Economy	27900.00
0005434724432	9877	Economy	27900.00
0005433766649	9877	Economy	27900.00
0005434550566	9877	Economy	27900.00
0005434724576	9877	Economy	27900.00
0005434724310	9877	Economy	27900.00
0005434724348	9877	Economy	27900.00
0005434724873	9877	Economy	27900.00
0005434724858	9877	Economy	27900.00
0005433234330	9877	Economy	27900.00
0005434550838	9877	Economy	27900.00
0005433234314	9877	Economy	27900.00
0005434550764	9877	Economy	27900.00
0005433181153	9877	Economy	27900.00
0005433234332	9877	Economy	27900.00
0005434724637	9877	Economy	27900.00
0005435142401	9877	Economy	27900.00
0005433234344	9877	Economy	27900.00
0005434550691	9877	Economy	27900.00
0005433234348	9877	Economy	27900.00
0005433234351	9877	Economy	27900.00
0005433181164	9877	Economy	27900.00
0005433181140	9877	Economy	27900.00
0005435142438	9877	Economy	27900.00
0005433181163	9877	Economy	27900.00
0005433234312	9877	Economy	27900.00
0005435142437	9877	Economy	27900.00
0005433234338	9877	Economy	27900.00
0005433181148	9877	Economy	27900.00
0005434032033	9877	Economy	27900.00
0005433126852	9877	Economy	27900.00
0005433113541	9877	Economy	27900.00
0005433129283	9877	Economy	27900.00
0005434724376	9877	Economy	27900.00
0005434735650	9877	Economy	27900.00
0005434724787	9877	Economy	27900.00
0005434724569	9877	Economy	27900.00
0005434724514	9877	Economy	27900.00
0005433234350	9877	Economy	27900.00
0005434550584	9877	Economy	27900.00
0005434724839	9877	Economy	27900.00
0005433234335	9877	Economy	27900.00
0005433181141	9877	Economy	27900.00
0005434032036	9877	Economy	27900.00
0005434724771	9877	Economy	27900.00
0005434724464	9877	Economy	27900.00
0005434550586	9877	Economy	27900.00
0005432199264	9877	Economy	27900.00
0005433113540	9877	Economy	27900.00
0005434550877	9877	Economy	27900.00
0005433289861	9877	Economy	27900.00
0005434550766	9877	Economy	27900.00
0005434067698	7734	Business	42100.00
0005432528311	7734	Business	42100.00
0005434067695	7734	Business	42100.00
0005435213153	7734	Business	42100.00
0005434067741	7734	Business	42100.00
0005435213029	7734	Business	42100.00
0005435213296	7734	Business	42100.00
0005434067684	7734	Business	42100.00
0005432150212	7734	Business	42100.00
0005435213219	7734	Business	42100.00
0005432528200	7734	Business	42100.00
0005432528213	7734	Business	42100.00
0005432528222	7734	Business	42100.00
0005432528312	7734	Business	42100.00
0005432528232	7734	Business	42100.00
0005434067704	7734	Business	42100.00
0005434067720	7734	Business	42100.00
0005432528204	7734	Business	42100.00
0005432528228	7734	Business	42100.00
0005434067688	7734	Business	42100.00
0005432528302	7734	Business	42100.00
0005432528226	7734	Business	42100.00
0005434067736	7734	Business	42100.00
0005432528255	7734	Business	42100.00
0005432535845	7734	Comfort	23900.00
0005432528239	7734	Comfort	23900.00
0005434067687	7734	Comfort	23900.00
0005434067689	7734	Comfort	23900.00
0005432069681	7734	Comfort	23900.00
0005435213295	7734	Comfort	23900.00
0005432528273	7734	Comfort	23900.00
0005435630939	7734	Comfort	23900.00
0005432533298	7734	Comfort	23900.00
0005432528257	7734	Comfort	23900.00
0005434067714	7734	Comfort	23900.00
0005435213083	7734	Comfort	23900.00
0005435213220	7734	Comfort	23900.00
0005432528191	7734	Comfort	23900.00
0005432528208	7734	Comfort	23900.00
0005432528241	7734	Comfort	23900.00
0005435725558	7734	Comfort	23900.00
0005432528282	7734	Comfort	23900.00
0005432528252	7734	Comfort	23900.00
0005435213004	7734	Comfort	23900.00
0005432528186	7734	Comfort	23900.00
0005432528260	7734	Comfort	23900.00
0005432528274	7734	Comfort	23900.00
0005432528291	7734	Comfort	23900.00
0005434067707	7734	Comfort	23900.00
0005432528316	7734	Comfort	23900.00
0005432528301	7734	Comfort	23900.00
0005432528187	7734	Comfort	23900.00
0005432528210	7734	Comfort	23900.00
0005432528253	7734	Comfort	23900.00
0005432069686	7734	Comfort	23900.00
0005434067717	7734	Comfort	23900.00
0005435213139	7734	Comfort	23900.00
0005434067693	7734	Comfort	23900.00
0005434067705	7734	Comfort	23900.00
0005432528267	7734	Comfort	23900.00
0005432528292	7734	Comfort	23900.00
0005432528185	7734	Comfort	23900.00
0005432069688	7734	Comfort	23900.00
0005432069684	7734	Economy	14000.00
0005435213163	7734	Comfort	23900.00
0005432528287	7734	Economy	14000.00
0005434067737	7734	Economy	14000.00
0005435725578	7734	Economy	14000.00
0005432528217	7734	Economy	14000.00
0005434067731	7734	Economy	14000.00
0005432528225	7734	Economy	14000.00
0005435212951	7734	Economy	14000.00
0005435213036	7734	Economy	14000.00
0005435725521	7734	Economy	14000.00
0005432528263	7734	Economy	14000.00
0005432528223	7734	Economy	14000.00
0005432528306	7734	Economy	14000.00
0005435213008	7734	Economy	14000.00
0005434067690	7734	Economy	14000.00
0005432528246	7734	Economy	14000.00
0005435725559	7734	Economy	14000.00
0005434067711	7734	Economy	14000.00
0005432528294	7734	Economy	14000.00
0005432528212	7734	Economy	14000.00
0005432528188	7734	Economy	14000.00
0005432535841	7734	Economy	14000.00
0005435212984	7734	Economy	14000.00
0005432528285	7734	Economy	14000.00
0005434067724	7734	Economy	14000.00
0005434067700	7734	Economy	14000.00
0005432069690	7734	Economy	14000.00
0005432069689	7734	Economy	14000.00
0005432528224	7734	Economy	14000.00
0005435213130	7734	Economy	14000.00
0005432528281	7734	Economy	14000.00
0005432528270	7734	Economy	14000.00
0005432528299	7734	Economy	14000.00
0005434067699	7734	Economy	14000.00
0005432528216	7734	Economy	14000.00
0005435213118	7734	Economy	14000.00
0005435213179	7734	Economy	14000.00
0005435630936	7734	Economy	14000.00
0005432528314	7734	Economy	14000.00
0005432528288	7734	Economy	14000.00
0005432528259	7734	Economy	14000.00
0005434067677	7734	Economy	14000.00
0005432428936	7734	Economy	14000.00
0005432150213	7734	Economy	14000.00
0005432535843	7734	Economy	14000.00
0005432528215	7734	Economy	14000.00
0005432528256	7734	Economy	14000.00
0005432069679	7734	Economy	14000.00
0005434067738	7734	Economy	14000.00
0005435212957	7734	Economy	14000.00
0005434067728	7734	Economy	14000.00
0005432528265	7734	Economy	14000.00
0005432528266	7734	Economy	14000.00
0005432069680	7734	Economy	14000.00
0005435212978	7734	Economy	14000.00
0005432528199	7734	Economy	15400.00
0005434067706	7734	Economy	15400.00
0005435213084	7734	Economy	14000.00
0005434067680	7734	Economy	14000.00
0005434067691	7734	Economy	14000.00
0005432069677	7734	Economy	15400.00
0005434067694	7734	Economy	14000.00
0005432428937	7734	Economy	15400.00
0005434067709	7734	Economy	14000.00
0005434067681	7734	Economy	15400.00
0005432528214	7734	Economy	14000.00
0005435213231	7734	Economy	14000.00
0005435213157	7734	Economy	14000.00
0005432528315	7734	Economy	14000.00
0005432528245	7734	Economy	14000.00
0005432528293	7734	Economy	14000.00
0005435213051	7734	Economy	14000.00
0005434067703	7734	Economy	14000.00
0005432528190	7734	Economy	14000.00
0005432528296	7734	Economy	14000.00
0005432528235	7734	Economy	14000.00
0005432069685	7734	Economy	14000.00
0005432528237	7734	Economy	14000.00
0005435212910	7734	Economy	14000.00
0005434067701	7734	Economy	14000.00
0005432528240	7734	Economy	14000.00
0005432528184	7734	Economy	14000.00
0005432528194	7734	Economy	14000.00
0005434067744	7734	Economy	14000.00
0005432528203	7734	Economy	14000.00
0005432528300	7734	Economy	14000.00
0005434067730	7734	Economy	14000.00
0005433656649	7734	Economy	14000.00
0005432528233	7734	Economy	14000.00
0005432150214	7734	Economy	14000.00
0005432528193	7734	Economy	14000.00
0005434067715	7734	Economy	14000.00
0005432528202	7734	Economy	14000.00
0005432528234	7734	Economy	14000.00
0005432528247	7734	Economy	14000.00
0005432528197	7734	Economy	14000.00
0005435213052	7734	Economy	14000.00
0005432528238	7734	Economy	14000.00
0005432528269	7734	Economy	14000.00
0005435212909	7734	Economy	14000.00
0005432528305	7734	Economy	14000.00
0005435213065	7734	Economy	14000.00
0005432528230	7734	Economy	14000.00
0005432069691	7734	Economy	14000.00
0005432528308	7734	Economy	14000.00
0005434067685	7734	Economy	14000.00
0005432528304	7734	Economy	14000.00
0005435212728	7734	Economy	14000.00
0005432428935	7734	Economy	14000.00
0005432528309	7734	Economy	14000.00
0005434067713	7734	Economy	14000.00
0005434067727	7734	Economy	14000.00
0005433656637	7734	Economy	14000.00
0005435630940	7734	Economy	14000.00
0005435213054	7734	Economy	14000.00
0005432528271	7734	Economy	14000.00
0005435725573	7734	Economy	14000.00
0005432528242	7734	Economy	14000.00
0005434067678	7734	Economy	14000.00
0005434067708	7734	Economy	14000.00
0005432528227	7734	Economy	14000.00
0005432150207	7734	Economy	14000.00
0005432528209	7734	Economy	14000.00
0005435213081	7734	Economy	14000.00
0005432528243	7734	Economy	14000.00
0005432528195	7734	Economy	14000.00
0005434067721	7734	Economy	14000.00
0005435213149	7734	Economy	14000.00
0005432528286	7734	Economy	14000.00
0005435213006	7734	Economy	14000.00
0005432528192	7734	Economy	14000.00
0005434067686	7734	Economy	14000.00
0005432528254	7734	Economy	14000.00
0005435213274	7734	Economy	14000.00
0005435213365	7734	Economy	14000.00
0005434067719	7734	Economy	14000.00
0005434067735	7734	Economy	14000.00
0005432528219	7734	Economy	14000.00
0005434067702	7734	Economy	14000.00
0005432528289	7734	Economy	14000.00
0005432528201	7734	Economy	14000.00
0005435212960	7734	Economy	14000.00
0005432528207	7734	Economy	14000.00
0005432528313	7734	Economy	14000.00
0005432150209	7734	Economy	14000.00
0005432528307	7734	Economy	14000.00
0005432528258	7734	Economy	14000.00
0005434067692	7734	Economy	14000.00
0005432069678	7734	Economy	14000.00
0005432528249	7734	Economy	14000.00
0005435213305	7734	Economy	14000.00
0005435213195	7734	Economy	14000.00
0005432528272	7734	Economy	14000.00
0005435213071	7734	Economy	14000.00
0005435213148	7734	Economy	14000.00
0005432528220	7734	Economy	14000.00
0005434067742	7734	Economy	14000.00
0005432528196	7734	Economy	14000.00
0005434067712	7734	Economy	15400.00
0005434067726	7734	Economy	15400.00
0005432535842	7734	Economy	15400.00
0005434067716	7734	Economy	15400.00
0005434067725	7734	Economy	15400.00
0005432528211	7734	Economy	14000.00
0005435213230	7734	Economy	14000.00
0005432528303	7734	Economy	14000.00
0005432528248	7734	Economy	14000.00
0005432528275	7734	Economy	14000.00
0005432537062	7734	Economy	14000.00
0005434067732	7734	Economy	14000.00
0005432150211	7734	Economy	14000.00
0005432528231	7734	Economy	14000.00
0005435213114	7734	Economy	14000.00
0005434067682	7734	Economy	14000.00
0005434067746	7734	Economy	14000.00
0005434067739	7734	Economy	14000.00
0005432528277	7734	Economy	14000.00
0005435213073	7734	Economy	14000.00
0005432069682	7734	Economy	14000.00
0005434067745	7734	Economy	14000.00
0005432528218	7734	Economy	14000.00
0005435213021	7734	Economy	14000.00
0005432535844	7734	Economy	14000.00
0005435212430	7734	Economy	14000.00
0005434067683	7734	Economy	14000.00
0005435212962	7734	Economy	14000.00
0005435213113	7734	Economy	14000.00
0005432150210	7734	Economy	14000.00
0005432528284	7734	Economy	14000.00
0005433656627	7734	Economy	14000.00
0005432069683	7734	Economy	14000.00
0005435212919	7734	Economy	14000.00
0005435213196	7734	Economy	14000.00
0005432528189	7734	Economy	14000.00
0005435213277	7734	Economy	14000.00
0005432528298	7734	Economy	14000.00
0005432528295	7734	Economy	14000.00
0005435212912	7734	Economy	14000.00
0005434067743	7734	Economy	14000.00
0005434067733	7734	Economy	14000.00
0005435213194	7734	Economy	14000.00
0005434067723	7734	Economy	14000.00
0005435212918	7734	Economy	14000.00
0005432528264	7734	Economy	14000.00
0005432528206	7734	Economy	14000.00
0005435213308	7734	Economy	14000.00
0005432533297	7734	Economy	14000.00
0005435630935	7734	Economy	14000.00
0005434067696	7734	Economy	14000.00
0005434067679	7734	Economy	14000.00
0005434067740	7734	Economy	14000.00
0005435212793	7734	Economy	14000.00
0005432528221	7734	Economy	14000.00
0005432528297	7734	Economy	14000.00
0005432528250	7734	Economy	14000.00
0005435213079	7734	Economy	14000.00
0005432528261	7734	Economy	14000.00
0005435213152	7734	Economy	14000.00
0005434067718	7734	Economy	14000.00
0005432528310	7734	Economy	14000.00
0005435213205	7734	Economy	14000.00
0005432150208	7734	Economy	14000.00
0005432528279	7734	Economy	14000.00
0005435212727	7734	Economy	14000.00
0005435212917	7734	Economy	14000.00
0005435213135	7734	Economy	14000.00
0005432528251	7734	Economy	14000.00
0005435213007	7734	Economy	14000.00
0005432528283	7734	Economy	14000.00
0005434067734	7734	Economy	14000.00
0005434067722	7734	Economy	14000.00
0005435212916	7734	Economy	14000.00
0005432528198	7734	Economy	14000.00
0005432537061	7734	Economy	14000.00
0005432528244	7734	Economy	14000.00
0005432069687	7734	Economy	14000.00
0005432528280	7734	Economy	14000.00
0005435213078	7734	Economy	14000.00
0005434067710	7734	Economy	14000.00
0005432528278	7734	Economy	14000.00
0005435213199	7734	Economy	14000.00
0005432528229	7734	Economy	14000.00
0005434067697	7734	Economy	14000.00
0005434067729	7734	Economy	14000.00
0005434067676	7734	Economy	14000.00
0005432069692	7734	Economy	14000.00
0005432528205	7734	Economy	14000.00
0005435212950	7734	Economy	14000.00
0005432528276	7734	Economy	14000.00
0005435212911	7734	Economy	14000.00
0005435213210	7734	Economy	14000.00
0005432528236	7734	Economy	14000.00
0005435213082	7734	Economy	14000.00
0005435213197	7734	Economy	14000.00
0005432528262	7734	Economy	14000.00
0005435213209	7734	Economy	14000.00
0005432528268	7734	Economy	14000.00
0005435213115	7734	Economy	14000.00
0005432528290	7734	Economy	14000.00
0005434244714	5336	Business	43100.00
0005435613872	5336	Business	43100.00
0005435490235	5336	Business	43100.00
0005434573375	5336	Business	43100.00
0005435491444	5336	Business	43100.00
0005434244801	5336	Business	43100.00
0005435613849	5336	Business	43100.00
0005435613904	5336	Business	43100.00
0005435613903	5336	Business	43100.00
0005435613859	5336	Business	43100.00
0005435613880	5336	Business	43100.00
0005434344312	5336	Business	43100.00
0005434573383	5336	Business	43100.00
0005435613821	5336	Business	43100.00
0005435613935	5336	Business	43100.00
0005435613936	5336	Business	43100.00
0005435613823	5336	Business	43100.00
0005435424434	5336	Business	43100.00
0005432133242	5336	Business	43100.00
0005435613918	5336	Business	43100.00
0005435424171	5336	Business	43100.00
0005435613956	5336	Business	43100.00
0005434344289	5336	Business	43100.00
0005435613873	5336	Business	43100.00
0005434344318	5336	Comfort	24400.00
0005435613871	5336	Comfort	24400.00
0005433719100	5336	Comfort	24400.00
0005435613825	5336	Comfort	24400.00
0005434244793	5336	Comfort	24400.00
0005435613914	5336	Comfort	24400.00
0005434244846	5336	Comfort	24400.00
0005432133245	5336	Comfort	24400.00
0005434344294	5336	Comfort	24400.00
0005434344316	5336	Comfort	24400.00
0005434344308	5336	Comfort	24400.00
0005434344313	5336	Comfort	24400.00
0005434573380	5336	Comfort	24400.00
0005435424586	5336	Comfort	24400.00
0005435097219	5336	Comfort	24400.00
0005435302179	5336	Comfort	24400.00
0005435613870	5336	Comfort	24400.00
0005435319520	5336	Comfort	24400.00
0005435613931	5336	Comfort	24400.00
0005435319533	5336	Comfort	24400.00
0005433719101	5336	Comfort	24400.00
0005435613855	5336	Comfort	24400.00
0005435613913	5336	Comfort	24400.00
0005435613867	5336	Comfort	24400.00
0005435613895	5336	Comfort	24400.00
0005435424484	5336	Comfort	24400.00
0005435424453	5336	Comfort	24400.00
0005435613929	5336	Comfort	24400.00
0005435613898	5336	Comfort	24400.00
0005432133249	5336	Comfort	24400.00
0005435424265	5336	Comfort	24400.00
0005434244729	5336	Comfort	24400.00
0005435613897	5336	Comfort	24400.00
0005435613944	5336	Comfort	24400.00
0005435613943	5336	Comfort	24400.00
0005434244794	5336	Comfort	24400.00
0005435613905	5336	Comfort	24400.00
0005435613869	5336	Comfort	24400.00
0005432133240	5336	Comfort	24400.00
0005435424304	5336	Comfort	24400.00
0005435424374	5336	Economy	14400.00
0005435613954	5336	Comfort	24400.00
0005435613878	5336	Economy	14400.00
0005435613822	5336	Economy	14400.00
0005435613851	5336	Economy	14400.00
0005434573376	5336	Economy	14400.00
0005433719121	5336	Economy	14400.00
0005434244927	5336	Economy	14400.00
0005435613911	5336	Economy	14400.00
0005435613839	5336	Economy	14400.00
0005434344288	5336	Economy	14400.00
0005435613894	5336	Economy	14400.00
0005435097215	5336	Economy	14400.00
0005435613921	5336	Economy	14400.00
0005435613932	5336	Economy	14400.00
0005435424216	5336	Economy	14400.00
0005435613922	5336	Economy	14400.00
0005435613860	5336	Economy	14400.00
0005432047559	5336	Economy	14400.00
0005435424380	5336	Economy	14400.00
0005435319546	5336	Economy	14400.00
0005435319532	5336	Economy	14400.00
0005435613901	5336	Economy	14400.00
0005435613950	5336	Economy	14400.00
0005435424366	5336	Economy	14400.00
0005435424255	5336	Economy	14400.00
0005435613926	5336	Economy	14400.00
0005434344299	5336	Economy	14400.00
0005435613848	5336	Economy	14400.00
0005435424376	5336	Economy	14400.00
0005435613836	5336	Economy	14400.00
0005435319534	5336	Economy	14400.00
0005435424495	5336	Economy	14400.00
0005434573377	5336	Economy	14400.00
0005434344307	5336	Economy	14400.00
0005435613874	5336	Economy	14400.00
0005435613884	5336	Economy	14400.00
0005432133241	5336	Economy	14400.00
0005435424210	5336	Economy	14400.00
0005435319565	5336	Economy	14400.00
0005435424571	5336	Economy	14400.00
0005435613948	5336	Economy	14400.00
0005435042832	5336	Economy	14400.00
0005435319518	5336	Economy	14400.00
0005435613902	5336	Economy	14400.00
0005435423963	5336	Economy	14400.00
0005435613949	5336	Economy	14400.00
0005435555372	5336	Economy	14400.00
0005434244685	5336	Economy	14400.00
0005434344322	5336	Economy	14400.00
0005435613906	5336	Economy	14400.00
0005432133237	5336	Economy	14400.00
0005435424347	5336	Economy	14400.00
0005435613838	5336	Economy	14400.00
0005435617171	5336	Economy	14400.00
0005435613864	5336	Economy	14400.00
0005434344301	5336	Economy	14400.00
0005435424241	5336	Economy	14400.00
0005435613947	5336	Economy	14400.00
0005435424616	5336	Economy	14400.00
0005435613889	5336	Economy	14400.00
0005435319564	5336	Economy	14400.00
0005435613863	5336	Economy	14400.00
0005435613907	5336	Economy	14400.00
0005435617234	5336	Economy	14400.00
0005434573379	5336	Economy	15800.00
0005434244745	5336	Economy	15800.00
0005434344302	5336	Economy	14400.00
0005434573381	5336	Economy	15800.00
0005435319553	5336	Economy	14400.00
0005435097222	5336	Economy	14400.00
0005435613891	5336	Economy	15800.00
0005435613952	5336	Economy	14400.00
0005435424313	5336	Economy	15800.00
0005434244825	5336	Economy	15800.00
0005435613834	5336	Economy	14400.00
0005435613862	5336	Economy	14400.00
0005434573389	5336	Economy	14400.00
0005435424572	5336	Economy	14400.00
0005434344320	5336	Economy	14400.00
0005435424353	5336	Economy	14400.00
0005435613925	5336	Economy	14400.00
0005435424305	5336	Economy	14400.00
0005435302126	5336	Economy	14400.00
0005435319535	5336	Economy	14400.00
0005435613840	5336	Economy	14400.00
0005435613883	5336	Economy	14400.00
0005435613868	5336	Economy	14400.00
0005434344300	5336	Economy	14400.00
0005435613885	5336	Economy	14400.00
0005432133235	5336	Economy	14400.00
0005434344291	5336	Economy	14400.00
0005435613866	5336	Economy	14400.00
0005435613908	5336	Economy	14400.00
0005432841002	5336	Economy	14400.00
0005435097221	5336	Economy	14400.00
0005435613881	5336	Economy	14400.00
0005435424256	5336	Economy	14400.00
0005435097214	5336	Economy	14400.00
0005435613953	5336	Economy	14400.00
0005435319523	5336	Economy	14400.00
0005435617235	5336	Economy	14400.00
0005435613915	5336	Economy	14400.00
0005435424697	5336	Economy	14400.00
0005435424526	5336	Economy	14400.00
0005432133236	5336	Economy	14400.00
0005435613876	5336	Economy	14400.00
0005432047557	5336	Economy	14400.00
0005435097216	5336	Economy	14400.00
0005435613899	5336	Economy	14400.00
0005434244840	5336	Economy	14400.00
0005435613850	5336	Economy	14400.00
0005435613888	5336	Economy	14400.00
0005435613946	5336	Economy	14400.00
0005435613912	5336	Economy	14400.00
0005435613857	5336	Economy	14400.00
0005435424308	5336	Economy	14400.00
0005435097218	5336	Economy	14400.00
0005434344323	5336	Economy	14400.00
0005435424681	5336	Economy	14400.00
0005435424378	5336	Economy	14400.00
0005435555373	5336	Economy	14400.00
0005432133246	5336	Economy	14400.00
0005435042831	5336	Economy	14400.00
0005434344305	5336	Economy	14400.00
0005435097223	5336	Economy	14400.00
0005435319517	5336	Economy	14400.00
0005435613854	5336	Economy	14400.00
0005435424500	5336	Economy	14400.00
0005434344310	5336	Economy	14400.00
0005435613827	5336	Economy	14400.00
0005435424170	5336	Economy	14400.00
0005435613829	5336	Economy	14400.00
0005434344324	5336	Economy	14400.00
0005435319502	5336	Economy	14400.00
0005435613826	5336	Economy	14400.00
0005435613856	5336	Economy	14400.00
0005435424489	5336	Economy	14400.00
0005435424721	5336	Economy	14400.00
0005432133247	5336	Economy	14400.00
0005434344315	5336	Economy	14400.00
0005435613909	5336	Economy	14400.00
0005435613828	5336	Economy	14400.00
0005435302127	5336	Economy	14400.00
0005435491443	5336	Economy	14400.00
0005434244926	5336	Economy	14400.00
0005435613927	5336	Economy	14400.00
0005434244746	5336	Economy	14400.00
0005435097220	5336	Economy	14400.00
0005435490234	5336	Economy	14400.00
0005435613896	5336	Economy	14400.00
0005435613890	5336	Economy	14400.00
0005435424373	5336	Economy	14400.00
0005434344304	5336	Economy	14400.00
0005435613877	5336	Economy	14400.00
0005435613853	5336	Economy	14400.00
0005434244910	5336	Economy	14400.00
0005434344287	5336	Economy	14400.00
0005434244754	5336	Economy	14400.00
0005434344309	5336	Economy	14400.00
0005434573378	5336	Economy	14400.00
0005435613916	5336	Economy	14400.00
0005432047558	5336	Economy	14400.00
0005434573387	5336	Economy	14400.00
0005435302157	5336	Economy	14400.00
0005435613945	5336	Economy	14400.00
0005435613846	5336	Economy	14400.00
0005432133238	5336	Economy	14400.00
0005435424687	5336	Economy	14400.00
0005434344292	5336	Economy	14400.00
0005434244874	5336	Economy	14400.00
0005435424615	5336	Economy	15800.00
0005435613832	5336	Economy	15800.00
0005434344321	5336	Economy	15800.00
0005434244715	5336	Economy	15800.00
0005435490236	5336	Economy	15800.00
0005435613892	5336	Economy	15800.00
0005435613900	5336	Economy	14400.00
0005435613830	5336	Economy	14400.00
0005434344290	5336	Economy	14400.00
0005435613951	5336	Economy	14400.00
0005434573385	5336	Economy	14400.00
0005435424215	5336	Economy	14400.00
0005434344311	5336	Economy	14400.00
0005435613858	5336	Economy	14400.00
0005434573384	5336	Economy	14400.00
0005435613879	5336	Economy	14400.00
0005435319522	5336	Economy	14400.00
0005435613824	5336	Economy	14400.00
0005434244728	5336	Economy	14400.00
0005435613919	5336	Economy	14400.00
0005433719113	5336	Economy	14400.00
0005435613893	5336	Economy	14400.00
0005435613924	5336	Economy	14400.00
0005435613939	5336	Economy	14400.00
0005435097224	5336	Economy	14400.00
0005435424367	5336	Economy	14400.00
0005435613930	5336	Economy	14400.00
0005435613933	5336	Economy	14400.00
0005435302169	5336	Economy	14400.00
0005435319516	5336	Economy	14400.00
0005435613835	5336	Economy	14400.00
0005435613923	5336	Economy	14400.00
0005435424365	5336	Economy	14400.00
0005435424494	5336	Economy	14400.00
0005435613845	5336	Economy	14400.00
0005434244873	5336	Economy	14400.00
0005432133239	5336	Economy	14400.00
0005434344317	5336	Economy	14400.00
0005435613887	5336	Economy	14400.00
0005435613942	5336	Economy	14400.00
0005434244698	5336	Economy	14400.00
0005435424589	5336	Economy	14400.00
0005434244802	5336	Economy	14400.00
0005435424628	5336	Economy	14400.00
0005434344295	5336	Economy	14400.00
0005435424623	5336	Economy	14400.00
0005433719120	5336	Economy	14400.00
0005432133248	5336	Economy	14400.00
0005435613941	5336	Economy	14400.00
0005435613920	5336	Economy	14400.00
0005435613882	5336	Economy	14400.00
0005435613837	5336	Economy	14400.00
0005435613917	5336	Economy	14400.00
0005434344306	5336	Economy	14400.00
0005435613875	5336	Economy	14400.00
0005435613934	5336	Economy	14400.00
0005435424490	5336	Economy	14400.00
0005434573388	5336	Economy	14400.00
0005435613886	5336	Economy	14400.00
0005435613847	5336	Economy	14400.00
0005434344314	5336	Economy	14400.00
0005434344319	5336	Economy	14400.00
0005434344293	5336	Economy	14400.00
0005434244841	5336	Economy	14400.00
0005435319555	5336	Economy	14400.00
0005435617172	5336	Economy	14400.00
0005434344297	5336	Economy	14400.00
0005435613833	5336	Economy	14400.00
0005435424461	5336	Economy	14400.00
0005435613852	5336	Economy	14400.00
0005434573382	5336	Economy	14400.00
0005435319554	5336	Economy	14400.00
0005435424368	5336	Economy	14400.00
0005435613938	5336	Economy	14400.00
0005432133243	5336	Economy	14400.00
0005434344298	5336	Economy	14400.00
0005435613844	5336	Economy	14400.00
0005435613940	5336	Economy	14400.00
0005435424172	5336	Economy	14400.00
0005435424462	5336	Economy	14400.00
0005435613955	5336	Economy	14400.00
0005435613865	5336	Economy	14400.00
0005435613842	5336	Economy	14400.00
0005434244734	5336	Economy	14400.00
0005433719102	5336	Economy	14400.00
0005435424488	5336	Economy	14400.00
0005435613841	5336	Economy	14400.00
0005435424570	5336	Economy	14400.00
0005435613843	5336	Economy	14400.00
0005435613861	5336	Economy	14400.00
0005435097217	5336	Economy	14400.00
0005435613910	5336	Economy	14400.00
0005434344303	5336	Economy	14400.00
0005432047556	5336	Economy	14400.00
0005435613937	5336	Economy	14400.00
0005435613820	5336	Economy	14400.00
0005435319521	5336	Economy	14400.00
0005434244843	5336	Economy	14400.00
0005434344296	5336	Economy	14400.00
0005434573386	5336	Economy	14400.00
0005432133244	5336	Economy	14400.00
0005435613831	5336	Economy	14400.00
0005435613928	5336	Economy	14400.00
0005435424242	5336	Economy	14400.00
0005434343898	10886	Business	43100.00
0005435612877	10886	Business	43100.00
0005434343945	10886	Business	43100.00
0005435424979	10886	Business	43100.00
0005435613184	10886	Business	43100.00
0005435613017	10886	Business	43100.00
0005434245032	10886	Business	43100.00
0005435424960	10886	Business	43100.00
0005435612908	10886	Business	43100.00
0005435612696	10886	Business	43100.00
0005435424937	10886	Business	43100.00
0005435613319	10886	Business	43100.00
0005434343991	10886	Business	43100.00
0005435612600	10886	Business	43100.00
0005435612657	10886	Business	43100.00
0005435424922	10886	Business	43100.00
0005434245053	10886	Business	43100.00
0005435319587	10886	Business	43100.00
0005432165054	10886	Business	43100.00
0005435424943	10886	Business	43100.00
0005435612273	10886	Business	43100.00
0005435424982	10886	Business	43100.00
0005435097138	10886	Business	43100.00
0005435613296	10886	Business	43100.00
0005435612820	10886	Business	43100.00
0005434344045	10886	Business	43100.00
0005434245040	10886	Business	43100.00
0005434245031	10886	Comfort	24400.00
0005435424917	10886	Comfort	24400.00
0005434344050	10886	Comfort	24400.00
0005434343780	10886	Comfort	24400.00
0005435613050	10886	Comfort	24400.00
0005435612692	10886	Comfort	24400.00
0005435424921	10886	Comfort	24400.00
0005435613141	10886	Comfort	24400.00
0005435612951	10886	Comfort	24400.00
0005435612753	10886	Comfort	24400.00
0005435612853	10886	Comfort	24400.00
0005434343942	10886	Comfort	24400.00
0005435380302	10886	Comfort	24400.00
0005435424961	10886	Comfort	24400.00
0005432165052	10886	Comfort	24400.00
0005435097117	10886	Comfort	24400.00
0005434573229	10886	Comfort	24400.00
0005435424977	10886	Comfort	24400.00
0005435424981	10886	Comfort	24400.00
0005433719149	10886	Comfort	24400.00
0005435424928	10886	Comfort	24400.00
0005435613338	10886	Comfort	24400.00
0005435424954	10886	Comfort	24400.00
0005434245044	10886	Comfort	24400.00
0005434343992	10886	Comfort	24400.00
0005435424941	10886	Comfort	24400.00
0005435424959	10886	Comfort	24400.00
0005434573241	10886	Comfort	24400.00
0005435613150	10886	Comfort	24400.00
0005434343876	10886	Comfort	24400.00
0005435380299	10886	Comfort	24400.00
0005435042858	10886	Comfort	24400.00
0005435424971	10886	Comfort	24400.00
0005435424942	10886	Comfort	24400.00
0005435319593	10886	Comfort	24400.00
0005434343955	10886	Economy	14400.00
0005435304167	10886	Economy	14400.00
0005435424934	10886	Economy	14400.00
0005435613018	10886	Economy	14400.00
0005434343911	10886	Economy	14400.00
0005432165051	10886	Economy	14400.00
0005432363424	10886	Economy	14400.00
0005435319588	10886	Economy	14400.00
0005435612913	10886	Economy	14400.00
0005434245028	10886	Economy	14400.00
0005435613183	10886	Economy	14400.00
0005435612914	10886	Economy	14400.00
0005435613276	10886	Economy	14400.00
0005435424953	10886	Economy	14400.00
0005435612915	10886	Economy	14400.00
0005434245033	10886	Economy	14400.00
0005435424974	10886	Economy	14400.00
0005434343829	10886	Economy	14400.00
0005435424924	10886	Economy	14400.00
0005434343890	10886	Economy	14400.00
0005434343941	10886	Economy	14400.00
0005435490205	10886	Economy	14400.00
0005435613126	10886	Economy	14400.00
0005434245043	10886	Economy	14400.00
0005435612715	10886	Economy	14400.00
0005435424967	10886	Economy	14400.00
0005434343996	10886	Economy	14400.00
0005434343737	10886	Economy	14400.00
0005432166910	10886	Economy	14400.00
0005435613295	10886	Economy	14400.00
0005435613233	10886	Economy	14400.00
0005435424976	10886	Economy	14400.00
0005435097139	10886	Economy	14400.00
0005435424932	10886	Economy	14400.00
0005435612975	10886	Economy	14400.00
0005434245026	10886	Economy	14400.00
0005435424929	10886	Economy	14400.00
0005435424964	10886	Economy	14400.00
0005435613027	10886	Economy	14400.00
0005434344003	10886	Economy	14400.00
0005435612267	10886	Economy	14400.00
0005435424983	10886	Economy	14400.00
0005434245050	10886	Economy	14400.00
0005434656560	10886	Economy	14400.00
0005434245045	10886	Economy	14400.00
0005435612545	10886	Economy	14400.00
0005435319591	10886	Economy	14400.00
0005435613072	10886	Economy	14400.00
0005435424958	10886	Economy	14400.00
0005435424939	10886	Economy	14400.00
0005434245052	10886	Economy	14400.00
0005435490208	10886	Economy	15800.00
0005435424980	10886	Economy	15800.00
0005435613052	10886	Economy	14400.00
0005435319589	10886	Economy	14400.00
0005435613001	10886	Economy	14400.00
0005434245041	10886	Economy	15800.00
0005435612738	10886	Economy	15800.00
0005435424944	10886	Economy	14400.00
0005435613320	10886	Economy	14400.00
0005434344031	10886	Economy	14400.00
0005435613112	10886	Economy	14400.00
0005435424933	10886	Economy	14400.00
0005435424962	10886	Economy	14400.00
0005435424952	10886	Economy	14400.00
0005435424923	10886	Economy	14400.00
0005434343958	10886	Economy	14400.00
0005434343884	10886	Economy	14400.00
0005435097127	10886	Economy	14400.00
0005435424931	10886	Economy	14400.00
0005434343993	10886	Economy	14400.00
0005435424925	10886	Economy	14400.00
0005435424936	10886	Economy	14400.00
0005435613306	10886	Economy	14400.00
0005434245054	10886	Economy	14400.00
0005435612928	10886	Economy	14400.00
0005432841017	10886	Economy	14400.00
0005435612748	10886	Economy	14400.00
0005435612845	10886	Economy	14400.00
0005434245027	10886	Economy	14400.00
0005435613080	10886	Economy	14400.00
0005435424919	10886	Economy	14400.00
0005434344002	10886	Economy	14400.00
0005434343830	10886	Economy	14400.00
0005432165057	10886	Economy	14400.00
0005435490221	10886	Economy	14400.00
0005435097088	10886	Economy	14400.00
0005435097132	10886	Economy	14400.00
0005435304164	10886	Economy	14400.00
0005435424948	10886	Economy	14400.00
0005435424969	10886	Economy	14400.00
0005435380304	10886	Economy	14400.00
0005434245034	10886	Economy	14400.00
0005435612695	10886	Economy	14400.00
0005434344127	10886	Economy	14400.00
0005435424945	10886	Economy	14400.00
0005434245051	10886	Economy	14400.00
0005434245037	10886	Economy	14400.00
0005435424920	10886	Economy	14400.00
0005434344077	10886	Economy	14400.00
0005435424973	10886	Economy	14400.00
0005432166909	10886	Economy	14400.00
0005435424940	10886	Economy	14400.00
0005432165050	10886	Economy	14400.00
0005434245042	10886	Economy	14400.00
0005435424950	10886	Economy	14400.00
0005434245048	10886	Economy	14400.00
0005432165053	10886	Economy	14400.00
0005433719148	10886	Economy	14400.00
0005435319590	10886	Economy	14400.00
0005435490204	10886	Economy	14400.00
0005435612909	10886	Economy	14400.00
0005435613095	10886	Economy	14400.00
0005435612683	10886	Economy	14400.00
0005432166907	10886	Economy	14400.00
0005435380303	10886	Economy	14400.00
0005435424918	10886	Economy	14400.00
0005435424956	10886	Economy	14400.00
0005435424972	10886	Economy	14400.00
0005434344021	10886	Economy	14400.00
0005434343956	10886	Economy	14400.00
0005435613038	10886	Economy	14400.00
0005434573312	10886	Economy	14400.00
0005434245036	10886	Economy	14400.00
0005434343856	10886	Economy	14400.00
0005434245049	10886	Economy	14400.00
0005435424927	10886	Economy	14400.00
0005432165056	10886	Economy	14400.00
0005434245056	10886	Economy	14400.00
0005435319586	10886	Economy	14400.00
0005434343886	10886	Economy	14400.00
0005434656561	10886	Economy	14400.00
0005435613258	10886	Economy	14400.00
0005435612568	10886	Economy	14400.00
0005435380301	10886	Economy	14400.00
0005432363425	10886	Economy	14400.00
0005434245046	10886	Economy	14400.00
0005435613224	10886	Economy	14400.00
0005435613110	10886	Economy	14400.00
0005435319592	10886	Economy	14400.00
0005434344049	10886	Economy	15800.00
0005434245038	10886	Economy	15800.00
0005435613548	10886	Economy	15800.00
0005434245030	10886	Economy	15800.00
0005435613046	10886	Economy	15800.00
0005435612872	10886	Economy	14400.00
0005435424978	10886	Economy	14400.00
0005434245029	10886	Economy	14400.00
0005432166906	10886	Economy	14400.00
0005435097125	10886	Economy	14400.00
0005435613142	10886	Economy	14400.00
0005434343891	10886	Economy	14400.00
0005434343700	10886	Economy	14400.00
0005435424947	10886	Economy	14400.00
0005435612903	10886	Economy	14400.00
0005435424966	10886	Economy	14400.00
0005435613222	10886	Economy	14400.00
0005434573224	10886	Economy	14400.00
0005435424949	10886	Economy	14400.00
0005434573220	10886	Economy	14400.00
0005434344078	10886	Economy	14400.00
0005435612873	10886	Economy	14400.00
0005435612974	10886	Economy	14400.00
0005433719147	10886	Economy	14400.00
0005435097126	10886	Economy	14400.00
0005435612546	10886	Economy	14400.00
0005435304166	10886	Economy	14400.00
0005434343925	10886	Economy	14400.00
0005435613000	10886	Economy	14400.00
0005432841018	10886	Economy	14400.00
0005435097140	10886	Economy	14400.00
0005434573264	10886	Economy	14400.00
0005434343949	10886	Economy	14400.00
0005434245055	10886	Economy	14400.00
0005434344061	10886	Economy	14400.00
0005435613191	10886	Economy	14400.00
0005435612665	10886	Economy	14400.00
0005435424926	10886	Economy	14400.00
0005435097118	10886	Economy	14400.00
0005434343905	10886	Economy	14400.00
0005435612714	10886	Economy	14400.00
0005435424963	10886	Economy	14400.00
0005435613339	10886	Economy	14400.00
0005432363423	10886	Economy	14400.00
0005435612818	10886	Economy	14400.00
0005434245047	10886	Economy	14400.00
0005435424955	10886	Economy	14400.00
0005435612993	10886	Economy	14400.00
0005435319595	10886	Economy	14400.00
0005435612996	10886	Economy	14400.00
0005435612846	10886	Economy	14400.00
0005435613221	10886	Economy	14400.00
0005435612739	10886	Economy	14400.00
0005435612943	10886	Economy	14400.00
0005432165055	10886	Economy	14400.00
0005435424946	10886	Economy	14400.00
0005434245035	10886	Economy	14400.00
0005435613026	10886	Economy	14400.00
0005435613243	10886	Economy	14400.00
0005435319594	10886	Economy	14400.00
0005435424951	10886	Economy	14400.00
0005435612664	10886	Economy	14400.00
0005435424968	10886	Economy	14400.00
0005435424984	10886	Economy	14400.00
0005435613037	10886	Economy	14400.00
0005434343707	10886	Economy	14400.00
0005435613064	10886	Economy	14400.00
0005435612749	10886	Economy	14400.00
0005434344097	10886	Economy	14400.00
0005434343825	10886	Economy	14400.00
0005435612851	10886	Economy	14400.00
0005434343960	10886	Economy	14400.00
0005434343885	10886	Economy	14400.00
0005435424957	10886	Economy	14400.00
0005434343959	10886	Economy	14400.00
0005435612920	10886	Economy	14400.00
0005435424938	10886	Economy	14400.00
0005434245039	10886	Economy	14400.00
0005435304165	10886	Economy	14400.00
0005435613094	10886	Economy	14400.00
0005435424975	10886	Economy	14400.00
0005435612852	10886	Economy	14400.00
0005435424970	10886	Economy	14400.00
0005435612292	10886	Economy	14400.00
0005432166908	10886	Economy	14400.00
0005434573297	10886	Economy	14400.00
0005435424930	10886	Economy	14400.00
0005435613252	10886	Economy	14400.00
0005435612272	10886	Economy	14400.00
0005435613307	10886	Economy	14400.00
0005435424935	10886	Economy	14400.00
0005435612415	10886	Economy	14400.00
0005435613045	10886	Economy	14400.00
0005435612693	10886	Economy	14400.00
0005435424965	10886	Economy	14400.00
0005435380300	10886	Economy	14400.00
0005434573158	10886	Economy	14400.00
0005434343850	10886	Economy	14400.00
0005433805451	3297	Business	18800.00
0005432459480	3297	Business	18800.00
0005432459572	3297	Business	18800.00
0005432181764	3297	Business	18800.00
0005432459287	3297	Business	18800.00
0005432459348	3297	Business	18800.00
0005432181759	3297	Business	18800.00
0005432181767	3297	Business	18800.00
0005433805440	3297	Business	18800.00
0005433805459	3297	Business	18800.00
0005433633882	3297	Business	18800.00
0005432459378	3297	Business	18800.00
0005432459752	3297	Business	18800.00
0005433633902	3297	Business	18800.00
0005433507217	3297	Business	18800.00
0005432459655	3297	Business	18800.00
0005433507228	3297	Business	18800.00
0005432459428	3297	Business	18800.00
0005434143726	3297	Business	18800.00
0005432181768	3297	Business	18800.00
0005433507213	3297	Business	18800.00
0005433805464	3297	Business	18800.00
0005433633884	3297	Business	18800.00
0005433633904	3297	Business	18800.00
0005432181761	3297	Business	18800.00
0005432181752	3297	Business	18800.00
0005432459407	3297	Business	18800.00
0005432181765	3297	Business	18800.00
0005433805462	3297	Economy	6900.00
0005432459449	3297	Economy	6900.00
0005433507232	3297	Economy	6900.00
0005432459441	3297	Economy	6900.00
0005432181757	3297	Economy	6900.00
0005433507225	3297	Economy	6900.00
0005432459401	3297	Economy	6300.00
0005433633900	3297	Economy	6300.00
0005433805441	3297	Economy	6300.00
0005432459668	3297	Economy	6300.00
0005433633908	3297	Economy	6300.00
0005432181754	3297	Economy	6300.00
0005432459333	3297	Economy	6300.00
0005433507223	3297	Economy	6300.00
0005433633893	3297	Economy	6300.00
0005433805436	3297	Economy	6300.00
0005433633885	3297	Economy	6300.00
0005433633910	3297	Economy	6300.00
0005432459578	3297	Economy	6300.00
0005433633888	3297	Economy	6300.00
0005432459392	3297	Economy	6300.00
0005433805463	3297	Economy	6300.00
0005432181760	3297	Economy	6300.00
0005433805449	3297	Economy	6300.00
0005433507216	3297	Economy	6300.00
0005433507221	3297	Economy	6300.00
0005433633878	3297	Economy	6300.00
0005433633894	3297	Economy	6300.00
0005432459579	3297	Economy	6300.00
0005433805475	3297	Economy	6300.00
0005433805444	3297	Economy	6300.00
0005433633899	3297	Economy	6300.00
0005434143727	3297	Economy	6300.00
0005433805442	3297	Economy	6300.00
0005433633877	3297	Economy	6300.00
0005433805476	3297	Economy	6300.00
0005433805443	3297	Economy	6300.00
0005433805471	3297	Economy	6300.00
0005433805469	3297	Economy	6300.00
0005432459654	3297	Economy	6300.00
0005433805473	3297	Economy	6300.00
0005433633889	3297	Economy	6300.00
0005433633890	3297	Economy	6300.00
0005433633892	3297	Economy	6300.00
0005433507222	3297	Economy	6300.00
0005433805467	3297	Economy	6300.00
0005433805438	3297	Economy	6300.00
0005433805470	3297	Economy	6300.00
0005432459391	3297	Economy	6300.00
0005433507230	3297	Economy	6300.00
0005434143730	3297	Economy	6300.00
0005433507227	3297	Economy	6300.00
0005432459490	3297	Economy	6300.00
0005433507226	3297	Economy	6300.00
0005432181772	3297	Economy	6300.00
0005432181774	3297	Economy	6300.00
0005433507219	3297	Economy	6300.00
0005433507215	3297	Economy	6300.00
0005433633906	3297	Economy	6300.00
0005433805461	3297	Economy	6300.00
0005433507229	3297	Economy	6300.00
0005433805474	3297	Economy	6300.00
0005433805453	3297	Economy	6300.00
0005432459608	3297	Economy	6300.00
0005433507212	3297	Economy	6300.00
0005432459334	3297	Economy	6300.00
0005432181755	3297	Economy	6900.00
0005432459527	3297	Economy	6900.00
0005433633880	3297	Economy	6900.00
0005433805445	3297	Economy	6900.00
0005433633903	3297	Economy	6900.00
0005432459471	3297	Economy	6300.00
0005432459514	3297	Economy	6300.00
0005432459669	3297	Economy	6300.00
0005432459504	3297	Economy	6300.00
0005432181758	3297	Economy	6900.00
0005433633905	3297	Economy	6300.00
0005432459363	3297	Economy	6300.00
0005433805450	3297	Economy	6300.00
0005433633886	3297	Economy	6300.00
0005432181756	3297	Economy	6300.00
0005432181766	3297	Economy	6300.00
0005433805457	3297	Economy	6300.00
0005432181762	3297	Economy	6300.00
0005432181770	3297	Economy	6300.00
0005433805472	3297	Economy	6300.00
0005433507233	3297	Economy	6300.00
0005432459437	3297	Economy	6300.00
0005432459184	3297	Economy	6300.00
0005433633879	3297	Economy	6300.00
0005433507214	3297	Economy	6300.00
0005432181771	3297	Economy	6300.00
0005433633887	3297	Economy	6300.00
0005433805446	3297	Economy	6300.00
0005432181769	3297	Economy	6300.00
0005433805447	3297	Economy	6300.00
0005434143725	3297	Economy	6300.00
0005433805458	3297	Economy	6300.00
0005432459269	3297	Economy	6300.00
0005433805466	3297	Economy	6300.00
0005433507231	3297	Economy	6300.00
0005433633897	3297	Economy	6300.00
0005433805437	3297	Economy	6300.00
0005432459609	3297	Economy	6300.00
0005434143729	3297	Economy	6300.00
0005433805456	3297	Economy	6300.00
0005432181763	3297	Economy	6300.00
0005432459438	3297	Economy	6300.00
0005432459619	3297	Economy	6300.00
0005433633891	3297	Economy	6300.00
0005433507218	3297	Economy	6300.00
0005432459618	3297	Economy	6300.00
0005432459545	3297	Economy	6300.00
0005432459523	3297	Economy	6300.00
0005433633907	3297	Economy	6300.00
0005432459677	3297	Economy	6300.00
0005433633883	3297	Economy	6300.00
0005433633896	3297	Economy	6300.00
0005433507220	3297	Economy	6300.00
0005432459288	3297	Economy	6300.00
0005433805448	3297	Economy	6300.00
0005432459515	3297	Economy	6300.00
0005433633901	3297	Economy	6300.00
0005433805460	3297	Economy	6300.00
0005433805455	3297	Economy	6300.00
0005433805452	3297	Economy	6300.00
0005433507224	3297	Economy	6300.00
0005433805454	3297	Economy	6300.00
0005433805465	3297	Economy	6300.00
0005432459676	3297	Economy	6300.00
0005433633895	3297	Economy	6300.00
0005433805439	3297	Economy	6300.00
0005433633898	3297	Economy	6300.00
0005433633881	3297	Economy	6300.00
0005433633909	3297	Economy	6300.00
0005433805468	3297	Economy	6300.00
0005432181753	3297	Economy	6300.00
0005434143728	3297	Economy	6300.00
0005432459402	3297	Economy	6300.00
0005432459571	3297	Economy	6300.00
0005432181773	3297	Economy	6300.00
0005432459450	3297	Economy	6300.00
0005435884929	3296	Business	18800.00
0005435885090	3296	Business	18800.00
0005435884633	3296	Business	18800.00
0005435885082	3296	Business	18800.00
0005435885123	3296	Business	18800.00
0005435884978	3296	Business	18800.00
0005435884981	3296	Economy	6900.00
0005435884874	3296	Economy	6900.00
0005435884872	3296	Economy	6300.00
0005435884805	3296	Economy	6300.00
0005435884632	3296	Economy	6300.00
0005435885010	3296	Economy	6300.00
0005435884742	3296	Economy	6300.00
0005435884961	3296	Economy	6300.00
0005435884895	3296	Economy	6300.00
0005435885054	3296	Economy	6300.00
0005435884804	3296	Economy	6300.00
0005435885038	3296	Economy	6300.00
0005435885083	3296	Economy	6300.00
0005435885008	3296	Economy	6300.00
0005435884963	3296	Economy	6300.00
0005435884983	3296	Economy	6900.00
0005435884926	3296	Economy	6300.00
0005435885183	3296	Economy	6300.00
0005435884871	3296	Economy	6300.00
0005435884810	3296	Economy	6300.00
0005435885089	3296	Economy	6300.00
0005435884966	3296	Economy	6300.00
0005435884971	3296	Economy	6300.00
0005435884570	3296	Economy	6300.00
0005435885006	3296	Economy	6300.00
0005435885009	3296	Economy	6300.00
0005435884970	3296	Economy	6300.00
0005435884917	3296	Economy	6300.00
0005435884960	3296	Economy	6300.00
0005435884965	3296	Economy	6300.00
0005435884852	3296	Economy	6300.00
0005435885148	3296	Economy	6300.00
0005435885135	3296	Economy	6300.00
0005435884792	3296	Economy	6300.00
0005435884912	3296	Economy	6300.00
0005435885039	3296	Economy	6300.00
0005435885147	3296	Economy	6300.00
0005435884791	3296	Economy	6300.00
0005435884919	3296	Economy	6300.00
0005433507078	8173	Business	18800.00
0005432042748	8173	Business	18800.00
0005432460009	8173	Business	18800.00
0005433506988	8173	Business	18800.00
0005432459999	8173	Business	18800.00
0005435885323	8173	Business	18800.00
0005433507023	8173	Business	18800.00
0005433507110	8173	Business	18800.00
0005432459983	8173	Business	18800.00
0005432459981	8173	Business	18800.00
0005432459997	8173	Business	18800.00
0005435885353	8173	Business	18800.00
0005432459995	8173	Business	18800.00
0005432460000	8173	Business	18800.00
0005435885340	8173	Business	18800.00
0005435885341	8173	Business	18800.00
0005433507122	8173	Business	18800.00
0005433507087	8173	Business	18800.00
0005435885349	8173	Business	18800.00
0005433507083	8173	Business	18800.00
0005435885325	8173	Business	18800.00
0005432460006	8173	Business	18800.00
0005435885345	8173	Business	18800.00
0005435885363	8173	Economy	6900.00
0005433507031	8173	Business	18800.00
0005432459990	8173	Economy	6900.00
0005432042741	8173	Economy	6900.00
0005432460003	8173	Economy	6900.00
0005432459980	8173	Economy	6900.00
0005435885368	8173	Economy	6900.00
0005435885343	8173	Economy	6300.00
0005432459994	8173	Economy	6300.00
0005432459976	8173	Economy	6300.00
0005432459991	8173	Economy	6300.00
0005432460010	8173	Economy	6300.00
0005433507051	8173	Economy	6300.00
0005435885356	8173	Economy	6300.00
0005435885344	8173	Economy	6300.00
0005432459986	8173	Economy	6300.00
0005435885330	8173	Economy	6300.00
0005435885338	8173	Economy	6300.00
0005433507082	8173	Economy	6300.00
0005432459978	8173	Economy	6300.00
0005434312326	8173	Economy	6300.00
0005435885322	8173	Economy	6300.00
0005433507084	8173	Economy	6300.00
0005433507034	8173	Economy	6300.00
0005434312325	8173	Economy	6300.00
0005435885348	8173	Economy	6300.00
0005432459973	8173	Economy	6300.00
0005433507109	8173	Economy	6300.00
0005432459996	8173	Economy	6300.00
0005435885324	8173	Economy	6300.00
0005432460011	8173	Economy	6300.00
0005432460023	8173	Economy	6300.00
0005432042743	8173	Economy	6300.00
0005432460021	8173	Economy	6300.00
0005432460016	8173	Economy	6300.00
0005435885346	8173	Economy	6300.00
0005435885351	8173	Economy	6300.00
0005432459987	8173	Economy	6300.00
0005433507062	8173	Economy	6300.00
0005435885327	8173	Economy	6300.00
0005432042752	8173	Economy	6300.00
0005432459988	8173	Economy	6300.00
0005432042751	8173	Economy	6300.00
0005432460004	8173	Economy	6300.00
0005435885342	8173	Economy	6300.00
0005435885326	8173	Economy	6300.00
0005432042742	8173	Economy	6300.00
0005433507052	8173	Economy	6300.00
0005435885366	8173	Economy	6300.00
0005435885357	8173	Economy	6300.00
0005432459992	8173	Economy	6300.00
0005433507057	8173	Economy	6300.00
0005432460015	8173	Economy	6300.00
0005435885355	8173	Economy	6300.00
0005435885337	8173	Economy	6300.00
0005432460020	8173	Economy	6300.00
0005433507148	8173	Economy	6300.00
0005435885359	8173	Economy	6300.00
0005435885361	8173	Economy	6300.00
0005432042739	8173	Economy	6300.00
0005435885347	8173	Economy	6300.00
0005432460008	8173	Economy	6300.00
0005432460012	8173	Economy	6900.00
0005435885362	8173	Economy	6900.00
0005433507066	8173	Economy	6900.00
0005432042745	8173	Economy	6300.00
0005435885365	8173	Economy	6300.00
0005435885328	8173	Economy	6300.00
0005432459982	8173	Economy	6900.00
0005435885329	8173	Economy	6300.00
0005432042749	8173	Economy	6300.00
0005435885335	8173	Economy	6300.00
0005433507111	8173	Economy	6300.00
0005432460019	8173	Economy	6300.00
0005432459984	8173	Economy	6300.00
0005435885358	8173	Economy	6300.00
0005432460024	8173	Economy	6300.00
0005435885364	8173	Economy	6300.00
0005432042750	8173	Economy	6300.00
0005432459998	8173	Economy	6300.00
0005435885339	8173	Economy	6300.00
0005432042747	8173	Economy	6300.00
0005432042746	8173	Economy	6300.00
0005435885350	8173	Economy	6300.00
0005432460014	8173	Economy	6300.00
0005432459989	8173	Economy	6300.00
0005433507013	8173	Economy	6300.00
0005432460022	8173	Economy	6300.00
0005432459993	8173	Economy	6300.00
0005433507089	8173	Economy	6300.00
0005432459977	8173	Economy	6300.00
0005435885354	8173	Economy	6300.00
0005435885334	8173	Economy	6300.00
0005435885367	8173	Economy	6300.00
0005435885352	8173	Economy	6300.00
0005433507077	8173	Economy	6300.00
0005432460001	8173	Economy	6300.00
0005432460002	8173	Economy	6300.00
0005435885369	8173	Economy	6300.00
0005435885332	8173	Economy	6300.00
0005432459979	8173	Economy	6300.00
0005432460018	8173	Economy	6300.00
0005432460007	8173	Economy	6300.00
0005432460013	8173	Economy	6300.00
0005432042740	8173	Economy	6300.00
0005435885333	8173	Economy	6300.00
0005432459972	8173	Economy	6300.00
0005433507030	8173	Economy	6300.00
0005433507065	8173	Economy	6300.00
0005432459985	8173	Economy	6300.00
0005432460005	8173	Economy	6300.00
0005432459975	8173	Economy	6300.00
0005432459974	8173	Economy	6300.00
0005435885336	8173	Economy	6300.00
0005435885321	8173	Economy	6300.00
0005432042744	8173	Economy	6300.00
0005432460017	8173	Economy	6300.00
0005435885331	8173	Economy	6300.00
0005435885360	8173	Economy	6300.00
0005434143718	8175	Business	18800.00
0005433805167	8175	Business	18800.00
0005433633604	8175	Business	18800.00
0005433633626	8175	Business	18800.00
0005433633627	8175	Business	18800.00
0005433633429	8175	Business	18800.00
0005433805207	8175	Business	18800.00
0005433805022	8175	Business	18800.00
0005433633488	8175	Business	18800.00
0005433805222	8175	Business	18800.00
0005433805324	8175	Economy	6900.00
0005433633524	8175	Economy	6900.00
0005433633454	8175	Economy	6900.00
0005433805141	8175	Economy	6900.00
0005433633583	8175	Economy	6300.00
0005433805162	8175	Economy	6300.00
0005433633648	8175	Economy	6300.00
0005433805173	8175	Economy	6300.00
0005433805206	8175	Economy	6300.00
0005433633382	8175	Economy	6300.00
0005433633489	8175	Economy	6300.00
0005433805154	8175	Economy	6300.00
0005433633564	8175	Economy	6300.00
0005433805089	8175	Economy	6300.00
0005433633607	8175	Economy	6300.00
0005433805061	8175	Economy	6300.00
0005433805039	8175	Economy	6300.00
0005433633571	8175	Economy	6300.00
0005433633453	8175	Economy	6300.00
0005433633566	8175	Economy	6300.00
0005433805194	8175	Economy	6300.00
0005433633499	8175	Economy	6300.00
0005433633625	8175	Economy	6300.00
0005433805163	8175	Economy	6900.00
0005433805245	8175	Economy	6900.00
0005433633438	8175	Economy	6300.00
0005433633487	8175	Economy	6300.00
0005434271299	8175	Economy	6300.00
0005433805244	8175	Economy	6300.00
0005433805155	8175	Economy	6300.00
0005433633565	8175	Economy	6300.00
0005433633495	8175	Economy	6300.00
0005433633506	8175	Economy	6300.00
0005433805062	8175	Economy	6300.00
0005433805142	8175	Economy	6300.00
0005433805164	8175	Economy	6300.00
0005433633563	8175	Economy	6300.00
0005433633507	8175	Economy	6300.00
0005433805205	8175	Economy	6300.00
0005433805166	8175	Economy	6300.00
0005433805023	8175	Economy	6300.00
0005433805082	8175	Economy	6300.00
0005433633669	8175	Economy	6300.00
0005433633630	8175	Economy	6300.00
0005433633562	8175	Economy	6300.00
0005434271291	8175	Economy	6300.00
0005433633557	8175	Economy	6300.00
0005433633508	8175	Economy	6300.00
0005433805165	8175	Economy	6300.00
0005433805172	8175	Economy	6300.00
0005433805157	8175	Economy	6300.00
0005434271304	8175	Economy	6300.00
0005433805081	8175	Economy	6300.00
0005434271300	8175	Economy	6300.00
0005433805243	8175	Economy	6300.00
0005433633523	8175	Economy	6300.00
0005433805011	8175	Economy	6300.00
0005433633555	8175	Economy	6300.00
0005434183565	8180	Business	18800.00
0005434183556	8180	Economy	6300.00
0005434183564	8180	Economy	6300.00
0005432383242	4596	Business	9900.00
0005432383255	4596	Business	9900.00
0005432383270	4596	Business	9900.00
0005432727961	4596	Business	9900.00
0005432383268	4596	Business	9900.00
0005432383249	4596	Business	9900.00
0005433722235	4596	Business	9900.00
0005432383278	4596	Economy	3300.00
0005433722232	4596	Economy	3300.00
0005432383238	4596	Economy	3300.00
0005432383276	4596	Economy	3300.00
0005432727964	4596	Economy	3300.00
0005432383240	4596	Economy	3300.00
0005432383243	4596	Economy	3600.00
0005432727969	4596	Economy	3600.00
0005432727968	4596	Economy	3600.00
0005432383260	4596	Economy	3600.00
0005433722234	4596	Economy	3300.00
0005432727967	4596	Economy	3300.00
0005432383277	4596	Economy	3300.00
0005432383261	4596	Economy	3300.00
0005432727965	4596	Economy	3300.00
0005432383275	4596	Economy	3300.00
0005433722233	4596	Economy	3300.00
0005432727970	4596	Economy	3300.00
0005432383253	4596	Economy	3300.00
0005433453766	4596	Economy	3300.00
0005432383239	4596	Economy	3300.00
0005432383266	4596	Economy	3300.00
0005432383269	4596	Economy	3300.00
0005432727960	4596	Economy	3300.00
0005432383272	4596	Economy	3300.00
0005432383244	4596	Economy	3300.00
0005432383267	4596	Economy	3300.00
0005432383274	4596	Economy	3300.00
0005432383264	4596	Economy	3300.00
0005432383247	4596	Economy	3300.00
0005433454879	4596	Economy	3300.00
0005432383257	4596	Economy	3300.00
0005432383265	4596	Economy	3300.00
0005432383271	4596	Economy	3300.00
0005432383250	4596	Economy	3300.00
0005432727963	4596	Economy	3300.00
0005432383252	4596	Economy	3300.00
0005432383245	4596	Economy	3300.00
0005432383262	4596	Economy	3300.00
0005432383251	4596	Economy	3300.00
0005432383241	4596	Economy	3300.00
0005433722236	4596	Economy	3300.00
0005432727971	4596	Economy	3300.00
0005432727959	4596	Economy	3300.00
0005432383259	4596	Economy	3300.00
0005432383248	4596	Economy	3300.00
0005433453767	4596	Economy	3300.00
0005433454880	4596	Economy	3300.00
0005432383263	4596	Economy	3300.00
0005432727966	4596	Economy	3300.00
0005432383254	4596	Economy	3300.00
0005432727962	4596	Economy	3300.00
0005432383258	4596	Economy	3300.00
0005432383246	4596	Economy	3300.00
0005433453765	4596	Economy	3300.00
0005432383256	4596	Economy	3300.00
0005432383273	4596	Economy	3300.00
0005432382956	30133	Business	9900.00
0005432382882	30133	Business	9900.00
0005432382957	30133	Business	9900.00
0005432382769	30133	Business	9900.00
0005432382669	30133	Business	9900.00
0005432382762	30133	Business	9900.00
0005433722116	30133	Business	9900.00
0005432382743	30133	Business	9900.00
0005433722148	30133	Economy	3300.00
0005432382768	30133	Economy	3300.00
0005432382761	30133	Economy	3300.00
0005432727804	30133	Economy	3300.00
0005432382915	30133	Economy	3300.00
0005432382829	30133	Economy	3600.00
0005432727823	30133	Economy	3600.00
0005432382772	30133	Economy	3600.00
0005432382883	30133	Economy	3300.00
0005432382770	30133	Economy	3300.00
0005432382958	30133	Economy	3300.00
0005433722160	30133	Economy	3300.00
0005432382983	30133	Economy	3300.00
0005432382832	30133	Economy	3300.00
0005432382820	30133	Economy	3300.00
0005432727843	30133	Economy	3300.00
0005432382744	30133	Economy	3300.00
0005432382804	30133	Economy	3300.00
0005432382699	30133	Economy	3300.00
0005433194838	30133	Economy	3300.00
0005433722161	30133	Economy	3300.00
0005432382620	30133	Economy	3300.00
0005432727808	30133	Economy	3300.00
0005433722147	30133	Economy	3300.00
0005432382813	30133	Economy	3300.00
0005433451588	30133	Economy	3300.00
0005432382845	30133	Economy	3300.00
0005432727876	30133	Economy	3300.00
0005432382816	30133	Economy	3300.00
0005432382968	30133	Economy	3300.00
0005432382830	30133	Economy	3300.00
0005433722151	30133	Economy	3300.00
0005432382745	30133	Economy	3300.00
0005432382814	30133	Economy	3300.00
0005432727809	30133	Economy	3300.00
0005432382825	30133	Economy	3300.00
0005432382773	30133	Economy	3300.00
0005432382817	30133	Economy	3300.00
0005433722162	30133	Economy	3300.00
0005432382824	30133	Economy	3300.00
0005432382828	30133	Economy	3300.00
0005433453754	30133	Economy	3300.00
0005432382884	30133	Economy	3300.00
0005432382763	30133	Economy	3300.00
0005432727905	30133	Economy	3300.00
0005432382846	30133	Economy	3300.00
0005432382634	30133	Economy	3300.00
0005433453753	30133	Economy	3300.00
0005432382771	30133	Economy	3300.00
0005432727875	30133	Economy	3300.00
0005432382914	30133	Economy	3300.00
0005432727833	30133	Economy	3300.00
0005432382967	30133	Economy	3300.00
0005433451610	30133	Economy	3300.00
0005432382791	30133	Economy	3300.00
0005433722154	30133	Economy	3300.00
0005433722166	30133	Economy	3300.00
0005432727892	30133	Economy	3300.00
0005433194844	30133	Economy	3300.00
0005432727815	30133	Economy	3300.00
0005433722155	30133	Economy	3300.00
0005432924999	1758	Business	57200.00
0005435529320	1758	Business	57200.00
0005435529311	1758	Business	57200.00
0005435529303	1758	Business	57200.00
0005435529308	1758	Business	57200.00
0005435541060	1758	Business	57200.00
0005435529317	1758	Business	57200.00
0005435529301	1758	Business	57200.00
0005435541065	1758	Economy	19100.00
0005435529312	1758	Economy	19100.00
0005435541044	1758	Economy	19100.00
0005435529321	1758	Economy	19100.00
0005435541052	1758	Economy	19100.00
0005435541064	1758	Economy	19100.00
0005435541061	1758	Economy	19100.00
0005435529300	1758	Economy	21000.00
0005435529313	1758	Economy	21000.00
0005435541055	1758	Economy	21000.00
0005435541043	1758	Economy	21000.00
0005435529310	1758	Economy	19100.00
0005433516911	1758	Economy	19100.00
0005435529316	1758	Economy	19100.00
0005435541059	1758	Economy	19100.00
0005435541048	1758	Economy	19100.00
0005433516905	1758	Economy	19100.00
0005435529318	1758	Economy	19100.00
0005435529304	1758	Economy	19100.00
0005432925016	1758	Economy	19100.00
0005435529302	1758	Economy	19100.00
0005432925004	1758	Economy	19100.00
0005435529314	1758	Economy	19100.00
0005432925012	1758	Economy	19100.00
0005433516907	1758	Economy	19100.00
0005433516903	1758	Economy	19100.00
0005435541057	1758	Economy	19100.00
0005435529306	1758	Economy	19100.00
0005435541050	1758	Economy	19100.00
0005432294493	1758	Economy	19100.00
0005432925008	1758	Economy	19100.00
0005432925006	1758	Economy	19100.00
0005433516909	1758	Economy	19100.00
0005435541049	1758	Economy	19100.00
0005432294492	1758	Economy	19100.00
0005435529315	1758	Economy	19100.00
0005435541047	1758	Economy	19100.00
0005435529307	1758	Economy	19100.00
0005435541062	1758	Economy	19100.00
0005435529309	1758	Economy	19100.00
0005435541051	1758	Economy	19100.00
0005435541053	1758	Economy	19100.00
0005435541046	1758	Economy	19100.00
0005435529319	1758	Economy	19100.00
0005433516904	1758	Economy	19100.00
0005435541063	1758	Economy	19100.00
0005433516910	1758	Economy	19100.00
0005435529305	1758	Economy	19100.00
0005435541058	1758	Economy	19100.00
0005433516908	1758	Economy	19100.00
0005435541056	1758	Economy	19100.00
0005433516906	1758	Economy	19100.00
0005435541054	1758	Economy	19100.00
0005435541045	1758	Economy	19100.00
0005435540713	21978	Business	57200.00
0005435540829	21978	Business	57200.00
0005435540932	21978	Business	57200.00
0005435517808	21978	Business	57200.00
0005435517866	21978	Business	57200.00
0005435540847	21978	Business	57200.00
0005435540856	21978	Business	57200.00
0005435517807	21978	Economy	19100.00
0005433516861	21978	Economy	19100.00
0005435540844	21978	Economy	19100.00
0005435540916	21978	Economy	19100.00
0005435517781	21978	Economy	19100.00
0005433516779	21978	Economy	19100.00
0005435540846	21978	Economy	19100.00
0005435540891	21978	Economy	21000.00
0005433516860	21978	Economy	21000.00
0005432925044	21978	Economy	21000.00
0005435540758	21978	Economy	21000.00
0005432925048	21978	Economy	19100.00
0005435540814	21978	Economy	19100.00
0005435540861	21978	Economy	19100.00
0005435540821	21978	Economy	19100.00
0005435517787	21978	Economy	19100.00
0005435540828	21978	Economy	19100.00
0005435540816	21978	Economy	19100.00
0005435517779	21978	Economy	19100.00
0005435540782	21978	Economy	19100.00
0005435540937	21978	Economy	19100.00
0005435540917	21978	Economy	19100.00
0005433516818	21978	Economy	19100.00
0005435540848	21978	Economy	19100.00
0005435540841	21978	Economy	19100.00
0005433516817	21978	Economy	19100.00
0005435517809	21978	Economy	19100.00
0005435540810	21978	Economy	19100.00
0005435517816	21978	Economy	19100.00
0005435540862	21978	Economy	19100.00
0005435517833	21978	Economy	19100.00
0005435517753	21978	Economy	19100.00
0005435517775	21978	Economy	19100.00
0005435540898	21978	Economy	19100.00
0005435517865	21978	Economy	19100.00
0005435540843	21978	Economy	19100.00
0005435517815	21978	Economy	19100.00
0005435540869	21978	Economy	19100.00
0005435540806	21978	Economy	19100.00
0005435540842	21978	Economy	19100.00
0005435540865	21978	Economy	19100.00
0005435517752	21978	Economy	19100.00
0005435540845	21978	Economy	19100.00
0005433516805	21978	Economy	19100.00
0005435540712	21978	Economy	19100.00
0005432925046	21978	Economy	19100.00
0005432925047	21978	Economy	19100.00
0005435517806	21978	Economy	19100.00
0005435517858	21978	Economy	19100.00
0005435540822	21978	Economy	19100.00
0005432925045	21978	Economy	19100.00
0005435517857	21978	Economy	19100.00
0005432839098	7386	Business	18500.00
0005432839085	7386	Business	18500.00
0005432839086	7386	Business	18500.00
0005434458842	7386	Business	18500.00
0005432839107	7386	Business	18500.00
0005432823453	7386	Business	18500.00
0005435252602	7386	Business	18500.00
0005432839100	7386	Business	18500.00
0005432839099	7386	Economy	6200.00
0005432839095	7386	Economy	6200.00
0005435252633	7386	Economy	6200.00
0005432839101	7386	Economy	6200.00
0005432823454	7386	Economy	6200.00
0005432839089	7386	Economy	6200.00
0005432839104	7386	Economy	6200.00
0005432839088	7386	Economy	6200.00
0005432839115	7386	Economy	6800.00
0005432839096	7386	Economy	6800.00
0005434458845	7386	Economy	6800.00
0005432839113	7386	Economy	6800.00
0005434458843	7386	Economy	6800.00
0005432839090	7386	Economy	6200.00
0005435252603	7386	Economy	6200.00
0005432073398	7386	Economy	6200.00
0005435252605	7386	Economy	6200.00
0005432073399	7386	Economy	6200.00
0005434458848	7386	Economy	6200.00
0005432839110	7386	Economy	6200.00
0005435252619	7386	Economy	6200.00
0005432839108	7386	Economy	6200.00
0005434458852	7386	Economy	6200.00
0005432073396	7386	Economy	6200.00
0005435252641	7386	Economy	6200.00
0005434458851	7386	Economy	6200.00
0005435491430	7386	Economy	6200.00
0005432839105	7386	Economy	6200.00
0005432839093	7386	Economy	6200.00
0005435252604	7386	Economy	6200.00
0005434458850	7386	Economy	6200.00
0005434458858	7386	Economy	6200.00
0005432839087	7386	Economy	6200.00
0005434458847	7386	Economy	6200.00
0005434458838	7386	Economy	6200.00
0005432839106	7386	Economy	6200.00
0005432839116	7386	Economy	6200.00
0005434458849	7386	Economy	6200.00
0005432841016	7386	Economy	6200.00
0005432839111	7386	Economy	6200.00
0005432839112	7386	Economy	6200.00
0005432839097	7386	Economy	6200.00
0005432839114	7386	Economy	6200.00
0005434458846	7386	Economy	6200.00
0005434458855	7386	Economy	6200.00
0005434458857	7386	Economy	6200.00
0005435252592	7386	Economy	6200.00
0005434458840	7386	Economy	6200.00
0005434458844	7386	Economy	6200.00
0005432839091	7386	Economy	6200.00
0005432839103	7386	Economy	6200.00
0005432839094	7386	Economy	6200.00
0005434458841	7386	Economy	6200.00
0005435252640	7386	Economy	6200.00
0005434458856	7386	Economy	6200.00
0005435252639	7386	Economy	6200.00
0005434458839	7386	Economy	6200.00
0005432839109	7386	Economy	6200.00
0005432841014	7386	Economy	6200.00
0005432839102	7386	Economy	6200.00
0005434458853	7386	Economy	6200.00
0005434458854	7386	Economy	6200.00
0005432841015	7386	Economy	6200.00
0005432073397	7386	Economy	6200.00
0005432839092	7386	Economy	6200.00
0005435491447	28900	Business	18500.00
0005434458628	28900	Business	18500.00
0005432839006	28900	Business	18500.00
0005435252749	28900	Business	18500.00
0005432823428	28900	Business	18500.00
0005432838897	28900	Business	18500.00
0005432001029	28900	Business	18500.00
0005435252738	28900	Business	18500.00
0005434458586	28900	Business	18500.00
0005432838924	28900	Business	18500.00
0005432838922	28900	Economy	6200.00
0005435252746	28900	Economy	6200.00
0005432838714	28900	Economy	6200.00
0005435252739	28900	Economy	6200.00
0005434458619	28900	Economy	6200.00
0005434458700	28900	Economy	6200.00
0005435252735	28900	Economy	6200.00
0005432838869	28900	Economy	6200.00
0005435252734	28900	Economy	6800.00
0005432838947	28900	Economy	6800.00
0005435252736	28900	Economy	6800.00
0005432838948	28900	Economy	6800.00
0005432838881	28900	Economy	6800.00
0005435252747	28900	Economy	6200.00
0005432838883	28900	Economy	6200.00
0005432838768	28900	Economy	6200.00
0005432838805	28900	Economy	6200.00
0005432838870	28900	Economy	6200.00
0005432838879	28900	Economy	6200.00
0005434458669	28900	Economy	6200.00
0005435252748	28900	Economy	6200.00
0005434458677	28900	Economy	6200.00
0005434458727	28900	Economy	6200.00
0005432838892	28900	Economy	6200.00
0005432838867	28900	Economy	6200.00
0005434458611	28900	Economy	6200.00
0005432001026	28900	Economy	6200.00
0005432838858	28900	Economy	6200.00
0005434458709	28900	Economy	6200.00
0005434458680	28900	Economy	6200.00
0005432838920	28900	Economy	6200.00
0005432838921	28900	Economy	6200.00
0005434458667	28900	Economy	6200.00
0005432838880	28900	Economy	6200.00
0005434458688	28900	Economy	6200.00
0005432838791	28900	Economy	6200.00
0005434458689	28900	Economy	6200.00
0005432838868	28900	Economy	6200.00
0005432838893	28900	Economy	6200.00
0005434458499	28900	Economy	6200.00
0005434458699	28900	Economy	6200.00
0005432001028	28900	Economy	6200.00
0005434664965	28900	Economy	6200.00
0005432838899	28900	Economy	6200.00
0005435252743	28900	Economy	6200.00
0005434458583	28900	Economy	6200.00
0005435252740	28900	Economy	6200.00
0005434458711	28900	Economy	6200.00
0005435491445	28900	Economy	6200.00
0005435252737	28900	Economy	6200.00
0005432838746	28900	Economy	6200.00
0005434458710	28900	Economy	6200.00
0005432838886	28900	Economy	6200.00
0005432838857	28900	Economy	6200.00
0005432838898	28900	Economy	6200.00
0005435252750	28900	Economy	6200.00
0005432001027	28900	Economy	6200.00
0005435252745	28900	Economy	6200.00
0005432838856	28900	Economy	6200.00
0005434458636	28900	Economy	6200.00
0005432838923	28900	Economy	6200.00
0005435252751	28900	Economy	6200.00
0005432838953	28900	Economy	6200.00
0005432838866	28900	Economy	6200.00
0005434458631	28900	Economy	6200.00
0005435252741	28900	Economy	6200.00
0005435252742	28900	Economy	6200.00
0005435491446	28900	Economy	6200.00
0005434458678	28900	Economy	6200.00
0005432838800	28900	Economy	6200.00
0005432838882	28900	Economy	6200.00
0005435252744	28900	Economy	6200.00
0005435990635	8773	Economy	48400.00
0005435990638	8773	Economy	53300.00
0005435990641	8773	Economy	48400.00
0005435990639	8773	Economy	48400.00
0005434275999	8773	Economy	48400.00
0005435990636	8773	Economy	48400.00
0005435990640	8773	Economy	48400.00
0005435990637	8773	Economy	48400.00
0005435990578	15725	Business	145300.00
0005434276038	15725	Business	145300.00
0005434276037	15725	Business	145300.00
0005435990605	15725	Economy	48400.00
0005434276040	15725	Economy	48400.00
0005435990558	15725	Economy	48400.00
0005435990572	15725	Economy	48400.00
0005435990557	15725	Economy	48400.00
0005434276041	15725	Economy	48400.00
0005435990568	15725	Economy	48400.00
0005434276039	15725	Economy	48400.00
0005435990571	15725	Economy	48400.00
0005433468358	2089	Economy	13300.00
0005432909227	2089	Economy	13300.00
0005432909245	2089	Economy	13300.00
0005432909233	2089	Economy	12100.00
0005432909244	2089	Economy	12100.00
0005433468360	2089	Economy	12100.00
0005432909254	2089	Economy	12100.00
0005432909243	2089	Economy	12100.00
0005433468345	2089	Economy	12100.00
0005433468355	2089	Economy	12100.00
0005432909241	2089	Economy	12100.00
0005433468354	2089	Economy	12100.00
0005433468341	2089	Economy	12100.00
0005432909249	2089	Economy	12100.00
0005433468348	2089	Economy	12100.00
0005433468340	2089	Economy	12100.00
0005432909236	2089	Economy	12100.00
0005432909242	2089	Economy	12100.00
0005432909240	2089	Economy	12100.00
0005433468343	2089	Economy	12100.00
0005433468359	2089	Economy	12100.00
0005433468344	2089	Economy	12100.00
0005433468357	2089	Economy	12100.00
0005433468336	2089	Economy	12100.00
0005433468352	2089	Economy	12100.00
0005433468346	2089	Economy	12100.00
0005432909235	2089	Economy	12100.00
0005432909237	2089	Economy	12100.00
0005432909239	2089	Economy	12100.00
0005433468356	2089	Economy	12100.00
0005432909234	2089	Economy	12100.00
0005432909221	2089	Economy	12100.00
0005433468361	2089	Economy	12100.00
0005433468342	2089	Economy	12100.00
0005433468338	2089	Economy	12100.00
0005433468337	2089	Economy	12100.00
0005432909253	2089	Economy	12100.00
0005433468351	2089	Economy	12100.00
0005433468339	2089	Economy	12100.00
0005433468349	2089	Economy	12100.00
0005433468353	2089	Economy	12100.00
0005433468347	2089	Economy	12100.00
0005432909231	2089	Economy	12100.00
0005432909264	2089	Economy	12100.00
0005433468350	2089	Economy	12100.00
0005435490208	6388	Business	36600.00
0005435176836	6388	Business	36600.00
0005435176831	6388	Business	36600.00
0005434149687	6388	Business	36600.00
0005434149614	6388	Business	36600.00
0005432360451	6388	Business	36600.00
0005434149670	6388	Business	36600.00
0005432360441	6388	Business	36600.00
0005435723025	6388	Business	36600.00
0005432360475	6388	Economy	12200.00
0005435176987	6388	Economy	12200.00
0005434149671	6388	Economy	12200.00
0005432360462	6388	Economy	12200.00
0005432363425	6388	Economy	12200.00
0005432360454	6388	Economy	12200.00
0005432360463	6388	Economy	12200.00
0005435176918	6388	Economy	12200.00
0005434149638	6388	Economy	12200.00
0005434149587	6388	Economy	12200.00
0005432360469	6388	Economy	12200.00
0005432360467	6388	Economy	12200.00
0005432360446	6388	Economy	12200.00
0005432360457	6388	Economy	12200.00
0005434149652	6388	Economy	12200.00
0005435490204	6388	Economy	12200.00
0005435490205	6388	Economy	12200.00
0005432336055	6388	Economy	12200.00
0005434149605	6388	Economy	12200.00
0005435723026	6388	Economy	12200.00
0005432062242	6388	Economy	12200.00
0005432363423	6388	Economy	12200.00
0005435176985	6388	Economy	12200.00
0005432336054	6388	Economy	12200.00
0005432360474	6388	Economy	12200.00
0005435176945	6388	Economy	12200.00
0005434149676	6388	Economy	12200.00
0005435176926	6388	Economy	12200.00
0005432360449	6388	Economy	12200.00
0005434149606	6388	Economy	12200.00
0005432360476	6388	Economy	12200.00
0005435176928	6388	Economy	12200.00
0005432360458	6388	Economy	12200.00
0005435176946	6388	Economy	12200.00
0005435176887	6388	Economy	12200.00
0005432360455	6388	Economy	12200.00
0005432360444	6388	Economy	13400.00
0005432336064	6388	Economy	13400.00
0005432336061	6388	Economy	13400.00
0005432360465	6388	Economy	13400.00
0005434149658	6388	Economy	13400.00
0005432360450	6388	Economy	13400.00
0005432360452	6388	Economy	12200.00
0005432062238	6388	Economy	12200.00
0005432363424	6388	Economy	12200.00
0005432360461	6388	Economy	12200.00
0005432360484	6388	Economy	12200.00
0005432360466	6388	Economy	12200.00
0005434149639	6388	Economy	12200.00
0005432360473	6388	Economy	12200.00
0005432360485	6388	Economy	12200.00
0005435176919	6388	Economy	12200.00
0005435176843	6388	Economy	12200.00
0005432336065	6388	Economy	12200.00
0005432360460	6388	Economy	12200.00
0005435176997	6388	Economy	12200.00
0005432360489	6388	Economy	12200.00
0005434149613	6388	Economy	12200.00
0005432360445	6388	Economy	12200.00
0005434149673	6388	Economy	12200.00
0005435176962	6388	Economy	12200.00
0005432336063	6388	Economy	12200.00
0005432360481	6388	Economy	12200.00
0005432360479	6388	Economy	12200.00
0005435176895	6388	Economy	12200.00
0005432360472	6388	Economy	12200.00
0005435176984	6388	Economy	12200.00
0005432360480	6388	Economy	12200.00
0005432360486	6388	Economy	12200.00
0005432336062	6388	Economy	12200.00
0005432062239	6388	Economy	12200.00
0005434149710	6388	Economy	12200.00
0005432360453	6388	Economy	12200.00
0005434149686	6388	Economy	12200.00
0005435176948	6388	Economy	12200.00
0005432360442	6388	Economy	12200.00
0005432360443	6388	Economy	12200.00
0005434149657	6388	Economy	12200.00
0005432062240	6388	Economy	12200.00
0005432360468	6388	Economy	12200.00
0005435176886	6388	Economy	12200.00
0005432336058	6388	Economy	12200.00
0005435490221	6388	Economy	12200.00
0005432360477	6388	Economy	12200.00
0005432336056	6388	Economy	12200.00
0005432360456	6388	Economy	12200.00
0005435176866	6388	Economy	12200.00
0005432336057	6388	Economy	12200.00
0005434149659	6388	Economy	12200.00
0005432360447	6388	Economy	12200.00
0005435176876	6388	Economy	12200.00
0005432336053	6388	Economy	12200.00
0005432360478	6388	Economy	12200.00
0005432360470	6388	Economy	12200.00
0005435723027	6388	Economy	12200.00
0005435176947	6388	Economy	12200.00
0005432360448	6388	Economy	12200.00
0005432360487	6388	Economy	12200.00
0005432360488	6388	Economy	12200.00
0005432360459	6388	Economy	12200.00
0005432360464	6388	Economy	12200.00
0005434149653	6388	Economy	12200.00
0005435176986	6388	Economy	12200.00
0005434149615	6388	Economy	12200.00
0005435176927	6388	Economy	12200.00
0005432336059	6388	Economy	12200.00
0005434149701	6388	Economy	12200.00
0005435176949	6388	Economy	12200.00
0005432336060	6388	Economy	12200.00
0005432360482	6388	Economy	12200.00
0005432360483	6388	Economy	12200.00
0005432062241	6388	Economy	12200.00
0005432360471	6388	Economy	12200.00
0005434149749	20994	Business	36600.00
0005435177140	20994	Business	36600.00
0005432360081	20994	Business	36600.00
0005432359970	20994	Business	36600.00
0005432336002	20994	Business	36600.00
0005435490240	20994	Business	36600.00
0005435723051	20994	Business	36600.00
0005435177146	20994	Business	36600.00
0005435177133	20994	Business	36600.00
0005432360017	20994	Business	36600.00
0005432360186	20994	Economy	12200.00
0005435177130	20994	Business	36600.00
0005432359959	20994	Economy	12200.00
0005432360188	20994	Economy	12200.00
0005435723050	20994	Economy	12200.00
0005435177147	20994	Economy	12200.00
0005435177125	20994	Economy	12200.00
0005435177141	20994	Economy	12200.00
0005432360045	20994	Economy	12200.00
0005432052752	20994	Economy	12200.00
0005432360083	20994	Economy	12200.00
0005432360182	20994	Economy	12200.00
0005435177123	20994	Economy	12200.00
0005434149750	20994	Economy	12200.00
0005432360189	20994	Economy	12200.00
0005432359994	20994	Economy	12200.00
0005432360126	20994	Economy	12200.00
0005432360062	20994	Economy	12200.00
0005432359920	20994	Economy	12200.00
0005432360108	20994	Economy	12200.00
0005432359997	20994	Economy	12200.00
0005432359982	20994	Economy	12200.00
0005435177144	20994	Economy	12200.00
0005435177127	20994	Economy	12200.00
0005432360228	20994	Economy	12200.00
0005434149759	20994	Economy	12200.00
0005432360187	20994	Economy	12200.00
0005435177138	20994	Economy	12200.00
0005435177122	20994	Economy	12200.00
0005432359951	20994	Economy	12200.00
0005432360184	20994	Economy	12200.00
0005432360180	20994	Economy	12200.00
0005434149758	20994	Economy	12200.00
0005435177139	20994	Economy	12200.00
0005435177131	20994	Economy	12200.00
0005432360054	20994	Economy	13400.00
0005434149755	20994	Economy	13400.00
0005434149754	20994	Economy	13400.00
0005435177142	20994	Economy	13400.00
0005432360227	20994	Economy	12200.00
0005435177120	20994	Economy	12200.00
0005434149760	20994	Economy	12200.00
0005432335955	20994	Economy	12200.00
0005434149753	20994	Economy	12200.00
0005432052753	20994	Economy	12200.00
0005432360226	20994	Economy	12200.00
0005432360190	20994	Economy	12200.00
0005435177129	20994	Economy	12200.00
0005432360015	20994	Economy	12200.00
0005435490239	20994	Economy	12200.00
0005432363389	20994	Economy	12200.00
0005432360181	20994	Economy	12200.00
0005435177137	20994	Economy	12200.00
0005435177148	20994	Economy	12200.00
0005432360082	20994	Economy	12200.00
0005432360046	20994	Economy	12200.00
0005435177136	20994	Economy	12200.00
0005432359995	20994	Economy	12200.00
0005435723052	20994	Economy	12200.00
0005432359948	20994	Economy	12200.00
0005432359985	20994	Economy	12200.00
0005432359930	20994	Economy	12200.00
0005435177145	20994	Economy	12200.00
0005434149757	20994	Economy	12200.00
0005435177128	20994	Economy	12200.00
0005435177135	20994	Economy	12200.00
0005435177143	20994	Economy	12200.00
0005432335990	20994	Economy	12200.00
0005432335951	20994	Economy	12200.00
0005434149751	20994	Economy	12200.00
0005432360159	20994	Economy	12200.00
0005432359971	20994	Economy	12200.00
0005432359953	20994	Economy	12200.00
0005432335994	20994	Economy	12200.00
0005435177121	20994	Economy	12200.00
0005435490238	20994	Economy	12200.00
0005432052751	20994	Economy	12200.00
0005435177132	20994	Economy	12200.00
0005432360099	20994	Economy	12200.00
0005434149752	20994	Economy	12200.00
0005432360122	20994	Economy	12200.00
0005434149756	20994	Economy	12200.00
0005435490237	20994	Economy	12200.00
0005435177124	20994	Economy	12200.00
0005432359952	20994	Economy	12200.00
0005432360000	20994	Economy	12200.00
0005435177134	20994	Economy	12200.00
0005435177126	20994	Economy	12200.00
0005434458726	17730	Economy	3400.00
0005434448293	17730	Economy	3400.00
0005434186206	17730	Economy	3100.00
0005434458731	17730	Economy	3100.00
0005434458782	17730	Economy	3100.00
0005434458719	17730	Economy	3100.00
0005434186207	17730	Economy	3100.00
0005434458737	17730	Economy	3100.00
0005434458762	17730	Economy	3100.00
0005434458666	17730	Economy	3100.00
0005434458720	17730	Economy	3100.00
0005434458725	17730	Economy	3100.00
0005434448280	17730	Economy	3100.00
0005434458686	17730	Economy	3100.00
0005434458761	17730	Economy	3100.00
0005434448287	17730	Economy	3100.00
0005434448294	17730	Economy	3100.00
0005434448306	17730	Economy	3100.00
0005434458703	17730	Economy	3100.00
0005434461637	17730	Economy	3100.00
0005434458645	17730	Economy	3100.00
0005434458760	17730	Economy	3100.00
0005434186205	17730	Economy	3100.00
0005434458732	17730	Economy	3100.00
0005434458788	17730	Economy	3100.00
0005434458629	17730	Economy	3100.00
0005434458713	17730	Economy	3100.00
0005434186204	17730	Economy	3100.00
0005434461635	17730	Economy	3100.00
0005434458630	17730	Economy	3100.00
0005434458687	17730	Economy	3100.00
0005434458693	17730	Economy	3100.00
0005434458712	17730	Economy	3100.00
0005434458791	17730	Economy	3100.00
0005434461636	17730	Economy	3100.00
0005434463924	17730	Economy	3100.00
0005434458781	17730	Economy	3100.00
0005434458704	17730	Economy	3100.00
0005434458646	17730	Economy	3100.00
0005434448282	17730	Economy	3100.00
0005434458849	29095	Economy	3400.00
0005434448320	29095	Economy	3100.00
0005434458839	29095	Economy	3100.00
0005434448319	29095	Economy	3100.00
0005434458845	29095	Economy	3100.00
0005434458841	29095	Economy	3100.00
0005434458856	29095	Economy	3100.00
0005434458854	29095	Economy	3100.00
0005434458846	29095	Economy	3100.00
0005434458857	29095	Economy	3100.00
0005434458858	29095	Economy	3100.00
0005434186179	29095	Economy	3100.00
0005434458843	29095	Economy	3100.00
0005434448318	29095	Economy	3100.00
0005434448317	29095	Economy	3100.00
0005434458848	29095	Economy	3100.00
0005434463931	29095	Economy	3100.00
0005434458844	29095	Economy	3100.00
0005434458855	29095	Economy	3100.00
0005434458838	29095	Economy	3100.00
0005434458852	29095	Economy	3100.00
0005434458850	29095	Economy	3100.00
0005434463933	29095	Economy	3100.00
0005434458840	29095	Economy	3100.00
0005434458851	29095	Economy	3100.00
0005434463932	29095	Economy	3100.00
0005434462793	29095	Economy	3100.00
0005434458842	29095	Economy	3100.00
0005434458847	29095	Economy	3100.00
0005434186172	29095	Economy	3100.00
0005434458853	29095	Economy	3100.00
0005432604394	21447	Economy	7300.00
0005432604372	21447	Economy	7300.00
0005432604383	21447	Economy	7300.00
0005432604387	21447	Economy	7300.00
0005432604404	21447	Economy	6600.00
0005432604390	21447	Economy	6600.00
0005432604388	21447	Economy	6600.00
0005432604373	21447	Economy	6600.00
0005432604402	21447	Economy	6600.00
0005432604399	21447	Economy	6600.00
0005432604377	21447	Economy	6600.00
0005432604386	21447	Economy	6600.00
0005432604389	21447	Economy	6600.00
0005432604406	21447	Economy	6600.00
0005432604382	21447	Economy	6600.00
0005432604401	21447	Economy	6600.00
0005432604405	21447	Economy	6600.00
0005432604403	21447	Economy	6600.00
0005432604379	21447	Economy	6600.00
0005432604378	21447	Economy	6600.00
0005432604407	21447	Economy	6600.00
0005432604410	21447	Economy	6600.00
0005432604397	21447	Economy	6600.00
0005432604411	21447	Economy	6600.00
0005432604395	21447	Economy	6600.00
0005432604374	21447	Economy	6600.00
0005432604393	21447	Economy	6600.00
0005432604398	21447	Economy	6600.00
0005432604409	21447	Economy	6600.00
0005432604384	21447	Economy	6600.00
0005432604400	21447	Economy	6600.00
0005432604392	21447	Economy	6600.00
0005432604375	21447	Economy	6600.00
0005432604396	21447	Economy	6600.00
0005432604376	21447	Economy	6600.00
0005432604385	21447	Economy	6600.00
0005432604391	21447	Economy	6600.00
0005432604408	21447	Economy	6600.00
0005432604381	21447	Economy	6600.00
0005432604380	21447	Economy	6600.00
0005432603869	31677	Economy	7300.00
0005432603930	31677	Economy	7300.00
0005432604168	31677	Economy	7300.00
0005432604055	31677	Economy	6600.00
0005435221054	31677	Economy	6600.00
0005432604154	31677	Economy	6600.00
0005432603987	31677	Economy	6600.00
0005432604029	31677	Economy	6600.00
0005432604167	31677	Economy	6600.00
0005432603967	31677	Economy	6600.00
0005432604047	31677	Economy	6600.00
0005432604031	31677	Economy	6600.00
0005432604060	31677	Economy	6600.00
0005432604179	31677	Economy	6600.00
0005432604030	31677	Economy	6600.00
0005432604146	31677	Economy	6600.00
0005435221516	31677	Economy	6600.00
0005432604059	31677	Economy	6600.00
0005432604032	31677	Economy	6600.00
0005432604043	31677	Economy	6600.00
0005432604054	31677	Economy	6600.00
0005435221056	31677	Economy	6600.00
0005432603960	31677	Economy	6600.00
0005432604074	31677	Economy	6600.00
0005432604056	31677	Economy	6600.00
0005432603974	31677	Economy	6600.00
0005432603955	31677	Economy	6600.00
0005432604143	31677	Economy	6600.00
0005432603966	31677	Economy	6600.00
0005432603905	31677	Economy	6600.00
0005432604153	31677	Economy	6600.00
0005432604018	31677	Economy	6600.00
0005432604042	31677	Economy	6600.00
0005432603983	31677	Economy	6600.00
0005432604041	31677	Economy	6600.00
0005435221055	31677	Economy	6600.00
0005432604009	31677	Economy	6600.00
0005432603959	31677	Economy	6600.00
0005432604226	31677	Economy	6600.00
0005432603984	31677	Economy	6600.00
0005432604201	31677	Economy	6600.00
0005432603973	31677	Economy	6600.00
0005434606795	18819	Economy	6600.00
0005434606797	18819	Economy	6600.00
0005434606796	18819	Economy	6600.00
0005435904896	18819	Economy	6600.00
0005435904897	18819	Economy	6600.00
0005434606809	18819	Economy	6600.00
0005434606833	22325	Economy	6600.00
0005434606831	22325	Economy	6600.00
0005435904892	22325	Economy	6600.00
0005434604902	22325	Economy	6600.00
0005435904891	22325	Economy	6600.00
0005434604900	22325	Economy	6600.00
0005434606832	22325	Economy	6600.00
0005434604901	22325	Economy	6600.00
0005434604903	22325	Economy	6600.00
0005432890933	397	Business	44500.00
0005432747622	397	Business	44500.00
0005432890852	397	Business	44500.00
0005432747627	397	Business	44500.00
0005433293222	397	Business	44500.00
0005432890872	397	Business	44500.00
0005432890937	397	Business	44500.00
0005432753303	397	Business	44500.00
0005432747624	397	Business	44500.00
0005432747650	397	Economy	14800.00
0005432890936	397	Economy	14800.00
0005432890853	397	Economy	14800.00
0005432753305	397	Economy	14800.00
0005432747628	397	Economy	14800.00
0005432747646	397	Economy	14800.00
0005432747649	397	Economy	16300.00
0005432747620	397	Economy	16300.00
0005432747637	397	Economy	16300.00
0005432747626	397	Economy	16300.00
0005432747631	397	Economy	14800.00
0005432747633	397	Economy	14800.00
0005432751531	397	Economy	14800.00
0005432890909	397	Economy	14800.00
0005432747621	397	Economy	14800.00
0005432747648	397	Economy	14800.00
0005432220010	397	Economy	14800.00
0005432220011	397	Economy	14800.00
0005432890870	397	Economy	14800.00
0005432890883	397	Economy	14800.00
0005432747651	397	Economy	14800.00
0005432753306	397	Economy	14800.00
0005432747639	397	Economy	14800.00
0005432749788	397	Economy	14800.00
0005432747615	397	Economy	14800.00
0005432747636	397	Economy	14800.00
0005432747641	397	Economy	14800.00
0005432890849	397	Economy	14800.00
0005432753304	397	Economy	14800.00
0005432747614	397	Economy	14800.00
0005432890911	397	Economy	14800.00
0005432747629	397	Economy	14800.00
0005432747632	397	Economy	14800.00
0005432747623	397	Economy	14800.00
0005432890829	397	Economy	14800.00
0005432747640	397	Economy	14800.00
0005433293223	397	Economy	14800.00
0005432747642	397	Economy	14800.00
0005432747630	397	Economy	14800.00
0005432747625	397	Economy	14800.00
0005432890862	397	Economy	14800.00
0005432747616	397	Economy	14800.00
0005432890931	397	Economy	14800.00
0005432747619	397	Economy	14800.00
0005432747635	397	Economy	14800.00
0005432747652	397	Economy	14800.00
0005432747644	397	Economy	14800.00
0005432747638	397	Economy	14800.00
0005432747634	397	Economy	14800.00
0005432747618	397	Economy	14800.00
0005435627120	397	Economy	14800.00
0005435627119	397	Economy	14800.00
0005432890971	397	Economy	14800.00
0005432747645	397	Economy	14800.00
0005433293204	397	Economy	14800.00
0005432890851	397	Economy	14800.00
0005432747617	397	Economy	14800.00
0005433293203	397	Economy	14800.00
0005432749787	397	Economy	14800.00
0005432220012	397	Economy	14800.00
0005432747643	397	Economy	14800.00
0005432890934	397	Economy	14800.00
0005432890908	397	Economy	14800.00
0005432890871	397	Economy	14800.00
0005432747647	397	Economy	14800.00
0005432753272	12081	Business	44500.00
0005432891063	12081	Business	44500.00
0005432747365	12081	Business	44500.00
0005432747134	12081	Business	44500.00
0005433293260	12081	Business	44500.00
0005433293259	12081	Business	44500.00
0005433293255	12081	Business	44500.00
0005432891052	12081	Business	44500.00
0005432891055	12081	Business	44500.00
0005432747294	12081	Business	44500.00
0005432747387	12081	Business	44500.00
0005432747269	12081	Business	44500.00
0005432891053	12081	Economy	14800.00
0005432891061	12081	Economy	14800.00
0005432747336	12081	Economy	14800.00
0005432749774	12081	Economy	14800.00
0005432753269	12081	Economy	14800.00
0005433293261	12081	Economy	14800.00
0005433293256	12081	Economy	14800.00
0005432753296	12081	Economy	14800.00
0005433293254	12081	Economy	14800.00
0005432214808	12081	Economy	14800.00
0005432747211	12081	Economy	16300.00
0005432747103	12081	Economy	16300.00
0005432747316	12081	Economy	16300.00
0005432747355	12081	Economy	16300.00
0005433875384	12081	Economy	16300.00
0005433293264	12081	Economy	14800.00
0005432891059	12081	Economy	14800.00
0005432747227	12081	Economy	14800.00
0005432753265	12081	Economy	14800.00
0005432747102	12081	Economy	14800.00
0005432747317	12081	Economy	14800.00
0005432891062	12081	Economy	14800.00
0005432891060	12081	Economy	14800.00
0005432747193	12081	Economy	14800.00
0005432891067	12081	Economy	14800.00
0005432747304	12081	Economy	14800.00
0005432747315	12081	Economy	14800.00
0005433293252	12081	Economy	14800.00
0005432749772	12081	Economy	14800.00
0005432747354	12081	Economy	14800.00
0005432747260	12081	Economy	14800.00
0005433293263	12081	Economy	14800.00
0005433293253	12081	Economy	14800.00
0005432891065	12081	Economy	14800.00
0005432747222	12081	Economy	14800.00
0005432891064	12081	Economy	14800.00
0005432747390	12081	Economy	14800.00
0005432756829	12081	Economy	14800.00
0005432891054	12081	Economy	14800.00
0005432747308	12081	Economy	14800.00
0005432747413	12081	Economy	14800.00
0005432747353	12081	Economy	14800.00
0005432747295	12081	Economy	14800.00
0005432747448	12081	Economy	14800.00
0005432749773	12081	Economy	14800.00
0005432891058	12081	Economy	14800.00
0005432747147	12081	Economy	14800.00
0005433293262	12081	Economy	14800.00
0005432747182	12081	Economy	14800.00
0005432747303	12081	Economy	14800.00
0005432747428	12081	Economy	14800.00
0005432747391	12081	Economy	14800.00
0005432747318	12081	Economy	14800.00
0005432747133	12081	Economy	14800.00
0005432747397	12081	Economy	14800.00
0005432214809	12081	Economy	14800.00
0005432747380	12081	Economy	14800.00
0005432747243	12081	Economy	14800.00
0005432747402	12081	Economy	14800.00
0005432891050	12081	Economy	14800.00
0005433293258	12081	Economy	14800.00
0005432747259	12081	Economy	14800.00
0005432214807	12081	Economy	14800.00
0005433875383	12081	Economy	14800.00
0005432747258	12081	Economy	14800.00
0005432753271	12081	Economy	14800.00
0005432747364	12081	Economy	14800.00
0005432891066	12081	Economy	14800.00
0005432891057	12081	Economy	14800.00
0005432891056	12081	Economy	14800.00
0005432747384	12081	Economy	14800.00
0005432747412	12081	Economy	14800.00
0005432891051	12081	Economy	14800.00
0005432891068	12081	Economy	14800.00
0005432747219	12081	Economy	14800.00
0005432747224	12081	Economy	14800.00
0005433293257	12081	Economy	14800.00
0005432747192	12081	Economy	14800.00
0005432747587	12081	Economy	14800.00
0005432747340	12081	Economy	14800.00
0005432891069	12081	Economy	14800.00
0005432747237	12081	Economy	14800.00
0005432747411	12081	Economy	14800.00
0005433525048	18968	Economy	28200.00
0005433525055	18968	Economy	28200.00
0005433533313	18968	Economy	28200.00
0005433525046	18968	Economy	25700.00
0005433531297	18968	Economy	25700.00
0005432927925	18968	Economy	25700.00
0005433525050	18968	Economy	25700.00
0005433525054	18968	Economy	25700.00
0005433531298	18968	Economy	25700.00
0005433531300	18968	Economy	25700.00
0005432927981	18968	Economy	25700.00
0005433525057	18968	Economy	25700.00
0005433525051	18968	Economy	25700.00
0005433531299	18968	Economy	25700.00
0005433525047	18968	Economy	25700.00
0005432927936	18968	Economy	25700.00
0005433533311	18968	Economy	25700.00
0005433525052	18968	Economy	25700.00
0005433531296	18968	Economy	25700.00
0005433525053	18968	Economy	25700.00
0005433533310	18968	Economy	25700.00
0005433533312	18968	Economy	25700.00
0005433531295	18968	Economy	25700.00
0005433525049	18968	Economy	25700.00
0005433525056	18968	Economy	25700.00
0005433524959	32460	Economy	28200.00
0005433531259	32460	Economy	28200.00
0005432927997	32460	Economy	25700.00
0005433531265	32460	Economy	25700.00
0005433527214	32460	Economy	25700.00
0005433531268	32460	Economy	25700.00
0005433524958	32460	Economy	25700.00
0005433524964	32460	Economy	25700.00
0005433531260	32460	Economy	25700.00
0005432927996	32460	Economy	25700.00
0005433531272	32460	Economy	25700.00
0005433524977	32460	Economy	25700.00
0005433531271	32460	Economy	25700.00
0005433524960	32460	Economy	25700.00
0005433527220	32460	Economy	25700.00
0005433531258	32460	Economy	25700.00
0005433527226	32460	Economy	25700.00
0005433531267	32460	Economy	25700.00
0005432927995	32460	Economy	25700.00
0005432927998	32460	Economy	25700.00
0005433524961	32460	Economy	25700.00
0005433524963	32460	Economy	25700.00
0005433524962	32460	Economy	25700.00
0005433524997	32460	Economy	25700.00
0005432927999	32460	Economy	25700.00
0005434831158	5293	Business	84000.00
0005435150065	5293	Business	84000.00
0005434558290	5293	Business	84000.00
0005434823801	5293	Business	84000.00
0005434823898	5293	Business	84000.00
0005435372777	5293	Business	84000.00
0005432121360	5293	Business	84000.00
0005434823785	5293	Business	84000.00
0005435372698	5293	Business	84000.00
0005435304125	5293	Business	84000.00
0005434823908	5293	Business	84000.00
0005434823814	5293	Business	84000.00
0005434823853	5293	Business	84000.00
0005435372863	5293	Business	84000.00
0005434823813	5293	Business	84000.00
0005434823840	5293	Business	84000.00
0005434558291	5293	Business	84000.00
0005434828700	5293	Business	84000.00
0005435372730	5293	Business	84000.00
0005434823871	5293	Business	84000.00
0005434823802	5293	Business	84000.00
0005434823822	5293	Business	84000.00
0005434823794	5293	Business	84000.00
0005434823779	5293	Business	84000.00
0005435372981	5293	Business	84000.00
0005435372812	5293	Comfort	47600.00
0005434823903	5293	Comfort	47600.00
0005432394110	5293	Comfort	47600.00
0005434823786	5293	Comfort	47600.00
0005434823869	5293	Comfort	47600.00
0005435372649	5293	Comfort	47600.00
0005435386505	5293	Comfort	47600.00
0005435372714	5293	Comfort	47600.00
0005432121361	5293	Comfort	47600.00
0005434823811	5293	Comfort	47600.00
0005435372574	5293	Comfort	47600.00
0005435661904	5293	Comfort	47600.00
0005434823823	5293	Comfort	47600.00
0005434823854	5293	Comfort	47600.00
0005435386518	5293	Comfort	47600.00
0005434823838	5293	Comfort	47600.00
0005435373023	5293	Comfort	47600.00
0005434823873	5293	Comfort	47600.00
0005435372902	5293	Comfort	47600.00
0005432396249	5293	Comfort	47600.00
0005434823844	5293	Comfort	47600.00
0005432121370	5293	Comfort	47600.00
0005434823864	5293	Comfort	47600.00
0005434558298	5293	Comfort	47600.00
0005435372840	5293	Comfort	47600.00
0005434823846	5293	Comfort	47600.00
0005434823858	5293	Comfort	47600.00
0005435372784	5293	Comfort	47600.00
0005434823850	5293	Comfort	47600.00
0005435372971	5293	Comfort	47600.00
0005434823816	5293	Comfort	47600.00
0005435372731	5293	Comfort	47600.00
0005434823805	5293	Comfort	47600.00
0005435735103	5293	Comfort	47600.00
0005432396253	5293	Comfort	47600.00
0005434823852	5293	Comfort	47600.00
0005434823791	5293	Economy	28000.00
0005435372970	5293	Economy	28000.00
0005435372852	5293	Economy	28000.00
0005435372849	5293	Economy	28000.00
0005434823867	5293	Economy	28000.00
0005435150057	5293	Economy	28000.00
0005434823819	5293	Economy	28000.00
0005434823798	5293	Economy	28000.00
0005434823835	5293	Economy	28000.00
0005434823799	5293	Economy	28000.00
0005434823778	5293	Economy	28000.00
0005434558295	5293	Economy	28000.00
0005434823800	5293	Economy	28000.00
0005434831157	5293	Economy	28000.00
0005434823796	5293	Economy	28000.00
0005434823792	5293	Economy	28000.00
0005434558301	5293	Economy	28000.00
0005434823882	5293	Economy	28000.00
0005434823899	5293	Economy	28000.00
0005435372842	5293	Economy	28000.00
0005434823841	5293	Economy	28000.00
0005434823891	5293	Economy	28000.00
0005434823897	5293	Economy	28000.00
0005434823807	5293	Economy	28000.00
0005435372758	5293	Economy	28000.00
0005435372922	5293	Economy	28000.00
0005434823782	5293	Economy	28000.00
0005434823880	5293	Economy	28000.00
0005435372868	5293	Economy	28000.00
0005434823894	5293	Economy	28000.00
0005432121364	5293	Economy	28000.00
0005434823856	5293	Economy	28000.00
0005432121366	5293	Economy	28000.00
0005434823817	5293	Economy	28000.00
0005435372914	5293	Economy	28000.00
0005434823906	5293	Economy	28000.00
0005434823839	5293	Economy	28000.00
0005432121368	5293	Economy	28000.00
0005435150052	5293	Economy	28000.00
0005435373144	5293	Economy	28000.00
0005435150060	5293	Economy	28000.00
0005435150053	5293	Economy	28000.00
0005435735104	5293	Economy	28000.00
0005435372776	5293	Economy	28000.00
0005434831155	5293	Economy	28000.00
0005434823886	5293	Economy	28000.00
0005434823892	5293	Economy	28000.00
0005434823793	5293	Economy	28000.00
0005435372725	5293	Economy	28000.00
0005434823780	5293	Economy	30800.00
0005434823783	5293	Economy	30800.00
0005434823889	5293	Economy	28000.00
0005435372702	5293	Economy	30800.00
0005434823818	5293	Economy	28000.00
0005435372783	5293	Economy	28000.00
0005434823812	5293	Economy	30800.00
0005432121365	5293	Economy	30800.00
0005435372771	5293	Economy	30800.00
0005435299731	5293	Economy	28000.00
0005435373038	5293	Economy	28000.00
0005435661897	5293	Economy	28000.00
0005434823834	5293	Economy	28000.00
0005434823905	5293	Economy	28000.00
0005435372751	5293	Economy	28000.00
0005434823862	5293	Economy	28000.00
0005434823826	5293	Economy	28000.00
0005434823887	5293	Economy	28000.00
0005434823855	5293	Economy	28000.00
0005435372781	5293	Economy	28000.00
0005434823810	5293	Economy	28000.00
0005432394111	5293	Economy	28000.00
0005435386543	5293	Economy	28000.00
0005435299746	5293	Economy	28000.00
0005435372775	5293	Economy	28000.00
0005432121359	5293	Economy	28000.00
0005434823901	5293	Economy	28000.00
0005435372980	5293	Economy	28000.00
0005434823815	5293	Economy	28000.00
0005434823865	5293	Economy	28000.00
0005434558293	5293	Economy	28000.00
0005435150055	5293	Economy	28000.00
0005435373050	5293	Economy	28000.00
0005432121362	5293	Economy	28000.00
0005435372862	5293	Economy	28000.00
0005432121367	5293	Economy	28000.00
0005434823833	5293	Economy	28000.00
0005434823821	5293	Economy	28000.00
0005432121369	5293	Economy	28000.00
0005434823797	5293	Economy	28000.00
0005435150063	5293	Economy	28000.00
0005434823820	5293	Economy	28000.00
0005434823884	5293	Economy	28000.00
0005435372877	5293	Economy	28000.00
0005434823828	5293	Economy	28000.00
0005435372853	5293	Economy	28000.00
0005434558302	5293	Economy	28000.00
0005435178987	5293	Economy	28000.00
0005434823860	5293	Economy	28000.00
0005435372841	5293	Economy	28000.00
0005435304142	5293	Economy	28000.00
0005432394113	5293	Economy	28000.00
0005435372831	5293	Economy	28000.00
0005435372653	5293	Economy	28000.00
0005434823832	5293	Economy	28000.00
0005434823824	5293	Economy	28000.00
0005434823845	5293	Economy	28000.00
0005434823877	5293	Economy	28000.00
0005435372729	5293	Economy	28000.00
0005435372956	5293	Economy	28000.00
0005435299732	5293	Economy	28000.00
0005432121358	5293	Economy	28000.00
0005434558296	5293	Economy	28000.00
0005434823795	5293	Economy	28000.00
0005434823787	5293	Economy	28000.00
0005435372881	5293	Economy	28000.00
0005434823883	5293	Economy	28000.00
0005435372982	5293	Economy	28000.00
0005435372489	5293	Economy	28000.00
0005434823857	5293	Economy	28000.00
0005435299734	5293	Economy	28000.00
0005434823888	5293	Economy	28000.00
0005434823809	5293	Economy	28000.00
0005434823863	5293	Economy	28000.00
0005435372774	5293	Economy	28000.00
0005434823836	5293	Economy	28000.00
0005435372923	5293	Economy	28000.00
0005434823895	5293	Economy	28000.00
0005435372655	5293	Economy	28000.00
0005435372904	5293	Economy	28000.00
0005435150054	5293	Economy	28000.00
0005434823874	5293	Economy	28000.00
0005435150058	5293	Economy	28000.00
0005432121363	5293	Economy	28000.00
0005434823837	5293	Economy	28000.00
0005435373055	5293	Economy	28000.00
0005434823830	5293	Economy	28000.00
0005434831159	5293	Economy	30800.00
0005435372882	5293	Economy	30800.00
0005435178985	5293	Economy	30800.00
0005432121357	5293	Economy	30800.00
0005434823789	5293	Economy	30800.00
0005435372869	5293	Economy	28000.00
0005434823803	5293	Economy	28000.00
0005435373117	5293	Economy	28000.00
0005434831156	5293	Economy	28000.00
0005435372715	5293	Economy	28000.00
0005434823848	5293	Economy	28000.00
0005434823831	5293	Economy	28000.00
0005432394112	5293	Economy	28000.00
0005434823843	5293	Economy	28000.00
0005434823790	5293	Economy	28000.00
0005434828701	5293	Economy	28000.00
0005434558289	5293	Economy	28000.00
0005435372740	5293	Economy	28000.00
0005434823829	5293	Economy	28000.00
0005434823847	5293	Economy	28000.00
0005435373039	5293	Economy	28000.00
0005434664964	5293	Economy	28000.00
0005434823859	5293	Economy	28000.00
0005434823879	5293	Economy	28000.00
0005435372895	5293	Economy	28000.00
0005432396250	5293	Economy	28000.00
0005434823808	5293	Economy	28000.00
0005435299737	5293	Economy	28000.00
0005435304134	5293	Economy	28000.00
0005434823804	5293	Economy	28000.00
0005434558297	5293	Economy	28000.00
0005434823876	5293	Economy	28000.00
0005434558292	5293	Economy	28000.00
0005434823878	5293	Economy	28000.00
0005435150059	5293	Economy	28000.00
0005435386532	5293	Economy	28000.00
0005435372608	5293	Economy	28000.00
0005435372969	5293	Economy	28000.00
0005435150061	5293	Economy	28000.00
0005434823827	5293	Economy	28000.00
0005435150056	5293	Economy	28000.00
0005435372757	5293	Economy	28000.00
0005434823784	5293	Economy	28000.00
0005435304126	5293	Economy	28000.00
0005434823788	5293	Economy	28000.00
0005435150062	5293	Economy	28000.00
0005435372609	5293	Economy	28000.00
0005432121356	5293	Economy	28000.00
0005432396252	5293	Economy	28000.00
0005435372663	5293	Economy	28000.00
0005435661903	5293	Economy	28000.00
0005434823851	5293	Economy	28000.00
0005434823893	5293	Economy	28000.00
0005435304124	5293	Economy	28000.00
0005435372674	5293	Economy	28000.00
0005434823890	5293	Economy	28000.00
0005434823868	5293	Economy	28000.00
0005434823902	5293	Economy	28000.00
0005435178988	5293	Economy	28000.00
0005434664963	5293	Economy	28000.00
0005434558300	5293	Economy	28000.00
0005432396251	5293	Economy	28000.00
0005434823781	5293	Economy	28000.00
0005434823881	5293	Economy	28000.00
0005434823900	5293	Economy	28000.00
0005435372977	5293	Economy	28000.00
0005434823825	5293	Economy	28000.00
0005435372547	5293	Economy	28000.00
0005434823872	5293	Economy	28000.00
0005434823907	5293	Economy	28000.00
0005434823904	5293	Economy	28000.00
0005434823861	5293	Economy	28000.00
0005434823866	5293	Economy	28000.00
0005434823849	5293	Economy	28000.00
0005435372976	5293	Economy	28000.00
0005434823875	5293	Economy	28000.00
0005434823896	5293	Economy	28000.00
0005435150064	5293	Economy	28000.00
0005434823870	5293	Economy	28000.00
0005434823885	5293	Economy	28000.00
0005435373063	5293	Economy	28000.00
0005435372673	5293	Economy	28000.00
0005434558299	5293	Economy	28000.00
0005434823842	5293	Economy	28000.00
0005434823806	5293	Economy	28000.00
0005434558294	5293	Economy	28000.00
0005434822675	9888	Business	84000.00
0005434822391	9888	Business	84000.00
0005435373397	9888	Business	84000.00
0005434558199	9888	Business	84000.00
0005434821987	9888	Business	84000.00
0005435373399	9888	Business	84000.00
0005435373392	9888	Business	84000.00
0005434823111	9888	Business	84000.00
0005434822704	9888	Business	84000.00
0005434823018	9888	Business	84000.00
0005434558203	9888	Business	84000.00
0005434822638	9888	Business	84000.00
0005432203075	9888	Business	84000.00
0005435661937	9888	Business	84000.00
0005435373424	9888	Business	84000.00
0005434822850	9888	Business	84000.00
0005434822656	9888	Comfort	47600.00
0005434664948	9888	Business	84000.00
0005435373377	9888	Comfort	47600.00
0005434822589	9888	Comfort	47600.00
0005434822600	9888	Comfort	47600.00
0005434822813	9888	Comfort	47600.00
0005434822708	9888	Comfort	47600.00
0005435373396	9888	Comfort	47600.00
0005434822411	9888	Comfort	47600.00
0005434664933	9888	Comfort	47600.00
0005435373406	9888	Comfort	47600.00
0005435386585	9888	Comfort	47600.00
0005434822849	9888	Comfort	47600.00
0005435373382	9888	Comfort	47600.00
0005435373391	9888	Comfort	47600.00
0005435299787	9888	Comfort	47600.00
0005434558218	9888	Comfort	47600.00
0005434822998	9888	Comfort	47600.00
0005435373370	9888	Comfort	47600.00
0005435373414	9888	Comfort	47600.00
0005435373401	9888	Comfort	47600.00
0005435373413	9888	Comfort	47600.00
0005434822538	9888	Comfort	47600.00
0005434822791	9888	Comfort	47600.00
0005434822546	9888	Comfort	47600.00
0005435373365	9888	Comfort	47600.00
0005434822480	9888	Comfort	47600.00
0005434822996	9888	Comfort	47600.00
0005434823278	9888	Comfort	47600.00
0005434558197	9888	Comfort	47600.00
0005435373426	9888	Comfort	47600.00
0005434822020	9888	Comfort	47600.00
0005435179396	9888	Comfort	47600.00
0005435302207	9888	Comfort	47600.00
0005434823202	9888	Comfort	47600.00
0005435373375	9888	Economy	28000.00
0005434822888	9888	Economy	28000.00
0005435386583	9888	Economy	28000.00
0005435302206	9888	Economy	28000.00
0005434558186	9888	Economy	28000.00
0005434822765	9888	Economy	28000.00
0005434664941	9888	Economy	28000.00
0005435373427	9888	Economy	28000.00
0005434822792	9888	Economy	28000.00
0005435386580	9888	Economy	28000.00
0005434822616	9888	Economy	28000.00
0005435373412	9888	Economy	28000.00
0005434822693	9888	Economy	28000.00
0005434822506	9888	Economy	28000.00
0005434822733	9888	Economy	28000.00
0005434822899	9888	Economy	28000.00
0005434558212	9888	Economy	28000.00
0005434822755	9888	Economy	28000.00
0005434822390	9888	Economy	28000.00
0005434822991	9888	Economy	28000.00
0005435302209	9888	Economy	28000.00
0005434823141	9888	Economy	28000.00
0005434822623	9888	Economy	28000.00
0005435373386	9888	Economy	28000.00
0005435373407	9888	Economy	28000.00
0005435373393	9888	Economy	28000.00
0005435373387	9888	Economy	28000.00
0005434822293	9888	Economy	28000.00
0005434822843	9888	Economy	28000.00
0005435373420	9888	Economy	28000.00
0005435386586	9888	Economy	28000.00
0005434821587	9888	Economy	28000.00
0005435149971	9888	Economy	28000.00
0005434822764	9888	Economy	28000.00
0005435373400	9888	Economy	28000.00
0005434822117	9888	Economy	28000.00
0005434558213	9888	Economy	28000.00
0005435373368	9888	Economy	28000.00
0005434822244	9888	Economy	28000.00
0005435149909	9888	Economy	28000.00
0005434822473	9888	Economy	28000.00
0005434822786	9888	Economy	28000.00
0005434822862	9888	Economy	28000.00
0005434823041	9888	Economy	28000.00
0005434822797	9888	Economy	28000.00
0005435373421	9888	Economy	28000.00
0005434821973	9888	Economy	28000.00
0005434822822	9888	Economy	28000.00
0005434831093	9888	Economy	28000.00
0005435302208	9888	Economy	30800.00
0005434822502	9888	Economy	28000.00
0005434822916	9888	Economy	30800.00
0005432203078	9888	Economy	28000.00
0005434822321	9888	Economy	28000.00
0005434822953	9888	Economy	30800.00
0005434823186	9888	Economy	28000.00
0005434822848	9888	Economy	28000.00
0005432203080	9888	Economy	28000.00
0005434823234	9888	Economy	28000.00
0005434822821	9888	Economy	28000.00
0005434558216	9888	Economy	28000.00
0005434822545	9888	Economy	28000.00
0005435373374	9888	Economy	28000.00
0005432396202	9888	Economy	28000.00
0005435373389	9888	Economy	28000.00
0005435373419	9888	Economy	28000.00
0005434823198	9888	Economy	28000.00
0005435373415	9888	Economy	28000.00
0005435373379	9888	Economy	28000.00
0005434822498	9888	Economy	28000.00
0005435373390	9888	Economy	28000.00
0005434822307	9888	Economy	28000.00
0005434822192	9888	Economy	28000.00
0005434822021	9888	Economy	28000.00
0005435373373	9888	Economy	28000.00
0005434823168	9888	Economy	28000.00
0005434558175	9888	Economy	28000.00
0005434822517	9888	Economy	28000.00
0005434558217	9888	Economy	28000.00
0005435373417	9888	Economy	28000.00
0005434664934	9888	Economy	28000.00
0005432400108	9888	Economy	28000.00
0005434822496	9888	Economy	28000.00
0005435735145	9888	Economy	28000.00
0005435386581	9888	Economy	28000.00
0005435373367	9888	Economy	28000.00
0005435735146	9888	Economy	28000.00
0005434822753	9888	Economy	28000.00
0005434822505	9888	Economy	28000.00
0005434823280	9888	Economy	28000.00
0005432823455	9888	Economy	28000.00
0005435373404	9888	Economy	28000.00
0005434823255	9888	Economy	28000.00
0005434831097	9888	Economy	28000.00
0005434822915	9888	Economy	28000.00
0005434664947	9888	Economy	28000.00
0005435373378	9888	Economy	28000.00
0005434822412	9888	Economy	28000.00
0005432203079	9888	Economy	28000.00
0005435373422	9888	Economy	28000.00
0005434664945	9888	Economy	28000.00
0005435373416	9888	Economy	28000.00
0005434822554	9888	Economy	28000.00
0005434822584	9888	Economy	28000.00
0005434821996	9888	Economy	28000.00
0005434822984	9888	Economy	28000.00
0005435373371	9888	Economy	28000.00
0005434822873	9888	Economy	28000.00
0005434822643	9888	Economy	28000.00
0005434822724	9888	Economy	28000.00
0005434822516	9888	Economy	28000.00
0005435373361	9888	Economy	28000.00
0005435299783	9888	Economy	28000.00
0005435373411	9888	Economy	28000.00
0005435373408	9888	Economy	28000.00
0005434822403	9888	Economy	28000.00
0005434822864	9888	Economy	28000.00
0005435299786	9888	Economy	28000.00
0005434823096	9888	Economy	28000.00
0005434828667	9888	Economy	28000.00
0005435373363	9888	Economy	28000.00
0005435735144	9888	Economy	28000.00
0005434822466	9888	Economy	28000.00
0005434822707	9888	Economy	28000.00
0005435149853	9888	Economy	28000.00
0005434822905	9888	Economy	28000.00
0005435373395	9888	Economy	28000.00
0005434664946	9888	Economy	28000.00
0005434822555	9888	Economy	28000.00
0005432400092	9888	Economy	28000.00
0005434822766	9888	Economy	28000.00
0005434558191	9888	Economy	28000.00
0005435149906	9888	Economy	28000.00
0005434822191	9888	Economy	28000.00
0005434822295	9888	Economy	28000.00
0005435373380	9888	Economy	28000.00
0005434822134	9888	Economy	28000.00
0005434822356	9888	Economy	28000.00
0005434822221	9888	Economy	30800.00
0005435373423	9888	Economy	30800.00
0005434822914	9888	Economy	28000.00
0005435373372	9888	Economy	28000.00
0005434823299	9888	Economy	28000.00
0005435373385	9888	Economy	28000.00
0005434822874	9888	Economy	28000.00
0005435373381	9888	Economy	28000.00
0005434823266	9888	Economy	28000.00
0005435373398	9888	Economy	28000.00
0005435661936	9888	Economy	28000.00
0005434823148	9888	Economy	28000.00
0005435373362	9888	Economy	28000.00
0005434664944	9888	Economy	28000.00
0005434821997	9888	Economy	28000.00
0005435386579	9888	Economy	28000.00
0005435149962	9888	Economy	28000.00
0005434822274	9888	Economy	28000.00
0005434822700	9888	Economy	28000.00
0005435373425	9888	Economy	28000.00
0005434822481	9888	Economy	28000.00
0005435373409	9888	Economy	28000.00
0005435373383	9888	Economy	28000.00
0005434823229	9888	Economy	28000.00
0005434822585	9888	Economy	28000.00
0005434823146	9888	Economy	28000.00
0005435373410	9888	Economy	28000.00
0005434823254	9888	Economy	28000.00
0005435179696	9888	Economy	28000.00
0005434822756	9888	Economy	28000.00
0005432396203	9888	Economy	28000.00
0005435373366	9888	Economy	28000.00
0005434822220	9888	Economy	28000.00
0005434822674	9888	Economy	28000.00
0005435299784	9888	Economy	28000.00
0005434822639	9888	Economy	28000.00
0005435386582	9888	Economy	28000.00
0005434822472	9888	Economy	28000.00
0005435661938	9888	Economy	28000.00
0005434822842	9888	Economy	28000.00
0005432203077	9888	Economy	28000.00
0005435373369	9888	Economy	28000.00
0005434831114	9888	Economy	28000.00
0005434831133	9888	Economy	28000.00
0005435373394	9888	Economy	28000.00
0005435179395	9888	Economy	28000.00
0005434822694	9888	Economy	28000.00
0005435299785	9888	Economy	28000.00
0005434822871	9888	Economy	28000.00
0005432203074	9888	Economy	28000.00
0005434831116	9888	Economy	28000.00
0005434558200	9888	Economy	28000.00
0005435373364	9888	Economy	28000.00
0005434822599	9888	Economy	28000.00
0005432396211	9888	Economy	28000.00
0005435373402	9888	Economy	28000.00
0005435373376	9888	Economy	28000.00
0005434822467	9888	Economy	28000.00
0005435373403	9888	Economy	28000.00
0005434822128	9888	Economy	28000.00
0005434823045	9888	Economy	28000.00
0005434822830	9888	Economy	28000.00
0005435373418	9888	Economy	28000.00
0005434558211	9888	Economy	28000.00
0005432203076	9888	Economy	28000.00
0005434822877	9888	Economy	28000.00
0005432203081	9888	Economy	28000.00
0005434822812	9888	Economy	28000.00
0005435149910	9888	Economy	28000.00
0005435373405	9888	Economy	28000.00
0005434822863	9888	Economy	28000.00
0005435386584	9888	Economy	28000.00
0005434822275	9888	Economy	28000.00
0005434822489	9888	Economy	28000.00
0005434822934	9888	Economy	28000.00
0005434822844	9888	Economy	28000.00
0005434823097	9888	Economy	28000.00
0005435302205	9888	Economy	28000.00
0005434822421	9888	Economy	28000.00
0005435373388	9888	Economy	28000.00
0005434822810	9888	Economy	28000.00
0005434823171	9888	Economy	28000.00
0005435373384	9888	Economy	28000.00
0005434822294	9888	Economy	28000.00
0005434822732	9888	Economy	28000.00
0005434823235	9888	Economy	28000.00
0005435735147	9888	Economy	28000.00
0005434822190	9888	Economy	28000.00
0005435082798	7002	Economy	7400.00
0005435082801	7002	Economy	7400.00
0005435082800	7002	Economy	7400.00
0005435790312	7002	Economy	7400.00
0005435082802	7002	Economy	7400.00
0005435790311	7002	Economy	7400.00
0005435790314	7002	Economy	7400.00
0005435082795	7002	Economy	7400.00
0005435082796	7002	Economy	7400.00
0005435082803	7002	Economy	7400.00
0005435082799	7002	Economy	7400.00
0005435790313	7002	Economy	7400.00
0005435082797	7002	Economy	7400.00
0005435082744	26018	Economy	7400.00
0005435082725	26018	Economy	7400.00
0005435790281	26018	Economy	7400.00
0005435082729	26018	Economy	7400.00
0005435082719	26018	Economy	7400.00
0005435082750	26018	Economy	7400.00
0005435790287	26018	Economy	7400.00
0005435082710	26018	Economy	7400.00
0005435082749	26018	Economy	7400.00
0005435082733	26018	Economy	7400.00
0005435790294	26018	Economy	7400.00
0005435790288	26018	Economy	7400.00
0005435082748	26018	Economy	7400.00
0005435082732	26018	Economy	7400.00
0005434214335	9564	Business	32800.00
0005434214358	9564	Business	32800.00
0005434214349	9564	Business	32800.00
0005434214030	9564	Business	32800.00
0005434756499	9564	Business	32800.00
0005434756480	9564	Business	32800.00
0005434756485	9564	Business	32800.00
0005434214072	9564	Business	32800.00
0005434214235	9564	Economy	10900.00
0005434214041	9564	Economy	10900.00
0005434756498	9564	Economy	10900.00
0005434214097	9564	Economy	10900.00
0005434756490	9564	Economy	10900.00
0005434756492	9564	Economy	10900.00
0005434756491	9564	Economy	12000.00
0005434756509	9564	Economy	12000.00
0005434214130	9564	Economy	10900.00
0005434756508	9564	Economy	10900.00
0005434756504	9564	Economy	10900.00
0005434756489	9564	Economy	10900.00
0005434756478	9564	Economy	10900.00
0005434756483	9564	Economy	10900.00
0005434756507	9564	Economy	10900.00
0005434214299	9564	Economy	10900.00
0005434214272	9564	Economy	10900.00
0005434756484	9564	Economy	10900.00
0005434214119	9564	Economy	10900.00
0005434756511	9564	Economy	10900.00
0005434214068	9564	Economy	10900.00
0005434214096	9564	Economy	10900.00
0005434214236	9564	Economy	10900.00
0005434214192	9564	Economy	10900.00
0005434756488	9564	Economy	10900.00
0005434756486	9564	Economy	10900.00
0005434756474	9564	Economy	10900.00
0005434756476	9564	Economy	10900.00
0005434756514	9564	Economy	10900.00
0005434756500	9564	Economy	10900.00
0005434214189	9564	Economy	10900.00
0005434756495	9564	Economy	10900.00
0005434756512	9564	Economy	10900.00
0005434756505	9564	Economy	10900.00
0005434214054	9564	Economy	10900.00
0005434756506	9564	Economy	10900.00
0005434756482	9564	Economy	10900.00
0005434214291	9564	Economy	10900.00
0005434756470	9564	Economy	10900.00
0005434756479	9564	Economy	10900.00
0005434756502	9564	Economy	10900.00
0005434214069	9564	Economy	10900.00
0005434214187	9564	Economy	10900.00
0005434756503	9564	Economy	10900.00
0005434214271	9564	Economy	10900.00
0005434756494	9564	Economy	10900.00
0005434756477	9564	Economy	10900.00
0005434756472	9564	Economy	10900.00
0005434756473	9564	Economy	10900.00
0005434214254	9564	Economy	10900.00
0005434756513	9564	Economy	10900.00
0005434756496	9564	Economy	10900.00
0005434214066	9564	Economy	10900.00
0005434756497	9564	Economy	10900.00
0005434756493	9564	Economy	10900.00
0005434756487	9564	Economy	10900.00
0005434756481	9564	Economy	10900.00
0005434756510	9564	Economy	10900.00
0005434214237	9564	Economy	10900.00
0005434214188	9564	Economy	10900.00
0005434756501	9564	Economy	10900.00
0005434756475	9564	Economy	10900.00
0005434756471	9564	Economy	10900.00
0005434214243	9564	Economy	10900.00
0005434214586	28613	Business	32800.00
0005434214599	28613	Business	32800.00
0005434756055	28613	Business	32800.00
0005434756106	28613	Business	32800.00
0005434214560	28613	Business	32800.00
0005434214562	28613	Business	32800.00
0005434756174	28613	Business	32800.00
0005434214566	28613	Business	32800.00
0005434755835	28613	Business	32800.00
0005434214585	28613	Business	32800.00
0005434756025	28613	Economy	10900.00
0005434214590	28613	Economy	10900.00
0005434214558	28613	Economy	10900.00
0005434755993	28613	Economy	10900.00
0005434756109	28613	Economy	10900.00
0005434756184	28613	Economy	10900.00
0005434214576	28613	Economy	10900.00
0005434214577	28613	Economy	10900.00
0005434756128	28613	Economy	10900.00
0005434214572	28613	Economy	10900.00
0005434214559	28613	Economy	12000.00
0005434214601	28613	Economy	12000.00
0005434756111	28613	Economy	12000.00
0005434756057	28613	Economy	12000.00
0005434756158	28613	Economy	10900.00
0005434756110	28613	Economy	10900.00
0005434756039	28613	Economy	10900.00
0005434756024	28613	Economy	10900.00
0005434214582	28613	Economy	10900.00
0005434214568	28613	Economy	10900.00
0005434756054	28613	Economy	10900.00
0005434756136	28613	Economy	10900.00
0005434214570	28613	Economy	10900.00
0005434756264	28613	Economy	10900.00
0005434214567	28613	Economy	10900.00
0005434755916	28613	Economy	10900.00
0005434756007	28613	Economy	10900.00
0005434756053	28613	Economy	10900.00
0005434214583	28613	Economy	10900.00
0005434756067	28613	Economy	10900.00
0005434214561	28613	Economy	10900.00
0005434214581	28613	Economy	10900.00
0005434214557	28613	Economy	10900.00
0005434756129	28613	Economy	10900.00
0005434214593	28613	Economy	10900.00
0005434214579	28613	Economy	10900.00
0005434756164	28613	Economy	10900.00
0005434214596	28613	Economy	10900.00
0005434756185	28613	Economy	10900.00
0005434756068	28613	Economy	10900.00
0005434214564	28613	Economy	10900.00
0005434756134	28613	Economy	10900.00
0005434214588	28613	Economy	10900.00
0005434755913	28613	Economy	10900.00
0005434756097	28613	Economy	10900.00
0005434756038	28613	Economy	10900.00
0005434756170	28613	Economy	10900.00
0005434214600	28613	Economy	10900.00
0005434756103	28613	Economy	10900.00
0005434214594	28613	Economy	10900.00
0005434756026	28613	Economy	10900.00
0005434214573	28613	Economy	10900.00
0005434756003	28613	Economy	10900.00
0005434756056	28613	Economy	10900.00
0005434756146	28613	Economy	10900.00
0005434214597	28613	Economy	10900.00
0005434214592	28613	Economy	10900.00
0005434214591	28613	Economy	10900.00
0005434214571	28613	Economy	10900.00
0005434214598	28613	Economy	10900.00
0005434214580	28613	Economy	10900.00
0005434756010	28613	Economy	10900.00
0005434214584	28613	Economy	10900.00
0005434756211	28613	Economy	10900.00
0005434214595	28613	Economy	10900.00
0005434214589	28613	Economy	10900.00
0005434214565	28613	Economy	10900.00
0005434756168	28613	Economy	10900.00
0005434756047	28613	Economy	10900.00
0005434756087	28613	Economy	10900.00
0005434756009	28613	Economy	10900.00
0005434756227	28613	Economy	10900.00
0005434756163	28613	Economy	10900.00
0005434214587	28613	Economy	10900.00
0005434214569	28613	Economy	10900.00
0005434214574	28613	Economy	10900.00
0005434214575	28613	Economy	10900.00
0005434756159	28613	Economy	10900.00
0005434756112	28613	Economy	10900.00
0005434214563	28613	Economy	10900.00
0005434214578	28613	Economy	10900.00
0005435100130	10822	Economy	9800.00
0005435100129	10822	Economy	8900.00
0005435100128	10822	Economy	8900.00
0005434760203	31837	Economy	8900.00
0005435100116	31837	Economy	8900.00
0005435100095	31837	Economy	8900.00
0005434760202	31837	Economy	8900.00
0005434639384	1980	Economy	20900.00
0005434639389	1980	Economy	20900.00
0005433202259	1980	Economy	20900.00
0005434639369	1980	Economy	19000.00
0005432290640	1980	Economy	19000.00
0005434639386	1980	Economy	19000.00
0005434639382	1980	Economy	19000.00
0005434639371	1980	Economy	19000.00
0005433202325	1980	Economy	19000.00
0005434639378	1980	Economy	19000.00
0005434639390	1980	Economy	19000.00
0005433202324	1980	Economy	19000.00
0005434639379	1980	Economy	19000.00
0005433202283	1980	Economy	19000.00
0005434639380	1980	Economy	19000.00
0005434639375	1980	Economy	19000.00
0005434639373	1980	Economy	19000.00
0005434639367	1980	Economy	19000.00
0005433202278	1980	Economy	19000.00
0005433202229	1980	Economy	19000.00
0005434639370	1980	Economy	19000.00
0005432290641	1980	Economy	19000.00
0005434639383	1980	Economy	19000.00
0005434639388	1980	Economy	19000.00
0005434639385	1980	Economy	19000.00
0005435948329	1980	Economy	19000.00
0005434639392	1980	Economy	19000.00
0005433202279	1980	Economy	19000.00
0005432290642	1980	Economy	19000.00
0005434639387	1980	Economy	19000.00
0005434639391	1980	Economy	19000.00
0005434639393	1980	Economy	19000.00
0005434639377	1980	Economy	19000.00
0005434639374	1980	Economy	19000.00
0005433202195	1980	Economy	19000.00
0005434639381	1980	Economy	19000.00
0005434639376	1980	Economy	19000.00
0005434639368	1980	Economy	19000.00
0005434639372	1980	Economy	19000.00
0005432290639	1980	Economy	19000.00
0005433202387	23286	Economy	20900.00
0005434639051	23286	Economy	20900.00
0005434639121	23286	Economy	20900.00
0005434639285	23286	Economy	20900.00
0005434639195	23286	Economy	19000.00
0005433202376	23286	Economy	19000.00
0005433202377	23286	Economy	19000.00
0005434639212	23286	Economy	19000.00
0005434639208	23286	Economy	19000.00
0005434639179	23286	Economy	19000.00
0005434639139	23286	Economy	19000.00
0005433202382	23286	Economy	19000.00
0005434639053	23286	Economy	19000.00
0005434639070	23286	Economy	19000.00
0005434639054	23286	Economy	19000.00
0005435948318	23286	Economy	19000.00
0005434639093	23286	Economy	19000.00
0005434639147	23286	Economy	19000.00
0005434639176	23286	Economy	19000.00
0005433202383	23286	Economy	19000.00
0005433202381	23286	Economy	19000.00
0005434639207	23286	Economy	19000.00
0005434639180	23286	Economy	19000.00
0005434639197	23286	Economy	19000.00
0005433202385	23286	Economy	19000.00
0005433202386	23286	Economy	19000.00
0005434639090	23286	Economy	19000.00
0005433202374	23286	Economy	19000.00
0005433202378	23286	Economy	19000.00
0005434639124	23286	Economy	19000.00
0005433202388	23286	Economy	19000.00
0005434639094	23286	Economy	19000.00
0005434639284	23286	Economy	19000.00
0005434639058	23286	Economy	19000.00
0005433202379	23286	Economy	19000.00
0005434639129	23286	Economy	19000.00
0005434638969	23286	Economy	19000.00
0005434639181	23286	Economy	19000.00
0005433202375	23286	Economy	19000.00
0005433202380	23286	Economy	19000.00
0005433202384	23286	Economy	19000.00
0005434639140	23286	Economy	19000.00
0005435948319	23286	Economy	19000.00
0005434639142	23286	Economy	19000.00
0005435326664	6069	Business	69700.00
0005434600859	6069	Business	69700.00
0005433533314	6069	Business	69700.00
0005434600864	6069	Business	69700.00
0005435326636	6069	Business	69700.00
0005434600862	6069	Business	69700.00
0005433531301	6069	Economy	23200.00
0005432111286	6069	Economy	23200.00
0005434600856	6069	Economy	23200.00
0005434600871	6069	Economy	23200.00
0005435326679	6069	Economy	23200.00
0005435326604	6069	Economy	23200.00
0005433531302	6069	Economy	23200.00
0005435326680	6069	Economy	25600.00
0005434600861	6069	Economy	25600.00
0005434600852	6069	Economy	25600.00
0005434600860	6069	Economy	25600.00
0005432111285	6069	Economy	23200.00
0005435326643	6069	Economy	23200.00
0005434600854	6069	Economy	23200.00
0005435326655	6069	Economy	23200.00
0005435326675	6069	Economy	23200.00
0005435326642	6069	Economy	23200.00
0005433533315	6069	Economy	23200.00
0005434600872	6069	Economy	23200.00
0005434600877	6069	Economy	23200.00
0005434600851	6069	Economy	23200.00
0005434600873	6069	Economy	23200.00
0005435326668	6069	Economy	23200.00
0005435326667	6069	Economy	23200.00
0005432111284	6069	Economy	23200.00
0005434600868	6069	Economy	23200.00
0005434600855	6069	Economy	23200.00
0005434600869	6069	Economy	23200.00
0005435326640	6069	Economy	23200.00
0005434600858	6069	Economy	23200.00
0005434600866	6069	Economy	23200.00
0005433533316	6069	Economy	23200.00
0005434600870	6069	Economy	23200.00
0005434600867	6069	Economy	23200.00
0005435326641	6069	Economy	23200.00
0005434600853	6069	Economy	23200.00
0005434600874	6069	Economy	23200.00
0005435326656	6069	Economy	23200.00
0005435326658	6069	Economy	23200.00
0005433531303	6069	Economy	23200.00
0005435326647	6069	Economy	23200.00
0005435326637	6069	Economy	23200.00
0005434600863	6069	Economy	23200.00
0005435326666	6069	Economy	23200.00
0005434600865	6069	Economy	23200.00
0005434600857	6069	Economy	23200.00
0005435326676	6069	Economy	23200.00
0005434600876	6069	Economy	23200.00
0005433533317	6069	Economy	23200.00
0005434600875	6069	Economy	23200.00
0005433527225	18573	Business	69700.00
0005434600645	18573	Business	69700.00
0005435326768	18573	Business	69700.00
0005434600652	18573	Business	69700.00
0005434600674	18573	Business	69700.00
0005434600575	18573	Business	69700.00
0005435326770	18573	Business	69700.00
0005434600609	18573	Business	69700.00
0005433531263	18573	Economy	23200.00
0005434600610	18573	Economy	23200.00
0005433531269	18573	Economy	23200.00
0005433531252	18573	Economy	23200.00
0005433531270	18573	Economy	23200.00
0005434600521	18573	Economy	23200.00
0005434600608	18573	Economy	23200.00
0005435326775	18573	Economy	25600.00
0005434600706	18573	Economy	25600.00
0005434600625	18573	Economy	23200.00
0005433531274	18573	Economy	23200.00
0005434600584	18573	Economy	23200.00
0005434600705	18573	Economy	23200.00
0005434600605	18573	Economy	23200.00
0005434600604	18573	Economy	23200.00
0005433531264	18573	Economy	23200.00
0005435326772	18573	Economy	23200.00
0005433527223	18573	Economy	23200.00
0005435326776	18573	Economy	23200.00
0005435326766	18573	Economy	23200.00
0005434600653	18573	Economy	23200.00
0005433531255	18573	Economy	23200.00
0005435326771	18573	Economy	23200.00
0005434600558	18573	Economy	23200.00
0005434600542	18573	Economy	23200.00
0005434600564	18573	Economy	23200.00
0005435326769	18573	Economy	23200.00
0005435326773	18573	Economy	23200.00
0005434600716	18573	Economy	23200.00
0005435326778	18573	Economy	23200.00
0005434600643	18573	Economy	23200.00
0005435326780	18573	Economy	23200.00
0005434600630	18573	Economy	23200.00
0005434600541	18573	Economy	23200.00
0005434600606	18573	Economy	23200.00
0005435326774	18573	Economy	23200.00
0005433531253	18573	Economy	23200.00
0005435326777	18573	Economy	23200.00
0005433527224	18573	Economy	23200.00
0005435326779	18573	Economy	23200.00
0005434600512	18573	Economy	23200.00
0005434600524	18573	Economy	23200.00
0005433527222	18573	Economy	23200.00
0005433527216	18573	Economy	23200.00
0005433531256	18573	Economy	23200.00
0005435326767	18573	Economy	23200.00
0005433531254	18573	Economy	23200.00
0005434600607	18573	Economy	23200.00
0005434551297	10635	Business	9100.00
0005434551288	10635	Business	9100.00
0005434551272	10635	Business	9100.00
0005433180957	10635	Business	9100.00
0005434558284	10635	Business	9100.00
0005434551308	10635	Business	9100.00
0005434551291	10635	Business	9100.00
0005433180926	10635	Business	9100.00
0005434551311	10635	Business	9100.00
0005434551278	10635	Business	9100.00
0005434551280	10635	Business	9100.00
0005434551305	10635	Economy	3000.00
0005434551313	10635	Economy	3000.00
0005433180879	10635	Economy	3000.00
0005434558286	10635	Economy	3000.00
0005433180909	10635	Economy	3000.00
0005434551294	10635	Economy	3000.00
0005434558282	10635	Economy	3000.00
0005434551317	10635	Economy	3000.00
0005434551269	10635	Economy	3000.00
0005434551315	10635	Economy	3000.00
0005434558287	10635	Economy	3300.00
0005434558283	10635	Economy	3300.00
0005434551289	10635	Economy	3300.00
0005434551304	10635	Economy	3300.00
0005434551279	10635	Economy	3300.00
0005433180802	10635	Economy	3000.00
0005434551283	10635	Economy	3000.00
0005434551282	10635	Economy	3000.00
0005433180745	10635	Economy	3000.00
0005434551303	10635	Economy	3000.00
0005434551292	10635	Economy	3000.00
0005434551285	10635	Economy	3000.00
0005434551319	10635	Economy	3000.00
0005434551306	10635	Economy	3000.00
0005434551323	10635	Economy	3000.00
0005433180776	10635	Economy	3000.00
0005433180744	10635	Economy	3000.00
0005434551300	10635	Economy	3000.00
0005434551268	10635	Economy	3000.00
0005434551277	10635	Economy	3000.00
0005434551281	10635	Economy	3000.00
0005434551276	10635	Economy	3000.00
0005434551321	10635	Economy	3000.00
0005433180888	10635	Economy	3000.00
0005434554069	10635	Economy	3000.00
0005434551314	10635	Economy	3000.00
0005433180848	10635	Economy	3000.00
0005433180987	10635	Economy	3000.00
0005434551275	10635	Economy	3000.00
0005433180903	10635	Economy	3000.00
0005433180887	10635	Economy	3000.00
0005434558281	10635	Economy	3000.00
0005434551310	10635	Economy	3000.00
0005434551273	10635	Economy	3000.00
0005434551307	10635	Economy	3000.00
0005434551318	10635	Economy	3000.00
0005433180947	10635	Economy	3000.00
0005434551274	10635	Economy	3000.00
0005434551287	10635	Economy	3000.00
0005433180944	10635	Economy	3000.00
0005433180980	10635	Economy	3000.00
0005434551302	10635	Economy	3000.00
0005434551301	10635	Economy	3000.00
0005433180866	10635	Economy	3000.00
0005434551298	10635	Economy	3000.00
0005434551296	10635	Economy	3000.00
0005433180919	10635	Economy	3000.00
0005434551309	10635	Economy	3000.00
0005434551299	10635	Economy	3000.00
0005434551320	10635	Economy	3000.00
0005434558285	10635	Economy	3000.00
0005433180904	10635	Economy	3000.00
0005433180961	10635	Economy	3000.00
0005434551293	10635	Economy	3000.00
0005434551295	10635	Economy	3000.00
0005434551270	10635	Economy	3000.00
0005434551316	10635	Economy	3000.00
0005434551284	10635	Economy	3000.00
0005433180956	10635	Economy	3000.00
0005434551290	10635	Economy	3000.00
0005434554068	10635	Economy	3000.00
0005434558288	10635	Economy	3000.00
0005433180942	10635	Economy	3000.00
0005434551322	10635	Economy	3000.00
0005434551286	10635	Economy	3000.00
0005434551271	10635	Economy	3000.00
0005434551312	10635	Economy	3000.00
0005433180902	10635	Economy	3000.00
0005433181146	27778	Business	9100.00
0005433181161	27778	Business	9100.00
0005433181140	27778	Business	9100.00
0005433181153	27778	Business	9100.00
0005433181160	27778	Business	9100.00
0005433181158	27778	Business	9100.00
0005433181144	27778	Economy	3000.00
0005433181148	27778	Economy	3000.00
0005433181154	27778	Economy	3300.00
0005433181156	27778	Economy	3000.00
0005433181149	27778	Economy	3000.00
0005433181143	27778	Economy	3000.00
0005433181159	27778	Economy	3000.00
0005433181162	27778	Economy	3000.00
0005433181147	27778	Economy	3000.00
0005433181163	27778	Economy	3000.00
0005433181155	27778	Economy	3000.00
0005433181152	27778	Economy	3000.00
0005433181151	27778	Economy	3000.00
0005433181145	27778	Economy	3000.00
0005433181164	27778	Economy	3000.00
0005433181157	27778	Economy	3000.00
0005433181139	27778	Economy	3000.00
0005433181141	27778	Economy	3000.00
0005433181142	27778	Economy	3000.00
0005433181150	27778	Economy	3000.00
0005434550871	27777	Business	9100.00
0005434551061	27777	Business	9100.00
0005434550686	27777	Business	9100.00
0005434550830	27777	Business	9100.00
0005434550814	27777	Business	9100.00
0005434550883	27777	Business	9100.00
0005434551004	27777	Business	9100.00
0005434550896	27777	Business	9100.00
0005434550960	27777	Business	9100.00
0005434550792	27777	Business	9100.00
0005434550835	27777	Business	9100.00
0005434551100	27777	Economy	3000.00
0005434558222	27777	Economy	3000.00
0005434558225	27777	Economy	3000.00
0005434551016	27777	Economy	3000.00
0005434551081	27777	Economy	3000.00
0005434554042	27777	Economy	3000.00
0005434551041	27777	Economy	3000.00
0005434550793	27777	Economy	3300.00
0005434550965	27777	Economy	3300.00
0005434551020	27777	Economy	3300.00
0005434550644	27777	Economy	3000.00
0005434550944	27777	Economy	3000.00
0005434550714	27777	Economy	3000.00
0005434550634	27777	Economy	3000.00
0005434551062	27777	Economy	3000.00
0005434558220	27777	Economy	3000.00
0005434550807	27777	Economy	3000.00
0005434550961	27777	Economy	3000.00
0005434550870	27777	Economy	3000.00
0005434550891	27777	Economy	3000.00
0005434550748	27777	Economy	3000.00
0005434550761	27777	Economy	3000.00
0005434550687	27777	Economy	3000.00
0005434550831	27777	Economy	3000.00
0005434550889	27777	Economy	3000.00
0005434550997	27777	Economy	3000.00
0005434550734	27777	Economy	3000.00
0005434550959	27777	Economy	3000.00
0005434551118	27777	Economy	3000.00
0005434550839	27777	Economy	3000.00
0005434558226	27777	Economy	3000.00
0005434550876	27777	Economy	3000.00
0005434550850	27777	Economy	3000.00
0005434550777	27777	Economy	3000.00
0005434551082	27777	Economy	3000.00
0005434554044	27777	Economy	3000.00
0005434550833	27777	Economy	3000.00
0005434551015	27777	Economy	3000.00
0005434550829	27777	Economy	3000.00
0005434550958	27777	Economy	3000.00
0005434550743	27777	Economy	3000.00
0005434551005	27777	Economy	3000.00
0005434550762	27777	Economy	3000.00
0005434550898	27777	Economy	3000.00
0005434550882	27777	Economy	3000.00
0005434550897	27777	Economy	3000.00
0005434554049	27777	Economy	3000.00
0005434550832	27777	Economy	3000.00
0005434550834	27777	Economy	3000.00
0005434550947	27777	Economy	3000.00
0005434551072	27777	Economy	3000.00
0005434550742	27777	Economy	3000.00
0005434558219	27777	Economy	3000.00
0005434550996	27777	Economy	3000.00
0005434550913	27777	Economy	3000.00
0005434550749	27777	Economy	3000.00
0005434558221	27777	Economy	3000.00
0005434554043	27777	Economy	3000.00
0005433459228	6117	Economy	11700.00
0005435254457	6117	Economy	11700.00
0005435254453	6117	Economy	11700.00
0005435254447	6117	Economy	11700.00
0005433459229	6117	Economy	11700.00
0005433459226	6117	Economy	11700.00
0005433459227	6117	Economy	11700.00
0005435254458	6117	Economy	11700.00
0005435254480	19346	Economy	11700.00
0005435254479	19346	Economy	11700.00
0005435254482	19346	Economy	11700.00
0005435254481	19346	Economy	11700.00
0005435682199	6764	Business	51100.00
0005435437875	6764	Business	51100.00
0005435682228	6764	Business	51100.00
0005435437843	6764	Business	51100.00
0005435682218	6764	Business	51100.00
0005435682232	6764	Business	51100.00
0005432136178	6764	Business	51100.00
0005435682217	6764	Business	51100.00
0005435682237	6764	Business	51100.00
0005432533278	6764	Business	51100.00
0005435682216	6764	Economy	17000.00
0005435437797	6764	Economy	17000.00
0005435437736	6764	Economy	17000.00
0005435437786	6764	Economy	17000.00
0005435437906	6764	Economy	17000.00
0005435682205	6764	Economy	17000.00
0005432533270	6764	Economy	17000.00
0005435437787	6764	Economy	17000.00
0005435682229	6764	Economy	17000.00
0005435682240	6764	Economy	17000.00
0005435221512	6764	Economy	18700.00
0005435682233	6764	Economy	18700.00
0005435682238	6764	Economy	18700.00
0005435682203	6764	Economy	18700.00
0005435437856	6764	Economy	18700.00
0005435682206	6764	Economy	17000.00
0005432533271	6764	Economy	17000.00
0005435661935	6764	Economy	17000.00
0005432533279	6764	Economy	17000.00
0005435682231	6764	Economy	17000.00
0005435682201	6764	Economy	17000.00
0005435437798	6764	Economy	17000.00
0005435682230	6764	Economy	17000.00
0005435682227	6764	Economy	17000.00
0005435437831	6764	Economy	17000.00
0005435437859	6764	Economy	17000.00
0005435220297	6764	Economy	17000.00
0005435682215	6764	Economy	17000.00
0005432533277	6764	Economy	17000.00
0005435682204	6764	Economy	17000.00
0005435682208	6764	Economy	17000.00
0005434828668	6764	Economy	17000.00
0005432136179	6764	Economy	17000.00
0005435437898	6764	Economy	17000.00
0005435682202	6764	Economy	17000.00
0005435220298	6764	Economy	17000.00
0005435682235	6764	Economy	17000.00
0005435682226	6764	Economy	17000.00
0005435682198	6764	Economy	17000.00
0005435682221	6764	Economy	17000.00
0005435682209	6764	Economy	17000.00
0005435682200	6764	Economy	17000.00
0005435682212	6764	Economy	17000.00
0005435437848	6764	Economy	17000.00
0005435682239	6764	Economy	17000.00
0005435682236	6764	Economy	17000.00
0005435682214	6764	Economy	17000.00
0005435682211	6764	Economy	17000.00
0005432136176	6764	Economy	17000.00
0005435630969	6764	Economy	17000.00
0005432533268	6764	Economy	17000.00
0005435720135	6764	Economy	17000.00
0005432533267	6764	Economy	17000.00
0005432533269	6764	Economy	17000.00
0005435682241	6764	Economy	17000.00
0005435682223	6764	Economy	17000.00
0005435682220	6764	Economy	17000.00
0005435630971	6764	Economy	17000.00
0005435682222	6764	Economy	17000.00
0005435220299	6764	Economy	17000.00
0005435437808	6764	Economy	17000.00
0005435437796	6764	Economy	17000.00
0005435682213	6764	Economy	17000.00
0005435682234	6764	Economy	17000.00
0005435630970	6764	Economy	17000.00
0005432136177	6764	Economy	17000.00
0005435682210	6764	Economy	17000.00
0005435661934	6764	Economy	17000.00
0005435682207	6764	Economy	17000.00
0005435682224	6764	Economy	17000.00
0005435661933	6764	Economy	17000.00
0005435437849	6764	Economy	17000.00
0005435720136	6764	Economy	17000.00
0005432136180	6764	Economy	17000.00
0005435437869	6764	Economy	17000.00
0005435682225	6764	Economy	17000.00
0005435682219	6764	Economy	17000.00
0005435681818	24594	Business	51100.00
0005432533297	24594	Business	51100.00
0005435681627	24594	Business	51100.00
0005435437985	24594	Business	51100.00
0005435720819	24594	Business	51100.00
0005435437993	24594	Business	51100.00
0005435437988	24594	Business	51100.00
0005435681936	24594	Business	51100.00
0005434828703	24594	Business	51100.00
0005435681815	24594	Business	51100.00
0005435681822	24594	Economy	17000.00
0005435681954	24594	Economy	17000.00
0005435681980	24594	Economy	17000.00
0005435681814	24594	Economy	17000.00
0005435437999	24594	Economy	17000.00
0005435438000	24594	Economy	17000.00
0005435681791	24594	Economy	17000.00
0005435681982	24594	Economy	17000.00
0005435437994	24594	Economy	17000.00
0005435438003	24594	Economy	17000.00
0005432305755	24594	Economy	18700.00
0005435220322	24594	Economy	18700.00
0005435437984	24594	Economy	18700.00
0005435720818	24594	Economy	18700.00
0005435630940	24594	Economy	17000.00
0005434828702	24594	Economy	17000.00
0005435681842	24594	Economy	17000.00
0005435219201	24594	Economy	17000.00
0005432305752	24594	Economy	17000.00
0005435630935	24594	Economy	17000.00
0005435681813	24594	Economy	17000.00
0005435681911	24594	Economy	17000.00
0005435437990	24594	Economy	17000.00
0005435661906	24594	Economy	17000.00
0005435438005	24594	Economy	17000.00
0005435437995	24594	Economy	17000.00
0005435437997	24594	Economy	17000.00
0005435219204	24594	Economy	17000.00
0005435719556	24594	Economy	17000.00
0005435437991	24594	Economy	17000.00
0005435681819	24594	Economy	17000.00
0005435681674	24594	Economy	17000.00
0005435682118	24594	Economy	17000.00
0005435719557	24594	Economy	17000.00
0005432533298	24594	Economy	17000.00
0005435681785	24594	Economy	17000.00
0005435681677	24594	Economy	17000.00
0005435681957	24594	Economy	17000.00
0005435437989	24594	Economy	17000.00
0005435630939	24594	Economy	17000.00
0005435437992	24594	Economy	17000.00
0005435438004	24594	Economy	17000.00
0005434828704	24594	Economy	17000.00
0005432305754	24594	Economy	17000.00
0005435437998	24594	Economy	17000.00
0005435682117	24594	Economy	17000.00
0005435681879	24594	Economy	17000.00
0005435437996	24594	Economy	17000.00
0005435219202	24594	Economy	17000.00
0005435681845	24594	Economy	17000.00
0005435681970	24594	Economy	17000.00
0005435438001	24594	Economy	17000.00
0005435681816	24594	Economy	17000.00
0005435681958	24594	Economy	17000.00
0005435220321	24594	Economy	17000.00
0005435681786	24594	Economy	17000.00
0005435437983	24594	Economy	17000.00
0005435220320	24594	Economy	17000.00
0005435437986	24594	Economy	17000.00
0005435681796	24594	Economy	17000.00
0005435438002	24594	Economy	17000.00
0005435220323	24594	Economy	17000.00
0005435681836	24594	Economy	17000.00
0005435681881	24594	Economy	17000.00
0005435681648	24594	Economy	17000.00
0005435630936	24594	Economy	17000.00
0005435437987	24594	Economy	17000.00
0005435219203	24594	Economy	17000.00
0005435681843	24594	Economy	17000.00
0005435681978	24594	Economy	17000.00
0005435681981	24594	Economy	17000.00
0005435681812	24594	Economy	17000.00
0005432305753	24594	Economy	17000.00
0005435681820	24594	Economy	17000.00
0005435126432	11534	Business	26400.00
0005435126405	11534	Business	26400.00
0005435126424	11534	Business	26400.00
0005435126415	11534	Business	26400.00
0005435126401	11534	Business	26400.00
0005435126399	11534	Business	26400.00
0005435126430	11534	Business	26400.00
0005435126431	11534	Economy	8800.00
0005435126404	11534	Economy	8800.00
0005435126406	11534	Economy	8800.00
0005435126416	11534	Economy	8800.00
0005435126398	11534	Economy	8800.00
0005435126421	11534	Economy	9700.00
0005435105986	11534	Economy	9700.00
0005435126434	11534	Economy	8800.00
0005435126403	11534	Economy	8800.00
0005435105985	11534	Economy	8800.00
0005435126418	11534	Economy	8800.00
0005435126422	11534	Economy	8800.00
0005435126425	11534	Economy	8800.00
0005435126397	11534	Economy	8800.00
0005435126402	11534	Economy	8800.00
0005435126423	11534	Economy	8800.00
0005435126411	11534	Economy	8800.00
0005435126435	11534	Economy	8800.00
0005435126414	11534	Economy	8800.00
0005435105987	11534	Economy	8800.00
0005435126400	11534	Economy	8800.00
0005435126412	11534	Economy	8800.00
0005435126428	11534	Economy	8800.00
0005435558056	11534	Economy	8800.00
0005435126437	11534	Economy	8800.00
0005435126419	11534	Economy	8800.00
0005435126426	11534	Economy	8800.00
0005435126396	11534	Economy	8800.00
0005435126417	11534	Economy	8800.00
0005435126413	11534	Economy	8800.00
0005435105984	11534	Economy	8800.00
0005435126429	11534	Economy	8800.00
0005435126433	11534	Economy	8800.00
0005435126436	11534	Economy	8800.00
0005435126409	11534	Economy	8800.00
0005435126410	11534	Economy	8800.00
0005435126427	11534	Economy	8800.00
0005435126407	11534	Economy	8800.00
0005435126408	11534	Economy	8800.00
0005435126420	11534	Economy	8800.00
0005435126193	31905	Business	26400.00
0005435126102	31905	Business	26400.00
0005435126132	31905	Business	26400.00
0005435126227	31905	Business	26400.00
0005435126216	31905	Business	26400.00
0005435126285	31905	Economy	8800.00
0005435126226	31905	Economy	8800.00
0005435105970	31905	Economy	8800.00
0005435126196	31905	Economy	9700.00
0005435558093	31905	Economy	9700.00
0005435105969	31905	Economy	9700.00
0005435558092	31905	Economy	8800.00
0005435126029	31905	Economy	8800.00
0005435125983	31905	Economy	8800.00
0005435105968	31905	Economy	8800.00
0005435126217	31905	Economy	8800.00
0005435126082	31905	Economy	8800.00
0005435126027	31905	Economy	8800.00
0005435558091	31905	Economy	8800.00
0005435126197	31905	Economy	8800.00
0005435105962	31905	Economy	8800.00
0005435105956	31905	Economy	8800.00
0005435126225	31905	Economy	8800.00
0005435125995	31905	Economy	8800.00
0005435105954	31905	Economy	8800.00
0005435126272	31905	Economy	8800.00
0005435126039	31905	Economy	8800.00
0005435125926	31905	Economy	8800.00
0005435126118	31905	Economy	8800.00
0005435125925	31905	Economy	8800.00
0005435126195	31905	Economy	8800.00
0005435126178	31905	Economy	8800.00
0005435126119	31905	Economy	8800.00
0005435126283	31905	Economy	8800.00
0005435125984	31905	Economy	8800.00
0005435126131	31905	Economy	8800.00
0005433398162	13529	Business	36600.00
0005433398148	13529	Business	36600.00
0005433398172	13529	Business	36600.00
0005433398124	13529	Business	36600.00
0005435732198	13529	Business	36600.00
0005433398170	13529	Business	36600.00
0005435732269	13529	Economy	12200.00
0005433398144	13529	Economy	12200.00
0005433398152	13529	Economy	12200.00
0005433398158	13529	Economy	12200.00
0005433398165	13529	Economy	13400.00
0005433398128	13529	Economy	13400.00
0005433398160	13529	Economy	13400.00
0005433398156	13529	Economy	13400.00
0005433398125	13529	Economy	12200.00
0005433398127	13529	Economy	12200.00
0005433398147	13529	Economy	12200.00
0005433398130	13529	Economy	12200.00
0005433398136	13529	Economy	12200.00
0005433398166	13529	Economy	12200.00
0005433398135	13529	Economy	12200.00
0005433398173	13529	Economy	12200.00
0005435732268	13529	Economy	12200.00
0005433398164	13529	Economy	12200.00
0005435732221	13529	Economy	12200.00
0005433398163	13529	Economy	12200.00
0005433398168	13529	Economy	12200.00
0005433398132	13529	Economy	12200.00
0005433398138	13529	Economy	12200.00
0005435732254	13529	Economy	12200.00
0005433398140	13529	Economy	12200.00
0005435732246	13529	Economy	12200.00
0005433398171	13529	Economy	12200.00
0005433398167	13529	Economy	12200.00
0005433398141	13529	Economy	12200.00
0005433398145	13529	Economy	12200.00
0005433398149	13529	Economy	12200.00
0005433398142	13529	Economy	12200.00
0005433398153	13529	Economy	12200.00
0005433398150	13529	Economy	12200.00
0005433398133	13529	Economy	12200.00
0005435732267	13529	Economy	12200.00
0005433398146	13529	Economy	12200.00
0005433398169	13529	Economy	12200.00
0005433398143	13529	Economy	12200.00
0005435732240	13529	Economy	12200.00
0005433398154	13529	Economy	12200.00
0005433398151	13529	Economy	12200.00
0005433398126	13529	Economy	12200.00
0005435732234	13529	Economy	12200.00
0005433398161	13529	Economy	12200.00
0005433398155	13529	Economy	12200.00
0005435732189	13529	Economy	12200.00
0005435732199	13529	Economy	12200.00
0005435732264	13529	Economy	12200.00
0005433398134	13529	Economy	12200.00
0005433398129	13529	Economy	12200.00
0005433398139	13529	Economy	12200.00
0005435732253	13529	Economy	12200.00
0005433398131	13529	Economy	12200.00
0005433398157	13529	Economy	12200.00
0005433398159	13529	Economy	12200.00
0005433398137	13529	Economy	12200.00
0005435732355	19390	Business	36600.00
0005433397682	19390	Business	36600.00
0005435732350	19390	Business	36600.00
0005435732354	19390	Business	36600.00
0005433397724	19390	Business	36600.00
0005433397675	19390	Business	36600.00
0005435732359	19390	Economy	12200.00
0005433397674	19390	Economy	12200.00
0005433397469	19390	Economy	12200.00
0005433397924	19390	Economy	12200.00
0005433397708	19390	Economy	12200.00
0005433397789	19390	Economy	12200.00
0005433397646	19390	Economy	12200.00
0005433397753	19390	Economy	12200.00
0005435732360	19390	Economy	13400.00
0005433397862	19390	Economy	13400.00
0005435732357	19390	Economy	13400.00
0005433397923	19390	Economy	12200.00
0005433397758	19390	Economy	12200.00
0005435732351	19390	Economy	12200.00
0005433397740	19390	Economy	12200.00
0005433397752	19390	Economy	12200.00
0005433397790	19390	Economy	12200.00
0005432297281	19390	Economy	12200.00
0005435732353	19390	Economy	12200.00
0005433397697	19390	Economy	12200.00
0005433397820	19390	Economy	12200.00
0005433397635	19390	Economy	12200.00
0005433397671	19390	Economy	12200.00
0005433397896	19390	Economy	12200.00
0005433397787	19390	Economy	12200.00
0005435732348	19390	Economy	12200.00
0005435732356	19390	Economy	12200.00
0005433397694	19390	Economy	12200.00
0005433397411	19390	Economy	12200.00
0005433397742	19390	Economy	12200.00
0005435732347	19390	Economy	12200.00
0005433397672	19390	Economy	12200.00
0005433397627	19390	Economy	12200.00
0005433397578	19390	Economy	12200.00
0005432297283	19390	Economy	12200.00
0005433397759	19390	Economy	12200.00
0005433397850	19390	Economy	12200.00
0005433397685	19390	Economy	12200.00
0005433397686	19390	Economy	12200.00
0005433397732	19390	Economy	12200.00
0005433397693	19390	Economy	12200.00
0005433397762	19390	Economy	12200.00
0005435732358	19390	Economy	12200.00
0005433397760	19390	Economy	12200.00
0005433397673	19390	Economy	12200.00
0005433397944	19390	Economy	12200.00
0005433397763	19390	Economy	12200.00
0005433397648	19390	Economy	12200.00
0005435732352	19390	Economy	12200.00
0005432297282	19390	Economy	12200.00
0005433397725	19390	Economy	12200.00
0005433397647	19390	Economy	12200.00
0005433397634	19390	Economy	12200.00
0005435732349	19390	Economy	12200.00
0005433397945	19390	Economy	12200.00
0005433397389	19390	Economy	12200.00
0005433397916	19390	Economy	12200.00
0005433397741	19390	Economy	12200.00
0005433397743	19390	Economy	12200.00
0005433397963	19390	Economy	12200.00
0005433397579	19390	Economy	12200.00
0005435068803	13174	Business	11300.00
0005435068804	13174	Business	11300.00
0005435925310	13174	Business	11300.00
0005435068704	13174	Business	11300.00
0005435068707	13174	Business	11300.00
0005435068733	13174	Business	11300.00
0005435925320	13174	Economy	3800.00
0005435925309	13174	Economy	3800.00
0005435925317	13174	Economy	3800.00
0005435925311	13174	Economy	3800.00
0005435068835	13174	Economy	3800.00
0005435068466	13174	Economy	3800.00
0005435925323	13174	Economy	3800.00
0005435068859	13174	Economy	3800.00
0005435068436	13174	Economy	4100.00
0005435068736	13174	Economy	4100.00
0005435068861	13174	Economy	4100.00
0005435068802	13174	Economy	3800.00
0005435068624	13174	Economy	3800.00
0005435925314	13174	Economy	3800.00
0005435068524	13174	Economy	3800.00
0005435068567	13174	Economy	3800.00
0005435068761	13174	Economy	3800.00
0005435068641	13174	Economy	3800.00
0005435068734	13174	Economy	3800.00
0005435068614	13174	Economy	3800.00
0005435068826	13174	Economy	3800.00
0005435068789	13174	Economy	3800.00
0005435068642	13174	Economy	3800.00
0005435068540	13174	Economy	3800.00
0005435068778	13174	Economy	3800.00
0005435925319	13174	Economy	3800.00
0005435068787	13174	Economy	3800.00
0005435068626	13174	Economy	3800.00
0005435068692	13174	Economy	3800.00
0005435925308	13174	Economy	3800.00
0005435925313	13174	Economy	3800.00
0005435068688	13174	Economy	3800.00
0005435925324	13174	Economy	3800.00
0005435925321	13174	Economy	3800.00
0005435068620	13174	Economy	3800.00
0005435925316	13174	Economy	3800.00
0005435068539	13174	Economy	3800.00
0005435068597	13174	Economy	3800.00
0005435068717	13174	Economy	3800.00
0005435068784	13174	Economy	3800.00
0005435068621	13174	Economy	3800.00
0005435068846	13174	Economy	3800.00
0005435068643	13174	Economy	3800.00
0005435068592	13174	Economy	3800.00
0005435925306	13174	Economy	3800.00
0005435068619	13174	Economy	3800.00
0005435925305	13174	Economy	3800.00
0005435925307	13174	Economy	3800.00
0005435925312	13174	Economy	3800.00
0005435925315	13174	Economy	3800.00
0005435925318	13174	Economy	3800.00
0005435068737	13174	Economy	3800.00
0005435068598	13174	Economy	3800.00
0005435068725	13174	Economy	3800.00
0005435068799	13174	Economy	3800.00
0005435068770	13174	Economy	3800.00
0005435925322	13174	Economy	3800.00
0005435068712	13174	Economy	3800.00
0005435069130	15508	Business	11300.00
0005435069158	15508	Business	11300.00
0005435069134	15508	Business	11300.00
0005435069145	15508	Business	11300.00
0005435069138	15508	Business	11300.00
0005435069125	15508	Business	11300.00
0005435069142	15508	Business	11300.00
0005435069127	15508	Business	11300.00
0005435069120	15508	Business	11300.00
0005435069161	15508	Economy	3800.00
0005435069154	15508	Economy	3800.00
0005435069112	15508	Economy	3800.00
0005435069153	15508	Economy	3800.00
0005435069137	15508	Economy	3800.00
0005435069140	15508	Economy	3800.00
0005435069117	15508	Economy	4100.00
0005435069150	15508	Economy	4100.00
0005435925150	15508	Economy	4100.00
0005435069152	15508	Economy	4100.00
0005435069143	15508	Economy	3800.00
0005435069147	15508	Economy	3800.00
0005435925175	15508	Economy	3800.00
0005435069124	15508	Economy	3800.00
0005435069122	15508	Economy	3800.00
0005435069118	15508	Economy	3800.00
0005435069165	15508	Economy	3800.00
0005435069162	15508	Economy	3800.00
0005435069160	15508	Economy	3800.00
0005435069121	15508	Economy	3800.00
0005435069115	15508	Economy	3800.00
0005435925157	15508	Economy	3800.00
0005435925166	15508	Economy	3800.00
0005435069148	15508	Economy	3800.00
0005435069163	15508	Economy	3800.00
0005435069159	15508	Economy	3800.00
0005435069141	15508	Economy	3800.00
0005435069136	15508	Economy	3800.00
0005435069157	15508	Economy	3800.00
0005435069114	15508	Economy	3800.00
0005435069128	15508	Economy	3800.00
0005435925182	15508	Economy	3800.00
0005435069123	15508	Economy	3800.00
0005435069113	15508	Economy	3800.00
0005435069164	15508	Economy	3800.00
0005435069166	15508	Economy	3800.00
0005435069132	15508	Economy	3800.00
0005435925181	15508	Economy	3800.00
0005435069116	15508	Economy	3800.00
0005435069156	15508	Economy	3800.00
0005435069155	15508	Economy	3800.00
0005435069149	15508	Economy	3800.00
0005435069126	15508	Economy	3800.00
0005435069131	15508	Economy	3800.00
0005435925164	15508	Economy	3800.00
0005435925183	15508	Economy	3800.00
0005435069133	15508	Economy	3800.00
0005435069129	15508	Economy	3800.00
0005435069119	15508	Economy	3800.00
0005435925177	15508	Economy	3800.00
0005435069139	15508	Economy	3800.00
0005435925134	15508	Economy	3800.00
0005435925165	15508	Economy	3800.00
0005435069146	15508	Economy	3800.00
0005435925176	15508	Economy	3800.00
0005435069151	15508	Economy	3800.00
0005435069144	15508	Economy	3800.00
0005435069135	15508	Economy	3800.00
0005435925189	15508	Economy	3800.00
0005434756230	10711	Business	61300.00
0005434756193	10711	Business	61300.00
0005434756157	10711	Business	61300.00
0005434214649	10711	Business	61300.00
0005434756037	10711	Business	61300.00
0005434214630	10711	Business	61300.00
0005434756238	10711	Business	61300.00
0005434756135	10711	Business	61300.00
0005434756071	10711	Business	61300.00
0005434756033	10711	Business	61300.00
0005434214626	10711	Business	61300.00
0005434214607	10711	Economy	20400.00
0005434214648	10711	Economy	20400.00
0005434214610	10711	Economy	20400.00
0005434214641	10711	Economy	20400.00
0005434756044	10711	Economy	20400.00
0005434756115	10711	Economy	20400.00
0005434214640	10711	Economy	20400.00
0005434214606	10711	Economy	20400.00
0005434214612	10711	Economy	20400.00
0005434214643	10711	Economy	20400.00
0005434756197	10711	Economy	22500.00
0005434756113	10711	Economy	22500.00
0005434214633	10711	Economy	22500.00
0005434214608	10711	Economy	20400.00
0005434214632	10711	Economy	20400.00
0005434756153	10711	Economy	20400.00
0005434214639	10711	Economy	20400.00
0005434756262	10711	Economy	20400.00
0005434214604	10711	Economy	20400.00
0005434756041	10711	Economy	20400.00
0005434214603	10711	Economy	20400.00
0005434214623	10711	Economy	20400.00
0005434214613	10711	Economy	20400.00
0005434756181	10711	Economy	20400.00
0005434214609	10711	Economy	20400.00
0005434756178	10711	Economy	20400.00
0005434214617	10711	Economy	20400.00
0005434756120	10711	Economy	20400.00
0005434214636	10711	Economy	20400.00
0005434214622	10711	Economy	20400.00
0005434756002	10711	Economy	20400.00
0005434756133	10711	Economy	20400.00
0005434756045	10711	Economy	20400.00
0005434755985	10711	Economy	20400.00
0005434214629	10711	Economy	20400.00
0005434756014	10711	Economy	20400.00
0005434214605	10711	Economy	20400.00
0005434214627	10711	Economy	20400.00
0005434214614	10711	Economy	20400.00
0005434214631	10711	Economy	20400.00
0005434756229	10711	Economy	20400.00
0005434214647	10711	Economy	20400.00
0005434214620	10711	Economy	20400.00
0005434214616	10711	Economy	20400.00
0005434214644	10711	Economy	20400.00
0005434214628	10711	Economy	20400.00
0005434214621	10711	Economy	20400.00
0005434756085	10711	Economy	20400.00
0005434756228	10711	Economy	20400.00
0005434756122	10711	Economy	20400.00
0005434756046	10711	Economy	20400.00
0005434214645	10711	Economy	20400.00
0005434755908	10711	Economy	20400.00
0005434214635	10711	Economy	20400.00
0005434756022	10711	Economy	20400.00
0005434214615	10711	Economy	20400.00
0005434755928	10711	Economy	20400.00
0005434214642	10711	Economy	20400.00
0005434214638	10711	Economy	20400.00
0005434214619	10711	Economy	20400.00
0005434755907	10711	Economy	20400.00
0005434214611	10711	Economy	20400.00
0005434755927	10711	Economy	20400.00
0005434756089	10711	Economy	20400.00
0005434756011	10711	Economy	20400.00
0005434756121	10711	Economy	20400.00
0005434756180	10711	Economy	20400.00
0005434214646	10711	Economy	20400.00
0005434214624	10711	Economy	20400.00
0005434756108	10711	Economy	20400.00
0005434214637	10711	Economy	20400.00
0005434214602	10711	Economy	20400.00
0005434756237	10711	Economy	20400.00
0005434214634	10711	Economy	20400.00
0005434214625	10711	Economy	20400.00
0005434214618	10711	Economy	20400.00
0005434756105	10711	Economy	20400.00
0005434756467	28704	Business	61300.00
0005434214204	28704	Business	61300.00
0005434756464	28704	Business	61300.00
0005434214179	28704	Business	61300.00
0005434214063	28704	Business	61300.00
0005434214118	28704	Business	61300.00
0005434756453	28704	Business	61300.00
0005434213982	28704	Business	61300.00
0005434214067	28704	Business	61300.00
0005434214170	28704	Business	61300.00
0005434214167	28704	Business	61300.00
0005434756452	28704	Business	61300.00
0005434214222	28704	Economy	20400.00
0005434214012	28704	Economy	20400.00
0005434214122	28704	Economy	20400.00
0005434756462	28704	Economy	20400.00
0005434214231	28704	Economy	20400.00
0005434214193	28704	Economy	20400.00
0005434214200	28704	Economy	20400.00
0005434756468	28704	Economy	20400.00
0005434214221	28704	Economy	20400.00
0005434214099	28704	Economy	20400.00
0005434214150	28704	Economy	22500.00
0005434214232	28704	Economy	22500.00
0005434213979	28704	Economy	22500.00
0005434214310	28704	Economy	22500.00
0005434214220	28704	Economy	22500.00
0005434756469	28704	Economy	20400.00
0005434214013	28704	Economy	20400.00
0005434756450	28704	Economy	20400.00
0005434756446	28704	Economy	20400.00
0005434756465	28704	Economy	20400.00
0005434214154	28704	Economy	20400.00
0005434213933	28704	Economy	20400.00
0005434214223	28704	Economy	20400.00
0005434214126	28704	Economy	20400.00
0005434214309	28704	Economy	20400.00
0005434756449	28704	Economy	20400.00
0005434213981	28704	Economy	20400.00
0005434214121	28704	Economy	20400.00
0005434756451	28704	Economy	20400.00
0005434214089	28704	Economy	20400.00
0005434756454	28704	Economy	20400.00
0005434214171	28704	Economy	20400.00
0005434214198	28704	Economy	20400.00
0005434213847	28704	Economy	20400.00
0005434214064	28704	Economy	20400.00
0005434213961	28704	Economy	20400.00
0005434213962	28704	Economy	20400.00
0005434214194	28704	Economy	20400.00
0005434756455	28704	Economy	20400.00
0005434214312	28704	Economy	20400.00
0005434756447	28704	Economy	20400.00
0005434214280	28704	Economy	20400.00
0005434756448	28704	Economy	20400.00
0005434756458	28704	Economy	20400.00
0005434214250	28704	Economy	20400.00
0005434756460	28704	Economy	20400.00
0005434214080	28704	Economy	20400.00
0005434214195	28704	Economy	20400.00
0005434214190	28704	Economy	20400.00
0005434213934	28704	Economy	20400.00
0005434756457	28704	Economy	20400.00
0005434214153	28704	Economy	20400.00
0005434213959	28704	Economy	20400.00
0005434756461	28704	Economy	20400.00
0005434214079	28704	Economy	20400.00
0005434214234	28704	Economy	20400.00
0005434214058	28704	Economy	20400.00
0005434214125	28704	Economy	20400.00
0005434756463	28704	Economy	20400.00
0005434214281	28704	Economy	20400.00
0005434756459	28704	Economy	20400.00
0005434214247	28704	Economy	20400.00
0005434214199	28704	Economy	20400.00
0005434756466	28704	Economy	20400.00
0005434213846	28704	Economy	20400.00
0005434214182	28704	Economy	20400.00
0005434213958	28704	Economy	20400.00
0005434214233	28704	Economy	20400.00
0005434214123	28704	Economy	20400.00
0005434214245	28704	Economy	20400.00
0005434214087	28704	Economy	20400.00
0005434756456	28704	Economy	20400.00
0005434213969	28704	Economy	20400.00
0005434214197	28704	Economy	20400.00
0005434214120	28704	Economy	20400.00
0005434214027	28704	Economy	20400.00
0005434214117	28704	Economy	20400.00
0005434214086	28704	Economy	20400.00
0005435039888	5426	Business	29500.00
0005434229225	5426	Business	29500.00
0005434229226	5426	Business	29500.00
0005432125469	5426	Business	29500.00
0005435039905	5426	Business	29500.00
0005435039920	5426	Business	29500.00
0005435039921	5426	Business	29500.00
0005435039912	5426	Business	29500.00
0005434229193	5426	Business	29500.00
0005435039925	5426	Economy	9800.00
0005434229178	5426	Economy	9800.00
0005435039928	5426	Economy	9800.00
0005434229167	5426	Economy	9800.00
0005435039910	5426	Economy	9800.00
0005435039874	5426	Economy	9800.00
0005434229283	5426	Economy	9800.00
0005435007080	5426	Economy	9800.00
0005435039891	5426	Economy	9800.00
0005435039869	5426	Economy	9800.00
0005435039878	5426	Economy	9800.00
0005435039904	5426	Economy	9800.00
0005435007072	5426	Economy	9800.00
0005434229104	5426	Economy	9800.00
0005435039911	5426	Economy	9800.00
0005435039930	5426	Economy	9800.00
0005435039868	5426	Economy	9800.00
0005435039887	5426	Economy	9800.00
0005435039923	5426	Economy	9800.00
0005435039875	5426	Economy	9800.00
0005434229210	5426	Economy	9800.00
0005435039879	5426	Economy	9800.00
0005435039884	5426	Economy	9800.00
0005435039908	5426	Economy	9800.00
0005435039917	5426	Economy	9800.00
0005435007084	5426	Economy	9800.00
0005434229282	5426	Economy	9800.00
0005435007074	5426	Economy	9800.00
0005435007081	5426	Economy	9800.00
0005435039899	5426	Economy	9800.00
0005435039914	5426	Economy	9800.00
0005435039906	5426	Economy	9800.00
0005434229247	5426	Economy	9800.00
0005435039919	5426	Economy	9800.00
0005434229213	5426	Economy	10800.00
0005435039892	5426	Economy	10800.00
0005434229128	5426	Economy	10800.00
0005435039896	5426	Economy	10800.00
0005435039903	5426	Economy	10800.00
0005434229219	5426	Economy	10800.00
0005435039881	5426	Economy	9800.00
0005435007077	5426	Economy	9800.00
0005435039929	5426	Economy	9800.00
0005435039918	5426	Economy	9800.00
0005435039876	5426	Economy	9800.00
0005432125467	5426	Economy	9800.00
0005434229144	5426	Economy	9800.00
0005434229188	5426	Economy	9800.00
0005435039867	5426	Economy	9800.00
0005435039926	5426	Economy	9800.00
0005435039927	5426	Economy	9800.00
0005435039907	5426	Economy	9800.00
0005435039871	5426	Economy	9800.00
0005434229262	5426	Economy	9800.00
0005435039900	5426	Economy	9800.00
0005435039901	5426	Economy	9800.00
0005435042858	5426	Economy	9800.00
0005435039872	5426	Economy	9800.00
0005434229263	5426	Economy	9800.00
0005435007071	5426	Economy	9800.00
0005435007073	5426	Economy	9800.00
0005435039880	5426	Economy	9800.00
0005435039877	5426	Economy	9800.00
0005435039886	5426	Economy	9800.00
0005435039883	5426	Economy	9800.00
0005435039890	5426	Economy	9800.00
0005435039924	5426	Economy	9800.00
0005432125464	5426	Economy	9800.00
0005435039898	5426	Economy	9800.00
0005435039889	5426	Economy	9800.00
0005432125466	5426	Economy	9800.00
0005432125465	5426	Economy	9800.00
0005435039922	5426	Economy	9800.00
0005435039873	5426	Economy	9800.00
0005435007083	5426	Economy	9800.00
0005434229268	5426	Economy	9800.00
0005434229129	5426	Economy	9800.00
0005435007076	5426	Economy	9800.00
0005435039894	5426	Economy	9800.00
0005435039916	5426	Economy	9800.00
0005435039913	5426	Economy	9800.00
0005435007082	5426	Economy	9800.00
0005435039882	5426	Economy	9800.00
0005435039893	5426	Economy	9800.00
0005432125468	5426	Economy	9800.00
0005434229212	5426	Economy	9800.00
0005434229311	5426	Economy	9800.00
0005435039902	5426	Economy	9800.00
0005435039931	5426	Economy	9800.00
0005435039870	5426	Economy	9800.00
0005434229187	5426	Economy	9800.00
0005435039885	5426	Economy	9800.00
0005434229292	5426	Economy	9800.00
0005434229166	5426	Economy	9800.00
0005435039915	5426	Economy	9800.00
0005434229222	5426	Economy	9800.00
0005435039897	5426	Economy	9800.00
0005432125463	5426	Economy	9800.00
0005435039909	5426	Economy	9800.00
0005435007075	5426	Economy	9800.00
0005435007078	5426	Economy	9800.00
0005434229209	5426	Economy	9800.00
0005435039895	5426	Economy	9800.00
0005435007079	5426	Economy	9800.00
0005435039201	12955	Business	29500.00
0005435039166	12955	Business	29500.00
0005435039275	12955	Business	29500.00
0005435006862	12955	Business	29500.00
0005434229413	12955	Business	29500.00
0005435039207	12955	Business	29500.00
0005434229424	12955	Business	29500.00
0005434229414	12955	Business	29500.00
0005435039295	12955	Business	29500.00
0005435039197	12955	Economy	9800.00
0005434229425	12955	Economy	9800.00
0005435039463	12955	Economy	9800.00
0005434229411	12955	Economy	9800.00
0005435039214	12955	Economy	9800.00
0005435039208	12955	Economy	9800.00
0005435039269	12955	Economy	9800.00
0005435039341	12955	Economy	9800.00
0005435039198	12955	Economy	9800.00
0005434229417	12955	Economy	9800.00
0005435006913	12955	Economy	9800.00
0005435039301	12955	Economy	9800.00
0005435039636	12955	Economy	9800.00
0005435039288	12955	Economy	9800.00
0005434229423	12955	Economy	9800.00
0005435039065	12955	Economy	9800.00
0005435039068	12955	Economy	9800.00
0005435039593	12955	Economy	9800.00
0005435039185	12955	Economy	9800.00
0005435006827	12955	Economy	9800.00
0005434229427	12955	Economy	9800.00
0005435042845	12955	Economy	9800.00
0005435006885	12955	Economy	9800.00
0005435039330	12955	Economy	9800.00
0005435006868	12955	Economy	9800.00
0005435006921	12955	Economy	9800.00
0005435006843	12955	Economy	9800.00
0005435039571	12955	Economy	9800.00
0005434229416	12955	Economy	9800.00
0005435006828	12955	Economy	9800.00
0005435006896	12955	Economy	9800.00
0005435039396	12955	Economy	9800.00
0005435039483	12955	Economy	9800.00
0005435039581	12955	Economy	9800.00
0005434229419	12955	Economy	9800.00
0005435039402	12955	Economy	9800.00
0005435006897	12955	Economy	9800.00
0005435039457	12955	Economy	9800.00
0005435006864	12955	Economy	10800.00
0005435039345	12955	Economy	10800.00
0005435039228	12955	Economy	10800.00
0005435006842	12955	Economy	10800.00
0005435039458	12955	Economy	9800.00
0005434229422	12955	Economy	9800.00
0005434229428	12955	Economy	9800.00
0005435006912	12955	Economy	9800.00
0005432304407	12955	Economy	9800.00
0005435006863	12955	Economy	9800.00
0005435039594	12955	Economy	9800.00
0005435039470	12955	Economy	9800.00
0005435006922	12955	Economy	9800.00
0005435039344	12955	Economy	9800.00
0005435043278	12955	Economy	9800.00
0005432304404	12955	Economy	9800.00
0005434229421	12955	Economy	9800.00
0005434229407	12955	Economy	9800.00
0005432304405	12955	Economy	9800.00
0005435039184	12955	Economy	9800.00
0005435006829	12955	Economy	9800.00
0005434229406	12955	Economy	9800.00
0005435039211	12955	Economy	9800.00
0005434229409	12955	Economy	9800.00
0005434229420	12955	Economy	9800.00
0005435006831	12955	Economy	9800.00
0005435039366	12955	Economy	9800.00
0005435042839	12955	Economy	9800.00
0005435006887	12955	Economy	9800.00
0005435043281	12955	Economy	9800.00
0005434229410	12955	Economy	9800.00
0005435039379	12955	Economy	9800.00
0005435039192	12955	Economy	9800.00
0005435039582	12955	Economy	9800.00
0005435039094	12955	Economy	9800.00
0005435039256	12955	Economy	9800.00
0005435039429	12955	Economy	9800.00
0005435039287	12955	Economy	9800.00
0005435039331	12955	Economy	9800.00
0005435006890	12955	Economy	9800.00
0005432304406	12955	Economy	9800.00
0005434229426	12955	Economy	9800.00
0005435039368	12955	Economy	9800.00
0005435039503	12955	Economy	9800.00
0005434229429	12955	Economy	9800.00
0005434229418	12955	Economy	9800.00
0005435006886	12955	Economy	9800.00
0005435039257	12955	Economy	9800.00
0005435039347	12955	Economy	9800.00
0005435039304	12955	Economy	9800.00
0005434229415	12955	Economy	9800.00
0005434229412	12955	Economy	9800.00
0005435039367	12955	Economy	9800.00
0005434229408	12955	Economy	9800.00
0005435039095	12955	Economy	9800.00
0005435039354	12955	Economy	9800.00
0005435039588	12955	Economy	9800.00
0005435039380	12955	Economy	9800.00
0005435039346	12955	Economy	9800.00
0005435006830	12955	Economy	9800.00
0005435039381	12955	Economy	9800.00
0005435039405	12955	Economy	9800.00
0005435039382	12955	Economy	9800.00
0005435039369	12955	Economy	9800.00
0005435039324	12955	Economy	9800.00
0005435039436	12955	Economy	9800.00
0005435039527	12955	Economy	9800.00
0005434426632	14850	Business	52900.00
0005434411782	14850	Business	52900.00
0005435902489	14850	Business	52900.00
0005435902598	14850	Business	52900.00
0005434426652	14850	Business	52900.00
0005434426642	14850	Business	52900.00
0005434426630	14850	Business	52900.00
0005434426649	14850	Business	52900.00
0005435902566	14850	Economy	17600.00
0005435902587	14850	Economy	17600.00
0005435902562	14850	Economy	17600.00
0005435902620	14850	Economy	17600.00
0005434426654	14850	Economy	17600.00
0005434426638	14850	Economy	19400.00
0005432188611	14850	Economy	19400.00
0005434426640	14850	Economy	19400.00
0005434426633	14850	Economy	19400.00
0005435902567	14850	Economy	17600.00
0005435902538	14850	Economy	17600.00
0005434426646	14850	Economy	17600.00
0005435902560	14850	Economy	17600.00
0005435902559	14850	Economy	17600.00
0005434426635	14850	Economy	17600.00
0005434426639	14850	Economy	17600.00
0005434426636	14850	Economy	17600.00
0005435902602	14850	Economy	17600.00
0005434426641	14850	Economy	17600.00
0005435554164	14850	Economy	17600.00
0005434426648	14850	Economy	17600.00
0005434426644	14850	Economy	17600.00
0005434426655	14850	Economy	17600.00
0005435902524	14850	Economy	17600.00
0005434426643	14850	Economy	17600.00
0005434426653	14850	Economy	17600.00
0005434411784	14850	Economy	17600.00
0005435902534	14850	Economy	17600.00
0005434426631	14850	Economy	17600.00
0005434426650	14850	Economy	17600.00
0005434426637	14850	Economy	17600.00
0005434411781	14850	Economy	17600.00
0005434426628	14850	Economy	17600.00
0005434426651	14850	Economy	17600.00
0005435902563	14850	Economy	17600.00
0005435902484	14850	Economy	17600.00
0005432188612	14850	Economy	17600.00
0005434426656	14850	Economy	17600.00
0005434426647	14850	Economy	17600.00
0005434426629	14850	Economy	17600.00
0005435902533	14850	Economy	17600.00
0005435554140	14850	Economy	17600.00
0005435902535	14850	Economy	17600.00
0005434426634	14850	Economy	17600.00
0005435902523	14850	Economy	17600.00
0005435902517	14850	Economy	17600.00
0005434411783	14850	Economy	17600.00
0005435902483	14850	Economy	17600.00
0005434426645	14850	Economy	17600.00
0005435902520	14850	Economy	17600.00
0005434426627	14850	Economy	17600.00
0005434411749	20193	Business	52900.00
0005434426193	20193	Business	52900.00
0005434411750	20193	Business	52900.00
0005434426513	20193	Business	52900.00
0005435902736	20193	Business	52900.00
0005435902730	20193	Economy	17600.00
0005434426440	20193	Economy	17600.00
0005435902744	20193	Economy	19400.00
0005434426349	20193	Economy	19400.00
0005435902742	20193	Economy	19400.00
0005435554199	20193	Economy	19400.00
0005435902732	20193	Economy	17600.00
0005434426305	20193	Economy	17600.00
0005435902747	20193	Economy	17600.00
0005435902731	20193	Economy	17600.00
0005435902745	20193	Economy	17600.00
0005434426348	20193	Economy	17600.00
0005434426343	20193	Economy	17600.00
0005434426458	20193	Economy	17600.00
0005434426306	20193	Economy	17600.00
0005435554200	20193	Economy	17600.00
0005434426426	20193	Economy	17600.00
0005434426464	20193	Economy	17600.00
0005434426483	20193	Economy	17600.00
0005435902740	20193	Economy	17600.00
0005435554198	20193	Economy	17600.00
0005435902739	20193	Economy	17600.00
0005435902746	20193	Economy	17600.00
0005434426463	20193	Economy	17600.00
0005434426421	20193	Economy	17600.00
0005434426424	20193	Economy	17600.00
0005434426484	20193	Economy	17600.00
0005434426514	20193	Economy	17600.00
0005434426422	20193	Economy	17600.00
0005434426478	20193	Economy	17600.00
0005434426449	20193	Economy	17600.00
0005434426390	20193	Economy	17600.00
0005434411754	20193	Economy	17600.00
0005434426511	20193	Economy	17600.00
0005435902735	20193	Economy	17600.00
0005435902738	20193	Economy	17600.00
0005435902737	20193	Economy	17600.00
0005435902743	20193	Economy	17600.00
0005435902741	20193	Economy	17600.00
0005435554201	20193	Economy	17600.00
0005434426363	20193	Economy	17600.00
0005434426450	20193	Economy	17600.00
0005434426391	20193	Economy	17600.00
0005435902733	20193	Economy	17600.00
0005435902734	20193	Economy	17600.00
0005434426296	20193	Economy	17600.00
0005435982361	26508	Business	18500.00
0005435982369	26508	Business	18500.00
0005433434346	26508	Business	18500.00
0005435982363	26508	Business	18500.00
0005435982365	26508	Business	18500.00
0005435982368	26508	Business	18500.00
0005433434603	26508	Business	18500.00
0005433434528	26508	Business	18500.00
0005435982383	26508	Business	18500.00
0005433434477	26508	Business	18500.00
0005435982351	26508	Business	18500.00
0005435982357	26508	Economy	6200.00
0005435982387	26508	Economy	6200.00
0005433434478	26508	Economy	6200.00
0005433434547	26508	Economy	6200.00
0005435982346	26508	Economy	6200.00
0005435982364	26508	Economy	6200.00
0005433434467	26508	Economy	6200.00
0005435982362	26508	Economy	6200.00
0005433434466	26508	Economy	6200.00
0005435982388	26508	Economy	6800.00
0005432300272	26508	Economy	6800.00
0005433434531	26508	Economy	6800.00
0005433434501	26508	Economy	6200.00
0005435982350	26508	Economy	6200.00
0005433434468	26508	Economy	6200.00
0005433434443	26508	Economy	6200.00
0005435982382	26508	Economy	6200.00
0005435982378	26508	Economy	6200.00
0005435982348	26508	Economy	6200.00
0005434270194	26508	Economy	6200.00
0005432300271	26508	Economy	6200.00
0005435982377	26508	Economy	6200.00
0005433434486	26508	Economy	6200.00
0005433434558	26508	Economy	6200.00
0005433434487	26508	Economy	6200.00
0005435982373	26508	Economy	6200.00
0005435982375	26508	Economy	6200.00
0005434273063	26508	Economy	6200.00
0005435982381	26508	Economy	6200.00
0005435982360	26508	Economy	6200.00
0005435982371	26508	Economy	6200.00
0005435982370	26508	Economy	6200.00
0005433434532	26508	Economy	6200.00
0005434270192	26508	Economy	6200.00
0005435982347	26508	Economy	6200.00
0005435982389	26508	Economy	6200.00
0005433434552	26508	Economy	6200.00
0005435982379	26508	Economy	6200.00
0005434273059	26508	Economy	6200.00
0005435982376	26508	Economy	6200.00
0005435982354	26508	Economy	6200.00
0005433434540	26508	Economy	6200.00
0005435982349	26508	Economy	6200.00
0005433434464	26508	Economy	6200.00
0005433434500	26508	Economy	6200.00
0005435982380	26508	Economy	6200.00
0005435982344	26508	Economy	6200.00
0005435982359	26508	Economy	6200.00
0005434273064	26508	Economy	6200.00
0005433434602	26508	Economy	6200.00
0005435982374	26508	Economy	6200.00
0005432300270	26508	Economy	6200.00
0005433434463	26508	Economy	6200.00
0005435982355	26508	Economy	6200.00
0005435982384	26508	Economy	6200.00
0005435982353	26508	Economy	6200.00
0005435982386	26508	Economy	6200.00
0005435982385	26508	Economy	6200.00
0005433434447	26508	Economy	6200.00
0005435982372	26508	Economy	6200.00
0005435982366	26508	Economy	6200.00
0005435982392	26508	Economy	6200.00
0005432300269	26508	Economy	6200.00
0005435982391	26508	Economy	6200.00
0005433434422	26508	Economy	6200.00
0005435982358	26508	Economy	6200.00
0005433434485	26508	Economy	6200.00
0005433434421	26508	Economy	6200.00
0005433434423	26508	Economy	6200.00
0005435982356	26508	Economy	6200.00
0005435982352	26508	Economy	6200.00
0005435982390	26508	Economy	6200.00
0005435982367	26508	Economy	6200.00
0005435982345	26508	Economy	6200.00
0005433434512	26508	Economy	6200.00
0005435982343	26508	Economy	6200.00
0005435981983	26679	Business	18500.00
0005433434755	26679	Business	18500.00
0005435981912	26679	Business	18500.00
0005433434732	26679	Business	18500.00
0005433434736	26679	Business	18500.00
0005435981827	26679	Business	18500.00
0005433434731	26679	Business	18500.00
0005435981996	26679	Business	18500.00
0005435981976	26679	Business	18500.00
0005435981926	26679	Business	18500.00
0005435981837	26679	Business	18500.00
0005435981858	26679	Business	18500.00
0005435982050	26679	Economy	6200.00
0005433434741	26679	Economy	6200.00
0005433434746	26679	Economy	6200.00
0005435981966	26679	Economy	6200.00
0005435982039	26679	Economy	6200.00
0005435981959	26679	Economy	6200.00
0005433434749	26679	Economy	6200.00
0005435982115	26679	Economy	6200.00
0005432051133	26679	Economy	6200.00
0005435981967	26679	Economy	6200.00
0005435981948	26679	Economy	6800.00
0005434269108	26679	Economy	6800.00
0005435981820	26679	Economy	6800.00
0005435981943	26679	Economy	6800.00
0005433434743	26679	Economy	6800.00
0005435981888	26679	Economy	6200.00
0005433434730	26679	Economy	6200.00
0005434269107	26679	Economy	6200.00
0005435981812	26679	Economy	6200.00
0005435981941	26679	Economy	6200.00
0005435982114	26679	Economy	6200.00
0005433434728	26679	Economy	6200.00
0005435981821	26679	Economy	6200.00
0005435981997	26679	Economy	6200.00
0005435981993	26679	Economy	6200.00
0005435981942	26679	Economy	6200.00
0005433434751	26679	Economy	6200.00
0005435981907	26679	Economy	6200.00
0005435982030	26679	Economy	6200.00
0005435982038	26679	Economy	6200.00
0005435981951	26679	Economy	6200.00
0005432051134	26679	Economy	6200.00
0005433434745	26679	Economy	6200.00
0005435981909	26679	Economy	6200.00
0005433434747	26679	Economy	6200.00
0005435981939	26679	Economy	6200.00
0005435981947	26679	Economy	6200.00
0005434271316	26679	Economy	6200.00
0005433434752	26679	Economy	6200.00
0005433434750	26679	Economy	6200.00
0005435982029	26679	Economy	6200.00
0005433434733	26679	Economy	6200.00
0005435982012	26679	Economy	6200.00
0005433434727	26679	Economy	6200.00
0005433434748	26679	Economy	6200.00
0005434271317	26679	Economy	6200.00
0005435981958	26679	Economy	6200.00
0005433434740	26679	Economy	6200.00
0005435981938	26679	Economy	6200.00
0005434270211	26679	Economy	6200.00
0005433434738	26679	Economy	6200.00
0005435982078	26679	Economy	6200.00
0005435981773	26679	Economy	6200.00
0005433434729	26679	Economy	6200.00
0005433434744	26679	Economy	6200.00
0005433434739	26679	Economy	6200.00
0005435981991	26679	Economy	6200.00
0005435982007	26679	Economy	6200.00
0005433434753	26679	Economy	6200.00
0005435981816	26679	Economy	6200.00
0005433434742	26679	Economy	6200.00
0005435982172	26679	Economy	6200.00
0005435981893	26679	Economy	6200.00
0005432051136	26679	Economy	6200.00
0005435981968	26679	Economy	6200.00
0005435981819	26679	Economy	6200.00
0005435982010	26679	Economy	6200.00
0005433434735	26679	Economy	6200.00
0005432051135	26679	Economy	6200.00
0005435981957	26679	Economy	6200.00
0005433434737	26679	Economy	6200.00
0005433434734	26679	Economy	6200.00
0005435982011	26679	Economy	6200.00
0005435981886	26679	Economy	6200.00
0005434270210	26679	Economy	6200.00
0005435981887	26679	Economy	6200.00
0005435982040	26679	Economy	6200.00
0005433434754	26679	Economy	6200.00
0005432584088	3131	Economy	11100.00
0005432584084	3131	Economy	11100.00
0005432584076	3131	Economy	11100.00
0005432584074	3131	Economy	11100.00
0005432584082	3131	Economy	10100.00
0005432857997	3131	Economy	10100.00
0005432216278	3131	Economy	10100.00
0005432857936	3131	Economy	10100.00
0005432584075	3131	Economy	10100.00
0005432858042	3131	Economy	10100.00
0005432584097	3131	Economy	10100.00
0005432584091	3131	Economy	10100.00
0005432216277	3131	Economy	10100.00
0005432584086	3131	Economy	10100.00
0005432584077	3131	Economy	10100.00
0005432858003	3131	Economy	10100.00
0005432857978	3131	Economy	10100.00
0005432584096	3131	Economy	10100.00
0005432584080	3131	Economy	10100.00
0005432584085	3131	Economy	10100.00
0005432584083	3131	Economy	10100.00
0005432857944	3131	Economy	10100.00
0005432857966	3131	Economy	10100.00
0005432584078	3131	Economy	10100.00
0005432584087	3131	Economy	10100.00
0005432857992	3131	Economy	10100.00
0005432584094	3131	Economy	10100.00
0005432584090	3131	Economy	10100.00
0005432584072	3131	Economy	10100.00
0005432584089	3131	Economy	10100.00
0005432584079	3131	Economy	10100.00
0005432857977	3131	Economy	10100.00
0005432584073	3131	Economy	10100.00
0005432858043	3131	Economy	10100.00
0005432857917	3131	Economy	10100.00
0005432216276	3131	Economy	10100.00
0005432584095	3131	Economy	10100.00
0005432584092	3131	Economy	10100.00
0005432857996	3131	Economy	10100.00
0005432584093	3131	Economy	10100.00
0005432857984	3131	Economy	10100.00
0005432216279	3131	Economy	10100.00
0005432584081	3131	Economy	10100.00
0005432857943	3131	Economy	10100.00
0005432857985	3131	Economy	10100.00
0005432583883	31524	Economy	11100.00
0005432858090	31524	Economy	11100.00
0005432583905	31524	Economy	11100.00
0005432583900	31524	Economy	10100.00
0005432858086	31524	Economy	10100.00
0005432583966	31524	Economy	10100.00
0005432583911	31524	Economy	10100.00
0005432583802	31524	Economy	10100.00
0005432858088	31524	Economy	10100.00
0005432583912	31524	Economy	10100.00
0005432858089	31524	Economy	10100.00
0005432858096	31524	Economy	10100.00
0005432583932	31524	Economy	10100.00
0005432858093	31524	Economy	10100.00
0005432583924	31524	Economy	10100.00
0005432858087	31524	Economy	10100.00
0005432858085	31524	Economy	10100.00
0005432858091	31524	Economy	10100.00
0005432583904	31524	Economy	10100.00
0005432583922	31524	Economy	10100.00
0005432858097	31524	Economy	10100.00
0005432583803	31524	Economy	10100.00
0005432583910	31524	Economy	10100.00
0005432583965	31524	Economy	10100.00
0005432583964	31524	Economy	10100.00
0005432583925	31524	Economy	10100.00
0005432583908	31524	Economy	10100.00
0005432858092	31524	Economy	10100.00
0005432583930	31524	Economy	10100.00
0005432858095	31524	Economy	10100.00
0005432858094	31524	Economy	10100.00
0005432583923	31524	Economy	10100.00
0005434943369	875	Economy	8300.00
0005434943373	875	Economy	7500.00
0005433255077	875	Economy	7500.00
0005434943366	875	Economy	7500.00
0005433255109	875	Economy	7500.00
0005434943367	875	Economy	7500.00
0005433255087	875	Economy	7500.00
0005434943370	875	Economy	7500.00
0005434943371	875	Economy	7500.00
0005434943372	875	Economy	7500.00
0005433255100	875	Economy	7500.00
0005434943365	875	Economy	7500.00
0005433255108	875	Economy	7500.00
0005434943368	875	Economy	7500.00
0005433255129	16202	Economy	8300.00
0005434943279	16202	Economy	8300.00
0005433255131	16202	Economy	7500.00
0005434943310	16202	Economy	7500.00
0005434943304	16202	Economy	7500.00
0005433255128	16202	Economy	7500.00
0005434943335	16202	Economy	7500.00
0005434943299	16202	Economy	7500.00
0005434943298	16202	Economy	7500.00
0005433255127	16202	Economy	7500.00
0005433255130	16202	Economy	7500.00
0005434943271	16202	Economy	7500.00
0005434943309	16202	Economy	7500.00
0005434943276	16202	Economy	7500.00
0005434943303	16202	Economy	7500.00
0005433255132	16202	Economy	7500.00
0005434943342	16202	Economy	7500.00
0005434943336	16202	Economy	7500.00
0005433811622	14370	Economy	4400.00
0005433811623	14370	Economy	4400.00
0005433811621	14370	Economy	4400.00
0005435653137	21747	Business	9800.00
0005435653132	21747	Business	9800.00
0005433367556	21747	Business	9800.00
0005435653120	21747	Business	9800.00
0005435653129	21747	Business	9800.00
0005433367440	21747	Business	9800.00
0005435653112	21747	Business	9800.00
0005433367648	21747	Business	9800.00
0005433367609	21747	Business	9800.00
0005435653134	21747	Business	9800.00
0005433367615	21747	Business	9800.00
0005435653127	21747	Economy	3300.00
0005435653105	21747	Economy	3300.00
0005435653117	21747	Economy	3300.00
0005435653121	21747	Economy	3300.00
0005433367553	21747	Economy	3300.00
0005435653124	21747	Economy	3300.00
0005433367588	21747	Economy	3300.00
0005433367699	21747	Economy	3300.00
0005435653133	21747	Economy	3300.00
0005433367623	21747	Economy	3300.00
0005433367585	21747	Economy	3600.00
0005433367474	21747	Economy	3600.00
0005435653135	21747	Economy	3600.00
0005435653118	21747	Economy	3600.00
0005435653099	21747	Economy	3600.00
0005433367431	21747	Economy	3300.00
0005435653095	21747	Economy	3300.00
0005433367568	21747	Economy	3300.00
0005435653123	21747	Economy	3300.00
0005435653107	21747	Economy	3300.00
0005433367576	21747	Economy	3300.00
0005433367612	21747	Economy	3300.00
0005435653108	21747	Economy	3300.00
0005435653128	21747	Economy	3300.00
0005435653131	21747	Economy	3300.00
0005435653119	21747	Economy	3300.00
0005433367780	21747	Economy	3300.00
0005433367614	21747	Economy	3300.00
0005435653098	21747	Economy	3300.00
0005433367473	21747	Economy	3300.00
0005433367610	21747	Economy	3300.00
0005435653122	21747	Economy	3300.00
0005435653138	21747	Economy	3300.00
0005433367438	21747	Economy	3300.00
0005433367608	21747	Economy	3300.00
0005433367633	21747	Economy	3300.00
0005435653110	21747	Economy	3300.00
0005435653104	21747	Economy	3300.00
0005435653111	21747	Economy	3300.00
0005435653094	21747	Economy	3300.00
0005433367552	21747	Economy	3300.00
0005433367716	21747	Economy	3300.00
0005435653115	21747	Economy	3300.00
0005433367781	21747	Economy	3300.00
0005433367624	21747	Economy	3300.00
0005435653109	21747	Economy	3300.00
0005433367589	21747	Economy	3300.00
0005435653097	21747	Economy	3300.00
0005435653114	21747	Economy	3300.00
0005435653101	21747	Economy	3300.00
0005435653125	21747	Economy	3300.00
0005433367644	21747	Economy	3300.00
0005435653126	21747	Economy	3300.00
0005433367432	21747	Economy	3300.00
0005435653100	21747	Economy	3300.00
0005433367433	21747	Economy	3300.00
0005433367647	21747	Economy	3300.00
0005433367587	21747	Economy	3300.00
0005433367715	21747	Economy	3300.00
0005435653116	21747	Economy	3300.00
0005433367439	21747	Economy	3300.00
0005435653103	21747	Economy	3300.00
0005433367674	21747	Economy	3300.00
0005435653096	21747	Economy	3300.00
0005435653106	21747	Economy	3300.00
0005433367697	21747	Economy	3300.00
0005433367671	21747	Economy	3300.00
0005435653136	21747	Economy	3300.00
0005435653102	21747	Economy	3300.00
0005435653130	21747	Economy	3300.00
0005435653113	21747	Economy	3300.00
0005433785001	9360	Business	186200.00
0005433805440	9360	Business	186200.00
0005433785012	9360	Business	186200.00
0005433805451	9360	Business	186200.00
0005433805444	9360	Business	186200.00
0005433805468	9360	Business	186200.00
0005433805442	9360	Business	186200.00
0005432665279	9360	Business	186200.00
0005432657456	9360	Business	186200.00
0005433785035	9360	Business	186200.00
0005433805459	9360	Business	186200.00
0005433805461	9360	Business	186200.00
0005433763234	9360	Business	186200.00
0005433785010	9360	Business	186200.00
0005433785037	9360	Business	186200.00
0005433785000	9360	Business	186200.00
0005433785016	9360	Business	186200.00
0005433785011	9360	Economy	68300.00
0005433805465	9360	Economy	68300.00
0005432666393	9360	Economy	68300.00
0005433805471	9360	Economy	62100.00
0005433785022	9360	Economy	62100.00
0005433805472	9360	Economy	62100.00
0005433785019	9360	Economy	62100.00
0005434170988	9360	Economy	62100.00
0005434170994	9360	Economy	62100.00
0005433805448	9360	Economy	62100.00
0005433763241	9360	Economy	62100.00
0005433805469	9360	Economy	62100.00
0005433785014	9360	Economy	62100.00
0005433763239	9360	Economy	62100.00
0005434170973	9360	Economy	62100.00
0005433785018	9360	Economy	62100.00
0005433805445	9360	Economy	62100.00
0005434171033	9360	Economy	62100.00
0005435269691	9360	Economy	62100.00
0005433805454	9360	Economy	62100.00
0005433785020	9360	Economy	62100.00
0005433785017	9360	Economy	62100.00
0005433805466	9360	Economy	62100.00
0005435269679	9360	Economy	62100.00
0005433763230	9360	Economy	62100.00
0005434170923	9360	Economy	62100.00
0005433785033	9360	Economy	62100.00
0005435269668	9360	Economy	62100.00
0005432665278	9360	Economy	62100.00
0005433805436	9360	Economy	62100.00
0005433784999	9360	Economy	62100.00
0005433763231	9360	Economy	62100.00
0005433805441	9360	Economy	62100.00
0005433785006	9360	Economy	62100.00
0005433805458	9360	Economy	62100.00
0005433763232	9360	Economy	62100.00
0005433785030	9360	Economy	62100.00
0005434170975	9360	Economy	62100.00
0005435269675	9360	Economy	62100.00
0005433805450	9360	Economy	62100.00
0005435269686	9360	Economy	62100.00
0005433805475	9360	Economy	62100.00
0005433805467	9360	Economy	62100.00
0005434170993	9360	Economy	62100.00
0005433805449	9360	Economy	62100.00
0005433805438	9360	Economy	62100.00
0005433785007	9360	Economy	62100.00
0005433805456	9360	Economy	62100.00
0005434170974	9360	Economy	62100.00
0005433763236	9360	Economy	62100.00
0005433763238	9360	Economy	62100.00
0005433785036	9360	Economy	62100.00
0005433805476	9360	Economy	62100.00
0005433805446	9360	Economy	62100.00
0005432657455	9360	Economy	62100.00
0005433805470	9360	Economy	62100.00
0005433785032	9360	Economy	62100.00
0005433785029	9360	Economy	62100.00
0005433805460	9360	Economy	62100.00
0005434171032	9360	Economy	62100.00
0005433785003	9360	Economy	68300.00
0005433785021	9360	Economy	62100.00
0005433805439	9360	Economy	62100.00
0005433805473	9360	Economy	62100.00
0005433763228	9360	Economy	68300.00
0005432666392	9360	Economy	62100.00
0005434171011	9360	Economy	62100.00
0005434170957	9360	Economy	62100.00
0005433763227	9360	Economy	62100.00
0005433763229	9360	Economy	62100.00
0005433805443	9360	Economy	62100.00
0005432667458	9360	Economy	62100.00
0005433805457	9360	Economy	62100.00
0005433785009	9360	Economy	62100.00
0005433763237	9360	Economy	62100.00
0005433785025	9360	Economy	62100.00
0005433785034	9360	Economy	62100.00
0005435269676	9360	Economy	62100.00
0005433763233	9360	Economy	62100.00
0005434170968	9360	Economy	62100.00
0005434170970	9360	Economy	62100.00
0005433785024	9360	Economy	62100.00
0005433805453	9360	Economy	62100.00
0005433805462	9360	Economy	62100.00
0005433805455	9360	Economy	62100.00
0005433785002	9360	Economy	62100.00
0005435269667	9360	Economy	62100.00
0005432667457	9360	Economy	62100.00
0005434170969	9360	Economy	62100.00
0005433785023	9360	Economy	62100.00
0005433785031	9360	Economy	62100.00
0005434170958	9360	Economy	62100.00
0005432657454	9360	Economy	62100.00
0005433785013	9360	Economy	62100.00
0005435269674	9360	Economy	62100.00
0005434170987	9360	Economy	62100.00
0005433805464	9360	Economy	62100.00
0005433785008	9360	Economy	62100.00
0005433785004	9360	Economy	62100.00
0005433785005	9360	Economy	62100.00
0005433785028	9360	Economy	62100.00
0005433805437	9360	Economy	62100.00
0005434270202	9360	Economy	62100.00
0005433805447	9360	Economy	62100.00
0005433763242	9360	Economy	62100.00
0005433785027	9360	Economy	62100.00
0005433785026	9360	Economy	62100.00
0005433785015	9360	Economy	62100.00
0005433763235	9360	Economy	62100.00
0005434270201	9360	Economy	62100.00
0005435269685	9360	Economy	62100.00
0005432657453	9360	Economy	62100.00
0005433805474	9360	Economy	62100.00
0005433805452	9360	Economy	62100.00
0005433763240	9360	Economy	62100.00
0005433805463	9360	Economy	62100.00
0005433784557	26270	Business	186200.00
0005433784755	26270	Business	186200.00
0005433805023	26270	Business	186200.00
0005435269755	26270	Business	186200.00
0005433784555	26270	Business	186200.00
0005433805089	26270	Business	186200.00
0005433784751	26270	Business	186200.00
0005433784913	26270	Business	186200.00
0005433805039	26270	Business	186200.00
0005434171082	26270	Business	186200.00
0005433805154	26270	Business	186200.00
0005433805167	26270	Business	186200.00
0005432663023	26270	Business	186200.00
0005433763147	26270	Business	186200.00
0005433805062	26270	Business	186200.00
0005432666373	26270	Business	186200.00
0005435269751	26270	Business	186200.00
0005433784791	26270	Business	186200.00
0005433805222	26270	Economy	68300.00
0005434271315	26270	Economy	68300.00
0005433763081	26270	Economy	68300.00
0005434151709	26270	Economy	62100.00
0005433805142	26270	Economy	62100.00
0005434269106	26270	Economy	62100.00
0005433784628	26270	Economy	62100.00
0005433784534	26270	Economy	62100.00
0005433763158	26270	Economy	62100.00
0005433784779	26270	Economy	62100.00
0005434171084	26270	Economy	62100.00
0005433784634	26270	Economy	62100.00
0005433805163	26270	Economy	62100.00
0005434171081	26270	Economy	62100.00
0005434171086	26270	Economy	62100.00
0005433805207	26270	Economy	62100.00
0005434269105	26270	Economy	62100.00
0005432659691	26270	Economy	62100.00
0005433805206	26270	Economy	62100.00
0005434171085	26270	Economy	62100.00
0005433805245	26270	Economy	62100.00
0005433784649	26270	Economy	62100.00
0005433784552	26270	Economy	62100.00
0005433784652	26270	Economy	62100.00
0005433805082	26270	Economy	62100.00
0005433784756	26270	Economy	62100.00
0005432659690	26270	Economy	62100.00
0005433784771	26270	Economy	62100.00
0005434171079	26270	Economy	62100.00
0005432666375	26270	Economy	62100.00
0005433784641	26270	Economy	62100.00
0005434151710	26270	Economy	62100.00
0005433784512	26270	Economy	62100.00
0005433784802	26270	Economy	62100.00
0005433805244	26270	Economy	62100.00
0005433805061	26270	Economy	62100.00
0005432659685	26270	Economy	62100.00
0005434171087	26270	Economy	62100.00
0005433805165	26270	Economy	62100.00
0005433784749	26270	Economy	62100.00
0005432657437	26270	Economy	62100.00
0005433784698	26270	Economy	62100.00
0005433784650	26270	Economy	62100.00
0005433784646	26270	Economy	62100.00
0005433784748	26270	Economy	62100.00
0005433763141	26270	Economy	62100.00
0005433805157	26270	Economy	62100.00
0005435269756	26270	Economy	62100.00
0005433805155	26270	Economy	62100.00
0005434270208	26270	Economy	62100.00
0005432659689	26270	Economy	62100.00
0005435269758	26270	Economy	62100.00
0005433805141	26270	Economy	62100.00
0005433784760	26270	Economy	62100.00
0005434171078	26270	Economy	62100.00
0005433763112	26270	Economy	62100.00
0005434171076	26270	Economy	62100.00
0005433784705	26270	Economy	68300.00
0005433784809	26270	Economy	62100.00
0005433805081	26270	Economy	62100.00
0005433784754	26270	Economy	62100.00
0005433763146	26270	Economy	62100.00
0005434171088	26270	Economy	62100.00
0005433784640	26270	Economy	62100.00
0005433763114	26270	Economy	62100.00
0005433784651	26270	Economy	62100.00
0005435269757	26270	Economy	62100.00
0005434171089	26270	Economy	62100.00
0005433805162	26270	Economy	62100.00
0005434171077	26270	Economy	62100.00
0005433805173	26270	Economy	62100.00
0005433784826	26270	Economy	62100.00
0005433805194	26270	Economy	62100.00
0005433805164	26270	Economy	62100.00
0005433805011	26270	Economy	62100.00
0005435269752	26270	Economy	62100.00
0005433805243	26270	Economy	62100.00
0005434271313	26270	Economy	62100.00
0005433805324	26270	Economy	62100.00
0005434270209	26270	Economy	62100.00
0005435269753	26270	Economy	62100.00
0005433784558	26270	Economy	62100.00
0005434171080	26270	Economy	62100.00
0005433784801	26270	Economy	62100.00
0005434271314	26270	Economy	62100.00
0005434171083	26270	Economy	62100.00
0005433784704	26270	Economy	62100.00
0005435269754	26270	Economy	62100.00
0005433784753	26270	Economy	62100.00
0005433784513	26270	Economy	62100.00
0005432657436	26270	Economy	62100.00
0005433784660	26270	Economy	62100.00
0005432657434	26270	Economy	62100.00
0005433805022	26270	Economy	62100.00
0005433784535	26270	Economy	62100.00
0005433784682	26270	Economy	62100.00
0005433784914	26270	Economy	62100.00
0005433763076	26270	Economy	62100.00
0005432657433	26270	Economy	62100.00
0005434151708	26270	Economy	62100.00
0005433805205	26270	Economy	62100.00
0005433805172	26270	Economy	62100.00
0005433805166	26270	Economy	62100.00
0005435929625	4879	Economy	5300.00
0005435135677	4879	Economy	5300.00
0005435135678	4879	Economy	5300.00
0005435135679	4879	Economy	5300.00
0005435135681	4879	Economy	5300.00
0005435135680	4879	Economy	5300.00
0005435929624	4879	Economy	5300.00
0005435135661	33039	Economy	5300.00
0005435135641	33039	Economy	5300.00
0005435929649	33039	Economy	5300.00
0005435135635	33039	Economy	5300.00
0005435135655	33039	Economy	5300.00
0005435135646	33039	Economy	5300.00
0005435135644	33039	Economy	5300.00
0005434217931	9504	Economy	19700.00
0005434983297	9504	Economy	17900.00
0005434217930	9504	Economy	17900.00
0005434983298	9504	Economy	17900.00
0005434217942	9504	Economy	17900.00
0005434983295	9504	Economy	17900.00
0005434983299	9504	Economy	17900.00
0005434983296	9504	Economy	17900.00
0005434217941	9504	Economy	17900.00
0005434983249	27347	Economy	19700.00
0005434217977	27347	Economy	17900.00
0005434983250	27347	Economy	17900.00
0005434983248	27347	Economy	17900.00
0005434983258	27347	Economy	17900.00
0005434217975	27347	Economy	17900.00
0005434217976	27347	Economy	17900.00
0005434983257	27347	Economy	17900.00
0005433960259	24235	Business	36400.00
0005433960365	24235	Business	36400.00
0005433985597	24235	Business	36400.00
0005433985573	24235	Business	36400.00
0005433985277	24235	Business	36400.00
0005433960163	24235	Business	36400.00
0005433960371	24235	Business	36400.00
0005433960460	24235	Business	36400.00
0005433960437	24235	Business	36400.00
0005433960210	24235	Business	36400.00
0005433985643	24235	Economy	13400.00
0005433985577	24235	Economy	13400.00
0005433985451	24235	Economy	12100.00
0005433960152	24235	Economy	12100.00
0005433960260	24235	Economy	12100.00
0005433985581	24235	Economy	12100.00
0005433985548	24235	Economy	12100.00
0005433960511	24235	Economy	12100.00
0005433985496	24235	Economy	12100.00
0005433960104	24235	Economy	12100.00
0005433985582	24235	Economy	12100.00
0005433960425	24235	Economy	12100.00
0005433960219	24235	Economy	12100.00
0005433960294	24235	Economy	12100.00
0005433960360	24235	Economy	12100.00
0005433960440	24235	Economy	12100.00
0005433985571	24235	Economy	12100.00
0005433960455	24235	Economy	12100.00
0005433960387	24235	Economy	12100.00
0005433985570	24235	Economy	12100.00
0005433960451	24235	Economy	12100.00
0005433985459	24235	Economy	12100.00
0005433960462	24235	Economy	12100.00
0005433985640	24235	Economy	12100.00
0005433985614	24235	Economy	12100.00
0005433960312	24235	Economy	12100.00
0005433960150	24235	Economy	12100.00
0005433985563	24235	Economy	12100.00
0005433960220	24235	Economy	12100.00
0005433985632	24235	Economy	12100.00
0005433959987	24235	Economy	12100.00
0005433960208	24235	Economy	12100.00
0005433960458	24235	Economy	12100.00
0005433985506	24235	Economy	12100.00
0005433985564	24235	Economy	12100.00
0005433985495	24235	Economy	12100.00
0005433960438	24235	Economy	12100.00
0005433960454	24235	Economy	12100.00
0005433960356	24235	Economy	12100.00
0005433960209	24235	Economy	12100.00
0005433960295	24235	Economy	12100.00
0005433960510	24235	Economy	12100.00
0005433960436	24235	Economy	12100.00
0005433960185	24235	Economy	12100.00
0005433985594	24235	Economy	12100.00
0005433985403	24235	Economy	12100.00
0005433985605	24235	Economy	12100.00
0005433985494	24235	Economy	12100.00
0005433960523	24235	Economy	13400.00
0005433960466	24235	Economy	12100.00
0005433985471	24235	Economy	13400.00
0005433960459	24235	Economy	12100.00
0005433960405	24235	Economy	12100.00
0005433960457	24235	Economy	12100.00
0005433960313	24235	Economy	12100.00
0005433985558	24235	Economy	12100.00
0005433985565	24235	Economy	12100.00
0005433985606	24235	Economy	12100.00
0005433985616	24235	Economy	12100.00
0005433985470	24235	Economy	12100.00
0005433985617	24235	Economy	12100.00
0005433985527	24235	Economy	12100.00
0005433985520	24235	Economy	12100.00
0005433960483	24235	Economy	12100.00
0005433960310	24235	Economy	12100.00
0005433985452	24235	Economy	12100.00
0005433960286	24235	Economy	12100.00
0005433985538	24235	Economy	12100.00
0005433959986	24235	Economy	12100.00
0005433985521	24235	Economy	12100.00
0005433960522	24235	Economy	12100.00
0005433985639	24235	Economy	12100.00
0005433985562	24235	Economy	12100.00
0005433960456	24235	Economy	12100.00
0005433960151	24235	Economy	12100.00
0005433985627	24235	Economy	12100.00
0005433960361	24235	Economy	12100.00
0005433985595	24235	Economy	12100.00
0005433985347	24235	Economy	12100.00
0005433960372	24235	Economy	12100.00
0005433985626	24235	Economy	12100.00
0005433985557	24235	Economy	12100.00
0005433985625	24235	Economy	12100.00
0005433960362	24235	Economy	12100.00
0005433985537	24235	Economy	12100.00
0005433960381	24235	Economy	12100.00
0005433985276	24235	Economy	12100.00
0005433960311	24235	Economy	12100.00
0005433985477	24235	Economy	12100.00
0005433985999	25931	Business	36400.00
0005433960930	25931	Business	36400.00
0005433986003	25931	Business	36400.00
0005433960971	25931	Business	36400.00
0005433960934	25931	Business	36400.00
0005433985991	25931	Business	36400.00
0005433960937	25931	Business	36400.00
0005433960953	25931	Business	36400.00
0005433960923	25931	Business	36400.00
0005433960970	25931	Business	36400.00
0005433986001	25931	Business	36400.00
0005433960952	25931	Business	36400.00
0005433985988	25931	Economy	13400.00
0005433986023	25931	Economy	12100.00
0005433960944	25931	Economy	12100.00
0005433960958	25931	Economy	12100.00
0005433985996	25931	Economy	12100.00
0005433986011	25931	Economy	12100.00
0005433985995	25931	Economy	12100.00
0005433960957	25931	Economy	12100.00
0005433986010	25931	Economy	12100.00
0005433986021	25931	Economy	12100.00
0005433960942	25931	Economy	12100.00
0005433960954	25931	Economy	12100.00
0005433960939	25931	Economy	12100.00
0005433960961	25931	Economy	12100.00
0005433985989	25931	Economy	12100.00
0005433960920	25931	Economy	12100.00
0005433960965	25931	Economy	12100.00
0005433960948	25931	Economy	12100.00
0005433985992	25931	Economy	12100.00
0005433960964	25931	Economy	12100.00
0005433985990	25931	Economy	12100.00
0005433985984	25931	Economy	12100.00
0005433960960	25931	Economy	12100.00
0005433960922	25931	Economy	12100.00
0005433960943	25931	Economy	12100.00
0005433986014	25931	Economy	12100.00
0005433960921	25931	Economy	12100.00
0005433986018	25931	Economy	12100.00
0005433986005	25931	Economy	12100.00
0005433960925	25931	Economy	12100.00
0005433985985	25931	Economy	12100.00
0005433960929	25931	Economy	12100.00
0005433986017	25931	Economy	12100.00
0005433960947	25931	Economy	12100.00
0005433960914	25931	Economy	12100.00
0005433985986	25931	Economy	12100.00
0005433986008	25931	Economy	12100.00
0005433960924	25931	Economy	12100.00
0005433960933	25931	Economy	12100.00
0005433960973	25931	Economy	12100.00
0005433986019	25931	Economy	12100.00
0005433960917	25931	Economy	12100.00
0005433986020	25931	Economy	12100.00
0005433986012	25931	Economy	12100.00
0005433985987	25931	Economy	12100.00
0005433986022	25931	Economy	12100.00
0005433960915	25931	Economy	12100.00
0005433960941	25931	Economy	12100.00
0005433985997	25931	Economy	12100.00
0005433985993	25931	Economy	12100.00
0005433960962	25931	Economy	12100.00
0005433960949	25931	Economy	12100.00
0005433960919	25931	Economy	12100.00
0005433960938	25931	Economy	12100.00
0005433960932	25931	Economy	12100.00
0005433960913	25931	Economy	12100.00
0005433960935	25931	Economy	13400.00
0005433960967	25931	Economy	12100.00
0005433960945	25931	Economy	12100.00
0005433960963	25931	Economy	12100.00
0005433986009	25931	Economy	12100.00
0005433960936	25931	Economy	12100.00
0005433986025	25931	Economy	12100.00
0005433960951	25931	Economy	12100.00
0005433986024	25931	Economy	12100.00
0005433960972	25931	Economy	12100.00
0005433960946	25931	Economy	12100.00
0005433960916	25931	Economy	12100.00
0005433960926	25931	Economy	12100.00
0005433960927	25931	Economy	12100.00
0005433960969	25931	Economy	12100.00
0005433986015	25931	Economy	12100.00
0005433986016	25931	Economy	12100.00
0005433985998	25931	Economy	12100.00
0005433986026	25931	Economy	12100.00
0005433960966	25931	Economy	12100.00
0005433986004	25931	Economy	12100.00
0005433960928	25931	Economy	12100.00
0005433986000	25931	Economy	12100.00
0005433960955	25931	Economy	12100.00
0005433960918	25931	Economy	12100.00
0005433960931	25931	Economy	12100.00
0005433986002	25931	Economy	12100.00
0005433986006	25931	Economy	12100.00
0005433985994	25931	Economy	12100.00
0005433960950	25931	Economy	12100.00
0005433960968	25931	Economy	12100.00
0005433960940	25931	Economy	12100.00
0005433986013	25931	Economy	12100.00
0005433986007	25931	Economy	12100.00
0005433960956	25931	Economy	12100.00
0005433960959	25931	Economy	12100.00
0005434480392	919	Economy	25400.00
0005434480369	919	Economy	25400.00
0005433165798	919	Economy	25400.00
0005434480378	919	Economy	23100.00
0005434480368	919	Economy	23100.00
0005434480374	919	Economy	23100.00
0005433165874	919	Economy	23100.00
0005434480388	919	Economy	23100.00
0005432269500	919	Economy	23100.00
0005434480389	919	Economy	23100.00
0005433165831	919	Economy	23100.00
0005434480372	919	Economy	23100.00
0005434480385	919	Economy	23100.00
0005434480367	919	Economy	23100.00
0005432269501	919	Economy	23100.00
0005434480381	919	Economy	23100.00
0005434480384	919	Economy	23100.00
0005434480387	919	Economy	23100.00
0005434480376	919	Economy	23100.00
0005433165830	919	Economy	23100.00
0005433165800	919	Economy	23100.00
0005434480379	919	Economy	23100.00
0005434480373	919	Economy	23100.00
0005434480370	919	Economy	23100.00
0005433165875	919	Economy	23100.00
0005434480386	919	Economy	23100.00
0005434480380	919	Economy	23100.00
0005434480377	919	Economy	23100.00
0005434480391	919	Economy	23100.00
0005434480383	919	Economy	23100.00
0005434480382	919	Economy	23100.00
0005433165812	919	Economy	23100.00
0005434480390	919	Economy	23100.00
0005434480375	919	Economy	23100.00
0005434480371	919	Economy	23100.00
0005433165829	919	Economy	23100.00
0005433165859	919	Economy	23100.00
0005434480083	16598	Economy	25400.00
0005434480101	16598	Economy	23100.00
0005434480231	16598	Economy	23100.00
0005434480146	16598	Economy	23100.00
0005433165935	16598	Economy	23100.00
0005434480255	16598	Economy	23100.00
0005434480302	16598	Economy	23100.00
0005434480198	16598	Economy	23100.00
0005433165930	16598	Economy	23100.00
0005434480100	16598	Economy	23100.00
0005433165924	16598	Economy	23100.00
0005434480176	16598	Economy	23100.00
0005433165931	16598	Economy	23100.00
0005434480109	16598	Economy	23100.00
0005434480186	16598	Economy	23100.00
0005434480134	16598	Economy	23100.00
0005434480256	16598	Economy	23100.00
0005434480193	16598	Economy	23100.00
0005433165926	16598	Economy	23100.00
0005433165925	16598	Economy	23100.00
0005433165928	16598	Economy	23100.00
0005434480261	16598	Economy	23100.00
0005434480180	16598	Economy	23100.00
0005433165932	16598	Economy	23100.00
0005434480110	16598	Economy	23100.00
0005433165934	16598	Economy	23100.00
0005433165927	16598	Economy	23100.00
0005434480133	16598	Economy	23100.00
0005434480082	16598	Economy	23100.00
0005434480095	16598	Economy	23100.00
0005433165929	16598	Economy	23100.00
0005434480189	16598	Economy	23100.00
0005433165933	16598	Economy	23100.00
0005434480230	16598	Economy	23100.00
0005434480175	16598	Economy	23100.00
0005435150041	10321	Economy	17000.00
0005435150040	10321	Economy	17000.00
0005435150051	10321	Economy	17000.00
0005435142590	10321	Economy	15400.00
0005435150044	10321	Economy	15400.00
0005433289769	10321	Economy	15400.00
0005435150039	10321	Economy	15400.00
0005435142595	10321	Economy	15400.00
0005435386501	10321	Economy	15400.00
0005435386511	10321	Economy	15400.00
0005435150042	10321	Economy	15400.00
0005435150043	10321	Economy	15400.00
0005435142586	10321	Economy	15400.00
0005435142593	10321	Economy	15400.00
0005435142598	10321	Economy	15400.00
0005435150048	10321	Economy	15400.00
0005435150047	10321	Economy	15400.00
0005433289792	10321	Economy	15400.00
0005435142594	10321	Economy	15400.00
0005435150049	10321	Economy	15400.00
0005435150050	10321	Economy	15400.00
0005435142597	10321	Economy	15400.00
0005435150037	10321	Economy	15400.00
0005435142589	10321	Economy	15400.00
0005433289770	10321	Economy	15400.00
0005435142588	10321	Economy	15400.00
0005435150046	10321	Economy	15400.00
0005435150038	10321	Economy	15400.00
0005435386526	10321	Economy	15400.00
0005435142592	10321	Economy	15400.00
0005435142591	10321	Economy	15400.00
0005433289791	10321	Economy	15400.00
0005435142585	10321	Economy	15400.00
0005435386512	10321	Economy	15400.00
0005435150045	10321	Economy	15400.00
0005433289801	10321	Economy	15400.00
0005435142587	10321	Economy	15400.00
0005435386500	10321	Economy	15400.00
0005433289798	10321	Economy	15400.00
0005435142596	10321	Economy	15400.00
0005433289871	21942	Economy	17000.00
0005435386579	21942	Economy	17000.00
0005435142421	21942	Economy	17000.00
0005435149910	21942	Economy	17000.00
0005435142417	21942	Economy	15400.00
0005435386582	21942	Economy	15400.00
0005435386580	21942	Economy	15400.00
0005435149971	21942	Economy	15400.00
0005435149853	21942	Economy	15400.00
0005435142465	21942	Economy	15400.00
0005435386584	21942	Economy	15400.00
0005435142448	21942	Economy	15400.00
0005433289867	21942	Economy	15400.00
0005435142529	21942	Economy	15400.00
0005433289866	21942	Economy	15400.00
0005435149962	21942	Economy	15400.00
0005435142464	21942	Economy	15400.00
0005433289872	21942	Economy	15400.00
0005435386581	21942	Economy	15400.00
0005435142478	21942	Economy	15400.00
0005435142468	21942	Economy	15400.00
0005435386586	21942	Economy	15400.00
0005433289868	21942	Economy	15400.00
0005435142463	21942	Economy	15400.00
0005435142440	21942	Economy	15400.00
0005435149906	21942	Economy	15400.00
0005435142439	21942	Economy	15400.00
0005433289870	21942	Economy	15400.00
0005433289865	21942	Economy	15400.00
0005435142422	21942	Economy	15400.00
0005435149909	21942	Economy	15400.00
0005435142528	21942	Economy	15400.00
0005435142495	21942	Economy	15400.00
0005435386585	21942	Economy	15400.00
0005433289869	21942	Economy	15400.00
0005435142511	21942	Economy	15400.00
0005435142512	21942	Economy	15400.00
0005435386583	21942	Economy	15400.00
0005435502066	11215	Business	57200.00
0005435319508	11215	Business	57200.00
0005434573368	11215	Business	57200.00
0005434573367	11215	Business	57200.00
0005435529126	11215	Business	57200.00
0005435529143	11215	Business	57200.00
0005435529180	11215	Business	57200.00
0005434573373	11215	Business	57200.00
0005435319510	11215	Business	57200.00
0005435319498	11215	Economy	19100.00
0005435545707	11215	Economy	19100.00
0005434573370	11215	Economy	19100.00
0005435545710	11215	Economy	19100.00
0005435319551	11215	Economy	19100.00
0005435529130	11215	Economy	19100.00
0005435319509	11215	Economy	21000.00
0005434573374	11215	Economy	21000.00
0005435319530	11215	Economy	21000.00
0005435529081	11215	Economy	19100.00
0005435319531	11215	Economy	19100.00
0005435528980	11215	Economy	19100.00
0005435529066	11215	Economy	19100.00
0005435319552	11215	Economy	19100.00
0005435529072	11215	Economy	19100.00
0005435502214	11215	Economy	19100.00
0005435529107	11215	Economy	19100.00
0005435319545	11215	Economy	19100.00
0005435319497	11215	Economy	19100.00
0005435529129	11215	Economy	19100.00
0005435545712	11215	Economy	19100.00
0005435502088	11215	Economy	19100.00
0005434573361	11215	Economy	19100.00
0005435545678	11215	Economy	19100.00
0005434573362	11215	Economy	19100.00
0005435545655	11215	Economy	19100.00
0005435529179	11215	Economy	19100.00
0005434573372	11215	Economy	19100.00
0005435502159	11215	Economy	19100.00
0005435545715	11215	Economy	19100.00
0005435529210	11215	Economy	19100.00
0005435502158	11215	Economy	19100.00
0005435545672	11215	Economy	19100.00
0005434573363	11215	Economy	19100.00
0005435502195	11215	Economy	19100.00
0005435529067	11215	Economy	19100.00
0005435529037	11215	Economy	19100.00
0005435502154	11215	Economy	19100.00
0005435502172	11215	Economy	19100.00
0005435528942	11215	Economy	19100.00
0005435319515	11215	Economy	19100.00
0005435529125	11215	Economy	19100.00
0005435545679	11215	Economy	19100.00
0005435502202	11215	Economy	19100.00
0005435529108	11215	Economy	19100.00
0005434573365	11215	Economy	19100.00
0005434573364	11215	Economy	19100.00
0005435529118	11215	Economy	19100.00
0005435529106	11215	Economy	19100.00
0005435502194	11215	Economy	19100.00
0005435502083	11215	Economy	19100.00
0005434573366	11215	Economy	19100.00
0005434573369	11215	Economy	19100.00
0005435529109	11215	Economy	19100.00
0005435545716	11215	Economy	19100.00
0005435545680	11215	Economy	19100.00
0005435545650	11215	Economy	19100.00
0005434573371	11215	Economy	19100.00
0005435502224	11215	Economy	19100.00
0005435502345	20947	Business	57200.00
0005435319600	20947	Business	57200.00
0005435508390	20947	Business	57200.00
0005435517939	20947	Business	57200.00
0005435319604	20947	Business	57200.00
0005434573261	20947	Business	57200.00
0005435517928	20947	Business	57200.00
0005435502347	20947	Business	57200.00
0005435517945	20947	Business	57200.00
0005435517938	20947	Business	57200.00
0005435517934	20947	Business	57200.00
0005435502350	20947	Business	57200.00
0005435319598	20947	Economy	19100.00
0005435508379	20947	Economy	19100.00
0005435502344	20947	Economy	19100.00
0005435502349	20947	Economy	19100.00
0005435502337	20947	Economy	19100.00
0005435517941	20947	Economy	19100.00
0005435508385	20947	Economy	21000.00
0005434573288	20947	Economy	21000.00
0005435508382	20947	Economy	21000.00
0005435502331	20947	Economy	21000.00
0005434573302	20947	Economy	21000.00
0005435517935	20947	Economy	19100.00
0005435508383	20947	Economy	19100.00
0005435502341	20947	Economy	19100.00
0005435517932	20947	Economy	19100.00
0005435502332	20947	Economy	19100.00
0005435517931	20947	Economy	19100.00
0005432291932	20947	Economy	19100.00
0005435517943	20947	Economy	19100.00
0005435502340	20947	Economy	19100.00
0005435502335	20947	Economy	19100.00
0005435508381	20947	Economy	19100.00
0005435508387	20947	Economy	19100.00
0005435517936	20947	Economy	19100.00
0005435502343	20947	Economy	19100.00
0005435502334	20947	Economy	19100.00
0005435319599	20947	Economy	19100.00
0005435502336	20947	Economy	19100.00
0005434573303	20947	Economy	19100.00
0005434573226	20947	Economy	19100.00
0005435319597	20947	Economy	19100.00
0005434573251	20947	Economy	19100.00
0005435508380	20947	Economy	19100.00
0005435508391	20947	Economy	19100.00
0005432291933	20947	Economy	19100.00
0005435502339	20947	Economy	19100.00
0005432291934	20947	Economy	19100.00
0005435319601	20947	Economy	19100.00
0005435517944	20947	Economy	19100.00
0005435502338	20947	Economy	19100.00
0005435508389	20947	Economy	19100.00
0005435319603	20947	Economy	19100.00
0005435517940	20947	Economy	19100.00
0005435502342	20947	Economy	19100.00
0005435508386	20947	Economy	19100.00
0005435517942	20947	Economy	19100.00
0005435517930	20947	Economy	19100.00
0005435517937	20947	Economy	19100.00
0005435502346	20947	Economy	19100.00
0005435517929	20947	Economy	19100.00
0005435508388	20947	Economy	19100.00
0005435508384	20947	Economy	19100.00
0005435502348	20947	Economy	19100.00
0005435502333	20947	Economy	19100.00
0005435502351	20947	Economy	19100.00
0005435319602	20947	Economy	19100.00
0005435517933	20947	Economy	19100.00
0005435319596	20947	Economy	19100.00
0005432692888	3053	Business	10300.00
0005432692983	3053	Business	10300.00
0005432692801	3053	Economy	3400.00
0005432692783	3053	Economy	3400.00
0005432692802	3053	Economy	3400.00
0005432692877	3053	Economy	3800.00
0005432692799	3053	Economy	3400.00
0005432692789	3053	Economy	3400.00
0005432692964	3053	Economy	3400.00
0005432692992	3053	Economy	3400.00
0005432692993	3053	Economy	3400.00
0005432692825	3053	Economy	3400.00
0005432692812	3053	Economy	3400.00
0005432692761	3053	Economy	3400.00
0005432692829	3053	Economy	3400.00
0005432692878	3053	Economy	3400.00
0005432692791	3053	Economy	3400.00
0005432692982	3053	Economy	3400.00
0005432692966	3053	Economy	3400.00
0005432692758	3053	Economy	3400.00
0005432692781	3053	Economy	3400.00
0005432692994	3053	Economy	3400.00
0005432692762	3053	Economy	3400.00
0005432692965	3053	Economy	3400.00
0005432692884	3053	Economy	3400.00
0005432692889	3053	Economy	3400.00
0005432692782	3053	Economy	3400.00
0005432692893	3053	Economy	3400.00
0005432692728	3053	Economy	3400.00
0005432692923	3053	Economy	3400.00
0005432692790	3053	Economy	3400.00
0005432692800	3053	Economy	3400.00
0005432706822	3052	Business	10300.00
0005433123858	3052	Business	10300.00
0005432706809	3052	Business	10300.00
0005432706806	3052	Business	10300.00
0005432706826	3052	Business	10300.00
0005432706818	3052	Business	10300.00
0005433123778	3052	Business	10300.00
0005432706823	3052	Economy	3400.00
0005432706828	3052	Economy	3400.00
0005433123777	3052	Economy	3400.00
0005432706805	3052	Economy	3400.00
0005432880732	3052	Economy	3400.00
0005433123780	3052	Economy	3400.00
0005432880687	3052	Economy	3800.00
0005432880714	3052	Economy	3800.00
0005433123732	3052	Economy	3400.00
0005432706821	3052	Economy	3400.00
0005432706808	3052	Economy	3400.00
0005432217780	3052	Economy	3400.00
0005433123812	3052	Economy	3400.00
0005432706816	3052	Economy	3400.00
0005432706811	3052	Economy	3400.00
0005433123798	3052	Economy	3400.00
0005432880769	3052	Economy	3400.00
0005433123823	3052	Economy	3400.00
0005432880715	3052	Economy	3400.00
0005432217781	3052	Economy	3400.00
0005433194846	3052	Economy	3400.00
0005432706827	3052	Economy	3400.00
0005433123813	3052	Economy	3400.00
0005432880693	3052	Economy	3400.00
0005432880712	3052	Economy	3400.00
0005432706825	3052	Economy	3400.00
0005433123712	3052	Economy	3400.00
0005432880742	3052	Economy	3400.00
0005432706820	3052	Economy	3400.00
0005432706817	3052	Economy	3400.00
0005432880679	3052	Economy	3400.00
0005432880717	3052	Economy	3400.00
0005432706810	3052	Economy	3400.00
0005432880718	3052	Economy	3400.00
0005432217782	3052	Economy	3400.00
0005432706814	3052	Economy	3400.00
0005433123797	3052	Economy	3400.00
0005432706819	3052	Economy	3400.00
0005432880733	3052	Economy	3400.00
0005433123826	3052	Economy	3400.00
0005432706813	3052	Economy	3400.00
0005433123733	3052	Economy	3400.00
0005433123717	3052	Economy	3400.00
0005432706812	3052	Economy	3400.00
0005432706829	3052	Economy	3400.00
0005433123711	3052	Economy	3400.00
0005432880686	3052	Economy	3400.00
0005432706815	3052	Economy	3400.00
0005433194833	3052	Economy	3400.00
0005432706830	3052	Economy	3400.00
0005433123740	3052	Economy	3400.00
0005432880770	3052	Economy	3400.00
0005432706807	3052	Economy	3400.00
0005432706824	3052	Economy	3400.00
0005432706606	29999	Business	10300.00
0005432880840	29999	Business	10300.00
0005432880841	29999	Business	10300.00
0005432693149	29999	Business	10300.00
0005432706665	29999	Business	10300.00
0005432693139	29999	Business	10300.00
0005433123965	29999	Business	10300.00
0005432693146	29999	Business	10300.00
0005432693127	29999	Business	10300.00
0005433123962	29999	Business	10300.00
0005432693134	29999	Business	10300.00
0005432706568	29999	Business	10300.00
0005432693150	29999	Economy	3400.00
0005432693154	29999	Economy	3400.00
0005432693144	29999	Economy	3400.00
0005432706608	29999	Economy	3400.00
0005432693147	29999	Economy	3400.00
0005432880851	29999	Economy	3400.00
0005432706634	29999	Economy	3400.00
0005433123955	29999	Economy	3400.00
0005433123964	29999	Economy	3400.00
0005432706677	29999	Economy	3400.00
0005433123957	29999	Economy	3800.00
0005432706607	29999	Economy	3800.00
0005432880844	29999	Economy	3800.00
0005432706667	29999	Economy	3800.00
0005433123971	29999	Economy	3800.00
0005432693143	29999	Economy	3400.00
0005432706556	29999	Economy	3400.00
0005433123958	29999	Economy	3400.00
0005432706678	29999	Economy	3400.00
0005432706599	29999	Economy	3400.00
0005433123968	29999	Economy	3400.00
0005432693153	29999	Economy	3400.00
0005432706681	29999	Economy	3400.00
0005432880846	29999	Economy	3400.00
0005432706635	29999	Economy	3400.00
0005433123961	29999	Economy	3400.00
0005432880839	29999	Economy	3400.00
0005432693152	29999	Economy	3400.00
0005432880847	29999	Economy	3400.00
0005432693155	29999	Economy	3400.00
0005432880838	29999	Economy	3400.00
0005432706682	29999	Economy	3400.00
0005432706652	29999	Economy	3400.00
0005432706662	29999	Economy	3400.00
0005432693131	29999	Economy	3400.00
0005432706630	29999	Economy	3400.00
0005432693137	29999	Economy	3400.00
0005432693142	29999	Economy	3400.00
0005432880848	29999	Economy	3400.00
0005433123960	29999	Economy	3400.00
0005432880849	29999	Economy	3400.00
0005432880843	29999	Economy	3400.00
0005432693138	29999	Economy	3400.00
0005432693129	29999	Economy	3400.00
0005432693157	29999	Economy	3400.00
0005432706609	29999	Economy	3400.00
0005432693145	29999	Economy	3400.00
0005432706655	29999	Economy	3400.00
0005432880842	29999	Economy	3400.00
0005432706631	29999	Economy	3400.00
0005433123963	29999	Economy	3400.00
0005433123959	29999	Economy	3400.00
0005432706605	29999	Economy	3400.00
0005432693156	29999	Economy	3400.00
0005432706654	29999	Economy	3400.00
0005432706663	29999	Economy	3400.00
0005432706651	29999	Economy	3400.00
0005433123972	29999	Economy	3400.00
0005432706548	29999	Economy	3400.00
0005433123969	29999	Economy	3400.00
0005432693148	29999	Economy	3400.00
0005432693135	29999	Economy	3400.00
0005432706640	29999	Economy	3400.00
0005432880837	29999	Economy	3400.00
0005432693136	29999	Economy	3400.00
0005433123966	29999	Economy	3400.00
0005433123967	29999	Economy	3400.00
0005433123954	29999	Economy	3400.00
0005432693130	29999	Economy	3400.00
0005432693132	29999	Economy	3400.00
0005433123970	29999	Economy	3400.00
0005433123973	29999	Economy	3400.00
0005432693133	29999	Economy	3400.00
0005432693151	29999	Economy	3400.00
0005432693141	29999	Economy	3400.00
0005432880845	29999	Economy	3400.00
0005432693128	29999	Economy	3400.00
0005432693158	29999	Economy	3400.00
0005432706666	29999	Economy	3400.00
0005432706653	29999	Economy	3400.00
0005432706610	29999	Economy	3400.00
0005433123956	29999	Economy	3400.00
0005432880850	29999	Economy	3400.00
0005432693140	29999	Economy	3400.00
0005432880836	29999	Economy	3400.00
0005434979835	23666	Economy	4000.00
0005434979833	23666	Economy	4000.00
0005434979818	23666	Economy	4000.00
0005434979819	23666	Economy	3600.00
0005434988754	23666	Economy	3600.00
0005434988762	23666	Economy	3600.00
0005434979831	23666	Economy	3600.00
0005434979810	23666	Economy	3600.00
0005434979820	23666	Economy	3600.00
0005434988753	23666	Economy	3600.00
0005434979816	23666	Economy	3600.00
0005434979832	23666	Economy	3600.00
0005434988761	23666	Economy	3600.00
0005434979827	23666	Economy	3600.00
0005434988752	23666	Economy	3600.00
0005434988755	23666	Economy	3600.00
0005434988757	23666	Economy	3600.00
0005434979836	23666	Economy	3600.00
0005434979822	23666	Economy	3600.00
0005434979829	23666	Economy	3600.00
0005434979812	23666	Economy	3600.00
0005434979834	23666	Economy	3600.00
0005434979826	23666	Economy	3600.00
0005434988756	23666	Economy	3600.00
0005434979809	23666	Economy	3600.00
0005434988760	23666	Economy	3600.00
0005434979821	23666	Economy	3600.00
0005434979815	23666	Economy	3600.00
0005434979814	23666	Economy	3600.00
0005434979808	23666	Economy	3600.00
0005434979817	23666	Economy	3600.00
0005434979806	23666	Economy	3600.00
0005434979807	23666	Economy	3600.00
0005434979823	23666	Economy	3600.00
0005434979828	23666	Economy	3600.00
0005434988759	23666	Economy	3600.00
0005434979825	23666	Economy	3600.00
0005434979813	23666	Economy	3600.00
0005434979811	23666	Economy	3600.00
0005434979824	23666	Economy	3600.00
0005434988758	23666	Economy	3600.00
0005434979830	23666	Economy	3600.00
0005434979656	27571	Economy	4000.00
0005434988656	27571	Economy	4000.00
0005434979517	27571	Economy	3600.00
0005434979630	27571	Economy	3600.00
0005434988623	27571	Economy	3600.00
0005434988655	27571	Economy	3600.00
0005434979629	27571	Economy	3600.00
0005434979644	27571	Economy	3600.00
0005434988624	27571	Economy	3600.00
0005434979469	27571	Economy	3600.00
0005434988642	27571	Economy	3600.00
0005434988622	27571	Economy	3600.00
0005434979472	27571	Economy	3600.00
0005434988665	27571	Economy	3600.00
0005434979645	27571	Economy	3600.00
0005434979564	27571	Economy	3600.00
0005434979468	27571	Economy	3600.00
0005434979631	27571	Economy	3600.00
0005434979609	27571	Economy	3600.00
0005434979643	27571	Economy	3600.00
0005434979447	27571	Economy	3600.00
0005434988654	27571	Economy	3600.00
0005434988620	27571	Economy	3600.00
0005434979588	27571	Economy	3600.00
0005434988677	27571	Economy	3600.00
0005434979519	27571	Economy	3600.00
0005434979524	27571	Economy	3600.00
0005434988634	27571	Economy	3600.00
0005434979569	27571	Economy	3600.00
0005434988621	27571	Economy	3600.00
0005434979520	27571	Economy	3600.00
0005434979473	27571	Economy	3600.00
0005433111495	10299	Economy	19700.00
0005433113515	10299	Economy	19700.00
0005433113516	10299	Economy	19700.00
0005434302462	10299	Economy	19700.00
0005433111492	10299	Economy	19700.00
0005434302466	10299	Economy	19700.00
0005434302463	10299	Economy	19700.00
0005434302465	10299	Economy	19700.00
0005433111494	10299	Economy	19700.00
0005433111493	10299	Economy	19700.00
0005433113513	10299	Economy	19700.00
0005433113523	10299	Economy	19700.00
0005433113514	10299	Economy	19700.00
0005434302464	10299	Economy	19700.00
0005434302416	19637	Economy	19700.00
0005434302419	19637	Economy	19700.00
0005433113539	19637	Economy	19700.00
0005433113540	19637	Economy	19700.00
0005434302427	19637	Economy	19700.00
0005433113541	19637	Economy	19700.00
0005434302417	19637	Economy	19700.00
0005434302418	19637	Economy	19700.00
0005435069171	3532	Business	26900.00
0005435925213	3532	Business	26900.00
0005435069168	3532	Business	26900.00
0005435069209	3532	Business	26900.00
0005435069172	3532	Business	26900.00
0005435925197	3532	Business	26900.00
0005435069206	3532	Business	26900.00
0005435069197	3532	Business	26900.00
0005435069187	3532	Business	26900.00
0005435069170	3532	Business	26900.00
0005435069167	3532	Business	26900.00
0005435718954	3532	Economy	9000.00
0005435925188	3532	Economy	9000.00
0005435925108	3532	Economy	9000.00
0005435069199	3532	Economy	9000.00
0005435925201	3532	Economy	9000.00
0005435069180	3532	Economy	9000.00
0005435069207	3532	Economy	9000.00
0005435069193	3532	Economy	9900.00
0005435069216	3532	Economy	9900.00
0005435939868	3532	Economy	9900.00
0005435925174	3532	Economy	9900.00
0005435069181	3532	Economy	9000.00
0005435925206	3532	Economy	9000.00
0005435069214	3532	Economy	9000.00
0005435718958	3532	Economy	9000.00
0005435069169	3532	Economy	9000.00
0005435069179	3532	Economy	9000.00
0005435069192	3532	Economy	9000.00
0005435718960	3532	Economy	9000.00
0005435069194	3532	Economy	9000.00
0005435069198	3532	Economy	9000.00
0005435069189	3532	Economy	9000.00
0005435069185	3532	Economy	9000.00
0005435069200	3532	Economy	9000.00
0005435718956	3532	Economy	9000.00
0005435069211	3532	Economy	9000.00
0005435069182	3532	Economy	9000.00
0005435925204	3532	Economy	9000.00
0005435069212	3532	Economy	9000.00
0005435718957	3532	Economy	9000.00
0005435925158	3532	Economy	9000.00
0005435069184	3532	Economy	9000.00
0005435069210	3532	Economy	9000.00
0005435069175	3532	Economy	9000.00
0005435925216	3532	Economy	9000.00
0005435069215	3532	Economy	9000.00
0005435069196	3532	Economy	9000.00
0005435069213	3532	Economy	9000.00
0005435925198	3532	Economy	9000.00
0005435718959	3532	Economy	9000.00
0005435069176	3532	Economy	9000.00
0005435069208	3532	Economy	9000.00
0005435925218	3532	Economy	9000.00
0005435069217	3532	Economy	9000.00
0005435069205	3532	Economy	9000.00
0005435925211	3532	Economy	9000.00
0005435069188	3532	Economy	9000.00
0005435069203	3532	Economy	9000.00
0005435718961	3532	Economy	9000.00
0005435069174	3532	Economy	9000.00
0005435925151	3532	Economy	9000.00
0005435925215	3532	Economy	9000.00
0005435069186	3532	Economy	9000.00
0005435950296	3532	Economy	9000.00
0005435069190	3532	Economy	9000.00
0005435069183	3532	Economy	9000.00
0005435069202	3532	Economy	9000.00
0005435069173	3532	Economy	9000.00
0005435069178	3532	Economy	9000.00
0005435718955	3532	Economy	9000.00
0005435069191	3532	Economy	9000.00
0005435069177	3532	Economy	9000.00
0005435069195	3532	Economy	9000.00
0005435069201	3532	Economy	9000.00
0005435069204	3532	Economy	9000.00
0005435925202	3532	Economy	9000.00
0005435068626	15328	Business	26900.00
0005435068802	15328	Business	26900.00
0005435068787	15328	Business	26900.00
0005435068692	15328	Business	26900.00
0005435925315	15328	Business	26900.00
0005435925305	15328	Business	26900.00
0005435925313	15328	Business	26900.00
0005435925314	15328	Business	26900.00
0005435068436	15328	Economy	9000.00
0005435925312	15328	Economy	9000.00
0005435068688	15328	Economy	9000.00
0005435068770	15328	Economy	9000.00
0005435068624	15328	Economy	9000.00
0005435925321	15328	Economy	9000.00
0005435068598	15328	Economy	9000.00
0005435068597	15328	Economy	9000.00
0005435068707	15328	Economy	9900.00
0005435068826	15328	Economy	9900.00
0005435068619	15328	Economy	9900.00
0005435925308	15328	Economy	9900.00
0005435068712	15328	Economy	9000.00
0005435068861	15328	Economy	9000.00
0005435925307	15328	Economy	9000.00
0005435925320	15328	Economy	9000.00
0005435068846	15328	Economy	9000.00
0005435068789	15328	Economy	9000.00
0005435925318	15328	Economy	9000.00
0005435068734	15328	Economy	9000.00
0005435068804	15328	Economy	9000.00
0005435068643	15328	Economy	9000.00
0005435925309	15328	Economy	9000.00
0005435068466	15328	Economy	9000.00
0005435925306	15328	Economy	9000.00
0005435068717	15328	Economy	9000.00
0005435068803	15328	Economy	9000.00
0005435068784	15328	Economy	9000.00
0005435068725	15328	Economy	9000.00
0005435925322	15328	Economy	9000.00
0005435925324	15328	Economy	9000.00
0005435068778	15328	Economy	9000.00
0005435925317	15328	Economy	9000.00
0005435925319	15328	Economy	9000.00
0005435068835	15328	Economy	9000.00
0005435068620	15328	Economy	9000.00
0005435925311	15328	Economy	9000.00
0005435068540	15328	Economy	9000.00
0005435925310	15328	Economy	9000.00
0005435068524	15328	Economy	9000.00
0005435068641	15328	Economy	9000.00
0005435068642	15328	Economy	9000.00
0005435068799	15328	Economy	9000.00
0005435939882	15328	Economy	9000.00
0005435068733	15328	Economy	9000.00
0005435068859	15328	Economy	9000.00
0005435925316	15328	Economy	9000.00
0005435925323	15328	Economy	9000.00
0005435068539	15328	Economy	9000.00
0005435068761	15328	Economy	9000.00
0005435068567	15328	Economy	9000.00
0005435068614	15328	Economy	9000.00
0005435068621	15328	Economy	9000.00
0005435068704	15328	Economy	9000.00
0005435068592	15328	Economy	9000.00
0005435068736	15328	Economy	9000.00
0005435068737	15328	Economy	9000.00
0005432660822	18159	Economy	5900.00
0005432659709	18159	Economy	5900.00
0005432659710	18159	Economy	5900.00
0005432658595	18159	Economy	5900.00
0005432660821	18159	Economy	5900.00
0005432660793	26434	Economy	5900.00
0005432667435	26434	Economy	5900.00
0005432664116	26434	Economy	5900.00
0005432664126	26434	Economy	5900.00
0005432664123	26434	Economy	5900.00
0005432667436	26434	Economy	5900.00
0005432664115	26434	Economy	5900.00
0005432667442	26434	Economy	5900.00
0005432664121	26434	Economy	5900.00
0005432664124	26434	Economy	5900.00
0005432901529	223	Business	20000.00
0005432919657	223	Business	20000.00
0005432919661	223	Business	20000.00
0005433101674	223	Business	20000.00
0005433101859	223	Business	20000.00
0005433101837	223	Business	20000.00
0005433101809	223	Business	20000.00
0005433101752	223	Business	20000.00
0005433101810	223	Business	20000.00
0005432901525	223	Business	20000.00
0005432919696	223	Business	20000.00
0005433101778	223	Business	20000.00
0005433101803	223	Business	20000.00
0005432901524	223	Business	20000.00
0005432919721	223	Business	20000.00
0005433101735	223	Business	20000.00
0005432677547	223	Business	20000.00
0005433101680	223	Business	20000.00
0005433101714	223	Economy	7300.00
0005432919641	223	Economy	7300.00
0005432901498	223	Economy	7300.00
0005433101700	223	Economy	7300.00
0005433101857	223	Economy	7300.00
0005433101607	223	Economy	6700.00
0005432901506	223	Economy	6700.00
0005432919695	223	Economy	6700.00
0005432901488	223	Economy	6700.00
0005433101830	223	Economy	6700.00
0005432677536	223	Economy	6700.00
0005432919764	223	Economy	6700.00
0005433101753	223	Economy	6700.00
0005432919779	223	Economy	6700.00
0005433101658	223	Economy	6700.00
0005433101498	223	Economy	6700.00
0005433101853	223	Economy	6700.00
0005432919672	223	Economy	6700.00
0005433101635	223	Economy	6700.00
0005432157495	223	Economy	6700.00
0005433101651	223	Economy	6700.00
0005432919720	223	Economy	6700.00
0005433101844	223	Economy	6700.00
0005432901526	223	Economy	6700.00
0005433101834	223	Economy	6700.00
0005432901505	223	Economy	6700.00
0005432919731	223	Economy	6700.00
0005433101593	223	Economy	6700.00
0005433101755	223	Economy	6700.00
0005432919826	223	Economy	6700.00
0005433101661	223	Economy	6700.00
0005433101675	223	Economy	6700.00
0005433101659	223	Economy	6700.00
0005433101754	223	Economy	6700.00
0005433101856	223	Economy	6700.00
0005432901533	223	Economy	6700.00
0005433101862	223	Economy	6700.00
0005433101774	223	Economy	6700.00
0005432901532	223	Economy	6700.00
0005432901528	223	Economy	7300.00
0005432901584	223	Economy	6700.00
0005432901502	223	Economy	6700.00
0005432919814	223	Economy	6700.00
0005433101845	223	Economy	6700.00
0005432677535	223	Economy	6700.00
0005432919815	223	Economy	6700.00
0005433101614	223	Economy	6700.00
0005433101676	223	Economy	6700.00
0005433101831	223	Economy	6700.00
0005433101795	223	Economy	6700.00
0005433101775	223	Economy	6700.00
0005432901487	223	Economy	6700.00
0005433101812	223	Economy	6700.00
0005432919739	223	Economy	6700.00
0005433101758	223	Economy	6700.00
0005433101805	223	Economy	6700.00
0005433101804	223	Economy	6700.00
0005432157496	223	Economy	6700.00
0005433101679	223	Economy	6700.00
0005432901486	223	Economy	6700.00
0005433101833	223	Economy	6700.00
0005432919656	223	Economy	6700.00
0005432919594	223	Economy	6700.00
0005433101843	223	Economy	6700.00
0005432919687	223	Economy	6700.00
0005433101742	223	Economy	6700.00
0005432919827	223	Economy	6700.00
0005433101826	223	Economy	6700.00
0005432919642	223	Economy	6700.00
0005433101723	223	Economy	6700.00
0005433101660	223	Economy	6700.00
0005433101823	223	Economy	6700.00
0005433101497	223	Economy	6700.00
0005432677546	223	Economy	6700.00
0005433101824	223	Economy	6700.00
0005433101705	223	Economy	6700.00
0005432919756	223	Economy	6700.00
0005432919732	223	Economy	6700.00
0005433101836	223	Economy	6700.00
0005433101645	223	Economy	6700.00
0005432901477	223	Economy	6700.00
0005433101825	223	Economy	6700.00
0005432817544	224	Business	20000.00
0005432817543	224	Business	20000.00
0005432756820	224	Business	20000.00
0005432262010	224	Business	20000.00
0005432262018	224	Business	20000.00
0005432817519	224	Business	20000.00
0005432753283	224	Business	20000.00
0005432817534	224	Business	20000.00
0005432817539	224	Business	20000.00
0005432261993	224	Business	20000.00
0005432262017	224	Business	20000.00
0005432817523	224	Business	20000.00
0005432817531	224	Business	20000.00
0005432262016	224	Business	20000.00
0005432261997	224	Business	20000.00
0005432262019	224	Business	20000.00
0005432817521	224	Business	20000.00
0005432262006	224	Business	20000.00
0005432262015	224	Economy	7300.00
0005432261996	224	Economy	7300.00
0005432753280	224	Economy	7300.00
0005432261999	224	Economy	7300.00
0005432262011	224	Economy	7300.00
0005432261982	224	Economy	6700.00
0005432817542	224	Economy	6700.00
0005433687679	224	Economy	6700.00
0005432261988	224	Economy	6700.00
0005432817532	224	Economy	6700.00
0005432262009	224	Economy	6700.00
0005432261985	224	Economy	6700.00
0005432261976	224	Economy	6700.00
0005432262005	224	Economy	6700.00
0005432817540	224	Economy	6700.00
0005434153536	224	Economy	6700.00
0005432817528	224	Economy	6700.00
0005432262000	224	Economy	6700.00
0005432262012	224	Economy	6700.00
0005432262022	224	Economy	6700.00
0005432817529	224	Economy	6700.00
0005432262001	224	Economy	6700.00
0005432288992	224	Economy	6700.00
0005432817526	224	Economy	6700.00
0005432261991	224	Economy	6700.00
0005432817530	224	Economy	6700.00
0005432262004	224	Economy	6700.00
0005432817525	224	Economy	6700.00
0005432261989	224	Economy	6700.00
0005434153538	224	Economy	6700.00
0005432261995	224	Economy	6700.00
0005432261994	224	Economy	6700.00
0005432817517	224	Economy	6700.00
0005432817545	224	Economy	6700.00
0005432262002	224	Economy	6700.00
0005432262003	224	Economy	6700.00
0005432817516	224	Economy	7300.00
0005432207665	224	Economy	7300.00
0005432817535	224	Economy	7300.00
0005432753274	224	Economy	7300.00
0005432817518	224	Economy	6700.00
0005432262023	224	Economy	7300.00
0005432817538	224	Economy	6700.00
0005432288993	224	Economy	6700.00
0005432261979	224	Economy	6700.00
0005432261984	224	Economy	6700.00
0005432261990	224	Economy	6700.00
0005432262020	224	Economy	6700.00
0005432262013	224	Economy	6700.00
0005433687678	224	Economy	6700.00
0005432261977	224	Economy	6700.00
0005432753273	224	Economy	6700.00
0005432261983	224	Economy	6700.00
0005432261987	224	Economy	6700.00
0005432817541	224	Economy	6700.00
0005432261980	224	Economy	6700.00
0005432261978	224	Economy	6700.00
0005432261981	224	Economy	6700.00
0005432262008	224	Economy	6700.00
0005434153537	224	Economy	6700.00
0005432817537	224	Economy	6700.00
0005432261998	224	Economy	6700.00
0005432817527	224	Economy	6700.00
0005432262007	224	Economy	6700.00
0005432207664	224	Economy	6700.00
0005432261986	224	Economy	6700.00
0005432817524	224	Economy	6700.00
0005432753281	224	Economy	6700.00
0005432262014	224	Economy	6700.00
0005432261992	224	Economy	6700.00
0005434153535	224	Economy	6700.00
0005432753282	224	Economy	6700.00
0005432817520	224	Economy	6700.00
0005432817536	224	Economy	6700.00
0005432817522	224	Economy	6700.00
0005432262021	224	Economy	6700.00
0005432817533	224	Economy	6700.00
0005432045618	8006	Business	20000.00
0005433102268	8006	Business	20000.00
0005432919889	8006	Business	20000.00
0005432919904	8006	Business	20000.00
0005432751532	8006	Business	20000.00
0005433102256	8006	Business	20000.00
0005432919890	8006	Business	20000.00
0005432020306	8006	Business	20000.00
0005432919891	8006	Business	20000.00
0005433102246	8006	Business	20000.00
0005432919902	8006	Business	20000.00
0005433102292	8006	Business	20000.00
0005432044529	8006	Business	20000.00
0005433102273	8006	Business	20000.00
0005432919896	8006	Business	20000.00
0005432020324	8006	Business	20000.00
0005432020302	8006	Business	20000.00
0005433102283	8006	Business	20000.00
0005433102240	8006	Business	20000.00
0005432020312	8006	Economy	7300.00
0005433102276	8006	Economy	7300.00
0005432020318	8006	Economy	7300.00
0005433102263	8006	Economy	7300.00
0005432020304	8006	Economy	7300.00
0005433102291	8006	Economy	6700.00
0005432392005	8006	Economy	6700.00
0005433102288	8006	Economy	6700.00
0005433102278	8006	Economy	6700.00
0005433102241	8006	Economy	6700.00
0005433102287	8006	Economy	6700.00
0005432919895	8006	Economy	6700.00
0005432919897	8006	Economy	6700.00
0005433102269	8006	Economy	6700.00
0005432751535	8006	Economy	6700.00
0005432020305	8006	Economy	6700.00
0005432020308	8006	Economy	6700.00
0005432020328	8006	Economy	6700.00
0005433102251	8006	Economy	6700.00
0005432045617	8006	Economy	6700.00
0005432919905	8006	Economy	6700.00
0005432020303	8006	Economy	6700.00
0005433102286	8006	Economy	6700.00
0005432020307	8006	Economy	6700.00
0005433102259	8006	Economy	6700.00
0005433102279	8006	Economy	6700.00
0005432044530	8006	Economy	6700.00
0005433102281	8006	Economy	6700.00
0005432020316	8006	Economy	6700.00
0005432919898	8006	Economy	6700.00
0005432020325	8006	Economy	6700.00
0005433102280	8006	Economy	6700.00
0005433102267	8006	Economy	6700.00
0005432020323	8006	Economy	6700.00
0005432392006	8006	Economy	6700.00
0005432919888	8006	Economy	6700.00
0005432751533	8006	Economy	6700.00
0005432020317	8006	Economy	6700.00
0005432020319	8006	Economy	6700.00
0005432753309	8006	Economy	6700.00
0005432020327	8006	Economy	6700.00
0005432919907	8006	Economy	6700.00
0005433102284	8006	Economy	6700.00
0005432020301	8006	Economy	6700.00
0005432751536	8006	Economy	6700.00
0005432751534	8006	Economy	6700.00
0005432020309	8006	Economy	7300.00
0005432919908	8006	Economy	7300.00
0005433102274	8006	Economy	6700.00
0005432020315	8006	Economy	6700.00
0005433102270	8006	Economy	6700.00
0005433102289	8006	Economy	7300.00
0005433102254	8006	Economy	6700.00
0005432919901	8006	Economy	6700.00
0005433102272	8006	Economy	6700.00
0005432020322	8006	Economy	6700.00
0005433102285	8006	Economy	6700.00
0005432020311	8006	Economy	6700.00
0005432020321	8006	Economy	6700.00
0005432677583	8006	Economy	6700.00
0005433102282	8006	Economy	6700.00
0005432677582	8006	Economy	6700.00
0005432919894	8006	Economy	6700.00
0005433102271	8006	Economy	6700.00
0005433102266	8006	Economy	6700.00
0005432020320	8006	Economy	6700.00
0005433102257	8006	Economy	6700.00
0005432919899	8006	Economy	6700.00
0005433102243	8006	Economy	6700.00
0005433102244	8006	Economy	6700.00
0005433102277	8006	Economy	6700.00
0005432919892	8006	Economy	6700.00
0005433102260	8006	Economy	6700.00
0005433102242	8006	Economy	6700.00
0005432020314	8006	Economy	6700.00
0005432919906	8006	Economy	6700.00
0005433102245	8006	Economy	6700.00
0005432753307	8006	Economy	6700.00
0005433102264	8006	Economy	6700.00
0005432677584	8006	Economy	6700.00
0005433102261	8006	Economy	6700.00
0005432919903	8006	Economy	6700.00
0005432020313	8006	Economy	6700.00
0005432020300	8006	Economy	6700.00
0005432919900	8006	Economy	6700.00
0005433102250	8006	Economy	6700.00
0005432753308	8006	Economy	6700.00
0005433102262	8006	Economy	6700.00
0005433102290	8006	Economy	6700.00
0005433102265	8006	Economy	6700.00
0005432753310	8006	Economy	6700.00
0005433102248	8006	Economy	6700.00
0005432044531	8006	Economy	6700.00
0005433102249	8006	Economy	6700.00
0005433102255	8006	Economy	6700.00
0005433102247	8006	Economy	6700.00
0005433102258	8006	Economy	6700.00
0005432020310	8006	Economy	6700.00
0005433102275	8006	Economy	6700.00
0005433102252	8006	Economy	6700.00
0005433102253	8006	Economy	6700.00
0005432919893	8006	Economy	6700.00
0005432020326	8006	Economy	6700.00
0005432901652	8007	Business	20000.00
0005432817301	8007	Business	20000.00
0005432901651	8007	Business	20000.00
0005432901650	8007	Business	20000.00
0005432901640	8007	Business	20000.00
0005432901648	8007	Business	20000.00
0005432817211	8007	Business	20000.00
0005432901643	8007	Economy	7300.00
0005432901636	8007	Economy	7300.00
0005432002079	8007	Economy	7300.00
0005432817275	8007	Economy	6700.00
0005432817401	8007	Economy	6700.00
0005432817320	8007	Economy	6700.00
0005432901635	8007	Economy	6700.00
0005432817225	8007	Economy	6700.00
0005432817171	8007	Economy	6700.00
0005432002081	8007	Economy	6700.00
0005432817253	8007	Economy	6700.00
0005432817359	8007	Economy	6700.00
0005432817353	8007	Economy	6700.00
0005432817210	8007	Economy	6700.00
0005432901639	8007	Economy	6700.00
0005432817286	8007	Economy	6700.00
0005432817185	8007	Economy	6700.00
0005432901645	8007	Economy	6700.00
0005432817170	8007	Economy	6700.00
0005432901649	8007	Economy	7300.00
0005432901647	8007	Economy	6700.00
0005432817418	8007	Economy	6700.00
0005432901642	8007	Economy	6700.00
0005432817267	8007	Economy	6700.00
0005432901641	8007	Economy	6700.00
0005432901637	8007	Economy	6700.00
0005432817268	8007	Economy	6700.00
0005432817289	8007	Economy	6700.00
0005432817285	8007	Economy	6700.00
0005432817310	8007	Economy	6700.00
0005432817311	8007	Economy	6700.00
0005432817419	8007	Economy	6700.00
0005432901638	8007	Economy	6700.00
0005432002080	8007	Economy	6700.00
0005432901644	8007	Economy	6700.00
0005432901646	8007	Economy	6700.00
0005434175720	9678	Economy	6900.00
0005434175740	9678	Economy	6900.00
0005434175738	9678	Economy	6900.00
0005433870734	9678	Economy	6900.00
0005434175737	9678	Economy	6900.00
0005434175739	9678	Economy	6900.00
0005433870735	9678	Economy	6900.00
0005434175741	9678	Economy	6900.00
0005434175719	9678	Economy	6900.00
0005433870736	9678	Economy	6900.00
0005433870737	9678	Economy	6900.00
0005434175761	32347	Economy	6900.00
0005434175760	32347	Economy	6900.00
0005434175759	32347	Economy	6900.00
0005434175762	32347	Economy	6900.00
0005433870721	32347	Economy	6900.00
0005433870722	32347	Economy	6900.00
0005432799514	3476	Business	35000.00
0005435902616	3476	Business	35000.00
0005434878411	3476	Business	35000.00
0005434938176	3476	Business	35000.00
0005432613870	3476	Business	35000.00
0005435913899	3476	Business	35000.00
0005434878458	3476	Business	35000.00
0005434878438	3476	Business	35000.00
0005432799517	3476	Business	35000.00
0005435126454	3476	Business	35000.00
0005434878392	3476	Business	35000.00
0005435126450	3476	Business	35000.00
0005435126441	3476	Business	35000.00
0005435841087	3476	Business	35000.00
0005434426657	3476	Business	35000.00
0005435626200	3476	Business	35000.00
0005434938188	3476	Business	35000.00
0005434426686	3476	Business	35000.00
0005434426681	3476	Business	35000.00
0005434878482	3476	Business	35000.00
0005435126459	3476	Business	35000.00
0005435841088	3476	Business	35000.00
0005434878440	3476	Business	35000.00
0005434878480	3476	Business	35000.00
0005434878445	3476	Business	35000.00
0005434878425	3476	Business	35000.00
0005434938191	3476	Comfort	19900.00
0005435126444	3476	Business	35000.00
0005434938179	3476	Comfort	19900.00
0005434426673	3476	Comfort	19900.00
0005434426658	3476	Comfort	19900.00
0005435626206	3476	Comfort	19900.00
0005434878435	3476	Comfort	19900.00
0005435902594	3476	Comfort	19900.00
0005435126455	3476	Comfort	19900.00
0005435626209	3476	Comfort	19900.00
0005435902605	3476	Comfort	19900.00
0005434938184	3476	Comfort	19900.00
0005434878475	3476	Comfort	19900.00
0005435626205	3476	Comfort	19900.00
0005434878391	3476	Comfort	19900.00
0005434878472	3476	Comfort	19900.00
0005432799506	3476	Comfort	19900.00
0005434878448	3476	Comfort	19900.00
0005435913894	3476	Comfort	19900.00
0005434878471	3476	Comfort	19900.00
0005434878457	3476	Comfort	19900.00
0005434878427	3476	Comfort	19900.00
0005435913893	3476	Comfort	19900.00
0005435126448	3476	Comfort	19900.00
0005435126471	3476	Comfort	19900.00
0005432799509	3476	Comfort	19900.00
0005434878397	3476	Comfort	19900.00
0005435126457	3476	Comfort	19900.00
0005434426662	3476	Comfort	19900.00
0005432799504	3476	Comfort	19900.00
0005435126447	3476	Comfort	19900.00
0005434426661	3476	Comfort	19900.00
0005432799511	3476	Comfort	19900.00
0005434938174	3476	Comfort	19900.00
0005434426670	3476	Comfort	19900.00
0005434938183	3476	Economy	11700.00
0005434878451	3476	Economy	11700.00
0005435126463	3476	Economy	11700.00
0005432799527	3476	Economy	11700.00
0005434878433	3476	Economy	11700.00
0005434878401	3476	Economy	11700.00
0005434938189	3476	Economy	11700.00
0005435913905	3476	Economy	11700.00
0005435126475	3476	Economy	11700.00
0005435626210	3476	Economy	11700.00
0005434878428	3476	Economy	11700.00
0005435626195	3476	Economy	11700.00
0005435913901	3476	Economy	11700.00
0005434426660	3476	Economy	11700.00
0005435126438	3476	Economy	11700.00
0005434426679	3476	Economy	11700.00
0005434878429	3476	Economy	11700.00
0005435626194	3476	Economy	11700.00
0005434878439	3476	Economy	11700.00
0005432799512	3476	Economy	11700.00
0005435902565	3476	Economy	11700.00
0005434878424	3476	Economy	11700.00
0005435902640	3476	Economy	11700.00
0005434938192	3476	Economy	11700.00
0005434878444	3476	Economy	11700.00
0005434878464	3476	Economy	11700.00
0005435126468	3476	Economy	11700.00
0005432799526	3476	Economy	11700.00
0005434878443	3476	Economy	11700.00
0005435902606	3476	Economy	11700.00
0005435626214	3476	Economy	11700.00
0005435902595	3476	Economy	11700.00
0005434878450	3476	Economy	11700.00
0005434938186	3476	Economy	11700.00
0005435126472	3476	Economy	11700.00
0005435626202	3476	Economy	11700.00
0005435626197	3476	Economy	11700.00
0005434878413	3476	Economy	11700.00
0005432799510	3476	Economy	11700.00
0005434426659	3476	Economy	11700.00
0005434878396	3476	Economy	11700.00
0005434878442	3476	Economy	11700.00
0005435626196	3476	Economy	11700.00
0005434426677	3476	Economy	11700.00
0005435626204	3476	Economy	11700.00
0005432188613	3476	Economy	11700.00
0005432799529	3476	Economy	11700.00
0005434878398	3476	Economy	11700.00
0005432799524	3476	Economy	12800.00
0005435902654	3476	Economy	11700.00
0005432611720	3476	Economy	11700.00
0005434878390	3476	Economy	12800.00
0005435126445	3476	Economy	12800.00
0005434426667	3476	Economy	12800.00
0005435126456	3476	Economy	11700.00
0005434878410	3476	Economy	11700.00
0005432183471	3476	Economy	11700.00
0005435126460	3476	Economy	11700.00
0005434878406	3476	Economy	11700.00
0005434878415	3476	Economy	11700.00
0005432799523	3476	Economy	11700.00
0005432611718	3476	Economy	11700.00
0005435126464	3476	Economy	11700.00
0005434938175	3476	Economy	11700.00
0005435626208	3476	Economy	11700.00
0005434878468	3476	Economy	11700.00
0005434938177	3476	Economy	11700.00
0005435902639	3476	Economy	11700.00
0005435626215	3476	Economy	11700.00
0005434878449	3476	Economy	11700.00
0005434878437	3476	Economy	11700.00
0005434878479	3476	Economy	11700.00
0005435913902	3476	Economy	11700.00
0005434878402	3476	Economy	11700.00
0005435126453	3476	Economy	11700.00
0005435902608	3476	Economy	11700.00
0005432799513	3476	Economy	11700.00
0005434878419	3476	Economy	11700.00
0005435902581	3476	Economy	11700.00
0005435126462	3476	Economy	11700.00
0005435126458	3476	Economy	11700.00
0005434878394	3476	Economy	11700.00
0005435913885	3476	Economy	11700.00
0005434878460	3476	Economy	11700.00
0005432613869	3476	Economy	11700.00
0005435902580	3476	Economy	11700.00
0005434878441	3476	Economy	11700.00
0005435902530	3476	Economy	11700.00
0005435126474	3476	Economy	11700.00
0005434878423	3476	Economy	11700.00
0005434878465	3476	Economy	11700.00
0005434878436	3476	Economy	11700.00
0005434878416	3476	Economy	11700.00
0005434878463	3476	Economy	11700.00
0005435126467	3476	Economy	11700.00
0005434426664	3476	Economy	11700.00
0005434878470	3476	Economy	11700.00
0005434938181	3476	Economy	11700.00
0005435626213	3476	Economy	11700.00
0005432799519	3476	Economy	11700.00
0005432188615	3476	Economy	11700.00
0005435902551	3476	Economy	11700.00
0005435126473	3476	Economy	11700.00
0005435626216	3476	Economy	11700.00
0005432799518	3476	Economy	11700.00
0005432799507	3476	Economy	11700.00
0005434878474	3476	Economy	11700.00
0005434878456	3476	Economy	11700.00
0005435126466	3476	Economy	11700.00
0005434878469	3476	Economy	11700.00
0005434426665	3476	Economy	11700.00
0005435126477	3476	Economy	11700.00
0005435626212	3476	Economy	11700.00
0005435902601	3476	Economy	11700.00
0005432188614	3476	Economy	11700.00
0005435902501	3476	Economy	11700.00
0005434426668	3476	Economy	11700.00
0005434878393	3476	Economy	11700.00
0005434878477	3476	Economy	11700.00
0005435126449	3476	Economy	11700.00
0005435626199	3476	Economy	11700.00
0005434878452	3476	Economy	11700.00
0005435126440	3476	Economy	11700.00
0005434426675	3476	Economy	11700.00
0005434878422	3476	Economy	11700.00
0005432799528	3476	Economy	11700.00
0005432799530	3476	Economy	11700.00
0005435626217	3476	Economy	11700.00
0005432799516	3476	Economy	11700.00
0005434878454	3476	Economy	11700.00
0005432799515	3476	Economy	11700.00
0005432799520	3476	Economy	11700.00
0005435126465	3476	Economy	11700.00
0005434426683	3476	Economy	11700.00
0005435626198	3476	Economy	11700.00
0005435902612	3476	Economy	11700.00
0005434426684	3476	Economy	11700.00
0005434878407	3476	Economy	11700.00
0005434938190	3476	Economy	12800.00
0005432799505	3476	Economy	12800.00
0005434426676	3476	Economy	12800.00
0005434426671	3476	Economy	12800.00
0005435902611	3476	Economy	11700.00
0005434878453	3476	Economy	11700.00
0005434878414	3476	Economy	11700.00
0005434878399	3476	Economy	11700.00
0005435126479	3476	Economy	11700.00
0005435913908	3476	Economy	11700.00
0005434878408	3476	Economy	11700.00
0005434878409	3476	Economy	11700.00
0005434938182	3476	Economy	11700.00
0005434878412	3476	Economy	11700.00
0005434878447	3476	Economy	11700.00
0005432613871	3476	Economy	11700.00
0005434878432	3476	Economy	11700.00
0005435841815	3476	Economy	11700.00
0005434878473	3476	Economy	11700.00
0005434938185	3476	Economy	11700.00
0005434878478	3476	Economy	11700.00
0005434878395	3476	Economy	11700.00
0005435126480	3476	Economy	11700.00
0005432183472	3476	Economy	11700.00
0005435626211	3476	Economy	11700.00
0005435902615	3476	Economy	11700.00
0005434878455	3476	Economy	11700.00
0005434878462	3476	Economy	11700.00
0005434878476	3476	Economy	11700.00
0005434426678	3476	Economy	11700.00
0005434878431	3476	Economy	11700.00
0005435126446	3476	Economy	11700.00
0005435126442	3476	Economy	11700.00
0005432611717	3476	Economy	11700.00
0005434878430	3476	Economy	11700.00
0005434878466	3476	Economy	11700.00
0005434878420	3476	Economy	11700.00
0005435126439	3476	Economy	11700.00
0005434426680	3476	Economy	11700.00
0005434426682	3476	Economy	11700.00
0005432799502	3476	Economy	11700.00
0005435626207	3476	Economy	11700.00
0005434878421	3476	Economy	11700.00
0005434878467	3476	Economy	11700.00
0005432799521	3476	Economy	11700.00
0005435126478	3476	Economy	11700.00
0005434878405	3476	Economy	11700.00
0005434426663	3476	Economy	11700.00
0005434426685	3476	Economy	11700.00
0005434878400	3476	Economy	11700.00
0005432799503	3476	Economy	11700.00
0005435626193	3476	Economy	11700.00
0005435126476	3476	Economy	11700.00
0005432799508	3476	Economy	11700.00
0005434878403	3476	Economy	11700.00
0005435126469	3476	Economy	11700.00
0005434878461	3476	Economy	11700.00
0005432613868	3476	Economy	11700.00
0005434878459	3476	Economy	11700.00
0005434878481	3476	Economy	11700.00
0005434938178	3476	Economy	11700.00
0005434938180	3476	Economy	11700.00
0005434938187	3476	Economy	11700.00
0005435841816	3476	Economy	11700.00
0005432799525	3476	Economy	11700.00
0005434878404	3476	Economy	11700.00
0005435126443	3476	Economy	11700.00
0005434878418	3476	Economy	11700.00
0005435126470	3476	Economy	11700.00
0005434878417	3476	Economy	11700.00
0005435126451	3476	Economy	11700.00
0005434426672	3476	Economy	11700.00
0005435902582	3476	Economy	11700.00
0005432799522	3476	Economy	11700.00
0005435126461	3476	Economy	11700.00
0005434426674	3476	Economy	11700.00
0005434878434	3476	Economy	11700.00
0005432611719	3476	Economy	11700.00
0005434878426	3476	Economy	11700.00
0005435626201	3476	Economy	11700.00
0005435902521	3476	Economy	11700.00
0005435126452	3476	Economy	11700.00
0005434426669	3476	Economy	11700.00
0005435913900	3476	Economy	11700.00
0005435626203	3476	Economy	11700.00
0005434426666	3476	Economy	11700.00
0005434878446	3476	Economy	11700.00
0005434877263	14583	Business	35000.00
0005435126137	14583	Business	35000.00
0005434426349	14583	Business	35000.00
0005434938015	14583	Business	35000.00
0005434877542	14583	Business	35000.00
0005434938012	14583	Business	35000.00
0005435126019	14583	Business	35000.00
0005435126206	14583	Business	35000.00
0005434877645	14583	Business	35000.00
0005434877755	14583	Business	35000.00
0005435126105	14583	Business	35000.00
0005434938016	14583	Business	35000.00
0005432611672	14583	Business	35000.00
0005432799262	14583	Business	35000.00
0005435125905	14583	Business	35000.00
0005434877612	14583	Business	35000.00
0005434877587	14583	Business	35000.00
0005434877545	14583	Business	35000.00
0005435126205	14583	Comfort	19900.00
0005434938013	14583	Business	35000.00
0005435126229	14583	Comfort	19900.00
0005434877870	14583	Comfort	19900.00
0005432799173	14583	Comfort	19900.00
0005435126173	14583	Comfort	19900.00
0005432799316	14583	Comfort	19900.00
0005435902734	14583	Comfort	19900.00
0005434426458	14583	Comfort	19900.00
0005432799325	14583	Comfort	19900.00
0005435914697	14583	Comfort	19900.00
0005435902744	14583	Comfort	19900.00
0005434877877	14583	Comfort	19900.00
0005434426424	14583	Comfort	19900.00
0005434877709	14583	Comfort	19900.00
0005435902743	14583	Comfort	19900.00
0005434426511	14583	Comfort	19900.00
0005435126207	14583	Comfort	19900.00
0005434877905	14583	Comfort	19900.00
0005432799264	14583	Comfort	19900.00
0005432799324	14583	Comfort	19900.00
0005434877662	14583	Comfort	19900.00
0005434426514	14583	Comfort	19900.00
0005434426343	14583	Comfort	19900.00
0005435126040	14583	Comfort	19900.00
0005432799172	14583	Comfort	19900.00
0005435125918	14583	Comfort	19900.00
0005434877384	14583	Comfort	19900.00
0005435126067	14583	Comfort	19900.00
0005434877728	14583	Comfort	19900.00
0005434877502	14583	Comfort	19900.00
0005434877711	14583	Comfort	19900.00
0005434877584	14583	Comfort	19900.00
0005434426305	14583	Comfort	19900.00
0005434938060	14583	Comfort	19900.00
0005434877575	14583	Comfort	19900.00
0005435125997	14583	Comfort	19900.00
0005435126055	14583	Economy	11700.00
0005434877454	14583	Economy	11700.00
0005434426478	14583	Economy	11700.00
0005434938068	14583	Economy	11700.00
0005434877802	14583	Economy	11700.00
0005435126230	14583	Economy	11700.00
0005435125979	14583	Economy	11700.00
0005434877646	14583	Economy	11700.00
0005434426390	14583	Economy	11700.00
0005434426450	14583	Economy	11700.00
0005434937965	14583	Economy	11700.00
0005435914696	14583	Economy	11700.00
0005434877667	14583	Economy	11700.00
0005432799265	14583	Economy	11700.00
0005434877504	14583	Economy	11700.00
0005435626040	14583	Economy	11700.00
0005435125993	14583	Economy	11700.00
0005435125962	14583	Economy	11700.00
0005434877729	14583	Economy	11700.00
0005432799271	14583	Economy	11700.00
0005434426440	14583	Economy	11700.00
0005435125968	14583	Economy	11700.00
0005432799348	14583	Economy	11700.00
0005435902735	14583	Economy	11700.00
0005434877715	14583	Economy	11700.00
0005435902745	14583	Economy	11700.00
0005434877800	14583	Economy	11700.00
0005432799189	14583	Economy	11700.00
0005434877574	14583	Economy	11700.00
0005432799248	14583	Economy	11700.00
0005435126182	14583	Economy	11700.00
0005432799254	14583	Economy	11700.00
0005434426421	14583	Economy	11700.00
0005434877618	14583	Economy	11700.00
0005434877694	14583	Economy	11700.00
0005435126181	14583	Economy	11700.00
0005435841822	14583	Economy	11700.00
0005434877564	14583	Economy	11700.00
0005434877461	14583	Economy	11700.00
0005434877573	14583	Economy	11700.00
0005435126204	14583	Economy	11700.00
0005435126058	14583	Economy	11700.00
0005435125851	14583	Economy	11700.00
0005434938067	14583	Economy	11700.00
0005434877897	14583	Economy	11700.00
0005435902739	14583	Economy	11700.00
0005435914699	14583	Economy	12800.00
0005435626026	14583	Economy	11700.00
0005434877730	14583	Economy	11700.00
0005434877359	14583	Economy	12800.00
0005435126160	14583	Economy	11700.00
0005434426464	14583	Economy	12800.00
0005435902730	14583	Economy	11700.00
0005432799292	14583	Economy	11700.00
0005435626041	14583	Economy	11700.00
0005434877999	14583	Economy	11700.00
0005432607539	14583	Economy	11700.00
0005434877444	14583	Economy	11700.00
0005432611684	14583	Economy	11700.00
0005432799277	14583	Economy	11700.00
0005432799297	14583	Economy	11700.00
0005434877563	14583	Economy	11700.00
0005435902731	14583	Economy	11700.00
0005434938032	14583	Economy	11700.00
0005434426484	14583	Economy	11700.00
0005434877385	14583	Economy	11700.00
0005435902741	14583	Economy	11700.00
0005434877268	14583	Economy	11700.00
0005434877451	14583	Economy	11700.00
0005435902733	14583	Economy	11700.00
0005435126161	14583	Economy	11700.00
0005434877792	14583	Economy	11700.00
0005432799326	14583	Economy	11700.00
0005435902742	14583	Economy	11700.00
0005435125999	14583	Economy	11700.00
0005434426449	14583	Economy	11700.00
0005434877713	14583	Economy	11700.00
0005435125898	14583	Economy	11700.00
0005434877335	14583	Economy	11700.00
0005434877622	14583	Economy	11700.00
0005434877805	14583	Economy	11700.00
0005434877499	14583	Economy	11700.00
0005434877741	14583	Economy	11700.00
0005434877617	14583	Economy	11700.00
0005435126147	14583	Economy	11700.00
0005432799337	14583	Economy	11700.00
0005434877611	14583	Economy	11700.00
0005432799405	14583	Economy	11700.00
0005434877628	14583	Economy	11700.00
0005432799278	14583	Economy	11700.00
0005434937949	14583	Economy	11700.00
0005434426391	14583	Economy	11700.00
0005432799336	14583	Economy	11700.00
0005434937964	14583	Economy	11700.00
0005434426296	14583	Economy	11700.00
0005432799155	14583	Economy	11700.00
0005434938059	14583	Economy	11700.00
0005434877820	14583	Economy	11700.00
0005435126057	14583	Economy	11700.00
0005434877425	14583	Economy	11700.00
0005434877341	14583	Economy	11700.00
0005434877782	14583	Economy	11700.00
0005434877663	14583	Economy	11700.00
0005435841825	14583	Economy	11700.00
0005434877775	14583	Economy	11700.00
0005434877426	14583	Economy	11700.00
0005432799253	14583	Economy	11700.00
0005432799293	14583	Economy	11700.00
0005434877620	14583	Economy	11700.00
0005434877904	14583	Economy	11700.00
0005434938038	14583	Economy	11700.00
0005435126159	14583	Economy	11700.00
0005434877572	14583	Economy	11700.00
0005434426363	14583	Economy	11700.00
0005434877896	14583	Economy	11700.00
0005434426306	14583	Economy	11700.00
0005435125969	14583	Economy	11700.00
0005432799404	14583	Economy	11700.00
0005434938089	14583	Economy	11700.00
0005435902738	14583	Economy	11700.00
0005434426422	14583	Economy	11700.00
0005434426513	14583	Economy	11700.00
0005434877666	14583	Economy	11700.00
0005432799163	14583	Economy	11700.00
0005434938014	14583	Economy	11700.00
0005435626004	14583	Economy	11700.00
0005434877505	14583	Economy	11700.00
0005434426463	14583	Economy	11700.00
0005435841824	14583	Economy	11700.00
0005434877101	14583	Economy	11700.00
0005435125974	14583	Economy	11700.00
0005435126070	14583	Economy	11700.00
0005432799131	14583	Economy	12800.00
0005435126148	14583	Economy	12800.00
0005434426193	14583	Economy	12800.00
0005434877556	14583	Economy	11700.00
0005434877740	14583	Economy	11700.00
0005435625954	14583	Economy	11700.00
0005434426348	14583	Economy	11700.00
0005432611678	14583	Economy	11700.00
0005434877360	14583	Economy	11700.00
0005435126138	14583	Economy	11700.00
0005434878000	14583	Economy	11700.00
0005434877831	14583	Economy	11700.00
0005434938039	14583	Economy	11700.00
0005435125919	14583	Economy	11700.00
0005432799328	14583	Economy	11700.00
0005434877861	14583	Economy	11700.00
0005435126098	14583	Economy	11700.00
0005435125906	14583	Economy	11700.00
0005432799225	14583	Economy	11700.00
0005434877830	14583	Economy	11700.00
0005435914698	14583	Economy	11700.00
0005435126322	14583	Economy	11700.00
0005434877801	14583	Economy	11700.00
0005432799238	14583	Economy	11700.00
0005434877803	14583	Economy	11700.00
0005434877449	14583	Economy	11700.00
0005434426426	14583	Economy	11700.00
0005434877862	14583	Economy	11700.00
0005435125852	14583	Economy	11700.00
0005435126253	14583	Economy	11700.00
0005434877721	14583	Economy	11700.00
0005435902737	14583	Economy	11700.00
0005434877875	14583	Economy	11700.00
0005434877269	14583	Economy	11700.00
0005435902747	14583	Economy	11700.00
0005434877421	14583	Economy	11700.00
0005434877714	14583	Economy	11700.00
0005434877693	14583	Economy	11700.00
0005434877876	14583	Economy	11700.00
0005435126066	14583	Economy	11700.00
0005432799132	14583	Economy	11700.00
0005434877621	14583	Economy	11700.00
0005432611677	14583	Economy	11700.00
0005434877631	14583	Economy	11700.00
0005432611686	14583	Economy	11700.00
0005432799272	14583	Economy	11700.00
0005435125998	14583	Economy	11700.00
0005435841823	14583	Economy	11700.00
0005434877625	14583	Economy	11700.00
0005435902746	14583	Economy	11700.00
0005434877405	14583	Economy	11700.00
0005434877619	14583	Economy	11700.00
0005435126068	14583	Economy	11700.00
0005434877543	14583	Economy	11700.00
0005435626042	14583	Economy	11700.00
0005434877577	14583	Economy	11700.00
0005435126180	14583	Economy	11700.00
0005435914695	14583	Economy	11700.00
0005435126028	14583	Economy	11700.00
0005434877293	14583	Economy	11700.00
0005432799296	14583	Economy	11700.00
0005435126187	14583	Economy	11700.00
0005435126104	14583	Economy	11700.00
0005434877793	14583	Economy	11700.00
0005432611687	14583	Economy	11700.00
0005432611676	14583	Economy	11700.00
0005435626039	14583	Economy	11700.00
0005434426483	14583	Economy	11700.00
0005435125920	14583	Economy	11700.00
0005432799138	14583	Economy	11700.00
0005435902740	14583	Economy	11700.00
0005435902736	14583	Economy	11700.00
0005435902732	14583	Economy	11700.00
0005434877627	14583	Economy	11700.00
0005434877774	14583	Economy	11700.00
0005435126146	14583	Economy	11700.00
0005434325673	3592	Economy	16300.00
0005434325669	3592	Economy	16300.00
0005434325679	3592	Economy	14800.00
0005434325668	3592	Economy	14800.00
0005435889880	3592	Economy	14800.00
0005434325677	3592	Economy	14800.00
0005434312322	3592	Economy	14800.00
0005434325678	3592	Economy	14800.00
0005435889839	3592	Economy	14800.00
0005435889886	3592	Economy	14800.00
0005435889879	3592	Economy	14800.00
0005435889840	3592	Economy	14800.00
0005434325674	3592	Economy	14800.00
0005435889876	3592	Economy	14800.00
0005434312324	3592	Economy	14800.00
0005434312323	3592	Economy	14800.00
0005434325670	3592	Economy	14800.00
0005435889877	3592	Economy	14800.00
0005435889844	3592	Economy	14800.00
0005434325671	3592	Economy	14800.00
0005435889855	3592	Economy	14800.00
0005434325672	3592	Economy	14800.00
0005434325676	3592	Economy	14800.00
0005435889854	3592	Economy	14800.00
0005434325675	3592	Economy	14800.00
0005434325588	15608	Economy	16300.00
0005434325574	15608	Economy	16300.00
0005435889906	15608	Economy	14800.00
0005434325532	15608	Economy	14800.00
0005434325576	15608	Economy	14800.00
0005434325575	15608	Economy	14800.00
0005434325580	15608	Economy	14800.00
0005435889907	15608	Economy	14800.00
0005434325557	15608	Economy	14800.00
0005434325552	15608	Economy	14800.00
0005435889909	15608	Economy	14800.00
0005434325563	15608	Economy	14800.00
0005434325584	15608	Economy	14800.00
0005434325643	15608	Economy	14800.00
0005434325618	15608	Economy	14800.00
0005435889908	15608	Economy	14800.00
0005435889910	15608	Economy	14800.00
0005434325556	15608	Economy	14800.00
0005434325583	15608	Economy	14800.00
0005435889912	15608	Economy	14800.00
0005434325617	15608	Economy	14800.00
0005435889911	15608	Economy	14800.00
0005435957727	661	Economy	4500.00
0005433420311	661	Economy	4500.00
0005433420337	661	Economy	4500.00
0005433420330	661	Economy	4100.00
0005433420312	661	Economy	4100.00
0005435957728	661	Economy	4100.00
0005433420318	661	Economy	4100.00
0005435957734	661	Economy	4100.00
0005435957733	661	Economy	4100.00
0005435957735	661	Economy	4100.00
0005433420343	661	Economy	4100.00
0005435957737	661	Economy	4100.00
0005433420321	661	Economy	4100.00
0005435957732	661	Economy	4100.00
0005433420319	661	Economy	4100.00
0005435957736	661	Economy	4100.00
0005435957729	661	Economy	4100.00
0005435957730	661	Economy	4100.00
0005435957726	661	Economy	4100.00
0005435957739	661	Economy	4100.00
0005435957738	661	Economy	4100.00
0005433420329	661	Economy	4100.00
0005435957731	661	Economy	4100.00
0005433420423	15183	Economy	4500.00
0005433420419	15183	Economy	4100.00
0005435957612	15183	Economy	4100.00
0005435957563	15183	Economy	4100.00
0005433420415	15183	Economy	4100.00
0005435957608	15183	Economy	4100.00
0005435957660	15183	Economy	4100.00
0005435957609	15183	Economy	4100.00
0005433420417	15183	Economy	4100.00
0005433420416	15183	Economy	4100.00
0005433420422	15183	Economy	4100.00
0005433420420	15183	Economy	4100.00
0005435957610	15183	Economy	4100.00
0005433420421	15183	Economy	4100.00
0005433420418	15183	Economy	4100.00
0005434247138	8919	Economy	10400.00
0005435629405	8919	Economy	10400.00
0005434247137	8919	Economy	10400.00
0005435629404	8919	Economy	10400.00
0005435629400	16079	Economy	10400.00
0005434247152	16079	Economy	10400.00
0005435629398	16079	Economy	10400.00
0005434247151	16079	Economy	10400.00
0005435629401	16079	Economy	10400.00
0005434247153	16079	Economy	10400.00
0005434247154	16079	Economy	10400.00
0005435163188	29510	Economy	13400.00
0005435933459	29510	Economy	13400.00
0005435163187	29510	Economy	13400.00
0005435933455	29510	Economy	13400.00
0005435163166	29510	Economy	12200.00
0005435163147	29510	Economy	12200.00
0005435933457	29510	Economy	12200.00
0005435933458	29510	Economy	12200.00
0005435933463	29510	Economy	12200.00
0005435163203	29510	Economy	12200.00
0005435933456	29510	Economy	12200.00
0005435163204	29510	Economy	12200.00
0005435933461	29510	Economy	12200.00
0005435163183	29510	Economy	12200.00
0005435933454	29510	Economy	12200.00
0005435933462	29510	Economy	12200.00
0005435163202	29510	Economy	12200.00
0005435163185	29510	Economy	12200.00
0005435163178	29510	Economy	12200.00
0005435933460	29510	Economy	12200.00
0005435797502	2829	Business	12600.00
0005433404768	2829	Economy	4200.00
0005435797506	2829	Economy	4600.00
0005435797507	2829	Economy	4600.00
0005435797497	2829	Economy	4600.00
0005435797504	2829	Economy	4600.00
0005435797499	2829	Economy	4200.00
0005435797500	2829	Economy	4200.00
0005433404783	2829	Economy	4200.00
0005435797505	2829	Economy	4200.00
0005435797503	2829	Economy	4200.00
0005433404785	2829	Economy	4200.00
0005435797510	2829	Economy	4200.00
0005433404738	2829	Economy	4200.00
0005435797501	2829	Economy	4200.00
0005435797511	2829	Economy	4200.00
0005435797509	2829	Economy	4200.00
0005433404782	2829	Economy	4200.00
0005435797498	2829	Economy	4200.00
0005435797508	2829	Economy	4200.00
0005435797446	29343	Business	12600.00
0005433404822	29343	Business	12600.00
0005435797425	29343	Business	12600.00
0005435797340	29343	Economy	4200.00
0005433404829	29343	Economy	4200.00
0005435797386	29343	Economy	4600.00
0005433404828	29343	Economy	4200.00
0005435797362	29343	Economy	4200.00
0005435797385	29343	Economy	4200.00
0005433404825	29343	Economy	4200.00
0005435797452	29343	Economy	4200.00
0005433404826	29343	Economy	4200.00
0005433404823	29343	Economy	4200.00
0005435797437	29343	Economy	4200.00
0005435797420	29343	Economy	4200.00
0005433404821	29343	Economy	4200.00
0005433404824	29343	Economy	4200.00
0005433404827	29343	Economy	4200.00
0005435797353	29343	Economy	4200.00
0005435376336	5802	Economy	6800.00
0005434948042	5808	Economy	6800.00
0005434948041	5808	Economy	6800.00
0005434948040	5808	Economy	6800.00
0005434948038	5808	Economy	6800.00
0005434948035	5808	Economy	6800.00
0005434948036	5808	Economy	6800.00
0005434948039	5808	Economy	6800.00
0005434948037	5808	Economy	6800.00
0005434947982	16352	Economy	6800.00
0005434947983	16352	Economy	6800.00
0005434947956	16352	Economy	6800.00
0005434948011	16352	Economy	6800.00
0005435376357	16352	Economy	6800.00
0005435376355	16352	Economy	6800.00
0005434948000	16352	Economy	6800.00
0005434947955	16352	Economy	6800.00
0005435376356	16352	Economy	6800.00
0005435376358	16352	Economy	6800.00
0005434947981	16352	Economy	6800.00
0005434947980	16352	Economy	6800.00
0005433961025	6923	Business	21400.00
0005433961001	6923	Business	21400.00
0005433961015	6923	Business	21400.00
0005433961014	6923	Business	21400.00
0005433960975	6923	Business	21400.00
0005433960997	6923	Business	21400.00
0005433961016	6923	Business	21400.00
0005433961022	6923	Economy	7100.00
0005433961004	6923	Economy	7100.00
0005433961000	6923	Economy	7100.00
0005433961019	6923	Economy	7100.00
0005433960979	6923	Economy	7100.00
0005433961021	6923	Economy	7100.00
0005433961033	6923	Economy	7100.00
0005433960999	6923	Economy	7800.00
0005433961009	6923	Economy	7800.00
0005433960987	6923	Economy	7800.00
0005433960991	6923	Economy	7800.00
0005433961023	6923	Economy	7100.00
0005433960996	6923	Economy	7100.00
0005433960981	6923	Economy	7100.00
0005433960992	6923	Economy	7100.00
0005433960989	6923	Economy	7100.00
0005433961020	6923	Economy	7100.00
0005433961005	6923	Economy	7100.00
0005433960988	6923	Economy	7100.00
0005433961024	6923	Economy	7100.00
0005433961003	6923	Economy	7100.00
0005433961030	6923	Economy	7100.00
0005433960982	6923	Economy	7100.00
0005433960980	6923	Economy	7100.00
0005433961010	6923	Economy	7100.00
0005433961018	6923	Economy	7100.00
0005433960985	6923	Economy	7100.00
0005433961012	6923	Economy	7100.00
0005433961028	6923	Economy	7100.00
0005433961006	6923	Economy	7100.00
0005433961027	6923	Economy	7100.00
0005433960990	6923	Economy	7100.00
0005433960984	6923	Economy	7100.00
0005433961002	6923	Economy	7100.00
0005433960978	6923	Economy	7100.00
0005433960977	6923	Economy	7100.00
0005433961032	6923	Economy	7100.00
0005433960976	6923	Economy	7100.00
0005433961017	6923	Economy	7100.00
0005433961007	6923	Economy	7100.00
0005433960986	6923	Economy	7100.00
0005433961008	6923	Economy	7100.00
0005433960974	6923	Economy	7100.00
0005433961026	6923	Economy	7100.00
0005433960993	6923	Economy	7100.00
0005433960994	6923	Economy	7100.00
0005433961011	6923	Economy	7100.00
0005433960983	6923	Economy	7100.00
0005433961031	6923	Economy	7100.00
0005433960995	6923	Economy	7100.00
0005433960998	6923	Economy	7100.00
0005433961013	6923	Economy	7100.00
0005433961029	6923	Economy	7100.00
0005433960427	25814	Business	21400.00
0005433960435	25814	Business	21400.00
0005433960422	25814	Business	21400.00
0005433960236	25814	Business	21400.00
0005433960433	25814	Economy	7100.00
0005433960363	25814	Economy	7100.00
0005433960398	25814	Economy	7100.00
0005433960226	25814	Economy	7100.00
0005433960408	25814	Economy	7100.00
0005433960355	25814	Economy	7800.00
0005433960434	25814	Economy	7800.00
0005433960195	25814	Economy	7100.00
0005433960323	25814	Economy	7100.00
0005433960144	25814	Economy	7100.00
0005433960344	25814	Economy	7100.00
0005433960165	25814	Economy	7100.00
0005433960282	25814	Economy	7100.00
0005433960379	25814	Economy	7100.00
0005433960431	25814	Economy	7100.00
0005433960324	25814	Economy	7100.00
0005433960224	25814	Economy	7100.00
0005433960345	25814	Economy	7100.00
0005433960239	25814	Economy	7100.00
0005433960406	25814	Economy	7100.00
0005433960382	25814	Economy	7100.00
0005433960430	25814	Economy	7100.00
0005433960238	25814	Economy	7100.00
0005433960201	25814	Economy	7100.00
0005433960258	25814	Economy	7100.00
0005433960326	25814	Economy	7100.00
0005433960380	25814	Economy	7100.00
0005433960327	25814	Economy	7100.00
0005433960322	25814	Economy	7100.00
0005433960413	25814	Economy	7100.00
0005433960348	25814	Economy	7100.00
0005433960383	25814	Economy	7100.00
0005433960428	25814	Economy	7100.00
0005433960145	25814	Economy	7100.00
0005433960200	25814	Economy	7100.00
0005435082725	24478	Economy	3900.00
0005435082749	24478	Economy	3900.00
0005435082733	24478	Economy	3900.00
0005435082710	24478	Economy	3900.00
0005435082719	24478	Economy	3900.00
0005435082732	24478	Economy	3900.00
0005435082750	24478	Economy	3900.00
0005435082729	24478	Economy	3900.00
0005435082748	24478	Economy	3900.00
0005435082744	24478	Economy	3900.00
0005435082788	26096	Economy	3900.00
0005435082793	26096	Economy	3900.00
0005435082791	26096	Economy	3900.00
0005435082789	26096	Economy	3900.00
0005435082794	26096	Economy	3900.00
0005435082792	26096	Economy	3900.00
0005435082790	26096	Economy	3900.00
0005434245032	5120	Business	18000.00
0005434245041	5120	Business	18000.00
0005434245056	5120	Business	18000.00
0005434245029	5120	Business	18000.00
0005434245033	5120	Business	18000.00
0005434245039	5120	Business	18000.00
0005434245043	5120	Business	18000.00
0005435286575	5120	Business	18000.00
0005435286576	5120	Economy	6600.00
0005434245040	5120	Economy	6600.00
0005434245052	5120	Economy	6600.00
0005434245027	5120	Economy	6000.00
0005434245046	5120	Economy	6000.00
0005432166906	5120	Economy	6000.00
0005434245053	5120	Economy	6000.00
0005434245049	5120	Economy	6000.00
0005434245036	5120	Economy	6000.00
0005435286598	5120	Economy	6000.00
0005434245042	5120	Economy	6000.00
0005435286591	5120	Economy	6000.00
0005435286596	5120	Economy	6000.00
0005435286573	5120	Economy	6000.00
0005434245047	5120	Economy	6600.00
0005434245044	5120	Economy	6600.00
0005434245035	5120	Economy	6000.00
0005432166909	5120	Economy	6000.00
0005434245030	5120	Economy	6000.00
0005435286600	5120	Economy	6000.00
0005432166907	5120	Economy	6000.00
0005435286590	5120	Economy	6000.00
0005434245048	5120	Economy	6000.00
0005434245028	5120	Economy	6000.00
0005435286599	5120	Economy	6000.00
0005434245051	5120	Economy	6000.00
0005434245055	5120	Economy	6000.00
0005434245050	5120	Economy	6000.00
0005434245031	5120	Economy	6000.00
0005434245034	5120	Economy	6000.00
0005434245026	5120	Economy	6000.00
0005434245037	5120	Economy	6000.00
0005434245045	5120	Economy	6000.00
0005432166910	5120	Economy	6000.00
0005434245038	5120	Economy	6000.00
0005434245054	5120	Economy	6000.00
0005432166908	5120	Economy	6000.00
0005433614857	5119	Business	18000.00
0005433614828	5119	Business	18000.00
0005433614867	5119	Business	18000.00
0005433614834	5119	Business	18000.00
0005433614840	5119	Business	18000.00
0005433614843	5119	Business	18000.00
0005433614816	5119	Business	18000.00
0005432105655	5119	Business	18000.00
0005433614869	5119	Business	18000.00
0005432105651	5119	Business	18000.00
0005433614853	5119	Business	18000.00
0005433785017	5119	Business	18000.00
0005433785037	5119	Business	18000.00
0005433614838	5119	Business	18000.00
0005433614841	5119	Business	18000.00
0005433614881	5119	Business	18000.00
0005432105689	5119	Business	18000.00
0005433785016	5119	Business	18000.00
0005432105654	5119	Business	18000.00
0005433614846	5119	Business	18000.00
0005433614818	5119	Business	18000.00
0005433614859	5119	Business	18000.00
0005433614882	5119	Business	18000.00
0005432666393	5119	Business	18000.00
0005433614874	5119	Business	18000.00
0005433614875	5119	Business	18000.00
0005433614824	5119	Business	18000.00
0005433614814	5119	Business	18000.00
0005433785015	5119	Economy	6600.00
0005433614836	5119	Economy	6600.00
0005433785036	5119	Economy	6600.00
0005433614813	5119	Economy	6600.00
0005433614832	5119	Economy	6600.00
0005433785010	5119	Economy	6600.00
0005433614862	5119	Economy	6000.00
0005432105669	5119	Economy	6000.00
0005433614847	5119	Economy	6000.00
0005432105685	5119	Economy	6000.00
0005433785007	5119	Economy	6000.00
0005433614872	5119	Economy	6000.00
0005432666392	5119	Economy	6000.00
0005432105649	5119	Economy	6000.00
0005433614848	5119	Economy	6000.00
0005432105675	5119	Economy	6000.00
0005433614833	5119	Economy	6000.00
0005432105656	5119	Economy	6000.00
0005432105688	5119	Economy	6000.00
0005432105679	5119	Economy	6000.00
0005433614879	5119	Economy	6000.00
0005433614839	5119	Economy	6000.00
0005433614878	5119	Economy	6000.00
0005432105662	5119	Economy	6000.00
0005432145117	5119	Economy	6000.00
0005433614863	5119	Economy	6000.00
0005433785002	5119	Economy	6000.00
0005433785008	5119	Economy	6000.00
0005433614810	5119	Economy	6000.00
0005433614819	5119	Economy	6000.00
0005433785011	5119	Economy	6000.00
0005433785027	5119	Economy	6000.00
0005432105645	5119	Economy	6000.00
0005433614815	5119	Economy	6000.00
0005432105659	5119	Economy	6000.00
0005433614864	5119	Economy	6000.00
0005433785025	5119	Economy	6000.00
0005433614809	5119	Economy	6000.00
0005432105643	5119	Economy	6000.00
0005432105646	5119	Economy	6000.00
0005432105650	5119	Economy	6000.00
0005432105681	5119	Economy	6000.00
0005433614868	5119	Economy	6000.00
0005433614826	5119	Economy	6000.00
0005433614851	5119	Economy	6000.00
0005432105642	5119	Economy	6000.00
0005433785014	5119	Economy	6000.00
0005433614877	5119	Economy	6000.00
0005432105660	5119	Economy	6000.00
0005433614811	5119	Economy	6000.00
0005433785020	5119	Economy	6000.00
0005432105687	5119	Economy	6000.00
0005432145116	5119	Economy	6000.00
0005433784999	5119	Economy	6000.00
0005433614854	5119	Economy	6000.00
0005433614856	5119	Economy	6000.00
0005432105668	5119	Economy	6000.00
0005432105666	5119	Economy	6000.00
0005433614876	5119	Economy	6000.00
0005432105671	5119	Economy	6000.00
0005433614871	5119	Economy	6000.00
0005433785000	5119	Economy	6000.00
0005433614831	5119	Economy	6000.00
0005432105684	5119	Economy	6000.00
0005433785026	5119	Economy	6000.00
0005433614845	5119	Economy	6000.00
0005432105644	5119	Economy	6600.00
0005433614842	5119	Economy	6600.00
0005433614870	5119	Economy	6600.00
0005433614823	5119	Economy	6600.00
0005433785021	5119	Economy	6600.00
0005432105641	5119	Economy	6000.00
0005432665278	5119	Economy	6000.00
0005432105667	5119	Economy	6000.00
0005432105670	5119	Economy	6000.00
0005433614812	5119	Economy	6600.00
0005433785012	5119	Economy	6000.00
0005432105674	5119	Economy	6000.00
0005432667458	5119	Economy	6000.00
0005432105673	5119	Economy	6000.00
0005433614835	5119	Economy	6000.00
0005433785018	5119	Economy	6000.00
0005433614880	5119	Economy	6000.00
0005433614837	5119	Economy	6000.00
0005432105672	5119	Economy	6000.00
0005432105648	5119	Economy	6000.00
0005432105683	5119	Economy	6000.00
0005433785032	5119	Economy	6000.00
0005433785004	5119	Economy	6000.00
0005433614830	5119	Economy	6000.00
0005432105653	5119	Economy	6000.00
0005433614849	5119	Economy	6000.00
0005433614827	5119	Economy	6000.00
0005432665279	5119	Economy	6000.00
0005433785006	5119	Economy	6000.00
0005432105661	5119	Economy	6000.00
0005433614820	5119	Economy	6000.00
0005432105665	5119	Economy	6000.00
0005433614855	5119	Economy	6000.00
0005433785009	5119	Economy	6000.00
0005433785022	5119	Economy	6000.00
0005433785003	5119	Economy	6000.00
0005433614866	5119	Economy	6000.00
0005433785013	5119	Economy	6000.00
0005433614817	5119	Economy	6000.00
0005433785024	5119	Economy	6000.00
0005433785028	5119	Economy	6000.00
0005432105686	5119	Economy	6000.00
0005433785030	5119	Economy	6000.00
0005433785034	5119	Economy	6000.00
0005432105652	5119	Economy	6000.00
0005433785023	5119	Economy	6000.00
0005432105658	5119	Economy	6000.00
0005432105664	5119	Economy	6000.00
0005433785001	5119	Economy	6000.00
0005433614829	5119	Economy	6000.00
0005433614844	5119	Economy	6000.00
0005433614861	5119	Economy	6000.00
0005433785005	5119	Economy	6000.00
0005432105657	5119	Economy	6000.00
0005433614865	5119	Economy	6000.00
0005433614873	5119	Economy	6000.00
0005433785031	5119	Economy	6000.00
0005432105647	5119	Economy	6000.00
0005432105663	5119	Economy	6000.00
0005433785029	5119	Economy	6000.00
0005432105677	5119	Economy	6000.00
0005433614860	5119	Economy	6000.00
0005433785035	5119	Economy	6000.00
0005432105678	5119	Economy	6000.00
0005432667457	5119	Economy	6000.00
0005432105682	5119	Economy	6000.00
0005433614825	5119	Economy	6000.00
0005433614850	5119	Economy	6000.00
0005433614821	5119	Economy	6000.00
0005433614858	5119	Economy	6000.00
0005433614822	5119	Economy	6000.00
0005433785033	5119	Economy	6000.00
0005433614852	5119	Economy	6000.00
0005433785019	5119	Economy	6000.00
0005432105680	5119	Economy	6000.00
0005432105676	5119	Economy	6000.00
0005434265179	5117	Business	18000.00
0005433688795	5117	Business	18000.00
0005434173527	5117	Business	18000.00
0005435006922	5117	Business	18000.00
0005434265200	5117	Business	18000.00
0005434312307	5117	Business	18000.00
0005434265194	5117	Business	18000.00
0005435006896	5117	Business	18000.00
0005434149751	5117	Business	18000.00
0005434173526	5117	Business	18000.00
0005434229419	5117	Business	18000.00
0005434229413	5117	Business	18000.00
0005433815366	5117	Business	18000.00
0005434173529	5117	Business	18000.00
0005434229414	5117	Business	18000.00
0005435269689	5117	Business	18000.00
0005432336002	5117	Business	18000.00
0005435006831	5117	Economy	6600.00
0005435269688	5117	Economy	6600.00
0005434312305	5117	Economy	6600.00
0005434229407	5117	Economy	6600.00
0005434265184	5117	Economy	6000.00
0005434265198	5117	Economy	6000.00
0005434229427	5117	Economy	6000.00
0005435269694	5117	Economy	6000.00
0005434149750	5117	Economy	6000.00
0005434229415	5117	Economy	6000.00
0005434265185	5117	Economy	6000.00
0005435269703	5117	Economy	6000.00
0005433688796	5117	Economy	6000.00
0005435006897	5117	Economy	6000.00
0005434265201	5117	Economy	6000.00
0005434229423	5117	Economy	6000.00
0005435006912	5117	Economy	6000.00
0005435269687	5117	Economy	6000.00
0005433815351	5117	Economy	6000.00
0005435269690	5117	Economy	6000.00
0005434149760	5117	Economy	6000.00
0005434265188	5117	Economy	6000.00
0005433688787	5117	Economy	6000.00
0005435006921	5117	Economy	6000.00
0005435269684	5117	Economy	6000.00
0005433688791	5117	Economy	6000.00
0005434265195	5117	Economy	6000.00
0005434229409	5117	Economy	6000.00
0005432335994	5117	Economy	6000.00
0005433815340	5117	Economy	6000.00
0005434312315	5117	Economy	6000.00
0005434229408	5117	Economy	6000.00
0005434265203	5117	Economy	6000.00
0005434265191	5117	Economy	6000.00
0005435006890	5117	Economy	6000.00
0005434229428	5117	Economy	6000.00
0005434149759	5117	Economy	6000.00
0005435006863	5117	Economy	6000.00
0005435006862	5117	Economy	6000.00
0005433815341	5117	Economy	6000.00
0005434229417	5117	Economy	6000.00
0005435006913	5117	Economy	6000.00
0005435006886	5117	Economy	6000.00
0005434229416	5117	Economy	6000.00
0005432335951	5117	Economy	6000.00
0005434229420	5117	Economy	6000.00
0005435006830	5117	Economy	6000.00
0005435006828	5117	Economy	6600.00
0005434149754	5117	Economy	6600.00
0005432335990	5117	Economy	6600.00
0005434229406	5117	Economy	6000.00
0005435006887	5117	Economy	6000.00
0005434265197	5117	Economy	6000.00
0005434265199	5117	Economy	6000.00
0005434229422	5117	Economy	6000.00
0005435269698	5117	Economy	6000.00
0005434149749	5117	Economy	6000.00
0005434229429	5117	Economy	6000.00
0005434229426	5117	Economy	6000.00
0005435006829	5117	Economy	6000.00
0005434149753	5117	Economy	6000.00
0005434311203	5117	Economy	6000.00
0005434265186	5117	Economy	6000.00
0005434265202	5117	Economy	6000.00
0005434229424	5117	Economy	6000.00
0005434229421	5117	Economy	6000.00
0005435006843	5117	Economy	6000.00
0005434265192	5117	Economy	6000.00
0005434149755	5117	Economy	6000.00
0005434229418	5117	Economy	6000.00
0005435006864	5117	Economy	6000.00
0005434149752	5117	Economy	6000.00
0005434265182	5117	Economy	6000.00
0005435006868	5117	Economy	6000.00
0005434265193	5117	Economy	6000.00
0005435269678	5117	Economy	6000.00
0005434312308	5117	Economy	6000.00
0005434265183	5117	Economy	6000.00
0005434229410	5117	Economy	6000.00
0005434265189	5117	Economy	6000.00
0005434265181	5117	Economy	6000.00
0005434173528	5117	Economy	6000.00
0005435006885	5117	Economy	6000.00
0005434265196	5117	Economy	6000.00
0005432335955	5117	Economy	6000.00
0005435006827	5117	Economy	6000.00
0005434265190	5117	Economy	6000.00
0005434229412	5117	Economy	6000.00
0005434229425	5117	Economy	6000.00
0005434229411	5117	Economy	6000.00
0005434149757	5117	Economy	6000.00
0005435006842	5117	Economy	6000.00
0005433815362	5117	Economy	6000.00
0005434149756	5117	Economy	6000.00
0005434312306	5117	Economy	6000.00
0005433815363	5117	Economy	6000.00
0005434265187	5117	Economy	6000.00
0005434173530	5117	Economy	6000.00
0005434265180	5117	Economy	6000.00
0005434149758	5117	Economy	6000.00
0005433784534	8495	Business	18000.00
0005433784779	8495	Business	18000.00
0005435269754	8495	Business	18000.00
0005434244775	8495	Business	18000.00
0005433784756	8495	Business	18000.00
0005435269757	8495	Business	18000.00
0005432659685	8495	Business	18000.00
0005433784650	8495	Business	18000.00
0005433784698	8495	Business	18000.00
0005434244717	8495	Business	18000.00
0005433784651	8495	Business	18000.00
0005433784755	8495	Economy	6600.00
0005433784535	8495	Economy	6600.00
0005435269756	8495	Economy	6000.00
0005433784914	8495	Economy	6000.00
0005433784513	8495	Economy	6000.00
0005434244741	8495	Economy	6000.00
0005434244817	8495	Economy	6000.00
0005433784809	8495	Economy	6000.00
0005434244892	8495	Economy	6000.00
0005432663023	8495	Economy	6000.00
0005435269752	8495	Economy	6000.00
0005435269753	8495	Economy	6000.00
0005433784754	8495	Economy	6000.00
0005434244883	8495	Economy	6000.00
0005433784826	8495	Economy	6000.00
0005434244833	8495	Economy	6000.00
0005433784557	8495	Economy	6000.00
0005434244776	8495	Economy	6000.00
0005432666373	8495	Economy	6000.00
0005433784913	8495	Economy	6000.00
0005433784751	8495	Economy	6000.00
0005433784753	8495	Economy	6000.00
0005433784749	8495	Economy	6000.00
0005433784512	8495	Economy	6000.00
0005432659689	8495	Economy	6000.00
0005433784760	8495	Economy	6000.00
0005434244900	8495	Economy	6000.00
0005433784555	8495	Economy	6000.00
0005434244750	8495	Economy	6000.00
0005433784649	8495	Economy	6000.00
0005434244870	8495	Economy	6000.00
0005434244821	8495	Economy	6000.00
0005433784791	8495	Economy	6000.00
0005434244901	8495	Economy	6000.00
0005434244718	8495	Economy	6000.00
0005433784802	8495	Economy	6600.00
0005433784646	8495	Economy	6000.00
0005432659690	8495	Economy	6000.00
0005435269751	8495	Economy	6000.00
0005433784558	8495	Economy	6000.00
0005433784771	8495	Economy	6000.00
0005434244891	8495	Economy	6000.00
0005433784748	8495	Economy	6000.00
0005432659691	8495	Economy	6000.00
0005434244784	8495	Economy	6000.00
0005433784641	8495	Economy	6000.00
0005434244882	8495	Economy	6000.00
0005433784801	8495	Economy	6000.00
0005434244779	8495	Economy	6000.00
0005435269758	8495	Economy	6000.00
0005433784628	8495	Economy	6000.00
0005434244834	8495	Economy	6000.00
0005433784634	8495	Economy	6000.00
0005434244783	8495	Economy	6000.00
0005433784652	8495	Economy	6000.00
0005433784660	8495	Economy	6000.00
0005433784552	8495	Economy	6000.00
0005432666375	8495	Economy	6000.00
0005434244830	8495	Economy	6000.00
0005434244742	8495	Economy	6000.00
0005434244854	8495	Economy	6000.00
0005434244822	8495	Economy	6000.00
0005433784704	8495	Economy	6000.00
0005433784682	8495	Economy	6000.00
0005434244753	8495	Economy	6000.00
0005433784705	8495	Economy	6000.00
0005435269755	8495	Economy	6000.00
0005434244785	8495	Economy	6000.00
0005433784640	8495	Economy	6000.00
0005433614226	8496	Business	18000.00
0005433614243	8496	Business	18000.00
0005433614354	8496	Business	18000.00
0005433614355	8496	Business	18000.00
0005433614132	8496	Business	18000.00
0005433614308	8496	Business	18000.00
0005433614277	8496	Business	18000.00
0005433614269	8496	Business	18000.00
0005433614135	8496	Business	18000.00
0005433614169	8496	Business	18000.00
0005433614060	8496	Business	18000.00
0005433614231	8496	Business	18000.00
0005433613956	8496	Economy	6600.00
0005433614136	8496	Economy	6600.00
0005433613916	8496	Economy	6000.00
0005433614202	8496	Economy	6000.00
0005433613863	8496	Economy	6000.00
0005433614441	8496	Economy	6000.00
0005433614081	8496	Economy	6000.00
0005433614281	8496	Economy	6000.00
0005433614167	8496	Economy	6000.00
0005433613897	8496	Economy	6000.00
0005433614185	8496	Economy	6000.00
0005433614137	8496	Economy	6000.00
0005433614082	8496	Economy	6000.00
0005433614406	8496	Economy	6000.00
0005433614080	8496	Economy	6000.00
0005433614435	8496	Economy	6000.00
0005433614148	8496	Economy	6000.00
0005433614247	8496	Economy	6000.00
0005433614248	8496	Economy	6000.00
0005433613858	8496	Economy	6000.00
0005433614244	8496	Economy	6000.00
0005433613873	8496	Economy	6000.00
0005433614178	8496	Economy	6000.00
0005433614336	8496	Economy	6000.00
0005433614075	8496	Economy	6000.00
0005433614205	8496	Economy	6000.00
0005433614140	8496	Economy	6000.00
0005433614158	8496	Economy	6000.00
0005433613976	8496	Economy	6000.00
0005433614118	8496	Economy	6000.00
0005433614111	8496	Economy	6000.00
0005433613907	8496	Economy	6000.00
0005433614061	8496	Economy	6000.00
0005433614028	8496	Economy	6000.00
0005433614186	8496	Economy	6000.00
0005433614590	8496	Economy	6000.00
0005433614299	8496	Economy	6600.00
0005433614353	8496	Economy	6000.00
0005433614312	8496	Economy	6000.00
0005433614214	8496	Economy	6000.00
0005433614062	8496	Economy	6000.00
0005433614015	8496	Economy	6000.00
0005433613771	8496	Economy	6000.00
0005433614280	8496	Economy	6000.00
0005433614106	8496	Economy	6000.00
0005433613943	8496	Economy	6000.00
0005433614246	8496	Economy	6000.00
0005433614055	8496	Economy	6000.00
0005433614083	8496	Economy	6000.00
0005433614442	8496	Economy	6000.00
0005433614315	8496	Economy	6000.00
0005433614232	8496	Economy	6000.00
0005433614065	8496	Economy	6000.00
0005433614314	8496	Economy	6000.00
0005433614041	8496	Economy	6000.00
0005433613959	8496	Economy	6000.00
0005433614104	8496	Economy	6000.00
0005433613857	8496	Economy	6000.00
0005433614337	8496	Economy	6000.00
0005433614095	8496	Economy	6000.00
0005433614184	8496	Economy	6000.00
0005433614096	8496	Economy	6000.00
0005433614309	8496	Economy	6000.00
0005433614264	8496	Economy	6000.00
0005433614090	8496	Economy	6000.00
0005433614105	8496	Economy	6000.00
0005433614278	8496	Economy	6000.00
0005433614168	8496	Economy	6000.00
0005435007082	8497	Business	18000.00
0005434264961	8497	Business	18000.00
0005433534503	8497	Business	18000.00
0005434265086	8497	Business	18000.00
0005434149606	8497	Business	18000.00
0005434264929	8497	Business	18000.00
0005435007076	8497	Business	18000.00
0005434264962	8497	Business	18000.00
0005434264954	8497	Business	18000.00
0005434229212	8497	Business	18000.00
0005434264895	8497	Business	18000.00
0005432034999	8497	Business	18000.00
0005434229209	8497	Business	18000.00
0005432336055	8497	Business	18000.00
0005434229283	8497	Business	18000.00
0005434149710	8497	Business	18000.00
0005432336063	8497	Business	18000.00
0005434229262	8497	Business	18000.00
0005434264937	8497	Business	18000.00
0005434229263	8497	Business	18000.00
0005432035010	8497	Business	18000.00
0005432034994	8497	Business	18000.00
0005432035008	8497	Business	18000.00
0005432035017	8497	Business	18000.00
0005435007077	8497	Business	18000.00
0005434229129	8497	Economy	6600.00
0005435007078	8497	Economy	6600.00
0005433815399	8497	Economy	6600.00
0005432035006	8497	Economy	6600.00
0005434229104	8497	Economy	6600.00
0005432034995	8497	Economy	6600.00
0005434149638	8497	Economy	6000.00
0005432047559	8497	Economy	6000.00
0005432336061	8497	Economy	6000.00
0005434149614	8497	Economy	6000.00
0005434229188	8497	Economy	6000.00
0005433534502	8497	Economy	6000.00
0005435007080	8497	Economy	6000.00
0005434265017	8497	Economy	6000.00
0005434229213	8497	Economy	6000.00
0005434149652	8497	Economy	6000.00
0005434264927	8497	Economy	6000.00
0005435007071	8497	Economy	6000.00
0005432336056	8497	Economy	6000.00
0005434264953	8497	Economy	6000.00
0005432336059	8497	Economy	6000.00
0005434229144	8497	Economy	6000.00
0005434149687	8497	Economy	6000.00
0005434229187	8497	Economy	6000.00
0005434229193	8497	Economy	6000.00
0005434264938	8497	Economy	6000.00
0005434149613	8497	Economy	6000.00
0005433689915	8497	Economy	6000.00
0005432035012	8497	Economy	6000.00
0005434264894	8497	Economy	6000.00
0005432035015	8497	Economy	6000.00
0005434311224	8497	Economy	6000.00
0005434149639	8497	Economy	6000.00
0005432035014	8497	Economy	6000.00
0005432336060	8497	Economy	6000.00
0005432035002	8497	Economy	6000.00
0005432047557	8497	Economy	6000.00
0005434149659	8497	Economy	6000.00
0005432035001	8497	Economy	6000.00
0005432047556	8497	Economy	6000.00
0005435007081	8497	Economy	6000.00
0005432336058	8497	Economy	6000.00
0005435007073	8497	Economy	6000.00
0005433815396	8497	Economy	6000.00
0005433690931	8497	Economy	6000.00
0005434229178	8497	Economy	6000.00
0005434265002	8497	Economy	6000.00
0005432336065	8497	Economy	6000.00
0005433688814	8497	Economy	6000.00
0005435007072	8497	Economy	6000.00
0005432034991	8497	Economy	6000.00
0005432336053	8497	Economy	6000.00
0005434229222	8497	Economy	6000.00
0005433815398	8497	Economy	6000.00
0005434264876	8497	Economy	6000.00
0005434149587	8497	Economy	6000.00
0005434173492	8497	Economy	6000.00
0005434229311	8497	Economy	6000.00
0005434264911	8497	Economy	6000.00
0005434265004	8497	Economy	6600.00
0005435007084	8497	Economy	6600.00
0005435007074	8497	Economy	6600.00
0005434229128	8497	Economy	6600.00
0005433689916	8497	Economy	6600.00
0005434264984	8497	Economy	6000.00
0005435007083	8497	Economy	6000.00
0005434229226	8497	Economy	6000.00
0005432047558	8497	Economy	6000.00
0005432034993	8497	Economy	6600.00
0005434229282	8497	Economy	6000.00
0005434149676	8497	Economy	6000.00
0005434149701	8497	Economy	6000.00
0005434229292	8497	Economy	6000.00
0005434229219	8497	Economy	6000.00
0005432035013	8497	Economy	6000.00
0005434149615	8497	Economy	6000.00
0005435007075	8497	Economy	6000.00
0005434264896	8497	Economy	6000.00
0005432034992	8497	Economy	6000.00
0005434265003	8497	Economy	6000.00
0005434229167	8497	Economy	6000.00
0005434229247	8497	Economy	6000.00
0005432035018	8497	Economy	6000.00
0005432336057	8497	Economy	6000.00
0005432034997	8497	Economy	6000.00
0005434173475	8497	Economy	6000.00
0005434149605	8497	Economy	6000.00
0005434264965	8497	Economy	6000.00
0005434149653	8497	Economy	6000.00
0005434149670	8497	Economy	6000.00
0005434264936	8497	Economy	6000.00
0005434265001	8497	Economy	6000.00
0005434265000	8497	Economy	6000.00
0005432035007	8497	Economy	6000.00
0005433815397	8497	Economy	6000.00
0005432035009	8497	Economy	6000.00
0005434311225	8497	Economy	6000.00
0005434173495	8497	Economy	6000.00
0005432336062	8497	Economy	6000.00
0005434149658	8497	Economy	6000.00
0005432035004	8497	Economy	6000.00
0005435007079	8497	Economy	6000.00
0005434265040	8497	Economy	6000.00
0005432336064	8497	Economy	6000.00
0005434229166	8497	Economy	6000.00
0005432336054	8497	Economy	6000.00
0005434149686	8497	Economy	6000.00
0005434264935	8497	Economy	6000.00
0005434149671	8497	Economy	6000.00
0005432034998	8497	Economy	6000.00
0005434229268	8497	Economy	6000.00
0005432035016	8497	Economy	6000.00
0005432035005	8497	Economy	6000.00
0005432035011	8497	Economy	6000.00
0005434311223	8497	Economy	6000.00
0005434264933	8497	Economy	6000.00
0005434264963	8497	Economy	6000.00
0005434265039	8497	Economy	6000.00
0005433688813	8497	Economy	6000.00
0005432035003	8497	Economy	6000.00
0005434229210	8497	Economy	6000.00
0005432034996	8497	Economy	6000.00
0005434149673	8497	Economy	6000.00
0005434264928	8497	Economy	6000.00
0005432035000	8497	Economy	6000.00
0005434264985	8497	Economy	6000.00
0005434149657	8497	Economy	6000.00
0005434229225	8497	Economy	6000.00
0005434639110	12614	Economy	16200.00
0005434639136	12614	Economy	16200.00
0005434639244	12614	Economy	16200.00
0005434639125	12614	Economy	16200.00
0005434639138	12614	Economy	14800.00
0005434639081	12614	Economy	14800.00
0005433202398	12614	Economy	14800.00
0005434639144	12614	Economy	14800.00
0005434639243	12614	Economy	14800.00
0005433202396	12614	Economy	14800.00
0005433202392	12614	Economy	14800.00
0005433202390	12614	Economy	14800.00
0005434639127	12614	Economy	14800.00
0005434639018	12614	Economy	14800.00
0005434639068	12614	Economy	14800.00
0005434639137	12614	Economy	14800.00
0005434639178	12614	Economy	14800.00
0005434639103	12614	Economy	14800.00
0005434639239	12614	Economy	14800.00
0005434639172	12614	Economy	14800.00
0005433202401	12614	Economy	14800.00
0005433202389	12614	Economy	14800.00
0005433202395	12614	Economy	14800.00
0005434639203	12614	Economy	14800.00
0005434639201	12614	Economy	14800.00
0005434639173	12614	Economy	14800.00
0005433202393	12614	Economy	14800.00
0005434639202	12614	Economy	14800.00
0005434639200	12614	Economy	14800.00
0005434639071	12614	Economy	14800.00
0005434639111	12614	Economy	14800.00
0005434639199	12614	Economy	14800.00
0005433202397	12614	Economy	14800.00
0005434639143	12614	Economy	14800.00
0005433202394	12614	Economy	14800.00
0005433202399	12614	Economy	14800.00
0005434639198	12614	Economy	14800.00
0005434639069	12614	Economy	14800.00
0005433202400	12614	Economy	14800.00
0005434639240	12614	Economy	14800.00
0005433202391	12614	Economy	14800.00
0005434639102	12614	Economy	14800.00
0005434639162	12614	Economy	14800.00
0005433202402	12614	Economy	14800.00
0005434639083	12614	Economy	14800.00
0005434639092	12614	Economy	14800.00
0005434639177	12614	Economy	14800.00
0005434639128	12614	Economy	14800.00
0005434639145	12614	Economy	14800.00
0005433202193	23377	Economy	16200.00
0005434639365	23377	Economy	16200.00
0005434639348	23377	Economy	16200.00
0005433202201	23377	Economy	16200.00
0005434639359	23377	Economy	14800.00
0005433202267	23377	Economy	14800.00
0005434639345	23377	Economy	14800.00
0005434639364	23377	Economy	14800.00
0005434639355	23377	Economy	14800.00
0005433202226	23377	Economy	14800.00
0005434639350	23377	Economy	14800.00
0005433202263	23377	Economy	14800.00
0005432290635	23377	Economy	14800.00
0005433202194	23377	Economy	14800.00
0005434639366	23377	Economy	14800.00
0005434639341	23377	Economy	14800.00
0005434639358	23377	Economy	14800.00
0005434639353	23377	Economy	14800.00
0005434639346	23377	Economy	14800.00
0005433202216	23377	Economy	14800.00
0005434639361	23377	Economy	14800.00
0005433202273	23377	Economy	14800.00
0005434639354	23377	Economy	14800.00
0005434639357	23377	Economy	14800.00
0005434639339	23377	Economy	14800.00
0005433202261	23377	Economy	14800.00
0005433202260	23377	Economy	14800.00
0005432290638	23377	Economy	14800.00
0005434639363	23377	Economy	14800.00
0005434639352	23377	Economy	14800.00
0005433202197	23377	Economy	14800.00
0005432290636	23377	Economy	14800.00
0005434639340	23377	Economy	14800.00
0005433202293	23377	Economy	14800.00
0005434639349	23377	Economy	14800.00
0005434639342	23377	Economy	14800.00
0005434639356	23377	Economy	14800.00
0005433202196	23377	Economy	14800.00
0005434639344	23377	Economy	14800.00
0005434639360	23377	Economy	14800.00
0005434639362	23377	Economy	14800.00
0005433202280	23377	Economy	14800.00
0005433202257	23377	Economy	14800.00
0005433202262	23377	Economy	14800.00
0005433202192	23377	Economy	14800.00
0005434639347	23377	Economy	14800.00
0005432290637	23377	Economy	14800.00
0005434639351	23377	Economy	14800.00
0005434639343	23377	Economy	14800.00
0005432328236	21083	Business	18900.00
0005432382860	21083	Business	18900.00
0005432328320	21083	Business	18900.00
0005432382805	21083	Business	18900.00
0005432328223	21083	Business	18900.00
0005432382795	21083	Business	18900.00
0005432328278	21083	Business	18900.00
0005432328330	21083	Business	18900.00
0005432382648	21083	Business	18900.00
0005432328379	21083	Business	18900.00
0005432328574	21083	Business	18900.00
0005432328445	21083	Business	18900.00
0005432328332	21083	Economy	6300.00
0005432383107	21083	Economy	6300.00
0005432328659	21083	Economy	6300.00
0005432383087	21083	Economy	6300.00
0005432328350	21083	Economy	6300.00
0005432328232	21083	Economy	6300.00
0005432382879	21083	Economy	6300.00
0005432382847	21083	Economy	6300.00
0005432054309	21083	Economy	6300.00
0005432382833	21083	Economy	6900.00
0005432382961	21083	Economy	6900.00
0005432328375	21083	Economy	6900.00
0005432328516	21083	Economy	6900.00
0005432328352	21083	Economy	6900.00
0005432328351	21083	Economy	6300.00
0005432328233	21083	Economy	6300.00
0005432382747	21083	Economy	6300.00
0005432328660	21083	Economy	6300.00
0005432382806	21083	Economy	6300.00
0005432328360	21083	Economy	6300.00
0005432328476	21083	Economy	6300.00
0005432328335	21083	Economy	6300.00
0005432328275	21083	Economy	6300.00
0005432327992	21083	Economy	6300.00
0005432328430	21083	Economy	6300.00
0005432328342	21083	Economy	6300.00
0005432328344	21083	Economy	6300.00
0005432328444	21083	Economy	6300.00
0005432054311	21083	Economy	6300.00
0005432328279	21083	Economy	6300.00
0005432382863	21083	Economy	6300.00
0005432328356	21083	Economy	6300.00
0005432328349	21083	Economy	6300.00
0005432328292	21083	Economy	6300.00
0005432382943	21083	Economy	6300.00
0005432382730	21083	Economy	6300.00
0005432382756	21083	Economy	6300.00
0005432382959	21083	Economy	6300.00
0005432328424	21083	Economy	6300.00
0005432382831	21083	Economy	6300.00
0005432328282	21083	Economy	6300.00
0005432054312	21083	Economy	6300.00
0005432328225	21083	Economy	6300.00
0005432382912	21083	Economy	6300.00
0005432328431	21083	Economy	6300.00
0005432328322	21083	Economy	6300.00
0005432328274	21083	Economy	6300.00
0005432382788	21083	Economy	6300.00
0005432383026	21083	Economy	6300.00
0005432328429	21083	Economy	6300.00
0005432382790	21083	Economy	6300.00
0005432328224	21083	Economy	6300.00
0005432382789	21083	Economy	6300.00
0005432328272	21083	Economy	6300.00
0005432328382	21083	Economy	6300.00
0005432328343	21083	Economy	6300.00
0005432383079	21083	Economy	6300.00
0005432382938	21083	Economy	6300.00
0005432328297	21083	Economy	6300.00
0005432382969	21083	Economy	6300.00
0005432328345	21083	Economy	6300.00
0005432382920	21083	Economy	6300.00
0005432383027	21083	Economy	6300.00
0005432382888	21083	Economy	6300.00
0005432328290	21083	Economy	6300.00
0005432328270	21083	Economy	6300.00
0005432328281	21083	Economy	6300.00
0005432328319	21083	Economy	6300.00
0005432054313	21083	Economy	6300.00
0005432382940	21083	Economy	6300.00
0005432328381	21083	Economy	6300.00
0005432382930	21083	Economy	6300.00
0005432328264	21083	Economy	6300.00
0005432328323	21083	Economy	6300.00
0005432054310	21083	Economy	6300.00
0005432328291	21083	Economy	6300.00
0005432382890	21083	Economy	6300.00
0005432328423	21083	Economy	6300.00
0005432382913	21083	Economy	6300.00
0005432328782	31245	Business	18900.00
0005432328766	31245	Business	18900.00
0005432328769	31245	Business	18900.00
0005432328763	31245	Business	18900.00
0005432328737	31245	Business	18900.00
0005432328772	31245	Business	18900.00
0005432383205	31245	Business	18900.00
0005432383207	31245	Business	18900.00
0005432383202	31245	Business	18900.00
0005432328753	31245	Business	18900.00
0005432328750	31245	Business	18900.00
0005432328778	31245	Business	18900.00
0005432328740	31245	Economy	6300.00
0005432328771	31245	Economy	6300.00
0005432287197	31245	Economy	6300.00
0005432328749	31245	Economy	6300.00
0005432328773	31245	Economy	6300.00
0005432328757	31245	Economy	6300.00
0005432287193	31245	Economy	6300.00
0005432328781	31245	Economy	6300.00
0005432328762	31245	Economy	6900.00
0005432287195	31245	Economy	6900.00
0005432328777	31245	Economy	6900.00
0005432383223	31245	Economy	6900.00
0005432383231	31245	Economy	6900.00
0005432383217	31245	Economy	6300.00
0005432328752	31245	Economy	6300.00
0005432328758	31245	Economy	6300.00
0005432383218	31245	Economy	6300.00
0005432328754	31245	Economy	6300.00
0005432287198	31245	Economy	6300.00
0005432383214	31245	Economy	6300.00
0005432328780	31245	Economy	6300.00
0005432383237	31245	Economy	6300.00
0005432383213	31245	Economy	6300.00
0005432328738	31245	Economy	6300.00
0005432328783	31245	Economy	6300.00
0005432287196	31245	Economy	6300.00
0005432383229	31245	Economy	6300.00
0005432328761	31245	Economy	6300.00
0005432328765	31245	Economy	6300.00
0005432383227	31245	Economy	6300.00
0005432383212	31245	Economy	6300.00
0005432383234	31245	Economy	6300.00
0005432383222	31245	Economy	6300.00
0005432328745	31245	Economy	6300.00
0005432383204	31245	Economy	6300.00
0005432328742	31245	Economy	6300.00
0005432328741	31245	Economy	6300.00
0005432383220	31245	Economy	6300.00
0005432383232	31245	Economy	6300.00
0005432383203	31245	Economy	6300.00
0005432328776	31245	Economy	6300.00
0005432383208	31245	Economy	6300.00
0005432383235	31245	Economy	6300.00
0005432383219	31245	Economy	6300.00
0005432383210	31245	Economy	6300.00
0005432328764	31245	Economy	6300.00
0005432328767	31245	Economy	6300.00
0005432328759	31245	Economy	6300.00
0005432328760	31245	Economy	6300.00
0005432328743	31245	Economy	6300.00
0005432328768	31245	Economy	6300.00
0005432328775	31245	Economy	6300.00
0005432383215	31245	Economy	6300.00
0005432328755	31245	Economy	6300.00
0005432287194	31245	Economy	6300.00
0005432383226	31245	Economy	6300.00
0005432328739	31245	Economy	6300.00
0005432383216	31245	Economy	6300.00
0005432383206	31245	Economy	6300.00
0005432383209	31245	Economy	6300.00
0005432328779	31245	Economy	6300.00
0005432328748	31245	Economy	6300.00
0005432328746	31245	Economy	6300.00
0005432328756	31245	Economy	6300.00
0005432383224	31245	Economy	6300.00
0005432383211	31245	Economy	6300.00
0005432328770	31245	Economy	6300.00
0005432383233	31245	Economy	6300.00
0005432328747	31245	Economy	6300.00
0005432328744	31245	Economy	6300.00
0005432383236	31245	Economy	6300.00
0005432383221	31245	Economy	6300.00
0005432383225	31245	Economy	6300.00
0005432328774	31245	Economy	6300.00
0005432383230	31245	Economy	6300.00
0005432328751	31245	Economy	6300.00
0005432383228	31245	Economy	6300.00
0005432424492	13259	Business	12700.00
0005432424483	13259	Business	12700.00
0005432424481	13259	Business	12700.00
0005432424495	13259	Business	12700.00
0005432424506	13259	Business	12700.00
0005432424477	13259	Business	12700.00
0005432424465	13259	Business	12700.00
0005432424485	13259	Economy	4200.00
0005432424463	13259	Economy	4200.00
0005432424501	13259	Economy	4200.00
0005432424470	13259	Economy	4200.00
0005432424511	13259	Economy	4200.00
0005432424475	13259	Economy	4200.00
0005432424486	13259	Economy	4200.00
0005432424488	13259	Economy	4700.00
0005432424490	13259	Economy	4700.00
0005432424498	13259	Economy	4200.00
0005432424507	13259	Economy	4200.00
0005432424487	13259	Economy	4200.00
0005432424519	13259	Economy	4200.00
0005432424466	13259	Economy	4200.00
0005432424464	13259	Economy	4200.00
0005432424517	13259	Economy	4200.00
0005432424503	13259	Economy	4200.00
0005432424508	13259	Economy	4200.00
0005432424496	13259	Economy	4200.00
0005432424474	13259	Economy	4200.00
0005432424515	13259	Economy	4200.00
0005432424504	13259	Economy	4200.00
0005432424510	13259	Economy	4200.00
0005432424480	13259	Economy	4200.00
0005432424505	13259	Economy	4200.00
0005432424500	13259	Economy	4200.00
0005432424479	13259	Economy	4200.00
0005432424489	13259	Economy	4200.00
0005432424493	13259	Economy	4200.00
0005432424482	13259	Economy	4200.00
0005432424516	13259	Economy	4200.00
0005432424502	13259	Economy	4200.00
0005432424476	13259	Economy	4200.00
0005432424478	13259	Economy	4200.00
0005432424514	13259	Economy	4200.00
0005432424473	13259	Economy	4200.00
0005432424494	13259	Economy	4200.00
0005432424512	13259	Economy	4200.00
0005432424471	13259	Economy	4200.00
0005432424499	13259	Economy	4200.00
0005432424491	13259	Economy	4200.00
0005432424467	13259	Economy	4200.00
0005432424513	13259	Economy	4200.00
0005432424518	13259	Economy	4200.00
0005432424509	13259	Economy	4200.00
0005432424497	13259	Economy	4200.00
0005432424468	13259	Economy	4200.00
0005432424469	13259	Economy	4200.00
0005432424472	13259	Economy	4200.00
0005432424484	13259	Economy	4200.00
0005432424061	30730	Business	12700.00
0005432424017	30730	Business	12700.00
0005432424062	30730	Business	12700.00
0005432424063	30730	Business	12700.00
0005432424097	30730	Business	12700.00
0005432424018	30730	Economy	4200.00
0005432424052	30730	Economy	4200.00
0005432424029	30730	Economy	4200.00
0005432423917	30730	Economy	4200.00
0005432424122	30730	Economy	4200.00
0005432424075	30730	Economy	4200.00
0005432424146	30730	Economy	4200.00
0005432423970	30730	Economy	4700.00
0005432424084	30730	Economy	4700.00
0005432423922	30730	Economy	4200.00
0005432424157	30730	Economy	4200.00
0005432424080	30730	Economy	4200.00
0005432424069	30730	Economy	4200.00
0005432424073	30730	Economy	4200.00
0005432424102	30730	Economy	4200.00
0005432424120	30730	Economy	4200.00
0005432424156	30730	Economy	4200.00
0005432424077	30730	Economy	4200.00
0005432424016	30730	Economy	4200.00
0005432424133	30730	Economy	4200.00
0005432423916	30730	Economy	4200.00
0005432424161	30730	Economy	4200.00
0005432424074	30730	Economy	4200.00
0005432424149	30730	Economy	4200.00
0005432423972	30730	Economy	4200.00
0005432424051	30730	Economy	4200.00
0005432423971	30730	Economy	4200.00
0005432424068	30730	Economy	4200.00
0005432423973	30730	Economy	4200.00
0005432424072	30730	Economy	4200.00
0005432424143	30730	Economy	4200.00
0005432424134	30730	Economy	4200.00
0005432424105	30730	Economy	4200.00
0005432423918	30730	Economy	4200.00
0005432423959	30730	Economy	4200.00
0005432424119	30730	Economy	4200.00
0005432424081	30730	Economy	4200.00
0005432424076	30730	Economy	4200.00
0005432424015	30730	Economy	4200.00
0005432817524	9603	Business	32600.00
0005432817540	9603	Business	32600.00
0005432817521	9603	Business	32600.00
0005434157458	9603	Business	32600.00
0005432817534	9603	Business	32600.00
0005432901424	9603	Business	32600.00
0005432817518	9603	Business	32600.00
0005432901389	9603	Business	32600.00
0005432822220	9603	Business	32600.00
0005432901489	9603	Business	32600.00
0005432901423	9603	Economy	10900.00
0005434186164	9603	Economy	10900.00
0005432817531	9603	Economy	10900.00
0005432901455	9603	Economy	10900.00
0005434157459	9603	Economy	10900.00
0005432901416	9603	Economy	10900.00
0005432901551	9603	Economy	10900.00
0005432817541	9603	Economy	11900.00
0005432817544	9603	Economy	11900.00
0005432288993	9603	Economy	11900.00
0005432901422	9603	Economy	10900.00
0005432817535	9603	Economy	10900.00
0005432901509	9603	Economy	10900.00
0005432901508	9603	Economy	10900.00
0005432822221	9603	Economy	10900.00
0005432901500	9603	Economy	10900.00
0005432901429	9603	Economy	10900.00
0005432817536	9603	Economy	10900.00
0005432817522	9603	Economy	10900.00
0005434448321	9603	Economy	10900.00
0005432817526	9603	Economy	10900.00
0005434186163	9603	Economy	10900.00
0005432817545	9603	Economy	10900.00
0005432901485	9603	Economy	10900.00
0005434448323	9603	Economy	10900.00
0005432817533	9603	Economy	10900.00
0005432822215	9603	Economy	10900.00
0005432817538	9603	Economy	10900.00
0005432817519	9603	Economy	10900.00
0005434448324	9603	Economy	10900.00
0005432817517	9603	Economy	10900.00
0005432901453	9603	Economy	10900.00
0005432817527	9603	Economy	10900.00
0005432901484	9603	Economy	10900.00
0005434448322	9603	Economy	10900.00
0005432901452	9603	Economy	10900.00
0005432817539	9603	Economy	10900.00
0005434186182	9603	Economy	10900.00
0005432822217	9603	Economy	10900.00
0005432817525	9603	Economy	10900.00
0005432822219	9603	Economy	10900.00
0005432817537	9603	Economy	10900.00
0005434448325	9603	Economy	10900.00
0005432901520	9603	Economy	10900.00
0005432817542	9603	Economy	10900.00
0005432901480	9603	Economy	10900.00
0005432817530	9603	Economy	10900.00
0005432817543	9603	Economy	10900.00
0005432817529	9603	Economy	10900.00
0005432817516	9603	Economy	10900.00
0005432817528	9603	Economy	10900.00
0005432901519	9603	Economy	10900.00
0005432817532	9603	Economy	10900.00
0005432901425	9603	Economy	10900.00
0005434157460	9603	Economy	10900.00
0005434186178	9603	Economy	10900.00
0005432822218	9603	Economy	10900.00
0005432901499	9603	Economy	10900.00
0005434186175	9603	Economy	10900.00
0005432288992	9603	Economy	10900.00
0005432817520	9603	Economy	10900.00
0005432901415	9603	Economy	10900.00
0005432817523	9603	Economy	10900.00
0005432822216	9603	Economy	10900.00
0005432822222	9603	Economy	10900.00
0005432901445	9603	Economy	10900.00
0005432901650	29012	Business	32600.00
0005434157492	29012	Business	32600.00
0005432817185	29012	Business	32600.00
0005432817253	29012	Business	32600.00
0005432817359	29012	Business	32600.00
0005432822165	29012	Business	32600.00
0005434448278	29012	Business	32600.00
0005432901647	29012	Business	32600.00
0005432002081	29012	Economy	10900.00
0005432817401	29012	Economy	10900.00
0005432817286	29012	Economy	10900.00
0005432901636	29012	Economy	10900.00
0005432817418	29012	Economy	10900.00
0005434157498	29012	Economy	10900.00
0005432901645	29012	Economy	11900.00
0005432817268	29012	Economy	11900.00
0005432817275	29012	Economy	10900.00
0005432817170	29012	Economy	10900.00
0005434157496	29012	Economy	10900.00
0005432822093	29012	Economy	10900.00
0005434186203	29012	Economy	10900.00
0005432822164	29012	Economy	10900.00
0005432822158	29012	Economy	10900.00
0005432901638	29012	Economy	10900.00
0005432817419	29012	Economy	10900.00
0005432817301	29012	Economy	10900.00
0005432901648	29012	Economy	10900.00
0005434157495	29012	Economy	10900.00
0005432822155	29012	Economy	10900.00
0005434157494	29012	Economy	10900.00
0005432901646	29012	Economy	10900.00
0005432901639	29012	Economy	10900.00
0005434186201	29012	Economy	10900.00
0005434157491	29012	Economy	10900.00
0005434157497	29012	Economy	10900.00
0005432822157	29012	Economy	10900.00
0005432817211	29012	Economy	10900.00
0005432901652	29012	Economy	10900.00
0005432817171	29012	Economy	10900.00
0005432901644	29012	Economy	10900.00
0005432002079	29012	Economy	10900.00
0005432901642	29012	Economy	10900.00
0005432901637	29012	Economy	10900.00
0005434186202	29012	Economy	10900.00
0005432002080	29012	Economy	10900.00
0005434448290	29012	Economy	10900.00
0005432817289	29012	Economy	10900.00
0005432901641	29012	Economy	10900.00
0005432901651	29012	Economy	10900.00
0005432901640	29012	Economy	10900.00
0005432817210	29012	Economy	10900.00
0005432822094	29012	Economy	10900.00
0005432817311	29012	Economy	10900.00
0005432901643	29012	Economy	10900.00
0005432817320	29012	Economy	10900.00
0005432817225	29012	Economy	10900.00
0005432822156	29012	Economy	10900.00
0005432817285	29012	Economy	10900.00
0005432817267	29012	Economy	10900.00
0005432901649	29012	Economy	10900.00
0005432822143	29012	Economy	10900.00
0005434157493	29012	Economy	10900.00
0005432817310	29012	Economy	10900.00
0005432817353	29012	Economy	10900.00
0005432901635	29012	Economy	10900.00
0005432611719	15082	Economy	11000.00
0005435841087	15082	Economy	11000.00
0005435841816	15082	Economy	11000.00
0005432613869	15082	Economy	11000.00
0005432611717	15082	Economy	11000.00
0005432613871	15082	Economy	11000.00
0005432611718	15082	Economy	11000.00
0005432611720	15082	Economy	11000.00
0005435841088	15082	Economy	11000.00
0005435841815	15082	Economy	11000.00
0005432613870	15082	Economy	11000.00
0005432613868	15082	Economy	11000.00
0005435841823	31602	Economy	11000.00
0005432611684	31602	Economy	11000.00
0005435841825	31602	Economy	11000.00
0005432611677	31602	Economy	11000.00
0005432611686	31602	Economy	11000.00
0005432607539	31602	Economy	11000.00
0005432611672	31602	Economy	11000.00
0005432611676	31602	Economy	11000.00
0005435841822	31602	Economy	11000.00
0005432611678	31602	Economy	11000.00
0005435841824	31602	Economy	11000.00
0005432611687	31602	Economy	11000.00
0005433569181	11871	Business	105900.00
0005432948281	11871	Business	105900.00
0005433569129	11871	Business	105900.00
0005432948177	11871	Business	105900.00
0005432948043	11871	Business	105900.00
0005433569169	11871	Business	105900.00
0005433569146	11871	Business	105900.00
0005432948182	11871	Business	105900.00
0005432948073	11871	Business	105900.00
0005433569147	11871	Business	105900.00
0005432947960	11871	Business	105900.00
0005433569134	11871	Business	105900.00
0005432948289	11871	Business	105900.00
0005433569167	11871	Business	105900.00
0005433569159	11871	Business	105900.00
0005433569149	11871	Business	105900.00
0005433569128	11871	Economy	35300.00
0005433569132	11871	Business	105900.00
0005433569125	11871	Economy	35300.00
0005432948111	11871	Economy	35300.00
0005432948122	11871	Economy	35300.00
0005432947974	11871	Economy	35300.00
0005432948194	11871	Economy	35300.00
0005432948262	11871	Economy	35300.00
0005433569138	11871	Economy	35300.00
0005432948183	11871	Economy	35300.00
0005433569148	11871	Economy	35300.00
0005432948121	11871	Economy	35300.00
0005432948107	11871	Economy	35300.00
0005433569137	11871	Economy	35300.00
0005433569133	11871	Economy	38800.00
0005432948217	11871	Economy	38800.00
0005433569158	11871	Economy	38800.00
0005433569150	11871	Economy	35300.00
0005433569164	11871	Economy	35300.00
0005433569127	11871	Economy	35300.00
0005432948171	11871	Economy	35300.00
0005433569139	11871	Economy	35300.00
0005432948019	11871	Economy	35300.00
0005433569165	11871	Economy	35300.00
0005432948280	11871	Economy	35300.00
0005433569162	11871	Economy	35300.00
0005433569140	11871	Economy	35300.00
0005432948085	11871	Economy	35300.00
0005432948081	11871	Economy	35300.00
0005433569141	11871	Economy	35300.00
0005432948110	11871	Economy	35300.00
0005433569136	11871	Economy	35300.00
0005432947938	11871	Economy	35300.00
0005432948105	11871	Economy	35300.00
0005432948248	11871	Economy	35300.00
0005433569161	11871	Economy	35300.00
0005433569163	11871	Economy	35300.00
0005433569153	11871	Economy	35300.00
0005433569152	11871	Economy	35300.00
0005433569170	11871	Economy	35300.00
0005432947961	11871	Economy	35300.00
0005433569178	11871	Economy	35300.00
0005433569143	11871	Economy	35300.00
0005432948146	11871	Economy	35300.00
0005433569166	11871	Economy	35300.00
0005433569145	11871	Economy	35300.00
0005433569126	11871	Economy	35300.00
0005432948232	11871	Economy	35300.00
0005433569168	11871	Economy	35300.00
0005433569154	11871	Economy	35300.00
0005433569175	11871	Economy	35300.00
0005433569173	11871	Economy	35300.00
0005432948216	11871	Economy	35300.00
0005432948231	11871	Economy	35300.00
0005432948225	11871	Economy	35300.00
0005432948254	11871	Economy	35300.00
0005433569176	11871	Economy	35300.00
0005433569144	11871	Economy	35300.00
0005433569151	11871	Economy	35300.00
0005433569142	11871	Economy	35300.00
0005432947827	11871	Economy	35300.00
0005433569124	11871	Economy	35300.00
0005433569131	11871	Economy	35300.00
0005432948181	11871	Economy	35300.00
0005432948172	11871	Economy	35300.00
0005433569135	11871	Economy	35300.00
0005432948255	11871	Economy	35300.00
0005432948106	11871	Economy	35300.00
0005432948050	11871	Economy	35300.00
0005433569172	11871	Economy	35300.00
0005433569130	11871	Economy	35300.00
0005432947973	11871	Economy	35300.00
0005433569174	11871	Economy	35300.00
0005433569180	11871	Economy	35300.00
0005433569177	11871	Economy	35300.00
0005432947989	11871	Economy	35300.00
0005432948292	11871	Economy	35300.00
0005432948040	11871	Economy	35300.00
0005432948250	11871	Economy	35300.00
0005432948145	11871	Economy	35300.00
0005432948133	11871	Economy	35300.00
0005432947972	11871	Economy	35300.00
0005433569171	11871	Economy	35300.00
0005433569156	11871	Economy	35300.00
0005433569179	11871	Economy	35300.00
0005433569155	11871	Economy	35300.00
0005432948042	11871	Economy	35300.00
0005433569157	11871	Economy	35300.00
0005433569160	11871	Economy	35300.00
0005432948556	25273	Business	105900.00
0005433568598	25273	Business	105900.00
0005433568439	25273	Business	105900.00
0005433568623	25273	Business	105900.00
0005433568579	25273	Business	105900.00
0005432948578	25273	Business	105900.00
0005432948586	25273	Business	105900.00
0005433568740	25273	Business	105900.00
0005433568663	25273	Business	105900.00
0005433568712	25273	Business	105900.00
0005433568754	25273	Business	105900.00
0005433568671	25273	Business	105900.00
0005433568785	25273	Business	105900.00
0005432948579	25273	Business	105900.00
0005432948563	25273	Business	105900.00
0005433568755	25273	Business	105900.00
0005433568354	25273	Business	105900.00
0005433568681	25273	Economy	35300.00
0005432948575	25273	Economy	35300.00
0005432948564	25273	Economy	35300.00
0005433568601	25273	Economy	35300.00
0005432948587	25273	Economy	35300.00
0005433568615	25273	Economy	35300.00
0005432948597	25273	Economy	35300.00
0005432948566	25273	Economy	35300.00
0005432948567	25273	Economy	35300.00
0005433568723	25273	Economy	35300.00
0005433568441	25273	Economy	35300.00
0005433568324	25273	Economy	35300.00
0005432948576	25273	Economy	38800.00
0005432948561	25273	Economy	38800.00
0005433568507	25273	Economy	38800.00
0005433568729	25273	Economy	38800.00
0005433568508	25273	Economy	35300.00
0005433568756	25273	Economy	35300.00
0005433568527	25273	Economy	35300.00
0005433568757	25273	Economy	35300.00
0005433568602	25273	Economy	35300.00
0005433568715	25273	Economy	35300.00
0005432948588	25273	Economy	35300.00
0005433568573	25273	Economy	35300.00
0005432948568	25273	Economy	35300.00
0005432948560	25273	Economy	35300.00
0005432948558	25273	Economy	35300.00
0005432948559	25273	Economy	35300.00
0005433568594	25273	Economy	35300.00
0005432948581	25273	Economy	35300.00
0005433568524	25273	Economy	35300.00
0005433568609	25273	Economy	35300.00
0005432948562	25273	Economy	35300.00
0005433568368	25273	Economy	35300.00
0005432948571	25273	Economy	35300.00
0005433568440	25273	Economy	35300.00
0005433568525	25273	Economy	35300.00
0005433568554	25273	Economy	35300.00
0005432948582	25273	Economy	35300.00
0005433568786	25273	Economy	35300.00
0005432948596	25273	Economy	35300.00
0005432948594	25273	Economy	35300.00
0005433568422	25273	Economy	35300.00
0005433568597	25273	Economy	35300.00
0005433568593	25273	Economy	35300.00
0005433568773	25273	Economy	35300.00
0005433568686	25273	Economy	35300.00
0005433568643	25273	Economy	35300.00
0005433568472	25273	Economy	35300.00
0005432948593	25273	Economy	35300.00
0005432948595	25273	Economy	35300.00
0005433568713	25273	Economy	35300.00
0005432948589	25273	Economy	35300.00
0005433568526	25273	Economy	35300.00
0005432948580	25273	Economy	35300.00
0005433568690	25273	Economy	35300.00
0005433568560	25273	Economy	35300.00
0005432948569	25273	Economy	35300.00
0005432948585	25273	Economy	35300.00
0005433568248	25273	Economy	35300.00
0005433568595	25273	Economy	35300.00
0005433568571	25273	Economy	35300.00
0005432948573	25273	Economy	35300.00
0005433568662	25273	Economy	35300.00
0005433568572	25273	Economy	35300.00
0005432948590	25273	Economy	35300.00
0005432948557	25273	Economy	35300.00
0005433568321	25273	Economy	35300.00
0005433568614	25273	Economy	35300.00
0005432948591	25273	Economy	35300.00
0005433568637	25273	Economy	35300.00
0005433568359	25273	Economy	35300.00
0005432948565	25273	Economy	35300.00
0005433568471	25273	Economy	35300.00
0005432948584	25273	Economy	35300.00
0005432948592	25273	Economy	35300.00
0005433568724	25273	Economy	35300.00
0005432948570	25273	Economy	35300.00
0005433568477	25273	Economy	35300.00
0005432948577	25273	Economy	35300.00
0005432948583	25273	Economy	35300.00
0005433568672	25273	Economy	35300.00
0005432948574	25273	Economy	35300.00
0005433568580	25273	Economy	35300.00
0005433568695	25273	Economy	35300.00
0005432948572	25273	Economy	35300.00
0005435340108	5420	Business	67200.00
0005435340150	5420	Business	67200.00
0005434654757	5420	Business	67200.00
0005434654751	5420	Business	67200.00
0005432114209	5420	Business	67200.00
0005435340179	5420	Business	67200.00
0005435340177	5420	Economy	22400.00
0005435340137	5420	Economy	22400.00
0005434654729	5420	Economy	22400.00
0005434656561	5420	Economy	22400.00
0005435340099	5420	Economy	22400.00
0005434654749	5420	Economy	22400.00
0005435340127	5420	Economy	22400.00
0005435340090	5420	Economy	24600.00
0005434654740	5420	Economy	24600.00
0005434654750	5420	Economy	24600.00
0005434654736	5420	Economy	24600.00
0005432114210	5420	Economy	22400.00
0005434654735	5420	Economy	22400.00
0005435340124	5420	Economy	22400.00
0005435340159	5420	Economy	22400.00
0005434654745	5420	Economy	22400.00
0005434654730	5420	Economy	22400.00
0005434654752	5420	Economy	22400.00
0005434654753	5420	Economy	22400.00
0005435340145	5420	Economy	22400.00
0005434654755	5420	Economy	22400.00
0005434654732	5420	Economy	22400.00
0005435340178	5420	Economy	22400.00
0005435340151	5420	Economy	22400.00
0005434654744	5420	Economy	22400.00
0005435340107	5420	Economy	22400.00
0005434654756	5420	Economy	22400.00
0005434654747	5420	Economy	22400.00
0005435340125	5420	Economy	22400.00
0005434654742	5420	Economy	22400.00
0005434654741	5420	Economy	22400.00
0005434654733	5420	Economy	22400.00
0005435340185	5420	Economy	22400.00
0005434654746	5420	Economy	22400.00
0005435340192	5420	Economy	22400.00
0005434654754	5420	Economy	22400.00
0005434654734	5420	Economy	22400.00
0005434654737	5420	Economy	22400.00
0005434654738	5420	Economy	22400.00
0005434656560	5420	Economy	22400.00
0005434654739	5420	Economy	22400.00
0005434654748	5420	Economy	22400.00
0005434654728	5420	Economy	22400.00
0005435340091	5420	Economy	22400.00
0005435340118	5420	Economy	22400.00
0005432114211	5420	Economy	22400.00
0005434654731	5420	Economy	22400.00
0005434654743	5420	Economy	22400.00
0005434654583	12519	Business	67200.00
0005435340299	12519	Business	67200.00
0005434654482	12519	Business	67200.00
0005434654365	12519	Business	67200.00
0005434654577	12519	Business	67200.00
0005434654442	12519	Business	67200.00
0005434654568	12519	Economy	22400.00
0005434654474	12519	Economy	22400.00
0005434654530	12519	Economy	22400.00
0005434654449	12519	Economy	22400.00
0005434654567	12519	Economy	22400.00
0005435340289	12519	Economy	24600.00
0005434654445	12519	Economy	24600.00
0005434654398	12519	Economy	22400.00
0005434654448	12519	Economy	22400.00
0005434654569	12519	Economy	22400.00
0005434654475	12519	Economy	22400.00
0005435340287	12519	Economy	22400.00
0005435340292	12519	Economy	22400.00
0005434654545	12519	Economy	22400.00
0005434654404	12519	Economy	22400.00
0005435340296	12519	Economy	22400.00
0005435340293	12519	Economy	22400.00
0005435340290	12519	Economy	22400.00
0005434654440	12519	Economy	22400.00
0005434656545	12519	Economy	22400.00
0005434654646	12519	Economy	22400.00
0005434654476	12519	Economy	22400.00
0005434654512	12519	Economy	22400.00
0005434654549	12519	Economy	22400.00
0005435340297	12519	Economy	22400.00
0005435555375	12519	Economy	22400.00
0005434654397	12519	Economy	22400.00
0005434654443	12519	Economy	22400.00
0005435555376	12519	Economy	22400.00
0005434654573	12519	Economy	22400.00
0005434654544	12519	Economy	22400.00
0005435340288	12519	Economy	22400.00
0005434654469	12519	Economy	22400.00
0005434654584	12519	Economy	22400.00
0005435340294	12519	Economy	22400.00
0005435340298	12519	Economy	22400.00
0005434656543	12519	Economy	22400.00
0005434654645	12519	Economy	22400.00
0005435340291	12519	Economy	22400.00
0005435340295	12519	Economy	22400.00
0005434656542	12519	Economy	22400.00
0005434656540	12519	Economy	22400.00
0005434654428	12519	Economy	22400.00
0005434654447	12519	Economy	22400.00
0005434654444	12519	Economy	22400.00
0005435555374	12519	Economy	22400.00
0005433716083	7418	Business	32000.00
0005433716085	7418	Business	32000.00
0005433716042	7418	Business	32000.00
0005433656676	7418	Business	32000.00
0005433716084	7418	Business	32000.00
0005432078121	7418	Business	32000.00
0005433716050	7418	Business	32000.00
0005433716075	7418	Business	32000.00
0005433716070	7418	Economy	10700.00
0005433716081	7418	Economy	10700.00
0005433716074	7418	Economy	10700.00
0005433716054	7418	Economy	10700.00
0005433716079	7418	Economy	10700.00
0005432078117	7418	Economy	10700.00
0005433689912	7418	Economy	10700.00
0005433719143	7418	Economy	10700.00
0005433716051	7418	Economy	10700.00
0005433716046	7418	Economy	10700.00
0005433716044	7418	Economy	10700.00
0005433716039	7418	Economy	10700.00
0005433716063	7418	Economy	10700.00
0005432428908	7418	Economy	10700.00
0005433716052	7418	Economy	10700.00
0005433716041	7418	Economy	10700.00
0005432078120	7418	Economy	10700.00
0005433716047	7418	Economy	10700.00
0005432428907	7418	Economy	10700.00
0005433716088	7418	Economy	10700.00
0005433716069	7418	Economy	10700.00
0005433716040	7418	Economy	10700.00
0005433716065	7418	Economy	10700.00
0005433716073	7418	Economy	10700.00
0005432078122	7418	Economy	11700.00
0005433719144	7418	Economy	11700.00
0005433716060	7418	Economy	11700.00
0005433716059	7418	Economy	10700.00
0005433716055	7418	Economy	10700.00
0005433716071	7418	Economy	10700.00
0005433716087	7418	Economy	10700.00
0005433716045	7418	Economy	10700.00
0005433656674	7418	Economy	10700.00
0005433656673	7418	Economy	10700.00
0005435266105	7418	Economy	10700.00
0005433656675	7418	Economy	10700.00
0005433716066	7418	Economy	10700.00
0005433716058	7418	Economy	10700.00
0005433716082	7418	Economy	10700.00
0005433688812	7418	Economy	10700.00
0005433716049	7418	Economy	10700.00
0005433716057	7418	Economy	10700.00
0005433716061	7418	Economy	10700.00
0005433716068	7418	Economy	10700.00
0005433719145	7418	Economy	10700.00
0005433716064	7418	Economy	10700.00
0005433689913	7418	Economy	10700.00
0005433690930	7418	Economy	10700.00
0005433716048	7418	Economy	10700.00
0005433716067	7418	Economy	10700.00
0005433722230	7418	Economy	10700.00
0005432078116	7418	Economy	10700.00
0005433716077	7418	Economy	10700.00
0005432078118	7418	Economy	10700.00
0005433719146	7418	Economy	10700.00
0005432078119	7418	Economy	10700.00
0005433690929	7418	Economy	10700.00
0005435266116	7418	Economy	10700.00
0005433689914	7418	Economy	10700.00
0005433716072	7418	Economy	10700.00
0005433716078	7418	Economy	10700.00
0005433716053	7418	Economy	10700.00
0005433716080	7418	Economy	10700.00
0005433716086	7418	Economy	10700.00
0005433716076	7418	Economy	10700.00
0005433722231	7418	Economy	10700.00
0005433716056	7418	Economy	10700.00
0005433716043	7418	Economy	10700.00
0005433716062	7418	Economy	10700.00
0005433688811	7418	Economy	10700.00
0005433715573	29222	Business	32000.00
0005433715833	29222	Business	32000.00
0005433719114	29222	Business	32000.00
0005433719123	29222	Business	32000.00
0005433715746	29222	Business	32000.00
0005433715595	29222	Economy	10700.00
0005433688795	29222	Economy	10700.00
0005433715731	29222	Economy	10700.00
0005433715587	29222	Economy	10700.00
0005433715503	29222	Economy	10700.00
0005433715553	29222	Economy	10700.00
0005433715626	29222	Economy	10700.00
0005433715690	29222	Economy	10700.00
0005433715511	29222	Economy	10700.00
0005432006767	29222	Economy	10700.00
0005433722169	29222	Economy	10700.00
0005433715417	29222	Economy	10700.00
0005433715557	29222	Economy	10700.00
0005433715722	29222	Economy	10700.00
0005433715805	29222	Economy	10700.00
0005433656637	29222	Economy	10700.00
0005433715571	29222	Economy	10700.00
0005433715404	29222	Economy	10700.00
0005433715684	29222	Economy	10700.00
0005433715651	29222	Economy	10700.00
0005435266149	29222	Economy	10700.00
0005433715570	29222	Economy	10700.00
0005433715832	29222	Economy	10700.00
0005433722167	29222	Economy	11700.00
0005433715795	29222	Economy	11700.00
0005433715668	29222	Economy	10700.00
0005433656649	29222	Economy	10700.00
0005433715614	29222	Economy	10700.00
0005433715510	29222	Economy	10700.00
0005433715627	29222	Economy	10700.00
0005433715714	29222	Economy	10700.00
0005435266150	29222	Economy	10700.00
0005433715796	29222	Economy	10700.00
0005433715547	29222	Economy	10700.00
0005432006766	29222	Economy	10700.00
0005433715572	29222	Economy	10700.00
0005433715578	29222	Economy	10700.00
0005435266152	29222	Economy	10700.00
0005432006768	29222	Economy	10700.00
0005435266153	29222	Economy	10700.00
0005435266151	29222	Economy	10700.00
0005433715724	29222	Economy	10700.00
0005433719112	29222	Economy	10700.00
0005433715806	29222	Economy	10700.00
0005433715470	29222	Economy	10700.00
0005433688787	29222	Economy	10700.00
0005433715548	29222	Economy	10700.00
0005432006765	29222	Economy	10700.00
0005433715435	29222	Economy	10700.00
0005433715723	29222	Economy	10700.00
0005432428936	29222	Economy	10700.00
0005433715733	29222	Economy	10700.00
0005433688796	29222	Economy	10700.00
0005433715658	29222	Economy	10700.00
0005433715732	29222	Economy	10700.00
0005433715577	29222	Economy	10700.00
0005432428937	29222	Economy	10700.00
0005433715763	29222	Economy	10700.00
0005433715739	29222	Economy	10700.00
0005433719111	29222	Economy	10700.00
0005433715691	29222	Economy	10700.00
0005433688791	29222	Economy	10700.00
0005433715878	29222	Economy	10700.00
0005433656627	29222	Economy	10700.00
0005432428935	29222	Economy	10700.00
0005433715416	29222	Economy	10700.00
0005434095305	8698	Business	36500.00
0005434143730	8698	Business	36500.00
0005434143727	8698	Business	36500.00
0005434182113	8698	Business	36500.00
0005434095307	8698	Business	36500.00
0005434182077	8698	Economy	12200.00
0005434182049	8698	Economy	13400.00
0005434181998	8698	Economy	13400.00
0005434095309	8698	Economy	12200.00
0005434095296	8698	Economy	12200.00
0005434182048	8698	Economy	12200.00
0005434182061	8698	Economy	12200.00
0005434095297	8698	Economy	12200.00
0005434095298	8698	Economy	12200.00
0005434182143	8698	Economy	12200.00
0005434095300	8698	Economy	12200.00
0005434095299	8698	Economy	12200.00
0005434095302	8698	Economy	12200.00
0005434095306	8698	Economy	12200.00
0005434095301	8698	Economy	12200.00
0005434095308	8698	Economy	12200.00
0005434181997	8698	Economy	12200.00
0005434143728	8698	Economy	12200.00
0005434143725	8698	Economy	12200.00
0005434182169	8698	Economy	12200.00
0005434182078	8698	Economy	12200.00
0005434182093	8698	Economy	12200.00
0005434182168	8698	Economy	12200.00
0005434182114	8698	Economy	12200.00
0005434095310	8698	Economy	12200.00
0005434095304	8698	Economy	12200.00
0005434095303	8698	Economy	12200.00
0005434143729	8698	Economy	12200.00
0005434143726	8698	Economy	12200.00
0005434182137	8698	Economy	12200.00
0005434182092	8698	Economy	12200.00
0005434182094	8698	Economy	12200.00
0005434095182	11677	Business	36500.00
0005434184667	11677	Business	36500.00
0005434095152	11677	Business	36500.00
0005434095199	11677	Business	36500.00
0005434182209	11677	Economy	12200.00
0005434095204	11677	Economy	12200.00
0005434183582	11677	Economy	12200.00
0005434095176	11677	Economy	12200.00
0005434182206	11677	Economy	12200.00
0005434095203	11677	Economy	12200.00
0005434182207	11677	Economy	13400.00
0005434095149	11677	Economy	13400.00
0005434182205	11677	Economy	12200.00
0005434095194	11677	Economy	12200.00
0005434095192	11677	Economy	12200.00
0005434182203	11677	Economy	12200.00
0005434182202	11677	Economy	12200.00
0005434095175	11677	Economy	12200.00
0005434095249	11677	Economy	12200.00
0005434183581	11677	Economy	12200.00
0005434182208	11677	Economy	12200.00
0005434095202	11677	Economy	12200.00
0005434182204	11677	Economy	12200.00
0005434182212	11677	Economy	12200.00
0005434182211	11677	Economy	12200.00
0005434182214	11677	Economy	12200.00
0005434095193	11677	Economy	12200.00
0005434183583	11677	Economy	12200.00
0005434143718	11677	Economy	12200.00
0005434182213	11677	Economy	12200.00
0005434182210	11677	Economy	12200.00
0005434095162	11677	Economy	12200.00
0005434095201	11677	Economy	12200.00
0005434095214	11677	Economy	12200.00
0005434182215	11677	Economy	12200.00
0005433397682	1440	Business	33000.00
0005435732347	1440	Business	33000.00
0005433397924	1440	Business	33000.00
0005433397762	1440	Business	33000.00
0005433397760	1440	Business	33000.00
0005433397741	1440	Business	33000.00
0005433397646	1440	Business	33000.00
0005433397672	1440	Business	33000.00
0005435732351	1440	Business	33000.00
0005433397635	1440	Business	33000.00
0005433397627	1440	Economy	11000.00
0005432297282	1440	Economy	11000.00
0005433456976	1440	Economy	11000.00
0005433397787	1440	Economy	11000.00
0005433397579	1440	Economy	11000.00
0005433397923	1440	Economy	12100.00
0005433397944	1440	Economy	12100.00
0005435732352	1440	Economy	12100.00
0005433397763	1440	Economy	12100.00
0005433397732	1440	Economy	12100.00
0005433397758	1440	Economy	11000.00
0005435732353	1440	Economy	11000.00
0005435732355	1440	Economy	11000.00
0005433397647	1440	Economy	11000.00
0005433397725	1440	Economy	11000.00
0005433397411	1440	Economy	11000.00
0005433397469	1440	Economy	11000.00
0005435732360	1440	Economy	11000.00
0005433397724	1440	Economy	11000.00
0005433397697	1440	Economy	11000.00
0005433397742	1440	Economy	11000.00
0005433397862	1440	Economy	11000.00
0005435732359	1440	Economy	11000.00
0005433397634	1440	Economy	11000.00
0005433397752	1440	Economy	11000.00
0005435732356	1440	Economy	11000.00
0005433397963	1440	Economy	11000.00
0005435732358	1440	Economy	11000.00
0005433397850	1440	Economy	11000.00
0005433397759	1440	Economy	11000.00
0005432906530	1440	Economy	11000.00
0005433397674	1440	Economy	11000.00
0005432297281	1440	Economy	11000.00
0005433397789	1440	Economy	11000.00
0005433397740	1440	Economy	11000.00
0005433397671	1440	Economy	11000.00
0005433456978	1440	Economy	11000.00
0005435732349	1440	Economy	11000.00
0005433397694	1440	Economy	11000.00
0005433397578	1440	Economy	11000.00
0005433397673	1440	Economy	11000.00
0005433397790	1440	Economy	11000.00
0005433397945	1440	Economy	11000.00
0005433397896	1440	Economy	11000.00
0005433397685	1440	Economy	11000.00
0005433397686	1440	Economy	11000.00
0005435732348	1440	Economy	11000.00
0005435732357	1440	Economy	11000.00
0005433397820	1440	Economy	11000.00
0005433397916	1440	Economy	11000.00
0005433397753	1440	Economy	11000.00
0005433397389	1440	Economy	11000.00
0005432297283	1440	Economy	11000.00
0005435732354	1440	Economy	11000.00
0005435732350	1440	Economy	11000.00
0005433397708	1440	Economy	11000.00
0005433456977	1440	Economy	11000.00
0005433397743	1440	Economy	11000.00
0005433397648	1440	Economy	11000.00
0005433397675	1440	Economy	11000.00
0005433397693	1440	Economy	11000.00
0005435732253	19236	Business	33000.00
0005435732240	19236	Business	33000.00
0005433398153	19236	Business	33000.00
0005433398132	19236	Business	33000.00
0005435732199	19236	Business	33000.00
0005433398160	19236	Business	33000.00
0005435732246	19236	Business	33000.00
0005433398140	19236	Economy	11000.00
0005433398133	19236	Economy	11000.00
0005433456942	19236	Economy	11000.00
0005433398144	19236	Economy	11000.00
0005433398156	19236	Economy	11000.00
0005433398148	19236	Economy	11000.00
0005435732198	19236	Economy	11000.00
0005433398164	19236	Economy	11000.00
0005433398126	19236	Economy	12100.00
0005433398146	19236	Economy	12100.00
0005435732269	19236	Economy	12100.00
0005435732268	19236	Economy	12100.00
0005433398147	19236	Economy	12100.00
0005433398170	19236	Economy	11000.00
0005433398171	19236	Economy	11000.00
0005433398136	19236	Economy	11000.00
0005433398167	19236	Economy	11000.00
0005433398149	19236	Economy	11000.00
0005433398173	19236	Economy	11000.00
0005433398139	19236	Economy	11000.00
0005433398137	19236	Economy	11000.00
0005433398141	19236	Economy	11000.00
0005433456943	19236	Economy	11000.00
0005433398172	19236	Economy	11000.00
0005433398162	19236	Economy	11000.00
0005433398127	19236	Economy	11000.00
0005433398165	19236	Economy	11000.00
0005433398138	19236	Economy	11000.00
0005435732234	19236	Economy	11000.00
0005433398152	19236	Economy	11000.00
0005435732254	19236	Economy	11000.00
0005433398142	19236	Economy	11000.00
0005433398163	19236	Economy	11000.00
0005435732264	19236	Economy	11000.00
0005433398159	19236	Economy	11000.00
0005433398166	19236	Economy	11000.00
0005435732221	19236	Economy	11000.00
0005433398131	19236	Economy	11000.00
0005433398125	19236	Economy	11000.00
0005433398129	19236	Economy	11000.00
0005433398154	19236	Economy	11000.00
0005433398130	19236	Economy	11000.00
0005432906541	19236	Economy	11000.00
0005433398155	19236	Economy	11000.00
0005433398134	19236	Economy	11000.00
0005433398161	19236	Economy	11000.00
0005433398124	19236	Economy	11000.00
0005433398169	19236	Economy	11000.00
0005435732189	19236	Economy	11000.00
0005435732267	19236	Economy	11000.00
0005433398158	19236	Economy	11000.00
0005433398150	19236	Economy	11000.00
0005433398143	19236	Economy	11000.00
0005433398145	19236	Economy	11000.00
0005433398128	19236	Economy	11000.00
0005433398151	19236	Economy	11000.00
0005433398135	19236	Economy	11000.00
0005433398157	19236	Economy	11000.00
0005433398168	19236	Economy	11000.00
0005433456934	19236	Economy	11000.00
0005434443593	17369	Economy	14100.00
0005434443629	17369	Economy	14100.00
0005434443518	17369	Economy	14100.00
0005434443630	17369	Economy	14100.00
0005434443631	17369	Economy	14100.00
0005434443563	17369	Economy	14100.00
0005434443726	20581	Economy	15600.00
0005434443721	20581	Economy	14100.00
0005434443735	20581	Economy	14100.00
0005434443722	20581	Economy	14100.00
0005434443734	20581	Economy	14100.00
0005434443724	20581	Economy	14100.00
0005434443729	20581	Economy	14100.00
0005434443736	20581	Economy	14100.00
0005434443732	20581	Economy	14100.00
0005434443725	20581	Economy	14100.00
0005434443733	20581	Economy	14100.00
0005434443727	20581	Economy	14100.00
0005434443730	20581	Economy	14100.00
0005434443728	20581	Economy	14100.00
0005434443731	20581	Economy	14100.00
0005434443723	20581	Economy	14100.00
0005434443737	20581	Economy	14100.00
0005434954617	7255	Economy	5800.00
0005434954616	7255	Economy	5800.00
0005434954585	28355	Economy	5800.00
0005434954582	28355	Economy	5800.00
0005434954577	28355	Economy	5800.00
0005435377585	28355	Economy	5800.00
0005434954584	28355	Economy	5800.00
0005435377586	28355	Economy	5800.00
0005434954588	28355	Economy	5800.00
0005435377584	28355	Economy	5800.00
0005434954583	28355	Economy	5800.00
0005435893593	4458	Economy	15400.00
0005434183570	4458	Economy	15400.00
0005435893596	4458	Economy	14000.00
0005435893590	4458	Economy	14000.00
0005434351715	4458	Economy	14000.00
0005434351724	4458	Economy	14000.00
0005434351721	4458	Economy	14000.00
0005435893605	4458	Economy	14000.00
0005435893600	4458	Economy	14000.00
0005434351716	4458	Economy	14000.00
0005435893574	4458	Economy	14000.00
0005434351714	4458	Economy	14000.00
0005434183569	4458	Economy	14000.00
0005434351717	4458	Economy	14000.00
0005434351720	4458	Economy	14000.00
0005435893604	4458	Economy	14000.00
0005435893599	4458	Economy	14000.00
0005434351725	4458	Economy	14000.00
0005434183568	4458	Economy	14000.00
0005435893595	4458	Economy	14000.00
0005435893594	4458	Economy	14000.00
0005434351723	4458	Economy	14000.00
0005435893589	4458	Economy	14000.00
0005435893573	4458	Economy	14000.00
0005434351722	4458	Economy	14000.00
0005435893601	4458	Economy	14000.00
0005435893561	4458	Economy	14000.00
0005434351719	4458	Economy	14000.00
0005435893586	4458	Economy	14000.00
0005434351718	4458	Economy	14000.00
0005434351592	29674	Economy	15400.00
0005435893644	29674	Economy	15400.00
0005434351589	29674	Economy	15400.00
0005434351652	29674	Economy	14000.00
0005434351554	29674	Economy	14000.00
0005434351667	29674	Economy	14000.00
0005435893643	29674	Economy	14000.00
0005434351649	29674	Economy	14000.00
0005434351614	29674	Economy	14000.00
0005434351666	29674	Economy	14000.00
0005434351605	29674	Economy	14000.00
0005434351613	29674	Economy	14000.00
0005434351591	29674	Economy	14000.00
0005434351594	29674	Economy	14000.00
0005434351644	29674	Economy	14000.00
0005435893642	29674	Economy	14000.00
0005434351643	29674	Economy	14000.00
0005435893647	29674	Economy	14000.00
0005434351621	29674	Economy	14000.00
0005435893648	29674	Economy	14000.00
0005435893641	29674	Economy	14000.00
0005434351645	29674	Economy	14000.00
0005435893645	29674	Economy	14000.00
0005434351593	29674	Economy	14000.00
0005434351555	29674	Economy	14000.00
0005434351648	29674	Economy	14000.00
0005435893646	29674	Economy	14000.00
0005435545760	1049	Business	30600.00
0005435092093	1049	Business	30600.00
0005433342448	1049	Business	30600.00
0005433342120	1049	Business	30600.00
0005433342014	1049	Business	30600.00
0005433342288	1049	Business	30600.00
0005433342477	1049	Business	30600.00
0005433342380	1049	Business	30600.00
0005433269674	1049	Business	30600.00
0005433269685	1049	Business	30600.00
0005433342121	1049	Business	30600.00
0005433342580	1049	Business	30600.00
0005433342211	1049	Business	30600.00
0005433342510	1049	Business	30600.00
0005433342167	1049	Business	30600.00
0005433342190	1049	Business	30600.00
0005435545765	1049	Economy	11200.00
0005434446523	1049	Economy	10200.00
0005433342303	1049	Economy	10200.00
0005435545752	1049	Economy	10200.00
0005433342660	1049	Economy	10200.00
0005435092090	1049	Economy	10200.00
0005433342451	1049	Economy	10200.00
0005433342198	1049	Economy	10200.00
0005433463905	1049	Economy	10200.00
0005434446524	1049	Economy	10200.00
0005435545758	1049	Economy	10200.00
0005434445252	1049	Economy	10200.00
0005433342466	1049	Economy	10200.00
0005433342362	1049	Economy	10200.00
0005433342794	1049	Economy	10200.00
0005433462750	1049	Economy	10200.00
0005433342625	1049	Economy	10200.00
0005433342287	1049	Economy	10200.00
0005433342403	1049	Economy	10200.00
0005432293214	1049	Economy	10200.00
0005435545759	1049	Economy	10200.00
0005433463904	1049	Economy	10200.00
0005433342037	1049	Economy	10200.00
0005433342013	1049	Economy	10200.00
0005433342212	1049	Economy	10200.00
0005435092087	1049	Economy	10200.00
0005435092089	1049	Economy	10200.00
0005433342491	1049	Economy	10200.00
0005435092094	1049	Economy	10200.00
0005435092096	1049	Economy	10200.00
0005433342447	1049	Economy	10200.00
0005433342125	1049	Economy	10200.00
0005433342111	1049	Economy	10200.00
0005435545766	1049	Economy	10200.00
0005433342558	1049	Economy	10200.00
0005435545762	1049	Economy	10200.00
0005433269684	1049	Economy	10200.00
0005433342615	1049	Economy	10200.00
0005435545756	1049	Economy	10200.00
0005433341870	1049	Economy	10200.00
0005433342183	1049	Economy	10200.00
0005433269673	1049	Economy	10200.00
0005433342482	1049	Economy	10200.00
0005433342312	1049	Economy	10200.00
0005433342419	1049	Economy	10200.00
0005433342420	1049	Economy	10200.00
0005433342484	1049	Economy	10200.00
0005432293213	1049	Economy	10200.00
0005433342712	1049	Economy	10200.00
0005433342421	1049	Economy	10200.00
0005433342659	1049	Economy	10200.00
0005433342581	1049	Economy	10200.00
0005433342562	1049	Economy	10200.00
0005432293212	1049	Economy	10200.00
0005433341898	1049	Economy	10200.00
0005433342122	1049	Economy	10200.00
0005433342231	1049	Economy	10200.00
0005435545757	1049	Economy	10200.00
0005433342043	1049	Economy	10200.00
0005435092097	1049	Economy	10200.00
0005433342382	1049	Economy	10200.00
0005433342476	1049	Economy	10200.00
0005433269659	1049	Economy	10200.00
0005433269658	1049	Economy	10200.00
0005433342302	1049	Economy	10200.00
0005433342669	1049	Economy	11200.00
0005433462751	1049	Economy	10200.00
0005433342596	1049	Economy	11200.00
0005433342617	1049	Economy	10200.00
0005435545754	1049	Economy	10200.00
0005433342511	1049	Economy	10200.00
0005433342490	1049	Economy	10200.00
0005435092095	1049	Economy	10200.00
0005435545761	1049	Economy	10200.00
0005433342191	1049	Economy	10200.00
0005435545755	1049	Economy	10200.00
0005435545753	1049	Economy	10200.00
0005433342410	1049	Economy	10200.00
0005433342354	1049	Economy	10200.00
0005433342636	1049	Economy	10200.00
0005433342694	1049	Economy	10200.00
0005434446521	1049	Economy	10200.00
0005433342483	1049	Economy	10200.00
0005435545767	1049	Economy	10200.00
0005434446522	1049	Economy	10200.00
0005433342626	1049	Economy	10200.00
0005433342262	1049	Economy	10200.00
0005433342346	1049	Economy	10200.00
0005433342290	1049	Economy	10200.00
0005433342671	1049	Economy	10200.00
0005433342616	1049	Economy	10200.00
0005433269660	1049	Economy	10200.00
0005433342627	1049	Economy	10200.00
0005433342977	1049	Economy	10200.00
0005433342347	1049	Economy	10200.00
0005433342478	1049	Economy	10200.00
0005433342392	1049	Economy	10200.00
0005433342108	1049	Economy	10200.00
0005433342342	1049	Economy	10200.00
0005435545763	1049	Economy	10200.00
0005434445253	1049	Economy	10200.00
0005433342519	1049	Economy	10200.00
0005435092092	1049	Economy	10200.00
0005433342363	1049	Economy	10200.00
0005433342582	1049	Economy	10200.00
0005433342059	1049	Economy	10200.00
0005433158122	1049	Economy	10200.00
0005433342701	1049	Economy	10200.00
0005435092091	1049	Economy	10200.00
0005435545764	1049	Economy	10200.00
0005433342635	1049	Economy	10200.00
0005433342264	1049	Economy	10200.00
0005433342157	1049	Economy	10200.00
0005435092088	1049	Economy	10200.00
0005433342263	1049	Economy	10200.00
0005433342450	1049	Economy	10200.00
0005433341970	1049	Economy	10200.00
0005433343269	17043	Business	30600.00
0005433343214	17043	Business	30600.00
0005435508237	17043	Business	30600.00
0005433343232	17043	Business	30600.00
0005433343220	17043	Business	30600.00
0005435092037	17043	Business	30600.00
0005434445238	17043	Business	30600.00
0005433343282	17043	Business	30600.00
0005433343268	17043	Business	30600.00
0005433343262	17043	Business	30600.00
0005433343251	17043	Business	30600.00
0005435091994	17043	Business	30600.00
0005433343218	17043	Business	30600.00
0005433343276	17043	Business	30600.00
0005435508248	17043	Business	30600.00
0005433343259	17043	Economy	11200.00
0005433343313	17043	Economy	11200.00
0005434445230	17043	Economy	11200.00
0005433343246	17043	Economy	10200.00
0005433343271	17043	Economy	10200.00
0005434445236	17043	Economy	10200.00
0005433343303	17043	Economy	10200.00
0005433343305	17043	Economy	10200.00
0005433343219	17043	Economy	10200.00
0005433343229	17043	Economy	10200.00
0005433343223	17043	Economy	10200.00
0005433343222	17043	Economy	10200.00
0005435091993	17043	Economy	10200.00
0005433343308	17043	Economy	10200.00
0005433343257	17043	Economy	10200.00
0005435508225	17043	Economy	10200.00
0005433343258	17043	Economy	10200.00
0005433343277	17043	Economy	10200.00
0005435091995	17043	Economy	10200.00
0005433343296	17043	Economy	10200.00
0005433343309	17043	Economy	10200.00
0005433343290	17043	Economy	10200.00
0005435508235	17043	Economy	10200.00
0005433343272	17043	Economy	10200.00
0005433343261	17043	Economy	10200.00
0005433269730	17043	Economy	10200.00
0005433343253	17043	Economy	10200.00
0005433343288	17043	Economy	10200.00
0005433343217	17043	Economy	10200.00
0005433343215	17043	Economy	10200.00
0005433343247	17043	Economy	10200.00
0005433343226	17043	Economy	10200.00
0005433343292	17043	Economy	10200.00
0005433343238	17043	Economy	10200.00
0005433343307	17043	Economy	10200.00
0005433343213	17043	Economy	10200.00
0005433343234	17043	Economy	10200.00
0005433343241	17043	Economy	10200.00
0005433343227	17043	Economy	10200.00
0005433343302	17043	Economy	10200.00
0005433343295	17043	Economy	10200.00
0005433343285	17043	Economy	10200.00
0005433343287	17043	Economy	10200.00
0005433269729	17043	Economy	10200.00
0005433343301	17043	Economy	10200.00
0005433343243	17043	Economy	10200.00
0005435508215	17043	Economy	10200.00
0005433343225	17043	Economy	10200.00
0005434445239	17043	Economy	10200.00
0005433343245	17043	Economy	10200.00
0005433343280	17043	Economy	10200.00
0005433343286	17043	Economy	10200.00
0005433343311	17043	Economy	10200.00
0005433343275	17043	Economy	10200.00
0005433343255	17043	Economy	10200.00
0005433343300	17043	Economy	10200.00
0005433343306	17043	Economy	10200.00
0005433343270	17043	Economy	10200.00
0005433343265	17043	Economy	10200.00
0005433343216	17043	Economy	10200.00
0005433343312	17043	Economy	11200.00
0005433343289	17043	Economy	11200.00
0005433343230	17043	Economy	10200.00
0005433343273	17043	Economy	10200.00
0005433343293	17043	Economy	10200.00
0005433343252	17043	Economy	11200.00
0005433343228	17043	Economy	10200.00
0005435508249	17043	Economy	10200.00
0005435508264	17043	Economy	10200.00
0005433343299	17043	Economy	10200.00
0005433343266	17043	Economy	10200.00
0005433343281	17043	Economy	10200.00
0005433343233	17043	Economy	10200.00
0005433343304	17043	Economy	10200.00
0005433343250	17043	Economy	10200.00
0005433343298	17043	Economy	10200.00
0005433343264	17043	Economy	10200.00
0005433343236	17043	Economy	10200.00
0005433269728	17043	Economy	10200.00
0005433343235	17043	Economy	10200.00
0005433343237	17043	Economy	10200.00
0005433269726	17043	Economy	10200.00
0005435091976	17043	Economy	10200.00
0005433343291	17043	Economy	10200.00
0005433343283	17043	Economy	10200.00
0005433343240	17043	Economy	10200.00
0005433343248	17043	Economy	10200.00
0005435508238	17043	Economy	10200.00
0005435508263	17043	Economy	10200.00
0005433343249	17043	Economy	10200.00
0005433343239	17043	Economy	10200.00
0005433343260	17043	Economy	10200.00
0005434445224	17043	Economy	10200.00
0005433343256	17043	Economy	10200.00
0005433343297	17043	Economy	10200.00
0005433343310	17043	Economy	10200.00
0005433343242	17043	Economy	10200.00
0005433343274	17043	Economy	10200.00
0005435508265	17043	Economy	10200.00
0005433269727	17043	Economy	10200.00
0005433343278	17043	Economy	10200.00
0005435092036	17043	Economy	10200.00
0005433343267	17043	Economy	10200.00
0005433343263	17043	Economy	10200.00
0005435508256	17043	Economy	10200.00
0005433343224	17043	Economy	10200.00
0005433343231	17043	Economy	10200.00
0005433343221	17043	Economy	10200.00
0005433343254	17043	Economy	10200.00
0005433343294	17043	Economy	10200.00
0005433343244	17043	Economy	10200.00
0005433343279	17043	Economy	10200.00
0005433343284	17043	Economy	10200.00
0005434067146	12810	Business	40300.00
0005434067065	12810	Business	40300.00
0005434066897	12810	Business	40300.00
0005434066984	12810	Business	40300.00
0005434081727	12810	Business	40300.00
0005434081677	12810	Business	40300.00
0005432159867	12810	Business	40300.00
0005434067151	12810	Business	40300.00
0005434066801	12810	Business	40300.00
0005434081714	12810	Business	40300.00
0005432433691	12810	Business	40300.00
0005434067253	12810	Business	40300.00
0005434067157	12810	Economy	13400.00
0005434067045	12810	Economy	13400.00
0005432159864	12810	Economy	13400.00
0005434081784	12810	Economy	13400.00
0005434081797	12810	Economy	13400.00
0005433989726	12810	Economy	13400.00
0005434066974	12810	Economy	13400.00
0005434066614	12810	Economy	13400.00
0005432433688	12810	Economy	13400.00
0005433989737	12810	Economy	13400.00
0005434081710	12810	Economy	13400.00
0005434066750	12810	Economy	13400.00
0005433989751	12810	Economy	13400.00
0005432433690	12810	Economy	13400.00
0005434067014	12810	Economy	13400.00
0005434067046	12810	Economy	13400.00
0005432159868	12810	Economy	13400.00
0005434081783	12810	Economy	13400.00
0005434067124	12810	Economy	13400.00
0005434081702	12810	Economy	13400.00
0005434081729	12810	Economy	13400.00
0005434067264	12810	Economy	13400.00
0005434066821	12810	Economy	13400.00
0005434067348	12810	Economy	13400.00
0005434067092	12810	Economy	13400.00
0005432161157	12810	Economy	13400.00
0005434067091	12810	Economy	13400.00
0005433812905	12810	Economy	13400.00
0005434067042	12810	Economy	13400.00
0005434066615	12810	Economy	13400.00
0005434066822	12810	Economy	13400.00
0005434067125	12810	Economy	13400.00
0005434067349	12810	Economy	13400.00
0005434067263	12810	Economy	13400.00
0005434066885	12810	Economy	13400.00
0005434081735	12810	Economy	13400.00
0005434081607	12810	Economy	13400.00
0005434081605	12810	Economy	13400.00
0005434066935	12810	Economy	13400.00
0005434081742	12810	Economy	14800.00
0005434066693	12810	Economy	14800.00
0005434067041	12810	Economy	14800.00
0005434066896	12810	Economy	14800.00
0005434066933	12810	Economy	14800.00
0005434067003	12810	Economy	13400.00
0005434067019	12810	Economy	13400.00
0005434067180	12810	Economy	13400.00
0005434081788	12810	Economy	13400.00
0005434066994	12810	Economy	13400.00
0005433989723	12810	Economy	13400.00
0005434067174	12810	Economy	13400.00
0005434081690	12810	Economy	13400.00
0005434067162	12810	Economy	13400.00
0005434066986	12810	Economy	13400.00
0005434067254	12810	Economy	13400.00
0005434066817	12810	Economy	13400.00
0005434066731	12810	Economy	13400.00
0005434067040	12810	Economy	13400.00
0005434081748	12810	Economy	13400.00
0005432159865	12810	Economy	13400.00
0005434066914	12810	Economy	13400.00
0005433989763	12810	Economy	13400.00
0005434081692	12810	Economy	13400.00
0005434066934	12810	Economy	13400.00
0005434066659	12810	Economy	13400.00
0005434067170	12810	Economy	13400.00
0005434066941	12810	Economy	13400.00
0005434081726	12810	Economy	13400.00
0005434081637	12810	Economy	13400.00
0005434067073	12810	Economy	13400.00
0005434067089	12810	Economy	13400.00
0005434066751	12810	Economy	13400.00
0005432159866	12810	Economy	13400.00
0005433989727	12810	Economy	13400.00
0005434067209	12810	Economy	13400.00
0005432161156	12810	Economy	13400.00
0005434081717	12810	Economy	13400.00
0005434066818	12810	Economy	13400.00
0005434066878	12810	Economy	13400.00
0005434066660	12810	Economy	13400.00
0005434081693	12810	Economy	13400.00
0005434081711	12810	Economy	13400.00
0005434067066	12810	Economy	13400.00
0005434066940	12810	Economy	13400.00
0005434081789	12810	Economy	13400.00
0005434067203	12810	Economy	13400.00
0005434067265	12810	Economy	13400.00
0005434066857	12810	Economy	13400.00
0005434081676	12810	Economy	13400.00
0005434067208	12810	Economy	13400.00
0005434067081	12810	Economy	13400.00
0005434066767	12810	Economy	13400.00
0005434066971	12810	Economy	13400.00
0005434066848	12810	Economy	13400.00
0005434081730	12810	Economy	13400.00
0005434067093	12810	Economy	13400.00
0005433812904	12810	Economy	13400.00
0005434067210	12810	Economy	13400.00
0005434081606	12810	Economy	13400.00
0005432433689	12810	Economy	13400.00
0005432433692	12810	Economy	13400.00
0005434066811	12810	Economy	13400.00
0005434081778	12810	Economy	13400.00
0005432161155	12810	Economy	13400.00
0005434067236	12810	Economy	13400.00
0005434067082	12810	Economy	13400.00
0005434067320	12810	Economy	13400.00
0005434067235	12810	Economy	13400.00
0005434081715	12810	Economy	13400.00
0005434067010	12810	Economy	13400.00
0005434067100	12810	Economy	13400.00
0005434081790	12810	Economy	13400.00
0005434066970	12810	Economy	13400.00
0005433989777	30660	Business	40300.00
0005432433664	30660	Business	40300.00
0005434067632	30660	Business	40300.00
0005433812876	30660	Business	40300.00
0005434067620	30660	Business	40300.00
0005434067666	30660	Business	40300.00
0005434067617	30660	Business	40300.00
0005434067622	30660	Business	40300.00
0005434067621	30660	Business	40300.00
0005434067673	30660	Business	40300.00
0005434081920	30660	Business	40300.00
0005432150200	30660	Economy	13400.00
0005434081925	30660	Economy	13400.00
0005434067605	30660	Economy	13400.00
0005434067624	30660	Economy	13400.00
0005434067656	30660	Economy	13400.00
0005434067657	30660	Economy	13400.00
0005433812873	30660	Economy	13400.00
0005434067667	30660	Economy	13400.00
0005433812877	30660	Economy	13400.00
0005432150205	30660	Economy	13400.00
0005434067651	30660	Economy	13400.00
0005434067642	30660	Economy	13400.00
0005434081921	30660	Economy	13400.00
0005434067604	30660	Economy	13400.00
0005434067650	30660	Economy	13400.00
0005434067653	30660	Economy	13400.00
0005433812875	30660	Economy	13400.00
0005434067627	30660	Economy	13400.00
0005434081927	30660	Economy	13400.00
0005434067668	30660	Economy	13400.00
0005434067649	30660	Economy	13400.00
0005434026702	30660	Economy	13400.00
0005434067630	30660	Economy	13400.00
0005434067654	30660	Economy	13400.00
0005434067635	30660	Economy	13400.00
0005434067619	30660	Economy	13400.00
0005432433665	30660	Economy	13400.00
0005433812864	30660	Economy	13400.00
0005434067603	30660	Economy	13400.00
0005434067612	30660	Economy	13400.00
0005434067672	30660	Economy	13400.00
0005433989776	30660	Economy	13400.00
0005434067663	30660	Economy	13400.00
0005434067658	30660	Economy	13400.00
0005434067628	30660	Economy	13400.00
0005434067664	30660	Economy	13400.00
0005434067655	30660	Economy	13400.00
0005434067660	30660	Economy	13400.00
0005434067618	30660	Economy	14800.00
0005434067611	30660	Economy	14800.00
0005432150203	30660	Economy	14800.00
0005434026701	30660	Economy	14800.00
0005432150204	30660	Economy	14800.00
0005434026705	30660	Economy	14800.00
0005434067639	30660	Economy	13400.00
0005434081926	30660	Economy	13400.00
0005434067616	30660	Economy	13400.00
0005433812872	30660	Economy	13400.00
0005434067675	30660	Economy	13400.00
0005433989775	30660	Economy	13400.00
0005434067615	30660	Economy	13400.00
0005434067671	30660	Economy	13400.00
0005434067636	30660	Economy	13400.00
0005434067659	30660	Economy	13400.00
0005434067623	30660	Economy	13400.00
0005434067652	30660	Economy	13400.00
0005434067631	30660	Economy	13400.00
0005432150206	30660	Economy	13400.00
0005432150201	30660	Economy	13400.00
0005432433629	30660	Economy	13400.00
0005434067670	30660	Economy	13400.00
0005432186873	30660	Economy	13400.00
0005434067643	30660	Economy	13400.00
0005434026708	30660	Economy	13400.00
0005434067614	30660	Economy	13400.00
0005434067641	30660	Economy	13400.00
0005434067638	30660	Economy	13400.00
0005434067607	30660	Economy	13400.00
0005434067609	30660	Economy	13400.00
0005433812865	30660	Economy	13400.00
0005434067644	30660	Economy	13400.00
0005434067625	30660	Economy	13400.00
0005434081922	30660	Economy	13400.00
0005432186871	30660	Economy	13400.00
0005434026704	30660	Economy	13400.00
0005434067634	30660	Economy	13400.00
0005434067669	30660	Economy	13400.00
0005433812867	30660	Economy	13400.00
0005434067646	30660	Economy	13400.00
0005434067606	30660	Economy	13400.00
0005434067608	30660	Economy	13400.00
0005434081928	30660	Economy	13400.00
0005434026707	30660	Economy	13400.00
0005432186874	30660	Economy	13400.00
0005434067665	30660	Economy	13400.00
0005434067640	30660	Economy	13400.00
0005432150202	30660	Economy	13400.00
0005434026706	30660	Economy	13400.00
0005434081919	30660	Economy	13400.00
0005433812874	30660	Economy	13400.00
0005432186872	30660	Economy	13400.00
0005432433635	30660	Economy	13400.00
0005434081923	30660	Economy	13400.00
0005432433649	30660	Economy	13400.00
0005434067633	30660	Economy	13400.00
0005434067661	30660	Economy	13400.00
0005434026703	30660	Economy	13400.00
0005434067610	30660	Economy	13400.00
0005434067662	30660	Economy	13400.00
0005434067645	30660	Economy	13400.00
0005432433636	30660	Economy	13400.00
0005434067674	30660	Economy	13400.00
0005434067613	30660	Economy	13400.00
0005434067629	30660	Economy	13400.00
0005434081924	30660	Economy	13400.00
0005434067626	30660	Economy	13400.00
0005434081918	30660	Economy	13400.00
0005434067647	30660	Economy	13400.00
0005434067637	30660	Economy	13400.00
0005434067648	30660	Economy	13400.00
0005435766347	5546	Business	35300.00
0005435735141	5546	Business	35300.00
0005435462152	5546	Business	35300.00
0005435725605	5546	Business	35300.00
0005434264910	5546	Business	35300.00
0005435461995	5546	Business	35300.00
0005435461993	5546	Business	35300.00
0005435766315	5546	Business	35300.00
0005435766354	5546	Business	35300.00
0005435766329	5546	Business	35300.00
0005435462148	5546	Business	35300.00
0005435462202	5546	Business	35300.00
0005434265064	5546	Business	35300.00
0005435462125	5546	Business	35300.00
0005435462054	5546	Business	35300.00
0005435766355	5546	Business	35300.00
0005434264897	5546	Business	35300.00
0005435766333	5546	Business	35300.00
0005435462262	5546	Business	35300.00
0005435462151	5546	Business	35300.00
0005435766346	5546	Business	35300.00
0005435462225	5546	Business	35300.00
0005434265090	5546	Business	35300.00
0005435462040	5546	Business	35300.00
0005435723048	5546	Economy	12900.00
0005435766343	5546	Economy	12900.00
0005433529286	5546	Economy	11800.00
0005433527273	5546	Economy	11800.00
0005435735142	5546	Economy	11800.00
0005435725608	5546	Economy	11800.00
0005433527274	5546	Economy	11800.00
0005435462327	5546	Economy	11800.00
0005434831091	5546	Economy	11800.00
0005435462250	5546	Economy	11800.00
0005435766319	5546	Economy	11800.00
0005435462266	5546	Economy	11800.00
0005435462027	5546	Economy	11800.00
0005435766317	5546	Economy	11800.00
0005435766357	5546	Economy	11800.00
0005433529285	5546	Economy	11800.00
0005433529289	5546	Economy	11800.00
0005435462326	5546	Economy	11800.00
0005435725603	5546	Economy	11800.00
0005435462281	5546	Economy	11800.00
0005435766332	5546	Economy	11800.00
0005435462166	5546	Economy	11800.00
0005434265011	5546	Economy	11800.00
0005435462252	5546	Economy	11800.00
0005435722060	5546	Economy	11800.00
0005435462218	5546	Economy	11800.00
0005434264909	5546	Economy	11800.00
0005435462306	5546	Economy	11800.00
0005432535794	5546	Economy	11800.00
0005432140465	5546	Economy	11800.00
0005434264947	5546	Economy	11800.00
0005432140462	5546	Economy	11800.00
0005435766322	5546	Economy	11800.00
0005434264864	5546	Economy	11800.00
0005435462160	5546	Economy	11800.00
0005435462251	5546	Economy	11800.00
0005434265063	5546	Economy	11800.00
0005434264945	5546	Economy	11800.00
0005435462169	5546	Economy	11800.00
0005435462140	5546	Economy	11800.00
0005432140460	5546	Economy	11800.00
0005435766340	5546	Economy	11800.00
0005435462195	5546	Economy	11800.00
0005435766311	5546	Economy	11800.00
0005435766336	5546	Economy	11800.00
0005435461997	5546	Economy	11800.00
0005435462168	5546	Economy	11800.00
0005435766352	5546	Economy	11800.00
0005435735143	5546	Economy	11800.00
0005435462150	5546	Economy	11800.00
0005435462024	5546	Economy	11800.00
0005433529288	5546	Economy	11800.00
0005432140466	5546	Economy	11800.00
0005435766324	5546	Economy	11800.00
0005435462149	5546	Economy	11800.00
0005434831103	5546	Economy	11800.00
0005433527275	5546	Economy	11800.00
0005432535807	5546	Economy	11800.00
0005435766345	5546	Economy	11800.00
0005432535808	5546	Economy	11800.00
0005435462199	5546	Economy	11800.00
0005435725604	5546	Economy	11800.00
0005435766348	5546	Economy	11800.00
0005435766327	5546	Economy	11800.00
0005435766351	5546	Economy	11800.00
0005435766338	5546	Economy	11800.00
0005435766356	5546	Economy	11800.00
0005435766325	5546	Economy	11800.00
0005435462203	5546	Economy	11800.00
0005435766321	5546	Economy	11800.00
0005435766318	5546	Economy	11800.00
0005435462219	5546	Economy	11800.00
0005433529287	5546	Economy	11800.00
0005434264959	5546	Economy	11800.00
0005435462161	5546	Economy	11800.00
0005432140464	5546	Economy	11800.00
0005435766328	5546	Economy	11800.00
0005435766331	5546	Economy	11800.00
0005435462200	5546	Economy	12900.00
0005434264991	5546	Economy	12900.00
0005435461996	5546	Economy	11800.00
0005435461934	5546	Economy	11800.00
0005435043280	5546	Economy	11800.00
0005435725606	5546	Economy	12900.00
0005432535814	5546	Economy	12900.00
0005435462182	5546	Economy	11800.00
0005435462224	5546	Economy	11800.00
0005435766330	5546	Economy	11800.00
0005435462264	5546	Economy	11800.00
0005435725607	5546	Economy	11800.00
0005432140463	5546	Economy	11800.00
0005434265065	5546	Economy	11800.00
0005435766358	5546	Economy	11800.00
0005432140461	5546	Economy	11800.00
0005435766334	5546	Economy	11800.00
0005435462269	5546	Economy	11800.00
0005435766312	5546	Economy	11800.00
0005435766349	5546	Economy	11800.00
0005435766323	5546	Economy	11800.00
0005432535790	5546	Economy	11800.00
0005435462028	5546	Economy	11800.00
0005435766337	5546	Economy	11800.00
0005435043279	5546	Economy	11800.00
0005435722058	5546	Economy	11800.00
0005435462204	5546	Economy	11800.00
0005435462180	5546	Economy	11800.00
0005435462291	5546	Economy	11800.00
0005435766342	5546	Economy	11800.00
0005435766320	5546	Economy	11800.00
0005435462272	5546	Economy	11800.00
0005435766316	5546	Economy	11800.00
0005435766359	5546	Economy	11800.00
0005435722059	5546	Economy	11800.00
0005435766353	5546	Economy	11800.00
0005435766339	5546	Economy	11800.00
0005435462126	5546	Economy	11800.00
0005435766344	5546	Economy	11800.00
0005435462261	5546	Economy	11800.00
0005433527276	5546	Economy	11800.00
0005434264964	5546	Economy	11800.00
0005435462206	5546	Economy	11800.00
0005435722061	5546	Economy	11800.00
0005435462098	5546	Economy	11800.00
0005434264781	5546	Economy	11800.00
0005435766350	5546	Economy	11800.00
0005435723049	5546	Economy	11800.00
0005434264948	5546	Economy	11800.00
0005434831109	5546	Economy	11800.00
0005434264981	5546	Economy	11800.00
0005434264990	5546	Economy	11800.00
0005435462181	5546	Economy	11800.00
0005435462332	5546	Economy	11800.00
0005435462282	5546	Economy	11800.00
0005435766341	5546	Economy	11800.00
0005435461994	5546	Economy	11800.00
0005435766335	5546	Economy	11800.00
0005433529284	5546	Economy	11800.00
0005435766326	5546	Economy	11800.00
0005435766314	5546	Economy	11800.00
0005434264946	5546	Economy	11800.00
0005435462290	5546	Economy	11800.00
0005434264835	5546	Economy	11800.00
0005435766313	5546	Economy	11800.00
0005435462217	5546	Economy	11800.00
0005435462513	13500	Business	35300.00
0005435462508	13500	Business	35300.00
0005435735090	13500	Business	35300.00
0005435765827	13500	Business	35300.00
0005435765960	13500	Business	35300.00
0005435722039	13500	Business	35300.00
0005435765767	13500	Business	35300.00
0005435765737	13500	Business	35300.00
0005435765856	13500	Business	35300.00
0005432535842	13500	Business	35300.00
0005435765809	13500	Business	35300.00
0005434265200	13500	Business	35300.00
0005434265182	13500	Business	35300.00
0005435720124	13500	Business	35300.00
0005434265194	13500	Business	35300.00
0005434265193	13500	Business	35300.00
0005432194518	13500	Business	35300.00
0005432535843	13500	Business	35300.00
0005435766105	13500	Business	35300.00
0005435462512	13500	Business	35300.00
0005435765845	13500	Business	35300.00
0005435765780	13500	Business	35300.00
0005435765506	13500	Business	35300.00
0005435725559	13500	Business	35300.00
0005435765972	13500	Business	35300.00
0005435765676	13500	Business	35300.00
0005434831160	13500	Economy	12900.00
0005435765694	13500	Economy	12900.00
0005435765756	13500	Economy	11800.00
0005435765792	13500	Economy	11800.00
0005435765637	13500	Economy	11800.00
0005435765727	13500	Economy	11800.00
0005435765844	13500	Economy	11800.00
0005435765965	13500	Economy	11800.00
0005435766011	13500	Economy	11800.00
0005435765507	13500	Economy	11800.00
0005435765903	13500	Economy	11800.00
0005435765797	13500	Economy	11800.00
0005434265202	13500	Economy	11800.00
0005435462526	13500	Economy	11800.00
0005435720129	13500	Economy	11800.00
0005435723027	13500	Economy	11800.00
0005434265198	13500	Economy	11800.00
0005435462523	13500	Economy	11800.00
0005435765958	13500	Economy	11800.00
0005432535845	13500	Economy	11800.00
0005435765872	13500	Economy	11800.00
0005435462499	13500	Economy	11800.00
0005434265192	13500	Economy	11800.00
0005435765926	13500	Economy	11800.00
0005434265179	13500	Economy	11800.00
0005435462503	13500	Economy	11800.00
0005435462494	13500	Economy	11800.00
0005435766106	13500	Economy	11800.00
0005435723026	13500	Economy	11800.00
0005435462495	13500	Economy	11800.00
0005435462517	13500	Economy	11800.00
0005435725578	13500	Economy	11800.00
0005435766099	13500	Economy	11800.00
0005434265184	13500	Economy	11800.00
0005434265180	13500	Economy	11800.00
0005432194520	13500	Economy	11800.00
0005435765914	13500	Economy	11800.00
0005435765966	13500	Economy	11800.00
0005435766160	13500	Economy	11800.00
0005435765414	13500	Economy	11800.00
0005435462520	13500	Economy	11800.00
0005434265190	13500	Economy	11800.00
0005435765863	13500	Economy	11800.00
0005435766128	13500	Economy	11800.00
0005435462500	13500	Economy	11800.00
0005434265195	13500	Economy	11800.00
0005435462507	13500	Economy	11800.00
0005435462511	13500	Economy	11800.00
0005435462510	13500	Economy	11800.00
0005435766002	13500	Economy	11800.00
0005434265196	13500	Economy	11800.00
0005434265181	13500	Economy	11800.00
0005435765876	13500	Economy	11800.00
0005432535841	13500	Economy	11800.00
0005435462505	13500	Economy	11800.00
0005435765859	13500	Economy	11800.00
0005435765700	13500	Economy	11800.00
0005435735093	13500	Economy	11800.00
0005435725521	13500	Economy	11800.00
0005435766129	13500	Economy	11800.00
0005434265183	13500	Economy	11800.00
0005435766159	13500	Economy	11800.00
0005435462498	13500	Economy	11800.00
0005435766024	13500	Economy	11800.00
0005435766009	13500	Economy	11800.00
0005435462491	13500	Economy	11800.00
0005435765785	13500	Economy	11800.00
0005432194519	13500	Economy	11800.00
0005435765988	13500	Economy	11800.00
0005435720127	13500	Economy	11800.00
0005435765798	13500	Economy	11800.00
0005435462502	13500	Economy	11800.00
0005435766049	13500	Economy	11800.00
0005435765667	13500	Economy	11800.00
0005435765673	13500	Economy	11800.00
0005435725573	13500	Economy	11800.00
0005435765699	13500	Economy	11800.00
0005435462522	13500	Economy	11800.00
0005434831161	13500	Economy	11800.00
0005432535844	13500	Economy	11800.00
0005435766130	13500	Economy	11800.00
0005435765829	13500	Economy	12900.00
0005435766004	13500	Economy	12900.00
0005435462527	13500	Economy	11800.00
0005434265187	13500	Economy	11800.00
0005435462528	13500	Economy	11800.00
0005435765779	13500	Economy	12900.00
0005435765723	13500	Economy	12900.00
0005435765837	13500	Economy	11800.00
0005435765415	13500	Economy	11800.00
0005435462515	13500	Economy	11800.00
0005435765799	13500	Economy	11800.00
0005435765649	13500	Economy	11800.00
0005435735086	13500	Economy	11800.00
0005435462509	13500	Economy	11800.00
0005435766003	13500	Economy	11800.00
0005435462521	13500	Economy	11800.00
0005435735097	13500	Economy	11800.00
0005435765816	13500	Economy	11800.00
0005435462516	13500	Economy	11800.00
0005435462525	13500	Economy	11800.00
0005435765902	13500	Economy	11800.00
0005435765489	13500	Economy	11800.00
0005435462524	13500	Economy	11800.00
0005434265191	13500	Economy	11800.00
0005435462501	13500	Economy	11800.00
0005434831162	13500	Economy	11800.00
0005435735098	13500	Economy	11800.00
0005434265188	13500	Economy	11800.00
0005435735099	13500	Economy	11800.00
0005435723025	13500	Economy	11800.00
0005434265189	13500	Economy	11800.00
0005434265199	13500	Economy	11800.00
0005435765838	13500	Economy	11800.00
0005435462497	13500	Economy	11800.00
0005435765777	13500	Economy	11800.00
0005435765839	13500	Economy	11800.00
0005435765746	13500	Economy	11800.00
0005435766025	13500	Economy	11800.00
0005435765817	13500	Economy	11800.00
0005435462506	13500	Economy	11800.00
0005435765490	13500	Economy	11800.00
0005435765877	13500	Economy	11800.00
0005435765755	13500	Economy	11800.00
0005434265186	13500	Economy	11800.00
0005435462492	13500	Economy	11800.00
0005435766162	13500	Economy	11800.00
0005434265201	13500	Economy	11800.00
0005435765922	13500	Economy	11800.00
0005435462504	13500	Economy	11800.00
0005435766161	13500	Economy	11800.00
0005435765751	13500	Economy	11800.00
0005435462518	13500	Economy	11800.00
0005435725558	13500	Economy	11800.00
0005434265185	13500	Economy	11800.00
0005435462496	13500	Economy	11800.00
0005434265197	13500	Economy	11800.00
0005435766010	13500	Economy	11800.00
0005435765828	13500	Economy	11800.00
0005435462519	13500	Economy	11800.00
0005435766046	13500	Economy	11800.00
0005435765665	13500	Economy	11800.00
0005435462514	13500	Economy	11800.00
0005435765678	13500	Economy	11800.00
0005435765961	13500	Economy	11800.00
0005435765909	13500	Economy	11800.00
0005435765551	13500	Economy	11800.00
0005435765904	13500	Economy	11800.00
0005435462493	13500	Economy	11800.00
0005434265203	13500	Economy	11800.00
0005434513582	18747	Economy	3300.00
0005434604862	18747	Economy	3300.00
0005434604861	18747	Economy	3300.00
0005434514970	18747	Economy	3300.00
0005434513583	18747	Economy	3300.00
0005434604871	18747	Economy	3300.00
0005435904707	18747	Economy	3300.00
0005434514971	18747	Economy	3300.00
0005434514969	18747	Economy	3300.00
0005434602904	19177	Economy	3300.00
0005434514941	19177	Economy	3300.00
0005434514963	19177	Economy	3300.00
0005434602902	19177	Economy	3300.00
0005434602903	19177	Economy	3300.00
0005434514957	19177	Economy	3300.00
0005434602901	19177	Economy	3300.00
0005434514940	19177	Economy	3300.00
0005434514964	19177	Economy	3300.00
0005434514946	19177	Economy	3300.00
0005434602900	19177	Economy	3300.00
0005435844326	25102	Business	88300.00
0005435846259	25102	Business	88300.00
0005432632680	25102	Business	88300.00
0005435844313	25102	Business	88300.00
0005432649351	25102	Business	88300.00
0005432632682	25102	Business	88300.00
0005432649372	25102	Business	88300.00
0005432632641	25102	Business	88300.00
0005432632652	25102	Business	88300.00
0005435844322	25102	Economy	29400.00
0005432632624	25102	Economy	29400.00
0005435844315	25102	Economy	29400.00
0005432632666	25102	Economy	29400.00
0005432649356	25102	Economy	29400.00
0005432649359	25102	Economy	29400.00
0005435846254	25102	Economy	29400.00
0005435846255	25102	Economy	29400.00
0005435844324	25102	Economy	32400.00
0005432649394	25102	Economy	32400.00
0005432632683	25102	Economy	32400.00
0005435844314	25102	Economy	29400.00
0005432632681	25102	Economy	29400.00
0005432649373	25102	Economy	29400.00
0005435844319	25102	Economy	29400.00
0005435846253	25102	Economy	29400.00
0005432649355	25102	Economy	29400.00
0005432649342	25102	Economy	29400.00
0005435844317	25102	Economy	29400.00
0005432632674	25102	Economy	29400.00
0005432632698	25102	Economy	29400.00
0005432632650	25102	Economy	29400.00
0005432632656	25102	Economy	29400.00
0005432632696	25102	Economy	29400.00
0005432632631	25102	Economy	29400.00
0005435846258	25102	Economy	29400.00
0005432632649	25102	Economy	29400.00
0005432649371	25102	Economy	29400.00
0005432632669	25102	Economy	29400.00
0005432632648	25102	Economy	29400.00
0005432632659	25102	Economy	29400.00
0005435844320	25102	Economy	29400.00
0005432632668	25102	Economy	29400.00
0005435844323	25102	Economy	29400.00
0005432632663	25102	Economy	29400.00
0005435844318	25102	Economy	29400.00
0005432649348	25102	Economy	29400.00
0005432649350	25102	Economy	29400.00
0005432649368	25102	Economy	29400.00
0005432632662	25102	Economy	29400.00
0005435846251	25102	Economy	29400.00
0005432632665	25102	Economy	29400.00
0005435846257	25102	Economy	29400.00
0005432632655	25102	Economy	29400.00
0005432632634	25102	Economy	29400.00
0005432632673	25102	Economy	29400.00
0005432632695	25102	Economy	29400.00
0005435846261	25102	Economy	29400.00
0005435846252	25102	Economy	29400.00
0005435844325	25102	Economy	29400.00
0005435844316	25102	Economy	29400.00
0005432632644	25102	Economy	29400.00
0005432649358	25102	Economy	29400.00
0005432632670	25102	Economy	29400.00
0005432649357	25102	Economy	29400.00
0005432632620	25102	Economy	29400.00
0005432649393	25102	Economy	29400.00
0005435844321	25102	Economy	29400.00
0005432632647	25102	Economy	29400.00
0005432632633	25102	Economy	29400.00
0005432632651	25102	Economy	29400.00
0005435846260	25102	Economy	29400.00
0005435846256	25102	Economy	29400.00
0005432632635	25102	Economy	29400.00
0005432632658	25102	Economy	29400.00
0005432649347	25102	Economy	29400.00
0005432632676	25102	Economy	29400.00
0005432295886	1845	Business	48700.00
0005433008306	1845	Business	48700.00
0005433285192	1845	Business	48700.00
0005433008321	1845	Business	48700.00
0005433285133	1845	Business	48700.00
0005433008238	1845	Business	48700.00
0005433810560	1845	Business	48700.00
0005433008155	1845	Business	48700.00
0005433810557	1845	Business	48700.00
0005433008176	1845	Business	48700.00
0005433285023	1845	Economy	16200.00
0005433008532	1845	Economy	16200.00
0005432295883	1845	Economy	16200.00
0005433285019	1845	Economy	16200.00
0005433810565	1845	Economy	16200.00
0005433008297	1845	Economy	16200.00
0005433285203	1845	Economy	16200.00
0005433008112	1845	Economy	16200.00
0005433008479	1845	Economy	17900.00
0005433008381	1845	Economy	17900.00
0005433285067	1845	Economy	17900.00
0005433810562	1845	Economy	17900.00
0005433008380	1845	Economy	17900.00
0005433008336	1845	Economy	16200.00
0005433285231	1845	Economy	16200.00
0005433285145	1845	Economy	16200.00
0005433008245	1845	Economy	16200.00
0005433008291	1845	Economy	16200.00
0005433008299	1845	Economy	16200.00
0005433285083	1845	Economy	16200.00
0005433284997	1845	Economy	16200.00
0005433285122	1845	Economy	16200.00
0005433008335	1845	Economy	16200.00
0005433285092	1845	Economy	16200.00
0005433285132	1845	Economy	16200.00
0005433285131	1845	Economy	16200.00
0005433285241	1845	Economy	16200.00
0005433008246	1845	Economy	16200.00
0005433008247	1845	Economy	16200.00
0005433285093	1845	Economy	16200.00
0005433285216	1845	Economy	16200.00
0005433008382	1845	Economy	16200.00
0005433008284	1845	Economy	16200.00
0005433008373	1845	Economy	16200.00
0005433810556	1845	Economy	16200.00
0005433008353	1845	Economy	16200.00
0005433810558	1845	Economy	16200.00
0005433008311	1845	Economy	16200.00
0005433008296	1845	Economy	16200.00
0005433285068	1845	Economy	16200.00
0005433810561	1845	Economy	16200.00
0005433284980	1845	Economy	16200.00
0005433285070	1845	Economy	16200.00
0005433285225	1845	Economy	16200.00
0005432295885	1845	Economy	16200.00
0005433008374	1845	Economy	16200.00
0005433008360	1845	Economy	16200.00
0005433285147	1845	Economy	16200.00
0005433285085	1845	Economy	16200.00
0005433285226	1845	Economy	16200.00
0005433008295	1845	Economy	16200.00
0005433285156	1845	Economy	16200.00
0005433008290	1845	Economy	16200.00
0005433285082	1845	Economy	16200.00
0005433810563	1845	Economy	16200.00
0005433008526	1845	Economy	16200.00
0005433285106	1845	Economy	16200.00
0005433285230	1845	Economy	16200.00
0005433285297	1845	Economy	16200.00
0005433008405	1845	Economy	16200.00
0005433285020	1845	Economy	16200.00
0005433008288	1845	Economy	16200.00
0005433008315	1845	Economy	16200.00
0005433284998	1845	Economy	16200.00
0005433008283	1845	Economy	16200.00
0005433810555	1845	Economy	16200.00
0005433810564	1845	Economy	16200.00
0005433008298	1845	Economy	16200.00
0005432295884	1845	Economy	16200.00
0005433008289	1845	Economy	16200.00
0005433285202	1845	Economy	16200.00
0005433810559	1845	Economy	16200.00
0005433008461	1845	Economy	16200.00
0005433008310	1845	Economy	16200.00
0005433285358	22530	Business	48700.00
0005433008695	22530	Business	48700.00
0005433008677	22530	Business	48700.00
0005433285353	22530	Business	48700.00
0005433008687	22530	Business	48700.00
0005433008662	22530	Business	48700.00
0005433285349	22530	Business	48700.00
0005433285346	22530	Business	48700.00
0005433008669	22530	Business	48700.00
0005433285333	22530	Business	48700.00
0005433008673	22530	Economy	16200.00
0005433008665	22530	Economy	16200.00
0005433008688	22530	Economy	16200.00
0005433008667	22530	Economy	16200.00
0005433008702	22530	Economy	16200.00
0005433008698	22530	Economy	16200.00
0005433008663	22530	Economy	17900.00
0005433008689	22530	Economy	17900.00
0005433008686	22530	Economy	17900.00
0005433008701	22530	Economy	17900.00
0005433285328	22530	Economy	17900.00
0005433810506	22530	Economy	16200.00
0005433285356	22530	Economy	16200.00
0005433008657	22530	Economy	16200.00
0005433008699	22530	Economy	16200.00
0005433285331	22530	Economy	16200.00
0005433285341	22530	Economy	16200.00
0005433008664	22530	Economy	16200.00
0005433285354	22530	Economy	16200.00
0005433285350	22530	Economy	16200.00
0005433285336	22530	Economy	16200.00
0005433285357	22530	Economy	16200.00
0005433008675	22530	Economy	16200.00
0005433008678	22530	Economy	16200.00
0005433008690	22530	Economy	16200.00
0005433008672	22530	Economy	16200.00
0005433285343	22530	Economy	16200.00
0005433008685	22530	Economy	16200.00
0005433285334	22530	Economy	16200.00
0005433008658	22530	Economy	16200.00
0005433008697	22530	Economy	16200.00
0005433285332	22530	Economy	16200.00
0005433008666	22530	Economy	16200.00
0005433008684	22530	Economy	16200.00
0005433285337	22530	Economy	16200.00
0005433285340	22530	Economy	16200.00
0005433008680	22530	Economy	16200.00
0005433008661	22530	Economy	16200.00
0005433285355	22530	Economy	16200.00
0005433285330	22530	Economy	16200.00
0005433008671	22530	Economy	16200.00
0005433008668	22530	Economy	16200.00
0005433285327	22530	Economy	16200.00
0005433285347	22530	Economy	16200.00
0005433008693	22530	Economy	16200.00
0005433008659	22530	Economy	16200.00
0005433008692	22530	Economy	16200.00
0005433285329	22530	Economy	16200.00
0005433285348	22530	Economy	16200.00
0005433008694	22530	Economy	16200.00
0005433008682	22530	Economy	16200.00
0005433008670	22530	Economy	16200.00
0005433008681	22530	Economy	16200.00
0005433285342	22530	Economy	16200.00
0005433008696	22530	Economy	16200.00
0005433285344	22530	Economy	16200.00
0005433285338	22530	Economy	16200.00
0005433008674	22530	Economy	16200.00
0005433008683	22530	Economy	16200.00
0005433008691	22530	Economy	16200.00
0005433285335	22530	Economy	16200.00
0005433285352	22530	Economy	16200.00
0005433285345	22530	Economy	16200.00
0005433008676	22530	Economy	16200.00
0005433285339	22530	Economy	16200.00
0005433285351	22530	Economy	16200.00
0005433008679	22530	Economy	16200.00
0005433008700	22530	Economy	16200.00
0005433008660	22530	Economy	16200.00
0005435282248	5593	Business	99800.00
0005434173477	5593	Business	99800.00
0005433846847	5593	Business	99800.00
0005433846828	5593	Business	99800.00
0005435282414	5593	Business	99800.00
0005432081524	5593	Business	99800.00
0005435282425	5593	Business	99800.00
0005433815393	5593	Business	99800.00
0005435282298	5593	Business	99800.00
0005433846820	5593	Business	99800.00
0005432081526	5593	Business	99800.00
0005433846834	5593	Business	99800.00
0005433815394	5593	Business	99800.00
0005433846846	5593	Business	99800.00
0005433846849	5593	Business	99800.00
0005433846821	5593	Business	99800.00
0005433846813	5593	Business	99800.00
0005433846857	5593	Economy	33300.00
0005432081522	5593	Economy	33300.00
0005433846826	5593	Economy	33300.00
0005433846841	5593	Economy	33300.00
0005433846848	5593	Economy	33300.00
0005433846837	5593	Economy	33300.00
0005435282257	5593	Economy	33300.00
0005433846801	5593	Economy	33300.00
0005433846803	5593	Economy	33300.00
0005433846835	5593	Economy	33300.00
0005433846827	5593	Economy	33300.00
0005435282430	5593	Economy	33300.00
0005433846855	5593	Economy	33300.00
0005433846830	5593	Economy	36600.00
0005435282284	5593	Economy	36600.00
0005433846858	5593	Economy	36600.00
0005434173485	5593	Economy	33300.00
0005433815395	5593	Economy	36600.00
0005435282242	5593	Economy	33300.00
0005432081523	5593	Economy	33300.00
0005433846817	5593	Economy	33300.00
0005433846851	5593	Economy	33300.00
0005433846810	5593	Economy	33300.00
0005435282392	5593	Economy	33300.00
0005433846829	5593	Economy	33300.00
0005435282308	5593	Economy	33300.00
0005433846804	5593	Economy	33300.00
0005435282312	5593	Economy	33300.00
0005435282313	5593	Economy	33300.00
0005433846811	5593	Economy	33300.00
0005435282357	5593	Economy	33300.00
0005433846853	5593	Economy	33300.00
0005435282427	5593	Economy	33300.00
0005433815390	5593	Economy	33300.00
0005433846807	5593	Economy	33300.00
0005433846815	5593	Economy	33300.00
0005435282348	5593	Economy	33300.00
0005433846838	5593	Economy	33300.00
0005432081519	5593	Economy	33300.00
0005433815389	5593	Economy	33300.00
0005434173476	5593	Economy	33300.00
0005433846854	5593	Economy	33300.00
0005433846845	5593	Economy	33300.00
0005433846816	5593	Economy	33300.00
0005433846814	5593	Economy	33300.00
0005435282424	5593	Economy	33300.00
0005432081521	5593	Economy	33300.00
0005433846832	5593	Economy	33300.00
0005433846852	5593	Economy	33300.00
0005433846800	5593	Economy	33300.00
0005433846805	5593	Economy	33300.00
0005433846806	5593	Economy	33300.00
0005433846825	5593	Economy	33300.00
0005433846822	5593	Economy	33300.00
0005433846819	5593	Economy	33300.00
0005435282328	5593	Economy	33300.00
0005433846831	5593	Economy	33300.00
0005433846836	5593	Economy	33300.00
0005433846823	5593	Economy	33300.00
0005432081520	5593	Economy	33300.00
0005435282391	5593	Economy	33300.00
0005433846842	5593	Economy	33300.00
0005433846812	5593	Economy	33300.00
0005435282307	5593	Economy	33300.00
0005433846839	5593	Economy	33300.00
0005435282351	5593	Economy	33300.00
0005435282228	5593	Economy	33300.00
0005435282255	5593	Economy	33300.00
0005435282327	5593	Economy	33300.00
0005433846802	5593	Economy	33300.00
0005433846824	5593	Economy	33300.00
0005433846833	5593	Economy	33300.00
0005433815392	5593	Economy	33300.00
0005433846818	5593	Economy	33300.00
0005435282256	5593	Economy	33300.00
0005433846843	5593	Economy	33300.00
0005432081525	5593	Economy	33300.00
0005435282413	5593	Economy	33300.00
0005433815391	5593	Economy	33300.00
0005433846808	5593	Economy	33300.00
0005433846850	5593	Economy	33300.00
0005435282426	5593	Economy	33300.00
0005433846844	5593	Economy	33300.00
0005433846809	5593	Economy	33300.00
0005435282258	5593	Economy	33300.00
0005433846840	5593	Economy	33300.00
0005433846856	5593	Economy	33300.00
0005433846171	13862	Business	99800.00
0005435282553	13862	Business	99800.00
0005433846358	13862	Business	99800.00
0005433846282	13862	Business	99800.00
0005433846373	13862	Business	99800.00
0005435282562	13862	Business	99800.00
0005433846286	13862	Business	99800.00
0005433846605	13862	Business	99800.00
0005433846398	13862	Business	99800.00
0005433815363	13862	Business	99800.00
0005433846160	13862	Business	99800.00
0005433815351	13862	Business	99800.00
0005435282552	13862	Business	99800.00
0005433846339	13862	Business	99800.00
0005433846535	13862	Business	99800.00
0005433846520	13862	Business	99800.00
0005433846280	13862	Business	99800.00
0005433846175	13862	Business	99800.00
0005432003708	13862	Business	99800.00
0005433846284	13862	Business	99800.00
0005435282560	13862	Economy	33300.00
0005433846338	13862	Economy	33300.00
0005433846591	13862	Economy	33300.00
0005433846253	13862	Economy	33300.00
0005433846427	13862	Economy	33300.00
0005433846281	13862	Economy	33300.00
0005433846383	13862	Economy	33300.00
0005435282547	13862	Economy	33300.00
0005433846547	13862	Economy	33300.00
0005433846321	13862	Economy	33300.00
0005433846384	13862	Economy	33300.00
0005435282563	13862	Economy	33300.00
0005435282558	13862	Economy	36600.00
0005435282557	13862	Economy	36600.00
0005433846378	13862	Economy	36600.00
0005433846327	13862	Economy	33300.00
0005433846070	13862	Economy	33300.00
0005432003706	13862	Economy	33300.00
0005434173529	13862	Economy	33300.00
0005433815340	13862	Economy	33300.00
0005433846456	13862	Economy	33300.00
0005433846294	13862	Economy	33300.00
0005435282556	13862	Economy	33300.00
0005433846399	13862	Economy	33300.00
0005433846390	13862	Economy	33300.00
0005433846546	13862	Economy	33300.00
0005433846275	13862	Economy	33300.00
0005433846266	13862	Economy	33300.00
0005432003707	13862	Economy	33300.00
0005433846389	13862	Economy	33300.00
0005433815341	13862	Economy	33300.00
0005435282550	13862	Economy	33300.00
0005435282545	13862	Economy	33300.00
0005434173526	13862	Economy	33300.00
0005433846453	13862	Economy	33300.00
0005433846519	13862	Economy	33300.00
0005433846274	13862	Economy	33300.00
0005433845970	13862	Economy	33300.00
0005433846224	13862	Economy	33300.00
0005433815366	13862	Economy	33300.00
0005433815362	13862	Economy	33300.00
0005433846478	13862	Economy	33300.00
0005433846479	13862	Economy	33300.00
0005433846174	13862	Economy	33300.00
0005434173530	13862	Economy	33300.00
0005433846249	13862	Economy	33300.00
0005435282549	13862	Economy	33300.00
0005433846330	13862	Economy	33300.00
0005434173528	13862	Economy	33300.00
0005433846276	13862	Economy	33300.00
0005435282548	13862	Economy	33300.00
0005435282561	13862	Economy	33300.00
0005433846416	13862	Economy	33300.00
0005434173527	13862	Economy	33300.00
0005433846169	13862	Economy	33300.00
0005433846379	13862	Economy	33300.00
0005435282544	13862	Economy	33300.00
0005433846636	13862	Economy	33300.00
0005433846454	13862	Economy	33300.00
0005435282559	13862	Economy	33300.00
0005433846289	13862	Economy	33300.00
0005433846388	13862	Economy	33300.00
0005433846254	13862	Economy	33300.00
0005433846366	13862	Economy	33300.00
0005433846455	13862	Economy	33300.00
0005433846374	13862	Economy	33300.00
0005433846434	13862	Economy	33300.00
0005433846248	13862	Economy	33300.00
0005435282546	13862	Economy	33300.00
0005433846221	13862	Economy	33300.00
0005433846252	13862	Economy	33300.00
0005435282554	13862	Economy	33300.00
0005433846211	13862	Economy	33300.00
0005433846212	13862	Economy	33300.00
0005433846548	13862	Economy	33300.00
0005433846355	13862	Economy	33300.00
0005433846283	13862	Economy	33300.00
0005433846426	13862	Economy	33300.00
0005433846291	13862	Economy	33300.00
0005433846259	13862	Economy	33300.00
0005435282555	13862	Economy	33300.00
0005433846290	13862	Economy	33300.00
0005435282551	13862	Economy	33300.00
0005434620638	7813	Economy	16600.00
0005435332267	7813	Economy	16600.00
0005434620623	7813	Economy	16600.00
0005434620627	7813	Economy	15100.00
0005435332239	7813	Economy	15100.00
0005434620628	7813	Economy	15100.00
0005432112520	7813	Economy	15100.00
0005435332319	7813	Economy	15100.00
0005434620637	7813	Economy	15100.00
0005434620641	7813	Economy	15100.00
0005435332266	7813	Economy	15100.00
0005435332304	7813	Economy	15100.00
0005434620634	7813	Economy	15100.00
0005434620635	7813	Economy	15100.00
0005434620626	7813	Economy	15100.00
0005434620630	7813	Economy	15100.00
0005435332262	7813	Economy	15100.00
0005435332247	7813	Economy	15100.00
0005435332303	7813	Economy	15100.00
0005434620640	7813	Economy	15100.00
0005435332263	7813	Economy	15100.00
0005435332246	7813	Economy	15100.00
0005434620631	7813	Economy	15100.00
0005434620639	7813	Economy	15100.00
0005434620632	7813	Economy	15100.00
0005435332318	7813	Economy	15100.00
0005434620642	7813	Economy	15100.00
0005434620636	7813	Economy	15100.00
0005434620624	7813	Economy	15100.00
0005434620629	7813	Economy	15100.00
0005434620625	7813	Economy	15100.00
0005434620622	7813	Economy	15100.00
0005434620633	7813	Economy	15100.00
0005435332238	7813	Economy	15100.00
0005434620499	32960	Economy	16600.00
0005435332352	32960	Economy	15100.00
0005435332355	32960	Economy	15100.00
0005434620446	32960	Economy	15100.00
0005434620431	32960	Economy	15100.00
0005435332353	32960	Economy	15100.00
0005435332354	32960	Economy	15100.00
0005434620509	32960	Economy	15100.00
0005435332358	32960	Economy	15100.00
0005435332350	32960	Economy	15100.00
0005434620423	32960	Economy	15100.00
0005434620422	32960	Economy	15100.00
0005434620476	32960	Economy	15100.00
0005434620459	32960	Economy	15100.00
0005434620428	32960	Economy	15100.00
0005434620390	32960	Economy	15100.00
0005434620437	32960	Economy	15100.00
0005435332349	32960	Economy	15100.00
0005434620432	32960	Economy	15100.00
0005434620439	32960	Economy	15100.00
0005435332351	32960	Economy	15100.00
0005434620516	32960	Economy	15100.00
0005435332348	32960	Economy	15100.00
0005434620447	32960	Economy	15100.00
0005435332356	32960	Economy	15100.00
0005435332357	32960	Economy	15100.00
0005434620473	32960	Economy	15100.00
0005434994038	4268	Business	38000.00
0005435785425	4268	Business	38000.00
0005432190636	4268	Business	38000.00
0005434994043	4268	Business	38000.00
0005435785435	4268	Business	38000.00
0005435785410	4268	Business	38000.00
0005435937341	4268	Business	38000.00
0005435785429	4268	Economy	12700.00
0005435785423	4268	Economy	12700.00
0005432190638	4268	Economy	12700.00
0005435785415	4268	Economy	12700.00
0005435785418	4268	Economy	13900.00
0005435785403	4268	Economy	13900.00
0005435785414	4268	Economy	13900.00
0005432190637	4268	Economy	13900.00
0005435785428	4268	Economy	13900.00
0005435918623	4268	Economy	12700.00
0005435785406	4268	Economy	12700.00
0005435785424	4268	Economy	12700.00
0005435937336	4268	Economy	12700.00
0005435785431	4268	Economy	12700.00
0005435937335	4268	Economy	12700.00
0005435918636	4268	Economy	12700.00
0005435785430	4268	Economy	12700.00
0005432190635	4268	Economy	12700.00
0005435785432	4268	Economy	12700.00
0005435785421	4268	Economy	12700.00
0005434994042	4268	Economy	12700.00
0005435937334	4268	Economy	12700.00
0005435785407	4268	Economy	12700.00
0005435785417	4268	Economy	12700.00
0005435785416	4268	Economy	12700.00
0005435785409	4268	Economy	12700.00
0005435785402	4268	Economy	12700.00
0005434994044	4268	Economy	12700.00
0005434994037	4268	Economy	12700.00
0005434994039	4268	Economy	12700.00
0005435937339	4268	Economy	12700.00
0005435785420	4268	Economy	12700.00
0005435785427	4268	Economy	12700.00
0005435937340	4268	Economy	12700.00
0005435785405	4268	Economy	12700.00
0005435785411	4268	Economy	12700.00
0005435785412	4268	Economy	12700.00
0005435785408	4268	Economy	12700.00
0005434994041	4268	Economy	12700.00
0005435785426	4268	Economy	12700.00
0005435937338	4268	Economy	12700.00
0005435918633	4268	Economy	12700.00
0005435785422	4268	Economy	12700.00
0005435785413	4268	Economy	12700.00
0005435785434	4268	Economy	12700.00
0005434994040	4268	Economy	12700.00
0005435787357	4268	Economy	12700.00
0005435785419	4268	Economy	12700.00
0005435918637	4268	Economy	12700.00
0005435785433	4268	Economy	12700.00
0005435787359	4268	Economy	12700.00
0005435787358	4268	Economy	12700.00
0005435918611	4268	Economy	12700.00
0005435785436	4268	Economy	12700.00
0005435785404	4268	Economy	12700.00
0005435785051	27295	Business	38000.00
0005435784970	27295	Business	38000.00
0005435785050	27295	Business	38000.00
0005435787328	27295	Business	38000.00
0005435785056	27295	Business	38000.00
0005435787346	27295	Business	38000.00
0005435784986	27295	Business	38000.00
0005435784952	27295	Business	38000.00
0005435918667	27295	Business	38000.00
0005434993937	27295	Economy	12700.00
0005434993938	27295	Economy	12700.00
0005435785171	27295	Economy	12700.00
0005435784997	27295	Economy	13900.00
0005435785052	27295	Economy	13900.00
0005435784944	27295	Economy	12700.00
0005435785101	27295	Economy	12700.00
0005435785129	27295	Economy	12700.00
0005435785172	27295	Economy	12700.00
0005435785114	27295	Economy	12700.00
0005434993935	27295	Economy	12700.00
0005435785127	27295	Economy	12700.00
0005434993927	27295	Economy	12700.00
0005434993956	27295	Economy	12700.00
0005435785092	27295	Economy	12700.00
0005435784943	27295	Economy	12700.00
0005435785049	27295	Economy	12700.00
0005435785135	27295	Economy	12700.00
0005434993955	27295	Economy	12700.00
0005435918662	27295	Economy	12700.00
0005435785046	27295	Economy	12700.00
0005435785047	27295	Economy	12700.00
0005435785112	27295	Economy	12700.00
0005435785089	27295	Economy	12700.00
0005435785170	27295	Economy	12700.00
0005432195696	27295	Economy	12700.00
0005435784984	27295	Economy	12700.00
0005435918666	27295	Economy	12700.00
0005435785057	27295	Economy	12700.00
0005435785062	27295	Economy	12700.00
0005434993939	27295	Economy	12700.00
0005435784945	27295	Economy	12700.00
0005435937390	27295	Economy	12700.00
0005435785169	27295	Economy	12700.00
0005434993923	27295	Economy	12700.00
0005435785035	27295	Economy	12700.00
0005435784951	27295	Economy	12700.00
0005435918665	27295	Economy	12700.00
0005435785128	27295	Economy	12700.00
0005435918664	27295	Economy	12700.00
0005435785055	27295	Economy	12700.00
0005435918663	27295	Economy	12700.00
0005435785045	27295	Economy	12700.00
0005435785034	27295	Economy	12700.00
0005434993921	27295	Economy	12700.00
0005435785091	27295	Economy	12700.00
0005435785173	27295	Economy	12700.00
0005432146202	19848	Economy	12800.00
0005432146201	19848	Economy	12800.00
0005432459958	4706	Business	40900.00
0005432170397	4706	Business	40900.00
0005433726108	4706	Business	40900.00
0005432186880	4706	Business	40900.00
0005432186875	4706	Business	40900.00
0005434081938	4706	Business	40900.00
0005432459936	4706	Business	40900.00
0005434081948	4706	Business	40900.00
0005433726110	4706	Business	40900.00
0005432459941	4706	Business	40900.00
0005432571327	4706	Business	40900.00
0005432571329	4706	Business	40900.00
0005434081933	4706	Business	40900.00
0005432170398	4706	Business	40900.00
0005432186878	4706	Business	40900.00
0005432459948	4706	Business	40900.00
0005434081930	4706	Business	40900.00
0005432567719	4706	Business	40900.00
0005432571328	4706	Business	40900.00
0005432459943	4706	Business	40900.00
0005432459956	4706	Business	40900.00
0005434081944	4706	Business	40900.00
0005432567756	4706	Economy	15000.00
0005432170403	4706	Economy	15000.00
0005432567737	4706	Economy	15000.00
0005432459934	4706	Economy	15000.00
0005432567772	4706	Economy	13600.00
0005434081940	4706	Economy	13600.00
0005432567742	4706	Economy	13600.00
0005432567739	4706	Economy	13600.00
0005432567769	4706	Economy	13600.00
0005434081934	4706	Economy	13600.00
0005432459955	4706	Economy	13600.00
0005432567718	4706	Economy	13600.00
0005432459945	4706	Economy	13600.00
0005432459949	4706	Economy	13600.00
0005432567746	4706	Economy	13600.00
0005432567732	4706	Economy	13600.00
0005432567734	4706	Economy	13600.00
0005432567754	4706	Economy	13600.00
0005432567726	4706	Economy	13600.00
0005432459938	4706	Economy	13600.00
0005432567749	4706	Economy	13600.00
0005432567728	4706	Economy	13600.00
0005432459962	4706	Economy	13600.00
0005434081937	4706	Economy	13600.00
0005432567757	4706	Economy	13600.00
0005432567745	4706	Economy	13600.00
0005433726109	4706	Economy	13600.00
0005432459932	4706	Economy	13600.00
0005432567720	4706	Economy	13600.00
0005432567714	4706	Economy	13600.00
0005432459924	4706	Economy	13600.00
0005432567760	4706	Economy	13600.00
0005432567753	4706	Economy	13600.00
0005433452743	4706	Economy	13600.00
0005432567730	4706	Economy	13600.00
0005432459953	4706	Economy	13600.00
0005432459929	4706	Economy	13600.00
0005432459933	4706	Economy	13600.00
0005432567771	4706	Economy	13600.00
0005432567733	4706	Economy	13600.00
0005432567765	4706	Economy	13600.00
0005432459942	4706	Economy	13600.00
0005432567740	4706	Economy	13600.00
0005432459966	4706	Economy	13600.00
0005432459970	4706	Economy	13600.00
0005432567764	4706	Economy	13600.00
0005432567741	4706	Economy	13600.00
0005432567715	4706	Economy	13600.00
0005432170401	4706	Economy	13600.00
0005432567761	4706	Economy	13600.00
0005432459965	4706	Economy	13600.00
0005432567736	4706	Economy	13600.00
0005432567723	4706	Economy	13600.00
0005432459947	4706	Economy	13600.00
0005432567747	4706	Economy	13600.00
0005432567766	4706	Economy	13600.00
0005432567727	4706	Economy	13600.00
0005434081943	4706	Economy	13600.00
0005432567763	4706	Economy	13600.00
0005432186879	4706	Economy	13600.00
0005432186876	4706	Economy	13600.00
0005432459954	4706	Economy	13600.00
0005434081935	4706	Economy	13600.00
0005432567716	4706	Economy	13600.00
0005432459940	4706	Economy	13600.00
0005432459921	4706	Economy	13600.00
0005432459951	4706	Economy	13600.00
0005432567748	4706	Economy	13600.00
0005432459967	4706	Economy	13600.00
0005432459928	4706	Economy	13600.00
0005432459946	4706	Economy	13600.00
0005434081942	4706	Economy	13600.00
0005434081931	4706	Economy	13600.00
0005432459925	4706	Economy	13600.00
0005432459944	4706	Economy	13600.00
0005432567755	4706	Economy	13600.00
0005432459918	4706	Economy	13600.00
0005432567752	4706	Economy	13600.00
0005432459957	4706	Economy	13600.00
0005432459963	4706	Economy	13600.00
0005432567767	4706	Economy	13600.00
0005432459969	4706	Economy	13600.00
0005432170402	4706	Economy	15000.00
0005432567724	4706	Economy	15000.00
0005432459952	4706	Economy	13600.00
0005432459927	4706	Economy	13600.00
0005434081952	4706	Economy	13600.00
0005432459919	4706	Economy	15000.00
0005432567738	4706	Economy	13600.00
0005432459926	4706	Economy	13600.00
0005432567725	4706	Economy	13600.00
0005432170399	4706	Economy	13600.00
0005432567759	4706	Economy	13600.00
0005432459960	4706	Economy	13600.00
0005432567758	4706	Economy	13600.00
0005432567729	4706	Economy	13600.00
0005433451622	4706	Economy	13600.00
0005432459922	4706	Economy	13600.00
0005432170400	4706	Economy	13600.00
0005434081929	4706	Economy	13600.00
0005432567744	4706	Economy	13600.00
0005432459939	4706	Economy	13600.00
0005432459959	4706	Economy	13600.00
0005433452744	4706	Economy	13600.00
0005432459968	4706	Economy	13600.00
0005433451623	4706	Economy	13600.00
0005432459920	4706	Economy	13600.00
0005432567775	4706	Economy	13600.00
0005432567721	4706	Economy	13600.00
0005432567735	4706	Economy	13600.00
0005432459923	4706	Economy	13600.00
0005434081947	4706	Economy	13600.00
0005434081949	4706	Economy	13600.00
0005432459935	4706	Economy	13600.00
0005432459937	4706	Economy	13600.00
0005434081939	4706	Economy	13600.00
0005432571330	4706	Economy	13600.00
0005432567768	4706	Economy	13600.00
0005432567762	4706	Economy	13600.00
0005432459961	4706	Economy	13600.00
0005432567774	4706	Economy	13600.00
0005434081945	4706	Economy	13600.00
0005432567743	4706	Economy	13600.00
0005432567773	4706	Economy	13600.00
0005432459950	4706	Economy	13600.00
0005432567717	4706	Economy	13600.00
0005434081951	4706	Economy	13600.00
0005434081936	4706	Economy	13600.00
0005432567770	4706	Economy	13600.00
0005432567731	4706	Economy	13600.00
0005432459971	4706	Economy	13600.00
0005434081953	4706	Economy	13600.00
0005432459964	4706	Economy	13600.00
0005432186877	4706	Economy	13600.00
0005432567751	4706	Economy	13600.00
0005434081941	4706	Economy	13600.00
0005432567750	4706	Economy	13600.00
0005432567776	4706	Economy	13600.00
0005432459931	4706	Economy	13600.00
0005434081932	4706	Economy	13600.00
0005432459930	4706	Economy	13600.00
0005433726107	4706	Economy	13600.00
0005434081950	4706	Economy	13600.00
0005434081946	4706	Economy	13600.00
0005432567722	4706	Economy	13600.00
0005432459540	30516	Business	40900.00
0005434081797	30516	Business	40900.00
0005432567399	30516	Business	40900.00
0005432459508	30516	Business	40900.00
0005432459582	30516	Business	40900.00
0005434081692	30516	Business	40900.00
0005432459554	30516	Business	40900.00
0005432567341	30516	Business	40900.00
0005432567376	30516	Business	40900.00
0005432459800	30516	Business	40900.00
0005432567195	30516	Business	40900.00
0005432459757	30516	Business	40900.00
0005432567439	30516	Business	40900.00
0005432459646	30516	Business	40900.00
0005432567279	30516	Business	40900.00
0005434081690	30516	Business	40900.00
0005433452717	30516	Business	40900.00
0005434081710	30516	Business	40900.00
0005434081727	30516	Business	40900.00
0005432567475	30516	Business	40900.00
0005432459662	30516	Business	40900.00
0005432567182	30516	Business	40900.00
0005432567251	30516	Business	40900.00
0005432459692	30516	Business	40900.00
0005432567296	30516	Business	40900.00
0005432567361	30516	Economy	15000.00
0005432567062	30516	Economy	15000.00
0005433452718	30516	Economy	15000.00
0005432459406	30516	Economy	13600.00
0005432567068	30516	Economy	13600.00
0005432459475	30516	Economy	13600.00
0005432161156	30516	Economy	13600.00
0005433452722	30516	Economy	13600.00
0005432567292	30516	Economy	13600.00
0005432213614	30516	Economy	13600.00
0005433454865	30516	Economy	13600.00
0005434081789	30516	Economy	13600.00
0005432459632	30516	Economy	13600.00
0005432567515	30516	Economy	13600.00
0005432567380	30516	Economy	13600.00
0005432567135	30516	Economy	13600.00
0005434081717	30516	Economy	13600.00
0005432567181	30516	Economy	13600.00
0005432567451	30516	Economy	13600.00
0005432459479	30516	Economy	13600.00
0005432567520	30516	Economy	13600.00
0005432567408	30516	Economy	13600.00
0005432459521	30516	Economy	13600.00
0005432459631	30516	Economy	13600.00
0005434081606	30516	Economy	13600.00
0005432459463	30516	Economy	13600.00
0005432567127	30516	Economy	13600.00
0005432567455	30516	Economy	13600.00
0005432459664	30516	Economy	13600.00
0005432567200	30516	Economy	13600.00
0005432459659	30516	Economy	13600.00
0005434081729	30516	Economy	13600.00
0005432567398	30516	Economy	13600.00
0005432567274	30516	Economy	13600.00
0005432567065	30516	Economy	13600.00
0005432459345	30516	Economy	13600.00
0005432567365	30516	Economy	13600.00
0005432567227	30516	Economy	13600.00
0005432459429	30516	Economy	13600.00
0005432459627	30516	Economy	13600.00
0005432567278	30516	Economy	13600.00
0005432459563	30516	Economy	13600.00
0005432459630	30516	Economy	13600.00
0005432459599	30516	Economy	13600.00
0005432567456	30516	Economy	13600.00
0005434081788	30516	Economy	13600.00
0005432567375	30516	Economy	13600.00
0005432459530	30516	Economy	13600.00
0005432161155	30516	Economy	13600.00
0005432567136	30516	Economy	13600.00
0005432459801	30516	Economy	13600.00
0005432567521	30516	Economy	13600.00
0005432567063	30516	Economy	13600.00
0005432459464	30516	Economy	13600.00
0005432459539	30516	Economy	13600.00
0005432567291	30516	Economy	13600.00
0005432567294	30516	Economy	13600.00
0005432459581	30516	Economy	13600.00
0005432459562	30516	Economy	13600.00
0005432213613	30516	Economy	13600.00
0005434081693	30516	Economy	13600.00
0005434081711	30516	Economy	13600.00
0005432459370	30516	Economy	13600.00
0005432567400	30516	Economy	13600.00
0005432567550	30516	Economy	13600.00
0005432567090	30516	Economy	13600.00
0005432567290	30516	Economy	13600.00
0005432459663	30516	Economy	13600.00
0005432459558	30516	Economy	13600.00
0005432567360	30516	Economy	13600.00
0005433454861	30516	Economy	13600.00
0005432459522	30516	Economy	13600.00
0005432567450	30516	Economy	13600.00
0005432459177	30516	Economy	13600.00
0005434081784	30516	Economy	13600.00
0005434081607	30516	Economy	13600.00
0005432567480	30516	Economy	13600.00
0005432459468	30516	Economy	13600.00
0005432567114	30516	Economy	13600.00
0005432459565	30516	Economy	13600.00
0005434081714	30516	Economy	13600.00
0005434081730	30516	Economy	13600.00
0005432571303	30516	Economy	13600.00
0005432567066	30516	Economy	13600.00
0005432459509	30516	Economy	13600.00
0005432567211	30516	Economy	13600.00
0005432567340	30516	Economy	13600.00
0005432459529	30516	Economy	15000.00
0005432567280	30516	Economy	13600.00
0005432567551	30516	Economy	13600.00
0005434081637	30516	Economy	15000.00
0005432459600	30516	Economy	13600.00
0005432567582	30516	Economy	13600.00
0005432567383	30516	Economy	13600.00
0005432459753	30516	Economy	13600.00
0005432567146	30516	Economy	13600.00
0005432161157	30516	Economy	13600.00
0005432459511	30516	Economy	13600.00
0005432459593	30516	Economy	13600.00
0005432459536	30516	Economy	13600.00
0005432567210	30516	Economy	13600.00
0005432459474	30516	Economy	13600.00
0005434081702	30516	Economy	13600.00
0005432571304	30516	Economy	13600.00
0005434081726	30516	Economy	13600.00
0005432567559	30516	Economy	13600.00
0005432459595	30516	Economy	13600.00
0005432459505	30516	Economy	13600.00
0005432459510	30516	Economy	13600.00
0005433454866	30516	Economy	13600.00
0005432567191	30516	Economy	13600.00
0005434081676	30516	Economy	13600.00
0005434081677	30516	Economy	13600.00
0005434081778	30516	Economy	13600.00
0005432567112	30516	Economy	13600.00
0005432459535	30516	Economy	13600.00
0005433454862	30516	Economy	13600.00
0005432567221	30516	Economy	13600.00
0005432567199	30516	Economy	13600.00
0005434081735	30516	Economy	13600.00
0005432459526	30516	Economy	13600.00
0005432567287	30516	Economy	13600.00
0005432567415	30516	Economy	13600.00
0005432567212	30516	Economy	13600.00
0005432567192	30516	Economy	13600.00
0005432567288	30516	Economy	13600.00
0005434081790	30516	Economy	13600.00
0005433454860	30516	Economy	13600.00
0005434081605	30516	Economy	13600.00
0005432567377	30516	Economy	13600.00
0005432459695	30516	Economy	13600.00
0005432459693	30516	Economy	13600.00
0005432567183	30516	Economy	13600.00
0005432567067	30516	Economy	13600.00
0005432213612	30516	Economy	13600.00
0005434081783	30516	Economy	13600.00
0005434081748	30516	Economy	13600.00
0005432459694	30516	Economy	13600.00
0005432459601	30516	Economy	13600.00
0005432567442	30516	Economy	13600.00
0005432213611	30516	Economy	13600.00
0005432567275	30516	Economy	13600.00
0005432567522	30516	Economy	13600.00
0005432567440	30516	Economy	13600.00
0005432459564	30516	Economy	13600.00
0005432459502	30516	Economy	13600.00
0005432459197	30516	Economy	13600.00
0005434081715	30516	Economy	13600.00
0005432567508	30516	Economy	13600.00
0005432459724	30516	Economy	13600.00
0005432459336	30516	Economy	13600.00
0005432567108	30516	Economy	13600.00
0005434081742	30516	Economy	13600.00
0005432567205	30516	Economy	13600.00
0005435722058	13590	Economy	9900.00
0005435722061	13590	Economy	9900.00
0005435722060	13590	Economy	9900.00
0005435722059	13590	Economy	9900.00
0005435720128	21173	Economy	9900.00
0005435722043	21173	Economy	9900.00
0005432295885	22764	Economy	8800.00
0005432295886	22764	Economy	8800.00
0005432295883	22764	Economy	8800.00
0005432295884	22764	Economy	8800.00
0005433343398	11074	Business	23600.00
0005435097211	11074	Business	23600.00
0005433343373	11074	Business	23600.00
0005433343409	11074	Business	23600.00
0005435380263	11074	Business	23600.00
0005433343344	11074	Business	23600.00
0005433343376	11074	Business	23600.00
0005433343328	11074	Business	23600.00
0005435508231	11074	Business	23600.00
0005433343366	11074	Business	23600.00
0005433343325	11074	Business	23600.00
0005433343351	11074	Economy	7900.00
0005435508226	11074	Economy	7900.00
0005433343326	11074	Economy	7900.00
0005433343385	11074	Economy	7900.00
0005433343381	11074	Economy	7900.00
0005435508245	11074	Economy	7900.00
0005433343377	11074	Economy	7900.00
0005433343355	11074	Economy	7900.00
0005433343404	11074	Economy	7900.00
0005433343321	11074	Economy	7900.00
0005433343342	11074	Economy	7900.00
0005435380260	11074	Economy	7900.00
0005433343413	11074	Economy	7900.00
0005433343395	11074	Economy	7900.00
0005433343335	11074	Economy	7900.00
0005433343374	11074	Economy	7900.00
0005433343320	11074	Economy	7900.00
0005433343369	11074	Economy	7900.00
0005433343388	11074	Economy	7900.00
0005433343363	11074	Economy	7900.00
0005433343330	11074	Economy	7900.00
0005433343358	11074	Economy	7900.00
0005433343356	11074	Economy	7900.00
0005433343329	11074	Economy	7900.00
0005433343407	11074	Economy	7900.00
0005433343396	11074	Economy	7900.00
0005433343384	11074	Economy	7900.00
0005433343352	11074	Economy	7900.00
0005435508267	11074	Economy	7900.00
0005433343337	11074	Economy	7900.00
0005433343323	11074	Economy	7900.00
0005433343347	11074	Economy	7900.00
0005433343317	11074	Economy	7900.00
0005433343410	11074	Economy	7900.00
0005433343391	11074	Economy	7900.00
0005433343380	11074	Economy	7900.00
0005433343353	11074	Economy	7900.00
0005433343375	11074	Economy	7900.00
0005433343345	11074	Economy	8600.00
0005433343399	11074	Economy	8600.00
0005433343318	11074	Economy	8600.00
0005435508233	11074	Economy	8600.00
0005435380267	11074	Economy	8600.00
0005433343367	11074	Economy	8600.00
0005433343370	11074	Economy	7900.00
0005435097212	11074	Economy	7900.00
0005433343362	11074	Economy	7900.00
0005433343400	11074	Economy	7900.00
0005433343378	11074	Economy	7900.00
0005433343333	11074	Economy	7900.00
0005433343364	11074	Economy	7900.00
0005433343338	11074	Economy	7900.00
0005435508251	11074	Economy	7900.00
0005433343402	11074	Economy	7900.00
0005433343357	11074	Economy	7900.00
0005435508232	11074	Economy	7900.00
0005433343343	11074	Economy	7900.00
0005433343393	11074	Economy	7900.00
0005433343394	11074	Economy	7900.00
0005433343327	11074	Economy	7900.00
0005433343411	11074	Economy	7900.00
0005433343365	11074	Economy	7900.00
0005433343397	11074	Economy	7900.00
0005433343406	11074	Economy	7900.00
0005433343316	11074	Economy	7900.00
0005433343334	11074	Economy	7900.00
0005433343386	11074	Economy	7900.00
0005433343360	11074	Economy	7900.00
0005433343319	11074	Economy	7900.00
0005433343324	11074	Economy	7900.00
0005433343315	11074	Economy	7900.00
0005433343331	11074	Economy	7900.00
0005435508244	11074	Economy	7900.00
0005433343371	11074	Economy	7900.00
0005433343361	11074	Economy	7900.00
0005433343405	11074	Economy	7900.00
0005433343390	11074	Economy	7900.00
0005435097209	11074	Economy	7900.00
0005433343383	11074	Economy	7900.00
0005433343336	11074	Economy	7900.00
0005433343403	11074	Economy	7900.00
0005435097210	11074	Economy	7900.00
0005433343341	11074	Economy	7900.00
0005435097208	11074	Economy	7900.00
0005433343379	11074	Economy	7900.00
0005433343348	11074	Economy	7900.00
0005433343314	11074	Economy	7900.00
0005433343412	11074	Economy	7900.00
0005433343339	11074	Economy	7900.00
0005433343382	11074	Economy	7900.00
0005433343401	11074	Economy	7900.00
0005435380266	11074	Economy	7900.00
0005433343346	11074	Economy	7900.00
0005433343392	11074	Economy	7900.00
0005433343408	11074	Economy	7900.00
0005433343387	11074	Economy	7900.00
0005433343368	11074	Economy	7900.00
0005435097213	11074	Economy	7900.00
0005433343389	11074	Economy	7900.00
0005433343359	11074	Economy	7900.00
0005435508275	11074	Economy	7900.00
0005433343372	11074	Economy	7900.00
0005435380254	11074	Economy	7900.00
0005433343340	11074	Economy	7900.00
0005433343349	11074	Economy	7900.00
0005433343322	11074	Economy	7900.00
0005433343332	11074	Economy	7900.00
0005433343350	11074	Economy	7900.00
0005433343354	11074	Economy	7900.00
0005433342183	17095	Business	23600.00
0005435545753	17095	Business	23600.00
0005432293214	17095	Business	23600.00
0005433342122	17095	Business	23600.00
0005433342303	17095	Business	23600.00
0005433342347	17095	Business	23600.00
0005435545766	17095	Business	23600.00
0005433342490	17095	Business	23600.00
0005433342447	17095	Business	23600.00
0005435097163	17095	Business	23600.00
0005435545752	17095	Business	23600.00
0005433342346	17095	Economy	7900.00
0005435545765	17095	Economy	7900.00
0005433342635	17095	Economy	7900.00
0005432293212	17095	Economy	7900.00
0005433342580	17095	Economy	7900.00
0005435097176	17095	Economy	7900.00
0005435545759	17095	Economy	7900.00
0005433342694	17095	Economy	7900.00
0005433342191	17095	Economy	7900.00
0005433342288	17095	Economy	7900.00
0005433342263	17095	Economy	7900.00
0005433342466	17095	Economy	7900.00
0005435097177	17095	Economy	7900.00
0005433342059	17095	Economy	7900.00
0005433342562	17095	Economy	7900.00
0005433342362	17095	Economy	7900.00
0005433342231	17095	Economy	7900.00
0005435545764	17095	Economy	7900.00
0005433342671	17095	Economy	7900.00
0005433342626	17095	Economy	7900.00
0005433342264	17095	Economy	7900.00
0005433342450	17095	Economy	7900.00
0005435380308	17095	Economy	7900.00
0005433342392	17095	Economy	7900.00
0005433342125	17095	Economy	7900.00
0005435380307	17095	Economy	7900.00
0005433342380	17095	Economy	7900.00
0005433342108	17095	Economy	7900.00
0005433342477	17095	Economy	7900.00
0005435545767	17095	Economy	7900.00
0005433342419	17095	Economy	7900.00
0005433342478	17095	Economy	7900.00
0005433342262	17095	Economy	7900.00
0005433342701	17095	Economy	7900.00
0005433342354	17095	Economy	7900.00
0005435545762	17095	Economy	7900.00
0005433342302	17095	Economy	7900.00
0005433342625	17095	Economy	8600.00
0005433342212	17095	Economy	8600.00
0005435097100	17095	Economy	8600.00
0005435545757	17095	Economy	8600.00
0005433342794	17095	Economy	8600.00
0005435545755	17095	Economy	8600.00
0005435097145	17095	Economy	7900.00
0005435545758	17095	Economy	7900.00
0005433341898	17095	Economy	7900.00
0005433342211	17095	Economy	7900.00
0005435097137	17095	Economy	7900.00
0005433342198	17095	Economy	7900.00
0005433342483	17095	Economy	7900.00
0005435380310	17095	Economy	7900.00
0005433342484	17095	Economy	7900.00
0005435545754	17095	Economy	7900.00
0005433342596	17095	Economy	7900.00
0005433342581	17095	Economy	7900.00
0005435097099	17095	Economy	7900.00
0005433342636	17095	Economy	7900.00
0005433342312	17095	Economy	7900.00
0005433342491	17095	Economy	7900.00
0005433342558	17095	Economy	7900.00
0005435097162	17095	Economy	7900.00
0005433342013	17095	Economy	7900.00
0005433342157	17095	Economy	7900.00
0005433342659	17095	Economy	7900.00
0005433342476	17095	Economy	7900.00
0005433341870	17095	Economy	7900.00
0005435380305	17095	Economy	7900.00
0005433342977	17095	Economy	7900.00
0005433342382	17095	Economy	7900.00
0005433342712	17095	Economy	7900.00
0005433342287	17095	Economy	7900.00
0005433342420	17095	Economy	7900.00
0005433342421	17095	Economy	7900.00
0005433342582	17095	Economy	7900.00
0005433342451	17095	Economy	7900.00
0005433342043	17095	Economy	7900.00
0005433342482	17095	Economy	7900.00
0005433342669	17095	Economy	7900.00
0005435380306	17095	Economy	7900.00
0005435097188	17095	Economy	7900.00
0005433342627	17095	Economy	7900.00
0005433342617	17095	Economy	7900.00
0005433342403	17095	Economy	7900.00
0005435380309	17095	Economy	7900.00
0005435097144	17095	Economy	7900.00
0005433342167	17095	Economy	7900.00
0005433342014	17095	Economy	7900.00
0005435097131	17095	Economy	7900.00
0005433342290	17095	Economy	7900.00
0005433342037	17095	Economy	7900.00
0005433342410	17095	Economy	7900.00
0005433342342	17095	Economy	7900.00
0005433341970	17095	Economy	7900.00
0005432293213	17095	Economy	7900.00
0005433342120	17095	Economy	7900.00
0005433342616	17095	Economy	7900.00
0005433342519	17095	Economy	7900.00
0005433342121	17095	Economy	7900.00
0005435545761	17095	Economy	7900.00
0005433342363	17095	Economy	7900.00
0005433342111	17095	Economy	7900.00
0005433342448	17095	Economy	7900.00
0005433342190	17095	Economy	7900.00
0005433342660	17095	Economy	7900.00
0005435545756	17095	Economy	7900.00
0005435545763	17095	Economy	7900.00
0005433342615	17095	Economy	7900.00
0005433342510	17095	Economy	7900.00
0005435097130	17095	Economy	7900.00
0005435545760	17095	Economy	7900.00
0005433342511	17095	Economy	7900.00
0005432919751	9062	Business	26600.00
0005434158965	9062	Business	26600.00
0005433507225	9062	Business	26600.00
0005432919750	9062	Business	26600.00
0005434158962	9062	Business	26600.00
0005433507217	9062	Business	26600.00
0005432919676	9062	Economy	8900.00
0005432919701	9062	Economy	8900.00
0005433507232	9062	Economy	9800.00
0005434158961	9062	Economy	9800.00
0005433507221	9062	Economy	9800.00
0005432919736	9062	Economy	8900.00
0005432919709	9062	Economy	8900.00
0005432919675	9062	Economy	8900.00
0005433507233	9062	Economy	8900.00
0005433507215	9062	Economy	8900.00
0005432919702	9062	Economy	8900.00
0005434158952	9062	Economy	8900.00
0005433481181	9062	Economy	8900.00
0005433507228	9062	Economy	8900.00
0005433481185	9062	Economy	8900.00
0005433507224	9062	Economy	8900.00
0005433481184	9062	Economy	8900.00
0005433507231	9062	Economy	8900.00
0005433481182	9062	Economy	8900.00
0005433507214	9062	Economy	8900.00
0005433507222	9062	Economy	8900.00
0005433507218	9062	Economy	8900.00
0005432919725	9062	Economy	8900.00
0005433481183	9062	Economy	8900.00
0005433507212	9062	Economy	8900.00
0005433507220	9062	Economy	8900.00
0005433507213	9062	Economy	8900.00
0005434158964	9062	Economy	8900.00
0005433507219	9062	Economy	8900.00
0005433481180	9062	Economy	8900.00
0005433481179	9062	Economy	8900.00
0005433507229	9062	Economy	8900.00
0005433507216	9062	Economy	8900.00
0005432919734	9062	Economy	8900.00
0005433507223	9062	Economy	8900.00
0005433507227	9062	Economy	8900.00
0005432919737	9062	Economy	8900.00
0005433507230	9062	Economy	8900.00
0005432919780	9062	Economy	8900.00
0005432919677	9062	Economy	8900.00
0005433507226	9062	Economy	8900.00
0005433507060	20477	Business	26600.00
0005434158980	20477	Business	26600.00
0005432919917	20477	Business	26600.00
0005432919915	20477	Business	26600.00
0005433507156	20477	Business	26600.00
0005434158981	20477	Business	26600.00
0005433507049	20477	Business	26600.00
0005432919912	20477	Economy	8900.00
0005432919914	20477	Economy	8900.00
0005433507048	20477	Economy	8900.00
0005432919930	20477	Economy	8900.00
0005434158982	20477	Economy	8900.00
0005433506965	20477	Economy	8900.00
0005433507024	20477	Economy	9800.00
0005433507098	20477	Economy	9800.00
0005433507105	20477	Economy	8900.00
0005433507010	20477	Economy	8900.00
0005432919925	20477	Economy	8900.00
0005432919924	20477	Economy	8900.00
0005433507144	20477	Economy	8900.00
0005433507047	20477	Economy	8900.00
0005433507107	20477	Economy	8900.00
0005433507059	20477	Economy	8900.00
0005433507061	20477	Economy	8900.00
0005433507073	20477	Economy	8900.00
0005432919909	20477	Economy	8900.00
0005433507143	20477	Economy	8900.00
0005432919927	20477	Economy	8900.00
0005434158978	20477	Economy	8900.00
0005433507091	20477	Economy	8900.00
0005433507032	20477	Economy	8900.00
0005432919916	20477	Economy	8900.00
0005432919928	20477	Economy	8900.00
0005433507090	20477	Economy	8900.00
0005432919913	20477	Economy	8900.00
0005432919921	20477	Economy	8900.00
0005432919919	20477	Economy	8900.00
0005433481117	20477	Economy	8900.00
0005432919920	20477	Economy	8900.00
0005432919922	20477	Economy	8900.00
0005434158979	20477	Economy	8900.00
0005433507046	20477	Economy	8900.00
0005433507075	20477	Economy	8900.00
0005433507104	20477	Economy	8900.00
0005432919926	20477	Economy	8900.00
0005432919929	20477	Economy	8900.00
0005432919910	20477	Economy	8900.00
0005432919918	20477	Economy	8900.00
0005433507076	20477	Economy	8900.00
0005433481116	20477	Economy	8900.00
0005434158983	20477	Economy	8900.00
0005432919923	20477	Economy	8900.00
0005432919911	20477	Economy	8900.00
0005433507033	20477	Economy	8900.00
0005432394107	10154	Economy	5800.00
0005432394109	10154	Economy	5800.00
0005435178986	10154	Economy	5800.00
0005432396245	10154	Economy	5800.00
0005432396248	10154	Economy	5800.00
0005432396247	10154	Economy	5800.00
0005432394108	10154	Economy	5800.00
0005432396246	10154	Economy	5800.00
0005432396211	18310	Economy	5800.00
0005432396203	18310	Economy	5800.00
0005435179696	18310	Economy	5800.00
0005432400108	18310	Economy	5800.00
0005432396202	18310	Economy	5800.00
0005435179395	18310	Economy	5800.00
0005435179396	18310	Economy	5800.00
0005432400092	18310	Economy	5800.00
0005435125918	10957	Business	9500.00
0005435556677	10957	Business	9500.00
0005435126161	10957	Business	9500.00
0005435126230	10957	Business	9500.00
0005435125920	10957	Business	9500.00
0005435126057	10957	Business	9500.00
0005435554136	10957	Business	9500.00
0005434411785	10957	Business	9500.00
0005435126148	10957	Business	9500.00
0005435556655	10957	Business	9500.00
0005435125993	10957	Business	9500.00
0005435126019	10957	Economy	3200.00
0005435626040	10957	Economy	3200.00
0005435126137	10957	Economy	3200.00
0005435126322	10957	Economy	3200.00
0005435126068	10957	Economy	3200.00
0005434411787	10957	Economy	3200.00
0005435126229	10957	Economy	3200.00
0005434411789	10957	Economy	3200.00
0005435626042	10957	Economy	3200.00
0005435554137	10957	Economy	3200.00
0005435125905	10957	Economy	3500.00
0005435126138	10957	Economy	3500.00
0005435554175	10957	Economy	3500.00
0005435625954	10957	Economy	3200.00
0005435126146	10957	Economy	3200.00
0005435126147	10957	Economy	3200.00
0005434928306	10957	Economy	3200.00
0005435126070	10957	Economy	3200.00
0005435126160	10957	Economy	3200.00
0005435125851	10957	Economy	3200.00
0005435125906	10957	Economy	3200.00
0005435126204	10957	Economy	3200.00
0005435556678	10957	Economy	3200.00
0005435626039	10957	Economy	3200.00
0005435125974	10957	Economy	3200.00
0005435126105	10957	Economy	3200.00
0005435125898	10957	Economy	3200.00
0005435125969	10957	Economy	3200.00
0005435556679	10957	Economy	3200.00
0005435125852	10957	Economy	3200.00
0005435554158	10957	Economy	3200.00
0005435626004	10957	Economy	3200.00
0005435126205	10957	Economy	3200.00
0005435126058	10957	Economy	3200.00
0005435126055	10957	Economy	3200.00
0005434928305	10957	Economy	3200.00
0005435126040	10957	Economy	3200.00
0005435126182	10957	Economy	3200.00
0005435554145	10957	Economy	3200.00
0005435126159	10957	Economy	3200.00
0005435125968	10957	Economy	3200.00
0005435554148	10957	Economy	3200.00
0005435554147	10957	Economy	3200.00
0005435125999	10957	Economy	3200.00
0005435556673	10957	Economy	3200.00
0005435125919	10957	Economy	3200.00
0005435126206	10957	Economy	3200.00
0005435126066	10957	Economy	3200.00
0005434411786	10957	Economy	3200.00
0005435556676	10957	Economy	3200.00
0005435556656	10957	Economy	3200.00
0005435125998	10957	Economy	3200.00
0005435125979	10957	Economy	3200.00
0005435125962	10957	Economy	3200.00
0005435126067	10957	Economy	3200.00
0005435126187	10957	Economy	3200.00
0005435126181	10957	Economy	3200.00
0005435554176	10957	Economy	3200.00
0005435556657	10957	Economy	3200.00
0005435126098	10957	Economy	3200.00
0005435126180	10957	Economy	3200.00
0005435126173	10957	Economy	3200.00
0005435626041	10957	Economy	3200.00
0005435126104	10957	Economy	3200.00
0005434411788	10957	Economy	3200.00
0005435556654	10957	Economy	3200.00
0005435126253	10957	Economy	3200.00
0005435556675	10957	Economy	3200.00
0005435126207	10957	Economy	3200.00
0005435125997	10957	Economy	3200.00
0005435126028	10957	Economy	3200.00
0005435626026	10957	Economy	3200.00
0005435126460	14740	Business	9500.00
0005435126463	14740	Business	9500.00
0005435126468	14740	Business	9500.00
0005435126474	14740	Business	9500.00
0005435126448	14740	Business	9500.00
0005435626207	14740	Business	9500.00
0005435626209	14740	Business	9500.00
0005435126466	14740	Business	9500.00
0005435126455	14740	Business	9500.00
0005435126446	14740	Business	9500.00
0005435626205	14740	Economy	3200.00
0005434411756	14740	Economy	3200.00
0005435626195	14740	Economy	3200.00
0005435554193	14740	Economy	3200.00
0005435626193	14740	Economy	3200.00
0005435554194	14740	Economy	3200.00
0005435554192	14740	Economy	3200.00
0005435126472	14740	Economy	3500.00
0005435126450	14740	Economy	3500.00
0005435126478	14740	Economy	3500.00
0005435126476	14740	Economy	3500.00
0005435626206	14740	Economy	3500.00
0005435126442	14740	Economy	3200.00
0005435626215	14740	Economy	3200.00
0005435126452	14740	Economy	3200.00
0005435126445	14740	Economy	3200.00
0005435626211	14740	Economy	3200.00
0005435626216	14740	Economy	3200.00
0005435626201	14740	Economy	3200.00
0005435554196	14740	Economy	3200.00
0005435554195	14740	Economy	3200.00
0005434411732	14740	Economy	3200.00
0005435126473	14740	Economy	3200.00
0005435126456	14740	Economy	3200.00
0005435126454	14740	Economy	3200.00
0005435126480	14740	Economy	3200.00
0005435554197	14740	Economy	3200.00
0005435126469	14740	Economy	3200.00
0005435626197	14740	Economy	3200.00
0005435126475	14740	Economy	3200.00
0005435126479	14740	Economy	3200.00
0005434928284	14740	Economy	3200.00
0005435126470	14740	Economy	3200.00
0005435626199	14740	Economy	3200.00
0005435126447	14740	Economy	3200.00
0005434411755	14740	Economy	3200.00
0005435626204	14740	Economy	3200.00
0005435626212	14740	Economy	3200.00
0005435126477	14740	Economy	3200.00
0005435126444	14740	Economy	3200.00
0005435626198	14740	Economy	3200.00
0005435626213	14740	Economy	3200.00
0005435126440	14740	Economy	3200.00
0005435126457	14740	Economy	3200.00
0005435126464	14740	Economy	3200.00
0005434411738	14740	Economy	3200.00
0005435626203	14740	Economy	3200.00
0005435126459	14740	Economy	3200.00
0005435626196	14740	Economy	3200.00
0005435126462	14740	Economy	3200.00
0005435626208	14740	Economy	3200.00
0005434411733	14740	Economy	3200.00
0005435626194	14740	Economy	3200.00
0005435126451	14740	Economy	3200.00
0005435626217	14740	Economy	3200.00
0005435626202	14740	Economy	3200.00
0005435556698	14740	Economy	3200.00
0005434928282	14740	Economy	3200.00
0005435126453	14740	Economy	3200.00
0005435126443	14740	Economy	3200.00
0005435126467	14740	Economy	3200.00
0005435126461	14740	Economy	3200.00
0005435126439	14740	Economy	3200.00
0005434411726	14740	Economy	3200.00
0005435126449	14740	Economy	3200.00
0005435126471	14740	Economy	3200.00
0005435626214	14740	Economy	3200.00
0005435126441	14740	Economy	3200.00
0005435556697	14740	Economy	3200.00
0005435126458	14740	Economy	3200.00
0005435626210	14740	Economy	3200.00
0005435126465	14740	Economy	3200.00
0005435626200	14740	Economy	3200.00
0005435126438	14740	Economy	3200.00
0005432398204	7111	Business	86900.00
0005435443263	7111	Business	86900.00
0005432398205	7111	Business	86900.00
0005435715510	7111	Business	86900.00
0005432400134	7111	Economy	29000.00
0005435179390	7111	Economy	29000.00
0005435178486	7111	Economy	29000.00
0005435715497	7111	Economy	29000.00
0005432400133	7111	Economy	29000.00
0005435216569	7111	Economy	29000.00
0005435715500	7111	Economy	31900.00
0005435715498	7111	Economy	31900.00
0005435443244	7111	Economy	31900.00
0005432400131	7111	Economy	31900.00
0005435443240	7111	Economy	29000.00
0005435178484	7111	Economy	29000.00
0005435715494	7111	Economy	29000.00
0005435715504	7111	Economy	29000.00
0005435715507	7111	Economy	29000.00
0005435715506	7111	Economy	29000.00
0005435443251	7111	Economy	29000.00
0005435443245	7111	Economy	29000.00
0005435443278	7111	Economy	29000.00
0005435219189	7111	Economy	29000.00
0005435443264	7111	Economy	29000.00
0005435443267	7111	Economy	29000.00
0005435443250	7111	Economy	29000.00
0005435715502	7111	Economy	29000.00
0005435715505	7111	Economy	29000.00
0005435443239	7111	Economy	29000.00
0005435443277	7111	Economy	29000.00
0005432400132	7111	Economy	29000.00
0005435715508	7111	Economy	29000.00
0005435178489	7111	Economy	29000.00
0005435443243	7111	Economy	29000.00
0005435715503	7111	Economy	29000.00
0005435443246	7111	Economy	29000.00
0005435715509	7111	Economy	29000.00
0005435219190	7111	Economy	29000.00
0005435715495	7111	Economy	29000.00
0005435219176	7111	Economy	29000.00
0005435715499	7111	Economy	29000.00
0005435219191	7111	Economy	29000.00
0005435219177	7111	Economy	29000.00
0005435715496	7111	Economy	29000.00
0005435443241	7111	Economy	29000.00
0005435715501	7111	Economy	29000.00
0005435715394	27048	Business	86900.00
0005435715342	27048	Business	86900.00
0005435715385	27048	Business	86900.00
0005435715270	27048	Economy	29000.00
0005435715407	27048	Economy	31900.00
0005435715339	27048	Economy	31900.00
0005435715271	27048	Economy	31900.00
0005435715364	27048	Economy	29000.00
0005435443336	27048	Economy	29000.00
0005435715303	27048	Economy	29000.00
0005435178995	27048	Economy	29000.00
0005435715384	27048	Economy	29000.00
0005432398181	27048	Economy	29000.00
0005435178993	27048	Economy	29000.00
0005435715418	27048	Economy	29000.00
0005435178498	27048	Economy	29000.00
0005435443330	27048	Economy	29000.00
0005435443332	27048	Economy	29000.00
0005432394081	27048	Economy	29000.00
0005435443331	27048	Economy	29000.00
0005435443334	27048	Economy	29000.00
0005435715302	27048	Economy	29000.00
0005435443329	27048	Economy	29000.00
0005435715464	27048	Economy	29000.00
0005432398164	27048	Economy	29000.00
0005435715313	27048	Economy	29000.00
0005435715465	27048	Economy	29000.00
0005435178994	27048	Economy	29000.00
0005435443328	27048	Economy	29000.00
0005435715338	27048	Economy	29000.00
0005435443333	27048	Economy	29000.00
0005432394080	27048	Economy	29000.00
0005432394082	27048	Economy	29000.00
0005435443335	27048	Economy	29000.00
0005433060394	2751	Economy	7700.00
0005434084937	2751	Economy	7700.00
0005433060401	2751	Economy	7700.00
0005434084942	2751	Economy	7700.00
0005434084941	2751	Economy	7700.00
0005433060400	2751	Economy	7700.00
0005433060388	2751	Economy	7700.00
0005433060383	2751	Economy	7700.00
0005434084938	2751	Economy	7700.00
0005434084940	2751	Economy	7700.00
0005434084939	2751	Economy	7700.00
0005434084899	28496	Economy	7700.00
0005433060419	28496	Economy	7700.00
0005434084898	28496	Economy	7700.00
0005433060418	28496	Economy	7700.00
0005435517777	11378	Business	20200.00
0005435540830	11378	Business	20200.00
0005435540781	11378	Economy	6700.00
0005435517803	11378	Economy	6700.00
0005435517848	11378	Economy	6700.00
0005435540888	11378	Economy	6700.00
0005435540930	11378	Economy	6700.00
0005435540889	11378	Economy	6700.00
0005435540824	11378	Economy	6700.00
0005435540837	11378	Economy	6700.00
0005435517824	11378	Economy	6700.00
0005435517823	11378	Economy	6700.00
0005435540949	11378	Economy	6700.00
0005435540823	11378	Economy	6700.00
0005435540890	11378	Economy	6700.00
0005435517776	11378	Economy	6700.00
0005435540825	11378	Economy	6700.00
0005435540939	11378	Economy	6700.00
0005435540969	11378	Economy	6700.00
0005435540780	11378	Economy	6700.00
0005435540826	11378	Economy	6700.00
0005435517847	11378	Economy	6700.00
0005435541035	22232	Business	20200.00
0005435529289	22232	Business	20200.00
0005435529295	22232	Business	20200.00
0005435529299	22232	Business	20200.00
0005435541033	22232	Business	20200.00
0005435541031	22232	Economy	6700.00
0005432294490	22232	Economy	6700.00
0005435529280	22232	Economy	6700.00
0005435529278	22232	Economy	6700.00
0005435529288	22232	Economy	6700.00
0005435529282	22232	Economy	6700.00
0005435529294	22232	Economy	7400.00
0005435541042	22232	Economy	7400.00
0005435529285	22232	Economy	6700.00
0005435541034	22232	Economy	6700.00
0005435529281	22232	Economy	6700.00
0005435541036	22232	Economy	6700.00
0005435541041	22232	Economy	6700.00
0005432294489	22232	Economy	6700.00
0005435529283	22232	Economy	6700.00
0005435541039	22232	Economy	6700.00
0005435529297	22232	Economy	6700.00
0005435541027	22232	Economy	6700.00
0005435541026	22232	Economy	6700.00
0005435529296	22232	Economy	6700.00
0005435541025	22232	Economy	6700.00
0005435541040	22232	Economy	6700.00
0005435541023	22232	Economy	6700.00
0005435541030	22232	Economy	6700.00
0005435541038	22232	Economy	6700.00
0005435529291	22232	Economy	6700.00
0005435541037	22232	Economy	6700.00
0005435529298	22232	Economy	6700.00
0005435541024	22232	Economy	6700.00
0005435541029	22232	Economy	6700.00
0005435541028	22232	Economy	6700.00
0005435529286	22232	Economy	6700.00
0005435529279	22232	Economy	6700.00
0005435529290	22232	Economy	6700.00
0005432294491	22232	Economy	6700.00
0005435541032	22232	Economy	6700.00
0005435529292	22232	Economy	6700.00
0005435529287	22232	Economy	6700.00
0005435529277	22232	Economy	6700.00
0005435529293	22232	Economy	6700.00
0005435529284	22232	Economy	6700.00
0005434907408	2272	Business	20200.00
0005434907419	2272	Business	20200.00
0005434907388	2272	Business	20200.00
0005433251296	2272	Business	20200.00
0005433251508	2272	Business	20200.00
0005434907426	2272	Business	20200.00
0005434907385	2272	Business	20200.00
0005433400966	2272	Business	20200.00
0005434907411	2272	Business	20200.00
0005434907427	2272	Business	20200.00
0005433251265	2272	Business	20200.00
0005434907412	2272	Business	20200.00
0005434907374	2272	Economy	6700.00
0005434907379	2272	Economy	6700.00
0005434907416	2272	Economy	6700.00
0005434907386	2272	Economy	6700.00
0005434907431	2272	Economy	6700.00
0005434907397	2272	Economy	6700.00
0005433400972	2272	Economy	6700.00
0005434907380	2272	Economy	6700.00
0005433400970	2272	Economy	6700.00
0005433400971	2272	Economy	6700.00
0005434907421	2272	Economy	7400.00
0005434907401	2272	Economy	7400.00
0005434907423	2272	Economy	7400.00
0005434907406	2272	Economy	7400.00
0005434907420	2272	Economy	7400.00
0005434907400	2272	Economy	6700.00
0005433400965	2272	Economy	6700.00
0005434907392	2272	Economy	6700.00
0005433251334	2272	Economy	6700.00
0005434907396	2272	Economy	6700.00
0005434907403	2272	Economy	6700.00
0005434907424	2272	Economy	6700.00
0005434907387	2272	Economy	6700.00
0005434907404	2272	Economy	6700.00
0005433251253	2272	Economy	6700.00
0005434907415	2272	Economy	6700.00
0005434907384	2272	Economy	6700.00
0005434907407	2272	Economy	6700.00
0005433251361	2272	Economy	6700.00
0005434907390	2272	Economy	6700.00
0005433251213	2272	Economy	6700.00
0005434907372	2272	Economy	6700.00
0005434907413	2272	Economy	6700.00
0005434907375	2272	Economy	6700.00
0005434907376	2272	Economy	6700.00
0005433251335	2272	Economy	6700.00
0005434907429	2272	Economy	6700.00
0005434907402	2272	Economy	6700.00
0005434907435	2272	Economy	6700.00
0005434907389	2272	Economy	6700.00
0005434907394	2272	Economy	6700.00
0005433251378	2272	Economy	6700.00
0005434907373	2272	Economy	6700.00
0005433251289	2272	Economy	6700.00
0005434907405	2272	Economy	6700.00
0005434907377	2272	Economy	6700.00
0005434907382	2272	Economy	6700.00
0005434907391	2272	Economy	6700.00
0005433251214	2272	Economy	6700.00
0005434907381	2272	Economy	6700.00
0005434907433	2272	Economy	6700.00
0005434907383	2272	Economy	6700.00
0005434907409	2272	Economy	6700.00
0005434907378	2272	Economy	6700.00
0005433251266	2272	Economy	6700.00
0005434907417	2272	Economy	6700.00
0005433251376	2272	Economy	6700.00
0005434907395	2272	Economy	6700.00
0005434907418	2272	Economy	6700.00
0005434907399	2272	Economy	6700.00
0005433251267	2272	Economy	6700.00
0005434907398	2272	Economy	6700.00
0005433251337	2272	Economy	6700.00
0005434907430	2272	Economy	6700.00
0005434907422	2272	Economy	6700.00
0005433251297	2272	Economy	6700.00
0005434907425	2272	Economy	6700.00
0005434907432	2272	Economy	6700.00
0005434907393	2272	Economy	6700.00
0005434907414	2272	Economy	6700.00
0005433400964	2272	Economy	6700.00
0005434907410	2272	Economy	6700.00
0005433251365	2272	Economy	6700.00
0005433251411	2272	Economy	6700.00
0005434907428	2272	Economy	6700.00
0005433251244	2272	Economy	6700.00
0005433251360	2272	Economy	6700.00
0005434907434	2272	Economy	6700.00
0005433251544	25588	Business	20200.00
0005433251538	25588	Business	20200.00
0005433251542	25588	Business	20200.00
0005434906870	25588	Business	20200.00
0005434906965	25588	Business	20200.00
0005434906764	25588	Business	20200.00
0005434907008	25588	Business	20200.00
0005433251554	25588	Business	20200.00
0005434906838	25588	Business	20200.00
0005434906890	25588	Business	20200.00
0005434906743	25588	Economy	6700.00
0005434906636	25588	Economy	6700.00
0005433251537	25588	Economy	6700.00
0005434906869	25588	Economy	6700.00
0005433251555	25588	Economy	6700.00
0005434906832	25588	Economy	6700.00
0005434906930	25588	Economy	6700.00
0005434906774	25588	Economy	6700.00
0005433251551	25588	Economy	6700.00
0005433251558	25588	Economy	6700.00
0005434906931	25588	Economy	7400.00
0005433251528	25588	Economy	7400.00
0005433251556	25588	Economy	7400.00
0005433251559	25588	Economy	7400.00
0005433251532	25588	Economy	7400.00
0005433251540	25588	Economy	6700.00
0005434906928	25588	Economy	6700.00
0005433251536	25588	Economy	6700.00
0005434907007	25588	Economy	6700.00
0005434907047	25588	Economy	6700.00
0005434906914	25588	Economy	6700.00
0005434906858	25588	Economy	6700.00
0005434906988	25588	Economy	6700.00
0005434906744	25588	Economy	6700.00
0005433251552	25588	Economy	6700.00
0005434906927	25588	Economy	6700.00
0005433251534	25588	Economy	6700.00
0005433251541	25588	Economy	6700.00
0005434906811	25588	Economy	6700.00
0005434906553	25588	Economy	6700.00
0005434906855	25588	Economy	6700.00
0005434906763	25588	Economy	6700.00
0005434906944	25588	Economy	6700.00
0005434906919	25588	Economy	6700.00
0005433400990	25588	Economy	6700.00
0005434906868	25588	Economy	6700.00
0005433251553	25588	Economy	6700.00
0005434906925	25588	Economy	6700.00
0005434906769	25588	Economy	6700.00
0005433251550	25588	Economy	6700.00
0005434906864	25588	Economy	6700.00
0005433251530	25588	Economy	6700.00
0005434906916	25588	Economy	6700.00
0005433251546	25588	Economy	6700.00
0005434906947	25588	Economy	6700.00
0005434906770	25588	Economy	6700.00
0005434906753	25588	Economy	6700.00
0005433251533	25588	Economy	6700.00
0005433251529	25588	Economy	6700.00
0005433251547	25588	Economy	6700.00
0005434906856	25588	Economy	6700.00
0005433251549	25588	Economy	6700.00
0005434906918	25588	Economy	6700.00
0005433251548	25588	Economy	6700.00
0005434906971	25588	Economy	6700.00
0005434906921	25588	Economy	6700.00
0005434906865	25588	Economy	6700.00
0005434906946	25588	Economy	6700.00
0005434906896	25588	Economy	6700.00
0005434906635	25588	Economy	6700.00
0005434907013	25588	Economy	6700.00
0005434906760	25588	Economy	6700.00
0005433400989	25588	Economy	6700.00
0005434906957	25588	Economy	6700.00
0005433251535	25588	Economy	6700.00
0005433251539	25588	Economy	6700.00
0005434906857	25588	Economy	6700.00
0005434906812	25588	Economy	6700.00
0005434906895	25588	Economy	6700.00
0005433251545	25588	Economy	6700.00
0005434906860	25588	Economy	6700.00
0005434906964	25588	Economy	6700.00
0005433251531	25588	Economy	6700.00
0005434907014	25588	Economy	6700.00
0005434906915	25588	Economy	6700.00
0005434906555	25588	Economy	6700.00
0005434906804	25588	Economy	6700.00
0005434906894	25588	Economy	6700.00
0005433251543	25588	Economy	6700.00
0005433251557	25588	Economy	6700.00
0005432621063	2496	Economy	13600.00
0005432862278	2496	Economy	13600.00
0005432862301	2496	Economy	12400.00
0005432862271	2496	Economy	12400.00
0005432862302	2496	Economy	12400.00
0005432621068	2496	Economy	12400.00
0005432621064	2496	Economy	12400.00
0005432621067	2496	Economy	12400.00
0005432621070	2496	Economy	12400.00
0005432862279	2496	Economy	12400.00
0005432621066	2496	Economy	12400.00
0005432862275	2496	Economy	12400.00
0005432621074	2496	Economy	12400.00
0005432862270	2496	Economy	12400.00
0005432621071	2496	Economy	12400.00
0005432621065	2496	Economy	12400.00
0005432621069	2496	Economy	12400.00
0005432621073	2496	Economy	12400.00
0005432862261	2496	Economy	12400.00
0005432862253	2496	Economy	12400.00
0005432621062	2496	Economy	12400.00
0005432621072	2496	Economy	12400.00
0005432862260	2496	Economy	12400.00
0005432862316	28048	Economy	13600.00
0005432862323	28048	Economy	13600.00
0005432620932	28048	Economy	13600.00
0005432862320	28048	Economy	12400.00
0005432620879	28048	Economy	12400.00
0005432862315	28048	Economy	12400.00
0005432620930	28048	Economy	12400.00
0005432620870	28048	Economy	12400.00
0005432862314	28048	Economy	12400.00
0005432862321	28048	Economy	12400.00
0005432862322	28048	Economy	12400.00
0005432620929	28048	Economy	12400.00
0005432620963	28048	Economy	12400.00
0005432620914	28048	Economy	12400.00
0005432620987	28048	Economy	12400.00
0005432620983	28048	Economy	12400.00
0005432620937	28048	Economy	12400.00
0005432620971	28048	Economy	12400.00
0005432620931	28048	Economy	12400.00
0005432620903	28048	Economy	12400.00
0005432862317	28048	Economy	12400.00
0005432620933	28048	Economy	12400.00
0005432862318	28048	Economy	12400.00
0005432620899	28048	Economy	12400.00
0005432862319	28048	Economy	12400.00
0005434097466	11721	Economy	11300.00
0005434097481	13046	Economy	11300.00
0005434097480	13046	Economy	11300.00
0005434097479	13046	Economy	11300.00
0005433452744	31097	Economy	8400.00
0005433451623	31097	Economy	8400.00
0005433452743	31097	Economy	8400.00
0005433451622	31097	Economy	8400.00
0005433452722	31343	Economy	8400.00
0005433454866	31343	Economy	8400.00
0005433454860	31343	Economy	8400.00
0005433452718	31343	Economy	8400.00
0005433454861	31343	Economy	8400.00
0005433452717	31343	Economy	8400.00
0005433454862	31343	Economy	8400.00
0005433454865	31343	Economy	8400.00
0005434142586	12003	Economy	7200.00
0005434142583	12003	Economy	7200.00
0005434142584	12003	Economy	7200.00
0005433134096	12003	Economy	6600.00
0005434184645	12003	Economy	6600.00
0005433134095	12003	Economy	6600.00
0005433134112	12003	Economy	6600.00
0005433134109	12003	Economy	6600.00
0005433134110	12003	Economy	6600.00
0005434142587	12003	Economy	6600.00
0005433129261	12003	Economy	6600.00
0005434142585	12003	Economy	6600.00
0005433129255	12003	Economy	6600.00
0005433134104	12003	Economy	6600.00
0005434184646	12003	Economy	6600.00
0005433134105	12003	Economy	6600.00
0005434183584	29832	Economy	7200.00
0005433131715	29832	Economy	7200.00
0005434142616	29832	Economy	6600.00
0005434184669	29832	Economy	6600.00
0005433134149	29832	Economy	6600.00
0005434142614	29832	Economy	6600.00
0005433131717	29832	Economy	6600.00
0005434142615	29832	Economy	6600.00
0005434142613	29832	Economy	6600.00
0005434142617	29832	Economy	6600.00
0005433131719	29832	Economy	6600.00
0005433134147	29832	Economy	6600.00
0005434184670	29832	Economy	6600.00
0005433134145	29832	Economy	6600.00
0005434184668	29832	Economy	6600.00
0005433134146	29832	Economy	6600.00
0005433134148	29832	Economy	6600.00
0005433134150	29832	Economy	6600.00
0005433131718	29832	Economy	6600.00
0005434183585	29832	Economy	6600.00
0005433131716	29832	Economy	6600.00
0005435697378	16447	Economy	19900.00
0005435697364	16447	Economy	19900.00
0005435697368	16447	Economy	18100.00
0005435697365	16447	Economy	18100.00
0005435697382	16447	Economy	18100.00
0005435697380	16447	Economy	18100.00
0005435697374	16447	Economy	18100.00
0005435697384	16447	Economy	18100.00
0005435697362	16447	Economy	18100.00
0005435697373	16447	Economy	18100.00
0005435697377	16447	Economy	18100.00
0005435697379	16447	Economy	18100.00
0005435697361	16447	Economy	18100.00
0005435697383	16447	Economy	18100.00
0005435697375	16447	Economy	18100.00
0005435697386	16447	Economy	18100.00
0005435697367	16447	Economy	18100.00
0005435697372	16447	Economy	18100.00
0005435697370	16447	Economy	18100.00
0005435697369	16447	Economy	18100.00
0005435697363	16447	Economy	18100.00
0005435697387	16447	Economy	18100.00
0005435697381	16447	Economy	18100.00
0005435697366	16447	Economy	18100.00
0005435697376	16447	Economy	18100.00
0005435697389	16447	Economy	18100.00
0005435697360	16447	Economy	18100.00
0005435697385	16447	Economy	18100.00
0005435697371	16447	Economy	18100.00
0005435697388	16447	Economy	18100.00
0005435935056	24704	Economy	19900.00
0005435697149	24704	Economy	19900.00
0005435697107	24704	Economy	19900.00
0005435697141	24704	Economy	19900.00
0005435697275	24704	Economy	18100.00
0005435935055	24704	Economy	18100.00
0005435935053	24704	Economy	18100.00
0005435697224	24704	Economy	18100.00
0005435697166	24704	Economy	18100.00
0005435697301	24704	Economy	18100.00
0005435697131	24704	Economy	18100.00
0005435697124	24704	Economy	18100.00
0005435697214	24704	Economy	18100.00
0005435697134	24704	Economy	18100.00
0005435697223	24704	Economy	18100.00
0005435697302	24704	Economy	18100.00
0005435697165	24704	Economy	18100.00
0005435697267	24704	Economy	18100.00
0005435697132	24704	Economy	18100.00
0005435935052	24704	Economy	18100.00
0005435697268	24704	Economy	18100.00
0005435697140	24704	Economy	18100.00
0005435697204	24704	Economy	18100.00
0005435697286	24704	Economy	18100.00
0005435935057	24704	Economy	18100.00
0005435697074	24704	Economy	18100.00
0005435697168	24704	Economy	18100.00
0005435935054	24704	Economy	18100.00
0005435697104	24704	Economy	18100.00
0005435697108	24704	Economy	18100.00
0005435697239	24704	Economy	18100.00
0005435697123	24704	Economy	18100.00
0005435697285	24704	Economy	18100.00
0005435697205	24704	Economy	18100.00
0005432968826	18814	Economy	4400.00
0005432968817	18814	Economy	4400.00
0005432968807	18814	Economy	4400.00
0005432968816	18814	Economy	4400.00
0005432968818	18814	Economy	4400.00
0005432968831	18814	Economy	4400.00
0005432968830	18814	Economy	4400.00
0005433724814	18814	Economy	4400.00
0005433724813	18814	Economy	4400.00
0005433724812	18814	Economy	4400.00
0005432968846	21626	Economy	4400.00
0005433724793	21626	Economy	4400.00
0005432968847	21626	Economy	4400.00
0005433724792	21626	Economy	4400.00
0005433724772	21626	Economy	4400.00
0005433724778	21626	Economy	4400.00
0005434138356	7292	Business	23100.00
0005434138329	7292	Business	23100.00
0005434138359	7292	Business	23100.00
0005434138307	7292	Business	23100.00
0005434138323	7292	Business	23100.00
0005434138331	7292	Business	23100.00
0005434138308	7292	Business	23100.00
0005434138341	7292	Business	23100.00
0005434138313	7292	Business	23100.00
0005434138347	7292	Business	23100.00
0005434138387	7292	Business	23100.00
0005434138380	7292	Economy	7700.00
0005434138355	7292	Economy	7700.00
0005434087522	7292	Economy	7700.00
0005434138357	7292	Economy	7700.00
0005434138336	7292	Economy	7700.00
0005434138363	7292	Economy	7700.00
0005434138351	7292	Economy	7700.00
0005434138337	7292	Economy	7700.00
0005434138352	7292	Economy	7700.00
0005434138346	7292	Economy	8500.00
0005434138325	7292	Economy	8500.00
0005434138339	7292	Economy	8500.00
0005434138362	7292	Economy	8500.00
0005434138353	7292	Economy	8500.00
0005434138324	7292	Economy	7700.00
0005434138376	7292	Economy	7700.00
0005434138310	7292	Economy	7700.00
0005434138338	7292	Economy	7700.00
0005434138361	7292	Economy	7700.00
0005434138335	7292	Economy	7700.00
0005434138368	7292	Economy	7700.00
0005434138350	7292	Economy	7700.00
0005434087525	7292	Economy	7700.00
0005434138322	7292	Economy	7700.00
0005434138340	7292	Economy	7700.00
0005434138383	7292	Economy	7700.00
0005434138315	7292	Economy	7700.00
0005434138369	7292	Economy	7700.00
0005434138318	7292	Economy	7700.00
0005434138348	7292	Economy	7700.00
0005434138372	7292	Economy	7700.00
0005434138328	7292	Economy	7700.00
0005434138333	7292	Economy	7700.00
0005434138334	7292	Economy	7700.00
0005434138382	7292	Economy	7700.00
0005434138349	7292	Economy	7700.00
0005434138330	7292	Economy	7700.00
0005434138386	7292	Economy	7700.00
0005434138343	7292	Economy	7700.00
0005434138375	7292	Economy	7700.00
0005434138377	7292	Economy	7700.00
0005434138311	7292	Economy	7700.00
0005434138388	7292	Economy	7700.00
0005434138320	7292	Economy	7700.00
0005434138309	7292	Economy	7700.00
0005434138374	7292	Economy	7700.00
0005434138314	7292	Economy	7700.00
0005434138306	7292	Economy	7700.00
0005434138384	7292	Economy	7700.00
0005434138379	7292	Economy	7700.00
0005434138344	7292	Economy	7700.00
0005434138312	7292	Economy	7700.00
0005434138371	7292	Economy	7700.00
0005434138319	7292	Economy	7700.00
0005434138385	7292	Economy	7700.00
0005434138378	7292	Economy	7700.00
0005434138326	7292	Economy	7700.00
0005434138366	7292	Economy	7700.00
0005434138373	7292	Economy	7700.00
0005434138367	7292	Economy	7700.00
0005434138317	7292	Economy	7700.00
0005434138342	7292	Economy	7700.00
0005434138354	7292	Economy	7700.00
0005434138332	7292	Economy	7700.00
0005434138370	7292	Economy	7700.00
0005434087523	7292	Economy	7700.00
0005434138360	7292	Economy	7700.00
0005434138316	7292	Economy	7700.00
0005434138365	7292	Economy	7700.00
0005434138345	7292	Economy	7700.00
0005434138327	7292	Economy	7700.00
0005434138381	7292	Economy	7700.00
0005434087524	7292	Economy	7700.00
0005434138364	7292	Economy	7700.00
0005434138321	7292	Economy	7700.00
0005434138358	7292	Economy	7700.00
0005434137546	28535	Business	23100.00
0005434137288	28535	Business	23100.00
0005434137297	28535	Business	23100.00
0005434137687	28535	Business	23100.00
0005434137517	28535	Business	23100.00
0005434137468	28535	Business	23100.00
0005434137179	28535	Business	23100.00
0005434137639	28535	Business	23100.00
0005434137348	28535	Business	23100.00
0005434137030	28535	Business	23100.00
0005434137482	28535	Economy	7700.00
0005434137199	28535	Economy	7700.00
0005434137395	28535	Economy	7700.00
0005434137477	28535	Economy	7700.00
0005434137333	28535	Economy	7700.00
0005434137693	28535	Economy	7700.00
0005434137406	28535	Economy	7700.00
0005434137602	28535	Economy	8500.00
0005434137209	28535	Economy	8500.00
0005434137699	28535	Economy	8500.00
0005434137043	28535	Economy	8500.00
0005434137120	28535	Economy	8500.00
0005434137379	28535	Economy	7700.00
0005434137566	28535	Economy	7700.00
0005434137467	28535	Economy	7700.00
0005434137119	28535	Economy	7700.00
0005434137519	28535	Economy	7700.00
0005434137296	28535	Economy	7700.00
0005434137513	28535	Economy	7700.00
0005434137453	28535	Economy	7700.00
0005434137399	28535	Economy	7700.00
0005434137478	28535	Economy	7700.00
0005434137651	28535	Economy	7700.00
0005434137522	28535	Economy	7700.00
0005434137317	28535	Economy	7700.00
0005434137387	28535	Economy	7700.00
0005434137374	28535	Economy	7700.00
0005434137316	28535	Economy	7700.00
0005434137650	28535	Economy	7700.00
0005434137345	28535	Economy	7700.00
0005434137652	28535	Economy	7700.00
0005434137516	28535	Economy	7700.00
0005434137547	28535	Economy	7700.00
0005434137686	28535	Economy	7700.00
0005434137393	28535	Economy	7700.00
0005434137665	28535	Economy	7700.00
0005434137565	28535	Economy	7700.00
0005434137638	28535	Economy	7700.00
0005434137505	28535	Economy	7700.00
0005434137042	28535	Economy	7700.00
0005434137636	28535	Economy	7700.00
0005434137470	28535	Economy	7700.00
0005434137521	28535	Economy	7700.00
0005434137506	28535	Economy	7700.00
0005434137108	28535	Economy	7700.00
0005434137694	28535	Economy	7700.00
0005434137210	28535	Economy	7700.00
0005434137447	28535	Economy	7700.00
0005434137186	28535	Economy	7700.00
0005434137375	28535	Economy	7700.00
0005434087483	28535	Economy	7700.00
0005434137483	28535	Economy	7700.00
0005434137041	28535	Economy	7700.00
0005434137378	28535	Economy	7700.00
0005434137508	28535	Economy	7700.00
0005434137548	28535	Economy	7700.00
0005434137315	28535	Economy	7700.00
0005434137664	28535	Economy	7700.00
0005434137581	28535	Economy	7700.00
0005434137641	28535	Economy	7700.00
0005434137580	28535	Economy	7700.00
0005434137314	28535	Economy	7700.00
0005434137452	28535	Economy	7700.00
0005434087489	28535	Economy	7700.00
0005434137342	28535	Economy	7700.00
0005434137562	28535	Economy	7700.00
0005434137394	28535	Economy	7700.00
0005434137640	28535	Economy	7700.00
0005434137388	28535	Economy	7700.00
0005434137535	28535	Economy	7700.00
0005434137727	28535	Economy	7700.00
0005434137343	28535	Economy	7700.00
0005434137481	28535	Economy	7700.00
0005434137635	28535	Economy	7700.00
0005434137507	28535	Economy	7700.00
0005435808253	1925	Economy	23900.00
0005433407497	1925	Economy	21700.00
0005435808261	1925	Economy	21700.00
0005435808262	1925	Economy	21700.00
0005434610236	1925	Economy	21700.00
0005435808258	1925	Economy	21700.00
0005435808255	1925	Economy	21700.00
0005435808260	1925	Economy	21700.00
0005435808252	1925	Economy	21700.00
0005433407520	1925	Economy	21700.00
0005435808256	1925	Economy	21700.00
0005434610237	1925	Economy	21700.00
0005433407519	1925	Economy	21700.00
0005433407521	1925	Economy	21700.00
0005433407524	1925	Economy	21700.00
0005435808254	1925	Economy	21700.00
0005435808257	1925	Economy	21700.00
0005434610238	1925	Economy	21700.00
0005435808259	1925	Economy	21700.00
0005435808097	23107	Economy	23900.00
0005435808137	23107	Economy	23900.00
0005433407566	23107	Economy	23900.00
0005434610205	23107	Economy	21700.00
0005435808114	23107	Economy	21700.00
0005435808123	23107	Economy	21700.00
0005435808102	23107	Economy	21700.00
0005435808139	23107	Economy	21700.00
0005434610217	23107	Economy	21700.00
0005433407572	23107	Economy	21700.00
0005434610204	23107	Economy	21700.00
0005435808085	23107	Economy	21700.00
0005434610192	23107	Economy	21700.00
0005435808138	23107	Economy	21700.00
0005435808100	23107	Economy	21700.00
0005435808169	23107	Economy	21700.00
0005434610203	23107	Economy	21700.00
0005435808131	23107	Economy	21700.00
0005433407574	23107	Economy	21700.00
0005435808161	23107	Economy	21700.00
0005435808118	23107	Economy	21700.00
0005433407569	23107	Economy	21700.00
0005433407568	23107	Economy	21700.00
0005435808113	23107	Economy	21700.00
0005435808087	23107	Economy	21700.00
0005433407567	23107	Economy	21700.00
0005433407565	23107	Economy	21700.00
0005435808111	23107	Economy	21700.00
0005435808099	23107	Economy	21700.00
0005435808126	23107	Economy	21700.00
0005435808117	23107	Economy	21700.00
0005433407570	23107	Economy	21700.00
0005435808119	23107	Economy	21700.00
0005435808088	23107	Economy	21700.00
0005435808122	23107	Economy	21700.00
0005433407573	23107	Economy	21700.00
0005433407571	23107	Economy	21700.00
0005434610199	23107	Economy	21700.00
0005435808132	23107	Economy	21700.00
0005434503835	16722	Economy	7600.00
0005434503834	16722	Economy	7600.00
0005434503883	16722	Economy	7600.00
0005434504049	16722	Economy	6900.00
0005434504020	16722	Economy	6900.00
0005434503892	16722	Economy	6900.00
0005434503678	16722	Economy	6900.00
0005434503700	16722	Economy	6900.00
0005434503921	16722	Economy	6900.00
0005434503941	16722	Economy	6900.00
0005434503851	16722	Economy	6900.00
0005434503804	16722	Economy	6900.00
0005434503769	16722	Economy	6900.00
0005434503898	16722	Economy	6900.00
0005434504011	16722	Economy	6900.00
0005434503635	16722	Economy	6900.00
0005434503878	16722	Economy	6900.00
0005434503922	16722	Economy	6900.00
0005434504012	16722	Economy	6900.00
0005434503781	16722	Economy	6900.00
0005434503942	16722	Economy	6900.00
0005434503770	16722	Economy	6900.00
0005434503647	16722	Economy	6900.00
0005434503971	16722	Economy	6900.00
0005434503886	16722	Economy	6900.00
0005434504013	16722	Economy	6900.00
0005434503805	16722	Economy	6900.00
0005434503646	16722	Economy	6900.00
0005434503877	16722	Economy	6900.00
0005434503981	16722	Economy	6900.00
0005434504006	16722	Economy	6900.00
0005434503880	16722	Economy	6900.00
0005434504021	16722	Economy	6900.00
0005434503963	16722	Economy	6900.00
0005434503782	16722	Economy	6900.00
0005434503771	16722	Economy	6900.00
0005434504051	16722	Economy	6900.00
0005434503980	16722	Economy	6900.00
0005434503634	16722	Economy	6900.00
0005434504211	22931	Economy	7600.00
0005434504210	22931	Economy	7600.00
0005434504195	22931	Economy	7600.00
0005434504202	22931	Economy	7600.00
0005434504203	22931	Economy	6900.00
0005434504217	22931	Economy	6900.00
0005434504188	22931	Economy	6900.00
0005434504215	22931	Economy	6900.00
0005434504207	22931	Economy	6900.00
0005434504220	22931	Economy	6900.00
0005434504193	22931	Economy	6900.00
0005434504189	22931	Economy	6900.00
0005434504214	22931	Economy	6900.00
0005434504185	22931	Economy	6900.00
0005434504194	22931	Economy	6900.00
0005434504201	22931	Economy	6900.00
0005434504219	22931	Economy	6900.00
0005434504191	22931	Economy	6900.00
0005434504209	22931	Economy	6900.00
0005434504199	22931	Economy	6900.00
0005434504187	22931	Economy	6900.00
0005434504223	22931	Economy	6900.00
0005434504218	22931	Economy	6900.00
0005434504198	22931	Economy	6900.00
0005434504190	22931	Economy	6900.00
0005434504216	22931	Economy	6900.00
0005434504200	22931	Economy	6900.00
0005434504222	22931	Economy	6900.00
0005434504213	22931	Economy	6900.00
0005434504225	22931	Economy	6900.00
0005434504224	22931	Economy	6900.00
0005434504205	22931	Economy	6900.00
0005434504212	22931	Economy	6900.00
0005434504192	22931	Economy	6900.00
0005434504204	22931	Economy	6900.00
0005434504221	22931	Economy	6900.00
0005434504186	22931	Economy	6900.00
0005434504196	22931	Economy	6900.00
0005434504206	22931	Economy	6900.00
0005434504197	22931	Economy	6900.00
0005434504208	22931	Economy	6900.00
0005435078375	2200	Economy	7700.00
0005435078368	2200	Economy	7700.00
0005435078374	2200	Economy	7000.00
0005435078376	2200	Economy	7000.00
0005435078378	2200	Economy	7000.00
0005433266659	2200	Economy	7000.00
0005433266655	2200	Economy	7000.00
0005435078371	2200	Economy	7000.00
0005435078366	2200	Economy	7000.00
0005433266643	2200	Economy	7000.00
0005435078370	2200	Economy	7000.00
0005433266708	2200	Economy	7000.00
0005435078369	2200	Economy	7000.00
0005435078367	2200	Economy	7000.00
0005435078372	2200	Economy	7000.00
0005435078381	2200	Economy	7000.00
0005435078373	2200	Economy	7000.00
0005433266667	2200	Economy	7000.00
0005435078380	2200	Economy	7000.00
0005433266669	2200	Economy	7000.00
0005435078377	2200	Economy	7000.00
0005433266681	2200	Economy	7000.00
0005433266706	2200	Economy	7000.00
0005433266594	2200	Economy	7000.00
0005433266683	2200	Economy	7000.00
0005433266687	2200	Economy	7000.00
0005433266668	2200	Economy	7000.00
0005435078379	2200	Economy	7000.00
0005433266644	2200	Economy	7000.00
0005433266744	24357	Economy	7700.00
0005435078216	24357	Economy	7700.00
0005435078242	24357	Economy	7000.00
0005435078258	24357	Economy	7000.00
0005433266739	24357	Economy	7000.00
0005435078275	24357	Economy	7000.00
0005433266740	24357	Economy	7000.00
0005435078278	24357	Economy	7000.00
0005433266743	24357	Economy	7000.00
0005435078276	24357	Economy	7000.00
0005435078306	24357	Economy	7000.00
0005435078257	24357	Economy	7000.00
0005435078236	24357	Economy	7000.00
0005433266745	24357	Economy	7000.00
0005435078277	24357	Economy	7000.00
0005433266746	24357	Economy	7000.00
0005435078202	24357	Economy	7000.00
0005435078235	24357	Economy	7000.00
0005435078292	24357	Economy	7000.00
0005435078319	24357	Economy	7000.00
0005435078201	24357	Economy	7000.00
0005433266741	24357	Economy	7000.00
0005433266742	24357	Economy	7000.00
0005434988772	6633	Economy	10800.00
0005435464492	6633	Economy	10800.00
0005434988770	6633	Economy	9800.00
0005435464495	6633	Economy	9800.00
0005435803269	6633	Economy	9800.00
0005434988774	6633	Economy	9800.00
0005434988771	6633	Economy	9800.00
0005434988767	6633	Economy	9800.00
0005434988766	6633	Economy	9800.00
0005434988765	6633	Economy	9800.00
0005434988769	6633	Economy	9800.00
0005434988776	6633	Economy	9800.00
0005434988773	6633	Economy	9800.00
0005434988775	6633	Economy	9800.00
0005434988768	6633	Economy	9800.00
0005434988764	6633	Economy	9800.00
0005434988763	6633	Economy	9800.00
0005434988633	23623	Economy	9800.00
0005434988626	23623	Economy	9800.00
0005434988645	23623	Economy	9800.00
0005435464510	23623	Economy	9800.00
0005435803248	23623	Economy	9800.00
0005434988644	23623	Economy	9800.00
0005435464512	23623	Economy	9800.00
0005434988636	23623	Economy	9800.00
0005434988625	23623	Economy	9800.00
0005434988619	23623	Economy	9800.00
0005435464511	23623	Economy	9800.00
0005434988643	23623	Economy	9800.00
0005435803237	23623	Economy	9800.00
0005433450012	30484	Business	9900.00
0005433450008	30484	Business	9900.00
0005432383270	30484	Business	9900.00
0005433450011	30484	Business	9900.00
0005432383250	30484	Business	9900.00
0005432383240	30484	Business	9900.00
0005432383263	30484	Business	9900.00
0005432383251	30484	Business	9900.00
0005432383256	30484	Business	9900.00
0005433450013	30484	Economy	3300.00
0005432383254	30484	Economy	3300.00
0005432383272	30484	Economy	3300.00
0005432383267	30484	Economy	3300.00
0005432383278	30484	Economy	3300.00
0005433450027	30484	Economy	3300.00
0005433450015	30484	Economy	3600.00
0005432383275	30484	Economy	3600.00
0005432383253	30484	Economy	3600.00
0005433450023	30484	Economy	3600.00
0005433450026	30484	Economy	3300.00
0005432383258	30484	Economy	3300.00
0005433450022	30484	Economy	3300.00
0005432383249	30484	Economy	3300.00
0005433450018	30484	Economy	3300.00
0005432383246	30484	Economy	3300.00
0005432383262	30484	Economy	3300.00
0005432383245	30484	Economy	3300.00
0005432383257	30484	Economy	3300.00
0005432383269	30484	Economy	3300.00
0005433454880	30484	Economy	3300.00
0005432383273	30484	Economy	3300.00
0005432383271	30484	Economy	3300.00
0005432383261	30484	Economy	3300.00
0005432383274	30484	Economy	3300.00
0005432383247	30484	Economy	3300.00
0005432383242	30484	Economy	3300.00
0005433450016	30484	Economy	3300.00
0005432383241	30484	Economy	3300.00
0005432383244	30484	Economy	3300.00
0005433450014	30484	Economy	3300.00
0005432383265	30484	Economy	3300.00
0005433453766	30484	Economy	3300.00
0005432383255	30484	Economy	3300.00
0005432383243	30484	Economy	3300.00
0005432383276	30484	Economy	3300.00
0005433450021	30484	Economy	3300.00
0005433450010	30484	Economy	3300.00
0005433450025	30484	Economy	3300.00
0005432383260	30484	Economy	3300.00
0005433450020	30484	Economy	3300.00
0005432383259	30484	Economy	3300.00
0005433453767	30484	Economy	3300.00
0005432383268	30484	Economy	3300.00
0005432383266	30484	Economy	3300.00
0005432383252	30484	Economy	3300.00
0005433450028	30484	Economy	3300.00
0005432383264	30484	Economy	3300.00
0005432383238	30484	Economy	3300.00
0005432383277	30484	Economy	3300.00
0005433454879	30484	Economy	3300.00
0005433453765	30484	Economy	3300.00
0005432383248	30484	Economy	3300.00
0005432383239	30484	Economy	3300.00
0005433450017	30484	Economy	3300.00
0005433450009	30484	Economy	3300.00
0005433450024	30484	Economy	3300.00
0005433450019	30484	Economy	3300.00
0005432382729	31310	Business	9900.00
0005432382725	31310	Business	9900.00
0005432382923	31310	Business	9900.00
0005433449831	31310	Business	9900.00
0005433451603	31310	Business	9900.00
0005432382924	31310	Business	9900.00
0005433449862	31310	Business	9900.00
0005432382999	31310	Business	9900.00
0005433449796	31310	Economy	3300.00
0005432382808	31310	Economy	3300.00
0005433449866	31310	Economy	3300.00
0005433453749	31310	Economy	3300.00
0005432382796	31310	Economy	3300.00
0005432382893	31310	Economy	3300.00
0005433449763	31310	Economy	3300.00
0005433449840	31310	Economy	3300.00
0005432382822	31310	Economy	3600.00
0005432382941	31310	Economy	3600.00
0005433449889	31310	Economy	3600.00
0005433451606	31310	Economy	3600.00
0005432382891	31310	Economy	3600.00
0005433449804	31310	Economy	3300.00
0005432382939	31310	Economy	3300.00
0005432382858	31310	Economy	3300.00
0005432382850	31310	Economy	3300.00
0005433449838	31310	Economy	3300.00
0005433449871	31310	Economy	3300.00
0005432382821	31310	Economy	3300.00
0005433449888	31310	Economy	3300.00
0005433451602	31310	Economy	3300.00
0005432382853	31310	Economy	3300.00
0005433449826	31310	Economy	3300.00
0005433453752	31310	Economy	3300.00
0005433449875	31310	Economy	3300.00
0005433449825	31310	Economy	3300.00
0005432382834	31310	Economy	3300.00
0005433453747	31310	Economy	3300.00
0005433451607	31310	Economy	3300.00
0005432382927	31310	Economy	3300.00
0005432382775	31310	Economy	3300.00
0005433449850	31310	Economy	3300.00
0005433453748	31310	Economy	3300.00
0005433449872	31310	Economy	3300.00
0005432383011	31310	Economy	3300.00
0005432382894	31310	Economy	3300.00
0005432382864	31310	Economy	3300.00
0005432382583	31310	Economy	3300.00
0005432382724	31310	Economy	3300.00
0005432382728	31310	Economy	3300.00
0005433449865	31310	Economy	3300.00
0005433449883	31310	Economy	3300.00
0005432382809	31310	Economy	3300.00
0005433449874	31310	Economy	3300.00
0005433449922	31310	Economy	3300.00
0005432382849	31310	Economy	3300.00
0005433453751	31310	Economy	3300.00
0005432382854	31310	Economy	3300.00
0005432382754	31310	Economy	3300.00
0005433449837	31310	Economy	3300.00
0005433449805	31310	Economy	3300.00
0005432382866	31310	Economy	3300.00
0005433449887	31310	Economy	3300.00
0005433449803	31310	Economy	3300.00
0005432382582	31310	Economy	3300.00
0005433449882	31310	Economy	3300.00
0005432382823	31310	Economy	3300.00
0005433449836	31310	Economy	3300.00
0005432382843	31310	Economy	3300.00
0005432382842	31310	Economy	3300.00
0005433449867	31310	Economy	3300.00
0005432382966	31310	Economy	3300.00
0005433449835	31310	Economy	3300.00
0005432382807	31310	Economy	3300.00
0005435304127	10785	Economy	17100.00
0005433126807	10785	Economy	17100.00
0005435299722	10785	Economy	15600.00
0005435304121	10785	Economy	15600.00
0005433131664	10785	Economy	15600.00
0005435304118	10785	Economy	15600.00
0005435304143	10785	Economy	15600.00
0005435304117	10785	Economy	15600.00
0005435304120	10785	Economy	15600.00
0005435304144	10785	Economy	15600.00
0005435304131	10785	Economy	15600.00
0005433126813	10785	Economy	15600.00
0005433126808	10785	Economy	15600.00
0005433131665	10785	Economy	15600.00
0005433126857	29708	Economy	15600.00
0005435299789	29708	Economy	15600.00
0005435299792	29708	Economy	15600.00
0005435302210	29708	Economy	15600.00
0005435302211	29708	Economy	15600.00
0005433129291	29708	Economy	15600.00
0005433129288	29708	Economy	15600.00
0005433129289	29708	Economy	15600.00
0005433129287	29708	Economy	15600.00
0005435302213	29708	Economy	15600.00
0005433129290	29708	Economy	15600.00
0005435299791	29708	Economy	15600.00
0005435302215	29708	Economy	15600.00
0005433126856	29708	Economy	15600.00
0005433126859	29708	Economy	15600.00
0005433126858	29708	Economy	15600.00
0005435299790	29708	Economy	15600.00
0005433126860	29708	Economy	15600.00
0005435302214	29708	Economy	15600.00
0005435299788	29708	Economy	15600.00
0005435302212	29708	Economy	15600.00
0005432264480	2432	Economy	17200.00
0005434287343	2432	Economy	17200.00
0005434287334	2432	Economy	15700.00
0005434287337	2432	Economy	15700.00
0005434287332	2432	Economy	15700.00
0005432264479	2432	Economy	15700.00
0005434287331	2432	Economy	15700.00
0005434287327	2432	Economy	15700.00
0005434287328	2432	Economy	15700.00
0005434287338	2432	Economy	15700.00
0005434287333	2432	Economy	15700.00
0005434287342	2432	Economy	15700.00
0005433109960	2432	Economy	15700.00
0005434287325	2432	Economy	15700.00
0005433110012	2432	Economy	15700.00
0005433109937	2432	Economy	15700.00
0005434287326	2432	Economy	15700.00
0005433110035	2432	Economy	15700.00
0005434287346	2432	Economy	15700.00
0005433109938	2432	Economy	15700.00
0005433109972	2432	Economy	15700.00
0005434287341	2432	Economy	15700.00
0005432264481	2432	Economy	15700.00
0005434287329	2432	Economy	15700.00
0005434287330	2432	Economy	15700.00
0005433110023	2432	Economy	15700.00
0005434287344	2432	Economy	15700.00
0005433109936	2432	Economy	15700.00
0005434287340	2432	Economy	15700.00
0005433109995	2432	Economy	15700.00
0005433109944	2432	Economy	15700.00
0005434287335	2432	Economy	15700.00
0005433110036	2432	Economy	15700.00
0005434287345	2432	Economy	15700.00
0005434287339	2432	Economy	15700.00
0005433109961	2432	Economy	15700.00
0005433109978	2432	Economy	15700.00
0005434287336	2432	Economy	15700.00
0005433110073	26845	Economy	17200.00
0005433110084	26845	Economy	17200.00
0005434287048	26845	Economy	17200.00
0005434287132	26845	Economy	15700.00
0005433110085	26845	Economy	15700.00
0005434287134	26845	Economy	15700.00
0005434287135	26845	Economy	15700.00
0005434287062	26845	Economy	15700.00
0005434287131	26845	Economy	15700.00
0005433110078	26845	Economy	15700.00
0005434287098	26845	Economy	15700.00
0005434287163	26845	Economy	15700.00
0005434287159	26845	Economy	15700.00
0005434287158	26845	Economy	15700.00
0005434287111	26845	Economy	15700.00
0005434287166	26845	Economy	15700.00
0005434287065	26845	Economy	15700.00
0005434287121	26845	Economy	15700.00
0005433110077	26845	Economy	15700.00
0005433110081	26845	Economy	15700.00
0005434287198	26845	Economy	15700.00
0005433110082	26845	Economy	15700.00
0005434287122	26845	Economy	15700.00
0005434287078	26845	Economy	15700.00
0005433110076	26845	Economy	15700.00
0005434287164	26845	Economy	15700.00
0005433110075	26845	Economy	15700.00
0005434287080	26845	Economy	15700.00
0005434287081	26845	Economy	15700.00
0005433110080	26845	Economy	15700.00
0005434287116	26845	Economy	15700.00
0005433110079	26845	Economy	15700.00
0005434287082	26845	Economy	15700.00
0005434287133	26845	Economy	15700.00
0005433110083	26845	Economy	15700.00
0005433110074	26845	Economy	15700.00
0005434269085	25498	Economy	22800.00
0005435856213	25498	Economy	22800.00
0005435856215	25498	Economy	22800.00
0005434272173	25498	Economy	22800.00
0005435856214	25498	Economy	22800.00
0005435854051	26663	Economy	25000.00
0005435856176	26663	Economy	25000.00
0005434272196	26663	Economy	22800.00
0005435856169	26663	Economy	22800.00
0005434272195	26663	Economy	22800.00
0005434272197	26663	Economy	22800.00
0005434273080	26663	Economy	22800.00
0005433650656	7154	Business	89800.00
0005433650688	7154	Business	89800.00
0005433650686	7154	Business	89800.00
0005433650646	7154	Business	89800.00
0005433650679	7154	Business	89800.00
0005433650687	7154	Business	89800.00
0005433650641	7154	Business	89800.00
0005433650651	7154	Business	89800.00
0005433650666	7154	Business	89800.00
0005433650689	7154	Business	89800.00
0005435263562	7154	Economy	29900.00
0005435263550	7154	Economy	29900.00
0005433650672	7154	Economy	29900.00
0005433650652	7154	Economy	29900.00
0005433650650	7154	Economy	29900.00
0005433650659	7154	Economy	29900.00
0005435263576	7154	Economy	29900.00
0005433650671	7154	Economy	32900.00
0005435263592	7154	Economy	32900.00
0005433650669	7154	Economy	32900.00
0005433650678	7154	Economy	32900.00
0005433650674	7154	Economy	29900.00
0005433650647	7154	Economy	29900.00
0005435263568	7154	Economy	29900.00
0005433650676	7154	Economy	29900.00
0005433650682	7154	Economy	29900.00
0005435263541	7154	Economy	29900.00
0005433650664	7154	Economy	29900.00
0005433650685	7154	Economy	29900.00
0005435263536	7154	Economy	29900.00
0005433650643	7154	Economy	29900.00
0005433650668	7154	Economy	29900.00
0005433650663	7154	Economy	29900.00
0005435263540	7154	Economy	29900.00
0005433650673	7154	Economy	29900.00
0005435263563	7154	Economy	29900.00
0005433650667	7154	Economy	29900.00
0005435263574	7154	Economy	29900.00
0005435263547	7154	Economy	29900.00
0005433650684	7154	Economy	29900.00
0005433650675	7154	Economy	29900.00
0005435263566	7154	Economy	29900.00
0005433650662	7154	Economy	29900.00
0005433650660	7154	Economy	29900.00
0005433650644	7154	Economy	29900.00
0005435263549	7154	Economy	29900.00
0005433650653	7154	Economy	29900.00
0005433650657	7154	Economy	29900.00
0005435263545	7154	Economy	29900.00
0005435263591	7154	Economy	29900.00
0005433650661	7154	Economy	29900.00
0005433650645	7154	Economy	29900.00
0005433650677	7154	Economy	29900.00
0005433650683	7154	Economy	29900.00
0005433650649	7154	Economy	29900.00
0005435263548	7154	Economy	29900.00
0005433650680	7154	Economy	29900.00
0005435263546	7154	Economy	29900.00
0005435263539	7154	Economy	29900.00
0005433650654	7154	Economy	29900.00
0005435263587	7154	Economy	29900.00
0005433650658	7154	Economy	29900.00
0005435263575	7154	Economy	29900.00
0005435263558	7154	Economy	29900.00
0005433650639	7154	Economy	29900.00
0005433650655	7154	Economy	29900.00
0005435263585	7154	Economy	29900.00
0005433650648	7154	Economy	29900.00
0005435263586	7154	Economy	29900.00
0005433650642	7154	Economy	29900.00
0005433650670	7154	Economy	29900.00
0005433650681	7154	Economy	29900.00
0005433650640	7154	Economy	29900.00
0005435263542	7154	Economy	29900.00
0005433650665	7154	Economy	29900.00
0005435263551	7154	Economy	29900.00
0005433868530	4768	Economy	19400.00
0005435860461	4768	Economy	19400.00
0005433868529	4768	Economy	19400.00
0005433868527	4768	Economy	17600.00
0005433868518	4768	Economy	17600.00
0005433868513	4768	Economy	17600.00
0005433868522	4768	Economy	17600.00
0005433868545	4768	Economy	17600.00
0005433868535	4768	Economy	17600.00
0005433868514	4768	Economy	17600.00
0005433868539	4768	Economy	17600.00
0005433868533	4768	Economy	17600.00
0005433868534	4768	Economy	17600.00
0005433868550	4768	Economy	17600.00
0005433868537	4768	Economy	17600.00
0005433868526	4768	Economy	17600.00
0005433868517	4768	Economy	17600.00
0005433868515	4768	Economy	17600.00
0005433868540	4768	Economy	17600.00
0005433868549	4768	Economy	17600.00
0005433868542	4768	Economy	17600.00
0005433868528	4768	Economy	17600.00
0005433868536	4768	Economy	17600.00
0005433868524	4768	Economy	17600.00
0005433868516	4768	Economy	17600.00
0005435860460	4768	Economy	17600.00
0005433868523	4768	Economy	17600.00
0005433868544	4768	Economy	17600.00
0005433868520	4768	Economy	17600.00
0005433868546	4768	Economy	17600.00
0005433868547	4768	Economy	17600.00
0005433868538	4768	Economy	17600.00
0005433868543	4768	Economy	17600.00
0005433868525	4768	Economy	17600.00
0005433868548	4768	Economy	17600.00
0005433868551	4768	Economy	17600.00
0005433868541	4768	Economy	17600.00
0005433868521	4768	Economy	17600.00
0005433868532	4768	Economy	17600.00
0005433868519	4768	Economy	17600.00
0005435860453	4768	Economy	17600.00
0005433868531	4768	Economy	17600.00
0005435860454	4768	Economy	17600.00
0005433868230	32600	Economy	19400.00
0005433868018	32600	Economy	19400.00
0005433868134	32600	Economy	19400.00
0005433868014	32600	Economy	17600.00
0005433868271	32600	Economy	17600.00
0005433868006	32600	Economy	17600.00
0005433868110	32600	Economy	17600.00
0005433867995	32600	Economy	17600.00
0005433868149	32600	Economy	17600.00
0005433868130	32600	Economy	17600.00
0005433868143	32600	Economy	17600.00
0005433868062	32600	Economy	17600.00
0005433868229	32600	Economy	17600.00
0005433867990	32600	Economy	17600.00
0005433868142	32600	Economy	17600.00
0005433868154	32600	Economy	17600.00
0005435860495	32600	Economy	17600.00
0005433868135	32600	Economy	17600.00
0005433868111	32600	Economy	17600.00
0005433868054	32600	Economy	17600.00
0005433868109	32600	Economy	17600.00
0005433868333	32600	Economy	17600.00
0005433868334	32600	Economy	17600.00
0005433868087	32600	Economy	17600.00
0005435860499	32600	Economy	17600.00
0005433868296	32600	Economy	17600.00
0005433868040	32600	Economy	17600.00
0005433867857	32600	Economy	17600.00
0005433868225	32600	Economy	17600.00
0005433868031	32600	Economy	17600.00
0005433868165	32600	Economy	17600.00
0005433868210	32600	Economy	17600.00
0005433868032	32600	Economy	17600.00
0005435860494	32600	Economy	17600.00
0005433867945	32600	Economy	17600.00
0005433868272	32600	Economy	17600.00
0005435860496	32600	Economy	17600.00
0005433868066	32600	Economy	17600.00
0005433868252	32600	Economy	17600.00
0005433868160	32600	Economy	17600.00
0005433868108	32600	Economy	17600.00
0005435860497	32600	Economy	17600.00
0005433868112	32600	Economy	17600.00
0005433868194	32600	Economy	17600.00
0005435860498	32600	Economy	17600.00
0005433868027	32600	Economy	17600.00
0005433868192	32600	Economy	17600.00
0005433868226	32600	Economy	17600.00
0005433868116	32600	Economy	17600.00
0005434663439	3434	Economy	24800.00
0005434663443	3434	Economy	24800.00
0005434461651	3434	Economy	22600.00
0005434663442	3434	Economy	22600.00
0005434663431	3434	Economy	22600.00
0005435911444	3434	Economy	22600.00
0005434663438	3434	Economy	22600.00
0005434460509	3434	Economy	22600.00
0005435911406	3434	Economy	22600.00
0005434663435	3434	Economy	22600.00
0005435911432	3434	Economy	22600.00
0005434663437	3434	Economy	22600.00
0005434663440	3434	Economy	22600.00
0005435911404	3434	Economy	22600.00
0005435911398	3434	Economy	22600.00
0005435911410	3434	Economy	22600.00
0005435911411	3434	Economy	22600.00
0005434663436	3434	Economy	22600.00
0005434663430	3434	Economy	22600.00
0005434663433	3434	Economy	22600.00
0005435911416	3434	Economy	22600.00
0005435911405	3434	Economy	22600.00
0005435911418	3434	Economy	22600.00
0005435911390	3434	Economy	22600.00
0005434461652	3434	Economy	22600.00
0005434663441	3434	Economy	22600.00
0005434460510	3434	Economy	22600.00
0005435911443	3434	Economy	22600.00
0005434663434	3434	Economy	22600.00
0005435911381	3434	Economy	22600.00
0005435911417	3434	Economy	22600.00
0005435911387	3434	Economy	22600.00
0005434663432	3434	Economy	22600.00
0005434663334	12496	Economy	24800.00
0005434663320	12496	Economy	22600.00
0005435911466	12496	Economy	22600.00
0005435911465	12496	Economy	22600.00
0005435911472	12496	Economy	22600.00
0005435911467	12496	Economy	22600.00
0005434663319	12496	Economy	22600.00
0005435911470	12496	Economy	22600.00
0005435911468	12496	Economy	22600.00
0005434663302	12496	Economy	22600.00
0005435911464	12496	Economy	22600.00
0005435911471	12496	Economy	22600.00
0005434663335	12496	Economy	22600.00
0005435911469	12496	Economy	22600.00
0005434663359	12496	Economy	22600.00
0005433868230	14524	Economy	18500.00
0005433867857	14524	Economy	18500.00
0005433868252	14524	Economy	18500.00
0005435860495	14524	Economy	18500.00
0005433868229	14524	Economy	16800.00
0005433868066	14524	Economy	16800.00
0005433868333	14524	Economy	16800.00
0005435860497	14524	Economy	16800.00
0005433867995	14524	Economy	16800.00
0005433868210	14524	Economy	16800.00
0005433868062	14524	Economy	16800.00
0005433868116	14524	Economy	16800.00
0005433868087	14524	Economy	16800.00
0005433868194	14524	Economy	16800.00
0005433868027	14524	Economy	16800.00
0005433868014	14524	Economy	16800.00
0005433868134	14524	Economy	16800.00
0005435860496	14524	Economy	16800.00
0005433868226	14524	Economy	16800.00
0005433867990	14524	Economy	16800.00
0005433868142	14524	Economy	16800.00
0005433868018	14524	Economy	16800.00
0005435860498	14524	Economy	16800.00
0005433868112	14524	Economy	16800.00
0005433868271	14524	Economy	16800.00
0005433868040	14524	Economy	16800.00
0005433868054	14524	Economy	16800.00
0005433867945	14524	Economy	16800.00
0005433868143	14524	Economy	16800.00
0005433868108	14524	Economy	16800.00
0005433868111	14524	Economy	16800.00
0005433868149	14524	Economy	16800.00
0005435860499	14524	Economy	16800.00
0005435860494	14524	Economy	16800.00
0005433868165	14524	Economy	16800.00
0005433868225	14524	Economy	16800.00
0005433868032	14524	Economy	16800.00
0005433868109	14524	Economy	16800.00
0005433868160	14524	Economy	16800.00
0005433868130	14524	Economy	16800.00
0005433868296	14524	Economy	16800.00
0005433868272	14524	Economy	16800.00
0005433868154	14524	Economy	16800.00
0005433868006	14524	Economy	16800.00
0005433868192	14524	Economy	16800.00
0005433868031	14524	Economy	16800.00
0005433868135	14524	Economy	16800.00
0005433868110	14524	Economy	16800.00
0005433868334	14524	Economy	16800.00
0005433868508	32702	Economy	18500.00
0005433868502	32702	Economy	18500.00
0005433868484	32702	Economy	18500.00
0005433868491	32702	Economy	18500.00
0005433868489	32702	Economy	16800.00
0005433868501	32702	Economy	16800.00
0005433868497	32702	Economy	16800.00
0005433868499	32702	Economy	16800.00
0005435860464	32702	Economy	16800.00
0005433868482	32702	Economy	16800.00
0005433868486	32702	Economy	16800.00
0005433868475	32702	Economy	16800.00
0005435860459	32702	Economy	16800.00
0005433868500	32702	Economy	16800.00
0005433868473	32702	Economy	16800.00
0005433868504	32702	Economy	16800.00
0005433868507	32702	Economy	16800.00
0005433868478	32702	Economy	16800.00
0005433868485	32702	Economy	16800.00
0005433868479	32702	Economy	16800.00
0005433868483	32702	Economy	16800.00
0005435860465	32702	Economy	16800.00
0005433868509	32702	Economy	16800.00
0005433868490	32702	Economy	16800.00
0005433868511	32702	Economy	16800.00
0005435860467	32702	Economy	16800.00
0005433868512	32702	Economy	16800.00
0005433868510	32702	Economy	16800.00
0005433868503	32702	Economy	16800.00
0005433868494	32702	Economy	16800.00
0005433868477	32702	Economy	16800.00
0005433868476	32702	Economy	16800.00
0005433868492	32702	Economy	16800.00
0005433868474	32702	Economy	16800.00
0005433868505	32702	Economy	16800.00
0005433868481	32702	Economy	16800.00
0005435860463	32702	Economy	16800.00
0005433868495	32702	Economy	16800.00
0005433868487	32702	Economy	16800.00
0005433868498	32702	Economy	16800.00
0005433868496	32702	Economy	16800.00
0005433868506	32702	Economy	16800.00
0005433868488	32702	Economy	16800.00
0005433868493	32702	Economy	16800.00
0005433868480	32702	Economy	16800.00
0005432799262	12119	Economy	4900.00
0005432799326	12119	Economy	4900.00
0005432799325	12119	Economy	4900.00
0005432799138	12119	Economy	4400.00
0005432799404	12119	Economy	4400.00
0005432799324	12119	Economy	4400.00
0005432799296	12119	Economy	4400.00
0005432799297	12119	Economy	4400.00
0005432799278	12119	Economy	4400.00
0005432799189	12119	Economy	4400.00
0005432799253	12119	Economy	4400.00
0005432799348	12119	Economy	4400.00
0005432799336	12119	Economy	4400.00
0005432799163	12119	Economy	4400.00
0005432799172	12119	Economy	4400.00
0005432799328	12119	Economy	4400.00
0005432799292	12119	Economy	4400.00
0005432799131	12119	Economy	4400.00
0005432799272	12119	Economy	4400.00
0005432799293	12119	Economy	4400.00
0005432799265	12119	Economy	4400.00
0005432799277	12119	Economy	4400.00
0005432799405	12119	Economy	4400.00
0005432799337	12119	Economy	4400.00
0005432799264	12119	Economy	4400.00
0005432799155	12119	Economy	4400.00
0005432799316	12119	Economy	4400.00
0005432799271	12119	Economy	4400.00
0005432799173	12119	Economy	4400.00
0005432799254	12119	Economy	4400.00
0005432799132	12119	Economy	4400.00
0005432799225	12119	Economy	4400.00
0005432799238	12119	Economy	4400.00
0005432799248	12119	Economy	4400.00
0005432799481	14811	Economy	4900.00
0005432799487	14811	Economy	4900.00
0005432799498	14811	Economy	4900.00
0005432799501	14811	Economy	4400.00
0005432799486	14811	Economy	4400.00
0005432799478	14811	Economy	4400.00
0005432799494	14811	Economy	4400.00
0005432799489	14811	Economy	4400.00
0005432799497	14811	Economy	4400.00
0005432799473	14811	Economy	4400.00
0005432799499	14811	Economy	4400.00
0005432799491	14811	Economy	4400.00
0005432799490	14811	Economy	4400.00
0005432799482	14811	Economy	4400.00
0005432799477	14811	Economy	4400.00
0005432799483	14811	Economy	4400.00
0005432799475	14811	Economy	4400.00
0005432799496	14811	Economy	4400.00
0005432799476	14811	Economy	4400.00
0005432799484	14811	Economy	4400.00
0005432799488	14811	Economy	4400.00
0005432799492	14811	Economy	4400.00
0005432799493	14811	Economy	4400.00
0005432799500	14811	Economy	4400.00
0005432799495	14811	Economy	4400.00
0005432799480	14811	Economy	4400.00
0005432799485	14811	Economy	4400.00
0005432799479	14811	Economy	4400.00
0005432799474	14811	Economy	4400.00
0005434407920	7035	Business	49100.00
0005434407900	7035	Business	49100.00
0005435310972	7035	Business	49100.00
0005434299602	7035	Business	49100.00
0005434407889	7035	Business	49100.00
0005435310973	7035	Business	49100.00
0005435293182	7035	Business	49100.00
0005435310968	7035	Business	49100.00
0005434407887	7035	Business	49100.00
0005434407923	7035	Business	49100.00
0005434407882	7035	Business	49100.00
0005435293183	7035	Business	49100.00
0005434299618	7035	Economy	16400.00
0005432153956	7035	Economy	16400.00
0005434407902	7035	Economy	16400.00
0005434407904	7035	Economy	16400.00
0005435310956	7035	Economy	16400.00
0005435310944	7035	Economy	16400.00
0005434407911	7035	Economy	16400.00
0005434407919	7035	Economy	16400.00
0005434299605	7035	Economy	16400.00
0005434299606	7035	Economy	16400.00
0005435293184	7035	Economy	16400.00
0005434407876	7035	Economy	16400.00
0005434407927	7035	Economy	16400.00
0005432153953	7035	Economy	16400.00
0005434299621	7035	Economy	16400.00
0005435310969	7035	Economy	16400.00
0005434407922	7035	Economy	16400.00
0005435310963	7035	Economy	16400.00
0005434407885	7035	Economy	16400.00
0005435293175	7035	Economy	16400.00
0005434299610	7035	Economy	16400.00
0005435293179	7035	Economy	16400.00
0005434299615	7035	Economy	16400.00
0005434299614	7035	Economy	16400.00
0005435310970	7035	Economy	16400.00
0005434299600	7035	Economy	16400.00
0005432108255	7035	Economy	16400.00
0005434407897	7035	Economy	16400.00
0005432153952	7035	Economy	16400.00
0005434407873	7035	Economy	16400.00
0005434407866	7035	Economy	16400.00
0005435293174	7035	Economy	16400.00
0005434407881	7035	Economy	16400.00
0005435310980	7035	Economy	16400.00
0005434299619	7035	Economy	16400.00
0005434407867	7035	Economy	16400.00
0005434407891	7035	Economy	18000.00
0005434407907	7035	Economy	18000.00
0005434407868	7035	Economy	18000.00
0005435293169	7035	Economy	18000.00
0005434407888	7035	Economy	18000.00
0005434407926	7035	Economy	18000.00
0005434407895	7035	Economy	16400.00
0005434299607	7035	Economy	16400.00
0005434407929	7035	Economy	16400.00
0005434407893	7035	Economy	16400.00
0005432108256	7035	Economy	16400.00
0005434407890	7035	Economy	16400.00
0005434299599	7035	Economy	16400.00
0005432153954	7035	Economy	16400.00
0005434407898	7035	Economy	16400.00
0005435310899	7035	Economy	16400.00
0005434407925	7035	Economy	16400.00
0005434407918	7035	Economy	16400.00
0005434407896	7035	Economy	16400.00
0005434407871	7035	Economy	16400.00
0005434407894	7035	Economy	16400.00
0005435293148	7035	Economy	16400.00
0005434407879	7035	Economy	16400.00
0005434407870	7035	Economy	16400.00
0005434407909	7035	Economy	16400.00
0005434407903	7035	Economy	16400.00
0005434407910	7035	Economy	16400.00
0005432108254	7035	Economy	16400.00
0005434299611	7035	Economy	16400.00
0005434299620	7035	Economy	16400.00
0005434407916	7035	Economy	16400.00
0005435293168	7035	Economy	16400.00
0005434299617	7035	Economy	16400.00
0005435293191	7035	Economy	16400.00
0005434407913	7035	Economy	16400.00
0005434407912	7035	Economy	16400.00
0005434407883	7035	Economy	16400.00
0005434407899	7035	Economy	16400.00
0005435293149	7035	Economy	16400.00
0005434407928	7035	Economy	16400.00
0005434407884	7035	Economy	16400.00
0005432153949	7035	Economy	16400.00
0005434299601	7035	Economy	16400.00
0005432153955	7035	Economy	16400.00
0005434407877	7035	Economy	16400.00
0005434299613	7035	Economy	16400.00
0005434407875	7035	Economy	16400.00
0005434407917	7035	Economy	16400.00
0005434407905	7035	Economy	16400.00
0005434407924	7035	Economy	16400.00
0005434407869	7035	Economy	16400.00
0005435310958	7035	Economy	16400.00
0005434407874	7035	Economy	16400.00
0005434407880	7035	Economy	16400.00
0005434299603	7035	Economy	16400.00
0005435310959	7035	Economy	16400.00
0005434299608	7035	Economy	16400.00
0005432153951	7035	Economy	16400.00
0005432153950	7035	Economy	16400.00
0005434407886	7035	Economy	16400.00
0005435310935	7035	Economy	16400.00
0005434407878	7035	Economy	16400.00
0005434299604	7035	Economy	16400.00
0005434299616	7035	Economy	16400.00
0005435310966	7035	Economy	16400.00
0005434407901	7035	Economy	16400.00
0005434407914	7035	Economy	16400.00
0005434407915	7035	Economy	16400.00
0005434407908	7035	Economy	16400.00
0005434299609	7035	Economy	16400.00
0005434407892	7035	Economy	16400.00
0005434407872	7035	Economy	16400.00
0005434407906	7035	Economy	16400.00
0005434407921	7035	Economy	16400.00
0005434299612	7035	Economy	16400.00
0005434299448	26906	Business	49100.00
0005435293283	26906	Business	49100.00
0005432058387	26906	Business	49100.00
0005434407084	26906	Business	49100.00
0005434407529	26906	Business	49100.00
0005434299410	26906	Business	49100.00
0005435293282	26906	Business	49100.00
0005435293284	26906	Business	49100.00
0005435311084	26906	Business	49100.00
0005434407030	26906	Business	49100.00
0005434407380	26906	Business	49100.00
0005435293277	26906	Economy	16400.00
0005435311085	26906	Economy	16400.00
0005434407082	26906	Economy	16400.00
0005434299457	26906	Economy	16400.00
0005435293274	26906	Economy	16400.00
0005434299449	26906	Economy	16400.00
0005434407214	26906	Economy	16400.00
0005434299418	26906	Economy	16400.00
0005434406922	26906	Economy	16400.00
0005434407331	26906	Economy	16400.00
0005434407642	26906	Economy	16400.00
0005434407528	26906	Economy	16400.00
0005434407354	26906	Economy	16400.00
0005434299402	26906	Economy	16400.00
0005434407220	26906	Economy	16400.00
0005434407496	26906	Economy	16400.00
0005435293280	26906	Economy	16400.00
0005434407091	26906	Economy	16400.00
0005434407157	26906	Economy	16400.00
0005434299523	26906	Economy	16400.00
0005434299435	26906	Economy	16400.00
0005434407420	26906	Economy	16400.00
0005434299417	26906	Economy	16400.00
0005434407310	26906	Economy	16400.00
0005435293276	26906	Economy	16400.00
0005434407129	26906	Economy	16400.00
0005434407034	26906	Economy	16400.00
0005434407032	26906	Economy	16400.00
0005434407035	26906	Economy	16400.00
0005434299395	26906	Economy	16400.00
0005434407470	26906	Economy	16400.00
0005435311083	26906	Economy	16400.00
0005434299386	26906	Economy	16400.00
0005435293279	26906	Economy	16400.00
0005434407104	26906	Economy	16400.00
0005435311078	26906	Economy	16400.00
0005435311081	26906	Economy	18000.00
0005434299385	26906	Economy	18000.00
0005434299447	26906	Economy	18000.00
0005435293285	26906	Economy	18000.00
0005434299430	26906	Economy	18000.00
0005434407258	26906	Economy	18000.00
0005434407083	26906	Economy	16400.00
0005434407483	26906	Economy	16400.00
0005434407163	26906	Economy	16400.00
0005434407092	26906	Economy	16400.00
0005434407330	26906	Economy	16400.00
0005434407308	26906	Economy	16400.00
0005434407010	26906	Economy	16400.00
0005434299482	26906	Economy	16400.00
0005434407139	26906	Economy	16400.00
0005434407158	26906	Economy	16400.00
0005434407289	26906	Economy	16400.00
0005434407254	26906	Economy	16400.00
0005435293275	26906	Economy	16400.00
0005434407197	26906	Economy	16400.00
0005434407286	26906	Economy	16400.00
0005434407218	26906	Economy	16400.00
0005435311082	26906	Economy	16400.00
0005432058386	26906	Economy	16400.00
0005434407088	26906	Economy	16400.00
0005434407641	26906	Economy	16400.00
0005434407215	26906	Economy	16400.00
0005434407316	26906	Economy	16400.00
0005434299483	26906	Economy	16400.00
0005434299422	26906	Economy	16400.00
0005434299440	26906	Economy	16400.00
0005434299466	26906	Economy	16400.00
0005434407119	26906	Economy	16400.00
0005434407209	26906	Economy	16400.00
0005434407219	26906	Economy	16400.00
0005432058388	26906	Economy	16400.00
0005434407297	26906	Economy	16400.00
0005434407530	26906	Economy	16400.00
0005434299500	26906	Economy	16400.00
0005434299450	26906	Economy	16400.00
0005434407309	26906	Economy	16400.00
0005434299420	26906	Economy	16400.00
0005435311080	26906	Economy	16400.00
0005434407643	26906	Economy	16400.00
0005434407332	26906	Economy	16400.00
0005434407123	26906	Economy	16400.00
0005434407140	26906	Economy	16400.00
0005435293281	26906	Economy	16400.00
0005435293278	26906	Economy	16400.00
0005434407395	26906	Economy	16400.00
0005435311087	26906	Economy	16400.00
0005435311079	26906	Economy	16400.00
0005434407374	26906	Economy	16400.00
0005434407375	26906	Economy	16400.00
0005434407031	26906	Economy	16400.00
0005434299441	26906	Economy	16400.00
0005434407206	26906	Economy	16400.00
0005434407436	26906	Economy	16400.00
0005434407359	26906	Economy	16400.00
0005434407307	26906	Economy	16400.00
0005434406921	26906	Economy	16400.00
0005434407120	26906	Economy	16400.00
0005435311086	26906	Economy	16400.00
0005434407257	26906	Economy	16400.00
0005434299463	26906	Economy	16400.00
0005434407009	26906	Economy	16400.00
0005434407290	26906	Economy	16400.00
0005434407333	26906	Economy	16400.00
0005434407164	26906	Economy	16400.00
0005432604425	6484	Economy	16500.00
0005432604416	6484	Economy	16500.00
0005432604435	6484	Economy	16500.00
0005432604437	6484	Economy	16500.00
0005432604450	6484	Economy	15000.00
0005432604417	6484	Economy	15000.00
0005432604452	6484	Economy	15000.00
0005432604428	6484	Economy	15000.00
0005432604429	6484	Economy	15000.00
0005432604446	6484	Economy	15000.00
0005432604418	6484	Economy	15000.00
0005432604449	6484	Economy	15000.00
0005432604451	6484	Economy	15000.00
0005432604413	6484	Economy	15000.00
0005432604444	6484	Economy	15000.00
0005432604422	6484	Economy	15000.00
0005432604445	6484	Economy	15000.00
0005432604439	6484	Economy	15000.00
0005432604414	6484	Economy	15000.00
0005432604440	6484	Economy	15000.00
0005432604448	6484	Economy	15000.00
0005432604427	6484	Economy	15000.00
0005432604412	6484	Economy	15000.00
0005432604441	6484	Economy	15000.00
0005432604438	6484	Economy	15000.00
0005432604420	6484	Economy	15000.00
0005435218108	6484	Economy	15000.00
0005432604415	6484	Economy	15000.00
0005432604419	6484	Economy	15000.00
0005432604426	6484	Economy	15000.00
0005432604436	6484	Economy	15000.00
0005432604421	6484	Economy	15000.00
0005432604442	6484	Economy	15000.00
0005432604432	6484	Economy	15000.00
0005432604423	6484	Economy	15000.00
0005432604424	6484	Economy	15000.00
0005432604430	6484	Economy	15000.00
0005435218109	6484	Economy	15000.00
0005432604431	6484	Economy	15000.00
0005432604434	6484	Economy	15000.00
0005432604443	6484	Economy	15000.00
0005432604433	6484	Economy	15000.00
0005432604447	6484	Economy	15000.00
0005432604029	21357	Economy	16500.00
0005432604074	21357	Economy	16500.00
0005432603960	21357	Economy	16500.00
0005432604146	21357	Economy	16500.00
0005432604055	21357	Economy	15000.00
0005432603955	21357	Economy	15000.00
0005432604032	21357	Economy	15000.00
0005432603974	21357	Economy	15000.00
0005432603973	21357	Economy	15000.00
0005432604041	21357	Economy	15000.00
0005432604143	21357	Economy	15000.00
0005432604056	21357	Economy	15000.00
0005432603959	21357	Economy	15000.00
0005432604042	21357	Economy	15000.00
0005432604179	21357	Economy	15000.00
0005432603984	21357	Economy	15000.00
0005434512084	21357	Economy	15000.00
0005432604047	21357	Economy	15000.00
0005435221516	21357	Economy	15000.00
0005435221054	21357	Economy	15000.00
0005434512110	21357	Economy	15000.00
0005432603966	21357	Economy	15000.00
0005435221056	21357	Economy	15000.00
0005432604018	21357	Economy	15000.00
0005432603905	21357	Economy	15000.00
0005432603930	21357	Economy	15000.00
0005432604060	21357	Economy	15000.00
0005432604043	21357	Economy	15000.00
0005434512072	21357	Economy	15000.00
0005434512100	21357	Economy	15000.00
0005432603987	21357	Economy	15000.00
0005434512111	21357	Economy	15000.00
0005435221055	21357	Economy	15000.00
0005432604059	21357	Economy	15000.00
0005434512106	21357	Economy	15000.00
0005432604054	21357	Economy	15000.00
0005432604201	21357	Economy	15000.00
0005434512089	21357	Economy	15000.00
0005432604031	21357	Economy	15000.00
0005432604226	21357	Economy	15000.00
0005432603983	21357	Economy	15000.00
0005432603967	21357	Economy	15000.00
0005432604153	21357	Economy	15000.00
0005432604030	21357	Economy	15000.00
0005432604168	21357	Economy	15000.00
0005432603869	21357	Economy	15000.00
0005434512082	21357	Economy	15000.00
0005432604154	21357	Economy	15000.00
0005432604167	21357	Economy	15000.00
0005432604009	21357	Economy	15000.00
0005433251528	15008	Business	18900.00
0005434906864	15008	Business	18900.00
0005433251553	15008	Business	18900.00
0005434906927	15008	Business	18900.00
0005434906804	15008	Business	18900.00
0005434906914	15008	Business	18900.00
0005434906858	15008	Business	18900.00
0005433251548	15008	Business	18900.00
0005434906957	15008	Business	18900.00
0005433251540	15008	Business	18900.00
0005433251552	15008	Business	18900.00
0005433251551	15008	Economy	6300.00
0005433251558	15008	Economy	6300.00
0005433251557	15008	Economy	6300.00
0005433251538	15008	Economy	6300.00
0005434906965	15008	Economy	6300.00
0005433251546	15008	Economy	6300.00
0005434906869	15008	Economy	6300.00
0005433251534	15008	Economy	6300.00
0005433251545	15008	Economy	6300.00
0005434906895	15008	Economy	6300.00
0005434906832	15008	Economy	6900.00
0005433251542	15008	Economy	6900.00
0005433251554	15008	Economy	6900.00
0005434906918	15008	Economy	6900.00
0005434906928	15008	Economy	6900.00
0005434906744	15008	Economy	6300.00
0005433251539	15008	Economy	6300.00
0005434906635	15008	Economy	6300.00
0005433251556	15008	Economy	6300.00
0005434906894	15008	Economy	6300.00
0005434906896	15008	Economy	6300.00
0005433251530	15008	Economy	6300.00
0005434906812	15008	Economy	6300.00
0005433251544	15008	Economy	6300.00
0005434906944	15008	Economy	6300.00
0005434906964	15008	Economy	6300.00
0005434906553	15008	Economy	6300.00
0005433251547	15008	Economy	6300.00
0005434906811	15008	Economy	6300.00
0005433251535	15008	Economy	6300.00
0005434906916	15008	Economy	6300.00
0005434906760	15008	Economy	6300.00
0005434906856	15008	Economy	6300.00
0005434906868	15008	Economy	6300.00
0005433251536	15008	Economy	6300.00
0005434907014	15008	Economy	6300.00
0005433251549	15008	Economy	6300.00
0005434906770	15008	Economy	6300.00
0005434906838	15008	Economy	6300.00
0005434906925	15008	Economy	6300.00
0005433251541	15008	Economy	6300.00
0005434906855	15008	Economy	6300.00
0005434906857	15008	Economy	6300.00
0005434906921	15008	Economy	6300.00
0005433251537	15008	Economy	6300.00
0005434907008	15008	Economy	6300.00
0005434906860	15008	Economy	6300.00
0005433251531	15008	Economy	6300.00
0005433251532	15008	Economy	6300.00
0005434906971	15008	Economy	6300.00
0005434906890	15008	Economy	6300.00
0005434907013	15008	Economy	6300.00
0005434906743	15008	Economy	6300.00
0005434906764	15008	Economy	6300.00
0005433251555	15008	Economy	6300.00
0005434906774	15008	Economy	6300.00
0005434906555	15008	Economy	6300.00
0005434906988	15008	Economy	6300.00
0005434907007	15008	Economy	6300.00
0005434906763	15008	Economy	6300.00
0005433251533	15008	Economy	6300.00
0005433251543	15008	Economy	6300.00
0005434906919	15008	Economy	6300.00
0005434906931	15008	Economy	6300.00
0005434907047	15008	Economy	6300.00
0005433251550	15008	Economy	6300.00
0005434906753	15008	Economy	6300.00
0005434906930	15008	Economy	6300.00
0005433251559	15008	Economy	6300.00
0005434906769	15008	Economy	6300.00
0005434906946	15008	Economy	6300.00
0005434906870	15008	Economy	6300.00
0005434906915	15008	Economy	6300.00
0005434906865	15008	Economy	6300.00
0005434906636	15008	Economy	6300.00
0005433251529	15008	Economy	6300.00
0005434906947	15008	Economy	6300.00
0005434907350	25868	Business	18900.00
0005433251252	25868	Business	18900.00
0005434907319	25868	Business	18900.00
0005434907327	25868	Business	18900.00
0005433251030	25868	Business	18900.00
0005433251417	25868	Business	18900.00
0005434907366	25868	Business	18900.00
0005434907318	25868	Business	18900.00
0005434907317	25868	Business	18900.00
0005433251269	25868	Economy	6300.00
0005433251182	25868	Economy	6300.00
0005433251348	25868	Economy	6300.00
0005434907329	25868	Economy	6300.00
0005434907347	25868	Economy	6300.00
0005434907326	25868	Economy	6300.00
0005434907368	25868	Economy	6300.00
0005434907334	25868	Economy	6300.00
0005434907365	25868	Economy	6300.00
0005434907345	25868	Economy	6300.00
0005434907337	25868	Economy	6900.00
0005434907363	25868	Economy	6900.00
0005434907369	25868	Economy	6900.00
0005434907371	25868	Economy	6900.00
0005434907328	25868	Economy	6300.00
0005433251270	25868	Economy	6300.00
0005433251181	25868	Economy	6300.00
0005434907359	25868	Economy	6300.00
0005434907343	25868	Economy	6300.00
0005434907360	25868	Economy	6300.00
0005434907332	25868	Economy	6300.00
0005434907316	25868	Economy	6300.00
0005433251263	25868	Economy	6300.00
0005433251029	25868	Economy	6300.00
0005434907321	25868	Economy	6300.00
0005434907338	25868	Economy	6300.00
0005434907355	25868	Economy	6300.00
0005434907370	25868	Economy	6300.00
0005434907341	25868	Economy	6300.00
0005433251364	25868	Economy	6300.00
0005433251288	25868	Economy	6300.00
0005433251331	25868	Economy	6300.00
0005433251251	25868	Economy	6300.00
0005434907336	25868	Economy	6300.00
0005434907353	25868	Economy	6300.00
0005434907342	25868	Economy	6300.00
0005434907339	25868	Economy	6300.00
0005434907331	25868	Economy	6300.00
0005434907351	25868	Economy	6300.00
0005434907325	25868	Economy	6300.00
0005434907356	25868	Economy	6300.00
0005434907322	25868	Economy	6300.00
0005434907344	25868	Economy	6300.00
0005434907323	25868	Economy	6300.00
0005434907367	25868	Economy	6300.00
0005433251248	25868	Economy	6300.00
0005434907324	25868	Economy	6300.00
0005434907320	25868	Economy	6300.00
0005434907354	25868	Economy	6300.00
0005433251349	25868	Economy	6300.00
0005433251202	25868	Economy	6300.00
0005433251237	25868	Economy	6300.00
0005434907330	25868	Economy	6300.00
0005434907348	25868	Economy	6300.00
0005433251201	25868	Economy	6300.00
0005434907364	25868	Economy	6300.00
0005433251340	25868	Economy	6300.00
0005434907358	25868	Economy	6300.00
0005433251353	25868	Economy	6300.00
0005434907346	25868	Economy	6300.00
0005433251183	25868	Economy	6300.00
0005434907333	25868	Economy	6300.00
0005434907352	25868	Economy	6300.00
0005434907335	25868	Economy	6300.00
0005434907340	25868	Economy	6300.00
0005434907349	25868	Economy	6300.00
0005434907357	25868	Economy	6300.00
0005434907362	25868	Economy	6300.00
0005433251180	25868	Economy	6300.00
0005434907361	25868	Economy	6300.00
0005433251236	25868	Economy	6300.00
0005433810509	14159	Business	52300.00
0005433008725	14159	Business	52300.00
0005433008724	14159	Business	52300.00
0005433008732	14159	Business	52300.00
0005433008744	14159	Business	52300.00
0005433008727	14159	Economy	17400.00
0005433008723	14159	Economy	17400.00
0005433008710	14159	Economy	17400.00
0005433008726	14159	Economy	17400.00
0005433008712	14159	Economy	17400.00
0005433008722	14159	Economy	17400.00
0005433810497	14159	Economy	17400.00
0005433008718	14159	Economy	17400.00
0005433008730	14159	Economy	19200.00
0005433008711	14159	Economy	19200.00
0005433008746	14159	Economy	17400.00
0005433008745	14159	Economy	17400.00
0005433008705	14159	Economy	17400.00
0005433008737	14159	Economy	17400.00
0005433008704	14159	Economy	17400.00
0005433008738	14159	Economy	17400.00
0005433008728	14159	Economy	17400.00
0005433008743	14159	Economy	17400.00
0005433008720	14159	Economy	17400.00
0005433008706	14159	Economy	17400.00
0005433008719	14159	Economy	17400.00
0005433008749	14159	Economy	17400.00
0005433008721	14159	Economy	17400.00
0005433810511	14159	Economy	17400.00
0005433008733	14159	Economy	17400.00
0005433008742	14159	Economy	17400.00
0005433008717	14159	Economy	17400.00
0005433008748	14159	Economy	17400.00
0005433008747	14159	Economy	17400.00
0005433008715	14159	Economy	17400.00
0005433008741	14159	Economy	17400.00
0005433810508	14159	Economy	17400.00
0005433008735	14159	Economy	17400.00
0005433008734	14159	Economy	17400.00
0005433810498	14159	Economy	17400.00
0005433008703	14159	Economy	17400.00
0005433008731	14159	Economy	17400.00
0005433008740	14159	Economy	17400.00
0005433008709	14159	Economy	17400.00
0005433008729	14159	Economy	17400.00
0005433008708	14159	Economy	17400.00
0005433008736	14159	Economy	17400.00
0005433810510	14159	Economy	17400.00
0005433008714	14159	Economy	17400.00
0005433008716	14159	Economy	17400.00
0005433008713	14159	Economy	17400.00
0005433008739	14159	Economy	17400.00
0005433008707	14159	Economy	17400.00
0005433008416	22825	Business	52300.00
0005433008292	22825	Business	52300.00
0005433008236	22825	Business	52300.00
0005433008301	22825	Business	52300.00
0005433810551	22825	Business	52300.00
0005433008377	22825	Business	52300.00
0005433008470	22825	Business	52300.00
0005433008304	22825	Business	52300.00
0005433008237	22825	Business	52300.00
0005433008312	22825	Economy	17400.00
0005433008475	22825	Economy	17400.00
0005433008270	22825	Economy	17400.00
0005433008378	22825	Economy	17400.00
0005433008269	22825	Economy	17400.00
0005433008303	22825	Economy	19200.00
0005433008313	22825	Economy	19200.00
0005433008330	22825	Economy	19200.00
0005433810554	22825	Economy	19200.00
0005433008159	22825	Economy	19200.00
0005433008160	22825	Economy	17400.00
0005433008418	22825	Economy	17400.00
0005433008305	22825	Economy	17400.00
0005433008424	22825	Economy	17400.00
0005433008421	22825	Economy	17400.00
0005433810550	22825	Economy	17400.00
0005433008098	22825	Economy	17400.00
0005433008294	22825	Economy	17400.00
0005433008420	22825	Economy	17400.00
0005433008096	22825	Economy	17400.00
0005433008518	22825	Economy	17400.00
0005433008215	22825	Economy	17400.00
0005433008275	22825	Economy	17400.00
0005433008398	22825	Economy	17400.00
0005433008466	22825	Economy	17400.00
0005433008327	22825	Economy	17400.00
0005433008158	22825	Economy	17400.00
0005433008115	22825	Economy	17400.00
0005433008197	22825	Economy	17400.00
0005433008362	22825	Economy	17400.00
0005433008293	22825	Economy	17400.00
0005433008329	22825	Economy	17400.00
0005433008471	22825	Economy	17400.00
0005433008408	22825	Economy	17400.00
0005433008195	22825	Economy	17400.00
0005433008220	22825	Economy	17400.00
0005433810553	22825	Economy	17400.00
0005433810552	22825	Economy	17400.00
0005433008255	22825	Economy	17400.00
0005433008221	22825	Economy	17400.00
0005433008256	22825	Economy	17400.00
0005433008419	22825	Economy	17400.00
0005433008111	22825	Economy	17400.00
0005433008097	22825	Economy	17400.00
0005433008271	22825	Economy	17400.00
0005433008196	22825	Economy	17400.00
0005433008361	22825	Economy	17400.00
0005434925545	14908	Business	22900.00
0005434925606	14908	Business	22900.00
0005434925506	14908	Business	22900.00
0005434925505	14908	Business	22900.00
0005434925509	14908	Business	22900.00
0005434925571	14908	Business	22900.00
0005434925507	14908	Economy	7600.00
0005434925436	14908	Economy	7600.00
0005434925521	14908	Economy	7600.00
0005434925586	14908	Economy	7600.00
0005434925640	14908	Economy	8400.00
0005434925504	14908	Economy	8400.00
0005434925533	14908	Economy	8400.00
0005434925600	14908	Economy	7600.00
0005434925641	14908	Economy	7600.00
0005434925592	14908	Economy	7600.00
0005434925598	14908	Economy	7600.00
0005434925409	14908	Economy	7600.00
0005434925596	14908	Economy	7600.00
0005434925547	14908	Economy	7600.00
0005434925435	14908	Economy	7600.00
0005434925563	14908	Economy	7600.00
0005434925582	14908	Economy	7600.00
0005434925655	14908	Economy	7600.00
0005434925483	14908	Economy	7600.00
0005434925587	14908	Economy	7600.00
0005434925583	14908	Economy	7600.00
0005434925501	14908	Economy	7600.00
0005434925408	14908	Economy	7600.00
0005434925368	14908	Economy	7600.00
0005434925645	14908	Economy	7600.00
0005434925500	14908	Economy	7600.00
0005434925567	14908	Economy	7600.00
0005434925367	14908	Economy	7600.00
0005434925644	14908	Economy	7600.00
0005434925599	14908	Economy	7600.00
0005434925561	14908	Economy	7600.00
0005434925562	14908	Economy	7600.00
0005434925565	14908	Economy	7600.00
0005434925534	14908	Economy	7600.00
0005434925568	14908	Economy	7600.00
0005434925585	14908	Economy	7600.00
0005434925566	14908	Economy	7600.00
0005434925584	14908	Economy	7600.00
0005434925546	14908	Economy	7600.00
0005434925603	14908	Economy	7600.00
0005434925518	14908	Economy	7600.00
0005434925843	20512	Business	22900.00
0005434925849	20512	Business	22900.00
0005434925835	20512	Business	22900.00
0005434925848	20512	Business	22900.00
0005434925856	20512	Business	22900.00
0005434925840	20512	Economy	7600.00
0005434925836	20512	Economy	7600.00
0005434925847	20512	Economy	7600.00
0005434925852	20512	Economy	7600.00
0005434925855	20512	Economy	8400.00
0005434925842	20512	Economy	7600.00
0005434925844	20512	Economy	7600.00
0005434925834	20512	Economy	7600.00
0005434925837	20512	Economy	7600.00
0005434925854	20512	Economy	7600.00
0005434925846	20512	Economy	7600.00
0005434925832	20512	Economy	7600.00
0005434925841	20512	Economy	7600.00
0005434925850	20512	Economy	7600.00
0005434925845	20512	Economy	7600.00
0005434925838	20512	Economy	7600.00
0005434925833	20512	Economy	7600.00
0005434925851	20512	Economy	7600.00
0005434925853	20512	Economy	7600.00
0005434925839	20512	Economy	7600.00
0005435999122	15840	Economy	8900.00
0005435487897	15840	Economy	8900.00
0005435487898	15840	Economy	8900.00
0005435487875	15840	Economy	8900.00
0005435487893	15840	Economy	8100.00
0005435487878	15840	Economy	8100.00
0005435999096	15840	Economy	8100.00
0005435999126	15840	Economy	8100.00
0005435487885	15840	Economy	8100.00
0005435999094	15840	Economy	8100.00
0005435487874	15840	Economy	8100.00
0005435999141	15840	Economy	8100.00
0005435487896	15840	Economy	8100.00
0005435487883	15840	Economy	8100.00
0005435999080	15840	Economy	8100.00
0005435487887	15840	Economy	8100.00
0005435999097	15840	Economy	8100.00
0005435487879	15840	Economy	8100.00
0005435999133	15840	Economy	8100.00
0005435999165	15840	Economy	8100.00
0005435999038	15840	Economy	8100.00
0005435999090	15840	Economy	8100.00
0005435999157	15840	Economy	8100.00
0005435487891	15840	Economy	8100.00
0005435487892	15840	Economy	8100.00
0005435999121	15840	Economy	8100.00
0005435487890	15840	Economy	8100.00
0005435487895	15840	Economy	8100.00
0005435999134	15840	Economy	8100.00
0005435999091	15840	Economy	8100.00
0005435487880	15840	Economy	8100.00
0005435999163	15840	Economy	8100.00
0005435487884	15840	Economy	8100.00
0005435487894	15840	Economy	8100.00
0005435999151	15840	Economy	8100.00
0005435999123	15840	Economy	8100.00
0005435999150	15840	Economy	8100.00
0005435487882	15840	Economy	8100.00
0005435487877	15840	Economy	8100.00
0005435487876	15840	Economy	8100.00
0005435487886	15840	Economy	8100.00
0005435487881	15840	Economy	8100.00
0005435999037	15840	Economy	8100.00
0005435999162	15840	Economy	8100.00
0005435487888	15840	Economy	8100.00
0005435487889	15840	Economy	8100.00
0005435999039	15840	Economy	8100.00
0005435999276	19698	Economy	8900.00
0005435999269	19698	Economy	8900.00
0005435487709	19698	Economy	8100.00
0005435487651	19698	Economy	8100.00
0005435999271	19698	Economy	8100.00
0005435487561	19698	Economy	8100.00
0005435487629	19698	Economy	8100.00
0005435487601	19698	Economy	8100.00
0005435487603	19698	Economy	8100.00
0005435999273	19698	Economy	8100.00
0005435487641	19698	Economy	8100.00
0005435999268	19698	Economy	8100.00
0005435487677	19698	Economy	8100.00
0005435999279	19698	Economy	8100.00
0005435487667	19698	Economy	8100.00
0005435487628	19698	Economy	8100.00
0005435999270	19698	Economy	8100.00
0005435487684	19698	Economy	8100.00
0005435999267	19698	Economy	8100.00
0005435487691	19698	Economy	8100.00
0005435487602	19698	Economy	8100.00
0005435487627	19698	Economy	8100.00
0005435999278	19698	Economy	8100.00
0005435999274	19698	Economy	8100.00
0005435999266	19698	Economy	8100.00
0005435999277	19698	Economy	8100.00
0005435999272	19698	Economy	8100.00
0005435487708	19698	Economy	8100.00
0005435487663	19698	Economy	8100.00
0005435999275	19698	Economy	8100.00
0005435472618	5991	Business	199300.00
0005435839506	5991	Business	199300.00
0005435839517	5991	Business	199300.00
0005432659714	5991	Business	199300.00
0005435839511	5991	Business	199300.00
0005435839531	5991	Business	199300.00
0005432658597	5991	Business	199300.00
0005435472695	5991	Business	199300.00
0005435472703	5991	Business	199300.00
0005432660823	5991	Business	199300.00
0005435839533	5991	Business	199300.00
0005435472717	5991	Economy	66400.00
0005432142261	5991	Economy	66400.00
0005432537040	5991	Economy	66400.00
0005435839529	5991	Economy	66400.00
0005435839518	5991	Economy	66400.00
0005435839522	5991	Economy	66400.00
0005435839513	5991	Economy	66400.00
0005435839528	5991	Economy	66400.00
0005435472636	5991	Economy	66400.00
0005435839516	5991	Economy	73100.00
0005435839521	5991	Economy	73100.00
0005432142259	5991	Economy	73100.00
0005432658596	5991	Economy	73100.00
0005435472719	5991	Economy	66400.00
0005435839519	5991	Economy	66400.00
0005435472669	5991	Economy	66400.00
0005435839515	5991	Economy	66400.00
0005432658598	5991	Economy	66400.00
0005435472746	5991	Economy	66400.00
0005435839523	5991	Economy	66400.00
0005435839526	5991	Economy	66400.00
0005435472740	5991	Economy	66400.00
0005435839507	5991	Economy	66400.00
0005435839509	5991	Economy	66400.00
0005435839505	5991	Economy	66400.00
0005435839527	5991	Economy	66400.00
0005435839525	5991	Economy	66400.00
0005435472769	5991	Economy	66400.00
0005432142258	5991	Economy	66400.00
0005432537041	5991	Economy	66400.00
0005432659711	5991	Economy	66400.00
0005435472687	5991	Economy	66400.00
0005435839510	5991	Economy	66400.00
0005435472688	5991	Economy	66400.00
0005435839530	5991	Economy	66400.00
0005435472660	5991	Economy	66400.00
0005435839514	5991	Economy	66400.00
0005432659712	5991	Economy	66400.00
0005435472747	5991	Economy	66400.00
0005435839524	5991	Economy	66400.00
0005435839508	5991	Economy	66400.00
0005432659713	5991	Economy	66400.00
0005435839532	5991	Economy	66400.00
0005435472702	5991	Economy	66400.00
0005435472739	5991	Economy	66400.00
0005435472670	5991	Economy	66400.00
0005435472696	5991	Economy	66400.00
0005432660824	5991	Economy	66400.00
0005435472720	5991	Economy	66400.00
0005432537045	5991	Economy	66400.00
0005435839520	5991	Economy	66400.00
0005432142260	5991	Economy	66400.00
0005435472768	5991	Economy	66400.00
0005435839512	5991	Economy	66400.00
0005435472842	18054	Business	199300.00
0005435839287	18054	Business	199300.00
0005435839306	18054	Business	199300.00
0005432660801	18054	Business	199300.00
0005435839356	18054	Business	199300.00
0005435839309	18054	Business	199300.00
0005435839328	18054	Business	199300.00
0005432660803	18054	Business	199300.00
0005435472832	18054	Economy	66400.00
0005435839295	18054	Economy	66400.00
0005435839233	18054	Economy	66400.00
0005432537064	18054	Economy	66400.00
0005435472834	18054	Economy	66400.00
0005435839415	18054	Economy	73100.00
0005435839245	18054	Economy	73100.00
0005435472843	18054	Economy	66400.00
0005435839189	18054	Economy	66400.00
0005435472844	18054	Economy	66400.00
0005432667434	18054	Economy	66400.00
0005435839323	18054	Economy	66400.00
0005435839277	18054	Economy	66400.00
0005432660799	18054	Economy	66400.00
0005435472833	18054	Economy	66400.00
0005432664117	18054	Economy	66400.00
0005435472836	18054	Economy	66400.00
0005435839246	18054	Economy	66400.00
0005435839322	18054	Economy	66400.00
0005435472846	18054	Economy	66400.00
0005432660800	18054	Economy	66400.00
0005435839276	18054	Economy	66400.00
0005435839244	18054	Economy	66400.00
0005435472837	18054	Economy	66400.00
0005432667443	18054	Economy	66400.00
0005435472840	18054	Economy	66400.00
0005435839294	18054	Economy	66400.00
0005432537063	18054	Economy	66400.00
0005435472841	18054	Economy	66400.00
0005435839286	18054	Economy	66400.00
0005435472847	18054	Economy	66400.00
0005432660797	18054	Economy	66400.00
0005435472839	18054	Economy	66400.00
0005435839302	18054	Economy	66400.00
0005435472838	18054	Economy	66400.00
0005435472848	18054	Economy	66400.00
0005435472845	18054	Economy	66400.00
0005435839243	18054	Economy	66400.00
0005435839234	18054	Economy	66400.00
0005435839305	18054	Economy	66400.00
0005435839355	18054	Economy	66400.00
0005435839331	18054	Economy	66400.00
0005435839252	18054	Economy	66400.00
0005435839340	18054	Economy	66400.00
0005435839329	18054	Economy	66400.00
0005435839114	18054	Economy	66400.00
0005435472835	18054	Economy	66400.00
0005432667439	18054	Economy	66400.00
0005435839327	18054	Economy	66400.00
0005433285131	23000	Business	15700.00
0005433285067	23000	Business	15700.00
0005433285023	23000	Economy	5200.00
0005435103943	23000	Economy	5200.00
0005433285203	23000	Economy	5200.00
0005433285085	23000	Economy	5200.00
0005435103949	23000	Economy	5200.00
0005433285156	23000	Economy	5200.00
0005433285147	23000	Economy	5200.00
0005433285241	23000	Economy	5200.00
0005433285225	23000	Economy	5200.00
0005433285093	23000	Economy	5200.00
0005433284998	23000	Economy	5200.00
0005433285070	23000	Economy	5700.00
0005433285132	23000	Economy	5700.00
0005435103948	23000	Economy	5700.00
0005435103944	23000	Economy	5200.00
0005435103946	23000	Economy	5200.00
0005433285068	23000	Economy	5200.00
0005433285297	23000	Economy	5200.00
0005433285145	23000	Economy	5200.00
0005433285216	23000	Economy	5200.00
0005433285020	23000	Economy	5200.00
0005433284980	23000	Economy	5200.00
0005433285226	23000	Economy	5200.00
0005433284997	23000	Economy	5200.00
0005433285231	23000	Economy	5200.00
0005433285019	23000	Economy	5200.00
0005433285082	23000	Economy	5200.00
0005433285092	23000	Economy	5200.00
0005435103942	23000	Economy	5200.00
0005433285202	23000	Economy	5200.00
0005433285106	23000	Economy	5200.00
0005433285230	23000	Economy	5200.00
0005435103945	23000	Economy	5200.00
0005433285192	23000	Economy	5200.00
0005433285122	23000	Economy	5200.00
0005433285133	23000	Economy	5200.00
0005433285083	23000	Economy	5200.00
0005435103947	23000	Economy	5200.00
0005433285387	32081	Business	15700.00
0005433285391	32081	Business	15700.00
0005433285379	32081	Business	15700.00
0005433285371	32081	Economy	5200.00
0005433285386	32081	Economy	5200.00
0005433285383	32081	Economy	5200.00
0005433285381	32081	Economy	5200.00
0005433285372	32081	Economy	5200.00
0005433285389	32081	Economy	5200.00
0005433285382	32081	Economy	5200.00
0005433285363	32081	Economy	5200.00
0005433285362	32081	Economy	5200.00
0005433285370	32081	Economy	5200.00
0005433285368	32081	Economy	5200.00
0005433285359	32081	Economy	5200.00
0005433285377	32081	Economy	5700.00
0005433285365	32081	Economy	5700.00
0005433285375	32081	Economy	5200.00
0005433285366	32081	Economy	5200.00
0005433285380	32081	Economy	5200.00
0005433285373	32081	Economy	5200.00
0005433285376	32081	Economy	5200.00
0005433285378	32081	Economy	5200.00
0005433285384	32081	Economy	5200.00
0005433285374	32081	Economy	5200.00
0005435103842	32081	Economy	5200.00
0005433285360	32081	Economy	5200.00
0005433285390	32081	Economy	5200.00
0005433285361	32081	Economy	5200.00
0005433285369	32081	Economy	5200.00
0005433285364	32081	Economy	5200.00
0005435103843	32081	Economy	5200.00
0005433285367	32081	Economy	5200.00
0005433285385	32081	Economy	5200.00
0005433285388	32081	Economy	5200.00
0005433475681	23878	Economy	13500.00
0005433475683	23878	Economy	12300.00
0005433475675	23878	Economy	12300.00
0005433475667	23878	Economy	12300.00
0005435852581	23878	Economy	12300.00
0005435852579	23878	Economy	12300.00
0005433475653	23878	Economy	12300.00
0005433475668	23878	Economy	12300.00
0005433475657	23878	Economy	12300.00
0005433475671	23878	Economy	12300.00
0005435852580	23878	Economy	12300.00
0005433475684	23878	Economy	12300.00
0005433475652	23878	Economy	12300.00
0005433475693	23878	Economy	12300.00
0005433475674	23878	Economy	12300.00
0005433475658	23878	Economy	12300.00
0005435852582	23878	Economy	12300.00
0005433475670	23878	Economy	12300.00
0005435852583	23878	Economy	12300.00
0005435213735	30590	Business	42100.00
0005432527461	30590	Business	42100.00
0005432527112	30590	Business	42100.00
0005434067368	30590	Business	42100.00
0005435213785	30590	Business	42100.00
0005432526940	30590	Business	42100.00
0005434067028	30590	Business	42100.00
0005432527660	30590	Business	42100.00
0005432527418	30590	Business	42100.00
0005435213780	30590	Business	42100.00
0005432526806	30590	Business	42100.00
0005434067443	30590	Business	42100.00
0005435213773	30590	Business	42100.00
0005434067166	30590	Business	42100.00
0005435213746	30590	Business	42100.00
0005435213784	30590	Business	42100.00
0005435213747	30590	Business	42100.00
0005432527375	30590	Business	42100.00
0005432527134	30590	Business	42100.00
0005432527770	30590	Business	42100.00
0005434067016	30590	Business	42100.00
0005434067338	30590	Comfort	23900.00
0005434067140	30590	Comfort	23900.00
0005435213775	30590	Comfort	23900.00
0005435213743	30590	Comfort	23900.00
0005435213738	30590	Comfort	23900.00
0005435725615	30590	Comfort	23900.00
0005432428901	30590	Comfort	23900.00
0005434067231	30590	Comfort	23900.00
0005432526764	30590	Comfort	23900.00
0005434067150	30590	Comfort	23900.00
0005435213741	30590	Comfort	23900.00
0005432526650	30590	Comfort	23900.00
0005434067185	30590	Comfort	23900.00
0005432527481	30590	Comfort	23900.00
0005434067128	30590	Comfort	23900.00
0005432527499	30590	Comfort	23900.00
0005432527706	30590	Comfort	23900.00
0005435283409	30590	Comfort	23900.00
0005435213744	30590	Comfort	23900.00
0005434067375	30590	Comfort	23900.00
0005435630976	30590	Comfort	23900.00
0005435213740	30590	Comfort	23900.00
0005432527046	30590	Comfort	23900.00
0005435213769	30590	Comfort	23900.00
0005435213762	30590	Comfort	23900.00
0005432527515	30590	Comfort	23900.00
0005434067206	30590	Comfort	23900.00
0005435213779	30590	Comfort	23900.00
0005435213751	30590	Comfort	23900.00
0005435213760	30590	Comfort	23900.00
0005434066976	30590	Comfort	23900.00
0005434067337	30590	Comfort	23900.00
0005432527750	30590	Comfort	23900.00
0005432527127	30590	Comfort	23900.00
0005432527543	30590	Comfort	23900.00
0005432526990	30590	Comfort	23900.00
0005435213782	30590	Comfort	23900.00
0005434067165	30590	Economy	14000.00
0005434067194	30590	Economy	14000.00
0005432526989	30590	Economy	14000.00
0005432527445	30590	Economy	14000.00
0005434067413	30590	Economy	14000.00
0005434066958	30590	Economy	14000.00
0005435725618	30590	Economy	14000.00
0005435213755	30590	Economy	14000.00
0005435213763	30590	Economy	14000.00
0005435630977	30590	Economy	14000.00
0005432526776	30590	Economy	14000.00
0005434067098	30590	Economy	14000.00
0005432527509	30590	Economy	14000.00
0005432527440	30590	Economy	14000.00
0005432527508	30590	Economy	14000.00
0005432428891	30590	Economy	14000.00
0005434067369	30590	Economy	14000.00
0005435213752	30590	Economy	14000.00
0005432526961	30590	Economy	14000.00
0005432159873	30590	Economy	14000.00
0005434067049	30590	Economy	14000.00
0005435725616	30590	Economy	14000.00
0005435213748	30590	Economy	14000.00
0005432527061	30590	Economy	14000.00
0005432526713	30590	Economy	14000.00
0005434067029	30590	Economy	14000.00
0005432527767	30590	Economy	14000.00
0005435213754	30590	Economy	14000.00
0005432211524	30590	Economy	14000.00
0005434067137	30590	Economy	14000.00
0005434067057	30590	Economy	14000.00
0005432526651	30590	Economy	14000.00
0005432535810	30590	Economy	14000.00
0005432527490	30590	Economy	14000.00
0005432527383	30590	Economy	14000.00
0005435213723	30590	Economy	14000.00
0005432527444	30590	Economy	14000.00
0005435213734	30590	Economy	14000.00
0005432527290	30590	Economy	14000.00
0005435213758	30590	Economy	14000.00
0005434067135	30590	Economy	14000.00
0005435213745	30590	Economy	14000.00
0005435213750	30590	Economy	14000.00
0005435213728	30590	Economy	14000.00
0005433656681	30590	Economy	14000.00
0005434067164	30590	Economy	14000.00
0005432527130	30590	Economy	14000.00
0005435213730	30590	Economy	14000.00
0005435725617	30590	Economy	14000.00
0005434067152	30590	Economy	14000.00
0005432527185	30590	Economy	14000.00
0005435213720	30590	Economy	14000.00
0005432159870	30590	Economy	14000.00
0005434067138	30590	Economy	14000.00
0005435213765	30590	Economy	14000.00
0005434067153	30590	Economy	14000.00
0005432527493	30590	Economy	14000.00
0005434067258	30590	Economy	14000.00
0005432526725	30590	Economy	15400.00
0005435213753	30590	Economy	14000.00
0005432526888	30590	Economy	14000.00
0005432526801	30590	Economy	14000.00
0005432527768	30590	Economy	15400.00
0005434067119	30590	Economy	14000.00
0005435213721	30590	Economy	14000.00
0005432527769	30590	Economy	14000.00
0005434067139	30590	Economy	14000.00
0005435213719	30590	Economy	14000.00
0005435213725	30590	Economy	14000.00
0005432527441	30590	Economy	14000.00
0005432211521	30590	Economy	14000.00
0005435213783	30590	Economy	14000.00
0005434066915	30590	Economy	14000.00
0005434067294	30590	Economy	14000.00
0005434067077	30590	Economy	14000.00
0005432527126	30590	Economy	14000.00
0005432526741	30590	Economy	14000.00
0005435213736	30590	Economy	14000.00
0005433656682	30590	Economy	14000.00
0005435213729	30590	Economy	14000.00
0005432537039	30590	Economy	14000.00
0005432526659	30590	Economy	14000.00
0005435213727	30590	Economy	14000.00
0005435213768	30590	Economy	14000.00
0005434067154	30590	Economy	14000.00
0005434067129	30590	Economy	14000.00
0005432527708	30590	Economy	14000.00
0005432527278	30590	Economy	14000.00
0005434066869	30590	Economy	14000.00
0005434067099	30590	Economy	14000.00
0005432526915	30590	Economy	14000.00
0005432527435	30590	Economy	14000.00
0005432527286	30590	Economy	14000.00
0005432527113	30590	Economy	14000.00
0005435213766	30590	Economy	14000.00
0005434067120	30590	Economy	14000.00
0005435283410	30590	Economy	14000.00
0005435630978	30590	Economy	14000.00
0005432527529	30590	Economy	14000.00
0005432527133	30590	Economy	14000.00
0005432526775	30590	Economy	14000.00
0005434067367	30590	Economy	14000.00
0005434066696	30590	Economy	14000.00
0005434067118	30590	Economy	14000.00
0005432527491	30590	Economy	14000.00
0005432527087	30590	Economy	14000.00
0005432526887	30590	Economy	14000.00
0005432527305	30590	Economy	14000.00
0005432527577	30590	Economy	14000.00
0005432526602	30590	Economy	14000.00
0005434067142	30590	Economy	14000.00
0005432159871	30590	Economy	14000.00
0005432527060	30590	Economy	14000.00
0005435213781	30590	Economy	14000.00
0005432527766	30590	Economy	14000.00
0005432535804	30590	Economy	14000.00
0005435213726	30590	Economy	14000.00
0005432527421	30590	Economy	14000.00
0005435213757	30590	Economy	14000.00
0005432526988	30590	Economy	14000.00
0005432527155	30590	Economy	14000.00
0005432526917	30590	Economy	14000.00
0005432527156	30590	Economy	14000.00
0005432526652	30590	Economy	14000.00
0005432211526	30590	Economy	14000.00
0005432527211	30590	Economy	14000.00
0005434066983	30590	Economy	14000.00
0005435213716	30590	Economy	14000.00
0005435213756	30590	Economy	14000.00
0005432428914	30590	Economy	14000.00
0005432527707	30590	Economy	14000.00
0005434067078	30590	Economy	14000.00
0005432527200	30590	Economy	14000.00
0005432527645	30590	Economy	14000.00
0005432527551	30590	Economy	14000.00
0005432211522	30590	Economy	14000.00
0005432527291	30590	Economy	14000.00
0005435213715	30590	Economy	14000.00
0005432526985	30590	Economy	14000.00
0005432527170	30590	Economy	14000.00
0005434066945	30590	Economy	14000.00
0005435213742	30590	Economy	14000.00
0005434066960	30590	Economy	14000.00
0005432527086	30590	Economy	14000.00
0005434067136	30590	Economy	14000.00
0005435213778	30590	Economy	14000.00
0005432526760	30590	Economy	15400.00
0005434067059	30590	Economy	15400.00
0005434066864	30590	Economy	15400.00
0005435213764	30590	Economy	15400.00
0005432527590	30590	Economy	15400.00
0005432527059	30590	Economy	14000.00
0005432527129	30590	Economy	14000.00
0005435213737	30590	Economy	14000.00
0005432211523	30590	Economy	14000.00
0005434067376	30590	Economy	14000.00
0005432527217	30590	Economy	14000.00
0005434067377	30590	Economy	14000.00
0005433656683	30590	Economy	14000.00
0005432527171	30590	Economy	14000.00
0005435213774	30590	Economy	14000.00
0005432526916	30590	Economy	14000.00
0005435213771	30590	Economy	14000.00
0005435213733	30590	Economy	14000.00
0005435213772	30590	Economy	14000.00
0005432527357	30590	Economy	14000.00
0005435725614	30590	Economy	14000.00
0005432527482	30590	Economy	14000.00
0005432527501	30590	Economy	14000.00
0005432527492	30590	Economy	14000.00
0005432527542	30590	Economy	14000.00
0005435213767	30590	Economy	14000.00
0005434067295	30590	Economy	14000.00
0005432428900	30590	Economy	14000.00
0005435213777	30590	Economy	14000.00
0005434067147	30590	Economy	14000.00
0005435213724	30590	Economy	14000.00
0005432526984	30590	Economy	14000.00
0005435213722	30590	Economy	14000.00
0005435213732	30590	Economy	14000.00
0005434067048	30590	Economy	14000.00
0005434067427	30590	Economy	14000.00
0005432527376	30590	Economy	14000.00
0005432211525	30590	Economy	14000.00
0005435213731	30590	Economy	14000.00
0005435213739	30590	Economy	14000.00
0005432527374	30590	Economy	14000.00
0005432526982	30590	Economy	14000.00
0005432527151	30590	Economy	14000.00
0005432527139	30590	Economy	14000.00
0005435213776	30590	Economy	14000.00
0005434067095	30590	Economy	14000.00
0005432527302	30590	Economy	14000.00
0005432527910	30590	Economy	14000.00
0005432159872	30590	Economy	14000.00
0005434067058	30590	Economy	14000.00
0005432526796	30590	Economy	14000.00
0005434066862	30590	Economy	14000.00
0005435213718	30590	Economy	14000.00
0005435213759	30590	Economy	14000.00
0005432527161	30590	Economy	14000.00
0005434067105	30590	Economy	14000.00
0005432527402	30590	Economy	14000.00
0005432527500	30590	Economy	14000.00
0005435213770	30590	Economy	14000.00
0005433656680	30590	Economy	14000.00
0005432527576	30590	Economy	14000.00
0005435630975	30590	Economy	14000.00
0005432527183	30590	Economy	14000.00
0005435213761	30590	Economy	14000.00
0005432527152	30590	Economy	14000.00
0005435213749	30590	Economy	14000.00
0005432535803	30590	Economy	14000.00
0005432535811	30590	Economy	14000.00
0005432527306	30590	Economy	14000.00
0005434067290	30590	Economy	14000.00
0005432527128	30590	Economy	14000.00
0005435213717	30590	Economy	14000.00
0005432159869	30590	Economy	14000.00
0005432527552	30590	Economy	14000.00
0005432527434	30590	Economy	14000.00
0005432428890	30590	Economy	14000.00
0005434067141	30590	Economy	14000.00
0005434066865	30590	Economy	14000.00
0005432527117	30590	Economy	14000.00
0005434067056	30590	Economy	14000.00
0005432428902	30590	Economy	14000.00
0005432527565	30590	Economy	14000.00
0005432527135	30590	Economy	14000.00
0005432527184	30590	Economy	14000.00
0005432527201	30590	Economy	14000.00
0005434067053	30590	Economy	14000.00
0005433368025	24873	Business	9800.00
0005435652713	24873	Business	9800.00
0005433368009	24873	Business	9800.00
0005433367990	24873	Business	9800.00
0005433368020	24873	Business	9800.00
0005435652791	24873	Business	9800.00
0005435652682	24873	Business	9800.00
0005435652667	24873	Business	9800.00
0005435652543	24873	Business	9800.00
0005433368015	24873	Business	9800.00
0005435652759	24873	Business	9800.00
0005435652741	24873	Business	9800.00
0005435652710	24873	Economy	3300.00
0005435652544	24873	Economy	3300.00
0005433367999	24873	Economy	3300.00
0005433368017	24873	Economy	3300.00
0005433368023	24873	Economy	3300.00
0005433368018	24873	Economy	3300.00
0005435652672	24873	Economy	3300.00
0005433368005	24873	Economy	3300.00
0005435652698	24873	Economy	3300.00
0005433368022	24873	Economy	3600.00
0005435652674	24873	Economy	3600.00
0005435652725	24873	Economy	3600.00
0005433367993	24873	Economy	3600.00
0005435652758	24873	Economy	3600.00
0005433368007	24873	Economy	3300.00
0005435652669	24873	Economy	3300.00
0005433368003	24873	Economy	3300.00
0005433368014	24873	Economy	3300.00
0005435652772	24873	Economy	3300.00
0005435652695	24873	Economy	3300.00
0005435652699	24873	Economy	3300.00
0005435652687	24873	Economy	3300.00
0005433367988	24873	Economy	3300.00
0005433368019	24873	Economy	3300.00
0005435652521	24873	Economy	3300.00
0005433368002	24873	Economy	3300.00
0005433367994	24873	Economy	3300.00
0005433367987	24873	Economy	3300.00
0005435652666	24873	Economy	3300.00
0005433368010	24873	Economy	3300.00
0005433367996	24873	Economy	3300.00
0005435652760	24873	Economy	3300.00
0005435652643	24873	Economy	3300.00
0005433367997	24873	Economy	3300.00
0005433367989	24873	Economy	3300.00
0005435652557	24873	Economy	3300.00
0005435652733	24873	Economy	3300.00
0005435652720	24873	Economy	3300.00
0005435652719	24873	Economy	3300.00
0005435652768	24873	Economy	3300.00
0005433368001	24873	Economy	3300.00
0005433368016	24873	Economy	3300.00
0005433367991	24873	Economy	3300.00
0005435652781	24873	Economy	3300.00
0005433368006	24873	Economy	3300.00
0005435652715	24873	Economy	3300.00
0005435652556	24873	Economy	3300.00
0005435652675	24873	Economy	3300.00
0005433368000	24873	Economy	3300.00
0005433368011	24873	Economy	3300.00
0005433367992	24873	Economy	3300.00
0005435652586	24873	Economy	3300.00
0005433368021	24873	Economy	3300.00
0005433367998	24873	Economy	3300.00
0005435652673	24873	Economy	3300.00
0005435652692	24873	Economy	3300.00
0005433368012	24873	Economy	3300.00
0005435652780	24873	Economy	3300.00
0005435652559	24873	Economy	3300.00
0005435652792	24873	Economy	3300.00
0005435652740	24873	Economy	3300.00
0005433367995	24873	Economy	3300.00
0005435652668	24873	Economy	3300.00
0005435652491	24873	Economy	3300.00
0005433368004	24873	Economy	3300.00
0005435652585	24873	Economy	3300.00
0005433368024	24873	Economy	3300.00
0005435652694	24873	Economy	3300.00
0005435652714	24873	Economy	3300.00
0005435652520	24873	Economy	3300.00
0005433368008	24873	Economy	3300.00
0005435652789	24873	Economy	3300.00
0005435652756	24873	Economy	3300.00
0005433368013	24873	Economy	3300.00
0005435652726	24873	Economy	3300.00
0005435652519	24873	Economy	3300.00
0005435652771	24873	Economy	3300.00
0005435652751	24873	Economy	3300.00
0005435949789	6601	Economy	18700.00
0005435949787	6601	Economy	18700.00
0005435949788	6601	Economy	18700.00
0005435949786	6601	Economy	18700.00
0005435949784	6601	Economy	18700.00
0005435949783	6601	Economy	18700.00
0005435949785	6601	Economy	18700.00
0005435949790	6601	Economy	18700.00
0005435949791	6601	Economy	18700.00
0005434979881	2052	Economy	10500.00
0005434979876	2052	Economy	10500.00
0005434979891	2052	Economy	10500.00
0005434979879	2052	Economy	9500.00
0005434979890	2052	Economy	9500.00
0005434979867	2052	Economy	9500.00
0005435801706	2052	Economy	9500.00
0005434979877	2052	Economy	9500.00
0005434979886	2052	Economy	9500.00
0005434979868	2052	Economy	9500.00
0005434979880	2052	Economy	9500.00
0005434979892	2052	Economy	9500.00
0005434979883	2052	Economy	9500.00
0005434979888	2052	Economy	9500.00
0005434979871	2052	Economy	9500.00
0005434979875	2052	Economy	9500.00
0005434979889	2052	Economy	9500.00
0005434979887	2052	Economy	9500.00
0005434979884	2052	Economy	9500.00
0005434979869	2052	Economy	9500.00
0005434979894	2052	Economy	9500.00
0005434979885	2052	Economy	9500.00
0005434979878	2052	Economy	9500.00
0005434979882	2052	Economy	9500.00
0005434979897	2052	Economy	9500.00
0005434979872	2052	Economy	9500.00
0005434979895	2052	Economy	9500.00
0005434979870	2052	Economy	9500.00
0005434979896	2052	Economy	9500.00
0005434979873	2052	Economy	9500.00
0005434979893	2052	Economy	9500.00
0005434979874	2052	Economy	9500.00
0005434979643	23540	Economy	10500.00
0005434979447	23540	Economy	10500.00
0005434979588	23540	Economy	9500.00
0005434979473	23540	Economy	9500.00
0005434979644	23540	Economy	9500.00
0005434979630	23540	Economy	9500.00
0005434979645	23540	Economy	9500.00
0005434979631	23540	Economy	9500.00
0005434979609	23540	Economy	9500.00
0005434979520	23540	Economy	9500.00
0005435801665	23540	Economy	9500.00
0005434979629	23540	Economy	9500.00
0005434979569	23540	Economy	9500.00
0005434979469	23540	Economy	9500.00
0005434979519	23540	Economy	9500.00
0005434979472	23540	Economy	9500.00
0005435801676	23540	Economy	9500.00
0005434979656	23540	Economy	9500.00
0005434979517	23540	Economy	9500.00
0005434979524	23540	Economy	9500.00
0005435801677	23540	Economy	9500.00
0005435801666	23540	Economy	9500.00
0005434979468	23540	Economy	9500.00
0005434979564	23540	Economy	9500.00
0005434952542	2637	Economy	5300.00
0005434952545	2637	Economy	5300.00
0005434952543	2637	Economy	5300.00
0005434952544	2637	Economy	5300.00
0005433256403	2636	Economy	5300.00
0005433256417	2636	Economy	5300.00
0005433256414	2636	Economy	5300.00
0005433256404	2636	Economy	5300.00
0005434952519	28262	Economy	5300.00
0005434952504	28262	Economy	5300.00
0005433256428	28262	Economy	5300.00
0005434952518	28262	Economy	5300.00
0005433256429	28262	Economy	5300.00
0005434952510	28262	Economy	5300.00
0005434952516	28262	Economy	5300.00
0005434952517	28262	Economy	5300.00
0005434952511	28262	Economy	5300.00
0005433112380	19746	Economy	8700.00
0005433111513	19746	Economy	8700.00
0005433111512	19746	Economy	8700.00
0005433111514	19746	Economy	8700.00
0005433112381	19746	Economy	8700.00
0005434137658	11953	Business	9700.00
0005434137889	11953	Business	9700.00
0005434137555	11953	Business	9700.00
0005434137563	11953	Business	9700.00
0005434137633	11953	Business	9700.00
0005434137745	11953	Business	9700.00
0005434137692	11953	Business	9700.00
0005434137243	11953	Business	9700.00
0005434137660	11953	Business	9700.00
0005434137245	11953	Business	9700.00
0005434137870	11953	Business	9700.00
0005434137659	11953	Economy	3200.00
0005434137423	11953	Economy	3200.00
0005434137681	11953	Economy	3200.00
0005434137785	11953	Economy	3200.00
0005434137761	11953	Economy	3200.00
0005434137859	11953	Economy	3200.00
0005434137449	11953	Economy	3200.00
0005434137850	11953	Economy	3200.00
0005434137691	11953	Economy	3500.00
0005434137377	11953	Economy	3500.00
0005434137857	11953	Economy	3500.00
0005434137800	11953	Economy	3500.00
0005434137754	11953	Economy	3500.00
0005434137695	11953	Economy	3200.00
0005434137792	11953	Economy	3200.00
0005434137611	11953	Economy	3200.00
0005434137573	11953	Economy	3200.00
0005434137568	11953	Economy	3200.00
0005434137637	11953	Economy	3200.00
0005434137703	11953	Economy	3200.00
0005434137495	11953	Economy	3200.00
0005434137518	11953	Economy	3200.00
0005434137442	11953	Economy	3200.00
0005434137744	11953	Economy	3200.00
0005434137592	11953	Economy	3200.00
0005434137672	11953	Economy	3200.00
0005434137725	11953	Economy	3200.00
0005434137582	11953	Economy	3200.00
0005434137696	11953	Economy	3200.00
0005434137802	11953	Economy	3200.00
0005434137847	11953	Economy	3200.00
0005434137634	11953	Economy	3200.00
0005434137523	11953	Economy	3200.00
0005434137840	11953	Economy	3200.00
0005434137690	11953	Economy	3200.00
0005434137567	11953	Economy	3200.00
0005434137849	11953	Economy	3200.00
0005434137540	11953	Economy	3200.00
0005434137878	11953	Economy	3200.00
0005434137845	11953	Economy	3200.00
0005434137583	11953	Economy	3200.00
0005434137654	11953	Economy	3200.00
0005434137755	11953	Economy	3200.00
0005434137799	11953	Economy	3200.00
0005434137376	11953	Economy	3200.00
0005434137752	11953	Economy	3200.00
0005434137614	11953	Economy	3200.00
0005434137336	11953	Economy	3200.00
0005434137677	11953	Economy	3200.00
0005434137865	11953	Economy	3200.00
0005434137564	11953	Economy	3200.00
0005434137556	11953	Economy	3200.00
0005434137359	11953	Economy	3200.00
0005434137671	11953	Economy	3200.00
0005434137839	11953	Economy	3200.00
0005434137524	11953	Economy	3200.00
0005434137788	11953	Economy	3200.00
0005434137676	11953	Economy	3200.00
0005434137584	11953	Economy	3200.00
0005434137244	11953	Economy	3200.00
0005434137818	11953	Economy	3200.00
0005434137743	11953	Economy	3200.00
0005434137773	11953	Economy	3200.00
0005434137762	11953	Economy	3200.00
0005434137786	11953	Economy	3200.00
0005434137789	11953	Economy	3200.00
0005434137879	11953	Economy	3200.00
0005434137794	11953	Economy	3200.00
0005434137653	11953	Economy	3200.00
0005434137429	11953	Economy	3200.00
0005434138317	28749	Business	9700.00
0005434138335	28749	Business	9700.00
0005434138331	28749	Business	9700.00
0005434138316	28749	Business	9700.00
0005434138342	28749	Business	9700.00
0005434138310	28749	Business	9700.00
0005434138385	28749	Business	9700.00
0005434138364	28749	Business	9700.00
0005434138348	28749	Business	9700.00
0005434138324	28749	Economy	3200.00
0005434138323	28749	Economy	3200.00
0005434138360	28749	Economy	3200.00
0005434138358	28749	Economy	3200.00
0005434138362	28749	Economy	3200.00
0005434138308	28749	Economy	3200.00
0005434138374	28749	Economy	3200.00
0005434138349	28749	Economy	3200.00
0005434138370	28749	Economy	3200.00
0005434138347	28749	Economy	3200.00
0005434138376	28749	Economy	3500.00
0005434138382	28749	Economy	3500.00
0005434138307	28749	Economy	3500.00
0005434138311	28749	Economy	3500.00
0005434138363	28749	Economy	3200.00
0005434138344	28749	Economy	3200.00
0005434138340	28749	Economy	3200.00
0005434138352	28749	Economy	3200.00
0005434138369	28749	Economy	3200.00
0005434138361	28749	Economy	3200.00
0005434138336	28749	Economy	3200.00
0005434138318	28749	Economy	3200.00
0005434138368	28749	Economy	3200.00
0005434138388	28749	Economy	3200.00
0005434138321	28749	Economy	3200.00
0005434138351	28749	Economy	3200.00
0005434138353	28749	Economy	3200.00
0005434138313	28749	Economy	3200.00
0005434138350	28749	Economy	3200.00
0005434138330	28749	Economy	3200.00
0005434138306	28749	Economy	3200.00
0005434138372	28749	Economy	3200.00
0005434138384	28749	Economy	3200.00
0005434138315	28749	Economy	3200.00
0005434138378	28749	Economy	3200.00
0005434138387	28749	Economy	3200.00
0005434138355	28749	Economy	3200.00
0005434138309	28749	Economy	3200.00
0005434138332	28749	Economy	3200.00
0005434138379	28749	Economy	3200.00
0005434138326	28749	Economy	3200.00
0005434138345	28749	Economy	3200.00
0005434138373	28749	Economy	3200.00
0005434138375	28749	Economy	3200.00
0005434138359	28749	Economy	3200.00
0005434138371	28749	Economy	3200.00
0005434138312	28749	Economy	3200.00
0005434138366	28749	Economy	3200.00
0005434138320	28749	Economy	3200.00
0005434138341	28749	Economy	3200.00
0005434138319	28749	Economy	3200.00
0005434138322	28749	Economy	3200.00
0005434138329	28749	Economy	3200.00
0005434138367	28749	Economy	3200.00
0005434138327	28749	Economy	3200.00
0005434138377	28749	Economy	3200.00
0005434138381	28749	Economy	3200.00
0005434138334	28749	Economy	3200.00
0005434138314	28749	Economy	3200.00
0005434138338	28749	Economy	3200.00
0005434138354	28749	Economy	3200.00
0005434138339	28749	Economy	3200.00
0005434138328	28749	Economy	3200.00
0005434138386	28749	Economy	3200.00
0005434138337	28749	Economy	3200.00
0005434138346	28749	Economy	3200.00
0005434138333	28749	Economy	3200.00
0005434138380	28749	Economy	3200.00
0005434138343	28749	Economy	3200.00
0005434138357	28749	Economy	3200.00
0005434138325	28749	Economy	3200.00
0005434138356	28749	Economy	3200.00
0005434138383	28749	Economy	3200.00
0005434138365	28749	Economy	3200.00
0005435312779	6579	Economy	23000.00
0005435312788	6579	Economy	20900.00
0005434466470	6579	Economy	20900.00
0005434466469	6579	Economy	20900.00
0005434466476	6579	Economy	20900.00
0005434466471	6579	Economy	20900.00
0005434466474	6579	Economy	20900.00
0005435312791	6579	Economy	20900.00
0005435312790	6579	Economy	20900.00
0005435312806	6579	Economy	20900.00
0005434466472	6579	Economy	20900.00
0005434466475	6579	Economy	20900.00
0005435312778	6579	Economy	20900.00
0005434466473	6579	Economy	20900.00
0005434466477	6579	Economy	20900.00
0005435312805	6579	Economy	20900.00
0005435312789	6579	Economy	20900.00
0005433538895	6780	Economy	10900.00
0005433538898	6780	Economy	10900.00
0005433538894	6780	Economy	10900.00
0005433538893	6780	Economy	9900.00
0005433538900	6780	Economy	9900.00
0005435259731	6780	Economy	9900.00
0005435259718	6780	Economy	9900.00
0005433538899	6780	Economy	9900.00
0005433534504	6780	Economy	9900.00
0005435259721	6780	Economy	9900.00
0005435259728	6780	Economy	9900.00
0005435259747	6780	Economy	9900.00
0005435259719	6780	Economy	9900.00
0005433538897	6780	Economy	9900.00
0005435259750	6780	Economy	9900.00
0005433534505	6780	Economy	9900.00
0005433538896	6780	Economy	9900.00
0005433538790	25020	Economy	9900.00
0005433538789	25020	Economy	9900.00
0005433538814	25020	Economy	9900.00
0005435259771	25020	Economy	9900.00
0005435259768	25020	Economy	9900.00
0005433534493	25020	Economy	9900.00
0005435259770	25020	Economy	9900.00
0005433534494	25020	Economy	9900.00
0005433538791	25020	Economy	9900.00
0005433538801	25020	Economy	9900.00
0005435259772	25020	Economy	9900.00
0005435259769	25020	Economy	9900.00
0005433538815	25020	Economy	9900.00
0005433534481	25020	Economy	9900.00
0005433511975	830	Economy	16100.00
0005433511973	830	Economy	14600.00
0005433511983	830	Economy	14600.00
0005432922506	830	Economy	14600.00
0005433511982	830	Economy	14600.00
0005433511974	830	Economy	14600.00
0005433511976	830	Economy	14600.00
0005433511977	830	Economy	14600.00
0005433511979	830	Economy	14600.00
0005432922497	830	Economy	14600.00
0005433511980	830	Economy	14600.00
0005433511981	830	Economy	14600.00
0005433511978	830	Economy	14600.00
0005433511894	16173	Economy	16100.00
0005433511912	16173	Economy	16100.00
0005433511919	16173	Economy	14600.00
0005432922536	16173	Economy	14600.00
0005432922538	16173	Economy	14600.00
0005433511910	16173	Economy	14600.00
0005433511909	16173	Economy	14600.00
0005433511916	16173	Economy	14600.00
0005432922537	16173	Economy	14600.00
0005433511921	16173	Economy	14600.00
0005433511892	16173	Economy	14600.00
0005433511918	16173	Economy	14600.00
0005432922539	16173	Economy	14600.00
0005433511893	16173	Economy	14600.00
0005433511890	16173	Economy	14600.00
0005433511908	16173	Economy	14600.00
0005433511913	16173	Economy	14600.00
0005435935020	3651	Economy	7900.00
0005434950542	3651	Economy	7900.00
0005435697426	3651	Economy	7900.00
0005435697420	3651	Economy	7200.00
0005435697438	3651	Economy	7200.00
0005435697422	3651	Economy	7200.00
0005435697440	3651	Economy	7200.00
0005435697437	3651	Economy	7200.00
0005435697424	3651	Economy	7200.00
0005435697417	3651	Economy	7200.00
0005435697436	3651	Economy	7200.00
0005435916163	3651	Economy	7200.00
0005435697443	3651	Economy	7200.00
0005435697434	3651	Economy	7200.00
0005435697432	3651	Economy	7200.00
0005435916156	3651	Economy	7200.00
0005435697421	3651	Economy	7200.00
0005435935029	3651	Economy	7200.00
0005434950544	3651	Economy	7200.00
0005434950546	3651	Economy	7200.00
0005435697430	3651	Economy	7200.00
0005435697429	3651	Economy	7200.00
0005435697441	3651	Economy	7200.00
0005435697442	3651	Economy	7200.00
0005435697418	3651	Economy	7200.00
0005435697433	3651	Economy	7200.00
0005434950541	3651	Economy	7200.00
0005435916161	3651	Economy	7200.00
0005435697427	3651	Economy	7200.00
0005435697423	3651	Economy	7200.00
0005435697431	3651	Economy	7200.00
0005435697419	3651	Economy	7200.00
0005434950543	3651	Economy	7200.00
0005435697428	3651	Economy	7200.00
0005435935028	3651	Economy	7200.00
0005435697435	3651	Economy	7200.00
0005435697445	3651	Economy	7200.00
0005435697425	3651	Economy	7200.00
0005435697444	3651	Economy	7200.00
0005434950545	3651	Economy	7200.00
0005435697439	3651	Economy	7200.00
0005435916162	3651	Economy	7200.00
0005435697149	16274	Economy	7900.00
0005435916177	16274	Economy	7900.00
0005435697165	16274	Economy	7900.00
0005435697168	16274	Economy	7200.00
0005435697286	16274	Economy	7200.00
0005434950498	16274	Economy	7200.00
0005435697124	16274	Economy	7200.00
0005435697301	16274	Economy	7200.00
0005435697267	16274	Economy	7200.00
0005435697214	16274	Economy	7200.00
0005435697224	16274	Economy	7200.00
0005435697131	16274	Economy	7200.00
0005435697107	16274	Economy	7200.00
0005435697285	16274	Economy	7200.00
0005435697205	16274	Economy	7200.00
0005435935055	16274	Economy	7200.00
0005435697104	16274	Economy	7200.00
0005435697134	16274	Economy	7200.00
0005434950499	16274	Economy	7200.00
0005435697123	16274	Economy	7200.00
0005435935056	16274	Economy	7200.00
0005435697132	16274	Economy	7200.00
0005435697141	16274	Economy	7200.00
0005435916175	16274	Economy	7200.00
0005435697204	16274	Economy	7200.00
0005435697166	16274	Economy	7200.00
0005435697140	16274	Economy	7200.00
0005435935054	16274	Economy	7200.00
0005435697074	16274	Economy	7200.00
0005435935057	16274	Economy	7200.00
0005435697108	16274	Economy	7200.00
0005435697275	16274	Economy	7200.00
0005435697302	16274	Economy	7200.00
0005435697223	16274	Economy	7200.00
0005435935053	16274	Economy	7200.00
0005435697268	16274	Economy	7200.00
0005435697239	16274	Economy	7200.00
0005435916176	16274	Economy	7200.00
0005435935052	16274	Economy	7200.00
0005433519473	3937	Economy	21300.00
0005432609746	3937	Economy	21300.00
0005432609744	3937	Economy	19300.00
0005434606838	3937	Economy	19300.00
0005432607581	3937	Economy	19300.00
0005433519475	3937	Economy	19300.00
0005433519474	3937	Economy	19300.00
0005435841471	3937	Economy	19300.00
0005432607579	3937	Economy	19300.00
0005433519470	3937	Economy	19300.00
0005432609743	3937	Economy	19300.00
0005432607580	3937	Economy	19300.00
0005432607578	3937	Economy	19300.00
0005434606837	3937	Economy	19300.00
0005432609742	3937	Economy	19300.00
0005432609745	3937	Economy	19300.00
0005433519471	3937	Economy	19300.00
0005433519472	3937	Economy	19300.00
0005435841475	3937	Economy	19300.00
0005432607582	3937	Economy	19300.00
0005435841465	3937	Economy	19300.00
0005435842323	3937	Economy	19300.00
0005432607577	3937	Economy	19300.00
0005434606797	22087	Economy	21300.00
0005434606809	22087	Economy	19300.00
0005433519428	22087	Economy	19300.00
0005435904897	22087	Economy	19300.00
0005435853616	22087	Economy	19300.00
0005433519429	22087	Economy	19300.00
0005435853619	22087	Economy	19300.00
0005433519427	22087	Economy	19300.00
0005435853618	22087	Economy	19300.00
0005434606796	22087	Economy	19300.00
0005435904896	22087	Economy	19300.00
0005434606795	22087	Economy	19300.00
0005435853617	22087	Economy	19300.00
0005433348950	793	Economy	3700.00
0005435628731	793	Economy	3700.00
0005435628735	793	Economy	3700.00
0005435628730	793	Economy	3700.00
0005433348958	793	Economy	3700.00
0005435628729	793	Economy	3700.00
0005435628733	793	Economy	3700.00
0005435628734	793	Economy	3700.00
0005435628728	793	Economy	3700.00
0005435628732	793	Economy	3700.00
0005435628715	15946	Economy	3700.00
0005433349008	15946	Economy	3700.00
0005435628717	15946	Economy	3700.00
0005433349011	15946	Economy	3700.00
0005435628693	15946	Economy	3700.00
0005433349007	15946	Economy	3700.00
0005433349010	15946	Economy	3700.00
0005435628692	15946	Economy	3700.00
0005433349006	15946	Economy	3700.00
0005433349009	15946	Economy	3700.00
0005434446523	17220	Economy	7100.00
0005434445253	17220	Economy	7100.00
0005434446521	17220	Economy	7100.00
0005434446522	17220	Economy	7100.00
0005434445252	17220	Economy	7100.00
0005433158122	17220	Economy	7100.00
0005434446524	17220	Economy	7100.00
0005434445226	17573	Economy	7100.00
0005434445227	17573	Economy	7100.00
0005434445233	17573	Economy	7100.00
0005434445234	17573	Economy	7100.00
0005433159320	17573	Economy	7100.00
0005434445235	17573	Economy	7100.00
0005434445237	17573	Economy	7100.00
0005433159321	17573	Economy	7100.00
0005435132917	7861	Economy	5400.00
0005435132921	7861	Economy	5400.00
0005435132911	7861	Economy	5400.00
0005435132915	7861	Economy	5400.00
0005435132919	7861	Economy	5400.00
0005435132920	7861	Economy	5400.00
0005435132912	7861	Economy	5400.00
0005435383118	7861	Economy	5400.00
0005435132916	7861	Economy	5400.00
0005435383132	7861	Economy	5400.00
0005435132914	7861	Economy	5400.00
0005435132918	7861	Economy	5400.00
0005435132913	7861	Economy	5400.00
0005435132856	33067	Economy	5400.00
0005435383166	33067	Economy	5400.00
0005435383169	33067	Economy	5400.00
0005435383165	33067	Economy	5400.00
0005435132833	33067	Economy	5400.00
0005435383167	33067	Economy	5400.00
0005435132832	33067	Economy	5400.00
0005435132816	33067	Economy	5400.00
0005435132871	33067	Economy	5400.00
0005435132857	33067	Economy	5400.00
0005435383168	33067	Economy	5400.00
0005435132864	33067	Economy	5400.00
0005435811088	4402	Business	133200.00
0005435811090	4402	Business	133200.00
0005435811095	4402	Economy	44400.00
0005435811086	4402	Economy	44400.00
0005435811089	4402	Economy	44400.00
0005435811087	4402	Economy	44400.00
0005435811085	4402	Economy	44400.00
0005435938877	4402	Economy	44400.00
0005435811094	4402	Economy	44400.00
0005435811091	4402	Economy	44400.00
0005435811092	4402	Economy	44400.00
0005435938878	4402	Economy	44400.00
0005435811093	4402	Economy	44400.00
0005435938895	29452	Business	133200.00
0005435938893	29452	Business	133200.00
0005435938896	29452	Economy	44400.00
0005435811038	29452	Economy	44400.00
0005435938894	29452	Economy	44400.00
0005435938892	29452	Economy	44400.00
0005435160337	7488	Economy	13800.00
0005435390201	7488	Economy	13800.00
0005435160340	7488	Economy	13800.00
0005435160341	7488	Economy	12500.00
0005435160334	7488	Economy	12500.00
0005435160339	7488	Economy	12500.00
0005435160338	7488	Economy	12500.00
0005435390191	7488	Economy	12500.00
0005435390192	7488	Economy	12500.00
0005435160342	7488	Economy	12500.00
0005435390207	7488	Economy	12500.00
0005435390234	7488	Economy	12500.00
0005435390215	7488	Economy	12500.00
0005435160333	7488	Economy	12500.00
0005435390187	7488	Economy	12500.00
0005435160343	7488	Economy	12500.00
0005435160335	7488	Economy	12500.00
0005435160336	7488	Economy	12500.00
0005435390188	7488	Economy	12500.00
0005435390202	7488	Economy	12500.00
0005435160268	29551	Economy	13800.00
0005435160251	29551	Economy	12500.00
0005435160212	29551	Economy	12500.00
0005435160289	29551	Economy	12500.00
0005435390264	29551	Economy	12500.00
0005435160213	29551	Economy	12500.00
0005435160214	29551	Economy	12500.00
0005435390265	29551	Economy	12500.00
0005435160250	29551	Economy	12500.00
0005435390262	29551	Economy	12500.00
0005435160240	29551	Economy	12500.00
0005435160284	29551	Economy	12500.00
0005435160278	29551	Economy	12500.00
0005435160235	29551	Economy	12500.00
0005435390259	29551	Economy	12500.00
0005435390261	29551	Economy	12500.00
0005435160237	29551	Economy	12500.00
0005435160267	29551	Economy	12500.00
0005435160236	29551	Economy	12500.00
0005435160285	29551	Economy	12500.00
0005435390260	29551	Economy	12500.00
0005435160223	29551	Economy	12500.00
0005435390263	29551	Economy	12500.00
0005432398176	18474	Economy	4900.00
0005435178996	18474	Economy	4900.00
0005432398165	18474	Economy	4900.00
0005432394067	18474	Economy	4900.00
0005432398163	18474	Economy	4900.00
0005432398177	18474	Economy	4900.00
0005432398178	18474	Economy	4900.00
0005435178501	18474	Economy	4900.00
0005435178997	18474	Economy	4900.00
0005432398189	18474	Economy	4900.00
0005432398173	18474	Economy	4900.00
0005435178486	27155	Economy	4900.00
0005432400132	27155	Economy	4900.00
0005435178489	27155	Economy	4900.00
0005435179390	27155	Economy	4900.00
0005432398204	27155	Economy	4900.00
0005432400131	27155	Economy	4900.00
0005432400134	27155	Economy	4900.00
0005432400133	27155	Economy	4900.00
0005435178484	27155	Economy	4900.00
0005432398205	27155	Economy	4900.00
0005432865971	2249	Business	87300.00
0005432639166	2249	Business	87300.00
0005432639165	2249	Business	87300.00
0005432639176	2249	Business	87300.00
0005432865967	2249	Economy	29100.00
0005432639175	2249	Economy	29100.00
0005432865962	2249	Economy	29100.00
0005432639158	2249	Economy	29100.00
0005432639179	2249	Economy	29100.00
0005432639164	2249	Economy	29100.00
0005432639173	2249	Economy	29100.00
0005432865970	2249	Economy	29100.00
0005432639180	2249	Economy	29100.00
0005432639163	2249	Economy	29100.00
0005432639178	2249	Economy	29100.00
0005432639170	2249	Economy	29100.00
0005432639171	2249	Economy	29100.00
0005432639162	2249	Economy	29100.00
0005432865936	2249	Economy	29100.00
0005432639168	2249	Economy	29100.00
0005432639160	2249	Economy	29100.00
0005432639182	2249	Economy	29100.00
0005432639174	2249	Economy	29100.00
0005432865953	2249	Economy	29100.00
0005432639161	2249	Economy	29100.00
0005432639177	2249	Economy	29100.00
0005432639172	2249	Economy	29100.00
0005432865954	2249	Economy	29100.00
0005432865993	2249	Economy	29100.00
0005432865968	2249	Economy	29100.00
0005432639169	2249	Economy	29100.00
0005432639159	2249	Economy	29100.00
0005432639167	2249	Economy	29100.00
0005432866006	2249	Economy	29100.00
0005432639157	2249	Economy	29100.00
0005432865952	2249	Economy	29100.00
0005432639181	2249	Economy	29100.00
0005433811639	24298	Economy	35100.00
0005433811640	24298	Economy	35100.00
0005433811642	24298	Economy	35100.00
0005433811638	24298	Economy	35100.00
0005433811634	24298	Economy	35100.00
0005433811641	24298	Economy	38600.00
0005433811636	24298	Economy	38600.00
0005433811644	24298	Economy	35100.00
0005433811643	24298	Economy	35100.00
0005433811637	24298	Economy	35100.00
0005433811633	24298	Economy	35100.00
0005433811635	24298	Economy	35100.00
0005434191282	32793	Economy	4400.00
0005434191279	32793	Economy	4400.00
0005434191280	32793	Economy	4400.00
0005434191281	32793	Economy	4400.00
0005434191278	32793	Economy	4400.00
0005434191277	32793	Economy	4400.00
0005434191283	32793	Economy	4400.00
0005434191284	32793	Economy	4400.00
0005434191274	32793	Economy	4400.00
0005434191276	32793	Economy	4400.00
0005434191275	32793	Economy	4400.00
0005432658560	26491	Business	92200.00
0005432661908	26491	Business	92200.00
0005432661906	26491	Business	92200.00
0005432658563	26491	Business	92200.00
0005432658568	26491	Business	92200.00
0005432661901	26491	Business	92200.00
0005432661907	26491	Business	92200.00
0005432658571	26491	Economy	30700.00
0005432665251	26491	Business	92200.00
0005432658580	26491	Economy	30700.00
0005432661912	26491	Economy	30700.00
0005432665253	26491	Economy	30700.00
0005432661905	26491	Economy	30700.00
0005432661904	26491	Economy	30700.00
0005432658558	26491	Economy	33800.00
0005432658570	26491	Economy	33800.00
0005432658581	26491	Economy	33800.00
0005432665260	26491	Economy	30700.00
0005432658559	26491	Economy	30700.00
0005432661903	26491	Economy	30700.00
0005432661899	26491	Economy	30700.00
0005432661898	26491	Economy	30700.00
0005432658569	26491	Economy	30700.00
0005432665259	26491	Economy	30700.00
0005432665256	26491	Economy	30700.00
0005432658575	26491	Economy	30700.00
0005432665254	26491	Economy	30700.00
0005432658562	26491	Economy	30700.00
0005432665266	26491	Economy	30700.00
0005432658574	26491	Economy	30700.00
0005432665257	26491	Economy	30700.00
0005432661910	26491	Economy	30700.00
0005432658577	26491	Economy	30700.00
0005432665258	26491	Economy	30700.00
0005432665248	26491	Economy	30700.00
0005432658564	26491	Economy	30700.00
0005432658573	26491	Economy	30700.00
0005432665252	26491	Economy	30700.00
0005432658576	26491	Economy	30700.00
0005432658557	26491	Economy	30700.00
0005432661902	26491	Economy	30700.00
0005432665255	26491	Economy	30700.00
0005432665265	26491	Economy	30700.00
0005432665267	26491	Economy	30700.00
0005432665246	26491	Economy	30700.00
0005432661909	26491	Economy	30700.00
0005432665247	26491	Economy	30700.00
0005435103957	6539	Business	48400.00
0005434504285	6539	Business	48400.00
0005435103961	6539	Business	48400.00
0005434504288	6539	Business	48400.00
0005434504289	6539	Business	48400.00
0005434504265	6539	Business	48400.00
0005435103956	6539	Business	48400.00
0005434504282	6539	Business	48400.00
0005434504286	6539	Economy	16100.00
0005434504262	6539	Economy	16100.00
0005434504270	6539	Economy	16100.00
0005434504261	6539	Economy	17800.00
0005435103955	6539	Economy	17800.00
0005434504300	6539	Economy	16100.00
0005434504264	6539	Economy	16100.00
0005434504281	6539	Economy	16100.00
0005434504277	6539	Economy	16100.00
0005434504298	6539	Economy	16100.00
0005435103958	6539	Economy	16100.00
0005434504267	6539	Economy	16100.00
0005434504295	6539	Economy	16100.00
0005434504296	6539	Economy	16100.00
0005434504263	6539	Economy	16100.00
0005434504294	6539	Economy	16100.00
0005434504284	6539	Economy	16100.00
0005434504292	6539	Economy	16100.00
0005435103954	6539	Economy	16100.00
0005434504274	6539	Economy	16100.00
0005434504272	6539	Economy	16100.00
0005435103960	6539	Economy	16100.00
0005434504269	6539	Economy	16100.00
0005434504299	6539	Economy	16100.00
0005434504268	6539	Economy	16100.00
0005434504280	6539	Economy	16100.00
0005435103959	6539	Economy	16100.00
0005434504293	6539	Economy	16100.00
0005434504290	6539	Economy	16100.00
0005434504283	6539	Economy	16100.00
0005434504279	6539	Economy	16100.00
0005434504291	6539	Economy	16100.00
0005434504276	6539	Economy	16100.00
0005434504273	6539	Economy	16100.00
0005434504297	6539	Economy	16100.00
0005434504287	6539	Economy	16100.00
0005434504266	6539	Economy	16100.00
0005434504275	6539	Economy	16100.00
0005434504278	6539	Economy	16100.00
0005434504271	6539	Economy	16100.00
0005434503782	22665	Business	48400.00
0005434504020	22665	Business	48400.00
0005434503771	22665	Business	48400.00
0005434503834	22665	Business	48400.00
0005434503878	22665	Business	48400.00
0005434503804	22665	Business	48400.00
0005435103843	22665	Business	48400.00
0005434503646	22665	Economy	16100.00
0005434503700	22665	Economy	16100.00
0005434503883	22665	Economy	16100.00
0005434503880	22665	Economy	16100.00
0005434503805	22665	Economy	16100.00
0005434503770	22665	Economy	16100.00
0005434503942	22665	Economy	16100.00
0005434503980	22665	Economy	16100.00
0005434503634	22665	Economy	16100.00
0005434504021	22665	Economy	16100.00
0005434504013	22665	Economy	16100.00
0005434504011	22665	Economy	16100.00
0005434503971	22665	Economy	16100.00
0005434503886	22665	Economy	16100.00
0005434503877	22665	Economy	16100.00
0005434504006	22665	Economy	16100.00
0005434503922	22665	Economy	16100.00
0005434503647	22665	Economy	16100.00
0005434504012	22665	Economy	16100.00
0005434503851	22665	Economy	16100.00
0005435103842	22665	Economy	16100.00
0005434503898	22665	Economy	16100.00
0005434503981	22665	Economy	16100.00
0005434504049	22665	Economy	16100.00
0005434503921	22665	Economy	16100.00
0005434503769	22665	Economy	16100.00
0005434503835	22665	Economy	16100.00
0005434504051	22665	Economy	16100.00
0005434503892	22665	Economy	16100.00
0005434503781	22665	Economy	16100.00
0005434503941	22665	Economy	16100.00
0005434503635	22665	Economy	16100.00
0005434503963	22665	Economy	16100.00
0005434503678	22665	Economy	16100.00
0005433367709	1640	Business	50000.00
0005435653218	1640	Business	50000.00
0005435653214	1640	Business	50000.00
0005435653234	1640	Business	50000.00
0005433367761	1640	Business	50000.00
0005435653192	1640	Business	50000.00
0005435653226	1640	Business	50000.00
0005433367677	1640	Business	50000.00
0005435653202	1640	Business	50000.00
0005435653205	1640	Economy	16700.00
0005435653221	1640	Economy	16700.00
0005433367661	1640	Economy	16700.00
0005433367600	1640	Economy	16700.00
0005435653220	1640	Economy	16700.00
0005435653196	1640	Economy	16700.00
0005435653224	1640	Economy	16700.00
0005435653195	1640	Economy	16700.00
0005433367805	1640	Economy	16700.00
0005435653233	1640	Economy	16700.00
0005435653200	1640	Economy	18300.00
0005435653227	1640	Economy	18300.00
0005433367676	1640	Economy	18300.00
0005435653236	1640	Economy	18300.00
0005435653229	1640	Economy	18300.00
0005433367701	1640	Economy	16700.00
0005433367555	1640	Economy	16700.00
0005435653232	1640	Economy	16700.00
0005435653208	1640	Economy	16700.00
0005435653215	1640	Economy	16700.00
0005433367528	1640	Economy	16700.00
0005435653213	1640	Economy	16700.00
0005433367713	1640	Economy	16700.00
0005433367675	1640	Economy	16700.00
0005435653235	1640	Economy	16700.00
0005435653230	1640	Economy	16700.00
0005435653198	1640	Economy	16700.00
0005433367747	1640	Economy	16700.00
0005433367467	1640	Economy	16700.00
0005435653206	1640	Economy	16700.00
0005435653219	1640	Economy	16700.00
0005433367728	1640	Economy	16700.00
0005433367678	1640	Economy	16700.00
0005433367554	1640	Economy	16700.00
0005435653193	1640	Economy	16700.00
0005433367660	1640	Economy	16700.00
0005433367686	1640	Economy	16700.00
0005435653194	1640	Economy	16700.00
0005433367601	1640	Economy	16700.00
0005435653222	1640	Economy	16700.00
0005435653231	1640	Economy	16700.00
0005435653197	1640	Economy	16700.00
0005433367746	1640	Economy	16700.00
0005435653212	1640	Economy	16700.00
0005433367730	1640	Economy	16700.00
0005433367634	1640	Economy	16700.00
0005435653210	1640	Economy	16700.00
0005435653211	1640	Economy	16700.00
0005435653204	1640	Economy	16700.00
0005433367599	1640	Economy	16700.00
0005435653225	1640	Economy	16700.00
0005433367646	1640	Economy	16700.00
0005435653203	1640	Economy	16700.00
0005433367779	1640	Economy	16700.00
0005435653216	1640	Economy	16700.00
0005435653223	1640	Economy	16700.00
0005433367804	1640	Economy	16700.00
0005435653201	1640	Economy	16700.00
0005435653207	1640	Economy	16700.00
0005435653228	1640	Economy	16700.00
0005433367702	1640	Economy	16700.00
0005433367651	1640	Economy	16700.00
0005435653199	1640	Economy	16700.00
0005435653217	1640	Economy	16700.00
0005433367870	1640	Economy	16700.00
0005435653209	1640	Economy	16700.00
0005433367658	1640	Economy	16700.00
0005433367650	1640	Economy	16700.00
0005433367635	1640	Economy	16700.00
0005435652726	21703	Business	50000.00
0005435652557	21703	Business	50000.00
0005435652520	21703	Business	50000.00
0005433368003	21703	Business	50000.00
0005433367999	21703	Business	50000.00
0005433367998	21703	Business	50000.00
0005435652719	21703	Business	50000.00
0005435652759	21703	Business	50000.00
0005435652720	21703	Business	50000.00
0005435652695	21703	Business	50000.00
0005435652674	21703	Business	50000.00
0005433368002	21703	Business	50000.00
0005433368011	21703	Economy	16700.00
0005433368021	21703	Economy	16700.00
0005435652699	21703	Economy	16700.00
0005435652698	21703	Economy	16700.00
0005433368020	21703	Economy	16700.00
0005435652519	21703	Economy	16700.00
0005435652758	21703	Economy	16700.00
0005435652781	21703	Economy	16700.00
0005435652756	21703	Economy	16700.00
0005433368014	21703	Economy	18300.00
0005433368000	21703	Economy	18300.00
0005433368001	21703	Economy	18300.00
0005435652687	21703	Economy	18300.00
0005433367987	21703	Economy	18300.00
0005433367994	21703	Economy	16700.00
0005435652672	21703	Economy	16700.00
0005435652585	21703	Economy	16700.00
0005433368022	21703	Economy	16700.00
0005433367989	21703	Economy	16700.00
0005435652713	21703	Economy	16700.00
0005435652694	21703	Economy	16700.00
0005433368007	21703	Economy	16700.00
0005433367992	21703	Economy	16700.00
0005433367991	21703	Economy	16700.00
0005433368006	21703	Economy	16700.00
0005433368023	21703	Economy	16700.00
0005433368018	21703	Economy	16700.00
0005435652772	21703	Economy	16700.00
0005433368009	21703	Economy	16700.00
0005435652780	21703	Economy	16700.00
0005433368025	21703	Economy	16700.00
0005435652666	21703	Economy	16700.00
0005435652559	21703	Economy	16700.00
0005433367993	21703	Economy	16700.00
0005435652586	21703	Economy	16700.00
0005435652692	21703	Economy	16700.00
0005435652543	21703	Economy	16700.00
0005435652751	21703	Economy	16700.00
0005435652768	21703	Economy	16700.00
0005435652733	21703	Economy	16700.00
0005433368015	21703	Economy	16700.00
0005435652741	21703	Economy	16700.00
0005433368013	21703	Economy	16700.00
0005435652544	21703	Economy	16700.00
0005433368008	21703	Economy	16700.00
0005435652668	21703	Economy	16700.00
0005435652789	21703	Economy	16700.00
0005433368019	21703	Economy	16700.00
0005433367996	21703	Economy	16700.00
0005435652491	21703	Economy	16700.00
0005433368017	21703	Economy	16700.00
0005435652669	21703	Economy	16700.00
0005435652673	21703	Economy	16700.00
0005435652771	21703	Economy	16700.00
0005433367988	21703	Economy	16700.00
0005435652521	21703	Economy	16700.00
0005435652792	21703	Economy	16700.00
0005435652682	21703	Economy	16700.00
0005433367990	21703	Economy	16700.00
0005433368004	21703	Economy	16700.00
0005435652643	21703	Economy	16700.00
0005435652725	21703	Economy	16700.00
0005433368024	21703	Economy	16700.00
0005433367997	21703	Economy	16700.00
0005433367995	21703	Economy	16700.00
0005435652667	21703	Economy	16700.00
0005435652760	21703	Economy	16700.00
0005435652791	21703	Economy	16700.00
0005435652740	21703	Economy	16700.00
0005435652714	21703	Economy	16700.00
0005435652715	21703	Economy	16700.00
0005433368005	21703	Economy	16700.00
0005433368010	21703	Economy	16700.00
0005433368012	21703	Economy	16700.00
0005435652710	21703	Economy	16700.00
0005433368016	21703	Economy	16700.00
0005435652675	21703	Economy	16700.00
0005435652556	21703	Economy	16700.00
0005435627119	12270	Economy	11200.00
0005435627120	12270	Economy	11200.00
0005435627114	23816	Economy	11200.00
0005435627115	23816	Economy	11200.00
0005435312815	23241	Economy	23000.00
0005434466449	23241	Economy	20900.00
0005434466448	23241	Economy	20900.00
0005435312814	23241	Economy	20900.00
0005434466420	23241	Economy	20900.00
0005435312812	23241	Economy	20900.00
0005435312813	23241	Economy	20900.00
0005434466430	23241	Economy	20900.00
0005435312816	23241	Economy	20900.00
0005434466435	23241	Economy	20900.00
0005434466453	23241	Economy	20900.00
0005434466428	23241	Economy	20900.00
0005433986121	4173	Business	21500.00
0005433986118	4173	Business	21500.00
0005433986129	4173	Business	21500.00
0005433986111	4173	Business	21500.00
0005433986093	4173	Business	21500.00
0005433986083	4173	Business	21500.00
0005433986122	4173	Economy	7200.00
0005433986112	4173	Economy	7200.00
0005433986108	4173	Economy	7200.00
0005433986105	4173	Economy	7200.00
0005433986092	4173	Economy	7200.00
0005433986077	4173	Economy	7200.00
0005433986079	4173	Economy	7200.00
0005433986116	4173	Economy	7900.00
0005433986107	4173	Economy	7900.00
0005433986089	4173	Economy	7900.00
0005433986097	4173	Economy	7900.00
0005433986085	4173	Economy	7900.00
0005433986124	4173	Economy	7200.00
0005433986088	4173	Economy	7200.00
0005433986087	4173	Economy	7200.00
0005433986123	4173	Economy	7200.00
0005433986084	4173	Economy	7200.00
0005435788779	4173	Economy	7200.00
0005433986099	4173	Economy	7200.00
0005433986100	4173	Economy	7200.00
0005433986091	4173	Economy	7200.00
0005435788780	4173	Economy	7200.00
0005433986098	4173	Economy	7200.00
0005433986126	4173	Economy	7200.00
0005433986125	4173	Economy	7200.00
0005433986095	4173	Economy	7200.00
0005433986109	4173	Economy	7200.00
0005433986110	4173	Economy	7200.00
0005433986080	4173	Economy	7200.00
0005433986076	4173	Economy	7200.00
0005433986104	4173	Economy	7200.00
0005433986078	4173	Economy	7200.00
0005433986090	4173	Economy	7200.00
0005433986115	4173	Economy	7200.00
0005433986114	4173	Economy	7200.00
0005433986086	4173	Economy	7200.00
0005433986094	4173	Economy	7200.00
0005433986096	4173	Economy	7200.00
0005433986106	4173	Economy	7200.00
0005433986120	4173	Economy	7200.00
0005433986117	4173	Economy	7200.00
0005433986081	4173	Economy	7200.00
0005433986102	4173	Economy	7200.00
0005433986128	4173	Economy	7200.00
0005433986101	4173	Economy	7200.00
0005433986082	4173	Economy	7200.00
0005433986127	4173	Economy	7200.00
0005433986113	4173	Economy	7200.00
0005433986119	4173	Economy	7200.00
0005433986103	4173	Economy	7200.00
0005433985725	25691	Business	21500.00
0005433985674	25691	Business	21500.00
0005433985555	25691	Business	21500.00
0005433985750	25691	Business	21500.00
0005433985502	25691	Business	21500.00
0005433985704	25691	Business	21500.00
0005433985768	25691	Business	21500.00
0005433985593	25691	Economy	7200.00
0005433985757	25691	Economy	7200.00
0005433985742	25691	Economy	7200.00
0005433985556	25691	Economy	7200.00
0005433985670	25691	Economy	7200.00
0005433985601	25691	Economy	7200.00
0005433985518	25691	Economy	7200.00
0005433985512	25691	Economy	7200.00
0005433985769	25691	Economy	7200.00
0005433985501	25691	Economy	7200.00
0005433985575	25691	Economy	7200.00
0005433985602	25691	Economy	7200.00
0005433985519	25691	Economy	7200.00
0005433985675	25691	Economy	7200.00
0005433985815	25691	Economy	7200.00
0005433985530	25691	Economy	7200.00
0005433985578	25691	Economy	7200.00
0005433985734	25691	Economy	7200.00
0005433985513	25691	Economy	7200.00
0005433985503	25691	Economy	7200.00
0005433985834	25691	Economy	7200.00
0005433985319	25691	Economy	7200.00
0005433985653	25691	Economy	7200.00
0005435788758	25691	Economy	7200.00
0005433985738	25691	Economy	7200.00
0005433985682	25691	Economy	7200.00
0005433985703	25691	Economy	7200.00
0005433985661	25691	Economy	7200.00
0005433985683	25691	Economy	7200.00
0005433985603	25691	Economy	7200.00
0005433985604	25691	Economy	7200.00
0005433985669	25691	Economy	7200.00
0005433985821	25691	Economy	7200.00
0005433985596	25691	Economy	7200.00
0005433985681	25691	Economy	7200.00
0005433985579	25691	Economy	7200.00
0005433985724	25691	Economy	7200.00
0005433985574	25691	Economy	7200.00
0005435720814	21251	Economy	9400.00
0005435719562	21251	Economy	9400.00
0005435719561	21251	Economy	9400.00
0005435720813	21251	Economy	9400.00
0005435720136	24769	Economy	10400.00
0005435720135	24769	Economy	9400.00
0005433168351	1617	Economy	17000.00
0005433168340	1617	Economy	15500.00
0005434509176	1617	Economy	15500.00
0005434509168	1617	Economy	15500.00
0005434509164	1617	Economy	15500.00
0005434509174	1617	Economy	15500.00
0005433168352	1617	Economy	15500.00
0005433168371	1617	Economy	15500.00
0005434509173	1617	Economy	15500.00
0005434509178	1617	Economy	15500.00
0005434509171	1617	Economy	15500.00
0005434509165	1617	Economy	15500.00
0005434509167	1617	Economy	15500.00
0005434509169	1617	Economy	15500.00
0005434509175	1617	Economy	15500.00
0005434509180	1617	Economy	15500.00
0005433168353	1617	Economy	15500.00
0005434509170	1617	Economy	15500.00
0005434509166	1617	Economy	15500.00
0005434509172	1617	Economy	15500.00
0005434509179	1617	Economy	15500.00
0005434509163	1617	Economy	15500.00
0005434509177	1617	Economy	15500.00
0005434190391	9017	Economy	26000.00
0005434516087	9017	Economy	26000.00
0005434516083	9017	Economy	23600.00
0005434516084	9017	Economy	23600.00
0005434190387	9017	Economy	23600.00
0005434516081	9017	Economy	23600.00
0005434516086	9017	Economy	23600.00
0005434190388	9017	Economy	23600.00
0005434190386	9017	Economy	23600.00
0005434516082	9017	Economy	23600.00
0005434190399	9017	Economy	23600.00
0005434190393	9017	Economy	23600.00
0005434516085	9017	Economy	23600.00
0005434190394	9017	Economy	23600.00
0005434190392	9017	Economy	23600.00
0005434190390	9017	Economy	23600.00
0005432869550	17840	Business	18000.00
0005432869546	17840	Business	18000.00
0005432665262	17840	Business	18000.00
0005432666382	17840	Business	18000.00
0005432660796	17840	Business	18000.00
0005432667438	17840	Economy	6000.00
0005432667437	17840	Economy	6000.00
0005432660807	17840	Economy	6600.00
0005432655421	17840	Economy	6600.00
0005432664118	17840	Economy	6000.00
0005432655387	17840	Economy	6000.00
0005432655445	17840	Economy	6000.00
0005432666369	17840	Economy	6000.00
0005432657444	17840	Economy	6000.00
0005432655453	17840	Economy	6000.00
0005434151715	17840	Economy	6000.00
0005432664128	17840	Economy	6000.00
0005434151714	17840	Economy	6000.00
0005434151716	17840	Economy	6000.00
0005432869548	17840	Economy	6000.00
0005432655479	17840	Economy	6000.00
0005432665261	17840	Economy	6000.00
0005432869549	17840	Economy	6000.00
0005432664119	17840	Economy	6000.00
0005432657443	17840	Economy	6000.00
0005432869551	17840	Economy	6000.00
0005432869547	17840	Economy	6000.00
0005432666367	17840	Economy	6000.00
0005432655480	17840	Economy	6000.00
0005432657429	17840	Economy	6000.00
0005432666368	17840	Economy	6000.00
0005432663015	17840	Economy	6000.00
0005432658578	17840	Economy	6000.00
0005432869552	17840	Economy	6000.00
0005432667447	17840	Economy	6000.00
0005432665278	26324	Business	18000.00
0005432655552	26324	Business	18000.00
0005432655556	26324	Business	18000.00
0005432655547	26324	Economy	6000.00
0005432667458	26324	Economy	6000.00
0005432655553	26324	Economy	6000.00
0005432666393	26324	Economy	6000.00
0005432657455	26324	Economy	6000.00
0005432869464	26324	Economy	6000.00
0005432658595	26324	Economy	6600.00
0005432666392	26324	Economy	6000.00
0005432869453	26324	Economy	6000.00
0005432660821	26324	Economy	6000.00
0005432659709	26324	Economy	6000.00
0005432869465	26324	Economy	6000.00
0005432655548	26324	Economy	6000.00
0005432869476	26324	Economy	6000.00
0005432655550	26324	Economy	6000.00
0005432869467	26324	Economy	6000.00
0005432667457	26324	Economy	6000.00
0005432657456	26324	Economy	6000.00
0005432655549	26324	Economy	6000.00
0005432660822	26324	Economy	6000.00
0005432655555	26324	Economy	6000.00
0005432659710	26324	Economy	6000.00
0005432657453	26324	Economy	6000.00
0005432657454	26324	Economy	6000.00
0005432655557	26324	Economy	6000.00
0005432665279	26324	Economy	6000.00
0005432655551	26324	Economy	6000.00
0005432655546	26324	Economy	6000.00
0005432655554	26324	Economy	6000.00
0005432869466	26324	Economy	6000.00
0005432866036	25070	Business	87300.00
0005432639032	25070	Business	87300.00
0005432639025	25070	Business	87300.00
0005432866034	25070	Business	87300.00
0005432639057	25070	Business	87300.00
0005432866041	25070	Business	87300.00
0005432639126	25070	Business	87300.00
0005432639070	25070	Business	87300.00
0005432639019	25070	Economy	29100.00
0005432639026	25070	Economy	29100.00
0005432639055	25070	Economy	29100.00
0005432639035	25070	Economy	29100.00
0005432866030	25070	Economy	29100.00
0005432639069	25070	Economy	32000.00
0005432866037	25070	Economy	32000.00
0005432866039	25070	Economy	29100.00
0005432639088	25070	Economy	29100.00
0005432639018	25070	Economy	29100.00
0005432866035	25070	Economy	29100.00
0005432866040	25070	Economy	29100.00
0005432639015	25070	Economy	29100.00
0005432866033	25070	Economy	29100.00
0005432866038	25070	Economy	29100.00
0005432639006	25070	Economy	29100.00
0005432639005	25070	Economy	29100.00
0005432866032	25070	Economy	29100.00
0005432639067	25070	Economy	29100.00
0005432639066	25070	Economy	29100.00
0005432639031	25070	Economy	29100.00
0005432639068	25070	Economy	29100.00
0005432639017	25070	Economy	29100.00
0005432639127	25070	Economy	29100.00
0005432866042	25070	Economy	29100.00
0005432639007	25070	Economy	29100.00
0005432866043	25070	Economy	29100.00
0005432639065	25070	Economy	29100.00
0005432639056	25070	Economy	29100.00
0005432866031	25070	Economy	29100.00
0005432639086	25070	Economy	29100.00
0005432639064	25070	Economy	29100.00
0005432639016	25070	Economy	29100.00
0005432639087	25070	Economy	29100.00
0005432639048	25070	Economy	29100.00
0005433438902	3090	Business	16100.00
0005432328845	3090	Business	16100.00
0005432905111	3090	Business	16100.00
0005432905079	3090	Business	16100.00
0005432328838	3090	Business	16100.00
0005432905080	3090	Business	16100.00
0005433438899	3090	Business	16100.00
0005432328850	3090	Business	16100.00
0005432328846	3090	Business	16100.00
0005432328844	3090	Economy	5400.00
0005432328840	3090	Economy	5400.00
0005433438900	3090	Economy	5400.00
0005432287209	3090	Economy	5400.00
0005432328851	3090	Economy	5400.00
0005432328837	3090	Economy	5400.00
0005432328875	3090	Economy	5900.00
0005432328862	3090	Economy	5900.00
0005432328870	3090	Economy	5900.00
0005432328842	3090	Economy	5900.00
0005432905115	3090	Economy	5400.00
0005432328858	3090	Economy	5400.00
0005432328831	3090	Economy	5400.00
0005432328852	3090	Economy	5400.00
0005432287208	3090	Economy	5400.00
0005432287207	3090	Economy	5400.00
0005432328853	3090	Economy	5400.00
0005432328864	3090	Economy	5400.00
0005432328873	3090	Economy	5400.00
0005432287206	3090	Economy	5400.00
0005432328867	3090	Economy	5400.00
0005432328860	3090	Economy	5400.00
0005432328854	3090	Economy	5400.00
0005432905101	3090	Economy	5400.00
0005432328835	3090	Economy	5400.00
0005432328869	3090	Economy	5400.00
0005432905110	3090	Economy	5400.00
0005432905102	3090	Economy	5400.00
0005432328833	3090	Economy	5400.00
0005432287205	3090	Economy	5400.00
0005432328876	3090	Economy	5400.00
0005432905103	3090	Economy	5400.00
0005432328871	3090	Economy	5400.00
0005432328839	3090	Economy	5400.00
0005432328836	3090	Economy	5400.00
0005432328866	3090	Economy	5400.00
0005432328865	3090	Economy	5400.00
0005432328855	3090	Economy	5400.00
0005432328848	3090	Economy	5400.00
0005432848837	3090	Economy	5400.00
0005432328834	3090	Economy	5400.00
0005432905117	3090	Economy	5400.00
0005432328857	3090	Economy	5400.00
0005433438901	3090	Economy	5400.00
0005432328841	3090	Economy	5400.00
0005432328849	3090	Economy	5400.00
0005432328843	3090	Economy	5400.00
0005432328856	3090	Economy	5400.00
0005432328832	3090	Economy	5400.00
0005432328859	3090	Economy	5400.00
0005432328868	3090	Economy	5400.00
0005432328872	3090	Economy	5400.00
0005432328874	3090	Economy	5400.00
0005432328861	3090	Economy	5400.00
0005432328863	3090	Economy	5400.00
0005432328847	3090	Economy	5400.00
0005433438819	31111	Business	16100.00
0005432848840	31111	Business	16100.00
0005432328370	31111	Business	16100.00
0005432328386	31111	Business	16100.00
0005432848839	31111	Business	16100.00
0005432328509	31111	Business	16100.00
0005432328447	31111	Business	16100.00
0005432328328	31111	Business	16100.00
0005432328432	31111	Economy	5400.00
0005432848838	31111	Economy	5400.00
0005432328465	31111	Economy	5400.00
0005432328593	31111	Economy	5400.00
0005432328314	31111	Economy	5400.00
0005432328564	31111	Economy	5400.00
0005432328493	31111	Economy	5400.00
0005432328480	31111	Economy	5900.00
0005432328380	31111	Economy	5400.00
0005432328387	31111	Economy	5400.00
0005433438820	31111	Economy	5400.00
0005432328463	31111	Economy	5400.00
0005432328472	31111	Economy	5400.00
0005432328442	31111	Economy	5400.00
0005432328389	31111	Economy	5400.00
0005432328528	31111	Economy	5400.00
0005432328280	31111	Economy	5400.00
0005432054314	31111	Economy	5400.00
0005432328457	31111	Economy	5400.00
0005432905145	31111	Economy	5400.00
0005432328635	31111	Economy	5400.00
0005432328570	31111	Economy	5400.00
0005432328478	31111	Economy	5400.00
0005432328443	31111	Economy	5400.00
0005432328503	31111	Economy	5400.00
0005432328277	31111	Economy	5400.00
0005432905143	31111	Economy	5400.00
0005432328473	31111	Economy	5400.00
0005432328167	31111	Economy	5400.00
0005432905144	31111	Economy	5400.00
0005432328065	31111	Economy	5400.00
0005432328441	31111	Economy	5400.00
0005433438864	31111	Economy	5400.00
0005433438834	31111	Economy	5400.00
0005432328064	31111	Economy	5400.00
0005432328228	31111	Economy	5400.00
0005432328504	31111	Economy	5400.00
0005432328562	31111	Economy	5400.00
0005432328240	31111	Economy	5400.00
0005433438858	31111	Economy	5400.00
0005432328481	31111	Economy	5400.00
0005432328634	31111	Economy	5400.00
0005433438845	31111	Economy	5400.00
0005433438833	31111	Economy	5400.00
0005432328477	31111	Economy	5400.00
0005432328550	31111	Economy	5400.00
0005432328417	31111	Economy	5400.00
0005432328388	31111	Economy	5400.00
0005432328448	31111	Economy	5400.00
0005433438821	31111	Economy	5400.00
0005432328359	31111	Economy	5400.00
0005435296992	6174	Business	124600.00
0005435999322	6174	Business	124600.00
0005435999302	6174	Business	124600.00
0005435999300	6174	Business	124600.00
0005434309793	6174	Business	124600.00
0005435487655	6174	Business	124600.00
0005435999320	6174	Economy	41500.00
0005435487733	6174	Economy	41500.00
0005435487738	6174	Economy	41500.00
0005435487675	6174	Economy	41500.00
0005435297021	6174	Economy	41500.00
0005435999304	6174	Economy	41500.00
0005435487693	6174	Economy	41500.00
0005434309790	6174	Economy	41500.00
0005435487757	6174	Economy	41500.00
0005435999316	6174	Economy	41500.00
0005434309787	6174	Economy	41500.00
0005434309791	6174	Economy	41500.00
0005435297008	6174	Economy	41500.00
0005435999313	6174	Economy	41500.00
0005435999318	6174	Economy	41500.00
0005434309792	6174	Economy	41500.00
0005435487659	6174	Economy	41500.00
0005435297033	6174	Economy	41500.00
0005435487674	6174	Economy	41500.00
0005435487640	6174	Economy	41500.00
0005434309785	6174	Economy	45700.00
0005434309781	6174	Economy	45700.00
0005435296997	6174	Economy	41500.00
0005435487761	6174	Economy	41500.00
0005435297022	6174	Economy	41500.00
0005434309784	6174	Economy	41500.00
0005435487703	6174	Economy	41500.00
0005435487717	6174	Economy	41500.00
0005435999305	6174	Economy	41500.00
0005435487732	6174	Economy	41500.00
0005435999317	6174	Economy	41500.00
0005435999315	6174	Economy	41500.00
0005434309783	6174	Economy	41500.00
0005435297032	6174	Economy	41500.00
0005435999303	6174	Economy	41500.00
0005435487648	6174	Economy	41500.00
0005435999314	6174	Economy	41500.00
0005435999319	6174	Economy	41500.00
0005435487666	6174	Economy	41500.00
0005434309788	6174	Economy	41500.00
0005435487740	6174	Economy	41500.00
0005432146206	6174	Economy	41500.00
0005435297007	6174	Economy	41500.00
0005435999301	6174	Economy	41500.00
0005435487758	6174	Economy	41500.00
0005435999321	6174	Economy	41500.00
0005435487762	6174	Economy	41500.00
0005434309782	6174	Economy	41500.00
0005435999308	6174	Economy	41500.00
0005435487635	6174	Economy	41500.00
0005435487739	6174	Economy	41500.00
0005435487697	6174	Economy	41500.00
0005435297017	6174	Economy	41500.00
0005435999310	6174	Economy	41500.00
0005435487720	6174	Economy	41500.00
0005435487698	6174	Economy	41500.00
0005435297034	6174	Economy	41500.00
0005435999309	6174	Economy	41500.00
0005435487704	6174	Economy	41500.00
0005435999307	6174	Economy	41500.00
0005435999312	6174	Economy	41500.00
0005434309789	6174	Economy	41500.00
0005432146205	6174	Economy	41500.00
0005435999306	6174	Economy	41500.00
0005434309786	6174	Economy	41500.00
0005435999311	6174	Economy	41500.00
0005435297081	19533	Business	124600.00
0005435487878	19533	Business	124600.00
0005435487898	19533	Business	124600.00
0005435999151	19533	Business	124600.00
0005435487876	19533	Business	124600.00
0005435999096	19533	Business	124600.00
0005435487880	19533	Economy	41500.00
0005435999141	19533	Economy	41500.00
0005435297083	19533	Economy	41500.00
0005435999122	19533	Economy	41500.00
0005434309703	19533	Economy	41500.00
0005435297079	19533	Economy	41500.00
0005435999080	19533	Economy	41500.00
0005435999097	19533	Economy	41500.00
0005435487897	19533	Economy	41500.00
0005434309644	19533	Economy	41500.00
0005434309650	19533	Economy	41500.00
0005434309694	19533	Economy	41500.00
0005435487886	19533	Economy	41500.00
0005434309649	19533	Economy	41500.00
0005435999121	19533	Economy	41500.00
0005435999165	19533	Economy	41500.00
0005435999038	19533	Economy	41500.00
0005435487882	19533	Economy	41500.00
0005435999150	19533	Economy	41500.00
0005435487884	19533	Economy	41500.00
0005434309701	19533	Economy	41500.00
0005435487881	19533	Economy	45700.00
0005435487877	19533	Economy	45700.00
0005435297082	19533	Economy	45700.00
0005435297080	19533	Economy	41500.00
0005435999094	19533	Economy	41500.00
0005435999133	19533	Economy	41500.00
0005435999091	19533	Economy	41500.00
0005435999162	19533	Economy	41500.00
0005435487879	19533	Economy	41500.00
0005435487874	19533	Economy	41500.00
0005435297084	19533	Economy	41500.00
0005434309648	19533	Economy	41500.00
0005435999126	19533	Economy	41500.00
0005435487888	19533	Economy	41500.00
0005435487887	19533	Economy	41500.00
0005435487896	19533	Economy	41500.00
0005435999157	19533	Economy	41500.00
0005435999163	19533	Economy	41500.00
0005435487893	19533	Economy	41500.00
0005435487875	19533	Economy	41500.00
0005435487895	19533	Economy	41500.00
0005434309683	19533	Economy	41500.00
0005435999134	19533	Economy	41500.00
0005435487885	19533	Economy	41500.00
0005435487890	19533	Economy	41500.00
0005435999037	19533	Economy	41500.00
0005434309684	19533	Economy	41500.00
0005435999039	19533	Economy	41500.00
0005434309695	19533	Economy	41500.00
0005435487883	19533	Economy	41500.00
0005435487894	19533	Economy	41500.00
0005435999123	19533	Economy	41500.00
0005435297078	19533	Economy	41500.00
0005435487891	19533	Economy	41500.00
0005435999090	19533	Economy	41500.00
0005435487889	19533	Economy	41500.00
0005435487892	19533	Economy	41500.00
0005434565966	1594	Business	86000.00
0005435517964	1594	Business	86000.00
0005435517965	1594	Business	86000.00
0005435517976	1594	Business	86000.00
0005435502389	1594	Business	86000.00
0005435502396	1594	Economy	28700.00
0005435517967	1594	Economy	28700.00
0005434565965	1594	Economy	28700.00
0005435502382	1594	Economy	28700.00
0005435502378	1594	Economy	28700.00
0005432291939	1594	Economy	28700.00
0005435502393	1594	Economy	31500.00
0005434565964	1594	Economy	31500.00
0005435502390	1594	Economy	31500.00
0005434565957	1594	Economy	31500.00
0005435502383	1594	Economy	31500.00
0005435502377	1594	Economy	28700.00
0005435517970	1594	Economy	28700.00
0005435502376	1594	Economy	28700.00
0005435508398	1594	Economy	28700.00
0005435502380	1594	Economy	28700.00
0005435517975	1594	Economy	28700.00
0005433186085	1594	Economy	28700.00
0005433186084	1594	Economy	28700.00
0005433186059	1594	Economy	28700.00
0005435517961	1594	Economy	28700.00
0005435502386	1594	Economy	28700.00
0005435502387	1594	Economy	28700.00
0005434565963	1594	Economy	28700.00
0005435502394	1594	Economy	28700.00
0005435502388	1594	Economy	28700.00
0005435502392	1594	Economy	28700.00
0005434565961	1594	Economy	28700.00
0005435517972	1594	Economy	28700.00
0005435508395	1594	Economy	28700.00
0005435517962	1594	Economy	28700.00
0005433186067	1594	Economy	28700.00
0005435502375	1594	Economy	28700.00
0005432291938	1594	Economy	28700.00
0005435502391	1594	Economy	28700.00
0005433186056	1594	Economy	28700.00
0005435502384	1594	Economy	28700.00
0005435508396	1594	Economy	28700.00
0005434565959	1594	Economy	28700.00
0005434565954	1594	Economy	28700.00
0005435517973	1594	Economy	28700.00
0005435508399	1594	Economy	28700.00
0005434565967	1594	Economy	28700.00
0005434565962	1594	Economy	28700.00
0005433186081	1594	Economy	28700.00
0005432291940	1594	Economy	28700.00
0005435517971	1594	Economy	28700.00
0005434565960	1594	Economy	28700.00
0005435517966	1594	Economy	28700.00
0005434565956	1594	Economy	28700.00
0005435502385	1594	Economy	28700.00
0005435517963	1594	Economy	28700.00
0005435502381	1594	Economy	28700.00
0005435502395	1594	Economy	28700.00
0005435517974	1594	Economy	28700.00
0005434565958	1594	Economy	28700.00
0005435502379	1594	Economy	28700.00
0005434565953	1594	Economy	28700.00
0005435517969	1594	Economy	28700.00
0005435517968	1594	Economy	28700.00
0005435508397	1594	Economy	28700.00
0005434565955	1594	Economy	28700.00
0005434565810	20883	Business	86000.00
0005434565840	20883	Business	86000.00
0005434565795	20883	Business	86000.00
0005435545715	20883	Business	86000.00
0005434565841	20883	Business	86000.00
0005434565826	20883	Business	86000.00
0005434565812	20883	Business	86000.00
0005435502066	20883	Business	86000.00
0005435529179	20883	Business	86000.00
0005434565813	20883	Economy	28700.00
0005435545672	20883	Economy	28700.00
0005433186147	20883	Economy	28700.00
0005435545678	20883	Economy	28700.00
0005435529107	20883	Economy	28700.00
0005435545716	20883	Economy	31500.00
0005433186151	20883	Economy	31500.00
0005435529109	20883	Economy	31500.00
0005435529072	20883	Economy	31500.00
0005435529081	20883	Economy	28700.00
0005435502202	20883	Economy	28700.00
0005435502214	20883	Economy	28700.00
0005435502159	20883	Economy	28700.00
0005435529108	20883	Economy	28700.00
0005435529126	20883	Economy	28700.00
0005435502194	20883	Economy	28700.00
0005435545655	20883	Economy	28700.00
0005435545712	20883	Economy	28700.00
0005435529067	20883	Economy	28700.00
0005435529180	20883	Economy	28700.00
0005435528980	20883	Economy	28700.00
0005435529106	20883	Economy	28700.00
0005435545707	20883	Economy	28700.00
0005435545710	20883	Economy	28700.00
0005434565805	20883	Economy	28700.00
0005435502083	20883	Economy	28700.00
0005435545679	20883	Economy	28700.00
0005433186149	20883	Economy	28700.00
0005434565806	20883	Economy	28700.00
0005435529143	20883	Economy	28700.00
0005433186144	20883	Economy	28700.00
0005434565842	20883	Economy	28700.00
0005434565859	20883	Economy	28700.00
0005435502195	20883	Economy	28700.00
0005435528942	20883	Economy	28700.00
0005435529129	20883	Economy	28700.00
0005435502158	20883	Economy	28700.00
0005433186146	20883	Economy	28700.00
0005434565804	20883	Economy	28700.00
0005434565858	20883	Economy	28700.00
0005433186145	20883	Economy	28700.00
0005434565801	20883	Economy	28700.00
0005435502172	20883	Economy	28700.00
0005435529210	20883	Economy	28700.00
0005434565835	20883	Economy	28700.00
0005435545680	20883	Economy	28700.00
0005434565793	20883	Economy	28700.00
0005435529130	20883	Economy	28700.00
0005435502088	20883	Economy	28700.00
0005435529118	20883	Economy	28700.00
0005435545650	20883	Economy	28700.00
0005434565882	20883	Economy	28700.00
0005434565794	20883	Economy	28700.00
0005434565846	20883	Economy	28700.00
0005435529037	20883	Economy	28700.00
0005435529125	20883	Economy	28700.00
0005433186150	20883	Economy	28700.00
0005435529066	20883	Economy	28700.00
0005435502224	20883	Economy	28700.00
0005435502154	20883	Economy	28700.00
0005433186148	20883	Economy	28700.00
0005435153766	3900	Economy	21600.00
0005435153764	3900	Economy	19700.00
0005435931573	3900	Economy	19700.00
0005435153762	3900	Economy	19700.00
0005435931583	3900	Economy	19700.00
0005435153765	3900	Economy	19700.00
0005435153763	3900	Economy	19700.00
0005435153761	3900	Economy	19700.00
0005435153700	21868	Economy	19700.00
0005435153724	21868	Economy	19700.00
0005435931612	21868	Economy	19700.00
0005435153681	21868	Economy	19700.00
0005435153723	21868	Economy	19700.00
0005435931613	21868	Economy	19700.00
0005435153699	21868	Economy	19700.00
0005435931615	21868	Economy	19700.00
0005435153716	21868	Economy	19700.00
0005435931614	21868	Economy	19700.00
0005432628903	7206	Economy	13000.00
0005432628893	7206	Economy	13000.00
0005435225546	7206	Economy	13000.00
0005432628899	7206	Economy	13000.00
0005435225483	7206	Economy	13000.00
0005432628895	7206	Economy	13000.00
0005432628901	7206	Economy	13000.00
0005432628897	7206	Economy	13000.00
0005432628894	7206	Economy	13000.00
0005435225492	7206	Economy	13000.00
0005432628890	7206	Economy	13000.00
0005435225538	7206	Economy	13000.00
0005432628891	7206	Economy	13000.00
0005432628898	7206	Economy	13000.00
0005435225574	7206	Economy	13000.00
0005432628888	7206	Economy	13000.00
0005432628896	7206	Economy	13000.00
0005432628889	7206	Economy	13000.00
0005435225535	7206	Economy	13000.00
0005435225517	7206	Economy	13000.00
0005432628902	7206	Economy	13000.00
0005432628892	7206	Economy	13000.00
0005432628900	7206	Economy	13000.00
0005435225536	7206	Economy	13000.00
0005435225537	7206	Economy	13000.00
0005435225516	7206	Economy	13000.00
0005432628719	28121	Economy	14300.00
0005435225607	28121	Economy	14300.00
0005432628765	28121	Economy	14300.00
0005435225611	28121	Economy	13000.00
0005432628837	28121	Economy	13000.00
0005432628740	28121	Economy	13000.00
0005432628856	28121	Economy	13000.00
0005432628770	28121	Economy	13000.00
0005432628794	28121	Economy	13000.00
0005432628764	28121	Economy	13000.00
0005432628691	28121	Economy	13000.00
0005435225615	28121	Economy	13000.00
0005432628845	28121	Economy	13000.00
0005435225614	28121	Economy	13000.00
0005432628795	28121	Economy	13000.00
0005435225613	28121	Economy	13000.00
0005432628839	28121	Economy	13000.00
0005435225609	28121	Economy	13000.00
0005432628754	28121	Economy	13000.00
0005432628807	28121	Economy	13000.00
0005432628840	28121	Economy	13000.00
0005435225610	28121	Economy	13000.00
0005435225612	28121	Economy	13000.00
0005432628741	28121	Economy	13000.00
0005435225608	28121	Economy	13000.00
0005432628756	28121	Economy	13000.00
0005432628742	28121	Economy	13000.00
0005434267929	8720	Economy	11500.00
0005434267930	8720	Economy	11500.00
0005434267928	8720	Economy	10500.00
0005435960062	8720	Economy	10500.00
0005434267931	8720	Economy	10500.00
0005435960063	8720	Economy	10500.00
0005434267936	8720	Economy	10500.00
0005434267940	8720	Economy	10500.00
0005435960061	8720	Economy	10500.00
0005434267937	8720	Economy	10500.00
0005435960064	8720	Economy	10500.00
0005435960047	15233	Economy	10500.00
0005434267960	15233	Economy	10500.00
0005435960009	15233	Economy	10500.00
0005434267962	15233	Economy	10500.00
0005434267961	15233	Economy	10500.00
0005434267963	15233	Economy	10500.00
0005432693147	1184	Business	115000.00
0005432693137	1184	Business	115000.00
0005432693142	1184	Business	115000.00
0005432693156	1184	Business	115000.00
0005432873259	1184	Business	115000.00
0005432693140	1184	Business	115000.00
0005432693153	1184	Business	115000.00
0005432675179	1184	Business	115000.00
0005432693145	1184	Business	115000.00
0005432675180	1184	Business	115000.00
0005432693148	1184	Economy	38300.00
0005432675178	1184	Economy	38300.00
0005432693144	1184	Economy	38300.00
0005432693152	1184	Economy	38300.00
0005432693135	1184	Economy	38300.00
0005432693138	1184	Economy	38300.00
0005432693157	1184	Economy	42200.00
0005432693158	1184	Economy	42200.00
0005432675176	1184	Economy	38300.00
0005432873237	1184	Economy	38300.00
0005432693129	1184	Economy	38300.00
0005432675188	1184	Economy	38300.00
0005432675183	1184	Economy	38300.00
0005432693154	1184	Economy	38300.00
0005432693132	1184	Economy	38300.00
0005432693143	1184	Economy	38300.00
0005432693128	1184	Economy	38300.00
0005432873265	1184	Economy	38300.00
0005432693150	1184	Economy	38300.00
0005432675175	1184	Economy	38300.00
0005432677584	1184	Economy	38300.00
0005432675181	1184	Economy	38300.00
0005432693131	1184	Economy	38300.00
0005432693149	1184	Economy	38300.00
0005432693130	1184	Economy	38300.00
0005432675184	1184	Economy	38300.00
0005432693146	1184	Economy	38300.00
0005432675182	1184	Economy	38300.00
0005432873266	1184	Economy	38300.00
0005432675187	1184	Economy	38300.00
0005432693133	1184	Economy	38300.00
0005432675177	1184	Economy	38300.00
0005432677582	1184	Economy	38300.00
0005432693141	1184	Economy	38300.00
0005432693136	1184	Economy	38300.00
0005432675185	1184	Economy	38300.00
0005432873238	1184	Economy	38300.00
0005432677583	1184	Economy	38300.00
0005432693127	1184	Economy	38300.00
0005432693151	1184	Economy	38300.00
0005432693139	1184	Economy	38300.00
0005432675186	1184	Economy	38300.00
0005432693134	1184	Economy	38300.00
0005432693155	1184	Economy	38300.00
0005432873258	1184	Economy	38300.00
0005432692963	17491	Business	115000.00
0005432873318	17491	Business	115000.00
0005432675050	17491	Business	115000.00
0005432692951	17491	Business	115000.00
0005432692976	17491	Business	115000.00
0005432693015	17491	Business	115000.00
0005432692855	17491	Business	115000.00
0005432692956	17491	Business	115000.00
0005432873314	17491	Business	115000.00
0005432692989	17491	Business	115000.00
0005432692901	17491	Business	115000.00
0005432675066	17491	Business	115000.00
0005432692837	17491	Business	115000.00
0005432674995	17491	Economy	38300.00
0005432675018	17491	Economy	38300.00
0005432692849	17491	Economy	38300.00
0005432692850	17491	Economy	38300.00
0005432692886	17491	Economy	38300.00
0005432675019	17491	Economy	38300.00
0005432692851	17491	Economy	42200.00
0005432692968	17491	Economy	42200.00
0005432692818	17491	Economy	42200.00
0005432675065	17491	Economy	42200.00
0005432692988	17491	Economy	38300.00
0005432675078	17491	Economy	38300.00
0005432692922	17491	Economy	38300.00
0005432692932	17491	Economy	38300.00
0005432692943	17491	Economy	38300.00
0005432692887	17491	Economy	38300.00
0005432693013	17491	Economy	38300.00
0005432692961	17491	Economy	38300.00
0005432675020	17491	Economy	38300.00
0005432692844	17491	Economy	38300.00
0005432674978	17491	Economy	38300.00
0005432692962	17491	Economy	38300.00
0005432674979	17491	Economy	38300.00
0005432873316	17491	Economy	38300.00
0005432677539	17491	Economy	38300.00
0005432692845	17491	Economy	38300.00
0005432692806	17491	Economy	38300.00
0005432674977	17491	Economy	38300.00
0005432692967	17491	Economy	38300.00
0005432692838	17491	Economy	38300.00
0005432675036	17491	Economy	38300.00
0005432675072	17491	Economy	38300.00
0005432675094	17491	Economy	38300.00
0005432692942	17491	Economy	38300.00
0005432692843	17491	Economy	38300.00
0005432692958	17491	Economy	38300.00
0005432674976	17491	Economy	38300.00
0005432675095	17491	Economy	38300.00
0005432692874	17491	Economy	38300.00
0005432675017	17491	Economy	38300.00
0005432675077	17491	Economy	38300.00
0005432693014	17491	Economy	38300.00
0005432692856	17491	Economy	38300.00
0005432873317	17491	Economy	38300.00
0005432692899	17491	Economy	38300.00
0005432692950	17491	Economy	38300.00
0005432692805	17491	Economy	38300.00
0005432692959	17491	Economy	38300.00
0005432675096	17491	Economy	38300.00
0005432873315	17491	Economy	38300.00
0005432692902	17491	Economy	38300.00
0005432692957	17491	Economy	38300.00
0005432675035	17491	Economy	38300.00
0005432692819	17491	Economy	38300.00
0005434435225	1118	Economy	15200.00
0005433156764	1118	Economy	15200.00
0005434435231	1118	Economy	13900.00
0005434435235	1118	Economy	13900.00
0005434435237	1118	Economy	13900.00
0005433156731	1118	Economy	13900.00
0005434435233	1118	Economy	13900.00
0005433156732	1118	Economy	13900.00
0005434435229	1118	Economy	13900.00
0005434435239	1118	Economy	13900.00
0005434435236	1118	Economy	13900.00
0005433156713	1118	Economy	13900.00
0005434435234	1118	Economy	13900.00
0005433156745	1118	Economy	13900.00
0005434435232	1118	Economy	13900.00
0005434435226	1118	Economy	13900.00
0005434435228	1118	Economy	13900.00
0005434435238	1118	Economy	13900.00
0005434435230	1118	Economy	13900.00
0005433156691	1118	Economy	13900.00
0005433156765	1118	Economy	13900.00
0005434435227	1118	Economy	13900.00
0005433156777	17293	Economy	15200.00
0005433156773	17293	Economy	15200.00
0005433156778	17293	Economy	15200.00
0005433156782	17293	Economy	13900.00
0005434435112	17293	Economy	13900.00
0005434435077	17293	Economy	13900.00
0005433156774	17293	Economy	13900.00
0005433156779	17293	Economy	13900.00
0005434435117	17293	Economy	13900.00
0005434435038	17293	Economy	13900.00
0005433156780	17293	Economy	13900.00
0005433156781	17293	Economy	13900.00
0005434435101	17293	Economy	13900.00
0005433156775	17293	Economy	13900.00
0005434435096	17293	Economy	13900.00
0005434435116	17293	Economy	13900.00
0005434435099	17293	Economy	13900.00
0005434434971	17293	Economy	13900.00
0005434435095	17293	Economy	13900.00
0005433156776	17293	Economy	13900.00
0005435928120	4058	Economy	8200.00
0005435086858	4058	Economy	8200.00
0005435086861	4058	Economy	7500.00
0005435086857	4058	Economy	7500.00
0005435928117	4058	Economy	7500.00
0005435086859	4058	Economy	7500.00
0005435086860	4058	Economy	7500.00
0005435086856	4058	Economy	7500.00
0005435928124	4058	Economy	7500.00
0005435928122	4058	Economy	7500.00
0005435928139	4058	Economy	7500.00
0005435086855	4058	Economy	7500.00
0005435928118	4058	Economy	7500.00
0005435928121	4058	Economy	7500.00
0005435928106	4058	Economy	7500.00
0005435928105	4058	Economy	7500.00
0005435086862	4058	Economy	7500.00
0005435928157	24395	Economy	8200.00
0005435086763	24395	Economy	8200.00
0005435928160	24395	Economy	8200.00
0005435086774	24395	Economy	7500.00
0005435086806	24395	Economy	7500.00
0005435928158	24395	Economy	7500.00
0005435086802	24395	Economy	7500.00
0005435086762	24395	Economy	7500.00
0005435086803	24395	Economy	7500.00
0005435086813	24395	Economy	7500.00
0005435928159	24395	Economy	7500.00
0005435086778	24395	Economy	7500.00
0005435086814	24395	Economy	7500.00
0005435928156	24395	Economy	7500.00
0005435086805	24395	Economy	7500.00
0005435551529	11069	Business	144300.00
0005435551520	11069	Business	144300.00
0005435551555	11069	Economy	52900.00
0005435551539	11069	Economy	48100.00
0005435551572	11069	Economy	48100.00
0005435098540	11069	Economy	48100.00
0005435551514	11069	Economy	48100.00
0005435551574	11069	Economy	48100.00
0005435551499	11069	Economy	48100.00
0005435551537	11069	Economy	48100.00
0005435551556	11069	Economy	48100.00
0005435551498	11069	Economy	48100.00
0005435551569	11069	Economy	48100.00
0005435551549	11069	Economy	48100.00
0005435551573	11069	Economy	48100.00
0005435551554	11069	Economy	48100.00
0005435551519	11069	Economy	48100.00
0005435551570	11069	Economy	48100.00
0005435551548	11069	Economy	48100.00
0005435551541	11069	Economy	48100.00
0005435551575	11069	Economy	48100.00
0005435551571	11069	Economy	48100.00
0005435551540	11069	Economy	48100.00
0005435706417	2446	Business	86800.00
0005435706432	2446	Business	86800.00
0005433373499	2446	Business	86800.00
0005435706427	2446	Business	86800.00
0005435706437	2446	Business	86800.00
0005435706429	2446	Business	86800.00
0005435706421	2446	Economy	28900.00
0005433373444	2446	Economy	28900.00
0005435706415	2446	Economy	28900.00
0005435706438	2446	Economy	28900.00
0005435706423	2446	Economy	28900.00
0005435706419	2446	Economy	31800.00
0005435706436	2446	Economy	31800.00
0005435706428	2446	Economy	28900.00
0005435706442	2446	Economy	28900.00
0005435706447	2446	Economy	28900.00
0005433373498	2446	Economy	28900.00
0005435706441	2446	Economy	28900.00
0005433373474	2446	Economy	28900.00
0005435706443	2446	Economy	28900.00
0005435706418	2446	Economy	28900.00
0005435706439	2446	Economy	28900.00
0005435706416	2446	Economy	28900.00
0005435706444	2446	Economy	28900.00
0005435706425	2446	Economy	28900.00
0005433373462	2446	Economy	28900.00
0005433373456	2446	Economy	28900.00
0005435706445	2446	Economy	28900.00
0005433373497	2446	Economy	28900.00
0005435706435	2446	Economy	28900.00
0005435706422	2446	Economy	28900.00
0005433373472	2446	Economy	28900.00
0005435706420	2446	Economy	28900.00
0005435706426	2446	Economy	28900.00
0005435706448	2446	Economy	28900.00
0005433373495	2446	Economy	28900.00
0005435706424	2446	Economy	28900.00
0005435706446	2446	Economy	28900.00
0005433373478	2446	Economy	28900.00
0005435706434	2446	Economy	28900.00
0005433373486	2446	Economy	28900.00
0005435706430	2446	Economy	28900.00
0005435706433	2446	Economy	28900.00
0005435706431	2446	Economy	28900.00
0005435706440	2446	Economy	28900.00
0005433373479	2446	Economy	28900.00
0005435706296	27027	Business	86800.00
0005435706305	27027	Business	86800.00
0005433373558	27027	Business	86800.00
0005435706264	27027	Business	86800.00
0005433373561	27027	Business	86800.00
0005433373564	27027	Business	86800.00
0005435706228	27027	Economy	28900.00
0005433373563	27027	Economy	28900.00
0005435706253	27027	Economy	28900.00
0005433373556	27027	Economy	28900.00
0005433373555	27027	Economy	28900.00
0005435706321	27027	Economy	28900.00
0005435706217	27027	Economy	28900.00
0005435706267	27027	Economy	28900.00
0005435706363	27027	Economy	31800.00
0005435706287	27027	Economy	31800.00
0005435706298	27027	Economy	28900.00
0005435706266	27027	Economy	28900.00
0005433373569	27027	Economy	28900.00
0005435706248	27027	Economy	28900.00
0005435706303	27027	Economy	28900.00
0005435706325	27027	Economy	28900.00
0005435706273	27027	Economy	28900.00
0005435706187	27027	Economy	28900.00
0005433373567	27027	Economy	28900.00
0005433373551	27027	Economy	28900.00
0005435706326	27027	Economy	28900.00
0005435706254	27027	Economy	28900.00
0005435706295	27027	Economy	28900.00
0005435706274	27027	Economy	28900.00
0005433373560	27027	Economy	28900.00
0005435706320	27027	Economy	28900.00
0005433373566	27027	Economy	28900.00
0005433373552	27027	Economy	28900.00
0005433373562	27027	Economy	28900.00
0005435706240	27027	Economy	28900.00
0005435706284	27027	Economy	28900.00
0005435706261	27027	Economy	28900.00
0005435706265	27027	Economy	28900.00
0005433373559	27027	Economy	28900.00
0005433373553	27027	Economy	28900.00
0005435706312	27027	Economy	28900.00
0005435706299	27027	Economy	28900.00
0005433373571	27027	Economy	28900.00
0005435706286	27027	Economy	28900.00
0005435706294	27027	Economy	28900.00
0005435706288	27027	Economy	28900.00
0005435706252	27027	Economy	28900.00
0005435706293	27027	Economy	28900.00
0005433373554	27027	Economy	28900.00
0005435706289	27027	Economy	28900.00
0005435706304	27027	Economy	28900.00
0005435706242	27027	Economy	28900.00
0005433373557	27027	Economy	28900.00
0005435706218	27027	Economy	28900.00
0005435706243	27027	Economy	28900.00
0005435706272	27027	Economy	28900.00
0005433373568	27027	Economy	28900.00
0005433373570	27027	Economy	28900.00
0005433373565	27027	Economy	28900.00
0005434964269	1326	Business	203300.00
0005434964297	1326	Business	203300.00
0005434964295	1326	Business	203300.00
0005434964298	1326	Business	203300.00
0005434964293	1326	Business	203300.00
0005434964288	1326	Business	203300.00
0005433261437	1326	Business	203300.00
0005434964294	1326	Business	203300.00
0005432279279	1326	Business	203300.00
0005434964278	1326	Business	203300.00
0005434964267	1326	Economy	74500.00
0005434964273	1326	Economy	67800.00
0005434964285	1326	Economy	67800.00
0005433261465	1326	Economy	67800.00
0005434964286	1326	Economy	67800.00
0005433261506	1326	Economy	67800.00
0005433261501	1326	Economy	67800.00
0005434964270	1326	Economy	67800.00
0005433261489	1326	Economy	67800.00
0005434964303	1326	Economy	67800.00
0005434964266	1326	Economy	67800.00
0005434964283	1326	Economy	67800.00
0005434964300	1326	Economy	67800.00
0005433261490	1326	Economy	67800.00
0005434964282	1326	Economy	67800.00
0005434964291	1326	Economy	67800.00
0005434964279	1326	Economy	67800.00
0005433261530	1326	Economy	67800.00
0005432279277	1326	Economy	67800.00
0005434964277	1326	Economy	67800.00
0005433261505	1326	Economy	67800.00
0005434964272	1326	Economy	67800.00
0005434964274	1326	Economy	67800.00
0005433261527	1326	Economy	67800.00
0005434964275	1326	Economy	67800.00
0005432279278	1326	Economy	67800.00
0005434964302	1326	Economy	67800.00
0005433261502	1326	Economy	67800.00
0005434964292	1326	Economy	67800.00
0005433261500	1326	Economy	67800.00
0005434964281	1326	Economy	74500.00
0005434964271	1326	Economy	67800.00
0005433261503	1326	Economy	67800.00
0005433261491	1326	Economy	67800.00
0005433261499	1326	Economy	67800.00
0005434964304	1326	Economy	67800.00
0005434964268	1326	Economy	67800.00
0005433261486	1326	Economy	67800.00
0005432279276	1326	Economy	67800.00
0005434964296	1326	Economy	67800.00
0005434964287	1326	Economy	67800.00
0005433261528	1326	Economy	67800.00
0005434964290	1326	Economy	67800.00
0005433261529	1326	Economy	67800.00
0005434964276	1326	Economy	67800.00
0005433261515	1326	Economy	67800.00
0005434964301	1326	Economy	67800.00
0005433261533	1326	Economy	67800.00
0005434964280	1326	Economy	67800.00
0005434964284	1326	Economy	67800.00
0005434964299	1326	Economy	67800.00
0005434964289	1326	Economy	67800.00
0005434964127	18234	Business	203300.00
0005433261585	18234	Business	203300.00
0005434964113	18234	Business	203300.00
0005433261589	18234	Business	203300.00
0005433261601	18234	Business	203300.00
0005433261598	18234	Business	203300.00
0005433261577	18234	Business	203300.00
0005433261602	18234	Business	203300.00
0005434964088	18234	Business	203300.00
0005433261592	18234	Business	203300.00
0005434964119	18234	Business	203300.00
0005433261606	18234	Business	203300.00
0005433261588	18234	Economy	67800.00
0005433261596	18234	Economy	67800.00
0005434964118	18234	Economy	67800.00
0005434964114	18234	Economy	67800.00
0005434964176	18234	Economy	67800.00
0005433261578	18234	Economy	67800.00
0005434964136	18234	Economy	67800.00
0005433261576	18234	Economy	67800.00
0005434964138	18234	Economy	67800.00
0005434964115	18234	Economy	67800.00
0005433261603	18234	Economy	67800.00
0005434964047	18234	Economy	67800.00
0005433261582	18234	Economy	67800.00
0005434964087	18234	Economy	67800.00
0005433261593	18234	Economy	67800.00
0005433261586	18234	Economy	67800.00
0005434964050	18234	Economy	67800.00
0005434964135	18234	Economy	67800.00
0005434964122	18234	Economy	67800.00
0005434964116	18234	Economy	67800.00
0005433261580	18234	Economy	67800.00
0005434964058	18234	Economy	67800.00
0005434964102	18234	Economy	67800.00
0005433261594	18234	Economy	67800.00
0005433261599	18234	Economy	67800.00
0005434964085	18234	Economy	67800.00
0005433261584	18234	Economy	67800.00
0005433261597	18234	Economy	67800.00
0005434964089	18234	Economy	67800.00
0005434964003	18234	Economy	67800.00
0005434964101	18234	Economy	67800.00
0005433261605	18234	Economy	67800.00
0005433261607	18234	Economy	67800.00
0005434964142	18234	Economy	67800.00
0005434964128	18234	Economy	67800.00
0005434964060	18234	Economy	67800.00
0005433261579	18234	Economy	67800.00
0005434964062	18234	Economy	67800.00
0005433261587	18234	Economy	67800.00
0005434964083	18234	Economy	67800.00
0005434964182	18234	Economy	67800.00
0005434964183	18234	Economy	74500.00
0005434964078	18234	Economy	74500.00
0005434964086	18234	Economy	67800.00
0005434964158	18234	Economy	74500.00
0005434964090	18234	Economy	67800.00
0005434964067	18234	Economy	67800.00
0005434964080	18234	Economy	67800.00
0005433261595	18234	Economy	67800.00
0005434964120	18234	Economy	67800.00
0005434964082	18234	Economy	67800.00
0005434964160	18234	Economy	67800.00
0005433261590	18234	Economy	67800.00
0005433261583	18234	Economy	67800.00
0005434964063	18234	Economy	67800.00
0005434964139	18234	Economy	67800.00
0005434964095	18234	Economy	67800.00
0005434964111	18234	Economy	67800.00
0005433261581	18234	Economy	67800.00
0005434964051	18234	Economy	67800.00
0005434964094	18234	Economy	67800.00
0005433261604	18234	Economy	67800.00
0005434964105	18234	Economy	67800.00
0005434964181	18234	Economy	67800.00
0005434964137	18234	Economy	67800.00
0005434964141	18234	Economy	67800.00
0005434964180	18234	Economy	67800.00
0005434964074	18234	Economy	67800.00
0005434964140	18234	Economy	67800.00
0005434964117	18234	Economy	67800.00
0005434964103	18234	Economy	67800.00
0005433261591	18234	Economy	67800.00
0005434964073	18234	Economy	67800.00
0005433261600	18234	Economy	67800.00
0005434964096	18234	Economy	67800.00
0005435907466	4841	Business	44200.00
0005434625996	4841	Economy	14700.00
0005434625989	4841	Economy	14700.00
0005434625987	4841	Economy	14700.00
0005434625990	4841	Economy	16200.00
0005434625993	4841	Economy	14700.00
0005434625991	4841	Economy	14700.00
0005433194833	4841	Economy	14700.00
0005434625995	4841	Economy	14700.00
0005434625992	4841	Economy	14700.00
0005435907467	4841	Economy	14700.00
0005435907479	4841	Economy	14700.00
0005433194846	4841	Economy	14700.00
0005434625994	4841	Economy	14700.00
0005435907478	4841	Economy	14700.00
0005435907493	4841	Economy	14700.00
0005434625988	4841	Economy	14700.00
0005435907498	4841	Economy	14700.00
0005434625890	32900	Business	44200.00
0005435907521	32900	Economy	14700.00
0005435907520	32900	Economy	14700.00
0005434625957	32900	Economy	14700.00
0005435907518	32900	Economy	14700.00
0005434625900	32900	Economy	14700.00
0005434625889	32900	Economy	14700.00
0005435907519	32900	Economy	14700.00
0005434625935	32900	Economy	14700.00
0005435907517	32900	Economy	14700.00
0005434625928	32900	Economy	14700.00
0005434625934	32900	Economy	14700.00
0005434625904	32900	Economy	14700.00
0005434625901	32900	Economy	14700.00
0005434625887	32900	Economy	14700.00
0005435785277	13797	Economy	3400.00
0005435785247	13797	Economy	3400.00
0005435785090	13797	Economy	3400.00
0005435784982	13797	Economy	3400.00
0005435785176	13797	Economy	3100.00
0005435785194	13797	Economy	3100.00
0005435937399	13797	Economy	3100.00
0005435785038	13797	Economy	3100.00
0005435937396	13797	Economy	3100.00
0005435937393	13797	Economy	3100.00
0005435785099	13797	Economy	3100.00
0005435785074	13797	Economy	3100.00
0005435785246	13797	Economy	3100.00
0005435937398	13797	Economy	3100.00
0005435785136	13797	Economy	3100.00
0005435785067	13797	Economy	3100.00
0005435785014	13797	Economy	3100.00
0005435785106	13797	Economy	3100.00
0005435785230	13797	Economy	3100.00
0005435785026	13797	Economy	3100.00
0005435785248	13797	Economy	3100.00
0005435785071	13797	Economy	3100.00
0005435785075	13797	Economy	3100.00
0005435785126	13797	Economy	3100.00
0005435784993	13797	Economy	3100.00
0005435785063	13797	Economy	3100.00
0005435785100	13797	Economy	3100.00
0005435785162	13797	Economy	3100.00
0005435785003	13797	Economy	3100.00
0005435785145	13797	Economy	3100.00
0005435785054	13797	Economy	3100.00
0005435785133	13797	Economy	3100.00
0005435785123	13797	Economy	3100.00
0005432195700	13797	Economy	3100.00
0005435785001	13797	Economy	3100.00
0005435785053	13797	Economy	3100.00
0005435785111	13797	Economy	3100.00
0005435785245	13797	Economy	3100.00
0005435937395	13797	Economy	3100.00
0005435785064	13797	Economy	3100.00
0005435785107	13797	Economy	3100.00
0005435937397	13797	Economy	3100.00
0005435785108	13797	Economy	3100.00
0005432195699	13797	Economy	3100.00
0005435937394	13797	Economy	3100.00
0005435787335	13797	Economy	3100.00
0005435785146	13797	Economy	3100.00
0005435785427	27427	Economy	3400.00
0005435785412	27427	Economy	3400.00
0005435787358	27427	Economy	3400.00
0005435785406	27427	Economy	3400.00
0005435785410	27427	Economy	3100.00
0005435785403	27427	Economy	3100.00
0005435785429	27427	Economy	3100.00
0005435785432	27427	Economy	3100.00
0005435785426	27427	Economy	3100.00
0005435785422	27427	Economy	3100.00
0005435785436	27427	Economy	3100.00
0005435785416	27427	Economy	3100.00
0005435785431	27427	Economy	3100.00
0005435785418	27427	Economy	3100.00
0005435787359	27427	Economy	3100.00
0005432190635	27427	Economy	3100.00
0005435785413	27427	Economy	3100.00
0005435785434	27427	Economy	3100.00
0005435785405	27427	Economy	3100.00
0005435937335	27427	Economy	3100.00
0005435785428	27427	Economy	3100.00
0005435785404	27427	Economy	3100.00
0005435785414	27427	Economy	3100.00
0005435787357	27427	Economy	3100.00
0005435785419	27427	Economy	3100.00
0005435785425	27427	Economy	3100.00
0005435937338	27427	Economy	3100.00
0005435785435	27427	Economy	3100.00
0005435785421	27427	Economy	3100.00
0005432190637	27427	Economy	3100.00
0005435937340	27427	Economy	3100.00
0005435937334	27427	Economy	3100.00
0005435785417	27427	Economy	3100.00
0005435785411	27427	Economy	3100.00
0005435785408	27427	Economy	3100.00
0005435785423	27427	Economy	3100.00
0005435937339	27427	Economy	3100.00
0005435937336	27427	Economy	3100.00
0005435785415	27427	Economy	3100.00
0005435785420	27427	Economy	3100.00
0005435785424	27427	Economy	3100.00
0005435785430	27427	Economy	3100.00
0005435937341	27427	Economy	3100.00
0005435785407	27427	Economy	3100.00
0005432190636	27427	Economy	3100.00
0005435785433	27427	Economy	3100.00
0005435785402	27427	Economy	3100.00
0005435785409	27427	Economy	3100.00
0005432190638	27427	Economy	3100.00
0005432058397	20253	Business	12000.00
0005434407428	20253	Business	12000.00
0005434407320	20253	Business	12000.00
0005434407440	20253	Business	12000.00
0005434407210	20253	Business	12000.00
0005434407451	20253	Business	12000.00
0005434407253	20253	Business	12000.00
0005434407500	20253	Business	12000.00
0005434407207	20253	Business	12000.00
0005435311098	20253	Business	12000.00
0005434407230	20253	Business	12000.00
0005434407541	20253	Business	12000.00
0005434407589	20253	Economy	4000.00
0005434407385	20253	Economy	4000.00
0005434407499	20253	Economy	4000.00
0005435311095	20253	Economy	4000.00
0005434407394	20253	Economy	4000.00
0005434407515	20253	Economy	4000.00
0005434407510	20253	Economy	4000.00
0005434407463	20253	Economy	4000.00
0005434407396	20253	Economy	4000.00
0005434407363	20253	Economy	4400.00
0005434407404	20253	Economy	4400.00
0005434407121	20253	Economy	4400.00
0005435311100	20253	Economy	4400.00
0005434407640	20253	Economy	4400.00
0005434407542	20253	Economy	4000.00
0005434407623	20253	Economy	4000.00
0005434407624	20253	Economy	4000.00
0005434407694	20253	Economy	4000.00
0005434407299	20253	Economy	4000.00
0005434407610	20253	Economy	4000.00
0005434407411	20253	Economy	4000.00
0005434407571	20253	Economy	4000.00
0005434407517	20253	Economy	4000.00
0005434407622	20253	Economy	4000.00
0005432058395	20253	Economy	4000.00
0005434407476	20253	Economy	4000.00
0005434407444	20253	Economy	4000.00
0005434407672	20253	Economy	4000.00
0005434407384	20253	Economy	4000.00
0005434407611	20253	Economy	4000.00
0005434407274	20253	Economy	4000.00
0005434407586	20253	Economy	4000.00
0005434407458	20253	Economy	4000.00
0005434407448	20253	Economy	4000.00
0005434407301	20253	Economy	4000.00
0005434407633	20253	Economy	4000.00
0005434407302	20253	Economy	4000.00
0005434407648	20253	Economy	4000.00
0005435311101	20253	Economy	4000.00
0005435311099	20253	Economy	4000.00
0005435311103	20253	Economy	4000.00
0005434407441	20253	Economy	4000.00
0005434407649	20253	Economy	4000.00
0005434407632	20253	Economy	4000.00
0005434407439	20253	Economy	4000.00
0005435311097	20253	Economy	4000.00
0005432058393	20253	Economy	4000.00
0005434407252	20253	Economy	4000.00
0005434407272	20253	Economy	4000.00
0005434407300	20253	Economy	4000.00
0005434407450	20253	Economy	4000.00
0005434407673	20253	Economy	4000.00
0005434407397	20253	Economy	4000.00
0005434407410	20253	Economy	4000.00
0005432058394	20253	Economy	4000.00
0005434407334	20253	Economy	4000.00
0005434407683	20253	Economy	4000.00
0005435311104	20253	Economy	4000.00
0005434407459	20253	Economy	4000.00
0005434407471	20253	Economy	4000.00
0005434407427	20253	Economy	4000.00
0005434407487	20253	Economy	4000.00
0005435311102	20253	Economy	4000.00
0005434407467	20253	Economy	4000.00
0005434407433	20253	Economy	4000.00
0005432058396	20253	Economy	4000.00
0005434407390	20253	Economy	4000.00
0005434407052	20253	Economy	4000.00
0005434407663	20253	Economy	4000.00
0005434407516	20253	Economy	4000.00
0005434407412	20253	Economy	4000.00
0005435311096	20253	Economy	4000.00
0005434407233	20253	Economy	4000.00
0005435311094	20253	Economy	4000.00
0005434407315	20253	Economy	4000.00
0005434407377	20253	Economy	4000.00
0005434407319	20253	Economy	4000.00
0005434407231	20253	Economy	4000.00
0005434407964	26992	Business	12000.00
0005434407966	26992	Business	12000.00
0005434407962	26992	Business	12000.00
0005434407955	26992	Business	12000.00
0005434407946	26992	Business	12000.00
0005432153962	26992	Business	12000.00
0005435310927	26992	Business	12000.00
0005432153959	26992	Business	12000.00
0005434407959	26992	Business	12000.00
0005434407961	26992	Business	12000.00
0005434407982	26992	Business	12000.00
0005434407989	26992	Economy	4000.00
0005432153958	26992	Economy	4000.00
0005434407992	26992	Economy	4000.00
0005434407978	26992	Economy	4000.00
0005434407931	26992	Economy	4000.00
0005434407984	26992	Economy	4000.00
0005434407986	26992	Economy	4000.00
0005435310928	26992	Economy	4000.00
0005434407970	26992	Economy	4000.00
0005434407968	26992	Economy	4400.00
0005434407939	26992	Economy	4400.00
0005434407967	26992	Economy	4400.00
0005434407941	26992	Economy	4400.00
0005435310949	26992	Economy	4400.00
0005434407958	26992	Economy	4000.00
0005435310992	26992	Economy	4000.00
0005434407981	26992	Economy	4000.00
0005432153957	26992	Economy	4000.00
0005434407977	26992	Economy	4000.00
0005435310976	26992	Economy	4000.00
0005434407972	26992	Economy	4000.00
0005434407940	26992	Economy	4000.00
0005432153960	26992	Economy	4000.00
0005434407969	26992	Economy	4000.00
0005434407954	26992	Economy	4000.00
0005434407935	26992	Economy	4000.00
0005435311003	26992	Economy	4000.00
0005434407987	26992	Economy	4000.00
0005434407932	26992	Economy	4000.00
0005434407991	26992	Economy	4000.00
0005434407974	26992	Economy	4000.00
0005434407933	26992	Economy	4000.00
0005435310982	26992	Economy	4000.00
0005434407983	26992	Economy	4000.00
0005435310987	26992	Economy	4000.00
0005434407993	26992	Economy	4000.00
0005435310977	26992	Economy	4000.00
0005434407973	26992	Economy	4000.00
0005434407971	26992	Economy	4000.00
0005435310940	26992	Economy	4000.00
0005434407980	26992	Economy	4000.00
0005434407949	26992	Economy	4000.00
0005434407953	26992	Economy	4000.00
0005435310945	26992	Economy	4000.00
0005434407944	26992	Economy	4000.00
0005434407938	26992	Economy	4000.00
0005434407963	26992	Economy	4000.00
0005434407942	26992	Economy	4000.00
0005434407948	26992	Economy	4000.00
0005435310993	26992	Economy	4000.00
0005434407979	26992	Economy	4000.00
0005434407947	26992	Economy	4000.00
0005434407976	26992	Economy	4000.00
0005434407990	26992	Economy	4000.00
0005434407957	26992	Economy	4000.00
0005435310926	26992	Economy	4000.00
0005434407960	26992	Economy	4000.00
0005435310939	26992	Economy	4000.00
0005434407951	26992	Economy	4000.00
0005432153963	26992	Economy	4000.00
0005434407975	26992	Economy	4000.00
0005435310951	26992	Economy	4000.00
0005434407988	26992	Economy	4000.00
0005434407965	26992	Economy	4000.00
0005434407985	26992	Economy	4000.00
0005434407943	26992	Economy	4000.00
0005434407937	26992	Economy	4000.00
0005435310967	26992	Economy	4000.00
0005432153961	26992	Economy	4000.00
0005434407956	26992	Economy	4000.00
0005434407952	26992	Economy	4000.00
0005435310983	26992	Economy	4000.00
0005434407945	26992	Economy	4000.00
0005434407950	26992	Economy	4000.00
0005434407934	26992	Economy	4000.00
0005435310986	26992	Economy	4000.00
0005434407930	26992	Economy	4000.00
0005434407936	26992	Economy	4000.00
0005434319439	5712	Business	43300.00
0005434319424	5712	Business	43300.00
0005434319426	5712	Business	43300.00
0005434319429	5712	Business	43300.00
0005433123830	5712	Business	43300.00
0005434311228	5712	Business	43300.00
0005434319436	5712	Economy	14400.00
0005434311227	5712	Economy	14400.00
0005433123788	5712	Economy	15900.00
0005432109712	5712	Economy	15900.00
0005434319438	5712	Economy	15900.00
0005433123806	5712	Economy	14400.00
0005433123799	5712	Economy	14400.00
0005434319444	5712	Economy	14400.00
0005434319428	5712	Economy	14400.00
0005434319431	5712	Economy	14400.00
0005433123829	5712	Economy	14400.00
0005433123746	5712	Economy	14400.00
0005432109711	5712	Economy	14400.00
0005433123840	5712	Economy	14400.00
0005434319427	5712	Economy	14400.00
0005434319433	5712	Economy	14400.00
0005433123811	5712	Economy	14400.00
0005434319435	5712	Economy	14400.00
0005434319445	5712	Economy	14400.00
0005433123814	5712	Economy	14400.00
0005434319423	5712	Economy	14400.00
0005433123815	5712	Economy	14400.00
0005433123795	5712	Economy	14400.00
0005433123745	5712	Economy	14400.00
0005434319443	5712	Economy	14400.00
0005432109715	5712	Economy	14400.00
0005432109713	5712	Economy	14400.00
0005434319441	5712	Economy	14400.00
0005434319430	5712	Economy	14400.00
0005434319432	5712	Economy	14400.00
0005434319437	5712	Economy	14400.00
0005434319425	5712	Economy	14400.00
0005433123804	5712	Economy	14400.00
0005434311226	5712	Economy	14400.00
0005433123787	5712	Economy	14400.00
0005432109714	5712	Economy	14400.00
0005434319440	5712	Economy	14400.00
0005434319434	5712	Economy	14400.00
0005434319442	5712	Economy	14400.00
0005433123737	5712	Economy	14400.00
0005433124006	15660	Business	43300.00
0005433124008	15660	Business	43300.00
0005433124012	15660	Business	43300.00
0005434319279	15660	Business	43300.00
0005433124009	15660	Business	43300.00
0005433123997	15660	Economy	14400.00
0005434319254	15660	Economy	14400.00
0005433124011	15660	Economy	14400.00
0005433123995	15660	Economy	14400.00
0005433124002	15660	Economy	14400.00
0005433123994	15660	Economy	15900.00
0005434319262	15660	Economy	15900.00
0005433124003	15660	Economy	14400.00
0005434311207	15660	Economy	14400.00
0005434311206	15660	Economy	14400.00
0005434319249	15660	Economy	14400.00
0005433124013	15660	Economy	14400.00
0005434319282	15660	Economy	14400.00
0005433124010	15660	Economy	14400.00
0005434319250	15660	Economy	14400.00
0005434319288	15660	Economy	14400.00
0005434312303	15660	Economy	14400.00
0005434319280	15660	Economy	14400.00
0005433123999	15660	Economy	14400.00
0005433123992	15660	Economy	14400.00
0005434319278	15660	Economy	14400.00
0005433123996	15660	Economy	14400.00
0005434312304	15660	Economy	14400.00
0005434319277	15660	Economy	14400.00
0005433124000	15660	Economy	14400.00
0005433123991	15660	Economy	14400.00
0005433123990	15660	Economy	14400.00
0005433123998	15660	Economy	14400.00
0005433124007	15660	Economy	14400.00
0005433124004	15660	Economy	14400.00
0005433123993	15660	Economy	14400.00
0005433124001	15660	Economy	14400.00
0005433124005	15660	Economy	14400.00
0005434311208	15660	Economy	14400.00
0005435217696	24982	Economy	17100.00
0005435220301	24982	Economy	15500.00
0005435220299	24982	Economy	15500.00
0005435217699	24982	Economy	15500.00
0005435221512	24982	Economy	15500.00
0005435221504	24982	Economy	15500.00
0005435217698	24982	Economy	15500.00
0005435217695	24982	Economy	15500.00
0005435220306	24982	Economy	15500.00
0005435220300	24982	Economy	15500.00
0005435220298	24982	Economy	15500.00
0005435217697	24982	Economy	15500.00
0005435220297	24982	Economy	15500.00
0005435220302	24982	Economy	15500.00
0005434189147	8973	Economy	27400.00
0005434189132	8973	Economy	27400.00
0005434484366	8973	Economy	24900.00
0005434189123	8973	Economy	24900.00
0005434189134	8973	Economy	24900.00
0005434484370	8973	Economy	24900.00
0005434189125	8973	Economy	24900.00
0005434189133	8973	Economy	24900.00
0005434484368	8973	Economy	24900.00
0005434189124	8973	Economy	24900.00
0005434484372	8973	Economy	24900.00
0005434484371	8973	Economy	24900.00
0005434189157	8973	Economy	24900.00
0005434189158	8973	Economy	24900.00
0005434484367	8973	Economy	24900.00
0005434189128	8973	Economy	24900.00
0005434484369	8973	Economy	24900.00
0005434189155	8973	Economy	24900.00
0005434189154	8973	Economy	24900.00
0005434189148	8973	Economy	24900.00
0005434484300	16633	Economy	24900.00
0005434189197	16633	Economy	24900.00
0005434189199	16633	Economy	24900.00
0005434484314	16633	Economy	24900.00
0005434484312	16633	Economy	24900.00
0005434189198	16633	Economy	24900.00
0005434189194	16633	Economy	24900.00
0005434189196	16633	Economy	24900.00
0005434484323	16633	Economy	24900.00
0005434484301	16633	Economy	24900.00
0005434189195	16633	Economy	24900.00
0005433123998	7608	Business	11100.00
0005433124012	7608	Business	11100.00
0005433123996	7608	Business	11100.00
0005433123992	7608	Economy	3700.00
0005433123997	7608	Economy	3700.00
0005433123993	7608	Economy	3700.00
0005433722174	7608	Economy	3700.00
0005433124009	7608	Economy	4100.00
0005433722183	7608	Economy	4100.00
0005433124001	7608	Economy	3700.00
0005433124005	7608	Economy	3700.00
0005433124000	7608	Economy	3700.00
0005433722191	7608	Economy	3700.00
0005433123994	7608	Economy	3700.00
0005433722178	7608	Economy	3700.00
0005433124007	7608	Economy	3700.00
0005433722159	7608	Economy	3700.00
0005433123995	7608	Economy	3700.00
0005433124003	7608	Economy	3700.00
0005433722196	7608	Economy	3700.00
0005433722181	7608	Economy	3700.00
0005433722173	7608	Economy	3700.00
0005433123990	7608	Economy	3700.00
0005433124010	7608	Economy	3700.00
0005433124004	7608	Economy	3700.00
0005433123999	7608	Economy	3700.00
0005433722158	7608	Economy	3700.00
0005433722157	7608	Economy	3700.00
0005433124002	7608	Economy	3700.00
0005433722164	7608	Economy	3700.00
0005433722156	7608	Economy	3700.00
0005433722165	7608	Economy	3700.00
0005433722179	7608	Economy	3700.00
0005433722175	7608	Economy	3700.00
0005433124011	7608	Economy	3700.00
0005433123991	7608	Economy	3700.00
0005433722176	7608	Economy	3700.00
0005433124006	7608	Economy	3700.00
0005433722180	7608	Economy	3700.00
0005433124008	7608	Economy	3700.00
0005433124013	7608	Economy	3700.00
0005432720980	7607	Business	11100.00
0005433450032	7607	Business	11100.00
0005432720994	7607	Business	11100.00
0005433450030	7607	Business	11100.00
0005432693161	7607	Business	11100.00
0005433450037	7607	Business	11100.00
0005432720991	7607	Business	11100.00
0005432693181	7607	Business	11100.00
0005432693178	7607	Business	11100.00
0005433450029	7607	Business	11100.00
0005432693187	7607	Business	11100.00
0005432720995	7607	Economy	3700.00
0005432720978	7607	Economy	3700.00
0005432693185	7607	Economy	3700.00
0005432721001	7607	Economy	3700.00
0005432693163	7607	Economy	3700.00
0005432693183	7607	Economy	3700.00
0005432720981	7607	Economy	3700.00
0005433450041	7607	Economy	4100.00
0005432720993	7607	Economy	4100.00
0005432693172	7607	Economy	3700.00
0005432693177	7607	Economy	3700.00
0005432720996	7607	Economy	3700.00
0005432693186	7607	Economy	3700.00
0005432693167	7607	Economy	3700.00
0005432693166	7607	Economy	3700.00
0005432721002	7607	Economy	3700.00
0005432693175	7607	Economy	3700.00
0005432720985	7607	Economy	3700.00
0005433450031	7607	Economy	3700.00
0005432721003	7607	Economy	3700.00
0005432693179	7607	Economy	3700.00
0005432693168	7607	Economy	3700.00
0005432693189	7607	Economy	3700.00
0005432693170	7607	Economy	3700.00
0005432693162	7607	Economy	3700.00
0005432693174	7607	Economy	3700.00
0005433450050	7607	Economy	3700.00
0005432071584	7607	Economy	3700.00
0005432721000	7607	Economy	3700.00
0005432693184	7607	Economy	3700.00
0005432720983	7607	Economy	3700.00
0005432693188	7607	Economy	3700.00
0005432720997	7607	Economy	3700.00
0005432720979	7607	Economy	3700.00
0005433450045	7607	Economy	3700.00
0005433450035	7607	Economy	3700.00
0005433450047	7607	Economy	3700.00
0005432720988	7607	Economy	3700.00
0005432693169	7607	Economy	3700.00
0005433450049	7607	Economy	3700.00
0005432720990	7607	Economy	3700.00
0005433450036	7607	Economy	3700.00
0005433450039	7607	Economy	3700.00
0005432720987	7607	Economy	3700.00
0005433450038	7607	Economy	3700.00
0005433450033	7607	Economy	3700.00
0005432071583	7607	Economy	3700.00
0005432693164	7607	Economy	3700.00
0005432693165	7607	Economy	3700.00
0005432693180	7607	Economy	3700.00
0005432720986	7607	Economy	3700.00
0005433450046	7607	Economy	3700.00
0005433450048	7607	Economy	3700.00
0005433450040	7607	Economy	3700.00
0005433450043	7607	Economy	3700.00
0005432693171	7607	Economy	3700.00
0005432721005	7607	Economy	3700.00
0005432693159	7607	Economy	3700.00
0005432693160	7607	Economy	3700.00
0005432693173	7607	Economy	3700.00
0005432693176	7607	Economy	3700.00
0005432720982	7607	Economy	3700.00
0005432720998	7607	Economy	3700.00
0005433450044	7607	Economy	3700.00
0005432720984	7607	Economy	3700.00
0005433450034	7607	Economy	3700.00
0005432720999	7607	Economy	3700.00
0005432693182	7607	Economy	3700.00
0005433450042	7607	Economy	3700.00
0005432071582	7607	Economy	3700.00
0005432720989	7607	Economy	3700.00
0005433450051	7607	Economy	3700.00
0005432721004	7607	Economy	3700.00
0005432720992	7607	Economy	3700.00
0005432692886	30281	Business	11100.00
0005432692843	30281	Business	11100.00
0005432693013	30281	Business	11100.00
0005432692951	30281	Business	11100.00
0005433449722	30281	Business	11100.00
0005432692845	30281	Business	11100.00
0005432692958	30281	Business	11100.00
0005433449915	30281	Economy	3700.00
0005432692956	30281	Economy	3700.00
0005432692849	30281	Economy	3700.00
0005433449717	30281	Economy	3700.00
0005433449841	30281	Economy	3700.00
0005433449958	30281	Economy	3700.00
0005433449842	30281	Economy	3700.00
0005432692957	30281	Economy	4100.00
0005432692932	30281	Economy	4100.00
0005433449832	30281	Economy	3700.00
0005432692942	30281	Economy	3700.00
0005432692805	30281	Economy	3700.00
0005432692961	30281	Economy	3700.00
0005432692902	30281	Economy	3700.00
0005432693014	30281	Economy	3700.00
0005432692899	30281	Economy	3700.00
0005433449937	30281	Economy	3700.00
0005432692901	30281	Economy	3700.00
0005433449810	30281	Economy	3700.00
0005432692838	30281	Economy	3700.00
0005432692818	30281	Economy	3700.00
0005432692943	30281	Economy	3700.00
0005433449901	30281	Economy	3700.00
0005432692962	30281	Economy	3700.00
0005432692959	30281	Economy	3700.00
0005432692874	30281	Economy	3700.00
0005432692851	30281	Economy	3700.00
0005432692850	30281	Economy	3700.00
0005433449855	30281	Economy	3700.00
0005432692988	30281	Economy	3700.00
0005432692856	30281	Economy	3700.00
0005432692887	30281	Economy	3700.00
0005433449936	30281	Economy	3700.00
0005432692844	30281	Economy	3700.00
0005433449765	30281	Economy	3700.00
0005432692950	30281	Economy	3700.00
0005432692989	30281	Economy	3700.00
0005432692963	30281	Economy	3700.00
0005432692837	30281	Economy	3700.00
0005432693015	30281	Economy	3700.00
0005432692806	30281	Economy	3700.00
0005432692922	30281	Economy	3700.00
0005432692967	30281	Economy	3700.00
0005433449723	30281	Economy	3700.00
0005433449766	30281	Economy	3700.00
0005432692976	30281	Economy	3700.00
0005432692819	30281	Economy	3700.00
0005432692968	30281	Economy	3700.00
0005433449780	30281	Economy	3700.00
0005433449902	30281	Economy	3700.00
0005433449725	30281	Economy	3700.00
0005432692855	30281	Economy	3700.00
0005432720723	30280	Business	11100.00
0005432720777	30280	Business	11100.00
0005433123795	30280	Business	11100.00
0005433123799	30280	Business	11100.00
0005433722237	30280	Business	11100.00
0005432720883	30280	Business	11100.00
0005433722245	30280	Business	11100.00
0005432720764	30280	Economy	3700.00
0005432720753	30280	Economy	3700.00
0005432720752	30280	Economy	3700.00
0005432720837	30280	Economy	3700.00
0005433123788	30280	Economy	3700.00
0005433722242	30280	Economy	3700.00
0005432720882	30280	Economy	4100.00
0005433123811	30280	Economy	4100.00
0005432720749	30280	Economy	4100.00
0005433722239	30280	Economy	4100.00
0005433722240	30280	Economy	3700.00
0005433123746	30280	Economy	3700.00
0005432720755	30280	Economy	3700.00
0005432720667	30280	Economy	3700.00
0005433722238	30280	Economy	3700.00
0005432720885	30280	Economy	3700.00
0005433722241	30280	Economy	3700.00
0005432720881	30280	Economy	3700.00
0005432720671	30280	Economy	3700.00
0005433123830	30280	Economy	3700.00
0005432720802	30280	Economy	3700.00
0005433123815	30280	Economy	3700.00
0005432720801	30280	Economy	3700.00
0005433722244	30280	Economy	3700.00
0005433123804	30280	Economy	3700.00
0005433123787	30280	Economy	3700.00
0005433123737	30280	Economy	3700.00
0005433123829	30280	Economy	3700.00
0005432720735	30280	Economy	3700.00
0005433123814	30280	Economy	3700.00
0005432720803	30280	Economy	3700.00
0005432720770	30280	Economy	3700.00
0005433123745	30280	Economy	3700.00
0005432720739	30280	Economy	3700.00
0005432720836	30280	Economy	3700.00
0005432720765	30280	Economy	3700.00
0005432720766	30280	Economy	3700.00
0005433123806	30280	Economy	3700.00
0005432720884	30280	Economy	3700.00
0005432720811	30280	Economy	3700.00
0005433123840	30280	Economy	3700.00
0005432720763	30280	Economy	3700.00
0005433722243	30280	Economy	3700.00
0005432720778	30280	Economy	3700.00
0005432720769	30280	Economy	3700.00
0005434586684	1394	Business	70400.00
0005432927957	1394	Business	70400.00
0005433525071	1394	Business	70400.00
0005433193017	1394	Business	70400.00
0005433192982	1394	Business	70400.00
0005433192960	1394	Business	70400.00
0005434586705	1394	Business	70400.00
0005434586687	1394	Business	70400.00
0005433193016	1394	Business	70400.00
0005434513589	1394	Economy	23500.00
0005432927955	1394	Economy	23500.00
0005434586691	1394	Economy	23500.00
0005433192987	1394	Economy	23500.00
0005434586703	1394	Economy	23500.00
0005433724820	1394	Economy	23500.00
0005433525076	1394	Economy	23500.00
0005434586700	1394	Economy	25800.00
0005434586706	1394	Economy	25800.00
0005433192981	1394	Economy	25800.00
0005433192971	1394	Economy	25800.00
0005434586701	1394	Economy	23500.00
0005434586696	1394	Economy	23500.00
0005434513590	1394	Economy	23500.00
0005432271012	1394	Economy	23500.00
0005433525073	1394	Economy	23500.00
0005432271014	1394	Economy	23500.00
0005433525074	1394	Economy	23500.00
0005433525079	1394	Economy	23500.00
0005434586690	1394	Economy	23500.00
0005433192984	1394	Economy	23500.00
0005434586693	1394	Economy	23500.00
0005434513591	1394	Economy	23500.00
0005434586695	1394	Economy	23500.00
0005434586688	1394	Economy	23500.00
0005434586692	1394	Economy	23500.00
0005433525078	1394	Economy	23500.00
0005432927956	1394	Economy	23500.00
0005434586685	1394	Economy	23500.00
0005433192959	1394	Economy	23500.00
0005434586689	1394	Economy	23500.00
0005432271013	1394	Economy	23500.00
0005433192972	1394	Economy	23500.00
0005434586683	1394	Economy	23500.00
0005434586686	1394	Economy	23500.00
0005434586702	1394	Economy	23500.00
0005434586699	1394	Economy	23500.00
0005434514975	1394	Economy	23500.00
0005434514977	1394	Economy	23500.00
0005433724819	1394	Economy	23500.00
0005433525077	1394	Economy	23500.00
0005434586697	1394	Economy	23500.00
0005432927926	1394	Economy	23500.00
0005434586704	1394	Economy	23500.00
0005433724821	1394	Economy	23500.00
0005434513588	1394	Economy	23500.00
0005433525075	1394	Economy	23500.00
0005432927939	1394	Economy	23500.00
0005434586707	1394	Economy	23500.00
0005434586708	1394	Economy	23500.00
0005434586698	1394	Economy	23500.00
0005434586694	1394	Economy	23500.00
0005433525072	1394	Economy	23500.00
0005433525070	1394	Economy	23500.00
0005434514976	1394	Economy	23500.00
0005432927996	18523	Business	70400.00
0005434586525	18523	Business	70400.00
0005434586562	18523	Business	70400.00
0005434586531	18523	Business	70400.00
0005434514946	18523	Business	70400.00
0005433193083	18523	Business	70400.00
0005433193084	18523	Business	70400.00
0005433724792	18523	Business	70400.00
0005433193095	18523	Business	70400.00
0005433724778	18523	Business	70400.00
0005433524977	18523	Economy	23500.00
0005434586482	18523	Economy	23500.00
0005434586537	18523	Economy	23500.00
0005434586387	18523	Economy	23500.00
0005434586437	18523	Economy	23500.00
0005432968847	18523	Economy	23500.00
0005432927997	18523	Economy	23500.00
0005433524964	18523	Economy	25800.00
0005434586448	18523	Economy	25800.00
0005434586524	18523	Economy	25800.00
0005434586547	18523	Economy	25800.00
0005434586542	18523	Economy	23500.00
0005433193092	18523	Economy	23500.00
0005433524997	18523	Economy	23500.00
0005433193093	18523	Economy	23500.00
0005433193088	18523	Economy	23500.00
0005434586373	18523	Economy	23500.00
0005433524958	18523	Economy	23500.00
0005434586480	18523	Economy	23500.00
0005433193090	18523	Economy	23500.00
0005434514957	18523	Economy	23500.00
0005434586412	18523	Economy	23500.00
0005434514963	18523	Economy	23500.00
0005434586413	18523	Economy	23500.00
0005434586507	18523	Economy	23500.00
0005434514964	18523	Economy	23500.00
0005433524961	18523	Economy	23500.00
0005432927995	18523	Economy	23500.00
0005434586451	18523	Economy	23500.00
0005432927998	18523	Economy	23500.00
0005434586506	18523	Economy	23500.00
0005434514941	18523	Economy	23500.00
0005433524962	18523	Economy	23500.00
0005434586374	18523	Economy	23500.00
0005433724772	18523	Economy	23500.00
0005434586460	18523	Economy	23500.00
0005434586505	18523	Economy	23500.00
0005433193086	18523	Economy	23500.00
0005434586541	18523	Economy	23500.00
0005433193094	18523	Economy	23500.00
0005433524960	18523	Economy	23500.00
0005434514940	18523	Economy	23500.00
0005432968846	18523	Economy	23500.00
0005434586414	18523	Economy	23500.00
0005433193085	18523	Economy	23500.00
0005433193082	18523	Economy	23500.00
0005434586466	18523	Economy	23500.00
0005432927999	18523	Economy	23500.00
0005433193091	18523	Economy	23500.00
0005433724793	18523	Economy	23500.00
0005434586449	18523	Economy	23500.00
0005433524959	18523	Economy	23500.00
0005433524963	18523	Economy	23500.00
0005434586386	18523	Economy	23500.00
0005433193089	18523	Economy	23500.00
0005433193087	18523	Economy	23500.00
0005434586500	18523	Economy	23500.00
0005435302179	11465	Economy	4300.00
0005434344308	11465	Economy	4300.00
0005435302157	11465	Economy	4300.00
0005434344302	11465	Economy	4000.00
0005434344296	11465	Economy	4000.00
0005434344321	11465	Economy	4000.00
0005434344309	11465	Economy	4000.00
0005434344304	11465	Economy	4000.00
0005434344287	11465	Economy	4000.00
0005434344295	11465	Economy	4000.00
0005434344297	11465	Economy	4000.00
0005434344324	11465	Economy	4000.00
0005434344319	11465	Economy	4000.00
0005434344314	11465	Economy	4000.00
0005434344315	11465	Economy	4000.00
0005435302126	11465	Economy	4000.00
0005434344318	11465	Economy	4000.00
0005434344317	11465	Economy	4000.00
0005434344313	11465	Economy	4000.00
0005434344311	11465	Economy	4000.00
0005434344300	11465	Economy	4000.00
0005434344306	11465	Economy	4000.00
0005434344305	11465	Economy	4000.00
0005434344322	11465	Economy	4000.00
0005434344293	11465	Economy	4000.00
0005434142624	11465	Economy	4000.00
0005434344307	11465	Economy	4000.00
0005434344301	11465	Economy	4000.00
0005434344289	11465	Economy	4000.00
0005434142622	11465	Economy	4000.00
0005434344290	11465	Economy	4000.00
0005434344288	11465	Economy	4000.00
0005434344323	11465	Economy	4000.00
0005434344294	11465	Economy	4000.00
0005434142625	11465	Economy	4000.00
0005434344291	11465	Economy	4000.00
0005435302127	11465	Economy	4000.00
0005434344292	11465	Economy	4000.00
0005434344299	11465	Economy	4000.00
0005434344320	11465	Economy	4000.00
0005434142623	11465	Economy	4000.00
0005434344298	11465	Economy	4000.00
0005434344303	11465	Economy	4000.00
0005434344310	11465	Economy	4000.00
0005434344316	11465	Economy	4000.00
0005434344312	11465	Economy	4000.00
0005435302169	11465	Economy	4000.00
0005434343962	29779	Economy	4300.00
0005434343930	29779	Economy	4300.00
0005434343931	29779	Economy	4300.00
0005434344037	29779	Economy	4300.00
0005435304175	29779	Economy	4000.00
0005434343968	29779	Economy	4000.00
0005434142585	29779	Economy	4000.00
0005434344025	29779	Economy	4000.00
0005434344133	29779	Economy	4000.00
0005435304176	29779	Economy	4000.00
0005434343855	29779	Economy	4000.00
0005434343897	29779	Economy	4000.00
0005434344010	29779	Economy	4000.00
0005434142584	29779	Economy	4000.00
0005434142583	29779	Economy	4000.00
0005434343939	29779	Economy	4000.00
0005435304178	29779	Economy	4000.00
0005434344136	29779	Economy	4000.00
0005434344098	29779	Economy	4000.00
0005434343947	29779	Economy	4000.00
0005434344080	29779	Economy	4000.00
0005434142586	29779	Economy	4000.00
0005434343948	29779	Economy	4000.00
0005434343967	29779	Economy	4000.00
0005434344174	29779	Economy	4000.00
0005434344067	29779	Economy	4000.00
0005434343927	29779	Economy	4000.00
0005435305016	29779	Economy	4000.00
0005434343976	29779	Economy	4000.00
0005435305017	29779	Economy	4000.00
0005434344081	29779	Economy	4000.00
0005434343883	29779	Economy	4000.00
0005434142587	29779	Economy	4000.00
0005434343929	29779	Economy	4000.00
0005434344011	29779	Economy	4000.00
0005435305018	29779	Economy	4000.00
0005434344094	29779	Economy	4000.00
0005434344110	29779	Economy	4000.00
0005435304177	29779	Economy	4000.00
0005434344042	29779	Economy	4000.00
0005434344101	29779	Economy	4000.00
0005435304174	29779	Economy	4000.00
0005434343896	29779	Economy	4000.00
0005434343953	29779	Economy	4000.00
0005434344100	29779	Economy	4000.00
0005434344013	29779	Economy	4000.00
0005434343957	29779	Economy	4000.00
0005434343963	29779	Economy	4000.00
0005434343878	29779	Economy	4000.00
0005433415653	1250	Business	199800.00
0005435824722	1250	Business	199800.00
0005433415663	1250	Business	199800.00
0005433415525	1250	Business	199800.00
0005435824717	1250	Business	199800.00
0005432284569	1250	Business	199800.00
0005435824727	1250	Business	199800.00
0005435824707	1250	Economy	66600.00
0005435824703	1250	Economy	66600.00
0005435824726	1250	Economy	66600.00
0005435824705	1250	Economy	66600.00
0005433415664	1250	Economy	73200.00
0005435824724	1250	Economy	66600.00
0005435824723	1250	Economy	66600.00
0005433415563	1250	Economy	66600.00
0005433415603	1250	Economy	66600.00
0005435824701	1250	Economy	66600.00
0005435824704	1250	Economy	66600.00
0005435824725	1250	Economy	66600.00
0005435824714	1250	Economy	66600.00
0005435824720	1250	Economy	66600.00
0005433415579	1250	Economy	66600.00
0005435824710	1250	Economy	66600.00
0005433415580	1250	Economy	66600.00
0005435824712	1250	Economy	66600.00
0005435824700	1250	Economy	66600.00
0005435824709	1250	Economy	66600.00
0005435824708	1250	Economy	66600.00
0005432284568	1250	Economy	66600.00
0005435824711	1250	Economy	66600.00
0005435824718	1250	Economy	66600.00
0005435824719	1250	Economy	66600.00
0005435824721	1250	Economy	66600.00
0005435824716	1250	Economy	66600.00
0005433415595	1250	Economy	66600.00
0005435824715	1250	Economy	66600.00
0005435824713	1250	Economy	66600.00
0005435824702	1250	Economy	66600.00
0005435824706	1250	Economy	66600.00
0005435824521	17976	Business	199800.00
0005435824459	17976	Business	199800.00
0005433415706	17976	Business	199800.00
0005433415713	17976	Business	199800.00
0005435824364	17976	Business	199800.00
0005435824524	17976	Business	199800.00
0005435824453	17976	Economy	66600.00
0005433415717	17976	Economy	66600.00
0005435824602	17976	Economy	66600.00
0005435824559	17976	Economy	66600.00
0005435824365	17976	Economy	66600.00
0005435824417	17976	Economy	66600.00
0005433415704	17976	Economy	66600.00
0005435824455	17976	Economy	66600.00
0005435824426	17976	Economy	66600.00
0005435824504	17976	Economy	73200.00
0005433415719	17976	Economy	73200.00
0005433415711	17976	Economy	73200.00
0005433415718	17976	Economy	66600.00
0005435824503	17976	Economy	66600.00
0005433415708	17976	Economy	66600.00
0005435824363	17976	Economy	66600.00
0005435824482	17976	Economy	66600.00
0005433415714	17976	Economy	66600.00
0005433415715	17976	Economy	66600.00
0005435824418	17976	Economy	66600.00
0005435824525	17976	Economy	66600.00
0005435824485	17976	Economy	66600.00
0005435824454	17976	Economy	66600.00
0005433415709	17976	Economy	66600.00
0005435824366	17976	Economy	66600.00
0005435824458	17976	Economy	66600.00
0005433415712	17976	Economy	66600.00
0005435824475	17976	Economy	66600.00
0005435824408	17976	Economy	66600.00
0005435824514	17976	Economy	66600.00
0005433415707	17976	Economy	66600.00
0005433415705	17976	Economy	66600.00
0005435824505	17976	Economy	66600.00
0005433415710	17976	Economy	66600.00
0005435824367	17976	Economy	66600.00
0005433415716	17976	Economy	66600.00
0005435824499	17976	Economy	66600.00
0005434462778	17520	Economy	14800.00
0005434460493	17520	Economy	13500.00
0005434460484	17520	Economy	13500.00
0005434462761	17520	Economy	13500.00
0005434462781	17520	Economy	13500.00
0005434462782	17520	Economy	13500.00
0005434460479	17520	Economy	13500.00
0005434460494	17520	Economy	13500.00
0005434462776	17520	Economy	13500.00
0005434460487	17520	Economy	13500.00
0005434462777	17520	Economy	13500.00
0005434460497	17520	Economy	13500.00
0005434462779	17520	Economy	13500.00
0005434462768	17520	Economy	13500.00
0005434462774	17520	Economy	13500.00
0005432783947	5619	Business	27800.00
0005432783977	5619	Business	27800.00
0005435242613	5619	Business	27800.00
0005435242680	5619	Business	27800.00
0005435476704	5619	Business	27800.00
0005432783981	5619	Business	27800.00
0005435242686	5619	Business	27800.00
0005432783987	5619	Business	27800.00
0005432783975	5619	Business	27800.00
0005432783982	5619	Business	27800.00
0005435242812	5619	Business	27800.00
0005435242711	5619	Business	27800.00
0005432783969	5619	Economy	9300.00
0005432783959	5619	Economy	9300.00
0005432783942	5619	Economy	9300.00
0005435242709	5619	Economy	9300.00
0005435242676	5619	Economy	9300.00
0005435242762	5619	Economy	9300.00
0005435242761	5619	Economy	9300.00
0005432783962	5619	Economy	9300.00
0005432783985	5619	Economy	9300.00
0005432783954	5619	Economy	9300.00
0005435242728	5619	Economy	10200.00
0005435242771	5619	Economy	10200.00
0005432783960	5619	Economy	10200.00
0005432783945	5619	Economy	10200.00
0005435242770	5619	Economy	10200.00
0005432783971	5619	Economy	9300.00
0005432143999	5619	Economy	9300.00
0005435242715	5619	Economy	9300.00
0005435242768	5619	Economy	9300.00
0005432783992	5619	Economy	9300.00
0005435242769	5619	Economy	9300.00
0005432783980	5619	Economy	9300.00
0005435242578	5619	Economy	9300.00
0005432783965	5619	Economy	9300.00
0005435242635	5619	Economy	9300.00
0005432783968	5619	Economy	9300.00
0005432783949	5619	Economy	9300.00
0005432783970	5619	Economy	9300.00
0005435242675	5619	Economy	9300.00
0005432783963	5619	Economy	9300.00
0005432783989	5619	Economy	9300.00
0005435242651	5619	Economy	9300.00
0005435242688	5619	Economy	9300.00
0005432783961	5619	Economy	9300.00
0005432783994	5619	Economy	9300.00
0005432783993	5619	Economy	9300.00
0005432783976	5619	Economy	9300.00
0005432783995	5619	Economy	9300.00
0005432783986	5619	Economy	9300.00
0005432783988	5619	Economy	9300.00
0005435476693	5619	Economy	9300.00
0005432783990	5619	Economy	9300.00
0005432783958	5619	Economy	9300.00
0005432783991	5619	Economy	9300.00
0005435242733	5619	Economy	9300.00
0005432783979	5619	Economy	9300.00
0005432783984	5619	Economy	9300.00
0005432783953	5619	Economy	9300.00
0005432783967	5619	Economy	9300.00
0005432783952	5619	Economy	9300.00
0005435242732	5619	Economy	9300.00
0005432783972	5619	Economy	9300.00
0005435476694	5619	Economy	9300.00
0005435242708	5619	Economy	9300.00
0005432783946	5619	Economy	9300.00
0005432783983	5619	Economy	9300.00
0005432783955	5619	Economy	9300.00
0005435242723	5619	Economy	9300.00
0005435242535	5619	Economy	9300.00
0005432783944	5619	Economy	9300.00
0005432144001	5619	Economy	9300.00
0005435242664	5619	Economy	9300.00
0005432783950	5619	Economy	9300.00
0005432783964	5619	Economy	9300.00
0005432143998	5619	Economy	9300.00
0005435476712	5619	Economy	9300.00
0005432143997	5619	Economy	9300.00
0005432783951	5619	Economy	9300.00
0005432143996	5619	Economy	9300.00
0005432783957	5619	Economy	9300.00
0005432783940	5619	Economy	9300.00
0005435242687	5619	Economy	9300.00
0005432783941	5619	Economy	9300.00
0005432783978	5619	Economy	9300.00
0005432783943	5619	Economy	9300.00
0005432783956	5619	Economy	9300.00
0005432783974	5619	Economy	9300.00
0005435242650	5619	Economy	9300.00
0005432783948	5619	Economy	9300.00
0005432783966	5619	Economy	9300.00
0005432144000	5619	Economy	9300.00
0005435242689	5619	Economy	9300.00
0005432783973	5619	Economy	9300.00
0005435242665	5619	Economy	9300.00
0005435242932	15388	Business	27800.00
0005432783431	15388	Business	27800.00
0005432783310	15388	Business	27800.00
0005432783518	15388	Business	27800.00
0005432783443	15388	Business	27800.00
0005435242918	15388	Business	27800.00
0005435242912	15388	Business	27800.00
0005432783476	15388	Business	27800.00
0005435242924	15388	Business	27800.00
0005435242922	15388	Business	27800.00
0005432783403	15388	Business	27800.00
0005432783437	15388	Business	27800.00
0005432783154	15388	Economy	9300.00
0005435242920	15388	Economy	9300.00
0005432783165	15388	Economy	9300.00
0005432783457	15388	Economy	9300.00
0005432783703	15388	Economy	9300.00
0005435242930	15388	Economy	9300.00
0005432783529	15388	Economy	9300.00
0005432783520	15388	Economy	9300.00
0005435242927	15388	Economy	9300.00
0005432783705	15388	Economy	10200.00
0005432783408	15388	Economy	10200.00
0005435242935	15388	Economy	10200.00
0005432783409	15388	Economy	10200.00
0005432783318	15388	Economy	10200.00
0005432783234	15388	Economy	9300.00
0005432783305	15388	Economy	9300.00
0005435242928	15388	Economy	9300.00
0005432783357	15388	Economy	9300.00
0005435242919	15388	Economy	9300.00
0005435242913	15388	Economy	9300.00
0005432783455	15388	Economy	9300.00
0005435242921	15388	Economy	9300.00
0005435242931	15388	Economy	9300.00
0005435476768	15388	Economy	9300.00
0005432783538	15388	Economy	9300.00
0005432783465	15388	Economy	9300.00
0005432783510	15388	Economy	9300.00
0005435242926	15388	Economy	9300.00
0005432783576	15388	Economy	9300.00
0005432783722	15388	Economy	9300.00
0005432783335	15388	Economy	9300.00
0005432783399	15388	Economy	9300.00
0005432783477	15388	Economy	9300.00
0005432783155	15388	Economy	9300.00
0005435242923	15388	Economy	9300.00
0005432783417	15388	Economy	9300.00
0005432783359	15388	Economy	9300.00
0005432783295	15388	Economy	9300.00
0005435242929	15388	Economy	9300.00
0005435476771	15388	Economy	9300.00
0005432783358	15388	Economy	9300.00
0005435476773	15388	Economy	9300.00
0005435242934	15388	Economy	9300.00
0005432783178	15388	Economy	9300.00
0005435476776	15388	Economy	9300.00
0005432783402	15388	Economy	9300.00
0005435476775	15388	Economy	9300.00
0005432783562	15388	Economy	9300.00
0005435242933	15388	Economy	9300.00
0005432783660	15388	Economy	9300.00
0005435476777	15388	Economy	9300.00
0005432783561	15388	Economy	9300.00
0005435242925	15388	Economy	9300.00
0005435476778	15388	Economy	9300.00
0005432783371	15388	Economy	9300.00
0005435242909	15388	Economy	9300.00
0005435242908	15388	Economy	9300.00
0005432783364	15388	Economy	9300.00
0005435242914	15388	Economy	9300.00
0005432783704	15388	Economy	9300.00
0005435476772	15388	Economy	9300.00
0005432783717	15388	Economy	9300.00
0005432783303	15388	Economy	9300.00
0005435242917	15388	Economy	9300.00
0005432783466	15388	Economy	9300.00
0005432783304	15388	Economy	9300.00
0005435242915	15388	Economy	9300.00
0005432783478	15388	Economy	9300.00
0005432783511	15388	Economy	9300.00
0005432783294	15388	Economy	9300.00
0005435476769	15388	Economy	9300.00
0005435242911	15388	Economy	9300.00
0005435242910	15388	Economy	9300.00
0005432783018	15388	Economy	9300.00
0005435242916	15388	Economy	9300.00
0005435476774	15388	Economy	9300.00
0005435476770	15388	Economy	9300.00
0005432783519	15388	Economy	9300.00
0005435850865	4335	Economy	7000.00
0005435850868	4335	Economy	7000.00
0005432848358	4335	Economy	6300.00
0005432848353	4335	Economy	6300.00
0005432848357	4335	Economy	6300.00
0005432848360	4335	Economy	6300.00
0005432848363	4335	Economy	6300.00
0005434463936	4335	Economy	6300.00
0005434462797	4335	Economy	6300.00
0005435850909	4335	Economy	6300.00
0005435850857	4335	Economy	6300.00
0005435850903	4335	Economy	6300.00
0005432848365	4335	Economy	6300.00
0005432848356	4335	Economy	6300.00
0005432848355	4335	Economy	6300.00
0005432848361	4335	Economy	6300.00
0005432848359	4335	Economy	6300.00
0005432848354	4335	Economy	6300.00
0005432848364	4335	Economy	6300.00
0005435850902	4335	Economy	6300.00
0005435850860	4335	Economy	6300.00
0005435850875	4335	Economy	6300.00
0005435850873	4335	Economy	6300.00
0005435850901	4335	Economy	6300.00
0005432848366	4335	Economy	6300.00
0005432848352	4335	Economy	6300.00
0005432848362	4335	Economy	6300.00
0005435850942	28847	Economy	6300.00
0005435850943	28847	Economy	6300.00
0005432848266	28847	Economy	6300.00
0005434461636	28847	Economy	6300.00
0005435850940	28847	Economy	6300.00
0005435850938	28847	Economy	6300.00
0005432848251	28847	Economy	6300.00
0005435850936	28847	Economy	6300.00
0005435850945	28847	Economy	6300.00
0005435850941	28847	Economy	6300.00
0005434461637	28847	Economy	6300.00
0005432848304	28847	Economy	6300.00
0005432848238	28847	Economy	6300.00
0005435850944	28847	Economy	6300.00
0005432848220	28847	Economy	6300.00
0005435850939	28847	Economy	6300.00
0005432848255	28847	Economy	6300.00
0005434463924	28847	Economy	6300.00
0005434461635	28847	Economy	6300.00
0005432848219	28847	Economy	6300.00
0005432848265	28847	Economy	6300.00
0005432848206	28847	Economy	6300.00
0005435850935	28847	Economy	6300.00
0005432848245	28847	Economy	6300.00
0005435850937	28847	Economy	6300.00
0005432848246	28847	Economy	6300.00
0005434925911	6321	Business	11900.00
0005433497074	6321	Business	11900.00
0005434925922	6321	Business	11900.00
0005434925902	6321	Business	11900.00
0005434443768	6321	Business	11900.00
0005434443765	6321	Business	11900.00
0005434925900	6321	Business	11900.00
0005434925917	6321	Business	11900.00
0005434443756	6321	Business	11900.00
0005434925894	6321	Business	11900.00
0005433497076	6321	Business	11900.00
0005433497059	6321	Economy	4000.00
0005433497079	6321	Economy	4000.00
0005433497072	6321	Economy	4000.00
0005432075240	6321	Economy	4000.00
0005433497087	6321	Economy	4000.00
0005433497062	6321	Economy	4000.00
0005433497061	6321	Economy	4000.00
0005434925907	6321	Economy	4000.00
0005434925903	6321	Economy	4000.00
0005434443761	6321	Economy	4400.00
0005434443764	6321	Economy	4400.00
0005434925887	6321	Economy	4400.00
0005432075242	6321	Economy	4400.00
0005434925889	6321	Economy	4400.00
0005434443758	6321	Economy	4000.00
0005433497088	6321	Economy	4000.00
0005434925910	6321	Economy	4000.00
0005434925893	6321	Economy	4000.00
0005434925883	6321	Economy	4000.00
0005434925895	6321	Economy	4000.00
0005433497082	6321	Economy	4000.00
0005434443760	6321	Economy	4000.00
0005434443757	6321	Economy	4000.00
0005434925886	6321	Economy	4000.00
0005433497064	6321	Economy	4000.00
0005433497080	6321	Economy	4000.00
0005434925914	6321	Economy	4000.00
0005433497078	6321	Economy	4000.00
0005434443763	6321	Economy	4000.00
0005433497071	6321	Economy	4000.00
0005434925918	6321	Economy	4000.00
0005434925899	6321	Economy	4000.00
0005434925898	6321	Economy	4000.00
0005434925884	6321	Economy	4000.00
0005433497085	6321	Economy	4000.00
0005434925896	6321	Economy	4000.00
0005434925919	6321	Economy	4000.00
0005434925920	6321	Economy	4000.00
0005434443766	6321	Economy	4000.00
0005433497077	6321	Economy	4000.00
0005433497067	6321	Economy	4000.00
0005434925916	6321	Economy	4000.00
0005433497066	6321	Economy	4000.00
0005433497060	6321	Economy	4000.00
0005434443770	6321	Economy	4000.00
0005434925890	6321	Economy	4000.00
0005434925888	6321	Economy	4000.00
0005434443762	6321	Economy	4000.00
0005434443755	6321	Economy	4000.00
0005434925906	6321	Economy	4000.00
0005433497069	6321	Economy	4000.00
0005433497070	6321	Economy	4000.00
0005434925901	6321	Economy	4000.00
0005433497073	6321	Economy	4000.00
0005434925912	6321	Economy	4000.00
0005433497084	6321	Economy	4000.00
0005433497086	6321	Economy	4000.00
0005434925892	6321	Economy	4000.00
0005434443767	6321	Economy	4000.00
0005433497063	6321	Economy	4000.00
0005434925908	6321	Economy	4000.00
0005434925905	6321	Economy	4000.00
0005433497089	6321	Economy	4000.00
0005433497083	6321	Economy	4000.00
0005433497065	6321	Economy	4000.00
0005434925904	6321	Economy	4000.00
0005434925891	6321	Economy	4000.00
0005434443769	6321	Economy	4000.00
0005433497075	6321	Economy	4000.00
0005434925897	6321	Economy	4000.00
0005433497081	6321	Economy	4000.00
0005434925921	6321	Economy	4000.00
0005434925913	6321	Economy	4000.00
0005434925885	6321	Economy	4000.00
0005434925915	6321	Economy	4000.00
0005434925909	6321	Economy	4000.00
0005432075241	6321	Economy	4000.00
0005433497058	6321	Economy	4000.00
0005434443759	6321	Economy	4000.00
0005433497068	6321	Economy	4000.00
0005434925570	20387	Business	11900.00
0005434443655	20387	Business	11900.00
0005434443626	20387	Business	11900.00
0005434443624	20387	Business	11900.00
0005434443636	20387	Business	11900.00
0005434443635	20387	Business	11900.00
0005433496837	20387	Business	11900.00
0005434443491	20387	Business	11900.00
0005433496966	20387	Business	11900.00
0005434925569	20387	Business	11900.00
0005433496881	20387	Economy	4000.00
0005434443576	20387	Economy	4000.00
0005433496808	20387	Economy	4000.00
0005434443625	20387	Economy	4000.00
0005434925539	20387	Economy	4000.00
0005434925576	20387	Economy	4000.00
0005433496786	20387	Economy	4000.00
0005434443595	20387	Economy	4400.00
0005434443627	20387	Economy	4400.00
0005434443553	20387	Economy	4400.00
0005434443589	20387	Economy	4400.00
0005434443674	20387	Economy	4000.00
0005434443637	20387	Economy	4000.00
0005434925621	20387	Economy	4000.00
0005434443550	20387	Economy	4000.00
0005433496889	20387	Economy	4000.00
0005434443575	20387	Economy	4000.00
0005434925531	20387	Economy	4000.00
0005434925618	20387	Economy	4000.00
0005434925538	20387	Economy	4000.00
0005434443594	20387	Economy	4000.00
0005434925575	20387	Economy	4000.00
0005434925611	20387	Economy	4000.00
0005433496834	20387	Economy	4000.00
0005434925620	20387	Economy	4000.00
0005434925430	20387	Economy	4000.00
0005434925597	20387	Economy	4000.00
0005433496937	20387	Economy	4000.00
0005434443573	20387	Economy	4000.00
0005433496796	20387	Economy	4000.00
0005433496831	20387	Economy	4000.00
0005434925578	20387	Economy	4000.00
0005434443588	20387	Economy	4000.00
0005434925574	20387	Economy	4000.00
0005433496801	20387	Economy	4000.00
0005434443599	20387	Economy	4000.00
0005433496838	20387	Economy	4000.00
0005434925622	20387	Economy	4000.00
0005434443628	20387	Economy	4000.00
0005433496770	20387	Economy	4000.00
0005433496781	20387	Economy	4000.00
0005433496690	20387	Economy	4000.00
0005434443549	20387	Economy	4000.00
0005433496830	20387	Economy	4000.00
0005433496878	20387	Economy	4000.00
0005433496764	20387	Economy	4000.00
0005433496936	20387	Economy	4000.00
0005433496938	20387	Economy	4000.00
0005433496769	20387	Economy	4000.00
0005434443598	20387	Economy	4000.00
0005433496807	20387	Economy	4000.00
0005433496802	20387	Economy	4000.00
0005434925530	20387	Economy	4000.00
0005433496765	20387	Economy	4000.00
0005433496800	20387	Economy	4000.00
0005434925619	20387	Economy	4000.00
0005434443548	20387	Economy	4000.00
0005434925397	20387	Economy	4000.00
0005434443572	20387	Economy	4000.00
0005433496771	20387	Economy	4000.00
0005433496785	20387	Economy	4000.00
0005434443591	20387	Economy	4000.00
0005434925532	20387	Economy	4000.00
0005434443586	20387	Economy	4000.00
0005433496871	20387	Economy	4000.00
0005434925523	20387	Economy	4000.00
0005433496833	20387	Economy	4000.00
0005433496782	20387	Economy	4000.00
0005433496880	20387	Economy	4000.00
0005433496793	20387	Economy	4000.00
0005432783591	12157	Business	41200.00
0005435242953	12157	Business	41200.00
0005432783681	12157	Business	41200.00
0005432783317	12157	Business	41200.00
0005435242945	12157	Business	41200.00
0005432783390	12157	Business	41200.00
0005432783621	12157	Business	41200.00
0005432783546	12157	Business	41200.00
0005432783642	12157	Business	41200.00
0005435242962	12157	Economy	13700.00
0005432783824	12157	Economy	13700.00
0005435242958	12157	Economy	13700.00
0005432783586	12157	Economy	13700.00
0005432783632	12157	Economy	13700.00
0005432783515	12157	Economy	13700.00
0005432783336	12157	Economy	13700.00
0005432783643	12157	Economy	13700.00
0005432783585	12157	Economy	13700.00
0005435242947	12157	Economy	15100.00
0005432783669	12157	Economy	15100.00
0005432783690	12157	Economy	15100.00
0005432783524	12157	Economy	15100.00
0005432783481	12157	Economy	15100.00
0005432783484	12157	Economy	13700.00
0005432783770	12157	Economy	13700.00
0005432783495	12157	Economy	13700.00
0005432783349	12157	Economy	13700.00
0005435242954	12157	Economy	13700.00
0005432783641	12157	Economy	13700.00
0005435242939	12157	Economy	13700.00
0005432783412	12157	Economy	13700.00
0005432783526	12157	Economy	13700.00
0005435242951	12157	Economy	13700.00
0005432783398	12157	Economy	13700.00
0005432783580	12157	Economy	13700.00
0005432783198	12157	Economy	13700.00
0005435242937	12157	Economy	13700.00
0005435242942	12157	Economy	13700.00
0005435242938	12157	Economy	13700.00
0005435242936	12157	Economy	13700.00
0005432783332	12157	Economy	13700.00
0005432783568	12157	Economy	13700.00
0005435242944	12157	Economy	13700.00
0005435242959	12157	Economy	13700.00
0005432783609	12157	Economy	13700.00
0005432783494	12157	Economy	13700.00
0005435242960	12157	Economy	13700.00
0005432783360	12157	Economy	13700.00
0005435242955	12157	Economy	13700.00
0005432783493	12157	Economy	13700.00
0005432783547	12157	Economy	13700.00
0005432783633	12157	Economy	13700.00
0005435242941	12157	Economy	13700.00
0005435242961	12157	Economy	13700.00
0005435242956	12157	Economy	13700.00
0005435242957	12157	Economy	13700.00
0005432783449	12157	Economy	13700.00
0005432783528	12157	Economy	13700.00
0005432783571	12157	Economy	13700.00
0005432783636	12157	Economy	13700.00
0005435242952	12157	Economy	13700.00
0005432783482	12157	Economy	13700.00
0005432783682	12157	Economy	13700.00
0005432783579	12157	Economy	13700.00
0005435242940	12157	Economy	13700.00
0005432783489	12157	Economy	13700.00
0005432783637	12157	Economy	13700.00
0005432783581	12157	Economy	13700.00
0005435242946	12157	Economy	13700.00
0005432783448	12157	Economy	13700.00
0005432783572	12157	Economy	13700.00
0005435242950	12157	Economy	13700.00
0005432783590	12157	Economy	13700.00
0005432783655	12157	Economy	13700.00
0005432783543	12157	Economy	13700.00
0005435242948	12157	Economy	13700.00
0005435242949	12157	Economy	13700.00
0005432783492	12157	Economy	13700.00
0005432783413	12157	Economy	13700.00
0005432783582	12157	Economy	13700.00
0005432783393	12157	Economy	13700.00
0005432783527	12157	Economy	13700.00
0005432783388	12157	Economy	13700.00
0005432783525	12157	Economy	13700.00
0005432783389	12157	Economy	13700.00
0005435242943	12157	Economy	13700.00
0005432783491	12157	Economy	13700.00
0005432783480	12157	Economy	13700.00
0005435242571	15427	Business	41200.00
0005432783903	15427	Business	41200.00
0005432783935	15427	Business	41200.00
0005435242631	15427	Business	41200.00
0005435242787	15427	Business	41200.00
0005435242572	15427	Business	41200.00
0005432783912	15427	Business	41200.00
0005435242658	15427	Business	41200.00
0005432783913	15427	Business	41200.00
0005435242690	15427	Economy	13700.00
0005432783932	15427	Economy	13700.00
0005432783910	15427	Economy	13700.00
0005432783921	15427	Economy	13700.00
0005432783938	15427	Economy	13700.00
0005432783895	15427	Economy	13700.00
0005432783914	15427	Economy	13700.00
0005435242694	15427	Economy	13700.00
0005432783925	15427	Economy	13700.00
0005435242630	15427	Economy	15100.00
0005432783902	15427	Economy	15100.00
0005432783893	15427	Economy	15100.00
0005432783905	15427	Economy	15100.00
0005432783888	15427	Economy	13700.00
0005432783936	15427	Economy	13700.00
0005432783917	15427	Economy	13700.00
0005432783906	15427	Economy	13700.00
0005432783911	15427	Economy	13700.00
0005432783920	15427	Economy	13700.00
0005432783897	15427	Economy	13700.00
0005432783898	15427	Economy	13700.00
0005432783919	15427	Economy	13700.00
0005432783901	15427	Economy	13700.00
0005435242587	15427	Economy	13700.00
0005435242760	15427	Economy	13700.00
0005432783930	15427	Economy	13700.00
0005435242786	15427	Economy	13700.00
0005435242588	15427	Economy	13700.00
0005435242657	15427	Economy	13700.00
0005435242722	15427	Economy	13700.00
0005432783904	15427	Economy	13700.00
0005432783909	15427	Economy	13700.00
0005435242555	15427	Economy	13700.00
0005432783928	15427	Economy	13700.00
0005432783899	15427	Economy	13700.00
0005432783927	15427	Economy	13700.00
0005432783934	15427	Economy	13700.00
0005432783892	15427	Economy	13700.00
0005432783926	15427	Economy	13700.00
0005432783889	15427	Economy	13700.00
0005432783900	15427	Economy	13700.00
0005432783885	15427	Economy	13700.00
0005432783908	15427	Economy	13700.00
0005432783929	15427	Economy	13700.00
0005432783924	15427	Economy	13700.00
0005432783896	15427	Economy	13700.00
0005432783886	15427	Economy	13700.00
0005432783916	15427	Economy	13700.00
0005432783918	15427	Economy	13700.00
0005432783931	15427	Economy	13700.00
0005435242673	15427	Economy	13700.00
0005432783937	15427	Economy	13700.00
0005435242671	15427	Economy	13700.00
0005435242785	15427	Economy	13700.00
0005435242670	15427	Economy	13700.00
0005435242632	15427	Economy	13700.00
0005432783922	15427	Economy	13700.00
0005432783890	15427	Economy	13700.00
0005435242612	15427	Economy	13700.00
0005435242663	15427	Economy	13700.00
0005432783923	15427	Economy	13700.00
0005435242611	15427	Economy	13700.00
0005432783907	15427	Economy	13700.00
0005432783887	15427	Economy	13700.00
0005435242724	15427	Economy	13700.00
0005432783933	15427	Economy	13700.00
0005432783915	15427	Economy	13700.00
0005432783894	15427	Economy	13700.00
0005432783939	15427	Economy	13700.00
0005432783891	15427	Economy	13700.00
0005434878041	10075	Business	49700.00
0005434878004	10075	Business	49700.00
0005434877589	10075	Business	49700.00
0005434877744	10075	Business	49700.00
0005434877252	10075	Business	49700.00
0005434910120	10075	Business	49700.00
0005434877312	10075	Business	49700.00
0005434878172	10075	Business	49700.00
0005434877824	10075	Business	49700.00
0005434877679	10075	Business	49700.00
0005434877289	10075	Business	49700.00
0005434877921	10075	Business	49700.00
0005434877559	10075	Business	49700.00
0005434877804	10075	Business	49700.00
0005434877680	10075	Business	49700.00
0005434877816	10075	Business	49700.00
0005434878194	10075	Business	49700.00
0005434877863	10075	Business	49700.00
0005434877756	10075	Business	49700.00
0005434877892	10075	Business	49700.00
0005434877843	10075	Economy	16600.00
0005434877988	10075	Economy	16600.00
0005434878005	10075	Economy	16600.00
0005434910119	10075	Economy	16600.00
0005434877526	10075	Economy	16600.00
0005434877857	10075	Economy	16600.00
0005434877152	10075	Economy	16600.00
0005434877605	10075	Economy	16600.00
0005434877742	10075	Economy	16600.00
0005434877249	10075	Economy	16600.00
0005434877856	10075	Economy	16600.00
0005434877789	10075	Economy	16600.00
0005434877153	10075	Economy	16600.00
0005434877790	10075	Economy	18200.00
0005434877253	10075	Economy	18200.00
0005434877796	10075	Economy	18200.00
0005434877567	10075	Economy	16600.00
0005434877737	10075	Economy	18200.00
0005434878051	10075	Economy	16600.00
0005434877541	10075	Economy	16600.00
0005434878068	10075	Economy	16600.00
0005434877773	10075	Economy	16600.00
0005434877748	10075	Economy	16600.00
0005434877465	10075	Economy	16600.00
0005434877974	10075	Economy	16600.00
0005434877783	10075	Economy	16600.00
0005434877557	10075	Economy	16600.00
0005434877864	10075	Economy	16600.00
0005434877371	10075	Economy	16600.00
0005434877525	10075	Economy	16600.00
0005434877678	10075	Economy	16600.00
0005434877989	10075	Economy	16600.00
0005434877650	10075	Economy	16600.00
0005434877735	10075	Economy	16600.00
0005434877604	10075	Economy	16600.00
0005434877648	10075	Economy	16600.00
0005434877749	10075	Economy	16600.00
0005434877372	10075	Economy	16600.00
0005434877758	10075	Economy	16600.00
0005434878205	10075	Economy	16600.00
0005434877886	10075	Economy	16600.00
0005434877844	10075	Economy	16600.00
0005434877759	10075	Economy	16600.00
0005434877659	10075	Economy	16600.00
0005434877858	10075	Economy	16600.00
0005434877757	10075	Economy	16600.00
0005434877936	10075	Economy	16600.00
0005434877725	10075	Economy	16600.00
0005434877450	10075	Economy	16600.00
0005434877660	10075	Economy	16600.00
0005434877937	10075	Economy	16600.00
0005434877893	10075	Economy	16600.00
0005434877392	10075	Economy	16600.00
0005434877845	10075	Economy	16600.00
0005434878178	10075	Economy	16600.00
0005434877228	10075	Economy	16600.00
0005434877624	10075	Economy	16600.00
0005434877860	10075	Economy	16600.00
0005434878033	10075	Economy	16600.00
0005434877658	10075	Economy	16600.00
0005434877649	10075	Economy	16600.00
0005434877781	10075	Economy	16600.00
0005434878021	10075	Economy	16600.00
0005434877990	10075	Economy	16600.00
0005434877651	10075	Economy	16600.00
0005434877350	10075	Economy	16600.00
0005434877464	10075	Economy	16600.00
0005434877723	10075	Economy	16600.00
0005434877647	10075	Economy	16600.00
0005434877865	10075	Economy	16600.00
0005434877634	10075	Economy	16600.00
0005434877717	10075	Economy	16600.00
0005434877453	10075	Economy	16600.00
0005434877670	10075	Economy	16600.00
0005434877736	10075	Economy	16600.00
0005434877922	10075	Economy	16600.00
0005434877760	10075	Economy	16600.00
0005434877797	10075	Economy	16600.00
0005434877772	10075	Economy	16600.00
0005434877540	10075	Economy	16600.00
0005434877794	10075	Economy	16600.00
0005434877409	10075	Economy	16600.00
0005434877641	10075	Economy	16600.00
0005434877975	10075	Economy	16600.00
0005434878107	10075	Economy	16600.00
0005434877452	10075	Economy	16600.00
0005434878022	10075	Economy	16600.00
0005434877642	10075	Economy	16600.00
0005434877581	10075	Economy	16600.00
0005434877823	10075	Economy	16600.00
0005434877810	10075	Economy	16600.00
0005434877791	10075	Economy	16600.00
0005434877558	10075	Economy	16600.00
0005434758878	10075	Economy	16600.00
0005434877486	10075	Economy	16600.00
0005434877743	10075	Economy	16600.00
0005434878572	14613	Business	49700.00
0005434910101	14613	Business	49700.00
0005434878570	14613	Business	49700.00
0005434878532	14613	Business	49700.00
0005434878553	14613	Business	49700.00
0005434878503	14613	Business	49700.00
0005434878564	14613	Business	49700.00
0005435913891	14613	Business	49700.00
0005434878573	14613	Business	49700.00
0005434878501	14613	Business	49700.00
0005434878523	14613	Business	49700.00
0005434878488	14613	Business	49700.00
0005434878504	14613	Business	49700.00
0005435913892	14613	Business	49700.00
0005434878567	14613	Business	49700.00
0005434878529	14613	Business	49700.00
0005435913911	14613	Business	49700.00
0005434878568	14613	Business	49700.00
0005434878530	14613	Economy	16600.00
0005434878549	14613	Economy	16600.00
0005434878537	14613	Economy	16600.00
0005434878559	14613	Economy	16600.00
0005434878494	14613	Economy	16600.00
0005434878527	14613	Economy	16600.00
0005434878563	14613	Economy	16600.00
0005434878506	14613	Economy	16600.00
0005434878498	14613	Economy	16600.00
0005434910099	14613	Economy	16600.00
0005435913868	14613	Economy	16600.00
0005434878542	14613	Economy	16600.00
0005435913910	14613	Economy	16600.00
0005434878533	14613	Economy	18200.00
0005434878576	14613	Economy	18200.00
0005434878484	14613	Economy	18200.00
0005434878560	14613	Economy	16600.00
0005434878552	14613	Economy	16600.00
0005434878487	14613	Economy	16600.00
0005435913898	14613	Economy	16600.00
0005434878489	14613	Economy	16600.00
0005434878546	14613	Economy	16600.00
0005434878524	14613	Economy	16600.00
0005434878565	14613	Economy	16600.00
0005434878521	14613	Economy	16600.00
0005434878547	14613	Economy	16600.00
0005434878495	14613	Economy	16600.00
0005434878557	14613	Economy	16600.00
0005434878562	14613	Economy	16600.00
0005434878536	14613	Economy	16600.00
0005435913897	14613	Economy	16600.00
0005434878538	14613	Economy	16600.00
0005434878548	14613	Economy	16600.00
0005434878499	14613	Economy	16600.00
0005434878550	14613	Economy	16600.00
0005434878574	14613	Economy	16600.00
0005434878522	14613	Economy	16600.00
0005434878502	14613	Economy	16600.00
0005434878561	14613	Economy	16600.00
0005434878493	14613	Economy	16600.00
0005434878541	14613	Economy	16600.00
0005434878485	14613	Economy	16600.00
0005434878520	14613	Economy	16600.00
0005434878544	14613	Economy	16600.00
0005434878569	14613	Economy	16600.00
0005434878492	14613	Economy	16600.00
0005434878551	14613	Economy	16600.00
0005434878571	14613	Economy	16600.00
0005434878526	14613	Economy	16600.00
0005434878514	14613	Economy	16600.00
0005434878566	14613	Economy	16600.00
0005434878545	14613	Economy	16600.00
0005434878510	14613	Economy	16600.00
0005434878555	14613	Economy	16600.00
0005434878496	14613	Economy	16600.00
0005434878577	14613	Economy	16600.00
0005434878508	14613	Economy	16600.00
0005434878535	14613	Economy	16600.00
0005434878483	14613	Economy	16600.00
0005434878554	14613	Economy	16600.00
0005434878519	14613	Economy	16600.00
0005434878516	14613	Economy	16600.00
0005434878525	14613	Economy	16600.00
0005434878486	14613	Economy	16600.00
0005434758900	14613	Economy	16600.00
0005434878578	14613	Economy	16600.00
0005434878505	14613	Economy	16600.00
0005434878507	14613	Economy	16600.00
0005434878556	14613	Economy	16600.00
0005434878517	14613	Economy	16600.00
0005434878543	14613	Economy	16600.00
0005434878511	14613	Economy	16600.00
0005435913906	14613	Economy	16600.00
0005434758901	14613	Economy	16600.00
0005434878490	14613	Economy	16600.00
0005434878518	14613	Economy	16600.00
0005434878558	14613	Economy	16600.00
0005434878515	14613	Economy	16600.00
0005434878500	14613	Economy	16600.00
0005434878528	14613	Economy	16600.00
0005434878512	14613	Economy	16600.00
0005434878531	14613	Economy	16600.00
0005434878509	14613	Economy	16600.00
0005434878539	14613	Economy	16600.00
0005434878513	14613	Economy	16600.00
0005434878491	14613	Economy	16600.00
0005434878540	14613	Economy	16600.00
0005434910100	14613	Economy	16600.00
0005434878497	14613	Economy	16600.00
0005434878575	14613	Economy	16600.00
0005434878534	14613	Economy	16600.00
0005435660176	9227	Economy	22400.00
0005435660174	9227	Economy	20300.00
0005435660169	9227	Economy	20300.00
0005434251951	9227	Economy	20300.00
0005435660170	9227	Economy	20300.00
0005435660173	9227	Economy	20300.00
0005435660175	9227	Economy	20300.00
0005434251885	9227	Economy	20300.00
0005434251922	9227	Economy	20300.00
0005434251949	9227	Economy	20300.00
0005434251912	9227	Economy	20300.00
0005434251929	9227	Economy	20300.00
0005435660172	9227	Economy	20300.00
0005434251869	9227	Economy	20300.00
0005435660177	9227	Economy	20300.00
0005434251950	9227	Economy	20300.00
0005435660178	9227	Economy	20300.00
0005434251884	9227	Economy	20300.00
0005435660168	9227	Economy	20300.00
0005434251921	9227	Economy	20300.00
0005435660171	9227	Economy	20300.00
0005434251898	9227	Economy	20300.00
0005435660031	24680	Economy	22400.00
0005434251996	24680	Economy	22400.00
0005434251994	24680	Economy	22400.00
0005435660090	24680	Economy	22400.00
0005435660030	24680	Economy	20300.00
0005434251997	24680	Economy	20300.00
0005435660057	24680	Economy	20300.00
0005435660056	24680	Economy	20300.00
0005435660058	24680	Economy	20300.00
0005435660029	24680	Economy	20300.00
0005435660092	24680	Economy	20300.00
0005434251998	24680	Economy	20300.00
0005434251995	24680	Economy	20300.00
0005435660089	24680	Economy	20300.00
0005435660088	24680	Economy	20300.00
0005435660091	24680	Economy	20300.00
0005434251992	24680	Economy	20300.00
0005434251993	24680	Economy	20300.00
0005434251999	24680	Economy	20300.00
0005434251991	24680	Economy	20300.00
0005434252000	24680	Economy	20300.00
0005433684426	2786	Business	33000.00
0005432966776	2786	Business	33000.00
0005432966728	2786	Business	33000.00
0005432966841	2786	Business	33000.00
0005433680688	2786	Business	33000.00
0005433680725	2786	Business	33000.00
0005433680695	2786	Business	33000.00
0005433680717	2786	Business	33000.00
0005433680690	2786	Economy	11000.00
0005432966848	2786	Economy	11000.00
0005433684425	2786	Economy	11000.00
0005433680723	2786	Economy	11000.00
0005433680691	2786	Economy	11000.00
0005433680720	2786	Economy	11000.00
0005433680733	2786	Economy	11000.00
0005432966808	2786	Economy	11000.00
0005433680718	2786	Economy	11000.00
0005432966842	2786	Economy	12100.00
0005433680701	2786	Economy	12100.00
0005432222800	2786	Economy	12100.00
0005433684424	2786	Economy	12100.00
0005433680694	2786	Economy	12100.00
0005433680714	2786	Economy	11000.00
0005432966871	2786	Economy	11000.00
0005433680692	2786	Economy	11000.00
0005433680705	2786	Economy	11000.00
0005433680724	2786	Economy	11000.00
0005433680687	2786	Economy	11000.00
0005433680719	2786	Economy	11000.00
0005433680707	2786	Economy	11000.00
0005433680689	2786	Economy	11000.00
0005433680709	2786	Economy	11000.00
0005433680728	2786	Economy	11000.00
0005432966786	2786	Economy	11000.00
0005433680712	2786	Economy	11000.00
0005433680716	2786	Economy	11000.00
0005433680700	2786	Economy	11000.00
0005433680708	2786	Economy	11000.00
0005432222799	2786	Economy	11000.00
0005433680686	2786	Economy	11000.00
0005433680731	2786	Economy	11000.00
0005432966865	2786	Economy	11000.00
0005433680703	2786	Economy	11000.00
0005433680727	2786	Economy	11000.00
0005433680706	2786	Economy	11000.00
0005432966815	2786	Economy	11000.00
0005432966727	2786	Economy	11000.00
0005433680713	2786	Economy	11000.00
0005432966798	2786	Economy	11000.00
0005432222797	2786	Economy	11000.00
0005432966765	2786	Economy	11000.00
0005433680715	2786	Economy	11000.00
0005433680699	2786	Economy	11000.00
0005433680722	2786	Economy	11000.00
0005432966793	2786	Economy	11000.00
0005433680704	2786	Economy	11000.00
0005433680730	2786	Economy	11000.00
0005432966864	2786	Economy	11000.00
0005432966650	2786	Economy	11000.00
0005433680696	2786	Economy	11000.00
0005432966730	2786	Economy	11000.00
0005433680702	2786	Economy	11000.00
0005433680698	2786	Economy	11000.00
0005433680732	2786	Economy	11000.00
0005432966816	2786	Economy	11000.00
0005433680729	2786	Economy	11000.00
0005432966830	2786	Economy	11000.00
0005433680693	2786	Economy	11000.00
0005433680711	2786	Economy	11000.00
0005432222798	2786	Economy	11000.00
0005433680710	2786	Economy	11000.00
0005432222796	2786	Economy	11000.00
0005432966866	2786	Economy	11000.00
0005433680726	2786	Economy	11000.00
0005433680734	2786	Economy	11000.00
0005432966843	2786	Economy	11000.00
0005433680697	2786	Economy	11000.00
0005432966742	2786	Economy	11000.00
0005433680721	2786	Economy	11000.00
0005432967011	29195	Business	33000.00
0005433680185	29195	Business	33000.00
0005432967003	29195	Business	33000.00
0005433687694	29195	Business	33000.00
0005433680294	29195	Business	33000.00
0005433680186	29195	Business	33000.00
0005433680470	29195	Business	33000.00
0005433680392	29195	Business	33000.00
0005433690920	29195	Business	33000.00
0005433680408	29195	Business	33000.00
0005432967010	29195	Business	33000.00
0005433680187	29195	Economy	11000.00
0005432967014	29195	Economy	11000.00
0005433680351	29195	Economy	11000.00
0005433680225	29195	Economy	11000.00
0005433680409	29195	Economy	11000.00
0005433680238	29195	Economy	11000.00
0005433684411	29195	Economy	11000.00
0005433680352	29195	Economy	11000.00
0005433680391	29195	Economy	11000.00
0005433680237	29195	Economy	12100.00
0005432967015	29195	Economy	12100.00
0005433684412	29195	Economy	12100.00
0005433680355	29195	Economy	12100.00
0005433680476	29195	Economy	11000.00
0005432967026	29195	Economy	11000.00
0005433690913	29195	Economy	11000.00
0005433680317	29195	Economy	11000.00
0005432967006	29195	Economy	11000.00
0005433680371	29195	Economy	11000.00
0005432967016	29195	Economy	11000.00
0005432967013	29195	Economy	11000.00
0005432967020	29195	Economy	11000.00
0005433687695	29195	Economy	11000.00
0005433680295	29195	Economy	11000.00
0005432967022	29195	Economy	11000.00
0005432967019	29195	Economy	11000.00
0005432967025	29195	Economy	11000.00
0005432005222	29195	Economy	11000.00
0005432967002	29195	Economy	11000.00
0005432967004	29195	Economy	11000.00
0005433684413	29195	Economy	11000.00
0005433680304	29195	Economy	11000.00
0005432005221	29195	Economy	11000.00
0005433680356	29195	Economy	11000.00
0005433680309	29195	Economy	11000.00
0005433680466	29195	Economy	11000.00
0005433680357	29195	Economy	11000.00
0005433680423	29195	Economy	11000.00
0005433680517	29195	Economy	11000.00
0005433680440	29195	Economy	11000.00
0005433680052	29195	Economy	11000.00
0005432967007	29195	Economy	11000.00
0005433680559	29195	Economy	11000.00
0005433680419	29195	Economy	11000.00
0005432967027	29195	Economy	11000.00
0005433680308	29195	Economy	11000.00
0005433680456	29195	Economy	11000.00
0005433680379	29195	Economy	11000.00
0005433680354	29195	Economy	11000.00
0005433680422	29195	Economy	11000.00
0005433690919	29195	Economy	11000.00
0005432967017	29195	Economy	11000.00
0005432005223	29195	Economy	11000.00
0005433680372	29195	Economy	11000.00
0005432967023	29195	Economy	11000.00
0005433680358	29195	Economy	11000.00
0005433690921	29195	Economy	11000.00
0005432967024	29195	Economy	11000.00
0005433680289	29195	Economy	11000.00
0005433680293	29195	Economy	11000.00
0005433687696	29195	Economy	11000.00
0005433690912	29195	Economy	11000.00
0005433680229	29195	Economy	11000.00
0005432967008	29195	Economy	11000.00
0005433680533	29195	Economy	11000.00
0005433680405	29195	Economy	11000.00
0005433680457	29195	Economy	11000.00
0005433680420	29195	Economy	11000.00
0005432967018	29195	Economy	11000.00
0005432967005	29195	Economy	11000.00
0005432967009	29195	Economy	11000.00
0005433680520	29195	Economy	11000.00
0005433680368	29195	Economy	11000.00
0005432967021	29195	Economy	11000.00
0005432967012	29195	Economy	11000.00
0005433633885	9289	Business	132900.00
0005433633882	9289	Business	132900.00
0005433614839	9289	Business	132900.00
0005433577853	9289	Business	132900.00
0005432756859	9289	Business	132900.00
0005433614868	9289	Business	132900.00
0005433614831	9289	Business	132900.00
0005433614816	9289	Business	132900.00
0005434163549	9289	Business	132900.00
0005433614857	9289	Business	132900.00
0005434163581	9289	Business	132900.00
0005433614840	9289	Business	132900.00
0005433614850	9289	Business	132900.00
0005433614863	9289	Business	132900.00
0005433577851	9289	Business	132900.00
0005434269089	9289	Business	132900.00
0005433614837	9289	Business	132900.00
0005433633907	9289	Business	132900.00
0005433614872	9289	Business	132900.00
0005433614833	9289	Business	132900.00
0005433633888	9289	Business	132900.00
0005433614826	9289	Business	132900.00
0005433577839	9289	Business	132900.00
0005433614844	9289	Business	132900.00
0005433614875	9289	Business	132900.00
0005433614846	9289	Economy	48700.00
0005432755085	9289	Economy	48700.00
0005432145117	9289	Economy	48700.00
0005433614876	9289	Economy	48700.00
0005433614843	9289	Economy	48700.00
0005433577848	9289	Economy	48700.00
0005433633909	9289	Economy	44300.00
0005434272178	9289	Economy	44300.00
0005433614822	9289	Economy	44300.00
0005433614879	9289	Economy	44300.00
0005433614815	9289	Economy	44300.00
0005433633881	9289	Economy	44300.00
0005434272182	9289	Economy	44300.00
0005433614864	9289	Economy	44300.00
0005433614881	9289	Economy	44300.00
0005433633891	9289	Economy	44300.00
0005433614855	9289	Economy	44300.00
0005434163594	9289	Economy	44300.00
0005433577852	9289	Economy	44300.00
0005433614835	9289	Economy	44300.00
0005433614834	9289	Economy	44300.00
0005433614842	9289	Economy	44300.00
0005433614832	9289	Economy	44300.00
0005433577844	9289	Economy	44300.00
0005433577842	9289	Economy	44300.00
0005433633898	9289	Economy	44300.00
0005433614874	9289	Economy	44300.00
0005433614836	9289	Economy	44300.00
0005432755086	9289	Economy	44300.00
0005432145116	9289	Economy	44300.00
0005433614825	9289	Economy	44300.00
0005433614871	9289	Economy	44300.00
0005433614819	9289	Economy	44300.00
0005433614830	9289	Economy	44300.00
0005433633880	9289	Economy	44300.00
0005433633908	9289	Economy	44300.00
0005434163547	9289	Economy	44300.00
0005433614817	9289	Economy	44300.00
0005433614823	9289	Economy	44300.00
0005433614877	9289	Economy	44300.00
0005434269093	9289	Economy	44300.00
0005433614860	9289	Economy	44300.00
0005433614838	9289	Economy	44300.00
0005434163552	9289	Economy	44300.00
0005433633879	9289	Economy	44300.00
0005433614859	9289	Economy	44300.00
0005433614847	9289	Economy	44300.00
0005433633892	9289	Economy	44300.00
0005433614821	9289	Economy	44300.00
0005433633897	9289	Economy	44300.00
0005433614867	9289	Economy	44300.00
0005433633894	9289	Economy	44300.00
0005433614812	9289	Economy	44300.00
0005433633901	9289	Economy	44300.00
0005433614810	9289	Economy	44300.00
0005433577840	9289	Economy	44300.00
0005433633887	9289	Economy	44300.00
0005433614854	9289	Economy	44300.00
0005433614829	9289	Economy	48700.00
0005433577843	9289	Economy	48700.00
0005433633890	9289	Economy	48700.00
0005433633877	9289	Economy	48700.00
0005433633893	9289	Economy	44300.00
0005433614820	9289	Economy	48700.00
0005433614814	9289	Economy	44300.00
0005433614841	9289	Economy	44300.00
0005433614866	9289	Economy	48700.00
0005434272179	9289	Economy	44300.00
0005434163548	9289	Economy	44300.00
0005433614856	9289	Economy	44300.00
0005433633896	9289	Economy	44300.00
0005433614809	9289	Economy	44300.00
0005433633900	9289	Economy	44300.00
0005433633902	9289	Economy	44300.00
0005433614862	9289	Economy	44300.00
0005433614824	9289	Economy	44300.00
0005432756857	9289	Economy	44300.00
0005433577841	9289	Economy	44300.00
0005433633910	9289	Economy	44300.00
0005433614878	9289	Economy	44300.00
0005433633905	9289	Economy	44300.00
0005433614861	9289	Economy	44300.00
0005433633899	9289	Economy	44300.00
0005433614827	9289	Economy	44300.00
0005432756858	9289	Economy	44300.00
0005433633903	9289	Economy	44300.00
0005433614813	9289	Economy	44300.00
0005433633889	9289	Economy	44300.00
0005433614811	9289	Economy	44300.00
0005433577849	9289	Economy	44300.00
0005433577850	9289	Economy	44300.00
0005433633883	9289	Economy	44300.00
0005434153529	9289	Economy	44300.00
0005433614828	9289	Economy	44300.00
0005433614869	9289	Economy	44300.00
0005434163550	9289	Economy	44300.00
0005434153525	9289	Economy	44300.00
0005433577847	9289	Economy	44300.00
0005433614851	9289	Economy	44300.00
0005433614873	9289	Economy	44300.00
0005433614882	9289	Economy	44300.00
0005433614865	9289	Economy	44300.00
0005434163588	9289	Economy	44300.00
0005433577846	9289	Economy	44300.00
0005432756860	9289	Economy	44300.00
0005433633886	9289	Economy	44300.00
0005433614848	9289	Economy	44300.00
0005433614845	9289	Economy	44300.00
0005433614853	9289	Economy	44300.00
0005433577845	9289	Economy	44300.00
0005433633884	9289	Economy	44300.00
0005433614858	9289	Economy	44300.00
0005433614880	9289	Economy	44300.00
0005434163589	9289	Economy	44300.00
0005433614849	9289	Economy	44300.00
0005433614870	9289	Economy	44300.00
0005433614852	9289	Economy	44300.00
0005433633895	9289	Economy	44300.00
0005433614818	9289	Economy	44300.00
0005433633878	9289	Economy	44300.00
0005433633904	9289	Economy	44300.00
0005433633906	9289	Economy	44300.00
0005434272180	9289	Economy	44300.00
0005433577722	25246	Business	132900.00
0005433613843	25246	Business	132900.00
0005433613982	25246	Business	132900.00
0005433614163	25246	Business	132900.00
0005433614189	25246	Business	132900.00
0005433577783	25246	Business	132900.00
0005433614283	25246	Business	132900.00
0005433614320	25246	Business	132900.00
0005433614322	25246	Business	132900.00
0005433614193	25246	Business	132900.00
0005434272197	25246	Business	132900.00
0005433614239	25246	Business	132900.00
0005433633641	25246	Business	132900.00
0005433614218	25246	Business	132900.00
0005433577769	25246	Business	132900.00
0005434163640	25246	Business	132900.00
0005433577712	25246	Business	132900.00
0005433633735	25246	Business	132900.00
0005433614196	25246	Business	132900.00
0005433633599	25246	Business	132900.00
0005433614204	25246	Business	132900.00
0005433614092	25246	Business	132900.00
0005433614227	25246	Business	132900.00
0005433614051	25246	Business	132900.00
0005433614171	25246	Business	132900.00
0005433577711	25246	Economy	48700.00
0005433614254	25246	Economy	48700.00
0005433633726	25246	Economy	48700.00
0005433614219	25246	Economy	48700.00
0005433614511	25246	Economy	44300.00
0005433614282	25246	Economy	44300.00
0005433614395	25246	Economy	44300.00
0005433577639	25246	Economy	44300.00
0005433577622	25246	Economy	44300.00
0005433614194	25246	Economy	44300.00
0005433614417	25246	Economy	44300.00
0005433577770	25246	Economy	44300.00
0005433614050	25246	Economy	44300.00
0005433633456	25246	Economy	44300.00
0005433614089	25246	Economy	44300.00
0005433613949	25246	Economy	44300.00
0005433614155	25246	Economy	44300.00
0005433633610	25246	Economy	44300.00
0005433614284	25246	Economy	44300.00
0005433614195	25246	Economy	44300.00
0005433633595	25246	Economy	44300.00
0005433614418	25246	Economy	44300.00
0005433633578	25246	Economy	44300.00
0005433633425	25246	Economy	44300.00
0005433633424	25246	Economy	44300.00
0005433614266	25246	Economy	44300.00
0005433614040	25246	Economy	44300.00
0005433577638	25246	Economy	44300.00
0005433614546	25246	Economy	44300.00
0005433614149	25246	Economy	44300.00
0005434272196	25246	Economy	44300.00
0005433633558	25246	Economy	44300.00
0005434163638	25246	Economy	44300.00
0005433614088	25246	Economy	44300.00
0005433614470	25246	Economy	44300.00
0005433614439	25246	Economy	44300.00
0005433633623	25246	Economy	44300.00
0005433633600	25246	Economy	44300.00
0005433633497	25246	Economy	44300.00
0005433633540	25246	Economy	44300.00
0005434163643	25246	Economy	44300.00
0005433613983	25246	Economy	44300.00
0005433614522	25246	Economy	44300.00
0005433614662	25246	Economy	44300.00
0005433614531	25246	Economy	44300.00
0005433614147	25246	Economy	44300.00
0005433633589	25246	Economy	44300.00
0005433633704	25246	Economy	44300.00
0005433633836	25246	Economy	44300.00
0005433633559	25246	Economy	44300.00
0005433614359	25246	Economy	44300.00
0005433614074	25246	Economy	44300.00
0005433633496	25246	Economy	44300.00
0005433577782	25246	Economy	44300.00
0005434163645	25246	Economy	44300.00
0005433614520	25246	Economy	44300.00
0005433614249	25246	Economy	44300.00
0005433614103	25246	Economy	48700.00
0005433614039	25246	Economy	48700.00
0005433633590	25246	Economy	48700.00
0005433633418	25246	Economy	48700.00
0005433633740	25246	Economy	48700.00
0005433613948	25246	Economy	44300.00
0005433614276	25246	Economy	44300.00
0005433633609	25246	Economy	48700.00
0005433614265	25246	Economy	44300.00
0005434163646	25246	Economy	44300.00
0005433577721	25246	Economy	44300.00
0005433633736	25246	Economy	44300.00
0005433614049	25246	Economy	44300.00
0005433614341	25246	Economy	44300.00
0005433613992	25246	Economy	44300.00
0005433614121	25246	Economy	44300.00
0005433614245	25246	Economy	44300.00
0005433577689	25246	Economy	44300.00
0005433614240	25246	Economy	44300.00
0005434273080	25246	Economy	44300.00
0005433633621	25246	Economy	44300.00
0005434163644	25246	Economy	44300.00
0005434163639	25246	Economy	44300.00
0005433614407	25246	Economy	44300.00
0005433633457	25246	Economy	44300.00
0005433633567	25246	Economy	44300.00
0005433614268	25246	Economy	44300.00
0005433614310	25246	Economy	44300.00
0005434163642	25246	Economy	44300.00
0005433633548	25246	Economy	44300.00
0005433614119	25246	Economy	44300.00
0005433613923	25246	Economy	44300.00
0005433614321	25246	Economy	44300.00
0005433633579	25246	Economy	44300.00
0005433614235	25246	Economy	44300.00
0005433614215	25246	Economy	44300.00
0005433613993	25246	Economy	44300.00
0005433613775	25246	Economy	44300.00
0005433633493	25246	Economy	44300.00
0005433614340	25246	Economy	44300.00
0005433614302	25246	Economy	44300.00
0005434163641	25246	Economy	44300.00
0005433633527	25246	Economy	44300.00
0005433614122	25246	Economy	44300.00
0005433613750	25246	Economy	44300.00
0005433614530	25246	Economy	44300.00
0005433577747	25246	Economy	44300.00
0005433633560	25246	Economy	44300.00
0005433614150	25246	Economy	44300.00
0005433614209	25246	Economy	44300.00
0005433633538	25246	Economy	44300.00
0005434272195	25246	Economy	44300.00
0005433614469	25246	Economy	44300.00
0005434163647	25246	Economy	44300.00
0005433614200	25246	Economy	44300.00
0005433614521	25246	Economy	44300.00
0005433633664	25246	Economy	44300.00
0005433614120	25246	Economy	44300.00
0005433614008	25246	Economy	44300.00
0005433633601	25246	Economy	44300.00
0005433577757	25246	Economy	44300.00
0005433614165	25246	Economy	44300.00
0005433614222	25246	Economy	44300.00
0005432571303	4236	Business	193100.00
0005435947200	4236	Business	193100.00
0005435947140	4236	Business	193100.00
0005435947216	4236	Business	193100.00
0005435947138	4236	Business	193100.00
0005435947157	4236	Business	193100.00
0005432184959	4236	Business	193100.00
0005435947134	4236	Economy	70800.00
0005435856158	4236	Economy	70800.00
0005432184958	4236	Economy	64400.00
0005434271291	4236	Economy	64400.00
0005435947133	4236	Economy	64400.00
0005435947173	4236	Economy	64400.00
0005434271299	4236	Economy	64400.00
0005435947196	4236	Economy	64400.00
0005435854052	4236	Economy	64400.00
0005435856173	4236	Economy	64400.00
0005435787339	4236	Economy	64400.00
0005435947177	4236	Economy	64400.00
0005435787340	4236	Economy	64400.00
0005435854053	4236	Economy	64400.00
0005435947178	4236	Economy	64400.00
0005435947076	4236	Economy	64400.00
0005435947197	4236	Economy	64400.00
0005432571304	4236	Economy	64400.00
0005435787338	4236	Economy	64400.00
0005435947174	4236	Economy	64400.00
0005435854050	4236	Economy	70800.00
0005435947161	4236	Economy	64400.00
0005435947201	4236	Economy	64400.00
0005435947139	4236	Economy	64400.00
0005434271300	4236	Economy	64400.00
0005435947192	4236	Economy	64400.00
0005435947150	4236	Economy	64400.00
0005434271304	4236	Economy	64400.00
0005435947124	4236	Economy	64400.00
0005432184960	4236	Economy	64400.00
0005435854049	4236	Economy	64400.00
0005435947193	4236	Economy	64400.00
0005435854054	4236	Economy	64400.00
0005435947304	26582	Business	193100.00
0005435947296	26582	Business	193100.00
0005435856216	26582	Business	193100.00
0005435986709	26582	Business	193100.00
0005435947303	26582	Business	193100.00
0005435986714	26582	Business	193100.00
0005435986715	26582	Economy	70800.00
0005435947295	26582	Economy	64400.00
0005435947299	26582	Economy	64400.00
0005432571335	26582	Economy	64400.00
0005435947301	26582	Economy	64400.00
0005435787363	26582	Economy	64400.00
0005435947305	26582	Economy	64400.00
0005435947306	26582	Economy	64400.00
0005435947298	26582	Economy	64400.00
0005435856219	26582	Economy	64400.00
0005435947297	26582	Economy	64400.00
0005435787361	26582	Economy	64400.00
0005432571336	26582	Economy	64400.00
0005435947308	26582	Economy	64400.00
0005435986713	26582	Economy	64400.00
0005435856218	26582	Economy	64400.00
0005435787362	26582	Economy	64400.00
0005435787364	26582	Economy	70800.00
0005435947300	26582	Economy	70800.00
0005435986742	26582	Economy	64400.00
0005435986722	26582	Economy	64400.00
0005435986729	26582	Economy	64400.00
0005435986707	26582	Economy	64400.00
0005435947302	26582	Economy	64400.00
0005435856217	26582	Economy	64400.00
0005435986700	26582	Economy	64400.00
0005435986701	26582	Economy	64400.00
0005432571337	26582	Economy	64400.00
0005435986708	26582	Economy	64400.00
0005435947307	26582	Economy	64400.00
0005432571334	26582	Economy	64400.00
0005432948115	342	Business	21500.00
0005433569254	342	Business	21500.00
0005433569295	342	Business	21500.00
0005433569274	342	Business	21500.00
0005433569270	342	Business	21500.00
0005433569296	342	Business	21500.00
0005433569273	342	Business	21500.00
0005432948180	342	Business	21500.00
0005433569286	342	Business	21500.00
0005433569267	342	Business	21500.00
0005433569260	342	Business	21500.00
0005433569294	342	Business	21500.00
0005433074593	342	Business	21500.00
0005432948179	342	Business	21500.00
0005432948142	342	Business	21500.00
0005433569276	342	Business	21500.00
0005433569242	342	Business	21500.00
0005432238956	342	Business	21500.00
0005433569259	342	Business	21500.00
0005433569249	342	Business	21500.00
0005433074589	342	Business	21500.00
0005433569279	342	Business	21500.00
0005433074566	342	Business	21500.00
0005433569266	342	Business	21500.00
0005432948132	342	Economy	7900.00
0005433569299	342	Economy	7900.00
0005432948210	342	Economy	7900.00
0005433569278	342	Economy	7900.00
0005432238955	342	Economy	7900.00
0005433074501	342	Economy	7900.00
0005432948381	342	Economy	7200.00
0005432948126	342	Economy	7200.00
0005433074503	342	Economy	7200.00
0005433569244	342	Economy	7200.00
0005433569252	342	Economy	7200.00
0005433569246	342	Economy	7200.00
0005433074565	342	Economy	7200.00
0005432238958	342	Economy	7200.00
0005433074685	342	Economy	7200.00
0005433569262	342	Economy	7200.00
0005433074579	342	Economy	7200.00
0005433569275	342	Economy	7200.00
0005433569264	342	Economy	7200.00
0005433569263	342	Economy	7200.00
0005432238954	342	Economy	7200.00
0005433134121	342	Economy	7200.00
0005432948206	342	Economy	7200.00
0005432948309	342	Economy	7200.00
0005432948153	342	Economy	7200.00
0005433074404	342	Economy	7200.00
0005433074550	342	Economy	7200.00
0005432238957	342	Economy	7200.00
0005433569250	342	Economy	7200.00
0005433134123	342	Economy	7200.00
0005433569285	342	Economy	7200.00
0005433569283	342	Economy	7200.00
0005432948160	342	Economy	7200.00
0005433074594	342	Economy	7200.00
0005433569271	342	Economy	7200.00
0005432948175	342	Economy	7200.00
0005432948143	342	Economy	7200.00
0005433074462	342	Economy	7200.00
0005432948187	342	Economy	7200.00
0005433074650	342	Economy	7200.00
0005433569292	342	Economy	7200.00
0005433569268	342	Economy	7200.00
0005433074463	342	Economy	7200.00
0005433569289	342	Economy	7200.00
0005433074455	342	Economy	7200.00
0005433074595	342	Economy	7200.00
0005433569256	342	Economy	7200.00
0005432948161	342	Economy	7200.00
0005433074558	342	Economy	7200.00
0005433569243	342	Economy	7200.00
0005433569287	342	Economy	7200.00
0005432948053	342	Economy	7200.00
0005432948136	342	Economy	7200.00
0005433074502	342	Economy	7200.00
0005433569245	342	Economy	7200.00
0005432948162	342	Economy	7200.00
0005432948364	342	Economy	7200.00
0005432948223	342	Economy	7200.00
0005433074596	342	Economy	7900.00
0005433569293	342	Economy	7900.00
0005433569265	342	Economy	7200.00
0005432948313	342	Economy	7200.00
0005432948329	342	Economy	7200.00
0005433074557	342	Economy	7200.00
0005433074546	342	Economy	7900.00
0005432948176	342	Economy	7200.00
0005432948203	342	Economy	7200.00
0005433569269	342	Economy	7200.00
0005433569282	342	Economy	7200.00
0005433569255	342	Economy	7200.00
0005433074438	342	Economy	7200.00
0005432947996	342	Economy	7200.00
0005433074519	342	Economy	7200.00
0005432948057	342	Economy	7200.00
0005433134099	342	Economy	7200.00
0005432948247	342	Economy	7200.00
0005432948246	342	Economy	7200.00
0005432238953	342	Economy	7200.00
0005432948365	342	Economy	7200.00
0005433569253	342	Economy	7200.00
0005433569298	342	Economy	7200.00
0005432948192	342	Economy	7200.00
0005432948137	342	Economy	7200.00
0005433569284	342	Economy	7200.00
0005432948224	342	Economy	7200.00
0005433569288	342	Economy	7200.00
0005432948098	342	Economy	7200.00
0005432948218	342	Economy	7200.00
0005433569272	342	Economy	7200.00
0005433074461	342	Economy	7200.00
0005433569261	342	Economy	7200.00
0005433129240	342	Economy	7200.00
0005432948116	342	Economy	7200.00
0005433569251	342	Economy	7200.00
0005433569291	342	Economy	7200.00
0005433074684	342	Economy	7200.00
0005433129254	342	Economy	7200.00
0005432948308	342	Economy	7200.00
0005432948148	342	Economy	7200.00
0005432948163	342	Economy	7200.00
0005433569280	342	Economy	7200.00
0005433569258	342	Economy	7200.00
0005433569277	342	Economy	7200.00
0005432948207	342	Economy	7200.00
0005433569297	342	Economy	7200.00
0005432948298	342	Economy	7200.00
0005432948296	342	Economy	7200.00
0005433569290	342	Economy	7200.00
0005433129239	342	Economy	7200.00
0005433569257	342	Economy	7200.00
0005433074590	342	Economy	7200.00
0005433074586	342	Economy	7200.00
0005432948152	342	Economy	7200.00
0005432948242	342	Economy	7200.00
0005432948202	342	Economy	7200.00
0005432948193	342	Economy	7200.00
0005432948256	342	Economy	7200.00
0005433569248	342	Economy	7200.00
0005433074580	342	Economy	7200.00
0005432948297	342	Economy	7200.00
0005433569247	342	Economy	7200.00
0005433569281	342	Economy	7200.00
0005433568572	11618	Business	21500.00
0005433568359	11618	Business	21500.00
0005432948584	11618	Business	21500.00
0005433568525	11618	Business	21500.00
0005433568643	11618	Business	21500.00
0005433568672	11618	Business	21500.00
0005433568441	11618	Business	21500.00
0005432948567	11618	Business	21500.00
0005433568729	11618	Business	21500.00
0005433568422	11618	Business	21500.00
0005432948589	11618	Business	21500.00
0005433568554	11618	Business	21500.00
0005433568368	11618	Business	21500.00
0005433568713	11618	Business	21500.00
0005433568248	11618	Business	21500.00
0005432948562	11618	Business	21500.00
0005432948588	11618	Business	21500.00
0005433568712	11618	Business	21500.00
0005432948581	11618	Business	21500.00
0005432948586	11618	Business	21500.00
0005433568321	11618	Business	21500.00
0005433074806	11618	Business	21500.00
0005433134152	11618	Business	21500.00
0005432948597	11618	Economy	7900.00
0005432192330	11618	Economy	7900.00
0005432948574	11618	Economy	7900.00
0005433568508	11618	Economy	7900.00
0005433568579	11618	Economy	7900.00
0005433568663	11618	Economy	7200.00
0005432948582	11618	Economy	7200.00
0005433074787	11618	Economy	7200.00
0005432948577	11618	Economy	7200.00
0005433568593	11618	Economy	7200.00
0005432948561	11618	Economy	7200.00
0005433074793	11618	Economy	7200.00
0005432948596	11618	Economy	7200.00
0005432948572	11618	Economy	7200.00
0005433568439	11618	Economy	7200.00
0005432948570	11618	Economy	7200.00
0005433568526	11618	Economy	7200.00
0005433568560	11618	Economy	7200.00
0005433074786	11618	Economy	7200.00
0005432948587	11618	Economy	7200.00
0005433568580	11618	Economy	7200.00
0005432948590	11618	Economy	7200.00
0005433074797	11618	Economy	7200.00
0005433568723	11618	Economy	7200.00
0005433074783	11618	Economy	7200.00
0005433568614	11618	Economy	7200.00
0005433568571	11618	Economy	7200.00
0005433568690	11618	Economy	7200.00
0005433074788	11618	Economy	7200.00
0005433568615	11618	Economy	7200.00
0005433568471	11618	Economy	7200.00
0005433568354	11618	Economy	7200.00
0005433568598	11618	Economy	7200.00
0005433568602	11618	Economy	7200.00
0005432948563	11618	Economy	7200.00
0005433074798	11618	Economy	7200.00
0005432948578	11618	Economy	7200.00
0005433074791	11618	Economy	7200.00
0005433568756	11618	Economy	7200.00
0005432948560	11618	Economy	7200.00
0005432948557	11618	Economy	7200.00
0005433074792	11618	Economy	7200.00
0005433074796	11618	Economy	7200.00
0005433568594	11618	Economy	7200.00
0005433131724	11618	Economy	7200.00
0005432948583	11618	Economy	7200.00
0005433568695	11618	Economy	7200.00
0005433568755	11618	Economy	7200.00
0005432948558	11618	Economy	7200.00
0005433074804	11618	Economy	7200.00
0005433568740	11618	Economy	7200.00
0005432948594	11618	Economy	7200.00
0005432948568	11618	Economy	7200.00
0005432948580	11618	Economy	7900.00
0005432192329	11618	Economy	7900.00
0005433568595	11618	Economy	7900.00
0005433134151	11618	Economy	7900.00
0005433568507	11618	Economy	7200.00
0005433568681	11618	Economy	7200.00
0005433568573	11618	Economy	7200.00
0005433568440	11618	Economy	7200.00
0005433134153	11618	Economy	7900.00
0005432948559	11618	Economy	7200.00
0005432948556	11618	Economy	7200.00
0005432948575	11618	Economy	7200.00
0005433568686	11618	Economy	7200.00
0005433074785	11618	Economy	7200.00
0005433074805	11618	Economy	7200.00
0005433568773	11618	Economy	7200.00
0005432948566	11618	Economy	7200.00
0005433568609	11618	Economy	7200.00
0005433074795	11618	Economy	7200.00
0005433568757	11618	Economy	7200.00
0005433074807	11618	Economy	7200.00
0005433131723	11618	Economy	7200.00
0005433568524	11618	Economy	7200.00
0005433074782	11618	Economy	7200.00
0005433074789	11618	Economy	7200.00
0005433568637	11618	Economy	7200.00
0005433568715	11618	Economy	7200.00
0005433074808	11618	Economy	7200.00
0005433568662	11618	Economy	7200.00
0005433074794	11618	Economy	7200.00
0005432948592	11618	Economy	7200.00
0005433568477	11618	Economy	7200.00
0005432948579	11618	Economy	7200.00
0005433568785	11618	Economy	7200.00
0005433568601	11618	Economy	7200.00
0005432948595	11618	Economy	7200.00
0005433074784	11618	Economy	7200.00
0005432948565	11618	Economy	7200.00
0005433568786	11618	Economy	7200.00
0005432948569	11618	Economy	7200.00
0005432948564	11618	Economy	7200.00
0005433568597	11618	Economy	7200.00
0005433568623	11618	Economy	7200.00
0005432948585	11618	Economy	7200.00
0005433131720	11618	Economy	7200.00
0005433568754	11618	Economy	7200.00
0005433074799	11618	Economy	7200.00
0005433568472	11618	Economy	7200.00
0005433568671	11618	Economy	7200.00
0005432948576	11618	Economy	7200.00
0005433568527	11618	Economy	7200.00
0005433074803	11618	Economy	7200.00
0005432948571	11618	Economy	7200.00
0005433074801	11618	Economy	7200.00
0005433131722	11618	Economy	7200.00
0005432948573	11618	Economy	7200.00
0005433131721	11618	Economy	7200.00
0005433568324	11618	Economy	7200.00
0005433568724	11618	Economy	7200.00
0005433074802	11618	Economy	7200.00
0005432948593	11618	Economy	7200.00
0005433074800	11618	Economy	7200.00
0005433074790	11618	Economy	7200.00
0005432948591	11618	Economy	7200.00
0005433134154	11618	Economy	7200.00
0005433817482	9969	Economy	6300.00
0005433817483	9969	Economy	6300.00
0005433817481	9969	Economy	6300.00
0005434732961	9969	Economy	6300.00
0005434732971	9969	Economy	6300.00
0005434732962	9969	Economy	6300.00
0005434732963	9969	Economy	6300.00
0005433817484	9969	Economy	6300.00
0005433817441	13958	Economy	6300.00
0005433817443	13958	Economy	6300.00
0005434732990	13958	Economy	6300.00
0005434732992	13958	Economy	6300.00
0005434732993	13958	Economy	6300.00
0005434732991	13958	Economy	6300.00
0005432984916	2354	Business	184500.00
0005433754382	2354	Business	184500.00
0005432984958	2354	Business	184500.00
0005435982449	2354	Business	184500.00
0005432984987	2354	Business	184500.00
0005435982443	2354	Business	184500.00
0005433754424	2354	Business	184500.00
0005432655571	2354	Business	184500.00
0005432984970	2354	Business	184500.00
0005432984785	2354	Business	184500.00
0005433754427	2354	Business	184500.00
0005435982445	2354	Business	184500.00
0005432984956	2354	Business	184500.00
0005433434454	2354	Business	184500.00
0005435982482	2354	Business	184500.00
0005433434545	2354	Business	184500.00
0005433754428	2354	Business	184500.00
0005433434610	2354	Business	184500.00
0005432869497	2354	Business	184500.00
0005432984890	2354	Business	184500.00
0005435982469	2354	Business	184500.00
0005433434586	2354	Business	184500.00
0005433434508	2354	Business	184500.00
0005435982462	2354	Business	184500.00
0005435982470	2354	Business	184500.00
0005432869500	2354	Business	184500.00
0005432984999	2354	Business	184500.00
0005433764685	2354	Business	184500.00
0005433434546	2354	Business	184500.00
0005433434502	2354	Business	184500.00
0005433754383	2354	Economy	67700.00
0005433754410	2354	Economy	67700.00
0005433434414	2354	Economy	67700.00
0005435982447	2354	Economy	67700.00
0005433434430	2354	Economy	61500.00
0005435982455	2354	Economy	61500.00
0005434731142	2354	Economy	61500.00
0005432984883	2354	Economy	61500.00
0005435982446	2354	Economy	61500.00
0005432985058	2354	Economy	61500.00
0005432984927	2354	Economy	61500.00
0005433754392	2354	Economy	61500.00
0005432300281	2354	Economy	61500.00
0005432984771	2354	Economy	61500.00
0005433434521	2354	Economy	61500.00
0005432984881	2354	Economy	61500.00
0005432655578	2354	Economy	61500.00
0005435982467	2354	Economy	61500.00
0005435982452	2354	Economy	61500.00
0005432869496	2354	Economy	61500.00
0005433754426	2354	Economy	61500.00
0005433754396	2354	Economy	61500.00
0005433754380	2354	Economy	61500.00
0005432869495	2354	Economy	61500.00
0005435982457	2354	Economy	61500.00
0005433434583	2354	Economy	61500.00
0005433754385	2354	Economy	61500.00
0005433754422	2354	Economy	61500.00
0005433434493	2354	Economy	61500.00
0005432984882	2354	Economy	61500.00
0005435982461	2354	Economy	61500.00
0005432226074	2354	Economy	61500.00
0005432655575	2354	Economy	61500.00
0005432300283	2354	Economy	61500.00
0005435982484	2354	Economy	61500.00
0005432985046	2354	Economy	61500.00
0005432655577	2354	Economy	61500.00
0005433754414	2354	Economy	61500.00
0005433754413	2354	Economy	61500.00
0005432985057	2354	Economy	61500.00
0005433754374	2354	Economy	61500.00
0005433754409	2354	Economy	61500.00
0005432984843	2354	Economy	61500.00
0005433754398	2354	Economy	61500.00
0005434731136	2354	Economy	61500.00
0005432655581	2354	Economy	61500.00
0005433754404	2354	Economy	61500.00
0005433754407	2354	Economy	61500.00
0005433754389	2354	Economy	61500.00
0005432869492	2354	Economy	61500.00
0005435982473	2354	Economy	61500.00
0005432984853	2354	Economy	61500.00
0005433754378	2354	Economy	61500.00
0005433754401	2354	Economy	61500.00
0005432984969	2354	Economy	61500.00
0005432300282	2354	Economy	61500.00
0005433434571	2354	Economy	61500.00
0005435982453	2354	Economy	61500.00
0005433754391	2354	Economy	61500.00
0005435982450	2354	Economy	61500.00
0005433754402	2354	Economy	61500.00
0005433754399	2354	Economy	61500.00
0005435982475	2354	Economy	61500.00
0005432984776	2354	Economy	61500.00
0005433764686	2354	Economy	61500.00
0005433754423	2354	Economy	61500.00
0005432984946	2354	Economy	61500.00
0005433434507	2354	Economy	61500.00
0005435982451	2354	Economy	61500.00
0005433766652	2354	Economy	61500.00
0005433434535	2354	Economy	61500.00
0005433434544	2354	Economy	61500.00
0005433754394	2354	Economy	61500.00
0005435982444	2354	Economy	61500.00
0005433434494	2354	Economy	61500.00
0005433754388	2354	Economy	61500.00
0005433764687	2354	Economy	61500.00
0005432300284	2354	Economy	61500.00
0005435982474	2354	Economy	61500.00
0005433434453	2354	Economy	61500.00
0005434731135	2354	Economy	61500.00
0005433434639	2354	Economy	61500.00
0005435982479	2354	Economy	61500.00
0005433434431	2354	Economy	61500.00
0005432655574	2354	Economy	61500.00
0005435982458	2354	Economy	61500.00
0005435982480	2354	Economy	61500.00
0005434731141	2354	Economy	61500.00
0005433754415	2354	Economy	61500.00
0005432984858	2354	Economy	61500.00
0005432869499	2354	Economy	61500.00
0005433754379	2354	Economy	61500.00
0005432226075	2354	Economy	61500.00
0005432984770	2354	Economy	61500.00
0005433434517	2354	Economy	61500.00
0005433754406	2354	Economy	61500.00
0005433434534	2354	Economy	61500.00
0005432655582	2354	Economy	61500.00
0005432984986	2354	Economy	61500.00
0005433754417	2354	Economy	61500.00
0005432226079	2354	Economy	61500.00
0005432869456	2354	Economy	61500.00
0005432226076	2354	Economy	61500.00
0005432984874	2354	Economy	61500.00
0005435982477	2354	Economy	67700.00
0005433766650	2354	Economy	67700.00
0005432984841	2354	Economy	61500.00
0005435982472	2354	Economy	61500.00
0005432300279	2354	Economy	61500.00
0005432226078	2354	Economy	67700.00
0005432655580	2354	Economy	67700.00
0005433754408	2354	Economy	61500.00
0005433754384	2354	Economy	61500.00
0005435982465	2354	Economy	61500.00
0005433754381	2354	Economy	61500.00
0005432869483	2354	Economy	61500.00
0005432226077	2354	Economy	61500.00
0005435982463	2354	Economy	61500.00
0005432655572	2354	Economy	61500.00
0005433754419	2354	Economy	61500.00
0005433754387	2354	Economy	61500.00
0005433754420	2354	Economy	61500.00
0005433434448	2354	Economy	61500.00
0005433754386	2354	Economy	61500.00
0005433754425	2354	Economy	61500.00
0005432984788	2354	Economy	61500.00
0005433434503	2354	Economy	61500.00
0005433754395	2354	Economy	61500.00
0005435982459	2354	Economy	61500.00
0005435982464	2354	Economy	61500.00
0005433434569	2354	Economy	61500.00
0005432984769	2354	Economy	61500.00
0005432655579	2354	Economy	61500.00
0005435982471	2354	Economy	61500.00
0005432985020	2354	Economy	61500.00
0005433434516	2354	Economy	61500.00
0005432984936	2354	Economy	61500.00
0005435982468	2354	Economy	61500.00
0005432655576	2354	Economy	61500.00
0005433754375	2354	Economy	61500.00
0005433754429	2354	Economy	61500.00
0005432300280	2354	Economy	61500.00
0005433754373	2354	Economy	61500.00
0005434731147	2354	Economy	61500.00
0005433754416	2354	Economy	61500.00
0005433754397	2354	Economy	61500.00
0005433754372	2354	Economy	61500.00
0005433754377	2354	Economy	61500.00
0005433434570	2354	Economy	61500.00
0005433754405	2354	Economy	61500.00
0005435982466	2354	Economy	61500.00
0005433754418	2354	Economy	61500.00
0005432984943	2354	Economy	61500.00
0005432984829	2354	Economy	61500.00
0005432984918	2354	Economy	61500.00
0005433434611	2354	Economy	61500.00
0005433754393	2354	Economy	61500.00
0005432984926	2354	Economy	61500.00
0005435982481	2354	Economy	61500.00
0005432985045	2354	Economy	61500.00
0005432984840	2354	Economy	61500.00
0005435982454	2354	Economy	61500.00
0005433766653	2354	Economy	61500.00
0005433434609	2354	Economy	61500.00
0005432984925	2354	Economy	61500.00
0005433754390	2354	Economy	61500.00
0005435982456	2354	Economy	61500.00
0005435982448	2354	Economy	61500.00
0005433754411	2354	Economy	61500.00
0005433434631	2354	Economy	61500.00
0005433766651	2354	Economy	61500.00
0005433754403	2354	Economy	61500.00
0005432984944	2354	Economy	61500.00
0005433754376	2354	Economy	61500.00
0005433754400	2354	Economy	61500.00
0005433754412	2354	Economy	61500.00
0005432984873	2354	Economy	61500.00
0005433434522	2354	Economy	61500.00
0005432984839	2354	Economy	61500.00
0005434731130	2354	Economy	61500.00
0005435982483	2354	Economy	61500.00
0005433754421	2354	Economy	61500.00
0005432655573	2354	Economy	61500.00
0005435982478	2354	Economy	61500.00
0005435982460	2354	Economy	61500.00
0005432984900	2354	Economy	61500.00
0005435982476	2354	Economy	61500.00
0005432984957	2354	Economy	61500.00
0005435982043	26157	Business	184500.00
0005433753782	26157	Business	184500.00
0005433753691	26157	Business	184500.00
0005433754129	26157	Business	184500.00
0005433754017	26157	Business	184500.00
0005435981843	26157	Business	184500.00
0005433753860	26157	Business	184500.00
0005433434765	26157	Business	184500.00
0005432985189	26157	Business	184500.00
0005433753914	26157	Business	184500.00
0005433754094	26157	Business	184500.00
0005432985170	26157	Business	184500.00
0005433754108	26157	Business	184500.00
0005433753986	26157	Business	184500.00
0005433753833	26157	Business	184500.00
0005433753915	26157	Business	184500.00
0005435982154	26157	Business	184500.00
0005432655436	26157	Business	184500.00
0005432869543	26157	Business	184500.00
0005433766608	26157	Business	184500.00
0005435982080	26157	Business	184500.00
0005433753872	26157	Business	184500.00
0005435982152	26157	Business	184500.00
0005432985183	26157	Business	184500.00
0005433434767	26157	Business	184500.00
0005435981937	26157	Business	184500.00
0005433754010	26157	Business	184500.00
0005433434777	26157	Business	184500.00
0005433434757	26157	Economy	67700.00
0005432985180	26157	Economy	67700.00
0005432985193	26157	Economy	67700.00
0005432985186	26157	Economy	67700.00
0005432985177	26157	Economy	61500.00
0005433754064	26157	Economy	61500.00
0005435982066	26157	Economy	61500.00
0005433753751	26157	Economy	61500.00
0005433753667	26157	Economy	61500.00
0005432985182	26157	Economy	61500.00
0005433753524	26157	Economy	61500.00
0005433753992	26157	Economy	61500.00
0005432985178	26157	Economy	61500.00
0005432985179	26157	Economy	61500.00
0005435981890	26157	Economy	61500.00
0005432655440	26157	Economy	61500.00
0005433753840	26157	Economy	61500.00
0005433754027	26157	Economy	61500.00
0005432985167	26157	Economy	61500.00
0005432051139	26157	Economy	61500.00
0005433753647	26157	Economy	61500.00
0005433434769	26157	Economy	61500.00
0005433434781	26157	Economy	61500.00
0005432985175	26157	Economy	61500.00
0005433434756	26157	Economy	61500.00
0005433753812	26157	Economy	61500.00
0005434731186	26157	Economy	61500.00
0005434731185	26157	Economy	61500.00
0005435982081	26157	Economy	61500.00
0005433434772	26157	Economy	61500.00
0005435982077	26157	Economy	61500.00
0005433754015	26157	Economy	61500.00
0005435982102	26157	Economy	61500.00
0005432655441	26157	Economy	61500.00
0005432985188	26157	Economy	61500.00
0005433753888	26157	Economy	61500.00
0005432985185	26157	Economy	61500.00
0005433434758	26157	Economy	61500.00
0005432985194	26157	Economy	61500.00
0005432985171	26157	Economy	61500.00
0005433753906	26157	Economy	61500.00
0005433753950	26157	Economy	61500.00
0005433766626	26157	Economy	61500.00
0005435982036	26157	Economy	61500.00
0005433753954	26157	Economy	61500.00
0005432655424	26157	Economy	61500.00
0005435982020	26157	Economy	61500.00
0005432985195	26157	Economy	61500.00
0005433753692	26157	Economy	61500.00
0005435982074	26157	Economy	61500.00
0005432051137	26157	Economy	61500.00
0005432985181	26157	Economy	61500.00
0005432655423	26157	Economy	61500.00
0005433753870	26157	Economy	61500.00
0005432655425	26157	Economy	61500.00
0005433754043	26157	Economy	61500.00
0005433753578	26157	Economy	61500.00
0005433753926	26157	Economy	61500.00
0005433753878	26157	Economy	61500.00
0005433753873	26157	Economy	61500.00
0005433753752	26157	Economy	61500.00
0005435982105	26157	Economy	61500.00
0005433753686	26157	Economy	61500.00
0005433434762	26157	Economy	61500.00
0005433754014	26157	Economy	61500.00
0005433753685	26157	Economy	61500.00
0005432869545	26157	Economy	61500.00
0005435982044	26157	Economy	61500.00
0005432869544	26157	Economy	61500.00
0005435982054	26157	Economy	61500.00
0005433766627	26157	Economy	61500.00
0005433753802	26157	Economy	61500.00
0005435981842	26157	Economy	61500.00
0005433434763	26157	Economy	61500.00
0005433434778	26157	Economy	61500.00
0005433434782	26157	Economy	61500.00
0005435981927	26157	Economy	61500.00
0005433434764	26157	Economy	61500.00
0005432869541	26157	Economy	61500.00
0005435982051	26157	Economy	61500.00
0005433754095	26157	Economy	61500.00
0005432655412	26157	Economy	61500.00
0005432985191	26157	Economy	61500.00
0005432985184	26157	Economy	61500.00
0005432985172	26157	Economy	61500.00
0005435981963	26157	Economy	61500.00
0005433753882	26157	Economy	61500.00
0005433434779	26157	Economy	61500.00
0005435981901	26157	Economy	61500.00
0005433753896	26157	Economy	61500.00
0005433434780	26157	Economy	61500.00
0005433753883	26157	Economy	61500.00
0005433753799	26157	Economy	61500.00
0005433434783	26157	Economy	61500.00
0005435981844	26157	Economy	61500.00
0005433753869	26157	Economy	67700.00
0005435981990	26157	Economy	67700.00
0005433753895	26157	Economy	61500.00
0005433434768	26157	Economy	61500.00
0005435982117	26157	Economy	61500.00
0005433434770	26157	Economy	67700.00
0005433434766	26157	Economy	67700.00
0005432655449	26157	Economy	61500.00
0005435982164	26157	Economy	61500.00
0005433753969	26157	Economy	61500.00
0005433766607	26157	Economy	61500.00
0005433753811	26157	Economy	61500.00
0005433753781	26157	Economy	61500.00
0005433753681	26157	Economy	61500.00
0005432049474	26157	Economy	61500.00
0005433754068	26157	Economy	61500.00
0005432985197	26157	Economy	61500.00
0005435982104	26157	Economy	61500.00
0005432985173	26157	Economy	61500.00
0005432985187	26157	Economy	61500.00
0005433434771	26157	Economy	61500.00
0005433753955	26157	Economy	61500.00
0005432985176	26157	Economy	61500.00
0005432985169	26157	Economy	61500.00
0005435982041	26157	Economy	61500.00
0005432985196	26157	Economy	61500.00
0005433753957	26157	Economy	61500.00
0005435982067	26157	Economy	61500.00
0005432655439	26157	Economy	61500.00
0005433434761	26157	Economy	61500.00
0005433753648	26157	Economy	61500.00
0005435982064	26157	Economy	61500.00
0005435982179	26157	Economy	61500.00
0005435982103	26157	Economy	61500.00
0005435982042	26157	Economy	61500.00
0005435981928	26157	Economy	61500.00
0005433753871	26157	Economy	61500.00
0005432985192	26157	Economy	61500.00
0005433434759	26157	Economy	61500.00
0005433766622	26157	Economy	61500.00
0005435982086	26157	Economy	61500.00
0005433434775	26157	Economy	61500.00
0005435982035	26157	Economy	61500.00
0005433754121	26157	Economy	61500.00
0005432655511	26157	Economy	61500.00
0005433434773	26157	Economy	61500.00
0005432985190	26157	Economy	61500.00
0005435982027	26157	Economy	61500.00
0005435981848	26157	Economy	61500.00
0005433753838	26157	Economy	61500.00
0005435981929	26157	Economy	61500.00
0005433764657	26157	Economy	61500.00
0005432655468	26157	Economy	61500.00
0005432985166	26157	Economy	61500.00
0005432049475	26157	Economy	61500.00
0005433754093	26157	Economy	61500.00
0005433753913	26157	Economy	61500.00
0005432985168	26157	Economy	61500.00
0005433434760	26157	Economy	61500.00
0005433753968	26157	Economy	61500.00
0005434731184	26157	Economy	61500.00
0005433754081	26157	Economy	61500.00
0005432985174	26157	Economy	61500.00
0005433753834	26157	Economy	61500.00
0005435981889	26157	Economy	61500.00
0005433753998	26157	Economy	61500.00
0005433753995	26157	Economy	61500.00
0005435981891	26157	Economy	61500.00
0005433753646	26157	Economy	61500.00
0005433766621	26157	Economy	61500.00
0005433754069	26157	Economy	61500.00
0005435982001	26157	Economy	61500.00
0005435981892	26157	Economy	61500.00
0005433766606	26157	Economy	61500.00
0005432049476	26157	Economy	61500.00
0005433434774	26157	Economy	61500.00
0005432051138	26157	Economy	61500.00
0005433753916	26157	Economy	61500.00
0005432985165	26157	Economy	61500.00
0005433753912	26157	Economy	61500.00
0005433764656	26157	Economy	61500.00
0005432869542	26157	Economy	61500.00
0005433434776	26157	Economy	61500.00
0005435981940	26157	Economy	61500.00
0005435981962	26157	Economy	61500.00
0005433151175	1514	Business	38900.00
0005434374803	1514	Business	38900.00
0005433151259	1514	Business	38900.00
0005434374810	1514	Business	38900.00
0005433151304	1514	Business	38900.00
0005434374799	1514	Business	38900.00
0005433764664	1514	Business	38900.00
0005434374787	1514	Economy	13000.00
0005432267918	1514	Economy	13000.00
0005433151186	1514	Economy	13000.00
0005433460444	1514	Economy	13000.00
0005434374773	1514	Economy	13000.00
0005434374802	1514	Economy	13000.00
0005434374804	1514	Economy	13000.00
0005434374805	1514	Economy	13000.00
0005434374767	1514	Economy	13000.00
0005434374796	1514	Economy	13000.00
0005433931447	1514	Economy	13000.00
0005434374809	1514	Economy	13000.00
0005434374774	1514	Economy	13000.00
0005433151302	1514	Economy	13000.00
0005434374770	1514	Economy	13000.00
0005434374772	1514	Economy	13000.00
0005434374776	1514	Economy	13000.00
0005433151347	1514	Economy	13000.00
0005434374760	1514	Economy	13000.00
0005433151270	1514	Economy	13000.00
0005433461595	1514	Economy	13000.00
0005433151213	1514	Economy	13000.00
0005434374782	1514	Economy	13000.00
0005433151249	1514	Economy	13000.00
0005433151339	1514	Economy	13000.00
0005434374800	1514	Economy	13000.00
0005433151076	1514	Economy	13000.00
0005434374771	1514	Economy	13000.00
0005433151308	1514	Economy	13000.00
0005433151235	1514	Economy	13000.00
0005434374759	1514	Economy	13000.00
0005434374775	1514	Economy	13000.00
0005434374806	1514	Economy	13000.00
0005434374761	1514	Economy	13000.00
0005433151180	1514	Economy	13000.00
0005433151239	1514	Economy	14300.00
0005433151323	1514	Economy	14300.00
0005434374764	1514	Economy	14300.00
0005434374783	1514	Economy	14300.00
0005434374794	1514	Economy	14300.00
0005433151333	1514	Economy	13000.00
0005433151340	1514	Economy	14300.00
0005433764662	1514	Economy	13000.00
0005433151075	1514	Economy	13000.00
0005433151260	1514	Economy	13000.00
0005434374762	1514	Economy	13000.00
0005433151040	1514	Economy	13000.00
0005434374789	1514	Economy	13000.00
0005433931446	1514	Economy	13000.00
0005434374792	1514	Economy	13000.00
0005434374793	1514	Economy	13000.00
0005434374808	1514	Economy	13000.00
0005433151250	1514	Economy	13000.00
0005433151271	1514	Economy	13000.00
0005434374811	1514	Economy	13000.00
0005433151218	1514	Economy	13000.00
0005433151257	1514	Economy	13000.00
0005433461594	1514	Economy	13000.00
0005433151334	1514	Economy	13000.00
0005433151150	1514	Economy	13000.00
0005434374786	1514	Economy	13000.00
0005433151217	1514	Economy	13000.00
0005433151184	1514	Economy	13000.00
0005433151307	1514	Economy	13000.00
0005432267915	1514	Economy	13000.00
0005432267914	1514	Economy	13000.00
0005434374781	1514	Economy	13000.00
0005433151273	1514	Economy	13000.00
0005434374795	1514	Economy	13000.00
0005433931449	1514	Economy	13000.00
0005434374788	1514	Economy	13000.00
0005433151272	1514	Economy	13000.00
0005434374777	1514	Economy	13000.00
0005434374778	1514	Economy	13000.00
0005434374791	1514	Economy	13000.00
0005434374807	1514	Economy	13000.00
0005433461596	1514	Economy	13000.00
0005433151303	1514	Economy	13000.00
0005434374784	1514	Economy	13000.00
0005432267916	1514	Economy	13000.00
0005434374780	1514	Economy	13000.00
0005434374765	1514	Economy	13000.00
0005433151183	1514	Economy	13000.00
0005433460443	1514	Economy	13000.00
0005432267919	1514	Economy	13000.00
0005432267917	1514	Economy	13000.00
0005434374769	1514	Economy	13000.00
0005434374779	1514	Economy	13000.00
0005433151348	1514	Economy	13000.00
0005434374801	1514	Economy	13000.00
0005434374763	1514	Economy	13000.00
0005433931448	1514	Economy	13000.00
0005434374797	1514	Economy	13000.00
0005434374798	1514	Economy	13000.00
0005434374766	1514	Economy	13000.00
0005434374785	1514	Economy	13000.00
0005433931445	1514	Economy	13000.00
0005434374790	1514	Economy	13000.00
0005434374768	1514	Economy	13000.00
0005434374377	20101	Business	38900.00
0005434374332	20101	Business	38900.00
0005434374365	20101	Business	38900.00
0005433151526	20101	Business	38900.00
0005434374353	20101	Business	38900.00
0005433151508	20101	Business	38900.00
0005434029664	20101	Business	38900.00
0005434374459	20101	Business	38900.00
0005434374364	20101	Business	38900.00
0005434374452	20101	Business	38900.00
0005433151503	20101	Economy	13000.00
0005434374487	20101	Economy	13000.00
0005434374548	20101	Economy	13000.00
0005434374426	20101	Economy	13000.00
0005433764687	20101	Economy	13000.00
0005434374379	20101	Economy	13000.00
0005433151523	20101	Economy	13000.00
0005434374382	20101	Economy	13000.00
0005433151531	20101	Economy	13000.00
0005434374469	20101	Economy	13000.00
0005434374486	20101	Economy	13000.00
0005434029663	20101	Economy	13000.00
0005433151504	20101	Economy	13000.00
0005433151522	20101	Economy	13000.00
0005434374300	20101	Economy	13000.00
0005433151507	20101	Economy	13000.00
0005434374412	20101	Economy	13000.00
0005433151506	20101	Economy	13000.00
0005434374507	20101	Economy	13000.00
0005434374194	20101	Economy	13000.00
0005434374658	20101	Economy	13000.00
0005433151500	20101	Economy	13000.00
0005434374299	20101	Economy	13000.00
0005433151512	20101	Economy	13000.00
0005434374384	20101	Economy	13000.00
0005434374376	20101	Economy	13000.00
0005433151519	20101	Economy	13000.00
0005433151505	20101	Economy	13000.00
0005434029665	20101	Economy	13000.00
0005434374495	20101	Economy	14300.00
0005434374292	20101	Economy	14300.00
0005434374252	20101	Economy	14300.00
0005433151510	20101	Economy	13000.00
0005434374577	20101	Economy	13000.00
0005434374524	20101	Economy	13000.00
0005434374381	20101	Economy	13000.00
0005433764685	20101	Economy	13000.00
0005433151514	20101	Economy	13000.00
0005434374468	20101	Economy	13000.00
0005433151517	20101	Economy	13000.00
0005433151525	20101	Economy	13000.00
0005434374673	20101	Economy	13000.00
0005433151527	20101	Economy	13000.00
0005433151520	20101	Economy	13000.00
0005434374117	20101	Economy	13000.00
0005433151524	20101	Economy	13000.00
0005434029666	20101	Economy	13000.00
0005433151518	20101	Economy	13000.00
0005433151498	20101	Economy	13000.00
0005433151521	20101	Economy	13000.00
0005434374506	20101	Economy	13000.00
0005434374484	20101	Economy	13000.00
0005433151515	20101	Economy	13000.00
0005434374488	20101	Economy	13000.00
0005433764686	20101	Economy	13000.00
0005433151499	20101	Economy	13000.00
0005434374458	20101	Economy	13000.00
0005433151497	20101	Economy	13000.00
0005434374525	20101	Economy	13000.00
0005433151511	20101	Economy	13000.00
0005434374508	20101	Economy	13000.00
0005434374467	20101	Economy	13000.00
0005433151509	20101	Economy	13000.00
0005434374367	20101	Economy	13000.00
0005432056312	20101	Economy	13000.00
0005434374528	20101	Economy	13000.00
0005433151513	20101	Economy	13000.00
0005434374451	20101	Economy	13000.00
0005432056310	20101	Economy	13000.00
0005434374503	20101	Economy	13000.00
0005434374529	20101	Economy	13000.00
0005434374453	20101	Economy	13000.00
0005433151516	20101	Economy	13000.00
0005433151502	20101	Economy	13000.00
0005433151530	20101	Economy	13000.00
0005432056311	20101	Economy	13000.00
0005434374509	20101	Economy	13000.00
0005434374192	20101	Economy	13000.00
0005434374539	20101	Economy	13000.00
0005434374672	20101	Economy	13000.00
0005434374413	20101	Economy	13000.00
0005433151501	20101	Economy	13000.00
0005434374195	20101	Economy	13000.00
0005433151528	20101	Economy	13000.00
0005434374378	20101	Economy	13000.00
0005434374324	20101	Economy	13000.00
0005433151529	20101	Economy	13000.00
0005434374494	20101	Economy	13000.00
0005434374538	20101	Economy	13000.00
0005434374318	20101	Economy	13000.00
0005432424606	567	Business	27500.00
0005432424600	567	Business	27500.00
0005432424604	567	Business	27500.00
0005432424595	567	Business	27500.00
0005432424571	567	Business	27500.00
0005432424581	567	Business	27500.00
0005432282889	567	Business	27500.00
0005432424603	567	Business	27500.00
0005432424605	567	Business	27500.00
0005432424596	567	Economy	9200.00
0005432424584	567	Economy	9200.00
0005432424574	567	Economy	9200.00
0005432424587	567	Economy	9200.00
0005432424588	567	Economy	9200.00
0005432424592	567	Economy	9200.00
0005432282886	567	Economy	9200.00
0005432282885	567	Economy	9200.00
0005432424577	567	Economy	9200.00
0005432424598	567	Economy	9200.00
0005432424589	567	Economy	9200.00
0005432424576	567	Economy	9200.00
0005432282891	567	Economy	9200.00
0005432424572	567	Economy	9200.00
0005432424607	567	Economy	9200.00
0005432424583	567	Economy	9200.00
0005432424593	567	Economy	9200.00
0005432282884	567	Economy	9200.00
0005432424608	567	Economy	10100.00
0005432424590	567	Economy	9200.00
0005432282887	567	Economy	9200.00
0005432282888	567	Economy	9200.00
0005432424579	567	Economy	9200.00
0005432424573	567	Economy	9200.00
0005432424578	567	Economy	9200.00
0005432424597	567	Economy	9200.00
0005432282883	567	Economy	9200.00
0005432424591	567	Economy	9200.00
0005432424602	567	Economy	9200.00
0005432424582	567	Economy	9200.00
0005432424575	567	Economy	9200.00
0005432424594	567	Economy	9200.00
0005432424599	567	Economy	9200.00
0005432424585	567	Economy	9200.00
0005432424580	567	Economy	9200.00
0005432424609	567	Economy	9200.00
0005432282890	567	Economy	9200.00
0005432424601	567	Economy	9200.00
0005432424586	567	Economy	9200.00
0005432302344	12884	Business	27500.00
0005432302341	12884	Business	27500.00
0005432302342	12884	Economy	9200.00
0005432302343	12884	Economy	9200.00
0005432424169	12932	Business	27500.00
0005432424138	12932	Business	27500.00
0005432424159	12932	Business	27500.00
0005432424095	12932	Business	27500.00
0005432424033	12932	Business	27500.00
0005432424123	12932	Business	27500.00
0005432424139	12932	Business	27500.00
0005432424020	12932	Business	27500.00
0005432424116	12932	Economy	10100.00
0005432424034	12932	Economy	10100.00
0005432424043	12932	Economy	9200.00
0005432424121	12932	Economy	9200.00
0005432424041	12932	Economy	9200.00
0005432424067	12932	Economy	9200.00
0005432423988	12932	Economy	9200.00
0005432424113	12932	Economy	9200.00
0005432424035	12932	Economy	9200.00
0005432424103	12932	Economy	9200.00
0005432424065	12932	Economy	9200.00
0005432424111	12932	Economy	9200.00
0005432424078	12932	Economy	9200.00
0005432424129	12932	Economy	9200.00
0005432423956	12932	Economy	9200.00
0005432424160	12932	Economy	9200.00
0005432424110	12932	Economy	9200.00
0005432423989	12932	Economy	9200.00
0005432424109	12932	Economy	10100.00
0005432424036	12932	Economy	10100.00
0005432423937	12932	Economy	9200.00
0005432424112	12932	Economy	9200.00
0005432424037	12932	Economy	9200.00
0005432423961	12932	Economy	9200.00
0005432424107	12932	Economy	9200.00
0005432424158	12932	Economy	9200.00
0005432424044	12932	Economy	9200.00
0005432424115	12932	Economy	9200.00
0005432424042	12932	Economy	9200.00
0005432424104	12932	Economy	9200.00
0005432424032	12932	Economy	9200.00
0005432424094	12932	Economy	9200.00
0005432424135	12932	Economy	9200.00
0005432423967	12932	Economy	9200.00
0005432424108	12932	Economy	9200.00
0005432424079	12932	Economy	9200.00
0005432424152	12932	Economy	9200.00
0005432235663	462	Business	24500.00
0005433057556	462	Business	24500.00
0005434023957	462	Business	24500.00
0005434029662	462	Business	24500.00
0005433684394	462	Business	24500.00
0005434023940	462	Business	24500.00
0005433057513	462	Business	24500.00
0005434023905	462	Business	24500.00
0005434028304	462	Business	24500.00
0005434023921	462	Business	24500.00
0005433057760	462	Business	24500.00
0005434735649	462	Business	24500.00
0005433057665	462	Business	24500.00
0005434023914	462	Business	24500.00
0005434023904	462	Business	24500.00
0005434023889	462	Business	24500.00
0005434023890	462	Business	24500.00
0005434023915	462	Business	24500.00
0005434023932	462	Business	24500.00
0005433057666	462	Business	24500.00
0005434032035	462	Business	24500.00
0005433057649	462	Business	24500.00
0005434023941	462	Economy	9000.00
0005434023918	462	Economy	9000.00
0005434023936	462	Economy	9000.00
0005434735650	462	Economy	9000.00
0005433057643	462	Economy	8200.00
0005434023952	462	Economy	8200.00
0005432235662	462	Economy	8200.00
0005434028306	462	Economy	8200.00
0005434023928	462	Economy	8200.00
0005434023951	462	Economy	8200.00
0005434023955	462	Economy	8200.00
0005433057617	462	Economy	8200.00
0005434023934	462	Economy	8200.00
0005433057645	462	Economy	8200.00
0005434023933	462	Economy	8200.00
0005434023924	462	Economy	8200.00
0005434023956	462	Economy	8200.00
0005433929572	462	Economy	8200.00
0005434023896	462	Economy	8200.00
0005433929571	462	Economy	8200.00
0005433057618	462	Economy	8200.00
0005432045618	462	Economy	8200.00
0005434023946	462	Economy	8200.00
0005434023895	462	Economy	8200.00
0005433057772	462	Economy	8200.00
0005433057714	462	Economy	8200.00
0005434023945	462	Economy	8200.00
0005433057677	462	Economy	8200.00
0005434023950	462	Economy	8200.00
0005434032037	462	Economy	8200.00
0005433057616	462	Economy	8200.00
0005434029661	462	Economy	8200.00
0005433057770	462	Economy	8200.00
0005434028305	462	Economy	8200.00
0005433057709	462	Economy	8200.00
0005433057924	462	Economy	8200.00
0005433057657	462	Economy	8200.00
0005434735647	462	Economy	8200.00
0005434023931	462	Economy	8200.00
0005434023888	462	Economy	8200.00
0005432235658	462	Economy	8200.00
0005434023930	462	Economy	8200.00
0005434032034	462	Economy	8200.00
0005434023913	462	Economy	8200.00
0005434023909	462	Economy	8200.00
0005433057646	462	Economy	8200.00
0005434023894	462	Economy	8200.00
0005434023953	462	Economy	8200.00
0005434023944	462	Economy	8200.00
0005434023920	462	Economy	8200.00
0005433057658	462	Economy	8200.00
0005432235665	462	Economy	8200.00
0005434735651	462	Economy	8200.00
0005434023942	462	Economy	8200.00
0005434023899	462	Economy	8200.00
0005433929582	462	Economy	8200.00
0005434023938	462	Economy	8200.00
0005434023900	462	Economy	8200.00
0005434028302	462	Economy	8200.00
0005432235664	462	Economy	8200.00
0005433057625	462	Economy	8200.00
0005433057642	462	Economy	8200.00
0005433057768	462	Economy	8200.00
0005433684405	462	Economy	8200.00
0005434023892	462	Economy	8200.00
0005434023947	462	Economy	8200.00
0005434023917	462	Economy	8200.00
0005434023926	462	Economy	8200.00
0005434023912	462	Economy	8200.00
0005433684410	462	Economy	8200.00
0005433057769	462	Economy	8200.00
0005434735652	462	Economy	8200.00
0005433929584	462	Economy	8200.00
0005433684407	462	Economy	9000.00
0005433057708	462	Economy	9000.00
0005434023903	462	Economy	8200.00
0005434023908	462	Economy	9000.00
0005434023923	462	Economy	8200.00
0005434023939	462	Economy	9000.00
0005433057716	462	Economy	8200.00
0005434023937	462	Economy	8200.00
0005433929580	462	Economy	8200.00
0005434023922	462	Economy	8200.00
0005433057681	462	Economy	8200.00
0005433057732	462	Economy	8200.00
0005433057536	462	Economy	8200.00
0005434023925	462	Economy	8200.00
0005432235660	462	Economy	8200.00
0005433929589	462	Economy	8200.00
0005434023898	462	Economy	8200.00
0005433057773	462	Economy	8200.00
0005433057680	462	Economy	8200.00
0005434023906	462	Economy	8200.00
0005434023948	462	Economy	8200.00
0005434023901	462	Economy	8200.00
0005434023929	462	Economy	8200.00
0005433929583	462	Economy	8200.00
0005434023893	462	Economy	8200.00
0005434023949	462	Economy	8200.00
0005433057771	462	Economy	8200.00
0005434023935	462	Economy	8200.00
0005433057641	462	Economy	8200.00
0005434032036	462	Economy	8200.00
0005434023897	462	Economy	8200.00
0005434023902	462	Economy	8200.00
0005434023954	462	Economy	8200.00
0005434023927	462	Economy	8200.00
0005432235659	462	Economy	8200.00
0005432235661	462	Economy	8200.00
0005433684404	462	Economy	8200.00
0005434023907	462	Economy	8200.00
0005434028303	462	Economy	8200.00
0005433057590	462	Economy	8200.00
0005433057753	462	Economy	8200.00
0005433057535	462	Economy	8200.00
0005434023916	462	Economy	8200.00
0005434023891	462	Economy	8200.00
0005433057923	462	Economy	8200.00
0005433057717	462	Economy	8200.00
0005432045617	462	Economy	8200.00
0005434032033	462	Economy	8200.00
0005434023943	462	Economy	8200.00
0005433057715	462	Economy	8200.00
0005434023919	462	Economy	8200.00
0005434023911	462	Economy	8200.00
0005434023910	462	Economy	8200.00
0005434735648	462	Economy	8200.00
0005433057555	462	Economy	8200.00
0005434023375	12643	Business	24500.00
0005432156381	12643	Business	24500.00
0005433057995	12643	Business	24500.00
0005434023273	12643	Business	24500.00
0005433058029	12643	Business	24500.00
0005434023340	12643	Business	24500.00
0005434023521	12643	Business	24500.00
0005433929625	12643	Business	24500.00
0005434031999	12643	Business	24500.00
0005434023083	12643	Business	24500.00
0005434023126	12643	Business	24500.00
0005434023001	12643	Business	24500.00
0005434023214	12643	Business	24500.00
0005434023174	12643	Business	24500.00
0005434023310	12643	Business	24500.00
0005434023276	12643	Business	24500.00
0005433058008	12643	Business	24500.00
0005433058016	12643	Business	24500.00
0005434023242	12643	Business	24500.00
0005433058027	12643	Economy	9000.00
0005433058005	12643	Economy	9000.00
0005432156379	12643	Economy	8200.00
0005434023231	12643	Economy	8200.00
0005433058018	12643	Economy	8200.00
0005434023355	12643	Economy	8200.00
0005434023417	12643	Economy	8200.00
0005434023181	12643	Economy	8200.00
0005433058017	12643	Economy	8200.00
0005434023160	12643	Economy	8200.00
0005433058024	12643	Economy	8200.00
0005433058007	12643	Economy	8200.00
0005434023161	12643	Economy	8200.00
0005434023222	12643	Economy	8200.00
0005434023525	12643	Economy	8200.00
0005432157499	12643	Economy	8200.00
0005434023230	12643	Economy	8200.00
0005434032004	12643	Economy	8200.00
0005434031987	12643	Economy	8200.00
0005434023309	12643	Economy	8200.00
0005433057998	12643	Economy	8200.00
0005433058025	12643	Economy	8200.00
0005432157498	12643	Economy	8200.00
0005434023520	12643	Economy	8200.00
0005434023243	12643	Economy	8200.00
0005433058028	12643	Economy	8200.00
0005433057997	12643	Economy	8200.00
0005433057994	12643	Economy	8200.00
0005434023330	12643	Economy	8200.00
0005434023605	12643	Economy	8200.00
0005434032001	12643	Economy	8200.00
0005434022870	12643	Economy	8200.00
0005434023519	12643	Economy	8200.00
0005433058009	12643	Economy	8200.00
0005434023262	12643	Economy	8200.00
0005434023171	12643	Economy	8200.00
0005432156377	12643	Economy	8200.00
0005434023258	12643	Economy	8200.00
0005434023059	12643	Economy	8200.00
0005433058019	12643	Economy	8200.00
0005433058006	12643	Economy	8200.00
0005433929624	12643	Economy	8200.00
0005434023268	12643	Economy	8200.00
0005434023152	12643	Economy	8200.00
0005433057996	12643	Economy	8200.00
0005434023334	12643	Economy	8200.00
0005432156380	12643	Economy	8200.00
0005434023709	12643	Economy	8200.00
0005434023441	12643	Economy	8200.00
0005434023339	12643	Economy	8200.00
0005434023280	12643	Economy	8200.00
0005434023215	12643	Economy	8200.00
0005434023281	12643	Economy	8200.00
0005433058000	12643	Economy	8200.00
0005433058010	12643	Economy	8200.00
0005434023082	12643	Economy	8200.00
0005433058011	12643	Economy	8200.00
0005433058012	12643	Economy	8200.00
0005434023376	12643	Economy	8200.00
0005434023418	12643	Economy	8200.00
0005434023428	12643	Economy	8200.00
0005433058004	12643	Economy	8200.00
0005434023263	12643	Economy	8200.00
0005433057992	12643	Economy	8200.00
0005434023408	12643	Economy	8200.00
0005434735705	12643	Economy	8200.00
0005433058030	12643	Economy	8200.00
0005434023351	12643	Economy	8200.00
0005434023272	12643	Economy	8200.00
0005433058001	12643	Economy	8200.00
0005434022882	12643	Economy	8200.00
0005434023329	12643	Economy	8200.00
0005434023614	12643	Economy	8200.00
0005434023356	12643	Economy	8200.00
0005434023457	12643	Economy	8200.00
0005432156378	12643	Economy	8200.00
0005434023201	12643	Economy	8200.00
0005434023058	12643	Economy	9000.00
0005434023127	12643	Economy	8200.00
0005434023172	12643	Economy	8200.00
0005434031995	12643	Economy	9000.00
0005434023629	12643	Economy	8200.00
0005434023269	12643	Economy	8200.00
0005434735704	12643	Economy	8200.00
0005434023275	12643	Economy	8200.00
0005434023458	12643	Economy	8200.00
0005433929626	12643	Economy	8200.00
0005434023168	12643	Economy	8200.00
0005434023102	12643	Economy	8200.00
0005434022921	12643	Economy	8200.00
0005432157497	12643	Economy	8200.00
0005434023613	12643	Economy	8200.00
0005433058003	12643	Economy	8200.00
0005434023382	12643	Economy	8200.00
0005434023471	12643	Economy	8200.00
0005434023383	12643	Economy	8200.00
0005433058021	12643	Economy	8200.00
0005434023216	12643	Economy	8200.00
0005434032000	12643	Economy	8200.00
0005434023220	12643	Economy	8200.00
0005433684427	12643	Economy	8200.00
0005433057993	12643	Economy	8200.00
0005434023186	12643	Economy	8200.00
0005433058014	12643	Economy	8200.00
0005434023221	12643	Economy	8200.00
0005434023537	12643	Economy	8200.00
0005434023460	12643	Economy	8200.00
0005433057999	12643	Economy	8200.00
0005433058026	12643	Economy	8200.00
0005433929628	12643	Economy	8200.00
0005434023579	12643	Economy	8200.00
0005434023708	12643	Economy	8200.00
0005433929627	12643	Economy	8200.00
0005434023335	12643	Economy	8200.00
0005434735707	12643	Economy	8200.00
0005434023203	12643	Economy	8200.00
0005433058023	12643	Economy	8200.00
0005434023510	12643	Economy	8200.00
0005434735708	12643	Economy	8200.00
0005433058002	12643	Economy	8200.00
0005433058020	12643	Economy	8200.00
0005434023159	12643	Economy	8200.00
0005434023202	12643	Economy	8200.00
0005433058022	12643	Economy	8200.00
0005434023571	12643	Economy	8200.00
0005432156382	12643	Economy	8200.00
0005434023459	12643	Economy	8200.00
0005433684428	12643	Economy	8200.00
0005434735706	12643	Economy	8200.00
0005434023170	12643	Economy	8200.00
0005433058015	12643	Economy	8200.00
0005433058013	12643	Economy	8200.00
0005433923564	2134	Business	34700.00
0005433035925	2134	Business	34700.00
0005433923633	2134	Business	34700.00
0005433923600	2134	Business	34700.00
0005433923627	2134	Business	34700.00
0005433036017	2134	Business	34700.00
0005433036065	2134	Business	34700.00
0005433923567	2134	Business	34700.00
0005433929628	2134	Business	34700.00
0005433036170	2134	Business	34700.00
0005433923570	2134	Business	34700.00
0005432231593	2134	Business	34700.00
0005432044533	2134	Business	34700.00
0005433923641	2134	Business	34700.00
0005433923645	2134	Business	34700.00
0005433923614	2134	Business	34700.00
0005433036212	2134	Business	34700.00
0005433923611	2134	Business	34700.00
0005433035987	2134	Business	34700.00
0005433923609	2134	Business	34700.00
0005433923605	2134	Business	34700.00
0005433923554	2134	Business	34700.00
0005432231594	2134	Business	34700.00
0005433923620	2134	Business	34700.00
0005433929625	2134	Business	34700.00
0005432749772	2134	Business	34700.00
0005433923562	2134	Business	34700.00
0005433923593	2134	Business	34700.00
0005433036165	2134	Economy	12700.00
0005433036042	2134	Economy	12700.00
0005433036000	2134	Economy	12700.00
0005433035736	2134	Economy	11600.00
0005433036083	2134	Economy	11600.00
0005433923592	2134	Economy	11600.00
0005433923581	2134	Economy	11600.00
0005433923625	2134	Economy	11600.00
0005433036126	2134	Economy	11600.00
0005433923585	2134	Economy	11600.00
0005433923553	2134	Economy	11600.00
0005433923624	2134	Economy	11600.00
0005433923563	2134	Economy	11600.00
0005433923571	2134	Economy	11600.00
0005433923603	2134	Economy	11600.00
0005433036146	2134	Economy	11600.00
0005433923634	2134	Economy	11600.00
0005432231600	2134	Economy	11600.00
0005433923643	2134	Economy	11600.00
0005433036185	2134	Economy	11600.00
0005433035907	2134	Economy	11600.00
0005433923552	2134	Economy	11600.00
0005433923587	2134	Economy	11600.00
0005433923565	2134	Economy	11600.00
0005433035919	2134	Economy	11600.00
0005433923615	2134	Economy	11600.00
0005433929624	2134	Economy	11600.00
0005433875383	2134	Economy	11600.00
0005433923607	2134	Economy	11600.00
0005433923639	2134	Economy	11600.00
0005433923599	2134	Economy	11600.00
0005433923584	2134	Economy	11600.00
0005433036025	2134	Economy	11600.00
0005432749773	2134	Economy	11600.00
0005433923583	2134	Economy	11600.00
0005433036043	2134	Economy	11600.00
0005433035940	2134	Economy	11600.00
0005433923555	2134	Economy	11600.00
0005433036097	2134	Economy	11600.00
0005433923589	2134	Economy	11600.00
0005433923560	2134	Economy	11600.00
0005433036055	2134	Economy	11600.00
0005433035735	2134	Economy	11600.00
0005433035915	2134	Economy	11600.00
0005433036075	2134	Economy	11600.00
0005433036041	2134	Economy	11600.00
0005433036001	2134	Economy	11600.00
0005433036147	2134	Economy	11600.00
0005433923596	2134	Economy	11600.00
0005433036186	2134	Economy	11600.00
0005433929627	2134	Economy	11600.00
0005433875384	2134	Economy	11600.00
0005433035916	2134	Economy	11600.00
0005433036080	2134	Economy	11600.00
0005433036058	2134	Economy	11600.00
0005433923638	2134	Economy	11600.00
0005433923626	2134	Economy	11600.00
0005433035950	2134	Economy	11600.00
0005433923606	2134	Economy	11600.00
0005433923647	2134	Economy	11600.00
0005432231597	2134	Economy	11600.00
0005433036099	2134	Economy	11600.00
0005433923617	2134	Economy	11600.00
0005433923602	2134	Economy	11600.00
0005433923619	2134	Economy	11600.00
0005432231596	2134	Economy	11600.00
0005433036191	2134	Economy	11600.00
0005433923646	2134	Economy	11600.00
0005433035828	2134	Economy	11600.00
0005433923630	2134	Economy	11600.00
0005433035949	2134	Economy	11600.00
0005433923595	2134	Economy	11600.00
0005433923608	2134	Economy	11600.00
0005433035994	2134	Economy	11600.00
0005433923572	2134	Economy	11600.00
0005433923561	2134	Economy	11600.00
0005433036067	2134	Economy	11600.00
0005433923631	2134	Economy	11600.00
0005433923622	2134	Economy	11600.00
0005433923637	2134	Economy	11600.00
0005433923597	2134	Economy	11600.00
0005433923648	2134	Economy	11600.00
0005432231602	2134	Economy	11600.00
0005433923616	2134	Economy	11600.00
0005433036096	2134	Economy	11600.00
0005433923578	2134	Economy	11600.00
0005432231598	2134	Economy	11600.00
0005433035861	2134	Economy	11600.00
0005433036046	2134	Economy	11600.00
0005433923640	2134	Economy	11600.00
0005433923635	2134	Economy	11600.00
0005433035999	2134	Economy	11600.00
0005433035784	2134	Economy	12700.00
0005433923594	2134	Economy	11600.00
0005433035793	2134	Economy	11600.00
0005432231601	2134	Economy	12700.00
0005433035947	2134	Economy	12700.00
0005433923612	2134	Economy	11600.00
0005433923586	2134	Economy	11600.00
0005433923604	2134	Economy	11600.00
0005433923610	2134	Economy	11600.00
0005433036098	2134	Economy	11600.00
0005433035989	2134	Economy	11600.00
0005433036164	2134	Economy	11600.00
0005433035821	2134	Economy	11600.00
0005433036072	2134	Economy	11600.00
0005433923574	2134	Economy	11600.00
0005433923576	2134	Economy	11600.00
0005433923629	2134	Economy	11600.00
0005433035858	2134	Economy	11600.00
0005433036026	2134	Economy	11600.00
0005433036152	2134	Economy	11600.00
0005432749774	2134	Economy	11600.00
0005433036057	2134	Economy	11600.00
0005433923598	2134	Economy	11600.00
0005433923621	2134	Economy	11600.00
0005433923575	2134	Economy	11600.00
0005433923613	2134	Economy	11600.00
0005433923636	2134	Economy	11600.00
0005432044532	2134	Economy	11600.00
0005433036269	2134	Economy	11600.00
0005433923618	2134	Economy	11600.00
0005433923644	2134	Economy	11600.00
0005433036030	2134	Economy	11600.00
0005433035931	2134	Economy	11600.00
0005433035945	2134	Economy	11600.00
0005433036045	2134	Economy	11600.00
0005433923557	2134	Economy	11600.00
0005433923556	2134	Economy	11600.00
0005433036031	2134	Economy	11600.00
0005433923580	2134	Economy	11600.00
0005433923569	2134	Economy	11600.00
0005433923601	2134	Economy	11600.00
0005433035982	2134	Economy	11600.00
0005433036196	2134	Economy	11600.00
0005433923590	2134	Economy	11600.00
0005433923566	2134	Economy	11600.00
0005433923559	2134	Economy	11600.00
0005433923582	2134	Economy	11600.00
0005433036074	2134	Economy	11600.00
0005433036071	2134	Economy	11600.00
0005433036084	2134	Economy	11600.00
0005432231599	2134	Economy	11600.00
0005433035988	2134	Economy	11600.00
0005433923568	2134	Economy	11600.00
0005433035941	2134	Economy	11600.00
0005433036027	2134	Economy	11600.00
0005433035906	2134	Economy	11600.00
0005433036038	2134	Economy	11600.00
0005433923642	2134	Economy	11600.00
0005433036102	2134	Economy	11600.00
0005433035959	2134	Economy	11600.00
0005433923577	2134	Economy	11600.00
0005432044534	2134	Economy	11600.00
0005433923623	2134	Economy	11600.00
0005433036125	2134	Economy	11600.00
0005433923573	2134	Economy	11600.00
0005433036010	2134	Economy	11600.00
0005433035944	2134	Economy	11600.00
0005433923591	2134	Economy	11600.00
0005433929626	2134	Economy	11600.00
0005433923588	2134	Economy	11600.00
0005433923558	2134	Economy	11600.00
0005433923632	2134	Economy	11600.00
0005433035901	2134	Economy	11600.00
0005433036171	2134	Economy	11600.00
0005432231595	2134	Economy	11600.00
0005433923579	2134	Economy	11600.00
0005433923628	2134	Economy	11600.00
0005433922498	24119	Business	34700.00
0005433922809	24119	Business	34700.00
0005433923022	24119	Business	34700.00
0005433922784	24119	Business	34700.00
0005433922905	24119	Business	34700.00
0005433923088	24119	Business	34700.00
0005433036453	24119	Business	34700.00
0005433923098	24119	Business	34700.00
0005433923111	24119	Business	34700.00
0005433922812	24119	Business	34700.00
0005434028308	24119	Business	34700.00
0005433922630	24119	Business	34700.00
0005433923002	24119	Business	34700.00
0005432206211	24119	Business	34700.00
0005433922777	24119	Business	34700.00
0005433922420	24119	Business	34700.00
0005433922803	24119	Business	34700.00
0005433036458	24119	Business	34700.00
0005433922428	24119	Business	34700.00
0005433036440	24119	Business	34700.00
0005433931440	24119	Business	34700.00
0005433923123	24119	Business	34700.00
0005433929591	24119	Business	34700.00
0005433922404	24119	Business	34700.00
0005433036473	24119	Business	34700.00
0005433922830	24119	Business	34700.00
0005433922429	24119	Business	34700.00
0005433923110	24119	Business	34700.00
0005433036483	24119	Economy	12700.00
0005433922102	24119	Economy	12700.00
0005433923085	24119	Economy	12700.00
0005433922907	24119	Economy	11600.00
0005433922771	24119	Economy	11600.00
0005433922472	24119	Economy	11600.00
0005433922539	24119	Economy	11600.00
0005433922790	24119	Economy	11600.00
0005433036454	24119	Economy	11600.00
0005433922860	24119	Economy	11600.00
0005433923082	24119	Economy	11600.00
0005433922952	24119	Economy	11600.00
0005433923132	24119	Economy	11600.00
0005433036459	24119	Economy	11600.00
0005433036460	24119	Economy	11600.00
0005433922772	24119	Economy	11600.00
0005433922722	24119	Economy	11600.00
0005433922549	24119	Economy	11600.00
0005433922933	24119	Economy	11600.00
0005433922632	24119	Economy	11600.00
0005433036456	24119	Economy	11600.00
0005432206215	24119	Economy	11600.00
0005433036462	24119	Economy	11600.00
0005433036438	24119	Economy	11600.00
0005433036485	24119	Economy	11600.00
0005433923142	24119	Economy	11600.00
0005433922872	24119	Economy	11600.00
0005433922537	24119	Economy	11600.00
0005433923083	24119	Economy	11600.00
0005433036461	24119	Economy	11600.00
0005433922940	24119	Economy	11600.00
0005433036446	24119	Economy	11600.00
0005434028307	24119	Economy	11600.00
0005433923079	24119	Economy	11600.00
0005433923086	24119	Economy	11600.00
0005433875359	24119	Economy	11600.00
0005432749792	24119	Economy	11600.00
0005433922570	24119	Economy	11600.00
0005433036478	24119	Economy	11600.00
0005433922706	24119	Economy	11600.00
0005433922903	24119	Economy	11600.00
0005433036455	24119	Economy	11600.00
0005433036475	24119	Economy	11600.00
0005433036448	24119	Economy	11600.00
0005433922811	24119	Economy	11600.00
0005433036450	24119	Economy	11600.00
0005433931426	24119	Economy	11600.00
0005433922643	24119	Economy	11600.00
0005433923031	24119	Economy	11600.00
0005433922886	24119	Economy	11600.00
0005433036449	24119	Economy	11600.00
0005432206212	24119	Economy	11600.00
0005433923049	24119	Economy	11600.00
0005433922890	24119	Economy	11600.00
0005433036467	24119	Economy	11600.00
0005432206214	24119	Economy	11600.00
0005433036439	24119	Economy	11600.00
0005433922953	24119	Economy	11600.00
0005433922505	24119	Economy	11600.00
0005433922800	24119	Economy	11600.00
0005432206217	24119	Economy	11600.00
0005433923124	24119	Economy	11600.00
0005433922717	24119	Economy	11600.00
0005433036481	24119	Economy	11600.00
0005433922883	24119	Economy	11600.00
0005433922504	24119	Economy	11600.00
0005433923045	24119	Economy	11600.00
0005433923130	24119	Economy	11600.00
0005433036464	24119	Economy	11600.00
0005433036488	24119	Economy	11600.00
0005433036442	24119	Economy	11600.00
0005433923109	24119	Economy	11600.00
0005433931442	24119	Economy	11600.00
0005433922949	24119	Economy	11600.00
0005433922955	24119	Economy	11600.00
0005433923084	24119	Economy	11600.00
0005433922810	24119	Economy	11600.00
0005433922571	24119	Economy	11600.00
0005433922744	24119	Economy	11600.00
0005433923129	24119	Economy	11600.00
0005433931441	24119	Economy	11600.00
0005433922497	24119	Economy	11600.00
0005433922701	24119	Economy	11600.00
0005433036468	24119	Economy	11600.00
0005433036443	24119	Economy	11600.00
0005433922935	24119	Economy	11600.00
0005433922473	24119	Economy	11600.00
0005433036490	24119	Economy	11600.00
0005432207669	24119	Economy	11600.00
0005433036437	24119	Economy	12700.00
0005433922550	24119	Economy	12700.00
0005433036470	24119	Economy	11600.00
0005433923254	24119	Economy	11600.00
0005433922822	24119	Economy	11600.00
0005433922783	24119	Economy	12700.00
0005433923050	24119	Economy	12700.00
0005433036441	24119	Economy	11600.00
0005433922700	24119	Economy	11600.00
0005433922631	24119	Economy	11600.00
0005433036489	24119	Economy	11600.00
0005433036444	24119	Economy	11600.00
0005433036480	24119	Economy	11600.00
0005433922904	24119	Economy	11600.00
0005433923015	24119	Economy	11600.00
0005433922948	24119	Economy	11600.00
0005432207670	24119	Economy	11600.00
0005433922501	24119	Economy	11600.00
0005433923001	24119	Economy	11600.00
0005433922702	24119	Economy	11600.00
0005433922908	24119	Economy	11600.00
0005432206216	24119	Economy	11600.00
0005433922745	24119	Economy	11600.00
0005433922735	24119	Economy	11600.00
0005433922861	24119	Economy	11600.00
0005433922221	24119	Economy	11600.00
0005433922773	24119	Economy	11600.00
0005433036452	24119	Economy	11600.00
0005433922382	24119	Economy	11600.00
0005433875365	24119	Economy	11600.00
0005433922770	24119	Economy	11600.00
0005433036487	24119	Economy	11600.00
0005433922557	24119	Economy	11600.00
0005433036447	24119	Economy	11600.00
0005433036477	24119	Economy	11600.00
0005433036479	24119	Economy	11600.00
0005433923108	24119	Economy	11600.00
0005433036472	24119	Economy	11600.00
0005433036474	24119	Economy	11600.00
0005433922841	24119	Economy	11600.00
0005433922939	24119	Economy	11600.00
0005433036465	24119	Economy	11600.00
0005433036463	24119	Economy	11600.00
0005433036451	24119	Economy	11600.00
0005433036482	24119	Economy	11600.00
0005433922690	24119	Economy	11600.00
0005432206213	24119	Economy	11600.00
0005433922713	24119	Economy	11600.00
0005433922220	24119	Economy	11600.00
0005433922228	24119	Economy	11600.00
0005433923105	24119	Economy	11600.00
0005433923141	24119	Economy	11600.00
0005433036471	24119	Economy	11600.00
0005433922840	24119	Economy	11600.00
0005433036484	24119	Economy	11600.00
0005433931456	24119	Economy	11600.00
0005433036466	24119	Economy	11600.00
0005433036476	24119	Economy	11600.00
0005433036457	24119	Economy	11600.00
0005433922950	24119	Economy	11600.00
0005433036486	24119	Economy	11600.00
0005433036445	24119	Economy	11600.00
0005433922741	24119	Economy	11600.00
0005433036469	24119	Economy	11600.00
0005433922947	24119	Economy	11600.00
0005433923044	24119	Economy	11600.00
0005433922734	24119	Economy	11600.00
0005433922657	24119	Economy	11600.00
0005433923131	24119	Economy	11600.00
0005434551437	268	Business	83700.00
0005434725864	268	Business	83700.00
0005434725867	268	Business	83700.00
0005433180861	268	Business	83700.00
0005433289780	268	Business	83700.00
0005434551395	268	Business	83700.00
0005434725903	268	Business	83700.00
0005434551397	268	Business	83700.00
0005433234070	268	Business	83700.00
0005434551388	268	Business	83700.00
0005434725801	268	Business	83700.00
0005433233862	268	Business	83700.00
0005434725807	268	Business	83700.00
0005434731180	268	Business	83700.00
0005433180989	268	Business	83700.00
0005433131663	268	Business	83700.00
0005433180869	268	Business	83700.00
0005434551429	268	Business	83700.00
0005434551432	268	Business	83700.00
0005434725885	268	Business	83700.00
0005433234079	268	Business	83700.00
0005434551404	268	Business	83700.00
0005434551417	268	Business	83700.00
0005434725875	268	Comfort	47400.00
0005433233670	268	Business	83700.00
0005434551396	268	Comfort	47400.00
0005433233910	268	Comfort	47400.00
0005433233627	268	Comfort	47400.00
0005432277858	268	Comfort	47400.00
0005434031996	268	Comfort	47400.00
0005434551424	268	Comfort	47400.00
0005434725810	268	Comfort	47400.00
0005434725884	268	Comfort	47400.00
0005432277856	268	Comfort	47400.00
0005434551384	268	Comfort	47400.00
0005433233843	268	Comfort	47400.00
0005434725846	268	Comfort	47400.00
0005433233748	268	Comfort	47400.00
0005434725878	268	Comfort	47400.00
0005434725809	268	Comfort	47400.00
0005433234101	268	Comfort	47400.00
0005433289783	268	Comfort	47400.00
0005433126805	268	Comfort	47400.00
0005434725865	268	Comfort	47400.00
0005434551420	268	Comfort	47400.00
0005433180860	268	Comfort	47400.00
0005434725835	268	Comfort	47400.00
0005434725887	268	Comfort	47400.00
0005434725902	268	Comfort	47400.00
0005434725832	268	Comfort	47400.00
0005434551409	268	Comfort	47400.00
0005434725901	268	Comfort	47400.00
0005434725790	268	Comfort	47400.00
0005434725819	268	Comfort	47400.00
0005434725828	268	Comfort	47400.00
0005434725860	268	Comfort	47400.00
0005434551405	268	Comfort	47400.00
0005435142624	268	Comfort	47400.00
0005435142620	268	Comfort	47400.00
0005433234010	268	Comfort	47400.00
0005433289785	268	Comfort	47400.00
0005432277851	268	Comfort	47400.00
0005433233883	268	Comfort	47400.00
0005433233702	268	Comfort	47400.00
0005433233795	268	Comfort	47400.00
0005435142613	268	Comfort	47400.00
0005434725817	268	Comfort	47400.00
0005434725816	268	Comfort	47400.00
0005434725868	268	Economy	27900.00
0005434725826	268	Economy	27900.00
0005434725871	268	Economy	27900.00
0005434725794	268	Economy	27900.00
0005433180943	268	Economy	27900.00
0005433289772	268	Economy	27900.00
0005433289827	268	Economy	27900.00
0005433180922	268	Economy	27900.00
0005434725888	268	Economy	27900.00
0005434551390	268	Economy	27900.00
0005434725847	268	Economy	27900.00
0005434551386	268	Economy	27900.00
0005435142615	268	Economy	27900.00
0005434725861	268	Economy	27900.00
0005434725831	268	Economy	27900.00
0005433289782	268	Economy	27900.00
0005434551428	268	Economy	27900.00
0005433180969	268	Economy	27900.00
0005434725874	268	Economy	27900.00
0005434725800	268	Economy	27900.00
0005434725872	268	Economy	27900.00
0005434725834	268	Economy	27900.00
0005434725825	268	Economy	27900.00
0005434725879	268	Economy	27900.00
0005433289819	268	Economy	27900.00
0005433233747	268	Economy	27900.00
0005433234155	268	Economy	27900.00
0005434725894	268	Economy	27900.00
0005434725811	268	Economy	27900.00
0005433180915	268	Economy	27900.00
0005434725889	268	Economy	27900.00
0005434032009	268	Economy	27900.00
0005434725812	268	Economy	27900.00
0005434735699	268	Economy	27900.00
0005434725797	268	Economy	27900.00
0005433234011	268	Economy	27900.00
0005434551416	268	Economy	27900.00
0005434725853	268	Economy	27900.00
0005433289809	268	Economy	27900.00
0005433233763	268	Economy	27900.00
0005433234042	268	Economy	27900.00
0005434551392	268	Economy	27900.00
0005433234003	268	Economy	27900.00
0005434725827	268	Economy	27900.00
0005433233623	268	Economy	27900.00
0005433233628	268	Economy	27900.00
0005434551391	268	Economy	27900.00
0005432277854	268	Economy	27900.00
0005433180901	268	Economy	27900.00
0005433233640	268	Economy	27900.00
0005434551406	268	Economy	27900.00
0005432277844	268	Economy	27900.00
0005434725873	268	Economy	27900.00
0005434725821	268	Economy	27900.00
0005433766613	268	Economy	27900.00
0005434725900	268	Economy	27900.00
0005433233950	268	Economy	27900.00
0005434725852	268	Economy	27900.00
0005434725869	268	Economy	27900.00
0005435142616	268	Economy	27900.00
0005434725870	268	Economy	27900.00
0005434302473	268	Economy	27900.00
0005434725854	268	Economy	27900.00
0005434731183	268	Economy	30700.00
0005434725822	268	Economy	30700.00
0005434031989	268	Economy	27900.00
0005433233916	268	Economy	30700.00
0005433233947	268	Economy	27900.00
0005433233934	268	Economy	27900.00
0005434302474	268	Economy	27900.00
0005434551412	268	Economy	30700.00
0005434551389	268	Economy	30700.00
0005434725808	268	Economy	27900.00
0005433233762	268	Economy	30700.00
0005433126830	268	Economy	27900.00
0005434032008	268	Economy	27900.00
0005433233915	268	Economy	27900.00
0005434725842	268	Economy	27900.00
0005434031960	268	Economy	27900.00
0005434551414	268	Economy	27900.00
0005434725851	268	Economy	27900.00
0005434725862	268	Economy	27900.00
0005433180954	268	Economy	27900.00
0005434551419	268	Economy	27900.00
0005432277850	268	Economy	27900.00
0005433180923	268	Economy	27900.00
0005434725806	268	Economy	27900.00
0005434551408	268	Economy	27900.00
0005433233924	268	Economy	27900.00
0005433180962	268	Economy	27900.00
0005433289771	268	Economy	27900.00
0005434725795	268	Economy	27900.00
0005434725898	268	Economy	27900.00
0005434731182	268	Economy	27900.00
0005434032006	268	Economy	27900.00
0005434725829	268	Economy	27900.00
0005433126822	268	Economy	27900.00
0005434551435	268	Economy	27900.00
0005433233981	268	Economy	27900.00
0005434725841	268	Economy	27900.00
0005434551434	268	Economy	27900.00
0005434725866	268	Economy	27900.00
0005434725799	268	Economy	27900.00
0005433766611	268	Economy	27900.00
0005434551433	268	Economy	27900.00
0005433180832	268	Economy	27900.00
0005434551381	268	Economy	27900.00
0005434551385	268	Economy	27900.00
0005433180900	268	Economy	27900.00
0005433233879	268	Economy	27900.00
0005432277846	268	Economy	27900.00
0005433234004	268	Economy	27900.00
0005433234040	268	Economy	27900.00
0005434725845	268	Economy	27900.00
0005434725909	268	Economy	27900.00
0005433233794	268	Economy	27900.00
0005434725882	268	Economy	27900.00
0005434735700	268	Economy	27900.00
0005434551399	268	Economy	27900.00
0005434551425	268	Economy	27900.00
0005434032003	268	Economy	27900.00
0005433289781	268	Economy	27900.00
0005435142617	268	Economy	27900.00
0005433180910	268	Economy	27900.00
0005434725815	268	Economy	27900.00
0005435142625	268	Economy	27900.00
0005433233683	268	Economy	27900.00
0005433233606	268	Economy	27900.00
0005434725803	268	Economy	27900.00
0005434725910	268	Economy	27900.00
0005434032002	268	Economy	27900.00
0005434551413	268	Economy	27900.00
0005433180968	268	Economy	27900.00
0005434551418	268	Economy	27900.00
0005433233943	268	Economy	27900.00
0005434725833	268	Economy	27900.00
0005434725908	268	Economy	27900.00
0005434725804	268	Economy	27900.00
0005433180963	268	Economy	27900.00
0005434031997	268	Economy	27900.00
0005434551422	268	Economy	27900.00
0005434725899	268	Economy	27900.00
0005435142618	268	Economy	27900.00
0005434725850	268	Economy	27900.00
0005434725796	268	Economy	27900.00
0005434725890	268	Economy	27900.00
0005433233546	268	Economy	27900.00
0005434725857	268	Economy	27900.00
0005433234102	268	Economy	27900.00
0005434551393	268	Economy	27900.00
0005434725863	268	Economy	27900.00
0005434725849	268	Economy	27900.00
0005434725883	268	Economy	27900.00
0005434725824	268	Economy	27900.00
0005433233774	268	Economy	27900.00
0005433289810	268	Economy	27900.00
0005433180985	268	Economy	27900.00
0005433233944	268	Economy	27900.00
0005432277845	268	Economy	27900.00
0005434725844	268	Economy	27900.00
0005434725839	268	Economy	27900.00
0005433766609	268	Economy	27900.00
0005433233998	268	Economy	27900.00
0005434725858	268	Economy	27900.00
0005434551427	268	Economy	27900.00
0005434731179	268	Economy	27900.00
0005434551394	268	Economy	27900.00
0005434725912	268	Economy	27900.00
0005433180870	268	Economy	27900.00
0005433233951	268	Economy	27900.00
0005434735702	268	Economy	27900.00
0005434725840	268	Economy	27900.00
0005434725877	268	Economy	27900.00
0005434725813	268	Economy	27900.00
0005433131697	268	Economy	27900.00
0005434032005	268	Economy	27900.00
0005434725792	268	Economy	27900.00
0005434735703	268	Economy	27900.00
0005433233798	268	Economy	27900.00
0005434551411	268	Economy	30700.00
0005434031984	268	Economy	30700.00
0005434725793	268	Economy	30700.00
0005434725791	268	Economy	30700.00
0005433233982	268	Economy	30700.00
0005434725818	268	Economy	30700.00
0005433233990	268	Economy	27900.00
0005434725895	268	Economy	27900.00
0005433126810	268	Economy	27900.00
0005434725855	268	Economy	27900.00
0005433233724	268	Economy	27900.00
0005434731181	268	Economy	27900.00
0005434725891	268	Economy	27900.00
0005434031988	268	Economy	27900.00
0005433233759	268	Economy	27900.00
0005433233830	268	Economy	27900.00
0005433234154	268	Economy	27900.00
0005434725798	268	Economy	27900.00
0005433180953	268	Economy	27900.00
0005433233914	268	Economy	27900.00
0005434725904	268	Economy	27900.00
0005435142623	268	Economy	27900.00
0005434725856	268	Economy	27900.00
0005433181044	268	Economy	27900.00
0005433233877	268	Economy	27900.00
0005435142614	268	Economy	27900.00
0005432277848	268	Economy	27900.00
0005434551387	268	Economy	27900.00
0005433233925	268	Economy	27900.00
0005434551398	268	Economy	27900.00
0005434735701	268	Economy	27900.00
0005434725880	268	Economy	27900.00
0005433233833	268	Economy	27900.00
0005434725881	268	Economy	27900.00
0005434551431	268	Economy	27900.00
0005433233624	268	Economy	27900.00
0005433180952	268	Economy	27900.00
0005434725876	268	Economy	27900.00
0005434725859	268	Economy	27900.00
0005432277849	268	Economy	27900.00
0005434551400	268	Economy	27900.00
0005434725911	268	Economy	27900.00
0005434725893	268	Economy	27900.00
0005434725892	268	Economy	27900.00
0005433233935	268	Economy	27900.00
0005434725848	268	Economy	27900.00
0005434551426	268	Economy	27900.00
0005434725823	268	Economy	27900.00
0005434725905	268	Economy	27900.00
0005433289784	268	Economy	27900.00
0005433233853	268	Economy	27900.00
0005434551403	268	Economy	27900.00
0005433181045	268	Economy	27900.00
0005435142621	268	Economy	27900.00
0005433126803	268	Economy	27900.00
0005433126806	268	Economy	27900.00
0005432277852	268	Economy	27900.00
0005433233684	268	Economy	27900.00
0005434725897	268	Economy	27900.00
0005434725802	268	Economy	27900.00
0005434725814	268	Economy	27900.00
0005433126809	268	Economy	27900.00
0005433233863	268	Economy	27900.00
0005434551430	268	Economy	27900.00
0005433234002	268	Economy	27900.00
0005432277847	268	Economy	27900.00
0005434551407	268	Economy	27900.00
0005434551410	268	Economy	27900.00
0005433233876	268	Economy	27900.00
0005434725805	268	Economy	27900.00
0005434551382	268	Economy	27900.00
0005433766623	268	Economy	27900.00
0005434725896	268	Economy	27900.00
0005434725836	268	Economy	27900.00
0005433233948	268	Economy	27900.00
0005434725907	268	Economy	27900.00
0005434551402	268	Economy	27900.00
0005433126811	268	Economy	27900.00
0005434725906	268	Economy	27900.00
0005433233960	268	Economy	27900.00
0005434725830	268	Economy	27900.00
0005432277855	268	Economy	27900.00
0005433234041	268	Economy	27900.00
0005434551415	268	Economy	27900.00
0005434551383	268	Economy	27900.00
0005432277853	268	Economy	27900.00
0005433233872	268	Economy	27900.00
0005435142622	268	Economy	27900.00
0005434725886	268	Economy	27900.00
0005434725820	268	Economy	27900.00
0005434551421	268	Economy	27900.00
0005434725838	268	Economy	27900.00
0005433180936	268	Economy	27900.00
0005433180937	268	Economy	27900.00
0005433113524	268	Economy	27900.00
0005434725843	268	Economy	27900.00
0005433180988	268	Economy	27900.00
0005435142619	268	Economy	27900.00
0005434302472	268	Economy	27900.00
0005434551401	268	Economy	27900.00
0005433233633	268	Economy	27900.00
0005433233729	268	Economy	27900.00
0005433180941	268	Economy	27900.00
0005434551436	268	Economy	27900.00
0005433233800	268	Economy	27900.00
0005432277857	268	Economy	27900.00
0005434551423	268	Economy	27900.00
0005434725837	268	Economy	27900.00
0005433181176	9847	Business	83700.00
0005433234377	9847	Business	83700.00
0005433181172	9847	Business	83700.00
0005434550947	9847	Business	83700.00
0005434032041	9847	Business	83700.00
0005434725226	9847	Business	83700.00
0005433129288	9847	Business	83700.00
0005433234403	9847	Business	83700.00
0005433129287	9847	Business	83700.00
0005433234379	9847	Business	83700.00
0005434725151	9847	Business	83700.00
0005434550833	9847	Business	83700.00
0005433234370	9847	Business	83700.00
0005433126857	9847	Business	83700.00
0005434724559	9847	Business	83700.00
0005434551020	9847	Business	83700.00
0005434724922	9847	Business	83700.00
0005434724591	9847	Business	83700.00
0005433234420	9847	Business	83700.00
0005434724562	9847	Business	83700.00
0005432199267	9847	Business	83700.00
0005434725094	9847	Business	83700.00
0005434724624	9847	Business	83700.00
0005434550898	9847	Comfort	47400.00
0005433181166	9847	Business	83700.00
0005434724801	9847	Comfort	47400.00
0005434724722	9847	Comfort	47400.00
0005434550876	9847	Comfort	47400.00
0005434550814	9847	Comfort	47400.00
0005434724776	9847	Comfort	47400.00
0005433181171	9847	Comfort	47400.00
0005433181178	9847	Comfort	47400.00
0005434724389	9847	Comfort	47400.00
0005435142468	9847	Comfort	47400.00
0005434724809	9847	Comfort	47400.00
0005434550870	9847	Comfort	47400.00
0005434550829	9847	Comfort	47400.00
0005434725104	9847	Comfort	47400.00
0005434724684	9847	Comfort	47400.00
0005434551062	9847	Comfort	47400.00
0005434550793	9847	Comfort	47400.00
0005434725039	9847	Comfort	47400.00
0005434724807	9847	Comfort	47400.00
0005433234380	9847	Comfort	47400.00
0005433181184	9847	Comfort	47400.00
0005434550997	9847	Comfort	47400.00
0005434724682	9847	Comfort	47400.00
0005434725078	9847	Comfort	47400.00
0005433181167	9847	Comfort	47400.00
0005433181183	9847	Comfort	47400.00
0005435142465	9847	Comfort	47400.00
0005432199268	9847	Comfort	47400.00
0005434550944	9847	Comfort	47400.00
0005433234400	9847	Comfort	47400.00
0005434550996	9847	Comfort	47400.00
0005433234373	9847	Comfort	47400.00
0005434724996	9847	Comfort	47400.00
0005433289870	9847	Comfort	47400.00
0005434724663	9847	Comfort	47400.00
0005434551041	9847	Comfort	47400.00
0005434724323	9847	Comfort	47400.00
0005433234418	9847	Comfort	47400.00
0005433766650	9847	Comfort	47400.00
0005434725093	9847	Comfort	47400.00
0005434724989	9847	Economy	27900.00
0005434724587	9847	Comfort	47400.00
0005434724908	9847	Economy	27900.00
0005434724288	9847	Economy	27900.00
0005433129290	9847	Economy	27900.00
0005434725002	9847	Economy	27900.00
0005433234430	9847	Economy	27900.00
0005433289869	9847	Economy	27900.00
0005434735628	9847	Economy	27900.00
0005432199270	9847	Economy	27900.00
0005434725408	9847	Economy	27900.00
0005433181180	9847	Economy	27900.00
0005434032038	9847	Economy	27900.00
0005434551082	9847	Economy	27900.00
0005434550714	9847	Economy	27900.00
0005433766653	9847	Economy	27900.00
0005432199272	9847	Economy	27900.00
0005434735660	9847	Economy	27900.00
0005434550807	9847	Economy	27900.00
0005434724472	9847	Economy	27900.00
0005434724459	9847	Economy	27900.00
0005433126859	9847	Economy	27900.00
0005435142528	9847	Economy	27900.00
0005433766652	9847	Economy	27900.00
0005433234428	9847	Economy	27900.00
0005434724893	9847	Economy	27900.00
0005433234423	9847	Economy	27900.00
0005434724802	9847	Economy	27900.00
0005433234404	9847	Economy	27900.00
0005434302434	9847	Economy	27900.00
0005434725071	9847	Economy	27900.00
0005433181189	9847	Economy	27900.00
0005434724806	9847	Economy	27900.00
0005433234396	9847	Economy	27900.00
0005434724681	9847	Economy	27900.00
0005435142421	9847	Economy	27900.00
0005434724713	9847	Economy	27900.00
0005434724799	9847	Economy	27900.00
0005434551072	9847	Economy	27900.00
0005433234397	9847	Economy	27900.00
0005433181187	9847	Economy	27900.00
0005433181170	9847	Economy	27900.00
0005434551061	9847	Economy	27900.00
0005433234408	9847	Economy	27900.00
0005433234371	9847	Economy	27900.00
0005435142512	9847	Economy	27900.00
0005434724915	9847	Economy	27900.00
0005433234414	9847	Economy	27900.00
0005434724479	9847	Economy	27900.00
0005433234402	9847	Economy	27900.00
0005433181175	9847	Economy	27900.00
0005433181185	9847	Economy	27900.00
0005434302421	9847	Economy	27900.00
0005434731142	9847	Economy	27900.00
0005433181177	9847	Economy	27900.00
0005434551081	9847	Economy	27900.00
0005433126856	9847	Economy	27900.00
0005433181168	9847	Economy	27900.00
0005434724710	9847	Economy	27900.00
0005434724653	9847	Economy	27900.00
0005434550777	9847	Economy	27900.00
0005434724678	9847	Economy	30700.00
0005434724412	9847	Economy	30700.00
0005434725407	9847	Economy	30700.00
0005434725040	9847	Economy	27900.00
0005433234374	9847	Economy	30700.00
0005435142529	9847	Economy	27900.00
0005434731147	9847	Economy	30700.00
0005434724695	9847	Economy	30700.00
0005435142511	9847	Economy	27900.00
0005434724615	9847	Economy	27900.00
0005432199269	9847	Economy	27900.00
0005433234372	9847	Economy	27900.00
0005434550748	9847	Economy	27900.00
0005433234427	9847	Economy	27900.00
0005434724541	9847	Economy	27900.00
0005434724995	9847	Economy	27900.00
0005433289872	9847	Economy	27900.00
0005433234406	9847	Economy	27900.00
0005434724872	9847	Economy	27900.00
0005434724815	9847	Economy	27900.00
0005434550634	9847	Economy	27900.00
0005434302422	9847	Economy	27900.00
0005434724497	9847	Economy	27900.00
0005434725001	9847	Economy	27900.00
0005433113543	9847	Economy	27900.00
0005434735642	9847	Economy	27900.00
0005434550850	9847	Economy	27900.00
0005434724664	9847	Economy	27900.00
0005434550762	9847	Economy	27900.00
0005434724686	9847	Economy	27900.00
0005434724363	9847	Economy	27900.00
0005432199266	9847	Economy	27900.00
0005435142478	9847	Economy	27900.00
0005433234387	9847	Economy	27900.00
0005434724543	9847	Economy	27900.00
0005434724877	9847	Economy	27900.00
0005434724824	9847	Economy	27900.00
0005434551016	9847	Economy	27900.00
0005433181179	9847	Economy	27900.00
0005435142464	9847	Economy	27900.00
0005434550830	9847	Economy	27900.00
0005434550961	9847	Economy	27900.00
0005434724652	9847	Economy	27900.00
0005434724745	9847	Economy	27900.00
0005434724610	9847	Economy	27900.00
0005434724685	9847	Economy	27900.00
0005434550686	9847	Economy	27900.00
0005432199271	9847	Economy	27900.00
0005433126860	9847	Economy	27900.00
0005434550644	9847	Economy	27900.00
0005433234416	9847	Economy	27900.00
0005434550896	9847	Economy	27900.00
0005433234412	9847	Economy	27900.00
0005433234385	9847	Economy	27900.00
0005434724798	9847	Economy	27900.00
0005434724679	9847	Economy	27900.00
0005434551015	9847	Economy	27900.00
0005434724906	9847	Economy	27900.00
0005433234399	9847	Economy	27900.00
0005433181188	9847	Economy	27900.00
0005434550883	9847	Economy	27900.00
0005434550749	9847	Economy	27900.00
0005434724629	9847	Economy	27900.00
0005434550871	9847	Economy	27900.00
0005434550834	9847	Economy	27900.00
0005434724818	9847	Economy	27900.00
0005434550832	9847	Economy	27900.00
0005434724097	9847	Economy	27900.00
0005434725075	9847	Economy	27900.00
0005434731136	9847	Economy	27900.00
0005434550839	9847	Economy	27900.00
0005433234425	9847	Economy	27900.00
0005434724810	9847	Economy	27900.00
0005433289871	9847	Economy	27900.00
0005434550792	9847	Economy	27900.00
0005434724992	9847	Economy	27900.00
0005434550913	9847	Economy	27900.00
0005434724816	9847	Economy	27900.00
0005435142463	9847	Economy	27900.00
0005434724201	9847	Economy	27900.00
0005434550687	9847	Economy	27900.00
0005433234422	9847	Economy	27900.00
0005434724712	9847	Economy	27900.00
0005433234395	9847	Economy	27900.00
0005434735643	9847	Economy	27900.00
0005433234383	9847	Economy	27900.00
0005434724540	9847	Economy	27900.00
0005433181182	9847	Economy	27900.00
0005434725137	9847	Economy	27900.00
0005433181174	9847	Economy	27900.00
0005434550889	9847	Economy	27900.00
0005434550960	9847	Economy	27900.00
0005433181190	9847	Economy	27900.00
0005433234409	9847	Economy	27900.00
0005433234426	9847	Economy	27900.00
0005434724905	9847	Economy	27900.00
0005434302433	9847	Economy	27900.00
0005433289867	9847	Economy	27900.00
0005433234419	9847	Economy	27900.00
0005434724289	9847	Economy	27900.00
0005434724364	9847	Economy	27900.00
0005434731130	9847	Economy	27900.00
0005434724462	9847	Economy	27900.00
0005434724940	9847	Economy	27900.00
0005435142448	9847	Economy	27900.00
0005433234411	9847	Economy	27900.00
0005433181173	9847	Economy	30700.00
0005434724825	9847	Economy	27900.00
0005434724627	9847	Economy	30700.00
0005433234401	9847	Economy	30700.00
0005434550761	9847	Economy	30700.00
0005433234398	9847	Economy	27900.00
0005434724790	9847	Economy	27900.00
0005433234386	9847	Economy	27900.00
0005434724803	9847	Economy	27900.00
0005434724725	9847	Economy	27900.00
0005434724552	9847	Economy	27900.00
0005433129291	9847	Economy	27900.00
0005433234376	9847	Economy	27900.00
0005433129289	9847	Economy	27900.00
0005433234410	9847	Economy	27900.00
0005434302423	9847	Economy	27900.00
0005433234431	9847	Economy	27900.00
0005435142440	9847	Economy	27900.00
0005433289868	9847	Economy	27900.00
0005434724864	9847	Economy	27900.00
0005434302424	9847	Economy	27900.00
0005434724365	9847	Economy	27900.00
0005434735671	9847	Economy	27900.00
0005434551004	9847	Economy	27900.00
0005434724694	9847	Economy	27900.00
0005433234369	9847	Economy	27900.00
0005434724791	9847	Economy	27900.00
0005433113542	9847	Economy	27900.00
0005433234424	9847	Economy	27900.00
0005433234393	9847	Economy	27900.00
0005434550831	9847	Economy	27900.00
0005433234394	9847	Economy	27900.00
0005433234390	9847	Economy	27900.00
0005434550959	9847	Economy	27900.00
0005434731141	9847	Economy	27900.00
0005434551118	9847	Economy	27900.00
0005433234392	9847	Economy	27900.00
0005435142439	9847	Economy	27900.00
0005434724909	9847	Economy	27900.00
0005434551005	9847	Economy	27900.00
0005435142422	9847	Economy	27900.00
0005433181186	9847	Economy	27900.00
0005434032040	9847	Economy	27900.00
0005434724914	9847	Economy	27900.00
0005434724283	9847	Economy	27900.00
0005433234388	9847	Economy	27900.00
0005434724800	9847	Economy	27900.00
0005434550965	9847	Economy	27900.00
0005433234375	9847	Economy	27900.00
0005434724980	9847	Economy	27900.00
0005433234381	9847	Economy	27900.00
0005434735627	9847	Economy	27900.00
0005433234417	9847	Economy	27900.00
0005434550891	9847	Economy	27900.00
0005434724448	9847	Economy	27900.00
0005434724792	9847	Economy	27900.00
0005434724458	9847	Economy	27900.00
0005435142495	9847	Economy	27900.00
0005433234413	9847	Economy	27900.00
0005433234407	9847	Economy	27900.00
0005434725130	9847	Economy	27900.00
0005434724654	9847	Economy	27900.00
0005434550882	9847	Economy	27900.00
0005434724367	9847	Economy	27900.00
0005434550743	9847	Economy	27900.00
0005434724117	9847	Economy	27900.00
0005434724808	9847	Economy	27900.00
0005434550742	9847	Economy	27900.00
0005433234405	9847	Economy	27900.00
0005434550897	9847	Economy	27900.00
0005434550958	9847	Economy	27900.00
0005433289865	9847	Economy	27900.00
0005433234391	9847	Economy	27900.00
0005435142417	9847	Economy	27900.00
0005434724619	9847	Economy	27900.00
0005433234429	9847	Economy	27900.00
0005433181165	9847	Economy	27900.00
0005433234432	9847	Economy	27900.00
0005434724521	9847	Economy	27900.00
0005433234382	9847	Economy	27900.00
0005433289866	9847	Economy	27900.00
0005434724544	9847	Economy	27900.00
0005433234378	9847	Economy	27900.00
0005433234389	9847	Economy	27900.00
0005434724312	9847	Economy	27900.00
0005434724991	9847	Economy	27900.00
0005434724489	9847	Economy	27900.00
0005433181181	9847	Economy	27900.00
0005434550734	9847	Economy	27900.00
0005434731135	9847	Economy	27900.00
0005433234415	9847	Economy	27900.00
0005433234384	9847	Economy	27900.00
0005434724833	9847	Economy	27900.00
0005433126858	9847	Economy	27900.00
0005434724193	9847	Economy	27900.00
0005434032039	9847	Economy	27900.00
0005434724616	9847	Economy	27900.00
0005434551100	9847	Economy	27900.00
0005434724438	9847	Economy	27900.00
0005433234368	9847	Economy	27900.00
0005433181169	9847	Economy	27900.00
0005433234421	9847	Economy	27900.00
0005434724498	9847	Economy	27900.00
0005433766651	9847	Economy	27900.00
0005434550835	9847	Economy	27900.00
0005432528356	7755	Business	42100.00
0005435213016	7755	Business	42100.00
0005432528436	7755	Business	42100.00
0005435213175	7755	Business	42100.00
0005432528369	7755	Business	42100.00
0005432528347	7755	Business	42100.00
0005432528427	7755	Business	42100.00
0005432150221	7755	Business	42100.00
0005432528392	7755	Business	42100.00
0005435213344	7755	Business	42100.00
0005435213343	7755	Business	42100.00
0005435213041	7755	Business	42100.00
0005435213119	7755	Business	42100.00
0005432535847	7755	Business	42100.00
0005432069701	7755	Business	42100.00
0005435213176	7755	Business	42100.00
0005435213226	7755	Business	42100.00
0005432528405	7755	Business	42100.00
0005435212883	7755	Business	42100.00
0005435213186	7755	Business	42100.00
0005435213321	7755	Business	42100.00
0005434067808	7755	Business	42100.00
0005433656644	7755	Business	42100.00
0005432069700	7755	Business	42100.00
0005434067773	7755	Business	42100.00
0005434067768	7755	Business	42100.00
0005432528416	7755	Comfort	23900.00
0005432528353	7755	Comfort	23900.00
0005435212958	7755	Comfort	23900.00
0005435213442	7755	Comfort	23900.00
0005432528344	7755	Comfort	23900.00
0005432528424	7755	Comfort	23900.00
0005435213317	7755	Comfort	23900.00
0005432528384	7755	Comfort	23900.00
0005435212882	7755	Comfort	23900.00
0005432528380	7755	Comfort	23900.00
0005434067781	7755	Comfort	23900.00
0005432528438	7755	Comfort	23900.00
0005432150219	7755	Comfort	23900.00
0005434067789	7755	Comfort	23900.00
0005434067777	7755	Comfort	23900.00
0005435213048	7755	Comfort	23900.00
0005435212816	7755	Comfort	23900.00
0005432528421	7755	Comfort	23900.00
0005432528415	7755	Comfort	23900.00
0005435213168	7755	Comfort	23900.00
0005432528430	7755	Comfort	23900.00
0005432528374	7755	Comfort	23900.00
0005432528337	7755	Comfort	23900.00
0005435213120	7755	Comfort	23900.00
0005432528375	7755	Comfort	23900.00
0005432528376	7755	Comfort	23900.00
0005432528389	7755	Comfort	23900.00
0005435213451	7755	Comfort	23900.00
0005432528368	7755	Comfort	23900.00
0005434067759	7755	Comfort	23900.00
0005432528318	7755	Comfort	23900.00
0005435213053	7755	Comfort	23900.00
0005432528413	7755	Comfort	23900.00
0005432528410	7755	Comfort	23900.00
0005434067818	7755	Comfort	23900.00
0005434067762	7755	Comfort	23900.00
0005435630949	7755	Comfort	23900.00
0005434067785	7755	Comfort	23900.00
0005435213289	7755	Economy	14000.00
0005433656655	7755	Economy	14000.00
0005435213619	7755	Economy	14000.00
0005432069705	7755	Economy	14000.00
0005435213425	7755	Economy	14000.00
0005432533302	7755	Economy	14000.00
0005434067751	7755	Economy	14000.00
0005434067806	7755	Economy	14000.00
0005434067794	7755	Economy	14000.00
0005434067797	7755	Economy	14000.00
0005432528445	7755	Economy	14000.00
0005432528386	7755	Economy	14000.00
0005432528418	7755	Economy	14000.00
0005432528329	7755	Economy	14000.00
0005435213255	7755	Economy	14000.00
0005434067776	7755	Economy	14000.00
0005432528340	7755	Economy	14000.00
0005435213389	7755	Economy	14000.00
0005432528391	7755	Economy	14000.00
0005435213086	7755	Economy	14000.00
0005434067790	7755	Economy	14000.00
0005432069698	7755	Economy	14000.00
0005432528338	7755	Economy	14000.00
0005432150220	7755	Economy	14000.00
0005435213161	7755	Economy	14000.00
0005432528360	7755	Economy	14000.00
0005432528357	7755	Economy	14000.00
0005435213174	7755	Economy	14000.00
0005432528326	7755	Economy	14000.00
0005434067807	7755	Economy	14000.00
0005434067780	7755	Economy	14000.00
0005432528320	7755	Economy	14000.00
0005432428938	7755	Economy	14000.00
0005432528426	7755	Economy	14000.00
0005432150218	7755	Economy	14000.00
0005434067763	7755	Economy	14000.00
0005432528435	7755	Economy	14000.00
0005432528400	7755	Economy	14000.00
0005434067787	7755	Economy	14000.00
0005432528428	7755	Economy	14000.00
0005432528439	7755	Economy	14000.00
0005432528366	7755	Economy	14000.00
0005434067756	7755	Economy	14000.00
0005432069697	7755	Economy	14000.00
0005434067747	7755	Economy	14000.00
0005435213003	7755	Economy	14000.00
0005435213096	7755	Economy	14000.00
0005435630950	7755	Economy	14000.00
0005434067767	7755	Economy	14000.00
0005432528327	7755	Economy	14000.00
0005432528359	7755	Economy	14000.00
0005432535850	7755	Economy	14000.00
0005432528404	7755	Economy	14000.00
0005432528419	7755	Economy	14000.00
0005432528403	7755	Economy	14000.00
0005432528423	7755	Economy	14000.00
0005435213261	7755	Economy	14000.00
0005434067771	7755	Economy	14000.00
0005432528446	7755	Economy	14000.00
0005432528345	7755	Economy	14000.00
0005432528373	7755	Economy	14000.00
0005434067774	7755	Economy	14000.00
0005435213474	7755	Economy	14000.00
0005435213262	7755	Economy	15400.00
0005434067770	7755	Economy	15400.00
0005434067749	7755	Economy	14000.00
0005432528407	7755	Economy	15400.00
0005432069702	7755	Economy	14000.00
0005435213042	7755	Economy	15400.00
0005434067783	7755	Economy	14000.00
0005434067779	7755	Economy	14000.00
0005433656643	7755	Economy	14000.00
0005432528444	7755	Economy	14000.00
0005435213284	7755	Economy	14000.00
0005432528440	7755	Economy	14000.00
0005435213131	7755	Economy	14000.00
0005435212975	7755	Economy	14000.00
0005435212817	7755	Economy	14000.00
0005434067801	7755	Economy	14000.00
0005434067800	7755	Economy	14000.00
0005435212835	7755	Economy	14000.00
0005435213331	7755	Economy	14000.00
0005432528385	7755	Economy	14000.00
0005435213249	7755	Economy	14000.00
0005434067786	7755	Economy	14000.00
0005435213080	7755	Economy	14000.00
0005434067752	7755	Economy	14000.00
0005432537064	7755	Economy	14000.00
0005432528346	7755	Economy	14000.00
0005432535846	7755	Economy	14000.00
0005432528378	7755	Economy	14000.00
0005435213095	7755	Economy	14000.00
0005432528370	7755	Economy	14000.00
0005432528417	7755	Economy	14000.00
0005435213072	7755	Economy	14000.00
0005432528339	7755	Economy	14000.00
0005435213040	7755	Economy	14000.00
0005432528442	7755	Economy	14000.00
0005432528328	7755	Economy	14000.00
0005435213045	7755	Economy	14000.00
0005432069699	7755	Economy	14000.00
0005435213323	7755	Economy	14000.00
0005432428939	7755	Economy	14000.00
0005432528324	7755	Economy	14000.00
0005432528351	7755	Economy	14000.00
0005434067764	7755	Economy	14000.00
0005432528433	7755	Economy	14000.00
0005434067795	7755	Economy	14000.00
0005434067758	7755	Economy	14000.00
0005432528437	7755	Economy	14000.00
0005432528367	7755	Economy	14000.00
0005432533301	7755	Economy	14000.00
0005434067766	7755	Economy	14000.00
0005432528406	7755	Economy	14000.00
0005432528393	7755	Economy	14000.00
0005432528450	7755	Economy	14000.00
0005432528330	7755	Economy	14000.00
0005434067750	7755	Economy	14000.00
0005432528422	7755	Economy	14000.00
0005432528399	7755	Economy	14000.00
0005434067812	7755	Economy	14000.00
0005432528402	7755	Economy	14000.00
0005434067769	7755	Economy	14000.00
0005434067803	7755	Economy	14000.00
0005432528434	7755	Economy	14000.00
0005432528354	7755	Economy	14000.00
0005432528319	7755	Economy	14000.00
0005432069706	7755	Economy	14000.00
0005432150222	7755	Economy	14000.00
0005432528395	7755	Economy	14000.00
0005434067804	7755	Economy	14000.00
0005435213291	7755	Economy	14000.00
0005435212986	7755	Economy	14000.00
0005435213143	7755	Economy	14000.00
0005434067799	7755	Economy	14000.00
0005432528323	7755	Economy	14000.00
0005432528394	7755	Economy	14000.00
0005432528336	7755	Economy	14000.00
0005435213309	7755	Economy	14000.00
0005434067809	7755	Economy	14000.00
0005432069696	7755	Economy	14000.00
0005432528363	7755	Economy	14000.00
0005435213290	7755	Economy	14000.00
0005432528325	7755	Economy	14000.00
0005432528317	7755	Economy	14000.00
0005432528350	7755	Economy	14000.00
0005432528432	7755	Economy	14000.00
0005432528335	7755	Economy	14000.00
0005435213017	7755	Economy	14000.00
0005434067811	7755	Economy	14000.00
0005435725594	7755	Economy	14000.00
0005432528447	7755	Economy	14000.00
0005432528333	7755	Economy	14000.00
0005432528349	7755	Economy	14000.00
0005432528425	7755	Economy	14000.00
0005432535848	7755	Economy	14000.00
0005434067810	7755	Economy	14000.00
0005435213337	7755	Economy	14000.00
0005432069703	7755	Economy	14000.00
0005432528334	7755	Economy	14000.00
0005432533299	7755	Economy	14000.00
0005432533300	7755	Economy	14000.00
0005435213105	7755	Economy	14000.00
0005432528361	7755	Economy	14000.00
0005434067805	7755	Economy	14000.00
0005434067813	7755	Economy	14000.00
0005435212954	7755	Economy	15400.00
0005435213185	7755	Economy	15400.00
0005434067761	7755	Economy	15400.00
0005432528321	7755	Economy	15400.00
0005432528431	7755	Economy	15400.00
0005435213223	7755	Economy	14000.00
0005432069694	7755	Economy	14000.00
0005434067796	7755	Economy	14000.00
0005434067772	7755	Economy	14000.00
0005434067753	7755	Economy	14000.00
0005432528358	7755	Economy	14000.00
0005434067775	7755	Economy	14000.00
0005432069695	7755	Economy	14000.00
0005432528332	7755	Economy	14000.00
0005435213203	7755	Economy	14000.00
0005432528414	7755	Economy	14000.00
0005432528365	7755	Economy	14000.00
0005432528388	7755	Economy	14000.00
0005432528390	7755	Economy	14000.00
0005432428941	7755	Economy	14000.00
0005435213022	7755	Economy	14000.00
0005432528342	7755	Economy	14000.00
0005432528381	7755	Economy	14000.00
0005432528429	7755	Economy	14000.00
0005435213164	7755	Economy	14000.00
0005435212987	7755	Economy	14000.00
0005435213310	7755	Economy	14000.00
0005435213221	7755	Economy	14000.00
0005433656654	7755	Economy	14000.00
0005432528449	7755	Economy	14000.00
0005434067816	7755	Economy	14000.00
0005435213165	7755	Economy	14000.00
0005432528396	7755	Economy	14000.00
0005432528412	7755	Economy	14000.00
0005432528401	7755	Economy	14000.00
0005434067760	7755	Economy	14000.00
0005432528371	7755	Economy	14000.00
0005432535849	7755	Economy	14000.00
0005435212959	7755	Economy	14000.00
0005435213162	7755	Economy	14000.00
0005434067778	7755	Economy	14000.00
0005432528420	7755	Economy	14000.00
0005434067793	7755	Economy	14000.00
0005432528362	7755	Economy	14000.00
0005432528364	7755	Economy	14000.00
0005435213283	7755	Economy	14000.00
0005432528343	7755	Economy	14000.00
0005434067755	7755	Economy	14000.00
0005432528331	7755	Economy	14000.00
0005434067815	7755	Economy	14000.00
0005435213087	7755	Economy	14000.00
0005434067784	7755	Economy	14000.00
0005432528348	7755	Economy	14000.00
0005434067814	7755	Economy	14000.00
0005435213239	7755	Economy	14000.00
0005432069704	7755	Economy	14000.00
0005435212803	7755	Economy	14000.00
0005432528377	7755	Economy	14000.00
0005435212931	7755	Economy	14000.00
0005432528379	7755	Economy	14000.00
0005432528443	7755	Economy	14000.00
0005435213484	7755	Economy	14000.00
0005434067782	7755	Economy	14000.00
0005434067765	7755	Economy	14000.00
0005435213070	7755	Economy	14000.00
0005434067819	7755	Economy	14000.00
0005435213250	7755	Economy	14000.00
0005434067757	7755	Economy	14000.00
0005434067788	7755	Economy	14000.00
0005434067754	7755	Economy	14000.00
0005432528352	7755	Economy	14000.00
0005432528382	7755	Economy	14000.00
0005434067798	7755	Economy	14000.00
0005432150216	7755	Economy	14000.00
0005432528372	7755	Economy	14000.00
0005432528411	7755	Economy	14000.00
0005432528398	7755	Economy	14000.00
0005434067802	7755	Economy	14000.00
0005432528448	7755	Economy	14000.00
0005435213088	7755	Economy	14000.00
0005435213213	7755	Economy	14000.00
0005434067817	7755	Economy	14000.00
0005432528383	7755	Economy	14000.00
0005435213094	7755	Economy	14000.00
0005432528387	7755	Economy	14000.00
0005432428940	7755	Economy	14000.00
0005435213330	7755	Economy	14000.00
0005432537063	7755	Economy	14000.00
0005434067792	7755	Economy	14000.00
0005434067748	7755	Economy	14000.00
0005432528322	7755	Economy	14000.00
0005432528341	7755	Economy	14000.00
0005432150215	7755	Economy	14000.00
0005435213214	7755	Economy	14000.00
0005432528441	7755	Economy	14000.00
0005432528409	7755	Economy	14000.00
0005435213034	7755	Economy	14000.00
0005432528397	7755	Economy	14000.00
0005432528355	7755	Economy	14000.00
0005432069693	7755	Economy	14000.00
0005434067791	7755	Economy	14000.00
0005435213224	7755	Economy	14000.00
0005432150217	7755	Economy	14000.00
0005432528408	7755	Economy	14000.00
0005435613963	5328	Business	43100.00
0005435614004	5328	Business	43100.00
0005435614060	5328	Business	43100.00
0005432133263	5328	Business	43100.00
0005435302160	5328	Business	43100.00
0005435490237	5328	Business	43100.00
0005435613957	5328	Business	43100.00
0005434244834	5328	Business	43100.00
0005435614073	5328	Business	43100.00
0005434244882	5328	Business	43100.00
0005435424339	5328	Business	43100.00
0005435319537	5328	Business	43100.00
0005435614036	5328	Business	43100.00
0005435614009	5328	Business	43100.00
0005434244718	5328	Business	43100.00
0005434573396	5328	Business	43100.00
0005435613984	5328	Business	43100.00
0005435097234	5328	Business	43100.00
0005435613959	5328	Business	43100.00
0005434344355	5328	Business	43100.00
0005435614011	5328	Business	43100.00
0005435097225	5328	Business	43100.00
0005435319500	5328	Business	43100.00
0005434244821	5328	Business	43100.00
0005435614034	5328	Business	43100.00
0005434573402	5328	Business	43100.00
0005435613994	5328	Comfort	24400.00
0005435614050	5328	Comfort	24400.00
0005435305005	5328	Comfort	24400.00
0005435613995	5328	Comfort	24400.00
0005435424286	5328	Comfort	24400.00
0005435424290	5328	Comfort	24400.00
0005434344359	5328	Comfort	24400.00
0005432133251	5328	Comfort	24400.00
0005434244717	5328	Comfort	24400.00
0005435319548	5328	Comfort	24400.00
0005435614012	5328	Comfort	24400.00
0005434244750	5328	Comfort	24400.00
0005434344345	5328	Comfort	24400.00
0005435424224	5328	Comfort	24400.00
0005435613960	5328	Comfort	24400.00
0005435614031	5328	Comfort	24400.00
0005435424644	5328	Comfort	24400.00
0005435424267	5328	Comfort	24400.00
0005435424467	5328	Comfort	24400.00
0005434344349	5328	Comfort	24400.00
0005435424554	5328	Comfort	24400.00
0005435614041	5328	Comfort	24400.00
0005434344353	5328	Comfort	24400.00
0005435614003	5328	Comfort	24400.00
0005434573399	5328	Comfort	24400.00
0005434344346	5328	Comfort	24400.00
0005435097229	5328	Comfort	24400.00
0005434344337	5328	Comfort	24400.00
0005435424292	5328	Comfort	24400.00
0005433719112	5328	Comfort	24400.00
0005434344335	5328	Comfort	24400.00
0005435613986	5328	Comfort	24400.00
0005435490240	5328	Comfort	24400.00
0005433719111	5328	Comfort	24400.00
0005435305004	5328	Comfort	24400.00
0005432133256	5328	Comfort	24400.00
0005434656543	5328	Comfort	24400.00
0005434573397	5328	Comfort	24400.00
0005435380277	5328	Comfort	24400.00
0005435614039	5328	Comfort	24400.00
0005432133258	5328	Comfort	24400.00
0005434244833	5328	Economy	14400.00
0005435614027	5328	Economy	14400.00
0005435424560	5328	Economy	14400.00
0005432363389	5328	Economy	14400.00
0005435319480	5328	Economy	14400.00
0005435424528	5328	Economy	14400.00
0005435614048	5328	Economy	14400.00
0005435614071	5328	Economy	14400.00
0005435613980	5328	Economy	14400.00
0005434573398	5328	Economy	14400.00
0005435424658	5328	Economy	14400.00
0005432133265	5328	Economy	14400.00
0005435424663	5328	Economy	14400.00
0005434344343	5328	Economy	14400.00
0005435614028	5328	Economy	14400.00
0005435614064	5328	Economy	14400.00
0005435424312	5328	Economy	14400.00
0005434244901	5328	Economy	14400.00
0005435424439	5328	Economy	14400.00
0005435424030	5328	Economy	14400.00
0005434244753	5328	Economy	14400.00
0005435614014	5328	Economy	14400.00
0005432133262	5328	Economy	14400.00
0005434244779	5328	Economy	14400.00
0005435424643	5328	Economy	14400.00
0005434244741	5328	Economy	14400.00
0005434344357	5328	Economy	14400.00
0005435424813	5328	Economy	14400.00
0005435613998	5328	Economy	14400.00
0005435613988	5328	Economy	14400.00
0005435614000	5328	Economy	14400.00
0005435614058	5328	Economy	14400.00
0005435613958	5328	Economy	14400.00
0005434344329	5328	Economy	14400.00
0005435614023	5328	Economy	14400.00
0005435614059	5328	Economy	14400.00
0005432133260	5328	Economy	14400.00
0005434244870	5328	Economy	14400.00
0005434344347	5328	Economy	14400.00
0005432133252	5328	Economy	14400.00
0005435424629	5328	Economy	14400.00
0005435491445	5328	Economy	14400.00
0005432133250	5328	Economy	14400.00
0005435042845	5328	Economy	14400.00
0005435614019	5328	Economy	14400.00
0005435614074	5328	Economy	14400.00
0005435613987	5328	Economy	14400.00
0005434344326	5328	Economy	14400.00
0005435424409	5328	Economy	14400.00
0005435613977	5328	Economy	14400.00
0005435424387	5328	Economy	14400.00
0005435424420	5328	Economy	14400.00
0005432133264	5328	Economy	14400.00
0005434573395	5328	Economy	14400.00
0005435042839	5328	Economy	14400.00
0005435614062	5328	Economy	14400.00
0005435614068	5328	Economy	14400.00
0005434344334	5328	Economy	14400.00
0005434656542	5328	Economy	14400.00
0005435614030	5328	Economy	14400.00
0005435424307	5328	Economy	14400.00
0005435613969	5328	Economy	14400.00
0005435614066	5328	Economy	14400.00
0005435614067	5328	Economy	14400.00
0005435424327	5328	Economy	14400.00
0005434344342	5328	Economy	15800.00
0005435424459	5328	Economy	15800.00
0005435614063	5328	Economy	14400.00
0005435424498	5328	Economy	14400.00
0005435614054	5328	Economy	14400.00
0005434344339	5328	Economy	15800.00
0005435613968	5328	Economy	14400.00
0005435424549	5328	Economy	15800.00
0005435614013	5328	Economy	14400.00
0005434244783	5328	Economy	14400.00
0005434244892	5328	Economy	14400.00
0005435555374	5328	Economy	14400.00
0005435424268	5328	Economy	14400.00
0005435614016	5328	Economy	14400.00
0005434344325	5328	Economy	14400.00
0005435097227	5328	Economy	14400.00
0005435614053	5328	Economy	14400.00
0005435614037	5328	Economy	14400.00
0005435614055	5328	Economy	14400.00
0005432133254	5328	Economy	14400.00
0005433719114	5328	Economy	14400.00
0005435613985	5328	Economy	14400.00
0005435614024	5328	Economy	14400.00
0005435614010	5328	Economy	14400.00
0005435613972	5328	Economy	14400.00
0005435614015	5328	Economy	14400.00
0005435614046	5328	Economy	14400.00
0005435613990	5328	Economy	14400.00
0005435097226	5328	Economy	14400.00
0005432133255	5328	Economy	14400.00
0005434573403	5328	Economy	14400.00
0005435614021	5328	Economy	14400.00
0005435613967	5328	Economy	14400.00
0005435614032	5328	Economy	14400.00
0005435424422	5328	Economy	14400.00
0005435424553	5328	Economy	14400.00
0005435424432	5328	Economy	14400.00
0005435613964	5328	Economy	14400.00
0005435613993	5328	Economy	14400.00
0005434344352	5328	Economy	14400.00
0005435614026	5328	Economy	14400.00
0005435613976	5328	Economy	14400.00
0005434244784	5328	Economy	14400.00
0005434573392	5328	Economy	14400.00
0005434344341	5328	Economy	14400.00
0005435424320	5328	Economy	14400.00
0005435424321	5328	Economy	14400.00
0005435319525	5328	Economy	14400.00
0005435555375	5328	Economy	14400.00
0005435614038	5328	Economy	14400.00
0005434244900	5328	Economy	14400.00
0005434244854	5328	Economy	14400.00
0005435613982	5328	Economy	14400.00
0005435614001	5328	Economy	14400.00
0005434344361	5328	Economy	14400.00
0005435613989	5328	Economy	14400.00
0005434244785	5328	Economy	14400.00
0005435614018	5328	Economy	14400.00
0005435319547	5328	Economy	14400.00
0005435380279	5328	Economy	14400.00
0005434344344	5328	Economy	14400.00
0005435613979	5328	Economy	14400.00
0005435491447	5328	Economy	14400.00
0005435424547	5328	Economy	14400.00
0005432133259	5328	Economy	14400.00
0005432133257	5328	Economy	14400.00
0005434244883	5328	Economy	14400.00
0005435613974	5328	Economy	14400.00
0005435614057	5328	Economy	14400.00
0005434573390	5328	Economy	14400.00
0005435424243	5328	Economy	14400.00
0005435614065	5328	Economy	14400.00
0005435614005	5328	Economy	14400.00
0005434573393	5328	Economy	14400.00
0005435424499	5328	Economy	14400.00
0005434573400	5328	Economy	14400.00
0005435614051	5328	Economy	14400.00
0005435424686	5328	Economy	14400.00
0005435424820	5328	Economy	14400.00
0005434573394	5328	Economy	14400.00
0005434344360	5328	Economy	14400.00
0005435424701	5328	Economy	14400.00
0005435613997	5328	Economy	14400.00
0005435614025	5328	Economy	14400.00
0005435424349	5328	Economy	14400.00
0005435424388	5328	Economy	14400.00
0005435614006	5328	Economy	14400.00
0005435613973	5328	Economy	14400.00
0005435319528	5328	Economy	14400.00
0005435613991	5328	Economy	14400.00
0005435424473	5328	Economy	14400.00
0005435424685	5328	Economy	14400.00
0005435319507	5328	Economy	14400.00
0005435424603	5328	Economy	14400.00
0005435319543	5328	Economy	14400.00
0005435614070	5328	Economy	14400.00
0005434244830	5328	Economy	14400.00
0005434344328	5328	Economy	14400.00
0005434344351	5328	Economy	14400.00
0005435424517	5328	Economy	14400.00
0005435302159	5328	Economy	14400.00
0005434344330	5328	Economy	14400.00
0005435614040	5328	Economy	14400.00
0005434344333	5328	Economy	14400.00
0005435424617	5328	Economy	14400.00
0005434344332	5328	Economy	14400.00
0005435424548	5328	Economy	14400.00
0005434344338	5328	Economy	14400.00
0005434344358	5328	Economy	14400.00
0005435424581	5328	Economy	14400.00
0005435097235	5328	Economy	15800.00
0005434344348	5328	Economy	15800.00
0005435614029	5328	Economy	15800.00
0005435424662	5328	Economy	15800.00
0005435424031	5328	Economy	14400.00
0005435380278	5328	Economy	14400.00
0005435613975	5328	Economy	14400.00
0005435097230	5328	Economy	14400.00
0005435613965	5328	Economy	14400.00
0005435424470	5328	Economy	14400.00
0005435424595	5328	Economy	14400.00
0005432133261	5328	Economy	14400.00
0005435613981	5328	Economy	14400.00
0005434244775	5328	Economy	14400.00
0005435614052	5328	Economy	14400.00
0005435097228	5328	Economy	14400.00
0005435424742	5328	Economy	14400.00
0005435319499	5328	Economy	14400.00
0005435424656	5328	Economy	14400.00
0005434244817	5328	Economy	14400.00
0005435614061	5328	Economy	14400.00
0005435097231	5328	Economy	14400.00
0005435613971	5328	Economy	14400.00
0005435097233	5328	Economy	14400.00
0005434344356	5328	Economy	14400.00
0005435613999	5328	Economy	14400.00
0005435614044	5328	Economy	14400.00
0005435613978	5328	Economy	14400.00
0005435555376	5328	Economy	14400.00
0005435424262	5328	Economy	14400.00
0005435424503	5328	Economy	14400.00
0005434656540	5328	Economy	14400.00
0005435614047	5328	Economy	14400.00
0005435424657	5328	Economy	14400.00
0005435424469	5328	Economy	14400.00
0005435424460	5328	Economy	14400.00
0005432047562	5328	Economy	14400.00
0005435319479	5328	Economy	14400.00
0005435305006	5328	Economy	14400.00
0005435097232	5328	Economy	14400.00
0005435613962	5328	Economy	14400.00
0005434573391	5328	Economy	14400.00
0005435424437	5328	Economy	14400.00
0005435424266	5328	Economy	14400.00
0005435614056	5328	Economy	14400.00
0005435614007	5328	Economy	14400.00
0005435614043	5328	Economy	14400.00
0005435424348	5328	Economy	14400.00
0005435490238	5328	Economy	14400.00
0005435380270	5328	Economy	14400.00
0005434344340	5328	Economy	14400.00
0005435424289	5328	Economy	14400.00
0005435613983	5328	Economy	14400.00
0005435614008	5328	Economy	14400.00
0005432133253	5328	Economy	14400.00
0005435424421	5328	Economy	14400.00
0005432047561	5328	Economy	14400.00
0005434244742	5328	Economy	14400.00
0005434244891	5328	Economy	14400.00
0005435614033	5328	Economy	14400.00
0005435613961	5328	Economy	14400.00
0005435614035	5328	Economy	14400.00
0005435614022	5328	Economy	14400.00
0005432047563	5328	Economy	14400.00
0005435380280	5328	Economy	14400.00
0005435613966	5328	Economy	14400.00
0005435614072	5328	Economy	14400.00
0005435424412	5328	Economy	14400.00
0005435614069	5328	Economy	14400.00
0005432047560	5328	Economy	14400.00
0005435424558	5328	Economy	14400.00
0005434344331	5328	Economy	14400.00
0005435491446	5328	Economy	14400.00
0005434573401	5328	Economy	14400.00
0005435614017	5328	Economy	14400.00
0005434344327	5328	Economy	14400.00
0005435614002	5328	Economy	14400.00
0005435424411	5328	Economy	14400.00
0005435424557	5328	Economy	14400.00
0005433719123	5328	Economy	14400.00
0005435424519	5328	Economy	14400.00
0005435614042	5328	Economy	14400.00
0005435319536	5328	Economy	14400.00
0005435614075	5328	Economy	14400.00
0005435614020	5328	Economy	14400.00
0005435613992	5328	Economy	14400.00
0005435490239	5328	Economy	14400.00
0005435614049	5328	Economy	14400.00
0005434656545	5328	Economy	14400.00
0005434244822	5328	Economy	14400.00
0005435305003	5328	Economy	14400.00
0005435613996	5328	Economy	14400.00
0005434344354	5328	Economy	14400.00
0005434344350	5328	Economy	14400.00
0005435424410	5328	Economy	14400.00
0005434344336	5328	Economy	14400.00
0005435424468	5328	Economy	14400.00
0005435424438	5328	Economy	14400.00
0005435614045	5328	Economy	14400.00
0005434244776	5328	Economy	14400.00
0005435424624	5328	Economy	14400.00
0005435613970	5328	Economy	14400.00
0005435425029	10906	Business	43100.00
0005435097144	10906	Business	43100.00
0005434573226	10906	Business	43100.00
0005435612942	10906	Business	43100.00
0005435612802	10906	Business	43100.00
0005435319597	10906	Business	43100.00
0005435613452	10906	Business	43100.00
0005434343877	10906	Business	43100.00
0005435612817	10906	Business	43100.00
0005435425050	10906	Business	43100.00
0005435612734	10906	Business	43100.00
0005435612760	10906	Business	43100.00
0005435425020	10906	Business	43100.00
0005434245072	10906	Business	43100.00
0005435612577	10906	Business	43100.00
0005435612895	10906	Business	43100.00
0005434245062	10906	Business	43100.00
0005432841020	10906	Business	43100.00
0005435612726	10906	Business	43100.00
0005435613225	10906	Business	43100.00
0005435425015	10906	Business	43100.00
0005435097100	10906	Business	43100.00
0005435380305	10906	Business	43100.00
0005435613105	10906	Business	43100.00
0005435613247	10906	Business	43100.00
0005435425055	10906	Comfort	24400.00
0005435613057	10906	Comfort	24400.00
0005435425009	10906	Comfort	24400.00
0005435425036	10906	Comfort	24400.00
0005435319604	10906	Comfort	24400.00
0005435613194	10906	Comfort	24400.00
0005434245081	10906	Comfort	24400.00
0005434245060	10906	Comfort	24400.00
0005435613356	10906	Comfort	24400.00
0005435613480	10906	Comfort	24400.00
0005435612848	10906	Comfort	24400.00
0005435613372	10906	Comfort	24400.00
0005434573302	10906	Comfort	24400.00
0005435613272	10906	Comfort	24400.00
0005435490193	10906	Comfort	24400.00
0005435613056	10906	Comfort	24400.00
0005435613563	10906	Comfort	24400.00
0005434343944	10906	Comfort	24400.00
0005435425043	10906	Comfort	24400.00
0005435613099	10906	Comfort	24400.00
0005435612576	10906	Comfort	24400.00
0005434245074	10906	Comfort	24400.00
0005435424994	10906	Comfort	24400.00
0005435490194	10906	Comfort	24400.00
0005435612938	10906	Comfort	24400.00
0005434573288	10906	Comfort	24400.00
0005435613071	10906	Comfort	24400.00
0005435304168	10906	Comfort	24400.00
0005435319599	10906	Comfort	24400.00
0005435613107	10906	Comfort	24400.00
0005435612640	10906	Comfort	24400.00
0005434245066	10906	Comfort	24400.00
0005434344022	10906	Comfort	24400.00
0005434245070	10906	Comfort	24400.00
0005434343860	10906	Comfort	24400.00
0005435613129	10906	Comfort	24400.00
0005434245079	10906	Economy	14400.00
0005432363427	10906	Economy	14400.00
0005435613204	10906	Economy	14400.00
0005435425045	10906	Economy	14400.00
0005435612816	10906	Economy	14400.00
0005435425012	10906	Economy	14400.00
0005435319600	10906	Economy	14400.00
0005435613172	10906	Economy	14400.00
0005435612800	10906	Economy	14400.00
0005435613171	10906	Economy	14400.00
0005435613364	10906	Economy	14400.00
0005434245061	10906	Economy	14400.00
0005435425038	10906	Economy	14400.00
0005435097131	10906	Economy	14400.00
0005434245075	10906	Economy	14400.00
0005435425008	10906	Economy	14400.00
0005435425004	10906	Economy	14400.00
0005435097099	10906	Economy	14400.00
0005435612761	10906	Economy	14400.00
0005435425005	10906	Economy	14400.00
0005435613100	10906	Economy	14400.00
0005435613487	10906	Economy	14400.00
0005435613181	10906	Economy	14400.00
0005435424987	10906	Economy	14400.00
0005435097130	10906	Economy	14400.00
0005435425040	10906	Economy	14400.00
0005434245084	10906	Economy	14400.00
0005435319598	10906	Economy	14400.00
0005435612833	10906	Economy	14400.00
0005434343875	10906	Economy	14400.00
0005435613368	10906	Economy	14400.00
0005432165061	10906	Economy	14400.00
0005435612894	10906	Economy	14400.00
0005435613012	10906	Economy	14400.00
0005435613377	10906	Economy	14400.00
0005434245083	10906	Economy	14400.00
0005435613123	10906	Economy	14400.00
0005435425030	10906	Economy	14400.00
0005435424997	10906	Economy	14400.00
0005435612880	10906	Economy	14400.00
0005435612912	10906	Economy	14400.00
0005435613025	10906	Economy	14400.00
0005435424986	10906	Economy	14400.00
0005434656562	10906	Economy	14400.00
0005434343814	10906	Economy	14400.00
0005435612829	10906	Economy	14400.00
0005435424992	10906	Economy	14400.00
0005435613479	10906	Economy	14400.00
0005434343978	10906	Economy	14400.00
0005435612595	10906	Economy	14400.00
0005435425044	10906	Economy	14400.00
0005434245068	10906	Economy	14400.00
0005434573261	10906	Economy	14400.00
0005435613030	10906	Economy	14400.00
0005432165060	10906	Economy	14400.00
0005434245067	10906	Economy	15800.00
0005435612904	10906	Economy	15800.00
0005435612083	10906	Economy	15800.00
0005434343861	10906	Economy	14400.00
0005435304171	10906	Economy	14400.00
0005435612862	10906	Economy	14400.00
0005434245073	10906	Economy	14400.00
0005435613033	10906	Economy	15800.00
0005435424999	10906	Economy	15800.00
0005432165064	10906	Economy	15800.00
0005434344016	10906	Economy	14400.00
0005435424985	10906	Economy	14400.00
0005435612897	10906	Economy	14400.00
0005434245058	10906	Economy	14400.00
0005435425022	10906	Economy	14400.00
0005435097162	10906	Economy	14400.00
0005435319601	10906	Economy	14400.00
0005434343775	10906	Economy	14400.00
0005435424988	10906	Economy	14400.00
0005432166912	10906	Economy	14400.00
0005435425052	10906	Economy	14400.00
0005434343815	10906	Economy	14400.00
0005434245078	10906	Economy	14400.00
0005434573303	10906	Economy	14400.00
0005435613232	10906	Economy	14400.00
0005435612801	10906	Economy	14400.00
0005435613002	10906	Economy	14400.00
0005434343862	10906	Economy	14400.00
0005435425024	10906	Economy	14400.00
0005434343936	10906	Economy	14400.00
0005432166911	10906	Economy	14400.00
0005435613209	10906	Economy	14400.00
0005432165063	10906	Economy	14400.00
0005435425053	10906	Economy	14400.00
0005435319602	10906	Economy	14400.00
0005435613215	10906	Economy	14400.00
0005435304169	10906	Economy	14400.00
0005435612184	10906	Economy	14400.00
0005434344006	10906	Economy	14400.00
0005435425010	10906	Economy	14400.00
0005435612949	10906	Economy	14400.00
0005434245063	10906	Economy	14400.00
0005435097145	10906	Economy	14400.00
0005434343859	10906	Economy	14400.00
0005435097163	10906	Economy	14400.00
0005435424996	10906	Economy	14400.00
0005434344125	10906	Economy	14400.00
0005435613217	10906	Economy	14400.00
0005433719150	10906	Economy	14400.00
0005435613210	10906	Economy	14400.00
0005435097177	10906	Economy	14400.00
0005432165062	10906	Economy	14400.00
0005435612506	10906	Economy	14400.00
0005435380310	10906	Economy	14400.00
0005435612937	10906	Economy	14400.00
0005435425018	10906	Economy	14400.00
0005434245064	10906	Economy	14400.00
0005435425026	10906	Economy	14400.00
0005435612864	10906	Economy	14400.00
0005434343932	10906	Economy	14400.00
0005435613016	10906	Economy	14400.00
0005434343943	10906	Economy	14400.00
0005435613035	10906	Economy	14400.00
0005432165059	10906	Economy	14400.00
0005434245077	10906	Economy	14400.00
0005434343857	10906	Economy	14400.00
0005435425031	10906	Economy	14400.00
0005435424991	10906	Economy	14400.00
0005435380308	10906	Economy	14400.00
0005435612807	10906	Economy	14400.00
0005434343980	10906	Economy	14400.00
0005435425032	10906	Economy	14400.00
0005434343791	10906	Economy	14400.00
0005435425013	10906	Economy	14400.00
0005435319596	10906	Economy	14400.00
0005435613154	10906	Economy	14400.00
0005435612596	10906	Economy	14400.00
0005435613423	10906	Economy	14400.00
0005434343926	10906	Economy	14400.00
0005435612810	10906	Economy	14400.00
0005435612879	10906	Economy	14400.00
0005434344048	10906	Economy	14400.00
0005435612896	10906	Economy	14400.00
0005435613743	10906	Economy	14400.00
0005435491432	10906	Economy	14400.00
0005435612887	10906	Economy	14400.00
0005434343984	10906	Economy	14400.00
0005434573251	10906	Economy	14400.00
0005435304173	10906	Economy	14400.00
0005434245080	10906	Economy	14400.00
0005435613109	10906	Economy	14400.00
0005434343981	10906	Economy	14400.00
0005435613371	10906	Economy	14400.00
0005435613267	10906	Economy	14400.00
0005435304172	10906	Economy	14400.00
0005435425037	10906	Economy	14400.00
0005435425035	10906	Economy	14400.00
0005435612905	10906	Economy	14400.00
0005435613041	10906	Economy	14400.00
0005435424993	10906	Economy	14400.00
0005433719152	10906	Economy	14400.00
0005435613246	10906	Economy	14400.00
0005435612809	10906	Economy	14400.00
0005434343858	10906	Economy	14400.00
0005435613098	10906	Economy	14400.00
0005435425016	10906	Economy	14400.00
0005435424995	10906	Economy	14400.00
0005435613083	10906	Economy	14400.00
0005435613216	10906	Economy	14400.00
0005435042859	10906	Economy	14400.00
0005434245076	10906	Economy	14400.00
0005434656563	10906	Economy	14400.00
0005435304170	10906	Economy	15800.00
0005435490186	10906	Economy	14400.00
0005434343902	10906	Economy	15800.00
0005435613207	10906	Economy	15800.00
0005434344059	10906	Economy	15800.00
0005435425047	10906	Economy	15800.00
0005434344018	10906	Economy	15800.00
0005435425006	10906	Economy	14400.00
0005435612840	10906	Economy	14400.00
0005435613273	10906	Economy	14400.00
0005435097176	10906	Economy	14400.00
0005434343937	10906	Economy	14400.00
0005435319603	10906	Economy	14400.00
0005435612828	10906	Economy	14400.00
0005435425014	10906	Economy	14400.00
0005435490187	10906	Economy	14400.00
0005435425011	10906	Economy	14400.00
0005435425001	10906	Economy	14400.00
0005435380306	10906	Economy	14400.00
0005435613088	10906	Economy	14400.00
0005435380309	10906	Economy	14400.00
0005435425017	10906	Economy	14400.00
0005435613260	10906	Economy	14400.00
0005435425023	10906	Economy	14400.00
0005435612997	10906	Economy	14400.00
0005435613082	10906	Economy	14400.00
0005435612888	10906	Economy	14400.00
0005435425028	10906	Economy	14400.00
0005435612827	10906	Economy	14400.00
0005435097188	10906	Economy	14400.00
0005435425003	10906	Economy	14400.00
0005434245069	10906	Economy	14400.00
0005435613472	10906	Economy	14400.00
0005435613081	10906	Economy	14400.00
0005435612998	10906	Economy	14400.00
0005435612641	10906	Economy	14400.00
0005435613034	10906	Economy	14400.00
0005432841019	10906	Economy	14400.00
0005434245082	10906	Economy	14400.00
0005435425027	10906	Economy	14400.00
0005435613116	10906	Economy	14400.00
0005435425019	10906	Economy	14400.00
0005434245085	10906	Economy	14400.00
0005435613042	10906	Economy	14400.00
0005435424990	10906	Economy	14400.00
0005435425048	10906	Economy	14400.00
0005435425042	10906	Economy	14400.00
0005435490207	10906	Economy	14400.00
0005435613022	10906	Economy	14400.00
0005435425025	10906	Economy	14400.00
0005435425046	10906	Economy	14400.00
0005435612878	10906	Economy	14400.00
0005435613086	10906	Economy	14400.00
0005435425000	10906	Economy	14400.00
0005435425051	10906	Economy	14400.00
0005435612856	10906	Economy	14400.00
0005435425002	10906	Economy	14400.00
0005435425049	10906	Economy	14400.00
0005435613208	10906	Economy	14400.00
0005435612863	10906	Economy	14400.00
0005435424998	10906	Economy	14400.00
0005435612214	10906	Economy	14400.00
0005434343961	10906	Economy	14400.00
0005435612847	10906	Economy	14400.00
0005435042860	10906	Economy	14400.00
0005435425007	10906	Economy	14400.00
0005434343792	10906	Economy	14400.00
0005435380307	10906	Economy	14400.00
0005435097137	10906	Economy	14400.00
0005432363426	10906	Economy	14400.00
0005435425034	10906	Economy	14400.00
0005435613424	10906	Economy	14400.00
0005435490206	10906	Economy	14400.00
0005435613032	10906	Economy	14400.00
0005435612468	10906	Economy	14400.00
0005435613024	10906	Economy	14400.00
0005435613564	10906	Economy	14400.00
0005434343954	10906	Economy	14400.00
0005433719151	10906	Economy	14400.00
0005433719153	10906	Economy	14400.00
0005435613163	10906	Economy	14400.00
0005435424989	10906	Economy	14400.00
0005435612966	10906	Economy	14400.00
0005435613031	10906	Economy	14400.00
0005434245059	10906	Economy	14400.00
0005435490211	10906	Economy	14400.00
0005435613113	10906	Economy	14400.00
0005435425033	10906	Economy	14400.00
0005434245071	10906	Economy	14400.00
0005435612967	10906	Economy	14400.00
0005435425039	10906	Economy	14400.00
0005435613361	10906	Economy	14400.00
0005435425041	10906	Economy	14400.00
0005434245065	10906	Economy	14400.00
0005434245057	10906	Economy	14400.00
0005435425054	10906	Economy	14400.00
0005434344017	10906	Economy	14400.00
0005435613180	10906	Economy	14400.00
0005435613367	10906	Economy	14400.00
0005435425021	10906	Economy	14400.00
0005432165058	10906	Economy	14400.00
0005435613127	10906	Economy	14400.00
0005432459600	3293	Business	18800.00
0005433633922	3293	Business	18800.00
0005432181788	3293	Business	18800.00
0005433507239	3293	Business	18800.00
0005432181777	3293	Business	18800.00
0005433805485	3293	Business	18800.00
0005433633942	3293	Business	18800.00
0005433805479	3293	Business	18800.00
0005433633928	3293	Business	18800.00
0005433507245	3293	Business	18800.00
0005432459530	3293	Business	18800.00
0005432459406	3293	Business	18800.00
0005432459508	3293	Business	18800.00
0005433805501	3293	Business	18800.00
0005432181780	3293	Business	18800.00
0005432459510	3293	Business	18800.00
0005433805488	3293	Business	18800.00
0005433633938	3293	Business	18800.00
0005433805486	3293	Business	18800.00
0005432459595	3293	Business	18800.00
0005432459540	3293	Business	18800.00
0005433633911	3293	Business	18800.00
0005432181778	3293	Business	18800.00
0005433633927	3293	Business	18800.00
0005433507237	3293	Business	18800.00
0005433633920	3293	Economy	6900.00
0005432459564	3293	Economy	6900.00
0005432459646	3293	Economy	6900.00
0005433633917	3293	Economy	6900.00
0005433805481	3293	Economy	6900.00
0005433633929	3293	Economy	6300.00
0005433633936	3293	Economy	6300.00
0005433507242	3293	Economy	6300.00
0005432459659	3293	Economy	6300.00
0005433507240	3293	Economy	6300.00
0005433507244	3293	Economy	6300.00
0005433507241	3293	Economy	6300.00
0005432459565	3293	Economy	6300.00
0005432459539	3293	Economy	6300.00
0005432459632	3293	Economy	6300.00
0005432459468	3293	Economy	6300.00
0005433805497	3293	Economy	6300.00
0005432459370	3293	Economy	6300.00
0005433633931	3293	Economy	6300.00
0005432181794	3293	Economy	6300.00
0005432459599	3293	Economy	6300.00
0005433805491	3293	Economy	6300.00
0005432181783	3293	Economy	6300.00
0005432459529	3293	Economy	6300.00
0005432181795	3293	Economy	6300.00
0005432459526	3293	Economy	6300.00
0005432459479	3293	Economy	6300.00
0005432181785	3293	Economy	6300.00
0005433507247	3293	Economy	6300.00
0005433633919	3293	Economy	6300.00
0005433507238	3293	Economy	6300.00
0005433633925	3293	Economy	6300.00
0005432459627	3293	Economy	6300.00
0005433805484	3293	Economy	6300.00
0005433507236	3293	Economy	6300.00
0005432181789	3293	Economy	6300.00
0005432181781	3293	Economy	6300.00
0005433805477	3293	Economy	6300.00
0005433507243	3293	Economy	6300.00
0005433805487	3293	Economy	6300.00
0005432459601	3293	Economy	6300.00
0005433805483	3293	Economy	6300.00
0005432459724	3293	Economy	6300.00
0005432459511	3293	Economy	6300.00
0005432459475	3293	Economy	6300.00
0005432459581	3293	Economy	6300.00
0005433805503	3293	Economy	6300.00
0005433805505	3293	Economy	6300.00
0005432459753	3293	Economy	6300.00
0005432181776	3293	Economy	6300.00
0005432181796	3293	Economy	6300.00
0005432181793	3293	Economy	6300.00
0005432459562	3293	Economy	6300.00
0005433805494	3293	Economy	6300.00
0005432459801	3293	Economy	6300.00
0005432181784	3293	Economy	6300.00
0005432459630	3293	Economy	6300.00
0005433805492	3293	Economy	6300.00
0005432459558	3293	Economy	6300.00
0005433633935	3293	Economy	6300.00
0005432181779	3293	Economy	6300.00
0005433633926	3293	Economy	6300.00
0005432459664	3293	Economy	6300.00
0005432459505	3293	Economy	6300.00
0005433507235	3293	Economy	6300.00
0005432459692	3293	Economy	6900.00
0005433633932	3293	Economy	6900.00
0005433633937	3293	Economy	6900.00
0005433805482	3293	Economy	6900.00
0005433805478	3293	Economy	6300.00
0005432459463	3293	Economy	6300.00
0005433805499	3293	Economy	6300.00
0005433633913	3293	Economy	6300.00
0005433805489	3293	Economy	6900.00
0005433633940	3293	Economy	6300.00
0005432459536	3293	Economy	6300.00
0005433633915	3293	Economy	6300.00
0005433633914	3293	Economy	6300.00
0005432459582	3293	Economy	6300.00
0005432459800	3293	Economy	6300.00
0005433633923	3293	Economy	6300.00
0005432181792	3293	Economy	6300.00
0005432181782	3293	Economy	6300.00
0005433633918	3293	Economy	6300.00
0005433633945	3293	Economy	6300.00
0005433633941	3293	Economy	6300.00
0005433633939	3293	Economy	6300.00
0005432181787	3293	Economy	6300.00
0005433507234	3293	Economy	6300.00
0005433633916	3293	Economy	6300.00
0005433805502	3293	Economy	6300.00
0005433805480	3293	Economy	6300.00
0005433805490	3293	Economy	6300.00
0005433633943	3293	Economy	6300.00
0005432459474	3293	Economy	6300.00
0005433633933	3293	Economy	6300.00
0005432459554	3293	Economy	6300.00
0005432459464	3293	Economy	6300.00
0005432181791	3293	Economy	6300.00
0005432459563	3293	Economy	6300.00
0005432459663	3293	Economy	6300.00
0005432459662	3293	Economy	6300.00
0005433507249	3293	Economy	6300.00
0005433633924	3293	Economy	6300.00
0005432459522	3293	Economy	6300.00
0005432459345	3293	Economy	6300.00
0005433805504	3293	Economy	6300.00
0005433633912	3293	Economy	6300.00
0005433805498	3293	Economy	6300.00
0005433805495	3293	Economy	6300.00
0005432459695	3293	Economy	6300.00
0005432181797	3293	Economy	6300.00
0005432459757	3293	Economy	6300.00
0005433805500	3293	Economy	6300.00
0005432459429	3293	Economy	6300.00
0005432459693	3293	Economy	6300.00
0005432459694	3293	Economy	6300.00
0005433633934	3293	Economy	6300.00
0005432181786	3293	Economy	6300.00
0005432459336	3293	Economy	6300.00
0005432459177	3293	Economy	6300.00
0005432459502	3293	Economy	6300.00
0005433805496	3293	Economy	6300.00
0005432459509	3293	Economy	6300.00
0005432181775	3293	Economy	6300.00
0005432459593	3293	Economy	6300.00
0005432181790	3293	Economy	6300.00
0005432181798	3293	Economy	6300.00
0005432459535	3293	Economy	6300.00
0005433507250	3293	Economy	6300.00
0005433805493	3293	Economy	6300.00
0005432459521	3293	Economy	6300.00
0005433507248	3293	Economy	6300.00
0005433633921	3293	Economy	6300.00
0005433633944	3293	Economy	6300.00
0005433633930	3293	Economy	6300.00
0005432459197	3293	Economy	6300.00
0005433507246	3293	Economy	6300.00
0005432459631	3293	Economy	6300.00
0005435885228	3292	Business	18800.00
0005435885024	3292	Business	18800.00
0005435885078	3292	Business	18800.00
0005435885070	3292	Business	18800.00
0005435884944	3292	Business	18800.00
0005435884996	3292	Business	18800.00
0005435885086	3292	Business	18800.00
0005435885212	3292	Business	18800.00
0005435885196	3292	Business	18800.00
0005435884995	3292	Business	18800.00
0005435885028	3292	Business	18800.00
0005435885073	3292	Economy	6900.00
0005435885029	3292	Economy	6900.00
0005435884867	3292	Economy	6300.00
0005435884957	3292	Economy	6300.00
0005435885020	3292	Economy	6300.00
0005435885027	3292	Economy	6300.00
0005435884993	3292	Economy	6300.00
0005435884991	3292	Economy	6300.00
0005435885032	3292	Economy	6300.00
0005435885168	3292	Economy	6300.00
0005435884994	3292	Economy	6300.00
0005435884997	3292	Economy	6300.00
0005435884913	3292	Economy	6300.00
0005435884902	3292	Economy	6300.00
0005435885072	3292	Economy	6300.00
0005435884984	3292	Economy	6300.00
0005435885042	3292	Economy	6300.00
0005435885053	3292	Economy	6300.00
0005435885059	3292	Economy	6900.00
0005435885129	3292	Economy	6900.00
0005435884967	3292	Economy	6300.00
0005435885069	3292	Economy	6300.00
0005435885079	3292	Economy	6300.00
0005435885041	3292	Economy	6300.00
0005435885014	3292	Economy	6300.00
0005435885111	3292	Economy	6300.00
0005435884992	3292	Economy	6300.00
0005435885023	3292	Economy	6300.00
0005435885191	3292	Economy	6300.00
0005435885192	3292	Economy	6300.00
0005435884841	3292	Economy	6300.00
0005435885229	3292	Economy	6300.00
0005435884956	3292	Economy	6300.00
0005435885169	3292	Economy	6300.00
0005435884911	3292	Economy	6300.00
0005435884959	3292	Economy	6300.00
0005435885386	8326	Business	18800.00
0005435885382	8326	Business	18800.00
0005435885377	8326	Business	18800.00
0005432460055	8326	Business	18800.00
0005432460061	8326	Business	18800.00
0005432460034	8326	Business	18800.00
0005435885405	8326	Business	18800.00
0005435885388	8326	Business	18800.00
0005432460031	8326	Business	18800.00
0005435885397	8326	Business	18800.00
0005435885381	8326	Business	18800.00
0005432460042	8326	Business	18800.00
0005435885416	8326	Business	18800.00
0005432042764	8326	Business	18800.00
0005432460032	8326	Business	18800.00
0005435885383	8326	Business	18800.00
0005432460073	8326	Business	18800.00
0005432460054	8326	Business	18800.00
0005435885403	8326	Business	18800.00
0005432460048	8326	Business	18800.00
0005432460059	8326	Business	18800.00
0005435885410	8326	Business	18800.00
0005435885394	8326	Business	18800.00
0005435885412	8326	Business	18800.00
0005432460069	8326	Economy	6900.00
0005435885380	8326	Economy	6900.00
0005435885373	8326	Economy	6900.00
0005435885395	8326	Economy	6900.00
0005432460035	8326	Economy	6900.00
0005433507010	8326	Economy	6300.00
0005432460049	8326	Economy	6300.00
0005435885370	8326	Economy	6300.00
0005432460044	8326	Economy	6300.00
0005432042755	8326	Economy	6300.00
0005433507090	8326	Economy	6300.00
0005432460052	8326	Economy	6300.00
0005435885402	8326	Economy	6300.00
0005435885390	8326	Economy	6300.00
0005432460071	8326	Economy	6300.00
0005432042759	8326	Economy	6300.00
0005432460051	8326	Economy	6300.00
0005435885413	8326	Economy	6300.00
0005435885374	8326	Economy	6300.00
0005432042766	8326	Economy	6300.00
0005433507156	8326	Economy	6300.00
0005433507032	8326	Economy	6300.00
0005433507144	8326	Economy	6300.00
0005433507024	8326	Economy	6300.00
0005433507105	8326	Economy	6300.00
0005435885396	8326	Economy	6300.00
0005432460058	8326	Economy	6300.00
0005432460066	8326	Economy	6300.00
0005432042758	8326	Economy	6300.00
0005432460072	8326	Economy	6300.00
0005432042763	8326	Economy	6300.00
0005432460060	8326	Economy	6300.00
0005435885415	8326	Economy	6300.00
0005435885418	8326	Economy	6300.00
0005433507048	8326	Economy	6300.00
0005432460057	8326	Economy	6300.00
0005435885389	8326	Economy	6300.00
0005435885409	8326	Economy	6300.00
0005433507073	8326	Economy	6300.00
0005432460050	8326	Economy	6300.00
0005432042757	8326	Economy	6300.00
0005432042760	8326	Economy	6300.00
0005435885375	8326	Economy	6300.00
0005432042756	8326	Economy	6300.00
0005433507091	8326	Economy	6300.00
0005432460033	8326	Economy	6300.00
0005432460046	8326	Economy	6300.00
0005432460039	8326	Economy	6300.00
0005432460026	8326	Economy	6300.00
0005432460053	8326	Economy	6300.00
0005432460029	8326	Economy	6300.00
0005432460038	8326	Economy	6300.00
0005433507104	8326	Economy	6300.00
0005435885393	8326	Economy	6300.00
0005432460076	8326	Economy	6300.00
0005432042762	8326	Economy	6300.00
0005432460077	8326	Economy	6300.00
0005435885400	8326	Economy	6300.00
0005432460040	8326	Economy	6900.00
0005432460074	8326	Economy	6900.00
0005432460043	8326	Economy	6300.00
0005432042761	8326	Economy	6900.00
0005432460067	8326	Economy	6300.00
0005435885387	8326	Economy	6300.00
0005433507046	8326	Economy	6300.00
0005435885378	8326	Economy	6900.00
0005432460047	8326	Economy	6300.00
0005432460064	8326	Economy	6300.00
0005432042753	8326	Economy	6300.00
0005435885414	8326	Economy	6300.00
0005435885408	8326	Economy	6300.00
0005435885417	8326	Economy	6300.00
0005433507049	8326	Economy	6300.00
0005432460028	8326	Economy	6300.00
0005435885407	8326	Economy	6300.00
0005433506965	8326	Economy	6300.00
0005433507060	8326	Economy	6300.00
0005434312327	8326	Economy	6300.00
0005435885392	8326	Economy	6300.00
0005432460062	8326	Economy	6300.00
0005432460036	8326	Economy	6300.00
0005435885376	8326	Economy	6300.00
0005435885404	8326	Economy	6300.00
0005433507061	8326	Economy	6300.00
0005433507075	8326	Economy	6300.00
0005433507107	8326	Economy	6300.00
0005432460056	8326	Economy	6300.00
0005432460063	8326	Economy	6300.00
0005432460030	8326	Economy	6300.00
0005435885398	8326	Economy	6300.00
0005432460041	8326	Economy	6300.00
0005432460027	8326	Economy	6300.00
0005435885411	8326	Economy	6300.00
0005432460037	8326	Economy	6300.00
0005435885419	8326	Economy	6300.00
0005435885384	8326	Economy	6300.00
0005432460075	8326	Economy	6300.00
0005433507033	8326	Economy	6300.00
0005432460065	8326	Economy	6300.00
0005432460045	8326	Economy	6300.00
0005433507059	8326	Economy	6300.00
0005435885420	8326	Economy	6300.00
0005433507143	8326	Economy	6300.00
0005432460070	8326	Economy	6300.00
0005432460068	8326	Economy	6300.00
0005435885371	8326	Economy	6300.00
0005435885379	8326	Economy	6300.00
0005435885372	8326	Economy	6300.00
0005433507076	8326	Economy	6300.00
0005435885391	8326	Economy	6300.00
0005435885399	8326	Economy	6300.00
0005432042765	8326	Economy	6300.00
0005435885385	8326	Economy	6300.00
0005432042754	8326	Economy	6300.00
0005433507047	8326	Economy	6300.00
0005435885406	8326	Economy	6300.00
0005435885401	8326	Economy	6300.00
0005433507098	8326	Economy	6300.00
0005432460025	8326	Economy	6300.00
0005433805170	8328	Business	18800.00
0005433805233	8328	Business	18800.00
0005433633538	8328	Business	18800.00
0005433805115	8328	Business	18800.00
0005433805051	8328	Business	18800.00
0005433633527	8328	Business	18800.00
0005433805208	8328	Business	18800.00
0005433805019	8328	Business	18800.00
0005434143720	8328	Business	18800.00
0005433805126	8328	Business	18800.00
0005433633601	8328	Business	18800.00
0005433633621	8328	Business	18800.00
0005433633595	8328	Business	18800.00
0005433805084	8328	Business	18800.00
0005433633836	8328	Business	18800.00
0005433805321	8328	Business	18800.00
0005433633579	8328	Economy	6900.00
0005433805200	8328	Economy	6900.00
0005433805254	8328	Economy	6900.00
0005433633704	8328	Economy	6900.00
0005433633559	8328	Economy	6300.00
0005433633664	8328	Economy	6300.00
0005433805136	8328	Economy	6300.00
0005433805103	8328	Economy	6300.00
0005433805171	8328	Economy	6300.00
0005434143707	8328	Economy	6300.00
0005433633609	8328	Economy	6300.00
0005433633540	8328	Economy	6300.00
0005433633496	8328	Economy	6300.00
0005433633497	8328	Economy	6300.00
0005433633548	8328	Economy	6300.00
0005433805179	8328	Economy	6300.00
0005433805320	8328	Economy	6300.00
0005433633735	8328	Economy	6300.00
0005433633457	8328	Economy	6300.00
0005433633567	8328	Economy	6300.00
0005433633623	8328	Economy	6300.00
0005433805143	8328	Economy	6300.00
0005433633726	8328	Economy	6300.00
0005433633590	8328	Economy	6300.00
0005433805199	8328	Economy	6300.00
0005433633740	8328	Economy	6300.00
0005433633610	8328	Economy	6300.00
0005433805018	8328	Economy	6300.00
0005433805113	8328	Economy	6300.00
0005433805127	8328	Economy	6300.00
0005433633424	8328	Economy	6300.00
0005433805050	8328	Economy	6900.00
0005433805101	8328	Economy	6300.00
0005433805102	8328	Economy	6300.00
0005433633599	8328	Economy	6300.00
0005433805083	8328	Economy	6300.00
0005433805319	8328	Economy	6900.00
0005433633600	8328	Economy	6300.00
0005433805094	8328	Economy	6300.00
0005433805255	8328	Economy	6300.00
0005433805190	8328	Economy	6300.00
0005434143723	8328	Economy	6300.00
0005433633589	8328	Economy	6300.00
0005433633736	8328	Economy	6300.00
0005433633560	8328	Economy	6300.00
0005433805218	8328	Economy	6300.00
0005433805228	8328	Economy	6300.00
0005433633641	8328	Economy	6300.00
0005433805198	8328	Economy	6300.00
0005433633578	8328	Economy	6300.00
0005433805266	8328	Economy	6300.00
0005433805265	8328	Economy	6300.00
0005433805213	8328	Economy	6300.00
0005433805189	8328	Economy	6300.00
0005433633425	8328	Economy	6300.00
0005433805129	8328	Economy	6300.00
0005433805227	8328	Economy	6300.00
0005433805112	8328	Economy	6300.00
0005434143719	8328	Economy	6300.00
0005433633493	8328	Economy	6300.00
0005433805175	8328	Economy	6300.00
0005433633558	8328	Economy	6300.00
0005433633456	8328	Economy	6300.00
0005434143706	8328	Economy	6300.00
0005433805128	8328	Economy	6300.00
0005434271308	8328	Economy	6300.00
0005433805079	8328	Economy	6300.00
0005433805100	8328	Economy	6300.00
0005433805144	8328	Economy	6300.00
0005433633418	8328	Economy	6300.00
0005433805219	8328	Economy	6300.00
0005434271298	8328	Economy	6300.00
0005434183578	8330	Business	18800.00
0005434183572	8330	Economy	6300.00
0005432383290	4654	Business	9900.00
0005432383302	4654	Business	9900.00
0005432727979	4654	Business	9900.00
0005432383315	4654	Business	9900.00
0005432383295	4654	Business	9900.00
0005432383287	4654	Business	9900.00
0005432383316	4654	Business	9900.00
0005433722237	4654	Business	9900.00
0005432383296	4654	Business	9900.00
0005432383314	4654	Business	9900.00
0005432383293	4654	Economy	3300.00
0005432383299	4654	Economy	3300.00
0005432383301	4654	Economy	3300.00
0005432383311	4654	Economy	3300.00
0005432727973	4654	Economy	3300.00
0005432383291	4654	Economy	3300.00
0005433722244	4654	Economy	3300.00
0005433722238	4654	Economy	3600.00
0005432383310	4654	Economy	3600.00
0005432383283	4654	Economy	3600.00
0005432727980	4654	Economy	3300.00
0005432727972	4654	Economy	3300.00
0005432383309	4654	Economy	3300.00
0005432727975	4654	Economy	3300.00
0005432383306	4654	Economy	3300.00
0005432383285	4654	Economy	3300.00
0005432727982	4654	Economy	3300.00
0005432727983	4654	Economy	3300.00
0005433454881	4654	Economy	3300.00
0005432383288	4654	Economy	3300.00
0005432383281	4654	Economy	3300.00
0005432727978	4654	Economy	3300.00
0005432383298	4654	Economy	3300.00
0005432383282	4654	Economy	3300.00
0005432727974	4654	Economy	3300.00
0005432727984	4654	Economy	3300.00
0005432727977	4654	Economy	3300.00
0005432727976	4654	Economy	3300.00
0005432383308	4654	Economy	3300.00
0005432383284	4654	Economy	3300.00
0005433454882	4654	Economy	3300.00
0005432383280	4654	Economy	3300.00
0005432383300	4654	Economy	3300.00
0005433722245	4654	Economy	3300.00
0005433722243	4654	Economy	3300.00
0005432383292	4654	Economy	3300.00
0005432383307	4654	Economy	3300.00
0005432383312	4654	Economy	3300.00
0005432383297	4654	Economy	3300.00
0005432383289	4654	Economy	3300.00
0005432383294	4654	Economy	3300.00
0005432727981	4654	Economy	3300.00
0005433722241	4654	Economy	3300.00
0005433722240	4654	Economy	3300.00
0005433722239	4654	Economy	3300.00
0005432383305	4654	Economy	3300.00
0005432383313	4654	Economy	3300.00
0005432383303	4654	Economy	3300.00
0005432383304	4654	Economy	3300.00
0005432383286	4654	Economy	3300.00
0005433453768	4654	Economy	3300.00
0005432383279	4654	Economy	3300.00
0005433722242	4654	Economy	3300.00
0005432727847	30238	Business	9900.00
0005433451606	30238	Business	9900.00
0005432382821	30238	Business	9900.00
0005432382724	30238	Business	9900.00
0005432382853	30238	Business	9900.00
0005433194846	30238	Business	9900.00
0005432382834	30238	Economy	3300.00
0005432382924	30238	Economy	3300.00
0005432727849	30238	Economy	3300.00
0005432382893	30238	Economy	3300.00
0005432382923	30238	Economy	3300.00
0005433451607	30238	Economy	3300.00
0005432382850	30238	Economy	3600.00
0005433453749	30238	Economy	3600.00
0005433453747	30238	Economy	3600.00
0005432382891	30238	Economy	3300.00
0005432727807	30238	Economy	3300.00
0005432382807	30238	Economy	3300.00
0005432727846	30238	Economy	3300.00
0005432382725	30238	Economy	3300.00
0005433451602	30238	Economy	3300.00
0005432382941	30238	Economy	3300.00
0005432382843	30238	Economy	3300.00
0005432382822	30238	Economy	3300.00
0005432382842	30238	Economy	3300.00
0005433453751	30238	Economy	3300.00
0005432727926	30238	Economy	3300.00
0005432727840	30238	Economy	3300.00
0005432382999	30238	Economy	3300.00
0005432727925	30238	Economy	3300.00
0005433722169	30238	Economy	3300.00
0005432727910	30238	Economy	3300.00
0005432382927	30238	Economy	3300.00
0005433194833	30238	Economy	3300.00
0005432382582	30238	Economy	3300.00
0005432382728	30238	Economy	3300.00
0005433453748	30238	Economy	3300.00
0005432382866	30238	Economy	3300.00
0005432383011	30238	Economy	3300.00
0005432382775	30238	Economy	3300.00
0005432382583	30238	Economy	3300.00
0005432382854	30238	Economy	3300.00
0005432727839	30238	Economy	3300.00
0005432727848	30238	Economy	3300.00
0005432382823	30238	Economy	3300.00
0005432382864	30238	Economy	3300.00
0005432382966	30238	Economy	3300.00
0005432382939	30238	Economy	3300.00
0005433451603	30238	Economy	3300.00
0005432382729	30238	Economy	3300.00
0005432382894	30238	Economy	3300.00
0005432382809	30238	Economy	3300.00
0005432727855	30238	Economy	3300.00
0005432382796	30238	Economy	3300.00
0005432382858	30238	Economy	3300.00
0005433453752	30238	Economy	3300.00
0005432382849	30238	Economy	3300.00
0005432382754	30238	Economy	3300.00
0005433722167	30238	Economy	3300.00
0005432382808	30238	Economy	3300.00
0005435529329	1754	Business	57200.00
0005435541072	1754	Business	57200.00
0005435541081	1754	Business	57200.00
0005435529341	1754	Business	57200.00
0005433516912	1754	Business	57200.00
0005435541075	1754	Business	57200.00
0005432924978	1754	Business	57200.00
0005435529326	1754	Business	57200.00
0005435541080	1754	Business	57200.00
0005435529339	1754	Economy	19100.00
0005435541068	1754	Economy	19100.00
0005433516919	1754	Economy	19100.00
0005435541069	1754	Economy	19100.00
0005435529335	1754	Economy	19100.00
0005432294494	1754	Economy	19100.00
0005435529340	1754	Economy	19100.00
0005435529334	1754	Economy	19100.00
0005435541088	1754	Economy	21000.00
0005433516917	1754	Economy	19100.00
0005435541079	1754	Economy	19100.00
0005433516915	1754	Economy	19100.00
0005432294495	1754	Economy	19100.00
0005435529332	1754	Economy	19100.00
0005435541082	1754	Economy	19100.00
0005433516921	1754	Economy	19100.00
0005435541078	1754	Economy	19100.00
0005432925020	1754	Economy	19100.00
0005432294496	1754	Economy	19100.00
0005435541085	1754	Economy	19100.00
0005435529336	1754	Economy	19100.00
0005435541086	1754	Economy	19100.00
0005433516920	1754	Economy	19100.00
0005435541083	1754	Economy	19100.00
0005432294497	1754	Economy	19100.00
0005435529327	1754	Economy	19100.00
0005435541084	1754	Economy	19100.00
0005435541074	1754	Economy	19100.00
0005433516918	1754	Economy	19100.00
0005435541076	1754	Economy	19100.00
0005435529323	1754	Economy	19100.00
0005433516916	1754	Economy	19100.00
0005435541067	1754	Economy	19100.00
0005435529325	1754	Economy	19100.00
0005435529322	1754	Economy	19100.00
0005435529338	1754	Economy	19100.00
0005435541087	1754	Economy	19100.00
0005435529324	1754	Economy	19100.00
0005435529331	1754	Economy	19100.00
0005435529342	1754	Economy	19100.00
0005435529337	1754	Economy	19100.00
0005432925000	1754	Economy	19100.00
0005435541066	1754	Economy	19100.00
0005435529330	1754	Economy	19100.00
0005435529328	1754	Economy	19100.00
0005433516914	1754	Economy	19100.00
0005435541071	1754	Economy	19100.00
0005435529343	1754	Economy	19100.00
0005435541073	1754	Economy	19100.00
0005435541077	1754	Economy	19100.00
0005433516913	1754	Economy	19100.00
0005435541070	1754	Economy	19100.00
0005435529333	1754	Economy	19100.00
0005433516831	22006	Business	57200.00
0005435540825	22006	Business	57200.00
0005435540949	22006	Business	57200.00
0005433516846	22006	Business	57200.00
0005435540939	22006	Economy	19100.00
0005435540824	22006	Economy	19100.00
0005435540969	22006	Economy	21000.00
0005433516854	22006	Economy	21000.00
0005435517803	22006	Economy	19100.00
0005435517823	22006	Economy	19100.00
0005435540889	22006	Economy	19100.00
0005433516859	22006	Economy	19100.00
0005435540930	22006	Economy	19100.00
0005435540823	22006	Economy	19100.00
0005432925050	22006	Economy	19100.00
0005433516844	22006	Economy	19100.00
0005435540830	22006	Economy	19100.00
0005432925053	22006	Economy	19100.00
0005432925049	22006	Economy	19100.00
0005435517776	22006	Economy	19100.00
0005435540780	22006	Economy	19100.00
0005435540826	22006	Economy	19100.00
0005435517848	22006	Economy	19100.00
0005435540837	22006	Economy	19100.00
0005435540888	22006	Economy	19100.00
0005433516829	22006	Economy	19100.00
0005435517777	22006	Economy	19100.00
0005435540890	22006	Economy	19100.00
0005432925052	22006	Economy	19100.00
0005435517847	22006	Economy	19100.00
0005433516837	22006	Economy	19100.00
0005433516845	22006	Economy	19100.00
0005433516853	22006	Economy	19100.00
0005433516828	22006	Economy	19100.00
0005435540781	22006	Economy	19100.00
0005433516830	22006	Economy	19100.00
0005433516847	22006	Economy	19100.00
0005435517824	22006	Economy	19100.00
0005433516838	22006	Economy	19100.00
0005432925051	22006	Economy	19100.00
0005434664941	7396	Business	18500.00
0005434664948	7396	Business	18500.00
0005434458875	7396	Business	18500.00
0005434458871	7396	Business	18500.00
0005432839142	7396	Business	18500.00
0005432823455	7396	Business	18500.00
0005432839126	7396	Business	18500.00
0005434458868	7396	Business	18500.00
0005432839134	7396	Business	18500.00
0005432839128	7396	Business	18500.00
0005434458867	7396	Business	18500.00
0005432839129	7396	Business	18500.00
0005435252650	7396	Economy	6200.00
0005432839141	7396	Economy	6200.00
0005432839146	7396	Economy	6200.00
0005432839140	7396	Economy	6200.00
0005432839117	7396	Economy	6200.00
0005435252570	7396	Economy	6200.00
0005435252652	7396	Economy	6200.00
0005434458862	7396	Economy	6200.00
0005432839119	7396	Economy	6200.00
0005434458865	7396	Economy	6800.00
0005432839131	7396	Economy	6800.00
0005434458872	7396	Economy	6800.00
0005432839137	7396	Economy	6800.00
0005432073400	7396	Economy	6200.00
0005432839123	7396	Economy	6200.00
0005432839124	7396	Economy	6200.00
0005432839130	7396	Economy	6200.00
0005434664944	7396	Economy	6200.00
0005432839120	7396	Economy	6200.00
0005435252606	7396	Economy	6200.00
0005432839145	7396	Economy	6200.00
0005435252620	7396	Economy	6200.00
0005434458876	7396	Economy	6200.00
0005434458860	7396	Economy	6200.00
0005434458864	7396	Economy	6200.00
0005434458880	7396	Economy	6200.00
0005432839127	7396	Economy	6200.00
0005432839133	7396	Economy	6200.00
0005432839147	7396	Economy	6200.00
0005434458861	7396	Economy	6200.00
0005435252622	7396	Economy	6200.00
0005432839144	7396	Economy	6200.00
0005435252516	7396	Economy	6200.00
0005432839136	7396	Economy	6200.00
0005435252507	7396	Economy	6200.00
0005435252625	7396	Economy	6200.00
0005434458869	7396	Economy	6200.00
0005435252651	7396	Economy	6200.00
0005432839121	7396	Economy	6200.00
0005434458873	7396	Economy	6200.00
0005434458870	7396	Economy	6200.00
0005432839148	7396	Economy	6200.00
0005434664945	7396	Economy	6200.00
0005432839118	7396	Economy	6200.00
0005432073401	7396	Economy	6200.00
0005432839138	7396	Economy	6200.00
0005435252627	7396	Economy	6200.00
0005432839149	7396	Economy	6200.00
0005432839122	7396	Economy	6200.00
0005435252659	7396	Economy	6200.00
0005434458866	7396	Economy	6200.00
0005432839135	7396	Economy	6200.00
0005432841018	7396	Economy	6200.00
0005432839132	7396	Economy	6200.00
0005434664933	7396	Economy	6200.00
0005434458859	7396	Economy	6200.00
0005434458878	7396	Economy	6200.00
0005435252668	7396	Economy	6200.00
0005434664946	7396	Economy	6200.00
0005434458879	7396	Economy	6200.00
0005434458863	7396	Economy	6200.00
0005435252508	7396	Economy	6200.00
0005432839143	7396	Economy	6200.00
0005435252612	7396	Economy	6200.00
0005435252632	7396	Economy	6200.00
0005434458881	7396	Economy	6200.00
0005432841017	7396	Economy	6200.00
0005432073402	7396	Economy	6200.00
0005434664947	7396	Economy	6200.00
0005435252590	7396	Economy	6200.00
0005434458877	7396	Economy	6200.00
0005435252595	7396	Economy	6200.00
0005432839139	7396	Economy	6200.00
0005434664934	7396	Economy	6200.00
0005432839125	7396	Economy	6200.00
0005434458874	7396	Economy	6200.00
0005435252667	7396	Economy	6200.00
0005435252544	7396	Economy	6200.00
0005435252753	28933	Business	18500.00
0005432840995	28933	Business	18500.00
0005432838988	28933	Business	18500.00
0005434458630	28933	Business	18500.00
0005432838937	28933	Business	18500.00
0005432838934	28933	Business	18500.00
0005434664966	28933	Business	18500.00
0005432838932	28933	Business	18500.00
0005432823436	28933	Business	18500.00
0005432838873	28933	Business	18500.00
0005434458645	28933	Business	18500.00
0005434664968	28933	Business	18500.00
0005434458760	28933	Economy	6200.00
0005434664967	28933	Economy	6200.00
0005435252761	28933	Economy	6200.00
0005432838909	28933	Economy	6200.00
0005432838936	28933	Economy	6200.00
0005435252757	28933	Economy	6200.00
0005434458791	28933	Economy	6200.00
0005432838908	28933	Economy	6200.00
0005432839022	28933	Economy	6200.00
0005434458726	28933	Economy	6200.00
0005434664969	28933	Economy	6800.00
0005432838979	28933	Economy	6800.00
0005432823435	28933	Economy	6800.00
0005432838843	28933	Economy	6800.00
0005432838821	28933	Economy	6800.00
0005432838989	28933	Economy	6200.00
0005432841001	28933	Economy	6200.00
0005434458693	28933	Economy	6200.00
0005432838935	28933	Economy	6200.00
0005432838973	28933	Economy	6200.00
0005432838875	28933	Economy	6200.00
0005434458703	28933	Economy	6200.00
0005432838983	28933	Economy	6200.00
0005434458737	28933	Economy	6200.00
0005432838876	28933	Economy	6200.00
0005432838913	28933	Economy	6200.00
0005432001030	28933	Economy	6200.00
0005432838877	28933	Economy	6200.00
0005434458629	28933	Economy	6200.00
0005434458732	28933	Economy	6200.00
0005434458719	28933	Economy	6200.00
0005434458762	28933	Economy	6200.00
0005434458782	28933	Economy	6200.00
0005432838895	28933	Economy	6200.00
0005435252756	28933	Economy	6200.00
0005434458731	28933	Economy	6200.00
0005434458713	28933	Economy	6200.00
0005434458646	28933	Economy	6200.00
0005434458725	28933	Economy	6200.00
0005432838912	28933	Economy	6200.00
0005432838878	28933	Economy	6200.00
0005434458720	28933	Economy	6200.00
0005432838894	28933	Economy	6200.00
0005432838826	28933	Economy	6200.00
0005432838842	28933	Economy	6200.00
0005434664970	28933	Economy	6200.00
0005434458704	28933	Economy	6200.00
0005432838822	28933	Economy	6200.00
0005434458781	28933	Economy	6200.00
0005432838804	28933	Economy	6200.00
0005435252762	28933	Economy	6200.00
0005432838902	28933	Economy	6200.00
0005432838978	28933	Economy	6200.00
0005435252765	28933	Economy	6200.00
0005432838827	28933	Economy	6200.00
0005432838914	28933	Economy	6200.00
0005434458788	28933	Economy	6200.00
0005432838787	28933	Economy	6200.00
0005435252764	28933	Economy	6200.00
0005434458712	28933	Economy	6200.00
0005435252754	28933	Economy	6200.00
0005432838933	28933	Economy	6200.00
0005435252752	28933	Economy	6200.00
0005434458687	28933	Economy	6200.00
0005432838949	28933	Economy	6200.00
0005432838794	28933	Economy	6200.00
0005432838874	28933	Economy	6200.00
0005434458761	28933	Economy	6200.00
0005434458666	28933	Economy	6200.00
0005432838900	28933	Economy	6200.00
0005432838915	28933	Economy	6200.00
0005432838838	28933	Economy	6200.00
0005432838970	28933	Economy	6200.00
0005432838741	28933	Economy	6200.00
0005435252759	28933	Economy	6200.00
0005434458686	28933	Economy	6200.00
0005435252758	28933	Economy	6200.00
0005435252763	28933	Economy	6200.00
0005435252760	28933	Economy	6200.00
0005432838871	28933	Economy	6200.00
0005432838872	28933	Economy	6200.00
0005435252755	28933	Economy	6200.00
0005432841000	28933	Economy	6200.00
0005432838980	28933	Economy	6200.00
0005432841016	28933	Economy	6200.00
0005434276007	8814	Business	145300.00
0005435990647	8814	Business	145300.00
0005434275993	8814	Economy	53300.00
0005435990645	8814	Economy	53300.00
0005434276009	8814	Economy	48400.00
0005435990646	8814	Economy	48400.00
0005434276008	8814	Economy	48400.00
0005434276010	8814	Economy	48400.00
0005435990648	8814	Economy	48400.00
0005435990644	8814	Economy	48400.00
0005435990642	8814	Economy	48400.00
0005435990643	8814	Economy	48400.00
0005435990649	8814	Economy	48400.00
0005434276045	15728	Business	145300.00
0005434276043	15728	Business	145300.00
0005434276048	15728	Economy	48400.00
0005435990594	15728	Economy	48400.00
0005434276044	15728	Economy	48400.00
0005434276046	15728	Economy	48400.00
0005435990596	15728	Economy	48400.00
0005435990598	15728	Economy	48400.00
0005435990595	15728	Economy	48400.00
0005435990608	15728	Economy	48400.00
0005434276047	15728	Economy	48400.00
0005434276042	15728	Economy	48400.00
0005432427145	20629	Economy	14500.00
0005432427144	20629	Economy	14500.00
0005433476876	20629	Economy	14500.00
0005432427149	20629	Economy	14500.00
0005433476882	20629	Economy	14500.00
0005433476877	20629	Economy	14500.00
0005432427148	20629	Economy	14500.00
0005432427146	20629	Economy	14500.00
0005433476881	20629	Economy	14500.00
0005432427150	20629	Economy	14500.00
0005433476883	20629	Economy	14500.00
0005432427147	20629	Economy	14500.00
0005432427125	30848	Economy	14500.00
0005433476897	30848	Economy	14500.00
0005432427135	30848	Economy	14500.00
0005432427134	30848	Economy	14500.00
0005432427126	30848	Economy	14500.00
0005433476898	30848	Economy	14500.00
0005432427131	30848	Economy	14500.00
0005432427117	30848	Economy	14500.00
0005433476900	30848	Economy	14500.00
0005433476896	30848	Economy	14500.00
0005432427130	30848	Economy	14500.00
0005433476899	30848	Economy	14500.00
0005433468277	23853	Economy	13300.00
0005433468260	23853	Economy	13300.00
0005432909298	23853	Economy	12100.00
0005433468265	23853	Economy	12100.00
0005432909303	23853	Economy	12100.00
0005433468270	23853	Economy	12100.00
0005433468284	23853	Economy	12100.00
0005433468276	23853	Economy	12100.00
0005432909295	23853	Economy	12100.00
0005433468256	23853	Economy	12100.00
0005433468288	23853	Economy	12100.00
0005433468258	23853	Economy	12100.00
0005432909297	23853	Economy	12100.00
0005433468273	23853	Economy	12100.00
0005432909300	23853	Economy	12100.00
0005433468263	23853	Economy	12100.00
0005433468257	23853	Economy	12100.00
0005433468309	23853	Economy	12100.00
0005433468295	23853	Economy	12100.00
0005433468269	23853	Economy	12100.00
0005432909304	23853	Economy	12100.00
0005432909296	23853	Economy	12100.00
0005432909302	23853	Economy	12100.00
0005433468262	23853	Economy	12100.00
0005433468294	23853	Economy	12100.00
0005433468250	23853	Economy	12100.00
0005433468238	23853	Economy	12100.00
0005433468264	23853	Economy	12100.00
0005432909299	23853	Economy	12100.00
0005432909301	23853	Economy	12100.00
0005432360498	6383	Business	36600.00
0005432336075	6383	Business	36600.00
0005432062246	6383	Business	36600.00
0005432360501	6383	Business	36600.00
0005435490194	6383	Business	36600.00
0005432360518	6383	Business	36600.00
0005432360514	6383	Business	36600.00
0005432360503	6383	Business	36600.00
0005432360509	6383	Business	36600.00
0005435176931	6383	Business	36600.00
0005434149669	6383	Economy	12200.00
0005435490207	6383	Economy	12200.00
0005435177033	6383	Economy	12200.00
0005432360533	6383	Economy	12200.00
0005435176864	6383	Economy	12200.00
0005432360515	6383	Economy	12200.00
0005435490187	6383	Economy	12200.00
0005432360539	6383	Economy	12200.00
0005432360490	6383	Economy	12200.00
0005432360536	6383	Economy	12200.00
0005432360492	6383	Economy	12200.00
0005434149683	6383	Economy	12200.00
0005432360506	6383	Economy	12200.00
0005432363426	6383	Economy	12200.00
0005435177007	6383	Economy	12200.00
0005432360512	6383	Economy	12200.00
0005432062247	6383	Economy	12200.00
0005435176956	6383	Economy	12200.00
0005434149719	6383	Economy	12200.00
0005435176971	6383	Economy	12200.00
0005432360494	6383	Economy	12200.00
0005432360522	6383	Economy	12200.00
0005432360500	6383	Economy	12200.00
0005432360491	6383	Economy	12200.00
0005432360513	6383	Economy	12200.00
0005432360534	6383	Economy	12200.00
0005434149682	6383	Economy	12200.00
0005434149611	6383	Economy	12200.00
0005432360496	6383	Economy	12200.00
0005435176955	6383	Economy	12200.00
0005432360528	6383	Economy	12200.00
0005435176912	6383	Economy	13400.00
0005435176980	6383	Economy	13400.00
0005432360524	6383	Economy	13400.00
0005432360508	6383	Economy	13400.00
0005434149711	6383	Economy	12200.00
0005432336066	6383	Economy	12200.00
0005432360521	6383	Economy	12200.00
0005432363427	6383	Economy	12200.00
0005432360505	6383	Economy	12200.00
0005435176894	6383	Economy	12200.00
0005432336067	6383	Economy	12200.00
0005435176867	6383	Economy	12200.00
0005435176844	6383	Economy	12200.00
0005435176981	6383	Economy	12200.00
0005432336069	6383	Economy	12200.00
0005432360520	6383	Economy	12200.00
0005432360497	6383	Economy	12200.00
0005435177016	6383	Economy	12200.00
0005432360502	6383	Economy	12200.00
0005432360507	6383	Economy	12200.00
0005432360499	6383	Economy	12200.00
0005435490211	6383	Economy	12200.00
0005435490206	6383	Economy	12200.00
0005435177027	6383	Economy	12200.00
0005432336071	6383	Economy	12200.00
0005432360510	6383	Economy	12200.00
0005435490193	6383	Economy	12200.00
0005432336073	6383	Economy	12200.00
0005432336077	6383	Economy	12200.00
0005435176848	6383	Economy	12200.00
0005435176868	6383	Economy	12200.00
0005435177028	6383	Economy	12200.00
0005435176849	6383	Economy	12200.00
0005432360527	6383	Economy	12200.00
0005432336076	6383	Economy	12200.00
0005434149712	6383	Economy	12200.00
0005432062243	6383	Economy	12200.00
0005432360517	6383	Economy	12200.00
0005432360516	6383	Economy	12200.00
0005434149696	6383	Economy	12200.00
0005432360526	6383	Economy	12200.00
0005432360530	6383	Economy	12200.00
0005432336070	6383	Economy	12200.00
0005432360538	6383	Economy	12200.00
0005432360504	6383	Economy	12200.00
0005435176863	6383	Economy	12200.00
0005432360532	6383	Economy	12200.00
0005432360535	6383	Economy	12200.00
0005432360537	6383	Economy	12200.00
0005435177080	6383	Economy	12200.00
0005432336074	6383	Economy	12200.00
0005432360511	6383	Economy	12200.00
0005432360531	6383	Economy	12200.00
0005432062244	6383	Economy	12200.00
0005432360519	6383	Economy	12200.00
0005434149668	6383	Economy	12200.00
0005432336068	6383	Economy	12200.00
0005432360529	6383	Economy	12200.00
0005435490186	6383	Economy	12200.00
0005432062245	6383	Economy	12200.00
0005432336072	6383	Economy	12200.00
0005435177008	6383	Economy	12200.00
0005432360495	6383	Economy	12200.00
0005432360523	6383	Economy	12200.00
0005434149640	6383	Economy	12200.00
0005432360493	6383	Economy	12200.00
0005432360525	6383	Economy	12200.00
0005432360048	21016	Business	36600.00
0005435177174	21016	Business	36600.00
0005435177154	21016	Business	36600.00
0005434149768	21016	Business	36600.00
0005432359957	21016	Business	36600.00
0005432360076	21016	Business	36600.00
0005435177175	21016	Business	36600.00
0005435177165	21016	Business	36600.00
0005435177152	21016	Business	36600.00
0005435177171	21016	Business	36600.00
0005432360333	21016	Economy	12200.00
0005435177159	21016	Economy	12200.00
0005432360058	21016	Economy	12200.00
0005432360090	21016	Economy	12200.00
0005435177158	21016	Economy	12200.00
0005432363391	21016	Economy	12200.00
0005432360124	21016	Economy	12200.00
0005432360151	21016	Economy	12200.00
0005435490244	21016	Economy	12200.00
0005432335985	21016	Economy	12200.00
0005432336015	21016	Economy	12200.00
0005432360123	21016	Economy	12200.00
0005435490242	21016	Economy	12200.00
0005432335961	21016	Economy	12200.00
0005432363392	21016	Economy	12200.00
0005432360104	21016	Economy	12200.00
0005435177169	21016	Economy	12200.00
0005434149771	21016	Economy	12200.00
0005434149762	21016	Economy	12200.00
0005432360150	21016	Economy	12200.00
0005432360024	21016	Economy	12200.00
0005432360341	21016	Economy	12200.00
0005432360077	21016	Economy	12200.00
0005435177153	21016	Economy	12200.00
0005432360107	21016	Economy	12200.00
0005435177163	21016	Economy	12200.00
0005432363393	21016	Economy	12200.00
0005432360130	21016	Economy	12200.00
0005435177161	21016	Economy	12200.00
0005432360143	21016	Economy	12200.00
0005434149765	21016	Economy	12200.00
0005432360262	21016	Economy	12200.00
0005432360136	21016	Economy	12200.00
0005432363394	21016	Economy	12200.00
0005432359919	21016	Economy	12200.00
0005432360138	21016	Economy	13400.00
0005434149763	21016	Economy	13400.00
0005435177172	21016	Economy	13400.00
0005432335953	21016	Economy	13400.00
0005432052757	21016	Economy	13400.00
0005432360270	21016	Economy	13400.00
0005432360095	21016	Economy	12200.00
0005432360106	21016	Economy	12200.00
0005432359898	21016	Economy	12200.00
0005434149772	21016	Economy	12200.00
0005432052755	21016	Economy	12200.00
0005432360246	21016	Economy	12200.00
0005432359910	21016	Economy	12200.00
0005432359908	21016	Economy	12200.00
0005435177166	21016	Economy	12200.00
0005432335949	21016	Economy	12200.00
0005435177173	21016	Economy	12200.00
0005435177155	21016	Economy	12200.00
0005432363396	21016	Economy	12200.00
0005435177151	21016	Economy	12200.00
0005432360098	21016	Economy	12200.00
0005434149769	21016	Economy	12200.00
0005432360132	21016	Economy	12200.00
0005432335959	21016	Economy	12200.00
0005434149773	21016	Economy	12200.00
0005434149770	21016	Economy	12200.00
0005432360109	21016	Economy	12200.00
0005432363397	21016	Economy	12200.00
0005434149766	21016	Economy	12200.00
0005432360284	21016	Economy	12200.00
0005432363405	21016	Economy	12200.00
0005432360097	21016	Economy	12200.00
0005432360096	21016	Economy	12200.00
0005432360010	21016	Economy	12200.00
0005435177157	21016	Economy	12200.00
0005435177156	21016	Economy	12200.00
0005435723053	21016	Economy	12200.00
0005432360137	21016	Economy	12200.00
0005435177150	21016	Economy	12200.00
0005435177160	21016	Economy	12200.00
0005432360133	21016	Economy	12200.00
0005432335952	21016	Economy	12200.00
0005432335927	21016	Economy	12200.00
0005432052754	21016	Economy	12200.00
0005432335958	21016	Economy	12200.00
0005434149767	21016	Economy	12200.00
0005432359906	21016	Economy	12200.00
0005432360031	21016	Economy	12200.00
0005432360013	21016	Economy	12200.00
0005432360149	21016	Economy	12200.00
0005435177149	21016	Economy	12200.00
0005432359909	21016	Economy	12200.00
0005432360129	21016	Economy	12200.00
0005434149761	21016	Economy	12200.00
0005432363402	21016	Economy	12200.00
0005435490241	21016	Economy	12200.00
0005432360342	21016	Economy	12200.00
0005432360089	21016	Economy	12200.00
0005432360263	21016	Economy	12200.00
0005435490243	21016	Economy	12200.00
0005432359996	21016	Economy	12200.00
0005435177168	21016	Economy	12200.00
0005435490245	21016	Economy	12200.00
0005434149764	21016	Economy	12200.00
0005432052756	21016	Economy	12200.00
0005435177167	21016	Economy	12200.00
0005432335948	21016	Economy	12200.00
0005432360141	21016	Economy	12200.00
0005432360271	21016	Economy	12200.00
0005432335928	21016	Economy	12200.00
0005432359811	21016	Economy	12200.00
0005435177162	21016	Economy	12200.00
0005435177170	21016	Economy	12200.00
0005435177176	21016	Economy	12200.00
0005435177164	21016	Economy	12200.00
0005434458745	17713	Economy	3400.00
0005434186208	17713	Economy	3400.00
0005434458705	17713	Economy	3400.00
0005434448300	17713	Economy	3100.00
0005434458633	17713	Economy	3100.00
0005434458702	17713	Economy	3100.00
0005434458662	17713	Economy	3100.00
0005434186209	17713	Economy	3100.00
0005434448295	17713	Economy	3100.00
0005434461631	17713	Economy	3100.00
0005434186210	17713	Economy	3100.00
0005434461628	17713	Economy	3100.00
0005434458672	17713	Economy	3100.00
0005434448305	17713	Economy	3100.00
0005434448309	17713	Economy	3100.00
0005434458706	17713	Economy	3100.00
0005434458769	17713	Economy	3100.00
0005434458771	17713	Economy	3100.00
0005434458802	17713	Economy	3100.00
0005434458698	17713	Economy	3100.00
0005434458701	17713	Economy	3100.00
0005434458671	17713	Economy	3100.00
0005434458661	17713	Economy	3100.00
0005434458632	17713	Economy	3100.00
0005434458758	17713	Economy	3100.00
0005434448304	17713	Economy	3100.00
0005434458744	17713	Economy	3100.00
0005434458863	29098	Economy	3400.00
0005434462794	29098	Economy	3400.00
0005434458869	29098	Economy	3400.00
0005434458868	29098	Economy	3100.00
0005434458878	29098	Economy	3100.00
0005434448324	29098	Economy	3100.00
0005434462796	29098	Economy	3100.00
0005434463935	29098	Economy	3100.00
0005434458874	29098	Economy	3100.00
0005434458875	29098	Economy	3100.00
0005434458867	29098	Economy	3100.00
0005434458865	29098	Economy	3100.00
0005434458862	29098	Economy	3100.00
0005434458879	29098	Economy	3100.00
0005434458861	29098	Economy	3100.00
0005434186178	29098	Economy	3100.00
0005434458873	29098	Economy	3100.00
0005434186163	29098	Economy	3100.00
0005434186175	29098	Economy	3100.00
0005434458876	29098	Economy	3100.00
0005434458864	29098	Economy	3100.00
0005434186182	29098	Economy	3100.00
0005434458866	29098	Economy	3100.00
0005434458859	29098	Economy	3100.00
0005434186164	29098	Economy	3100.00
0005434448322	29098	Economy	3100.00
0005434448325	29098	Economy	3100.00
0005434448323	29098	Economy	3100.00
0005434458860	29098	Economy	3100.00
0005434458877	29098	Economy	3100.00
0005434463934	29098	Economy	3100.00
0005434458872	29098	Economy	3100.00
0005434458871	29098	Economy	3100.00
0005434462795	29098	Economy	3100.00
0005434458880	29098	Economy	3100.00
0005434458881	29098	Economy	3100.00
0005434448321	29098	Economy	3100.00
0005434458870	29098	Economy	3100.00
0005432664155	6494	Business	185300.00
0005432663054	6494	Business	185300.00
0005432664144	6494	Business	185300.00
0005432664153	6494	Business	185300.00
0005432663052	6494	Business	185300.00
0005432664149	6494	Business	185300.00
0005432663046	6494	Business	185300.00
0005432661940	6494	Business	185300.00
0005432661934	6494	Economy	61800.00
0005432661938	6494	Economy	61800.00
0005432664154	6494	Economy	61800.00
0005432663048	6494	Economy	61800.00
0005432663042	6494	Economy	61800.00
0005432661936	6494	Economy	61800.00
0005432661931	6494	Economy	61800.00
0005432661939	6494	Economy	67900.00
0005432663041	6494	Economy	67900.00
0005432663045	6494	Economy	61800.00
0005432661941	6494	Economy	61800.00
0005432663044	6494	Economy	61800.00
0005432663051	6494	Economy	61800.00
0005432664145	6494	Economy	61800.00
0005432663047	6494	Economy	61800.00
0005432663049	6494	Economy	61800.00
0005432664152	6494	Economy	61800.00
0005432663050	6494	Economy	61800.00
0005432664157	6494	Economy	61800.00
0005432664151	6494	Economy	61800.00
0005432663053	6494	Economy	61800.00
0005432661932	6494	Economy	61800.00
0005432661943	6494	Economy	61800.00
0005432661942	6494	Economy	61800.00
0005432661930	6494	Economy	61800.00
0005432664148	6494	Economy	61800.00
0005432664147	6494	Economy	61800.00
0005432661928	6494	Economy	61800.00
0005432661935	6494	Economy	61800.00
0005432661929	6494	Economy	61800.00
0005432664150	6494	Economy	61800.00
0005432664146	6494	Economy	61800.00
0005432664143	6494	Economy	61800.00
0005432664156	6494	Economy	61800.00
0005432663055	6494	Economy	61800.00
0005432663043	6494	Economy	61800.00
0005432661937	6494	Economy	61800.00
0005432661933	6494	Economy	61800.00
0005432604445	21426	Economy	7300.00
0005432604440	21426	Economy	7300.00
0005432604433	21426	Economy	7300.00
0005432604412	21426	Economy	6600.00
0005432604439	21426	Economy	6600.00
0005432604451	21426	Economy	6600.00
0005432604413	21426	Economy	6600.00
0005432604422	21426	Economy	6600.00
0005432604437	21426	Economy	6600.00
0005432604438	21426	Economy	6600.00
0005432604432	21426	Economy	6600.00
0005432604444	21426	Economy	6600.00
0005432604429	21426	Economy	6600.00
0005432604436	21426	Economy	6600.00
0005432604449	21426	Economy	6600.00
0005432604442	21426	Economy	6600.00
0005432604424	21426	Economy	6600.00
0005432604430	21426	Economy	6600.00
0005432604423	21426	Economy	6600.00
0005432604441	21426	Economy	6600.00
0005432604443	21426	Economy	6600.00
0005432604448	21426	Economy	6600.00
0005432604420	21426	Economy	6600.00
0005435218108	21426	Economy	6600.00
0005432604414	21426	Economy	6600.00
0005432604452	21426	Economy	6600.00
0005432604447	21426	Economy	6600.00
0005432604431	21426	Economy	6600.00
0005432604426	21426	Economy	6600.00
0005432604415	21426	Economy	6600.00
0005432604419	21426	Economy	6600.00
0005432604450	21426	Economy	6600.00
0005432604417	21426	Economy	6600.00
0005432604428	21426	Economy	6600.00
0005432604446	21426	Economy	6600.00
0005432604425	21426	Economy	6600.00
0005432604435	21426	Economy	6600.00
0005432604418	21426	Economy	6600.00
0005432604421	21426	Economy	6600.00
0005432604416	21426	Economy	6600.00
0005435218109	21426	Economy	6600.00
0005432604427	21426	Economy	6600.00
0005432604434	21426	Economy	6600.00
0005432604147	31669	Economy	7300.00
0005432604121	31669	Economy	7300.00
0005432604117	31669	Economy	6600.00
0005435221518	31669	Economy	6600.00
0005432604207	31669	Economy	6600.00
0005432604208	31669	Economy	6600.00
0005432604209	31669	Economy	6600.00
0005432604004	31669	Economy	6600.00
0005432604139	31669	Economy	6600.00
0005432604156	31669	Economy	6600.00
0005432604193	31669	Economy	6600.00
0005432604107	31669	Economy	6600.00
0005432604017	31669	Economy	6600.00
0005435221057	31669	Economy	6600.00
0005432603849	31669	Economy	6600.00
0005432604140	31669	Economy	6600.00
0005432604132	31669	Economy	6600.00
0005432604102	31669	Economy	6600.00
0005432604137	31669	Economy	6600.00
0005432604109	31669	Economy	6600.00
0005432604092	31669	Economy	6600.00
0005432604122	31669	Economy	6600.00
0005432604138	31669	Economy	6600.00
0005432604025	31669	Economy	6600.00
0005432604108	31669	Economy	6600.00
0005432604144	31669	Economy	6600.00
0005432604155	31669	Economy	6600.00
0005432604280	31669	Economy	6600.00
0005432604085	31669	Economy	6600.00
0005435221517	31669	Economy	6600.00
0005432604011	31669	Economy	6600.00
0005432604016	31669	Economy	6600.00
0005432604093	31669	Economy	6600.00
0005433293171	12312	Economy	19500.00
0005433293178	12312	Economy	19500.00
0005433293179	12312	Economy	19500.00
0005433293168	12312	Economy	17800.00
0005433293170	12312	Economy	17800.00
0005433293172	12312	Economy	17800.00
0005433293217	12312	Economy	17800.00
0005433293218	12312	Economy	17800.00
0005433293210	12312	Economy	17800.00
0005435154597	12312	Economy	17800.00
0005433293222	12312	Economy	17800.00
0005433293201	12312	Economy	17800.00
0005433293181	12312	Economy	17800.00
0005433293198	12312	Economy	17800.00
0005435154598	12312	Economy	17800.00
0005433293187	12312	Economy	17800.00
0005433293182	12312	Economy	17800.00
0005433293223	12312	Economy	17800.00
0005433293169	12312	Economy	17800.00
0005433293203	12312	Economy	17800.00
0005433293197	12312	Economy	17800.00
0005435154596	12312	Economy	17800.00
0005433293204	12312	Economy	17800.00
0005433293213	12312	Economy	17800.00
0005433293185	12312	Economy	17800.00
0005433293196	12312	Economy	17800.00
0005433293186	12312	Economy	17800.00
0005433473209	23889	Economy	14000.00
0005435257250	23889	Economy	14000.00
0005433473210	23889	Economy	14000.00
0005433473181	23889	Economy	12700.00
0005435257247	23889	Economy	12700.00
0005435257255	23889	Economy	12700.00
0005433473211	23889	Economy	12700.00
0005435257249	23889	Economy	12700.00
0005433473190	23889	Economy	12700.00
0005435257254	23889	Economy	12700.00
0005433473147	23889	Economy	12700.00
0005433473199	23889	Economy	12700.00
0005433473201	23889	Economy	12700.00
0005433473192	23889	Economy	12700.00
0005435257257	23889	Economy	12700.00
0005433473230	23889	Economy	12700.00
0005433473180	23889	Economy	12700.00
0005433473205	23889	Economy	12700.00
0005433473191	23889	Economy	12700.00
0005435257251	23889	Economy	12700.00
0005435257246	23889	Economy	12700.00
0005433473179	23889	Economy	12700.00
0005433473229	23889	Economy	12700.00
0005435257253	23889	Economy	12700.00
0005433473241	23889	Economy	12700.00
0005433473146	23889	Economy	12700.00
0005433473225	23889	Economy	12700.00
0005435257252	23889	Economy	12700.00
0005435257256	23889	Economy	12700.00
0005435257248	23889	Economy	12700.00
0005434606801	18923	Economy	6600.00
0005434603020	18923	Economy	6600.00
0005434606806	18923	Economy	6600.00
0005434606800	18923	Economy	6600.00
0005434606802	18923	Economy	6600.00
0005434606836	22303	Economy	6600.00
0005434604907	22303	Economy	6600.00
0005434604908	22303	Economy	6600.00
0005434604905	22303	Economy	6600.00
0005434606835	22303	Economy	6600.00
0005434604906	22303	Economy	6600.00
0005434604904	22303	Economy	6600.00
0005435904893	22303	Economy	6600.00
0005434606834	22303	Economy	6600.00
0005434602908	3859	Economy	24900.00
0005434522457	3859	Economy	22600.00
0005434602909	3859	Economy	22600.00
0005434522455	3859	Economy	22600.00
0005434522451	3859	Economy	22600.00
0005434602910	3859	Economy	22600.00
0005434522452	3859	Economy	22600.00
0005434602905	3859	Economy	22600.00
0005434602907	3859	Economy	22600.00
0005434602906	3859	Economy	22600.00
0005434522454	3859	Economy	22600.00
0005435904392	3859	Economy	22600.00
0005435904384	3859	Economy	22600.00
0005434522459	3859	Economy	22600.00
0005434522456	3859	Economy	22600.00
0005434522458	3859	Economy	22600.00
0005434522453	3859	Economy	22600.00
0005434604866	19048	Economy	24900.00
0005434522425	19048	Economy	24900.00
0005434604852	19048	Economy	22600.00
0005434522420	19048	Economy	22600.00
0005435904417	19048	Economy	22600.00
0005434602880	19048	Economy	22600.00
0005434604862	19048	Economy	22600.00
0005435904416	19048	Economy	22600.00
0005435904413	19048	Economy	22600.00
0005434522426	19048	Economy	22600.00
0005434522422	19048	Economy	22600.00
0005434602875	19048	Economy	22600.00
0005434602884	19048	Economy	22600.00
0005434522448	19048	Economy	22600.00
0005435904415	19048	Economy	22600.00
0005434522441	19048	Economy	22600.00
0005434522406	19048	Economy	22600.00
0005435904414	19048	Economy	22600.00
0005434602876	19048	Economy	22600.00
0005434604851	19048	Economy	22600.00
0005434522447	19048	Economy	22600.00
0005434522430	19048	Economy	22600.00
0005434604865	19048	Economy	22600.00
0005434604871	19048	Economy	22600.00
0005434604867	19048	Economy	22600.00
0005434522419	19048	Economy	22600.00
0005434604861	19048	Economy	22600.00
0005435904707	19048	Economy	22600.00
0005434522440	19048	Economy	22600.00
0005434522421	19048	Economy	22600.00
0005434602879	19048	Economy	22600.00
0005434602881	19048	Economy	22600.00
0005432747680	396	Business	44500.00
0005432747667	396	Business	44500.00
0005432747656	396	Business	44500.00
0005432747668	396	Business	44500.00
0005432751535	396	Business	44500.00
0005432890877	396	Business	44500.00
0005432890921	396	Business	44500.00
0005432890922	396	Business	44500.00
0005432747666	396	Business	44500.00
0005432890869	396	Business	44500.00
0005432751532	396	Business	44500.00
0005432747655	396	Business	44500.00
0005432890929	396	Economy	14800.00
0005432747675	396	Economy	14800.00
0005432747669	396	Economy	14800.00
0005432220019	396	Economy	14800.00
0005432890887	396	Economy	14800.00
0005432890932	396	Economy	14800.00
0005433293221	396	Economy	14800.00
0005432890892	396	Economy	14800.00
0005432220017	396	Economy	14800.00
0005432747657	396	Economy	14800.00
0005432890713	396	Economy	16300.00
0005432890882	396	Economy	16300.00
0005432747663	396	Economy	16300.00
0005432747693	396	Economy	16300.00
0005432749789	396	Economy	16300.00
0005432220018	396	Economy	14800.00
0005433875367	396	Economy	14800.00
0005433293208	396	Economy	14800.00
0005432753310	396	Economy	14800.00
0005432890910	396	Economy	14800.00
0005433293206	396	Economy	14800.00
0005432749790	396	Economy	14800.00
0005432747673	396	Economy	14800.00
0005432890888	396	Economy	14800.00
0005432890898	396	Economy	14800.00
0005432747687	396	Economy	14800.00
0005432749791	396	Economy	14800.00
0005432751533	396	Economy	14800.00
0005432890930	396	Economy	14800.00
0005432890894	396	Economy	14800.00
0005432890926	396	Economy	14800.00
0005432747684	396	Economy	14800.00
0005432747662	396	Economy	14800.00
0005432747688	396	Economy	14800.00
0005432747671	396	Economy	14800.00
0005432747679	396	Economy	14800.00
0005433875370	396	Economy	14800.00
0005433293227	396	Economy	14800.00
0005432751534	396	Economy	14800.00
0005432890960	396	Economy	14800.00
0005432890886	396	Economy	14800.00
0005433293199	396	Economy	14800.00
0005432747654	396	Economy	14800.00
0005432220015	396	Economy	14800.00
0005432747659	396	Economy	14800.00
0005432890885	396	Economy	14800.00
0005432747665	396	Economy	14800.00
0005432747674	396	Economy	14800.00
0005432753307	396	Economy	14800.00
0005432220016	396	Economy	14800.00
0005432753308	396	Economy	14800.00
0005432747664	396	Economy	14800.00
0005432890966	396	Economy	14800.00
0005432747678	396	Economy	14800.00
0005432751536	396	Economy	14800.00
0005432890884	396	Economy	14800.00
0005432890965	396	Economy	14800.00
0005432890868	396	Economy	14800.00
0005432747670	396	Economy	14800.00
0005433293220	396	Economy	14800.00
0005432747676	396	Economy	14800.00
0005432747685	396	Economy	14800.00
0005432747672	396	Economy	14800.00
0005432747653	396	Economy	14800.00
0005432890920	396	Economy	14800.00
0005432747681	396	Economy	14800.00
0005433293226	396	Economy	14800.00
0005432747677	396	Economy	14800.00
0005432747691	396	Economy	14800.00
0005432747682	396	Economy	14800.00
0005432747661	396	Economy	14800.00
0005432747686	396	Economy	14800.00
0005432747683	396	Economy	14800.00
0005432747690	396	Economy	14800.00
0005432753309	396	Economy	14800.00
0005433293195	396	Economy	14800.00
0005432220013	396	Economy	14800.00
0005432890967	396	Economy	14800.00
0005432220014	396	Economy	14800.00
0005432747658	396	Economy	14800.00
0005432890928	396	Economy	14800.00
0005432747660	396	Economy	14800.00
0005433293194	396	Economy	14800.00
0005432747692	396	Economy	14800.00
0005432747689	396	Economy	14800.00
0005432747349	12093	Business	44500.00
0005432753288	12093	Business	44500.00
0005432747515	12093	Business	44500.00
0005432747305	12093	Business	44500.00
0005432747300	12093	Business	44500.00
0005432747418	12093	Business	44500.00
0005432756815	12093	Business	44500.00
0005432747419	12093	Business	44500.00
0005432747301	12093	Economy	14800.00
0005432747132	12093	Economy	14800.00
0005432891089	12093	Economy	14800.00
0005432747369	12093	Economy	14800.00
0005432747550	12093	Economy	14800.00
0005432891071	12093	Economy	14800.00
0005432747306	12093	Economy	14800.00
0005432747517	12093	Economy	14800.00
0005432747404	12093	Economy	14800.00
0005432747371	12093	Economy	14800.00
0005432747386	12093	Economy	16300.00
0005433875386	12093	Economy	16300.00
0005432747417	12093	Economy	16300.00
0005432891084	12093	Economy	16300.00
0005432747131	12093	Economy	16300.00
0005432747398	12093	Economy	14800.00
0005432891078	12093	Economy	14800.00
0005432747551	12093	Economy	14800.00
0005432747310	12093	Economy	14800.00
0005432891087	12093	Economy	14800.00
0005432891081	12093	Economy	14800.00
0005432747447	12093	Economy	14800.00
0005432891085	12093	Economy	14800.00
0005432747405	12093	Economy	14800.00
0005432747533	12093	Economy	14800.00
0005432214810	12093	Economy	14800.00
0005432747372	12093	Economy	14800.00
0005433875385	12093	Economy	14800.00
0005432891088	12093	Economy	14800.00
0005432214811	12093	Economy	14800.00
0005432747231	12093	Economy	14800.00
0005432747399	12093	Economy	14800.00
0005432891072	12093	Economy	14800.00
0005435627115	12093	Economy	14800.00
0005432747233	12093	Economy	14800.00
0005432891076	12093	Economy	14800.00
0005432747416	12093	Economy	14800.00
0005432747518	12093	Economy	14800.00
0005432747307	12093	Economy	14800.00
0005432747470	12093	Economy	14800.00
0005432747338	12093	Economy	14800.00
0005432747337	12093	Economy	14800.00
0005432747532	12093	Economy	14800.00
0005432214812	12093	Economy	14800.00
0005432753276	12093	Economy	14800.00
0005432891077	12093	Economy	14800.00
0005432891075	12093	Economy	14800.00
0005432756826	12093	Economy	14800.00
0005432891082	12093	Economy	14800.00
0005432891079	12093	Economy	14800.00
0005432747367	12093	Economy	14800.00
0005432747351	12093	Economy	14800.00
0005432747462	12093	Economy	14800.00
0005435627114	12093	Economy	14800.00
0005432891070	12093	Economy	14800.00
0005432747373	12093	Economy	14800.00
0005432747420	12093	Economy	14800.00
0005432749770	12093	Economy	14800.00
0005432747433	12093	Economy	14800.00
0005432891083	12093	Economy	14800.00
0005432747393	12093	Economy	14800.00
0005432747446	12093	Economy	14800.00
0005432753275	12093	Economy	14800.00
0005432747319	12093	Economy	14800.00
0005432747350	12093	Economy	14800.00
0005432891080	12093	Economy	14800.00
0005432891086	12093	Economy	14800.00
0005432891074	12093	Economy	14800.00
0005432753295	12093	Economy	14800.00
0005432747270	12093	Economy	14800.00
0005432753285	12093	Economy	14800.00
0005432747536	12093	Economy	14800.00
0005432747370	12093	Economy	14800.00
0005432753284	12093	Economy	14800.00
0005432891073	12093	Economy	14800.00
0005432747403	12093	Economy	14800.00
0005432747514	12093	Economy	14800.00
0005432747320	12093	Economy	14800.00
0005432927954	18959	Economy	25700.00
0005433525060	18959	Economy	25700.00
0005433525063	18959	Economy	25700.00
0005433525067	18959	Economy	25700.00
0005433525062	18959	Economy	25700.00
0005433533315	18959	Economy	25700.00
0005433525065	18959	Economy	25700.00
0005433531301	18959	Economy	25700.00
0005432927938	18959	Economy	25700.00
0005433531302	18959	Economy	25700.00
0005433533316	18959	Economy	25700.00
0005433525066	18959	Economy	25700.00
0005433525061	18959	Economy	25700.00
0005433525059	18959	Economy	25700.00
0005432927952	18959	Economy	25700.00
0005433533314	18959	Economy	25700.00
0005433525064	18959	Economy	25700.00
0005433525069	18959	Economy	25700.00
0005433531303	18959	Economy	25700.00
0005432927937	18959	Economy	25700.00
0005433533317	18959	Economy	25700.00
0005433525068	18959	Economy	25700.00
0005433525058	18959	Economy	25700.00
0005433524984	32489	Economy	28200.00
0005433524969	32489	Economy	28200.00
0005433524989	32489	Economy	28200.00
0005432928003	32489	Economy	25700.00
0005433531280	32489	Economy	25700.00
0005433524981	32489	Economy	25700.00
0005433524971	32489	Economy	25700.00
0005433524998	32489	Economy	25700.00
0005432928000	32489	Economy	25700.00
0005433524982	32489	Economy	25700.00
0005432928005	32489	Economy	25700.00
0005433524983	32489	Economy	25700.00
0005433524990	32489	Economy	25700.00
0005432928002	32489	Economy	25700.00
0005433531277	32489	Economy	25700.00
0005433525031	32489	Economy	25700.00
0005433525016	32489	Economy	25700.00
0005433525032	32489	Economy	25700.00
0005432928001	32489	Economy	25700.00
0005433531285	32489	Economy	25700.00
0005433531275	32489	Economy	25700.00
0005433531284	32489	Economy	25700.00
0005432928006	32489	Economy	25700.00
0005433531276	32489	Economy	25700.00
0005432928004	32489	Economy	25700.00
0005435373007	5244	Business	84000.00
0005434824017	5244	Business	84000.00
0005435373049	5244	Business	84000.00
0005432121378	5244	Business	84000.00
0005435372962	5244	Business	84000.00
0005435372761	5244	Business	84000.00
0005435372732	5244	Business	84000.00
0005435150078	5244	Business	84000.00
0005435372919	5244	Business	84000.00
0005435372898	5244	Business	84000.00
0005434828704	5244	Business	84000.00
0005434824029	5244	Business	84000.00
0005434823941	5244	Business	84000.00
0005434824015	5244	Business	84000.00
0005432121374	5244	Business	84000.00
0005434823939	5244	Business	84000.00
0005435150075	5244	Business	84000.00
0005434824027	5244	Business	84000.00
0005434824013	5244	Business	84000.00
0005435372861	5244	Business	84000.00
0005434824003	5244	Business	84000.00
0005435372804	5244	Business	84000.00
0005435299747	5244	Comfort	47600.00
0005435150070	5244	Comfort	47600.00
0005432394114	5244	Comfort	47600.00
0005434823959	5244	Comfort	47600.00
0005432396254	5244	Comfort	47600.00
0005434824023	5244	Comfort	47600.00
0005434823936	5244	Comfort	47600.00
0005434824035	5244	Comfort	47600.00
0005435373014	5244	Comfort	47600.00
0005434558303	5244	Comfort	47600.00
0005434823938	5244	Comfort	47600.00
0005435735098	5244	Comfort	47600.00
0005434823970	5244	Comfort	47600.00
0005435372791	5244	Comfort	47600.00
0005434824007	5244	Comfort	47600.00
0005435372948	5244	Comfort	47600.00
0005435372668	5244	Comfort	47600.00
0005434823994	5244	Comfort	47600.00
0005435372889	5244	Comfort	47600.00
0005432394119	5244	Comfort	47600.00
0005435372803	5244	Comfort	47600.00
0005435373018	5244	Comfort	47600.00
0005434558308	5244	Comfort	47600.00
0005434823918	5244	Comfort	47600.00
0005434823947	5244	Comfort	47600.00
0005435372864	5244	Comfort	47600.00
0005435150072	5244	Comfort	47600.00
0005434823933	5244	Comfort	47600.00
0005435150068	5244	Comfort	47600.00
0005434823973	5244	Comfort	47600.00
0005434823985	5244	Comfort	47600.00
0005434823931	5244	Comfort	47600.00
0005434823986	5244	Comfort	47600.00
0005434558307	5244	Comfort	47600.00
0005434824001	5244	Comfort	47600.00
0005434823969	5244	Comfort	47600.00
0005434823952	5244	Economy	28000.00
0005435372986	5244	Economy	28000.00
0005435373002	5244	Economy	28000.00
0005432121376	5244	Economy	28000.00
0005435372704	5244	Economy	28000.00
0005435372552	5244	Economy	28000.00
0005435372694	5244	Economy	28000.00
0005434824022	5244	Economy	28000.00
0005435735097	5244	Economy	28000.00
0005434823968	5244	Economy	28000.00
0005434823995	5244	Economy	28000.00
0005434823966	5244	Economy	28000.00
0005435150067	5244	Economy	28000.00
0005434823987	5244	Economy	28000.00
0005435372756	5244	Economy	28000.00
0005434823993	5244	Economy	28000.00
0005434823911	5244	Economy	28000.00
0005434823965	5244	Economy	28000.00
0005434823932	5244	Economy	28000.00
0005434823958	5244	Economy	28000.00
0005432121377	5244	Economy	28000.00
0005435372859	5244	Economy	28000.00
0005432121381	5244	Economy	28000.00
0005435373153	5244	Economy	28000.00
0005434824012	5244	Economy	28000.00
0005434823999	5244	Economy	28000.00
0005434823996	5244	Economy	28000.00
0005435150079	5244	Economy	28000.00
0005435150066	5244	Economy	28000.00
0005435386541	5244	Economy	28000.00
0005434823955	5244	Economy	28000.00
0005432394120	5244	Economy	28000.00
0005435150071	5244	Economy	28000.00
0005434823992	5244	Economy	28000.00
0005434824009	5244	Economy	28000.00
0005434824008	5244	Economy	28000.00
0005435373164	5244	Economy	28000.00
0005435150077	5244	Economy	28000.00
0005434823915	5244	Economy	28000.00
0005434823945	5244	Economy	28000.00
0005434831162	5244	Economy	28000.00
0005434823982	5244	Economy	28000.00
0005435150069	5244	Economy	28000.00
0005435372767	5244	Economy	28000.00
0005434823990	5244	Economy	28000.00
0005434824026	5244	Economy	28000.00
0005435372855	5244	Economy	28000.00
0005435150076	5244	Economy	28000.00
0005432121372	5244	Economy	28000.00
0005435150074	5244	Economy	28000.00
0005434824021	5244	Economy	30800.00
0005435299762	5244	Economy	28000.00
0005432121375	5244	Economy	28000.00
0005434823917	5244	Economy	30800.00
0005434664965	5244	Economy	28000.00
0005434823909	5244	Economy	28000.00
0005434824010	5244	Economy	30800.00
0005435299749	5244	Economy	28000.00
0005435373084	5244	Economy	28000.00
0005434823991	5244	Economy	28000.00
0005435372566	5244	Economy	28000.00
0005435299748	5244	Economy	28000.00
0005434558305	5244	Economy	28000.00
0005432121379	5244	Economy	28000.00
0005434823967	5244	Economy	28000.00
0005434823997	5244	Economy	28000.00
0005435150080	5244	Economy	28000.00
0005435372820	5244	Economy	28000.00
0005434823949	5244	Economy	28000.00
0005434823922	5244	Economy	28000.00
0005434823957	5244	Economy	28000.00
0005434823943	5244	Economy	28000.00
0005434831161	5244	Economy	28000.00
0005434823924	5244	Economy	28000.00
0005434823927	5244	Economy	28000.00
0005435373103	5244	Economy	28000.00
0005434823921	5244	Economy	28000.00
0005434823998	5244	Economy	28000.00
0005435372705	5244	Economy	28000.00
0005434823971	5244	Economy	28000.00
0005434823913	5244	Economy	28000.00
0005434823942	5244	Economy	28000.00
0005434823937	5244	Economy	28000.00
0005434828702	5244	Economy	28000.00
0005435735090	5244	Economy	28000.00
0005434823948	5244	Economy	28000.00
0005434823910	5244	Economy	28000.00
0005434823981	5244	Economy	28000.00
0005434824005	5244	Economy	28000.00
0005434823980	5244	Economy	28000.00
0005432394117	5244	Economy	28000.00
0005434824014	5244	Economy	28000.00
0005432121385	5244	Economy	28000.00
0005432823428	5244	Economy	28000.00
0005434823977	5244	Economy	28000.00
0005434823984	5244	Economy	28000.00
0005435372964	5244	Economy	28000.00
0005434824032	5244	Economy	28000.00
0005435372760	5244	Economy	28000.00
0005435372965	5244	Economy	28000.00
0005435372741	5244	Economy	28000.00
0005435373121	5244	Economy	28000.00
0005434823920	5244	Economy	28000.00
0005435372854	5244	Economy	28000.00
0005435372918	5244	Economy	28000.00
0005434824025	5244	Economy	28000.00
0005435372915	5244	Economy	28000.00
0005434824020	5244	Economy	28000.00
0005434824030	5244	Economy	28000.00
0005434823950	5244	Economy	28000.00
0005434824002	5244	Economy	28000.00
0005434828703	5244	Economy	28000.00
0005434824024	5244	Economy	28000.00
0005434824006	5244	Economy	28000.00
0005434823935	5244	Economy	28000.00
0005435372993	5244	Economy	28000.00
0005432121382	5244	Economy	28000.00
0005435150073	5244	Economy	28000.00
0005435373017	5244	Economy	28000.00
0005435372773	5244	Economy	28000.00
0005432394115	5244	Economy	28000.00
0005435386520	5244	Economy	28000.00
0005432121371	5244	Economy	28000.00
0005435735093	5244	Economy	28000.00
0005435372827	5244	Economy	28000.00
0005434824031	5244	Economy	28000.00
0005434823914	5244	Economy	28000.00
0005435661906	5244	Economy	28000.00
0005435299739	5244	Economy	28000.00
0005435373165	5244	Economy	28000.00
0005435386544	5244	Economy	28000.00
0005434823979	5244	Economy	28000.00
0005435372790	5244	Economy	28000.00
0005434823925	5244	Economy	28000.00
0005434824019	5244	Economy	28000.00
0005434823930	5244	Economy	28000.00
0005432394116	5244	Economy	28000.00
0005435386531	5244	Economy	28000.00
0005435372899	5244	Economy	28000.00
0005434823962	5244	Economy	30800.00
0005435373043	5244	Economy	30800.00
0005434558304	5244	Economy	30800.00
0005435150081	5244	Economy	28000.00
0005434823974	5244	Economy	28000.00
0005435735099	5244	Economy	28000.00
0005435372768	5244	Economy	28000.00
0005435299721	5244	Economy	28000.00
0005434823946	5244	Economy	28000.00
0005434823964	5244	Economy	28000.00
0005434823923	5244	Economy	28000.00
0005434824018	5244	Economy	28000.00
0005435372989	5244	Economy	28000.00
0005432121380	5244	Economy	28000.00
0005434824016	5244	Economy	28000.00
0005435386521	5244	Economy	28000.00
0005435372695	5244	Economy	28000.00
0005435372565	5244	Economy	28000.00
0005434823988	5244	Economy	28000.00
0005434824037	5244	Economy	28000.00
0005434824034	5244	Economy	28000.00
0005434823975	5244	Economy	28000.00
0005435372727	5244	Economy	28000.00
0005434823961	5244	Economy	28000.00
0005435386506	5244	Economy	28000.00
0005435386519	5244	Economy	28000.00
0005434824028	5244	Economy	28000.00
0005435735086	5244	Economy	28000.00
0005434824000	5244	Economy	28000.00
0005434823976	5244	Economy	28000.00
0005434823972	5244	Economy	28000.00
0005435372795	5244	Economy	28000.00
0005434824004	5244	Economy	28000.00
0005434558306	5244	Economy	28000.00
0005432121383	5244	Economy	28000.00
0005432396255	5244	Economy	28000.00
0005435372703	5244	Economy	28000.00
0005435372796	5244	Economy	28000.00
0005434823978	5244	Economy	28000.00
0005434824033	5244	Economy	28000.00
0005435373116	5244	Economy	28000.00
0005435372835	5244	Economy	28000.00
0005435372865	5244	Economy	28000.00
0005434824036	5244	Economy	28000.00
0005432121384	5244	Economy	28000.00
0005434823929	5244	Economy	28000.00
0005435372939	5244	Economy	28000.00
0005434823916	5244	Economy	28000.00
0005435372642	5244	Economy	28000.00
0005434824011	5244	Economy	28000.00
0005432396256	5244	Economy	28000.00
0005434823989	5244	Economy	28000.00
0005434823928	5244	Economy	28000.00
0005435372654	5244	Economy	28000.00
0005434823940	5244	Economy	28000.00
0005434823944	5244	Economy	28000.00
0005434823934	5244	Economy	28000.00
0005435372985	5244	Economy	28000.00
0005435372553	5244	Economy	28000.00
0005435372866	5244	Economy	28000.00
0005434823951	5244	Economy	28000.00
0005434831160	5244	Economy	28000.00
0005435372957	5244	Economy	28000.00
0005435386507	5244	Economy	28000.00
0005434823963	5244	Economy	28000.00
0005434823954	5244	Economy	28000.00
0005435373083	5244	Economy	28000.00
0005434823956	5244	Economy	28000.00
0005435372728	5244	Economy	28000.00
0005432394118	5244	Economy	28000.00
0005434823953	5244	Economy	28000.00
0005434823960	5244	Economy	28000.00
0005434823983	5244	Economy	28000.00
0005434823926	5244	Economy	28000.00
0005432396257	5244	Economy	28000.00
0005435372897	5244	Economy	28000.00
0005432121373	5244	Economy	28000.00
0005434823919	5244	Economy	28000.00
0005434823912	5244	Economy	28000.00
0005435373477	9890	Business	84000.00
0005435373452	9890	Business	84000.00
0005434822451	9890	Business	84000.00
0005434823482	9890	Business	84000.00
0005434822879	9890	Business	84000.00
0005434822897	9890	Business	84000.00
0005434558225	9890	Business	84000.00
0005432396223	9890	Business	84000.00
0005434823009	9890	Business	84000.00
0005435373480	9890	Business	84000.00
0005435302212	9890	Business	84000.00
0005435150001	9890	Business	84000.00
0005434823078	9890	Business	84000.00
0005434823244	9890	Business	84000.00
0005435373473	9890	Business	84000.00
0005435373483	9890	Business	84000.00
0005434822962	9890	Business	84000.00
0005432203088	9890	Business	84000.00
0005432400086	9890	Business	84000.00
0005435373442	9890	Comfort	47600.00
0005435149953	9890	Comfort	47600.00
0005434823405	9890	Comfort	47600.00
0005434822311	9890	Comfort	47600.00
0005434823139	9890	Comfort	47600.00
0005434831119	9890	Comfort	47600.00
0005435373487	9890	Comfort	47600.00
0005432823456	9890	Comfort	47600.00
0005434823079	9890	Comfort	47600.00
0005434823120	9890	Comfort	47600.00
0005434822918	9890	Comfort	47600.00
0005434823253	9890	Comfort	47600.00
0005434822787	9890	Comfort	47600.00
0005432396232	9890	Comfort	47600.00
0005435373432	9890	Comfort	47600.00
0005434822659	9890	Comfort	47600.00
0005434822922	9890	Comfort	47600.00
0005435373458	9890	Comfort	47600.00
0005435386589	9890	Comfort	47600.00
0005434822983	9890	Comfort	47600.00
0005434823136	9890	Comfort	47600.00
0005432400115	9890	Comfort	47600.00
0005434823064	9890	Comfort	47600.00
0005435373440	9890	Comfort	47600.00
0005435386587	9890	Comfort	47600.00
0005435373431	9890	Comfort	47600.00
0005435299791	9890	Comfort	47600.00
0005435150000	9890	Comfort	47600.00
0005435299789	9890	Comfort	47600.00
0005435373461	9890	Comfort	47600.00
0005435373491	9890	Economy	28000.00
0005434822335	9890	Economy	28000.00
0005435373436	9890	Economy	28000.00
0005434822419	9890	Economy	28000.00
0005434828681	9890	Economy	28000.00
0005434823190	9890	Economy	28000.00
0005434664951	9890	Economy	28000.00
0005432203087	9890	Economy	28000.00
0005434822739	9890	Economy	28000.00
0005434823630	9890	Economy	28000.00
0005435373446	9890	Economy	28000.00
0005434822414	9890	Economy	28000.00
0005432400096	9890	Economy	28000.00
0005434823221	9890	Economy	28000.00
0005432203084	9890	Economy	28000.00
0005434823144	9890	Economy	28000.00
0005435373468	9890	Economy	28000.00
0005434558220	9890	Economy	28000.00
0005434823187	9890	Economy	28000.00
0005434823032	9890	Economy	28000.00
0005432203085	9890	Economy	28000.00
0005434664938	9890	Economy	28000.00
0005434823236	9890	Economy	28000.00
0005434822789	9890	Economy	28000.00
0005434823062	9890	Economy	28000.00
0005435302214	9890	Economy	28000.00
0005434823145	9890	Economy	28000.00
0005434822688	9890	Economy	28000.00
0005434831118	9890	Economy	28000.00
0005435149912	9890	Economy	28000.00
0005435373478	9890	Economy	28000.00
0005434823110	9890	Economy	28000.00
0005434822881	9890	Economy	28000.00
0005435373430	9890	Economy	28000.00
0005434822651	9890	Economy	28000.00
0005435149954	9890	Economy	28000.00
0005434823065	9890	Economy	28000.00
0005435373481	9890	Economy	28000.00
0005434822433	9890	Economy	28000.00
0005435373463	9890	Economy	28000.00
0005434822801	9890	Economy	28000.00
0005434822336	9890	Economy	28000.00
0005434823348	9890	Economy	28000.00
0005435386593	9890	Economy	28000.00
0005434831120	9890	Economy	28000.00
0005434822534	9890	Economy	28000.00
0005435373474	9890	Economy	28000.00
0005434823029	9890	Economy	30800.00
0005435373482	9890	Economy	30800.00
0005434822163	9890	Economy	28000.00
0005434822730	9890	Economy	28000.00
0005434822652	9890	Economy	28000.00
0005434831086	9890	Economy	28000.00
0005432396215	9890	Economy	30800.00
0005434822720	9890	Economy	28000.00
0005435299792	9890	Economy	28000.00
0005434823358	9890	Economy	28000.00
0005435373447	9890	Economy	28000.00
0005434822661	9890	Economy	28000.00
0005435149913	9890	Economy	28000.00
0005434823107	9890	Economy	28000.00
0005434823629	9890	Economy	28000.00
0005434822993	9890	Economy	28000.00
0005435373464	9890	Economy	28000.00
0005434822974	9890	Economy	28000.00
0005434822875	9890	Economy	28000.00
0005435386591	9890	Economy	28000.00
0005434822788	9890	Economy	28000.00
0005435373443	9890	Economy	28000.00
0005434822500	9890	Economy	28000.00
0005435373445	9890	Economy	28000.00
0005434823135	9890	Economy	28000.00
0005435373455	9890	Economy	28000.00
0005434822917	9890	Economy	28000.00
0005434822418	9890	Economy	28000.00
0005435373476	9890	Economy	28000.00
0005435735150	9890	Economy	28000.00
0005435373465	9890	Economy	28000.00
0005435373484	9890	Economy	28000.00
0005434558219	9890	Economy	28000.00
0005434822719	9890	Economy	28000.00
0005435373439	9890	Economy	28000.00
0005434823275	9890	Economy	28000.00
0005434822802	9890	Economy	28000.00
0005434823220	9890	Economy	28000.00
0005435373441	9890	Economy	28000.00
0005434822533	9890	Economy	28000.00
0005434831126	9890	Economy	28000.00
0005432203083	9890	Economy	28000.00
0005435149942	9890	Economy	28000.00
0005435661940	9890	Economy	28000.00
0005435373449	9890	Economy	28000.00
0005434823157	9890	Economy	28000.00
0005432203082	9890	Economy	28000.00
0005434822796	9890	Economy	28000.00
0005434823347	9890	Economy	28000.00
0005434823243	9890	Economy	28000.00
0005435373490	9890	Economy	28000.00
0005434823158	9890	Economy	28000.00
0005435735149	9890	Economy	28000.00
0005434823237	9890	Economy	28000.00
0005434822417	9890	Economy	28000.00
0005435661939	9890	Economy	28000.00
0005435373444	9890	Economy	28000.00
0005435373485	9890	Economy	28000.00
0005435373459	9890	Economy	28000.00
0005434822975	9890	Economy	28000.00
0005435302215	9890	Economy	28000.00
0005434822831	9890	Economy	28000.00
0005435373428	9890	Economy	28000.00
0005435373470	9890	Economy	28000.00
0005434664937	9890	Economy	28000.00
0005434822855	9890	Economy	28000.00
0005434823091	9890	Economy	28000.00
0005434823004	9890	Economy	28000.00
0005434822784	9890	Economy	28000.00
0005434822549	9890	Economy	28000.00
0005434822771	9890	Economy	28000.00
0005435373467	9890	Economy	28000.00
0005434823245	9890	Economy	28000.00
0005435386590	9890	Economy	28000.00
0005435735151	9890	Economy	28000.00
0005435373454	9890	Economy	28000.00
0005432203086	9890	Economy	28000.00
0005434828680	9890	Economy	28000.00
0005434822415	9890	Economy	28000.00
0005435373434	9890	Economy	28000.00
0005434822851	9890	Economy	28000.00
0005434823021	9890	Economy	30800.00
0005434558222	9890	Economy	30800.00
0005434822236	9890	Economy	30800.00
0005435373475	9890	Economy	30800.00
0005435373450	9890	Economy	28000.00
0005435149926	9890	Economy	28000.00
0005434823020	9890	Economy	28000.00
0005435661941	9890	Economy	28000.00
0005435373438	9890	Economy	28000.00
0005434823003	9890	Economy	28000.00
0005435373433	9890	Economy	28000.00
0005434831087	9890	Economy	28000.00
0005435373469	9890	Economy	28000.00
0005434822978	9890	Economy	28000.00
0005435299790	9890	Economy	28000.00
0005434823068	9890	Economy	28000.00
0005435373456	9890	Economy	28000.00
0005434822738	9890	Economy	28000.00
0005434831117	9890	Economy	28000.00
0005435386592	9890	Economy	28000.00
0005434823442	9890	Economy	28000.00
0005434823106	9890	Economy	28000.00
0005435373466	9890	Economy	28000.00
0005435373460	9890	Economy	28000.00
0005434823019	9890	Economy	28000.00
0005434823261	9890	Economy	28000.00
0005434823109	9890	Economy	28000.00
0005432400104	9890	Economy	28000.00
0005435302211	9890	Economy	28000.00
0005435373435	9890	Economy	28000.00
0005435373488	9890	Economy	28000.00
0005435386588	9890	Economy	28000.00
0005434831112	9890	Economy	28000.00
0005434822961	9890	Economy	28000.00
0005434823574	9890	Economy	28000.00
0005434822994	9890	Economy	28000.00
0005435373448	9890	Economy	28000.00
0005435386594	9890	Economy	28000.00
0005435373492	9890	Economy	28000.00
0005434822794	9890	Economy	28000.00
0005434823184	9890	Economy	28000.00
0005435373462	9890	Economy	28000.00
0005435373457	9890	Economy	28000.00
0005435373489	9890	Economy	28000.00
0005434822963	9890	Economy	28000.00
0005435373493	9890	Economy	28000.00
0005435373479	9890	Economy	28000.00
0005432823457	9890	Economy	28000.00
0005435735148	9890	Economy	28000.00
0005434828679	9890	Economy	28000.00
0005435373486	9890	Economy	28000.00
0005434822895	9890	Economy	28000.00
0005434822880	9890	Economy	28000.00
0005434822633	9890	Economy	28000.00
0005435149951	9890	Economy	28000.00
0005434823406	9890	Economy	28000.00
0005434822532	9890	Economy	28000.00
0005434822956	9890	Economy	28000.00
0005435373494	9890	Economy	28000.00
0005435373451	9890	Economy	28000.00
0005434558221	9890	Economy	28000.00
0005434822829	9890	Economy	28000.00
0005435373437	9890	Economy	28000.00
0005435299788	9890	Economy	28000.00
0005434822800	9890	Economy	28000.00
0005435149928	9890	Economy	28000.00
0005432396196	9890	Economy	28000.00
0005434823063	9890	Economy	28000.00
0005434823080	9890	Economy	28000.00
0005435373429	9890	Economy	28000.00
0005434822977	9890	Economy	28000.00
0005435373453	9890	Economy	28000.00
0005435302210	9890	Economy	28000.00
0005434822392	9890	Economy	28000.00
0005435302213	9890	Economy	28000.00
0005434822976	9890	Economy	28000.00
0005434822920	9890	Economy	28000.00
0005435373471	9890	Economy	28000.00
0005434823092	9890	Economy	28000.00
0005434822660	9890	Economy	28000.00
0005434823081	9890	Economy	28000.00
0005434822744	9890	Economy	28000.00
0005435735152	9890	Economy	28000.00
0005435373472	9890	Economy	28000.00
0005434823010	9890	Economy	28000.00
0005434822728	9890	Economy	28000.00
0005434558226	9890	Economy	28000.00
0005434822457	9890	Economy	28000.00
0005435082810	6997	Economy	8200.00
0005435790316	6997	Economy	7400.00
0005435082804	6997	Economy	7400.00
0005435082811	6997	Economy	7400.00
0005435082809	6997	Economy	7400.00
0005435082808	6997	Economy	7400.00
0005435082806	6997	Economy	7400.00
0005435790315	6997	Economy	7400.00
0005435082812	6997	Economy	7400.00
0005435082805	6997	Economy	7400.00
0005435790317	6997	Economy	7400.00
0005435082807	6997	Economy	7400.00
0005435082758	26002	Economy	8200.00
0005435790308	26002	Economy	7400.00
0005435790293	26002	Economy	7400.00
0005435082730	26002	Economy	7400.00
0005435082734	26002	Economy	7400.00
0005435082731	26002	Economy	7400.00
0005435790299	26002	Economy	7400.00
0005435790300	26002	Economy	7400.00
0005435790309	26002	Economy	7400.00
0005435790310	26002	Economy	7400.00
0005435082735	26002	Economy	7400.00
0005435790292	26002	Economy	7400.00
0005435082756	26002	Economy	7400.00
0005435790296	26002	Economy	7400.00
0005435082757	26002	Economy	7400.00
0005434214183	9558	Business	32800.00
0005434756564	9558	Business	32800.00
0005434214201	9558	Business	32800.00
0005434756541	9558	Business	32800.00
0005434214165	9558	Business	32800.00
0005434214174	9558	Business	32800.00
0005434756563	9558	Business	32800.00
0005434756516	9558	Business	32800.00
0005434756535	9558	Business	32800.00
0005434756537	9558	Business	32800.00
0005434214360	9558	Economy	10900.00
0005434214140	9558	Economy	10900.00
0005434756547	9558	Economy	10900.00
0005434756540	9558	Economy	10900.00
0005434756549	9558	Economy	10900.00
0005434756527	9558	Economy	10900.00
0005434756554	9558	Economy	10900.00
0005434756558	9558	Economy	10900.00
0005434756560	9558	Economy	10900.00
0005434756524	9558	Economy	12000.00
0005434756526	9558	Economy	12000.00
0005434214176	9558	Economy	12000.00
0005434756528	9558	Economy	12000.00
0005434756538	9558	Economy	12000.00
0005434756559	9558	Economy	10900.00
0005434214128	9558	Economy	10900.00
0005434756566	9558	Economy	10900.00
0005434214255	9558	Economy	10900.00
0005434214249	9558	Economy	10900.00
0005434214111	9558	Economy	10900.00
0005434756517	9558	Economy	10900.00
0005434756550	9558	Economy	10900.00
0005434756525	9558	Economy	10900.00
0005434756557	9558	Economy	10900.00
0005434214325	9558	Economy	10900.00
0005434214300	9558	Economy	10900.00
0005434756565	9558	Economy	10900.00
0005434214217	9558	Economy	10900.00
0005434756539	9558	Economy	10900.00
0005434214330	9558	Economy	10900.00
0005434214216	9558	Economy	10900.00
0005434756546	9558	Economy	10900.00
0005434756545	9558	Economy	10900.00
0005434214212	9558	Economy	10900.00
0005434756522	9558	Economy	10900.00
0005434756515	9558	Economy	10900.00
0005434214127	9558	Economy	10900.00
0005434214143	9558	Economy	10900.00
0005434756543	9558	Economy	10900.00
0005434756523	9558	Economy	10900.00
0005434214230	9558	Economy	10900.00
0005434756552	9558	Economy	10900.00
0005434756531	9558	Economy	10900.00
0005434214285	9558	Economy	10900.00
0005434214061	9558	Economy	10900.00
0005434756556	9558	Economy	10900.00
0005434756561	9558	Economy	10900.00
0005434214164	9558	Economy	10900.00
0005434756520	9558	Economy	10900.00
0005434756532	9558	Economy	10900.00
0005434756533	9558	Economy	10900.00
0005434756562	9558	Economy	10900.00
0005434214286	9558	Economy	10900.00
0005434214177	9558	Economy	10900.00
0005434756555	9558	Economy	10900.00
0005434214129	9558	Economy	10900.00
0005434214278	9558	Economy	10900.00
0005434756544	9558	Economy	10900.00
0005434756536	9558	Economy	10900.00
0005434214246	9558	Economy	10900.00
0005434756542	9558	Economy	10900.00
0005434756521	9558	Economy	10900.00
0005434756553	9558	Economy	10900.00
0005434756551	9558	Economy	10900.00
0005434214141	9558	Economy	10900.00
0005434214112	9558	Economy	10900.00
0005434214107	9558	Economy	10900.00
0005434756548	9558	Economy	10900.00
0005434756534	9558	Economy	10900.00
0005434214329	9558	Economy	10900.00
0005434214211	9558	Economy	10900.00
0005434756530	9558	Economy	10900.00
0005434756518	9558	Economy	10900.00
0005434756519	9558	Economy	10900.00
0005434214138	9558	Economy	10900.00
0005434756529	9558	Economy	10900.00
0005434214622	28636	Business	32800.00
0005434756041	28636	Business	32800.00
0005434755985	28636	Business	32800.00
0005434214647	28636	Business	32800.00
0005434214617	28636	Business	32800.00
0005434214625	28636	Business	32800.00
0005434214634	28636	Business	32800.00
0005434756237	28636	Business	32800.00
0005434756120	28636	Business	32800.00
0005434214607	28636	Business	32800.00
0005434756121	28636	Business	32800.00
0005434214623	28636	Economy	10900.00
0005434214615	28636	Economy	10900.00
0005434214636	28636	Economy	10900.00
0005434214609	28636	Economy	10900.00
0005434755927	28636	Economy	10900.00
0005434756197	28636	Economy	10900.00
0005434214618	28636	Economy	10900.00
0005434756044	28636	Economy	10900.00
0005434214630	28636	Economy	10900.00
0005434214614	28636	Economy	12000.00
0005434214606	28636	Economy	12000.00
0005434756046	28636	Economy	12000.00
0005434756153	28636	Economy	12000.00
0005434756115	28636	Economy	10900.00
0005434756193	28636	Economy	12000.00
0005434756033	28636	Economy	10900.00
0005434756157	28636	Economy	10900.00
0005434756229	28636	Economy	10900.00
0005434756045	28636	Economy	10900.00
0005434214632	28636	Economy	10900.00
0005434214610	28636	Economy	10900.00
0005434756133	28636	Economy	10900.00
0005434214643	28636	Economy	10900.00
0005434214646	28636	Economy	10900.00
0005434756135	28636	Economy	10900.00
0005434214626	28636	Economy	10900.00
0005434756122	28636	Economy	10900.00
0005434214608	28636	Economy	10900.00
0005434214613	28636	Economy	10900.00
0005434214602	28636	Economy	10900.00
0005434756230	28636	Economy	10900.00
0005434756262	28636	Economy	10900.00
0005434214640	28636	Economy	10900.00
0005434756002	28636	Economy	10900.00
0005434755908	28636	Economy	10900.00
0005434214633	28636	Economy	10900.00
0005434214635	28636	Economy	10900.00
0005434214631	28636	Economy	10900.00
0005434756105	28636	Economy	10900.00
0005434756238	28636	Economy	10900.00
0005434214649	28636	Economy	10900.00
0005434756014	28636	Economy	10900.00
0005434214604	28636	Economy	10900.00
0005434214648	28636	Economy	10900.00
0005434214638	28636	Economy	10900.00
0005434214627	28636	Economy	10900.00
0005434756178	28636	Economy	10900.00
0005434755928	28636	Economy	10900.00
0005434756089	28636	Economy	10900.00
0005434756022	28636	Economy	10900.00
0005434756108	28636	Economy	10900.00
0005434756071	28636	Economy	10900.00
0005434214624	28636	Economy	10900.00
0005434214621	28636	Economy	10900.00
0005434756011	28636	Economy	10900.00
0005434214642	28636	Economy	10900.00
0005434214620	28636	Economy	10900.00
0005434214611	28636	Economy	10900.00
0005434756037	28636	Economy	10900.00
0005434214637	28636	Economy	10900.00
0005434214619	28636	Economy	10900.00
0005434214616	28636	Economy	10900.00
0005434214644	28636	Economy	10900.00
0005434756228	28636	Economy	10900.00
0005434214629	28636	Economy	10900.00
0005434214605	28636	Economy	10900.00
0005434756113	28636	Economy	10900.00
0005434214639	28636	Economy	10900.00
0005434214628	28636	Economy	10900.00
0005434214603	28636	Economy	10900.00
0005434756180	28636	Economy	10900.00
0005434214612	28636	Economy	10900.00
0005434755907	28636	Economy	10900.00
0005434214645	28636	Economy	10900.00
0005434756181	28636	Economy	10900.00
0005434756085	28636	Economy	10900.00
0005434214641	28636	Economy	10900.00
0005434760184	10857	Economy	8900.00
0005435100133	10857	Economy	8900.00
0005434760173	10857	Economy	8900.00
0005435100132	10857	Economy	8900.00
0005435100131	10857	Economy	8900.00
0005435100107	31814	Economy	8900.00
0005434760205	31814	Economy	8900.00
0005435100106	31814	Economy	8900.00
0005435100111	31814	Economy	8900.00
0005435100108	31814	Economy	8900.00
0005434760204	31814	Economy	8900.00
0005435100109	31814	Economy	8900.00
0005434639399	1991	Economy	20900.00
0005434639417	1991	Economy	20900.00
0005434639408	1991	Economy	20900.00
0005434639398	1991	Economy	20900.00
0005434639397	1991	Economy	19000.00
0005433202302	1991	Economy	19000.00
0005434639419	1991	Economy	19000.00
0005434639400	1991	Economy	19000.00
0005434639415	1991	Economy	19000.00
0005434639403	1991	Economy	19000.00
0005433202210	1991	Economy	19000.00
0005434639409	1991	Economy	19000.00
0005434639405	1991	Economy	19000.00
0005433202223	1991	Economy	19000.00
0005434639421	1991	Economy	19000.00
0005434639411	1991	Economy	19000.00
0005434639402	1991	Economy	19000.00
0005433202248	1991	Economy	19000.00
0005433202281	1991	Economy	19000.00
0005434639401	1991	Economy	19000.00
0005433202276	1991	Economy	19000.00
0005434639394	1991	Economy	19000.00
0005434639418	1991	Economy	19000.00
0005433202277	1991	Economy	19000.00
0005432290644	1991	Economy	19000.00
0005433202225	1991	Economy	19000.00
0005433202285	1991	Economy	19000.00
0005434639416	1991	Economy	19000.00
0005434639406	1991	Economy	19000.00
0005434639410	1991	Economy	19000.00
0005434639404	1991	Economy	19000.00
0005433202290	1991	Economy	19000.00
0005433202245	1991	Economy	19000.00
0005433202299	1991	Economy	19000.00
0005434639407	1991	Economy	19000.00
0005434639395	1991	Economy	19000.00
0005434639412	1991	Economy	19000.00
0005434639396	1991	Economy	19000.00
0005434639414	1991	Economy	19000.00
0005434639413	1991	Economy	19000.00
0005432290643	1991	Economy	19000.00
0005434639420	1991	Economy	19000.00
0005433202396	23294	Economy	20900.00
0005434639177	23294	Economy	20900.00
0005434639018	23294	Economy	20900.00
0005433202391	23294	Economy	20900.00
0005434639240	23294	Economy	19000.00
0005434639125	23294	Economy	19000.00
0005433202400	23294	Economy	19000.00
0005434639143	23294	Economy	19000.00
0005434639138	23294	Economy	19000.00
0005433202389	23294	Economy	19000.00
0005434639198	23294	Economy	19000.00
0005433202398	23294	Economy	19000.00
0005434639244	23294	Economy	19000.00
0005433202395	23294	Economy	19000.00
0005434639069	23294	Economy	19000.00
0005433202401	23294	Economy	19000.00
0005434639092	23294	Economy	19000.00
0005434639203	23294	Economy	19000.00
0005434639178	23294	Economy	19000.00
0005434639137	23294	Economy	19000.00
0005434639239	23294	Economy	19000.00
0005434639127	23294	Economy	19000.00
0005434639200	23294	Economy	19000.00
0005434639111	23294	Economy	19000.00
0005434639243	23294	Economy	19000.00
0005434639199	23294	Economy	19000.00
0005434639136	23294	Economy	19000.00
0005434639103	23294	Economy	19000.00
0005434639145	23294	Economy	19000.00
0005434639081	23294	Economy	19000.00
0005434639202	23294	Economy	19000.00
0005434639128	23294	Economy	19000.00
0005433202397	23294	Economy	19000.00
0005434639071	23294	Economy	19000.00
0005433202402	23294	Economy	19000.00
0005434639172	23294	Economy	19000.00
0005434639201	23294	Economy	19000.00
0005433202394	23294	Economy	19000.00
0005434639162	23294	Economy	19000.00
0005434639083	23294	Economy	19000.00
0005434639144	23294	Economy	19000.00
0005433202399	23294	Economy	19000.00
0005434639173	23294	Economy	19000.00
0005433202392	23294	Economy	19000.00
0005433202390	23294	Economy	19000.00
0005434639068	23294	Economy	19000.00
0005434639110	23294	Economy	19000.00
0005433202393	23294	Economy	19000.00
0005434639102	23294	Economy	19000.00
0005435326630	6077	Business	69700.00
0005435326682	6077	Business	69700.00
0005434600879	6077	Business	69700.00
0005434600897	6077	Business	69700.00
0005433533318	6077	Business	69700.00
0005435326621	6077	Business	69700.00
0005434600881	6077	Business	69700.00
0005434600899	6077	Business	69700.00
0005433531305	6077	Economy	23200.00
0005434600878	6077	Economy	23200.00
0005432111288	6077	Economy	23200.00
0005433533319	6077	Economy	23200.00
0005432111287	6077	Economy	23200.00
0005434600885	6077	Economy	23200.00
0005434600905	6077	Economy	25600.00
0005434600896	6077	Economy	25600.00
0005434600880	6077	Economy	25600.00
0005434600895	6077	Economy	25600.00
0005435326738	6077	Economy	23200.00
0005434600900	6077	Economy	23200.00
0005434600904	6077	Economy	23200.00
0005435326631	6077	Economy	23200.00
0005435326665	6077	Economy	23200.00
0005434600882	6077	Economy	23200.00
0005434600890	6077	Economy	23200.00
0005433533322	6077	Economy	23200.00
0005434600902	6077	Economy	23200.00
0005435326633	6077	Economy	23200.00
0005434600892	6077	Economy	23200.00
0005434600893	6077	Economy	23200.00
0005434600888	6077	Economy	23200.00
0005434600886	6077	Economy	23200.00
0005435326697	6077	Economy	23200.00
0005434600894	6077	Economy	23200.00
0005435326632	6077	Economy	23200.00
0005434600884	6077	Economy	23200.00
0005433531306	6077	Economy	23200.00
0005434600903	6077	Economy	23200.00
0005435326696	6077	Economy	23200.00
0005434600891	6077	Economy	23200.00
0005433533320	6077	Economy	23200.00
0005434600883	6077	Economy	23200.00
0005435326620	6077	Economy	23200.00
0005434600898	6077	Economy	23200.00
0005433533321	6077	Economy	23200.00
0005433531304	6077	Economy	23200.00
0005434600889	6077	Economy	23200.00
0005434600901	6077	Economy	23200.00
0005435326663	6077	Economy	23200.00
0005435326660	6077	Economy	23200.00
0005434600887	6077	Economy	23200.00
0005434600906	6077	Economy	23200.00
0005433527220	18570	Business	69700.00
0005434600547	18570	Business	69700.00
0005434600611	18570	Business	69700.00
0005434600586	18570	Business	69700.00
0005435326794	18570	Business	69700.00
0005433531272	18570	Business	69700.00
0005434600664	18570	Economy	23200.00
0005434600731	18570	Economy	23200.00
0005434600551	18570	Economy	25600.00
0005435326781	18570	Economy	25600.00
0005434600744	18570	Economy	25600.00
0005434600702	18570	Economy	23200.00
0005435326792	18570	Economy	23200.00
0005433531260	18570	Economy	23200.00
0005435326784	18570	Economy	23200.00
0005433527226	18570	Economy	23200.00
0005434600701	18570	Economy	23200.00
0005433531259	18570	Economy	23200.00
0005435326790	18570	Economy	23200.00
0005435326793	18570	Economy	23200.00
0005435326783	18570	Economy	23200.00
0005435326782	18570	Economy	23200.00
0005433531267	18570	Economy	23200.00
0005433527214	18570	Economy	23200.00
0005433531268	18570	Economy	23200.00
0005434600546	18570	Economy	23200.00
0005434600722	18570	Economy	23200.00
0005435326791	18570	Economy	23200.00
0005434600603	18570	Economy	23200.00
0005435326787	18570	Economy	23200.00
0005435326789	18570	Economy	23200.00
0005435326788	18570	Economy	23200.00
0005435326785	18570	Economy	23200.00
0005433531265	18570	Economy	23200.00
0005433531258	18570	Economy	23200.00
0005433531271	18570	Economy	23200.00
0005434600641	18570	Economy	23200.00
0005435326786	18570	Economy	23200.00
0005434600688	18570	Economy	23200.00
0005434600656	18570	Economy	23200.00
0005434600755	18570	Economy	23200.00
0005434558291	10567	Business	9100.00
0005434558296	10567	Business	9100.00
0005434551350	10567	Business	9100.00
0005434551378	10567	Business	9100.00
0005434558302	10567	Business	9100.00
0005434551371	10567	Business	9100.00
0005434551346	10567	Business	9100.00
0005434551355	10567	Business	9100.00
0005434554070	10567	Business	9100.00
0005434551344	10567	Business	9100.00
0005434551334	10567	Business	9100.00
0005434551337	10567	Economy	3000.00
0005434551343	10567	Economy	3000.00
0005434551333	10567	Economy	3000.00
0005434558290	10567	Economy	3000.00
0005434551358	10567	Economy	3000.00
0005433180970	10567	Economy	3000.00
0005433180971	10567	Economy	3000.00
0005434551361	10567	Economy	3000.00
0005434554072	10567	Economy	3000.00
0005434551359	10567	Economy	3000.00
0005433180810	10567	Economy	3300.00
0005434551362	10567	Economy	3300.00
0005434558299	10567	Economy	3300.00
0005434551380	10567	Economy	3300.00
0005434551349	10567	Economy	3000.00
0005434551368	10567	Economy	3000.00
0005433180878	10567	Economy	3000.00
0005434551369	10567	Economy	3000.00
0005433180995	10567	Economy	3000.00
0005434558294	10567	Economy	3000.00
0005434551331	10567	Economy	3000.00
0005433180938	10567	Economy	3000.00
0005433180972	10567	Economy	3000.00
0005434558300	10567	Economy	3000.00
0005434551329	10567	Economy	3000.00
0005434551341	10567	Economy	3000.00
0005434558297	10567	Economy	3000.00
0005434551342	10567	Economy	3000.00
0005434551326	10567	Economy	3000.00
0005434551376	10567	Economy	3000.00
0005433180859	10567	Economy	3000.00
0005434551347	10567	Economy	3000.00
0005434558301	10567	Economy	3000.00
0005434551365	10567	Economy	3000.00
0005433180927	10567	Economy	3000.00
0005434554071	10567	Economy	3000.00
0005434551330	10567	Economy	3000.00
0005434551327	10567	Economy	3000.00
0005433180907	10567	Economy	3000.00
0005434551375	10567	Economy	3000.00
0005434551336	10567	Economy	3000.00
0005434551332	10567	Economy	3000.00
0005434551354	10567	Economy	3000.00
0005434558298	10567	Economy	3000.00
0005434551366	10567	Economy	3000.00
0005433180996	10567	Economy	3000.00
0005434551353	10567	Economy	3000.00
0005434558295	10567	Economy	3000.00
0005434551363	10567	Economy	3000.00
0005434551335	10567	Economy	3000.00
0005434551345	10567	Economy	3000.00
0005434554073	10567	Economy	3000.00
0005434551352	10567	Economy	3000.00
0005433180986	10567	Economy	3000.00
0005434558293	10567	Economy	3000.00
0005434551364	10567	Economy	3000.00
0005433180891	10567	Economy	3000.00
0005433180950	10567	Economy	3000.00
0005434551367	10567	Economy	3000.00
0005434551374	10567	Economy	3000.00
0005434558289	10567	Economy	3000.00
0005433180916	10567	Economy	3000.00
0005434551339	10567	Economy	3000.00
0005434551340	10567	Economy	3000.00
0005434551324	10567	Economy	3000.00
0005433180906	10567	Economy	3000.00
0005434551338	10567	Economy	3000.00
0005433180905	10567	Economy	3000.00
0005434551379	10567	Economy	3000.00
0005434551351	10567	Economy	3000.00
0005433180908	10567	Economy	3000.00
0005434551357	10567	Economy	3000.00
0005434551325	10567	Economy	3000.00
0005434551328	10567	Economy	3000.00
0005434558292	10567	Economy	3000.00
0005434551370	10567	Economy	3000.00
0005434551348	10567	Economy	3000.00
0005434551377	10567	Economy	3000.00
0005434551360	10567	Economy	3000.00
0005434551372	10567	Economy	3000.00
0005434551356	10567	Economy	3000.00
0005434551373	10567	Economy	3000.00
0005433180933	10567	Economy	3000.00
0005433181173	27723	Business	9100.00
0005433181185	27723	Business	9100.00
0005433181179	27723	Business	9100.00
0005433181167	27723	Business	9100.00
0005433181183	27723	Economy	3000.00
0005433181186	27723	Economy	3000.00
0005433181188	27723	Economy	3300.00
0005433181175	27723	Economy	3300.00
0005433181166	27723	Economy	3300.00
0005433181187	27723	Economy	3000.00
0005433181189	27723	Economy	3000.00
0005433181172	27723	Economy	3000.00
0005433181178	27723	Economy	3000.00
0005433181171	27723	Economy	3000.00
0005433181170	27723	Economy	3000.00
0005433181168	27723	Economy	3000.00
0005433181165	27723	Economy	3000.00
0005433181182	27723	Economy	3000.00
0005433181184	27723	Economy	3000.00
0005433181177	27723	Economy	3000.00
0005433181181	27723	Economy	3000.00
0005433181176	27723	Economy	3000.00
0005433181174	27723	Economy	3000.00
0005433181169	27723	Economy	3000.00
0005433181190	27723	Economy	3000.00
0005433181180	27723	Economy	3000.00
0005434558223	27722	Business	9100.00
0005434551013	27722	Business	9100.00
0005434551201	27722	Business	9100.00
0005434550629	27722	Business	9100.00
0005434550975	27722	Business	9100.00
0005434551050	27722	Business	9100.00
0005434550908	27722	Business	9100.00
0005434550989	27722	Business	9100.00
0005434550995	27722	Business	9100.00
0005434550843	27722	Business	9100.00
0005434550954	27722	Economy	3000.00
0005434550924	27722	Economy	3000.00
0005434550658	27722	Economy	3000.00
0005434550849	27722	Economy	3000.00
0005434550712	27722	Economy	3000.00
0005434550909	27722	Economy	3000.00
0005434550842	27722	Economy	3300.00
0005434550630	27722	Economy	3300.00
0005434551086	27722	Economy	3300.00
0005434551108	27722	Economy	3300.00
0005434550985	27722	Economy	3000.00
0005434550772	27722	Economy	3000.00
0005434550910	27722	Economy	3000.00
0005434550934	27722	Economy	3000.00
0005434550914	27722	Economy	3000.00
0005434551025	27722	Economy	3000.00
0005434551032	27722	Economy	3000.00
0005434551109	27722	Economy	3000.00
0005434550929	27722	Economy	3000.00
0005434550848	27722	Economy	3000.00
0005434550986	27722	Economy	3000.00
0005434550990	27722	Economy	3000.00
0005434550888	27722	Economy	3000.00
0005434550713	27722	Economy	3000.00
0005434551092	27722	Economy	3000.00
0005434550972	27722	Economy	3000.00
0005434550977	27722	Economy	3000.00
0005434558224	27722	Economy	3000.00
0005434558205	27722	Economy	3000.00
0005434551122	27722	Economy	3000.00
0005434550978	27722	Economy	3000.00
0005434551091	27722	Economy	3000.00
0005434558198	27722	Economy	3000.00
0005434558214	27722	Economy	3000.00
0005434551114	27722	Economy	3000.00
0005434550922	27722	Economy	3000.00
0005434550880	27722	Economy	3000.00
0005434550974	27722	Economy	3000.00
0005434550955	27722	Economy	3000.00
0005434554060	27722	Economy	3000.00
0005434551085	27722	Economy	3000.00
0005434550923	27722	Economy	3000.00
0005434551034	27722	Economy	3000.00
0005434551033	27722	Economy	3000.00
0005434550962	27722	Economy	3000.00
0005434550921	27722	Economy	3000.00
0005434550813	27722	Economy	3000.00
0005434550984	27722	Economy	3000.00
0005434550928	27722	Economy	3000.00
0005434550560	27722	Economy	3000.00
0005434558215	27722	Economy	3000.00
0005434551012	27722	Economy	3000.00
0005434551115	27722	Economy	3000.00
0005434551019	27722	Economy	3000.00
0005434551123	27722	Economy	3000.00
0005434550991	27722	Economy	3000.00
0005434550939	27722	Economy	3000.00
0005434550920	27722	Economy	3000.00
0005434550992	27722	Economy	3000.00
0005434554059	27722	Economy	3000.00
0005434551052	27722	Economy	3000.00
0005434551093	27722	Economy	3000.00
0005434550971	27722	Economy	3000.00
0005434550618	27722	Economy	3000.00
0005433459233	6172	Economy	11700.00
0005435254455	6172	Economy	11700.00
0005435254452	6172	Economy	11700.00
0005435254451	6172	Economy	11700.00
0005433459232	6172	Economy	11700.00
0005433459230	6172	Economy	11700.00
0005435254470	6172	Economy	11700.00
0005433459231	6172	Economy	11700.00
0005435254469	6172	Economy	11700.00
0005435254483	19302	Economy	11700.00
0005433459200	19302	Economy	11700.00
0005432533276	6751	Business	51100.00
0005435682244	6751	Business	51100.00
0005432136185	6751	Business	51100.00
0005435437761	6751	Business	51100.00
0005432136183	6751	Business	51100.00
0005435221509	6751	Business	51100.00
0005435682276	6751	Business	51100.00
0005435437818	6751	Business	51100.00
0005435682251	6751	Business	51100.00
0005435682257	6751	Business	51100.00
0005435682281	6751	Business	51100.00
0005435682264	6751	Business	51100.00
0005435437802	6751	Economy	17000.00
0005432136184	6751	Economy	17000.00
0005435221507	6751	Economy	17000.00
0005435682262	6751	Economy	17000.00
0005435682267	6751	Economy	17000.00
0005435437829	6751	Economy	17000.00
0005435220318	6751	Economy	17000.00
0005435437825	6751	Economy	17000.00
0005435682250	6751	Economy	17000.00
0005435682269	6751	Economy	17000.00
0005435437855	6751	Economy	18700.00
0005432136182	6751	Economy	18700.00
0005432136186	6751	Economy	18700.00
0005435437817	6751	Economy	18700.00
0005435682258	6751	Economy	18700.00
0005435437838	6751	Economy	17000.00
0005435221508	6751	Economy	17000.00
0005435682247	6751	Economy	17000.00
0005435437826	6751	Economy	17000.00
0005435437845	6751	Economy	17000.00
0005435682259	6751	Economy	17000.00
0005432533272	6751	Economy	17000.00
0005435682275	6751	Economy	17000.00
0005432136181	6751	Economy	17000.00
0005435220296	6751	Economy	17000.00
0005434828667	6751	Economy	17000.00
0005435437807	6751	Economy	17000.00
0005435682243	6751	Economy	17000.00
0005435682266	6751	Economy	17000.00
0005435682285	6751	Economy	17000.00
0005435682253	6751	Economy	17000.00
0005435682280	6751	Economy	17000.00
0005435437937	6751	Economy	17000.00
0005435220303	6751	Economy	17000.00
0005435437748	6751	Economy	17000.00
0005435437905	6751	Economy	17000.00
0005435437839	6751	Economy	17000.00
0005435682245	6751	Economy	17000.00
0005435682274	6751	Economy	17000.00
0005435682252	6751	Economy	17000.00
0005435682279	6751	Economy	17000.00
0005435682282	6751	Economy	17000.00
0005435682249	6751	Economy	17000.00
0005435682272	6751	Economy	17000.00
0005435661937	6751	Economy	17000.00
0005435630973	6751	Economy	17000.00
0005435437870	6751	Economy	17000.00
0005435682270	6751	Economy	17000.00
0005435437758	6751	Economy	17000.00
0005435661938	6751	Economy	17000.00
0005435682246	6751	Economy	17000.00
0005435630972	6751	Economy	17000.00
0005435682263	6751	Economy	17000.00
0005435682242	6751	Economy	17000.00
0005435437801	6751	Economy	17000.00
0005435437828	6751	Economy	17000.00
0005435217705	6751	Economy	17000.00
0005435661936	6751	Economy	17000.00
0005435630974	6751	Economy	17000.00
0005435437862	6751	Economy	17000.00
0005435682268	6751	Economy	17000.00
0005435437883	6751	Economy	17000.00
0005435682254	6751	Economy	17000.00
0005435682278	6751	Economy	17000.00
0005435682248	6751	Economy	17000.00
0005435682255	6751	Economy	17000.00
0005435682283	6751	Economy	17000.00
0005435437803	6751	Economy	17000.00
0005435682284	6751	Economy	17000.00
0005435682277	6751	Economy	17000.00
0005435437834	6751	Economy	17000.00
0005435437882	6751	Economy	17000.00
0005435437757	6751	Economy	17000.00
0005435437860	6751	Economy	17000.00
0005435437878	6751	Economy	17000.00
0005435437844	6751	Economy	17000.00
0005435682261	6751	Economy	17000.00
0005435682271	6751	Economy	17000.00
0005435437854	6751	Economy	17000.00
0005435682265	6751	Economy	17000.00
0005435682256	6751	Economy	17000.00
0005435682273	6751	Economy	17000.00
0005435437827	6751	Economy	17000.00
0005435682260	6751	Economy	17000.00
0005435681724	24565	Business	51100.00
0005435681837	24565	Business	51100.00
0005435720817	24565	Business	51100.00
0005435681619	24565	Business	51100.00
0005435438018	24565	Business	51100.00
0005435719558	24565	Business	51100.00
0005435681772	24565	Business	51100.00
0005435681941	24565	Business	51100.00
0005435681800	24565	Business	51100.00
0005435681972	24565	Business	51100.00
0005435438027	24565	Business	51100.00
0005435681993	24565	Economy	17000.00
0005435438028	24565	Economy	17000.00
0005435719559	24565	Economy	17000.00
0005435681771	24565	Economy	17000.00
0005435681866	24565	Economy	17000.00
0005435681928	24565	Economy	17000.00
0005435682027	24565	Economy	17000.00
0005435681920	24565	Economy	17000.00
0005435438015	24565	Economy	17000.00
0005435681965	24565	Economy	18700.00
0005435681885	24565	Economy	18700.00
0005435681825	24565	Economy	18700.00
0005435438019	24565	Economy	18700.00
0005435681805	24565	Economy	17000.00
0005435438012	24565	Economy	17000.00
0005434828707	24565	Economy	17000.00
0005432533302	24565	Economy	17000.00
0005435438021	24565	Economy	17000.00
0005435438020	24565	Economy	17000.00
0005435438016	24565	Economy	17000.00
0005435438008	24565	Economy	17000.00
0005435682099	24565	Economy	17000.00
0005435719560	24565	Economy	17000.00
0005435681725	24565	Economy	17000.00
0005435681873	24565	Economy	17000.00
0005435438009	24565	Economy	17000.00
0005435661907	24565	Economy	17000.00
0005435681926	24565	Economy	17000.00
0005435681831	24565	Economy	17000.00
0005435681770	24565	Economy	17000.00
0005435681733	24565	Economy	17000.00
0005435438011	24565	Economy	17000.00
0005435438025	24565	Economy	17000.00
0005435681620	24565	Economy	17000.00
0005435438006	24565	Economy	17000.00
0005435682008	24565	Economy	17000.00
0005432305756	24565	Economy	17000.00
0005435630949	24565	Economy	17000.00
0005435630950	24565	Economy	17000.00
0005435681973	24565	Economy	17000.00
0005435682115	24565	Economy	17000.00
0005432533299	24565	Economy	17000.00
0005435681838	24565	Economy	17000.00
0005434828706	24565	Economy	17000.00
0005435438017	24565	Economy	17000.00
0005435681900	24565	Economy	17000.00
0005435681832	24565	Economy	17000.00
0005435681999	24565	Economy	17000.00
0005435681750	24565	Economy	17000.00
0005435719564	24565	Economy	17000.00
0005432533301	24565	Economy	17000.00
0005435438007	24565	Economy	17000.00
0005435438022	24565	Economy	17000.00
0005435438026	24565	Economy	17000.00
0005435438013	24565	Economy	17000.00
0005435438024	24565	Economy	17000.00
0005435681801	24565	Economy	17000.00
0005435681737	24565	Economy	17000.00
0005435438023	24565	Economy	17000.00
0005435661917	24565	Economy	17000.00
0005435681736	24565	Economy	17000.00
0005435438010	24565	Economy	17000.00
0005435661921	24565	Economy	17000.00
0005434828705	24565	Economy	17000.00
0005435682055	24565	Economy	17000.00
0005435438014	24565	Economy	17000.00
0005435681962	24565	Economy	17000.00
0005435681910	24565	Economy	17000.00
0005435681925	24565	Economy	17000.00
0005432533300	24565	Economy	17000.00
0005435681929	24565	Economy	17000.00
0005435126474	11503	Business	26400.00
0005435126464	11503	Business	26400.00
0005435126479	11503	Business	26400.00
0005435126449	11503	Economy	8800.00
0005435126452	11503	Economy	8800.00
0005435126438	11503	Economy	8800.00
0005435126459	11503	Economy	9700.00
0005435126463	11503	Economy	9700.00
0005435105988	11503	Economy	8800.00
0005435126458	11503	Economy	8800.00
0005435126439	11503	Economy	8800.00
0005435126442	11503	Economy	8800.00
0005435126471	11503	Economy	8800.00
0005435126440	11503	Economy	8800.00
0005435126456	11503	Economy	8800.00
0005435105990	11503	Economy	8800.00
0005435126465	11503	Economy	8800.00
0005435558077	11503	Economy	8800.00
0005435126468	11503	Economy	8800.00
0005435558076	11503	Economy	8800.00
0005435126472	11503	Economy	8800.00
0005435126477	11503	Economy	8800.00
0005435126457	11503	Economy	8800.00
0005435126443	11503	Economy	8800.00
0005435105989	11503	Economy	8800.00
0005435126445	11503	Economy	8800.00
0005435558071	11503	Economy	8800.00
0005435126447	11503	Economy	8800.00
0005435126460	11503	Economy	8800.00
0005435126441	11503	Economy	8800.00
0005435126478	11503	Economy	8800.00
0005435126453	11503	Economy	8800.00
0005435126461	11503	Economy	8800.00
0005435126466	11503	Economy	8800.00
0005435126450	11503	Economy	8800.00
0005435126448	11503	Economy	8800.00
0005435126467	11503	Economy	8800.00
0005435126475	11503	Economy	8800.00
0005435126446	11503	Economy	8800.00
0005435126454	11503	Economy	8800.00
0005435126451	11503	Economy	8800.00
0005435126469	11503	Economy	8800.00
0005435126480	11503	Economy	8800.00
0005435126476	11503	Economy	8800.00
0005435126470	11503	Economy	8800.00
0005435126455	11503	Economy	8800.00
0005435126444	11503	Economy	8800.00
0005435126473	11503	Economy	8800.00
0005435126462	11503	Economy	8800.00
0005435126117	31876	Business	26400.00
0005435126221	31876	Economy	8800.00
0005435126238	31876	Economy	8800.00
0005435126143	31876	Economy	8800.00
0005435126025	31876	Economy	8800.00
0005435098541	31876	Economy	8800.00
0005435126200	31876	Economy	9700.00
0005435126011	31876	Economy	9700.00
0005435558096	31876	Economy	9700.00
0005435126155	31876	Economy	9700.00
0005435126141	31876	Economy	8800.00
0005435126094	31876	Economy	8800.00
0005435126144	31876	Economy	8800.00
0005435126046	31876	Economy	8800.00
0005435126108	31876	Economy	8800.00
0005435126056	31876	Economy	8800.00
0005435125940	31876	Economy	8800.00
0005435126114	31876	Economy	8800.00
0005435126084	31876	Economy	8800.00
0005435126106	31876	Economy	8800.00
0005435126095	31876	Economy	8800.00
0005435125956	31876	Economy	8800.00
0005435125955	31876	Economy	8800.00
0005435125971	31876	Economy	8800.00
0005435105952	31876	Economy	8800.00
0005435126133	31876	Economy	8800.00
0005435126291	31876	Economy	8800.00
0005435126047	31876	Economy	8800.00
0005435558094	31876	Economy	8800.00
0005435126201	31876	Economy	8800.00
0005435126088	31876	Economy	8800.00
0005435126136	31876	Economy	8800.00
0005435126026	31876	Economy	8800.00
0005435126220	31876	Economy	8800.00
0005435126062	31876	Economy	8800.00
0005435126010	31876	Economy	8800.00
0005435126154	31876	Economy	8800.00
0005435098556	31876	Economy	8800.00
0005435558095	31876	Economy	8800.00
0005435126209	31876	Economy	8800.00
0005435126063	31876	Economy	8800.00
0005435126113	31876	Economy	8800.00
0005435126252	31876	Economy	8800.00
0005435126264	31876	Economy	8800.00
0005435126135	31876	Economy	8800.00
0005435126140	31876	Economy	8800.00
0005435126126	31876	Economy	8800.00
0005435105951	31876	Economy	8800.00
0005435105955	31876	Economy	8800.00
0005435126107	31876	Economy	8800.00
0005435126093	31876	Economy	8800.00
0005433398183	13532	Business	36600.00
0005433398194	13532	Business	36600.00
0005433398186	13532	Business	36600.00
0005433398199	13532	Business	36600.00
0005433398221	13532	Business	36600.00
0005433398197	13532	Business	36600.00
0005433398216	13532	Business	36600.00
0005435732275	13532	Business	36600.00
0005433398212	13532	Business	36600.00
0005433398184	13532	Economy	12200.00
0005433398191	13532	Economy	12200.00
0005433398202	13532	Economy	12200.00
0005435732218	13532	Economy	12200.00
0005433398180	13532	Economy	12200.00
0005433398219	13532	Economy	12200.00
0005433398205	13532	Economy	13400.00
0005433398190	13532	Economy	13400.00
0005435732289	13532	Economy	13400.00
0005433398209	13532	Economy	13400.00
0005433398178	13532	Economy	12200.00
0005433398195	13532	Economy	12200.00
0005433398215	13532	Economy	12200.00
0005433398198	13532	Economy	12200.00
0005433398210	13532	Economy	12200.00
0005433398179	13532	Economy	12200.00
0005433398200	13532	Economy	12200.00
0005435732261	13532	Economy	12200.00
0005435732233	13532	Economy	12200.00
0005433398206	13532	Economy	12200.00
0005433398188	13532	Economy	12200.00
0005435732274	13532	Economy	12200.00
0005433398223	13532	Economy	12200.00
0005433398211	13532	Economy	12200.00
0005433398201	13532	Economy	12200.00
0005433398187	13532	Economy	12200.00
0005433398217	13532	Economy	12200.00
0005433398218	13532	Economy	12200.00
0005435732249	13532	Economy	12200.00
0005433398220	13532	Economy	12200.00
0005433398182	13532	Economy	12200.00
0005435732252	13532	Economy	12200.00
0005433398177	13532	Economy	12200.00
0005433398181	13532	Economy	12200.00
0005433398204	13532	Economy	12200.00
0005433398207	13532	Economy	12200.00
0005433398222	13532	Economy	12200.00
0005433398193	13532	Economy	12200.00
0005433398174	13532	Economy	12200.00
0005433398203	13532	Economy	12200.00
0005435732280	13532	Economy	12200.00
0005433398196	13532	Economy	12200.00
0005433398208	13532	Economy	12200.00
0005433398175	13532	Economy	12200.00
0005433398213	13532	Economy	12200.00
0005433398192	13532	Economy	12200.00
0005435732262	13532	Economy	12200.00
0005433398189	13532	Economy	12200.00
0005433398176	13532	Economy	12200.00
0005433398214	13532	Economy	12200.00
0005433398185	13532	Economy	12200.00
0005433397870	19369	Business	36600.00
0005433397768	19369	Business	36600.00
0005433397706	19369	Business	36600.00
0005433398027	19369	Business	36600.00
0005432297287	19369	Business	36600.00
0005433397529	19369	Economy	12200.00
0005433397705	19369	Economy	12200.00
0005435732364	19369	Economy	12200.00
0005435732361	19369	Economy	12200.00
0005433397704	19369	Economy	12200.00
0005433397903	19369	Economy	13400.00
0005433397868	19369	Economy	13400.00
0005433397716	19369	Economy	13400.00
0005433397772	19369	Economy	12200.00
0005433397681	19369	Economy	12200.00
0005433397765	19369	Economy	12200.00
0005432297284	19369	Economy	12200.00
0005432297286	19369	Economy	12200.00
0005433397849	19369	Economy	12200.00
0005433397586	19369	Economy	12200.00
0005433397883	19369	Economy	12200.00
0005433397754	19369	Economy	12200.00
0005433397869	19369	Economy	12200.00
0005433397699	19369	Economy	12200.00
0005433397610	19369	Economy	12200.00
0005433397547	19369	Economy	12200.00
0005433397773	19369	Economy	12200.00
0005433397727	19369	Economy	12200.00
0005435732365	19369	Economy	12200.00
0005433397845	19369	Economy	12200.00
0005433397650	19369	Economy	12200.00
0005433397804	19369	Economy	12200.00
0005432297288	19369	Economy	12200.00
0005433397638	19369	Economy	12200.00
0005433397879	19369	Economy	12200.00
0005433397653	19369	Economy	12200.00
0005433397840	19369	Economy	12200.00
0005433397967	19369	Economy	12200.00
0005435732363	19369	Economy	12200.00
0005435732362	19369	Economy	12200.00
0005433397993	19369	Economy	12200.00
0005433397731	19369	Economy	12200.00
0005433397767	19369	Economy	12200.00
0005433397683	19369	Economy	12200.00
0005433397757	19369	Economy	12200.00
0005433397715	19369	Economy	12200.00
0005433397764	19369	Economy	12200.00
0005433397651	19369	Economy	12200.00
0005432297285	19369	Economy	12200.00
0005433397707	19369	Economy	12200.00
0005433397877	19369	Economy	12200.00
0005433397918	19369	Economy	12200.00
0005433397771	19369	Economy	12200.00
0005433397906	19369	Economy	12200.00
0005433397701	19369	Economy	12200.00
0005433397654	19369	Economy	12200.00
0005433397703	19369	Economy	12200.00
0005433397848	19369	Economy	12200.00
0005433397656	19369	Economy	12200.00
0005433397920	19369	Economy	12200.00
0005433397756	19369	Economy	12200.00
0005433397937	19369	Economy	12200.00
0005433397700	19369	Economy	12200.00
0005433397728	19369	Economy	12200.00
0005435068698	13181	Business	11300.00
0005435068729	13181	Business	11300.00
0005435068750	13181	Business	11300.00
0005435069034	13181	Business	11300.00
0005435068724	13181	Business	11300.00
0005435068780	13181	Business	11300.00
0005435068927	13181	Business	11300.00
0005435925329	13181	Business	11300.00
0005435068735	13181	Economy	3800.00
0005435068613	13181	Economy	3800.00
0005435068728	13181	Economy	3800.00
0005435068836	13181	Economy	3800.00
0005435925336	13181	Economy	3800.00
0005435068587	13181	Economy	3800.00
0005435925328	13181	Economy	4100.00
0005435068612	13181	Economy	4100.00
0005435925335	13181	Economy	3800.00
0005435925340	13181	Economy	3800.00
0005435068751	13181	Economy	3800.00
0005435068465	13181	Economy	3800.00
0005435068782	13181	Economy	3800.00
0005435068769	13181	Economy	3800.00
0005435925326	13181	Economy	3800.00
0005435068697	13181	Economy	3800.00
0005435068553	13181	Economy	3800.00
0005435068483	13181	Economy	3800.00
0005435068676	13181	Economy	3800.00
0005435068727	13181	Economy	3800.00
0005435068916	13181	Economy	3800.00
0005435068781	13181	Economy	3800.00
0005435068738	13181	Economy	3800.00
0005435925338	13181	Economy	3800.00
0005435925331	13181	Economy	3800.00
0005435925334	13181	Economy	3800.00
0005435068670	13181	Economy	3800.00
0005435068671	13181	Economy	3800.00
0005435925332	13181	Economy	3800.00
0005435068595	13181	Economy	3800.00
0005435068753	13181	Economy	3800.00
0005435068342	13181	Economy	3800.00
0005435068943	13181	Economy	3800.00
0005435068723	13181	Economy	3800.00
0005435925337	13181	Economy	3800.00
0005435068823	13181	Economy	3800.00
0005435068923	13181	Economy	3800.00
0005435925325	13181	Economy	3800.00
0005435925333	13181	Economy	3800.00
0005435068779	13181	Economy	3800.00
0005435925330	13181	Economy	3800.00
0005435068607	13181	Economy	3800.00
0005435068594	13181	Economy	3800.00
0005435068843	13181	Economy	3800.00
0005435068533	13181	Economy	3800.00
0005435925339	13181	Economy	3800.00
0005435068730	13181	Economy	3800.00
0005435925327	13181	Economy	3800.00
0005435068768	13181	Economy	3800.00
0005435068532	13181	Economy	3800.00
0005435068924	13181	Economy	3800.00
0005435925204	15503	Business	11300.00
0005435069208	15503	Business	11300.00
0005435069168	15503	Business	11300.00
0005435925201	15503	Business	11300.00
0005435925197	15503	Business	11300.00
0005435069186	15503	Business	11300.00
0005435069201	15503	Business	11300.00
0005435069193	15503	Economy	3800.00
0005435069174	15503	Economy	3800.00
0005435069172	15503	Economy	3800.00
0005435069216	15503	Economy	3800.00
0005435069199	15503	Economy	3800.00
0005435925206	15503	Economy	3800.00
0005435069184	15503	Economy	3800.00
0005435069207	15503	Economy	3800.00
0005435069204	15503	Economy	4100.00
0005435069205	15503	Economy	4100.00
0005435925213	15503	Economy	4100.00
0005435069178	15503	Economy	4100.00
0005435925218	15503	Economy	3800.00
0005435069189	15503	Economy	3800.00
0005435069215	15503	Economy	3800.00
0005435069197	15503	Economy	3800.00
0005435069202	15503	Economy	3800.00
0005435069190	15503	Economy	3800.00
0005435925108	15503	Economy	3800.00
0005435925198	15503	Economy	3800.00
0005435069210	15503	Economy	3800.00
0005435069198	15503	Economy	3800.00
0005435069167	15503	Economy	3800.00
0005435069192	15503	Economy	3800.00
0005435069176	15503	Economy	3800.00
0005435069181	15503	Economy	3800.00
0005435925216	15503	Economy	3800.00
0005435069194	15503	Economy	3800.00
0005435069188	15503	Economy	3800.00
0005435925211	15503	Economy	3800.00
0005435069206	15503	Economy	3800.00
0005435069177	15503	Economy	3800.00
0005435925151	15503	Economy	3800.00
0005435069212	15503	Economy	3800.00
0005435069170	15503	Economy	3800.00
0005435069169	15503	Economy	3800.00
0005435925202	15503	Economy	3800.00
0005435069196	15503	Economy	3800.00
0005435069214	15503	Economy	3800.00
0005435069179	15503	Economy	3800.00
0005435069200	15503	Economy	3800.00
0005435925215	15503	Economy	3800.00
0005435069180	15503	Economy	3800.00
0005435925188	15503	Economy	3800.00
0005435069211	15503	Economy	3800.00
0005435069203	15503	Economy	3800.00
0005435069213	15503	Economy	3800.00
0005435069187	15503	Economy	3800.00
0005435069195	15503	Economy	3800.00
0005435069183	15503	Economy	3800.00
0005435069182	15503	Economy	3800.00
0005435069175	15503	Economy	3800.00
0005435069185	15503	Economy	3800.00
0005435925174	15503	Economy	3800.00
0005435069217	15503	Economy	3800.00
0005435069171	15503	Economy	3800.00
0005435069191	15503	Economy	3800.00
0005435069173	15503	Economy	3800.00
0005435069209	15503	Economy	3800.00
0005435925158	15503	Economy	3800.00
0005435808259	23186	Economy	27100.00
0005435808250	23186	Economy	27100.00
0005435808262	23186	Economy	27100.00
0005435808243	23186	Economy	27100.00
0005433407526	23186	Economy	24700.00
0005433407503	23186	Economy	24700.00
0005435808233	23186	Economy	24700.00
0005435808253	23186	Economy	24700.00
0005433407525	23186	Economy	24700.00
0005435808247	23186	Economy	24700.00
0005435808256	23186	Economy	24700.00
0005435808258	23186	Economy	24700.00
0005435808244	23186	Economy	24700.00
0005435808260	23186	Economy	24700.00
0005435808242	23186	Economy	24700.00
0005433407520	23186	Economy	24700.00
0005433407529	23186	Economy	24700.00
0005433407497	23186	Economy	24700.00
0005435808251	23186	Economy	24700.00
0005435808239	23186	Economy	24700.00
0005435808231	23186	Economy	24700.00
0005433407534	23186	Economy	24700.00
0005435808232	23186	Economy	24700.00
0005433407533	23186	Economy	24700.00
0005435808246	23186	Economy	24700.00
0005435808240	23186	Economy	24700.00
0005433407507	23186	Economy	24700.00
0005433407504	23186	Economy	24700.00
0005435808237	23186	Economy	24700.00
0005435808249	23186	Economy	24700.00
0005433407501	23186	Economy	24700.00
0005435808235	23186	Economy	24700.00
0005435808238	23186	Economy	24700.00
0005433407527	23186	Economy	24700.00
0005435808248	23186	Economy	24700.00
0005433407524	23186	Economy	24700.00
0005435808255	23186	Economy	24700.00
0005435808261	23186	Economy	24700.00
0005435808257	23186	Economy	24700.00
0005435808252	23186	Economy	24700.00
0005433407519	23186	Economy	24700.00
0005435808245	23186	Economy	24700.00
0005435808234	23186	Economy	24700.00
0005435808254	23186	Economy	24700.00
0005435808241	23186	Economy	24700.00
0005433407521	23186	Economy	24700.00
0005435808236	23186	Economy	24700.00
0005433407528	23186	Economy	24700.00
0005434214658	10683	Business	61300.00
0005434214693	10683	Business	61300.00
0005434755966	10683	Business	61300.00
0005434756102	10683	Business	61300.00
0005434756150	10683	Business	61300.00
0005434756179	10683	Business	61300.00
0005434755975	10683	Business	61300.00
0005434756124	10683	Business	61300.00
0005434756243	10683	Business	61300.00
0005434214666	10683	Business	61300.00
0005434756200	10683	Business	61300.00
0005434756148	10683	Economy	20400.00
0005434756095	10683	Economy	20400.00
0005434756126	10683	Economy	20400.00
0005434756173	10683	Economy	20400.00
0005434214681	10683	Economy	20400.00
0005434214677	10683	Economy	20400.00
0005434756138	10683	Economy	22500.00
0005434214678	10683	Economy	22500.00
0005434214676	10683	Economy	22500.00
0005434214651	10683	Economy	22500.00
0005434214690	10683	Economy	22500.00
0005434756162	10683	Economy	20400.00
0005434214695	10683	Economy	20400.00
0005434214680	10683	Economy	20400.00
0005434756171	10683	Economy	20400.00
0005434756239	10683	Economy	20400.00
0005434756268	10683	Economy	20400.00
0005434756182	10683	Economy	20400.00
0005434756029	10683	Economy	20400.00
0005434756101	10683	Economy	20400.00
0005434756177	10683	Economy	20400.00
0005434214669	10683	Economy	20400.00
0005434214689	10683	Economy	20400.00
0005434756096	10683	Economy	20400.00
0005434214687	10683	Economy	20400.00
0005434214661	10683	Economy	20400.00
0005434214679	10683	Economy	20400.00
0005434756042	10683	Economy	20400.00
0005434214686	10683	Economy	20400.00
0005434214653	10683	Economy	20400.00
0005434214667	10683	Economy	20400.00
0005434214655	10683	Economy	20400.00
0005434756269	10683	Economy	20400.00
0005434214656	10683	Economy	20400.00
0005434214683	10683	Economy	20400.00
0005434756183	10683	Economy	20400.00
0005434214665	10683	Economy	20400.00
0005434214696	10683	Economy	20400.00
0005434214674	10683	Economy	20400.00
0005434756294	10683	Economy	20400.00
0005434214685	10683	Economy	20400.00
0005434214657	10683	Economy	20400.00
0005434756149	10683	Economy	20400.00
0005434214650	10683	Economy	20400.00
0005434214691	10683	Economy	20400.00
0005434756099	10683	Economy	20400.00
0005434756373	10683	Economy	20400.00
0005434756118	10683	Economy	20400.00
0005434214664	10683	Economy	20400.00
0005434756114	10683	Economy	20400.00
0005434214692	10683	Economy	20400.00
0005434214662	10683	Economy	20400.00
0005434214673	10683	Economy	20400.00
0005434756191	10683	Economy	20400.00
0005434214675	10683	Economy	20400.00
0005434214671	10683	Economy	20400.00
0005434214670	10683	Economy	20400.00
0005434214694	10683	Economy	20400.00
0005434756125	10683	Economy	20400.00
0005434756161	10683	Economy	20400.00
0005434214688	10683	Economy	20400.00
0005434214663	10683	Economy	20400.00
0005434756116	10683	Economy	20400.00
0005434214672	10683	Economy	20400.00
0005434756107	10683	Economy	20400.00
0005434214654	10683	Economy	20400.00
0005434756267	10683	Economy	20400.00
0005434756244	10683	Economy	20400.00
0005434756043	10683	Economy	20400.00
0005434214668	10683	Economy	20400.00
0005434756210	10683	Economy	20400.00
0005434214659	10683	Economy	20400.00
0005434756190	10683	Economy	20400.00
0005434214684	10683	Economy	20400.00
0005434214652	10683	Economy	20400.00
0005434214682	10683	Economy	20400.00
0005434214660	10683	Economy	20400.00
0005434756502	28674	Business	61300.00
0005434756478	28674	Business	61300.00
0005434214291	28674	Business	61300.00
0005434756498	28674	Business	61300.00
0005434756497	28674	Business	61300.00
0005434214097	28674	Business	61300.00
0005434756495	28674	Business	61300.00
0005434214335	28674	Business	61300.00
0005434756504	28674	Business	61300.00
0005434756496	28674	Economy	20400.00
0005434756475	28674	Economy	20400.00
0005434756489	28674	Economy	20400.00
0005434756503	28674	Economy	20400.00
0005434214237	28674	Economy	20400.00
0005434756487	28674	Economy	20400.00
0005434214066	28674	Economy	20400.00
0005434756490	28674	Economy	22500.00
0005434214041	28674	Economy	22500.00
0005434756476	28674	Economy	22500.00
0005434214271	28674	Economy	22500.00
0005434214189	28674	Economy	20400.00
0005434756509	28674	Economy	20400.00
0005434756472	28674	Economy	20400.00
0005434214030	28674	Economy	20400.00
0005434214130	28674	Economy	20400.00
0005434214254	28674	Economy	20400.00
0005434756484	28674	Economy	20400.00
0005434756507	28674	Economy	20400.00
0005434214119	28674	Economy	20400.00
0005434214236	28674	Economy	20400.00
0005434756508	28674	Economy	20400.00
0005434756488	28674	Economy	20400.00
0005434756506	28674	Economy	20400.00
0005434756492	28674	Economy	20400.00
0005434756470	28674	Economy	20400.00
0005434214188	28674	Economy	20400.00
0005434214272	28674	Economy	20400.00
0005434214349	28674	Economy	20400.00
0005434756483	28674	Economy	20400.00
0005434756477	28674	Economy	20400.00
0005434756491	28674	Economy	20400.00
0005434756501	28674	Economy	20400.00
0005434756500	28674	Economy	20400.00
0005434214069	28674	Economy	20400.00
0005434214187	28674	Economy	20400.00
0005434756499	28674	Economy	20400.00
0005434756482	28674	Economy	20400.00
0005434756471	28674	Economy	20400.00
0005434756511	28674	Economy	20400.00
0005434214068	28674	Economy	20400.00
0005434756480	28674	Economy	20400.00
0005434214072	28674	Economy	20400.00
0005434756510	28674	Economy	20400.00
0005434214235	28674	Economy	20400.00
0005434756473	28674	Economy	20400.00
0005434214299	28674	Economy	20400.00
0005434756479	28674	Economy	20400.00
0005434756512	28674	Economy	20400.00
0005434214054	28674	Economy	20400.00
0005434214096	28674	Economy	20400.00
0005434756474	28674	Economy	20400.00
0005434756481	28674	Economy	20400.00
0005434214192	28674	Economy	20400.00
0005434214358	28674	Economy	20400.00
0005434756494	28674	Economy	20400.00
0005434756485	28674	Economy	20400.00
0005434756505	28674	Economy	20400.00
0005434214243	28674	Economy	20400.00
0005434756486	28674	Economy	20400.00
0005434756513	28674	Economy	20400.00
0005434756493	28674	Economy	20400.00
0005434756514	28674	Economy	20400.00
0005435042859	5430	Business	29500.00
0005435039971	5430	Business	29500.00
0005435039969	5430	Business	29500.00
0005435039952	5430	Business	29500.00
0005432125475	5430	Business	29500.00
0005435042860	5430	Business	29500.00
0005435039975	5430	Business	29500.00
0005432125472	5430	Business	29500.00
0005435039978	5430	Business	29500.00
0005435007099	5430	Business	29500.00
0005434229248	5430	Business	29500.00
0005435007091	5430	Economy	9800.00
0005435007104	5430	Economy	9800.00
0005435007103	5430	Economy	9800.00
0005435039991	5430	Economy	9800.00
0005435007102	5430	Economy	9800.00
0005435039974	5430	Economy	9800.00
0005435007095	5430	Economy	9800.00
0005435039938	5430	Economy	9800.00
0005435039955	5430	Economy	9800.00
0005435039943	5430	Economy	9800.00
0005435039964	5430	Economy	9800.00
0005435039985	5430	Economy	9800.00
0005435039948	5430	Economy	9800.00
0005435039945	5430	Economy	9800.00
0005435039973	5430	Economy	9800.00
0005435039942	5430	Economy	9800.00
0005434229296	5430	Economy	9800.00
0005435039993	5430	Economy	9800.00
0005434229218	5430	Economy	9800.00
0005435039939	5430	Economy	9800.00
0005435039970	5430	Economy	9800.00
0005435007092	5430	Economy	9800.00
0005435007106	5430	Economy	9800.00
0005435007089	5430	Economy	9800.00
0005434229183	5430	Economy	9800.00
0005434229231	5430	Economy	9800.00
0005435007086	5430	Economy	9800.00
0005435039949	5430	Economy	9800.00
0005435039994	5430	Economy	9800.00
0005435039960	5430	Economy	9800.00
0005435039986	5430	Economy	9800.00
0005432125471	5430	Economy	9800.00
0005435007105	5430	Economy	9800.00
0005435039963	5430	Economy	9800.00
0005435007098	5430	Economy	9800.00
0005434229171	5430	Economy	9800.00
0005435039941	5430	Economy	10800.00
0005435039996	5430	Economy	10800.00
0005434229234	5430	Economy	10800.00
0005435007087	5430	Economy	10800.00
0005435039968	5430	Economy	10800.00
0005434229182	5430	Economy	10800.00
0005435039966	5430	Economy	9800.00
0005435039961	5430	Economy	9800.00
0005435039987	5430	Economy	9800.00
0005435007096	5430	Economy	9800.00
0005434229330	5430	Economy	9800.00
0005435039965	5430	Economy	9800.00
0005432125473	5430	Economy	9800.00
0005435039988	5430	Economy	9800.00
0005435039932	5430	Economy	9800.00
0005435039992	5430	Economy	9800.00
0005435039944	5430	Economy	9800.00
0005435039983	5430	Economy	9800.00
0005434229232	5430	Economy	9800.00
0005435039940	5430	Economy	9800.00
0005435039957	5430	Economy	9800.00
0005435007094	5430	Economy	9800.00
0005435039982	5430	Economy	9800.00
0005435039976	5430	Economy	9800.00
0005435039953	5430	Economy	9800.00
0005435007108	5430	Economy	9800.00
0005435039962	5430	Economy	9800.00
0005435007101	5430	Economy	9800.00
0005435039954	5430	Economy	9800.00
0005435007100	5430	Economy	9800.00
0005434229285	5430	Economy	9800.00
0005435039947	5430	Economy	9800.00
0005434229200	5430	Economy	9800.00
0005432125476	5430	Economy	9800.00
0005435007085	5430	Economy	9800.00
0005435039934	5430	Economy	9800.00
0005434229243	5430	Economy	9800.00
0005435039956	5430	Economy	9800.00
0005434229302	5430	Economy	9800.00
0005435039989	5430	Economy	9800.00
0005435039981	5430	Economy	9800.00
0005435007109	5430	Economy	9800.00
0005435039979	5430	Economy	9800.00
0005434229135	5430	Economy	9800.00
0005434229261	5430	Economy	9800.00
0005435039984	5430	Economy	9800.00
0005432125470	5430	Economy	9800.00
0005435039936	5430	Economy	9800.00
0005435039972	5430	Economy	9800.00
0005435039958	5430	Economy	9800.00
0005435007090	5430	Economy	9800.00
0005435007107	5430	Economy	9800.00
0005435039967	5430	Economy	9800.00
0005435039935	5430	Economy	9800.00
0005435039950	5430	Economy	9800.00
0005435007093	5430	Economy	9800.00
0005435039959	5430	Economy	9800.00
0005435039990	5430	Economy	9800.00
0005435007097	5430	Economy	9800.00
0005435039977	5430	Economy	9800.00
0005435039946	5430	Economy	9800.00
0005432125474	5430	Economy	9800.00
0005434229199	5430	Economy	9800.00
0005435039980	5430	Economy	9800.00
0005434229142	5430	Economy	9800.00
0005435039937	5430	Economy	9800.00
0005434229233	5430	Economy	9800.00
0005434229236	5430	Economy	9800.00
0005435007088	5430	Economy	9800.00
0005435039995	5430	Economy	9800.00
0005435039951	5430	Economy	9800.00
0005435039933	5430	Economy	9800.00
0005434229431	12953	Business	29500.00
0005435039129	12953	Business	29500.00
0005435039613	12953	Business	29500.00
0005435039181	12953	Business	29500.00
0005435039574	12953	Business	29500.00
0005435006935	12953	Business	29500.00
0005435039536	12953	Business	29500.00
0005432304410	12953	Business	29500.00
0005435039439	12953	Business	29500.00
0005435039606	12953	Business	29500.00
0005435043277	12953	Business	29500.00
0005435039551	12953	Business	29500.00
0005435039127	12953	Economy	9800.00
0005435006845	12953	Economy	9800.00
0005435039407	12953	Economy	9800.00
0005434229436	12953	Economy	9800.00
0005432304409	12953	Economy	9800.00
0005435039584	12953	Economy	9800.00
0005432304408	12953	Economy	9800.00
0005434229440	12953	Economy	9800.00
0005435039501	12953	Economy	9800.00
0005435039189	12953	Economy	9800.00
0005435039621	12953	Economy	9800.00
0005435039473	12953	Economy	9800.00
0005435039409	12953	Economy	9800.00
0005435039494	12953	Economy	9800.00
0005435006821	12953	Economy	9800.00
0005435039559	12953	Economy	9800.00
0005434229449	12953	Economy	9800.00
0005435006893	12953	Economy	9800.00
0005435006906	12953	Economy	9800.00
0005435039469	12953	Economy	9800.00
0005435006875	12953	Economy	9800.00
0005435039438	12953	Economy	9800.00
0005434229450	12953	Economy	9800.00
0005435006774	12953	Economy	9800.00
0005435039128	12953	Economy	9800.00
0005435039273	12953	Economy	9800.00
0005435039464	12953	Economy	9800.00
0005435039704	12953	Economy	9800.00
0005435039374	12953	Economy	9800.00
0005435039425	12953	Economy	9800.00
0005435039404	12953	Economy	9800.00
0005435039333	12953	Economy	9800.00
0005435006859	12953	Economy	9800.00
0005435039648	12953	Economy	9800.00
0005435039560	12953	Economy	9800.00
0005434229445	12953	Economy	9800.00
0005435039150	12953	Economy	9800.00
0005435377904	12953	Economy	9800.00
0005435039413	12953	Economy	9800.00
0005435039142	12953	Economy	9800.00
0005434229434	12953	Economy	10800.00
0005435039141	12953	Economy	10800.00
0005434229443	12953	Economy	10800.00
0005435039575	12953	Economy	10800.00
0005434229447	12953	Economy	10800.00
0005435042844	12953	Economy	9800.00
0005435042843	12953	Economy	10800.00
0005435006951	12953	Economy	9800.00
0005435039539	12953	Economy	9800.00
0005435039513	12953	Economy	9800.00
0005435039447	12953	Economy	9800.00
0005434229435	12953	Economy	9800.00
0005435039153	12953	Economy	9800.00
0005435039530	12953	Economy	9800.00
0005434229437	12953	Economy	9800.00
0005435039224	12953	Economy	9800.00
0005434229441	12953	Economy	9800.00
0005435006858	12953	Economy	9800.00
0005434229433	12953	Economy	9800.00
0005435007018	12953	Economy	9800.00
0005435039537	12953	Economy	9800.00
0005435006955	12953	Economy	9800.00
0005435039332	12953	Economy	9800.00
0005435039280	12953	Economy	9800.00
0005435039424	12953	Economy	9800.00
0005435039552	12953	Economy	9800.00
0005435039292	12953	Economy	9800.00
0005435039482	12953	Economy	9800.00
0005435039437	12953	Economy	9800.00
0005434229432	12953	Economy	9800.00
0005435042838	12953	Economy	9800.00
0005435006894	12953	Economy	9800.00
0005435039204	12953	Economy	9800.00
0005435039507	12953	Economy	9800.00
0005435039403	12953	Economy	9800.00
0005435006844	12953	Economy	9800.00
0005435039576	12953	Economy	9800.00
0005435039225	12953	Economy	9800.00
0005435039694	12953	Economy	9800.00
0005435039239	12953	Economy	9800.00
0005434229430	12953	Economy	9800.00
0005435006963	12953	Economy	9800.00
0005435006916	12953	Economy	9800.00
0005434229448	12953	Economy	9800.00
0005435039272	12953	Economy	9800.00
0005435039472	12953	Economy	9800.00
0005434229446	12953	Economy	9800.00
0005435039240	12953	Economy	9800.00
0005435039423	12953	Economy	9800.00
0005432304411	12953	Economy	9800.00
0005435039535	12953	Economy	9800.00
0005435039406	12953	Economy	9800.00
0005434229442	12953	Economy	9800.00
0005435006907	12953	Economy	9800.00
0005435039399	12953	Economy	9800.00
0005435039349	12953	Economy	9800.00
0005434229438	12953	Economy	9800.00
0005434229444	12953	Economy	9800.00
0005435039514	12953	Economy	9800.00
0005435039622	12953	Economy	9800.00
0005435006860	12953	Economy	9800.00
0005435006950	12953	Economy	9800.00
0005435039542	12953	Economy	9800.00
0005435006861	12953	Economy	9800.00
0005435039096	12953	Economy	9800.00
0005435039408	12953	Economy	9800.00
0005434229439	12953	Economy	9800.00
0005435039529	12953	Economy	9800.00
0005435039520	12953	Economy	9800.00
0005435039620	12953	Economy	9800.00
0005435039430	12953	Economy	9800.00
0005435039703	12953	Economy	9800.00
0005435039446	12953	Economy	9800.00
0005435039583	12953	Economy	9800.00
0005434426668	14847	Business	52900.00
0005435902580	14847	Business	52900.00
0005435554136	14847	Business	52900.00
0005434426681	14847	Business	52900.00
0005435902654	14847	Business	52900.00
0005435554145	14847	Business	52900.00
0005434426660	14847	Business	52900.00
0005435902521	14847	Economy	17600.00
0005434426672	14847	Economy	17600.00
0005434426666	14847	Economy	17600.00
0005434411789	14847	Economy	17600.00
0005435902606	14847	Economy	17600.00
0005435902611	14847	Economy	17600.00
0005435902615	14847	Economy	17600.00
0005434411787	14847	Economy	19400.00
0005435902640	14847	Economy	19400.00
0005434426678	14847	Economy	19400.00
0005435554137	14847	Economy	17600.00
0005435902565	14847	Economy	17600.00
0005434426673	14847	Economy	17600.00
0005434426662	14847	Economy	17600.00
0005434426684	14847	Economy	17600.00
0005435554176	14847	Economy	17600.00
0005435902639	14847	Economy	17600.00
0005434426676	14847	Economy	17600.00
0005432188614	14847	Economy	17600.00
0005434426680	14847	Economy	17600.00
0005434426679	14847	Economy	17600.00
0005435902595	14847	Economy	17600.00
0005435902608	14847	Economy	17600.00
0005434426682	14847	Economy	17600.00
0005434426667	14847	Economy	17600.00
0005435902601	14847	Economy	17600.00
0005434426664	14847	Economy	17600.00
0005435902612	14847	Economy	17600.00
0005435902605	14847	Economy	17600.00
0005434426657	14847	Economy	17600.00
0005435902501	14847	Economy	17600.00
0005434426661	14847	Economy	17600.00
0005434426658	14847	Economy	17600.00
0005435554148	14847	Economy	17600.00
0005435554147	14847	Economy	17600.00
0005435902616	14847	Economy	17600.00
0005434426677	14847	Economy	17600.00
0005435902594	14847	Economy	17600.00
0005432188615	14847	Economy	17600.00
0005434426670	14847	Economy	17600.00
0005434411788	14847	Economy	17600.00
0005432188613	14847	Economy	17600.00
0005434426685	14847	Economy	17600.00
0005434426674	14847	Economy	17600.00
0005434426659	14847	Economy	17600.00
0005434426669	14847	Economy	17600.00
0005435902530	14847	Economy	17600.00
0005435554175	14847	Economy	17600.00
0005435554158	14847	Economy	17600.00
0005435902581	14847	Economy	17600.00
0005434426675	14847	Economy	17600.00
0005434426671	14847	Economy	17600.00
0005434426686	14847	Economy	17600.00
0005435902582	14847	Economy	17600.00
0005434426665	14847	Economy	17600.00
0005434411785	14847	Economy	17600.00
0005434411786	14847	Economy	17600.00
0005435902551	14847	Economy	17600.00
0005434426663	14847	Economy	17600.00
0005434426683	14847	Economy	17600.00
0005435902760	20191	Business	52900.00
0005435902754	20191	Business	52900.00
0005434426505	20191	Business	52900.00
0005435902749	20191	Business	52900.00
0005434426494	20191	Business	52900.00
0005434426508	20191	Business	52900.00
0005432059510	20191	Business	52900.00
0005434426504	20191	Economy	17600.00
0005434426432	20191	Economy	17600.00
0005434426502	20191	Economy	17600.00
0005435902759	20191	Economy	17600.00
0005434426603	20191	Economy	17600.00
0005435554204	20191	Economy	19400.00
0005435902756	20191	Economy	19400.00
0005434426546	20191	Economy	19400.00
0005434426433	20191	Economy	17600.00
0005434426493	20191	Economy	17600.00
0005435902763	20191	Economy	17600.00
0005435902765	20191	Economy	17600.00
0005434411757	20191	Economy	17600.00
0005435902761	20191	Economy	17600.00
0005435902750	20191	Economy	17600.00
0005435554205	20191	Economy	17600.00
0005434426455	20191	Economy	17600.00
0005434426398	20191	Economy	17600.00
0005435554206	20191	Economy	17600.00
0005435902753	20191	Economy	17600.00
0005435902758	20191	Economy	17600.00
0005435902748	20191	Economy	17600.00
0005434426474	20191	Economy	17600.00
0005434426554	20191	Economy	17600.00
0005435902752	20191	Economy	17600.00
0005434426392	20191	Economy	17600.00
0005432059509	20191	Economy	17600.00
0005435902764	20191	Economy	17600.00
0005434411762	20191	Economy	17600.00
0005434426591	20191	Economy	17600.00
0005435902755	20191	Economy	17600.00
0005432059511	20191	Economy	17600.00
0005434426370	20191	Economy	17600.00
0005434426371	20191	Economy	17600.00
0005435902751	20191	Economy	17600.00
0005434426475	20191	Economy	17600.00
0005434426575	20191	Economy	17600.00
0005434411763	20191	Economy	17600.00
0005435902757	20191	Economy	17600.00
0005434426448	20191	Economy	17600.00
0005435902766	20191	Economy	17600.00
0005434426328	20191	Economy	17600.00
0005435554202	20191	Economy	17600.00
0005434426576	20191	Economy	17600.00
0005435902762	20191	Economy	17600.00
0005434426372	20191	Economy	17600.00
0005434426459	20191	Economy	17600.00
0005434411770	20191	Economy	17600.00
0005434426456	20191	Economy	17600.00
0005435554203	20191	Economy	17600.00
0005434411769	20191	Economy	17600.00
0005434523756	28015	Economy	35600.00
0005434559082	28015	Economy	35600.00
0005434523754	28015	Economy	35600.00
0005434559083	28015	Economy	35600.00
0005432462514	28015	Economy	35600.00
0005432462519	28015	Economy	35600.00
0005434523759	28015	Economy	35600.00
0005434523755	28015	Economy	35600.00
0005434523748	28015	Economy	35600.00
0005432462523	28015	Economy	35600.00
0005434523747	28015	Economy	39200.00
0005432462515	28015	Economy	39200.00
0005432462520	28015	Economy	39200.00
0005434559085	28015	Economy	35600.00
0005432462517	28015	Economy	35600.00
0005434523757	28015	Economy	35600.00
0005432462521	28015	Economy	35600.00
0005434523758	28015	Economy	35600.00
0005434559087	28015	Economy	35600.00
0005432462518	28015	Economy	35600.00
0005432462522	28015	Economy	35600.00
0005434559084	28015	Economy	35600.00
0005434523753	28015	Economy	35600.00
0005432462516	28015	Economy	35600.00
0005434559086	28015	Economy	35600.00
0005434523750	28015	Economy	35600.00
0005432462490	30895	Business	106800.00
0005434523777	30895	Economy	35600.00
0005434523780	30895	Economy	35600.00
0005432462489	30895	Economy	35600.00
0005434523778	30895	Economy	35600.00
0005432462487	30895	Economy	35600.00
0005434523779	30895	Economy	35600.00
0005432462495	30895	Economy	35600.00
0005432462505	30895	Economy	35600.00
0005434523781	30895	Economy	35600.00
0005434523776	30895	Economy	35600.00
0005434523782	30895	Economy	35600.00
0005432462494	30895	Economy	35600.00
0005432462506	30895	Economy	35600.00
0005433726103	30866	Business	91700.00
0005433726098	30866	Business	91700.00
0005433726101	30866	Economy	30600.00
0005433726100	30866	Economy	30600.00
0005433726109	30866	Economy	30600.00
0005433726097	30866	Economy	30600.00
0005433726106	30866	Economy	30600.00
0005433726102	30866	Economy	30600.00
0005433726104	30866	Economy	30600.00
0005433726093	30866	Economy	30600.00
0005433726096	30866	Economy	30600.00
0005433726108	30866	Economy	30600.00
0005433726094	30866	Economy	30600.00
0005433726107	30866	Economy	30600.00
0005433726110	30866	Economy	30600.00
0005433726105	30866	Economy	30600.00
0005433726095	30866	Economy	30600.00
0005433726099	30866	Economy	30600.00
0005435982426	26535	Business	18500.00
0005435982424	26535	Business	18500.00
0005432300274	26535	Business	18500.00
0005433434513	26535	Business	18500.00
0005432300276	26535	Business	18500.00
0005435982397	26535	Business	18500.00
0005435982400	26535	Business	18500.00
0005435982434	26535	Business	18500.00
0005433434445	26535	Business	18500.00
0005432300273	26535	Business	18500.00
0005435982432	26535	Business	18500.00
0005435982394	26535	Economy	6200.00
0005435982416	26535	Economy	6200.00
0005433434677	26535	Economy	6200.00
0005435982409	26535	Economy	6200.00
0005433434530	26535	Economy	6200.00
0005435982442	26535	Economy	6200.00
0005435982441	26535	Economy	6200.00
0005435982411	26535	Economy	6200.00
0005433434461	26535	Economy	6200.00
0005433434536	26535	Economy	6200.00
0005433434417	26535	Economy	6800.00
0005435982414	26535	Economy	6800.00
0005433434533	26535	Economy	6800.00
0005435982419	26535	Economy	6800.00
0005435982410	26535	Economy	6200.00
0005435982418	26535	Economy	6200.00
0005433434541	26535	Economy	6200.00
0005435982435	26535	Economy	6200.00
0005433434434	26535	Economy	6200.00
0005435982422	26535	Economy	6200.00
0005433434444	26535	Economy	6200.00
0005435982412	26535	Economy	6200.00
0005435982420	26535	Economy	6200.00
0005435982407	26535	Economy	6200.00
0005435982440	26535	Economy	6200.00
0005435982431	26535	Economy	6200.00
0005433434460	26535	Economy	6200.00
0005435982413	26535	Economy	6200.00
0005433434446	26535	Economy	6200.00
0005435982421	26535	Economy	6200.00
0005433434623	26535	Economy	6200.00
0005433434506	26535	Economy	6200.00
0005435982405	26535	Economy	6200.00
0005435982439	26535	Economy	6200.00
0005435982406	26535	Economy	6200.00
0005433434537	26535	Economy	6200.00
0005433434459	26535	Economy	6200.00
0005435982438	26535	Economy	6200.00
0005435982428	26535	Economy	6200.00
0005433434395	26535	Economy	6200.00
0005435982393	26535	Economy	6200.00
0005435982436	26535	Economy	6200.00
0005433434553	26535	Economy	6200.00
0005435982427	26535	Economy	6200.00
0005434270202	26535	Economy	6200.00
0005435982425	26535	Economy	6200.00
0005432300277	26535	Economy	6200.00
0005435982398	26535	Economy	6200.00
0005432300275	26535	Economy	6200.00
0005435982399	26535	Economy	6200.00
0005433434462	26535	Economy	6200.00
0005435982437	26535	Economy	6200.00
0005433434622	26535	Economy	6200.00
0005434270201	26535	Economy	6200.00
0005435982403	26535	Economy	6200.00
0005435982402	26535	Economy	6200.00
0005433434424	26535	Economy	6200.00
0005435982433	26535	Economy	6200.00
0005435982401	26535	Economy	6200.00
0005433434394	26535	Economy	6200.00
0005432300278	26535	Economy	6200.00
0005435982417	26535	Economy	6200.00
0005435982395	26535	Economy	6200.00
0005433434529	26535	Economy	6200.00
0005435982396	26535	Economy	6200.00
0005435982408	26535	Economy	6200.00
0005435982404	26535	Economy	6200.00
0005433434519	26535	Economy	6200.00
0005435982429	26535	Economy	6200.00
0005435982415	26535	Economy	6200.00
0005433434433	26535	Economy	6200.00
0005435982430	26535	Economy	6200.00
0005435982423	26535	Economy	6200.00
0005433434776	26721	Business	18500.00
0005435981962	26721	Business	18500.00
0005433434771	26721	Business	18500.00
0005434271318	26721	Business	18500.00
0005433434757	26721	Business	18500.00
0005433434780	26721	Business	18500.00
0005435982152	26721	Business	18500.00
0005435982001	26721	Business	18500.00
0005435982086	26721	Business	18500.00
0005433434781	26721	Business	18500.00
0005435981940	26721	Economy	6200.00
0005433434770	26721	Economy	6200.00
0005435982020	26721	Economy	6200.00
0005434269110	26721	Economy	6200.00
0005435981843	26721	Economy	6200.00
0005433434782	26721	Economy	6200.00
0005432051137	26721	Economy	6200.00
0005435981848	26721	Economy	6200.00
0005433434775	26721	Economy	6200.00
0005435982117	26721	Economy	6800.00
0005435982104	26721	Economy	6800.00
0005433434758	26721	Economy	6800.00
0005435981842	26721	Economy	6800.00
0005435982036	26721	Economy	6200.00
0005435982042	26721	Economy	6200.00
0005433434777	26721	Economy	6200.00
0005434270214	26721	Economy	6200.00
0005435982035	26721	Economy	6200.00
0005435981929	26721	Economy	6200.00
0005433434773	26721	Economy	6200.00
0005435981927	26721	Economy	6200.00
0005433434772	26721	Economy	6200.00
0005435981990	26721	Economy	6200.00
0005435981889	26721	Economy	6200.00
0005435981844	26721	Economy	6200.00
0005435981891	26721	Economy	6200.00
0005433434783	26721	Economy	6200.00
0005435982044	26721	Economy	6200.00
0005435982103	26721	Economy	6200.00
0005434269109	26721	Economy	6200.00
0005433434756	26721	Economy	6200.00
0005435982064	26721	Economy	6200.00
0005435982154	26721	Economy	6200.00
0005433434762	26721	Economy	6200.00
0005434271319	26721	Economy	6200.00
0005435982043	26721	Economy	6200.00
0005433434764	26721	Economy	6200.00
0005435982067	26721	Economy	6200.00
0005435981928	26721	Economy	6200.00
0005433434778	26721	Economy	6200.00
0005433434760	26721	Economy	6200.00
0005433434766	26721	Economy	6200.00
0005435981892	26721	Economy	6200.00
0005435982077	26721	Economy	6200.00
0005435981937	26721	Economy	6200.00
0005435981890	26721	Economy	6200.00
0005435982164	26721	Economy	6200.00
0005433434768	26721	Economy	6200.00
0005434270212	26721	Economy	6200.00
0005434270213	26721	Economy	6200.00
0005433434763	26721	Economy	6200.00
0005433434767	26721	Economy	6200.00
0005435982080	26721	Economy	6200.00
0005433434761	26721	Economy	6200.00
0005435981901	26721	Economy	6200.00
0005435982179	26721	Economy	6200.00
0005435982081	26721	Economy	6200.00
0005435982041	26721	Economy	6200.00
0005435982027	26721	Economy	6200.00
0005435981963	26721	Economy	6200.00
0005435982051	26721	Economy	6200.00
0005433434765	26721	Economy	6200.00
0005433434779	26721	Economy	6200.00
0005435982102	26721	Economy	6200.00
0005435982066	26721	Economy	6200.00
0005433434759	26721	Economy	6200.00
0005435982074	26721	Economy	6200.00
0005432051139	26721	Economy	6200.00
0005435982105	26721	Economy	6200.00
0005433434769	26721	Economy	6200.00
0005432051138	26721	Economy	6200.00
0005433434774	26721	Economy	6200.00
0005435982054	26721	Economy	6200.00
0005433689897	29260	Economy	21000.00
0005433686622	29260	Economy	21000.00
0005433686627	29260	Economy	21000.00
0005433686613	29260	Economy	19100.00
0005433686610	29260	Economy	19100.00
0005433689894	29260	Economy	19100.00
0005433686617	29260	Economy	19100.00
0005433686618	29260	Economy	19100.00
0005433689891	29260	Economy	19100.00
0005433689893	29260	Economy	19100.00
0005433689904	29260	Economy	19100.00
0005433689905	29260	Economy	19100.00
0005433686615	29260	Economy	19100.00
0005433689896	29260	Economy	19100.00
0005433689890	29260	Economy	19100.00
0005433686621	29260	Economy	19100.00
0005433689900	29260	Economy	19100.00
0005433686603	29260	Economy	19100.00
0005433689903	29260	Economy	19100.00
0005433686616	29260	Economy	19100.00
0005433689902	29260	Economy	19100.00
0005433686611	29260	Economy	19100.00
0005433686612	29260	Economy	19100.00
0005433689895	29260	Economy	19100.00
0005433689892	29260	Economy	19100.00
0005432584112	3187	Economy	11100.00
0005432584123	3187	Economy	11100.00
0005432584109	3187	Economy	10100.00
0005432584122	3187	Economy	10100.00
0005432584106	3187	Economy	10100.00
0005432584117	3187	Economy	10100.00
0005432858022	3187	Economy	10100.00
0005432584111	3187	Economy	10100.00
0005432857990	3187	Economy	10100.00
0005432216280	3187	Economy	10100.00
0005432584114	3187	Economy	10100.00
0005432584105	3187	Economy	10100.00
0005432216281	3187	Economy	10100.00
0005432584098	3187	Economy	10100.00
0005432857979	3187	Economy	10100.00
0005432584108	3187	Economy	10100.00
0005432858021	3187	Economy	10100.00
0005432584102	3187	Economy	10100.00
0005432584113	3187	Economy	10100.00
0005432858059	3187	Economy	10100.00
0005432584100	3187	Economy	10100.00
0005432858013	3187	Economy	10100.00
0005432584107	3187	Economy	10100.00
0005432584115	3187	Economy	10100.00
0005432584099	3187	Economy	10100.00
0005432584116	3187	Economy	10100.00
0005432858023	3187	Economy	10100.00
0005432584120	3187	Economy	10100.00
0005432584121	3187	Economy	10100.00
0005432584110	3187	Economy	10100.00
0005432584103	3187	Economy	10100.00
0005432857980	3187	Economy	10100.00
0005432858008	3187	Economy	10100.00
0005432584118	3187	Economy	10100.00
0005432584104	3187	Economy	10100.00
0005432584101	3187	Economy	10100.00
0005432584119	3187	Economy	10100.00
0005432583909	31507	Economy	11100.00
0005432583880	31507	Economy	11100.00
0005432583906	31507	Economy	11100.00
0005432858105	31507	Economy	10100.00
0005432583841	31507	Economy	10100.00
0005432858098	31507	Economy	10100.00
0005432583895	31507	Economy	10100.00
0005432583918	31507	Economy	10100.00
0005432583852	31507	Economy	10100.00
0005432858108	31507	Economy	10100.00
0005432583879	31507	Economy	10100.00
0005432858101	31507	Economy	10100.00
0005432583931	31507	Economy	10100.00
0005432583914	31507	Economy	10100.00
0005432583754	31507	Economy	10100.00
0005432583840	31507	Economy	10100.00
0005432583882	31507	Economy	10100.00
0005432858104	31507	Economy	10100.00
0005432858107	31507	Economy	10100.00
0005432858102	31507	Economy	10100.00
0005432858099	31507	Economy	10100.00
0005432583968	31507	Economy	10100.00
0005432583953	31507	Economy	10100.00
0005432583877	31507	Economy	10100.00
0005432583956	31507	Economy	10100.00
0005432583957	31507	Economy	10100.00
0005432583894	31507	Economy	10100.00
0005432583919	31507	Economy	10100.00
0005432583896	31507	Economy	10100.00
0005432583990	31507	Economy	10100.00
0005432858106	31507	Economy	10100.00
0005432583967	31507	Economy	10100.00
0005432858100	31507	Economy	10100.00
0005432858109	31507	Economy	10100.00
0005432858103	31507	Economy	10100.00
0005434943378	866	Economy	7500.00
0005434943383	866	Economy	7500.00
0005433255102	866	Economy	7500.00
0005434943381	866	Economy	7500.00
0005434943376	866	Economy	7500.00
0005434943377	866	Economy	7500.00
0005433255101	866	Economy	7500.00
0005434943382	866	Economy	7500.00
0005434943375	866	Economy	7500.00
0005434943380	866	Economy	7500.00
0005434943374	866	Economy	7500.00
0005434943379	866	Economy	7500.00
0005433255135	16213	Economy	8300.00
0005433255136	16213	Economy	7500.00
0005434943319	16213	Economy	7500.00
0005434943317	16213	Economy	7500.00
0005434943293	16213	Economy	7500.00
0005434943264	16213	Economy	7500.00
0005433255134	16213	Economy	7500.00
0005433255133	16213	Economy	7500.00
0005434943318	16213	Economy	7500.00
0005433255137	16213	Economy	7500.00
0005435858563	27619	Business	90500.00
0005435858570	27619	Business	90500.00
0005433654727	27619	Business	90500.00
0005435858577	27619	Business	90500.00
0005433654730	27619	Business	90500.00
0005433654699	27619	Business	90500.00
0005435858576	27619	Business	90500.00
0005435858573	27619	Economy	30200.00
0005433654721	27619	Economy	30200.00
0005433654747	27619	Economy	30200.00
0005433654723	27619	Economy	33200.00
0005435858567	27619	Economy	33200.00
0005435858575	27619	Economy	30200.00
0005433654720	27619	Economy	30200.00
0005435858569	27619	Economy	30200.00
0005435858568	27619	Economy	30200.00
0005435858578	27619	Economy	30200.00
0005433654728	27619	Economy	30200.00
0005433654710	27619	Economy	30200.00
0005435858574	27619	Economy	30200.00
0005433654700	27619	Economy	30200.00
0005433654725	27619	Economy	30200.00
0005433654703	27619	Economy	30200.00
0005433654722	27619	Economy	30200.00
0005435858571	27619	Economy	30200.00
0005435858572	27619	Economy	30200.00
0005433654685	27619	Economy	30200.00
0005433654744	27619	Economy	30200.00
0005433654704	27619	Economy	30200.00
0005433654731	27619	Economy	30200.00
0005433654746	27619	Economy	30200.00
0005435858566	27619	Economy	30200.00
0005433654748	27619	Economy	30200.00
0005435858564	27619	Economy	30200.00
0005433654724	27619	Economy	30200.00
0005433654729	27619	Economy	30200.00
0005433654726	27619	Economy	30200.00
0005435858565	27619	Economy	30200.00
0005433654705	27619	Economy	30200.00
0005433811630	14345	Economy	4400.00
0005435653147	21740	Business	9800.00
0005433367812	21740	Business	9800.00
0005435653177	21740	Business	9800.00
0005435653174	21740	Business	9800.00
0005433367645	21740	Business	9800.00
0005435653186	21740	Business	9800.00
0005433367667	21740	Business	9800.00
0005435653190	21740	Business	9800.00
0005433367680	21740	Business	9800.00
0005435653159	21740	Business	9800.00
0005435653157	21740	Business	9800.00
0005435653154	21740	Economy	3300.00
0005435653144	21740	Economy	3300.00
0005433367772	21740	Economy	3300.00
0005435653179	21740	Economy	3300.00
0005433367487	21740	Economy	3300.00
0005433367502	21740	Economy	3300.00
0005433367619	21740	Economy	3300.00
0005435653187	21740	Economy	3300.00
0005435653166	21740	Economy	3300.00
0005435653178	21740	Economy	3600.00
0005433367681	21740	Economy	3600.00
0005435653181	21740	Economy	3600.00
0005433367642	21740	Economy	3300.00
0005435653152	21740	Economy	3300.00
0005433367657	21740	Economy	3300.00
0005435653158	21740	Economy	3300.00
0005433367407	21740	Economy	3300.00
0005433367652	21740	Economy	3300.00
0005435653151	21740	Economy	3300.00
0005435653148	21740	Economy	3300.00
0005433367719	21740	Economy	3300.00
0005433367811	21740	Economy	3300.00
0005433367707	21740	Economy	3300.00
0005435653167	21740	Economy	3300.00
0005435653155	21740	Economy	3300.00
0005433367757	21740	Economy	3300.00
0005435653165	21740	Economy	3300.00
0005435653176	21740	Economy	3300.00
0005435653171	21740	Economy	3300.00
0005433367529	21740	Economy	3300.00
0005433367695	21740	Economy	3300.00
0005433367771	21740	Economy	3300.00
0005435653163	21740	Economy	3300.00
0005433367586	21740	Economy	3300.00
0005435653153	21740	Economy	3300.00
0005435653173	21740	Economy	3300.00
0005435653170	21740	Economy	3300.00
0005435653142	21740	Economy	3300.00
0005433367641	21740	Economy	3300.00
0005433367501	21740	Economy	3300.00
0005435653182	21740	Economy	3300.00
0005435653168	21740	Economy	3300.00
0005435653185	21740	Economy	3300.00
0005435653162	21740	Economy	3300.00
0005435653164	21740	Economy	3300.00
0005435653189	21740	Economy	3300.00
0005435653172	21740	Economy	3300.00
0005433367813	21740	Economy	3300.00
0005433367535	21740	Economy	3300.00
0005435653188	21740	Economy	3300.00
0005433367696	21740	Economy	3300.00
0005435653161	21740	Economy	3300.00
0005435653139	21740	Economy	3300.00
0005433367408	21740	Economy	3300.00
0005435653149	21740	Economy	3300.00
0005435653150	21740	Economy	3300.00
0005435653169	21740	Economy	3300.00
0005435653191	21740	Economy	3300.00
0005435653146	21740	Economy	3300.00
0005433367666	21740	Economy	3300.00
0005435653160	21740	Economy	3300.00
0005433367791	21740	Economy	3300.00
0005433367689	21740	Economy	3300.00
0005435653143	21740	Economy	3300.00
0005435653140	21740	Economy	3300.00
0005435653180	21740	Economy	3300.00
0005435653183	21740	Economy	3300.00
0005435653156	21740	Economy	3300.00
0005435653145	21740	Economy	3300.00
0005433367534	21740	Economy	3300.00
0005433367665	21740	Economy	3300.00
0005435653175	21740	Economy	3300.00
0005433367613	21740	Economy	3300.00
0005435653141	21740	Economy	3300.00
0005433367409	21740	Economy	3300.00
0005435653184	21740	Economy	3300.00
0005433785066	9377	Business	186200.00
0005433805493	9377	Business	186200.00
0005434170999	9377	Business	186200.00
0005432666395	9377	Business	186200.00
0005433785056	9377	Business	186200.00
0005433785059	9377	Business	186200.00
0005432667459	9377	Business	186200.00
0005434273067	9377	Business	186200.00
0005433785068	9377	Business	186200.00
0005433763243	9377	Business	186200.00
0005433785061	9377	Business	186200.00
0005433785044	9377	Business	186200.00
0005433805498	9377	Business	186200.00
0005434171036	9377	Business	186200.00
0005434170951	9377	Economy	62100.00
0005432665280	9377	Economy	62100.00
0005432657457	9377	Economy	62100.00
0005433805502	9377	Economy	62100.00
0005435269678	9377	Economy	62100.00
0005433805477	9377	Economy	62100.00
0005433785054	9377	Economy	62100.00
0005433785053	9377	Economy	62100.00
0005433785060	9377	Economy	62100.00
0005433785070	9377	Economy	62100.00
0005433785075	9377	Economy	62100.00
0005434171005	9377	Economy	62100.00
0005433763253	9377	Economy	62100.00
0005435269688	9377	Economy	62100.00
0005433763250	9377	Economy	62100.00
0005434170972	9377	Economy	62100.00
0005434270191	9377	Economy	62100.00
0005434270200	9377	Economy	62100.00
0005432665281	9377	Economy	62100.00
0005433785043	9377	Economy	62100.00
0005433785055	9377	Economy	62100.00
0005433763256	9377	Economy	62100.00
0005434270193	9377	Economy	62100.00
0005433805489	9377	Economy	62100.00
0005433805497	9377	Economy	62100.00
0005433785042	9377	Economy	62100.00
0005433805491	9377	Economy	62100.00
0005433763246	9377	Economy	62100.00
0005433785048	9377	Economy	62100.00
0005433763252	9377	Economy	62100.00
0005433805503	9377	Economy	62100.00
0005434171037	9377	Economy	62100.00
0005433763255	9377	Economy	62100.00
0005433785040	9377	Economy	62100.00
0005433785051	9377	Economy	62100.00
0005433805481	9377	Economy	62100.00
0005433785071	9377	Economy	62100.00
0005433785063	9377	Economy	62100.00
0005432657458	9377	Economy	62100.00
0005432657459	9377	Economy	62100.00
0005435269703	9377	Economy	62100.00
0005433805496	9377	Economy	62100.00
0005434170998	9377	Economy	62100.00
0005434170955	9377	Economy	62100.00
0005433805486	9377	Economy	62100.00
0005433805499	9377	Economy	62100.00
0005433805479	9377	Economy	62100.00
0005433785041	9377	Economy	62100.00
0005434151679	9377	Economy	62100.00
0005434273068	9377	Economy	62100.00
0005433805488	9377	Economy	62100.00
0005434151693	9377	Economy	62100.00
0005435269684	9377	Economy	62100.00
0005432667461	9377	Economy	62100.00
0005434171000	9377	Economy	62100.00
0005433763245	9377	Economy	62100.00
0005433785067	9377	Economy	62100.00
0005433805480	9377	Economy	62100.00
0005435269687	9377	Economy	62100.00
0005433785069	9377	Economy	62100.00
0005433785046	9377	Economy	62100.00
0005435269698	9377	Economy	62100.00
0005433785047	9377	Economy	68300.00
0005434171013	9377	Economy	68300.00
0005433805504	9377	Economy	62100.00
0005433763254	9377	Economy	62100.00
0005433805487	9377	Economy	62100.00
0005433763247	9377	Economy	62100.00
0005433785073	9377	Economy	62100.00
0005433805494	9377	Economy	62100.00
0005433785072	9377	Economy	62100.00
0005433805492	9377	Economy	62100.00
0005435269694	9377	Economy	62100.00
0005433763251	9377	Economy	62100.00
0005433805495	9377	Economy	62100.00
0005432666394	9377	Economy	62100.00
0005433785058	9377	Economy	62100.00
0005433763244	9377	Economy	62100.00
0005433785062	9377	Economy	62100.00
0005433805501	9377	Economy	62100.00
0005434171002	9377	Economy	62100.00
0005433763248	9377	Economy	62100.00
0005432667460	9377	Economy	62100.00
0005433785050	9377	Economy	62100.00
0005433763249	9377	Economy	62100.00
0005433805490	9377	Economy	62100.00
0005433785065	9377	Economy	62100.00
0005433805478	9377	Economy	62100.00
0005433785049	9377	Economy	62100.00
0005433805484	9377	Economy	62100.00
0005433785074	9377	Economy	62100.00
0005434170950	9377	Economy	62100.00
0005433805483	9377	Economy	62100.00
0005433785064	9377	Economy	62100.00
0005433805485	9377	Economy	62100.00
0005433785039	9377	Economy	62100.00
0005435269690	9377	Economy	62100.00
0005433785045	9377	Economy	62100.00
0005435269689	9377	Economy	62100.00
0005433785038	9377	Economy	62100.00
0005433805482	9377	Economy	62100.00
0005433785057	9377	Economy	62100.00
0005434171038	9377	Economy	62100.00
0005433805505	9377	Economy	62100.00
0005433805500	9377	Economy	62100.00
0005434170956	9377	Economy	62100.00
0005433785052	9377	Economy	62100.00
0005434170963	9377	Economy	62100.00
0005434270210	26243	Business	186200.00
0005433805019	26243	Business	186200.00
0005433784915	26243	Business	186200.00
0005433784719	26243	Business	186200.00
0005433805255	26243	Business	186200.00
0005433763151	26243	Business	186200.00
0005433805094	26243	Business	186200.00
0005434171102	26243	Business	186200.00
0005433763154	26243	Business	186200.00
0005435269761	26243	Business	186200.00
0005434171103	26243	Business	186200.00
0005433784619	26243	Business	186200.00
0005433784616	26243	Business	186200.00
0005433784615	26243	Business	186200.00
0005433805144	26243	Business	186200.00
0005433784644	26243	Business	186200.00
0005434171101	26243	Business	186200.00
0005433784624	26243	Business	186200.00
0005433784614	26243	Business	186200.00
0005434269108	26243	Business	186200.00
0005433763127	26243	Business	186200.00
0005433805218	26243	Business	186200.00
0005433763107	26243	Economy	68300.00
0005433763093	26243	Economy	68300.00
0005433763103	26243	Economy	68300.00
0005433805233	26243	Economy	68300.00
0005433805200	26243	Economy	62100.00
0005433763160	26243	Economy	62100.00
0005435269766	26243	Economy	62100.00
0005433763123	26243	Economy	62100.00
0005433805113	26243	Economy	62100.00
0005434171100	26243	Economy	62100.00
0005433784708	26243	Economy	62100.00
0005432657431	26243	Economy	62100.00
0005433784794	26243	Economy	62100.00
0005433805228	26243	Economy	62100.00
0005433784820	26243	Economy	62100.00
0005433805143	26243	Economy	62100.00
0005433763106	26243	Economy	62100.00
0005434151712	26243	Economy	62100.00
0005433805051	26243	Economy	62100.00
0005433805083	26243	Economy	62100.00
0005432666372	26243	Economy	62100.00
0005433805198	26243	Economy	62100.00
0005434171092	26243	Economy	62100.00
0005435269765	26243	Economy	62100.00
0005433784885	26243	Economy	62100.00
0005433805179	26243	Economy	62100.00
0005433805319	26243	Economy	62100.00
0005432663026	26243	Economy	62100.00
0005433763156	26243	Economy	62100.00
0005434151711	26243	Economy	62100.00
0005435269762	26243	Economy	62100.00
0005433784822	26243	Economy	62100.00
0005433784777	26243	Economy	62100.00
0005433784713	26243	Economy	62100.00
0005433805199	26243	Economy	62100.00
0005435269763	26243	Economy	62100.00
0005433805219	26243	Economy	62100.00
0005433805100	26243	Economy	62100.00
0005434171093	26243	Economy	62100.00
0005434171091	26243	Economy	62100.00
0005433784738	26243	Economy	62100.00
0005433784792	26243	Economy	62100.00
0005434171095	26243	Economy	62100.00
0005433805190	26243	Economy	62100.00
0005433784818	26243	Economy	62100.00
0005433784737	26243	Economy	62100.00
0005433784645	26243	Economy	62100.00
0005434171097	26243	Economy	62100.00
0005433784703	26243	Economy	62100.00
0005432657438	26243	Economy	62100.00
0005434271316	26243	Economy	62100.00
0005433763122	26243	Economy	62100.00
0005432663012	26243	Economy	62100.00
0005433784790	26243	Economy	62100.00
0005433784750	26243	Economy	62100.00
0005432657430	26243	Economy	62100.00
0005433805103	26243	Economy	62100.00
0005433805079	26243	Economy	62100.00
0005433784745	26243	Economy	62100.00
0005434171099	26243	Economy	62100.00
0005433784757	26243	Economy	62100.00
0005433784819	26243	Economy	62100.00
0005433784788	26243	Economy	62100.00
0005433784718	26243	Economy	62100.00
0005433805018	26243	Economy	62100.00
0005433805189	26243	Economy	62100.00
0005433805050	26243	Economy	62100.00
0005433805128	26243	Economy	62100.00
0005433763142	26243	Economy	62100.00
0005433784766	26243	Economy	62100.00
0005433763094	26243	Economy	62100.00
0005433805101	26243	Economy	62100.00
0005433805127	26243	Economy	68300.00
0005435269760	26243	Economy	62100.00
0005434171096	26243	Economy	62100.00
0005435269759	26243	Economy	62100.00
0005433805213	26243	Economy	62100.00
0005433805171	26243	Economy	62100.00
0005432663025	26243	Economy	62100.00
0005432666362	26243	Economy	62100.00
0005433805115	26243	Economy	62100.00
0005433805266	26243	Economy	62100.00
0005433805175	26243	Economy	62100.00
0005433763104	26243	Economy	62100.00
0005433805208	26243	Economy	62100.00
0005435269764	26243	Economy	62100.00
0005433763115	26243	Economy	62100.00
0005433805129	26243	Economy	62100.00
0005434271317	26243	Economy	62100.00
0005433784765	26243	Economy	62100.00
0005432663018	26243	Economy	62100.00
0005434171094	26243	Economy	62100.00
0005433805136	26243	Economy	62100.00
0005433805254	26243	Economy	62100.00
0005433784666	26243	Economy	62100.00
0005433784884	26243	Economy	62100.00
0005433763050	26243	Economy	62100.00
0005432666361	26243	Economy	62100.00
0005434270211	26243	Economy	62100.00
0005434171090	26243	Economy	62100.00
0005433805102	26243	Economy	62100.00
0005433784793	26243	Economy	62100.00
0005433784789	26243	Economy	62100.00
0005434151713	26243	Economy	62100.00
0005433805265	26243	Economy	62100.00
0005433805170	26243	Economy	62100.00
0005433805320	26243	Economy	62100.00
0005433784817	26243	Economy	62100.00
0005433784665	26243	Economy	62100.00
0005433805126	26243	Economy	62100.00
0005433805227	26243	Economy	62100.00
0005433805112	26243	Economy	62100.00
0005433805321	26243	Economy	62100.00
0005433805084	26243	Economy	62100.00
0005432657439	26243	Economy	62100.00
0005434171104	26243	Economy	62100.00
0005432657440	26243	Economy	62100.00
0005434269107	26243	Economy	62100.00
0005434171098	26243	Economy	62100.00
0005433763051	26243	Economy	62100.00
0005435135684	4889	Economy	5900.00
0005435135682	4889	Economy	5300.00
0005435135687	4889	Economy	5300.00
0005435135686	4889	Economy	5300.00
0005435929620	4889	Economy	5300.00
0005435135685	4889	Economy	5300.00
0005435135683	4889	Economy	5300.00
0005435135642	33030	Economy	5900.00
0005435135633	33030	Economy	5900.00
0005435135637	33030	Economy	5300.00
0005435135660	33030	Economy	5300.00
0005435135638	33030	Economy	5300.00
0005435929651	33030	Economy	5300.00
0005435135659	33030	Economy	5300.00
0005435135636	33030	Economy	5300.00
0005435135643	33030	Economy	5300.00
0005435929652	33030	Economy	5300.00
0005435929650	33030	Economy	5300.00
0005435135639	33030	Economy	5300.00
0005434983304	9486	Economy	17900.00
0005434217940	9486	Economy	17900.00
0005434983302	9486	Economy	17900.00
0005434983300	9486	Economy	17900.00
0005434983301	9486	Economy	17900.00
0005434217943	9486	Economy	17900.00
0005434983303	9486	Economy	17900.00
0005434217944	9486	Economy	17900.00
0005434983266	27389	Economy	19700.00
0005434983267	27389	Economy	19700.00
0005434217981	27389	Economy	17900.00
0005434217978	27389	Economy	17900.00
0005434217980	27389	Economy	17900.00
0005434983278	27389	Economy	17900.00
0005434217982	27389	Economy	17900.00
0005434983268	27389	Economy	17900.00
0005434217979	27389	Economy	17900.00
0005434983272	27389	Economy	17900.00
0005434983262	27389	Economy	17900.00
0005434983271	27389	Economy	17900.00
0005434983269	27389	Economy	17900.00
0005433960432	24268	Business	36400.00
0005433985513	24268	Business	36400.00
0005433960506	24268	Business	36400.00
0005433960521	24268	Business	36400.00
0005433985575	24268	Business	36400.00
0005433960424	24268	Business	36400.00
0005433960528	24268	Business	36400.00
0005433960341	24268	Business	36400.00
0005433960520	24268	Business	36400.00
0005433985661	24268	Business	36400.00
0005433985821	24268	Business	36400.00
0005433960563	24268	Business	36400.00
0005433960429	24268	Business	36400.00
0005433960441	24268	Economy	13400.00
0005433985769	24268	Economy	13400.00
0005433960416	24268	Economy	12100.00
0005433960480	24268	Economy	12100.00
0005433960550	24268	Economy	12100.00
0005433985674	24268	Economy	12100.00
0005433985670	24268	Economy	12100.00
0005433960423	24268	Economy	12100.00
0005433985603	24268	Economy	12100.00
0005433985682	24268	Economy	12100.00
0005433985530	24268	Economy	12100.00
0005433985503	24268	Economy	12100.00
0005433960246	24268	Economy	12100.00
0005433960439	24268	Economy	12100.00
0005433960417	24268	Economy	12100.00
0005433960421	24268	Economy	12100.00
0005433960548	24268	Economy	12100.00
0005433985675	24268	Economy	12100.00
0005433985578	24268	Economy	12100.00
0005433985556	24268	Economy	12100.00
0005433960426	24268	Economy	12100.00
0005433960512	24268	Economy	12100.00
0005433960217	24268	Economy	12100.00
0005433985596	24268	Economy	12100.00
0005433960549	24268	Economy	12100.00
0005433960273	24268	Economy	12100.00
0005433960278	24268	Economy	12100.00
0005433960574	24268	Economy	12100.00
0005433985512	24268	Economy	12100.00
0005433960351	24268	Economy	12100.00
0005433985519	24268	Economy	12100.00
0005433960450	24268	Economy	12100.00
0005433960397	24268	Economy	12100.00
0005433960069	24268	Economy	12100.00
0005433960352	24268	Economy	12100.00
0005433960517	24268	Economy	12100.00
0005433985555	24268	Economy	12100.00
0005433985601	24268	Economy	12100.00
0005433985501	24268	Economy	12100.00
0005433960407	24268	Economy	12100.00
0005433960279	24268	Economy	12100.00
0005433960303	24268	Economy	12100.00
0005433960518	24268	Economy	12100.00
0005433985502	24268	Economy	12100.00
0005433960481	24268	Economy	12100.00
0005433985704	24268	Economy	12100.00
0005433960551	24268	Economy	12100.00
0005433985681	24268	Economy	12100.00
0005433985815	24268	Economy	12100.00
0005433985683	24268	Economy	12100.00
0005433985724	24268	Economy	12100.00
0005433985602	24268	Economy	12100.00
0005433960400	24268	Economy	12100.00
0005433960513	24268	Economy	12100.00
0005433985653	24268	Economy	12100.00
0005433960391	24268	Economy	12100.00
0005433985725	24268	Economy	12100.00
0005433960527	24268	Economy	12100.00
0005433960364	24268	Economy	12100.00
0005433960111	24268	Economy	12100.00
0005433985574	24268	Economy	12100.00
0005433985703	24268	Economy	12100.00
0005433985742	24268	Economy	12100.00
0005433985750	24268	Economy	12100.00
0005433960274	24268	Economy	12100.00
0005433985669	24268	Economy	12100.00
0005433985319	24268	Economy	12100.00
0005433985768	24268	Economy	12100.00
0005433960442	24268	Economy	12100.00
0005433985734	24268	Economy	12100.00
0005433985518	24268	Economy	12100.00
0005433985579	24268	Economy	12100.00
0005433985738	24268	Economy	12100.00
0005433985593	24268	Economy	12100.00
0005433960475	24268	Economy	12100.00
0005433960402	24268	Economy	12100.00
0005433985834	24268	Economy	12100.00
0005433960505	24268	Economy	12100.00
0005433960552	24268	Economy	12100.00
0005433960399	24268	Economy	12100.00
0005433985757	24268	Economy	12100.00
0005433985604	24268	Economy	12100.00
0005433960366	24268	Economy	12100.00
0005433960340	24268	Economy	12100.00
0005433986031	25908	Business	36400.00
0005433986030	25908	Business	36400.00
0005433986060	25908	Business	36400.00
0005433961008	25908	Business	36400.00
0005433986066	25908	Business	36400.00
0005433961029	25908	Business	36400.00
0005433961016	25908	Business	36400.00
0005433960991	25908	Business	36400.00
0005433961000	25908	Business	36400.00
0005433986064	25908	Business	36400.00
0005433986036	25908	Business	36400.00
0005433960990	25908	Business	36400.00
0005433986040	25908	Economy	13400.00
0005433986071	25908	Economy	13400.00
0005433986044	25908	Economy	12100.00
0005433961032	25908	Economy	12100.00
0005433986061	25908	Economy	12100.00
0005433986043	25908	Economy	12100.00
0005433961002	25908	Economy	12100.00
0005433961011	25908	Economy	12100.00
0005433960994	25908	Economy	12100.00
0005433986035	25908	Economy	12100.00
0005433961010	25908	Economy	12100.00
0005433986051	25908	Economy	12100.00
0005433961003	25908	Economy	12100.00
0005433960992	25908	Economy	12100.00
0005433960998	25908	Economy	12100.00
0005433986041	25908	Economy	12100.00
0005433986042	25908	Economy	12100.00
0005433986047	25908	Economy	12100.00
0005433961021	25908	Economy	12100.00
0005433986055	25908	Economy	12100.00
0005433960997	25908	Economy	12100.00
0005433986027	25908	Economy	12100.00
0005433986046	25908	Economy	12100.00
0005433960988	25908	Economy	12100.00
0005433961024	25908	Economy	12100.00
0005433960981	25908	Economy	12100.00
0005433961001	25908	Economy	12100.00
0005433986039	25908	Economy	12100.00
0005433986029	25908	Economy	12100.00
0005433960976	25908	Economy	12100.00
0005433961006	25908	Economy	12100.00
0005433960974	25908	Economy	12100.00
0005433961022	25908	Economy	12100.00
0005433961023	25908	Economy	12100.00
0005433961004	25908	Economy	12100.00
0005433960978	25908	Economy	12100.00
0005433986062	25908	Economy	12100.00
0005433961030	25908	Economy	12100.00
0005433961018	25908	Economy	12100.00
0005433986065	25908	Economy	12100.00
0005433986034	25908	Economy	12100.00
0005433961028	25908	Economy	12100.00
0005433960996	25908	Economy	12100.00
0005433986057	25908	Economy	12100.00
0005433960985	25908	Economy	12100.00
0005433986037	25908	Economy	12100.00
0005433961009	25908	Economy	12100.00
0005433961015	25908	Economy	12100.00
0005433986049	25908	Economy	12100.00
0005433961013	25908	Economy	12100.00
0005433960995	25908	Economy	13400.00
0005433986068	25908	Economy	12100.00
0005433961031	25908	Economy	12100.00
0005433960999	25908	Economy	13400.00
0005433960993	25908	Economy	12100.00
0005433960980	25908	Economy	12100.00
0005433961005	25908	Economy	12100.00
0005433960979	25908	Economy	12100.00
0005433986058	25908	Economy	12100.00
0005433961014	25908	Economy	12100.00
0005433986063	25908	Economy	12100.00
0005433961017	25908	Economy	12100.00
0005433961007	25908	Economy	12100.00
0005433986073	25908	Economy	12100.00
0005433960989	25908	Economy	12100.00
0005433961033	25908	Economy	12100.00
0005433986052	25908	Economy	12100.00
0005433960984	25908	Economy	12100.00
0005433986050	25908	Economy	12100.00
0005433986028	25908	Economy	12100.00
0005433960977	25908	Economy	12100.00
0005433961026	25908	Economy	12100.00
0005433986054	25908	Economy	12100.00
0005433986072	25908	Economy	12100.00
0005433986075	25908	Economy	12100.00
0005433960987	25908	Economy	12100.00
0005433986033	25908	Economy	12100.00
0005433961019	25908	Economy	12100.00
0005433986045	25908	Economy	12100.00
0005433986069	25908	Economy	12100.00
0005433961027	25908	Economy	12100.00
0005433961020	25908	Economy	12100.00
0005433960982	25908	Economy	12100.00
0005433986067	25908	Economy	12100.00
0005433986048	25908	Economy	12100.00
0005433986053	25908	Economy	12100.00
0005433986070	25908	Economy	12100.00
0005433960975	25908	Economy	12100.00
0005433961025	25908	Economy	12100.00
0005433986074	25908	Economy	12100.00
0005433986032	25908	Economy	12100.00
0005433961012	25908	Economy	12100.00
0005433986059	25908	Economy	12100.00
0005433960983	25908	Economy	12100.00
0005433960986	25908	Economy	12100.00
0005433986038	25908	Economy	12100.00
0005433986056	25908	Economy	12100.00
0005434480406	920	Economy	25400.00
0005434480395	920	Economy	25400.00
0005434480408	920	Economy	25400.00
0005434480404	920	Economy	23100.00
0005434480400	920	Economy	23100.00
0005434480412	920	Economy	23100.00
0005434480413	920	Economy	23100.00
0005433165862	920	Economy	23100.00
0005434480394	920	Economy	23100.00
0005432269502	920	Economy	23100.00
0005434480402	920	Economy	23100.00
0005433165882	920	Economy	23100.00
0005434480415	920	Economy	23100.00
0005434480398	920	Economy	23100.00
0005434480397	920	Economy	23100.00
0005433165823	920	Economy	23100.00
0005434480418	920	Economy	23100.00
0005434480399	920	Economy	23100.00
0005434480407	920	Economy	23100.00
0005434480414	920	Economy	23100.00
0005434480405	920	Economy	23100.00
0005434480396	920	Economy	23100.00
0005434480416	920	Economy	23100.00
0005433165861	920	Economy	23100.00
0005434480410	920	Economy	23100.00
0005433165887	920	Economy	23100.00
0005433165883	920	Economy	23100.00
0005434480401	920	Economy	23100.00
0005434480411	920	Economy	23100.00
0005433165886	920	Economy	23100.00
0005432269503	920	Economy	23100.00
0005432269504	920	Economy	23100.00
0005434480417	920	Economy	23100.00
0005434480409	920	Economy	23100.00
0005433165822	920	Economy	23100.00
0005434480393	920	Economy	23100.00
0005432269505	920	Economy	23100.00
0005434480403	920	Economy	23100.00
0005434480226	16606	Economy	25400.00
0005434480246	16606	Economy	25400.00
0005434480245	16606	Economy	25400.00
0005433165945	16606	Economy	25400.00
0005434480276	16606	Economy	23100.00
0005433165947	16606	Economy	23100.00
0005434480117	16606	Economy	23100.00
0005434480178	16606	Economy	23100.00
0005434480252	16606	Economy	23100.00
0005433165940	16606	Economy	23100.00
0005434480107	16606	Economy	23100.00
0005434480182	16606	Economy	23100.00
0005434480201	16606	Economy	23100.00
0005434480288	16606	Economy	23100.00
0005434480202	16606	Economy	23100.00
0005434480285	16606	Economy	23100.00
0005433165937	16606	Economy	23100.00
0005433165942	16606	Economy	23100.00
0005434480197	16606	Economy	23100.00
0005433165944	16606	Economy	23100.00
0005434480163	16606	Economy	23100.00
0005434479983	16606	Economy	23100.00
0005433165941	16606	Economy	23100.00
0005434480164	16606	Economy	23100.00
0005433165943	16606	Economy	23100.00
0005433165949	16606	Economy	23100.00
0005434480242	16606	Economy	23100.00
0005434480122	16606	Economy	23100.00
0005434480181	16606	Economy	23100.00
0005434480199	16606	Economy	23100.00
0005434480251	16606	Economy	23100.00
0005434480143	16606	Economy	23100.00
0005433165948	16606	Economy	23100.00
0005434480121	16606	Economy	23100.00
0005433165938	16606	Economy	23100.00
0005433165946	16606	Economy	23100.00
0005434480144	16606	Economy	23100.00
0005433165939	16606	Economy	23100.00
0005433165936	16606	Economy	23100.00
0005434480243	16606	Economy	23100.00
0005435150063	10375	Economy	17000.00
0005435142599	10375	Economy	17000.00
0005435150059	10375	Economy	15400.00
0005435142606	10375	Economy	15400.00
0005433289811	10375	Economy	15400.00
0005435142608	10375	Economy	15400.00
0005435150064	10375	Economy	15400.00
0005435150058	10375	Economy	15400.00
0005435386518	10375	Economy	15400.00
0005435142611	10375	Economy	15400.00
0005435150062	10375	Economy	15400.00
0005435142607	10375	Economy	15400.00
0005435150056	10375	Economy	15400.00
0005435150053	10375	Economy	15400.00
0005435142602	10375	Economy	15400.00
0005435386505	10375	Economy	15400.00
0005435150065	10375	Economy	15400.00
0005435386543	10375	Economy	15400.00
0005435142600	10375	Economy	15400.00
0005435150060	10375	Economy	15400.00
0005435142603	10375	Economy	15400.00
0005435142605	10375	Economy	15400.00
0005433289813	10375	Economy	15400.00
0005435150055	10375	Economy	15400.00
0005433289797	10375	Economy	15400.00
0005435150061	10375	Economy	15400.00
0005435150052	10375	Economy	15400.00
0005435150054	10375	Economy	15400.00
0005435142610	10375	Economy	15400.00
0005435142612	10375	Economy	15400.00
0005435150057	10375	Economy	15400.00
0005433289779	10375	Economy	15400.00
0005433289816	10375	Economy	15400.00
0005435142601	10375	Economy	15400.00
0005435142604	10375	Economy	15400.00
0005435142609	10375	Economy	15400.00
0005435386532	10375	Economy	15400.00
0005433289812	10375	Economy	15400.00
0005435386591	21941	Economy	17000.00
0005435149953	21941	Economy	17000.00
0005435142484	21941	Economy	17000.00
0005433289880	21941	Economy	15400.00
0005433289878	21941	Economy	15400.00
0005435142521	21941	Economy	15400.00
0005435386592	21941	Economy	15400.00
0005435142408	21941	Economy	15400.00
0005435142570	21941	Economy	15400.00
0005435142520	21941	Economy	15400.00
0005435150001	21941	Economy	15400.00
0005435142522	21941	Economy	15400.00
0005433289875	21941	Economy	15400.00
0005435142498	21941	Economy	15400.00
0005435149912	21941	Economy	15400.00
0005433289876	21941	Economy	15400.00
0005435149954	21941	Economy	15400.00
0005435149928	21941	Economy	15400.00
0005435149926	21941	Economy	15400.00
0005435386590	21941	Economy	15400.00
0005435386588	21941	Economy	15400.00
0005433289877	21941	Economy	15400.00
0005435149942	21941	Economy	15400.00
0005435142472	21941	Economy	15400.00
0005433289874	21941	Economy	15400.00
0005433289879	21941	Economy	15400.00
0005435386594	21941	Economy	15400.00
0005435142485	21941	Economy	15400.00
0005435149913	21941	Economy	15400.00
0005435149951	21941	Economy	15400.00
0005435142428	21941	Economy	15400.00
0005435142482	21941	Economy	15400.00
0005435142483	21941	Economy	15400.00
0005435142486	21941	Economy	15400.00
0005435386587	21941	Economy	15400.00
0005435142519	21941	Economy	15400.00
0005435386589	21941	Economy	15400.00
0005433289873	21941	Economy	15400.00
0005435142473	21941	Economy	15400.00
0005435386593	21941	Economy	15400.00
0005435150000	21941	Economy	15400.00
0005435142569	21941	Economy	15400.00
0005435319518	11188	Business	57200.00
0005434573386	11188	Business	57200.00
0005435529199	11188	Business	57200.00
0005435502233	11188	Business	57200.00
0005435502118	11188	Business	57200.00
0005435502180	11188	Business	57200.00
0005435319554	11188	Business	57200.00
0005435502193	11188	Business	57200.00
0005435502132	11188	Business	57200.00
0005435502240	11188	Business	57200.00
0005435502179	11188	Business	57200.00
0005435529181	11188	Economy	19100.00
0005435502107	11188	Economy	19100.00
0005435502299	11188	Economy	19100.00
0005435502300	11188	Economy	19100.00
0005435502241	11188	Economy	19100.00
0005435529095	11188	Economy	19100.00
0005435502192	11188	Economy	19100.00
0005434573387	11188	Economy	19100.00
0005434573376	11188	Economy	19100.00
0005435319522	11188	Economy	19100.00
0005435319555	11188	Economy	21000.00
0005434573385	11188	Economy	21000.00
0005435545657	11188	Economy	21000.00
0005434573375	11188	Economy	21000.00
0005435529087	11188	Economy	21000.00
0005435502206	11188	Economy	19100.00
0005434573382	11188	Economy	19100.00
0005435502225	11188	Economy	19100.00
0005435529198	11188	Economy	19100.00
0005435529096	11188	Economy	19100.00
0005435502215	11188	Economy	19100.00
0005435502176	11188	Economy	19100.00
0005435529039	11188	Economy	19100.00
0005435319521	11188	Economy	19100.00
0005435545684	11188	Economy	19100.00
0005435502242	11188	Economy	19100.00
0005435502272	11188	Economy	19100.00
0005435545673	11188	Economy	19100.00
0005435319520	11188	Economy	19100.00
0005435502175	11188	Economy	19100.00
0005434573380	11188	Economy	19100.00
0005435319502	11188	Economy	19100.00
0005435502209	11188	Economy	19100.00
0005435502260	11188	Economy	19100.00
0005435529141	11188	Economy	19100.00
0005435502146	11188	Economy	19100.00
0005434573383	11188	Economy	19100.00
0005435319517	11188	Economy	19100.00
0005435529239	11188	Economy	19100.00
0005435529200	11188	Economy	19100.00
0005435545683	11188	Economy	19100.00
0005434573389	11188	Economy	19100.00
0005435319534	11188	Economy	19100.00
0005435502254	11188	Economy	19100.00
0005435502203	11188	Economy	19100.00
0005434573377	11188	Economy	19100.00
0005435319564	11188	Economy	19100.00
0005435319546	11188	Economy	19100.00
0005434573381	11188	Economy	19100.00
0005435319535	11188	Economy	19100.00
0005435502204	11188	Economy	19100.00
0005435502157	11188	Economy	19100.00
0005435502119	11188	Economy	19100.00
0005435502189	11188	Economy	19100.00
0005435319523	11188	Economy	19100.00
0005435502220	11188	Economy	19100.00
0005435502271	11188	Economy	19100.00
0005435529201	11188	Economy	19100.00
0005435502183	11188	Economy	19100.00
0005435529061	11188	Economy	19100.00
0005434573379	11188	Economy	19100.00
0005435529142	11188	Economy	19100.00
0005435502182	11188	Economy	19100.00
0005435319516	11188	Economy	19100.00
0005435502207	11188	Economy	19100.00
0005435529122	11188	Economy	19100.00
0005435545692	11188	Economy	19100.00
0005435319532	11188	Economy	19100.00
0005435319553	11188	Economy	19100.00
0005435502277	11188	Economy	19100.00
0005434573378	11188	Economy	19100.00
0005435502145	11188	Economy	19100.00
0005435319533	11188	Economy	19100.00
0005435529128	11188	Economy	19100.00
0005435319565	11188	Economy	19100.00
0005435502188	11188	Economy	19100.00
0005435545668	11188	Economy	19100.00
0005434573388	11188	Economy	19100.00
0005434573384	11188	Economy	19100.00
0005435502216	11188	Economy	19100.00
0005435508392	20924	Business	57200.00
0005434573272	20924	Business	57200.00
0005435517953	20924	Business	57200.00
0005435517955	20924	Business	57200.00
0005435502373	20924	Business	57200.00
0005434573200	20924	Business	57200.00
0005435319609	20924	Business	57200.00
0005435502354	20924	Business	57200.00
0005435319605	20924	Business	57200.00
0005435517956	20924	Business	57200.00
0005435502364	20924	Economy	19100.00
0005435319606	20924	Economy	19100.00
0005435502370	20924	Economy	19100.00
0005435517958	20924	Economy	19100.00
0005435517948	20924	Economy	19100.00
0005435502358	20924	Economy	19100.00
0005435502372	20924	Economy	21000.00
0005435319611	20924	Economy	21000.00
0005435517947	20924	Economy	21000.00
0005434573247	20924	Economy	19100.00
0005435502368	20924	Economy	19100.00
0005435319610	20924	Economy	19100.00
0005435502361	20924	Economy	19100.00
0005435517950	20924	Economy	19100.00
0005435502365	20924	Economy	19100.00
0005435502355	20924	Economy	19100.00
0005435508393	20924	Economy	19100.00
0005435502353	20924	Economy	19100.00
0005432291937	20924	Economy	19100.00
0005435502369	20924	Economy	19100.00
0005435517954	20924	Economy	19100.00
0005434573250	20924	Economy	19100.00
0005434573225	20924	Economy	19100.00
0005435502360	20924	Economy	19100.00
0005435517951	20924	Economy	19100.00
0005435502363	20924	Economy	19100.00
0005435319613	20924	Economy	19100.00
0005435502357	20924	Economy	19100.00
0005435502352	20924	Economy	19100.00
0005435517946	20924	Economy	19100.00
0005435502362	20924	Economy	19100.00
0005435319607	20924	Economy	19100.00
0005434573263	20924	Economy	19100.00
0005434573204	20924	Economy	19100.00
0005435517957	20924	Economy	19100.00
0005432291935	20924	Economy	19100.00
0005435517960	20924	Economy	19100.00
0005435508394	20924	Economy	19100.00
0005434573222	20924	Economy	19100.00
0005435502359	20924	Economy	19100.00
0005435319612	20924	Economy	19100.00
0005435502371	20924	Economy	19100.00
0005435502374	20924	Economy	19100.00
0005435517952	20924	Economy	19100.00
0005434573199	20924	Economy	19100.00
0005432291936	20924	Economy	19100.00
0005435502356	20924	Economy	19100.00
0005434573246	20924	Economy	19100.00
0005435517949	20924	Economy	19100.00
0005435517959	20924	Economy	19100.00
0005435502367	20924	Economy	19100.00
0005435319608	20924	Economy	19100.00
0005435502366	20924	Economy	19100.00
0005435319614	20924	Economy	19100.00
0005432692963	2976	Business	10300.00
0005432692976	2976	Business	10300.00
0005432692922	2976	Business	10300.00
0005432693015	2976	Business	10300.00
0005432692989	2976	Business	10300.00
0005432692849	2976	Business	10300.00
0005432692951	2976	Business	10300.00
0005432692850	2976	Economy	3400.00
0005432692967	2976	Economy	3400.00
0005432692887	2976	Economy	3400.00
0005432692942	2976	Economy	3400.00
0005432692837	2976	Economy	3800.00
0005432692805	2976	Economy	3800.00
0005432692819	2976	Economy	3800.00
0005432692856	2976	Economy	3400.00
0005432692843	2976	Economy	3400.00
0005432692886	2976	Economy	3400.00
0005432692874	2976	Economy	3400.00
0005432692855	2976	Economy	3400.00
0005432692851	2976	Economy	3400.00
0005432692806	2976	Economy	3400.00
0005432692959	2976	Economy	3400.00
0005432692943	2976	Economy	3400.00
0005432692899	2976	Economy	3400.00
0005432692961	2976	Economy	3400.00
0005432692962	2976	Economy	3400.00
0005432692932	2976	Economy	3400.00
0005432692958	2976	Economy	3400.00
0005432692818	2976	Economy	3400.00
0005432692988	2976	Economy	3400.00
0005432692902	2976	Economy	3400.00
0005432692901	2976	Economy	3400.00
0005432692844	2976	Economy	3400.00
0005432692838	2976	Economy	3400.00
0005432693014	2976	Economy	3400.00
0005432692950	2976	Economy	3400.00
0005432692845	2976	Economy	3400.00
0005432692957	2976	Economy	3400.00
0005432693013	2976	Economy	3400.00
0005432692956	2976	Economy	3400.00
0005432692968	2976	Economy	3400.00
0005432706853	2977	Business	10300.00
0005432880730	2977	Business	10300.00
0005433123795	2977	Business	10300.00
0005433123840	2977	Business	10300.00
0005433194840	2977	Business	10300.00
0005432217783	2977	Business	10300.00
0005432880691	2977	Business	10300.00
0005433123788	2977	Economy	3400.00
0005432706847	2977	Economy	3400.00
0005432706833	2977	Economy	3400.00
0005432706856	2977	Economy	3400.00
0005433123815	2977	Economy	3400.00
0005433123737	2977	Economy	3400.00
0005433123799	2977	Economy	3800.00
0005433194837	2977	Economy	3800.00
0005432706842	2977	Economy	3800.00
0005432880757	2977	Economy	3800.00
0005433194839	2977	Economy	3400.00
0005433123746	2977	Economy	3400.00
0005432880741	2977	Economy	3400.00
0005432706851	2977	Economy	3400.00
0005432706854	2977	Economy	3400.00
0005432706843	2977	Economy	3400.00
0005432706835	2977	Economy	3400.00
0005432880758	2977	Economy	3400.00
0005432880765	2977	Economy	3400.00
0005433123829	2977	Economy	3400.00
0005433123745	2977	Economy	3400.00
0005433123804	2977	Economy	3400.00
0005432880731	2977	Economy	3400.00
0005432706841	2977	Economy	3400.00
0005432706857	2977	Economy	3400.00
0005432706850	2977	Economy	3400.00
0005433123830	2977	Economy	3400.00
0005432880694	2977	Economy	3400.00
0005432706837	2977	Economy	3400.00
0005432706844	2977	Economy	3400.00
0005432706858	2977	Economy	3400.00
0005432880745	2977	Economy	3400.00
0005432880692	2977	Economy	3400.00
0005433123811	2977	Economy	3400.00
0005432706849	2977	Economy	3400.00
0005433123806	2977	Economy	3400.00
0005432217785	2977	Economy	3400.00
0005432880720	2977	Economy	3400.00
0005432706836	2977	Economy	3400.00
0005432706834	2977	Economy	3400.00
0005432706846	2977	Economy	3400.00
0005432217784	2977	Economy	3400.00
0005432880689	2977	Economy	3400.00
0005433123787	2977	Economy	3400.00
0005432706832	2977	Economy	3400.00
0005432706839	2977	Economy	3400.00
0005432706838	2977	Economy	3400.00
0005432706848	2977	Economy	3400.00
0005432706855	2977	Economy	3400.00
0005432880744	2977	Economy	3400.00
0005432706852	2977	Economy	3400.00
0005432706845	2977	Economy	3400.00
0005433123814	2977	Economy	3400.00
0005432706840	2977	Economy	3400.00
0005432706831	2977	Economy	3400.00
0005433123985	29990	Business	10300.00
0005432880853	29990	Business	10300.00
0005432706580	29990	Business	10300.00
0005433123980	29990	Business	10300.00
0005432706638	29990	Business	10300.00
0005432706696	29990	Business	10300.00
0005432693167	29990	Business	10300.00
0005432880858	29990	Business	10300.00
0005432693181	29990	Business	10300.00
0005433123988	29990	Business	10300.00
0005432706636	29990	Business	10300.00
0005433123974	29990	Business	10300.00
0005432706650	29990	Economy	3400.00
0005432693185	29990	Economy	3400.00
0005432880859	29990	Economy	3400.00
0005432693188	29990	Economy	3400.00
0005433123984	29990	Economy	3400.00
0005433123981	29990	Economy	3400.00
0005432706719	29990	Economy	3400.00
0005432706583	29990	Economy	3400.00
0005433123979	29990	Economy	3400.00
0005433123982	29990	Economy	3400.00
0005432706752	29990	Economy	3800.00
0005432706592	29990	Economy	3800.00
0005432880860	29990	Economy	3800.00
0005432693179	29990	Economy	3800.00
0005432706613	29990	Economy	3400.00
0005432706721	29990	Economy	3400.00
0005433123978	29990	Economy	3400.00
0005432693183	29990	Economy	3400.00
0005432706692	29990	Economy	3400.00
0005432706759	29990	Economy	3400.00
0005432693162	29990	Economy	3400.00
0005433123986	29990	Economy	3400.00
0005432880857	29990	Economy	3400.00
0005432706718	29990	Economy	3400.00
0005432693187	29990	Economy	3400.00
0005432706712	29990	Economy	3400.00
0005432693178	29990	Economy	3400.00
0005432693170	29990	Economy	3400.00
0005433123975	29990	Economy	3400.00
0005432880856	29990	Economy	3400.00
0005432880852	29990	Economy	3400.00
0005432693182	29990	Economy	3400.00
0005432880855	29990	Economy	3400.00
0005432706695	29990	Economy	3400.00
0005432693176	29990	Economy	3400.00
0005432706637	29990	Economy	3400.00
0005432706582	29990	Economy	3400.00
0005433123983	29990	Economy	3400.00
0005432693159	29990	Economy	3400.00
0005432693160	29990	Economy	3400.00
0005432693174	29990	Economy	3400.00
0005432693172	29990	Economy	3400.00
0005432706693	29990	Economy	3400.00
0005432693161	29990	Economy	3400.00
0005432706671	29990	Economy	3400.00
0005432706670	29990	Economy	3400.00
0005432706672	29990	Economy	3400.00
0005432706591	29990	Economy	3400.00
0005432706716	29990	Economy	3400.00
0005432693164	29990	Economy	3400.00
0005432706469	29990	Economy	3400.00
0005432693166	29990	Economy	3400.00
0005432706615	29990	Economy	3400.00
0005432706456	29990	Economy	3400.00
0005432693169	29990	Economy	3400.00
0005432880861	29990	Economy	3400.00
0005432706617	29990	Economy	3400.00
0005432880864	29990	Economy	3400.00
0005432693189	29990	Economy	3400.00
0005432693175	29990	Economy	3400.00
0005432693168	29990	Economy	3400.00
0005432880863	29990	Economy	3400.00
0005432693163	29990	Economy	3400.00
0005432880866	29990	Economy	3400.00
0005432706639	29990	Economy	3400.00
0005433123977	29990	Economy	3400.00
0005432693171	29990	Economy	3400.00
0005432693180	29990	Economy	3400.00
0005432693173	29990	Economy	3400.00
0005433123989	29990	Economy	3400.00
0005432880862	29990	Economy	3400.00
0005432693177	29990	Economy	3400.00
0005433123976	29990	Economy	3400.00
0005432706576	29990	Economy	3400.00
0005432693186	29990	Economy	3400.00
0005432706715	29990	Economy	3400.00
0005432880865	29990	Economy	3400.00
0005432693165	29990	Economy	3400.00
0005432706711	29990	Economy	3400.00
0005432706614	29990	Economy	3400.00
0005432693184	29990	Economy	3400.00
0005433123987	29990	Economy	3400.00
0005432706457	29990	Economy	3400.00
0005432880854	29990	Economy	3400.00
0005434988773	23663	Economy	4000.00
0005434979851	23663	Economy	4000.00
0005434979848	23663	Economy	4000.00
0005434979866	23663	Economy	4000.00
0005434979837	23663	Economy	3600.00
0005434979843	23663	Economy	3600.00
0005434988775	23663	Economy	3600.00
0005434988764	23663	Economy	3600.00
0005434979861	23663	Economy	3600.00
0005434979860	23663	Economy	3600.00
0005434979840	23663	Economy	3600.00
0005434979863	23663	Economy	3600.00
0005434979852	23663	Economy	3600.00
0005434988766	23663	Economy	3600.00
0005434979846	23663	Economy	3600.00
0005434979856	23663	Economy	3600.00
0005434988771	23663	Economy	3600.00
0005434979839	23663	Economy	3600.00
0005434979854	23663	Economy	3600.00
0005434979850	23663	Economy	3600.00
0005434979864	23663	Economy	3600.00
0005434979845	23663	Economy	3600.00
0005434979855	23663	Economy	3600.00
0005434988770	23663	Economy	3600.00
0005434979844	23663	Economy	3600.00
0005434988765	23663	Economy	3600.00
0005434979853	23663	Economy	3600.00
0005434979858	23663	Economy	3600.00
0005434988767	23663	Economy	3600.00
0005434979841	23663	Economy	3600.00
0005434988776	23663	Economy	3600.00
0005434988768	23663	Economy	3600.00
0005434988774	23663	Economy	3600.00
0005434979862	23663	Economy	3600.00
0005434988763	23663	Economy	3600.00
0005434979859	23663	Economy	3600.00
0005434979847	23663	Economy	3600.00
0005434979857	23663	Economy	3600.00
0005434979865	23663	Economy	3600.00
0005434988772	23663	Economy	3600.00
0005434979842	23663	Economy	3600.00
0005434988769	23663	Economy	3600.00
0005434979849	23663	Economy	3600.00
0005434979838	23663	Economy	3600.00
0005434979532	27528	Economy	4000.00
0005434979550	27528	Economy	4000.00
0005434979548	27528	Economy	3600.00
0005434988641	27528	Economy	3600.00
0005434988659	27528	Economy	3600.00
0005434979549	27528	Economy	3600.00
0005434979536	27528	Economy	3600.00
0005434988650	27528	Economy	3600.00
0005434979551	27528	Economy	3600.00
0005434988666	27528	Economy	3600.00
0005434979616	27528	Economy	3600.00
0005434979607	27528	Economy	3600.00
0005434979602	27528	Economy	3600.00
0005434979653	27528	Economy	3600.00
0005434979597	27528	Economy	3600.00
0005434979771	27528	Economy	3600.00
0005434979541	27528	Economy	3600.00
0005434979534	27528	Economy	3600.00
0005434979566	27528	Economy	3600.00
0005434988660	27528	Economy	3600.00
0005434979509	27528	Economy	3600.00
0005434979537	27528	Economy	3600.00
0005434979497	27528	Economy	3600.00
0005434979664	27528	Economy	3600.00
0005434979577	27528	Economy	3600.00
0005434988661	27528	Economy	3600.00
0005434979763	27528	Economy	3600.00
0005434988664	27528	Economy	3600.00
0005434979538	27528	Economy	3600.00
0005434979552	27528	Economy	3600.00
0005434979503	27528	Economy	3600.00
0005434979542	27528	Economy	3600.00
0005434979568	27528	Economy	3600.00
0005434979762	27528	Economy	3600.00
0005434979533	27528	Economy	3600.00
0005434979539	27528	Economy	3600.00
0005434979603	27528	Economy	3600.00
0005434979540	27528	Economy	3600.00
0005434979615	27528	Economy	3600.00
0005434979518	27528	Economy	3600.00
0005434979684	27528	Economy	3600.00
0005434979654	27528	Economy	3600.00
0005434988646	27528	Economy	3600.00
0005434979513	27528	Economy	3600.00
0005433113517	10278	Economy	19700.00
0005433113525	10278	Economy	19700.00
0005434302468	10278	Economy	19700.00
0005434302467	10278	Economy	19700.00
0005434302471	10278	Economy	19700.00
0005434302469	10278	Economy	19700.00
0005433113526	10278	Economy	19700.00
0005434302470	10278	Economy	19700.00
0005433113518	10278	Economy	19700.00
0005434302422	19643	Economy	19700.00
0005434302424	19643	Economy	19700.00
0005434302434	19643	Economy	19700.00
0005433113543	19643	Economy	19700.00
0005434302433	19643	Economy	19700.00
0005433113542	19643	Economy	19700.00
0005434302423	19643	Economy	19700.00
0005434302421	19643	Economy	19700.00
0005435069221	3563	Business	26900.00
0005435069257	3563	Business	26900.00
0005435069247	3563	Business	26900.00
0005435925260	3563	Business	26900.00
0005435069230	3563	Business	26900.00
0005435069250	3563	Business	26900.00
0005435069238	3563	Business	26900.00
0005435069235	3563	Business	26900.00
0005435069254	3563	Economy	9000.00
0005435069259	3563	Economy	9000.00
0005435069220	3563	Economy	9000.00
0005435069260	3563	Economy	9000.00
0005435925225	3563	Economy	9000.00
0005435069266	3563	Economy	9000.00
0005435718967	3563	Economy	9000.00
0005435069244	3563	Economy	9000.00
0005435069255	3563	Economy	9000.00
0005435939867	3563	Economy	9900.00
0005435718968	3563	Economy	9900.00
0005435069236	3563	Economy	9900.00
0005435069227	3563	Economy	9900.00
0005435069267	3563	Economy	9000.00
0005435939866	3563	Economy	9000.00
0005435069239	3563	Economy	9000.00
0005435069252	3563	Economy	9000.00
0005435069229	3563	Economy	9000.00
0005435069222	3563	Economy	9000.00
0005435925220	3563	Economy	9000.00
0005435069231	3563	Economy	9000.00
0005435069226	3563	Economy	9000.00
0005435069248	3563	Economy	9000.00
0005435069240	3563	Economy	9000.00
0005435069269	3563	Economy	9000.00
0005435069258	3563	Economy	9000.00
0005435069265	3563	Economy	9000.00
0005435718964	3563	Economy	9000.00
0005435069249	3563	Economy	9000.00
0005435718966	3563	Economy	9000.00
0005435069218	3563	Economy	9000.00
0005435718970	3563	Economy	9000.00
0005435069261	3563	Economy	9000.00
0005435925253	3563	Economy	9000.00
0005435069246	3563	Economy	9000.00
0005435069242	3563	Economy	9000.00
0005435069237	3563	Economy	9000.00
0005435925105	3563	Economy	9000.00
0005435925237	3563	Economy	9000.00
0005435718965	3563	Economy	9000.00
0005435925241	3563	Economy	9000.00
0005435069224	3563	Economy	9000.00
0005435069232	3563	Economy	9000.00
0005435718963	3563	Economy	9000.00
0005435718969	3563	Economy	9000.00
0005435069270	3563	Economy	9000.00
0005435925238	3563	Economy	9000.00
0005435069241	3563	Economy	9000.00
0005435925219	3563	Economy	9000.00
0005435939873	3563	Economy	9000.00
0005435069268	3563	Economy	9000.00
0005435069256	3563	Economy	9000.00
0005435069262	3563	Economy	9000.00
0005435718962	3563	Economy	9000.00
0005435069243	3563	Economy	9000.00
0005435925214	3563	Economy	9000.00
0005435069233	3563	Economy	9000.00
0005435069223	3563	Economy	9000.00
0005435069263	3563	Economy	9000.00
0005435925180	3563	Economy	9000.00
0005435069234	3563	Economy	9000.00
0005435069253	3563	Economy	9000.00
0005435069225	3563	Economy	9000.00
0005435069271	3563	Economy	9000.00
0005435925240	3563	Economy	9000.00
0005435069264	3563	Economy	9000.00
0005435925203	3563	Economy	9000.00
0005435069245	3563	Economy	9000.00
0005435069251	3563	Economy	9000.00
0005435069228	3563	Economy	9000.00
0005435069219	3563	Economy	9000.00
0005435925326	15307	Business	26900.00
0005435068671	15307	Business	26900.00
0005435925325	15307	Business	26900.00
0005435068750	15307	Business	26900.00
0005435068613	15307	Business	26900.00
0005435068670	15307	Business	26900.00
0005435069034	15307	Economy	9000.00
0005435939885	15307	Economy	9000.00
0005435068768	15307	Economy	9000.00
0005435068533	15307	Economy	9000.00
0005435939884	15307	Economy	9000.00
0005435925337	15307	Economy	9000.00
0005435068943	15307	Economy	9000.00
0005435068738	15307	Economy	9900.00
0005435939883	15307	Economy	9900.00
0005435068724	15307	Economy	9900.00
0005435925340	15307	Economy	9000.00
0005435068782	15307	Economy	9000.00
0005435068532	15307	Economy	9000.00
0005435068843	15307	Economy	9000.00
0005435068924	15307	Economy	9000.00
0005435068676	15307	Economy	9000.00
0005435068836	15307	Economy	9000.00
0005435068780	15307	Economy	9000.00
0005435068553	15307	Economy	9000.00
0005435068342	15307	Economy	9000.00
0005435068781	15307	Economy	9000.00
0005435068698	15307	Economy	9000.00
0005435068727	15307	Economy	9000.00
0005435925327	15307	Economy	9000.00
0005435925339	15307	Economy	9000.00
0005435068753	15307	Economy	9000.00
0005435068587	15307	Economy	9000.00
0005435068697	15307	Economy	9000.00
0005435068927	15307	Economy	9000.00
0005435925334	15307	Economy	9000.00
0005435925338	15307	Economy	9000.00
0005435068483	15307	Economy	9000.00
0005435068751	15307	Economy	9000.00
0005435068769	15307	Economy	9000.00
0005435068612	15307	Economy	9000.00
0005435068729	15307	Economy	9000.00
0005435068723	15307	Economy	9000.00
0005435068823	15307	Economy	9000.00
0005435925329	15307	Economy	9000.00
0005435068916	15307	Economy	9000.00
0005435068735	15307	Economy	9000.00
0005435925333	15307	Economy	9000.00
0005435925328	15307	Economy	9000.00
0005435068594	15307	Economy	9000.00
0005435068465	15307	Economy	9000.00
0005435925335	15307	Economy	9000.00
0005435068730	15307	Economy	9000.00
0005435068607	15307	Economy	9000.00
0005435068923	15307	Economy	9000.00
0005435925331	15307	Economy	9000.00
0005435068779	15307	Economy	9000.00
0005435068728	15307	Economy	9000.00
0005435925330	15307	Economy	9000.00
0005435925332	15307	Economy	9000.00
0005435068595	15307	Economy	9000.00
0005435925336	15307	Economy	9000.00
0005432659712	18197	Economy	5900.00
0005432658597	18197	Economy	5900.00
0005432658596	18197	Economy	5900.00
0005432658598	18197	Economy	5900.00
0005432659714	18197	Economy	5900.00
0005432659711	18197	Economy	5900.00
0005432659713	18197	Economy	5900.00
0005432660824	18197	Economy	5900.00
0005432660823	18197	Economy	5900.00
0005432667441	26360	Economy	5900.00
0005432664120	26360	Economy	5900.00
0005432660804	26360	Economy	5900.00
0005432660805	26360	Economy	5900.00
0005433101832	2	Business	20000.00
0005433101885	2	Business	20000.00
0005433101689	2	Business	20000.00
0005433101879	2	Business	20000.00
0005432157499	2	Business	20000.00
0005433101867	2	Business	20000.00
0005433101883	2	Business	20000.00
0005433101934	2	Business	20000.00
0005433101684	2	Business	20000.00
0005433101784	2	Business	20000.00
0005433101736	2	Business	20000.00
0005433101892	2	Business	20000.00
0005432901540	2	Business	20000.00
0005432919745	2	Business	20000.00
0005433101770	2	Economy	7300.00
0005432919789	2	Economy	7300.00
0005432919786	2	Economy	7300.00
0005432901523	2	Economy	7300.00
0005432901442	2	Economy	6700.00
0005432901443	2	Economy	6700.00
0005433101886	2	Economy	6700.00
0005432901510	2	Economy	6700.00
0005433101839	2	Economy	6700.00
0005433101919	2	Economy	6700.00
0005432901482	2	Economy	6700.00
0005433101688	2	Economy	6700.00
0005432901522	2	Economy	6700.00
0005433101877	2	Economy	6700.00
0005432901543	2	Economy	6700.00
0005433101865	2	Economy	6700.00
0005433101739	2	Economy	6700.00
0005433101893	2	Economy	6700.00
0005433101918	2	Economy	6700.00
0005433101794	2	Economy	6700.00
0005433101852	2	Economy	6700.00
0005433101903	2	Economy	6700.00
0005432901608	2	Economy	6700.00
0005432901538	2	Economy	6700.00
0005432901512	2	Economy	6700.00
0005432919744	2	Economy	6700.00
0005433101911	2	Economy	6700.00
0005432919743	2	Economy	6700.00
0005432919738	2	Economy	6700.00
0005433101866	2	Economy	6700.00
0005432919741	2	Economy	6700.00
0005432919787	2	Economy	6700.00
0005433101829	2	Economy	6700.00
0005432919774	2	Economy	6700.00
0005433101838	2	Economy	6700.00
0005432901539	2	Economy	6700.00
0005433101719	2	Economy	6700.00
0005433101710	2	Economy	7300.00
0005432919765	2	Economy	7300.00
0005432919771	2	Economy	7300.00
0005432901497	2	Economy	7300.00
0005432919714	2	Economy	6700.00
0005433101887	2	Economy	6700.00
0005432919821	2	Economy	6700.00
0005433101798	2	Economy	6700.00
0005433101796	2	Economy	6700.00
0005432919794	2	Economy	6700.00
0005433101708	2	Economy	6700.00
0005432919742	2	Economy	6700.00
0005432919688	2	Economy	6700.00
0005432901483	2	Economy	6700.00
0005433101874	2	Economy	6700.00
0005432677539	2	Economy	6700.00
0005432919740	2	Economy	6700.00
0005432919812	2	Economy	6700.00
0005432901496	2	Economy	6700.00
0005433101895	2	Economy	6700.00
0005433101709	2	Economy	6700.00
0005432919730	2	Economy	6700.00
0005432157498	2	Economy	6700.00
0005433101938	2	Economy	6700.00
0005432901511	2	Economy	6700.00
0005433101801	2	Economy	6700.00
0005433101763	2	Economy	6700.00
0005433101840	2	Economy	6700.00
0005433101935	2	Economy	6700.00
0005432919729	2	Economy	6700.00
0005432919820	2	Economy	6700.00
0005432901609	2	Economy	6700.00
0005433101718	2	Economy	6700.00
0005433101875	2	Economy	6700.00
0005432157497	2	Economy	6700.00
0005432919767	2	Economy	6700.00
0005433101822	2	Economy	6700.00
0005433101855	2	Economy	6700.00
0005433101850	2	Economy	6700.00
0005432919716	2	Economy	6700.00
0005433101884	2	Economy	6700.00
0005433101797	2	Economy	6700.00
0005432919775	2	Economy	6700.00
0005432901567	2	Economy	6700.00
0005432901568	2	Economy	6700.00
0005433101881	2	Economy	6700.00
0005433101740	2	Economy	6700.00
0005432919819	2	Economy	6700.00
0005433101864	2	Economy	6700.00
0005432919715	2	Economy	6700.00
0005432207667	3	Business	20000.00
0005432817568	3	Business	20000.00
0005432817559	3	Business	20000.00
0005432817560	3	Business	20000.00
0005432817573	3	Business	20000.00
0005432753271	3	Business	20000.00
0005433687684	3	Business	20000.00
0005432817558	3	Business	20000.00
0005432817547	3	Business	20000.00
0005432753272	3	Business	20000.00
0005432817564	3	Business	20000.00
0005432262047	3	Business	20000.00
0005432817561	3	Business	20000.00
0005433687681	3	Business	20000.00
0005432262061	3	Business	20000.00
0005432262057	3	Economy	7300.00
0005432817563	3	Economy	7300.00
0005432262027	3	Economy	7300.00
0005432262031	3	Economy	7300.00
0005432262042	3	Economy	6700.00
0005432262054	3	Economy	6700.00
0005432262046	3	Economy	6700.00
0005432817549	3	Economy	6700.00
0005432817570	3	Economy	6700.00
0005432288995	3	Economy	6700.00
0005432753265	3	Economy	6700.00
0005432817566	3	Economy	6700.00
0005432262059	3	Economy	6700.00
0005432262035	3	Economy	6700.00
0005432262064	3	Economy	6700.00
0005432262025	3	Economy	6700.00
0005432262048	3	Economy	6700.00
0005432262034	3	Economy	6700.00
0005432262051	3	Economy	6700.00
0005432262068	3	Economy	6700.00
0005432262063	3	Economy	6700.00
0005432288994	3	Economy	6700.00
0005432262045	3	Economy	6700.00
0005433687685	3	Economy	6700.00
0005432262053	3	Economy	6700.00
0005432262032	3	Economy	6700.00
0005432262026	3	Economy	6700.00
0005432262036	3	Economy	6700.00
0005432262069	3	Economy	6700.00
0005432262039	3	Economy	6700.00
0005432262024	3	Economy	6700.00
0005432753269	3	Economy	6700.00
0005433690911	3	Economy	6700.00
0005432817572	3	Economy	6700.00
0005432817567	3	Economy	6700.00
0005432262044	3	Economy	6700.00
0005432817565	3	Economy	7300.00
0005432262058	3	Economy	7300.00
0005432817574	3	Economy	7300.00
0005432817562	3	Economy	6700.00
0005432753296	3	Economy	6700.00
0005432817546	3	Economy	6700.00
0005432817575	3	Economy	6700.00
0005432262033	3	Economy	6700.00
0005432262049	3	Economy	6700.00
0005432262050	3	Economy	6700.00
0005432262029	3	Economy	6700.00
0005432817556	3	Economy	6700.00
0005432817555	3	Economy	6700.00
0005433690909	3	Economy	6700.00
0005432262055	3	Economy	6700.00
0005432262041	3	Economy	6700.00
0005432817557	3	Economy	6700.00
0005432262067	3	Economy	6700.00
0005432262066	3	Economy	6700.00
0005432262043	3	Economy	6700.00
0005432262056	3	Economy	6700.00
0005432262040	3	Economy	6700.00
0005432262060	3	Economy	6700.00
0005432262038	3	Economy	6700.00
0005433687682	3	Economy	6700.00
0005432262070	3	Economy	6700.00
0005432756829	3	Economy	6700.00
0005432817553	3	Economy	6700.00
0005432262065	3	Economy	6700.00
0005432262052	3	Economy	6700.00
0005432262062	3	Economy	6700.00
0005432817552	3	Economy	6700.00
0005432207666	3	Economy	6700.00
0005432207668	3	Economy	6700.00
0005432817551	3	Economy	6700.00
0005432288997	3	Economy	6700.00
0005432817554	3	Economy	6700.00
0005432817569	3	Economy	6700.00
0005432262037	3	Economy	6700.00
0005432262030	3	Economy	6700.00
0005432817550	3	Economy	6700.00
0005432817548	3	Economy	6700.00
0005432288996	3	Economy	6700.00
0005432262028	3	Economy	6700.00
0005433690910	3	Economy	6700.00
0005432817571	3	Economy	6700.00
0005432020342	8097	Business	20000.00
0005433102309	8097	Business	20000.00
0005433102338	8097	Business	20000.00
0005433102339	8097	Business	20000.00
0005432919910	8097	Business	20000.00
0005433102333	8097	Business	20000.00
0005432392007	8097	Business	20000.00
0005432919930	8097	Business	20000.00
0005432919911	8097	Business	20000.00
0005432020337	8097	Business	20000.00
0005433102299	8097	Business	20000.00
0005432045619	8097	Business	20000.00
0005432751538	8097	Business	20000.00
0005433102317	8097	Business	20000.00
0005432045620	8097	Business	20000.00
0005433102304	8097	Business	20000.00
0005433102328	8097	Business	20000.00
0005433102296	8097	Economy	7300.00
0005433102320	8097	Economy	7300.00
0005432020348	8097	Economy	7300.00
0005433102312	8097	Economy	6700.00
0005432392009	8097	Economy	6700.00
0005433102307	8097	Economy	6700.00
0005432919918	8097	Economy	6700.00
0005432919915	8097	Economy	6700.00
0005433102335	8097	Economy	6700.00
0005433102295	8097	Economy	6700.00
0005432020336	8097	Economy	6700.00
0005432919921	8097	Economy	6700.00
0005432020339	8097	Economy	6700.00
0005432677585	8097	Economy	6700.00
0005432919919	8097	Economy	6700.00
0005432020331	8097	Economy	6700.00
0005433102336	8097	Economy	6700.00
0005432919922	8097	Economy	6700.00
0005432919917	8097	Economy	6700.00
0005433102306	8097	Economy	6700.00
0005432020349	8097	Economy	6700.00
0005432753312	8097	Economy	6700.00
0005433102313	8097	Economy	6700.00
0005433102301	8097	Economy	6700.00
0005432020334	8097	Economy	6700.00
0005432020351	8097	Economy	6700.00
0005432919916	8097	Economy	6700.00
0005433102298	8097	Economy	6700.00
0005433102331	8097	Economy	6700.00
0005432020329	8097	Economy	6700.00
0005433102294	8097	Economy	6700.00
0005433102319	8097	Economy	6700.00
0005432044534	8097	Economy	6700.00
0005432677586	8097	Economy	6700.00
0005432020341	8097	Economy	6700.00
0005432020330	8097	Economy	6700.00
0005433102332	8097	Economy	6700.00
0005433102318	8097	Economy	6700.00
0005433102322	8097	Economy	6700.00
0005433102314	8097	Economy	6700.00
0005432044532	8097	Economy	6700.00
0005432020354	8097	Economy	6700.00
0005432919909	8097	Economy	6700.00
0005433102311	8097	Economy	6700.00
0005432020347	8097	Economy	6700.00
0005432919920	8097	Economy	6700.00
0005433102310	8097	Economy	7300.00
0005433102316	8097	Economy	7300.00
0005433102303	8097	Economy	7300.00
0005433102325	8097	Economy	7300.00
0005432020353	8097	Economy	6700.00
0005432677588	8097	Economy	6700.00
0005433102330	8097	Economy	6700.00
0005432020345	8097	Economy	6700.00
0005432020352	8097	Economy	6700.00
0005432919913	8097	Economy	6700.00
0005432753313	8097	Economy	6700.00
0005433102308	8097	Economy	6700.00
0005433102321	8097	Economy	6700.00
0005432392008	8097	Economy	6700.00
0005432020332	8097	Economy	6700.00
0005433102300	8097	Economy	6700.00
0005432919926	8097	Economy	6700.00
0005433102327	8097	Economy	6700.00
0005432677587	8097	Economy	6700.00
0005432919912	8097	Economy	6700.00
0005433102329	8097	Economy	6700.00
0005432919928	8097	Economy	6700.00
0005432919927	8097	Economy	6700.00
0005433102315	8097	Economy	6700.00
0005433102324	8097	Economy	6700.00
0005432919923	8097	Economy	6700.00
0005432753311	8097	Economy	6700.00
0005432020350	8097	Economy	6700.00
0005433102337	8097	Economy	6700.00
0005433102305	8097	Economy	6700.00
0005432020335	8097	Economy	6700.00
0005432020344	8097	Economy	6700.00
0005432020333	8097	Economy	6700.00
0005432020343	8097	Economy	6700.00
0005433102293	8097	Economy	6700.00
0005433102323	8097	Economy	6700.00
0005432020338	8097	Economy	6700.00
0005432020346	8097	Economy	6700.00
0005432751537	8097	Economy	6700.00
0005432919914	8097	Economy	6700.00
0005432753314	8097	Economy	6700.00
0005432919925	8097	Economy	6700.00
0005432919929	8097	Economy	6700.00
0005433102326	8097	Economy	6700.00
0005432044533	8097	Economy	6700.00
0005433102297	8097	Economy	6700.00
0005433102334	8097	Economy	6700.00
0005432919924	8097	Economy	6700.00
0005433102302	8097	Economy	6700.00
0005432020340	8097	Economy	6700.00
0005432901665	8098	Business	20000.00
0005432817169	8098	Business	20000.00
0005432817362	8098	Business	20000.00
0005432817297	8098	Business	20000.00
0005432901653	8098	Business	20000.00
0005432901656	8098	Business	20000.00
0005432817177	8098	Business	20000.00
0005432002082	8098	Business	20000.00
0005432901666	8098	Business	20000.00
0005432901660	8098	Economy	7300.00
0005432817332	8098	Economy	6700.00
0005432817206	8098	Economy	6700.00
0005432817312	8098	Economy	6700.00
0005432817410	8098	Economy	6700.00
0005432002084	8098	Economy	6700.00
0005432817341	8098	Economy	6700.00
0005432901663	8098	Economy	6700.00
0005432901670	8098	Economy	6700.00
0005432817314	8098	Economy	6700.00
0005432817236	8098	Economy	6700.00
0005432817383	8098	Economy	6700.00
0005432817411	8098	Economy	6700.00
0005432901669	8098	Economy	7300.00
0005432817182	8098	Economy	6700.00
0005432901668	8098	Economy	6700.00
0005432817280	8098	Economy	6700.00
0005432901654	8098	Economy	6700.00
0005432817260	8098	Economy	6700.00
0005432901658	8098	Economy	6700.00
0005432817294	8098	Economy	6700.00
0005432817315	8098	Economy	6700.00
0005432901661	8098	Economy	6700.00
0005432817361	8098	Economy	6700.00
0005432901664	8098	Economy	6700.00
0005432901667	8098	Economy	6700.00
0005432901662	8098	Economy	6700.00
0005432817333	8098	Economy	6700.00
0005432817363	8098	Economy	6700.00
0005432901657	8098	Economy	6700.00
0005432817208	8098	Economy	6700.00
0005432817381	8098	Economy	6700.00
0005432817209	8098	Economy	6700.00
0005432901659	8098	Economy	6700.00
0005432901655	8098	Economy	6700.00
0005432817281	8098	Economy	6700.00
0005432817128	8098	Economy	6700.00
0005432002083	8098	Economy	6700.00
0005432817183	8098	Economy	6700.00
0005433870738	9655	Economy	6900.00
0005434175723	9655	Economy	6900.00
0005434175721	9655	Economy	6900.00
0005434175730	9655	Economy	6900.00
0005434175722	9655	Economy	6900.00
0005434175765	32322	Economy	6900.00
0005433870723	32322	Economy	6900.00
0005434175767	32322	Economy	6900.00
0005434175763	32322	Economy	6900.00
0005434175764	32322	Economy	6900.00
0005434175766	32322	Economy	6900.00
0005435126484	3486	Business	35000.00
0005432799533	3486	Business	35000.00
0005435126508	3486	Business	35000.00
0005434938197	3486	Business	35000.00
0005435126504	3486	Business	35000.00
0005434878506	3486	Business	35000.00
0005434878528	3486	Business	35000.00
0005432799537	3486	Business	35000.00
0005434878494	3486	Business	35000.00
0005434426705	3486	Business	35000.00
0005435913906	3486	Business	35000.00
0005434878567	3486	Business	35000.00
0005435902633	3486	Business	35000.00
0005434878522	3486	Business	35000.00
0005432188619	3486	Business	35000.00
0005434426700	3486	Business	35000.00
0005434878500	3486	Business	35000.00
0005434878503	3486	Business	35000.00
0005432799541	3486	Business	35000.00
0005432188616	3486	Business	35000.00
0005435626236	3486	Business	35000.00
0005432799558	3486	Business	35000.00
0005435126485	3486	Comfort	19900.00
0005434878566	3486	Comfort	19900.00
0005432799561	3486	Comfort	19900.00
0005434938212	3486	Comfort	19900.00
0005432611723	3486	Comfort	19900.00
0005435126512	3486	Comfort	19900.00
0005434426691	3486	Comfort	19900.00
0005434878492	3486	Comfort	19900.00
0005434878505	3486	Comfort	19900.00
0005434426715	3486	Comfort	19900.00
0005435902622	3486	Comfort	19900.00
0005434878534	3486	Comfort	19900.00
0005434426703	3486	Comfort	19900.00
0005434878555	3486	Comfort	19900.00
0005435902584	3486	Comfort	19900.00
0005435126514	3486	Comfort	19900.00
0005435902695	3486	Comfort	19900.00
0005434878576	3486	Comfort	19900.00
0005434426716	3486	Comfort	19900.00
0005434878569	3486	Comfort	19900.00
0005434426718	3486	Comfort	19900.00
0005435626222	3486	Comfort	19900.00
0005432613876	3486	Comfort	19900.00
0005435902655	3486	Comfort	19900.00
0005435902642	3486	Comfort	19900.00
0005432188617	3486	Comfort	19900.00
0005435126497	3486	Comfort	19900.00
0005435626229	3486	Comfort	19900.00
0005434878525	3486	Comfort	19900.00
0005434878559	3486	Comfort	19900.00
0005434426711	3486	Comfort	19900.00
0005434938204	3486	Comfort	19900.00
0005435126490	3486	Economy	11700.00
0005434878573	3486	Economy	11700.00
0005435126487	3486	Economy	11700.00
0005434878489	3486	Economy	11700.00
0005435902638	3486	Economy	11700.00
0005432183474	3486	Economy	11700.00
0005434878493	3486	Economy	11700.00
0005435902649	3486	Economy	11700.00
0005434878547	3486	Economy	11700.00
0005434878570	3486	Economy	11700.00
0005434878524	3486	Economy	11700.00
0005434878510	3486	Economy	11700.00
0005434426717	3486	Economy	11700.00
0005435902641	3486	Economy	11700.00
0005435126488	3486	Economy	11700.00
0005434878513	3486	Economy	11700.00
0005434938193	3486	Economy	11700.00
0005432799556	3486	Economy	11700.00
0005432799553	3486	Economy	11700.00
0005434878539	3486	Economy	11700.00
0005434878545	3486	Economy	11700.00
0005434878520	3486	Economy	11700.00
0005435902597	3486	Economy	11700.00
0005432799542	3486	Economy	11700.00
0005434426687	3486	Economy	11700.00
0005435902648	3486	Economy	11700.00
0005434878495	3486	Economy	11700.00
0005434426697	3486	Economy	11700.00
0005435913910	3486	Economy	11700.00
0005435126496	3486	Economy	11700.00
0005434878523	3486	Economy	11700.00
0005434878504	3486	Economy	11700.00
0005435626225	3486	Economy	11700.00
0005434878565	3486	Economy	11700.00
0005435126502	3486	Economy	11700.00
0005434878553	3486	Economy	11700.00
0005432799531	3486	Economy	11700.00
0005435841817	3486	Economy	11700.00
0005435902596	3486	Economy	11700.00
0005435126519	3486	Economy	11700.00
0005434426689	3486	Economy	11700.00
0005432799549	3486	Economy	11700.00
0005435626231	3486	Economy	11700.00
0005435902677	3486	Economy	11700.00
0005435913891	3486	Economy	11700.00
0005434878488	3486	Economy	11700.00
0005435126492	3486	Economy	11700.00
0005434938199	3486	Economy	11700.00
0005435626233	3486	Economy	11700.00
0005435126511	3486	Economy	11700.00
0005434938194	3486	Economy	11700.00
0005432799540	3486	Economy	11700.00
0005435626221	3486	Economy	11700.00
0005435126500	3486	Economy	11700.00
0005435626226	3486	Economy	11700.00
0005434426704	3486	Economy	12800.00
0005434878563	3486	Economy	11700.00
0005434938198	3486	Economy	11700.00
0005434426713	3486	Economy	11700.00
0005434938207	3486	Economy	11700.00
0005435626224	3486	Economy	11700.00
0005435126499	3486	Economy	11700.00
0005432799557	3486	Economy	11700.00
0005434878550	3486	Economy	11700.00
0005434938203	3486	Economy	11700.00
0005435126495	3486	Economy	11700.00
0005434426708	3486	Economy	11700.00
0005435126507	3486	Economy	11700.00
0005434878541	3486	Economy	11700.00
0005434878511	3486	Economy	11700.00
0005434938202	3486	Economy	11700.00
0005432183473	3486	Economy	11700.00
0005434878483	3486	Economy	11700.00
0005434426706	3486	Economy	11700.00
0005435126482	3486	Economy	11700.00
0005435126513	3486	Economy	11700.00
0005434878512	3486	Economy	11700.00
0005434878486	3486	Economy	11700.00
0005434878554	3486	Economy	11700.00
0005432611725	3486	Economy	11700.00
0005434878558	3486	Economy	11700.00
0005435626219	3486	Economy	11700.00
0005435913868	3486	Economy	11700.00
0005434878562	3486	Economy	11700.00
0005435126517	3486	Economy	11700.00
0005434878527	3486	Economy	11700.00
0005434938195	3486	Economy	11700.00
0005434426696	3486	Economy	11700.00
0005435913898	3486	Economy	11700.00
0005434878502	3486	Economy	11700.00
0005435902632	3486	Economy	11700.00
0005435126503	3486	Economy	11700.00
0005434878501	3486	Economy	11700.00
0005434938201	3486	Economy	11700.00
0005434878551	3486	Economy	11700.00
0005435126481	3486	Economy	11700.00
0005434878484	3486	Economy	11700.00
0005432799538	3486	Economy	11700.00
0005434426710	3486	Economy	11700.00
0005434878490	3486	Economy	11700.00
0005434878519	3486	Economy	11700.00
0005435126520	3486	Economy	11700.00
0005435126483	3486	Economy	11700.00
0005434938200	3486	Economy	11700.00
0005432613873	3486	Economy	11700.00
0005435126491	3486	Economy	11700.00
0005435902651	3486	Economy	11700.00
0005434938196	3486	Economy	11700.00
0005435626227	3486	Economy	11700.00
0005435626218	3486	Economy	11700.00
0005432188618	3486	Economy	11700.00
0005432799545	3486	Economy	11700.00
0005434878540	3486	Economy	11700.00
0005434878529	3486	Economy	11700.00
0005432611722	3486	Economy	11700.00
0005434426690	3486	Economy	11700.00
0005434878499	3486	Economy	11700.00
0005435913892	3486	Economy	11700.00
0005434938211	3486	Economy	11700.00
0005434426688	3486	Economy	11700.00
0005435126489	3486	Economy	11700.00
0005434878556	3486	Economy	11700.00
0005435902634	3486	Economy	11700.00
0005434878544	3486	Economy	11700.00
0005434878498	3486	Economy	11700.00
0005435126505	3486	Economy	11700.00
0005434878491	3486	Economy	11700.00
0005432799559	3486	Economy	11700.00
0005434878530	3486	Economy	11700.00
0005432613874	3486	Economy	11700.00
0005435126510	3486	Economy	11700.00
0005434878564	3486	Economy	11700.00
0005435626235	3486	Economy	11700.00
0005434426709	3486	Economy	11700.00
0005435126515	3486	Economy	11700.00
0005435626228	3486	Economy	11700.00
0005435126509	3486	Economy	11700.00
0005435626239	3486	Economy	11700.00
0005434878535	3486	Economy	11700.00
0005434878507	3486	Economy	11700.00
0005432799536	3486	Economy	11700.00
0005435126516	3486	Economy	11700.00
0005434878578	3486	Economy	11700.00
0005434878518	3486	Economy	11700.00
0005435626220	3486	Economy	11700.00
0005434878514	3486	Economy	12800.00
0005434938206	3486	Economy	12800.00
0005432799554	3486	Economy	12800.00
0005432799560	3486	Economy	12800.00
0005434878508	3486	Economy	12800.00
0005434878496	3486	Economy	11700.00
0005434878533	3486	Economy	11700.00
0005435126493	3486	Economy	11700.00
0005435902629	3486	Economy	11700.00
0005434878561	3486	Economy	11700.00
0005432799544	3486	Economy	11700.00
0005435902600	3486	Economy	11700.00
0005435626232	3486	Economy	11700.00
0005434878517	3486	Economy	11700.00
0005434878560	3486	Economy	11700.00
0005434878516	3486	Economy	11700.00
0005434426707	3486	Economy	11700.00
0005434938205	3486	Economy	11700.00
0005432799548	3486	Economy	11700.00
0005434878577	3486	Economy	11700.00
0005435902531	3486	Economy	11700.00
0005435902623	3486	Economy	11700.00
0005434878571	3486	Economy	11700.00
0005435626238	3486	Economy	11700.00
0005435626237	3486	Economy	11700.00
0005435126498	3486	Economy	11700.00
0005432611724	3486	Economy	11700.00
0005432799539	3486	Economy	11700.00
0005432799532	3486	Economy	11700.00
0005432799555	3486	Economy	11700.00
0005434938210	3486	Economy	11700.00
0005434878485	3486	Economy	11700.00
0005435626234	3486	Economy	11700.00
0005434878537	3486	Economy	11700.00
0005435126518	3486	Economy	11700.00
0005434878497	3486	Economy	11700.00
0005435902656	3486	Economy	11700.00
0005434938209	3486	Economy	11700.00
0005434878538	3486	Economy	11700.00
0005434878572	3486	Economy	11700.00
0005435902540	3486	Economy	11700.00
0005435902532	3486	Economy	11700.00
0005434878542	3486	Economy	11700.00
0005435626230	3486	Economy	11700.00
0005434426702	3486	Economy	11700.00
0005434878575	3486	Economy	11700.00
0005434426699	3486	Economy	11700.00
0005434426695	3486	Economy	11700.00
0005432799551	3486	Economy	11700.00
0005435626223	3486	Economy	11700.00
0005434426694	3486	Economy	11700.00
0005434426714	3486	Economy	11700.00
0005432799550	3486	Economy	11700.00
0005435126506	3486	Economy	11700.00
0005432799543	3486	Economy	11700.00
0005434426693	3486	Economy	11700.00
0005434878536	3486	Economy	11700.00
0005432799546	3486	Economy	11700.00
0005434938208	3486	Economy	11700.00
0005432613875	3486	Economy	11700.00
0005434426712	3486	Economy	11700.00
0005434878531	3486	Economy	11700.00
0005435126494	3486	Economy	11700.00
0005434426701	3486	Economy	11700.00
0005435126501	3486	Economy	11700.00
0005432799552	3486	Economy	11700.00
0005434878509	3486	Economy	11700.00
0005434878546	3486	Economy	11700.00
0005434878515	3486	Economy	11700.00
0005434878574	3486	Economy	11700.00
0005432613872	3486	Economy	11700.00
0005432799535	3486	Economy	11700.00
0005434878557	3486	Economy	11700.00
0005432188620	3486	Economy	11700.00
0005434878548	3486	Economy	11700.00
0005434878549	3486	Economy	11700.00
0005432611721	3486	Economy	11700.00
0005434426698	3486	Economy	11700.00
0005435126486	3486	Economy	11700.00
0005435913897	3486	Economy	11700.00
0005434878552	3486	Economy	11700.00
0005434878487	3486	Economy	11700.00
0005434878526	3486	Economy	11700.00
0005434878521	3486	Economy	11700.00
0005434878532	3486	Economy	11700.00
0005434878543	3486	Economy	11700.00
0005434878568	3486	Economy	11700.00
0005432799534	3486	Economy	11700.00
0005435913911	3486	Economy	11700.00
0005434426692	3486	Economy	11700.00
0005432799547	3486	Economy	11700.00
0005435626090	14550	Business	35000.00
0005435126217	14550	Business	35000.00
0005434877796	14550	Business	35000.00
0005434877743	14550	Business	35000.00
0005432799303	14550	Business	35000.00
0005434877773	14550	Business	35000.00
0005432607527	14550	Business	35000.00
0005434426371	14550	Business	35000.00
0005434877759	14550	Business	35000.00
0005432799288	14550	Business	35000.00
0005432607563	14550	Business	35000.00
0005434878005	14550	Business	35000.00
0005434426474	14550	Business	35000.00
0005435126285	14550	Business	35000.00
0005435126132	14550	Business	35000.00
0005434877742	14550	Business	35000.00
0005434877649	14550	Business	35000.00
0005434877790	14550	Business	35000.00
0005434877810	14550	Business	35000.00
0005434877758	14550	Business	35000.00
0005434877804	14550	Comfort	19900.00
0005434877725	14550	Comfort	19900.00
0005434877864	14550	Comfort	19900.00
0005435902749	14550	Comfort	19900.00
0005434878051	14550	Comfort	19900.00
0005435902751	14550	Comfort	19900.00
0005435126118	14550	Comfort	19900.00
0005435842328	14550	Comfort	19900.00
0005434877289	14550	Comfort	19900.00
0005434426502	14550	Comfort	19900.00
0005434426591	14550	Comfort	19900.00
0005432799229	14550	Comfort	19900.00
0005434938046	14550	Comfort	19900.00
0005432799301	14550	Comfort	19900.00
0005435626088	14550	Comfort	19900.00
0005435626087	14550	Comfort	19900.00
0005432799376	14550	Comfort	19900.00
0005434426505	14550	Comfort	19900.00
0005434877660	14550	Comfort	19900.00
0005432799414	14550	Comfort	19900.00
0005435126195	14550	Comfort	19900.00
0005435626035	14550	Comfort	19900.00
0005432607525	14550	Comfort	19900.00
0005435902748	14550	Comfort	19900.00
0005434877679	14550	Comfort	19900.00
0005434938109	14550	Comfort	19900.00
0005434877557	14550	Comfort	19900.00
0005434877860	14550	Comfort	19900.00
0005432799287	14550	Comfort	19900.00
0005435126196	14550	Comfort	19900.00
0005435626037	14550	Comfort	19900.00
0005434877605	14550	Comfort	19900.00
0005435902761	14550	Comfort	19900.00
0005432611694	14550	Economy	11700.00
0005432799216	14550	Economy	11700.00
0005435902765	14550	Economy	11700.00
0005434877989	14550	Economy	11700.00
0005434877772	14550	Economy	11700.00
0005434877680	14550	Economy	11700.00
0005435626062	14550	Economy	11700.00
0005434877452	14550	Economy	11700.00
0005434426603	14550	Economy	11700.00
0005435626063	14550	Economy	11700.00
0005435126225	14550	Economy	11700.00
0005434938111	14550	Economy	11700.00
0005435626013	14550	Economy	11700.00
0005435126227	14550	Economy	11700.00
0005434877372	14550	Economy	11700.00
0005435126197	14550	Economy	11700.00
0005435626044	14550	Economy	11700.00
0005432799357	14550	Economy	11700.00
0005435842330	14550	Economy	11700.00
0005434877990	14550	Economy	11700.00
0005434426372	14550	Economy	11700.00
0005432799247	14550	Economy	11700.00
0005434426508	14550	Economy	11700.00
0005434877648	14550	Economy	11700.00
0005435126131	14550	Economy	11700.00
0005434426433	14550	Economy	11700.00
0005435126102	14550	Economy	11700.00
0005434877858	14550	Economy	11700.00
0005435626038	14550	Economy	11700.00
0005434877486	14550	Economy	11700.00
0005432611681	14550	Economy	11700.00
0005434877865	14550	Economy	11700.00
0005434877936	14550	Economy	11700.00
0005434938021	14550	Economy	11700.00
0005435902753	14550	Economy	11700.00
0005434877558	14550	Economy	11700.00
0005434877892	14550	Economy	11700.00
0005434426576	14550	Economy	11700.00
0005434877465	14550	Economy	11700.00
0005434938052	14550	Economy	11700.00
0005435626065	14550	Economy	11700.00
0005434938077	14550	Economy	12800.00
0005434878194	14550	Economy	12800.00
0005434877409	14550	Economy	11700.00
0005434877789	14550	Economy	12800.00
0005434877797	14550	Economy	11700.00
0005434878004	14550	Economy	11700.00
0005435125983	14550	Economy	11700.00
0005435126029	14550	Economy	12800.00
0005435902763	14550	Economy	11700.00
0005434877253	14550	Economy	11700.00
0005434877453	14550	Economy	11700.00
0005434426448	14550	Economy	11700.00
0005434426398	14550	Economy	11700.00
0005434877581	14550	Economy	11700.00
0005435126216	14550	Economy	11700.00
0005432799299	14550	Economy	11700.00
0005435902764	14550	Economy	11700.00
0005434877975	14550	Economy	11700.00
0005435902762	14550	Economy	11700.00
0005432799355	14550	Economy	11700.00
0005435126082	14550	Economy	11700.00
0005434938064	14550	Economy	11700.00
0005432799273	14550	Economy	11700.00
0005435842329	14550	Economy	11700.00
0005434426493	14550	Economy	11700.00
0005434426455	14550	Economy	11700.00
0005435626057	14550	Economy	11700.00
0005434938047	14550	Economy	11700.00
0005434426456	14550	Economy	11700.00
0005435902752	14550	Economy	11700.00
0005434938020	14550	Economy	11700.00
0005434877735	14550	Economy	11700.00
0005432799392	14550	Economy	11700.00
0005434426546	14550	Economy	11700.00
0005434878205	14550	Economy	11700.00
0005434877823	14550	Economy	11700.00
0005434877857	14550	Economy	11700.00
0005432799304	14550	Economy	11700.00
0005434426554	14550	Economy	11700.00
0005435125995	14550	Economy	11700.00
0005434877988	14550	Economy	11700.00
0005434877464	14550	Economy	11700.00
0005434877589	14550	Economy	11700.00
0005434426432	14550	Economy	11700.00
0005435125984	14550	Economy	11700.00
0005434877781	14550	Economy	11700.00
0005434877312	14550	Economy	11700.00
0005434877816	14550	Economy	11700.00
0005434426370	14550	Economy	11700.00
0005434426575	14550	Economy	11700.00
0005432799356	14550	Economy	11700.00
0005434877541	14550	Economy	11700.00
0005434877659	14550	Economy	11700.00
0005434877371	14550	Economy	11700.00
0005432607551	14550	Economy	11700.00
0005435902757	14550	Economy	11700.00
0005434877794	14550	Economy	11700.00
0005435126039	14550	Economy	11700.00
0005434877650	14550	Economy	11700.00
0005435902758	14550	Economy	11700.00
0005434877723	14550	Economy	11700.00
0005434938084	14550	Economy	11700.00
0005432607526	14550	Economy	11700.00
0005434877748	14550	Economy	11700.00
0005434877921	14550	Economy	11700.00
0005434878107	14550	Economy	11700.00
0005434877791	14550	Economy	11700.00
0005435125926	14550	Economy	11700.00
0005434878178	14550	Economy	11700.00
0005434877647	14550	Economy	11700.00
0005432059510	14550	Economy	11700.00
0005435625985	14550	Economy	11700.00
0005435126119	14550	Economy	11700.00
0005434426475	14550	Economy	11700.00
0005432799171	14550	Economy	11700.00
0005434938070	14550	Economy	11700.00
0005434938074	14550	Economy	11700.00
0005434877392	14550	Economy	11700.00
0005434877634	14550	Economy	11700.00
0005435126027	14550	Economy	11700.00
0005434877757	14550	Economy	11700.00
0005434938045	14550	Economy	11700.00
0005434877153	14550	Economy	11700.00
0005435902754	14550	Economy	11700.00
0005434877844	14550	Economy	11700.00
0005434938063	14550	Economy	12800.00
0005434878041	14550	Economy	11700.00
0005434878068	14550	Economy	12800.00
0005432607552	14550	Economy	12800.00
0005434426328	14550	Economy	11700.00
0005434877152	14550	Economy	11700.00
0005435625960	14550	Economy	11700.00
0005435902759	14550	Economy	11700.00
0005434877736	14550	Economy	11700.00
0005435125925	14550	Economy	11700.00
0005434877651	14550	Economy	11700.00
0005435626017	14550	Economy	11700.00
0005434877824	14550	Economy	11700.00
0005435902760	14550	Economy	11700.00
0005434877252	14550	Economy	11700.00
0005435626043	14550	Economy	11700.00
0005434426494	14550	Economy	11700.00
0005434877856	14550	Economy	11700.00
0005434938078	14550	Economy	11700.00
0005434877937	14550	Economy	11700.00
0005434938069	14550	Economy	11700.00
0005435626008	14550	Economy	11700.00
0005434877843	14550	Economy	11700.00
0005435626032	14550	Economy	11700.00
0005434937944	14550	Economy	11700.00
0005434938058	14550	Economy	11700.00
0005435902766	14550	Economy	11700.00
0005434877604	14550	Economy	11700.00
0005434877749	14550	Economy	11700.00
0005434877886	14550	Economy	11700.00
0005434877658	14550	Economy	11700.00
0005434878021	14550	Economy	11700.00
0005435626012	14550	Economy	11700.00
0005435902756	14550	Economy	11700.00
0005434877642	14550	Economy	11700.00
0005435126193	14550	Economy	11700.00
0005434877737	14550	Economy	11700.00
0005432059511	14550	Economy	11700.00
0005435126226	14550	Economy	11700.00
0005434877249	14550	Economy	11700.00
0005435126283	14550	Economy	11700.00
0005432799205	14550	Economy	11700.00
0005435902750	14550	Economy	11700.00
0005434877783	14550	Economy	11700.00
0005434877922	14550	Economy	11700.00
0005434877540	14550	Economy	11700.00
0005432607556	14550	Economy	11700.00
0005434877756	14550	Economy	11700.00
0005434426392	14550	Economy	11700.00
0005434938057	14550	Economy	11700.00
0005435126272	14550	Economy	11700.00
0005434877670	14550	Economy	11700.00
0005434937988	14550	Economy	11700.00
0005434426459	14550	Economy	11700.00
0005434938019	14550	Economy	11700.00
0005434938100	14550	Economy	11700.00
0005434877863	14550	Economy	11700.00
0005434877760	14550	Economy	11700.00
0005434937989	14550	Economy	11700.00
0005434878022	14550	Economy	11700.00
0005432059509	14550	Economy	11700.00
0005434877559	14550	Economy	11700.00
0005435126178	14550	Economy	11700.00
0005434877624	14550	Economy	11700.00
0005434877717	14550	Economy	11700.00
0005434877450	14550	Economy	11700.00
0005434877744	14550	Economy	11700.00
0005432799391	14550	Economy	11700.00
0005435626061	14550	Economy	11700.00
0005434877845	14550	Economy	11700.00
0005434877525	14550	Economy	11700.00
0005434878033	14550	Economy	11700.00
0005435626009	14550	Economy	11700.00
0005434877678	14550	Economy	11700.00
0005434877228	14550	Economy	11700.00
0005434877350	14550	Economy	11700.00
0005434877974	14550	Economy	11700.00
0005434877526	14550	Economy	11700.00
0005434877567	14550	Economy	11700.00
0005432799300	14550	Economy	11700.00
0005434877641	14550	Economy	11700.00
0005434878172	14550	Economy	11700.00
0005435902755	14550	Economy	11700.00
0005434426504	14550	Economy	11700.00
0005434877893	14550	Economy	11700.00
0005434312326	3597	Economy	14800.00
0005435889867	3597	Economy	14800.00
0005434325682	3597	Economy	14800.00
0005434325685	3597	Economy	14800.00
0005435889866	3597	Economy	14800.00
0005434325689	3597	Economy	14800.00
0005434325687	3597	Economy	14800.00
0005434325690	3597	Economy	14800.00
0005435889869	3597	Economy	14800.00
0005434325683	3597	Economy	14800.00
0005434325688	3597	Economy	14800.00
0005434325680	3597	Economy	14800.00
0005435889856	3597	Economy	14800.00
0005435889871	3597	Economy	14800.00
0005434325681	3597	Economy	14800.00
0005435889872	3597	Economy	14800.00
0005434325684	3597	Economy	14800.00
0005435889865	3597	Economy	14800.00
0005434312325	3597	Economy	14800.00
0005434325686	3597	Economy	14800.00
0005434325561	15603	Economy	16300.00
0005435889917	15603	Economy	16300.00
0005435889913	15603	Economy	14800.00
0005435889918	15603	Economy	14800.00
0005434325594	15603	Economy	14800.00
0005434325605	15603	Economy	14800.00
0005434325644	15603	Economy	14800.00
0005434325645	15603	Economy	14800.00
0005435889914	15603	Economy	14800.00
0005434325655	15603	Economy	14800.00
0005435889916	15603	Economy	14800.00
0005434325604	15603	Economy	14800.00
0005434325579	15603	Economy	14800.00
0005434325646	15603	Economy	14800.00
0005434325550	15603	Economy	14800.00
0005434325613	15603	Economy	14800.00
0005434325593	15603	Economy	14800.00
0005435889915	15603	Economy	14800.00
0005433420336	647	Economy	4500.00
0005433420380	647	Economy	4100.00
0005435957745	647	Economy	4100.00
0005435957744	647	Economy	4100.00
0005433420356	647	Economy	4100.00
0005435957755	647	Economy	4100.00
0005435957752	647	Economy	4100.00
0005435957750	647	Economy	4100.00
0005435957742	647	Economy	4100.00
0005435957756	647	Economy	4100.00
0005435957754	647	Economy	4100.00
0005435957740	647	Economy	4100.00
0005435957749	647	Economy	4100.00
0005435957748	647	Economy	4100.00
0005435957751	647	Economy	4100.00
0005435957747	647	Economy	4100.00
0005435957743	647	Economy	4100.00
0005435957746	647	Economy	4100.00
0005433420322	647	Economy	4100.00
0005433420381	647	Economy	4100.00
0005433420335	647	Economy	4100.00
0005435957741	647	Economy	4100.00
0005435957753	647	Economy	4100.00
0005433420340	647	Economy	4100.00
0005433420428	15206	Economy	4500.00
0005435957639	15206	Economy	4100.00
0005435957616	15206	Economy	4100.00
0005433420425	15206	Economy	4100.00
0005435957681	15206	Economy	4100.00
0005433420429	15206	Economy	4100.00
0005435957579	15206	Economy	4100.00
0005435957562	15206	Economy	4100.00
0005433420432	15206	Economy	4100.00
0005435957637	15206	Economy	4100.00
0005433420424	15206	Economy	4100.00
0005433420427	15206	Economy	4100.00
0005435957586	15206	Economy	4100.00
0005435957585	15206	Economy	4100.00
0005433420430	15206	Economy	4100.00
0005435957638	15206	Economy	4100.00
0005433420431	15206	Economy	4100.00
0005433420426	15206	Economy	4100.00
0005435957568	15206	Economy	4100.00
0005435957615	15206	Economy	4100.00
0005435629406	8947	Economy	10400.00
0005434247139	8947	Economy	10400.00
0005435629408	8947	Economy	10400.00
0005434247126	8947	Economy	10400.00
0005435629407	8947	Economy	10400.00
0005434247156	16088	Economy	10400.00
0005434247155	16088	Economy	10400.00
0005434096725	11825	Economy	13400.00
0005434096732	11825	Economy	13400.00
0005434096721	11825	Economy	13400.00
0005434096722	11825	Economy	13400.00
0005434096723	11825	Economy	13400.00
0005434096727	11825	Economy	13400.00
0005434096726	11825	Economy	13400.00
0005434096748	20167	Economy	14700.00
0005434096746	20167	Economy	13400.00
0005434096745	20167	Economy	13400.00
0005434096749	20167	Economy	13400.00
0005434096747	20167	Economy	13400.00
0005432645947	25113	Business	87700.00
0005432645883	25113	Business	87700.00
0005432645837	25113	Business	87700.00
0005435229449	25113	Business	87700.00
0005432645935	25113	Business	87700.00
0005432645834	25113	Business	87700.00
0005432645895	25113	Economy	29200.00
0005432645890	25113	Economy	29200.00
0005435229444	25113	Economy	29200.00
0005432645851	25113	Economy	29200.00
0005432645833	25113	Economy	29200.00
0005432645904	25113	Economy	29200.00
0005432645900	25113	Economy	32200.00
0005435229435	25113	Economy	32200.00
0005432645953	25113	Economy	32200.00
0005432645880	25113	Economy	32200.00
0005432645862	25113	Economy	29200.00
0005432645921	25113	Economy	29200.00
0005435229441	25113	Economy	29200.00
0005432645836	25113	Economy	29200.00
0005432645909	25113	Economy	29200.00
0005432645910	25113	Economy	29200.00
0005432645879	25113	Economy	29200.00
0005432645882	25113	Economy	29200.00
0005432645933	25113	Economy	29200.00
0005432645835	25113	Economy	29200.00
0005432645932	25113	Economy	29200.00
0005432645884	25113	Economy	29200.00
0005435229437	25113	Economy	29200.00
0005435229442	25113	Economy	29200.00
0005432645958	25113	Economy	29200.00
0005432645871	25113	Economy	29200.00
0005432645870	25113	Economy	29200.00
0005435229454	25113	Economy	29200.00
0005432645875	25113	Economy	29200.00
0005435229438	25113	Economy	29200.00
0005435229436	25113	Economy	29200.00
0005435229451	25113	Economy	29200.00
0005435229447	25113	Economy	29200.00
0005432645915	25113	Economy	29200.00
0005435229448	25113	Economy	29200.00
0005435229453	25113	Economy	29200.00
0005432645896	25113	Economy	29200.00
0005432645885	25113	Economy	29200.00
0005432645878	25113	Economy	29200.00
0005435229456	25113	Economy	29200.00
0005435229455	25113	Economy	29200.00
0005435229443	25113	Economy	29200.00
0005435229440	25113	Economy	29200.00
0005432645824	25113	Economy	29200.00
0005432645943	25113	Economy	29200.00
0005432645931	25113	Economy	29200.00
0005435229439	25113	Economy	29200.00
0005435229452	25113	Economy	29200.00
0005435229445	25113	Economy	29200.00
0005435229450	25113	Economy	29200.00
0005432645872	25113	Economy	29200.00
0005435229446	25113	Economy	29200.00
0005432645905	25113	Economy	29200.00
0005432645823	25113	Economy	29200.00
0005432645826	25113	Economy	29200.00
0005435797518	2881	Business	12600.00
0005435797516	2881	Economy	4200.00
0005435797512	2881	Economy	4200.00
0005435797513	2881	Economy	4200.00
0005435797523	2881	Economy	4600.00
0005435797520	2881	Economy	4200.00
0005435797519	2881	Economy	4200.00
0005435797522	2881	Economy	4200.00
0005433404784	2881	Economy	4200.00
0005435797525	2881	Economy	4200.00
0005435797515	2881	Economy	4200.00
0005435797514	2881	Economy	4200.00
0005435797521	2881	Economy	4200.00
0005433404804	2881	Economy	4200.00
0005435797524	2881	Economy	4200.00
0005433404803	2881	Economy	4200.00
0005433404739	2881	Economy	4200.00
0005435797517	2881	Economy	4200.00
0005435797368	29306	Business	12600.00
0005435797363	29306	Business	12600.00
0005435797474	29306	Economy	4200.00
0005435797429	29306	Economy	4200.00
0005435797434	29306	Economy	4200.00
0005435797393	29306	Economy	4600.00
0005433404834	29306	Economy	4600.00
0005433404833	29306	Economy	4200.00
0005435797407	29306	Economy	4200.00
0005435797408	29306	Economy	4200.00
0005435797392	29306	Economy	4200.00
0005433404836	29306	Economy	4200.00
0005435797383	29306	Economy	4200.00
0005435797417	29306	Economy	4200.00
0005433404837	29306	Economy	4200.00
0005433404830	29306	Economy	4200.00
0005433404831	29306	Economy	4200.00
0005435797404	29306	Economy	4200.00
0005433404835	29306	Economy	4200.00
0005435797435	29306	Economy	4200.00
0005435797433	29306	Economy	4200.00
0005435797367	29306	Economy	4200.00
0005433404832	29306	Economy	4200.00
0005435376343	5756	Economy	6800.00
0005435376354	5756	Economy	6800.00
0005435376342	5756	Economy	6800.00
0005435376345	5756	Economy	6800.00
0005435376353	5756	Economy	6800.00
0005435376344	5756	Economy	6800.00
0005435376341	5756	Economy	6800.00
0005434948044	5794	Economy	6800.00
0005434948043	5794	Economy	6800.00
0005434948045	5794	Economy	6800.00
0005434947978	16346	Economy	6800.00
0005434948003	16346	Economy	6800.00
0005434947988	16346	Economy	6800.00
0005434947970	16346	Economy	6800.00
0005434947979	16346	Economy	6800.00
0005434947966	16346	Economy	6800.00
0005434947989	16346	Economy	6800.00
0005434947961	16346	Economy	6800.00
0005434947954	16346	Economy	6800.00
0005434948012	16346	Economy	6800.00
0005434947965	16346	Economy	6800.00
0005433961086	6955	Business	21400.00
0005433961055	6955	Business	21400.00
0005433961084	6955	Business	21400.00
0005433961079	6955	Business	21400.00
0005433961067	6955	Business	21400.00
0005433961044	6955	Business	21400.00
0005433961099	6955	Business	21400.00
0005433961054	6955	Business	21400.00
0005433961057	6955	Business	21400.00
0005433961088	6955	Economy	7100.00
0005433961068	6955	Economy	7100.00
0005433961058	6955	Economy	7100.00
0005433961075	6955	Economy	7100.00
0005433961108	6955	Economy	7100.00
0005433961102	6955	Economy	7100.00
0005433961083	6955	Economy	7100.00
0005433961073	6955	Economy	7100.00
0005433961071	6955	Economy	7800.00
0005433961077	6955	Economy	7800.00
0005433961094	6955	Economy	7800.00
0005433961070	6955	Economy	7100.00
0005433961097	6955	Economy	7100.00
0005433961106	6955	Economy	7100.00
0005433961103	6955	Economy	7100.00
0005433961063	6955	Economy	7100.00
0005433961076	6955	Economy	7100.00
0005433961038	6955	Economy	7100.00
0005433961095	6955	Economy	7100.00
0005433961062	6955	Economy	7100.00
0005433961053	6955	Economy	7100.00
0005433961082	6955	Economy	7100.00
0005433961089	6955	Economy	7100.00
0005433961050	6955	Economy	7100.00
0005433961069	6955	Economy	7100.00
0005433961074	6955	Economy	7100.00
0005433961101	6955	Economy	7100.00
0005433961093	6955	Economy	7100.00
0005433961087	6955	Economy	7100.00
0005433961056	6955	Economy	7100.00
0005433961047	6955	Economy	7100.00
0005433961048	6955	Economy	7100.00
0005433961052	6955	Economy	7100.00
0005433961080	6955	Economy	7100.00
0005433961066	6955	Economy	7100.00
0005433961035	6955	Economy	7100.00
0005433961034	6955	Economy	7100.00
0005433961098	6955	Economy	7100.00
0005433961049	6955	Economy	7100.00
0005433961046	6955	Economy	7100.00
0005433961064	6955	Economy	7100.00
0005433961045	6955	Economy	7100.00
0005433961107	6955	Economy	7100.00
0005433961091	6955	Economy	7100.00
0005433961065	6955	Economy	7100.00
0005433961105	6955	Economy	7100.00
0005433961040	6955	Economy	7100.00
0005433961041	6955	Economy	7100.00
0005433961051	6955	Economy	7100.00
0005433961039	6955	Economy	7100.00
0005433961043	6955	Economy	7100.00
0005433961061	6955	Economy	7100.00
0005433961085	6955	Economy	7100.00
0005433961090	6955	Economy	7100.00
0005433961072	6955	Economy	7100.00
0005433961037	6955	Economy	7100.00
0005433961059	6955	Economy	7100.00
0005433961104	6955	Economy	7100.00
0005433961081	6955	Economy	7100.00
0005433961100	6955	Economy	7100.00
0005433961060	6955	Economy	7100.00
0005433961092	6955	Economy	7100.00
0005433961096	6955	Economy	7100.00
0005433961042	6955	Economy	7100.00
0005433961078	6955	Economy	7100.00
0005433961036	6955	Economy	7100.00
0005433961109	6955	Economy	7100.00
0005433960220	25728	Business	21400.00
0005433960522	25728	Business	21400.00
0005433960295	25728	Business	21400.00
0005433960361	25728	Business	21400.00
0005433960286	25728	Economy	7100.00
0005433960462	25728	Economy	7100.00
0005433959987	25728	Economy	7100.00
0005433960219	25728	Economy	7100.00
0005433960104	25728	Economy	7100.00
0005433960310	25728	Economy	7800.00
0005433960459	25728	Economy	7800.00
0005433960356	25728	Economy	7100.00
0005433960456	25728	Economy	7100.00
0005433960210	25728	Economy	7100.00
0005433960460	25728	Economy	7100.00
0005433960151	25728	Economy	7100.00
0005433960436	25728	Economy	7100.00
0005433960466	25728	Economy	7100.00
0005433960163	25728	Economy	7100.00
0005433960208	25728	Economy	7100.00
0005433960362	25728	Economy	7100.00
0005433959986	25728	Economy	7100.00
0005433960311	25728	Economy	7100.00
0005433960425	25728	Economy	7100.00
0005433960360	25728	Economy	7100.00
0005433960372	25728	Economy	7100.00
0005433960294	25728	Economy	7100.00
0005433960185	25728	Economy	7100.00
0005433960440	25728	Economy	7100.00
0005433960457	25728	Economy	7100.00
0005433960511	25728	Economy	7100.00
0005433960313	25728	Economy	7100.00
0005433960260	25728	Economy	7100.00
0005433960312	25728	Economy	7100.00
0005433960387	25728	Economy	7100.00
0005433960437	25728	Economy	7100.00
0005433960371	25728	Economy	7100.00
0005433960259	25728	Economy	7100.00
0005433960405	25728	Economy	7100.00
0005433960438	25728	Economy	7100.00
0005433960381	25728	Economy	7100.00
0005433960483	25728	Economy	7100.00
0005433960458	25728	Economy	7100.00
0005433960454	25728	Economy	7100.00
0005433960451	25728	Economy	7100.00
0005433960455	25728	Economy	7100.00
0005433960523	25728	Economy	7100.00
0005433960209	25728	Economy	7100.00
0005433960152	25728	Economy	7100.00
0005433960510	25728	Economy	7100.00
0005433960150	25728	Economy	7100.00
0005433960365	25728	Economy	7100.00
0005435082757	24448	Economy	3900.00
0005435082730	24448	Economy	3900.00
0005435082735	24448	Economy	3900.00
0005435082758	24448	Economy	3900.00
0005435082756	24448	Economy	3900.00
0005435082734	24448	Economy	3900.00
0005435082731	24448	Economy	3900.00
0005435082802	26051	Economy	3900.00
0005435082797	26051	Economy	3900.00
0005435082803	26051	Economy	3900.00
0005435082796	26051	Economy	3900.00
0005435082795	26051	Economy	3900.00
0005435082801	26051	Economy	3900.00
0005435082798	26051	Economy	3900.00
0005435082800	26051	Economy	3900.00
0005435082799	26051	Economy	3900.00
0005434245076	5049	Business	18000.00
0005434245073	5049	Business	18000.00
0005434245061	5049	Business	18000.00
0005435286585	5049	Business	18000.00
0005434245069	5049	Business	18000.00
0005435286593	5049	Business	18000.00
0005434245060	5049	Business	18000.00
0005434245057	5049	Economy	6600.00
0005434245065	5049	Economy	6000.00
0005434245063	5049	Economy	6000.00
0005434245068	5049	Economy	6000.00
0005433534494	5049	Economy	6000.00
0005434245072	5049	Economy	6000.00
0005434245070	5049	Economy	6000.00
0005434245074	5049	Economy	6000.00
0005434245062	5049	Economy	6000.00
0005434245084	5049	Economy	6000.00
0005434245059	5049	Economy	6000.00
0005435286594	5049	Economy	6000.00
0005434245067	5049	Economy	6000.00
0005434245085	5049	Economy	6000.00
0005434245079	5049	Economy	6600.00
0005435286604	5049	Economy	6000.00
0005433534493	5049	Economy	6000.00
0005432166911	5049	Economy	6000.00
0005434245082	5049	Economy	6600.00
0005434245071	5049	Economy	6000.00
0005434245077	5049	Economy	6000.00
0005434245083	5049	Economy	6000.00
0005434245066	5049	Economy	6000.00
0005433534481	5049	Economy	6000.00
0005432166912	5049	Economy	6000.00
0005434245081	5049	Economy	6000.00
0005434245064	5049	Economy	6000.00
0005434245075	5049	Economy	6000.00
0005434245078	5049	Economy	6000.00
0005434245058	5049	Economy	6000.00
0005434245080	5049	Economy	6000.00
0005433614917	5048	Business	18000.00
0005433785055	5048	Business	18000.00
0005433614900	5048	Business	18000.00
0005432105701	5048	Business	18000.00
0005433614892	5048	Business	18000.00
0005432105732	5048	Business	18000.00
0005432105709	5048	Business	18000.00
0005433614887	5048	Business	18000.00
0005433614926	5048	Business	18000.00
0005433614949	5048	Business	18000.00
0005432105690	5048	Business	18000.00
0005432105695	5048	Business	18000.00
0005433785051	5048	Business	18000.00
0005433614948	5048	Business	18000.00
0005433614934	5048	Business	18000.00
0005433785068	5048	Business	18000.00
0005433614933	5048	Business	18000.00
0005433614952	5048	Business	18000.00
0005432105693	5048	Business	18000.00
0005432105723	5048	Business	18000.00
0005432105716	5048	Business	18000.00
0005432105691	5048	Business	18000.00
0005433614956	5048	Business	18000.00
0005432667459	5048	Business	18000.00
0005433785070	5048	Business	18000.00
0005432105707	5048	Business	18000.00
0005433785040	5048	Business	18000.00
0005433614908	5048	Business	18000.00
0005433785072	5048	Economy	6600.00
0005433614937	5048	Economy	6600.00
0005433614905	5048	Economy	6600.00
0005432105720	5048	Economy	6600.00
0005433614890	5048	Economy	6600.00
0005433614935	5048	Economy	6000.00
0005432105726	5048	Economy	6600.00
0005433785047	5048	Economy	6000.00
0005433614902	5048	Economy	6000.00
0005433785065	5048	Economy	6000.00
0005433785039	5048	Economy	6000.00
0005433614888	5048	Economy	6000.00
0005433785056	5048	Economy	6000.00
0005433614955	5048	Economy	6000.00
0005433614938	5048	Economy	6000.00
0005433785057	5048	Economy	6000.00
0005433785058	5048	Economy	6000.00
0005432105708	5048	Economy	6000.00
0005433785042	5048	Economy	6000.00
0005433614944	5048	Economy	6000.00
0005433614911	5048	Economy	6000.00
0005433785044	5048	Economy	6000.00
0005433614945	5048	Economy	6000.00
0005433614906	5048	Economy	6000.00
0005433785059	5048	Economy	6000.00
0005433614931	5048	Economy	6000.00
0005432105727	5048	Economy	6000.00
0005433785069	5048	Economy	6000.00
0005433785066	5048	Economy	6000.00
0005433614920	5048	Economy	6000.00
0005433614939	5048	Economy	6000.00
0005433785061	5048	Economy	6000.00
0005432105731	5048	Economy	6000.00
0005433614943	5048	Economy	6000.00
0005433614912	5048	Economy	6000.00
0005433614924	5048	Economy	6000.00
0005432105722	5048	Economy	6000.00
0005433614910	5048	Economy	6000.00
0005433614932	5048	Economy	6000.00
0005432105699	5048	Economy	6000.00
0005433614889	5048	Economy	6000.00
0005432105697	5048	Economy	6000.00
0005432105728	5048	Economy	6000.00
0005433785041	5048	Economy	6000.00
0005433614895	5048	Economy	6000.00
0005432105736	5048	Economy	6000.00
0005433614915	5048	Economy	6000.00
0005433785048	5048	Economy	6000.00
0005433785075	5048	Economy	6000.00
0005433785054	5048	Economy	6000.00
0005432665280	5048	Economy	6000.00
0005433785064	5048	Economy	6000.00
0005433614947	5048	Economy	6000.00
0005432666394	5048	Economy	6000.00
0005433614883	5048	Economy	6000.00
0005433614914	5048	Economy	6000.00
0005432105735	5048	Economy	6000.00
0005433614898	5048	Economy	6000.00
0005432105729	5048	Economy	6000.00
0005433614950	5048	Economy	6000.00
0005433614921	5048	Economy	6000.00
0005432105730	5048	Economy	6000.00
0005433614946	5048	Economy	6000.00
0005432105719	5048	Economy	6000.00
0005433614899	5048	Economy	6000.00
0005433614916	5048	Economy	6600.00
0005432667460	5048	Economy	6000.00
0005432105712	5048	Economy	6600.00
0005432105717	5048	Economy	6600.00
0005432105733	5048	Economy	6600.00
0005433614929	5048	Economy	6600.00
0005433614886	5048	Economy	6000.00
0005433614904	5048	Economy	6000.00
0005433614941	5048	Economy	6000.00
0005432105694	5048	Economy	6000.00
0005433614907	5048	Economy	6600.00
0005433785045	5048	Economy	6000.00
0005433614925	5048	Economy	6000.00
0005432105711	5048	Economy	6000.00
0005433785038	5048	Economy	6000.00
0005432105721	5048	Economy	6000.00
0005432105724	5048	Economy	6000.00
0005432666395	5048	Economy	6000.00
0005432105734	5048	Economy	6000.00
0005432105704	5048	Economy	6000.00
0005433785073	5048	Economy	6000.00
0005433614928	5048	Economy	6000.00
0005433785049	5048	Economy	6000.00
0005432105710	5048	Economy	6000.00
0005433614957	5048	Economy	6000.00
0005433614919	5048	Economy	6000.00
0005433614954	5048	Economy	6000.00
0005432105692	5048	Economy	6000.00
0005433614918	5048	Economy	6000.00
0005433785053	5048	Economy	6000.00
0005433614894	5048	Economy	6000.00
0005433785043	5048	Economy	6000.00
0005432105725	5048	Economy	6000.00
0005432665281	5048	Economy	6000.00
0005433614951	5048	Economy	6000.00
0005432105705	5048	Economy	6000.00
0005433785050	5048	Economy	6000.00
0005432105713	5048	Economy	6000.00
0005433614953	5048	Economy	6000.00
0005432105718	5048	Economy	6000.00
0005433614927	5048	Economy	6000.00
0005433785071	5048	Economy	6000.00
0005433614901	5048	Economy	6000.00
0005433614909	5048	Economy	6000.00
0005432667461	5048	Economy	6000.00
0005433785062	5048	Economy	6000.00
0005432105706	5048	Economy	6000.00
0005433614897	5048	Economy	6000.00
0005433785060	5048	Economy	6000.00
0005433614913	5048	Economy	6000.00
0005433614930	5048	Economy	6000.00
0005433614891	5048	Economy	6000.00
0005433614896	5048	Economy	6000.00
0005433614903	5048	Economy	6000.00
0005433614922	5048	Economy	6000.00
0005432105698	5048	Economy	6000.00
0005433785067	5048	Economy	6000.00
0005432105738	5048	Economy	6000.00
0005433614942	5048	Economy	6000.00
0005433614884	5048	Economy	6000.00
0005433614923	5048	Economy	6000.00
0005433614936	5048	Economy	6000.00
0005432105702	5048	Economy	6000.00
0005432105714	5048	Economy	6000.00
0005433614940	5048	Economy	6000.00
0005433785046	5048	Economy	6000.00
0005433785074	5048	Economy	6000.00
0005432105715	5048	Economy	6000.00
0005432105703	5048	Economy	6000.00
0005432105700	5048	Economy	6000.00
0005432105696	5048	Economy	6000.00
0005433785063	5048	Economy	6000.00
0005432105737	5048	Economy	6000.00
0005433785052	5048	Economy	6000.00
0005433614893	5048	Economy	6000.00
0005433614885	5048	Economy	6000.00
0005432145118	5048	Economy	6000.00
0005434149761	5046	Business	18000.00
0005435269721	5046	Business	18000.00
0005434229447	5046	Business	18000.00
0005434312304	5046	Business	18000.00
0005434173531	5046	Business	18000.00
0005434229430	5046	Business	18000.00
0005434265214	5046	Business	18000.00
0005434265215	5046	Business	18000.00
0005434265225	5046	Business	18000.00
0005435269716	5046	Business	18000.00
0005434265210	5046	Business	18000.00
0005433815348	5046	Business	18000.00
0005434265227	5046	Business	18000.00
0005434149765	5046	Business	18000.00
0005434229434	5046	Business	18000.00
0005432335949	5046	Business	18000.00
0005435006894	5046	Business	18000.00
0005434229449	5046	Business	18000.00
0005434149766	5046	Business	18000.00
0005435269732	5046	Economy	6600.00
0005435269705	5046	Economy	6600.00
0005434229443	5046	Economy	6600.00
0005434265213	5046	Economy	6600.00
0005433685501	5046	Economy	6600.00
0005432336015	5046	Economy	6000.00
0005434229442	5046	Economy	6000.00
0005435269744	5046	Economy	6000.00
0005434265207	5046	Economy	6000.00
0005435269702	5046	Economy	6000.00
0005434265219	5046	Economy	6000.00
0005432335952	5046	Economy	6000.00
0005435006893	5046	Economy	6000.00
0005434265228	5046	Economy	6000.00
0005435006858	5046	Economy	6000.00
0005435269677	5046	Economy	6000.00
0005434265208	5046	Economy	6000.00
0005434265218	5046	Economy	6000.00
0005434229445	5046	Economy	6000.00
0005435006821	5046	Economy	6000.00
0005435269696	5046	Economy	6000.00
0005434173532	5046	Economy	6000.00
0005434229432	5046	Economy	6000.00
0005434311206	5046	Economy	6000.00
0005435269720	5046	Economy	6000.00
0005434149773	5046	Economy	6000.00
0005435269697	5046	Economy	6000.00
0005434265209	5046	Economy	6000.00
0005432335953	5046	Economy	6000.00
0005434265222	5046	Economy	6000.00
0005435269715	5046	Economy	6000.00
0005434265212	5046	Economy	6000.00
0005434229439	5046	Economy	6000.00
0005434265226	5046	Economy	6000.00
0005434265216	5046	Economy	6000.00
0005435006906	5046	Economy	6000.00
0005432335927	5046	Economy	6000.00
0005434229435	5046	Economy	6000.00
0005435006774	5046	Economy	6000.00
0005434265206	5046	Economy	6000.00
0005434149764	5046	Economy	6000.00
0005433815375	5046	Economy	6000.00
0005435269704	5046	Economy	6000.00
0005435269714	5046	Economy	6000.00
0005432335985	5046	Economy	6000.00
0005433815360	5046	Economy	6000.00
0005434149762	5046	Economy	6000.00
0005434229431	5046	Economy	6000.00
0005434149763	5046	Economy	6000.00
0005435006950	5046	Economy	6000.00
0005434229444	5046	Economy	6000.00
0005435269741	5046	Economy	6000.00
0005434229450	5046	Economy	6000.00
0005434229440	5046	Economy	6000.00
0005434265229	5046	Economy	6600.00
0005434229448	5046	Economy	6600.00
0005434265223	5046	Economy	6000.00
0005435269745	5046	Economy	6600.00
0005434229433	5046	Economy	6000.00
0005434229438	5046	Economy	6000.00
0005432335958	5046	Economy	6600.00
0005433815343	5046	Economy	6000.00
0005435006859	5046	Economy	6000.00
0005434149767	5046	Economy	6000.00
0005435006861	5046	Economy	6000.00
0005434265224	5046	Economy	6000.00
0005435269726	5046	Economy	6000.00
0005435006951	5046	Economy	6000.00
0005435269717	5046	Economy	6000.00
0005435006935	5046	Economy	6000.00
0005435269682	5046	Economy	6000.00
0005435006955	5046	Economy	6000.00
0005433815359	5046	Economy	6000.00
0005435006845	5046	Economy	6000.00
0005435269727	5046	Economy	6000.00
0005433685502	5046	Economy	6000.00
0005434173533	5046	Economy	6000.00
0005432335959	5046	Economy	6000.00
0005435269680	5046	Economy	6000.00
0005435006844	5046	Economy	6000.00
0005434229441	5046	Economy	6000.00
0005432335928	5046	Economy	6000.00
0005435006907	5046	Economy	6000.00
0005434311207	5046	Economy	6000.00
0005434312303	5046	Economy	6000.00
0005434311208	5046	Economy	6000.00
0005434265211	5046	Economy	6000.00
0005435007018	5046	Economy	6000.00
0005434149768	5046	Economy	6000.00
0005434229436	5046	Economy	6000.00
0005435269731	5046	Economy	6000.00
0005435269742	5046	Economy	6000.00
0005434149771	5046	Economy	6000.00
0005434149769	5046	Economy	6000.00
0005435006916	5046	Economy	6000.00
0005434265204	5046	Economy	6000.00
0005434229437	5046	Economy	6000.00
0005433815342	5046	Economy	6000.00
0005434265205	5046	Economy	6000.00
0005434149772	5046	Economy	6000.00
0005434265221	5046	Economy	6000.00
0005435006963	5046	Economy	6000.00
0005434149770	5046	Economy	6000.00
0005432335961	5046	Economy	6000.00
0005434265217	5046	Economy	6000.00
0005435006860	5046	Economy	6000.00
0005434265220	5046	Economy	6000.00
0005435269683	5046	Economy	6000.00
0005435006875	5046	Economy	6000.00
0005435269681	5046	Economy	6000.00
0005432335948	5046	Economy	6000.00
0005434229446	5046	Economy	6000.00
0005433784713	8520	Business	18000.00
0005434244808	8520	Business	18000.00
0005434244844	8520	Business	18000.00
0005433784614	8520	Business	18000.00
0005434244702	8520	Business	18000.00
0005433784766	8520	Business	18000.00
0005433784624	8520	Business	18000.00
0005432663026	8520	Business	18000.00
0005434244995	8520	Business	18000.00
0005434244762	8520	Business	18000.00
0005434244792	8520	Business	18000.00
0005434244758	8520	Economy	6600.00
0005434244922	8520	Business	18000.00
0005433784820	8520	Economy	6600.00
0005435269764	8520	Economy	6600.00
0005433784822	8520	Economy	6600.00
0005434244939	8520	Economy	6000.00
0005433784884	8520	Economy	6000.00
0005433784738	8520	Economy	6000.00
0005433784619	8520	Economy	6000.00
0005432663025	8520	Economy	6000.00
0005433784645	8520	Economy	6000.00
0005434244751	8520	Economy	6000.00
0005434244903	8520	Economy	6000.00
0005434244851	8520	Economy	6000.00
0005433784790	8520	Economy	6000.00
0005434244815	8520	Economy	6000.00
0005434244904	8520	Economy	6000.00
0005434244814	8520	Economy	6000.00
0005434244867	8520	Economy	6000.00
0005434244872	8520	Economy	6000.00
0005435269759	8520	Economy	6000.00
0005434244791	8520	Economy	6000.00
0005433784792	8520	Economy	6000.00
0005433784750	8520	Economy	6000.00
0005434244805	8520	Economy	6000.00
0005434244906	8520	Economy	6000.00
0005433784819	8520	Economy	6000.00
0005434244757	8520	Economy	6000.00
0005434244804	8520	Economy	6000.00
0005434244871	8520	Economy	6000.00
0005434244905	8520	Economy	6000.00
0005433784777	8520	Economy	6000.00
0005434244876	8520	Economy	6000.00
0005434244968	8520	Economy	6000.00
0005434244897	8520	Economy	6000.00
0005433784915	8520	Economy	6000.00
0005433784793	8520	Economy	6000.00
0005433784616	8520	Economy	6000.00
0005433784665	8520	Economy	6000.00
0005435269761	8520	Economy	6000.00
0005434244902	8520	Economy	6000.00
0005435269760	8520	Economy	6600.00
0005432663018	8520	Economy	6600.00
0005435269762	8520	Economy	6600.00
0005435269763	8520	Economy	6000.00
0005433784644	8520	Economy	6600.00
0005434244638	8520	Economy	6000.00
0005433784737	8520	Economy	6000.00
0005433784885	8520	Economy	6000.00
0005435269766	8520	Economy	6000.00
0005433784757	8520	Economy	6000.00
0005434244701	8520	Economy	6000.00
0005435269765	8520	Economy	6000.00
0005432666362	8520	Economy	6000.00
0005433784817	8520	Economy	6000.00
0005433784719	8520	Economy	6000.00
0005433784708	8520	Economy	6000.00
0005433784788	8520	Economy	6000.00
0005434244810	8520	Economy	6000.00
0005433784789	8520	Economy	6000.00
0005433784765	8520	Economy	6000.00
0005434244845	8520	Economy	6000.00
0005434244969	8520	Economy	6000.00
0005432663012	8520	Economy	6000.00
0005434244809	8520	Economy	6000.00
0005433784745	8520	Economy	6000.00
0005434244819	8520	Economy	6000.00
0005432666361	8520	Economy	6000.00
0005432666372	8520	Economy	6000.00
0005433784818	8520	Economy	6000.00
0005433784718	8520	Economy	6000.00
0005434244938	8520	Economy	6000.00
0005434244820	8520	Economy	6000.00
0005433784794	8520	Economy	6000.00
0005434244866	8520	Economy	6000.00
0005433784615	8520	Economy	6000.00
0005434244966	8520	Economy	6000.00
0005433784703	8520	Economy	6000.00
0005434244896	8520	Economy	6000.00
0005433784666	8520	Economy	6000.00
0005433614194	8521	Business	18000.00
0005433614283	8521	Business	18000.00
0005433614218	8521	Business	18000.00
0005433614050	8521	Business	18000.00
0005433614470	8521	Business	18000.00
0005433614320	8521	Business	18000.00
0005433614200	8521	Business	18000.00
0005433614511	8521	Business	18000.00
0005433614122	8521	Business	18000.00
0005433613949	8521	Business	18000.00
0005433613775	8521	Business	18000.00
0005433613993	8521	Business	18000.00
0005433614222	8521	Business	18000.00
0005433614235	8521	Business	18000.00
0005433614040	8521	Business	18000.00
0005433614239	8521	Economy	6600.00
0005433614149	8521	Economy	6600.00
0005433614439	8521	Economy	6600.00
0005433614322	8521	Economy	6000.00
0005433614008	8521	Economy	6000.00
0005433614196	8521	Economy	6000.00
0005433614088	8521	Economy	6000.00
0005433614120	8521	Economy	6000.00
0005433614321	8521	Economy	6000.00
0005433614039	8521	Economy	6000.00
0005433614195	8521	Economy	6000.00
0005433614150	8521	Economy	6000.00
0005433614215	8521	Economy	6000.00
0005433614240	8521	Economy	6000.00
0005433614341	8521	Economy	6000.00
0005433614165	8521	Economy	6000.00
0005433614074	8521	Economy	6000.00
0005433614265	8521	Economy	6000.00
0005433614302	8521	Economy	6000.00
0005433614284	8521	Economy	6000.00
0005433614051	8521	Economy	6000.00
0005433614119	8521	Economy	6000.00
0005433614310	8521	Economy	6000.00
0005433614521	8521	Economy	6000.00
0005433613983	8521	Economy	6000.00
0005433614189	8521	Economy	6000.00
0005433614219	8521	Economy	6000.00
0005433614417	8521	Economy	6000.00
0005433613843	8521	Economy	6600.00
0005433614282	8521	Economy	6000.00
0005433614469	8521	Economy	6600.00
0005433614268	8521	Economy	6000.00
0005433614531	8521	Economy	6000.00
0005433613948	8521	Economy	6000.00
0005433614171	8521	Economy	6000.00
0005433614227	8521	Economy	6000.00
0005433614155	8521	Economy	6000.00
0005433614407	8521	Economy	6000.00
0005433614276	8521	Economy	6000.00
0005433613750	8521	Economy	6000.00
0005433614340	8521	Economy	6000.00
0005433614089	8521	Economy	6000.00
0005433613982	8521	Economy	6000.00
0005433614049	8521	Economy	6000.00
0005433613992	8521	Economy	6000.00
0005433614546	8521	Economy	6000.00
0005433614530	8521	Economy	6000.00
0005433614092	8521	Economy	6000.00
0005433614662	8521	Economy	6000.00
0005433614147	8521	Economy	6000.00
0005433614359	8521	Economy	6000.00
0005433614103	8521	Economy	6000.00
0005433614245	8521	Economy	6000.00
0005433614395	8521	Economy	6000.00
0005433614254	8521	Economy	6000.00
0005433614193	8521	Economy	6000.00
0005433614209	8521	Economy	6000.00
0005433613923	8521	Economy	6000.00
0005433614418	8521	Economy	6000.00
0005433614249	8521	Economy	6000.00
0005433614204	8521	Economy	6000.00
0005433614163	8521	Economy	6000.00
0005433614520	8521	Economy	6000.00
0005433614266	8521	Economy	6000.00
0005433614121	8521	Economy	6000.00
0005433614522	8521	Economy	6000.00
0005434229200	8522	Business	18000.00
0005433689918	8522	Business	18000.00
0005435286645	8522	Business	18000.00
0005435286643	8522	Business	18000.00
0005432035034	8522	Business	18000.00
0005435007094	8522	Business	18000.00
0005435007090	8522	Business	18000.00
0005433690932	8522	Business	18000.00
0005434229285	8522	Business	18000.00
0005435286646	8522	Business	18000.00
0005432035037	8522	Business	18000.00
0005434229171	8522	Business	18000.00
0005435286649	8522	Business	18000.00
0005435007104	8522	Business	18000.00
0005434229231	8522	Business	18000.00
0005434264982	8522	Business	18000.00
0005434229330	8522	Business	18000.00
0005434229199	8522	Business	18000.00
0005432336075	8522	Business	18000.00
0005432035041	8522	Business	18000.00
0005433688816	8522	Business	18000.00
0005434265056	8522	Business	18000.00
0005434229243	8522	Business	18000.00
0005434229236	8522	Business	18000.00
0005435286641	8522	Economy	6600.00
0005432035046	8522	Economy	6600.00
0005434229183	8522	Economy	6600.00
0005432035045	8522	Economy	6600.00
0005434149696	8522	Economy	6600.00
0005432035033	8522	Economy	6600.00
0005434311226	8522	Economy	6000.00
0005434311227	8522	Economy	6000.00
0005435007092	8522	Economy	6000.00
0005433815401	8522	Economy	6000.00
0005432035029	8522	Economy	6000.00
0005434229302	8522	Economy	6000.00
0005434149611	8522	Economy	6000.00
0005432336070	8522	Economy	6000.00
0005432035030	8522	Economy	6000.00
0005434311228	8522	Economy	6000.00
0005435007088	8522	Economy	6000.00
0005434264980	8522	Economy	6000.00
0005432035019	8522	Economy	6000.00
0005435007107	8522	Economy	6000.00
0005432336076	8522	Economy	6000.00
0005435007093	8522	Economy	6000.00
0005435007103	8522	Economy	6000.00
0005432035043	8522	Economy	6000.00
0005434229261	8522	Economy	6000.00
0005435007097	8522	Economy	6000.00
0005435007109	8522	Economy	6000.00
0005435286642	8522	Economy	6000.00
0005432336073	8522	Economy	6000.00
0005434229142	8522	Economy	6000.00
0005435286636	8522	Economy	6000.00
0005434229233	8522	Economy	6000.00
0005433534505	8522	Economy	6000.00
0005433815403	8522	Economy	6000.00
0005434173506	8522	Economy	6000.00
0005432035039	8522	Economy	6000.00
0005432035032	8522	Economy	6000.00
0005435286651	8522	Economy	6000.00
0005435007106	8522	Economy	6000.00
0005435286648	8522	Economy	6000.00
0005432047563	8522	Economy	6000.00
0005435007099	8522	Economy	6000.00
0005435007101	8522	Economy	6000.00
0005432035035	8522	Economy	6000.00
0005435007098	8522	Economy	6000.00
0005434264995	8522	Economy	6000.00
0005434149682	8522	Economy	6000.00
0005434265022	8522	Economy	6000.00
0005434264958	8522	Economy	6000.00
0005434264943	8522	Economy	6000.00
0005434173525	8522	Economy	6000.00
0005432035024	8522	Economy	6000.00
0005434265049	8522	Economy	6000.00
0005433689917	8522	Economy	6000.00
0005434229248	8522	Economy	6000.00
0005434265082	8522	Economy	6000.00
0005432035028	8522	Economy	6000.00
0005435007095	8522	Economy	6000.00
0005432336068	8522	Economy	6000.00
0005432035031	8522	Economy	6000.00
0005435286644	8522	Economy	6000.00
0005434265081	8522	Economy	6000.00
0005435286650	8522	Economy	6000.00
0005434229232	8522	Economy	6600.00
0005434264956	8522	Economy	6600.00
0005434265048	8522	Economy	6600.00
0005433534504	8522	Economy	6600.00
0005435007108	8522	Economy	6000.00
0005432035022	8522	Economy	6000.00
0005434229182	8522	Economy	6000.00
0005435286637	8522	Economy	6000.00
0005432336066	8522	Economy	6000.00
0005434264884	8522	Economy	6600.00
0005434149668	8522	Economy	6000.00
0005434264919	8522	Economy	6000.00
0005435286635	8522	Economy	6000.00
0005434265057	8522	Economy	6000.00
0005435007086	8522	Economy	6000.00
0005434264944	8522	Economy	6000.00
0005434265013	8522	Economy	6000.00
0005433688815	8522	Economy	6000.00
0005435007089	8522	Economy	6000.00
0005432336074	8522	Economy	6000.00
0005432035027	8522	Economy	6000.00
0005434149669	8522	Economy	6000.00
0005434264983	8522	Economy	6000.00
0005434149719	8522	Economy	6000.00
0005433815402	8522	Economy	6000.00
0005432035021	8522	Economy	6000.00
0005435286647	8522	Economy	6000.00
0005434229218	8522	Economy	6000.00
0005432336072	8522	Economy	6000.00
0005434149683	8522	Economy	6000.00
0005435286638	8522	Economy	6000.00
0005432336071	8522	Economy	6000.00
0005434149711	8522	Economy	6000.00
0005433815400	8522	Economy	6000.00
0005434229135	8522	Economy	6000.00
0005434149640	8522	Economy	6000.00
0005434264971	8522	Economy	6000.00
0005432035023	8522	Economy	6000.00
0005435286639	8522	Economy	6000.00
0005432035040	8522	Economy	6000.00
0005432047562	8522	Economy	6000.00
0005432035044	8522	Economy	6000.00
0005434173489	8522	Economy	6000.00
0005435007091	8522	Economy	6000.00
0005435007085	8522	Economy	6000.00
0005434229296	8522	Economy	6000.00
0005434173507	8522	Economy	6000.00
0005434264994	8522	Economy	6000.00
0005432035025	8522	Economy	6000.00
0005432336069	8522	Economy	6000.00
0005435007102	8522	Economy	6000.00
0005434264957	8522	Economy	6000.00
0005432047561	8522	Economy	6000.00
0005432035036	8522	Economy	6000.00
0005432336077	8522	Economy	6000.00
0005434264918	8522	Economy	6000.00
0005435007105	8522	Economy	6000.00
0005432047560	8522	Economy	6000.00
0005435286640	8522	Economy	6000.00
0005434229234	8522	Economy	6000.00
0005432336067	8522	Economy	6000.00
0005435007100	8522	Economy	6000.00
0005432035042	8522	Economy	6000.00
0005432035026	8522	Economy	6000.00
0005434264979	8522	Economy	6000.00
0005435007096	8522	Economy	6000.00
0005432035020	8522	Economy	6000.00
0005435007087	8522	Economy	6000.00
0005434265050	8522	Economy	6000.00
0005432035038	8522	Economy	6000.00
0005434149712	8522	Economy	6000.00
0005433202417	12639	Economy	16200.00
0005434639224	12639	Economy	16200.00
0005433202410	12639	Economy	16200.00
0005434639148	12639	Economy	14800.00
0005434639190	12639	Economy	14800.00
0005434639221	12639	Economy	14800.00
0005433202409	12639	Economy	14800.00
0005434639188	12639	Economy	14800.00
0005434639267	12639	Economy	14800.00
0005434639196	12639	Economy	14800.00
0005433202415	12639	Economy	14800.00
0005434639234	12639	Economy	14800.00
0005433202416	12639	Economy	14800.00
0005433202413	12639	Economy	14800.00
0005434639225	12639	Economy	14800.00
0005433202407	12639	Economy	14800.00
0005434639213	12639	Economy	14800.00
0005433202405	12639	Economy	14800.00
0005434639222	12639	Economy	14800.00
0005434639228	12639	Economy	14800.00
0005434639191	12639	Economy	14800.00
0005433202403	12639	Economy	14800.00
0005434639204	12639	Economy	14800.00
0005433202414	12639	Economy	14800.00
0005434639279	12639	Economy	14800.00
0005433202408	12639	Economy	14800.00
0005434639017	12639	Economy	14800.00
0005434639189	12639	Economy	14800.00
0005434639223	12639	Economy	14800.00
0005433202411	12639	Economy	14800.00
0005434639205	12639	Economy	14800.00
0005433202404	12639	Economy	14800.00
0005434639227	12639	Economy	14800.00
0005433202412	12639	Economy	14800.00
0005434639082	12639	Economy	14800.00
0005433202418	12639	Economy	14800.00
0005434639146	12639	Economy	14800.00
0005434639226	12639	Economy	14800.00
0005434639098	12639	Economy	14800.00
0005433202406	12639	Economy	14800.00
0005434639149	12639	Economy	14800.00
0005434639235	12639	Economy	14800.00
0005434639374	23372	Economy	16200.00
0005434639385	23372	Economy	16200.00
0005433202279	23372	Economy	14800.00
0005434639383	23372	Economy	14800.00
0005434639381	23372	Economy	14800.00
0005434639378	23372	Economy	14800.00
0005433202195	23372	Economy	14800.00
0005432290640	23372	Economy	14800.00
0005434639377	23372	Economy	14800.00
0005434639392	23372	Economy	14800.00
0005434639386	23372	Economy	14800.00
0005434639384	23372	Economy	14800.00
0005434639389	23372	Economy	14800.00
0005434639371	23372	Economy	14800.00
0005432290642	23372	Economy	14800.00
0005433202259	23372	Economy	14800.00
0005434639379	23372	Economy	14800.00
0005434639380	23372	Economy	14800.00
0005434639390	23372	Economy	14800.00
0005434639387	23372	Economy	14800.00
0005434639369	23372	Economy	14800.00
0005432290641	23372	Economy	14800.00
0005434639375	23372	Economy	14800.00
0005433202324	23372	Economy	14800.00
0005433202325	23372	Economy	14800.00
0005433202229	23372	Economy	14800.00
0005434639373	23372	Economy	14800.00
0005433202283	23372	Economy	14800.00
0005434639368	23372	Economy	14800.00
0005434639388	23372	Economy	14800.00
0005434639382	23372	Economy	14800.00
0005434639367	23372	Economy	14800.00
0005433202278	23372	Economy	14800.00
0005434639393	23372	Economy	14800.00
0005434639372	23372	Economy	14800.00
0005434639376	23372	Economy	14800.00
0005434639370	23372	Economy	14800.00
0005434639391	23372	Economy	14800.00
0005432290639	23372	Economy	14800.00
0005432848840	21091	Business	18900.00
0005432328564	21091	Business	18900.00
0005432328064	21091	Business	18900.00
0005432848838	21091	Business	18900.00
0005432328504	21091	Business	18900.00
0005432328473	21091	Business	18900.00
0005432382777	21091	Business	18900.00
0005432328328	21091	Business	18900.00
0005432328509	21091	Business	18900.00
0005432328463	21091	Business	18900.00
0005432328493	21091	Business	18900.00
0005432383075	21091	Business	18900.00
0005432383088	21091	Economy	6300.00
0005432328448	21091	Economy	6300.00
0005432328443	21091	Economy	6300.00
0005432382989	21091	Economy	6300.00
0005432382978	21091	Economy	6300.00
0005432382948	21091	Economy	6300.00
0005432382733	21091	Economy	6300.00
0005432382902	21091	Economy	6300.00
0005432382909	21091	Economy	6300.00
0005432328387	21091	Economy	6300.00
0005432382901	21091	Economy	6900.00
0005432382844	21091	Economy	6900.00
0005432382945	21091	Economy	6900.00
0005432328167	21091	Economy	6900.00
0005432328481	21091	Economy	6900.00
0005432328277	21091	Economy	6300.00
0005432328442	21091	Economy	6300.00
0005432382755	21091	Economy	6300.00
0005432328457	21091	Economy	6300.00
0005432328472	21091	Economy	6300.00
0005432382949	21091	Economy	6300.00
0005432382908	21091	Economy	6300.00
0005432328465	21091	Economy	6300.00
0005432328228	21091	Economy	6300.00
0005432328380	21091	Economy	6300.00
0005432382946	21091	Economy	6300.00
0005432328417	21091	Economy	6300.00
0005432382835	21091	Economy	6300.00
0005432328432	21091	Economy	6300.00
0005432328634	21091	Economy	6300.00
0005432328562	21091	Economy	6300.00
0005432328389	21091	Economy	6300.00
0005432382925	21091	Economy	6300.00
0005432054314	21091	Economy	6300.00
0005432382900	21091	Economy	6300.00
0005432328314	21091	Economy	6300.00
0005432328503	21091	Economy	6300.00
0005432382903	21091	Economy	6300.00
0005432328478	21091	Economy	6300.00
0005432382873	21091	Economy	6300.00
0005432382736	21091	Economy	6300.00
0005432328570	21091	Economy	6300.00
0005432328480	21091	Economy	6300.00
0005432383002	21091	Economy	6300.00
0005432328635	21091	Economy	6300.00
0005432383122	21091	Economy	6300.00
0005432328359	21091	Economy	6300.00
0005432328441	21091	Economy	6300.00
0005432383074	21091	Economy	6300.00
0005432328477	21091	Economy	6300.00
0005432328550	21091	Economy	6300.00
0005432382977	21091	Economy	6300.00
0005432328528	21091	Economy	6300.00
0005432382953	21091	Economy	6300.00
0005432382780	21091	Economy	6300.00
0005432328240	21091	Economy	6300.00
0005432382881	21091	Economy	6300.00
0005432382926	21091	Economy	6300.00
0005432328447	21091	Economy	6300.00
0005432382921	21091	Economy	6300.00
0005432383001	21091	Economy	6300.00
0005432382859	21091	Economy	6300.00
0005432382779	21091	Economy	6300.00
0005432328593	21091	Economy	6300.00
0005432328388	21091	Economy	6300.00
0005432382787	21091	Economy	6300.00
0005432328386	21091	Economy	6300.00
0005432382954	21091	Economy	6300.00
0005432382922	21091	Economy	6300.00
0005432383168	21091	Economy	6300.00
0005432382778	21091	Economy	6300.00
0005432328065	21091	Economy	6300.00
0005432382947	21091	Economy	6300.00
0005432848839	21091	Economy	6300.00
0005432382759	21091	Economy	6300.00
0005432382781	21091	Economy	6300.00
0005432328280	21091	Economy	6300.00
0005432383124	21091	Economy	6300.00
0005432328370	21091	Economy	6300.00
0005432382827	21091	Economy	6300.00
0005432383123	21091	Economy	6300.00
0005432382855	21091	Economy	6300.00
0005432383240	31258	Business	18900.00
0005432328815	31258	Business	18900.00
0005432383275	31258	Business	18900.00
0005432383243	31258	Business	18900.00
0005432328795	31258	Business	18900.00
0005432328800	31258	Business	18900.00
0005432383273	31258	Business	18900.00
0005432328792	31258	Business	18900.00
0005432328806	31258	Business	18900.00
0005432383272	31258	Business	18900.00
0005432383242	31258	Business	18900.00
0005432328810	31258	Economy	6300.00
0005432383274	31258	Economy	6300.00
0005432383257	31258	Economy	6300.00
0005432383258	31258	Economy	6300.00
0005432287203	31258	Economy	6300.00
0005432328798	31258	Economy	6300.00
0005432328824	31258	Economy	6300.00
0005432328787	31258	Economy	6300.00
0005432383277	31258	Economy	6300.00
0005432287200	31258	Economy	6900.00
0005432328785	31258	Economy	6900.00
0005432383265	31258	Economy	6900.00
0005432328801	31258	Economy	6900.00
0005432383264	31258	Economy	6300.00
0005432328827	31258	Economy	6300.00
0005432383271	31258	Economy	6300.00
0005432328819	31258	Economy	6300.00
0005432328812	31258	Economy	6300.00
0005432328823	31258	Economy	6300.00
0005432328818	31258	Economy	6300.00
0005432383276	31258	Economy	6300.00
0005432328784	31258	Economy	6300.00
0005432383267	31258	Economy	6300.00
0005432383262	31258	Economy	6300.00
0005432328794	31258	Economy	6300.00
0005432383244	31258	Economy	6300.00
0005432328817	31258	Economy	6300.00
0005432328797	31258	Economy	6300.00
0005432287202	31258	Economy	6300.00
0005432383268	31258	Economy	6300.00
0005432328820	31258	Economy	6300.00
0005432328813	31258	Economy	6300.00
0005432328803	31258	Economy	6300.00
0005432328796	31258	Economy	6300.00
0005432287201	31258	Economy	6300.00
0005432328825	31258	Economy	6300.00
0005432328793	31258	Economy	6300.00
0005432328789	31258	Economy	6300.00
0005432328799	31258	Economy	6300.00
0005432383239	31258	Economy	6300.00
0005432328791	31258	Economy	6300.00
0005432383248	31258	Economy	6300.00
0005432287199	31258	Economy	6300.00
0005432383241	31258	Economy	6300.00
0005432328811	31258	Economy	6300.00
0005432383260	31258	Economy	6300.00
0005432328816	31258	Economy	6300.00
0005432383245	31258	Economy	6300.00
0005432328804	31258	Economy	6300.00
0005432383278	31258	Economy	6300.00
0005432328830	31258	Economy	6300.00
0005432383255	31258	Economy	6300.00
0005432328786	31258	Economy	6300.00
0005432383270	31258	Economy	6300.00
0005432287204	31258	Economy	6300.00
0005432383247	31258	Economy	6300.00
0005432383253	31258	Economy	6300.00
0005432328822	31258	Economy	6300.00
0005432328790	31258	Economy	6300.00
0005432383256	31258	Economy	6300.00
0005432328828	31258	Economy	6300.00
0005432383238	31258	Economy	6300.00
0005432383269	31258	Economy	6300.00
0005432328808	31258	Economy	6300.00
0005432383252	31258	Economy	6300.00
0005432383261	31258	Economy	6300.00
0005432328805	31258	Economy	6300.00
0005432328802	31258	Economy	6300.00
0005432328829	31258	Economy	6300.00
0005432383254	31258	Economy	6300.00
0005432383251	31258	Economy	6300.00
0005432383263	31258	Economy	6300.00
0005432383250	31258	Economy	6300.00
0005432383249	31258	Economy	6300.00
0005432383266	31258	Economy	6300.00
0005432328821	31258	Economy	6300.00
0005432328807	31258	Economy	6300.00
0005432328809	31258	Economy	6300.00
0005432328826	31258	Economy	6300.00
0005432383246	31258	Economy	6300.00
0005432383259	31258	Economy	6300.00
0005432328788	31258	Economy	6300.00
0005432328814	31258	Economy	6300.00
0005432953967	27587	Business	89600.00
0005432953953	27587	Business	89600.00
0005433642222	27587	Business	89600.00
0005433642251	27587	Business	89600.00
0005432953961	27587	Economy	29900.00
0005432953954	27587	Economy	29900.00
0005432953951	27587	Economy	29900.00
0005433642252	27587	Economy	32800.00
0005432953960	27587	Economy	32800.00
0005432953955	27587	Economy	32800.00
0005433642253	27587	Economy	29900.00
0005432953957	27587	Economy	29900.00
0005433642211	27587	Economy	29900.00
0005433642230	27587	Economy	29900.00
0005432953966	27587	Economy	29900.00
0005433642212	27587	Economy	29900.00
0005432953959	27587	Economy	29900.00
0005433642279	27587	Economy	29900.00
0005433642187	27587	Economy	29900.00
0005433642166	27587	Economy	29900.00
0005432953965	27587	Economy	29900.00
0005433642264	27587	Economy	29900.00
0005433642213	27587	Economy	29900.00
0005432953963	27587	Economy	29900.00
0005432953962	27587	Economy	29900.00
0005433642302	27587	Economy	29900.00
0005432953958	27587	Economy	29900.00
0005432953968	27587	Economy	29900.00
0005433642209	27587	Economy	29900.00
0005433642332	27587	Economy	29900.00
0005432953964	27587	Economy	29900.00
0005433642236	27587	Economy	29900.00
0005433642229	27587	Economy	29900.00
0005432953952	27587	Economy	29900.00
0005433642233	27587	Economy	29900.00
0005432953956	27587	Economy	29900.00
0005433642291	27587	Economy	29900.00
0005432424546	13335	Business	12700.00
0005432424566	13335	Business	12700.00
0005432424534	13335	Business	12700.00
0005432424558	13335	Business	12700.00
0005432424562	13335	Business	12700.00
0005432424555	13335	Business	12700.00
0005432424554	13335	Business	12700.00
0005432424560	13335	Business	12700.00
0005432424551	13335	Economy	4200.00
0005432424520	13335	Economy	4200.00
0005432424523	13335	Economy	4200.00
0005432424531	13335	Economy	4200.00
0005432424568	13335	Economy	4200.00
0005432424565	13335	Economy	4200.00
0005432424556	13335	Economy	4200.00
0005432424542	13335	Economy	4700.00
0005432424549	13335	Economy	4700.00
0005432424557	13335	Economy	4700.00
0005432424527	13335	Economy	4700.00
0005432424553	13335	Economy	4200.00
0005432424547	13335	Economy	4200.00
0005432424529	13335	Economy	4200.00
0005432424541	13335	Economy	4200.00
0005432424522	13335	Economy	4200.00
0005432424559	13335	Economy	4200.00
0005432424561	13335	Economy	4200.00
0005432424524	13335	Economy	4200.00
0005432424538	13335	Economy	4200.00
0005432424532	13335	Economy	4200.00
0005432424545	13335	Economy	4200.00
0005432424544	13335	Economy	4200.00
0005432424526	13335	Economy	4200.00
0005432424548	13335	Economy	4200.00
0005432424539	13335	Economy	4200.00
0005432424533	13335	Economy	4200.00
0005432424569	13335	Economy	4200.00
0005432424530	13335	Economy	4200.00
0005432424570	13335	Economy	4200.00
0005432424521	13335	Economy	4200.00
0005432424543	13335	Economy	4200.00
0005432424537	13335	Economy	4200.00
0005432424567	13335	Economy	4200.00
0005432424528	13335	Economy	4200.00
0005432424563	13335	Economy	4200.00
0005432424525	13335	Economy	4200.00
0005432424536	13335	Economy	4200.00
0005432424552	13335	Economy	4200.00
0005432424540	13335	Economy	4200.00
0005432424535	13335	Economy	4200.00
0005432424550	13335	Economy	4200.00
0005432424564	13335	Economy	4200.00
0005432424094	30709	Business	12700.00
0005432424129	30709	Business	12700.00
0005432424095	30709	Business	12700.00
0005432424078	30709	Business	12700.00
0005432423956	30709	Business	12700.00
0005432424160	30709	Business	12700.00
0005432424169	30709	Business	12700.00
0005432424113	30709	Economy	4200.00
0005432424115	30709	Economy	4200.00
0005432424020	30709	Economy	4200.00
0005432424138	30709	Economy	4200.00
0005432423967	30709	Economy	4200.00
0005432424135	30709	Economy	4200.00
0005432424139	30709	Economy	4700.00
0005432424079	30709	Economy	4700.00
0005432424035	30709	Economy	4200.00
0005432424041	30709	Economy	4200.00
0005432424111	30709	Economy	4200.00
0005432424109	30709	Economy	4200.00
0005432424033	30709	Economy	4200.00
0005432424159	30709	Economy	4200.00
0005432424107	30709	Economy	4200.00
0005432424032	30709	Economy	4200.00
0005432424037	30709	Economy	4200.00
0005432423961	30709	Economy	4200.00
0005432424121	30709	Economy	4200.00
0005432424042	30709	Economy	4200.00
0005432424110	30709	Economy	4200.00
0005432424034	30709	Economy	4200.00
0005432424104	30709	Economy	4200.00
0005432424043	30709	Economy	4200.00
0005432424065	30709	Economy	4200.00
0005432424044	30709	Economy	4200.00
0005432424152	30709	Economy	4200.00
0005432424158	30709	Economy	4200.00
0005432424123	30709	Economy	4200.00
0005432424116	30709	Economy	4200.00
0005432424036	30709	Economy	4200.00
0005432423937	30709	Economy	4200.00
0005432424103	30709	Economy	4200.00
0005432423988	30709	Economy	4200.00
0005432424108	30709	Economy	4200.00
0005432424067	30709	Economy	4200.00
0005432424112	30709	Economy	4200.00
0005432423989	30709	Economy	4200.00
0005432822229	9591	Business	32600.00
0005432817569	9591	Business	32600.00
0005434157471	9591	Business	32600.00
0005432817571	9591	Business	32600.00
0005432817568	9591	Business	32600.00
0005432901486	9591	Business	32600.00
0005432817557	9591	Business	32600.00
0005432901487	9591	Business	32600.00
0005432288994	9591	Business	32600.00
0005434157470	9591	Economy	10900.00
0005432901505	9591	Economy	10900.00
0005432817550	9591	Economy	10900.00
0005434186169	9591	Economy	10900.00
0005432901528	9591	Economy	10900.00
0005432817549	9591	Economy	10900.00
0005432901498	9591	Economy	10900.00
0005434448326	9591	Economy	10900.00
0005432901502	9591	Economy	11900.00
0005432901506	9591	Economy	11900.00
0005434157452	9591	Economy	11900.00
0005434157457	9591	Economy	11900.00
0005432817563	9591	Economy	11900.00
0005432822223	9591	Economy	10900.00
0005432817564	9591	Economy	10900.00
0005432817551	9591	Economy	10900.00
0005432288997	9591	Economy	10900.00
0005432901584	9591	Economy	10900.00
0005432817559	9591	Economy	10900.00
0005432817558	9591	Economy	10900.00
0005432817573	9591	Economy	10900.00
0005432817554	9591	Economy	10900.00
0005434157435	9591	Economy	10900.00
0005432822224	9591	Economy	10900.00
0005432817565	9591	Economy	10900.00
0005434157448	9591	Economy	10900.00
0005432817572	9591	Economy	10900.00
0005432822230	9591	Economy	10900.00
0005432901526	9591	Economy	10900.00
0005432288995	9591	Economy	10900.00
0005432817561	9591	Economy	10900.00
0005432822225	9591	Economy	10900.00
0005432817555	9591	Economy	10900.00
0005432901488	9591	Economy	10900.00
0005432817548	9591	Economy	10900.00
0005432822228	9591	Economy	10900.00
0005434157431	9591	Economy	10900.00
0005432822226	9591	Economy	10900.00
0005432817552	9591	Economy	10900.00
0005434157453	9591	Economy	10900.00
0005434157444	9591	Economy	10900.00
0005432817566	9591	Economy	10900.00
0005432901525	9591	Economy	10900.00
0005432817570	9591	Economy	10900.00
0005432817575	9591	Economy	10900.00
0005434157407	9591	Economy	10900.00
0005434157434	9591	Economy	10900.00
0005432817553	9591	Economy	10900.00
0005432817556	9591	Economy	10900.00
0005432817546	9591	Economy	10900.00
0005434448328	9591	Economy	10900.00
0005432901532	9591	Economy	10900.00
0005432817560	9591	Economy	10900.00
0005434448327	9591	Economy	10900.00
0005432817547	9591	Economy	10900.00
0005432901524	9591	Economy	10900.00
0005434157456	9591	Economy	10900.00
0005432901529	9591	Economy	10900.00
0005432817562	9591	Economy	10900.00
0005432822227	9591	Economy	10900.00
0005432901477	9591	Economy	10900.00
0005432817574	9591	Economy	10900.00
0005432288996	9591	Economy	10900.00
0005432901533	9591	Economy	10900.00
0005432817567	9591	Economy	10900.00
0005432822170	28975	Business	32600.00
0005434157503	28975	Business	32600.00
0005432901662	28975	Business	32600.00
0005432822163	28975	Business	32600.00
0005432817297	28975	Business	32600.00
0005432817383	28975	Business	32600.00
0005432817333	28975	Business	32600.00
0005432817332	28975	Economy	10900.00
0005432901658	28975	Economy	10900.00
0005432901670	28975	Economy	10900.00
0005432817381	28975	Economy	10900.00
0005434157500	28975	Economy	10900.00
0005432822153	28975	Economy	10900.00
0005432817341	28975	Economy	10900.00
0005432901665	28975	Economy	11900.00
0005432002084	28975	Economy	11900.00
0005432822132	28975	Economy	11900.00
0005434448280	28975	Economy	11900.00
0005432817169	28975	Economy	11900.00
0005432901668	28975	Economy	10900.00
0005432817410	28975	Economy	10900.00
0005432901656	28975	Economy	10900.00
0005434448287	28975	Economy	10900.00
0005434186205	28975	Economy	10900.00
0005432817183	28975	Economy	10900.00
0005434157499	28975	Economy	10900.00
0005432817280	28975	Economy	10900.00
0005432817208	28975	Economy	10900.00
0005432901669	28975	Economy	10900.00
0005432901666	28975	Economy	10900.00
0005432817411	28975	Economy	10900.00
0005434448293	28975	Economy	10900.00
0005432817281	28975	Economy	10900.00
0005432817236	28975	Economy	10900.00
0005432817260	28975	Economy	10900.00
0005432817361	28975	Economy	10900.00
0005432822183	28975	Economy	10900.00
0005434186206	28975	Economy	10900.00
0005432901655	28975	Economy	10900.00
0005432901660	28975	Economy	10900.00
0005432901664	28975	Economy	10900.00
0005432817312	28975	Economy	10900.00
0005432822154	28975	Economy	10900.00
0005432817363	28975	Economy	10900.00
0005432901657	28975	Economy	10900.00
0005432817177	28975	Economy	10900.00
0005432002083	28975	Economy	10900.00
0005432817315	28975	Economy	10900.00
0005432901667	28975	Economy	10900.00
0005432822162	28975	Economy	10900.00
0005432002082	28975	Economy	10900.00
0005434448282	28975	Economy	10900.00
0005434157501	28975	Economy	10900.00
0005432817182	28975	Economy	10900.00
0005432822166	28975	Economy	10900.00
0005432901663	28975	Economy	10900.00
0005432817206	28975	Economy	10900.00
0005434157505	28975	Economy	10900.00
0005434157502	28975	Economy	10900.00
0005434448294	28975	Economy	10900.00
0005434186207	28975	Economy	10900.00
0005434157504	28975	Economy	10900.00
0005432901661	28975	Economy	10900.00
0005432822133	28975	Economy	10900.00
0005432817294	28975	Economy	10900.00
0005432817128	28975	Economy	10900.00
0005432817314	28975	Economy	10900.00
0005432822134	28975	Economy	10900.00
0005432901653	28975	Economy	10900.00
0005432817362	28975	Economy	10900.00
0005432901659	28975	Economy	10900.00
0005434448306	28975	Economy	10900.00
0005434186204	28975	Economy	10900.00
0005432817209	28975	Economy	10900.00
0005434157506	28975	Economy	10900.00
0005432901654	28975	Economy	10900.00
0005432611723	15060	Economy	11000.00
0005435841817	15060	Economy	11000.00
0005432611725	15060	Economy	11000.00
0005432611724	15060	Economy	11000.00
0005432613872	15060	Economy	11000.00
0005432613876	15060	Economy	11000.00
0005432613873	15060	Economy	11000.00
0005432613874	15060	Economy	11000.00
0005432611722	15060	Economy	11000.00
0005432613875	15060	Economy	11000.00
0005432611721	15060	Economy	11000.00
0005432607525	31545	Economy	11000.00
0005432607563	31545	Economy	11000.00
0005432607552	31545	Economy	11000.00
0005432611681	31545	Economy	11000.00
0005432607527	31545	Economy	11000.00
0005435842328	31545	Economy	11000.00
0005432607526	31545	Economy	11000.00
0005432607556	31545	Economy	11000.00
0005432607551	31545	Economy	11000.00
0005435842330	31545	Economy	11000.00
0005435842329	31545	Economy	11000.00
0005432611694	31545	Economy	11000.00
0005432948235	11882	Business	105900.00
0005433569186	11882	Business	105900.00
0005432948243	11882	Business	105900.00
0005433569217	11882	Business	105900.00
0005432948238	11882	Business	105900.00
0005433569231	11882	Business	105900.00
0005433569199	11882	Business	105900.00
0005433569221	11882	Business	105900.00
0005433569235	11882	Business	105900.00
0005433569227	11882	Business	105900.00
0005433569238	11882	Business	105900.00
0005432948071	11882	Business	105900.00
0005432948093	11882	Business	105900.00
0005432948244	11882	Business	105900.00
0005433569226	11882	Business	105900.00
0005433569224	11882	Business	105900.00
0005433569229	11882	Business	105900.00
0005433569189	11882	Economy	35300.00
0005433569202	11882	Business	105900.00
0005432948261	11882	Economy	35300.00
0005432948118	11882	Economy	35300.00
0005432948190	11882	Economy	35300.00
0005433569214	11882	Economy	35300.00
0005432947936	11882	Economy	35300.00
0005432948076	11882	Economy	35300.00
0005433569191	11882	Economy	35300.00
0005433569187	11882	Economy	35300.00
0005433569196	11882	Economy	35300.00
0005433569222	11882	Economy	38800.00
0005432948091	11882	Economy	38800.00
0005432948129	11882	Economy	38800.00
0005432948149	11882	Economy	35300.00
0005432948211	11882	Economy	35300.00
0005433569182	11882	Economy	35300.00
0005432948279	11882	Economy	35300.00
0005433569188	11882	Economy	35300.00
0005433569225	11882	Economy	35300.00
0005433569216	11882	Economy	35300.00
0005432948318	11882	Economy	35300.00
0005433569195	11882	Economy	35300.00
0005433569207	11882	Economy	35300.00
0005433569215	11882	Economy	35300.00
0005433569183	11882	Economy	35300.00
0005433569237	11882	Economy	35300.00
0005433569192	11882	Economy	35300.00
0005432948253	11882	Economy	35300.00
0005432948092	11882	Economy	35300.00
0005433569205	11882	Economy	35300.00
0005433569208	11882	Economy	35300.00
0005433569201	11882	Economy	35300.00
0005433569197	11882	Economy	35300.00
0005433569232	11882	Economy	35300.00
0005433569233	11882	Economy	35300.00
0005432947937	11882	Economy	35300.00
0005432948117	11882	Economy	35300.00
0005433569241	11882	Economy	35300.00
0005432948196	11882	Economy	35300.00
0005433569228	11882	Economy	35300.00
0005432948159	11882	Economy	35300.00
0005433569240	11882	Economy	35300.00
0005433569198	11882	Economy	35300.00
0005433569194	11882	Economy	35300.00
0005433569200	11882	Economy	35300.00
0005433569218	11882	Economy	35300.00
0005433569204	11882	Economy	35300.00
0005433569203	11882	Economy	35300.00
0005433569212	11882	Economy	35300.00
0005433569206	11882	Economy	35300.00
0005432948090	11882	Economy	35300.00
0005432948352	11882	Economy	35300.00
0005433569209	11882	Economy	35300.00
0005432948147	11882	Economy	35300.00
0005433569219	11882	Economy	35300.00
0005432948230	11882	Economy	35300.00
0005433569223	11882	Economy	35300.00
0005433569230	11882	Economy	35300.00
0005432948300	11882	Economy	35300.00
0005433569190	11882	Economy	35300.00
0005432948222	11882	Economy	35300.00
0005432948191	11882	Economy	35300.00
0005432948079	11882	Economy	35300.00
0005433569220	11882	Economy	35300.00
0005432948270	11882	Economy	35300.00
0005433569185	11882	Economy	35300.00
0005433569211	11882	Economy	35300.00
0005432948158	11882	Economy	35300.00
0005432948156	11882	Economy	35300.00
0005433569210	11882	Economy	35300.00
0005433569236	11882	Economy	35300.00
0005433569239	11882	Economy	35300.00
0005433569184	11882	Economy	35300.00
0005432948049	11882	Economy	35300.00
0005432948080	11882	Economy	35300.00
0005433569213	11882	Economy	35300.00
0005433569193	11882	Economy	35300.00
0005432948178	11882	Economy	35300.00
0005433569234	11882	Economy	35300.00
0005433568650	25286	Business	105900.00
0005433568547	25286	Business	105900.00
0005433568781	25286	Business	105900.00
0005432948637	25286	Business	105900.00
0005432948635	25286	Business	105900.00
0005433568687	25286	Business	105900.00
0005432948630	25286	Business	105900.00
0005433568667	25286	Business	105900.00
0005433568676	25286	Business	105900.00
0005432948618	25286	Business	105900.00
0005433568624	25286	Business	105900.00
0005433568769	25286	Business	105900.00
0005433568600	25286	Business	105900.00
0005432948620	25286	Business	105900.00
0005433568691	25286	Business	105900.00
0005432948604	25286	Business	105900.00
0005432948614	25286	Business	105900.00
0005433568784	25286	Business	105900.00
0005433568619	25286	Economy	35300.00
0005433568506	25286	Economy	35300.00
0005433568727	25286	Economy	35300.00
0005432948613	25286	Economy	35300.00
0005433568574	25286	Economy	35300.00
0005433568664	25286	Economy	35300.00
0005433568749	25286	Economy	35300.00
0005432948629	25286	Economy	35300.00
0005433568699	25286	Economy	35300.00
0005433568567	25286	Economy	35300.00
0005432948627	25286	Economy	35300.00
0005433568725	25286	Economy	35300.00
0005433568541	25286	Economy	38800.00
0005432948633	25286	Economy	38800.00
0005432948599	25286	Economy	38800.00
0005432948628	25286	Economy	38800.00
0005432948622	25286	Economy	35300.00
0005432948612	25286	Economy	35300.00
0005432948616	25286	Economy	35300.00
0005432948626	25286	Economy	35300.00
0005433568566	25286	Economy	35300.00
0005433568635	25286	Economy	35300.00
0005432948608	25286	Economy	35300.00
0005433568620	25286	Economy	35300.00
0005433568657	25286	Economy	35300.00
0005432948624	25286	Economy	35300.00
0005433568780	25286	Economy	35300.00
0005432948603	25286	Economy	35300.00
0005433568737	25286	Economy	35300.00
0005432948600	25286	Economy	35300.00
0005432948617	25286	Economy	35300.00
0005433568583	25286	Economy	35300.00
0005432948606	25286	Economy	35300.00
0005433568505	25286	Economy	35300.00
0005432948602	25286	Economy	35300.00
0005433568733	25286	Economy	35300.00
0005433568707	25286	Economy	35300.00
0005433568736	25286	Economy	35300.00
0005433568758	25286	Economy	35300.00
0005433568633	25286	Economy	35300.00
0005433568734	25286	Economy	35300.00
0005432948625	25286	Economy	35300.00
0005433568611	25286	Economy	35300.00
0005432948623	25286	Economy	35300.00
0005433568730	25286	Economy	35300.00
0005432948636	25286	Economy	35300.00
0005433568685	25286	Economy	35300.00
0005433568721	25286	Economy	35300.00
0005433568648	25286	Economy	35300.00
0005432948609	25286	Economy	35300.00
0005433568621	25286	Economy	35300.00
0005433568568	25286	Economy	35300.00
0005433568618	25286	Economy	35300.00
0005433568392	25286	Economy	35300.00
0005433568473	25286	Economy	35300.00
0005432948601	25286	Economy	35300.00
0005433568540	25286	Economy	35300.00
0005433568759	25286	Economy	35300.00
0005433568581	25286	Economy	35300.00
0005432948631	25286	Economy	35300.00
0005433568634	25286	Economy	35300.00
0005433568726	25286	Economy	35300.00
0005432948638	25286	Economy	35300.00
0005433568746	25286	Economy	35300.00
0005433568705	25286	Economy	35300.00
0005432948621	25286	Economy	35300.00
0005433568460	25286	Economy	35300.00
0005433568703	25286	Economy	35300.00
0005433568805	25286	Economy	35300.00
0005433568647	25286	Economy	35300.00
0005433568481	25286	Economy	35300.00
0005432948632	25286	Economy	35300.00
0005432948639	25286	Economy	35300.00
0005433568731	25286	Economy	35300.00
0005433568565	25286	Economy	35300.00
0005432948619	25286	Economy	35300.00
0005433568428	25286	Economy	35300.00
0005432948634	25286	Economy	35300.00
0005433568649	25286	Economy	35300.00
0005433568706	25286	Economy	35300.00
0005432948607	25286	Economy	35300.00
0005433568482	25286	Economy	35300.00
0005433568718	25286	Economy	35300.00
0005432948605	25286	Economy	35300.00
0005432948598	25286	Economy	35300.00
0005432948611	25286	Economy	35300.00
0005432948610	25286	Economy	35300.00
0005433568632	25286	Economy	35300.00
0005432948615	25286	Economy	35300.00
0005433568766	25286	Economy	35300.00
0005433568735	25286	Economy	35300.00
0005434654777	5380	Business	67200.00
0005434654765	5380	Business	67200.00
0005434654786	5380	Business	67200.00
0005435340191	5380	Business	67200.00
0005434654758	5380	Business	67200.00
0005434654784	5380	Economy	22400.00
0005434654783	5380	Economy	22400.00
0005434654773	5380	Economy	22400.00
0005434654787	5380	Economy	22400.00
0005434654774	5380	Economy	22400.00
0005434656563	5380	Economy	24600.00
0005434654782	5380	Economy	24600.00
0005435340101	5380	Economy	24600.00
0005434654775	5380	Economy	24600.00
0005434654776	5380	Economy	22400.00
0005434654771	5380	Economy	22400.00
0005435340197	5380	Economy	22400.00
0005434654772	5380	Economy	22400.00
0005434654766	5380	Economy	22400.00
0005435340082	5380	Economy	22400.00
0005432114214	5380	Economy	22400.00
0005434654760	5380	Economy	22400.00
0005435340190	5380	Economy	22400.00
0005435340172	5380	Economy	22400.00
0005434654780	5380	Economy	22400.00
0005434654759	5380	Economy	22400.00
0005434654763	5380	Economy	22400.00
0005435340193	5380	Economy	22400.00
0005432114213	5380	Economy	22400.00
0005434654767	5380	Economy	22400.00
0005434654769	5380	Economy	22400.00
0005435340130	5380	Economy	22400.00
0005434654761	5380	Economy	22400.00
0005434654778	5380	Economy	22400.00
0005435340093	5380	Economy	22400.00
0005434654770	5380	Economy	22400.00
0005434654768	5380	Economy	22400.00
0005434654785	5380	Economy	22400.00
0005435340187	5380	Economy	22400.00
0005434654762	5380	Economy	22400.00
0005435340121	5380	Economy	22400.00
0005435340122	5380	Economy	22400.00
0005435340212	5380	Economy	22400.00
0005434654779	5380	Economy	22400.00
0005434654781	5380	Economy	22400.00
0005435340129	5380	Economy	22400.00
0005434654764	5380	Economy	22400.00
0005434656562	5380	Economy	22400.00
0005432114212	5380	Economy	22400.00
0005435340315	12522	Business	67200.00
0005434654612	12522	Business	67200.00
0005434654576	12522	Business	67200.00
0005434654555	12522	Business	67200.00
0005434654613	12522	Business	67200.00
0005434654501	12522	Business	67200.00
0005434654529	12522	Business	67200.00
0005434654346	12522	Business	67200.00
0005434654582	12522	Business	67200.00
0005435340307	12522	Economy	22400.00
0005435555377	12522	Economy	22400.00
0005435340311	12522	Economy	22400.00
0005434654472	12522	Economy	22400.00
0005435340313	12522	Economy	22400.00
0005434654495	12522	Economy	22400.00
0005434654436	12522	Economy	22400.00
0005434654526	12522	Economy	22400.00
0005434654496	12522	Economy	24600.00
0005434654587	12522	Economy	24600.00
0005434654459	12522	Economy	22400.00
0005435340305	12522	Economy	22400.00
0005434654525	12522	Economy	22400.00
0005435340302	12522	Economy	22400.00
0005434654522	12522	Economy	22400.00
0005434654490	12522	Economy	22400.00
0005434654541	12522	Economy	22400.00
0005434654551	12522	Economy	22400.00
0005434654537	12522	Economy	22400.00
0005434654430	12522	Economy	22400.00
0005435340306	12522	Economy	22400.00
0005435340300	12522	Economy	22400.00
0005435340314	12522	Economy	22400.00
0005434654528	12522	Economy	22400.00
0005434654562	12522	Economy	22400.00
0005434654538	12522	Economy	22400.00
0005434654460	12522	Economy	22400.00
0005434654500	12522	Economy	22400.00
0005434654552	12522	Economy	22400.00
0005435555378	12522	Economy	22400.00
0005434654340	12522	Economy	22400.00
0005435340309	12522	Economy	22400.00
0005434654438	12522	Economy	22400.00
0005434654506	12522	Economy	22400.00
0005434654400	12522	Economy	22400.00
0005434654329	12522	Economy	22400.00
0005434654498	12522	Economy	22400.00
0005434654345	12522	Economy	22400.00
0005435340303	12522	Economy	22400.00
0005434654458	12522	Economy	22400.00
0005435340308	12522	Economy	22400.00
0005434654473	12522	Economy	22400.00
0005434654497	12522	Economy	22400.00
0005435340301	12522	Economy	22400.00
0005435340312	12522	Economy	22400.00
0005434654507	12522	Economy	22400.00
0005435340310	12522	Economy	22400.00
0005434654471	12522	Economy	22400.00
0005435340304	12522	Economy	22400.00
0005434654439	12522	Economy	22400.00
0005434654499	12522	Economy	22400.00
0005433716095	7423	Business	32000.00
0005433716101	7423	Business	32000.00
0005432428919	7423	Business	32000.00
0005433716116	7423	Business	32000.00
0005433716123	7423	Business	32000.00
0005433722232	7423	Business	32000.00
0005433716122	7423	Business	32000.00
0005435266117	7423	Business	32000.00
0005433722235	7423	Economy	10700.00
0005432078123	7423	Economy	10700.00
0005433716138	7423	Economy	10700.00
0005433716126	7423	Economy	10700.00
0005433716103	7423	Economy	10700.00
0005433688813	7423	Economy	10700.00
0005432078127	7423	Economy	10700.00
0005433716141	7423	Economy	10700.00
0005433719149	7423	Economy	10700.00
0005433688814	7423	Economy	10700.00
0005433689916	7423	Economy	10700.00
0005433716121	7423	Economy	10700.00
0005433716104	7423	Economy	10700.00
0005433716100	7423	Economy	10700.00
0005433716125	7423	Economy	10700.00
0005433716099	7423	Economy	10700.00
0005433716117	7423	Economy	10700.00
0005433716110	7423	Economy	10700.00
0005433716136	7423	Economy	10700.00
0005432078126	7423	Economy	10700.00
0005433716115	7423	Economy	10700.00
0005433690931	7423	Economy	10700.00
0005433716102	7423	Economy	10700.00
0005433716120	7423	Economy	10700.00
0005433716106	7423	Economy	10700.00
0005433716127	7423	Economy	10700.00
0005433656677	7423	Economy	10700.00
0005433689915	7423	Economy	11700.00
0005433716132	7423	Economy	11700.00
0005432428910	7423	Economy	10700.00
0005433716133	7423	Economy	10700.00
0005433716131	7423	Economy	10700.00
0005433722234	7423	Economy	10700.00
0005433716091	7423	Economy	10700.00
0005433716093	7423	Economy	10700.00
0005433716130	7423	Economy	10700.00
0005433716090	7423	Economy	10700.00
0005433716109	7423	Economy	10700.00
0005433716140	7423	Economy	10700.00
0005433656679	7423	Economy	10700.00
0005432078124	7423	Economy	10700.00
0005433716092	7423	Economy	10700.00
0005433716118	7423	Economy	10700.00
0005433722233	7423	Economy	10700.00
0005433656678	7423	Economy	10700.00
0005433716105	7423	Economy	10700.00
0005433716111	7423	Economy	10700.00
0005433722236	7423	Economy	10700.00
0005433716135	7423	Economy	10700.00
0005433716129	7423	Economy	10700.00
0005433716113	7423	Economy	10700.00
0005432428917	7423	Economy	10700.00
0005433716094	7423	Economy	10700.00
0005433716128	7423	Economy	10700.00
0005433716098	7423	Economy	10700.00
0005433716114	7423	Economy	10700.00
0005433716107	7423	Economy	10700.00
0005433716097	7423	Economy	10700.00
0005433716096	7423	Economy	10700.00
0005432078125	7423	Economy	10700.00
0005433716124	7423	Economy	10700.00
0005433719147	7423	Economy	10700.00
0005432428921	7423	Economy	10700.00
0005433716112	7423	Economy	10700.00
0005432428918	7423	Economy	10700.00
0005433719148	7423	Economy	10700.00
0005433716108	7423	Economy	10700.00
0005433716089	7423	Economy	10700.00
0005433716119	7423	Economy	10700.00
0005433716134	7423	Economy	10700.00
0005432428922	7423	Economy	10700.00
0005433716139	7423	Economy	10700.00
0005433716137	7423	Economy	10700.00
0005433722196	29234	Business	32000.00
0005433715644	29234	Business	32000.00
0005433715635	29234	Business	32000.00
0005435266157	29234	Business	32000.00
0005433715734	29234	Business	32000.00
0005435266156	29234	Business	32000.00
0005433715599	29234	Business	32000.00
0005433719105	29234	Business	32000.00
0005433685501	29234	Business	32000.00
0005433656643	29234	Economy	10700.00
0005433715776	29234	Economy	10700.00
0005433715713	29234	Economy	10700.00
0005433722191	29234	Economy	10700.00
0005433715439	29234	Economy	10700.00
0005433722173	29234	Economy	10700.00
0005432428941	29234	Economy	10700.00
0005433715414	29234	Economy	10700.00
0005433715526	29234	Economy	10700.00
0005433715580	29234	Economy	10700.00
0005433715911	29234	Economy	10700.00
0005433715768	29234	Economy	10700.00
0005433719098	29234	Economy	10700.00
0005433715743	29234	Economy	10700.00
0005433715811	29234	Economy	10700.00
0005433715744	29234	Economy	10700.00
0005433715631	29234	Economy	10700.00
0005433722174	29234	Economy	10700.00
0005433715492	29234	Economy	10700.00
0005433715784	29234	Economy	10700.00
0005435266155	29234	Economy	10700.00
0005433715584	29234	Economy	10700.00
0005433715605	29234	Economy	10700.00
0005435266154	29234	Economy	10700.00
0005433722183	29234	Economy	11700.00
0005433722178	29234	Economy	10700.00
0005433715581	29234	Economy	11700.00
0005433715770	29234	Economy	11700.00
0005433722156	29234	Economy	11700.00
0005433715912	29234	Economy	10700.00
0005433715530	29234	Economy	10700.00
0005433715777	29234	Economy	10700.00
0005433715630	29234	Economy	10700.00
0005433715525	29234	Economy	10700.00
0005433715738	29234	Economy	10700.00
0005433722176	29234	Economy	10700.00
0005433715607	29234	Economy	10700.00
0005433685502	29234	Economy	10700.00
0005433722179	29234	Economy	10700.00
0005433715555	29234	Economy	10700.00
0005433715715	29234	Economy	10700.00
0005433715670	29234	Economy	10700.00
0005433715711	29234	Economy	10700.00
0005433715591	29234	Economy	10700.00
0005433715735	29234	Economy	10700.00
0005433715527	29234	Economy	10700.00
0005433722180	29234	Economy	10700.00
0005433715633	29234	Economy	10700.00
0005433719134	29234	Economy	10700.00
0005433656655	29234	Economy	10700.00
0005433715608	29234	Economy	10700.00
0005433715643	29234	Economy	10700.00
0005433715778	29234	Economy	10700.00
0005433719126	29234	Economy	10700.00
0005433715726	29234	Economy	10700.00
0005433715737	29234	Economy	10700.00
0005433715788	29234	Economy	10700.00
0005433656644	29234	Economy	10700.00
0005433715910	29234	Economy	10700.00
0005433722159	29234	Economy	10700.00
0005433715812	29234	Economy	10700.00
0005433719125	29234	Economy	10700.00
0005433715652	29234	Economy	10700.00
0005433656654	29234	Economy	10700.00
0005433715789	29234	Economy	10700.00
0005432006770	29234	Economy	10700.00
0005433722175	29234	Economy	10700.00
0005435266158	29234	Economy	10700.00
0005433715742	29234	Economy	10700.00
0005433715654	29234	Economy	10700.00
0005433715415	29234	Economy	10700.00
0005433722158	29234	Economy	10700.00
0005432428939	29234	Economy	10700.00
0005432428938	29234	Economy	10700.00
0005433722157	29234	Economy	10700.00
0005433715783	29234	Economy	10700.00
0005433715646	29234	Economy	10700.00
0005433715669	29234	Economy	10700.00
0005433715741	29234	Economy	10700.00
0005432006769	29234	Economy	10700.00
0005433715634	29234	Economy	10700.00
0005433722165	29234	Economy	10700.00
0005433715645	29234	Economy	10700.00
0005433715637	29234	Economy	10700.00
0005433722181	29234	Economy	10700.00
0005433722164	29234	Economy	10700.00
0005432428940	29234	Economy	10700.00
0005433715769	29234	Economy	10700.00
0005434182171	8700	Business	36500.00
0005434095314	8700	Business	36500.00
0005434095313	8700	Business	36500.00
0005434182165	8700	Business	36500.00
0005434182158	8700	Business	36500.00
0005434095319	8700	Economy	12200.00
0005434182123	8700	Economy	12200.00
0005434095324	8700	Economy	12200.00
0005434095322	8700	Economy	12200.00
0005434182112	8700	Economy	13400.00
0005434095315	8700	Economy	13400.00
0005434182144	8700	Economy	13400.00
0005434182089	8700	Economy	12200.00
0005434095311	8700	Economy	12200.00
0005434184656	8700	Economy	12200.00
0005434182157	8700	Economy	12200.00
0005434182138	8700	Economy	12200.00
0005434182111	8700	Economy	12200.00
0005434095317	8700	Economy	12200.00
0005434182167	8700	Economy	12200.00
0005434182135	8700	Economy	12200.00
0005434095323	8700	Economy	12200.00
0005434095312	8700	Economy	12200.00
0005434095316	8700	Economy	12200.00
0005434095321	8700	Economy	12200.00
0005434182161	8700	Economy	12200.00
0005434095320	8700	Economy	12200.00
0005434095318	8700	Economy	12200.00
0005434182155	8700	Economy	12200.00
0005434184653	8700	Economy	12200.00
0005434182220	11667	Business	36500.00
0005434182218	11667	Business	36500.00
0005434182227	11667	Business	36500.00
0005434182228	11667	Business	36500.00
0005434095198	11667	Economy	12200.00
0005434182217	11667	Economy	12200.00
0005434184669	11667	Economy	12200.00
0005434095173	11667	Economy	12200.00
0005434095188	11667	Economy	13400.00
0005434182223	11667	Economy	13400.00
0005434182221	11667	Economy	12200.00
0005434182226	11667	Economy	12200.00
0005434182216	11667	Economy	12200.00
0005434143723	11667	Economy	12200.00
0005434183585	11667	Economy	12200.00
0005434182224	11667	Economy	12200.00
0005434143720	11667	Economy	12200.00
0005434143707	11667	Economy	12200.00
0005434095263	11667	Economy	12200.00
0005434184670	11667	Economy	12200.00
0005434183584	11667	Economy	12200.00
0005434182225	11667	Economy	12200.00
0005434095206	11667	Economy	12200.00
0005434095189	11667	Economy	12200.00
0005434095172	11667	Economy	12200.00
0005434143706	11667	Economy	12200.00
0005434182222	11667	Economy	12200.00
0005434143719	11667	Economy	12200.00
0005434184668	11667	Economy	12200.00
0005434095205	11667	Economy	12200.00
0005434182219	11667	Economy	12200.00
0005433456980	1416	Business	33000.00
0005433398027	1416	Business	33000.00
0005433397870	1416	Business	33000.00
0005433397764	1416	Business	33000.00
0005433397651	1416	Business	33000.00
0005433397840	1416	Business	33000.00
0005433397845	1416	Business	33000.00
0005435732364	1416	Business	33000.00
0005433397869	1416	Business	33000.00
0005433456983	1416	Business	33000.00
0005433397529	1416	Economy	11000.00
0005433397848	1416	Economy	11000.00
0005433397650	1416	Economy	11000.00
0005433397653	1416	Economy	11000.00
0005433397703	1416	Economy	11000.00
0005433397967	1416	Economy	11000.00
0005433397906	1416	Economy	11000.00
0005432297284	1416	Economy	11000.00
0005433397547	1416	Economy	11000.00
0005433397683	1416	Economy	11000.00
0005433397883	1416	Economy	12100.00
0005433397715	1416	Economy	12100.00
0005435732365	1416	Economy	12100.00
0005433397700	1416	Economy	12100.00
0005433397937	1416	Economy	11000.00
0005433397879	1416	Economy	11000.00
0005433397765	1416	Economy	11000.00
0005433397699	1416	Economy	11000.00
0005432297285	1416	Economy	11000.00
0005435732363	1416	Economy	11000.00
0005433397656	1416	Economy	11000.00
0005433397638	1416	Economy	11000.00
0005433397727	1416	Economy	11000.00
0005433456981	1416	Economy	11000.00
0005433397586	1416	Economy	11000.00
0005433397681	1416	Economy	11000.00
0005433397918	1416	Economy	11000.00
0005433397706	1416	Economy	11000.00
0005433397767	1416	Economy	11000.00
0005433397773	1416	Economy	11000.00
0005433397701	1416	Economy	11000.00
0005433397771	1416	Economy	11000.00
0005433397768	1416	Economy	11000.00
0005432297286	1416	Economy	11000.00
0005433397756	1416	Economy	11000.00
0005435732362	1416	Economy	11000.00
0005433397868	1416	Economy	11000.00
0005432297287	1416	Economy	11000.00
0005433397707	1416	Economy	11000.00
0005433397993	1416	Economy	11000.00
0005432297288	1416	Economy	11000.00
0005433456979	1416	Economy	11000.00
0005433397757	1416	Economy	11000.00
0005433397654	1416	Economy	11000.00
0005433397704	1416	Economy	11000.00
0005433397610	1416	Economy	11000.00
0005433397754	1416	Economy	11000.00
0005433397920	1416	Economy	11000.00
0005433397903	1416	Economy	11000.00
0005433397804	1416	Economy	11000.00
0005433397849	1416	Economy	11000.00
0005433397877	1416	Economy	11000.00
0005433397772	1416	Economy	11000.00
0005433397716	1416	Economy	11000.00
0005433397705	1416	Economy	11000.00
0005433397728	1416	Economy	11000.00
0005433456982	1416	Economy	11000.00
0005432906516	1416	Economy	11000.00
0005433397731	1416	Economy	11000.00
0005435732361	1416	Economy	11000.00
0005433398181	19227	Business	33000.00
0005435732280	19227	Business	33000.00
0005433398193	19227	Business	33000.00
0005433398208	19227	Business	33000.00
0005433398195	19227	Business	33000.00
0005435732218	19227	Business	33000.00
0005433398197	19227	Business	33000.00
0005433398175	19227	Economy	11000.00
0005433398190	19227	Economy	11000.00
0005433398180	19227	Economy	11000.00
0005433456957	19227	Economy	11000.00
0005433398178	19227	Economy	11000.00
0005433398214	19227	Economy	11000.00
0005435732289	19227	Economy	12100.00
0005433398207	19227	Economy	12100.00
0005433456950	19227	Economy	12100.00
0005433398176	19227	Economy	12100.00
0005433398213	19227	Economy	12100.00
0005433398215	19227	Economy	11000.00
0005435732275	19227	Economy	11000.00
0005433398183	19227	Economy	11000.00
0005433398223	19227	Economy	11000.00
0005433398199	19227	Economy	11000.00
0005433398189	19227	Economy	11000.00
0005433398219	19227	Economy	11000.00
0005433456951	19227	Economy	11000.00
0005435732274	19227	Economy	11000.00
0005433398179	19227	Economy	11000.00
0005433398210	19227	Economy	11000.00
0005433398206	19227	Economy	11000.00
0005433398202	19227	Economy	11000.00
0005433398216	19227	Economy	11000.00
0005433398182	19227	Economy	11000.00
0005435732261	19227	Economy	11000.00
0005433398218	19227	Economy	11000.00
0005433398185	19227	Economy	11000.00
0005433398196	19227	Economy	11000.00
0005433398201	19227	Economy	11000.00
0005433398221	19227	Economy	11000.00
0005433398177	19227	Economy	11000.00
0005435732249	19227	Economy	11000.00
0005433398204	19227	Economy	11000.00
0005435732252	19227	Economy	11000.00
0005433398188	19227	Economy	11000.00
0005433398200	19227	Economy	11000.00
0005433398212	19227	Economy	11000.00
0005432906542	19227	Economy	11000.00
0005432906543	19227	Economy	11000.00
0005433398187	19227	Economy	11000.00
0005433398222	19227	Economy	11000.00
0005433398192	19227	Economy	11000.00
0005433398220	19227	Economy	11000.00
0005433456953	19227	Economy	11000.00
0005435732233	19227	Economy	11000.00
0005433398198	19227	Economy	11000.00
0005433398186	19227	Economy	11000.00
0005433398205	19227	Economy	11000.00
0005433398209	19227	Economy	11000.00
0005433398211	19227	Economy	11000.00
0005433398217	19227	Economy	11000.00
0005433398174	19227	Economy	11000.00
0005433398194	19227	Economy	11000.00
0005433398191	19227	Economy	11000.00
0005433398203	19227	Economy	11000.00
0005435732262	19227	Economy	11000.00
0005433398184	19227	Economy	11000.00
0005433456949	19227	Economy	11000.00
0005434443553	17342	Economy	15600.00
0005434443628	17342	Economy	15600.00
0005434443635	17342	Economy	15600.00
0005434443491	17342	Economy	14100.00
0005434443549	17342	Economy	14100.00
0005434443591	17342	Economy	14100.00
0005434443674	17342	Economy	14100.00
0005434443572	17342	Economy	14100.00
0005434443595	17342	Economy	14100.00
0005434443627	17342	Economy	14100.00
0005434443588	17342	Economy	14100.00
0005434443575	17342	Economy	14100.00
0005434443624	17342	Economy	14100.00
0005434443586	17342	Economy	14100.00
0005434443637	17342	Economy	14100.00
0005434443576	17342	Economy	14100.00
0005434443598	17342	Economy	14100.00
0005434443573	17342	Economy	14100.00
0005434443550	17342	Economy	14100.00
0005434443594	17342	Economy	14100.00
0005434443636	17342	Economy	14100.00
0005434443599	17342	Economy	14100.00
0005434443548	17342	Economy	14100.00
0005434443589	17342	Economy	14100.00
0005434443626	17342	Economy	14100.00
0005434443625	17342	Economy	14100.00
0005434443655	17342	Economy	14100.00
0005434443750	20601	Economy	15600.00
0005434443744	20601	Economy	15600.00
0005434443745	20601	Economy	14100.00
0005434443742	20601	Economy	14100.00
0005434443738	20601	Economy	14100.00
0005434443749	20601	Economy	14100.00
0005434443740	20601	Economy	14100.00
0005434443753	20601	Economy	14100.00
0005434443746	20601	Economy	14100.00
0005434443741	20601	Economy	14100.00
0005434443748	20601	Economy	14100.00
0005434443747	20601	Economy	14100.00
0005434443751	20601	Economy	14100.00
0005434443743	20601	Economy	14100.00
0005434443752	20601	Economy	14100.00
0005434443739	20601	Economy	14100.00
0005434443754	20601	Economy	14100.00
0005435377574	7287	Economy	5800.00
0005435377572	7287	Economy	5800.00
0005435377570	7287	Economy	5800.00
0005435377575	7287	Economy	5800.00
0005434954618	7287	Economy	5800.00
0005435377567	7287	Economy	5800.00
0005434954620	7287	Economy	5800.00
0005434954619	7287	Economy	5800.00
0005434954621	7287	Economy	5800.00
0005435377566	7287	Economy	5800.00
0005435377571	7287	Economy	5800.00
0005434954589	28335	Economy	5800.00
0005434954603	28335	Economy	5800.00
0005434954576	28335	Economy	5800.00
0005434954602	28335	Economy	5800.00
0005435377587	28335	Economy	5800.00
0005435893615	4469	Economy	15400.00
0005435893567	4469	Economy	15400.00
0005434351732	4469	Economy	15400.00
0005434351735	4469	Economy	14000.00
0005434183564	4469	Economy	14000.00
0005434351726	4469	Economy	14000.00
0005435893588	4469	Economy	14000.00
0005435893628	4469	Economy	14000.00
0005434183565	4469	Economy	14000.00
0005434351737	4469	Economy	14000.00
0005434351736	4469	Economy	14000.00
0005434183556	4469	Economy	14000.00
0005435893577	4469	Economy	14000.00
0005434351728	4469	Economy	14000.00
0005435893566	4469	Economy	14000.00
0005434351733	4469	Economy	14000.00
0005434351738	4469	Economy	14000.00
0005434351729	4469	Economy	14000.00
0005434351739	4469	Economy	14000.00
0005434351731	4469	Economy	14000.00
0005435893597	4469	Economy	14000.00
0005434351734	4469	Economy	14000.00
0005434351730	4469	Economy	14000.00
0005434351727	4469	Economy	14000.00
0005435893619	4469	Economy	14000.00
0005435893598	4469	Economy	14000.00
0005435893568	4469	Economy	14000.00
0005435893650	29654	Economy	15400.00
0005434351553	29654	Economy	15400.00
0005435893649	29654	Economy	15400.00
0005435893652	29654	Economy	15400.00
0005434351653	29654	Economy	14000.00
0005435893651	29654	Economy	14000.00
0005434351616	29654	Economy	14000.00
0005434351590	29654	Economy	14000.00
0005434351633	29654	Economy	14000.00
0005434351650	29654	Economy	14000.00
0005434351639	29654	Economy	14000.00
0005434351634	29654	Economy	14000.00
0005435893654	29654	Economy	14000.00
0005434351632	29654	Economy	14000.00
0005434351615	29654	Economy	14000.00
0005434351583	29654	Economy	14000.00
0005434351651	29654	Economy	14000.00
0005434351584	29654	Economy	14000.00
0005434351637	29654	Economy	14000.00
0005434351595	29654	Economy	14000.00
0005435893655	29654	Economy	14000.00
0005434351638	29654	Economy	14000.00
0005434351581	29654	Economy	14000.00
0005435893653	29654	Economy	14000.00
0005433342543	1079	Business	30600.00
0005435092100	1079	Business	30600.00
0005433342521	1079	Business	30600.00
0005435092099	1079	Business	30600.00
0005433269686	1079	Business	30600.00
0005433342426	1079	Business	30600.00
0005433159307	1079	Business	30600.00
0005433342664	1079	Business	30600.00
0005433342031	1079	Business	30600.00
0005433342464	1079	Business	30600.00
0005433342320	1079	Business	30600.00
0005433159293	1079	Business	30600.00
0005433342523	1079	Business	30600.00
0005433342765	1079	Business	30600.00
0005435092103	1079	Business	30600.00
0005433342535	1079	Business	30600.00
0005433343002	1079	Business	30600.00
0005433342753	1079	Business	30600.00
0005433342425	1079	Economy	11200.00
0005433342929	1079	Economy	11200.00
0005433342348	1079	Economy	10200.00
0005434445255	1079	Economy	10200.00
0005433342690	1079	Economy	10200.00
0005433342542	1079	Economy	10200.00
0005433269677	1079	Economy	10200.00
0005433342643	1079	Economy	10200.00
0005433342735	1079	Economy	10200.00
0005433342500	1079	Economy	10200.00
0005433342899	1079	Economy	10200.00
0005433342261	1079	Economy	10200.00
0005433342460	1079	Economy	10200.00
0005433342631	1079	Economy	10200.00
0005433342143	1079	Economy	10200.00
0005433463906	1079	Economy	10200.00
0005433342391	1079	Economy	10200.00
0005433342509	1079	Economy	10200.00
0005433342278	1079	Economy	10200.00
0005433342316	1079	Economy	10200.00
0005433342299	1079	Economy	10200.00
0005433342759	1079	Economy	10200.00
0005433342622	1079	Economy	10200.00
0005433342226	1079	Economy	10200.00
0005435092102	1079	Economy	10200.00
0005433342621	1079	Economy	10200.00
0005433269676	1079	Economy	10200.00
0005433342691	1079	Economy	10200.00
0005433342654	1079	Economy	10200.00
0005433342336	1079	Economy	10200.00
0005433343003	1079	Economy	10200.00
0005433342456	1079	Economy	10200.00
0005433159294	1079	Economy	10200.00
0005433342308	1079	Economy	10200.00
0005433159304	1079	Economy	10200.00
0005433342030	1079	Economy	10200.00
0005433342828	1079	Economy	10200.00
0005433342928	1079	Economy	10200.00
0005435092101	1079	Economy	10200.00
0005433462753	1079	Economy	10200.00
0005433342630	1079	Economy	10200.00
0005434445254	1079	Economy	10200.00
0005432293215	1079	Economy	10200.00
0005433342520	1079	Economy	10200.00
0005433342695	1079	Economy	10200.00
0005433342472	1079	Economy	10200.00
0005435092105	1079	Economy	10200.00
0005433462752	1079	Economy	10200.00
0005433342576	1079	Economy	10200.00
0005433342776	1079	Economy	10200.00
0005433342790	1079	Economy	10200.00
0005433342663	1079	Economy	10200.00
0005433342216	1079	Economy	10200.00
0005433342071	1079	Economy	10200.00
0005433463907	1079	Economy	10200.00
0005433342291	1079	Economy	10200.00
0005433342564	1079	Economy	10200.00
0005433342390	1079	Economy	10200.00
0005433342845	1079	Economy	10200.00
0005433342737	1079	Economy	10200.00
0005433342319	1079	Economy	10200.00
0005433343070	1079	Economy	10200.00
0005433342736	1079	Economy	10200.00
0005433341864	1079	Economy	10200.00
0005433342277	1079	Economy	10200.00
0005433342349	1079	Economy	10200.00
0005433158117	1079	Economy	10200.00
0005433342301	1079	Economy	11200.00
0005433342594	1079	Economy	11200.00
0005433343024	1079	Economy	10200.00
0005433342335	1079	Economy	10200.00
0005433342187	1079	Economy	10200.00
0005433342424	1079	Economy	10200.00
0005433342827	1079	Economy	10200.00
0005433342557	1079	Economy	10200.00
0005433342785	1079	Economy	10200.00
0005433342593	1079	Economy	10200.00
0005433342752	1079	Economy	10200.00
0005433269689	1079	Economy	10200.00
0005433342497	1079	Economy	10200.00
0005433343023	1079	Economy	10200.00
0005433342775	1079	Economy	10200.00
0005433342341	1079	Economy	10200.00
0005435092098	1079	Economy	10200.00
0005433342644	1079	Economy	10200.00
0005433342541	1079	Economy	10200.00
0005433342859	1079	Economy	10200.00
0005433342321	1079	Economy	10200.00
0005433342538	1079	Economy	10200.00
0005433342667	1079	Economy	10200.00
0005435092104	1079	Economy	10200.00
0005433159295	1079	Economy	10200.00
0005433342418	1079	Economy	10200.00
0005433342376	1079	Economy	10200.00
0005433342544	1079	Economy	10200.00
0005433342333	1079	Economy	10200.00
0005433342758	1079	Economy	10200.00
0005433342276	1079	Economy	10200.00
0005433342300	1079	Economy	10200.00
0005433342496	1079	Economy	10200.00
0005433342857	1079	Economy	10200.00
0005433342653	1079	Economy	10200.00
0005433342215	1079	Economy	10200.00
0005435092107	1079	Economy	10200.00
0005433342242	1079	Economy	10200.00
0005433342243	1079	Economy	10200.00
0005433342317	1079	Economy	10200.00
0005433342461	1079	Economy	10200.00
0005433158127	1079	Economy	10200.00
0005435092106	1079	Economy	10200.00
0005433342637	1079	Economy	10200.00
0005433342259	1079	Economy	10200.00
0005433342679	1079	Economy	10200.00
0005433342867	1079	Economy	10200.00
0005433269697	1079	Economy	10200.00
0005432293216	1079	Economy	10200.00
0005433342318	1079	Economy	10200.00
0005433341985	1079	Economy	10200.00
0005433342455	1079	Economy	10200.00
0005433158126	1079	Economy	10200.00
0005433342822	1079	Economy	10200.00
0005433342356	1079	Economy	10200.00
0005433269657	1079	Economy	10200.00
0005433269691	1079	Economy	10200.00
0005433342323	1079	Economy	10200.00
0005433342702	1079	Economy	10200.00
0005433342858	1079	Economy	10200.00
0005433342504	1079	Economy	10200.00
0005433269690	1079	Economy	10200.00
0005433342355	1079	Economy	10200.00
0005433343370	17066	Business	30600.00
0005433343332	17066	Business	30600.00
0005433343363	17066	Business	30600.00
0005433343378	17066	Business	30600.00
0005433269735	17066	Business	30600.00
0005433343376	17066	Business	30600.00
0005433343386	17066	Business	30600.00
0005433343408	17066	Business	30600.00
0005433343335	17066	Business	30600.00
0005435508233	17066	Business	30600.00
0005434445225	17066	Business	30600.00
0005433343405	17066	Business	30600.00
0005433343346	17066	Business	30600.00
0005435092002	17066	Business	30600.00
0005433343412	17066	Business	30600.00
0005435092035	17066	Business	30600.00
0005433343410	17066	Business	30600.00
0005433343391	17066	Economy	11200.00
0005433343377	17066	Economy	11200.00
0005433343397	17066	Economy	11200.00
0005435092032	17066	Economy	10200.00
0005433343358	17066	Economy	10200.00
0005433343407	17066	Economy	10200.00
0005433269733	17066	Economy	10200.00
0005433343368	17066	Economy	10200.00
0005433343380	17066	Economy	10200.00
0005435092023	17066	Economy	10200.00
0005435508244	17066	Economy	10200.00
0005433343382	17066	Economy	10200.00
0005435508267	17066	Economy	10200.00
0005433343342	17066	Economy	10200.00
0005433343339	17066	Economy	10200.00
0005433343333	17066	Economy	10200.00
0005433343379	17066	Economy	10200.00
0005435091973	17066	Economy	10200.00
0005433343330	17066	Economy	10200.00
0005433343359	17066	Economy	10200.00
0005435508232	17066	Economy	10200.00
0005433343328	17066	Economy	10200.00
0005433343383	17066	Economy	10200.00
0005433343352	17066	Economy	10200.00
0005433343349	17066	Economy	10200.00
0005433343372	17066	Economy	10200.00
0005433343360	17066	Economy	10200.00
0005433343318	17066	Economy	10200.00
0005433343392	17066	Economy	10200.00
0005433343327	17066	Economy	10200.00
0005433343396	17066	Economy	10200.00
0005433343404	17066	Economy	10200.00
0005433343357	17066	Economy	10200.00
0005433343319	17066	Economy	10200.00
0005433343341	17066	Economy	10200.00
0005433343375	17066	Economy	10200.00
0005435508275	17066	Economy	10200.00
0005433343401	17066	Economy	10200.00
0005433343351	17066	Economy	10200.00
0005433343337	17066	Economy	10200.00
0005433343326	17066	Economy	10200.00
0005433343371	17066	Economy	10200.00
0005433343409	17066	Economy	10200.00
0005433343324	17066	Economy	10200.00
0005433343331	17066	Economy	10200.00
0005433343398	17066	Economy	10200.00
0005433343325	17066	Economy	10200.00
0005433343338	17066	Economy	10200.00
0005433343347	17066	Economy	10200.00
0005435092021	17066	Economy	10200.00
0005433343320	17066	Economy	10200.00
0005433343329	17066	Economy	10200.00
0005433159318	17066	Economy	10200.00
0005433343413	17066	Economy	10200.00
0005433343345	17066	Economy	10200.00
0005433343393	17066	Economy	10200.00
0005433343336	17066	Economy	10200.00
0005433343399	17066	Economy	10200.00
0005433343384	17066	Economy	10200.00
0005433343365	17066	Economy	10200.00
0005433343389	17066	Economy	10200.00
0005433343321	17066	Economy	11200.00
0005433343340	17066	Economy	11200.00
0005433343387	17066	Economy	10200.00
0005433343388	17066	Economy	10200.00
0005433159319	17066	Economy	10200.00
0005433343394	17066	Economy	10200.00
0005435508231	17066	Economy	10200.00
0005435508245	17066	Economy	10200.00
0005433343348	17066	Economy	10200.00
0005433343364	17066	Economy	10200.00
0005433269732	17066	Economy	10200.00
0005435091972	17066	Economy	10200.00
0005435508251	17066	Economy	10200.00
0005433343322	17066	Economy	10200.00
0005433343400	17066	Economy	10200.00
0005435092022	17066	Economy	10200.00
0005433343374	17066	Economy	10200.00
0005433269731	17066	Economy	10200.00
0005433343367	17066	Economy	10200.00
0005433343385	17066	Economy	10200.00
0005433343406	17066	Economy	10200.00
0005433343403	17066	Economy	10200.00
0005433343402	17066	Economy	10200.00
0005433343343	17066	Economy	10200.00
0005433343369	17066	Economy	10200.00
0005433343344	17066	Economy	10200.00
0005435091992	17066	Economy	10200.00
0005433159317	17066	Economy	10200.00
0005433269734	17066	Economy	10200.00
0005435508226	17066	Economy	10200.00
0005433343395	17066	Economy	10200.00
0005433343334	17066	Economy	10200.00
0005433343355	17066	Economy	10200.00
0005435092031	17066	Economy	10200.00
0005433343366	17066	Economy	10200.00
0005435091981	17066	Economy	10200.00
0005433343317	17066	Economy	10200.00
0005433343411	17066	Economy	10200.00
0005433343356	17066	Economy	10200.00
0005433343361	17066	Economy	10200.00
0005433343390	17066	Economy	10200.00
0005433343362	17066	Economy	10200.00
0005433343354	17066	Economy	10200.00
0005433343373	17066	Economy	10200.00
0005433269736	17066	Economy	10200.00
0005433343350	17066	Economy	10200.00
0005433343314	17066	Economy	10200.00
0005433343323	17066	Economy	10200.00
0005433343315	17066	Economy	10200.00
0005433343316	17066	Economy	10200.00
0005433343381	17066	Economy	10200.00
0005433343353	17066	Economy	10200.00
0005432390160	1342	Business	101000.00
0005432851856	1342	Business	101000.00
0005432851822	1342	Business	101000.00
0005432392004	1342	Business	101000.00
0005432851889	1342	Business	101000.00
0005432390164	1342	Business	101000.00
0005432390156	1342	Business	101000.00
0005432390166	1342	Business	101000.00
0005432390138	1342	Business	101000.00
0005432391999	1342	Business	101000.00
0005432390181	1342	Business	101000.00
0005432390143	1342	Business	101000.00
0005432851868	1342	Business	101000.00
0005432390159	1342	Business	101000.00
0005432391996	1342	Business	101000.00
0005432390148	1342	Economy	33700.00
0005432390155	1342	Economy	33700.00
0005432851871	1342	Economy	33700.00
0005432392001	1342	Economy	33700.00
0005432390136	1342	Economy	33700.00
0005432851876	1342	Economy	33700.00
0005432851869	1342	Economy	33700.00
0005432851865	1342	Economy	37000.00
0005432390177	1342	Economy	37000.00
0005432390171	1342	Economy	37000.00
0005432390145	1342	Economy	37000.00
0005432851888	1342	Economy	33700.00
0005432851845	1342	Economy	33700.00
0005432390147	1342	Economy	33700.00
0005432390154	1342	Economy	33700.00
0005432390161	1342	Economy	33700.00
0005432390163	1342	Economy	33700.00
0005432390174	1342	Economy	33700.00
0005432851870	1342	Economy	33700.00
0005432851867	1342	Economy	33700.00
0005432851878	1342	Economy	33700.00
0005432851881	1342	Economy	33700.00
0005432392003	1342	Economy	33700.00
0005432851847	1342	Economy	33700.00
0005432390142	1342	Economy	33700.00
0005432851880	1342	Economy	33700.00
0005432390175	1342	Economy	33700.00
0005432390172	1342	Economy	33700.00
0005432390157	1342	Economy	33700.00
0005432390153	1342	Economy	33700.00
0005432851861	1342	Economy	33700.00
0005432390150	1342	Economy	33700.00
0005432851866	1342	Economy	33700.00
0005432851864	1342	Economy	33700.00
0005432390169	1342	Economy	33700.00
0005432390173	1342	Economy	33700.00
0005432390179	1342	Economy	33700.00
0005432390140	1342	Economy	33700.00
0005432391997	1342	Economy	33700.00
0005432851877	1342	Economy	33700.00
0005432390167	1342	Economy	33700.00
0005432390162	1342	Economy	33700.00
0005432851844	1342	Economy	33700.00
0005432851842	1342	Economy	33700.00
0005432390149	1342	Economy	33700.00
0005432390170	1342	Economy	33700.00
0005432391998	1342	Economy	33700.00
0005432390180	1342	Economy	33700.00
0005432851862	1342	Economy	33700.00
0005432851843	1342	Economy	33700.00
0005432390165	1342	Economy	33700.00
0005432851879	1342	Economy	33700.00
0005432390158	1342	Economy	33700.00
0005432390137	1342	Economy	33700.00
0005432392005	1342	Economy	33700.00
0005432390135	1342	Economy	33700.00
0005432851882	1342	Economy	33700.00
0005432390168	1342	Economy	33700.00
0005432851848	1342	Economy	33700.00
0005432851898	1342	Economy	33700.00
0005432390178	1342	Economy	33700.00
0005432392000	1342	Economy	33700.00
0005432390151	1342	Economy	33700.00
0005432390141	1342	Economy	33700.00
0005432392006	1342	Economy	33700.00
0005432390152	1342	Economy	33700.00
0005432851846	1342	Economy	33700.00
0005432390176	1342	Economy	33700.00
0005432392002	1342	Economy	33700.00
0005432390144	1342	Economy	33700.00
0005432390139	1342	Economy	33700.00
0005432390182	1342	Economy	33700.00
0005432851863	1342	Economy	33700.00
0005432390146	1342	Economy	33700.00
0005432391995	1342	Economy	33700.00
0005432851891	1342	Economy	33700.00
0005432851858	1342	Economy	33700.00
0005432433697	12770	Business	40300.00
0005434067337	12770	Business	40300.00
0005434067165	12770	Business	40300.00
0005434067294	12770	Business	40300.00
0005434067077	12770	Business	40300.00
0005434081740	12770	Business	40300.00
0005433989736	12770	Business	40300.00
0005434067016	12770	Business	40300.00
0005434067095	12770	Economy	13400.00
0005433812907	12770	Economy	13400.00
0005434081756	12770	Economy	13400.00
0005434067028	12770	Economy	13400.00
0005434067375	12770	Economy	13400.00
0005434067048	12770	Economy	13400.00
0005434066862	12770	Economy	13400.00
0005434067231	12770	Economy	13400.00
0005434067128	12770	Economy	13400.00
0005435283410	12770	Economy	13400.00
0005434067056	12770	Economy	13400.00
0005434081737	12770	Economy	13400.00
0005434067099	12770	Economy	13400.00
0005432161158	12770	Economy	13400.00
0005434067413	12770	Economy	13400.00
0005434067119	12770	Economy	13400.00
0005434067029	12770	Economy	13400.00
0005434067141	12770	Economy	13400.00
0005434067058	12770	Economy	13400.00
0005434067290	12770	Economy	13400.00
0005434081881	12770	Economy	13400.00
0005434067164	12770	Economy	13400.00
0005434066983	12770	Economy	13400.00
0005433812908	12770	Economy	13400.00
0005434081767	12770	Economy	13400.00
0005435283409	12770	Economy	13400.00
0005434067150	12770	Economy	13400.00
0005434081844	12770	Economy	13400.00
0005432159871	12770	Economy	13400.00
0005434067139	12770	Economy	13400.00
0005434067185	12770	Economy	13400.00
0005434067137	12770	Economy	13400.00
0005432159869	12770	Economy	13400.00
0005434067049	12770	Economy	14800.00
0005434066696	12770	Economy	14800.00
0005432433694	12770	Economy	14800.00
0005434081749	12770	Economy	14800.00
0005432159872	12770	Economy	14800.00
0005433989733	12770	Economy	14800.00
0005434066865	12770	Economy	13400.00
0005434081682	12770	Economy	13400.00
0005434067377	12770	Economy	13400.00
0005434067338	12770	Economy	13400.00
0005434066915	12770	Economy	13400.00
0005434066976	12770	Economy	13400.00
0005434066960	12770	Economy	13400.00
0005432161159	12770	Economy	13400.00
0005434067258	12770	Economy	13400.00
0005434067120	12770	Economy	13400.00
0005434067118	12770	Economy	13400.00
0005433989734	12770	Economy	13400.00
0005434066869	12770	Economy	13400.00
0005434067147	12770	Economy	13400.00
0005434067078	12770	Economy	13400.00
0005434067053	12770	Economy	13400.00
0005434067206	12770	Economy	13400.00
0005434067138	12770	Economy	13400.00
0005434081758	12770	Economy	13400.00
0005434067142	12770	Economy	13400.00
0005434081716	12770	Economy	13400.00
0005434067152	12770	Economy	13400.00
0005434067427	12770	Economy	13400.00
0005434067129	12770	Economy	13400.00
0005434081681	12770	Economy	13400.00
0005434067376	12770	Economy	13400.00
0005434067057	12770	Economy	13400.00
0005433989745	12770	Economy	13400.00
0005434067059	12770	Economy	13400.00
0005434067098	12770	Economy	13400.00
0005434067135	12770	Economy	13400.00
0005434067367	12770	Economy	13400.00
0005434067443	12770	Economy	13400.00
0005433812909	12770	Economy	13400.00
0005434081706	12770	Economy	13400.00
0005434067295	12770	Economy	13400.00
0005432159873	12770	Economy	13400.00
0005433812906	12770	Economy	13400.00
0005432433696	12770	Economy	13400.00
0005432433695	12770	Economy	13400.00
0005434067368	12770	Economy	13400.00
0005434081736	12770	Economy	13400.00
0005434067140	12770	Economy	13400.00
0005433989724	12770	Economy	13400.00
0005434067154	12770	Economy	13400.00
0005434067105	12770	Economy	13400.00
0005434067369	12770	Economy	13400.00
0005434067194	12770	Economy	13400.00
0005434067166	12770	Economy	13400.00
0005432159870	12770	Economy	13400.00
0005434066945	12770	Economy	13400.00
0005434067153	12770	Economy	13400.00
0005434081686	12770	Economy	13400.00
0005434067136	12770	Economy	13400.00
0005432433693	12770	Economy	13400.00
0005434081739	12770	Economy	13400.00
0005434081738	12770	Economy	13400.00
0005434066864	12770	Economy	13400.00
0005434066958	12770	Economy	13400.00
0005434067707	30688	Business	40300.00
0005432150209	30688	Business	40300.00
0005434067697	30688	Business	40300.00
0005434067715	30688	Business	40300.00
0005434081948	30688	Business	40300.00
0005432433628	30688	Business	40300.00
0005434067691	30688	Business	40300.00
0005434081933	30688	Business	40300.00
0005434081944	30688	Business	40300.00
0005434067720	30688	Business	40300.00
0005434067683	30688	Business	40300.00
0005434067734	30688	Business	40300.00
0005434081943	30688	Economy	13400.00
0005434081940	30688	Economy	13400.00
0005434067745	30688	Economy	13400.00
0005434067679	30688	Economy	13400.00
0005434067685	30688	Economy	13400.00
0005432186875	30688	Economy	13400.00
0005434067686	30688	Economy	13400.00
0005434067676	30688	Economy	13400.00
0005434081931	30688	Economy	13400.00
0005434067716	30688	Economy	13400.00
0005434067712	30688	Economy	13400.00
0005434081929	30688	Economy	13400.00
0005434067731	30688	Economy	13400.00
0005434067729	30688	Economy	13400.00
0005434067741	30688	Economy	13400.00
0005432433669	30688	Economy	13400.00
0005434081949	30688	Economy	13400.00
0005433989782	30688	Economy	13400.00
0005432433653	30688	Economy	13400.00
0005434067719	30688	Economy	13400.00
0005434067709	30688	Economy	13400.00
0005434067677	30688	Economy	13400.00
0005434067699	30688	Economy	13400.00
0005433989779	30688	Economy	13400.00
0005432150213	30688	Economy	13400.00
0005434067714	30688	Economy	13400.00
0005434067718	30688	Economy	13400.00
0005434067695	30688	Economy	13400.00
0005432150208	30688	Economy	13400.00
0005434067736	30688	Economy	13400.00
0005434067694	30688	Economy	13400.00
0005434067698	30688	Economy	13400.00
0005434067711	30688	Economy	13400.00
0005434081937	30688	Economy	13400.00
0005432186877	30688	Economy	13400.00
0005434067692	30688	Economy	13400.00
0005434067682	30688	Economy	13400.00
0005434081932	30688	Economy	13400.00
0005434067706	30688	Economy	13400.00
0005434067721	30688	Economy	14800.00
0005433989778	30688	Economy	14800.00
0005434067733	30688	Economy	14800.00
0005432150212	30688	Economy	14800.00
0005434067737	30688	Economy	14800.00
0005432433648	30688	Economy	13400.00
0005434067688	30688	Economy	14800.00
0005434067680	30688	Economy	13400.00
0005434067702	30688	Economy	13400.00
0005434067678	30688	Economy	13400.00
0005434067746	30688	Economy	13400.00
0005434067704	30688	Economy	13400.00
0005434067700	30688	Economy	13400.00
0005434067723	30688	Economy	13400.00
0005434067681	30688	Economy	13400.00
0005434081946	30688	Economy	13400.00
0005432186878	30688	Economy	13400.00
0005434067725	30688	Economy	13400.00
0005434081942	30688	Economy	13400.00
0005434081945	30688	Economy	13400.00
0005434067717	30688	Economy	13400.00
0005434067687	30688	Economy	13400.00
0005432186880	30688	Economy	13400.00
0005434081953	30688	Economy	13400.00
0005432150207	30688	Economy	13400.00
0005434081952	30688	Economy	13400.00
0005434067732	30688	Economy	13400.00
0005434067728	30688	Economy	13400.00
0005434067738	30688	Economy	13400.00
0005434081934	30688	Economy	13400.00
0005432433650	30688	Economy	13400.00
0005434067739	30688	Economy	13400.00
0005434067690	30688	Economy	13400.00
0005434081938	30688	Economy	13400.00
0005434067713	30688	Economy	13400.00
0005434067684	30688	Economy	13400.00
0005434067708	30688	Economy	13400.00
0005434081947	30688	Economy	13400.00
0005434081930	30688	Economy	13400.00
0005434067722	30688	Economy	13400.00
0005432150214	30688	Economy	13400.00
0005434067730	30688	Economy	13400.00
0005434067701	30688	Economy	13400.00
0005434081939	30688	Economy	13400.00
0005432150211	30688	Economy	13400.00
0005434067703	30688	Economy	13400.00
0005433989780	30688	Economy	13400.00
0005434081950	30688	Economy	13400.00
0005434067689	30688	Economy	13400.00
0005434067724	30688	Economy	13400.00
0005434067735	30688	Economy	13400.00
0005434081951	30688	Economy	13400.00
0005433989781	30688	Economy	13400.00
0005432433652	30688	Economy	13400.00
0005432150210	30688	Economy	13400.00
0005432433651	30688	Economy	13400.00
0005434081941	30688	Economy	13400.00
0005434067693	30688	Economy	13400.00
0005434067743	30688	Economy	13400.00
0005432186879	30688	Economy	13400.00
0005434067740	30688	Economy	13400.00
0005434067742	30688	Economy	13400.00
0005432433660	30688	Economy	13400.00
0005434081935	30688	Economy	13400.00
0005434067705	30688	Economy	13400.00
0005434081936	30688	Economy	13400.00
0005434067744	30688	Economy	13400.00
0005432433661	30688	Economy	13400.00
0005434067710	30688	Economy	13400.00
0005432433657	30688	Economy	13400.00
0005434067696	30688	Economy	13400.00
0005434067727	30688	Economy	13400.00
0005434067726	30688	Economy	13400.00
0005432186876	30688	Economy	13400.00
0005433685532	9034	Economy	19300.00
0005433685534	9034	Economy	17600.00
0005433687713	9034	Economy	17600.00
0005433687716	9034	Economy	17600.00
0005433685533	9034	Economy	17600.00
0005433687715	9034	Economy	17600.00
0005433687714	9034	Economy	17600.00
0005433687717	9034	Economy	17600.00
0005433686644	9034	Economy	17600.00
0005433685529	9034	Economy	17600.00
0005433686646	9034	Economy	17600.00
0005433685535	9034	Economy	17600.00
0005433685530	9034	Economy	17600.00
0005433686641	9034	Economy	17600.00
0005433686642	9034	Economy	17600.00
0005433685531	9034	Economy	17600.00
0005433686643	9034	Economy	17600.00
0005433687718	9034	Economy	17600.00
0005433686645	9034	Economy	17600.00
0005434831133	5521	Business	35300.00
0005435766360	5521	Business	35300.00
0005435766392	5521	Business	35300.00
0005435725612	5521	Business	35300.00
0005434264927	5521	Business	35300.00
0005435462321	5521	Business	35300.00
0005434265000	5521	Business	35300.00
0005435462331	5521	Business	35300.00
0005435462236	5521	Business	35300.00
0005434264965	5521	Business	35300.00
0005435723052	5521	Business	35300.00
0005435462104	5521	Business	35300.00
0005435462333	5521	Business	35300.00
0005435462271	5521	Business	35300.00
0005435766408	5521	Business	35300.00
0005435735146	5521	Business	35300.00
0005435766374	5521	Business	35300.00
0005435766416	5521	Business	35300.00
0005435462392	5521	Business	35300.00
0005435766410	5521	Business	35300.00
0005435766417	5521	Business	35300.00
0005435766365	5521	Business	35300.00
0005435462351	5521	Business	35300.00
0005434264938	5521	Business	35300.00
0005435766397	5521	Business	35300.00
0005434265001	5521	Economy	12900.00
0005435462106	5521	Economy	12900.00
0005435766399	5521	Economy	12900.00
0005434831114	5521	Economy	12900.00
0005435766398	5521	Economy	11800.00
0005434831093	5521	Economy	11800.00
0005433529291	5521	Economy	11800.00
0005435766420	5521	Economy	11800.00
0005432140470	5521	Economy	11800.00
0005435462184	5521	Economy	11800.00
0005435462159	5521	Economy	11800.00
0005435462115	5521	Economy	11800.00
0005435462133	5521	Economy	11800.00
0005435723051	5521	Economy	11800.00
0005434265086	5521	Economy	11800.00
0005434264937	5521	Economy	11800.00
0005435766418	5521	Economy	11800.00
0005435766388	5521	Economy	11800.00
0005434264962	5521	Economy	11800.00
0005432140468	5521	Economy	11800.00
0005433527281	5521	Economy	11800.00
0005434264896	5521	Economy	11800.00
0005435462398	5521	Economy	11800.00
0005434264895	5521	Economy	11800.00
0005433529290	5521	Economy	11800.00
0005435766404	5521	Economy	11800.00
0005433527280	5521	Economy	11800.00
0005432140473	5521	Economy	11800.00
0005434264933	5521	Economy	11800.00
0005435766413	5521	Economy	11800.00
0005435462285	5521	Economy	11800.00
0005435462145	5521	Economy	11800.00
0005435462146	5521	Economy	11800.00
0005435735145	5521	Economy	11800.00
0005434264961	5521	Economy	11800.00
0005435766426	5521	Economy	11800.00
0005435766396	5521	Economy	11800.00
0005434265003	5521	Economy	11800.00
0005435766395	5521	Economy	11800.00
0005435720825	5521	Economy	11800.00
0005434264963	5521	Economy	11800.00
0005433527279	5521	Economy	11800.00
0005435766379	5521	Economy	11800.00
0005435766382	5521	Economy	11800.00
0005435766364	5521	Economy	11800.00
0005432535798	5521	Economy	11800.00
0005435766384	5521	Economy	11800.00
0005434264953	5521	Economy	11800.00
0005432535781	5521	Economy	11800.00
0005435766376	5521	Economy	11800.00
0005434264928	5521	Economy	11800.00
0005435766366	5521	Economy	11800.00
0005435766375	5521	Economy	11800.00
0005435462276	5521	Economy	11800.00
0005435766386	5521	Economy	11800.00
0005434264894	5521	Economy	11800.00
0005435462397	5521	Economy	11800.00
0005435462056	5521	Economy	11800.00
0005435766385	5521	Economy	11800.00
0005435766394	5521	Economy	11800.00
0005435723050	5521	Economy	11800.00
0005435043281	5521	Economy	11800.00
0005435766393	5521	Economy	11800.00
0005435766373	5521	Economy	11800.00
0005434265040	5521	Economy	11800.00
0005435766424	5521	Economy	11800.00
0005435462352	5521	Economy	11800.00
0005435766419	5521	Economy	11800.00
0005434264936	5521	Economy	11800.00
0005434265039	5521	Economy	11800.00
0005435766412	5521	Economy	11800.00
0005434831097	5521	Economy	11800.00
0005435766378	5521	Economy	11800.00
0005435766405	5521	Economy	11800.00
0005435462270	5521	Economy	11800.00
0005432140471	5521	Economy	11800.00
0005434264985	5521	Economy	11800.00
0005435725610	5521	Economy	11800.00
0005435766387	5521	Economy	11800.00
0005432535782	5521	Economy	11800.00
0005435462322	5521	Economy	11800.00
0005435766401	5521	Economy	11800.00
0005433527277	5521	Economy	11800.00
0005435766422	5521	Economy	11800.00
0005435766403	5521	Economy	11800.00
0005435462308	5521	Economy	12900.00
0005433527278	5521	Economy	11800.00
0005435462141	5521	Economy	11800.00
0005435735147	5521	Economy	11800.00
0005435766377	5521	Economy	12900.00
0005434265004	5521	Economy	11800.00
0005435462304	5521	Economy	11800.00
0005435766423	5521	Economy	11800.00
0005434264984	5521	Economy	11800.00
0005435766381	5521	Economy	11800.00
0005435766402	5521	Economy	11800.00
0005435766383	5521	Economy	11800.00
0005435462309	5521	Economy	11800.00
0005432140467	5521	Economy	11800.00
0005435462158	5521	Economy	11800.00
0005434831116	5521	Economy	11800.00
0005435766406	5521	Economy	11800.00
0005435722062	5521	Economy	11800.00
0005435766400	5521	Economy	11800.00
0005435462391	5521	Economy	11800.00
0005435462330	5521	Economy	11800.00
0005435462142	5521	Economy	11800.00
0005432140474	5521	Economy	11800.00
0005435766368	5521	Economy	11800.00
0005435766414	5521	Economy	11800.00
0005435766369	5521	Economy	11800.00
0005434264876	5521	Economy	11800.00
0005435766409	5521	Economy	11800.00
0005435462305	5521	Economy	11800.00
0005435462105	5521	Economy	11800.00
0005434264935	5521	Economy	11800.00
0005435766361	5521	Economy	11800.00
0005434264929	5521	Economy	11800.00
0005434264954	5521	Economy	11800.00
0005434265002	5521	Economy	11800.00
0005435766415	5521	Economy	11800.00
0005435766407	5521	Economy	11800.00
0005432140472	5521	Economy	11800.00
0005435766362	5521	Economy	11800.00
0005432535813	5521	Economy	11800.00
0005432535795	5521	Economy	11800.00
0005435462399	5521	Economy	11800.00
0005432140475	5521	Economy	11800.00
0005435462310	5521	Economy	11800.00
0005435766371	5521	Economy	11800.00
0005435725613	5521	Economy	11800.00
0005435766389	5521	Economy	11800.00
0005434265017	5521	Economy	11800.00
0005435766391	5521	Economy	11800.00
0005435766411	5521	Economy	11800.00
0005435462134	5521	Economy	11800.00
0005435462247	5521	Economy	11800.00
0005435043278	5521	Economy	11800.00
0005432535783	5521	Economy	11800.00
0005435725609	5521	Economy	11800.00
0005432140469	5521	Economy	11800.00
0005434264911	5521	Economy	11800.00
0005435766367	5521	Economy	11800.00
0005435462114	5521	Economy	11800.00
0005435725611	5521	Economy	11800.00
0005435766370	5521	Economy	11800.00
0005435766380	5521	Economy	11800.00
0005435766390	5521	Economy	11800.00
0005435766372	5521	Economy	11800.00
0005435735144	5521	Economy	11800.00
0005435766363	5521	Economy	11800.00
0005435766421	5521	Economy	11800.00
0005435766425	5521	Economy	11800.00
0005434265210	13448	Business	35300.00
0005435765888	13448	Business	35300.00
0005435765957	13448	Business	35300.00
0005435462561	13448	Business	35300.00
0005435765605	13448	Business	35300.00
0005432194524	13448	Business	35300.00
0005434265217	13448	Business	35300.00
0005435765976	13448	Business	35300.00
0005435462532	13448	Business	35300.00
0005432535846	13448	Business	35300.00
0005435462557	13448	Business	35300.00
0005435765807	13448	Business	35300.00
0005434265222	13448	Business	35300.00
0005435765906	13448	Business	35300.00
0005432535848	13448	Business	35300.00
0005434265226	13448	Business	35300.00
0005435462529	13448	Business	35300.00
0005435735114	13448	Economy	12900.00
0005435765818	13448	Economy	12900.00
0005435462540	13448	Economy	11800.00
0005434265214	13448	Economy	11800.00
0005434265208	13448	Economy	11800.00
0005432194522	13448	Economy	11800.00
0005434265221	13448	Economy	11800.00
0005435462545	13448	Economy	11800.00
0005435765847	13448	Economy	11800.00
0005435765788	13448	Economy	11800.00
0005435462555	13448	Economy	11800.00
0005435765758	13448	Economy	11800.00
0005435765820	13448	Economy	11800.00
0005435462556	13448	Economy	11800.00
0005435765879	13448	Economy	11800.00
0005435765939	13448	Economy	11800.00
0005435765808	13448	Economy	11800.00
0005434265220	13448	Economy	11800.00
0005434265218	13448	Economy	11800.00
0005435735100	13448	Economy	11800.00
0005434831167	13448	Economy	11800.00
0005435765420	13448	Economy	11800.00
0005434265212	13448	Economy	11800.00
0005435765771	13448	Economy	11800.00
0005435735125	13448	Economy	11800.00
0005435462553	13448	Economy	11800.00
0005435462536	13448	Economy	11800.00
0005435735116	13448	Economy	11800.00
0005435462530	13448	Economy	11800.00
0005435462549	13448	Economy	11800.00
0005435765886	13448	Economy	11800.00
0005435765772	13448	Economy	11800.00
0005435462558	13448	Economy	11800.00
0005435462560	13448	Economy	11800.00
0005435765913	13448	Economy	11800.00
0005435462541	13448	Economy	11800.00
0005435765800	13448	Economy	11800.00
0005432535849	13448	Economy	11800.00
0005435765730	13448	Economy	11800.00
0005435765419	13448	Economy	11800.00
0005435735120	13448	Economy	11800.00
0005435462550	13448	Economy	11800.00
0005435765908	13448	Economy	11800.00
0005435462537	13448	Economy	11800.00
0005435765709	13448	Economy	11800.00
0005435765705	13448	Economy	11800.00
0005434831163	13448	Economy	11800.00
0005435462533	13448	Economy	11800.00
0005432535850	13448	Economy	11800.00
0005435462546	13448	Economy	11800.00
0005435462565	13448	Economy	11800.00
0005435765609	13448	Economy	11800.00
0005434265227	13448	Economy	11800.00
0005435725594	13448	Economy	11800.00
0005434265215	13448	Economy	11800.00
0005435765769	13448	Economy	11800.00
0005432194521	13448	Economy	11800.00
0005435765765	13448	Economy	11800.00
0005435462568	13448	Economy	11800.00
0005435765941	13448	Economy	11800.00
0005435765878	13448	Economy	11800.00
0005435462554	13448	Economy	11800.00
0005435765701	13448	Economy	11800.00
0005435765927	13448	Economy	11800.00
0005434265213	13448	Economy	11800.00
0005435735115	13448	Economy	11800.00
0005435765831	13448	Economy	11800.00
0005434265219	13448	Economy	12900.00
0005432535847	13448	Economy	12900.00
0005435765912	13448	Economy	11800.00
0005434831166	13448	Economy	12900.00
0005435462567	13448	Economy	11800.00
0005435462539	13448	Economy	11800.00
0005434265229	13448	Economy	11800.00
0005434831165	13448	Economy	11800.00
0005435765935	13448	Economy	11800.00
0005435765938	13448	Economy	11800.00
0005435765757	13448	Economy	11800.00
0005434265228	13448	Economy	11800.00
0005435462535	13448	Economy	11800.00
0005434265225	13448	Economy	11800.00
0005435720128	13448	Economy	11800.00
0005435462544	13448	Economy	11800.00
0005435462542	13448	Economy	11800.00
0005435462538	13448	Economy	11800.00
0005435462563	13448	Economy	11800.00
0005435765762	13448	Economy	11800.00
0005435765794	13448	Economy	11800.00
0005432194523	13448	Economy	11800.00
0005434265205	13448	Economy	11800.00
0005435765880	13448	Economy	11800.00
0005435765911	13448	Economy	11800.00
0005435765970	13448	Economy	11800.00
0005435765764	13448	Economy	11800.00
0005435765846	13448	Economy	11800.00
0005434265216	13448	Economy	11800.00
0005435722043	13448	Economy	11800.00
0005435765934	13448	Economy	11800.00
0005434265224	13448	Economy	11800.00
0005435462552	13448	Economy	11800.00
0005435462562	13448	Economy	11800.00
0005435765662	13448	Economy	11800.00
0005435462551	13448	Economy	11800.00
0005435765686	13448	Economy	11800.00
0005435462566	13448	Economy	11800.00
0005435462534	13448	Economy	11800.00
0005435462547	13448	Economy	11800.00
0005435765843	13448	Economy	11800.00
0005435765928	13448	Economy	11800.00
0005435462543	13448	Economy	11800.00
0005435765632	13448	Economy	11800.00
0005435462531	13448	Economy	11800.00
0005434265211	13448	Economy	11800.00
0005434265206	13448	Economy	11800.00
0005435765819	13448	Economy	11800.00
0005434831164	13448	Economy	11800.00
0005435765806	13448	Economy	11800.00
0005435765833	13448	Economy	11800.00
0005434265204	13448	Economy	11800.00
0005435765747	13448	Economy	11800.00
0005435462564	13448	Economy	11800.00
0005434265223	13448	Economy	11800.00
0005434265207	13448	Economy	11800.00
0005435765776	13448	Economy	11800.00
0005435462548	13448	Economy	11800.00
0005434265209	13448	Economy	11800.00
0005435735092	13448	Economy	11800.00
0005435765552	13448	Economy	11800.00
0005435462559	13448	Economy	11800.00
0005434602886	18682	Economy	3300.00
0005434513586	18684	Economy	3300.00
0005434604851	18684	Economy	3300.00
0005434604865	18684	Economy	3300.00
0005434604852	18684	Economy	3300.00
0005434604866	18684	Economy	3300.00
0005434513587	18684	Economy	3300.00
0005434513584	18684	Economy	3300.00
0005434514974	18684	Economy	3300.00
0005434513585	18684	Economy	3300.00
0005434604867	18684	Economy	3300.00
0005434514972	18684	Economy	3300.00
0005434514973	18684	Economy	3300.00
0005434514945	19192	Economy	3300.00
0005434514949	19192	Economy	3300.00
0005432649424	4119	Business	88300.00
0005432649419	4119	Business	88300.00
0005432649421	4119	Business	88300.00
0005432649422	4119	Business	88300.00
0005435844306	4119	Economy	29400.00
0005432632767	4119	Economy	29400.00
0005432632755	4119	Economy	29400.00
0005432649415	4119	Economy	29400.00
0005432649423	4119	Economy	32400.00
0005435846223	4119	Economy	29400.00
0005435846224	4119	Economy	29400.00
0005435844295	4119	Economy	29400.00
0005432632766	4119	Economy	29400.00
0005432649425	4119	Economy	29400.00
0005435844297	4119	Economy	29400.00
0005432649426	4119	Economy	29400.00
0005432632764	4119	Economy	29400.00
0005432632758	4119	Economy	29400.00
0005435844296	4119	Economy	29400.00
0005432632760	4119	Economy	29400.00
0005432649417	4119	Economy	29400.00
0005432649418	4119	Economy	29400.00
0005432649420	4119	Economy	29400.00
0005432632763	4119	Economy	29400.00
0005432632765	4119	Economy	29400.00
0005435846203	4119	Economy	29400.00
0005432632756	4119	Economy	29400.00
0005435844299	4119	Economy	29400.00
0005432649414	4119	Economy	29400.00
0005435846220	4119	Economy	29400.00
0005432632761	4119	Economy	29400.00
0005435844298	4119	Economy	29400.00
0005432632762	4119	Economy	29400.00
0005435844291	4119	Economy	29400.00
0005432632757	4119	Economy	29400.00
0005432649416	4119	Economy	29400.00
0005432632759	4119	Economy	29400.00
0005433284990	1857	Business	48700.00
0005433285167	1857	Business	48700.00
0005433810566	1857	Business	48700.00
0005433285119	1857	Business	48700.00
0005432295887	1857	Business	48700.00
0005433008309	1857	Business	48700.00
0005433284989	1857	Business	48700.00
0005433285191	1857	Business	48700.00
0005433008460	1857	Business	48700.00
0005433285026	1857	Business	48700.00
0005433008506	1857	Business	48700.00
0005433008287	1857	Economy	16200.00
0005433285103	1857	Economy	16200.00
0005433284965	1857	Economy	16200.00
0005433285155	1857	Economy	16200.00
0005433008178	1857	Economy	16200.00
0005433008355	1857	Economy	16200.00
0005433285028	1857	Economy	16200.00
0005433285200	1857	Economy	16200.00
0005433008308	1857	Economy	16200.00
0005433008512	1857	Economy	16200.00
0005433285185	1857	Economy	17900.00
0005433285081	1857	Economy	17900.00
0005433285055	1857	Economy	17900.00
0005433285053	1857	Economy	17900.00
0005433008505	1857	Economy	17900.00
0005433008464	1857	Economy	16200.00
0005433285054	1857	Economy	16200.00
0005433008490	1857	Economy	16200.00
0005433008194	1857	Economy	16200.00
0005433008435	1857	Economy	16200.00
0005433285105	1857	Economy	16200.00
0005433008457	1857	Economy	16200.00
0005433008440	1857	Economy	16200.00
0005433008491	1857	Economy	16200.00
0005433285190	1857	Economy	16200.00
0005433008314	1857	Economy	16200.00
0005433285089	1857	Economy	16200.00
0005433008370	1857	Economy	16200.00
0005433008507	1857	Economy	16200.00
0005433008513	1857	Economy	16200.00
0005433008438	1857	Economy	16200.00
0005433008216	1857	Economy	16200.00
0005433008286	1857	Economy	16200.00
0005433285182	1857	Economy	16200.00
0005433008494	1857	Economy	16200.00
0005433008148	1857	Economy	16200.00
0005433008333	1857	Economy	16200.00
0005433008302	1857	Economy	16200.00
0005433008437	1857	Economy	16200.00
0005433285134	1857	Economy	16200.00
0005433008371	1857	Economy	16200.00
0005433008341	1857	Economy	16200.00
0005432295888	1857	Economy	16200.00
0005433285097	1857	Economy	16200.00
0005433008429	1857	Economy	16200.00
0005433285052	1857	Economy	16200.00
0005433285239	1857	Economy	16200.00
0005433008439	1857	Economy	16200.00
0005433008500	1857	Economy	16200.00
0005433008367	1857	Economy	16200.00
0005433008263	1857	Economy	16200.00
0005433285198	1857	Economy	16200.00
0005433008366	1857	Economy	16200.00
0005433008504	1857	Economy	16200.00
0005433008324	1857	Economy	16200.00
0005433285128	1857	Economy	16200.00
0005433008257	1857	Economy	16200.00
0005433008436	1857	Economy	16200.00
0005433285066	1857	Economy	16200.00
0005433008469	1857	Economy	16200.00
0005433285183	1857	Economy	16200.00
0005433008480	1857	Economy	16200.00
0005433285184	1857	Economy	16200.00
0005433008503	1857	Economy	16200.00
0005433008492	1857	Economy	16200.00
0005433285237	1857	Economy	16200.00
0005433285181	1857	Economy	16200.00
0005433008519	1857	Economy	16200.00
0005433285135	1857	Economy	16200.00
0005433008340	1857	Economy	16200.00
0005433285042	1857	Economy	16200.00
0005433285088	1857	Economy	16200.00
0005433285104	1857	Economy	16200.00
0005433285168	1857	Economy	16200.00
0005433285136	1857	Economy	16200.00
0005433008342	1857	Economy	16200.00
0005433008149	1857	Economy	16200.00
0005433285359	22520	Business	48700.00
0005433008727	22520	Business	48700.00
0005433008708	22520	Business	48700.00
0005433008747	22520	Business	48700.00
0005433285370	22520	Business	48700.00
0005433285377	22520	Business	48700.00
0005433008734	22520	Business	48700.00
0005433008737	22520	Business	48700.00
0005433008718	22520	Business	48700.00
0005433008719	22520	Business	48700.00
0005433008723	22520	Business	48700.00
0005433285363	22520	Economy	16200.00
0005433008726	22520	Economy	16200.00
0005433285391	22520	Economy	16200.00
0005433008746	22520	Economy	16200.00
0005433008722	22520	Economy	16200.00
0005433285390	22520	Economy	16200.00
0005433008739	22520	Economy	16200.00
0005433008721	22520	Economy	16200.00
0005433008728	22520	Economy	17900.00
0005433008715	22520	Economy	17900.00
0005433008712	22520	Economy	17900.00
0005433285367	22520	Economy	17900.00
0005433810511	22520	Economy	17900.00
0005433285378	22520	Economy	16200.00
0005433285384	22520	Economy	16200.00
0005433285366	22520	Economy	16200.00
0005433810497	22520	Economy	16200.00
0005433008706	22520	Economy	16200.00
0005433285382	22520	Economy	16200.00
0005433285371	22520	Economy	16200.00
0005433008703	22520	Economy	16200.00
0005433810510	22520	Economy	16200.00
0005433008738	22520	Economy	16200.00
0005433810509	22520	Economy	16200.00
0005433008749	22520	Economy	16200.00
0005433008743	22520	Economy	16200.00
0005433008731	22520	Economy	16200.00
0005433008729	22520	Economy	16200.00
0005433285362	22520	Economy	16200.00
0005433285385	22520	Economy	16200.00
0005433008720	22520	Economy	16200.00
0005433285389	22520	Economy	16200.00
0005433285379	22520	Economy	16200.00
0005433008745	22520	Economy	16200.00
0005433285361	22520	Economy	16200.00
0005433008707	22520	Economy	16200.00
0005433008713	22520	Economy	16200.00
0005433008741	22520	Economy	16200.00
0005433285373	22520	Economy	16200.00
0005433285376	22520	Economy	16200.00
0005433810498	22520	Economy	16200.00
0005433285374	22520	Economy	16200.00
0005433285387	22520	Economy	16200.00
0005433285364	22520	Economy	16200.00
0005433285388	22520	Economy	16200.00
0005433008732	22520	Economy	16200.00
0005433810508	22520	Economy	16200.00
0005433285375	22520	Economy	16200.00
0005433285365	22520	Economy	16200.00
0005433008744	22520	Economy	16200.00
0005433008704	22520	Economy	16200.00
0005433008736	22520	Economy	16200.00
0005433008724	22520	Economy	16200.00
0005433285369	22520	Economy	16200.00
0005433008735	22520	Economy	16200.00
0005433008733	22520	Economy	16200.00
0005433008742	22520	Economy	16200.00
0005433285386	22520	Economy	16200.00
0005433008705	22520	Economy	16200.00
0005433285360	22520	Economy	16200.00
0005433285372	22520	Economy	16200.00
0005433285380	22520	Economy	16200.00
0005433008709	22520	Economy	16200.00
0005433008717	22520	Economy	16200.00
0005433008716	22520	Economy	16200.00
0005433008740	22520	Economy	16200.00
0005433008710	22520	Economy	16200.00
0005433285368	22520	Economy	16200.00
0005433008711	22520	Economy	16200.00
0005433008730	22520	Economy	16200.00
0005433285383	22520	Economy	16200.00
0005433285381	22520	Economy	16200.00
0005433008725	22520	Economy	16200.00
0005433008748	22520	Economy	16200.00
0005433008714	22520	Economy	16200.00
0005432751489	12282	Business	83800.00
0005432755042	12282	Business	83800.00
0005432755058	12282	Business	83800.00
0005434152783	12282	Economy	27900.00
0005432751490	12282	Economy	27900.00
0005434152791	12282	Economy	27900.00
0005434152790	12282	Economy	27900.00
0005432755057	12282	Economy	27900.00
0005434152782	12282	Economy	27900.00
0005434152792	12282	Economy	30700.00
0005432751488	12282	Economy	27900.00
0005432751497	12282	Economy	27900.00
0005432755046	12282	Economy	27900.00
0005432751501	12282	Economy	27900.00
0005432755041	12282	Economy	27900.00
0005432751500	12282	Economy	27900.00
0005432755037	12282	Economy	27900.00
0005434152789	12282	Economy	27900.00
0005432751499	12282	Economy	27900.00
0005432751515	12282	Economy	27900.00
0005432755039	12282	Economy	27900.00
0005434152787	12282	Economy	27900.00
0005434152784	12282	Economy	27900.00
0005432755040	12282	Economy	27900.00
0005432755063	12282	Economy	27900.00
0005434152788	12282	Economy	27900.00
0005432755048	12282	Economy	27900.00
0005432751491	12282	Economy	27900.00
0005432751496	12282	Economy	27900.00
0005434152786	12282	Economy	27900.00
0005432755062	12282	Economy	27900.00
0005432755029	12282	Economy	27900.00
0005432755045	12282	Economy	27900.00
0005434152785	12282	Economy	27900.00
0005433846900	5565	Business	99800.00
0005432081530	5565	Business	99800.00
0005433846883	5565	Business	99800.00
0005433815399	5565	Business	99800.00
0005435282418	5565	Business	99800.00
0005433846863	5565	Business	99800.00
0005433846903	5565	Business	99800.00
0005433846865	5565	Business	99800.00
0005433846875	5565	Business	99800.00
0005433846891	5565	Business	99800.00
0005433846879	5565	Business	99800.00
0005433846884	5565	Business	99800.00
0005433846889	5565	Business	99800.00
0005433846861	5565	Business	99800.00
0005433846893	5565	Business	99800.00
0005435282379	5565	Business	99800.00
0005433815396	5565	Business	99800.00
0005433846899	5565	Business	99800.00
0005433846908	5565	Business	99800.00
0005432081531	5565	Business	99800.00
0005434173492	5565	Economy	33300.00
0005435282380	5565	Economy	33300.00
0005433846892	5565	Economy	33300.00
0005433846905	5565	Economy	33300.00
0005433846915	5565	Economy	33300.00
0005433846902	5565	Economy	33300.00
0005435282316	5565	Economy	33300.00
0005435282287	5565	Economy	33300.00
0005434173495	5565	Economy	33300.00
0005435282311	5565	Economy	33300.00
0005432081527	5565	Economy	36600.00
0005433846867	5565	Economy	33300.00
0005433846906	5565	Economy	36600.00
0005433846868	5565	Economy	36600.00
0005434173475	5565	Economy	36600.00
0005433846909	5565	Economy	33300.00
0005435282336	5565	Economy	33300.00
0005435282419	5565	Economy	33300.00
0005435282331	5565	Economy	33300.00
0005433846877	5565	Economy	33300.00
0005435282429	5565	Economy	33300.00
0005433846869	5565	Economy	33300.00
0005433846872	5565	Economy	33300.00
0005433846895	5565	Economy	33300.00
0005433846870	5565	Economy	33300.00
0005433846910	5565	Economy	33300.00
0005433846876	5565	Economy	33300.00
0005435282321	5565	Economy	33300.00
0005435282332	5565	Economy	33300.00
0005433846913	5565	Economy	33300.00
0005432081528	5565	Economy	33300.00
0005435282474	5565	Economy	33300.00
0005433846860	5565	Economy	33300.00
0005433846901	5565	Economy	33300.00
0005433846885	5565	Economy	33300.00
0005435282433	5565	Economy	33300.00
0005435282417	5565	Economy	33300.00
0005433846864	5565	Economy	33300.00
0005433846890	5565	Economy	33300.00
0005433846911	5565	Economy	33300.00
0005435282261	5565	Economy	33300.00
0005433846866	5565	Economy	33300.00
0005433846912	5565	Economy	33300.00
0005433846904	5565	Economy	33300.00
0005433846888	5565	Economy	33300.00
0005435282337	5565	Economy	33300.00
0005435282382	5565	Economy	33300.00
0005433846887	5565	Economy	33300.00
0005435282339	5565	Economy	33300.00
0005435282389	5565	Economy	33300.00
0005433846878	5565	Economy	33300.00
0005433846916	5565	Economy	33300.00
0005433815398	5565	Economy	33300.00
0005433846917	5565	Economy	33300.00
0005433846882	5565	Economy	33300.00
0005432081529	5565	Economy	33300.00
0005433846874	5565	Economy	33300.00
0005433846897	5565	Economy	33300.00
0005433815397	5565	Economy	33300.00
0005435282428	5565	Economy	33300.00
0005433846886	5565	Economy	33300.00
0005435282325	5565	Economy	33300.00
0005433846907	5565	Economy	33300.00
0005433846898	5565	Economy	33300.00
0005435282445	5565	Economy	33300.00
0005433846873	5565	Economy	33300.00
0005433846896	5565	Economy	33300.00
0005433846859	5565	Economy	33300.00
0005433846880	5565	Economy	33300.00
0005433846894	5565	Economy	33300.00
0005435282324	5565	Economy	33300.00
0005435282345	5565	Economy	33300.00
0005435282368	5565	Economy	33300.00
0005433846862	5565	Economy	33300.00
0005435282342	5565	Economy	33300.00
0005435282446	5565	Economy	33300.00
0005433846914	5565	Economy	33300.00
0005435282335	5565	Economy	33300.00
0005435282330	5565	Economy	33300.00
0005433846871	5565	Economy	33300.00
0005435282353	5565	Economy	33300.00
0005433846881	5565	Economy	33300.00
0005433846334	13835	Business	99800.00
0005435282584	13835	Business	99800.00
0005433846232	13835	Business	99800.00
0005433846428	13835	Business	99800.00
0005433846336	13835	Business	99800.00
0005433846326	13835	Business	99800.00
0005433846420	13835	Business	99800.00
0005435282590	13835	Business	99800.00
0005433846510	13835	Business	99800.00
0005433846451	13835	Business	99800.00
0005433846447	13835	Business	99800.00
0005433815343	13835	Business	99800.00
0005435282577	13835	Business	99800.00
0005433846749	13835	Business	99800.00
0005435282568	13835	Business	99800.00
0005433846205	13835	Economy	33300.00
0005433846136	13835	Business	99800.00
0005435282576	13835	Economy	33300.00
0005432003710	13835	Economy	33300.00
0005433846432	13835	Economy	33300.00
0005435282569	13835	Economy	33300.00
0005434173531	13835	Economy	33300.00
0005435282564	13835	Economy	33300.00
0005433815359	13835	Economy	36600.00
0005435282572	13835	Economy	36600.00
0005433846233	13835	Economy	36600.00
0005433846365	13835	Economy	33300.00
0005435282586	13835	Economy	33300.00
0005433846613	13835	Economy	33300.00
0005433846446	13835	Economy	33300.00
0005433846616	13835	Economy	33300.00
0005435282589	13835	Economy	33300.00
0005435282578	13835	Economy	33300.00
0005433846277	13835	Economy	33300.00
0005433846364	13835	Economy	33300.00
0005433815375	13835	Economy	33300.00
0005433846357	13835	Economy	33300.00
0005435282574	13835	Economy	33300.00
0005433846356	13835	Economy	33300.00
0005435282591	13835	Economy	33300.00
0005433846483	13835	Economy	33300.00
0005435282570	13835	Economy	33300.00
0005435282567	13835	Economy	33300.00
0005435282571	13835	Economy	33300.00
0005435282575	13835	Economy	33300.00
0005435282583	13835	Economy	33300.00
0005433846614	13835	Economy	33300.00
0005435282582	13835	Economy	33300.00
0005433846481	13835	Economy	33300.00
0005435282565	13835	Economy	33300.00
0005433846297	13835	Economy	33300.00
0005433846076	13835	Economy	33300.00
0005433846380	13835	Economy	33300.00
0005435282587	13835	Economy	33300.00
0005433815360	13835	Economy	33300.00
0005433846721	13835	Economy	33300.00
0005432003709	13835	Economy	33300.00
0005433815342	13835	Economy	33300.00
0005435282580	13835	Economy	33300.00
0005433846075	13835	Economy	33300.00
0005433846657	13835	Economy	33300.00
0005433846507	13835	Economy	33300.00
0005433846204	13835	Economy	33300.00
0005435282573	13835	Economy	33300.00
0005434173532	13835	Economy	33300.00
0005435282579	13835	Economy	33300.00
0005432003711	13835	Economy	33300.00
0005435282566	13835	Economy	33300.00
0005435282585	13835	Economy	33300.00
0005435282588	13835	Economy	33300.00
0005433846612	13835	Economy	33300.00
0005433815348	13835	Economy	33300.00
0005433846529	13835	Economy	33300.00
0005435282581	13835	Economy	33300.00
0005433846385	13835	Economy	33300.00
0005433846418	13835	Economy	33300.00
0005434173533	13835	Economy	33300.00
0005433846333	13835	Economy	33300.00
0005433846433	13835	Economy	33300.00
0005435332338	7802	Economy	16600.00
0005435332327	7802	Economy	16600.00
0005434620646	7802	Economy	16600.00
0005434620644	7802	Economy	16600.00
0005434620656	7802	Economy	15100.00
0005432112523	7802	Economy	15100.00
0005432112521	7802	Economy	15100.00
0005434620662	7802	Economy	15100.00
0005434620650	7802	Economy	15100.00
0005434620660	7802	Economy	15100.00
0005434620652	7802	Economy	15100.00
0005434620658	7802	Economy	15100.00
0005435332326	7802	Economy	15100.00
0005432112522	7802	Economy	15100.00
0005434620643	7802	Economy	15100.00
0005432112524	7802	Economy	15100.00
0005435332337	7802	Economy	15100.00
0005435332264	7802	Economy	15100.00
0005434620654	7802	Economy	15100.00
0005434620653	7802	Economy	15100.00
0005434620659	7802	Economy	15100.00
0005434620649	7802	Economy	15100.00
0005435332265	7802	Economy	15100.00
0005434620663	7802	Economy	15100.00
0005434620651	7802	Economy	15100.00
0005434620657	7802	Economy	15100.00
0005434620661	7802	Economy	15100.00
0005435332255	7802	Economy	15100.00
0005434620655	7802	Economy	15100.00
0005434620648	7802	Economy	15100.00
0005434620647	7802	Economy	15100.00
0005434620645	7802	Economy	15100.00
0005434620419	32969	Economy	16600.00
0005435332366	32969	Economy	16600.00
0005435332359	32969	Economy	16600.00
0005434620505	32969	Economy	16600.00
0005435332365	32969	Economy	15100.00
0005435332364	32969	Economy	15100.00
0005435332363	32969	Economy	15100.00
0005435332369	32969	Economy	15100.00
0005434620506	32969	Economy	15100.00
0005435332362	32969	Economy	15100.00
0005434620452	32969	Economy	15100.00
0005434620487	32969	Economy	15100.00
0005434620392	32969	Economy	15100.00
0005434620455	32969	Economy	15100.00
0005434620454	32969	Economy	15100.00
0005434620391	32969	Economy	15100.00
0005434620339	32969	Economy	15100.00
0005434620463	32969	Economy	15100.00
0005434620491	32969	Economy	15100.00
0005434620490	32969	Economy	15100.00
0005434620504	32969	Economy	15100.00
0005434620512	32969	Economy	15100.00
0005435332361	32969	Economy	15100.00
0005434620427	32969	Economy	15100.00
0005435332367	32969	Economy	15100.00
0005434620340	32969	Economy	15100.00
0005435332368	32969	Economy	15100.00
0005434620466	32969	Economy	15100.00
0005435332360	32969	Economy	15100.00
0005434620562	32969	Economy	15100.00
0005434620557	32969	Economy	15100.00
0005434620449	32969	Economy	15100.00
0005434620338	32969	Economy	15100.00
0005434620420	32969	Economy	15100.00
0005435785441	4276	Business	38000.00
0005435918646	4276	Business	38000.00
0005434994050	4276	Business	38000.00
0005435785438	4276	Business	38000.00
0005434994051	4276	Business	38000.00
0005435785453	4276	Business	38000.00
0005435937351	4276	Business	38000.00
0005435785439	4276	Economy	12700.00
0005435785449	4276	Economy	12700.00
0005435785437	4276	Economy	12700.00
0005435785440	4276	Economy	12700.00
0005435785452	4276	Economy	12700.00
0005435785468	4276	Economy	12700.00
0005435785442	4276	Economy	12700.00
0005435785454	4276	Economy	13900.00
0005435785444	4276	Economy	13900.00
0005435785461	4276	Economy	13900.00
0005432190641	4276	Economy	13900.00
0005434994049	4276	Economy	12700.00
0005435785459	4276	Economy	12700.00
0005434994054	4276	Economy	12700.00
0005435785456	4276	Economy	12700.00
0005435785445	4276	Economy	12700.00
0005435785466	4276	Economy	12700.00
0005435785463	4276	Economy	12700.00
0005435937359	4276	Economy	12700.00
0005435918634	4276	Economy	12700.00
0005435785448	4276	Economy	12700.00
0005435937362	4276	Economy	12700.00
0005434994052	4276	Economy	12700.00
0005435785469	4276	Economy	12700.00
0005435785460	4276	Economy	12700.00
0005435785465	4276	Economy	12700.00
0005434994053	4276	Economy	12700.00
0005435918632	4276	Economy	12700.00
0005435785443	4276	Economy	12700.00
0005435918624	4276	Economy	12700.00
0005435785467	4276	Economy	12700.00
0005435785446	4276	Economy	12700.00
0005435785451	4276	Economy	12700.00
0005435787360	4276	Economy	12700.00
0005434994048	4276	Economy	12700.00
0005435785455	4276	Economy	12700.00
0005435785462	4276	Economy	12700.00
0005435937357	4276	Economy	12700.00
0005435785470	4276	Economy	12700.00
0005434994045	4276	Economy	12700.00
0005435785447	4276	Economy	12700.00
0005435918629	4276	Economy	12700.00
0005434994056	4276	Economy	12700.00
0005435937353	4276	Economy	12700.00
0005434994047	4276	Economy	12700.00
0005434994046	4276	Economy	12700.00
0005435785450	4276	Economy	12700.00
0005434994055	4276	Economy	12700.00
0005432190639	4276	Economy	12700.00
0005435785458	4276	Economy	12700.00
0005432190640	4276	Economy	12700.00
0005435937346	4276	Economy	12700.00
0005435785464	4276	Economy	12700.00
0005435937363	4276	Economy	12700.00
0005435785457	4276	Economy	12700.00
0005434993973	27313	Business	38000.00
0005435784979	27313	Business	38000.00
0005435937391	27313	Business	38000.00
0005435785113	27313	Business	38000.00
0005435785059	27313	Business	38000.00
0005435785216	27313	Business	38000.00
0005435785060	27313	Business	38000.00
0005435785121	27313	Economy	12700.00
0005434993951	27313	Economy	12700.00
0005435785105	27313	Economy	12700.00
0005435785109	27313	Economy	13900.00
0005435918669	27313	Economy	13900.00
0005435918670	27313	Economy	12700.00
0005435785102	27313	Economy	12700.00
0005435785202	27313	Economy	12700.00
0005435787340	27313	Economy	12700.00
0005432195697	27313	Economy	12700.00
0005435785211	27313	Economy	12700.00
0005435785098	27313	Economy	12700.00
0005435785122	27313	Economy	12700.00
0005435785244	27313	Economy	12700.00
0005435785188	27313	Economy	12700.00
0005435918668	27313	Economy	12700.00
0005435785167	27313	Economy	12700.00
0005435785201	27313	Economy	12700.00
0005435787338	27313	Economy	12700.00
0005435785110	27313	Economy	12700.00
0005435787339	27313	Economy	12700.00
0005435918671	27313	Economy	12700.00
0005435785207	27313	Economy	12700.00
0005435937392	27313	Economy	12700.00
0005435785152	27313	Economy	12700.00
0005435785210	27313	Economy	12700.00
0005435785151	27313	Economy	12700.00
0005435785031	27313	Economy	12700.00
0005434993950	27313	Economy	12700.00
0005432195698	27313	Economy	12700.00
0005435784925	27313	Economy	12700.00
0005434993941	27313	Economy	12700.00
0005435785084	27313	Economy	12700.00
0005432146204	19869	Economy	12800.00
0005432146203	19869	Economy	12800.00
0005432460013	4713	Business	40900.00
0005432460001	4713	Business	40900.00
0005432460004	4713	Business	40900.00
0005433726111	4713	Business	40900.00
0005432567812	4713	Business	40900.00
0005432170405	4713	Business	40900.00
0005434081964	4713	Business	40900.00
0005434081969	4713	Business	40900.00
0005432460014	4713	Business	40900.00
0005432567807	4713	Business	40900.00
0005432460008	4713	Business	40900.00
0005432567817	4713	Business	40900.00
0005432567802	4713	Business	40900.00
0005432567830	4713	Business	40900.00
0005434081974	4713	Business	40900.00
0005432460010	4713	Business	40900.00
0005432567777	4713	Business	40900.00
0005432567811	4713	Business	40900.00
0005434081975	4713	Business	40900.00
0005432567828	4713	Business	40900.00
0005432567798	4713	Business	40900.00
0005432460017	4713	Business	40900.00
0005432567804	4713	Economy	15000.00
0005432460002	4713	Economy	15000.00
0005432459994	4713	Economy	15000.00
0005432567813	4713	Economy	13600.00
0005433452745	4713	Economy	13600.00
0005432459986	4713	Economy	13600.00
0005432459988	4713	Economy	13600.00
0005432567819	4713	Economy	13600.00
0005435840358	4713	Economy	13600.00
0005432567801	4713	Economy	13600.00
0005434081982	4713	Economy	13600.00
0005432459975	4713	Economy	13600.00
0005432567793	4713	Economy	13600.00
0005432567816	4713	Economy	13600.00
0005434081959	4713	Economy	13600.00
0005432571331	4713	Economy	13600.00
0005432567795	4713	Economy	13600.00
0005432567800	4713	Economy	13600.00
0005432567810	4713	Economy	13600.00
0005432459977	4713	Economy	13600.00
0005432459991	4713	Economy	13600.00
0005432567829	4713	Economy	13600.00
0005432460022	4713	Economy	13600.00
0005432567835	4713	Economy	13600.00
0005432567789	4713	Economy	13600.00
0005432567827	4713	Economy	13600.00
0005432460021	4713	Economy	13600.00
0005433451624	4713	Economy	13600.00
0005434081961	4713	Economy	13600.00
0005434081983	4713	Economy	13600.00
0005432567796	4713	Economy	13600.00
0005432459996	4713	Economy	13600.00
0005434081980	4713	Economy	13600.00
0005434081960	4713	Economy	13600.00
0005432459987	4713	Economy	13600.00
0005432170406	4713	Economy	13600.00
0005433451625	4713	Economy	13600.00
0005434081977	4713	Economy	13600.00
0005432460016	4713	Economy	13600.00
0005432567825	4713	Economy	13600.00
0005432567790	4713	Economy	13600.00
0005434081979	4713	Economy	13600.00
0005432460012	4713	Economy	13600.00
0005432571332	4713	Economy	13600.00
0005434081955	4713	Economy	13600.00
0005434081958	4713	Economy	13600.00
0005432567786	4713	Economy	13600.00
0005432567832	4713	Economy	13600.00
0005432459981	4713	Economy	13600.00
0005432459984	4713	Economy	13600.00
0005432459997	4713	Economy	13600.00
0005432567824	4713	Economy	13600.00
0005432460003	4713	Economy	13600.00
0005432459998	4713	Economy	13600.00
0005432567799	4713	Economy	13600.00
0005432567797	4713	Economy	13600.00
0005434081967	4713	Economy	13600.00
0005432567837	4713	Economy	13600.00
0005432460019	4713	Economy	13600.00
0005432567808	4713	Economy	13600.00
0005432567809	4713	Economy	13600.00
0005432459973	4713	Economy	13600.00
0005432567814	4713	Economy	13600.00
0005432571333	4713	Economy	13600.00
0005432567803	4713	Economy	13600.00
0005432567784	4713	Economy	13600.00
0005434081962	4713	Economy	13600.00
0005432567779	4713	Economy	13600.00
0005432459995	4713	Economy	13600.00
0005432459993	4713	Economy	13600.00
0005434081968	4713	Economy	13600.00
0005432460020	4713	Economy	13600.00
0005432567782	4713	Economy	13600.00
0005432459985	4713	Economy	13600.00
0005434081976	4713	Economy	13600.00
0005432567833	4713	Economy	13600.00
0005432186881	4713	Economy	15000.00
0005432567838	4713	Economy	13600.00
0005432567818	4713	Economy	15000.00
0005432567806	4713	Economy	13600.00
0005432460009	4713	Economy	13600.00
0005434081970	4713	Economy	15000.00
0005432459976	4713	Economy	13600.00
0005434081973	4713	Economy	13600.00
0005432567791	4713	Economy	13600.00
0005432567820	4713	Economy	13600.00
0005432567821	4713	Economy	13600.00
0005432460023	4713	Economy	13600.00
0005432170407	4713	Economy	13600.00
0005432567823	4713	Economy	13600.00
0005433452746	4713	Economy	13600.00
0005432567785	4713	Economy	13600.00
0005432460015	4713	Economy	13600.00
0005432460011	4713	Economy	13600.00
0005432567836	4713	Economy	13600.00
0005432459999	4713	Economy	13600.00
0005432567805	4713	Economy	13600.00
0005434081966	4713	Economy	13600.00
0005432459978	4713	Economy	13600.00
0005432459983	4713	Economy	13600.00
0005432459992	4713	Economy	13600.00
0005434559098	4713	Economy	13600.00
0005432459972	4713	Economy	13600.00
0005432459989	4713	Economy	13600.00
0005432567781	4713	Economy	13600.00
0005434081978	4713	Economy	13600.00
0005434081972	4713	Economy	13600.00
0005432170404	4713	Economy	13600.00
0005434559096	4713	Economy	13600.00
0005432567778	4713	Economy	13600.00
0005434081971	4713	Economy	13600.00
0005432459974	4713	Economy	13600.00
0005432459980	4713	Economy	13600.00
0005434081956	4713	Economy	13600.00
0005432460005	4713	Economy	13600.00
0005432459990	4713	Economy	13600.00
0005432567783	4713	Economy	13600.00
0005432460018	4713	Economy	13600.00
0005432460006	4713	Economy	13600.00
0005434081957	4713	Economy	13600.00
0005432567822	4713	Economy	13600.00
0005434081965	4713	Economy	13600.00
0005432567787	4713	Economy	13600.00
0005432567826	4713	Economy	13600.00
0005432170409	4713	Economy	13600.00
0005432460024	4713	Economy	13600.00
0005432567794	4713	Economy	13600.00
0005432170408	4713	Economy	13600.00
0005432567792	4713	Economy	13600.00
0005432567834	4713	Economy	13600.00
0005434081981	4713	Economy	13600.00
0005434081954	4713	Economy	13600.00
0005432459982	4713	Economy	13600.00
0005434081963	4713	Economy	13600.00
0005434559099	4713	Economy	13600.00
0005434559097	4713	Economy	13600.00
0005432459979	4713	Economy	13600.00
0005434081984	4713	Economy	13600.00
0005432460007	4713	Economy	13600.00
0005432567831	4713	Economy	13600.00
0005432460000	4713	Economy	13600.00
0005432567815	4713	Economy	13600.00
0005432567780	4713	Economy	13600.00
0005432567788	4713	Economy	13600.00
0005432567314	30547	Business	40900.00
0005434081844	30547	Business	40900.00
0005434081767	30547	Business	40900.00
0005434081739	30547	Business	40900.00
0005432459642	30547	Business	40900.00
0005432459550	30547	Business	40900.00
0005434081881	30547	Business	40900.00
0005432567476	30547	Business	40900.00
0005432567273	30547	Business	40900.00
0005432567128	30547	Business	40900.00
0005434081738	30547	Business	40900.00
0005432567264	30547	Business	40900.00
0005432459784	30547	Business	40900.00
0005432459658	30547	Business	40900.00
0005432459683	30547	Business	40900.00
0005432567548	30547	Business	40900.00
0005432567289	30547	Business	40900.00
0005432567185	30547	Business	40900.00
0005432567156	30547	Business	40900.00
0005432567525	30547	Business	40900.00
0005434081736	30547	Business	40900.00
0005432567359	30547	Business	40900.00
0005432567625	30547	Business	40900.00
0005432567334	30547	Economy	15000.00
0005432567307	30547	Economy	15000.00
0005432459552	30547	Economy	15000.00
0005432459636	30547	Economy	13600.00
0005432567368	30547	Economy	13600.00
0005432567385	30547	Economy	13600.00
0005432459494	30547	Economy	13600.00
0005432567332	30547	Economy	13600.00
0005432567428	30547	Economy	13600.00
0005432567370	30547	Economy	13600.00
0005432567285	30547	Economy	13600.00
0005432567310	30547	Economy	13600.00
0005432459624	30547	Economy	13600.00
0005432459821	30547	Economy	13600.00
0005434559083	30547	Economy	13600.00
0005432459633	30547	Economy	13600.00
0005432567409	30547	Economy	13600.00
0005434081686	30547	Economy	13600.00
0005432567449	30547	Economy	13600.00
0005432459635	30547	Economy	13600.00
0005432459783	30547	Economy	13600.00
0005432567435	30547	Economy	13600.00
0005432459525	30547	Economy	13600.00
0005434081681	30547	Economy	13600.00
0005432459528	30547	Economy	13600.00
0005432459671	30547	Economy	13600.00
0005432567201	30547	Economy	13600.00
0005432567265	30547	Economy	13600.00
0005432567352	30547	Economy	13600.00
0005432459592	30547	Economy	13600.00
0005434081756	30547	Economy	13600.00
0005433454863	30547	Economy	13600.00
0005432567091	30547	Economy	13600.00
0005432459712	30547	Economy	13600.00
0005432459666	30547	Economy	13600.00
0005432567441	30547	Economy	13600.00
0005432459466	30547	Economy	13600.00
0005432567447	30547	Economy	13600.00
0005432213617	30547	Economy	13600.00
0005432567234	30547	Economy	13600.00
0005434081682	30547	Economy	13600.00
0005432571306	30547	Economy	13600.00
0005432567568	30547	Economy	13600.00
0005432567263	30547	Economy	13600.00
0005432567446	30547	Economy	13600.00
0005432459670	30547	Economy	13600.00
0005432571292	30547	Economy	13600.00
0005432567410	30547	Economy	13600.00
0005432161158	30547	Economy	13600.00
0005434081737	30547	Economy	13600.00
0005432567371	30547	Economy	13600.00
0005432459551	30547	Economy	13600.00
0005432567072	30547	Economy	13600.00
0005432213616	30547	Economy	13600.00
0005432567519	30547	Economy	13600.00
0005432567351	30547	Economy	13600.00
0005434559086	30547	Economy	13600.00
0005432459665	30547	Economy	13600.00
0005432213615	30547	Economy	13600.00
0005434559082	30547	Economy	13600.00
0005432571307	30547	Economy	13600.00
0005432459413	30547	Economy	13600.00
0005432567422	30547	Economy	13600.00
0005432459387	30547	Economy	13600.00
0005432567203	30547	Economy	13600.00
0005432571298	30547	Economy	13600.00
0005432567549	30547	Economy	13600.00
0005432459399	30547	Economy	13600.00
0005432459605	30547	Economy	13600.00
0005432459607	30547	Economy	13600.00
0005432567039	30547	Economy	13600.00
0005432459398	30547	Economy	13600.00
0005432459478	30547	Economy	13600.00
0005432567262	30547	Economy	13600.00
0005432567189	30547	Economy	13600.00
0005432459518	30547	Economy	15000.00
0005432567615	30547	Economy	13600.00
0005432459455	30547	Economy	13600.00
0005432567427	30547	Economy	15000.00
0005432567407	30547	Economy	15000.00
0005434081749	30547	Economy	13600.00
0005432567350	30547	Economy	13600.00
0005432567299	30547	Economy	13600.00
0005432459657	30547	Economy	13600.00
0005432459644	30547	Economy	13600.00
0005432567382	30547	Economy	13600.00
0005432567231	30547	Economy	13600.00
0005432459667	30547	Economy	13600.00
0005432459761	30547	Economy	13600.00
0005432567233	30547	Economy	13600.00
0005432459517	30547	Economy	13600.00
0005432459574	30547	Economy	13600.00
0005432567261	30547	Economy	13600.00
0005432459590	30547	Economy	13600.00
0005432567419	30547	Economy	13600.00
0005432567184	30547	Economy	13600.00
0005432459531	30547	Economy	13600.00
0005432567542	30547	Economy	13600.00
0005432567389	30547	Economy	13600.00
0005432567204	30547	Economy	13600.00
0005432161159	30547	Economy	13600.00
0005434559085	30547	Economy	13600.00
0005432567362	30547	Economy	13600.00
0005432459713	30547	Economy	13600.00
0005432459711	30547	Economy	13600.00
0005432567369	30547	Economy	13600.00
0005434081716	30547	Economy	13600.00
0005432459524	30547	Economy	13600.00
0005432459573	30547	Economy	13600.00
0005432567250	30547	Economy	13600.00
0005432459589	30547	Economy	13600.00
0005432571301	30547	Economy	13600.00
0005432459606	30547	Economy	13600.00
0005434081740	30547	Economy	13600.00
0005432459495	30547	Economy	13600.00
0005432567155	30547	Economy	13600.00
0005432571293	30547	Economy	13600.00
0005432567363	30547	Economy	13600.00
0005434559084	30547	Economy	13600.00
0005432459634	30547	Economy	13600.00
0005432459454	30547	Economy	13600.00
0005432459553	30547	Economy	13600.00
0005432459691	30547	Economy	13600.00
0005433454859	30547	Economy	13600.00
0005432459591	30547	Economy	13600.00
0005432213618	30547	Economy	13600.00
0005432567423	30547	Economy	13600.00
0005432459778	30547	Economy	13600.00
0005432567616	30547	Economy	13600.00
0005432459710	30547	Economy	13600.00
0005432567545	30547	Economy	13600.00
0005434559087	30547	Economy	13600.00
0005434081758	30547	Economy	13600.00
0005432567170	30547	Economy	13600.00
0005432459498	30547	Economy	13600.00
0005432459364	30547	Economy	13600.00
0005434081706	30547	Economy	13600.00
0005432459486	30547	Economy	13600.00
0005432459643	30547	Economy	13600.00
0005435720825	13669	Economy	9900.00
0005435722062	13669	Economy	9900.00
0005435722044	21230	Economy	9900.00
0005435722026	21230	Economy	9900.00
0005435722045	21230	Economy	9900.00
0005435722034	21230	Economy	9900.00
0005435722035	21230	Economy	9900.00
0005432295887	22788	Economy	8800.00
0005432295888	22788	Economy	8800.00
0005433343471	11093	Business	23600.00
0005433343465	11093	Business	23600.00
0005433343440	11093	Business	23600.00
0005433343459	11093	Business	23600.00
0005435097224	11093	Business	23600.00
0005433343431	11093	Business	23600.00
0005433343491	11093	Business	23600.00
0005433343443	11093	Business	23600.00
0005433343444	11093	Business	23600.00
0005433343494	11093	Business	23600.00
0005433343425	11093	Business	23600.00
0005435508295	11093	Business	23600.00
0005433343501	11093	Economy	7900.00
0005433343473	11093	Economy	7900.00
0005433343470	11093	Economy	7900.00
0005435508341	11093	Economy	7900.00
0005433343507	11093	Economy	7900.00
0005435508294	11093	Economy	7900.00
0005433343458	11093	Economy	7900.00
0005433343502	11093	Economy	7900.00
0005435508259	11093	Economy	7900.00
0005433343428	11093	Economy	7900.00
0005433343418	11093	Economy	7900.00
0005435508321	11093	Economy	7900.00
0005433343426	11093	Economy	7900.00
0005433343434	11093	Economy	7900.00
0005433343497	11093	Economy	7900.00
0005433343490	11093	Economy	7900.00
0005433343474	11093	Economy	7900.00
0005433343495	11093	Economy	7900.00
0005433343441	11093	Economy	7900.00
0005433343449	11093	Economy	7900.00
0005433343505	11093	Economy	7900.00
0005433343463	11093	Economy	7900.00
0005433343478	11093	Economy	7900.00
0005433343506	11093	Economy	7900.00
0005433343487	11093	Economy	7900.00
0005433343475	11093	Economy	7900.00
0005433343485	11093	Economy	7900.00
0005433343486	11093	Economy	7900.00
0005435508322	11093	Economy	7900.00
0005433343415	11093	Economy	7900.00
0005433343460	11093	Economy	7900.00
0005433343435	11093	Economy	7900.00
0005433343429	11093	Economy	7900.00
0005433343437	11093	Economy	7900.00
0005433343416	11093	Economy	7900.00
0005433343513	11093	Economy	7900.00
0005433343508	11093	Economy	7900.00
0005435097217	11093	Economy	7900.00
0005433343504	11093	Economy	7900.00
0005435508278	11093	Economy	8600.00
0005433343445	11093	Economy	7900.00
0005433343436	11093	Economy	8600.00
0005433343420	11093	Economy	8600.00
0005435097218	11093	Economy	8600.00
0005433343466	11093	Economy	8600.00
0005435508289	11093	Economy	8600.00
0005435097214	11093	Economy	7900.00
0005433343422	11093	Economy	7900.00
0005435508320	11093	Economy	7900.00
0005433343467	11093	Economy	7900.00
0005433343493	11093	Economy	7900.00
0005433343419	11093	Economy	7900.00
0005433343509	11093	Economy	7900.00
0005433343510	11093	Economy	7900.00
0005433343456	11093	Economy	7900.00
0005435097215	11093	Economy	7900.00
0005433343489	11093	Economy	7900.00
0005433343499	11093	Economy	7900.00
0005433343488	11093	Economy	7900.00
0005433343514	11093	Economy	7900.00
0005435508281	11093	Economy	7900.00
0005433343455	11093	Economy	7900.00
0005433343450	11093	Economy	7900.00
0005433343461	11093	Economy	7900.00
0005433343479	11093	Economy	7900.00
0005433343432	11093	Economy	7900.00
0005435508308	11093	Economy	7900.00
0005433343421	11093	Economy	7900.00
0005433343424	11093	Economy	7900.00
0005433343451	11093	Economy	7900.00
0005433343481	11093	Economy	7900.00
0005433343472	11093	Economy	7900.00
0005435097221	11093	Economy	7900.00
0005433343492	11093	Economy	7900.00
0005433343468	11093	Economy	7900.00
0005435508336	11093	Economy	7900.00
0005433343477	11093	Economy	7900.00
0005433343439	11093	Economy	7900.00
0005433343414	11093	Economy	7900.00
0005433343503	11093	Economy	7900.00
0005435097219	11093	Economy	7900.00
0005433343438	11093	Economy	7900.00
0005435097220	11093	Economy	7900.00
0005433343433	11093	Economy	7900.00
0005433343454	11093	Economy	7900.00
0005433343469	11093	Economy	7900.00
0005433343483	11093	Economy	7900.00
0005433343448	11093	Economy	7900.00
0005433343427	11093	Economy	7900.00
0005435508362	11093	Economy	7900.00
0005433343453	11093	Economy	7900.00
0005433343464	11093	Economy	7900.00
0005435508319	11093	Economy	7900.00
0005433343452	11093	Economy	7900.00
0005433343430	11093	Economy	7900.00
0005433343500	11093	Economy	7900.00
0005433343482	11093	Economy	7900.00
0005433343480	11093	Economy	7900.00
0005433343423	11093	Economy	7900.00
0005433343498	11093	Economy	7900.00
0005433343496	11093	Economy	7900.00
0005435097216	11093	Economy	7900.00
0005435508282	11093	Economy	7900.00
0005433343484	11093	Economy	7900.00
0005435508307	11093	Economy	7900.00
0005435097223	11093	Economy	7900.00
0005433343447	11093	Economy	7900.00
0005433343442	11093	Economy	7900.00
0005433343462	11093	Economy	7900.00
0005433343446	11093	Economy	7900.00
0005435097222	11093	Economy	7900.00
0005433343511	11093	Economy	7900.00
0005433343512	11093	Economy	7900.00
0005433343417	11093	Economy	7900.00
0005433343476	11093	Economy	7900.00
0005433343457	11093	Economy	7900.00
0005433342663	17115	Business	23600.00
0005433342822	17115	Business	23600.00
0005433342929	17115	Business	23600.00
0005432293215	17115	Business	23600.00
0005433342630	17115	Business	23600.00
0005433342278	17115	Business	23600.00
0005433342644	17115	Business	23600.00
0005433342593	17115	Business	23600.00
0005433342867	17115	Business	23600.00
0005433341864	17115	Business	23600.00
0005433342261	17115	Business	23600.00
0005433342557	17115	Economy	7900.00
0005433342523	17115	Business	23600.00
0005433342564	17115	Economy	7900.00
0005435097151	17115	Economy	7900.00
0005433343002	17115	Economy	7900.00
0005433342538	17115	Economy	7900.00
0005433342736	17115	Economy	7900.00
0005433342621	17115	Economy	7900.00
0005433342496	17115	Economy	7900.00
0005433342653	17115	Economy	7900.00
0005433342277	17115	Economy	7900.00
0005433342425	17115	Economy	7900.00
0005433342426	17115	Economy	7900.00
0005433342301	17115	Economy	7900.00
0005435097149	17115	Economy	7900.00
0005433342424	17115	Economy	7900.00
0005433342631	17115	Economy	7900.00
0005433342320	17115	Economy	7900.00
0005433342859	17115	Economy	7900.00
0005433342543	17115	Economy	7900.00
0005433342071	17115	Economy	7900.00
0005433342521	17115	Economy	7900.00
0005433342504	17115	Economy	7900.00
0005432293216	17115	Economy	7900.00
0005433342664	17115	Economy	7900.00
0005433342622	17115	Economy	7900.00
0005433342348	17115	Economy	7900.00
0005433342790	17115	Economy	7900.00
0005435097128	17115	Economy	7900.00
0005433341985	17115	Economy	7900.00
0005433342318	17115	Economy	7900.00
0005433342535	17115	Economy	7900.00
0005433342691	17115	Economy	7900.00
0005433342376	17115	Economy	7900.00
0005433342509	17115	Economy	7900.00
0005433342259	17115	Economy	7900.00
0005435097143	17115	Economy	7900.00
0005433343023	17115	Economy	7900.00
0005433342695	17115	Economy	7900.00
0005433343070	17115	Economy	7900.00
0005433342690	17115	Economy	7900.00
0005433342341	17115	Economy	8600.00
0005435097116	17115	Economy	8600.00
0005433342594	17115	Economy	8600.00
0005433342637	17115	Economy	8600.00
0005433343003	17115	Economy	8600.00
0005435097142	17115	Economy	8600.00
0005433342143	17115	Economy	7900.00
0005433342858	17115	Economy	7900.00
0005433342775	17115	Economy	7900.00
0005433342520	17115	Economy	7900.00
0005433342702	17115	Economy	7900.00
0005433342464	17115	Economy	7900.00
0005433342356	17115	Economy	7900.00
0005433342500	17115	Economy	7900.00
0005433342308	17115	Economy	7900.00
0005433342765	17115	Economy	7900.00
0005433342735	17115	Economy	7900.00
0005433342679	17115	Economy	7900.00
0005433342391	17115	Economy	7900.00
0005433342243	17115	Economy	7900.00
0005433342355	17115	Economy	7900.00
0005433342472	17115	Economy	7900.00
0005433342349	17115	Economy	7900.00
0005435097165	17115	Economy	7900.00
0005433342336	17115	Economy	7900.00
0005433342455	17115	Economy	7900.00
0005433342576	17115	Economy	7900.00
0005433342461	17115	Economy	7900.00
0005433342418	17115	Economy	7900.00
0005433342300	17115	Economy	7900.00
0005433342187	17115	Economy	7900.00
0005433343024	17115	Economy	7900.00
0005433342390	17115	Economy	7900.00
0005433342316	17115	Economy	7900.00
0005433342828	17115	Economy	7900.00
0005433342226	17115	Economy	7900.00
0005433342319	17115	Economy	7900.00
0005433342785	17115	Economy	7900.00
0005433342759	17115	Economy	7900.00
0005433342291	17115	Economy	7900.00
0005433342758	17115	Economy	7900.00
0005435097119	17115	Economy	7900.00
0005433342335	17115	Economy	7900.00
0005433342667	17115	Economy	7900.00
0005435097164	17115	Economy	7900.00
0005433342544	17115	Economy	7900.00
0005433342299	17115	Economy	7900.00
0005435097135	17115	Economy	7900.00
0005433342216	17115	Economy	7900.00
0005433342928	17115	Economy	7900.00
0005433342857	17115	Economy	7900.00
0005433342541	17115	Economy	7900.00
0005433342323	17115	Economy	7900.00
0005433342030	17115	Economy	7900.00
0005433342215	17115	Economy	7900.00
0005433342737	17115	Economy	7900.00
0005435097150	17115	Economy	7900.00
0005433342654	17115	Economy	7900.00
0005435097141	17115	Economy	7900.00
0005433342643	17115	Economy	7900.00
0005433342031	17115	Economy	7900.00
0005433342899	17115	Economy	7900.00
0005435097129	17115	Economy	7900.00
0005433342456	17115	Economy	7900.00
0005433342333	17115	Economy	7900.00
0005433342497	17115	Economy	7900.00
0005433342242	17115	Economy	7900.00
0005433342276	17115	Economy	7900.00
0005433342542	17115	Economy	7900.00
0005433342752	17115	Economy	7900.00
0005433342776	17115	Economy	7900.00
0005433342321	17115	Economy	7900.00
0005433342317	17115	Economy	7900.00
0005433342460	17115	Economy	7900.00
0005435097136	17115	Economy	7900.00
0005433342753	17115	Economy	7900.00
0005433342827	17115	Economy	7900.00
0005433342845	17115	Economy	7900.00
0005433507242	9089	Business	26600.00
0005432919779	9089	Business	26600.00
0005434158959	9089	Business	26600.00
0005432919732	9089	Business	26600.00
0005432919756	9089	Business	26600.00
0005433481191	9089	Business	26600.00
0005433507249	9089	Business	26600.00
0005433507239	9089	Business	26600.00
0005433481187	9089	Business	26600.00
0005433507246	9089	Business	26600.00
0005433507237	9089	Economy	8900.00
0005432919687	9089	Economy	8900.00
0005433507238	9089	Economy	8900.00
0005433481192	9089	Economy	8900.00
0005432919721	9089	Economy	8900.00
0005433507236	9089	Economy	9800.00
0005432919815	9089	Economy	8900.00
0005432919720	9089	Economy	8900.00
0005433507245	9089	Economy	8900.00
0005432919661	9089	Economy	8900.00
0005433481188	9089	Economy	8900.00
0005433481186	9089	Economy	8900.00
0005433481189	9089	Economy	8900.00
0005432919641	9089	Economy	8900.00
0005432919642	9089	Economy	8900.00
0005432919814	9089	Economy	8900.00
0005432919594	9089	Economy	8900.00
0005433507244	9089	Economy	8900.00
0005433507240	9089	Economy	8900.00
0005432919826	9089	Economy	8900.00
0005433481190	9089	Economy	8900.00
0005432919731	9089	Economy	8900.00
0005432919696	9089	Economy	8900.00
0005433507234	9089	Economy	8900.00
0005432919827	9089	Economy	8900.00
0005433507247	9089	Economy	8900.00
0005433507241	9089	Economy	8900.00
0005433481193	9089	Economy	8900.00
0005432919739	9089	Economy	8900.00
0005433507248	9089	Economy	8900.00
0005432919656	9089	Economy	8900.00
0005432919657	9089	Economy	8900.00
0005433507235	9089	Economy	8900.00
0005433507243	9089	Economy	8900.00
0005433507250	9089	Economy	8900.00
0005432919764	9089	Economy	8900.00
0005432919672	9089	Economy	8900.00
0005432919695	9089	Economy	8900.00
0005433507123	20481	Business	26600.00
0005433507011	20481	Business	26600.00
0005433481128	20481	Business	26600.00
0005432919945	20481	Business	26600.00
0005433507067	20481	Business	26600.00
0005432919940	20481	Business	26600.00
0005433507063	20481	Economy	8900.00
0005432919942	20481	Economy	8900.00
0005433507079	20481	Economy	8900.00
0005433507134	20481	Economy	9800.00
0005432919935	20481	Economy	9800.00
0005432919931	20481	Economy	8900.00
0005432919932	20481	Economy	8900.00
0005432919944	20481	Economy	8900.00
0005432919949	20481	Economy	8900.00
0005433507085	20481	Economy	8900.00
0005432919934	20481	Economy	8900.00
0005432919933	20481	Economy	8900.00
0005433481131	20481	Economy	8900.00
0005433507118	20481	Economy	8900.00
0005432919947	20481	Economy	8900.00
0005433507125	20481	Economy	8900.00
0005432919938	20481	Economy	8900.00
0005432919941	20481	Economy	8900.00
0005433481152	20481	Economy	8900.00
0005433481129	20481	Economy	8900.00
0005432919948	20481	Economy	8900.00
0005432919950	20481	Economy	8900.00
0005433507086	20481	Economy	8900.00
0005433481130	20481	Economy	8900.00
0005433507108	20481	Economy	8900.00
0005433507124	20481	Economy	8900.00
0005433507157	20481	Economy	8900.00
0005433507012	20481	Economy	8900.00
0005433507097	20481	Economy	8900.00
0005433507180	20481	Economy	8900.00
0005433507113	20481	Economy	8900.00
0005433507080	20481	Economy	8900.00
0005432919943	20481	Economy	8900.00
0005433507167	20481	Economy	8900.00
0005433507096	20481	Economy	8900.00
0005432919939	20481	Economy	8900.00
0005433507127	20481	Economy	8900.00
0005432919936	20481	Economy	8900.00
0005432919946	20481	Economy	8900.00
0005432919951	20481	Economy	8900.00
0005432919937	20481	Economy	8900.00
0005432396252	10135	Economy	5800.00
0005432394112	10135	Economy	5800.00
0005432394113	10135	Economy	5800.00
0005432396251	10135	Economy	5800.00
0005432396250	10135	Economy	5800.00
0005432396249	10135	Economy	5800.00
0005435178985	10135	Economy	5800.00
0005432394110	10135	Economy	5800.00
0005432396253	10135	Economy	5800.00
0005432394111	10135	Economy	5800.00
0005435178988	10135	Economy	5800.00
0005435178987	10135	Economy	5800.00
0005432396215	18331	Economy	5800.00
0005432400115	18331	Economy	5800.00
0005432396196	18331	Economy	5800.00
0005432400086	18331	Economy	5800.00
0005432396223	18331	Economy	5800.00
0005432396232	18331	Economy	5800.00
0005432400096	18331	Economy	5800.00
0005432400104	18331	Economy	5800.00
0005435554160	10971	Business	9500.00
0005435625985	10971	Business	9500.00
0005435626035	10971	Business	9500.00
0005435126027	10971	Business	9500.00
0005435626063	10971	Business	9500.00
0005435554144	10971	Business	9500.00
0005435626043	10971	Economy	3200.00
0005435626012	10971	Economy	3200.00
0005435126039	10971	Economy	3200.00
0005434928308	10971	Economy	3200.00
0005434411790	10971	Economy	3200.00
0005435126227	10971	Economy	3500.00
0005435626009	10971	Economy	3500.00
0005435626008	10971	Economy	3500.00
0005435626057	10971	Economy	3500.00
0005435626017	10971	Economy	3500.00
0005435126285	10971	Economy	3200.00
0005434411793	10971	Economy	3200.00
0005435626044	10971	Economy	3200.00
0005435126225	10971	Economy	3200.00
0005435126029	10971	Economy	3200.00
0005435126178	10971	Economy	3200.00
0005435126193	10971	Economy	3200.00
0005435125995	10971	Economy	3200.00
0005435626090	10971	Economy	3200.00
0005434411791	10971	Economy	3200.00
0005435126217	10971	Economy	3200.00
0005435126119	10971	Economy	3200.00
0005435626032	10971	Economy	3200.00
0005435626065	10971	Economy	3200.00
0005435126272	10971	Economy	3200.00
0005435626038	10971	Economy	3200.00
0005435126216	10971	Economy	3200.00
0005435126197	10971	Economy	3200.00
0005435126226	10971	Economy	3200.00
0005435125926	10971	Economy	3200.00
0005435626087	10971	Economy	3200.00
0005435625960	10971	Economy	3200.00
0005435126082	10971	Economy	3200.00
0005435556672	10971	Economy	3200.00
0005435125983	10971	Economy	3200.00
0005434928307	10971	Economy	3200.00
0005435626061	10971	Economy	3200.00
0005435126196	10971	Economy	3200.00
0005435554153	10971	Economy	3200.00
0005435556674	10971	Economy	3200.00
0005435126283	10971	Economy	3200.00
0005435126131	10971	Economy	3200.00
0005435626013	10971	Economy	3200.00
0005435126195	10971	Economy	3200.00
0005435125925	10971	Economy	3200.00
0005434411792	10971	Economy	3200.00
0005434928309	10971	Economy	3200.00
0005435126118	10971	Economy	3200.00
0005435626088	10971	Economy	3200.00
0005435126102	10971	Economy	3200.00
0005435626037	10971	Economy	3200.00
0005435626062	10971	Economy	3200.00
0005435126132	10971	Economy	3200.00
0005435554156	10971	Economy	3200.00
0005435125984	10971	Economy	3200.00
0005435626228	14774	Business	9500.00
0005435626223	14774	Business	9500.00
0005435626221	14774	Business	9500.00
0005435126495	14774	Business	9500.00
0005435626233	14774	Business	9500.00
0005435126504	14774	Business	9500.00
0005435626225	14774	Economy	3200.00
0005435126508	14774	Economy	3200.00
0005435126516	14774	Economy	3200.00
0005435126514	14774	Economy	3200.00
0005435126511	14774	Economy	3200.00
0005435126506	14774	Economy	3200.00
0005435556700	14774	Economy	3200.00
0005435126502	14774	Economy	3500.00
0005435126512	14774	Economy	3500.00
0005435626219	14774	Economy	3500.00
0005435126484	14774	Economy	3500.00
0005435126510	14774	Economy	3500.00
0005435126481	14774	Economy	3200.00
0005435126482	14774	Economy	3200.00
0005435626226	14774	Economy	3200.00
0005435126505	14774	Economy	3200.00
0005435126507	14774	Economy	3200.00
0005435556699	14774	Economy	3200.00
0005434411754	14774	Economy	3200.00
0005435126496	14774	Economy	3200.00
0005435126520	14774	Economy	3200.00
0005435126499	14774	Economy	3200.00
0005435626236	14774	Economy	3200.00
0005435626237	14774	Economy	3200.00
0005435626218	14774	Economy	3200.00
0005435126487	14774	Economy	3200.00
0005435626222	14774	Economy	3200.00
0005435626227	14774	Economy	3200.00
0005435554199	14774	Economy	3200.00
0005435126517	14774	Economy	3200.00
0005435554198	14774	Economy	3200.00
0005435126518	14774	Economy	3200.00
0005435126498	14774	Economy	3200.00
0005435126509	14774	Economy	3200.00
0005435126513	14774	Economy	3200.00
0005435126519	14774	Economy	3200.00
0005435626230	14774	Economy	3200.00
0005435556701	14774	Economy	3200.00
0005435126492	14774	Economy	3200.00
0005435554200	14774	Economy	3200.00
0005434928289	14774	Economy	3200.00
0005435126497	14774	Economy	3200.00
0005435126491	14774	Economy	3200.00
0005434411749	14774	Economy	3200.00
0005435126490	14774	Economy	3200.00
0005435126485	14774	Economy	3200.00
0005435626229	14774	Economy	3200.00
0005435626235	14774	Economy	3200.00
0005435626220	14774	Economy	3200.00
0005435626231	14774	Economy	3200.00
0005435126500	14774	Economy	3200.00
0005435126488	14774	Economy	3200.00
0005435126494	14774	Economy	3200.00
0005435626224	14774	Economy	3200.00
0005434411750	14774	Economy	3200.00
0005435126489	14774	Economy	3200.00
0005435626238	14774	Economy	3200.00
0005435626232	14774	Economy	3200.00
0005435626234	14774	Economy	3200.00
0005435126483	14774	Economy	3200.00
0005435126503	14774	Economy	3200.00
0005435126486	14774	Economy	3200.00
0005435126501	14774	Economy	3200.00
0005435126515	14774	Economy	3200.00
0005435626239	14774	Economy	3200.00
0005435126493	14774	Economy	3200.00
0005435554201	14774	Economy	3200.00
0005435443238	7145	Business	86900.00
0005435221046	7145	Business	86900.00
0005435443266	7145	Business	86900.00
0005435715525	7145	Economy	29000.00
0005435715522	7145	Economy	29000.00
0005435715520	7145	Economy	29000.00
0005435715516	7145	Economy	29000.00
0005435715517	7145	Economy	29000.00
0005435443289	7145	Economy	29000.00
0005435715512	7145	Economy	31900.00
0005435443288	7145	Economy	31900.00
0005435715518	7145	Economy	29000.00
0005435715524	7145	Economy	29000.00
0005435443273	7145	Economy	29000.00
0005435219185	7145	Economy	29000.00
0005432400136	7145	Economy	29000.00
0005432398207	7145	Economy	29000.00
0005432398210	7145	Economy	29000.00
0005435715515	7145	Economy	29000.00
0005435443286	7145	Economy	29000.00
0005435715513	7145	Economy	29000.00
0005435443260	7145	Economy	29000.00
0005435715523	7145	Economy	29000.00
0005435443237	7145	Economy	29000.00
0005435715511	7145	Economy	29000.00
0005435178481	7145	Economy	29000.00
0005432400139	7145	Economy	29000.00
0005435715519	7145	Economy	29000.00
0005435219184	7145	Economy	29000.00
0005435443274	7145	Economy	29000.00
0005435443265	7145	Economy	29000.00
0005435443252	7145	Economy	29000.00
0005435715527	7145	Economy	29000.00
0005432398206	7145	Economy	29000.00
0005435715521	7145	Economy	29000.00
0005432400137	7145	Economy	29000.00
0005432398208	7145	Economy	29000.00
0005435443254	7145	Economy	29000.00
0005435715528	7145	Economy	29000.00
0005435715526	7145	Economy	29000.00
0005432398209	7145	Economy	29000.00
0005432400135	7145	Economy	29000.00
0005435219186	7145	Economy	29000.00
0005435715514	7145	Economy	29000.00
0005432400138	7145	Economy	29000.00
0005435715350	27046	Business	86900.00
0005435715416	27046	Business	86900.00
0005435715414	27046	Business	86900.00
0005432394072	27046	Business	86900.00
0005432394071	27046	Business	86900.00
0005432398188	27046	Economy	29000.00
0005435715287	27046	Economy	29000.00
0005435443342	27046	Economy	29000.00
0005435443346	27046	Economy	29000.00
0005435715288	27046	Economy	29000.00
0005435715381	27046	Economy	29000.00
0005435715371	27046	Economy	29000.00
0005435443341	27046	Economy	29000.00
0005435443345	27046	Economy	29000.00
0005435715434	27046	Economy	29000.00
0005435715341	27046	Economy	31900.00
0005435443339	27046	Economy	31900.00
0005432398175	27046	Economy	31900.00
0005435443338	27046	Economy	29000.00
0005435715433	27046	Economy	29000.00
0005435715365	27046	Economy	29000.00
0005432394091	27046	Economy	29000.00
0005435715357	27046	Economy	29000.00
0005435715366	27046	Economy	29000.00
0005432394090	27046	Economy	29000.00
0005435443347	27046	Economy	29000.00
0005435715382	27046	Economy	29000.00
0005435443340	27046	Economy	29000.00
0005432398174	27046	Economy	29000.00
0005432394066	27046	Economy	29000.00
0005435715417	27046	Economy	29000.00
0005435178500	27046	Economy	29000.00
0005432394069	27046	Economy	29000.00
0005435443348	27046	Economy	29000.00
0005435443343	27046	Economy	29000.00
0005435178499	27046	Economy	29000.00
0005432394070	27046	Economy	29000.00
0005435443344	27046	Economy	29000.00
0005435715415	27046	Economy	29000.00
0005435715286	27046	Economy	29000.00
0005435715380	27046	Economy	29000.00
0005435715340	27046	Economy	29000.00
0005435443337	27046	Economy	29000.00
0005434084944	2738	Economy	7700.00
0005434084946	2738	Economy	7700.00
0005434084943	2738	Economy	7700.00
0005434084947	2738	Economy	7700.00
0005434084945	2738	Economy	7700.00
0005433060399	2738	Economy	7700.00
0005433060422	28491	Economy	7700.00
0005434084912	28491	Economy	7700.00
0005434084911	28491	Economy	7700.00
0005434084913	28491	Economy	7700.00
0005434084906	28491	Economy	7700.00
0005434084904	28491	Economy	7700.00
0005434084903	28491	Economy	7700.00
0005433060420	28491	Economy	7700.00
0005434084907	28491	Economy	7700.00
0005434084910	28491	Economy	7700.00
0005433060421	28491	Economy	7700.00
0005434084914	28491	Economy	7700.00
0005432632749	25196	Economy	29000.00
0005432632741	25196	Economy	29000.00
0005435844304	25196	Economy	26400.00
0005432632751	25196	Economy	26400.00
0005435844283	25196	Economy	26400.00
0005432632733	25196	Economy	26400.00
0005432632737	25196	Economy	26400.00
0005432632752	25196	Economy	26400.00
0005432632744	25196	Economy	26400.00
0005435844277	25196	Economy	26400.00
0005435844278	25196	Economy	26400.00
0005435844276	25196	Economy	26400.00
0005435844274	25196	Economy	26400.00
0005435844284	25196	Economy	26400.00
0005432632743	25196	Economy	26400.00
0005432632739	25196	Economy	26400.00
0005432632750	25196	Economy	26400.00
0005432632754	25196	Economy	26400.00
0005432632734	25196	Economy	26400.00
0005432632747	25196	Economy	26400.00
0005435844271	25196	Economy	26400.00
0005435844281	25196	Economy	26400.00
0005432632742	25196	Economy	26400.00
0005432632746	25196	Economy	26400.00
0005432632738	25196	Economy	26400.00
0005432632736	25196	Economy	26400.00
0005432632753	25196	Economy	26400.00
0005435844275	25196	Economy	26400.00
0005432632740	25196	Economy	26400.00
0005432632748	25196	Economy	26400.00
0005432632745	25196	Economy	26400.00
0005432632735	25196	Economy	26400.00
0005435844332	28163	Economy	29000.00
0005435844327	28163	Economy	29000.00
0005432632694	28163	Economy	26400.00
0005432632661	28163	Economy	26400.00
0005435844330	28163	Economy	26400.00
0005435844336	28163	Economy	26400.00
0005432632671	28163	Economy	26400.00
0005432632675	28163	Economy	26400.00
0005432632699	28163	Economy	26400.00
0005432632660	28163	Economy	26400.00
0005432632643	28163	Economy	26400.00
0005435844337	28163	Economy	26400.00
0005435844335	28163	Economy	26400.00
0005435844333	28163	Economy	26400.00
0005435844334	28163	Economy	26400.00
0005432632672	28163	Economy	26400.00
0005432632667	28163	Economy	26400.00
0005435844331	28163	Economy	26400.00
0005432632731	28163	Economy	26400.00
0005435844329	28163	Economy	26400.00
0005435844328	28163	Economy	26400.00
0005435540920	11384	Business	20200.00
0005435517867	11384	Business	20200.00
0005435540892	11384	Business	20200.00
0005435540993	11384	Business	20200.00
0005435517725	11384	Business	20200.00
0005435540922	11384	Business	20200.00
0005435540992	11384	Business	20200.00
0005435540904	11384	Business	20200.00
0005435540879	11384	Economy	6700.00
0005435540909	11384	Economy	6700.00
0005435540910	11384	Economy	6700.00
0005435517812	11384	Economy	6700.00
0005435540790	11384	Economy	6700.00
0005435540852	11384	Economy	6700.00
0005435517882	11384	Economy	6700.00
0005435540875	11384	Economy	6700.00
0005435540933	11384	Economy	7400.00
0005435517766	11384	Economy	6700.00
0005435540894	11384	Economy	6700.00
0005435517771	11384	Economy	6700.00
0005435517856	11384	Economy	6700.00
0005435517820	11384	Economy	6700.00
0005435517838	11384	Economy	6700.00
0005435540991	11384	Economy	6700.00
0005435540901	11384	Economy	6700.00
0005435540905	11384	Economy	6700.00
0005435517804	11384	Economy	6700.00
0005435517827	11384	Economy	6700.00
0005435540870	11384	Economy	6700.00
0005435540948	11384	Economy	6700.00
0005435517819	11384	Economy	6700.00
0005435517821	11384	Economy	6700.00
0005435540903	11384	Economy	6700.00
0005435517814	11384	Economy	6700.00
0005435540908	11384	Economy	6700.00
0005435540972	11384	Economy	6700.00
0005435517852	11384	Economy	6700.00
0005435517778	11384	Economy	6700.00
0005435540802	11384	Economy	6700.00
0005435540935	11384	Economy	6700.00
0005435540853	11384	Economy	6700.00
0005435540955	11384	Economy	6700.00
0005435540902	11384	Economy	6700.00
0005435540945	11384	Economy	6700.00
0005435540886	11384	Economy	6700.00
0005435517774	11384	Economy	6700.00
0005435540952	11384	Economy	6700.00
0005435540791	11384	Economy	6700.00
0005435540893	11384	Economy	6700.00
0005435517813	11384	Economy	6700.00
0005435540803	11384	Economy	6700.00
0005435540840	11384	Economy	6700.00
0005435540923	11384	Economy	6700.00
0005435517770	11384	Economy	6700.00
0005435540885	11384	Economy	6700.00
0005435517767	11384	Economy	6700.00
0005435540921	11384	Economy	6700.00
0005435540900	11384	Economy	6700.00
0005435517748	11384	Economy	6700.00
0005435540874	11384	Economy	6700.00
0005435540928	11384	Economy	6700.00
0005435517773	11384	Economy	6700.00
0005435529314	22262	Business	20200.00
0005435529315	22262	Business	20200.00
0005435541061	22262	Business	20200.00
0005435541054	22262	Business	20200.00
0005435529307	22262	Business	20200.00
0005435529317	22262	Business	20200.00
0005435541059	22262	Business	20200.00
0005435541050	22262	Business	20200.00
0005435529306	22262	Economy	6700.00
0005435529320	22262	Economy	6700.00
0005435529310	22262	Economy	6700.00
0005435529303	22262	Economy	6700.00
0005435541051	22262	Economy	7400.00
0005435541064	22262	Economy	6700.00
0005435541047	22262	Economy	6700.00
0005435529312	22262	Economy	6700.00
0005435529302	22262	Economy	6700.00
0005435529313	22262	Economy	6700.00
0005435529321	22262	Economy	6700.00
0005435541060	22262	Economy	6700.00
0005435541063	22262	Economy	6700.00
0005435541062	22262	Economy	6700.00
0005435541046	22262	Economy	6700.00
0005432294493	22262	Economy	6700.00
0005435541049	22262	Economy	6700.00
0005435541056	22262	Economy	6700.00
0005432294492	22262	Economy	6700.00
0005435529309	22262	Economy	6700.00
0005435541053	22262	Economy	6700.00
0005435541055	22262	Economy	6700.00
0005435529301	22262	Economy	6700.00
0005435529311	22262	Economy	6700.00
0005435541058	22262	Economy	6700.00
0005435541052	22262	Economy	6700.00
0005435529304	22262	Economy	6700.00
0005435541065	22262	Economy	6700.00
0005435541043	22262	Economy	6700.00
0005435541057	22262	Economy	6700.00
0005435529300	22262	Economy	6700.00
0005435541048	22262	Economy	6700.00
0005435529305	22262	Economy	6700.00
0005435529308	22262	Economy	6700.00
0005435529319	22262	Economy	6700.00
0005435541044	22262	Economy	6700.00
0005435541045	22262	Economy	6700.00
0005435529316	22262	Economy	6700.00
0005435529318	22262	Economy	6700.00
0005433251317	2259	Business	20200.00
0005433251372	2259	Business	20200.00
0005434907481	2259	Business	20200.00
0005434907448	2259	Business	20200.00
0005433251205	2259	Business	20200.00
0005433251284	2259	Business	20200.00
0005434907474	2259	Business	20200.00
0005434907458	2259	Business	20200.00
0005434907455	2259	Business	20200.00
0005434907473	2259	Business	20200.00
0005434907468	2259	Economy	6700.00
0005434907485	2259	Economy	6700.00
0005434907449	2259	Economy	6700.00
0005433251298	2259	Economy	6700.00
0005434907477	2259	Economy	6700.00
0005433251300	2259	Economy	6700.00
0005433251423	2259	Economy	6700.00
0005434907466	2259	Economy	6700.00
0005434907465	2259	Economy	6700.00
0005434907445	2259	Economy	6700.00
0005433251369	2259	Economy	7400.00
0005434907437	2259	Economy	7400.00
0005434907470	2259	Economy	7400.00
0005434907439	2259	Economy	7400.00
0005434907469	2259	Economy	6700.00
0005433251362	2259	Economy	6700.00
0005433251373	2259	Economy	6700.00
0005433251342	2259	Economy	6700.00
0005433251309	2259	Economy	6700.00
0005434907453	2259	Economy	6700.00
0005433251308	2259	Economy	6700.00
0005434907484	2259	Economy	6700.00
0005433251368	2259	Economy	6700.00
0005433251375	2259	Economy	6700.00
0005434907443	2259	Economy	6700.00
0005434907479	2259	Economy	6700.00
0005433251363	2259	Economy	6700.00
0005433251370	2259	Economy	6700.00
0005433251295	2259	Economy	6700.00
0005434907451	2259	Economy	6700.00
0005434907452	2259	Economy	6700.00
0005434907476	2259	Economy	6700.00
0005433251287	2259	Economy	6700.00
0005433251354	2259	Economy	6700.00
0005433251394	2259	Economy	6700.00
0005434907446	2259	Economy	6700.00
0005434907459	2259	Economy	6700.00
0005434907467	2259	Economy	6700.00
0005433251290	2259	Economy	6700.00
0005434907480	2259	Economy	6700.00
0005434907447	2259	Economy	6700.00
0005433251350	2259	Economy	6700.00
0005434907471	2259	Economy	6700.00
0005434907457	2259	Economy	6700.00
0005434907472	2259	Economy	6700.00
0005434907475	2259	Economy	6700.00
0005433251393	2259	Economy	6700.00
0005433251206	2259	Economy	6700.00
0005434907460	2259	Economy	6700.00
0005434907454	2259	Economy	6700.00
0005433251374	2259	Economy	6700.00
0005434907462	2259	Economy	6700.00
0005434907444	2259	Economy	6700.00
0005433251384	2259	Economy	6700.00
0005433251274	2259	Economy	6700.00
0005433251318	2259	Economy	6700.00
0005434907464	2259	Economy	6700.00
0005433251440	2259	Economy	6700.00
0005434907436	2259	Economy	6700.00
0005433251333	2259	Economy	6700.00
0005434907450	2259	Economy	6700.00
0005434907442	2259	Economy	6700.00
0005434907483	2259	Economy	6700.00
0005434907461	2259	Economy	6700.00
0005433251301	2259	Economy	6700.00
0005434907456	2259	Economy	6700.00
0005433251385	2259	Economy	6700.00
0005434907478	2259	Economy	6700.00
0005434907463	2259	Economy	6700.00
0005434907441	2259	Economy	6700.00
0005433251294	2259	Economy	6700.00
0005434907482	2259	Economy	6700.00
0005433400976	2259	Economy	6700.00
0005434907438	2259	Economy	6700.00
0005434907440	2259	Economy	6700.00
0005433251302	2259	Economy	6700.00
0005433251422	2259	Economy	6700.00
0005434907094	25632	Business	20200.00
0005433251580	25632	Business	20200.00
0005433251574	25632	Business	20200.00
0005434906633	25632	Business	20200.00
0005434906935	25632	Business	20200.00
0005433251562	25632	Business	20200.00
0005434906996	25632	Business	20200.00
0005434907080	25632	Business	20200.00
0005433251563	25632	Business	20200.00
0005434906803	25632	Business	20200.00
0005433251583	25632	Economy	6700.00
0005434907009	25632	Economy	6700.00
0005433251573	25632	Economy	6700.00
0005433251561	25632	Economy	6700.00
0005433251570	25632	Economy	6700.00
0005434907095	25632	Economy	6700.00
0005433251590	25632	Economy	6700.00
0005434906632	25632	Economy	6700.00
0005434906815	25632	Economy	7400.00
0005433251572	25632	Economy	7400.00
0005433251567	25632	Economy	7400.00
0005434906993	25632	Economy	7400.00
0005434907117	25632	Economy	6700.00
0005434906759	25632	Economy	6700.00
0005433400992	25632	Economy	6700.00
0005434906817	25632	Economy	6700.00
0005434906863	25632	Economy	6700.00
0005434906891	25632	Economy	6700.00
0005433251566	25632	Economy	6700.00
0005434907018	25632	Economy	6700.00
0005434907049	25632	Economy	6700.00
0005434907006	25632	Economy	6700.00
0005434906873	25632	Economy	6700.00
0005434906938	25632	Economy	6700.00
0005434906976	25632	Economy	6700.00
0005433251576	25632	Economy	6700.00
0005433251568	25632	Economy	6700.00
0005433400993	25632	Economy	6700.00
0005434907129	25632	Economy	6700.00
0005434906845	25632	Economy	6700.00
0005434906846	25632	Economy	6700.00
0005433251586	25632	Economy	6700.00
0005433251588	25632	Economy	6700.00
0005434907118	25632	Economy	6700.00
0005434906997	25632	Economy	6700.00
0005433251584	25632	Economy	6700.00
0005433251564	25632	Economy	6700.00
0005433251582	25632	Economy	6700.00
0005433400991	25632	Economy	6700.00
0005433251587	25632	Economy	6700.00
0005434906859	25632	Economy	6700.00
0005433251565	25632	Economy	6700.00
0005434907089	25632	Economy	6700.00
0005434907090	25632	Economy	6700.00
0005433251578	25632	Economy	6700.00
0005433251581	25632	Economy	6700.00
0005434906934	25632	Economy	6700.00
0005433251571	25632	Economy	6700.00
0005434906933	25632	Economy	6700.00
0005433251589	25632	Economy	6700.00
0005434906940	25632	Economy	6700.00
0005433251585	25632	Economy	6700.00
0005434906882	25632	Economy	6700.00
0005434906602	25632	Economy	6700.00
0005434906972	25632	Economy	6700.00
0005433251579	25632	Economy	6700.00
0005434906802	25632	Economy	6700.00
0005434907071	25632	Economy	6700.00
0005433251569	25632	Economy	6700.00
0005433251560	25632	Economy	6700.00
0005434906942	25632	Economy	6700.00
0005434906872	25632	Economy	6700.00
0005433251577	25632	Economy	6700.00
0005434907001	25632	Economy	6700.00
0005434906689	25632	Economy	6700.00
0005434907076	25632	Economy	6700.00
0005434906758	25632	Economy	6700.00
0005434906816	25632	Economy	6700.00
0005434906973	25632	Economy	6700.00
0005434907119	25632	Economy	6700.00
0005434907088	25632	Economy	6700.00
0005434907116	25632	Economy	6700.00
0005433251575	25632	Economy	6700.00
0005432621077	2553	Economy	13600.00
0005432621084	2553	Economy	12400.00
0005432621080	2553	Economy	12400.00
0005432621086	2553	Economy	12400.00
0005432621076	2553	Economy	12400.00
0005432621085	2553	Economy	12400.00
0005432621090	2553	Economy	12400.00
0005432862232	2553	Economy	12400.00
0005432621075	2553	Economy	12400.00
0005432621087	2553	Economy	12400.00
0005432621078	2553	Economy	12400.00
0005432621082	2553	Economy	12400.00
0005432621083	2553	Economy	12400.00
0005432621089	2553	Economy	12400.00
0005432621088	2553	Economy	12400.00
0005432862289	2553	Economy	12400.00
0005432862297	2553	Economy	12400.00
0005432621081	2553	Economy	12400.00
0005432621079	2553	Economy	12400.00
0005432620936	28076	Economy	13600.00
0005432620909	28076	Economy	12400.00
0005432620959	28076	Economy	12400.00
0005432620904	28076	Economy	12400.00
0005432621004	28076	Economy	12400.00
0005432620911	28076	Economy	12400.00
0005432620988	28076	Economy	12400.00
0005432862327	28076	Economy	12400.00
0005432862326	28076	Economy	12400.00
0005432862324	28076	Economy	12400.00
0005432620935	28076	Economy	12400.00
0005432620923	28076	Economy	12400.00
0005432621013	28076	Economy	12400.00
0005432620910	28076	Economy	12400.00
0005432620984	28076	Economy	12400.00
0005432862328	28076	Economy	12400.00
0005432862329	28076	Economy	12400.00
0005432620924	28076	Economy	12400.00
0005432862325	28076	Economy	12400.00
0005432620985	28076	Economy	12400.00
0005432620986	28076	Economy	12400.00
0005432621003	28076	Economy	12400.00
0005434191281	28027	Business	89600.00
0005434191282	28027	Economy	32800.00
0005434191277	28027	Economy	32800.00
0005434191279	28027	Economy	32800.00
0005434191274	28027	Economy	29900.00
0005434191278	28027	Economy	29900.00
0005434191280	28027	Economy	29900.00
0005434191275	28027	Economy	29900.00
0005434191276	28027	Economy	29900.00
0005434191283	28027	Economy	29900.00
0005434191284	28027	Economy	29900.00
0005433452745	31080	Economy	8400.00
0005433451625	31080	Economy	8400.00
0005433451624	31080	Economy	8400.00
0005433452746	31080	Economy	8400.00
0005433454859	31424	Economy	8400.00
0005433454863	31424	Economy	8400.00
0005434142590	12017	Economy	7200.00
0005433134099	12017	Economy	6600.00
0005433134121	12017	Economy	6600.00
0005433129239	12017	Economy	6600.00
0005433129240	12017	Economy	6600.00
0005434142591	12017	Economy	6600.00
0005433134123	12017	Economy	6600.00
0005433129254	12017	Economy	6600.00
0005434142589	12017	Economy	6600.00
0005434184672	29812	Economy	7200.00
0005433134153	29812	Economy	7200.00
0005433134154	29812	Economy	7200.00
0005433131723	29812	Economy	6600.00
0005434183586	29812	Economy	6600.00
0005434184671	29812	Economy	6600.00
0005433131721	29812	Economy	6600.00
0005433131722	29812	Economy	6600.00
0005434142620	29812	Economy	6600.00
0005434142619	29812	Economy	6600.00
0005433131724	29812	Economy	6600.00
0005434142621	29812	Economy	6600.00
0005433131720	29812	Economy	6600.00
0005433134151	29812	Economy	6600.00
0005434142618	29812	Economy	6600.00
0005433134152	29812	Economy	6600.00
0005435697408	16470	Economy	19900.00
0005435697393	16470	Economy	19900.00
0005435935026	16470	Economy	19900.00
0005435697414	16470	Economy	18100.00
0005435935036	16470	Economy	18100.00
0005435935025	16470	Economy	18100.00
0005435697391	16470	Economy	18100.00
0005435697392	16470	Economy	18100.00
0005435697413	16470	Economy	18100.00
0005435697411	16470	Economy	18100.00
0005435697397	16470	Economy	18100.00
0005435935037	16470	Economy	18100.00
0005435697403	16470	Economy	18100.00
0005435697409	16470	Economy	18100.00
0005435697400	16470	Economy	18100.00
0005435697395	16470	Economy	18100.00
0005435697398	16470	Economy	18100.00
0005435697405	16470	Economy	18100.00
0005435697410	16470	Economy	18100.00
0005435697412	16470	Economy	18100.00
0005435935027	16470	Economy	18100.00
0005435697396	16470	Economy	18100.00
0005435697404	16470	Economy	18100.00
0005435697390	16470	Economy	18100.00
0005435697406	16470	Economy	18100.00
0005435697394	16470	Economy	18100.00
0005435697415	16470	Economy	18100.00
0005435697399	16470	Economy	18100.00
0005435697402	16470	Economy	18100.00
0005435697401	16470	Economy	18100.00
0005435697416	16470	Economy	18100.00
0005435697407	16470	Economy	18100.00
0005435697308	24722	Economy	19900.00
0005435697170	24722	Economy	19900.00
0005435697148	24722	Economy	19900.00
0005435935058	24722	Economy	19900.00
0005435697169	24722	Economy	18100.00
0005435697164	24722	Economy	18100.00
0005435697144	24722	Economy	18100.00
0005435697080	24722	Economy	18100.00
0005435697243	24722	Economy	18100.00
0005435697242	24722	Economy	18100.00
0005435697113	24722	Economy	18100.00
0005435697172	24722	Economy	18100.00
0005435697227	24722	Economy	18100.00
0005435697117	24722	Economy	18100.00
0005435697218	24722	Economy	18100.00
0005435697079	24722	Economy	18100.00
0005435697159	24722	Economy	18100.00
0005435697102	24722	Economy	18100.00
0005435697260	24722	Economy	18100.00
0005435697251	24722	Economy	18100.00
0005435697261	24722	Economy	18100.00
0005435697147	24722	Economy	18100.00
0005435697078	24722	Economy	18100.00
0005435697052	24722	Economy	18100.00
0005435697317	24722	Economy	18100.00
0005435697238	24722	Economy	18100.00
0005435697127	24722	Economy	18100.00
0005435697153	24722	Economy	18100.00
0005435697278	24722	Economy	18100.00
0005435697244	24722	Economy	18100.00
0005435697197	24722	Economy	18100.00
0005435697277	24722	Economy	18100.00
0005435697146	24722	Economy	18100.00
0005435697053	24722	Economy	18100.00
0005435697228	24722	Economy	18100.00
0005432968820	18796	Economy	4400.00
0005433724816	18796	Economy	4400.00
0005432968821	18796	Economy	4400.00
0005432968828	18796	Economy	4400.00
0005432968822	18796	Economy	4400.00
0005433724818	18796	Economy	4400.00
0005433724815	18796	Economy	4400.00
0005432968829	18796	Economy	4400.00
0005433724817	18796	Economy	4400.00
0005433724791	21595	Economy	4400.00
0005432968848	21595	Economy	4400.00
0005433724780	21595	Economy	4400.00
0005432968849	21595	Economy	4400.00
0005433724779	21595	Economy	4400.00
0005432968850	21595	Economy	4400.00
0005433724795	21595	Economy	4400.00
0005434138441	7310	Business	23100.00
0005434138464	7310	Business	23100.00
0005434138409	7310	Business	23100.00
0005434138459	7310	Business	23100.00
0005434138421	7310	Business	23100.00
0005434138433	7310	Business	23100.00
0005434138408	7310	Business	23100.00
0005434138446	7310	Business	23100.00
0005434138447	7310	Business	23100.00
0005434138460	7310	Economy	7700.00
0005434138431	7310	Economy	7700.00
0005434138392	7310	Economy	7700.00
0005434138395	7310	Economy	7700.00
0005434138457	7310	Economy	7700.00
0005434138456	7310	Economy	7700.00
0005434138389	7310	Economy	7700.00
0005434138448	7310	Economy	7700.00
0005434087529	7310	Economy	7700.00
0005434138404	7310	Economy	7700.00
0005434138399	7310	Economy	8500.00
0005434138422	7310	Economy	8500.00
0005434138415	7310	Economy	8500.00
0005434138450	7310	Economy	8500.00
0005434138410	7310	Economy	8500.00
0005434138440	7310	Economy	7700.00
0005434138414	7310	Economy	7700.00
0005434138396	7310	Economy	7700.00
0005434138452	7310	Economy	7700.00
0005434138424	7310	Economy	7700.00
0005434138438	7310	Economy	7700.00
0005434138420	7310	Economy	7700.00
0005434138429	7310	Economy	7700.00
0005434138468	7310	Economy	7700.00
0005434138442	7310	Economy	7700.00
0005434138403	7310	Economy	7700.00
0005434138469	7310	Economy	7700.00
0005434138439	7310	Economy	7700.00
0005434138465	7310	Economy	7700.00
0005434138461	7310	Economy	7700.00
0005434138444	7310	Economy	7700.00
0005434138397	7310	Economy	7700.00
0005434138445	7310	Economy	7700.00
0005434138467	7310	Economy	7700.00
0005434138417	7310	Economy	7700.00
0005434087527	7310	Economy	7700.00
0005434138455	7310	Economy	7700.00
0005434138412	7310	Economy	7700.00
0005434138454	7310	Economy	7700.00
0005434138458	7310	Economy	7700.00
0005434138462	7310	Economy	7700.00
0005434138423	7310	Economy	7700.00
0005434138411	7310	Economy	7700.00
0005434138436	7310	Economy	7700.00
0005434087526	7310	Economy	7700.00
0005434138453	7310	Economy	7700.00
0005434138437	7310	Economy	7700.00
0005434138402	7310	Economy	7700.00
0005434138418	7310	Economy	7700.00
0005434138390	7310	Economy	7700.00
0005434138426	7310	Economy	7700.00
0005434138432	7310	Economy	7700.00
0005434138419	7310	Economy	7700.00
0005434138393	7310	Economy	7700.00
0005434087528	7310	Economy	7700.00
0005434138466	7310	Economy	7700.00
0005434138406	7310	Economy	7700.00
0005434138391	7310	Economy	7700.00
0005434138405	7310	Economy	7700.00
0005434138430	7310	Economy	7700.00
0005434138449	7310	Economy	7700.00
0005434138443	7310	Economy	7700.00
0005434138451	7310	Economy	7700.00
0005434138435	7310	Economy	7700.00
0005434138434	7310	Economy	7700.00
0005434138398	7310	Economy	7700.00
0005434138427	7310	Economy	7700.00
0005434138400	7310	Economy	7700.00
0005434087530	7310	Economy	7700.00
0005434138463	7310	Economy	7700.00
0005434138394	7310	Economy	7700.00
0005434138428	7310	Economy	7700.00
0005434138401	7310	Economy	7700.00
0005434138425	7310	Economy	7700.00
0005434138413	7310	Economy	7700.00
0005434138416	7310	Economy	7700.00
0005434138407	7310	Economy	7700.00
0005434137817	28530	Business	23100.00
0005434137498	28530	Business	23100.00
0005434137570	28530	Business	23100.00
0005434137360	28530	Business	23100.00
0005434137559	28530	Business	23100.00
0005434137415	28530	Business	23100.00
0005434137801	28530	Business	23100.00
0005434137675	28530	Business	23100.00
0005434137606	28530	Business	23100.00
0005434137446	28530	Business	23100.00
0005434137778	28530	Business	23100.00
0005434137697	28530	Economy	7700.00
0005434137764	28530	Economy	7700.00
0005434087487	28530	Economy	7700.00
0005434137607	28530	Economy	7700.00
0005434137073	28530	Economy	7700.00
0005434137608	28530	Economy	7700.00
0005434137600	28530	Economy	7700.00
0005434137586	28530	Economy	7700.00
0005434137444	28530	Economy	7700.00
0005434087501	28530	Economy	8500.00
0005434137503	28530	Economy	8500.00
0005434137262	28530	Economy	8500.00
0005434137610	28530	Economy	8500.00
0005434137763	28530	Economy	8500.00
0005434137823	28530	Economy	7700.00
0005434137837	28530	Economy	7700.00
0005434137809	28530	Economy	7700.00
0005434137736	28530	Economy	7700.00
0005434137733	28530	Economy	7700.00
0005434137674	28530	Economy	7700.00
0005434137337	28530	Economy	7700.00
0005434137510	28530	Economy	7700.00
0005434137412	28530	Economy	7700.00
0005434137291	28530	Economy	7700.00
0005434137615	28530	Economy	7700.00
0005434137543	28530	Economy	7700.00
0005434137504	28530	Economy	7700.00
0005434137874	28530	Economy	7700.00
0005434137338	28530	Economy	7700.00
0005434137824	28530	Economy	7700.00
0005434137418	28530	Economy	7700.00
0005434137499	28530	Economy	7700.00
0005434137629	28530	Economy	7700.00
0005434137511	28530	Economy	7700.00
0005434137598	28530	Economy	7700.00
0005434137880	28530	Economy	7700.00
0005434137585	28530	Economy	7700.00
0005434137875	28530	Economy	7700.00
0005434137560	28530	Economy	7700.00
0005434137862	28530	Economy	7700.00
0005434087488	28530	Economy	7700.00
0005434137419	28530	Economy	7700.00
0005434137707	28530	Economy	7700.00
0005434137739	28530	Economy	7700.00
0005434137627	28530	Economy	7700.00
0005434137876	28530	Economy	7700.00
0005434137026	28530	Economy	7700.00
0005434137500	28530	Economy	7700.00
0005434087497	28530	Economy	7700.00
0005434137667	28530	Economy	7700.00
0005434137588	28530	Economy	7700.00
0005434087482	28530	Economy	7700.00
0005434137735	28530	Economy	7700.00
0005434137599	28530	Economy	7700.00
0005434137732	28530	Economy	7700.00
0005434137718	28530	Economy	7700.00
0005434137575	28530	Economy	7700.00
0005434087474	28530	Economy	7700.00
0005434137807	28530	Economy	7700.00
0005434137258	28530	Economy	7700.00
0005434136882	28530	Economy	7700.00
0005434087473	28530	Economy	7700.00
0005434137734	28530	Economy	7700.00
0005434137445	28530	Economy	7700.00
0005434137587	28530	Economy	7700.00
0005434137623	28530	Economy	7700.00
0005434137628	28530	Economy	7700.00
0005434137831	28530	Economy	7700.00
0005434137858	28530	Economy	7700.00
0005434137515	28530	Economy	7700.00
0005434137863	28530	Economy	7700.00
0005434137836	28530	Economy	7700.00
0005434137808	28530	Economy	7700.00
0005434137313	28530	Economy	7700.00
0005434137469	28530	Economy	7700.00
0005434137622	28530	Economy	7700.00
0005434137609	28530	Economy	7700.00
0005434137668	28530	Economy	7700.00
0005434137183	28530	Economy	7700.00
0005434137601	28530	Economy	7700.00
0005433407547	1922	Economy	23900.00
0005435808268	1922	Economy	23900.00
0005433407515	1922	Economy	21700.00
0005434610240	1922	Economy	21700.00
0005435808272	1922	Economy	21700.00
0005433407548	1922	Economy	21700.00
0005435808266	1922	Economy	21700.00
0005435808271	1922	Economy	21700.00
0005435808263	1922	Economy	21700.00
0005433407514	1922	Economy	21700.00
0005435808273	1922	Economy	21700.00
0005435808270	1922	Economy	21700.00
0005433407522	1922	Economy	21700.00
0005433407511	1922	Economy	21700.00
0005434610241	1922	Economy	21700.00
0005433407549	1922	Economy	21700.00
0005434610239	1922	Economy	21700.00
0005435808265	1922	Economy	21700.00
0005433407523	1922	Economy	21700.00
0005435808267	1922	Economy	21700.00
0005433407550	1922	Economy	21700.00
0005435808264	1922	Economy	21700.00
0005435808269	1922	Economy	21700.00
0005434610206	23070	Economy	23900.00
0005434610207	23070	Economy	21700.00
0005434503955	16683	Economy	7600.00
0005434503940	16683	Economy	7600.00
0005434503917	16683	Economy	7600.00
0005434504009	16683	Economy	7600.00
0005434504062	16683	Economy	6900.00
0005434503927	16683	Economy	6900.00
0005434503706	16683	Economy	6900.00
0005434503969	16683	Economy	6900.00
0005434503668	16683	Economy	6900.00
0005434503904	16683	Economy	6900.00
0005434503970	16683	Economy	6900.00
0005434503926	16683	Economy	6900.00
0005434503998	16683	Economy	6900.00
0005434503881	16683	Economy	6900.00
0005434503788	16683	Economy	6900.00
0005434503874	16683	Economy	6900.00
0005434503875	16683	Economy	6900.00
0005434503777	16683	Economy	6900.00
0005434503906	16683	Economy	6900.00
0005434503786	16683	Economy	6900.00
0005434503918	16683	Economy	6900.00
0005434503828	16683	Economy	6900.00
0005434503964	16683	Economy	6900.00
0005434503787	16683	Economy	6900.00
0005434504018	16683	Economy	6900.00
0005434503734	16683	Economy	6900.00
0005434503852	16683	Economy	6900.00
0005434503934	16683	Economy	6900.00
0005434503793	16683	Economy	6900.00
0005434503937	16683	Economy	6900.00
0005434503761	16683	Economy	6900.00
0005434503965	16683	Economy	6900.00
0005434503829	16683	Economy	6900.00
0005434504007	16683	Economy	6900.00
0005434503916	16683	Economy	6900.00
0005434503931	16683	Economy	6900.00
0005434503957	16683	Economy	6900.00
0005434504054	16683	Economy	6900.00
0005434503723	16683	Economy	6900.00
0005434503905	16683	Economy	6900.00
0005434503742	16683	Economy	6900.00
0005434503903	16683	Economy	6900.00
0005434503958	16683	Economy	6900.00
0005434503935	16683	Economy	6900.00
0005434503735	16683	Economy	6900.00
0005434503743	16683	Economy	6900.00
0005434504010	16683	Economy	6900.00
0005434504240	22916	Economy	7600.00
0005434504254	22916	Economy	7600.00
0005434504228	22916	Economy	7600.00
0005434504243	22916	Economy	6900.00
0005434504226	22916	Economy	6900.00
0005434504246	22916	Economy	6900.00
0005434504232	22916	Economy	6900.00
0005434504258	22916	Economy	6900.00
0005434504247	22916	Economy	6900.00
0005434504237	22916	Economy	6900.00
0005434504256	22916	Economy	6900.00
0005434504231	22916	Economy	6900.00
0005434504238	22916	Economy	6900.00
0005434504248	22916	Economy	6900.00
0005434504242	22916	Economy	6900.00
0005434504236	22916	Economy	6900.00
0005434504255	22916	Economy	6900.00
0005434504249	22916	Economy	6900.00
0005434504239	22916	Economy	6900.00
0005434504251	22916	Economy	6900.00
0005434504227	22916	Economy	6900.00
0005434504260	22916	Economy	6900.00
0005434504235	22916	Economy	6900.00
0005434504230	22916	Economy	6900.00
0005434504241	22916	Economy	6900.00
0005434504234	22916	Economy	6900.00
0005434504229	22916	Economy	6900.00
0005434504253	22916	Economy	6900.00
0005434504233	22916	Economy	6900.00
0005434504244	22916	Economy	6900.00
0005434504250	22916	Economy	6900.00
0005434504252	22916	Economy	6900.00
0005434504257	22916	Economy	6900.00
0005434504259	22916	Economy	6900.00
0005434504245	22916	Economy	6900.00
0005435078395	2181	Economy	7700.00
0005435078391	2181	Economy	7700.00
0005433266662	2181	Economy	7700.00
0005435078390	2181	Economy	7000.00
0005435078394	2181	Economy	7000.00
0005435078397	2181	Economy	7000.00
0005435078385	2181	Economy	7000.00
0005433266689	2181	Economy	7000.00
0005435078398	2181	Economy	7000.00
0005435078392	2181	Economy	7000.00
0005435078396	2181	Economy	7000.00
0005435078389	2181	Economy	7000.00
0005433266688	2181	Economy	7000.00
0005435078382	2181	Economy	7000.00
0005433266682	2181	Economy	7000.00
0005435078384	2181	Economy	7000.00
0005435078393	2181	Economy	7000.00
0005433266673	2181	Economy	7000.00
0005435078386	2181	Economy	7000.00
0005433266671	2181	Economy	7000.00
0005433266679	2181	Economy	7000.00
0005435078387	2181	Economy	7000.00
0005433266670	2181	Economy	7000.00
0005435078388	2181	Economy	7000.00
0005433266672	2181	Economy	7000.00
0005435078383	2181	Economy	7000.00
0005433266680	2181	Economy	7000.00
0005433266755	24367	Economy	7700.00
0005435078287	24367	Economy	7700.00
0005433266748	24367	Economy	7000.00
0005433266752	24367	Economy	7000.00
0005433266754	24367	Economy	7000.00
0005433266747	24367	Economy	7000.00
0005435078307	24367	Economy	7000.00
0005433266750	24367	Economy	7000.00
0005435078322	24367	Economy	7000.00
0005433266756	24367	Economy	7000.00
0005433266751	24367	Economy	7000.00
0005435078195	24367	Economy	7000.00
0005435078244	24367	Economy	7000.00
0005435078243	24367	Economy	7000.00
0005435078270	24367	Economy	7000.00
0005435078223	24367	Economy	7000.00
0005435078271	24367	Economy	7000.00
0005435078302	24367	Economy	7000.00
0005433266753	24367	Economy	7000.00
0005435078310	24367	Economy	7000.00
0005435078296	24367	Economy	7000.00
0005435078238	24367	Economy	7000.00
0005435078303	24367	Economy	7000.00
0005435078323	24367	Economy	7000.00
0005435078308	24367	Economy	7000.00
0005433266749	24367	Economy	7000.00
0005434988780	6648	Economy	10800.00
0005434988781	6648	Economy	9800.00
0005435803271	6648	Economy	9800.00
0005435803272	6648	Economy	9800.00
0005435464493	6648	Economy	9800.00
0005434988782	6648	Economy	9800.00
0005434988779	6648	Economy	9800.00
0005434988778	6648	Economy	9800.00
0005434988777	6648	Economy	9800.00
0005435803270	6648	Economy	9800.00
0005435803273	6648	Economy	9800.00
0005434988783	6648	Economy	9800.00
0005434988624	23626	Economy	10800.00
0005435464515	23626	Economy	10800.00
0005434988634	23626	Economy	9800.00
0005435803236	23626	Economy	9800.00
0005435803258	23626	Economy	9800.00
0005434988654	23626	Economy	9800.00
0005434988656	23626	Economy	9800.00
0005435803246	23626	Economy	9800.00
0005434988620	23626	Economy	9800.00
0005434988665	23626	Economy	9800.00
0005435803247	23626	Economy	9800.00
0005435464514	23626	Economy	9800.00
0005434988623	23626	Economy	9800.00
0005435803259	23626	Economy	9800.00
0005434988677	23626	Economy	9800.00
0005435464513	23626	Economy	9800.00
0005434988621	23626	Economy	9800.00
0005434988642	23626	Economy	9800.00
0005434988622	23626	Economy	9800.00
0005434988655	23626	Economy	9800.00
0005433450051	30485	Business	9900.00
0005432383311	30485	Business	9900.00
0005433450043	30485	Business	9900.00
0005432383281	30485	Business	9900.00
0005432383282	30485	Business	9900.00
0005432383283	30485	Business	9900.00
0005432383286	30485	Business	9900.00
0005432383310	30485	Business	9900.00
0005433450045	30485	Economy	3300.00
0005433450029	30485	Economy	3300.00
0005433450035	30485	Economy	3300.00
0005432383289	30485	Economy	3300.00
0005433450034	30485	Economy	3300.00
0005432383305	30485	Economy	3300.00
0005432383314	30485	Economy	3600.00
0005432383296	30485	Economy	3600.00
0005432383294	30485	Economy	3600.00
0005432383290	30485	Economy	3600.00
0005433450032	30485	Economy	3300.00
0005432383297	30485	Economy	3300.00
0005433450037	30485	Economy	3300.00
0005432383292	30485	Economy	3300.00
0005432383279	30485	Economy	3300.00
0005433450033	30485	Economy	3300.00
0005432383284	30485	Economy	3300.00
0005432383302	30485	Economy	3300.00
0005432383301	30485	Economy	3300.00
0005433450046	30485	Economy	3300.00
0005433450038	30485	Economy	3300.00
0005433450030	30485	Economy	3300.00
0005433450039	30485	Economy	3300.00
0005433450031	30485	Economy	3300.00
0005433450044	30485	Economy	3300.00
0005432383295	30485	Economy	3300.00
0005433450036	30485	Economy	3300.00
0005432383303	30485	Economy	3300.00
0005432383299	30485	Economy	3300.00
0005432383316	30485	Economy	3300.00
0005433454882	30485	Economy	3300.00
0005433450042	30485	Economy	3300.00
0005432383315	30485	Economy	3300.00
0005432383307	30485	Economy	3300.00
0005432383288	30485	Economy	3300.00
0005432383309	30485	Economy	3300.00
0005433450049	30485	Economy	3300.00
0005432383280	30485	Economy	3300.00
0005432383308	30485	Economy	3300.00
0005432383287	30485	Economy	3300.00
0005432383306	30485	Economy	3300.00
0005432383300	30485	Economy	3300.00
0005432383285	30485	Economy	3300.00
0005433450040	30485	Economy	3300.00
0005432383293	30485	Economy	3300.00
0005432383291	30485	Economy	3300.00
0005433454881	30485	Economy	3300.00
0005432383304	30485	Economy	3300.00
0005432383298	30485	Economy	3300.00
0005433453768	30485	Economy	3300.00
0005433450047	30485	Economy	3300.00
0005433450050	30485	Economy	3300.00
0005433450041	30485	Economy	3300.00
0005432383312	30485	Economy	3300.00
0005433450048	30485	Economy	3300.00
0005432383313	30485	Economy	3300.00
0005433449855	31319	Business	9900.00
0005433449902	31319	Business	9900.00
0005432383079	31319	Business	9900.00
0005432382940	31319	Business	9900.00
0005432383107	31319	Business	9900.00
0005433451616	31319	Business	9900.00
0005433449958	31319	Business	9900.00
0005432382890	31319	Business	9900.00
0005433449780	31319	Economy	3300.00
0005432382863	31319	Economy	3300.00
0005432382913	31319	Economy	3300.00
0005432382879	31319	Economy	3300.00
0005433449915	31319	Economy	3300.00
0005432382756	31319	Economy	3300.00
0005432382789	31319	Economy	3300.00
0005432382730	31319	Economy	3300.00
0005432382961	31319	Economy	3600.00
0005433449725	31319	Economy	3300.00
0005432382747	31319	Economy	3300.00
0005433449841	31319	Economy	3300.00
0005432382795	31319	Economy	3300.00
0005432382805	31319	Economy	3300.00
0005433449810	31319	Economy	3300.00
0005432382920	31319	Economy	3300.00
0005433449832	31319	Economy	3300.00
0005433449723	31319	Economy	3300.00
0005432382943	31319	Economy	3300.00
0005432382959	31319	Economy	3300.00
0005433449766	31319	Economy	3300.00
0005433449717	31319	Economy	3300.00
0005432382888	31319	Economy	3300.00
0005432382969	31319	Economy	3300.00
0005432382648	31319	Economy	3300.00
0005433451604	31319	Economy	3300.00
0005433449936	31319	Economy	3300.00
0005433449842	31319	Economy	3300.00
0005432382860	31319	Economy	3300.00
0005433449722	31319	Economy	3300.00
0005432383027	31319	Economy	3300.00
0005432382912	31319	Economy	3300.00
0005432382806	31319	Economy	3300.00
0005432382938	31319	Economy	3300.00
0005432382833	31319	Economy	3300.00
0005432383087	31319	Economy	3300.00
0005432382788	31319	Economy	3300.00
0005432382790	31319	Economy	3300.00
0005432382930	31319	Economy	3300.00
0005432382831	31319	Economy	3300.00
0005432382847	31319	Economy	3300.00
0005432383026	31319	Economy	3300.00
0005433449937	31319	Economy	3300.00
0005433449901	31319	Economy	3300.00
0005433449765	31319	Economy	3300.00
0005433788169	26483	Economy	26200.00
0005435548507	26483	Economy	23800.00
0005433788163	26483	Economy	23800.00
0005433788179	26483	Economy	23800.00
0005433788161	26483	Economy	23800.00
0005433788176	26483	Economy	23800.00
0005435548513	26483	Economy	23800.00
0005435548509	26483	Economy	23800.00
0005433788162	26483	Economy	23800.00
0005435548506	26483	Economy	23800.00
0005435548511	26483	Economy	23800.00
0005435548512	26483	Economy	23800.00
0005433788180	26483	Economy	23800.00
0005433788178	26483	Economy	23800.00
0005433788189	26483	Economy	23800.00
0005435548505	26483	Economy	23800.00
0005433788164	26483	Economy	23800.00
0005435548508	26483	Economy	23800.00
0005435548510	26483	Economy	23800.00
0005435299734	10752	Economy	17100.00
0005433131677	10752	Economy	17100.00
0005435299732	10752	Economy	17100.00
0005435299731	10752	Economy	15600.00
0005435299746	10752	Economy	15600.00
0005433131658	10752	Economy	15600.00
0005433131659	10752	Economy	15600.00
0005435299737	10752	Economy	15600.00
0005435304134	10752	Economy	15600.00
0005433131680	10752	Economy	15600.00
0005435304142	10752	Economy	15600.00
0005435304124	10752	Economy	15600.00
0005433126802	10752	Economy	15600.00
0005435304126	10752	Economy	15600.00
0005435304125	10752	Economy	15600.00
0005433126862	29696	Economy	17100.00
0005433129292	29696	Economy	17100.00
0005435299796	29696	Economy	17100.00
0005433129296	29696	Economy	15600.00
0005433126861	29696	Economy	15600.00
0005435302216	29696	Economy	15600.00
0005435299798	29696	Economy	15600.00
0005433129295	29696	Economy	15600.00
0005435299793	29696	Economy	15600.00
0005435302219	29696	Economy	15600.00
0005435299797	29696	Economy	15600.00
0005433126863	29696	Economy	15600.00
0005433126865	29696	Economy	15600.00
0005435299795	29696	Economy	15600.00
0005433129294	29696	Economy	15600.00
0005435299794	29696	Economy	15600.00
0005435302217	29696	Economy	15600.00
0005435302218	29696	Economy	15600.00
0005433129293	29696	Economy	15600.00
0005433126864	29696	Economy	15600.00
0005434287350	2395	Economy	17200.00
0005433109987	2395	Economy	17200.00
0005433109989	2395	Economy	17200.00
0005433109988	2395	Economy	15700.00
0005434287361	2395	Economy	15700.00
0005433110031	2395	Economy	15700.00
0005434287366	2395	Economy	15700.00
0005434287362	2395	Economy	15700.00
0005434287351	2395	Economy	15700.00
0005434287353	2395	Economy	15700.00
0005434287360	2395	Economy	15700.00
0005434287359	2395	Economy	15700.00
0005434287370	2395	Economy	15700.00
0005433109986	2395	Economy	15700.00
0005434287358	2395	Economy	15700.00
0005434287354	2395	Economy	15700.00
0005433110034	2395	Economy	15700.00
0005433110009	2395	Economy	15700.00
0005432264482	2395	Economy	15700.00
0005434287356	2395	Economy	15700.00
0005433109997	2395	Economy	15700.00
0005434287357	2395	Economy	15700.00
0005434287365	2395	Economy	15700.00
0005434287364	2395	Economy	15700.00
0005434287368	2395	Economy	15700.00
0005434287369	2395	Economy	15700.00
0005434287352	2395	Economy	15700.00
0005432264483	2395	Economy	15700.00
0005434287347	2395	Economy	15700.00
0005433109984	2395	Economy	15700.00
0005434287367	2395	Economy	15700.00
0005433110032	2395	Economy	15700.00
0005434287348	2395	Economy	15700.00
0005433109996	2395	Economy	15700.00
0005434287349	2395	Economy	15700.00
0005434287355	2395	Economy	15700.00
0005433110033	2395	Economy	15700.00
0005434287363	2395	Economy	15700.00
0005433110094	26840	Economy	17200.00
0005433110092	26840	Economy	17200.00
0005434287267	26840	Economy	17200.00
0005434287154	26840	Economy	15700.00
0005434287168	26840	Economy	15700.00
0005433110091	26840	Economy	15700.00
0005433110090	26840	Economy	15700.00
0005433110087	26840	Economy	15700.00
0005433110093	26840	Economy	15700.00
0005434287170	26840	Economy	15700.00
0005433110096	26840	Economy	15700.00
0005433110095	26840	Economy	15700.00
0005434287217	26840	Economy	15700.00
0005434287167	26840	Economy	15700.00
0005434287183	26840	Economy	15700.00
0005434287174	26840	Economy	15700.00
0005434287216	26840	Economy	15700.00
0005434287147	26840	Economy	15700.00
0005433110086	26840	Economy	15700.00
0005434287087	26840	Economy	15700.00
0005433110089	26840	Economy	15700.00
0005434287246	26840	Economy	15700.00
0005434287206	26840	Economy	15700.00
0005434287086	26840	Economy	15700.00
0005434287175	26840	Economy	15700.00
0005434287171	26840	Economy	15700.00
0005434287210	26840	Economy	15700.00
0005433110088	26840	Economy	15700.00
0005434287155	26840	Economy	15700.00
0005435856219	25486	Economy	22800.00
0005435856217	25486	Economy	22800.00
0005435856218	25486	Economy	22800.00
0005434269083	25486	Economy	22800.00
0005434269084	25486	Economy	22800.00
0005435856216	25486	Economy	22800.00
0005435856166	26676	Economy	22800.00
0005435856151	26676	Economy	22800.00
0005434520283	6104	Economy	24600.00
0005434520289	6104	Economy	24600.00
0005434520273	6104	Economy	24600.00
0005434520295	6104	Economy	24600.00
0005435314808	6104	Economy	22300.00
0005434520278	6104	Economy	22300.00
0005434520302	6104	Economy	22300.00
0005434520300	6104	Economy	22300.00
0005434520298	6104	Economy	22300.00
0005434520292	6104	Economy	22300.00
0005435314803	6104	Economy	22300.00
0005435314806	6104	Economy	22300.00
0005434520279	6104	Economy	22300.00
0005435314813	6104	Economy	22300.00
0005434520288	6104	Economy	22300.00
0005435314807	6104	Economy	22300.00
0005435314804	6104	Economy	22300.00
0005435314816	6104	Economy	22300.00
0005434520303	6104	Economy	22300.00
0005434520290	6104	Economy	22300.00
0005434520285	6104	Economy	22300.00
0005434520281	6104	Economy	22300.00
0005434520277	6104	Economy	22300.00
0005434520284	6104	Economy	22300.00
0005434520275	6104	Economy	22300.00
0005435314801	6104	Economy	22300.00
0005435314777	6104	Economy	22300.00
0005434520293	6104	Economy	22300.00
0005435314800	6104	Economy	22300.00
0005434520297	6104	Economy	22300.00
0005434520301	6104	Economy	22300.00
0005434520276	6104	Economy	22300.00
0005434520291	6104	Economy	22300.00
0005434520282	6104	Economy	22300.00
0005434520296	6104	Economy	22300.00
0005434520299	6104	Economy	22300.00
0005435314809	6104	Economy	22300.00
0005435314792	6104	Economy	22300.00
0005434520286	6104	Economy	22300.00
0005434520272	6104	Economy	22300.00
0005434520271	6104	Economy	22300.00
0005434520294	6104	Economy	22300.00
0005435314789	6104	Economy	22300.00
0005434520274	6104	Economy	22300.00
0005435314788	6104	Economy	22300.00
0005434520270	6104	Economy	22300.00
0005434520287	6104	Economy	22300.00
0005434520280	6104	Economy	22300.00
0005433650556	27633	Business	89800.00
0005433650510	27633	Business	89800.00
0005433650538	27633	Business	89800.00
0005435263632	27633	Business	89800.00
0005433650476	27633	Business	89800.00
0005433650529	27633	Business	89800.00
0005433650494	27633	Business	89800.00
0005435263638	27633	Business	89800.00
0005433650542	27633	Business	89800.00
0005433650545	27633	Business	89800.00
0005435263618	27633	Business	89800.00
0005435263639	27633	Business	89800.00
0005433650526	27633	Economy	29900.00
0005435263637	27633	Economy	29900.00
0005435263626	27633	Economy	29900.00
0005433650569	27633	Economy	29900.00
0005433650492	27633	Economy	29900.00
0005433650479	27633	Economy	29900.00
0005435263648	27633	Economy	29900.00
0005433650426	27633	Economy	29900.00
0005433650550	27633	Economy	29900.00
0005435263650	27633	Economy	29900.00
0005433650543	27633	Economy	32900.00
0005433650537	27633	Economy	32900.00
0005433650505	27633	Economy	32900.00
0005433650512	27633	Economy	32900.00
0005433650432	27633	Economy	32900.00
0005433650470	27633	Economy	29900.00
0005433650623	27633	Economy	29900.00
0005433650573	27633	Economy	29900.00
0005435263623	27633	Economy	29900.00
0005433650563	27633	Economy	29900.00
0005433650541	27633	Economy	29900.00
0005435263635	27633	Economy	29900.00
0005433650436	27633	Economy	29900.00
0005433650535	27633	Economy	29900.00
0005433650463	27633	Economy	29900.00
0005435263644	27633	Economy	29900.00
0005435263625	27633	Economy	29900.00
0005433650546	27633	Economy	29900.00
0005433650516	27633	Economy	29900.00
0005433650539	27633	Economy	29900.00
0005433650566	27633	Economy	29900.00
0005435263630	27633	Economy	29900.00
0005433650451	27633	Economy	29900.00
0005433650517	27633	Economy	29900.00
0005433650482	27633	Economy	29900.00
0005433650491	27633	Economy	29900.00
0005435263634	27633	Economy	29900.00
0005435263641	27633	Economy	29900.00
0005433650475	27633	Economy	29900.00
0005433650471	27633	Economy	29900.00
0005435263631	27633	Economy	29900.00
0005435263636	27633	Economy	29900.00
0005433650481	27633	Economy	29900.00
0005433650394	27633	Economy	29900.00
0005435263624	27633	Economy	29900.00
0005435263621	27633	Economy	29900.00
0005433650548	27633	Economy	29900.00
0005433650498	27633	Economy	29900.00
0005433650496	27633	Economy	29900.00
0005433650574	27633	Economy	29900.00
0005435263619	27633	Economy	29900.00
0005433650567	27633	Economy	29900.00
0005433650431	27633	Economy	29900.00
0005435263651	27633	Economy	29900.00
0005433650495	27633	Economy	29900.00
0005433650497	27633	Economy	29900.00
0005435263620	27633	Economy	29900.00
0005433650575	27633	Economy	29900.00
0005433650484	27633	Economy	29900.00
0005433650437	27633	Economy	29900.00
0005435263647	27633	Economy	29900.00
0005435263646	27633	Economy	29900.00
0005433650572	27633	Economy	29900.00
0005433650540	27633	Economy	29900.00
0005435263629	27633	Economy	29900.00
0005435263617	27633	Economy	29900.00
0005433650544	27633	Economy	29900.00
0005435263642	27633	Economy	29900.00
0005433650434	27633	Economy	29900.00
0005435263622	27633	Economy	29900.00
0005433650530	27633	Economy	29900.00
0005433650472	27633	Economy	29900.00
0005433650427	27633	Economy	29900.00
0005435263649	27633	Economy	29900.00
0005435263640	27633	Economy	29900.00
0005435263633	27633	Economy	29900.00
0005433650488	27633	Economy	29900.00
0005433650518	27633	Economy	29900.00
0005433650527	27633	Economy	29900.00
0005433650549	27633	Economy	29900.00
0005435263628	27633	Economy	29900.00
0005433650525	27633	Economy	29900.00
0005435263627	27633	Economy	29900.00
0005435263643	27633	Economy	29900.00
0005435263645	27633	Economy	29900.00
0005433868571	4800	Economy	19400.00
0005433868569	4800	Economy	19400.00
0005433868591	4800	Economy	19400.00
0005433868592	4800	Economy	19400.00
0005433868564	4800	Economy	17600.00
0005433868575	4800	Economy	17600.00
0005433868585	4800	Economy	17600.00
0005433868567	4800	Economy	17600.00
0005433868578	4800	Economy	17600.00
0005433868568	4800	Economy	17600.00
0005433868584	4800	Economy	17600.00
0005433868582	4800	Economy	17600.00
0005433868560	4800	Economy	17600.00
0005433868561	4800	Economy	17600.00
0005433868559	4800	Economy	17600.00
0005433868554	4800	Economy	17600.00
0005433868555	4800	Economy	17600.00
0005433868589	4800	Economy	17600.00
0005435860466	4800	Economy	17600.00
0005435860457	4800	Economy	17600.00
0005433868580	4800	Economy	17600.00
0005433868586	4800	Economy	17600.00
0005433868566	4800	Economy	17600.00
0005433868573	4800	Economy	17600.00
0005433868581	4800	Economy	17600.00
0005435860458	4800	Economy	17600.00
0005433868562	4800	Economy	17600.00
0005433868590	4800	Economy	17600.00
0005433868583	4800	Economy	17600.00
0005433868556	4800	Economy	17600.00
0005433868572	4800	Economy	17600.00
0005435860456	4800	Economy	17600.00
0005433868587	4800	Economy	17600.00
0005433868557	4800	Economy	17600.00
0005433868552	4800	Economy	17600.00
0005433868565	4800	Economy	17600.00
0005433868570	4800	Economy	17600.00
0005433868553	4800	Economy	17600.00
0005433868577	4800	Economy	17600.00
0005433868574	4800	Economy	17600.00
0005433868558	4800	Economy	17600.00
0005433868579	4800	Economy	17600.00
0005433868593	4800	Economy	17600.00
0005433868588	4800	Economy	17600.00
0005433868576	4800	Economy	17600.00
0005433868563	4800	Economy	17600.00
0005433868444	32576	Economy	19400.00
0005433868215	32576	Economy	19400.00
0005433868257	32576	Economy	19400.00
0005433868007	32576	Economy	17600.00
0005433868076	32576	Economy	17600.00
0005433868069	32576	Economy	17600.00
0005433868206	32576	Economy	17600.00
0005433868077	32576	Economy	17600.00
0005433868282	32576	Economy	17600.00
0005433868102	32576	Economy	17600.00
0005433868106	32576	Economy	17600.00
0005435860501	32576	Economy	17600.00
0005433868166	32576	Economy	17600.00
0005433868445	32576	Economy	17600.00
0005433868085	32576	Economy	17600.00
0005433868067	32576	Economy	17600.00
0005433868287	32576	Economy	17600.00
0005433868285	32576	Economy	17600.00
0005433868298	32576	Economy	17600.00
0005433868197	32576	Economy	17600.00
0005433868300	32576	Economy	17600.00
0005433868117	32576	Economy	17600.00
0005433868283	32576	Economy	17600.00
0005433868286	32576	Economy	17600.00
0005433868072	32576	Economy	17600.00
0005433868319	32576	Economy	17600.00
0005433868071	32576	Economy	17600.00
0005433868259	32576	Economy	17600.00
0005433868068	32576	Economy	17600.00
0005435860500	32576	Economy	17600.00
0005433868171	32576	Economy	17600.00
0005433868028	32576	Economy	17600.00
0005433868299	32576	Economy	17600.00
0005433868151	32576	Economy	17600.00
0005433868284	32576	Economy	17600.00
0005433868107	32576	Economy	17600.00
0005433868243	32576	Economy	17600.00
0005433868103	32576	Economy	17600.00
0005433868204	32576	Economy	17600.00
0005433868105	32576	Economy	17600.00
0005433867994	32576	Economy	17600.00
0005433867970	32576	Economy	17600.00
0005433868258	32576	Economy	17600.00
0005434663457	3460	Economy	24800.00
0005434663451	3460	Economy	24800.00
0005434663450	3460	Economy	24800.00
0005434663444	3460	Economy	22600.00
0005434663453	3460	Economy	22600.00
0005435911419	3460	Economy	22600.00
0005434663446	3460	Economy	22600.00
0005434663445	3460	Economy	22600.00
0005434460513	3460	Economy	22600.00
0005434663456	3460	Economy	22600.00
0005435911371	3460	Economy	22600.00
0005435911435	3460	Economy	22600.00
0005435911397	3460	Economy	22600.00
0005434663448	3460	Economy	22600.00
0005434663447	3460	Economy	22600.00
0005434461653	3460	Economy	22600.00
0005434663455	3460	Economy	22600.00
0005435911428	3460	Economy	22600.00
0005434460511	3460	Economy	22600.00
0005434461654	3460	Economy	22600.00
0005434663452	3460	Economy	22600.00
0005434460512	3460	Economy	22600.00
0005435911434	3460	Economy	22600.00
0005434663454	3460	Economy	22600.00
0005434663449	3460	Economy	22600.00
0005435911388	3460	Economy	22600.00
0005435911429	3460	Economy	22600.00
0005434663458	3460	Economy	22600.00
0005434663267	12480	Economy	24800.00
0005434663341	12480	Economy	24800.00
0005434663304	12480	Economy	22600.00
0005434663339	12480	Economy	22600.00
0005434663338	12480	Economy	22600.00
0005435911477	12480	Economy	22600.00
0005434663340	12480	Economy	22600.00
0005434663357	12480	Economy	22600.00
0005434663306	12480	Economy	22600.00
0005435911475	12480	Economy	22600.00
0005435911476	12480	Economy	22600.00
0005434663309	12480	Economy	22600.00
0005435911474	12480	Economy	22600.00
0005434663305	12480	Economy	22600.00
0005435911473	12480	Economy	22600.00
0005434663345	12480	Economy	22600.00
0005434663333	12480	Economy	22600.00
0005434663266	12480	Economy	22600.00
0005435911478	12480	Economy	22600.00
0005433867994	14481	Economy	18500.00
0005433868085	14481	Economy	18500.00
0005433868151	14481	Economy	18500.00
0005433868445	14481	Economy	16800.00
0005433868215	14481	Economy	16800.00
0005433868071	14481	Economy	16800.00
0005433868257	14481	Economy	16800.00
0005433868072	14481	Economy	16800.00
0005433868285	14481	Economy	16800.00
0005433868444	14481	Economy	16800.00
0005433868107	14481	Economy	16800.00
0005433868286	14481	Economy	16800.00
0005433868076	14481	Economy	16800.00
0005433868243	14481	Economy	16800.00
0005433868106	14481	Economy	16800.00
0005433868068	14481	Economy	16800.00
0005433868067	14481	Economy	16800.00
0005433868077	14481	Economy	16800.00
0005435860500	14481	Economy	16800.00
0005435860501	14481	Economy	16800.00
0005433868103	14481	Economy	16800.00
0005433868319	14481	Economy	16800.00
0005433868171	14481	Economy	16800.00
0005433868197	14481	Economy	16800.00
0005433868028	14481	Economy	16800.00
0005433868206	14481	Economy	16800.00
0005433868287	14481	Economy	16800.00
0005433868102	14481	Economy	16800.00
0005433868007	14481	Economy	16800.00
0005433868204	14481	Economy	16800.00
0005433868283	14481	Economy	16800.00
0005433868117	14481	Economy	16800.00
0005433868258	14481	Economy	16800.00
0005433868105	14481	Economy	16800.00
0005433868259	14481	Economy	16800.00
0005433868069	14481	Economy	16800.00
0005433868282	14481	Economy	16800.00
0005433868284	14481	Economy	16800.00
0005433867970	14481	Economy	16800.00
0005433868299	14481	Economy	16800.00
0005433868298	14481	Economy	16800.00
0005433868300	14481	Economy	16800.00
0005433868166	14481	Economy	16800.00
0005433868535	32670	Economy	18500.00
0005433868539	32670	Economy	18500.00
0005433868548	32670	Economy	18500.00
0005433868517	32670	Economy	18500.00
0005435860454	32670	Economy	16800.00
0005433868529	32670	Economy	16800.00
0005433868532	32670	Economy	16800.00
0005433868541	32670	Economy	16800.00
0005435860461	32670	Economy	16800.00
0005433868524	32670	Economy	16800.00
0005433868514	32670	Economy	16800.00
0005433868516	32670	Economy	16800.00
0005433868526	32670	Economy	16800.00
0005433868538	32670	Economy	16800.00
0005435860453	32670	Economy	16800.00
0005433868531	32670	Economy	16800.00
0005433868537	32670	Economy	16800.00
0005433868534	32670	Economy	16800.00
0005433868550	32670	Economy	16800.00
0005433868536	32670	Economy	16800.00
0005433868513	32670	Economy	16800.00
0005433868515	32670	Economy	16800.00
0005433868551	32670	Economy	16800.00
0005433868549	32670	Economy	16800.00
0005433868519	32670	Economy	16800.00
0005433868543	32670	Economy	16800.00
0005433868544	32670	Economy	16800.00
0005433868540	32670	Economy	16800.00
0005433868542	32670	Economy	16800.00
0005433868522	32670	Economy	16800.00
0005433868547	32670	Economy	16800.00
0005433868533	32670	Economy	16800.00
0005433868545	32670	Economy	16800.00
0005433868523	32670	Economy	16800.00
0005433868528	32670	Economy	16800.00
0005433868527	32670	Economy	16800.00
0005433868525	32670	Economy	16800.00
0005433868520	32670	Economy	16800.00
0005433868518	32670	Economy	16800.00
0005433868530	32670	Economy	16800.00
0005433868546	32670	Economy	16800.00
0005435860460	32670	Economy	16800.00
0005433868521	32670	Economy	16800.00
0005432799287	12114	Economy	4900.00
0005432799229	12114	Economy	4900.00
0005432799288	12114	Economy	4400.00
0005432799205	12114	Economy	4400.00
0005432799301	12114	Economy	4400.00
0005432799392	12114	Economy	4400.00
0005432799247	12114	Economy	4400.00
0005432799216	12114	Economy	4400.00
0005432799357	12114	Economy	4400.00
0005432799356	12114	Economy	4400.00
0005432799273	12114	Economy	4400.00
0005432799303	12114	Economy	4400.00
0005432799414	12114	Economy	4400.00
0005432799171	12114	Economy	4400.00
0005432799304	12114	Economy	4400.00
0005432799355	12114	Economy	4400.00
0005432799300	12114	Economy	4400.00
0005432799391	12114	Economy	4400.00
0005432799299	12114	Economy	4400.00
0005432799376	12114	Economy	4400.00
0005432799505	14833	Economy	4900.00
0005432799521	14833	Economy	4900.00
0005432799506	14833	Economy	4900.00
0005432799504	14833	Economy	4400.00
0005432799524	14833	Economy	4400.00
0005432799509	14833	Economy	4400.00
0005432799519	14833	Economy	4400.00
0005432799520	14833	Economy	4400.00
0005432799528	14833	Economy	4400.00
0005432799516	14833	Economy	4400.00
0005432799510	14833	Economy	4400.00
0005432799522	14833	Economy	4400.00
0005432799530	14833	Economy	4400.00
0005432799526	14833	Economy	4400.00
0005432799527	14833	Economy	4400.00
0005432799529	14833	Economy	4400.00
0005432799507	14833	Economy	4400.00
0005432799517	14833	Economy	4400.00
0005432799513	14833	Economy	4400.00
0005432799523	14833	Economy	4400.00
0005432799525	14833	Economy	4400.00
0005432799502	14833	Economy	4400.00
0005432799515	14833	Economy	4400.00
0005432799512	14833	Economy	4400.00
0005432799514	14833	Economy	4400.00
0005432799503	14833	Economy	4400.00
0005432799511	14833	Economy	4400.00
0005432799508	14833	Economy	4400.00
0005432799518	14833	Economy	4400.00
0005434299637	7071	Business	49100.00
0005434407966	7071	Business	49100.00
0005434299627	7071	Business	49100.00
0005434299632	7071	Business	49100.00
0005434407987	7071	Business	49100.00
0005434407967	7071	Business	49100.00
0005432153960	7071	Business	49100.00
0005434407955	7071	Business	49100.00
0005435293203	7071	Business	49100.00
0005434407950	7071	Business	49100.00
0005435310983	7071	Business	49100.00
0005434407941	7071	Economy	16400.00
0005432108259	7071	Economy	16400.00
0005435293186	7071	Economy	16400.00
0005434407957	7071	Economy	16400.00
0005434407964	7071	Economy	16400.00
0005434407949	7071	Economy	16400.00
0005435310945	7071	Economy	16400.00
0005434407961	7071	Economy	16400.00
0005434299645	7071	Economy	16400.00
0005434299629	7071	Economy	16400.00
0005434407984	7071	Economy	16400.00
0005435310949	7071	Economy	16400.00
0005435310993	7071	Economy	16400.00
0005434407980	7071	Economy	16400.00
0005434407986	7071	Economy	16400.00
0005435310939	7071	Economy	16400.00
0005434299634	7071	Economy	16400.00
0005434407975	7071	Economy	16400.00
0005434299643	7071	Economy	16400.00
0005435310940	7071	Economy	16400.00
0005434299639	7071	Economy	16400.00
0005434407960	7071	Economy	16400.00
0005435293177	7071	Economy	16400.00
0005434407958	7071	Economy	16400.00
0005434407992	7071	Economy	16400.00
0005434299626	7071	Economy	16400.00
0005434407962	7071	Economy	16400.00
0005434299640	7071	Economy	16400.00
0005435293193	7071	Economy	16400.00
0005434299624	7071	Economy	16400.00
0005434407985	7071	Economy	16400.00
0005434407946	7071	Economy	16400.00
0005434407937	7071	Economy	16400.00
0005434299641	7071	Economy	16400.00
0005434407954	7071	Economy	16400.00
0005434299628	7071	Economy	16400.00
0005434299638	7071	Economy	16400.00
0005434407933	7071	Economy	18000.00
0005434407940	7071	Economy	18000.00
0005434407965	7071	Economy	18000.00
0005435310987	7071	Economy	18000.00
0005434299636	7071	Economy	18000.00
0005434407979	7071	Economy	18000.00
0005434407939	7071	Economy	16400.00
0005434407952	7071	Economy	16400.00
0005434407945	7071	Economy	16400.00
0005434407930	7071	Economy	16400.00
0005434299622	7071	Economy	16400.00
0005434407974	7071	Economy	16400.00
0005434407983	7071	Economy	16400.00
0005434407973	7071	Economy	16400.00
0005434407990	7071	Economy	16400.00
0005435310926	7071	Economy	16400.00
0005432108258	7071	Economy	16400.00
0005434407971	7071	Economy	16400.00
0005434299630	7071	Economy	16400.00
0005435310927	7071	Economy	16400.00
0005434407959	7071	Economy	16400.00
0005434407936	7071	Economy	16400.00
0005435310977	7071	Economy	16400.00
0005434299623	7071	Economy	16400.00
0005434407988	7071	Economy	16400.00
0005435310982	7071	Economy	16400.00
0005432153958	7071	Economy	16400.00
0005434407977	7071	Economy	16400.00
0005434299635	7071	Economy	16400.00
0005434407981	7071	Economy	16400.00
0005435293192	7071	Economy	16400.00
0005434407951	7071	Economy	16400.00
0005435311003	7071	Economy	16400.00
0005434407968	7071	Economy	16400.00
0005432153957	7071	Economy	16400.00
0005435310928	7071	Economy	16400.00
0005434407953	7071	Economy	16400.00
0005435310986	7071	Economy	16400.00
0005432108257	7071	Economy	16400.00
0005434299642	7071	Economy	16400.00
0005434299625	7071	Economy	16400.00
0005434407935	7071	Economy	16400.00
0005434407934	7071	Economy	16400.00
0005434407963	7071	Economy	16400.00
0005434407989	7071	Economy	16400.00
0005435293150	7071	Economy	16400.00
0005434299644	7071	Economy	16400.00
0005434407944	7071	Economy	16400.00
0005432153959	7071	Economy	16400.00
0005435310992	7071	Economy	16400.00
0005432153961	7071	Economy	16400.00
0005434407969	7071	Economy	16400.00
0005432153962	7071	Economy	16400.00
0005434407947	7071	Economy	16400.00
0005434407970	7071	Economy	16400.00
0005434407931	7071	Economy	16400.00
0005434407972	7071	Economy	16400.00
0005434407938	7071	Economy	16400.00
0005434407991	7071	Economy	16400.00
0005434407942	7071	Economy	16400.00
0005434299633	7071	Economy	16400.00
0005434299631	7071	Economy	16400.00
0005435310951	7071	Economy	16400.00
0005434407982	7071	Economy	16400.00
0005434407978	7071	Economy	16400.00
0005435310976	7071	Economy	16400.00
0005434407956	7071	Economy	16400.00
0005434407932	7071	Economy	16400.00
0005435293187	7071	Economy	16400.00
0005434407948	7071	Economy	16400.00
0005434407993	7071	Economy	16400.00
0005435293190	7071	Economy	16400.00
0005432153963	7071	Economy	16400.00
0005434407976	7071	Economy	16400.00
0005434407943	7071	Economy	16400.00
0005435310967	7071	Economy	16400.00
0005435311088	26922	Business	49100.00
0005434407190	26922	Business	49100.00
0005435293292	26922	Business	49100.00
0005434299512	26922	Business	49100.00
0005434407389	26922	Business	49100.00
0005435293295	26922	Business	49100.00
0005434407175	26922	Business	49100.00
0005435293297	26922	Business	49100.00
0005434407312	26922	Business	49100.00
0005434407373	26922	Business	49100.00
0005434407552	26922	Economy	16400.00
0005434299477	26922	Economy	16400.00
0005434407304	26922	Economy	16400.00
0005434407408	26922	Economy	16400.00
0005434299442	26922	Economy	16400.00
0005434407457	26922	Economy	16400.00
0005434407527	26922	Economy	16400.00
0005434407508	26922	Economy	16400.00
0005434407075	26922	Economy	16400.00
0005434299437	26922	Economy	16400.00
0005434407169	26922	Economy	16400.00
0005434407237	26922	Economy	16400.00
0005434407076	26922	Economy	16400.00
0005434407251	26922	Economy	16400.00
0005434299565	26922	Economy	16400.00
0005434299344	26922	Economy	16400.00
0005434407303	26922	Economy	16400.00
0005434407407	26922	Economy	16400.00
0005434299406	26922	Economy	16400.00
0005434407191	26922	Economy	16400.00
0005434407421	26922	Economy	16400.00
0005434407454	26922	Economy	16400.00
0005435311093	26922	Economy	16400.00
0005434407217	26922	Economy	16400.00
0005434407478	26922	Economy	16400.00
0005434407205	26922	Economy	16400.00
0005434407168	26922	Economy	16400.00
0005434407558	26922	Economy	16400.00
0005432058390	26922	Economy	16400.00
0005434407595	26922	Economy	16400.00
0005434407141	26922	Economy	16400.00
0005434407211	26922	Economy	16400.00
0005434406700	26922	Economy	16400.00
0005434407195	26922	Economy	16400.00
0005434407392	26922	Economy	16400.00
0005434299426	26922	Economy	16400.00
0005434407362	26922	Economy	16400.00
0005434407485	26922	Economy	18000.00
0005435311090	26922	Economy	18000.00
0005434407550	26922	Economy	18000.00
0005434299534	26922	Economy	18000.00
0005434407096	26922	Economy	18000.00
0005434407238	26922	Economy	16400.00
0005434407479	26922	Economy	16400.00
0005434407170	26922	Economy	16400.00
0005434407383	26922	Economy	16400.00
0005435293296	26922	Economy	16400.00
0005432058389	26922	Economy	16400.00
0005435293286	26922	Economy	16400.00
0005434299354	26922	Economy	16400.00
0005434407343	26922	Economy	16400.00
0005435311091	26922	Economy	16400.00
0005434407537	26922	Economy	16400.00
0005434407351	26922	Economy	16400.00
0005434407365	26922	Economy	16400.00
0005434407477	26922	Economy	16400.00
0005434407489	26922	Economy	16400.00
0005435293290	26922	Economy	16400.00
0005435311089	26922	Economy	16400.00
0005434299427	26922	Economy	16400.00
0005432058391	26922	Economy	16400.00
0005434407438	26922	Economy	16400.00
0005434407186	26922	Economy	16400.00
0005434299436	26922	Economy	16400.00
0005434407437	26922	Economy	16400.00
0005434407118	26922	Economy	16400.00
0005434407569	26922	Economy	16400.00
0005434407124	26922	Economy	16400.00
0005434407142	26922	Economy	16400.00
0005434407204	26922	Economy	16400.00
0005434407352	26922	Economy	16400.00
0005434407212	26922	Economy	16400.00
0005434407171	26922	Economy	16400.00
0005434407553	26922	Economy	16400.00
0005434407638	26922	Economy	16400.00
0005434299524	26922	Economy	16400.00
0005434407159	26922	Economy	16400.00
0005434407563	26922	Economy	16400.00
0005434407293	26922	Economy	16400.00
0005435311092	26922	Economy	16400.00
0005434407279	26922	Economy	16400.00
0005434407372	26922	Economy	16400.00
0005434406920	26922	Economy	16400.00
0005435293288	26922	Economy	16400.00
0005434407538	26922	Economy	16400.00
0005435293293	26922	Economy	16400.00
0005434407317	26922	Economy	16400.00
0005434299497	26922	Economy	16400.00
0005434407453	26922	Economy	16400.00
0005434407409	26922	Economy	16400.00
0005432058392	26922	Economy	16400.00
0005435293287	26922	Economy	16400.00
0005434407562	26922	Economy	16400.00
0005434299513	26922	Economy	16400.00
0005434299566	26922	Economy	16400.00
0005434299537	26922	Economy	16400.00
0005434407185	26922	Economy	16400.00
0005435293294	26922	Economy	16400.00
0005434407194	26922	Economy	16400.00
0005434299190	26922	Economy	16400.00
0005434299554	26922	Economy	16400.00
0005435293289	26922	Economy	16400.00
0005434407509	26922	Economy	16400.00
0005434407388	26922	Economy	16400.00
0005434299191	26922	Economy	16400.00
0005434407127	26922	Economy	16400.00
0005434299424	26922	Economy	16400.00
0005434407138	26922	Economy	16400.00
0005434407449	26922	Economy	16400.00
0005434407480	26922	Economy	16400.00
0005434299443	26922	Economy	16400.00
0005434407370	26922	Economy	16400.00
0005434299476	26922	Economy	16400.00
0005435293291	26922	Economy	16400.00
0005432604479	6445	Economy	16500.00
0005432604453	6445	Economy	16500.00
0005432604467	6445	Economy	15000.00
0005432604478	6445	Economy	15000.00
0005432604470	6445	Economy	15000.00
0005432604492	6445	Economy	15000.00
0005432604477	6445	Economy	15000.00
0005432604464	6445	Economy	15000.00
0005432604459	6445	Economy	15000.00
0005432604458	6445	Economy	15000.00
0005432604480	6445	Economy	15000.00
0005434512128	6445	Economy	15000.00
0005432604493	6445	Economy	15000.00
0005432604473	6445	Economy	15000.00
0005432604475	6445	Economy	15000.00
0005432604457	6445	Economy	15000.00
0005432604491	6445	Economy	15000.00
0005432604481	6445	Economy	15000.00
0005432604483	6445	Economy	15000.00
0005432604490	6445	Economy	15000.00
0005432604460	6445	Economy	15000.00
0005432604463	6445	Economy	15000.00
0005432604489	6445	Economy	15000.00
0005432604468	6445	Economy	15000.00
0005432604484	6445	Economy	15000.00
0005432604476	6445	Economy	15000.00
0005432604486	6445	Economy	15000.00
0005432604461	6445	Economy	15000.00
0005432604465	6445	Economy	15000.00
0005432604471	6445	Economy	15000.00
0005432604454	6445	Economy	15000.00
0005432604472	6445	Economy	15000.00
0005432604487	6445	Economy	15000.00
0005432604469	6445	Economy	15000.00
0005432604456	6445	Economy	15000.00
0005432604466	6445	Economy	15000.00
0005432604488	6445	Economy	15000.00
0005432604462	6445	Economy	15000.00
0005432604455	6445	Economy	15000.00
0005432604474	6445	Economy	15000.00
0005432604482	6445	Economy	15000.00
0005434512127	6445	Economy	15000.00
0005432604485	6445	Economy	15000.00
0005432604138	21369	Economy	16500.00
0005432604137	21369	Economy	16500.00
0005435221517	21369	Economy	16500.00
0005432604122	21369	Economy	16500.00
0005434512091	21369	Economy	15000.00
0005434512087	21369	Economy	15000.00
0005432604004	21369	Economy	15000.00
0005432604121	21369	Economy	15000.00
0005434512088	21369	Economy	15000.00
0005432604108	21369	Economy	15000.00
0005432604140	21369	Economy	15000.00
0005432604209	21369	Economy	15000.00
0005432604139	21369	Economy	15000.00
0005432604016	21369	Economy	15000.00
0005432604208	21369	Economy	15000.00
0005432604092	21369	Economy	15000.00
0005432604155	21369	Economy	15000.00
0005432604093	21369	Economy	15000.00
0005432604109	21369	Economy	15000.00
0005432604102	21369	Economy	15000.00
0005432604017	21369	Economy	15000.00
0005432604193	21369	Economy	15000.00
0005432603849	21369	Economy	15000.00
0005432604025	21369	Economy	15000.00
0005432604147	21369	Economy	15000.00
0005435221057	21369	Economy	15000.00
0005432604280	21369	Economy	15000.00
0005432604144	21369	Economy	15000.00
0005432604011	21369	Economy	15000.00
0005432604132	21369	Economy	15000.00
0005432604156	21369	Economy	15000.00
0005432604117	21369	Economy	15000.00
0005432604107	21369	Economy	15000.00
0005432604207	21369	Economy	15000.00
0005435221518	21369	Economy	15000.00
0005432604085	21369	Economy	15000.00
0005434906940	14970	Business	18900.00
0005433251575	14970	Business	18900.00
0005433251568	14970	Business	18900.00
0005434907095	14970	Business	18900.00
0005433251574	14970	Business	18900.00
0005434906802	14970	Business	18900.00
0005434907080	14970	Business	18900.00
0005434906633	14970	Business	18900.00
0005434906815	14970	Business	18900.00
0005433251570	14970	Business	18900.00
0005434906935	14970	Business	18900.00
0005433251584	14970	Economy	6300.00
0005433251579	14970	Economy	6300.00
0005434907090	14970	Economy	6300.00
0005433251577	14970	Economy	6300.00
0005433251586	14970	Economy	6300.00
0005434906972	14970	Economy	6300.00
0005433251587	14970	Economy	6300.00
0005433251565	14970	Economy	6300.00
0005434907018	14970	Economy	6300.00
0005434907129	14970	Economy	6900.00
0005434906933	14970	Economy	6900.00
0005434906863	14970	Economy	6900.00
0005434907071	14970	Economy	6300.00
0005433251578	14970	Economy	6300.00
0005433251562	14970	Economy	6300.00
0005434907006	14970	Economy	6300.00
0005434906996	14970	Economy	6300.00
0005434907118	14970	Economy	6300.00
0005434906872	14970	Economy	6300.00
0005433251583	14970	Economy	6300.00
0005434907094	14970	Economy	6300.00
0005434906934	14970	Economy	6300.00
0005434906882	14970	Economy	6300.00
0005434906689	14970	Economy	6300.00
0005434906873	14970	Economy	6300.00
0005433251564	14970	Economy	6300.00
0005434906846	14970	Economy	6300.00
0005434906817	14970	Economy	6300.00
0005434906993	14970	Economy	6300.00
0005433251581	14970	Economy	6300.00
0005433251580	14970	Economy	6300.00
0005434907009	14970	Economy	6300.00
0005434906632	14970	Economy	6300.00
0005434906942	14970	Economy	6300.00
0005434907076	14970	Economy	6300.00
0005433251571	14970	Economy	6300.00
0005433251567	14970	Economy	6300.00
0005433251561	14970	Economy	6300.00
0005434906759	14970	Economy	6300.00
0005434906973	14970	Economy	6300.00
0005433251589	14970	Economy	6300.00
0005434906758	14970	Economy	6300.00
0005434907089	14970	Economy	6300.00
0005433251572	14970	Economy	6300.00
0005434906891	14970	Economy	6300.00
0005434906602	14970	Economy	6300.00
0005434907116	14970	Economy	6300.00
0005434906803	14970	Economy	6300.00
0005433251563	14970	Economy	6300.00
0005433251590	14970	Economy	6300.00
0005434906845	14970	Economy	6300.00
0005434906997	14970	Economy	6300.00
0005434907049	14970	Economy	6300.00
0005433251588	14970	Economy	6300.00
0005433251585	14970	Economy	6300.00
0005434906938	14970	Economy	6300.00
0005434906859	14970	Economy	6300.00
0005434907088	14970	Economy	6300.00
0005434906816	14970	Economy	6300.00
0005433251569	14970	Economy	6300.00
0005434907119	14970	Economy	6300.00
0005434907117	14970	Economy	6300.00
0005433251560	14970	Economy	6300.00
0005433251576	14970	Economy	6300.00
0005434906976	14970	Economy	6300.00
0005433251573	14970	Economy	6300.00
0005434907001	14970	Economy	6300.00
0005433251582	14970	Economy	6300.00
0005433251566	14970	Economy	6300.00
0005433251335	25830	Business	18900.00
0005434907434	25830	Business	18900.00
0005434907384	25830	Business	18900.00
0005434907380	25830	Business	18900.00
0005434907377	25830	Business	18900.00
0005433251360	25830	Business	18900.00
0005434907391	25830	Business	18900.00
0005434907419	25830	Business	18900.00
0005434907408	25830	Business	18900.00
0005434907405	25830	Business	18900.00
0005434907404	25830	Business	18900.00
0005434907386	25830	Business	18900.00
0005433251411	25830	Economy	6300.00
0005434907392	25830	Economy	6300.00
0005434907372	25830	Economy	6300.00
0005434907424	25830	Economy	6300.00
0005434907414	25830	Economy	6300.00
0005434907412	25830	Economy	6300.00
0005434907396	25830	Economy	6300.00
0005434907394	25830	Economy	6300.00
0005434907417	25830	Economy	6300.00
0005434907395	25830	Economy	6900.00
0005434907420	25830	Economy	6900.00
0005434907429	25830	Economy	6900.00
0005434907422	25830	Economy	6900.00
0005434907393	25830	Economy	6900.00
0005434907426	25830	Economy	6300.00
0005434907411	25830	Economy	6300.00
0005433251214	25830	Economy	6300.00
0005434907390	25830	Economy	6300.00
0005434907397	25830	Economy	6300.00
0005433251365	25830	Economy	6300.00
0005433251334	25830	Economy	6300.00
0005433251253	25830	Economy	6300.00
0005433251213	25830	Economy	6300.00
0005433251361	25830	Economy	6300.00
0005434907433	25830	Economy	6300.00
0005434907401	25830	Economy	6300.00
0005434907388	25830	Economy	6300.00
0005434907423	25830	Economy	6300.00
0005434907398	25830	Economy	6300.00
0005434907432	25830	Economy	6300.00
0005434907430	25830	Economy	6300.00
0005434907387	25830	Economy	6300.00
0005434907378	25830	Economy	6300.00
0005434907382	25830	Economy	6300.00
0005434907418	25830	Economy	6300.00
0005434907381	25830	Economy	6300.00
0005434907379	25830	Economy	6300.00
0005433251266	25830	Economy	6300.00
0005433251289	25830	Economy	6300.00
0005434907374	25830	Economy	6300.00
0005434907400	25830	Economy	6300.00
0005434907425	25830	Economy	6300.00
0005434907373	25830	Economy	6300.00
0005434907406	25830	Economy	6300.00
0005434907399	25830	Economy	6300.00
0005433251378	25830	Economy	6300.00
0005434907403	25830	Economy	6300.00
0005433251265	25830	Economy	6300.00
0005433251297	25830	Economy	6300.00
0005434907407	25830	Economy	6300.00
0005433251376	25830	Economy	6300.00
0005433251267	25830	Economy	6300.00
0005434907421	25830	Economy	6300.00
0005433251296	25830	Economy	6300.00
0005434907376	25830	Economy	6300.00
0005434907410	25830	Economy	6300.00
0005434907375	25830	Economy	6300.00
0005434907409	25830	Economy	6300.00
0005434907435	25830	Economy	6300.00
0005434907431	25830	Economy	6300.00
0005434907416	25830	Economy	6300.00
0005434907389	25830	Economy	6300.00
0005434907385	25830	Economy	6300.00
0005434907413	25830	Economy	6300.00
0005434907383	25830	Economy	6300.00
0005434907415	25830	Economy	6300.00
0005434907428	25830	Economy	6300.00
0005434907427	25830	Economy	6300.00
0005433251508	25830	Economy	6300.00
0005434907402	25830	Economy	6300.00
0005433251337	25830	Economy	6300.00
0005433251244	25830	Economy	6300.00
0005433008774	14155	Business	52300.00
0005433008793	14155	Business	52300.00
0005433008777	14155	Business	52300.00
0005433008783	14155	Business	52300.00
0005433008794	14155	Business	52300.00
0005433008779	14155	Business	52300.00
0005433008778	14155	Business	52300.00
0005433008764	14155	Economy	17400.00
0005433008770	14155	Economy	17400.00
0005433008752	14155	Economy	17400.00
0005433008755	14155	Economy	17400.00
0005433008765	14155	Economy	17400.00
0005433008776	14155	Economy	19200.00
0005433008753	14155	Economy	19200.00
0005433008782	14155	Economy	19200.00
0005433008772	14155	Economy	17400.00
0005433008751	14155	Economy	17400.00
0005433008767	14155	Economy	17400.00
0005433008754	14155	Economy	17400.00
0005433008787	14155	Economy	17400.00
0005433008760	14155	Economy	17400.00
0005433008761	14155	Economy	17400.00
0005433008762	14155	Economy	17400.00
0005433008785	14155	Economy	17400.00
0005433008780	14155	Economy	17400.00
0005433008784	14155	Economy	17400.00
0005433008757	14155	Economy	17400.00
0005433008773	14155	Economy	17400.00
0005433008789	14155	Economy	17400.00
0005433008775	14155	Economy	17400.00
0005433008768	14155	Economy	17400.00
0005433008791	14155	Economy	17400.00
0005433008792	14155	Economy	17400.00
0005433008796	14155	Economy	17400.00
0005433008795	14155	Economy	17400.00
0005433008750	14155	Economy	17400.00
0005433008763	14155	Economy	17400.00
0005433008790	14155	Economy	17400.00
0005433008756	14155	Economy	17400.00
0005433008786	14155	Economy	17400.00
0005433008771	14155	Economy	17400.00
0005433008781	14155	Economy	17400.00
0005433008769	14155	Economy	17400.00
0005433008758	14155	Economy	17400.00
0005433008766	14155	Economy	17400.00
0005433008759	14155	Economy	17400.00
0005433008788	14155	Economy	17400.00
0005433008461	22848	Business	52300.00
0005433008283	22848	Business	52300.00
0005433008284	22848	Business	52300.00
0005433008306	22848	Business	52300.00
0005433008382	22848	Business	52300.00
0005433008311	22848	Economy	17400.00
0005433008299	22848	Economy	17400.00
0005433008296	22848	Economy	17400.00
0005433810562	22848	Economy	17400.00
0005433810556	22848	Economy	19200.00
0005433008321	22848	Economy	19200.00
0005433810565	22848	Economy	17400.00
0005433008526	22848	Economy	17400.00
0005433008374	22848	Economy	17400.00
0005433008405	22848	Economy	17400.00
0005433008380	22848	Economy	17400.00
0005433008360	22848	Economy	17400.00
0005433008290	22848	Economy	17400.00
0005433008238	22848	Economy	17400.00
0005433008310	22848	Economy	17400.00
0005433810564	22848	Economy	17400.00
0005433008336	22848	Economy	17400.00
0005433810559	22848	Economy	17400.00
0005433008295	22848	Economy	17400.00
0005433810561	22848	Economy	17400.00
0005433810563	22848	Economy	17400.00
0005433008315	22848	Economy	17400.00
0005433008245	22848	Economy	17400.00
0005433008112	22848	Economy	17400.00
0005433008291	22848	Economy	17400.00
0005433008247	22848	Economy	17400.00
0005433008246	22848	Economy	17400.00
0005433008479	22848	Economy	17400.00
0005433008373	22848	Economy	17400.00
0005433008176	22848	Economy	17400.00
0005433008381	22848	Economy	17400.00
0005433810557	22848	Economy	17400.00
0005433810558	22848	Economy	17400.00
0005433008532	22848	Economy	17400.00
0005433008298	22848	Economy	17400.00
0005433810555	22848	Economy	17400.00
0005433008288	22848	Economy	17400.00
0005433008297	22848	Economy	17400.00
0005433810560	22848	Economy	17400.00
0005433008155	22848	Economy	17400.00
0005433008289	22848	Economy	17400.00
0005433008353	22848	Economy	17400.00
0005433008335	22848	Economy	17400.00
0005434925532	14917	Business	22900.00
0005434925618	14917	Business	22900.00
0005434925621	14917	Business	22900.00
0005434925530	14917	Business	22900.00
0005434925574	14917	Economy	7600.00
0005434925430	14917	Economy	7600.00
0005434925611	14917	Economy	7600.00
0005434925538	14917	Economy	7600.00
0005434925578	14917	Economy	7600.00
0005434925570	14917	Economy	7600.00
0005434925569	14917	Economy	7600.00
0005434925597	14917	Economy	7600.00
0005434925620	14917	Economy	7600.00
0005434925397	14917	Economy	7600.00
0005434925575	14917	Economy	7600.00
0005434925619	14917	Economy	7600.00
0005434925531	14917	Economy	7600.00
0005434925539	14917	Economy	7600.00
0005434925576	14917	Economy	7600.00
0005434925622	14917	Economy	7600.00
0005434925523	14917	Economy	7600.00
0005434925873	20545	Business	22900.00
0005434925876	20545	Business	22900.00
0005434925875	20545	Business	22900.00
0005434925867	20545	Economy	8400.00
0005434925861	20545	Economy	8400.00
0005434925863	20545	Economy	7600.00
0005434925869	20545	Economy	7600.00
0005434925859	20545	Economy	7600.00
0005434925879	20545	Economy	7600.00
0005434925860	20545	Economy	7600.00
0005434925874	20545	Economy	7600.00
0005434925881	20545	Economy	7600.00
0005434925865	20545	Economy	7600.00
0005434925877	20545	Economy	7600.00
0005434925868	20545	Economy	7600.00
0005434925864	20545	Economy	7600.00
0005434925866	20545	Economy	7600.00
0005434925870	20545	Economy	7600.00
0005434925857	20545	Economy	7600.00
0005434925880	20545	Economy	7600.00
0005434925872	20545	Economy	7600.00
0005434925882	20545	Economy	7600.00
0005434925871	20545	Economy	7600.00
0005434925878	20545	Economy	7600.00
0005434925862	20545	Economy	7600.00
0005434925858	20545	Economy	7600.00
0005435487914	15841	Economy	8900.00
0005435999166	15841	Economy	8900.00
0005435487899	15841	Economy	8900.00
0005435999138	15841	Economy	8900.00
0005435487900	15841	Economy	8100.00
0005435999180	15841	Economy	8100.00
0005435487916	15841	Economy	8100.00
0005435487904	15841	Economy	8100.00
0005435999105	15841	Economy	8100.00
0005435999181	15841	Economy	8100.00
0005435487908	15841	Economy	8100.00
0005435999101	15841	Economy	8100.00
0005435999136	15841	Economy	8100.00
0005435487909	15841	Economy	8100.00
0005435999143	15841	Economy	8100.00
0005435487905	15841	Economy	8100.00
0005435999108	15841	Economy	8100.00
0005435487903	15841	Economy	8100.00
0005435487915	15841	Economy	8100.00
0005435999158	15841	Economy	8100.00
0005435999109	15841	Economy	8100.00
0005435999139	15841	Economy	8100.00
0005435999168	15841	Economy	8100.00
0005435487913	15841	Economy	8100.00
0005435999153	15841	Economy	8100.00
0005435999152	15841	Economy	8100.00
0005435487917	15841	Economy	8100.00
0005435999119	15841	Economy	8100.00
0005435487910	15841	Economy	8100.00
0005435487902	15841	Economy	8100.00
0005435998987	15841	Economy	8100.00
0005435999135	15841	Economy	8100.00
0005435487911	15841	Economy	8100.00
0005435999125	15841	Economy	8100.00
0005435487918	15841	Economy	8100.00
0005435487907	15841	Economy	8100.00
0005435999169	15841	Economy	8100.00
0005435487906	15841	Economy	8100.00
0005435999167	15841	Economy	8100.00
0005435487901	15841	Economy	8100.00
0005435487912	15841	Economy	8100.00
0005435999137	15841	Economy	8100.00
0005435999298	19723	Economy	8900.00
0005435487669	19723	Economy	8900.00
0005435487695	19723	Economy	8900.00
0005435487745	19723	Economy	8900.00
0005435999290	19723	Economy	8100.00
0005435487672	19723	Economy	8100.00
0005435487660	19723	Economy	8100.00
0005435999297	19723	Economy	8100.00
0005435487573	19723	Economy	8100.00
0005435999280	19723	Economy	8100.00
0005435487735	19723	Economy	8100.00
0005435487716	19723	Economy	8100.00
0005435487652	19723	Economy	8100.00
0005435487744	19723	Economy	8100.00
0005435999291	19723	Economy	8100.00
0005435999283	19723	Economy	8100.00
0005435999296	19723	Economy	8100.00
0005435487572	19723	Economy	8100.00
0005435999284	19723	Economy	8100.00
0005435487715	19723	Economy	8100.00
0005435487688	19723	Economy	8100.00
0005435487734	19723	Economy	8100.00
0005435999292	19723	Economy	8100.00
0005435999285	19723	Economy	8100.00
0005435487670	19723	Economy	8100.00
0005435487679	19723	Economy	8100.00
0005435487615	19723	Economy	8100.00
0005435999281	19723	Economy	8100.00
0005435487662	19723	Economy	8100.00
0005435999299	19723	Economy	8100.00
0005435487673	19723	Economy	8100.00
0005435999286	19723	Economy	8100.00
0005435999282	19723	Economy	8100.00
0005435999288	19723	Economy	8100.00
0005435487646	19723	Economy	8100.00
0005435487694	19723	Economy	8100.00
0005435999293	19723	Economy	8100.00
0005435999287	19723	Economy	8100.00
0005435999289	19723	Economy	8100.00
0005435487687	19723	Economy	8100.00
0005435999294	19723	Economy	8100.00
0005435999295	19723	Economy	8100.00
0005435472754	5996	Business	199300.00
0005432142262	5996	Business	199300.00
0005435472683	5996	Business	199300.00
0005432660826	5996	Business	199300.00
0005435839545	5996	Business	199300.00
0005435839540	5996	Business	199300.00
0005435839561	5996	Business	199300.00
0005435839534	5996	Economy	66400.00
0005435472743	5996	Economy	66400.00
0005435472682	5996	Economy	66400.00
0005435839555	5996	Economy	66400.00
0005435839560	5996	Economy	66400.00
0005435839542	5996	Economy	66400.00
0005435472605	5996	Economy	66400.00
0005435472715	5996	Economy	73100.00
0005435472671	5996	Economy	73100.00
0005435472732	5996	Economy	66400.00
0005435839558	5996	Economy	66400.00
0005435839539	5996	Economy	66400.00
0005435472734	5996	Economy	66400.00
0005435472712	5996	Economy	66400.00
0005435839549	5996	Economy	66400.00
0005435472780	5996	Economy	66400.00
0005435839535	5996	Economy	66400.00
0005435839537	5996	Economy	66400.00
0005435472744	5996	Economy	66400.00
0005435839546	5996	Economy	66400.00
0005432142263	5996	Economy	66400.00
0005435839550	5996	Economy	66400.00
0005432659715	5996	Economy	66400.00
0005435839548	5996	Economy	66400.00
0005432537038	5996	Economy	66400.00
0005435472767	5996	Economy	66400.00
0005435472779	5996	Economy	66400.00
0005435472692	5996	Economy	66400.00
0005435472753	5996	Economy	66400.00
0005435472726	5996	Economy	66400.00
0005435472772	5996	Economy	66400.00
0005432660825	5996	Economy	66400.00
0005435472672	5996	Economy	66400.00
0005435839541	5996	Economy	66400.00
0005435472733	5996	Economy	66400.00
0005432658599	5996	Economy	66400.00
0005435472668	5996	Economy	66400.00
0005435839559	5996	Economy	66400.00
0005435472667	5996	Economy	66400.00
0005435472752	5996	Economy	66400.00
0005435839544	5996	Economy	66400.00
0005435839536	5996	Economy	66400.00
0005435472771	5996	Economy	66400.00
0005435839557	5996	Economy	66400.00
0005435839554	5996	Economy	66400.00
0005435839551	5996	Economy	66400.00
0005435839556	5996	Economy	66400.00
0005435839553	5996	Economy	66400.00
0005435472729	5996	Economy	66400.00
0005435839543	5996	Economy	66400.00
0005435472749	5996	Economy	66400.00
0005435839547	5996	Economy	66400.00
0005435839552	5996	Economy	66400.00
0005435472606	5996	Economy	66400.00
0005435472766	5996	Economy	66400.00
0005435839538	5996	Economy	66400.00
0005435839296	18092	Business	199300.00
0005435839332	18092	Business	199300.00
0005432667436	18092	Business	199300.00
0005435839320	18092	Business	199300.00
0005432664116	18092	Business	199300.00
0005435472855	18092	Business	199300.00
0005435839310	18092	Business	199300.00
0005432667442	18092	Business	199300.00
0005435472860	18092	Business	199300.00
0005435839253	18092	Business	199300.00
0005435839254	18092	Economy	66400.00
0005435839308	18092	Economy	66400.00
0005435472857	18092	Economy	66400.00
0005435472850	18092	Economy	66400.00
0005435472863	18092	Economy	73100.00
0005432664115	18092	Economy	66400.00
0005435839298	18092	Economy	73100.00
0005435472856	18092	Economy	66400.00
0005435839425	18092	Economy	66400.00
0005435839273	18092	Economy	66400.00
0005435472849	18092	Economy	66400.00
0005435472861	18092	Economy	66400.00
0005435839219	18092	Economy	66400.00
0005435839248	18092	Economy	66400.00
0005435472854	18092	Economy	66400.00
0005435472864	18092	Economy	66400.00
0005435839424	18092	Economy	66400.00
0005435839319	18092	Economy	66400.00
0005432660793	18092	Economy	66400.00
0005435839307	18092	Economy	66400.00
0005435839354	18092	Economy	66400.00
0005432537066	18092	Economy	66400.00
0005432664124	18092	Economy	66400.00
0005432664121	18092	Economy	66400.00
0005435839398	18092	Economy	66400.00
0005435472851	18092	Economy	66400.00
0005435839397	18092	Economy	66400.00
0005435472852	18092	Economy	66400.00
0005435472866	18092	Economy	66400.00
0005435472853	18092	Economy	66400.00
0005435472862	18092	Economy	66400.00
0005435472858	18092	Economy	66400.00
0005432667435	18092	Economy	66400.00
0005435839218	18092	Economy	66400.00
0005435839297	18092	Economy	66400.00
0005432537067	18092	Economy	66400.00
0005435839321	18092	Economy	66400.00
0005432537065	18092	Economy	66400.00
0005432664123	18092	Economy	66400.00
0005432664126	18092	Economy	66400.00
0005435472865	18092	Economy	66400.00
0005435839396	18092	Economy	66400.00
0005435472859	18092	Economy	66400.00
0005435839423	18092	Economy	66400.00
0005435839251	18092	Economy	66400.00
0005435839436	18092	Economy	66400.00
0005435839403	18092	Economy	66400.00
0005433285105	23025	Business	15700.00
0005433285181	23025	Business	15700.00
0005433285185	23025	Business	15700.00
0005433285042	23025	Business	15700.00
0005433285088	23025	Business	15700.00
0005433285239	23025	Economy	5200.00
0005433285237	23025	Economy	5200.00
0005435103953	23025	Economy	5200.00
0005433285198	23025	Economy	5200.00
0005433285119	23025	Economy	5200.00
0005433284965	23025	Economy	5200.00
0005433285182	23025	Economy	5200.00
0005433285055	23025	Economy	5200.00
0005433285097	23025	Economy	5200.00
0005433285190	23025	Economy	5200.00
0005433285103	23025	Economy	5200.00
0005433285135	23025	Economy	5200.00
0005433285081	23025	Economy	5200.00
0005433285167	23025	Economy	5700.00
0005433285053	23025	Economy	5200.00
0005433285136	23025	Economy	5200.00
0005433285200	23025	Economy	5200.00
0005435103952	23025	Economy	5200.00
0005433285089	23025	Economy	5200.00
0005433285168	23025	Economy	5200.00
0005433285028	23025	Economy	5200.00
0005433285183	23025	Economy	5200.00
0005433285191	23025	Economy	5200.00
0005433285104	23025	Economy	5200.00
0005433285134	23025	Economy	5200.00
0005433284990	23025	Economy	5200.00
0005433285128	23025	Economy	5200.00
0005435103950	23025	Economy	5200.00
0005433285052	23025	Economy	5200.00
0005433285026	23025	Economy	5200.00
0005433285066	23025	Economy	5200.00
0005435103951	23025	Economy	5200.00
0005433284989	23025	Economy	5200.00
0005433285155	23025	Economy	5200.00
0005433285054	23025	Economy	5200.00
0005433285184	23025	Economy	5200.00
0005435103877	32095	Business	15700.00
0005435103851	32095	Business	15700.00
0005433285404	32095	Business	15700.00
0005435103856	32095	Business	15700.00
0005433285416	32095	Business	15700.00
0005435103866	32095	Business	15700.00
0005433285393	32095	Business	15700.00
0005433285408	32095	Economy	5200.00
0005435103834	32095	Economy	5200.00
0005433285417	32095	Economy	5200.00
0005433285423	32095	Economy	5200.00
0005433285414	32095	Economy	5200.00
0005433285396	32095	Economy	5200.00
0005433285395	32095	Economy	5200.00
0005433285412	32095	Economy	5200.00
0005435103864	32095	Economy	5200.00
0005433285415	32095	Economy	5700.00
0005433285402	32095	Economy	5700.00
0005433285420	32095	Economy	5200.00
0005433285392	32095	Economy	5200.00
0005433285403	32095	Economy	5200.00
0005433285406	32095	Economy	5200.00
0005435103870	32095	Economy	5200.00
0005433285411	32095	Economy	5200.00
0005435103845	32095	Economy	5200.00
0005433285398	32095	Economy	5200.00
0005435103876	32095	Economy	5200.00
0005435103871	32095	Economy	5200.00
0005433285405	32095	Economy	5200.00
0005435103865	32095	Economy	5200.00
0005433285410	32095	Economy	5200.00
0005433285407	32095	Economy	5200.00
0005433285401	32095	Economy	5200.00
0005433285421	32095	Economy	5200.00
0005433285397	32095	Economy	5200.00
0005433285422	32095	Economy	5200.00
0005433285419	32095	Economy	5200.00
0005435103872	32095	Economy	5200.00
0005433285400	32095	Economy	5200.00
0005433285394	32095	Economy	5200.00
0005433285409	32095	Economy	5200.00
0005433285399	32095	Economy	5200.00
0005433285413	32095	Economy	5200.00
0005435103873	32095	Economy	5200.00
0005433285418	32095	Economy	5200.00
0005435103850	32095	Economy	5200.00
0005434067476	30615	Business	42100.00
0005435213840	30615	Business	42100.00
0005432535799	30615	Business	42100.00
0005434066909	30615	Business	42100.00
0005432527583	30615	Business	42100.00
0005432527345	30615	Business	42100.00
0005435725619	30615	Business	42100.00
0005432537057	30615	Business	42100.00
0005435213794	30615	Business	42100.00
0005435213786	30615	Business	42100.00
0005435213791	30615	Business	42100.00
0005432527052	30615	Business	42100.00
0005435213828	30615	Business	42100.00
0005432527637	30615	Business	42100.00
0005434067287	30615	Business	42100.00
0005434067035	30615	Business	42100.00
0005434067156	30615	Business	42100.00
0005432527144	30615	Business	42100.00
0005432527142	30615	Business	42100.00
0005432527324	30615	Business	42100.00
0005432527625	30615	Comfort	23900.00
0005432527497	30615	Comfort	23900.00
0005435213816	30615	Comfort	23900.00
0005434067107	30615	Comfort	23900.00
0005434067419	30615	Comfort	23900.00
0005432527788	30615	Comfort	23900.00
0005435213817	30615	Comfort	23900.00
0005434067158	30615	Comfort	23900.00
0005432527478	30615	Comfort	23900.00
0005432526944	30615	Comfort	23900.00
0005435213839	30615	Comfort	23900.00
0005432527568	30615	Comfort	23900.00
0005432527396	30615	Comfort	23900.00
0005434067394	30615	Comfort	23900.00
0005435630980	30615	Comfort	23900.00
0005435213819	30615	Comfort	23900.00
0005432527373	30615	Comfort	23900.00
0005432428911	30615	Comfort	23900.00
0005432527297	30615	Comfort	23900.00
0005434067310	30615	Comfort	23900.00
0005432527611	30615	Comfort	23900.00
0005434067112	30615	Comfort	23900.00
0005432211527	30615	Comfort	23900.00
0005434067032	30615	Comfort	23900.00
0005434067308	30615	Comfort	23900.00
0005432527296	30615	Comfort	23900.00
0005432527495	30615	Comfort	23900.00
0005432527261	30615	Comfort	23900.00
0005434066978	30615	Comfort	23900.00
0005435213834	30615	Comfort	23900.00
0005434067068	30615	Comfort	23900.00
0005432533274	30615	Comfort	23900.00
0005435213853	30615	Comfort	23900.00
0005435213837	30615	Comfort	23900.00
0005434067256	30615	Comfort	23900.00
0005435725621	30615	Comfort	23900.00
0005435213802	30615	Comfort	23900.00
0005432537053	30615	Comfort	23900.00
0005432527635	30615	Economy	14000.00
0005434067025	30615	Economy	14000.00
0005434067109	30615	Economy	14000.00
0005435213813	30615	Economy	14000.00
0005434066979	30615	Economy	14000.00
0005435213812	30615	Economy	14000.00
0005432527601	30615	Economy	14000.00
0005434067108	30615	Economy	14000.00
0005432526474	30615	Economy	14000.00
0005432526999	30615	Economy	14000.00
0005434066770	30615	Economy	14000.00
0005434066911	30615	Economy	14000.00
0005432526814	30615	Economy	14000.00
0005435213809	30615	Economy	14000.00
0005435213833	30615	Economy	14000.00
0005435213827	30615	Economy	14000.00
0005432527732	30615	Economy	14000.00
0005434067306	30615	Economy	14000.00
0005432527281	30615	Economy	14000.00
0005432527591	30615	Economy	14000.00
0005432527807	30615	Economy	14000.00
0005432526765	30615	Economy	14000.00
0005432535800	30615	Economy	14000.00
0005434067218	30615	Economy	14000.00
0005435213804	30615	Economy	14000.00
0005435213849	30615	Economy	14000.00
0005435213820	30615	Economy	14000.00
0005433656686	30615	Economy	14000.00
0005434067207	30615	Economy	14000.00
0005435213848	30615	Economy	14000.00
0005432526945	30615	Economy	14000.00
0005434066901	30615	Economy	14000.00
0005432159874	30615	Economy	14000.00
0005432527496	30615	Economy	14000.00
0005432527304	30615	Economy	14000.00
0005432527784	30615	Economy	14000.00
0005432527612	30615	Economy	14000.00
0005435213823	30615	Economy	14000.00
0005435725623	30615	Economy	14000.00
0005434066989	30615	Economy	14000.00
0005433656685	30615	Economy	14000.00
0005435213797	30615	Economy	14000.00
0005434067033	30615	Economy	14000.00
0005435213803	30615	Economy	14000.00
0005432428912	30615	Economy	14000.00
0005435725622	30615	Economy	14000.00
0005432527998	30615	Economy	15400.00
0005435213815	30615	Economy	15400.00
0005432527693	30615	Economy	14000.00
0005432211533	30615	Economy	14000.00
0005432211528	30615	Economy	14000.00
0005434067148	30615	Economy	15400.00
0005434067393	30615	Economy	14000.00
0005435213798	30615	Economy	14000.00
0005435213808	30615	Economy	14000.00
0005435213835	30615	Economy	14000.00
0005434067298	30615	Economy	14000.00
0005435213830	30615	Economy	14000.00
0005432527506	30615	Economy	14000.00
0005435213790	30615	Economy	14000.00
0005435213818	30615	Economy	14000.00
0005434067307	30615	Economy	14000.00
0005432211529	30615	Economy	14000.00
0005432159876	30615	Economy	14000.00
0005432527121	30615	Economy	14000.00
0005434067346	30615	Economy	14000.00
0005435213852	30615	Economy	14000.00
0005432527323	30615	Economy	14000.00
0005432526884	30615	Economy	14000.00
0005434067198	30615	Economy	14000.00
0005432527393	30615	Economy	14000.00
0005432527366	30615	Economy	14000.00
0005432526841	30615	Economy	14000.00
0005432159875	30615	Economy	14000.00
0005434066929	30615	Economy	14000.00
0005432527656	30615	Economy	14000.00
0005434067455	30615	Economy	14000.00
0005432527237	30615	Economy	14000.00
0005432535815	30615	Economy	14000.00
0005432527567	30615	Economy	14000.00
0005434067494	30615	Economy	14000.00
0005435213807	30615	Economy	14000.00
0005432527498	30615	Economy	14000.00
0005432526783	30615	Economy	14000.00
0005432528013	30615	Economy	14000.00
0005434067356	30615	Economy	14000.00
0005435213838	30615	Economy	14000.00
0005435213842	30615	Economy	14000.00
0005435213851	30615	Economy	14000.00
0005435213821	30615	Economy	14000.00
0005434067186	30615	Economy	14000.00
0005432527414	30615	Economy	14000.00
0005432527430	30615	Economy	14000.00
0005435213832	30615	Economy	14000.00
0005432527715	30615	Economy	14000.00
0005435213800	30615	Economy	14000.00
0005432527322	30615	Economy	14000.00
0005432527438	30615	Economy	14000.00
0005432533288	30615	Economy	14000.00
0005435213843	30615	Economy	14000.00
0005432533287	30615	Economy	14000.00
0005434067241	30615	Economy	14000.00
0005435213825	30615	Economy	14000.00
0005435213846	30615	Economy	14000.00
0005434067193	30615	Economy	14000.00
0005432211531	30615	Economy	14000.00
0005432527727	30615	Economy	14000.00
0005432535801	30615	Economy	14000.00
0005432527249	30615	Economy	14000.00
0005435213850	30615	Economy	14000.00
0005432527834	30615	Economy	14000.00
0005435213805	30615	Economy	14000.00
0005432527626	30615	Economy	14000.00
0005434066991	30615	Economy	14000.00
0005432527160	30615	Economy	14000.00
0005432526910	30615	Economy	14000.00
0005432527749	30615	Economy	14000.00
0005434067495	30615	Economy	14000.00
0005434067200	30615	Economy	14000.00
0005435213826	30615	Economy	14000.00
0005432527190	30615	Economy	14000.00
0005432527204	30615	Economy	14000.00
0005434067299	30615	Economy	14000.00
0005432526781	30615	Economy	14000.00
0005432527697	30615	Economy	14000.00
0005432526622	30615	Economy	14000.00
0005434067044	30615	Economy	14000.00
0005434067074	30615	Economy	14000.00
0005435213788	30615	Economy	14000.00
0005435213796	30615	Economy	14000.00
0005433656684	30615	Economy	15400.00
0005435213836	30615	Economy	15400.00
0005432527613	30615	Economy	15400.00
0005434067024	30615	Economy	14000.00
0005432526908	30615	Economy	15400.00
0005435213792	30615	Economy	14000.00
0005432159878	30615	Economy	14000.00
0005434067404	30615	Economy	14000.00
0005432527799	30615	Economy	14000.00
0005432211534	30615	Economy	14000.00
0005432527120	30615	Economy	14000.00
0005432526998	30615	Economy	14000.00
0005432527282	30615	Economy	14000.00
0005434067199	30615	Economy	14000.00
0005434067103	30615	Economy	14000.00
0005434066981	30615	Economy	14000.00
0005435213810	30615	Economy	14000.00
0005435213811	30615	Economy	14000.00
0005435213829	30615	Economy	14000.00
0005432211532	30615	Economy	14000.00
0005432527655	30615	Economy	14000.00
0005434067403	30615	Economy	14000.00
0005432535832	30615	Economy	14000.00
0005432535827	30615	Economy	14000.00
0005435213814	30615	Economy	14000.00
0005434067239	30615	Economy	14000.00
0005432526780	30615	Economy	14000.00
0005432527175	30615	Economy	14000.00
0005432211530	30615	Economy	14000.00
0005434067009	30615	Economy	14000.00
0005434067161	30615	Economy	14000.00
0005432527180	30615	Economy	14000.00
0005432526476	30615	Economy	14000.00
0005434067347	30615	Economy	14000.00
0005434067223	30615	Economy	14000.00
0005435725620	30615	Economy	14000.00
0005435213822	30615	Economy	14000.00
0005435213787	30615	Economy	14000.00
0005432527582	30615	Economy	14000.00
0005435213845	30615	Economy	14000.00
0005435213801	30615	Economy	14000.00
0005434067201	30615	Economy	14000.00
0005434067023	30615	Economy	14000.00
0005434067121	30615	Economy	14000.00
0005432527902	30615	Economy	14000.00
0005434067370	30615	Economy	14000.00
0005432527024	30615	Economy	14000.00
0005435630981	30615	Economy	14000.00
0005432159877	30615	Economy	14000.00
0005434067083	30615	Economy	14000.00
0005432527722	30615	Economy	14000.00
0005432527346	30615	Economy	14000.00
0005434066990	30615	Economy	14000.00
0005434067130	30615	Economy	14000.00
0005434066910	30615	Economy	14000.00
0005435213789	30615	Economy	14000.00
0005435213824	30615	Economy	14000.00
0005434067436	30615	Economy	14000.00
0005434067470	30615	Economy	14000.00
0005432526909	30615	Economy	14000.00
0005435213793	30615	Economy	14000.00
0005434067202	30615	Economy	14000.00
0005435213795	30615	Economy	14000.00
0005435213847	30615	Economy	14000.00
0005432527205	30615	Economy	14000.00
0005434067102	30615	Economy	14000.00
0005432527602	30615	Economy	14000.00
0005434067469	30615	Economy	14000.00
0005434067034	30615	Economy	14000.00
0005434067133	30615	Economy	14000.00
0005432526784	30615	Economy	14000.00
0005432527460	30615	Economy	14000.00
0005432527335	30615	Economy	14000.00
0005435213806	30615	Economy	14000.00
0005434067087	30615	Economy	14000.00
0005432527579	30615	Economy	14000.00
0005435213841	30615	Economy	14000.00
0005434067088	30615	Economy	14000.00
0005434067288	30615	Economy	14000.00
0005435213831	30615	Economy	14000.00
0005432527578	30615	Economy	14000.00
0005432527933	30615	Economy	14000.00
0005432535816	30615	Economy	14000.00
0005432527208	30615	Economy	14000.00
0005435213844	30615	Economy	14000.00
0005435630979	30615	Economy	14000.00
0005435725624	30615	Economy	14000.00
0005435213799	30615	Economy	14000.00
0005434067160	30615	Economy	14000.00
0005432526842	30615	Economy	14000.00
0005433368042	24839	Business	9800.00
0005435652683	24839	Business	9800.00
0005433368058	24839	Business	9800.00
0005435652747	24839	Business	9800.00
0005433368062	24839	Business	9800.00
0005435652844	24839	Business	9800.00
0005435652735	24839	Business	9800.00
0005433368061	24839	Business	9800.00
0005435652690	24839	Economy	3300.00
0005433368039	24839	Economy	3300.00
0005433368056	24839	Economy	3300.00
0005435652828	24839	Economy	3300.00
0005435652804	24839	Economy	3300.00
0005433368043	24839	Economy	3300.00
0005435652665	24839	Economy	3300.00
0005435652748	24839	Economy	3300.00
0005435652805	24839	Economy	3300.00
0005433368046	24839	Economy	3600.00
0005433368033	24839	Economy	3600.00
0005435652853	24839	Economy	3600.00
0005433368048	24839	Economy	3600.00
0005433368047	24839	Economy	3300.00
0005435652846	24839	Economy	3300.00
0005433368052	24839	Economy	3300.00
0005433368041	24839	Economy	3300.00
0005435652650	24839	Economy	3300.00
0005435652696	24839	Economy	3300.00
0005435652852	24839	Economy	3300.00
0005435652764	24839	Economy	3300.00
0005433368054	24839	Economy	3300.00
0005433368040	24839	Economy	3300.00
0005435652688	24839	Economy	3300.00
0005433368027	24839	Economy	3300.00
0005435652845	24839	Economy	3300.00
0005435652762	24839	Economy	3300.00
0005435652839	24839	Economy	3300.00
0005433368049	24839	Economy	3300.00
0005435652854	24839	Economy	3300.00
0005435652700	24839	Economy	3300.00
0005435652689	24839	Economy	3300.00
0005433368035	24839	Economy	3300.00
0005435652761	24839	Economy	3300.00
0005435652736	24839	Economy	3300.00
0005433368038	24839	Economy	3300.00
0005433368034	24839	Economy	3300.00
0005435652786	24839	Economy	3300.00
0005433368059	24839	Economy	3300.00
0005435652732	24839	Economy	3300.00
0005435652825	24839	Economy	3300.00
0005435652803	24839	Economy	3300.00
0005433368030	24839	Economy	3300.00
0005433368055	24839	Economy	3300.00
0005435652843	24839	Economy	3300.00
0005435652466	24839	Economy	3300.00
0005433368053	24839	Economy	3300.00
0005433368029	24839	Economy	3300.00
0005433368032	24839	Economy	3300.00
0005435652653	24839	Economy	3300.00
0005433368031	24839	Economy	3300.00
0005433368044	24839	Economy	3300.00
0005433368036	24839	Economy	3300.00
0005433368050	24839	Economy	3300.00
0005433368060	24839	Economy	3300.00
0005435652824	24839	Economy	3300.00
0005435652778	24839	Economy	3300.00
0005435652829	24839	Economy	3300.00
0005435652773	24839	Economy	3300.00
0005435652779	24839	Economy	3300.00
0005433368045	24839	Economy	3300.00
0005433368028	24839	Economy	3300.00
0005435652862	24839	Economy	3300.00
0005435652649	24839	Economy	3300.00
0005433368057	24839	Economy	3300.00
0005435652664	24839	Economy	3300.00
0005435652749	24839	Economy	3300.00
0005435652872	24839	Economy	3300.00
0005435652763	24839	Economy	3300.00
0005435652684	24839	Economy	3300.00
0005433368026	24839	Economy	3300.00
0005435652840	24839	Economy	3300.00
0005433368037	24839	Economy	3300.00
0005435652802	24839	Economy	3300.00
0005435652836	24839	Economy	3300.00
0005435652806	24839	Economy	3300.00
0005433368051	24839	Economy	3300.00
0005435949771	23308	Economy	20600.00
0005435949759	23308	Economy	20600.00
0005435949765	23308	Economy	18700.00
0005435949760	23308	Economy	18700.00
0005435949761	23308	Economy	18700.00
0005435949770	23308	Economy	18700.00
0005435949769	23308	Economy	18700.00
0005435949756	23308	Economy	18700.00
0005435949753	23308	Economy	18700.00
0005435949782	23308	Economy	18700.00
0005435949752	23308	Economy	18700.00
0005435949755	23308	Economy	18700.00
0005435801709	2054	Economy	10500.00
0005434979914	2054	Economy	10500.00
0005434979910	2054	Economy	10500.00
0005434979905	2054	Economy	9500.00
0005434979928	2054	Economy	9500.00
0005434979917	2054	Economy	9500.00
0005434979920	2054	Economy	9500.00
0005434979926	2054	Economy	9500.00
0005434979921	2054	Economy	9500.00
0005434979924	2054	Economy	9500.00
0005434979911	2054	Economy	9500.00
0005434979909	2054	Economy	9500.00
0005434979912	2054	Economy	9500.00
0005434979918	2054	Economy	9500.00
0005435801707	2054	Economy	9500.00
0005434979907	2054	Economy	9500.00
0005434979915	2054	Economy	9500.00
0005434979900	2054	Economy	9500.00
0005434979913	2054	Economy	9500.00
0005434979927	2054	Economy	9500.00
0005434979916	2054	Economy	9500.00
0005434979904	2054	Economy	9500.00
0005434979901	2054	Economy	9500.00
0005434979899	2054	Economy	9500.00
0005434979903	2054	Economy	9500.00
0005434979902	2054	Economy	9500.00
0005434979919	2054	Economy	9500.00
0005434979898	2054	Economy	9500.00
0005434979908	2054	Economy	9500.00
0005434979922	2054	Economy	9500.00
0005435801708	2054	Economy	9500.00
0005434979906	2054	Economy	9500.00
0005434979925	2054	Economy	9500.00
0005434979923	2054	Economy	9500.00
0005434979654	23536	Economy	10500.00
0005434979534	23536	Economy	10500.00
0005434979541	23536	Economy	10500.00
0005434979537	23536	Economy	9500.00
0005434979597	23536	Economy	9500.00
0005434979552	23536	Economy	9500.00
0005434979763	23536	Economy	9500.00
0005435801699	23536	Economy	9500.00
0005434979568	23536	Economy	9500.00
0005434979539	23536	Economy	9500.00
0005434979762	23536	Economy	9500.00
0005434979540	23536	Economy	9500.00
0005435801698	23536	Economy	9500.00
0005434979607	23536	Economy	9500.00
0005434979615	23536	Economy	9500.00
0005434979533	23536	Economy	9500.00
0005434979664	23536	Economy	9500.00
0005434979566	23536	Economy	9500.00
0005434979616	23536	Economy	9500.00
0005434979542	23536	Economy	9500.00
0005434979548	23536	Economy	9500.00
0005434979532	23536	Economy	9500.00
0005434979551	23536	Economy	9500.00
0005434979577	23536	Economy	9500.00
0005435801683	23536	Economy	9500.00
0005434979549	23536	Economy	9500.00
0005434979603	23536	Economy	9500.00
0005434979653	23536	Economy	9500.00
0005434979550	23536	Economy	9500.00
0005434979518	23536	Economy	9500.00
0005434979602	23536	Economy	9500.00
0005434979536	23536	Economy	9500.00
0005435801687	23536	Economy	9500.00
0005434979497	23536	Economy	9500.00
0005434979538	23536	Economy	9500.00
0005434979684	23536	Economy	9500.00
0005434979513	23536	Economy	9500.00
0005435801684	23536	Economy	9500.00
0005434979503	23536	Economy	9500.00
0005434979509	23536	Economy	9500.00
0005434979771	23536	Economy	9500.00
0005434952546	2598	Economy	5300.00
0005434952547	2598	Economy	5300.00
0005433256430	28253	Economy	5300.00
0005433256431	28253	Economy	5300.00
0005434952514	28253	Economy	5300.00
0005433111516	19744	Economy	8700.00
0005433111515	19744	Economy	8700.00
0005434137576	11948	Business	9700.00
0005434137787	11948	Business	9700.00
0005434137358	11948	Business	9700.00
0005434137410	11948	Business	9700.00
0005434137894	11948	Business	9700.00
0005434137723	11948	Business	9700.00
0005434137830	11948	Business	9700.00
0005434137777	11948	Business	9700.00
0005434137996	11948	Business	9700.00
0005434137678	11948	Business	9700.00
0005434137577	11948	Business	9700.00
0005434137649	11948	Economy	3200.00
0005434137578	11948	Economy	3200.00
0005434137753	11948	Economy	3200.00
0005434137829	11948	Economy	3200.00
0005434137661	11948	Economy	3200.00
0005434137893	11948	Economy	3200.00
0005434137646	11948	Economy	3200.00
0005434137766	11948	Economy	3200.00
0005434137877	11948	Economy	3500.00
0005434137620	11948	Economy	3500.00
0005434137760	11948	Economy	3500.00
0005434137724	11948	Economy	3500.00
0005434137721	11948	Economy	3500.00
0005434137952	11948	Economy	3200.00
0005434137885	11948	Economy	3200.00
0005434137751	11948	Economy	3200.00
0005434138001	11948	Economy	3200.00
0005434137621	11948	Economy	3200.00
0005434137856	11948	Economy	3200.00
0005434137485	11948	Economy	3200.00
0005434137798	11948	Economy	3200.00
0005434137549	11948	Economy	3200.00
0005434137475	11948	Economy	3200.00
0005434137944	11948	Economy	3200.00
0005434137486	11948	Economy	3200.00
0005434137618	11948	Economy	3200.00
0005434137669	11948	Economy	3200.00
0005434137409	11948	Economy	3200.00
0005434137625	11948	Economy	3200.00
0005434137542	11948	Economy	3200.00
0005434137995	11948	Economy	3200.00
0005434137932	11948	Economy	3200.00
0005434137941	11948	Economy	3200.00
0005434137496	11948	Economy	3200.00
0005434137632	11948	Economy	3200.00
0005434137720	11948	Economy	3200.00
0005434137617	11948	Economy	3200.00
0005434137726	11948	Economy	3200.00
0005434137776	11948	Economy	3200.00
0005434137322	11948	Economy	3200.00
0005434137305	11948	Economy	3200.00
0005434137722	11948	Economy	3200.00
0005434137767	11948	Economy	3200.00
0005434137886	11948	Economy	3200.00
0005434137974	11948	Economy	3200.00
0005434137931	11948	Economy	3200.00
0005434137871	11948	Economy	3200.00
0005434138015	11948	Economy	3200.00
0005434137626	11948	Economy	3200.00
0005434137975	11948	Economy	3200.00
0005434137647	11948	Economy	3200.00
0005434137719	11948	Economy	3200.00
0005434137612	11948	Economy	3200.00
0005434137740	11948	Economy	3200.00
0005434137497	11948	Economy	3200.00
0005434137550	11948	Economy	3200.00
0005434137306	11948	Economy	3200.00
0005434137969	11948	Economy	3200.00
0005434137768	11948	Economy	3200.00
0005434138020	11948	Economy	3200.00
0005434137545	11948	Economy	3200.00
0005434137541	11948	Economy	3200.00
0005434137759	11948	Economy	3200.00
0005434138014	11948	Economy	3200.00
0005434138068	11948	Economy	3200.00
0005434137662	11948	Economy	3200.00
0005434137981	11948	Economy	3200.00
0005434137961	11948	Economy	3200.00
0005434137624	11948	Economy	3200.00
0005434137663	11948	Economy	3200.00
0005434137631	11948	Economy	3200.00
0005434137713	11948	Economy	3200.00
0005434137619	11948	Economy	3200.00
0005434137929	11948	Economy	3200.00
0005434137866	11948	Economy	3200.00
0005434137321	11948	Economy	3200.00
0005434137630	11948	Economy	3200.00
0005434137616	11948	Economy	3200.00
0005434137769	11948	Economy	3200.00
0005434137307	11948	Economy	3200.00
0005434137848	11948	Economy	3200.00
0005434138464	28715	Business	9700.00
0005434138451	28715	Business	9700.00
0005434138418	28715	Business	9700.00
0005434138447	28715	Business	9700.00
0005434138427	28715	Business	9700.00
0005434138435	28715	Business	9700.00
0005434138396	28715	Business	9700.00
0005434138403	28715	Business	9700.00
0005434138414	28715	Business	9700.00
0005434138459	28715	Business	9700.00
0005434138462	28715	Business	9700.00
0005434138389	28715	Business	9700.00
0005434138394	28715	Economy	3200.00
0005434138405	28715	Economy	3200.00
0005434138438	28715	Economy	3200.00
0005434138416	28715	Economy	3200.00
0005434138450	28715	Economy	3200.00
0005434138423	28715	Economy	3200.00
0005434138407	28715	Economy	3200.00
0005434138390	28715	Economy	3200.00
0005434138402	28715	Economy	3500.00
0005434138452	28715	Economy	3500.00
0005434138463	28715	Economy	3500.00
0005434138432	28715	Economy	3500.00
0005434138466	28715	Economy	3200.00
0005434138404	28715	Economy	3200.00
0005434138443	28715	Economy	3200.00
0005434138453	28715	Economy	3200.00
0005434138440	28715	Economy	3200.00
0005434138454	28715	Economy	3200.00
0005434138412	28715	Economy	3200.00
0005434138400	28715	Economy	3200.00
0005434138391	28715	Economy	3200.00
0005434138397	28715	Economy	3200.00
0005434138417	28715	Economy	3200.00
0005434138421	28715	Economy	3200.00
0005434138446	28715	Economy	3200.00
0005434138456	28715	Economy	3200.00
0005434138467	28715	Economy	3200.00
0005434138426	28715	Economy	3200.00
0005434138409	28715	Economy	3200.00
0005434138428	28715	Economy	3200.00
0005434138393	28715	Economy	3200.00
0005434138431	28715	Economy	3200.00
0005434138420	28715	Economy	3200.00
0005434138430	28715	Economy	3200.00
0005434138392	28715	Economy	3200.00
0005434138419	28715	Economy	3200.00
0005434138436	28715	Economy	3200.00
0005434138468	28715	Economy	3200.00
0005434138449	28715	Economy	3200.00
0005434138413	28715	Economy	3200.00
0005434138434	28715	Economy	3200.00
0005434138399	28715	Economy	3200.00
0005434138444	28715	Economy	3200.00
0005434138398	28715	Economy	3200.00
0005434138415	28715	Economy	3200.00
0005434138455	28715	Economy	3200.00
0005434138424	28715	Economy	3200.00
0005434138460	28715	Economy	3200.00
0005434138442	28715	Economy	3200.00
0005434138411	28715	Economy	3200.00
0005434138410	28715	Economy	3200.00
0005434138425	28715	Economy	3200.00
0005434138469	28715	Economy	3200.00
0005434138465	28715	Economy	3200.00
0005434138408	28715	Economy	3200.00
0005434138458	28715	Economy	3200.00
0005434138429	28715	Economy	3200.00
0005434138445	28715	Economy	3200.00
0005434138439	28715	Economy	3200.00
0005434138422	28715	Economy	3200.00
0005434138406	28715	Economy	3200.00
0005434138437	28715	Economy	3200.00
0005434138433	28715	Economy	3200.00
0005434138461	28715	Economy	3200.00
0005434138457	28715	Economy	3200.00
0005434138395	28715	Economy	3200.00
0005434138401	28715	Economy	3200.00
0005434138441	28715	Economy	3200.00
0005434138448	28715	Economy	3200.00
0005434516070	19094	Economy	26000.00
0005434513559	19094	Economy	23600.00
0005434513575	19094	Economy	23600.00
0005434516061	19094	Economy	23600.00
0005434516063	19094	Economy	23600.00
0005434190412	19094	Economy	23600.00
0005434516068	19094	Economy	23600.00
0005434190413	19094	Economy	23600.00
0005434516069	19094	Economy	23600.00
0005434516067	19094	Economy	23600.00
0005434190414	19094	Economy	23600.00
0005434516066	19094	Economy	23600.00
0005434516071	19094	Economy	23600.00
0005434516065	19094	Economy	23600.00
0005434513565	19094	Economy	23600.00
0005434513566	19094	Economy	23600.00
0005434190410	19094	Economy	23600.00
0005434513560	19094	Economy	23600.00
0005434190409	19094	Economy	23600.00
0005434190411	19094	Economy	23600.00
0005433538901	6813	Economy	10900.00
0005433534506	6813	Economy	10900.00
0005433538906	6813	Economy	10900.00
0005433538902	6813	Economy	9900.00
0005433538908	6813	Economy	9900.00
0005433538903	6813	Economy	9900.00
0005433534507	6813	Economy	9900.00
0005433538907	6813	Economy	9900.00
0005435259734	6813	Economy	9900.00
0005433538905	6813	Economy	9900.00
0005435259741	6813	Economy	9900.00
0005433538904	6813	Economy	9900.00
0005433538909	6813	Economy	9900.00
0005433538827	25039	Economy	10900.00
0005435259775	25039	Economy	10900.00
0005433538862	25039	Economy	9900.00
0005433538841	25039	Economy	9900.00
0005433538773	25039	Economy	9900.00
0005435259773	25039	Economy	9900.00
0005433538830	25039	Economy	9900.00
0005433538858	25039	Economy	9900.00
0005433538856	25039	Economy	9900.00
0005435259774	25039	Economy	9900.00
0005433538832	25039	Economy	9900.00
0005433538831	25039	Economy	9900.00
0005433538861	25039	Economy	9900.00
0005433538837	25039	Economy	9900.00
0005433538829	25039	Economy	9900.00
0005433538828	25039	Economy	9900.00
0005433538833	25039	Economy	9900.00
0005433538855	25039	Economy	9900.00
0005433538813	25039	Economy	9900.00
0005433538799	25039	Economy	9900.00
0005435259776	25039	Economy	9900.00
0005433534483	25039	Economy	9900.00
0005433534482	25039	Economy	9900.00
0005433538772	25039	Economy	9900.00
0005433538826	25039	Economy	9900.00
0005433538800	25039	Economy	9900.00
0005433511985	795	Economy	14600.00
0005432922504	795	Economy	14600.00
0005433511986	795	Economy	14600.00
0005433511990	795	Economy	14600.00
0005433511989	795	Economy	14600.00
0005432922505	795	Economy	14600.00
0005433511984	795	Economy	14600.00
0005433511988	795	Economy	14600.00
0005432922513	795	Economy	14600.00
0005433511987	795	Economy	14600.00
0005433511905	16139	Economy	16100.00
0005432922542	16139	Economy	14600.00
0005433511895	16139	Economy	14600.00
0005433511926	16139	Economy	14600.00
0005433511896	16139	Economy	14600.00
0005433511911	16139	Economy	14600.00
0005433511948	16139	Economy	14600.00
0005433511945	16139	Economy	14600.00
0005432922540	16139	Economy	14600.00
0005433511942	16139	Economy	14600.00
0005433511947	16139	Economy	14600.00
0005432922543	16139	Economy	14600.00
0005433511943	16139	Economy	14600.00
0005433511904	16139	Economy	14600.00
0005432922541	16139	Economy	14600.00
0005433475722	4045	Economy	12300.00
0005435852567	4045	Economy	12300.00
0005433475726	4045	Economy	12300.00
0005435852572	4045	Economy	12300.00
0005433475724	4045	Economy	12300.00
0005435852565	4045	Economy	12300.00
0005433475723	4045	Economy	12300.00
0005433475725	4045	Economy	12300.00
0005435852559	4045	Economy	12300.00
0005433475720	4045	Economy	12300.00
0005435852560	4045	Economy	12300.00
0005433475719	4045	Economy	12300.00
0005435852573	4045	Economy	12300.00
0005433475721	4045	Economy	12300.00
0005435852570	4045	Economy	12300.00
0005435852562	4045	Economy	12300.00
0005435852569	4045	Economy	12300.00
0005435852561	4045	Economy	12300.00
0005433475727	4045	Economy	12300.00
0005435697457	3662	Economy	7900.00
0005435697465	3662	Economy	7200.00
0005435697464	3662	Economy	7200.00
0005435697446	3662	Economy	7200.00
0005435935048	3662	Economy	7200.00
0005434950547	3662	Economy	7200.00
0005435697448	3662	Economy	7200.00
0005434950548	3662	Economy	7200.00
0005435697452	3662	Economy	7200.00
0005435697455	3662	Economy	7200.00
0005435697450	3662	Economy	7200.00
0005435697466	3662	Economy	7200.00
0005435697447	3662	Economy	7200.00
0005435697449	3662	Economy	7200.00
0005435697470	3662	Economy	7200.00
0005435697467	3662	Economy	7200.00
0005434950549	3662	Economy	7200.00
0005435697473	3662	Economy	7200.00
0005435697453	3662	Economy	7200.00
0005435697454	3662	Economy	7200.00
0005435697451	3662	Economy	7200.00
0005435697461	3662	Economy	7200.00
0005435697460	3662	Economy	7200.00
0005435916157	3662	Economy	7200.00
0005435935035	3662	Economy	7200.00
0005435697458	3662	Economy	7200.00
0005435697471	3662	Economy	7200.00
0005435697463	3662	Economy	7200.00
0005435697462	3662	Economy	7200.00
0005435697456	3662	Economy	7200.00
0005434950550	3662	Economy	7200.00
0005435697459	3662	Economy	7200.00
0005435697469	3662	Economy	7200.00
0005435697472	3662	Economy	7200.00
0005435916155	3662	Economy	7200.00
0005435697468	3662	Economy	7200.00
0005435697102	16300	Economy	7900.00
0005435697079	16300	Economy	7900.00
0005434950512	16300	Economy	7900.00
0005435697052	16300	Economy	7900.00
0005434950528	16300	Economy	7200.00
0005435697169	16300	Economy	7200.00
0005435697172	16300	Economy	7200.00
0005434950509	16300	Economy	7200.00
0005435916179	16300	Economy	7200.00
0005435697243	16300	Economy	7200.00
0005435697147	16300	Economy	7200.00
0005435697053	16300	Economy	7200.00
0005435697144	16300	Economy	7200.00
0005435697080	16300	Economy	7200.00
0005434950513	16300	Economy	7200.00
0005435697170	16300	Economy	7200.00
0005435697148	16300	Economy	7200.00
0005435697117	16300	Economy	7200.00
0005434950517	16300	Economy	7200.00
0005435697242	16300	Economy	7200.00
0005435697238	16300	Economy	7200.00
0005435697251	16300	Economy	7200.00
0005435697277	16300	Economy	7200.00
0005434950524	16300	Economy	7200.00
0005435697078	16300	Economy	7200.00
0005435697127	16300	Economy	7200.00
0005434950516	16300	Economy	7200.00
0005435697317	16300	Economy	7200.00
0005435916178	16300	Economy	7200.00
0005435697228	16300	Economy	7200.00
0005435697260	16300	Economy	7200.00
0005435697164	16300	Economy	7200.00
0005435697244	16300	Economy	7200.00
0005435697227	16300	Economy	7200.00
0005435697159	16300	Economy	7200.00
0005435697153	16300	Economy	7200.00
0005435916180	16300	Economy	7200.00
0005435697146	16300	Economy	7200.00
0005435935058	16300	Economy	7200.00
0005435697308	16300	Economy	7200.00
0005435697113	16300	Economy	7200.00
0005434950529	16300	Economy	7200.00
0005435697218	16300	Economy	7200.00
0005435697278	16300	Economy	7200.00
0005435697197	16300	Economy	7200.00
0005435697261	16300	Economy	7200.00
0005434606841	3965	Economy	21300.00
0005433519476	3965	Economy	21300.00
0005432609751	3965	Economy	21300.00
0005432609747	3965	Economy	19300.00
0005433519479	3965	Economy	19300.00
0005434604912	3965	Economy	19300.00
0005433519480	3965	Economy	19300.00
0005435853609	3965	Economy	19300.00
0005434604914	3965	Economy	19300.00
0005434606842	3965	Economy	19300.00
0005433519478	3965	Economy	19300.00
0005432607585	3965	Economy	19300.00
0005434604910	3965	Economy	19300.00
0005435853610	3965	Economy	19300.00
0005432609749	3965	Economy	19300.00
0005432609748	3965	Economy	19300.00
0005434604909	3965	Economy	19300.00
0005435853611	3965	Economy	19300.00
0005434606843	3965	Economy	19300.00
0005432607584	3965	Economy	19300.00
0005432609750	3965	Economy	19300.00
0005435853599	3965	Economy	19300.00
0005434606844	3965	Economy	19300.00
0005434604911	3965	Economy	19300.00
0005434606839	3965	Economy	19300.00
0005434604913	3965	Economy	19300.00
0005433519477	3965	Economy	19300.00
0005434606840	3965	Economy	19300.00
0005432607583	3965	Economy	19300.00
0005433519435	22060	Economy	21300.00
0005435853620	22060	Economy	19300.00
0005434606802	22060	Economy	19300.00
0005433519439	22060	Economy	19300.00
0005434606806	22060	Economy	19300.00
0005434606800	22060	Economy	19300.00
0005433519436	22060	Economy	19300.00
0005434606801	22060	Economy	19300.00
0005434603020	22060	Economy	19300.00
0005433348991	726	Economy	3700.00
0005433348981	726	Economy	3700.00
0005433348992	726	Economy	3700.00
0005433348969	726	Economy	3700.00
0005433348967	726	Economy	3700.00
0005433348974	726	Economy	3700.00
0005433348952	726	Economy	3700.00
0005433348980	726	Economy	3700.00
0005433348968	726	Economy	3700.00
0005435628736	726	Economy	3700.00
0005433349016	15921	Economy	3700.00
0005433349015	15921	Economy	3700.00
0005433349012	15921	Economy	3700.00
0005433349013	15921	Economy	3700.00
0005435628707	15921	Economy	3700.00
0005435628716	15921	Economy	3700.00
0005433349014	15921	Economy	3700.00
0005433159307	17202	Economy	7100.00
0005433158127	17202	Economy	7100.00
0005434445254	17202	Economy	7100.00
0005433159294	17202	Economy	7100.00
0005433159304	17202	Economy	7100.00
0005433159295	17202	Economy	7100.00
0005434445255	17202	Economy	7100.00
0005433158117	17202	Economy	7100.00
0005433158126	17202	Economy	7100.00
0005433159293	17202	Economy	7100.00
0005433159322	17567	Economy	7100.00
0005433159323	17567	Economy	7100.00
0005435132926	7913	Economy	5900.00
0005435132927	7913	Economy	5400.00
0005435132922	7913	Economy	5400.00
0005435132929	7913	Economy	5400.00
0005435383129	7913	Economy	5400.00
0005435132928	7913	Economy	5400.00
0005435132923	7913	Economy	5400.00
0005435132930	7913	Economy	5400.00
0005435132925	7913	Economy	5400.00
0005435132931	7913	Economy	5400.00
0005435132924	7913	Economy	5400.00
0005435383140	7913	Economy	5400.00
0005435383134	7913	Economy	5400.00
0005435383133	7913	Economy	5400.00
0005435132837	33078	Economy	5900.00
0005435383173	33078	Economy	5900.00
0005435383171	33078	Economy	5900.00
0005435383175	33078	Economy	5400.00
0005435132825	33078	Economy	5400.00
0005435132794	33078	Economy	5400.00
0005435383170	33078	Economy	5400.00
0005435132836	33078	Economy	5400.00
0005435383174	33078	Economy	5400.00
0005435132850	33078	Economy	5400.00
0005435132865	33078	Economy	5400.00
0005435132851	33078	Economy	5400.00
0005435132866	33078	Economy	5400.00
0005435383172	33078	Economy	5400.00
0005435160346	7509	Economy	13800.00
0005435390200	7509	Economy	12500.00
0005435390180	7509	Economy	12500.00
0005435390193	7509	Economy	12500.00
0005435390214	7509	Economy	12500.00
0005435390222	7509	Economy	12500.00
0005435160347	7509	Economy	12500.00
0005435160345	7509	Economy	12500.00
0005435160348	7509	Economy	12500.00
0005435160352	7509	Economy	12500.00
0005435160354	7509	Economy	12500.00
0005435160353	7509	Economy	12500.00
0005435160351	7509	Economy	12500.00
0005435160349	7509	Economy	12500.00
0005435390181	7509	Economy	12500.00
0005435160350	7509	Economy	12500.00
0005435160344	7509	Economy	12500.00
0005435390221	7509	Economy	12500.00
0005435390270	29562	Economy	13800.00
0005435160255	29562	Economy	13800.00
0005435160282	29562	Economy	13800.00
0005435390273	29562	Economy	12500.00
0005435160279	29562	Economy	12500.00
0005435160272	29562	Economy	12500.00
0005435390269	29562	Economy	12500.00
0005435390272	29562	Economy	12500.00
0005435160247	29562	Economy	12500.00
0005435160248	29562	Economy	12500.00
0005435160249	29562	Economy	12500.00
0005435390267	29562	Economy	12500.00
0005435160217	29562	Economy	12500.00
0005435160232	29562	Economy	12500.00
0005435160219	29562	Economy	12500.00
0005435390274	29562	Economy	12500.00
0005435160281	29562	Economy	12500.00
0005435390271	29562	Economy	12500.00
0005435390268	29562	Economy	12500.00
0005435160227	29562	Economy	12500.00
0005435390266	29562	Economy	12500.00
0005435160271	29562	Economy	12500.00
0005435160280	29562	Economy	12500.00
0005432394086	18425	Economy	4900.00
0005432394074	18425	Economy	4900.00
0005432394087	18425	Economy	4900.00
0005432398183	18425	Economy	4900.00
0005432398179	18425	Economy	4900.00
0005432394073	18425	Economy	4900.00
0005432394084	18425	Economy	4900.00
0005432394094	18425	Economy	4900.00
0005432394085	18425	Economy	4900.00
0005432394095	18425	Economy	4900.00
0005432398182	18425	Economy	4900.00
0005432394096	18425	Economy	4900.00
0005435178481	27154	Economy	4900.00
0005432398208	27154	Economy	4900.00
0005432398210	27154	Economy	4900.00
0005432400136	27154	Economy	4900.00
0005432400139	27154	Economy	4900.00
0005432400137	27154	Economy	4900.00
0005432398207	27154	Economy	4900.00
0005432398209	27154	Economy	4900.00
0005432400138	27154	Economy	4900.00
0005432398206	27154	Economy	4900.00
0005432400135	27154	Economy	4900.00
0005434504334	6535	Business	48400.00
0005434504325	6535	Business	48400.00
0005435103963	6535	Business	48400.00
0005434504306	6535	Business	48400.00
0005434504340	6535	Business	48400.00
0005434504316	6535	Business	48400.00
0005434504321	6535	Economy	16100.00
0005434504333	6535	Economy	16100.00
0005434504311	6535	Economy	17800.00
0005434504318	6535	Economy	16100.00
0005435103962	6535	Economy	16100.00
0005434504302	6535	Economy	16100.00
0005434504315	6535	Economy	16100.00
0005434504341	6535	Economy	16100.00
0005434504336	6535	Economy	16100.00
0005434504314	6535	Economy	16100.00
0005434504323	6535	Economy	16100.00
0005434504339	6535	Economy	16100.00
0005434504322	6535	Economy	16100.00
0005434504307	6535	Economy	16100.00
0005434504313	6535	Economy	16100.00
0005434504320	6535	Economy	16100.00
0005434504308	6535	Economy	16100.00
0005434504330	6535	Economy	16100.00
0005434504329	6535	Economy	16100.00
0005434504331	6535	Economy	16100.00
0005434504304	6535	Economy	16100.00
0005434504310	6535	Economy	16100.00
0005435103966	6535	Economy	16100.00
0005434504335	6535	Economy	16100.00
0005434504326	6535	Economy	16100.00
0005434504324	6535	Economy	16100.00
0005435103964	6535	Economy	16100.00
0005434504301	6535	Economy	16100.00
0005434504328	6535	Economy	16100.00
0005434504309	6535	Economy	16100.00
0005434504327	6535	Economy	16100.00
0005434504319	6535	Economy	16100.00
0005434504338	6535	Economy	16100.00
0005435103967	6535	Economy	16100.00
0005434504317	6535	Economy	16100.00
0005434504332	6535	Economy	16100.00
0005434504303	6535	Economy	16100.00
0005434504337	6535	Economy	16100.00
0005435103965	6535	Economy	16100.00
0005434504312	6535	Economy	16100.00
0005434504305	6535	Economy	16100.00
0005435103877	22637	Business	48400.00
0005434504018	22637	Business	48400.00
0005435103845	22637	Business	48400.00
0005434503875	22637	Business	48400.00
0005434503969	22637	Business	48400.00
0005434503735	22637	Business	48400.00
0005434504010	22637	Business	48400.00
0005434503903	22637	Business	48400.00
0005434503937	22637	Economy	16100.00
0005434503918	22637	Economy	16100.00
0005435103864	22637	Economy	16100.00
0005435103871	22637	Economy	16100.00
0005435103865	22637	Economy	17800.00
0005434503935	22637	Economy	17800.00
0005434503787	22637	Economy	17800.00
0005434503828	22637	Economy	16100.00
0005434503998	22637	Economy	16100.00
0005435103870	22637	Economy	16100.00
0005434503829	22637	Economy	16100.00
0005434503668	22637	Economy	16100.00
0005434503957	22637	Economy	16100.00
0005434504007	22637	Economy	16100.00
0005435103866	22637	Economy	16100.00
0005435103856	22637	Economy	16100.00
0005434503874	22637	Economy	16100.00
0005434503706	22637	Economy	16100.00
0005434503970	22637	Economy	16100.00
0005435103873	22637	Economy	16100.00
0005434503905	22637	Economy	16100.00
0005434503964	22637	Economy	16100.00
0005435103872	22637	Economy	16100.00
0005435103834	22637	Economy	16100.00
0005434503761	22637	Economy	16100.00
0005434504009	22637	Economy	16100.00
0005434503916	22637	Economy	16100.00
0005434503926	22637	Economy	16100.00
0005434503955	22637	Economy	16100.00
0005434503723	22637	Economy	16100.00
0005434503917	22637	Economy	16100.00
0005435103876	22637	Economy	16100.00
0005434503881	22637	Economy	16100.00
0005435103850	22637	Economy	16100.00
0005434503788	22637	Economy	16100.00
0005434504054	22637	Economy	16100.00
0005434503927	22637	Economy	16100.00
0005434503904	22637	Economy	16100.00
0005434504062	22637	Economy	16100.00
0005434503958	22637	Economy	16100.00
0005435103851	22637	Economy	16100.00
0005434503931	22637	Economy	16100.00
0005434503793	22637	Economy	16100.00
0005434503734	22637	Economy	16100.00
0005434503940	22637	Economy	16100.00
0005434503786	22637	Economy	16100.00
0005434503934	22637	Economy	16100.00
0005434503852	22637	Economy	16100.00
0005434503906	22637	Economy	16100.00
0005434503777	22637	Economy	16100.00
0005434503743	22637	Economy	16100.00
0005434503742	22637	Economy	16100.00
0005434503965	22637	Economy	16100.00
0005433367753	1697	Business	50000.00
0005435653237	1697	Business	50000.00
0005433367659	1697	Business	50000.00
0005435653261	1697	Business	50000.00
0005433367692	1697	Business	50000.00
0005433367776	1697	Business	50000.00
0005435653240	1697	Business	50000.00
0005433367505	1697	Business	50000.00
0005433367604	1697	Economy	16700.00
0005433367818	1697	Economy	16700.00
0005433367673	1697	Economy	16700.00
0005433367718	1697	Economy	16700.00
0005435653252	1697	Economy	16700.00
0005433367734	1697	Economy	16700.00
0005433367770	1697	Economy	16700.00
0005433367856	1697	Economy	16700.00
0005435653245	1697	Economy	18300.00
0005433367769	1697	Economy	18300.00
0005435653256	1697	Economy	18300.00
0005433367766	1697	Economy	16700.00
0005433367855	1697	Economy	16700.00
0005435653259	1697	Economy	16700.00
0005433367817	1697	Economy	16700.00
0005435653253	1697	Economy	16700.00
0005435653242	1697	Economy	16700.00
0005433367672	1697	Economy	16700.00
0005433367724	1697	Economy	16700.00
0005435653249	1697	Economy	16700.00
0005435653247	1697	Economy	16700.00
0005435653248	1697	Economy	16700.00
0005433367748	1697	Economy	16700.00
0005435653243	1697	Economy	16700.00
0005433367679	1697	Economy	16700.00
0005433367750	1697	Economy	16700.00
0005435653250	1697	Economy	16700.00
0005433367712	1697	Economy	16700.00
0005435653254	1697	Economy	16700.00
0005433367749	1697	Economy	16700.00
0005433367694	1697	Economy	16700.00
0005433367775	1697	Economy	16700.00
0005435653260	1697	Economy	16700.00
0005433367732	1697	Economy	16700.00
0005433367808	1697	Economy	16700.00
0005433367807	1697	Economy	16700.00
0005433367790	1697	Economy	16700.00
0005435653255	1697	Economy	16700.00
0005435653241	1697	Economy	16700.00
0005435653239	1697	Economy	16700.00
0005433367683	1697	Economy	16700.00
0005433367703	1697	Economy	16700.00
0005435653238	1697	Economy	16700.00
0005433367758	1697	Economy	16700.00
0005435653258	1697	Economy	16700.00
0005433367574	1697	Economy	16700.00
0005433367789	1697	Economy	16700.00
0005433367729	1697	Economy	16700.00
0005433367693	1697	Economy	16700.00
0005433367711	1697	Economy	16700.00
0005433367798	1697	Economy	16700.00
0005433367717	1697	Economy	16700.00
0005433367627	1697	Economy	16700.00
0005433367733	1697	Economy	16700.00
0005433367751	1697	Economy	16700.00
0005433367731	1697	Economy	16700.00
0005433367853	1697	Economy	16700.00
0005433367852	1697	Economy	16700.00
0005433367691	1697	Economy	16700.00
0005433367682	1697	Economy	16700.00
0005435653246	1697	Economy	16700.00
0005433367765	1697	Economy	16700.00
0005433367605	1697	Economy	16700.00
0005435653244	1697	Economy	16700.00
0005433367506	1697	Economy	16700.00
0005435653257	1697	Economy	16700.00
0005435653251	1697	Economy	16700.00
0005433367656	1697	Economy	16700.00
0005435652665	21717	Business	50000.00
0005435652839	21717	Business	50000.00
0005435652749	21717	Business	50000.00
0005435652763	21717	Business	50000.00
0005435652779	21717	Business	50000.00
0005433368035	21717	Business	50000.00
0005435652764	21717	Business	50000.00
0005435652664	21717	Business	50000.00
0005435652840	21717	Business	50000.00
0005435652852	21717	Business	50000.00
0005433368037	21717	Business	50000.00
0005435652688	21717	Business	50000.00
0005433368049	21717	Economy	16700.00
0005433368062	21717	Economy	16700.00
0005433368059	21717	Economy	16700.00
0005433368054	21717	Economy	16700.00
0005433368043	21717	Economy	16700.00
0005435652825	21717	Economy	16700.00
0005433368042	21717	Economy	16700.00
0005435652650	21717	Economy	16700.00
0005433368050	21717	Economy	16700.00
0005433368032	21717	Economy	18300.00
0005435652732	21717	Economy	18300.00
0005435652836	21717	Economy	18300.00
0005435652735	21717	Economy	18300.00
0005435652843	21717	Economy	18300.00
0005433368046	21717	Economy	16700.00
0005433368029	21717	Economy	16700.00
0005433368061	21717	Economy	16700.00
0005435652802	21717	Economy	16700.00
0005433368030	21717	Economy	16700.00
0005433368036	21717	Economy	16700.00
0005435652844	21717	Economy	16700.00
0005433368056	21717	Economy	16700.00
0005433368047	21717	Economy	16700.00
0005435652778	21717	Economy	16700.00
0005435652829	21717	Economy	16700.00
0005433368028	21717	Economy	16700.00
0005433368034	21717	Economy	16700.00
0005435652853	21717	Economy	16700.00
0005435652862	21717	Economy	16700.00
0005435652806	21717	Economy	16700.00
0005435652824	21717	Economy	16700.00
0005435652854	21717	Economy	16700.00
0005435652700	21717	Economy	16700.00
0005435652466	21717	Economy	16700.00
0005435652683	21717	Economy	16700.00
0005433368031	21717	Economy	16700.00
0005433368052	21717	Economy	16700.00
0005435652761	21717	Economy	16700.00
0005435652762	21717	Economy	16700.00
0005435652653	21717	Economy	16700.00
0005435652845	21717	Economy	16700.00
0005433368053	21717	Economy	16700.00
0005433368033	21717	Economy	16700.00
0005433368055	21717	Economy	16700.00
0005435652828	21717	Economy	16700.00
0005433368051	21717	Economy	16700.00
0005433368048	21717	Economy	16700.00
0005433368041	21717	Economy	16700.00
0005433368040	21717	Economy	16700.00
0005433368027	21717	Economy	16700.00
0005435652747	21717	Economy	16700.00
0005435652805	21717	Economy	16700.00
0005433368039	21717	Economy	16700.00
0005435652684	21717	Economy	16700.00
0005433368057	21717	Economy	16700.00
0005433368060	21717	Economy	16700.00
0005433368038	21717	Economy	16700.00
0005435652748	21717	Economy	16700.00
0005433368026	21717	Economy	16700.00
0005435652689	21717	Economy	16700.00
0005433368058	21717	Economy	16700.00
0005435652690	21717	Economy	16700.00
0005435652872	21717	Economy	16700.00
0005435652846	21717	Economy	16700.00
0005435652786	21717	Economy	16700.00
0005433368044	21717	Economy	16700.00
0005433368045	21717	Economy	16700.00
0005435652649	21717	Economy	16700.00
0005435652803	21717	Economy	16700.00
0005435652696	21717	Economy	16700.00
0005435652804	21717	Economy	16700.00
0005435652736	21717	Economy	16700.00
0005435652773	21717	Economy	16700.00
0005435627117	23771	Economy	11200.00
0005435627116	23771	Economy	11200.00
0005433986173	4146	Business	21500.00
0005433986162	4146	Business	21500.00
0005433986172	4146	Business	21500.00
0005433986143	4146	Business	21500.00
0005433986166	4146	Business	21500.00
0005433986148	4146	Economy	7200.00
0005433986146	4146	Economy	7200.00
0005433986160	4146	Economy	7200.00
0005433986156	4146	Economy	7200.00
0005433986149	4146	Economy	7900.00
0005433986134	4146	Economy	7900.00
0005433986168	4146	Economy	7900.00
0005433986158	4146	Economy	7900.00
0005433986155	4146	Economy	7200.00
0005433986153	4146	Economy	7200.00
0005433986141	4146	Economy	7200.00
0005433986165	4146	Economy	7200.00
0005433986131	4146	Economy	7200.00
0005433986150	4146	Economy	7200.00
0005433986164	4146	Economy	7200.00
0005433986138	4146	Economy	7200.00
0005433986139	4146	Economy	7200.00
0005433986144	4146	Economy	7200.00
0005433986161	4146	Economy	7200.00
0005433986159	4146	Economy	7200.00
0005433986145	4146	Economy	7200.00
0005433986132	4146	Economy	7200.00
0005433986175	4146	Economy	7200.00
0005433986135	4146	Economy	7200.00
0005433986133	4146	Economy	7200.00
0005433986170	4146	Economy	7200.00
0005433986167	4146	Economy	7200.00
0005435788781	4146	Economy	7200.00
0005433986152	4146	Economy	7200.00
0005433986142	4146	Economy	7200.00
0005433986130	4146	Economy	7200.00
0005433986154	4146	Economy	7200.00
0005433986163	4146	Economy	7200.00
0005433986151	4146	Economy	7200.00
0005433986174	4146	Economy	7200.00
0005433986171	4146	Economy	7200.00
0005433986137	4146	Economy	7200.00
0005433986169	4146	Economy	7200.00
0005433986157	4146	Economy	7200.00
0005433986147	4146	Economy	7200.00
0005433986140	4146	Economy	7200.00
0005435788782	4146	Economy	7200.00
0005433986136	4146	Economy	7200.00
0005433985549	25649	Business	21500.00
0005433985711	25649	Business	21500.00
0005433985619	25649	Business	21500.00
0005433985727	25649	Business	21500.00
0005433985789	25649	Business	21500.00
0005433985642	25649	Business	21500.00
0005433985644	25649	Business	21500.00
0005433985584	25649	Economy	7200.00
0005433985630	25649	Economy	7200.00
0005433985721	25649	Economy	7200.00
0005433985710	25649	Economy	7200.00
0005433985647	25649	Economy	7200.00
0005433985657	25649	Economy	7200.00
0005433985636	25649	Economy	7200.00
0005433985790	25649	Economy	7900.00
0005433985645	25649	Economy	7900.00
0005433985665	25649	Economy	7200.00
0005433985786	25649	Economy	7200.00
0005433985801	25649	Economy	7200.00
0005433985751	25649	Economy	7200.00
0005433985656	25649	Economy	7200.00
0005433985658	25649	Economy	7200.00
0005433985699	25649	Economy	7200.00
0005433985787	25649	Economy	7200.00
0005433985705	25649	Economy	7200.00
0005433985666	25649	Economy	7200.00
0005433985720	25649	Economy	7200.00
0005433985649	25649	Economy	7200.00
0005433985698	25649	Economy	7200.00
0005433985620	25649	Economy	7200.00
0005433985580	25649	Economy	7200.00
0005433985697	25649	Economy	7200.00
0005433985812	25649	Economy	7200.00
0005433985740	25649	Economy	7200.00
0005433985631	25649	Economy	7200.00
0005433985550	25649	Economy	7200.00
0005433985690	25649	Economy	7200.00
0005433985771	25649	Economy	7200.00
0005433985650	25649	Economy	7200.00
0005433985623	25649	Economy	7200.00
0005433985746	25649	Economy	7200.00
0005435788768	25649	Economy	7200.00
0005433985728	25649	Economy	7200.00
0005433985646	25649	Economy	7200.00
0005433985726	25649	Economy	7200.00
0005433985741	25649	Economy	7200.00
0005433985551	25649	Economy	7200.00
0005433461585	20247	Business	201300.00
0005433460436	20247	Business	201300.00
0005433461591	20247	Business	201300.00
0005433461590	20247	Business	201300.00
0005433460438	20247	Economy	73800.00
0005433461596	20247	Economy	73800.00
0005433460440	20247	Economy	67100.00
0005433460443	20247	Economy	67100.00
0005433460442	20247	Economy	67100.00
0005433461581	20247	Economy	67100.00
0005433460430	20247	Economy	67100.00
0005433460429	20247	Economy	67100.00
0005433461589	20247	Economy	67100.00
0005433460431	20247	Economy	67100.00
0005433460441	20247	Economy	67100.00
0005433461593	20247	Economy	67100.00
0005433460434	20247	Economy	67100.00
0005433461584	20247	Economy	67100.00
0005433461583	20247	Economy	67100.00
0005433461594	20247	Economy	67100.00
0005433460432	20247	Economy	67100.00
0005433460435	20247	Economy	67100.00
0005433460433	20247	Economy	67100.00
0005433461595	20247	Economy	67100.00
0005433461582	20247	Economy	67100.00
0005433461586	20247	Economy	67100.00
0005433460437	20247	Economy	67100.00
0005433460439	20247	Economy	67100.00
0005433461592	20247	Economy	67100.00
0005433461588	20247	Economy	67100.00
0005433460444	20247	Economy	67100.00
0005433461587	20247	Economy	67100.00
0005435719568	21234	Economy	9400.00
0005435719567	21234	Economy	9400.00
0005433168384	21333	Economy	15500.00
0005434509135	21333	Economy	15500.00
0005434509097	21333	Economy	15500.00
0005433168390	21333	Economy	15500.00
0005434509110	21333	Economy	15500.00
0005433168387	21333	Economy	15500.00
0005434509109	21333	Economy	15500.00
0005434509093	21333	Economy	15500.00
0005433168388	21333	Economy	15500.00
0005433168385	21333	Economy	15500.00
0005433168389	21333	Economy	15500.00
0005433168392	21333	Economy	15500.00
0005433168391	21333	Economy	15500.00
0005434509087	21333	Economy	15500.00
0005433168386	21333	Economy	15500.00
0005432659693	17834	Business	18000.00
0005432661900	17834	Business	18000.00
0005432657441	17834	Business	18000.00
0005432665263	17834	Business	18000.00
0005432657442	17834	Business	18000.00
0005432666387	17834	Economy	6000.00
0005432666379	17834	Economy	6000.00
0005432661911	17834	Economy	6000.00
0005434151718	17834	Economy	6000.00
0005432869554	17834	Economy	6000.00
0005432655463	17834	Economy	6600.00
0005432655438	17834	Economy	6600.00
0005432655478	17834	Economy	6600.00
0005432667448	17834	Economy	6600.00
0005432665264	17834	Economy	6000.00
0005434151717	17834	Economy	6000.00
0005432869559	17834	Economy	6000.00
0005432667446	17834	Economy	6000.00
0005432667445	17834	Economy	6000.00
0005432666366	17834	Economy	6000.00
0005432655437	17834	Economy	6000.00
0005432659698	17834	Economy	6000.00
0005432869555	17834	Economy	6000.00
0005432666378	17834	Economy	6000.00
0005432655476	17834	Economy	6000.00
0005432655457	17834	Economy	6000.00
0005432664125	17834	Economy	6000.00
0005432666377	17834	Economy	6000.00
0005432869557	17834	Economy	6000.00
0005432869558	17834	Economy	6000.00
0005432657428	17834	Economy	6000.00
0005432655477	17834	Economy	6000.00
0005432657426	17834	Economy	6000.00
0005432667449	17834	Economy	6000.00
0005432659697	17834	Economy	6000.00
0005432655442	17834	Economy	6000.00
0005432659692	17834	Economy	6000.00
0005432660806	17834	Economy	6000.00
0005432655506	17834	Economy	6000.00
0005432655496	17834	Economy	6000.00
0005432660802	17834	Economy	6000.00
0005432655489	17834	Economy	6000.00
0005432655450	17834	Economy	6000.00
0005434151720	17834	Economy	6000.00
0005432659694	17834	Economy	6000.00
0005432869556	17834	Economy	6000.00
0005432655460	17834	Economy	6000.00
0005432655475	17834	Economy	6000.00
0005432658572	17834	Economy	6000.00
0005432655422	17834	Economy	6000.00
0005432667440	17834	Economy	6000.00
0005432657427	17834	Economy	6000.00
0005432869553	17834	Economy	6000.00
0005434151719	17834	Economy	6000.00
0005432869488	26284	Business	18000.00
0005432658598	26284	Business	18000.00
0005432667460	26284	Business	18000.00
0005432655564	26284	Business	18000.00
0005432869485	26284	Business	18000.00
0005432667459	26284	Business	18000.00
0005432655559	26284	Economy	6000.00
0005432659713	26284	Economy	6000.00
0005432655562	26284	Economy	6000.00
0005432655565	26284	Economy	6000.00
0005432869482	26284	Economy	6000.00
0005432655561	26284	Economy	6600.00
0005432666395	26284	Economy	6600.00
0005432655568	26284	Economy	6000.00
0005432869493	26284	Economy	6000.00
0005432659711	26284	Economy	6000.00
0005432659714	26284	Economy	6000.00
0005432666394	26284	Economy	6000.00
0005432660824	26284	Economy	6000.00
0005432657458	26284	Economy	6000.00
0005432658597	26284	Economy	6000.00
0005432667461	26284	Economy	6000.00
0005432655569	26284	Economy	6000.00
0005432869484	26284	Economy	6000.00
0005432657459	26284	Economy	6000.00
0005432869486	26284	Economy	6000.00
0005432660823	26284	Economy	6000.00
0005432655567	26284	Economy	6000.00
0005432659712	26284	Economy	6000.00
0005432869469	26284	Economy	6000.00
0005432665281	26284	Economy	6000.00
0005432665280	26284	Economy	6000.00
0005432655566	26284	Economy	6000.00
0005434151693	26284	Economy	6000.00
0005432655570	26284	Economy	6000.00
0005434151679	26284	Economy	6000.00
0005432655560	26284	Economy	6000.00
0005432657457	26284	Economy	6000.00
0005432869470	26284	Economy	6000.00
0005432869475	26284	Economy	6000.00
0005432658596	26284	Economy	6000.00
0005432655563	26284	Economy	6000.00
0005432655558	26284	Economy	6000.00
0005432328902	3119	Business	16100.00
0005432905097	3119	Business	16100.00
0005432328886	3119	Business	16100.00
0005432328898	3119	Business	16100.00
0005432328893	3119	Business	16100.00
0005432328897	3119	Business	16100.00
0005432328916	3119	Business	16100.00
0005433438911	3119	Business	16100.00
0005432328892	3119	Business	16100.00
0005432328922	3119	Economy	5400.00
0005432905098	3119	Economy	5400.00
0005432328877	3119	Economy	5400.00
0005432287213	3119	Economy	5400.00
0005432328907	3119	Economy	5400.00
0005433438908	3119	Economy	5400.00
0005433438905	3119	Economy	5400.00
0005432328891	3119	Economy	5400.00
0005433438906	3119	Economy	5400.00
0005432328882	3119	Economy	5900.00
0005432328889	3119	Economy	5900.00
0005432328923	3119	Economy	5900.00
0005432287212	3119	Economy	5400.00
0005432905129	3119	Economy	5400.00
0005432328900	3119	Economy	5400.00
0005433438903	3119	Economy	5400.00
0005432328925	3119	Economy	5400.00
0005432287211	3119	Economy	5400.00
0005432905128	3119	Economy	5400.00
0005432328905	3119	Economy	5400.00
0005433438904	3119	Economy	5400.00
0005432328906	3119	Economy	5400.00
0005432328919	3119	Economy	5400.00
0005432328920	3119	Economy	5400.00
0005432328880	3119	Economy	5400.00
0005432328924	3119	Economy	5400.00
0005432328917	3119	Economy	5400.00
0005432328909	3119	Economy	5400.00
0005432328914	3119	Economy	5400.00
0005432328883	3119	Economy	5400.00
0005432905084	3119	Economy	5400.00
0005432328921	3119	Economy	5400.00
0005432328884	3119	Economy	5400.00
0005432328881	3119	Economy	5400.00
0005432328918	3119	Economy	5400.00
0005432328887	3119	Economy	5400.00
0005432328904	3119	Economy	5400.00
0005432328915	3119	Economy	5400.00
0005432328896	3119	Economy	5400.00
0005432328901	3119	Economy	5400.00
0005432328903	3119	Economy	5400.00
0005433438907	3119	Economy	5400.00
0005432328913	3119	Economy	5400.00
0005432328910	3119	Economy	5400.00
0005432328911	3119	Economy	5400.00
0005432328890	3119	Economy	5400.00
0005432287210	3119	Economy	5400.00
0005432328912	3119	Economy	5400.00
0005432328895	3119	Economy	5400.00
0005432905085	3119	Economy	5400.00
0005432328879	3119	Economy	5400.00
0005433438912	3119	Economy	5400.00
0005432328885	3119	Economy	5400.00
0005432328878	3119	Economy	5400.00
0005432328888	3119	Economy	5400.00
0005432328908	3119	Economy	5400.00
0005433438909	3119	Economy	5400.00
0005432328894	3119	Economy	5400.00
0005432328899	3119	Economy	5400.00
0005433438910	3119	Economy	5400.00
0005432328427	31137	Business	16100.00
0005432905148	31137	Business	16100.00
0005432328498	31137	Business	16100.00
0005432328372	31137	Business	16100.00
0005432328454	31137	Business	16100.00
0005432328420	31137	Business	16100.00
0005432328255	31137	Business	16100.00
0005433438805	31137	Business	16100.00
0005432328373	31137	Economy	5400.00
0005433438828	31137	Economy	5400.00
0005432328416	31137	Economy	5400.00
0005432328422	31137	Economy	5400.00
0005432328400	31137	Economy	5400.00
0005432328474	31137	Economy	5400.00
0005432328648	31137	Economy	5400.00
0005432328401	31137	Economy	5400.00
0005432328647	31137	Economy	5400.00
0005432328318	31137	Economy	5900.00
0005432328575	31137	Economy	5900.00
0005432054316	31137	Economy	5900.00
0005432328300	31137	Economy	5900.00
0005432328649	31137	Economy	5400.00
0005432328361	31137	Economy	5400.00
0005432328499	31137	Economy	5400.00
0005432905150	31137	Economy	5400.00
0005432328582	31137	Economy	5400.00
0005432328341	31137	Economy	5400.00
0005432905149	31137	Economy	5400.00
0005432328398	31137	Economy	5400.00
0005432905151	31137	Economy	5400.00
0005432328296	31137	Economy	5400.00
0005432328469	31137	Economy	5400.00
0005432328395	31137	Economy	5400.00
0005433438827	31137	Economy	5400.00
0005432328428	31137	Economy	5400.00
0005432328538	31137	Economy	5400.00
0005432054315	31137	Economy	5400.00
0005432328502	31137	Economy	5400.00
0005432328583	31137	Economy	5400.00
0005432054317	31137	Economy	5400.00
0005433438829	31137	Economy	5400.00
0005432328301	31137	Economy	5400.00
0005432328519	31137	Economy	5400.00
0005432328507	31137	Economy	5400.00
0005432328563	31137	Economy	5400.00
0005432328415	31137	Economy	5400.00
0005433438836	31137	Economy	5400.00
0005432328421	31137	Economy	5400.00
0005432328407	31137	Economy	5400.00
0005432328620	31137	Economy	5400.00
0005432328496	31137	Economy	5400.00
0005432328348	31137	Economy	5400.00
0005432328347	31137	Economy	5400.00
0005432328378	31137	Economy	5400.00
0005432328531	31137	Economy	5400.00
0005432328466	31137	Economy	5400.00
0005432328495	31137	Economy	5400.00
0005432328408	31137	Economy	5400.00
0005432328459	31137	Economy	5400.00
0005432328302	31137	Economy	5400.00
0005432328394	31137	Economy	5400.00
0005432905147	31137	Economy	5400.00
0005432328397	31137	Economy	5400.00
0005433438837	31137	Economy	5400.00
0005432905146	31137	Economy	5400.00
0005432328257	31137	Economy	5400.00
0005435487730	6185	Business	124600.00
0005435999324	6185	Business	124600.00
0005435999331	6185	Business	124600.00
0005435487737	6185	Business	124600.00
0005435487723	6185	Economy	41500.00
0005434309803	6185	Economy	41500.00
0005432146207	6185	Economy	41500.00
0005434309797	6185	Economy	41500.00
0005434309807	6185	Economy	41500.00
0005435297018	6185	Economy	41500.00
0005435487724	6185	Economy	41500.00
0005435487771	6185	Economy	41500.00
0005435487712	6185	Economy	41500.00
0005434309796	6185	Economy	41500.00
0005435487793	6185	Economy	41500.00
0005435999330	6185	Economy	41500.00
0005432146208	6185	Economy	41500.00
0005435487653	6185	Economy	41500.00
0005434309799	6185	Economy	41500.00
0005435297031	6185	Economy	41500.00
0005434309802	6185	Economy	45700.00
0005435999329	6185	Economy	45700.00
0005434309794	6185	Economy	41500.00
0005434309795	6185	Economy	41500.00
0005435999332	6185	Economy	41500.00
0005435999326	6185	Economy	41500.00
0005435487736	6185	Economy	41500.00
0005435487654	6185	Economy	41500.00
0005435487630	6185	Economy	41500.00
0005435487721	6185	Economy	41500.00
0005435487692	6185	Economy	41500.00
0005435999327	6185	Economy	41500.00
0005435999323	6185	Economy	41500.00
0005434309798	6185	Economy	41500.00
0005434309800	6185	Economy	41500.00
0005434309804	6185	Economy	41500.00
0005435999325	6185	Economy	41500.00
0005435487593	6185	Economy	41500.00
0005435999333	6185	Economy	41500.00
0005434309805	6185	Economy	41500.00
0005435487722	6185	Economy	41500.00
0005435487594	6185	Economy	41500.00
0005434309806	6185	Economy	41500.00
0005435999328	6185	Economy	41500.00
0005434309801	6185	Economy	41500.00
0005435487805	6185	Economy	41500.00
0005435487719	6185	Economy	41500.00
0005435487729	6185	Economy	41500.00
0005435487792	6185	Economy	41500.00
0005435487829	6185	Economy	41500.00
0005435999334	6185	Economy	41500.00
0005435999105	19541	Business	124600.00
0005435487911	19541	Business	124600.00
0005435487909	19541	Business	124600.00
0005435999181	19541	Business	124600.00
0005435487913	19541	Business	124600.00
0005434309646	19541	Business	124600.00
0005435487917	19541	Economy	41500.00
0005435487914	19541	Economy	41500.00
0005435999152	19541	Economy	41500.00
0005435999119	19541	Economy	41500.00
0005435487900	19541	Economy	41500.00
0005435487901	19541	Economy	41500.00
0005435999158	19541	Economy	41500.00
0005435297091	19541	Economy	41500.00
0005435999138	19541	Economy	41500.00
0005435487899	19541	Economy	41500.00
0005435297090	19541	Economy	41500.00
0005434309728	19541	Economy	41500.00
0005435487908	19541	Economy	41500.00
0005435487915	19541	Economy	41500.00
0005435487902	19541	Economy	41500.00
0005435999169	19541	Economy	41500.00
0005435999137	19541	Economy	41500.00
0005435999125	19541	Economy	41500.00
0005434309662	19541	Economy	45700.00
0005434309645	19541	Economy	45700.00
0005435297086	19541	Economy	41500.00
0005435999166	19541	Economy	41500.00
0005435999180	19541	Economy	41500.00
0005435999168	19541	Economy	41500.00
0005435487904	19541	Economy	41500.00
0005435297088	19541	Economy	41500.00
0005434309691	19541	Economy	41500.00
0005434309661	19541	Economy	41500.00
0005435297085	19541	Economy	41500.00
0005434309708	19541	Economy	41500.00
0005435487906	19541	Economy	41500.00
0005434309659	19541	Economy	41500.00
0005435999139	19541	Economy	41500.00
0005435487910	19541	Economy	41500.00
0005435487916	19541	Economy	41500.00
0005435999108	19541	Economy	41500.00
0005435487905	19541	Economy	41500.00
0005435297089	19541	Economy	41500.00
0005434309619	19541	Economy	41500.00
0005435999153	19541	Economy	41500.00
0005434309702	19541	Economy	41500.00
0005435487912	19541	Economy	41500.00
0005435999143	19541	Economy	41500.00
0005435297087	19541	Economy	41500.00
0005435487907	19541	Economy	41500.00
0005434309685	19541	Economy	41500.00
0005435998987	19541	Economy	41500.00
0005435999109	19541	Economy	41500.00
0005435999136	19541	Economy	41500.00
0005435487903	19541	Economy	41500.00
0005435487918	19541	Economy	41500.00
0005435999135	19541	Economy	41500.00
0005435999101	19541	Economy	41500.00
0005434309647	19541	Economy	41500.00
0005435999167	19541	Economy	41500.00
0005434446513	17545	Economy	13600.00
0005433158140	17545	Economy	13600.00
0005433158137	17545	Economy	12300.00
0005434446498	17545	Economy	12300.00
0005433158138	17545	Economy	12300.00
0005433158139	17545	Economy	12300.00
0005434446504	17545	Economy	12300.00
0005434446505	17545	Economy	12300.00
0005434446506	17545	Economy	12300.00
0005433158136	17545	Economy	12300.00
0005433158141	17545	Economy	12300.00
0005434446503	17545	Economy	12300.00
0005434446512	17545	Economy	12300.00
0005434446511	17545	Economy	12300.00
0005435517984	1557	Business	86000.00
0005435517992	1557	Business	86000.00
0005434565971	1557	Business	86000.00
0005435502407	1557	Business	86000.00
0005434565975	1557	Business	86000.00
0005435502397	1557	Business	86000.00
0005435502419	1557	Business	86000.00
0005434565974	1557	Business	86000.00
0005435517995	1557	Business	86000.00
0005435517991	1557	Economy	28700.00
0005435502404	1557	Economy	28700.00
0005433186096	1557	Economy	28700.00
0005435517986	1557	Economy	28700.00
0005435502416	1557	Economy	28700.00
0005432291941	1557	Economy	28700.00
0005434565976	1557	Economy	28700.00
0005435517994	1557	Economy	28700.00
0005434565970	1557	Economy	28700.00
0005435502406	1557	Economy	28700.00
0005435517990	1557	Economy	31500.00
0005434565968	1557	Economy	31500.00
0005433186095	1557	Economy	31500.00
0005435508401	1557	Economy	31500.00
0005435517993	1557	Economy	28700.00
0005435502413	1557	Economy	28700.00
0005435502414	1557	Economy	28700.00
0005435517987	1557	Economy	28700.00
0005433186109	1557	Economy	28700.00
0005434565973	1557	Economy	28700.00
0005435517982	1557	Economy	28700.00
0005435502410	1557	Economy	28700.00
0005435517985	1557	Economy	28700.00
0005433186101	1557	Economy	28700.00
0005435508403	1557	Economy	28700.00
0005435502408	1557	Economy	28700.00
0005435502405	1557	Economy	28700.00
0005435502401	1557	Economy	28700.00
0005435502415	1557	Economy	28700.00
0005435502399	1557	Economy	28700.00
0005435502403	1557	Economy	28700.00
0005435517988	1557	Economy	28700.00
0005435502418	1557	Economy	28700.00
0005433186080	1557	Economy	28700.00
0005433186076	1557	Economy	28700.00
0005435517980	1557	Economy	28700.00
0005435517979	1557	Economy	28700.00
0005435517989	1557	Economy	28700.00
0005435517978	1557	Economy	28700.00
0005435502411	1557	Economy	28700.00
0005433186108	1557	Economy	28700.00
0005433186075	1557	Economy	28700.00
0005435508405	1557	Economy	28700.00
0005434565969	1557	Economy	28700.00
0005434565972	1557	Economy	28700.00
0005435508400	1557	Economy	28700.00
0005435502409	1557	Economy	28700.00
0005435508404	1557	Economy	28700.00
0005435517996	1557	Economy	28700.00
0005435502417	1557	Economy	28700.00
0005434565978	1557	Economy	28700.00
0005435508402	1557	Economy	28700.00
0005434565977	1557	Economy	28700.00
0005435502398	1557	Economy	28700.00
0005435502400	1557	Economy	28700.00
0005435502412	1557	Economy	28700.00
0005435502402	1557	Economy	28700.00
0005433186110	1557	Economy	28700.00
0005435517983	1557	Economy	28700.00
0005434565979	1557	Economy	28700.00
0005435517981	1557	Economy	28700.00
0005435517977	1557	Economy	28700.00
0005435502277	20895	Business	86000.00
0005433186159	20895	Business	86000.00
0005435502182	20895	Business	86000.00
0005434565836	20895	Business	86000.00
0005435502260	20895	Business	86000.00
0005435502188	20895	Business	86000.00
0005435502241	20895	Business	86000.00
0005434565807	20895	Business	86000.00
0005435545683	20895	Business	86000.00
0005435502254	20895	Business	86000.00
0005435529181	20895	Business	86000.00
0005434565808	20895	Economy	28700.00
0005435502271	20895	Economy	28700.00
0005433186155	20895	Economy	28700.00
0005434565874	20895	Economy	28700.00
0005435529128	20895	Economy	28700.00
0005435502225	20895	Economy	28700.00
0005435502242	20895	Economy	28700.00
0005435502119	20895	Economy	28700.00
0005435529061	20895	Economy	28700.00
0005435502118	20895	Economy	31500.00
0005435502180	20895	Economy	31500.00
0005433186153	20895	Economy	31500.00
0005434565845	20895	Economy	31500.00
0005435502215	20895	Economy	28700.00
0005435502204	20895	Economy	28700.00
0005435502175	20895	Economy	28700.00
0005434565875	20895	Economy	28700.00
0005435502107	20895	Economy	28700.00
0005434565869	20895	Economy	28700.00
0005435502193	20895	Economy	28700.00
0005435529142	20895	Economy	28700.00
0005433186156	20895	Economy	28700.00
0005435502300	20895	Economy	28700.00
0005435502176	20895	Economy	28700.00
0005435529087	20895	Economy	28700.00
0005434565809	20895	Economy	28700.00
0005435529199	20895	Economy	28700.00
0005433186152	20895	Economy	28700.00
0005435545668	20895	Economy	28700.00
0005435502203	20895	Economy	28700.00
0005435502179	20895	Economy	28700.00
0005435502209	20895	Economy	28700.00
0005435502146	20895	Economy	28700.00
0005433186154	20895	Economy	28700.00
0005435502206	20895	Economy	28700.00
0005435502216	20895	Economy	28700.00
0005435529201	20895	Economy	28700.00
0005434565838	20895	Economy	28700.00
0005435502240	20895	Economy	28700.00
0005434565863	20895	Economy	28700.00
0005434565873	20895	Economy	28700.00
0005434565837	20895	Economy	28700.00
0005435545657	20895	Economy	28700.00
0005435502207	20895	Economy	28700.00
0005435502299	20895	Economy	28700.00
0005435529141	20895	Economy	28700.00
0005434565870	20895	Economy	28700.00
0005435545692	20895	Economy	28700.00
0005434565889	20895	Economy	28700.00
0005435502145	20895	Economy	28700.00
0005435529095	20895	Economy	28700.00
0005435529122	20895	Economy	28700.00
0005435502183	20895	Economy	28700.00
0005433186157	20895	Economy	28700.00
0005434565828	20895	Economy	28700.00
0005435545673	20895	Economy	28700.00
0005435502189	20895	Economy	28700.00
0005435502192	20895	Economy	28700.00
0005435502272	20895	Economy	28700.00
0005435529096	20895	Economy	28700.00
0005435529039	20895	Economy	28700.00
0005435529198	20895	Economy	28700.00
0005435502132	20895	Economy	28700.00
0005435502157	20895	Economy	28700.00
0005435502233	20895	Economy	28700.00
0005435502220	20895	Economy	28700.00
0005433186160	20895	Economy	28700.00
0005435529200	20895	Economy	28700.00
0005435545684	20895	Economy	28700.00
0005433186158	20895	Economy	28700.00
0005435529239	20895	Economy	28700.00
0005435153767	3915	Economy	21600.00
0005435153772	3915	Economy	21600.00
0005435931586	3915	Economy	19700.00
0005435153769	3915	Economy	19700.00
0005435931589	3915	Economy	19700.00
0005435153768	3915	Economy	19700.00
0005435153773	3915	Economy	19700.00
0005435931590	3915	Economy	19700.00
0005435931587	3915	Economy	19700.00
0005435153771	3915	Economy	19700.00
0005435153770	3915	Economy	19700.00
0005435153708	21869	Economy	19700.00
0005435931619	21869	Economy	19700.00
0005435153707	21869	Economy	19700.00
0005435931618	21869	Economy	19700.00
0005435931617	21869	Economy	19700.00
0005435931616	21869	Economy	19700.00
0005435153727	21869	Economy	19700.00
0005435153715	21869	Economy	19700.00
0005432628915	7204	Economy	14300.00
0005435225569	7204	Economy	14300.00
0005435225529	7204	Economy	14300.00
0005435225539	7204	Economy	14300.00
0005435225570	7204	Economy	13000.00
0005432628904	7204	Economy	13000.00
0005432628910	7204	Economy	13000.00
0005432628907	7204	Economy	13000.00
0005435225559	7204	Economy	13000.00
0005435225543	7204	Economy	13000.00
0005432628906	7204	Economy	13000.00
0005432628909	7204	Economy	13000.00
0005435225541	7204	Economy	13000.00
0005432628911	7204	Economy	13000.00
0005432628913	7204	Economy	13000.00
0005432628914	7204	Economy	13000.00
0005432628916	7204	Economy	13000.00
0005435225549	7204	Economy	13000.00
0005435225540	7204	Economy	13000.00
0005432628908	7204	Economy	13000.00
0005432628918	7204	Economy	13000.00
0005432628917	7204	Economy	13000.00
0005432628905	7204	Economy	13000.00
0005435225521	7204	Economy	13000.00
0005435225548	7204	Economy	13000.00
0005435225563	7204	Economy	13000.00
0005432628912	7204	Economy	13000.00
0005435225542	7204	Economy	13000.00
0005432628818	28149	Economy	14300.00
0005432628750	28149	Economy	13000.00
0005432628792	28149	Economy	13000.00
0005432628829	28149	Economy	13000.00
0005435225619	28149	Economy	13000.00
0005435225621	28149	Economy	13000.00
0005432628779	28149	Economy	13000.00
0005432628681	28149	Economy	13000.00
0005432628785	28149	Economy	13000.00
0005432628780	28149	Economy	13000.00
0005435225616	28149	Economy	13000.00
0005435225620	28149	Economy	13000.00
0005435225618	28149	Economy	13000.00
0005432628758	28149	Economy	13000.00
0005432628810	28149	Economy	13000.00
0005432628817	28149	Economy	13000.00
0005432628786	28149	Economy	13000.00
0005432628733	28149	Economy	13000.00
0005432628791	28149	Economy	13000.00
0005432628828	28149	Economy	13000.00
0005435225623	28149	Economy	13000.00
0005432628757	28149	Economy	13000.00
0005435225622	28149	Economy	13000.00
0005435225617	28149	Economy	13000.00
0005432628793	28149	Economy	13000.00
0005432628800	28149	Economy	13000.00
0005432628732	28149	Economy	13000.00
0005432628798	28149	Economy	13000.00
0005432628799	28149	Economy	13000.00
0005434267944	8735	Economy	10500.00
0005435960067	8735	Economy	10500.00
0005435960065	8735	Economy	10500.00
0005434267924	8735	Economy	10500.00
0005435960068	8735	Economy	10500.00
0005435960069	8735	Economy	10500.00
0005434267945	8735	Economy	10500.00
0005435960066	8735	Economy	10500.00
0005434267938	8735	Economy	10500.00
0005434267965	15262	Economy	11500.00
0005434267964	15262	Economy	10500.00
0005435960035	15262	Economy	10500.00
0005435960040	15262	Economy	10500.00
0005434267966	15262	Economy	10500.00
0005435960050	15262	Economy	10500.00
0005434267967	15262	Economy	10500.00
0005435960034	15262	Economy	10500.00
0005435960051	15262	Economy	10500.00
0005432675192	1196	Business	115000.00
0005432693176	1196	Business	115000.00
0005432675200	1196	Business	115000.00
0005432693171	1196	Business	115000.00
0005432675201	1196	Business	115000.00
0005432677587	1196	Business	115000.00
0005432675199	1196	Business	115000.00
0005432873228	1196	Business	115000.00
0005432693188	1196	Business	115000.00
0005432693185	1196	Business	115000.00
0005432677588	1196	Business	115000.00
0005432693167	1196	Business	115000.00
0005432693162	1196	Business	115000.00
0005432693181	1196	Business	115000.00
0005432675204	1196	Economy	38300.00
0005432693175	1196	Economy	38300.00
0005432693183	1196	Economy	38300.00
0005432675193	1196	Economy	38300.00
0005432675191	1196	Economy	38300.00
0005432693169	1196	Economy	42200.00
0005432693180	1196	Economy	38300.00
0005432675203	1196	Economy	38300.00
0005432693161	1196	Economy	38300.00
0005432675194	1196	Economy	38300.00
0005432693170	1196	Economy	38300.00
0005432693184	1196	Economy	38300.00
0005432693163	1196	Economy	38300.00
0005432693182	1196	Economy	38300.00
0005432693165	1196	Economy	38300.00
0005432675197	1196	Economy	38300.00
0005432693166	1196	Economy	38300.00
0005432677585	1196	Economy	38300.00
0005432675195	1196	Economy	38300.00
0005432693160	1196	Economy	38300.00
0005432873250	1196	Economy	38300.00
0005432693189	1196	Economy	38300.00
0005432693186	1196	Economy	38300.00
0005432693173	1196	Economy	38300.00
0005432873247	1196	Economy	38300.00
0005432873213	1196	Economy	38300.00
0005432693164	1196	Economy	38300.00
0005432873219	1196	Economy	38300.00
0005432675196	1196	Economy	38300.00
0005432693187	1196	Economy	38300.00
0005432873214	1196	Economy	38300.00
0005432675189	1196	Economy	38300.00
0005432693159	1196	Economy	38300.00
0005432693168	1196	Economy	38300.00
0005432675202	1196	Economy	38300.00
0005432693174	1196	Economy	38300.00
0005432677586	1196	Economy	38300.00
0005432873255	1196	Economy	38300.00
0005432873248	1196	Economy	38300.00
0005432693177	1196	Economy	38300.00
0005432675190	1196	Economy	38300.00
0005432873249	1196	Economy	38300.00
0005432675198	1196	Economy	38300.00
0005432693179	1196	Economy	38300.00
0005432693172	1196	Economy	38300.00
0005432693178	1196	Economy	38300.00
0005432675104	17485	Business	115000.00
0005432692861	17485	Business	115000.00
0005432692871	17485	Business	115000.00
0005432692903	17485	Business	115000.00
0005432692954	17485	Business	115000.00
0005432692928	17485	Business	115000.00
0005432692798	17485	Business	115000.00
0005432675075	17485	Business	115000.00
0005432675046	17485	Business	115000.00
0005432693021	17485	Business	115000.00
0005432692955	17485	Economy	38300.00
0005432873325	17485	Economy	38300.00
0005432675097	17485	Economy	38300.00
0005432675074	17485	Economy	38300.00
0005432873323	17485	Economy	38300.00
0005432873322	17485	Economy	42200.00
0005432677545	17485	Economy	42200.00
0005432692939	17485	Economy	42200.00
0005432675123	17485	Economy	38300.00
0005432675076	17485	Economy	38300.00
0005432692918	17485	Economy	38300.00
0005432692927	17485	Economy	38300.00
0005432675052	17485	Economy	38300.00
0005432675087	17485	Economy	38300.00
0005432692766	17485	Economy	38300.00
0005432692910	17485	Economy	38300.00
0005432677550	17485	Economy	38300.00
0005432692940	17485	Economy	38300.00
0005432692895	17485	Economy	38300.00
0005432692797	17485	Economy	38300.00
0005432692883	17485	Economy	38300.00
0005432873320	17485	Economy	38300.00
0005432675061	17485	Economy	38300.00
0005432692938	17485	Economy	38300.00
0005432675032	17485	Economy	38300.00
0005432693061	17485	Economy	38300.00
0005432675045	17485	Economy	38300.00
0005432693003	17485	Economy	38300.00
0005432692866	17485	Economy	38300.00
0005432677551	17485	Economy	38300.00
0005432873324	17485	Economy	38300.00
0005432873321	17485	Economy	38300.00
0005432873319	17485	Economy	38300.00
0005432675031	17485	Economy	38300.00
0005432692830	17485	Economy	38300.00
0005432692831	17485	Economy	38300.00
0005432692924	17485	Economy	38300.00
0005432692997	17485	Economy	38300.00
0005432692846	17485	Economy	38300.00
0005432692941	17485	Economy	38300.00
0005432692865	17485	Economy	38300.00
0005432675106	17485	Economy	38300.00
0005432692867	17485	Economy	38300.00
0005432675055	17485	Economy	38300.00
0005432692860	17485	Economy	38300.00
0005432692712	17485	Economy	38300.00
0005432675090	17485	Economy	38300.00
0005432692870	17485	Economy	38300.00
0005432675089	17485	Economy	38300.00
0005432692859	17485	Economy	38300.00
0005432692822	17485	Economy	38300.00
0005432675103	17485	Economy	38300.00
0005432692926	17485	Economy	38300.00
0005432692832	17485	Economy	38300.00
0005433156718	1124	Economy	15200.00
0005434435245	1124	Economy	13900.00
0005433156717	1124	Economy	13900.00
0005434435250	1124	Economy	13900.00
0005434435255	1124	Economy	13900.00
0005433156736	1124	Economy	13900.00
0005434435249	1124	Economy	13900.00
0005434435248	1124	Economy	13900.00
0005433156716	1124	Economy	13900.00
0005433156705	1124	Economy	13900.00
0005433156704	1124	Economy	13900.00
0005433156708	1124	Economy	13900.00
0005434435242	1124	Economy	13900.00
0005434435241	1124	Economy	13900.00
0005433156719	1124	Economy	13900.00
0005434435247	1124	Economy	13900.00
0005434435246	1124	Economy	13900.00
0005434435254	1124	Economy	13900.00
0005434435240	1124	Economy	13900.00
0005434435251	1124	Economy	13900.00
0005434435243	1124	Economy	13900.00
0005434435253	1124	Economy	13900.00
0005434435252	1124	Economy	13900.00
0005433156715	1124	Economy	13900.00
0005434435244	1124	Economy	13900.00
0005434435066	17306	Economy	15200.00
0005434435061	17306	Economy	15200.00
0005434435114	17306	Economy	13900.00
0005433156784	17306	Economy	13900.00
0005433156788	17306	Economy	13900.00
0005434435172	17306	Economy	13900.00
0005433156787	17306	Economy	13900.00
0005434435171	17306	Economy	13900.00
0005433156790	17306	Economy	13900.00
0005433156789	17306	Economy	13900.00
0005433156785	17306	Economy	13900.00
0005433156783	17306	Economy	13900.00
0005434435136	17306	Economy	13900.00
0005434435060	17306	Economy	13900.00
0005434435080	17306	Economy	13900.00
0005434435074	17306	Economy	13900.00
0005434435115	17306	Economy	13900.00
0005434435138	17306	Economy	13900.00
0005434435168	17306	Economy	13900.00
0005434435078	17306	Economy	13900.00
0005434435139	17306	Economy	13900.00
0005433156786	17306	Economy	13900.00
0005435928119	4075	Economy	7500.00
0005435086870	4075	Economy	7500.00
0005435928101	4075	Economy	7500.00
0005435928136	4075	Economy	7500.00
0005435086868	4075	Economy	7500.00
0005435086865	4075	Economy	7500.00
0005435086866	4075	Economy	7500.00
0005435928132	4075	Economy	7500.00
0005435086869	4075	Economy	7500.00
0005435086863	4075	Economy	7500.00
0005435928133	4075	Economy	7500.00
0005435086867	4075	Economy	7500.00
0005435086864	4075	Economy	7500.00
0005435928134	4075	Economy	7500.00
0005435086775	24433	Economy	8200.00
0005435928164	24433	Economy	8200.00
0005435928165	24433	Economy	7500.00
0005435928163	24433	Economy	7500.00
0005435086804	24433	Economy	7500.00
0005435928161	24433	Economy	7500.00
0005435928162	24433	Economy	7500.00
0005435086784	24433	Economy	7500.00
0005435086794	24433	Economy	7500.00
0005435086801	24433	Economy	7500.00
0005435086795	24433	Economy	7500.00
0005435551611	17009	Business	144300.00
0005435551615	17009	Business	144300.00
0005435551604	17009	Business	144300.00
0005435551603	17009	Business	144300.00
0005435098561	17009	Economy	52900.00
0005435098568	17009	Economy	48100.00
0005435098564	17009	Economy	48100.00
0005435551619	17009	Economy	48100.00
0005435098562	17009	Economy	48100.00
0005435551607	17009	Economy	48100.00
0005435098565	17009	Economy	48100.00
0005435551601	17009	Economy	48100.00
0005435551618	17009	Economy	48100.00
0005435551620	17009	Economy	48100.00
0005435551605	17009	Economy	48100.00
0005435551613	17009	Economy	48100.00
0005435551612	17009	Economy	48100.00
0005435551617	17009	Economy	48100.00
0005435551609	17009	Economy	48100.00
0005435551598	17009	Economy	48100.00
0005435098563	17009	Economy	48100.00
0005435551610	17009	Economy	48100.00
0005435098567	17009	Economy	52900.00
0005435551614	17009	Economy	48100.00
0005435098566	17009	Economy	48100.00
0005435551621	17009	Economy	48100.00
0005435551602	17009	Economy	48100.00
0005435098569	17009	Economy	48100.00
0005435551616	17009	Economy	48100.00
0005435551606	17009	Economy	48100.00
0005435551600	17009	Economy	48100.00
0005435551608	17009	Economy	48100.00
0005435551599	17009	Economy	48100.00
0005434626002	4868	Economy	16200.00
0005434626004	4868	Economy	16200.00
0005435907469	4868	Economy	14700.00
0005434626000	4868	Economy	14700.00
0005434626003	4868	Economy	14700.00
0005435907508	4868	Economy	14700.00
0005434625999	4868	Economy	14700.00
0005434625997	4868	Economy	14700.00
0005434626006	4868	Economy	14700.00
0005434625998	4868	Economy	14700.00
0005433194839	4868	Economy	14700.00
0005433194837	4868	Economy	14700.00
0005434626005	4868	Economy	14700.00
0005433194840	4868	Economy	14700.00
0005434626001	4868	Economy	14700.00
0005435907482	4868	Economy	14700.00
0005435907525	32933	Business	44200.00
0005434625963	32933	Business	44200.00
0005435907522	32933	Economy	14700.00
0005434625964	32933	Economy	16200.00
0005434625946	32933	Economy	14700.00
0005434625930	32933	Economy	14700.00
0005434625954	32933	Economy	14700.00
0005435907523	32933	Economy	14700.00
0005434625931	32933	Economy	14700.00
0005434625953	32933	Economy	14700.00
0005434625952	32933	Economy	14700.00
0005434625974	32933	Economy	14700.00
0005434625923	32933	Economy	14700.00
0005435907524	32933	Economy	14700.00
0005434625933	32933	Economy	14700.00
0005434625975	32933	Economy	14700.00
0005435785304	13766	Economy	3400.00
0005432195702	13766	Economy	3400.00
0005435785142	13766	Economy	3400.00
0005435785303	13766	Economy	3400.00
0005435785313	13766	Economy	3100.00
0005435785157	13766	Economy	3100.00
0005435785094	13766	Economy	3100.00
0005435785120	13766	Economy	3100.00
0005435785125	13766	Economy	3100.00
0005435785212	13766	Economy	3100.00
0005435785279	13766	Economy	3100.00
0005435785278	13766	Economy	3100.00
0005435785087	13766	Economy	3100.00
0005435785312	13766	Economy	3100.00
0005435785215	13766	Economy	3100.00
0005435785238	13766	Economy	3100.00
0005435785093	13766	Economy	3100.00
0005435785061	13766	Economy	3100.00
0005435785024	13766	Economy	3100.00
0005435785214	13766	Economy	3100.00
0005435785134	13766	Economy	3100.00
0005435785148	13766	Economy	3100.00
0005432195701	13766	Economy	3100.00
0005435785302	13766	Economy	3100.00
0005435785195	13766	Economy	3100.00
0005435785253	13766	Economy	3100.00
0005435785116	13766	Economy	3100.00
0005435787334	13766	Economy	3100.00
0005435785104	13766	Economy	3100.00
0005435787342	13766	Economy	3100.00
0005435785213	13766	Economy	3100.00
0005432195703	13766	Economy	3100.00
0005435785239	13766	Economy	3100.00
0005435784892	13766	Economy	3100.00
0005435785217	13766	Economy	3100.00
0005435785124	13766	Economy	3100.00
0005435785012	13766	Economy	3100.00
0005435785076	13766	Economy	3100.00
0005435785117	13766	Economy	3100.00
0005435785025	13766	Economy	3100.00
0005435785103	13766	Economy	3100.00
0005435785083	13766	Economy	3100.00
0005435785156	13766	Economy	3100.00
0005435785043	13766	Economy	3100.00
0005435785066	13766	Economy	3100.00
0005435785088	13766	Economy	3100.00
0005435785158	13766	Economy	3100.00
0005435785044	13766	Economy	3100.00
0005435785221	13766	Economy	3100.00
0005435785222	13766	Economy	3100.00
0005435785462	27412	Economy	3400.00
0005435785468	27412	Economy	3400.00
0005435785440	27412	Economy	3400.00
0005432190640	27412	Economy	3400.00
0005435785452	27412	Economy	3100.00
0005435785446	27412	Economy	3100.00
0005435785464	27412	Economy	3100.00
0005432190639	27412	Economy	3100.00
0005435785445	27412	Economy	3100.00
0005435785437	27412	Economy	3100.00
0005435785439	27412	Economy	3100.00
0005435937359	27412	Economy	3100.00
0005435787360	27412	Economy	3100.00
0005435937357	27412	Economy	3100.00
0005435937353	27412	Economy	3100.00
0005435785456	27412	Economy	3100.00
0005432190641	27412	Economy	3100.00
0005435937346	27412	Economy	3100.00
0005435785455	27412	Economy	3100.00
0005435785457	27412	Economy	3100.00
0005435785447	27412	Economy	3100.00
0005435785466	27412	Economy	3100.00
0005435785459	27412	Economy	3100.00
0005435785460	27412	Economy	3100.00
0005435785443	27412	Economy	3100.00
0005435937351	27412	Economy	3100.00
0005435785470	27412	Economy	3100.00
0005435785449	27412	Economy	3100.00
0005435937363	27412	Economy	3100.00
0005435785454	27412	Economy	3100.00
0005435785463	27412	Economy	3100.00
0005435785438	27412	Economy	3100.00
0005435785465	27412	Economy	3100.00
0005435785448	27412	Economy	3100.00
0005435785442	27412	Economy	3100.00
0005435937362	27412	Economy	3100.00
0005435785467	27412	Economy	3100.00
0005435785461	27412	Economy	3100.00
0005435785444	27412	Economy	3100.00
0005435785469	27412	Economy	3100.00
0005435785450	27412	Economy	3100.00
0005435785458	27412	Economy	3100.00
0005435785441	27412	Economy	3100.00
0005435785453	27412	Economy	3100.00
0005435785451	27412	Economy	3100.00
0005434407582	20268	Business	12000.00
0005434407521	20268	Business	12000.00
0005435311110	20268	Business	12000.00
0005434407554	20268	Business	12000.00
0005435311112	20268	Business	12000.00
0005434407364	20268	Business	12000.00
0005434407263	20268	Business	12000.00
0005434407493	20268	Business	12000.00
0005434407455	20268	Business	12000.00
0005434407598	20268	Business	12000.00
0005434407498	20268	Business	12000.00
0005434407546	20268	Business	12000.00
0005434407355	20268	Economy	4000.00
0005434407360	20268	Economy	4000.00
0005434407335	20268	Economy	4000.00
0005434407357	20268	Economy	4000.00
0005434407519	20268	Economy	4000.00
0005434407462	20268	Economy	4000.00
0005434407484	20268	Economy	4400.00
0005435311109	20268	Economy	4400.00
0005434407560	20268	Economy	4400.00
0005435311107	20268	Economy	4400.00
0005434407726	20268	Economy	4000.00
0005434407250	20268	Economy	4000.00
0005435311111	20268	Economy	4000.00
0005434407473	20268	Economy	4000.00
0005434407652	20268	Economy	4000.00
0005434407416	20268	Economy	4000.00
0005434407668	20268	Economy	4000.00
0005434407667	20268	Economy	4000.00
0005434407590	20268	Economy	4000.00
0005435311108	20268	Economy	4000.00
0005434407502	20268	Economy	4000.00
0005434407512	20268	Economy	4000.00
0005434407241	20268	Economy	4000.00
0005434407491	20268	Economy	4000.00
0005434407345	20268	Economy	4000.00
0005434407503	20268	Economy	4000.00
0005434407381	20268	Economy	4000.00
0005435311106	20268	Economy	4000.00
0005434407518	20268	Economy	4000.00
0005434407603	20268	Economy	4000.00
0005434407504	20268	Economy	4000.00
0005434407265	20268	Economy	4000.00
0005435311105	20268	Economy	4000.00
0005434407488	20268	Economy	4000.00
0005432058398	20268	Economy	4000.00
0005434407259	20268	Economy	4000.00
0005434407513	20268	Economy	4000.00
0005434407551	20268	Economy	4000.00
0005434407604	20268	Economy	4000.00
0005435311113	20268	Economy	4000.00
0005434407350	20268	Economy	4000.00
0005434407492	20268	Economy	4000.00
0005434407592	20268	Economy	4000.00
0005434407621	20268	Economy	4000.00
0005434407501	20268	Economy	4000.00
0005434407368	20268	Economy	4000.00
0005432058399	20268	Economy	4000.00
0005435311114	20268	Economy	4000.00
0005434407358	20268	Economy	4000.00
0005434407602	20268	Economy	4000.00
0005434407193	20268	Economy	4000.00
0005434407776	20268	Economy	4000.00
0005434407533	20268	Economy	4000.00
0005434407382	20268	Economy	4000.00
0005432058401	20268	Economy	4000.00
0005434407369	20268	Economy	4000.00
0005434407445	20268	Economy	4000.00
0005434407739	20268	Economy	4000.00
0005434407417	20268	Economy	4000.00
0005434407545	20268	Economy	4000.00
0005434407264	20268	Economy	4000.00
0005434407472	20268	Economy	4000.00
0005434407591	20268	Economy	4000.00
0005432058400	20268	Economy	4000.00
0005434407361	20268	Economy	4000.00
0005434407497	20268	Economy	4000.00
0005434408047	26983	Business	12000.00
0005432153967	26983	Business	12000.00
0005434408053	26983	Business	12000.00
0005434407996	26983	Business	12000.00
0005435310984	26983	Business	12000.00
0005434408012	26983	Business	12000.00
0005435311008	26983	Business	12000.00
0005434408037	26983	Business	12000.00
0005434408019	26983	Business	12000.00
0005432153970	26983	Business	12000.00
0005434408048	26983	Business	12000.00
0005434408014	26983	Economy	4000.00
0005434408057	26983	Economy	4000.00
0005435311006	26983	Economy	4000.00
0005434408043	26983	Economy	4000.00
0005434408005	26983	Economy	4000.00
0005434408023	26983	Economy	4000.00
0005435310996	26983	Economy	4000.00
0005434408054	26983	Economy	4000.00
0005435310985	26983	Economy	4000.00
0005434408046	26983	Economy	4000.00
0005434408002	26983	Economy	4400.00
0005434408022	26983	Economy	4400.00
0005435311021	26983	Economy	4400.00
0005434408038	26983	Economy	4400.00
0005434407995	26983	Economy	4400.00
0005434408025	26983	Economy	4000.00
0005434408016	26983	Economy	4000.00
0005434408044	26983	Economy	4000.00
0005434408013	26983	Economy	4000.00
0005432153968	26983	Economy	4000.00
0005434408049	26983	Economy	4000.00
0005435311004	26983	Economy	4000.00
0005434408036	26983	Economy	4000.00
0005434408024	26983	Economy	4000.00
0005435310990	26983	Economy	4000.00
0005434408008	26983	Economy	4000.00
0005434408009	26983	Economy	4000.00
0005434408026	26983	Economy	4000.00
0005434408032	26983	Economy	4000.00
0005432153966	26983	Economy	4000.00
0005434408041	26983	Economy	4000.00
0005434407999	26983	Economy	4000.00
0005434408051	26983	Economy	4000.00
0005434408011	26983	Economy	4000.00
0005434408052	26983	Economy	4000.00
0005434408045	26983	Economy	4000.00
0005434408018	26983	Economy	4000.00
0005434408020	26983	Economy	4000.00
0005434408007	26983	Economy	4000.00
0005434408028	26983	Economy	4000.00
0005432153969	26983	Economy	4000.00
0005435311023	26983	Economy	4000.00
0005434408035	26983	Economy	4000.00
0005434408021	26983	Economy	4000.00
0005435310991	26983	Economy	4000.00
0005434408050	26983	Economy	4000.00
0005434408039	26983	Economy	4000.00
0005434407994	26983	Economy	4000.00
0005434408058	26983	Economy	4000.00
0005434408001	26983	Economy	4000.00
0005434408006	26983	Economy	4000.00
0005434408042	26983	Economy	4000.00
0005434408030	26983	Economy	4000.00
0005434408015	26983	Economy	4000.00
0005434408029	26983	Economy	4000.00
0005434408059	26983	Economy	4000.00
0005432153965	26983	Economy	4000.00
0005434408033	26983	Economy	4000.00
0005435310989	26983	Economy	4000.00
0005434408004	26983	Economy	4000.00
0005435310999	26983	Economy	4000.00
0005434408003	26983	Economy	4000.00
0005434408000	26983	Economy	4000.00
0005434408056	26983	Economy	4000.00
0005432153964	26983	Economy	4000.00
0005435311020	26983	Economy	4000.00
0005434408017	26983	Economy	4000.00
0005435310960	26983	Economy	4000.00
0005435311001	26983	Economy	4000.00
0005434408040	26983	Economy	4000.00
0005435311002	26983	Economy	4000.00
0005434408027	26983	Economy	4000.00
0005434407998	26983	Economy	4000.00
0005434408010	26983	Economy	4000.00
0005434407997	26983	Economy	4000.00
0005434408055	26983	Economy	4000.00
0005434408031	26983	Economy	4000.00
0005434408034	26983	Economy	4000.00
0005434319461	5714	Business	43300.00
0005434319459	5714	Business	43300.00
0005434319446	5714	Economy	14400.00
0005434319465	5714	Economy	14400.00
0005433123801	5714	Economy	14400.00
0005432109717	5714	Economy	15900.00
0005433123781	5714	Economy	15900.00
0005433123894	5714	Economy	15900.00
0005434319462	5714	Economy	14400.00
0005432109716	5714	Economy	14400.00
0005434319449	5714	Economy	14400.00
0005434319455	5714	Economy	14400.00
0005434319463	5714	Economy	14400.00
0005434319464	5714	Economy	14400.00
0005433123782	5714	Economy	14400.00
0005433123776	5714	Economy	14400.00
0005434319468	5714	Economy	14400.00
0005434319453	5714	Economy	14400.00
0005433123874	5714	Economy	14400.00
0005434319456	5714	Economy	14400.00
0005433123886	5714	Economy	14400.00
0005433123847	5714	Economy	14400.00
0005433123774	5714	Economy	14400.00
0005433123834	5714	Economy	14400.00
0005433123846	5714	Economy	14400.00
0005434319452	5714	Economy	14400.00
0005434319448	5714	Economy	14400.00
0005433123828	5714	Economy	14400.00
0005434319467	5714	Economy	14400.00
0005434319457	5714	Economy	14400.00
0005433123802	5714	Economy	14400.00
0005434319458	5714	Economy	14400.00
0005433123845	5714	Economy	14400.00
0005434319447	5714	Economy	14400.00
0005434319466	5714	Economy	14400.00
0005433123863	5714	Economy	14400.00
0005434319460	5714	Economy	14400.00
0005434319451	5714	Economy	14400.00
0005434319450	5714	Economy	14400.00
0005434319454	5714	Economy	14400.00
0005433123873	5714	Economy	14400.00
0005433123868	5714	Economy	14400.00
0005433124025	15707	Business	43300.00
0005434319358	15707	Economy	14400.00
0005433124018	15707	Economy	14400.00
0005434319296	15707	Economy	14400.00
0005433124015	15707	Economy	14400.00
0005433124014	15707	Economy	14400.00
0005433124024	15707	Economy	14400.00
0005434319301	15707	Economy	14400.00
0005433124019	15707	Economy	14400.00
0005434319312	15707	Economy	14400.00
0005434319300	15707	Economy	14400.00
0005433124017	15707	Economy	14400.00
0005434319357	15707	Economy	14400.00
0005434319381	15707	Economy	14400.00
0005433124021	15707	Economy	14400.00
0005434312316	15707	Economy	14400.00
0005433124023	15707	Economy	14400.00
0005434319290	15707	Economy	14400.00
0005433124022	15707	Economy	14400.00
0005434319308	15707	Economy	14400.00
0005434319317	15707	Economy	14400.00
0005433124020	15707	Economy	14400.00
0005434319295	15707	Economy	14400.00
0005433124016	15707	Economy	14400.00
0005433124026	15707	Economy	14400.00
0005435220324	31743	Economy	17100.00
0005435220327	31743	Economy	15500.00
0005435220325	31743	Economy	15500.00
0005435219211	31743	Economy	15500.00
0005435220330	31743	Economy	15500.00
0005435219209	31743	Economy	15500.00
0005435220328	31743	Economy	15500.00
0005435219207	31743	Economy	15500.00
0005435219205	31743	Economy	15500.00
0005435219210	31743	Economy	15500.00
0005435219206	31743	Economy	15500.00
0005435220326	31743	Economy	15500.00
0005435219208	31743	Economy	15500.00
0005435220329	31743	Economy	15500.00
0005435220491	31743	Economy	15500.00
0005434189145	8988	Economy	27400.00
0005434484376	8988	Economy	24900.00
0005434484373	8988	Economy	24900.00
0005434484378	8988	Economy	24900.00
0005434189144	8988	Economy	24900.00
0005434484374	8988	Economy	24900.00
0005434484379	8988	Economy	24900.00
0005434189150	8988	Economy	24900.00
0005434484377	8988	Economy	24900.00
0005434189151	8988	Economy	24900.00
0005434484375	8988	Economy	24900.00
0005434484289	16657	Economy	24900.00
0005434189205	16657	Economy	24900.00
0005434189202	16657	Economy	24900.00
0005434484343	16657	Economy	24900.00
0005434189203	16657	Economy	24900.00
0005434189201	16657	Economy	24900.00
0005434189200	16657	Economy	24900.00
0005434189206	16657	Economy	24900.00
0005434484329	16657	Economy	24900.00
0005434484288	16657	Economy	24900.00
0005434484334	16657	Economy	24900.00
0005434189204	16657	Economy	24900.00
0005433124021	7596	Business	11100.00
0005433124018	7596	Business	11100.00
0005433124014	7596	Business	11100.00
0005433124020	7596	Economy	3700.00
0005433124024	7596	Economy	3700.00
0005433124016	7596	Economy	3700.00
0005433124026	7596	Economy	3700.00
0005433124015	7596	Economy	3700.00
0005433722170	7596	Economy	3700.00
0005433124017	7596	Economy	3700.00
0005433124023	7596	Economy	3700.00
0005433124022	7596	Economy	3700.00
0005433124019	7596	Economy	3700.00
0005433124025	7596	Economy	3700.00
0005432693215	7595	Business	11100.00
0005432693200	7595	Business	11100.00
0005432693221	7595	Business	11100.00
0005433450060	7595	Business	11100.00
0005432721025	7595	Business	11100.00
0005432721032	7595	Business	11100.00
0005432693216	7595	Business	11100.00
0005432721029	7595	Business	11100.00
0005433450066	7595	Business	11100.00
0005432721007	7595	Business	11100.00
0005432693190	7595	Business	11100.00
0005432721010	7595	Business	11100.00
0005432721008	7595	Economy	3700.00
0005432693214	7595	Economy	3700.00
0005432693213	7595	Economy	3700.00
0005432721028	7595	Economy	3700.00
0005433450071	7595	Economy	3700.00
0005432721030	7595	Economy	3700.00
0005432693192	7595	Economy	3700.00
0005432721013	7595	Economy	3700.00
0005433450065	7595	Economy	3700.00
0005433450064	7595	Economy	3700.00
0005432071587	7595	Economy	4100.00
0005432693207	7595	Economy	4100.00
0005432693205	7595	Economy	4100.00
0005432693198	7595	Economy	4100.00
0005432693219	7595	Economy	4100.00
0005433450073	7595	Economy	3700.00
0005432721023	7595	Economy	3700.00
0005432693208	7595	Economy	3700.00
0005432721031	7595	Economy	3700.00
0005433450068	7595	Economy	3700.00
0005432693220	7595	Economy	3700.00
0005432693191	7595	Economy	3700.00
0005432721011	7595	Economy	3700.00
0005432693199	7595	Economy	3700.00
0005432693211	7595	Economy	3700.00
0005432693210	7595	Economy	3700.00
0005432721022	7595	Economy	3700.00
0005432693195	7595	Economy	3700.00
0005432693197	7595	Economy	3700.00
0005433450053	7595	Economy	3700.00
0005433450072	7595	Economy	3700.00
0005433450069	7595	Economy	3700.00
0005433450056	7595	Economy	3700.00
0005432693222	7595	Economy	3700.00
0005433450061	7595	Economy	3700.00
0005432721018	7595	Economy	3700.00
0005432721027	7595	Economy	3700.00
0005432693202	7595	Economy	3700.00
0005432693203	7595	Economy	3700.00
0005433450067	7595	Economy	3700.00
0005432721017	7595	Economy	3700.00
0005432693201	7595	Economy	3700.00
0005432721016	7595	Economy	3700.00
0005433450054	7595	Economy	3700.00
0005433450052	7595	Economy	3700.00
0005432721006	7595	Economy	3700.00
0005432693212	7595	Economy	3700.00
0005433450055	7595	Economy	3700.00
0005432721026	7595	Economy	3700.00
0005432071586	7595	Economy	3700.00
0005433450063	7595	Economy	3700.00
0005432721012	7595	Economy	3700.00
0005433450059	7595	Economy	3700.00
0005433450062	7595	Economy	3700.00
0005433450070	7595	Economy	3700.00
0005432693204	7595	Economy	3700.00
0005432693217	7595	Economy	3700.00
0005432721009	7595	Economy	3700.00
0005432693194	7595	Economy	3700.00
0005432721024	7595	Economy	3700.00
0005432693209	7595	Economy	3700.00
0005432693196	7595	Economy	3700.00
0005432721021	7595	Economy	3700.00
0005432721014	7595	Economy	3700.00
0005432071585	7595	Economy	3700.00
0005432693206	7595	Economy	3700.00
0005432721020	7595	Economy	3700.00
0005432693193	7595	Economy	3700.00
0005432721015	7595	Economy	3700.00
0005432721019	7595	Economy	3700.00
0005433450058	7595	Economy	3700.00
0005433450057	7595	Economy	3700.00
0005432693218	7595	Economy	3700.00
0005432692895	30272	Business	11100.00
0005432693061	30272	Business	11100.00
0005432692870	30272	Business	11100.00
0005432692867	30272	Business	11100.00
0005433449798	30272	Business	11100.00
0005432692926	30272	Business	11100.00
0005432692954	30272	Business	11100.00
0005432692941	30272	Business	11100.00
0005432692955	30272	Economy	3700.00
0005433449827	30272	Economy	3700.00
0005432693003	30272	Economy	3700.00
0005432692938	30272	Economy	3700.00
0005432692798	30272	Economy	3700.00
0005432692846	30272	Economy	3700.00
0005432692822	30272	Economy	4100.00
0005432692928	30272	Economy	4100.00
0005432692866	30272	Economy	4100.00
0005432692910	30272	Economy	3700.00
0005432692918	30272	Economy	3700.00
0005432692712	30272	Economy	3700.00
0005433449788	30272	Economy	3700.00
0005433450006	30272	Economy	3700.00
0005433449914	30272	Economy	3700.00
0005432692903	30272	Economy	3700.00
0005432692797	30272	Economy	3700.00
0005432692927	30272	Economy	3700.00
0005432692924	30272	Economy	3700.00
0005432692997	30272	Economy	3700.00
0005433450007	30272	Economy	3700.00
0005433449881	30272	Economy	3700.00
0005432692871	30272	Economy	3700.00
0005433449864	30272	Economy	3700.00
0005432692861	30272	Economy	3700.00
0005433449879	30272	Economy	3700.00
0005432692831	30272	Economy	3700.00
0005433449847	30272	Economy	3700.00
0005432692940	30272	Economy	3700.00
0005433449762	30272	Economy	3700.00
0005432693021	30272	Economy	3700.00
0005433449876	30272	Economy	3700.00
0005433449942	30272	Economy	3700.00
0005432692830	30272	Economy	3700.00
0005432692860	30272	Economy	3700.00
0005432692859	30272	Economy	3700.00
0005432692883	30272	Economy	3700.00
0005433449938	30272	Economy	3700.00
0005432692766	30272	Economy	3700.00
0005432692832	30272	Economy	3700.00
0005433449885	30272	Economy	3700.00
0005433449870	30272	Economy	3700.00
0005432692939	30272	Economy	3700.00
0005432692865	30272	Economy	3700.00
0005433123774	30271	Business	11100.00
0005432720867	30271	Business	11100.00
0005432720773	30271	Business	11100.00
0005433123782	30271	Business	11100.00
0005433123847	30271	Business	11100.00
0005432720756	30271	Business	11100.00
0005433722249	30271	Business	11100.00
0005432720772	30271	Economy	3700.00
0005433123868	30271	Economy	3700.00
0005432720852	30271	Economy	3700.00
0005432720736	30271	Economy	4100.00
0005433722252	30271	Economy	4100.00
0005433123863	30271	Economy	4100.00
0005433123802	30271	Economy	3700.00
0005433123845	30271	Economy	3700.00
0005433722250	30271	Economy	3700.00
0005432720827	30271	Economy	3700.00
0005433123801	30271	Economy	3700.00
0005432720925	30271	Economy	3700.00
0005433722251	30271	Economy	3700.00
0005433123781	30271	Economy	3700.00
0005432720742	30271	Economy	3700.00
0005432720942	30271	Economy	3700.00
0005433123894	30271	Economy	3700.00
0005432720807	30271	Economy	3700.00
0005432720774	30271	Economy	3700.00
0005432720941	30271	Economy	3700.00
0005433722247	30271	Economy	3700.00
0005432720808	30271	Economy	3700.00
0005433123834	30271	Economy	3700.00
0005432720790	30271	Economy	3700.00
0005432720832	30271	Economy	3700.00
0005432720705	30271	Economy	3700.00
0005433123846	30271	Economy	3700.00
0005432720745	30271	Economy	3700.00
0005433722253	30271	Economy	3700.00
0005433123828	30271	Economy	3700.00
0005432720740	30271	Economy	3700.00
0005433123874	30271	Economy	3700.00
0005432720812	30271	Economy	3700.00
0005432720875	30271	Economy	3700.00
0005432720775	30271	Economy	3700.00
0005432720640	30271	Economy	3700.00
0005432720744	30271	Economy	3700.00
0005432720804	30271	Economy	3700.00
0005432720741	30271	Economy	3700.00
0005433123776	30271	Economy	3700.00
0005433123886	30271	Economy	3700.00
0005433123873	30271	Economy	3700.00
0005432720788	30271	Economy	3700.00
0005432720821	30271	Economy	3700.00
0005433722248	30271	Economy	3700.00
0005432720771	30271	Economy	3700.00
0005432720682	30271	Economy	3700.00
0005432720813	30271	Economy	3700.00
0005432720853	30271	Economy	3700.00
0005433722246	30271	Economy	3700.00
0005432720757	30271	Economy	3700.00
0005432720659	30271	Economy	3700.00
0005432720940	30271	Economy	3700.00
0005432720760	30271	Economy	3700.00
0005432927966	1406	Business	70400.00
0005434586733	1406	Business	70400.00
0005433193010	1406	Business	70400.00
0005434586734	1406	Business	70400.00
0005433525087	1406	Business	70400.00
0005434586716	1406	Business	70400.00
0005433525081	1406	Business	70400.00
0005434514978	1406	Business	70400.00
0005434514979	1406	Business	70400.00
0005432271018	1406	Business	70400.00
0005433193015	1406	Economy	23500.00
0005434586723	1406	Economy	23500.00
0005434586712	1406	Economy	23500.00
0005434586725	1406	Economy	23500.00
0005434586715	1406	Economy	23500.00
0005432927970	1406	Economy	23500.00
0005433192965	1406	Economy	23500.00
0005434586735	1406	Economy	23500.00
0005433724825	1406	Economy	23500.00
0005432927967	1406	Economy	25800.00
0005433525091	1406	Economy	25800.00
0005433193019	1406	Economy	25800.00
0005434586711	1406	Economy	25800.00
0005434586728	1406	Economy	23500.00
0005434586720	1406	Economy	23500.00
0005434586718	1406	Economy	23500.00
0005434586722	1406	Economy	23500.00
0005434586709	1406	Economy	23500.00
0005433525086	1406	Economy	23500.00
0005432271017	1406	Economy	23500.00
0005433192994	1406	Economy	23500.00
0005434586719	1406	Economy	23500.00
0005434586732	1406	Economy	23500.00
0005433525084	1406	Economy	23500.00
0005434586721	1406	Economy	23500.00
0005433193020	1406	Economy	23500.00
0005432271016	1406	Economy	23500.00
0005432927971	1406	Economy	23500.00
0005433193052	1406	Economy	23500.00
0005434586710	1406	Economy	23500.00
0005432968838	1406	Economy	23500.00
0005434586713	1406	Economy	23500.00
0005434586724	1406	Economy	23500.00
0005433724822	1406	Economy	23500.00
0005433193030	1406	Economy	23500.00
0005433525085	1406	Economy	23500.00
0005433192991	1406	Economy	23500.00
0005433525090	1406	Economy	23500.00
0005433525083	1406	Economy	23500.00
0005433193024	1406	Economy	23500.00
0005434586714	1406	Economy	23500.00
0005433525080	1406	Economy	23500.00
0005433525088	1406	Economy	23500.00
0005434586717	1406	Economy	23500.00
0005434586726	1406	Economy	23500.00
0005433724824	1406	Economy	23500.00
0005433525089	1406	Economy	23500.00
0005432927942	1406	Economy	23500.00
0005433193014	1406	Economy	23500.00
0005434586731	1406	Economy	23500.00
0005433193009	1406	Economy	23500.00
0005432271015	1406	Economy	23500.00
0005433193053	1406	Economy	23500.00
0005433525092	1406	Economy	23500.00
0005433525082	1406	Economy	23500.00
0005434586727	1406	Economy	23500.00
0005432927943	1406	Economy	23500.00
0005433724823	1406	Economy	23500.00
0005433192996	1406	Economy	23500.00
0005433192979	1406	Economy	23500.00
0005434586729	1406	Economy	23500.00
0005434586730	1406	Economy	23500.00
0005432927941	1406	Economy	23500.00
0005434586487	18502	Business	70400.00
0005434586513	18502	Business	70400.00
0005434586382	18502	Business	70400.00
0005432928000	18502	Business	70400.00
0005434586416	18502	Business	70400.00
0005433193108	18502	Business	70400.00
0005433193098	18502	Business	70400.00
0005433724779	18502	Business	70400.00
0005434586481	18502	Business	70400.00
0005434586405	18502	Economy	23500.00
0005432928003	18502	Economy	23500.00
0005434586540	18502	Economy	23500.00
0005433193105	18502	Economy	23500.00
0005433193100	18502	Economy	23500.00
0005433524971	18502	Economy	23500.00
0005434586496	18502	Economy	23500.00
0005432968849	18502	Economy	23500.00
0005433524982	18502	Economy	23500.00
0005434586381	18502	Economy	25800.00
0005434586615	18502	Economy	25800.00
0005432928006	18502	Economy	25800.00
0005434586538	18502	Economy	25800.00
0005433193101	18502	Economy	23500.00
0005434586597	18502	Economy	23500.00
0005433525032	18502	Economy	23500.00
0005434514945	18502	Economy	23500.00
0005434586570	18502	Economy	23500.00
0005434586561	18502	Economy	23500.00
0005433193106	18502	Economy	23500.00
0005434586380	18502	Economy	23500.00
0005434586520	18502	Economy	23500.00
0005433524983	18502	Economy	23500.00
0005433193099	18502	Economy	23500.00
0005432928002	18502	Economy	23500.00
0005433524984	18502	Economy	23500.00
0005433524969	18502	Economy	23500.00
0005434586455	18502	Economy	23500.00
0005434586551	18502	Economy	23500.00
0005432928004	18502	Economy	23500.00
0005434586575	18502	Economy	23500.00
0005434586459	18502	Economy	23500.00
0005433193096	18502	Economy	23500.00
0005433524998	18502	Economy	23500.00
0005434586586	18502	Economy	23500.00
0005433193104	18502	Economy	23500.00
0005434586486	18502	Economy	23500.00
0005433724791	18502	Economy	23500.00
0005434586536	18502	Economy	23500.00
0005433193102	18502	Economy	23500.00
0005434586395	18502	Economy	23500.00
0005433193097	18502	Economy	23500.00
0005433524989	18502	Economy	23500.00
0005433724780	18502	Economy	23500.00
0005432968848	18502	Economy	23500.00
0005433724795	18502	Economy	23500.00
0005433193103	18502	Economy	23500.00
0005432928001	18502	Economy	23500.00
0005434586576	18502	Economy	23500.00
0005433525016	18502	Economy	23500.00
0005432968850	18502	Economy	23500.00
0005433524981	18502	Economy	23500.00
0005434514949	18502	Economy	23500.00
0005434586535	18502	Economy	23500.00
0005434586640	18502	Economy	23500.00
0005434586569	18502	Economy	23500.00
0005433524990	18502	Economy	23500.00
0005432928005	18502	Economy	23500.00
0005434586534	18502	Economy	23500.00
0005434586559	18502	Economy	23500.00
0005433193107	18502	Economy	23500.00
0005433193109	18502	Economy	23500.00
0005434586530	18502	Economy	23500.00
0005433525031	18502	Economy	23500.00
0005434586519	18502	Economy	23500.00
0005434586426	18502	Economy	23500.00
0005434586616	18502	Economy	23500.00
0005434586550	18502	Economy	23500.00
0005434344340	11450	Economy	4300.00
0005434344359	11450	Economy	4300.00
0005434344339	11450	Economy	4300.00
0005434344354	11450	Economy	4300.00
0005434142629	11450	Economy	4000.00
0005434344331	11450	Economy	4000.00
0005434344353	11450	Economy	4000.00
0005434344326	11450	Economy	4000.00
0005434344347	11450	Economy	4000.00
0005434344342	11450	Economy	4000.00
0005434344349	11450	Economy	4000.00
0005434344341	11450	Economy	4000.00
0005434344329	11450	Economy	4000.00
0005435305004	11450	Economy	4000.00
0005434344345	11450	Economy	4000.00
0005434344352	11450	Economy	4000.00
0005434344333	11450	Economy	4000.00
0005434344343	11450	Economy	4000.00
0005435305003	11450	Economy	4000.00
0005435305006	11450	Economy	4000.00
0005435305005	11450	Economy	4000.00
0005434344360	11450	Economy	4000.00
0005434344344	11450	Economy	4000.00
0005434344351	11450	Economy	4000.00
0005434344358	11450	Economy	4000.00
0005434344348	11450	Economy	4000.00
0005434344356	11450	Economy	4000.00
0005434344334	11450	Economy	4000.00
0005434344335	11450	Economy	4000.00
0005434344325	11450	Economy	4000.00
0005435302159	11450	Economy	4000.00
0005434142628	11450	Economy	4000.00
0005434142627	11450	Economy	4000.00
0005434344355	11450	Economy	4000.00
0005434344327	11450	Economy	4000.00
0005434344346	11450	Economy	4000.00
0005434344332	11450	Economy	4000.00
0005435302160	11450	Economy	4000.00
0005434344357	11450	Economy	4000.00
0005434344338	11450	Economy	4000.00
0005434344361	11450	Economy	4000.00
0005434344330	11450	Economy	4000.00
0005434344328	11450	Economy	4000.00
0005434344337	11450	Economy	4000.00
0005434344350	11450	Economy	4000.00
0005434344336	11450	Economy	4000.00
0005434142626	11450	Economy	4000.00
0005434344180	29794	Economy	4300.00
0005434344118	29794	Economy	4300.00
0005435305021	29794	Economy	4300.00
0005434344027	29794	Economy	4300.00
0005435305019	29794	Economy	4000.00
0005434344054	29794	Economy	4000.00
0005434343973	29794	Economy	4000.00
0005434343786	29794	Economy	4000.00
0005434344014	29794	Economy	4000.00
0005434344117	29794	Economy	4000.00
0005435305020	29794	Economy	4000.00
0005434343873	29794	Economy	4000.00
0005434344028	29794	Economy	4000.00
0005434344158	29794	Economy	4000.00
0005435304181	29794	Economy	4000.00
0005434344038	29794	Economy	4000.00
0005434343872	29794	Economy	4000.00
0005434344210	29794	Economy	4000.00
0005434343922	29794	Economy	4000.00
0005434343923	29794	Economy	4000.00
0005434344116	29794	Economy	4000.00
0005435304183	29794	Economy	4000.00
0005434142590	29794	Economy	4000.00
0005435304182	29794	Economy	4000.00
0005434343921	29794	Economy	4000.00
0005434344052	29794	Economy	4000.00
0005435304179	29794	Economy	4000.00
0005435305022	29794	Economy	4000.00
0005434142589	29794	Economy	4000.00
0005434344157	29794	Economy	4000.00
0005434344015	29794	Economy	4000.00
0005434344170	29794	Economy	4000.00
0005434344026	29794	Economy	4000.00
0005434343974	29794	Economy	4000.00
0005434343997	29794	Economy	4000.00
0005434344259	29794	Economy	4000.00
0005435304180	29794	Economy	4000.00
0005434344093	29794	Economy	4000.00
0005434142591	29794	Economy	4000.00
0005434344156	29794	Economy	4000.00
0005434343990	29794	Economy	4000.00
0005434343822	29794	Economy	4000.00
0005434344070	29794	Economy	4000.00
0005434344039	29794	Economy	4000.00
0005434344260	29794	Economy	4000.00
0005434343989	29794	Economy	4000.00
0005434343874	29794	Economy	4000.00
0005434344071	29794	Economy	4000.00
0005435824742	1278	Business	199800.00
0005433415528	1278	Business	199800.00
0005433415582	1278	Business	199800.00
0005433415606	1278	Business	199800.00
0005435824733	1278	Business	199800.00
0005433415627	1278	Business	199800.00
0005435824736	1278	Business	199800.00
0005435824730	1278	Business	199800.00
0005433415611	1278	Business	199800.00
0005435824741	1278	Business	199800.00
0005433415615	1278	Economy	66600.00
0005435824748	1278	Economy	66600.00
0005433415625	1278	Economy	66600.00
0005435824743	1278	Economy	66600.00
0005433415583	1278	Economy	66600.00
0005433415669	1278	Economy	66600.00
0005433415682	1278	Economy	73200.00
0005435824750	1278	Economy	66600.00
0005433415607	1278	Economy	66600.00
0005433415614	1278	Economy	66600.00
0005435824744	1278	Economy	66600.00
0005435824747	1278	Economy	66600.00
0005435824745	1278	Economy	66600.00
0005433415549	1278	Economy	66600.00
0005433415608	1278	Economy	66600.00
0005432284572	1278	Economy	66600.00
0005433415623	1278	Economy	66600.00
0005433415681	1278	Economy	66600.00
0005435824737	1278	Economy	66600.00
0005433415591	1278	Economy	66600.00
0005435824731	1278	Economy	66600.00
0005435824754	1278	Economy	66600.00
0005435824738	1278	Economy	66600.00
0005435824740	1278	Economy	66600.00
0005433415652	1278	Economy	66600.00
0005435824734	1278	Economy	66600.00
0005435824728	1278	Economy	66600.00
0005433415562	1278	Economy	66600.00
0005435824735	1278	Economy	66600.00
0005435824732	1278	Economy	66600.00
0005433415610	1278	Economy	66600.00
0005433415624	1278	Economy	66600.00
0005435824749	1278	Economy	66600.00
0005433415626	1278	Economy	66600.00
0005435824752	1278	Economy	66600.00
0005432284570	1278	Economy	66600.00
0005435824753	1278	Economy	66600.00
0005432284571	1278	Economy	66600.00
0005433415529	1278	Economy	66600.00
0005433415561	1278	Economy	66600.00
0005435824746	1278	Economy	66600.00
0005435824729	1278	Economy	66600.00
0005433415592	1278	Economy	66600.00
0005435824739	1278	Economy	66600.00
0005435824751	1278	Economy	66600.00
0005433415635	1278	Economy	66600.00
0005433415530	1278	Economy	66600.00
0005433415736	17978	Business	199800.00
0005435824489	17978	Business	199800.00
0005435824549	17978	Business	199800.00
0005433415727	17978	Business	199800.00
0005433415724	17978	Business	199800.00
0005435824520	17978	Business	199800.00
0005433415726	17978	Economy	66600.00
0005433415735	17978	Economy	66600.00
0005435824488	17978	Economy	66600.00
0005433415730	17978	Economy	66600.00
0005433415723	17978	Economy	66600.00
0005435824461	17978	Economy	66600.00
0005435824436	17978	Economy	66600.00
0005433415737	17978	Economy	66600.00
0005435824533	17978	Economy	66600.00
0005435824483	17978	Economy	66600.00
0005433415720	17978	Economy	66600.00
0005433415733	17978	Economy	66600.00
0005433415732	17978	Economy	66600.00
0005435824416	17978	Economy	66600.00
0005435824534	17978	Economy	66600.00
0005435824570	17978	Economy	66600.00
0005433415734	17978	Economy	66600.00
0005433415729	17978	Economy	66600.00
0005433415721	17978	Economy	66600.00
0005435824435	17978	Economy	66600.00
0005433415728	17978	Economy	66600.00
0005433415731	17978	Economy	66600.00
0005433415722	17978	Economy	66600.00
0005435824564	17978	Economy	66600.00
0005435824484	17978	Economy	66600.00
0005435824450	17978	Economy	66600.00
0005435824523	17978	Economy	66600.00
0005435824473	17978	Economy	66600.00
0005435824555	17978	Economy	66600.00
0005433415725	17978	Economy	66600.00
0005435824563	17978	Economy	66600.00
0005435824546	17978	Economy	66600.00
0005435824532	17978	Economy	66600.00
0005435824462	17978	Economy	66600.00
0005435824572	17978	Economy	66600.00
0005432784007	5637	Business	27800.00
0005432784045	5637	Business	27800.00
0005432784020	5637	Business	27800.00
0005432784047	5637	Business	27800.00
0005432784003	5637	Business	27800.00
0005435242737	5637	Business	27800.00
0005435242639	5637	Business	27800.00
0005435242742	5637	Business	27800.00
0005435242754	5637	Business	27800.00
0005432784023	5637	Business	27800.00
0005432784046	5637	Economy	9300.00
0005435242751	5637	Economy	9300.00
0005435242714	5637	Economy	9300.00
0005432784033	5637	Economy	9300.00
0005432784029	5637	Economy	9300.00
0005435242806	5637	Economy	9300.00
0005435242816	5637	Economy	9300.00
0005432784036	5637	Economy	9300.00
0005432784017	5637	Economy	9300.00
0005432784040	5637	Economy	10200.00
0005432784019	5637	Economy	10200.00
0005432784037	5637	Economy	10200.00
0005435476747	5637	Economy	10200.00
0005432784025	5637	Economy	10200.00
0005432783997	5637	Economy	9300.00
0005432784049	5637	Economy	9300.00
0005435242738	5637	Economy	9300.00
0005435242794	5637	Economy	9300.00
0005432784044	5637	Economy	9300.00
0005435242743	5637	Economy	9300.00
0005435242582	5637	Economy	9300.00
0005432784006	5637	Economy	9300.00
0005432784018	5637	Economy	9300.00
0005435242746	5637	Economy	9300.00
0005432784030	5637	Economy	9300.00
0005435476738	5637	Economy	9300.00
0005432784002	5637	Economy	9300.00
0005432783999	5637	Economy	9300.00
0005432784014	5637	Economy	9300.00
0005435242668	5637	Economy	9300.00
0005435476739	5637	Economy	9300.00
0005432784001	5637	Economy	9300.00
0005432784022	5637	Economy	9300.00
0005435242712	5637	Economy	9300.00
0005435476722	5637	Economy	9300.00
0005432784032	5637	Economy	9300.00
0005435242745	5637	Economy	9300.00
0005432784010	5637	Economy	9300.00
0005432784042	5637	Economy	9300.00
0005432784015	5637	Economy	9300.00
0005432144002	5637	Economy	9300.00
0005432784011	5637	Economy	9300.00
0005435242753	5637	Economy	9300.00
0005432784000	5637	Economy	9300.00
0005435242793	5637	Economy	9300.00
0005432784034	5637	Economy	9300.00
0005435242583	5637	Economy	9300.00
0005432784039	5637	Economy	9300.00
0005435242788	5637	Economy	9300.00
0005435242656	5637	Economy	9300.00
0005432784043	5637	Economy	9300.00
0005432784024	5637	Economy	9300.00
0005432784009	5637	Economy	9300.00
0005432784031	5637	Economy	9300.00
0005435242667	5637	Economy	9300.00
0005432784012	5637	Economy	9300.00
0005435476724	5637	Economy	9300.00
0005432784048	5637	Economy	9300.00
0005435242718	5637	Economy	9300.00
0005435476723	5637	Economy	9300.00
0005432784021	5637	Economy	9300.00
0005435242640	5637	Economy	9300.00
0005432784041	5637	Economy	9300.00
0005435242803	5637	Economy	9300.00
0005435242764	5637	Economy	9300.00
0005435242713	5637	Economy	9300.00
0005435242716	5637	Economy	9300.00
0005432784016	5637	Economy	9300.00
0005432784004	5637	Economy	9300.00
0005435242797	5637	Economy	9300.00
0005432783996	5637	Economy	9300.00
0005432784038	5637	Economy	9300.00
0005432784035	5637	Economy	9300.00
0005435476725	5637	Economy	9300.00
0005432784005	5637	Economy	9300.00
0005432784028	5637	Economy	9300.00
0005432783998	5637	Economy	9300.00
0005432784008	5637	Economy	9300.00
0005432784026	5637	Economy	9300.00
0005432784013	5637	Economy	9300.00
0005435242798	5637	Economy	9300.00
0005432784027	5637	Economy	9300.00
0005435242681	5637	Economy	9300.00
0005432783824	15356	Business	27800.00
0005432783389	15356	Business	27800.00
0005435242961	15356	Business	27800.00
0005432783568	15356	Business	27800.00
0005432783198	15356	Business	27800.00
0005432783690	15356	Business	27800.00
0005432783525	15356	Business	27800.00
0005432783641	15356	Business	27800.00
0005432783493	15356	Business	27800.00
0005435476779	15356	Business	27800.00
0005432783642	15356	Business	27800.00
0005432783546	15356	Business	27800.00
0005432783481	15356	Economy	9300.00
0005432783482	15356	Economy	9300.00
0005432783489	15356	Economy	9300.00
0005432783390	15356	Economy	9300.00
0005432783643	15356	Economy	9300.00
0005435242937	15356	Economy	9300.00
0005432783609	15356	Economy	9300.00
0005435242947	15356	Economy	9300.00
0005432783491	15356	Economy	9300.00
0005432783581	15356	Economy	9300.00
0005432783580	15356	Economy	10200.00
0005432783480	15356	Economy	10200.00
0005432783492	15356	Economy	10200.00
0005435242948	15356	Economy	10200.00
0005435242944	15356	Economy	10200.00
0005432783579	15356	Economy	9300.00
0005432783572	15356	Economy	9300.00
0005432783585	15356	Economy	9300.00
0005432783621	15356	Economy	9300.00
0005435476784	15356	Economy	9300.00
0005432783682	15356	Economy	9300.00
0005435476787	15356	Economy	9300.00
0005435242946	15356	Economy	9300.00
0005432783586	15356	Economy	9300.00
0005432783349	15356	Economy	9300.00
0005432783590	15356	Economy	9300.00
0005432783412	15356	Economy	9300.00
0005432783388	15356	Economy	9300.00
0005432783636	15356	Economy	9300.00
0005432783632	15356	Economy	9300.00
0005435242954	15356	Economy	9300.00
0005435476785	15356	Economy	9300.00
0005432783413	15356	Economy	9300.00
0005435242955	15356	Economy	9300.00
0005435242960	15356	Economy	9300.00
0005432783495	15356	Economy	9300.00
0005435242962	15356	Economy	9300.00
0005435242949	15356	Economy	9300.00
0005432783547	15356	Economy	9300.00
0005432783449	15356	Economy	9300.00
0005435476782	15356	Economy	9300.00
0005432783681	15356	Economy	9300.00
0005435242956	15356	Economy	9300.00
0005432783393	15356	Economy	9300.00
0005432783526	15356	Economy	9300.00
0005435476781	15356	Economy	9300.00
0005435242952	15356	Economy	9300.00
0005432783332	15356	Economy	9300.00
0005432783317	15356	Economy	9300.00
0005435242950	15356	Economy	9300.00
0005435476780	15356	Economy	9300.00
0005432783669	15356	Economy	9300.00
0005432783770	15356	Economy	9300.00
0005432783582	15356	Economy	9300.00
0005435242953	15356	Economy	9300.00
0005435242940	15356	Economy	9300.00
0005432783637	15356	Economy	9300.00
0005435242936	15356	Economy	9300.00
0005432783633	15356	Economy	9300.00
0005435476786	15356	Economy	9300.00
0005435242957	15356	Economy	9300.00
0005432783524	15356	Economy	9300.00
0005432783448	15356	Economy	9300.00
0005432783571	15356	Economy	9300.00
0005432783591	15356	Economy	9300.00
0005432783515	15356	Economy	9300.00
0005432783543	15356	Economy	9300.00
0005435242958	15356	Economy	9300.00
0005435242941	15356	Economy	9300.00
0005432783528	15356	Economy	9300.00
0005432783484	15356	Economy	9300.00
0005435242942	15356	Economy	9300.00
0005435242938	15356	Economy	9300.00
0005435476783	15356	Economy	9300.00
0005435242951	15356	Economy	9300.00
0005435242943	15356	Economy	9300.00
0005432783336	15356	Economy	9300.00
0005435242939	15356	Economy	9300.00
0005435242945	15356	Economy	9300.00
0005432783398	15356	Economy	9300.00
0005432783527	15356	Economy	9300.00
0005432783360	15356	Economy	9300.00
0005432783494	15356	Economy	9300.00
0005435242959	15356	Economy	9300.00
0005432783655	15356	Economy	9300.00
0005434463937	4349	Economy	7000.00
0005435850872	4349	Economy	7000.00
0005432848381	4349	Economy	7000.00
0005435850886	4349	Economy	6300.00
0005434463939	4349	Economy	6300.00
0005434462799	4349	Economy	6300.00
0005435850877	4349	Economy	6300.00
0005435850876	4349	Economy	6300.00
0005432848369	4349	Economy	6300.00
0005434462801	4349	Economy	6300.00
0005434462798	4349	Economy	6300.00
0005432848367	4349	Economy	6300.00
0005432848372	4349	Economy	6300.00
0005435850885	4349	Economy	6300.00
0005432848379	4349	Economy	6300.00
0005432848377	4349	Economy	6300.00
0005432848371	4349	Economy	6300.00
0005432848368	4349	Economy	6300.00
0005434462800	4349	Economy	6300.00
0005432848382	4349	Economy	6300.00
0005434463938	4349	Economy	6300.00
0005432848376	4349	Economy	6300.00
0005432848370	4349	Economy	6300.00
0005432848374	4349	Economy	6300.00
0005435850869	4349	Economy	6300.00
0005432848373	4349	Economy	6300.00
0005432848378	4349	Economy	6300.00
0005432848375	4349	Economy	6300.00
0005432848380	4349	Economy	6300.00
0005435850951	28865	Economy	7000.00
0005432848194	28865	Economy	6300.00
0005432848233	28865	Economy	6300.00
0005432848200	28865	Economy	6300.00
0005435850946	28865	Economy	6300.00
0005432848209	28865	Economy	6300.00
0005434461628	28865	Economy	6300.00
0005432848264	28865	Economy	6300.00
0005432848252	28865	Economy	6300.00
0005432848226	28865	Economy	6300.00
0005435850953	28865	Economy	6300.00
0005435850952	28865	Economy	6300.00
0005432848217	28865	Economy	6300.00
0005435850950	28865	Economy	6300.00
0005434461631	28865	Economy	6300.00
0005432848195	28865	Economy	6300.00
0005435850948	28865	Economy	6300.00
0005432848247	28865	Economy	6300.00
0005432848201	28865	Economy	6300.00
0005435850947	28865	Economy	6300.00
0005435850949	28865	Economy	6300.00
0005434925949	6243	Business	11900.00
0005433497121	6243	Business	11900.00
0005434925936	6243	Business	11900.00
0005433497103	6243	Business	11900.00
0005434925951	6243	Business	11900.00
0005432075245	6243	Business	11900.00
0005434925928	6243	Business	11900.00
0005434925929	6243	Business	11900.00
0005434443779	6243	Business	11900.00
0005433497094	6243	Business	11900.00
0005433497096	6243	Business	11900.00
0005433497108	6243	Economy	4000.00
0005433497115	6243	Economy	4000.00
0005434925952	6243	Economy	4000.00
0005434925959	6243	Economy	4000.00
0005433497114	6243	Economy	4000.00
0005434443774	6243	Economy	4000.00
0005434925944	6243	Economy	4000.00
0005434925950	6243	Economy	4000.00
0005433497093	6243	Economy	4000.00
0005433497095	6243	Economy	4000.00
0005433497119	6243	Economy	4400.00
0005433497091	6243	Economy	4400.00
0005434443776	6243	Economy	4400.00
0005433497092	6243	Economy	4400.00
0005434443771	6243	Economy	4400.00
0005434925941	6243	Economy	4000.00
0005434925940	6243	Economy	4000.00
0005434925943	6243	Economy	4000.00
0005434443785	6243	Economy	4000.00
0005433497120	6243	Economy	4000.00
0005434443777	6243	Economy	4000.00
0005432075243	6243	Economy	4000.00
0005433497098	6243	Economy	4000.00
0005433497099	6243	Economy	4000.00
0005433497090	6243	Economy	4000.00
0005434443778	6243	Economy	4000.00
0005433497104	6243	Economy	4000.00
0005434925925	6243	Economy	4000.00
0005433497111	6243	Economy	4000.00
0005434925961	6243	Economy	4000.00
0005432075244	6243	Economy	4000.00
0005433497110	6243	Economy	4000.00
0005433497117	6243	Economy	4000.00
0005434925955	6243	Economy	4000.00
0005434925933	6243	Economy	4000.00
0005434925942	6243	Economy	4000.00
0005433497112	6243	Economy	4000.00
0005433497106	6243	Economy	4000.00
0005433497105	6243	Economy	4000.00
0005434925953	6243	Economy	4000.00
0005434925954	6243	Economy	4000.00
0005434925948	6243	Economy	4000.00
0005432075246	6243	Economy	4000.00
0005434925956	6243	Economy	4000.00
0005434925927	6243	Economy	4000.00
0005434443780	6243	Economy	4000.00
0005434925931	6243	Economy	4000.00
0005433497118	6243	Economy	4000.00
0005433497102	6243	Economy	4000.00
0005434443782	6243	Economy	4000.00
0005434925935	6243	Economy	4000.00
0005434925946	6243	Economy	4000.00
0005434443775	6243	Economy	4000.00
0005433497097	6243	Economy	4000.00
0005434925934	6243	Economy	4000.00
0005434925926	6243	Economy	4000.00
0005433497100	6243	Economy	4000.00
0005434443772	6243	Economy	4000.00
0005434925937	6243	Economy	4000.00
0005434925958	6243	Economy	4000.00
0005434925945	6243	Economy	4000.00
0005433497109	6243	Economy	4000.00
0005434925947	6243	Economy	4000.00
0005434443786	6243	Economy	4000.00
0005434925932	6243	Economy	4000.00
0005434925924	6243	Economy	4000.00
0005434925939	6243	Economy	4000.00
0005434443783	6243	Economy	4000.00
0005434925962	6243	Economy	4000.00
0005433497107	6243	Economy	4000.00
0005433497101	6243	Economy	4000.00
0005434443773	6243	Economy	4000.00
0005434443781	6243	Economy	4000.00
0005433497116	6243	Economy	4000.00
0005434925930	6243	Economy	4000.00
0005434925923	6243	Economy	4000.00
0005434925957	6243	Economy	4000.00
0005434925960	6243	Economy	4000.00
0005433497113	6243	Economy	4000.00
0005434925938	6243	Economy	4000.00
0005434443784	6243	Economy	4000.00
0005433496948	20327	Business	11900.00
0005433496919	20327	Business	11900.00
0005434925664	20327	Business	11900.00
0005434925651	20327	Business	11900.00
0005434443602	20327	Business	11900.00
0005434925725	20327	Business	11900.00
0005433496659	20327	Business	11900.00
0005434443616	20327	Business	11900.00
0005433496921	20327	Business	11900.00
0005434925654	20327	Business	11900.00
0005434925639	20327	Economy	4000.00
0005434925475	20327	Economy	4000.00
0005434443597	20327	Economy	4000.00
0005433496918	20327	Economy	4000.00
0005434925734	20327	Economy	4000.00
0005434925787	20327	Economy	4000.00
0005434925601	20327	Economy	4000.00
0005434925683	20327	Economy	4000.00
0005434925626	20327	Economy	4400.00
0005433496944	20327	Economy	4400.00
0005434925726	20327	Economy	4400.00
0005434925590	20327	Economy	4400.00
0005434443522	20327	Economy	4400.00
0005434925788	20327	Economy	4000.00
0005434443675	20327	Economy	4000.00
0005433496725	20327	Economy	4000.00
0005434925602	20327	Economy	4000.00
0005433496946	20327	Economy	4000.00
0005433496883	20327	Economy	4000.00
0005433496989	20327	Economy	4000.00
0005434443622	20327	Economy	4000.00
0005433496945	20327	Economy	4000.00
0005434443651	20327	Economy	4000.00
0005434443654	20327	Economy	4000.00
0005434925742	20327	Economy	4000.00
0005434443617	20327	Economy	4000.00
0005434443679	20327	Economy	4000.00
0005434443690	20327	Economy	4000.00
0005433496851	20327	Economy	4000.00
0005434925591	20327	Economy	4000.00
0005433496824	20327	Economy	4000.00
0005433497018	20327	Economy	4000.00
0005434925643	20327	Economy	4000.00
0005433496893	20327	Economy	4000.00
0005434925666	20327	Economy	4000.00
0005434925743	20327	Economy	4000.00
0005434925738	20327	Economy	4000.00
0005434443608	20327	Economy	4000.00
0005433496726	20327	Economy	4000.00
0005434925684	20327	Economy	4000.00
0005434443689	20327	Economy	4000.00
0005434925588	20327	Economy	4000.00
0005434925656	20327	Economy	4000.00
0005433496827	20327	Economy	4000.00
0005434443650	20327	Economy	4000.00
0005434925612	20327	Economy	4000.00
0005434925642	20327	Economy	4000.00
0005434925712	20327	Economy	4000.00
0005434925474	20327	Economy	4000.00
0005433496974	20327	Economy	4000.00
0005434443557	20327	Economy	4000.00
0005434443592	20327	Economy	4000.00
0005434925589	20327	Economy	4000.00
0005434925638	20327	Economy	4000.00
0005434443577	20327	Economy	4000.00
0005434925627	20327	Economy	4000.00
0005434925746	20327	Economy	4000.00
0005434443556	20327	Economy	4000.00
0005434925499	20327	Economy	4000.00
0005433496897	20327	Economy	4000.00
0005434443596	20327	Economy	4000.00
0005434925650	20327	Economy	4000.00
0005434925552	20327	Economy	4000.00
0005434925623	20327	Economy	4000.00
0005433496898	20327	Economy	4000.00
0005434925604	20327	Economy	4000.00
0005434925660	20327	Economy	4000.00
0005435242982	12160	Business	41200.00
0005435242969	12160	Business	41200.00
0005432783829	12160	Business	41200.00
0005432783676	12160	Business	41200.00
0005435242973	12160	Business	41200.00
0005432783794	12160	Business	41200.00
0005432783716	12160	Business	41200.00
0005432783589	12160	Business	41200.00
0005432783613	12160	Business	41200.00
0005432783628	12160	Business	41200.00
0005432783772	12160	Business	41200.00
0005435242968	12160	Business	41200.00
0005435242988	12160	Economy	13700.00
0005432783639	12160	Economy	13700.00
0005432783570	12160	Economy	13700.00
0005432783445	12160	Economy	13700.00
0005432783435	12160	Economy	13700.00
0005432783719	12160	Economy	13700.00
0005435242979	12160	Economy	13700.00
0005432783243	12160	Economy	13700.00
0005432783683	12160	Economy	13700.00
0005432783679	12160	Economy	13700.00
0005432783607	12160	Economy	15100.00
0005435242965	12160	Economy	15100.00
0005432783559	12160	Economy	15100.00
0005435242977	12160	Economy	15100.00
0005432783454	12160	Economy	15100.00
0005435242980	12160	Economy	13700.00
0005432783363	12160	Economy	13700.00
0005435242978	12160	Economy	13700.00
0005432783685	12160	Economy	13700.00
0005435242986	12160	Economy	13700.00
0005432783458	12160	Economy	13700.00
0005432783560	12160	Economy	13700.00
0005432783422	12160	Economy	13700.00
0005432783701	12160	Economy	13700.00
0005432783436	12160	Economy	13700.00
0005432783686	12160	Economy	13700.00
0005432783531	12160	Economy	13700.00
0005435242964	12160	Economy	13700.00
0005432783726	12160	Economy	13700.00
0005435242963	12160	Economy	13700.00
0005435242967	12160	Economy	13700.00
0005432783509	12160	Economy	13700.00
0005435242983	12160	Economy	13700.00
0005432783638	12160	Economy	13700.00
0005432783622	12160	Economy	13700.00
0005432783512	12160	Economy	13700.00
0005435242990	12160	Economy	13700.00
0005432783533	12160	Economy	13700.00
0005435242976	12160	Economy	13700.00
0005432783627	12160	Economy	13700.00
0005432783488	12160	Economy	13700.00
0005432783727	12160	Economy	13700.00
0005432783828	12160	Economy	13700.00
0005435242975	12160	Economy	13700.00
0005432783715	12160	Economy	13700.00
0005435242971	12160	Economy	13700.00
0005435242987	12160	Economy	13700.00
0005432783483	12160	Economy	13700.00
0005432783416	12160	Economy	13700.00
0005432783626	12160	Economy	13700.00
0005435242972	12160	Economy	13700.00
0005432783242	12160	Economy	13700.00
0005435242989	12160	Economy	13700.00
0005432783513	12160	Economy	13700.00
0005432783521	12160	Economy	13700.00
0005432783608	12160	Economy	13700.00
0005432783404	12160	Economy	13700.00
0005432783337	12160	Economy	13700.00
0005432783612	12160	Economy	13700.00
0005432783675	12160	Economy	13700.00
0005432783569	12160	Economy	13700.00
0005432783508	12160	Economy	13700.00
0005432783444	12160	Economy	13700.00
0005432783517	12160	Economy	13700.00
0005432783718	12160	Economy	13700.00
0005432783487	12160	Economy	13700.00
0005432783419	12160	Economy	13700.00
0005432783728	12160	Economy	13700.00
0005435242985	12160	Economy	13700.00
0005435242970	12160	Economy	13700.00
0005432783516	12160	Economy	13700.00
0005435242984	12160	Economy	13700.00
0005432783375	12160	Economy	13700.00
0005435242981	12160	Economy	13700.00
0005435242966	12160	Economy	13700.00
0005432783652	12160	Economy	13700.00
0005432783450	12160	Economy	13700.00
0005435242974	12160	Economy	13700.00
0005432783789	12160	Economy	13700.00
0005432783953	15429	Business	41200.00
0005432783959	15429	Business	41200.00
0005432783983	15429	Business	41200.00
0005432783957	15429	Business	41200.00
0005432783984	15429	Business	41200.00
0005435242768	15429	Business	41200.00
0005435242762	15429	Business	41200.00
0005432783970	15429	Business	41200.00
0005432783966	15429	Business	41200.00
0005432783972	15429	Business	41200.00
0005435242688	15429	Business	41200.00
0005432783975	15429	Business	41200.00
0005435242708	15429	Economy	13700.00
0005435242578	15429	Economy	13700.00
0005435242711	15429	Economy	13700.00
0005435242675	15429	Economy	13700.00
0005435242732	15429	Economy	13700.00
0005432783956	15429	Economy	13700.00
0005432783973	15429	Economy	13700.00
0005435242664	15429	Economy	13700.00
0005435242715	15429	Economy	13700.00
0005432783993	15429	Economy	15100.00
0005432783954	15429	Economy	15100.00
0005432783980	15429	Economy	15100.00
0005432783995	15429	Economy	15100.00
0005435242761	15429	Economy	15100.00
0005435242635	15429	Economy	13700.00
0005432783940	15429	Economy	13700.00
0005435242689	15429	Economy	13700.00
0005432783941	15429	Economy	13700.00
0005432783976	15429	Economy	13700.00
0005432783965	15429	Economy	13700.00
0005432783950	15429	Economy	13700.00
0005432783942	15429	Economy	13700.00
0005435242686	15429	Economy	13700.00
0005432783963	15429	Economy	13700.00
0005432783964	15429	Economy	13700.00
0005432783952	15429	Economy	13700.00
0005432783992	15429	Economy	13700.00
0005432783946	15429	Economy	13700.00
0005432783947	15429	Economy	13700.00
0005435242709	15429	Economy	13700.00
0005432783991	15429	Economy	13700.00
0005435242771	15429	Economy	13700.00
0005432783944	15429	Economy	13700.00
0005432783958	15429	Economy	13700.00
0005432783962	15429	Economy	13700.00
0005432783951	15429	Economy	13700.00
0005432783968	15429	Economy	13700.00
0005432783977	15429	Economy	13700.00
0005432783945	15429	Economy	13700.00
0005435242613	15429	Economy	13700.00
0005435242723	15429	Economy	13700.00
0005435242812	15429	Economy	13700.00
0005435242665	15429	Economy	13700.00
0005432783990	15429	Economy	13700.00
0005432783985	15429	Economy	13700.00
0005435242733	15429	Economy	13700.00
0005432783981	15429	Economy	13700.00
0005435242728	15429	Economy	13700.00
0005432783955	15429	Economy	13700.00
0005435242650	15429	Economy	13700.00
0005435242687	15429	Economy	13700.00
0005432783989	15429	Economy	13700.00
0005432783979	15429	Economy	13700.00
0005432783948	15429	Economy	13700.00
0005432783971	15429	Economy	13700.00
0005432783982	15429	Economy	13700.00
0005435242770	15429	Economy	13700.00
0005435242535	15429	Economy	13700.00
0005432783969	15429	Economy	13700.00
0005432783978	15429	Economy	13700.00
0005432783987	15429	Economy	13700.00
0005432783949	15429	Economy	13700.00
0005435242676	15429	Economy	13700.00
0005435242769	15429	Economy	13700.00
0005432783961	15429	Economy	13700.00
0005432783974	15429	Economy	13700.00
0005432783943	15429	Economy	13700.00
0005432783986	15429	Economy	13700.00
0005432783988	15429	Economy	13700.00
0005432783960	15429	Economy	13700.00
0005435242651	15429	Economy	13700.00
0005432783994	15429	Economy	13700.00
0005435242680	15429	Economy	13700.00
0005432783967	15429	Economy	13700.00
0005435913941	10080	Business	49700.00
0005434877855	10080	Business	49700.00
0005434877635	10080	Business	49700.00
0005434877416	10080	Business	49700.00
0005434877826	10080	Business	49700.00
0005434877953	10080	Business	49700.00
0005434877906	10080	Business	49700.00
0005434877928	10080	Business	49700.00
0005434877524	10080	Business	49700.00
0005435913945	10080	Business	49700.00
0005434877838	10080	Business	49700.00
0005434877506	10080	Business	49700.00
0005434877983	10080	Business	49700.00
0005434877629	10080	Business	49700.00
0005434877851	10080	Business	49700.00
0005434877982	10080	Business	49700.00
0005434878061	10080	Business	49700.00
0005434877883	10080	Economy	16600.00
0005434878151	10080	Economy	16600.00
0005434877738	10080	Economy	16600.00
0005434877381	10080	Economy	16600.00
0005435913944	10080	Economy	16600.00
0005434877867	10080	Economy	16600.00
0005434878152	10080	Economy	16600.00
0005434877553	10080	Economy	16600.00
0005434878143	10080	Economy	16600.00
0005434877593	10080	Economy	16600.00
0005434878142	10080	Economy	16600.00
0005434877552	10080	Economy	16600.00
0005434877985	10080	Economy	18200.00
0005434877731	10080	Economy	18200.00
0005434877745	10080	Economy	16600.00
0005434877520	10080	Economy	18200.00
0005434877734	10080	Economy	16600.00
0005434877763	10080	Economy	16600.00
0005434877825	10080	Economy	16600.00
0005434877850	10080	Economy	16600.00
0005434877501	10080	Economy	16600.00
0005434877994	10080	Economy	16600.00
0005434877533	10080	Economy	16600.00
0005434877716	10080	Economy	16600.00
0005434877484	10080	Economy	16600.00
0005434877973	10080	Economy	16600.00
0005434877582	10080	Economy	16600.00
0005434877986	10080	Economy	16600.00
0005434877762	10080	Economy	16600.00
0005434878060	10080	Economy	16600.00
0005434877665	10080	Economy	16600.00
0005434877733	10080	Economy	16600.00
0005434877602	10080	Economy	16600.00
0005434878014	10080	Economy	16600.00
0005434878283	10080	Economy	16600.00
0005434877960	10080	Economy	16600.00
0005434877571	10080	Economy	16600.00
0005434877554	10080	Economy	16600.00
0005434877929	10080	Economy	16600.00
0005434878160	10080	Economy	16600.00
0005434877672	10080	Economy	16600.00
0005434877732	10080	Economy	16600.00
0005434877885	10080	Economy	16600.00
0005434877511	10080	Economy	16600.00
0005434878013	10080	Economy	16600.00
0005434878035	10080	Economy	16600.00
0005434877684	10080	Economy	16600.00
0005434877594	10080	Economy	16600.00
0005434877664	10080	Economy	16600.00
0005434877282	10080	Economy	16600.00
0005434877700	10080	Economy	16600.00
0005434877468	10080	Economy	16600.00
0005434877673	10080	Economy	16600.00
0005434878044	10080	Economy	16600.00
0005434877523	10080	Economy	16600.00
0005434877993	10080	Economy	16600.00
0005435913940	10080	Economy	16600.00
0005434910121	10080	Economy	16600.00
0005434877766	10080	Economy	16600.00
0005434877739	10080	Economy	16600.00
0005434877683	10080	Economy	16600.00
0005435913943	10080	Economy	16600.00
0005434877981	10080	Economy	16600.00
0005434878161	10080	Economy	16600.00
0005434910122	10080	Economy	16600.00
0005434877601	10080	Economy	16600.00
0005435913942	10080	Economy	16600.00
0005434878141	10080	Economy	16600.00
0005435913946	10080	Economy	16600.00
0005434878006	10080	Economy	16600.00
0005434877630	10080	Economy	16600.00
0005434877754	10080	Economy	16600.00
0005434877961	10080	Economy	16600.00
0005434877570	10080	Economy	16600.00
0005434878020	10080	Economy	16600.00
0005434910123	10080	Economy	16600.00
0005434878034	10080	Economy	16600.00
0005434877903	10080	Economy	16600.00
0005434877767	10080	Economy	16600.00
0005434878010	10080	Economy	16600.00
0005434877900	10080	Economy	16600.00
0005434878643	14621	Business	49700.00
0005434878601	14621	Business	49700.00
0005434878579	14621	Business	49700.00
0005434878637	14621	Business	49700.00
0005434910118	14621	Business	49700.00
0005434758903	14621	Business	49700.00
0005434878612	14621	Business	49700.00
0005434878580	14621	Business	49700.00
0005434878671	14621	Business	49700.00
0005434878618	14621	Business	49700.00
0005434878619	14621	Business	49700.00
0005434878596	14621	Business	49700.00
0005434878648	14621	Business	49700.00
0005434878667	14621	Business	49700.00
0005434878593	14621	Business	49700.00
0005434878651	14621	Business	49700.00
0005434878589	14621	Business	49700.00
0005434878623	14621	Business	49700.00
0005435913920	14621	Economy	16600.00
0005434878631	14621	Economy	16600.00
0005434878668	14621	Economy	16600.00
0005434878660	14621	Economy	16600.00
0005434878622	14621	Economy	16600.00
0005434878666	14621	Economy	16600.00
0005434878610	14621	Economy	16600.00
0005434878624	14621	Economy	16600.00
0005434878616	14621	Economy	16600.00
0005434878664	14621	Economy	16600.00
0005434910117	14621	Economy	16600.00
0005434878630	14621	Economy	16600.00
0005434878602	14621	Economy	18200.00
0005434878665	14621	Economy	18200.00
0005434878594	14621	Economy	18200.00
0005434878620	14621	Economy	18200.00
0005434878609	14621	Economy	16600.00
0005434878608	14621	Economy	16600.00
0005434878653	14621	Economy	16600.00
0005434878661	14621	Economy	16600.00
0005434878604	14621	Economy	16600.00
0005434878636	14621	Economy	16600.00
0005434878611	14621	Economy	16600.00
0005434878642	14621	Economy	16600.00
0005434878614	14621	Economy	16600.00
0005434878626	14621	Economy	16600.00
0005434878625	14621	Economy	16600.00
0005434878603	14621	Economy	16600.00
0005435913918	14621	Economy	16600.00
0005434878633	14621	Economy	16600.00
0005434878605	14621	Economy	16600.00
0005434878617	14621	Economy	16600.00
0005434878644	14621	Economy	16600.00
0005434878650	14621	Economy	16600.00
0005434878629	14621	Economy	16600.00
0005434878600	14621	Economy	16600.00
0005434878647	14621	Economy	16600.00
0005435913912	14621	Economy	16600.00
0005434878659	14621	Economy	16600.00
0005435913913	14621	Economy	16600.00
0005434878657	14621	Economy	16600.00
0005434758902	14621	Economy	16600.00
0005434878584	14621	Economy	16600.00
0005434878606	14621	Economy	16600.00
0005434878613	14621	Economy	16600.00
0005434878599	14621	Economy	16600.00
0005434878615	14621	Economy	16600.00
0005434878639	14621	Economy	16600.00
0005434878669	14621	Economy	16600.00
0005434878634	14621	Economy	16600.00
0005434878635	14621	Economy	16600.00
0005434878582	14621	Economy	16600.00
0005434878645	14621	Economy	16600.00
0005434878585	14621	Economy	16600.00
0005434910102	14621	Economy	16600.00
0005434878588	14621	Economy	16600.00
0005435913907	14621	Economy	16600.00
0005434878607	14621	Economy	16600.00
0005434878646	14621	Economy	16600.00
0005434878595	14621	Economy	16600.00
0005435913917	14621	Economy	16600.00
0005434878662	14621	Economy	16600.00
0005434878632	14621	Economy	16600.00
0005434878590	14621	Economy	16600.00
0005434878598	14621	Economy	16600.00
0005434878628	14621	Economy	16600.00
0005434878641	14621	Economy	16600.00
0005434878663	14621	Economy	16600.00
0005434878621	14621	Economy	16600.00
0005434758904	14621	Economy	16600.00
0005434878586	14621	Economy	16600.00
0005434878597	14621	Economy	16600.00
0005434878652	14621	Economy	16600.00
0005434878592	14621	Economy	16600.00
0005434878587	14621	Economy	16600.00
0005434878591	14621	Economy	16600.00
0005434878638	14621	Economy	16600.00
0005434878583	14621	Economy	16600.00
0005434878649	14621	Economy	16600.00
0005434878670	14621	Economy	16600.00
0005434878581	14621	Economy	16600.00
0005434878656	14621	Economy	16600.00
0005434878654	14621	Economy	16600.00
0005435913921	14621	Economy	16600.00
0005434878640	14621	Economy	16600.00
0005434878655	14621	Economy	16600.00
0005434878627	14621	Economy	16600.00
0005434878658	14621	Economy	16600.00
0005434251928	9264	Economy	22400.00
0005434251915	9264	Economy	22400.00
0005434251906	9264	Economy	22400.00
0005434251927	9264	Economy	20300.00
0005434251940	9264	Economy	20300.00
0005434251902	9264	Economy	20300.00
0005434251948	9264	Economy	20300.00
0005435660179	9264	Economy	20300.00
0005435660188	9264	Economy	20300.00
0005434251909	9264	Economy	20300.00
0005434251910	9264	Economy	20300.00
0005435660184	9264	Economy	20300.00
0005434251905	9264	Economy	20300.00
0005434251914	9264	Economy	20300.00
0005435660180	9264	Economy	20300.00
0005434251916	9264	Economy	20300.00
0005435660181	9264	Economy	20300.00
0005435660189	9264	Economy	20300.00
0005435660186	9264	Economy	20300.00
0005435660183	9264	Economy	20300.00
0005434251888	9264	Economy	20300.00
0005435660182	9264	Economy	20300.00
0005435660185	9264	Economy	20300.00
0005434251941	9264	Economy	20300.00
0005435660187	9264	Economy	20300.00
0005434251925	9264	Economy	20300.00
0005434252008	24672	Economy	22400.00
0005435660099	24672	Economy	20300.00
0005434252006	24672	Economy	20300.00
0005434252003	24672	Economy	20300.00
0005435660068	24672	Economy	20300.00
0005435660046	24672	Economy	20300.00
0005434252002	24672	Economy	20300.00
0005434252007	24672	Economy	20300.00
0005435660093	24672	Economy	20300.00
0005435660065	24672	Economy	20300.00
0005434252005	24672	Economy	20300.00
0005435660064	24672	Economy	20300.00
0005435660076	24672	Economy	20300.00
0005434252004	24672	Economy	20300.00
0005435660047	24672	Economy	20300.00
0005434252001	24672	Economy	20300.00
0005435660098	24672	Economy	20300.00
0005433680764	2766	Business	33000.00
0005432966810	2766	Business	33000.00
0005433680739	2766	Business	33000.00
0005432966828	2766	Business	33000.00
0005432966783	2766	Business	33000.00
0005432966820	2766	Business	33000.00
0005433680758	2766	Business	33000.00
0005433684427	2766	Business	33000.00
0005432966829	2766	Business	33000.00
0005433680745	2766	Business	33000.00
0005433680762	2766	Economy	11000.00
0005433680779	2766	Economy	11000.00
0005433680772	2766	Economy	11000.00
0005433680756	2766	Economy	11000.00
0005433680744	2766	Economy	11000.00
0005432966811	2766	Economy	11000.00
0005432966697	2766	Economy	11000.00
0005433680778	2766	Economy	11000.00
0005432222803	2766	Economy	12100.00
0005432222805	2766	Economy	12100.00
0005432966890	2766	Economy	12100.00
0005432966784	2766	Economy	12100.00
0005432966806	2766	Economy	11000.00
0005433680751	2766	Economy	11000.00
0005433680748	2766	Economy	11000.00
0005433680759	2766	Economy	11000.00
0005433680765	2766	Economy	11000.00
0005433680769	2766	Economy	11000.00
0005433680780	2766	Economy	11000.00
0005432966850	2766	Economy	11000.00
0005433680747	2766	Economy	11000.00
0005432966948	2766	Economy	11000.00
0005432966851	2766	Economy	11000.00
0005432966809	2766	Economy	11000.00
0005433680742	2766	Economy	11000.00
0005433680781	2766	Economy	11000.00
0005433680763	2766	Economy	11000.00
0005433680777	2766	Economy	11000.00
0005433680736	2766	Economy	11000.00
0005433680771	2766	Economy	11000.00
0005432966803	2766	Economy	11000.00
0005433680767	2766	Economy	11000.00
0005433680746	2766	Economy	11000.00
0005432966911	2766	Economy	11000.00
0005433680737	2766	Economy	11000.00
0005432966835	2766	Economy	11000.00
0005433680768	2766	Economy	11000.00
0005432222806	2766	Economy	11000.00
0005432966772	2766	Economy	11000.00
0005432966819	2766	Economy	11000.00
0005433680738	2766	Economy	11000.00
0005433680749	2766	Economy	11000.00
0005433680776	2766	Economy	11000.00
0005433680754	2766	Economy	11000.00
0005432966844	2766	Economy	11000.00
0005432966782	2766	Economy	11000.00
0005433680761	2766	Economy	11000.00
0005433680752	2766	Economy	11000.00
0005432966796	2766	Economy	11000.00
0005433684428	2766	Economy	11000.00
0005433680775	2766	Economy	11000.00
0005433680770	2766	Economy	11000.00
0005433680735	2766	Economy	11000.00
0005433680743	2766	Economy	11000.00
0005432966902	2766	Economy	11000.00
0005433680753	2766	Economy	11000.00
0005432966879	2766	Economy	11000.00
0005433680766	2766	Economy	11000.00
0005433680750	2766	Economy	11000.00
0005433680740	2766	Economy	11000.00
0005433680755	2766	Economy	11000.00
0005433680774	2766	Economy	11000.00
0005432966837	2766	Economy	11000.00
0005433680760	2766	Economy	11000.00
0005432222804	2766	Economy	11000.00
0005432966797	2766	Economy	11000.00
0005432966836	2766	Economy	11000.00
0005432222802	2766	Economy	11000.00
0005433680773	2766	Economy	11000.00
0005433680783	2766	Economy	11000.00
0005432966791	2766	Economy	11000.00
0005433680782	2766	Economy	11000.00
0005432966957	2766	Economy	11000.00
0005432222801	2766	Economy	11000.00
0005433680757	2766	Economy	11000.00
0005433680741	2766	Economy	11000.00
0005433687689	29189	Business	33000.00
0005433680399	29189	Business	33000.00
0005432967035	29189	Business	33000.00
0005432967036	29189	Business	33000.00
0005433680280	29189	Business	33000.00
0005433680232	29189	Business	33000.00
0005433687699	29189	Business	33000.00
0005433680397	29189	Business	33000.00
0005433680558	29189	Business	33000.00
0005433680243	29189	Business	33000.00
0005433680152	29189	Business	33000.00
0005433680322	29189	Economy	11000.00
0005433680328	29189	Economy	11000.00
0005433687700	29189	Economy	11000.00
0005432967032	29189	Economy	11000.00
0005433680442	29189	Economy	11000.00
0005433687693	29189	Economy	11000.00
0005432967037	29189	Economy	11000.00
0005433680327	29189	Economy	11000.00
0005433680562	29189	Economy	11000.00
0005433680387	29189	Economy	11000.00
0005433680643	29189	Economy	12100.00
0005432005224	29189	Economy	12100.00
0005433680493	29189	Economy	12100.00
0005433680303	29189	Economy	12100.00
0005433680217	29189	Economy	12100.00
0005433680324	29189	Economy	11000.00
0005433680323	29189	Economy	11000.00
0005433680283	29189	Economy	11000.00
0005433680245	29189	Economy	11000.00
0005432967042	29189	Economy	11000.00
0005432967052	29189	Economy	11000.00
0005432967039	29189	Economy	11000.00
0005433680515	29189	Economy	11000.00
0005433680502	29189	Economy	11000.00
0005433687698	29189	Economy	11000.00
0005433680252	29189	Economy	11000.00
0005433680207	29189	Economy	11000.00
0005433680279	29189	Economy	11000.00
0005433680434	29189	Economy	11000.00
0005433680384	29189	Economy	11000.00
0005433680563	29189	Economy	11000.00
0005432967033	29189	Economy	11000.00
0005433680365	29189	Economy	11000.00
0005433680582	29189	Economy	11000.00
0005432967050	29189	Economy	11000.00
0005432967040	29189	Economy	11000.00
0005432967044	29189	Economy	11000.00
0005432967045	29189	Economy	11000.00
0005433680485	29189	Economy	11000.00
0005432967048	29189	Economy	11000.00
0005432967029	29189	Economy	11000.00
0005432967049	29189	Economy	11000.00
0005433680246	29189	Economy	11000.00
0005432967051	29189	Economy	11000.00
0005433680431	29189	Economy	11000.00
0005433680410	29189	Economy	11000.00
0005433680514	29189	Economy	11000.00
0005433680412	29189	Economy	11000.00
0005433680486	29189	Economy	11000.00
0005432967041	29189	Economy	11000.00
0005433680127	29189	Economy	11000.00
0005433684416	29189	Economy	11000.00
0005433680426	29189	Economy	11000.00
0005433680544	29189	Economy	11000.00
0005433680437	29189	Economy	11000.00
0005433680639	29189	Economy	11000.00
0005432005226	29189	Economy	11000.00
0005433690917	29189	Economy	11000.00
0005433680398	29189	Economy	11000.00
0005432967038	29189	Economy	11000.00
0005433690918	29189	Economy	11000.00
0005433680404	29189	Economy	11000.00
0005433680530	29189	Economy	11000.00
0005433680350	29189	Economy	11000.00
0005433680516	29189	Economy	11000.00
0005432967053	29189	Economy	11000.00
0005433690924	29189	Economy	11000.00
0005432967034	29189	Economy	11000.00
0005433690923	29189	Economy	11000.00
0005433680302	29189	Economy	11000.00
0005433680331	29189	Economy	11000.00
0005432967046	29189	Economy	11000.00
0005432967047	29189	Economy	11000.00
0005433680333	29189	Economy	11000.00
0005432967031	29189	Economy	11000.00
0005433680366	29189	Economy	11000.00
0005433680208	29189	Economy	11000.00
0005432967028	29189	Economy	11000.00
0005432967043	29189	Economy	11000.00
0005433680149	29189	Economy	11000.00
0005433680108	29189	Economy	11000.00
0005432967030	29189	Economy	11000.00
0005433680421	29189	Economy	11000.00
0005433680438	29189	Economy	11000.00
0005432005225	29189	Economy	11000.00
0005433614938	9313	Business	132900.00
0005433633943	9313	Business	132900.00
0005433614896	9313	Business	132900.00
0005432755088	9313	Business	132900.00
0005433633937	9313	Business	132900.00
0005433614898	9313	Business	132900.00
0005433614936	9313	Business	132900.00
0005433614946	9313	Business	132900.00
0005433614902	9313	Business	132900.00
0005433614932	9313	Business	132900.00
0005433577862	9313	Business	132900.00
0005433614915	9313	Business	132900.00
0005433614883	9313	Business	132900.00
0005433633940	9313	Business	132900.00
0005433614886	9313	Business	132900.00
0005433614926	9313	Business	132900.00
0005434163527	9313	Business	132900.00
0005433614941	9313	Business	132900.00
0005433633913	9313	Business	132900.00
0005433614952	9313	Business	132900.00
0005433633917	9313	Business	132900.00
0005433633925	9313	Business	132900.00
0005434152775	9313	Business	132900.00
0005433614951	9313	Business	132900.00
0005433614919	9313	Economy	48700.00
0005433633918	9313	Business	132900.00
0005433614907	9313	Economy	48700.00
0005433614913	9313	Economy	48700.00
0005433614887	9313	Economy	48700.00
0005433633923	9313	Economy	44300.00
0005433614954	9313	Economy	44300.00
0005433633941	9313	Economy	44300.00
0005433614916	9313	Economy	44300.00
0005433614933	9313	Economy	44300.00
0005433633926	9313	Economy	44300.00
0005432755089	9313	Economy	44300.00
0005433614937	9313	Economy	44300.00
0005433614895	9313	Economy	44300.00
0005433577859	9313	Economy	44300.00
0005433614924	9313	Economy	44300.00
0005433614934	9313	Economy	44300.00
0005433633929	9313	Economy	44300.00
0005433633932	9313	Economy	44300.00
0005433614892	9313	Economy	44300.00
0005433614912	9313	Economy	44300.00
0005432145118	9313	Economy	44300.00
0005434152772	9313	Economy	44300.00
0005434153524	9313	Economy	44300.00
0005433614900	9313	Economy	44300.00
0005433614922	9313	Economy	44300.00
0005433614914	9313	Economy	44300.00
0005433633942	9313	Economy	44300.00
0005434272185	9313	Economy	44300.00
0005433633912	9313	Economy	44300.00
0005433633936	9313	Economy	44300.00
0005433633934	9313	Economy	44300.00
0005433614953	9313	Economy	44300.00
0005433577861	9313	Economy	44300.00
0005433633911	9313	Economy	44300.00
0005433633927	9313	Economy	44300.00
0005433614944	9313	Economy	44300.00
0005433614942	9313	Economy	44300.00
0005434163575	9313	Economy	44300.00
0005433614920	9313	Economy	44300.00
0005433614904	9313	Economy	44300.00
0005433614897	9313	Economy	44300.00
0005433633933	9313	Economy	44300.00
0005433614949	9313	Economy	44300.00
0005433633944	9313	Economy	44300.00
0005434163567	9313	Economy	44300.00
0005433577854	9313	Economy	44300.00
0005433633922	9313	Economy	44300.00
0005434163609	9313	Economy	44300.00
0005434269087	9313	Economy	44300.00
0005433614927	9313	Economy	44300.00
0005433577864	9313	Economy	44300.00
0005433614921	9313	Economy	44300.00
0005433633920	9313	Economy	44300.00
0005433633939	9313	Economy	44300.00
0005434163559	9313	Economy	44300.00
0005433633938	9313	Economy	48700.00
0005434163526	9313	Economy	48700.00
0005433577865	9313	Economy	48700.00
0005433614903	9313	Economy	48700.00
0005433633924	9313	Economy	44300.00
0005433614935	9313	Economy	48700.00
0005434163568	9313	Economy	44300.00
0005433614911	9313	Economy	44300.00
0005433633914	9313	Economy	44300.00
0005433614923	9313	Economy	48700.00
0005433614893	9313	Economy	44300.00
0005433614888	9313	Economy	44300.00
0005433614885	9313	Economy	44300.00
0005433614931	9313	Economy	44300.00
0005434272186	9313	Economy	44300.00
0005433614894	9313	Economy	44300.00
0005433614918	9313	Economy	44300.00
0005433614940	9313	Economy	44300.00
0005433614950	9313	Economy	44300.00
0005433614955	9313	Economy	44300.00
0005433614945	9313	Economy	44300.00
0005433577858	9313	Economy	44300.00
0005433614890	9313	Economy	44300.00
0005433633921	9313	Economy	44300.00
0005433633928	9313	Economy	44300.00
0005433614943	9313	Economy	44300.00
0005434163558	9313	Economy	44300.00
0005433633935	9313	Economy	44300.00
0005433614939	9313	Economy	44300.00
0005433614889	9313	Economy	44300.00
0005433633919	9313	Economy	44300.00
0005433633916	9313	Economy	44300.00
0005433614905	9313	Economy	44300.00
0005433614884	9313	Economy	44300.00
0005432755087	9313	Economy	44300.00
0005433577855	9313	Economy	44300.00
0005433633945	9313	Economy	44300.00
0005433577863	9313	Economy	44300.00
0005432756861	9313	Economy	44300.00
0005433577857	9313	Economy	44300.00
0005433614928	9313	Economy	44300.00
0005433614956	9313	Economy	44300.00
0005434152773	9313	Economy	44300.00
0005433614899	9313	Economy	44300.00
0005433614925	9313	Economy	44300.00
0005433614908	9313	Economy	44300.00
0005433614929	9313	Economy	44300.00
0005433614930	9313	Economy	44300.00
0005433614947	9313	Economy	44300.00
0005433614909	9313	Economy	44300.00
0005433614957	9313	Economy	44300.00
0005433614910	9313	Economy	44300.00
0005433633915	9313	Economy	44300.00
0005433577856	9313	Economy	44300.00
0005433633931	9313	Economy	44300.00
0005432756862	9313	Economy	44300.00
0005433614948	9313	Economy	44300.00
0005433633930	9313	Economy	44300.00
0005434163566	9313	Economy	44300.00
0005433577860	9313	Economy	44300.00
0005433614891	9313	Economy	44300.00
0005433614906	9313	Economy	44300.00
0005433614917	9313	Economy	44300.00
0005433577866	9313	Economy	44300.00
0005433614901	9313	Economy	44300.00
0005433577686	25245	Business	132900.00
0005433614142	25245	Business	132900.00
0005432751500	25245	Business	132900.00
0005433614325	25245	Business	132900.00
0005433614644	25245	Business	132900.00
0005433614259	25245	Business	132900.00
0005433633576	25245	Business	132900.00
0005433614357	25245	Business	132900.00
0005432755058	25245	Business	132900.00
0005433633657	25245	Business	132900.00
0005433614319	25245	Business	132900.00
0005433614455	25245	Business	132900.00
0005433633427	25245	Business	132900.00
0005433614128	25245	Business	132900.00
0005433614293	25245	Business	132900.00
0005433633581	25245	Business	132900.00
0005433633428	25245	Business	132900.00
0005433614129	25245	Business	132900.00
0005434152785	25245	Business	132900.00
0005433577748	25245	Business	132900.00
0005432755057	25245	Business	132900.00
0005433633543	25245	Business	132900.00
0005434152782	25245	Business	132900.00
0005432751489	25245	Business	132900.00
0005433614153	25245	Business	132900.00
0005433614450	25245	Business	132900.00
0005433614331	25245	Business	132900.00
0005433633716	25245	Economy	48700.00
0005433614451	25245	Business	132900.00
0005433614294	25245	Economy	48700.00
0005433633659	25245	Economy	48700.00
0005433614014	25245	Economy	48700.00
0005433614391	25245	Economy	44300.00
0005433633721	25245	Economy	44300.00
0005433614166	25245	Economy	44300.00
0005432751499	25245	Economy	44300.00
0005433577685	25245	Economy	44300.00
0005433577701	25245	Economy	44300.00
0005433633702	25245	Economy	44300.00
0005433614386	25245	Economy	44300.00
0005433614079	25245	Economy	44300.00
0005434152791	25245	Economy	44300.00
0005433614152	25245	Economy	44300.00
0005433614261	25245	Economy	44300.00
0005434152786	25245	Economy	44300.00
0005433633568	25245	Economy	44300.00
0005433633750	25245	Economy	44300.00
0005432755046	25245	Economy	44300.00
0005434152783	25245	Economy	44300.00
0005433577776	25245	Economy	44300.00
0005432755037	25245	Economy	44300.00
0005433633618	25245	Economy	44300.00
0005433614272	25245	Economy	44300.00
0005433577744	25245	Economy	44300.00
0005433577768	25245	Economy	44300.00
0005433633722	25245	Economy	44300.00
0005433614324	25245	Economy	44300.00
0005433614401	25245	Economy	44300.00
0005432751488	25245	Economy	44300.00
0005433614348	25245	Economy	44300.00
0005433614552	25245	Economy	44300.00
0005433633550	25245	Economy	44300.00
0005433614238	25245	Economy	44300.00
0005433614285	25245	Economy	44300.00
0005433614445	25245	Economy	44300.00
0005433614398	25245	Economy	44300.00
0005433614220	25245	Economy	44300.00
0005433614429	25245	Economy	44300.00
0005433614304	25245	Economy	44300.00
0005433633613	25245	Economy	44300.00
0005433614241	25245	Economy	44300.00
0005433577773	25245	Economy	44300.00
0005434152788	25245	Economy	44300.00
0005433633616	25245	Economy	44300.00
0005432755048	25245	Economy	44300.00
0005432755041	25245	Economy	44300.00
0005434152792	25245	Economy	44300.00
0005433614423	25245	Economy	44300.00
0005433633612	25245	Economy	44300.00
0005434152789	25245	Economy	44300.00
0005433633689	25245	Economy	44300.00
0005433614017	25245	Economy	44300.00
0005433614306	25245	Economy	44300.00
0005433614179	25245	Economy	44300.00
0005433633542	25245	Economy	44300.00
0005433633751	25245	Economy	48700.00
0005433577723	25245	Economy	48700.00
0005433614012	25245	Economy	48700.00
0005433614452	25245	Economy	48700.00
0005433614115	25245	Economy	44300.00
0005432751497	25245	Economy	48700.00
0005433614262	25245	Economy	44300.00
0005433633594	25245	Economy	44300.00
0005433614255	25245	Economy	44300.00
0005433614317	25245	Economy	48700.00
0005432751501	25245	Economy	44300.00
0005433633756	25245	Economy	44300.00
0005433614311	25245	Economy	44300.00
0005433633561	25245	Economy	44300.00
0005432751490	25245	Economy	44300.00
0005433577775	25245	Economy	44300.00
0005432755063	25245	Economy	44300.00
0005432751491	25245	Economy	44300.00
0005433577779	25245	Economy	44300.00
0005433633633	25245	Economy	44300.00
0005433614591	25245	Economy	44300.00
0005432755039	25245	Economy	44300.00
0005433614456	25245	Economy	44300.00
0005432755029	25245	Economy	44300.00
0005433633712	25245	Economy	44300.00
0005433614292	25245	Economy	44300.00
0005433577780	25245	Economy	44300.00
0005433614434	25245	Economy	44300.00
0005433614198	25245	Economy	44300.00
0005432755062	25245	Economy	44300.00
0005433614253	25245	Economy	44300.00
0005433633569	25245	Economy	44300.00
0005433614197	25245	Economy	44300.00
0005433614201	25245	Economy	44300.00
0005432755045	25245	Economy	44300.00
0005433614330	25245	Economy	44300.00
0005433614446	25245	Economy	44300.00
0005433614303	25245	Economy	44300.00
0005432751496	25245	Economy	44300.00
0005433614457	25245	Economy	44300.00
0005432751515	25245	Economy	44300.00
0005433633619	25245	Economy	44300.00
0005433614141	25245	Economy	44300.00
0005433614318	25245	Economy	44300.00
0005433613946	25245	Economy	44300.00
0005433614154	25245	Economy	44300.00
0005433614440	25245	Economy	44300.00
0005433614078	25245	Economy	44300.00
0005432755040	25245	Economy	44300.00
0005434152787	25245	Economy	44300.00
0005433577626	25245	Economy	44300.00
0005434152784	25245	Economy	44300.00
0005432755042	25245	Economy	44300.00
0005433614034	25245	Economy	44300.00
0005433633635	25245	Economy	44300.00
0005433614077	25245	Economy	44300.00
0005433614013	25245	Economy	44300.00
0005433633658	25245	Economy	44300.00
0005433614524	25245	Economy	44300.00
0005433614221	25245	Economy	44300.00
0005433614180	25245	Economy	44300.00
0005433614018	25245	Economy	44300.00
0005434152790	25245	Economy	44300.00
0005433614323	25245	Economy	44300.00
0005433614291	25245	Economy	44300.00
0005433633620	25245	Economy	44300.00
0005433577781	25245	Economy	44300.00
0005433633399	25245	Economy	44300.00
0005433613947	25245	Economy	44300.00
0005433614143	25245	Economy	44300.00
0005433633582	25245	Economy	44300.00
0005432184963	4198	Business	193100.00
0005435947234	4198	Business	193100.00
0005435986799	4198	Business	193100.00
0005432184961	4198	Business	193100.00
0005435947217	4198	Economy	64400.00
0005435986797	4198	Economy	64400.00
0005435947168	4198	Economy	64400.00
0005432571306	4198	Economy	64400.00
0005435947162	4198	Economy	64400.00
0005435947233	4198	Economy	64400.00
0005435856196	4198	Economy	64400.00
0005434271308	4198	Economy	64400.00
0005435947163	4198	Economy	64400.00
0005432571307	4198	Economy	64400.00
0005435947226	4198	Economy	64400.00
0005435947160	4198	Economy	64400.00
0005432571293	4198	Economy	64400.00
0005435947215	4198	Economy	64400.00
0005432571298	4198	Economy	64400.00
0005435947227	4198	Economy	64400.00
0005435947214	4198	Economy	64400.00
0005432571301	4198	Economy	64400.00
0005432571292	4198	Economy	64400.00
0005434271298	4198	Economy	64400.00
0005435787335	4198	Economy	64400.00
0005435986798	4198	Economy	64400.00
0005435947169	4198	Economy	64400.00
0005435986795	4198	Economy	64400.00
0005435986794	4198	Economy	64400.00
0005435986796	4198	Economy	64400.00
0005432184962	4198	Economy	64400.00
0005435947322	26563	Business	193100.00
0005432571339	26563	Business	193100.00
0005435856222	26563	Economy	64400.00
0005435856221	26563	Economy	64400.00
0005435947313	26563	Economy	64400.00
0005435856223	26563	Economy	64400.00
0005435947317	26563	Economy	64400.00
0005435947316	26563	Economy	64400.00
0005435947320	26563	Economy	64400.00
0005435947315	26563	Economy	64400.00
0005435947314	26563	Economy	64400.00
0005435856220	26563	Economy	64400.00
0005435947310	26563	Economy	64400.00
0005435947312	26563	Economy	64400.00
0005435947318	26563	Economy	64400.00
0005432571338	26563	Economy	64400.00
0005435947309	26563	Economy	64400.00
0005435947319	26563	Economy	64400.00
0005435947323	26563	Economy	64400.00
0005432571341	26563	Economy	64400.00
0005435947311	26563	Economy	64400.00
0005435947321	26563	Economy	64400.00
0005435787365	26563	Economy	64400.00
0005432571340	26563	Economy	64400.00
0005433569324	346	Business	21500.00
0005432948169	346	Business	21500.00
0005433569343	346	Business	21500.00
0005433569314	346	Business	21500.00
0005433569353	346	Business	21500.00
0005433569307	346	Business	21500.00
0005432948335	346	Business	21500.00
0005432948228	346	Business	21500.00
0005433569358	346	Business	21500.00
0005433074627	346	Business	21500.00
0005433569356	346	Business	21500.00
0005433569317	346	Business	21500.00
0005433074706	346	Business	21500.00
0005433569347	346	Business	21500.00
0005433074707	346	Business	21500.00
0005433074638	346	Business	21500.00
0005433074592	346	Business	21500.00
0005433129253	346	Business	21500.00
0005432948290	346	Business	21500.00
0005432238964	346	Business	21500.00
0005432948150	346	Business	21500.00
0005433074414	346	Business	21500.00
0005433569338	346	Business	21500.00
0005433074637	346	Business	21500.00
0005433569329	346	Business	21500.00
0005433074449	346	Economy	7900.00
0005433569344	346	Economy	7900.00
0005433074450	346	Economy	7900.00
0005433569334	346	Economy	7900.00
0005433074458	346	Economy	7200.00
0005432948285	346	Economy	7200.00
0005432948167	346	Economy	7200.00
0005432238959	346	Economy	7200.00
0005433569354	346	Economy	7200.00
0005433569348	346	Economy	7200.00
0005433074587	346	Economy	7200.00
0005433074673	346	Economy	7200.00
0005433569332	346	Economy	7200.00
0005432948453	346	Economy	7200.00
0005432948174	346	Economy	7200.00
0005433569316	346	Economy	7200.00
0005433074554	346	Economy	7200.00
0005432948226	346	Economy	7200.00
0005433134106	346	Economy	7200.00
0005433074660	346	Economy	7200.00
0005432948347	346	Economy	7200.00
0005433569359	346	Economy	7200.00
0005433074464	346	Economy	7200.00
0005433074456	346	Economy	7200.00
0005433074459	346	Economy	7200.00
0005432948452	346	Economy	7200.00
0005433569315	346	Economy	7200.00
0005433569318	346	Economy	7200.00
0005433569350	346	Economy	7200.00
0005432948173	346	Economy	7200.00
0005432948168	346	Economy	7200.00
0005433569330	346	Economy	7200.00
0005433129252	346	Economy	7200.00
0005433569333	346	Economy	7200.00
0005432238961	346	Economy	7200.00
0005433569339	346	Economy	7200.00
0005432948220	346	Economy	7200.00
0005432948315	346	Economy	7200.00
0005432948229	346	Economy	7200.00
0005432948219	346	Economy	7200.00
0005433569349	346	Economy	7200.00
0005433569312	346	Economy	7200.00
0005433569319	346	Economy	7200.00
0005433074511	346	Economy	7200.00
0005433569335	346	Economy	7200.00
0005433074470	346	Economy	7200.00
0005432948165	346	Economy	7200.00
0005432948144	346	Economy	7200.00
0005433569355	346	Economy	7200.00
0005433074578	346	Economy	7200.00
0005433569311	346	Economy	7200.00
0005433569313	346	Economy	7200.00
0005432948204	346	Economy	7200.00
0005433074403	346	Economy	7200.00
0005433074597	346	Economy	7200.00
0005432948271	346	Economy	7200.00
0005432948370	346	Economy	7200.00
0005433569304	346	Economy	7200.00
0005433074652	346	Economy	7200.00
0005433569323	346	Economy	7900.00
0005433134103	346	Economy	7900.00
0005433569322	346	Economy	7900.00
0005433074457	346	Economy	7900.00
0005433569357	346	Economy	7200.00
0005433074692	346	Economy	7200.00
0005433074552	346	Economy	7200.00
0005432238962	346	Economy	7200.00
0005433074448	346	Economy	7900.00
0005433569346	346	Economy	7200.00
0005433569306	346	Economy	7200.00
0005433569305	346	Economy	7200.00
0005433074551	346	Economy	7200.00
0005432948269	346	Economy	7200.00
0005433569309	346	Economy	7200.00
0005432948099	346	Economy	7200.00
0005433569320	346	Economy	7200.00
0005433569345	346	Economy	7200.00
0005432948170	346	Economy	7200.00
0005433569325	346	Economy	7200.00
0005433569340	346	Economy	7200.00
0005433134113	346	Economy	7200.00
0005432948151	346	Economy	7200.00
0005433569301	346	Economy	7200.00
0005433569331	346	Economy	7200.00
0005433569300	346	Economy	7200.00
0005432948372	346	Economy	7200.00
0005433074651	346	Economy	7200.00
0005433074469	346	Economy	7200.00
0005432948263	346	Economy	7200.00
0005432948383	346	Economy	7200.00
0005433074626	346	Economy	7200.00
0005433569321	346	Economy	7200.00
0005433074718	346	Economy	7200.00
0005432948205	346	Economy	7200.00
0005433074486	346	Economy	7200.00
0005432238960	346	Economy	7200.00
0005432948237	346	Economy	7200.00
0005433074598	346	Economy	7200.00
0005433074687	346	Economy	7200.00
0005433569336	346	Economy	7200.00
0005432948236	346	Economy	7200.00
0005433569342	346	Economy	7200.00
0005433074708	346	Economy	7200.00
0005433569302	346	Economy	7200.00
0005433569341	346	Economy	7200.00
0005433074485	346	Economy	7200.00
0005432948166	346	Economy	7200.00
0005433569303	346	Economy	7200.00
0005432948130	346	Economy	7200.00
0005433074610	346	Economy	7200.00
0005433569351	346	Economy	7200.00
0005433569328	346	Economy	7200.00
0005433074426	346	Economy	7200.00
0005433569337	346	Economy	7200.00
0005433569310	346	Economy	7200.00
0005432948227	346	Economy	7200.00
0005432948314	346	Economy	7200.00
0005433074661	346	Economy	7200.00
0005433074563	346	Economy	7200.00
0005433569352	346	Economy	7200.00
0005433569326	346	Economy	7200.00
0005433569327	346	Economy	7200.00
0005432238963	346	Economy	7200.00
0005432948291	346	Economy	7200.00
0005432948273	346	Economy	7200.00
0005433569308	346	Economy	7200.00
0005432948609	11577	Business	21500.00
0005432948601	11577	Business	21500.00
0005433568624	11577	Business	21500.00
0005433074830	11577	Business	21500.00
0005432948634	11577	Business	21500.00
0005432948608	11577	Business	21500.00
0005433568473	11577	Business	21500.00
0005433568649	11577	Business	21500.00
0005432948605	11577	Business	21500.00
0005432192331	11577	Business	21500.00
0005433074818	11577	Business	21500.00
0005432948623	11577	Business	21500.00
0005433074819	11577	Business	21500.00
0005433074827	11577	Business	21500.00
0005433568633	11577	Business	21500.00
0005433568727	11577	Business	21500.00
0005433568600	11577	Business	21500.00
0005432948627	11577	Business	21500.00
0005433568567	11577	Business	21500.00
0005433568611	11577	Business	21500.00
0005432948618	11577	Business	21500.00
0005433568506	11577	Business	21500.00
0005433568687	11577	Business	21500.00
0005433568482	11577	Business	21500.00
0005432948635	11577	Business	21500.00
0005433568574	11577	Economy	7900.00
0005433568726	11577	Economy	7900.00
0005433568766	11577	Economy	7900.00
0005433074837	11577	Economy	7900.00
0005433074822	11577	Economy	7200.00
0005433568428	11577	Economy	7200.00
0005433568676	11577	Economy	7200.00
0005433568721	11577	Economy	7200.00
0005433568731	11577	Economy	7200.00
0005433568707	11577	Economy	7200.00
0005433568746	11577	Economy	7200.00
0005432948626	11577	Economy	7200.00
0005433568581	11577	Economy	7200.00
0005433074834	11577	Economy	7200.00
0005433131725	11577	Economy	7200.00
0005433134157	11577	Economy	7200.00
0005433568734	11577	Economy	7200.00
0005433568566	11577	Economy	7200.00
0005433568736	11577	Economy	7200.00
0005433074833	11577	Economy	7200.00
0005433074809	11577	Economy	7200.00
0005433074817	11577	Economy	7200.00
0005432948602	11577	Economy	7200.00
0005433568583	11577	Economy	7200.00
0005433568541	11577	Economy	7200.00
0005433568718	11577	Economy	7200.00
0005433568780	11577	Economy	7200.00
0005433134158	11577	Economy	7200.00
0005433131728	11577	Economy	7200.00
0005433568685	11577	Economy	7200.00
0005433568667	11577	Economy	7200.00
0005432948617	11577	Economy	7200.00
0005432948624	11577	Economy	7200.00
0005432948604	11577	Economy	7200.00
0005433074836	11577	Economy	7200.00
0005433074815	11577	Economy	7200.00
0005432948638	11577	Economy	7200.00
0005433568540	11577	Economy	7200.00
0005433568392	11577	Economy	7200.00
0005433074835	11577	Economy	7200.00
0005432948598	11577	Economy	7200.00
0005433568759	11577	Economy	7200.00
0005433568725	11577	Economy	7200.00
0005433568632	11577	Economy	7200.00
0005433568547	11577	Economy	7200.00
0005432948637	11577	Economy	7200.00
0005432948630	11577	Economy	7200.00
0005433074813	11577	Economy	7200.00
0005433568618	11577	Economy	7200.00
0005432948631	11577	Economy	7200.00
0005432948619	11577	Economy	7200.00
0005433074826	11577	Economy	7200.00
0005433568481	11577	Economy	7200.00
0005433568691	11577	Economy	7200.00
0005432948614	11577	Economy	7200.00
0005433074829	11577	Economy	7200.00
0005433131727	11577	Economy	7200.00
0005432948639	11577	Economy	7900.00
0005433568619	11577	Economy	7900.00
0005433074811	11577	Economy	7900.00
0005432948611	11577	Economy	7900.00
0005432948607	11577	Economy	7200.00
0005433568657	11577	Economy	7200.00
0005433568705	11577	Economy	7200.00
0005433568805	11577	Economy	7900.00
0005432948603	11577	Economy	7200.00
0005433568647	11577	Economy	7200.00
0005432948606	11577	Economy	7200.00
0005432948600	11577	Economy	7200.00
0005432948599	11577	Economy	7200.00
0005433074820	11577	Economy	7200.00
0005432192333	11577	Economy	7200.00
0005432948625	11577	Economy	7200.00
0005432948613	11577	Economy	7200.00
0005432948622	11577	Economy	7200.00
0005433568505	11577	Economy	7200.00
0005433074816	11577	Economy	7200.00
0005433568784	11577	Economy	7200.00
0005433134156	11577	Economy	7200.00
0005433568565	11577	Economy	7200.00
0005432948629	11577	Economy	7200.00
0005433074831	11577	Economy	7200.00
0005433074824	11577	Economy	7200.00
0005432192332	11577	Economy	7200.00
0005433568769	11577	Economy	7200.00
0005433074812	11577	Economy	7200.00
0005433568730	11577	Economy	7200.00
0005433074823	11577	Economy	7200.00
0005433568699	11577	Economy	7200.00
0005433568621	11577	Economy	7200.00
0005433568634	11577	Economy	7200.00
0005433131726	11577	Economy	7200.00
0005432948633	11577	Economy	7200.00
0005433568749	11577	Economy	7200.00
0005433568706	11577	Economy	7200.00
0005433568735	11577	Economy	7200.00
0005432948612	11577	Economy	7200.00
0005433568568	11577	Economy	7200.00
0005433568620	11577	Economy	7200.00
0005433568703	11577	Economy	7200.00
0005432948610	11577	Economy	7200.00
0005433074828	11577	Economy	7200.00
0005432948615	11577	Economy	7200.00
0005433074821	11577	Economy	7200.00
0005432948616	11577	Economy	7200.00
0005433568648	11577	Economy	7200.00
0005433074814	11577	Economy	7200.00
0005433568460	11577	Economy	7200.00
0005433568650	11577	Economy	7200.00
0005432948621	11577	Economy	7200.00
0005433134155	11577	Economy	7200.00
0005433568664	11577	Economy	7200.00
0005433074832	11577	Economy	7200.00
0005432192334	11577	Economy	7200.00
0005432948636	11577	Economy	7200.00
0005433074810	11577	Economy	7200.00
0005432948632	11577	Economy	7200.00
0005432948628	11577	Economy	7200.00
0005433568737	11577	Economy	7200.00
0005433568758	11577	Economy	7200.00
0005433074825	11577	Economy	7200.00
0005433568733	11577	Economy	7200.00
0005433568635	11577	Economy	7200.00
0005432948620	11577	Economy	7200.00
0005433568781	11577	Economy	7200.00
0005434732975	10002	Economy	6300.00
0005434732976	10002	Economy	6300.00
0005433817485	10002	Economy	6300.00
0005433817487	10002	Economy	6300.00
0005433817486	10002	Economy	6300.00
0005433817446	13960	Economy	6300.00
0005434732994	13960	Economy	6300.00
0005433817439	13960	Economy	6300.00
0005433817438	13960	Economy	6300.00
0005434732995	13960	Economy	6300.00
0005433817447	13960	Economy	6300.00
0005434732996	13960	Economy	6300.00
0005432984786	2373	Business	184500.00
0005432655583	2373	Business	184500.00
0005433754443	2373	Business	184500.00
0005435982502	2373	Business	184500.00
0005435982494	2373	Business	184500.00
0005435982504	2373	Business	184500.00
0005435982487	2373	Business	184500.00
0005432984797	2373	Business	184500.00
0005433434667	2373	Business	184500.00
0005433754457	2373	Business	184500.00
0005433754456	2373	Business	184500.00
0005432984991	2373	Business	184500.00
0005433754480	2373	Business	184500.00
0005435982491	2373	Business	184500.00
0005432984911	2373	Business	184500.00
0005433434492	2373	Business	184500.00
0005435982520	2373	Business	184500.00
0005433754477	2373	Business	184500.00
0005435982498	2373	Business	184500.00
0005432226084	2373	Business	184500.00
0005432226086	2373	Business	184500.00
0005433434607	2373	Business	184500.00
0005432984857	2373	Business	184500.00
0005432300288	2373	Business	184500.00
0005432655588	2373	Business	184500.00
0005435982509	2373	Business	184500.00
0005432984908	2373	Business	184500.00
0005432226082	2373	Business	184500.00
0005435982510	2373	Economy	67700.00
0005435982519	2373	Economy	67700.00
0005435982515	2373	Economy	67700.00
0005433434515	2373	Economy	67700.00
0005433754449	2373	Economy	61500.00
0005432655585	2373	Economy	61500.00
0005435982526	2373	Economy	61500.00
0005432984837	2373	Economy	61500.00
0005433434568	2373	Economy	61500.00
0005433754482	2373	Economy	61500.00
0005432984997	2373	Economy	61500.00
0005432984947	2373	Economy	61500.00
0005432984942	2373	Economy	61500.00
0005435982512	2373	Economy	61500.00
0005433754452	2373	Economy	61500.00
0005432300290	2373	Economy	61500.00
0005433754473	2373	Economy	61500.00
0005433434591	2373	Economy	61500.00
0005432226080	2373	Economy	61500.00
0005435982486	2373	Economy	61500.00
0005433754442	2373	Economy	61500.00
0005435982499	2373	Economy	61500.00
0005433754454	2373	Economy	61500.00
0005432984965	2373	Economy	61500.00
0005433754437	2373	Economy	61500.00
0005433434499	2373	Economy	61500.00
0005435982493	2373	Economy	61500.00
0005433434480	2373	Economy	61500.00
0005433434518	2373	Economy	61500.00
0005433754466	2373	Economy	61500.00
0005432226083	2373	Economy	61500.00
0005433754433	2373	Economy	61500.00
0005433754458	2373	Economy	61500.00
0005433754475	2373	Economy	61500.00
0005433754469	2373	Economy	61500.00
0005433754474	2373	Economy	61500.00
0005433434606	2373	Economy	61500.00
0005432984856	2373	Economy	61500.00
0005432655594	2373	Economy	61500.00
0005433754462	2373	Economy	61500.00
0005433754434	2373	Economy	61500.00
0005435982489	2373	Economy	61500.00
0005432984798	2373	Economy	61500.00
0005435982503	2373	Economy	61500.00
0005432984955	2373	Economy	61500.00
0005432984847	2373	Economy	61500.00
0005432655584	2373	Economy	61500.00
0005435982485	2373	Economy	61500.00
0005433754476	2373	Economy	61500.00
0005433434566	2373	Economy	61500.00
0005433766657	2373	Economy	61500.00
0005432984954	2373	Economy	61500.00
0005433434498	2373	Economy	61500.00
0005432984981	2373	Economy	61500.00
0005433754439	2373	Economy	61500.00
0005433754432	2373	Economy	61500.00
0005435982492	2373	Economy	61500.00
0005435982501	2373	Economy	61500.00
0005435982522	2373	Economy	61500.00
0005433434625	2373	Economy	61500.00
0005432984933	2373	Economy	61500.00
0005432984838	2373	Economy	61500.00
0005435982511	2373	Economy	61500.00
0005432985061	2373	Economy	61500.00
0005433766658	2373	Economy	61500.00
0005432984868	2373	Economy	61500.00
0005433754448	2373	Economy	61500.00
0005433754444	2373	Economy	61500.00
0005433754438	2373	Economy	61500.00
0005432984996	2373	Economy	61500.00
0005433754441	2373	Economy	61500.00
0005432300289	2373	Economy	61500.00
0005432984982	2373	Economy	61500.00
0005432655591	2373	Economy	61500.00
0005433766656	2373	Economy	61500.00
0005435982523	2373	Economy	61500.00
0005433754459	2373	Economy	61500.00
0005432984912	2373	Economy	61500.00
0005435982524	2373	Economy	61500.00
0005433764688	2373	Economy	61500.00
0005433434559	2373	Economy	61500.00
0005432984929	2373	Economy	61500.00
0005433434514	2373	Economy	61500.00
0005433434565	2373	Economy	61500.00
0005433754464	2373	Economy	61500.00
0005433754484	2373	Economy	61500.00
0005433434564	2373	Economy	61500.00
0005432226081	2373	Economy	61500.00
0005432300286	2373	Economy	61500.00
0005435982517	2373	Economy	61500.00
0005432984968	2373	Economy	61500.00
0005432300287	2373	Economy	61500.00
0005433766655	2373	Economy	61500.00
0005432984990	2373	Economy	61500.00
0005433754430	2373	Economy	61500.00
0005432300285	2373	Economy	61500.00
0005435982516	2373	Economy	61500.00
0005433754471	2373	Economy	67700.00
0005432655592	2373	Economy	61500.00
0005433754460	2373	Economy	61500.00
0005433754479	2373	Economy	67700.00
0005432984898	2373	Economy	61500.00
0005433434589	2373	Economy	67700.00
0005433766654	2373	Economy	61500.00
0005432655590	2373	Economy	61500.00
0005433754440	2373	Economy	61500.00
0005433434524	2373	Economy	61500.00
0005433754470	2373	Economy	61500.00
0005433434588	2373	Economy	61500.00
0005433754451	2373	Economy	61500.00
0005432869481	2373	Economy	61500.00
0005432984880	2373	Economy	61500.00
0005433754453	2373	Economy	61500.00
0005433754447	2373	Economy	61500.00
0005433434626	2373	Economy	61500.00
0005435982505	2373	Economy	61500.00
0005433754431	2373	Economy	61500.00
0005432984948	2373	Economy	61500.00
0005432984879	2373	Economy	61500.00
0005435982496	2373	Economy	61500.00
0005432984897	2373	Economy	61500.00
0005433754472	2373	Economy	61500.00
0005432226085	2373	Economy	61500.00
0005433754435	2373	Economy	61500.00
0005433754467	2373	Economy	61500.00
0005432655589	2373	Economy	61500.00
0005435982514	2373	Economy	61500.00
0005432655586	2373	Economy	61500.00
0005433754468	2373	Economy	61500.00
0005435982506	2373	Economy	61500.00
0005433754455	2373	Economy	61500.00
0005433754478	2373	Economy	61500.00
0005435982490	2373	Economy	61500.00
0005432984869	2373	Economy	61500.00
0005435982525	2373	Economy	61500.00
0005435982488	2373	Economy	61500.00
0005433754450	2373	Economy	61500.00
0005433754463	2373	Economy	61500.00
0005433754486	2373	Economy	61500.00
0005433434523	2373	Economy	61500.00
0005432984989	2373	Economy	61500.00
0005433754481	2373	Economy	61500.00
0005435982508	2373	Economy	61500.00
0005435982513	2373	Economy	61500.00
0005433754485	2373	Economy	61500.00
0005432984928	2373	Economy	61500.00
0005432655587	2373	Economy	61500.00
0005435982521	2373	Economy	61500.00
0005435982507	2373	Economy	61500.00
0005433754446	2373	Economy	61500.00
0005432655593	2373	Economy	61500.00
0005432984983	2373	Economy	61500.00
0005433754445	2373	Economy	61500.00
0005433434590	2373	Economy	61500.00
0005433434592	2373	Economy	61500.00
0005435982500	2373	Economy	61500.00
0005433754483	2373	Economy	61500.00
0005432984934	2373	Economy	61500.00
0005433434593	2373	Economy	61500.00
0005432984967	2373	Economy	61500.00
0005433434458	2373	Economy	61500.00
0005433434479	2373	Economy	61500.00
0005432985107	2373	Economy	61500.00
0005433754465	2373	Economy	61500.00
0005433434567	2373	Economy	61500.00
0005435982495	2373	Economy	61500.00
0005435982497	2373	Economy	61500.00
0005433754436	2373	Economy	61500.00
0005433754461	2373	Economy	61500.00
0005432984913	2373	Economy	61500.00
0005432984896	2373	Economy	61500.00
0005432984941	2373	Economy	61500.00
0005433434497	2373	Economy	61500.00
0005435982518	2373	Economy	61500.00
0005433434576	2373	Economy	61500.00
0005433753863	26178	Business	184500.00
0005433753960	26178	Business	184500.00
0005432985227	26178	Business	184500.00
0005433754172	26178	Business	184500.00
0005432985214	26178	Business	184500.00
0005432985206	26178	Business	184500.00
0005435982264	26178	Business	184500.00
0005433753925	26178	Business	184500.00
0005432985199	26178	Business	184500.00
0005432985202	26178	Business	184500.00
0005433764675	26178	Business	184500.00
0005432985217	26178	Business	184500.00
0005433754078	26178	Business	184500.00
0005435982025	26178	Business	184500.00
0005433753989	26178	Business	184500.00
0005435981915	26178	Business	184500.00
0005435982176	26178	Business	184500.00
0005435981982	26178	Business	184500.00
0005432985226	26178	Business	184500.00
0005435982177	26178	Business	184500.00
0005435982083	26178	Business	184500.00
0005435981862	26178	Business	184500.00
0005433754059	26178	Business	184500.00
0005433753717	26178	Business	184500.00
0005432051142	26178	Business	184500.00
0005432985220	26178	Economy	67700.00
0005432655480	26178	Economy	67700.00
0005433753847	26178	Economy	67700.00
0005433754075	26178	Economy	61500.00
0005435981964	26178	Economy	61500.00
0005432869549	26178	Economy	61500.00
0005433434794	26178	Economy	61500.00
0005433753815	26178	Economy	61500.00
0005433753949	26178	Economy	61500.00
0005433754072	26178	Economy	61500.00
0005432985211	26178	Economy	61500.00
0005435981950	26178	Economy	61500.00
0005433753921	26178	Economy	61500.00
0005433754118	26178	Economy	61500.00
0005433753928	26178	Economy	61500.00
0005432985210	26178	Economy	61500.00
0005433754197	26178	Economy	61500.00
0005432655421	26178	Economy	61500.00
0005435981772	26178	Economy	61500.00
0005433766624	26178	Economy	61500.00
0005433434808	26178	Economy	61500.00
0005432049482	26178	Economy	61500.00
0005433753805	26178	Economy	61500.00
0005435982265	26178	Economy	61500.00
0005435982085	26178	Economy	61500.00
0005433434799	26178	Economy	61500.00
0005433753719	26178	Economy	61500.00
0005433434812	26178	Economy	61500.00
0005433764679	26178	Economy	61500.00
0005435982112	26178	Economy	61500.00
0005435982128	26178	Economy	61500.00
0005435982140	26178	Economy	61500.00
0005433753929	26178	Economy	61500.00
0005433754117	26178	Economy	61500.00
0005433754091	26178	Economy	61500.00
0005433753848	26178	Economy	61500.00
0005435981989	26178	Economy	61500.00
0005435982301	26178	Economy	61500.00
0005433754061	26178	Economy	61500.00
0005433753964	26178	Economy	61500.00
0005432869547	26178	Economy	61500.00
0005432985224	26178	Economy	61500.00
0005432985218	26178	Economy	61500.00
0005432985209	26178	Economy	61500.00
0005433754028	26178	Economy	61500.00
0005435982072	26178	Economy	61500.00
0005433754097	26178	Economy	61500.00
0005433753930	26178	Economy	61500.00
0005433434804	26178	Economy	61500.00
0005432985216	26178	Economy	61500.00
0005432049478	26178	Economy	61500.00
0005433434798	26178	Economy	61500.00
0005433434792	26178	Economy	61500.00
0005433434806	26178	Economy	61500.00
0005432869548	26178	Economy	61500.00
0005432985213	26178	Economy	61500.00
0005433434810	26178	Economy	61500.00
0005433753718	26178	Economy	61500.00
0005435982079	26178	Economy	61500.00
0005435982013	26178	Economy	61500.00
0005432655453	26178	Economy	61500.00
0005433753997	26178	Economy	61500.00
0005432869550	26178	Economy	61500.00
0005433754090	26178	Economy	61500.00
0005432655479	26178	Economy	61500.00
0005435982068	26178	Economy	61500.00
0005433753898	26178	Economy	61500.00
0005432985198	26178	Economy	61500.00
0005435982082	26178	Economy	61500.00
0005433434811	26178	Economy	61500.00
0005435982022	26178	Economy	61500.00
0005432985219	26178	Economy	61500.00
0005433434790	26178	Economy	61500.00
0005435981863	26178	Economy	61500.00
0005433754096	26178	Economy	61500.00
0005435981935	26178	Economy	61500.00
0005432049479	26178	Economy	61500.00
0005433753864	26178	Economy	61500.00
0005432985215	26178	Economy	61500.00
0005433754045	26178	Economy	61500.00
0005435982300	26178	Economy	61500.00
0005433434795	26178	Economy	61500.00
0005432985201	26178	Economy	61500.00
0005433434788	26178	Economy	61500.00
0005434731189	26178	Economy	61500.00
0005434731190	26178	Economy	61500.00
0005433753966	26178	Economy	61500.00
0005432051140	26178	Economy	61500.00
0005432985212	26178	Economy	61500.00
0005435982033	26178	Economy	61500.00
0005432869552	26178	Economy	61500.00
0005435982048	26178	Economy	61500.00
0005432049477	26178	Economy	61500.00
0005433753816	26178	Economy	61500.00
0005433434784	26178	Economy	61500.00
0005433434805	26178	Economy	61500.00
0005433754077	26178	Economy	61500.00
0005432869546	26178	Economy	67700.00
0005433754099	26178	Economy	67700.00
0005433753934	26178	Economy	61500.00
0005432985228	26178	Economy	61500.00
0005433754067	26178	Economy	61500.00
0005435982017	26178	Economy	67700.00
0005435982097	26178	Economy	61500.00
0005433753994	26178	Economy	61500.00
0005433434802	26178	Economy	61500.00
0005432985222	26178	Economy	61500.00
0005432051141	26178	Economy	61500.00
0005433764678	26178	Economy	61500.00
0005433753996	26178	Economy	61500.00
0005433754035	26178	Economy	61500.00
0005432985221	26178	Economy	61500.00
0005433753817	26178	Economy	61500.00
0005433766629	26178	Economy	61500.00
0005433754006	26178	Economy	61500.00
0005432655445	26178	Economy	61500.00
0005433434796	26178	Economy	61500.00
0005432049480	26178	Economy	61500.00
0005432985225	26178	Economy	61500.00
0005433754062	26178	Economy	61500.00
0005433753639	26178	Economy	61500.00
0005432655387	26178	Economy	61500.00
0005433754200	26178	Economy	61500.00
0005433754088	26178	Economy	61500.00
0005433753933	26178	Economy	61500.00
0005433754060	26178	Economy	61500.00
0005433434786	26178	Economy	61500.00
0005433434793	26178	Economy	61500.00
0005435981864	26178	Economy	61500.00
0005435982045	26178	Economy	61500.00
0005435982111	26178	Economy	61500.00
0005433753716	26178	Economy	61500.00
0005435982031	26178	Economy	61500.00
0005434731187	26178	Economy	61500.00
0005435982306	26178	Economy	61500.00
0005433434787	26178	Economy	61500.00
0005435982373	26178	Economy	61500.00
0005432869551	26178	Economy	61500.00
0005435981978	26178	Economy	61500.00
0005433754089	26178	Economy	61500.00
0005435982069	26178	Economy	61500.00
0005435982305	26178	Economy	61500.00
0005433753887	26178	Economy	61500.00
0005435981865	26178	Economy	61500.00
0005433434800	26178	Economy	61500.00
0005433754029	26178	Economy	61500.00
0005433434801	26178	Economy	61500.00
0005432985203	26178	Economy	61500.00
0005432985204	26178	Economy	61500.00
0005432985229	26178	Economy	61500.00
0005432985223	26178	Economy	61500.00
0005433753935	26178	Economy	61500.00
0005432985207	26178	Economy	61500.00
0005434731188	26178	Economy	61500.00
0005432985208	26178	Economy	61500.00
0005435981977	26178	Economy	61500.00
0005433434797	26178	Economy	61500.00
0005432049481	26178	Economy	61500.00
0005433434807	26178	Economy	61500.00
0005435982032	26178	Economy	61500.00
0005433764674	26178	Economy	61500.00
0005433434809	26178	Economy	61500.00
0005435982024	26178	Economy	61500.00
0005433434791	26178	Economy	61500.00
0005432985200	26178	Economy	61500.00
0005435982021	26178	Economy	61500.00
0005433434785	26178	Economy	61500.00
0005433434789	26178	Economy	61500.00
0005433434803	26178	Economy	61500.00
0005432985205	26178	Economy	61500.00
0005433753963	26178	Economy	61500.00
0005433151195	1529	Business	38900.00
0005433151296	1529	Business	38900.00
0005432267925	1529	Business	38900.00
0005433764656	1529	Business	38900.00
0005433151280	1529	Business	38900.00
0005433151317	1529	Business	38900.00
0005434374836	1529	Business	38900.00
0005434029643	1529	Business	38900.00
0005433151316	1529	Business	38900.00
0005434374817	1529	Business	38900.00
0005433151384	1529	Business	38900.00
0005434029642	1529	Economy	13000.00
0005433151306	1529	Economy	13000.00
0005434374839	1529	Economy	13000.00
0005433151153	1529	Economy	13000.00
0005433151116	1529	Economy	13000.00
0005433151416	1529	Economy	13000.00
0005432267926	1529	Economy	13000.00
0005433151282	1529	Economy	13000.00
0005433764657	1529	Economy	13000.00
0005433151245	1529	Economy	13000.00
0005433151248	1529	Economy	13000.00
0005434029648	1529	Economy	13000.00
0005433151338	1529	Economy	13000.00
0005433151276	1529	Economy	13000.00
0005433151154	1529	Economy	13000.00
0005433460446	1529	Economy	13000.00
0005433151265	1529	Economy	13000.00
0005434029647	1529	Economy	13000.00
0005434374824	1529	Economy	13000.00
0005434374842	1529	Economy	13000.00
0005433931426	1529	Economy	13000.00
0005433461598	1529	Economy	13000.00
0005433151200	1529	Economy	13000.00
0005433151312	1529	Economy	13000.00
0005433151243	1529	Economy	13000.00
0005433151287	1529	Economy	13000.00
0005434374825	1529	Economy	13000.00
0005434029635	1529	Economy	13000.00
0005434374821	1529	Economy	13000.00
0005434374843	1529	Economy	13000.00
0005433151335	1529	Economy	13000.00
0005434374834	1529	Economy	13000.00
0005434374818	1529	Economy	13000.00
0005433931456	1529	Economy	13000.00
0005432267921	1529	Economy	13000.00
0005434374838	1529	Economy	13000.00
0005433151324	1529	Economy	14300.00
0005433151319	1529	Economy	14300.00
0005433151421	1529	Economy	14300.00
0005434374832	1529	Economy	13000.00
0005433151155	1529	Economy	14300.00
0005433151226	1529	Economy	13000.00
0005434374829	1529	Economy	13000.00
0005432267923	1529	Economy	13000.00
0005433151415	1529	Economy	13000.00
0005433460445	1529	Economy	13000.00
0005434374828	1529	Economy	13000.00
0005434374830	1529	Economy	13000.00
0005433151344	1529	Economy	13000.00
0005434374815	1529	Economy	13000.00
0005433151459	1529	Economy	13000.00
0005433151295	1529	Economy	13000.00
0005433931440	1529	Economy	13000.00
0005434374841	1529	Economy	13000.00
0005433151351	1529	Economy	13000.00
0005432267920	1529	Economy	13000.00
0005433151274	1529	Economy	13000.00
0005434374837	1529	Economy	13000.00
0005433151244	1529	Economy	13000.00
0005434374835	1529	Economy	13000.00
0005434029636	1529	Economy	13000.00
0005433151346	1529	Economy	13000.00
0005433931442	1529	Economy	13000.00
0005432267924	1529	Economy	13000.00
0005433151264	1529	Economy	13000.00
0005433151138	1529	Economy	13000.00
0005434029644	1529	Economy	13000.00
0005433151297	1529	Economy	13000.00
0005432267927	1529	Economy	13000.00
0005433151460	1529	Economy	13000.00
0005433151325	1529	Economy	13000.00
0005434374827	1529	Economy	13000.00
0005433151152	1529	Economy	13000.00
0005434374820	1529	Economy	13000.00
0005433460447	1529	Economy	13000.00
0005434374814	1529	Economy	13000.00
0005433151345	1529	Economy	13000.00
0005434374845	1529	Economy	13000.00
0005433151115	1529	Economy	13000.00
0005433151326	1529	Economy	13000.00
0005433931441	1529	Economy	13000.00
0005433151263	1529	Economy	13000.00
0005433151417	1529	Economy	13000.00
0005433151286	1529	Economy	13000.00
0005433461597	1529	Economy	13000.00
0005434374833	1529	Economy	13000.00
0005434374831	1529	Economy	13000.00
0005434374826	1529	Economy	13000.00
0005433151281	1529	Economy	13000.00
0005434374816	1529	Economy	13000.00
0005434374812	1529	Economy	13000.00
0005433151201	1529	Economy	13000.00
0005434374823	1529	Economy	13000.00
0005433151275	1529	Economy	13000.00
0005432267922	1529	Economy	13000.00
0005434374844	1529	Economy	13000.00
0005433151151	1529	Economy	13000.00
0005433151277	1529	Economy	13000.00
0005434374813	1529	Economy	13000.00
0005434374840	1529	Economy	13000.00
0005433151196	1529	Economy	13000.00
0005433151343	1529	Economy	13000.00
0005434374819	1529	Economy	13000.00
0005434374822	1529	Economy	13000.00
0005434374474	20119	Business	38900.00
0005433151549	20119	Business	38900.00
0005433151546	20119	Business	38900.00
0005433151566	20119	Business	38900.00
0005433151548	20119	Business	38900.00
0005433151547	20119	Economy	13000.00
0005434374587	20119	Economy	13000.00
0005434374627	20119	Economy	13000.00
0005433931476	20119	Economy	13000.00
0005433151551	20119	Economy	13000.00
0005434374466	20119	Economy	13000.00
0005434374599	20119	Economy	13000.00
0005434029667	20119	Economy	13000.00
0005434374510	20119	Economy	13000.00
0005433151538	20119	Economy	13000.00
0005434374321	20119	Economy	13000.00
0005433764688	20119	Economy	13000.00
0005433151552	20119	Economy	13000.00
0005434374570	20119	Economy	13000.00
0005433151567	20119	Economy	13000.00
0005434374407	20119	Economy	13000.00
0005433151542	20119	Economy	13000.00
0005433151545	20119	Economy	13000.00
0005434374464	20119	Economy	13000.00
0005434374564	20119	Economy	13000.00
0005433151543	20119	Economy	13000.00
0005433151557	20119	Economy	13000.00
0005433151536	20119	Economy	13000.00
0005434374406	20119	Economy	13000.00
0005434374505	20119	Economy	13000.00
0005434374344	20119	Economy	13000.00
0005433151532	20119	Economy	13000.00
0005434374555	20119	Economy	13000.00
0005434374443	20119	Economy	13000.00
0005434374315	20119	Economy	13000.00
0005434374457	20119	Economy	13000.00
0005433151555	20119	Economy	13000.00
0005434374465	20119	Economy	14300.00
0005432056316	20119	Economy	14300.00
0005434374444	20119	Economy	14300.00
0005432056313	20119	Economy	13000.00
0005433151535	20119	Economy	13000.00
0005434374552	20119	Economy	13000.00
0005434374405	20119	Economy	13000.00
0005433151541	20119	Economy	13000.00
0005433151559	20119	Economy	13000.00
0005434374610	20119	Economy	13000.00
0005434374523	20119	Economy	13000.00
0005432056314	20119	Economy	13000.00
0005434374345	20119	Economy	13000.00
0005433151563	20119	Economy	13000.00
0005433151554	20119	Economy	13000.00
0005433151544	20119	Economy	13000.00
0005434374565	20119	Economy	13000.00
0005434374456	20119	Economy	13000.00
0005434374322	20119	Economy	13000.00
0005433931475	20119	Economy	13000.00
0005434374374	20119	Economy	13000.00
0005433151562	20119	Economy	13000.00
0005433151533	20119	Economy	13000.00
0005434374542	20119	Economy	13000.00
0005434374581	20119	Economy	13000.00
0005433151540	20119	Economy	13000.00
0005433151560	20119	Economy	13000.00
0005434374450	20119	Economy	13000.00
0005433151565	20119	Economy	13000.00
0005434374511	20119	Economy	13000.00
0005433151556	20119	Economy	13000.00
0005434374334	20119	Economy	13000.00
0005433931477	20119	Economy	13000.00
0005434374316	20119	Economy	13000.00
0005433151534	20119	Economy	13000.00
0005433151564	20119	Economy	13000.00
0005434374477	20119	Economy	13000.00
0005433151550	20119	Economy	13000.00
0005434374478	20119	Economy	13000.00
0005433151558	20119	Economy	13000.00
0005434374566	20119	Economy	13000.00
0005433151561	20119	Economy	13000.00
0005434374522	20119	Economy	13000.00
0005434374475	20119	Economy	13000.00
0005434374323	20119	Economy	13000.00
0005434374571	20119	Economy	13000.00
0005434374298	20119	Economy	13000.00
0005433151537	20119	Economy	13000.00
0005434374441	20119	Economy	13000.00
0005432056315	20119	Economy	13000.00
0005433151553	20119	Economy	13000.00
0005434374259	20119	Economy	13000.00
0005434374473	20119	Economy	13000.00
0005434029668	20119	Economy	13000.00
0005433151539	20119	Economy	13000.00
0005434374553	20119	Economy	13000.00
0005434374479	20119	Economy	13000.00
0005432424617	513	Business	27500.00
0005432424667	513	Business	27500.00
0005432424665	513	Business	27500.00
0005432424651	513	Business	27500.00
0005432424619	513	Business	27500.00
0005432424633	513	Business	27500.00
0005432424636	513	Business	27500.00
0005432424628	513	Business	27500.00
0005432282897	513	Business	27500.00
0005432282895	513	Business	27500.00
0005432424621	513	Business	27500.00
0005432424666	513	Economy	10100.00
0005432424629	513	Economy	10100.00
0005432424610	513	Economy	9200.00
0005432424650	513	Economy	9200.00
0005432424638	513	Economy	9200.00
0005432424611	513	Economy	9200.00
0005432424626	513	Economy	9200.00
0005432424657	513	Economy	9200.00
0005432424632	513	Economy	9200.00
0005432424654	513	Economy	9200.00
0005432282893	513	Economy	9200.00
0005432424645	513	Economy	9200.00
0005432424659	513	Economy	9200.00
0005432424656	513	Economy	9200.00
0005432424643	513	Economy	9200.00
0005432424655	513	Economy	9200.00
0005432424613	513	Economy	9200.00
0005432424634	513	Economy	9200.00
0005432282894	513	Economy	9200.00
0005432424612	513	Economy	10100.00
0005432282892	513	Economy	10100.00
0005432424616	513	Economy	10100.00
0005432424631	513	Economy	9200.00
0005432424618	513	Economy	9200.00
0005432424658	513	Economy	9200.00
0005432424661	513	Economy	9200.00
0005432424623	513	Economy	9200.00
0005432424660	513	Economy	9200.00
0005432424614	513	Economy	9200.00
0005432424622	513	Economy	9200.00
0005432424627	513	Economy	9200.00
0005432424664	513	Economy	9200.00
0005432424640	513	Economy	9200.00
0005432424639	513	Economy	9200.00
0005432424620	513	Economy	9200.00
0005432424624	513	Economy	9200.00
0005432424648	513	Economy	9200.00
0005432424663	513	Economy	9200.00
0005432424625	513	Economy	9200.00
0005432424649	513	Economy	9200.00
0005432424637	513	Economy	9200.00
0005432424646	513	Economy	9200.00
0005432424630	513	Economy	9200.00
0005432424644	513	Economy	9200.00
0005432424653	513	Economy	9200.00
0005432424642	513	Economy	9200.00
0005432424641	513	Economy	9200.00
0005432282896	513	Economy	9200.00
0005432424635	513	Economy	9200.00
0005432424662	513	Economy	9200.00
0005432424615	513	Economy	9200.00
0005432424647	513	Economy	9200.00
0005432424652	513	Economy	9200.00
0005434446503	12891	Business	27500.00
0005434446504	12891	Business	27500.00
0005432302346	12891	Business	27500.00
0005433158140	12891	Economy	9200.00
0005433158141	12891	Economy	9200.00
0005434446498	12891	Economy	9200.00
0005433158139	12891	Economy	9200.00
0005434446505	12891	Economy	9200.00
0005434446506	12891	Economy	9200.00
0005433158137	12891	Economy	10100.00
0005433158136	12891	Economy	9200.00
0005434446511	12891	Economy	9200.00
0005432302348	12891	Economy	9200.00
0005434446513	12891	Economy	9200.00
0005432302345	12891	Economy	9200.00
0005432302347	12891	Economy	9200.00
0005434446512	12891	Economy	9200.00
0005433158138	12891	Economy	9200.00
0005432424178	12936	Business	27500.00
0005432424225	12936	Business	27500.00
0005432424201	12936	Business	27500.00
0005432424172	12936	Business	27500.00
0005432424207	12936	Business	27500.00
0005432424128	12936	Business	27500.00
0005432424210	12936	Business	27500.00
0005432424147	12936	Economy	10100.00
0005432424114	12936	Economy	9200.00
0005432424170	12936	Economy	9200.00
0005432424218	12936	Economy	9200.00
0005432424214	12936	Economy	9200.00
0005432424191	12936	Economy	9200.00
0005432424224	12936	Economy	9200.00
0005432424230	12936	Economy	9200.00
0005432424136	12936	Economy	9200.00
0005432424162	12936	Economy	9200.00
0005432424167	12936	Economy	9200.00
0005432424228	12936	Economy	9200.00
0005432424204	12936	Economy	10100.00
0005432424153	12936	Economy	9200.00
0005432424219	12936	Economy	10100.00
0005432424203	12936	Economy	9200.00
0005432424213	12936	Economy	9200.00
0005432424166	12936	Economy	9200.00
0005432424175	12936	Economy	9200.00
0005432424173	12936	Economy	9200.00
0005432424174	12936	Economy	9200.00
0005432424209	12936	Economy	9200.00
0005432424198	12936	Economy	9200.00
0005432423984	12936	Economy	9200.00
0005432424014	12936	Economy	9200.00
0005432424229	12936	Economy	9200.00
0005432424188	12936	Economy	9200.00
0005432424184	12936	Economy	9200.00
0005432424148	12936	Economy	9200.00
0005432424137	12936	Economy	9200.00
0005432424171	12936	Economy	9200.00
0005432424205	12936	Economy	9200.00
0005432424127	12936	Economy	9200.00
0005432424179	12936	Economy	9200.00
0005432424223	12936	Economy	9200.00
0005432424192	12936	Economy	9200.00
0005432045620	433	Business	24500.00
0005433684411	433	Business	24500.00
0005434023998	433	Business	24500.00
0005434735627	433	Business	24500.00
0005433057656	433	Business	24500.00
0005433057763	433	Business	24500.00
0005433057949	433	Business	24500.00
0005434023994	433	Business	24500.00
0005434023999	433	Business	24500.00
0005433057850	433	Business	24500.00
0005433057668	433	Business	24500.00
0005433057783	433	Business	24500.00
0005434735642	433	Business	24500.00
0005434735660	433	Business	24500.00
0005434023985	433	Business	24500.00
0005434029666	433	Business	24500.00
0005434024003	433	Business	24500.00
0005434735628	433	Business	24500.00
0005433057777	433	Business	24500.00
0005434023958	433	Business	24500.00
0005434023959	433	Business	24500.00
0005434023984	433	Economy	9000.00
0005434024009	433	Economy	8200.00
0005434023993	433	Economy	8200.00
0005433057672	433	Economy	8200.00
0005434029664	433	Economy	8200.00
0005434024023	433	Economy	8200.00
0005434024021	433	Economy	8200.00
0005434023986	433	Economy	8200.00
0005433057629	433	Economy	8200.00
0005434032038	433	Economy	8200.00
0005433057865	433	Economy	8200.00
0005434023965	433	Economy	8200.00
0005434023995	433	Economy	8200.00
0005433684413	433	Economy	8200.00
0005434024020	433	Economy	8200.00
0005434023961	433	Economy	8200.00
0005434023990	433	Economy	8200.00
0005434024004	433	Economy	8200.00
0005433057795	433	Economy	8200.00
0005434735643	433	Economy	8200.00
0005434023978	433	Economy	8200.00
0005434023962	433	Economy	8200.00
0005434024013	433	Economy	8200.00
0005432235671	433	Economy	8200.00
0005434024001	433	Economy	8200.00
0005432235670	433	Economy	8200.00
0005434023967	433	Economy	8200.00
0005433684412	433	Economy	8200.00
0005433057551	433	Economy	8200.00
0005434023969	433	Economy	8200.00
0005433057579	433	Economy	8200.00
0005434024024	433	Economy	8200.00
0005434024006	433	Economy	8200.00
0005434023966	433	Economy	8200.00
0005434024022	433	Economy	8200.00
0005434024019	433	Economy	8200.00
0005434023988	433	Economy	8200.00
0005434032039	433	Economy	8200.00
0005434024014	433	Economy	8200.00
0005433057578	433	Economy	8200.00
0005433929591	433	Economy	8200.00
0005434024015	433	Economy	8200.00
0005433057655	433	Economy	8200.00
0005434023982	433	Economy	8200.00
0005434024025	433	Economy	8200.00
0005433057758	433	Economy	8200.00
0005432235668	433	Economy	8200.00
0005433057888	433	Economy	8200.00
0005432235667	433	Economy	8200.00
0005434024005	433	Economy	8200.00
0005434024017	433	Economy	8200.00
0005434029665	433	Economy	8200.00
0005433057693	433	Economy	8200.00
0005434735671	433	Economy	8200.00
0005434028308	433	Economy	8200.00
0005434023989	433	Economy	8200.00
0005433057803	433	Economy	9000.00
0005433057701	433	Economy	8200.00
0005434023979	433	Economy	8200.00
0005434023976	433	Economy	9000.00
0005434024010	433	Economy	8200.00
0005434032041	433	Economy	8200.00
0005434023977	433	Economy	8200.00
0005434023980	433	Economy	8200.00
0005432045619	433	Economy	8200.00
0005432235672	433	Economy	8200.00
0005432235669	433	Economy	8200.00
0005434024011	433	Economy	8200.00
0005433057762	433	Economy	8200.00
0005434023970	433	Economy	8200.00
0005433057634	433	Economy	8200.00
0005434032040	433	Economy	8200.00
0005434023975	433	Economy	8200.00
0005434023987	433	Economy	8200.00
0005434023971	433	Economy	8200.00
0005433057776	433	Economy	8200.00
0005434023996	433	Economy	8200.00
0005433057818	433	Economy	8200.00
0005434024018	433	Economy	8200.00
0005434023963	433	Economy	8200.00
0005434024002	433	Economy	8200.00
0005434023973	433	Economy	8200.00
0005434024008	433	Economy	8200.00
0005434024016	433	Economy	8200.00
0005433057804	433	Economy	8200.00
0005434023964	433	Economy	8200.00
0005433057651	433	Economy	8200.00
0005434023972	433	Economy	8200.00
0005433057794	433	Economy	8200.00
0005434024007	433	Economy	8200.00
0005433057630	433	Economy	8200.00
0005432235666	433	Economy	8200.00
0005434023960	433	Economy	8200.00
0005434023997	433	Economy	8200.00
0005433057550	433	Economy	8200.00
0005434024000	433	Economy	8200.00
0005434023981	433	Economy	8200.00
0005434023983	433	Economy	8200.00
0005433057719	433	Economy	8200.00
0005434023992	433	Economy	8200.00
0005433057796	433	Economy	8200.00
0005433057851	433	Economy	8200.00
0005434024012	433	Economy	8200.00
0005434028307	433	Economy	8200.00
0005434023968	433	Economy	8200.00
0005434023974	433	Economy	8200.00
0005433057696	433	Economy	8200.00
0005434029663	433	Economy	8200.00
0005433057808	433	Economy	8200.00
0005434023991	433	Economy	8200.00
0005434023285	12699	Business	24500.00
0005434023639	12699	Business	24500.00
0005434023277	12699	Business	24500.00
0005434023410	12699	Business	24500.00
0005433058071	12699	Business	24500.00
0005433058051	12699	Business	24500.00
0005434023463	12699	Business	24500.00
0005433058069	12699	Business	24500.00
0005434023564	12699	Business	24500.00
0005434023409	12699	Business	24500.00
0005433684429	12699	Business	24500.00
0005434023290	12699	Business	24500.00
0005432156383	12699	Business	24500.00
0005433058049	12699	Business	24500.00
0005434029644	12699	Business	24500.00
0005434023342	12699	Business	24500.00
0005433058065	12699	Business	24500.00
0005434735713	12699	Business	24500.00
0005433058039	12699	Business	24500.00
0005432157500	12699	Business	24500.00
0005434023716	12699	Business	24500.00
0005434023493	12699	Economy	9000.00
0005434023516	12699	Economy	9000.00
0005432156385	12699	Economy	9000.00
0005433684430	12699	Economy	9000.00
0005432156384	12699	Economy	8200.00
0005434023165	12699	Economy	8200.00
0005434735712	12699	Economy	8200.00
0005434023573	12699	Economy	8200.00
0005434023518	12699	Economy	8200.00
0005434023426	12699	Economy	8200.00
0005434023061	12699	Economy	8200.00
0005433058040	12699	Economy	8200.00
0005433058038	12699	Economy	8200.00
0005434023289	12699	Economy	8200.00
0005434023352	12699	Economy	8200.00
0005434023488	12699	Economy	8200.00
0005434023362	12699	Economy	8200.00
0005434029648	12699	Economy	8200.00
0005434735714	12699	Economy	8200.00
0005434023489	12699	Economy	8200.00
0005434023490	12699	Economy	8200.00
0005434023397	12699	Economy	8200.00
0005434023123	12699	Economy	8200.00
0005434023345	12699	Economy	8200.00
0005434028278	12699	Economy	8200.00
0005433058063	12699	Economy	8200.00
0005434028290	12699	Economy	8200.00
0005434023424	12699	Economy	8200.00
0005434029647	12699	Economy	8200.00
0005433058054	12699	Economy	8200.00
0005434023341	12699	Economy	8200.00
0005433058046	12699	Economy	8200.00
0005434023182	12699	Economy	8200.00
0005434023002	12699	Economy	8200.00
0005434023574	12699	Economy	8200.00
0005434023425	12699	Economy	8200.00
0005433058068	12699	Economy	8200.00
0005433058036	12699	Economy	8200.00
0005434023164	12699	Economy	8200.00
0005433058047	12699	Economy	8200.00
0005434031992	12699	Economy	8200.00
0005433058031	12699	Economy	8200.00
0005433058057	12699	Economy	8200.00
0005433058033	12699	Economy	8200.00
0005434023412	12699	Economy	8200.00
0005433058043	12699	Economy	8200.00
0005434023363	12699	Economy	8200.00
0005434023509	12699	Economy	8200.00
0005434028279	12699	Economy	8200.00
0005432157501	12699	Economy	8200.00
0005433058032	12699	Economy	8200.00
0005434735710	12699	Economy	8200.00
0005434023598	12699	Economy	8200.00
0005434028286	12699	Economy	8200.00
0005434023462	12699	Economy	8200.00
0005434023385	12699	Economy	8200.00
0005434023390	12699	Economy	8200.00
0005433058059	12699	Economy	8200.00
0005434023517	12699	Economy	8200.00
0005434023599	12699	Economy	8200.00
0005434028289	12699	Economy	8200.00
0005434023311	12699	Economy	8200.00
0005434029643	12699	Economy	8200.00
0005434023592	12699	Economy	8200.00
0005433058064	12699	Economy	8200.00
0005434023538	12699	Economy	8200.00
0005434023481	12699	Economy	8200.00
0005433058037	12699	Economy	8200.00
0005434735709	12699	Economy	8200.00
0005434023212	12699	Economy	8200.00
0005434023429	12699	Economy	8200.00
0005434023470	12699	Economy	8200.00
0005433058034	12699	Economy	8200.00
0005434023416	12699	Economy	8200.00
0005434023098	12699	Economy	8200.00
0005434023479	12699	Economy	8200.00
0005434023401	12699	Economy	8200.00
0005434023378	12699	Economy	9000.00
0005434023389	12699	Economy	9000.00
0005434023384	12699	Economy	9000.00
0005434023469	12699	Economy	8200.00
0005433058050	12699	Economy	8200.00
0005433058045	12699	Economy	8200.00
0005434023487	12699	Economy	8200.00
0005434022981	12699	Economy	8200.00
0005434029642	12699	Economy	8200.00
0005433058053	12699	Economy	8200.00
0005433929630	12699	Economy	8200.00
0005434031998	12699	Economy	8200.00
0005434023343	12699	Economy	8200.00
0005434023361	12699	Economy	8200.00
0005433929629	12699	Economy	8200.00
0005433058035	12699	Economy	8200.00
0005434023062	12699	Economy	8200.00
0005433058067	12699	Economy	8200.00
0005434029636	12699	Economy	8200.00
0005433058062	12699	Economy	8200.00
0005434023264	12699	Economy	8200.00
0005434023593	12699	Economy	8200.00
0005434023286	12699	Economy	8200.00
0005434023326	12699	Economy	8200.00
0005434023372	12699	Economy	8200.00
0005434023400	12699	Economy	8200.00
0005434023217	12699	Economy	8200.00
0005433058042	12699	Economy	8200.00
0005433058066	12699	Economy	8200.00
0005434023287	12699	Economy	8200.00
0005434023325	12699	Economy	8200.00
0005433058055	12699	Economy	8200.00
0005432156386	12699	Economy	8200.00
0005434023396	12699	Economy	8200.00
0005433058048	12699	Economy	8200.00
0005434023480	12699	Economy	8200.00
0005434023494	12699	Economy	8200.00
0005433058058	12699	Economy	8200.00
0005434023659	12699	Economy	8200.00
0005433058060	12699	Economy	8200.00
0005434028276	12699	Economy	8200.00
0005433058041	12699	Economy	8200.00
0005433058061	12699	Economy	8200.00
0005434023357	12699	Economy	8200.00
0005434031993	12699	Economy	8200.00
0005434031991	12699	Economy	8200.00
0005434735711	12699	Economy	8200.00
0005434023715	12699	Economy	8200.00
0005434023353	12699	Economy	8200.00
0005434023157	12699	Economy	8200.00
0005434029635	12699	Economy	8200.00
0005433929631	12699	Economy	8200.00
0005434023604	12699	Economy	8200.00
0005433058044	12699	Economy	8200.00
0005433058052	12699	Economy	8200.00
0005433058056	12699	Economy	8200.00
0005433058070	12699	Economy	8200.00
0005433527272	13816	Business	111600.00
0005433529283	13816	Business	111600.00
0005433529280	13816	Business	111600.00
0005433529279	13816	Business	111600.00
0005433529281	13816	Business	111600.00
0005433529288	13816	Business	111600.00
0005433527281	13816	Economy	37200.00
0005433527266	13816	Economy	37200.00
0005433529289	13816	Economy	40900.00
0005433529282	13816	Economy	40900.00
0005433527268	13816	Economy	37200.00
0005433527276	13816	Economy	37200.00
0005433527273	13816	Economy	37200.00
0005433527269	13816	Economy	37200.00
0005433529291	13816	Economy	37200.00
0005433527271	13816	Economy	37200.00
0005433527278	13816	Economy	37200.00
0005433529278	13816	Economy	37200.00
0005433527280	13816	Economy	37200.00
0005433529285	13816	Economy	37200.00
0005433527279	13816	Economy	37200.00
0005433527274	13816	Economy	37200.00
0005433527267	13816	Economy	37200.00
0005433529287	13816	Economy	37200.00
0005433527270	13816	Economy	37200.00
0005433527275	13816	Economy	37200.00
0005433529284	13816	Economy	37200.00
0005433529290	13816	Economy	37200.00
0005433529286	13816	Economy	37200.00
0005433527277	13816	Economy	37200.00
0005433527265	13816	Economy	37200.00
0005433529277	13816	Economy	37200.00
0005433533302	32452	Business	111600.00
0005433533278	32452	Business	111600.00
0005433529246	32452	Business	111600.00
0005433529263	32452	Business	111600.00
0005433529237	32452	Business	111600.00
0005433529242	32452	Economy	37200.00
0005433533284	32452	Economy	37200.00
0005433533306	32452	Economy	40900.00
0005433529248	32452	Economy	37200.00
0005433529252	32452	Economy	37200.00
0005433533272	32452	Economy	37200.00
0005433533290	32452	Economy	37200.00
0005433533276	32452	Economy	37200.00
0005433533294	32452	Economy	37200.00
0005433533301	32452	Economy	37200.00
0005433533265	32452	Economy	37200.00
0005433533295	32452	Economy	37200.00
0005433529264	32452	Economy	37200.00
0005433529247	32452	Economy	37200.00
0005433529230	32452	Economy	37200.00
0005433529253	32452	Economy	37200.00
0005433533273	32452	Economy	37200.00
0005433529232	32452	Economy	37200.00
0005433529243	32452	Economy	37200.00
0005433533283	32452	Economy	37200.00
0005433533305	32452	Economy	37200.00
0005433529234	32452	Economy	37200.00
0005433529245	32452	Economy	37200.00
0005433529238	32452	Economy	37200.00
0005433529225	32452	Economy	37200.00
0005433533277	32452	Economy	37200.00
0005433529233	32452	Economy	37200.00
0005433923727	2131	Business	34700.00
0005433923703	2131	Business	34700.00
0005433035877	2131	Business	34700.00
0005433923652	2131	Business	34700.00
0005433923667	2131	Business	34700.00
0005433923744	2131	Business	34700.00
0005433923736	2131	Business	34700.00
0005433923709	2131	Business	34700.00
0005432044537	2131	Business	34700.00
0005433923677	2131	Business	34700.00
0005433923731	2131	Business	34700.00
0005434028290	2131	Business	34700.00
0005433035981	2131	Business	34700.00
0005433036078	2131	Business	34700.00
0005433923720	2131	Business	34700.00
0005433923718	2131	Business	34700.00
0005433929631	2131	Business	34700.00
0005433923740	2131	Business	34700.00
0005433923675	2131	Business	34700.00
0005433923747	2131	Business	34700.00
0005434028286	2131	Business	34700.00
0005433036061	2131	Business	34700.00
0005434028289	2131	Business	34700.00
0005433923689	2131	Economy	12700.00
0005433923697	2131	Economy	11600.00
0005433923666	2131	Economy	11600.00
0005433923654	2131	Economy	11600.00
0005433036199	2131	Economy	11600.00
0005433923701	2131	Economy	11600.00
0005432231603	2131	Economy	11600.00
0005433036127	2131	Economy	11600.00
0005432044536	2131	Economy	11600.00
0005433923691	2131	Economy	11600.00
0005433923688	2131	Economy	11600.00
0005433035927	2131	Economy	11600.00
0005433923694	2131	Economy	11600.00
0005433923660	2131	Economy	11600.00
0005433036107	2131	Economy	11600.00
0005433035977	2131	Economy	11600.00
0005432231610	2131	Economy	11600.00
0005433931475	2131	Economy	11600.00
0005433923684	2131	Economy	11600.00
0005433036148	2131	Economy	11600.00
0005433923672	2131	Economy	11600.00
0005433923653	2131	Economy	11600.00
0005433036121	2131	Economy	11600.00
0005433923699	2131	Economy	11600.00
0005433923695	2131	Economy	11600.00
0005432044535	2131	Economy	11600.00
0005432231611	2131	Economy	11600.00
0005433923733	2131	Economy	11600.00
0005433036062	2131	Economy	11600.00
0005433036048	2131	Economy	11600.00
0005433036149	2131	Economy	11600.00
0005433035852	2131	Economy	11600.00
0005433923679	2131	Economy	11600.00
0005433923722	2131	Economy	11600.00
0005433923732	2131	Economy	11600.00
0005433035978	2131	Economy	11600.00
0005433035968	2131	Economy	11600.00
0005433923723	2131	Economy	11600.00
0005433923730	2131	Economy	11600.00
0005433923711	2131	Economy	11600.00
0005433923725	2131	Economy	11600.00
0005433923712	2131	Economy	11600.00
0005433036263	2131	Economy	11600.00
0005434028276	2131	Economy	11600.00
0005433036120	2131	Economy	11600.00
0005433923719	2131	Economy	11600.00
0005433036052	2131	Economy	11600.00
0005433923734	2131	Economy	11600.00
0005433923693	2131	Economy	11600.00
0005433923702	2131	Economy	11600.00
0005433036262	2131	Economy	11600.00
0005433923738	2131	Economy	11600.00
0005433931477	2131	Economy	11600.00
0005433923661	2131	Economy	11600.00
0005433923746	2131	Economy	11600.00
0005433923680	2131	Economy	11600.00
0005433923663	2131	Economy	11600.00
0005433036036	2131	Economy	11600.00
0005433875386	2131	Economy	11600.00
0005433036054	2131	Economy	11600.00
0005433923715	2131	Economy	11600.00
0005433035851	2131	Economy	11600.00
0005433923685	2131	Economy	11600.00
0005432044538	2131	Economy	11600.00
0005433923674	2131	Economy	11600.00
0005433036047	2131	Economy	11600.00
0005433923657	2131	Economy	11600.00
0005433923698	2131	Economy	11600.00
0005433036009	2131	Economy	11600.00
0005433923707	2131	Economy	11600.00
0005432231604	2131	Economy	11600.00
0005433923748	2131	Economy	11600.00
0005433035933	2131	Economy	11600.00
0005433923705	2131	Economy	11600.00
0005433923651	2131	Economy	11600.00
0005433923726	2131	Economy	11600.00
0005433923665	2131	Economy	11600.00
0005433923681	2131	Economy	12700.00
0005433035966	2131	Economy	11600.00
0005433929630	2131	Economy	12700.00
0005433923669	2131	Economy	11600.00
0005433923656	2131	Economy	11600.00
0005433923700	2131	Economy	12700.00
0005432231613	2131	Economy	12700.00
0005433923735	2131	Economy	11600.00
0005433036014	2131	Economy	11600.00
0005433036053	2131	Economy	11600.00
0005433923717	2131	Economy	11600.00
0005433923739	2131	Economy	11600.00
0005433923696	2131	Economy	11600.00
0005432231607	2131	Economy	11600.00
0005433923729	2131	Economy	11600.00
0005433923710	2131	Economy	11600.00
0005433929629	2131	Economy	11600.00
0005432231612	2131	Economy	11600.00
0005433923690	2131	Economy	11600.00
0005433923713	2131	Economy	11600.00
0005434028279	2131	Economy	11600.00
0005433036100	2131	Economy	11600.00
0005433036119	2131	Economy	11600.00
0005433923692	2131	Economy	11600.00
0005433923658	2131	Economy	11600.00
0005432749770	2131	Economy	11600.00
0005433923673	2131	Economy	11600.00
0005434028278	2131	Economy	11600.00
0005433923683	2131	Economy	11600.00
0005433923650	2131	Economy	11600.00
0005433923670	2131	Economy	11600.00
0005433923649	2131	Economy	11600.00
0005433931476	2131	Economy	11600.00
0005433036130	2131	Economy	11600.00
0005433923676	2131	Economy	11600.00
0005433923743	2131	Economy	11600.00
0005432231605	2131	Economy	11600.00
0005433036209	2131	Economy	11600.00
0005433923678	2131	Economy	11600.00
0005433923716	2131	Economy	11600.00
0005433923742	2131	Economy	11600.00
0005432231608	2131	Economy	11600.00
0005433923737	2131	Economy	11600.00
0005433035967	2131	Economy	11600.00
0005433923671	2131	Economy	11600.00
0005433036091	2131	Economy	11600.00
0005433923686	2131	Economy	11600.00
0005433036265	2131	Economy	11600.00
0005433923704	2131	Economy	11600.00
0005433923706	2131	Economy	11600.00
0005433923708	2131	Economy	11600.00
0005433923655	2131	Economy	11600.00
0005433036090	2131	Economy	11600.00
0005433035902	2131	Economy	11600.00
0005432231606	2131	Economy	11600.00
0005433923724	2131	Economy	11600.00
0005433923728	2131	Economy	11600.00
0005433923662	2131	Economy	11600.00
0005433923721	2131	Economy	11600.00
0005433035842	2131	Economy	11600.00
0005433923714	2131	Economy	11600.00
0005433036035	2131	Economy	11600.00
0005433036167	2131	Economy	11600.00
0005433875385	2131	Economy	11600.00
0005433036093	2131	Economy	11600.00
0005432231609	2131	Economy	11600.00
0005433923745	2131	Economy	11600.00
0005433923682	2131	Economy	11600.00
0005433923659	2131	Economy	11600.00
0005433923668	2131	Economy	11600.00
0005433923664	2131	Economy	11600.00
0005433923741	2131	Economy	11600.00
0005433923687	2131	Economy	11600.00
0005433922752	24113	Business	34700.00
0005433036528	24113	Business	34700.00
0005433923013	24113	Business	34700.00
0005433923160	24113	Business	34700.00
0005433036542	24113	Business	34700.00
0005433923239	24113	Business	34700.00
0005433036531	24113	Business	34700.00
0005433922399	24113	Business	34700.00
0005433036504	24113	Business	34700.00
0005433929598	24113	Business	34700.00
0005433922601	24113	Business	34700.00
0005432749793	24113	Business	34700.00
0005433923223	24113	Business	34700.00
0005433036509	24113	Business	34700.00
0005433922814	24113	Business	34700.00
0005433931455	24113	Business	34700.00
0005433036521	24113	Business	34700.00
0005433929613	24113	Business	34700.00
0005433922869	24113	Business	34700.00
0005433922765	24113	Business	34700.00
0005433922739	24113	Business	34700.00
0005433036517	24113	Business	34700.00
0005433036538	24113	Business	34700.00
0005433036505	24113	Business	34700.00
0005433922613	24113	Business	34700.00
0005433036497	24113	Business	34700.00
0005433922824	24113	Business	34700.00
0005433922520	24113	Economy	12700.00
0005433923014	24113	Economy	12700.00
0005433922621	24113	Economy	12700.00
0005433923198	24113	Economy	11600.00
0005433036527	24113	Economy	11600.00
0005433922460	24113	Economy	11600.00
0005433036522	24113	Economy	11600.00
0005433931453	24113	Economy	11600.00
0005433929599	24113	Economy	11600.00
0005433036503	24113	Economy	11600.00
0005433922893	24113	Economy	11600.00
0005433036543	24113	Economy	11600.00
0005433922569	24113	Economy	11600.00
0005433923010	24113	Economy	11600.00
0005433929597	24113	Economy	11600.00
0005433922823	24113	Economy	11600.00
0005434028309	24113	Economy	11600.00
0005433922321	24113	Economy	11600.00
0005433036539	24113	Economy	11600.00
0005433036541	24113	Economy	11600.00
0005433036496	24113	Economy	11600.00
0005433923229	24113	Economy	11600.00
0005433036494	24113	Economy	11600.00
0005433036533	24113	Economy	11600.00
0005433922917	24113	Economy	11600.00
0005433922568	24113	Economy	11600.00
0005433922782	24113	Economy	11600.00
0005433923272	24113	Economy	11600.00
0005433922614	24113	Economy	11600.00
0005432207673	24113	Economy	11600.00
0005432206221	24113	Economy	11600.00
0005433922873	24113	Economy	11600.00
0005433036515	24113	Economy	11600.00
0005433922721	24113	Economy	11600.00
0005433036523	24113	Economy	11600.00
0005432206223	24113	Economy	11600.00
0005433036501	24113	Economy	11600.00
0005433922639	24113	Economy	11600.00
0005433922694	24113	Economy	11600.00
0005433931450	24113	Economy	11600.00
0005433922915	24113	Economy	11600.00
0005433036492	24113	Economy	11600.00
0005433036498	24113	Economy	11600.00
0005433929593	24113	Economy	11600.00
0005433036502	24113	Economy	11600.00
0005433923060	24113	Economy	11600.00
0005433036536	24113	Economy	11600.00
0005433922758	24113	Economy	11600.00
0005433922916	24113	Economy	11600.00
0005433923167	24113	Economy	11600.00
0005433036540	24113	Economy	11600.00
0005433036491	24113	Economy	11600.00
0005433922365	24113	Economy	11600.00
0005433922381	24113	Economy	11600.00
0005433922849	24113	Economy	11600.00
0005433929605	24113	Economy	11600.00
0005433922938	24113	Economy	11600.00
0005433923095	24113	Economy	11600.00
0005433922519	24113	Economy	11600.00
0005433929592	24113	Economy	11600.00
0005433922764	24113	Economy	11600.00
0005433922397	24113	Economy	11600.00
0005433922638	24113	Economy	11600.00
0005433922868	24113	Economy	11600.00
0005433923145	24113	Economy	11600.00
0005433922757	24113	Economy	11600.00
0005433036534	24113	Economy	11600.00
0005433923185	24113	Economy	11600.00
0005433922602	24113	Economy	11600.00
0005433922751	24113	Economy	11600.00
0005433923156	24113	Economy	11600.00
0005433923319	24113	Economy	11600.00
0005433036516	24113	Economy	11600.00
0005433922720	24113	Economy	11600.00
0005433923286	24113	Economy	11600.00
0005433922850	24113	Economy	11600.00
0005433922857	24113	Economy	11600.00
0005432207672	24113	Economy	11600.00
0005432207671	24113	Economy	11600.00
0005433036500	24113	Economy	11600.00
0005433922407	24113	Economy	11600.00
0005433923186	24113	Economy	11600.00
0005433922461	24113	Economy	11600.00
0005433036513	24113	Economy	11600.00
0005433923221	24113	Economy	11600.00
0005433922693	24113	Economy	11600.00
0005433036530	24113	Economy	11600.00
0005433922692	24113	Economy	11600.00
0005432206222	24113	Economy	12700.00
0005433922988	24113	Economy	12700.00
0005432206220	24113	Economy	11600.00
0005432749795	24113	Economy	12700.00
0005433036508	24113	Economy	11600.00
0005433036495	24113	Economy	11600.00
0005433923135	24113	Economy	11600.00
0005433036506	24113	Economy	11600.00
0005433923224	24113	Economy	11600.00
0005432206218	24113	Economy	11600.00
0005433922993	24113	Economy	11600.00
0005433929604	24113	Economy	11600.00
0005433036512	24113	Economy	11600.00
0005433036524	24113	Economy	11600.00
0005433922380	24113	Economy	11600.00
0005433036525	24113	Economy	11600.00
0005433036526	24113	Economy	11600.00
0005433929612	24113	Economy	11600.00
0005433931443	24113	Economy	11600.00
0005433923166	24113	Economy	11600.00
0005433923047	24113	Economy	11600.00
0005433922320	24113	Economy	11600.00
0005433922799	24113	Economy	11600.00
0005433922680	24113	Economy	11600.00
0005433036519	24113	Economy	11600.00
0005433036493	24113	Economy	11600.00
0005433922844	24113	Economy	11600.00
0005433036514	24113	Economy	11600.00
0005433036537	24113	Economy	11600.00
0005433922462	24113	Economy	11600.00
0005433036510	24113	Economy	11600.00
0005433923320	24113	Economy	11600.00
0005433922817	24113	Economy	11600.00
0005433036518	24113	Economy	11600.00
0005433923287	24113	Economy	11600.00
0005433923139	24113	Economy	11600.00
0005433922398	24113	Economy	11600.00
0005433922417	24113	Economy	11600.00
0005433931454	24113	Economy	11600.00
0005433036520	24113	Economy	11600.00
0005433923009	24113	Economy	11600.00
0005433922891	24113	Economy	11600.00
0005433036511	24113	Economy	11600.00
0005433922819	24113	Economy	11600.00
0005433922902	24113	Economy	11600.00
0005434028310	24113	Economy	11600.00
0005433036529	24113	Economy	11600.00
0005433036535	24113	Economy	11600.00
0005433922477	24113	Economy	11600.00
0005433922738	24113	Economy	11600.00
0005433923134	24113	Economy	11600.00
0005433036507	24113	Economy	11600.00
0005433922843	24113	Economy	11600.00
0005433922732	24113	Economy	11600.00
0005433036532	24113	Economy	11600.00
0005433922813	24113	Economy	11600.00
0005433922914	24113	Economy	11600.00
0005433922615	24113	Economy	11600.00
0005433922322	24113	Economy	11600.00
0005432206219	24113	Economy	11600.00
0005433923222	24113	Economy	11600.00
0005433923046	24113	Economy	11600.00
0005432749794	24113	Economy	11600.00
0005433922723	24113	Economy	11600.00
0005433036499	24113	Economy	11600.00
0005433180966	298	Business	83700.00
0005434725923	298	Business	83700.00
0005434725955	298	Business	83700.00
0005434726015	298	Business	83700.00
0005434725921	298	Business	83700.00
0005434551471	298	Business	83700.00
0005433180999	298	Business	83700.00
0005433180896	298	Business	83700.00
0005434726010	298	Business	83700.00
0005434726008	298	Business	83700.00
0005433234049	298	Business	83700.00
0005434725996	298	Business	83700.00
0005434725973	298	Business	83700.00
0005433766621	298	Business	83700.00
0005434551456	298	Business	83700.00
0005433233834	298	Business	83700.00
0005434032000	298	Business	83700.00
0005433233980	298	Business	83700.00
0005434725936	298	Business	83700.00
0005432277861	298	Business	83700.00
0005434726000	298	Business	83700.00
0005434726031	298	Business	83700.00
0005434725998	298	Business	83700.00
0005433233793	298	Business	83700.00
0005434726013	298	Business	83700.00
0005434551439	298	Business	83700.00
0005434726020	298	Business	83700.00
0005434725978	298	Comfort	47400.00
0005434725969	298	Comfort	47400.00
0005434551462	298	Comfort	47400.00
0005434551481	298	Comfort	47400.00
0005433233770	298	Comfort	47400.00
0005433113527	298	Comfort	47400.00
0005434551447	298	Comfort	47400.00
0005434302478	298	Comfort	47400.00
0005434725981	298	Comfort	47400.00
0005434551464	298	Comfort	47400.00
0005433233886	298	Comfort	47400.00
0005433126824	298	Comfort	47400.00
0005433181038	298	Comfort	47400.00
0005434551453	298	Comfort	47400.00
0005434551480	298	Comfort	47400.00
0005434726017	298	Comfort	47400.00
0005434725940	298	Comfort	47400.00
0005433180982	298	Comfort	47400.00
0005434551486	298	Comfort	47400.00
0005434551457	298	Comfort	47400.00
0005433131693	298	Comfort	47400.00
0005434725918	298	Comfort	47400.00
0005433180991	298	Comfort	47400.00
0005434726034	298	Comfort	47400.00
0005433180918	298	Comfort	47400.00
0005433234030	298	Comfort	47400.00
0005433766608	298	Comfort	47400.00
0005434726003	298	Comfort	47400.00
0005433113536	298	Comfort	47400.00
0005434551468	298	Comfort	47400.00
0005434726006	298	Comfort	47400.00
0005433234027	298	Comfort	47400.00
0005434726012	298	Comfort	47400.00
0005433233909	298	Comfort	47400.00
0005433289832	298	Comfort	47400.00
0005433181004	298	Comfort	47400.00
0005434551482	298	Comfort	47400.00
0005432277868	298	Comfort	47400.00
0005433180884	298	Comfort	47400.00
0005433766607	298	Comfort	47400.00
0005434725945	298	Comfort	47400.00
0005434551455	298	Economy	27900.00
0005434551485	298	Economy	27900.00
0005432277859	298	Economy	27900.00
0005434725913	298	Economy	27900.00
0005434551459	298	Economy	27900.00
0005434731185	298	Economy	27900.00
0005434725966	298	Economy	27900.00
0005433181082	298	Economy	27900.00
0005433181039	298	Economy	27900.00
0005435142630	298	Economy	27900.00
0005434725992	298	Economy	27900.00
0005433126841	298	Economy	27900.00
0005434725927	298	Economy	27900.00
0005434551492	298	Economy	27900.00
0005434551438	298	Economy	27900.00
0005434726028	298	Economy	27900.00
0005433233653	298	Economy	27900.00
0005433181005	298	Economy	27900.00
0005433233953	298	Economy	27900.00
0005433111483	298	Economy	27900.00
0005434551461	298	Economy	27900.00
0005433180895	298	Economy	27900.00
0005433233922	298	Economy	27900.00
0005433289808	298	Economy	27900.00
0005434031999	298	Economy	27900.00
0005433180974	298	Economy	27900.00
0005434551465	298	Economy	27900.00
0005434725943	298	Economy	27900.00
0005434302475	298	Economy	27900.00
0005434725997	298	Economy	27900.00
0005434725958	298	Economy	27900.00
0005434725993	298	Economy	27900.00
0005433233654	298	Economy	27900.00
0005433234152	298	Economy	27900.00
0005434031987	298	Economy	27900.00
0005434725939	298	Economy	27900.00
0005433289794	298	Economy	27900.00
0005434726005	298	Economy	27900.00
0005435142627	298	Economy	27900.00
0005434551440	298	Economy	27900.00
0005434725986	298	Economy	27900.00
0005433766606	298	Economy	27900.00
0005434725976	298	Economy	27900.00
0005434551472	298	Economy	27900.00
0005434032004	298	Economy	27900.00
0005433180979	298	Economy	27900.00
0005435142637	298	Economy	27900.00
0005434551467	298	Economy	27900.00
0005434725977	298	Economy	27900.00
0005433180951	298	Economy	27900.00
0005434725980	298	Economy	27900.00
0005433180975	298	Economy	27900.00
0005434551488	298	Economy	27900.00
0005434551477	298	Economy	27900.00
0005434726016	298	Economy	27900.00
0005433233978	298	Economy	27900.00
0005434725937	298	Economy	27900.00
0005434725962	298	Economy	27900.00
0005434725919	298	Economy	27900.00
0005432277869	298	Economy	30700.00
0005434726022	298	Economy	30700.00
0005433766626	298	Economy	27900.00
0005434726030	298	Economy	30700.00
0005434725948	298	Economy	27900.00
0005434725926	298	Economy	27900.00
0005434725999	298	Economy	30700.00
0005433180978	298	Economy	27900.00
0005433181011	298	Economy	30700.00
0005432277867	298	Economy	27900.00
0005433233908	298	Economy	30700.00
0005434725961	298	Economy	27900.00
0005434551466	298	Economy	27900.00
0005433180973	298	Economy	27900.00
0005434725963	298	Economy	27900.00
0005435142633	298	Economy	27900.00
0005434726026	298	Economy	27900.00
0005433180892	298	Economy	27900.00
0005434725987	298	Economy	27900.00
0005434725979	298	Economy	27900.00
0005433234029	298	Economy	27900.00
0005433766627	298	Economy	27900.00
0005433180976	298	Economy	27900.00
0005433233946	298	Economy	27900.00
0005433181036	298	Economy	27900.00
0005433181066	298	Economy	27900.00
0005433289818	298	Economy	27900.00
0005434551470	298	Economy	27900.00
0005433180917	298	Economy	27900.00
0005434551445	298	Economy	27900.00
0005434551444	298	Economy	27900.00
0005434725985	298	Economy	27900.00
0005433180990	298	Economy	27900.00
0005435142638	298	Economy	27900.00
0005434725941	298	Economy	27900.00
0005433233617	298	Economy	27900.00
0005433233923	298	Economy	27900.00
0005433181037	298	Economy	27900.00
0005433233963	298	Economy	27900.00
0005434725956	298	Economy	27900.00
0005433233945	298	Economy	27900.00
0005433234150	298	Economy	27900.00
0005434031995	298	Economy	27900.00
0005434726011	298	Economy	27900.00
0005433234062	298	Economy	27900.00
0005433233661	298	Economy	27900.00
0005433233529	298	Economy	27900.00
0005434551443	298	Economy	27900.00
0005434725932	298	Economy	27900.00
0005433234077	298	Economy	27900.00
0005434725968	298	Economy	27900.00
0005434725952	298	Economy	27900.00
0005434726009	298	Economy	27900.00
0005434725942	298	Economy	27900.00
0005434551478	298	Economy	27900.00
0005434725989	298	Economy	27900.00
0005434551460	298	Economy	27900.00
0005434735706	298	Economy	27900.00
0005433233769	298	Economy	27900.00
0005433233810	298	Economy	27900.00
0005434725916	298	Economy	27900.00
0005434725972	298	Economy	27900.00
0005434725949	298	Economy	27900.00
0005433234087	298	Economy	27900.00
0005434726025	298	Economy	27900.00
0005434726027	298	Economy	27900.00
0005434551484	298	Economy	27900.00
0005433233928	298	Economy	27900.00
0005433233736	298	Economy	27900.00
0005434725960	298	Economy	27900.00
0005434551449	298	Economy	27900.00
0005432277862	298	Economy	27900.00
0005434551489	298	Economy	27900.00
0005434551479	298	Economy	27900.00
0005434726029	298	Economy	27900.00
0005434726004	298	Economy	27900.00
0005434551446	298	Economy	27900.00
0005433233904	298	Economy	27900.00
0005434725954	298	Economy	27900.00
0005433113528	298	Economy	27900.00
0005434551491	298	Economy	27900.00
0005434551442	298	Economy	27900.00
0005434725988	298	Economy	27900.00
0005433233931	298	Economy	27900.00
0005435142636	298	Economy	27900.00
0005435142626	298	Economy	27900.00
0005434725970	298	Economy	27900.00
0005433111498	298	Economy	27900.00
0005433233906	298	Economy	27900.00
0005433180955	298	Economy	27900.00
0005434725950	298	Economy	27900.00
0005434551454	298	Economy	27900.00
0005434725983	298	Economy	27900.00
0005433233932	298	Economy	27900.00
0005434726033	298	Economy	27900.00
0005434731184	298	Economy	27900.00
0005433234061	298	Economy	27900.00
0005435142632	298	Economy	27900.00
0005432277870	298	Economy	27900.00
0005433234233	298	Economy	27900.00
0005433233751	298	Economy	27900.00
0005434725971	298	Economy	27900.00
0005434735705	298	Economy	27900.00
0005433289793	298	Economy	27900.00
0005434735708	298	Economy	27900.00
0005433233971	298	Economy	27900.00
0005435142634	298	Economy	27900.00
0005434725917	298	Economy	27900.00
0005434725929	298	Economy	27900.00
0005434551450	298	Economy	27900.00
0005434725974	298	Economy	27900.00
0005434302477	298	Economy	27900.00
0005434551474	298	Economy	30700.00
0005433233874	298	Economy	30700.00
0005434735707	298	Economy	30700.00
0005433233840	298	Economy	30700.00
0005433766622	298	Economy	27900.00
0005435142631	298	Economy	27900.00
0005434725959	298	Economy	27900.00
0005433180958	298	Economy	27900.00
0005433233865	298	Economy	27900.00
0005434725975	298	Economy	27900.00
0005434725925	298	Economy	27900.00
0005433181020	298	Economy	27900.00
0005434551490	298	Economy	27900.00
0005433233734	298	Economy	27900.00
0005434726019	298	Economy	27900.00
0005433233818	298	Economy	27900.00
0005434725994	298	Economy	27900.00
0005434726018	298	Economy	27900.00
0005433113532	298	Economy	27900.00
0005434725967	298	Economy	27900.00
0005433233949	298	Economy	27900.00
0005434725990	298	Economy	27900.00
0005432277865	298	Economy	27900.00
0005434725965	298	Economy	27900.00
0005434725922	298	Economy	27900.00
0005434725946	298	Economy	27900.00
0005434551483	298	Economy	27900.00
0005434726002	298	Economy	27900.00
0005434551493	298	Economy	27900.00
0005433181081	298	Economy	27900.00
0005433111484	298	Economy	27900.00
0005434551476	298	Economy	27900.00
0005435142635	298	Economy	27900.00
0005434726007	298	Economy	27900.00
0005434551473	298	Economy	27900.00
0005434725951	298	Economy	27900.00
0005435142628	298	Economy	27900.00
0005434551452	298	Economy	27900.00
0005434725924	298	Economy	27900.00
0005434735704	298	Economy	27900.00
0005434725947	298	Economy	27900.00
0005434551469	298	Economy	27900.00
0005434726032	298	Economy	27900.00
0005434726035	298	Economy	27900.00
0005433233979	298	Economy	27900.00
0005433233952	298	Economy	27900.00
0005434551487	298	Economy	27900.00
0005434725991	298	Economy	27900.00
0005433233811	298	Economy	27900.00
0005433234012	298	Economy	27900.00
0005434725995	298	Economy	27900.00
0005434551441	298	Economy	27900.00
0005433180959	298	Economy	27900.00
0005434725930	298	Economy	27900.00
0005434725957	298	Economy	27900.00
0005433180967	298	Economy	27900.00
0005434725953	298	Economy	27900.00
0005434725938	298	Economy	27900.00
0005434726023	298	Economy	27900.00
0005434725915	298	Economy	27900.00
0005434551458	298	Economy	27900.00
0005434725914	298	Economy	27900.00
0005434032001	298	Economy	27900.00
0005432277863	298	Economy	27900.00
0005433289815	298	Economy	27900.00
0005434725964	298	Economy	27900.00
0005434725920	298	Economy	27900.00
0005434726014	298	Economy	27900.00
0005434725944	298	Economy	27900.00
0005433180964	298	Economy	27900.00
0005433233682	298	Economy	27900.00
0005434725982	298	Economy	27900.00
0005433233991	298	Economy	27900.00
0005432277866	298	Economy	27900.00
0005433180920	298	Economy	27900.00
0005434551463	298	Economy	27900.00
0005434725935	298	Economy	27900.00
0005434726001	298	Economy	27900.00
0005433233780	298	Economy	27900.00
0005433233792	298	Economy	27900.00
0005434731186	298	Economy	27900.00
0005434726021	298	Economy	27900.00
0005433234023	298	Economy	27900.00
0005433234085	298	Economy	27900.00
0005434551475	298	Economy	27900.00
0005434551451	298	Economy	27900.00
0005433180890	298	Economy	27900.00
0005434725933	298	Economy	27900.00
0005434726024	298	Economy	27900.00
0005434302476	298	Economy	27900.00
0005433233905	298	Economy	27900.00
0005434725931	298	Economy	27900.00
0005432277860	298	Economy	27900.00
0005434725928	298	Economy	27900.00
0005435142629	298	Economy	27900.00
0005433233864	298	Economy	27900.00
0005433181059	298	Economy	27900.00
0005432277864	298	Economy	27900.00
0005434725934	298	Economy	27900.00
0005434725984	298	Economy	27900.00
0005435142639	298	Economy	27900.00
0005433180831	298	Economy	27900.00
0005433234028	298	Economy	27900.00
0005434726036	298	Economy	27900.00
0005434551448	298	Economy	27900.00
0005434551109	9831	Business	83700.00
0005434725290	9831	Business	83700.00
0005433289877	9831	Business	83700.00
0005433234474	9831	Business	83700.00
0005434550928	9831	Business	83700.00
0005433234492	9831	Business	83700.00
0005434725287	9831	Business	83700.00
0005434725030	9831	Business	83700.00
0005434550986	9831	Business	83700.00
0005433181198	9831	Business	83700.00
0005435142498	9831	Business	83700.00
0005434724794	9831	Business	83700.00
0005433181194	9831	Business	83700.00
0005434724302	9831	Business	83700.00
0005434725409	9831	Business	83700.00
0005433234495	9831	Business	83700.00
0005434735654	9831	Business	83700.00
0005433234488	9831	Business	83700.00
0005434724912	9831	Business	83700.00
0005434725386	9831	Business	83700.00
0005434724773	9831	Business	83700.00
0005434725399	9831	Business	83700.00
0005434735678	9831	Business	83700.00
0005435142521	9831	Business	83700.00
0005433234487	9831	Business	83700.00
0005433234482	9831	Business	83700.00
0005434551012	9831	Comfort	47400.00
0005432199275	9831	Business	83700.00
0005433234476	9831	Comfort	47400.00
0005434725238	9831	Comfort	47400.00
0005432199273	9831	Comfort	47400.00
0005433234457	9831	Comfort	47400.00
0005434735684	9831	Comfort	47400.00
0005433234453	9831	Comfort	47400.00
0005433234443	9831	Comfort	47400.00
0005433181191	9831	Comfort	47400.00
0005433234437	9831	Comfort	47400.00
0005434724997	9831	Comfort	47400.00
0005434302445	9831	Comfort	47400.00
0005433234452	9831	Comfort	47400.00
0005434724517	9831	Comfort	47400.00
0005433181197	9831	Comfort	47400.00
0005433126865	9831	Comfort	47400.00
0005433129295	9831	Comfort	47400.00
0005434735656	9831	Comfort	47400.00
0005433766655	9831	Comfort	47400.00
0005434550560	9831	Comfort	47400.00
0005434725163	9831	Comfort	47400.00
0005433113545	9831	Comfort	47400.00
0005434725057	9831	Comfort	47400.00
0005433234454	9831	Comfort	47400.00
0005434725124	9831	Comfort	47400.00
0005434550888	9831	Comfort	47400.00
0005434725308	9831	Comfort	47400.00
0005434724842	9831	Comfort	47400.00
0005434724984	9831	Comfort	47400.00
0005434725289	9831	Comfort	47400.00
0005433181211	9831	Comfort	47400.00
0005435142486	9831	Comfort	47400.00
0005434725339	9831	Comfort	47400.00
0005434725187	9831	Comfort	47400.00
0005433234470	9831	Comfort	47400.00
0005433126862	9831	Comfort	47400.00
0005434550629	9831	Comfort	47400.00
0005434724862	9831	Comfort	47400.00
0005434550990	9831	Comfort	47400.00
0005433234438	9831	Economy	27900.00
0005433289875	9831	Economy	27900.00
0005434724896	9831	Economy	27900.00
0005434725034	9831	Economy	27900.00
0005434551122	9831	Economy	27900.00
0005434724998	9831	Economy	27900.00
0005434724518	9831	Economy	27900.00
0005434724131	9831	Economy	27900.00
0005434725000	9831	Economy	27900.00
0005434550712	9831	Economy	27900.00
0005434550658	9831	Economy	27900.00
0005434724981	9831	Economy	27900.00
0005434725020	9831	Economy	27900.00
0005434725401	9831	Economy	27900.00
0005434735691	9831	Economy	27900.00
0005434725400	9831	Economy	27900.00
0005433129293	9831	Economy	27900.00
0005434032043	9831	Economy	27900.00
0005434724956	9831	Economy	27900.00
0005434725288	9831	Economy	27900.00
0005433181203	9831	Economy	27900.00
0005433234460	9831	Economy	27900.00
0005434725264	9831	Economy	27900.00
0005434724282	9831	Economy	27900.00
0005435142519	9831	Economy	27900.00
0005434724849	9831	Economy	27900.00
0005434725136	9831	Economy	27900.00
0005435142520	9831	Economy	27900.00
0005433234471	9831	Economy	27900.00
0005433234446	9831	Economy	27900.00
0005433234479	9831	Economy	27900.00
0005433181207	9831	Economy	27900.00
0005435142569	9831	Economy	27900.00
0005433234433	9831	Economy	27900.00
0005434725105	9831	Economy	27900.00
0005434550955	9831	Economy	27900.00
0005434551085	9831	Economy	27900.00
0005432199276	9831	Economy	27900.00
0005435142482	9831	Economy	27900.00
0005434735655	9831	Economy	27900.00
0005432199279	9831	Economy	27900.00
0005434724887	9831	Economy	27900.00
0005433181202	9831	Economy	27900.00
0005434724855	9831	Economy	27900.00
0005434724063	9831	Economy	27900.00
0005434550843	9831	Economy	27900.00
0005433234483	9831	Economy	27900.00
0005434724977	9831	Economy	27900.00
0005434725184	9831	Economy	27900.00
0005433234439	9831	Economy	27900.00
0005434550939	9831	Economy	27900.00
0005434725234	9831	Economy	27900.00
0005434724920	9831	Economy	27900.00
0005433234468	9831	Economy	27900.00
0005434724853	9831	Economy	27900.00
0005434550984	9831	Economy	27900.00
0005434724566	9831	Economy	27900.00
0005433234461	9831	Economy	27900.00
0005434550975	9831	Economy	27900.00
0005434735685	9831	Economy	27900.00
0005434032046	9831	Economy	27900.00
0005433289873	9831	Economy	27900.00
0005434735692	9831	Economy	27900.00
0005433234466	9831	Economy	30700.00
0005432199277	9831	Economy	27900.00
0005433181193	9831	Economy	30700.00
0005434550630	9831	Economy	30700.00
0005434724779	9831	Economy	27900.00
0005434725004	9831	Economy	27900.00
0005434724702	9831	Economy	27900.00
0005433234480	9831	Economy	30700.00
0005434550842	9831	Economy	30700.00
0005433234445	9831	Economy	27900.00
0005434724982	9831	Economy	27900.00
0005433289879	9831	Economy	27900.00
0005434724913	9831	Economy	27900.00
0005434725069	9831	Economy	27900.00
0005433234475	9831	Economy	27900.00
0005434550772	9831	Economy	27900.00
0005434725342	9831	Economy	27900.00
0005434551201	9831	Economy	27900.00
0005434550954	9831	Economy	27900.00
0005434724817	9831	Economy	27900.00
0005432199278	9831	Economy	27900.00
0005433234491	9831	Economy	27900.00
0005434724281	9831	Economy	27900.00
0005434724805	9831	Economy	27900.00
0005434724823	9831	Economy	27900.00
0005434724780	9831	Economy	27900.00
0005434724730	9831	Economy	27900.00
0005434735658	9831	Economy	27900.00
0005433289876	9831	Economy	27900.00
0005433181216	9831	Economy	27900.00
0005434551108	9831	Economy	27900.00
0005434551052	9831	Economy	27900.00
0005433234442	9831	Economy	27900.00
0005434725248	9831	Economy	27900.00
0005434735659	9831	Economy	27900.00
0005434725021	9831	Economy	27900.00
0005434724999	9831	Economy	27900.00
0005434724916	9831	Economy	27900.00
0005434725230	9831	Economy	27900.00
0005433234465	9831	Economy	27900.00
0005434550991	9831	Economy	27900.00
0005434550978	9831	Economy	27900.00
0005433234463	9831	Economy	27900.00
0005434550929	9831	Economy	27900.00
0005434725035	9831	Economy	27900.00
0005434551034	9831	Economy	27900.00
0005435142428	9831	Economy	27900.00
0005434725088	9831	Economy	27900.00
0005434724701	9831	Economy	27900.00
0005433181204	9831	Economy	27900.00
0005434724879	9831	Economy	27900.00
0005434724565	9831	Economy	27900.00
0005433234464	9831	Economy	27900.00
0005433234494	9831	Economy	27900.00
0005434724804	9831	Economy	27900.00
0005435142485	9831	Economy	27900.00
0005434550972	9831	Economy	27900.00
0005433766656	9831	Economy	27900.00
0005433234434	9831	Economy	27900.00
0005434724964	9831	Economy	27900.00
0005434725236	9831	Economy	27900.00
0005434550920	9831	Economy	27900.00
0005434032045	9831	Economy	27900.00
0005434724675	9831	Economy	27900.00
0005434551091	9831	Economy	27900.00
0005433181200	9831	Economy	27900.00
0005433181210	9831	Economy	27900.00
0005434032042	9831	Economy	27900.00
0005433181209	9831	Economy	27900.00
0005434725036	9831	Economy	27900.00
0005434724245	9831	Economy	27900.00
0005434724880	9831	Economy	27900.00
0005433234447	9831	Economy	27900.00
0005435142483	9831	Economy	27900.00
0005434551032	9831	Economy	27900.00
0005433126864	9831	Economy	27900.00
0005434725031	9831	Economy	27900.00
0005434550934	9831	Economy	27900.00
0005434725310	9831	Economy	27900.00
0005433766654	9831	Economy	27900.00
0005434550848	9831	Economy	27900.00
0005434551025	9831	Economy	27900.00
0005433766657	9831	Economy	27900.00
0005434725162	9831	Economy	27900.00
0005433234436	9831	Economy	27900.00
0005434724955	9831	Economy	27900.00
0005433234490	9831	Economy	27900.00
0005434551114	9831	Economy	27900.00
0005434551092	9831	Economy	27900.00
0005433234493	9831	Economy	27900.00
0005434550977	9831	Economy	27900.00
0005434551086	9831	Economy	27900.00
0005433181212	9831	Economy	27900.00
0005433129292	9831	Economy	27900.00
0005434735686	9831	Economy	27900.00
0005434725223	9831	Economy	27900.00
0005434725241	9831	Economy	27900.00
0005434725056	9831	Economy	27900.00
0005433234462	9831	Economy	27900.00
0005434724767	9831	Economy	27900.00
0005433234451	9831	Economy	27900.00
0005434032044	9831	Economy	27900.00
0005434550992	9831	Economy	27900.00
0005433181214	9831	Economy	27900.00
0005433234440	9831	Economy	27900.00
0005433234489	9831	Economy	27900.00
0005433234469	9831	Economy	27900.00
0005433234448	9831	Economy	27900.00
0005433129294	9831	Economy	27900.00
0005434724427	9831	Economy	30700.00
0005434550995	9831	Economy	30700.00
0005433181213	9831	Economy	30700.00
0005435142408	9831	Economy	30700.00
0005433234477	9831	Economy	30700.00
0005434725113	9831	Economy	27900.00
0005433181201	9831	Economy	27900.00
0005434550985	9831	Economy	27900.00
0005434724868	9831	Economy	27900.00
0005434725087	9831	Economy	27900.00
0005433234486	9831	Economy	27900.00
0005434724772	9831	Economy	27900.00
0005434550974	9831	Economy	27900.00
0005433234435	9831	Economy	27900.00
0005434725442	9831	Economy	27900.00
0005434724251	9831	Economy	27900.00
0005433234456	9831	Economy	27900.00
0005435142473	9831	Economy	27900.00
0005434724852	9831	Economy	27900.00
0005434551019	9831	Economy	27900.00
0005434725237	9831	Economy	27900.00
0005433129296	9831	Economy	27900.00
0005433234472	9831	Economy	27900.00
0005433234449	9831	Economy	27900.00
0005433234450	9831	Economy	27900.00
0005434725067	9831	Economy	27900.00
0005434550914	9831	Economy	27900.00
0005434551033	9831	Economy	27900.00
0005433234444	9831	Economy	27900.00
0005433234467	9831	Economy	27900.00
0005434550989	9831	Economy	27900.00
0005434724674	9831	Economy	27900.00
0005433234481	9831	Economy	27900.00
0005434725185	9831	Economy	27900.00
0005433181195	9831	Economy	27900.00
0005434725341	9831	Economy	27900.00
0005434724921	9831	Economy	27900.00
0005434724854	9831	Economy	27900.00
0005434550908	9831	Economy	27900.00
0005433234496	9831	Economy	27900.00
0005434725197	9831	Economy	27900.00
0005433289880	9831	Economy	27900.00
0005434725089	9831	Economy	27900.00
0005434725068	9831	Economy	27900.00
0005434724731	9831	Economy	27900.00
0005433234473	9831	Economy	27900.00
0005433289878	9831	Economy	27900.00
0005434725235	9831	Economy	27900.00
0005434550849	9831	Economy	27900.00
0005433234484	9831	Economy	27900.00
0005433126861	9831	Economy	27900.00
0005434550910	9831	Economy	27900.00
0005434725217	9831	Economy	27900.00
0005434725086	9831	Economy	27900.00
0005433126863	9831	Economy	27900.00
0005434550971	9831	Economy	27900.00
0005434551123	9831	Economy	27900.00
0005433181192	9831	Economy	27900.00
0005433181196	9831	Economy	27900.00
0005433181208	9831	Economy	27900.00
0005435142522	9831	Economy	27900.00
0005434724850	9831	Economy	27900.00
0005433234459	9831	Economy	27900.00
0005434724252	9831	Economy	27900.00
0005434550962	9831	Economy	27900.00
0005433234441	9831	Economy	27900.00
0005433766658	9831	Economy	27900.00
0005432199274	9831	Economy	27900.00
0005434551013	9831	Economy	27900.00
0005434724976	9831	Economy	27900.00
0005434725090	9831	Economy	27900.00
0005434724952	9831	Economy	27900.00
0005434725240	9831	Economy	27900.00
0005434550909	9831	Economy	27900.00
0005434551115	9831	Economy	27900.00
0005434550813	9831	Economy	27900.00
0005434550922	9831	Economy	27900.00
0005434725476	9831	Economy	27900.00
0005434724651	9831	Economy	27900.00
0005434550618	9831	Economy	27900.00
0005433181215	9831	Economy	27900.00
0005434724483	9831	Economy	27900.00
0005434550923	9831	Economy	27900.00
0005434725269	9831	Economy	27900.00
0005433234458	9831	Economy	27900.00
0005434725045	9831	Economy	27900.00
0005434724863	9831	Economy	27900.00
0005434550924	9831	Economy	27900.00
0005433181205	9831	Economy	27900.00
0005433234478	9831	Economy	27900.00
0005433181206	9831	Economy	27900.00
0005433234485	9831	Economy	27900.00
0005434735673	9831	Economy	27900.00
0005434550880	9831	Economy	27900.00
0005434550713	9831	Economy	27900.00
0005434551050	9831	Economy	27900.00
0005433289874	9831	Economy	27900.00
0005434551093	9831	Economy	27900.00
0005434550921	9831	Economy	27900.00
0005435142484	9831	Economy	27900.00
0005435142472	9831	Economy	27900.00
0005435142570	9831	Economy	27900.00
0005433181199	9831	Economy	27900.00
0005433113544	9831	Economy	27900.00
0005433234455	9831	Economy	27900.00
0005435213409	7739	Business	42100.00
0005435213097	7739	Business	42100.00
0005432528466	7739	Business	42100.00
0005432528493	7739	Business	42100.00
0005432528462	7739	Business	42100.00
0005435213302	7739	Business	42100.00
0005432528584	7739	Business	42100.00
0005432069717	7739	Business	42100.00
0005432528479	7739	Business	42100.00
0005434067877	7739	Business	42100.00
0005432528497	7739	Business	42100.00
0005435212868	7739	Business	42100.00
0005433656647	7739	Business	42100.00
0005432528469	7739	Business	42100.00
0005435212964	7739	Business	42100.00
0005432528560	7739	Business	42100.00
0005432528536	7739	Business	42100.00
0005432528503	7739	Business	42100.00
0005432528537	7739	Business	42100.00
0005432535851	7739	Business	42100.00
0005432528526	7739	Business	42100.00
0005435212928	7739	Business	42100.00
0005434067879	7739	Comfort	23900.00
0005432528460	7739	Comfort	23900.00
0005434067835	7739	Comfort	23900.00
0005432528568	7739	Comfort	23900.00
0005432528453	7739	Comfort	23900.00
0005432528534	7739	Comfort	23900.00
0005435212998	7739	Comfort	23900.00
0005435213380	7739	Comfort	23900.00
0005434067862	7739	Comfort	23900.00
0005432535856	7739	Comfort	23900.00
0005435213128	7739	Comfort	23900.00
0005432150227	7739	Comfort	23900.00
0005432528578	7739	Comfort	23900.00
0005432528535	7739	Comfort	23900.00
0005435213324	7739	Comfort	23900.00
0005432069712	7739	Comfort	23900.00
0005435213116	7739	Comfort	23900.00
0005432528492	7739	Comfort	23900.00
0005432528456	7739	Comfort	23900.00
0005432528582	7739	Comfort	23900.00
0005434067850	7739	Comfort	23900.00
0005432528523	7739	Comfort	23900.00
0005434067875	7739	Comfort	23900.00
0005435725562	7739	Comfort	23900.00
0005435212965	7739	Comfort	23900.00
0005432069721	7739	Comfort	23900.00
0005432528501	7739	Comfort	23900.00
0005432528484	7739	Comfort	23900.00
0005434067822	7739	Comfort	23900.00
0005432528550	7739	Comfort	23900.00
0005435213144	7739	Comfort	23900.00
0005432528575	7739	Comfort	23900.00
0005432528451	7739	Comfort	23900.00
0005434067865	7739	Comfort	23900.00
0005432069715	7739	Comfort	23900.00
0005432528500	7739	Comfort	23900.00
0005435213169	7739	Comfort	23900.00
0005432069709	7739	Comfort	23900.00
0005432528542	7739	Economy	14000.00
0005435213258	7739	Economy	14000.00
0005432069708	7739	Economy	14000.00
0005432069716	7739	Economy	14000.00
0005432528467	7739	Economy	14000.00
0005432528548	7739	Economy	14000.00
0005434067838	7739	Economy	14000.00
0005435213378	7739	Economy	14000.00
0005434067833	7739	Economy	14000.00
0005432528482	7739	Economy	14000.00
0005432528512	7739	Economy	14000.00
0005435213410	7739	Economy	14000.00
0005432528510	7739	Economy	14000.00
0005434067882	7739	Economy	14000.00
0005434067886	7739	Economy	14000.00
0005432150229	7739	Economy	14000.00
0005432537066	7739	Economy	14000.00
0005435213158	7739	Economy	14000.00
0005435213405	7739	Economy	14000.00
0005432528454	7739	Economy	14000.00
0005435213319	7739	Economy	14000.00
0005434067881	7739	Economy	14000.00
0005432528455	7739	Economy	14000.00
0005432528511	7739	Economy	14000.00
0005435213259	7739	Economy	14000.00
0005432528508	7739	Economy	14000.00
0005432528516	7739	Economy	14000.00
0005435212897	7739	Economy	14000.00
0005432069718	7739	Economy	14000.00
0005433656645	7739	Economy	14000.00
0005434067869	7739	Economy	14000.00
0005432528532	7739	Economy	14000.00
0005432528496	7739	Economy	14000.00
0005432528476	7739	Economy	14000.00
0005432528515	7739	Economy	14000.00
0005432528480	7739	Economy	14000.00
0005432528522	7739	Economy	14000.00
0005432528504	7739	Economy	14000.00
0005432528475	7739	Economy	14000.00
0005435213268	7739	Economy	14000.00
0005435213371	7739	Economy	14000.00
0005432528577	7739	Economy	14000.00
0005435213333	7739	Economy	14000.00
0005432528529	7739	Economy	14000.00
0005432528459	7739	Economy	14000.00
0005432528502	7739	Economy	14000.00
0005432528498	7739	Economy	14000.00
0005432528463	7739	Economy	14000.00
0005434067840	7739	Economy	14000.00
0005432535852	7739	Economy	14000.00
0005432528571	7739	Economy	14000.00
0005432528544	7739	Economy	14000.00
0005432528472	7739	Economy	14000.00
0005432069720	7739	Economy	14000.00
0005435725572	7739	Economy	14000.00
0005432150225	7739	Economy	14000.00
0005432528477	7739	Economy	14000.00
0005434067841	7739	Economy	14000.00
0005432528458	7739	Economy	14000.00
0005432528452	7739	Economy	14000.00
0005434067839	7739	Economy	15400.00
0005432528519	7739	Economy	15400.00
0005432535855	7739	Economy	14000.00
0005432528474	7739	Economy	14000.00
0005435213269	7739	Economy	14000.00
0005432528566	7739	Economy	15400.00
0005434067891	7739	Economy	15400.00
0005435213106	7739	Economy	15400.00
0005434067884	7739	Economy	14000.00
0005432528541	7739	Economy	14000.00
0005435213030	7739	Economy	14000.00
0005434067880	7739	Economy	14000.00
0005434067825	7739	Economy	14000.00
0005432528546	7739	Economy	14000.00
0005435212898	7739	Economy	14000.00
0005432528528	7739	Economy	14000.00
0005432528464	7739	Economy	14000.00
0005432528518	7739	Economy	14000.00
0005432528573	7739	Economy	14000.00
0005432528506	7739	Economy	14000.00
0005434067844	7739	Economy	14000.00
0005432528576	7739	Economy	14000.00
0005432528461	7739	Economy	14000.00
0005432528489	7739	Economy	14000.00
0005434067845	7739	Economy	14000.00
0005432528555	7739	Economy	14000.00
0005432528527	7739	Economy	14000.00
0005432150228	7739	Economy	14000.00
0005435213236	7739	Economy	14000.00
0005432528572	7739	Economy	14000.00
0005434067859	7739	Economy	14000.00
0005434067868	7739	Economy	14000.00
0005432528520	7739	Economy	14000.00
0005435212936	7739	Economy	14000.00
0005433656634	7739	Economy	14000.00
0005435212999	7739	Economy	14000.00
0005434067837	7739	Economy	14000.00
0005435725582	7739	Economy	14000.00
0005432528552	7739	Economy	14000.00
0005432150223	7739	Economy	14000.00
0005432528561	7739	Economy	14000.00
0005432528569	7739	Economy	14000.00
0005435212961	7739	Economy	14000.00
0005435213381	7739	Economy	14000.00
0005434067834	7739	Economy	14000.00
0005432528488	7739	Economy	14000.00
0005434067821	7739	Economy	14000.00
0005432528513	7739	Economy	14000.00
0005432528470	7739	Economy	14000.00
0005435212927	7739	Economy	14000.00
0005432528545	7739	Economy	14000.00
0005432428942	7739	Economy	14000.00
0005432528579	7739	Economy	14000.00
0005432528486	7739	Economy	14000.00
0005435213294	7739	Economy	14000.00
0005434067863	7739	Economy	14000.00
0005434067856	7739	Economy	14000.00
0005432528509	7739	Economy	14000.00
0005432528574	7739	Economy	14000.00
0005435213404	7739	Economy	14000.00
0005434067836	7739	Economy	14000.00
0005432428943	7739	Economy	14000.00
0005432069710	7739	Economy	14000.00
0005435213370	7739	Economy	14000.00
0005434067861	7739	Economy	14000.00
0005434067860	7739	Economy	14000.00
0005435213109	7739	Economy	14000.00
0005435212972	7739	Economy	14000.00
0005434067843	7739	Economy	14000.00
0005432528540	7739	Economy	14000.00
0005435213313	7739	Economy	14000.00
0005435725563	7739	Economy	14000.00
0005432528471	7739	Economy	14000.00
0005432528494	7739	Economy	14000.00
0005432528543	7739	Economy	14000.00
0005432528558	7739	Economy	14000.00
0005434067852	7739	Economy	14000.00
0005435213332	7739	Economy	14000.00
0005435213077	7739	Economy	14000.00
0005432528473	7739	Economy	14000.00
0005432537065	7739	Economy	14000.00
0005432528570	7739	Economy	14000.00
0005435213320	7739	Economy	14000.00
0005434067873	7739	Economy	14000.00
0005432528478	7739	Economy	14000.00
0005432528580	7739	Economy	14000.00
0005434067851	7739	Economy	14000.00
0005432069719	7739	Economy	14000.00
0005434067828	7739	Economy	14000.00
0005435213280	7739	Economy	14000.00
0005432537067	7739	Economy	14000.00
0005432528559	7739	Economy	14000.00
0005432069711	7739	Economy	14000.00
0005435213594	7739	Economy	14000.00
0005434067872	7739	Economy	14000.00
0005434067889	7739	Economy	14000.00
0005434067827	7739	Economy	14000.00
0005434067867	7739	Economy	14000.00
0005434067866	7739	Economy	14000.00
0005432528581	7739	Economy	14000.00
0005432528554	7739	Economy	14000.00
0005432528531	7739	Economy	14000.00
0005435213248	7739	Economy	14000.00
0005435213075	7739	Economy	14000.00
0005432528465	7739	Economy	15400.00
0005434067887	7739	Economy	15400.00
0005432528517	7739	Economy	15400.00
0005434067871	7739	Economy	14000.00
0005435213110	7739	Economy	15400.00
0005432528524	7739	Economy	15400.00
0005432069713	7739	Economy	14000.00
0005432528549	7739	Economy	14000.00
0005432528525	7739	Economy	14000.00
0005432069714	7739	Economy	14000.00
0005432535853	7739	Economy	14000.00
0005434067854	7739	Economy	14000.00
0005435213270	7739	Economy	14000.00
0005434067853	7739	Economy	14000.00
0005435213127	7739	Economy	14000.00
0005435212937	7739	Economy	14000.00
0005435213282	7739	Economy	14000.00
0005434067855	7739	Economy	14000.00
0005432150226	7739	Economy	14000.00
0005432528567	7739	Economy	14000.00
0005432528495	7739	Economy	14000.00
0005432528563	7739	Economy	14000.00
0005434067878	7739	Economy	14000.00
0005434067874	7739	Economy	14000.00
0005432528468	7739	Economy	14000.00
0005435213247	7739	Economy	14000.00
0005432533304	7739	Economy	14000.00
0005435213520	7739	Economy	14000.00
0005432069707	7739	Economy	14000.00
0005432535857	7739	Economy	14000.00
0005434067885	7739	Economy	14000.00
0005434067858	7739	Economy	14000.00
0005435213222	7739	Economy	14000.00
0005432528491	7739	Economy	14000.00
0005435213281	7739	Economy	14000.00
0005432533303	7739	Economy	14000.00
0005432528539	7739	Economy	14000.00
0005435213494	7739	Economy	14000.00
0005432528533	7739	Economy	14000.00
0005435213325	7739	Economy	14000.00
0005435213182	7739	Economy	14000.00
0005434067831	7739	Economy	14000.00
0005432150231	7739	Economy	14000.00
0005435213035	7739	Economy	14000.00
0005435213076	7739	Economy	14000.00
0005435213278	7739	Economy	14000.00
0005432528505	7739	Economy	14000.00
0005434067823	7739	Economy	14000.00
0005434067888	7739	Economy	14000.00
0005432528564	7739	Economy	14000.00
0005434067890	7739	Economy	14000.00
0005435213237	7739	Economy	14000.00
0005432528457	7739	Economy	14000.00
0005432528547	7739	Economy	14000.00
0005432528553	7739	Economy	14000.00
0005433656653	7739	Economy	14000.00
0005434067876	7739	Economy	14000.00
0005435213098	7739	Economy	14000.00
0005434067848	7739	Economy	14000.00
0005432528483	7739	Economy	14000.00
0005434067846	7739	Economy	14000.00
0005432150224	7739	Economy	14000.00
0005432528556	7739	Economy	14000.00
0005435213264	7739	Economy	14000.00
0005434067826	7739	Economy	14000.00
0005432528485	7739	Economy	14000.00
0005432528487	7739	Economy	14000.00
0005432528521	7739	Economy	14000.00
0005434067857	7739	Economy	14000.00
0005434067829	7739	Economy	14000.00
0005434067847	7739	Economy	14000.00
0005435725555	7739	Economy	14000.00
0005434067820	7739	Economy	14000.00
0005432528514	7739	Economy	14000.00
0005434067870	7739	Economy	14000.00
0005434067883	7739	Economy	14000.00
0005432528562	7739	Economy	14000.00
0005432528499	7739	Economy	14000.00
0005434067864	7739	Economy	14000.00
0005432528551	7739	Economy	14000.00
0005432528557	7739	Economy	14000.00
0005434067849	7739	Economy	14000.00
0005434067842	7739	Economy	14000.00
0005432528481	7739	Economy	14000.00
0005435213183	7739	Economy	14000.00
0005432428944	7739	Economy	14000.00
0005435212973	7739	Economy	14000.00
0005432535854	7739	Economy	14000.00
0005435213495	7739	Economy	14000.00
0005432528565	7739	Economy	14000.00
0005432528583	7739	Economy	14000.00
0005432528490	7739	Economy	14000.00
0005432528507	7739	Economy	14000.00
0005434067830	7739	Economy	14000.00
0005432528538	7739	Economy	14000.00
0005434067824	7739	Economy	14000.00
0005434067832	7739	Economy	14000.00
0005432528530	7739	Economy	14000.00
0005432150230	7739	Economy	14000.00
0005435424582	5360	Business	43100.00
0005435097243	5360	Business	43100.00
0005435614077	5360	Business	43100.00
0005432363394	5360	Business	43100.00
0005434244876	5360	Business	43100.00
0005435614166	5360	Business	43100.00
0005435424505	5360	Business	43100.00
0005432133276	5360	Business	43100.00
0005434344386	5360	Business	43100.00
0005434244702	5360	Business	43100.00
0005434344381	5360	Business	43100.00
0005435614115	5360	Business	43100.00
0005435424491	5360	Business	43100.00
0005434244922	5360	Business	43100.00
0005435614153	5360	Business	43100.00
0005434344372	5360	Business	43100.00
0005435614090	5360	Business	43100.00
0005435424764	5360	Business	43100.00
0005435614103	5360	Business	43100.00
0005435424511	5360	Business	43100.00
0005435424599	5360	Business	43100.00
0005435490241	5360	Business	43100.00
0005434573405	5360	Business	43100.00
0005435614092	5360	Business	43100.00
0005434344390	5360	Business	43100.00
0005435424577	5360	Business	43100.00
0005434344365	5360	Comfort	24400.00
0005435614160	5360	Business	43100.00
0005435424728	5360	Comfort	24400.00
0005434244902	5360	Comfort	24400.00
0005434344370	5360	Comfort	24400.00
0005434344379	5360	Comfort	24400.00
0005435614137	5360	Comfort	24400.00
0005435614127	5360	Comfort	24400.00
0005435614095	5360	Comfort	24400.00
0005435319549	5360	Comfort	24400.00
0005432133267	5360	Comfort	24400.00
0005435614081	5360	Comfort	24400.00
0005435614110	5360	Comfort	24400.00
0005434344367	5360	Comfort	24400.00
0005435614093	5360	Comfort	24400.00
0005434344395	5360	Comfort	24400.00
0005435424418	5360	Comfort	24400.00
0005435614113	5360	Comfort	24400.00
0005432133274	5360	Comfort	24400.00
0005435424806	5360	Comfort	24400.00
0005434344388	5360	Comfort	24400.00
0005434344394	5360	Comfort	24400.00
0005432133272	5360	Comfort	24400.00
0005435614082	5360	Comfort	24400.00
0005435424512	5360	Comfort	24400.00
0005435424522	5360	Comfort	24400.00
0005435380275	5360	Comfort	24400.00
0005435424077	5360	Comfort	24400.00
0005435424888	5360	Comfort	24400.00
0005435424605	5360	Comfort	24400.00
0005435614084	5360	Comfort	24400.00
0005435380265	5360	Comfort	24400.00
0005435302168	5360	Comfort	24400.00
0005435614121	5360	Comfort	24400.00
0005435424552	5360	Comfort	24400.00
0005435614136	5360	Comfort	24400.00
0005435097244	5360	Comfort	24400.00
0005435424597	5360	Comfort	24400.00
0005434244819	5360	Comfort	24400.00
0005434244845	5360	Comfort	24400.00
0005435614140	5360	Comfort	24400.00
0005434344384	5360	Comfort	24400.00
0005435490243	5360	Comfort	24400.00
0005434244904	5360	Comfort	24400.00
0005432133268	5360	Comfort	24400.00
0005435424134	5360	Comfort	24400.00
0005435614150	5360	Economy	14400.00
0005435424354	5360	Comfort	24400.00
0005435614149	5360	Economy	14400.00
0005435305007	5360	Economy	14400.00
0005432133273	5360	Economy	14400.00
0005435380264	5360	Economy	14400.00
0005435614162	5360	Economy	14400.00
0005435614147	5360	Economy	14400.00
0005435614112	5360	Economy	14400.00
0005432841001	5360	Economy	14400.00
0005435614083	5360	Economy	14400.00
0005434573414	5360	Economy	14400.00
0005434344380	5360	Economy	14400.00
0005435424821	5360	Economy	14400.00
0005435424664	5360	Economy	14400.00
0005434244966	5360	Economy	14400.00
0005435614105	5360	Economy	14400.00
0005435614099	5360	Economy	14400.00
0005435614098	5360	Economy	14400.00
0005435614173	5360	Economy	14400.00
0005435097238	5360	Economy	14400.00
0005434244804	5360	Economy	14400.00
0005435424504	5360	Economy	14400.00
0005435614175	5360	Economy	14400.00
0005435319524	5360	Economy	14400.00
0005434573407	5360	Economy	14400.00
0005435424523	5360	Economy	14400.00
0005435555378	5360	Economy	14400.00
0005434244867	5360	Economy	14400.00
0005434244866	5360	Economy	14400.00
0005435424492	5360	Economy	14400.00
0005435614107	5360	Economy	14400.00
0005435424567	5360	Economy	14400.00
0005435097241	5360	Economy	14400.00
0005434244969	5360	Economy	14400.00
0005435614114	5360	Economy	14400.00
0005435555377	5360	Economy	14400.00
0005435424120	5360	Economy	14400.00
0005435424654	5360	Economy	14400.00
0005435424249	5360	Economy	14400.00
0005432363393	5360	Economy	14400.00
0005434244762	5360	Economy	14400.00
0005435424568	5360	Economy	14400.00
0005435424486	5360	Economy	14400.00
0005433719126	5360	Economy	14400.00
0005434244758	5360	Economy	14400.00
0005432133269	5360	Economy	14400.00
0005432133275	5360	Economy	14400.00
0005435614076	5360	Economy	14400.00
0005434573412	5360	Economy	14400.00
0005435424704	5360	Economy	14400.00
0005435424343	5360	Economy	14400.00
0005435614169	5360	Economy	14400.00
0005434244814	5360	Economy	14400.00
0005434573404	5360	Economy	14400.00
0005435424428	5360	Economy	14400.00
0005434573408	5360	Economy	14400.00
0005435614167	5360	Economy	14400.00
0005434244872	5360	Economy	14400.00
0005435424719	5360	Economy	14400.00
0005435424598	5360	Economy	14400.00
0005435424550	5360	Economy	14400.00
0005432047567	5360	Economy	15800.00
0005435424445	5360	Economy	15800.00
0005435614131	5360	Economy	14400.00
0005434344396	5360	Economy	15800.00
0005435424636	5360	Economy	14400.00
0005435305000	5360	Economy	14400.00
0005434244808	5360	Economy	15800.00
0005435097240	5360	Economy	14400.00
0005432133278	5360	Economy	15800.00
0005432133266	5360	Economy	14400.00
0005433719105	5360	Economy	14400.00
0005434344366	5360	Economy	14400.00
0005435042838	5360	Economy	14400.00
0005434344398	5360	Economy	14400.00
0005435614087	5360	Economy	14400.00
0005435042843	5360	Economy	14400.00
0005434244871	5360	Economy	14400.00
0005435614146	5360	Economy	14400.00
0005434244701	5360	Economy	14400.00
0005434244903	5360	Economy	14400.00
0005434573410	5360	Economy	14400.00
0005435614126	5360	Economy	14400.00
0005434244815	5360	Economy	14400.00
0005435614142	5360	Economy	14400.00
0005434344385	5360	Economy	14400.00
0005434344371	5360	Economy	14400.00
0005434244897	5360	Economy	14400.00
0005434244905	5360	Economy	14400.00
0005435424446	5360	Economy	14400.00
0005435614102	5360	Economy	14400.00
0005435424720	5360	Economy	14400.00
0005435614158	5360	Economy	14400.00
0005435424604	5360	Economy	14400.00
0005435614176	5360	Economy	14400.00
0005435424485	5360	Economy	14400.00
0005432363397	5360	Economy	14400.00
0005435614170	5360	Economy	14400.00
0005432047564	5360	Economy	14400.00
0005435424540	5360	Economy	14400.00
0005435614129	5360	Economy	14400.00
0005435614163	5360	Economy	14400.00
0005435097236	5360	Economy	14400.00
0005432133280	5360	Economy	14400.00
0005435614089	5360	Economy	14400.00
0005435614141	5360	Economy	14400.00
0005435424213	5360	Economy	14400.00
0005434244939	5360	Economy	14400.00
0005435490245	5360	Economy	14400.00
0005435424651	5360	Economy	14400.00
0005435614125	5360	Economy	14400.00
0005435614097	5360	Economy	14400.00
0005435614106	5360	Economy	14400.00
0005435614154	5360	Economy	14400.00
0005435614171	5360	Economy	14400.00
0005435424524	5360	Economy	14400.00
0005434344363	5360	Economy	14400.00
0005435319558	5360	Economy	14400.00
0005435424393	5360	Economy	14400.00
0005434244844	5360	Economy	14400.00
0005435424551	5360	Economy	14400.00
0005435614148	5360	Economy	14400.00
0005434244638	5360	Economy	14400.00
0005435614117	5360	Economy	14400.00
0005434244810	5360	Economy	14400.00
0005434344368	5360	Economy	14400.00
0005434344378	5360	Economy	14400.00
0005433719125	5360	Economy	14400.00
0005434573415	5360	Economy	14400.00
0005435424565	5360	Economy	14400.00
0005432363392	5360	Economy	14400.00
0005432841016	5360	Economy	14400.00
0005435097245	5360	Economy	14400.00
0005435424665	5360	Economy	14400.00
0005435424652	5360	Economy	14400.00
0005433719098	5360	Economy	14400.00
0005432047565	5360	Economy	14400.00
0005435424447	5360	Economy	14400.00
0005435614143	5360	Economy	14400.00
0005434344375	5360	Economy	14400.00
0005435424566	5360	Economy	14400.00
0005434344374	5360	Economy	14400.00
0005432133271	5360	Economy	14400.00
0005435614157	5360	Economy	14400.00
0005435614094	5360	Economy	14400.00
0005435097239	5360	Economy	14400.00
0005434244968	5360	Economy	14400.00
0005435097237	5360	Economy	14400.00
0005435424483	5360	Economy	14400.00
0005435424525	5360	Economy	14400.00
0005435097242	5360	Economy	14400.00
0005435614108	5360	Economy	14400.00
0005435424458	5360	Economy	14400.00
0005434244851	5360	Economy	14400.00
0005435614079	5360	Economy	14400.00
0005434344393	5360	Economy	14400.00
0005434344364	5360	Economy	14400.00
0005435614091	5360	Economy	14400.00
0005434244809	5360	Economy	14400.00
0005435424712	5360	Economy	14400.00
0005435614122	5360	Economy	14400.00
0005435424797	5360	Economy	14400.00
0005435424441	5360	Economy	14400.00
0005434344383	5360	Economy	14400.00
0005435614172	5360	Economy	14400.00
0005435424655	5360	Economy	14400.00
0005435424113	5360	Economy	14400.00
0005435614138	5360	Economy	14400.00
0005435424431	5360	Economy	14400.00
0005434344382	5360	Economy	14400.00
0005435614156	5360	Economy	14400.00
0005435614130	5360	Economy	14400.00
0005434573416	5360	Economy	14400.00
0005435302178	5360	Economy	14400.00
0005435424355	5360	Economy	14400.00
0005435319550	5360	Economy	15800.00
0005435614159	5360	Economy	14400.00
0005435319571	5360	Economy	15800.00
0005435614135	5360	Economy	15800.00
0005434573417	5360	Economy	15800.00
0005435614116	5360	Economy	15800.00
0005434244995	5360	Economy	14400.00
0005435424569	5360	Economy	14400.00
0005435490244	5360	Economy	14400.00
0005435614101	5360	Economy	14400.00
0005434573418	5360	Economy	14400.00
0005435424614	5360	Economy	14400.00
0005435614109	5360	Economy	14400.00
0005435302177	5360	Economy	14400.00
0005435614155	5360	Economy	14400.00
0005435424394	5360	Economy	14400.00
0005435042844	5360	Economy	14400.00
0005435424404	5360	Economy	14400.00
0005435614164	5360	Economy	14400.00
0005432363402	5360	Economy	14400.00
0005434344369	5360	Economy	14400.00
0005435614151	5360	Economy	14400.00
0005435614144	5360	Economy	14400.00
0005434344373	5360	Economy	14400.00
0005433719134	5360	Economy	14400.00
0005435614120	5360	Economy	14400.00
0005435614134	5360	Economy	14400.00
0005432133277	5360	Economy	14400.00
0005434344389	5360	Economy	14400.00
0005435424585	5360	Economy	14400.00
0005432133279	5360	Economy	14400.00
0005434344397	5360	Economy	14400.00
0005434344362	5360	Economy	14400.00
0005432047566	5360	Economy	14400.00
0005435424417	5360	Economy	14400.00
0005434344377	5360	Economy	14400.00
0005435614152	5360	Economy	14400.00
0005435614132	5360	Economy	14400.00
0005434244820	5360	Economy	14400.00
0005432363396	5360	Economy	14400.00
0005434573411	5360	Economy	14400.00
0005435614161	5360	Economy	14400.00
0005435614096	5360	Economy	14400.00
0005435319557	5360	Economy	14400.00
0005435424763	5360	Economy	14400.00
0005435424638	5360	Economy	14400.00
0005435614168	5360	Economy	14400.00
0005434573409	5360	Economy	14400.00
0005435614086	5360	Economy	14400.00
0005435424612	5360	Economy	14400.00
0005434244791	5360	Economy	14400.00
0005435614100	5360	Economy	14400.00
0005435614078	5360	Economy	14400.00
0005435424637	5360	Economy	14400.00
0005435614104	5360	Economy	14400.00
0005434244757	5360	Economy	14400.00
0005432363391	5360	Economy	14400.00
0005434244805	5360	Economy	14400.00
0005435614080	5360	Economy	14400.00
0005432840995	5360	Economy	14400.00
0005435424539	5360	Economy	14400.00
0005435614119	5360	Economy	14400.00
0005432133270	5360	Economy	14400.00
0005435614088	5360	Economy	14400.00
0005432841000	5360	Economy	14400.00
0005435424679	5360	Economy	14400.00
0005435614111	5360	Economy	14400.00
0005432363405	5360	Economy	14400.00
0005434344387	5360	Economy	14400.00
0005435614085	5360	Economy	14400.00
0005435614118	5360	Economy	14400.00
0005435424711	5360	Economy	14400.00
0005434344392	5360	Economy	14400.00
0005435614139	5360	Economy	14400.00
0005434244896	5360	Economy	14400.00
0005434244906	5360	Economy	14400.00
0005435424440	5360	Economy	14400.00
0005435490242	5360	Economy	14400.00
0005434244792	5360	Economy	14400.00
0005434344376	5360	Economy	14400.00
0005435424594	5360	Economy	14400.00
0005435424889	5360	Economy	14400.00
0005434344391	5360	Economy	14400.00
0005435614128	5360	Economy	14400.00
0005435614174	5360	Economy	14400.00
0005435097246	5360	Economy	14400.00
0005434573406	5360	Economy	14400.00
0005435614123	5360	Economy	14400.00
0005434573413	5360	Economy	14400.00
0005435424606	5360	Economy	14400.00
0005435424541	5360	Economy	14400.00
0005435614124	5360	Economy	14400.00
0005435380276	5360	Economy	14400.00
0005435614145	5360	Economy	14400.00
0005434244751	5360	Economy	14400.00
0005434244938	5360	Economy	14400.00
0005435614165	5360	Economy	14400.00
0005435614133	5360	Economy	14400.00
0005435612686	10882	Business	43100.00
0005435613436	10882	Business	43100.00
0005434344037	10882	Business	43100.00
0005435425112	10882	Business	43100.00
0005435613101	10882	Business	43100.00
0005434656564	10882	Business	43100.00
0005434245104	10882	Business	43100.00
0005435304178	10882	Business	43100.00
0005435613254	10882	Business	43100.00
0005435425069	10882	Business	43100.00
0005435613289	10882	Business	43100.00
0005435425084	10882	Business	43100.00
0005435425058	10882	Business	43100.00
0005435097119	10882	Business	43100.00
0005435097135	10882	Business	43100.00
0005435097149	10882	Business	43100.00
0005432363430	10882	Business	43100.00
0005435613118	10882	Business	43100.00
0005435304175	10882	Business	43100.00
0005434343968	10882	Business	43100.00
0005434343896	10882	Business	43100.00
0005434344174	10882	Business	43100.00
0005435490213	10882	Business	43100.00
0005434343883	10882	Business	43100.00
0005435613239	10882	Business	43100.00
0005435613167	10882	Comfort	24400.00
0005435612992	10882	Comfort	24400.00
0005435613342	10882	Comfort	24400.00
0005434245103	10882	Comfort	24400.00
0005435613242	10882	Comfort	24400.00
0005435425120	10882	Comfort	24400.00
0005434344080	10882	Comfort	24400.00
0005434573247	10882	Comfort	24400.00
0005435425073	10882	Comfort	24400.00
0005435305018	10882	Comfort	24400.00
0005435613138	10882	Comfort	24400.00
0005435425062	10882	Comfort	24400.00
0005434245096	10882	Comfort	24400.00
0005435425089	10882	Comfort	24400.00
0005434344094	10882	Comfort	24400.00
0005435613193	10882	Comfort	24400.00
0005435097116	10882	Comfort	24400.00
0005434573199	10882	Comfort	24400.00
0005434245101	10882	Comfort	24400.00
0005434245086	10882	Comfort	24400.00
0005435097128	10882	Comfort	24400.00
0005435612791	10882	Comfort	24400.00
0005435425107	10882	Comfort	24400.00
0005434573250	10882	Comfort	24400.00
0005434656565	10882	Comfort	24400.00
0005435097143	10882	Comfort	24400.00
0005435613244	10882	Comfort	24400.00
0005432363429	10882	Comfort	24400.00
0005435612965	10882	Comfort	24400.00
0005434573263	10882	Comfort	24400.00
0005434343947	10882	Comfort	24400.00
0005435425059	10882	Comfort	24400.00
0005435613330	10882	Comfort	24400.00
0005435305016	10882	Comfort	24400.00
0005435613005	10882	Comfort	24400.00
0005435425111	10882	Comfort	24400.00
0005434245111	10882	Comfort	24400.00
0005435612906	10882	Comfort	24400.00
0005435613146	10882	Economy	14400.00
0005435490209	10882	Economy	14400.00
0005434344081	10882	Economy	14400.00
0005435613418	10882	Economy	14400.00
0005435490210	10882	Economy	14400.00
0005434343929	10882	Economy	14400.00
0005435425088	10882	Economy	14400.00
0005435425100	10882	Economy	14400.00
0005435613346	10882	Economy	14400.00
0005435612826	10882	Economy	14400.00
0005433719156	10882	Economy	14400.00
0005434343967	10882	Economy	14400.00
0005435425063	10882	Economy	14400.00
0005435612989	10882	Economy	14400.00
0005435425125	10882	Economy	14400.00
0005435490217	10882	Economy	14400.00
0005435491439	10882	Economy	14400.00
0005435613166	10882	Economy	14400.00
0005433719154	10882	Economy	14400.00
0005435613556	10882	Economy	14400.00
0005435612673	10882	Economy	14400.00
0005435304177	10882	Economy	14400.00
0005435612792	10882	Economy	14400.00
0005434245092	10882	Economy	14400.00
0005435612910	10882	Economy	14400.00
0005435319605	10882	Economy	14400.00
0005434343878	10882	Economy	14400.00
0005435613777	10882	Economy	14400.00
0005434344101	10882	Economy	14400.00
0005435425123	10882	Economy	14400.00
0005435097129	10882	Economy	14400.00
0005432363428	10882	Economy	14400.00
0005435425106	10882	Economy	14400.00
0005435613014	10882	Economy	14400.00
0005434245102	10882	Economy	14400.00
0005434245094	10882	Economy	14400.00
0005435612917	10882	Economy	14400.00
0005435613065	10882	Economy	14400.00
0005435613446	10882	Economy	14400.00
0005435425122	10882	Economy	14400.00
0005435425072	10882	Economy	14400.00
0005435425078	10882	Economy	14400.00
0005432166914	10882	Economy	14400.00
0005432166916	10882	Economy	14400.00
0005435425070	10882	Economy	14400.00
0005435613111	10882	Economy	14400.00
0005435425109	10882	Economy	14400.00
0005435425094	10882	Economy	14400.00
0005435612911	10882	Economy	14400.00
0005435425103	10882	Economy	14400.00
0005435613439	10882	Economy	14400.00
0005434344011	10882	Economy	14400.00
0005435612986	10882	Economy	14400.00
0005435097150	10882	Economy	14400.00
0005435425090	10882	Economy	14400.00
0005435042864	10882	Economy	14400.00
0005434344098	10882	Economy	15800.00
0005435425081	10882	Economy	15800.00
0005435319614	10882	Economy	15800.00
0005435425060	10882	Economy	14400.00
0005435319613	10882	Economy	14400.00
0005434245093	10882	Economy	14400.00
0005435425124	10882	Economy	15800.00
0005435613309	10882	Economy	14400.00
0005435319608	10882	Economy	15800.00
0005434344133	10882	Economy	14400.00
0005435425064	10882	Economy	14400.00
0005434245087	10882	Economy	14400.00
0005435612932	10882	Economy	14400.00
0005435425074	10882	Economy	14400.00
0005434245106	10882	Economy	14400.00
0005435555364	10882	Economy	14400.00
0005434245112	10882	Economy	14400.00
0005435613139	10882	Economy	14400.00
0005435613170	10882	Economy	14400.00
0005434245107	10882	Economy	14400.00
0005432841022	10882	Economy	14400.00
0005435612651	10882	Economy	14400.00
0005435613237	10882	Economy	14400.00
0005435612839	10882	Economy	14400.00
0005435613102	10882	Economy	14400.00
0005435319609	10882	Economy	14400.00
0005435425092	10882	Economy	14400.00
0005435613348	10882	Economy	14400.00
0005435425068	10882	Economy	14400.00
0005435425066	10882	Economy	14400.00
0005435555357	10882	Economy	14400.00
0005435612652	10882	Economy	14400.00
0005435612688	10882	Economy	14400.00
0005432363431	10882	Economy	14400.00
0005434344042	10882	Economy	14400.00
0005435555363	10882	Economy	14400.00
0005435425076	10882	Economy	14400.00
0005435425085	10882	Economy	14400.00
0005435613595	10882	Economy	14400.00
0005435097142	10882	Economy	14400.00
0005435613474	10882	Economy	14400.00
0005435612689	10882	Economy	14400.00
0005434343953	10882	Economy	14400.00
0005434245100	10882	Economy	14400.00
0005435491426	10882	Economy	14400.00
0005435425101	10882	Economy	14400.00
0005434344013	10882	Economy	14400.00
0005435613347	10882	Economy	14400.00
0005435425080	10882	Economy	14400.00
0005435612860	10882	Economy	14400.00
0005435613036	10882	Economy	14400.00
0005434573246	10882	Economy	14400.00
0005435425118	10882	Economy	14400.00
0005435097165	10882	Economy	14400.00
0005434344136	10882	Economy	14400.00
0005435613310	10882	Economy	14400.00
0005435613085	10882	Economy	14400.00
0005435612931	10882	Economy	14400.00
0005435097164	10882	Economy	14400.00
0005435425115	10882	Economy	14400.00
0005435425086	10882	Economy	14400.00
0005435425113	10882	Economy	14400.00
0005435613131	10882	Economy	14400.00
0005434344010	10882	Economy	14400.00
0005432165071	10882	Economy	14400.00
0005434245091	10882	Economy	14400.00
0005434573200	10882	Economy	14400.00
0005435612806	10882	Economy	14400.00
0005435613341	10882	Economy	14400.00
0005434245109	10882	Economy	14400.00
0005435613245	10882	Economy	14400.00
0005433719155	10882	Economy	14400.00
0005435425057	10882	Economy	14400.00
0005434245090	10882	Economy	14400.00
0005435425096	10882	Economy	14400.00
0005435612916	10882	Economy	14400.00
0005434573272	10882	Economy	14400.00
0005435319607	10882	Economy	14400.00
0005434343930	10882	Economy	14400.00
0005435612980	10882	Economy	14400.00
0005435612694	10882	Economy	14400.00
0005435613165	10882	Economy	14400.00
0005435613073	10882	Economy	14400.00
0005435491427	10882	Economy	14400.00
0005435613303	10882	Economy	14400.00
0005434344025	10882	Economy	14400.00
0005435097136	10882	Economy	14400.00
0005435613220	10882	Economy	14400.00
0005435425065	10882	Economy	14400.00
0005435613238	10882	Economy	14400.00
0005434343931	10882	Economy	14400.00
0005435613206	10882	Economy	14400.00
0005432165067	10882	Economy	14400.00
0005435612727	10882	Economy	14400.00
0005435612855	10882	Economy	14400.00
0005435319612	10882	Economy	14400.00
0005435425114	10882	Economy	14400.00
0005435612668	10882	Economy	14400.00
0005435612381	10882	Economy	14400.00
0005432165072	10882	Economy	14400.00
0005435425056	10882	Economy	14400.00
0005435613169	10882	Economy	14400.00
0005435613429	10882	Economy	14400.00
0005434343962	10882	Economy	14400.00
0005432165066	10882	Economy	14400.00
0005435425121	10882	Economy	14400.00
0005435042861	10882	Economy	14400.00
0005435425108	10882	Economy	14400.00
0005434573225	10882	Economy	15800.00
0005435425095	10882	Economy	15800.00
0005435319606	10882	Economy	14400.00
0005435613115	10882	Economy	15800.00
0005435613015	10882	Economy	14400.00
0005432166915	10882	Economy	14400.00
0005435425067	10882	Economy	14400.00
0005434245114	10882	Economy	14400.00
0005435425098	10882	Economy	14400.00
0005435425104	10882	Economy	14400.00
0005434343897	10882	Economy	14400.00
0005435097151	10882	Economy	14400.00
0005435613253	10882	Economy	14400.00
0005435612678	10882	Economy	14400.00
0005435425105	10882	Economy	14400.00
0005435612746	10882	Economy	14400.00
0005434245115	10882	Economy	14400.00
0005435613125	10882	Economy	14400.00
0005435425117	10882	Economy	14400.00
0005434245098	10882	Economy	14400.00
0005434344100	10882	Economy	14400.00
0005434245105	10882	Economy	14400.00
0005435304174	10882	Economy	14400.00
0005435425079	10882	Economy	14400.00
0005435613345	10882	Economy	14400.00
0005434343976	10882	Economy	14400.00
0005435097141	10882	Economy	14400.00
0005435612969	10882	Economy	14400.00
0005435612849	10882	Economy	14400.00
0005435613335	10882	Economy	14400.00
0005435613218	10882	Economy	14400.00
0005435612999	10882	Economy	14400.00
0005435425087	10882	Economy	14400.00
0005435304176	10882	Economy	14400.00
0005432165069	10882	Economy	14400.00
0005435613117	10882	Economy	14400.00
0005432165068	10882	Economy	14400.00
0005434245089	10882	Economy	14400.00
0005435612871	10882	Economy	14400.00
0005435613331	10882	Economy	14400.00
0005434245110	10882	Economy	14400.00
0005434343855	10882	Economy	14400.00
0005434573204	10882	Economy	14400.00
0005434245095	10882	Economy	14400.00
0005435425082	10882	Economy	14400.00
0005435425071	10882	Economy	14400.00
0005434344110	10882	Economy	14400.00
0005435613485	10882	Economy	14400.00
0005432165070	10882	Economy	14400.00
0005435042862	10882	Economy	14400.00
0005432841021	10882	Economy	14400.00
0005435425119	10882	Economy	14400.00
0005435613047	10882	Economy	14400.00
0005435613251	10882	Economy	14400.00
0005435305017	10882	Economy	14400.00
0005434343963	10882	Economy	14400.00
0005435613079	10882	Economy	14400.00
0005434343939	10882	Economy	14400.00
0005435425083	10882	Economy	14400.00
0005435612868	10882	Economy	14400.00
0005434245088	10882	Economy	14400.00
0005435425091	10882	Economy	14400.00
0005435425110	10882	Economy	14400.00
0005435425077	10882	Economy	14400.00
0005435555356	10882	Economy	14400.00
0005435319610	10882	Economy	14400.00
0005435613456	10882	Economy	14400.00
0005434343957	10882	Economy	14400.00
0005435613263	10882	Economy	14400.00
0005434573222	10882	Economy	14400.00
0005435613387	10882	Economy	14400.00
0005435425075	10882	Economy	14400.00
0005435613140	10882	Economy	14400.00
0005434245113	10882	Economy	14400.00
0005435042863	10882	Economy	14400.00
0005435613284	10882	Economy	14400.00
0005435613096	10882	Economy	14400.00
0005434343927	10882	Economy	14400.00
0005435425099	10882	Economy	14400.00
0005435613575	10882	Economy	14400.00
0005435319611	10882	Economy	14400.00
0005435613430	10882	Economy	14400.00
0005435425061	10882	Economy	14400.00
0005434344067	10882	Economy	14400.00
0005435613019	10882	Economy	14400.00
0005435613067	10882	Economy	14400.00
0005432166913	10882	Economy	14400.00
0005435425093	10882	Economy	14400.00
0005435425116	10882	Economy	14400.00
0005435613084	10882	Economy	14400.00
0005435425097	10882	Economy	14400.00
0005434245108	10882	Economy	14400.00
0005435613219	10882	Economy	14400.00
0005435612747	10882	Economy	14400.00
0005434245097	10882	Economy	14400.00
0005435425102	10882	Economy	14400.00
0005434343948	10882	Economy	14400.00
0005434245099	10882	Economy	14400.00
0005432165065	10882	Economy	14400.00
0005435612805	10882	Economy	14400.00
0005435612728	10882	Economy	14400.00
0005435613009	10882	Economy	14400.00
0005435612930	10882	Economy	14400.00
0005433805512	3278	Business	18800.00
0005432459498	3278	Business	18800.00
0005433805517	3278	Business	18800.00
0005433805513	3278	Business	18800.00
0005433507255	3278	Business	18800.00
0005432459399	3278	Business	18800.00
0005432459589	3278	Business	18800.00
0005433805514	3278	Business	18800.00
0005432459712	3278	Business	18800.00
0005433805516	3278	Business	18800.00
0005432459387	3278	Business	18800.00
0005433633955	3278	Business	18800.00
0005432181821	3278	Business	18800.00
0005433507262	3278	Business	18800.00
0005432459455	3278	Business	18800.00
0005432181812	3278	Business	18800.00
0005433805533	3278	Business	18800.00
0005433805509	3278	Business	18800.00
0005433507263	3278	Business	18800.00
0005433805526	3278	Business	18800.00
0005432459657	3278	Business	18800.00
0005432459454	3278	Business	18800.00
0005432181817	3278	Business	18800.00
0005432459607	3278	Business	18800.00
0005432459666	3278	Business	18800.00
0005433805523	3278	Business	18800.00
0005433633951	3278	Business	18800.00
0005432459784	3278	Business	18800.00
0005433805511	3278	Economy	6900.00
0005432459671	3278	Economy	6900.00
0005432181810	3278	Economy	6900.00
0005432459591	3278	Economy	6900.00
0005433633980	3278	Economy	6900.00
0005432459605	3278	Economy	6900.00
0005433507268	3278	Economy	6300.00
0005433805522	3278	Economy	6300.00
0005433633946	3278	Economy	6300.00
0005432459364	3278	Economy	6300.00
0005432181813	3278	Economy	6300.00
0005432181799	3278	Economy	6300.00
0005433633963	3278	Economy	6300.00
0005433633973	3278	Economy	6300.00
0005432459518	3278	Economy	6300.00
0005432459691	3278	Economy	6300.00
0005432459711	3278	Economy	6300.00
0005433633960	3278	Economy	6300.00
0005433633947	3278	Economy	6300.00
0005432459670	3278	Economy	6300.00
0005433633964	3278	Economy	6300.00
0005433633965	3278	Economy	6300.00
0005432459478	3278	Economy	6300.00
0005433507259	3278	Economy	6300.00
0005433633956	3278	Economy	6300.00
0005432459642	3278	Economy	6300.00
0005432459398	3278	Economy	6300.00
0005432181803	3278	Economy	6300.00
0005432459658	3278	Economy	6300.00
0005433507265	3278	Economy	6300.00
0005432459633	3278	Economy	6300.00
0005433633962	3278	Economy	6300.00
0005432459644	3278	Economy	6300.00
0005433633967	3278	Economy	6300.00
0005433633949	3278	Economy	6300.00
0005432181818	3278	Economy	6300.00
0005433805507	3278	Economy	6300.00
0005432459573	3278	Economy	6300.00
0005432181802	3278	Economy	6300.00
0005433507254	3278	Economy	6300.00
0005432181816	3278	Economy	6300.00
0005432181804	3278	Economy	6300.00
0005433805534	3278	Economy	6300.00
0005432181820	3278	Economy	6300.00
0005432459761	3278	Economy	6300.00
0005432459528	3278	Economy	6300.00
0005432459590	3278	Economy	6300.00
0005432459413	3278	Economy	6300.00
0005433633971	3278	Economy	6300.00
0005433633975	3278	Economy	6300.00
0005433507257	3278	Economy	6300.00
0005433805518	3278	Economy	6300.00
0005432181801	3278	Economy	6300.00
0005432181805	3278	Economy	6300.00
0005432459494	3278	Economy	6300.00
0005433805521	3278	Economy	6300.00
0005432459525	3278	Economy	6300.00
0005433633954	3278	Economy	6300.00
0005433805506	3278	Economy	6300.00
0005433805515	3278	Economy	6300.00
0005432181819	3278	Economy	6300.00
0005433633981	3278	Economy	6300.00
0005432459665	3278	Economy	6300.00
0005432181800	3278	Economy	6300.00
0005433633970	3278	Economy	6300.00
0005432459550	3278	Economy	6300.00
0005433805519	3278	Economy	6900.00
0005432459517	3278	Economy	6900.00
0005432459486	3278	Economy	6900.00
0005433805531	3278	Economy	6900.00
0005432459466	3278	Economy	6900.00
0005433633969	3278	Economy	6300.00
0005433633948	3278	Economy	6300.00
0005432459778	3278	Economy	6300.00
0005433633966	3278	Economy	6300.00
0005433507252	3278	Economy	6900.00
0005433805508	3278	Economy	6300.00
0005433805527	3278	Economy	6300.00
0005432459667	3278	Economy	6300.00
0005432459606	3278	Economy	6300.00
0005433507251	3278	Economy	6300.00
0005433507253	3278	Economy	6300.00
0005432459634	3278	Economy	6300.00
0005432459524	3278	Economy	6300.00
0005433507267	3278	Economy	6300.00
0005432459495	3278	Economy	6300.00
0005433507256	3278	Economy	6300.00
0005432181808	3278	Economy	6300.00
0005433633959	3278	Economy	6300.00
0005432181811	3278	Economy	6300.00
0005433507258	3278	Economy	6300.00
0005433633974	3278	Economy	6300.00
0005433507261	3278	Economy	6300.00
0005432459592	3278	Economy	6300.00
0005433633961	3278	Economy	6300.00
0005432459635	3278	Economy	6300.00
0005433633977	3278	Economy	6300.00
0005433633979	3278	Economy	6300.00
0005433805535	3278	Economy	6300.00
0005433507260	3278	Economy	6300.00
0005433507266	3278	Economy	6300.00
0005432459551	3278	Economy	6300.00
0005432459643	3278	Economy	6300.00
0005433633953	3278	Economy	6300.00
0005432459821	3278	Economy	6300.00
0005433805520	3278	Economy	6300.00
0005433805525	3278	Economy	6300.00
0005432181809	3278	Economy	6300.00
0005432181814	3278	Economy	6300.00
0005433507264	3278	Economy	6300.00
0005432459713	3278	Economy	6300.00
0005433633968	3278	Economy	6300.00
0005432459552	3278	Economy	6300.00
0005433633972	3278	Economy	6300.00
0005433633958	3278	Economy	6300.00
0005432459636	3278	Economy	6300.00
0005433805530	3278	Economy	6300.00
0005432459783	3278	Economy	6300.00
0005433633952	3278	Economy	6300.00
0005433633950	3278	Economy	6300.00
0005433805528	3278	Economy	6300.00
0005432459531	3278	Economy	6300.00
0005432181815	3278	Economy	6300.00
0005432181807	3278	Economy	6300.00
0005432459574	3278	Economy	6300.00
0005432459710	3278	Economy	6300.00
0005432459624	3278	Economy	6300.00
0005433805529	3278	Economy	6300.00
0005433805532	3278	Economy	6300.00
0005433805524	3278	Economy	6300.00
0005432459683	3278	Economy	6300.00
0005432181806	3278	Economy	6300.00
0005433633978	3278	Economy	6300.00
0005433633957	3278	Economy	6300.00
0005432459553	3278	Economy	6300.00
0005433633976	3278	Economy	6300.00
0005433805510	3278	Economy	6300.00
0005435885283	3277	Business	18800.00
0005435885243	3277	Business	18800.00
0005435885012	3277	Business	18800.00
0005435885013	3277	Business	18800.00
0005435884833	3277	Business	18800.00
0005435885115	3277	Business	18800.00
0005435885098	3277	Economy	6900.00
0005435885058	3277	Economy	6300.00
0005435884977	3277	Economy	6900.00
0005435884710	3277	Economy	6300.00
0005435885109	3277	Economy	6300.00
0005435885201	3277	Economy	6300.00
0005435885116	3277	Economy	6300.00
0005435885102	3277	Economy	6300.00
0005435884936	3277	Economy	6300.00
0005435885365	3277	Economy	6300.00
0005435884927	3277	Economy	6300.00
0005435885232	3277	Economy	6300.00
0005435885035	3277	Economy	6300.00
0005435885071	3277	Economy	6300.00
0005435885180	3277	Economy	6300.00
0005435885199	3277	Economy	6300.00
0005435884907	3277	Economy	6300.00
0005435885067	3277	Economy	6300.00
0005435885211	3277	Economy	6300.00
0005435884972	3277	Economy	6900.00
0005435884968	3277	Economy	6900.00
0005435885153	3277	Economy	6900.00
0005435885040	3277	Economy	6300.00
0005435884954	3277	Economy	6300.00
0005435885190	3277	Economy	6300.00
0005435885222	3277	Economy	6900.00
0005435884709	3277	Economy	6300.00
0005435884915	3277	Economy	6300.00
0005435885034	3277	Economy	6300.00
0005435884974	3277	Economy	6300.00
0005435885057	3277	Economy	6300.00
0005435884953	3277	Economy	6300.00
0005435885015	3277	Economy	6300.00
0005435885128	3277	Economy	6300.00
0005435884763	3277	Economy	6300.00
0005435884955	3277	Economy	6300.00
0005435885097	3277	Economy	6300.00
0005435885181	3277	Economy	6300.00
0005435885011	3277	Economy	6300.00
0005435885177	3277	Economy	6300.00
0005435885176	3277	Economy	6300.00
0005435885110	3277	Economy	6300.00
0005435884834	3277	Economy	6300.00
0005435885366	3277	Economy	6300.00
0005435885230	3277	Economy	6300.00
0005435885244	3277	Economy	6300.00
0005435884898	3277	Economy	6300.00
0005435884937	3277	Economy	6300.00
0005435884948	3277	Economy	6300.00
0005435885182	3277	Economy	6300.00
0005435885430	8220	Business	18800.00
0005435885456	8220	Business	18800.00
0005433507157	8220	Business	18800.00
0005435885447	8220	Business	18800.00
0005435885421	8220	Business	18800.00
0005432460123	8220	Business	18800.00
0005433507097	8220	Business	18800.00
0005433507124	8220	Business	18800.00
0005432460121	8220	Business	18800.00
0005435885458	8220	Business	18800.00
0005433507085	8220	Business	18800.00
0005435885437	8220	Business	18800.00
0005433507012	8220	Business	18800.00
0005432460078	8220	Business	18800.00
0005432460106	8220	Business	18800.00
0005433507096	8220	Business	18800.00
0005432460092	8220	Business	18800.00
0005435885440	8220	Business	18800.00
0005432460095	8220	Business	18800.00
0005435885455	8220	Business	18800.00
0005434326273	8220	Business	18800.00
0005435885434	8220	Business	18800.00
0005433507086	8220	Business	18800.00
0005435885436	8220	Business	18800.00
0005433507127	8220	Business	18800.00
0005432460097	8220	Economy	6900.00
0005432460081	8220	Economy	6900.00
0005435885429	8220	Economy	6900.00
0005432460082	8220	Economy	6900.00
0005435885462	8220	Economy	6900.00
0005432460100	8220	Economy	6900.00
0005435885457	8220	Economy	6300.00
0005432460119	8220	Economy	6300.00
0005435885422	8220	Economy	6300.00
0005432042768	8220	Economy	6300.00
0005435885435	8220	Economy	6300.00
0005432460096	8220	Economy	6300.00
0005432460094	8220	Economy	6300.00
0005432042773	8220	Economy	6300.00
0005432460124	8220	Economy	6300.00
0005432460110	8220	Economy	6300.00
0005432460115	8220	Economy	6300.00
0005435885433	8220	Economy	6300.00
0005432460118	8220	Economy	6300.00
0005432460099	8220	Economy	6300.00
0005435885450	8220	Economy	6300.00
0005435885451	8220	Economy	6300.00
0005433507167	8220	Economy	6300.00
0005432460107	8220	Economy	6300.00
0005435885460	8220	Economy	6300.00
0005432460127	8220	Economy	6300.00
0005432460130	8220	Economy	6300.00
0005432460125	8220	Economy	6300.00
0005435885468	8220	Economy	6300.00
0005432042769	8220	Economy	6300.00
0005434312330	8220	Economy	6300.00
0005433507067	8220	Economy	6300.00
0005432460098	8220	Economy	6300.00
0005432460116	8220	Economy	6300.00
0005432460102	8220	Economy	6300.00
0005432460120	8220	Economy	6300.00
0005432042770	8220	Economy	6300.00
0005432460090	8220	Economy	6300.00
0005435885466	8220	Economy	6300.00
0005435885452	8220	Economy	6300.00
0005432460086	8220	Economy	6300.00
0005435885469	8220	Economy	6300.00
0005432460104	8220	Economy	6300.00
0005435885467	8220	Economy	6300.00
0005432460108	8220	Economy	6300.00
0005432042779	8220	Economy	6300.00
0005432460122	8220	Economy	6300.00
0005435885459	8220	Economy	6300.00
0005435885444	8220	Economy	6300.00
0005432460087	8220	Economy	6300.00
0005433507125	8220	Economy	6300.00
0005435885439	8220	Economy	6300.00
0005432460084	8220	Economy	6300.00
0005432042774	8220	Economy	6300.00
0005432460112	8220	Economy	6900.00
0005433507080	8220	Economy	6900.00
0005435885463	8220	Economy	6300.00
0005434312329	8220	Economy	6300.00
0005432460126	8220	Economy	6300.00
0005435885428	8220	Economy	6300.00
0005434326272	8220	Economy	6300.00
0005432460111	8220	Economy	6300.00
0005432460085	8220	Economy	6300.00
0005433507134	8220	Economy	6300.00
0005432460089	8220	Economy	6300.00
0005435885454	8220	Economy	6300.00
0005433507113	8220	Economy	6300.00
0005433507079	8220	Economy	6300.00
0005433507011	8220	Economy	6300.00
0005432460101	8220	Economy	6300.00
0005432042780	8220	Economy	6300.00
0005432460117	8220	Economy	6300.00
0005432460128	8220	Economy	6300.00
0005432042771	8220	Economy	6300.00
0005435885441	8220	Economy	6300.00
0005432460129	8220	Economy	6300.00
0005435885424	8220	Economy	6300.00
0005432460131	8220	Economy	6300.00
0005432042777	8220	Economy	6300.00
0005435885445	8220	Economy	6300.00
0005432042778	8220	Economy	6300.00
0005432042775	8220	Economy	6300.00
0005435885453	8220	Economy	6300.00
0005435885432	8220	Economy	6300.00
0005435885448	8220	Economy	6300.00
0005432460093	8220	Economy	6300.00
0005432460114	8220	Economy	6300.00
0005435885443	8220	Economy	6300.00
0005432460109	8220	Economy	6300.00
0005435885464	8220	Economy	6300.00
0005435885427	8220	Economy	6300.00
0005435885425	8220	Economy	6300.00
0005432460088	8220	Economy	6300.00
0005432460083	8220	Economy	6300.00
0005432460080	8220	Economy	6300.00
0005432460079	8220	Economy	6300.00
0005435885438	8220	Economy	6300.00
0005435885423	8220	Economy	6300.00
0005432042776	8220	Economy	6300.00
0005435885431	8220	Economy	6300.00
0005435885442	8220	Economy	6300.00
0005435885449	8220	Economy	6300.00
0005433507180	8220	Economy	6300.00
0005432460103	8220	Economy	6300.00
0005433507063	8220	Economy	6300.00
0005435885465	8220	Economy	6300.00
0005432042767	8220	Economy	6300.00
0005435885446	8220	Economy	6300.00
0005432460105	8220	Economy	6300.00
0005432042772	8220	Economy	6300.00
0005435885461	8220	Economy	6300.00
0005433507108	8220	Economy	6300.00
0005435885426	8220	Economy	6300.00
0005433507118	8220	Economy	6300.00
0005432460113	8220	Economy	6300.00
0005434312328	8220	Economy	6300.00
0005433507123	8220	Economy	6300.00
0005432460091	8220	Economy	6300.00
0005433633427	8204	Business	18800.00
0005433805201	8204	Business	18800.00
0005433633569	8204	Business	18800.00
0005433805125	8204	Business	18800.00
0005433805169	8204	Business	18800.00
0005433633616	8204	Business	18800.00
0005433633543	8204	Business	18800.00
0005433633612	8204	Business	18800.00
0005433633613	8204	Business	18800.00
0005433633618	8204	Business	18800.00
0005433805105	8204	Business	18800.00
0005433805054	8204	Business	18800.00
0005433805153	8204	Business	18800.00
0005433805249	8204	Business	18800.00
0005433805376	8204	Economy	6900.00
0005433805258	8204	Economy	6300.00
0005433633750	8204	Economy	6300.00
0005433633716	8204	Economy	6300.00
0005433633581	8204	Economy	6300.00
0005433805240	8204	Economy	6300.00
0005433805316	8204	Economy	6300.00
0005433633594	8204	Economy	6300.00
0005433633635	8204	Economy	6300.00
0005433805286	8204	Economy	6300.00
0005434143721	8204	Economy	6300.00
0005433633619	8204	Economy	6300.00
0005433805124	8204	Economy	6300.00
0005433805337	8204	Economy	6300.00
0005433805202	8204	Economy	6300.00
0005433805287	8204	Economy	6300.00
0005433805289	8204	Economy	6300.00
0005433805280	8204	Economy	6300.00
0005433805187	8204	Economy	6300.00
0005433805230	8204	Economy	6300.00
0005433805168	8204	Economy	6300.00
0005433633633	8204	Economy	6300.00
0005433805326	8204	Economy	6300.00
0005433633702	8204	Economy	6300.00
0005433805037	8204	Economy	6300.00
0005433805267	8204	Economy	6300.00
0005433805140	8204	Economy	6300.00
0005433633721	8204	Economy	6300.00
0005433805314	8204	Economy	6300.00
0005433805247	8204	Economy	6300.00
0005433805188	8204	Economy	6900.00
0005433805288	8204	Economy	6900.00
0005433633542	8204	Economy	6900.00
0005433805241	8204	Economy	6300.00
0005433633561	8204	Economy	6900.00
0005433633659	8204	Economy	6300.00
0005433633658	8204	Economy	6300.00
0005433805149	8204	Economy	6300.00
0005433805216	8204	Economy	6300.00
0005433633657	8204	Economy	6300.00
0005433633620	8204	Economy	6300.00
0005433805246	8204	Economy	6300.00
0005433633756	8204	Economy	6300.00
0005433633399	8204	Economy	6300.00
0005433805234	8204	Economy	6300.00
0005433633576	8204	Economy	6300.00
0005433633568	8204	Economy	6300.00
0005433633550	8204	Economy	6300.00
0005433633712	8204	Economy	6300.00
0005433805203	8204	Economy	6300.00
0005433633428	8204	Economy	6300.00
0005433805311	8204	Economy	6300.00
0005433805181	8204	Economy	6300.00
0005433805330	8204	Economy	6300.00
0005433633689	8204	Economy	6300.00
0005433805377	8204	Economy	6300.00
0005433805159	8204	Economy	6300.00
0005433805263	8204	Economy	6300.00
0005433805151	8204	Economy	6300.00
0005433633722	8204	Economy	6300.00
0005433633751	8204	Economy	6300.00
0005433805150	8204	Economy	6300.00
0005433805158	8204	Economy	6300.00
0005433633582	8204	Economy	6300.00
0005434271297	8204	Economy	6300.00
0005434183567	8288	Economy	6300.00
0005434183566	8288	Economy	6300.00
0005432383352	4575	Business	9900.00
0005432383343	4575	Business	9900.00
0005432383335	4575	Business	9900.00
0005433454886	4575	Business	9900.00
0005433722247	4575	Business	9900.00
0005432727993	4575	Business	9900.00
0005432727987	4575	Business	9900.00
0005432383322	4575	Business	9900.00
0005432383329	4575	Business	9900.00
0005432727988	4575	Economy	3300.00
0005433722252	4575	Economy	3300.00
0005433722250	4575	Economy	3300.00
0005432383350	4575	Economy	3300.00
0005433722248	4575	Economy	3300.00
0005432383323	4575	Economy	3300.00
0005432383349	4575	Economy	3300.00
0005432727996	4575	Economy	3600.00
0005432383326	4575	Economy	3600.00
0005432727989	4575	Economy	3600.00
0005432383340	4575	Economy	3600.00
0005432383353	4575	Economy	3600.00
0005433722253	4575	Economy	3300.00
0005433454885	4575	Economy	3300.00
0005432383344	4575	Economy	3300.00
0005433454884	4575	Economy	3300.00
0005432383341	4575	Economy	3300.00
0005432383330	4575	Economy	3300.00
0005432383331	4575	Economy	3300.00
0005432383355	4575	Economy	3300.00
0005432383328	4575	Economy	3300.00
0005432383357	4575	Economy	3300.00
0005432383333	4575	Economy	3300.00
0005433722246	4575	Economy	3300.00
0005432383348	4575	Economy	3300.00
0005432383325	4575	Economy	3300.00
0005432383347	4575	Economy	3300.00
0005432383319	4575	Economy	3300.00
0005432383317	4575	Economy	3300.00
0005432383332	4575	Economy	3300.00
0005432383338	4575	Economy	3300.00
0005432383318	4575	Economy	3300.00
0005432727990	4575	Economy	3300.00
0005432383337	4575	Economy	3300.00
0005432383342	4575	Economy	3300.00
0005432383358	4575	Economy	3300.00
0005432383356	4575	Economy	3300.00
0005432383336	4575	Economy	3300.00
0005432727995	4575	Economy	3300.00
0005432383354	4575	Economy	3300.00
0005433722249	4575	Economy	3300.00
0005432727992	4575	Economy	3300.00
0005433722251	4575	Economy	3300.00
0005432727985	4575	Economy	3300.00
0005432383339	4575	Economy	3300.00
0005433453769	4575	Economy	3300.00
0005432727997	4575	Economy	3300.00
0005432383327	4575	Economy	3300.00
0005432383351	4575	Economy	3300.00
0005432383320	4575	Economy	3300.00
0005432383345	4575	Economy	3300.00
0005432727994	4575	Economy	3300.00
0005432383321	4575	Economy	3300.00
0005432383346	4575	Economy	3300.00
0005432383334	4575	Economy	3300.00
0005432383324	4575	Economy	3300.00
0005432727991	4575	Economy	3300.00
0005433454883	4575	Economy	3300.00
0005432727986	4575	Economy	3300.00
0005432727872	30137	Business	9900.00
0005432382888	30137	Business	9900.00
0005432383027	30137	Business	9900.00
0005432382938	30137	Business	9900.00
0005433451604	30137	Business	9900.00
0005433722196	30137	Business	9900.00
0005432727852	30137	Business	9900.00
0005432382789	30137	Business	9900.00
0005432382730	30137	Business	9900.00
0005433451616	30137	Economy	3300.00
0005432727889	30137	Economy	3300.00
0005432382879	30137	Economy	3300.00
0005432382890	30137	Economy	3300.00
0005432382833	30137	Economy	3300.00
0005432727845	30137	Economy	3300.00
0005432382940	30137	Economy	3300.00
0005432382795	30137	Economy	3300.00
0005432382806	30137	Economy	3600.00
0005432727873	30137	Economy	3600.00
0005432382930	30137	Economy	3600.00
0005432727881	30137	Economy	3600.00
0005433722175	30137	Economy	3300.00
0005432383079	30137	Economy	3300.00
0005433722191	30137	Economy	3300.00
0005433722178	30137	Economy	3300.00
0005432382959	30137	Economy	3300.00
0005432382805	30137	Economy	3300.00
0005432383107	30137	Economy	3300.00
0005433722157	30137	Economy	3300.00
0005432727887	30137	Economy	3300.00
0005432382860	30137	Economy	3300.00
0005433722183	30137	Economy	3300.00
0005432727882	30137	Economy	3300.00
0005432727871	30137	Economy	3300.00
0005432383026	30137	Economy	3300.00
0005432727844	30137	Economy	3300.00
0005432382961	30137	Economy	3300.00
0005432382913	30137	Economy	3300.00
0005433722176	30137	Economy	3300.00
0005433722164	30137	Economy	3300.00
0005432382969	30137	Economy	3300.00
0005433722180	30137	Economy	3300.00
0005432382912	30137	Economy	3300.00
0005433722179	30137	Economy	3300.00
0005432727870	30137	Economy	3300.00
0005432727891	30137	Economy	3300.00
0005433722159	30137	Economy	3300.00
0005432727822	30137	Economy	3300.00
0005432382943	30137	Economy	3300.00
0005432382847	30137	Economy	3300.00
0005433194839	30137	Economy	3300.00
0005432727874	30137	Economy	3300.00
0005433194840	30137	Economy	3300.00
0005433194837	30137	Economy	3300.00
0005432727888	30137	Economy	3300.00
0005432382920	30137	Economy	3300.00
0005432382831	30137	Economy	3300.00
0005433722174	30137	Economy	3300.00
0005432383087	30137	Economy	3300.00
0005433722173	30137	Economy	3300.00
0005432382648	30137	Economy	3300.00
0005433722165	30137	Economy	3300.00
0005432382863	30137	Economy	3300.00
0005432382756	30137	Economy	3300.00
0005432382788	30137	Economy	3300.00
0005432382747	30137	Economy	3300.00
0005433722156	30137	Economy	3300.00
0005432727851	30137	Economy	3300.00
0005433722181	30137	Economy	3300.00
0005433722158	30137	Economy	3300.00
0005432382790	30137	Economy	3300.00
0005435541090	1747	Business	57200.00
0005432925024	1747	Business	57200.00
0005435529358	1747	Business	57200.00
0005432925030	1747	Business	57200.00
0005435541100	1747	Business	57200.00
0005433516924	1747	Business	57200.00
0005435541104	1747	Business	57200.00
0005435541108	1747	Business	57200.00
0005435541095	1747	Business	57200.00
0005435541101	1747	Business	57200.00
0005435529363	1747	Economy	19100.00
0005435529365	1747	Economy	19100.00
0005435541109	1747	Economy	19100.00
0005433516930	1747	Economy	19100.00
0005435541089	1747	Economy	19100.00
0005433516922	1747	Economy	19100.00
0005433516925	1747	Economy	19100.00
0005433516927	1747	Economy	21000.00
0005435541092	1747	Economy	21000.00
0005435541094	1747	Economy	19100.00
0005433516928	1747	Economy	19100.00
0005435529361	1747	Economy	19100.00
0005435529364	1747	Economy	19100.00
0005433516926	1747	Economy	19100.00
0005435541103	1747	Economy	19100.00
0005435529362	1747	Economy	19100.00
0005433516923	1747	Economy	19100.00
0005433516931	1747	Economy	19100.00
0005435529349	1747	Economy	19100.00
0005432925013	1747	Economy	19100.00
0005435529347	1747	Economy	19100.00
0005433516929	1747	Economy	19100.00
0005435529345	1747	Economy	19100.00
0005435541105	1747	Economy	19100.00
0005435529355	1747	Economy	19100.00
0005432925023	1747	Economy	19100.00
0005435529348	1747	Economy	19100.00
0005435529344	1747	Economy	19100.00
0005435529353	1747	Economy	19100.00
0005435541097	1747	Economy	19100.00
0005435541091	1747	Economy	19100.00
0005435541102	1747	Economy	19100.00
0005435529350	1747	Economy	19100.00
0005435541096	1747	Economy	19100.00
0005435541098	1747	Economy	19100.00
0005435529351	1747	Economy	19100.00
0005435541106	1747	Economy	19100.00
0005435529352	1747	Economy	19100.00
0005435529357	1747	Economy	19100.00
0005435529360	1747	Economy	19100.00
0005435529359	1747	Economy	19100.00
0005432294498	1747	Economy	19100.00
0005435529356	1747	Economy	19100.00
0005435541107	1747	Economy	19100.00
0005432925015	1747	Economy	19100.00
0005432925014	1747	Economy	19100.00
0005435541093	1747	Economy	19100.00
0005435529346	1747	Economy	19100.00
0005435529354	1747	Economy	19100.00
0005435541099	1747	Economy	19100.00
0005435517770	22026	Business	57200.00
0005435517767	22026	Business	57200.00
0005435540993	22026	Business	57200.00
0005435540935	22026	Business	57200.00
0005435540893	22026	Business	57200.00
0005435540905	22026	Business	57200.00
0005432925059	22026	Business	57200.00
0005435517773	22026	Business	57200.00
0005435540874	22026	Business	57200.00
0005435517819	22026	Economy	19100.00
0005433516842	22026	Economy	19100.00
0005435517852	22026	Economy	19100.00
0005435540908	22026	Economy	19100.00
0005435517814	22026	Economy	19100.00
0005435517838	22026	Economy	19100.00
0005435540791	22026	Economy	19100.00
0005435517725	22026	Economy	19100.00
0005435540952	22026	Economy	21000.00
0005435540920	22026	Economy	21000.00
0005435540803	22026	Economy	21000.00
0005433516841	22026	Economy	19100.00
0005435540802	22026	Economy	19100.00
0005435540948	22026	Economy	19100.00
0005435540955	22026	Economy	19100.00
0005435540904	22026	Economy	19100.00
0005435517882	22026	Economy	19100.00
0005435517771	22026	Economy	19100.00
0005435540902	22026	Economy	19100.00
0005435517856	22026	Economy	19100.00
0005435540879	22026	Economy	19100.00
0005432925056	22026	Economy	19100.00
0005435540945	22026	Economy	19100.00
0005433516833	22026	Economy	19100.00
0005433516848	22026	Economy	19100.00
0005435540903	22026	Economy	19100.00
0005435540900	22026	Economy	19100.00
0005435517804	22026	Economy	19100.00
0005435540894	22026	Economy	19100.00
0005435517766	22026	Economy	19100.00
0005435517827	22026	Economy	19100.00
0005432925055	22026	Economy	19100.00
0005435540885	22026	Economy	19100.00
0005435540933	22026	Economy	19100.00
0005435540853	22026	Economy	19100.00
0005435540909	22026	Economy	19100.00
0005435540928	22026	Economy	19100.00
0005435540901	22026	Economy	19100.00
0005435540910	22026	Economy	19100.00
0005435517820	22026	Economy	19100.00
0005435540790	22026	Economy	19100.00
0005435517748	22026	Economy	19100.00
0005435540923	22026	Economy	19100.00
0005435540840	22026	Economy	19100.00
0005433516874	22026	Economy	19100.00
0005435540870	22026	Economy	19100.00
0005435540992	22026	Economy	19100.00
0005435540972	22026	Economy	19100.00
0005433516849	22026	Economy	19100.00
0005433516812	22026	Economy	19100.00
0005435540875	22026	Economy	19100.00
0005432925057	22026	Economy	19100.00
0005435540921	22026	Economy	19100.00
0005433516873	22026	Economy	19100.00
0005435517867	22026	Economy	19100.00
0005435540886	22026	Economy	19100.00
0005432925058	22026	Economy	19100.00
0005432925054	22026	Economy	19100.00
0005435517813	22026	Economy	19100.00
0005435540892	22026	Economy	19100.00
0005435540852	22026	Economy	19100.00
0005433516832	22026	Economy	19100.00
0005435540991	22026	Economy	19100.00
0005435517778	22026	Economy	19100.00
0005435517821	22026	Economy	19100.00
0005435540922	22026	Economy	19100.00
0005435517812	22026	Economy	19100.00
0005435517774	22026	Economy	19100.00
0005434458887	7379	Business	18500.00
0005432839156	7379	Business	18500.00
0005432839160	7379	Business	18500.00
0005432839164	7379	Business	18500.00
0005435252626	7379	Business	18500.00
0005434458900	7379	Business	18500.00
0005434458884	7379	Business	18500.00
0005434458899	7379	Business	18500.00
0005434458888	7379	Business	18500.00
0005432839153	7379	Business	18500.00
0005432839151	7379	Economy	6200.00
0005434664938	7379	Economy	6200.00
0005434458901	7379	Economy	6200.00
0005435252535	7379	Economy	6200.00
0005435252636	7379	Economy	6200.00
0005435252517	7379	Economy	6200.00
0005434664937	7379	Economy	6200.00
0005434458885	7379	Economy	6200.00
0005432073406	7379	Economy	6200.00
0005434664951	7379	Economy	6200.00
0005432839178	7379	Economy	6800.00
0005435252685	7379	Economy	6800.00
0005434458882	7379	Economy	6800.00
0005432839170	7379	Economy	6800.00
0005434458898	7379	Economy	6800.00
0005432839174	7379	Economy	6200.00
0005435491432	7379	Economy	6200.00
0005434458889	7379	Economy	6200.00
0005432839159	7379	Economy	6200.00
0005432073403	7379	Economy	6200.00
0005435252473	7379	Economy	6200.00
0005435252658	7379	Economy	6200.00
0005432839158	7379	Economy	6200.00
0005435252677	7379	Economy	6200.00
0005435252475	7379	Economy	6200.00
0005435252696	7379	Economy	6200.00
0005432839161	7379	Economy	6200.00
0005432839172	7379	Economy	6200.00
0005432073405	7379	Economy	6200.00
0005434458896	7379	Economy	6200.00
0005432839177	7379	Economy	6200.00
0005432839179	7379	Economy	6200.00
0005432839152	7379	Economy	6200.00
0005435252642	7379	Economy	6200.00
0005434458897	7379	Economy	6200.00
0005432823456	7379	Economy	6200.00
0005434458895	7379	Economy	6200.00
0005435252534	7379	Economy	6200.00
0005434458886	7379	Economy	6200.00
0005432839162	7379	Economy	6200.00
0005435252523	7379	Economy	6200.00
0005435252474	7379	Economy	6200.00
0005432839155	7379	Economy	6200.00
0005432073404	7379	Economy	6200.00
0005435252657	7379	Economy	6200.00
0005434458894	7379	Economy	6200.00
0005432839171	7379	Economy	6200.00
0005434458892	7379	Economy	6200.00
0005435252686	7379	Economy	6200.00
0005432839166	7379	Economy	6200.00
0005432841020	7379	Economy	6200.00
0005434458883	7379	Economy	6200.00
0005435252524	7379	Economy	6200.00
0005434458891	7379	Economy	6200.00
0005435252669	7379	Economy	6200.00
0005432823457	7379	Economy	6200.00
0005432841019	7379	Economy	6200.00
0005432839169	7379	Economy	6200.00
0005434458890	7379	Economy	6200.00
0005432839167	7379	Economy	6200.00
0005432839150	7379	Economy	6200.00
0005435252678	7379	Economy	6200.00
0005432839181	7379	Economy	6200.00
0005435252623	7379	Economy	6200.00
0005432839173	7379	Economy	6200.00
0005432839165	7379	Economy	6200.00
0005432839157	7379	Economy	6200.00
0005432839168	7379	Economy	6200.00
0005435252601	7379	Economy	6200.00
0005432839154	7379	Economy	6200.00
0005432839175	7379	Economy	6200.00
0005432839176	7379	Economy	6200.00
0005432839180	7379	Economy	6200.00
0005432839163	7379	Economy	6200.00
0005434458893	7379	Economy	6200.00
0005435252697	7379	Economy	6200.00
0005432823439	28902	Business	18500.00
0005435252770	28902	Business	18500.00
0005435491449	28902	Business	18500.00
0005432839001	28902	Business	18500.00
0005432838951	28902	Business	18500.00
0005435252766	28902	Business	18500.00
0005435252774	28902	Business	18500.00
0005432838931	28902	Business	18500.00
0005434458661	28902	Business	18500.00
0005432839002	28902	Economy	6200.00
0005434458662	28902	Economy	6200.00
0005434458705	28902	Economy	6200.00
0005434458758	28902	Economy	6200.00
0005432838896	28902	Economy	6200.00
0005435252776	28902	Economy	6200.00
0005432838930	28902	Economy	6800.00
0005432823441	28902	Economy	6800.00
0005435252781	28902	Economy	6800.00
0005432001032	28902	Economy	6200.00
0005432838911	28902	Economy	6200.00
0005432838939	28902	Economy	6200.00
0005435252772	28902	Economy	6200.00
0005432838695	28902	Economy	6200.00
0005435252773	28902	Economy	6200.00
0005432839041	28902	Economy	6200.00
0005432001031	28902	Economy	6200.00
0005435252778	28902	Economy	6200.00
0005435252775	28902	Economy	6200.00
0005432823434	28902	Economy	6200.00
0005432839084	28902	Economy	6200.00
0005432838964	28902	Economy	6200.00
0005434458672	28902	Economy	6200.00
0005434458698	28902	Economy	6200.00
0005434458671	28902	Economy	6200.00
0005434458744	28902	Economy	6200.00
0005432823448	28902	Economy	6200.00
0005432838952	28902	Economy	6200.00
0005434458771	28902	Economy	6200.00
0005432838850	28902	Economy	6200.00
0005434458706	28902	Economy	6200.00
0005435252782	28902	Economy	6200.00
0005435252769	28902	Economy	6200.00
0005435252780	28902	Economy	6200.00
0005432838797	28902	Economy	6200.00
0005435252779	28902	Economy	6200.00
0005435252777	28902	Economy	6200.00
0005432838845	28902	Economy	6200.00
0005432838839	28902	Economy	6200.00
0005434458802	28902	Economy	6200.00
0005435252771	28902	Economy	6200.00
0005434458702	28902	Economy	6200.00
0005435252768	28902	Economy	6200.00
0005432838905	28902	Economy	6200.00
0005435252767	28902	Economy	6200.00
0005434458701	28902	Economy	6200.00
0005435491448	28902	Economy	6200.00
0005434458633	28902	Economy	6200.00
0005432838803	28902	Economy	6200.00
0005434458745	28902	Economy	6200.00
0005434458769	28902	Economy	6200.00
0005432838910	28902	Economy	6200.00
0005432838967	28902	Economy	6200.00
0005432838940	28902	Economy	6200.00
0005434458632	28902	Economy	6200.00
0005435252783	28902	Economy	6200.00
0005432839042	28902	Economy	6200.00
0005432838694	28902	Economy	6200.00
0005432838999	28902	Economy	6200.00
0005435990654	8776	Business	145300.00
0005434276021	8776	Business	145300.00
0005435990653	8776	Business	145300.00
0005434276028	8776	Business	145300.00
0005435990651	8776	Economy	48400.00
0005434276024	8776	Economy	48400.00
0005434276003	8776	Economy	48400.00
0005434276004	8776	Economy	48400.00
0005434276019	8776	Economy	48400.00
0005434276029	8776	Economy	48400.00
0005435990652	8776	Economy	48400.00
0005434276023	8776	Economy	48400.00
0005434276020	8776	Economy	48400.00
0005434276022	8776	Economy	48400.00
0005435990657	8776	Economy	48400.00
0005434276014	8776	Economy	48400.00
0005435990655	8776	Economy	48400.00
0005435990650	8776	Economy	48400.00
0005435990656	8776	Economy	48400.00
0005435990588	15739	Economy	48400.00
0005434276052	15739	Economy	48400.00
0005434276050	15739	Economy	48400.00
0005435990586	15739	Economy	48400.00
0005434276049	15739	Economy	48400.00
0005434276053	15739	Economy	48400.00
0005434276051	15739	Economy	48400.00
0005433468373	2100	Economy	13300.00
0005432909261	2100	Economy	13300.00
0005433468366	2100	Economy	13300.00
0005433468370	2100	Economy	12100.00
0005433468363	2100	Economy	12100.00
0005432909255	2100	Economy	12100.00
0005433468379	2100	Economy	12100.00
0005433468378	2100	Economy	12100.00
0005432909228	2100	Economy	12100.00
0005433468375	2100	Economy	12100.00
0005432909248	2100	Economy	12100.00
0005432909252	2100	Economy	12100.00
0005432909250	2100	Economy	12100.00
0005432909265	2100	Economy	12100.00
0005433468367	2100	Economy	12100.00
0005433468364	2100	Economy	12100.00
0005432909273	2100	Economy	12100.00
0005433468369	2100	Economy	12100.00
0005433468377	2100	Economy	12100.00
0005433468381	2100	Economy	12100.00
0005433468371	2100	Economy	12100.00
0005433468368	2100	Economy	12100.00
0005433468376	2100	Economy	12100.00
0005433468365	2100	Economy	12100.00
0005432909272	2100	Economy	12100.00
0005433468362	2100	Economy	12100.00
0005432909246	2100	Economy	12100.00
0005432909247	2100	Economy	12100.00
0005433468374	2100	Economy	12100.00
0005432909262	2100	Economy	12100.00
0005433468380	2100	Economy	12100.00
0005433468372	2100	Economy	12100.00
0005432360585	6367	Business	36600.00
0005432062252	6367	Business	36600.00
0005435176951	6367	Business	36600.00
0005432360545	6367	Business	36600.00
0005432360569	6367	Business	36600.00
0005435176890	6367	Business	36600.00
0005435176952	6367	Business	36600.00
0005432360542	6367	Business	36600.00
0005432360549	6367	Business	36600.00
0005435177097	6367	Business	36600.00
0005432062254	6367	Business	36600.00
0005435176988	6367	Economy	12200.00
0005432360548	6367	Economy	12200.00
0005434149691	6367	Economy	12200.00
0005432360584	6367	Economy	12200.00
0005432360563	6367	Economy	12200.00
0005432360579	6367	Economy	12200.00
0005435177035	6367	Economy	12200.00
0005432360581	6367	Economy	12200.00
0005432360566	6367	Economy	12200.00
0005435723031	6367	Economy	12200.00
0005434149698	6367	Economy	12200.00
0005432062253	6367	Economy	12200.00
0005434149627	6367	Economy	12200.00
0005432360568	6367	Economy	12200.00
0005432360544	6367	Economy	12200.00
0005434149716	6367	Economy	12200.00
0005432360540	6367	Economy	12200.00
0005432336081	6367	Economy	12200.00
0005434149725	6367	Economy	12200.00
0005432360577	6367	Economy	12200.00
0005435177019	6367	Economy	12200.00
0005434149661	6367	Economy	12200.00
0005435176862	6367	Economy	12200.00
0005432360561	6367	Economy	12200.00
0005432360562	6367	Economy	12200.00
0005435177032	6367	Economy	12200.00
0005432360567	6367	Economy	12200.00
0005432062249	6367	Economy	12200.00
0005432360582	6367	Economy	12200.00
0005432360543	6367	Economy	12200.00
0005434149709	6367	Economy	12200.00
0005432360580	6367	Economy	12200.00
0005432336089	6367	Economy	12200.00
0005432360551	6367	Economy	12200.00
0005432336088	6367	Economy	13400.00
0005435176959	6367	Economy	13400.00
0005432336083	6367	Economy	13400.00
0005432360546	6367	Economy	13400.00
0005432363430	6367	Economy	12200.00
0005435177010	6367	Economy	13400.00
0005434149635	6367	Economy	12200.00
0005432336091	6367	Economy	12200.00
0005435490209	6367	Economy	12200.00
0005434149695	6367	Economy	12200.00
0005432360583	6367	Economy	12200.00
0005432360575	6367	Economy	12200.00
0005432062248	6367	Economy	12200.00
0005435177023	6367	Economy	12200.00
0005432363431	6367	Economy	12200.00
0005435177036	6367	Economy	12200.00
0005435490217	6367	Economy	12200.00
0005432336090	6367	Economy	12200.00
0005432336086	6367	Economy	12200.00
0005435177001	6367	Economy	12200.00
0005432360586	6367	Economy	12200.00
0005432360587	6367	Economy	12200.00
0005432360553	6367	Economy	12200.00
0005434149732	6367	Economy	12200.00
0005434149733	6367	Economy	12200.00
0005435176860	6367	Economy	12200.00
0005432336079	6367	Economy	12200.00
0005432360572	6367	Economy	12200.00
0005434149705	6367	Economy	12200.00
0005432360574	6367	Economy	12200.00
0005432336080	6367	Economy	12200.00
0005435176925	6367	Economy	12200.00
0005432360541	6367	Economy	12200.00
0005432360552	6367	Economy	12200.00
0005435176861	6367	Economy	12200.00
0005432360554	6367	Economy	12200.00
0005434149633	6367	Economy	12200.00
0005432360564	6367	Economy	12200.00
0005432360573	6367	Economy	12200.00
0005432360559	6367	Economy	12200.00
0005435176938	6367	Economy	12200.00
0005435176922	6367	Economy	12200.00
0005435176964	6367	Economy	12200.00
0005432360555	6367	Economy	12200.00
0005432360578	6367	Economy	12200.00
0005432360557	6367	Economy	12200.00
0005432360571	6367	Economy	12200.00
0005432336085	6367	Economy	12200.00
0005432363428	6367	Economy	12200.00
0005432360576	6367	Economy	12200.00
0005432360547	6367	Economy	12200.00
0005434149632	6367	Economy	12200.00
0005432360550	6367	Economy	12200.00
0005435490213	6367	Economy	12200.00
0005435490210	6367	Economy	12200.00
0005432360556	6367	Economy	12200.00
0005435176954	6367	Economy	12200.00
0005432360560	6367	Economy	12200.00
0005434149734	6367	Economy	12200.00
0005432062250	6367	Economy	12200.00
0005432336082	6367	Economy	12200.00
0005434149641	6367	Economy	12200.00
0005432062251	6367	Economy	12200.00
0005432360558	6367	Economy	12200.00
0005432336078	6367	Economy	12200.00
0005434149690	6367	Economy	12200.00
0005432336087	6367	Economy	12200.00
0005432360570	6367	Economy	12200.00
0005435176963	6367	Economy	12200.00
0005432363429	6367	Economy	12200.00
0005435177020	6367	Economy	12200.00
0005432360565	6367	Economy	12200.00
0005432336084	6367	Economy	12200.00
0005432360588	6367	Economy	12200.00
0005435723055	20996	Business	36600.00
0005435177201	20996	Business	36600.00
0005432359967	20996	Business	36600.00
0005432360236	20996	Business	36600.00
0005434149774	20996	Business	36600.00
0005434149777	20996	Business	36600.00
0005434149779	20996	Business	36600.00
0005432336001	20996	Business	36600.00
0005432360158	20996	Business	36600.00
0005435177177	20996	Economy	12200.00
0005434149778	20996	Economy	12200.00
0005432360052	20996	Economy	12200.00
0005432360367	20996	Economy	12200.00
0005432335997	20996	Economy	12200.00
0005435177187	20996	Economy	12200.00
0005435723057	20996	Economy	12200.00
0005435177185	20996	Economy	12200.00
0005432359961	20996	Economy	12200.00
0005432360225	20996	Economy	12200.00
0005435177196	20996	Economy	12200.00
0005432335908	20996	Economy	12200.00
0005435177202	20996	Economy	12200.00
0005432335970	20996	Economy	12200.00
0005432360220	20996	Economy	12200.00
0005435177194	20996	Economy	12200.00
0005432360368	20996	Economy	12200.00
0005432360066	20996	Economy	12200.00
0005432335996	20996	Economy	12200.00
0005432052759	20996	Economy	12200.00
0005434149782	20996	Economy	12200.00
0005432360295	20996	Economy	12200.00
0005434149780	20996	Economy	12200.00
0005435177199	20996	Economy	12200.00
0005432360174	20996	Economy	12200.00
0005432360073	20996	Economy	12200.00
0005432360111	20996	Economy	12200.00
0005432335989	20996	Economy	12200.00
0005435177198	20996	Economy	12200.00
0005432360219	20996	Economy	12200.00
0005432360286	20996	Economy	12200.00
0005435177182	20996	Economy	12200.00
0005435177186	20996	Economy	12200.00
0005435177188	20996	Economy	12200.00
0005432360102	20996	Economy	12200.00
0005435177183	20996	Economy	12200.00
0005432335971	20996	Economy	13400.00
0005432360279	20996	Economy	13400.00
0005432360250	20996	Economy	13400.00
0005432363403	20996	Economy	13400.00
0005435177179	20996	Economy	13400.00
0005432360202	20996	Economy	13400.00
0005432360034	20996	Economy	12200.00
0005432335972	20996	Economy	12200.00
0005432335969	20996	Economy	12200.00
0005432360216	20996	Economy	12200.00
0005435177189	20996	Economy	12200.00
0005435723054	20996	Economy	12200.00
0005435177195	20996	Economy	12200.00
0005435177190	20996	Economy	12200.00
0005432335986	20996	Economy	12200.00
0005432360023	20996	Economy	12200.00
0005435177193	20996	Economy	12200.00
0005435177197	20996	Economy	12200.00
0005434149783	20996	Economy	12200.00
0005435177178	20996	Economy	12200.00
0005432360339	20996	Economy	12200.00
0005432360161	20996	Economy	12200.00
0005432360148	20996	Economy	12200.00
0005435723056	20996	Economy	12200.00
0005432360203	20996	Economy	12200.00
0005435177200	20996	Economy	12200.00
0005432360022	20996	Economy	12200.00
0005435490248	20996	Economy	12200.00
0005434149784	20996	Economy	12200.00
0005432360242	20996	Economy	12200.00
0005432360218	20996	Economy	12200.00
0005432360105	20996	Economy	12200.00
0005432360171	20996	Economy	12200.00
0005432336014	20996	Economy	12200.00
0005432360154	20996	Economy	12200.00
0005434149781	20996	Economy	12200.00
0005434149775	20996	Economy	12200.00
0005432363404	20996	Economy	12200.00
0005432052758	20996	Economy	12200.00
0005435177191	20996	Economy	12200.00
0005432360116	20996	Economy	12200.00
0005432360195	20996	Economy	12200.00
0005432335966	20996	Economy	12200.00
0005432359993	20996	Economy	12200.00
0005432360075	20996	Economy	12200.00
0005432360147	20996	Economy	12200.00
0005432360241	20996	Economy	12200.00
0005432360100	20996	Economy	12200.00
0005435177203	20996	Economy	12200.00
0005432335919	20996	Economy	12200.00
0005435177192	20996	Economy	12200.00
0005432360103	20996	Economy	12200.00
0005432335987	20996	Economy	12200.00
0005432336000	20996	Economy	12200.00
0005435490246	20996	Economy	12200.00
0005432360160	20996	Economy	12200.00
0005435177181	20996	Economy	12200.00
0005432360033	20996	Economy	12200.00
0005432335977	20996	Economy	12200.00
0005435490247	20996	Economy	12200.00
0005432360340	20996	Economy	12200.00
0005432360142	20996	Economy	12200.00
0005435177204	20996	Economy	12200.00
0005432360115	20996	Economy	12200.00
0005432360065	20996	Economy	12200.00
0005434149776	20996	Economy	12200.00
0005432360170	20996	Economy	12200.00
0005435177180	20996	Economy	12200.00
0005432360196	20996	Economy	12200.00
0005432360110	20996	Economy	12200.00
0005435177184	20996	Economy	12200.00
0005432335950	20996	Economy	12200.00
0005434458790	17708	Economy	3400.00
0005434458696	17708	Economy	3100.00
0005434458783	17708	Economy	3100.00
0005434458827	17708	Economy	3100.00
0005434448288	17708	Economy	3100.00
0005434458805	17708	Economy	3100.00
0005434458714	17708	Economy	3100.00
0005434458697	17708	Economy	3100.00
0005434458789	17708	Economy	3100.00
0005434458752	17708	Economy	3100.00
0005434458716	17708	Economy	3100.00
0005434448319	17708	Economy	3100.00
0005434458773	17708	Economy	3100.00
0005434186212	17708	Economy	3100.00
0005434458806	17708	Economy	3100.00
0005434461634	17708	Economy	3100.00
0005434458620	17708	Economy	3100.00
0005434458718	17708	Economy	3100.00
0005434458772	17708	Economy	3100.00
0005434448289	17708	Economy	3100.00
0005434458774	17708	Economy	3100.00
0005434458668	17708	Economy	3100.00
0005434461640	17708	Economy	3100.00
0005434458708	17708	Economy	3100.00
0005434458717	17708	Economy	3100.00
0005434461641	17708	Economy	3100.00
0005434448291	17708	Economy	3100.00
0005434458657	17708	Economy	3100.00
0005434186211	17708	Economy	3100.00
0005434448292	17708	Economy	3100.00
0005434458796	17708	Economy	3100.00
0005434463914	17708	Economy	3100.00
0005434458715	17708	Economy	3100.00
0005434186213	17708	Economy	3100.00
0005434463936	29083	Economy	3400.00
0005434448328	29083	Economy	3400.00
0005434458887	29083	Economy	3100.00
0005434458890	29083	Economy	3100.00
0005434458893	29083	Economy	3100.00
0005434458894	29083	Economy	3100.00
0005434458899	29083	Economy	3100.00
0005434458891	29083	Economy	3100.00
0005434448326	29083	Economy	3100.00
0005434458898	29083	Economy	3100.00
0005434458892	29083	Economy	3100.00
0005434458883	29083	Economy	3100.00
0005434458901	29083	Economy	3100.00
0005434458882	29083	Economy	3100.00
0005434458897	29083	Economy	3100.00
0005434458900	29083	Economy	3100.00
0005434458895	29083	Economy	3100.00
0005434458885	29083	Economy	3100.00
0005434186169	29083	Economy	3100.00
0005434458888	29083	Economy	3100.00
0005434458896	29083	Economy	3100.00
0005434458884	29083	Economy	3100.00
0005434448327	29083	Economy	3100.00
0005434458889	29083	Economy	3100.00
0005434462797	29083	Economy	3100.00
0005434458886	29083	Economy	3100.00
0005432604465	21460	Economy	7300.00
0005432604460	21460	Economy	7300.00
0005432604482	21460	Economy	6600.00
0005432604455	21460	Economy	6600.00
0005432604456	21460	Economy	6600.00
0005432604458	21460	Economy	6600.00
0005432604461	21460	Economy	6600.00
0005432604483	21460	Economy	6600.00
0005432604476	21460	Economy	6600.00
0005432604454	21460	Economy	6600.00
0005432604459	21460	Economy	6600.00
0005432604464	21460	Economy	6600.00
0005432604478	21460	Economy	6600.00
0005432604457	21460	Economy	6600.00
0005432604477	21460	Economy	6600.00
0005432604468	21460	Economy	6600.00
0005432604469	21460	Economy	6600.00
0005432604475	21460	Economy	6600.00
0005432604490	21460	Economy	6600.00
0005432604491	21460	Economy	6600.00
0005432604462	21460	Economy	6600.00
0005432604472	21460	Economy	6600.00
0005432604489	21460	Economy	6600.00
0005432604485	21460	Economy	6600.00
0005432604487	21460	Economy	6600.00
0005432604481	21460	Economy	6600.00
0005432604484	21460	Economy	6600.00
0005432604453	21460	Economy	6600.00
0005432604471	21460	Economy	6600.00
0005432604492	21460	Economy	6600.00
0005432604493	21460	Economy	6600.00
0005432604474	21460	Economy	6600.00
0005432604488	21460	Economy	6600.00
0005432604466	21460	Economy	6600.00
0005432604473	21460	Economy	6600.00
0005432604480	21460	Economy	6600.00
0005432604486	21460	Economy	6600.00
0005432604463	21460	Economy	6600.00
0005432604470	21460	Economy	6600.00
0005432604479	21460	Economy	6600.00
0005432604467	21460	Economy	6600.00
0005432604095	31709	Economy	7300.00
0005432604050	31709	Economy	7300.00
0005432604184	31709	Economy	6600.00
0005432604118	31709	Economy	6600.00
0005432604196	31709	Economy	6600.00
0005432604227	31709	Economy	6600.00
0005432604039	31709	Economy	6600.00
0005435221519	31709	Economy	6600.00
0005432604127	31709	Economy	6600.00
0005432604066	31709	Economy	6600.00
0005432604185	31709	Economy	6600.00
0005432604040	31709	Economy	6600.00
0005432604141	31709	Economy	6600.00
0005432604065	31709	Economy	6600.00
0005435221059	31709	Economy	6600.00
0005432604105	31709	Economy	6600.00
0005432604103	31709	Economy	6600.00
0005432604166	31709	Economy	6600.00
0005432604079	31709	Economy	6600.00
0005432604277	31709	Economy	6600.00
0005432604067	31709	Economy	6600.00
0005432604111	31709	Economy	6600.00
0005432604278	31709	Economy	6600.00
0005432604003	31709	Economy	6600.00
0005432604061	31709	Economy	6600.00
0005432604104	31709	Economy	6600.00
0005432604096	31709	Economy	6600.00
0005432604049	31709	Economy	6600.00
0005435221058	31709	Economy	6600.00
0005432604142	31709	Economy	6600.00
0005432604183	31709	Economy	6600.00
0005432604194	31709	Economy	6600.00
0005432604112	31709	Economy	6600.00
0005432604228	31709	Economy	6600.00
0005432604197	31709	Economy	6600.00
0005433293271	29593	Economy	19500.00
0005433293285	29593	Economy	19500.00
0005433293266	29593	Economy	17800.00
0005433293283	29593	Economy	17800.00
0005433293276	29593	Economy	17800.00
0005433293272	29593	Economy	17800.00
0005433293278	29593	Economy	17800.00
0005433293277	29593	Economy	17800.00
0005433293281	29593	Economy	17800.00
0005433293279	29593	Economy	17800.00
0005433293273	29593	Economy	17800.00
0005433293280	29593	Economy	17800.00
0005433293282	29593	Economy	17800.00
0005433293284	29593	Economy	17800.00
0005433293265	29593	Economy	17800.00
0005433293269	29593	Economy	17800.00
0005433293275	29593	Economy	17800.00
0005433293270	29593	Economy	17800.00
0005433293267	29593	Economy	17800.00
0005433293274	29593	Economy	17800.00
0005433293268	29593	Economy	17800.00
0005435257207	6683	Economy	14000.00
0005433473294	6683	Economy	14000.00
0005433473283	6683	Economy	14000.00
0005433473282	6683	Economy	14000.00
0005433473307	6683	Economy	12700.00
0005435257205	6683	Economy	12700.00
0005433473301	6683	Economy	12700.00
0005433473297	6683	Economy	12700.00
0005435257221	6683	Economy	12700.00
0005433473284	6683	Economy	12700.00
0005433473305	6683	Economy	12700.00
0005433473296	6683	Economy	12700.00
0005433473280	6683	Economy	12700.00
0005435257225	6683	Economy	12700.00
0005435257213	6683	Economy	12700.00
0005435257193	6683	Economy	12700.00
0005433473288	6683	Economy	12700.00
0005433473291	6683	Economy	12700.00
0005433473302	6683	Economy	12700.00
0005433473306	6683	Economy	12700.00
0005435257206	6683	Economy	12700.00
0005435257202	6683	Economy	12700.00
0005435257184	6683	Economy	12700.00
0005435257186	6683	Economy	12700.00
0005433473303	6683	Economy	12700.00
0005435257211	6683	Economy	12700.00
0005433473304	6683	Economy	12700.00
0005435257201	6683	Economy	12700.00
0005433473293	6683	Economy	12700.00
0005433473292	6683	Economy	12700.00
0005435257197	6683	Economy	12700.00
0005435257215	6683	Economy	12700.00
0005435257219	6683	Economy	12700.00
0005435257220	6683	Economy	12700.00
0005435257203	6683	Economy	12700.00
0005435257214	6683	Economy	12700.00
0005433473290	6683	Economy	12700.00
0005433473289	6683	Economy	12700.00
0005433473299	6683	Economy	12700.00
0005433473295	6683	Economy	12700.00
0005433473287	6683	Economy	12700.00
0005433473281	6683	Economy	12700.00
0005433473285	6683	Economy	12700.00
0005433473308	6683	Economy	12700.00
0005433473286	6683	Economy	12700.00
0005433473298	6683	Economy	12700.00
0005435257198	6683	Economy	12700.00
0005435257204	6683	Economy	12700.00
0005433473300	6683	Economy	12700.00
0005434606807	18894	Economy	6600.00
0005434606808	18894	Economy	6600.00
0005434606816	18894	Economy	6600.00
0005434606815	18894	Economy	6600.00
0005434606838	22392	Economy	6600.00
0005434606837	22392	Economy	6600.00
0005432747728	391	Business	44500.00
0005432747716	391	Business	44500.00
0005432747708	391	Business	44500.00
0005432747712	391	Business	44500.00
0005432747709	391	Business	44500.00
0005432747697	391	Business	44500.00
0005432890949	391	Business	44500.00
0005432890990	391	Economy	14800.00
0005432747696	391	Economy	14800.00
0005432753314	391	Economy	14800.00
0005432747701	391	Economy	14800.00
0005432747727	391	Economy	16300.00
0005432747730	391	Economy	16300.00
0005432747717	391	Economy	16300.00
0005432890968	391	Economy	14800.00
0005432747726	391	Economy	14800.00
0005432747719	391	Economy	14800.00
0005432890792	391	Economy	14800.00
0005432747729	391	Economy	14800.00
0005432747721	391	Economy	14800.00
0005432747723	391	Economy	14800.00
0005432747698	391	Economy	14800.00
0005432753313	391	Economy	14800.00
0005432747700	391	Economy	14800.00
0005432890916	391	Economy	14800.00
0005433293205	391	Economy	14800.00
0005432751538	391	Economy	14800.00
0005432751537	391	Economy	14800.00
0005432890917	391	Economy	14800.00
0005435154599	391	Economy	14800.00
0005432747702	391	Economy	14800.00
0005432747694	391	Economy	14800.00
0005432747695	391	Economy	14800.00
0005433875365	391	Economy	14800.00
0005432890876	391	Economy	14800.00
0005432747711	391	Economy	14800.00
0005432890889	391	Economy	14800.00
0005432747725	391	Economy	14800.00
0005432747713	391	Economy	14800.00
0005432747704	391	Economy	14800.00
0005432747720	391	Economy	14800.00
0005432753312	391	Economy	14800.00
0005432747722	391	Economy	14800.00
0005432890963	391	Economy	14800.00
0005432890875	391	Economy	14800.00
0005432747714	391	Economy	14800.00
0005432890788	391	Economy	14800.00
0005432747724	391	Economy	14800.00
0005433293211	391	Economy	14800.00
0005432747715	391	Economy	14800.00
0005432890959	391	Economy	14800.00
0005432747710	391	Economy	14800.00
0005432747703	391	Economy	14800.00
0005432890850	391	Economy	14800.00
0005432749792	391	Economy	14800.00
0005432220021	391	Economy	14800.00
0005432753311	391	Economy	14800.00
0005432747706	391	Economy	14800.00
0005433875359	391	Economy	14800.00
0005432891034	391	Economy	14800.00
0005432747705	391	Economy	14800.00
0005432890893	391	Economy	14800.00
0005432891033	391	Economy	14800.00
0005432747731	391	Economy	14800.00
0005432747718	391	Economy	14800.00
0005432890927	391	Economy	14800.00
0005433293200	391	Economy	14800.00
0005432220020	391	Economy	14800.00
0005432747707	391	Economy	14800.00
0005432747699	391	Economy	14800.00
0005432747431	12054	Business	44500.00
0005432747508	12054	Business	44500.00
0005432747437	12054	Business	44500.00
0005432747499	12054	Business	44500.00
0005432753289	12054	Business	44500.00
0005432891104	12054	Business	44500.00
0005432891108	12054	Business	44500.00
0005435627116	12054	Business	44500.00
0005432747346	12054	Business	44500.00
0005432747236	12054	Business	44500.00
0005432891099	12054	Business	44500.00
0005432747284	12054	Business	44500.00
0005432747471	12054	Economy	14800.00
0005435627117	12054	Economy	14800.00
0005432747407	12054	Economy	14800.00
0005432891105	12054	Economy	14800.00
0005432747472	12054	Economy	14800.00
0005432891107	12054	Economy	14800.00
0005432747292	12054	Economy	14800.00
0005432747480	12054	Economy	14800.00
0005432756827	12054	Economy	16300.00
0005432747331	12054	Economy	16300.00
0005433875387	12054	Economy	16300.00
0005432747238	12054	Economy	16300.00
0005432747311	12054	Economy	14800.00
0005432747584	12054	Economy	14800.00
0005432749778	12054	Economy	14800.00
0005432747376	12054	Economy	14800.00
0005432747449	12054	Economy	14800.00
0005432747438	12054	Economy	14800.00
0005432747498	12054	Economy	14800.00
0005432747410	12054	Economy	14800.00
0005432756823	12054	Economy	14800.00
0005432891102	12054	Economy	14800.00
0005432747326	12054	Economy	14800.00
0005433875388	12054	Economy	14800.00
0005432891096	12054	Economy	14800.00
0005432891110	12054	Economy	14800.00
0005432891100	12054	Economy	14800.00
0005432891095	12054	Economy	14800.00
0005432891101	12054	Economy	14800.00
0005432747506	12054	Economy	14800.00
0005432747293	12054	Economy	14800.00
0005432747432	12054	Economy	14800.00
0005432891098	12054	Economy	14800.00
0005432756817	12054	Economy	14800.00
0005432747509	12054	Economy	14800.00
0005432891109	12054	Economy	14800.00
0005432747456	12054	Economy	14800.00
0005432747406	12054	Economy	14800.00
0005432747348	12054	Economy	14800.00
0005432747483	12054	Economy	14800.00
0005432891091	12054	Economy	14800.00
0005432747500	12054	Economy	14800.00
0005432747277	12054	Economy	14800.00
0005432756822	12054	Economy	14800.00
0005432747363	12054	Economy	14800.00
0005432891093	12054	Economy	14800.00
0005432747421	12054	Economy	14800.00
0005432747325	12054	Economy	14800.00
0005432891097	12054	Economy	14800.00
0005432756816	12054	Economy	14800.00
0005432756824	12054	Economy	14800.00
0005432747501	12054	Economy	14800.00
0005432891103	12054	Economy	14800.00
0005432891092	12054	Economy	14800.00
0005432747291	12054	Economy	14800.00
0005432747450	12054	Economy	14800.00
0005432891106	12054	Economy	14800.00
0005432747457	12054	Economy	14800.00
0005432891090	12054	Economy	14800.00
0005432891094	12054	Economy	14800.00
0005432747283	12054	Economy	14800.00
0005432747374	12054	Economy	14800.00
0005432747324	12054	Economy	14800.00
0005432747377	12054	Economy	14800.00
0005432927955	18965	Economy	28200.00
0005433525073	18965	Economy	25700.00
0005433531305	18965	Economy	25700.00
0005433531304	18965	Economy	25700.00
0005433525078	18965	Economy	25700.00
0005432927926	18965	Economy	25700.00
0005432927957	18965	Economy	25700.00
0005433533322	18965	Economy	25700.00
0005432927956	18965	Economy	25700.00
0005433533318	18965	Economy	25700.00
0005433525071	18965	Economy	25700.00
0005433531306	18965	Economy	25700.00
0005433525077	18965	Economy	25700.00
0005433533321	18965	Economy	25700.00
0005433525074	18965	Economy	25700.00
0005433525070	18965	Economy	25700.00
0005433525079	18965	Economy	25700.00
0005433525076	18965	Economy	25700.00
0005432927939	18965	Economy	25700.00
0005433525072	18965	Economy	25700.00
0005433533320	18965	Economy	25700.00
0005433533319	18965	Economy	25700.00
0005433525075	18965	Economy	25700.00
0005433524999	32497	Economy	28200.00
0005433525017	32497	Economy	25700.00
0005432928008	32497	Economy	25700.00
0005433525011	32497	Economy	25700.00
0005433525023	32497	Economy	25700.00
0005432928007	32497	Economy	25700.00
0005433527250	32497	Economy	25700.00
0005433524988	32497	Economy	25700.00
0005433527242	32497	Economy	25700.00
0005433527247	32497	Economy	25700.00
0005433524972	32497	Economy	25700.00
0005432928010	32497	Economy	25700.00
0005433525000	32497	Economy	25700.00
0005433527249	32497	Economy	25700.00
0005433525053	32497	Economy	25700.00
0005433525013	32497	Economy	25700.00
0005433527248	32497	Economy	25700.00
0005433525012	32497	Economy	25700.00
0005433524973	32497	Economy	25700.00
0005432928009	32497	Economy	25700.00
0005433525035	32497	Economy	25700.00
0005433525018	32497	Economy	25700.00
0005433525007	32497	Economy	25700.00
0005433527237	32497	Economy	25700.00
0005433527238	32497	Economy	25700.00
0005433527219	32497	Economy	25700.00
0005433524909	32497	Economy	25700.00
0005434824062	5288	Business	84000.00
0005434824119	5288	Business	84000.00
0005434824046	5288	Business	84000.00
0005434824065	5288	Business	84000.00
0005434824166	5288	Business	84000.00
0005435386522	5288	Business	84000.00
0005434824095	5288	Business	84000.00
0005435150082	5288	Business	84000.00
0005434824090	5288	Business	84000.00
0005434824147	5288	Business	84000.00
0005434824143	5288	Business	84000.00
0005434824148	5288	Business	84000.00
0005435372891	5288	Business	84000.00
0005434824068	5288	Business	84000.00
0005434824167	5288	Business	84000.00
0005434824085	5288	Business	84000.00
0005435735116	5288	Business	84000.00
0005435372829	5288	Business	84000.00
0005434831164	5288	Business	84000.00
0005434664969	5288	Business	84000.00
0005434824121	5288	Business	84000.00
0005434831167	5288	Business	84000.00
0005435373119	5288	Business	84000.00
0005432121386	5288	Comfort	47600.00
0005435150084	5288	Comfort	47600.00
0005434824052	5288	Comfort	47600.00
0005435299756	5288	Comfort	47600.00
0005432121391	5288	Comfort	47600.00
0005434824042	5288	Comfort	47600.00
0005434824117	5288	Comfort	47600.00
0005434824151	5288	Comfort	47600.00
0005434824071	5288	Comfort	47600.00
0005434824161	5288	Comfort	47600.00
0005432121397	5288	Comfort	47600.00
0005432121398	5288	Comfort	47600.00
0005432396261	5288	Comfort	47600.00
0005434824078	5288	Comfort	47600.00
0005432121393	5288	Comfort	47600.00
0005434824108	5288	Comfort	47600.00
0005435386535	5288	Comfort	47600.00
0005435373003	5288	Comfort	47600.00
0005435373060	5288	Comfort	47600.00
0005434824104	5288	Comfort	47600.00
0005434824127	5288	Comfort	47600.00
0005434824049	5288	Comfort	47600.00
0005434824140	5288	Comfort	47600.00
0005435386552	5288	Comfort	47600.00
0005434824137	5288	Comfort	47600.00
0005434824162	5288	Comfort	47600.00
0005434824131	5288	Comfort	47600.00
0005435304150	5288	Comfort	47600.00
0005432121399	5288	Comfort	47600.00
0005434824123	5288	Comfort	47600.00
0005432121390	5288	Comfort	47600.00
0005434824135	5288	Comfort	47600.00
0005434664966	5288	Comfort	47600.00
0005432396260	5288	Comfort	47600.00
0005435372934	5288	Comfort	47600.00
0005434824072	5288	Comfort	47600.00
0005435372809	5288	Comfort	47600.00
0005435373135	5288	Comfort	47600.00
0005434824126	5288	Economy	28000.00
0005434824081	5288	Comfort	47600.00
0005432121388	5288	Economy	28000.00
0005435372686	5288	Economy	28000.00
0005435372931	5288	Economy	28000.00
0005434824120	5288	Economy	28000.00
0005435386564	5288	Economy	28000.00
0005434824093	5288	Economy	28000.00
0005434824150	5288	Economy	28000.00
0005435373008	5288	Economy	28000.00
0005435372873	5288	Economy	28000.00
0005434824111	5288	Economy	28000.00
0005434824070	5288	Economy	28000.00
0005435373034	5288	Economy	28000.00
0005435372802	5288	Economy	28000.00
0005434824129	5288	Economy	28000.00
0005432396259	5288	Economy	28000.00
0005435373122	5288	Economy	28000.00
0005435735125	5288	Economy	28000.00
0005435373104	5288	Economy	28000.00
0005434824115	5288	Economy	28000.00
0005435373098	5288	Economy	28000.00
0005434824060	5288	Economy	28000.00
0005435386556	5288	Economy	28000.00
0005435299773	5288	Economy	28000.00
0005435373040	5288	Economy	28000.00
0005434824079	5288	Economy	28000.00
0005434824113	5288	Economy	28000.00
0005435386574	5288	Economy	28000.00
0005432396258	5288	Economy	28000.00
0005434824059	5288	Economy	28000.00
0005435373025	5288	Economy	28000.00
0005434824110	5288	Economy	28000.00
0005435372503	5288	Economy	28000.00
0005435372808	5288	Economy	28000.00
0005434824130	5288	Economy	28000.00
0005435661907	5288	Economy	28000.00
0005434824092	5288	Economy	28000.00
0005434824074	5288	Economy	28000.00
0005435372910	5288	Economy	28000.00
0005432394123	5288	Economy	28000.00
0005435150089	5288	Economy	28000.00
0005434824125	5288	Economy	28000.00
0005434824149	5288	Economy	28000.00
0005435372872	5288	Economy	28000.00
0005435373082	5288	Economy	28000.00
0005434824057	5288	Economy	30800.00
0005434664967	5288	Economy	28000.00
0005434824082	5288	Economy	30800.00
0005434824076	5288	Economy	28000.00
0005434824112	5288	Economy	30800.00
0005434824053	5288	Economy	28000.00
0005435372883	5288	Economy	28000.00
0005435150091	5288	Economy	28000.00
0005434824039	5288	Economy	30800.00
0005435372937	5288	Economy	28000.00
0005435372699	5288	Economy	30800.00
0005434824083	5288	Economy	28000.00
0005435373074	5288	Economy	28000.00
0005434824094	5288	Economy	28000.00
0005434824054	5288	Economy	28000.00
0005435299744	5288	Economy	28000.00
0005435304130	5288	Economy	28000.00
0005435373118	5288	Economy	28000.00
0005434824153	5288	Economy	28000.00
0005435735092	5288	Economy	28000.00
0005435661921	5288	Economy	28000.00
0005435661917	5288	Economy	28000.00
0005435373073	5288	Economy	28000.00
0005432121396	5288	Economy	28000.00
0005434824066	5288	Economy	28000.00
0005434824047	5288	Economy	28000.00
0005435372858	5288	Economy	28000.00
0005432121392	5288	Economy	28000.00
0005435372830	5288	Economy	28000.00
0005435373168	5288	Economy	28000.00
0005435372874	5288	Economy	28000.00
0005435299761	5288	Economy	28000.00
0005435372925	5288	Economy	28000.00
0005434824061	5288	Economy	28000.00
0005434824102	5288	Economy	28000.00
0005435373010	5288	Economy	28000.00
0005432121387	5288	Economy	28000.00
0005434824084	5288	Economy	28000.00
0005434824069	5288	Economy	28000.00
0005434828707	5288	Economy	28000.00
0005434664968	5288	Economy	28000.00
0005435373019	5288	Economy	28000.00
0005434824133	5288	Economy	28000.00
0005435372737	5288	Economy	28000.00
0005435372857	5288	Economy	28000.00
0005434824136	5288	Economy	28000.00
0005432121395	5288	Economy	28000.00
0005435150083	5288	Economy	28000.00
0005434824044	5288	Economy	28000.00
0005435150085	5288	Economy	28000.00
0005435735120	5288	Economy	28000.00
0005435372998	5288	Economy	28000.00
0005435372911	5288	Economy	28000.00
0005435150088	5288	Economy	28000.00
0005434824043	5288	Economy	28000.00
0005434824138	5288	Economy	28000.00
0005434824141	5288	Economy	28000.00
0005434824134	5288	Economy	28000.00
0005432394122	5288	Economy	28000.00
0005434824100	5288	Economy	28000.00
0005435372672	5288	Economy	28000.00
0005435373021	5288	Economy	28000.00
0005434824064	5288	Economy	28000.00
0005434824163	5288	Economy	28000.00
0005434824041	5288	Economy	28000.00
0005435299757	5288	Economy	28000.00
0005434824156	5288	Economy	28000.00
0005434824106	5288	Economy	28000.00
0005434824048	5288	Economy	28000.00
0005434824116	5288	Economy	28000.00
0005435386540	5288	Economy	28000.00
0005435372936	5288	Economy	28000.00
0005434824080	5288	Economy	28000.00
0005435372738	5288	Economy	28000.00
0005435150090	5288	Economy	28000.00
0005434824103	5288	Economy	28000.00
0005434824105	5288	Economy	28000.00
0005435372502	5288	Economy	28000.00
0005435372671	5288	Economy	28000.00
0005435373071	5288	Economy	28000.00
0005435373134	5288	Economy	28000.00
0005434824086	5288	Economy	28000.00
0005435372685	5288	Economy	28000.00
0005434831166	5288	Economy	28000.00
0005432394121	5288	Economy	28000.00
0005432121394	5288	Economy	28000.00
0005434824114	5288	Economy	28000.00
0005434824157	5288	Economy	28000.00
0005435735114	5288	Economy	30800.00
0005434828705	5288	Economy	30800.00
0005434824145	5288	Economy	30800.00
0005434824128	5288	Economy	30800.00
0005435386555	5288	Economy	30800.00
0005434824164	5288	Economy	28000.00
0005435373053	5288	Economy	30800.00
0005435150092	5288	Economy	28000.00
0005434824045	5288	Economy	28000.00
0005435372789	5288	Economy	28000.00
0005434824122	5288	Economy	28000.00
0005435386553	5288	Economy	28000.00
0005435373225	5288	Economy	28000.00
0005434824051	5288	Economy	28000.00
0005435372983	5288	Economy	28000.00
0005432121389	5288	Economy	28000.00
0005434824132	5288	Economy	28000.00
0005434824040	5288	Economy	28000.00
0005434824050	5288	Economy	28000.00
0005434824038	5288	Economy	28000.00
0005435373087	5288	Economy	28000.00
0005434824055	5288	Economy	28000.00
0005435150086	5288	Economy	28000.00
0005434831163	5288	Economy	28000.00
0005434824073	5288	Economy	28000.00
0005435299772	5288	Economy	28000.00
0005434824098	5288	Economy	28000.00
0005435373011	5288	Economy	28000.00
0005434824101	5288	Economy	28000.00
0005435373024	5288	Economy	28000.00
0005435372930	5288	Economy	28000.00
0005434824109	5288	Economy	28000.00
0005434824096	5288	Economy	28000.00
0005434824139	5288	Economy	28000.00
0005435372933	5288	Economy	28000.00
0005435372845	5288	Economy	28000.00
0005434824160	5288	Economy	28000.00
0005434824155	5288	Economy	28000.00
0005435372836	5288	Economy	28000.00
0005435386539	5288	Economy	28000.00
0005434664970	5288	Economy	28000.00
0005432823436	5288	Economy	28000.00
0005434824152	5288	Economy	28000.00
0005435150087	5288	Economy	28000.00
0005435735100	5288	Economy	28000.00
0005434824097	5288	Economy	28000.00
0005434824058	5288	Economy	28000.00
0005435373151	5288	Economy	28000.00
0005434824091	5288	Economy	28000.00
0005434824124	5288	Economy	28000.00
0005434824159	5288	Economy	28000.00
0005434824089	5288	Economy	28000.00
0005435372935	5288	Economy	28000.00
0005434824088	5288	Economy	28000.00
0005435372928	5288	Economy	28000.00
0005434831165	5288	Economy	28000.00
0005434828706	5288	Economy	28000.00
0005434824158	5288	Economy	28000.00
0005435372763	5288	Economy	28000.00
0005435372828	5288	Economy	28000.00
0005434824142	5288	Economy	28000.00
0005434824144	5288	Economy	28000.00
0005434824099	5288	Economy	28000.00
0005434824067	5288	Economy	28000.00
0005434824146	5288	Economy	28000.00
0005434824077	5288	Economy	28000.00
0005435372884	5288	Economy	28000.00
0005434824063	5288	Economy	28000.00
0005434824056	5288	Economy	28000.00
0005435735115	5288	Economy	28000.00
0005434824075	5288	Economy	28000.00
0005434824087	5288	Economy	28000.00
0005435299745	5288	Economy	28000.00
0005434824107	5288	Economy	28000.00
0005434824118	5288	Economy	28000.00
0005434824165	5288	Economy	28000.00
0005435372893	5288	Economy	28000.00
0005435372894	5288	Economy	28000.00
0005434824154	5288	Economy	28000.00
0005435373099	5288	Economy	28000.00
0005432823435	5288	Economy	28000.00
0005435372905	5288	Economy	28000.00
0005434823100	9926	Business	84000.00
0005435661944	9926	Business	84000.00
0005435735154	9926	Business	84000.00
0005434823084	9926	Business	84000.00
0005434823240	9926	Business	84000.00
0005434822635	9926	Business	84000.00
0005435373540	9926	Business	84000.00
0005435299797	9926	Business	84000.00
0005434823093	9926	Business	84000.00
0005434822779	9926	Business	84000.00
0005435373547	9926	Business	84000.00
0005435373525	9926	Business	84000.00
0005434823396	9926	Business	84000.00
0005432396212	9926	Business	84000.00
0005434822497	9926	Business	84000.00
0005434822750	9926	Business	84000.00
0005434822973	9926	Business	84000.00
0005434828683	9926	Business	84000.00
0005435735155	9926	Business	84000.00
0005435299793	9926	Business	84000.00
0005435373521	9926	Business	84000.00
0005432823459	9926	Business	84000.00
0005435373559	9926	Business	84000.00
0005434558214	9926	Business	84000.00
0005434822980	9926	Business	84000.00
0005435373553	9926	Business	84000.00
0005435373562	9926	Comfort	47600.00
0005435373550	9926	Business	84000.00
0005435373534	9926	Comfort	47600.00
0005435373517	9926	Comfort	47600.00
0005434558198	9926	Comfort	47600.00
0005434823177	9926	Comfort	47600.00
0005435373538	9926	Comfort	47600.00
0005435149963	9926	Comfort	47600.00
0005435179397	9926	Comfort	47600.00
0005435373561	9926	Comfort	47600.00
0005434823073	9926	Comfort	47600.00
0005432203093	9926	Comfort	47600.00
0005434822837	9926	Comfort	47600.00
0005432400100	9926	Comfort	47600.00
0005434822868	9926	Comfort	47600.00
0005432203091	9926	Comfort	47600.00
0005434822870	9926	Comfort	47600.00
0005432396221	9926	Comfort	47600.00
0005435149998	9926	Comfort	47600.00
0005434822884	9926	Comfort	47600.00
0005434823241	9926	Comfort	47600.00
0005432400111	9926	Comfort	47600.00
0005434822928	9926	Comfort	47600.00
0005434823289	9926	Comfort	47600.00
0005435149936	9926	Comfort	47600.00
0005434822845	9926	Comfort	47600.00
0005435373539	9926	Comfort	47600.00
0005435373518	9926	Comfort	47600.00
0005434823296	9926	Comfort	47600.00
0005434823499	9926	Comfort	47600.00
0005434822911	9926	Comfort	47600.00
0005435661943	9926	Comfort	47600.00
0005434823219	9926	Comfort	47600.00
0005435302218	9926	Comfort	47600.00
0005435149992	9926	Comfort	47600.00
0005434823379	9926	Comfort	47600.00
0005435149975	9926	Comfort	47600.00
0005434558223	9926	Comfort	47600.00
0005435149957	9926	Economy	28000.00
0005434823149	9926	Comfort	47600.00
0005434822957	9926	Economy	28000.00
0005435386596	9926	Economy	28000.00
0005434823200	9926	Economy	28000.00
0005435373516	9926	Economy	28000.00
0005434823297	9926	Economy	28000.00
0005435149930	9926	Economy	28000.00
0005435373529	9926	Economy	28000.00
0005435373505	9926	Economy	28000.00
0005435661945	9926	Economy	28000.00
0005435373526	9926	Economy	28000.00
0005435149880	9926	Economy	28000.00
0005435299798	9926	Economy	28000.00
0005435373557	9926	Economy	28000.00
0005434823017	9926	Economy	28000.00
0005435149938	9926	Economy	28000.00
0005434822898	9926	Economy	28000.00
0005435373515	9926	Economy	28000.00
0005434822896	9926	Economy	28000.00
0005435373507	9926	Economy	28000.00
0005435149985	9926	Economy	28000.00
0005435373536	9926	Economy	28000.00
0005435735153	9926	Economy	28000.00
0005435373509	9926	Economy	28000.00
0005434823098	9926	Economy	28000.00
0005434822971	9926	Economy	28000.00
0005434822927	9926	Economy	28000.00
0005434822520	9926	Economy	28000.00
0005434822860	9926	Economy	28000.00
0005434822923	9926	Economy	28000.00
0005434822913	9926	Economy	28000.00
0005434822754	9926	Economy	28000.00
0005434823665	9926	Economy	28000.00
0005434823223	9926	Economy	28000.00
0005434822972	9926	Economy	28000.00
0005434823239	9926	Economy	28000.00
0005434823674	9926	Economy	28000.00
0005435373528	9926	Economy	28000.00
0005435149950	9926	Economy	28000.00
0005435373503	9926	Economy	28000.00
0005434823685	9926	Economy	28000.00
0005434823077	9926	Economy	28000.00
0005434823362	9926	Economy	28000.00
0005432203094	9926	Economy	28000.00
0005434822408	9926	Economy	28000.00
0005434831132	9926	Economy	28000.00
0005435373496	9926	Economy	28000.00
0005434822872	9926	Economy	28000.00
0005432396235	9926	Economy	28000.00
0005434823397	9926	Economy	28000.00
0005435373510	9926	Economy	28000.00
0005432396230	9926	Economy	28000.00
0005434831105	9926	Economy	28000.00
0005434558224	9926	Economy	30800.00
0005434823152	9926	Economy	28000.00
0005434823616	9926	Economy	30800.00
0005434822992	9926	Economy	30800.00
0005434828676	9926	Economy	28000.00
0005432203089	9926	Economy	28000.00
0005435373520	9926	Economy	30800.00
0005434823072	9926	Economy	30800.00
0005434822537	9926	Economy	28000.00
0005435373532	9926	Economy	28000.00
0005434823419	9926	Economy	28000.00
0005435299795	9926	Economy	28000.00
0005434822988	9926	Economy	28000.00
0005435373552	9926	Economy	28000.00
0005434823071	9926	Economy	28000.00
0005435373542	9926	Economy	28000.00
0005432823460	9926	Economy	28000.00
0005435149976	9926	Economy	28000.00
0005435149988	9926	Economy	28000.00
0005434831104	9926	Economy	28000.00
0005434823542	9926	Economy	28000.00
0005434831125	9926	Economy	28000.00
0005434823516	9926	Economy	28000.00
0005434822970	9926	Economy	28000.00
0005432400127	9926	Economy	28000.00
0005434823380	9926	Economy	28000.00
0005435373514	9926	Economy	28000.00
0005434823551	9926	Economy	28000.00
0005434822540	9926	Economy	28000.00
0005435373527	9926	Economy	28000.00
0005435373551	9926	Economy	28000.00
0005434828684	9926	Economy	28000.00
0005435373504	9926	Economy	28000.00
0005435302219	9926	Economy	28000.00
0005435373522	9926	Economy	28000.00
0005434823281	9926	Economy	28000.00
0005435735157	9926	Economy	28000.00
0005434823666	9926	Economy	28000.00
0005432203096	9926	Economy	28000.00
0005435373535	9926	Economy	28000.00
0005435735158	9926	Economy	28000.00
0005435299794	9926	Economy	28000.00
0005434823250	9926	Economy	28000.00
0005435149978	9926	Economy	28000.00
0005434822780	9926	Economy	28000.00
0005434823614	9926	Economy	28000.00
0005434822634	9926	Economy	28000.00
0005434823094	9926	Economy	28000.00
0005434823095	9926	Economy	28000.00
0005435373497	9926	Economy	28000.00
0005435735156	9926	Economy	28000.00
0005432203095	9926	Economy	28000.00
0005435373541	9926	Economy	28000.00
0005435373560	9926	Economy	28000.00
0005434823590	9926	Economy	28000.00
0005434822774	9926	Economy	28000.00
0005434822809	9926	Economy	28000.00
0005435373524	9926	Economy	28000.00
0005434822981	9926	Economy	28000.00
0005435373548	9926	Economy	28000.00
0005435373519	9926	Economy	28000.00
0005432203092	9926	Economy	28000.00
0005435373555	9926	Economy	28000.00
0005435149935	9926	Economy	28000.00
0005435386595	9926	Economy	28000.00
0005435661942	9926	Economy	28000.00
0005432400097	9926	Economy	28000.00
0005434823151	9926	Economy	28000.00
0005435373508	9926	Economy	28000.00
0005434823103	9926	Economy	28000.00
0005434823686	9926	Economy	28000.00
0005434822979	9926	Economy	28000.00
0005432823458	9926	Economy	28000.00
0005435373543	9926	Economy	28000.00
0005435149977	9926	Economy	28000.00
0005435373544	9926	Economy	28000.00
0005434823476	9926	Economy	28000.00
0005434823167	9926	Economy	28000.00
0005434831107	9926	Economy	28000.00
0005435373495	9926	Economy	28000.00
0005434831108	9926	Economy	28000.00
0005435302217	9926	Economy	28000.00
0005434822484	9926	Economy	28000.00
0005434822890	9926	Economy	28000.00
0005435373530	9926	Economy	28000.00
0005434823101	9926	Economy	28000.00
0005434822936	9926	Economy	28000.00
0005434823487	9926	Economy	28000.00
0005435373502	9926	Economy	28000.00
0005435373533	9926	Economy	30800.00
0005434822593	9926	Economy	30800.00
0005434664943	9926	Economy	30800.00
0005435149932	9926	Economy	30800.00
0005434823123	9926	Economy	28000.00
0005435373549	9926	Economy	28000.00
0005435373554	9926	Economy	28000.00
0005435373500	9926	Economy	28000.00
0005434831124	9926	Economy	28000.00
0005434822743	9926	Economy	28000.00
0005434823589	9926	Economy	28000.00
0005435373506	9926	Economy	28000.00
0005435386597	9926	Economy	28000.00
0005434823251	9926	Economy	28000.00
0005434823238	9926	Economy	28000.00
0005434822510	9926	Economy	28000.00
0005434822767	9926	Economy	28000.00
0005435373512	9926	Economy	28000.00
0005435149956	9926	Economy	28000.00
0005434822680	9926	Economy	28000.00
0005434823486	9926	Economy	28000.00
0005434823383	9926	Economy	28000.00
0005435149989	9926	Economy	28000.00
0005434558205	9926	Economy	28000.00
0005434822808	9926	Economy	28000.00
0005434822941	9926	Economy	28000.00
0005435149949	9926	Economy	28000.00
0005435149991	9926	Economy	28000.00
0005434823222	9926	Economy	28000.00
0005435373498	9926	Economy	28000.00
0005434822885	9926	Economy	28000.00
0005434822541	9926	Economy	28000.00
0005435373501	9926	Economy	28000.00
0005434831127	9926	Economy	28000.00
0005435149961	9926	Economy	28000.00
0005434831128	9926	Economy	28000.00
0005434823122	9926	Economy	28000.00
0005432396216	9926	Economy	28000.00
0005434822929	9926	Economy	28000.00
0005434822641	9926	Economy	28000.00
0005434558215	9926	Economy	28000.00
0005435373558	9926	Economy	28000.00
0005435373523	9926	Economy	28000.00
0005435149990	9926	Economy	28000.00
0005434823382	9926	Economy	28000.00
0005432400112	9926	Economy	28000.00
0005434822949	9926	Economy	28000.00
0005434822940	9926	Economy	28000.00
0005435149960	9926	Economy	28000.00
0005435149952	9926	Economy	28000.00
0005435149937	9926	Economy	28000.00
0005434823381	9926	Economy	28000.00
0005435149948	9926	Economy	28000.00
0005434823361	9926	Economy	28000.00
0005434822539	9926	Economy	28000.00
0005435302216	9926	Economy	28000.00
0005434823615	9926	Economy	28000.00
0005435373545	9926	Economy	28000.00
0005434823059	9926	Economy	28000.00
0005434822945	9926	Economy	28000.00
0005435373531	9926	Economy	28000.00
0005434823113	9926	Economy	28000.00
0005434822790	9926	Economy	28000.00
0005434822861	9926	Economy	28000.00
0005434823625	9926	Economy	28000.00
0005434823768	9926	Economy	28000.00
0005435373511	9926	Economy	28000.00
0005435373513	9926	Economy	28000.00
0005435149918	9926	Economy	28000.00
0005434823099	9926	Economy	28000.00
0005434831110	9926	Economy	28000.00
0005434823000	9926	Economy	28000.00
0005434822982	9926	Economy	28000.00
0005434822592	9926	Economy	28000.00
0005434823218	9926	Economy	28000.00
0005432400109	9926	Economy	28000.00
0005435299796	9926	Economy	28000.00
0005434823005	9926	Economy	28000.00
0005434822987	9926	Economy	28000.00
0005435149993	9926	Economy	28000.00
0005435149919	9926	Economy	28000.00
0005435373537	9926	Economy	28000.00
0005434823242	9926	Economy	28000.00
0005435373499	9926	Economy	28000.00
0005432203090	9926	Economy	28000.00
0005434822937	9926	Economy	28000.00
0005435373546	9926	Economy	28000.00
0005434823370	9926	Economy	28000.00
0005435373556	9926	Economy	28000.00
0005435082815	7009	Economy	8200.00
0005435082819	7009	Economy	7400.00
0005435082818	7009	Economy	7400.00
0005435790320	7009	Economy	7400.00
0005435082816	7009	Economy	7400.00
0005435082817	7009	Economy	7400.00
0005435082820	7009	Economy	7400.00
0005435790318	7009	Economy	7400.00
0005435790319	7009	Economy	7400.00
0005435082821	7009	Economy	7400.00
0005435082814	7009	Economy	7400.00
0005435082813	7009	Economy	7400.00
0005435082822	7009	Economy	7400.00
0005435082715	25999	Economy	8200.00
0005435082755	25999	Economy	7400.00
0005435082760	25999	Economy	7400.00
0005435082761	25999	Economy	7400.00
0005435082752	25999	Economy	7400.00
0005435082759	25999	Economy	7400.00
0005435082754	25999	Economy	7400.00
0005435082737	25999	Economy	7400.00
0005435082765	25999	Economy	7400.00
0005435082736	25999	Economy	7400.00
0005435082753	25999	Economy	7400.00
0005434214455	9533	Business	32800.00
0005434214242	9533	Business	32800.00
0005434756609	9533	Business	32800.00
0005434756568	9533	Business	32800.00
0005434214381	9533	Business	32800.00
0005434756605	9533	Business	32800.00
0005434756599	9533	Business	32800.00
0005434214409	9533	Business	32800.00
0005434214268	9533	Business	32800.00
0005434214284	9533	Business	32800.00
0005434756596	9533	Business	32800.00
0005434214457	9533	Economy	10900.00
0005434214456	9533	Economy	10900.00
0005434756584	9533	Economy	10900.00
0005434756569	9533	Economy	10900.00
0005434756601	9533	Economy	10900.00
0005434214238	9533	Economy	10900.00
0005434756583	9533	Economy	10900.00
0005434214404	9533	Economy	10900.00
0005434756600	9533	Economy	10900.00
0005434214314	9533	Economy	10900.00
0005434214239	9533	Economy	12000.00
0005434214373	9533	Economy	12000.00
0005434756598	9533	Economy	12000.00
0005434756572	9533	Economy	12000.00
0005434214224	9533	Economy	12000.00
0005434214251	9533	Economy	10900.00
0005434756602	9533	Economy	10900.00
0005434756573	9533	Economy	10900.00
0005434214290	9533	Economy	10900.00
0005434214331	9533	Economy	10900.00
0005434756575	9533	Economy	10900.00
0005434214228	9533	Economy	10900.00
0005434756576	9533	Economy	10900.00
0005434214288	9533	Economy	10900.00
0005434756570	9533	Economy	10900.00
0005434214205	9533	Economy	10900.00
0005434756606	9533	Economy	10900.00
0005434214308	9533	Economy	10900.00
0005434214116	9533	Economy	10900.00
0005434756608	9533	Economy	10900.00
0005434756595	9533	Economy	10900.00
0005434214289	9533	Economy	10900.00
0005434756589	9533	Economy	10900.00
0005434756588	9533	Economy	10900.00
0005434756574	9533	Economy	10900.00
0005434756611	9533	Economy	10900.00
0005434214378	9533	Economy	10900.00
0005434756571	9533	Economy	10900.00
0005434214306	9533	Economy	10900.00
0005434756582	9533	Economy	10900.00
0005434756585	9533	Economy	10900.00
0005434214241	9533	Economy	10900.00
0005434756597	9533	Economy	10900.00
0005434756586	9533	Economy	10900.00
0005434214351	9533	Economy	10900.00
0005434756580	9533	Economy	10900.00
0005434756607	9533	Economy	10900.00
0005434214319	9533	Economy	10900.00
0005434756581	9533	Economy	10900.00
0005434214206	9533	Economy	10900.00
0005434214277	9533	Economy	10900.00
0005434756590	9533	Economy	10900.00
0005434214215	9533	Economy	10900.00
0005434214082	9533	Economy	10900.00
0005434756577	9533	Economy	10900.00
0005434214403	9533	Economy	10900.00
0005434214267	9533	Economy	10900.00
0005434214166	9533	Economy	10900.00
0005434214425	9533	Economy	10900.00
0005434214258	9533	Economy	10900.00
0005434214375	9533	Economy	10900.00
0005434756612	9533	Economy	10900.00
0005434214266	9533	Economy	10900.00
0005434214196	9533	Economy	10900.00
0005434214276	9533	Economy	10900.00
0005434756579	9533	Economy	10900.00
0005434756591	9533	Economy	10900.00
0005434756603	9533	Economy	10900.00
0005434214350	9533	Economy	10900.00
0005434756593	9533	Economy	10900.00
0005434756594	9533	Economy	10900.00
0005434214240	9533	Economy	10900.00
0005434214262	9533	Economy	10900.00
0005434756567	9533	Economy	10900.00
0005434756604	9533	Economy	10900.00
0005434214337	9533	Economy	10900.00
0005434214081	9533	Economy	10900.00
0005434756578	9533	Economy	10900.00
0005434214374	9533	Economy	10900.00
0005434756592	9533	Economy	10900.00
0005434756610	9533	Economy	10900.00
0005434756587	9533	Economy	10900.00
0005434214694	28601	Business	32800.00
0005434214681	28601	Business	32800.00
0005434214653	28601	Business	32800.00
0005434214674	28601	Business	32800.00
0005434214661	28601	Business	32800.00
0005434214688	28601	Business	32800.00
0005434756161	28601	Business	32800.00
0005434756138	28601	Business	32800.00
0005434214670	28601	Business	32800.00
0005434214667	28601	Business	32800.00
0005434756099	28601	Business	32800.00
0005434756042	28601	Economy	10900.00
0005434214659	28601	Economy	10900.00
0005434756243	28601	Economy	10900.00
0005434214677	28601	Economy	10900.00
0005434756179	28601	Economy	10900.00
0005434214684	28601	Economy	10900.00
0005434214656	28601	Economy	10900.00
0005434756173	28601	Economy	10900.00
0005434214680	28601	Economy	10900.00
0005434214695	28601	Economy	10900.00
0005434756118	28601	Economy	12000.00
0005434756182	28601	Economy	12000.00
0005434756373	28601	Economy	12000.00
0005434756101	28601	Economy	10900.00
0005434214687	28601	Economy	10900.00
0005434214678	28601	Economy	10900.00
0005434756043	28601	Economy	10900.00
0005434756171	28601	Economy	10900.00
0005434214662	28601	Economy	10900.00
0005434214658	28601	Economy	10900.00
0005434756150	28601	Economy	10900.00
0005434756210	28601	Economy	10900.00
0005434214691	28601	Economy	10900.00
0005434214679	28601	Economy	10900.00
0005434214692	28601	Economy	10900.00
0005434214685	28601	Economy	10900.00
0005434214668	28601	Economy	10900.00
0005434214663	28601	Economy	10900.00
0005434756126	28601	Economy	10900.00
0005434214660	28601	Economy	10900.00
0005434756148	28601	Economy	10900.00
0005434214650	28601	Economy	10900.00
0005434214665	28601	Economy	10900.00
0005434756162	28601	Economy	10900.00
0005434214664	28601	Economy	10900.00
0005434214669	28601	Economy	10900.00
0005434214686	28601	Economy	10900.00
0005434756102	28601	Economy	10900.00
0005434755975	28601	Economy	10900.00
0005434756029	28601	Economy	10900.00
0005434756177	28601	Economy	10900.00
0005434214693	28601	Economy	10900.00
0005434756124	28601	Economy	10900.00
0005434755966	28601	Economy	10900.00
0005434756244	28601	Economy	10900.00
0005434214666	28601	Economy	10900.00
0005434756125	28601	Economy	10900.00
0005434756294	28601	Economy	10900.00
0005434214676	28601	Economy	10900.00
0005434756183	28601	Economy	10900.00
0005434214654	28601	Economy	10900.00
0005434214652	28601	Economy	10900.00
0005434756239	28601	Economy	10900.00
0005434756107	28601	Economy	10900.00
0005434756267	28601	Economy	10900.00
0005434756095	28601	Economy	10900.00
0005434214683	28601	Economy	10900.00
0005434214651	28601	Economy	10900.00
0005434756268	28601	Economy	10900.00
0005434214689	28601	Economy	10900.00
0005434756149	28601	Economy	10900.00
0005434214690	28601	Economy	10900.00
0005434756114	28601	Economy	10900.00
0005434214671	28601	Economy	10900.00
0005434756096	28601	Economy	10900.00
0005434756190	28601	Economy	10900.00
0005434756269	28601	Economy	10900.00
0005434214672	28601	Economy	10900.00
0005434214682	28601	Economy	10900.00
0005434214673	28601	Economy	10900.00
0005434756116	28601	Economy	10900.00
0005434214675	28601	Economy	10900.00
0005434214657	28601	Economy	10900.00
0005434756200	28601	Economy	10900.00
0005434214696	28601	Economy	10900.00
0005434214655	28601	Economy	10900.00
0005434756191	28601	Economy	10900.00
0005435100137	10812	Economy	9800.00
0005434760188	10812	Economy	9800.00
0005434760193	10812	Economy	8900.00
0005434760183	10812	Economy	8900.00
0005434760191	10812	Economy	8900.00
0005435100134	10812	Economy	8900.00
0005435100136	10812	Economy	8900.00
0005435100135	10812	Economy	8900.00
0005434760206	31840	Economy	9800.00
0005434760208	31840	Economy	8900.00
0005435100124	31840	Economy	8900.00
0005435100123	31840	Economy	8900.00
0005435100125	31840	Economy	8900.00
0005434760207	31840	Economy	8900.00
0005434639443	2006	Economy	20900.00
0005434639444	2006	Economy	20900.00
0005434639428	2006	Economy	20900.00
0005433202311	2006	Economy	20900.00
0005434639424	2006	Economy	19000.00
0005433202253	2006	Economy	19000.00
0005432290646	2006	Economy	19000.00
0005433202268	2006	Economy	19000.00
0005433202301	2006	Economy	19000.00
0005433202214	2006	Economy	19000.00
0005434639436	2006	Economy	19000.00
0005434639426	2006	Economy	19000.00
0005434639434	2006	Economy	19000.00
0005434639422	2006	Economy	19000.00
0005434639438	2006	Economy	19000.00
0005434639427	2006	Economy	19000.00
0005432290647	2006	Economy	19000.00
0005433202264	2006	Economy	19000.00
0005432290645	2006	Economy	19000.00
0005433202208	2006	Economy	19000.00
0005434639441	2006	Economy	19000.00
0005434639437	2006	Economy	19000.00
0005434639439	2006	Economy	19000.00
0005434639442	2006	Economy	19000.00
0005433202270	2006	Economy	19000.00
0005433202308	2006	Economy	19000.00
0005434639446	2006	Economy	19000.00
0005434639435	2006	Economy	19000.00
0005434639431	2006	Economy	19000.00
0005434639449	2006	Economy	19000.00
0005433202265	2006	Economy	19000.00
0005434639430	2006	Economy	19000.00
0005434639425	2006	Economy	19000.00
0005434639432	2006	Economy	19000.00
0005433202300	2006	Economy	19000.00
0005434639445	2006	Economy	19000.00
0005433202239	2006	Economy	19000.00
0005433202394	2006	Economy	19000.00
0005433202266	2006	Economy	19000.00
0005434639447	2006	Economy	19000.00
0005433202209	2006	Economy	19000.00
0005435948330	2006	Economy	19000.00
0005434639440	2006	Economy	19000.00
0005433202288	2006	Economy	19000.00
0005434639423	2006	Economy	19000.00
0005434639429	2006	Economy	19000.00
0005433202269	2006	Economy	19000.00
0005433202286	2006	Economy	19000.00
0005434639448	2006	Economy	19000.00
0005434639433	2006	Economy	19000.00
0005434639149	23265	Economy	20900.00
0005433202404	23265	Economy	20900.00
0005434639204	23265	Economy	20900.00
0005434639196	23265	Economy	19000.00
0005434639148	23265	Economy	19000.00
0005433202414	23265	Economy	19000.00
0005434639227	23265	Economy	19000.00
0005435948324	23265	Economy	19000.00
0005433202416	23265	Economy	19000.00
0005434639234	23265	Economy	19000.00
0005434639222	23265	Economy	19000.00
0005434639190	23265	Economy	19000.00
0005434639188	23265	Economy	19000.00
0005435948322	23265	Economy	19000.00
0005434639279	23265	Economy	19000.00
0005434639017	23265	Economy	19000.00
0005434639267	23265	Economy	19000.00
0005434639224	23265	Economy	19000.00
0005434639223	23265	Economy	19000.00
0005434639205	23265	Economy	19000.00
0005434639235	23265	Economy	19000.00
0005433202409	23265	Economy	19000.00
0005434639189	23265	Economy	19000.00
0005433202408	23265	Economy	19000.00
0005434639221	23265	Economy	19000.00
0005434639082	23265	Economy	19000.00
0005434639146	23265	Economy	19000.00
0005435948323	23265	Economy	19000.00
0005434639098	23265	Economy	19000.00
0005433202418	23265	Economy	19000.00
0005433202403	23265	Economy	19000.00
0005433202417	23265	Economy	19000.00
0005434639226	23265	Economy	19000.00
0005433202413	23265	Economy	19000.00
0005433202415	23265	Economy	19000.00
0005433202407	23265	Economy	19000.00
0005435948320	23265	Economy	19000.00
0005433202411	23265	Economy	19000.00
0005434639191	23265	Economy	19000.00
0005433202412	23265	Economy	19000.00
0005434639228	23265	Economy	19000.00
0005435948321	23265	Economy	19000.00
0005434639225	23265	Economy	19000.00
0005433202406	23265	Economy	19000.00
0005434639213	23265	Economy	19000.00
0005433202405	23265	Economy	19000.00
0005433202410	23265	Economy	19000.00
0005435948325	23265	Economy	19000.00
0005434600921	6061	Business	69700.00
0005434600920	6061	Business	69700.00
0005435326659	6061	Business	69700.00
0005435326684	6061	Business	69700.00
0005434600928	6061	Business	69700.00
0005435326651	6061	Business	69700.00
0005432111290	6061	Business	69700.00
0005435326704	6061	Business	69700.00
0005434600932	6061	Business	69700.00
0005434600908	6061	Economy	23200.00
0005433531309	6061	Economy	23200.00
0005434600917	6061	Economy	23200.00
0005434600915	6061	Economy	23200.00
0005435326646	6061	Economy	23200.00
0005434600914	6061	Economy	23200.00
0005435326703	6061	Economy	23200.00
0005434600930	6061	Economy	25600.00
0005434600927	6061	Economy	25600.00
0005434600916	6061	Economy	25600.00
0005435326692	6061	Economy	25600.00
0005434600911	6061	Economy	23200.00
0005435326758	6061	Economy	23200.00
0005435326678	6061	Economy	23200.00
0005434600918	6061	Economy	23200.00
0005435326728	6061	Economy	23200.00
0005435326735	6061	Economy	23200.00
0005434600909	6061	Economy	23200.00
0005434600923	6061	Economy	23200.00
0005434600922	6061	Economy	23200.00
0005434600924	6061	Economy	23200.00
0005435326673	6061	Economy	23200.00
0005433531307	6061	Economy	23200.00
0005434600907	6061	Economy	23200.00
0005435326690	6061	Economy	23200.00
0005433533324	6061	Economy	23200.00
0005433533323	6061	Economy	23200.00
0005432111291	6061	Economy	23200.00
0005434600925	6061	Economy	23200.00
0005434600910	6061	Economy	23200.00
0005435326683	6061	Economy	23200.00
0005435326706	6061	Economy	23200.00
0005435326662	6061	Economy	23200.00
0005432111293	6061	Economy	23200.00
0005435326727	6061	Economy	23200.00
0005434600919	6061	Economy	23200.00
0005433531310	6061	Economy	23200.00
0005435326645	6061	Economy	23200.00
0005434600912	6061	Economy	23200.00
0005432111292	6061	Economy	23200.00
0005434600926	6061	Economy	23200.00
0005434600929	6061	Economy	23200.00
0005435326717	6061	Economy	23200.00
0005434600913	6061	Economy	23200.00
0005435326693	6061	Economy	23200.00
0005432111289	6061	Economy	23200.00
0005435326687	6061	Economy	23200.00
0005435326756	6061	Economy	23200.00
0005435326672	6061	Economy	23200.00
0005433531308	6061	Economy	23200.00
0005435326757	6061	Economy	23200.00
0005435326650	6061	Economy	23200.00
0005433533325	6061	Economy	23200.00
0005435326733	6061	Economy	23200.00
0005434600931	6061	Economy	23200.00
0005434600737	18566	Business	69700.00
0005435326803	18566	Business	69700.00
0005435326795	18566	Business	69700.00
0005434600713	18566	Business	69700.00
0005434600709	18566	Business	69700.00
0005435326806	18566	Economy	23200.00
0005433531275	18566	Economy	23200.00
0005434600647	18566	Economy	23200.00
0005434600566	18566	Economy	23200.00
0005434600662	18566	Economy	25600.00
0005434600747	18566	Economy	23200.00
0005435326796	18566	Economy	23200.00
0005435326799	18566	Economy	23200.00
0005433531284	18566	Economy	23200.00
0005434600684	18566	Economy	23200.00
0005433531280	18566	Economy	23200.00
0005434600663	18566	Economy	23200.00
0005434600618	18566	Economy	23200.00
0005435326802	18566	Economy	23200.00
0005434600717	18566	Economy	23200.00
0005434600683	18566	Economy	23200.00
0005434600696	18566	Economy	23200.00
0005433531277	18566	Economy	23200.00
0005434600681	18566	Economy	23200.00
0005435326805	18566	Economy	23200.00
0005434600732	18566	Economy	23200.00
0005435326797	18566	Economy	23200.00
0005434600720	18566	Economy	23200.00
0005434600714	18566	Economy	23200.00
0005434600680	18566	Economy	23200.00
0005435326800	18566	Economy	23200.00
0005434600692	18566	Economy	23200.00
0005435326798	18566	Economy	23200.00
0005435326801	18566	Economy	23200.00
0005434600718	18566	Economy	23200.00
0005433531276	18566	Economy	23200.00
0005434600567	18566	Economy	23200.00
0005434600655	18566	Economy	23200.00
0005434600736	18566	Economy	23200.00
0005434600685	18566	Economy	23200.00
0005433531285	18566	Economy	23200.00
0005434600666	18566	Economy	23200.00
0005434600762	18566	Economy	23200.00
0005434600721	18566	Economy	23200.00
0005435326808	18566	Economy	23200.00
0005434600724	18566	Economy	23200.00
0005434600725	18566	Economy	23200.00
0005434600726	18566	Economy	23200.00
0005434600695	18566	Economy	23200.00
0005435326807	18566	Economy	23200.00
0005435326804	18566	Economy	23200.00
0005434551412	10672	Business	9100.00
0005434551402	10672	Business	9100.00
0005434558306	10672	Business	9100.00
0005433180832	10672	Business	9100.00
0005434551404	10672	Business	9100.00
0005433180969	10672	Business	9100.00
0005434558304	10672	Business	9100.00
0005434551420	10672	Business	9100.00
0005434551403	10672	Business	9100.00
0005434551433	10672	Business	9100.00
0005434551386	10672	Economy	3000.00
0005434551390	10672	Economy	3000.00
0005434551408	10672	Economy	3000.00
0005433180954	10672	Economy	3000.00
0005434551435	10672	Economy	3000.00
0005434551424	10672	Economy	3000.00
0005434551398	10672	Economy	3000.00
0005434551397	10672	Economy	3000.00
0005434551436	10672	Economy	3000.00
0005434551421	10672	Economy	3000.00
0005434551394	10672	Economy	3300.00
0005434551429	10672	Economy	3300.00
0005434551410	10672	Economy	3300.00
0005433180943	10672	Economy	3300.00
0005434551413	10672	Economy	3300.00
0005434551385	10672	Economy	3000.00
0005434551389	10672	Economy	3000.00
0005433180941	10672	Economy	3000.00
0005434551430	10672	Economy	3000.00
0005434551423	10672	Economy	3000.00
0005434551388	10672	Economy	3000.00
0005434551437	10672	Economy	3000.00
0005433180985	10672	Economy	3000.00
0005433180870	10672	Economy	3000.00
0005434551432	10672	Economy	3000.00
0005434551406	10672	Economy	3000.00
0005433180988	10672	Economy	3000.00
0005433180952	10672	Economy	3000.00
0005434551393	10672	Economy	3000.00
0005433180910	10672	Economy	3000.00
0005434551392	10672	Economy	3000.00
0005434558303	10672	Economy	3000.00
0005434551401	10672	Economy	3000.00
0005433180860	10672	Economy	3000.00
0005434551417	10672	Economy	3000.00
0005433181045	10672	Economy	3000.00
0005434551409	10672	Economy	3000.00
0005434551418	10672	Economy	3000.00
0005433180900	10672	Economy	3000.00
0005434551422	10672	Economy	3000.00
0005434551399	10672	Economy	3000.00
0005434551384	10672	Economy	3000.00
0005434551391	10672	Economy	3000.00
0005434551411	10672	Economy	3000.00
0005434558305	10672	Economy	3000.00
0005433180989	10672	Economy	3000.00
0005434551383	10672	Economy	3000.00
0005434551426	10672	Economy	3000.00
0005434551382	10672	Economy	3000.00
0005434551414	10672	Economy	3000.00
0005433180936	10672	Economy	3000.00
0005433180963	10672	Economy	3000.00
0005433180962	10672	Economy	3000.00
0005434554074	10672	Economy	3000.00
0005434551407	10672	Economy	3000.00
0005434551419	10672	Economy	3000.00
0005434551405	10672	Economy	3000.00
0005433180923	10672	Economy	3000.00
0005434551434	10672	Economy	3000.00
0005434551427	10672	Economy	3000.00
0005434551381	10672	Economy	3000.00
0005434551396	10672	Economy	3000.00
0005434551428	10672	Economy	3000.00
0005434551387	10672	Economy	3000.00
0005433180901	10672	Economy	3000.00
0005433180869	10672	Economy	3000.00
0005434551425	10672	Economy	3000.00
0005434551395	10672	Economy	3000.00
0005434558308	10672	Economy	3000.00
0005433180937	10672	Economy	3000.00
0005433180915	10672	Economy	3000.00
0005434551400	10672	Economy	3000.00
0005433180861	10672	Economy	3000.00
0005434551415	10672	Economy	3000.00
0005433181044	10672	Economy	3000.00
0005434551416	10672	Economy	3000.00
0005434558307	10672	Economy	3000.00
0005434551431	10672	Economy	3000.00
0005433180968	10672	Economy	3000.00
0005433180953	10672	Economy	3000.00
0005433180922	10672	Economy	3000.00
0005433181210	27735	Business	9100.00
0005433181205	27735	Business	9100.00
0005433181215	27735	Economy	3000.00
0005433181216	27735	Economy	3300.00
0005433181207	27735	Economy	3300.00
0005433181200	27735	Economy	3000.00
0005433181195	27735	Economy	3000.00
0005433181203	27735	Economy	3000.00
0005433181198	27735	Economy	3000.00
0005433181202	27735	Economy	3000.00
0005433181194	27735	Economy	3000.00
0005433181206	27735	Economy	3000.00
0005433181204	27735	Economy	3000.00
0005433181213	27735	Economy	3000.00
0005433181209	27735	Economy	3000.00
0005433181193	27735	Economy	3000.00
0005433181197	27735	Economy	3000.00
0005433181208	27735	Economy	3000.00
0005433181212	27735	Economy	3000.00
0005433181192	27735	Economy	3000.00
0005433181191	27735	Economy	3000.00
0005433181211	27735	Economy	3000.00
0005433181196	27735	Economy	3000.00
0005433181201	27735	Economy	3000.00
0005433181199	27735	Economy	3000.00
0005433181214	27735	Economy	3000.00
0005434551087	27769	Business	9100.00
0005434550886	27769	Business	9100.00
0005434551080	27769	Business	9100.00
0005434558227	27769	Business	9100.00
0005434558206	27769	Business	9100.00
0005434554047	27769	Business	9100.00
0005434550798	27769	Business	9100.00
0005434551009	27769	Business	9100.00
0005434551142	27769	Business	9100.00
0005434550730	27769	Economy	3000.00
0005434558231	27769	Economy	3000.00
0005434551036	27769	Economy	3000.00
0005434550994	27769	Economy	3000.00
0005434550943	27769	Economy	3000.00
0005434550822	27769	Economy	3000.00
0005434550957	27769	Economy	3000.00
0005434551077	27769	Economy	3000.00
0005434551140	27769	Economy	3000.00
0005434550927	27769	Economy	3000.00
0005434550953	27769	Economy	3300.00
0005434551178	27769	Economy	3300.00
0005434550738	27769	Economy	3300.00
0005434551018	27769	Economy	3300.00
0005434551011	27769	Economy	3300.00
0005434550711	27769	Economy	3000.00
0005434550739	27769	Economy	3000.00
0005434550851	27769	Economy	3000.00
0005434550912	27769	Economy	3000.00
0005434551071	27769	Economy	3000.00
0005434550740	27769	Economy	3000.00
0005434551211	27769	Economy	3000.00
0005434550799	27769	Economy	3000.00
0005434551067	27769	Economy	3000.00
0005434550941	27769	Economy	3000.00
0005434550993	27769	Economy	3000.00
0005434551035	27769	Economy	3000.00
0005434550796	27769	Economy	3000.00
0005434551163	27769	Economy	3000.00
0005434551164	27769	Economy	3000.00
0005434551053	27769	Economy	3000.00
0005434551070	27769	Economy	3000.00
0005434550952	27769	Economy	3000.00
0005434550887	27769	Economy	3000.00
0005434551141	27769	Economy	3000.00
0005434550968	27769	Economy	3000.00
0005434551049	27769	Economy	3000.00
0005434551068	27769	Economy	3000.00
0005434550940	27769	Economy	3000.00
0005434551146	27769	Economy	3000.00
0005434551037	27769	Economy	3000.00
0005434551045	27769	Economy	3000.00
0005434558230	27769	Economy	3000.00
0005434551179	27769	Economy	3000.00
0005434551161	27769	Economy	3000.00
0005434550731	27769	Economy	3000.00
0005434550879	27769	Economy	3000.00
0005434550895	27769	Economy	3000.00
0005434550956	27769	Economy	3000.00
0005434551160	27769	Economy	3000.00
0005434551038	27769	Economy	3000.00
0005434551173	27769	Economy	3000.00
0005434550795	27769	Economy	3000.00
0005434551054	27769	Economy	3000.00
0005434551084	27769	Economy	3000.00
0005434550855	27769	Economy	3000.00
0005434550797	27769	Economy	3000.00
0005434550894	27769	Economy	3000.00
0005434550911	27769	Economy	3000.00
0005434550932	27769	Economy	3000.00
0005434551083	27769	Economy	3000.00
0005434550794	27769	Economy	3000.00
0005434558228	27769	Economy	3000.00
0005434550942	27769	Economy	3000.00
0005434551079	27769	Economy	3000.00
0005434551076	27769	Economy	3000.00
0005435254465	6139	Economy	11700.00
0005433459239	6139	Economy	11700.00
0005433459234	6139	Economy	11700.00
0005433459238	6139	Economy	11700.00
0005433459236	6139	Economy	11700.00
0005433459235	6139	Economy	11700.00
0005433459237	6139	Economy	11700.00
0005433459212	19330	Economy	11700.00
0005433459197	19330	Economy	11700.00
0005433459213	19330	Economy	11700.00
0005433459194	19330	Economy	11700.00
0005433459211	19330	Economy	11700.00
0005433459195	19330	Economy	11700.00
0005433459199	19330	Economy	11700.00
0005433459196	19330	Economy	11700.00
0005435254485	19330	Economy	11700.00
0005435254484	19330	Economy	11700.00
0005433459193	19330	Economy	11700.00
0005433459192	19330	Economy	11700.00
0005435682286	6722	Business	51100.00
0005435217689	6722	Business	51100.00
0005435682294	6722	Business	51100.00
0005435682291	6722	Business	51100.00
0005435720137	6722	Business	51100.00
0005435720138	6722	Business	51100.00
0005435437927	6722	Business	51100.00
0005435682326	6722	Business	51100.00
0005435682318	6722	Business	51100.00
0005435220308	6722	Business	51100.00
0005435437925	6722	Economy	17000.00
0005435682328	6722	Economy	17000.00
0005435437928	6722	Economy	17000.00
0005435682314	6722	Economy	17000.00
0005435682304	6722	Economy	17000.00
0005435682312	6722	Economy	17000.00
0005435682317	6722	Economy	17000.00
0005435221505	6722	Economy	17000.00
0005435682292	6722	Economy	17000.00
0005435682315	6722	Economy	17000.00
0005435682301	6722	Economy	18700.00
0005435437835	6722	Economy	18700.00
0005435437830	6722	Economy	18700.00
0005432136190	6722	Economy	18700.00
0005432136189	6722	Economy	17000.00
0005434828681	6722	Economy	17000.00
0005432136191	6722	Economy	17000.00
0005435221510	6722	Economy	17000.00
0005435682309	6722	Economy	17000.00
0005434828679	6722	Economy	17000.00
0005434828680	6722	Economy	17000.00
0005435661941	6722	Economy	17000.00
0005435682298	6722	Economy	17000.00
0005435437864	6722	Economy	17000.00
0005435220309	6722	Economy	17000.00
0005435437915	6722	Economy	17000.00
0005435682290	6722	Economy	17000.00
0005435682289	6722	Economy	17000.00
0005435630976	6722	Economy	17000.00
0005435682327	6722	Economy	17000.00
0005435220310	6722	Economy	17000.00
0005435682325	6722	Economy	17000.00
0005435682306	6722	Economy	17000.00
0005435437816	6722	Economy	17000.00
0005435682302	6722	Economy	17000.00
0005435682287	6722	Economy	17000.00
0005435682319	6722	Economy	17000.00
0005435682324	6722	Economy	17000.00
0005435437876	6722	Economy	17000.00
0005435682310	6722	Economy	17000.00
0005432136187	6722	Economy	17000.00
0005435682297	6722	Economy	17000.00
0005435682313	6722	Economy	17000.00
0005435630975	6722	Economy	17000.00
0005435682293	6722	Economy	17000.00
0005435682303	6722	Economy	17000.00
0005435630978	6722	Economy	17000.00
0005435437790	6722	Economy	17000.00
0005435630977	6722	Economy	17000.00
0005435661940	6722	Economy	17000.00
0005435437762	6722	Economy	17000.00
0005435437885	6722	Economy	17000.00
0005435437926	6722	Economy	17000.00
0005435682329	6722	Economy	17000.00
0005432136188	6722	Economy	17000.00
0005435682305	6722	Economy	17000.00
0005435217712	6722	Economy	17000.00
0005435682295	6722	Economy	17000.00
0005435682323	6722	Economy	17000.00
0005435682320	6722	Economy	17000.00
0005435682316	6722	Economy	17000.00
0005435720139	6722	Economy	17000.00
0005435682308	6722	Economy	17000.00
0005435682299	6722	Economy	17000.00
0005435661939	6722	Economy	17000.00
0005435437861	6722	Economy	17000.00
0005435437884	6722	Economy	17000.00
0005435437857	6722	Economy	17000.00
0005435437929	6722	Economy	17000.00
0005435682322	6722	Economy	17000.00
0005435437877	6722	Economy	17000.00
0005435682300	6722	Economy	17000.00
0005435682311	6722	Economy	17000.00
0005435217690	6722	Economy	17000.00
0005435437759	6722	Economy	17000.00
0005435682307	6722	Economy	17000.00
0005435682288	6722	Economy	17000.00
0005435682321	6722	Economy	17000.00
0005435682296	6722	Economy	17000.00
0005435681971	24586	Business	51100.00
0005435438046	24586	Business	51100.00
0005435681892	24586	Business	51100.00
0005434828710	24586	Business	51100.00
0005435681834	24586	Business	51100.00
0005435682040	24586	Business	51100.00
0005435681850	24586	Business	51100.00
0005435681808	24586	Business	51100.00
0005435438045	24586	Business	51100.00
0005435682005	24586	Business	51100.00
0005435438033	24586	Business	51100.00
0005435438050	24586	Business	51100.00
0005435681901	24586	Economy	17000.00
0005435681935	24586	Economy	17000.00
0005435681937	24586	Economy	17000.00
0005435438041	24586	Economy	17000.00
0005435438048	24586	Economy	17000.00
0005435438042	24586	Economy	17000.00
0005432305760	24586	Economy	17000.00
0005435438039	24586	Economy	17000.00
0005435681946	24586	Economy	17000.00
0005435681992	24586	Economy	18700.00
0005435681995	24586	Economy	18700.00
0005435681918	24586	Economy	18700.00
0005435720814	24586	Economy	18700.00
0005435682086	24586	Economy	17000.00
0005435438043	24586	Economy	17000.00
0005435719561	24586	Economy	17000.00
0005435661913	24586	Economy	17000.00
0005435681862	24586	Economy	17000.00
0005435681979	24586	Economy	17000.00
0005435681921	24586	Economy	17000.00
0005435682016	24586	Economy	17000.00
0005435682060	24586	Economy	17000.00
0005435682098	24586	Economy	17000.00
0005432305759	24586	Economy	17000.00
0005435438047	24586	Economy	17000.00
0005435661914	24586	Economy	17000.00
0005432305757	24586	Economy	17000.00
0005435682084	24586	Economy	17000.00
0005435681874	24586	Economy	17000.00
0005432533303	24586	Economy	17000.00
0005435438049	24586	Economy	17000.00
0005435682025	24586	Economy	17000.00
0005435681934	24586	Economy	17000.00
0005435438031	24586	Economy	17000.00
0005434828708	24586	Economy	17000.00
0005435438035	24586	Economy	17000.00
0005435681891	24586	Economy	17000.00
0005435720813	24586	Economy	17000.00
0005435438036	24586	Economy	17000.00
0005435681895	24586	Economy	17000.00
0005435438032	24586	Economy	17000.00
0005435719562	24586	Economy	17000.00
0005435682026	24586	Economy	17000.00
0005435682085	24586	Economy	17000.00
0005435681877	24586	Economy	17000.00
0005435681997	24586	Economy	17000.00
0005435438037	24586	Economy	17000.00
0005432305758	24586	Economy	17000.00
0005435682004	24586	Economy	17000.00
0005435681938	24586	Economy	17000.00
0005432533304	24586	Economy	17000.00
0005435438038	24586	Economy	17000.00
0005435438030	24586	Economy	17000.00
0005435438051	24586	Economy	17000.00
0005435681915	24586	Economy	17000.00
0005435681931	24586	Economy	17000.00
0005435438034	24586	Economy	17000.00
0005435438044	24586	Economy	17000.00
0005434828709	24586	Economy	17000.00
0005435681807	24586	Economy	17000.00
0005435681851	24586	Economy	17000.00
0005435681858	24586	Economy	17000.00
0005435681907	24586	Economy	17000.00
0005435681996	24586	Economy	17000.00
0005435681829	24586	Economy	17000.00
0005435681896	24586	Economy	17000.00
0005435682017	24586	Economy	17000.00
0005435681945	24586	Economy	17000.00
0005435681914	24586	Economy	17000.00
0005435682052	24586	Economy	17000.00
0005435438052	24586	Economy	17000.00
0005435682039	24586	Economy	17000.00
0005435682097	24586	Economy	17000.00
0005435681853	24586	Economy	17000.00
0005435681908	24586	Economy	17000.00
0005435681876	24586	Economy	17000.00
0005435438029	24586	Economy	17000.00
0005435438040	24586	Economy	17000.00
0005435682076	24586	Economy	17000.00
0005435681852	24586	Economy	17000.00
0005435126503	11501	Business	26400.00
0005435126510	11501	Business	26400.00
0005435126485	11501	Business	26400.00
0005435126520	11501	Business	26400.00
0005435126483	11501	Business	26400.00
0005435126514	11501	Economy	8800.00
0005435126488	11501	Economy	8800.00
0005435126496	11501	Economy	8800.00
0005435126502	11501	Economy	8800.00
0005435126490	11501	Economy	8800.00
0005435105991	11501	Economy	9700.00
0005435126509	11501	Economy	9700.00
0005435126500	11501	Economy	8800.00
0005435126493	11501	Economy	8800.00
0005435126504	11501	Economy	8800.00
0005435126516	11501	Economy	8800.00
0005435126489	11501	Economy	8800.00
0005435126518	11501	Economy	8800.00
0005435126481	11501	Economy	8800.00
0005435558063	11501	Economy	8800.00
0005435126491	11501	Economy	8800.00
0005435126487	11501	Economy	8800.00
0005435126501	11501	Economy	8800.00
0005435126484	11501	Economy	8800.00
0005435126506	11501	Economy	8800.00
0005435126482	11501	Economy	8800.00
0005435126517	11501	Economy	8800.00
0005435126508	11501	Economy	8800.00
0005435558064	11501	Economy	8800.00
0005435126494	11501	Economy	8800.00
0005435126495	11501	Economy	8800.00
0005435126486	11501	Economy	8800.00
0005435126511	11501	Economy	8800.00
0005435126513	11501	Economy	8800.00
0005435126515	11501	Economy	8800.00
0005435126492	11501	Economy	8800.00
0005435105993	11501	Economy	8800.00
0005435126505	11501	Economy	8800.00
0005435126512	11501	Economy	8800.00
0005435105994	11501	Economy	8800.00
0005435126519	11501	Economy	8800.00
0005435126497	11501	Economy	8800.00
0005435105992	11501	Economy	8800.00
0005435126499	11501	Economy	8800.00
0005435126498	11501	Economy	8800.00
0005435126507	11501	Economy	8800.00
0005435126234	31908	Business	26400.00
0005435126184	31908	Business	26400.00
0005435126183	31908	Business	26400.00
0005435126269	31908	Economy	8800.00
0005435126222	31908	Economy	8800.00
0005435126301	31908	Economy	8800.00
0005435558098	31908	Economy	8800.00
0005435126166	31908	Economy	8800.00
0005435126167	31908	Economy	9700.00
0005435125941	31908	Economy	9700.00
0005435126072	31908	Economy	9700.00
0005435126233	31908	Economy	9700.00
0005435126073	31908	Economy	8800.00
0005435126350	31908	Economy	8800.00
0005435126174	31908	Economy	8800.00
0005435126002	31908	Economy	8800.00
0005435126109	31908	Economy	8800.00
0005435126169	31908	Economy	8800.00
0005435126319	31908	Economy	8800.00
0005435558097	31908	Economy	8800.00
0005435126177	31908	Economy	8800.00
0005435126191	31908	Economy	8800.00
0005435126194	31908	Economy	8800.00
0005435126190	31908	Economy	8800.00
0005435126185	31908	Economy	8800.00
0005435126085	31908	Economy	8800.00
0005435126176	31908	Economy	8800.00
0005435126083	31908	Economy	8800.00
0005435105964	31908	Economy	8800.00
0005435126003	31908	Economy	8800.00
0005435126110	31908	Economy	8800.00
0005435126175	31908	Economy	8800.00
0005435126192	31908	Economy	8800.00
0005433398228	13539	Business	36600.00
0005433398246	13539	Business	36600.00
0005433398258	13539	Business	36600.00
0005433398265	13539	Business	36600.00
0005433398264	13539	Business	36600.00
0005433398240	13539	Business	36600.00
0005433398250	13539	Business	36600.00
0005435732248	13539	Business	36600.00
0005433398254	13539	Business	36600.00
0005433398230	13539	Business	36600.00
0005433398225	13539	Economy	12200.00
0005433398242	13539	Economy	12200.00
0005433398270	13539	Economy	12200.00
0005435732311	13539	Economy	12200.00
0005433398247	13539	Economy	12200.00
0005433398243	13539	Economy	12200.00
0005433398238	13539	Economy	12200.00
0005433398257	13539	Economy	12200.00
0005435732279	13539	Economy	13400.00
0005433398248	13539	Economy	13400.00
0005435732245	13539	Economy	13400.00
0005433398241	13539	Economy	13400.00
0005433398263	13539	Economy	12200.00
0005433398256	13539	Economy	12200.00
0005433398227	13539	Economy	12200.00
0005433398267	13539	Economy	12200.00
0005433398245	13539	Economy	12200.00
0005433398231	13539	Economy	12200.00
0005433398234	13539	Economy	12200.00
0005433398268	13539	Economy	12200.00
0005433398262	13539	Economy	12200.00
0005433398233	13539	Economy	12200.00
0005435732286	13539	Economy	12200.00
0005433398261	13539	Economy	12200.00
0005433398235	13539	Economy	12200.00
0005435732272	13539	Economy	12200.00
0005433398224	13539	Economy	12200.00
0005433398249	13539	Economy	12200.00
0005433398252	13539	Economy	12200.00
0005435732214	13539	Economy	12200.00
0005433398260	13539	Economy	12200.00
0005433398229	13539	Economy	12200.00
0005433398237	13539	Economy	12200.00
0005435732243	13539	Economy	12200.00
0005433398269	13539	Economy	12200.00
0005433398266	13539	Economy	12200.00
0005433398226	13539	Economy	12200.00
0005433398239	13539	Economy	12200.00
0005435732257	13539	Economy	12200.00
0005433398251	13539	Economy	12200.00
0005435732277	13539	Economy	12200.00
0005435732278	13539	Economy	12200.00
0005433398253	13539	Economy	12200.00
0005433398259	13539	Economy	12200.00
0005433398255	13539	Economy	12200.00
0005433398244	13539	Economy	12200.00
0005435732244	13539	Economy	12200.00
0005433398232	13539	Economy	12200.00
0005435732273	13539	Economy	12200.00
0005433398236	13539	Economy	12200.00
0005433398271	13539	Economy	12200.00
0005435732215	13539	Economy	12200.00
0005433397997	19407	Business	36600.00
0005435732383	19407	Business	36600.00
0005433397921	19407	Business	36600.00
0005433397747	19407	Business	36600.00
0005435732366	19407	Business	36600.00
0005433397853	19407	Business	36600.00
0005433398022	19407	Business	36600.00
0005435732380	19407	Business	36600.00
0005433397928	19407	Business	36600.00
0005433397590	19407	Economy	12200.00
0005433397832	19407	Economy	12200.00
0005435732375	19407	Economy	12200.00
0005433397919	19407	Economy	12200.00
0005433397961	19407	Economy	12200.00
0005433397810	19407	Economy	12200.00
0005433397829	19407	Economy	12200.00
0005435732372	19407	Economy	13400.00
0005433397541	19407	Economy	13400.00
0005433397803	19407	Economy	12200.00
0005433397927	19407	Economy	12200.00
0005435732370	19407	Economy	12200.00
0005433397735	19407	Economy	12200.00
0005433397802	19407	Economy	12200.00
0005433397769	19407	Economy	12200.00
0005435732379	19407	Economy	12200.00
0005433397795	19407	Economy	12200.00
0005435732381	19407	Economy	12200.00
0005433397913	19407	Economy	12200.00
0005435732387	19407	Economy	12200.00
0005435732385	19407	Economy	12200.00
0005433397662	19407	Economy	12200.00
0005435732388	19407	Economy	12200.00
0005433397914	19407	Economy	12200.00
0005435732384	19407	Economy	12200.00
0005435732371	19407	Economy	12200.00
0005433398004	19407	Economy	12200.00
0005435732378	19407	Economy	12200.00
0005433397748	19407	Economy	12200.00
0005435732389	19407	Economy	12200.00
0005435732374	19407	Economy	12200.00
0005435732368	19407	Economy	12200.00
0005435732376	19407	Economy	12200.00
0005433397922	19407	Economy	12200.00
0005435732386	19407	Economy	12200.00
0005433397824	19407	Economy	12200.00
0005435732382	19407	Economy	12200.00
0005435732377	19407	Economy	12200.00
0005433397833	19407	Economy	12200.00
0005435732369	19407	Economy	12200.00
0005433397925	19407	Economy	12200.00
0005435732367	19407	Economy	12200.00
0005433397898	19407	Economy	12200.00
0005433397904	19407	Economy	12200.00
0005433397825	19407	Economy	12200.00
0005433397737	19407	Economy	12200.00
0005433397834	19407	Economy	12200.00
0005433397805	19407	Economy	12200.00
0005433397797	19407	Economy	12200.00
0005433397915	19407	Economy	12200.00
0005433397553	19407	Economy	12200.00
0005433397897	19407	Economy	12200.00
0005433397955	19407	Economy	12200.00
0005435732373	19407	Economy	12200.00
0005433397796	19407	Economy	12200.00
0005433397652	19407	Economy	12200.00
0005433397983	19407	Economy	12200.00
0005433397926	19407	Economy	12200.00
0005433397982	19407	Economy	12200.00
0005433398031	19407	Economy	12200.00
0005435925345	13155	Business	11300.00
0005435925341	13155	Business	11300.00
0005435068658	13155	Business	11300.00
0005435068651	13155	Business	11300.00
0005435068832	13155	Business	11300.00
0005435068678	13155	Business	11300.00
0005435068718	13155	Economy	3800.00
0005435068842	13155	Economy	3800.00
0005435925355	13155	Economy	3800.00
0005435068679	13155	Economy	3800.00
0005435068830	13155	Economy	3800.00
0005435925356	13155	Economy	3800.00
0005435925348	13155	Economy	3800.00
0005435068772	13155	Economy	4100.00
0005435068690	13155	Economy	4100.00
0005435068741	13155	Economy	4100.00
0005435925352	13155	Economy	4100.00
0005435068771	13155	Economy	3800.00
0005435068827	13155	Economy	3800.00
0005435925349	13155	Economy	3800.00
0005435925353	13155	Economy	3800.00
0005435068705	13155	Economy	3800.00
0005435068710	13155	Economy	3800.00
0005435068926	13155	Economy	3800.00
0005435068742	13155	Economy	3800.00
0005435925346	13155	Economy	3800.00
0005435068941	13155	Economy	3800.00
0005435068918	13155	Economy	3800.00
0005435925343	13155	Economy	3800.00
0005435068974	13155	Economy	3800.00
0005435068659	13155	Economy	3800.00
0005435068989	13155	Economy	3800.00
0005435068917	13155	Economy	3800.00
0005435068689	13155	Economy	3800.00
0005435068970	13155	Economy	3800.00
0005435068726	13155	Economy	3800.00
0005435925344	13155	Economy	3800.00
0005435068870	13155	Economy	3800.00
0005435068656	13155	Economy	3800.00
0005435068646	13155	Economy	3800.00
0005435068764	13155	Economy	3800.00
0005435068773	13155	Economy	3800.00
0005435068925	13155	Economy	3800.00
0005435068817	13155	Economy	3800.00
0005435068833	13155	Economy	3800.00
0005435068891	13155	Economy	3800.00
0005435068831	13155	Economy	3800.00
0005435925354	13155	Economy	3800.00
0005435068893	13155	Economy	3800.00
0005435069087	13155	Economy	3800.00
0005435925347	13155	Economy	3800.00
0005435068677	13155	Economy	3800.00
0005435925342	13155	Economy	3800.00
0005435925351	13155	Economy	3800.00
0005435068794	13155	Economy	3800.00
0005435925350	13155	Economy	3800.00
0005435069259	15489	Business	11300.00
0005435069251	15489	Business	11300.00
0005435069225	15489	Business	11300.00
0005435069231	15489	Business	11300.00
0005435069269	15489	Business	11300.00
0005435069266	15489	Business	11300.00
0005435069224	15489	Business	11300.00
0005435069271	15489	Business	11300.00
0005435069252	15489	Economy	3800.00
0005435069228	15489	Economy	3800.00
0005435069241	15489	Economy	3800.00
0005435069265	15489	Economy	3800.00
0005435069238	15489	Economy	3800.00
0005435069229	15489	Economy	3800.00
0005435925253	15489	Economy	3800.00
0005435069235	15489	Economy	4100.00
0005435925180	15489	Economy	4100.00
0005435069223	15489	Economy	3800.00
0005435069220	15489	Economy	3800.00
0005435069242	15489	Economy	3800.00
0005435925105	15489	Economy	3800.00
0005435069237	15489	Economy	3800.00
0005435069244	15489	Economy	3800.00
0005435069253	15489	Economy	3800.00
0005435069268	15489	Economy	3800.00
0005435069254	15489	Economy	3800.00
0005435069239	15489	Economy	3800.00
0005435069247	15489	Economy	3800.00
0005435069240	15489	Economy	3800.00
0005435069243	15489	Economy	3800.00
0005435925241	15489	Economy	3800.00
0005435069248	15489	Economy	3800.00
0005435069256	15489	Economy	3800.00
0005435069245	15489	Economy	3800.00
0005435069263	15489	Economy	3800.00
0005435069233	15489	Economy	3800.00
0005435925214	15489	Economy	3800.00
0005435069255	15489	Economy	3800.00
0005435069260	15489	Economy	3800.00
0005435925220	15489	Economy	3800.00
0005435069249	15489	Economy	3800.00
0005435069234	15489	Economy	3800.00
0005435069262	15489	Economy	3800.00
0005435069230	15489	Economy	3800.00
0005435925240	15489	Economy	3800.00
0005435069264	15489	Economy	3800.00
0005435069219	15489	Economy	3800.00
0005435069221	15489	Economy	3800.00
0005435069267	15489	Economy	3800.00
0005435069222	15489	Economy	3800.00
0005435069232	15489	Economy	3800.00
0005435925237	15489	Economy	3800.00
0005435069218	15489	Economy	3800.00
0005435925260	15489	Economy	3800.00
0005435069246	15489	Economy	3800.00
0005435069227	15489	Economy	3800.00
0005435925203	15489	Economy	3800.00
0005435925238	15489	Economy	3800.00
0005435069257	15489	Economy	3800.00
0005435069270	15489	Economy	3800.00
0005435925219	15489	Economy	3800.00
0005435069236	15489	Economy	3800.00
0005435925225	15489	Economy	3800.00
0005435069258	15489	Economy	3800.00
0005435069226	15489	Economy	3800.00
0005435069250	15489	Economy	3800.00
0005435069261	15489	Economy	3800.00
0005435808149	29491	Economy	27100.00
0005435808202	29491	Economy	27100.00
0005433407580	29491	Economy	27100.00
0005433407581	29491	Economy	27100.00
0005433407577	29491	Economy	24700.00
0005433407576	29491	Economy	24700.00
0005435808172	29491	Economy	24700.00
0005433407589	29491	Economy	24700.00
0005435808128	29491	Economy	24700.00
0005435808177	29491	Economy	24700.00
0005435808158	29491	Economy	24700.00
0005433407586	29491	Economy	24700.00
0005433407582	29491	Economy	24700.00
0005435808171	29491	Economy	24700.00
0005433407585	29491	Economy	24700.00
0005435808207	29491	Economy	24700.00
0005435808203	29491	Economy	24700.00
0005433407590	29491	Economy	24700.00
0005435808089	29491	Economy	24700.00
0005435808164	29491	Economy	24700.00
0005433407583	29491	Economy	24700.00
0005433407587	29491	Economy	24700.00
0005435808157	29491	Economy	24700.00
0005435808174	29491	Economy	24700.00
0005435808160	29491	Economy	24700.00
0005435808156	29491	Economy	24700.00
0005433407578	29491	Economy	24700.00
0005433407584	29491	Economy	24700.00
0005435808170	29491	Economy	24700.00
0005435808205	29491	Economy	24700.00
0005433407591	29491	Economy	24700.00
0005433407588	29491	Economy	24700.00
0005435808090	29491	Economy	24700.00
0005435808206	29491	Economy	24700.00
0005435808152	29491	Economy	24700.00
0005433407575	29491	Economy	24700.00
0005435808142	29491	Economy	24700.00
0005433407579	29491	Economy	24700.00
0005435808143	29491	Economy	24700.00
0005435808150	29491	Economy	24700.00
0005435808151	29491	Economy	24700.00
0005434756084	10720	Business	61300.00
0005434756252	10720	Business	61300.00
0005434756290	10720	Business	61300.00
0005434756145	10720	Business	61300.00
0005434214698	10720	Business	61300.00
0005434214724	10720	Business	61300.00
0005434214734	10720	Business	61300.00
0005434214739	10720	Business	61300.00
0005434214700	10720	Business	61300.00
0005434756336	10720	Business	61300.00
0005434214708	10720	Business	61300.00
0005434214737	10720	Business	61300.00
0005434214742	10720	Economy	20400.00
0005434214736	10720	Economy	20400.00
0005434756069	10720	Economy	20400.00
0005434214705	10720	Economy	20400.00
0005434214735	10720	Economy	20400.00
0005434214729	10720	Economy	20400.00
0005434214704	10720	Economy	20400.00
0005434756322	10720	Economy	20400.00
0005434214717	10720	Economy	20400.00
0005434214718	10720	Economy	22500.00
0005434214702	10720	Economy	22500.00
0005434756151	10720	Economy	22500.00
0005434756167	10720	Economy	22500.00
0005434756152	10720	Economy	20400.00
0005434214731	10720	Economy	20400.00
0005434214740	10720	Economy	20400.00
0005434214715	10720	Economy	20400.00
0005434214743	10720	Economy	20400.00
0005434756251	10720	Economy	20400.00
0005434214714	10720	Economy	20400.00
0005434756245	10720	Economy	20400.00
0005434756272	10720	Economy	20400.00
0005434214722	10720	Economy	20400.00
0005434756253	10720	Economy	20400.00
0005434756250	10720	Economy	20400.00
0005434214741	10720	Economy	20400.00
0005434756143	10720	Economy	20400.00
0005434756258	10720	Economy	20400.00
0005434214699	10720	Economy	20400.00
0005434214725	10720	Economy	20400.00
0005434214738	10720	Economy	20400.00
0005434214712	10720	Economy	20400.00
0005434756273	10720	Economy	20400.00
0005434214719	10720	Economy	20400.00
0005434214711	10720	Economy	20400.00
0005434214710	10720	Economy	20400.00
0005434214697	10720	Economy	20400.00
0005434756144	10720	Economy	20400.00
0005434756285	10720	Economy	20400.00
0005434214744	10720	Economy	20400.00
0005434214716	10720	Economy	20400.00
0005434756088	10720	Economy	20400.00
0005434756202	10720	Economy	20400.00
0005434214720	10720	Economy	20400.00
0005434214728	10720	Economy	20400.00
0005434756284	10720	Economy	20400.00
0005434756100	10720	Economy	20400.00
0005434756217	10720	Economy	20400.00
0005434756082	10720	Economy	20400.00
0005434214709	10720	Economy	20400.00
0005434756270	10720	Economy	20400.00
0005434214723	10720	Economy	20400.00
0005434214732	10720	Economy	20400.00
0005434214713	10720	Economy	20400.00
0005434214707	10720	Economy	20400.00
0005434756169	10720	Economy	20400.00
0005434214703	10720	Economy	20400.00
0005434214701	10720	Economy	20400.00
0005434756292	10720	Economy	20400.00
0005434214733	10720	Economy	20400.00
0005434214730	10720	Economy	20400.00
0005434214706	10720	Economy	20400.00
0005434214721	10720	Economy	20400.00
0005434214726	10720	Economy	20400.00
0005434214727	10720	Economy	20400.00
0005434756142	10720	Economy	20400.00
0005434756083	10720	Economy	20400.00
0005434214143	28669	Business	61300.00
0005434214211	28669	Business	61300.00
0005434756557	28669	Business	61300.00
0005434214255	28669	Business	61300.00
0005434214217	28669	Business	61300.00
0005434214127	28669	Business	61300.00
0005434756519	28669	Business	61300.00
0005434756528	28669	Business	61300.00
0005434214138	28669	Economy	20400.00
0005434214141	28669	Economy	20400.00
0005434756539	28669	Economy	20400.00
0005434756542	28669	Economy	20400.00
0005434756560	28669	Economy	20400.00
0005434756540	28669	Economy	20400.00
0005434756537	28669	Economy	20400.00
0005434756564	28669	Economy	20400.00
0005434756538	28669	Economy	22500.00
0005434756561	28669	Economy	22500.00
0005434214249	28669	Economy	22500.00
0005434756527	28669	Economy	22500.00
0005434214112	28669	Economy	22500.00
0005434756549	28669	Economy	20400.00
0005434756541	28669	Economy	20400.00
0005434214174	28669	Economy	20400.00
0005434756529	28669	Economy	20400.00
0005434214212	28669	Economy	20400.00
0005434214107	28669	Economy	20400.00
0005434214165	28669	Economy	20400.00
0005434756551	28669	Economy	20400.00
0005434756520	28669	Economy	20400.00
0005434756531	28669	Economy	20400.00
0005434214286	28669	Economy	20400.00
0005434756556	28669	Economy	20400.00
0005434214129	28669	Economy	20400.00
0005434756525	28669	Economy	20400.00
0005434756544	28669	Economy	20400.00
0005434214325	28669	Economy	20400.00
0005434214201	28669	Economy	20400.00
0005434756559	28669	Economy	20400.00
0005434756523	28669	Economy	20400.00
0005434756536	28669	Economy	20400.00
0005434756534	28669	Economy	20400.00
0005434756558	28669	Economy	20400.00
0005434756533	28669	Economy	20400.00
0005434214183	28669	Economy	20400.00
0005434214176	28669	Economy	20400.00
0005434756546	28669	Economy	20400.00
0005434214111	28669	Economy	20400.00
0005434756535	28669	Economy	20400.00
0005434756517	28669	Economy	20400.00
0005434756563	28669	Economy	20400.00
0005434214128	28669	Economy	20400.00
0005434756516	28669	Economy	20400.00
0005434214216	28669	Economy	20400.00
0005434756552	28669	Economy	20400.00
0005434756522	28669	Economy	20400.00
0005434756515	28669	Economy	20400.00
0005434756553	28669	Economy	20400.00
0005434756521	28669	Economy	20400.00
0005434214329	28669	Economy	20400.00
0005434756566	28669	Economy	20400.00
0005434214300	28669	Economy	20400.00
0005434756550	28669	Economy	20400.00
0005434214230	28669	Economy	20400.00
0005434214246	28669	Economy	20400.00
0005434756565	28669	Economy	20400.00
0005434214330	28669	Economy	20400.00
0005434756532	28669	Economy	20400.00
0005434214285	28669	Economy	20400.00
0005434756545	28669	Economy	20400.00
0005434214177	28669	Economy	20400.00
0005434756526	28669	Economy	20400.00
0005434214061	28669	Economy	20400.00
0005434756518	28669	Economy	20400.00
0005434756562	28669	Economy	20400.00
0005434756548	28669	Economy	20400.00
0005434214164	28669	Economy	20400.00
0005434756530	28669	Economy	20400.00
0005434214278	28669	Economy	20400.00
0005434756547	28669	Economy	20400.00
0005434214360	28669	Economy	20400.00
0005434756524	28669	Economy	20400.00
0005434756555	28669	Economy	20400.00
0005434756554	28669	Economy	20400.00
0005434756543	28669	Economy	20400.00
0005434214140	28669	Economy	20400.00
0005435007129	5477	Business	29500.00
0005435040059	5477	Business	29500.00
0005435040053	5477	Business	29500.00
0005435042861	5477	Business	29500.00
0005432125481	5477	Business	29500.00
0005432125483	5477	Business	29500.00
0005434229215	5477	Business	29500.00
0005435040019	5477	Business	29500.00
0005432125478	5477	Business	29500.00
0005435007123	5477	Business	29500.00
0005435040047	5477	Business	29500.00
0005434229280	5477	Business	29500.00
0005435040060	5477	Economy	9800.00
0005435040018	5477	Economy	9800.00
0005432125477	5477	Economy	9800.00
0005435040032	5477	Economy	9800.00
0005435040041	5477	Economy	9800.00
0005435040048	5477	Economy	9800.00
0005434229305	5477	Economy	9800.00
0005435040038	5477	Economy	9800.00
0005434229204	5477	Economy	9800.00
0005435040020	5477	Economy	9800.00
0005435040062	5477	Economy	9800.00
0005435039998	5477	Economy	9800.00
0005435007111	5477	Economy	9800.00
0005435040054	5477	Economy	9800.00
0005435040050	5477	Economy	9800.00
0005435040051	5477	Economy	9800.00
0005435040025	5477	Economy	9800.00
0005435007136	5477	Economy	9800.00
0005432125482	5477	Economy	9800.00
0005435007113	5477	Economy	9800.00
0005435040058	5477	Economy	9800.00
0005434229254	5477	Economy	9800.00
0005435040061	5477	Economy	9800.00
0005434229323	5477	Economy	9800.00
0005435007130	5477	Economy	9800.00
0005435040012	5477	Economy	9800.00
0005435040015	5477	Economy	9800.00
0005435007131	5477	Economy	9800.00
0005435040039	5477	Economy	9800.00
0005435040064	5477	Economy	9800.00
0005435040049	5477	Economy	9800.00
0005435040005	5477	Economy	9800.00
0005435007120	5477	Economy	9800.00
0005435040028	5477	Economy	9800.00
0005434229322	5477	Economy	9800.00
0005435039997	5477	Economy	9800.00
0005435007133	5477	Economy	9800.00
0005435040008	5477	Economy	9800.00
0005435007115	5477	Economy	9800.00
0005435007132	5477	Economy	10800.00
0005435043287	5477	Economy	10800.00
0005435040011	5477	Economy	10800.00
0005435040001	5477	Economy	10800.00
0005435040036	5477	Economy	10800.00
0005435007128	5477	Economy	10800.00
0005435040034	5477	Economy	9800.00
0005434229286	5477	Economy	9800.00
0005435007126	5477	Economy	9800.00
0005435007114	5477	Economy	9800.00
0005435040024	5477	Economy	9800.00
0005435007110	5477	Economy	9800.00
0005435007121	5477	Economy	9800.00
0005435040021	5477	Economy	9800.00
0005435040016	5477	Economy	9800.00
0005435040014	5477	Economy	9800.00
0005435040057	5477	Economy	9800.00
0005434229034	5477	Economy	9800.00
0005435040040	5477	Economy	9800.00
0005435039999	5477	Economy	9800.00
0005435042862	5477	Economy	9800.00
0005435040044	5477	Economy	9800.00
0005432125484	5477	Economy	9800.00
0005435040055	5477	Economy	9800.00
0005435040042	5477	Economy	9800.00
0005435040022	5477	Economy	9800.00
0005435007135	5477	Economy	9800.00
0005434229301	5477	Economy	9800.00
0005434229304	5477	Economy	9800.00
0005435040030	5477	Economy	9800.00
0005435007117	5477	Economy	9800.00
0005435007119	5477	Economy	9800.00
0005435042864	5477	Economy	9800.00
0005435040046	5477	Economy	9800.00
0005435040031	5477	Economy	9800.00
0005435040052	5477	Economy	9800.00
0005434229206	5477	Economy	9800.00
0005435040027	5477	Economy	9800.00
0005435040013	5477	Economy	9800.00
0005435040063	5477	Economy	9800.00
0005435040023	5477	Economy	9800.00
0005435007112	5477	Economy	9800.00
0005435007127	5477	Economy	9800.00
0005435040045	5477	Economy	9800.00
0005435040035	5477	Economy	9800.00
0005435040004	5477	Economy	9800.00
0005434229207	5477	Economy	9800.00
0005435040026	5477	Economy	9800.00
0005435007134	5477	Economy	9800.00
0005435007125	5477	Economy	9800.00
0005435040010	5477	Economy	9800.00
0005435007118	5477	Economy	9800.00
0005434229253	5477	Economy	9800.00
0005434229279	5477	Economy	9800.00
0005434229255	5477	Economy	9800.00
0005435040009	5477	Economy	9800.00
0005432125480	5477	Economy	9800.00
0005435040017	5477	Economy	9800.00
0005435007124	5477	Economy	9800.00
0005432125479	5477	Economy	9800.00
0005435042863	5477	Economy	9800.00
0005435040033	5477	Economy	9800.00
0005435040000	5477	Economy	9800.00
0005435040037	5477	Economy	9800.00
0005435040007	5477	Economy	9800.00
0005435040056	5477	Economy	9800.00
0005435040006	5477	Economy	9800.00
0005435040003	5477	Economy	9800.00
0005435043286	5477	Economy	9800.00
0005435007116	5477	Economy	9800.00
0005435040043	5477	Economy	9800.00
0005435040002	5477	Economy	9800.00
0005435007122	5477	Economy	9800.00
0005434229298	5477	Economy	9800.00
0005434229257	5477	Economy	9800.00
0005434229256	5477	Economy	9800.00
0005435040029	5477	Economy	9800.00
0005435006968	12970	Business	29500.00
0005435039337	12970	Business	29500.00
0005435042847	12970	Business	29500.00
0005435006943	12970	Business	29500.00
0005435006967	12970	Business	29500.00
0005435039431	12970	Business	29500.00
0005435039134	12970	Business	29500.00
0005435039415	12970	Business	29500.00
0005435039356	12970	Business	29500.00
0005432304415	12970	Business	29500.00
0005434229459	12970	Business	29500.00
0005435039479	12970	Economy	9800.00
0005435039398	12970	Economy	9800.00
0005435039543	12970	Economy	9800.00
0005435039355	12970	Economy	9800.00
0005435039666	12970	Economy	9800.00
0005435039524	12970	Economy	9800.00
0005434229457	12970	Economy	9800.00
0005435006910	12970	Economy	9800.00
0005435039126	12970	Economy	9800.00
0005435039392	12970	Economy	9800.00
0005432304414	12970	Economy	9800.00
0005435039418	12970	Economy	9800.00
0005435006929	12970	Economy	9800.00
0005435039342	12970	Economy	9800.00
0005435043283	12970	Economy	9800.00
0005435039665	12970	Economy	9800.00
0005435006865	12970	Economy	9800.00
0005435006959	12970	Economy	9800.00
0005434229463	12970	Economy	9800.00
0005434229470	12970	Economy	9800.00
0005435006923	12970	Economy	9800.00
0005435006924	12970	Economy	9800.00
0005434229469	12970	Economy	9800.00
0005435039440	12970	Economy	9800.00
0005435377905	12970	Economy	9800.00
0005435039538	12970	Economy	9800.00
0005434229474	12970	Economy	9800.00
0005434229464	12970	Economy	9800.00
0005435039528	12970	Economy	9800.00
0005434229460	12970	Economy	9800.00
0005435039338	12970	Economy	9800.00
0005434229467	12970	Economy	9800.00
0005435039792	12970	Economy	9800.00
0005435006966	12970	Economy	9800.00
0005435039177	12970	Economy	9800.00
0005434229451	12970	Economy	9800.00
0005435039432	12970	Economy	9800.00
0005434229458	12970	Economy	9800.00
0005435039454	12970	Economy	10800.00
0005435039247	12970	Economy	10800.00
0005434229461	12970	Economy	10800.00
0005435039534	12970	Economy	10800.00
0005435006898	12970	Economy	10800.00
0005435039302	12970	Economy	9800.00
0005435039549	12970	Economy	9800.00
0005435006874	12970	Economy	9800.00
0005435006876	12970	Economy	9800.00
0005435042837	12970	Economy	9800.00
0005434229452	12970	Economy	9800.00
0005434229465	12970	Economy	9800.00
0005435006965	12970	Economy	9800.00
0005435039523	12970	Economy	9800.00
0005435039577	12970	Economy	9800.00
0005434229462	12970	Economy	9800.00
0005435039417	12970	Economy	9800.00
0005435006909	12970	Economy	9800.00
0005434229456	12970	Economy	9800.00
0005435006911	12970	Economy	9800.00
0005435006877	12970	Economy	9800.00
0005435039526	12970	Economy	9800.00
0005435039378	12970	Economy	9800.00
0005435039509	12970	Economy	9800.00
0005432304413	12970	Economy	9800.00
0005435006941	12970	Economy	9800.00
0005435039393	12970	Economy	9800.00
0005434229455	12970	Economy	9800.00
0005435039481	12970	Economy	9800.00
0005435006847	12970	Economy	9800.00
0005435039401	12970	Economy	9800.00
0005435039419	12970	Economy	9800.00
0005435039505	12970	Economy	9800.00
0005435043285	12970	Economy	9800.00
0005432304412	12970	Economy	9800.00
0005435039662	12970	Economy	9800.00
0005435039547	12970	Economy	9800.00
0005435039254	12970	Economy	9800.00
0005435039125	12970	Economy	9800.00
0005435039480	12970	Economy	9800.00
0005435039570	12970	Economy	9800.00
0005435006878	12970	Economy	9800.00
0005434229468	12970	Economy	9800.00
0005435006908	12970	Economy	9800.00
0005435007040	12970	Economy	9800.00
0005434229454	12970	Economy	9800.00
0005435039569	12970	Economy	9800.00
0005434229472	12970	Economy	9800.00
0005434229473	12970	Economy	9800.00
0005434229471	12970	Economy	9800.00
0005435006942	12970	Economy	9800.00
0005435039599	12970	Economy	9800.00
0005435039546	12970	Economy	9800.00
0005434229466	12970	Economy	9800.00
0005435039400	12970	Economy	9800.00
0005434229453	12970	Economy	9800.00
0005435007041	12970	Economy	9800.00
0005435039585	12970	Economy	9800.00
0005435039649	12970	Economy	9800.00
0005435039107	12970	Economy	9800.00
0005435006758	12970	Economy	9800.00
0005435039493	12970	Economy	9800.00
0005434426713	14884	Business	52900.00
0005434426695	14884	Business	52900.00
0005435902600	14884	Business	52900.00
0005435902655	14884	Business	52900.00
0005435902642	14884	Business	52900.00
0005435902651	14884	Business	52900.00
0005435902622	14884	Business	52900.00
0005432188617	14884	Business	52900.00
0005432188618	14884	Business	52900.00
0005434426707	14884	Economy	17600.00
0005434426716	14884	Economy	17600.00
0005435902677	14884	Economy	17600.00
0005434426710	14884	Economy	17600.00
0005435902648	14884	Economy	17600.00
0005435902584	14884	Economy	17600.00
0005434426698	14884	Economy	17600.00
0005434426694	14884	Economy	17600.00
0005435902532	14884	Economy	19400.00
0005432188616	14884	Economy	17600.00
0005434411790	14884	Economy	17600.00
0005435902531	14884	Economy	17600.00
0005434426693	14884	Economy	17600.00
0005435902623	14884	Economy	17600.00
0005434426699	14884	Economy	17600.00
0005435902649	14884	Economy	17600.00
0005434426718	14884	Economy	17600.00
0005434426687	14884	Economy	17600.00
0005434426691	14884	Economy	17600.00
0005435554144	14884	Economy	17600.00
0005435554156	14884	Economy	17600.00
0005434426700	14884	Economy	17600.00
0005434426692	14884	Economy	17600.00
0005434426708	14884	Economy	17600.00
0005435902695	14884	Economy	17600.00
0005434411791	14884	Economy	17600.00
0005434426715	14884	Economy	17600.00
0005434426714	14884	Economy	17600.00
0005434426703	14884	Economy	17600.00
0005432188619	14884	Economy	17600.00
0005434426689	14884	Economy	17600.00
0005434426696	14884	Economy	17600.00
0005435902629	14884	Economy	17600.00
0005435554153	14884	Economy	17600.00
0005435902633	14884	Economy	17600.00
0005435902641	14884	Economy	17600.00
0005434426701	14884	Economy	17600.00
0005432188620	14884	Economy	17600.00
0005435902634	14884	Economy	17600.00
0005435902632	14884	Economy	17600.00
0005435902540	14884	Economy	17600.00
0005434426709	14884	Economy	17600.00
0005434426688	14884	Economy	17600.00
0005434426706	14884	Economy	17600.00
0005435554160	14884	Economy	17600.00
0005434426704	14884	Economy	17600.00
0005434426697	14884	Economy	17600.00
0005435902596	14884	Economy	17600.00
0005434426702	14884	Economy	17600.00
0005435902656	14884	Economy	17600.00
0005435902638	14884	Economy	17600.00
0005434411792	14884	Economy	17600.00
0005434426690	14884	Economy	17600.00
0005434426711	14884	Economy	17600.00
0005434426712	14884	Economy	17600.00
0005434426717	14884	Economy	17600.00
0005434411793	14884	Economy	17600.00
0005434426705	14884	Economy	17600.00
0005435902597	14884	Economy	17600.00
0005432059514	20207	Business	52900.00
0005435902774	20207	Business	52900.00
0005434426530	20207	Business	52900.00
0005434411741	20207	Business	52900.00
0005434426468	20207	Business	52900.00
0005434426589	20207	Business	52900.00
0005435902770	20207	Business	52900.00
0005434411758	20207	Business	52900.00
0005435902771	20207	Economy	17600.00
0005435554209	20207	Economy	17600.00
0005434426417	20207	Economy	17600.00
0005434426625	20207	Economy	17600.00
0005435902783	20207	Economy	17600.00
0005434426416	20207	Economy	17600.00
0005434426529	20207	Economy	17600.00
0005435902775	20207	Economy	19400.00
0005434426375	20207	Economy	19400.00
0005434426582	20207	Economy	19400.00
0005435902768	20207	Economy	17600.00
0005435902780	20207	Economy	17600.00
0005435902781	20207	Economy	17600.00
0005434411751	20207	Economy	17600.00
0005432059512	20207	Economy	17600.00
0005435902782	20207	Economy	17600.00
0005434426558	20207	Economy	17600.00
0005434426376	20207	Economy	17600.00
0005434426626	20207	Economy	17600.00
0005435902777	20207	Economy	17600.00
0005434426485	20207	Economy	17600.00
0005434426559	20207	Economy	17600.00
0005434426374	20207	Economy	17600.00
0005434426590	20207	Economy	17600.00
0005435554211	20207	Economy	17600.00
0005434426437	20207	Economy	17600.00
0005435902767	20207	Economy	17600.00
0005435554210	20207	Economy	17600.00
0005434426507	20207	Economy	17600.00
0005434411753	20207	Economy	17600.00
0005434426366	20207	Economy	17600.00
0005435902769	20207	Economy	17600.00
0005435554208	20207	Economy	17600.00
0005435902776	20207	Economy	17600.00
0005434426389	20207	Economy	17600.00
0005435902773	20207	Economy	17600.00
0005434426557	20207	Economy	17600.00
0005434426547	20207	Economy	17600.00
0005434426444	20207	Economy	17600.00
0005434426388	20207	Economy	17600.00
0005435902779	20207	Economy	17600.00
0005435902772	20207	Economy	17600.00
0005434426506	20207	Economy	17600.00
0005434426581	20207	Economy	17600.00
0005435554207	20207	Economy	17600.00
0005434411759	20207	Economy	17600.00
0005434426486	20207	Economy	17600.00
0005434426425	20207	Economy	17600.00
0005434426462	20207	Economy	17600.00
0005434426556	20207	Economy	17600.00
0005435902784	20207	Economy	17600.00
0005435902778	20207	Economy	17600.00
0005432059513	20207	Economy	17600.00
0005434426373	20207	Economy	17600.00
0005434411752	20207	Economy	17600.00
0005434426412	20207	Economy	17600.00
0005432300281	26507	Business	18500.00
0005435982474	26507	Business	18500.00
0005433434583	26507	Business	18500.00
0005433434503	26507	Business	18500.00
0005435982452	26507	Business	18500.00
0005434270193	26507	Business	18500.00
0005435982476	26507	Business	18500.00
0005435982451	26507	Business	18500.00
0005432300283	26507	Business	18500.00
0005435982450	26507	Business	18500.00
0005435982470	26507	Economy	6200.00
0005433434546	26507	Economy	6200.00
0005435982483	26507	Economy	6200.00
0005435982446	26507	Economy	6200.00
0005433434516	26507	Economy	6200.00
0005435982455	26507	Economy	6200.00
0005435982462	26507	Economy	6200.00
0005433434610	26507	Economy	6200.00
0005435982466	26507	Economy	6200.00
0005433434493	26507	Economy	6200.00
0005433434639	26507	Economy	6800.00
0005435982453	26507	Economy	6800.00
0005435982456	26507	Economy	6800.00
0005433434494	26507	Economy	6200.00
0005435982475	26507	Economy	6200.00
0005434273067	26507	Economy	6200.00
0005435982465	26507	Economy	6200.00
0005433434517	26507	Economy	6200.00
0005433434609	26507	Economy	6200.00
0005435982447	26507	Economy	6200.00
0005435982471	26507	Economy	6200.00
0005435982479	26507	Economy	6200.00
0005433434586	26507	Economy	6200.00
0005433434570	26507	Economy	6200.00
0005432300284	26507	Economy	6200.00
0005435982459	26507	Economy	6200.00
0005433434502	26507	Economy	6200.00
0005432300282	26507	Economy	6200.00
0005435982443	26507	Economy	6200.00
0005435982472	26507	Economy	6200.00
0005433434507	26507	Economy	6200.00
0005433434522	26507	Economy	6200.00
0005435982454	26507	Economy	6200.00
0005433434430	26507	Economy	6200.00
0005433434521	26507	Economy	6200.00
0005433434454	26507	Economy	6200.00
0005435982478	26507	Economy	6200.00
0005435982463	26507	Economy	6200.00
0005434270191	26507	Economy	6200.00
0005433434534	26507	Economy	6200.00
0005435982484	26507	Economy	6200.00
0005435982460	26507	Economy	6200.00
0005433434431	26507	Economy	6200.00
0005435982464	26507	Economy	6200.00
0005435982469	26507	Economy	6200.00
0005433434545	26507	Economy	6200.00
0005433434535	26507	Economy	6200.00
0005435982482	26507	Economy	6200.00
0005434273068	26507	Economy	6200.00
0005433434571	26507	Economy	6200.00
0005435982449	26507	Economy	6200.00
0005435982445	26507	Economy	6200.00
0005435982480	26507	Economy	6200.00
0005433434631	26507	Economy	6200.00
0005433434569	26507	Economy	6200.00
0005433434611	26507	Economy	6200.00
0005435982467	26507	Economy	6200.00
0005435982461	26507	Economy	6200.00
0005435982448	26507	Economy	6200.00
0005435982444	26507	Economy	6200.00
0005435982477	26507	Economy	6200.00
0005433434544	26507	Economy	6200.00
0005435982481	26507	Economy	6200.00
0005435982458	26507	Economy	6200.00
0005432300280	26507	Economy	6200.00
0005434270200	26507	Economy	6200.00
0005433434453	26507	Economy	6200.00
0005433434448	26507	Economy	6200.00
0005432300279	26507	Economy	6200.00
0005435982457	26507	Economy	6200.00
0005435982468	26507	Economy	6200.00
0005433434508	26507	Economy	6200.00
0005433434414	26507	Economy	6200.00
0005435982473	26507	Economy	6200.00
0005435982264	26727	Business	18500.00
0005435982022	26727	Business	18500.00
0005435981865	26727	Business	18500.00
0005435981989	26727	Business	18500.00
0005435982265	26727	Business	18500.00
0005435982373	26727	Business	18500.00
0005433434801	26727	Business	18500.00
0005435982072	26727	Business	18500.00
0005433434785	26727	Business	18500.00
0005433434808	26727	Business	18500.00
0005433434806	26727	Business	18500.00
0005435981964	26727	Economy	6200.00
0005435982082	26727	Economy	6200.00
0005435982306	26727	Economy	6200.00
0005435982079	26727	Economy	6200.00
0005434270215	26727	Economy	6200.00
0005432051142	26727	Economy	6200.00
0005433434788	26727	Economy	6200.00
0005433434797	26727	Economy	6200.00
0005432051140	26727	Economy	6800.00
0005433434800	26727	Economy	6800.00
0005435981950	26727	Economy	6800.00
0005435981978	26727	Economy	6800.00
0005435982305	26727	Economy	6800.00
0005433434789	26727	Economy	6200.00
0005435982301	26727	Economy	6200.00
0005435982068	26727	Economy	6200.00
0005435981772	26727	Economy	6200.00
0005435981915	26727	Economy	6200.00
0005435982097	26727	Economy	6200.00
0005435982300	26727	Economy	6200.00
0005433434811	26727	Economy	6200.00
0005433434802	26727	Economy	6200.00
0005435981935	26727	Economy	6200.00
0005434271320	26727	Economy	6200.00
0005435982024	26727	Economy	6200.00
0005433434784	26727	Economy	6200.00
0005433434798	26727	Economy	6200.00
0005435982128	26727	Economy	6200.00
0005433434805	26727	Economy	6200.00
0005433434792	26727	Economy	6200.00
0005435981982	26727	Economy	6200.00
0005435981863	26727	Economy	6200.00
0005435982177	26727	Economy	6200.00
0005435982176	26727	Economy	6200.00
0005435982112	26727	Economy	6200.00
0005435982031	26727	Economy	6200.00
0005433434790	26727	Economy	6200.00
0005434270216	26727	Economy	6200.00
0005435981864	26727	Economy	6200.00
0005435982025	26727	Economy	6200.00
0005434271321	26727	Economy	6200.00
0005435982021	26727	Economy	6200.00
0005433434793	26727	Economy	6200.00
0005433434803	26727	Economy	6200.00
0005433434812	26727	Economy	6200.00
0005434269111	26727	Economy	6200.00
0005433434786	26727	Economy	6200.00
0005435982083	26727	Economy	6200.00
0005433434809	26727	Economy	6200.00
0005435982013	26727	Economy	6200.00
0005433434787	26727	Economy	6200.00
0005435981977	26727	Economy	6200.00
0005433434791	26727	Economy	6200.00
0005433434807	26727	Economy	6200.00
0005433434794	26727	Economy	6200.00
0005435981862	26727	Economy	6200.00
0005432051141	26727	Economy	6200.00
0005433434795	26727	Economy	6200.00
0005435982111	26727	Economy	6200.00
0005435982017	26727	Economy	6200.00
0005433434804	26727	Economy	6200.00
0005433434810	26727	Economy	6200.00
0005434269113	26727	Economy	6200.00
0005435982085	26727	Economy	6200.00
0005434269112	26727	Economy	6200.00
0005433434796	26727	Economy	6200.00
0005435982069	26727	Economy	6200.00
0005435982033	26727	Economy	6200.00
0005435982048	26727	Economy	6200.00
0005433434799	26727	Economy	6200.00
0005435982140	26727	Economy	6200.00
0005435982032	26727	Economy	6200.00
0005435982045	26727	Economy	6200.00
0005433686634	19520	Economy	21000.00
0005433686633	19520	Economy	21000.00
0005433687710	19520	Economy	21000.00
0005433686636	19520	Economy	19100.00
0005433687709	19520	Economy	19100.00
0005433687713	19520	Economy	19100.00
0005433686639	19520	Economy	19100.00
0005433685531	19520	Economy	19100.00
0005433685521	19520	Economy	19100.00
0005433686640	19520	Economy	19100.00
0005433687705	19520	Economy	19100.00
0005433686646	19520	Economy	19100.00
0005433685527	19520	Economy	19100.00
0005433687718	19520	Economy	19100.00
0005433685526	19520	Economy	19100.00
0005433687708	19520	Economy	19100.00
0005433687715	19520	Economy	19100.00
0005433685529	19520	Economy	19100.00
0005433687716	19520	Economy	19100.00
0005433686635	19520	Economy	19100.00
0005433687717	19520	Economy	19100.00
0005433686644	19520	Economy	19100.00
0005433685523	19520	Economy	19100.00
0005433687706	19520	Economy	19100.00
0005433686643	19520	Economy	19100.00
0005433687712	19520	Economy	19100.00
0005433686638	19520	Economy	19100.00
0005433685522	19520	Economy	19100.00
0005433687711	19520	Economy	19100.00
0005433687714	19520	Economy	19100.00
0005433686631	19520	Economy	19100.00
0005433686632	19520	Economy	19100.00
0005433686641	19520	Economy	19100.00
0005433687704	19520	Economy	19100.00
0005433685524	19520	Economy	19100.00
0005433686645	19520	Economy	19100.00
0005433686637	19520	Economy	19100.00
0005433685533	19520	Economy	19100.00
0005433685525	19520	Economy	19100.00
0005433685534	19520	Economy	19100.00
0005433685532	19520	Economy	19100.00
0005433685535	19520	Economy	19100.00
0005433685528	19520	Economy	19100.00
0005433685530	19520	Economy	19100.00
0005433686642	19520	Economy	19100.00
0005433687707	19520	Economy	19100.00
0005432857998	3143	Economy	11100.00
0005432584129	3143	Economy	11100.00
0005432584144	3143	Economy	11100.00
0005432584130	3143	Economy	11100.00
0005432858031	3143	Economy	10100.00
0005432858037	3143	Economy	10100.00
0005432584149	3143	Economy	10100.00
0005432858002	3143	Economy	10100.00
0005432584150	3143	Economy	10100.00
0005432584127	3143	Economy	10100.00
0005432584148	3143	Economy	10100.00
0005432584135	3143	Economy	10100.00
0005432584136	3143	Economy	10100.00
0005432584146	3143	Economy	10100.00
0005432858000	3143	Economy	10100.00
0005432584147	3143	Economy	10100.00
0005432584133	3143	Economy	10100.00
0005432584125	3143	Economy	10100.00
0005432858034	3143	Economy	10100.00
0005432584145	3143	Economy	10100.00
0005432584132	3143	Economy	10100.00
0005432584140	3143	Economy	10100.00
0005432584134	3143	Economy	10100.00
0005432584141	3143	Economy	10100.00
0005432584128	3143	Economy	10100.00
0005432216282	3143	Economy	10100.00
0005432858019	3143	Economy	10100.00
0005432584137	3143	Economy	10100.00
0005432857983	3143	Economy	10100.00
0005432858030	3143	Economy	10100.00
0005432858001	3143	Economy	10100.00
0005432584142	3143	Economy	10100.00
0005432216284	3143	Economy	10100.00
0005432857971	3143	Economy	10100.00
0005432857970	3143	Economy	10100.00
0005432584131	3143	Economy	10100.00
0005432858025	3143	Economy	10100.00
0005432584143	3143	Economy	10100.00
0005432858032	3143	Economy	10100.00
0005432216283	3143	Economy	10100.00
0005432858046	3143	Economy	10100.00
0005432858036	3143	Economy	10100.00
0005432584124	3143	Economy	10100.00
0005432858017	3143	Economy	10100.00
0005432584138	3143	Economy	10100.00
0005432584126	3143	Economy	10100.00
0005432584139	3143	Economy	10100.00
0005432584031	31477	Economy	11100.00
0005432583983	31477	Economy	11100.00
0005432584010	31477	Economy	11100.00
0005432583963	31477	Economy	10100.00
0005432858110	31477	Economy	10100.00
0005432583951	31477	Economy	10100.00
0005432858113	31477	Economy	10100.00
0005432583934	31477	Economy	10100.00
0005432583892	31477	Economy	10100.00
0005432584091	31477	Economy	10100.00
0005432584008	31477	Economy	10100.00
0005432583982	31477	Economy	10100.00
0005432858118	31477	Economy	10100.00
0005432583891	31477	Economy	10100.00
0005432858115	31477	Economy	10100.00
0005432583929	31477	Economy	10100.00
0005432583938	31477	Economy	10100.00
0005432858111	31477	Economy	10100.00
0005432583981	31477	Economy	10100.00
0005432583988	31477	Economy	10100.00
0005432858112	31477	Economy	10100.00
0005432583920	31477	Economy	10100.00
0005432583921	31477	Economy	10100.00
0005432583984	31477	Economy	10100.00
0005432583933	31477	Economy	10100.00
0005432858121	31477	Economy	10100.00
0005432583884	31477	Economy	10100.00
0005432583903	31477	Economy	10100.00
0005432583899	31477	Economy	10100.00
0005432584024	31477	Economy	10100.00
0005432583944	31477	Economy	10100.00
0005432583974	31477	Economy	10100.00
0005432858114	31477	Economy	10100.00
0005432584009	31477	Economy	10100.00
0005432858122	31477	Economy	10100.00
0005432584092	31477	Economy	10100.00
0005432858120	31477	Economy	10100.00
0005432858117	31477	Economy	10100.00
0005432858116	31477	Economy	10100.00
0005432858119	31477	Economy	10100.00
0005434943390	904	Economy	8300.00
0005434943387	904	Economy	8300.00
0005434943389	904	Economy	7500.00
0005433255075	904	Economy	7500.00
0005434943386	904	Economy	7500.00
0005433255110	904	Economy	7500.00
0005434943385	904	Economy	7500.00
0005434943388	904	Economy	7500.00
0005434943391	904	Economy	7500.00
0005434943392	904	Economy	7500.00
0005434943384	904	Economy	7500.00
0005434943352	16219	Economy	8300.00
0005433255145	16219	Economy	7500.00
0005434943306	16219	Economy	7500.00
0005434943348	16219	Economy	7500.00
0005434943329	16219	Economy	7500.00
0005434943341	16219	Economy	7500.00
0005434943305	16219	Economy	7500.00
0005434943327	16219	Economy	7500.00
0005434943308	16219	Economy	7500.00
0005434943326	16219	Economy	7500.00
0005433255144	16219	Economy	7500.00
0005434943325	16219	Economy	7500.00
0005433255143	16219	Economy	7500.00
0005433255142	16219	Economy	7500.00
0005434943328	16219	Economy	7500.00
0005434943337	16219	Economy	7500.00
0005434943297	16219	Economy	7500.00
0005434943351	16219	Economy	7500.00
0005433255140	16219	Economy	7500.00
0005433255141	16219	Economy	7500.00
0005433255138	16219	Economy	7500.00
0005434943307	16219	Economy	7500.00
0005433255139	16219	Economy	7500.00
0005434943330	16219	Economy	7500.00
0005433654801	4319	Business	90500.00
0005433654799	4319	Business	90500.00
0005435858548	4319	Business	90500.00
0005433654811	4319	Business	90500.00
0005435858516	4319	Business	90500.00
0005433654803	4319	Business	90500.00
0005433654792	4319	Business	90500.00
0005435858538	4319	Economy	30200.00
0005435858539	4319	Economy	30200.00
0005435858525	4319	Economy	30200.00
0005433654806	4319	Economy	30200.00
0005433654791	4319	Economy	30200.00
0005433654809	4319	Economy	30200.00
0005435858544	4319	Economy	30200.00
0005435858529	4319	Economy	30200.00
0005435858549	4319	Economy	30200.00
0005433654790	4319	Economy	30200.00
0005433654804	4319	Economy	30200.00
0005433654795	4319	Economy	30200.00
0005433654813	4319	Economy	30200.00
0005433654805	4319	Economy	30200.00
0005433654796	4319	Economy	30200.00
0005435858528	4319	Economy	30200.00
0005433654807	4319	Economy	30200.00
0005433654798	4319	Economy	30200.00
0005435858531	4319	Economy	30200.00
0005433654808	4319	Economy	30200.00
0005433654793	4319	Economy	30200.00
0005433654797	4319	Economy	30200.00
0005433654800	4319	Economy	30200.00
0005433654810	4319	Economy	30200.00
0005433654794	4319	Economy	30200.00
0005435858497	4319	Economy	30200.00
0005433654812	4319	Economy	30200.00
0005435858498	4319	Economy	30200.00
0005435858530	4319	Economy	30200.00
0005435858543	4319	Economy	30200.00
0005435858527	4319	Economy	30200.00
0005433654802	4319	Economy	30200.00
0005433811632	14340	Economy	4400.00
0005433811644	27893	Economy	4400.00
0005433811635	27893	Economy	4400.00
0005433811636	27893	Economy	4400.00
0005433811642	27893	Economy	4400.00
0005433811634	27893	Economy	4400.00
0005433811640	27893	Economy	4400.00
0005433811637	27893	Economy	4400.00
0005433811638	27893	Economy	4400.00
0005433811639	27893	Economy	4400.00
0005433811633	27893	Economy	4400.00
0005433811641	27893	Economy	4400.00
0005433811643	27893	Economy	4400.00
0005433367747	21750	Business	9800.00
0005435653235	21750	Business	9800.00
0005433367870	21750	Business	9800.00
0005433367634	21750	Business	9800.00
0005435653208	21750	Business	9800.00
0005435653200	21750	Business	9800.00
0005435653234	21750	Business	9800.00
0005433367805	21750	Business	9800.00
0005435653192	21750	Business	9800.00
0005435653217	21750	Business	9800.00
0005435653216	21750	Economy	3300.00
0005435653232	21750	Economy	3300.00
0005435653215	21750	Economy	3300.00
0005433367635	21750	Economy	3300.00
0005433367599	21750	Economy	3300.00
0005435653225	21750	Economy	3300.00
0005435653209	21750	Economy	3300.00
0005435653222	21750	Economy	3300.00
0005433367709	21750	Economy	3300.00
0005435653207	21750	Economy	3600.00
0005435653221	21750	Economy	3600.00
0005435653193	21750	Economy	3600.00
0005435653206	21750	Economy	3600.00
0005435653212	21750	Economy	3600.00
0005435653201	21750	Economy	3300.00
0005433367678	21750	Economy	3300.00
0005435653198	21750	Economy	3300.00
0005435653197	21750	Economy	3300.00
0005435653224	21750	Economy	3300.00
0005433367804	21750	Economy	3300.00
0005435653219	21750	Economy	3300.00
0005433367555	21750	Economy	3300.00
0005435653195	21750	Economy	3300.00
0005435653229	21750	Economy	3300.00
0005433367554	21750	Economy	3300.00
0005435653202	21750	Economy	3300.00
0005435653236	21750	Economy	3300.00
0005435653220	21750	Economy	3300.00
0005433367467	21750	Economy	3300.00
0005433367713	21750	Economy	3300.00
0005435653213	21750	Economy	3300.00
0005433367661	21750	Economy	3300.00
0005433367601	21750	Economy	3300.00
0005435653210	21750	Economy	3300.00
0005435653228	21750	Economy	3300.00
0005435653205	21750	Economy	3300.00
0005435653199	21750	Economy	3300.00
0005435653214	21750	Economy	3300.00
0005433367676	21750	Economy	3300.00
0005435653211	21750	Economy	3300.00
0005435653226	21750	Economy	3300.00
0005433367701	21750	Economy	3300.00
0005433367651	21750	Economy	3300.00
0005435653203	21750	Economy	3300.00
0005433367660	21750	Economy	3300.00
0005433367528	21750	Economy	3300.00
0005433367600	21750	Economy	3300.00
0005433367658	21750	Economy	3300.00
0005433367677	21750	Economy	3300.00
0005433367730	21750	Economy	3300.00
0005433367761	21750	Economy	3300.00
0005433367779	21750	Economy	3300.00
0005433367675	21750	Economy	3300.00
0005435653194	21750	Economy	3300.00
0005433367650	21750	Economy	3300.00
0005433367646	21750	Economy	3300.00
0005435653231	21750	Economy	3300.00
0005433367702	21750	Economy	3300.00
0005435653233	21750	Economy	3300.00
0005435653196	21750	Economy	3300.00
0005433367746	21750	Economy	3300.00
0005433367686	21750	Economy	3300.00
0005435653218	21750	Economy	3300.00
0005435653204	21750	Economy	3300.00
0005435653227	21750	Economy	3300.00
0005435653230	21750	Economy	3300.00
0005433367728	21750	Economy	3300.00
0005435653223	21750	Economy	3300.00
0005432666396	9338	Business	186200.00
0005434171012	9338	Business	186200.00
0005433805535	9338	Business	186200.00
0005435269721	9338	Business	186200.00
0005433785088	9338	Business	186200.00
0005435269714	9338	Business	186200.00
0005433785103	9338	Business	186200.00
0005433805514	9338	Business	186200.00
0005434171047	9338	Business	186200.00
0005435269696	9338	Business	186200.00
0005433785106	9338	Business	186200.00
0005433763268	9338	Business	186200.00
0005433785080	9338	Business	186200.00
0005434270198	9338	Business	186200.00
0005432657462	9338	Business	186200.00
0005433805517	9338	Economy	68300.00
0005433805534	9338	Business	186200.00
0005432665282	9338	Economy	68300.00
0005433805512	9338	Economy	68300.00
0005434270190	9338	Economy	62100.00
0005433763264	9338	Economy	62100.00
0005433785079	9338	Economy	62100.00
0005433763269	9338	Economy	62100.00
0005433763270	9338	Economy	62100.00
0005433785104	9338	Economy	62100.00
0005435269732	9338	Economy	62100.00
0005435269716	9338	Economy	62100.00
0005434270205	9338	Economy	62100.00
0005433763258	9338	Economy	62100.00
0005433763271	9338	Economy	62100.00
0005433805530	9338	Economy	62100.00
0005432657461	9338	Economy	62100.00
0005433785090	9338	Economy	62100.00
0005434171040	9338	Economy	62100.00
0005433805506	9338	Economy	62100.00
0005435269720	9338	Economy	62100.00
0005434171053	9338	Economy	62100.00
0005433805529	9338	Economy	62100.00
0005435269745	9338	Economy	62100.00
0005432667462	9338	Economy	62100.00
0005434170995	9338	Economy	62100.00
0005435269682	9338	Economy	62100.00
0005435269717	9338	Economy	62100.00
0005433805516	9338	Economy	62100.00
0005433805528	9338	Economy	62100.00
0005433805520	9338	Economy	62100.00
0005432666398	9338	Economy	62100.00
0005435269741	9338	Economy	62100.00
0005434151692	9338	Economy	62100.00
0005433805533	9338	Economy	62100.00
0005435269697	9338	Economy	62100.00
0005434171046	9338	Economy	62100.00
0005432665283	9338	Economy	62100.00
0005433785091	9338	Economy	62100.00
0005434171061	9338	Economy	62100.00
0005434171059	9338	Economy	62100.00
0005433785096	9338	Economy	62100.00
0005433763262	9338	Economy	62100.00
0005434171060	9338	Economy	62100.00
0005435269715	9338	Economy	62100.00
0005435269744	9338	Economy	62100.00
0005433805524	9338	Economy	62100.00
0005434273065	9338	Economy	62100.00
0005435269677	9338	Economy	62100.00
0005435269742	9338	Economy	62100.00
0005433805508	9338	Economy	62100.00
0005435269704	9338	Economy	62100.00
0005434270196	9338	Economy	62100.00
0005433805532	9338	Economy	62100.00
0005433785092	9338	Economy	62100.00
0005433763265	9338	Economy	62100.00
0005433785076	9338	Economy	62100.00
0005433785089	9338	Economy	62100.00
0005433763259	9338	Economy	62100.00
0005433785078	9338	Economy	62100.00
0005433805515	9338	Economy	62100.00
0005433785094	9338	Economy	62100.00
0005433785095	9338	Economy	62100.00
0005435269726	9338	Economy	62100.00
0005433805527	9338	Economy	62100.00
0005435269702	9338	Economy	68300.00
0005432657460	9338	Economy	62100.00
0005432666397	9338	Economy	68300.00
0005433785085	9338	Economy	62100.00
0005433805518	9338	Economy	62100.00
0005433763263	9338	Economy	62100.00
0005433785084	9338	Economy	62100.00
0005433785100	9338	Economy	62100.00
0005433763267	9338	Economy	62100.00
0005433785087	9338	Economy	62100.00
0005434270197	9338	Economy	62100.00
0005433785086	9338	Economy	62100.00
0005433785081	9338	Economy	62100.00
0005435269731	9338	Economy	62100.00
0005433805521	9338	Economy	62100.00
0005433805523	9338	Economy	62100.00
0005433785097	9338	Economy	62100.00
0005433785098	9338	Economy	62100.00
0005433805507	9338	Economy	62100.00
0005433785107	9338	Economy	62100.00
0005434171062	9338	Economy	62100.00
0005433805531	9338	Economy	62100.00
0005435269681	9338	Economy	62100.00
0005435269727	9338	Economy	62100.00
0005433785108	9338	Economy	62100.00
0005434270199	9338	Economy	62100.00
0005433785082	9338	Economy	62100.00
0005433785102	9338	Economy	62100.00
0005433763266	9338	Economy	62100.00
0005433763257	9338	Economy	62100.00
0005435269705	9338	Economy	62100.00
0005434273066	9338	Economy	62100.00
0005432667463	9338	Economy	62100.00
0005433805510	9338	Economy	62100.00
0005433805525	9338	Economy	62100.00
0005435269683	9338	Economy	62100.00
0005433785083	9338	Economy	62100.00
0005433805526	9338	Economy	62100.00
0005433805522	9338	Economy	62100.00
0005433805509	9338	Economy	62100.00
0005433785077	9338	Economy	62100.00
0005433763261	9338	Economy	62100.00
0005433785093	9338	Economy	62100.00
0005433763260	9338	Economy	62100.00
0005434270204	9338	Economy	62100.00
0005434171041	9338	Economy	62100.00
0005434170985	9338	Economy	62100.00
0005433785109	9338	Economy	62100.00
0005433785099	9338	Economy	62100.00
0005434171054	9338	Economy	62100.00
0005433805511	9338	Economy	62100.00
0005433805519	9338	Economy	62100.00
0005434151689	9338	Economy	62100.00
0005433805513	9338	Economy	62100.00
0005434151690	9338	Economy	62100.00
0005433785105	9338	Economy	62100.00
0005435269680	9338	Economy	62100.00
0005433785101	9338	Economy	62100.00
0005434171120	26261	Business	186200.00
0005433784744	26261	Business	186200.00
0005433805249	26261	Business	186200.00
0005434271319	26261	Business	186200.00
0005433784696	26261	Business	186200.00
0005434171109	26261	Business	186200.00
0005435269770	26261	Business	186200.00
0005433805286	26261	Business	186200.00
0005433805311	26261	Business	186200.00
0005433784835	26261	Business	186200.00
0005434270212	26261	Business	186200.00
0005433805216	26261	Business	186200.00
0005433805326	26261	Business	186200.00
0005434171117	26261	Business	186200.00
0005434151715	26261	Business	186200.00
0005433805289	26261	Business	186200.00
0005433763174	26261	Business	186200.00
0005432666382	26261	Business	186200.00
0005433805288	26261	Business	186200.00
0005433763085	26261	Business	186200.00
0005433784761	26261	Business	186200.00
0005434171108	26261	Economy	68300.00
0005433784653	26261	Economy	68300.00
0005434270213	26261	Economy	68300.00
0005433784836	26261	Economy	68300.00
0005433784672	26261	Economy	62100.00
0005434151714	26261	Economy	62100.00
0005433805188	26261	Economy	62100.00
0005433784907	26261	Economy	62100.00
0005433805263	26261	Economy	62100.00
0005434271318	26261	Economy	62100.00
0005433763063	26261	Economy	62100.00
0005433805159	26261	Economy	62100.00
0005433763119	26261	Economy	62100.00
0005433805316	26261	Economy	62100.00
0005434270214	26261	Economy	62100.00
0005432666367	26261	Economy	62100.00
0005433805234	26261	Economy	62100.00
0005433763097	26261	Economy	62100.00
0005433784775	26261	Economy	62100.00
0005433805241	26261	Economy	62100.00
0005433763134	26261	Economy	62100.00
0005433784832	26261	Economy	62100.00
0005432663015	26261	Economy	62100.00
0005433784758	26261	Economy	62100.00
0005433805314	26261	Economy	62100.00
0005433784762	26261	Economy	62100.00
0005432666368	26261	Economy	62100.00
0005433784787	26261	Economy	62100.00
0005433805280	26261	Economy	62100.00
0005435269767	26261	Economy	62100.00
0005434171107	26261	Economy	62100.00
0005433784675	26261	Economy	62100.00
0005433763136	26261	Economy	62100.00
0005433763175	26261	Economy	62100.00
0005433784688	26261	Economy	62100.00
0005434151716	26261	Economy	62100.00
0005433784803	26261	Economy	62100.00
0005433805140	26261	Economy	62100.00
0005433784776	26261	Economy	62100.00
0005433805124	26261	Economy	62100.00
0005433805203	26261	Economy	62100.00
0005433763145	26261	Economy	62100.00
0005433784786	26261	Economy	62100.00
0005433805377	26261	Economy	62100.00
0005433805037	26261	Economy	62100.00
0005432666369	26261	Economy	62100.00
0005433784770	26261	Economy	62100.00
0005433805150	26261	Economy	62100.00
0005433763144	26261	Economy	62100.00
0005433805054	26261	Economy	62100.00
0005433763143	26261	Economy	62100.00
0005433805105	26261	Economy	62100.00
0005432657429	26261	Economy	62100.00
0005433784695	26261	Economy	62100.00
0005432657444	26261	Economy	62100.00
0005433805376	26261	Economy	62100.00
0005434171115	26261	Economy	62100.00
0005434269109	26261	Economy	62100.00
0005434171121	26261	Economy	62100.00
0005434171110	26261	Economy	62100.00
0005433763096	26261	Economy	62100.00
0005433784906	26261	Economy	68300.00
0005433763086	26261	Economy	62100.00
0005433763176	26261	Economy	68300.00
0005433784851	26261	Economy	62100.00
0005433805337	26261	Economy	62100.00
0005434269110	26261	Economy	62100.00
0005433805330	26261	Economy	62100.00
0005433805202	26261	Economy	62100.00
0005433784676	26261	Economy	62100.00
0005433805168	26261	Economy	62100.00
0005433805149	26261	Economy	62100.00
0005433763177	26261	Economy	62100.00
0005433784785	26261	Economy	62100.00
0005433763118	26261	Economy	62100.00
0005433763189	26261	Economy	62100.00
0005433805230	26261	Economy	62100.00
0005433805125	26261	Economy	62100.00
0005435269771	26261	Economy	62100.00
0005433805246	26261	Economy	62100.00
0005434171111	26261	Economy	62100.00
0005433805158	26261	Economy	62100.00
0005433805267	26261	Economy	62100.00
0005435269769	26261	Economy	62100.00
0005434171112	26261	Economy	62100.00
0005433784685	26261	Economy	62100.00
0005433784702	26261	Economy	62100.00
0005433805187	26261	Economy	62100.00
0005434171113	26261	Economy	62100.00
0005433805240	26261	Economy	62100.00
0005433763138	26261	Economy	62100.00
0005434171106	26261	Economy	62100.00
0005433805287	26261	Economy	62100.00
0005435269772	26261	Economy	62100.00
0005433784686	26261	Economy	62100.00
0005434171119	26261	Economy	62100.00
0005434171114	26261	Economy	62100.00
0005433784780	26261	Economy	62100.00
0005432657443	26261	Economy	62100.00
0005433805151	26261	Economy	62100.00
0005435269773	26261	Economy	62100.00
0005433784667	26261	Economy	62100.00
0005433805181	26261	Economy	62100.00
0005434171116	26261	Economy	62100.00
0005433805201	26261	Economy	62100.00
0005433805153	26261	Economy	62100.00
0005433805258	26261	Economy	62100.00
0005433784759	26261	Economy	62100.00
0005434171118	26261	Economy	62100.00
0005435269768	26261	Economy	62100.00
0005434171105	26261	Economy	62100.00
0005433784769	26261	Economy	62100.00
0005433784834	26261	Economy	62100.00
0005433805169	26261	Economy	62100.00
0005433763215	26261	Economy	62100.00
0005433805247	26261	Economy	62100.00
0005435135691	4888	Economy	5300.00
0005435929629	4888	Economy	5300.00
0005435929640	4888	Economy	5300.00
0005435135688	4888	Economy	5300.00
0005435929618	4888	Economy	5300.00
0005435135690	4888	Economy	5300.00
0005435929637	4888	Economy	5300.00
0005435929636	4888	Economy	5300.00
0005435929630	4888	Economy	5300.00
0005435929628	4888	Economy	5300.00
0005435135689	4888	Economy	5300.00
0005435135631	33001	Economy	5300.00
0005435929655	33001	Economy	5300.00
0005435135657	33001	Economy	5300.00
0005435135640	33001	Economy	5300.00
0005435135632	33001	Economy	5300.00
0005435929653	33001	Economy	5300.00
0005435929654	33001	Economy	5300.00
0005434983306	9471	Economy	19700.00
0005434983307	9471	Economy	17900.00
0005434983305	9471	Economy	17900.00
0005434983309	9471	Economy	17900.00
0005434217937	9471	Economy	17900.00
0005434217936	9471	Economy	17900.00
0005434983310	9471	Economy	17900.00
0005434983308	9471	Economy	17900.00
0005434217960	9471	Economy	17900.00
0005434217961	9471	Economy	17900.00
0005434217966	9471	Economy	17900.00
0005434217959	9471	Economy	17900.00
0005434217987	27364	Economy	17900.00
0005434983282	27364	Economy	17900.00
0005434983275	27364	Economy	17900.00
0005434217985	27364	Economy	17900.00
0005434217983	27364	Economy	17900.00
0005434217984	27364	Economy	17900.00
0005434983283	27364	Economy	17900.00
0005434983273	27364	Economy	17900.00
0005434983274	27364	Economy	17900.00
0005434217986	27364	Economy	17900.00
0005433960568	24241	Business	36400.00
0005433985720	24241	Business	36400.00
0005433985771	24241	Business	36400.00
0005433985580	24241	Business	36400.00
0005433985699	24241	Business	36400.00
0005433960557	24241	Business	36400.00
0005433960534	24241	Business	36400.00
0005433960541	24241	Business	36400.00
0005433960565	24241	Business	36400.00
0005433960558	24241	Business	36400.00
0005433985740	24241	Business	36400.00
0005433960464	24241	Economy	13400.00
0005433960489	24241	Economy	13400.00
0005433985697	24241	Economy	12100.00
0005433960476	24241	Economy	12100.00
0005433960332	24241	Economy	12100.00
0005433985630	24241	Economy	12100.00
0005433985549	24241	Economy	12100.00
0005433960509	24241	Economy	12100.00
0005433960535	24241	Economy	12100.00
0005433960281	24241	Economy	12100.00
0005433960542	24241	Economy	12100.00
0005433985728	24241	Economy	12100.00
0005433960583	24241	Economy	12100.00
0005433960443	24241	Economy	12100.00
0005433960490	24241	Economy	12100.00
0005433985647	24241	Economy	12100.00
0005433985746	24241	Economy	12100.00
0005433985631	24241	Economy	12100.00
0005433960571	24241	Economy	12100.00
0005433960468	24241	Economy	12100.00
0005433985623	24241	Economy	12100.00
0005433960605	24241	Economy	12100.00
0005433960386	24241	Economy	12100.00
0005433985551	24241	Economy	12100.00
0005433985812	24241	Economy	12100.00
0005433985705	24241	Economy	12100.00
0005433960388	24241	Economy	12100.00
0005433960331	24241	Economy	12100.00
0005433960477	24241	Economy	12100.00
0005433960582	24241	Economy	12100.00
0005433960559	24241	Economy	12100.00
0005433985790	24241	Economy	12100.00
0005433985657	24241	Economy	12100.00
0005433985690	24241	Economy	12100.00
0005433960580	24241	Economy	12100.00
0005433985620	24241	Economy	12100.00
0005433960625	24241	Economy	12100.00
0005433985741	24241	Economy	12100.00
0005433960448	24241	Economy	12100.00
0005433985710	24241	Economy	12100.00
0005433960404	24241	Economy	12100.00
0005433960507	24241	Economy	12100.00
0005433985649	24241	Economy	12100.00
0005433960330	24241	Economy	12100.00
0005433960508	24241	Economy	12100.00
0005433985721	24241	Economy	12100.00
0005433985711	24241	Economy	12100.00
0005433985642	24241	Economy	12100.00
0005433960401	24241	Economy	12100.00
0005433960470	24241	Economy	13400.00
0005433985656	24241	Economy	13400.00
0005433960359	24241	Economy	12100.00
0005433960609	24241	Economy	12100.00
0005433960579	24241	Economy	12100.00
0005433985645	24241	Economy	12100.00
0005433960393	24241	Economy	12100.00
0005433960289	24241	Economy	12100.00
0005433960395	24241	Economy	12100.00
0005433960479	24241	Economy	12100.00
0005433985644	24241	Economy	12100.00
0005433985787	24241	Economy	12100.00
0005433960392	24241	Economy	12100.00
0005433960494	24241	Economy	12100.00
0005433985636	24241	Economy	12100.00
0005433960482	24241	Economy	12100.00
0005433985789	24241	Economy	12100.00
0005433985619	24241	Economy	12100.00
0005433985727	24241	Economy	12100.00
0005433960449	24241	Economy	12100.00
0005433960555	24241	Economy	12100.00
0005433960467	24241	Economy	12100.00
0005433960465	24241	Economy	12100.00
0005433960411	24241	Economy	12100.00
0005433960478	24241	Economy	12100.00
0005433985646	24241	Economy	12100.00
0005433960592	24241	Economy	12100.00
0005433985726	24241	Economy	12100.00
0005433960556	24241	Economy	12100.00
0005433985698	24241	Economy	12100.00
0005433960394	24241	Economy	12100.00
0005433985665	24241	Economy	12100.00
0005433960375	24241	Economy	12100.00
0005433985658	24241	Economy	12100.00
0005433985786	24241	Economy	12100.00
0005433985666	24241	Economy	12100.00
0005433985650	24241	Economy	12100.00
0005433985550	24241	Economy	12100.00
0005433985801	24241	Economy	12100.00
0005433960472	24241	Economy	12100.00
0005433960358	24241	Economy	12100.00
0005433960469	24241	Economy	12100.00
0005433985584	24241	Economy	12100.00
0005433960493	24241	Economy	12100.00
0005433985751	24241	Economy	12100.00
0005433986100	25920	Business	36400.00
0005433961049	25920	Business	36400.00
0005433961082	25920	Business	36400.00
0005433986082	25920	Business	36400.00
0005433961058	25920	Business	36400.00
0005433961040	25920	Business	36400.00
0005433961085	25920	Business	36400.00
0005433986085	25920	Business	36400.00
0005433986111	25920	Business	36400.00
0005433986129	25920	Business	36400.00
0005433986091	25920	Business	36400.00
0005433986090	25920	Business	36400.00
0005433986127	25920	Business	36400.00
0005433961050	25920	Business	36400.00
0005433986116	25920	Business	36400.00
0005433986113	25920	Business	36400.00
0005433961079	25920	Business	36400.00
0005433961062	25920	Business	36400.00
0005433961075	25920	Economy	13400.00
0005433961091	25920	Economy	12100.00
0005433986102	25920	Economy	12100.00
0005433961066	25920	Economy	12100.00
0005433961056	25920	Economy	12100.00
0005433986114	25920	Economy	12100.00
0005433986081	25920	Economy	12100.00
0005433961087	25920	Economy	12100.00
0005433986110	25920	Economy	12100.00
0005433961093	25920	Economy	12100.00
0005433961106	25920	Economy	12100.00
0005433961089	25920	Economy	12100.00
0005433961067	25920	Economy	12100.00
0005433986126	25920	Economy	12100.00
0005433961078	25920	Economy	12100.00
0005433961053	25920	Economy	12100.00
0005433961109	25920	Economy	12100.00
0005433986118	25920	Economy	12100.00
0005433961095	25920	Economy	12100.00
0005433986095	25920	Economy	12100.00
0005433986096	25920	Economy	12100.00
0005433961045	25920	Economy	12100.00
0005433961043	25920	Economy	12100.00
0005433986117	25920	Economy	12100.00
0005433961044	25920	Economy	12100.00
0005433986078	25920	Economy	12100.00
0005433986099	25920	Economy	12100.00
0005433986088	25920	Economy	12100.00
0005433986077	25920	Economy	12100.00
0005433961107	25920	Economy	12100.00
0005433986089	25920	Economy	12100.00
0005433961068	25920	Economy	12100.00
0005433986121	25920	Economy	12100.00
0005433961103	25920	Economy	12100.00
0005433986104	25920	Economy	12100.00
0005433961097	25920	Economy	12100.00
0005433961090	25920	Economy	12100.00
0005433961092	25920	Economy	12100.00
0005433961035	25920	Economy	12100.00
0005433986122	25920	Economy	12100.00
0005433986124	25920	Economy	12100.00
0005433961101	25920	Economy	12100.00
0005433961069	25920	Economy	12100.00
0005433986120	25920	Economy	12100.00
0005433961104	25920	Economy	12100.00
0005433986076	25920	Economy	12100.00
0005433986097	25920	Economy	12100.00
0005433961063	25920	Economy	12100.00
0005433961102	25920	Economy	12100.00
0005433961038	25920	Economy	12100.00
0005433986128	25920	Economy	12100.00
0005433961055	25920	Economy	12100.00
0005433961047	25920	Economy	12100.00
0005433961080	25920	Economy	12100.00
0005433961037	25920	Economy	12100.00
0005433961064	25920	Economy	12100.00
0005433986101	25920	Economy	12100.00
0005433961060	25920	Economy	12100.00
0005433961088	25920	Economy	12100.00
0005433986112	25920	Economy	12100.00
0005433961084	25920	Economy	12100.00
0005433986092	25920	Economy	12100.00
0005433961074	25920	Economy	12100.00
0005433986103	25920	Economy	13400.00
0005433961054	25920	Economy	12100.00
0005433961073	25920	Economy	12100.00
0005433961039	25920	Economy	12100.00
0005433961072	25920	Economy	13400.00
0005433961094	25920	Economy	12100.00
0005433961046	25920	Economy	12100.00
0005433961098	25920	Economy	12100.00
0005433961071	25920	Economy	12100.00
0005433986105	25920	Economy	12100.00
0005433986086	25920	Economy	12100.00
0005433986123	25920	Economy	12100.00
0005433986125	25920	Economy	12100.00
0005433961086	25920	Economy	12100.00
0005433961061	25920	Economy	12100.00
0005433961036	25920	Economy	12100.00
0005433961081	25920	Economy	12100.00
0005433986083	25920	Economy	12100.00
0005433986087	25920	Economy	12100.00
0005433986093	25920	Economy	12100.00
0005433986108	25920	Economy	12100.00
0005433961100	25920	Economy	12100.00
0005433961076	25920	Economy	12100.00
0005433961070	25920	Economy	12100.00
0005433986115	25920	Economy	12100.00
0005433986098	25920	Economy	12100.00
0005433961108	25920	Economy	12100.00
0005433961041	25920	Economy	12100.00
0005433986084	25920	Economy	12100.00
0005433961096	25920	Economy	12100.00
0005433961051	25920	Economy	12100.00
0005433986119	25920	Economy	12100.00
0005433961105	25920	Economy	12100.00
0005433961077	25920	Economy	12100.00
0005433986080	25920	Economy	12100.00
0005433986079	25920	Economy	12100.00
0005433961065	25920	Economy	12100.00
0005433961042	25920	Economy	12100.00
0005433961057	25920	Economy	12100.00
0005433961059	25920	Economy	12100.00
0005433986106	25920	Economy	12100.00
0005433961034	25920	Economy	12100.00
0005433961083	25920	Economy	12100.00
0005433986094	25920	Economy	12100.00
0005433961099	25920	Economy	12100.00
0005433961048	25920	Economy	12100.00
0005433986109	25920	Economy	12100.00
0005433986107	25920	Economy	12100.00
0005433961052	25920	Economy	12100.00
0005433165867	955	Economy	25400.00
0005434480435	955	Economy	25400.00
0005434480432	955	Economy	25400.00
0005434480428	955	Economy	25400.00
0005434480420	955	Economy	23100.00
0005434480439	955	Economy	23100.00
0005434480442	955	Economy	23100.00
0005434480437	955	Economy	23100.00
0005434480438	955	Economy	23100.00
0005434480444	955	Economy	23100.00
0005434480427	955	Economy	23100.00
0005434480430	955	Economy	23100.00
0005434480436	955	Economy	23100.00
0005434480443	955	Economy	23100.00
0005433165865	955	Economy	23100.00
0005434480440	955	Economy	23100.00
0005433165826	955	Economy	23100.00
0005434480421	955	Economy	23100.00
0005433165810	955	Economy	23100.00
0005434480431	955	Economy	23100.00
0005434480422	955	Economy	23100.00
0005434480445	955	Economy	23100.00
0005433165832	955	Economy	23100.00
0005434480426	955	Economy	23100.00
0005434480419	955	Economy	23100.00
0005434480434	955	Economy	23100.00
0005434480433	955	Economy	23100.00
0005434480424	955	Economy	23100.00
0005433165923	955	Economy	23100.00
0005432269507	955	Economy	23100.00
0005433165922	955	Economy	23100.00
0005434480441	955	Economy	23100.00
0005434480423	955	Economy	23100.00
0005432269506	955	Economy	23100.00
0005433165803	955	Economy	23100.00
0005433165872	955	Economy	23100.00
0005433165866	955	Economy	23100.00
0005433165850	955	Economy	23100.00
0005434480429	955	Economy	23100.00
0005434480425	955	Economy	23100.00
0005433165825	955	Economy	23100.00
0005434480210	16570	Economy	25400.00
0005434480314	16570	Economy	25400.00
0005433165956	16570	Economy	25400.00
0005434480141	16570	Economy	25400.00
0005433165953	16570	Economy	23100.00
0005434480221	16570	Economy	23100.00
0005434480248	16570	Economy	23100.00
0005433165952	16570	Economy	23100.00
0005434480160	16570	Economy	23100.00
0005433165950	16570	Economy	23100.00
0005434480211	16570	Economy	23100.00
0005433165960	16570	Economy	23100.00
0005434480257	16570	Economy	23100.00
0005433165955	16570	Economy	23100.00
0005434480301	16570	Economy	23100.00
0005434480253	16570	Economy	23100.00
0005434480142	16570	Economy	23100.00
0005433165959	16570	Economy	23100.00
0005434480250	16570	Economy	23100.00
0005434480247	16570	Economy	23100.00
0005434480249	16570	Economy	23100.00
0005434480234	16570	Economy	23100.00
0005434480315	16570	Economy	23100.00
0005434480219	16570	Economy	23100.00
0005434480161	16570	Economy	23100.00
0005434480236	16570	Economy	23100.00
0005434480084	16570	Economy	23100.00
0005434480124	16570	Economy	23100.00
0005434480300	16570	Economy	23100.00
0005434480125	16570	Economy	23100.00
0005434480259	16570	Economy	23100.00
0005433165958	16570	Economy	23100.00
0005434480258	16570	Economy	23100.00
0005433165954	16570	Economy	23100.00
0005434480262	16570	Economy	23100.00
0005433165962	16570	Economy	23100.00
0005434480059	16570	Economy	23100.00
0005433165951	16570	Economy	23100.00
0005434480154	16570	Economy	23100.00
0005433165957	16570	Economy	23100.00
0005433165961	16570	Economy	23100.00
0005434480207	16570	Economy	23100.00
0005434480126	16570	Economy	23100.00
0005434480153	16570	Economy	23100.00
0005434480235	16570	Economy	23100.00
0005433872492	3216	Economy	19000.00
0005433872501	3216	Economy	19000.00
0005433872494	3216	Economy	17200.00
0005433872495	3216	Economy	17200.00
0005433872496	3216	Economy	17200.00
0005433872491	3216	Economy	17200.00
0005433872498	3216	Economy	17200.00
0005433872500	3216	Economy	17200.00
0005433872499	3216	Economy	17200.00
0005433872493	3216	Economy	17200.00
0005433872502	3216	Economy	17200.00
0005433872497	3216	Economy	17200.00
0005433872470	32547	Economy	19000.00
0005433872465	32547	Economy	19000.00
0005433872477	32547	Economy	17200.00
0005433872469	32547	Economy	17200.00
0005433872458	32547	Economy	17200.00
0005433872460	32547	Economy	17200.00
0005433872461	32547	Economy	17200.00
0005433872467	32547	Economy	17200.00
0005433872459	32547	Economy	17200.00
0005433872466	32547	Economy	17200.00
0005433872468	32547	Economy	17200.00
0005433872464	32547	Economy	17200.00
0005433872446	32547	Economy	17200.00
0005433872463	32547	Economy	17200.00
0005433872462	32547	Economy	17200.00
0005433872473	32547	Economy	17200.00
0005433872445	32547	Economy	17200.00
0005435142619	10354	Economy	17000.00
0005435150076	10354	Economy	17000.00
0005435386541	10354	Economy	17000.00
0005435386520	10354	Economy	17000.00
0005433289781	10354	Economy	15400.00
0005433289771	10354	Economy	15400.00
0005435150067	10354	Economy	15400.00
0005435150075	10354	Economy	15400.00
0005435150066	10354	Economy	15400.00
0005435142613	10354	Economy	15400.00
0005435150070	10354	Economy	15400.00
0005435142620	10354	Economy	15400.00
0005435150081	10354	Economy	15400.00
0005435142618	10354	Economy	15400.00
0005435142614	10354	Economy	15400.00
0005435150080	10354	Economy	15400.00
0005435386544	10354	Economy	15400.00
0005433289780	10354	Economy	15400.00
0005433289809	10354	Economy	15400.00
0005435150068	10354	Economy	15400.00
0005435142623	10354	Economy	15400.00
0005433289810	10354	Economy	15400.00
0005433289785	10354	Economy	15400.00
0005435386519	10354	Economy	15400.00
0005435142616	10354	Economy	15400.00
0005435386521	10354	Economy	15400.00
0005435150077	10354	Economy	15400.00
0005435142625	10354	Economy	15400.00
0005433289819	10354	Economy	15400.00
0005435142624	10354	Economy	15400.00
0005435150079	10354	Economy	15400.00
0005433289783	10354	Economy	15400.00
0005435142622	10354	Economy	15400.00
0005433289772	10354	Economy	15400.00
0005435150071	10354	Economy	15400.00
0005435386506	10354	Economy	15400.00
0005435386507	10354	Economy	15400.00
0005433289782	10354	Economy	15400.00
0005435386531	10354	Economy	15400.00
0005435150073	10354	Economy	15400.00
0005435150072	10354	Economy	15400.00
0005435142621	10354	Economy	15400.00
0005435142615	10354	Economy	15400.00
0005435142617	10354	Economy	15400.00
0005433289784	10354	Economy	15400.00
0005435150069	10354	Economy	15400.00
0005435150074	10354	Economy	15400.00
0005433289827	10354	Economy	15400.00
0005435150078	10354	Economy	15400.00
0005433289885	21962	Economy	17000.00
0005435142513	21962	Economy	17000.00
0005435142378	21962	Economy	17000.00
0005435149975	21962	Economy	17000.00
0005435149989	21962	Economy	15400.00
0005435149976	21962	Economy	15400.00
0005435142508	21962	Economy	15400.00
0005435149952	21962	Economy	15400.00
0005435149936	21962	Economy	15400.00
0005435142505	21962	Economy	15400.00
0005435142466	21962	Economy	15400.00
0005435149992	21962	Economy	15400.00
0005435149993	21962	Economy	15400.00
0005435149960	21962	Economy	15400.00
0005433289882	21962	Economy	15400.00
0005435149956	21962	Economy	15400.00
0005435149918	21962	Economy	15400.00
0005435142377	21962	Economy	15400.00
0005435149930	21962	Economy	15400.00
0005435386595	21962	Economy	15400.00
0005435149978	21962	Economy	15400.00
0005435149919	21962	Economy	15400.00
0005435386597	21962	Economy	15400.00
0005435142565	21962	Economy	15400.00
0005433289886	21962	Economy	15400.00
0005435149988	21962	Economy	15400.00
0005435142507	21962	Economy	15400.00
0005435142566	21962	Economy	15400.00
0005435149949	21962	Economy	15400.00
0005435149990	21962	Economy	15400.00
0005435149935	21962	Economy	15400.00
0005435149880	21962	Economy	15400.00
0005435149937	21962	Economy	15400.00
0005435149998	21962	Economy	15400.00
0005435149932	21962	Economy	15400.00
0005435149938	21962	Economy	15400.00
0005435386596	21962	Economy	15400.00
0005435149985	21962	Economy	15400.00
0005435149977	21962	Economy	15400.00
0005433289881	21962	Economy	15400.00
0005435142497	21962	Economy	15400.00
0005433289883	21962	Economy	15400.00
0005435149948	21962	Economy	15400.00
0005435142469	21962	Economy	15400.00
0005435149957	21962	Economy	15400.00
0005433289884	21962	Economy	15400.00
0005435149961	21962	Economy	15400.00
0005435149991	21962	Economy	15400.00
0005435149950	21962	Economy	15400.00
0005435149963	21962	Economy	15400.00
0005434573391	11199	Business	57200.00
0005435545718	11199	Business	57200.00
0005435502156	11199	Business	57200.00
0005435529063	11199	Business	57200.00
0005435502288	11199	Business	57200.00
0005435545694	11199	Business	57200.00
0005435319537	11199	Business	57200.00
0005435502210	11199	Business	57200.00
0005434573402	11199	Business	57200.00
0005435502298	11199	Business	57200.00
0005435502116	11199	Business	57200.00
0005434573398	11199	Business	57200.00
0005435529137	11199	Economy	19100.00
0005435529116	11199	Economy	19100.00
0005435502185	11199	Economy	19100.00
0005435529117	11199	Economy	19100.00
0005434573390	11199	Economy	19100.00
0005435502267	11199	Economy	19100.00
0005435319507	11199	Economy	19100.00
0005435319479	11199	Economy	19100.00
0005435502155	11199	Economy	19100.00
0005434573393	11199	Economy	21000.00
0005435529160	11199	Economy	21000.00
0005435502117	11199	Economy	21000.00
0005435319547	11199	Economy	21000.00
0005435529167	11199	Economy	21000.00
0005435529161	11199	Economy	19100.00
0005434573394	11199	Economy	19100.00
0005435502217	11199	Economy	19100.00
0005435545703	11199	Economy	19100.00
0005435529190	11199	Economy	19100.00
0005435319528	11199	Economy	19100.00
0005435529138	11199	Economy	19100.00
0005434573399	11199	Economy	19100.00
0005435545658	11199	Economy	19100.00
0005435545695	11199	Economy	19100.00
0005435319499	11199	Economy	19100.00
0005435502198	11199	Economy	19100.00
0005435502266	11199	Economy	19100.00
0005435529165	11199	Economy	19100.00
0005434573397	11199	Economy	19100.00
0005435529056	11199	Economy	19100.00
0005434573392	11199	Economy	19100.00
0005435529115	11199	Economy	19100.00
0005435319536	11199	Economy	19100.00
0005435545705	11199	Economy	19100.00
0005435529102	11199	Economy	19100.00
0005435502250	11199	Economy	19100.00
0005434573403	11199	Economy	19100.00
0005435545722	11199	Economy	19100.00
0005435545711	11199	Economy	19100.00
0005435502212	11199	Economy	19100.00
0005435502127	11199	Economy	19100.00
0005435545696	11199	Economy	19100.00
0005435529101	11199	Economy	19100.00
0005435529168	11199	Economy	19100.00
0005435545714	11199	Economy	19100.00
0005435502184	11199	Economy	19100.00
0005435545713	11199	Economy	19100.00
0005435319543	11199	Economy	19100.00
0005435529133	11199	Economy	19100.00
0005435545706	11199	Economy	19100.00
0005435319548	11199	Economy	19100.00
0005435529093	11199	Economy	19100.00
0005435502213	11199	Economy	19100.00
0005435529146	11199	Economy	19100.00
0005434573401	11199	Economy	19100.00
0005435529191	11199	Economy	19100.00
0005435529134	11199	Economy	19100.00
0005435502230	11199	Economy	19100.00
0005435529202	11199	Economy	19100.00
0005435529069	11199	Economy	19100.00
0005435502208	11199	Economy	19100.00
0005435502128	11199	Economy	19100.00
0005435502201	11199	Economy	19100.00
0005435545708	11199	Economy	19100.00
0005435502223	11199	Economy	19100.00
0005434573396	11199	Economy	19100.00
0005435545647	11199	Economy	19100.00
0005435319480	11199	Economy	19100.00
0005435529088	11199	Economy	19100.00
0005435529205	11199	Economy	19100.00
0005435319525	11199	Economy	19100.00
0005435529166	11199	Economy	19100.00
0005434573395	11199	Economy	19100.00
0005435529195	11199	Economy	19100.00
0005434573400	11199	Economy	19100.00
0005435502218	11199	Economy	19100.00
0005435529094	11199	Economy	19100.00
0005435545646	11199	Economy	19100.00
0005435319500	11199	Economy	19100.00
0005435502375	20950	Business	57200.00
0005435502379	20950	Business	57200.00
0005435517965	20950	Business	57200.00
0005434573242	20950	Business	57200.00
0005435517968	20950	Business	57200.00
0005434573234	20950	Business	57200.00
0005434573281	20950	Business	57200.00
0005435502383	20950	Business	57200.00
0005435517974	20950	Business	57200.00
0005435517967	20950	Business	57200.00
0005435502393	20950	Economy	19100.00
0005434573208	20950	Economy	19100.00
0005435502376	20950	Economy	19100.00
0005435502384	20950	Economy	19100.00
0005434573318	20950	Economy	19100.00
0005435502390	20950	Economy	21000.00
0005434573279	20950	Economy	21000.00
0005435502385	20950	Economy	21000.00
0005435502391	20950	Economy	21000.00
0005435502386	20950	Economy	19100.00
0005435517963	20950	Economy	19100.00
0005435517976	20950	Economy	19100.00
0005434573209	20950	Economy	19100.00
0005434573286	20950	Economy	19100.00
0005434573308	20950	Economy	19100.00
0005435502381	20950	Economy	19100.00
0005434573262	20950	Economy	19100.00
0005435517975	20950	Economy	19100.00
0005435502389	20950	Economy	19100.00
0005435319618	20950	Economy	19100.00
0005435502380	20950	Economy	19100.00
0005435319619	20950	Economy	19100.00
0005435502382	20950	Economy	19100.00
0005435517962	20950	Economy	19100.00
0005434573295	20950	Economy	19100.00
0005435508397	20950	Economy	19100.00
0005435517971	20950	Economy	19100.00
0005435502396	20950	Economy	19100.00
0005435517966	20950	Economy	19100.00
0005435517970	20950	Economy	19100.00
0005435508396	20950	Economy	19100.00
0005435517964	20950	Economy	19100.00
0005434573217	20950	Economy	19100.00
0005435319616	20950	Economy	19100.00
0005435502392	20950	Economy	19100.00
0005435319621	20950	Economy	19100.00
0005434573271	20950	Economy	19100.00
0005434573235	20950	Economy	19100.00
0005434573283	20950	Economy	19100.00
0005434573268	20950	Economy	19100.00
0005432291940	20950	Economy	19100.00
0005435319620	20950	Economy	19100.00
0005435517973	20950	Economy	19100.00
0005435319622	20950	Economy	19100.00
0005434573275	20950	Economy	19100.00
0005435502378	20950	Economy	19100.00
0005435508399	20950	Economy	19100.00
0005434573278	20950	Economy	19100.00
0005435502388	20950	Economy	19100.00
0005432291938	20950	Economy	19100.00
0005435502377	20950	Economy	19100.00
0005435517972	20950	Economy	19100.00
0005432291939	20950	Economy	19100.00
0005434573274	20950	Economy	19100.00
0005435517961	20950	Economy	19100.00
0005435319615	20950	Economy	19100.00
0005435502394	20950	Economy	19100.00
0005435502395	20950	Economy	19100.00
0005435517969	20950	Economy	19100.00
0005435502387	20950	Economy	19100.00
0005435508395	20950	Economy	19100.00
0005435508398	20950	Economy	19100.00
0005435319617	20950	Economy	19100.00
0005434573280	20950	Economy	19100.00
0005434573359	20950	Economy	19100.00
0005433927432	24312	Economy	18800.00
0005433927435	24312	Economy	18800.00
0005433927423	24312	Economy	17100.00
0005433927433	24312	Economy	17100.00
0005433927428	24312	Economy	17100.00
0005433927427	24312	Economy	17100.00
0005433927406	24312	Economy	17100.00
0005433683345	24312	Economy	17100.00
0005433927424	24312	Economy	17100.00
0005433927407	24312	Economy	17100.00
0005433683350	24312	Economy	17100.00
0005433683346	24312	Economy	17100.00
0005433683348	24312	Economy	17100.00
0005433927417	24312	Economy	17100.00
0005433683343	24312	Economy	17100.00
0005433683341	24312	Economy	17100.00
0005433927434	24312	Economy	17100.00
0005433683344	24312	Economy	17100.00
0005433927420	24312	Economy	17100.00
0005433927425	24312	Economy	17100.00
0005433683351	24312	Economy	17100.00
0005433683342	24312	Economy	17100.00
0005433927436	24312	Economy	17100.00
0005433683349	24312	Economy	17100.00
0005433683347	24312	Economy	17100.00
0005433683323	29289	Economy	18800.00
0005433927444	29289	Economy	18800.00
0005433927452	29289	Economy	18800.00
0005433683327	29289	Economy	17100.00
0005433683329	29289	Economy	17100.00
0005433683312	29289	Economy	17100.00
0005433927445	29289	Economy	17100.00
0005433683318	29289	Economy	17100.00
0005433927448	29289	Economy	17100.00
0005433927450	29289	Economy	17100.00
0005433927449	29289	Economy	17100.00
0005433927453	29289	Economy	17100.00
0005433927447	29289	Economy	17100.00
0005433683317	29289	Economy	17100.00
0005433927446	29289	Economy	17100.00
0005433927451	29289	Economy	17100.00
0005433683316	29289	Economy	17100.00
0005432692831	3005	Business	10300.00
0005432692997	3005	Business	10300.00
0005432692870	3005	Business	10300.00
0005432692867	3005	Business	10300.00
0005432692954	3005	Business	10300.00
0005432692865	3005	Economy	3400.00
0005432693021	3005	Economy	3400.00
0005432692861	3005	Economy	3400.00
0005432692938	3005	Economy	3800.00
0005432693003	3005	Economy	3800.00
0005432692797	3005	Economy	3800.00
0005432692822	3005	Economy	3400.00
0005432692918	3005	Economy	3400.00
0005432692712	3005	Economy	3400.00
0005432692798	3005	Economy	3400.00
0005432692895	3005	Economy	3400.00
0005432692941	3005	Economy	3400.00
0005432693061	3005	Economy	3400.00
0005432692859	3005	Economy	3400.00
0005432692910	3005	Economy	3400.00
0005432692883	3005	Economy	3400.00
0005432692766	3005	Economy	3400.00
0005432692926	3005	Economy	3400.00
0005432692924	3005	Economy	3400.00
0005432692928	3005	Economy	3400.00
0005432692832	3005	Economy	3400.00
0005432692871	3005	Economy	3400.00
0005432692830	3005	Economy	3400.00
0005432692940	3005	Economy	3400.00
0005432692955	3005	Economy	3400.00
0005432692860	3005	Economy	3400.00
0005432692846	3005	Economy	3400.00
0005432692927	3005	Economy	3400.00
0005432692903	3005	Economy	3400.00
0005432692866	3005	Economy	3400.00
0005432692939	3005	Economy	3400.00
0005432706859	3001	Business	10300.00
0005432217786	3001	Business	10300.00
0005433123874	3001	Business	10300.00
0005432880726	3001	Business	10300.00
0005432880760	3001	Business	10300.00
0005433123828	3001	Business	10300.00
0005432706869	3001	Business	10300.00
0005433123894	3001	Business	10300.00
0005433123776	3001	Business	10300.00
0005433123802	3001	Economy	3400.00
0005432706879	3001	Economy	3400.00
0005432706863	3001	Economy	3400.00
0005432706871	3001	Economy	3400.00
0005432880743	3001	Economy	3400.00
0005432706882	3001	Economy	3800.00
0005432880785	3001	Economy	3800.00
0005432706873	3001	Economy	3800.00
0005432706862	3001	Economy	3800.00
0005432880772	3001	Economy	3800.00
0005432706877	3001	Economy	3400.00
0005432706881	3001	Economy	3400.00
0005433194855	3001	Economy	3400.00
0005432706867	3001	Economy	3400.00
0005432706874	3001	Economy	3400.00
0005433123846	3001	Economy	3400.00
0005432706860	3001	Economy	3400.00
0005433123845	3001	Economy	3400.00
0005432706883	3001	Economy	3400.00
0005433194843	3001	Economy	3400.00
0005433123863	3001	Economy	3400.00
0005432217788	3001	Economy	3400.00
0005432706878	3001	Economy	3400.00
0005433123834	3001	Economy	3400.00
0005432880774	3001	Economy	3400.00
0005432880704	3001	Economy	3400.00
0005433123868	3001	Economy	3400.00
0005432706870	3001	Economy	3400.00
0005432706865	3001	Economy	3400.00
0005433123782	3001	Economy	3400.00
0005433123886	3001	Economy	3400.00
0005433123781	3001	Economy	3400.00
0005432706864	3001	Economy	3400.00
0005433123801	3001	Economy	3400.00
0005432706875	3001	Economy	3400.00
0005432706876	3001	Economy	3400.00
0005432880759	3001	Economy	3400.00
0005433123774	3001	Economy	3400.00
0005432217787	3001	Economy	3400.00
0005433123873	3001	Economy	3400.00
0005432706866	3001	Economy	3400.00
0005432706861	3001	Economy	3400.00
0005432706872	3001	Economy	3400.00
0005432880750	3001	Economy	3400.00
0005432706868	3001	Economy	3400.00
0005432880773	3001	Economy	3400.00
0005433123847	3001	Economy	3400.00
0005432880684	3001	Economy	3400.00
0005432880740	3001	Economy	3400.00
0005432706880	3001	Economy	3400.00
0005432880868	30012	Business	10300.00
0005433123992	30012	Business	10300.00
0005432693221	30012	Business	10300.00
0005432706641	30012	Business	10300.00
0005432706725	30012	Business	10300.00
0005432693198	30012	Business	10300.00
0005433123990	30012	Business	10300.00
0005432693195	30012	Business	10300.00
0005433123994	30012	Business	10300.00
0005432693192	30012	Business	10300.00
0005432693216	30012	Business	10300.00
0005433124001	30012	Business	10300.00
0005432706745	30012	Economy	3400.00
0005433124006	30012	Economy	3400.00
0005432693220	30012	Economy	3400.00
0005432693191	30012	Economy	3400.00
0005432693222	30012	Economy	3400.00
0005432693211	30012	Economy	3400.00
0005432706575	30012	Economy	3400.00
0005432706750	30012	Economy	3400.00
0005433124002	30012	Economy	3400.00
0005433123991	30012	Economy	3400.00
0005433124007	30012	Economy	3800.00
0005432880881	30012	Economy	3800.00
0005432693201	30012	Economy	3800.00
0005432706648	30012	Economy	3800.00
0005433123993	30012	Economy	3800.00
0005433123999	30012	Economy	3400.00
0005433123996	30012	Economy	3400.00
0005432693196	30012	Economy	3400.00
0005432880879	30012	Economy	3400.00
0005432880876	30012	Economy	3400.00
0005432880873	30012	Economy	3400.00
0005433124013	30012	Economy	3400.00
0005432880875	30012	Economy	3400.00
0005432693209	30012	Economy	3400.00
0005432706723	30012	Economy	3400.00
0005432693194	30012	Economy	3400.00
0005432693213	30012	Economy	3400.00
0005432880867	30012	Economy	3400.00
0005433124011	30012	Economy	3400.00
0005432706744	30012	Economy	3400.00
0005432706722	30012	Economy	3400.00
0005432693205	30012	Economy	3400.00
0005433124009	30012	Economy	3400.00
0005432880877	30012	Economy	3400.00
0005432880871	30012	Economy	3400.00
0005432706703	30012	Economy	3400.00
0005432693200	30012	Economy	3400.00
0005432706687	30012	Economy	3400.00
0005432693212	30012	Economy	3400.00
0005432693207	30012	Economy	3400.00
0005433124010	30012	Economy	3400.00
0005432706702	30012	Economy	3400.00
0005432693219	30012	Economy	3400.00
0005432706668	30012	Economy	3400.00
0005432693203	30012	Economy	3400.00
0005432880880	30012	Economy	3400.00
0005432706661	30012	Economy	3400.00
0005432706618	30012	Economy	3400.00
0005433123995	30012	Economy	3400.00
0005432880869	30012	Economy	3400.00
0005432693199	30012	Economy	3400.00
0005433124005	30012	Economy	3400.00
0005432706694	30012	Economy	3400.00
0005432693210	30012	Economy	3400.00
0005432706619	30012	Economy	3400.00
0005432693215	30012	Economy	3400.00
0005432706726	30012	Economy	3400.00
0005432880878	30012	Economy	3400.00
0005432693214	30012	Economy	3400.00
0005432693193	30012	Economy	3400.00
0005432880872	30012	Economy	3400.00
0005433123997	30012	Economy	3400.00
0005432693218	30012	Economy	3400.00
0005432693204	30012	Economy	3400.00
0005432693208	30012	Economy	3400.00
0005432693190	30012	Economy	3400.00
0005432693206	30012	Economy	3400.00
0005432706669	30012	Economy	3400.00
0005432693202	30012	Economy	3400.00
0005433124012	30012	Economy	3400.00
0005432706644	30012	Economy	3400.00
0005433124008	30012	Economy	3400.00
0005433124004	30012	Economy	3400.00
0005433123998	30012	Economy	3400.00
0005432706623	30012	Economy	3400.00
0005433124000	30012	Economy	3400.00
0005432880874	30012	Economy	3400.00
0005432880870	30012	Economy	3400.00
0005433124003	30012	Economy	3400.00
0005432706624	30012	Economy	3400.00
0005432706751	30012	Economy	3400.00
0005432706642	30012	Economy	3400.00
0005432693197	30012	Economy	3400.00
0005432693217	30012	Economy	3400.00
0005434979875	23694	Economy	4000.00
0005434988781	23694	Economy	4000.00
0005434979885	23694	Economy	4000.00
0005434979874	23694	Economy	4000.00
0005434979887	23694	Economy	3600.00
0005434979867	23694	Economy	3600.00
0005434979878	23694	Economy	3600.00
0005434988782	23694	Economy	3600.00
0005434988779	23694	Economy	3600.00
0005434979891	23694	Economy	3600.00
0005434979889	23694	Economy	3600.00
0005434988783	23694	Economy	3600.00
0005434979873	23694	Economy	3600.00
0005434979880	23694	Economy	3600.00
0005434979871	23694	Economy	3600.00
0005434988778	23694	Economy	3600.00
0005434988777	23694	Economy	3600.00
0005434979897	23694	Economy	3600.00
0005434979872	23694	Economy	3600.00
0005434979886	23694	Economy	3600.00
0005434979896	23694	Economy	3600.00
0005434979893	23694	Economy	3600.00
0005434979883	23694	Economy	3600.00
0005434979884	23694	Economy	3600.00
0005434979881	23694	Economy	3600.00
0005434979895	23694	Economy	3600.00
0005434979870	23694	Economy	3600.00
0005434988780	23694	Economy	3600.00
0005434979879	23694	Economy	3600.00
0005434979876	23694	Economy	3600.00
0005434979894	23694	Economy	3600.00
0005434979868	23694	Economy	3600.00
0005434979882	23694	Economy	3600.00
0005434979869	23694	Economy	3600.00
0005434979877	23694	Economy	3600.00
0005434979888	23694	Economy	3600.00
0005434979890	23694	Economy	3600.00
0005434979892	23694	Economy	3600.00
0005434979666	27526	Economy	4000.00
0005434979640	27526	Economy	4000.00
0005434979580	27526	Economy	4000.00
0005434988648	27526	Economy	3600.00
0005434979599	27526	Economy	3600.00
0005434979563	27526	Economy	3600.00
0005434979710	27526	Economy	3600.00
0005434988635	27526	Economy	3600.00
0005434979657	27526	Economy	3600.00
0005434988628	27526	Economy	3600.00
0005434988658	27526	Economy	3600.00
0005434979562	27526	Economy	3600.00
0005434979604	27526	Economy	3600.00
0005434979799	27526	Economy	3600.00
0005434979636	27526	Economy	3600.00
0005434979738	27526	Economy	3600.00
0005434988649	27526	Economy	3600.00
0005434979709	27526	Economy	3600.00
0005434979665	27526	Economy	3600.00
0005434979637	27526	Economy	3600.00
0005434979498	27526	Economy	3600.00
0005434979572	27526	Economy	3600.00
0005434988627	27526	Economy	3600.00
0005434979617	27526	Economy	3600.00
0005434979623	27526	Economy	3600.00
0005434979646	27526	Economy	3600.00
0005434979581	27526	Economy	3600.00
0005434979687	27526	Economy	3600.00
0005434979676	27526	Economy	3600.00
0005434979571	27526	Economy	3600.00
0005434979618	27526	Economy	3600.00
0005434988647	27526	Economy	3600.00
0005434979598	27526	Economy	3600.00
0005434988613	27526	Economy	3600.00
0005434979619	27526	Economy	3600.00
0005434988640	27526	Economy	3600.00
0005434979535	27526	Economy	3600.00
0005434979647	27526	Economy	3600.00
0005434979641	27526	Economy	3600.00
0005434988639	27526	Economy	3600.00
0005434979648	27526	Economy	3600.00
0005434302472	10245	Economy	19700.00
0005434302473	10245	Economy	19700.00
0005434302474	10245	Economy	19700.00
0005433113524	10245	Economy	19700.00
0005434302445	19625	Economy	19700.00
0005433113545	19625	Economy	19700.00
0005433113544	19625	Economy	19700.00
0005435069296	3549	Business	26900.00
0005435069295	3549	Business	26900.00
0005435069317	3549	Business	26900.00
0005435069302	3549	Business	26900.00
0005435069307	3549	Business	26900.00
0005435069323	3549	Business	26900.00
0005435069322	3549	Business	26900.00
0005435925217	3549	Business	26900.00
0005435069316	3549	Business	26900.00
0005435718971	3549	Business	26900.00
0005435925195	3549	Business	26900.00
0005435939864	3549	Economy	9000.00
0005435069305	3549	Economy	9000.00
0005435069273	3549	Economy	9000.00
0005435925236	3549	Economy	9000.00
0005435069288	3549	Economy	9000.00
0005435925194	3549	Economy	9000.00
0005435069320	3549	Economy	9000.00
0005435718973	3549	Economy	9000.00
0005435069313	3549	Economy	9000.00
0005435718974	3549	Economy	9900.00
0005435718976	3549	Economy	9900.00
0005435069315	3549	Economy	9900.00
0005435925153	3549	Economy	9900.00
0005435939875	3549	Economy	9000.00
0005435925205	3549	Economy	9000.00
0005435069285	3549	Economy	9000.00
0005435069281	3549	Economy	9000.00
0005435069298	3549	Economy	9000.00
0005435069277	3549	Economy	9000.00
0005435939874	3549	Economy	9000.00
0005435069287	3549	Economy	9000.00
0005435069319	3549	Economy	9000.00
0005435069308	3549	Economy	9000.00
0005435069292	3549	Economy	9000.00
0005435069301	3549	Economy	9000.00
0005435718975	3549	Economy	9000.00
0005435069306	3549	Economy	9000.00
0005435069300	3549	Economy	9000.00
0005435069310	3549	Economy	9000.00
0005435069284	3549	Economy	9000.00
0005435925235	3549	Economy	9000.00
0005435069280	3549	Economy	9000.00
0005435069303	3549	Economy	9000.00
0005435069286	3549	Economy	9000.00
0005435718979	3549	Economy	9000.00
0005435069318	3549	Economy	9000.00
0005435069314	3549	Economy	9000.00
0005435069290	3549	Economy	9000.00
0005435069321	3549	Economy	9000.00
0005435069289	3549	Economy	9000.00
0005435069283	3549	Economy	9000.00
0005435069304	3549	Economy	9000.00
0005435718977	3549	Economy	9000.00
0005435069278	3549	Economy	9000.00
0005435069293	3549	Economy	9000.00
0005435069294	3549	Economy	9000.00
0005435925196	3549	Economy	9000.00
0005435069274	3549	Economy	9000.00
0005435718972	3549	Economy	9000.00
0005435069309	3549	Economy	9000.00
0005435925200	3549	Economy	9000.00
0005435069272	3549	Economy	9000.00
0005435069297	3549	Economy	9000.00
0005435069311	3549	Economy	9000.00
0005435069275	3549	Economy	9000.00
0005435069291	3549	Economy	9000.00
0005435939869	3549	Economy	9000.00
0005435069279	3549	Economy	9000.00
0005435925199	3549	Economy	9000.00
0005435069312	3549	Economy	9000.00
0005435925230	3549	Economy	9000.00
0005435718978	3549	Economy	9000.00
0005435069299	3549	Economy	9000.00
0005435069276	3549	Economy	9000.00
0005435069282	3549	Economy	9000.00
0005435925229	3549	Economy	9000.00
0005435939870	3549	Economy	9000.00
0005435068833	15312	Business	26900.00
0005435068771	15312	Business	26900.00
0005435925355	15312	Business	26900.00
0005435925344	15312	Business	26900.00
0005435925343	15312	Business	26900.00
0005435068941	15312	Business	26900.00
0005435925349	15312	Business	26900.00
0005435939890	15312	Business	26900.00
0005435068764	15312	Economy	9000.00
0005435068817	15312	Economy	9000.00
0005435068705	15312	Economy	9000.00
0005435925353	15312	Economy	9900.00
0005435068891	15312	Economy	9900.00
0005435068690	15312	Economy	9900.00
0005435068726	15312	Economy	9900.00
0005435939887	15312	Economy	9000.00
0005435939889	15312	Economy	9000.00
0005435925346	15312	Economy	9000.00
0005435925342	15312	Economy	9000.00
0005435939886	15312	Economy	9000.00
0005435939888	15312	Economy	9000.00
0005435925348	15312	Economy	9000.00
0005435925341	15312	Economy	9000.00
0005435068827	15312	Economy	9000.00
0005435068830	15312	Economy	9000.00
0005435068658	15312	Economy	9000.00
0005435068772	15312	Economy	9000.00
0005435068678	15312	Economy	9000.00
0005435068679	15312	Economy	9000.00
0005435068926	15312	Economy	9000.00
0005435925354	15312	Economy	9000.00
0005435068710	15312	Economy	9000.00
0005435068893	15312	Economy	9000.00
0005435068689	15312	Economy	9000.00
0005435068974	15312	Economy	9000.00
0005435068989	15312	Economy	9000.00
0005435925351	15312	Economy	9000.00
0005435068741	15312	Economy	9000.00
0005435068794	15312	Economy	9000.00
0005435068659	15312	Economy	9000.00
0005435925356	15312	Economy	9000.00
0005435068651	15312	Economy	9000.00
0005435068970	15312	Economy	9000.00
0005435068718	15312	Economy	9000.00
0005435068677	15312	Economy	9000.00
0005435068742	15312	Economy	9000.00
0005435068842	15312	Economy	9000.00
0005435068773	15312	Economy	9000.00
0005435068918	15312	Economy	9000.00
0005435068925	15312	Economy	9000.00
0005435925352	15312	Economy	9000.00
0005435068917	15312	Economy	9000.00
0005435068646	15312	Economy	9000.00
0005435068831	15312	Economy	9000.00
0005435069087	15312	Economy	9000.00
0005435068870	15312	Economy	9000.00
0005435068656	15312	Economy	9000.00
0005435925345	15312	Economy	9000.00
0005435068832	15312	Economy	9000.00
0005435925350	15312	Economy	9000.00
0005435925347	15312	Economy	9000.00
0005432660826	18115	Economy	5900.00
0005432658599	18115	Economy	5900.00
0005432659715	18115	Economy	5900.00
0005432660825	18115	Economy	5900.00
0005432667437	26373	Economy	5900.00
0005432664128	26373	Economy	5900.00
0005432664119	26373	Economy	5900.00
0005432664118	26373	Economy	5900.00
0005432660796	26373	Economy	5900.00
0005432667438	26373	Economy	5900.00
0005432667447	26373	Economy	5900.00
0005432660807	26373	Economy	5900.00
0005432919806	17	Business	20000.00
0005433101771	17	Business	20000.00
0005433101916	17	Business	20000.00
0005432919704	17	Business	20000.00
0005432677550	17	Business	20000.00
0005433101946	17	Business	20000.00
0005432901597	17	Business	20000.00
0005433101816	17	Business	20000.00
0005433101808	17	Business	20000.00
0005432919667	17	Business	20000.00
0005432391976	17	Business	20000.00
0005432901558	17	Business	20000.00
0005432919829	17	Business	20000.00
0005432901598	17	Business	20000.00
0005432391984	17	Business	20000.00
0005432391973	17	Business	20000.00
0005432919807	17	Business	20000.00
0005433101878	17	Business	20000.00
0005433101789	17	Business	20000.00
0005432391979	17	Economy	7300.00
0005432919828	17	Economy	7300.00
0005433101846	17	Economy	7300.00
0005433101751	17	Economy	6700.00
0005432901575	17	Economy	6700.00
0005432157501	17	Economy	6700.00
0005432391968	17	Economy	6700.00
0005433101749	17	Economy	6700.00
0005432919749	17	Economy	6700.00
0005432901559	17	Economy	6700.00
0005432919859	17	Economy	6700.00
0005432391970	17	Economy	6700.00
0005432901462	17	Economy	6700.00
0005432919803	17	Economy	6700.00
0005433101978	17	Economy	6700.00
0005432919878	17	Economy	6700.00
0005433101872	17	Economy	6700.00
0005433101591	17	Economy	6700.00
0005433101729	17	Economy	6700.00
0005433101756	17	Economy	6700.00
0005432919759	17	Economy	6700.00
0005432919805	17	Economy	6700.00
0005432901595	17	Economy	6700.00
0005433101906	17	Economy	6700.00
0005432391969	17	Economy	6700.00
0005433101902	17	Economy	6700.00
0005433101671	17	Economy	6700.00
0005433101799	17	Economy	6700.00
0005432919810	17	Economy	6700.00
0005433101952	17	Economy	6700.00
0005432901611	17	Economy	6700.00
0005432391985	17	Economy	6700.00
0005433101711	17	Economy	6700.00
0005433101964	17	Economy	6700.00
0005433101750	17	Economy	6700.00
0005432901563	17	Economy	6700.00
0005433101800	17	Economy	6700.00
0005433101913	17	Economy	6700.00
0005432677545	17	Economy	6700.00
0005432901600	17	Economy	7300.00
0005432919748	17	Economy	7300.00
0005432901610	17	Economy	7300.00
0005432919851	17	Economy	6700.00
0005432901527	17	Economy	6700.00
0005433101863	17	Economy	7300.00
0005432919852	17	Economy	6700.00
0005432919788	17	Economy	6700.00
0005433101977	17	Economy	6700.00
0005433101757	17	Economy	6700.00
0005432901494	17	Economy	6700.00
0005432919842	17	Economy	6700.00
0005432901562	17	Economy	6700.00
0005432901564	17	Economy	6700.00
0005432901547	17	Economy	6700.00
0005433101694	17	Economy	6700.00
0005432901513	17	Economy	6700.00
0005433101731	17	Economy	6700.00
0005433101737	17	Economy	6700.00
0005433101793	17	Economy	6700.00
0005432919823	17	Economy	6700.00
0005433101914	17	Economy	6700.00
0005432901546	17	Economy	6700.00
0005432391991	17	Economy	6700.00
0005433101984	17	Economy	6700.00
0005433101730	17	Economy	6700.00
0005432919860	17	Economy	6700.00
0005433101876	17	Economy	6700.00
0005433101807	17	Economy	6700.00
0005432677551	17	Economy	6700.00
0005432919811	17	Economy	6700.00
0005432391978	17	Economy	6700.00
0005432919735	17	Economy	6700.00
0005432391974	17	Economy	6700.00
0005433101923	17	Economy	6700.00
0005432391977	17	Economy	6700.00
0005432919873	17	Economy	6700.00
0005433101767	17	Economy	6700.00
0005432391975	17	Economy	6700.00
0005432391990	17	Economy	6700.00
0005432157500	17	Economy	6700.00
0005433101962	17	Economy	6700.00
0005432391971	17	Economy	6700.00
0005432262096	18	Business	20000.00
0005433687696	18	Business	20000.00
0005432817603	18	Business	20000.00
0005432817591	18	Business	20000.00
0005433687694	18	Business	20000.00
0005432262074	18	Business	20000.00
0005432817584	18	Business	20000.00
0005432817592	18	Business	20000.00
0005432817581	18	Business	20000.00
0005432262071	18	Business	20000.00
0005432817599	18	Business	20000.00
0005432817583	18	Business	20000.00
0005432817576	18	Business	20000.00
0005432289000	18	Business	20000.00
0005432817596	18	Economy	7300.00
0005433690920	18	Economy	7300.00
0005432756826	18	Economy	7300.00
0005432262093	18	Economy	7300.00
0005432207670	18	Economy	6700.00
0005432262113	18	Economy	6700.00
0005433687695	18	Economy	6700.00
0005432817590	18	Economy	6700.00
0005432262092	18	Economy	6700.00
0005432262110	18	Economy	6700.00
0005432262083	18	Economy	6700.00
0005432262089	18	Economy	6700.00
0005432262109	18	Economy	6700.00
0005432817582	18	Economy	6700.00
0005432262075	18	Economy	6700.00
0005432817589	18	Economy	6700.00
0005432262115	18	Economy	6700.00
0005433690913	18	Economy	6700.00
0005433690919	18	Economy	6700.00
0005432817595	18	Economy	6700.00
0005432262076	18	Economy	6700.00
0005432753276	18	Economy	6700.00
0005432262090	18	Economy	6700.00
0005432756815	18	Economy	6700.00
0005432262072	18	Economy	6700.00
0005432817585	18	Economy	6700.00
0005432817597	18	Economy	6700.00
0005432262073	18	Economy	6700.00
0005433690912	18	Economy	6700.00
0005432288998	18	Economy	6700.00
0005432262084	18	Economy	6700.00
0005432262107	18	Economy	6700.00
0005432817593	18	Economy	6700.00
0005432817578	18	Economy	6700.00
0005432207669	18	Economy	6700.00
0005432288999	18	Economy	6700.00
0005432262114	18	Economy	6700.00
0005432262077	18	Economy	6700.00
0005432262101	18	Economy	6700.00
0005432817604	18	Economy	7300.00
0005432262078	18	Economy	6700.00
0005432817605	18	Economy	7300.00
0005432262080	18	Economy	7300.00
0005432817577	18	Economy	7300.00
0005432817600	18	Economy	6700.00
0005432817601	18	Economy	6700.00
0005433690921	18	Economy	6700.00
0005432262108	18	Economy	6700.00
0005432753284	18	Economy	6700.00
0005432262086	18	Economy	6700.00
0005432262112	18	Economy	6700.00
0005432817579	18	Economy	6700.00
0005432262105	18	Economy	6700.00
0005432753295	18	Economy	6700.00
0005432262082	18	Economy	6700.00
0005432817602	18	Economy	6700.00
0005432262098	18	Economy	6700.00
0005432262094	18	Economy	6700.00
0005432262111	18	Economy	6700.00
0005432753288	18	Economy	6700.00
0005432262097	18	Economy	6700.00
0005432817580	18	Economy	6700.00
0005432262081	18	Economy	6700.00
0005432262099	18	Economy	6700.00
0005432753275	18	Economy	6700.00
0005432817586	18	Economy	6700.00
0005432817588	18	Economy	6700.00
0005432262088	18	Economy	6700.00
0005432262102	18	Economy	6700.00
0005432817587	18	Economy	6700.00
0005432753285	18	Economy	6700.00
0005432262095	18	Economy	6700.00
0005432262085	18	Economy	6700.00
0005432262103	18	Economy	6700.00
0005432262091	18	Economy	6700.00
0005432262087	18	Economy	6700.00
0005432817594	18	Economy	6700.00
0005432262100	18	Economy	6700.00
0005432262104	18	Economy	6700.00
0005432817598	18	Economy	6700.00
0005432262079	18	Economy	6700.00
0005432262106	18	Economy	6700.00
0005432919936	8141	Business	20000.00
0005432919942	8141	Business	20000.00
0005432020375	8141	Business	20000.00
0005432919945	8141	Business	20000.00
0005433102341	8141	Business	20000.00
0005433102345	8141	Business	20000.00
0005432919947	8141	Business	20000.00
0005432020366	8141	Business	20000.00
0005433102389	8141	Business	20000.00
0005433102351	8141	Business	20000.00
0005433102350	8141	Business	20000.00
0005432919938	8141	Business	20000.00
0005433102360	8141	Business	20000.00
0005433102357	8141	Business	20000.00
0005433102348	8141	Business	20000.00
0005432020378	8141	Business	20000.00
0005432020382	8141	Business	20000.00
0005432020371	8141	Business	20000.00
0005432919948	8141	Business	20000.00
0005432020383	8141	Business	20000.00
0005433102355	8141	Business	20000.00
0005432045621	8141	Business	20000.00
0005433102393	8141	Business	20000.00
0005433102365	8141	Economy	7300.00
0005432044535	8141	Economy	7300.00
0005433102344	8141	Economy	7300.00
0005432677591	8141	Economy	7300.00
0005432020368	8141	Economy	6700.00
0005432919934	8141	Economy	6700.00
0005432020359	8141	Economy	6700.00
0005432020361	8141	Economy	6700.00
0005433102386	8141	Economy	6700.00
0005432020356	8141	Economy	6700.00
0005432919950	8141	Economy	6700.00
0005432020365	8141	Economy	6700.00
0005433102372	8141	Economy	6700.00
0005433102354	8141	Economy	6700.00
0005432020373	8141	Economy	6700.00
0005432020364	8141	Economy	6700.00
0005433102342	8141	Economy	6700.00
0005433102356	8141	Economy	6700.00
0005433102384	8141	Economy	6700.00
0005433102349	8141	Economy	6700.00
0005433102374	8141	Economy	6700.00
0005432677592	8141	Economy	6700.00
0005432677593	8141	Economy	6700.00
0005432044536	8141	Economy	6700.00
0005432751541	8141	Economy	6700.00
0005432919939	8141	Economy	6700.00
0005433102353	8141	Economy	6700.00
0005433102358	8141	Economy	6700.00
0005433102343	8141	Economy	6700.00
0005432919949	8141	Economy	6700.00
0005432392013	8141	Economy	6700.00
0005432919940	8141	Economy	6700.00
0005432044538	8141	Economy	6700.00
0005433102347	8141	Economy	6700.00
0005432751539	8141	Economy	6700.00
0005432919946	8141	Economy	6700.00
0005433102385	8141	Economy	6700.00
0005432020374	8141	Economy	6700.00
0005433102346	8141	Economy	6700.00
0005432020355	8141	Economy	6700.00
0005433102361	8141	Economy	6700.00
0005433102379	8141	Economy	6700.00
0005433102362	8141	Economy	6700.00
0005433102382	8141	Economy	6700.00
0005432753315	8141	Economy	6700.00
0005432020381	8141	Economy	6700.00
0005433102366	8141	Economy	6700.00
0005433102368	8141	Economy	6700.00
0005432020369	8141	Economy	7300.00
0005432392012	8141	Economy	7300.00
0005432020363	8141	Economy	7300.00
0005432919933	8141	Economy	7300.00
0005433102364	8141	Economy	6700.00
0005432919941	8141	Economy	6700.00
0005433102378	8141	Economy	6700.00
0005432751540	8141	Economy	7300.00
0005432919935	8141	Economy	6700.00
0005432020376	8141	Economy	6700.00
0005433102352	8141	Economy	6700.00
0005433102387	8141	Economy	6700.00
0005433102340	8141	Economy	6700.00
0005433102383	8141	Economy	6700.00
0005432392010	8141	Economy	6700.00
0005432677590	8141	Economy	6700.00
0005433102381	8141	Economy	6700.00
0005433102377	8141	Economy	6700.00
0005432392011	8141	Economy	6700.00
0005432020358	8141	Economy	6700.00
0005432020379	8141	Economy	6700.00
0005432020372	8141	Economy	6700.00
0005432677589	8141	Economy	6700.00
0005432020370	8141	Economy	6700.00
0005432020357	8141	Economy	6700.00
0005433102391	8141	Economy	6700.00
0005433102388	8141	Economy	6700.00
0005432919944	8141	Economy	6700.00
0005432020362	8141	Economy	6700.00
0005433102373	8141	Economy	6700.00
0005432753316	8141	Economy	6700.00
0005433102390	8141	Economy	6700.00
0005433102392	8141	Economy	6700.00
0005433102369	8141	Economy	6700.00
0005433102370	8141	Economy	6700.00
0005432020367	8141	Economy	6700.00
0005432919943	8141	Economy	6700.00
0005433102376	8141	Economy	6700.00
0005432045622	8141	Economy	6700.00
0005432919931	8141	Economy	6700.00
0005433102359	8141	Economy	6700.00
0005432044537	8141	Economy	6700.00
0005432919932	8141	Economy	6700.00
0005432919937	8141	Economy	6700.00
0005432020360	8141	Economy	6700.00
0005433102363	8141	Economy	6700.00
0005433102375	8141	Economy	6700.00
0005433102380	8141	Economy	6700.00
0005433102367	8141	Economy	6700.00
0005432020377	8141	Economy	6700.00
0005432919951	8141	Economy	6700.00
0005433102371	8141	Economy	6700.00
0005432020380	8141	Economy	6700.00
0005432817380	8140	Business	20000.00
0005432817283	8140	Business	20000.00
0005432901685	8140	Business	20000.00
0005434513565	8140	Business	20000.00
0005432817309	8140	Business	20000.00
0005434513566	8140	Business	20000.00
0005432817351	8140	Business	20000.00
0005432817349	8140	Business	20000.00
0005432817354	8140	Business	20000.00
0005432901687	8140	Economy	7300.00
0005432901679	8140	Economy	6700.00
0005432901673	8140	Economy	6700.00
0005432817357	8140	Economy	6700.00
0005432817265	8140	Economy	6700.00
0005432817241	8140	Economy	6700.00
0005432901677	8140	Economy	6700.00
0005432901671	8140	Economy	6700.00
0005432901682	8140	Economy	6700.00
0005432002085	8140	Economy	6700.00
0005432817452	8140	Economy	6700.00
0005432817388	8140	Economy	6700.00
0005432817322	8140	Economy	6700.00
0005432817240	8140	Economy	6700.00
0005432817284	8140	Economy	6700.00
0005432817221	8140	Economy	6700.00
0005434513575	8140	Economy	6700.00
0005432817300	8140	Economy	6700.00
0005434513559	8140	Economy	6700.00
0005432901678	8140	Economy	6700.00
0005432817287	8140	Economy	6700.00
0005432817350	8140	Economy	7300.00
0005432817266	8140	Economy	7300.00
0005432817257	8140	Economy	6700.00
0005432817205	8140	Economy	6700.00
0005432817293	8140	Economy	6700.00
0005432901680	8140	Economy	6700.00
0005434513560	8140	Economy	6700.00
0005432901684	8140	Economy	6700.00
0005432817413	8140	Economy	6700.00
0005432901674	8140	Economy	6700.00
0005432817308	8140	Economy	6700.00
0005432817321	8140	Economy	6700.00
0005432901676	8140	Economy	6700.00
0005432901681	8140	Economy	6700.00
0005432901683	8140	Economy	6700.00
0005432817397	8140	Economy	6700.00
0005432901688	8140	Economy	6700.00
0005432817313	8140	Economy	6700.00
0005432901686	8140	Economy	6700.00
0005432817437	8140	Economy	6700.00
0005432817356	8140	Economy	6700.00
0005432817495	8140	Economy	6700.00
0005432901675	8140	Economy	6700.00
0005432901672	8140	Economy	6700.00
0005432817256	8140	Economy	6700.00
0005432817329	8140	Economy	6700.00
0005433870739	9657	Economy	6900.00
0005433870740	9657	Economy	6900.00
0005434175706	9657	Economy	6900.00
0005434175705	9657	Economy	6900.00
0005434175707	9657	Economy	6900.00
0005433870741	9657	Economy	6900.00
0005434175769	32324	Economy	6900.00
0005434175771	32324	Economy	6900.00
0005433870728	32324	Economy	6900.00
0005434175770	32324	Economy	6900.00
0005433870726	32324	Economy	6900.00
0005433870727	32324	Economy	6900.00
0005434175772	32324	Economy	6900.00
0005434175768	32324	Economy	6900.00
0005435126521	3504	Business	35000.00
0005434878633	3504	Business	35000.00
0005435913912	3504	Business	35000.00
0005434878653	3504	Business	35000.00
0005434938218	3504	Business	35000.00
0005432799573	3504	Business	35000.00
0005435126531	3504	Business	35000.00
0005435626248	3504	Business	35000.00
0005435902720	3504	Business	35000.00
0005434878598	3504	Business	35000.00
0005435626249	3504	Business	35000.00
0005434878657	3504	Business	35000.00
0005434878610	3504	Business	35000.00
0005434878582	3504	Business	35000.00
0005434878662	3504	Business	35000.00
0005434878634	3504	Business	35000.00
0005434878666	3504	Business	35000.00
0005435626244	3504	Business	35000.00
0005435914692	3504	Business	35000.00
0005434878626	3504	Business	35000.00
0005435126558	3504	Business	35000.00
0005434878621	3504	Business	35000.00
0005432799569	3504	Business	35000.00
0005434878631	3504	Comfort	19900.00
0005435902561	3504	Business	35000.00
0005435626260	3504	Comfort	19900.00
0005435626261	3504	Comfort	19900.00
0005434938227	3504	Comfort	19900.00
0005434878628	3504	Comfort	19900.00
0005434878588	3504	Comfort	19900.00
0005434878639	3504	Comfort	19900.00
0005434426736	3504	Comfort	19900.00
0005435913913	3504	Comfort	19900.00
0005435626259	3504	Comfort	19900.00
0005434878664	3504	Comfort	19900.00
0005434938216	3504	Comfort	19900.00
0005435626251	3504	Comfort	19900.00
0005434878583	3504	Comfort	19900.00
0005432799566	3504	Comfort	19900.00
0005434426722	3504	Comfort	19900.00
0005434878607	3504	Comfort	19900.00
0005434938230	3504	Comfort	19900.00
0005434878635	3504	Comfort	19900.00
0005434938214	3504	Comfort	19900.00
0005434878650	3504	Comfort	19900.00
0005435126549	3504	Comfort	19900.00
0005435626258	3504	Comfort	19900.00
0005432799568	3504	Comfort	19900.00
0005434878580	3504	Comfort	19900.00
0005435126539	3504	Comfort	19900.00
0005434878617	3504	Comfort	19900.00
0005434878640	3504	Comfort	19900.00
0005434878667	3504	Comfort	19900.00
0005432611729	3504	Comfort	19900.00
0005435913921	3504	Comfort	19900.00
0005434938221	3504	Comfort	19900.00
0005432611730	3504	Comfort	19900.00
0005434878638	3504	Comfort	19900.00
0005434878659	3504	Economy	11700.00
0005435126548	3504	Economy	11700.00
0005435126552	3504	Economy	11700.00
0005435626252	3504	Economy	11700.00
0005435126532	3504	Economy	11700.00
0005432613877	3504	Economy	11700.00
0005432799576	3504	Economy	11700.00
0005432799564	3504	Economy	11700.00
0005432799585	3504	Economy	11700.00
0005435126547	3504	Economy	11700.00
0005434878660	3504	Economy	11700.00
0005435626253	3504	Economy	11700.00
0005434878614	3504	Economy	11700.00
0005434878612	3504	Economy	11700.00
0005434878654	3504	Economy	11700.00
0005435126525	3504	Economy	11700.00
0005434878609	3504	Economy	11700.00
0005435126541	3504	Economy	11700.00
0005434878658	3504	Economy	11700.00
0005434878651	3504	Economy	11700.00
0005434426734	3504	Economy	11700.00
0005435626263	3504	Economy	11700.00
0005434426737	3504	Economy	11700.00
0005435126551	3504	Economy	11700.00
0005432799570	3504	Economy	11700.00
0005435126522	3504	Economy	11700.00
0005434426740	3504	Economy	11700.00
0005434878655	3504	Economy	11700.00
0005434938213	3504	Economy	11700.00
0005434938217	3504	Economy	11700.00
0005434426732	3504	Economy	11700.00
0005435626241	3504	Economy	11700.00
0005434878584	3504	Economy	11700.00
0005434426730	3504	Economy	11700.00
0005435626246	3504	Economy	11700.00
0005435902626	3504	Economy	11700.00
0005434878641	3504	Economy	11700.00
0005434878608	3504	Economy	11700.00
0005434878619	3504	Economy	11700.00
0005435126529	3504	Economy	11700.00
0005434938232	3504	Economy	11700.00
0005432799567	3504	Economy	11700.00
0005435126534	3504	Economy	11700.00
0005434426729	3504	Economy	11700.00
0005435126550	3504	Economy	11700.00
0005434426727	3504	Economy	11700.00
0005434878669	3504	Economy	11700.00
0005434878656	3504	Economy	11700.00
0005434426741	3504	Economy	11700.00
0005434938220	3504	Economy	11700.00
0005434426738	3504	Economy	11700.00
0005432799575	3504	Economy	11700.00
0005432799562	3504	Economy	11700.00
0005435626243	3504	Economy	12800.00
0005435626264	3504	Economy	11700.00
0005435126544	3504	Economy	12800.00
0005432613879	3504	Economy	11700.00
0005434878581	3504	Economy	12800.00
0005432799584	3504	Economy	12800.00
0005434878627	3504	Economy	11700.00
0005435626245	3504	Economy	11700.00
0005434878611	3504	Economy	11700.00
0005432611728	3504	Economy	11700.00
0005434878579	3504	Economy	11700.00
0005434878625	3504	Economy	11700.00
0005435126542	3504	Economy	11700.00
0005434878648	3504	Economy	11700.00
0005432183476	3504	Economy	11700.00
0005434878670	3504	Economy	11700.00
0005434938222	3504	Economy	11700.00
0005434878585	3504	Economy	11700.00
0005432611726	3504	Economy	11700.00
0005434878620	3504	Economy	11700.00
0005435126559	3504	Economy	11700.00
0005435126555	3504	Economy	11700.00
0005435126562	3504	Economy	11700.00
0005434878599	3504	Economy	11700.00
0005434878595	3504	Economy	11700.00
0005434426724	3504	Economy	11700.00
0005435126556	3504	Economy	11700.00
0005434878632	3504	Economy	11700.00
0005435126545	3504	Economy	11700.00
0005432183477	3504	Economy	11700.00
0005434878661	3504	Economy	11700.00
0005434878623	3504	Economy	11700.00
0005435913918	3504	Economy	11700.00
0005435841818	3504	Economy	11700.00
0005432613881	3504	Economy	11700.00
0005432799587	3504	Economy	11700.00
0005435126561	3504	Economy	11700.00
0005435626242	3504	Economy	11700.00
0005434426743	3504	Economy	11700.00
0005432611727	3504	Economy	11700.00
0005435626256	3504	Economy	11700.00
0005434878649	3504	Economy	11700.00
0005435902673	3504	Economy	11700.00
0005435913920	3504	Economy	11700.00
0005435126546	3504	Economy	11700.00
0005434426742	3504	Economy	11700.00
0005432799581	3504	Economy	11700.00
0005434938223	3504	Economy	11700.00
0005434878606	3504	Economy	11700.00
0005434878592	3504	Economy	11700.00
0005435126527	3504	Economy	11700.00
0005434938215	3504	Economy	11700.00
0005434878601	3504	Economy	11700.00
0005435902599	3504	Economy	11700.00
0005434878613	3504	Economy	11700.00
0005435126526	3504	Economy	11700.00
0005434878652	3504	Economy	11700.00
0005434878594	3504	Economy	11700.00
0005434878629	3504	Economy	11700.00
0005435902591	3504	Economy	11700.00
0005435626255	3504	Economy	11700.00
0005432799574	3504	Economy	11700.00
0005434878589	3504	Economy	11700.00
0005432799583	3504	Economy	11700.00
0005435902692	3504	Economy	11700.00
0005434878637	3504	Economy	11700.00
0005432188622	3504	Economy	11700.00
0005432799571	3504	Economy	11700.00
0005435626254	3504	Economy	11700.00
0005434878663	3504	Economy	11700.00
0005435126543	3504	Economy	11700.00
0005434426747	3504	Economy	11700.00
0005435126524	3504	Economy	11700.00
0005434878647	3504	Economy	11700.00
0005434426719	3504	Economy	11700.00
0005434938228	3504	Economy	11700.00
0005434878645	3504	Economy	11700.00
0005434878668	3504	Economy	11700.00
0005434938219	3504	Economy	11700.00
0005432613878	3504	Economy	11700.00
0005435626257	3504	Economy	11700.00
0005434878605	3504	Economy	11700.00
0005434426731	3504	Economy	11700.00
0005434426725	3504	Economy	11700.00
0005434878646	3504	Economy	12800.00
0005435626265	3504	Economy	11700.00
0005435902700	3504	Economy	12800.00
0005435626247	3504	Economy	12800.00
0005434426739	3504	Economy	12800.00
0005434878593	3504	Economy	12800.00
0005434426721	3504	Economy	12800.00
0005434938231	3504	Economy	11700.00
0005435902590	3504	Economy	11700.00
0005435126538	3504	Economy	11700.00
0005435126530	3504	Economy	11700.00
0005434426746	3504	Economy	11700.00
0005432799579	3504	Economy	11700.00
0005434878630	3504	Economy	11700.00
0005435126540	3504	Economy	11700.00
0005432799565	3504	Economy	11700.00
0005434426745	3504	Economy	11700.00
0005432183475	3504	Economy	11700.00
0005432799588	3504	Economy	11700.00
0005435902672	3504	Economy	11700.00
0005434878644	3504	Economy	11700.00
0005434878624	3504	Economy	11700.00
0005434878603	3504	Economy	11700.00
0005435914691	3504	Economy	11700.00
0005434426723	3504	Economy	11700.00
0005432799586	3504	Economy	11700.00
0005434878597	3504	Economy	11700.00
0005432799572	3504	Economy	11700.00
0005434938226	3504	Economy	11700.00
0005434426728	3504	Economy	11700.00
0005435126536	3504	Economy	11700.00
0005434878591	3504	Economy	11700.00
0005434878618	3504	Economy	11700.00
0005434426726	3504	Economy	11700.00
0005434426733	3504	Economy	11700.00
0005434878665	3504	Economy	11700.00
0005434426720	3504	Economy	11700.00
0005435126528	3504	Economy	11700.00
0005434878616	3504	Economy	11700.00
0005434878604	3504	Economy	11700.00
0005435626240	3504	Economy	11700.00
0005435626262	3504	Economy	11700.00
0005432613880	3504	Economy	11700.00
0005435126535	3504	Economy	11700.00
0005435126537	3504	Economy	11700.00
0005434878590	3504	Economy	11700.00
0005432799580	3504	Economy	11700.00
0005434878615	3504	Economy	11700.00
0005434938229	3504	Economy	11700.00
0005435913907	3504	Economy	11700.00
0005435126523	3504	Economy	11700.00
0005434878636	3504	Economy	11700.00
0005434878602	3504	Economy	11700.00
0005434878600	3504	Economy	11700.00
0005435626250	3504	Economy	11700.00
0005432188621	3504	Economy	11700.00
0005434878642	3504	Economy	11700.00
0005435902539	3504	Economy	11700.00
0005434878586	3504	Economy	11700.00
0005434878671	3504	Economy	11700.00
0005435126560	3504	Economy	11700.00
0005435126557	3504	Economy	11700.00
0005434878596	3504	Economy	11700.00
0005432799582	3504	Economy	11700.00
0005435913917	3504	Economy	11700.00
0005434878622	3504	Economy	11700.00
0005435126553	3504	Economy	11700.00
0005434426744	3504	Economy	11700.00
0005435126533	3504	Economy	11700.00
0005432799577	3504	Economy	11700.00
0005432799578	3504	Economy	11700.00
0005434938225	3504	Economy	11700.00
0005432799563	3504	Economy	11700.00
0005435126554	3504	Economy	11700.00
0005434938224	3504	Economy	11700.00
0005434878643	3504	Economy	11700.00
0005434878587	3504	Economy	11700.00
0005434426735	3504	Economy	11700.00
0005434426582	14547	Business	35000.00
0005432799335	14547	Business	35000.00
0005435126088	14547	Business	35000.00
0005435626060	14547	Business	35000.00
0005435126220	14547	Business	35000.00
0005434937966	14547	Business	35000.00
0005432059514	14547	Business	35000.00
0005432799261	14547	Business	35000.00
0005434878034	14547	Business	35000.00
0005434426373	14547	Business	35000.00
0005434877501	14547	Business	35000.00
0005434877767	14547	Business	35000.00
0005434426376	14547	Business	35000.00
0005435626031	14547	Business	35000.00
0005435902779	14547	Business	35000.00
0005432799251	14547	Business	35000.00
0005434877672	14547	Business	35000.00
0005435126291	14547	Business	35000.00
0005435626083	14547	Business	35000.00
0005434426530	14547	Business	35000.00
0005435126238	14547	Business	35000.00
0005434426558	14547	Comfort	19900.00
0005432059513	14547	Comfort	19900.00
0005435626054	14547	Comfort	19900.00
0005434938129	14547	Comfort	19900.00
0005432799344	14547	Comfort	19900.00
0005432799279	14547	Comfort	19900.00
0005434426374	14547	Comfort	19900.00
0005435902771	14547	Comfort	19900.00
0005435626069	14547	Comfort	19900.00
0005434878010	14547	Comfort	19900.00
0005435626052	14547	Comfort	19900.00
0005435626033	14547	Comfort	19900.00
0005434877985	14547	Comfort	19900.00
0005434878151	14547	Comfort	19900.00
0005434877381	14547	Comfort	19900.00
0005432799206	14547	Comfort	19900.00
0005434877511	14547	Comfort	19900.00
0005434426506	14547	Comfort	19900.00
0005434938121	14547	Comfort	19900.00
0005434877960	14547	Comfort	19900.00
0005434938105	14547	Comfort	19900.00
0005435626067	14547	Comfort	19900.00
0005434877570	14547	Comfort	19900.00
0005434878141	14547	Comfort	19900.00
0005432799351	14547	Comfort	19900.00
0005434877763	14547	Comfort	19900.00
0005432611696	14547	Comfort	19900.00
0005434877630	14547	Comfort	19900.00
0005435902767	14547	Comfort	19900.00
0005434938159	14547	Comfort	19900.00
0005434426425	14547	Comfort	19900.00
0005434877733	14547	Comfort	19900.00
0005435626068	14547	Economy	11700.00
0005435902768	14547	Economy	11700.00
0005432799403	14547	Economy	11700.00
0005435626066	14547	Economy	11700.00
0005434937967	14547	Economy	11700.00
0005434877754	14547	Economy	11700.00
0005434877994	14547	Economy	11700.00
0005434878013	14547	Economy	11700.00
0005434426589	14547	Economy	11700.00
0005434878020	14547	Economy	11700.00
0005434938103	14547	Economy	11700.00
0005435126011	14547	Economy	11700.00
0005434877554	14547	Economy	11700.00
0005435913945	14547	Economy	11700.00
0005432799237	14547	Economy	11700.00
0005435902775	14547	Economy	11700.00
0005434877745	14547	Economy	11700.00
0005434878160	14547	Economy	11700.00
0005434426416	14547	Economy	11700.00
0005435902778	14547	Economy	11700.00
0005435126143	14547	Economy	11700.00
0005434426412	14547	Economy	11700.00
0005434878142	14547	Economy	11700.00
0005434878060	14547	Economy	11700.00
0005434938104	14547	Economy	11700.00
0005434877885	14547	Economy	11700.00
0005435126106	14547	Economy	11700.00
0005435126047	14547	Economy	11700.00
0005434938160	14547	Economy	11700.00
0005435126209	14547	Economy	11700.00
0005435913942	14547	Economy	11700.00
0005434877953	14547	Economy	11700.00
0005434938106	14547	Economy	11700.00
0005432799375	14547	Economy	11700.00
0005434877416	14547	Economy	11700.00
0005435125971	14547	Economy	11700.00
0005435902777	14547	Economy	11700.00
0005434877520	14547	Economy	11700.00
0005434426559	14547	Economy	11700.00
0005434877739	14547	Economy	11700.00
0005434426389	14547	Economy	11700.00
0005434877762	14547	Economy	11700.00
0005435626064	14547	Economy	11700.00
0005434877961	14547	Economy	12800.00
0005435126117	14547	Economy	12800.00
0005434877850	14547	Economy	12800.00
0005434878006	14547	Economy	11700.00
0005434877929	14547	Economy	11700.00
0005435126264	14547	Economy	12800.00
0005434426417	14547	Economy	11700.00
0005434878143	14547	Economy	11700.00
0005435126136	14547	Economy	11700.00
0005432799230	14547	Economy	11700.00
0005435125956	14547	Economy	11700.00
0005435626082	14547	Economy	11700.00
0005434878283	14547	Economy	11700.00
0005434877766	14547	Economy	11700.00
0005434877973	14547	Economy	11700.00
0005435126094	14547	Economy	11700.00
0005435902769	14547	Economy	11700.00
0005435126056	14547	Economy	11700.00
0005434877983	14547	Economy	11700.00
0005434877731	14547	Economy	11700.00
0005435626034	14547	Economy	11700.00
0005434877673	14547	Economy	11700.00
0005434877524	14547	Economy	11700.00
0005434877282	14547	Economy	11700.00
0005432799314	14547	Economy	11700.00
0005432607558	14547	Economy	11700.00
0005432799329	14547	Economy	11700.00
0005434878014	14547	Economy	11700.00
0005435126133	14547	Economy	11700.00
0005434426485	14547	Economy	11700.00
0005435902781	14547	Economy	11700.00
0005432607559	14547	Economy	11700.00
0005434938056	14547	Economy	11700.00
0005434426581	14547	Economy	11700.00
0005432607546	14547	Economy	11700.00
0005434877594	14547	Economy	11700.00
0005435126113	14547	Economy	11700.00
0005432059512	14547	Economy	11700.00
0005435126201	14547	Economy	11700.00
0005434938062	14547	Economy	11700.00
0005434877683	14547	Economy	11700.00
0005432799243	14547	Economy	11700.00
0005435626050	14547	Economy	11700.00
0005434426437	14547	Economy	11700.00
0005435126144	14547	Economy	11700.00
0005435126010	14547	Economy	11700.00
0005434877867	14547	Economy	11700.00
0005435126095	14547	Economy	11700.00
0005435902770	14547	Economy	11700.00
0005435902773	14547	Economy	11700.00
0005434877838	14547	Economy	11700.00
0005434877738	14547	Economy	11700.00
0005435126140	14547	Economy	11700.00
0005435126046	14547	Economy	11700.00
0005434877593	14547	Economy	11700.00
0005435126221	14547	Economy	11700.00
0005435626081	14547	Economy	11700.00
0005435913940	14547	Economy	11700.00
0005434877716	14547	Economy	11700.00
0005434426468	14547	Economy	11700.00
0005434426486	14547	Economy	11700.00
0005434426529	14547	Economy	11700.00
0005434877552	14547	Economy	11700.00
0005435913943	14547	Economy	11700.00
0005434877906	14547	Economy	11700.00
0005432611697	14547	Economy	11700.00
0005432799305	14547	Economy	11700.00
0005434877900	14547	Economy	11700.00
0005434878061	14547	Economy	11700.00
0005434877602	14547	Economy	11700.00
0005434877484	14547	Economy	11700.00
0005432799188	14547	Economy	11700.00
0005432799233	14547	Economy	11700.00
0005434938093	14547	Economy	11700.00
0005434426556	14547	Economy	11700.00
0005435902772	14547	Economy	11700.00
0005434938094	14547	Economy	11700.00
0005434426626	14547	Economy	11700.00
0005435126108	14547	Economy	11700.00
0005435913946	14547	Economy	11700.00
0005434877986	14547	Economy	11700.00
0005435126062	14547	Economy	11700.00
0005434877523	14547	Economy	11700.00
0005435125955	14547	Economy	11700.00
0005435626053	14547	Economy	11700.00
0005435126025	14547	Economy	11700.00
0005434877700	14547	Economy	12800.00
0005434878161	14547	Economy	12800.00
0005432611690	14547	Economy	12800.00
0005435126093	14547	Economy	11700.00
0005434877855	14547	Economy	12800.00
0005434426375	14547	Economy	11700.00
0005435125940	14547	Economy	11700.00
0005434877664	14547	Economy	11700.00
0005434877851	14547	Economy	11700.00
0005434877629	14547	Economy	11700.00
0005432799399	14547	Economy	11700.00
0005435126114	14547	Economy	11700.00
0005435626048	14547	Economy	11700.00
0005432799256	14547	Economy	11700.00
0005434877732	14547	Economy	11700.00
0005434877982	14547	Economy	11700.00
0005435126200	14547	Economy	11700.00
0005434878152	14547	Economy	11700.00
0005435902780	14547	Economy	11700.00
0005432611693	14547	Economy	11700.00
0005434426388	14547	Economy	11700.00
0005434877993	14547	Economy	11700.00
0005435902776	14547	Economy	11700.00
0005434426557	14547	Economy	11700.00
0005435626027	14547	Economy	11700.00
0005434877665	14547	Economy	11700.00
0005434938119	14547	Economy	11700.00
0005434877582	14547	Economy	11700.00
0005434938122	14547	Economy	11700.00
0005434426462	14547	Economy	11700.00
0005435126107	14547	Economy	11700.00
0005434877883	14547	Economy	11700.00
0005434877903	14547	Economy	11700.00
0005435126252	14547	Economy	11700.00
0005434426625	14547	Economy	11700.00
0005434426547	14547	Economy	11700.00
0005434938073	14547	Economy	11700.00
0005434877825	14547	Economy	11700.00
0005434877826	14547	Economy	11700.00
0005435126154	14547	Economy	11700.00
0005432611698	14547	Economy	11700.00
0005434877928	14547	Economy	11700.00
0005432799257	14547	Economy	11700.00
0005435126026	14547	Economy	11700.00
0005432799315	14547	Economy	11700.00
0005435126126	14547	Economy	11700.00
0005435913944	14547	Economy	11700.00
0005434877684	14547	Economy	11700.00
0005435902784	14547	Economy	11700.00
0005435126135	14547	Economy	11700.00
0005434877506	14547	Economy	11700.00
0005432607544	14547	Economy	11700.00
0005434877981	14547	Economy	11700.00
0005435126063	14547	Economy	11700.00
0005432607557	14547	Economy	11700.00
0005432799408	14547	Economy	11700.00
0005434877533	14547	Economy	11700.00
0005435126155	14547	Economy	11700.00
0005434426366	14547	Economy	11700.00
0005435126084	14547	Economy	11700.00
0005435902774	14547	Economy	11700.00
0005434426507	14547	Economy	11700.00
0005434938127	14547	Economy	11700.00
0005435126141	14547	Economy	11700.00
0005434877734	14547	Economy	11700.00
0005432799258	14547	Economy	11700.00
0005434938082	14547	Economy	11700.00
0005434938044	14547	Economy	11700.00
0005432799407	14547	Economy	11700.00
0005432607561	14547	Economy	11700.00
0005432799302	14547	Economy	11700.00
0005434938083	14547	Economy	11700.00
0005434878035	14547	Economy	11700.00
0005434877635	14547	Economy	11700.00
0005434877571	14547	Economy	11700.00
0005432611685	14547	Economy	11700.00
0005435626059	14547	Economy	11700.00
0005435902782	14547	Economy	11700.00
0005434878044	14547	Economy	11700.00
0005434938128	14547	Economy	11700.00
0005434877553	14547	Economy	11700.00
0005434426444	14547	Economy	11700.00
0005434877601	14547	Economy	11700.00
0005434877468	14547	Economy	11700.00
0005435902783	14547	Economy	11700.00
0005432799382	14547	Economy	11700.00
0005435913941	14547	Economy	11700.00
0005435626028	14547	Economy	11700.00
0005434426590	14547	Economy	11700.00
0005434325699	3607	Economy	16300.00
0005434325697	3607	Economy	14800.00
0005434312327	3607	Economy	14800.00
0005434325700	3607	Economy	14800.00
0005434325698	3607	Economy	14800.00
0005434325692	3607	Economy	14800.00
0005435889846	3607	Economy	14800.00
0005434325701	3607	Economy	14800.00
0005434325695	3607	Economy	14800.00
0005434325696	3607	Economy	14800.00
0005434325693	3607	Economy	14800.00
0005435889870	3607	Economy	14800.00
0005434325694	3607	Economy	14800.00
0005434325702	3607	Economy	14800.00
0005434325691	3607	Economy	14800.00
0005435889878	3607	Economy	14800.00
0005435889920	15601	Economy	14800.00
0005434325662	15601	Economy	14800.00
0005434325598	15601	Economy	14800.00
0005435889921	15601	Economy	14800.00
0005434325616	15601	Economy	14800.00
0005435889919	15601	Economy	14800.00
0005435889924	15601	Economy	14800.00
0005434325625	15601	Economy	14800.00
0005434325622	15601	Economy	14800.00
0005434325628	15601	Economy	14800.00
0005434325620	15601	Economy	14800.00
0005434325629	15601	Economy	14800.00
0005435889923	15601	Economy	14800.00
0005435889922	15601	Economy	14800.00
0005435957757	634	Economy	4500.00
0005435957761	634	Economy	4100.00
0005435957759	634	Economy	4100.00
0005435957762	634	Economy	4100.00
0005435957770	634	Economy	4100.00
0005435957765	634	Economy	4100.00
0005433420378	634	Economy	4100.00
0005433420344	634	Economy	4100.00
0005433420379	634	Economy	4100.00
0005433420368	634	Economy	4100.00
0005435957763	634	Economy	4100.00
0005435957758	634	Economy	4100.00
0005433420404	634	Economy	4100.00
0005433420345	634	Economy	4100.00
0005433420377	634	Economy	4100.00
0005435957769	634	Economy	4100.00
0005435957767	634	Economy	4100.00
0005433420405	634	Economy	4100.00
0005435957768	634	Economy	4100.00
0005435957760	634	Economy	4100.00
0005433420364	634	Economy	4100.00
0005435957766	634	Economy	4100.00
0005433420362	634	Economy	4100.00
0005433420363	634	Economy	4100.00
0005435957764	634	Economy	4100.00
0005433420338	634	Economy	4100.00
0005433420299	634	Economy	4100.00
0005435957644	15199	Economy	4500.00
0005435957618	15199	Economy	4100.00
0005433420440	15199	Economy	4100.00
0005433420439	15199	Economy	4100.00
0005433420433	15199	Economy	4100.00
0005433420436	15199	Economy	4100.00
0005433420434	15199	Economy	4100.00
0005435957582	15199	Economy	4100.00
0005435957561	15199	Economy	4100.00
0005433420437	15199	Economy	4100.00
0005435957560	15199	Economy	4100.00
0005435957635	15199	Economy	4100.00
0005435957682	15199	Economy	4100.00
0005435957640	15199	Economy	4100.00
0005435957636	15199	Economy	4100.00
0005433420441	15199	Economy	4100.00
0005435957641	15199	Economy	4100.00
0005433420438	15199	Economy	4100.00
0005433420435	15199	Economy	4100.00
0005435216576	27257	Economy	28100.00
0005435219186	27257	Economy	28100.00
0005435219184	27257	Economy	28100.00
0005435219185	27257	Economy	28100.00
0005435219176	27257	Economy	25500.00
0005435219191	27257	Economy	25500.00
0005435216569	27257	Economy	25500.00
0005435219195	27257	Economy	25500.00
0005435219192	27257	Economy	25500.00
0005435216577	27257	Economy	25500.00
0005435221046	27257	Economy	25500.00
0005435219190	27257	Economy	25500.00
0005435216570	27257	Economy	25500.00
0005435219189	27257	Economy	25500.00
0005435216584	27257	Economy	25500.00
0005435219194	27257	Economy	25500.00
0005435219177	27257	Economy	25500.00
0005435217718	31782	Economy	25500.00
0005435216595	31782	Economy	25500.00
0005435218118	31782	Economy	25500.00
0005435218120	31782	Economy	25500.00
0005435216593	31782	Economy	25500.00
0005435216594	31782	Economy	25500.00
0005435216599	31782	Economy	25500.00
0005435217719	31782	Economy	25500.00
0005435218116	31782	Economy	25500.00
0005435217722	31782	Economy	25500.00
0005435217720	31782	Economy	25500.00
0005435217716	31782	Economy	25500.00
0005435216597	31782	Economy	25500.00
0005435216592	31782	Economy	25500.00
0005435217721	31782	Economy	25500.00
0005435217723	31782	Economy	25500.00
0005435216598	31782	Economy	25500.00
0005435218119	31782	Economy	25500.00
0005435217717	31782	Economy	25500.00
0005435218117	31782	Economy	25500.00
0005435216596	31782	Economy	25500.00
0005435629409	8946	Economy	10400.00
0005434247133	8946	Economy	10400.00
0005434247134	8946	Economy	10400.00
0005435629399	16095	Economy	10400.00
0005434247158	16095	Economy	10400.00
0005434247157	16095	Economy	10400.00
0005434467765	4020	Economy	23400.00
0005434467767	4020	Economy	21200.00
0005434467769	4020	Economy	21200.00
0005434467773	4020	Economy	21200.00
0005434467771	4020	Economy	21200.00
0005434467768	4020	Economy	21200.00
0005434467774	4020	Economy	21200.00
0005434467770	4020	Economy	21200.00
0005434467766	4020	Economy	21200.00
0005434467772	4020	Economy	21200.00
0005434467752	23202	Economy	21200.00
0005434467750	23202	Economy	21200.00
0005434467748	23202	Economy	21200.00
0005434467740	23202	Economy	21200.00
0005434467742	23202	Economy	21200.00
0005434467749	23202	Economy	21200.00
0005434467753	23202	Economy	21200.00
0005434467747	23202	Economy	21200.00
0005434467733	23202	Economy	21200.00
0005434467751	23202	Economy	21200.00
0005435933445	4428	Economy	13400.00
0005435163254	4428	Economy	13400.00
0005435933423	4428	Economy	12200.00
0005435163250	4428	Economy	12200.00
0005435933444	4428	Economy	12200.00
0005435163252	4428	Economy	12200.00
0005435163248	4428	Economy	12200.00
0005435933441	4428	Economy	12200.00
0005435163253	4428	Economy	12200.00
0005435163255	4428	Economy	12200.00
0005435163246	4428	Economy	12200.00
0005435163242	4428	Economy	12200.00
0005435163251	4428	Economy	12200.00
0005435163241	4428	Economy	12200.00
0005435163249	4428	Economy	12200.00
0005435933422	4428	Economy	12200.00
0005435933438	4428	Economy	12200.00
0005435163245	4428	Economy	12200.00
0005435163244	4428	Economy	12200.00
0005435933431	4428	Economy	12200.00
0005435163243	4428	Economy	12200.00
0005435933429	4428	Economy	12200.00
0005435933449	4428	Economy	12200.00
0005435933421	4428	Economy	12200.00
0005435163247	4428	Economy	12200.00
0005435163256	4428	Economy	12200.00
0005435163200	29503	Economy	12200.00
0005435933468	29503	Economy	12200.00
0005435163195	29503	Economy	12200.00
0005435933464	29503	Economy	12200.00
0005435163197	29503	Economy	12200.00
0005435163186	29503	Economy	12200.00
0005435163201	29503	Economy	12200.00
0005435933467	29503	Economy	12200.00
0005435163224	29503	Economy	12200.00
0005435163194	29503	Economy	12200.00
0005435933466	29503	Economy	12200.00
0005435933465	29503	Economy	12200.00
0005435933470	29503	Economy	12200.00
0005435933469	29503	Economy	12200.00
0005435163182	29503	Economy	12200.00
0005435163220	29503	Economy	12200.00
0005435163214	29503	Economy	12200.00
0005435229396	6843	Business	87700.00
0005432646051	6843	Business	87700.00
0005435229357	6843	Business	87700.00
0005432646031	6843	Business	87700.00
0005432646017	6843	Business	87700.00
0005432646043	6843	Business	87700.00
0005432646035	6843	Business	87700.00
0005435229422	6843	Business	87700.00
0005435229421	6843	Business	87700.00
0005435229410	6843	Business	87700.00
0005432646034	6843	Business	87700.00
0005432646023	6843	Business	87700.00
0005432646019	6843	Economy	29200.00
0005435229367	6843	Economy	29200.00
0005435229393	6843	Economy	29200.00
0005435229305	6843	Economy	29200.00
0005432646027	6843	Economy	29200.00
0005435229397	6843	Economy	29200.00
0005435229366	6843	Economy	29200.00
0005432646039	6843	Economy	29200.00
0005435229373	6843	Economy	29200.00
0005432646030	6843	Economy	29200.00
0005432646014	6843	Economy	32200.00
0005435229377	6843	Economy	32200.00
0005435229398	6843	Economy	32200.00
0005432645999	6843	Economy	32200.00
0005432646037	6843	Economy	32200.00
0005432646026	6843	Economy	29200.00
0005432646011	6843	Economy	29200.00
0005432646047	6843	Economy	29200.00
0005432646010	6843	Economy	29200.00
0005435229371	6843	Economy	29200.00
0005432646000	6843	Economy	29200.00
0005432646042	6843	Economy	29200.00
0005432646048	6843	Economy	29200.00
0005432646013	6843	Economy	29200.00
0005435229401	6843	Economy	29200.00
0005435229384	6843	Economy	29200.00
0005432646044	6843	Economy	29200.00
0005432646022	6843	Economy	29200.00
0005432646015	6843	Economy	29200.00
0005435229374	6843	Economy	29200.00
0005435229369	6843	Economy	29200.00
0005435229363	6843	Economy	29200.00
0005435229387	6843	Economy	29200.00
0005435229380	6843	Economy	29200.00
0005432646033	6843	Economy	29200.00
0005435229403	6843	Economy	29200.00
0005432646021	6843	Economy	29200.00
0005435229385	6843	Economy	29200.00
0005432646003	6843	Economy	29200.00
0005432646008	6843	Economy	29200.00
0005435229368	6843	Economy	29200.00
0005432646001	6843	Economy	29200.00
0005432646032	6843	Economy	29200.00
0005432646049	6843	Economy	29200.00
0005435229365	6843	Economy	29200.00
0005432646006	6843	Economy	29200.00
0005432646005	6843	Economy	29200.00
0005435229402	6843	Economy	29200.00
0005435229376	6843	Economy	29200.00
0005432646029	6843	Economy	29200.00
0005432646028	6843	Economy	29200.00
0005432646018	6843	Economy	29200.00
0005435229372	6843	Economy	29200.00
0005432646004	6843	Economy	29200.00
0005432646050	6843	Economy	29200.00
0005432646025	6843	Economy	29200.00
0005432646012	6843	Economy	29200.00
0005435229350	6843	Economy	29200.00
0005435229423	6843	Economy	29200.00
0005432646020	6843	Economy	29200.00
0005432646040	6843	Economy	29200.00
0005435229394	6843	Economy	29200.00
0005435229379	6843	Economy	29200.00
0005432646046	6843	Economy	29200.00
0005432646045	6843	Economy	29200.00
0005432646036	6843	Economy	29200.00
0005432646007	6843	Economy	29200.00
0005435229395	6843	Economy	29200.00
0005435229358	6843	Economy	29200.00
0005435229378	6843	Economy	29200.00
0005432646024	6843	Economy	29200.00
0005435229362	6843	Economy	29200.00
0005432646016	6843	Economy	29200.00
0005432646038	6843	Economy	29200.00
0005432646002	6843	Economy	29200.00
0005432646041	6843	Economy	29200.00
0005432646009	6843	Economy	29200.00
0005435797531	2853	Business	12600.00
0005433404780	2853	Business	12600.00
0005435797535	2853	Business	12600.00
0005435797529	2853	Business	12600.00
0005433404773	2853	Economy	4600.00
0005435797539	2853	Economy	4600.00
0005435797532	2853	Economy	4200.00
0005433404790	2853	Economy	4200.00
0005435797526	2853	Economy	4200.00
0005435797534	2853	Economy	4200.00
0005435797530	2853	Economy	4200.00
0005433404741	2853	Economy	4200.00
0005435797533	2853	Economy	4200.00
0005433404765	2853	Economy	4200.00
0005435797538	2853	Economy	4200.00
0005435797537	2853	Economy	4200.00
0005433404791	2853	Economy	4200.00
0005433404708	2853	Economy	4200.00
0005435797528	2853	Economy	4200.00
0005435797536	2853	Economy	4200.00
0005433404802	2853	Economy	4200.00
0005435797527	2853	Economy	4200.00
0005433404772	2853	Economy	4200.00
0005433404767	2853	Economy	4200.00
0005435797426	29335	Business	12600.00
0005435797413	29335	Economy	4200.00
0005433404842	29335	Economy	4200.00
0005433404841	29335	Economy	4200.00
0005435797384	29335	Economy	4200.00
0005433404839	29335	Economy	4200.00
0005435797410	29335	Economy	4200.00
0005435797411	29335	Economy	4200.00
0005435797510	29335	Economy	4200.00
0005435797462	29335	Economy	4200.00
0005435797405	29335	Economy	4200.00
0005435797511	29335	Economy	4200.00
0005435797406	29335	Economy	4200.00
0005435797424	29335	Economy	4200.00
0005435797459	29335	Economy	4200.00
0005435797421	29335	Economy	4200.00
0005435797403	29335	Economy	4200.00
0005433404840	29335	Economy	4200.00
0005435797412	29335	Economy	4200.00
0005433404838	29335	Economy	4200.00
0005435797409	29335	Economy	4200.00
0005433404843	29335	Economy	4200.00
0005435797423	29335	Economy	4200.00
0005435797463	29335	Economy	4200.00
0005435376350	5806	Economy	6800.00
0005434948054	5810	Economy	6800.00
0005434948050	5810	Economy	6800.00
0005434948053	5810	Economy	6800.00
0005434948048	5810	Economy	6800.00
0005434948051	5810	Economy	6800.00
0005434948052	5810	Economy	6800.00
0005434948049	5810	Economy	6800.00
0005434948047	5810	Economy	6800.00
0005434948046	5810	Economy	6800.00
0005434948016	16342	Economy	6800.00
0005434947959	16342	Economy	6800.00
0005434947990	16342	Economy	6800.00
0005435376360	16342	Economy	6800.00
0005434947964	16342	Economy	6800.00
0005434947986	16342	Economy	6800.00
0005434947991	16342	Economy	6800.00
0005434948015	16342	Economy	6800.00
0005435376359	16342	Economy	6800.00
0005434947987	16342	Economy	6800.00
0005434947958	16342	Economy	6800.00
0005433961158	6966	Business	21400.00
0005433961144	6966	Business	21400.00
0005433961115	6966	Business	21400.00
0005433961139	6966	Business	21400.00
0005433961145	6966	Business	21400.00
0005433961152	6966	Business	21400.00
0005433961117	6966	Business	21400.00
0005433961160	6966	Business	21400.00
0005433961122	6966	Economy	7100.00
0005433961159	6966	Economy	7100.00
0005433961119	6966	Economy	7100.00
0005433961140	6966	Economy	7100.00
0005433961162	6966	Economy	7100.00
0005433961148	6966	Economy	7800.00
0005433961116	6966	Economy	7800.00
0005433961132	6966	Economy	7800.00
0005433961114	6966	Economy	7800.00
0005433961113	6966	Economy	7100.00
0005433961149	6966	Economy	7100.00
0005433961126	6966	Economy	7100.00
0005433961138	6966	Economy	7100.00
0005433961111	6966	Economy	7100.00
0005433961147	6966	Economy	7100.00
0005433961136	6966	Economy	7100.00
0005433961127	6966	Economy	7100.00
0005433961155	6966	Economy	7100.00
0005433961137	6966	Economy	7100.00
0005433961153	6966	Economy	7100.00
0005433961124	6966	Economy	7100.00
0005433961143	6966	Economy	7100.00
0005433961141	6966	Economy	7100.00
0005433961150	6966	Economy	7100.00
0005433961134	6966	Economy	7100.00
0005433961142	6966	Economy	7100.00
0005433961121	6966	Economy	7100.00
0005433961110	6966	Economy	7100.00
0005433961123	6966	Economy	7100.00
0005433961130	6966	Economy	7100.00
0005433961163	6966	Economy	7100.00
0005433961129	6966	Economy	7100.00
0005433961120	6966	Economy	7100.00
0005433961151	6966	Economy	7100.00
0005433961131	6966	Economy	7100.00
0005433961156	6966	Economy	7100.00
0005433961135	6966	Economy	7100.00
0005433961118	6966	Economy	7100.00
0005433961112	6966	Economy	7100.00
0005433961146	6966	Economy	7100.00
0005433961164	6966	Economy	7100.00
0005433961154	6966	Economy	7100.00
0005433961161	6966	Economy	7100.00
0005433961157	6966	Economy	7100.00
0005433961133	6966	Economy	7100.00
0005433961125	6966	Economy	7100.00
0005433961128	6966	Economy	7100.00
0005433960274	25733	Business	21400.00
0005433960518	25733	Business	21400.00
0005433960364	25733	Business	21400.00
0005433960528	25733	Business	21400.00
0005433960441	25733	Economy	7100.00
0005433960429	25733	Economy	7100.00
0005433960521	25733	Economy	7100.00
0005433960527	25733	Economy	7100.00
0005433960111	25733	Economy	7100.00
0005433960423	25733	Economy	7100.00
0005433960407	25733	Economy	7800.00
0005433960574	25733	Economy	7800.00
0005433960512	25733	Economy	7800.00
0005433960391	25733	Economy	7100.00
0005433960426	25733	Economy	7100.00
0005433960475	25733	Economy	7100.00
0005433960506	25733	Economy	7100.00
0005433960480	25733	Economy	7100.00
0005433960481	25733	Economy	7100.00
0005433960069	25733	Economy	7100.00
0005433960273	25733	Economy	7100.00
0005433960432	25733	Economy	7100.00
0005433960439	25733	Economy	7100.00
0005433960513	25733	Economy	7100.00
0005433960424	25733	Economy	7100.00
0005433960421	25733	Economy	7100.00
0005433960351	25733	Economy	7100.00
0005433960520	25733	Economy	7100.00
0005433960416	25733	Economy	7100.00
0005433960278	25733	Economy	7100.00
0005433960303	25733	Economy	7100.00
0005433960442	25733	Economy	7100.00
0005433960366	25733	Economy	7100.00
0005433960548	25733	Economy	7100.00
0005433960340	25733	Economy	7100.00
0005433960563	25733	Economy	7100.00
0005433960402	25733	Economy	7100.00
0005433960552	25733	Economy	7100.00
0005433960341	25733	Economy	7100.00
0005433960397	25733	Economy	7100.00
0005433960246	25733	Economy	7100.00
0005433960551	25733	Economy	7100.00
0005433960550	25733	Economy	7100.00
0005433960417	25733	Economy	7100.00
0005433960505	25733	Economy	7100.00
0005433960450	25733	Economy	7100.00
0005433960400	25733	Economy	7100.00
0005433960399	25733	Economy	7100.00
0005433960517	25733	Economy	7100.00
0005433960549	25733	Economy	7100.00
0005433960279	25733	Economy	7100.00
0005433960352	25733	Economy	7100.00
0005433960217	25733	Economy	7100.00
0005435082755	24533	Economy	3900.00
0005435082754	24533	Economy	3900.00
0005435082715	24533	Economy	3900.00
0005435082753	24533	Economy	3900.00
0005435082765	24533	Economy	3900.00
0005435082759	24533	Economy	3900.00
0005435082761	24533	Economy	3900.00
0005435082736	24533	Economy	3900.00
0005435082760	24533	Economy	3900.00
0005435082752	24533	Economy	3900.00
0005435082737	24533	Economy	3900.00
0005435082811	26148	Economy	3900.00
0005435082806	26148	Economy	3900.00
0005435082808	26148	Economy	3900.00
0005435082804	26148	Economy	3900.00
0005435082805	26148	Economy	3900.00
0005435082807	26148	Economy	3900.00
0005435082810	26148	Economy	3900.00
0005435082812	26148	Economy	3900.00
0005435082809	26148	Economy	3900.00
0005434245113	4983	Business	18000.00
0005434245101	4983	Business	18000.00
0005434245093	4983	Business	18000.00
0005434245104	4983	Business	18000.00
0005434245089	4983	Business	18000.00
0005434245097	4983	Business	18000.00
0005435286611	4983	Business	18000.00
0005435286609	4983	Business	18000.00
0005434245094	4983	Business	18000.00
0005434245115	4983	Business	18000.00
0005434245100	4983	Economy	6600.00
0005435286584	4983	Economy	6600.00
0005434245111	4983	Economy	6000.00
0005434245108	4983	Economy	6000.00
0005434245109	4983	Economy	6000.00
0005432166914	4983	Economy	6000.00
0005434245102	4983	Economy	6000.00
0005434245091	4983	Economy	6000.00
0005433534482	4983	Economy	6000.00
0005434245107	4983	Economy	6000.00
0005434245114	4983	Economy	6000.00
0005432166916	4983	Economy	6000.00
0005435286610	4983	Economy	6000.00
0005433534483	4983	Economy	6000.00
0005435286587	4983	Economy	6000.00
0005434245096	4983	Economy	6000.00
0005435286603	4983	Economy	6000.00
0005434245086	4983	Economy	6000.00
0005434245099	4983	Economy	6000.00
0005435286601	4983	Economy	6000.00
0005434245095	4983	Economy	6600.00
0005432166913	4983	Economy	6600.00
0005434245092	4983	Economy	6000.00
0005432166915	4983	Economy	6000.00
0005434245103	4983	Economy	6000.00
0005434245090	4983	Economy	6000.00
0005434245106	4983	Economy	6000.00
0005434245087	4983	Economy	6000.00
0005434245098	4983	Economy	6000.00
0005434245112	4983	Economy	6000.00
0005435286606	4983	Economy	6000.00
0005435286588	4983	Economy	6000.00
0005434245088	4983	Economy	6000.00
0005434245110	4983	Economy	6000.00
0005434245105	4983	Economy	6000.00
0005435286602	4983	Economy	6000.00
0005433615017	4982	Business	18000.00
0005433614979	4982	Business	18000.00
0005433614966	4982	Business	18000.00
0005433785080	4982	Business	18000.00
0005433785108	4982	Business	18000.00
0005433614996	4982	Business	18000.00
0005432665282	4982	Business	18000.00
0005432105778	4982	Business	18000.00
0005433614989	4982	Business	18000.00
0005433614960	4982	Business	18000.00
0005432105786	4982	Business	18000.00
0005433615010	4982	Business	18000.00
0005433785102	4982	Business	18000.00
0005432105785	4982	Business	18000.00
0005433614972	4982	Business	18000.00
0005433785084	4982	Business	18000.00
0005433614971	4982	Business	18000.00
0005433614965	4982	Business	18000.00
0005432105780	4982	Business	18000.00
0005433615024	4982	Business	18000.00
0005432105770	4982	Business	18000.00
0005433785101	4982	Business	18000.00
0005432105764	4982	Business	18000.00
0005433785091	4982	Business	18000.00
0005432105769	4982	Business	18000.00
0005433785095	4982	Business	18000.00
0005433615026	4982	Business	18000.00
0005433614988	4982	Business	18000.00
0005433615021	4982	Economy	6600.00
0005433785109	4982	Economy	6600.00
0005433614962	4982	Economy	6600.00
0005433615027	4982	Economy	6600.00
0005433785079	4982	Economy	6600.00
0005432666398	4982	Economy	6600.00
0005432105767	4982	Economy	6000.00
0005433785103	4982	Economy	6000.00
0005433615005	4982	Economy	6000.00
0005433785092	4982	Economy	6000.00
0005433785097	4982	Economy	6000.00
0005433785081	4982	Economy	6000.00
0005433614997	4982	Economy	6000.00
0005432105739	4982	Economy	6000.00
0005432105766	4982	Economy	6000.00
0005433614961	4982	Economy	6000.00
0005433614981	4982	Economy	6000.00
0005433615031	4982	Economy	6000.00
0005432105777	4982	Economy	6000.00
0005433614968	4982	Economy	6000.00
0005433614963	4982	Economy	6000.00
0005432105744	4982	Economy	6000.00
0005433615012	4982	Economy	6000.00
0005433615025	4982	Economy	6000.00
0005433614978	4982	Economy	6000.00
0005433615015	4982	Economy	6000.00
0005432105771	4982	Economy	6000.00
0005433615013	4982	Economy	6000.00
0005433614982	4982	Economy	6000.00
0005433614964	4982	Economy	6000.00
0005433614974	4982	Economy	6000.00
0005432105750	4982	Economy	6000.00
0005433614975	4982	Economy	6000.00
0005433785093	4982	Economy	6000.00
0005433615008	4982	Economy	6000.00
0005432105741	4982	Economy	6000.00
0005432105747	4982	Economy	6000.00
0005433785078	4982	Economy	6000.00
0005433614995	4982	Economy	6000.00
0005432105784	4982	Economy	6000.00
0005433614977	4982	Economy	6000.00
0005432666397	4982	Economy	6000.00
0005433615028	4982	Economy	6000.00
0005433615023	4982	Economy	6000.00
0005432105757	4982	Economy	6000.00
0005432105742	4982	Economy	6000.00
0005433614970	4982	Economy	6000.00
0005432105743	4982	Economy	6000.00
0005432105740	4982	Economy	6000.00
0005433614980	4982	Economy	6000.00
0005432105783	4982	Economy	6000.00
0005432105765	4982	Economy	6000.00
0005433785082	4982	Economy	6000.00
0005432105760	4982	Economy	6000.00
0005433614991	4982	Economy	6000.00
0005433614969	4982	Economy	6000.00
0005432145119	4982	Economy	6000.00
0005433785107	4982	Economy	6000.00
0005433785104	4982	Economy	6000.00
0005433785098	4982	Economy	6000.00
0005433615032	4982	Economy	6000.00
0005433785088	4982	Economy	6000.00
0005432145121	4982	Economy	6000.00
0005433785086	4982	Economy	6000.00
0005433785090	4982	Economy	6000.00
0005433785087	4982	Economy	6000.00
0005433785089	4982	Economy	6600.00
0005433615020	4982	Economy	6600.00
0005433615022	4982	Economy	6600.00
0005433614994	4982	Economy	6600.00
0005432105758	4982	Economy	6600.00
0005432105759	4982	Economy	6000.00
0005433615014	4982	Economy	6000.00
0005432105746	4982	Economy	6000.00
0005432105782	4982	Economy	6000.00
0005433785077	4982	Economy	6000.00
0005433614958	4982	Economy	6600.00
0005433785100	4982	Economy	6000.00
0005433615018	4982	Economy	6000.00
0005433614976	4982	Economy	6000.00
0005433614984	4982	Economy	6000.00
0005433785106	4982	Economy	6000.00
0005432105773	4982	Economy	6000.00
0005432105788	4982	Economy	6000.00
0005433614992	4982	Economy	6000.00
0005432105755	4982	Economy	6000.00
0005433614993	4982	Economy	6000.00
0005432105762	4982	Economy	6000.00
0005433615000	4982	Economy	6000.00
0005432105781	4982	Economy	6000.00
0005433615019	4982	Economy	6000.00
0005433615003	4982	Economy	6000.00
0005432667462	4982	Economy	6000.00
0005432105751	4982	Economy	6000.00
0005433615016	4982	Economy	6000.00
0005433614998	4982	Economy	6000.00
0005433615007	4982	Economy	6000.00
0005433614985	4982	Economy	6000.00
0005433785096	4982	Economy	6000.00
0005432105776	4982	Economy	6000.00
0005432105779	4982	Economy	6000.00
0005432105749	4982	Economy	6000.00
0005432145120	4982	Economy	6000.00
0005433615009	4982	Economy	6000.00
0005432105787	4982	Economy	6000.00
0005433614967	4982	Economy	6000.00
0005433615002	4982	Economy	6000.00
0005432105772	4982	Economy	6000.00
0005433614999	4982	Economy	6000.00
0005433614959	4982	Economy	6000.00
0005433614986	4982	Economy	6000.00
0005432105761	4982	Economy	6000.00
0005432105774	4982	Economy	6000.00
0005433614983	4982	Economy	6000.00
0005432105745	4982	Economy	6000.00
0005433615030	4982	Economy	6000.00
0005433785099	4982	Economy	6000.00
0005433615004	4982	Economy	6000.00
0005432105775	4982	Economy	6000.00
0005433614973	4982	Economy	6000.00
0005432105754	4982	Economy	6000.00
0005433785094	4982	Economy	6000.00
0005433785083	4982	Economy	6000.00
0005432105756	4982	Economy	6000.00
0005433615033	4982	Economy	6000.00
0005433614990	4982	Economy	6000.00
0005433615001	4982	Economy	6000.00
0005432666396	4982	Economy	6000.00
0005433785105	4982	Economy	6000.00
0005433615011	4982	Economy	6000.00
0005433785085	4982	Economy	6000.00
0005432665283	4982	Economy	6000.00
0005432105763	4982	Economy	6000.00
0005433614987	4982	Economy	6000.00
0005432105768	4982	Economy	6000.00
0005432105753	4982	Economy	6000.00
0005433785076	4982	Economy	6000.00
0005433615029	4982	Economy	6000.00
0005432667463	4982	Economy	6000.00
0005433615006	4982	Economy	6000.00
0005432105752	4982	Economy	6000.00
0005432105748	4982	Economy	6000.00
0005435006942	4980	Business	18000.00
0005434229456	4980	Business	18000.00
0005435006876	4980	Business	18000.00
0005432335908	4980	Business	18000.00
0005434229460	4980	Business	18000.00
0005434265245	4980	Business	18000.00
0005434265238	4980	Business	18000.00
0005434265242	4980	Business	18000.00
0005434265251	4980	Business	18000.00
0005434229464	4980	Business	18000.00
0005434149782	4980	Business	18000.00
0005432335970	4980	Business	18000.00
0005432336014	4980	Business	18000.00
0005434265235	4980	Business	18000.00
0005434173537	4980	Business	18000.00
0005434229470	4980	Business	18000.00
0005435006923	4980	Business	18000.00
0005435006898	4980	Business	18000.00
0005434229463	4980	Business	18000.00
0005435006965	4980	Business	18000.00
0005434312316	4980	Business	18000.00
0005434149779	4980	Business	18000.00
0005435006878	4980	Business	18000.00
0005434229457	4980	Business	18000.00
0005435006941	4980	Business	18000.00
0005435007040	4980	Economy	6600.00
0005435007041	4980	Economy	6600.00
0005435269708	4980	Economy	6600.00
0005434229465	4980	Economy	6600.00
0005434265237	4980	Economy	6000.00
0005435006967	4980	Economy	6000.00
0005434265233	4980	Economy	6000.00
0005435269706	4980	Economy	6000.00
0005433685518	4980	Economy	6000.00
0005432335997	4980	Economy	6000.00
0005435006911	4980	Economy	6000.00
0005435269722	4980	Economy	6000.00
0005434149775	4980	Economy	6000.00
0005434149784	4980	Economy	6000.00
0005435006910	4980	Economy	6000.00
0005434229467	4980	Economy	6000.00
0005435006909	4980	Economy	6000.00
0005435269695	4980	Economy	6000.00
0005434265248	4980	Economy	6000.00
0005434265254	4980	Economy	6000.00
0005435269707	4980	Economy	6000.00
0005434265236	4980	Economy	6000.00
0005434265247	4980	Economy	6000.00
0005434229453	4980	Economy	6000.00
0005434173536	4980	Economy	6000.00
0005434265252	4980	Economy	6000.00
0005434265243	4980	Economy	6000.00
0005434149774	4980	Economy	6000.00
0005432335972	4980	Economy	6000.00
0005434149783	4980	Economy	6000.00
0005435006959	4980	Economy	6000.00
0005435269713	4980	Economy	6000.00
0005434265256	4980	Economy	6000.00
0005435006966	4980	Economy	6000.00
0005435269724	4980	Economy	6000.00
0005432335966	4980	Economy	6000.00
0005432335971	4980	Economy	6000.00
0005434229454	4980	Economy	6000.00
0005433815357	4980	Economy	6000.00
0005435006929	4980	Economy	6000.00
0005434149781	4980	Economy	6000.00
0005435269709	4980	Economy	6000.00
0005435006924	4980	Economy	6000.00
0005435269719	4980	Economy	6000.00
0005434229473	4980	Economy	6000.00
0005434229452	4980	Economy	6000.00
0005433685517	4980	Economy	6000.00
0005432335996	4980	Economy	6000.00
0005435006877	4980	Economy	6600.00
0005434229461	4980	Economy	6600.00
0005435006847	4980	Economy	6600.00
0005434149776	4980	Economy	6600.00
0005435006865	4980	Economy	6000.00
0005434149780	4980	Economy	6000.00
0005434149778	4980	Economy	6000.00
0005434229466	4980	Economy	6000.00
0005434229451	4980	Economy	6000.00
0005432336000	4980	Economy	6000.00
0005434265257	4980	Economy	6000.00
0005435006758	4980	Economy	6000.00
0005434173535	4980	Economy	6000.00
0005434229455	4980	Economy	6000.00
0005434265249	4980	Economy	6000.00
0005432335919	4980	Economy	6000.00
0005434229474	4980	Economy	6000.00
0005435006968	4980	Economy	6000.00
0005434265246	4980	Economy	6000.00
0005434229468	4980	Economy	6000.00
0005434265234	4980	Economy	6000.00
0005435269723	4980	Economy	6000.00
0005435269718	4980	Economy	6000.00
0005434149777	4980	Economy	6000.00
0005434229458	4980	Economy	6000.00
0005435006874	4980	Economy	6000.00
0005434265230	4980	Economy	6000.00
0005432335950	4980	Economy	6000.00
0005434265253	4980	Economy	6000.00
0005432335986	4980	Economy	6000.00
0005434173534	4980	Economy	6000.00
0005434229462	4980	Economy	6000.00
0005432335987	4980	Economy	6000.00
0005434265239	4980	Economy	6000.00
0005434265255	4980	Economy	6000.00
0005434229471	4980	Economy	6000.00
0005435006908	4980	Economy	6000.00
0005434229469	4980	Economy	6000.00
0005435006943	4980	Economy	6000.00
0005434229472	4980	Economy	6000.00
0005432335989	4980	Economy	6000.00
0005434229459	4980	Economy	6000.00
0005434265250	4980	Economy	6000.00
0005434265240	4980	Economy	6000.00
0005434265244	4980	Economy	6000.00
0005435269693	4980	Economy	6000.00
0005433815358	4980	Economy	6000.00
0005434265241	4980	Economy	6000.00
0005434265231	4980	Economy	6000.00
0005432335969	4980	Economy	6000.00
0005432336001	4980	Economy	6000.00
0005432335977	4980	Economy	6000.00
0005434265232	4980	Economy	6000.00
0005433784907	8530	Business	18000.00
0005434245008	8530	Business	18000.00
0005433784836	8530	Business	18000.00
0005434244827	8530	Business	18000.00
0005434244963	8530	Business	18000.00
0005434244853	8530	Business	18000.00
0005433784758	8530	Business	18000.00
0005433784834	8530	Business	18000.00
0005433784695	8530	Business	18000.00
0005434244862	8530	Business	18000.00
0005434244868	8530	Business	18000.00
0005435269770	8530	Business	18000.00
0005433784685	8530	Economy	6600.00
0005433784769	8530	Economy	6600.00
0005434244869	8530	Economy	6000.00
0005433784786	8530	Economy	6000.00
0005433784675	8530	Economy	6000.00
0005432663015	8530	Economy	6000.00
0005434244829	8530	Economy	6000.00
0005435269771	8530	Economy	6000.00
0005433784787	8530	Economy	6000.00
0005433784672	8530	Economy	6000.00
0005434244975	8530	Economy	6000.00
0005433784776	8530	Economy	6000.00
0005433784686	8530	Economy	6000.00
0005433784770	8530	Economy	6000.00
0005433784676	8530	Economy	6000.00
0005435269769	8530	Economy	6000.00
0005434245051	8530	Economy	6000.00
0005432666369	8530	Economy	6000.00
0005434244857	8530	Economy	6000.00
0005434244974	8530	Economy	6000.00
0005434244898	8530	Economy	6000.00
0005434244828	8530	Economy	6000.00
0005434244899	8530	Economy	6000.00
0005434244961	8530	Economy	6000.00
0005434244756	8530	Economy	6000.00
0005432666382	8530	Economy	6000.00
0005434244788	8530	Economy	6000.00
0005434245010	8530	Economy	6600.00
0005433784696	8530	Economy	6600.00
0005434244863	8530	Economy	6000.00
0005433784702	8530	Economy	6000.00
0005435269772	8530	Economy	6000.00
0005434244764	8530	Economy	6000.00
0005434244837	8530	Economy	6000.00
0005433784688	8530	Economy	6000.00
0005433784775	8530	Economy	6000.00
0005432666367	8530	Economy	6000.00
0005434244960	8530	Economy	6000.00
0005434244738	8530	Economy	6000.00
0005434244789	8530	Economy	6000.00
0005435269768	8530	Economy	6000.00
0005433784851	8530	Economy	6000.00
0005433784653	8530	Economy	6000.00
0005433784667	8530	Economy	6000.00
0005433784744	8530	Economy	6000.00
0005434244940	8530	Economy	6000.00
0005433784906	8530	Economy	6000.00
0005433784780	8530	Economy	6000.00
0005433784762	8530	Economy	6000.00
0005434244913	8530	Economy	6000.00
0005433784835	8530	Economy	6000.00
0005433784759	8530	Economy	6000.00
0005435269767	8530	Economy	6000.00
0005435269773	8530	Economy	6000.00
0005433784832	8530	Economy	6000.00
0005434244836	8530	Economy	6000.00
0005433784761	8530	Economy	6000.00
0005432666368	8530	Economy	6000.00
0005433784785	8530	Economy	6000.00
0005434244838	8530	Economy	6000.00
0005433784803	8530	Economy	6000.00
0005434245009	8530	Economy	6000.00
0005433614079	8531	Business	18000.00
0005433614141	8531	Business	18000.00
0005433614241	8531	Business	18000.00
0005433614391	8531	Business	18000.00
0005433614450	8531	Business	18000.00
0005433614292	8531	Business	18000.00
0005433614201	8531	Business	18000.00
0005433614323	8531	Business	18000.00
0005433614154	8531	Business	18000.00
0005433614317	8531	Business	18000.00
0005433614306	8531	Economy	6600.00
0005433614198	8531	Economy	6600.00
0005433614285	8531	Economy	6600.00
0005433614017	8531	Economy	6600.00
0005433614272	8531	Economy	6000.00
0005433614324	8531	Economy	6000.00
0005433613946	8531	Economy	6000.00
0005433614262	8531	Economy	6000.00
0005433614253	8531	Economy	6000.00
0005433614078	8531	Economy	6000.00
0005433614331	8531	Economy	6000.00
0005433614445	8531	Economy	6000.00
0005433614446	8531	Economy	6000.00
0005433614166	8531	Economy	6000.00
0005433614221	8531	Economy	6000.00
0005433614423	8531	Economy	6000.00
0005433614291	8531	Economy	6000.00
0005433614319	8531	Economy	6000.00
0005433614220	8531	Economy	6000.00
0005433614143	8531	Economy	6000.00
0005433614452	8531	Economy	6000.00
0005433614259	8531	Economy	6000.00
0005433614440	8531	Economy	6000.00
0005433614348	8531	Economy	6000.00
0005433614386	8531	Economy	6000.00
0005433614129	8531	Economy	6000.00
0005433614644	8531	Economy	6000.00
0005433614455	8531	Economy	6000.00
0005433614434	8531	Economy	6000.00
0005433614591	8531	Economy	6000.00
0005433614330	8531	Economy	6000.00
0005433614115	8531	Economy	6000.00
0005433614325	8531	Economy	6000.00
0005433614294	8531	Economy	6600.00
0005433614014	8531	Economy	6600.00
0005433614524	8531	Economy	6600.00
0005433614318	8531	Economy	6000.00
0005433613947	8531	Economy	6000.00
0005433614457	8531	Economy	6000.00
0005433614077	8531	Economy	6000.00
0005433614552	8531	Economy	6000.00
0005433614012	8531	Economy	6000.00
0005433614429	8531	Economy	6000.00
0005433614261	8531	Economy	6000.00
0005433614013	8531	Economy	6000.00
0005433614034	8531	Economy	6000.00
0005433614018	8531	Economy	6000.00
0005433614304	8531	Economy	6000.00
0005433614293	8531	Economy	6000.00
0005433614153	8531	Economy	6000.00
0005433614311	8531	Economy	6000.00
0005433614238	8531	Economy	6000.00
0005433614451	8531	Economy	6000.00
0005433614180	8531	Economy	6000.00
0005433614255	8531	Economy	6000.00
0005433614152	8531	Economy	6000.00
0005433614179	8531	Economy	6000.00
0005433614142	8531	Economy	6000.00
0005433614456	8531	Economy	6000.00
0005433614398	8531	Economy	6000.00
0005433614303	8531	Economy	6000.00
0005433614197	8531	Economy	6000.00
0005433614128	8531	Economy	6000.00
0005433614357	8531	Economy	6000.00
0005433614401	8531	Economy	6000.00
0005432035055	8532	Business	18000.00
0005434265131	8532	Business	18000.00
0005434229280	8532	Business	18000.00
0005434264915	8532	Business	18000.00
0005432035050	8532	Business	18000.00
0005432336085	8532	Business	18000.00
0005432336088	8532	Business	18000.00
0005432035065	8532	Business	18000.00
0005432047566	8532	Business	18000.00
0005434265012	8532	Business	18000.00
0005435007133	8532	Business	18000.00
0005433815406	8532	Business	18000.00
0005434229253	8532	Business	18000.00
0005434265061	8532	Business	18000.00
0005434265142	8532	Business	18000.00
0005435007127	8532	Business	18000.00
0005434149725	8532	Business	18000.00
0005433690934	8532	Business	18000.00
0005432047565	8532	Business	18000.00
0005435007123	8532	Business	18000.00
0005434229207	8532	Business	18000.00
0005434149661	8532	Business	18000.00
0005435007122	8532	Business	18000.00
0005434229301	8532	Business	18000.00
0005433815408	8532	Business	18000.00
0005432035056	8532	Business	18000.00
0005434229215	8532	Economy	6600.00
0005432035070	8532	Economy	6600.00
0005434149733	8532	Economy	6600.00
0005434264966	8532	Economy	6600.00
0005435007117	8532	Economy	6600.00
0005434265046	8532	Economy	6000.00
0005432336091	8532	Economy	6600.00
0005434264967	8532	Economy	6000.00
0005434264932	8532	Economy	6000.00
0005434173505	8532	Economy	6000.00
0005434229255	8532	Economy	6000.00
0005435007118	8532	Economy	6000.00
0005434265092	8532	Economy	6000.00
0005434265021	8532	Economy	6000.00
0005432336082	8532	Economy	6000.00
0005432336084	8532	Economy	6000.00
0005432035072	8532	Economy	6000.00
0005434149627	8532	Economy	6000.00
0005435007110	8532	Economy	6000.00
0005432336078	8532	Economy	6000.00
0005435007129	8532	Economy	6000.00
0005434229323	8532	Economy	6000.00
0005435007136	8532	Economy	6000.00
0005434149705	8532	Economy	6000.00
0005434265033	8532	Economy	6000.00
0005434265054	8532	Economy	6000.00
0005432336079	8532	Economy	6000.00
0005432035075	8532	Economy	6000.00
0005435007135	8532	Economy	6000.00
0005434173501	8532	Economy	6000.00
0005435007131	8532	Economy	6000.00
0005434265083	8532	Economy	6000.00
0005432035061	8532	Economy	6000.00
0005434173504	8532	Economy	6000.00
0005434149635	8532	Economy	6000.00
0005433815405	8532	Economy	6000.00
0005434149732	8532	Economy	6000.00
0005432035074	8532	Economy	6000.00
0005434265032	8532	Economy	6000.00
0005432336087	8532	Economy	6000.00
0005432035064	8532	Economy	6000.00
0005432035071	8532	Economy	6000.00
0005432035058	8532	Economy	6000.00
0005433688817	8532	Economy	6000.00
0005432035066	8532	Economy	6000.00
0005434229322	8532	Economy	6000.00
0005434265118	8532	Economy	6000.00
0005434149695	8532	Economy	6000.00
0005432047564	8532	Economy	6000.00
0005435007112	8532	Economy	6000.00
0005434265168	8532	Economy	6000.00
0005434265095	8532	Economy	6000.00
0005435007113	8532	Economy	6000.00
0005433688818	8532	Economy	6000.00
0005434264942	8532	Economy	6000.00
0005435007114	8532	Economy	6000.00
0005434149734	8532	Economy	6000.00
0005434149691	8532	Economy	6000.00
0005434265078	8532	Economy	6000.00
0005435007132	8532	Economy	6000.00
0005434264999	8532	Economy	6000.00
0005432035048	8532	Economy	6000.00
0005434265084	8532	Economy	6000.00
0005435007119	8532	Economy	6600.00
0005432035062	8532	Economy	6000.00
0005432035051	8532	Economy	6600.00
0005434265169	8532	Economy	6600.00
0005434149632	8532	Economy	6600.00
0005434229254	8532	Economy	6600.00
0005435007134	8532	Economy	6000.00
0005434265062	8532	Economy	6000.00
0005434229256	8532	Economy	6000.00
0005435007120	8532	Economy	6600.00
0005434149698	8532	Economy	6000.00
0005433815407	8532	Economy	6000.00
0005432035069	8532	Economy	6000.00
0005434265034	8532	Economy	6000.00
0005435007124	8532	Economy	6000.00
0005435007128	8532	Economy	6000.00
0005435007111	8532	Economy	6000.00
0005434265167	8532	Economy	6000.00
0005432035054	8532	Economy	6000.00
0005434229034	8532	Economy	6000.00
0005432336080	8532	Economy	6000.00
0005432035068	8532	Economy	6000.00
0005432035047	8532	Economy	6000.00
0005432035063	8532	Economy	6000.00
0005435007125	8532	Economy	6000.00
0005434229304	8532	Economy	6000.00
0005433534507	8532	Economy	6000.00
0005434265053	8532	Economy	6000.00
0005435007130	8532	Economy	6000.00
0005434229298	8532	Economy	6000.00
0005434229206	8532	Economy	6000.00
0005434264997	8532	Economy	6000.00
0005433690933	8532	Economy	6000.00
0005434229286	8532	Economy	6000.00
0005432336081	8532	Economy	6000.00
0005434265047	8532	Economy	6000.00
0005434229279	8532	Economy	6000.00
0005434149716	8532	Economy	6000.00
0005432035060	8532	Economy	6000.00
0005434265020	8532	Economy	6000.00
0005434265117	8532	Economy	6000.00
0005432035057	8532	Economy	6000.00
0005433689920	8532	Economy	6000.00
0005434229257	8532	Economy	6000.00
0005434265091	8532	Economy	6000.00
0005432336083	8532	Economy	6000.00
0005434229204	8532	Economy	6000.00
0005433534506	8532	Economy	6000.00
0005432035073	8532	Economy	6000.00
0005434149690	8532	Economy	6000.00
0005435007126	8532	Economy	6000.00
0005435007115	8532	Economy	6000.00
0005434265141	8532	Economy	6000.00
0005434264996	8532	Economy	6000.00
0005433689919	8532	Economy	6000.00
0005432035049	8532	Economy	6000.00
0005432047567	8532	Economy	6000.00
0005432035059	8532	Economy	6000.00
0005434149633	8532	Economy	6000.00
0005434229305	8532	Economy	6000.00
0005432336090	8532	Economy	6000.00
0005432035053	8532	Economy	6000.00
0005434149709	8532	Economy	6000.00
0005434149641	8532	Economy	6000.00
0005434265059	8532	Economy	6000.00
0005432035067	8532	Economy	6000.00
0005434264914	8532	Economy	6000.00
0005435007121	8532	Economy	6000.00
0005434264908	8532	Economy	6000.00
0005432035052	8532	Economy	6000.00
0005435007116	8532	Economy	6000.00
0005432336086	8532	Economy	6000.00
0005433815404	8532	Economy	6000.00
0005432336089	8532	Economy	6000.00
0005434639268	12595	Economy	16200.00
0005434639210	12595	Economy	16200.00
0005433202428	12595	Economy	14800.00
0005434639209	12595	Economy	14800.00
0005433202426	12595	Economy	14800.00
0005434639170	12595	Economy	14800.00
0005434639118	12595	Economy	14800.00
0005433202421	12595	Economy	14800.00
0005433202420	12595	Economy	14800.00
0005434639278	12595	Economy	14800.00
0005433202430	12595	Economy	14800.00
0005433202432	12595	Economy	14800.00
0005433202425	12595	Economy	14800.00
0005434639241	12595	Economy	14800.00
0005434639168	12595	Economy	14800.00
0005434639257	12595	Economy	14800.00
0005434639245	12595	Economy	14800.00
0005433202433	12595	Economy	14800.00
0005434639260	12595	Economy	14800.00
0005434639233	12595	Economy	14800.00
0005434639250	12595	Economy	14800.00
0005433202431	12595	Economy	14800.00
0005434639114	12595	Economy	14800.00
0005433202434	12595	Economy	14800.00
0005434639231	12595	Economy	14800.00
0005434639214	12595	Economy	14800.00
0005434639259	12595	Economy	14800.00
0005433202424	12595	Economy	14800.00
0005434639237	12595	Economy	14800.00
0005434639126	12595	Economy	14800.00
0005433202422	12595	Economy	14800.00
0005434639141	12595	Economy	14800.00
0005433202419	12595	Economy	14800.00
0005434639115	12595	Economy	14800.00
0005434639347	12595	Economy	14800.00
0005433202427	12595	Economy	14800.00
0005434639171	12595	Economy	14800.00
0005433202423	12595	Economy	14800.00
0005434639153	12595	Economy	14800.00
0005434639242	12595	Economy	14800.00
0005433202429	12595	Economy	14800.00
0005434639230	12595	Economy	14800.00
0005434639169	12595	Economy	14800.00
0005434639152	12595	Economy	14800.00
0005433202225	23394	Economy	16200.00
0005433202290	23394	Economy	16200.00
0005434639415	23394	Economy	16200.00
0005434639416	23394	Economy	14800.00
0005434639417	23394	Economy	14800.00
0005433202281	23394	Economy	14800.00
0005434639394	23394	Economy	14800.00
0005434639400	23394	Economy	14800.00
0005433202248	23394	Economy	14800.00
0005433202276	23394	Economy	14800.00
0005434639420	23394	Economy	14800.00
0005434639395	23394	Economy	14800.00
0005434639410	23394	Economy	14800.00
0005434639418	23394	Economy	14800.00
0005434639396	23394	Economy	14800.00
0005434639413	23394	Economy	14800.00
0005434639406	23394	Economy	14800.00
0005434639421	23394	Economy	14800.00
0005434639419	23394	Economy	14800.00
0005434639414	23394	Economy	14800.00
0005433202299	23394	Economy	14800.00
0005434639398	23394	Economy	14800.00
0005434639407	23394	Economy	14800.00
0005434639412	23394	Economy	14800.00
0005433202223	23394	Economy	14800.00
0005434639401	23394	Economy	14800.00
0005434639409	23394	Economy	14800.00
0005432290643	23394	Economy	14800.00
0005432290644	23394	Economy	14800.00
0005434639405	23394	Economy	14800.00
0005434639402	23394	Economy	14800.00
0005433202285	23394	Economy	14800.00
0005434639411	23394	Economy	14800.00
0005434639403	23394	Economy	14800.00
0005434639397	23394	Economy	14800.00
0005433202277	23394	Economy	14800.00
0005434639408	23394	Economy	14800.00
0005434639404	23394	Economy	14800.00
0005433202245	23394	Economy	14800.00
0005433202210	23394	Economy	14800.00
0005434639399	23394	Economy	14800.00
0005433202302	23394	Economy	14800.00
0005432328257	21097	Business	18900.00
0005432328361	21097	Business	18900.00
0005432328495	21097	Business	18900.00
0005432328416	21097	Business	18900.00
0005432328459	21097	Business	18900.00
0005432328372	21097	Business	18900.00
0005432328421	21097	Business	18900.00
0005432328474	21097	Business	18900.00
0005432382950	21097	Business	18900.00
0005432328531	21097	Business	18900.00
0005432382929	21097	Business	18900.00
0005432328395	21097	Economy	6300.00
0005432382936	21097	Economy	6300.00
0005432328498	21097	Economy	6300.00
0005432382838	21097	Economy	6300.00
0005432054316	21097	Economy	6300.00
0005432328499	21097	Economy	6300.00
0005432328348	21097	Economy	6300.00
0005432054317	21097	Economy	6300.00
0005432328466	21097	Economy	6900.00
0005432328507	21097	Economy	6900.00
0005432328420	21097	Economy	6900.00
0005432328496	21097	Economy	6900.00
0005432382862	21097	Economy	6900.00
0005432328302	21097	Economy	6300.00
0005432328296	21097	Economy	6300.00
0005432328300	21097	Economy	6300.00
0005432383120	21097	Economy	6300.00
0005432382963	21097	Economy	6300.00
0005432328583	21097	Economy	6300.00
0005432383091	21097	Economy	6300.00
0005432328407	21097	Economy	6300.00
0005432328318	21097	Economy	6300.00
0005432328255	21097	Economy	6300.00
0005432382889	21097	Economy	6300.00
0005432382964	21097	Economy	6300.00
0005432328649	21097	Economy	6300.00
0005432382907	21097	Economy	6300.00
0005432328401	21097	Economy	6300.00
0005432328378	21097	Economy	6300.00
0005432054315	21097	Economy	6300.00
0005432382826	21097	Economy	6300.00
0005432382897	21097	Economy	6300.00
0005432382962	21097	Economy	6300.00
0005432328428	21097	Economy	6300.00
0005432328347	21097	Economy	6300.00
0005432328502	21097	Economy	6300.00
0005432328422	21097	Economy	6300.00
0005432382984	21097	Economy	6300.00
0005432382861	21097	Economy	6300.00
0005432328648	21097	Economy	6300.00
0005432328408	21097	Economy	6300.00
0005432382933	21097	Economy	6300.00
0005432382935	21097	Economy	6300.00
0005432328398	21097	Economy	6300.00
0005432383065	21097	Economy	6300.00
0005432383066	21097	Economy	6300.00
0005432328519	21097	Economy	6300.00
0005432383073	21097	Economy	6300.00
0005432328400	21097	Economy	6300.00
0005432328397	21097	Economy	6300.00
0005432382911	21097	Economy	6300.00
0005432382867	21097	Economy	6300.00
0005432328620	21097	Economy	6300.00
0005432382937	21097	Economy	6300.00
0005432328563	21097	Economy	6300.00
0005432328341	21097	Economy	6300.00
0005432328582	21097	Economy	6300.00
0005432328301	21097	Economy	6300.00
0005432382868	21097	Economy	6300.00
0005432382905	21097	Economy	6300.00
0005432328575	21097	Economy	6300.00
0005432328538	21097	Economy	6300.00
0005432328427	21097	Economy	6300.00
0005432382985	21097	Economy	6300.00
0005432328469	21097	Economy	6300.00
0005432328647	21097	Economy	6300.00
0005432328454	21097	Economy	6300.00
0005432328415	21097	Economy	6300.00
0005432328394	21097	Economy	6300.00
0005432382952	21097	Economy	6300.00
0005432328373	21097	Economy	6300.00
0005432287206	31235	Business	18900.00
0005432383293	31235	Business	18900.00
0005432287205	31235	Business	18900.00
0005432328860	31235	Business	18900.00
0005432328843	31235	Business	18900.00
0005432328842	31235	Business	18900.00
0005432383288	31235	Business	18900.00
0005432328833	31235	Business	18900.00
0005432383291	31235	Business	18900.00
0005432328834	31235	Business	18900.00
0005432328866	31235	Business	18900.00
0005432383285	31235	Business	18900.00
0005432328864	31235	Economy	6300.00
0005432328858	31235	Economy	6300.00
0005432383302	31235	Economy	6300.00
0005432328831	31235	Economy	6300.00
0005432383310	31235	Economy	6300.00
0005432383290	31235	Economy	6300.00
0005432383313	31235	Economy	6300.00
0005432328859	31235	Economy	6300.00
0005432328873	31235	Economy	6900.00
0005432383314	31235	Economy	6900.00
0005432383294	31235	Economy	6900.00
0005432328855	31235	Economy	6900.00
0005432328840	31235	Economy	6300.00
0005432383316	31235	Economy	6300.00
0005432383287	31235	Economy	6300.00
0005432328853	31235	Economy	6300.00
0005432328850	31235	Economy	6300.00
0005432383306	31235	Economy	6300.00
0005432328838	31235	Economy	6300.00
0005432328837	31235	Economy	6300.00
0005432848837	31235	Economy	6300.00
0005432328844	31235	Economy	6300.00
0005432328851	31235	Economy	6300.00
0005432383296	31235	Economy	6300.00
0005432383295	31235	Economy	6300.00
0005432328869	31235	Economy	6300.00
0005432287207	31235	Economy	6300.00
0005432328832	31235	Economy	6300.00
0005432328846	31235	Economy	6300.00
0005432383299	31235	Economy	6300.00
0005432328852	31235	Economy	6300.00
0005432383305	31235	Economy	6300.00
0005432328854	31235	Economy	6300.00
0005432328865	31235	Economy	6300.00
0005432328857	31235	Economy	6300.00
0005432383307	31235	Economy	6300.00
0005432328848	31235	Economy	6300.00
0005432383282	31235	Economy	6300.00
0005432383297	31235	Economy	6300.00
0005432328870	31235	Economy	6300.00
0005432383284	31235	Economy	6300.00
0005432328835	31235	Economy	6300.00
0005432383283	31235	Economy	6300.00
0005432383281	31235	Economy	6300.00
0005432328867	31235	Economy	6300.00
0005432383315	31235	Economy	6300.00
0005432287209	31235	Economy	6300.00
0005432328876	31235	Economy	6300.00
0005432328863	31235	Economy	6300.00
0005432383286	31235	Economy	6300.00
0005432328841	31235	Economy	6300.00
0005432383289	31235	Economy	6300.00
0005432287208	31235	Economy	6300.00
0005432328847	31235	Economy	6300.00
0005432383312	31235	Economy	6300.00
0005432383303	31235	Economy	6300.00
0005432383301	31235	Economy	6300.00
0005432328836	31235	Economy	6300.00
0005432328868	31235	Economy	6300.00
0005432383280	31235	Economy	6300.00
0005432328849	31235	Economy	6300.00
0005432328856	31235	Economy	6300.00
0005432383292	31235	Economy	6300.00
0005432328862	31235	Economy	6300.00
0005432328872	31235	Economy	6300.00
0005432383309	31235	Economy	6300.00
0005432383300	31235	Economy	6300.00
0005432383279	31235	Economy	6300.00
0005432383304	31235	Economy	6300.00
0005432383298	31235	Economy	6300.00
0005432328839	31235	Economy	6300.00
0005432328874	31235	Economy	6300.00
0005432328875	31235	Economy	6300.00
0005432328861	31235	Economy	6300.00
0005432383311	31235	Economy	6300.00
0005432328871	31235	Economy	6300.00
0005432328845	31235	Economy	6300.00
0005432383308	31235	Economy	6300.00
0005433642402	2484	Business	89600.00
0005432953885	2484	Business	89600.00
0005433642401	2484	Business	89600.00
0005432953864	2484	Business	89600.00
0005433642399	2484	Business	89600.00
0005433642367	2484	Business	89600.00
0005432953901	2484	Business	89600.00
0005432953856	2484	Business	89600.00
0005433642375	2484	Economy	29900.00
0005433642376	2484	Economy	29900.00
0005432953857	2484	Economy	29900.00
0005433642398	2484	Economy	29900.00
0005432953884	2484	Economy	29900.00
0005432953892	2484	Economy	29900.00
0005432953921	2484	Economy	29900.00
0005432953853	2484	Economy	29900.00
0005433642369	2484	Economy	29900.00
0005432953931	2484	Economy	32800.00
0005432953851	2484	Economy	32800.00
0005432953852	2484	Economy	32800.00
0005433642400	2484	Economy	32800.00
0005432953886	2484	Economy	29900.00
0005433642392	2484	Economy	29900.00
0005433642405	2484	Economy	29900.00
0005433642410	2484	Economy	29900.00
0005433642387	2484	Economy	29900.00
0005433642377	2484	Economy	29900.00
0005433642384	2484	Economy	29900.00
0005432953880	2484	Economy	29900.00
0005432953904	2484	Economy	29900.00
0005433642393	2484	Economy	29900.00
0005432953896	2484	Economy	29900.00
0005432953865	2484	Economy	29900.00
0005433642391	2484	Economy	29900.00
0005433642404	2484	Economy	29900.00
0005433642368	2484	Economy	29900.00
0005432953890	2484	Economy	29900.00
0005432953877	2484	Economy	29900.00
0005432953855	2484	Economy	29900.00
0005432953881	2484	Economy	29900.00
0005432953879	2484	Economy	29900.00
0005433642371	2484	Economy	29900.00
0005432953888	2484	Economy	29900.00
0005432953910	2484	Economy	29900.00
0005433642372	2484	Economy	29900.00
0005433642406	2484	Economy	29900.00
0005433642386	2484	Economy	29900.00
0005432953911	2484	Economy	29900.00
0005433642409	2484	Economy	29900.00
0005432953891	2484	Economy	29900.00
0005433642403	2484	Economy	29900.00
0005433642370	2484	Economy	29900.00
0005432953902	2484	Economy	29900.00
0005432953895	2484	Economy	29900.00
0005433642408	2484	Economy	29900.00
0005432953900	2484	Economy	29900.00
0005433642379	2484	Economy	29900.00
0005433642389	2484	Economy	29900.00
0005433642374	2484	Economy	29900.00
0005432953897	2484	Economy	29900.00
0005433642390	2484	Economy	29900.00
0005432953903	2484	Economy	29900.00
0005432953882	2484	Economy	29900.00
0005433642411	2484	Economy	29900.00
0005433642383	2484	Economy	29900.00
0005433642395	2484	Economy	29900.00
0005433642394	2484	Economy	29900.00
0005433642381	2484	Economy	29900.00
0005433642407	2484	Economy	29900.00
0005433642382	2484	Economy	29900.00
0005433642373	2484	Economy	29900.00
0005433642385	2484	Economy	29900.00
0005432953898	2484	Economy	29900.00
0005433642397	2484	Economy	29900.00
0005432953850	2484	Economy	29900.00
0005433642378	2484	Economy	29900.00
0005433642388	2484	Economy	29900.00
0005432953887	2484	Economy	29900.00
0005433642380	2484	Economy	29900.00
0005433642396	2484	Economy	29900.00
0005432953899	2484	Economy	29900.00
0005432424582	13271	Business	12700.00
0005432424578	13271	Business	12700.00
0005432424609	13271	Business	12700.00
0005432424608	13271	Economy	4200.00
0005432424589	13271	Economy	4200.00
0005432424586	13271	Economy	4200.00
0005432424605	13271	Economy	4700.00
0005432424581	13271	Economy	4200.00
0005432424575	13271	Economy	4200.00
0005432424594	13271	Economy	4200.00
0005432424587	13271	Economy	4200.00
0005432424595	13271	Economy	4200.00
0005432424606	13271	Economy	4200.00
0005432424588	13271	Economy	4200.00
0005432424591	13271	Economy	4200.00
0005432424585	13271	Economy	4200.00
0005432424600	13271	Economy	4200.00
0005432424572	13271	Economy	4200.00
0005432424584	13271	Economy	4200.00
0005432424599	13271	Economy	4200.00
0005432424580	13271	Economy	4200.00
0005432424571	13271	Economy	4200.00
0005432424573	13271	Economy	4200.00
0005432424603	13271	Economy	4200.00
0005432424577	13271	Economy	4200.00
0005432424590	13271	Economy	4200.00
0005432424579	13271	Economy	4200.00
0005432424593	13271	Economy	4200.00
0005432424607	13271	Economy	4200.00
0005432424576	13271	Economy	4200.00
0005432424583	13271	Economy	4200.00
0005432424598	13271	Economy	4200.00
0005432424602	13271	Economy	4200.00
0005432424597	13271	Economy	4200.00
0005432424601	13271	Economy	4200.00
0005432424592	13271	Economy	4200.00
0005432424604	13271	Economy	4200.00
0005432424596	13271	Economy	4200.00
0005432424574	13271	Economy	4200.00
0005432424170	30724	Business	12700.00
0005432424175	30724	Business	12700.00
0005432424147	30724	Business	12700.00
0005432424218	30724	Business	12700.00
0005432424219	30724	Business	12700.00
0005432424014	30724	Business	12700.00
0005432424137	30724	Economy	4200.00
0005432424136	30724	Economy	4200.00
0005432424203	30724	Economy	4200.00
0005432424171	30724	Economy	4200.00
0005432424209	30724	Economy	4200.00
0005432424213	30724	Economy	4200.00
0005432424127	30724	Economy	4200.00
0005432424153	30724	Economy	4700.00
0005432424188	30724	Economy	4700.00
0005432424224	30724	Economy	4200.00
0005432424167	30724	Economy	4200.00
0005432424201	30724	Economy	4200.00
0005432424204	30724	Economy	4200.00
0005432424229	30724	Economy	4200.00
0005432424228	30724	Economy	4200.00
0005432424210	30724	Economy	4200.00
0005432424214	30724	Economy	4200.00
0005432424172	30724	Economy	4200.00
0005432424230	30724	Economy	4200.00
0005432424174	30724	Economy	4200.00
0005432424148	30724	Economy	4200.00
0005432424192	30724	Economy	4200.00
0005432424225	30724	Economy	4200.00
0005432424173	30724	Economy	4200.00
0005432424184	30724	Economy	4200.00
0005432424114	30724	Economy	4200.00
0005432424179	30724	Economy	4200.00
0005432424191	30724	Economy	4200.00
0005432424162	30724	Economy	4200.00
0005432424223	30724	Economy	4200.00
0005432424166	30724	Economy	4200.00
0005432423984	30724	Economy	4200.00
0005432424205	30724	Economy	4200.00
0005432424178	30724	Economy	4200.00
0005432424198	30724	Economy	4200.00
0005432424128	30724	Economy	4200.00
0005432424207	30724	Economy	4200.00
0005432901539	9633	Business	32600.00
0005432822231	9633	Business	32600.00
0005432901442	9633	Business	32600.00
0005432817590	9633	Business	32600.00
0005432901522	9633	Business	32600.00
0005432817601	9633	Business	32600.00
0005432817577	9633	Business	32600.00
0005432901523	9633	Business	32600.00
0005432817599	9633	Economy	10900.00
0005434157454	9633	Economy	10900.00
0005432288999	9633	Economy	10900.00
0005432817581	9633	Economy	10900.00
0005434157433	9633	Economy	10900.00
0005432822235	9633	Economy	10900.00
0005432901497	9633	Economy	11900.00
0005432817589	9633	Economy	11900.00
0005432901608	9633	Economy	11900.00
0005434186181	9633	Economy	10900.00
0005432817592	9633	Economy	10900.00
0005432817587	9633	Economy	10900.00
0005432817586	9633	Economy	10900.00
0005432901482	9633	Economy	10900.00
0005434157464	9633	Economy	10900.00
0005434186194	9633	Economy	10900.00
0005432822233	9633	Economy	10900.00
0005432817594	9633	Economy	10900.00
0005432901543	9633	Economy	10900.00
0005434157455	9633	Economy	10900.00
0005432817578	9633	Economy	10900.00
0005432901443	9633	Economy	10900.00
0005434157475	9633	Economy	10900.00
0005432901512	9633	Economy	10900.00
0005432901567	9633	Economy	10900.00
0005432817582	9633	Economy	10900.00
0005432817595	9633	Economy	10900.00
0005434186195	9633	Economy	10900.00
0005432822232	9633	Economy	10900.00
0005432817591	9633	Economy	10900.00
0005432817605	9633	Economy	10900.00
0005432817602	9633	Economy	10900.00
0005432901496	9633	Economy	10900.00
0005432817596	9633	Economy	10900.00
0005432901568	9633	Economy	10900.00
0005432817603	9633	Economy	10900.00
0005432817600	9633	Economy	10900.00
0005432817583	9633	Economy	10900.00
0005432817597	9633	Economy	10900.00
0005432817585	9633	Economy	10900.00
0005434157449	9633	Economy	10900.00
0005432288998	9633	Economy	10900.00
0005432901538	9633	Economy	10900.00
0005432817593	9633	Economy	10900.00
0005432822236	9633	Economy	10900.00
0005432817576	9633	Economy	10900.00
0005432289000	9633	Economy	10900.00
0005432817579	9633	Economy	10900.00
0005432822234	9633	Economy	10900.00
0005434448330	9633	Economy	10900.00
0005432817584	9633	Economy	10900.00
0005434448329	9633	Economy	10900.00
0005432901483	9633	Economy	10900.00
0005432901510	9633	Economy	10900.00
0005432817580	9633	Economy	10900.00
0005432822237	9633	Economy	10900.00
0005432817604	9633	Economy	10900.00
0005432901511	9633	Economy	10900.00
0005434448331	9633	Economy	10900.00
0005432901540	9633	Economy	10900.00
0005432901609	9633	Economy	10900.00
0005434157476	9633	Economy	10900.00
0005432817588	9633	Economy	10900.00
0005432817598	9633	Economy	10900.00
0005432901687	28999	Business	32600.00
0005432817356	28999	Business	32600.00
0005434448305	28999	Business	32600.00
0005432901679	28999	Business	32600.00
0005432817350	28999	Business	32600.00
0005434157515	28999	Business	32600.00
0005432817240	28999	Business	32600.00
0005432817257	28999	Business	32600.00
0005434157510	28999	Business	32600.00
0005432817354	28999	Business	32600.00
0005432822167	28999	Business	32600.00
0005432817388	28999	Economy	10900.00
0005432901677	28999	Economy	10900.00
0005432817313	28999	Economy	10900.00
0005432817309	28999	Economy	10900.00
0005432817413	28999	Economy	11900.00
0005432817293	28999	Economy	11900.00
0005432901682	28999	Economy	11900.00
0005432002085	28999	Economy	11900.00
0005432817380	28999	Economy	11900.00
0005432817397	28999	Economy	10900.00
0005434157508	28999	Economy	10900.00
0005434157516	28999	Economy	10900.00
0005432901681	28999	Economy	10900.00
0005432901684	28999	Economy	10900.00
0005432817241	28999	Economy	10900.00
0005432901671	28999	Economy	10900.00
0005432817351	28999	Economy	10900.00
0005432817322	28999	Economy	10900.00
0005432901676	28999	Economy	10900.00
0005432901674	28999	Economy	10900.00
0005432817357	28999	Economy	10900.00
0005434157514	28999	Economy	10900.00
0005432817283	28999	Economy	10900.00
0005434448309	28999	Economy	10900.00
0005434157511	28999	Economy	10900.00
0005432901675	28999	Economy	10900.00
0005432817287	28999	Economy	10900.00
0005434448304	28999	Economy	10900.00
0005434157507	28999	Economy	10900.00
0005434186210	28999	Economy	10900.00
0005434157512	28999	Economy	10900.00
0005434157509	28999	Economy	10900.00
0005432817495	28999	Economy	10900.00
0005432817221	28999	Economy	10900.00
0005432817329	28999	Economy	10900.00
0005432817265	28999	Economy	10900.00
0005432901688	28999	Economy	10900.00
0005434448300	28999	Economy	10900.00
0005432822178	28999	Economy	10900.00
0005434186208	28999	Economy	10900.00
0005432901673	28999	Economy	10900.00
0005432822182	28999	Economy	10900.00
0005432817452	28999	Economy	10900.00
0005432817321	28999	Economy	10900.00
0005432901686	28999	Economy	10900.00
0005432817349	28999	Economy	10900.00
0005432817266	28999	Economy	10900.00
0005432817308	28999	Economy	10900.00
0005434157513	28999	Economy	10900.00
0005432901683	28999	Economy	10900.00
0005432901680	28999	Economy	10900.00
0005432817256	28999	Economy	10900.00
0005432817284	28999	Economy	10900.00
0005434186209	28999	Economy	10900.00
0005434448295	28999	Economy	10900.00
0005432817437	28999	Economy	10900.00
0005432817205	28999	Economy	10900.00
0005432901672	28999	Economy	10900.00
0005432901685	28999	Economy	10900.00
0005434157517	28999	Economy	10900.00
0005432817300	28999	Economy	10900.00
0005432901678	28999	Economy	10900.00
0005432613879	15129	Economy	11000.00
0005432611730	15129	Economy	11000.00
0005435841818	15129	Economy	11000.00
0005432613878	15129	Economy	11000.00
0005432611729	15129	Economy	11000.00
0005432611727	15129	Economy	11000.00
0005432613881	15129	Economy	11000.00
0005432613877	15129	Economy	11000.00
0005432611728	15129	Economy	11000.00
0005432613880	15129	Economy	11000.00
0005432611726	15129	Economy	11000.00
0005432607546	31628	Economy	11000.00
0005432611696	31628	Economy	11000.00
0005432607561	31628	Economy	11000.00
0005432611690	31628	Economy	11000.00
0005432607558	31628	Economy	11000.00
0005432611685	31628	Economy	11000.00
0005432611693	31628	Economy	11000.00
0005432607544	31628	Economy	11000.00
0005432611697	31628	Economy	11000.00
0005432607559	31628	Economy	11000.00
0005432611698	31628	Economy	11000.00
0005432607557	31628	Economy	11000.00
0005433569261	11887	Business	105900.00
0005433569283	11887	Business	105900.00
0005432948143	11887	Business	105900.00
0005432948148	11887	Business	105900.00
0005433569264	11887	Business	105900.00
0005433569249	11887	Business	105900.00
0005432948160	11887	Business	105900.00
0005433569247	11887	Business	105900.00
0005432948098	11887	Business	105900.00
0005433569258	11887	Business	105900.00
0005433569290	11887	Business	105900.00
0005433569246	11887	Business	105900.00
0005432947996	11887	Business	105900.00
0005433569253	11887	Business	105900.00
0005432948207	11887	Business	105900.00
0005433569272	11887	Business	105900.00
0005432948180	11887	Business	105900.00
0005433569267	11887	Economy	35300.00
0005432948223	11887	Economy	35300.00
0005433569285	11887	Economy	35300.00
0005433569273	11887	Economy	35300.00
0005433569274	11887	Economy	35300.00
0005433569250	11887	Economy	35300.00
0005432948364	11887	Economy	35300.00
0005433569248	11887	Economy	35300.00
0005433569266	11887	Economy	35300.00
0005433569271	11887	Economy	35300.00
0005432948381	11887	Economy	35300.00
0005433569276	11887	Economy	38800.00
0005432948176	11887	Economy	35300.00
0005433569296	11887	Economy	38800.00
0005433569284	11887	Economy	38800.00
0005432948115	11887	Economy	38800.00
0005433569243	11887	Economy	35300.00
0005433569298	11887	Economy	35300.00
0005433569245	11887	Economy	35300.00
0005432948218	11887	Economy	35300.00
0005433569299	11887	Economy	35300.00
0005432948365	11887	Economy	35300.00
0005432948053	11887	Economy	35300.00
0005433569277	11887	Economy	35300.00
0005433569288	11887	Economy	35300.00
0005432948142	11887	Economy	35300.00
0005432948256	11887	Economy	35300.00
0005433569280	11887	Economy	35300.00
0005433569269	11887	Economy	35300.00
0005432948224	11887	Economy	35300.00
0005432948126	11887	Economy	35300.00
0005433569281	11887	Economy	35300.00
0005433569289	11887	Economy	35300.00
0005432948242	11887	Economy	35300.00
0005433569294	11887	Economy	35300.00
0005432948308	11887	Economy	35300.00
0005433569257	11887	Economy	35300.00
0005432948116	11887	Economy	35300.00
0005433569265	11887	Economy	35300.00
0005432948246	11887	Economy	35300.00
0005432948210	11887	Economy	35300.00
0005432948193	11887	Economy	35300.00
0005432948247	11887	Economy	35300.00
0005433569282	11887	Economy	35300.00
0005433569244	11887	Economy	35300.00
0005433569275	11887	Economy	35300.00
0005432948206	11887	Economy	35300.00
0005432948137	11887	Economy	35300.00
0005433569270	11887	Economy	35300.00
0005432948329	11887	Economy	35300.00
0005433569254	11887	Economy	35300.00
0005433569252	11887	Economy	35300.00
0005432948057	11887	Economy	35300.00
0005432948297	11887	Economy	35300.00
0005432948162	11887	Economy	35300.00
0005432948192	11887	Economy	35300.00
0005433569293	11887	Economy	35300.00
0005432948136	11887	Economy	35300.00
0005433569263	11887	Economy	35300.00
0005433569286	11887	Economy	35300.00
0005432948202	11887	Economy	35300.00
0005433569260	11887	Economy	35300.00
0005432948175	11887	Economy	35300.00
0005432948309	11887	Economy	35300.00
0005432948298	11887	Economy	35300.00
0005433569268	11887	Economy	35300.00
0005433569255	11887	Economy	35300.00
0005432948132	11887	Economy	35300.00
0005433569297	11887	Economy	35300.00
0005432948161	11887	Economy	35300.00
0005433569291	11887	Economy	35300.00
0005432948187	11887	Economy	35300.00
0005432948153	11887	Economy	35300.00
0005433569278	11887	Economy	35300.00
0005433569259	11887	Economy	35300.00
0005433569292	11887	Economy	35300.00
0005433569287	11887	Economy	35300.00
0005433569279	11887	Economy	35300.00
0005433569251	11887	Economy	35300.00
0005432948296	11887	Economy	35300.00
0005433569262	11887	Economy	35300.00
0005432948152	11887	Economy	35300.00
0005433569256	11887	Economy	35300.00
0005432948203	11887	Economy	35300.00
0005432948313	11887	Economy	35300.00
0005432948179	11887	Economy	35300.00
0005433569242	11887	Economy	35300.00
0005432948163	11887	Economy	35300.00
0005433569295	11887	Economy	35300.00
0005433568613	25284	Business	105900.00
0005433568919	25284	Business	105900.00
0005432948663	25284	Business	105900.00
0005432948661	25284	Business	105900.00
0005433568867	25284	Business	105900.00
0005432948646	25284	Business	105900.00
0005433568883	25284	Business	105900.00
0005433568717	25284	Business	105900.00
0005433568882	25284	Business	105900.00
0005432948675	25284	Business	105900.00
0005433568500	25284	Business	105900.00
0005432948670	25284	Business	105900.00
0005433568739	25284	Business	105900.00
0005433568607	25284	Business	105900.00
0005433568511	25284	Business	105900.00
0005433568693	25284	Business	105900.00
0005433568923	25284	Business	105900.00
0005433568605	25284	Business	105900.00
0005433568828	25284	Business	105900.00
0005433568809	25284	Business	105900.00
0005432948665	25284	Economy	35300.00
0005432948673	25284	Economy	35300.00
0005432948674	25284	Economy	35300.00
0005432948648	25284	Economy	35300.00
0005433568608	25284	Economy	35300.00
0005433568678	25284	Economy	35300.00
0005433568510	25284	Economy	35300.00
0005433568458	25284	Economy	35300.00
0005433568782	25284	Economy	35300.00
0005432948660	25284	Economy	35300.00
0005432948666	25284	Economy	35300.00
0005433568837	25284	Economy	38800.00
0005432948659	25284	Economy	38800.00
0005432948679	25284	Economy	38800.00
0005432948656	25284	Economy	35300.00
0005432948662	25284	Economy	35300.00
0005433568668	25284	Economy	35300.00
0005433568955	25284	Economy	35300.00
0005432948653	25284	Economy	35300.00
0005432948672	25284	Economy	35300.00
0005432948669	25284	Economy	35300.00
0005433568596	25284	Economy	35300.00
0005433568665	25284	Economy	35300.00
0005432948649	25284	Economy	35300.00
0005432948651	25284	Economy	35300.00
0005433568688	25284	Economy	35300.00
0005433568913	25284	Economy	35300.00
0005433568945	25284	Economy	35300.00
0005433568631	25284	Economy	35300.00
0005432948657	25284	Economy	35300.00
0005433568967	25284	Economy	35300.00
0005433568694	25284	Economy	35300.00
0005432948647	25284	Economy	35300.00
0005433568986	25284	Economy	35300.00
0005433568658	25284	Economy	35300.00
0005433568551	25284	Economy	35300.00
0005433568947	25284	Economy	35300.00
0005432948650	25284	Economy	35300.00
0005433568499	25284	Economy	35300.00
0005433568384	25284	Economy	35300.00
0005432948678	25284	Economy	35300.00
0005432948644	25284	Economy	35300.00
0005433568783	25284	Economy	35300.00
0005433568612	25284	Economy	35300.00
0005432948643	25284	Economy	35300.00
0005432948671	25284	Economy	35300.00
0005433568838	25284	Economy	35300.00
0005433568728	25284	Economy	35300.00
0005433568821	25284	Economy	35300.00
0005432948677	25284	Economy	35300.00
0005432948640	25284	Economy	35300.00
0005432948664	25284	Economy	35300.00
0005433568556	25284	Economy	35300.00
0005433568876	25284	Economy	35300.00
0005432948652	25284	Economy	35300.00
0005433568823	25284	Economy	35300.00
0005433568674	25284	Economy	35300.00
0005432948641	25284	Economy	35300.00
0005433568946	25284	Economy	35300.00
0005433568924	25284	Economy	35300.00
0005432948680	25284	Economy	35300.00
0005433568677	25284	Economy	35300.00
0005433568895	25284	Economy	35300.00
0005433568830	25284	Economy	35300.00
0005433568985	25284	Economy	35300.00
0005433568829	25284	Economy	35300.00
0005433568789	25284	Economy	35300.00
0005432948668	25284	Economy	35300.00
0005433568661	25284	Economy	35300.00
0005432948645	25284	Economy	35300.00
0005432948667	25284	Economy	35300.00
0005433568914	25284	Economy	35300.00
0005433568427	25284	Economy	35300.00
0005432948658	25284	Economy	35300.00
0005432948655	25284	Economy	35300.00
0005432948676	25284	Economy	35300.00
0005432948654	25284	Economy	35300.00
0005433568660	25284	Economy	35300.00
0005432948642	25284	Economy	35300.00
0005433568683	25284	Economy	35300.00
0005433568700	25284	Economy	35300.00
0005433568922	25284	Economy	35300.00
0005433568774	25284	Economy	35300.00
0005433812885	14463	Business	117400.00
0005433808352	14463	Business	117400.00
0005432430873	14463	Business	117400.00
0005432430876	14463	Business	117400.00
0005433812884	14463	Business	117400.00
0005433808360	14463	Business	117400.00
0005432430874	14463	Business	117400.00
0005433812892	14463	Business	117400.00
0005433808374	14463	Business	117400.00
0005432430880	14463	Economy	39100.00
0005433812890	14463	Economy	39100.00
0005433808362	14463	Economy	39100.00
0005434026714	14463	Economy	39100.00
0005433808336	14463	Economy	39100.00
0005432430877	14463	Economy	39100.00
0005432430878	14463	Economy	39100.00
0005433808359	14463	Economy	39100.00
0005434026713	14463	Economy	39100.00
0005432430875	14463	Economy	39100.00
0005432430882	14463	Economy	39100.00
0005433808338	14463	Economy	39100.00
0005433808337	14463	Economy	39100.00
0005433812891	14463	Economy	39100.00
0005432430879	14463	Economy	39100.00
0005433812889	14463	Economy	39100.00
0005433808355	14463	Economy	39100.00
0005433808351	14463	Economy	39100.00
0005433812888	14463	Economy	39100.00
0005432430881	14463	Economy	39100.00
0005432430872	14463	Economy	39100.00
0005433808363	14463	Economy	39100.00
0005433808361	14463	Economy	39100.00
0005433808373	14463	Economy	39100.00
0005434026712	14463	Economy	39100.00
0005434026711	14463	Economy	39100.00
0005433808375	14463	Economy	39100.00
0005434026710	14463	Economy	39100.00
0005434026709	14463	Economy	39100.00
0005433812900	30823	Business	117400.00
0005433808392	30823	Business	117400.00
0005433808387	30823	Business	117400.00
0005434026677	30823	Business	117400.00
0005433808385	30823	Business	117400.00
0005433812901	30823	Economy	39100.00
0005433808380	30823	Economy	39100.00
0005433808391	30823	Economy	39100.00
0005434026683	30823	Economy	39100.00
0005432430835	30823	Economy	39100.00
0005433812902	30823	Economy	39100.00
0005432430851	30823	Economy	43000.00
0005432430828	30823	Economy	43000.00
0005434026696	30823	Economy	39100.00
0005433808388	30823	Economy	39100.00
0005433812905	30823	Economy	39100.00
0005433812899	30823	Economy	39100.00
0005432430834	30823	Economy	39100.00
0005432430832	30823	Economy	39100.00
0005434026685	30823	Economy	39100.00
0005433812908	30823	Economy	39100.00
0005432430850	30823	Economy	39100.00
0005433812904	30823	Economy	39100.00
0005432430840	30823	Economy	39100.00
0005433808390	30823	Economy	39100.00
0005433812906	30823	Economy	39100.00
0005432430843	30823	Economy	39100.00
0005433808384	30823	Economy	39100.00
0005432430836	30823	Economy	39100.00
0005434026686	30823	Economy	39100.00
0005433808381	30823	Economy	39100.00
0005432430837	30823	Economy	39100.00
0005432430827	30823	Economy	39100.00
0005433812903	30823	Economy	39100.00
0005432430839	30823	Economy	39100.00
0005433808386	30823	Economy	39100.00
0005433808383	30823	Economy	39100.00
0005433808389	30823	Economy	39100.00
0005433812909	30823	Economy	39100.00
0005434026678	30823	Economy	39100.00
0005432430838	30823	Economy	39100.00
0005433812907	30823	Economy	39100.00
0005432430847	30823	Economy	39100.00
0005433808379	30823	Economy	39100.00
0005433808382	30823	Economy	39100.00
0005434654798	5407	Business	67200.00
0005434654812	5407	Business	67200.00
0005435340203	5407	Business	67200.00
0005434654791	5407	Business	67200.00
0005432114215	5407	Business	67200.00
0005434654796	5407	Business	67200.00
0005434654799	5407	Economy	22400.00
0005435555357	5407	Economy	22400.00
0005435340171	5407	Economy	22400.00
0005434654811	5407	Economy	22400.00
0005434654792	5407	Economy	22400.00
0005434654802	5407	Economy	22400.00
0005434654788	5407	Economy	22400.00
0005434654790	5407	Economy	22400.00
0005435340152	5407	Economy	24600.00
0005435340180	5407	Economy	22400.00
0005434654804	5407	Economy	22400.00
0005435340174	5407	Economy	22400.00
0005435340201	5407	Economy	22400.00
0005434654810	5407	Economy	22400.00
0005434654815	5407	Economy	22400.00
0005434654807	5407	Economy	22400.00
0005434654809	5407	Economy	22400.00
0005435555364	5407	Economy	22400.00
0005435340111	5407	Economy	22400.00
0005434654816	5407	Economy	22400.00
0005434654805	5407	Economy	22400.00
0005434654797	5407	Economy	22400.00
0005435340204	5407	Economy	22400.00
0005435340112	5407	Economy	22400.00
0005435340173	5407	Economy	22400.00
0005435340211	5407	Economy	22400.00
0005432114216	5407	Economy	22400.00
0005435340194	5407	Economy	22400.00
0005435340208	5407	Economy	22400.00
0005435340200	5407	Economy	22400.00
0005435555356	5407	Economy	22400.00
0005434654806	5407	Economy	22400.00
0005434654813	5407	Economy	22400.00
0005434656564	5407	Economy	22400.00
0005435555363	5407	Economy	22400.00
0005434654801	5407	Economy	22400.00
0005435340176	5407	Economy	22400.00
0005434654800	5407	Economy	22400.00
0005435340196	5407	Economy	22400.00
0005434656565	5407	Economy	22400.00
0005434654793	5407	Economy	22400.00
0005434654789	5407	Economy	22400.00
0005434654814	5407	Economy	22400.00
0005435340209	5407	Economy	22400.00
0005434654808	5407	Economy	22400.00
0005434654803	5407	Economy	22400.00
0005432114217	5407	Economy	22400.00
0005434654795	5407	Economy	22400.00
0005434654794	5407	Economy	22400.00
0005435340327	12556	Business	67200.00
0005435340318	12556	Business	67200.00
0005435340317	12556	Business	67200.00
0005434654559	12556	Business	67200.00
0005434654532	12556	Business	67200.00
0005435340326	12556	Business	67200.00
0005435340320	12556	Economy	22400.00
0005434654435	12556	Economy	22400.00
0005435340324	12556	Economy	24600.00
0005435555381	12556	Economy	24600.00
0005434654502	12556	Economy	24600.00
0005435340329	12556	Economy	22400.00
0005434654539	12556	Economy	22400.00
0005434654572	12556	Economy	22400.00
0005434654533	12556	Economy	22400.00
0005434654561	12556	Economy	22400.00
0005434654558	12556	Economy	22400.00
0005435340322	12556	Economy	22400.00
0005434654595	12556	Economy	22400.00
0005434654560	12556	Economy	22400.00
0005435340332	12556	Economy	22400.00
0005434654617	12556	Economy	22400.00
0005434654616	12556	Economy	22400.00
0005434654434	12556	Economy	22400.00
0005434654527	12556	Economy	22400.00
0005434654451	12556	Economy	22400.00
0005435340328	12556	Economy	22400.00
0005435340331	12556	Economy	22400.00
0005435555379	12556	Economy	22400.00
0005434654450	12556	Economy	22400.00
0005435340319	12556	Economy	22400.00
0005434654553	12556	Economy	22400.00
0005434654635	12556	Economy	22400.00
0005434654511	12556	Economy	22400.00
0005434654485	12556	Economy	22400.00
0005434654566	12556	Economy	22400.00
0005435340325	12556	Economy	22400.00
0005435340330	12556	Economy	22400.00
0005434654588	12556	Economy	22400.00
0005434654600	12556	Economy	22400.00
0005435340323	12556	Economy	22400.00
0005434654494	12556	Economy	22400.00
0005435555380	12556	Economy	22400.00
0005434654540	12556	Economy	22400.00
0005435340321	12556	Economy	22400.00
0005435340316	12556	Economy	22400.00
0005434654594	12556	Economy	22400.00
0005433716169	7438	Business	32000.00
0005433716148	7438	Business	32000.00
0005433716161	7438	Business	32000.00
0005433716186	7438	Business	32000.00
0005433716189	7438	Business	32000.00
0005435266126	7438	Business	32000.00
0005433722241	7438	Economy	10700.00
0005435266123	7438	Economy	10700.00
0005433716174	7438	Economy	10700.00
0005435266110	7438	Economy	10700.00
0005433722242	7438	Economy	10700.00
0005433716173	7438	Economy	10700.00
0005433656680	7438	Economy	10700.00
0005433716163	7438	Economy	10700.00
0005432428900	7438	Economy	10700.00
0005433719150	7438	Economy	10700.00
0005433690932	7438	Economy	10700.00
0005433716155	7438	Economy	10700.00
0005433716152	7438	Economy	10700.00
0005433716168	7438	Economy	10700.00
0005433722240	7438	Economy	10700.00
0005433689917	7438	Economy	10700.00
0005433716146	7438	Economy	10700.00
0005433722238	7438	Economy	10700.00
0005433722243	7438	Economy	10700.00
0005433716185	7438	Economy	10700.00
0005433716172	7438	Economy	10700.00
0005435266125	7438	Economy	10700.00
0005433716153	7438	Economy	10700.00
0005433716150	7438	Economy	10700.00
0005433716171	7438	Economy	10700.00
0005432428890	7438	Economy	10700.00
0005433688815	7438	Economy	10700.00
0005433716145	7438	Economy	10700.00
0005432428914	7438	Economy	10700.00
0005433716158	7438	Economy	11700.00
0005433716178	7438	Economy	11700.00
0005433716165	7438	Economy	11700.00
0005435266122	7438	Economy	11700.00
0005432428902	7438	Economy	11700.00
0005433719153	7438	Economy	11700.00
0005433716180	7438	Economy	10700.00
0005435266131	7438	Economy	10700.00
0005432428901	7438	Economy	10700.00
0005433716159	7438	Economy	10700.00
0005433716191	7438	Economy	10700.00
0005433716184	7438	Economy	10700.00
0005433716147	7438	Economy	10700.00
0005432428891	7438	Economy	10700.00
0005433716151	7438	Economy	10700.00
0005433716160	7438	Economy	10700.00
0005433688816	7438	Economy	10700.00
0005433716183	7438	Economy	10700.00
0005433656683	7438	Economy	10700.00
0005432078132	7438	Economy	10700.00
0005435266112	7438	Economy	10700.00
0005433716162	7438	Economy	10700.00
0005433716187	7438	Economy	10700.00
0005432078128	7438	Economy	10700.00
0005433719151	7438	Economy	10700.00
0005432078129	7438	Economy	10700.00
0005433716156	7438	Economy	10700.00
0005433716144	7438	Economy	10700.00
0005433716149	7438	Economy	10700.00
0005433722239	7438	Economy	10700.00
0005433719152	7438	Economy	10700.00
0005433716164	7438	Economy	10700.00
0005433716177	7438	Economy	10700.00
0005435266119	7438	Economy	10700.00
0005433716143	7438	Economy	10700.00
0005433716182	7438	Economy	10700.00
0005433716154	7438	Economy	10700.00
0005433716176	7438	Economy	10700.00
0005433716166	7438	Economy	10700.00
0005433716190	7438	Economy	10700.00
0005433722244	7438	Economy	10700.00
0005432078131	7438	Economy	10700.00
0005433716188	7438	Economy	10700.00
0005433656681	7438	Economy	10700.00
0005433716170	7438	Economy	10700.00
0005433656682	7438	Economy	10700.00
0005432078130	7438	Economy	10700.00
0005433722245	7438	Economy	10700.00
0005433716142	7438	Economy	10700.00
0005433716157	7438	Economy	10700.00
0005433689918	7438	Economy	10700.00
0005433716167	7438	Economy	10700.00
0005433716179	7438	Economy	10700.00
0005433716175	7438	Economy	10700.00
0005433716181	7438	Economy	10700.00
0005435266120	7438	Economy	10700.00
0005433722237	7438	Economy	10700.00
0005433656647	29219	Business	32000.00
0005433715762	29219	Business	32000.00
0005433715686	29219	Business	32000.00
0005433715932	29219	Business	32000.00
0005433715716	29219	Business	32000.00
0005432428942	29219	Business	32000.00
0005433715750	29219	Business	32000.00
0005433715650	29219	Business	32000.00
0005433715721	29219	Economy	10700.00
0005433715717	29219	Economy	10700.00
0005433715536	29219	Economy	10700.00
0005433715673	29219	Economy	10700.00
0005433715751	29219	Economy	10700.00
0005433715672	29219	Economy	10700.00
0005433715967	29219	Economy	10700.00
0005433715767	29219	Economy	10700.00
0005433715859	29219	Economy	10700.00
0005433715692	29219	Economy	10700.00
0005433715623	29219	Economy	10700.00
0005433719117	29219	Economy	10700.00
0005433715579	29219	Economy	10700.00
0005433715902	29219	Economy	10700.00
0005433715469	29219	Economy	10700.00
0005433685518	29219	Economy	10700.00
0005433715736	29219	Economy	10700.00
0005433715759	29219	Economy	10700.00
0005433715757	29219	Economy	10700.00
0005433715843	29219	Economy	10700.00
0005433719138	29219	Economy	10700.00
0005433715680	29219	Economy	10700.00
0005433715885	29219	Economy	10700.00
0005433656653	29219	Economy	10700.00
0005433715808	29219	Economy	10700.00
0005432006774	29219	Economy	10700.00
0005433715748	29219	Economy	10700.00
0005432006773	29219	Economy	10700.00
0005433715931	29219	Economy	10700.00
0005433715597	29219	Economy	11700.00
0005433715508	29219	Economy	11700.00
0005433715747	29219	Economy	11700.00
0005433715730	29219	Economy	10700.00
0005433715758	29219	Economy	10700.00
0005433715968	29219	Economy	10700.00
0005433715824	29219	Economy	10700.00
0005433715822	29219	Economy	10700.00
0005433715705	29219	Economy	10700.00
0005433715842	29219	Economy	10700.00
0005433715847	29219	Economy	10700.00
0005433719130	29219	Economy	10700.00
0005433715854	29219	Economy	10700.00
0005433685517	29219	Economy	10700.00
0005433715809	29219	Economy	10700.00
0005433715468	29219	Economy	10700.00
0005433715520	29219	Economy	10700.00
0005433719119	29219	Economy	10700.00
0005433715760	29219	Economy	10700.00
0005433715856	29219	Economy	10700.00
0005433715827	29219	Economy	10700.00
0005432428943	29219	Economy	10700.00
0005433715971	29219	Economy	10700.00
0005433715683	29219	Economy	10700.00
0005433719116	29219	Economy	10700.00
0005433722170	29219	Economy	10700.00
0005433719127	29219	Economy	10700.00
0005432006772	29219	Economy	10700.00
0005432428944	29219	Economy	10700.00
0005432006771	29219	Economy	10700.00
0005433715884	29219	Economy	10700.00
0005433715682	29219	Economy	10700.00
0005433715702	29219	Economy	10700.00
0005433715855	29219	Economy	10700.00
0005433715701	29219	Economy	10700.00
0005433715761	29219	Economy	10700.00
0005433656634	29219	Economy	10700.00
0005433715814	29219	Economy	10700.00
0005433715681	29219	Economy	10700.00
0005433715915	29219	Economy	10700.00
0005433715549	29219	Economy	10700.00
0005433715582	29219	Economy	10700.00
0005433715725	29219	Economy	10700.00
0005433715596	29219	Economy	10700.00
0005433715815	29219	Economy	10700.00
0005433719139	29219	Economy	10700.00
0005433715467	29219	Economy	10700.00
0005433715825	29219	Economy	10700.00
0005433715882	29219	Economy	10700.00
0005433715844	29219	Economy	10700.00
0005433715834	29219	Economy	10700.00
0005433715749	29219	Economy	10700.00
0005433656645	29219	Economy	10700.00
0005434095327	8654	Business	36500.00
0005434182096	8654	Business	36500.00
0005434095330	8654	Business	36500.00
0005434095329	8654	Business	36500.00
0005434095338	8654	Business	36500.00
0005434095332	8654	Business	36500.00
0005434095339	8654	Economy	12200.00
0005434095325	8654	Economy	13400.00
0005434182105	8654	Economy	13400.00
0005434182160	8654	Economy	12200.00
0005434182115	8654	Economy	12200.00
0005434095337	8654	Economy	12200.00
0005434182150	8654	Economy	12200.00
0005434095328	8654	Economy	12200.00
0005434182121	8654	Economy	12200.00
0005434182177	8654	Economy	12200.00
0005434095331	8654	Economy	12200.00
0005434095333	8654	Economy	12200.00
0005434182151	8654	Economy	12200.00
0005434095335	8654	Economy	12200.00
0005434182116	8654	Economy	12200.00
0005434095336	8654	Economy	12200.00
0005434182090	8654	Economy	12200.00
0005434095334	8654	Economy	12200.00
0005434095326	8654	Economy	12200.00
0005434182238	11626	Business	36500.00
0005434095217	11626	Business	36500.00
0005434095208	11626	Business	36500.00
0005434095225	11626	Economy	12200.00
0005434095246	11626	Economy	13400.00
0005434183586	11626	Economy	13400.00
0005434095245	11626	Economy	12200.00
0005434095207	11626	Economy	12200.00
0005434182237	11626	Economy	12200.00
0005434182233	11626	Economy	12200.00
0005434182234	11626	Economy	12200.00
0005434182230	11626	Economy	12200.00
0005434182236	11626	Economy	12200.00
0005434095268	11626	Economy	12200.00
0005434182231	11626	Economy	12200.00
0005434182239	11626	Economy	12200.00
0005434182240	11626	Economy	12200.00
0005434095218	11626	Economy	12200.00
0005434095236	11626	Economy	12200.00
0005434095291	11626	Economy	12200.00
0005434095238	11626	Economy	12200.00
0005434182232	11626	Economy	12200.00
0005434095224	11626	Economy	12200.00
0005434095237	11626	Economy	12200.00
0005434184672	11626	Economy	12200.00
0005434143721	11626	Economy	12200.00
0005434095239	11626	Economy	12200.00
0005434095195	11626	Economy	12200.00
0005434182229	11626	Economy	12200.00
0005434184671	11626	Economy	12200.00
0005434095219	11626	Economy	12200.00
0005434182235	11626	Economy	12200.00
0005433397913	1439	Business	33000.00
0005433397590	1439	Business	33000.00
0005435732382	1439	Business	33000.00
0005433397810	1439	Business	33000.00
0005433397803	1439	Business	33000.00
0005433397747	1439	Business	33000.00
0005435732368	1439	Business	33000.00
0005435732388	1439	Business	33000.00
0005432906534	1439	Business	33000.00
0005435732370	1439	Economy	11000.00
0005433397997	1439	Economy	11000.00
0005433397925	1439	Economy	11000.00
0005435732379	1439	Economy	11000.00
0005433456986	1439	Economy	11000.00
0005433397904	1439	Economy	12100.00
0005433397833	1439	Economy	12100.00
0005435732375	1439	Economy	12100.00
0005433397735	1439	Economy	11000.00
0005435732367	1439	Economy	11000.00
0005433397652	1439	Economy	11000.00
0005433397915	1439	Economy	11000.00
0005435732380	1439	Economy	11000.00
0005433397922	1439	Economy	11000.00
0005433397927	1439	Economy	11000.00
0005435732389	1439	Economy	11000.00
0005433397983	1439	Economy	11000.00
0005433397897	1439	Economy	11000.00
0005435732385	1439	Economy	11000.00
0005433397737	1439	Economy	11000.00
0005433397928	1439	Economy	11000.00
0005433398004	1439	Economy	11000.00
0005433397795	1439	Economy	11000.00
0005433456984	1439	Economy	11000.00
0005435732372	1439	Economy	11000.00
0005433398022	1439	Economy	11000.00
0005435732374	1439	Economy	11000.00
0005435732378	1439	Economy	11000.00
0005435732387	1439	Economy	11000.00
0005435732366	1439	Economy	11000.00
0005433397921	1439	Economy	11000.00
0005433397829	1439	Economy	11000.00
0005433397919	1439	Economy	11000.00
0005433456987	1439	Economy	11000.00
0005433397769	1439	Economy	11000.00
0005435732377	1439	Economy	11000.00
0005433397662	1439	Economy	11000.00
0005435732383	1439	Economy	11000.00
0005432906517	1439	Economy	11000.00
0005433397805	1439	Economy	11000.00
0005433397825	1439	Economy	11000.00
0005435732384	1439	Economy	11000.00
0005433397797	1439	Economy	11000.00
0005433397832	1439	Economy	11000.00
0005433397748	1439	Economy	11000.00
0005433397802	1439	Economy	11000.00
0005433397853	1439	Economy	11000.00
0005433397914	1439	Economy	11000.00
0005433397796	1439	Economy	11000.00
0005433397834	1439	Economy	11000.00
0005435732369	1439	Economy	11000.00
0005435732386	1439	Economy	11000.00
0005433397553	1439	Economy	11000.00
0005435732381	1439	Economy	11000.00
0005433456985	1439	Economy	11000.00
0005435732373	1439	Economy	11000.00
0005433397541	1439	Economy	11000.00
0005433398031	1439	Economy	11000.00
0005433397824	1439	Economy	11000.00
0005433397982	1439	Economy	11000.00
0005433397955	1439	Economy	11000.00
0005435732371	1439	Economy	11000.00
0005433397898	1439	Economy	11000.00
0005435732376	1439	Economy	11000.00
0005433397961	1439	Economy	11000.00
0005433397926	1439	Economy	11000.00
0005433398236	19257	Business	33000.00
0005433398269	19257	Business	33000.00
0005433398228	19257	Business	33000.00
0005435732286	19257	Business	33000.00
0005433398237	19257	Business	33000.00
0005433398267	19257	Business	33000.00
0005433398242	19257	Business	33000.00
0005435732273	19257	Business	33000.00
0005433398268	19257	Business	33000.00
0005432906548	19257	Economy	11000.00
0005433398255	19257	Economy	11000.00
0005433398240	19257	Economy	11000.00
0005433398253	19257	Economy	11000.00
0005435732278	19257	Economy	11000.00
0005433398231	19257	Economy	12100.00
0005433398230	19257	Economy	11000.00
0005433398248	19257	Economy	11000.00
0005433398271	19257	Economy	11000.00
0005432906547	19257	Economy	11000.00
0005433398224	19257	Economy	11000.00
0005433398261	19257	Economy	11000.00
0005433398234	19257	Economy	11000.00
0005433398262	19257	Economy	11000.00
0005435732272	19257	Economy	11000.00
0005435732248	19257	Economy	11000.00
0005433398257	19257	Economy	11000.00
0005433398233	19257	Economy	11000.00
0005432906546	19257	Economy	11000.00
0005433398252	19257	Economy	11000.00
0005433398264	19257	Economy	11000.00
0005433398270	19257	Economy	11000.00
0005433398243	19257	Economy	11000.00
0005435732245	19257	Economy	11000.00
0005433398241	19257	Economy	11000.00
0005435732243	19257	Economy	11000.00
0005433398245	19257	Economy	11000.00
0005433398259	19257	Economy	11000.00
0005435732215	19257	Economy	11000.00
0005435732214	19257	Economy	11000.00
0005433398251	19257	Economy	11000.00
0005433398225	19257	Economy	11000.00
0005433398238	19257	Economy	11000.00
0005435732257	19257	Economy	11000.00
0005435732279	19257	Economy	11000.00
0005435732244	19257	Economy	11000.00
0005433398229	19257	Economy	11000.00
0005432906545	19257	Economy	11000.00
0005433398244	19257	Economy	11000.00
0005433398265	19257	Economy	11000.00
0005433398263	19257	Economy	11000.00
0005433398249	19257	Economy	11000.00
0005433398226	19257	Economy	11000.00
0005433398232	19257	Economy	11000.00
0005435732277	19257	Economy	11000.00
0005433398246	19257	Economy	11000.00
0005433398266	19257	Economy	11000.00
0005435732311	19257	Economy	11000.00
0005433398239	19257	Economy	11000.00
0005433398254	19257	Economy	11000.00
0005433398256	19257	Economy	11000.00
0005433398247	19257	Economy	11000.00
0005433398260	19257	Economy	11000.00
0005432906544	19257	Economy	11000.00
0005433398227	19257	Economy	11000.00
0005433398250	19257	Economy	11000.00
0005433398258	19257	Economy	11000.00
0005433398235	19257	Economy	11000.00
0005434443596	17361	Economy	15600.00
0005434443556	17361	Economy	15600.00
0005434443679	17361	Economy	15600.00
0005434443617	17361	Economy	14100.00
0005434443577	17361	Economy	14100.00
0005434443597	17361	Economy	14100.00
0005434443654	17361	Economy	14100.00
0005434443557	17361	Economy	14100.00
0005434443651	17361	Economy	14100.00
0005434443650	17361	Economy	14100.00
0005434443616	17361	Economy	14100.00
0005434443622	17361	Economy	14100.00
0005434443592	17361	Economy	14100.00
0005434443689	17361	Economy	14100.00
0005434443608	17361	Economy	14100.00
0005434443522	17361	Economy	14100.00
0005434443602	17361	Economy	14100.00
0005434443690	17361	Economy	14100.00
0005434443675	17361	Economy	14100.00
0005434443764	20564	Economy	15600.00
0005434443769	20564	Economy	15600.00
0005434443755	20564	Economy	15600.00
0005434443756	20564	Economy	14100.00
0005434443762	20564	Economy	14100.00
0005434443768	20564	Economy	14100.00
0005434443766	20564	Economy	14100.00
0005434443765	20564	Economy	14100.00
0005434443770	20564	Economy	14100.00
0005434443759	20564	Economy	14100.00
0005434443757	20564	Economy	14100.00
0005434443758	20564	Economy	14100.00
0005434443760	20564	Economy	14100.00
0005434443761	20564	Economy	14100.00
0005434443763	20564	Economy	14100.00
0005434443767	20564	Economy	14100.00
0005434954623	7282	Economy	5800.00
0005434954626	7282	Economy	5800.00
0005434954625	7282	Economy	5800.00
0005434954622	7282	Economy	5800.00
0005434954624	7282	Economy	5800.00
0005435377590	28334	Economy	5800.00
0005435377588	28334	Economy	5800.00
0005434954594	28334	Economy	5800.00
0005434954600	28334	Economy	5800.00
0005435377589	28334	Economy	5800.00
0005434954580	28334	Economy	5800.00
0005434326272	4471	Economy	15400.00
0005435893571	4471	Economy	15400.00
0005434183578	4471	Economy	14000.00
0005435893579	4471	Economy	14000.00
0005434326273	4471	Economy	14000.00
0005434351744	4471	Economy	14000.00
0005435893623	4471	Economy	14000.00
0005434351746	4471	Economy	14000.00
0005434351750	4471	Economy	14000.00
0005434351751	4471	Economy	14000.00
0005434351743	4471	Economy	14000.00
0005434351748	4471	Economy	14000.00
0005434351740	4471	Economy	14000.00
0005434351745	4471	Economy	14000.00
0005435893630	4471	Economy	14000.00
0005435893624	4471	Economy	14000.00
0005434351747	4471	Economy	14000.00
0005434351749	4471	Economy	14000.00
0005435893620	4471	Economy	14000.00
0005434183572	4471	Economy	14000.00
0005434351742	4471	Economy	14000.00
0005435893631	4471	Economy	14000.00
0005434351741	4471	Economy	14000.00
0005434351671	29664	Economy	15400.00
0005435893656	29664	Economy	15400.00
0005435893661	29664	Economy	14000.00
0005434351663	29664	Economy	14000.00
0005434351673	29664	Economy	14000.00
0005435893660	29664	Economy	14000.00
0005435893658	29664	Economy	14000.00
0005435893662	29664	Economy	14000.00
0005434351672	29664	Economy	14000.00
0005434351654	29664	Economy	14000.00
0005435893659	29664	Economy	14000.00
0005434351655	29664	Economy	14000.00
0005435893657	29664	Economy	14000.00
0005434446526	1067	Business	30600.00
0005433342524	1067	Business	30600.00
0005433269678	1067	Business	30600.00
0005433342880	1067	Business	30600.00
0005435092114	1067	Business	30600.00
0005433341823	1067	Business	30600.00
0005433463909	1067	Business	30600.00
0005433342489	1067	Business	30600.00
0005433342904	1067	Business	30600.00
0005433342554	1067	Business	30600.00
0005433342530	1067	Business	30600.00
0005433342311	1067	Business	30600.00
0005433342903	1067	Business	30600.00
0005435092109	1067	Business	30600.00
0005433342885	1067	Business	30600.00
0005435092110	1067	Business	30600.00
0005432293219	1067	Economy	11200.00
0005434446528	1067	Economy	11200.00
0005433342697	1067	Economy	11200.00
0005433342394	1067	Economy	10200.00
0005435092113	1067	Economy	10200.00
0005433462754	1067	Economy	10200.00
0005433342604	1067	Economy	10200.00
0005433463908	1067	Economy	10200.00
0005433342525	1067	Economy	10200.00
0005433342907	1067	Economy	10200.00
0005433342740	1067	Economy	10200.00
0005433342614	1067	Economy	10200.00
0005433342533	1067	Economy	10200.00
0005433342692	1067	Economy	10200.00
0005433342443	1067	Economy	10200.00
0005433159299	1067	Economy	10200.00
0005433342098	1067	Economy	10200.00
0005433342870	1067	Economy	10200.00
0005433342947	1067	Economy	10200.00
0005433342717	1067	Economy	10200.00
0005433342652	1067	Economy	10200.00
0005433342400	1067	Economy	10200.00
0005433269702	1067	Economy	10200.00
0005433269681	1067	Economy	10200.00
0005433269679	1067	Economy	10200.00
0005433342599	1067	Economy	10200.00
0005433342313	1067	Economy	10200.00
0005433342575	1067	Economy	10200.00
0005433342184	1067	Economy	10200.00
0005433342457	1067	Economy	10200.00
0005433342613	1067	Economy	10200.00
0005433342503	1067	Economy	10200.00
0005433342471	1067	Economy	10200.00
0005432293217	1067	Economy	10200.00
0005433342470	1067	Economy	10200.00
0005433342587	1067	Economy	10200.00
0005433342629	1067	Economy	10200.00
0005433342884	1067	Economy	10200.00
0005433342442	1067	Economy	10200.00
0005434446527	1067	Economy	10200.00
0005433342565	1067	Economy	10200.00
0005433342675	1067	Economy	10200.00
0005433342441	1067	Economy	10200.00
0005433342202	1067	Economy	10200.00
0005433342203	1067	Economy	10200.00
0005433462756	1067	Economy	10200.00
0005433342650	1067	Economy	10200.00
0005433342869	1067	Economy	10200.00
0005433342532	1067	Economy	10200.00
0005433342888	1067	Economy	10200.00
0005433342796	1067	Economy	10200.00
0005435092116	1067	Economy	10200.00
0005433342399	1067	Economy	10200.00
0005433342546	1067	Economy	10200.00
0005433341893	1067	Economy	10200.00
0005433342707	1067	Economy	10200.00
0005433342905	1067	Economy	10200.00
0005433342220	1067	Economy	10200.00
0005433343211	1067	Economy	10200.00
0005433342628	1067	Economy	10200.00
0005433342795	1067	Economy	10200.00
0005433342488	1067	Economy	10200.00
0005433342889	1067	Economy	10200.00
0005433342492	1067	Economy	10200.00
0005433342930	1067	Economy	10200.00
0005435092112	1067	Economy	10200.00
0005433341824	1067	Economy	11200.00
0005433342545	1067	Economy	10200.00
0005433159300	1067	Economy	11200.00
0005433342152	1067	Economy	10200.00
0005433342551	1067	Economy	10200.00
0005435545768	1067	Economy	10200.00
0005433269701	1067	Economy	10200.00
0005433342487	1067	Economy	10200.00
0005435092111	1067	Economy	10200.00
0005433463910	1067	Economy	10200.00
0005433342881	1067	Economy	10200.00
0005433342850	1067	Economy	10200.00
0005433342949	1067	Economy	10200.00
0005433342620	1067	Economy	10200.00
0005433342151	1067	Economy	10200.00
0005433342781	1067	Economy	10200.00
0005433342431	1067	Economy	10200.00
0005433342002	1067	Economy	10200.00
0005433342322	1067	Economy	10200.00
0005433342097	1067	Economy	10200.00
0005433342415	1067	Economy	10200.00
0005433342206	1067	Economy	10200.00
0005433342522	1067	Economy	10200.00
0005433342693	1067	Economy	10200.00
0005435545769	1067	Economy	10200.00
0005433342609	1067	Economy	10200.00
0005433342882	1067	Economy	10200.00
0005433342648	1067	Economy	10200.00
0005432293218	1067	Economy	10200.00
0005434446525	1067	Economy	10200.00
0005433343212	1067	Economy	10200.00
0005433342586	1067	Economy	10200.00
0005433342223	1067	Economy	10200.00
0005435092117	1067	Economy	10200.00
0005433342502	1067	Economy	10200.00
0005433342414	1067	Economy	10200.00
0005433342948	1067	Economy	10200.00
0005433342780	1067	Economy	10200.00
0005433342001	1067	Economy	10200.00
0005433342879	1067	Economy	10200.00
0005435092115	1067	Economy	10200.00
0005433342791	1067	Economy	10200.00
0005433342674	1067	Economy	10200.00
0005433462755	1067	Economy	10200.00
0005433342624	1067	Economy	10200.00
0005433343205	1067	Economy	10200.00
0005435092108	1067	Economy	10200.00
0005433342133	1067	Economy	10200.00
0005433342906	1067	Economy	10200.00
0005433342787	1067	Economy	10200.00
0005433343434	17048	Business	30600.00
0005433343416	17048	Business	30600.00
0005435092067	17048	Business	30600.00
0005433343430	17048	Business	30600.00
0005433159321	17048	Business	30600.00
0005433343423	17048	Business	30600.00
0005433159320	17048	Business	30600.00
0005433343491	17048	Business	30600.00
0005433269737	17048	Business	30600.00
0005434445235	17048	Business	30600.00
0005435508259	17048	Business	30600.00
0005433343497	17048	Business	30600.00
0005433343478	17048	Business	30600.00
0005433343437	17048	Business	30600.00
0005434445226	17048	Business	30600.00
0005433343440	17048	Business	30600.00
0005433343417	17048	Business	30600.00
0005435092039	17048	Business	30600.00
0005434445233	17048	Business	30600.00
0005435508320	17048	Economy	11200.00
0005433343419	17048	Economy	11200.00
0005433343467	17048	Economy	10200.00
0005433343460	17048	Economy	10200.00
0005433343508	17048	Economy	10200.00
0005433343480	17048	Economy	10200.00
0005433343414	17048	Economy	10200.00
0005433343459	17048	Economy	10200.00
0005433343481	17048	Economy	10200.00
0005433343494	17048	Economy	10200.00
0005435508294	17048	Economy	10200.00
0005433343448	17048	Economy	10200.00
0005433343449	17048	Economy	10200.00
0005433343439	17048	Economy	10200.00
0005433343498	17048	Economy	10200.00
0005435508308	17048	Economy	10200.00
0005433343420	17048	Economy	10200.00
0005433343495	17048	Economy	10200.00
0005433343514	17048	Economy	10200.00
0005433343477	17048	Economy	10200.00
0005435508319	17048	Economy	10200.00
0005435508362	17048	Economy	10200.00
0005433343482	17048	Economy	10200.00
0005435508341	17048	Economy	10200.00
0005435508307	17048	Economy	10200.00
0005433343458	17048	Economy	10200.00
0005433343426	17048	Economy	10200.00
0005433343428	17048	Economy	10200.00
0005433343507	17048	Economy	10200.00
0005433343446	17048	Economy	10200.00
0005433343433	17048	Economy	10200.00
0005433343465	17048	Economy	10200.00
0005433343474	17048	Economy	10200.00
0005433343483	17048	Economy	10200.00
0005433343442	17048	Economy	10200.00
0005433343503	17048	Economy	10200.00
0005433343425	17048	Economy	10200.00
0005434445237	17048	Economy	10200.00
0005433343415	17048	Economy	10200.00
0005433343486	17048	Economy	10200.00
0005435092020	17048	Economy	10200.00
0005433343512	17048	Economy	10200.00
0005433343511	17048	Economy	10200.00
0005433343429	17048	Economy	10200.00
0005433343421	17048	Economy	10200.00
0005433343466	17048	Economy	10200.00
0005433343513	17048	Economy	10200.00
0005433343476	17048	Economy	10200.00
0005433343501	17048	Economy	10200.00
0005433343487	17048	Economy	10200.00
0005433343445	17048	Economy	10200.00
0005433269741	17048	Economy	10200.00
0005433343469	17048	Economy	10200.00
0005433343462	17048	Economy	10200.00
0005433343489	17048	Economy	10200.00
0005433343500	17048	Economy	10200.00
0005433343447	17048	Economy	10200.00
0005435092038	17048	Economy	10200.00
0005433343492	17048	Economy	10200.00
0005433343424	17048	Economy	10200.00
0005433343443	17048	Economy	10200.00
0005435508281	17048	Economy	10200.00
0005433343427	17048	Economy	11200.00
0005435508321	17048	Economy	10200.00
0005433343450	17048	Economy	10200.00
0005433269740	17048	Economy	11200.00
0005435508336	17048	Economy	10200.00
0005435508278	17048	Economy	10200.00
0005433343484	17048	Economy	10200.00
0005433343422	17048	Economy	10200.00
0005433343441	17048	Economy	10200.00
0005433343435	17048	Economy	10200.00
0005433343438	17048	Economy	10200.00
0005433343472	17048	Economy	10200.00
0005433343493	17048	Economy	10200.00
0005433343505	17048	Economy	10200.00
0005433343479	17048	Economy	10200.00
0005433343431	17048	Economy	10200.00
0005433343454	17048	Economy	10200.00
0005433343456	17048	Economy	10200.00
0005433343453	17048	Economy	10200.00
0005433269738	17048	Economy	10200.00
0005433343436	17048	Economy	10200.00
0005433343510	17048	Economy	10200.00
0005433343451	17048	Economy	10200.00
0005435508295	17048	Economy	10200.00
0005433269739	17048	Economy	10200.00
0005433343452	17048	Economy	10200.00
0005433343470	17048	Economy	10200.00
0005433343457	17048	Economy	10200.00
0005433343490	17048	Economy	10200.00
0005433343473	17048	Economy	10200.00
0005435508282	17048	Economy	10200.00
0005435508289	17048	Economy	10200.00
0005433343464	17048	Economy	10200.00
0005433343509	17048	Economy	10200.00
0005433343432	17048	Economy	10200.00
0005433343502	17048	Economy	10200.00
0005433343485	17048	Economy	10200.00
0005433343471	17048	Economy	10200.00
0005433343506	17048	Economy	10200.00
0005433343444	17048	Economy	10200.00
0005433343461	17048	Economy	10200.00
0005434445234	17048	Economy	10200.00
0005433343488	17048	Economy	10200.00
0005433343455	17048	Economy	10200.00
0005433343463	17048	Economy	10200.00
0005433343468	17048	Economy	10200.00
0005433343499	17048	Economy	10200.00
0005433343504	17048	Economy	10200.00
0005434445227	17048	Economy	10200.00
0005433343418	17048	Economy	10200.00
0005433343496	17048	Economy	10200.00
0005435508322	17048	Economy	10200.00
0005433343475	17048	Economy	10200.00
0005432390001	18264	Business	101000.00
0005432390044	18264	Business	101000.00
0005432390039	18264	Business	101000.00
0005432390093	18264	Business	101000.00
0005432391977	18264	Business	101000.00
0005432390050	18264	Business	101000.00
0005432390118	18264	Business	101000.00
0005432390034	18264	Business	101000.00
0005432851933	18264	Business	101000.00
0005432851930	18264	Business	101000.00
0005432390018	18264	Economy	33700.00
0005432391971	18264	Business	101000.00
0005432391985	18264	Economy	33700.00
0005432390058	18264	Economy	33700.00
0005432390067	18264	Economy	33700.00
0005432391975	18264	Economy	33700.00
0005432390073	18264	Economy	33700.00
0005432391984	18264	Economy	33700.00
0005432390047	18264	Economy	33700.00
0005432391990	18264	Economy	33700.00
0005432391976	18264	Economy	37000.00
0005432390077	18264	Economy	37000.00
0005432851940	18264	Economy	33700.00
0005432390109	18264	Economy	37000.00
0005432851949	18264	Economy	33700.00
0005432390092	18264	Economy	33700.00
0005432851946	18264	Economy	33700.00
0005432851928	18264	Economy	33700.00
0005432389974	18264	Economy	33700.00
0005432390064	18264	Economy	33700.00
0005432390131	18264	Economy	33700.00
0005432391973	18264	Economy	33700.00
0005432390000	18264	Economy	33700.00
0005432390076	18264	Economy	33700.00
0005432391970	18264	Economy	33700.00
0005432391968	18264	Economy	33700.00
0005432851927	18264	Economy	33700.00
0005432851937	18264	Economy	33700.00
0005432390024	18264	Economy	33700.00
0005432851941	18264	Economy	33700.00
0005432390059	18264	Economy	33700.00
0005432851934	18264	Economy	33700.00
0005432390049	18264	Economy	33700.00
0005432851929	18264	Economy	33700.00
0005432390114	18264	Economy	33700.00
0005432390075	18264	Economy	33700.00
0005432851947	18264	Economy	33700.00
0005432851948	18264	Economy	33700.00
0005432390057	18264	Economy	33700.00
0005432390133	18264	Economy	33700.00
0005432851944	18264	Economy	33700.00
0005432390119	18264	Economy	33700.00
0005432390046	18264	Economy	33700.00
0005432390132	18264	Economy	33700.00
0005432851932	18264	Economy	33700.00
0005432390011	18264	Economy	33700.00
0005432390080	18264	Economy	33700.00
0005432391991	18264	Economy	33700.00
0005432390048	18264	Economy	33700.00
0005432851939	18264	Economy	33700.00
0005432391969	18264	Economy	33700.00
0005432851926	18264	Economy	33700.00
0005432391979	18264	Economy	33700.00
0005432851945	18264	Economy	33700.00
0005432391974	18264	Economy	33700.00
0005432851943	18264	Economy	33700.00
0005432390117	18264	Economy	33700.00
0005432389980	18264	Economy	33700.00
0005432851931	18264	Economy	33700.00
0005432851938	18264	Economy	33700.00
0005432851935	18264	Economy	33700.00
0005432851942	18264	Economy	33700.00
0005432391978	18264	Economy	33700.00
0005432851936	18264	Economy	33700.00
0005432390045	18264	Economy	33700.00
0005434067239	12779	Business	40300.00
0005433812910	12779	Business	40300.00
0005432159877	12779	Business	40300.00
0005434067083	12779	Business	40300.00
0005434067024	12779	Business	40300.00
0005432159876	12779	Business	40300.00
0005434067009	12779	Business	40300.00
0005434067470	12779	Business	40300.00
0005434067393	12779	Business	40300.00
0005434067347	12779	Business	40300.00
0005434067088	12779	Business	40300.00
0005434081777	12779	Business	40300.00
0005434067193	12779	Economy	13400.00
0005434081745	12779	Economy	13400.00
0005434067308	12779	Economy	13400.00
0005434067288	12779	Economy	13400.00
0005434067156	12779	Economy	13400.00
0005434081724	12779	Economy	13400.00
0005434067201	12779	Economy	13400.00
0005434067403	12779	Economy	13400.00
0005434067256	12779	Economy	13400.00
0005432159875	12779	Economy	13400.00
0005434066981	12779	Economy	13400.00
0005434067469	12779	Economy	13400.00
0005434067034	12779	Economy	13400.00
0005434066911	12779	Economy	13400.00
0005432161162	12779	Economy	13400.00
0005434066929	12779	Economy	13400.00
0005434067068	12779	Economy	13400.00
0005434081813	12779	Economy	13400.00
0005434081786	12779	Economy	13400.00
0005434067200	12779	Economy	13400.00
0005434067025	12779	Economy	13400.00
0005434067087	12779	Economy	13400.00
0005434067023	12779	Economy	13400.00
0005434081685	12779	Economy	13400.00
0005432433702	12779	Economy	13400.00
0005434066979	12779	Economy	13400.00
0005434067494	12779	Economy	13400.00
0005434067299	12779	Economy	13400.00
0005434067476	12779	Economy	13400.00
0005434067394	12779	Economy	13400.00
0005432433698	12779	Economy	13400.00
0005434081713	12779	Economy	13400.00
0005434067033	12779	Economy	13400.00
0005434066978	12779	Economy	13400.00
0005433989750	12779	Economy	13400.00
0005434081712	12779	Economy	13400.00
0005432433703	12779	Economy	13400.00
0005434081696	12779	Economy	14800.00
0005434067346	12779	Economy	14800.00
0005434026692	12779	Economy	14800.00
0005434067436	12779	Economy	14800.00
0005434067202	12779	Economy	14800.00
0005434081684	12779	Economy	13400.00
0005433989731	12779	Economy	13400.00
0005434066910	12779	Economy	13400.00
0005434067102	12779	Economy	13400.00
0005434067032	12779	Economy	13400.00
0005434067307	12779	Economy	13400.00
0005434067074	12779	Economy	13400.00
0005434067133	12779	Economy	13400.00
0005432433701	12779	Economy	13400.00
0005434067158	12779	Economy	13400.00
0005434067108	12779	Economy	13400.00
0005434067198	12779	Economy	13400.00
0005432159878	12779	Economy	13400.00
0005434067370	12779	Economy	13400.00
0005434066989	12779	Economy	13400.00
0005434081779	12779	Economy	13400.00
0005434067130	12779	Economy	13400.00
0005434067103	12779	Economy	13400.00
0005434067161	12779	Economy	13400.00
0005432433699	12779	Economy	13400.00
0005434081640	12779	Economy	13400.00
0005434081785	12779	Economy	13400.00
0005434067287	12779	Economy	13400.00
0005433989730	12779	Economy	13400.00
0005434081815	12779	Economy	13400.00
0005434067160	12779	Economy	13400.00
0005434067035	12779	Economy	13400.00
0005434081793	12779	Economy	13400.00
0005434067148	12779	Economy	13400.00
0005433989739	12779	Economy	13400.00
0005434081689	12779	Economy	13400.00
0005434081792	12779	Economy	13400.00
0005434067404	12779	Economy	13400.00
0005432433700	12779	Economy	13400.00
0005434081814	12779	Economy	13400.00
0005434081782	12779	Economy	13400.00
0005434067121	12779	Economy	13400.00
0005434067455	12779	Economy	13400.00
0005434067356	12779	Economy	13400.00
0005434067306	12779	Economy	13400.00
0005434067044	12779	Economy	13400.00
0005433989732	12779	Economy	13400.00
0005434067112	12779	Economy	13400.00
0005434067223	12779	Economy	13400.00
0005432161161	12779	Economy	13400.00
0005434066990	12779	Economy	13400.00
0005434081780	12779	Economy	13400.00
0005434066770	12779	Economy	13400.00
0005434067107	12779	Economy	13400.00
0005434081781	12779	Economy	13400.00
0005434067419	12779	Economy	13400.00
0005434067218	12779	Economy	13400.00
0005434067495	12779	Economy	13400.00
0005434067109	12779	Economy	13400.00
0005434067199	12779	Economy	13400.00
0005434066901	12779	Economy	13400.00
0005432161160	12779	Economy	13400.00
0005434067186	12779	Economy	13400.00
0005434067241	12779	Economy	13400.00
0005433989738	12779	Economy	13400.00
0005434081741	12779	Economy	13400.00
0005432159874	12779	Economy	13400.00
0005434067207	12779	Economy	13400.00
0005434067310	12779	Economy	13400.00
0005434067298	12779	Economy	13400.00
0005434081639	12779	Economy	13400.00
0005434066991	12779	Economy	13400.00
0005434081725	12779	Economy	13400.00
0005434026691	12779	Economy	13400.00
0005434066909	12779	Economy	13400.00
0005434067754	30664	Business	40300.00
0005434081983	30664	Business	40300.00
0005434067816	30664	Business	40300.00
0005434067785	30664	Business	40300.00
0005432433626	30664	Business	40300.00
0005432150220	30664	Business	40300.00
0005434067770	30664	Business	40300.00
0005434067795	30664	Business	40300.00
0005434067775	30664	Business	40300.00
0005434081965	30664	Business	40300.00
0005434081957	30664	Business	40300.00
0005434081966	30664	Business	40300.00
0005434081971	30664	Economy	13400.00
0005434067804	30664	Economy	13400.00
0005434067761	30664	Economy	13400.00
0005434067809	30664	Economy	13400.00
0005434067769	30664	Economy	13400.00
0005432150215	30664	Economy	13400.00
0005434067757	30664	Economy	13400.00
0005434067793	30664	Economy	13400.00
0005432150217	30664	Economy	13400.00
0005434067790	30664	Economy	13400.00
0005434067817	30664	Economy	13400.00
0005434081960	30664	Economy	13400.00
0005434067753	30664	Economy	13400.00
0005434067801	30664	Economy	13400.00
0005434081979	30664	Economy	13400.00
0005434081984	30664	Economy	13400.00
0005434067776	30664	Economy	13400.00
0005434067748	30664	Economy	13400.00
0005434081975	30664	Economy	13400.00
0005434081980	30664	Economy	13400.00
0005434067810	30664	Economy	13400.00
0005434067758	30664	Economy	13400.00
0005434067765	30664	Economy	13400.00
0005434081954	30664	Economy	13400.00
0005434067772	30664	Economy	13400.00
0005434081955	30664	Economy	13400.00
0005434067818	30664	Economy	13400.00
0005434081958	30664	Economy	13400.00
0005434067763	30664	Economy	13400.00
0005432186881	30664	Economy	13400.00
0005434067777	30664	Economy	13400.00
0005432433659	30664	Economy	13400.00
0005434067756	30664	Economy	13400.00
0005434067760	30664	Economy	13400.00
0005434067805	30664	Economy	13400.00
0005433989783	30664	Economy	13400.00
0005434067812	30664	Economy	13400.00
0005434081981	30664	Economy	13400.00
0005434067767	30664	Economy	13400.00
0005434081967	30664	Economy	13400.00
0005432433679	30664	Economy	14800.00
0005434081969	30664	Economy	14800.00
0005434067774	30664	Economy	14800.00
0005434067806	30664	Economy	14800.00
0005434067768	30664	Economy	14800.00
0005434081978	30664	Economy	14800.00
0005434067771	30664	Economy	13400.00
0005434067783	30664	Economy	13400.00
0005434081963	30664	Economy	13400.00
0005434067766	30664	Economy	13400.00
0005434067773	30664	Economy	13400.00
0005434067792	30664	Economy	13400.00
0005434067789	30664	Economy	13400.00
0005434081959	30664	Economy	13400.00
0005432150222	30664	Economy	13400.00
0005434067787	30664	Economy	13400.00
0005434067779	30664	Economy	13400.00
0005434081968	30664	Economy	13400.00
0005434067811	30664	Economy	13400.00
0005434067815	30664	Economy	13400.00
0005434067786	30664	Economy	13400.00
0005434067796	30664	Economy	13400.00
0005432433677	30664	Economy	13400.00
0005434067797	30664	Economy	13400.00
0005434067750	30664	Economy	13400.00
0005432150221	30664	Economy	13400.00
0005434081962	30664	Economy	13400.00
0005432150219	30664	Economy	13400.00
0005434081973	30664	Economy	13400.00
0005434081970	30664	Economy	13400.00
0005434067802	30664	Economy	13400.00
0005433989786	30664	Economy	13400.00
0005434067800	30664	Economy	13400.00
0005434067794	30664	Economy	13400.00
0005432433678	30664	Economy	13400.00
0005434067762	30664	Economy	13400.00
0005432433666	30664	Economy	13400.00
0005434081974	30664	Economy	13400.00
0005434067751	30664	Economy	13400.00
0005434081961	30664	Economy	13400.00
0005432150218	30664	Economy	13400.00
0005434067755	30664	Economy	13400.00
0005434067782	30664	Economy	13400.00
0005434067747	30664	Economy	13400.00
0005434067798	30664	Economy	13400.00
0005433989785	30664	Economy	13400.00
0005434067780	30664	Economy	13400.00
0005432150216	30664	Economy	13400.00
0005434067764	30664	Economy	13400.00
0005432433643	30664	Economy	13400.00
0005434081972	30664	Economy	13400.00
0005434067788	30664	Economy	13400.00
0005433989787	30664	Economy	13400.00
0005434067799	30664	Economy	13400.00
0005434067803	30664	Economy	13400.00
0005434081982	30664	Economy	13400.00
0005434067791	30664	Economy	13400.00
0005434081977	30664	Economy	13400.00
0005434067752	30664	Economy	13400.00
0005434067814	30664	Economy	13400.00
0005434067759	30664	Economy	13400.00
0005434067784	30664	Economy	13400.00
0005434067749	30664	Economy	13400.00
0005434081964	30664	Economy	13400.00
0005434067778	30664	Economy	13400.00
0005434067819	30664	Economy	13400.00
0005434067781	30664	Economy	13400.00
0005434081956	30664	Economy	13400.00
0005434067808	30664	Economy	13400.00
0005433989784	30664	Economy	13400.00
0005434067807	30664	Economy	13400.00
0005434081976	30664	Economy	13400.00
0005434067813	30664	Economy	13400.00
0005433686617	19363	Economy	19300.00
0005433689902	19363	Economy	19300.00
0005433686603	19363	Economy	19300.00
0005433689890	19363	Economy	19300.00
0005433689900	19363	Economy	17600.00
0005433686612	19363	Economy	17600.00
0005433686610	19363	Economy	17600.00
0005433686618	19363	Economy	17600.00
0005433689894	19363	Economy	17600.00
0005433689903	19363	Economy	17600.00
0005433689905	19363	Economy	17600.00
0005433689897	19363	Economy	17600.00
0005433689891	19363	Economy	17600.00
0005433686616	19363	Economy	17600.00
0005433689904	19363	Economy	17600.00
0005433686611	19363	Economy	17600.00
0005433689892	19363	Economy	17600.00
0005433686613	19363	Economy	17600.00
0005433689896	19363	Economy	17600.00
0005433686621	19363	Economy	17600.00
0005433689893	19363	Economy	17600.00
0005433686627	19363	Economy	17600.00
0005433689895	19363	Economy	17600.00
0005433686615	19363	Economy	17600.00
0005433686622	19363	Economy	17600.00
0005435725614	5526	Business	35300.00
0005435462228	5526	Business	35300.00
0005435766490	5526	Business	35300.00
0005435462230	5526	Business	35300.00
0005434831112	5526	Business	35300.00
0005432140476	5526	Business	35300.00
0005435766440	5526	Business	35300.00
0005434264957	5526	Business	35300.00
0005434831120	5526	Business	35300.00
0005435462209	5526	Business	35300.00
0005435766434	5526	Business	35300.00
0005435462227	5526	Business	35300.00
0005434265056	5526	Business	35300.00
0005435766450	5526	Business	35300.00
0005435766487	5526	Business	35300.00
0005434264982	5526	Business	35300.00
0005435462363	5526	Business	35300.00
0005435462087	5526	Business	35300.00
0005435462201	5526	Business	35300.00
0005435766503	5526	Business	35300.00
0005435766470	5526	Business	35300.00
0005435725616	5526	Business	35300.00
0005435766432	5526	Business	35300.00
0005435766442	5526	Business	35300.00
0005434264956	5526	Economy	12900.00
0005434264979	5526	Economy	12900.00
0005435766427	5526	Economy	12900.00
0005435766502	5526	Economy	11800.00
0005435766431	5526	Economy	11800.00
0005435766479	5526	Economy	11800.00
0005435462323	5526	Economy	11800.00
0005435462231	5526	Economy	11800.00
0005435766437	5526	Economy	11800.00
0005435462342	5526	Economy	11800.00
0005435462355	5526	Economy	11800.00
0005435766471	5526	Economy	11800.00
0005435766443	5526	Economy	11800.00
0005435462108	5526	Economy	11800.00
0005435766462	5526	Economy	11800.00
0005435766467	5526	Economy	11800.00
0005434831117	5526	Economy	11800.00
0005435462074	5526	Economy	11800.00
0005435766457	5526	Economy	11800.00
0005435722064	5526	Economy	11800.00
0005435462301	5526	Economy	11800.00
0005435766496	5526	Economy	11800.00
0005435766460	5526	Economy	11800.00
0005435462313	5526	Economy	11800.00
0005435766480	5526	Economy	11800.00
0005434831119	5526	Economy	11800.00
0005435766489	5526	Economy	11800.00
0005432535811	5526	Economy	11800.00
0005435766458	5526	Economy	11800.00
0005435766494	5526	Economy	11800.00
0005434264971	5526	Economy	11800.00
0005432140481	5526	Economy	11800.00
0005435766459	5526	Economy	11800.00
0005435735151	5526	Economy	11800.00
0005435735148	5526	Economy	11800.00
0005432140483	5526	Economy	11800.00
0005435766465	5526	Economy	11800.00
0005435766466	5526	Economy	11800.00
0005435766438	5526	Economy	11800.00
0005434264958	5526	Economy	11800.00
0005433529293	5526	Economy	11800.00
0005435766474	5526	Economy	11800.00
0005432140477	5526	Economy	11800.00
0005435766475	5526	Economy	11800.00
0005433529294	5526	Economy	11800.00
0005435722065	5526	Economy	11800.00
0005433527284	5526	Economy	11800.00
0005434264944	5526	Economy	11800.00
0005434265022	5526	Economy	11800.00
0005435462226	5526	Economy	11800.00
0005435462037	5526	Economy	11800.00
0005435735150	5526	Economy	11800.00
0005435766448	5526	Economy	11800.00
0005435462221	5526	Economy	11800.00
0005435462356	5526	Economy	11800.00
0005435766456	5526	Economy	11800.00
0005435462237	5526	Economy	11800.00
0005435462288	5526	Economy	11800.00
0005434831118	5526	Economy	11800.00
0005435766447	5526	Economy	11800.00
0005435766454	5526	Economy	11800.00
0005435725617	5526	Economy	11800.00
0005435735149	5526	Economy	11800.00
0005435766433	5526	Economy	11800.00
0005435766429	5526	Economy	11800.00
0005433527282	5526	Economy	11800.00
0005435766498	5526	Economy	11800.00
0005434265057	5526	Economy	11800.00
0005435766469	5526	Economy	11800.00
0005435766499	5526	Economy	11800.00
0005435766444	5526	Economy	11800.00
0005434265082	5526	Economy	11800.00
0005435462211	5526	Economy	11800.00
0005435766491	5526	Economy	11800.00
0005435766492	5526	Economy	11800.00
0005435766493	5526	Economy	11800.00
0005435462210	5526	Economy	11800.00
0005434264995	5526	Economy	11800.00
0005435766441	5526	Economy	11800.00
0005435462364	5526	Economy	11800.00
0005435462167	5526	Economy	11800.00
0005434264884	5526	Economy	11800.00
0005432140479	5526	Economy	11800.00
0005432140480	5526	Economy	11800.00
0005432140482	5526	Economy	12900.00
0005435462343	5526	Economy	12900.00
0005435462086	5526	Economy	11800.00
0005432535810	5526	Economy	11800.00
0005435766483	5526	Economy	11800.00
0005435766428	5526	Economy	12900.00
0005434264919	5526	Economy	11800.00
0005432535804	5526	Economy	12900.00
0005432140478	5526	Economy	11800.00
0005435766430	5526	Economy	11800.00
0005435766436	5526	Economy	11800.00
0005435766473	5526	Economy	11800.00
0005435766455	5526	Economy	11800.00
0005435766446	5526	Economy	11800.00
0005435462222	5526	Economy	11800.00
0005435725615	5526	Economy	11800.00
0005435462311	5526	Economy	11800.00
0005434264983	5526	Economy	11800.00
0005434264918	5526	Economy	11800.00
0005435766482	5526	Economy	11800.00
0005435462238	5526	Economy	11800.00
0005435766495	5526	Economy	11800.00
0005435462229	5526	Economy	11800.00
0005435766477	5526	Economy	11800.00
0005434264943	5526	Economy	11800.00
0005434265049	5526	Economy	11800.00
0005432535803	5526	Economy	11800.00
0005435766497	5526	Economy	11800.00
0005435766445	5526	Economy	11800.00
0005435766485	5526	Economy	11800.00
0005435735152	5526	Economy	11800.00
0005435766500	5526	Economy	11800.00
0005435766468	5526	Economy	11800.00
0005435766478	5526	Economy	11800.00
0005435766439	5526	Economy	11800.00
0005435766451	5526	Economy	11800.00
0005434265081	5526	Economy	11800.00
0005434831086	5526	Economy	11800.00
0005435462287	5526	Economy	11800.00
0005433527283	5526	Economy	11800.00
0005435766476	5526	Economy	11800.00
0005435722063	5526	Economy	11800.00
0005435723053	5526	Economy	11800.00
0005434265013	5526	Economy	11800.00
0005435766486	5526	Economy	11800.00
0005435043277	5526	Economy	11800.00
0005435766453	5526	Economy	11800.00
0005433529292	5526	Economy	11800.00
0005435462286	5526	Economy	11800.00
0005435766472	5526	Economy	11800.00
0005434265048	5526	Economy	11800.00
0005435722066	5526	Economy	11800.00
0005434831126	5526	Economy	11800.00
0005435462299	5526	Economy	11800.00
0005435462410	5526	Economy	11800.00
0005435766481	5526	Economy	11800.00
0005434264980	5526	Economy	11800.00
0005435766449	5526	Economy	11800.00
0005434831087	5526	Economy	11800.00
0005435766484	5526	Economy	11800.00
0005435766452	5526	Economy	11800.00
0005435766501	5526	Economy	11800.00
0005434264994	5526	Economy	11800.00
0005435766488	5526	Economy	11800.00
0005435462258	5526	Economy	11800.00
0005435766461	5526	Economy	11800.00
0005435462307	5526	Economy	11800.00
0005435766463	5526	Economy	11800.00
0005435766464	5526	Economy	11800.00
0005434265050	5526	Economy	11800.00
0005433529295	5526	Economy	11800.00
0005435725618	5526	Economy	11800.00
0005435766435	5526	Economy	11800.00
0005435462295	5526	Economy	11800.00
0005435765697	13494	Business	35300.00
0005435462591	13494	Business	35300.00
0005432535852	13494	Business	35300.00
0005435462571	13494	Business	35300.00
0005435462569	13494	Business	35300.00
0005435765813	13494	Business	35300.00
0005435462592	13494	Business	35300.00
0005434265233	13494	Business	35300.00
0005435766210	13494	Business	35300.00
0005435765875	13494	Business	35300.00
0005435765750	13494	Business	35300.00
0005435765881	13494	Business	35300.00
0005434265248	13494	Business	35300.00
0005434831172	13494	Business	35300.00
0005434265254	13494	Business	35300.00
0005435765811	13494	Business	35300.00
0005434265239	13494	Business	35300.00
0005435766023	13494	Business	35300.00
0005434265242	13494	Business	35300.00
0005435462600	13494	Business	35300.00
0005434831171	13494	Business	35300.00
0005435725563	13494	Business	35300.00
0005435765854	13494	Business	35300.00
0005434265256	13494	Economy	12900.00
0005435462572	13494	Economy	12900.00
0005435765810	13494	Economy	12900.00
0005435765892	13494	Economy	11800.00
0005435462577	13494	Economy	11800.00
0005435765801	13494	Economy	11800.00
0005434265252	13494	Economy	11800.00
0005435462593	13494	Economy	11800.00
0005435765759	13494	Economy	11800.00
0005435765696	13494	Economy	11800.00
0005432194525	13494	Economy	11800.00
0005434831169	13494	Economy	11800.00
0005435765725	13494	Economy	11800.00
0005435766074	13494	Economy	11800.00
0005434265250	13494	Economy	11800.00
0005435766035	13494	Economy	11800.00
0005435043287	13494	Economy	11800.00
0005434265241	13494	Economy	11800.00
0005435462573	13494	Economy	11800.00
0005435462590	13494	Economy	11800.00
0005435765869	13494	Economy	11800.00
0005435462581	13494	Economy	11800.00
0005435723031	13494	Economy	11800.00
0005435765907	13494	Economy	11800.00
0005434265245	13494	Economy	11800.00
0005435765995	13494	Economy	11800.00
0005434265240	13494	Economy	11800.00
0005435765899	13494	Economy	11800.00
0005435765891	13494	Economy	11800.00
0005435462584	13494	Economy	11800.00
0005435462583	13494	Economy	11800.00
0005434265243	13494	Economy	11800.00
0005435765890	13494	Economy	11800.00
0005435765741	13494	Economy	11800.00
0005435462578	13494	Economy	11800.00
0005435462574	13494	Economy	11800.00
0005435765743	13494	Economy	11800.00
0005432535855	13494	Economy	11800.00
0005435722034	13494	Economy	11800.00
0005435462595	13494	Economy	11800.00
0005434265249	13494	Economy	11800.00
0005434265253	13494	Economy	11800.00
0005435462596	13494	Economy	11800.00
0005432194526	13494	Economy	11800.00
0005432535854	13494	Economy	11800.00
0005435765963	13494	Economy	11800.00
0005435462597	13494	Economy	11800.00
0005435765742	13494	Economy	11800.00
0005435765916	13494	Economy	11800.00
0005435766073	13494	Economy	11800.00
0005435765549	13494	Economy	11800.00
0005435766029	13494	Economy	11800.00
0005435462602	13494	Economy	11800.00
0005435765967	13494	Economy	11800.00
0005435462570	13494	Economy	11800.00
0005435766038	13494	Economy	11800.00
0005435725582	13494	Economy	11800.00
0005435765985	13494	Economy	11800.00
0005435766064	13494	Economy	11800.00
0005434265231	13494	Economy	11800.00
0005435462579	13494	Economy	11800.00
0005435722026	13494	Economy	11800.00
0005435765783	13494	Economy	11800.00
0005435766039	13494	Economy	11800.00
0005435766133	13494	Economy	11800.00
0005435765782	13494	Economy	11800.00
0005435462594	13494	Economy	11800.00
0005435765814	13494	Economy	11800.00
0005435765760	13494	Economy	11800.00
0005435462598	13494	Economy	11800.00
0005435765947	13494	Economy	11800.00
0005435462599	13494	Economy	11800.00
0005435725555	13494	Economy	11800.00
0005435765835	13494	Economy	11800.00
0005434265247	13494	Economy	11800.00
0005432535856	13494	Economy	11800.00
0005435766095	13494	Economy	11800.00
0005435766181	13494	Economy	11800.00
0005434831168	13494	Economy	12900.00
0005435765868	13494	Economy	12900.00
0005432194528	13494	Economy	11800.00
0005435462587	13494	Economy	11800.00
0005434265246	13494	Economy	11800.00
0005432535857	13494	Economy	12900.00
0005434265257	13494	Economy	11800.00
0005435766146	13494	Economy	12900.00
0005434831170	13494	Economy	11800.00
0005435766141	13494	Economy	11800.00
0005435765917	13494	Economy	11800.00
0005435722035	13494	Economy	11800.00
0005435462586	13494	Economy	11800.00
0005435735121	13494	Economy	11800.00
0005434265244	13494	Economy	11800.00
0005435462603	13494	Economy	11800.00
0005434265230	13494	Economy	11800.00
0005434265237	13494	Economy	11800.00
0005435766030	13494	Economy	11800.00
0005434265236	13494	Economy	11800.00
0005434265234	13494	Economy	11800.00
0005435766016	13494	Economy	11800.00
0005435765784	13494	Economy	11800.00
0005435765948	13494	Economy	11800.00
0005435725572	13494	Economy	11800.00
0005435462580	13494	Economy	11800.00
0005435043286	13494	Economy	11800.00
0005435765982	13494	Economy	11800.00
0005435462604	13494	Economy	11800.00
0005435766079	13494	Economy	11800.00
0005435765980	13494	Economy	11800.00
0005435765992	13494	Economy	11800.00
0005434265232	13494	Economy	11800.00
0005434265238	13494	Economy	11800.00
0005435766132	13494	Economy	11800.00
0005432535851	13494	Economy	11800.00
0005435765987	13494	Economy	11800.00
0005435765802	13494	Economy	11800.00
0005435765971	13494	Economy	11800.00
0005435765889	13494	Economy	11800.00
0005435765986	13494	Economy	11800.00
0005435765996	13494	Economy	11800.00
0005435766005	13494	Economy	11800.00
0005435462585	13494	Economy	11800.00
0005435765550	13494	Economy	11800.00
0005435765858	13494	Economy	11800.00
0005435765984	13494	Economy	11800.00
0005435765874	13494	Economy	11800.00
0005435462588	13494	Economy	11800.00
0005434265235	13494	Economy	11800.00
0005435462575	13494	Economy	11800.00
0005435722045	13494	Economy	11800.00
0005435722044	13494	Economy	11800.00
0005434265251	13494	Economy	11800.00
0005435765754	13494	Economy	11800.00
0005434831173	13494	Economy	11800.00
0005435765981	13494	Economy	11800.00
0005435462576	13494	Economy	11800.00
0005434265255	13494	Economy	11800.00
0005435462605	13494	Economy	11800.00
0005432535853	13494	Economy	11800.00
0005435765887	13494	Economy	11800.00
0005435462582	13494	Economy	11800.00
0005435725562	13494	Economy	11800.00
0005435765962	13494	Economy	11800.00
0005435766142	13494	Economy	11800.00
0005435765832	13494	Economy	11800.00
0005435765910	13494	Economy	11800.00
0005432194527	13494	Economy	11800.00
0005435462601	13494	Economy	11800.00
0005435462589	13494	Economy	11800.00
0005434602883	18724	Economy	3300.00
0005434602888	18724	Economy	3300.00
0005434602894	18724	Economy	3300.00
0005434602882	18724	Economy	3300.00
0005434604878	18723	Economy	3300.00
0005434513590	18723	Economy	3300.00
0005434513588	18723	Economy	3300.00
0005434513591	18723	Economy	3300.00
0005434513589	18723	Economy	3300.00
0005434604875	18723	Economy	3300.00
0005434514975	18723	Economy	3300.00
0005434604879	18723	Economy	3300.00
0005434604877	18723	Economy	3300.00
0005434514977	18723	Economy	3300.00
0005434514976	18723	Economy	3300.00
0005434602908	19205	Economy	3300.00
0005434602907	19205	Economy	3300.00
0005434602906	19205	Economy	3300.00
0005434514956	19205	Economy	3300.00
0005434602910	19205	Economy	3300.00
0005434514955	19205	Economy	3300.00
0005434514952	19205	Economy	3300.00
0005434602909	19205	Economy	3300.00
0005434602905	19205	Economy	3300.00
0005434514953	19205	Economy	3300.00
0005435844335	25093	Business	88300.00
0005432649375	25093	Business	88300.00
0005432632671	25093	Business	88300.00
0005435844329	25093	Business	88300.00
0005432649383	25093	Business	88300.00
0005435844333	25093	Economy	29400.00
0005435844332	25093	Economy	29400.00
0005435844327	25093	Economy	29400.00
0005435846264	25093	Economy	29400.00
0005435846265	25093	Economy	32400.00
0005432649353	25093	Economy	32400.00
0005432632731	25093	Economy	32400.00
0005435846266	25093	Economy	32400.00
0005432649365	25093	Economy	29400.00
0005432632667	25093	Economy	29400.00
0005432649369	25093	Economy	29400.00
0005435846267	25093	Economy	29400.00
0005432649384	25093	Economy	29400.00
0005432649354	25093	Economy	29400.00
0005435846263	25093	Economy	29400.00
0005435844337	25093	Economy	29400.00
0005435844336	25093	Economy	29400.00
0005432632675	25093	Economy	29400.00
0005432632699	25093	Economy	29400.00
0005435844334	25093	Economy	29400.00
0005432649380	25093	Economy	29400.00
0005435844328	25093	Economy	29400.00
0005432632661	25093	Economy	29400.00
0005432649389	25093	Economy	29400.00
0005435846262	25093	Economy	29400.00
0005435844331	25093	Economy	29400.00
0005432649376	25093	Economy	29400.00
0005432649374	25093	Economy	29400.00
0005432632643	25093	Economy	29400.00
0005432632672	25093	Economy	29400.00
0005435846269	25093	Economy	29400.00
0005432649352	25093	Economy	29400.00
0005435844330	25093	Economy	29400.00
0005432649386	25093	Economy	29400.00
0005432632660	25093	Economy	29400.00
0005432649379	25093	Economy	29400.00
0005435846268	25093	Economy	29400.00
0005432649366	25093	Economy	29400.00
0005432632694	25093	Economy	29400.00
0005433008413	1787	Business	48700.00
0005433285179	1787	Business	48700.00
0005433008609	1787	Business	48700.00
0005433008486	1787	Business	48700.00
0005433008414	1787	Business	48700.00
0005433008443	1787	Business	48700.00
0005433285262	1787	Business	48700.00
0005433008395	1787	Business	48700.00
0005433008510	1787	Business	48700.00
0005433285280	1787	Business	48700.00
0005433008352	1787	Business	48700.00
0005433008350	1787	Economy	16200.00
0005433285158	1787	Economy	16200.00
0005433810568	1787	Economy	16200.00
0005433285075	1787	Economy	16200.00
0005433008397	1787	Economy	16200.00
0005433008253	1787	Economy	16200.00
0005433008525	1787	Economy	16200.00
0005433008459	1787	Economy	16200.00
0005432295890	1787	Economy	17900.00
0005433285115	1787	Economy	17900.00
0005433285169	1787	Economy	17900.00
0005433008386	1787	Economy	17900.00
0005433008384	1787	Economy	17900.00
0005432295889	1787	Economy	16200.00
0005433008478	1787	Economy	16200.00
0005433285196	1787	Economy	16200.00
0005433008351	1787	Economy	16200.00
0005433008390	1787	Economy	16200.00
0005433008307	1787	Economy	16200.00
0005433008467	1787	Economy	16200.00
0005432295891	1787	Economy	16200.00
0005433008208	1787	Economy	16200.00
0005433008446	1787	Economy	16200.00
0005433008509	1787	Economy	16200.00
0005433008385	1787	Economy	16200.00
0005433008358	1787	Economy	16200.00
0005433285152	1787	Economy	16200.00
0005433285323	1787	Economy	16200.00
0005433008411	1787	Economy	16200.00
0005433008517	1787	Economy	16200.00
0005433285233	1787	Economy	16200.00
0005433285187	1787	Economy	16200.00
0005433008548	1787	Economy	16200.00
0005433008477	1787	Economy	16200.00
0005433285263	1787	Economy	16200.00
0005433285195	1787	Economy	16200.00
0005433285080	1787	Economy	16200.00
0005433008394	1787	Economy	16200.00
0005433008249	1787	Economy	16200.00
0005433008323	1787	Economy	16200.00
0005433008472	1787	Economy	16200.00
0005433285151	1787	Economy	16200.00
0005433810569	1787	Economy	16200.00
0005433008248	1787	Economy	16200.00
0005433810570	1787	Economy	16200.00
0005433008368	1787	Economy	16200.00
0005433008468	1787	Economy	16200.00
0005433008523	1787	Economy	16200.00
0005433810567	1787	Economy	16200.00
0005433285221	1787	Economy	16200.00
0005433810571	1787	Economy	16200.00
0005433008322	1787	Economy	16200.00
0005433285188	1787	Economy	16200.00
0005433285199	1787	Economy	16200.00
0005433008412	1787	Economy	16200.00
0005433008369	1787	Economy	16200.00
0005433008326	1787	Economy	16200.00
0005433285113	1787	Economy	16200.00
0005433285130	1787	Economy	16200.00
0005433285261	1787	Economy	16200.00
0005433008393	1787	Economy	16200.00
0005433008579	1787	Economy	16200.00
0005433008339	1787	Economy	16200.00
0005433008458	1787	Economy	16200.00
0005433285258	1787	Economy	16200.00
0005433008547	1787	Economy	16200.00
0005433008349	1787	Economy	16200.00
0005433008389	1787	Economy	16200.00
0005433008608	1787	Economy	16200.00
0005433285074	1787	Economy	16200.00
0005433008447	1787	Economy	16200.00
0005433285219	1787	Economy	16200.00
0005433008281	1787	Economy	16200.00
0005433285402	22585	Business	48700.00
0005433285395	22585	Business	48700.00
0005433285405	22585	Business	48700.00
0005433285420	22585	Business	48700.00
0005433008757	22585	Business	48700.00
0005433285406	22585	Business	48700.00
0005433008788	22585	Business	48700.00
0005433008753	22585	Business	48700.00
0005433008763	22585	Economy	16200.00
0005433008789	22585	Economy	16200.00
0005433285415	22585	Economy	16200.00
0005433008783	22585	Economy	16200.00
0005433008769	22585	Economy	16200.00
0005433285410	22585	Economy	16200.00
0005433008764	22585	Economy	16200.00
0005433285408	22585	Economy	17900.00
0005433008775	22585	Economy	17900.00
0005433008760	22585	Economy	17900.00
0005433285401	22585	Economy	16200.00
0005433285400	22585	Economy	16200.00
0005433008765	22585	Economy	16200.00
0005433285423	22585	Economy	16200.00
0005433285409	22585	Economy	16200.00
0005433285393	22585	Economy	16200.00
0005433285418	22585	Economy	16200.00
0005433285413	22585	Economy	16200.00
0005433285396	22585	Economy	16200.00
0005433008779	22585	Economy	16200.00
0005433008767	22585	Economy	16200.00
0005433008785	22585	Economy	16200.00
0005433008778	22585	Economy	16200.00
0005433008768	22585	Economy	16200.00
0005433008774	22585	Economy	16200.00
0005433008777	22585	Economy	16200.00
0005433008786	22585	Economy	16200.00
0005433008773	22585	Economy	16200.00
0005433008780	22585	Economy	16200.00
0005433285417	22585	Economy	16200.00
0005433285392	22585	Economy	16200.00
0005433008791	22585	Economy	16200.00
0005433008795	22585	Economy	16200.00
0005433285421	22585	Economy	16200.00
0005433285422	22585	Economy	16200.00
0005433285416	22585	Economy	16200.00
0005433008784	22585	Economy	16200.00
0005433008794	22585	Economy	16200.00
0005433008756	22585	Economy	16200.00
0005433008772	22585	Economy	16200.00
0005433008787	22585	Economy	16200.00
0005433285412	22585	Economy	16200.00
0005433008751	22585	Economy	16200.00
0005433285403	22585	Economy	16200.00
0005433008762	22585	Economy	16200.00
0005433008770	22585	Economy	16200.00
0005433008796	22585	Economy	16200.00
0005433008761	22585	Economy	16200.00
0005433008754	22585	Economy	16200.00
0005433008766	22585	Economy	16200.00
0005433285419	22585	Economy	16200.00
0005433008790	22585	Economy	16200.00
0005433008758	22585	Economy	16200.00
0005433285399	22585	Economy	16200.00
0005433008793	22585	Economy	16200.00
0005433285411	22585	Economy	16200.00
0005433285398	22585	Economy	16200.00
0005433285414	22585	Economy	16200.00
0005433008776	22585	Economy	16200.00
0005433008792	22585	Economy	16200.00
0005433285407	22585	Economy	16200.00
0005433008759	22585	Economy	16200.00
0005433285394	22585	Economy	16200.00
0005433008750	22585	Economy	16200.00
0005433008755	22585	Economy	16200.00
0005433008782	22585	Economy	16200.00
0005433285404	22585	Economy	16200.00
0005433008752	22585	Economy	16200.00
0005433008771	22585	Economy	16200.00
0005433008781	22585	Economy	16200.00
0005433285397	22585	Economy	16200.00
0005432756857	25335	Business	83800.00
0005432756847	25335	Business	83800.00
0005434152780	25335	Business	83800.00
0005432756856	25335	Business	83800.00
0005432755086	25335	Business	83800.00
0005432756845	25335	Economy	27900.00
0005434152777	25335	Economy	27900.00
0005432755081	25335	Economy	27900.00
0005432755080	25335	Economy	27900.00
0005434152779	25335	Economy	30700.00
0005432755076	25335	Economy	30700.00
0005432756848	25335	Economy	27900.00
0005432756851	25335	Economy	27900.00
0005432755075	25335	Economy	27900.00
0005432756852	25335	Economy	27900.00
0005432755078	25335	Economy	27900.00
0005432756855	25335	Economy	27900.00
0005432756849	25335	Economy	27900.00
0005434152774	25335	Economy	27900.00
0005432756846	25335	Economy	27900.00
0005432756853	25335	Economy	27900.00
0005434152776	25335	Economy	27900.00
0005432756850	25335	Economy	27900.00
0005434153529	25335	Economy	27900.00
0005434152778	25335	Economy	27900.00
0005432755085	25335	Economy	27900.00
0005432755082	25335	Economy	27900.00
0005432756860	25335	Economy	27900.00
0005434153525	25335	Economy	27900.00
0005432756854	25335	Economy	27900.00
0005432755079	25335	Economy	27900.00
0005432755074	25335	Economy	27900.00
0005432756858	25335	Economy	27900.00
0005432755083	25335	Economy	27900.00
0005432756859	25335	Economy	27900.00
0005432755084	25335	Economy	27900.00
0005432755073	25335	Economy	27900.00
0005432755077	25335	Economy	27900.00
0005433846952	5570	Business	99800.00
0005433846930	5570	Business	99800.00
0005433846938	5570	Business	99800.00
0005433846922	5570	Business	99800.00
0005435282340	5570	Business	99800.00
0005435282377	5570	Business	99800.00
0005433815403	5570	Business	99800.00
0005433846962	5570	Business	99800.00
0005433846924	5570	Business	99800.00
0005433846972	5570	Business	99800.00
0005433846927	5570	Business	99800.00
0005433846945	5570	Business	99800.00
0005433846963	5570	Business	99800.00
0005432081535	5570	Business	99800.00
0005435282393	5570	Economy	33300.00
0005433846956	5570	Business	99800.00
0005433846960	5570	Economy	33300.00
0005433846935	5570	Economy	33300.00
0005433846939	5570	Economy	33300.00
0005433846955	5570	Economy	33300.00
0005433846973	5570	Economy	33300.00
0005435282505	5570	Economy	33300.00
0005433846965	5570	Economy	33300.00
0005435282346	5570	Economy	33300.00
0005433846950	5570	Economy	33300.00
0005435282402	5570	Economy	36600.00
0005433815400	5570	Economy	36600.00
0005433846937	5570	Economy	36600.00
0005433846940	5570	Economy	36600.00
0005434173507	5570	Economy	33300.00
0005433846923	5570	Economy	33300.00
0005433846947	5570	Economy	33300.00
0005435282434	5570	Economy	33300.00
0005432081532	5570	Economy	33300.00
0005433846948	5570	Economy	33300.00
0005433846942	5570	Economy	33300.00
0005433846958	5570	Economy	33300.00
0005433846944	5570	Economy	33300.00
0005433846976	5570	Economy	33300.00
0005433846933	5570	Economy	33300.00
0005433846951	5570	Economy	33300.00
0005432081537	5570	Economy	33300.00
0005433815402	5570	Economy	33300.00
0005435282442	5570	Economy	33300.00
0005433846957	5570	Economy	33300.00
0005433846918	5570	Economy	33300.00
0005433846934	5570	Economy	33300.00
0005433846921	5570	Economy	33300.00
0005433846925	5570	Economy	33300.00
0005433815401	5570	Economy	33300.00
0005433846943	5570	Economy	33300.00
0005433846926	5570	Economy	33300.00
0005433846928	5570	Economy	33300.00
0005434173506	5570	Economy	33300.00
0005435282371	5570	Economy	33300.00
0005433846959	5570	Economy	33300.00
0005435282452	5570	Economy	33300.00
0005435282374	5570	Economy	33300.00
0005433846971	5570	Economy	33300.00
0005433846967	5570	Economy	33300.00
0005433846964	5570	Economy	33300.00
0005433846970	5570	Economy	33300.00
0005433846954	5570	Economy	33300.00
0005435282275	5570	Economy	33300.00
0005432081534	5570	Economy	33300.00
0005433846932	5570	Economy	33300.00
0005434173489	5570	Economy	33300.00
0005433846919	5570	Economy	33300.00
0005433846968	5570	Economy	33300.00
0005433846949	5570	Economy	33300.00
0005433846953	5570	Economy	33300.00
0005433846969	5570	Economy	33300.00
0005435282347	5570	Economy	33300.00
0005433846929	5570	Economy	33300.00
0005433846920	5570	Economy	33300.00
0005433846936	5570	Economy	33300.00
0005433846966	5570	Economy	33300.00
0005433846941	5570	Economy	33300.00
0005433846946	5570	Economy	33300.00
0005432081533	5570	Economy	33300.00
0005432081538	5570	Economy	33300.00
0005435282297	5570	Economy	33300.00
0005433846974	5570	Economy	33300.00
0005435282449	5570	Economy	33300.00
0005435282364	5570	Economy	33300.00
0005435282451	5570	Economy	33300.00
0005434173525	5570	Economy	33300.00
0005433846931	5570	Economy	33300.00
0005432081536	5570	Economy	33300.00
0005433846977	5570	Economy	33300.00
0005433846975	5570	Economy	33300.00
0005433846961	5570	Economy	33300.00
0005433846524	13859	Business	99800.00
0005433815357	13859	Business	99800.00
0005435282615	13859	Business	99800.00
0005435282612	13859	Business	99800.00
0005433846242	13859	Business	99800.00
0005433846363	13859	Business	99800.00
0005433846464	13859	Business	99800.00
0005433846236	13859	Business	99800.00
0005433846124	13859	Business	99800.00
0005434173536	13859	Business	99800.00
0005435282617	13859	Business	99800.00
0005433846610	13859	Business	99800.00
0005435282606	13859	Business	99800.00
0005435282608	13859	Business	99800.00
0005433846429	13859	Business	99800.00
0005435282610	13859	Business	99800.00
0005433846572	13859	Business	99800.00
0005434173537	13859	Business	99800.00
0005433846545	13859	Economy	33300.00
0005433846404	13859	Economy	33300.00
0005435282595	13859	Economy	33300.00
0005433846310	13859	Economy	33300.00
0005435282599	13859	Economy	33300.00
0005433846511	13859	Economy	33300.00
0005433846342	13859	Economy	33300.00
0005433846391	13859	Economy	33300.00
0005435282596	13859	Economy	33300.00
0005433846553	13859	Economy	36600.00
0005433846387	13859	Economy	36600.00
0005433846410	13859	Economy	36600.00
0005433846444	13859	Economy	36600.00
0005433846571	13859	Economy	33300.00
0005435282592	13859	Economy	33300.00
0005433846285	13859	Economy	33300.00
0005433815358	13859	Economy	33300.00
0005433846268	13859	Economy	33300.00
0005433846377	13859	Economy	33300.00
0005433846324	13859	Economy	33300.00
0005433846638	13859	Economy	33300.00
0005435282601	13859	Economy	33300.00
0005435282616	13859	Economy	33300.00
0005433846361	13859	Economy	33300.00
0005433846203	13859	Economy	33300.00
0005433846544	13859	Economy	33300.00
0005432003714	13859	Economy	33300.00
0005433846074	13859	Economy	33300.00
0005432003712	13859	Economy	33300.00
0005435282609	13859	Economy	33300.00
0005433846411	13859	Economy	33300.00
0005433846226	13859	Economy	33300.00
0005433846530	13859	Economy	33300.00
0005433846536	13859	Economy	33300.00
0005433846738	13859	Economy	33300.00
0005433846376	13859	Economy	33300.00
0005433846406	13859	Economy	33300.00
0005435282605	13859	Economy	33300.00
0005435282613	13859	Economy	33300.00
0005433846473	13859	Economy	33300.00
0005433846549	13859	Economy	33300.00
0005433846668	13859	Economy	33300.00
0005433846412	13859	Economy	33300.00
0005435282607	13859	Economy	33300.00
0005435282611	13859	Economy	33300.00
0005433846393	13859	Economy	33300.00
0005435282602	13859	Economy	33300.00
0005433846335	13859	Economy	33300.00
0005435282604	13859	Economy	33300.00
0005435282598	13859	Economy	33300.00
0005433846543	13859	Economy	33300.00
0005435282614	13859	Economy	33300.00
0005435282593	13859	Economy	33300.00
0005433846360	13859	Economy	33300.00
0005433846470	13859	Economy	33300.00
0005433846405	13859	Economy	33300.00
0005433846600	13859	Economy	33300.00
0005433846443	13859	Economy	33300.00
0005435282594	13859	Economy	33300.00
0005433846669	13859	Economy	33300.00
0005433846243	13859	Economy	33300.00
0005433846537	13859	Economy	33300.00
0005433846359	13859	Economy	33300.00
0005433846570	13859	Economy	33300.00
0005433846128	13859	Economy	33300.00
0005435282600	13859	Economy	33300.00
0005433846513	13859	Economy	33300.00
0005433846311	13859	Economy	33300.00
0005434173534	13859	Economy	33300.00
0005433846554	13859	Economy	33300.00
0005433846531	13859	Economy	33300.00
0005434173535	13859	Economy	33300.00
0005433846667	13859	Economy	33300.00
0005433846436	13859	Economy	33300.00
0005433846576	13859	Economy	33300.00
0005433846325	13859	Economy	33300.00
0005433846340	13859	Economy	33300.00
0005432003713	13859	Economy	33300.00
0005435282603	13859	Economy	33300.00
0005433846512	13859	Economy	33300.00
0005435282597	13859	Economy	33300.00
0005433846341	13859	Economy	33300.00
0005433846508	13859	Economy	33300.00
0005434620674	7799	Economy	16600.00
0005434620673	7799	Economy	16600.00
0005434620667	7799	Economy	15100.00
0005435332300	7799	Economy	15100.00
0005435332297	7799	Economy	15100.00
0005435332291	7799	Economy	15100.00
0005434620672	7799	Economy	15100.00
0005434620666	7799	Economy	15100.00
0005434620682	7799	Economy	15100.00
0005434620670	7799	Economy	15100.00
0005434620684	7799	Economy	15100.00
0005434620675	7799	Economy	15100.00
0005435332292	7799	Economy	15100.00
0005435332279	7799	Economy	15100.00
0005434620679	7799	Economy	15100.00
0005434620668	7799	Economy	15100.00
0005435332299	7799	Economy	15100.00
0005435332286	7799	Economy	15100.00
0005434620685	7799	Economy	15100.00
0005434620680	7799	Economy	15100.00
0005434620665	7799	Economy	15100.00
0005434620678	7799	Economy	15100.00
0005435332298	7799	Economy	15100.00
0005435332280	7799	Economy	15100.00
0005434620677	7799	Economy	15100.00
0005434620683	7799	Economy	15100.00
0005434620671	7799	Economy	15100.00
0005432112525	7799	Economy	15100.00
0005434620676	7799	Economy	15100.00
0005434620669	7799	Economy	15100.00
0005434620664	7799	Economy	15100.00
0005434620681	7799	Economy	15100.00
0005434620515	32993	Economy	16600.00
0005434620531	32993	Economy	16600.00
0005435332375	32993	Economy	16600.00
0005434620514	32993	Economy	16600.00
0005435332379	32993	Economy	15100.00
0005434620399	32993	Economy	15100.00
0005434620519	32993	Economy	15100.00
0005434620483	32993	Economy	15100.00
0005434620465	32993	Economy	15100.00
0005435332378	32993	Economy	15100.00
0005435332373	32993	Economy	15100.00
0005435332371	32993	Economy	15100.00
0005434620496	32993	Economy	15100.00
0005434620464	32993	Economy	15100.00
0005434620599	32993	Economy	15100.00
0005434620400	32993	Economy	15100.00
0005434620564	32993	Economy	15100.00
0005435332377	32993	Economy	15100.00
0005434620513	32993	Economy	15100.00
0005434620448	32993	Economy	15100.00
0005434620529	32993	Economy	15100.00
0005434620498	32993	Economy	15100.00
0005434620418	32993	Economy	15100.00
0005434620601	32993	Economy	15100.00
0005434620497	32993	Economy	15100.00
0005435332374	32993	Economy	15100.00
0005434620492	32993	Economy	15100.00
0005434620500	32993	Economy	15100.00
0005434620462	32993	Economy	15100.00
0005434620484	32993	Economy	15100.00
0005434620489	32993	Economy	15100.00
0005434620450	32993	Economy	15100.00
0005435332376	32993	Economy	15100.00
0005435332380	32993	Economy	15100.00
0005435332370	32993	Economy	15100.00
0005434620600	32993	Economy	15100.00
0005435332372	32993	Economy	15100.00
0005435785490	4299	Business	38000.00
0005435785499	4299	Business	38000.00
0005435785476	4299	Business	38000.00
0005434994058	4299	Business	38000.00
0005434994057	4299	Business	38000.00
0005435785491	4299	Business	38000.00
0005435785487	4299	Business	38000.00
0005435785482	4299	Business	38000.00
0005435785495	4299	Business	38000.00
0005435785506	4299	Business	38000.00
0005435785478	4299	Business	38000.00
0005435785485	4299	Economy	12700.00
0005435785474	4299	Economy	12700.00
0005435787364	4299	Economy	12700.00
0005434994061	4299	Economy	12700.00
0005435785473	4299	Economy	12700.00
0005435785497	4299	Economy	12700.00
0005435918661	4299	Economy	13900.00
0005435785500	4299	Economy	13900.00
0005435787361	4299	Economy	12700.00
0005435785472	4299	Economy	12700.00
0005435785481	4299	Economy	12700.00
0005435785479	4299	Economy	12700.00
0005435785493	4299	Economy	12700.00
0005435937356	4299	Economy	12700.00
0005435785477	4299	Economy	12700.00
0005435918612	4299	Economy	12700.00
0005435785498	4299	Economy	12700.00
0005435785475	4299	Economy	12700.00
0005435937349	4299	Economy	12700.00
0005435785488	4299	Economy	12700.00
0005434994063	4299	Economy	12700.00
0005435785504	4299	Economy	12700.00
0005435918650	4299	Economy	12700.00
0005435785484	4299	Economy	12700.00
0005435785503	4299	Economy	12700.00
0005432190645	4299	Economy	12700.00
0005435785505	4299	Economy	12700.00
0005435787362	4299	Economy	12700.00
0005432190643	4299	Economy	12700.00
0005435785483	4299	Economy	12700.00
0005435785471	4299	Economy	12700.00
0005435785480	4299	Economy	12700.00
0005434994064	4299	Economy	12700.00
0005434994059	4299	Economy	12700.00
0005435937337	4299	Economy	12700.00
0005435785489	4299	Economy	12700.00
0005435785492	4299	Economy	12700.00
0005434994060	4299	Economy	12700.00
0005435785502	4299	Economy	12700.00
0005435785494	4299	Economy	12700.00
0005432190644	4299	Economy	12700.00
0005435785486	4299	Economy	12700.00
0005435918642	4299	Economy	12700.00
0005434994062	4299	Economy	12700.00
0005435785496	4299	Economy	12700.00
0005435785501	4299	Economy	12700.00
0005432190642	4299	Economy	12700.00
0005435787363	4299	Economy	12700.00
0005434993972	27310	Business	38000.00
0005435785064	27310	Business	38000.00
0005435785107	27310	Business	38000.00
0005435918672	27310	Business	38000.00
0005435785108	27310	Business	38000.00
0005435918677	27310	Business	38000.00
0005435918675	27310	Business	38000.00
0005435785194	27310	Business	38000.00
0005435785067	27310	Business	38000.00
0005435937399	27310	Business	38000.00
0005435785074	27310	Economy	12700.00
0005435785176	27310	Economy	12700.00
0005435785026	27310	Economy	12700.00
0005435785162	27310	Economy	12700.00
0005435787335	27310	Economy	12700.00
0005432195700	27310	Economy	12700.00
0005435918676	27310	Economy	12700.00
0005435785123	27310	Economy	13900.00
0005434993936	27310	Economy	13900.00
0005435785111	27310	Economy	13900.00
0005435785075	27310	Economy	12700.00
0005435937395	27310	Economy	12700.00
0005435785248	27310	Economy	12700.00
0005434994007	27310	Economy	12700.00
0005435785100	27310	Economy	12700.00
0005434993980	27310	Economy	12700.00
0005435785136	27310	Economy	12700.00
0005435785245	27310	Economy	12700.00
0005434993971	27310	Economy	12700.00
0005435918674	27310	Economy	12700.00
0005435785053	27310	Economy	12700.00
0005435785277	27310	Economy	12700.00
0005435785054	27310	Economy	12700.00
0005435785090	27310	Economy	12700.00
0005435785146	27310	Economy	12700.00
0005434994006	27310	Economy	12700.00
0005435785230	27310	Economy	12700.00
0005435785099	27310	Economy	12700.00
0005435785133	27310	Economy	12700.00
0005435784982	27310	Economy	12700.00
0005435785071	27310	Economy	12700.00
0005435937398	27310	Economy	12700.00
0005434994008	27310	Economy	12700.00
0005435785106	27310	Economy	12700.00
0005435785246	27310	Economy	12700.00
0005432195699	27310	Economy	12700.00
0005435785038	27310	Economy	12700.00
0005435785014	27310	Economy	12700.00
0005435785063	27310	Economy	12700.00
0005435937394	27310	Economy	12700.00
0005435785003	27310	Economy	12700.00
0005435937393	27310	Economy	12700.00
0005435785126	27310	Economy	12700.00
0005434993978	27310	Economy	12700.00
0005435785001	27310	Economy	12700.00
0005434993979	27310	Economy	12700.00
0005435937397	27310	Economy	12700.00
0005435784993	27310	Economy	12700.00
0005435937396	27310	Economy	12700.00
0005435785145	27310	Economy	12700.00
0005435785247	27310	Economy	12700.00
0005435918673	27310	Economy	12700.00
0005432146206	19880	Economy	12800.00
0005432146205	19880	Economy	12800.00
0005434081985	4721	Business	40900.00
0005433451627	4721	Business	40900.00
0005432571337	4721	Business	40900.00
0005432567841	4721	Business	40900.00
0005432567885	4721	Business	40900.00
0005432170415	4721	Business	40900.00
0005432460031	4721	Business	40900.00
0005432567894	4721	Business	40900.00
0005432460029	4721	Business	40900.00
0005432567865	4721	Business	40900.00
0005432567887	4721	Business	40900.00
0005432460035	4721	Business	40900.00
0005432567901	4721	Business	40900.00
0005432170413	4721	Business	40900.00
0005432460039	4721	Business	40900.00
0005434082000	4721	Business	40900.00
0005432460063	4721	Business	40900.00
0005432460033	4721	Business	40900.00
0005432567868	4721	Business	40900.00
0005432567858	4721	Business	40900.00
0005432567884	4721	Business	40900.00
0005432567888	4721	Economy	15000.00
0005432460043	4721	Economy	15000.00
0005432170411	4721	Economy	15000.00
0005432567857	4721	Economy	13600.00
0005432567870	4721	Economy	13600.00
0005432567846	4721	Economy	13600.00
0005432460060	4721	Economy	13600.00
0005432186883	4721	Economy	13600.00
0005432571335	4721	Economy	13600.00
0005433726112	4721	Economy	13600.00
0005432460037	4721	Economy	13600.00
0005432567898	4721	Economy	13600.00
0005432460046	4721	Economy	13600.00
0005433452748	4721	Economy	13600.00
0005432567879	4721	Economy	13600.00
0005432567861	4721	Economy	13600.00
0005432460069	4721	Economy	13600.00
0005434081990	4721	Economy	13600.00
0005434082003	4721	Economy	13600.00
0005432460075	4721	Economy	13600.00
0005432460071	4721	Economy	13600.00
0005434082007	4721	Economy	13600.00
0005434082005	4721	Economy	13600.00
0005432460027	4721	Economy	13600.00
0005432460044	4721	Economy	13600.00
0005432567896	4721	Economy	13600.00
0005434081996	4721	Economy	13600.00
0005432567871	4721	Economy	13600.00
0005432460070	4721	Economy	13600.00
0005432567860	4721	Economy	13600.00
0005432460059	4721	Economy	13600.00
0005432460064	4721	Economy	13600.00
0005432460052	4721	Economy	13600.00
0005432567886	4721	Economy	13600.00
0005432460049	4721	Economy	13600.00
0005432567889	4721	Economy	13600.00
0005432567878	4721	Economy	13600.00
0005432567895	4721	Economy	13600.00
0005432567852	4721	Economy	13600.00
0005432567897	4721	Economy	13600.00
0005434081991	4721	Economy	13600.00
0005432460061	4721	Economy	13600.00
0005432460026	4721	Economy	13600.00
0005432567844	4721	Economy	13600.00
0005432460065	4721	Economy	13600.00
0005432460047	4721	Economy	13600.00
0005432567892	4721	Economy	13600.00
0005434082004	4721	Economy	13600.00
0005432460042	4721	Economy	13600.00
0005432567872	4721	Economy	13600.00
0005432571336	4721	Economy	13600.00
0005432170416	4721	Economy	13600.00
0005434081988	4721	Economy	13600.00
0005432460045	4721	Economy	13600.00
0005432567863	4721	Economy	13600.00
0005432567862	4721	Economy	13600.00
0005432170412	4721	Economy	13600.00
0005432567877	4721	Economy	13600.00
0005432460057	4721	Economy	13600.00
0005432567843	4721	Economy	13600.00
0005432460036	4721	Economy	13600.00
0005432460028	4721	Economy	13600.00
0005432460055	4721	Economy	13600.00
0005432460072	4721	Economy	13600.00
0005432460053	4721	Economy	13600.00
0005432460048	4721	Economy	13600.00
0005434081986	4721	Economy	13600.00
0005432567845	4721	Economy	13600.00
0005432460077	4721	Economy	13600.00
0005432567876	4721	Economy	13600.00
0005432460050	4721	Economy	13600.00
0005432567848	4721	Economy	13600.00
0005432567853	4721	Economy	15000.00
0005432460025	4721	Economy	15000.00
0005432567842	4721	Economy	13600.00
0005434081995	4721	Economy	15000.00
0005432186882	4721	Economy	15000.00
0005432567851	4721	Economy	13600.00
0005432460074	4721	Economy	13600.00
0005432567866	4721	Economy	13600.00
0005432567873	4721	Economy	13600.00
0005434081999	4721	Economy	13600.00
0005434082001	4721	Economy	13600.00
0005432567864	4721	Economy	13600.00
0005434081994	4721	Economy	13600.00
0005432460067	4721	Economy	13600.00
0005432460058	4721	Economy	13600.00
0005432567880	4721	Economy	13600.00
0005432460056	4721	Economy	13600.00
0005432460038	4721	Economy	13600.00
0005432567883	4721	Economy	13600.00
0005432567847	4721	Economy	13600.00
0005434082006	4721	Economy	13600.00
0005433451626	4721	Economy	13600.00
0005432460034	4721	Economy	13600.00
0005432567881	4721	Economy	13600.00
0005432567850	4721	Economy	13600.00
0005432186885	4721	Economy	13600.00
0005432567869	4721	Economy	13600.00
0005432460066	4721	Economy	13600.00
0005434081987	4721	Economy	13600.00
0005434081989	4721	Economy	13600.00
0005433452747	4721	Economy	13600.00
0005432460032	4721	Economy	13600.00
0005432460062	4721	Economy	13600.00
0005432567855	4721	Economy	13600.00
0005432567875	4721	Economy	13600.00
0005432567893	4721	Economy	13600.00
0005433726113	4721	Economy	13600.00
0005434081998	4721	Economy	13600.00
0005432170410	4721	Economy	13600.00
0005432567839	4721	Economy	13600.00
0005432460030	4721	Economy	13600.00
0005432186884	4721	Economy	13600.00
0005432460040	4721	Economy	13600.00
0005432567856	4721	Economy	13600.00
0005432567854	4721	Economy	13600.00
0005432460054	4721	Economy	13600.00
0005434081993	4721	Economy	13600.00
0005432460076	4721	Economy	13600.00
0005432567849	4721	Economy	13600.00
0005432567890	4721	Economy	13600.00
0005434081992	4721	Economy	13600.00
0005432567882	4721	Economy	13600.00
0005434082002	4721	Economy	13600.00
0005432460073	4721	Economy	13600.00
0005432567867	4721	Economy	13600.00
0005432567891	4721	Economy	13600.00
0005432460068	4721	Economy	13600.00
0005432567840	4721	Economy	13600.00
0005432567859	4721	Economy	13600.00
0005432571334	4721	Economy	13600.00
0005432460041	4721	Economy	13600.00
0005432567874	4721	Economy	13600.00
0005432170414	4721	Economy	13600.00
0005432567900	4721	Economy	13600.00
0005432567899	4721	Economy	13600.00
0005432460051	4721	Economy	13600.00
0005434081997	4721	Economy	13600.00
0005432567523	30550	Business	40900.00
0005432567283	30550	Business	40900.00
0005432459461	30550	Business	40900.00
0005432571287	30550	Business	40900.00
0005432567300	30550	Business	40900.00
0005432459759	30550	Business	40900.00
0005432459680	30550	Business	40900.00
0005432567256	30550	Business	40900.00
0005432567498	30550	Business	40900.00
0005432161161	30550	Business	40900.00
0005432567484	30550	Business	40900.00
0005432459718	30550	Business	40900.00
0005434081782	30550	Business	40900.00
0005432213619	30550	Business	40900.00
0005432459842	30550	Business	40900.00
0005434081696	30550	Business	40900.00
0005432567454	30550	Business	40900.00
0005432567104	30550	Business	40900.00
0005432459672	30550	Business	40900.00
0005432571308	30550	Economy	15000.00
0005432459755	30550	Economy	13600.00
0005432459771	30550	Economy	15000.00
0005432459697	30550	Economy	13600.00
0005432459411	30550	Economy	13600.00
0005434081785	30550	Economy	13600.00
0005432459549	30550	Economy	13600.00
0005432567028	30550	Economy	13600.00
0005432567302	30550	Economy	13600.00
0005432459839	30550	Economy	13600.00
0005433452725	30550	Economy	13600.00
0005432567468	30550	Economy	13600.00
0005432459596	30550	Economy	13600.00
0005434081712	30550	Economy	13600.00
0005432459748	30550	Economy	13600.00
0005432567103	30550	Economy	13600.00
0005432567236	30550	Economy	13600.00
0005432459812	30550	Economy	13600.00
0005434081741	30550	Economy	13600.00
0005433452729	30550	Economy	13600.00
0005434081725	30550	Economy	13600.00
0005433452730	30550	Economy	13600.00
0005432459810	30550	Economy	13600.00
0005432459544	30550	Economy	13600.00
0005432567636	30550	Economy	13600.00
0005434081793	30550	Economy	13600.00
0005432567255	30550	Economy	13600.00
0005432459722	30550	Economy	13600.00
0005432459811	30550	Economy	13600.00
0005434081684	30550	Economy	13600.00
0005432459575	30550	Economy	13600.00
0005432567460	30550	Economy	13600.00
0005432459568	30550	Economy	13600.00
0005432459443	30550	Economy	13600.00
0005432567473	30550	Economy	13600.00
0005432567506	30550	Economy	13600.00
0005432459645	30550	Economy	13600.00
0005433454864	30550	Economy	13600.00
0005432567257	30550	Economy	13600.00
0005432567282	30550	Economy	13600.00
0005432459442	30550	Economy	13600.00
0005432567424	30550	Economy	13600.00
0005434081640	30550	Economy	13600.00
0005432459699	30550	Economy	13600.00
0005432459491	30550	Economy	13600.00
0005434081685	30550	Economy	13600.00
0005432567479	30550	Economy	13600.00
0005434081779	30550	Economy	13600.00
0005434081780	30550	Economy	13600.00
0005432567324	30550	Economy	13600.00
0005432567577	30550	Economy	13600.00
0005434081781	30550	Economy	13600.00
0005432567505	30550	Economy	13600.00
0005432459462	30550	Economy	13600.00
0005432459620	30550	Economy	13600.00
0005432567301	30550	Economy	13600.00
0005432567390	30550	Economy	13600.00
0005432567478	30550	Economy	13600.00
0005432459534	30550	Economy	13600.00
0005432459621	30550	Economy	13600.00
0005432567281	30550	Economy	13600.00
0005432567483	30550	Economy	13600.00
0005432571305	30550	Economy	13600.00
0005434081815	30550	Economy	15000.00
0005432567459	30550	Economy	15000.00
0005432459717	30550	Economy	13600.00
0005432459396	30550	Economy	13600.00
0005434081814	30550	Economy	13600.00
0005432459577	30550	Economy	15000.00
0005434081792	30550	Economy	15000.00
0005432567235	30550	Economy	13600.00
0005432459681	30550	Economy	13600.00
0005432459686	30550	Economy	13600.00
0005432459731	30550	Economy	13600.00
0005432213623	30550	Economy	13600.00
0005432459687	30550	Economy	13600.00
0005432459843	30550	Economy	13600.00
0005432567123	30550	Economy	13600.00
0005432567457	30550	Economy	13600.00
0005432567325	30550	Economy	13600.00
0005434081689	30550	Economy	13600.00
0005432459716	30550	Economy	13600.00
0005434081813	30550	Economy	13600.00
0005432459543	30550	Economy	13600.00
0005434081777	30550	Economy	13600.00
0005432567237	30550	Economy	13600.00
0005432161160	30550	Economy	13600.00
0005432459616	30550	Economy	13600.00
0005432567474	30550	Economy	13600.00
0005432567187	30550	Economy	13600.00
0005432567485	30550	Economy	13600.00
0005432161162	30550	Economy	13600.00
0005432459556	30550	Economy	13600.00
0005432459679	30550	Economy	13600.00
0005432459760	30550	Economy	13600.00
0005432459728	30550	Economy	13600.00
0005433454867	30550	Economy	13600.00
0005432567364	30550	Economy	13600.00
0005432459395	30550	Economy	13600.00
0005432567228	30550	Economy	13600.00
0005434081639	30550	Economy	13600.00
0005432571299	30550	Economy	13600.00
0005434081745	30550	Economy	13600.00
0005433454869	30550	Economy	13600.00
0005432567372	30550	Economy	13600.00
0005432459723	30550	Economy	13600.00
0005434081786	30550	Economy	13600.00
0005432213621	30550	Economy	13600.00
0005432567190	30550	Economy	13600.00
0005432459698	30550	Economy	13600.00
0005432213622	30550	Economy	13600.00
0005432213620	30550	Economy	13600.00
0005433454868	30550	Economy	13600.00
0005432459420	30550	Economy	13600.00
0005432567438	30550	Economy	13600.00
0005432459497	30550	Economy	13600.00
0005432567157	30550	Economy	13600.00
0005432567401	30550	Economy	13600.00
0005432459576	30550	Economy	13600.00
0005432459533	30550	Economy	13600.00
0005434081724	30550	Economy	13600.00
0005432459779	30550	Economy	13600.00
0005434081713	30550	Economy	13600.00
0005432459790	30550	Economy	13600.00
0005432567354	30550	Economy	13600.00
0005435722065	13670	Economy	9900.00
0005435722064	13670	Economy	9900.00
0005435722066	13670	Economy	9900.00
0005435722063	13670	Economy	9900.00
0005435722053	21186	Economy	9900.00
0005435720131	21186	Economy	9900.00
0005435722052	21186	Economy	9900.00
0005432295889	22785	Economy	8800.00
0005432295890	22785	Economy	8800.00
0005432295891	22785	Economy	8800.00
0005433343527	11106	Business	23600.00
0005435508292	11106	Business	23600.00
0005433343518	11106	Business	23600.00
0005433343547	11106	Business	23600.00
0005433343560	11106	Business	23600.00
0005435508288	11106	Business	23600.00
0005433343568	11106	Business	23600.00
0005433343590	11106	Business	23600.00
0005433343584	11106	Business	23600.00
0005433343581	11106	Business	23600.00
0005433343532	11106	Economy	7900.00
0005433343564	11106	Economy	7900.00
0005433343587	11106	Economy	7900.00
0005435508284	11106	Economy	7900.00
0005435097229	11106	Economy	7900.00
0005433343525	11106	Economy	7900.00
0005433343615	11106	Economy	7900.00
0005433343536	11106	Economy	7900.00
0005433343583	11106	Economy	7900.00
0005435380280	11106	Economy	7900.00
0005433343598	11106	Economy	7900.00
0005433343541	11106	Economy	7900.00
0005433343573	11106	Economy	7900.00
0005433343595	11106	Economy	7900.00
0005435097232	11106	Economy	7900.00
0005433343556	11106	Economy	7900.00
0005433343570	11106	Economy	7900.00
0005435508293	11106	Economy	7900.00
0005433343561	11106	Economy	7900.00
0005433343533	11106	Economy	7900.00
0005433343519	11106	Economy	7900.00
0005433343604	11106	Economy	7900.00
0005433343548	11106	Economy	7900.00
0005433343592	11106	Economy	7900.00
0005433343545	11106	Economy	7900.00
0005433343569	11106	Economy	7900.00
0005433343540	11106	Economy	7900.00
0005433343572	11106	Economy	7900.00
0005433343558	11106	Economy	7900.00
0005435097235	11106	Economy	7900.00
0005433343516	11106	Economy	7900.00
0005433343529	11106	Economy	7900.00
0005433343575	11106	Economy	7900.00
0005433343588	11106	Economy	7900.00
0005433343574	11106	Economy	7900.00
0005433343579	11106	Economy	7900.00
0005433343614	11106	Economy	7900.00
0005435508280	11106	Economy	7900.00
0005433343578	11106	Economy	7900.00
0005433343600	11106	Economy	7900.00
0005435508285	11106	Economy	8600.00
0005433343550	11106	Economy	8600.00
0005433343554	11106	Economy	8600.00
0005433343517	11106	Economy	8600.00
0005433343528	11106	Economy	8600.00
0005433343608	11106	Economy	8600.00
0005433343605	11106	Economy	7900.00
0005435097231	11106	Economy	7900.00
0005433343539	11106	Economy	7900.00
0005433343553	11106	Economy	7900.00
0005433343534	11106	Economy	7900.00
0005433343542	11106	Economy	7900.00
0005433343606	11106	Economy	7900.00
0005433343551	11106	Economy	7900.00
0005433343557	11106	Economy	7900.00
0005433343526	11106	Economy	7900.00
0005433343601	11106	Economy	7900.00
0005433343566	11106	Economy	7900.00
0005433343589	11106	Economy	7900.00
0005433343531	11106	Economy	7900.00
0005433343520	11106	Economy	7900.00
0005433343582	11106	Economy	7900.00
0005433343577	11106	Economy	7900.00
0005433343580	11106	Economy	7900.00
0005433343546	11106	Economy	7900.00
0005433343523	11106	Economy	7900.00
0005433343613	11106	Economy	7900.00
0005433343559	11106	Economy	7900.00
0005433343563	11106	Economy	7900.00
0005433343535	11106	Economy	7900.00
0005435380279	11106	Economy	7900.00
0005435097230	11106	Economy	7900.00
0005435380278	11106	Economy	7900.00
0005433343515	11106	Economy	7900.00
0005433343609	11106	Economy	7900.00
0005433343597	11106	Economy	7900.00
0005433343538	11106	Economy	7900.00
0005435097234	11106	Economy	7900.00
0005433343610	11106	Economy	7900.00
0005433343616	11106	Economy	7900.00
0005433343602	11106	Economy	7900.00
0005435097233	11106	Economy	7900.00
0005433343586	11106	Economy	7900.00
0005433343612	11106	Economy	7900.00
0005433343591	11106	Economy	7900.00
0005435508253	11106	Economy	7900.00
0005435380277	11106	Economy	7900.00
0005433343543	11106	Economy	7900.00
0005433343585	11106	Economy	7900.00
0005433343611	11106	Economy	7900.00
0005433343593	11106	Economy	7900.00
0005433343571	11106	Economy	7900.00
0005433343521	11106	Economy	7900.00
0005433343562	11106	Economy	7900.00
0005435097225	11106	Economy	7900.00
0005433343596	11106	Economy	7900.00
0005433343555	11106	Economy	7900.00
0005435508274	11106	Economy	7900.00
0005433343567	11106	Economy	7900.00
0005433343565	11106	Economy	7900.00
0005433343522	11106	Economy	7900.00
0005433343549	11106	Economy	7900.00
0005433343599	11106	Economy	7900.00
0005433343607	11106	Economy	7900.00
0005433343537	11106	Economy	7900.00
0005433343594	11106	Economy	7900.00
0005433343576	11106	Economy	7900.00
0005433343544	11106	Economy	7900.00
0005435508252	11106	Economy	7900.00
0005435097228	11106	Economy	7900.00
0005433343530	11106	Economy	7900.00
0005435097226	11106	Economy	7900.00
0005433343552	11106	Economy	7900.00
0005435380270	11106	Economy	7900.00
0005435097227	11106	Economy	7900.00
0005433343524	11106	Economy	7900.00
0005433343603	11106	Economy	7900.00
0005435380312	17102	Business	23600.00
0005433342613	17102	Business	23600.00
0005435097189	17102	Business	23600.00
0005435097173	17102	Business	23600.00
0005433342795	17102	Business	23600.00
0005433342796	17102	Business	23600.00
0005433341893	17102	Business	23600.00
0005433342881	17102	Business	23600.00
0005433342740	17102	Business	23600.00
0005433342907	17102	Business	23600.00
0005433342888	17102	Business	23600.00
0005432293219	17102	Business	23600.00
0005433342414	17102	Economy	7900.00
0005435380314	17102	Economy	7900.00
0005433342470	17102	Economy	7900.00
0005435097146	17102	Economy	7900.00
0005433342203	17102	Economy	7900.00
0005433343211	17102	Economy	7900.00
0005433341823	17102	Economy	7900.00
0005433342717	17102	Economy	7900.00
0005433342151	17102	Economy	7900.00
0005435380311	17102	Economy	7900.00
0005435545769	17102	Economy	7900.00
0005433342206	17102	Economy	7900.00
0005433342624	17102	Economy	7900.00
0005433342457	17102	Economy	7900.00
0005435097171	17102	Economy	7900.00
0005433342001	17102	Economy	7900.00
0005433342614	17102	Economy	7900.00
0005435545768	17102	Economy	7900.00
0005433342488	17102	Economy	7900.00
0005433342906	17102	Economy	7900.00
0005433342489	17102	Economy	7900.00
0005433342202	17102	Economy	7900.00
0005433342628	17102	Economy	7900.00
0005433342850	17102	Economy	7900.00
0005433342184	17102	Economy	7900.00
0005433342554	17102	Economy	7900.00
0005433342220	17102	Economy	7900.00
0005433342525	17102	Economy	7900.00
0005433342889	17102	Economy	7900.00
0005432293217	17102	Economy	7900.00
0005433342431	17102	Economy	7900.00
0005433342503	17102	Economy	7900.00
0005433341824	17102	Economy	7900.00
0005433342442	17102	Economy	7900.00
0005433342879	17102	Economy	7900.00
0005433342530	17102	Economy	7900.00
0005433342693	17102	Economy	7900.00
0005433342551	17102	Economy	7900.00
0005433342880	17102	Economy	7900.00
0005433342313	17102	Economy	8600.00
0005433342599	17102	Economy	8600.00
0005435097200	17102	Economy	8600.00
0005433342674	17102	Economy	8600.00
0005435380313	17102	Economy	8600.00
0005433342629	17102	Economy	7900.00
0005433342882	17102	Economy	8600.00
0005433342791	17102	Economy	7900.00
0005433342152	17102	Economy	7900.00
0005432293218	17102	Economy	7900.00
0005433342546	17102	Economy	7900.00
0005433342692	17102	Economy	7900.00
0005435097187	17102	Economy	7900.00
0005433342787	17102	Economy	7900.00
0005435097161	17102	Economy	7900.00
0005433342098	17102	Economy	7900.00
0005433342545	17102	Economy	7900.00
0005433342903	17102	Economy	7900.00
0005433342311	17102	Economy	7900.00
0005433342565	17102	Economy	7900.00
0005433342948	17102	Economy	7900.00
0005433342884	17102	Economy	7900.00
0005433342524	17102	Economy	7900.00
0005433342575	17102	Economy	7900.00
0005435097123	17102	Economy	7900.00
0005433342487	17102	Economy	7900.00
0005433342609	17102	Economy	7900.00
0005433342930	17102	Economy	7900.00
0005433342781	17102	Economy	7900.00
0005433342904	17102	Economy	7900.00
0005433342587	17102	Economy	7900.00
0005433343212	17102	Economy	7900.00
0005435097147	17102	Economy	7900.00
0005433342322	17102	Economy	7900.00
0005433342471	17102	Economy	7900.00
0005433342697	17102	Economy	7900.00
0005433342532	17102	Economy	7900.00
0005433342869	17102	Economy	7900.00
0005433342650	17102	Economy	7900.00
0005433342885	17102	Economy	7900.00
0005433342780	17102	Economy	7900.00
0005433342492	17102	Economy	7900.00
0005433342675	17102	Economy	7900.00
0005433342394	17102	Economy	7900.00
0005433342586	17102	Economy	7900.00
0005433342502	17102	Economy	7900.00
0005435097124	17102	Economy	7900.00
0005433342620	17102	Economy	7900.00
0005433342870	17102	Economy	7900.00
0005435097201	17102	Economy	7900.00
0005433342652	17102	Economy	7900.00
0005433342905	17102	Economy	7900.00
0005435097172	17102	Economy	7900.00
0005433342400	17102	Economy	7900.00
0005435097166	17102	Economy	7900.00
0005435097179	17102	Economy	7900.00
0005435097159	17102	Economy	7900.00
0005435380315	17102	Economy	7900.00
0005433342949	17102	Economy	7900.00
0005435097148	17102	Economy	7900.00
0005433342947	17102	Economy	7900.00
0005433342707	17102	Economy	7900.00
0005433342522	17102	Economy	7900.00
0005435097157	17102	Economy	7900.00
0005435097186	17102	Economy	7900.00
0005433342415	17102	Economy	7900.00
0005433342133	17102	Economy	7900.00
0005433342097	17102	Economy	7900.00
0005433342441	17102	Economy	7900.00
0005433343205	17102	Economy	7900.00
0005433342002	17102	Economy	7900.00
0005433342533	17102	Economy	7900.00
0005433342443	17102	Economy	7900.00
0005433342399	17102	Economy	7900.00
0005433342648	17102	Economy	7900.00
0005433342223	17102	Economy	7900.00
0005433342604	17102	Economy	7900.00
0005433507263	9114	Business	26600.00
0005432919820	9114	Business	26600.00
0005432919789	9114	Business	26600.00
0005432919716	9114	Business	26600.00
0005433481199	9114	Business	26600.00
0005433507254	9114	Economy	8900.00
0005432919743	9114	Economy	8900.00
0005432919738	9114	Economy	8900.00
0005432919787	9114	Economy	8900.00
0005432919715	9114	Economy	8900.00
0005433507265	9114	Economy	9800.00
0005432919742	9114	Economy	9800.00
0005432919821	9114	Economy	9800.00
0005433507253	9114	Economy	8900.00
0005432919745	9114	Economy	8900.00
0005432919740	9114	Economy	8900.00
0005432919714	9114	Economy	8900.00
0005433507256	9114	Economy	8900.00
0005433481201	9114	Economy	8900.00
0005433481197	9114	Economy	8900.00
0005433481200	9114	Economy	8900.00
0005433481202	9114	Economy	8900.00
0005432919794	9114	Economy	8900.00
0005432919741	9114	Economy	8900.00
0005433507267	9114	Economy	8900.00
0005433507252	9114	Economy	8900.00
0005433481195	9114	Economy	8900.00
0005433507258	9114	Economy	8900.00
0005433507266	9114	Economy	8900.00
0005432919729	9114	Economy	8900.00
0005432919771	9114	Economy	8900.00
0005433507257	9114	Economy	8900.00
0005432919819	9114	Economy	8900.00
0005432919767	9114	Economy	8900.00
0005432919688	9114	Economy	8900.00
0005432919786	9114	Economy	8900.00
0005433507261	9114	Economy	8900.00
0005433507262	9114	Economy	8900.00
0005433507268	9114	Economy	8900.00
0005433507255	9114	Economy	8900.00
0005433481198	9114	Economy	8900.00
0005432919774	9114	Economy	8900.00
0005433507259	9114	Economy	8900.00
0005433481196	9114	Economy	8900.00
0005432919730	9114	Economy	8900.00
0005433481194	9114	Economy	8900.00
0005433507264	9114	Economy	8900.00
0005433507260	9114	Economy	8900.00
0005432919744	9114	Economy	8900.00
0005432919812	9114	Economy	8900.00
0005432919775	9114	Economy	8900.00
0005433507251	9114	Economy	8900.00
0005432919765	9114	Economy	8900.00
0005432919971	20486	Business	26600.00
0005433481153	20486	Economy	8900.00
0005432919970	20486	Economy	8900.00
0005433481185	20486	Economy	8900.00
0005432919959	20486	Economy	8900.00
0005433481109	20486	Economy	9800.00
0005432919952	20486	Economy	9800.00
0005433507126	20486	Economy	9800.00
0005432919973	20486	Economy	9800.00
0005432919963	20486	Economy	8900.00
0005432919967	20486	Economy	8900.00
0005432919964	20486	Economy	8900.00
0005432919953	20486	Economy	8900.00
0005433481143	20486	Economy	8900.00
0005433507092	20486	Economy	8900.00
0005433507094	20486	Economy	8900.00
0005432919968	20486	Economy	8900.00
0005432919956	20486	Economy	8900.00
0005433481132	20486	Economy	8900.00
0005432919958	20486	Economy	8900.00
0005433481158	20486	Economy	8900.00
0005432919961	20486	Economy	8900.00
0005433507100	20486	Economy	8900.00
0005433507132	20486	Economy	8900.00
0005432919972	20486	Economy	8900.00
0005432919957	20486	Economy	8900.00
0005432919965	20486	Economy	8900.00
0005432919962	20486	Economy	8900.00
0005433481159	20486	Economy	8900.00
0005433481110	20486	Economy	8900.00
0005433507119	20486	Economy	8900.00
0005433481118	20486	Economy	8900.00
0005432919960	20486	Economy	8900.00
0005432919955	20486	Economy	8900.00
0005433507117	20486	Economy	8900.00
0005432919966	20486	Economy	8900.00
0005432919954	20486	Economy	8900.00
0005433507116	20486	Economy	8900.00
0005432919969	20486	Economy	8900.00
0005433507027	20486	Economy	8900.00
0005432394120	10213	Economy	5800.00
0005432394116	10213	Economy	5800.00
0005432396257	10213	Economy	5800.00
0005432396255	10213	Economy	5800.00
0005432394119	10213	Economy	5800.00
0005432396256	10213	Economy	5800.00
0005432394118	10213	Economy	5800.00
0005432394114	10213	Economy	5800.00
0005432394117	10213	Economy	5800.00
0005432394115	10213	Economy	5800.00
0005432396254	10213	Economy	5800.00
0005432396230	18359	Economy	5800.00
0005432396212	18359	Economy	5800.00
0005432400097	18359	Economy	5800.00
0005432400109	18359	Economy	5800.00
0005432400127	18359	Economy	5800.00
0005435179397	18359	Economy	5800.00
0005432396216	18359	Economy	5800.00
0005432400111	18359	Economy	5800.00
0005432400100	18359	Economy	5800.00
0005432396221	18359	Economy	5800.00
0005432396235	18359	Economy	5800.00
0005432400112	18359	Economy	5800.00
0005435626082	11018	Business	9500.00
0005435126046	11018	Business	9500.00
0005435126221	11018	Business	9500.00
0005435126063	11018	Business	9500.00
0005435554180	11018	Business	9500.00
0005434411796	11018	Business	9500.00
0005435626060	11018	Business	9500.00
0005435126135	11018	Business	9500.00
0005435126084	11018	Business	9500.00
0005435126140	11018	Economy	3200.00
0005435626034	11018	Economy	3200.00
0005435126025	11018	Economy	3200.00
0005435626048	11018	Economy	3200.00
0005435126264	11018	Economy	3200.00
0005435126093	11018	Economy	3200.00
0005435126047	11018	Economy	3200.00
0005435126238	11018	Economy	3200.00
0005435626033	11018	Economy	3500.00
0005435125940	11018	Economy	3500.00
0005435126106	11018	Economy	3500.00
0005435126062	11018	Economy	3200.00
0005435125955	11018	Economy	3200.00
0005435626050	11018	Economy	3200.00
0005435126220	11018	Economy	3200.00
0005435126143	11018	Economy	3200.00
0005435126133	11018	Economy	3200.00
0005435126108	11018	Economy	3200.00
0005435626083	11018	Economy	3200.00
0005435126056	11018	Economy	3200.00
0005435626027	11018	Economy	3200.00
0005435556682	11018	Economy	3200.00
0005435126088	11018	Economy	3200.00
0005435126094	11018	Economy	3200.00
0005435626053	11018	Economy	3200.00
0005435626067	11018	Economy	3200.00
0005435626028	11018	Economy	3200.00
0005435126126	11018	Economy	3200.00
0005435125971	11018	Economy	3200.00
0005435126155	11018	Economy	3200.00
0005435126026	11018	Economy	3200.00
0005435126010	11018	Economy	3200.00
0005435126136	11018	Economy	3200.00
0005435626081	11018	Economy	3200.00
0005435554155	11018	Economy	3200.00
0005434928311	11018	Economy	3200.00
0005435126209	11018	Economy	3200.00
0005435554184	11018	Economy	3200.00
0005435554159	11018	Economy	3200.00
0005434411795	11018	Economy	3200.00
0005434411797	11018	Economy	3200.00
0005435554167	11018	Economy	3200.00
0005435126144	11018	Economy	3200.00
0005435556683	11018	Economy	3200.00
0005435626031	11018	Economy	3200.00
0005435626054	11018	Economy	3200.00
0005434411794	11018	Economy	3200.00
0005435126291	11018	Economy	3200.00
0005435126113	11018	Economy	3200.00
0005435126252	11018	Economy	3200.00
0005435126201	11018	Economy	3200.00
0005435126114	11018	Economy	3200.00
0005435626059	11018	Economy	3200.00
0005435126117	11018	Economy	3200.00
0005434928312	11018	Economy	3200.00
0005435554154	11018	Economy	3200.00
0005435126095	11018	Economy	3200.00
0005435126141	11018	Economy	3200.00
0005435626064	11018	Economy	3200.00
0005435554157	11018	Economy	3200.00
0005435126154	11018	Economy	3200.00
0005435626066	11018	Economy	3200.00
0005435626068	11018	Economy	3200.00
0005435556668	11018	Economy	3200.00
0005434928310	11018	Economy	3200.00
0005435126011	11018	Economy	3200.00
0005435626069	11018	Economy	3200.00
0005435626052	11018	Economy	3200.00
0005435126200	11018	Economy	3200.00
0005435126107	11018	Economy	3200.00
0005435125956	11018	Economy	3200.00
0005435554185	11018	Economy	3200.00
0005435626248	14763	Business	9500.00
0005435126548	14763	Business	9500.00
0005435126529	14763	Business	9500.00
0005435126527	14763	Business	9500.00
0005435126522	14763	Business	9500.00
0005435126523	14763	Business	9500.00
0005435626252	14763	Business	9500.00
0005435126557	14763	Business	9500.00
0005435626258	14763	Business	9500.00
0005435126544	14763	Business	9500.00
0005434411757	14763	Business	9500.00
0005435126554	14763	Economy	3200.00
0005435626246	14763	Economy	3200.00
0005435126545	14763	Economy	3200.00
0005435126534	14763	Economy	3200.00
0005435126524	14763	Economy	3200.00
0005435126562	14763	Economy	3200.00
0005435626251	14763	Economy	3200.00
0005435554202	14763	Economy	3200.00
0005435556704	14763	Economy	3500.00
0005435626262	14763	Economy	3500.00
0005435626256	14763	Economy	3500.00
0005435626254	14763	Economy	3200.00
0005435126530	14763	Economy	3200.00
0005435626260	14763	Economy	3200.00
0005435626261	14763	Economy	3200.00
0005435126547	14763	Economy	3200.00
0005435626243	14763	Economy	3200.00
0005435626250	14763	Economy	3200.00
0005435626255	14763	Economy	3200.00
0005435126537	14763	Economy	3200.00
0005435626240	14763	Economy	3200.00
0005435126549	14763	Economy	3200.00
0005435126541	14763	Economy	3200.00
0005435626249	14763	Economy	3200.00
0005435126532	14763	Economy	3200.00
0005434928290	14763	Economy	3200.00
0005435626264	14763	Economy	3200.00
0005435126553	14763	Economy	3200.00
0005435626244	14763	Economy	3200.00
0005435556703	14763	Economy	3200.00
0005435126556	14763	Economy	3200.00
0005435126559	14763	Economy	3200.00
0005435126525	14763	Economy	3200.00
0005435554206	14763	Economy	3200.00
0005435126526	14763	Economy	3200.00
0005434411770	14763	Economy	3200.00
0005435626259	14763	Economy	3200.00
0005434411763	14763	Economy	3200.00
0005435126536	14763	Economy	3200.00
0005435626253	14763	Economy	3200.00
0005434411769	14763	Economy	3200.00
0005435126533	14763	Economy	3200.00
0005435626263	14763	Economy	3200.00
0005435126528	14763	Economy	3200.00
0005435126542	14763	Economy	3200.00
0005435626241	14763	Economy	3200.00
0005435626257	14763	Economy	3200.00
0005435126539	14763	Economy	3200.00
0005435126552	14763	Economy	3200.00
0005435126560	14763	Economy	3200.00
0005435554204	14763	Economy	3200.00
0005435126558	14763	Economy	3200.00
0005434928291	14763	Economy	3200.00
0005435626245	14763	Economy	3200.00
0005435554203	14763	Economy	3200.00
0005435626242	14763	Economy	3200.00
0005435626247	14763	Economy	3200.00
0005435126531	14763	Economy	3200.00
0005434411762	14763	Economy	3200.00
0005435126555	14763	Economy	3200.00
0005435126551	14763	Economy	3200.00
0005435126535	14763	Economy	3200.00
0005435126561	14763	Economy	3200.00
0005435126538	14763	Economy	3200.00
0005435126550	14763	Economy	3200.00
0005435556702	14763	Economy	3200.00
0005435126543	14763	Economy	3200.00
0005435126521	14763	Economy	3200.00
0005435126546	14763	Economy	3200.00
0005435626265	14763	Economy	3200.00
0005435126540	14763	Economy	3200.00
0005435554205	14763	Economy	3200.00
0005435715546	7118	Business	86900.00
0005435216570	7118	Business	86900.00
0005435443234	7118	Business	86900.00
0005435715536	7118	Business	86900.00
0005432398213	7118	Business	86900.00
0005435715540	7118	Economy	29000.00
0005435443258	7118	Economy	29000.00
0005435715542	7118	Economy	29000.00
0005435715544	7118	Economy	29000.00
0005435715545	7118	Economy	31900.00
0005435443283	7118	Economy	31900.00
0005435715543	7118	Economy	29000.00
0005435179387	7118	Economy	29000.00
0005435443235	7118	Economy	29000.00
0005435216577	7118	Economy	29000.00
0005435715541	7118	Economy	29000.00
0005435715534	7118	Economy	29000.00
0005432398214	7118	Economy	29000.00
0005435715531	7118	Economy	29000.00
0005432398211	7118	Economy	29000.00
0005435219194	7118	Economy	29000.00
0005435715532	7118	Economy	29000.00
0005432400141	7118	Economy	29000.00
0005435715530	7118	Economy	29000.00
0005435216576	7118	Economy	29000.00
0005435715533	7118	Economy	29000.00
0005435715537	7118	Economy	29000.00
0005432400140	7118	Economy	29000.00
0005435219192	7118	Economy	29000.00
0005435443247	7118	Economy	29000.00
0005435443223	7118	Economy	29000.00
0005435178487	7118	Economy	29000.00
0005432398215	7118	Economy	29000.00
0005435715529	7118	Economy	29000.00
0005435179391	7118	Economy	29000.00
0005435216584	7118	Economy	29000.00
0005435443236	7118	Economy	29000.00
0005435443270	7118	Economy	29000.00
0005435178488	7118	Economy	29000.00
0005435715538	7118	Economy	29000.00
0005435443294	7118	Economy	29000.00
0005435219195	7118	Economy	29000.00
0005432400142	7118	Economy	29000.00
0005435715539	7118	Economy	29000.00
0005432398212	7118	Economy	29000.00
0005435715535	7118	Economy	29000.00
0005435178996	27060	Business	86900.00
0005435715408	27060	Business	86900.00
0005435715374	27060	Business	86900.00
0005435443356	27060	Business	86900.00
0005432398165	27060	Economy	29000.00
0005435715375	27060	Economy	29000.00
0005435443353	27060	Economy	31900.00
0005435443349	27060	Economy	31900.00
0005435443351	27060	Economy	31900.00
0005435715383	27060	Economy	31900.00
0005435715392	27060	Economy	29000.00
0005435443357	27060	Economy	29000.00
0005435443355	27060	Economy	29000.00
0005432398178	27060	Economy	29000.00
0005435715460	27060	Economy	29000.00
0005435715370	27060	Economy	29000.00
0005435715432	27060	Economy	29000.00
0005435715409	27060	Economy	29000.00
0005432398189	27060	Economy	29000.00
0005432398163	27060	Economy	29000.00
0005435443350	27060	Economy	29000.00
0005435715431	27060	Economy	29000.00
0005435443354	27060	Economy	29000.00
0005435715393	27060	Economy	29000.00
0005435715452	27060	Economy	29000.00
0005432398177	27060	Economy	29000.00
0005435178501	27060	Economy	29000.00
0005435443352	27060	Economy	29000.00
0005432398176	27060	Economy	29000.00
0005432398173	27060	Economy	29000.00
0005435178997	27060	Economy	29000.00
0005432394067	27060	Economy	29000.00
0005435715461	27060	Economy	29000.00
0005435715428	27060	Economy	29000.00
0005434084949	2726	Economy	7700.00
0005434084950	2726	Economy	7700.00
0005434084952	2726	Economy	7700.00
0005434084951	2726	Economy	7700.00
0005433060409	2726	Economy	7700.00
0005434084948	2726	Economy	7700.00
0005433060410	2726	Economy	7700.00
0005433060397	2726	Economy	7700.00
0005433060411	2726	Economy	7700.00
0005433060423	28486	Economy	7700.00
0005433060424	28486	Economy	7700.00
0005434084897	28486	Economy	7700.00
0005434084889	28486	Economy	7700.00
0005433060425	28486	Economy	7700.00
0005435540929	11389	Business	20200.00
0005435540876	11389	Business	20200.00
0005435517909	11389	Business	20200.00
0005435517842	11389	Business	20200.00
0005435540872	11389	Business	20200.00
0005435540987	11389	Economy	6700.00
0005435517802	11389	Economy	6700.00
0005435540953	11389	Economy	7400.00
0005435517763	11389	Economy	6700.00
0005435517908	11389	Economy	6700.00
0005435517841	11389	Economy	6700.00
0005435517799	11389	Economy	6700.00
0005435540975	11389	Economy	6700.00
0005435517810	11389	Economy	6700.00
0005435540899	11389	Economy	6700.00
0005435540883	11389	Economy	6700.00
0005435517836	11389	Economy	6700.00
0005435517780	11389	Economy	6700.00
0005435517853	11389	Economy	6700.00
0005435517874	11389	Economy	6700.00
0005435517850	11389	Economy	6700.00
0005435517870	11389	Economy	6700.00
0005435540986	11389	Economy	6700.00
0005435540881	11389	Economy	6700.00
0005435540954	11389	Economy	6700.00
0005435517843	11389	Economy	6700.00
0005435540884	11389	Economy	6700.00
0005435517854	11389	Economy	6700.00
0005435540938	11389	Economy	6700.00
0005435540944	11389	Economy	6700.00
0005435517801	11389	Economy	6700.00
0005435517860	11389	Economy	6700.00
0005435540915	11389	Economy	6700.00
0005435540934	11389	Economy	6700.00
0005435540871	11389	Economy	6700.00
0005435517875	11389	Economy	6700.00
0005435540882	11389	Economy	6700.00
0005435517859	11389	Economy	6700.00
0005435517835	11389	Economy	6700.00
0005435529337	22243	Business	20200.00
0005435541068	22243	Business	20200.00
0005435541082	22243	Economy	6700.00
0005435529341	22243	Economy	6700.00
0005435541074	22243	Economy	6700.00
0005435541086	22243	Economy	6700.00
0005435529342	22243	Economy	6700.00
0005435541080	22243	Economy	7400.00
0005435541088	22243	Economy	7400.00
0005435529343	22243	Economy	7400.00
0005435541069	22243	Economy	7400.00
0005435529326	22243	Economy	6700.00
0005435529325	22243	Economy	6700.00
0005435529327	22243	Economy	6700.00
0005435529332	22243	Economy	6700.00
0005435541067	22243	Economy	6700.00
0005435541081	22243	Economy	6700.00
0005435529323	22243	Economy	6700.00
0005435541078	22243	Economy	6700.00
0005435541083	22243	Economy	6700.00
0005435529336	22243	Economy	6700.00
0005435541077	22243	Economy	6700.00
0005435541085	22243	Economy	6700.00
0005435529338	22243	Economy	6700.00
0005432294496	22243	Economy	6700.00
0005435541073	22243	Economy	6700.00
0005435529329	22243	Economy	6700.00
0005435529328	22243	Economy	6700.00
0005435541072	22243	Economy	6700.00
0005432294494	22243	Economy	6700.00
0005435541071	22243	Economy	6700.00
0005435529340	22243	Economy	6700.00
0005432294497	22243	Economy	6700.00
0005435529331	22243	Economy	6700.00
0005435529324	22243	Economy	6700.00
0005435529335	22243	Economy	6700.00
0005435541087	22243	Economy	6700.00
0005435541076	22243	Economy	6700.00
0005435541066	22243	Economy	6700.00
0005435529333	22243	Economy	6700.00
0005432294495	22243	Economy	6700.00
0005435541070	22243	Economy	6700.00
0005435529322	22243	Economy	6700.00
0005435529330	22243	Economy	6700.00
0005435529334	22243	Economy	6700.00
0005435541084	22243	Economy	6700.00
0005435529339	22243	Economy	6700.00
0005435541075	22243	Economy	6700.00
0005435541079	22243	Economy	6700.00
0005434907491	2270	Business	20200.00
0005434907505	2270	Business	20200.00
0005434907522	2270	Business	20200.00
0005433251157	2270	Business	20200.00
0005434907500	2270	Business	20200.00
0005434907515	2270	Business	20200.00
0005434907486	2270	Business	20200.00
0005433251345	2270	Business	20200.00
0005434907493	2270	Business	20200.00
0005434907532	2270	Business	20200.00
0005434907511	2270	Business	20200.00
0005434907508	2270	Economy	6700.00
0005434907530	2270	Economy	6700.00
0005433251430	2270	Economy	6700.00
0005433251259	2270	Economy	6700.00
0005433251446	2270	Economy	6700.00
0005434907504	2270	Economy	6700.00
0005434907506	2270	Economy	6700.00
0005434907492	2270	Economy	6700.00
0005434907502	2270	Economy	6700.00
0005434907520	2270	Economy	6700.00
0005434907512	2270	Economy	7400.00
0005433251332	2270	Economy	7400.00
0005434907527	2270	Economy	7400.00
0005434907517	2270	Economy	7400.00
0005433251355	2270	Economy	7400.00
0005434907525	2270	Economy	6700.00
0005433251299	2270	Economy	6700.00
0005433251258	2270	Economy	6700.00
0005434907487	2270	Economy	6700.00
0005434907490	2270	Economy	6700.00
0005433251457	2270	Economy	6700.00
0005434907518	2270	Economy	6700.00
0005434907489	2270	Economy	6700.00
0005433400980	2270	Economy	6700.00
0005434907529	2270	Economy	6700.00
0005434907519	2270	Economy	6700.00
0005434907499	2270	Economy	6700.00
0005434907510	2270	Economy	6700.00
0005433251344	2270	Economy	6700.00
0005433251311	2270	Economy	6700.00
0005433251406	2270	Economy	6700.00
0005433400984	2270	Economy	6700.00
0005434907495	2270	Economy	6700.00
0005434907494	2270	Economy	6700.00
0005433251356	2270	Economy	6700.00
0005433251313	2270	Economy	6700.00
0005433251431	2270	Economy	6700.00
0005433251235	2270	Economy	6700.00
0005433251424	2270	Economy	6700.00
0005433251398	2270	Economy	6700.00
0005434907498	2270	Economy	6700.00
0005433251400	2270	Economy	6700.00
0005433251316	2270	Economy	6700.00
0005433251314	2270	Economy	6700.00
0005434907514	2270	Economy	6700.00
0005434907488	2270	Economy	6700.00
0005433251366	2270	Economy	6700.00
0005433251399	2270	Economy	6700.00
0005434907528	2270	Economy	6700.00
0005434907533	2270	Economy	6700.00
0005433400963	2270	Economy	6700.00
0005433251310	2270	Economy	6700.00
0005433400981	2270	Economy	6700.00
0005434907521	2270	Economy	6700.00
0005433251415	2270	Economy	6700.00
0005434907531	2270	Economy	6700.00
0005434907507	2270	Economy	6700.00
0005433251396	2270	Economy	6700.00
0005433251444	2270	Economy	6700.00
0005434907524	2270	Economy	6700.00
0005433251312	2270	Economy	6700.00
0005434907497	2270	Economy	6700.00
0005433251222	2270	Economy	6700.00
0005433251437	2270	Economy	6700.00
0005434907516	2270	Economy	6700.00
0005434907501	2270	Economy	6700.00
0005433251351	2270	Economy	6700.00
0005433251429	2270	Economy	6700.00
0005433251303	2270	Economy	6700.00
0005433251315	2270	Economy	6700.00
0005434907523	2270	Economy	6700.00
0005434907509	2270	Economy	6700.00
0005433251260	2270	Economy	6700.00
0005433251432	2270	Economy	6700.00
0005434907496	2270	Economy	6700.00
0005434907513	2270	Economy	6700.00
0005434907503	2270	Economy	6700.00
0005433251438	2270	Economy	6700.00
0005434907526	2270	Economy	6700.00
0005433251606	25575	Business	20200.00
0005433251608	25575	Business	20200.00
0005434907069	25575	Business	20200.00
0005433251596	25575	Business	20200.00
0005434906978	25575	Business	20200.00
0005434906926	25575	Business	20200.00
0005434906987	25575	Business	20200.00
0005434906900	25575	Business	20200.00
0005433251601	25575	Business	20200.00
0005434907079	25575	Business	20200.00
0005433251621	25575	Business	20200.00
0005434907055	25575	Economy	6700.00
0005433400994	25575	Economy	6700.00
0005434907040	25575	Economy	6700.00
0005433251618	25575	Economy	6700.00
0005434907072	25575	Economy	6700.00
0005433251614	25575	Economy	6700.00
0005434907026	25575	Economy	6700.00
0005434906904	25575	Economy	6700.00
0005433251622	25575	Economy	6700.00
0005434906984	25575	Economy	6700.00
0005433251617	25575	Economy	7400.00
0005433251609	25575	Economy	7400.00
0005434907019	25575	Economy	7400.00
0005434907011	25575	Economy	7400.00
0005433251623	25575	Economy	6700.00
0005434906903	25575	Economy	6700.00
0005434906959	25575	Economy	6700.00
0005434907002	25575	Economy	6700.00
0005433400995	25575	Economy	6700.00
0005434906982	25575	Economy	6700.00
0005433251594	25575	Economy	6700.00
0005433251603	25575	Economy	6700.00
0005434907074	25575	Economy	6700.00
0005434906977	25575	Economy	6700.00
0005434906983	25575	Economy	6700.00
0005434906875	25575	Economy	6700.00
0005433251605	25575	Economy	6700.00
0005433251597	25575	Economy	6700.00
0005434907004	25575	Economy	6700.00
0005434907021	25575	Economy	6700.00
0005433251591	25575	Economy	6700.00
0005434907037	25575	Economy	6700.00
0005434907000	25575	Economy	6700.00
0005434906877	25575	Economy	6700.00
0005434907003	25575	Economy	6700.00
0005434907046	25575	Economy	6700.00
0005433251592	25575	Economy	6700.00
0005434906850	25575	Economy	6700.00
0005433251604	25575	Economy	6700.00
0005433251598	25575	Economy	6700.00
0005434907005	25575	Economy	6700.00
0005434907038	25575	Economy	6700.00
0005434907022	25575	Economy	6700.00
0005434906990	25575	Economy	6700.00
0005433251600	25575	Economy	6700.00
0005434907056	25575	Economy	6700.00
0005434907045	25575	Economy	6700.00
0005433251593	25575	Economy	6700.00
0005434906958	25575	Economy	6700.00
0005433251607	25575	Economy	6700.00
0005433400996	25575	Economy	6700.00
0005434907020	25575	Economy	6700.00
0005433251620	25575	Economy	6700.00
0005433400997	25575	Economy	6700.00
0005434906912	25575	Economy	6700.00
0005434907010	25575	Economy	6700.00
0005434907054	25575	Economy	6700.00
0005434907012	25575	Economy	6700.00
0005434907044	25575	Economy	6700.00
0005433251611	25575	Economy	6700.00
0005433251612	25575	Economy	6700.00
0005434907023	25575	Economy	6700.00
0005434906885	25575	Economy	6700.00
0005433251616	25575	Economy	6700.00
0005433251610	25575	Economy	6700.00
0005434906878	25575	Economy	6700.00
0005434906948	25575	Economy	6700.00
0005433251595	25575	Economy	6700.00
0005433251599	25575	Economy	6700.00
0005434906681	25575	Economy	6700.00
0005434906923	25575	Economy	6700.00
0005433251619	25575	Economy	6700.00
0005434906899	25575	Economy	6700.00
0005433251615	25575	Economy	6700.00
0005434906682	25575	Economy	6700.00
0005434907081	25575	Economy	6700.00
0005434906941	25575	Economy	6700.00
0005433251613	25575	Economy	6700.00
0005433251602	25575	Economy	6700.00
0005434906986	25575	Economy	6700.00
0005432862259	2516	Economy	13600.00
0005432862304	2516	Economy	12400.00
0005432621091	2516	Economy	12400.00
0005432862245	2516	Economy	12400.00
0005432862223	2516	Economy	12400.00
0005432621099	2516	Economy	12400.00
0005432862280	2516	Economy	12400.00
0005432621096	2516	Economy	12400.00
0005432621102	2516	Economy	12400.00
0005432621101	2516	Economy	12400.00
0005432621092	2516	Economy	12400.00
0005432621103	2516	Economy	12400.00
0005432621100	2516	Economy	12400.00
0005432621094	2516	Economy	12400.00
0005432621093	2516	Economy	12400.00
0005432621097	2516	Economy	12400.00
0005432862254	2516	Economy	12400.00
0005432621098	2516	Economy	12400.00
0005432621095	2516	Economy	12400.00
0005432862288	2516	Economy	12400.00
0005432862337	28079	Economy	13600.00
0005432620922	28079	Economy	12400.00
0005432862333	28079	Economy	12400.00
0005432862331	28079	Economy	12400.00
0005432620993	28079	Economy	12400.00
0005432620975	28079	Economy	12400.00
0005432620921	28079	Economy	12400.00
0005432620918	28079	Economy	12400.00
0005432862330	28079	Economy	12400.00
0005432862336	28079	Economy	12400.00
0005432862332	28079	Economy	12400.00
0005432620957	28079	Economy	12400.00
0005432620919	28079	Economy	12400.00
0005432862334	28079	Economy	12400.00
0005432862335	28079	Economy	12400.00
0005434191262	32876	Business	89600.00
0005434191258	32876	Economy	29900.00
0005434191254	32876	Economy	29900.00
0005434191267	32876	Economy	29900.00
0005434191269	32876	Economy	29900.00
0005434191272	32876	Economy	29900.00
0005434191259	32876	Economy	29900.00
0005434191266	32876	Economy	29900.00
0005434191255	32876	Economy	29900.00
0005434191270	32876	Economy	29900.00
0005433452747	31096	Economy	8400.00
0005433451627	31096	Economy	8400.00
0005433452748	31096	Economy	8400.00
0005433451626	31096	Economy	8400.00
0005433452725	31410	Economy	8400.00
0005433452729	31410	Economy	8400.00
0005433452730	31410	Economy	8400.00
0005433454867	31410	Economy	8400.00
0005433454864	31410	Economy	8400.00
0005433454869	31410	Economy	8400.00
0005433454868	31410	Economy	8400.00
0005434184656	11994	Economy	7200.00
0005434142575	11994	Economy	6600.00
0005433129252	11994	Economy	6600.00
0005433134113	11994	Economy	6600.00
0005433134103	11994	Economy	6600.00
0005433129253	11994	Economy	6600.00
0005434184653	11994	Economy	6600.00
0005434142574	11994	Economy	6600.00
0005433134106	11994	Economy	6600.00
0005434142593	11994	Economy	6600.00
0005434142596	11994	Economy	6600.00
0005433134156	29815	Economy	6600.00
0005433131728	29815	Economy	6600.00
0005434142624	29815	Economy	6600.00
0005434183588	29815	Economy	6600.00
0005434142623	29815	Economy	6600.00
0005434184673	29815	Economy	6600.00
0005434184674	29815	Economy	6600.00
0005434142622	29815	Economy	6600.00
0005433131726	29815	Economy	6600.00
0005433134155	29815	Economy	6600.00
0005434183587	29815	Economy	6600.00
0005433134158	29815	Economy	6600.00
0005433131725	29815	Economy	6600.00
0005433134157	29815	Economy	6600.00
0005433131727	29815	Economy	6600.00
0005434142625	29815	Economy	6600.00
0005434183589	29815	Economy	6600.00
0005435798947	1604	Economy	17200.00
0005435798951	1604	Economy	15700.00
0005435798952	1604	Economy	15700.00
0005435798958	1604	Economy	15700.00
0005435798949	1604	Economy	15700.00
0005435798954	1604	Economy	15700.00
0005435798959	1604	Economy	15700.00
0005435798946	1604	Economy	15700.00
0005435798957	1604	Economy	15700.00
0005435798960	1604	Economy	15700.00
0005435798956	1604	Economy	15700.00
0005435798955	1604	Economy	15700.00
0005435798950	1604	Economy	15700.00
0005435798953	1604	Economy	15700.00
0005435798948	1604	Economy	15700.00
0005435697444	16501	Economy	19900.00
0005435697445	16501	Economy	19900.00
0005435697429	16501	Economy	19900.00
0005435935020	16501	Economy	18100.00
0005435697432	16501	Economy	18100.00
0005435935028	16501	Economy	18100.00
0005435697424	16501	Economy	18100.00
0005435697421	16501	Economy	18100.00
0005435697436	16501	Economy	18100.00
0005435697417	16501	Economy	18100.00
0005435697438	16501	Economy	18100.00
0005435697419	16501	Economy	18100.00
0005435697418	16501	Economy	18100.00
0005435697423	16501	Economy	18100.00
0005435697433	16501	Economy	18100.00
0005435697440	16501	Economy	18100.00
0005435697443	16501	Economy	18100.00
0005435697420	16501	Economy	18100.00
0005435935029	16501	Economy	18100.00
0005435697442	16501	Economy	18100.00
0005435697439	16501	Economy	18100.00
0005435697426	16501	Economy	18100.00
0005435697430	16501	Economy	18100.00
0005435697431	16501	Economy	18100.00
0005435697428	16501	Economy	18100.00
0005435697427	16501	Economy	18100.00
0005435697434	16501	Economy	18100.00
0005435697437	16501	Economy	18100.00
0005435697422	16501	Economy	18100.00
0005435697441	16501	Economy	18100.00
0005435697425	16501	Economy	18100.00
0005435697435	16501	Economy	18100.00
0005435697232	24724	Economy	19900.00
0005435697200	24724	Economy	19900.00
0005435697230	24724	Economy	19900.00
0005435697264	24724	Economy	18100.00
0005435697137	24724	Economy	18100.00
0005435935059	24724	Economy	18100.00
0005435697237	24724	Economy	18100.00
0005435697163	24724	Economy	18100.00
0005435697284	24724	Economy	18100.00
0005435697282	24724	Economy	18100.00
0005435935061	24724	Economy	18100.00
0005435935060	24724	Economy	18100.00
0005435697320	24724	Economy	18100.00
0005435697256	24724	Economy	18100.00
0005435697356	24724	Economy	18100.00
0005435697231	24724	Economy	18100.00
0005435697283	24724	Economy	18100.00
0005435697198	24724	Economy	18100.00
0005435697188	24724	Economy	18100.00
0005435697318	24724	Economy	18100.00
0005435697195	24724	Economy	18100.00
0005435697196	24724	Economy	18100.00
0005435697201	24724	Economy	18100.00
0005435697271	24724	Economy	18100.00
0005435697266	24724	Economy	18100.00
0005435697315	24724	Economy	18100.00
0005433724819	18815	Economy	4400.00
0005433724821	18815	Economy	4400.00
0005433724820	18815	Economy	4400.00
0005433724800	21606	Economy	4400.00
0005433724801	21606	Economy	4400.00
0005433724790	21606	Economy	4400.00
0005433724789	21606	Economy	4400.00
0005432968852	21606	Economy	4400.00
0005432968851	21606	Economy	4400.00
0005433724787	21606	Economy	4400.00
0005433724794	21606	Economy	4400.00
0005434087535	7293	Business	23100.00
0005434138491	7293	Business	23100.00
0005434138479	7293	Business	23100.00
0005434138550	7293	Business	23100.00
0005434138470	7293	Business	23100.00
0005434138496	7293	Business	23100.00
0005434138490	7293	Business	23100.00
0005434138503	7293	Business	23100.00
0005434138512	7293	Business	23100.00
0005434138474	7293	Business	23100.00
0005434138543	7293	Business	23100.00
0005434138504	7293	Business	23100.00
0005434138481	7293	Economy	7700.00
0005434138540	7293	Economy	7700.00
0005434138538	7293	Economy	7700.00
0005434138499	7293	Economy	7700.00
0005434138546	7293	Economy	7700.00
0005434087531	7293	Economy	7700.00
0005434138518	7293	Economy	7700.00
0005434138537	7293	Economy	7700.00
0005434138524	7293	Economy	7700.00
0005434138508	7293	Economy	7700.00
0005434138507	7293	Economy	8500.00
0005434138521	7293	Economy	8500.00
0005434138532	7293	Economy	8500.00
0005434138533	7293	Economy	8500.00
0005434138480	7293	Economy	8500.00
0005434138486	7293	Economy	7700.00
0005434138530	7293	Economy	7700.00
0005434138547	7293	Economy	7700.00
0005434087533	7293	Economy	7700.00
0005434138489	7293	Economy	7700.00
0005434138492	7293	Economy	7700.00
0005434138542	7293	Economy	7700.00
0005434138536	7293	Economy	7700.00
0005434138488	7293	Economy	7700.00
0005434138495	7293	Economy	7700.00
0005434138548	7293	Economy	7700.00
0005434138551	7293	Economy	7700.00
0005434138534	7293	Economy	7700.00
0005434138483	7293	Economy	7700.00
0005434138523	7293	Economy	7700.00
0005434138525	7293	Economy	7700.00
0005434138516	7293	Economy	7700.00
0005434138535	7293	Economy	7700.00
0005434138527	7293	Economy	7700.00
0005434138539	7293	Economy	7700.00
0005434138552	7293	Economy	7700.00
0005434138477	7293	Economy	7700.00
0005434138472	7293	Economy	7700.00
0005434138519	7293	Economy	7700.00
0005434138511	7293	Economy	7700.00
0005434087534	7293	Economy	7700.00
0005434138476	7293	Economy	7700.00
0005434138528	7293	Economy	7700.00
0005434138505	7293	Economy	7700.00
0005434138498	7293	Economy	7700.00
0005434138497	7293	Economy	7700.00
0005434138517	7293	Economy	7700.00
0005434138545	7293	Economy	7700.00
0005434138482	7293	Economy	7700.00
0005434138531	7293	Economy	7700.00
0005434138544	7293	Economy	7700.00
0005434138502	7293	Economy	7700.00
0005434087536	7293	Economy	7700.00
0005434087532	7293	Economy	7700.00
0005434138500	7293	Economy	7700.00
0005434138541	7293	Economy	7700.00
0005434138513	7293	Economy	7700.00
0005434138514	7293	Economy	7700.00
0005434138493	7293	Economy	7700.00
0005434138485	7293	Economy	7700.00
0005434138510	7293	Economy	7700.00
0005434138515	7293	Economy	7700.00
0005434138501	7293	Economy	7700.00
0005434138549	7293	Economy	7700.00
0005434138471	7293	Economy	7700.00
0005434138506	7293	Economy	7700.00
0005434138487	7293	Economy	7700.00
0005434138529	7293	Economy	7700.00
0005434138494	7293	Economy	7700.00
0005434138473	7293	Economy	7700.00
0005434138475	7293	Economy	7700.00
0005434138522	7293	Economy	7700.00
0005434138526	7293	Economy	7700.00
0005434138509	7293	Economy	7700.00
0005434138520	7293	Economy	7700.00
0005434138478	7293	Economy	7700.00
0005434138484	7293	Economy	7700.00
0005434137677	28532	Business	23100.00
0005434137563	28532	Business	23100.00
0005434137703	28532	Business	23100.00
0005434137725	28532	Business	23100.00
0005434137788	28532	Business	23100.00
0005434137870	28532	Business	23100.00
0005434137658	28532	Business	23100.00
0005434137564	28532	Business	23100.00
0005434137659	28532	Business	23100.00
0005434137592	28532	Business	23100.00
0005434137859	28532	Business	23100.00
0005434137336	28532	Business	23100.00
0005434087495	28532	Economy	7700.00
0005434137671	28532	Economy	7700.00
0005434137745	28532	Economy	7700.00
0005434137786	28532	Economy	7700.00
0005434137794	28532	Economy	7700.00
0005434137799	28532	Economy	7700.00
0005434137672	28532	Economy	7700.00
0005434137681	28532	Economy	7700.00
0005434087476	28532	Economy	7700.00
0005434087475	28532	Economy	8500.00
0005434137789	28532	Economy	8500.00
0005434137878	28532	Economy	8500.00
0005434137850	28532	Economy	8500.00
0005434137839	28532	Economy	8500.00
0005434137840	28532	Economy	7700.00
0005434137691	28532	Economy	7700.00
0005434137568	28532	Economy	7700.00
0005434137857	28532	Economy	7700.00
0005434137818	28532	Economy	7700.00
0005434137634	28532	Economy	7700.00
0005434137245	28532	Economy	7700.00
0005434137849	28532	Economy	7700.00
0005434137244	28532	Economy	7700.00
0005434137555	28532	Economy	7700.00
0005434087508	28532	Economy	7700.00
0005434137660	28532	Economy	7700.00
0005434137695	28532	Economy	7700.00
0005434137761	28532	Economy	7700.00
0005434137573	28532	Economy	7700.00
0005434137523	28532	Economy	7700.00
0005434087502	28532	Economy	7700.00
0005434137743	28532	Economy	7700.00
0005434137755	28532	Economy	7700.00
0005434137654	28532	Economy	7700.00
0005434137653	28532	Economy	7700.00
0005434137377	28532	Economy	7700.00
0005434137376	28532	Economy	7700.00
0005434137429	28532	Economy	7700.00
0005434137495	28532	Economy	7700.00
0005434137865	28532	Economy	7700.00
0005434087503	28532	Economy	7700.00
0005434137676	28532	Economy	7700.00
0005434087494	28532	Economy	7700.00
0005434137847	28532	Economy	7700.00
0005434137449	28532	Economy	7700.00
0005434137889	28532	Economy	7700.00
0005434137524	28532	Economy	7700.00
0005434137582	28532	Economy	7700.00
0005434137611	28532	Economy	7700.00
0005434137845	28532	Economy	7700.00
0005434137792	28532	Economy	7700.00
0005434137556	28532	Economy	7700.00
0005434137754	28532	Economy	7700.00
0005434137762	28532	Economy	7700.00
0005434137567	28532	Economy	7700.00
0005434137243	28532	Economy	7700.00
0005434137442	28532	Economy	7700.00
0005434137423	28532	Economy	7700.00
0005434137744	28532	Economy	7700.00
0005434137800	28532	Economy	7700.00
0005434137540	28532	Economy	7700.00
0005434137696	28532	Economy	7700.00
0005434137879	28532	Economy	7700.00
0005434137802	28532	Economy	7700.00
0005434137773	28532	Economy	7700.00
0005434137692	28532	Economy	7700.00
0005434137752	28532	Economy	7700.00
0005434137690	28532	Economy	7700.00
0005434137614	28532	Economy	7700.00
0005434137633	28532	Economy	7700.00
0005434137518	28532	Economy	7700.00
0005434137583	28532	Economy	7700.00
0005434087504	28532	Economy	7700.00
0005434137584	28532	Economy	7700.00
0005434137785	28532	Economy	7700.00
0005434137637	28532	Economy	7700.00
0005434137359	28532	Economy	7700.00
0005434610243	1911	Economy	23900.00
0005433407508	1911	Economy	23900.00
0005435808278	1911	Economy	23900.00
0005434610244	1911	Economy	21700.00
0005433407532	1911	Economy	21700.00
0005435808280	1911	Economy	21700.00
0005435808281	1911	Economy	21700.00
0005435808276	1911	Economy	21700.00
0005433407553	1911	Economy	21700.00
0005435808277	1911	Economy	21700.00
0005434610242	1911	Economy	21700.00
0005434610245	1911	Economy	21700.00
0005435808275	1911	Economy	21700.00
0005435808282	1911	Economy	21700.00
0005435808283	1911	Economy	21700.00
0005435808279	1911	Economy	21700.00
0005435808274	1911	Economy	21700.00
0005434610201	23099	Economy	23900.00
0005434610219	23099	Economy	21700.00
0005434610202	23099	Economy	21700.00
0005434610212	23099	Economy	21700.00
0005434610214	23099	Economy	21700.00
0005434610215	23099	Economy	21700.00
0005434503850	16687	Economy	7600.00
0005434503796	16687	Economy	7600.00
0005434503876	16687	Economy	6900.00
0005434504043	16687	Economy	6900.00
0005434503924	16687	Economy	6900.00
0005434503925	16687	Economy	6900.00
0005434503895	16687	Economy	6900.00
0005434504055	16687	Economy	6900.00
0005434504029	16687	Economy	6900.00
0005434503915	16687	Economy	6900.00
0005434503783	16687	Economy	6900.00
0005434503961	16687	Economy	6900.00
0005434503884	16687	Economy	6900.00
0005434503879	16687	Economy	6900.00
0005434503973	16687	Economy	6900.00
0005434504084	16687	Economy	6900.00
0005434503799	16687	Economy	6900.00
0005434503900	16687	Economy	6900.00
0005434503914	16687	Economy	6900.00
0005434503825	16687	Economy	6900.00
0005434503967	16687	Economy	6900.00
0005434503784	16687	Economy	6900.00
0005434503885	16687	Economy	6900.00
0005434503841	16687	Economy	6900.00
0005434503968	16687	Economy	6900.00
0005434503983	16687	Economy	6900.00
0005434503985	16687	Economy	6900.00
0005434503894	16687	Economy	6900.00
0005434503822	16687	Economy	6900.00
0005434504040	16687	Economy	6900.00
0005434503798	16687	Economy	6900.00
0005434504056	16687	Economy	6900.00
0005434503899	16687	Economy	6900.00
0005434503867	16687	Economy	6900.00
0005434503987	16687	Economy	6900.00
0005434503821	16687	Economy	6900.00
0005434504041	16687	Economy	6900.00
0005434503737	16687	Economy	6900.00
0005434504050	16687	Economy	6900.00
0005434504005	16687	Economy	6900.00
0005434503795	16687	Economy	6900.00
0005434504039	16687	Economy	6900.00
0005434503756	16687	Economy	6900.00
0005434503988	16687	Economy	6900.00
0005434503986	16687	Economy	6900.00
0005434503738	16687	Economy	6900.00
0005434504042	16687	Economy	6900.00
0005434503984	16687	Economy	6900.00
0005434504294	22896	Economy	7600.00
0005434504286	22896	Economy	7600.00
0005434504291	22896	Economy	7600.00
0005434504297	22896	Economy	6900.00
0005434504266	22896	Economy	6900.00
0005434504281	22896	Economy	6900.00
0005434504269	22896	Economy	6900.00
0005434504296	22896	Economy	6900.00
0005434504288	22896	Economy	6900.00
0005434504261	22896	Economy	6900.00
0005434504275	22896	Economy	6900.00
0005434504280	22896	Economy	6900.00
0005434504289	22896	Economy	6900.00
0005434504274	22896	Economy	6900.00
0005434504299	22896	Economy	6900.00
0005434504262	22896	Economy	6900.00
0005434504264	22896	Economy	6900.00
0005434504279	22896	Economy	6900.00
0005434504282	22896	Economy	6900.00
0005434504277	22896	Economy	6900.00
0005434504270	22896	Economy	6900.00
0005434504290	22896	Economy	6900.00
0005434504272	22896	Economy	6900.00
0005434504268	22896	Economy	6900.00
0005434504278	22896	Economy	6900.00
0005434504287	22896	Economy	6900.00
0005434504267	22896	Economy	6900.00
0005434504276	22896	Economy	6900.00
0005434504284	22896	Economy	6900.00
0005434504263	22896	Economy	6900.00
0005434504300	22896	Economy	6900.00
0005434504285	22896	Economy	6900.00
0005434504295	22896	Economy	6900.00
0005434504293	22896	Economy	6900.00
0005434504283	22896	Economy	6900.00
0005434504265	22896	Economy	6900.00
0005434504298	22896	Economy	6900.00
0005434504292	22896	Economy	6900.00
0005434504271	22896	Economy	6900.00
0005434504273	22896	Economy	6900.00
0005434608320	6501	Economy	19100.00
0005434608322	6501	Economy	17300.00
0005434608318	6501	Economy	17300.00
0005434608329	6501	Economy	17300.00
0005434608324	6501	Economy	17300.00
0005434608333	6501	Economy	17300.00
0005434608337	6501	Economy	17300.00
0005434608336	6501	Economy	17300.00
0005434608330	6501	Economy	17300.00
0005434608319	6501	Economy	17300.00
0005434608328	6501	Economy	17300.00
0005434608338	6501	Economy	17300.00
0005434608331	6501	Economy	17300.00
0005434608325	6501	Economy	17300.00
0005434608327	6501	Economy	17300.00
0005434608321	6501	Economy	17300.00
0005434608326	6501	Economy	17300.00
0005434608332	6501	Economy	17300.00
0005434608323	6501	Economy	17300.00
0005434608335	6501	Economy	17300.00
0005434608334	6501	Economy	17300.00
0005434608304	22493	Economy	19100.00
0005434608284	22493	Economy	19100.00
0005434608288	22493	Economy	17300.00
0005434608315	22493	Economy	17300.00
0005434608300	22493	Economy	17300.00
0005434608289	22493	Economy	17300.00
0005434608292	22493	Economy	17300.00
0005434608291	22493	Economy	17300.00
0005434608298	22493	Economy	17300.00
0005434608281	22493	Economy	17300.00
0005434608293	22493	Economy	17300.00
0005434608282	22493	Economy	17300.00
0005434608314	22493	Economy	17300.00
0005434608297	22493	Economy	17300.00
0005434608295	22493	Economy	17300.00
0005434608285	22493	Economy	17300.00
0005434608283	22493	Economy	17300.00
0005434608299	22493	Economy	17300.00
0005434608296	22493	Economy	17300.00
0005434608305	22493	Economy	17300.00
0005434608290	22493	Economy	17300.00
0005433266666	2183	Economy	7700.00
0005435078412	2183	Economy	7700.00
0005433266652	2183	Economy	7000.00
0005435078405	2183	Economy	7000.00
0005435078401	2183	Economy	7000.00
0005435078410	2183	Economy	7000.00
0005435078409	2183	Economy	7000.00
0005435078413	2183	Economy	7000.00
0005433266653	2183	Economy	7000.00
0005433266665	2183	Economy	7000.00
0005435078408	2183	Economy	7000.00
0005435078404	2183	Economy	7000.00
0005435078406	2183	Economy	7000.00
0005435078407	2183	Economy	7000.00
0005435078411	2183	Economy	7000.00
0005433266651	2183	Economy	7000.00
0005435078399	2183	Economy	7000.00
0005435078402	2183	Economy	7000.00
0005435078403	2183	Economy	7000.00
0005435078400	2183	Economy	7000.00
0005433266758	24353	Economy	7700.00
0005435078290	24353	Economy	7000.00
0005433266760	24353	Economy	7000.00
0005435078261	24353	Economy	7000.00
0005433266762	24353	Economy	7000.00
0005433266763	24353	Economy	7000.00
0005435078260	24353	Economy	7000.00
0005433266757	24353	Economy	7000.00
0005435078325	24353	Economy	7000.00
0005435078288	24353	Economy	7000.00
0005435078241	24353	Economy	7000.00
0005435078304	24353	Economy	7000.00
0005433266759	24353	Economy	7000.00
0005435078273	24353	Economy	7000.00
0005435078250	24353	Economy	7000.00
0005433266761	24353	Economy	7000.00
0005435078351	24353	Economy	7000.00
0005435078283	24353	Economy	7000.00
0005435078248	24353	Economy	7000.00
0005433266765	24353	Economy	7000.00
0005433266764	24353	Economy	7000.00
0005435078249	24353	Economy	7000.00
0005434988790	6652	Economy	9800.00
0005434988788	6652	Economy	9800.00
0005434988789	6652	Economy	9800.00
0005434988786	6652	Economy	9800.00
0005435803275	6652	Economy	9800.00
0005435803276	6652	Economy	9800.00
0005434988785	6652	Economy	9800.00
0005434988784	6652	Economy	9800.00
0005434988787	6652	Economy	9800.00
0005435803274	6652	Economy	9800.00
0005434988664	23636	Economy	10800.00
0005434988641	23636	Economy	9800.00
0005434988646	23636	Economy	9800.00
0005434988650	23636	Economy	9800.00
0005434988666	23636	Economy	9800.00
0005434988661	23636	Economy	9800.00
0005434988659	23636	Economy	9800.00
0005435803264	23636	Economy	9800.00
0005434988660	23636	Economy	9800.00
0005432383318	30511	Business	9900.00
0005432383338	30511	Business	9900.00
0005433450062	30511	Business	9900.00
0005433450059	30511	Business	9900.00
0005433450068	30511	Business	9900.00
0005432383326	30511	Business	9900.00
0005432383349	30511	Business	9900.00
0005432383344	30511	Economy	3300.00
0005433450063	30511	Economy	3300.00
0005433453769	30511	Economy	3300.00
0005433450056	30511	Economy	3300.00
0005433450070	30511	Economy	3300.00
0005433450067	30511	Economy	3300.00
0005432383320	30511	Economy	3300.00
0005433454884	30511	Economy	3600.00
0005433450058	30511	Economy	3600.00
0005432383330	30511	Economy	3600.00
0005433450060	30511	Economy	3600.00
0005432383350	30511	Economy	3600.00
0005432383336	30511	Economy	3300.00
0005432383339	30511	Economy	3300.00
0005432383317	30511	Economy	3300.00
0005433450055	30511	Economy	3300.00
0005432383323	30511	Economy	3300.00
0005432383341	30511	Economy	3300.00
0005433450065	30511	Economy	3300.00
0005433454886	30511	Economy	3300.00
0005433454883	30511	Economy	3300.00
0005433450053	30511	Economy	3300.00
0005432383355	30511	Economy	3300.00
0005432383347	30511	Economy	3300.00
0005432383334	30511	Economy	3300.00
0005432383332	30511	Economy	3300.00
0005432383356	30511	Economy	3300.00
0005432383345	30511	Economy	3300.00
0005432383343	30511	Economy	3300.00
0005432383324	30511	Economy	3300.00
0005433450071	30511	Economy	3300.00
0005432383357	30511	Economy	3300.00
0005432383328	30511	Economy	3300.00
0005432383353	30511	Economy	3300.00
0005432383331	30511	Economy	3300.00
0005432383321	30511	Economy	3300.00
0005432383340	30511	Economy	3300.00
0005432383351	30511	Economy	3300.00
0005432383319	30511	Economy	3300.00
0005432383322	30511	Economy	3300.00
0005433450073	30511	Economy	3300.00
0005432383342	30511	Economy	3300.00
0005432383346	30511	Economy	3300.00
0005433450069	30511	Economy	3300.00
0005432383327	30511	Economy	3300.00
0005432383354	30511	Economy	3300.00
0005433450064	30511	Economy	3300.00
0005432383333	30511	Economy	3300.00
0005432383352	30511	Economy	3300.00
0005432383325	30511	Economy	3300.00
0005433450066	30511	Economy	3300.00
0005433450061	30511	Economy	3300.00
0005433450052	30511	Economy	3300.00
0005433450072	30511	Economy	3300.00
0005432383337	30511	Economy	3300.00
0005432383329	30511	Economy	3300.00
0005433454885	30511	Economy	3300.00
0005432383358	30511	Economy	3300.00
0005433450054	30511	Economy	3300.00
0005433450057	30511	Economy	3300.00
0005432383335	30511	Economy	3300.00
0005432383348	30511	Economy	3300.00
0005433449881	31296	Business	9900.00
0005432382779	31296	Business	9900.00
0005432383123	31296	Business	9900.00
0005432382901	31296	Business	9900.00
0005433450007	31296	Business	9900.00
0005432383001	31296	Business	9900.00
0005433449798	31296	Business	9900.00
0005432382977	31296	Economy	3300.00
0005432382777	31296	Economy	3300.00
0005432383075	31296	Economy	3300.00
0005432382900	31296	Economy	3300.00
0005433449942	31296	Economy	3300.00
0005433449876	31296	Economy	3300.00
0005433450006	31296	Economy	3300.00
0005432382844	31296	Economy	3600.00
0005432382945	31296	Economy	3600.00
0005432382733	31296	Economy	3600.00
0005432382947	31296	Economy	3600.00
0005433449762	31296	Economy	3300.00
0005432382949	31296	Economy	3300.00
0005432382989	31296	Economy	3300.00
0005432382859	31296	Economy	3300.00
0005432382921	31296	Economy	3300.00
0005433449847	31296	Economy	3300.00
0005432383074	31296	Economy	3300.00
0005433449879	31296	Economy	3300.00
0005432382909	31296	Economy	3300.00
0005432382953	31296	Economy	3300.00
0005432382902	31296	Economy	3300.00
0005432382827	31296	Economy	3300.00
0005432382873	31296	Economy	3300.00
0005432382787	31296	Economy	3300.00
0005432382759	31296	Economy	3300.00
0005433449827	31296	Economy	3300.00
0005432382755	31296	Economy	3300.00
0005432382855	31296	Economy	3300.00
0005432382736	31296	Economy	3300.00
0005432383002	31296	Economy	3300.00
0005432382781	31296	Economy	3300.00
0005433449885	31296	Economy	3300.00
0005433449914	31296	Economy	3300.00
0005432382780	31296	Economy	3300.00
0005432382925	31296	Economy	3300.00
0005432383124	31296	Economy	3300.00
0005432383122	31296	Economy	3300.00
0005433451609	31296	Economy	3300.00
0005432383088	31296	Economy	3300.00
0005432382946	31296	Economy	3300.00
0005433449788	31296	Economy	3300.00
0005433453759	31296	Economy	3300.00
0005432382954	31296	Economy	3300.00
0005432382908	31296	Economy	3300.00
0005433449938	31296	Economy	3300.00
0005432382881	31296	Economy	3300.00
0005432382926	31296	Economy	3300.00
0005432382922	31296	Economy	3300.00
0005432382835	31296	Economy	3300.00
0005432382978	31296	Economy	3300.00
0005432382948	31296	Economy	3300.00
0005432382778	31296	Economy	3300.00
0005432383168	31296	Economy	3300.00
0005433449864	31296	Economy	3300.00
0005432382903	31296	Economy	3300.00
0005433453760	31296	Economy	3300.00
0005433449870	31296	Economy	3300.00
0005433788217	20822	Economy	26200.00
0005435548452	20822	Economy	26200.00
0005433788218	20822	Economy	26200.00
0005435548440	20822	Economy	23800.00
0005435548428	20822	Economy	23800.00
0005433788212	20822	Economy	23800.00
0005435548460	20822	Economy	23800.00
0005433788210	20822	Economy	23800.00
0005433788216	20822	Economy	23800.00
0005435548464	20822	Economy	23800.00
0005433788209	20822	Economy	23800.00
0005435548427	20822	Economy	23800.00
0005435548467	20822	Economy	23800.00
0005433788208	20822	Economy	23800.00
0005435548453	20822	Economy	23800.00
0005435548448	20822	Economy	23800.00
0005433788215	20822	Economy	23800.00
0005433788214	20822	Economy	23800.00
0005433788207	20822	Economy	23800.00
0005433788213	20822	Economy	23800.00
0005433788206	20822	Economy	23800.00
0005435548454	20822	Economy	23800.00
0005435548449	20822	Economy	23800.00
0005435548444	20822	Economy	23800.00
0005433788211	20822	Economy	23800.00
0005433126805	10768	Economy	15600.00
0005433126811	10768	Economy	15600.00
0005433131663	10768	Economy	15600.00
0005435299748	10768	Economy	15600.00
0005433131697	10768	Economy	15600.00
0005435299747	10768	Economy	15600.00
0005433126822	10768	Economy	15600.00
0005435299739	10768	Economy	15600.00
0005433126809	10768	Economy	15600.00
0005433126806	10768	Economy	15600.00
0005433126810	10768	Economy	15600.00
0005433126830	10768	Economy	15600.00
0005435299762	10768	Economy	15600.00
0005435299721	10768	Economy	15600.00
0005433126803	10768	Economy	15600.00
0005435299749	10768	Economy	15600.00
0005433126867	29746	Economy	17100.00
0005435299799	29746	Economy	17100.00
0005433126869	29746	Economy	17100.00
0005433126870	29746	Economy	15600.00
0005435302223	29746	Economy	15600.00
0005435299800	29746	Economy	15600.00
0005433129297	29746	Economy	15600.00
0005435302221	29746	Economy	15600.00
0005433129300	29746	Economy	15600.00
0005433126866	29746	Economy	15600.00
0005433126868	29746	Economy	15600.00
0005435299801	29746	Economy	15600.00
0005435302224	29746	Economy	15600.00
0005435302220	29746	Economy	15600.00
0005433129298	29746	Economy	15600.00
0005435299802	29746	Economy	15600.00
0005433129299	29746	Economy	15600.00
0005435302222	29746	Economy	15600.00
0005433110027	2424	Economy	17200.00
0005433110061	2424	Economy	17200.00
0005434287391	2424	Economy	17200.00
0005433110039	2424	Economy	17200.00
0005432264485	2424	Economy	15700.00
0005433110021	2424	Economy	15700.00
0005433110005	2424	Economy	15700.00
0005434287373	2424	Economy	15700.00
0005433110095	2424	Economy	15700.00
0005434287375	2424	Economy	15700.00
0005433110026	2424	Economy	15700.00
0005432264484	2424	Economy	15700.00
0005433110041	2424	Economy	15700.00
0005433110022	2424	Economy	15700.00
0005434287383	2424	Economy	15700.00
0005433110006	2424	Economy	15700.00
0005433110025	2424	Economy	15700.00
0005434287376	2424	Economy	15700.00
0005434287385	2424	Economy	15700.00
0005434287379	2424	Economy	15700.00
0005434287372	2424	Economy	15700.00
0005434287389	2424	Economy	15700.00
0005434287378	2424	Economy	15700.00
0005434287371	2424	Economy	15700.00
0005434287384	2424	Economy	15700.00
0005434287388	2424	Economy	15700.00
0005433109973	2424	Economy	15700.00
0005434287381	2424	Economy	15700.00
0005433110019	2424	Economy	15700.00
0005433110016	2424	Economy	15700.00
0005434287386	2424	Economy	15700.00
0005434287380	2424	Economy	15700.00
0005433109990	2424	Economy	15700.00
0005433110040	2424	Economy	15700.00
0005434287374	2424	Economy	15700.00
0005434287382	2424	Economy	15700.00
0005434287387	2424	Economy	15700.00
0005434287390	2424	Economy	15700.00
0005432264486	2424	Economy	15700.00
0005433110014	2424	Economy	15700.00
0005434287377	2424	Economy	15700.00
0005434287392	2424	Economy	15700.00
0005433110097	26834	Economy	17200.00
0005434287253	26834	Economy	17200.00
0005433110107	26834	Economy	15700.00
0005434287088	26834	Economy	15700.00
0005434287120	26834	Economy	15700.00
0005433110098	26834	Economy	15700.00
0005434287169	26834	Economy	15700.00
0005434287119	26834	Economy	15700.00
0005433110105	26834	Economy	15700.00
0005433110101	26834	Economy	15700.00
0005434287172	26834	Economy	15700.00
0005433110102	26834	Economy	15700.00
0005434287199	26834	Economy	15700.00
0005434287200	26834	Economy	15700.00
0005434287146	26834	Economy	15700.00
0005433110109	26834	Economy	15700.00
0005433110108	26834	Economy	15700.00
0005434287107	26834	Economy	15700.00
0005434287252	26834	Economy	15700.00
0005433110104	26834	Economy	15700.00
0005433110100	26834	Economy	15700.00
0005434287145	26834	Economy	15700.00
0005434287112	26834	Economy	15700.00
0005433110099	26834	Economy	15700.00
0005434287225	26834	Economy	15700.00
0005434287173	26834	Economy	15700.00
0005434287241	26834	Economy	15700.00
0005434287211	26834	Economy	15700.00
0005433110106	26834	Economy	15700.00
0005434287152	26834	Economy	15700.00
0005434287191	26834	Economy	15700.00
0005433110103	26834	Economy	15700.00
0005434269093	25444	Economy	22800.00
0005435856220	25444	Economy	22800.00
0005435856222	25444	Economy	22800.00
0005435856223	25444	Economy	22800.00
0005434272182	25444	Economy	22800.00
0005434272178	25444	Economy	22800.00
0005435856221	25444	Economy	22800.00
0005434272180	25444	Economy	22800.00
0005434272179	25444	Economy	22800.00
0005434269089	25444	Economy	22800.00
0005434272198	26673	Economy	25000.00
0005435854045	26673	Economy	22800.00
0005435856171	26673	Economy	22800.00
0005435854046	26673	Economy	22800.00
0005435856179	26673	Economy	22800.00
0005435856172	26673	Economy	22800.00
0005435856177	26673	Economy	22800.00
0005434273083	26673	Economy	22800.00
0005435856178	26673	Economy	22800.00
0005435856191	26673	Economy	22800.00
0005435856180	26673	Economy	22800.00
0005435856186	26673	Economy	22800.00
0005435854048	26673	Economy	22800.00
0005434273082	26673	Economy	22800.00
0005434273081	26673	Economy	22800.00
0005434520221	19079	Economy	24600.00
0005435314844	19079	Economy	24600.00
0005434520194	19079	Economy	24600.00
0005434520235	19079	Economy	22300.00
0005434520245	19079	Economy	22300.00
0005434520262	19079	Economy	22300.00
0005434520231	19079	Economy	22300.00
0005434520217	19079	Economy	22300.00
0005435314850	19079	Economy	22300.00
0005435314849	19079	Economy	22300.00
0005434520211	19079	Economy	22300.00
0005434520238	19079	Economy	22300.00
0005435314845	19079	Economy	22300.00
0005435314851	19079	Economy	22300.00
0005435314846	19079	Economy	22300.00
0005435314848	19079	Economy	22300.00
0005434520263	19079	Economy	22300.00
0005434520230	19079	Economy	22300.00
0005435314854	19079	Economy	22300.00
0005434520220	19079	Economy	22300.00
0005434520186	19079	Economy	22300.00
0005435314847	19079	Economy	22300.00
0005434520198	19079	Economy	22300.00
0005434520212	19079	Economy	22300.00
0005434520195	19079	Economy	22300.00
0005434520222	19079	Economy	22300.00
0005435314852	19079	Economy	22300.00
0005434520233	19079	Economy	22300.00
0005434520244	19079	Economy	22300.00
0005434520243	19079	Economy	22300.00
0005435314853	19079	Economy	22300.00
0005434520236	19079	Economy	22300.00
0005434520197	19079	Economy	22300.00
0005434520239	19079	Economy	22300.00
0005435314855	19079	Economy	22300.00
0005434520232	19079	Economy	22300.00
0005434520156	19079	Economy	22300.00
0005435314856	19079	Economy	22300.00
0005435314857	19079	Economy	22300.00
0005434520189	19079	Economy	22300.00
0005434520229	19079	Economy	22300.00
0005434520196	19079	Economy	22300.00
0005434520237	19079	Economy	22300.00
0005434520193	19079	Economy	22300.00
0005435314858	19079	Economy	22300.00
0005434520213	19079	Economy	22300.00
0005433874365	7795	Economy	17400.00
0005433874361	7795	Economy	17400.00
0005433874369	7795	Economy	17400.00
0005433874362	7795	Economy	17400.00
0005433874368	7795	Economy	17400.00
0005433874363	7795	Economy	17400.00
0005433874367	7795	Economy	17400.00
0005433874360	7795	Economy	17400.00
0005433874366	7795	Economy	17400.00
0005433874359	7795	Economy	17400.00
0005433874364	7795	Economy	17400.00
0005433874327	32640	Economy	19200.00
0005433874330	32640	Economy	19200.00
0005433874321	32640	Economy	17400.00
0005433874326	32640	Economy	17400.00
0005433874337	32640	Economy	17400.00
0005433874336	32640	Economy	17400.00
0005433874335	32640	Economy	17400.00
0005433868620	4797	Economy	19400.00
0005433868622	4797	Economy	19400.00
0005435860469	4797	Economy	19400.00
0005433868594	4797	Economy	19400.00
0005433868625	4797	Economy	17600.00
0005433868606	4797	Economy	17600.00
0005433868611	4797	Economy	17600.00
0005433868607	4797	Economy	17600.00
0005433868608	4797	Economy	17600.00
0005435860455	4797	Economy	17600.00
0005433868609	4797	Economy	17600.00
0005433868627	4797	Economy	17600.00
0005433868626	4797	Economy	17600.00
0005433868628	4797	Economy	17600.00
0005433868610	4797	Economy	17600.00
0005433868623	4797	Economy	17600.00
0005433868605	4797	Economy	17600.00
0005433868617	4797	Economy	17600.00
0005433868600	4797	Economy	17600.00
0005433868621	4797	Economy	17600.00
0005433868624	4797	Economy	17600.00
0005433868612	4797	Economy	17600.00
0005433868601	4797	Economy	17600.00
0005433868616	4797	Economy	17600.00
0005433868599	4797	Economy	17600.00
0005433868603	4797	Economy	17600.00
0005433868619	4797	Economy	17600.00
0005433868618	4797	Economy	17600.00
0005433868615	4797	Economy	17600.00
0005433868602	4797	Economy	17600.00
0005433868614	4797	Economy	17600.00
0005433868596	4797	Economy	17600.00
0005433868613	4797	Economy	17600.00
0005433868604	4797	Economy	17600.00
0005433868629	4797	Economy	17600.00
0005433868595	4797	Economy	17600.00
0005433868598	4797	Economy	17600.00
0005433868597	4797	Economy	17600.00
0005433868256	32613	Economy	19400.00
0005433868173	32613	Economy	19400.00
0005433868241	32613	Economy	19400.00
0005433868161	32613	Economy	17600.00
0005433868281	32613	Economy	17600.00
0005433868213	32613	Economy	17600.00
0005433868126	32613	Economy	17600.00
0005433868338	32613	Economy	17600.00
0005433868214	32613	Economy	17600.00
0005433868280	32613	Economy	17600.00
0005433868310	32613	Economy	17600.00
0005433868153	32613	Economy	17600.00
0005433868137	32613	Economy	17600.00
0005433868218	32613	Economy	17600.00
0005433868138	32613	Economy	17600.00
0005433868227	32613	Economy	17600.00
0005433868190	32613	Economy	17600.00
0005433868136	32613	Economy	17600.00
0005433868236	32613	Economy	17600.00
0005433868175	32613	Economy	17600.00
0005433868276	32613	Economy	17600.00
0005433868216	32613	Economy	17600.00
0005433868275	32613	Economy	17600.00
0005433868144	32613	Economy	17600.00
0005433868124	32613	Economy	17600.00
0005433868189	32613	Economy	17600.00
0005433868184	32613	Economy	17600.00
0005433868152	32613	Economy	17600.00
0005433868222	32613	Economy	17600.00
0005433868185	32613	Economy	17600.00
0005433868242	32613	Economy	17600.00
0005433868339	32613	Economy	17600.00
0005433868095	32613	Economy	17600.00
0005433868362	32613	Economy	17600.00
0005435860502	32613	Economy	17600.00
0005433868174	32613	Economy	17600.00
0005433868253	32613	Economy	17600.00
0005433868363	32613	Economy	17600.00
0005433868199	32613	Economy	17600.00
0005433868314	32613	Economy	17600.00
0005433868104	32613	Economy	17600.00
0005433867963	32613	Economy	17600.00
0005435860503	32613	Economy	17600.00
0005433868139	32613	Economy	17600.00
0005433868337	32613	Economy	17600.00
0005433868308	32613	Economy	17600.00
0005435911414	3430	Economy	24800.00
0005435911394	3430	Economy	24800.00
0005434460514	3430	Economy	22600.00
0005434460515	3430	Economy	22600.00
0005435911386	3430	Economy	22600.00
0005434663460	3430	Economy	22600.00
0005435911425	3430	Economy	22600.00
0005435911415	3430	Economy	22600.00
0005434663459	3430	Economy	22600.00
0005434663465	3430	Economy	22600.00
0005434461656	3430	Economy	22600.00
0005435911423	3430	Economy	22600.00
0005434460516	3430	Economy	22600.00
0005434663469	3430	Economy	22600.00
0005434663466	3430	Economy	22600.00
0005434663468	3430	Economy	22600.00
0005434663470	3430	Economy	22600.00
0005434663464	3430	Economy	22600.00
0005434663462	3430	Economy	22600.00
0005434663471	3430	Economy	22600.00
0005435911424	3430	Economy	22600.00
0005434663463	3430	Economy	22600.00
0005434461655	3430	Economy	22600.00
0005434663461	3430	Economy	22600.00
0005434663467	3430	Economy	22600.00
0005435911420	3430	Economy	22600.00
0005434460484	12484	Economy	24800.00
0005434663299	12484	Economy	24800.00
0005434462777	12484	Economy	24800.00
0005434462778	12484	Economy	24800.00
0005435911484	12484	Economy	22600.00
0005434663297	12484	Economy	22600.00
0005435911480	12484	Economy	22600.00
0005434462776	12484	Economy	22600.00
0005434460494	12484	Economy	22600.00
0005434460493	12484	Economy	22600.00
0005434462782	12484	Economy	22600.00
0005435911483	12484	Economy	22600.00
0005434663366	12484	Economy	22600.00
0005435911479	12484	Economy	22600.00
0005434462781	12484	Economy	22600.00
0005435911482	12484	Economy	22600.00
0005434663364	12484	Economy	22600.00
0005435911481	12484	Economy	22600.00
0005434460487	12484	Economy	22600.00
0005435911486	12484	Economy	22600.00
0005434663365	12484	Economy	22600.00
0005434462761	12484	Economy	22600.00
0005434462768	12484	Economy	22600.00
0005434663387	12484	Economy	22600.00
0005434462779	12484	Economy	22600.00
0005434663418	12484	Economy	22600.00
0005434460497	12484	Economy	22600.00
0005434663396	12484	Economy	22600.00
0005434460479	12484	Economy	22600.00
0005434663298	12484	Economy	22600.00
0005435911485	12484	Economy	22600.00
0005434462774	12484	Economy	22600.00
0005433868280	14493	Economy	18500.00
0005433868175	14493	Economy	18500.00
0005433868281	14493	Economy	18500.00
0005433868241	14493	Economy	18500.00
0005433868253	14493	Economy	16800.00
0005433868137	14493	Economy	16800.00
0005433868216	14493	Economy	16800.00
0005433868184	14493	Economy	16800.00
0005433868126	14493	Economy	16800.00
0005433868190	14493	Economy	16800.00
0005433868337	14493	Economy	16800.00
0005433868227	14493	Economy	16800.00
0005433868338	14493	Economy	16800.00
0005433868363	14493	Economy	16800.00
0005433868138	14493	Economy	16800.00
0005433868214	14493	Economy	16800.00
0005433868185	14493	Economy	16800.00
0005433868276	14493	Economy	16800.00
0005435860502	14493	Economy	16800.00
0005433868152	14493	Economy	16800.00
0005433868153	14493	Economy	16800.00
0005433868339	14493	Economy	16800.00
0005433868236	14493	Economy	16800.00
0005435860503	14493	Economy	16800.00
0005433868139	14493	Economy	16800.00
0005433868173	14493	Economy	16800.00
0005433868189	14493	Economy	16800.00
0005433867963	14493	Economy	16800.00
0005433868222	14493	Economy	16800.00
0005433868308	14493	Economy	16800.00
0005433868136	14493	Economy	16800.00
0005433868314	14493	Economy	16800.00
0005433868362	14493	Economy	16800.00
0005433868161	14493	Economy	16800.00
0005433868256	14493	Economy	16800.00
0005433868199	14493	Economy	16800.00
0005433868174	14493	Economy	16800.00
0005433868242	14493	Economy	16800.00
0005433868124	14493	Economy	16800.00
0005433868144	14493	Economy	16800.00
0005433868104	14493	Economy	16800.00
0005433868218	14493	Economy	16800.00
0005433868095	14493	Economy	16800.00
0005433868275	14493	Economy	16800.00
0005433868310	14493	Economy	16800.00
0005433868213	14493	Economy	16800.00
0005433868564	32654	Economy	18500.00
0005433868576	32654	Economy	18500.00
0005433868581	32654	Economy	18500.00
0005433868561	32654	Economy	18500.00
0005435860456	32654	Economy	16800.00
0005433868570	32654	Economy	16800.00
0005433868566	32654	Economy	16800.00
0005433868589	32654	Economy	16800.00
0005433868583	32654	Economy	16800.00
0005433868573	32654	Economy	16800.00
0005433868582	32654	Economy	16800.00
0005433868590	32654	Economy	16800.00
0005433868579	32654	Economy	16800.00
0005433868592	32654	Economy	16800.00
0005433868555	32654	Economy	16800.00
0005433868588	32654	Economy	16800.00
0005433868559	32654	Economy	16800.00
0005433868568	32654	Economy	16800.00
0005433868563	32654	Economy	16800.00
0005433868586	32654	Economy	16800.00
0005433868591	32654	Economy	16800.00
0005433868585	32654	Economy	16800.00
0005433868562	32654	Economy	16800.00
0005435860458	32654	Economy	16800.00
0005433868569	32654	Economy	16800.00
0005433868567	32654	Economy	16800.00
0005433868558	32654	Economy	16800.00
0005433868572	32654	Economy	16800.00
0005433868575	32654	Economy	16800.00
0005435860457	32654	Economy	16800.00
0005433868574	32654	Economy	16800.00
0005433868552	32654	Economy	16800.00
0005433868571	32654	Economy	16800.00
0005433868557	32654	Economy	16800.00
0005433868587	32654	Economy	16800.00
0005433868577	32654	Economy	16800.00
0005433868565	32654	Economy	16800.00
0005433868553	32654	Economy	16800.00
0005433868578	32654	Economy	16800.00
0005433868593	32654	Economy	16800.00
0005433868554	32654	Economy	16800.00
0005433868556	32654	Economy	16800.00
0005433868584	32654	Economy	16800.00
0005433868580	32654	Economy	16800.00
0005435860466	32654	Economy	16800.00
0005433868560	32654	Economy	16800.00
0005432799230	12118	Economy	4900.00
0005432799257	12118	Economy	4400.00
0005432799399	12118	Economy	4400.00
0005432799188	12118	Economy	4400.00
0005432799403	12118	Economy	4400.00
0005432799279	12118	Economy	4400.00
0005432799344	12118	Economy	4400.00
0005432799261	12118	Economy	4400.00
0005432799315	12118	Economy	4400.00
0005432799375	12118	Economy	4400.00
0005432799335	12118	Economy	4400.00
0005432799305	12118	Economy	4400.00
0005432799407	12118	Economy	4400.00
0005432799329	12118	Economy	4400.00
0005432799408	12118	Economy	4400.00
0005432799251	12118	Economy	4400.00
0005432799382	12118	Economy	4400.00
0005432799256	12118	Economy	4400.00
0005432799302	12118	Economy	4400.00
0005432799243	12118	Economy	4400.00
0005432799351	12118	Economy	4400.00
0005432799206	12118	Economy	4400.00
0005432799314	12118	Economy	4400.00
0005432799233	12118	Economy	4400.00
0005432799258	12118	Economy	4400.00
0005432799237	12118	Economy	4400.00
0005432799540	14791	Economy	4900.00
0005432799537	14791	Economy	4900.00
0005432799536	14791	Economy	4900.00
0005432799545	14791	Economy	4400.00
0005432799541	14791	Economy	4400.00
0005432799556	14791	Economy	4400.00
0005432799558	14791	Economy	4400.00
0005432799534	14791	Economy	4400.00
0005432799548	14791	Economy	4400.00
0005432799551	14791	Economy	4400.00
0005432799533	14791	Economy	4400.00
0005432799535	14791	Economy	4400.00
0005432799546	14791	Economy	4400.00
0005432799543	14791	Economy	4400.00
0005432799538	14791	Economy	4400.00
0005432799560	14791	Economy	4400.00
0005432799544	14791	Economy	4400.00
0005432799532	14791	Economy	4400.00
0005432799552	14791	Economy	4400.00
0005432799549	14791	Economy	4400.00
0005432799561	14791	Economy	4400.00
0005432799547	14791	Economy	4400.00
0005432799554	14791	Economy	4400.00
0005432799550	14791	Economy	4400.00
0005432799531	14791	Economy	4400.00
0005432799542	14791	Economy	4400.00
0005432799553	14791	Economy	4400.00
0005432799559	14791	Economy	4400.00
0005432799557	14791	Economy	4400.00
0005432799539	14791	Economy	4400.00
0005432799555	14791	Economy	4400.00
0005434408025	7062	Business	49100.00
0005434408011	7062	Business	49100.00
0005435293283	7062	Business	49100.00
0005434408001	7062	Business	49100.00
0005434408013	7062	Business	49100.00
0005435310989	7062	Business	49100.00
0005434408047	7062	Business	49100.00
0005435293156	7062	Business	49100.00
0005434408034	7062	Business	49100.00
0005434299653	7062	Business	49100.00
0005435310960	7062	Business	49100.00
0005434407996	7062	Business	49100.00
0005432153970	7062	Economy	16400.00
0005434408026	7062	Economy	16400.00
0005435311004	7062	Economy	16400.00
0005434408024	7062	Economy	16400.00
0005434408022	7062	Economy	16400.00
0005435293215	7062	Economy	16400.00
0005435293159	7062	Economy	16400.00
0005434408002	7062	Economy	16400.00
0005434407994	7062	Economy	16400.00
0005434299667	7062	Economy	16400.00
0005434408057	7062	Economy	16400.00
0005432153967	7062	Economy	16400.00
0005435310999	7062	Economy	16400.00
0005434408053	7062	Economy	16400.00
0005434408017	7062	Economy	16400.00
0005434299665	7062	Economy	16400.00
0005434408044	7062	Economy	16400.00
0005435311006	7062	Economy	16400.00
0005432153965	7062	Economy	16400.00
0005434408008	7062	Economy	16400.00
0005435293166	7062	Economy	16400.00
0005434407999	7062	Economy	16400.00
0005434407997	7062	Economy	16400.00
0005435310996	7062	Economy	16400.00
0005434408003	7062	Economy	16400.00
0005435311008	7062	Economy	16400.00
0005434408049	7062	Economy	16400.00
0005434408052	7062	Economy	16400.00
0005434299662	7062	Economy	16400.00
0005435293152	7062	Economy	16400.00
0005434299657	7062	Economy	16400.00
0005434299669	7062	Economy	16400.00
0005434408058	7062	Economy	16400.00
0005435311001	7062	Economy	16400.00
0005434408014	7062	Economy	16400.00
0005434408023	7062	Economy	16400.00
0005434408048	7062	Economy	16400.00
0005434299658	7062	Economy	16400.00
0005434299661	7062	Economy	16400.00
0005432153964	7062	Economy	18000.00
0005434408012	7062	Economy	18000.00
0005434408040	7062	Economy	18000.00
0005434408010	7062	Economy	18000.00
0005434408020	7062	Economy	18000.00
0005434408019	7062	Economy	16400.00
0005434408056	7062	Economy	16400.00
0005434408031	7062	Economy	16400.00
0005434407995	7062	Economy	16400.00
0005434408006	7062	Economy	16400.00
0005434408042	7062	Economy	16400.00
0005434408029	7062	Economy	16400.00
0005434408035	7062	Economy	16400.00
0005434408018	7062	Economy	16400.00
0005434408036	7062	Economy	16400.00
0005434408004	7062	Economy	16400.00
0005434408038	7062	Economy	16400.00
0005434299664	7062	Economy	16400.00
0005434408039	7062	Economy	16400.00
0005434408043	7062	Economy	16400.00
0005435293157	7062	Economy	16400.00
0005434408033	7062	Economy	16400.00
0005434299654	7062	Economy	16400.00
0005432153968	7062	Economy	16400.00
0005432153969	7062	Economy	16400.00
0005434408016	7062	Economy	16400.00
0005434299651	7062	Economy	16400.00
0005434408050	7062	Economy	16400.00
0005435310984	7062	Economy	16400.00
0005435310985	7062	Economy	16400.00
0005435293285	7062	Economy	16400.00
0005434299652	7062	Economy	16400.00
0005434408041	7062	Economy	16400.00
0005434299656	7062	Economy	16400.00
0005435311020	7062	Economy	16400.00
0005434408037	7062	Economy	16400.00
0005434408000	7062	Economy	16400.00
0005432153966	7062	Economy	16400.00
0005434408054	7062	Economy	16400.00
0005434299668	7062	Economy	16400.00
0005434299660	7062	Economy	16400.00
0005434408021	7062	Economy	16400.00
0005434408051	7062	Economy	16400.00
0005434299650	7062	Economy	16400.00
0005434299655	7062	Economy	16400.00
0005434299648	7062	Economy	16400.00
0005434408005	7062	Economy	16400.00
0005434408032	7062	Economy	16400.00
0005434299666	7062	Economy	16400.00
0005434299646	7062	Economy	16400.00
0005435293214	7062	Economy	16400.00
0005435311002	7062	Economy	16400.00
0005435293178	7062	Economy	16400.00
0005435293185	7062	Economy	16400.00
0005432108260	7062	Economy	16400.00
0005434408027	7062	Economy	16400.00
0005434408007	7062	Economy	16400.00
0005435311023	7062	Economy	16400.00
0005435310991	7062	Economy	16400.00
0005434408009	7062	Economy	16400.00
0005434299663	7062	Economy	16400.00
0005434299647	7062	Economy	16400.00
0005434299659	7062	Economy	16400.00
0005432108261	7062	Economy	16400.00
0005435310990	7062	Economy	16400.00
0005434408055	7062	Economy	16400.00
0005434408045	7062	Economy	16400.00
0005435311021	7062	Economy	16400.00
0005434299649	7062	Economy	16400.00
0005434408046	7062	Economy	16400.00
0005434407998	7062	Economy	16400.00
0005434408015	7062	Economy	16400.00
0005434408030	7062	Economy	16400.00
0005434408059	7062	Economy	16400.00
0005434408028	7062	Economy	16400.00
0005435293158	7062	Economy	16400.00
0005435293284	7062	Economy	16400.00
0005434299564	26908	Business	49100.00
0005434407633	26908	Business	49100.00
0005434407412	26908	Business	49100.00
0005432058394	26908	Business	49100.00
0005434407404	26908	Business	49100.00
0005434407471	26908	Business	49100.00
0005434299400	26908	Business	49100.00
0005434407611	26908	Business	49100.00
0005435311104	26908	Business	49100.00
0005434407396	26908	Business	49100.00
0005435293311	26908	Business	49100.00
0005434407640	26908	Business	49100.00
0005434407397	26908	Economy	16400.00
0005434407499	26908	Economy	16400.00
0005434299401	26908	Economy	16400.00
0005434407571	26908	Economy	16400.00
0005434407390	26908	Economy	16400.00
0005434407252	26908	Economy	16400.00
0005434407411	26908	Economy	16400.00
0005435293307	26908	Economy	16400.00
0005434407589	26908	Economy	16400.00
0005434407517	26908	Economy	16400.00
0005434407458	26908	Economy	16400.00
0005435293310	26908	Economy	16400.00
0005434407672	26908	Economy	16400.00
0005434407441	26908	Economy	16400.00
0005432058393	26908	Economy	16400.00
0005434407231	26908	Economy	16400.00
0005434299480	26908	Economy	16400.00
0005434299413	26908	Economy	16400.00
0005434407319	26908	Economy	16400.00
0005434407487	26908	Economy	16400.00
0005434299474	26908	Economy	16400.00
0005434407253	26908	Economy	16400.00
0005434407315	26908	Economy	16400.00
0005435293304	26908	Economy	16400.00
0005435311103	26908	Economy	16400.00
0005434407384	26908	Economy	16400.00
0005435293306	26908	Economy	16400.00
0005434407440	26908	Economy	16400.00
0005434407385	26908	Economy	16400.00
0005434407663	26908	Economy	16400.00
0005432058397	26908	Economy	16400.00
0005434407363	26908	Economy	18000.00
0005434299465	26908	Economy	16400.00
0005434407302	26908	Economy	18000.00
0005434407683	26908	Economy	18000.00
0005434299563	26908	Economy	18000.00
0005434299412	26908	Economy	18000.00
0005434407394	26908	Economy	18000.00
0005434407230	26908	Economy	16400.00
0005435311098	26908	Economy	16400.00
0005435311096	26908	Economy	16400.00
0005435311101	26908	Economy	16400.00
0005434407052	26908	Economy	16400.00
0005434407433	26908	Economy	16400.00
0005434407459	26908	Economy	16400.00
0005434407444	26908	Economy	16400.00
0005434407541	26908	Economy	16400.00
0005434299473	26908	Economy	16400.00
0005434407648	26908	Economy	16400.00
0005434407439	26908	Economy	16400.00
0005434407377	26908	Economy	16400.00
0005434407448	26908	Economy	16400.00
0005434407632	26908	Economy	16400.00
0005435311102	26908	Economy	16400.00
0005435293309	26908	Economy	16400.00
0005434407274	26908	Economy	16400.00
0005434407694	26908	Economy	16400.00
0005435293303	26908	Economy	16400.00
0005434299434	26908	Economy	16400.00
0005434407320	26908	Economy	16400.00
0005434407300	26908	Economy	16400.00
0005435293301	26908	Economy	16400.00
0005434407450	26908	Economy	16400.00
0005434407515	26908	Economy	16400.00
0005434407121	26908	Economy	16400.00
0005434407428	26908	Economy	16400.00
0005435293308	26908	Economy	16400.00
0005432058396	26908	Economy	16400.00
0005434407673	26908	Economy	16400.00
0005434299598	26908	Economy	16400.00
0005434407233	26908	Economy	16400.00
0005434407272	26908	Economy	16400.00
0005435311097	26908	Economy	16400.00
0005435311100	26908	Economy	16400.00
0005434407210	26908	Economy	16400.00
0005434407463	26908	Economy	16400.00
0005434407610	26908	Economy	16400.00
0005434407624	26908	Economy	16400.00
0005434407649	26908	Economy	16400.00
0005434407500	26908	Economy	16400.00
0005435311095	26908	Economy	16400.00
0005435293302	26908	Economy	16400.00
0005434407510	26908	Economy	16400.00
0005434299475	26908	Economy	16400.00
0005434407586	26908	Economy	16400.00
0005434407476	26908	Economy	16400.00
0005432058395	26908	Economy	16400.00
0005435293299	26908	Economy	16400.00
0005435293298	26908	Economy	16400.00
0005435293300	26908	Economy	16400.00
0005434407451	26908	Economy	16400.00
0005434407542	26908	Economy	16400.00
0005434407301	26908	Economy	16400.00
0005434299433	26908	Economy	16400.00
0005434407467	26908	Economy	16400.00
0005434407516	26908	Economy	16400.00
0005434407427	26908	Economy	16400.00
0005435311094	26908	Economy	16400.00
0005434407623	26908	Economy	16400.00
0005435311099	26908	Economy	16400.00
0005434407299	26908	Economy	16400.00
0005434407410	26908	Economy	16400.00
0005434407207	26908	Economy	16400.00
0005435293305	26908	Economy	16400.00
0005434407334	26908	Economy	16400.00
0005434407622	26908	Economy	16400.00
0005432604526	6457	Economy	16500.00
0005432604498	6457	Economy	16500.00
0005432604501	6457	Economy	16500.00
0005432604513	6457	Economy	16500.00
0005432604521	6457	Economy	15000.00
0005432604505	6457	Economy	15000.00
0005432604517	6457	Economy	15000.00
0005432604519	6457	Economy	15000.00
0005432604532	6457	Economy	15000.00
0005432604506	6457	Economy	15000.00
0005432604522	6457	Economy	15000.00
0005432604495	6457	Economy	15000.00
0005432604507	6457	Economy	15000.00
0005432604528	6457	Economy	15000.00
0005432604515	6457	Economy	15000.00
0005432604516	6457	Economy	15000.00
0005434512131	6457	Economy	15000.00
0005432604510	6457	Economy	15000.00
0005434512130	6457	Economy	15000.00
0005432604533	6457	Economy	15000.00
0005432604523	6457	Economy	15000.00
0005432604497	6457	Economy	15000.00
0005434512132	6457	Economy	15000.00
0005432604514	6457	Economy	15000.00
0005432604531	6457	Economy	15000.00
0005432604502	6457	Economy	15000.00
0005434512129	6457	Economy	15000.00
0005432604503	6457	Economy	15000.00
0005432604525	6457	Economy	15000.00
0005432604508	6457	Economy	15000.00
0005432604524	6457	Economy	15000.00
0005435218111	6457	Economy	15000.00
0005432604504	6457	Economy	15000.00
0005432604499	6457	Economy	15000.00
0005432604527	6457	Economy	15000.00
0005432604512	6457	Economy	15000.00
0005435218110	6457	Economy	15000.00
0005432604509	6457	Economy	15000.00
0005432604518	6457	Economy	15000.00
0005432604496	6457	Economy	15000.00
0005432604494	6457	Economy	15000.00
0005432604500	6457	Economy	15000.00
0005432604529	6457	Economy	15000.00
0005432604530	6457	Economy	15000.00
0005432604511	6457	Economy	15000.00
0005432604520	6457	Economy	15000.00
0005432604184	21380	Economy	16500.00
0005434512096	21380	Economy	16500.00
0005435221059	21380	Economy	16500.00
0005432604196	21380	Economy	16500.00
0005432604111	21380	Economy	15000.00
0005434512114	21380	Economy	15000.00
0005434512108	21380	Economy	15000.00
0005434512058	21380	Economy	15000.00
0005432604103	21380	Economy	15000.00
0005432604166	21380	Economy	15000.00
0005432604049	21380	Economy	15000.00
0005432604141	21380	Economy	15000.00
0005432604194	21380	Economy	15000.00
0005432604105	21380	Economy	15000.00
0005432604050	21380	Economy	15000.00
0005432604277	21380	Economy	15000.00
0005432604039	21380	Economy	15000.00
0005432604183	21380	Economy	15000.00
0005432604095	21380	Economy	15000.00
0005432604003	21380	Economy	15000.00
0005432604185	21380	Economy	15000.00
0005432604142	21380	Economy	15000.00
0005432604065	21380	Economy	15000.00
0005432604040	21380	Economy	15000.00
0005434512107	21380	Economy	15000.00
0005432604227	21380	Economy	15000.00
0005432604197	21380	Economy	15000.00
0005432604079	21380	Economy	15000.00
0005434512057	21380	Economy	15000.00
0005435221519	21380	Economy	15000.00
0005432604067	21380	Economy	15000.00
0005432604104	21380	Economy	15000.00
0005435221058	21380	Economy	15000.00
0005432604066	21380	Economy	15000.00
0005432604278	21380	Economy	15000.00
0005434512093	21380	Economy	15000.00
0005432604061	21380	Economy	15000.00
0005432604096	21380	Economy	15000.00
0005434512109	21380	Economy	15000.00
0005432604112	21380	Economy	15000.00
0005432604228	21380	Economy	15000.00
0005432604118	21380	Economy	15000.00
0005432604127	21380	Economy	15000.00
0005434906958	14971	Business	18900.00
0005434906977	14971	Business	18900.00
0005434907002	14971	Business	18900.00
0005433251606	14971	Business	18900.00
0005434907012	14971	Business	18900.00
0005434907020	14971	Business	18900.00
0005433251604	14971	Business	18900.00
0005433251591	14971	Business	18900.00
0005434906982	14971	Business	18900.00
0005434906941	14971	Business	18900.00
0005434906987	14971	Economy	6300.00
0005434906682	14971	Economy	6300.00
0005433251603	14971	Economy	6300.00
0005433251597	14971	Economy	6300.00
0005434906885	14971	Economy	6300.00
0005434907055	14971	Economy	6300.00
0005434906959	14971	Economy	6300.00
0005434906984	14971	Economy	6300.00
0005434907038	14971	Economy	6300.00
0005434907010	14971	Economy	6900.00
0005433251623	14971	Economy	6900.00
0005434906903	14971	Economy	6900.00
0005434907000	14971	Economy	6900.00
0005433251612	14971	Economy	6900.00
0005434907019	14971	Economy	6300.00
0005434906983	14971	Economy	6300.00
0005433251613	14971	Economy	6300.00
0005434907054	14971	Economy	6300.00
0005433251621	14971	Economy	6300.00
0005434906986	14971	Economy	6300.00
0005434907011	14971	Economy	6300.00
0005433251618	14971	Economy	6300.00
0005434906912	14971	Economy	6300.00
0005433251593	14971	Economy	6300.00
0005433251598	14971	Economy	6300.00
0005434906875	14971	Economy	6300.00
0005434907045	14971	Economy	6300.00
0005433251611	14971	Economy	6300.00
0005433251605	14971	Economy	6300.00
0005434907056	14971	Economy	6300.00
0005434906948	14971	Economy	6300.00
0005434907069	14971	Economy	6300.00
0005434906878	14971	Economy	6300.00
0005434906926	14971	Economy	6300.00
0005434907004	14971	Economy	6300.00
0005434906900	14971	Economy	6300.00
0005433251601	14971	Economy	6300.00
0005433251619	14971	Economy	6300.00
0005433251615	14971	Economy	6300.00
0005434907079	14971	Economy	6300.00
0005434907081	14971	Economy	6300.00
0005434906904	14971	Economy	6300.00
0005434906850	14971	Economy	6300.00
0005433251609	14971	Economy	6300.00
0005433251592	14971	Economy	6300.00
0005434907072	14971	Economy	6300.00
0005434907046	14971	Economy	6300.00
0005434907003	14971	Economy	6300.00
0005434907074	14971	Economy	6300.00
0005433251607	14971	Economy	6300.00
0005433251616	14971	Economy	6300.00
0005433251608	14971	Economy	6300.00
0005433251617	14971	Economy	6300.00
0005434906923	14971	Economy	6300.00
0005433251600	14971	Economy	6300.00
0005434906899	14971	Economy	6300.00
0005433251614	14971	Economy	6300.00
0005434907040	14971	Economy	6300.00
0005434906877	14971	Economy	6300.00
0005433251620	14971	Economy	6300.00
0005434906978	14971	Economy	6300.00
0005433251599	14971	Economy	6300.00
0005434906681	14971	Economy	6300.00
0005434907021	14971	Economy	6300.00
0005433251610	14971	Economy	6300.00
0005434906990	14971	Economy	6300.00
0005434907023	14971	Economy	6300.00
0005433251596	14971	Economy	6300.00
0005433251595	14971	Economy	6300.00
0005434907037	14971	Economy	6300.00
0005434907005	14971	Economy	6300.00
0005434907044	14971	Economy	6300.00
0005433251594	14971	Economy	6300.00
0005434907022	14971	Economy	6300.00
0005433251602	14971	Economy	6300.00
0005434907026	14971	Economy	6300.00
0005433251622	14971	Economy	6300.00
0005433251440	25877	Business	18900.00
0005434907441	25877	Business	18900.00
0005434907465	25877	Business	18900.00
0005434907457	25877	Business	18900.00
0005434907475	25877	Business	18900.00
0005433251354	25877	Business	18900.00
0005434907483	25877	Business	18900.00
0005433251298	25877	Business	18900.00
0005434907454	25877	Business	18900.00
0005434907443	25877	Business	18900.00
0005434907479	25877	Business	18900.00
0005433251384	25877	Economy	6300.00
0005434907462	25877	Economy	6300.00
0005434907458	25877	Economy	6300.00
0005433251422	25877	Economy	6300.00
0005434907461	25877	Economy	6300.00
0005433251294	25877	Economy	6300.00
0005434907471	25877	Economy	6300.00
0005433251287	25877	Economy	6300.00
0005434907440	25877	Economy	6900.00
0005434907439	25877	Economy	6900.00
0005434907456	25877	Economy	6900.00
0005433251302	25877	Economy	6900.00
0005433251295	25877	Economy	6900.00
0005434907481	25877	Economy	6300.00
0005433251206	25877	Economy	6300.00
0005434907446	25877	Economy	6300.00
0005434907473	25877	Economy	6300.00
0005433251342	25877	Economy	6300.00
0005433251373	25877	Economy	6300.00
0005434907472	25877	Economy	6300.00
0005434907467	25877	Economy	6300.00
0005433251363	25877	Economy	6300.00
0005434907453	25877	Economy	6300.00
0005433251374	25877	Economy	6300.00
0005434907464	25877	Economy	6300.00
0005434907442	25877	Economy	6300.00
0005433251375	25877	Economy	6300.00
0005434907482	25877	Economy	6300.00
0005434907444	25877	Economy	6300.00
0005434907459	25877	Economy	6300.00
0005434907477	25877	Economy	6300.00
0005433251394	25877	Economy	6300.00
0005433251369	25877	Economy	6300.00
0005434907437	25877	Economy	6300.00
0005433251333	25877	Economy	6300.00
0005433251284	25877	Economy	6300.00
0005434907480	25877	Economy	6300.00
0005433251385	25877	Economy	6300.00
0005434907484	25877	Economy	6300.00
0005433251350	25877	Economy	6300.00
0005433251309	25877	Economy	6300.00
0005434907469	25877	Economy	6300.00
0005434907438	25877	Economy	6300.00
0005433251317	25877	Economy	6300.00
0005434907485	25877	Economy	6300.00
0005433251370	25877	Economy	6300.00
0005433251301	25877	Economy	6300.00
0005433251393	25877	Economy	6300.00
0005434907455	25877	Economy	6300.00
0005433251368	25877	Economy	6300.00
0005434907466	25877	Economy	6300.00
0005434907445	25877	Economy	6300.00
0005433251308	25877	Economy	6300.00
0005434907476	25877	Economy	6300.00
0005434907468	25877	Economy	6300.00
0005434907436	25877	Economy	6300.00
0005434907449	25877	Economy	6300.00
0005433251205	25877	Economy	6300.00
0005434907474	25877	Economy	6300.00
0005434907470	25877	Economy	6300.00
0005433251362	25877	Economy	6300.00
0005434907460	25877	Economy	6300.00
0005433251300	25877	Economy	6300.00
0005434907450	25877	Economy	6300.00
0005434907451	25877	Economy	6300.00
0005433251318	25877	Economy	6300.00
0005434907463	25877	Economy	6300.00
0005433251372	25877	Economy	6300.00
0005434907478	25877	Economy	6300.00
0005434907448	25877	Economy	6300.00
0005434907452	25877	Economy	6300.00
0005433251290	25877	Economy	6300.00
0005433251423	25877	Economy	6300.00
0005433251274	25877	Economy	6300.00
0005434907447	25877	Economy	6300.00
0005432607571	22476	Economy	16400.00
0005432609744	22476	Economy	16400.00
0005432607577	22476	Economy	16400.00
0005432609740	22476	Economy	16400.00
0005432607568	22476	Economy	14900.00
0005432609732	22476	Economy	14900.00
0005432609737	22476	Economy	14900.00
0005432607569	22476	Economy	14900.00
0005432607567	22476	Economy	14900.00
0005435842320	22476	Economy	14900.00
0005432609741	22476	Economy	14900.00
0005435842322	22476	Economy	14900.00
0005432607572	22476	Economy	14900.00
0005432609731	22476	Economy	14900.00
0005432607574	22476	Economy	14900.00
0005435841465	22476	Economy	14900.00
0005435842321	22476	Economy	14900.00
0005432609743	22476	Economy	14900.00
0005432609735	22476	Economy	14900.00
0005432609736	22476	Economy	14900.00
0005432607575	22476	Economy	14900.00
0005432609746	22476	Economy	14900.00
0005435841466	22476	Economy	14900.00
0005435841469	22476	Economy	14900.00
0005432607576	22476	Economy	14900.00
0005432609730	22476	Economy	14900.00
0005432607570	22476	Economy	14900.00
0005432607581	22476	Economy	14900.00
0005435841475	22476	Economy	14900.00
0005435841468	22476	Economy	14900.00
0005432609745	22476	Economy	14900.00
0005432607573	22476	Economy	14900.00
0005432609739	22476	Economy	14900.00
0005432607578	22476	Economy	14900.00
0005432609738	22476	Economy	14900.00
0005432607580	22476	Economy	14900.00
0005432607579	22476	Economy	14900.00
0005432607582	22476	Economy	14900.00
0005432607566	22476	Economy	14900.00
0005435842323	22476	Economy	14900.00
0005435841471	22476	Economy	14900.00
0005432609733	22476	Economy	14900.00
0005432609742	22476	Economy	14900.00
0005435841467	22476	Economy	14900.00
0005432609734	22476	Economy	14900.00
0005432613838	31733	Economy	16400.00
0005432613827	31733	Economy	16400.00
0005432613834	31733	Economy	14900.00
0005432609699	31733	Economy	14900.00
0005432613826	31733	Economy	14900.00
0005432609703	31733	Economy	14900.00
0005432613818	31733	Economy	14900.00
0005432609701	31733	Economy	14900.00
0005432609714	31733	Economy	14900.00
0005432613819	31733	Economy	14900.00
0005432613855	31733	Economy	14900.00
0005432613844	31733	Economy	14900.00
0005432613820	31733	Economy	14900.00
0005432613825	31733	Economy	14900.00
0005432609694	31733	Economy	14900.00
0005432609704	31733	Economy	14900.00
0005432613821	31733	Economy	14900.00
0005432613828	31733	Economy	14900.00
0005432613833	31733	Economy	14900.00
0005432613816	31733	Economy	14900.00
0005432613837	31733	Economy	14900.00
0005432613839	31733	Economy	14900.00
0005432609678	31733	Economy	14900.00
0005432613817	31733	Economy	14900.00
0005432613822	31733	Economy	14900.00
0005432609683	31733	Economy	14900.00
0005432613840	31733	Economy	14900.00
0005432609706	31733	Economy	14900.00
0005432609700	31733	Economy	14900.00
0005432609679	31733	Economy	14900.00
0005432609680	31733	Economy	14900.00
0005432609707	31733	Economy	14900.00
0005432609682	31733	Economy	14900.00
0005432609709	31733	Economy	14900.00
0005432613853	31733	Economy	14900.00
0005432609686	31733	Economy	14900.00
0005433008807	14204	Business	52300.00
0005433008823	14204	Business	52300.00
0005433008800	14204	Business	52300.00
0005433008802	14204	Business	52300.00
0005433008815	14204	Business	52300.00
0005433008817	14204	Business	52300.00
0005433810514	14204	Business	52300.00
0005433008805	14204	Economy	17400.00
0005433008826	14204	Economy	17400.00
0005433008814	14204	Economy	17400.00
0005433008834	14204	Economy	17400.00
0005433008840	14204	Economy	19200.00
0005433008820	14204	Economy	19200.00
0005433008830	14204	Economy	19200.00
0005433008833	14204	Economy	17400.00
0005433810512	14204	Economy	17400.00
0005433008816	14204	Economy	17400.00
0005433008829	14204	Economy	17400.00
0005433008835	14204	Economy	17400.00
0005433008831	14204	Economy	17400.00
0005433008838	14204	Economy	17400.00
0005433008842	14204	Economy	17400.00
0005433008843	14204	Economy	17400.00
0005433008841	14204	Economy	17400.00
0005433008825	14204	Economy	17400.00
0005433008803	14204	Economy	17400.00
0005433008801	14204	Economy	17400.00
0005433008808	14204	Economy	17400.00
0005433008811	14204	Economy	17400.00
0005433008837	14204	Economy	17400.00
0005433008839	14204	Economy	17400.00
0005433008827	14204	Economy	17400.00
0005433008822	14204	Economy	17400.00
0005433008809	14204	Economy	17400.00
0005433008812	14204	Economy	17400.00
0005433008806	14204	Economy	17400.00
0005433008832	14204	Economy	17400.00
0005433008821	14204	Economy	17400.00
0005433008799	14204	Economy	17400.00
0005433008828	14204	Economy	17400.00
0005433008824	14204	Economy	17400.00
0005433008810	14204	Economy	17400.00
0005433008836	14204	Economy	17400.00
0005433008813	14204	Economy	17400.00
0005433008798	14204	Economy	17400.00
0005433008819	14204	Economy	17400.00
0005433008818	14204	Economy	17400.00
0005433008797	14204	Economy	17400.00
0005433810513	14204	Economy	17400.00
0005433008804	14204	Economy	17400.00
0005433008519	22827	Business	52300.00
0005433008286	22827	Business	52300.00
0005433008505	22827	Business	52300.00
0005433008513	22827	Business	52300.00
0005433008494	22827	Business	52300.00
0005433008355	22827	Economy	17400.00
0005433008309	22827	Economy	17400.00
0005433008435	22827	Economy	17400.00
0005433008257	22827	Economy	17400.00
0005433008341	22827	Economy	17400.00
0005433008491	22827	Economy	17400.00
0005433008178	22827	Economy	17400.00
0005433008439	22827	Economy	19200.00
0005433008340	22827	Economy	19200.00
0005433008512	22827	Economy	19200.00
0005433008308	22827	Economy	17400.00
0005433008480	22827	Economy	17400.00
0005433008440	22827	Economy	17400.00
0005433008314	22827	Economy	17400.00
0005433008503	22827	Economy	17400.00
0005433008437	22827	Economy	17400.00
0005433008333	22827	Economy	17400.00
0005433008490	22827	Economy	17400.00
0005433008148	22827	Economy	17400.00
0005433008371	22827	Economy	17400.00
0005433008194	22827	Economy	17400.00
0005433008370	22827	Economy	17400.00
0005433008506	22827	Economy	17400.00
0005433008367	22827	Economy	17400.00
0005433008492	22827	Economy	17400.00
0005433008469	22827	Economy	17400.00
0005433008438	22827	Economy	17400.00
0005433008436	22827	Economy	17400.00
0005433008287	22827	Economy	17400.00
0005433008149	22827	Economy	17400.00
0005433008302	22827	Economy	17400.00
0005433008366	22827	Economy	17400.00
0005433810566	22827	Economy	17400.00
0005433008263	22827	Economy	17400.00
0005433008457	22827	Economy	17400.00
0005433008500	22827	Economy	17400.00
0005433008504	22827	Economy	17400.00
0005433008342	22827	Economy	17400.00
0005433008464	22827	Economy	17400.00
0005433008507	22827	Economy	17400.00
0005433008460	22827	Economy	17400.00
0005433008324	22827	Economy	17400.00
0005433008216	22827	Economy	17400.00
0005433008429	22827	Economy	17400.00
0005434925590	14953	Business	22900.00
0005434925684	14953	Business	22900.00
0005434925623	14953	Business	22900.00
0005434925746	14953	Business	22900.00
0005434925664	14953	Business	22900.00
0005434925602	14953	Business	22900.00
0005434925725	14953	Economy	7600.00
0005434925589	14953	Economy	7600.00
0005434925638	14953	Economy	7600.00
0005434925654	14953	Economy	7600.00
0005434925742	14953	Economy	8400.00
0005434925788	14953	Economy	8400.00
0005434925743	14953	Economy	7600.00
0005434925552	14953	Economy	7600.00
0005434925601	14953	Economy	7600.00
0005434925726	14953	Economy	7600.00
0005434925474	14953	Economy	7600.00
0005434925712	14953	Economy	7600.00
0005434925660	14953	Economy	7600.00
0005434925626	14953	Economy	7600.00
0005434925734	14953	Economy	7600.00
0005434925683	14953	Economy	7600.00
0005434925588	14953	Economy	7600.00
0005434925642	14953	Economy	7600.00
0005434925604	14953	Economy	7600.00
0005434925656	14953	Economy	7600.00
0005434925650	14953	Economy	7600.00
0005434925787	14953	Economy	7600.00
0005434925475	14953	Economy	7600.00
0005434925738	14953	Economy	7600.00
0005434925651	14953	Economy	7600.00
0005434925639	14953	Economy	7600.00
0005434925666	14953	Economy	7600.00
0005434925499	14953	Economy	7600.00
0005434925612	14953	Economy	7600.00
0005434925643	14953	Economy	7600.00
0005434925627	14953	Economy	7600.00
0005434925591	14953	Economy	7600.00
0005434925889	20500	Business	22900.00
0005434925922	20500	Business	22900.00
0005434925917	20500	Business	22900.00
0005434925896	20500	Business	22900.00
0005434925885	20500	Economy	7600.00
0005434925888	20500	Economy	7600.00
0005434925898	20500	Economy	7600.00
0005434925884	20500	Economy	7600.00
0005434925907	20500	Economy	7600.00
0005434925914	20500	Economy	8400.00
0005434925904	20500	Economy	8400.00
0005434925908	20500	Economy	7600.00
0005434925890	20500	Economy	7600.00
0005434925899	20500	Economy	7600.00
0005434925892	20500	Economy	7600.00
0005434925902	20500	Economy	7600.00
0005434925895	20500	Economy	7600.00
0005434925903	20500	Economy	7600.00
0005434925921	20500	Economy	7600.00
0005434925918	20500	Economy	7600.00
0005434925893	20500	Economy	7600.00
0005434925919	20500	Economy	7600.00
0005434925883	20500	Economy	7600.00
0005434925887	20500	Economy	7600.00
0005434925911	20500	Economy	7600.00
0005434925891	20500	Economy	7600.00
0005434925886	20500	Economy	7600.00
0005434925909	20500	Economy	7600.00
0005434925900	20500	Economy	7600.00
0005434925912	20500	Economy	7600.00
0005434925915	20500	Economy	7600.00
0005434925897	20500	Economy	7600.00
0005434925906	20500	Economy	7600.00
0005434925910	20500	Economy	7600.00
0005434925913	20500	Economy	7600.00
0005434925916	20500	Economy	7600.00
0005434925894	20500	Economy	7600.00
0005434925905	20500	Economy	7600.00
0005434925920	20500	Economy	7600.00
0005434925901	20500	Economy	7600.00
0005435999172	15845	Economy	8900.00
0005435487940	15845	Economy	8900.00
0005435487928	15845	Economy	8900.00
0005435999236	15845	Economy	8100.00
0005435999155	15845	Economy	8100.00
0005435999145	15845	Economy	8100.00
0005435487931	15845	Economy	8100.00
0005435487932	15845	Economy	8100.00
0005435999230	15845	Economy	8100.00
0005435999099	15845	Economy	8100.00
0005435999171	15845	Economy	8100.00
0005435999223	15845	Economy	8100.00
0005435487923	15845	Economy	8100.00
0005435999100	15845	Economy	8100.00
0005435487937	15845	Economy	8100.00
0005435487924	15845	Economy	8100.00
0005435487930	15845	Economy	8100.00
0005435999115	15845	Economy	8100.00
0005435999154	15845	Economy	8100.00
0005435999142	15845	Economy	8100.00
0005435999196	15845	Economy	8100.00
0005435999129	15845	Economy	8100.00
0005435487922	15845	Economy	8100.00
0005435999170	15845	Economy	8100.00
0005435999177	15845	Economy	8100.00
0005435487919	15845	Economy	8100.00
0005435487925	15845	Economy	8100.00
0005435999098	15845	Economy	8100.00
0005435487938	15845	Economy	8100.00
0005435999194	15845	Economy	8100.00
0005435487926	15845	Economy	8100.00
0005435487934	15845	Economy	8100.00
0005435999114	15845	Economy	8100.00
0005435999195	15845	Economy	8100.00
0005435999146	15845	Economy	8100.00
0005435999156	15845	Economy	8100.00
0005435487929	15845	Economy	8100.00
0005435487936	15845	Economy	8100.00
0005435487921	15845	Economy	8100.00
0005435487920	15845	Economy	8100.00
0005435487939	15845	Economy	8100.00
0005435487927	15845	Economy	8100.00
0005435487935	15845	Economy	8100.00
0005435487933	15845	Economy	8100.00
0005435487733	19694	Economy	8900.00
0005435487758	19694	Economy	8900.00
0005435487698	19694	Economy	8900.00
0005435999318	19694	Economy	8900.00
0005435999310	19694	Economy	8100.00
0005435999306	19694	Economy	8100.00
0005435999313	19694	Economy	8100.00
0005435487674	19694	Economy	8100.00
0005435999304	19694	Economy	8100.00
0005435999314	19694	Economy	8100.00
0005435999320	19694	Economy	8100.00
0005435999322	19694	Economy	8100.00
0005435487666	19694	Economy	8100.00
0005435487704	19694	Economy	8100.00
0005435999309	19694	Economy	8100.00
0005435487697	19694	Economy	8100.00
0005435999321	19694	Economy	8100.00
0005435487655	19694	Economy	8100.00
0005435487717	19694	Economy	8100.00
0005435999316	19694	Economy	8100.00
0005435999302	19694	Economy	8100.00
0005435487761	19694	Economy	8100.00
0005435487739	19694	Economy	8100.00
0005435999317	19694	Economy	8100.00
0005435999307	19694	Economy	8100.00
0005435487757	19694	Economy	8100.00
0005435487738	19694	Economy	8100.00
0005435999311	19694	Economy	8100.00
0005435487762	19694	Economy	8100.00
0005435999301	19694	Economy	8100.00
0005435487740	19694	Economy	8100.00
0005435487732	19694	Economy	8100.00
0005435999305	19694	Economy	8100.00
0005435999315	19694	Economy	8100.00
0005435487648	19694	Economy	8100.00
0005435999308	19694	Economy	8100.00
0005435487675	19694	Economy	8100.00
0005435487693	19694	Economy	8100.00
0005435487640	19694	Economy	8100.00
0005435999300	19694	Economy	8100.00
0005435487635	19694	Economy	8100.00
0005435487659	19694	Economy	8100.00
0005435487703	19694	Economy	8100.00
0005435999303	19694	Economy	8100.00
0005435999312	19694	Economy	8100.00
0005435999319	19694	Economy	8100.00
0005435487720	19694	Economy	8100.00
0005432660827	5975	Business	199300.00
0005435839579	5975	Business	199300.00
0005435839584	5975	Business	199300.00
0005435472697	5975	Business	199300.00
0005435839585	5975	Economy	66400.00
0005435472690	5975	Economy	66400.00
0005435472708	5975	Economy	66400.00
0005435472765	5975	Economy	66400.00
0005435472706	5975	Economy	66400.00
0005435472673	5975	Economy	66400.00
0005435839562	5975	Economy	66400.00
0005435839578	5975	Economy	73100.00
0005432659717	5975	Economy	73100.00
0005435839589	5975	Economy	66400.00
0005432659718	5975	Economy	66400.00
0005435839564	5975	Economy	66400.00
0005435839587	5975	Economy	66400.00
0005435839590	5975	Economy	66400.00
0005432537039	5975	Economy	66400.00
0005435472741	5975	Economy	66400.00
0005435839580	5975	Economy	66400.00
0005435839581	5975	Economy	66400.00
0005432658601	5975	Economy	66400.00
0005432659716	5975	Economy	66400.00
0005432142265	5975	Economy	66400.00
0005435472790	5975	Economy	66400.00
0005435839572	5975	Economy	66400.00
0005435839576	5975	Economy	66400.00
0005435839571	5975	Economy	66400.00
0005435839570	5975	Economy	66400.00
0005435839569	5975	Economy	66400.00
0005435839565	5975	Economy	66400.00
0005435839575	5975	Economy	66400.00
0005435839574	5975	Economy	66400.00
0005435839588	5975	Economy	66400.00
0005435839582	5975	Economy	66400.00
0005432142267	5975	Economy	66400.00
0005435472698	5975	Economy	66400.00
0005435839567	5975	Economy	66400.00
0005435839573	5975	Economy	66400.00
0005435839566	5975	Economy	66400.00
0005432142264	5975	Economy	66400.00
0005435472691	5975	Economy	66400.00
0005432658600	5975	Economy	66400.00
0005435839563	5975	Economy	66400.00
0005435472633	5975	Economy	66400.00
0005435839577	5975	Economy	66400.00
0005435472699	5975	Economy	66400.00
0005435472714	5975	Economy	66400.00
0005435839583	5975	Economy	66400.00
0005432660828	5975	Economy	66400.00
0005435839568	5975	Economy	66400.00
0005435839586	5975	Economy	66400.00
0005432142266	5975	Economy	66400.00
0005435839235	18089	Business	199300.00
0005435472871	18089	Business	199300.00
0005432537068	18089	Business	199300.00
0005435839418	18089	Business	199300.00
0005435839460	18089	Business	199300.00
0005435472882	18089	Business	199300.00
0005432664120	18089	Business	199300.00
0005435839315	18089	Business	199300.00
0005432660804	18089	Business	199300.00
0005432660805	18089	Business	199300.00
0005435839362	18089	Business	199300.00
0005435839312	18089	Business	199300.00
0005435472868	18089	Business	199300.00
0005435839387	18089	Business	199300.00
0005435472877	18089	Economy	66400.00
0005435839230	18089	Business	199300.00
0005435472879	18089	Economy	66400.00
0005435472870	18089	Economy	66400.00
0005435839439	18089	Economy	66400.00
0005435839259	18089	Economy	66400.00
0005435472872	18089	Economy	66400.00
0005435839311	18089	Economy	66400.00
0005435839361	18089	Economy	66400.00
0005435839274	18089	Economy	73100.00
0005435839378	18089	Economy	73100.00
0005435839231	18089	Economy	73100.00
0005435839188	18089	Economy	73100.00
0005435472880	18089	Economy	66400.00
0005435839343	18089	Economy	66400.00
0005435839469	18089	Economy	66400.00
0005435839304	18089	Economy	66400.00
0005435839275	18089	Economy	66400.00
0005435472876	18089	Economy	66400.00
0005435472869	18089	Economy	66400.00
0005435839270	18089	Economy	66400.00
0005435839317	18089	Economy	66400.00
0005435839257	18089	Economy	66400.00
0005435839339	18089	Economy	66400.00
0005435472875	18089	Economy	66400.00
0005435839374	18089	Economy	66400.00
0005435839318	18089	Economy	66400.00
0005435839371	18089	Economy	66400.00
0005435472881	18089	Economy	66400.00
0005435839289	18089	Economy	66400.00
0005435839381	18089	Economy	66400.00
0005435839232	18089	Economy	66400.00
0005435839279	18089	Economy	66400.00
0005435839363	18089	Economy	66400.00
0005435839515	18089	Economy	66400.00
0005432667441	18089	Economy	66400.00
0005435839341	18089	Economy	66400.00
0005435839333	18089	Economy	66400.00
0005435839271	18089	Economy	66400.00
0005432537069	18089	Economy	66400.00
0005435839240	18089	Economy	66400.00
0005435839375	18089	Economy	66400.00
0005435839278	18089	Economy	66400.00
0005435839367	18089	Economy	66400.00
0005435472874	18089	Economy	66400.00
0005435472878	18089	Economy	66400.00
0005435839379	18089	Economy	66400.00
0005435839272	18089	Economy	66400.00
0005435839380	18089	Economy	66400.00
0005435839468	18089	Economy	66400.00
0005435839370	18089	Economy	66400.00
0005435472873	18089	Economy	66400.00
0005435839303	18089	Economy	66400.00
0005435839386	18089	Economy	66400.00
0005435472867	18089	Economy	66400.00
0005435839385	18089	Economy	66400.00
0005435839342	18089	Economy	66400.00
0005432537070	18089	Economy	66400.00
0005435839258	18089	Economy	66400.00
0005433463910	17265	Business	146400.00
0005433462748	17265	Business	146400.00
0005433463909	17265	Business	146400.00
0005433462756	17265	Business	146400.00
0005433463903	17265	Economy	48800.00
0005433463899	17265	Economy	48800.00
0005433463901	17265	Economy	48800.00
0005433463904	17265	Economy	48800.00
0005433463898	17265	Economy	48800.00
0005433462754	17265	Economy	48800.00
0005433462749	17265	Economy	48800.00
0005433463900	17265	Economy	48800.00
0005433463907	17265	Economy	48800.00
0005433462747	17265	Economy	48800.00
0005433462746	17265	Economy	48800.00
0005433462755	17265	Economy	48800.00
0005433463906	17265	Economy	48800.00
0005433462743	17265	Economy	48800.00
0005433463908	17265	Economy	48800.00
0005433463895	17265	Economy	48800.00
0005433462744	17265	Economy	48800.00
0005433462750	17265	Economy	48800.00
0005433463896	17265	Economy	48800.00
0005433462753	17265	Economy	48800.00
0005433462742	17265	Economy	48800.00
0005433463902	17265	Economy	48800.00
0005433463897	17265	Economy	48800.00
0005433462745	17265	Economy	48800.00
0005433463905	17265	Economy	48800.00
0005433462752	17265	Economy	48800.00
0005433462751	17265	Economy	48800.00
0005433285262	23053	Economy	5200.00
0005435103954	23053	Economy	5200.00
0005433285158	23053	Economy	5200.00
0005435103957	23053	Economy	5200.00
0005433285113	23053	Economy	5200.00
0005433285199	23053	Economy	5200.00
0005433285258	23053	Economy	5200.00
0005433285130	23053	Economy	5200.00
0005433285074	23053	Economy	5200.00
0005433285080	23053	Economy	5200.00
0005433285152	23053	Economy	5200.00
0005435103958	23053	Economy	5700.00
0005433285263	23053	Economy	5200.00
0005433285169	23053	Economy	5200.00
0005433285221	23053	Economy	5200.00
0005435103959	23053	Economy	5200.00
0005435103960	23053	Economy	5200.00
0005433285188	23053	Economy	5200.00
0005433285219	23053	Economy	5200.00
0005433285187	23053	Economy	5200.00
0005435103956	23053	Economy	5200.00
0005433285196	23053	Economy	5200.00
0005433285179	23053	Economy	5200.00
0005433285261	23053	Economy	5200.00
0005433285233	23053	Economy	5200.00
0005433285195	23053	Economy	5200.00
0005433285280	23053	Economy	5200.00
0005433285075	23053	Economy	5200.00
0005435103961	23053	Economy	5200.00
0005433285151	23053	Economy	5200.00
0005435103955	23053	Economy	5200.00
0005433285323	23053	Economy	5200.00
0005433285115	23053	Economy	5200.00
0005433285441	32071	Business	15700.00
0005433285448	32071	Business	15700.00
0005433285442	32071	Economy	5200.00
0005433285429	32071	Economy	5200.00
0005433285454	32071	Economy	5200.00
0005433285450	32071	Economy	5200.00
0005433285435	32071	Economy	5200.00
0005433285449	32071	Economy	5200.00
0005433285452	32071	Economy	5200.00
0005433285428	32071	Economy	5700.00
0005433285439	32071	Economy	5200.00
0005435103862	32071	Economy	5200.00
0005433285453	32071	Economy	5200.00
0005433285431	32071	Economy	5200.00
0005435103854	32071	Economy	5200.00
0005433285432	32071	Economy	5200.00
0005435103835	32071	Economy	5200.00
0005433285426	32071	Economy	5200.00
0005433285430	32071	Economy	5200.00
0005435103855	32071	Economy	5200.00
0005433285451	32071	Economy	5200.00
0005433285425	32071	Economy	5200.00
0005433285445	32071	Economy	5200.00
0005433285433	32071	Economy	5200.00
0005433285427	32071	Economy	5200.00
0005433285440	32071	Economy	5200.00
0005433285444	32071	Economy	5200.00
0005433285446	32071	Economy	5200.00
0005433285455	32071	Economy	5200.00
0005433285424	32071	Economy	5200.00
0005433285436	32071	Economy	5200.00
0005433285438	32071	Economy	5200.00
0005433285437	32071	Economy	5200.00
0005433285434	32071	Economy	5200.00
0005433285443	32071	Economy	5200.00
0005433285447	32071	Economy	5200.00
0005435103859	32071	Economy	5200.00
0005432527685	30618	Business	42100.00
0005435630983	30618	Business	42100.00
0005434067480	30618	Business	42100.00
0005432527400	30618	Business	42100.00
0005435213915	30618	Business	42100.00
0005432159881	30618	Business	42100.00
0005432527564	30618	Business	42100.00
0005434067374	30618	Business	42100.00
0005435725625	30618	Business	42100.00
0005434067474	30618	Business	42100.00
0005434067205	30618	Business	42100.00
0005435213900	30618	Business	42100.00
0005435213882	30618	Business	42100.00
0005435213918	30618	Business	42100.00
0005432527386	30618	Business	42100.00
0005432527512	30618	Business	42100.00
0005434067080	30618	Business	42100.00
0005432528050	30618	Business	42100.00
0005432527487	30618	Business	42100.00
0005434067587	30618	Business	42100.00
0005435213886	30618	Comfort	23900.00
0005434067273	30618	Comfort	23900.00
0005434067079	30618	Comfort	23900.00
0005432527712	30618	Comfort	23900.00
0005432527754	30618	Comfort	23900.00
0005432527110	30618	Comfort	23900.00
0005435213856	30618	Comfort	23900.00
0005434067175	30618	Comfort	23900.00
0005432527699	30618	Comfort	23900.00
0005435213919	30618	Comfort	23900.00
0005432527710	30618	Comfort	23900.00
0005432527547	30618	Comfort	23900.00
0005432527572	30618	Comfort	23900.00
0005434067226	30618	Comfort	23900.00
0005432526986	30618	Comfort	23900.00
0005432527331	30618	Comfort	23900.00
0005434067335	30618	Comfort	23900.00
0005432535812	30618	Comfort	23900.00
0005432527563	30618	Comfort	23900.00
0005434067267	30618	Comfort	23900.00
0005435213887	30618	Comfort	23900.00
0005434067167	30618	Comfort	23900.00
0005435213906	30618	Comfort	23900.00
0005432527228	30618	Comfort	23900.00
0005434067543	30618	Comfort	23900.00
0005432537063	30618	Comfort	23900.00
0005434067411	30618	Comfort	23900.00
0005435213920	30618	Comfort	23900.00
0005432527630	30618	Comfort	23900.00
0005435213873	30618	Comfort	23900.00
0005432527172	30618	Comfort	23900.00
0005434067123	30618	Comfort	23900.00
0005432528022	30618	Comfort	23900.00
0005432528007	30618	Comfort	23900.00
0005432527150	30618	Comfort	23900.00
0005434067625	30618	Comfort	23900.00
0005432537051	30618	Comfort	23900.00
0005434067060	30618	Comfort	23900.00
0005434067599	30618	Comfort	23900.00
0005432527189	30618	Comfort	23900.00
0005432527405	30618	Comfort	23900.00
0005432527556	30618	Comfort	23900.00
0005432527391	30618	Comfort	23900.00
0005435213869	30618	Economy	14000.00
0005434067224	30618	Economy	14000.00
0005435213854	30618	Economy	14000.00
0005435213908	30618	Economy	14000.00
0005435213876	30618	Economy	14000.00
0005432535796	30618	Economy	14000.00
0005432159879	30618	Economy	14000.00
0005434067536	30618	Economy	14000.00
0005432527651	30618	Economy	14000.00
0005432537049	30618	Economy	14000.00
0005432211535	30618	Economy	14000.00
0005432527254	30618	Economy	14000.00
0005432527149	30618	Economy	14000.00
0005432527779	30618	Economy	14000.00
0005432535797	30618	Economy	14000.00
0005434067168	30618	Economy	14000.00
0005434067261	30618	Economy	14000.00
0005432211536	30618	Economy	14000.00
0005432527675	30618	Economy	14000.00
0005434067418	30618	Economy	14000.00
0005432527587	30618	Economy	14000.00
0005434067373	30618	Economy	14000.00
0005435213863	30618	Economy	14000.00
0005434067217	30618	Economy	14000.00
0005435213917	30618	Economy	14000.00
0005432527459	30618	Economy	14000.00
0005434067260	30618	Economy	14000.00
0005432527595	30618	Economy	14000.00
0005432527691	30618	Economy	14000.00
0005432527695	30618	Economy	14000.00
0005432527280	30618	Economy	14000.00
0005432527826	30618	Economy	14000.00
0005435213896	30618	Economy	14000.00
0005435213859	30618	Economy	14000.00
0005435213870	30618	Economy	14000.00
0005435213861	30618	Economy	14000.00
0005432527510	30618	Economy	14000.00
0005432527692	30618	Economy	14000.00
0005432537048	30618	Economy	14000.00
0005435213888	30618	Economy	14000.00
0005434067545	30618	Economy	14000.00
0005432527163	30618	Economy	14000.00
0005432527594	30618	Economy	14000.00
0005435725628	30618	Economy	14000.00
0005435213922	30618	Economy	14000.00
0005432527111	30618	Economy	14000.00
0005435213884	30618	Economy	14000.00
0005434067215	30618	Economy	14000.00
0005435213911	30618	Economy	14000.00
0005432526852	30618	Economy	14000.00
0005432527401	30618	Economy	14000.00
0005435213891	30618	Economy	14000.00
0005435213889	30618	Economy	14000.00
0005435213860	30618	Economy	15400.00
0005434067568	30618	Economy	14000.00
0005432537050	30618	Economy	15400.00
0005435213874	30618	Economy	15400.00
0005435213878	30618	Economy	14000.00
0005432527511	30618	Economy	14000.00
0005432527207	30618	Economy	15400.00
0005434067031	30618	Economy	15400.00
0005434067326	30618	Economy	15400.00
0005434067127	30618	Economy	14000.00
0005435213877	30618	Economy	14000.00
0005432527586	30618	Economy	14000.00
0005432535802	30618	Economy	14000.00
0005434067220	30618	Economy	14000.00
0005432527473	30618	Economy	14000.00
0005432527778	30618	Economy	14000.00
0005432527025	30618	Economy	14000.00
0005434067304	30618	Economy	14000.00
0005432527800	30618	Economy	14000.00
0005434067499	30618	Economy	14000.00
0005432527566	30618	Economy	14000.00
0005435213923	30618	Economy	14000.00
0005432527520	30618	Economy	14000.00
0005434067544	30618	Economy	14000.00
0005432535828	30618	Economy	14000.00
0005432527299	30618	Economy	14000.00
0005432527390	30618	Economy	14000.00
0005432211541	30618	Economy	14000.00
0005432527206	30618	Economy	14000.00
0005435213905	30618	Economy	14000.00
0005435213899	30618	Economy	14000.00
0005434067452	30618	Economy	14000.00
0005432537064	30618	Economy	14000.00
0005435213885	30618	Economy	14000.00
0005435213901	30618	Economy	14000.00
0005434067110	30618	Economy	14000.00
0005432527231	30618	Economy	14000.00
0005435213907	30618	Economy	14000.00
0005434067506	30618	Economy	14000.00
0005432527443	30618	Economy	14000.00
0005432527596	30618	Economy	14000.00
0005434067566	30618	Economy	14000.00
0005432527436	30618	Economy	14000.00
0005435213865	30618	Economy	14000.00
0005434067227	30618	Economy	14000.00
0005432527871	30618	Economy	14000.00
0005432527410	30618	Economy	14000.00
0005433656688	30618	Economy	14000.00
0005432527774	30618	Economy	14000.00
0005434067178	30618	Economy	14000.00
0005432527716	30618	Economy	14000.00
0005432527339	30618	Economy	14000.00
0005434067216	30618	Economy	14000.00
0005435213904	30618	Economy	14000.00
0005432211539	30618	Economy	14000.00
0005434067225	30618	Economy	14000.00
0005433656687	30618	Economy	14000.00
0005434067188	30618	Economy	14000.00
0005432527202	30618	Economy	14000.00
0005432527347	30618	Economy	14000.00
0005432527713	30618	Economy	14000.00
0005432527507	30618	Economy	14000.00
0005432527946	30618	Economy	14000.00
0005435213864	30618	Economy	14000.00
0005435213903	30618	Economy	14000.00
0005432527458	30618	Economy	14000.00
0005432533273	30618	Economy	14000.00
0005432527063	30618	Economy	14000.00
0005432527642	30618	Economy	14000.00
0005435213857	30618	Economy	14000.00
0005434067412	30618	Economy	14000.00
0005432527073	30618	Economy	14000.00
0005435213916	30618	Economy	14000.00
0005432527464	30618	Economy	14000.00
0005434067284	30618	Economy	14000.00
0005434067219	30618	Economy	14000.00
0005435213879	30618	Economy	14000.00
0005432526851	30618	Economy	14000.00
0005434067116	30618	Economy	14000.00
0005435213892	30618	Economy	14000.00
0005434067008	30618	Economy	14000.00
0005435213875	30618	Economy	14000.00
0005432527463	30618	Economy	14000.00
0005435213872	30618	Economy	14000.00
0005432527736	30618	Economy	14000.00
0005435213862	30618	Economy	14000.00
0005432527881	30618	Economy	14000.00
0005432527188	30618	Economy	14000.00
0005434067371	30618	Economy	14000.00
0005434067485	30618	Economy	14000.00
0005435630984	30618	Economy	14000.00
0005432527253	30618	Economy	14000.00
0005432527415	30618	Economy	14000.00
0005432527694	30618	Economy	14000.00
0005435213909	30618	Economy	14000.00
0005432527554	30618	Economy	14000.00
0005432527437	30618	Economy	14000.00
0005435213898	30618	Economy	14000.00
0005432527773	30618	Economy	14000.00
0005432527731	30618	Economy	14000.00
0005435213912	30618	Economy	14000.00
0005432527631	30618	Economy	14000.00
0005434067314	30618	Economy	14000.00
0005432527815	30618	Economy	14000.00
0005434067221	30618	Economy	14000.00
0005432527340	30618	Economy	14000.00
0005434067316	30618	Economy	14000.00
0005434067303	30618	Economy	14000.00
0005434067039	30618	Economy	14000.00
0005432527387	30618	Economy	14000.00
0005434067325	30618	Economy	14000.00
0005434067588	30618	Economy	15400.00
0005432527431	30618	Economy	15400.00
0005435725627	30618	Economy	15400.00
0005432527486	30618	Economy	15400.00
0005434067242	30618	Economy	15400.00
0005435213910	30618	Economy	14000.00
0005432527182	30618	Economy	14000.00
0005432527661	30618	Economy	14000.00
0005435213894	30618	Economy	14000.00
0005433656689	30618	Economy	14000.00
0005434067315	30618	Economy	14000.00
0005435213868	30618	Economy	14000.00
0005432527555	30618	Economy	14000.00
0005434067331	30618	Economy	14000.00
0005435630982	30618	Economy	14000.00
0005435213913	30618	Economy	14000.00
0005432211540	30618	Economy	14000.00
0005435213897	30618	Economy	14000.00
0005435213855	30618	Economy	14000.00
0005435213866	30618	Economy	14000.00
0005435213881	30618	Economy	14000.00
0005434066962	30618	Economy	14000.00
0005432527118	30618	Economy	14000.00
0005434067149	30618	Economy	14000.00
0005434067332	30618	Economy	14000.00
0005434067211	30618	Economy	14000.00
0005435725626	30618	Economy	14000.00
0005434067537	30618	Economy	14000.00
0005432527485	30618	Economy	14000.00
0005432526956	30618	Economy	14000.00
0005432527124	30618	Economy	14000.00
0005432527771	30618	Economy	14000.00
0005435213858	30618	Economy	14000.00
0005432527230	30618	Economy	14000.00
0005432537046	30618	Economy	14000.00
0005432527795	30618	Economy	14000.00
0005435213893	30618	Economy	14000.00
0005432537052	30618	Economy	14000.00
0005435213902	30618	Economy	14000.00
0005434067268	30618	Economy	14000.00
0005432211542	30618	Economy	14000.00
0005432527298	30618	Economy	14000.00
0005432528029	30618	Economy	14000.00
0005432527344	30618	Economy	14000.00
0005432159882	30618	Economy	14000.00
0005434066961	30618	Economy	14000.00
0005432159880	30618	Economy	14000.00
0005432526746	30618	Economy	14000.00
0005434067305	30618	Economy	14000.00
0005432527076	30618	Economy	14000.00
0005435213890	30618	Economy	14000.00
0005432527709	30618	Economy	14000.00
0005432527792	30618	Economy	14000.00
0005432526957	30618	Economy	14000.00
0005434067417	30618	Economy	14000.00
0005434067285	30618	Economy	14000.00
0005434067327	30618	Economy	14000.00
0005434067173	30618	Economy	14000.00
0005432526896	30618	Economy	14000.00
0005434067187	30618	Economy	14000.00
0005434067243	30618	Economy	14000.00
0005432527240	30618	Economy	14000.00
0005434067363	30618	Economy	14000.00
0005434067286	30618	Economy	14000.00
0005432528049	30618	Economy	14000.00
0005435213914	30618	Economy	14000.00
0005432527793	30618	Economy	14000.00
0005435213921	30618	Economy	14000.00
0005434067244	30618	Economy	14000.00
0005432526850	30618	Economy	14000.00
0005432527442	30618	Economy	14000.00
0005432528103	30618	Economy	14000.00
0005432527131	30618	Economy	14000.00
0005435213895	30618	Economy	14000.00
0005435213867	30618	Economy	14000.00
0005435213880	30618	Economy	14000.00
0005432527643	30618	Economy	14000.00
0005432527546	30618	Economy	14000.00
0005434067313	30618	Economy	14000.00
0005432527652	30618	Economy	14000.00
0005432211538	30618	Economy	14000.00
0005432528006	30618	Economy	14000.00
0005432211537	30618	Economy	14000.00
0005434067117	30618	Economy	14000.00
0005432527794	30618	Economy	14000.00
0005435213871	30618	Economy	14000.00
0005432527521	30618	Economy	14000.00
0005435213883	30618	Economy	14000.00
0005434067341	30618	Economy	14000.00
0005434067222	30618	Economy	14000.00
0005433656690	30618	Economy	14000.00
0005432537047	30618	Economy	14000.00
0005435652860	24855	Business	9800.00
0005435652911	24855	Business	9800.00
0005433368092	24855	Business	9800.00
0005435652855	24855	Business	9800.00
0005435652794	24855	Business	9800.00
0005433368072	24855	Business	9800.00
0005433368067	24855	Business	9800.00
0005435652793	24855	Business	9800.00
0005435652750	24855	Business	9800.00
0005433368071	24855	Business	9800.00
0005435652730	24855	Economy	3300.00
0005435652679	24855	Economy	3300.00
0005435652914	24855	Economy	3300.00
0005433368077	24855	Economy	3300.00
0005433368098	24855	Economy	3300.00
0005435652885	24855	Economy	3300.00
0005435652790	24855	Economy	3300.00
0005435652785	24855	Economy	3300.00
0005435652903	24855	Economy	3300.00
0005433368075	24855	Economy	3600.00
0005433368101	24855	Economy	3600.00
0005433368079	24855	Economy	3600.00
0005433368064	24855	Economy	3600.00
0005433368085	24855	Economy	3600.00
0005435652833	24855	Economy	3300.00
0005435652892	24855	Economy	3300.00
0005433368100	24855	Economy	3300.00
0005433368086	24855	Economy	3300.00
0005433368066	24855	Economy	3300.00
0005433368065	24855	Economy	3300.00
0005435652728	24855	Economy	3300.00
0005435652866	24855	Economy	3300.00
0005433368095	24855	Economy	3300.00
0005433368068	24855	Economy	3300.00
0005433368074	24855	Economy	3300.00
0005433368073	24855	Economy	3300.00
0005435652865	24855	Economy	3300.00
0005435652765	24855	Economy	3300.00
0005435652913	24855	Economy	3300.00
0005435652708	24855	Economy	3300.00
0005435652711	24855	Economy	3300.00
0005435652627	24855	Economy	3300.00
0005435652898	24855	Economy	3300.00
0005435652909	24855	Economy	3300.00
0005435652891	24855	Economy	3300.00
0005433368094	24855	Economy	3300.00
0005433368091	24855	Economy	3300.00
0005435652910	24855	Economy	3300.00
0005435652901	24855	Economy	3300.00
0005435652703	24855	Economy	3300.00
0005435652859	24855	Economy	3300.00
0005435652722	24855	Economy	3300.00
0005435652834	24855	Economy	3300.00
0005433368087	24855	Economy	3300.00
0005433368093	24855	Economy	3300.00
0005435652912	24855	Economy	3300.00
0005435652680	24855	Economy	3300.00
0005433368063	24855	Economy	3300.00
0005435652739	24855	Economy	3300.00
0005435652775	24855	Economy	3300.00
0005435652893	24855	Economy	3300.00
0005433368076	24855	Economy	3300.00
0005435652784	24855	Economy	3300.00
0005433368097	24855	Economy	3300.00
0005435652902	24855	Economy	3300.00
0005435652729	24855	Economy	3300.00
0005433368069	24855	Economy	3300.00
0005435652709	24855	Economy	3300.00
0005433368081	24855	Economy	3300.00
0005435652727	24855	Economy	3300.00
0005433368090	24855	Economy	3300.00
0005433368082	24855	Economy	3300.00
0005433368089	24855	Economy	3300.00
0005435652869	24855	Economy	3300.00
0005435652882	24855	Economy	3300.00
0005433368102	24855	Economy	3300.00
0005435652641	24855	Economy	3300.00
0005433368078	24855	Economy	3300.00
0005435652823	24855	Economy	3300.00
0005433368084	24855	Economy	3300.00
0005433368096	24855	Economy	3300.00
0005433368083	24855	Economy	3300.00
0005433368070	24855	Economy	3300.00
0005433368088	24855	Economy	3300.00
0005435652716	24855	Economy	3300.00
0005433368080	24855	Economy	3300.00
0005433368099	24855	Economy	3300.00
0005435652856	24855	Economy	3300.00
0005434979958	2042	Economy	10500.00
0005434979938	2042	Economy	10500.00
0005435801710	2042	Economy	9500.00
0005434979956	2042	Economy	9500.00
0005434979931	2042	Economy	9500.00
0005434979944	2042	Economy	9500.00
0005434979933	2042	Economy	9500.00
0005434979930	2042	Economy	9500.00
0005434979959	2042	Economy	9500.00
0005434979941	2042	Economy	9500.00
0005434979929	2042	Economy	9500.00
0005434979936	2042	Economy	9500.00
0005434979949	2042	Economy	9500.00
0005434979950	2042	Economy	9500.00
0005434979947	2042	Economy	9500.00
0005434979935	2042	Economy	9500.00
0005434979945	2042	Economy	9500.00
0005434979932	2042	Economy	9500.00
0005434979946	2042	Economy	9500.00
0005434979954	2042	Economy	9500.00
0005434979937	2042	Economy	9500.00
0005434979940	2042	Economy	9500.00
0005434979955	2042	Economy	9500.00
0005434979951	2042	Economy	9500.00
0005435801712	2042	Economy	9500.00
0005434979953	2042	Economy	9500.00
0005434979942	2042	Economy	9500.00
0005434979934	2042	Economy	9500.00
0005435801711	2042	Economy	9500.00
0005435801713	2042	Economy	9500.00
0005434979952	2042	Economy	9500.00
0005434979948	2042	Economy	9500.00
0005434979943	2042	Economy	9500.00
0005434979957	2042	Economy	9500.00
0005434979939	2042	Economy	9500.00
0005434979598	23524	Economy	10500.00
0005434979619	23524	Economy	10500.00
0005434979647	23524	Economy	9500.00
0005434979599	23524	Economy	9500.00
0005435801688	23524	Economy	9500.00
0005434979738	23524	Economy	9500.00
0005434979641	23524	Economy	9500.00
0005434979646	23524	Economy	9500.00
0005434979640	23524	Economy	9500.00
0005434979665	23524	Economy	9500.00
0005434979604	23524	Economy	9500.00
0005434979623	23524	Economy	9500.00
0005434979563	23524	Economy	9500.00
0005434979581	23524	Economy	9500.00
0005434979617	23524	Economy	9500.00
0005434979562	23524	Economy	9500.00
0005434979571	23524	Economy	9500.00
0005434979636	23524	Economy	9500.00
0005434979676	23524	Economy	9500.00
0005434979572	23524	Economy	9500.00
0005434979799	23524	Economy	9500.00
0005435801694	23524	Economy	9500.00
0005434979637	23524	Economy	9500.00
0005434979580	23524	Economy	9500.00
0005434979666	23524	Economy	9500.00
0005434979710	23524	Economy	9500.00
0005434979498	23524	Economy	9500.00
0005434979687	23524	Economy	9500.00
0005434979535	23524	Economy	9500.00
0005434979657	23524	Economy	9500.00
0005435801693	23524	Economy	9500.00
0005434979618	23524	Economy	9500.00
0005435801680	23524	Economy	9500.00
0005434979648	23524	Economy	9500.00
0005434979709	23524	Economy	9500.00
0005434952549	2649	Economy	5300.00
0005434952550	2649	Economy	5300.00
0005434952551	2649	Economy	5300.00
0005434952548	2649	Economy	5300.00
0005433256419	2650	Economy	5300.00
0005433256418	2650	Economy	5300.00
0005433256410	2650	Economy	5300.00
0005434952531	28227	Economy	5300.00
0005433256434	28227	Economy	5300.00
0005433256432	28227	Economy	5300.00
0005433256433	28227	Economy	5300.00
0005433256435	28227	Economy	5300.00
0005434952512	28227	Economy	5300.00
0005433112383	19736	Economy	8700.00
0005433112382	19736	Economy	8700.00
0005433111517	19736	Economy	8700.00
0005433111519	19736	Economy	8700.00
0005433111518	19736	Economy	8700.00
0005434137710	11930	Business	9700.00
0005434137714	11930	Business	9700.00
0005434137967	11930	Business	9700.00
0005434137390	11930	Business	9700.00
0005434138126	11930	Business	9700.00
0005434138040	11930	Business	9700.00
0005434137873	11930	Business	9700.00
0005434137771	11930	Business	9700.00
0005434137684	11930	Economy	3200.00
0005434137748	11930	Economy	3200.00
0005434138033	11930	Economy	3200.00
0005434138009	11930	Economy	3200.00
0005434138100	11930	Economy	3200.00
0005434137644	11930	Economy	3200.00
0005434137742	11930	Economy	3200.00
0005434137814	11930	Economy	3200.00
0005434138097	11930	Economy	3500.00
0005434137643	11930	Economy	3500.00
0005434138019	11930	Economy	3500.00
0005434137846	11930	Economy	3200.00
0005434137680	11930	Economy	3200.00
0005434137716	11930	Economy	3200.00
0005434138134	11930	Economy	3200.00
0005434137715	11930	Economy	3200.00
0005434137717	11930	Economy	3200.00
0005434137815	11930	Economy	3200.00
0005434137304	11930	Economy	3200.00
0005434137779	11930	Economy	3200.00
0005434138011	11930	Economy	3200.00
0005434138086	11930	Economy	3200.00
0005434137985	11930	Economy	3200.00
0005434137968	11930	Economy	3200.00
0005434138092	11930	Economy	3200.00
0005434138012	11930	Economy	3200.00
0005434138221	11930	Economy	3200.00
0005434137934	11930	Economy	3200.00
0005434137747	11930	Economy	3200.00
0005434137705	11930	Economy	3200.00
0005434137987	11930	Economy	3200.00
0005434137813	11930	Economy	3200.00
0005434137949	11930	Economy	3200.00
0005434137951	11930	Economy	3200.00
0005434138265	11930	Economy	3200.00
0005434137917	11930	Economy	3200.00
0005434138124	11930	Economy	3200.00
0005434137780	11930	Economy	3200.00
0005434137882	11930	Economy	3200.00
0005434137816	11930	Economy	3200.00
0005434137812	11930	Economy	3200.00
0005434137704	11930	Economy	3200.00
0005434138021	11930	Economy	3200.00
0005434137883	11930	Economy	3200.00
0005434138008	11930	Economy	3200.00
0005434137709	11930	Economy	3200.00
0005434137990	11930	Economy	3200.00
0005434137756	11930	Economy	3200.00
0005434137933	11930	Economy	3200.00
0005434138200	11930	Economy	3200.00
0005434137912	11930	Economy	3200.00
0005434138101	11930	Economy	3200.00
0005434137729	11930	Economy	3200.00
0005434137983	11930	Economy	3200.00
0005434138010	11930	Economy	3200.00
0005434138085	11930	Economy	3200.00
0005434138093	11930	Economy	3200.00
0005434137988	11930	Economy	3200.00
0005434137685	11930	Economy	3200.00
0005434137731	11930	Economy	3200.00
0005434137911	11930	Economy	3200.00
0005434138191	11930	Economy	3200.00
0005434137706	11930	Economy	3200.00
0005434137989	11930	Economy	3200.00
0005434137682	11930	Economy	3200.00
0005434138199	11930	Economy	3200.00
0005434137642	11930	Economy	3200.00
0005434137683	11930	Economy	3200.00
0005434137881	11930	Economy	3200.00
0005434137843	11930	Economy	3200.00
0005434138003	11930	Economy	3200.00
0005434137984	11930	Economy	3200.00
0005434137730	11930	Economy	3200.00
0005434138518	28767	Business	9700.00
0005434138513	28767	Business	9700.00
0005434138547	28767	Business	9700.00
0005434138530	28767	Business	9700.00
0005434138525	28767	Business	9700.00
0005434138480	28767	Business	9700.00
0005434138532	28767	Business	9700.00
0005434138471	28767	Business	9700.00
0005434138491	28767	Business	9700.00
0005434138533	28767	Business	9700.00
0005434138539	28767	Business	9700.00
0005434138507	28767	Business	9700.00
0005434138482	28767	Economy	3200.00
0005434138544	28767	Economy	3200.00
0005434138500	28767	Economy	3200.00
0005434138526	28767	Economy	3200.00
0005434138488	28767	Economy	3200.00
0005434138515	28767	Economy	3200.00
0005434138503	28767	Economy	3200.00
0005434138495	28767	Economy	3200.00
0005434138523	28767	Economy	3200.00
0005434138514	28767	Economy	3500.00
0005434138505	28767	Economy	3500.00
0005434138548	28767	Economy	3500.00
0005434138531	28767	Economy	3500.00
0005434138481	28767	Economy	3200.00
0005434138499	28767	Economy	3200.00
0005434138510	28767	Economy	3200.00
0005434138511	28767	Economy	3200.00
0005434138551	28767	Economy	3200.00
0005434138529	28767	Economy	3200.00
0005434138474	28767	Economy	3200.00
0005434138542	28767	Economy	3200.00
0005434138535	28767	Economy	3200.00
0005434138473	28767	Economy	3200.00
0005434138489	28767	Economy	3200.00
0005434138478	28767	Economy	3200.00
0005434138487	28767	Economy	3200.00
0005434138521	28767	Economy	3200.00
0005434138534	28767	Economy	3200.00
0005434138501	28767	Economy	3200.00
0005434138541	28767	Economy	3200.00
0005434138540	28767	Economy	3200.00
0005434138497	28767	Economy	3200.00
0005434138543	28767	Economy	3200.00
0005434138546	28767	Economy	3200.00
0005434138492	28767	Economy	3200.00
0005434138506	28767	Economy	3200.00
0005434138483	28767	Economy	3200.00
0005434138512	28767	Economy	3200.00
0005434138504	28767	Economy	3200.00
0005434138470	28767	Economy	3200.00
0005434138498	28767	Economy	3200.00
0005434138552	28767	Economy	3200.00
0005434138528	28767	Economy	3200.00
0005434138484	28767	Economy	3200.00
0005434138545	28767	Economy	3200.00
0005434138537	28767	Economy	3200.00
0005434138524	28767	Economy	3200.00
0005434138475	28767	Economy	3200.00
0005434138479	28767	Economy	3200.00
0005434138536	28767	Economy	3200.00
0005434138490	28767	Economy	3200.00
0005434138476	28767	Economy	3200.00
0005434138477	28767	Economy	3200.00
0005434138485	28767	Economy	3200.00
0005434138517	28767	Economy	3200.00
0005434138550	28767	Economy	3200.00
0005434138496	28767	Economy	3200.00
0005434138502	28767	Economy	3200.00
0005434138522	28767	Economy	3200.00
0005434138493	28767	Economy	3200.00
0005434138549	28767	Economy	3200.00
0005434138486	28767	Economy	3200.00
0005434138494	28767	Economy	3200.00
0005434138527	28767	Economy	3200.00
0005434138519	28767	Economy	3200.00
0005434138520	28767	Economy	3200.00
0005434138508	28767	Economy	3200.00
0005434138472	28767	Economy	3200.00
0005434138509	28767	Economy	3200.00
0005434138538	28767	Economy	3200.00
0005434138516	28767	Economy	3200.00
0005433538911	6793	Economy	10900.00
0005433538910	6793	Economy	10900.00
0005433538917	6793	Economy	9900.00
0005433538918	6793	Economy	9900.00
0005433538919	6793	Economy	9900.00
0005433538915	6793	Economy	9900.00
0005435259749	6793	Economy	9900.00
0005435259739	6793	Economy	9900.00
0005433534508	6793	Economy	9900.00
0005433538914	6793	Economy	9900.00
0005433538912	6793	Economy	9900.00
0005433538913	6793	Economy	9900.00
0005433534509	6793	Economy	9900.00
0005433534510	6793	Economy	9900.00
0005433538916	6793	Economy	9900.00
0005433538804	25000	Economy	10900.00
0005433538844	25000	Economy	10900.00
0005435259781	25000	Economy	9900.00
0005435259778	25000	Economy	9900.00
0005435259779	25000	Economy	9900.00
0005433534487	25000	Economy	9900.00
0005433538823	25000	Economy	9900.00
0005435259780	25000	Economy	9900.00
0005433538848	25000	Economy	9900.00
0005433534489	25000	Economy	9900.00
0005433534490	25000	Economy	9900.00
0005433538819	25000	Economy	9900.00
0005433538853	25000	Economy	9900.00
0005433534486	25000	Economy	9900.00
0005433538810	25000	Economy	9900.00
0005435259777	25000	Economy	9900.00
0005433511994	819	Economy	14600.00
0005433511993	819	Economy	14600.00
0005433511996	819	Economy	14600.00
0005432922517	819	Economy	14600.00
0005433511992	819	Economy	14600.00
0005433511995	819	Economy	14600.00
0005432922519	819	Economy	14600.00
0005432922518	819	Economy	14600.00
0005432922516	819	Economy	14600.00
0005433511991	819	Economy	14600.00
0005433511998	819	Economy	14600.00
0005433511997	819	Economy	14600.00
0005432922544	16140	Economy	14600.00
0005433511914	16140	Economy	14600.00
0005432922545	16140	Economy	14600.00
0005433511920	16140	Economy	14600.00
0005432922546	16140	Economy	14600.00
0005432922547	16140	Economy	14600.00
0005435697494	3650	Economy	7900.00
0005434950554	3650	Economy	7900.00
0005435697496	3650	Economy	7900.00
0005435697498	3650	Economy	7200.00
0005435697485	3650	Economy	7200.00
0005435697489	3650	Economy	7200.00
0005435697500	3650	Economy	7200.00
0005435697476	3650	Economy	7200.00
0005435697497	3650	Economy	7200.00
0005435697491	3650	Economy	7200.00
0005434950553	3650	Economy	7200.00
0005435935034	3650	Economy	7200.00
0005435697502	3650	Economy	7200.00
0005435697479	3650	Economy	7200.00
0005435935033	3650	Economy	7200.00
0005435697495	3650	Economy	7200.00
0005435697481	3650	Economy	7200.00
0005435697480	3650	Economy	7200.00
0005435697475	3650	Economy	7200.00
0005435916154	3650	Economy	7200.00
0005435697499	3650	Economy	7200.00
0005435697487	3650	Economy	7200.00
0005435697492	3650	Economy	7200.00
0005435697477	3650	Economy	7200.00
0005435697484	3650	Economy	7200.00
0005435697482	3650	Economy	7200.00
0005435697486	3650	Economy	7200.00
0005435697490	3650	Economy	7200.00
0005435697483	3650	Economy	7200.00
0005435697493	3650	Economy	7200.00
0005434950552	3650	Economy	7200.00
0005435935021	3650	Economy	7200.00
0005434950551	3650	Economy	7200.00
0005435697488	3650	Economy	7200.00
0005435697503	3650	Economy	7200.00
0005435697478	3650	Economy	7200.00
0005435697501	3650	Economy	7200.00
0005435697474	3650	Economy	7200.00
0005435697231	16301	Economy	7900.00
0005435916183	16301	Economy	7900.00
0005435697256	16301	Economy	7900.00
0005435697264	16301	Economy	7200.00
0005435697201	16301	Economy	7200.00
0005435697284	16301	Economy	7200.00
0005434950502	16301	Economy	7200.00
0005435697200	16301	Economy	7200.00
0005435697320	16301	Economy	7200.00
0005435916181	16301	Economy	7200.00
0005435697188	16301	Economy	7200.00
0005435935060	16301	Economy	7200.00
0005435935059	16301	Economy	7200.00
0005435916182	16301	Economy	7200.00
0005435697315	16301	Economy	7200.00
0005435697318	16301	Economy	7200.00
0005435697266	16301	Economy	7200.00
0005435697282	16301	Economy	7200.00
0005435697196	16301	Economy	7200.00
0005435697232	16301	Economy	7200.00
0005435697237	16301	Economy	7200.00
0005435697283	16301	Economy	7200.00
0005435697137	16301	Economy	7200.00
0005435697356	16301	Economy	7200.00
0005435697271	16301	Economy	7200.00
0005435697195	16301	Economy	7200.00
0005435697198	16301	Economy	7200.00
0005435697163	16301	Economy	7200.00
0005435697230	16301	Economy	7200.00
0005435935061	16301	Economy	7200.00
0005432607587	3978	Economy	21300.00
0005433519481	3978	Economy	21300.00
0005432607589	3978	Economy	21300.00
0005432607588	3978	Economy	19300.00
0005434606847	3978	Economy	19300.00
0005434606846	3978	Economy	19300.00
0005434606845	3978	Economy	19300.00
0005434604916	3978	Economy	19300.00
0005432609753	3978	Economy	19300.00
0005435904705	3978	Economy	19300.00
0005432609754	3978	Economy	19300.00
0005433519482	3978	Economy	19300.00
0005435853602	3978	Economy	19300.00
0005435842325	3978	Economy	19300.00
0005435841472	3978	Economy	19300.00
0005434604915	3978	Economy	19300.00
0005435841474	3978	Economy	19300.00
0005434604917	3978	Economy	19300.00
0005433519483	3978	Economy	19300.00
0005435842324	3978	Economy	19300.00
0005435841473	3978	Economy	19300.00
0005432609752	3978	Economy	19300.00
0005432607586	3978	Economy	19300.00
0005433519456	22086	Economy	21300.00
0005433519458	22086	Economy	21300.00
0005432609709	22086	Economy	21300.00
0005432609703	22086	Economy	19300.00
0005434606815	22086	Economy	19300.00
0005432609704	22086	Economy	19300.00
0005432613833	22086	Economy	19300.00
0005432609714	22086	Economy	19300.00
0005432609694	22086	Economy	19300.00
0005432613828	22086	Economy	19300.00
0005432613822	22086	Economy	19300.00
0005432613821	22086	Economy	19300.00
0005432609680	22086	Economy	19300.00
0005432613844	22086	Economy	19300.00
0005432609701	22086	Economy	19300.00
0005433519442	22086	Economy	19300.00
0005432613818	22086	Economy	19300.00
0005432609686	22086	Economy	19300.00
0005432613855	22086	Economy	19300.00
0005432613853	22086	Economy	19300.00
0005432613827	22086	Economy	19300.00
0005434606816	22086	Economy	19300.00
0005432613839	22086	Economy	19300.00
0005434606808	22086	Economy	19300.00
0005432609683	22086	Economy	19300.00
0005432609699	22086	Economy	19300.00
0005432613817	22086	Economy	19300.00
0005432613816	22086	Economy	19300.00
0005432613834	22086	Economy	19300.00
0005432613837	22086	Economy	19300.00
0005432609700	22086	Economy	19300.00
0005434606807	22086	Economy	19300.00
0005432613819	22086	Economy	19300.00
0005432609679	22086	Economy	19300.00
0005432609678	22086	Economy	19300.00
0005433519430	22086	Economy	19300.00
0005433519457	22086	Economy	19300.00
0005432613826	22086	Economy	19300.00
0005432613840	22086	Economy	19300.00
0005432609682	22086	Economy	19300.00
0005432609707	22086	Economy	19300.00
0005432613825	22086	Economy	19300.00
0005432613838	22086	Economy	19300.00
0005432609706	22086	Economy	19300.00
0005432613820	22086	Economy	19300.00
0005433348978	711	Economy	3700.00
0005433348977	711	Economy	3700.00
0005433348951	711	Economy	3700.00
0005435628738	711	Economy	3700.00
0005435628737	711	Economy	3700.00
0005433348972	711	Economy	3700.00
0005433348964	711	Economy	3700.00
0005433348971	711	Economy	3700.00
0005433349017	15879	Economy	3700.00
0005433349022	15879	Economy	3700.00
0005435628713	15879	Economy	3700.00
0005433349021	15879	Economy	3700.00
0005433349018	15879	Economy	3700.00
0005433349020	15879	Economy	3700.00
0005433349019	15879	Economy	3700.00
0005434446526	17181	Economy	7100.00
0005434446528	17181	Economy	7100.00
0005433159299	17181	Economy	7100.00
0005434446525	17181	Economy	7100.00
0005434446527	17181	Economy	7100.00
0005433159300	17181	Economy	7100.00
0005433159326	17596	Economy	7100.00
0005434445229	17596	Economy	7100.00
0005434445242	17596	Economy	7100.00
0005434445241	17596	Economy	7100.00
0005433159327	17596	Economy	7100.00
0005433159324	17596	Economy	7100.00
0005433159325	17596	Economy	7100.00
0005435132941	7866	Economy	5400.00
0005435383143	7866	Economy	5400.00
0005435132936	7866	Economy	5400.00
0005435132942	7866	Economy	5400.00
0005435132935	7866	Economy	5400.00
0005435132932	7866	Economy	5400.00
0005435132933	7866	Economy	5400.00
0005435132940	7866	Economy	5400.00
0005435132937	7866	Economy	5400.00
0005435132938	7866	Economy	5400.00
0005435132939	7866	Economy	5400.00
0005435132934	7866	Economy	5400.00
0005435132827	33109	Economy	5400.00
0005435132868	33109	Economy	5400.00
0005435383177	33109	Economy	5400.00
0005435383180	33109	Economy	5400.00
0005435383178	33109	Economy	5400.00
0005435132834	33109	Economy	5400.00
0005435132840	33109	Economy	5400.00
0005435383181	33109	Economy	5400.00
0005435383182	33109	Economy	5400.00
0005435132826	33109	Economy	5400.00
0005435383176	33109	Economy	5400.00
0005435132861	33109	Economy	5400.00
0005435383179	33109	Economy	5400.00
0005435132878	33109	Economy	5400.00
0005435811103	4411	Business	133200.00
0005435811097	4411	Business	133200.00
0005435938870	4411	Business	133200.00
0005435811101	4411	Economy	44400.00
0005435938875	4411	Economy	44400.00
0005435811102	4411	Economy	48800.00
0005435811099	4411	Economy	44400.00
0005435811098	4411	Economy	44400.00
0005435811105	4411	Economy	44400.00
0005435938867	4411	Economy	44400.00
0005435811100	4411	Economy	44400.00
0005435938876	4411	Economy	44400.00
0005435938869	4411	Economy	44400.00
0005435938882	4411	Economy	44400.00
0005435811096	4411	Economy	44400.00
0005435938871	4411	Economy	44400.00
0005435938868	4411	Economy	44400.00
0005435811104	4411	Economy	44400.00
0005435938874	4411	Economy	44400.00
0005435938902	29444	Business	133200.00
0005435938899	29444	Business	133200.00
0005435938901	29444	Economy	44400.00
0005435811079	29444	Economy	44400.00
0005435938897	29444	Economy	44400.00
0005435811042	29444	Economy	44400.00
0005435811055	29444	Economy	44400.00
0005435811052	29444	Economy	44400.00
0005435811040	29444	Economy	44400.00
0005435938898	29444	Economy	44400.00
0005435938900	29444	Economy	44400.00
0005435811060	29444	Economy	44400.00
0005435811062	29444	Economy	44400.00
0005435811050	29444	Economy	44400.00
0005435811057	29444	Economy	44400.00
0005435811039	29444	Economy	44400.00
0005435811047	29444	Economy	44400.00
0005435938903	29444	Economy	44400.00
0005435811078	29444	Economy	44400.00
0005435811063	29444	Economy	44400.00
0005435811056	29444	Economy	44400.00
0005435811049	29444	Economy	44400.00
0005435811053	29444	Economy	44400.00
0005435390208	7479	Economy	13800.00
0005435160366	7479	Economy	12500.00
0005435160357	7479	Economy	12500.00
0005435160360	7479	Economy	12500.00
0005435160363	7479	Economy	12500.00
0005435160355	7479	Economy	12500.00
0005435160358	7479	Economy	12500.00
0005435160362	7479	Economy	12500.00
0005435160359	7479	Economy	12500.00
0005435160364	7479	Economy	12500.00
0005435160365	7479	Economy	12500.00
0005435390224	7479	Economy	12500.00
0005435390223	7479	Economy	12500.00
0005435160361	7479	Economy	12500.00
0005435390220	7479	Economy	12500.00
0005435390212	7479	Economy	12500.00
0005435390203	7479	Economy	12500.00
0005435160356	7479	Economy	12500.00
0005435160291	29560	Economy	13800.00
0005435160273	29560	Economy	12500.00
0005435160262	29560	Economy	12500.00
0005435160306	29560	Economy	12500.00
0005435160263	29560	Economy	12500.00
0005435390277	29560	Economy	12500.00
0005435160305	29560	Economy	12500.00
0005435160307	29560	Economy	12500.00
0005435390278	29560	Economy	12500.00
0005435390276	29560	Economy	12500.00
0005435390279	29560	Economy	12500.00
0005435160290	29560	Economy	12500.00
0005435160260	29560	Economy	12500.00
0005435160256	29560	Economy	12500.00
0005435390275	29560	Economy	12500.00
0005435160242	29560	Economy	12500.00
0005435160241	29560	Economy	12500.00
0005435160264	29560	Economy	12500.00
0005435160309	29560	Economy	12500.00
0005432394089	18454	Economy	4900.00
0005432398185	18454	Economy	4900.00
0005435178502	18454	Economy	4900.00
0005432398184	18454	Economy	4900.00
0005435178503	18454	Economy	4900.00
0005432398212	27152	Economy	4900.00
0005432400142	27152	Economy	4900.00
0005435178487	27152	Economy	4900.00
0005435179391	27152	Economy	4900.00
0005432398213	27152	Economy	4900.00
0005432398215	27152	Economy	4900.00
0005432398214	27152	Economy	4900.00
0005435179387	27152	Economy	4900.00
0005432400141	27152	Economy	4900.00
0005432400140	27152	Economy	4900.00
0005435178488	27152	Economy	4900.00
0005432398211	27152	Economy	4900.00
0005434191268	9744	Economy	4400.00
0005434191271	9744	Economy	4400.00
0005434504376	6556	Business	48400.00
0005434504344	6556	Business	48400.00
0005434504379	6556	Business	48400.00
0005434504355	6556	Business	48400.00
0005435103975	6556	Business	48400.00
0005434504342	6556	Business	48400.00
0005434504365	6556	Economy	16100.00
0005435103974	6556	Economy	16100.00
0005434504360	6556	Economy	16100.00
0005434504345	6556	Economy	16100.00
0005434504370	6556	Economy	16100.00
0005434504371	6556	Economy	17800.00
0005434504357	6556	Economy	17800.00
0005435103969	6556	Economy	17800.00
0005434504380	6556	Economy	16100.00
0005434504368	6556	Economy	16100.00
0005434504351	6556	Economy	16100.00
0005434504349	6556	Economy	16100.00
0005434504377	6556	Economy	16100.00
0005434504347	6556	Economy	16100.00
0005434504359	6556	Economy	16100.00
0005434504378	6556	Economy	16100.00
0005434504358	6556	Economy	16100.00
0005435103971	6556	Economy	16100.00
0005434504367	6556	Economy	16100.00
0005434504352	6556	Economy	16100.00
0005434504353	6556	Economy	16100.00
0005435103968	6556	Economy	16100.00
0005435103973	6556	Economy	16100.00
0005434504381	6556	Economy	16100.00
0005435103976	6556	Economy	16100.00
0005435103978	6556	Economy	16100.00
0005434504361	6556	Economy	16100.00
0005434504363	6556	Economy	16100.00
0005434504343	6556	Economy	16100.00
0005434504382	6556	Economy	16100.00
0005434504375	6556	Economy	16100.00
0005434504346	6556	Economy	16100.00
0005434504372	6556	Economy	16100.00
0005435103970	6556	Economy	16100.00
0005434504350	6556	Economy	16100.00
0005434504354	6556	Economy	16100.00
0005434504366	6556	Economy	16100.00
0005434504373	6556	Economy	16100.00
0005434504374	6556	Economy	16100.00
0005434504369	6556	Economy	16100.00
0005434504364	6556	Economy	16100.00
0005435103972	6556	Economy	16100.00
0005435103977	6556	Economy	16100.00
0005434504362	6556	Economy	16100.00
0005434504348	6556	Economy	16100.00
0005434504356	6556	Economy	16100.00
0005434504043	22684	Business	48400.00
0005435103859	22684	Business	48400.00
0005434504042	22684	Business	48400.00
0005434503900	22684	Business	48400.00
0005434503850	22684	Business	48400.00
0005434503885	22684	Business	48400.00
0005434503987	22684	Business	48400.00
0005434504055	22684	Economy	16100.00
0005434503985	22684	Economy	17800.00
0005434503894	22684	Economy	17800.00
0005434503825	22684	Economy	16100.00
0005434503795	22684	Economy	16100.00
0005435103855	22684	Economy	16100.00
0005434503988	22684	Economy	16100.00
0005434503867	22684	Economy	16100.00
0005434503915	22684	Economy	16100.00
0005434504029	22684	Economy	16100.00
0005434503798	22684	Economy	16100.00
0005434504041	22684	Economy	16100.00
0005434503925	22684	Economy	16100.00
0005434503961	22684	Economy	16100.00
0005434503984	22684	Economy	16100.00
0005434503986	22684	Economy	16100.00
0005434503821	22684	Economy	16100.00
0005434503756	22684	Economy	16100.00
0005434504056	22684	Economy	16100.00
0005434503799	22684	Economy	16100.00
0005434503895	22684	Economy	16100.00
0005434503876	22684	Economy	16100.00
0005434503924	22684	Economy	16100.00
0005434504039	22684	Economy	16100.00
0005434503841	22684	Economy	16100.00
0005434503967	22684	Economy	16100.00
0005434503737	22684	Economy	16100.00
0005434503784	22684	Economy	16100.00
0005434503822	22684	Economy	16100.00
0005434503973	22684	Economy	16100.00
0005434503968	22684	Economy	16100.00
0005434503738	22684	Economy	16100.00
0005434504040	22684	Economy	16100.00
0005434504084	22684	Economy	16100.00
0005434503884	22684	Economy	16100.00
0005434504050	22684	Economy	16100.00
0005435103862	22684	Economy	16100.00
0005434503796	22684	Economy	16100.00
0005434503914	22684	Economy	16100.00
0005435103854	22684	Economy	16100.00
0005434504005	22684	Economy	16100.00
0005435103835	22684	Economy	16100.00
0005434503983	22684	Economy	16100.00
0005434503899	22684	Economy	16100.00
0005434503783	22684	Economy	16100.00
0005434503879	22684	Economy	16100.00
0005435800101	21305	Economy	16800.00
0005435800084	21305	Economy	15300.00
0005435800097	21305	Economy	15300.00
0005435800096	21305	Economy	15300.00
0005435800090	21305	Economy	15300.00
0005435800082	21305	Economy	15300.00
0005435800091	21305	Economy	15300.00
0005435800086	21305	Economy	15300.00
0005435800093	21305	Economy	15300.00
0005435800095	21305	Economy	15300.00
0005435800094	21305	Economy	15300.00
0005435800092	21305	Economy	15300.00
0005435800083	21305	Economy	15300.00
0005435800085	21305	Economy	15300.00
0005435653274	1650	Business	50000.00
0005433367704	1650	Business	50000.00
0005435653262	1650	Business	50000.00
0005433367700	1650	Business	50000.00
0005433367867	1650	Business	50000.00
0005435653289	1650	Business	50000.00
0005433367759	1650	Business	50000.00
0005433367706	1650	Business	50000.00
0005435653294	1650	Business	50000.00
0005433367649	1650	Economy	16700.00
0005433367823	1650	Economy	16700.00
0005433367760	1650	Economy	16700.00
0005433367721	1650	Economy	16700.00
0005433367572	1650	Economy	16700.00
0005433367826	1650	Economy	16700.00
0005435653267	1650	Economy	16700.00
0005435653279	1650	Economy	16700.00
0005435653292	1650	Economy	16700.00
0005435653266	1650	Economy	18300.00
0005435653290	1650	Economy	18300.00
0005433367857	1650	Economy	16700.00
0005435653281	1650	Economy	16700.00
0005433367687	1650	Economy	16700.00
0005435653286	1650	Economy	16700.00
0005433367745	1650	Economy	16700.00
0005435653276	1650	Economy	16700.00
0005433367705	1650	Economy	16700.00
0005433367643	1650	Economy	16700.00
0005435653285	1650	Economy	16700.00
0005435653284	1650	Economy	16700.00
0005435653271	1650	Economy	16700.00
0005435653283	1650	Economy	16700.00
0005433367602	1650	Economy	16700.00
0005435653277	1650	Economy	16700.00
0005433367744	1650	Economy	16700.00
0005433367822	1650	Economy	16700.00
0005433367727	1650	Economy	16700.00
0005435653275	1650	Economy	16700.00
0005435653280	1650	Economy	16700.00
0005433367722	1650	Economy	16700.00
0005433367628	1650	Economy	16700.00
0005433367688	1650	Economy	16700.00
0005435653278	1650	Economy	16700.00
0005433367832	1650	Economy	16700.00
0005435653273	1650	Economy	16700.00
0005435653268	1650	Economy	16700.00
0005433367796	1650	Economy	16700.00
0005435653264	1650	Economy	16700.00
0005435653293	1650	Economy	16700.00
0005435653288	1650	Economy	16700.00
0005435653291	1650	Economy	16700.00
0005433367726	1650	Economy	16700.00
0005433367606	1650	Economy	16700.00
0005433367611	1650	Economy	16700.00
0005433367571	1650	Economy	16700.00
0005433367821	1650	Economy	16700.00
0005433367854	1650	Economy	16700.00
0005435653272	1650	Economy	16700.00
0005433367819	1650	Economy	16700.00
0005433367752	1650	Economy	16700.00
0005435653282	1650	Economy	16700.00
0005435653265	1650	Economy	16700.00
0005435653287	1650	Economy	16700.00
0005435653263	1650	Economy	16700.00
0005433367825	1650	Economy	16700.00
0005433367849	1650	Economy	16700.00
0005433367907	1650	Economy	16700.00
0005435653269	1650	Economy	16700.00
0005433367607	1650	Economy	16700.00
0005435653270	1650	Economy	16700.00
0005433367845	1650	Economy	16700.00
0005433367850	1650	Economy	16700.00
0005433368065	21667	Business	50000.00
0005433368070	21667	Business	50000.00
0005435652892	21667	Business	50000.00
0005435652727	21667	Business	50000.00
0005435652856	21667	Business	50000.00
0005435652859	21667	Business	50000.00
0005433368067	21667	Business	50000.00
0005433368087	21667	Business	50000.00
0005435652834	21667	Business	50000.00
0005435652790	21667	Business	50000.00
0005435652750	21667	Economy	16700.00
0005435652765	21667	Economy	16700.00
0005435652711	21667	Economy	16700.00
0005435652703	21667	Economy	16700.00
0005433368081	21667	Economy	16700.00
0005433368099	21667	Economy	16700.00
0005433368080	21667	Economy	16700.00
0005435652909	21667	Economy	16700.00
0005435652794	21667	Economy	16700.00
0005435652898	21667	Economy	16700.00
0005433368095	21667	Economy	18300.00
0005433368094	21667	Economy	18300.00
0005435652627	21667	Economy	18300.00
0005433368102	21667	Economy	18300.00
0005433368063	21667	Economy	16700.00
0005435652784	21667	Economy	16700.00
0005433368074	21667	Economy	16700.00
0005435652722	21667	Economy	16700.00
0005435652709	21667	Economy	16700.00
0005435652855	21667	Economy	16700.00
0005435652901	21667	Economy	16700.00
0005433368096	21667	Economy	16700.00
0005435652882	21667	Economy	16700.00
0005435652823	21667	Economy	16700.00
0005435652912	21667	Economy	16700.00
0005435652903	21667	Economy	16700.00
0005433368084	21667	Economy	16700.00
0005433368066	21667	Economy	16700.00
0005435652679	21667	Economy	16700.00
0005435652891	21667	Economy	16700.00
0005433368082	21667	Economy	16700.00
0005435652716	21667	Economy	16700.00
0005433368097	21667	Economy	16700.00
0005435652910	21667	Economy	16700.00
0005435652729	21667	Economy	16700.00
0005435652708	21667	Economy	16700.00
0005435652775	21667	Economy	16700.00
0005435652730	21667	Economy	16700.00
0005433368071	21667	Economy	16700.00
0005435652785	21667	Economy	16700.00
0005435652865	21667	Economy	16700.00
0005433368079	21667	Economy	16700.00
0005433368088	21667	Economy	16700.00
0005433368098	21667	Economy	16700.00
0005433368093	21667	Economy	16700.00
0005433368085	21667	Economy	16700.00
0005435652913	21667	Economy	16700.00
0005433368086	21667	Economy	16700.00
0005433368083	21667	Economy	16700.00
0005435652793	21667	Economy	16700.00
0005433368068	21667	Economy	16700.00
0005433368075	21667	Economy	16700.00
0005433368064	21667	Economy	16700.00
0005433368078	21667	Economy	16700.00
0005433368072	21667	Economy	16700.00
0005433368090	21667	Economy	16700.00
0005433368100	21667	Economy	16700.00
0005433368089	21667	Economy	16700.00
0005435652728	21667	Economy	16700.00
0005435652680	21667	Economy	16700.00
0005433368077	21667	Economy	16700.00
0005435652866	21667	Economy	16700.00
0005435652739	21667	Economy	16700.00
0005435652860	21667	Economy	16700.00
0005433368101	21667	Economy	16700.00
0005433368076	21667	Economy	16700.00
0005435652833	21667	Economy	16700.00
0005435652911	21667	Economy	16700.00
0005435652893	21667	Economy	16700.00
0005433368091	21667	Economy	16700.00
0005435652914	21667	Economy	16700.00
0005433368073	21667	Economy	16700.00
0005433368069	21667	Economy	16700.00
0005433368092	21667	Economy	16700.00
0005435652869	21667	Economy	16700.00
0005435652641	21667	Economy	16700.00
0005435652885	21667	Economy	16700.00
0005435652902	21667	Economy	16700.00
0005433986198	4171	Business	21500.00
0005433986211	4171	Business	21500.00
0005433986210	4171	Business	21500.00
0005433986193	4171	Business	21500.00
0005433986209	4171	Business	21500.00
0005433986218	4171	Business	21500.00
0005433986199	4171	Business	21500.00
0005433986176	4171	Economy	7200.00
0005433986183	4171	Economy	7200.00
0005433986212	4171	Economy	7200.00
0005433986192	4171	Economy	7200.00
0005433986196	4171	Economy	7900.00
0005433986201	4171	Economy	7900.00
0005433986187	4171	Economy	7900.00
0005433986194	4171	Economy	7200.00
0005435788783	4171	Economy	7200.00
0005433986217	4171	Economy	7200.00
0005433986184	4171	Economy	7200.00
0005433986200	4171	Economy	7200.00
0005433986190	4171	Economy	7200.00
0005433986189	4171	Economy	7200.00
0005433986207	4171	Economy	7200.00
0005433986214	4171	Economy	7200.00
0005433986197	4171	Economy	7200.00
0005433986186	4171	Economy	7200.00
0005433986202	4171	Economy	7200.00
0005433986185	4171	Economy	7200.00
0005433986177	4171	Economy	7200.00
0005433986206	4171	Economy	7200.00
0005433986204	4171	Economy	7200.00
0005433986215	4171	Economy	7200.00
0005433986182	4171	Economy	7200.00
0005433986178	4171	Economy	7200.00
0005435788785	4171	Economy	7200.00
0005433986191	4171	Economy	7200.00
0005433986208	4171	Economy	7200.00
0005433986180	4171	Economy	7200.00
0005433986213	4171	Economy	7200.00
0005433986216	4171	Economy	7200.00
0005433986205	4171	Economy	7200.00
0005433986203	4171	Economy	7200.00
0005433986188	4171	Economy	7200.00
0005433986179	4171	Economy	7200.00
0005433986181	4171	Economy	7200.00
0005433986195	4171	Economy	7200.00
0005435788784	4171	Economy	7200.00
0005433985714	25652	Business	21500.00
0005433985712	25652	Business	21500.00
0005433985651	25652	Business	21500.00
0005433985752	25652	Business	21500.00
0005433985560	25652	Business	21500.00
0005433985688	25652	Business	21500.00
0005433985687	25652	Economy	7200.00
0005433985680	25652	Economy	7200.00
0005433985685	25652	Economy	7200.00
0005433985692	25652	Economy	7200.00
0005433985431	25652	Economy	7200.00
0005433985691	25652	Economy	7900.00
0005433985753	25652	Economy	7900.00
0005433985668	25652	Economy	7200.00
0005433985585	25652	Economy	7200.00
0005433985709	25652	Economy	7200.00
0005433985432	25652	Economy	7200.00
0005435788769	25652	Economy	7200.00
0005433985535	25652	Economy	7200.00
0005433985678	25652	Economy	7200.00
0005433985677	25652	Economy	7200.00
0005433985648	25652	Economy	7200.00
0005433985737	25652	Economy	7200.00
0005433985624	25652	Economy	7200.00
0005433985755	25652	Economy	7200.00
0005433985713	25652	Economy	7200.00
0005433985679	25652	Economy	7200.00
0005433985652	25652	Economy	7200.00
0005433985542	25652	Economy	7200.00
0005433985689	25652	Economy	7200.00
0005433985722	25652	Economy	7200.00
0005433985475	25652	Economy	7200.00
0005433985569	25652	Economy	7200.00
0005433985590	25652	Economy	7200.00
0005435788765	25652	Economy	7200.00
0005433985534	25652	Economy	7200.00
0005433985672	25652	Economy	7200.00
0005433985667	25652	Economy	7200.00
0005433985476	25652	Economy	7200.00
0005433985541	25652	Economy	7200.00
0005433985686	25652	Economy	7200.00
0005433985684	25652	Economy	7200.00
0005433985693	25652	Economy	7200.00
0005435720821	21255	Economy	10400.00
0005435719563	21255	Economy	9400.00
0005435719565	21255	Economy	9400.00
0005435720820	21255	Economy	9400.00
0005435720139	24772	Economy	9400.00
0005435720137	24772	Economy	9400.00
0005435720138	24772	Economy	9400.00
0005433168347	1624	Economy	17000.00
0005434509181	1624	Economy	17000.00
0005433168359	1624	Economy	17000.00
0005434509186	1624	Economy	15500.00
0005433168346	1624	Economy	15500.00
0005434509187	1624	Economy	15500.00
0005433168339	1624	Economy	15500.00
0005434509191	1624	Economy	15500.00
0005433168350	1624	Economy	15500.00
0005434509182	1624	Economy	15500.00
0005434509185	1624	Economy	15500.00
0005434509188	1624	Economy	15500.00
0005433168345	1624	Economy	15500.00
0005433168349	1624	Economy	15500.00
0005434509184	1624	Economy	15500.00
0005433168342	1624	Economy	15500.00
0005433168370	1624	Economy	15500.00
0005433168354	1624	Economy	15500.00
0005434509190	1624	Economy	15500.00
0005434509183	1624	Economy	15500.00
0005434509193	1624	Economy	15500.00
0005433168344	1624	Economy	15500.00
0005434509192	1624	Economy	15500.00
0005433168355	1624	Economy	15500.00
0005434509189	1624	Economy	15500.00
0005433168343	1624	Economy	15500.00
0005432663016	17827	Business	18000.00
0005432664122	17827	Business	18000.00
0005432655504	17827	Business	18000.00
0005432655518	17827	Economy	6000.00
0005432655498	17827	Economy	6000.00
0005432869563	17827	Economy	6000.00
0005432667454	17827	Economy	6000.00
0005432869560	17827	Economy	6600.00
0005432658579	17827	Economy	6600.00
0005432655517	17827	Economy	6600.00
0005432658592	17827	Economy	6600.00
0005432665273	17827	Economy	6000.00
0005432869566	17827	Economy	6000.00
0005432869567	17827	Economy	6000.00
0005432655481	17827	Economy	6000.00
0005432666374	17827	Economy	6000.00
0005432655493	17827	Economy	6000.00
0005432655448	17827	Economy	6000.00
0005432655505	17827	Economy	6000.00
0005434151721	17827	Economy	6000.00
0005432869561	17827	Economy	6000.00
0005432667455	17827	Economy	6000.00
0005434151722	17827	Economy	6000.00
0005432655497	17827	Economy	6000.00
0005432655492	17827	Economy	6000.00
0005432659704	17827	Economy	6000.00
0005432665274	17827	Economy	6000.00
0005432655447	17827	Economy	6000.00
0005432655455	17827	Economy	6000.00
0005432660810	17827	Economy	6000.00
0005432869565	17827	Economy	6000.00
0005432665275	17827	Economy	6000.00
0005432659703	17827	Economy	6000.00
0005432869562	17827	Economy	6000.00
0005432667444	17827	Economy	6000.00
0005432655488	17827	Economy	6000.00
0005432660809	17827	Economy	6000.00
0005432869564	17827	Economy	6000.00
0005432655582	26335	Business	18000.00
0005432666397	26335	Business	18000.00
0005432667462	26335	Economy	6000.00
0005432655574	26335	Economy	6000.00
0005432667463	26335	Economy	6000.00
0005432869499	26335	Economy	6000.00
0005432869483	26335	Economy	6000.00
0005434151689	26335	Economy	6600.00
0005432655572	26335	Economy	6600.00
0005432655571	26335	Economy	6000.00
0005432658599	26335	Economy	6000.00
0005432660826	26335	Economy	6000.00
0005432869497	26335	Economy	6000.00
0005432666398	26335	Economy	6000.00
0005432655576	26335	Economy	6000.00
0005432655577	26335	Economy	6000.00
0005434151692	26335	Economy	6000.00
0005432655581	26335	Economy	6000.00
0005432657462	26335	Economy	6000.00
0005432655578	26335	Economy	6000.00
0005432666396	26335	Economy	6000.00
0005432665283	26335	Economy	6000.00
0005432869496	26335	Economy	6000.00
0005432655575	26335	Economy	6000.00
0005432657460	26335	Economy	6000.00
0005432660825	26335	Economy	6000.00
0005432655579	26335	Economy	6000.00
0005432655580	26335	Economy	6000.00
0005432655573	26335	Economy	6000.00
0005432869500	26335	Economy	6000.00
0005432659715	26335	Economy	6000.00
0005434151690	26335	Economy	6000.00
0005432665282	26335	Economy	6000.00
0005432869495	26335	Economy	6000.00
0005432869492	26335	Economy	6000.00
0005432657461	26335	Economy	6000.00
0005432869456	26335	Economy	6000.00
0005432639029	25057	Business	87300.00
0005432866052	25057	Business	87300.00
0005432639060	25057	Business	87300.00
0005432866050	25057	Economy	29100.00
0005432639077	25057	Economy	29100.00
0005432639076	25057	Economy	29100.00
0005432866055	25057	Economy	29100.00
0005432639100	25057	Economy	32000.00
0005432866045	25057	Economy	29100.00
0005432866049	25057	Economy	29100.00
0005432866056	25057	Economy	29100.00
0005432639047	25057	Economy	29100.00
0005432639046	25057	Economy	29100.00
0005432866047	25057	Economy	29100.00
0005432639104	25057	Economy	29100.00
0005432866044	25057	Economy	29100.00
0005432639063	25057	Economy	29100.00
0005432866046	25057	Economy	29100.00
0005432639071	25057	Economy	29100.00
0005432639083	25057	Economy	29100.00
0005432866051	25057	Economy	29100.00
0005432639082	25057	Economy	29100.00
0005432639043	25057	Economy	29100.00
0005432866057	25057	Economy	29100.00
0005432866048	25057	Economy	29100.00
0005432866053	25057	Economy	29100.00
0005432639042	25057	Economy	29100.00
0005432866054	25057	Economy	29100.00
0005432639103	25057	Economy	29100.00
0005432639106	25057	Economy	29100.00
0005432905124	3107	Business	16100.00
0005432328965	3107	Business	16100.00
0005432328935	3107	Business	16100.00
0005432905134	3107	Business	16100.00
0005432328927	3107	Business	16100.00
0005432328928	3107	Business	16100.00
0005432328937	3107	Business	16100.00
0005432328929	3107	Business	16100.00
0005432905109	3107	Business	16100.00
0005433438918	3107	Economy	5400.00
0005432328932	3107	Economy	5400.00
0005432328938	3107	Economy	5400.00
0005433438917	3107	Economy	5400.00
0005433438922	3107	Economy	5400.00
0005432328943	3107	Economy	5400.00
0005432328930	3107	Economy	5400.00
0005432328941	3107	Economy	5400.00
0005432328966	3107	Economy	5400.00
0005433438916	3107	Economy	5900.00
0005432328968	3107	Economy	5900.00
0005433438915	3107	Economy	5900.00
0005432328945	3107	Economy	5400.00
0005432328961	3107	Economy	5400.00
0005432905122	3107	Economy	5400.00
0005432328970	3107	Economy	5400.00
0005432328969	3107	Economy	5400.00
0005432328946	3107	Economy	5400.00
0005432328940	3107	Economy	5400.00
0005433438919	3107	Economy	5400.00
0005433438923	3107	Economy	5400.00
0005432328950	3107	Economy	5400.00
0005432328953	3107	Economy	5400.00
0005432328960	3107	Economy	5400.00
0005432328959	3107	Economy	5400.00
0005432328934	3107	Economy	5400.00
0005432328933	3107	Economy	5400.00
0005432328955	3107	Economy	5400.00
0005432328939	3107	Economy	5400.00
0005433438924	3107	Economy	5400.00
0005432328942	3107	Economy	5400.00
0005432328963	3107	Economy	5400.00
0005432328952	3107	Economy	5400.00
0005432328948	3107	Economy	5400.00
0005432905123	3107	Economy	5400.00
0005432328944	3107	Economy	5400.00
0005432905100	3107	Economy	5400.00
0005432287214	3107	Economy	5400.00
0005433438925	3107	Economy	5400.00
0005433438913	3107	Economy	5400.00
0005432287217	3107	Economy	5400.00
0005432328954	3107	Economy	5400.00
0005432905116	3107	Economy	5400.00
0005432905107	3107	Economy	5400.00
0005432287215	3107	Economy	5400.00
0005433438921	3107	Economy	5400.00
0005432905108	3107	Economy	5400.00
0005432328962	3107	Economy	5400.00
0005432287216	3107	Economy	5400.00
0005432328931	3107	Economy	5400.00
0005432328947	3107	Economy	5400.00
0005433438920	3107	Economy	5400.00
0005432287218	3107	Economy	5400.00
0005432328956	3107	Economy	5400.00
0005432328967	3107	Economy	5400.00
0005432328957	3107	Economy	5400.00
0005432328958	3107	Economy	5400.00
0005432328936	3107	Economy	5400.00
0005433438914	3107	Economy	5400.00
0005432328951	3107	Economy	5400.00
0005432905114	3107	Economy	5400.00
0005432328964	3107	Economy	5400.00
0005432328949	3107	Economy	5400.00
0005432328926	3107	Economy	5400.00
0005432328637	31140	Business	16100.00
0005432328521	31140	Business	16100.00
0005432905152	31140	Business	16100.00
0005432328453	31140	Business	16100.00
0005432328586	31140	Business	16100.00
0005433438842	31140	Business	16100.00
0005432054321	31140	Business	16100.00
0005432328624	31140	Business	16100.00
0005432328565	31140	Economy	5400.00
0005432328497	31140	Economy	5400.00
0005432328556	31140	Economy	5400.00
0005432328529	31140	Economy	5400.00
0005432328451	31140	Economy	5400.00
0005432905158	31140	Economy	5400.00
0005432328669	31140	Economy	5400.00
0005432054320	31140	Economy	5900.00
0005432328627	31140	Economy	5900.00
0005432328555	31140	Economy	5900.00
0005432328625	31140	Economy	5400.00
0005432328629	31140	Economy	5400.00
0005433438849	31140	Economy	5400.00
0005432328439	31140	Economy	5400.00
0005432328535	31140	Economy	5400.00
0005432328530	31140	Economy	5400.00
0005432328293	31140	Economy	5400.00
0005432328545	31140	Economy	5400.00
0005432328539	31140	Economy	5400.00
0005432328468	31140	Economy	5400.00
0005432328484	31140	Economy	5400.00
0005432328551	31140	Economy	5400.00
0005432328683	31140	Economy	5400.00
0005432328560	31140	Economy	5400.00
0005432328524	31140	Economy	5400.00
0005432054322	31140	Economy	5400.00
0005432328403	31140	Economy	5400.00
0005432328452	31140	Economy	5400.00
0005432328467	31140	Economy	5400.00
0005432328517	31140	Economy	5400.00
0005432328534	31140	Economy	5400.00
0005432328552	31140	Economy	5400.00
0005432905156	31140	Economy	5400.00
0005433438843	31140	Economy	5400.00
0005432905153	31140	Economy	5400.00
0005432328525	31140	Economy	5400.00
0005432328569	31140	Economy	5400.00
0005432328492	31140	Economy	5400.00
0005433438812	31140	Economy	5400.00
0005432054318	31140	Economy	5400.00
0005432328446	31140	Economy	5400.00
0005432328587	31140	Economy	5400.00
0005432328485	31140	Economy	5400.00
0005432328561	31140	Economy	5400.00
0005432328576	31140	Economy	5400.00
0005432328337	31140	Economy	5400.00
0005432328404	31140	Economy	5400.00
0005432905154	31140	Economy	5400.00
0005432328501	31140	Economy	5400.00
0005432328537	31140	Economy	5400.00
0005432328479	31140	Economy	5400.00
0005432905157	31140	Economy	5400.00
0005432328544	31140	Economy	5400.00
0005432328668	31140	Economy	5400.00
0005432328543	31140	Economy	5400.00
0005432328438	31140	Economy	5400.00
0005432328377	31140	Economy	5400.00
0005432328414	31140	Economy	5400.00
0005432905155	31140	Economy	5400.00
0005432328458	31140	Economy	5400.00
0005432328533	31140	Economy	5400.00
0005432328508	31140	Economy	5400.00
0005432054319	31140	Economy	5400.00
0005434309818	6199	Business	124600.00
0005432146211	6199	Business	124600.00
0005435487838	6199	Business	124600.00
0005435487780	6199	Business	124600.00
0005435487726	6199	Business	124600.00
0005435297004	6199	Business	124600.00
0005434309819	6199	Business	124600.00
0005435487837	6199	Business	124600.00
0005435487743	6199	Economy	41500.00
0005434309817	6199	Economy	41500.00
0005434309811	6199	Economy	41500.00
0005435999348	6199	Economy	41500.00
0005435487753	6199	Economy	41500.00
0005435487665	6199	Economy	41500.00
0005435487760	6199	Economy	41500.00
0005435487664	6199	Economy	41500.00
0005435297016	6199	Economy	41500.00
0005435487661	6199	Economy	41500.00
0005434309821	6199	Economy	41500.00
0005435487803	6199	Economy	41500.00
0005435487678	6199	Economy	41500.00
0005435297010	6199	Economy	41500.00
0005435999353	6199	Economy	41500.00
0005435999335	6199	Economy	41500.00
0005435999352	6199	Economy	41500.00
0005434309808	6199	Economy	41500.00
0005435297015	6199	Economy	41500.00
0005435487690	6199	Economy	41500.00
0005435487763	6199	Economy	41500.00
0005435297013	6199	Economy	41500.00
0005435999347	6199	Economy	41500.00
0005435999346	6199	Economy	45700.00
0005435297036	6199	Economy	45700.00
0005435999338	6199	Economy	45700.00
0005435487759	6199	Economy	45700.00
0005435999350	6199	Economy	45700.00
0005435999343	6199	Economy	41500.00
0005435999342	6199	Economy	41500.00
0005435297014	6199	Economy	41500.00
0005435297023	6199	Economy	41500.00
0005435999340	6199	Economy	41500.00
0005434309810	6199	Economy	41500.00
0005435999349	6199	Economy	41500.00
0005434309816	6199	Economy	41500.00
0005434309809	6199	Economy	41500.00
0005435297005	6199	Economy	41500.00
0005434309813	6199	Economy	41500.00
0005435999354	6199	Economy	41500.00
0005435999336	6199	Economy	41500.00
0005435999337	6199	Economy	41500.00
0005435999351	6199	Economy	41500.00
0005435297059	6199	Economy	41500.00
0005434309820	6199	Economy	41500.00
0005435999355	6199	Economy	41500.00
0005434309815	6199	Economy	41500.00
0005435297047	6199	Economy	41500.00
0005435999345	6199	Economy	41500.00
0005435487752	6199	Economy	41500.00
0005434309812	6199	Economy	41500.00
0005435487725	6199	Economy	41500.00
0005435999356	6199	Economy	41500.00
0005432146210	6199	Economy	41500.00
0005434309814	6199	Economy	41500.00
0005432146209	6199	Economy	41500.00
0005435999344	6199	Economy	41500.00
0005435487728	6199	Economy	41500.00
0005435999339	6199	Economy	41500.00
0005435487705	6199	Economy	41500.00
0005435297058	6199	Economy	41500.00
0005435999341	6199	Economy	41500.00
0005435297011	6199	Economy	41500.00
0005435487713	6199	Economy	41500.00
0005435999129	19558	Business	124600.00
0005435487922	19558	Business	124600.00
0005435487939	19558	Business	124600.00
0005435297095	19558	Business	124600.00
0005435999098	19558	Business	124600.00
0005434309672	19558	Business	124600.00
0005434309730	19558	Economy	41500.00
0005434309673	19558	Economy	41500.00
0005435999230	19558	Economy	41500.00
0005435999195	19558	Economy	41500.00
0005435487920	19558	Economy	41500.00
0005435999196	19558	Economy	41500.00
0005435297098	19558	Economy	41500.00
0005435487933	19558	Economy	41500.00
0005434309676	19558	Economy	41500.00
0005435999172	19558	Economy	41500.00
0005435999223	19558	Economy	41500.00
0005435487929	19558	Economy	41500.00
0005435297094	19558	Economy	41500.00
0005435487925	19558	Economy	41500.00
0005434309630	19558	Economy	41500.00
0005434309631	19558	Economy	41500.00
0005435999177	19558	Economy	41500.00
0005435999154	19558	Economy	41500.00
0005434309748	19558	Economy	41500.00
0005435487938	19558	Economy	41500.00
0005434309678	19558	Economy	41500.00
0005435487927	19558	Economy	45700.00
0005434309658	19558	Economy	45700.00
0005435999145	19558	Economy	45700.00
0005435487931	19558	Economy	45700.00
0005435999100	19558	Economy	41500.00
0005435487924	19558	Economy	41500.00
0005435487935	19558	Economy	41500.00
0005434309670	19558	Economy	41500.00
0005434309718	19558	Economy	41500.00
0005435999155	19558	Economy	41500.00
0005435999146	19558	Economy	41500.00
0005435487940	19558	Economy	41500.00
0005435999142	19558	Economy	41500.00
0005434309596	19558	Economy	41500.00
0005435999115	19558	Economy	41500.00
0005435297093	19558	Economy	41500.00
0005435487926	19558	Economy	41500.00
0005434309677	19558	Economy	41500.00
0005434309693	19558	Economy	41500.00
0005435487923	19558	Economy	41500.00
0005435999114	19558	Economy	41500.00
0005435999171	19558	Economy	41500.00
0005435999156	19558	Economy	41500.00
0005435999236	19558	Economy	41500.00
0005435999194	19558	Economy	41500.00
0005435999170	19558	Economy	41500.00
0005435487937	19558	Economy	41500.00
0005435297097	19558	Economy	41500.00
0005435487934	19558	Economy	41500.00
0005435487928	19558	Economy	41500.00
0005434309671	19558	Economy	41500.00
0005435487936	19558	Economy	41500.00
0005435487919	19558	Economy	41500.00
0005435487930	19558	Economy	41500.00
0005435487932	19558	Economy	41500.00
0005435999099	19558	Economy	41500.00
0005435487921	19558	Economy	41500.00
0005435297092	19558	Economy	41500.00
0005435297096	19558	Economy	41500.00
0005435518007	1578	Business	86000.00
0005435502420	1578	Business	86000.00
0005435517997	1578	Business	86000.00
0005434565983	1578	Business	86000.00
0005434565989	1578	Business	86000.00
0005434565988	1578	Business	86000.00
0005435502422	1578	Business	86000.00
0005434565992	1578	Economy	28700.00
0005435502438	1578	Economy	28700.00
0005435518015	1578	Economy	28700.00
0005435508406	1578	Economy	28700.00
0005434565980	1578	Economy	28700.00
0005432291942	1578	Economy	28700.00
0005435502436	1578	Economy	28700.00
0005435508410	1578	Economy	28700.00
0005435508409	1578	Economy	28700.00
0005435518006	1578	Economy	31500.00
0005435508408	1578	Economy	31500.00
0005435502430	1578	Economy	31500.00
0005435518002	1578	Economy	28700.00
0005435502426	1578	Economy	28700.00
0005434565987	1578	Economy	28700.00
0005435517998	1578	Economy	28700.00
0005433186060	1578	Economy	28700.00
0005435518008	1578	Economy	28700.00
0005435508413	1578	Economy	28700.00
0005435518004	1578	Economy	28700.00
0005435502433	1578	Economy	28700.00
0005435502437	1578	Economy	28700.00
0005435518011	1578	Economy	28700.00
0005435502435	1578	Economy	28700.00
0005435502425	1578	Economy	28700.00
0005435508416	1578	Economy	28700.00
0005435502428	1578	Economy	28700.00
0005435518005	1578	Economy	28700.00
0005434565993	1578	Economy	28700.00
0005435508411	1578	Economy	28700.00
0005434565982	1578	Economy	28700.00
0005435517999	1578	Economy	28700.00
0005433186106	1578	Economy	28700.00
0005435502429	1578	Economy	28700.00
0005435518014	1578	Economy	28700.00
0005435502431	1578	Economy	28700.00
0005435502440	1578	Economy	28700.00
0005435518001	1578	Economy	28700.00
0005434565986	1578	Economy	28700.00
0005433186097	1578	Economy	28700.00
0005435508407	1578	Economy	28700.00
0005432291943	1578	Economy	28700.00
0005435518013	1578	Economy	28700.00
0005433186107	1578	Economy	28700.00
0005435502423	1578	Economy	28700.00
0005434565984	1578	Economy	28700.00
0005435502427	1578	Economy	28700.00
0005435518012	1578	Economy	28700.00
0005435508415	1578	Economy	28700.00
0005435502439	1578	Economy	28700.00
0005435518010	1578	Economy	28700.00
0005435518009	1578	Economy	28700.00
0005435502424	1578	Economy	28700.00
0005434565990	1578	Economy	28700.00
0005435518000	1578	Economy	28700.00
0005435502434	1578	Economy	28700.00
0005435518003	1578	Economy	28700.00
0005435508412	1578	Economy	28700.00
0005435502432	1578	Economy	28700.00
0005435508414	1578	Economy	28700.00
0005434565981	1578	Economy	28700.00
0005434565991	1578	Economy	28700.00
0005434565985	1578	Economy	28700.00
0005435502421	1578	Economy	28700.00
0005435545706	20879	Business	86000.00
0005435529133	20879	Business	86000.00
0005435529191	20879	Business	86000.00
0005435502298	20879	Business	86000.00
0005435529134	20879	Business	86000.00
0005434565892	20879	Business	86000.00
0005435529101	20879	Business	86000.00
0005435502117	20879	Business	86000.00
0005435529190	20879	Business	86000.00
0005433186166	20879	Business	86000.00
0005435502266	20879	Economy	28700.00
0005435545694	20879	Economy	28700.00
0005435529063	20879	Economy	28700.00
0005435502210	20879	Economy	28700.00
0005435545708	20879	Economy	28700.00
0005435529167	20879	Economy	28700.00
0005435545696	20879	Economy	28700.00
0005435502213	20879	Economy	28700.00
0005435502184	20879	Economy	31500.00
0005433186161	20879	Economy	31500.00
0005435529138	20879	Economy	31500.00
0005433186164	20879	Economy	31500.00
0005435545713	20879	Economy	28700.00
0005435502128	20879	Economy	28700.00
0005435545647	20879	Economy	28700.00
0005435529088	20879	Economy	28700.00
0005435502198	20879	Economy	28700.00
0005435545711	20879	Economy	28700.00
0005435545703	20879	Economy	28700.00
0005434565821	20879	Economy	28700.00
0005435529195	20879	Economy	28700.00
0005434565822	20879	Economy	28700.00
0005435502223	20879	Economy	28700.00
0005435502185	20879	Economy	28700.00
0005435502267	20879	Economy	28700.00
0005435502212	20879	Economy	28700.00
0005435529166	20879	Economy	28700.00
0005435545695	20879	Economy	28700.00
0005435502127	20879	Economy	28700.00
0005435545722	20879	Economy	28700.00
0005433186167	20879	Economy	28700.00
0005435529202	20879	Economy	28700.00
0005435502155	20879	Economy	28700.00
0005435529160	20879	Economy	28700.00
0005435529205	20879	Economy	28700.00
0005435502156	20879	Economy	28700.00
0005434565868	20879	Economy	28700.00
0005435502288	20879	Economy	28700.00
0005434565823	20879	Economy	28700.00
0005435529102	20879	Economy	28700.00
0005435529115	20879	Economy	28700.00
0005435529168	20879	Economy	28700.00
0005435502250	20879	Economy	28700.00
0005435545646	20879	Economy	28700.00
0005435545714	20879	Economy	28700.00
0005434565884	20879	Economy	28700.00
0005435529117	20879	Economy	28700.00
0005435529161	20879	Economy	28700.00
0005435545658	20879	Economy	28700.00
0005435502208	20879	Economy	28700.00
0005433186163	20879	Economy	28700.00
0005435529093	20879	Economy	28700.00
0005435502201	20879	Economy	28700.00
0005434565824	20879	Economy	28700.00
0005435545718	20879	Economy	28700.00
0005433186168	20879	Economy	28700.00
0005435545705	20879	Economy	28700.00
0005435529069	20879	Economy	28700.00
0005435529056	20879	Economy	28700.00
0005435502218	20879	Economy	28700.00
0005435529165	20879	Economy	28700.00
0005435502230	20879	Economy	28700.00
0005433186162	20879	Economy	28700.00
0005435529116	20879	Economy	28700.00
0005433186165	20879	Economy	28700.00
0005435502116	20879	Economy	28700.00
0005435529094	20879	Economy	28700.00
0005435529137	20879	Economy	28700.00
0005434565883	20879	Economy	28700.00
0005434565877	20879	Economy	28700.00
0005435502217	20879	Economy	28700.00
0005435529146	20879	Economy	28700.00
0005435153780	3930	Economy	19700.00
0005435153776	3930	Economy	19700.00
0005435153775	3930	Economy	19700.00
0005435931605	3930	Economy	19700.00
0005435153777	3930	Economy	19700.00
0005435153778	3930	Economy	19700.00
0005435153779	3930	Economy	19700.00
0005435153774	3930	Economy	19700.00
0005435153697	21870	Economy	19700.00
0005435153698	21870	Economy	19700.00
0005435153712	21870	Economy	19700.00
0005435931620	21870	Economy	19700.00
0005435153726	21870	Economy	19700.00
0005435931621	21870	Economy	19700.00
0005435931622	21870	Economy	19700.00
0005435153717	21870	Economy	19700.00
0005435153739	21870	Economy	19700.00
0005435931623	21870	Economy	19700.00
0005432628933	7197	Economy	14300.00
0005432628924	7197	Economy	13000.00
0005432628928	7197	Economy	13000.00
0005432628920	7197	Economy	13000.00
0005432628925	7197	Economy	13000.00
0005432628930	7197	Economy	13000.00
0005432628919	7197	Economy	13000.00
0005432628921	7197	Economy	13000.00
0005432628922	7197	Economy	13000.00
0005435225526	7197	Economy	13000.00
0005435225580	7197	Economy	13000.00
0005432628927	7197	Economy	13000.00
0005432628923	7197	Economy	13000.00
0005432628931	7197	Economy	13000.00
0005435225525	7197	Economy	13000.00
0005432628929	7197	Economy	13000.00
0005432628934	7197	Economy	13000.00
0005432628932	7197	Economy	13000.00
0005435225544	7197	Economy	13000.00
0005432628926	7197	Economy	13000.00
0005432628834	28096	Economy	14300.00
0005432628825	28096	Economy	14300.00
0005435225629	28096	Economy	13000.00
0005432628736	28096	Economy	13000.00
0005432628838	28096	Economy	13000.00
0005435225626	28096	Economy	13000.00
0005432628870	28096	Economy	13000.00
0005432628820	28096	Economy	13000.00
0005435225631	28096	Economy	13000.00
0005435225632	28096	Economy	13000.00
0005432628847	28096	Economy	13000.00
0005432628821	28096	Economy	13000.00
0005435225624	28096	Economy	13000.00
0005432628861	28096	Economy	13000.00
0005432628789	28096	Economy	13000.00
0005435225630	28096	Economy	13000.00
0005432628850	28096	Economy	13000.00
0005435225625	28096	Economy	13000.00
0005435225627	28096	Economy	13000.00
0005435225628	28096	Economy	13000.00
0005432628833	28096	Economy	13000.00
0005432628869	28096	Economy	13000.00
0005432628835	28096	Economy	13000.00
0005432628826	28096	Economy	13000.00
0005434267947	8718	Economy	11500.00
0005435960071	8718	Economy	10500.00
0005435960070	8718	Economy	10500.00
0005435960072	8718	Economy	10500.00
0005434267946	8718	Economy	10500.00
0005435960073	8718	Economy	10500.00
0005434267969	15242	Economy	10500.00
0005434267972	15242	Economy	10500.00
0005435960042	15242	Economy	10500.00
0005434267968	15242	Economy	10500.00
0005435960043	15242	Economy	10500.00
0005434267973	15242	Economy	10500.00
0005434267971	15242	Economy	10500.00
0005435960037	15242	Economy	10500.00
0005434267970	15242	Economy	10500.00
0005432677592	1211	Business	115000.00
0005432675212	1211	Business	115000.00
0005432693195	1211	Business	115000.00
0005432873271	1211	Business	115000.00
0005432693219	1211	Business	115000.00
0005432873267	1211	Business	115000.00
0005432675213	1211	Business	115000.00
0005432873268	1211	Business	115000.00
0005432675210	1211	Business	115000.00
0005432693207	1211	Business	115000.00
0005432693210	1211	Business	115000.00
0005432675207	1211	Economy	38300.00
0005432677593	1211	Economy	38300.00
0005432693201	1211	Economy	38300.00
0005432675209	1211	Economy	38300.00
0005432693206	1211	Economy	38300.00
0005432873280	1211	Economy	38300.00
0005432693200	1211	Economy	38300.00
0005432693212	1211	Economy	42200.00
0005432675217	1211	Economy	38300.00
0005432693216	1211	Economy	38300.00
0005432677590	1211	Economy	38300.00
0005432693214	1211	Economy	38300.00
0005432693218	1211	Economy	38300.00
0005432677589	1211	Economy	38300.00
0005432693217	1211	Economy	38300.00
0005432693213	1211	Economy	38300.00
0005432675211	1211	Economy	38300.00
0005432677591	1211	Economy	38300.00
0005432675215	1211	Economy	38300.00
0005432675206	1211	Economy	38300.00
0005432675219	1211	Economy	38300.00
0005432693222	1211	Economy	38300.00
0005432693220	1211	Economy	38300.00
0005432693191	1211	Economy	38300.00
0005432873272	1211	Economy	38300.00
0005432693221	1211	Economy	38300.00
0005432693211	1211	Economy	38300.00
0005432693199	1211	Economy	38300.00
0005432873270	1211	Economy	38300.00
0005432675205	1211	Economy	38300.00
0005432873273	1211	Economy	38300.00
0005432675221	1211	Economy	38300.00
0005432693192	1211	Economy	38300.00
0005432675218	1211	Economy	38300.00
0005432693202	1211	Economy	38300.00
0005432693196	1211	Economy	38300.00
0005432675208	1211	Economy	38300.00
0005432693190	1211	Economy	38300.00
0005432693203	1211	Economy	38300.00
0005432693209	1211	Economy	38300.00
0005432693197	1211	Economy	38300.00
0005432693193	1211	Economy	38300.00
0005432873269	1211	Economy	38300.00
0005432693198	1211	Economy	38300.00
0005432693204	1211	Economy	38300.00
0005432675220	1211	Economy	38300.00
0005432693208	1211	Economy	38300.00
0005432693215	1211	Economy	38300.00
0005432693205	1211	Economy	38300.00
0005432873279	1211	Economy	38300.00
0005432675214	1211	Economy	38300.00
0005432693194	1211	Economy	38300.00
0005432675216	1211	Economy	38300.00
0005432675098	17494	Business	115000.00
0005432675113	17494	Business	115000.00
0005432692827	17494	Business	115000.00
0005432693046	17494	Business	115000.00
0005432675110	17494	Business	115000.00
0005432674998	17494	Business	115000.00
0005432675109	17494	Business	115000.00
0005432692980	17494	Business	115000.00
0005432873332	17494	Business	115000.00
0005432692991	17494	Business	115000.00
0005432677544	17494	Business	115000.00
0005432675069	17494	Business	115000.00
0005432693000	17494	Economy	38300.00
0005432692984	17494	Economy	38300.00
0005432675057	17494	Economy	38300.00
0005432677538	17494	Economy	38300.00
0005432873333	17494	Economy	38300.00
0005432692840	17494	Economy	38300.00
0005432692826	17494	Economy	38300.00
0005432675079	17494	Economy	42200.00
0005432692786	17494	Economy	42200.00
0005432692784	17494	Economy	42200.00
0005432692935	17494	Economy	38300.00
0005432692969	17494	Economy	38300.00
0005432693006	17494	Economy	38300.00
0005432675064	17494	Economy	38300.00
0005432677537	17494	Economy	38300.00
0005432873330	17494	Economy	38300.00
0005432692925	17494	Economy	38300.00
0005432692986	17494	Economy	38300.00
0005432675091	17494	Economy	38300.00
0005432692839	17494	Economy	38300.00
0005432675112	17494	Economy	38300.00
0005432873329	17494	Economy	38300.00
0005432675058	17494	Economy	38300.00
0005432692894	17494	Economy	38300.00
0005432692785	17494	Economy	38300.00
0005432692929	17494	Economy	38300.00
0005432692897	17494	Economy	38300.00
0005432692946	17494	Economy	38300.00
0005432692853	17494	Economy	38300.00
0005432692898	17494	Economy	38300.00
0005432677560	17494	Economy	38300.00
0005432692787	17494	Economy	38300.00
0005432692854	17494	Economy	38300.00
0005432675111	17494	Economy	38300.00
0005432692848	17494	Economy	38300.00
0005432873328	17494	Economy	38300.00
0005432692934	17494	Economy	38300.00
0005432692694	17494	Economy	38300.00
0005432692937	17494	Economy	38300.00
0005432692900	17494	Economy	38300.00
0005432873331	17494	Economy	38300.00
0005432675068	17494	Economy	38300.00
0005432692906	17494	Economy	38300.00
0005432873327	17494	Economy	38300.00
0005432873326	17494	Economy	38300.00
0005432677561	17494	Economy	38300.00
0005432692990	17494	Economy	38300.00
0005434435260	1109	Economy	15200.00
0005433156743	1109	Economy	15200.00
0005433156735	1109	Economy	15200.00
0005433156722	1109	Economy	13900.00
0005434435262	1109	Economy	13900.00
0005434435267	1109	Economy	13900.00
0005434435258	1109	Economy	13900.00
0005433156744	1109	Economy	13900.00
0005434435265	1109	Economy	13900.00
0005434435257	1109	Economy	13900.00
0005433156726	1109	Economy	13900.00
0005434435271	1109	Economy	13900.00
0005434435264	1109	Economy	13900.00
0005434435259	1109	Economy	13900.00
0005434435269	1109	Economy	13900.00
0005433156678	1109	Economy	13900.00
0005434435268	1109	Economy	13900.00
0005434435270	1109	Economy	13900.00
0005434435266	1109	Economy	13900.00
0005433156709	1109	Economy	13900.00
0005434435256	1109	Economy	13900.00
0005433156734	1109	Economy	13900.00
0005433156729	1109	Economy	13900.00
0005434435263	1109	Economy	13900.00
0005434435261	1109	Economy	13900.00
0005433156730	1109	Economy	13900.00
0005433156792	17287	Economy	13900.00
0005434435176	17287	Economy	13900.00
0005434435140	17287	Economy	13900.00
0005433156798	17287	Economy	13900.00
0005433156797	17287	Economy	13900.00
0005434435105	17287	Economy	13900.00
0005433156793	17287	Economy	13900.00
0005433156794	17287	Economy	13900.00
0005433156795	17287	Economy	13900.00
0005434435069	17287	Economy	13900.00
0005434435160	17287	Economy	13900.00
0005434435178	17287	Economy	13900.00
0005433156796	17287	Economy	13900.00
0005434435180	17287	Economy	13900.00
0005434435113	17287	Economy	13900.00
0005434435081	17287	Economy	13900.00
0005434435079	17287	Economy	13900.00
0005433156799	17287	Economy	13900.00
0005434435147	17287	Economy	13900.00
0005433156791	17287	Economy	13900.00
0005434435150	17287	Economy	13900.00
0005435086876	4094	Economy	8200.00
0005435086877	4094	Economy	7500.00
0005435928131	4094	Economy	7500.00
0005435928111	4094	Economy	7500.00
0005435086875	4094	Economy	7500.00
0005435086874	4094	Economy	7500.00
0005435086872	4094	Economy	7500.00
0005435086871	4094	Economy	7500.00
0005435086873	4094	Economy	7500.00
0005435928130	4094	Economy	7500.00
0005435086879	4094	Economy	7500.00
0005435928112	4094	Economy	7500.00
0005435086878	4094	Economy	7500.00
0005435928169	24405	Economy	7500.00
0005435928166	24405	Economy	7500.00
0005435928168	24405	Economy	7500.00
0005435086797	24405	Economy	7500.00
0005435928170	24405	Economy	7500.00
0005435928172	24405	Economy	7500.00
0005435086812	24405	Economy	7500.00
0005435928171	24405	Economy	7500.00
0005435086796	24405	Economy	7500.00
0005435928167	24405	Economy	7500.00
0005434964326	1317	Business	203300.00
0005434964338	1317	Business	203300.00
0005433261517	1317	Business	203300.00
0005434964343	1317	Business	203300.00
0005432279284	1317	Business	203300.00
0005432279283	1317	Business	203300.00
0005433261464	1317	Business	203300.00
0005434964327	1317	Business	203300.00
0005433261487	1317	Business	203300.00
0005433261519	1317	Business	203300.00
0005433261532	1317	Business	203300.00
0005434964321	1317	Business	203300.00
0005434964340	1317	Economy	74500.00
0005434964317	1317	Business	203300.00
0005433261520	1317	Economy	67800.00
0005434964337	1317	Economy	67800.00
0005433261507	1317	Economy	67800.00
0005434964335	1317	Economy	67800.00
0005433261496	1317	Economy	67800.00
0005433261497	1317	Economy	67800.00
0005434964334	1317	Economy	67800.00
0005434964309	1317	Economy	67800.00
0005434964341	1317	Economy	67800.00
0005433261534	1317	Economy	67800.00
0005434964329	1317	Economy	67800.00
0005434964308	1317	Economy	67800.00
0005432279282	1317	Economy	67800.00
0005434964315	1317	Economy	67800.00
0005432279281	1317	Economy	67800.00
0005434964330	1317	Economy	67800.00
0005433261538	1317	Economy	67800.00
0005434964332	1317	Economy	67800.00
0005433261547	1317	Economy	67800.00
0005434964313	1317	Economy	67800.00
0005433261516	1317	Economy	67800.00
0005434964311	1317	Economy	67800.00
0005434964328	1317	Economy	67800.00
0005434964314	1317	Economy	67800.00
0005434964336	1317	Economy	67800.00
0005434964323	1317	Economy	67800.00
0005433261504	1317	Economy	67800.00
0005434964325	1317	Economy	67800.00
0005434964305	1317	Economy	67800.00
0005434964324	1317	Economy	74500.00
0005434964312	1317	Economy	74500.00
0005434964331	1317	Economy	67800.00
0005433261554	1317	Economy	67800.00
0005433261535	1317	Economy	67800.00
0005434964342	1317	Economy	67800.00
0005433261525	1317	Economy	67800.00
0005433261569	1317	Economy	67800.00
0005434964322	1317	Economy	67800.00
0005434964307	1317	Economy	67800.00
0005433261523	1317	Economy	67800.00
0005434964306	1317	Economy	67800.00
0005433261495	1317	Economy	67800.00
0005433261522	1317	Economy	67800.00
0005433261546	1317	Economy	67800.00
0005434964310	1317	Economy	67800.00
0005434964320	1317	Economy	67800.00
0005432279280	1317	Economy	67800.00
0005433261518	1317	Economy	67800.00
0005434964339	1317	Economy	67800.00
0005433261570	1317	Economy	67800.00
0005434964333	1317	Economy	67800.00
0005434964318	1317	Economy	67800.00
0005433261561	1317	Economy	67800.00
0005434964319	1317	Economy	67800.00
0005434964316	1317	Economy	67800.00
0005433261521	1317	Economy	67800.00
0005434964146	18246	Business	203300.00
0005434964190	18246	Business	203300.00
0005433261613	18246	Business	203300.00
0005434964144	18246	Business	203300.00
0005434964165	18246	Business	203300.00
0005434964145	18246	Business	203300.00
0005434964093	18246	Business	203300.00
0005434964253	18246	Business	203300.00
0005434964202	18246	Business	203300.00
0005433261624	18246	Business	203300.00
0005434964097	18246	Business	203300.00
0005433261609	18246	Business	203300.00
0005434964048	18246	Business	203300.00
0005433261626	18246	Economy	74500.00
0005433261612	18246	Economy	67800.00
0005433261610	18246	Economy	67800.00
0005434964130	18246	Economy	67800.00
0005433261614	18246	Economy	67800.00
0005434964098	18246	Economy	67800.00
0005434964187	18246	Economy	67800.00
0005434964178	18246	Economy	67800.00
0005433261617	18246	Economy	67800.00
0005434964194	18246	Economy	67800.00
0005434964153	18246	Economy	67800.00
0005433261611	18246	Economy	67800.00
0005433261616	18246	Economy	67800.00
0005433261608	18246	Economy	67800.00
0005434964125	18246	Economy	67800.00
0005433261622	18246	Economy	67800.00
0005434964148	18246	Economy	67800.00
0005434964100	18246	Economy	67800.00
0005433261619	18246	Economy	67800.00
0005434964185	18246	Economy	67800.00
0005434964155	18246	Economy	67800.00
0005434964071	18246	Economy	67800.00
0005434964055	18246	Economy	67800.00
0005433261621	18246	Economy	67800.00
0005434964072	18246	Economy	67800.00
0005433261618	18246	Economy	67800.00
0005433261623	18246	Economy	67800.00
0005434964210	18246	Economy	67800.00
0005434964081	18246	Economy	67800.00
0005434964166	18246	Economy	67800.00
0005434964193	18246	Economy	67800.00
0005433261620	18246	Economy	67800.00
0005434964150	18246	Economy	67800.00
0005434964154	18246	Economy	67800.00
0005434964189	18246	Economy	67800.00
0005434964167	18246	Economy	67800.00
0005434964151	18246	Economy	67800.00
0005434964195	18246	Economy	67800.00
0005433261625	18246	Economy	67800.00
0005434964188	18246	Economy	67800.00
0005434964186	18246	Economy	67800.00
0005434964129	18246	Economy	67800.00
0005434964147	18246	Economy	67800.00
0005434964061	18246	Economy	67800.00
0005434964134	18246	Economy	67800.00
0005434964133	18246	Economy	67800.00
0005434964022	18246	Economy	67800.00
0005434964132	18246	Economy	67800.00
0005434964203	18246	Economy	67800.00
0005434964152	18246	Economy	67800.00
0005433261615	18246	Economy	67800.00
0005434964171	18246	Economy	67800.00
0005435907500	4855	Business	44200.00
0005433194855	4855	Economy	14700.00
0005434626013	4855	Economy	14700.00
0005434626007	4855	Economy	14700.00
0005434626014	4855	Economy	16200.00
0005434626016	4855	Economy	16200.00
0005434626008	4855	Economy	16200.00
0005434626015	4855	Economy	14700.00
0005434626010	4855	Economy	14700.00
0005433194843	4855	Economy	14700.00
0005435907492	4855	Economy	14700.00
0005434626009	4855	Economy	14700.00
0005434626012	4855	Economy	14700.00
0005435907501	4855	Economy	14700.00
0005435907486	4855	Economy	14700.00
0005435907507	4855	Economy	14700.00
0005435907487	4855	Economy	14700.00
0005434626011	4855	Economy	14700.00
0005435907499	4855	Economy	14700.00
0005435907505	4855	Economy	14700.00
0005435907491	4855	Economy	14700.00
0005434625965	32912	Business	44200.00
0005434625918	32912	Business	44200.00
0005435907528	32912	Business	44200.00
0005435907529	32912	Economy	14700.00
0005435907527	32912	Economy	16200.00
0005434625922	32912	Economy	14700.00
0005435907526	32912	Economy	14700.00
0005434625924	32912	Economy	14700.00
0005434625919	32912	Economy	14700.00
0005434625951	32912	Economy	14700.00
0005434625960	32912	Economy	14700.00
0005433194861	32912	Economy	14700.00
0005434625938	32912	Economy	14700.00
0005434625937	32912	Economy	14700.00
0005434625945	32912	Economy	14700.00
0005435907530	32912	Economy	14700.00
0005434625959	32912	Economy	14700.00
0005435907531	32912	Economy	14700.00
0005435785233	13802	Economy	3400.00
0005435785232	13802	Economy	3400.00
0005435785069	13802	Economy	3400.00
0005435785174	13802	Economy	3400.00
0005435785029	13802	Economy	3100.00
0005435785197	13802	Economy	3100.00
0005435785236	13802	Economy	3100.00
0005435785079	13802	Economy	3100.00
0005435785235	13802	Economy	3100.00
0005435785160	13802	Economy	3100.00
0005435785265	13802	Economy	3100.00
0005435787341	13802	Economy	3100.00
0005435787327	13802	Economy	3100.00
0005435785030	13802	Economy	3100.00
0005435785163	13802	Economy	3100.00
0005435785191	13802	Economy	3100.00
0005435785200	13802	Economy	3100.00
0005435785180	13802	Economy	3100.00
0005435785164	13802	Economy	3100.00
0005435785280	13802	Economy	3100.00
0005435785080	13802	Economy	3100.00
0005435785231	13802	Economy	3100.00
0005435787353	13802	Economy	3100.00
0005435785256	13802	Economy	3100.00
0005435787337	13802	Economy	3100.00
0005435785266	13802	Economy	3100.00
0005435784991	13802	Economy	3100.00
0005435785186	13802	Economy	3100.00
0005435785155	13802	Economy	3100.00
0005435937401	13802	Economy	3100.00
0005435785140	13802	Economy	3100.00
0005435785165	13802	Economy	3100.00
0005435785229	13802	Economy	3100.00
0005435785198	13802	Economy	3100.00
0005435787351	13802	Economy	3100.00
0005435785255	13802	Economy	3100.00
0005435785324	13802	Economy	3100.00
0005435937400	13802	Economy	3100.00
0005435787336	13802	Economy	3100.00
0005435785241	13802	Economy	3100.00
0005435785141	13802	Economy	3100.00
0005432195704	13802	Economy	3100.00
0005435785154	13802	Economy	3100.00
0005435785068	13802	Economy	3100.00
0005435785072	13802	Economy	3100.00
0005435785139	13802	Economy	3100.00
0005435785073	13802	Economy	3100.00
0005435785234	13802	Economy	3100.00
0005435787352	13802	Economy	3100.00
0005435937356	27397	Economy	3400.00
0005435785478	27397	Economy	3400.00
0005435785482	27397	Economy	3400.00
0005435785480	27397	Economy	3400.00
0005435785499	27397	Economy	3100.00
0005432190644	27397	Economy	3100.00
0005435785473	27397	Economy	3100.00
0005435785500	27397	Economy	3100.00
0005435785472	27397	Economy	3100.00
0005435785493	27397	Economy	3100.00
0005435785506	27397	Economy	3100.00
0005435937349	27397	Economy	3100.00
0005435785477	27397	Economy	3100.00
0005435785486	27397	Economy	3100.00
0005435785474	27397	Economy	3100.00
0005435785483	27397	Economy	3100.00
0005435785498	27397	Economy	3100.00
0005432190645	27397	Economy	3100.00
0005435785501	27397	Economy	3100.00
0005435785475	27397	Economy	3100.00
0005435787363	27397	Economy	3100.00
0005435785485	27397	Economy	3100.00
0005435785492	27397	Economy	3100.00
0005435785504	27397	Economy	3100.00
0005435787362	27397	Economy	3100.00
0005435785505	27397	Economy	3100.00
0005435785488	27397	Economy	3100.00
0005435785479	27397	Economy	3100.00
0005435785481	27397	Economy	3100.00
0005435785476	27397	Economy	3100.00
0005432190642	27397	Economy	3100.00
0005435785489	27397	Economy	3100.00
0005435785497	27397	Economy	3100.00
0005435785491	27397	Economy	3100.00
0005435785494	27397	Economy	3100.00
0005435785496	27397	Economy	3100.00
0005435785484	27397	Economy	3100.00
0005435787364	27397	Economy	3100.00
0005435785502	27397	Economy	3100.00
0005435785490	27397	Economy	3100.00
0005435787361	27397	Economy	3100.00
0005432190643	27397	Economy	3100.00
0005435785487	27397	Economy	3100.00
0005435785471	27397	Economy	3100.00
0005435785503	27397	Economy	3100.00
0005435785495	27397	Economy	3100.00
0005435937337	27397	Economy	3100.00
0005435311131	20283	Business	12000.00
0005434407655	20283	Business	12000.00
0005434407704	20283	Business	12000.00
0005434407547	20283	Business	12000.00
0005434407405	20283	Business	12000.00
0005434407567	20283	Business	12000.00
0005434407654	20283	Business	12000.00
0005435311124	20283	Business	12000.00
0005434407469	20283	Business	12000.00
0005434407664	20283	Business	12000.00
0005434407579	20283	Business	12000.00
0005434407531	20283	Economy	4000.00
0005435311126	20283	Economy	4000.00
0005434407737	20283	Economy	4000.00
0005434407614	20283	Economy	4000.00
0005434407716	20283	Economy	4000.00
0005434407482	20283	Economy	4000.00
0005435311120	20283	Economy	4000.00
0005435311137	20283	Economy	4400.00
0005434407336	20283	Economy	4400.00
0005434407419	20283	Economy	4400.00
0005434407424	20283	Economy	4400.00
0005434407701	20283	Economy	4400.00
0005434407662	20283	Economy	4000.00
0005434407468	20283	Economy	4000.00
0005434407717	20283	Economy	4000.00
0005435311128	20283	Economy	4000.00
0005435311136	20283	Economy	4000.00
0005434407406	20283	Economy	4000.00
0005434407580	20283	Economy	4000.00
0005434407425	20283	Economy	4000.00
0005435311115	20283	Economy	4000.00
0005434407732	20283	Economy	4000.00
0005434407349	20283	Economy	4000.00
0005434407339	20283	Economy	4000.00
0005434407712	20283	Economy	4000.00
0005434407511	20283	Economy	4000.00
0005434407393	20283	Economy	4000.00
0005434407607	20283	Economy	4000.00
0005434407731	20283	Economy	4000.00
0005435311133	20283	Economy	4000.00
0005434407532	20283	Economy	4000.00
0005435311135	20283	Economy	4000.00
0005432058403	20283	Economy	4000.00
0005434407615	20283	Economy	4000.00
0005434407514	20283	Economy	4000.00
0005434407733	20283	Economy	4000.00
0005435311117	20283	Economy	4000.00
0005435311129	20283	Economy	4000.00
0005435311130	20283	Economy	4000.00
0005434407338	20283	Economy	4000.00
0005434407574	20283	Economy	4000.00
0005435311116	20283	Economy	4000.00
0005434407522	20283	Economy	4000.00
0005434407599	20283	Economy	4000.00
0005434407534	20283	Economy	4000.00
0005434407544	20283	Economy	4000.00
0005432058404	20283	Economy	4000.00
0005434407606	20283	Economy	4000.00
0005435311123	20283	Economy	4000.00
0005432058402	20283	Economy	4000.00
0005434407526	20283	Economy	4000.00
0005435311125	20283	Economy	4000.00
0005434407432	20283	Economy	4000.00
0005434407578	20283	Economy	4000.00
0005434407306	20283	Economy	4000.00
0005435311127	20283	Economy	4000.00
0005434407548	20283	Economy	4000.00
0005434407600	20283	Economy	4000.00
0005434407605	20283	Economy	4000.00
0005435311118	20283	Economy	4000.00
0005435311122	20283	Economy	4000.00
0005435311134	20283	Economy	4000.00
0005434407746	20283	Economy	4000.00
0005434407705	20283	Economy	4000.00
0005434407617	20283	Economy	4000.00
0005434407575	20283	Economy	4000.00
0005434407356	20283	Economy	4000.00
0005435311119	20283	Economy	4000.00
0005435311121	20283	Economy	4000.00
0005435311132	20283	Economy	4000.00
0005434407556	20283	Economy	4000.00
0005434407415	20283	Economy	4000.00
0005432153971	27007	Business	12000.00
0005434408064	27007	Business	12000.00
0005434408089	27007	Business	12000.00
0005435310995	27007	Business	12000.00
0005434408060	27007	Business	12000.00
0005434408087	27007	Business	12000.00
0005434408081	27007	Business	12000.00
0005435311009	27007	Business	12000.00
0005435310964	27007	Business	12000.00
0005435310974	27007	Business	12000.00
0005434408117	27007	Business	12000.00
0005432153974	27007	Business	12000.00
0005432153972	27007	Economy	4000.00
0005434408078	27007	Economy	4000.00
0005434408105	27007	Economy	4000.00
0005432153973	27007	Economy	4000.00
0005435310994	27007	Economy	4000.00
0005434408104	27007	Economy	4000.00
0005435311011	27007	Economy	4000.00
0005434408121	27007	Economy	4000.00
0005434408111	27007	Economy	4000.00
0005435311000	27007	Economy	4400.00
0005432153975	27007	Economy	4400.00
0005434408085	27007	Economy	4400.00
0005434408068	27007	Economy	4400.00
0005434408100	27007	Economy	4400.00
0005434408086	27007	Economy	4000.00
0005434408093	27007	Economy	4000.00
0005432153978	27007	Economy	4000.00
0005434408070	27007	Economy	4000.00
0005434408074	27007	Economy	4000.00
0005435310978	27007	Economy	4000.00
0005434408109	27007	Economy	4000.00
0005434408072	27007	Economy	4000.00
0005434408083	27007	Economy	4000.00
0005434408088	27007	Economy	4000.00
0005434408113	27007	Economy	4000.00
0005434408098	27007	Economy	4000.00
0005434408066	27007	Economy	4000.00
0005435311012	27007	Economy	4000.00
0005434408080	27007	Economy	4000.00
0005434408110	27007	Economy	4000.00
0005434408119	27007	Economy	4000.00
0005434408107	27007	Economy	4000.00
0005434408115	27007	Economy	4000.00
0005434408114	27007	Economy	4000.00
0005434408122	27007	Economy	4000.00
0005435310965	27007	Economy	4000.00
0005435311005	27007	Economy	4000.00
0005434408061	27007	Economy	4000.00
0005434408095	27007	Economy	4000.00
0005435311007	27007	Economy	4000.00
0005434408075	27007	Economy	4000.00
0005434408091	27007	Economy	4000.00
0005434408097	27007	Economy	4000.00
0005434408099	27007	Economy	4000.00
0005432153977	27007	Economy	4000.00
0005434408063	27007	Economy	4000.00
0005432153976	27007	Economy	4000.00
0005434408082	27007	Economy	4000.00
0005434408120	27007	Economy	4000.00
0005435311017	27007	Economy	4000.00
0005435310975	27007	Economy	4000.00
0005434408118	27007	Economy	4000.00
0005434408077	27007	Economy	4000.00
0005434408071	27007	Economy	4000.00
0005434408108	27007	Economy	4000.00
0005434408125	27007	Economy	4000.00
0005434408069	27007	Economy	4000.00
0005434408103	27007	Economy	4000.00
0005434408112	27007	Economy	4000.00
0005434408084	27007	Economy	4000.00
0005434408090	27007	Economy	4000.00
0005434408092	27007	Economy	4000.00
0005434408073	27007	Economy	4000.00
0005434408124	27007	Economy	4000.00
0005434408079	27007	Economy	4000.00
0005434408065	27007	Economy	4000.00
0005434408123	27007	Economy	4000.00
0005434408116	27007	Economy	4000.00
0005435310997	27007	Economy	4000.00
0005434408094	27007	Economy	4000.00
0005434408067	27007	Economy	4000.00
0005434408102	27007	Economy	4000.00
0005435311016	27007	Economy	4000.00
0005434408101	27007	Economy	4000.00
0005434408096	27007	Economy	4000.00
0005434408076	27007	Economy	4000.00
0005434408062	27007	Economy	4000.00
0005434408106	27007	Economy	4000.00
0005434311229	5716	Business	43300.00
0005434319476	5716	Business	43300.00
0005433123833	5716	Business	43300.00
0005433123844	5716	Business	43300.00
0005434319482	5716	Business	43300.00
0005433123890	5716	Economy	14400.00
0005434319473	5716	Economy	14400.00
0005433123805	5716	Economy	14400.00
0005434319474	5716	Economy	14400.00
0005434319470	5716	Economy	14400.00
0005433123822	5716	Economy	15900.00
0005433123752	5716	Economy	14400.00
0005433123835	5716	Economy	14400.00
0005433123905	5716	Economy	14400.00
0005434319471	5716	Economy	14400.00
0005434311231	5716	Economy	14400.00
0005434319477	5716	Economy	14400.00
0005434319485	5716	Economy	14400.00
0005433123870	5716	Economy	14400.00
0005434319479	5716	Economy	14400.00
0005433123759	5716	Economy	14400.00
0005433123843	5716	Economy	14400.00
0005434319469	5716	Economy	14400.00
0005434319472	5716	Economy	14400.00
0005433123810	5716	Economy	14400.00
0005433123910	5716	Economy	14400.00
0005434319486	5716	Economy	14400.00
0005434311232	5716	Economy	14400.00
0005434319480	5716	Economy	14400.00
0005432109718	5716	Economy	14400.00
0005434319487	5716	Economy	14400.00
0005434319483	5716	Economy	14400.00
0005433123891	5716	Economy	14400.00
0005433123753	5716	Economy	14400.00
0005434319484	5716	Economy	14400.00
0005433123816	5716	Economy	14400.00
0005434319481	5716	Economy	14400.00
0005434319475	5716	Economy	14400.00
0005434319478	5716	Economy	14400.00
0005433123817	5716	Economy	14400.00
0005433123832	5716	Economy	14400.00
0005434311230	5716	Economy	14400.00
0005433123889	5716	Economy	14400.00
0005433124047	15678	Business	43300.00
0005433124049	15678	Business	43300.00
0005433124032	15678	Business	43300.00
0005434319329	15678	Business	43300.00
0005434319305	15678	Business	43300.00
0005434319321	15678	Business	43300.00
0005434319396	15678	Economy	14400.00
0005433124048	15678	Economy	14400.00
0005434319325	15678	Economy	15900.00
0005434312313	15678	Economy	15900.00
0005434311216	15678	Economy	14400.00
0005433124027	15678	Economy	14400.00
0005434319320	15678	Economy	14400.00
0005434319319	15678	Economy	14400.00
0005434312312	15678	Economy	14400.00
0005433124038	15678	Economy	14400.00
0005433124045	15678	Economy	14400.00
0005433124029	15678	Economy	14400.00
0005433124037	15678	Economy	14400.00
0005433124042	15678	Economy	14400.00
0005433124028	15678	Economy	14400.00
0005433124030	15678	Economy	14400.00
0005434319362	15678	Economy	14400.00
0005434319322	15678	Economy	14400.00
0005434319391	15678	Economy	14400.00
0005433124033	15678	Economy	14400.00
0005433124031	15678	Economy	14400.00
0005433124036	15678	Economy	14400.00
0005433124050	15678	Economy	14400.00
0005434319307	15678	Economy	14400.00
0005433124041	15678	Economy	14400.00
0005434319402	15678	Economy	14400.00
0005434319306	15678	Economy	14400.00
0005434319326	15678	Economy	14400.00
0005433124043	15678	Economy	14400.00
0005434319363	15678	Economy	14400.00
0005433124046	15678	Economy	14400.00
0005433124035	15678	Economy	14400.00
0005434311209	15678	Economy	14400.00
0005433124039	15678	Economy	14400.00
0005434319379	15678	Economy	14400.00
0005434319348	15678	Economy	14400.00
0005434319380	15678	Economy	14400.00
0005434319299	15678	Economy	14400.00
0005433124044	15678	Economy	14400.00
0005434319359	15678	Economy	14400.00
0005433124040	15678	Economy	14400.00
0005433124034	15678	Economy	14400.00
0005435220310	24973	Economy	17100.00
0005435221510	24973	Economy	15500.00
0005435221509	24973	Economy	15500.00
0005435220303	24973	Economy	15500.00
0005435221507	24973	Economy	15500.00
0005435217712	24973	Economy	15500.00
0005435220296	24973	Economy	15500.00
0005435221508	24973	Economy	15500.00
0005435220309	24973	Economy	15500.00
0005435221505	24973	Economy	15500.00
0005435220308	24973	Economy	15500.00
0005435217690	24973	Economy	15500.00
0005435217689	24973	Economy	15500.00
0005435220318	24973	Economy	15500.00
0005435217705	24973	Economy	15500.00
0005434484380	8986	Economy	27400.00
0005434484383	8986	Economy	24900.00
0005434189142	8986	Economy	24900.00
0005434484382	8986	Economy	24900.00
0005434484385	8986	Economy	24900.00
0005434189162	8986	Economy	24900.00
0005434189181	8986	Economy	24900.00
0005434484384	8986	Economy	24900.00
0005434484381	8986	Economy	24900.00
0005434189141	8986	Economy	24900.00
0005434189207	16644	Economy	24900.00
0005434484331	16644	Economy	24900.00
0005434189210	16644	Economy	24900.00
0005434484317	16644	Economy	24900.00
0005434484319	16644	Economy	24900.00
0005434484330	16644	Economy	24900.00
0005434189211	16644	Economy	24900.00
0005434189208	16644	Economy	24900.00
0005434484318	16644	Economy	24900.00
0005434189209	16644	Economy	24900.00
0005433124045	7574	Business	11100.00
0005433722186	7574	Business	11100.00
0005433124039	7574	Business	11100.00
0005433722224	7574	Business	11100.00
0005433124030	7574	Economy	3700.00
0005433722219	7574	Economy	3700.00
0005433722207	7574	Economy	3700.00
0005433124042	7574	Economy	4100.00
0005433722208	7574	Economy	4100.00
0005433722184	7574	Economy	3700.00
0005433722172	7574	Economy	3700.00
0005433124048	7574	Economy	3700.00
0005433124046	7574	Economy	3700.00
0005433124036	7574	Economy	3700.00
0005433722213	7574	Economy	3700.00
0005433722185	7574	Economy	3700.00
0005433124032	7574	Economy	3700.00
0005433124047	7574	Economy	3700.00
0005433124049	7574	Economy	3700.00
0005433124038	7574	Economy	3700.00
0005433124028	7574	Economy	3700.00
0005433722171	7574	Economy	3700.00
0005433124033	7574	Economy	3700.00
0005433124040	7574	Economy	3700.00
0005433722214	7574	Economy	3700.00
0005433722220	7574	Economy	3700.00
0005433722203	7574	Economy	3700.00
0005433124035	7574	Economy	3700.00
0005433124027	7574	Economy	3700.00
0005433124044	7574	Economy	3700.00
0005433124029	7574	Economy	3700.00
0005433124050	7574	Economy	3700.00
0005433722195	7574	Economy	3700.00
0005433722218	7574	Economy	3700.00
0005433124041	7574	Economy	3700.00
0005433722210	7574	Economy	3700.00
0005433722221	7574	Economy	3700.00
0005433124034	7574	Economy	3700.00
0005433124037	7574	Economy	3700.00
0005433722182	7574	Economy	3700.00
0005433124031	7574	Economy	3700.00
0005433124043	7574	Economy	3700.00
0005433450079	7575	Business	11100.00
0005432721051	7575	Business	11100.00
0005432071590	7575	Business	11100.00
0005432693228	7575	Business	11100.00
0005433450095	7575	Business	11100.00
0005432721034	7575	Business	11100.00
0005432693249	7575	Business	11100.00
0005432721055	7575	Business	11100.00
0005432721038	7575	Business	11100.00
0005432693247	7575	Business	11100.00
0005432721046	7575	Economy	3700.00
0005433450082	7575	Economy	3700.00
0005433450077	7575	Economy	3700.00
0005432693230	7575	Economy	3700.00
0005432693242	7575	Economy	3700.00
0005432693234	7575	Economy	3700.00
0005433450078	7575	Economy	3700.00
0005432693246	7575	Economy	3700.00
0005432693245	7575	Economy	3700.00
0005433450074	7575	Economy	4100.00
0005432721054	7575	Economy	4100.00
0005432693236	7575	Economy	4100.00
0005432721048	7575	Economy	4100.00
0005432693248	7575	Economy	3700.00
0005432721058	7575	Economy	3700.00
0005432693226	7575	Economy	3700.00
0005432693227	7575	Economy	3700.00
0005432693239	7575	Economy	3700.00
0005432721042	7575	Economy	3700.00
0005433450087	7575	Economy	3700.00
0005432721053	7575	Economy	3700.00
0005433450075	7575	Economy	3700.00
0005432693223	7575	Economy	3700.00
0005432721047	7575	Economy	3700.00
0005432693235	7575	Economy	3700.00
0005432693244	7575	Economy	3700.00
0005433450094	7575	Economy	3700.00
0005433450090	7575	Economy	3700.00
0005432693250	7575	Economy	3700.00
0005433450093	7575	Economy	3700.00
0005432721050	7575	Economy	3700.00
0005433450076	7575	Economy	3700.00
0005433450084	7575	Economy	3700.00
0005432721049	7575	Economy	3700.00
0005432721036	7575	Economy	3700.00
0005433450089	7575	Economy	3700.00
0005432721052	7575	Economy	3700.00
0005432721040	7575	Economy	3700.00
0005432693229	7575	Economy	3700.00
0005432693233	7575	Economy	3700.00
0005433450081	7575	Economy	3700.00
0005432071588	7575	Economy	3700.00
0005432693238	7575	Economy	3700.00
0005432693232	7575	Economy	3700.00
0005432721044	7575	Economy	3700.00
0005432693240	7575	Economy	3700.00
0005433450080	7575	Economy	3700.00
0005432071589	7575	Economy	3700.00
0005432721041	7575	Economy	3700.00
0005432721043	7575	Economy	3700.00
0005433450085	7575	Economy	3700.00
0005432721033	7575	Economy	3700.00
0005432693243	7575	Economy	3700.00
0005433450092	7575	Economy	3700.00
0005432721035	7575	Economy	3700.00
0005432693237	7575	Economy	3700.00
0005432693225	7575	Economy	3700.00
0005432693231	7575	Economy	3700.00
0005432693251	7575	Economy	3700.00
0005432721045	7575	Economy	3700.00
0005432693224	7575	Economy	3700.00
0005433450088	7575	Economy	3700.00
0005432693252	7575	Economy	3700.00
0005432721057	7575	Economy	3700.00
0005433450091	7575	Economy	3700.00
0005432721059	7575	Economy	3700.00
0005432721037	7575	Economy	3700.00
0005433450086	7575	Economy	3700.00
0005432721056	7575	Economy	3700.00
0005433450083	7575	Economy	3700.00
0005432721039	7575	Economy	3700.00
0005432693241	7575	Economy	3700.00
0005432692826	30278	Business	11100.00
0005432692894	30278	Business	11100.00
0005432692980	30278	Business	11100.00
0005433449891	30278	Business	11100.00
0005433449975	30278	Business	11100.00
0005433449919	30278	Business	11100.00
0005432692897	30278	Business	11100.00
0005433449907	30278	Economy	3700.00
0005432692787	30278	Economy	3700.00
0005433449920	30278	Economy	3700.00
0005433449904	30278	Economy	3700.00
0005432692785	30278	Economy	3700.00
0005432692937	30278	Economy	4100.00
0005432692694	30278	Economy	4100.00
0005432692900	30278	Economy	4100.00
0005433449823	30278	Economy	3700.00
0005432692929	30278	Economy	3700.00
0005432692853	30278	Economy	3700.00
0005433449873	30278	Economy	3700.00
0005432692986	30278	Economy	3700.00
0005433449800	30278	Economy	3700.00
0005432692935	30278	Economy	3700.00
0005432692898	30278	Economy	3700.00
0005432692786	30278	Economy	3700.00
0005433449859	30278	Economy	3700.00
0005432692946	30278	Economy	3700.00
0005433449845	30278	Economy	3700.00
0005432692848	30278	Economy	3700.00
0005433449852	30278	Economy	3700.00
0005432693006	30278	Economy	3700.00
0005433449860	30278	Economy	3700.00
0005432692906	30278	Economy	3700.00
0005432692969	30278	Economy	3700.00
0005433449918	30278	Economy	3700.00
0005433449903	30278	Economy	3700.00
0005433449925	30278	Economy	3700.00
0005432692990	30278	Economy	3700.00
0005432692991	30278	Economy	3700.00
0005433449906	30278	Economy	3700.00
0005432692925	30278	Economy	3700.00
0005432692827	30278	Economy	3700.00
0005433449824	30278	Economy	3700.00
0005432693000	30278	Economy	3700.00
0005433449863	30278	Economy	3700.00
0005432692934	30278	Economy	3700.00
0005433449851	30278	Economy	3700.00
0005432692840	30278	Economy	3700.00
0005433449952	30278	Economy	3700.00
0005433449854	30278	Economy	3700.00
0005433449853	30278	Economy	3700.00
0005432692984	30278	Economy	3700.00
0005432692854	30278	Economy	3700.00
0005432693046	30278	Economy	3700.00
0005432692784	30278	Economy	3700.00
0005432692839	30278	Economy	3700.00
0005433449951	30278	Economy	3700.00
0005433722256	30279	Business	11100.00
0005432720864	30279	Business	11100.00
0005432720818	30279	Business	11100.00
0005432720869	30279	Business	11100.00
0005433123759	30279	Business	11100.00
0005432720891	30279	Business	11100.00
0005433722262	30279	Economy	3700.00
0005433123835	30279	Economy	3700.00
0005433123752	30279	Economy	3700.00
0005433123805	30279	Economy	3700.00
0005432720861	30279	Economy	3700.00
0005432720825	30279	Economy	3700.00
0005433722258	30279	Economy	3700.00
0005432720990	30279	Economy	3700.00
0005433722264	30279	Economy	4100.00
0005433123817	30279	Economy	4100.00
0005432720727	30279	Economy	4100.00
0005433123832	30279	Economy	3700.00
0005433722254	30279	Economy	3700.00
0005433123843	30279	Economy	3700.00
0005432720877	30279	Economy	3700.00
0005433722260	30279	Economy	3700.00
0005432720911	30279	Economy	3700.00
0005433123905	30279	Economy	3700.00
0005432720809	30279	Economy	3700.00
0005433123870	30279	Economy	3700.00
0005432720868	30279	Economy	3700.00
0005432720860	30279	Economy	3700.00
0005432720847	30279	Economy	3700.00
0005432720909	30279	Economy	3700.00
0005432720843	30279	Economy	3700.00
0005432720851	30279	Economy	3700.00
0005433722259	30279	Economy	3700.00
0005432720798	30279	Economy	3700.00
0005433123822	30279	Economy	3700.00
0005433722263	30279	Economy	3700.00
0005433722255	30279	Economy	3700.00
0005432720910	30279	Economy	3700.00
0005432720844	30279	Economy	3700.00
0005433722265	30279	Economy	3700.00
0005433123816	30279	Economy	3700.00
0005433123889	30279	Economy	3700.00
0005432720824	30279	Economy	3700.00
0005433123753	30279	Economy	3700.00
0005433722269	30279	Economy	3700.00
0005433722261	30279	Economy	3700.00
0005433123910	30279	Economy	3700.00
0005433123833	30279	Economy	3700.00
0005433722266	30279	Economy	3700.00
0005433123891	30279	Economy	3700.00
0005433722268	30279	Economy	3700.00
0005433722257	30279	Economy	3700.00
0005433123890	30279	Economy	3700.00
0005432720754	30279	Economy	3700.00
0005432720743	30279	Economy	3700.00
0005432720714	30279	Economy	3700.00
0005432720951	30279	Economy	3700.00
0005432720982	30279	Economy	3700.00
0005433123844	30279	Economy	3700.00
0005432720826	30279	Economy	3700.00
0005432720750	30279	Economy	3700.00
0005432720866	30279	Economy	3700.00
0005432720819	30279	Economy	3700.00
0005433722267	30279	Economy	3700.00
0005433123810	30279	Economy	3700.00
0005432720865	30279	Economy	3700.00
0005433525093	1391	Business	70400.00
0005432927959	1391	Business	70400.00
0005434586753	1391	Business	70400.00
0005433192980	1391	Business	70400.00
0005434586745	1391	Business	70400.00
0005432271020	1391	Business	70400.00
0005433525098	1391	Business	70400.00
0005434586754	1391	Economy	23500.00
0005434586744	1391	Economy	23500.00
0005433193012	1391	Economy	23500.00
0005432271019	1391	Economy	23500.00
0005433193033	1391	Economy	23500.00
0005433193001	1391	Economy	23500.00
0005432927980	1391	Economy	25800.00
0005433193013	1391	Economy	25800.00
0005433525095	1391	Economy	25800.00
0005434586757	1391	Economy	25800.00
0005434586738	1391	Economy	25800.00
0005433193021	1391	Economy	23500.00
0005433525094	1391	Economy	23500.00
0005434586760	1391	Economy	23500.00
0005433724828	1391	Economy	23500.00
0005434586752	1391	Economy	23500.00
0005434586748	1391	Economy	23500.00
0005432927974	1391	Economy	23500.00
0005434586736	1391	Economy	23500.00
0005434586742	1391	Economy	23500.00
0005433724829	1391	Economy	23500.00
0005434513593	1391	Economy	23500.00
0005434586759	1391	Economy	23500.00
0005433525096	1391	Economy	23500.00
0005432927958	1391	Economy	23500.00
0005434586761	1391	Economy	23500.00
0005433525101	1391	Economy	23500.00
0005433193044	1391	Economy	23500.00
0005433525097	1391	Economy	23500.00
0005432927979	1391	Economy	23500.00
0005433193034	1391	Economy	23500.00
0005434586741	1391	Economy	23500.00
0005434514983	1391	Economy	23500.00
0005434514980	1391	Economy	23500.00
0005433193002	1391	Economy	23500.00
0005434586743	1391	Economy	23500.00
0005434513592	1391	Economy	23500.00
0005434586739	1391	Economy	23500.00
0005434586751	1391	Economy	23500.00
0005434586749	1391	Economy	23500.00
0005434586750	1391	Economy	23500.00
0005433193060	1391	Economy	23500.00
0005434586756	1391	Economy	23500.00
0005432927953	1391	Economy	23500.00
0005433192983	1391	Economy	23500.00
0005433525099	1391	Economy	23500.00
0005433724827	1391	Economy	23500.00
0005433525100	1391	Economy	23500.00
0005434586747	1391	Economy	23500.00
0005434586758	1391	Economy	23500.00
0005433724830	1391	Economy	23500.00
0005433192988	1391	Economy	23500.00
0005433724826	1391	Economy	23500.00
0005434586746	1391	Economy	23500.00
0005434513594	1391	Economy	23500.00
0005434514982	1391	Economy	23500.00
0005434586740	1391	Economy	23500.00
0005434514981	1391	Economy	23500.00
0005434586755	1391	Economy	23500.00
0005434586737	1391	Economy	23500.00
0005434586762	1391	Economy	23500.00
0005433192973	1391	Economy	23500.00
0005433193122	18550	Business	70400.00
0005433724789	18550	Business	70400.00
0005433193118	18550	Business	70400.00
0005434586607	18550	Business	70400.00
0005433525018	18550	Business	70400.00
0005434586554	18550	Business	70400.00
0005434586532	18550	Business	70400.00
0005433724801	18550	Business	70400.00
0005434586614	18550	Business	70400.00
0005434514955	18550	Economy	23500.00
0005434586499	18550	Economy	23500.00
0005434586399	18550	Economy	23500.00
0005433525023	18550	Economy	23500.00
0005434586601	18550	Economy	23500.00
0005434586492	18550	Economy	23500.00
0005434586457	18550	Economy	23500.00
0005433525017	18550	Economy	23500.00
0005434514956	18550	Economy	25800.00
0005433193115	18550	Economy	25800.00
0005432968852	18550	Economy	23500.00
0005433525035	18550	Economy	23500.00
0005433724794	18550	Economy	23500.00
0005433524909	18550	Economy	23500.00
0005434586546	18550	Economy	23500.00
0005432928008	18550	Economy	23500.00
0005434586447	18550	Economy	23500.00
0005434514952	18550	Economy	23500.00
0005433724787	18550	Economy	23500.00
0005434586574	18550	Economy	23500.00
0005433193113	18550	Economy	23500.00
0005433193116	18550	Economy	23500.00
0005433193110	18550	Economy	23500.00
0005434586458	18550	Economy	23500.00
0005433193112	18550	Economy	23500.00
0005433524972	18550	Economy	23500.00
0005432928010	18550	Economy	23500.00
0005434586456	18550	Economy	23500.00
0005434586474	18550	Economy	23500.00
0005433524973	18550	Economy	23500.00
0005434586564	18550	Economy	23500.00
0005434514953	18550	Economy	23500.00
0005433724790	18550	Economy	23500.00
0005433193123	18550	Economy	23500.00
0005433193120	18550	Economy	23500.00
0005433193117	18550	Economy	23500.00
0005433193114	18550	Economy	23500.00
0005434586433	18550	Economy	23500.00
0005433525053	18550	Economy	23500.00
0005434586489	18550	Economy	23500.00
0005433525013	18550	Economy	23500.00
0005433525012	18550	Economy	23500.00
0005434586565	18550	Economy	23500.00
0005434586498	18550	Economy	23500.00
0005434586533	18550	Economy	23500.00
0005433193111	18550	Economy	23500.00
0005434586398	18550	Economy	23500.00
0005433524988	18550	Economy	23500.00
0005433525000	18550	Economy	23500.00
0005432928009	18550	Economy	23500.00
0005434586488	18550	Economy	23500.00
0005433524999	18550	Economy	23500.00
0005433193121	18550	Economy	23500.00
0005433525007	18550	Economy	23500.00
0005434586527	18550	Economy	23500.00
0005434586385	18550	Economy	23500.00
0005434586602	18550	Economy	23500.00
0005434586563	18550	Economy	23500.00
0005432968851	18550	Economy	23500.00
0005433525011	18550	Economy	23500.00
0005433193119	18550	Economy	23500.00
0005432928007	18550	Economy	23500.00
0005433724800	18550	Economy	23500.00
0005434344371	11433	Economy	4300.00
0005434344368	11433	Economy	4300.00
0005434344372	11433	Economy	4300.00
0005434344382	11433	Economy	4300.00
0005434142633	11433	Economy	4000.00
0005435302168	11433	Economy	4000.00
0005434344374	11433	Economy	4000.00
0005434344364	11433	Economy	4000.00
0005435302177	11433	Economy	4000.00
0005434344377	11433	Economy	4000.00
0005434344392	11433	Economy	4000.00
0005434344376	11433	Economy	4000.00
0005434344369	11433	Economy	4000.00
0005434344390	11433	Economy	4000.00
0005434142630	11433	Economy	4000.00
0005434344391	11433	Economy	4000.00
0005434344380	11433	Economy	4000.00
0005434344367	11433	Economy	4000.00
0005434142634	11433	Economy	4000.00
0005434142631	11433	Economy	4000.00
0005434142632	11433	Economy	4000.00
0005434344389	11433	Economy	4000.00
0005434344398	11433	Economy	4000.00
0005434344370	11433	Economy	4000.00
0005434344393	11433	Economy	4000.00
0005434344366	11433	Economy	4000.00
0005434344397	11433	Economy	4000.00
0005434344383	11433	Economy	4000.00
0005434344395	11433	Economy	4000.00
0005434344365	11433	Economy	4000.00
0005434344388	11433	Economy	4000.00
0005434344396	11433	Economy	4000.00
0005434344373	11433	Economy	4000.00
0005434344363	11433	Economy	4000.00
0005434344394	11433	Economy	4000.00
0005434344375	11433	Economy	4000.00
0005434344378	11433	Economy	4000.00
0005435305007	11433	Economy	4000.00
0005435305000	11433	Economy	4000.00
0005434344384	11433	Economy	4000.00
0005434344362	11433	Economy	4000.00
0005434344386	11433	Economy	4000.00
0005435302178	11433	Economy	4000.00
0005434344381	11433	Economy	4000.00
0005434344385	11433	Economy	4000.00
0005434344387	11433	Economy	4000.00
0005434344379	11433	Economy	4000.00
0005434344104	29787	Economy	4300.00
0005434344175	29787	Economy	4300.00
0005434142575	29787	Economy	4300.00
0005434343999	29787	Economy	4300.00
0005434142593	29787	Economy	4000.00
0005434344062	29787	Economy	4000.00
0005434343995	29787	Economy	4000.00
0005434344040	29787	Economy	4000.00
0005434344073	29787	Economy	4000.00
0005434344107	29787	Economy	4000.00
0005434344234	29787	Economy	4000.00
0005434344046	29787	Economy	4000.00
0005434142574	29787	Economy	4000.00
0005434344124	29787	Economy	4000.00
0005434344060	29787	Economy	4000.00
0005434344251	29787	Economy	4000.00
0005434344108	29787	Economy	4000.00
0005435304184	29787	Economy	4000.00
0005434344024	29787	Economy	4000.00
0005434142596	29787	Economy	4000.00
0005434344130	29787	Economy	4000.00
0005434344131	29787	Economy	4000.00
0005434343972	29787	Economy	4000.00
0005434344012	29787	Economy	4000.00
0005435305023	29787	Economy	4000.00
0005434343935	29787	Economy	4000.00
0005434344115	29787	Economy	4000.00
0005434344000	29787	Economy	4000.00
0005434344173	29787	Economy	4000.00
0005434344072	29787	Economy	4000.00
0005434344019	29787	Economy	4000.00
0005434344047	29787	Economy	4000.00
0005434343842	29787	Economy	4000.00
0005434343994	29787	Economy	4000.00
0005434344121	29787	Economy	4000.00
0005435305025	29787	Economy	4000.00
0005434343918	29787	Economy	4000.00
0005435304185	29787	Economy	4000.00
0005434343919	29787	Economy	4000.00
0005434344123	29787	Economy	4000.00
0005434344252	29787	Economy	4000.00
0005434344053	29787	Economy	4000.00
0005435305024	29787	Economy	4000.00
0005434344122	29787	Economy	4000.00
0005434344068	29787	Economy	4000.00
0005434343988	29787	Economy	4000.00
0005435304186	29787	Economy	4000.00
0005434344103	29787	Economy	4000.00
0005434343934	29787	Economy	4000.00
0005435824758	1303	Business	199800.00
0005435824762	1303	Business	199800.00
0005435824769	1303	Business	199800.00
0005435824760	1303	Business	199800.00
0005433415650	1303	Business	199800.00
0005433415555	1303	Business	199800.00
0005435824779	1303	Business	199800.00
0005433415571	1303	Business	199800.00
0005433415672	1303	Business	199800.00
0005433415641	1303	Business	199800.00
0005433415640	1303	Economy	66600.00
0005435824759	1303	Economy	66600.00
0005433415659	1303	Economy	66600.00
0005435824768	1303	Economy	66600.00
0005433415617	1303	Economy	66600.00
0005435824761	1303	Economy	66600.00
0005435824782	1303	Economy	66600.00
0005435824781	1303	Economy	66600.00
0005435824757	1303	Economy	66600.00
0005435824773	1303	Economy	66600.00
0005433415671	1303	Economy	66600.00
0005433415696	1303	Economy	66600.00
0005432284574	1303	Economy	66600.00
0005435824774	1303	Economy	66600.00
0005435824777	1303	Economy	66600.00
0005433415658	1303	Economy	66600.00
0005435824767	1303	Economy	66600.00
0005432284573	1303	Economy	66600.00
0005433415656	1303	Economy	66600.00
0005433415590	1303	Economy	66600.00
0005435824772	1303	Economy	66600.00
0005432284575	1303	Economy	66600.00
0005433415697	1303	Economy	66600.00
0005435824778	1303	Economy	66600.00
0005435824780	1303	Economy	66600.00
0005433415695	1303	Economy	66600.00
0005435824763	1303	Economy	66600.00
0005435824764	1303	Economy	66600.00
0005435824765	1303	Economy	66600.00
0005435824775	1303	Economy	66600.00
0005433415589	1303	Economy	66600.00
0005433415690	1303	Economy	66600.00
0005433415657	1303	Economy	66600.00
0005435824770	1303	Economy	66600.00
0005435824771	1303	Economy	66600.00
0005433415647	1303	Economy	66600.00
0005435824755	1303	Economy	66600.00
0005433415651	1303	Economy	66600.00
0005435824766	1303	Economy	66600.00
0005435824756	1303	Economy	66600.00
0005435824776	1303	Economy	66600.00
0005433415649	1303	Economy	66600.00
0005433415742	18011	Business	199800.00
0005435824538	18011	Business	199800.00
0005435824502	18011	Business	199800.00
0005435824658	18011	Business	199800.00
0005435824486	18011	Business	199800.00
0005435824680	18011	Business	199800.00
0005433415749	18011	Economy	66600.00
0005433415752	18011	Economy	66600.00
0005435824621	18011	Economy	66600.00
0005433415745	18011	Economy	66600.00
0005435824639	18011	Economy	73200.00
0005433415746	18011	Economy	73200.00
0005435824496	18011	Economy	66600.00
0005435824487	18011	Economy	66600.00
0005435824519	18011	Economy	66600.00
0005435824513	18011	Economy	66600.00
0005435824497	18011	Economy	66600.00
0005435824640	18011	Economy	66600.00
0005435824550	18011	Economy	66600.00
0005435824463	18011	Economy	66600.00
0005433415738	18011	Economy	66600.00
0005433415747	18011	Economy	66600.00
0005433415741	18011	Economy	66600.00
0005435824531	18011	Economy	66600.00
0005435824501	18011	Economy	66600.00
0005433415751	18011	Economy	66600.00
0005433415739	18011	Economy	66600.00
0005433415750	18011	Economy	66600.00
0005433415744	18011	Economy	66600.00
0005435824464	18011	Economy	66600.00
0005435824571	18011	Economy	66600.00
0005435824588	18011	Economy	66600.00
0005435824615	18011	Economy	66600.00
0005433415748	18011	Economy	66600.00
0005435824384	18011	Economy	66600.00
0005435824490	18011	Economy	66600.00
0005435824582	18011	Economy	66600.00
0005435824593	18011	Economy	66600.00
0005435824393	18011	Economy	66600.00
0005433415743	18011	Economy	66600.00
0005435824522	18011	Economy	66600.00
0005435824539	18011	Economy	66600.00
0005433415740	18011	Economy	66600.00
0005435824551	18011	Economy	66600.00
0005434461654	12576	Economy	14800.00
0005434460510	12576	Economy	13500.00
0005434460513	12576	Economy	13500.00
0005434461656	12576	Economy	13500.00
0005434460509	12576	Economy	13500.00
0005434461652	12576	Economy	13500.00
0005434461651	12576	Economy	13500.00
0005434460512	12576	Economy	13500.00
0005434460515	12576	Economy	13500.00
0005434461655	12576	Economy	13500.00
0005434460511	12576	Economy	13500.00
0005434460516	12576	Economy	13500.00
0005434461653	12576	Economy	13500.00
0005434460514	12576	Economy	13500.00
0005432784050	5642	Business	27800.00
0005432784065	5642	Business	27800.00
0005432784077	5642	Business	27800.00
0005432784061	5642	Business	27800.00
0005435242710	5642	Business	27800.00
0005432784074	5642	Business	27800.00
0005435242804	5642	Business	27800.00
0005432784071	5642	Business	27800.00
0005432784072	5642	Business	27800.00
0005432784070	5642	Business	27800.00
0005432784105	5642	Business	27800.00
0005432784096	5642	Business	27800.00
0005435242590	5642	Economy	9300.00
0005432784078	5642	Economy	9300.00
0005432784055	5642	Economy	9300.00
0005432784079	5642	Economy	9300.00
0005432784066	5642	Economy	9300.00
0005435476718	5642	Economy	9300.00
0005432784082	5642	Economy	9300.00
0005432784094	5642	Economy	9300.00
0005435242734	5642	Economy	9300.00
0005432784062	5642	Economy	9300.00
0005432784091	5642	Economy	10200.00
0005432784098	5642	Economy	10200.00
0005432784058	5642	Economy	10200.00
0005432784095	5642	Economy	10200.00
0005432784067	5642	Economy	9300.00
0005435242818	5642	Economy	9300.00
0005432784085	5642	Economy	9300.00
0005432784080	5642	Economy	9300.00
0005432784057	5642	Economy	9300.00
0005435242807	5642	Economy	9300.00
0005435242739	5642	Economy	9300.00
0005432784100	5642	Economy	9300.00
0005435242703	5642	Economy	9300.00
0005435242704	5642	Economy	9300.00
0005435242700	5642	Economy	9300.00
0005432784052	5642	Economy	9300.00
0005435242736	5642	Economy	9300.00
0005432144003	5642	Economy	9300.00
0005432784083	5642	Economy	9300.00
0005435242767	5642	Economy	9300.00
0005432784086	5642	Economy	9300.00
0005435242799	5642	Economy	9300.00
0005432784092	5642	Economy	9300.00
0005432784068	5642	Economy	9300.00
0005432784075	5642	Economy	9300.00
0005432144005	5642	Economy	9300.00
0005435242840	5642	Economy	9300.00
0005432784102	5642	Economy	9300.00
0005435242740	5642	Economy	9300.00
0005432784104	5642	Economy	9300.00
0005432784081	5642	Economy	9300.00
0005432784053	5642	Economy	9300.00
0005432784087	5642	Economy	9300.00
0005432784088	5642	Economy	9300.00
0005435242805	5642	Economy	9300.00
0005432784084	5642	Economy	9300.00
0005432784059	5642	Economy	9300.00
0005435242832	5642	Economy	9300.00
0005432144004	5642	Economy	9300.00
0005435242755	5642	Economy	9300.00
0005432784097	5642	Economy	9300.00
0005435242757	5642	Economy	9300.00
0005432144006	5642	Economy	9300.00
0005432784093	5642	Economy	9300.00
0005435242735	5642	Economy	9300.00
0005432784056	5642	Economy	9300.00
0005435242758	5642	Economy	9300.00
0005435476719	5642	Economy	9300.00
0005435242819	5642	Economy	9300.00
0005435242702	5642	Economy	9300.00
0005432784089	5642	Economy	9300.00
0005432784063	5642	Economy	9300.00
0005435242744	5642	Economy	9300.00
0005435476761	5642	Economy	9300.00
0005432784103	5642	Economy	9300.00
0005432784054	5642	Economy	9300.00
0005432784101	5642	Economy	9300.00
0005435476727	5642	Economy	9300.00
0005432784090	5642	Economy	9300.00
0005432784051	5642	Economy	9300.00
0005432784073	5642	Economy	9300.00
0005435242831	5642	Economy	9300.00
0005432784064	5642	Economy	9300.00
0005432784060	5642	Economy	9300.00
0005432784076	5642	Economy	9300.00
0005435242699	5642	Economy	9300.00
0005432784099	5642	Economy	9300.00
0005435242701	5642	Economy	9300.00
0005432784069	5642	Economy	9300.00
0005432144007	5642	Economy	9300.00
0005432783727	15348	Business	27800.00
0005432783608	15348	Business	27800.00
0005432783794	15348	Business	27800.00
0005435242987	15348	Business	27800.00
0005435242977	15348	Business	27800.00
0005432783404	15348	Business	27800.00
0005432783638	15348	Business	27800.00
0005432783454	15348	Business	27800.00
0005432783419	15348	Business	27800.00
0005432783521	15348	Business	27800.00
0005435242966	15348	Business	27800.00
0005435242986	15348	Business	27800.00
0005432783652	15348	Economy	9300.00
0005435476789	15348	Economy	9300.00
0005432783726	15348	Economy	9300.00
0005432783829	15348	Economy	9300.00
0005435242964	15348	Economy	9300.00
0005435242973	15348	Economy	9300.00
0005432783243	15348	Economy	9300.00
0005432783487	15348	Economy	9300.00
0005432783675	15348	Economy	9300.00
0005432783516	15348	Economy	9300.00
0005432783375	15348	Economy	10200.00
0005435476790	15348	Economy	10200.00
0005435242988	15348	Economy	10200.00
0005432783445	15348	Economy	10200.00
0005432783508	15348	Economy	10200.00
0005435242969	15348	Economy	9300.00
0005432783676	15348	Economy	9300.00
0005435476791	15348	Economy	9300.00
0005432783728	15348	Economy	9300.00
0005435242984	15348	Economy	9300.00
0005432783444	15348	Economy	9300.00
0005432783686	15348	Economy	9300.00
0005432783450	15348	Economy	9300.00
0005435242980	15348	Economy	9300.00
0005435242979	15348	Economy	9300.00
0005435242965	15348	Economy	9300.00
0005435242971	15348	Economy	9300.00
0005432783639	15348	Economy	9300.00
0005432783513	15348	Economy	9300.00
0005432783531	15348	Economy	9300.00
0005432783716	15348	Economy	9300.00
0005432783612	15348	Economy	9300.00
0005435242972	15348	Economy	9300.00
0005432783512	15348	Economy	9300.00
0005435242976	15348	Economy	9300.00
0005435242978	15348	Economy	9300.00
0005435242968	15348	Economy	9300.00
0005432783242	15348	Economy	9300.00
0005435242970	15348	Economy	9300.00
0005435242981	15348	Economy	9300.00
0005432783488	15348	Economy	9300.00
0005432783589	15348	Economy	9300.00
0005435242975	15348	Economy	9300.00
0005435242983	15348	Economy	9300.00
0005432783435	15348	Economy	9300.00
0005432783627	15348	Economy	9300.00
0005435242990	15348	Economy	9300.00
0005432783683	15348	Economy	9300.00
0005435242989	15348	Economy	9300.00
0005432783772	15348	Economy	9300.00
0005435242985	15348	Economy	9300.00
0005432783416	15348	Economy	9300.00
0005432783719	15348	Economy	9300.00
0005432783458	15348	Economy	9300.00
0005432783570	15348	Economy	9300.00
0005432783715	15348	Economy	9300.00
0005432783483	15348	Economy	9300.00
0005432783718	15348	Economy	9300.00
0005432783679	15348	Economy	9300.00
0005432783622	15348	Economy	9300.00
0005432783533	15348	Economy	9300.00
0005435476788	15348	Economy	9300.00
0005435242982	15348	Economy	9300.00
0005432783559	15348	Economy	9300.00
0005432783422	15348	Economy	9300.00
0005435242967	15348	Economy	9300.00
0005432783569	15348	Economy	9300.00
0005432783517	15348	Economy	9300.00
0005435242963	15348	Economy	9300.00
0005432783436	15348	Economy	9300.00
0005432783613	15348	Economy	9300.00
0005432783509	15348	Economy	9300.00
0005432783363	15348	Economy	9300.00
0005432783685	15348	Economy	9300.00
0005432783828	15348	Economy	9300.00
0005432783789	15348	Economy	9300.00
0005432783701	15348	Economy	9300.00
0005432783626	15348	Economy	9300.00
0005435242974	15348	Economy	9300.00
0005432783560	15348	Economy	9300.00
0005432783607	15348	Economy	9300.00
0005432783337	15348	Economy	9300.00
0005432783628	15348	Economy	9300.00
0005435850870	4380	Economy	7000.00
0005432848386	4380	Economy	6300.00
0005432848385	4380	Economy	6300.00
0005434463941	4380	Economy	6300.00
0005432848388	4380	Economy	6300.00
0005435850895	4380	Economy	6300.00
0005435850858	4380	Economy	6300.00
0005435850896	4380	Economy	6300.00
0005435850887	4380	Economy	6300.00
0005435850871	4380	Economy	6300.00
0005432848391	4380	Economy	6300.00
0005432848393	4380	Economy	6300.00
0005434463940	4380	Economy	6300.00
0005432848394	4380	Economy	6300.00
0005432848387	4380	Economy	6300.00
0005432848384	4380	Economy	6300.00
0005432848396	4380	Economy	6300.00
0005435850892	4380	Economy	6300.00
0005435850911	4380	Economy	6300.00
0005432848395	4380	Economy	6300.00
0005432848390	4380	Economy	6300.00
0005432848392	4380	Economy	6300.00
0005435850891	4380	Economy	6300.00
0005435850859	4380	Economy	6300.00
0005432848383	4380	Economy	6300.00
0005434462802	4380	Economy	6300.00
0005432848389	4380	Economy	6300.00
0005434462803	4380	Economy	6300.00
0005435850962	28866	Economy	7000.00
0005435850958	28866	Economy	7000.00
0005435850954	28866	Economy	7000.00
0005432848253	28866	Economy	6300.00
0005435850963	28866	Economy	6300.00
0005432848311	28866	Economy	6300.00
0005435850957	28866	Economy	6300.00
0005435850961	28866	Economy	6300.00
0005432848224	28866	Economy	6300.00
0005435850956	28866	Economy	6300.00
0005432848301	28866	Economy	6300.00
0005432848205	28866	Economy	6300.00
0005432848288	28866	Economy	6300.00
0005435850960	28866	Economy	6300.00
0005435850955	28866	Economy	6300.00
0005434461634	28866	Economy	6300.00
0005434463914	28866	Economy	6300.00
0005432848204	28866	Economy	6300.00
0005435850959	28866	Economy	6300.00
0005432848298	28866	Economy	6300.00
0005432848232	28866	Economy	6300.00
0005432848287	28866	Economy	6300.00
0005432848241	28866	Economy	6300.00
0005432848305	28866	Economy	6300.00
0005432848210	28866	Economy	6300.00
0005434461640	28866	Economy	6300.00
0005434461641	28866	Economy	6300.00
0005432848291	28866	Economy	6300.00
0005432848225	28866	Economy	6300.00
0005432848271	28866	Economy	6300.00
0005434443804	6306	Business	11900.00
0005434925969	6306	Business	11900.00
0005432075250	6306	Business	11900.00
0005434925967	6306	Business	11900.00
0005433497143	6306	Business	11900.00
0005433497123	6306	Business	11900.00
0005434925975	6306	Business	11900.00
0005433497137	6306	Business	11900.00
0005434925983	6306	Business	11900.00
0005434925963	6306	Economy	4000.00
0005434925977	6306	Economy	4000.00
0005433497150	6306	Economy	4000.00
0005433497135	6306	Economy	4000.00
0005433497152	6306	Economy	4000.00
0005433497144	6306	Economy	4000.00
0005433497153	6306	Economy	4000.00
0005433497145	6306	Economy	4000.00
0005434443802	6306	Economy	4000.00
0005434925965	6306	Economy	4400.00
0005432075248	6306	Economy	4400.00
0005433497147	6306	Economy	4400.00
0005434925973	6306	Economy	4400.00
0005433497146	6306	Economy	4000.00
0005433497141	6306	Economy	4000.00
0005434925976	6306	Economy	4000.00
0005434443794	6306	Economy	4000.00
0005434443788	6306	Economy	4000.00
0005434925984	6306	Economy	4000.00
0005433497129	6306	Economy	4000.00
0005434925982	6306	Economy	4000.00
0005434925964	6306	Economy	4000.00
0005433497133	6306	Economy	4000.00
0005434925987	6306	Economy	4000.00
0005433497148	6306	Economy	4000.00
0005432075249	6306	Economy	4000.00
0005433497138	6306	Economy	4000.00
0005433497140	6306	Economy	4000.00
0005434925971	6306	Economy	4000.00
0005433497136	6306	Economy	4000.00
0005434925980	6306	Economy	4000.00
0005433497132	6306	Economy	4000.00
0005434443795	6306	Economy	4000.00
0005434443801	6306	Economy	4000.00
0005433497139	6306	Economy	4000.00
0005433497131	6306	Economy	4000.00
0005432075251	6306	Economy	4000.00
0005434925968	6306	Economy	4000.00
0005434443791	6306	Economy	4000.00
0005434443796	6306	Economy	4000.00
0005432075247	6306	Economy	4000.00
0005433497127	6306	Economy	4000.00
0005434443798	6306	Economy	4000.00
0005433497126	6306	Economy	4000.00
0005434925978	6306	Economy	4000.00
0005434443789	6306	Economy	4000.00
0005433497134	6306	Economy	4000.00
0005433497122	6306	Economy	4000.00
0005434925986	6306	Economy	4000.00
0005434443803	6306	Economy	4000.00
0005434925988	6306	Economy	4000.00
0005434443799	6306	Economy	4000.00
0005433497124	6306	Economy	4000.00
0005434443793	6306	Economy	4000.00
0005433497149	6306	Economy	4000.00
0005434443790	6306	Economy	4000.00
0005434443797	6306	Economy	4000.00
0005433497130	6306	Economy	4000.00
0005434925985	6306	Economy	4000.00
0005434925972	6306	Economy	4000.00
0005434443787	6306	Economy	4000.00
0005434925970	6306	Economy	4000.00
0005434443792	6306	Economy	4000.00
0005433497128	6306	Economy	4000.00
0005433497125	6306	Economy	4000.00
0005433497142	6306	Economy	4000.00
0005434925981	6306	Economy	4000.00
0005434925966	6306	Economy	4000.00
0005434925974	6306	Economy	4000.00
0005433497151	6306	Economy	4000.00
0005434925979	6306	Economy	4000.00
0005434443800	6306	Economy	4000.00
0005433496928	20310	Business	11900.00
0005434443632	20310	Business	11900.00
0005434443668	20310	Business	11900.00
0005433496925	20310	Business	11900.00
0005434925617	20310	Business	11900.00
0005434443660	20310	Business	11900.00
0005434443700	20310	Business	11900.00
0005434443580	20310	Business	11900.00
0005434925616	20310	Business	11900.00
0005433496854	20310	Business	11900.00
0005433496775	20310	Economy	4000.00
0005434925615	20310	Economy	4000.00
0005434925630	20310	Economy	4000.00
0005434443581	20310	Economy	4000.00
0005434443606	20310	Economy	4000.00
0005434925614	20310	Economy	4000.00
0005433497020	20310	Economy	4000.00
0005433496822	20310	Economy	4000.00
0005434443647	20310	Economy	4400.00
0005433496752	20310	Economy	4400.00
0005434925653	20310	Economy	4000.00
0005434443641	20310	Economy	4000.00
0005434925634	20310	Economy	4000.00
0005434925700	20310	Economy	4000.00
0005434443569	20310	Economy	4000.00
0005434443644	20310	Economy	4000.00
0005434443708	20310	Economy	4000.00
0005434925682	20310	Economy	4000.00
0005434443633	20310	Economy	4000.00
0005434443605	20310	Economy	4000.00
0005433496737	20310	Economy	4000.00
0005434925477	20310	Economy	4000.00
0005433496872	20310	Economy	4000.00
0005434925706	20310	Economy	4000.00
0005434925637	20310	Economy	4000.00
0005433496969	20310	Economy	4000.00
0005433496947	20310	Economy	4000.00
0005434925528	20310	Economy	4000.00
0005434443667	20310	Economy	4000.00
0005434925550	20310	Economy	4000.00
0005434925519	20310	Economy	4000.00
0005433496999	20310	Economy	4000.00
0005433496750	20310	Economy	4000.00
0005434925496	20310	Economy	4000.00
0005434925670	20310	Economy	4000.00
0005433496965	20310	Economy	4000.00
0005434443552	20310	Economy	4000.00
0005434925701	20310	Economy	4000.00
0005433496849	20310	Economy	4000.00
0005434925628	20310	Economy	4000.00
0005433496873	20310	Economy	4000.00
0005434925705	20310	Economy	4000.00
0005434925629	20310	Economy	4000.00
0005433496818	20310	Economy	4000.00
0005434925549	20310	Economy	4000.00
0005434925478	20310	Economy	4000.00
0005433496823	20310	Economy	4000.00
0005434925535	20310	Economy	4000.00
0005434443584	20310	Economy	4000.00
0005433496751	20310	Economy	4000.00
0005434925526	20310	Economy	4000.00
0005433496753	20310	Economy	4000.00
0005434925672	20310	Economy	4000.00
0005434925631	20310	Economy	4000.00
0005433496913	20310	Economy	4000.00
0005433496736	20310	Economy	4000.00
0005433496835	20310	Economy	4000.00
0005434925633	20310	Economy	4000.00
0005434443583	20310	Economy	4000.00
0005434925581	20310	Economy	4000.00
0005434925702	20310	Economy	4000.00
0005433497021	20310	Economy	4000.00
0005434925579	20310	Economy	4000.00
0005434925551	20310	Economy	4000.00
0005434925671	20310	Economy	4000.00
0005434443722	20310	Economy	4000.00
0005434925632	20310	Economy	4000.00
0005435242997	12171	Business	41200.00
0005432783366	12171	Business	41200.00
0005435243002	12171	Business	41200.00
0005432783502	12171	Business	41200.00
0005432783922	12171	Business	41200.00
0005435243009	12171	Business	41200.00
0005432783773	12171	Business	41200.00
0005432783854	12171	Business	41200.00
0005432783551	12171	Business	41200.00
0005435243017	12171	Business	41200.00
0005432783548	12171	Economy	13700.00
0005435242993	12171	Economy	13700.00
0005435242994	12171	Economy	13700.00
0005432783672	12171	Economy	13700.00
0005435243018	12171	Economy	13700.00
0005432783692	12171	Economy	13700.00
0005432783414	12171	Economy	13700.00
0005432783557	12171	Economy	13700.00
0005432783490	12171	Economy	15100.00
0005435243011	12171	Economy	15100.00
0005432783577	12171	Economy	15100.00
0005435243006	12171	Economy	13700.00
0005432783556	12171	Economy	13700.00
0005435243005	12171	Economy	13700.00
0005435242996	12171	Economy	13700.00
0005435243010	12171	Economy	13700.00
0005435243000	12171	Economy	13700.00
0005432783671	12171	Economy	13700.00
0005432783475	12171	Economy	13700.00
0005432783673	12171	Economy	13700.00
0005432783725	12171	Economy	13700.00
0005432783696	12171	Economy	13700.00
0005435243015	12171	Economy	13700.00
0005432783578	12171	Economy	13700.00
0005432783752	12171	Economy	13700.00
0005432783813	12171	Economy	13700.00
0005432783233	12171	Economy	13700.00
0005435242992	12171	Economy	13700.00
0005432783656	12171	Economy	13700.00
0005432783798	12171	Economy	13700.00
0005432783505	12171	Economy	13700.00
0005435242991	12171	Economy	13700.00
0005435243003	12171	Economy	13700.00
0005432783693	12171	Economy	13700.00
0005432783552	12171	Economy	13700.00
0005432783634	12171	Economy	13700.00
0005432783324	12171	Economy	13700.00
0005435242998	12171	Economy	13700.00
0005435243004	12171	Economy	13700.00
0005432783625	12171	Economy	13700.00
0005432783694	12171	Economy	13700.00
0005432783322	12171	Economy	13700.00
0005435243001	12171	Economy	13700.00
0005432783503	12171	Economy	13700.00
0005432783651	12171	Economy	13700.00
0005435242995	12171	Economy	13700.00
0005435243008	12171	Economy	13700.00
0005432783497	12171	Economy	13700.00
0005432783763	12171	Economy	13700.00
0005432783496	12171	Economy	13700.00
0005435242999	12171	Economy	13700.00
0005432783739	12171	Economy	13700.00
0005432783379	12171	Economy	13700.00
0005432783762	12171	Economy	13700.00
0005435243013	12171	Economy	13700.00
0005432783530	12171	Economy	13700.00
0005435243016	12171	Economy	13700.00
0005435243012	12171	Economy	13700.00
0005435243007	12171	Economy	13700.00
0005432783323	12171	Economy	13700.00
0005432783700	12171	Economy	13700.00
0005432783504	12171	Economy	13700.00
0005435243014	12171	Economy	13700.00
0005432783695	12171	Economy	13700.00
0005432784040	15430	Business	41200.00
0005435242713	15430	Business	41200.00
0005435242753	15430	Business	41200.00
0005432784038	15430	Business	41200.00
0005435242798	15430	Business	41200.00
0005432784018	15430	Business	41200.00
0005435242751	15430	Business	41200.00
0005435242681	15430	Business	41200.00
0005432784019	15430	Business	41200.00
0005435242793	15430	Business	41200.00
0005432784042	15430	Business	41200.00
0005435242582	15430	Economy	13700.00
0005435242737	15430	Economy	13700.00
0005432783998	15430	Economy	13700.00
0005432784034	15430	Economy	13700.00
0005432784014	15430	Economy	13700.00
0005432784023	15430	Economy	13700.00
0005432784049	15430	Economy	13700.00
0005435242667	15430	Economy	13700.00
0005432784046	15430	Economy	13700.00
0005435242738	15430	Economy	13700.00
0005432784000	15430	Economy	15100.00
0005432784009	15430	Economy	15100.00
0005435242764	15430	Economy	15100.00
0005435242583	15430	Economy	15100.00
0005432784003	15430	Economy	15100.00
0005432784036	15430	Economy	13700.00
0005432783996	15430	Economy	13700.00
0005435242716	15430	Economy	13700.00
0005432784043	15430	Economy	13700.00
0005432784010	15430	Economy	13700.00
0005435242714	15430	Economy	13700.00
0005432783999	15430	Economy	13700.00
0005432784008	15430	Economy	13700.00
0005432784001	15430	Economy	13700.00
0005432784024	15430	Economy	13700.00
0005435242746	15430	Economy	13700.00
0005432784039	15430	Economy	13700.00
0005435242797	15430	Economy	13700.00
0005432784029	15430	Economy	13700.00
0005432784005	15430	Economy	13700.00
0005432784017	15430	Economy	13700.00
0005432784026	15430	Economy	13700.00
0005432784045	15430	Economy	13700.00
0005432784016	15430	Economy	13700.00
0005432784032	15430	Economy	13700.00
0005435242754	15430	Economy	13700.00
0005435242639	15430	Economy	13700.00
0005435242640	15430	Economy	13700.00
0005435242718	15430	Economy	13700.00
0005432784007	15430	Economy	13700.00
0005432784012	15430	Economy	13700.00
0005432784041	15430	Economy	13700.00
0005435242656	15430	Economy	13700.00
0005432784020	15430	Economy	13700.00
0005432784028	15430	Economy	13700.00
0005432783997	15430	Economy	13700.00
0005435242745	15430	Economy	13700.00
0005432784004	15430	Economy	13700.00
0005432784044	15430	Economy	13700.00
0005435242794	15430	Economy	13700.00
0005435242803	15430	Economy	13700.00
0005432784025	15430	Economy	13700.00
0005435242816	15430	Economy	13700.00
0005432784030	15430	Economy	13700.00
0005432784047	15430	Economy	13700.00
0005432784027	15430	Economy	13700.00
0005432784015	15430	Economy	13700.00
0005432784037	15430	Economy	13700.00
0005432784011	15430	Economy	13700.00
0005432784031	15430	Economy	13700.00
0005432784035	15430	Economy	13700.00
0005435242742	15430	Economy	13700.00
0005435242743	15430	Economy	13700.00
0005435242712	15430	Economy	13700.00
0005432784033	15430	Economy	13700.00
0005435242668	15430	Economy	13700.00
0005432784048	15430	Economy	13700.00
0005432784002	15430	Economy	13700.00
0005432784006	15430	Economy	13700.00
0005432784013	15430	Economy	13700.00
0005432784021	15430	Economy	13700.00
0005432784022	15430	Economy	13700.00
0005435242806	15430	Economy	13700.00
0005435242788	15430	Economy	13700.00
0005434878096	10103	Business	49700.00
0005434877882	10103	Business	49700.00
0005434877821	10103	Business	49700.00
0005434878173	10103	Business	49700.00
0005434878018	10103	Business	49700.00
0005434878024	10103	Business	49700.00
0005434878056	10103	Business	49700.00
0005434758887	10103	Business	49700.00
0005434877720	10103	Business	49700.00
0005434910127	10103	Business	49700.00
0005434878332	10103	Business	49700.00
0005434910128	10103	Business	49700.00
0005434877822	10103	Business	49700.00
0005434878026	10103	Business	49700.00
0005434877945	10103	Business	49700.00
0005434878333	10103	Business	49700.00
0005434877697	10103	Business	49700.00
0005434877910	10103	Economy	16600.00
0005434877947	10103	Economy	16600.00
0005434878001	10103	Economy	16600.00
0005434877443	10103	Economy	16600.00
0005434877761	10103	Economy	16600.00
0005434877695	10103	Economy	16600.00
0005434878003	10103	Economy	16600.00
0005434878167	10103	Economy	16600.00
0005434877909	10103	Economy	16600.00
0005434877933	10103	Economy	16600.00
0005434878170	10103	Economy	16600.00
0005434877458	10103	Economy	18200.00
0005434878027	10103	Economy	18200.00
0005434878250	10103	Economy	18200.00
0005434877704	10103	Economy	16600.00
0005434877966	10103	Economy	16600.00
0005434877354	10103	Economy	16600.00
0005434877164	10103	Economy	16600.00
0005434878087	10103	Economy	16600.00
0005434878174	10103	Economy	16600.00
0005434878199	10103	Economy	16600.00
0005435913947	10103	Economy	16600.00
0005434878433	10103	Economy	16600.00
0005434877747	10103	Economy	16600.00
0005435913953	10103	Economy	16600.00
0005434877698	10103	Economy	16600.00
0005434877626	10103	Economy	16600.00
0005434877944	10103	Economy	16600.00
0005434877785	10103	Economy	16600.00
0005434877536	10103	Economy	16600.00
0005434878295	10103	Economy	16600.00
0005435913950	10103	Economy	16600.00
0005434877703	10103	Economy	16600.00
0005434878354	10103	Economy	16600.00
0005434877661	10103	Economy	16600.00
0005435913952	10103	Economy	16600.00
0005435913951	10103	Economy	16600.00
0005434878132	10103	Economy	16600.00
0005434877751	10103	Economy	16600.00
0005434878432	10103	Economy	16600.00
0005434877353	10103	Economy	16600.00
0005434877923	10103	Economy	16600.00
0005434878075	10103	Economy	16600.00
0005434877696	10103	Economy	16600.00
0005434877956	10103	Economy	16600.00
0005434877705	10103	Economy	16600.00
0005434878198	10103	Economy	16600.00
0005434878055	10103	Economy	16600.00
0005434878175	10103	Economy	16600.00
0005434878086	10103	Economy	16600.00
0005434877719	10103	Economy	16600.00
0005434758882	10103	Economy	16600.00
0005434910124	10103	Economy	16600.00
0005434758881	10103	Economy	16600.00
0005434910126	10103	Economy	16600.00
0005435913948	10103	Economy	16600.00
0005434877750	10103	Economy	16600.00
0005434877780	10103	Economy	16600.00
0005434878081	10103	Economy	16600.00
0005434877686	10103	Economy	16600.00
0005434877948	10103	Economy	16600.00
0005435913949	10103	Economy	16600.00
0005434878009	10103	Economy	16600.00
0005434910125	10103	Economy	16600.00
0005435913954	10103	Economy	16600.00
0005434878002	10103	Economy	16600.00
0005434877788	10103	Economy	16600.00
0005434878251	10103	Economy	16600.00
0005434878249	10103	Economy	16600.00
0005434877907	10103	Economy	16600.00
0005434878202	10103	Economy	16600.00
0005434878023	10103	Economy	16600.00
0005434878117	10103	Economy	16600.00
0005434878220	10103	Economy	16600.00
0005434877848	10103	Economy	16600.00
0005434877537	10103	Economy	16600.00
0005434877881	10103	Economy	16600.00
0005434878085	10103	Economy	16600.00
0005434878221	10103	Economy	16600.00
0005434877837	10103	Economy	16600.00
0005434877784	10103	Economy	16600.00
0005434877899	10103	Economy	16600.00
0005434878681	14614	Business	49700.00
0005434878690	14614	Business	49700.00
0005434878702	14614	Business	49700.00
0005434878703	14614	Business	49700.00
0005434878731	14614	Business	49700.00
0005434878700	14614	Business	49700.00
0005434878697	14614	Business	49700.00
0005434878684	14614	Business	49700.00
0005434878765	14614	Business	49700.00
0005434878740	14614	Business	49700.00
0005434878709	14614	Business	49700.00
0005434878678	14614	Business	49700.00
0005434878723	14614	Business	49700.00
0005434878705	14614	Business	49700.00
0005434878729	14614	Business	49700.00
0005434878682	14614	Business	49700.00
0005434878757	14614	Business	49700.00
0005434878683	14614	Economy	16600.00
0005434878716	14614	Economy	16600.00
0005434878730	14614	Economy	16600.00
0005434878706	14614	Economy	16600.00
0005434878743	14614	Economy	16600.00
0005435913919	14614	Economy	16600.00
0005434878744	14614	Economy	16600.00
0005434878724	14614	Economy	16600.00
0005434878714	14614	Economy	16600.00
0005434878733	14614	Economy	16600.00
0005434878677	14614	Economy	16600.00
0005434878722	14614	Economy	16600.00
0005434878752	14614	Economy	18200.00
0005434878674	14614	Economy	18200.00
0005434878761	14614	Economy	18200.00
0005434878747	14614	Economy	16600.00
0005434878701	14614	Economy	16600.00
0005434878712	14614	Economy	16600.00
0005434878735	14614	Economy	16600.00
0005434878680	14614	Economy	16600.00
0005434878688	14614	Economy	16600.00
0005434878675	14614	Economy	16600.00
0005434878726	14614	Economy	16600.00
0005434878755	14614	Economy	16600.00
0005434878766	14614	Economy	16600.00
0005434878763	14614	Economy	16600.00
0005434910103	14614	Economy	16600.00
0005434878762	14614	Economy	16600.00
0005434878698	14614	Economy	16600.00
0005434878695	14614	Economy	16600.00
0005434878707	14614	Economy	16600.00
0005434878751	14614	Economy	16600.00
0005434758906	14614	Economy	16600.00
0005434878710	14614	Economy	16600.00
0005434878692	14614	Economy	16600.00
0005434878750	14614	Economy	16600.00
0005434878689	14614	Economy	16600.00
0005434878691	14614	Economy	16600.00
0005434878685	14614	Economy	16600.00
0005434878718	14614	Economy	16600.00
0005434878679	14614	Economy	16600.00
0005435913896	14614	Economy	16600.00
0005434878720	14614	Economy	16600.00
0005434878727	14614	Economy	16600.00
0005434878704	14614	Economy	16600.00
0005434878715	14614	Economy	16600.00
0005434878699	14614	Economy	16600.00
0005434878732	14614	Economy	16600.00
0005434878742	14614	Economy	16600.00
0005434878728	14614	Economy	16600.00
0005434878759	14614	Economy	16600.00
0005434878676	14614	Economy	16600.00
0005434878764	14614	Economy	16600.00
0005434878721	14614	Economy	16600.00
0005434878739	14614	Economy	16600.00
0005434878738	14614	Economy	16600.00
0005434878749	14614	Economy	16600.00
0005434878717	14614	Economy	16600.00
0005434878708	14614	Economy	16600.00
0005434878686	14614	Economy	16600.00
0005434878737	14614	Economy	16600.00
0005434878673	14614	Economy	16600.00
0005434758905	14614	Economy	16600.00
0005434878696	14614	Economy	16600.00
0005434878713	14614	Economy	16600.00
0005434878687	14614	Economy	16600.00
0005434878734	14614	Economy	16600.00
0005434878753	14614	Economy	16600.00
0005434878756	14614	Economy	16600.00
0005434878711	14614	Economy	16600.00
0005434878754	14614	Economy	16600.00
0005434878745	14614	Economy	16600.00
0005434878725	14614	Economy	16600.00
0005434878760	14614	Economy	16600.00
0005434878758	14614	Economy	16600.00
0005434878672	14614	Economy	16600.00
0005434878741	14614	Economy	16600.00
0005434878719	14614	Economy	16600.00
0005434878694	14614	Economy	16600.00
0005434878746	14614	Economy	16600.00
0005434878736	14614	Economy	16600.00
0005434878748	14614	Economy	16600.00
0005434910104	14614	Economy	16600.00
0005434878693	14614	Economy	16600.00
0005434251946	9215	Economy	22400.00
0005435660196	9215	Economy	20300.00
0005435660191	9215	Economy	20300.00
0005435660201	9215	Economy	20300.00
0005434251988	9215	Economy	20300.00
0005434251978	9215	Economy	20300.00
0005435660193	9215	Economy	20300.00
0005435660200	9215	Economy	20300.00
0005435660192	9215	Economy	20300.00
0005435660198	9215	Economy	20300.00
0005435660194	9215	Economy	20300.00
0005434251961	9215	Economy	20300.00
0005435660199	9215	Economy	20300.00
0005435660197	9215	Economy	20300.00
0005435660190	9215	Economy	20300.00
0005435660195	9215	Economy	20300.00
0005434251979	9215	Economy	20300.00
0005434252010	24658	Economy	22400.00
0005435660105	24658	Economy	22400.00
0005435660042	24658	Economy	20300.00
0005435660063	24658	Economy	20300.00
0005434252016	24658	Economy	20300.00
0005434252018	24658	Economy	20300.00
0005434252011	24658	Economy	20300.00
0005435660102	24658	Economy	20300.00
0005435660103	24658	Economy	20300.00
0005434252017	24658	Economy	20300.00
0005435660137	24658	Economy	20300.00
0005435660085	24658	Economy	20300.00
0005434252012	24658	Economy	20300.00
0005434252015	24658	Economy	20300.00
0005434252013	24658	Economy	20300.00
0005434252009	24658	Economy	20300.00
0005435660041	24658	Economy	20300.00
0005434252014	24658	Economy	20300.00
0005432966916	2801	Business	33000.00
0005432966818	2801	Business	33000.00
0005433680788	2801	Business	33000.00
0005433680812	2801	Business	33000.00
0005433680831	2801	Business	33000.00
0005433680784	2801	Business	33000.00
0005433680802	2801	Business	33000.00
0005433680819	2801	Business	33000.00
0005432966761	2801	Business	33000.00
0005432966863	2801	Business	33000.00
0005432966853	2801	Business	33000.00
0005433680805	2801	Business	33000.00
0005432966847	2801	Economy	11000.00
0005433680813	2801	Economy	11000.00
0005433680820	2801	Economy	11000.00
0005432966915	2801	Economy	11000.00
0005433680806	2801	Economy	11000.00
0005433680800	2801	Economy	11000.00
0005433680796	2801	Economy	11000.00
0005433680827	2801	Economy	11000.00
0005432222811	2801	Economy	11000.00
0005433680823	2801	Economy	12100.00
0005432966747	2801	Economy	12100.00
0005433680833	2801	Economy	12100.00
0005432222809	2801	Economy	12100.00
0005433680786	2801	Economy	12100.00
0005432966845	2801	Economy	11000.00
0005433680790	2801	Economy	11000.00
0005433680791	2801	Economy	11000.00
0005433680792	2801	Economy	11000.00
0005433680799	2801	Economy	11000.00
0005433680816	2801	Economy	11000.00
0005433680824	2801	Economy	11000.00
0005433680795	2801	Economy	11000.00
0005432966882	2801	Economy	11000.00
0005433680808	2801	Economy	11000.00
0005432966821	2801	Economy	11000.00
0005432966917	2801	Economy	11000.00
0005432966857	2801	Economy	11000.00
0005433680821	2801	Economy	11000.00
0005433680815	2801	Economy	11000.00
0005432966913	2801	Economy	11000.00
0005432966912	2801	Economy	11000.00
0005433680825	2801	Economy	11000.00
0005432966838	2801	Economy	11000.00
0005433680810	2801	Economy	11000.00
0005432966763	2801	Economy	11000.00
0005433680826	2801	Economy	11000.00
0005433680797	2801	Economy	11000.00
0005432966874	2801	Economy	11000.00
0005432222808	2801	Economy	11000.00
0005432966883	2801	Economy	11000.00
0005433680794	2801	Economy	11000.00
0005433680829	2801	Economy	11000.00
0005433680789	2801	Economy	11000.00
0005432222810	2801	Economy	11000.00
0005432966846	2801	Economy	11000.00
0005432966794	2801	Economy	11000.00
0005433680811	2801	Economy	11000.00
0005432966746	2801	Economy	11000.00
0005432966762	2801	Economy	11000.00
0005433680817	2801	Economy	11000.00
0005432966932	2801	Economy	11000.00
0005433680793	2801	Economy	11000.00
0005432966884	2801	Economy	11000.00
0005432222807	2801	Economy	11000.00
0005433684429	2801	Economy	11000.00
0005433680801	2801	Economy	11000.00
0005432966795	2801	Economy	11000.00
0005433680822	2801	Economy	11000.00
0005433680818	2801	Economy	11000.00
0005433680798	2801	Economy	11000.00
0005432966856	2801	Economy	11000.00
0005433684430	2801	Economy	11000.00
0005432966832	2801	Economy	11000.00
0005432966748	2801	Economy	11000.00
0005433680785	2801	Economy	11000.00
0005433680807	2801	Economy	11000.00
0005432966691	2801	Economy	11000.00
0005433680803	2801	Economy	11000.00
0005433680832	2801	Economy	11000.00
0005433680809	2801	Economy	11000.00
0005433680830	2801	Economy	11000.00
0005433680814	2801	Economy	11000.00
0005433680787	2801	Economy	11000.00
0005432966774	2801	Economy	11000.00
0005433680828	2801	Economy	11000.00
0005433680804	2801	Economy	11000.00
0005433680464	29146	Business	33000.00
0005433680447	29146	Business	33000.00
0005433680674	29146	Business	33000.00
0005433680501	29146	Business	33000.00
0005432967059	29146	Business	33000.00
0005433680460	29146	Business	33000.00
0005433680532	29146	Business	33000.00
0005433680346	29146	Business	33000.00
0005432967056	29146	Business	33000.00
0005432967067	29146	Economy	11000.00
0005433680414	29146	Economy	11000.00
0005433680381	29146	Economy	11000.00
0005432967058	29146	Economy	11000.00
0005432967079	29146	Economy	11000.00
0005433680417	29146	Economy	11000.00
0005432967062	29146	Economy	11000.00
0005432967054	29146	Economy	11000.00
0005433680463	29146	Economy	12100.00
0005433680451	29146	Economy	12100.00
0005432967075	29146	Economy	12100.00
0005432967069	29146	Economy	12100.00
0005432967071	29146	Economy	11000.00
0005433680522	29146	Economy	11000.00
0005433680496	29146	Economy	11000.00
0005432967061	29146	Economy	11000.00
0005433680446	29146	Economy	11000.00
0005432967066	29146	Economy	11000.00
0005433680459	29146	Economy	11000.00
0005433680160	29146	Economy	11000.00
0005433680117	29146	Economy	11000.00
0005432967076	29146	Economy	11000.00
0005433680461	29146	Economy	11000.00
0005433680268	29146	Economy	11000.00
0005433680306	29146	Economy	11000.00
0005433680478	29146	Economy	11000.00
0005432005229	29146	Economy	11000.00
0005432967072	29146	Economy	11000.00
0005433680524	29146	Economy	11000.00
0005433680413	29146	Economy	11000.00
0005433680528	29146	Economy	11000.00
0005432967073	29146	Economy	11000.00
0005433680318	29146	Economy	11000.00
0005433680449	29146	Economy	11000.00
0005433680273	29146	Economy	11000.00
0005432967065	29146	Economy	11000.00
0005433684418	29146	Economy	11000.00
0005433680148	29146	Economy	11000.00
0005432967060	29146	Economy	11000.00
0005433680450	29146	Economy	11000.00
0005433680348	29146	Economy	11000.00
0005433680439	29146	Economy	11000.00
0005433680311	29146	Economy	11000.00
0005432005228	29146	Economy	11000.00
0005433680448	29146	Economy	11000.00
0005432967070	29146	Economy	11000.00
0005432967057	29146	Economy	11000.00
0005433680445	29146	Economy	11000.00
0005432967078	29146	Economy	11000.00
0005433680581	29146	Economy	11000.00
0005433680394	29146	Economy	11000.00
0005433680444	29146	Economy	11000.00
0005433680276	29146	Economy	11000.00
0005432967077	29146	Economy	11000.00
0005433684417	29146	Economy	11000.00
0005432967074	29146	Economy	11000.00
0005432967063	29146	Economy	11000.00
0005432967068	29146	Economy	11000.00
0005432967055	29146	Economy	11000.00
0005433680393	29146	Economy	11000.00
0005433680156	29146	Economy	11000.00
0005432005227	29146	Economy	11000.00
0005433680580	29146	Economy	11000.00
0005433680349	29146	Economy	11000.00
0005433680455	29146	Economy	11000.00
0005433680458	29146	Economy	11000.00
0005433680523	29146	Economy	11000.00
0005432967064	29146	Economy	11000.00
0005433680506	29146	Economy	11000.00
0005433633962	9325	Business	132900.00
0005432755091	9325	Business	132900.00
0005433615020	9325	Business	132900.00
0005433615016	9325	Business	132900.00
0005433614975	9325	Business	132900.00
0005433633976	9325	Business	132900.00
0005433615027	9325	Business	132900.00
0005433615007	9325	Business	132900.00
0005433615006	9325	Business	132900.00
0005433614963	9325	Business	132900.00
0005434163570	9325	Business	132900.00
0005433614972	9325	Business	132900.00
0005434163591	9325	Business	132900.00
0005433633974	9325	Business	132900.00
0005434163579	9325	Business	132900.00
0005433614995	9325	Business	132900.00
0005433615010	9325	Business	132900.00
0005433614993	9325	Business	132900.00
0005433615012	9325	Business	132900.00
0005433615024	9325	Business	132900.00
0005433615021	9325	Business	132900.00
0005433615015	9325	Business	132900.00
0005432756864	9325	Business	132900.00
0005433633958	9325	Economy	48700.00
0005433577874	9325	Economy	48700.00
0005433633948	9325	Economy	48700.00
0005433614990	9325	Economy	48700.00
0005433614997	9325	Economy	48700.00
0005433614967	9325	Economy	48700.00
0005433633963	9325	Economy	44300.00
0005433615032	9325	Economy	44300.00
0005433633947	9325	Economy	44300.00
0005433614959	9325	Economy	44300.00
0005432145120	9325	Economy	44300.00
0005433577877	9325	Economy	44300.00
0005433577876	9325	Economy	44300.00
0005433633981	9325	Economy	44300.00
0005433633973	9325	Economy	44300.00
0005433633971	9325	Economy	44300.00
0005433615033	9325	Economy	44300.00
0005433615011	9325	Economy	44300.00
0005433633979	9325	Economy	44300.00
0005433614970	9325	Economy	44300.00
0005434163561	9325	Economy	44300.00
0005433615031	9325	Economy	44300.00
0005433577870	9325	Economy	44300.00
0005434163578	9325	Economy	44300.00
0005433615018	9325	Economy	44300.00
0005433615003	9325	Economy	44300.00
0005433614985	9325	Economy	44300.00
0005432755092	9325	Economy	44300.00
0005433614996	9325	Economy	44300.00
0005432755090	9325	Economy	44300.00
0005433614986	9325	Economy	44300.00
0005433633954	9325	Economy	44300.00
0005433633956	9325	Economy	44300.00
0005433633952	9325	Economy	44300.00
0005433577881	9325	Economy	44300.00
0005433615005	9325	Economy	44300.00
0005433614988	9325	Economy	44300.00
0005434163569	9325	Economy	44300.00
0005433633975	9325	Economy	44300.00
0005433633970	9325	Economy	44300.00
0005433615004	9325	Economy	44300.00
0005433614980	9325	Economy	44300.00
0005433633969	9325	Economy	44300.00
0005433577868	9325	Economy	44300.00
0005433615013	9325	Economy	44300.00
0005433615028	9325	Economy	44300.00
0005433614971	9325	Economy	44300.00
0005433615017	9325	Economy	44300.00
0005433615030	9325	Economy	44300.00
0005433614989	9325	Economy	44300.00
0005434163590	9325	Economy	44300.00
0005433633950	9325	Economy	44300.00
0005433615001	9325	Economy	44300.00
0005433614976	9325	Economy	44300.00
0005433614984	9325	Economy	44300.00
0005433633972	9325	Economy	44300.00
0005433614983	9325	Economy	44300.00
0005433633959	9325	Economy	44300.00
0005433577878	9325	Economy	48700.00
0005434272184	9325	Economy	48700.00
0005432145119	9325	Economy	48700.00
0005433615029	9325	Economy	48700.00
0005433633964	9325	Economy	44300.00
0005433614968	9325	Economy	44300.00
0005433614998	9325	Economy	44300.00
0005433577871	9325	Economy	48700.00
0005433633966	9325	Economy	44300.00
0005433614994	9325	Economy	44300.00
0005433577875	9325	Economy	44300.00
0005433633946	9325	Economy	44300.00
0005433633978	9325	Economy	44300.00
0005432145121	9325	Economy	44300.00
0005433614978	9325	Economy	44300.00
0005433615019	9325	Economy	44300.00
0005433577879	9325	Economy	44300.00
0005433614999	9325	Economy	44300.00
0005433615002	9325	Economy	44300.00
0005434163562	9325	Economy	44300.00
0005433615022	9325	Economy	44300.00
0005433633957	9325	Economy	44300.00
0005433633965	9325	Economy	44300.00
0005433614982	9325	Economy	44300.00
0005433614974	9325	Economy	44300.00
0005433614979	9325	Economy	44300.00
0005433614992	9325	Economy	44300.00
0005433633967	9325	Economy	44300.00
0005433614977	9325	Economy	44300.00
0005433614958	9325	Economy	44300.00
0005433577869	9325	Economy	44300.00
0005433614966	9325	Economy	44300.00
0005433614960	9325	Economy	44300.00
0005433615026	9325	Economy	44300.00
0005433577880	9325	Economy	44300.00
0005433633951	9325	Economy	44300.00
0005433614961	9325	Economy	44300.00
0005433633949	9325	Economy	44300.00
0005433614981	9325	Economy	44300.00
0005433615023	9325	Economy	44300.00
0005433633977	9325	Economy	44300.00
0005433614965	9325	Economy	44300.00
0005433615014	9325	Economy	44300.00
0005434163577	9325	Economy	44300.00
0005433614991	9325	Economy	44300.00
0005433577873	9325	Economy	44300.00
0005432756865	9325	Economy	44300.00
0005433577872	9325	Economy	44300.00
0005433615025	9325	Economy	44300.00
0005433614964	9325	Economy	44300.00
0005433633953	9325	Economy	44300.00
0005433615009	9325	Economy	44300.00
0005433633968	9325	Economy	44300.00
0005433577867	9325	Economy	44300.00
0005433614969	9325	Economy	44300.00
0005433614973	9325	Economy	44300.00
0005433633955	9325	Economy	44300.00
0005432755093	9325	Economy	44300.00
0005433615000	9325	Economy	44300.00
0005433615008	9325	Economy	44300.00
0005434163572	9325	Economy	44300.00
0005433633980	9325	Economy	44300.00
0005433633960	9325	Economy	44300.00
0005433633961	9325	Economy	44300.00
0005433614962	9325	Economy	44300.00
0005433614987	9325	Economy	44300.00
0005434163586	9325	Economy	44300.00
0005432756863	9325	Economy	44300.00
0005433614489	25267	Business	132900.00
0005433633680	25267	Business	132900.00
0005433614413	25267	Business	132900.00
0005433633672	25267	Business	132900.00
0005433614414	25267	Business	132900.00
0005433633652	25267	Business	132900.00
0005433614117	25267	Business	132900.00
0005434163658	25267	Business	132900.00
0005434273083	25267	Business	132900.00
0005433633575	25267	Business	132900.00
0005433614404	25267	Business	132900.00
0005433577765	25267	Business	132900.00
0005433614728	25267	Business	132900.00
0005433633632	25267	Business	132900.00
0005433614399	25267	Business	132900.00
0005434163657	25267	Business	132900.00
0005433614352	25267	Business	132900.00
0005433614252	25267	Business	132900.00
0005433633741	25267	Business	132900.00
0005433614713	25267	Business	132900.00
0005434163654	25267	Business	132900.00
0005433633673	25267	Business	132900.00
0005434272198	25267	Economy	48700.00
0005433577745	25267	Economy	48700.00
0005433577823	25267	Economy	48700.00
0005433633532	25267	Economy	48700.00
0005433614191	25267	Economy	44300.00
0005433633593	25267	Economy	44300.00
0005433633588	25267	Economy	44300.00
0005434163653	25267	Economy	44300.00
0005433614648	25267	Economy	44300.00
0005433614346	25267	Economy	44300.00
0005433633696	25267	Economy	44300.00
0005433614011	25267	Economy	44300.00
0005433633678	25267	Economy	44300.00
0005433614432	25267	Economy	44300.00
0005433614256	25267	Economy	44300.00
0005433614488	25267	Economy	44300.00
0005433614612	25267	Economy	44300.00
0005434273082	25267	Economy	44300.00
0005433614274	25267	Economy	44300.00
0005433614410	25267	Economy	44300.00
0005433633549	25267	Economy	44300.00
0005433614402	25267	Economy	44300.00
0005433614570	25267	Economy	44300.00
0005433614212	25267	Economy	44300.00
0005433614362	25267	Economy	44300.00
0005433633744	25267	Economy	44300.00
0005433577767	25267	Economy	44300.00
0005433577796	25267	Economy	44300.00
0005434163650	25267	Economy	44300.00
0005433614360	25267	Economy	44300.00
0005433577771	25267	Economy	44300.00
0005433577766	25267	Economy	44300.00
0005433614465	25267	Economy	44300.00
0005433614649	25267	Economy	44300.00
0005433577692	25267	Economy	44300.00
0005433577772	25267	Economy	44300.00
0005433614370	25267	Economy	44300.00
0005433613995	25267	Economy	44300.00
0005433614160	25267	Economy	44300.00
0005433633701	25267	Economy	44300.00
0005434163652	25267	Economy	44300.00
0005433614420	25267	Economy	44300.00
0005433614273	25267	Economy	44300.00
0005434163651	25267	Economy	44300.00
0005433577699	25267	Economy	44300.00
0005433633733	25267	Economy	44300.00
0005433614390	25267	Economy	44300.00
0005433633723	25267	Economy	44300.00
0005433614730	25267	Economy	44300.00
0005433633697	25267	Economy	44300.00
0005433633585	25267	Economy	44300.00
0005433614368	25267	Economy	44300.00
0005433577700	25267	Economy	44300.00
0005433633718	25267	Economy	44300.00
0005433633683	25267	Economy	48700.00
0005433577797	25267	Economy	48700.00
0005433614250	25267	Economy	48700.00
0005434163648	25267	Economy	48700.00
0005434163649	25267	Economy	48700.00
0005433633757	25267	Economy	44300.00
0005433614714	25267	Economy	44300.00
0005434163655	25267	Economy	44300.00
0005433614342	25267	Economy	44300.00
0005433614526	25267	Economy	48700.00
0005433614343	25267	Economy	44300.00
0005433614393	25267	Economy	44300.00
0005433614369	25267	Economy	44300.00
0005433614458	25267	Economy	44300.00
0005433614609	25267	Economy	44300.00
0005433633703	25267	Economy	44300.00
0005433614656	25267	Economy	44300.00
0005433577774	25267	Economy	44300.00
0005433633574	25267	Economy	44300.00
0005433614396	25267	Economy	44300.00
0005433577735	25267	Economy	44300.00
0005433633653	25267	Economy	44300.00
0005433614419	25267	Economy	44300.00
0005433633684	25267	Economy	44300.00
0005433614478	25267	Economy	44300.00
0005433614403	25267	Economy	44300.00
0005433614267	25267	Economy	44300.00
0005433633759	25267	Economy	44300.00
0005433614344	25267	Economy	44300.00
0005433633713	25267	Economy	44300.00
0005433633665	25267	Economy	44300.00
0005433577693	25267	Economy	44300.00
0005433614431	25267	Economy	44300.00
0005433614361	25267	Economy	44300.00
0005433614345	25267	Economy	44300.00
0005434273081	25267	Economy	44300.00
0005433614203	25267	Economy	44300.00
0005433633758	25267	Economy	44300.00
0005433633617	25267	Economy	44300.00
0005433614190	25267	Economy	44300.00
0005433577822	25267	Economy	44300.00
0005433614394	25267	Economy	44300.00
0005433614613	25267	Economy	44300.00
0005433633608	25267	Economy	44300.00
0005433614411	25267	Economy	44300.00
0005433614466	25267	Economy	44300.00
0005433614729	25267	Economy	44300.00
0005433633551	25267	Economy	44300.00
0005433614467	25267	Economy	44300.00
0005433633668	25267	Economy	44300.00
0005433633587	25267	Economy	44300.00
0005433633694	25267	Economy	44300.00
0005433633681	25267	Economy	44300.00
0005433614571	25267	Economy	44300.00
0005433577750	25267	Economy	44300.00
0005433614459	25267	Economy	44300.00
0005433614367	25267	Economy	44300.00
0005433614573	25267	Economy	44300.00
0005433614616	25267	Economy	44300.00
0005433614468	25267	Economy	44300.00
0005433614251	25267	Economy	44300.00
0005433633700	25267	Economy	44300.00
0005434163656	25267	Economy	44300.00
0005435856201	4245	Business	193100.00
0005432184965	4245	Business	193100.00
0005435947171	4245	Business	193100.00
0005435787342	4245	Business	193100.00
0005435856199	4245	Business	193100.00
0005435947209	4245	Business	193100.00
0005435854058	4245	Business	193100.00
0005435856188	4245	Business	193100.00
0005435947152	4245	Economy	64400.00
0005435947232	4245	Economy	64400.00
0005435947237	4245	Economy	64400.00
0005435947213	4245	Economy	64400.00
0005435856200	4245	Economy	64400.00
0005435947221	4245	Economy	64400.00
0005435947181	4245	Economy	64400.00
0005435947180	4245	Economy	64400.00
0005435947203	4245	Economy	64400.00
0005435947195	4245	Economy	64400.00
0005432184966	4245	Economy	64400.00
0005435947183	4245	Economy	64400.00
0005435947222	4245	Economy	64400.00
0005432571308	4245	Economy	64400.00
0005435947125	4245	Economy	64400.00
0005435947204	4245	Economy	64400.00
0005435947208	4245	Economy	64400.00
0005434271297	4245	Economy	64400.00
0005435856183	4245	Economy	64400.00
0005432571305	4245	Economy	64400.00
0005435854055	4245	Economy	64400.00
0005435854056	4245	Economy	70800.00
0005435947240	4245	Economy	64400.00
0005435856184	4245	Economy	64400.00
0005435787334	4245	Economy	64400.00
0005435854057	4245	Economy	64400.00
0005435947172	4245	Economy	64400.00
0005432184964	4245	Economy	64400.00
0005435947223	4245	Economy	64400.00
0005435856189	4245	Economy	64400.00
0005435947220	4245	Economy	64400.00
0005432571299	4245	Economy	64400.00
0005435947238	4245	Economy	64400.00
0005432571287	4245	Economy	64400.00
0005435947212	4245	Economy	64400.00
0005435856225	26562	Business	193100.00
0005435947338	26562	Business	193100.00
0005435986770	26562	Business	193100.00
0005435947339	26562	Business	193100.00
0005435856228	26562	Economy	64400.00
0005432571342	26562	Economy	64400.00
0005435787366	26562	Economy	64400.00
0005435947328	26562	Economy	64400.00
0005435986758	26562	Economy	64400.00
0005435986769	26562	Economy	64400.00
0005435986718	26562	Economy	64400.00
0005435986746	26562	Economy	64400.00
0005435947325	26562	Economy	64400.00
0005435856224	26562	Economy	64400.00
0005435947327	26562	Economy	64400.00
0005432571343	26562	Economy	64400.00
0005435856226	26562	Economy	64400.00
0005435947326	26562	Economy	64400.00
0005435856227	26562	Economy	64400.00
0005435947331	26562	Economy	64400.00
0005435947330	26562	Economy	64400.00
0005435947337	26562	Economy	64400.00
0005435947329	26562	Economy	64400.00
0005435947333	26562	Economy	64400.00
0005435986721	26562	Economy	64400.00
0005435947335	26562	Economy	64400.00
0005435986723	26562	Economy	64400.00
0005432571344	26562	Economy	64400.00
0005435947334	26562	Economy	64400.00
0005435947336	26562	Economy	64400.00
0005435787367	26562	Economy	64400.00
0005435947324	26562	Economy	64400.00
0005435947332	26562	Economy	64400.00
0005432571345	26562	Economy	64400.00
0005433074600	351	Business	21500.00
0005432948348	351	Business	21500.00
0005433074440	351	Business	21500.00
0005433569369	351	Business	21500.00
0005433074657	351	Business	21500.00
0005433569403	351	Business	21500.00
0005432948382	351	Business	21500.00
0005433569399	351	Business	21500.00
0005432238965	351	Business	21500.00
0005433569366	351	Business	21500.00
0005433074745	351	Business	21500.00
0005432948212	351	Business	21500.00
0005433569384	351	Business	21500.00
0005433569393	351	Business	21500.00
0005433074570	351	Business	21500.00
0005433569387	351	Business	21500.00
0005433569415	351	Business	21500.00
0005432948234	351	Business	21500.00
0005432948125	351	Business	21500.00
0005433074556	351	Business	21500.00
0005432238972	351	Business	21500.00
0005433569408	351	Business	21500.00
0005433569394	351	Business	21500.00
0005433569392	351	Business	21500.00
0005433569361	351	Business	21500.00
0005433569419	351	Business	21500.00
0005433569371	351	Economy	7900.00
0005433074645	351	Economy	7900.00
0005433569417	351	Economy	7900.00
0005433074609	351	Economy	7900.00
0005433569390	351	Economy	7900.00
0005432948233	351	Economy	7200.00
0005433569405	351	Economy	7200.00
0005432948123	351	Economy	7200.00
0005433074729	351	Economy	7200.00
0005432948213	351	Economy	7200.00
0005433074654	351	Economy	7200.00
0005433569368	351	Economy	7200.00
0005433569395	351	Economy	7200.00
0005432238969	351	Economy	7200.00
0005433569372	351	Economy	7200.00
0005433074442	351	Economy	7200.00
0005433569381	351	Economy	7200.00
0005433569426	351	Economy	7200.00
0005433569367	351	Economy	7200.00
0005433129262	351	Economy	7200.00
0005433569391	351	Economy	7200.00
0005433569424	351	Economy	7200.00
0005432948326	351	Economy	7200.00
0005433074670	351	Economy	7200.00
0005433569400	351	Economy	7200.00
0005433074569	351	Economy	7200.00
0005432948245	351	Economy	7200.00
0005432948360	351	Economy	7200.00
0005433074612	351	Economy	7200.00
0005433569416	351	Economy	7200.00
0005432948385	351	Economy	7200.00
0005433569425	351	Economy	7200.00
0005432948343	351	Economy	7200.00
0005433569377	351	Economy	7200.00
0005433569409	351	Economy	7200.00
0005433074622	351	Economy	7200.00
0005433569396	351	Economy	7200.00
0005432948363	351	Economy	7200.00
0005432948301	351	Economy	7200.00
0005433569414	351	Economy	7200.00
0005433569422	351	Economy	7200.00
0005432948124	351	Economy	7200.00
0005433569373	351	Economy	7200.00
0005433134131	351	Economy	7200.00
0005433569397	351	Economy	7200.00
0005433074746	351	Economy	7200.00
0005433074441	351	Economy	7200.00
0005432948275	351	Economy	7200.00
0005433074691	351	Economy	7200.00
0005433569389	351	Economy	7200.00
0005432948240	351	Economy	7200.00
0005433569411	351	Economy	7200.00
0005433129264	351	Economy	7200.00
0005432948443	351	Economy	7200.00
0005433569404	351	Economy	7200.00
0005433569402	351	Economy	7200.00
0005433569386	351	Economy	7200.00
0005433074620	351	Economy	7200.00
0005433074693	351	Economy	7200.00
0005433569412	351	Economy	7200.00
0005433569382	351	Economy	7200.00
0005432948299	351	Economy	7200.00
0005433074665	351	Economy	7900.00
0005433569364	351	Economy	7900.00
0005433074779	351	Economy	7900.00
0005432948342	351	Economy	7900.00
0005433134111	351	Economy	7900.00
0005433074639	351	Economy	7200.00
0005433569378	351	Economy	7200.00
0005433074653	351	Economy	7200.00
0005432948357	351	Economy	7200.00
0005433569376	351	Economy	7200.00
0005432948241	351	Economy	7900.00
0005433074643	351	Economy	7200.00
0005433569413	351	Economy	7200.00
0005433569421	351	Economy	7200.00
0005433074781	351	Economy	7200.00
0005432238971	351	Economy	7200.00
0005433569427	351	Economy	7200.00
0005433569406	351	Economy	7200.00
0005432948344	351	Economy	7200.00
0005433569401	351	Economy	7200.00
0005433569379	351	Economy	7200.00
0005432948334	351	Economy	7200.00
0005433569410	351	Economy	7200.00
0005432948330	351	Economy	7200.00
0005433074621	351	Economy	7200.00
0005433569365	351	Economy	7200.00
0005433569407	351	Economy	7200.00
0005432948371	351	Economy	7200.00
0005432948274	351	Economy	7200.00
0005432948353	351	Economy	7200.00
0005432238970	351	Economy	7200.00
0005433569374	351	Economy	7200.00
0005433074780	351	Economy	7200.00
0005432948316	351	Economy	7200.00
0005432948351	351	Economy	7200.00
0005432948413	351	Economy	7200.00
0005433569385	351	Economy	7200.00
0005432238966	351	Economy	7200.00
0005433074439	351	Economy	7200.00
0005433569418	351	Economy	7200.00
0005433569423	351	Economy	7200.00
0005433569420	351	Economy	7200.00
0005433074669	351	Economy	7200.00
0005433569375	351	Economy	7200.00
0005433129268	351	Economy	7200.00
0005433569398	351	Economy	7200.00
0005432948355	351	Economy	7200.00
0005432948282	351	Economy	7200.00
0005432948249	351	Economy	7200.00
0005432948221	351	Economy	7200.00
0005433569363	351	Economy	7200.00
0005433569370	351	Economy	7200.00
0005432948349	351	Economy	7200.00
0005433569388	351	Economy	7200.00
0005433074694	351	Economy	7200.00
0005432948436	351	Economy	7200.00
0005433074603	351	Economy	7200.00
0005433074499	351	Economy	7200.00
0005432948356	351	Economy	7200.00
0005432238968	351	Economy	7200.00
0005433074625	351	Economy	7200.00
0005433129265	351	Economy	7200.00
0005433074604	351	Economy	7200.00
0005433569360	351	Economy	7200.00
0005432948384	351	Economy	7200.00
0005432238967	351	Economy	7200.00
0005433569383	351	Economy	7200.00
0005432948350	351	Economy	7200.00
0005433569380	351	Economy	7200.00
0005433074504	351	Economy	7200.00
0005433569362	351	Economy	7200.00
0005433074608	351	Economy	7200.00
0005432948157	351	Economy	7200.00
0005433568556	11607	Business	21500.00
0005433568945	11607	Business	21500.00
0005432948663	11607	Business	21500.00
0005432948674	11607	Business	21500.00
0005433568458	11607	Business	21500.00
0005432948655	11607	Business	21500.00
0005432948642	11607	Business	21500.00
0005433568883	11607	Business	21500.00
0005432192337	11607	Business	21500.00
0005433134162	11607	Business	21500.00
0005433568789	11607	Business	21500.00
0005432192336	11607	Business	21500.00
0005433074859	11607	Business	21500.00
0005433131731	11607	Business	21500.00
0005433074864	11607	Business	21500.00
0005433134163	11607	Business	21500.00
0005432948679	11607	Business	21500.00
0005433568837	11607	Business	21500.00
0005433074855	11607	Business	21500.00
0005433134161	11607	Business	21500.00
0005432948665	11607	Business	21500.00
0005433568613	11607	Business	21500.00
0005433074858	11607	Business	21500.00
0005433074854	11607	Business	21500.00
0005433568677	11607	Business	21500.00
0005433074847	11607	Economy	7900.00
0005432948673	11607	Economy	7900.00
0005433568922	11607	Economy	7900.00
0005433568919	11607	Economy	7900.00
0005433568683	11607	Economy	7900.00
0005433131732	11607	Economy	7200.00
0005432948647	11607	Economy	7200.00
0005433568607	11607	Economy	7200.00
0005433568511	11607	Economy	7200.00
0005433568955	11607	Economy	7200.00
0005433074865	11607	Economy	7200.00
0005433074866	11607	Economy	7200.00
0005433568914	11607	Economy	7200.00
0005433074839	11607	Economy	7200.00
0005433074856	11607	Economy	7200.00
0005432948652	11607	Economy	7200.00
0005433568967	11607	Economy	7200.00
0005433134159	11607	Economy	7200.00
0005432948640	11607	Economy	7200.00
0005433131730	11607	Economy	7200.00
0005432192335	11607	Economy	7200.00
0005433568913	11607	Economy	7200.00
0005433131729	11607	Economy	7200.00
0005433568774	11607	Economy	7200.00
0005432948649	11607	Economy	7200.00
0005432948668	11607	Economy	7200.00
0005433568895	11607	Economy	7200.00
0005433568728	11607	Economy	7200.00
0005433568551	11607	Economy	7200.00
0005433568668	11607	Economy	7200.00
0005433568882	11607	Economy	7200.00
0005433568947	11607	Economy	7200.00
0005433568700	11607	Economy	7200.00
0005433568658	11607	Economy	7200.00
0005433568693	11607	Economy	7200.00
0005433568499	11607	Economy	7200.00
0005432948664	11607	Economy	7200.00
0005433568829	11607	Economy	7200.00
0005433074849	11607	Economy	7200.00
0005433568830	11607	Economy	7200.00
0005433568500	11607	Economy	7200.00
0005432948662	11607	Economy	7200.00
0005432948670	11607	Economy	7200.00
0005432948680	11607	Economy	7200.00
0005433568946	11607	Economy	7200.00
0005432948658	11607	Economy	7200.00
0005432948676	11607	Economy	7200.00
0005433568838	11607	Economy	7200.00
0005433074853	11607	Economy	7200.00
0005433568661	11607	Economy	7200.00
0005432948648	11607	Economy	7200.00
0005433074842	11607	Economy	7200.00
0005432948661	11607	Economy	7200.00
0005432948651	11607	Economy	7200.00
0005433568923	11607	Economy	7200.00
0005433074851	11607	Economy	7200.00
0005432948669	11607	Economy	7200.00
0005432948667	11607	Economy	7900.00
0005433074841	11607	Economy	7900.00
0005433568821	11607	Economy	7900.00
0005432948656	11607	Economy	7900.00
0005432948644	11607	Economy	7900.00
0005432948650	11607	Economy	7200.00
0005432948641	11607	Economy	7200.00
0005433074862	11607	Economy	7200.00
0005433568665	11607	Economy	7200.00
0005433568660	11607	Economy	7900.00
0005432948654	11607	Economy	7200.00
0005433134160	11607	Economy	7200.00
0005433074840	11607	Economy	7200.00
0005432948660	11607	Economy	7200.00
0005432948666	11607	Economy	7200.00
0005433131733	11607	Economy	7200.00
0005433568924	11607	Economy	7200.00
0005433568783	11607	Economy	7200.00
0005433074861	11607	Economy	7200.00
0005432948653	11607	Economy	7200.00
0005433568739	11607	Economy	7200.00
0005433074852	11607	Economy	7200.00
0005433074846	11607	Economy	7200.00
0005433568688	11607	Economy	7200.00
0005432948678	11607	Economy	7200.00
0005433074843	11607	Economy	7200.00
0005433568510	11607	Economy	7200.00
0005433568608	11607	Economy	7200.00
0005433568674	11607	Economy	7200.00
0005432948672	11607	Economy	7200.00
0005433568986	11607	Economy	7200.00
0005432948645	11607	Economy	7200.00
0005433568596	11607	Economy	7200.00
0005433568427	11607	Economy	7200.00
0005433074860	11607	Economy	7200.00
0005433568876	11607	Economy	7200.00
0005433568631	11607	Economy	7200.00
0005432948677	11607	Economy	7200.00
0005433074863	11607	Economy	7200.00
0005433568782	11607	Economy	7200.00
0005433568694	11607	Economy	7200.00
0005433568605	11607	Economy	7200.00
0005433568809	11607	Economy	7200.00
0005433074857	11607	Economy	7200.00
0005433568985	11607	Economy	7200.00
0005433074838	11607	Economy	7200.00
0005432948643	11607	Economy	7200.00
0005433568717	11607	Economy	7200.00
0005433074850	11607	Economy	7200.00
0005433074844	11607	Economy	7200.00
0005433568678	11607	Economy	7200.00
0005433568612	11607	Economy	7200.00
0005432948671	11607	Economy	7200.00
0005432948646	11607	Economy	7200.00
0005433568823	11607	Economy	7200.00
0005433074848	11607	Economy	7200.00
0005433074845	11607	Economy	7200.00
0005433568867	11607	Economy	7200.00
0005432948659	11607	Economy	7200.00
0005432948657	11607	Economy	7200.00
0005433568828	11607	Economy	7200.00
0005432948675	11607	Economy	7200.00
0005433568384	11607	Economy	7200.00
0005433817489	9986	Economy	6300.00
0005434732970	9986	Economy	6300.00
0005434732978	9986	Economy	6300.00
0005434732964	9986	Economy	6300.00
0005434732965	9986	Economy	6300.00
0005434732969	9986	Economy	6300.00
0005433817488	9986	Economy	6300.00
0005434732973	9986	Economy	6300.00
0005434732979	9986	Economy	6300.00
0005433817491	9986	Economy	6300.00
0005433817490	9986	Economy	6300.00
0005434732972	9986	Economy	6300.00
0005434733000	13922	Economy	6300.00
0005434732999	13922	Economy	6300.00
0005434732997	13922	Economy	6300.00
0005434732998	13922	Economy	6300.00
0005433817463	13922	Economy	6300.00
0005433817461	13922	Economy	6300.00
0005433754524	2330	Business	184500.00
0005432984977	2330	Business	184500.00
0005433434674	2330	Business	184500.00
0005432226092	2330	Business	184500.00
0005433754507	2330	Business	184500.00
0005433754500	2330	Business	184500.00
0005435982555	2330	Business	184500.00
0005432984904	2330	Business	184500.00
0005432984761	2330	Business	184500.00
0005433434554	2330	Business	184500.00
0005433754491	2330	Business	184500.00
0005435982564	2330	Business	184500.00
0005433754487	2330	Business	184500.00
0005435982539	2330	Business	184500.00
0005432226091	2330	Business	184500.00
0005432985012	2330	Business	184500.00
0005432984762	2330	Business	184500.00
0005433754505	2330	Business	184500.00
0005433754519	2330	Business	184500.00
0005435982534	2330	Business	184500.00
0005433434596	2330	Business	184500.00
0005435982529	2330	Business	184500.00
0005433434597	2330	Business	184500.00
0005432869490	2330	Business	184500.00
0005433434482	2330	Business	184500.00
0005435982568	2330	Business	184500.00
0005435982541	2330	Business	184500.00
0005432655595	2330	Business	184500.00
0005433434572	2330	Economy	67700.00
0005433754511	2330	Business	184500.00
0005432226088	2330	Economy	67700.00
0005433754488	2330	Economy	67700.00
0005433434574	2330	Economy	67700.00
0005432985003	2330	Economy	61500.00
0005433434562	2330	Economy	61500.00
0005433434527	2330	Economy	61500.00
0005434731148	2330	Economy	61500.00
0005432984850	2330	Economy	61500.00
0005433754522	2330	Economy	61500.00
0005432869491	2330	Economy	61500.00
0005435982557	2330	Economy	61500.00
0005432984962	2330	Economy	61500.00
0005433434594	2330	Economy	61500.00
0005435982537	2330	Economy	61500.00
0005435982532	2330	Economy	61500.00
0005435982536	2330	Economy	61500.00
0005432985059	2330	Economy	61500.00
0005433434599	2330	Economy	61500.00
0005432655603	2330	Economy	61500.00
0005433764691	2330	Economy	61500.00
0005433754542	2330	Economy	61500.00
0005435982540	2330	Economy	61500.00
0005433754489	2330	Economy	61500.00
0005434731161	2330	Economy	61500.00
0005435982528	2330	Economy	61500.00
0005433754502	2330	Economy	61500.00
0005432984993	2330	Economy	61500.00
0005433754506	2330	Economy	61500.00
0005433434471	2330	Economy	61500.00
0005433754490	2330	Economy	61500.00
0005434731150	2330	Economy	61500.00
0005432984930	2330	Economy	61500.00
0005435982558	2330	Economy	61500.00
0005433754543	2330	Economy	61500.00
0005432984963	2330	Economy	61500.00
0005433754534	2330	Economy	61500.00
0005433434619	2330	Economy	61500.00
0005433434587	2330	Economy	61500.00
0005433754516	2330	Economy	61500.00
0005435982535	2330	Economy	61500.00
0005433754533	2330	Economy	61500.00
0005432655606	2330	Economy	61500.00
0005435982538	2330	Economy	61500.00
0005433754525	2330	Economy	61500.00
0005433754536	2330	Economy	61500.00
0005433434621	2330	Economy	61500.00
0005433754535	2330	Economy	61500.00
0005432300295	2330	Economy	61500.00
0005432984836	2330	Economy	61500.00
0005432984903	2330	Economy	61500.00
0005433434715	2330	Economy	61500.00
0005433434561	2330	Economy	61500.00
0005433434483	2330	Economy	61500.00
0005432985016	2330	Economy	61500.00
0005432655597	2330	Economy	61500.00
0005435982560	2330	Economy	61500.00
0005435982551	2330	Economy	61500.00
0005435982544	2330	Economy	61500.00
0005433754537	2330	Economy	61500.00
0005435982542	2330	Economy	61500.00
0005432655598	2330	Economy	61500.00
0005432984923	2330	Economy	61500.00
0005432655602	2330	Economy	61500.00
0005435982548	2330	Economy	61500.00
0005433754517	2330	Economy	61500.00
0005433754529	2330	Economy	61500.00
0005435982566	2330	Economy	61500.00
0005432300292	2330	Economy	61500.00
0005433754514	2330	Economy	61500.00
0005432226093	2330	Economy	61500.00
0005434731149	2330	Economy	61500.00
0005433754520	2330	Economy	61500.00
0005433434595	2330	Economy	61500.00
0005432984992	2330	Economy	61500.00
0005432655605	2330	Economy	61500.00
0005433754545	2330	Economy	61500.00
0005433754509	2330	Economy	61500.00
0005435982533	2330	Economy	61500.00
0005435982545	2330	Economy	61500.00
0005433754494	2330	Economy	61500.00
0005432984976	2330	Economy	61500.00
0005434731151	2330	Economy	61500.00
0005432300293	2330	Economy	61500.00
0005433754531	2330	Economy	61500.00
0005435982549	2330	Economy	61500.00
0005432869504	2330	Economy	61500.00
0005432985004	2330	Economy	61500.00
0005432984961	2330	Economy	61500.00
0005433754499	2330	Economy	61500.00
0005432984975	2330	Economy	61500.00
0005433754495	2330	Economy	61500.00
0005433754521	2330	Economy	61500.00
0005432655604	2330	Economy	61500.00
0005433754539	2330	Economy	61500.00
0005433754540	2330	Economy	61500.00
0005433766660	2330	Economy	61500.00
0005435982550	2330	Economy	61500.00
0005433434575	2330	Economy	61500.00
0005435982561	2330	Economy	61500.00
0005432984964	2330	Economy	61500.00
0005435982556	2330	Economy	61500.00
0005432985060	2330	Economy	61500.00
0005432300294	2330	Economy	67700.00
0005433754497	2330	Economy	61500.00
0005433764690	2330	Economy	67700.00
0005435982563	2330	Economy	61500.00
0005433434629	2330	Economy	61500.00
0005433434636	2330	Economy	61500.00
0005433434662	2330	Economy	67700.00
0005432984937	2330	Economy	67700.00
0005432984819	2330	Economy	61500.00
0005433434449	2330	Economy	61500.00
0005433754492	2330	Economy	61500.00
0005432984931	2330	Economy	61500.00
0005435982543	2330	Economy	61500.00
0005433754518	2330	Economy	61500.00
0005432655600	2330	Economy	61500.00
0005432869511	2330	Economy	61500.00
0005433434580	2330	Economy	61500.00
0005435982565	2330	Economy	61500.00
0005433754513	2330	Economy	61500.00
0005432226089	2330	Economy	61500.00
0005435982547	2330	Economy	61500.00
0005433754501	2330	Economy	61500.00
0005435982570	2330	Economy	61500.00
0005432226087	2330	Economy	61500.00
0005432655601	2330	Economy	61500.00
0005435982554	2330	Economy	61500.00
0005433754538	2330	Economy	61500.00
0005433434526	2330	Economy	61500.00
0005433754544	2330	Economy	61500.00
0005433764689	2330	Economy	61500.00
0005435982546	2330	Economy	61500.00
0005432300291	2330	Economy	61500.00
0005433754541	2330	Economy	61500.00
0005434731162	2330	Economy	61500.00
0005435982559	2330	Economy	61500.00
0005432869510	2330	Economy	61500.00
0005433754496	2330	Economy	61500.00
0005433434563	2330	Economy	61500.00
0005433754510	2330	Economy	61500.00
0005433434470	2330	Economy	61500.00
0005433754523	2330	Economy	61500.00
0005433754526	2330	Economy	61500.00
0005435982530	2330	Economy	61500.00
0005435982552	2330	Economy	61500.00
0005433754493	2330	Economy	61500.00
0005433754512	2330	Economy	61500.00
0005432655596	2330	Economy	61500.00
0005433754504	2330	Economy	61500.00
0005433434450	2330	Economy	61500.00
0005433766659	2330	Economy	61500.00
0005433434630	2330	Economy	61500.00
0005433754498	2330	Economy	61500.00
0005433754528	2330	Economy	61500.00
0005433434573	2330	Economy	61500.00
0005432984846	2330	Economy	61500.00
0005433754532	2330	Economy	61500.00
0005432869519	2330	Economy	61500.00
0005433434620	2330	Economy	61500.00
0005432984845	2330	Economy	61500.00
0005435982531	2330	Economy	61500.00
0005432984988	2330	Economy	61500.00
0005432985162	2330	Economy	61500.00
0005432984875	2330	Economy	61500.00
0005432300296	2330	Economy	61500.00
0005432869489	2330	Economy	61500.00
0005435982527	2330	Economy	61500.00
0005432984818	2330	Economy	61500.00
0005432226090	2330	Economy	61500.00
0005432869520	2330	Economy	61500.00
0005432985102	2330	Economy	61500.00
0005433754503	2330	Economy	61500.00
0005433766661	2330	Economy	61500.00
0005432984922	2330	Economy	61500.00
0005433754530	2330	Economy	61500.00
0005435982562	2330	Economy	61500.00
0005433754527	2330	Economy	61500.00
0005432655599	2330	Economy	61500.00
0005433754515	2330	Economy	61500.00
0005433754508	2330	Economy	61500.00
0005435982553	2330	Economy	61500.00
0005435982569	2330	Economy	61500.00
0005435982567	2330	Economy	61500.00
0005432984994	2330	Economy	61500.00
0005432984876	2330	Economy	61500.00
0005432985246	26173	Business	184500.00
0005435982091	26173	Business	184500.00
0005432985236	26173	Business	184500.00
0005432655475	26173	Business	184500.00
0005433434830	26173	Business	184500.00
0005433434818	26173	Business	184500.00
0005433434814	26173	Business	184500.00
0005435982231	26173	Business	184500.00
0005432985243	26173	Business	184500.00
0005433764670	26173	Business	184500.00
0005433754047	26173	Business	184500.00
0005432985234	26173	Business	184500.00
0005435982003	26173	Business	184500.00
0005435982153	26173	Business	184500.00
0005435982065	26173	Business	184500.00
0005435982163	26173	Business	184500.00
0005433754005	26173	Business	184500.00
0005433753766	26173	Business	184500.00
0005433753948	26173	Business	184500.00
0005432985252	26173	Business	184500.00
0005432655478	26173	Business	184500.00
0005433764669	26173	Business	184500.00
0005432655477	26173	Business	184500.00
0005432985238	26173	Business	184500.00
0005432985254	26173	Business	184500.00
0005433434838	26173	Business	184500.00
0005433754002	26173	Business	184500.00
0005433754119	26173	Business	184500.00
0005433754048	26173	Business	184500.00
0005432869559	26173	Business	184500.00
0005435982120	26173	Economy	67700.00
0005433434840	26173	Economy	67700.00
0005435982392	26173	Economy	67700.00
0005435982133	26173	Economy	67700.00
0005433753976	26173	Economy	61500.00
0005433754066	26173	Economy	61500.00
0005432051145	26173	Economy	61500.00
0005435982131	26173	Economy	61500.00
0005432985232	26173	Economy	61500.00
0005432985263	26173	Economy	61500.00
0005432985239	26173	Economy	61500.00
0005433754269	26173	Economy	61500.00
0005433764676	26173	Economy	61500.00
0005432985249	26173	Economy	61500.00
0005435982055	26173	Economy	61500.00
0005435982156	26173	Economy	61500.00
0005435982134	26173	Economy	61500.00
0005432869556	26173	Economy	61500.00
0005435982185	26173	Economy	61500.00
0005432655422	26173	Economy	61500.00
0005433754031	26173	Economy	61500.00
0005435982162	26173	Economy	61500.00
0005433766633	26173	Economy	61500.00
0005435982023	26173	Economy	61500.00
0005433753905	26173	Economy	61500.00
0005435982215	26173	Economy	61500.00
0005433754120	26173	Economy	61500.00
0005433434836	26173	Economy	61500.00
0005433753981	26173	Economy	61500.00
0005433754270	26173	Economy	61500.00
0005432051143	26173	Economy	61500.00
0005433754209	26173	Economy	61500.00
0005435982193	26173	Economy	61500.00
0005432049483	26173	Economy	61500.00
0005433434817	26173	Economy	61500.00
0005433754316	26173	Economy	61500.00
0005432655450	26173	Economy	61500.00
0005433754004	26173	Economy	61500.00
0005433753765	26173	Economy	61500.00
0005433753757	26173	Economy	61500.00
0005433754040	26173	Economy	61500.00
0005432985241	26173	Economy	61500.00
0005433753962	26173	Economy	61500.00
0005432985231	26173	Economy	61500.00
0005433754063	26173	Economy	61500.00
0005433754100	26173	Economy	61500.00
0005433434839	26173	Economy	61500.00
0005433753951	26173	Economy	61500.00
0005432985242	26173	Economy	61500.00
0005432985250	26173	Economy	61500.00
0005433434837	26173	Economy	61500.00
0005432985253	26173	Economy	61500.00
0005432985240	26173	Economy	61500.00
0005435982186	26173	Economy	61500.00
0005433434832	26173	Economy	61500.00
0005433754182	26173	Economy	61500.00
0005433753944	26173	Economy	61500.00
0005433434816	26173	Economy	61500.00
0005432655506	26173	Economy	61500.00
0005433753983	26173	Economy	61500.00
0005432985260	26173	Economy	61500.00
0005432869554	26173	Economy	61500.00
0005433753974	26173	Economy	61500.00
0005433753982	26173	Economy	61500.00
0005435982132	26173	Economy	61500.00
0005433434827	26173	Economy	61500.00
0005432985230	26173	Economy	61500.00
0005434731194	26173	Economy	61500.00
0005435982184	26173	Economy	61500.00
0005435982094	26173	Economy	61500.00
0005433434815	26173	Economy	61500.00
0005433434824	26173	Economy	61500.00
0005435982192	26173	Economy	61500.00
0005433434820	26173	Economy	61500.00
0005435982187	26173	Economy	61500.00
0005432985245	26173	Economy	61500.00
0005432985237	26173	Economy	61500.00
0005435982121	26173	Economy	61500.00
0005433753987	26173	Economy	61500.00
0005435982099	26173	Economy	61500.00
0005433754162	26173	Economy	61500.00
0005432655438	26173	Economy	61500.00
0005435982144	26173	Economy	61500.00
0005434731192	26173	Economy	61500.00
0005433434823	26173	Economy	61500.00
0005433434826	26173	Economy	61500.00
0005433753711	26173	Economy	61500.00
0005435982189	26173	Economy	61500.00
0005433754073	26173	Economy	61500.00
0005435982026	26173	Economy	61500.00
0005433754207	26173	Economy	61500.00
0005435982230	26173	Economy	61500.00
0005433434821	26173	Economy	61500.00
0005433434841	26173	Economy	61500.00
0005435982116	26173	Economy	61500.00
0005434731193	26173	Economy	61500.00
0005432985255	26173	Economy	61500.00
0005435982195	26173	Economy	61500.00
0005432985247	26173	Economy	67700.00
0005432985258	26173	Economy	67700.00
0005432655489	26173	Economy	61500.00
0005435982108	26173	Economy	61500.00
0005432985257	26173	Economy	67700.00
0005433434813	26173	Economy	61500.00
0005433754211	26173	Economy	67700.00
0005432985244	26173	Economy	61500.00
0005435982391	26173	Economy	61500.00
0005433754133	26173	Economy	61500.00
0005435982165	26173	Economy	61500.00
0005433754030	26173	Economy	61500.00
0005433753810	26173	Economy	61500.00
0005432985251	26173	Economy	61500.00
0005433754016	26173	Economy	61500.00
0005432051144	26173	Economy	61500.00
0005433434833	26173	Economy	61500.00
0005432985233	26173	Economy	61500.00
0005432869557	26173	Economy	61500.00
0005435982145	26173	Economy	61500.00
0005432655442	26173	Economy	61500.00
0005433754130	26173	Economy	61500.00
0005433754074	26173	Economy	61500.00
0005432655457	26173	Economy	61500.00
0005432869553	26173	Economy	61500.00
0005433754131	26173	Economy	61500.00
0005433753977	26173	Economy	61500.00
0005435982109	26173	Economy	61500.00
0005435982178	26173	Economy	61500.00
0005435982135	26173	Economy	61500.00
0005435981992	26173	Economy	61500.00
0005432869558	26173	Economy	61500.00
0005435982222	26173	Economy	61500.00
0005435982148	26173	Economy	61500.00
0005432655496	26173	Economy	61500.00
0005433434835	26173	Economy	61500.00
0005432655463	26173	Economy	61500.00
0005432985248	26173	Economy	61500.00
0005435982092	26173	Economy	61500.00
0005435982138	26173	Economy	61500.00
0005432985256	26173	Economy	61500.00
0005433753767	26173	Economy	61500.00
0005433434819	26173	Economy	61500.00
0005432655476	26173	Economy	61500.00
0005433753984	26173	Economy	61500.00
0005433754194	26173	Economy	61500.00
0005433766634	26173	Economy	61500.00
0005432869555	26173	Economy	61500.00
0005433754003	26173	Economy	61500.00
0005433753947	26173	Economy	61500.00
0005432985259	26173	Economy	61500.00
0005433754206	26173	Economy	61500.00
0005435982194	26173	Economy	61500.00
0005432985262	26173	Economy	61500.00
0005433434831	26173	Economy	61500.00
0005433753922	26173	Economy	61500.00
0005433434825	26173	Economy	61500.00
0005433434834	26173	Economy	61500.00
0005434731191	26173	Economy	61500.00
0005432985261	26173	Economy	61500.00
0005433434822	26173	Economy	61500.00
0005433753923	26173	Economy	61500.00
0005433434829	26173	Economy	61500.00
0005435982122	26173	Economy	61500.00
0005433754092	26173	Economy	61500.00
0005435982137	26173	Economy	61500.00
0005433754009	26173	Economy	61500.00
0005435982136	26173	Economy	61500.00
0005432985235	26173	Economy	61500.00
0005433754304	26173	Economy	61500.00
0005432655437	26173	Economy	61500.00
0005433753980	26173	Economy	61500.00
0005433754101	26173	Economy	61500.00
0005433753936	26173	Economy	61500.00
0005435982188	26173	Economy	61500.00
0005432655460	26173	Economy	61500.00
0005433753988	26173	Economy	61500.00
0005435982095	26173	Economy	61500.00
0005433434828	26173	Economy	61500.00
0005433754315	26173	Economy	61500.00
0005434374883	1482	Business	38900.00
0005434374877	1482	Business	38900.00
0005433764675	1482	Business	38900.00
0005433461600	1482	Business	38900.00
0005434374884	1482	Business	38900.00
0005434374880	1482	Business	38900.00
0005433151311	1482	Business	38900.00
0005433151322	1482	Business	38900.00
0005433151318	1482	Business	38900.00
0005433151434	1482	Economy	13000.00
0005434374887	1482	Economy	13000.00
0005433151382	1482	Economy	13000.00
0005434374881	1482	Economy	13000.00
0005434374865	1482	Economy	13000.00
0005432267930	1482	Economy	13000.00
0005433764679	1482	Economy	13000.00
0005433151321	1482	Economy	13000.00
0005434374889	1482	Economy	13000.00
0005433151320	1482	Economy	13000.00
0005433151292	1482	Economy	13000.00
0005433151191	1482	Economy	13000.00
0005433151332	1482	Economy	13000.00
0005434374876	1482	Economy	13000.00
0005433764674	1482	Economy	13000.00
0005433151279	1482	Economy	13000.00
0005434374875	1482	Economy	13000.00
0005433151412	1482	Economy	13000.00
0005433764678	1482	Economy	13000.00
0005434374851	1482	Economy	13000.00
0005434374871	1482	Economy	13000.00
0005434374893	1482	Economy	13000.00
0005433151289	1482	Economy	13000.00
0005434374891	1482	Economy	13000.00
0005433460448	1482	Economy	13000.00
0005434374882	1482	Economy	13000.00
0005433461601	1482	Economy	13000.00
0005432267933	1482	Economy	14300.00
0005433151396	1482	Economy	14300.00
0005434374859	1482	Economy	14300.00
0005434374886	1482	Economy	14300.00
0005434374885	1482	Economy	14300.00
0005434374867	1482	Economy	14300.00
0005433151241	1482	Economy	13000.00
0005434374862	1482	Economy	13000.00
0005433151360	1482	Economy	13000.00
0005434374854	1482	Economy	13000.00
0005433151291	1482	Economy	13000.00
0005434374868	1482	Economy	13000.00
0005434374850	1482	Economy	13000.00
0005433151389	1482	Economy	13000.00
0005434374855	1482	Economy	13000.00
0005434374869	1482	Economy	13000.00
0005434374858	1482	Economy	13000.00
0005434374860	1482	Economy	13000.00
0005432267932	1482	Economy	13000.00
0005434374861	1482	Economy	13000.00
0005434374892	1482	Economy	13000.00
0005434374864	1482	Economy	13000.00
0005434374857	1482	Economy	13000.00
0005433931450	1482	Economy	13000.00
0005434374872	1482	Economy	13000.00
0005434374878	1482	Economy	13000.00
0005433931443	1482	Economy	13000.00
0005432267928	1482	Economy	13000.00
0005433151242	1482	Economy	13000.00
0005434374853	1482	Economy	13000.00
0005434374888	1482	Economy	13000.00
0005433151436	1482	Economy	13000.00
0005433931453	1482	Economy	13000.00
0005433151448	1482	Economy	13000.00
0005433461599	1482	Economy	13000.00
0005433931454	1482	Economy	13000.00
0005434374890	1482	Economy	13000.00
0005433151305	1482	Economy	13000.00
0005433151394	1482	Economy	13000.00
0005434374852	1482	Economy	13000.00
0005434374874	1482	Economy	13000.00
0005434374879	1482	Economy	13000.00
0005433151290	1482	Economy	13000.00
0005434374846	1482	Economy	13000.00
0005432267931	1482	Economy	13000.00
0005433151381	1482	Economy	13000.00
0005434374863	1482	Economy	13000.00
0005434374856	1482	Economy	13000.00
0005434374849	1482	Economy	13000.00
0005434374866	1482	Economy	13000.00
0005433151393	1482	Economy	13000.00
0005433151357	1482	Economy	13000.00
0005433151390	1482	Economy	13000.00
0005434374870	1482	Economy	13000.00
0005433931455	1482	Economy	13000.00
0005434374848	1482	Economy	13000.00
0005433151403	1482	Economy	13000.00
0005433151341	1482	Economy	13000.00
0005433151429	1482	Economy	13000.00
0005434374847	1482	Economy	13000.00
0005434374873	1482	Economy	13000.00
0005432267929	1482	Economy	13000.00
0005434374272	20109	Business	38900.00
0005434374370	20109	Business	38900.00
0005433151598	20109	Business	38900.00
0005433151584	20109	Business	38900.00
0005434374425	20109	Business	38900.00
0005433151595	20109	Business	38900.00
0005433151572	20109	Economy	13000.00
0005434374530	20109	Economy	13000.00
0005433151570	20109	Economy	13000.00
0005433151579	20109	Economy	13000.00
0005433151594	20109	Economy	13000.00
0005434374167	20109	Economy	13000.00
0005433151582	20109	Economy	13000.00
0005434374514	20109	Economy	13000.00
0005434374515	20109	Economy	13000.00
0005432056319	20109	Economy	13000.00
0005433931481	20109	Economy	13000.00
0005434374586	20109	Economy	13000.00
0005434374401	20109	Economy	13000.00
0005434374168	20109	Economy	13000.00
0005434374371	20109	Economy	13000.00
0005434374550	20109	Economy	13000.00
0005433151589	20109	Economy	13000.00
0005433151591	20109	Economy	13000.00
0005434374420	20109	Economy	13000.00
0005434374578	20109	Economy	13000.00
0005434374545	20109	Economy	13000.00
0005434374400	20109	Economy	13000.00
0005433151585	20109	Economy	13000.00
0005433151577	20109	Economy	13000.00
0005434374219	20109	Economy	13000.00
0005434374489	20109	Economy	13000.00
0005434374440	20109	Economy	13000.00
0005433151569	20109	Economy	13000.00
0005432056317	20109	Economy	13000.00
0005432056318	20109	Economy	13000.00
0005433151599	20109	Economy	14300.00
0005434374402	20109	Economy	14300.00
0005434374476	20109	Economy	14300.00
0005434374532	20109	Economy	13000.00
0005434374604	20109	Economy	14300.00
0005433151597	20109	Economy	13000.00
0005434374567	20109	Economy	13000.00
0005433764691	20109	Economy	13000.00
0005434374408	20109	Economy	13000.00
0005434374363	20109	Economy	13000.00
0005434374562	20109	Economy	13000.00
0005433151580	20109	Economy	13000.00
0005433931479	20109	Economy	13000.00
0005434374513	20109	Economy	13000.00
0005433151571	20109	Economy	13000.00
0005433151574	20109	Economy	13000.00
0005433151601	20109	Economy	13000.00
0005434374531	20109	Economy	13000.00
0005434374341	20109	Economy	13000.00
0005434374424	20109	Economy	13000.00
0005434374411	20109	Economy	13000.00
0005434374338	20109	Economy	13000.00
0005434374166	20109	Economy	13000.00
0005434029669	20109	Economy	13000.00
0005434029670	20109	Economy	13000.00
0005433151575	20109	Economy	13000.00
0005433764689	20109	Economy	13000.00
0005433931478	20109	Economy	13000.00
0005434374543	20109	Economy	13000.00
0005434374497	20109	Economy	13000.00
0005434374404	20109	Economy	13000.00
0005433151587	20109	Economy	13000.00
0005433931480	20109	Economy	13000.00
0005433764690	20109	Economy	13000.00
0005434374534	20109	Economy	13000.00
0005434374563	20109	Economy	13000.00
0005433151576	20109	Economy	13000.00
0005433151592	20109	Economy	13000.00
0005433151590	20109	Economy	13000.00
0005434374480	20109	Economy	13000.00
0005433151568	20109	Economy	13000.00
0005434374593	20109	Economy	13000.00
0005434374463	20109	Economy	13000.00
0005434374628	20109	Economy	13000.00
0005434374502	20109	Economy	13000.00
0005433151593	20109	Economy	13000.00
0005434374592	20109	Economy	13000.00
0005434374313	20109	Economy	13000.00
0005433151586	20109	Economy	13000.00
0005434374481	20109	Economy	13000.00
0005434374314	20109	Economy	13000.00
0005433151578	20109	Economy	13000.00
0005434374576	20109	Economy	13000.00
0005433151573	20109	Economy	13000.00
0005433151581	20109	Economy	13000.00
0005434374512	20109	Economy	13000.00
0005432056320	20109	Economy	13000.00
0005434374369	20109	Economy	13000.00
0005433151596	20109	Economy	13000.00
0005433151583	20109	Economy	13000.00
0005434374544	20109	Economy	13000.00
0005434374533	20109	Economy	13000.00
0005434374614	20109	Economy	13000.00
0005433151588	20109	Economy	13000.00
0005433151600	20109	Economy	13000.00
0005434374501	20109	Economy	13000.00
0005432424678	551	Business	27500.00
0005432424670	551	Business	27500.00
0005432424692	551	Business	27500.00
0005432424709	551	Business	27500.00
0005432424695	551	Business	27500.00
0005432424677	551	Business	27500.00
0005432424707	551	Business	27500.00
0005432424694	551	Business	27500.00
0005432282899	551	Business	27500.00
0005432424697	551	Business	27500.00
0005432424698	551	Business	27500.00
0005432424711	551	Economy	10100.00
0005432424680	551	Economy	10100.00
0005432424693	551	Economy	10100.00
0005432424714	551	Economy	9200.00
0005432424708	551	Economy	9200.00
0005432424673	551	Economy	9200.00
0005432424706	551	Economy	9200.00
0005432424668	551	Economy	9200.00
0005432424703	551	Economy	9200.00
0005432424704	551	Economy	9200.00
0005432424696	551	Economy	9200.00
0005432424702	551	Economy	9200.00
0005432424679	551	Economy	9200.00
0005432424686	551	Economy	9200.00
0005432424683	551	Economy	9200.00
0005432424687	551	Economy	9200.00
0005432424689	551	Economy	9200.00
0005432424671	551	Economy	9200.00
0005432282901	551	Economy	9200.00
0005432282898	551	Economy	9200.00
0005432424674	551	Economy	9200.00
0005432424685	551	Economy	10100.00
0005432424699	551	Economy	9200.00
0005432424681	551	Economy	9200.00
0005432424688	551	Economy	9200.00
0005432424682	551	Economy	9200.00
0005432424672	551	Economy	9200.00
0005432282900	551	Economy	9200.00
0005432424691	551	Economy	9200.00
0005432424710	551	Economy	9200.00
0005432282903	551	Economy	9200.00
0005432424700	551	Economy	9200.00
0005432424690	551	Economy	9200.00
0005432424713	551	Economy	9200.00
0005432424669	551	Economy	9200.00
0005432282902	551	Economy	9200.00
0005432424701	551	Economy	9200.00
0005432424705	551	Economy	9200.00
0005432424676	551	Economy	9200.00
0005432424675	551	Economy	9200.00
0005432282904	551	Economy	9200.00
0005432424684	551	Economy	9200.00
0005432424712	551	Economy	9200.00
0005432302349	12889	Business	27500.00
0005432302352	12889	Economy	9200.00
0005432302350	12889	Economy	10100.00
0005432302351	12889	Economy	9200.00
0005432424251	12934	Business	27500.00
0005432424248	12934	Business	27500.00
0005432424269	12934	Business	27500.00
0005432424131	12934	Business	27500.00
0005432424282	12934	Business	27500.00
0005432424235	12934	Business	27500.00
0005432424245	12934	Business	27500.00
0005432424215	12934	Business	27500.00
0005432424211	12934	Business	27500.00
0005432424206	12934	Business	27500.00
0005432424250	12934	Business	27500.00
0005432424140	12934	Business	27500.00
0005432424182	12934	Business	27500.00
0005432424168	12934	Business	27500.00
0005432424279	12934	Economy	10100.00
0005432424237	12934	Economy	9200.00
0005432424070	12934	Economy	9200.00
0005432424216	12934	Economy	9200.00
0005432424220	12934	Economy	9200.00
0005432424142	12934	Economy	9200.00
0005432424186	12934	Economy	9200.00
0005432424221	12934	Economy	9200.00
0005432424177	12934	Economy	9200.00
0005432424164	12934	Economy	9200.00
0005432424287	12934	Economy	9200.00
0005432424290	12934	Economy	9200.00
0005432424023	12934	Economy	9200.00
0005432424264	12934	Economy	9200.00
0005432424317	12934	Economy	9200.00
0005432424185	12934	Economy	9200.00
0005432424199	12934	Economy	9200.00
0005432424085	12934	Economy	9200.00
0005432424249	12934	Economy	9200.00
0005432424288	12934	Economy	9200.00
0005432424246	12934	Economy	9200.00
0005432424236	12934	Economy	9200.00
0005432424289	12934	Economy	10100.00
0005432424265	12934	Economy	10100.00
0005432424190	12934	Economy	10100.00
0005432424253	12934	Economy	10100.00
0005432424132	12934	Economy	9200.00
0005432424064	12934	Economy	9200.00
0005432424280	12934	Economy	9200.00
0005432424311	12934	Economy	9200.00
0005432424244	12934	Economy	9200.00
0005432424276	12934	Economy	9200.00
0005432424271	12934	Economy	9200.00
0005432424176	12934	Economy	9200.00
0005432424222	12934	Economy	9200.00
0005432424086	12934	Economy	9200.00
0005432424316	12934	Economy	9200.00
0005432424238	12934	Economy	9200.00
0005432424165	12934	Economy	9200.00
0005432424071	12934	Economy	9200.00
0005432424266	12934	Economy	9200.00
0005432424087	12934	Economy	9200.00
0005432424208	12934	Economy	9200.00
0005432424283	12934	Economy	9200.00
0005432424270	12934	Economy	9200.00
0005432424217	12934	Economy	9200.00
0005432424155	12934	Economy	9200.00
0005432424106	12934	Economy	9200.00
0005432424141	12934	Economy	9200.00
0005432424130	12934	Economy	9200.00
0005432424255	12934	Economy	9200.00
0005432424212	12934	Economy	9200.00
0005434024037	474	Business	24500.00
0005433057884	474	Business	24500.00
0005434024056	474	Business	24500.00
0005434024093	474	Business	24500.00
0005434024050	474	Business	24500.00
0005433057819	474	Business	24500.00
0005433057585	474	Business	24500.00
0005433057614	474	Business	24500.00
0005434735691	474	Business	24500.00
0005434024062	474	Business	24500.00
0005433057583	474	Business	24500.00
0005434735686	474	Business	24500.00
0005434024094	474	Business	24500.00
0005433057829	474	Business	24500.00
0005433929593	474	Business	24500.00
0005434024082	474	Business	24500.00
0005434024048	474	Business	24500.00
0005434024064	474	Business	24500.00
0005434735658	474	Business	24500.00
0005434032046	474	Business	24500.00
0005433684416	474	Business	24500.00
0005434024040	474	Business	24500.00
0005434024028	474	Business	24500.00
0005434024043	474	Business	24500.00
0005433929605	474	Business	24500.00
0005433057789	474	Economy	9000.00
0005434032045	474	Economy	9000.00
0005432235680	474	Economy	9000.00
0005434024087	474	Economy	8200.00
0005434024053	474	Economy	8200.00
0005433057883	474	Economy	8200.00
0005434024031	474	Economy	8200.00
0005434024090	474	Economy	8200.00
0005433057654	474	Economy	8200.00
0005433057828	474	Economy	8200.00
0005433057909	474	Economy	8200.00
0005434024061	474	Economy	8200.00
0005433057870	474	Economy	8200.00
0005433057653	474	Economy	8200.00
0005433057866	474	Economy	8200.00
0005433057797	474	Economy	8200.00
0005434024049	474	Economy	8200.00
0005434024068	474	Economy	8200.00
0005433057661	474	Economy	8200.00
0005433057801	474	Economy	8200.00
0005434735654	474	Economy	8200.00
0005433057867	474	Economy	8200.00
0005433057852	474	Economy	8200.00
0005434024089	474	Economy	8200.00
0005432235679	474	Economy	8200.00
0005434024085	474	Economy	8200.00
0005433057788	474	Economy	8200.00
0005433057905	474	Economy	8200.00
0005434024046	474	Economy	8200.00
0005434024058	474	Economy	8200.00
0005434735659	474	Economy	8200.00
0005434735656	474	Economy	8200.00
0005434028309	474	Economy	8200.00
0005434024051	474	Economy	8200.00
0005434024091	474	Economy	8200.00
0005433057704	474	Economy	8200.00
0005434024032	474	Economy	8200.00
0005434024074	474	Economy	8200.00
0005433057662	474	Economy	8200.00
0005433057778	474	Economy	8200.00
0005433058010	474	Economy	8200.00
0005434024045	474	Economy	8200.00
0005432235673	474	Economy	8200.00
0005434735684	474	Economy	8200.00
0005434024083	474	Economy	8200.00
0005433057712	474	Economy	8200.00
0005434024027	474	Economy	8200.00
0005433057780	474	Economy	8200.00
0005434024060	474	Economy	8200.00
0005434024044	474	Economy	8200.00
0005434024092	474	Economy	8200.00
0005434024075	474	Economy	8200.00
0005434735655	474	Economy	8200.00
0005433057741	474	Economy	8200.00
0005433057584	474	Economy	8200.00
0005434028310	474	Economy	8200.00
0005432045621	474	Economy	8200.00
0005434024035	474	Economy	8200.00
0005433929604	474	Economy	8200.00
0005434024042	474	Economy	8200.00
0005434024071	474	Economy	8200.00
0005433057740	474	Economy	8200.00
0005433929612	474	Economy	8200.00
0005433057906	474	Economy	8200.00
0005433057948	474	Economy	8200.00
0005434024057	474	Economy	8200.00
0005432235678	474	Economy	8200.00
0005434024039	474	Economy	8200.00
0005434024054	474	Economy	8200.00
0005433929597	474	Economy	8200.00
0005434735678	474	Economy	8200.00
0005434024066	474	Economy	8200.00
0005434024026	474	Economy	8200.00
0005434024079	474	Economy	8200.00
0005434024034	474	Economy	8200.00
0005434735685	474	Economy	8200.00
0005433057605	474	Economy	8200.00
0005432045622	474	Economy	8200.00
0005433057869	474	Economy	8200.00
0005434024067	474	Economy	8200.00
0005434024086	474	Economy	8200.00
0005434024072	474	Economy	8200.00
0005433057885	474	Economy	9000.00
0005433057871	474	Economy	9000.00
0005433057742	474	Economy	8200.00
0005433057836	474	Economy	8200.00
0005432235674	474	Economy	8200.00
0005433057986	474	Economy	8200.00
0005433057730	474	Economy	8200.00
0005434024076	474	Economy	8200.00
0005432235676	474	Economy	8200.00
0005434024073	474	Economy	8200.00
0005434024029	474	Economy	8200.00
0005434024047	474	Economy	8200.00
0005434024059	474	Economy	8200.00
0005433929599	474	Economy	8200.00
0005434024065	474	Economy	8200.00
0005434024036	474	Economy	8200.00
0005433057586	474	Economy	8200.00
0005433057816	474	Economy	8200.00
0005434032042	474	Economy	8200.00
0005434024063	474	Economy	8200.00
0005433929613	474	Economy	8200.00
0005433057941	474	Economy	8200.00
0005432235677	474	Economy	8200.00
0005433057615	474	Economy	8200.00
0005433057781	474	Economy	8200.00
0005434024084	474	Economy	8200.00
0005434029667	474	Economy	8200.00
0005433057904	474	Economy	8200.00
0005434024077	474	Economy	8200.00
0005434024052	474	Economy	8200.00
0005434024081	474	Economy	8200.00
0005434024070	474	Economy	8200.00
0005434024055	474	Economy	8200.00
0005433058009	474	Economy	8200.00
0005434024069	474	Economy	8200.00
0005434024095	474	Economy	8200.00
0005434024041	474	Economy	8200.00
0005433057840	474	Economy	8200.00
0005433929598	474	Economy	8200.00
0005433057606	474	Economy	8200.00
0005433058008	474	Economy	8200.00
0005434024096	474	Economy	8200.00
0005433057872	474	Economy	8200.00
0005434024038	474	Economy	8200.00
0005433057802	474	Economy	8200.00
0005434032043	474	Economy	8200.00
0005433057729	474	Economy	8200.00
0005434024030	474	Economy	8200.00
0005434032044	474	Economy	8200.00
0005434735673	474	Economy	8200.00
0005434024078	474	Economy	8200.00
0005432235675	474	Economy	8200.00
0005433057830	474	Economy	8200.00
0005434735692	474	Economy	8200.00
0005434029668	474	Economy	8200.00
0005433929592	474	Economy	8200.00
0005433057424	474	Economy	8200.00
0005433057835	474	Economy	8200.00
0005434024033	474	Economy	8200.00
0005433057815	474	Economy	8200.00
0005434024088	474	Economy	8200.00
0005434024080	474	Economy	8200.00
0005433057790	474	Economy	8200.00
0005434023468	12673	Business	24500.00
0005434023528	12673	Business	24500.00
0005434023318	12673	Business	24500.00
0005434032011	12673	Business	24500.00
0005434023282	12673	Business	24500.00
0005434023337	12673	Business	24500.00
0005434023503	12673	Business	24500.00
0005434023293	12673	Business	24500.00
0005433058098	12673	Business	24500.00
0005434023219	12673	Business	24500.00
0005433058105	12673	Business	24500.00
0005434023347	12673	Business	24500.00
0005434023635	12673	Business	24500.00
0005434023371	12673	Business	24500.00
0005434023283	12673	Business	24500.00
0005433058079	12673	Business	24500.00
0005433058091	12673	Economy	9000.00
0005434023607	12673	Economy	8200.00
0005434023495	12673	Economy	8200.00
0005434023338	12673	Economy	8200.00
0005433058104	12673	Economy	8200.00
0005433058097	12673	Economy	8200.00
0005433058073	12673	Economy	8200.00
0005434023452	12673	Economy	8200.00
0005434023349	12673	Economy	8200.00
0005434023498	12673	Economy	8200.00
0005432156390	12673	Economy	8200.00
0005434023482	12673	Economy	8200.00
0005433058089	12673	Economy	8200.00
0005433058083	12673	Economy	8200.00
0005433929632	12673	Economy	8200.00
0005432156389	12673	Economy	8200.00
0005433058076	12673	Economy	8200.00
0005434023539	12673	Economy	8200.00
0005434028295	12673	Economy	8200.00
0005434023526	12673	Economy	8200.00
0005433058094	12673	Economy	8200.00
0005433058075	12673	Economy	8200.00
0005434023769	12673	Economy	8200.00
0005434023483	12673	Economy	8200.00
0005434023523	12673	Economy	8200.00
0005434023673	12673	Economy	8200.00
0005434735717	12673	Economy	8200.00
0005434028296	12673	Economy	8200.00
0005434028285	12673	Economy	8200.00
0005434023379	12673	Economy	8200.00
0005434023642	12673	Economy	8200.00
0005434023300	12673	Economy	8200.00
0005434023456	12673	Economy	8200.00
0005433058102	12673	Economy	8200.00
0005434023373	12673	Economy	8200.00
0005434023403	12673	Economy	8200.00
0005434023446	12673	Economy	8200.00
0005433058090	12673	Economy	8200.00
0005434023474	12673	Economy	8200.00
0005434023244	12673	Economy	8200.00
0005433058108	12673	Economy	8200.00
0005434023546	12673	Economy	8200.00
0005433058085	12673	Economy	8200.00
0005433929636	12673	Economy	8200.00
0005433058082	12673	Economy	8200.00
0005433058101	12673	Economy	8200.00
0005434023545	12673	Economy	8200.00
0005433058077	12673	Economy	8200.00
0005434023502	12673	Economy	8200.00
0005433058074	12673	Economy	8200.00
0005433058081	12673	Economy	8200.00
0005433058092	12673	Economy	8200.00
0005434023527	12673	Economy	8200.00
0005433684432	12673	Economy	8200.00
0005434023348	12673	Economy	8200.00
0005433929633	12673	Economy	8200.00
0005433058088	12673	Economy	8200.00
0005434028272	12673	Economy	8200.00
0005434023496	12673	Economy	8200.00
0005434023196	12673	Economy	8200.00
0005433058106	12673	Economy	8200.00
0005434023484	12673	Economy	8200.00
0005434032013	12673	Economy	8200.00
0005433058111	12673	Economy	8200.00
0005433058095	12673	Economy	8200.00
0005434735716	12673	Economy	8200.00
0005434023374	12673	Economy	8200.00
0005434032012	12673	Economy	8200.00
0005434023580	12673	Economy	8200.00
0005432156387	12673	Economy	9000.00
0005433058087	12673	Economy	8200.00
0005433058107	12673	Economy	9000.00
0005434023568	12673	Economy	8200.00
0005434023529	12673	Economy	8200.00
0005434023299	12673	Economy	9000.00
0005434023501	12673	Economy	9000.00
0005434023252	12673	Economy	8200.00
0005433058096	12673	Economy	8200.00
0005433058103	12673	Economy	8200.00
0005434032007	12673	Economy	8200.00
0005434023354	12673	Economy	8200.00
0005434023333	12673	Economy	8200.00
0005433058080	12673	Economy	8200.00
0005434023643	12673	Economy	8200.00
0005434023608	12673	Economy	8200.00
0005434023245	12673	Economy	8200.00
0005434023332	12673	Economy	8200.00
0005433058086	12673	Economy	8200.00
0005434023499	12673	Economy	8200.00
0005434735719	12673	Economy	8200.00
0005432157502	12673	Economy	8200.00
0005433058084	12673	Economy	8200.00
0005433058113	12673	Economy	8200.00
0005434023515	12673	Economy	8200.00
0005434023346	12673	Economy	8200.00
0005433058072	12673	Economy	8200.00
0005434032010	12673	Economy	8200.00
0005433058110	12673	Economy	8200.00
0005433058099	12673	Economy	8200.00
0005434023569	12673	Economy	8200.00
0005434023344	12673	Economy	8200.00
0005433058109	12673	Economy	8200.00
0005434023636	12673	Economy	8200.00
0005434023350	12673	Economy	8200.00
0005434023461	12673	Economy	8200.00
0005433058093	12673	Economy	8200.00
0005434023547	12673	Economy	8200.00
0005433058100	12673	Economy	8200.00
0005434023522	12673	Economy	8200.00
0005433684431	12673	Economy	8200.00
0005434023284	12673	Economy	8200.00
0005433058112	12673	Economy	8200.00
0005433929635	12673	Economy	8200.00
0005434735715	12673	Economy	8200.00
0005434023623	12673	Economy	8200.00
0005433929634	12673	Economy	8200.00
0005434023514	12673	Economy	8200.00
0005434023485	12673	Economy	8200.00
0005433058078	12673	Economy	8200.00
0005432156388	12673	Economy	8200.00
0005434023391	12673	Economy	8200.00
0005434735718	12673	Economy	8200.00
0005434023556	12673	Economy	8200.00
0005434023455	12673	Economy	8200.00
0005434023298	12673	Economy	8200.00
0005434023370	12673	Economy	8200.00
0005433036079	2147	Business	34700.00
0005433923786	2147	Business	34700.00
0005433875388	2147	Business	34700.00
0005433923768	2147	Business	34700.00
0005433923804	2147	Business	34700.00
0005433036073	2147	Business	34700.00
0005433923757	2147	Business	34700.00
0005433923838	2147	Business	34700.00
0005433923816	2147	Business	34700.00
0005433036158	2147	Business	34700.00
0005433931478	2147	Business	34700.00
0005433035817	2147	Business	34700.00
0005432749778	2147	Business	34700.00
0005433035984	2147	Business	34700.00
0005433923803	2147	Business	34700.00
0005433035816	2147	Business	34700.00
0005433923806	2147	Business	34700.00
0005433036110	2147	Business	34700.00
0005433923755	2147	Business	34700.00
0005433923796	2147	Business	34700.00
0005433035970	2147	Business	34700.00
0005433036145	2147	Business	34700.00
0005433923764	2147	Business	34700.00
0005433929636	2147	Economy	12700.00
0005433035997	2147	Economy	12700.00
0005433036113	2147	Economy	11600.00
0005433923784	2147	Economy	11600.00
0005433923807	2147	Economy	11600.00
0005433923787	2147	Economy	11600.00
0005433923773	2147	Economy	11600.00
0005433923751	2147	Economy	11600.00
0005433923823	2147	Economy	11600.00
0005432231614	2147	Economy	11600.00
0005433923812	2147	Economy	11600.00
0005433923763	2147	Economy	11600.00
0005433035998	2147	Economy	11600.00
0005433036181	2147	Economy	11600.00
0005433923822	2147	Economy	11600.00
0005433923780	2147	Economy	11600.00
0005433923841	2147	Economy	11600.00
0005433923818	2147	Economy	11600.00
0005433923821	2147	Economy	11600.00
0005433923808	2147	Economy	11600.00
0005432231616	2147	Economy	11600.00
0005433931481	2147	Economy	11600.00
0005433929634	2147	Economy	11600.00
0005433036287	2147	Economy	11600.00
0005433923809	2147	Economy	11600.00
0005433036160	2147	Economy	11600.00
0005432231623	2147	Economy	11600.00
0005433923753	2147	Economy	11600.00
0005432231617	2147	Economy	11600.00
0005433923785	2147	Economy	11600.00
0005433035963	2147	Economy	11600.00
0005433036172	2147	Economy	11600.00
0005433923802	2147	Economy	11600.00
0005433923801	2147	Economy	11600.00
0005433923837	2147	Economy	11600.00
0005433923758	2147	Economy	11600.00
0005433035985	2147	Economy	11600.00
0005433923829	2147	Economy	11600.00
0005433923750	2147	Economy	11600.00
0005433923805	2147	Economy	11600.00
0005433923769	2147	Economy	11600.00
0005432231620	2147	Economy	11600.00
0005433923830	2147	Economy	11600.00
0005433035840	2147	Economy	11600.00
0005433036202	2147	Economy	11600.00
0005433036104	2147	Economy	11600.00
0005433036092	2147	Economy	11600.00
0005432231624	2147	Economy	11600.00
0005433036348	2147	Economy	11600.00
0005433923795	2147	Economy	11600.00
0005433036111	2147	Economy	11600.00
0005433923766	2147	Economy	11600.00
0005433035910	2147	Economy	11600.00
0005433923832	2147	Economy	11600.00
0005433923824	2147	Economy	11600.00
0005433923774	2147	Economy	11600.00
0005433036213	2147	Economy	11600.00
0005433035964	2147	Economy	11600.00
0005433923834	2147	Economy	11600.00
0005433929633	2147	Economy	11600.00
0005433923749	2147	Economy	11600.00
0005433923820	2147	Economy	11600.00
0005433923835	2147	Economy	11600.00
0005433036123	2147	Economy	11600.00
0005433036156	2147	Economy	11600.00
0005433923819	2147	Economy	11600.00
0005434028296	2147	Economy	11600.00
0005433923798	2147	Economy	11600.00
0005433036361	2147	Economy	11600.00
0005433931479	2147	Economy	11600.00
0005432044539	2147	Economy	11600.00
0005433035839	2147	Economy	11600.00
0005433923782	2147	Economy	11600.00
0005433923770	2147	Economy	11600.00
0005433036161	2147	Economy	11600.00
0005433923828	2147	Economy	11600.00
0005433036157	2147	Economy	11600.00
0005433875387	2147	Economy	11600.00
0005433929635	2147	Economy	11600.00
0005433036270	2147	Economy	11600.00
0005433923843	2147	Economy	11600.00
0005433036203	2147	Economy	11600.00
0005432231621	2147	Economy	11600.00
0005434028295	2147	Economy	11600.00
0005433923839	2147	Economy	11600.00
0005433035986	2147	Economy	12700.00
0005433036318	2147	Economy	11600.00
0005433923793	2147	Economy	11600.00
0005433923760	2147	Economy	11600.00
0005433923765	2147	Economy	12700.00
0005433923775	2147	Economy	11600.00
0005432231615	2147	Economy	12700.00
0005433923778	2147	Economy	11600.00
0005432231622	2147	Economy	11600.00
0005433923811	2147	Economy	11600.00
0005433036288	2147	Economy	11600.00
0005432231619	2147	Economy	11600.00
0005433923810	2147	Economy	11600.00
0005432231618	2147	Economy	11600.00
0005433036347	2147	Economy	11600.00
0005433036173	2147	Economy	11600.00
0005433923772	2147	Economy	11600.00
0005433923840	2147	Economy	11600.00
0005433923771	2147	Economy	11600.00
0005433923842	2147	Economy	11600.00
0005433036159	2147	Economy	11600.00
0005433923776	2147	Economy	11600.00
0005434028272	2147	Economy	11600.00
0005433923792	2147	Economy	11600.00
0005433923817	2147	Economy	11600.00
0005433931480	2147	Economy	11600.00
0005433923791	2147	Economy	11600.00
0005433923799	2147	Economy	11600.00
0005433923788	2147	Economy	11600.00
0005433923826	2147	Economy	11600.00
0005433036434	2147	Economy	11600.00
0005433923844	2147	Economy	11600.00
0005433923767	2147	Economy	11600.00
0005433923836	2147	Economy	11600.00
0005433923800	2147	Economy	11600.00
0005434028285	2147	Economy	11600.00
0005433923783	2147	Economy	11600.00
0005433923756	2147	Economy	11600.00
0005433923813	2147	Economy	11600.00
0005433923762	2147	Economy	11600.00
0005433923831	2147	Economy	11600.00
0005433923777	2147	Economy	11600.00
0005433923779	2147	Economy	11600.00
0005433923781	2147	Economy	11600.00
0005433036103	2147	Economy	11600.00
0005433036271	2147	Economy	11600.00
0005433923814	2147	Economy	11600.00
0005433923754	2147	Economy	11600.00
0005433036264	2147	Economy	11600.00
0005433923845	2147	Economy	11600.00
0005433923789	2147	Economy	11600.00
0005433923761	2147	Economy	11600.00
0005433923833	2147	Economy	11600.00
0005433923825	2147	Economy	11600.00
0005433923752	2147	Economy	11600.00
0005433036106	2147	Economy	11600.00
0005433923759	2147	Economy	11600.00
0005433923790	2147	Economy	11600.00
0005433923815	2147	Economy	11600.00
0005433929632	2147	Economy	11600.00
0005433036029	2147	Economy	11600.00
0005433923794	2147	Economy	11600.00
0005433036112	2147	Economy	11600.00
0005433923827	2147	Economy	11600.00
0005433923797	2147	Economy	11600.00
0005433035983	2147	Economy	11600.00
0005433922932	24137	Business	34700.00
0005433036590	24137	Business	34700.00
0005433923071	24137	Business	34700.00
0005433923100	24137	Business	34700.00
0005432206227	24137	Business	34700.00
0005433923138	24137	Business	34700.00
0005433922913	24137	Business	34700.00
0005432207675	24137	Business	34700.00
0005433036564	24137	Business	34700.00
0005433923206	24137	Business	34700.00
0005433922645	24137	Business	34700.00
0005433036581	24137	Business	34700.00
0005433036594	24137	Business	34700.00
0005433923091	24137	Business	34700.00
0005432206225	24137	Business	34700.00
0005433923204	24137	Business	34700.00
0005433036566	24137	Business	34700.00
0005433929594	24137	Business	34700.00
0005433931444	24137	Business	34700.00
0005433923092	24137	Business	34700.00
0005433923107	24137	Business	34700.00
0005433922987	24137	Economy	12700.00
0005433036574	24137	Economy	12700.00
0005433922997	24137	Economy	11600.00
0005433923003	24137	Economy	11600.00
0005433923016	24137	Economy	11600.00
0005433036576	24137	Economy	11600.00
0005432207676	24137	Economy	11600.00
0005433923176	24137	Economy	11600.00
0005433923330	24137	Economy	11600.00
0005433036573	24137	Economy	11600.00
0005433923106	24137	Economy	11600.00
0005433923005	24137	Economy	11600.00
0005433923148	24137	Economy	11600.00
0005433931460	24137	Economy	11600.00
0005433922527	24137	Economy	11600.00
0005432207674	24137	Economy	11600.00
0005433036558	24137	Economy	11600.00
0005433922767	24137	Economy	11600.00
0005433036555	24137	Economy	11600.00
0005433922974	24137	Economy	11600.00
0005432206226	24137	Economy	11600.00
0005433923171	24137	Economy	11600.00
0005433922574	24137	Economy	11600.00
0005433922583	24137	Economy	11600.00
0005433923072	24137	Economy	11600.00
0005433036595	24137	Economy	11600.00
0005433922629	24137	Economy	11600.00
0005434028312	24137	Economy	11600.00
0005433922661	24137	Economy	11600.00
0005432749796	24137	Economy	11600.00
0005433922899	24137	Economy	11600.00
0005433922876	24137	Economy	11600.00
0005433922983	24137	Economy	11600.00
0005433036567	24137	Economy	11600.00
0005433922906	24137	Economy	11600.00
0005433036549	24137	Economy	11600.00
0005433922892	24137	Economy	11600.00
0005433922646	24137	Economy	11600.00
0005433036560	24137	Economy	11600.00
0005433036559	24137	Economy	11600.00
0005433922882	24137	Economy	11600.00
0005433922374	24137	Economy	11600.00
0005433036545	24137	Economy	11600.00
0005433036546	24137	Economy	11600.00
0005433036584	24137	Economy	11600.00
0005434028311	24137	Economy	11600.00
0005433036570	24137	Economy	11600.00
0005433036544	24137	Economy	11600.00
0005433923241	24137	Economy	11600.00
0005433922546	24137	Economy	11600.00
0005433922859	24137	Economy	11600.00
0005433036582	24137	Economy	11600.00
0005433922731	24137	Economy	11600.00
0005433036571	24137	Economy	11600.00
0005433929595	24137	Economy	11600.00
0005433036585	24137	Economy	11600.00
0005433036586	24137	Economy	11600.00
0005433036557	24137	Economy	11600.00
0005433923118	24137	Economy	11600.00
0005433922912	24137	Economy	11600.00
0005433036591	24137	Economy	11600.00
0005434028313	24137	Economy	11600.00
0005433922934	24137	Economy	11600.00
0005433922958	24137	Economy	11600.00
0005433036550	24137	Economy	11600.00
0005433036575	24137	Economy	11600.00
0005433922798	24137	Economy	11600.00
0005433036577	24137	Economy	11600.00
0005433923143	24137	Economy	11600.00
0005433922628	24137	Economy	11600.00
0005433922845	24137	Economy	12700.00
0005433929610	24137	Economy	12700.00
0005433922874	24137	Economy	11600.00
0005433922973	24137	Economy	12700.00
0005433922870	24137	Economy	12700.00
0005433036579	24137	Economy	11600.00
0005433036589	24137	Economy	11600.00
0005433922984	24137	Economy	11600.00
0005433922900	24137	Economy	11600.00
0005433036553	24137	Economy	11600.00
0005433036580	24137	Economy	11600.00
0005433923051	24137	Economy	11600.00
0005433923004	24137	Economy	11600.00
0005433922808	24137	Economy	11600.00
0005433036551	24137	Economy	11600.00
0005432206228	24137	Economy	11600.00
0005433036554	24137	Economy	11600.00
0005433036569	24137	Economy	11600.00
0005433923017	24137	Economy	11600.00
0005433036593	24137	Economy	11600.00
0005433036563	24137	Economy	11600.00
0005432749797	24137	Economy	11600.00
0005433922871	24137	Economy	11600.00
0005433923242	24137	Economy	11600.00
0005432749798	24137	Economy	11600.00
0005433923067	24137	Economy	11600.00
0005433922778	24137	Economy	11600.00
0005433923170	24137	Economy	11600.00
0005433036548	24137	Economy	11600.00
0005433929600	24137	Economy	11600.00
0005433922951	24137	Economy	11600.00
0005433036556	24137	Economy	11600.00
0005433036572	24137	Economy	11600.00
0005433036552	24137	Economy	11600.00
0005433922766	24137	Economy	11600.00
0005433036597	24137	Economy	11600.00
0005433036592	24137	Economy	11600.00
0005433036565	24137	Economy	11600.00
0005433036562	24137	Economy	11600.00
0005433923172	24137	Economy	11600.00
0005433036561	24137	Economy	11600.00
0005433923137	24137	Economy	11600.00
0005433036596	24137	Economy	11600.00
0005432206224	24137	Economy	11600.00
0005433929602	24137	Economy	11600.00
0005433922858	24137	Economy	11600.00
0005433922901	24137	Economy	11600.00
0005433922730	24137	Economy	11600.00
0005433923442	24137	Economy	11600.00
0005433923207	24137	Economy	11600.00
0005433036587	24137	Economy	11600.00
0005433036583	24137	Economy	11600.00
0005433922718	24137	Economy	11600.00
0005433036547	24137	Economy	11600.00
0005433036588	24137	Economy	11600.00
0005433922877	24137	Economy	11600.00
0005433923099	24137	Economy	11600.00
0005433922779	24137	Economy	11600.00
0005433036578	24137	Economy	11600.00
0005433036568	24137	Economy	11600.00
0005433922957	24137	Economy	11600.00
0005433922804	24137	Economy	11600.00
0005433923140	24137	Economy	11600.00
0005432277880	247	Business	83700.00
0005433180921	247	Business	83700.00
0005434302481	247	Business	83700.00
0005434726109	247	Business	83700.00
0005433233868	247	Business	83700.00
0005433181100	247	Business	83700.00
0005434726086	247	Business	83700.00
0005434726097	247	Business	83700.00
0005434551502	247	Business	83700.00
0005434726137	247	Business	83700.00
0005434551545	247	Business	83700.00
0005434551517	247	Business	83700.00
0005433233786	247	Business	83700.00
0005433181046	247	Business	83700.00
0005434726038	247	Business	83700.00
0005433234210	247	Business	83700.00
0005434726123	247	Business	83700.00
0005435142650	247	Business	83700.00
0005433126825	247	Business	83700.00
0005434726127	247	Business	83700.00
0005433111499	247	Business	83700.00
0005434726139	247	Business	83700.00
0005434726037	247	Business	83700.00
0005434726078	247	Comfort	47400.00
0005433180998	247	Comfort	47400.00
0005433234252	247	Comfort	47400.00
0005433233598	247	Comfort	47400.00
0005434726083	247	Comfort	47400.00
0005434726115	247	Comfort	47400.00
0005434726160	247	Comfort	47400.00
0005434551521	247	Comfort	47400.00
0005433234115	247	Comfort	47400.00
0005434726048	247	Comfort	47400.00
0005434551523	247	Comfort	47400.00
0005434726136	247	Comfort	47400.00
0005434726056	247	Comfort	47400.00
0005435142649	247	Comfort	47400.00
0005434726059	247	Comfort	47400.00
0005433289817	247	Comfort	47400.00
0005434551527	247	Comfort	47400.00
0005434726141	247	Comfort	47400.00
0005434726090	247	Comfort	47400.00
0005434551503	247	Comfort	47400.00
0005433233597	247	Comfort	47400.00
0005432277877	247	Comfort	47400.00
0005434726069	247	Comfort	47400.00
0005433111496	247	Comfort	47400.00
0005434551495	247	Comfort	47400.00
0005433233665	247	Comfort	47400.00
0005434726058	247	Comfort	47400.00
0005434726066	247	Comfort	47400.00
0005433289820	247	Comfort	47400.00
0005434726068	247	Comfort	47400.00
0005434551522	247	Comfort	47400.00
0005433234140	247	Comfort	47400.00
0005434551511	247	Comfort	47400.00
0005433180984	247	Comfort	47400.00
0005434551513	247	Comfort	47400.00
0005434551544	247	Comfort	47400.00
0005432277881	247	Comfort	47400.00
0005434031992	247	Comfort	47400.00
0005433233997	247	Comfort	47400.00
0005433181047	247	Economy	27900.00
0005434726084	247	Economy	27900.00
0005434726051	247	Economy	27900.00
0005434726116	247	Economy	27900.00
0005432277876	247	Economy	27900.00
0005434551538	247	Economy	27900.00
0005434726080	247	Economy	27900.00
0005434302479	247	Economy	27900.00
0005433233889	247	Economy	27900.00
0005433181048	247	Economy	27900.00
0005432277879	247	Economy	27900.00
0005434726095	247	Economy	27900.00
0005434726114	247	Economy	27900.00
0005434726129	247	Economy	27900.00
0005434726134	247	Economy	27900.00
0005433233970	247	Economy	27900.00
0005434726047	247	Economy	27900.00
0005434551497	247	Economy	27900.00
0005434302483	247	Economy	27900.00
0005434726075	247	Economy	27900.00
0005434726054	247	Economy	27900.00
0005434726138	247	Economy	27900.00
0005434731190	247	Economy	27900.00
0005433111501	247	Economy	27900.00
0005433180997	247	Economy	27900.00
0005433233869	247	Economy	27900.00
0005434726042	247	Economy	27900.00
0005433126839	247	Economy	27900.00
0005434726091	247	Economy	27900.00
0005433234261	247	Economy	27900.00
0005434031998	247	Economy	27900.00
0005433234324	247	Economy	27900.00
0005433131689	247	Economy	27900.00
0005434726133	247	Economy	27900.00
0005434726077	247	Economy	27900.00
0005432277872	247	Economy	27900.00
0005433233857	247	Economy	27900.00
0005434731188	247	Economy	27900.00
0005434551506	247	Economy	27900.00
0005433233788	247	Economy	27900.00
0005434726128	247	Economy	27900.00
0005434726046	247	Economy	27900.00
0005433111500	247	Economy	27900.00
0005434731189	247	Economy	27900.00
0005434726055	247	Economy	27900.00
0005433181095	247	Economy	27900.00
0005432277875	247	Economy	27900.00
0005434726117	247	Economy	27900.00
0005433131690	247	Economy	27900.00
0005434726108	247	Economy	27900.00
0005434726053	247	Economy	27900.00
0005433180948	247	Economy	27900.00
0005434726063	247	Economy	27900.00
0005433234141	247	Economy	30700.00
0005434726100	247	Economy	27900.00
0005433233657	247	Economy	30700.00
0005435142651	247	Economy	30700.00
0005434735712	247	Economy	27900.00
0005434551494	247	Economy	30700.00
0005434735711	247	Economy	27900.00
0005434551515	247	Economy	27900.00
0005434551499	247	Economy	30700.00
0005434726040	247	Economy	27900.00
0005434726152	247	Economy	27900.00
0005432277871	247	Economy	27900.00
0005434551537	247	Economy	27900.00
0005433233966	247	Economy	27900.00
0005434551542	247	Economy	27900.00
0005433234019	247	Economy	27900.00
0005434735710	247	Economy	27900.00
0005434726081	247	Economy	27900.00
0005434551534	247	Economy	27900.00
0005434726062	247	Economy	27900.00
0005433234017	247	Economy	27900.00
0005435142653	247	Economy	27900.00
0005434726131	247	Economy	27900.00
0005434726070	247	Economy	27900.00
0005433126817	247	Economy	27900.00
0005434726088	247	Economy	27900.00
0005434551519	247	Economy	27900.00
0005435142646	247	Economy	27900.00
0005435142644	247	Economy	27900.00
0005434551524	247	Economy	27900.00
0005434726147	247	Economy	27900.00
0005435142642	247	Economy	27900.00
0005433234099	247	Economy	27900.00
0005434551531	247	Economy	27900.00
0005434726132	247	Economy	27900.00
0005434726110	247	Economy	27900.00
0005435142643	247	Economy	27900.00
0005434551548	247	Economy	27900.00
0005433234098	247	Economy	27900.00
0005433234094	247	Economy	27900.00
0005432277873	247	Economy	27900.00
0005434726103	247	Economy	27900.00
0005434726067	247	Economy	27900.00
0005434726158	247	Economy	27900.00
0005434551529	247	Economy	27900.00
0005434735713	247	Economy	27900.00
0005433234018	247	Economy	27900.00
0005434551536	247	Economy	27900.00
0005434551508	247	Economy	27900.00
0005433180977	247	Economy	27900.00
0005434551518	247	Economy	27900.00
0005434726101	247	Economy	27900.00
0005433234033	247	Economy	27900.00
0005433131670	247	Economy	27900.00
0005434551528	247	Economy	27900.00
0005434726071	247	Economy	27900.00
0005435142647	247	Economy	27900.00
0005433126826	247	Economy	27900.00
0005433234032	247	Economy	27900.00
0005434726076	247	Economy	27900.00
0005433766629	247	Economy	27900.00
0005434726079	247	Economy	27900.00
0005434726092	247	Economy	27900.00
0005434726039	247	Economy	27900.00
0005434735709	247	Economy	27900.00
0005434726125	247	Economy	27900.00
0005434726155	247	Economy	27900.00
0005434726126	247	Economy	27900.00
0005434726072	247	Economy	27900.00
0005435142640	247	Economy	27900.00
0005434726102	247	Economy	27900.00
0005434726065	247	Economy	27900.00
0005434726120	247	Economy	27900.00
0005434726112	247	Economy	27900.00
0005432277878	247	Economy	27900.00
0005434726057	247	Economy	27900.00
0005434726087	247	Economy	27900.00
0005434726157	247	Economy	27900.00
0005433234020	247	Economy	27900.00
0005433234262	247	Economy	27900.00
0005434726041	247	Economy	27900.00
0005434726148	247	Economy	27900.00
0005434551501	247	Economy	27900.00
0005434551500	247	Economy	27900.00
0005433181022	247	Economy	27900.00
0005434551539	247	Economy	27900.00
0005433233885	247	Economy	27900.00
0005433234053	247	Economy	27900.00
0005434551520	247	Economy	27900.00
0005434726085	247	Economy	27900.00
0005433131691	247	Economy	27900.00
0005434726145	247	Economy	27900.00
0005434726154	247	Economy	27900.00
0005433233962	247	Economy	27900.00
0005432277883	247	Economy	27900.00
0005434726050	247	Economy	27900.00
0005434726098	247	Economy	27900.00
0005434726064	247	Economy	27900.00
0005434551504	247	Economy	27900.00
0005434726124	247	Economy	27900.00
0005434726060	247	Economy	27900.00
0005434726049	247	Economy	27900.00
0005433233961	247	Economy	27900.00
0005434726074	247	Economy	30700.00
0005434031991	247	Economy	27900.00
0005434726156	247	Economy	30700.00
0005434726122	247	Economy	30700.00
0005434726113	247	Economy	30700.00
0005434551514	247	Economy	30700.00
0005434726146	247	Economy	27900.00
0005435142648	247	Economy	27900.00
0005433234031	247	Economy	27900.00
0005435142641	247	Economy	27900.00
0005433289821	247	Economy	27900.00
0005434726104	247	Economy	27900.00
0005433233954	247	Economy	27900.00
0005434726045	247	Economy	27900.00
0005433126840	247	Economy	27900.00
0005434726106	247	Economy	27900.00
0005434726135	247	Economy	27900.00
0005433181043	247	Economy	27900.00
0005434551535	247	Economy	27900.00
0005434726043	247	Economy	27900.00
0005433234100	247	Economy	27900.00
0005434726151	247	Economy	27900.00
0005434726099	247	Economy	27900.00
0005434726044	247	Economy	27900.00
0005433766624	247	Economy	27900.00
0005433126816	247	Economy	27900.00
0005434551533	247	Economy	27900.00
0005434551509	247	Economy	27900.00
0005433180983	247	Economy	27900.00
0005434726089	247	Economy	27900.00
0005432277884	247	Economy	27900.00
0005434551512	247	Economy	27900.00
0005434726061	247	Economy	27900.00
0005433234024	247	Economy	27900.00
0005434551543	247	Economy	27900.00
0005434726118	247	Economy	27900.00
0005434726153	247	Economy	27900.00
0005434726052	247	Economy	27900.00
0005434551516	247	Economy	27900.00
0005433113531	247	Economy	27900.00
0005433233815	247	Economy	27900.00
0005433289849	247	Economy	27900.00
0005434551505	247	Economy	27900.00
0005434551546	247	Economy	27900.00
0005434551510	247	Economy	27900.00
0005434731187	247	Economy	27900.00
0005435142645	247	Economy	27900.00
0005434551526	247	Economy	27900.00
0005434726105	247	Economy	27900.00
0005435142652	247	Economy	27900.00
0005433234001	247	Economy	27900.00
0005434031993	247	Economy	27900.00
0005434726150	247	Economy	27900.00
0005433233861	247	Economy	27900.00
0005434551541	247	Economy	27900.00
0005432277874	247	Economy	27900.00
0005433233890	247	Economy	27900.00
0005434551496	247	Economy	27900.00
0005434726143	247	Economy	27900.00
0005434726159	247	Economy	27900.00
0005434302480	247	Economy	27900.00
0005434726144	247	Economy	27900.00
0005433233727	247	Economy	27900.00
0005434551498	247	Economy	27900.00
0005433180949	247	Economy	27900.00
0005434726149	247	Economy	27900.00
0005434551540	247	Economy	27900.00
0005434726142	247	Economy	27900.00
0005434726121	247	Economy	27900.00
0005434726119	247	Economy	27900.00
0005432277882	247	Economy	27900.00
0005434726111	247	Economy	27900.00
0005434551525	247	Economy	27900.00
0005433233907	247	Economy	27900.00
0005434726140	247	Economy	27900.00
0005434302482	247	Economy	27900.00
0005434726093	247	Economy	27900.00
0005434726073	247	Economy	27900.00
0005434726107	247	Economy	27900.00
0005434551530	247	Economy	27900.00
0005434735714	247	Economy	27900.00
0005434726096	247	Economy	27900.00
0005433234054	247	Economy	27900.00
0005434551532	247	Economy	27900.00
0005434551507	247	Economy	27900.00
0005434551549	247	Economy	27900.00
0005434726130	247	Economy	27900.00
0005434726094	247	Economy	27900.00
0005434551547	247	Economy	27900.00
0005434726082	247	Economy	27900.00
0005433234537	9849	Business	83700.00
0005434724586	9849	Business	83700.00
0005433234548	9849	Business	83700.00
0005434551045	9849	Business	83700.00
0005433234550	9849	Business	83700.00
0005434724420	9849	Business	83700.00
0005434725394	9849	Business	83700.00
0005433181234	9849	Business	83700.00
0005434724827	9849	Business	83700.00
0005434032048	9849	Business	83700.00
0005434735665	9849	Business	83700.00
0005434724601	9849	Business	83700.00
0005434725051	9849	Business	83700.00
0005433234523	9849	Business	83700.00
0005434731162	9849	Business	83700.00
0005434725119	9849	Business	83700.00
0005433181235	9849	Business	83700.00
0005433234532	9849	Business	83700.00
0005434724946	9849	Business	83700.00
0005433234500	9849	Business	83700.00
0005434551068	9849	Business	83700.00
0005434724671	9849	Business	83700.00
0005434725361	9849	Business	83700.00
0005433234511	9849	Business	83700.00
0005433234554	9849	Business	83700.00
0005433181227	9849	Business	83700.00
0005434725044	9849	Business	83700.00
0005434725444	9849	Business	83700.00
0005433234525	9849	Comfort	47400.00
0005434724699	9849	Comfort	47400.00
0005434724886	9849	Comfort	47400.00
0005434724551	9849	Comfort	47400.00
0005434724550	9849	Comfort	47400.00
0005434725156	9849	Comfort	47400.00
0005434550894	9849	Comfort	47400.00
0005434550740	9849	Comfort	47400.00
0005433181230	9849	Comfort	47400.00
0005434731149	9849	Comfort	47400.00
0005434302454	9849	Comfort	47400.00
0005434725244	9849	Comfort	47400.00
0005433181223	9849	Comfort	47400.00
0005433234514	9849	Comfort	47400.00
0005433234504	9849	Comfort	47400.00
0005434724766	9849	Comfort	47400.00
0005434725120	9849	Comfort	47400.00
0005434725158	9849	Comfort	47400.00
0005434550956	9849	Comfort	47400.00
0005433181225	9849	Comfort	47400.00
0005434550879	9849	Comfort	47400.00
0005434725157	9849	Comfort	47400.00
0005433181220	9849	Comfort	47400.00
0005434731151	9849	Comfort	47400.00
0005434725099	9849	Comfort	47400.00
0005434551071	9849	Comfort	47400.00
0005433234505	9849	Comfort	47400.00
0005434724777	9849	Comfort	47400.00
0005434725043	9849	Comfort	47400.00
0005433181232	9849	Comfort	47400.00
0005432199283	9849	Comfort	47400.00
0005432199282	9849	Comfort	47400.00
0005434725015	9849	Comfort	47400.00
0005435142513	9849	Comfort	47400.00
0005434725082	9849	Comfort	47400.00
0005434725268	9849	Comfort	47400.00
0005434302453	9849	Comfort	47400.00
0005434731148	9849	Comfort	47400.00
0005434551080	9849	Comfort	47400.00
0005433234556	9849	Comfort	47400.00
0005434725174	9849	Comfort	47400.00
0005434302446	9849	Comfort	47400.00
0005433234522	9849	Comfort	47400.00
0005434550711	9849	Economy	27900.00
0005433234517	9849	Comfort	47400.00
0005434724723	9849	Economy	27900.00
0005434725357	9849	Economy	27900.00
0005433234513	9849	Economy	27900.00
0005434725167	9849	Economy	27900.00
0005435142566	9849	Economy	27900.00
0005433766660	9849	Economy	27900.00
0005434724570	9849	Economy	27900.00
0005434551038	9849	Economy	27900.00
0005433234502	9849	Economy	27900.00
0005434725206	9849	Economy	27900.00
0005433234549	9849	Economy	27900.00
0005433181241	9849	Economy	27900.00
0005435142466	9849	Economy	27900.00
0005434302430	9849	Economy	27900.00
0005434551163	9849	Economy	27900.00
0005434551179	9849	Economy	27900.00
0005433234534	9849	Economy	27900.00
0005434550738	9849	Economy	27900.00
0005433234499	9849	Economy	27900.00
0005434725443	9849	Economy	27900.00
0005433234551	9849	Economy	27900.00
0005434724811	9849	Economy	27900.00
0005434724923	9849	Economy	27900.00
0005434725112	9849	Economy	27900.00
0005433234516	9849	Economy	27900.00
0005434725100	9849	Economy	27900.00
0005433234542	9849	Economy	27900.00
0005434550795	9849	Economy	27900.00
0005433234546	9849	Economy	27900.00
0005434724870	9849	Economy	27900.00
0005434725070	9849	Economy	27900.00
0005434551067	9849	Economy	27900.00
0005434550886	9849	Economy	27900.00
0005434725741	9849	Economy	27900.00
0005434725117	9849	Economy	27900.00
0005433181221	9849	Economy	27900.00
0005434550855	9849	Economy	27900.00
0005434724770	9849	Economy	27900.00
0005434725427	9849	Economy	27900.00
0005434551160	9849	Economy	27900.00
0005434550952	9849	Economy	27900.00
0005434725273	9849	Economy	27900.00
0005434551083	9849	Economy	27900.00
0005434550932	9849	Economy	27900.00
0005434550927	9849	Economy	27900.00
0005433181218	9849	Economy	27900.00
0005433181222	9849	Economy	27900.00
0005434725282	9849	Economy	27900.00
0005434550953	9849	Economy	27900.00
0005433766661	9849	Economy	27900.00
0005434550993	9849	Economy	27900.00
0005434725309	9849	Economy	27900.00
0005434724622	9849	Economy	27900.00
0005434550799	9849	Economy	27900.00
0005433181240	9849	Economy	27900.00
0005434550730	9849	Economy	27900.00
0005433113547	9849	Economy	27900.00
0005434550739	9849	Economy	27900.00
0005434550822	9849	Economy	27900.00
0005434551037	9849	Economy	30700.00
0005433126870	9849	Economy	30700.00
0005433181219	9849	Economy	30700.00
0005432199281	9849	Economy	27900.00
0005434724949	9849	Economy	27900.00
0005433234526	9849	Economy	30700.00
0005434550851	9849	Economy	27900.00
0005433129297	9849	Economy	30700.00
0005434551009	9849	Economy	27900.00
0005434551087	9849	Economy	30700.00
0005434550943	9849	Economy	27900.00
0005434725284	9849	Economy	27900.00
0005434724593	9849	Economy	27900.00
0005433234518	9849	Economy	27900.00
0005434725426	9849	Economy	27900.00
0005434724509	9849	Economy	27900.00
0005433126868	9849	Economy	27900.00
0005433234535	9849	Economy	27900.00
0005433234507	9849	Economy	27900.00
0005434550794	9849	Economy	27900.00
0005434551053	9849	Economy	27900.00
0005434724950	9849	Economy	27900.00
0005434725083	9849	Economy	27900.00
0005434550968	9849	Economy	27900.00
0005434032051	9849	Economy	27900.00
0005433181224	9849	Economy	27900.00
0005434302447	9849	Economy	27900.00
0005433181226	9849	Economy	27900.00
0005435142508	9849	Economy	27900.00
0005433181229	9849	Economy	27900.00
0005434725186	9849	Economy	27900.00
0005434551035	9849	Economy	27900.00
0005434724876	9849	Economy	27900.00
0005435142505	9849	Economy	27900.00
0005434725183	9849	Economy	27900.00
0005434551161	9849	Economy	27900.00
0005434724602	9849	Economy	27900.00
0005434724623	9849	Economy	27900.00
0005434551140	9849	Economy	27900.00
0005434551011	9849	Economy	27900.00
0005433234558	9849	Economy	27900.00
0005434551077	9849	Economy	27900.00
0005434550994	9849	Economy	27900.00
0005434550798	9849	Economy	27900.00
0005432199284	9849	Economy	27900.00
0005433234531	9849	Economy	27900.00
0005434725359	9849	Economy	27900.00
0005434724841	9849	Economy	27900.00
0005434550796	9849	Economy	27900.00
0005433126867	9849	Economy	27900.00
0005434724446	9849	Economy	27900.00
0005434725381	9849	Economy	27900.00
0005434731150	9849	Economy	27900.00
0005433234529	9849	Economy	27900.00
0005433234497	9849	Economy	27900.00
0005434724836	9849	Economy	27900.00
0005433234559	9849	Economy	27900.00
0005433234555	9849	Economy	27900.00
0005434551018	9849	Economy	27900.00
0005433181237	9849	Economy	27900.00
0005434550940	9849	Economy	27900.00
0005434725168	9849	Economy	27900.00
0005434725405	9849	Economy	27900.00
0005434725227	9849	Economy	27900.00
0005434725014	9849	Economy	27900.00
0005434724510	9849	Economy	27900.00
0005433289881	9849	Economy	27900.00
0005433129300	9849	Economy	27900.00
0005434550731	9849	Economy	27900.00
0005433234527	9849	Economy	27900.00
0005433234560	9849	Economy	27900.00
0005433234547	9849	Economy	27900.00
0005434302455	9849	Economy	27900.00
0005434725171	9849	Economy	27900.00
0005434551164	9849	Economy	27900.00
0005434724966	9849	Economy	27900.00
0005434725047	9849	Economy	27900.00
0005434724724	9849	Economy	27900.00
0005434551079	9849	Economy	27900.00
0005434725172	9849	Economy	27900.00
0005433234506	9849	Economy	27900.00
0005434725098	9849	Economy	27900.00
0005434724924	9849	Economy	27900.00
0005434725358	9849	Economy	27900.00
0005434725022	9849	Economy	27900.00
0005433234557	9849	Economy	27900.00
0005434551084	9849	Economy	27900.00
0005433289885	9849	Economy	27900.00
0005434725406	9849	Economy	27900.00
0005433234521	9849	Economy	27900.00
0005434551076	9849	Economy	27900.00
0005434725081	9849	Economy	27900.00
0005433129298	9849	Economy	27900.00
0005432199286	9849	Economy	27900.00
0005434551054	9849	Economy	27900.00
0005435142378	9849	Economy	27900.00
0005434725271	9849	Economy	27900.00
0005434731161	9849	Economy	27900.00
0005434032047	9849	Economy	27900.00
0005434551211	9849	Economy	27900.00
0005434302443	9849	Economy	27900.00
0005433234553	9849	Economy	27900.00
0005433234498	9849	Economy	27900.00
0005433234503	9849	Economy	27900.00
0005434032049	9849	Economy	27900.00
0005433289886	9849	Economy	27900.00
0005433234541	9849	Economy	27900.00
0005434551036	9849	Economy	27900.00
0005434725200	9849	Economy	30700.00
0005435142565	9849	Economy	30700.00
0005433181236	9849	Economy	30700.00
0005434550942	9849	Economy	27900.00
0005433181242	9849	Economy	27900.00
0005434735663	9849	Economy	27900.00
0005434550957	9849	Economy	27900.00
0005433181238	9849	Economy	27900.00
0005434725182	9849	Economy	27900.00
0005434725218	9849	Economy	27900.00
0005434724871	9849	Economy	27900.00
0005433234538	9849	Economy	27900.00
0005435142377	9849	Economy	27900.00
0005433234508	9849	Economy	27900.00
0005434724374	9849	Economy	27900.00
0005434724948	9849	Economy	27900.00
0005433234544	9849	Economy	27900.00
0005434724965	9849	Economy	27900.00
0005433289883	9849	Economy	27900.00
0005434551178	9849	Economy	27900.00
0005434302438	9849	Economy	27900.00
0005433181217	9849	Economy	27900.00
0005434735666	9849	Economy	27900.00
0005434551146	9849	Economy	27900.00
0005433234501	9849	Economy	27900.00
0005433289882	9849	Economy	27900.00
0005434550941	9849	Economy	27900.00
0005434724756	9849	Economy	27900.00
0005433126866	9849	Economy	27900.00
0005434735657	9849	Economy	27900.00
0005434724930	9849	Economy	27900.00
0005433234545	9849	Economy	27900.00
0005435142497	9849	Economy	27900.00
0005433113546	9849	Economy	27900.00
0005434724524	9849	Economy	27900.00
0005435142469	9849	Economy	27900.00
0005434725372	9849	Economy	27900.00
0005433234528	9849	Economy	27900.00
0005434550797	9849	Economy	27900.00
0005434551173	9849	Economy	27900.00
0005433129299	9849	Economy	27900.00
0005433234520	9849	Economy	27900.00
0005433181228	9849	Economy	27900.00
0005434550911	9849	Economy	27900.00
0005434725360	9849	Economy	27900.00
0005433234533	9849	Economy	27900.00
0005434550887	9849	Economy	27900.00
0005433766659	9849	Economy	27900.00
0005432199285	9849	Economy	27900.00
0005432199280	9849	Economy	27900.00
0005434725382	9849	Economy	27900.00
0005434725050	9849	Economy	27900.00
0005433234552	9849	Economy	27900.00
0005433234543	9849	Economy	27900.00
0005433126869	9849	Economy	27900.00
0005434550912	9849	Economy	27900.00
0005433234539	9849	Economy	27900.00
0005434725042	9849	Economy	27900.00
0005433234536	9849	Economy	27900.00
0005433234515	9849	Economy	27900.00
0005434725283	9849	Economy	27900.00
0005434725097	9849	Economy	27900.00
0005433234509	9849	Economy	27900.00
0005434725318	9849	Economy	27900.00
0005433234519	9849	Economy	27900.00
0005433181233	9849	Economy	27900.00
0005434551141	9849	Economy	27900.00
0005433234540	9849	Economy	27900.00
0005434551142	9849	Economy	27900.00
0005434725272	9849	Economy	27900.00
0005434551070	9849	Economy	27900.00
0005434725231	9849	Economy	27900.00
0005434725255	9849	Economy	27900.00
0005434032050	9849	Economy	27900.00
0005434724523	9849	Economy	27900.00
0005434735664	9849	Economy	27900.00
0005434725054	9849	Economy	27900.00
0005434724945	9849	Economy	27900.00
0005433181231	9849	Economy	27900.00
0005435142507	9849	Economy	27900.00
0005434725204	9849	Economy	27900.00
0005434550895	9849	Economy	27900.00
0005433234512	9849	Economy	27900.00
0005434724975	9849	Economy	27900.00
0005434551049	9849	Economy	27900.00
0005434725128	9849	Economy	27900.00
0005434725133	9849	Economy	27900.00
0005434724461	9849	Economy	27900.00
0005434725160	9849	Economy	27900.00
0005433289884	9849	Economy	27900.00
0005434725159	9849	Economy	27900.00
0005433234530	9849	Economy	27900.00
0005434725116	9849	Economy	27900.00
0005433234524	9849	Economy	27900.00
0005434725216	9849	Economy	27900.00
0005434724778	9849	Economy	27900.00
0005434725614	9849	Economy	27900.00
0005434725731	9849	Economy	27900.00
0005433181239	9849	Economy	27900.00
0005433234510	9849	Economy	27900.00
0005434067949	7770	Business	42100.00
0005434067902	7770	Business	42100.00
0005432528601	7770	Business	42100.00
0005434067937	7770	Business	42100.00
0005432528637	7770	Business	42100.00
0005432528600	7770	Business	42100.00
0005432537069	7770	Business	42100.00
0005435213132	7770	Business	42100.00
0005432528618	7770	Business	42100.00
0005432528635	7770	Business	42100.00
0005432528692	7770	Business	42100.00
0005435213092	7770	Business	42100.00
0005432069722	7770	Business	42100.00
0005432535860	7770	Business	42100.00
0005432528673	7770	Business	42100.00
0005432528715	7770	Business	42100.00
0005435213055	7770	Business	42100.00
0005435213462	7770	Business	42100.00
0005432150237	7770	Business	42100.00
0005434067896	7770	Business	42100.00
0005435213242	7770	Business	42100.00
0005432533306	7770	Business	42100.00
0005435213180	7770	Business	42100.00
0005435213391	7770	Comfort	23900.00
0005434067930	7770	Business	42100.00
0005432528626	7770	Comfort	23900.00
0005432528680	7770	Comfort	23900.00
0005434067917	7770	Comfort	23900.00
0005435212939	7770	Comfort	23900.00
0005432150236	7770	Comfort	23900.00
0005432528643	7770	Comfort	23900.00
0005434067911	7770	Comfort	23900.00
0005432428947	7770	Comfort	23900.00
0005432528679	7770	Comfort	23900.00
0005432528603	7770	Comfort	23900.00
0005434067918	7770	Comfort	23900.00
0005434067931	7770	Comfort	23900.00
0005432528656	7770	Comfort	23900.00
0005435213347	7770	Comfort	23900.00
0005435213421	7770	Comfort	23900.00
0005435213200	7770	Comfort	23900.00
0005434067910	7770	Comfort	23900.00
0005432528697	7770	Comfort	23900.00
0005432528657	7770	Comfort	23900.00
0005435213251	7770	Comfort	23900.00
0005434067956	7770	Comfort	23900.00
0005432528665	7770	Comfort	23900.00
0005435213311	7770	Comfort	23900.00
0005432528599	7770	Comfort	23900.00
0005435213204	7770	Comfort	23900.00
0005432069732	7770	Comfort	23900.00
0005434067908	7770	Comfort	23900.00
0005432150238	7770	Comfort	23900.00
0005432528659	7770	Comfort	23900.00
0005435213159	7770	Comfort	23900.00
0005432528597	7770	Comfort	23900.00
0005434067895	7770	Comfort	23900.00
0005435212980	7770	Comfort	23900.00
0005434067941	7770	Comfort	23900.00
0005434067950	7770	Comfort	23900.00
0005435213228	7770	Comfort	23900.00
0005433656659	7770	Comfort	23900.00
0005435213440	7770	Comfort	23900.00
0005432428946	7770	Comfort	23900.00
0005432528591	7770	Comfort	23900.00
0005435213254	7770	Comfort	23900.00
0005435213285	7770	Comfort	23900.00
0005434067924	7770	Economy	14000.00
0005435213027	7770	Economy	14000.00
0005432528663	7770	Economy	14000.00
0005432069729	7770	Economy	14000.00
0005432528632	7770	Economy	14000.00
0005434067921	7770	Economy	14000.00
0005432069737	7770	Economy	14000.00
0005432528619	7770	Economy	14000.00
0005435213364	7770	Economy	14000.00
0005434067954	7770	Economy	14000.00
0005435213396	7770	Economy	14000.00
0005434067958	7770	Economy	14000.00
0005435213093	7770	Economy	14000.00
0005432069728	7770	Economy	14000.00
0005432528687	7770	Economy	14000.00
0005435213193	7770	Economy	14000.00
0005432528640	7770	Economy	14000.00
0005432528675	7770	Economy	14000.00
0005432528605	7770	Economy	14000.00
0005435213279	7770	Economy	14000.00
0005432528633	7770	Economy	14000.00
0005432528592	7770	Economy	14000.00
0005434067963	7770	Economy	14000.00
0005432528621	7770	Economy	14000.00
0005435630951	7770	Economy	14000.00
0005432528701	7770	Economy	14000.00
0005432528606	7770	Economy	14000.00
0005432150233	7770	Economy	14000.00
0005435213545	7770	Economy	14000.00
0005432150235	7770	Economy	14000.00
0005432528712	7770	Economy	14000.00
0005432528671	7770	Economy	14000.00
0005435213546	7770	Economy	14000.00
0005434067951	7770	Economy	14000.00
0005432528624	7770	Economy	14000.00
0005434067897	7770	Economy	14000.00
0005432528667	7770	Economy	14000.00
0005435213473	7770	Economy	14000.00
0005432528617	7770	Economy	14000.00
0005434067914	7770	Economy	14000.00
0005435213028	7770	Economy	14000.00
0005432528589	7770	Economy	14000.00
0005435213184	7770	Economy	14000.00
0005435213373	7770	Economy	14000.00
0005434067932	7770	Economy	14000.00
0005432528684	7770	Economy	14000.00
0005432069724	7770	Economy	14000.00
0005432528607	7770	Economy	14000.00
0005432528641	7770	Economy	14000.00
0005432528688	7770	Economy	14000.00
0005435213212	7770	Economy	14000.00
0005432528685	7770	Economy	14000.00
0005432528629	7770	Economy	14000.00
0005432528706	7770	Economy	14000.00
0005434067929	7770	Economy	14000.00
0005432528652	7770	Economy	14000.00
0005434067906	7770	Economy	14000.00
0005434067915	7770	Economy	14000.00
0005432528595	7770	Economy	14000.00
0005432150232	7770	Economy	14000.00
0005435213265	7770	Economy	15400.00
0005432528616	7770	Economy	15400.00
0005434067960	7770	Economy	15400.00
0005432528698	7770	Economy	14000.00
0005434067900	7770	Economy	14000.00
0005435213307	7770	Economy	14000.00
0005432528664	7770	Economy	14000.00
0005435213360	7770	Economy	15400.00
0005434067935	7770	Economy	15400.00
0005432537068	7770	Economy	15400.00
0005432528708	7770	Economy	14000.00
0005435213482	7770	Economy	14000.00
0005432528696	7770	Economy	14000.00
0005432528705	7770	Economy	14000.00
0005432528666	7770	Economy	14000.00
0005434067916	7770	Economy	14000.00
0005432528662	7770	Economy	14000.00
0005432535859	7770	Economy	14000.00
0005434067909	7770	Economy	14000.00
0005432428945	7770	Economy	14000.00
0005434067934	7770	Economy	14000.00
0005432528604	7770	Economy	14000.00
0005434067926	7770	Economy	14000.00
0005435213090	7770	Economy	14000.00
0005435213383	7770	Economy	14000.00
0005435213227	7770	Economy	14000.00
0005432528694	7770	Economy	14000.00
0005432528610	7770	Economy	14000.00
0005434067912	7770	Economy	14000.00
0005432528713	7770	Economy	14000.00
0005435213361	7770	Economy	14000.00
0005432528602	7770	Economy	14000.00
0005434067933	7770	Economy	14000.00
0005432528711	7770	Economy	14000.00
0005435213246	7770	Economy	14000.00
0005435213342	7770	Economy	14000.00
0005434067944	7770	Economy	14000.00
0005435213538	7770	Economy	14000.00
0005432528625	7770	Economy	14000.00
0005432069727	7770	Economy	14000.00
0005432528587	7770	Economy	14000.00
0005432528718	7770	Economy	14000.00
0005435213160	7770	Economy	14000.00
0005432528660	7770	Economy	14000.00
0005435213063	7770	Economy	14000.00
0005435213481	7770	Economy	14000.00
0005434067928	7770	Economy	14000.00
0005435213189	7770	Economy	14000.00
0005434067964	7770	Economy	14000.00
0005432528647	7770	Economy	14000.00
0005432528703	7770	Economy	14000.00
0005435213399	7770	Economy	14000.00
0005432528704	7770	Economy	14000.00
0005432528590	7770	Economy	14000.00
0005433656656	7770	Economy	14000.00
0005432150239	7770	Economy	14000.00
0005432528683	7770	Economy	14000.00
0005435213379	7770	Economy	14000.00
0005434067957	7770	Economy	14000.00
0005435213202	7770	Economy	14000.00
0005432528677	7770	Economy	14000.00
0005432528716	7770	Economy	14000.00
0005432528639	7770	Economy	14000.00
0005432528658	7770	Economy	14000.00
0005432528654	7770	Economy	14000.00
0005434067925	7770	Economy	14000.00
0005432528651	7770	Economy	14000.00
0005435213470	7770	Economy	14000.00
0005432535858	7770	Economy	14000.00
0005432528693	7770	Economy	14000.00
0005435213129	7770	Economy	14000.00
0005432528676	7770	Economy	14000.00
0005434067942	7770	Economy	14000.00
0005432528614	7770	Economy	14000.00
0005432069726	7770	Economy	14000.00
0005435213304	7770	Economy	14000.00
0005434067899	7770	Economy	14000.00
0005435630952	7770	Economy	14000.00
0005434067962	7770	Economy	14000.00
0005432528644	7770	Economy	14000.00
0005435212982	7770	Economy	14000.00
0005432528648	7770	Economy	14000.00
0005432069731	7770	Economy	14000.00
0005432528646	7770	Economy	14000.00
0005435213229	7770	Economy	14000.00
0005435213710	7770	Economy	14000.00
0005435213400	7770	Economy	14000.00
0005434067961	7770	Economy	14000.00
0005432528613	7770	Economy	14000.00
0005432069736	7770	Economy	14000.00
0005435213406	7770	Economy	14000.00
0005435213327	7770	Economy	14000.00
0005432150234	7770	Economy	14000.00
0005434067919	7770	Economy	14000.00
0005434067947	7770	Economy	14000.00
0005432528615	7770	Economy	14000.00
0005435213519	7770	Economy	14000.00
0005432528598	7770	Economy	14000.00
0005434067892	7770	Economy	14000.00
0005433656652	7770	Economy	14000.00
0005435213415	7770	Economy	14000.00
0005435213431	7770	Economy	14000.00
0005432533305	7770	Economy	14000.00
0005434067953	7770	Economy	14000.00
0005435213461	7770	Economy	14000.00
0005434067920	7770	Economy	14000.00
0005432528710	7770	Economy	14000.00
0005434067905	7770	Economy	14000.00
0005432528620	7770	Economy	14000.00
0005434067898	7770	Economy	14000.00
0005432528707	7770	Economy	15400.00
0005432528668	7770	Economy	14000.00
0005432528669	7770	Economy	15400.00
0005432528638	7770	Economy	15400.00
0005432528612	7770	Economy	15400.00
0005434067940	7770	Economy	15400.00
0005432528689	7770	Economy	14000.00
0005432528588	7770	Economy	14000.00
0005432528670	7770	Economy	14000.00
0005435213206	7770	Economy	14000.00
0005435213020	7770	Economy	14000.00
0005435213287	7770	Economy	14000.00
0005432528690	7770	Economy	14000.00
0005432528702	7770	Economy	14000.00
0005432069734	7770	Economy	14000.00
0005434067955	7770	Economy	14000.00
0005432528585	7770	Economy	14000.00
0005435213329	7770	Economy	14000.00
0005435213384	7770	Economy	14000.00
0005434067907	7770	Economy	14000.00
0005432528700	7770	Economy	14000.00
0005432528594	7770	Economy	14000.00
0005432528714	7770	Economy	14000.00
0005432528623	7770	Economy	14000.00
0005434067952	7770	Economy	14000.00
0005432528681	7770	Economy	14000.00
0005434067903	7770	Economy	14000.00
0005432528682	7770	Economy	14000.00
0005432528709	7770	Economy	14000.00
0005435213211	7770	Economy	14000.00
0005432528695	7770	Economy	14000.00
0005434067904	7770	Economy	14000.00
0005433656646	7770	Economy	14000.00
0005432528596	7770	Economy	14000.00
0005435213432	7770	Economy	14000.00
0005432528650	7770	Economy	14000.00
0005432528678	7770	Economy	14000.00
0005433656651	7770	Economy	14000.00
0005432069735	7770	Economy	14000.00
0005434067945	7770	Economy	14000.00
0005432535861	7770	Economy	14000.00
0005432069733	7770	Economy	14000.00
0005434067922	7770	Economy	14000.00
0005435213253	7770	Economy	14000.00
0005434067948	7770	Economy	14000.00
0005434067894	7770	Economy	14000.00
0005432528631	7770	Economy	14000.00
0005432533307	7770	Economy	14000.00
0005435213198	7770	Economy	14000.00
0005432528661	7770	Economy	14000.00
0005432528608	7770	Economy	14000.00
0005435213372	7770	Economy	14000.00
0005435213241	7770	Economy	14000.00
0005434067913	7770	Economy	14000.00
0005432528636	7770	Economy	14000.00
0005434067927	7770	Economy	14000.00
0005432528634	7770	Economy	14000.00
0005432528672	7770	Economy	14000.00
0005432069730	7770	Economy	14000.00
0005434067893	7770	Economy	14000.00
0005434067901	7770	Economy	14000.00
0005432528686	7770	Economy	14000.00
0005432528611	7770	Economy	14000.00
0005435725577	7770	Economy	14000.00
0005434067959	7770	Economy	14000.00
0005435213422	7770	Economy	14000.00
0005432069725	7770	Economy	14000.00
0005434067936	7770	Economy	14000.00
0005432528655	7770	Economy	14000.00
0005434067939	7770	Economy	14000.00
0005432528627	7770	Economy	14000.00
0005432528628	7770	Economy	14000.00
0005432528653	7770	Economy	14000.00
0005432528609	7770	Economy	14000.00
0005434067946	7770	Economy	14000.00
0005435213245	7770	Economy	14000.00
0005432528593	7770	Economy	14000.00
0005435630942	7770	Economy	14000.00
0005434067938	7770	Economy	14000.00
0005432528642	7770	Economy	14000.00
0005435213244	7770	Economy	14000.00
0005435213547	7770	Economy	14000.00
0005432528622	7770	Economy	14000.00
0005435213328	7770	Economy	14000.00
0005432537070	7770	Economy	14000.00
0005435213608	7770	Economy	14000.00
0005432528649	7770	Economy	14000.00
0005432528717	7770	Economy	14000.00
0005432528674	7770	Economy	14000.00
0005432528699	7770	Economy	14000.00
0005432528645	7770	Economy	14000.00
0005434067943	7770	Economy	14000.00
0005435213190	7770	Economy	14000.00
0005435213252	7770	Economy	14000.00
0005435212981	7770	Economy	14000.00
0005432528630	7770	Economy	14000.00
0005434067923	7770	Economy	14000.00
0005432528691	7770	Economy	14000.00
0005432069723	7770	Economy	14000.00
0005432528586	7770	Economy	14000.00
0005432133285	5307	Business	43100.00
0005434244961	5307	Business	43100.00
0005434573432	5307	Business	43100.00
0005435614195	5307	Business	43100.00
0005435614251	5307	Business	43100.00
0005435097250	5307	Business	43100.00
0005434244828	5307	Business	43100.00
0005435424634	5307	Business	43100.00
0005435614222	5307	Business	43100.00
0005435424819	5307	Business	43100.00
0005435097247	5307	Business	43100.00
0005435302183	5307	Business	43100.00
0005435614207	5307	Business	43100.00
0005434573424	5307	Business	43100.00
0005435302188	5307	Business	43100.00
0005435424212	5307	Business	43100.00
0005435042847	5307	Business	43100.00
0005435319476	5307	Business	43100.00
0005435614208	5307	Business	43100.00
0005435614297	5307	Business	43100.00
0005435614194	5307	Business	43100.00
0005434244827	5307	Business	43100.00
0005435614218	5307	Comfort	24400.00
0005435614262	5307	Business	43100.00
0005435424893	5307	Comfort	24400.00
0005435614197	5307	Comfort	24400.00
0005432363404	5307	Comfort	24400.00
0005435424818	5307	Comfort	24400.00
0005435319580	5307	Comfort	24400.00
0005435614257	5307	Comfort	24400.00
0005434344402	5307	Comfort	24400.00
0005435614178	5307	Comfort	24400.00
0005434344428	5307	Comfort	24400.00
0005435614236	5307	Comfort	24400.00
0005435424576	5307	Comfort	24400.00
0005435424477	5307	Comfort	24400.00
0005435097256	5307	Comfort	24400.00
0005435614203	5307	Comfort	24400.00
0005434244837	5307	Comfort	24400.00
0005435614271	5307	Comfort	24400.00
0005435424847	5307	Comfort	24400.00
0005432133294	5307	Comfort	24400.00
0005435614291	5307	Comfort	24400.00
0005433719119	5307	Comfort	24400.00
0005435614200	5307	Comfort	24400.00
0005435302187	5307	Comfort	24400.00
0005435319581	5307	Comfort	24400.00
0005435424798	5307	Comfort	24400.00
0005435614315	5307	Comfort	24400.00
0005435424676	5307	Comfort	24400.00
0005435614254	5307	Comfort	24400.00
0005435614303	5307	Comfort	24400.00
0005435424671	5307	Comfort	24400.00
0005432133284	5307	Comfort	24400.00
0005434344434	5307	Comfort	24400.00
0005435614226	5307	Comfort	24400.00
0005432133295	5307	Comfort	24400.00
0005434344409	5307	Comfort	24400.00
0005434244899	5307	Comfort	24400.00
0005435614264	5307	Comfort	24400.00
0005435614232	5307	Comfort	24400.00
0005435424811	5307	Comfort	24400.00
0005435555381	5307	Comfort	24400.00
0005434245009	5307	Comfort	24400.00
0005435042837	5307	Comfort	24400.00
0005432133283	5307	Economy	14400.00
0005434244898	5307	Comfort	24400.00
0005432133290	5307	Economy	14400.00
0005435614224	5307	Economy	14400.00
0005435614279	5307	Economy	14400.00
0005435614231	5307	Economy	14400.00
0005434344426	5307	Economy	14400.00
0005434344432	5307	Economy	14400.00
0005435614280	5307	Economy	14400.00
0005435614210	5307	Economy	14400.00
0005432047568	5307	Economy	14400.00
0005435424751	5307	Economy	14400.00
0005435614281	5307	Economy	14400.00
0005434344415	5307	Economy	14400.00
0005435614192	5307	Economy	14400.00
0005435424518	5307	Economy	14400.00
0005434344435	5307	Economy	14400.00
0005434573427	5307	Economy	14400.00
0005434244789	5307	Economy	14400.00
0005435614290	5307	Economy	14400.00
0005434244829	5307	Economy	14400.00
0005435424621	5307	Economy	14400.00
0005433719117	5307	Economy	14400.00
0005434244975	5307	Economy	14400.00
0005434573421	5307	Economy	14400.00
0005435614177	5307	Economy	14400.00
0005434244838	5307	Economy	14400.00
0005434244862	5307	Economy	14400.00
0005435614228	5307	Economy	14400.00
0005435614260	5307	Economy	14400.00
0005435614204	5307	Economy	14400.00
0005435614299	5307	Economy	14400.00
0005435490246	5307	Economy	14400.00
0005432047569	5307	Economy	14400.00
0005435614294	5307	Economy	14400.00
0005432133281	5307	Economy	14400.00
0005435097255	5307	Economy	14400.00
0005435319596	5307	Economy	14400.00
0005435614277	5307	Economy	14400.00
0005435614182	5307	Economy	14400.00
0005435424848	5307	Economy	14400.00
0005432133289	5307	Economy	14400.00
0005435614215	5307	Economy	14400.00
0005434573433	5307	Economy	14400.00
0005435424574	5307	Economy	14400.00
0005435614255	5307	Economy	14400.00
0005434573420	5307	Economy	14400.00
0005435424449	5307	Economy	14400.00
0005433719139	5307	Economy	14400.00
0005434344410	5307	Economy	14400.00
0005434244738	5307	Economy	14400.00
0005435614205	5307	Economy	14400.00
0005434245008	5307	Economy	14400.00
0005435614263	5307	Economy	14400.00
0005435491448	5307	Economy	14400.00
0005433719127	5307	Economy	14400.00
0005434244963	5307	Economy	14400.00
0005435614242	5307	Economy	14400.00
0005435491449	5307	Economy	14400.00
0005434344406	5307	Economy	14400.00
0005435614191	5307	Economy	14400.00
0005435614258	5307	Economy	15800.00
0005435614273	5307	Economy	15800.00
0005434573431	5307	Economy	14400.00
0005435424536	5307	Economy	14400.00
0005435319582	5307	Economy	14400.00
0005435614198	5307	Economy	14400.00
0005435614193	5307	Economy	15800.00
0005435614234	5307	Economy	15800.00
0005435424669	5307	Economy	14400.00
0005435614274	5307	Economy	15800.00
0005435302184	5307	Economy	14400.00
0005434344427	5307	Economy	14400.00
0005432133293	5307	Economy	14400.00
0005435614256	5307	Economy	14400.00
0005435424456	5307	Economy	14400.00
0005435614225	5307	Economy	14400.00
0005434344423	5307	Economy	14400.00
0005432133292	5307	Economy	14400.00
0005434344416	5307	Economy	14400.00
0005434344431	5307	Economy	14400.00
0005434344404	5307	Economy	14400.00
0005435424805	5307	Economy	14400.00
0005435614221	5307	Economy	14400.00
0005435614233	5307	Economy	14400.00
0005435424773	5307	Economy	14400.00
0005435614186	5307	Economy	14400.00
0005435614306	5307	Economy	14400.00
0005435614286	5307	Economy	14400.00
0005435424544	5307	Economy	14400.00
0005434244863	5307	Economy	14400.00
0005432133296	5307	Economy	14400.00
0005435424861	5307	Economy	14400.00
0005435302182	5307	Economy	14400.00
0005435614189	5307	Economy	14400.00
0005434344399	5307	Economy	14400.00
0005435424894	5307	Economy	14400.00
0005435424677	5307	Economy	14400.00
0005435424450	5307	Economy	14400.00
0005435424668	5307	Economy	14400.00
0005435614265	5307	Economy	14400.00
0005434573422	5307	Economy	14400.00
0005435614184	5307	Economy	14400.00
0005434244869	5307	Economy	14400.00
0005435614305	5307	Economy	14400.00
0005434245010	5307	Economy	14400.00
0005435614308	5307	Economy	14400.00
0005435097253	5307	Economy	14400.00
0005435424578	5307	Economy	14400.00
0005434244940	5307	Economy	14400.00
0005435614266	5307	Economy	14400.00
0005432047570	5307	Economy	14400.00
0005435614272	5307	Economy	14400.00
0005433719116	5307	Economy	14400.00
0005432133282	5307	Economy	14400.00
0005435614217	5307	Economy	14400.00
0005434344412	5307	Economy	14400.00
0005435614216	5307	Economy	14400.00
0005435614240	5307	Economy	14400.00
0005434573419	5307	Economy	14400.00
0005434344401	5307	Economy	14400.00
0005435097254	5307	Economy	14400.00
0005434344436	5307	Economy	14400.00
0005435614287	5307	Economy	14400.00
0005435614190	5307	Economy	14400.00
0005434344417	5307	Economy	14400.00
0005435424622	5307	Economy	14400.00
0005435424533	5307	Economy	14400.00
0005435614213	5307	Economy	14400.00
0005435424435	5307	Economy	14400.00
0005435424478	5307	Economy	14400.00
0005434573426	5307	Economy	14400.00
0005435614196	5307	Economy	14400.00
0005435614278	5307	Economy	14400.00
0005435614241	5307	Economy	14400.00
0005435614314	5307	Economy	14400.00
0005435614311	5307	Economy	14400.00
0005435380286	5307	Economy	14400.00
0005435424645	5307	Economy	14400.00
0005435614292	5307	Economy	14400.00
0005435614296	5307	Economy	14400.00
0005434573428	5307	Economy	14400.00
0005434344413	5307	Economy	14400.00
0005435614202	5307	Economy	14400.00
0005435614238	5307	Economy	14400.00
0005435555380	5307	Economy	14400.00
0005435424809	5307	Economy	14400.00
0005435424649	5307	Economy	14400.00
0005435614301	5307	Economy	14400.00
0005435380287	5307	Economy	14400.00
0005432363403	5307	Economy	14400.00
0005435424613	5307	Economy	14400.00
0005435614237	5307	Economy	14400.00
0005434344421	5307	Economy	14400.00
0005434344420	5307	Economy	14400.00
0005434244857	5307	Economy	14400.00
0005435614227	5307	Economy	14400.00
0005435614285	5307	Economy	14400.00
0005435555379	5307	Economy	14400.00
0005435614289	5307	Economy	14400.00
0005435424573	5307	Economy	14400.00
0005434244756	5307	Economy	14400.00
0005435614282	5307	Economy	14400.00
0005435319527	5307	Economy	14400.00
0005434344418	5307	Economy	14400.00
0005435614252	5307	Economy	14400.00
0005435424464	5307	Economy	14400.00
0005435614229	5307	Economy	14400.00
0005433719138	5307	Economy	14400.00
0005435614206	5307	Economy	14400.00
0005435319477	5307	Economy	14400.00
0005434573423	5307	Economy	14400.00
0005435614247	5307	Economy	14400.00
0005435614295	5307	Economy	14400.00
0005434344407	5307	Economy	14400.00
0005435614201	5307	Economy	14400.00
0005434344400	5307	Economy	14400.00
0005435614230	5307	Economy	15800.00
0005435614250	5307	Economy	15800.00
0005435614183	5307	Economy	15800.00
0005435097248	5307	Economy	15800.00
0005434344419	5307	Economy	15800.00
0005432133291	5307	Economy	14400.00
0005435490248	5307	Economy	15800.00
0005435302167	5307	Economy	14400.00
0005435424520	5307	Economy	14400.00
0005434344424	5307	Economy	14400.00
0005435614246	5307	Economy	14400.00
0005435424635	5307	Economy	14400.00
0005435614209	5307	Economy	14400.00
0005434573429	5307	Economy	14400.00
0005435614259	5307	Economy	14400.00
0005435614235	5307	Economy	14400.00
0005435614179	5307	Economy	14400.00
0005434244960	5307	Economy	14400.00
0005435614223	5307	Economy	14400.00
0005435614211	5307	Economy	14400.00
0005435097249	5307	Economy	14400.00
0005435424832	5307	Economy	14400.00
0005434344414	5307	Economy	14400.00
0005435614180	5307	Economy	14400.00
0005434244764	5307	Economy	14400.00
0005434344403	5307	Economy	14400.00
0005435614268	5307	Economy	14400.00
0005434244836	5307	Economy	14400.00
0005435614302	5307	Economy	14400.00
0005435614249	5307	Economy	14400.00
0005435424521	5307	Economy	14400.00
0005434244868	5307	Economy	14400.00
0005435614269	5307	Economy	14400.00
0005435614309	5307	Economy	14400.00
0005435097251	5307	Economy	14400.00
0005435614187	5307	Economy	14400.00
0005435614270	5307	Economy	14400.00
0005435614181	5307	Economy	14400.00
0005435424600	5307	Economy	14400.00
0005435424774	5307	Economy	14400.00
0005435097252	5307	Economy	14400.00
0005435614276	5307	Economy	14400.00
0005435424750	5307	Economy	14400.00
0005432133286	5307	Economy	14400.00
0005435424740	5307	Economy	14400.00
0005435614288	5307	Economy	14400.00
0005435614214	5307	Economy	14400.00
0005435614300	5307	Economy	14400.00
0005435614298	5307	Economy	14400.00
0005434344405	5307	Economy	14400.00
0005435614248	5307	Economy	14400.00
0005435614220	5307	Economy	14400.00
0005435614199	5307	Economy	14400.00
0005435614212	5307	Economy	14400.00
0005435424775	5307	Economy	14400.00
0005434344433	5307	Economy	14400.00
0005435424667	5307	Economy	14400.00
0005435614253	5307	Economy	14400.00
0005435614244	5307	Economy	14400.00
0005435614243	5307	Economy	14400.00
0005435614313	5307	Economy	14400.00
0005435424546	5307	Economy	14400.00
0005434245051	5307	Economy	14400.00
0005435424575	5307	Economy	14400.00
0005435424716	5307	Economy	14400.00
0005435614245	5307	Economy	14400.00
0005435614267	5307	Economy	14400.00
0005434244913	5307	Economy	14400.00
0005435424607	5307	Economy	14400.00
0005434573430	5307	Economy	14400.00
0005435614261	5307	Economy	14400.00
0005435424688	5307	Economy	14400.00
0005434344425	5307	Economy	14400.00
0005432133287	5307	Economy	14400.00
0005435614307	5307	Economy	14400.00
0005434344411	5307	Economy	14400.00
0005435614283	5307	Economy	14400.00
0005435614304	5307	Economy	14400.00
0005434244853	5307	Economy	14400.00
0005432133288	5307	Economy	14400.00
0005435424661	5307	Economy	14400.00
0005435319573	5307	Economy	14400.00
0005435424812	5307	Economy	14400.00
0005435614188	5307	Economy	14400.00
0005435614239	5307	Economy	14400.00
0005434344408	5307	Economy	14400.00
0005435614219	5307	Economy	14400.00
0005435424768	5307	Economy	14400.00
0005435614275	5307	Economy	14400.00
0005434244974	5307	Economy	14400.00
0005435424250	5307	Economy	14400.00
0005435614284	5307	Economy	14400.00
0005435302164	5307	Economy	14400.00
0005434244788	5307	Economy	14400.00
0005435614293	5307	Economy	14400.00
0005434344430	5307	Economy	14400.00
0005435424545	5307	Economy	14400.00
0005435490247	5307	Economy	14400.00
0005434344422	5307	Economy	14400.00
0005435614310	5307	Economy	14400.00
0005433719130	5307	Economy	14400.00
0005434344429	5307	Economy	14400.00
0005435614312	5307	Economy	14400.00
0005434573425	5307	Economy	14400.00
0005435424285	5307	Economy	14400.00
0005435424465	5307	Economy	14400.00
0005435614185	5307	Economy	14400.00
0005435613213	10884	Business	43100.00
0005435613174	10884	Business	43100.00
0005435613323	10884	Business	43100.00
0005434344054	10884	Business	43100.00
0005435425152	10884	Business	43100.00
0005434245131	10884	Business	43100.00
0005434245139	10884	Business	43100.00
0005435425182	10884	Business	43100.00
0005434245125	10884	Business	43100.00
0005435425158	10884	Business	43100.00
0005435613091	10884	Business	43100.00
0005435613313	10884	Business	43100.00
0005435319621	10884	Business	43100.00
0005434245137	10884	Business	43100.00
0005435304183	10884	Business	43100.00
0005435613062	10884	Business	43100.00
0005435425137	10884	Business	43100.00
0005434573217	10884	Business	43100.00
0005434344014	10884	Business	43100.00
0005435612944	10884	Business	43100.00
0005435425193	10884	Business	43100.00
0005435613040	10884	Business	43100.00
0005434245145	10884	Business	43100.00
0005434245129	10884	Business	43100.00
0005434343989	10884	Business	43100.00
0005435425144	10884	Comfort	24400.00
0005435612948	10884	Comfort	24400.00
0005435380314	10884	Comfort	24400.00
0005435097200	10884	Comfort	24400.00
0005435425196	10884	Comfort	24400.00
0005435612945	10884	Comfort	24400.00
0005435613363	10884	Comfort	24400.00
0005435613106	10884	Comfort	24400.00
0005434573308	10884	Comfort	24400.00
0005435425175	10884	Comfort	24400.00
0005435613144	10884	Comfort	24400.00
0005435613200	10884	Comfort	24400.00
0005434245136	10884	Comfort	24400.00
0005435612720	10884	Comfort	24400.00
0005435612553	10884	Comfort	24400.00
0005435425147	10884	Comfort	24400.00
0005433719158	10884	Comfort	24400.00
0005435491429	10884	Comfort	24400.00
0005433719160	10884	Comfort	24400.00
0005435425128	10884	Comfort	24400.00
0005435425134	10884	Comfort	24400.00
0005432166919	10884	Comfort	24400.00
0005435612995	10884	Comfort	24400.00
0005434344260	10884	Comfort	24400.00
0005435425176	10884	Comfort	24400.00
0005435612971	10884	Comfort	24400.00
0005435304180	10884	Comfort	24400.00
0005435425179	10884	Comfort	24400.00
0005434245143	10884	Comfort	24400.00
0005435612775	10884	Comfort	24400.00
0005434245133	10884	Comfort	24400.00
0005434573281	10884	Comfort	24400.00
0005435425131	10884	Comfort	24400.00
0005435612929	10884	Comfort	24400.00
0005435612968	10884	Comfort	24400.00
0005435319622	10884	Comfort	24400.00
0005434245142	10884	Comfort	24400.00
0005432165078	10884	Comfort	24400.00
0005434656568	10884	Comfort	24400.00
0005434344158	10884	Economy	14400.00
0005435425163	10884	Economy	14400.00
0005435305020	10884	Economy	14400.00
0005435613355	10884	Economy	14400.00
0005435613188	10884	Economy	14400.00
0005435613160	10884	Economy	14400.00
0005435613090	10884	Economy	14400.00
0005434573274	10884	Economy	14400.00
0005435612797	10884	Economy	14400.00
0005434344026	10884	Economy	14400.00
0005435613226	10884	Economy	14400.00
0005434573295	10884	Economy	14400.00
0005434573271	10884	Economy	14400.00
0005435425167	10884	Economy	14400.00
0005435425129	10884	Economy	14400.00
0005435425166	10884	Economy	14400.00
0005434343921	10884	Economy	14400.00
0005434245127	10884	Economy	14400.00
0005434245140	10884	Economy	14400.00
0005435319618	10884	Economy	14400.00
0005434343873	10884	Economy	14400.00
0005435425126	10884	Economy	14400.00
0005435613108	10884	Economy	14400.00
0005432166920	10884	Economy	14400.00
0005435612922	10884	Economy	14400.00
0005435613061	10884	Economy	14400.00
0005435613370	10884	Economy	14400.00
0005432841023	10884	Economy	14400.00
0005435097189	10884	Economy	14400.00
0005435613240	10884	Economy	14400.00
0005435613148	10884	Economy	14400.00
0005435425189	10884	Economy	14400.00
0005434343997	10884	Economy	14400.00
0005435425171	10884	Economy	14400.00
0005435380313	10884	Economy	14400.00
0005435425159	10884	Economy	14400.00
0005434344038	10884	Economy	14400.00
0005435490226	10884	Economy	14400.00
0005435425162	10884	Economy	14400.00
0005434344071	10884	Economy	14400.00
0005434656567	10884	Economy	14400.00
0005434573209	10884	Economy	14400.00
0005435613279	10884	Economy	14400.00
0005435612919	10884	Economy	14400.00
0005435425177	10884	Economy	14400.00
0005435425173	10884	Economy	14400.00
0005434343990	10884	Economy	14400.00
0005434245130	10884	Economy	14400.00
0005435305019	10884	Economy	14400.00
0005434245119	10884	Economy	14400.00
0005435097201	10884	Economy	14400.00
0005435425138	10884	Economy	14400.00
0005435425191	10884	Economy	14400.00
0005435613187	10884	Economy	14400.00
0005435612869	10884	Economy	14400.00
0005435425169	10884	Economy	14400.00
0005435425168	10884	Economy	14400.00
0005435425180	10884	Economy	14400.00
0005435613282	10884	Economy	14400.00
0005435613003	10884	Economy	14400.00
0005435612933	10884	Economy	14400.00
0005435490225	10884	Economy	14400.00
0005434573235	10884	Economy	15800.00
0005435425127	10884	Economy	14400.00
0005435613288	10884	Economy	15800.00
0005435319619	10884	Economy	14400.00
0005435612921	10884	Economy	14400.00
0005435425132	10884	Economy	14400.00
0005434573242	10884	Economy	14400.00
0005434344039	10884	Economy	15800.00
0005432165074	10884	Economy	15800.00
0005435042865	10884	Economy	15800.00
0005435613257	10884	Economy	14400.00
0005435425160	10884	Economy	14400.00
0005435097157	10884	Economy	14400.00
0005435425151	10884	Economy	14400.00
0005435097171	10884	Economy	14400.00
0005434245135	10884	Economy	14400.00
0005434344070	10884	Economy	14400.00
0005435380311	10884	Economy	14400.00
0005435612994	10884	Economy	14400.00
0005435425148	10884	Economy	14400.00
0005435612644	10884	Economy	14400.00
0005435613362	10884	Economy	14400.00
0005434573208	10884	Economy	14400.00
0005435425146	10884	Economy	14400.00
0005434344116	10884	Economy	14400.00
0005435425153	10884	Economy	14400.00
0005434573359	10884	Economy	14400.00
0005435425178	10884	Economy	14400.00
0005435613011	10884	Economy	14400.00
0005434343973	10884	Economy	14400.00
0005435425150	10884	Economy	14400.00
0005435097186	10884	Economy	14400.00
0005434245120	10884	Economy	14400.00
0005435425149	10884	Economy	14400.00
0005434344156	10884	Economy	14400.00
0005435097123	10884	Economy	14400.00
0005434245116	10884	Economy	14400.00
0005435613314	10884	Economy	14400.00
0005434343974	10884	Economy	14400.00
0005435613366	10884	Economy	14400.00
0005432165077	10884	Economy	14400.00
0005435097179	10884	Economy	14400.00
0005435380312	10884	Economy	14400.00
0005434344259	10884	Economy	14400.00
0005435612981	10884	Economy	14400.00
0005435491433	10884	Economy	14400.00
0005435612495	10884	Economy	14400.00
0005435425181	10884	Economy	14400.00
0005435612552	10884	Economy	14400.00
0005434245123	10884	Economy	14400.00
0005435613269	10884	Economy	14400.00
0005435425157	10884	Economy	14400.00
0005435490212	10884	Economy	14400.00
0005435613173	10884	Economy	14400.00
0005435425164	10884	Economy	14400.00
0005435612970	10884	Economy	14400.00
0005435555360	10884	Economy	14400.00
0005435425172	10884	Economy	14400.00
0005433719157	10884	Economy	14400.00
0005434245126	10884	Economy	14400.00
0005432165076	10884	Economy	14400.00
0005435612798	10884	Economy	14400.00
0005435425136	10884	Economy	14400.00
0005434245146	10884	Economy	14400.00
0005435613063	10884	Economy	14400.00
0005434245117	10884	Economy	14400.00
0005435613324	10884	Economy	14400.00
0005432166918	10884	Economy	14400.00
0005434245118	10884	Economy	14400.00
0005434343872	10884	Economy	14400.00
0005435425140	10884	Economy	14400.00
0005432841024	10884	Economy	14400.00
0005435613365	10884	Economy	14400.00
0005434245138	10884	Economy	14400.00
0005435097161	10884	Economy	14400.00
0005435425141	10884	Economy	14400.00
0005434245134	10884	Economy	14400.00
0005435425139	10884	Economy	14400.00
0005435425192	10884	Economy	14400.00
0005434343923	10884	Economy	14400.00
0005435319615	10884	Economy	14400.00
0005435613212	10884	Economy	14400.00
0005435612859	10884	Economy	14400.00
0005435425185	10884	Economy	14400.00
0005434344118	10884	Economy	14400.00
0005435425156	10884	Economy	14400.00
0005435555361	10884	Economy	14400.00
0005434573268	10884	Economy	14400.00
0005434343874	10884	Economy	14400.00
0005435425143	10884	Economy	14400.00
0005435097147	10884	Economy	14400.00
0005435305021	10884	Economy	14400.00
0005435613280	10884	Economy	14400.00
0005434656566	10884	Economy	14400.00
0005435612822	10884	Economy	14400.00
0005435612946	10884	Economy	14400.00
0005435425197	10884	Economy	14400.00
0005434344052	10884	Economy	14400.00
0005435613250	10884	Economy	14400.00
0005434343822	10884	Economy	14400.00
0005435425170	10884	Economy	14400.00
0005435425187	10884	Economy	14400.00
0005435425133	10884	Economy	14400.00
0005434344093	10884	Economy	14400.00
0005435613175	10884	Economy	14400.00
0005435425188	10884	Economy	15800.00
0005435613278	10884	Economy	15800.00
0005435612821	10884	Economy	15800.00
0005434245128	10884	Economy	15800.00
0005435304182	10884	Economy	15800.00
0005435612958	10884	Economy	14400.00
0005434573279	10884	Economy	15800.00
0005435613189	10884	Economy	14400.00
0005435613058	10884	Economy	14400.00
0005434573234	10884	Economy	14400.00
0005432166917	10884	Economy	14400.00
0005435613128	10884	Economy	14400.00
0005435613195	10884	Economy	14400.00
0005435612950	10884	Economy	14400.00
0005432363432	10884	Economy	14400.00
0005434573278	10884	Economy	14400.00
0005435613249	10884	Economy	14400.00
0005435612719	10884	Economy	14400.00
0005434344015	10884	Economy	14400.00
0005432165073	10884	Economy	14400.00
0005435425161	10884	Economy	14400.00
0005435613176	10884	Economy	14400.00
0005435612972	10884	Economy	14400.00
0005435319617	10884	Economy	14400.00
0005434343786	10884	Economy	14400.00
0005435097173	10884	Economy	14400.00
0005435425142	10884	Economy	14400.00
0005435613004	10884	Economy	14400.00
0005435612918	10884	Economy	14400.00
0005434573280	10884	Economy	14400.00
0005435425184	10884	Economy	14400.00
0005435613186	10884	Economy	14400.00
0005435097146	10884	Economy	14400.00
0005435425135	10884	Economy	14400.00
0005434245124	10884	Economy	14400.00
0005434344027	10884	Economy	14400.00
0005435612947	10884	Economy	14400.00
0005435425195	10884	Economy	14400.00
0005435613136	10884	Economy	14400.00
0005434344170	10884	Economy	14400.00
0005434573318	10884	Economy	14400.00
0005435319620	10884	Economy	14400.00
0005435612984	10884	Economy	14400.00
0005434573275	10884	Economy	14400.00
0005434245122	10884	Economy	14400.00
0005435613287	10884	Economy	14400.00
0005433719159	10884	Economy	14400.00
0005435319616	10884	Economy	14400.00
0005435425183	10884	Economy	14400.00
0005435613315	10884	Economy	14400.00
0005434344180	10884	Economy	14400.00
0005435491431	10884	Economy	14400.00
0005434344028	10884	Economy	14400.00
0005435612858	10884	Economy	14400.00
0005435097159	10884	Economy	14400.00
0005435612979	10884	Economy	14400.00
0005435613178	10884	Economy	14400.00
0005432165080	10884	Economy	14400.00
0005435097172	10884	Economy	14400.00
0005435097124	10884	Economy	14400.00
0005432363433	10884	Economy	14400.00
0005434245132	10884	Economy	14400.00
0005435425194	10884	Economy	14400.00
0005435612643	10884	Economy	14400.00
0005435425154	10884	Economy	14400.00
0005432165075	10884	Economy	14400.00
0005435425130	10884	Economy	14400.00
0005434245144	10884	Economy	14400.00
0005435613055	10884	Economy	14400.00
0005435613149	10884	Economy	14400.00
0005435490203	10884	Economy	14400.00
0005434343922	10884	Economy	14400.00
0005435425165	10884	Economy	14400.00
0005435613130	10884	Economy	14400.00
0005432165079	10884	Economy	14400.00
0005435425174	10884	Economy	14400.00
0005435097187	10884	Economy	14400.00
0005435304181	10884	Economy	14400.00
0005435425145	10884	Economy	14400.00
0005434573283	10884	Economy	14400.00
0005434245141	10884	Economy	14400.00
0005434344117	10884	Economy	14400.00
0005434245121	10884	Economy	14400.00
0005435097166	10884	Economy	14400.00
0005435613241	10884	Economy	14400.00
0005435425155	10884	Economy	14400.00
0005435613190	10884	Economy	14400.00
0005435612776	10884	Economy	14400.00
0005435613199	10884	Economy	14400.00
0005435305022	10884	Economy	14400.00
0005435425186	10884	Economy	14400.00
0005435613089	10884	Economy	14400.00
0005434573286	10884	Economy	14400.00
0005435380315	10884	Economy	14400.00
0005435613143	10884	Economy	14400.00
0005434344210	10884	Economy	14400.00
0005435097148	10884	Economy	14400.00
0005435304179	10884	Economy	14400.00
0005435425190	10884	Economy	14400.00
0005434573262	10884	Economy	14400.00
0005434344157	10884	Economy	14400.00
0005435612781	10884	Economy	14400.00
0005433805546	3269	Business	18800.00
0005432459790	3269	Business	18800.00
0005432459698	3269	Business	18800.00
0005432459723	3269	Business	18800.00
0005433507279	3269	Business	18800.00
0005433805549	3269	Business	18800.00
0005433634000	3269	Business	18800.00
0005433805571	3269	Business	18800.00
0005432459544	3269	Business	18800.00
0005432459687	3269	Business	18800.00
0005432459812	3269	Business	18800.00
0005433805538	3269	Business	18800.00
0005433805548	3269	Business	18800.00
0005433805554	3269	Business	18800.00
0005432459420	3269	Business	18800.00
0005432181828	3269	Business	18800.00
0005433634003	3269	Business	18800.00
0005432181829	3269	Business	18800.00
0005432459443	3269	Business	18800.00
0005432459731	3269	Business	18800.00
0005433805555	3269	Business	18800.00
0005433633986	3269	Business	18800.00
0005433805552	3269	Business	18800.00
0005433805545	3269	Business	18800.00
0005433805556	3269	Business	18800.00
0005433805559	3269	Business	18800.00
0005433507284	3269	Business	18800.00
0005433805537	3269	Business	18800.00
0005432459842	3269	Economy	6900.00
0005433805562	3269	Economy	6900.00
0005432181838	3269	Economy	6900.00
0005433634008	3269	Economy	6900.00
0005433633987	3269	Economy	6900.00
0005433507270	3269	Economy	6900.00
0005433633990	3269	Economy	6300.00
0005432459396	3269	Economy	6300.00
0005433634007	3269	Economy	6300.00
0005432459568	3269	Economy	6300.00
0005432181830	3269	Economy	6300.00
0005432459442	3269	Economy	6300.00
0005433805564	3269	Economy	6300.00
0005433507273	3269	Economy	6300.00
0005433805572	3269	Economy	6300.00
0005432181831	3269	Economy	6300.00
0005432459672	3269	Economy	6300.00
0005433633998	3269	Economy	6300.00
0005433633984	3269	Economy	6300.00
0005433805550	3269	Economy	6300.00
0005433805536	3269	Economy	6300.00
0005433805568	3269	Economy	6300.00
0005432459728	3269	Economy	6300.00
0005433634014	3269	Economy	6300.00
0005433805542	3269	Economy	6300.00
0005433634013	3269	Economy	6300.00
0005433507286	3269	Economy	6300.00
0005433634015	3269	Economy	6300.00
0005432181833	3269	Economy	6300.00
0005433633995	3269	Economy	6300.00
0005432459679	3269	Economy	6300.00
0005433633989	3269	Economy	6300.00
0005432459748	3269	Economy	6300.00
0005432459549	3269	Economy	6300.00
0005433634004	3269	Economy	6300.00
0005432459755	3269	Economy	6300.00
0005433805553	3269	Economy	6300.00
0005432459699	3269	Economy	6300.00
0005432181822	3269	Economy	6300.00
0005432459621	3269	Economy	6300.00
0005433507271	3269	Economy	6300.00
0005432181823	3269	Economy	6300.00
0005432459686	3269	Economy	6300.00
0005433634005	3269	Economy	6300.00
0005433633997	3269	Economy	6300.00
0005432181832	3269	Economy	6300.00
0005433634002	3269	Economy	6300.00
0005433633993	3269	Economy	6300.00
0005433507282	3269	Economy	6300.00
0005433805560	3269	Economy	6300.00
0005432181839	3269	Economy	6300.00
0005432459839	3269	Economy	6300.00
0005432459771	3269	Economy	6300.00
0005433633982	3269	Economy	6300.00
0005432459811	3269	Economy	6300.00
0005432181841	3269	Economy	6300.00
0005432459616	3269	Economy	6300.00
0005432459461	3269	Economy	6300.00
0005433805565	3269	Economy	6300.00
0005433633994	3269	Economy	6300.00
0005433507272	3269	Economy	6300.00
0005432459462	3269	Economy	6300.00
0005433805539	3269	Economy	6300.00
0005433805544	3269	Economy	6300.00
0005433633992	3269	Economy	6900.00
0005433634001	3269	Economy	6900.00
0005432459779	3269	Economy	6900.00
0005433633985	3269	Economy	6900.00
0005432459716	3269	Economy	6900.00
0005433805570	3269	Economy	6300.00
0005432181827	3269	Economy	6300.00
0005433805566	3269	Economy	6300.00
0005432181824	3269	Economy	6300.00
0005432459620	3269	Economy	6900.00
0005432459760	3269	Economy	6300.00
0005432459680	3269	Economy	6300.00
0005433633988	3269	Economy	6300.00
0005432181835	3269	Economy	6300.00
0005432459533	3269	Economy	6300.00
0005432459497	3269	Economy	6300.00
0005432181842	3269	Economy	6300.00
0005433805561	3269	Economy	6300.00
0005432459645	3269	Economy	6300.00
0005433634011	3269	Economy	6300.00
0005433507283	3269	Economy	6300.00
0005433507275	3269	Economy	6300.00
0005433805541	3269	Economy	6300.00
0005433634010	3269	Economy	6300.00
0005432459395	3269	Economy	6300.00
0005432459697	3269	Economy	6300.00
0005433633983	3269	Economy	6300.00
0005432181825	3269	Economy	6300.00
0005432459681	3269	Economy	6300.00
0005433805551	3269	Economy	6300.00
0005433507277	3269	Economy	6300.00
0005432459722	3269	Economy	6300.00
0005432181834	3269	Economy	6300.00
0005432459543	3269	Economy	6300.00
0005433633999	3269	Economy	6300.00
0005433507278	3269	Economy	6300.00
0005432459843	3269	Economy	6300.00
0005432459534	3269	Economy	6300.00
0005432459575	3269	Economy	6300.00
0005432459596	3269	Economy	6300.00
0005433805567	3269	Economy	6300.00
0005433507269	3269	Economy	6300.00
0005432459577	3269	Economy	6300.00
0005433805543	3269	Economy	6300.00
0005432459717	3269	Economy	6300.00
0005433507281	3269	Economy	6300.00
0005433633991	3269	Economy	6300.00
0005433805569	3269	Economy	6300.00
0005432459491	3269	Economy	6300.00
0005432181836	3269	Economy	6300.00
0005433634009	3269	Economy	6300.00
0005433805563	3269	Economy	6300.00
0005433805547	3269	Economy	6300.00
0005433805540	3269	Economy	6300.00
0005432459810	3269	Economy	6300.00
0005433507276	3269	Economy	6300.00
0005433507280	3269	Economy	6300.00
0005432459411	3269	Economy	6300.00
0005433507285	3269	Economy	6300.00
0005432459576	3269	Economy	6300.00
0005433633996	3269	Economy	6300.00
0005433507274	3269	Economy	6300.00
0005432459556	3269	Economy	6300.00
0005432181826	3269	Economy	6300.00
0005432459759	3269	Economy	6300.00
0005433805557	3269	Economy	6300.00
0005433805558	3269	Economy	6300.00
0005432459718	3269	Economy	6300.00
0005432181840	3269	Economy	6300.00
0005432181837	3269	Economy	6300.00
0005433634012	3269	Economy	6300.00
0005433634006	3269	Economy	6300.00
0005435885033	3268	Business	18800.00
0005435885160	3268	Business	18800.00
0005435885157	3268	Business	18800.00
0005435885021	3268	Business	18800.00
0005435885170	3268	Business	18800.00
0005435885256	3268	Business	18800.00
0005435885210	3268	Business	18800.00
0005435884914	3268	Economy	6900.00
0005435885316	3268	Economy	6300.00
0005435885112	3268	Economy	6300.00
0005435885248	3268	Economy	6300.00
0005435884851	3268	Economy	6300.00
0005435885186	3268	Economy	6300.00
0005435885113	3268	Economy	6300.00
0005435885044	3268	Economy	6300.00
0005435885250	3268	Economy	6300.00
0005435884888	3268	Economy	6300.00
0005435885161	3268	Economy	6300.00
0005435885095	3268	Economy	6300.00
0005435885249	3268	Economy	6300.00
0005435885209	3268	Economy	6300.00
0005435884890	3268	Economy	6300.00
0005435885084	3268	Economy	6300.00
0005435885045	3268	Economy	6300.00
0005435885140	3268	Economy	6300.00
0005435885094	3268	Economy	6300.00
0005435885178	3268	Economy	6900.00
0005435885213	3268	Economy	6300.00
0005435885174	3268	Economy	6300.00
0005435885167	3268	Economy	6300.00
0005435884887	3268	Economy	6300.00
0005435885022	3268	Economy	6300.00
0005435885200	3268	Economy	6300.00
0005435885301	3268	Economy	6300.00
0005435885172	3268	Economy	6300.00
0005435885048	3268	Economy	6300.00
0005435885134	3268	Economy	6300.00
0005435885049	3268	Economy	6300.00
0005435885043	3268	Economy	6300.00
0005435885055	3268	Economy	6300.00
0005435885302	3268	Economy	6300.00
0005435885173	3268	Economy	6300.00
0005435885093	3268	Economy	6300.00
0005435885480	8171	Business	18800.00
0005435885502	8171	Business	18800.00
0005435885516	8171	Business	18800.00
0005435885513	8171	Business	18800.00
0005432042788	8171	Business	18800.00
0005432460178	8171	Business	18800.00
0005435885479	8171	Business	18800.00
0005432042794	8171	Business	18800.00
0005432042782	8171	Business	18800.00
0005432460174	8171	Business	18800.00
0005432460147	8171	Business	18800.00
0005432460163	8171	Business	18800.00
0005435885514	8171	Business	18800.00
0005435885517	8171	Business	18800.00
0005435885485	8171	Business	18800.00
0005432460149	8171	Business	18800.00
0005435885515	8171	Business	18800.00
0005432042781	8171	Business	18800.00
0005432460141	8171	Business	18800.00
0005432460138	8171	Business	18800.00
0005435885483	8171	Business	18800.00
0005435885477	8171	Business	18800.00
0005432042792	8171	Business	18800.00
0005435885478	8171	Economy	6900.00
0005435885482	8171	Economy	6900.00
0005432460166	8171	Economy	6900.00
0005435885497	8171	Economy	6900.00
0005434312332	8171	Economy	6900.00
0005432460183	8171	Economy	6300.00
0005435885498	8171	Economy	6300.00
0005432460144	8171	Economy	6300.00
0005432460136	8171	Economy	6300.00
0005435885525	8171	Economy	6300.00
0005433507027	8171	Economy	6300.00
0005432460151	8171	Economy	6300.00
0005432460167	8171	Economy	6300.00
0005435885528	8171	Economy	6300.00
0005432460182	8171	Economy	6300.00
0005434312331	8171	Economy	6300.00
0005432460155	8171	Economy	6300.00
0005432042795	8171	Economy	6300.00
0005435885523	8171	Economy	6300.00
0005432460179	8171	Economy	6300.00
0005432042789	8171	Economy	6300.00
0005435885481	8171	Economy	6300.00
0005432042784	8171	Economy	6300.00
0005432042786	8171	Economy	6300.00
0005432460164	8171	Economy	6300.00
0005432460154	8171	Economy	6300.00
0005433507092	8171	Economy	6300.00
0005432460169	8171	Economy	6300.00
0005435885518	8171	Economy	6300.00
0005435885484	8171	Economy	6300.00
0005435885524	8171	Economy	6300.00
0005432460148	8171	Economy	6300.00
0005435885491	8171	Economy	6300.00
0005435885489	8171	Economy	6300.00
0005432460158	8171	Economy	6300.00
0005432460180	8171	Economy	6300.00
0005435885471	8171	Economy	6300.00
0005432460153	8171	Economy	6300.00
0005435885519	8171	Economy	6300.00
0005435885476	8171	Economy	6300.00
0005432460143	8171	Economy	6300.00
0005432460184	8171	Economy	6300.00
0005435885472	8171	Economy	6300.00
0005435885486	8171	Economy	6300.00
0005435885470	8171	Economy	6300.00
0005432460132	8171	Economy	6300.00
0005435885494	8171	Economy	6300.00
0005433507132	8171	Economy	6300.00
0005432460165	8171	Economy	6300.00
0005433507126	8171	Economy	6300.00
0005435885493	8171	Economy	6300.00
0005435885508	8171	Economy	6300.00
0005433507116	8171	Economy	6300.00
0005435885521	8171	Economy	6300.00
0005435885501	8171	Economy	6300.00
0005432460172	8171	Economy	6900.00
0005432460137	8171	Economy	6900.00
0005432042785	8171	Economy	6900.00
0005432460177	8171	Economy	6900.00
0005432460150	8171	Economy	6900.00
0005432460133	8171	Economy	6300.00
0005432042791	8171	Economy	6300.00
0005432042790	8171	Economy	6300.00
0005435885487	8171	Economy	6300.00
0005432042793	8171	Economy	6900.00
0005432460139	8171	Economy	6300.00
0005435885495	8171	Economy	6300.00
0005432460170	8171	Economy	6300.00
0005432460162	8171	Economy	6300.00
0005435885490	8171	Economy	6300.00
0005432042783	8171	Economy	6300.00
0005435885505	8171	Economy	6300.00
0005432460157	8171	Economy	6300.00
0005435885527	8171	Economy	6300.00
0005432460175	8171	Economy	6300.00
0005432460145	8171	Economy	6300.00
0005432460135	8171	Economy	6300.00
0005432460142	8171	Economy	6300.00
0005432460171	8171	Economy	6300.00
0005435885475	8171	Economy	6300.00
0005432460161	8171	Economy	6300.00
0005435885473	8171	Economy	6300.00
0005433507100	8171	Economy	6300.00
0005432460160	8171	Economy	6300.00
0005432460146	8171	Economy	6300.00
0005435885510	8171	Economy	6300.00
0005435885529	8171	Economy	6300.00
0005435885522	8171	Economy	6300.00
0005432460181	8171	Economy	6300.00
0005435885507	8171	Economy	6300.00
0005435885509	8171	Economy	6300.00
0005433507119	8171	Economy	6300.00
0005432460173	8171	Economy	6300.00
0005433507117	8171	Economy	6300.00
0005432460140	8171	Economy	6300.00
0005432460168	8171	Economy	6300.00
0005435885503	8171	Economy	6300.00
0005432460159	8171	Economy	6300.00
0005432460134	8171	Economy	6300.00
0005432460152	8171	Economy	6300.00
0005435885499	8171	Economy	6300.00
0005435885511	8171	Economy	6300.00
0005435885500	8171	Economy	6300.00
0005435885488	8171	Economy	6300.00
0005435885506	8171	Economy	6300.00
0005432460156	8171	Economy	6300.00
0005435885512	8171	Economy	6300.00
0005432042787	8171	Economy	6300.00
0005435885526	8171	Economy	6300.00
0005435885496	8171	Economy	6300.00
0005435885474	8171	Economy	6300.00
0005432460176	8171	Economy	6300.00
0005435885520	8171	Economy	6300.00
0005433507094	8171	Economy	6300.00
0005435885492	8171	Economy	6300.00
0005435885504	8171	Economy	6300.00
0005433633723	8164	Business	18800.00
0005433805133	8164	Business	18800.00
0005433633684	8164	Business	18800.00
0005433805183	8164	Business	18800.00
0005433633678	8164	Business	18800.00
0005433633744	8164	Business	18800.00
0005433633574	8164	Business	18800.00
0005433633593	8164	Business	18800.00
0005433805209	8164	Business	18800.00
0005433805252	8164	Business	18800.00
0005433805248	8164	Business	18800.00
0005433633585	8164	Business	18800.00
0005433805414	8164	Economy	6900.00
0005433805087	8164	Economy	6300.00
0005433805397	8164	Economy	6300.00
0005433633759	8164	Economy	6300.00
0005433805192	8164	Economy	6300.00
0005433805382	8164	Economy	6300.00
0005433633549	8164	Economy	6300.00
0005433633587	8164	Economy	6300.00
0005433633694	8164	Economy	6300.00
0005433633632	8164	Economy	6300.00
0005433805250	8164	Economy	6300.00
0005433633683	8164	Economy	6300.00
0005433805275	8164	Economy	6300.00
0005433633588	8164	Economy	6300.00
0005433633532	8164	Economy	6300.00
0005434143711	8164	Economy	6300.00
0005433633672	8164	Economy	6300.00
0005434143717	8164	Economy	6300.00
0005433805191	8164	Economy	6300.00
0005433805193	8164	Economy	6300.00
0005433633680	8164	Economy	6300.00
0005433805251	8164	Economy	6300.00
0005433805229	8164	Economy	6300.00
0005433633575	8164	Economy	6300.00
0005433633668	8164	Economy	6300.00
0005433633701	8164	Economy	6300.00
0005433805325	8164	Economy	6300.00
0005433805357	8164	Economy	6300.00
0005433633652	8164	Economy	6300.00
0005433805283	8164	Economy	6300.00
0005433633696	8164	Economy	6300.00
0005433633741	8164	Economy	6900.00
0005434271302	8164	Economy	6900.00
0005434143724	8164	Economy	6300.00
0005433805224	8164	Economy	6300.00
0005433633697	8164	Economy	6300.00
0005433633758	8164	Economy	6900.00
0005433805160	8164	Economy	6300.00
0005433805348	8164	Economy	6300.00
0005433633673	8164	Economy	6300.00
0005433633617	8164	Economy	6300.00
0005433633551	8164	Economy	6300.00
0005433805226	8164	Economy	6300.00
0005434271303	8164	Economy	6300.00
0005433805088	8164	Economy	6300.00
0005433805184	8164	Economy	6300.00
0005433633703	8164	Economy	6300.00
0005433805174	8164	Economy	6300.00
0005433633757	8164	Economy	6300.00
0005433633665	8164	Economy	6300.00
0005433805210	8164	Economy	6300.00
0005433633733	8164	Economy	6300.00
0005433805211	8164	Economy	6300.00
0005433633608	8164	Economy	6300.00
0005433805225	8164	Economy	6300.00
0005434271307	8164	Economy	6300.00
0005433805322	8164	Economy	6300.00
0005433633718	8164	Economy	6300.00
0005434143710	8164	Economy	6300.00
0005433633653	8164	Economy	6300.00
0005433633700	8164	Economy	6300.00
0005433805298	8164	Economy	6300.00
0005433633713	8164	Economy	6300.00
0005433633681	8164	Economy	6300.00
0005434183573	8337	Economy	6300.00
0005434183580	8337	Economy	6300.00
0005432383374	4679	Business	9900.00
0005432728009	4679	Business	9900.00
0005432383367	4679	Business	9900.00
0005433453771	4679	Business	9900.00
0005433722266	4679	Business	9900.00
0005433722256	4679	Business	9900.00
0005432383362	4679	Business	9900.00
0005432383395	4679	Business	9900.00
0005432383373	4679	Economy	3300.00
0005433722267	4679	Economy	3300.00
0005432383401	4679	Economy	3300.00
0005432383375	4679	Economy	3300.00
0005432383391	4679	Economy	3300.00
0005432383369	4679	Economy	3300.00
0005432728007	4679	Economy	3600.00
0005432383399	4679	Economy	3600.00
0005433454887	4679	Economy	3600.00
0005433722259	4679	Economy	3600.00
0005432728010	4679	Economy	3300.00
0005433722263	4679	Economy	3300.00
0005432383380	4679	Economy	3300.00
0005432383377	4679	Economy	3300.00
0005432383376	4679	Economy	3300.00
0005433453770	4679	Economy	3300.00
0005432383365	4679	Economy	3300.00
0005432383372	4679	Economy	3300.00
0005433722257	4679	Economy	3300.00
0005432383382	4679	Economy	3300.00
0005432383383	4679	Economy	3300.00
0005432383363	4679	Economy	3300.00
0005432383371	4679	Economy	3300.00
0005432383396	4679	Economy	3300.00
0005432728000	4679	Economy	3300.00
0005432728006	4679	Economy	3300.00
0005432383390	4679	Economy	3300.00
0005432727998	4679	Economy	3300.00
0005432728001	4679	Economy	3300.00
0005432383359	4679	Economy	3300.00
0005433722258	4679	Economy	3300.00
0005432383397	4679	Economy	3300.00
0005432383392	4679	Economy	3300.00
0005433722255	4679	Economy	3300.00
0005432383384	4679	Economy	3300.00
0005432383394	4679	Economy	3300.00
0005432727999	4679	Economy	3300.00
0005432383360	4679	Economy	3300.00
0005432383364	4679	Economy	3300.00
0005432728003	4679	Economy	3300.00
0005432383389	4679	Economy	3300.00
0005432728005	4679	Economy	3300.00
0005432383379	4679	Economy	3300.00
0005433722268	4679	Economy	3300.00
0005433722262	4679	Economy	3300.00
0005432383378	4679	Economy	3300.00
0005432383366	4679	Economy	3300.00
0005432383385	4679	Economy	3300.00
0005432383398	4679	Economy	3300.00
0005432383388	4679	Economy	3300.00
0005432728008	4679	Economy	3300.00
0005433722261	4679	Economy	3300.00
0005433722265	4679	Economy	3300.00
0005432728004	4679	Economy	3300.00
0005432728002	4679	Economy	3300.00
0005432383381	4679	Economy	3300.00
0005432383370	4679	Economy	3300.00
0005432383386	4679	Economy	3300.00
0005433722254	4679	Economy	3300.00
0005433722264	4679	Economy	3300.00
0005433722269	4679	Economy	3300.00
0005433722260	4679	Economy	3300.00
0005432383368	4679	Economy	3300.00
0005432383387	4679	Economy	3300.00
0005432383393	4679	Economy	3300.00
0005432383400	4679	Economy	3300.00
0005432383361	4679	Economy	3300.00
0005433453759	30257	Business	9900.00
0005432727940	30257	Business	9900.00
0005432382926	30257	Business	9900.00
0005432382827	30257	Business	9900.00
0005432382925	30257	Business	9900.00
0005432382901	30257	Business	9900.00
0005432382780	30257	Business	9900.00
0005432383088	30257	Business	9900.00
0005432383075	30257	Economy	3300.00
0005432382844	30257	Economy	3300.00
0005432727939	30257	Economy	3300.00
0005432382909	30257	Economy	3300.00
0005432727883	30257	Economy	3300.00
0005432382779	30257	Economy	3300.00
0005433194843	30257	Economy	3300.00
0005432382945	30257	Economy	3300.00
0005432382978	30257	Economy	3600.00
0005432382873	30257	Economy	3600.00
0005432383001	30257	Economy	3300.00
0005432727938	30257	Economy	3300.00
0005432727923	30257	Economy	3300.00
0005432727921	30257	Economy	3300.00
0005432382902	30257	Economy	3300.00
0005432382736	30257	Economy	3300.00
0005432727900	30257	Economy	3300.00
0005432383168	30257	Economy	3300.00
0005432382977	30257	Economy	3300.00
0005432383122	30257	Economy	3300.00
0005432382908	30257	Economy	3300.00
0005432382759	30257	Economy	3300.00
0005432727914	30257	Economy	3300.00
0005432382855	30257	Economy	3300.00
0005432727795	30257	Economy	3300.00
0005432382989	30257	Economy	3300.00
0005432382921	30257	Economy	3300.00
0005432382903	30257	Economy	3300.00
0005432727924	30257	Economy	3300.00
0005432727884	30257	Economy	3300.00
0005432727919	30257	Economy	3300.00
0005432727868	30257	Economy	3300.00
0005433451609	30257	Economy	3300.00
0005432727899	30257	Economy	3300.00
0005432727916	30257	Economy	3300.00
0005432382954	30257	Economy	3300.00
0005433194855	30257	Economy	3300.00
0005432382948	30257	Economy	3300.00
0005432382859	30257	Economy	3300.00
0005432382922	30257	Economy	3300.00
0005432382881	30257	Economy	3300.00
0005432382781	30257	Economy	3300.00
0005432727920	30257	Economy	3300.00
0005432727913	30257	Economy	3300.00
0005432727877	30257	Economy	3300.00
0005432383124	30257	Economy	3300.00
0005432382755	30257	Economy	3300.00
0005432382778	30257	Economy	3300.00
0005432382900	30257	Economy	3300.00
0005432727937	30257	Economy	3300.00
0005432382787	30257	Economy	3300.00
0005432727796	30257	Economy	3300.00
0005432727878	30257	Economy	3300.00
0005432382733	30257	Economy	3300.00
0005432383074	30257	Economy	3300.00
0005432382953	30257	Economy	3300.00
0005433453760	30257	Economy	3300.00
0005432383123	30257	Economy	3300.00
0005432383002	30257	Economy	3300.00
0005432382835	30257	Economy	3300.00
0005432382947	30257	Economy	3300.00
0005432382946	30257	Economy	3300.00
0005432382777	30257	Economy	3300.00
0005432382949	30257	Economy	3300.00
0005432727942	30257	Economy	3300.00
0005433722170	30257	Economy	3300.00
0005435541119	1740	Business	57200.00
0005435541118	1740	Business	57200.00
0005433516934	1740	Business	57200.00
0005432925022	1740	Economy	19100.00
0005435529375	1740	Economy	19100.00
0005435529385	1740	Economy	19100.00
0005435541120	1740	Economy	19100.00
0005435529377	1740	Economy	19100.00
0005435541126	1740	Economy	19100.00
0005435541110	1740	Economy	19100.00
0005435529373	1740	Economy	19100.00
0005435529376	1740	Economy	21000.00
0005435529384	1740	Economy	21000.00
0005432925021	1740	Economy	21000.00
0005435529378	1740	Economy	19100.00
0005433516937	1740	Economy	19100.00
0005435541124	1740	Economy	19100.00
0005432294500	1740	Economy	19100.00
0005433516938	1740	Economy	19100.00
0005435541115	1740	Economy	19100.00
0005435541112	1740	Economy	19100.00
0005435529368	1740	Economy	19100.00
0005433516933	1740	Economy	19100.00
0005435541121	1740	Economy	19100.00
0005435541122	1740	Economy	19100.00
0005435529382	1740	Economy	19100.00
0005435541117	1740	Economy	19100.00
0005435541116	1740	Economy	19100.00
0005435529379	1740	Economy	19100.00
0005435541114	1740	Economy	19100.00
0005435541129	1740	Economy	19100.00
0005435529386	1740	Economy	19100.00
0005435541123	1740	Economy	19100.00
0005435529371	1740	Economy	19100.00
0005435529383	1740	Economy	19100.00
0005435529367	1740	Economy	19100.00
0005435541130	1740	Economy	19100.00
0005435529372	1740	Economy	19100.00
0005435529374	1740	Economy	19100.00
0005433516939	1740	Economy	19100.00
0005432294499	1740	Economy	19100.00
0005435541128	1740	Economy	19100.00
0005435541131	1740	Economy	19100.00
0005433516932	1740	Economy	19100.00
0005432925025	1740	Economy	19100.00
0005435529370	1740	Economy	19100.00
0005432925036	1740	Economy	19100.00
0005435529380	1740	Economy	19100.00
0005433516935	1740	Economy	19100.00
0005433516940	1740	Economy	19100.00
0005433516936	1740	Economy	19100.00
0005432294501	1740	Economy	19100.00
0005435541127	1740	Economy	19100.00
0005435541125	1740	Economy	19100.00
0005435529387	1740	Economy	19100.00
0005435529366	1740	Economy	19100.00
0005435529381	1740	Economy	19100.00
0005435541111	1740	Economy	19100.00
0005435541113	1740	Economy	19100.00
0005435529369	1740	Economy	19100.00
0005435540899	22000	Business	57200.00
0005432925063	22000	Business	57200.00
0005435517850	22000	Business	57200.00
0005435540884	22000	Business	57200.00
0005435540872	22000	Business	57200.00
0005435540986	22000	Business	57200.00
0005433516826	22000	Business	57200.00
0005435517799	22000	Business	57200.00
0005433516824	22000	Business	57200.00
0005435517908	22000	Business	57200.00
0005432925060	22000	Economy	19100.00
0005432925061	22000	Economy	19100.00
0005432925064	22000	Economy	19100.00
0005435540876	22000	Economy	21000.00
0005435517842	22000	Economy	21000.00
0005435517802	22000	Economy	19100.00
0005435517843	22000	Economy	19100.00
0005435540975	22000	Economy	19100.00
0005435517780	22000	Economy	19100.00
0005435540987	22000	Economy	19100.00
0005435540954	22000	Economy	19100.00
0005435540871	22000	Economy	19100.00
0005435540944	22000	Economy	19100.00
0005435517870	22000	Economy	19100.00
0005435517853	22000	Economy	19100.00
0005433516850	22000	Economy	19100.00
0005435517909	22000	Economy	19100.00
0005435517810	22000	Economy	19100.00
0005435517801	22000	Economy	19100.00
0005435517859	22000	Economy	19100.00
0005433516816	22000	Economy	19100.00
0005435517860	22000	Economy	19100.00
0005435540938	22000	Economy	19100.00
0005435540929	22000	Economy	19100.00
0005433516825	22000	Economy	19100.00
0005435540934	22000	Economy	19100.00
0005435540915	22000	Economy	19100.00
0005435540881	22000	Economy	19100.00
0005432925062	22000	Economy	19100.00
0005433516815	22000	Economy	19100.00
0005435540882	22000	Economy	19100.00
0005435517854	22000	Economy	19100.00
0005435517841	22000	Economy	19100.00
0005435540953	22000	Economy	19100.00
0005435517835	22000	Economy	19100.00
0005435517763	22000	Economy	19100.00
0005435517875	22000	Economy	19100.00
0005435517874	22000	Economy	19100.00
0005435517836	22000	Economy	19100.00
0005435540883	22000	Economy	19100.00
0005435252664	7409	Business	18500.00
0005435252628	7409	Business	18500.00
0005435252608	7409	Business	18500.00
0005434664943	7409	Business	18500.00
0005432839202	7409	Business	18500.00
0005434458916	7409	Business	18500.00
0005432839203	7409	Business	18500.00
0005432839198	7409	Business	18500.00
0005435252593	7409	Business	18500.00
0005434458920	7409	Business	18500.00
0005432839190	7409	Economy	6200.00
0005434458919	7409	Economy	6200.00
0005432839201	7409	Economy	6200.00
0005434458917	7409	Economy	6200.00
0005434458913	7409	Economy	6200.00
0005432839193	7409	Economy	6200.00
0005432839184	7409	Economy	6200.00
0005432073409	7409	Economy	6200.00
0005435252643	7409	Economy	6200.00
0005432839191	7409	Economy	6200.00
0005435491439	7409	Economy	6800.00
0005435252665	7409	Economy	6800.00
0005432073408	7409	Economy	6800.00
0005432839208	7409	Economy	6800.00
0005432839186	7409	Economy	6200.00
0005435491426	7409	Economy	6200.00
0005435252609	7409	Economy	6200.00
0005435252607	7409	Economy	6200.00
0005435252547	7409	Economy	6200.00
0005432839206	7409	Economy	6200.00
0005432839205	7409	Economy	6200.00
0005432839196	7409	Economy	6200.00
0005435252610	7409	Economy	6200.00
0005435252644	7409	Economy	6200.00
0005432839200	7409	Economy	6200.00
0005432839210	7409	Economy	6200.00
0005435252683	7409	Economy	6200.00
0005432841021	7409	Economy	6200.00
0005432839194	7409	Economy	6200.00
0005435252695	7409	Economy	6200.00
0005435252594	7409	Economy	6200.00
0005435491427	7409	Economy	6200.00
0005435252546	7409	Economy	6200.00
0005432839207	7409	Economy	6200.00
0005434458904	7409	Economy	6200.00
0005432839185	7409	Economy	6200.00
0005434458914	7409	Economy	6200.00
0005432823460	7409	Economy	6200.00
0005432839188	7409	Economy	6200.00
0005432839209	7409	Economy	6200.00
0005432073407	7409	Economy	6200.00
0005434458903	7409	Economy	6200.00
0005432839189	7409	Economy	6200.00
0005432839199	7409	Economy	6200.00
0005432839192	7409	Economy	6200.00
0005432841022	7409	Economy	6200.00
0005432839197	7409	Economy	6200.00
0005435252645	7409	Economy	6200.00
0005434458915	7409	Economy	6200.00
0005432839195	7409	Economy	6200.00
0005434458910	7409	Economy	6200.00
0005435252629	7409	Economy	6200.00
0005435252575	7409	Economy	6200.00
0005434458922	7409	Economy	6200.00
0005434458912	7409	Economy	6200.00
0005432839187	7409	Economy	6200.00
0005434458923	7409	Economy	6200.00
0005434458906	7409	Economy	6200.00
0005432839211	7409	Economy	6200.00
0005432839182	7409	Economy	6200.00
0005434458911	7409	Economy	6200.00
0005434458909	7409	Economy	6200.00
0005434458907	7409	Economy	6200.00
0005434458902	7409	Economy	6200.00
0005432823458	7409	Economy	6200.00
0005432823459	7409	Economy	6200.00
0005434458905	7409	Economy	6200.00
0005434458921	7409	Economy	6200.00
0005435252646	7409	Economy	6200.00
0005434458908	7409	Economy	6200.00
0005432839204	7409	Economy	6200.00
0005432839183	7409	Economy	6200.00
0005434458918	7409	Economy	6200.00
0005432838961	28928	Business	18500.00
0005434458783	28928	Business	18500.00
0005435491450	28928	Business	18500.00
0005435252800	28928	Business	18500.00
0005432839027	28928	Business	18500.00
0005432838946	28928	Business	18500.00
0005435252796	28928	Business	18500.00
0005432823438	28928	Business	18500.00
0005435252792	28928	Business	18500.00
0005434458796	28928	Business	18500.00
0005432838974	28928	Business	18500.00
0005434458805	28928	Business	18500.00
0005435252795	28928	Economy	6200.00
0005432838993	28928	Economy	6200.00
0005435252784	28928	Economy	6200.00
0005432839060	28928	Economy	6200.00
0005435252802	28928	Economy	6200.00
0005434458657	28928	Economy	6200.00
0005432838968	28928	Economy	6200.00
0005432839000	28928	Economy	6200.00
0005432838950	28928	Economy	6200.00
0005435252798	28928	Economy	6200.00
0005435491451	28928	Economy	6800.00
0005435252801	28928	Economy	6800.00
0005432838992	28928	Economy	6800.00
0005434458773	28928	Economy	6800.00
0005432838798	28928	Economy	6800.00
0005432838884	28928	Economy	6200.00
0005434458668	28928	Economy	6200.00
0005432841006	28928	Economy	6200.00
0005432001033	28928	Economy	6200.00
0005432841015	28928	Economy	6200.00
0005435252787	28928	Economy	6200.00
0005434458620	28928	Economy	6200.00
0005432838971	28928	Economy	6200.00
0005434458708	28928	Economy	6200.00
0005434664972	28928	Economy	6200.00
0005432838975	28928	Economy	6200.00
0005435252789	28928	Economy	6200.00
0005434458789	28928	Economy	6200.00
0005432001035	28928	Economy	6200.00
0005432838972	28928	Economy	6200.00
0005434458790	28928	Economy	6200.00
0005435252793	28928	Economy	6200.00
0005432838770	28928	Economy	6200.00
0005432841003	28928	Economy	6200.00
0005434458715	28928	Economy	6200.00
0005435252785	28928	Economy	6200.00
0005432839012	28928	Economy	6200.00
0005435252794	28928	Economy	6200.00
0005432839010	28928	Economy	6200.00
0005434458774	28928	Economy	6200.00
0005432839074	28928	Economy	6200.00
0005432838977	28928	Economy	6200.00
0005434458827	28928	Economy	6200.00
0005435252790	28928	Economy	6200.00
0005432838994	28928	Economy	6200.00
0005432839035	28928	Economy	6200.00
0005434458697	28928	Economy	6200.00
0005432001034	28928	Economy	6200.00
0005434458772	28928	Economy	6200.00
0005435252799	28928	Economy	6200.00
0005434458716	28928	Economy	6200.00
0005432838954	28928	Economy	6200.00
0005432839061	28928	Economy	6200.00
0005434458752	28928	Economy	6200.00
0005434458696	28928	Economy	6200.00
0005434458718	28928	Economy	6200.00
0005434664973	28928	Economy	6200.00
0005434458717	28928	Economy	6200.00
0005435252791	28928	Economy	6200.00
0005434458714	28928	Economy	6200.00
0005434664971	28928	Economy	6200.00
0005432838769	28928	Economy	6200.00
0005435252797	28928	Economy	6200.00
0005432839026	28928	Economy	6200.00
0005432838885	28928	Economy	6200.00
0005435491452	28928	Economy	6200.00
0005435252786	28928	Economy	6200.00
0005432823437	28928	Economy	6200.00
0005435252788	28928	Economy	6200.00
0005434458806	28928	Economy	6200.00
0005434276016	8787	Business	145300.00
0005434276005	8787	Economy	48400.00
0005434276012	8787	Economy	48400.00
0005435990658	8787	Economy	48400.00
0005434276013	8787	Economy	48400.00
0005434276011	8787	Economy	48400.00
0005435990663	8787	Economy	48400.00
0005435990662	8787	Economy	48400.00
0005435990661	8787	Economy	48400.00
0005435990659	8787	Economy	48400.00
0005435990660	8787	Economy	48400.00
0005434276015	8787	Economy	48400.00
0005435990602	15754	Business	145300.00
0005435990579	15754	Business	145300.00
0005434276056	15754	Business	145300.00
0005435990593	15754	Business	145300.00
0005434276057	15754	Economy	53300.00
0005435990603	15754	Economy	53300.00
0005434276058	15754	Economy	48400.00
0005435990592	15754	Economy	48400.00
0005434276059	15754	Economy	48400.00
0005434276054	15754	Economy	48400.00
0005434276055	15754	Economy	48400.00
0005435990615	15754	Economy	48400.00
0005435990580	15754	Economy	48400.00
0005435990591	15754	Economy	48400.00
0005435990619	15754	Economy	48400.00
0005433476889	20616	Economy	15900.00
0005433476875	20616	Economy	14500.00
0005432427154	20616	Economy	14500.00
0005433476874	20616	Economy	14500.00
0005433476888	20616	Economy	14500.00
0005433476887	20616	Economy	14500.00
0005432427153	20616	Economy	14500.00
0005432427152	20616	Economy	14500.00
0005432427151	20616	Economy	14500.00
0005433476890	20616	Economy	14500.00
0005432427136	30845	Economy	15900.00
0005433476902	30845	Economy	14500.00
0005433476901	30845	Economy	14500.00
0005433476903	30845	Economy	14500.00
0005433476904	30845	Economy	14500.00
0005433476906	30845	Economy	14500.00
0005432427133	30845	Economy	14500.00
0005432427137	30845	Economy	14500.00
0005433476905	30845	Economy	14500.00
0005432360597	6410	Business	36600.00
0005432360629	6410	Business	36600.00
0005432360626	6410	Business	36600.00
0005435177005	6410	Business	36600.00
0005435177018	6410	Business	36600.00
0005432360592	6410	Business	36600.00
0005432360599	6410	Business	36600.00
0005435176993	6410	Business	36600.00
0005432360598	6410	Business	36600.00
0005432360630	6410	Business	36600.00
0005432360608	6410	Economy	12200.00
0005432062256	6410	Economy	12200.00
0005435177147	6410	Economy	12200.00
0005432336093	6410	Economy	12200.00
0005435177087	6410	Economy	12200.00
0005435177101	6410	Economy	12200.00
0005435176990	6410	Economy	12200.00
0005432360589	6410	Economy	12200.00
0005432360625	6410	Economy	12200.00
0005435177109	6410	Economy	12200.00
0005435177014	6410	Economy	12200.00
0005432360591	6410	Economy	12200.00
0005432360637	6410	Economy	12200.00
0005432062255	6410	Economy	12200.00
0005435177024	6410	Economy	12200.00
0005434149630	6410	Economy	12200.00
0005432360610	6410	Economy	12200.00
0005435177006	6410	Economy	12200.00
0005435177100	6410	Economy	12200.00
0005432360590	6410	Economy	12200.00
0005432062259	6410	Economy	12200.00
0005435176995	6410	Economy	12200.00
0005432336095	6410	Economy	12200.00
0005432360632	6410	Economy	12200.00
0005432360603	6410	Economy	12200.00
0005432360601	6410	Economy	12200.00
0005432360622	6410	Economy	12200.00
0005435177030	6410	Economy	12200.00
0005432363432	6410	Economy	12200.00
0005432360605	6410	Economy	12200.00
0005432360600	6410	Economy	12200.00
0005435176996	6410	Economy	12200.00
0005432336096	6410	Economy	12200.00
0005432360614	6410	Economy	12200.00
0005432360621	6410	Economy	12200.00
0005435177065	6410	Economy	13400.00
0005432336098	6410	Economy	13400.00
0005432336099	6410	Economy	13400.00
0005435177017	6410	Economy	13400.00
0005432336094	6410	Economy	13400.00
0005435177015	6410	Economy	12200.00
0005432336100	6410	Economy	12200.00
0005435723035	6410	Economy	12200.00
0005435177059	6410	Economy	12200.00
0005435176994	6410	Economy	12200.00
0005432360595	6410	Economy	12200.00
0005435176821	6410	Economy	12200.00
0005432360613	6410	Economy	12200.00
0005432360596	6410	Economy	12200.00
0005435176929	6410	Economy	12200.00
0005435177056	6410	Economy	12200.00
0005432360618	6410	Economy	12200.00
0005432360606	6410	Economy	12200.00
0005432360628	6410	Economy	12200.00
0005435490212	6410	Economy	12200.00
0005432360615	6410	Economy	12200.00
0005434149662	6410	Economy	12200.00
0005435177031	6410	Economy	12200.00
0005435176823	6410	Economy	12200.00
0005432360617	6410	Economy	12200.00
0005432360634	6410	Economy	12200.00
0005435176935	6410	Economy	12200.00
0005432360633	6410	Economy	12200.00
0005432363433	6410	Economy	12200.00
0005432360604	6410	Economy	12200.00
0005432062257	6410	Economy	12200.00
0005435176822	6410	Economy	12200.00
0005432360593	6410	Economy	12200.00
0005432062258	6410	Economy	12200.00
0005435177002	6410	Economy	12200.00
0005435490203	6410	Economy	12200.00
0005432360623	6410	Economy	12200.00
0005434149675	6410	Economy	12200.00
0005432360636	6410	Economy	12200.00
0005432360627	6410	Economy	12200.00
0005434149684	6410	Economy	12200.00
0005432360631	6410	Economy	12200.00
0005435723036	6410	Economy	12200.00
0005432360619	6410	Economy	12200.00
0005432360607	6410	Economy	12200.00
0005432360638	6410	Economy	12200.00
0005432360594	6410	Economy	12200.00
0005432360624	6410	Economy	12200.00
0005435490225	6410	Economy	12200.00
0005435177013	6410	Economy	12200.00
0005435490226	6410	Economy	12200.00
0005432336097	6410	Economy	12200.00
0005432360612	6410	Economy	12200.00
0005432360611	6410	Economy	12200.00
0005432360609	6410	Economy	12200.00
0005435176989	6410	Economy	12200.00
0005435177025	6410	Economy	12200.00
0005432360635	6410	Economy	12200.00
0005435176992	6410	Economy	12200.00
0005432336101	6410	Economy	12200.00
0005432360602	6410	Economy	12200.00
0005432360616	6410	Economy	12200.00
0005432360620	6410	Economy	12200.00
0005432336092	6410	Economy	12200.00
0005432360229	21007	Business	36600.00
0005432360290	21007	Business	36600.00
0005435177225	21007	Business	36600.00
0005435177210	21007	Business	36600.00
0005432360213	21007	Business	36600.00
0005432335976	21007	Business	36600.00
0005435177228	21007	Business	36600.00
0005432360287	21007	Business	36600.00
0005435177224	21007	Business	36600.00
0005432363411	21007	Business	36600.00
0005432363418	21007	Business	36600.00
0005435177219	21007	Business	36600.00
0005435177221	21007	Economy	12200.00
0005432363420	21007	Economy	12200.00
0005432360204	21007	Economy	12200.00
0005432360288	21007	Economy	12200.00
0005432360496	21007	Economy	12200.00
0005434149786	21007	Economy	12200.00
0005432360272	21007	Economy	12200.00
0005432360497	21007	Economy	12200.00
0005432052761	21007	Economy	12200.00
0005432336031	21007	Economy	12200.00
0005434149795	21007	Economy	12200.00
0005435177220	21007	Economy	12200.00
0005435177217	21007	Economy	12200.00
0005435490252	21007	Economy	12200.00
0005432360244	21007	Economy	12200.00
0005432360053	21007	Economy	12200.00
0005432360291	21007	Economy	12200.00
0005432360422	21007	Economy	12200.00
0005432336003	21007	Economy	12200.00
0005432360072	21007	Economy	12200.00
0005435177218	21007	Economy	12200.00
0005432336030	21007	Economy	12200.00
0005434149790	21007	Economy	12200.00
0005435177215	21007	Economy	12200.00
0005432363401	21007	Economy	12200.00
0005432363408	21007	Economy	12200.00
0005432360289	21007	Economy	12200.00
0005432360118	21007	Economy	12200.00
0005432336036	21007	Economy	12200.00
0005435177205	21007	Economy	12200.00
0005432360277	21007	Economy	12200.00
0005435177213	21007	Economy	12200.00
0005435177208	21007	Economy	12200.00
0005435177207	21007	Economy	13400.00
0005432360047	21007	Economy	13400.00
0005432360369	21007	Economy	13400.00
0005432360210	21007	Economy	13400.00
0005432363406	21007	Economy	13400.00
0005435177212	21007	Economy	13400.00
0005435490250	21007	Economy	12200.00
0005432360278	21007	Economy	12200.00
0005434149787	21007	Economy	12200.00
0005432360157	21007	Economy	12200.00
0005432360070	21007	Economy	12200.00
0005432359921	21007	Economy	12200.00
0005432360254	21007	Economy	12200.00
0005435177226	21007	Economy	12200.00
0005435177227	21007	Economy	12200.00
0005435177206	21007	Economy	12200.00
0005434149789	21007	Economy	12200.00
0005432052760	21007	Economy	12200.00
0005435177211	21007	Economy	12200.00
0005432360260	21007	Economy	12200.00
0005432360121	21007	Economy	12200.00
0005432363419	21007	Economy	12200.00
0005432360211	21007	Economy	12200.00
0005432360212	21007	Economy	12200.00
0005432360155	21007	Economy	12200.00
0005432360243	21007	Economy	12200.00
0005435177230	21007	Economy	12200.00
0005435177222	21007	Economy	12200.00
0005432360127	21007	Economy	12200.00
0005432335998	21007	Economy	12200.00
0005432360153	21007	Economy	12200.00
0005435490249	21007	Economy	12200.00
0005432363407	21007	Economy	12200.00
0005432360305	21007	Economy	12200.00
0005432360245	21007	Economy	12200.00
0005435177209	21007	Economy	12200.00
0005434149792	21007	Economy	12200.00
0005432335931	21007	Economy	12200.00
0005432360194	21007	Economy	12200.00
0005432360423	21007	Economy	12200.00
0005435177232	21007	Economy	12200.00
0005432360156	21007	Economy	12200.00
0005434149785	21007	Economy	12200.00
0005434149793	21007	Economy	12200.00
0005432363410	21007	Economy	12200.00
0005432363421	21007	Economy	12200.00
0005432052762	21007	Economy	12200.00
0005432360002	21007	Economy	12200.00
0005432360232	21007	Economy	12200.00
0005435177214	21007	Economy	12200.00
0005435177229	21007	Economy	12200.00
0005435490251	21007	Economy	12200.00
0005434149791	21007	Economy	12200.00
0005432360235	21007	Economy	12200.00
0005435177216	21007	Economy	12200.00
0005432336004	21007	Economy	12200.00
0005434149788	21007	Economy	12200.00
0005432336043	21007	Economy	12200.00
0005432360087	21007	Economy	12200.00
0005432360193	21007	Economy	12200.00
0005432360071	21007	Economy	12200.00
0005432336044	21007	Economy	12200.00
0005432363422	21007	Economy	12200.00
0005432360021	21007	Economy	12200.00
0005435177231	21007	Economy	12200.00
0005432360003	21007	Economy	12200.00
0005435177223	21007	Economy	12200.00
0005434149794	21007	Economy	12200.00
0005432336005	21007	Economy	12200.00
0005434149796	21007	Economy	12200.00
0005434458743	17726	Economy	3400.00
0005434458765	17726	Economy	3400.00
0005434186214	17726	Economy	3400.00
0005434458738	17726	Economy	3400.00
0005434458740	17726	Economy	3100.00
0005434458723	17726	Economy	3100.00
0005434458795	17726	Economy	3100.00
0005434463916	17726	Economy	3100.00
0005434458728	17726	Economy	3100.00
0005434448312	17726	Economy	3100.00
0005434463915	17726	Economy	3100.00
0005434458816	17726	Economy	3100.00
0005434458724	17726	Economy	3100.00
0005434458850	17726	Economy	3100.00
0005434458721	17726	Economy	3100.00
0005434458691	17726	Economy	3100.00
0005434186215	17726	Economy	3100.00
0005434463921	17726	Economy	3100.00
0005434463917	17726	Economy	3100.00
0005434458679	17726	Economy	3100.00
0005434458707	17726	Economy	3100.00
0005434463929	17726	Economy	3100.00
0005434458692	17726	Economy	3100.00
0005434458722	17726	Economy	3100.00
0005434463926	17726	Economy	3100.00
0005434458730	17726	Economy	3100.00
0005434458784	17726	Economy	3100.00
0005434458729	17726	Economy	3100.00
0005434458830	17726	Economy	3100.00
0005434448296	17726	Economy	3100.00
0005434458770	17726	Economy	3100.00
0005434458739	17726	Economy	3100.00
0005434458812	17726	Economy	3100.00
0005434462798	29109	Economy	3400.00
0005434458912	29109	Economy	3400.00
0005434463937	29109	Economy	3400.00
0005434448331	29109	Economy	3400.00
0005434458910	29109	Economy	3100.00
0005434186181	29109	Economy	3100.00
0005434458902	29109	Economy	3100.00
0005434186194	29109	Economy	3100.00
0005434458916	29109	Economy	3100.00
0005434462799	29109	Economy	3100.00
0005434462800	29109	Economy	3100.00
0005434458919	29109	Economy	3100.00
0005434448330	29109	Economy	3100.00
0005434458909	29109	Economy	3100.00
0005434458906	29109	Economy	3100.00
0005434458904	29109	Economy	3100.00
0005434463938	29109	Economy	3100.00
0005434186195	29109	Economy	3100.00
0005434458922	29109	Economy	3100.00
0005434458923	29109	Economy	3100.00
0005434458921	29109	Economy	3100.00
0005434458908	29109	Economy	3100.00
0005434448329	29109	Economy	3100.00
0005434458911	29109	Economy	3100.00
0005434458914	29109	Economy	3100.00
0005434458915	29109	Economy	3100.00
0005434463939	29109	Economy	3100.00
0005434462801	29109	Economy	3100.00
0005434458918	29109	Economy	3100.00
0005434458903	29109	Economy	3100.00
0005434458917	29109	Economy	3100.00
0005434458913	29109	Economy	3100.00
0005434458920	29109	Economy	3100.00
0005434458907	29109	Economy	3100.00
0005434458905	29109	Economy	3100.00
0005432604507	21453	Economy	7300.00
0005432604531	21453	Economy	7300.00
0005432604511	21453	Economy	7300.00
0005432604527	21453	Economy	6600.00
0005432604523	21453	Economy	6600.00
0005432604521	21453	Economy	6600.00
0005435218110	21453	Economy	6600.00
0005432604533	21453	Economy	6600.00
0005432604508	21453	Economy	6600.00
0005435218111	21453	Economy	6600.00
0005432604515	21453	Economy	6600.00
0005432604530	21453	Economy	6600.00
0005432604529	21453	Economy	6600.00
0005432604519	21453	Economy	6600.00
0005432604532	21453	Economy	6600.00
0005432604494	21453	Economy	6600.00
0005432604518	21453	Economy	6600.00
0005432604528	21453	Economy	6600.00
0005432604495	21453	Economy	6600.00
0005432604509	21453	Economy	6600.00
0005432604517	21453	Economy	6600.00
0005432604513	21453	Economy	6600.00
0005432604525	21453	Economy	6600.00
0005432604497	21453	Economy	6600.00
0005432604504	21453	Economy	6600.00
0005432604522	21453	Economy	6600.00
0005432604500	21453	Economy	6600.00
0005432604502	21453	Economy	6600.00
0005432604526	21453	Economy	6600.00
0005432604499	21453	Economy	6600.00
0005432604514	21453	Economy	6600.00
0005432604506	21453	Economy	6600.00
0005432604516	21453	Economy	6600.00
0005432604498	21453	Economy	6600.00
0005432604512	21453	Economy	6600.00
0005432604520	21453	Economy	6600.00
0005432604501	21453	Economy	6600.00
0005432604496	21453	Economy	6600.00
0005432604503	21453	Economy	6600.00
0005432604510	21453	Economy	6600.00
0005432604505	21453	Economy	6600.00
0005432604524	21453	Economy	6600.00
0005432604327	31655	Economy	7300.00
0005432604217	31655	Economy	7300.00
0005432604215	31655	Economy	6600.00
0005432604125	31655	Economy	6600.00
0005432604123	31655	Economy	6600.00
0005432604116	31655	Economy	6600.00
0005432604216	31655	Economy	6600.00
0005432604176	31655	Economy	6600.00
0005432604174	31655	Economy	6600.00
0005432604202	31655	Economy	6600.00
0005432604075	31655	Economy	6600.00
0005432604164	31655	Economy	6600.00
0005432604250	31655	Economy	6600.00
0005432604251	31655	Economy	6600.00
0005432604124	31655	Economy	6600.00
0005432604328	31655	Economy	6600.00
0005432604115	31655	Economy	6600.00
0005432603991	31655	Economy	6600.00
0005432604089	31655	Economy	6600.00
0005432603940	31655	Economy	6600.00
0005432604312	31655	Economy	6600.00
0005432604126	31655	Economy	6600.00
0005435221520	31655	Economy	6600.00
0005432604173	31655	Economy	6600.00
0005432604254	31655	Economy	6600.00
0005432604203	31655	Economy	6600.00
0005432604321	31655	Economy	6600.00
0005432604255	31655	Economy	6600.00
0005435221521	31655	Economy	6600.00
0005432604189	31655	Economy	6600.00
0005432604163	31655	Economy	6600.00
0005435221060	31655	Economy	6600.00
0005435221061	31655	Economy	6600.00
0005432604188	31655	Economy	6600.00
0005432604165	31655	Economy	6600.00
0005432604088	31655	Economy	6600.00
0005432604187	31655	Economy	6600.00
0005432604150	31655	Economy	6600.00
0005433293200	12319	Economy	19500.00
0005433293220	12319	Economy	17800.00
0005433293194	12319	Economy	17800.00
0005435154599	12319	Economy	17800.00
0005433293195	12319	Economy	17800.00
0005433293226	12319	Economy	17800.00
0005433293221	12319	Economy	17800.00
0005433293208	12319	Economy	17800.00
0005433293205	12319	Economy	17800.00
0005433293206	12319	Economy	17800.00
0005433293199	12319	Economy	17800.00
0005433293211	12319	Economy	17800.00
0005433293227	12319	Economy	17800.00
0005434606812	18859	Economy	6600.00
0005434606813	18859	Economy	6600.00
0005434606805	18859	Economy	6600.00
0005434606818	18859	Economy	6600.00
0005434606804	18859	Economy	6600.00
0005434606789	18859	Economy	6600.00
0005434603019	18859	Economy	6600.00
0005434606803	18859	Economy	6600.00
0005434606817	18859	Economy	6600.00
0005434606839	22300	Economy	6600.00
0005434604911	22300	Economy	6600.00
0005434606840	22300	Economy	6600.00
0005434604909	22300	Economy	6600.00
0005434604913	22300	Economy	6600.00
0005434604912	22300	Economy	6600.00
0005434604910	22300	Economy	6600.00
0005434606844	22300	Economy	6600.00
0005434606843	22300	Economy	6600.00
0005434606841	22300	Economy	6600.00
0005434606842	22300	Economy	6600.00
0005434604914	22300	Economy	6600.00
0005432890992	388	Business	44500.00
0005432747750	388	Business	44500.00
0005435154601	388	Business	44500.00
0005432890923	388	Business	44500.00
0005432747741	388	Business	44500.00
0005433293233	388	Business	44500.00
0005432891017	388	Business	44500.00
0005432747766	388	Business	44500.00
0005432747764	388	Business	44500.00
0005432747754	388	Business	44500.00
0005433293216	388	Economy	14800.00
0005432747758	388	Economy	14800.00
0005432220025	388	Economy	14800.00
0005432747744	388	Economy	14800.00
0005432749794	388	Economy	14800.00
0005432747735	388	Economy	14800.00
0005432747745	388	Economy	14800.00
0005433293230	388	Economy	16300.00
0005432747765	388	Economy	16300.00
0005432747753	388	Economy	16300.00
0005432747737	388	Economy	16300.00
0005432890958	388	Economy	14800.00
0005432747736	388	Economy	14800.00
0005432747761	388	Economy	14800.00
0005435154600	388	Economy	14800.00
0005432747748	388	Economy	14800.00
0005432747752	388	Economy	14800.00
0005432747755	388	Economy	14800.00
0005432747738	388	Economy	14800.00
0005432747746	388	Economy	14800.00
0005432220023	388	Economy	14800.00
0005432747769	388	Economy	14800.00
0005432747760	388	Economy	14800.00
0005432747756	388	Economy	14800.00
0005432747734	388	Economy	14800.00
0005432747740	388	Economy	14800.00
0005433293235	388	Economy	14800.00
0005432747770	388	Economy	14800.00
0005432747771	388	Economy	14800.00
0005433293241	388	Economy	14800.00
0005432220024	388	Economy	14800.00
0005432747759	388	Economy	14800.00
0005433293234	388	Economy	14800.00
0005432753316	388	Economy	14800.00
0005432747747	388	Economy	14800.00
0005433293240	388	Economy	14800.00
0005432749793	388	Economy	14800.00
0005432751539	388	Economy	14800.00
0005432749795	388	Economy	14800.00
0005432890890	388	Economy	14800.00
0005433293239	388	Economy	14800.00
0005432751541	388	Economy	14800.00
0005432747762	388	Economy	14800.00
0005432890891	388	Economy	14800.00
0005432220022	388	Economy	14800.00
0005432890993	388	Economy	14800.00
0005432747767	388	Economy	14800.00
0005433293215	388	Economy	14800.00
0005433293214	388	Economy	14800.00
0005432753315	388	Economy	14800.00
0005432747732	388	Economy	14800.00
0005433293219	388	Economy	14800.00
0005433293232	388	Economy	14800.00
0005432747751	388	Economy	14800.00
0005432747739	388	Economy	14800.00
0005432747742	388	Economy	14800.00
0005432890952	388	Economy	14800.00
0005432747768	388	Economy	14800.00
0005432747757	388	Economy	14800.00
0005432890989	388	Economy	14800.00
0005432747733	388	Economy	14800.00
0005432747743	388	Economy	14800.00
0005432747749	388	Economy	14800.00
0005432747763	388	Economy	14800.00
0005432890915	388	Economy	14800.00
0005432751540	388	Economy	14800.00
0005432891121	12033	Business	44500.00
0005432747415	12033	Business	44500.00
0005432747519	12033	Business	44500.00
0005432747388	12033	Business	44500.00
0005432747381	12033	Business	44500.00
0005432747435	12033	Business	44500.00
0005432747414	12033	Business	44500.00
0005432747492	12033	Business	44500.00
0005432747401	12033	Business	44500.00
0005432747434	12033	Business	44500.00
0005432747488	12033	Business	44500.00
0005433293274	12033	Economy	14800.00
0005433293280	12033	Economy	14800.00
0005432747400	12033	Economy	14800.00
0005433293278	12033	Economy	14800.00
0005432891126	12033	Economy	14800.00
0005433293271	12033	Economy	14800.00
0005432747524	12033	Economy	14800.00
0005433293275	12033	Economy	14800.00
0005432747440	12033	Economy	14800.00
0005432891125	12033	Economy	14800.00
0005432214815	12033	Economy	16300.00
0005433293265	12033	Economy	16300.00
0005432753279	12033	Economy	16300.00
0005433293284	12033	Economy	16300.00
0005432214813	12033	Economy	16300.00
0005432747504	12033	Economy	14800.00
0005433293272	12033	Economy	14800.00
0005432747507	12033	Economy	14800.00
0005433875390	12033	Economy	14800.00
0005432891127	12033	Economy	14800.00
0005432891113	12033	Economy	14800.00
0005433293279	12033	Economy	14800.00
0005432747389	12033	Economy	14800.00
0005432747642	12033	Economy	14800.00
0005432747489	12033	Economy	14800.00
0005433293285	12033	Economy	14800.00
0005432891115	12033	Economy	14800.00
0005432214816	12033	Economy	14800.00
0005432891116	12033	Economy	14800.00
0005432747460	12033	Economy	14800.00
0005433293283	12033	Economy	14800.00
0005432747442	12033	Economy	14800.00
0005433875389	12033	Economy	14800.00
0005432747511	12033	Economy	14800.00
0005432753298	12033	Economy	14800.00
0005433293269	12033	Economy	14800.00
0005432891117	12033	Economy	14800.00
0005432747538	12033	Economy	14800.00
0005432891118	12033	Economy	14800.00
0005432891124	12033	Economy	14800.00
0005432747274	12033	Economy	14800.00
0005432747467	12033	Economy	14800.00
0005432747396	12033	Economy	14800.00
0005432891128	12033	Economy	14800.00
0005432747531	12033	Economy	14800.00
0005433293277	12033	Economy	14800.00
0005432756834	12033	Economy	14800.00
0005433293270	12033	Economy	14800.00
0005432747512	12033	Economy	14800.00
0005432747266	12033	Economy	14800.00
0005432891120	12033	Economy	14800.00
0005433293267	12033	Economy	14800.00
0005433293273	12033	Economy	14800.00
0005432891114	12033	Economy	14800.00
0005432747441	12033	Economy	14800.00
0005432747493	12033	Economy	14800.00
0005432747539	12033	Economy	14800.00
0005433293276	12033	Economy	14800.00
0005433293266	12033	Economy	14800.00
0005432747382	12033	Economy	14800.00
0005432891129	12033	Economy	14800.00
0005432747368	12033	Economy	14800.00
0005432747562	12033	Economy	14800.00
0005432891111	12033	Economy	14800.00
0005433293268	12033	Economy	14800.00
0005433293281	12033	Economy	14800.00
0005432747378	12033	Economy	14800.00
0005432747523	12033	Economy	14800.00
0005432891130	12033	Economy	14800.00
0005432891123	12033	Economy	14800.00
0005432747481	12033	Economy	14800.00
0005433293282	12033	Economy	14800.00
0005432891119	12033	Economy	14800.00
0005432747537	12033	Economy	14800.00
0005432747379	12033	Economy	14800.00
0005432214814	12033	Economy	14800.00
0005432891112	12033	Economy	14800.00
0005432891122	12033	Economy	14800.00
0005432747540	12033	Economy	14800.00
0005432747513	12033	Economy	14800.00
0005432927966	18951	Economy	28200.00
0005432927943	18951	Economy	28200.00
0005433525090	18951	Economy	28200.00
0005433531310	18951	Economy	28200.00
0005433533324	18951	Economy	25700.00
0005432927970	18951	Economy	25700.00
0005433525081	18951	Economy	25700.00
0005432927942	18951	Economy	25700.00
0005433525089	18951	Economy	25700.00
0005433525082	18951	Economy	25700.00
0005433525080	18951	Economy	25700.00
0005433531307	18951	Economy	25700.00
0005433525088	18951	Economy	25700.00
0005432927941	18951	Economy	25700.00
0005433525092	18951	Economy	25700.00
0005433533323	18951	Economy	25700.00
0005433531309	18951	Economy	25700.00
0005433531308	18951	Economy	25700.00
0005433525087	18951	Economy	25700.00
0005433533325	18951	Economy	25700.00
0005433525085	18951	Economy	25700.00
0005433525083	18951	Economy	25700.00
0005433525091	18951	Economy	25700.00
0005432927971	18951	Economy	25700.00
0005432927967	18951	Economy	25700.00
0005433525086	18951	Economy	25700.00
0005433525084	18951	Economy	25700.00
0005433524974	32488	Economy	28200.00
0005433527235	32488	Economy	28200.00
0005432928017	32488	Economy	25700.00
0005433531273	32488	Economy	25700.00
0005432928014	32488	Economy	25700.00
0005433531289	32488	Economy	25700.00
0005433531283	32488	Economy	25700.00
0005433531281	32488	Economy	25700.00
0005432928013	32488	Economy	25700.00
0005433524979	32488	Economy	25700.00
0005433524995	32488	Economy	25700.00
0005433524992	32488	Economy	25700.00
0005432928015	32488	Economy	25700.00
0005433525010	32488	Economy	25700.00
0005433527236	32488	Economy	25700.00
0005433525009	32488	Economy	25700.00
0005432928011	32488	Economy	25700.00
0005433527243	32488	Economy	25700.00
0005433531303	32488	Economy	25700.00
0005433525024	32488	Economy	25700.00
0005433527244	32488	Economy	25700.00
0005433524993	32488	Economy	25700.00
0005433531302	32488	Economy	25700.00
0005433524975	32488	Economy	25700.00
0005433525015	32488	Economy	25700.00
0005433525014	32488	Economy	25700.00
0005432928012	32488	Economy	25700.00
0005433524991	32488	Economy	25700.00
0005432928016	32488	Economy	25700.00
0005435372770	5275	Business	84000.00
0005434824291	5275	Business	84000.00
0005434558324	5275	Business	84000.00
0005435373046	5275	Business	84000.00
0005435661913	5275	Business	84000.00
0005434824205	5275	Business	84000.00
0005435372921	5275	Business	84000.00
0005434824271	5275	Business	84000.00
0005434824172	5275	Business	84000.00
0005435150097	5275	Business	84000.00
0005434824217	5275	Business	84000.00
0005434824297	5275	Business	84000.00
0005435661914	5275	Business	84000.00
0005434824241	5275	Business	84000.00
0005432823448	5275	Business	84000.00
0005434824242	5275	Business	84000.00
0005434824246	5275	Business	84000.00
0005435372907	5275	Business	84000.00
0005432121403	5275	Business	84000.00
0005434824274	5275	Business	84000.00
0005435372797	5275	Business	84000.00
0005432823434	5275	Business	84000.00
0005434824174	5275	Comfort	47600.00
0005434824224	5275	Business	84000.00
0005434824286	5275	Comfort	47600.00
0005434824294	5275	Comfort	47600.00
0005435373013	5275	Comfort	47600.00
0005435299733	5275	Comfort	47600.00
0005435372906	5275	Comfort	47600.00
0005434824251	5275	Comfort	47600.00
0005435386554	5275	Comfort	47600.00
0005434824218	5275	Comfort	47600.00
0005434824267	5275	Comfort	47600.00
0005435373037	5275	Comfort	47600.00
0005432396266	5275	Comfort	47600.00
0005435372888	5275	Comfort	47600.00
0005432121406	5275	Comfort	47600.00
0005435372880	5275	Comfort	47600.00
0005434558311	5275	Comfort	47600.00
0005434824264	5275	Comfort	47600.00
0005435373256	5275	Comfort	47600.00
0005432823441	5275	Comfort	47600.00
0005435299765	5275	Comfort	47600.00
0005434824275	5275	Comfort	47600.00
0005434824255	5275	Comfort	47600.00
0005435372664	5275	Comfort	47600.00
0005434824170	5275	Comfort	47600.00
0005434824284	5275	Comfort	47600.00
0005434824212	5275	Comfort	47600.00
0005435304145	5275	Comfort	47600.00
0005434824263	5275	Comfort	47600.00
0005434824193	5275	Comfort	47600.00
0005435386546	5275	Comfort	47600.00
0005434558318	5275	Comfort	47600.00
0005434824289	5275	Comfort	47600.00
0005434824206	5275	Comfort	47600.00
0005435150094	5275	Comfort	47600.00
0005435373048	5275	Comfort	47600.00
0005435304141	5275	Comfort	47600.00
0005434824237	5275	Economy	28000.00
0005435179689	5275	Economy	28000.00
0005434824204	5275	Economy	28000.00
0005435299751	5275	Economy	28000.00
0005435373203	5275	Economy	28000.00
0005434824287	5275	Economy	28000.00
0005434824254	5275	Economy	28000.00
0005434824169	5275	Economy	28000.00
0005434824269	5275	Economy	28000.00
0005434824220	5275	Economy	28000.00
0005434824285	5275	Economy	28000.00
0005432396264	5275	Economy	28000.00
0005432121411	5275	Economy	28000.00
0005434824177	5275	Economy	28000.00
0005434558313	5275	Economy	28000.00
0005435386536	5275	Economy	28000.00
0005434824229	5275	Economy	28000.00
0005435735121	5275	Economy	28000.00
0005434824225	5275	Economy	28000.00
0005435372612	5275	Economy	28000.00
0005432823439	5275	Economy	28000.00
0005434824233	5275	Economy	28000.00
0005434824281	5275	Economy	28000.00
0005435373009	5275	Economy	28000.00
0005434824197	5275	Economy	28000.00
0005434824276	5275	Economy	28000.00
0005434831170	5275	Economy	28000.00
0005435386563	5275	Economy	28000.00
0005434824261	5275	Economy	28000.00
0005435372988	5275	Economy	28000.00
0005434824249	5275	Economy	28000.00
0005434831172	5275	Economy	28000.00
0005434824200	5275	Economy	28000.00
0005435373187	5275	Economy	28000.00
0005434824219	5275	Economy	28000.00
0005435150105	5275	Economy	28000.00
0005434824182	5275	Economy	28000.00
0005435299776	5275	Economy	28000.00
0005434824260	5275	Economy	28000.00
0005435299758	5275	Economy	28000.00
0005434824234	5275	Economy	28000.00
0005434824226	5275	Economy	28000.00
0005434558316	5275	Economy	30800.00
0005434824185	5275	Economy	28000.00
0005435386562	5275	Economy	28000.00
0005434824232	5275	Economy	30800.00
0005432121402	5275	Economy	30800.00
0005434824290	5275	Economy	28000.00
0005434831171	5275	Economy	28000.00
0005435372856	5275	Economy	28000.00
0005434824256	5275	Economy	28000.00
0005435372834	5275	Economy	28000.00
0005435150095	5275	Economy	28000.00
0005434824288	5275	Economy	28000.00
0005434824201	5275	Economy	28000.00
0005435373031	5275	Economy	28000.00
0005434558322	5275	Economy	28000.00
0005434824203	5275	Economy	28000.00
0005434824199	5275	Economy	28000.00
0005435299759	5275	Economy	28000.00
0005432396265	5275	Economy	28000.00
0005435373001	5275	Economy	28000.00
0005432121400	5275	Economy	28000.00
0005435299782	5275	Economy	28000.00
0005435373072	5275	Economy	28000.00
0005434824168	5275	Economy	28000.00
0005432121412	5275	Economy	28000.00
0005432394126	5275	Economy	28000.00
0005432121404	5275	Economy	28000.00
0005434824179	5275	Economy	28000.00
0005434824253	5275	Economy	28000.00
0005434824296	5275	Economy	28000.00
0005434824298	5275	Economy	28000.00
0005435373162	5275	Economy	28000.00
0005434824282	5275	Economy	28000.00
0005435150102	5275	Economy	28000.00
0005435372966	5275	Economy	28000.00
0005434824266	5275	Economy	28000.00
0005434824208	5275	Economy	28000.00
0005435373249	5275	Economy	28000.00
0005435299764	5275	Economy	28000.00
0005435372997	5275	Economy	28000.00
0005435150093	5275	Economy	28000.00
0005432121413	5275	Economy	28000.00
0005434824240	5275	Economy	28000.00
0005435299753	5275	Economy	28000.00
0005432394125	5275	Economy	28000.00
0005434824176	5275	Economy	28000.00
0005434824262	5275	Economy	28000.00
0005432121407	5275	Economy	28000.00
0005434824184	5275	Economy	28000.00
0005435386547	5275	Economy	28000.00
0005434824293	5275	Economy	28000.00
0005434824268	5275	Economy	28000.00
0005434824223	5275	Economy	28000.00
0005435150101	5275	Economy	28000.00
0005434824171	5275	Economy	28000.00
0005434824247	5275	Economy	28000.00
0005434824178	5275	Economy	28000.00
0005435299775	5275	Economy	28000.00
0005434824194	5275	Economy	28000.00
0005434824214	5275	Economy	28000.00
0005434824195	5275	Economy	28000.00
0005435299768	5275	Economy	28000.00
0005435373323	5275	Economy	28000.00
0005434558320	5275	Economy	28000.00
0005435372987	5275	Economy	28000.00
0005435372832	5275	Economy	28000.00
0005434831169	5275	Economy	28000.00
0005435150099	5275	Economy	28000.00
0005434824259	5275	Economy	28000.00
0005434824239	5275	Economy	28000.00
0005434824181	5275	Economy	28000.00
0005435373000	5275	Economy	28000.00
0005434824279	5275	Economy	28000.00
0005434824252	5275	Economy	28000.00
0005434824243	5275	Economy	28000.00
0005434824273	5275	Economy	28000.00
0005432396263	5275	Economy	28000.00
0005435304140	5275	Economy	28000.00
0005434824227	5275	Economy	28000.00
0005434828710	5275	Economy	28000.00
0005434824283	5275	Economy	28000.00
0005435150096	5275	Economy	28000.00
0005434824236	5275	Economy	28000.00
0005434824235	5275	Economy	28000.00
0005434824192	5275	Economy	28000.00
0005434824258	5275	Economy	28000.00
0005434824209	5275	Economy	28000.00
0005434824198	5275	Economy	28000.00
0005434558323	5275	Economy	28000.00
0005434824238	5275	Economy	30800.00
0005435373022	5275	Economy	30800.00
0005435372513	5275	Economy	30800.00
0005434824280	5275	Economy	28000.00
0005434824248	5275	Economy	30800.00
0005434824265	5275	Economy	28000.00
0005434824250	5275	Economy	28000.00
0005434824270	5275	Economy	28000.00
0005434824245	5275	Economy	28000.00
0005435150104	5275	Economy	28000.00
0005434824216	5275	Economy	28000.00
0005435372924	5275	Economy	28000.00
0005434824196	5275	Economy	28000.00
0005432396262	5275	Economy	28000.00
0005434824244	5275	Economy	28000.00
0005434828709	5275	Economy	28000.00
0005435372932	5275	Economy	28000.00
0005434824230	5275	Economy	28000.00
0005434824222	5275	Economy	28000.00
0005435372920	5275	Economy	28000.00
0005432394124	5275	Economy	28000.00
0005435372917	5275	Economy	28000.00
0005434558314	5275	Economy	28000.00
0005435299769	5275	Economy	28000.00
0005435372963	5275	Economy	28000.00
0005432394127	5275	Economy	28000.00
0005435299763	5275	Economy	28000.00
0005434558312	5275	Economy	28000.00
0005434824190	5275	Economy	28000.00
0005434824295	5275	Economy	28000.00
0005434824211	5275	Economy	28000.00
0005434824188	5275	Economy	28000.00
0005435304139	5275	Economy	28000.00
0005434828708	5275	Economy	28000.00
0005434824257	5275	Economy	28000.00
0005434824272	5275	Economy	28000.00
0005435373047	5275	Economy	28000.00
0005434558317	5275	Economy	28000.00
0005434824180	5275	Economy	28000.00
0005432121409	5275	Economy	28000.00
0005434824231	5275	Economy	28000.00
0005434831168	5275	Economy	28000.00
0005434824173	5275	Economy	28000.00
0005434824221	5275	Economy	28000.00
0005432121405	5275	Economy	28000.00
0005434831173	5275	Economy	28000.00
0005435373036	5275	Economy	28000.00
0005435373012	5275	Economy	28000.00
0005432121410	5275	Economy	28000.00
0005434824186	5275	Economy	28000.00
0005434824191	5275	Economy	28000.00
0005434824278	5275	Economy	28000.00
0005435150098	5275	Economy	28000.00
0005434824210	5275	Economy	28000.00
0005435373257	5275	Economy	28000.00
0005435372944	5275	Economy	28000.00
0005434558315	5275	Economy	28000.00
0005435150103	5275	Economy	28000.00
0005435299760	5275	Economy	28000.00
0005435372979	5275	Economy	28000.00
0005435372908	5275	Economy	28000.00
0005434558309	5275	Economy	28000.00
0005435372978	5275	Economy	28000.00
0005435178990	5275	Economy	28000.00
0005434824189	5275	Economy	28000.00
0005432121401	5275	Economy	28000.00
0005435373147	5275	Economy	28000.00
0005432121408	5275	Economy	28000.00
0005434824213	5275	Economy	28000.00
0005435372972	5275	Economy	28000.00
0005434824207	5275	Economy	28000.00
0005435373152	5275	Economy	28000.00
0005435150100	5275	Economy	28000.00
0005434824292	5275	Economy	28000.00
0005434558319	5275	Economy	28000.00
0005434824183	5275	Economy	28000.00
0005434824277	5275	Economy	28000.00
0005434558310	5275	Economy	28000.00
0005434824215	5275	Economy	28000.00
0005435299752	5275	Economy	28000.00
0005434824202	5275	Economy	28000.00
0005435373324	5275	Economy	28000.00
0005435386549	5275	Economy	28000.00
0005434558321	5275	Economy	28000.00
0005435373064	5275	Economy	28000.00
0005434824228	5275	Economy	28000.00
0005434824187	5275	Economy	28000.00
0005434824175	5275	Economy	28000.00
0005434822904	9907	Business	84000.00
0005432400106	9907	Business	84000.00
0005434822535	9907	Business	84000.00
0005435373611	9907	Business	84000.00
0005435302221	9907	Business	84000.00
0005434823311	9907	Business	84000.00
0005434823454	9907	Business	84000.00
0005432400099	9907	Business	84000.00
0005435373627	9907	Business	84000.00
0005435373615	9907	Business	84000.00
0005435373602	9907	Business	84000.00
0005435302220	9907	Business	84000.00
0005434823070	9907	Business	84000.00
0005434823887	9907	Business	84000.00
0005434558228	9907	Business	84000.00
0005435373616	9907	Business	84000.00
0005434822622	9907	Business	84000.00
0005435735159	9907	Business	84000.00
0005435735161	9907	Business	84000.00
0005435373598	9907	Business	84000.00
0005434822876	9907	Comfort	47600.00
0005435149958	9907	Comfort	47600.00
0005435373583	9907	Comfort	47600.00
0005435149925	9907	Comfort	47600.00
0005434823336	9907	Comfort	47600.00
0005434823090	9907	Comfort	47600.00
0005434823337	9907	Comfort	47600.00
0005434823075	9907	Comfort	47600.00
0005434823546	9907	Comfort	47600.00
0005435149980	9907	Comfort	47600.00
0005434823155	9907	Comfort	47600.00
0005434823456	9907	Comfort	47600.00
0005434822878	9907	Comfort	47600.00
0005434822558	9907	Comfort	47600.00
0005434822529	9907	Comfort	47600.00
0005434823286	9907	Comfort	47600.00
0005434822965	9907	Comfort	47600.00
0005434823341	9907	Comfort	47600.00
0005434822745	9907	Comfort	47600.00
0005434822742	9907	Comfort	47600.00
0005435373582	9907	Comfort	47600.00
0005434823069	9907	Comfort	47600.00
0005434822776	9907	Comfort	47600.00
0005435735162	9907	Comfort	47600.00
0005435373577	9907	Comfort	47600.00
0005435373612	9907	Comfort	47600.00
0005435149968	9907	Comfort	47600.00
0005434823040	9907	Comfort	47600.00
0005434822926	9907	Comfort	47600.00
0005434822621	9907	Comfort	47600.00
0005435373574	9907	Comfort	47600.00
0005434822852	9907	Comfort	47600.00
0005432823461	9907	Comfort	47600.00
0005432203101	9907	Comfort	47600.00
0005435386600	9907	Comfort	47600.00
0005434823557	9907	Comfort	47600.00
0005435373580	9907	Comfort	47600.00
0005435373585	9907	Economy	28000.00
0005434823283	9907	Economy	28000.00
0005435302224	9907	Economy	28000.00
0005434823159	9907	Economy	28000.00
0005432203100	9907	Economy	28000.00
0005434823515	9907	Economy	28000.00
0005434823088	9907	Economy	28000.00
0005435373620	9907	Economy	28000.00
0005434823164	9907	Economy	28000.00
0005435373576	9907	Economy	28000.00
0005434822931	9907	Economy	28000.00
0005434823050	9907	Economy	28000.00
0005434823161	9907	Economy	28000.00
0005435373625	9907	Economy	28000.00
0005434822559	9907	Economy	28000.00
0005434823451	9907	Economy	28000.00
0005432396226	9907	Economy	28000.00
0005434823800	9907	Economy	28000.00
0005434823746	9907	Economy	28000.00
0005434822854	9907	Economy	28000.00
0005434823126	9907	Economy	28000.00
0005434823731	9907	Economy	28000.00
0005434823801	9907	Economy	28000.00
0005434823760	9907	Economy	28000.00
0005434822636	9907	Economy	28000.00
0005435373563	9907	Economy	28000.00
0005434822493	9907	Economy	28000.00
0005434823163	9907	Economy	28000.00
0005434822681	9907	Economy	28000.00
0005434822696	9907	Economy	28000.00
0005435386603	9907	Economy	28000.00
0005434823346	9907	Economy	28000.00
0005435373590	9907	Economy	28000.00
0005435373595	9907	Economy	28000.00
0005435661946	9907	Economy	28000.00
0005434823647	9907	Economy	28000.00
0005434823595	9907	Economy	28000.00
0005434822609	9907	Economy	28000.00
0005434823452	9907	Economy	28000.00
0005432396227	9907	Economy	28000.00
0005435373617	9907	Economy	28000.00
0005434822775	9907	Economy	28000.00
0005434823127	9907	Economy	28000.00
0005435373570	9907	Economy	28000.00
0005434822952	9907	Economy	28000.00
0005434823453	9907	Economy	28000.00
0005434823037	9907	Economy	28000.00
0005434822930	9907	Economy	28000.00
0005435373578	9907	Economy	28000.00
0005432203097	9907	Economy	28000.00
0005434823271	9907	Economy	28000.00
0005434823338	9907	Economy	28000.00
0005432396234	9907	Economy	28000.00
0005434822758	9907	Economy	28000.00
0005434822838	9907	Economy	28000.00
0005435373608	9907	Economy	30800.00
0005435373569	9907	Economy	30800.00
0005434823514	9907	Economy	28000.00
0005434822491	9907	Economy	28000.00
0005432203102	9907	Economy	28000.00
0005435373626	9907	Economy	30800.00
0005434822604	9907	Economy	30800.00
0005434828689	9907	Economy	28000.00
0005434823292	9907	Economy	28000.00
0005435373593	9907	Economy	28000.00
0005434823536	9907	Economy	28000.00
0005434823036	9907	Economy	28000.00
0005435373618	9907	Economy	28000.00
0005435299800	9907	Economy	28000.00
0005435386602	9907	Economy	28000.00
0005434828697	9907	Economy	28000.00
0005434823284	9907	Economy	28000.00
0005434823154	9907	Economy	28000.00
0005434823285	9907	Economy	28000.00
0005435373564	9907	Economy	28000.00
0005434822501	9907	Economy	28000.00
0005434822528	9907	Economy	28000.00
0005435149959	9907	Economy	28000.00
0005434823748	9907	Economy	28000.00
0005435149955	9907	Economy	28000.00
0005434823039	9907	Economy	28000.00
0005434823527	9907	Economy	28000.00
0005432400098	9907	Economy	28000.00
0005435149969	9907	Economy	28000.00
0005434664956	9907	Economy	28000.00
0005434822560	9907	Economy	28000.00
0005434823740	9907	Economy	28000.00
0005432203098	9907	Economy	28000.00
0005435373589	9907	Economy	28000.00
0005435373571	9907	Economy	28000.00
0005434822757	9907	Economy	28000.00
0005434823282	9907	Economy	28000.00
0005434822950	9907	Economy	28000.00
0005434831129	9907	Economy	28000.00
0005434823267	9907	Economy	28000.00
0005435179398	9907	Economy	28000.00
0005434822948	9907	Economy	28000.00
0005434558206	9907	Economy	28000.00
0005435149967	9907	Economy	28000.00
0005434823395	9907	Economy	28000.00
0005434823426	9907	Economy	28000.00
0005435373575	9907	Economy	28000.00
0005432203103	9907	Economy	28000.00
0005434831141	9907	Economy	28000.00
0005434822731	9907	Economy	28000.00
0005435373579	9907	Economy	28000.00
0005434822954	9907	Economy	28000.00
0005434822527	9907	Economy	28000.00
0005434822951	9907	Economy	28000.00
0005435386598	9907	Economy	28000.00
0005434822866	9907	Economy	28000.00
0005434822964	9907	Economy	28000.00
0005435149970	9907	Economy	28000.00
0005434822729	9907	Economy	28000.00
0005434823182	9907	Economy	28000.00
0005434828688	9907	Economy	28000.00
0005434823696	9907	Economy	28000.00
0005435373599	9907	Economy	28000.00
0005435150004	9907	Economy	28000.00
0005435373591	9907	Economy	28000.00
0005434558231	9907	Economy	28000.00
0005435373621	9907	Economy	28000.00
0005434823537	9907	Economy	28000.00
0005434823112	9907	Economy	28000.00
0005435373613	9907	Economy	28000.00
0005434823364	9907	Economy	28000.00
0005435373581	9907	Economy	28000.00
0005435150007	9907	Economy	28000.00
0005435373565	9907	Economy	28000.00
0005435386601	9907	Economy	28000.00
0005435302222	9907	Economy	28000.00
0005435373600	9907	Economy	28000.00
0005434823493	9907	Economy	28000.00
0005435373584	9907	Economy	28000.00
0005435373596	9907	Economy	28000.00
0005434823270	9907	Economy	28000.00
0005434822955	9907	Economy	28000.00
0005434822942	9907	Economy	28000.00
0005435373623	9907	Economy	28000.00
0005435373603	9907	Economy	28000.00
0005434822740	9907	Economy	28000.00
0005435373566	9907	Economy	28000.00
0005434558227	9907	Economy	28000.00
0005435373622	9907	Economy	28000.00
0005434558230	9907	Economy	28000.00
0005435373619	9907	Economy	28000.00
0005435373624	9907	Economy	28000.00
0005434822853	9907	Economy	28000.00
0005435299799	9907	Economy	30800.00
0005434822553	9907	Economy	30800.00
0005435373587	9907	Economy	30800.00
0005434822561	9907	Economy	30800.00
0005435373592	9907	Economy	28000.00
0005435373614	9907	Economy	28000.00
0005434823174	9907	Economy	28000.00
0005435373573	9907	Economy	28000.00
0005434822228	9907	Economy	28000.00
0005435179697	9907	Economy	28000.00
0005435149981	9907	Economy	28000.00
0005434822637	9907	Economy	28000.00
0005434822536	9907	Economy	28000.00
0005434822865	9907	Economy	28000.00
0005434823162	9907	Economy	28000.00
0005434823121	9907	Economy	28000.00
0005434823074	9907	Economy	28000.00
0005435373605	9907	Economy	28000.00
0005435373568	9907	Economy	28000.00
0005435373594	9907	Economy	28000.00
0005434822229	9907	Economy	28000.00
0005434828687	9907	Economy	28000.00
0005434831131	9907	Economy	28000.00
0005434831130	9907	Economy	28000.00
0005434823087	9907	Economy	28000.00
0005434822490	9907	Economy	28000.00
0005434823076	9907	Economy	28000.00
0005432203099	9907	Economy	28000.00
0005435735160	9907	Economy	28000.00
0005434822959	9907	Economy	28000.00
0005434822741	9907	Economy	28000.00
0005434822425	9907	Economy	28000.00
0005435373567	9907	Economy	28000.00
0005435299801	9907	Economy	28000.00
0005434822426	9907	Economy	28000.00
0005434822960	9907	Economy	28000.00
0005435150025	9907	Economy	28000.00
0005434823269	9907	Economy	28000.00
0005435149983	9907	Economy	28000.00
0005435373610	9907	Economy	28000.00
0005434831136	9907	Economy	28000.00
0005434822427	9907	Economy	28000.00
0005435149924	9907	Economy	28000.00
0005435373609	9907	Economy	28000.00
0005434664958	9907	Economy	28000.00
0005434822947	9907	Economy	28000.00
0005435299802	9907	Economy	28000.00
0005432400105	9907	Economy	28000.00
0005435661947	9907	Economy	28000.00
0005434823268	9907	Economy	28000.00
0005432396229	9907	Economy	28000.00
0005435373607	9907	Economy	28000.00
0005434823128	9907	Economy	28000.00
0005435373606	9907	Economy	28000.00
0005434823183	9907	Economy	28000.00
0005434823492	9907	Economy	28000.00
0005434823329	9907	Economy	28000.00
0005434823759	9907	Economy	28000.00
0005435302223	9907	Economy	28000.00
0005435386604	9907	Economy	28000.00
0005435373601	9907	Economy	28000.00
0005434823153	9907	Economy	28000.00
0005434822932	9907	Economy	28000.00
0005434823038	9907	Economy	28000.00
0005435373597	9907	Economy	28000.00
0005435149982	9907	Economy	28000.00
0005435373604	9907	Economy	28000.00
0005434822552	9907	Economy	28000.00
0005435386599	9907	Economy	28000.00
0005434822839	9907	Economy	28000.00
0005434822795	9907	Economy	28000.00
0005435373572	9907	Economy	28000.00
0005434823124	9907	Economy	28000.00
0005434822946	9907	Economy	28000.00
0005434823464	9907	Economy	28000.00
0005434822666	9907	Economy	28000.00
0005434823209	9907	Economy	28000.00
0005435373588	9907	Economy	28000.00
0005435373586	9907	Economy	28000.00
0005434823067	9907	Economy	28000.00
0005434823195	9907	Economy	28000.00
0005434822989	9907	Economy	28000.00
0005434822925	9907	Economy	28000.00
0005434823741	9907	Economy	28000.00
0005434664959	9907	Economy	28000.00
0005434822610	9907	Economy	28000.00
0005434828685	9907	Economy	28000.00
0005434823042	9907	Economy	28000.00
0005434823298	9907	Economy	28000.00
0005434823310	9907	Economy	28000.00
0005434823208	9907	Economy	28000.00
0005435082823	7015	Economy	8200.00
0005435082831	7015	Economy	7400.00
0005435082826	7015	Economy	7400.00
0005435790321	7015	Economy	7400.00
0005435082829	7015	Economy	7400.00
0005435082827	7015	Economy	7400.00
0005435082824	7015	Economy	7400.00
0005435790322	7015	Economy	7400.00
0005435082828	7015	Economy	7400.00
0005435082830	7015	Economy	7400.00
0005435082825	7015	Economy	7400.00
0005435082747	26020	Economy	8200.00
0005435082686	26020	Economy	7400.00
0005435082720	26020	Economy	7400.00
0005435790301	26020	Economy	7400.00
0005435082769	26020	Economy	7400.00
0005435082782	26020	Economy	7400.00
0005435082773	26020	Economy	7400.00
0005435082685	26020	Economy	7400.00
0005435082777	26020	Economy	7400.00
0005435082783	26020	Economy	7400.00
0005434214256	9569	Business	32800.00
0005434214265	9569	Business	32800.00
0005434756617	9569	Business	32800.00
0005434756629	9569	Business	32800.00
0005434214169	9569	Business	32800.00
0005434756655	9569	Business	32800.00
0005434756653	9569	Business	32800.00
0005434756639	9569	Business	32800.00
0005434756618	9569	Business	32800.00
0005434214151	9569	Business	32800.00
0005434214168	9569	Business	32800.00
0005434214477	9569	Economy	10900.00
0005434756620	9569	Economy	10900.00
0005434214323	9569	Economy	10900.00
0005434214435	9569	Economy	10900.00
0005434756626	9569	Economy	10900.00
0005434214344	9569	Economy	10900.00
0005434214321	9569	Economy	10900.00
0005434756638	9569	Economy	10900.00
0005434756630	9569	Economy	10900.00
0005434756647	9569	Economy	10900.00
0005434756649	9569	Economy	12000.00
0005434214408	9569	Economy	12000.00
0005434756631	9569	Economy	12000.00
0005434756619	9569	Economy	12000.00
0005434756657	9569	Economy	12000.00
0005434756648	9569	Economy	10900.00
0005434756634	9569	Economy	10900.00
0005434756621	9569	Economy	10900.00
0005434214452	9569	Economy	10900.00
0005434214370	9569	Economy	10900.00
0005434756641	9569	Economy	10900.00
0005434214371	9569	Economy	10900.00
0005434756662	9569	Economy	10900.00
0005434214461	9569	Economy	10900.00
0005434214282	9569	Economy	10900.00
0005434214462	9569	Economy	10900.00
0005434756622	9569	Economy	10900.00
0005434214451	9569	Economy	10900.00
0005434214296	9569	Economy	10900.00
0005434214324	9569	Economy	10900.00
0005434756636	9569	Economy	10900.00
0005434756652	9569	Economy	10900.00
0005434756650	9569	Economy	10900.00
0005434756627	9569	Economy	10900.00
0005434214244	9569	Economy	10900.00
0005434756643	9569	Economy	10900.00
0005434214135	9569	Economy	10900.00
0005434756658	9569	Economy	10900.00
0005434756659	9569	Economy	10900.00
0005434756642	9569	Economy	10900.00
0005434214347	9569	Economy	10900.00
0005434214570	9569	Economy	10900.00
0005434214180	9569	Economy	10900.00
0005434756632	9569	Economy	10900.00
0005434756616	9569	Economy	10900.00
0005434756628	9569	Economy	10900.00
0005434756664	9569	Economy	10900.00
0005434214450	9569	Economy	10900.00
0005434214113	9569	Economy	10900.00
0005434214134	9569	Economy	10900.00
0005434214191	9569	Economy	10900.00
0005434756624	9569	Economy	10900.00
0005434756651	9569	Economy	10900.00
0005434756646	9569	Economy	10900.00
0005434756625	9569	Economy	10900.00
0005434214297	9569	Economy	10900.00
0005434756615	9569	Economy	10900.00
0005434214147	9569	Economy	10900.00
0005434214155	9569	Economy	10900.00
0005434214434	9569	Economy	10900.00
0005434756637	9569	Economy	10900.00
0005434214345	9569	Economy	10900.00
0005434756614	9569	Economy	10900.00
0005434214359	9569	Economy	10900.00
0005434756644	9569	Economy	10900.00
0005434214263	9569	Economy	10900.00
0005434756613	9569	Economy	10900.00
0005434756660	9569	Economy	10900.00
0005434756654	9569	Economy	10900.00
0005434756623	9569	Economy	10900.00
0005434756645	9569	Economy	10900.00
0005434756661	9569	Economy	10900.00
0005434214458	9569	Economy	10900.00
0005434756635	9569	Economy	10900.00
0005434214279	9569	Economy	10900.00
0005434756633	9569	Economy	10900.00
0005434756640	9569	Economy	10900.00
0005434214136	9569	Economy	10900.00
0005434214429	9569	Economy	10900.00
0005434214283	9569	Economy	10900.00
0005434756656	9569	Economy	10900.00
0005434756663	9569	Economy	10900.00
0005434214292	9569	Economy	10900.00
0005434214713	28634	Business	32800.00
0005434756258	28634	Business	32800.00
0005434756152	28634	Business	32800.00
0005434214726	28634	Business	32800.00
0005434756083	28634	Business	32800.00
0005434214715	28634	Business	32800.00
0005434756144	28634	Business	32800.00
0005434214709	28634	Business	32800.00
0005434214721	28634	Business	32800.00
0005434214708	28634	Business	32800.00
0005434756273	28634	Economy	10900.00
0005434214705	28634	Economy	10900.00
0005434214698	28634	Economy	10900.00
0005434214737	28634	Economy	10900.00
0005434214741	28634	Economy	10900.00
0005434214718	28634	Economy	10900.00
0005434756169	28634	Economy	10900.00
0005434214730	28634	Economy	10900.00
0005434214731	28634	Economy	12000.00
0005434756217	28634	Economy	12000.00
0005434756202	28634	Economy	12000.00
0005434756100	28634	Economy	12000.00
0005434214701	28634	Economy	12000.00
0005434214707	28634	Economy	10900.00
0005434214719	28634	Economy	10900.00
0005434756151	28634	Economy	10900.00
0005434214711	28634	Economy	10900.00
0005434214742	28634	Economy	10900.00
0005434756322	28634	Economy	10900.00
0005434756084	28634	Economy	10900.00
0005434214728	28634	Economy	10900.00
0005434756290	28634	Economy	10900.00
0005434214744	28634	Economy	10900.00
0005434214738	28634	Economy	10900.00
0005434214724	28634	Economy	10900.00
0005434756167	28634	Economy	10900.00
0005434756142	28634	Economy	10900.00
0005434214727	28634	Economy	10900.00
0005434756251	28634	Economy	10900.00
0005434214729	28634	Economy	10900.00
0005434756252	28634	Economy	10900.00
0005434214700	28634	Economy	10900.00
0005434756088	28634	Economy	10900.00
0005434214703	28634	Economy	10900.00
0005434756292	28634	Economy	10900.00
0005434214735	28634	Economy	10900.00
0005434214743	28634	Economy	10900.00
0005434214717	28634	Economy	10900.00
0005434756272	28634	Economy	10900.00
0005434756143	28634	Economy	10900.00
0005434756285	28634	Economy	10900.00
0005434756253	28634	Economy	10900.00
0005434214740	28634	Economy	10900.00
0005434756336	28634	Economy	10900.00
0005434214725	28634	Economy	10900.00
0005434756145	28634	Economy	10900.00
0005434214733	28634	Economy	10900.00
0005434214699	28634	Economy	10900.00
0005434214736	28634	Economy	10900.00
0005434756245	28634	Economy	10900.00
0005434214732	28634	Economy	10900.00
0005434214720	28634	Economy	10900.00
0005434214739	28634	Economy	10900.00
0005434214716	28634	Economy	10900.00
0005434214702	28634	Economy	10900.00
0005434214704	28634	Economy	10900.00
0005434756069	28634	Economy	10900.00
0005434214723	28634	Economy	10900.00
0005434214734	28634	Economy	10900.00
0005434214697	28634	Economy	10900.00
0005434214706	28634	Economy	10900.00
0005434214710	28634	Economy	10900.00
0005434756284	28634	Economy	10900.00
0005434214714	28634	Economy	10900.00
0005434214712	28634	Economy	10900.00
0005434214722	28634	Economy	10900.00
0005434756082	28634	Economy	10900.00
0005434756270	28634	Economy	10900.00
0005434756250	28634	Economy	10900.00
0005435100139	10839	Economy	8900.00
0005434760189	10839	Economy	8900.00
0005434760190	10839	Economy	8900.00
0005435100138	10839	Economy	8900.00
0005434760180	10839	Economy	8900.00
0005434760209	31841	Economy	8900.00
0005434760210	31841	Economy	8900.00
0005435100118	31841	Economy	8900.00
0005434639459	1967	Economy	20900.00
0005434639453	1967	Economy	20900.00
0005433202327	1967	Economy	20900.00
0005433202294	1967	Economy	20900.00
0005433202312	1967	Economy	19000.00
0005434639474	1967	Economy	19000.00
0005434639460	1967	Economy	19000.00
0005434639451	1967	Economy	19000.00
0005434639462	1967	Economy	19000.00
0005434639454	1967	Economy	19000.00
0005434639450	1967	Economy	19000.00
0005433202287	1967	Economy	19000.00
0005432290649	1967	Economy	19000.00
0005433202272	1967	Economy	19000.00
0005434639457	1967	Economy	19000.00
0005433202292	1967	Economy	19000.00
0005434639456	1967	Economy	19000.00
0005434639465	1967	Economy	19000.00
0005435948331	1967	Economy	19000.00
0005433202337	1967	Economy	19000.00
0005433202291	1967	Economy	19000.00
0005434639467	1967	Economy	19000.00
0005432290648	1967	Economy	19000.00
0005433202307	1967	Economy	19000.00
0005434639476	1967	Economy	19000.00
0005434639461	1967	Economy	19000.00
0005434639468	1967	Economy	19000.00
0005433202326	1967	Economy	19000.00
0005434639473	1967	Economy	19000.00
0005432290650	1967	Economy	19000.00
0005434639470	1967	Economy	19000.00
0005433202328	1967	Economy	19000.00
0005434639463	1967	Economy	19000.00
0005434639464	1967	Economy	19000.00
0005434639475	1967	Economy	19000.00
0005434639471	1967	Economy	19000.00
0005434639469	1967	Economy	19000.00
0005435948332	1967	Economy	19000.00
0005434639472	1967	Economy	19000.00
0005434639458	1967	Economy	19000.00
0005433202271	1967	Economy	19000.00
0005433202289	1967	Economy	19000.00
0005433202310	1967	Economy	19000.00
0005434639466	1967	Economy	19000.00
0005434639452	1967	Economy	19000.00
0005434639455	1967	Economy	19000.00
0005434639168	23293	Economy	20900.00
0005433202427	23293	Economy	20900.00
0005434639347	23293	Economy	20900.00
0005434639250	23293	Economy	20900.00
0005434639230	23293	Economy	19000.00
0005433202423	23293	Economy	19000.00
0005433202422	23293	Economy	19000.00
0005433202426	23293	Economy	19000.00
0005434639118	23293	Economy	19000.00
0005433202425	23293	Economy	19000.00
0005434639214	23293	Economy	19000.00
0005434639242	23293	Economy	19000.00
0005434639209	23293	Economy	19000.00
0005433202429	23293	Economy	19000.00
0005434639245	23293	Economy	19000.00
0005434639114	23293	Economy	19000.00
0005434639257	23293	Economy	19000.00
0005434639115	23293	Economy	19000.00
0005433202430	23293	Economy	19000.00
0005434639153	23293	Economy	19000.00
0005434639152	23293	Economy	19000.00
0005434639237	23293	Economy	19000.00
0005434639259	23293	Economy	19000.00
0005434639241	23293	Economy	19000.00
0005433202419	23293	Economy	19000.00
0005434639210	23293	Economy	19000.00
0005433202428	23293	Economy	19000.00
0005434639170	23293	Economy	19000.00
0005434639169	23293	Economy	19000.00
0005434639260	23293	Economy	19000.00
0005434639231	23293	Economy	19000.00
0005433202432	23293	Economy	19000.00
0005433202433	23293	Economy	19000.00
0005434639233	23293	Economy	19000.00
0005433202434	23293	Economy	19000.00
0005433202420	23293	Economy	19000.00
0005434639171	23293	Economy	19000.00
0005433202424	23293	Economy	19000.00
0005433202431	23293	Economy	19000.00
0005434639268	23293	Economy	19000.00
0005433202421	23293	Economy	19000.00
0005434639126	23293	Economy	19000.00
0005435948326	23293	Economy	19000.00
0005434639141	23293	Economy	19000.00
0005434639278	23293	Economy	19000.00
0005435326712	6066	Business	69700.00
0005434600950	6066	Business	69700.00
0005434600958	6066	Business	69700.00
0005433531314	6066	Business	69700.00
0005432111296	6066	Business	69700.00
0005433531313	6066	Business	69700.00
0005434600935	6066	Economy	23200.00
0005434600955	6066	Economy	23200.00
0005434600961	6066	Economy	23200.00
0005434600949	6066	Economy	25600.00
0005434600937	6066	Economy	25600.00
0005434600952	6066	Economy	23200.00
0005434600954	6066	Economy	23200.00
0005435326711	6066	Economy	23200.00
0005434600960	6066	Economy	23200.00
0005434600956	6066	Economy	23200.00
0005435326718	6066	Economy	23200.00
0005435326695	6066	Economy	23200.00
0005434600941	6066	Economy	23200.00
0005433533330	6066	Economy	23200.00
0005433533329	6066	Economy	23200.00
0005435326759	6066	Economy	23200.00
0005433531311	6066	Economy	23200.00
0005433533327	6066	Economy	23200.00
0005434600951	6066	Economy	23200.00
0005434600942	6066	Economy	23200.00
0005435326688	6066	Economy	23200.00
0005433533328	6066	Economy	23200.00
0005434600946	6066	Economy	23200.00
0005433533326	6066	Economy	23200.00
0005435326674	6066	Economy	23200.00
0005434600938	6066	Economy	23200.00
0005434600962	6066	Economy	23200.00
0005434600948	6066	Economy	23200.00
0005434600940	6066	Economy	23200.00
0005434600957	6066	Economy	23200.00
0005434600947	6066	Economy	23200.00
0005435326719	6066	Economy	23200.00
0005434600939	6066	Economy	23200.00
0005432111294	6066	Economy	23200.00
0005433531312	6066	Economy	23200.00
0005434600945	6066	Economy	23200.00
0005432111295	6066	Economy	23200.00
0005434600943	6066	Economy	23200.00
0005434600936	6066	Economy	23200.00
0005435326689	6066	Economy	23200.00
0005434600934	6066	Economy	23200.00
0005434600933	6066	Economy	23200.00
0005434600959	6066	Economy	23200.00
0005435326694	6066	Economy	23200.00
0005434600944	6066	Economy	23200.00
0005434600953	6066	Economy	23200.00
0005434600689	18564	Business	69700.00
0005434600811	18564	Business	69700.00
0005435326818	18564	Business	69700.00
0005434600734	18564	Business	69700.00
0005433527237	18564	Business	69700.00
0005434600620	18564	Economy	23200.00
0005435326815	18564	Economy	23200.00
0005435326822	18564	Economy	23200.00
0005434600711	18564	Economy	23200.00
0005435326819	18564	Economy	25600.00
0005433527247	18564	Economy	25600.00
0005435326809	18564	Economy	23200.00
0005435326816	18564	Economy	23200.00
0005434600758	18564	Economy	23200.00
0005434600809	18564	Economy	23200.00
0005434600668	18564	Economy	23200.00
0005433527219	18564	Economy	23200.00
0005434600588	18564	Economy	23200.00
0005435326811	18564	Economy	23200.00
0005434600810	18564	Economy	23200.00
0005434600658	18564	Economy	23200.00
0005433527249	18564	Economy	23200.00
0005434600634	18564	Economy	23200.00
0005434600712	18564	Economy	23200.00
0005434600704	18564	Economy	23200.00
0005434600772	18564	Economy	23200.00
0005434600691	18564	Economy	23200.00
0005433527250	18564	Economy	23200.00
0005433527242	18564	Economy	23200.00
0005435326820	18564	Economy	23200.00
0005434600617	18564	Economy	23200.00
0005435326810	18564	Economy	23200.00
0005435326817	18564	Economy	23200.00
0005434600719	18564	Economy	23200.00
0005434600777	18564	Economy	23200.00
0005434600640	18564	Economy	23200.00
0005434600629	18564	Economy	23200.00
0005433527248	18564	Economy	23200.00
0005434600715	18564	Economy	23200.00
0005434600587	18564	Economy	23200.00
0005434600791	18564	Economy	23200.00
0005435326821	18564	Economy	23200.00
0005435326812	18564	Economy	23200.00
0005434600690	18564	Economy	23200.00
0005434600753	18564	Economy	23200.00
0005434600778	18564	Economy	23200.00
0005435326814	18564	Economy	23200.00
0005434600703	18564	Economy	23200.00
0005435326813	18564	Economy	23200.00
0005434600642	18564	Economy	23200.00
0005433527238	18564	Economy	23200.00
0005433180892	10630	Business	9100.00
0005434551461	10630	Business	9100.00
0005434551480	10630	Business	9100.00
0005433181082	10630	Business	9100.00
0005434551450	10630	Business	9100.00
0005434554075	10630	Business	9100.00
0005433181038	10630	Business	9100.00
0005433180920	10630	Business	9100.00
0005434551446	10630	Business	9100.00
0005434551465	10630	Business	9100.00
0005433180979	10630	Business	9100.00
0005433180896	10630	Business	9100.00
0005434551487	10630	Economy	3000.00
0005434551456	10630	Economy	3000.00
0005433180895	10630	Economy	3000.00
0005434551470	10630	Economy	3000.00
0005434551464	10630	Economy	3000.00
0005433180966	10630	Economy	3000.00
0005434551463	10630	Economy	3000.00
0005433180955	10630	Economy	3000.00
0005434551481	10630	Economy	3000.00
0005434551462	10630	Economy	3000.00
0005433181005	10630	Economy	3300.00
0005433181036	10630	Economy	3300.00
0005433180982	10630	Economy	3300.00
0005434551482	10630	Economy	3300.00
0005434551451	10630	Economy	3300.00
0005434551460	10630	Economy	3000.00
0005434551455	10630	Economy	3000.00
0005433180976	10630	Economy	3000.00
0005434551491	10630	Economy	3000.00
0005433181039	10630	Economy	3000.00
0005434551468	10630	Economy	3000.00
0005434551459	10630	Economy	3000.00
0005434551441	10630	Economy	3000.00
0005434551474	10630	Economy	3000.00
0005434551490	10630	Economy	3000.00
0005433180951	10630	Economy	3000.00
0005434551486	10630	Economy	3000.00
0005433180884	10630	Economy	3000.00
0005433180991	10630	Economy	3000.00
0005433180831	10630	Economy	3000.00
0005433180999	10630	Economy	3000.00
0005433180990	10630	Economy	3000.00
0005434551475	10630	Economy	3000.00
0005433180918	10630	Economy	3000.00
0005434551439	10630	Economy	3000.00
0005433181020	10630	Economy	3000.00
0005434551452	10630	Economy	3000.00
0005434554076	10630	Economy	3000.00
0005433181037	10630	Economy	3000.00
0005434551476	10630	Economy	3000.00
0005434551472	10630	Economy	3000.00
0005433180975	10630	Economy	3000.00
0005433180890	10630	Economy	3000.00
0005433180967	10630	Economy	3000.00
0005434551448	10630	Economy	3000.00
0005434551467	10630	Economy	3000.00
0005434551445	10630	Economy	3000.00
0005434551454	10630	Economy	3000.00
0005433180958	10630	Economy	3000.00
0005433181081	10630	Economy	3000.00
0005434551484	10630	Economy	3000.00
0005434551478	10630	Economy	3000.00
0005434551466	10630	Economy	3000.00
0005434551440	10630	Economy	3000.00
0005433181004	10630	Economy	3000.00
0005434551457	10630	Economy	3000.00
0005434551493	10630	Economy	3000.00
0005434551471	10630	Economy	3000.00
0005434551479	10630	Economy	3000.00
0005433180917	10630	Economy	3000.00
0005433180973	10630	Economy	3000.00
0005434551438	10630	Economy	3000.00
0005434551488	10630	Economy	3000.00
0005433180964	10630	Economy	3000.00
0005434551469	10630	Economy	3000.00
0005434551485	10630	Economy	3000.00
0005433181059	10630	Economy	3000.00
0005434551453	10630	Economy	3000.00
0005434551447	10630	Economy	3000.00
0005434551449	10630	Economy	3000.00
0005434551444	10630	Economy	3000.00
0005433181066	10630	Economy	3000.00
0005434551473	10630	Economy	3000.00
0005434551477	10630	Economy	3000.00
0005434551483	10630	Economy	3000.00
0005433180978	10630	Economy	3000.00
0005433180974	10630	Economy	3000.00
0005434551442	10630	Economy	3000.00
0005434551443	10630	Economy	3000.00
0005433180959	10630	Economy	3000.00
0005434551489	10630	Economy	3000.00
0005434551492	10630	Economy	3000.00
0005434551458	10630	Economy	3000.00
0005433181011	10630	Economy	3000.00
0005433181232	27728	Business	9100.00
0005433181223	27728	Business	9100.00
0005433181237	27728	Economy	3000.00
0005433181226	27728	Economy	3300.00
0005433181238	27728	Economy	3000.00
0005433181236	27728	Economy	3000.00
0005433181221	27728	Economy	3000.00
0005433181217	27728	Economy	3000.00
0005433181224	27728	Economy	3000.00
0005433181225	27728	Economy	3000.00
0005433181240	27728	Economy	3000.00
0005433181242	27728	Economy	3000.00
0005433181220	27728	Economy	3000.00
0005433181219	27728	Economy	3000.00
0005433181218	27728	Economy	3000.00
0005433181231	27728	Economy	3000.00
0005433181235	27728	Economy	3000.00
0005433181222	27728	Economy	3000.00
0005433181239	27728	Economy	3000.00
0005433181227	27728	Economy	3000.00
0005433181228	27728	Economy	3000.00
0005433181229	27728	Economy	3000.00
0005433181234	27728	Economy	3000.00
0005433181241	27728	Economy	3000.00
0005433181230	27728	Economy	3000.00
0005433181233	27728	Economy	3000.00
0005434551021	27729	Business	9100.00
0005434558263	27729	Business	9100.00
0005434551167	27729	Business	9100.00
0005434551220	27729	Business	9100.00
0005434550827	27729	Business	9100.00
0005434551195	27729	Business	9100.00
0005434551262	27729	Business	9100.00
0005434550966	27729	Economy	3000.00
0005434550981	27729	Economy	3000.00
0005434550938	27729	Economy	3000.00
0005434554056	27729	Economy	3000.00
0005434551180	27729	Economy	3000.00
0005434551135	27729	Economy	3000.00
0005434551117	27729	Economy	3000.00
0005434550983	27729	Economy	3300.00
0005434550869	27729	Economy	3300.00
0005434551138	27729	Economy	3300.00
0005434550899	27729	Economy	3000.00
0005434550967	27729	Economy	3000.00
0005434550999	27729	Economy	3000.00
0005434550925	27729	Economy	3000.00
0005434550963	27729	Economy	3000.00
0005434551026	27729	Economy	3000.00
0005434551105	27729	Economy	3000.00
0005434551196	27729	Economy	3000.00
0005434550973	27729	Economy	3000.00
0005434550919	27729	Economy	3000.00
0005434554055	27729	Economy	3000.00
0005434554057	27729	Economy	3000.00
0005434551181	27729	Economy	3000.00
0005434551116	27729	Economy	3000.00
0005434550937	27729	Economy	3000.00
0005434550988	27729	Economy	3000.00
0005434550856	27729	Economy	3000.00
0005434550982	27729	Economy	3000.00
0005434551136	27729	Economy	3000.00
0005434551022	27729	Economy	3000.00
0005434551205	27729	Economy	3000.00
0005434550916	27729	Economy	3000.00
0005434551199	27729	Economy	3000.00
0005434551066	27729	Economy	3000.00
0005434550945	27729	Economy	3000.00
0005434550820	27729	Economy	3000.00
0005434551308	27729	Economy	3000.00
0005434550900	27729	Economy	3000.00
0005434551206	27729	Economy	3000.00
0005434550918	27729	Economy	3000.00
0005434551143	27729	Economy	3000.00
0005434551010	27729	Economy	3000.00
0005434551253	27729	Economy	3000.00
0005434551095	27729	Economy	3000.00
0005434551106	27729	Economy	3000.00
0005434550901	27729	Economy	3000.00
0005434550936	27729	Economy	3000.00
0005434550821	27729	Economy	3000.00
0005434551096	27729	Economy	3000.00
0005434551137	27729	Economy	3000.00
0005434551207	27729	Economy	3000.00
0005434551182	27729	Economy	3000.00
0005434551131	27729	Economy	3000.00
0005433459242	6144	Economy	11700.00
0005433459240	6144	Economy	11700.00
0005433459241	6144	Economy	11700.00
0005433459205	19291	Economy	11700.00
0005433459204	19291	Economy	11700.00
0005435254487	19291	Economy	11700.00
0005433459208	19291	Economy	11700.00
0005433459207	19291	Economy	11700.00
0005433459206	19291	Economy	11700.00
0005435254486	19291	Economy	11700.00
0005433459203	19291	Economy	11700.00
0005435220311	6754	Business	51100.00
0005432533288	6754	Business	51100.00
0005435437800	6754	Business	51100.00
0005435682348	6754	Business	51100.00
0005435682343	6754	Business	51100.00
0005435437873	6754	Business	51100.00
0005435437912	6754	Business	51100.00
0005435682345	6754	Business	51100.00
0005435437889	6754	Business	51100.00
0005435437805	6754	Business	51100.00
0005435682332	6754	Business	51100.00
0005435437833	6754	Economy	17000.00
0005435437892	6754	Economy	17000.00
0005435217703	6754	Economy	17000.00
0005435682353	6754	Economy	17000.00
0005432136196	6754	Economy	17000.00
0005434828683	6754	Economy	17000.00
0005435682347	6754	Economy	17000.00
0005435437936	6754	Economy	17000.00
0005435437832	6754	Economy	18700.00
0005434828684	6754	Economy	18700.00
0005435682335	6754	Economy	18700.00
0005435220305	6754	Economy	18700.00
0005435682338	6754	Economy	18700.00
0005435437841	6754	Economy	17000.00
0005435682346	6754	Economy	17000.00
0005435682331	6754	Economy	17000.00
0005435630981	6754	Economy	17000.00
0005435630979	6754	Economy	17000.00
0005435682358	6754	Economy	17000.00
0005435220315	6754	Economy	17000.00
0005435437980	6754	Economy	17000.00
0005435437888	6754	Economy	17000.00
0005435682361	6754	Economy	17000.00
0005435682341	6754	Economy	17000.00
0005435437999	6754	Economy	17000.00
0005435437866	6754	Economy	17000.00
0005435682349	6754	Economy	17000.00
0005435682351	6754	Economy	17000.00
0005435437891	6754	Economy	17000.00
0005435437893	6754	Economy	17000.00
0005435217701	6754	Economy	17000.00
0005435437806	6754	Economy	17000.00
0005435437874	6754	Economy	17000.00
0005435682359	6754	Economy	17000.00
0005432136192	6754	Economy	17000.00
0005435682344	6754	Economy	17000.00
0005432533274	6754	Economy	17000.00
0005435661942	6754	Economy	17000.00
0005435682355	6754	Economy	17000.00
0005435682356	6754	Economy	17000.00
0005435682352	6754	Economy	17000.00
0005435682334	6754	Economy	17000.00
0005435437863	6754	Economy	17000.00
0005435437894	6754	Economy	17000.00
0005435661943	6754	Economy	17000.00
0005432533287	6754	Economy	17000.00
0005435437872	6754	Economy	17000.00
0005435437799	6754	Economy	17000.00
0005432136194	6754	Economy	17000.00
0005432136195	6754	Economy	17000.00
0005435682339	6754	Economy	17000.00
0005435682357	6754	Economy	17000.00
0005435682350	6754	Economy	17000.00
0005432136193	6754	Economy	17000.00
0005435682330	6754	Economy	17000.00
0005435682336	6754	Economy	17000.00
0005435221513	6754	Economy	17000.00
0005435217702	6754	Economy	17000.00
0005435682337	6754	Economy	17000.00
0005435661945	6754	Economy	17000.00
0005435437907	6754	Economy	17000.00
0005435682342	6754	Economy	17000.00
0005434828676	6754	Economy	17000.00
0005435437850	6754	Economy	17000.00
0005435630980	6754	Economy	17000.00
0005435437887	6754	Economy	17000.00
0005435437865	6754	Economy	17000.00
0005435682333	6754	Economy	17000.00
0005435661944	6754	Economy	17000.00
0005435437840	6754	Economy	17000.00
0005435682340	6754	Economy	17000.00
0005435682354	6754	Economy	17000.00
0005435682360	6754	Economy	17000.00
0005435220314	6754	Economy	17000.00
0005435220324	24602	Business	51100.00
0005435719568	24602	Business	51100.00
0005435220329	24602	Business	51100.00
0005435438072	24602	Business	51100.00
0005435682015	24602	Business	51100.00
0005435219207	24602	Business	51100.00
0005435682034	24602	Business	51100.00
0005435438055	24602	Business	51100.00
0005435220328	24602	Business	51100.00
0005435438053	24602	Business	51100.00
0005435438060	24602	Business	51100.00
0005435438063	24602	Economy	17000.00
0005435682007	24602	Economy	17000.00
0005435438071	24602	Economy	17000.00
0005435219209	24602	Economy	17000.00
0005435681964	24602	Economy	17000.00
0005435220327	24602	Economy	17000.00
0005435682002	24602	Economy	17000.00
0005435438059	24602	Economy	17000.00
0005435681924	24602	Economy	17000.00
0005435719567	24602	Economy	17000.00
0005435438065	24602	Economy	18700.00
0005435438056	24602	Economy	18700.00
0005435681904	24602	Economy	18700.00
0005435682197	24602	Economy	18700.00
0005435682083	24602	Economy	17000.00
0005435438066	24602	Economy	17000.00
0005432533306	24602	Economy	17000.00
0005435438064	24602	Economy	17000.00
0005435438067	24602	Economy	17000.00
0005435681923	24602	Economy	17000.00
0005432533307	24602	Economy	17000.00
0005435681880	24602	Economy	17000.00
0005435438062	24602	Economy	17000.00
0005435681870	24602	Economy	17000.00
0005435681887	24602	Economy	17000.00
0005435438058	24602	Economy	17000.00
0005435681976	24602	Economy	17000.00
0005435681953	24602	Economy	17000.00
0005432305761	24602	Economy	17000.00
0005435682106	24602	Economy	17000.00
0005435682036	24602	Economy	17000.00
0005434828711	24602	Economy	17000.00
0005435682009	24602	Economy	17000.00
0005435682082	24602	Economy	17000.00
0005435682081	24602	Economy	17000.00
0005435219208	24602	Economy	17000.00
0005435681952	24602	Economy	17000.00
0005435219210	24602	Economy	17000.00
0005435681949	24602	Economy	17000.00
0005435682033	24602	Economy	17000.00
0005435220491	24602	Economy	17000.00
0005432533305	24602	Economy	17000.00
0005435682035	24602	Economy	17000.00
0005435219211	24602	Economy	17000.00
0005435681869	24602	Economy	17000.00
0005434828712	24602	Economy	17000.00
0005432305762	24602	Economy	17000.00
0005435682183	24602	Economy	17000.00
0005435681960	24602	Economy	17000.00
0005435661926	24602	Economy	17000.00
0005435630942	24602	Economy	17000.00
0005435219205	24602	Economy	17000.00
0005435681783	24602	Economy	17000.00
0005435630951	24602	Economy	17000.00
0005435220326	24602	Economy	17000.00
0005435438070	24602	Economy	17000.00
0005435438057	24602	Economy	17000.00
0005435438054	24602	Economy	17000.00
0005435681985	24602	Economy	17000.00
0005435681890	24602	Economy	17000.00
0005435681948	24602	Economy	17000.00
0005435661923	24602	Economy	17000.00
0005435219206	24602	Economy	17000.00
0005435661922	24602	Economy	17000.00
0005435220330	24602	Economy	17000.00
0005435438068	24602	Economy	17000.00
0005435681991	24602	Economy	17000.00
0005435438073	24602	Economy	17000.00
0005435630952	24602	Economy	17000.00
0005435682089	24602	Economy	17000.00
0005435681872	24602	Economy	17000.00
0005435681927	24602	Economy	17000.00
0005435438069	24602	Economy	17000.00
0005435438061	24602	Economy	17000.00
0005435681893	24602	Economy	17000.00
0005435681889	24602	Economy	17000.00
0005435661927	24602	Economy	17000.00
0005435682095	24602	Economy	17000.00
0005435220325	24602	Economy	17000.00
0005435126554	11542	Business	26400.00
0005435126557	11542	Business	26400.00
0005435126523	11542	Business	26400.00
0005435558068	11542	Business	26400.00
0005435126559	11542	Business	26400.00
0005435558067	11542	Business	26400.00
0005435126548	11542	Business	26400.00
0005435098566	11542	Business	26400.00
0005435105995	11542	Business	26400.00
0005435126555	11542	Economy	8800.00
0005435126538	11542	Economy	8800.00
0005435126530	11542	Economy	8800.00
0005435126534	11542	Economy	8800.00
0005435126537	11542	Economy	8800.00
0005435126525	11542	Economy	8800.00
0005435558088	11542	Economy	9700.00
0005435126529	11542	Economy	9700.00
0005435558078	11542	Economy	8800.00
0005435126528	11542	Economy	8800.00
0005435126522	11542	Economy	8800.00
0005435126532	11542	Economy	8800.00
0005435126558	11542	Economy	8800.00
0005435126545	11542	Economy	8800.00
0005435126542	11542	Economy	8800.00
0005435126550	11542	Economy	8800.00
0005435558087	11542	Economy	8800.00
0005435126549	11542	Economy	8800.00
0005435126544	11542	Economy	8800.00
0005435126546	11542	Economy	8800.00
0005435098563	11542	Economy	8800.00
0005435558080	11542	Economy	8800.00
0005435126561	11542	Economy	8800.00
0005435126533	11542	Economy	8800.00
0005435126553	11542	Economy	8800.00
0005435126562	11542	Economy	8800.00
0005435126536	11542	Economy	8800.00
0005435558079	11542	Economy	8800.00
0005435126539	11542	Economy	8800.00
0005435098561	11542	Economy	8800.00
0005435098568	11542	Economy	8800.00
0005435126521	11542	Economy	8800.00
0005435126531	11542	Economy	8800.00
0005435558070	11542	Economy	8800.00
0005435126556	11542	Economy	8800.00
0005435126524	11542	Economy	8800.00
0005435126547	11542	Economy	8800.00
0005435126551	11542	Economy	8800.00
0005435126541	11542	Economy	8800.00
0005435098564	11542	Economy	8800.00
0005435098567	11542	Economy	8800.00
0005435126526	11542	Economy	8800.00
0005435126540	11542	Economy	8800.00
0005435098562	11542	Economy	8800.00
0005435126535	11542	Economy	8800.00
0005435105996	11542	Economy	8800.00
0005435126543	11542	Economy	8800.00
0005435126527	11542	Economy	8800.00
0005435098565	11542	Economy	8800.00
0005435098569	11542	Economy	8800.00
0005435126560	11542	Economy	8800.00
0005435126552	11542	Economy	8800.00
0005435126262	31878	Business	26400.00
0005435126309	31878	Business	26400.00
0005435126343	31878	Business	26400.00
0005435126139	31878	Business	26400.00
0005435105978	31878	Business	26400.00
0005435098542	31878	Business	26400.00
0005435098543	31878	Business	26400.00
0005435126218	31878	Business	26400.00
0005435126305	31878	Business	26400.00
0005435126403	31878	Business	26400.00
0005435126418	31878	Economy	8800.00
0005435126163	31878	Economy	8800.00
0005435126329	31878	Economy	8800.00
0005435126323	31878	Economy	8800.00
0005435126129	31878	Economy	8800.00
0005435126179	31878	Economy	8800.00
0005435126203	31878	Economy	9700.00
0005435126439	31878	Economy	9700.00
0005435126378	31878	Economy	8800.00
0005435126248	31878	Economy	8800.00
0005435126130	31878	Economy	8800.00
0005435098548	31878	Economy	8800.00
0005435126377	31878	Economy	8800.00
0005435098547	31878	Economy	8800.00
0005435126279	31878	Economy	8800.00
0005435126308	31878	Economy	8800.00
0005435126211	31878	Economy	8800.00
0005435126273	31878	Economy	8800.00
0005435126328	31878	Economy	8800.00
0005435126170	31878	Economy	8800.00
0005435126087	31878	Economy	8800.00
0005435558099	31878	Economy	8800.00
0005435125936	31878	Economy	8800.00
0005435126165	31878	Economy	8800.00
0005435098549	31878	Economy	8800.00
0005435558100	31878	Economy	8800.00
0005435126263	31878	Economy	8800.00
0005435126202	31878	Economy	8800.00
0005435126304	31878	Economy	8800.00
0005435126224	31878	Economy	8800.00
0005435126122	31878	Economy	8800.00
0005435126150	31878	Economy	8800.00
0005435126345	31878	Economy	8800.00
0005435126086	31878	Economy	8800.00
0005435126261	31878	Economy	8800.00
0005435126260	31878	Economy	8800.00
0005435098550	31878	Economy	8800.00
0005435126402	31878	Economy	8800.00
0005435126164	31878	Economy	8800.00
0005435126024	31878	Economy	8800.00
0005435126344	31878	Economy	8800.00
0005435126121	31878	Economy	8800.00
0005435126282	31878	Economy	8800.00
0005435126287	31878	Economy	8800.00
0005435126186	31878	Economy	8800.00
0005435126023	31878	Economy	8800.00
0005435126390	31878	Economy	8800.00
0005435126296	31878	Economy	8800.00
0005435126338	31878	Economy	8800.00
0005433398280	13534	Business	36600.00
0005435732271	13534	Business	36600.00
0005433398300	13534	Business	36600.00
0005433398299	13534	Business	36600.00
0005433398291	13534	Business	36600.00
0005435732293	13534	Business	36600.00
0005433398293	13534	Business	36600.00
0005433398278	13534	Business	36600.00
0005435732260	13534	Business	36600.00
0005433398317	13534	Economy	12200.00
0005433398284	13534	Economy	12200.00
0005435732236	13534	Economy	12200.00
0005433398298	13534	Economy	12200.00
0005433398296	13534	Economy	12200.00
0005433398282	13534	Economy	12200.00
0005435732263	13534	Economy	12200.00
0005435732250	13534	Economy	13400.00
0005433398321	13534	Economy	13400.00
0005435732239	13534	Economy	13400.00
0005433398318	13534	Economy	13400.00
0005433398305	13534	Economy	12200.00
0005433398274	13534	Economy	12200.00
0005435732315	13534	Economy	12200.00
0005433398303	13534	Economy	12200.00
0005435732313	13534	Economy	12200.00
0005433398316	13534	Economy	12200.00
0005433398283	13534	Economy	12200.00
0005433398281	13534	Economy	12200.00
0005433398294	13534	Economy	12200.00
0005433398292	13534	Economy	12200.00
0005435732294	13534	Economy	12200.00
0005433398304	13534	Economy	12200.00
0005435732238	13534	Economy	12200.00
0005433398313	13534	Economy	12200.00
0005433398272	13534	Economy	12200.00
0005433398288	13534	Economy	12200.00
0005433398295	13534	Economy	12200.00
0005433398315	13534	Economy	12200.00
0005433398312	13534	Economy	12200.00
0005433398279	13534	Economy	12200.00
0005433398290	13534	Economy	12200.00
0005433398320	13534	Economy	12200.00
0005433398301	13534	Economy	12200.00
0005433398311	13534	Economy	12200.00
0005433398276	13534	Economy	12200.00
0005433398309	13534	Economy	12200.00
0005433398287	13534	Economy	12200.00
0005435732314	13534	Economy	12200.00
0005435732251	13534	Economy	12200.00
0005433398297	13534	Economy	12200.00
0005433398306	13534	Economy	12200.00
0005433398286	13534	Economy	12200.00
0005433398302	13534	Economy	12200.00
0005433398314	13534	Economy	12200.00
0005433398319	13534	Economy	12200.00
0005433398310	13534	Economy	12200.00
0005435732237	13534	Economy	12200.00
0005433398277	13534	Economy	12200.00
0005433398275	13534	Economy	12200.00
0005433398285	13534	Economy	12200.00
0005433398308	13534	Economy	12200.00
0005433398307	13534	Economy	12200.00
0005433398273	13534	Economy	12200.00
0005433398289	13534	Economy	12200.00
0005433397964	19427	Business	36600.00
0005433397846	19427	Business	36600.00
0005433397911	19427	Business	36600.00
0005433397889	19427	Business	36600.00
0005433397912	19427	Business	36600.00
0005433397871	19427	Business	36600.00
0005433397909	19427	Economy	12200.00
0005433398074	19427	Economy	12200.00
0005433397814	19427	Economy	12200.00
0005433397815	19427	Economy	12200.00
0005433397888	19427	Economy	12200.00
0005433397935	19427	Economy	12200.00
0005433397866	19427	Economy	12200.00
0005433397892	19427	Economy	12200.00
0005433398050	19427	Economy	13400.00
0005432297289	19427	Economy	13400.00
0005433397770	19427	Economy	13400.00
0005433397857	19427	Economy	12200.00
0005433397843	19427	Economy	12200.00
0005433398067	19427	Economy	12200.00
0005433397865	19427	Economy	12200.00
0005432297290	19427	Economy	12200.00
0005433397687	19427	Economy	12200.00
0005433397751	19427	Economy	12200.00
0005433397875	19427	Economy	12200.00
0005433397954	19427	Economy	12200.00
0005433398015	19427	Economy	12200.00
0005433398080	19427	Economy	12200.00
0005433398032	19427	Economy	12200.00
0005433398040	19427	Economy	12200.00
0005433397884	19427	Economy	12200.00
0005433398073	19427	Economy	12200.00
0005433397783	19427	Economy	12200.00
0005433397861	19427	Economy	12200.00
0005433397838	19427	Economy	12200.00
0005433397878	19427	Economy	12200.00
0005433397929	19427	Economy	12200.00
0005433397860	19427	Economy	12200.00
0005433397778	19427	Economy	12200.00
0005433397894	19427	Economy	12200.00
0005433398168	19427	Economy	12200.00
0005433397779	19427	Economy	12200.00
0005433397459	19427	Economy	12200.00
0005433397885	19427	Economy	12200.00
0005433397893	19427	Economy	12200.00
0005433397934	19427	Economy	12200.00
0005433397949	19427	Economy	12200.00
0005433398072	19427	Economy	12200.00
0005433397981	19427	Economy	12200.00
0005433397872	19427	Economy	12200.00
0005433397895	19427	Economy	12200.00
0005433397943	19427	Economy	12200.00
0005433397890	19427	Economy	12200.00
0005433397828	19427	Economy	12200.00
0005433397750	19427	Economy	12200.00
0005433397821	19427	Economy	12200.00
0005433397953	19427	Economy	12200.00
0005432297291	19427	Economy	12200.00
0005433397910	19427	Economy	12200.00
0005433397816	19427	Economy	12200.00
0005433397858	19427	Economy	12200.00
0005433397782	19427	Economy	12200.00
0005433397950	19427	Economy	12200.00
0005435925359	13134	Business	11300.00
0005435068816	13134	Business	11300.00
0005435068811	13134	Business	11300.00
0005435068411	13134	Business	11300.00
0005435069045	13134	Business	11300.00
0005435925362	13134	Business	11300.00
0005435068856	13134	Business	11300.00
0005435068801	13134	Business	11300.00
0005435069159	13134	Economy	3800.00
0005435068950	13134	Economy	3800.00
0005435068997	13134	Economy	3800.00
0005435068798	13134	Economy	3800.00
0005435068998	13134	Economy	3800.00
0005435068800	13134	Economy	3800.00
0005435068791	13134	Economy	3800.00
0005435068841	13134	Economy	3800.00
0005435068949	13134	Economy	3800.00
0005435068740	13134	Economy	3800.00
0005435068866	13134	Economy	4100.00
0005435068857	13134	Economy	4100.00
0005435068790	13134	Economy	4100.00
0005435068674	13134	Economy	4100.00
0005435068675	13134	Economy	3800.00
0005435068628	13134	Economy	3800.00
0005435068667	13134	Economy	3800.00
0005435925358	13134	Economy	3800.00
0005435068792	13134	Economy	3800.00
0005435068808	13134	Economy	3800.00
0005435068739	13134	Economy	3800.00
0005435925357	13134	Economy	3800.00
0005435069062	13134	Economy	3800.00
0005435068839	13134	Economy	3800.00
0005435068935	13134	Economy	3800.00
0005435068848	13134	Economy	3800.00
0005435068637	13134	Economy	3800.00
0005435068410	13134	Economy	3800.00
0005435068934	13134	Economy	3800.00
0005435925363	13134	Economy	3800.00
0005435069074	13134	Economy	3800.00
0005435068913	13134	Economy	3800.00
0005435068980	13134	Economy	3800.00
0005435925360	13134	Economy	3800.00
0005435068840	13134	Economy	3800.00
0005435925361	13134	Economy	3800.00
0005435068921	13134	Economy	3800.00
0005435068953	13134	Economy	3800.00
0005435068807	13134	Economy	3800.00
0005435068814	13134	Economy	3800.00
0005435925364	13134	Economy	3800.00
0005435068885	13134	Economy	3800.00
0005435069007	13134	Economy	3800.00
0005435068855	13134	Economy	3800.00
0005435068813	13134	Economy	3800.00
0005435068719	13134	Economy	3800.00
0005435068880	13134	Economy	3800.00
0005435068938	13134	Economy	3800.00
0005435068793	13134	Economy	3800.00
0005435068755	13134	Economy	3800.00
0005435068993	13134	Economy	3800.00
0005435068954	13134	Economy	3800.00
0005435068847	13134	Economy	3800.00
0005435068752	13134	Economy	3800.00
0005435068815	13134	Economy	3800.00
0005435068629	13134	Economy	3800.00
0005435068756	13134	Economy	3800.00
0005435068933	13134	Economy	3800.00
0005435068881	13134	Economy	3800.00
0005435068810	13134	Economy	3800.00
0005435068858	13134	Economy	3800.00
0005435068854	13134	Economy	3800.00
0005435069158	13134	Economy	3800.00
0005435068720	13134	Economy	3800.00
0005435068638	13134	Economy	3800.00
0005435069282	15475	Business	11300.00
0005435925217	15475	Business	11300.00
0005435069323	15475	Business	11300.00
0005435069292	15475	Business	11300.00
0005435069285	15475	Business	11300.00
0005435069280	15475	Business	11300.00
0005435069319	15475	Business	11300.00
0005435069288	15475	Business	11300.00
0005435925199	15475	Business	11300.00
0005435069297	15475	Business	11300.00
0005435069272	15475	Economy	3800.00
0005435069302	15475	Economy	3800.00
0005435069322	15475	Economy	3800.00
0005435925230	15475	Economy	3800.00
0005435925196	15475	Economy	3800.00
0005435925194	15475	Economy	3800.00
0005435069284	15475	Economy	3800.00
0005435069309	15475	Economy	4100.00
0005435069305	15475	Economy	4100.00
0005435069291	15475	Economy	4100.00
0005435069314	15475	Economy	3800.00
0005435069318	15475	Economy	3800.00
0005435069294	15475	Economy	3800.00
0005435069316	15475	Economy	3800.00
0005435069320	15475	Economy	3800.00
0005435069313	15475	Economy	3800.00
0005435069298	15475	Economy	3800.00
0005435069303	15475	Economy	3800.00
0005435069301	15475	Economy	3800.00
0005435069277	15475	Economy	3800.00
0005435069321	15475	Economy	3800.00
0005435069287	15475	Economy	3800.00
0005435069290	15475	Economy	3800.00
0005435069278	15475	Economy	3800.00
0005435069274	15475	Economy	3800.00
0005435925195	15475	Economy	3800.00
0005435069293	15475	Economy	3800.00
0005435069300	15475	Economy	3800.00
0005435069295	15475	Economy	3800.00
0005435069307	15475	Economy	3800.00
0005435069279	15475	Economy	3800.00
0005435069286	15475	Economy	3800.00
0005435925200	15475	Economy	3800.00
0005435925153	15475	Economy	3800.00
0005435069276	15475	Economy	3800.00
0005435069317	15475	Economy	3800.00
0005435069311	15475	Economy	3800.00
0005435069283	15475	Economy	3800.00
0005435925236	15475	Economy	3800.00
0005435069296	15475	Economy	3800.00
0005435069306	15475	Economy	3800.00
0005435069299	15475	Economy	3800.00
0005435069312	15475	Economy	3800.00
0005435069310	15475	Economy	3800.00
0005435069315	15475	Economy	3800.00
0005435069289	15475	Economy	3800.00
0005435069304	15475	Economy	3800.00
0005435925229	15475	Economy	3800.00
0005435069273	15475	Economy	3800.00
0005435069275	15475	Economy	3800.00
0005435925235	15475	Economy	3800.00
0005435925205	15475	Economy	3800.00
0005435069281	15475	Economy	3800.00
0005435069308	15475	Economy	3800.00
0005435808271	23189	Economy	27100.00
0005435808265	23189	Economy	27100.00
0005435808276	23189	Economy	27100.00
0005433407522	23189	Economy	24700.00
0005433407547	23189	Economy	24700.00
0005433407553	23189	Economy	24700.00
0005435808279	23189	Economy	24700.00
0005435808269	23189	Economy	24700.00
0005433407523	23189	Economy	24700.00
0005435808272	23189	Economy	24700.00
0005435808263	23189	Economy	24700.00
0005435808277	23189	Economy	24700.00
0005435808275	23189	Economy	24700.00
0005433407548	23189	Economy	24700.00
0005435808264	23189	Economy	24700.00
0005435808273	23189	Economy	24700.00
0005435808270	23189	Economy	24700.00
0005435808281	23189	Economy	24700.00
0005433407549	23189	Economy	24700.00
0005433407550	23189	Economy	24700.00
0005435808266	23189	Economy	24700.00
0005433407532	23189	Economy	24700.00
0005435808268	23189	Economy	24700.00
0005433407515	23189	Economy	24700.00
0005435808282	23189	Economy	24700.00
0005435808280	23189	Economy	24700.00
0005435808278	23189	Economy	24700.00
0005433407511	23189	Economy	24700.00
0005433407508	23189	Economy	24700.00
0005435808274	23189	Economy	24700.00
0005435808267	23189	Economy	24700.00
0005433407514	23189	Economy	24700.00
0005435808283	23189	Economy	24700.00
0005434214772	10732	Business	61300.00
0005434756137	10732	Business	61300.00
0005434214790	10732	Business	61300.00
0005434756192	10732	Business	61300.00
0005434214749	10732	Business	61300.00
0005434214759	10732	Business	61300.00
0005434756176	10732	Business	61300.00
0005434756175	10732	Business	61300.00
0005434756277	10732	Business	61300.00
0005434214761	10732	Economy	20400.00
0005434214751	10732	Economy	20400.00
0005434756303	10732	Economy	20400.00
0005434756080	10732	Economy	20400.00
0005434214768	10732	Economy	20400.00
0005434756206	10732	Economy	20400.00
0005434756225	10732	Economy	20400.00
0005434756278	10732	Economy	20400.00
0005434756189	10732	Economy	20400.00
0005434214787	10732	Economy	20400.00
0005434756208	10732	Economy	22500.00
0005434214756	10732	Economy	22500.00
0005434756147	10732	Economy	22500.00
0005434214765	10732	Economy	22500.00
0005434214771	10732	Economy	20400.00
0005434756194	10732	Economy	22500.00
0005434214760	10732	Economy	20400.00
0005434214769	10732	Economy	20400.00
0005434214755	10732	Economy	20400.00
0005434214789	10732	Economy	20400.00
0005434214745	10732	Economy	20400.00
0005434756226	10732	Economy	20400.00
0005434214786	10732	Economy	20400.00
0005434214783	10732	Economy	20400.00
0005434756207	10732	Economy	20400.00
0005434214774	10732	Economy	20400.00
0005434214775	10732	Economy	20400.00
0005434214777	10732	Economy	20400.00
0005434756281	10732	Economy	20400.00
0005434756234	10732	Economy	20400.00
0005434214779	10732	Economy	20400.00
0005434214780	10732	Economy	20400.00
0005434214757	10732	Economy	20400.00
0005434214747	10732	Economy	20400.00
0005434214764	10732	Economy	20400.00
0005434214776	10732	Economy	20400.00
0005434214791	10732	Economy	20400.00
0005434214773	10732	Economy	20400.00
0005434756214	10732	Economy	20400.00
0005434214781	10732	Economy	20400.00
0005434756165	10732	Economy	20400.00
0005434214767	10732	Economy	20400.00
0005434214766	10732	Economy	20400.00
0005434214746	10732	Economy	20400.00
0005434756132	10732	Economy	20400.00
0005434214763	10732	Economy	20400.00
0005434756199	10732	Economy	20400.00
0005434756213	10732	Economy	20400.00
0005434214784	10732	Economy	20400.00
0005434756310	10732	Economy	20400.00
0005434756166	10732	Economy	20400.00
0005434214770	10732	Economy	20400.00
0005434214785	10732	Economy	20400.00
0005434214788	10732	Economy	20400.00
0005434214754	10732	Economy	20400.00
0005434214778	10732	Economy	20400.00
0005434756224	10732	Economy	20400.00
0005434756304	10732	Economy	20400.00
0005434756212	10732	Economy	20400.00
0005434756291	10732	Economy	20400.00
0005434756204	10732	Economy	20400.00
0005434756131	10732	Economy	20400.00
0005434214752	10732	Economy	20400.00
0005434214792	10732	Economy	20400.00
0005434756123	10732	Economy	20400.00
0005434756198	10732	Economy	20400.00
0005434756081	10732	Economy	20400.00
0005434756309	10732	Economy	20400.00
0005434214758	10732	Economy	20400.00
0005434756203	10732	Economy	20400.00
0005434214750	10732	Economy	20400.00
0005434214753	10732	Economy	20400.00
0005434214762	10732	Economy	20400.00
0005434756220	10732	Economy	20400.00
0005434214782	10732	Economy	20400.00
0005434756241	10732	Economy	20400.00
0005434214748	10732	Economy	20400.00
0005434756574	28707	Business	61300.00
0005434756592	28707	Business	61300.00
0005434214350	28707	Business	61300.00
0005434756595	28707	Business	61300.00
0005434214457	28707	Business	61300.00
0005434756612	28707	Business	61300.00
0005434756580	28707	Business	61300.00
0005434756567	28707	Business	61300.00
0005434214404	28707	Business	61300.00
0005434756571	28707	Business	61300.00
0005434756591	28707	Business	61300.00
0005434214224	28707	Economy	20400.00
0005434756585	28707	Economy	20400.00
0005434214403	28707	Economy	20400.00
0005434756584	28707	Economy	20400.00
0005434756577	28707	Economy	20400.00
0005434214239	28707	Economy	20400.00
0005434214277	28707	Economy	20400.00
0005434756578	28707	Economy	20400.00
0005434214262	28707	Economy	20400.00
0005434214331	28707	Economy	20400.00
0005434756587	28707	Economy	22500.00
0005434756598	28707	Economy	22500.00
0005434214206	28707	Economy	22500.00
0005434214251	28707	Economy	22500.00
0005434756607	28707	Economy	22500.00
0005434756594	28707	Economy	20400.00
0005434214238	28707	Economy	20400.00
0005434214082	28707	Economy	20400.00
0005434214242	28707	Economy	20400.00
0005434756610	28707	Economy	20400.00
0005434214241	28707	Economy	20400.00
0005434214378	28707	Economy	20400.00
0005434214284	28707	Economy	20400.00
0005434756583	28707	Economy	20400.00
0005434756597	28707	Economy	20400.00
0005434214268	28707	Economy	20400.00
0005434214266	28707	Economy	20400.00
0005434756593	28707	Economy	20400.00
0005434214374	28707	Economy	20400.00
0005434214116	28707	Economy	20400.00
0005434214267	28707	Economy	20400.00
0005434756570	28707	Economy	20400.00
0005434214215	28707	Economy	20400.00
0005434756601	28707	Economy	20400.00
0005434214337	28707	Economy	20400.00
0005434756573	28707	Economy	20400.00
0005434214306	28707	Economy	20400.00
0005434756586	28707	Economy	20400.00
0005434214319	28707	Economy	20400.00
0005434756602	28707	Economy	20400.00
0005434214375	28707	Economy	20400.00
0005434756581	28707	Economy	20400.00
0005434214240	28707	Economy	20400.00
0005434214288	28707	Economy	20400.00
0005434214314	28707	Economy	20400.00
0005434756609	28707	Economy	20400.00
0005434214228	28707	Economy	20400.00
0005434756572	28707	Economy	20400.00
0005434756589	28707	Economy	20400.00
0005434756608	28707	Economy	20400.00
0005434214373	28707	Economy	20400.00
0005434214351	28707	Economy	20400.00
0005434214409	28707	Economy	20400.00
0005434756596	28707	Economy	20400.00
0005434756576	28707	Economy	20400.00
0005434214081	28707	Economy	20400.00
0005434214166	28707	Economy	20400.00
0005434756569	28707	Economy	20400.00
0005434756611	28707	Economy	20400.00
0005434214276	28707	Economy	20400.00
0005434214290	28707	Economy	20400.00
0005434756590	28707	Economy	20400.00
0005434756600	28707	Economy	20400.00
0005434756579	28707	Economy	20400.00
0005434756588	28707	Economy	20400.00
0005434214425	28707	Economy	20400.00
0005434756603	28707	Economy	20400.00
0005434214196	28707	Economy	20400.00
0005434756606	28707	Economy	20400.00
0005434756568	28707	Economy	20400.00
0005434214308	28707	Economy	20400.00
0005434214381	28707	Economy	20400.00
0005434756605	28707	Economy	20400.00
0005434214205	28707	Economy	20400.00
0005434214456	28707	Economy	20400.00
0005434756582	28707	Economy	20400.00
0005434214455	28707	Economy	20400.00
0005434756599	28707	Economy	20400.00
0005434214289	28707	Economy	20400.00
0005434756575	28707	Economy	20400.00
0005434214258	28707	Economy	20400.00
0005434756604	28707	Economy	20400.00
0005432125489	5432	Business	29500.00
0005435040120	5432	Business	29500.00
0005434229327	5432	Business	29500.00
0005435007155	5432	Business	29500.00
0005435040095	5432	Business	29500.00
0005434229287	5432	Business	29500.00
0005435040078	5432	Business	29500.00
0005432125491	5432	Business	29500.00
0005435040122	5432	Business	29500.00
0005434229198	5432	Business	29500.00
0005435007150	5432	Business	29500.00
0005435040077	5432	Business	29500.00
0005435007154	5432	Economy	9800.00
0005435040081	5432	Economy	9800.00
0005435007145	5432	Economy	9800.00
0005435040085	5432	Economy	9800.00
0005434229297	5432	Economy	9800.00
0005435007140	5432	Economy	9800.00
0005435040108	5432	Economy	9800.00
0005435007138	5432	Economy	9800.00
0005435007137	5432	Economy	9800.00
0005435040068	5432	Economy	9800.00
0005435007139	5432	Economy	9800.00
0005434229317	5432	Economy	9800.00
0005435007160	5432	Economy	9800.00
0005432125488	5432	Economy	9800.00
0005435040089	5432	Economy	9800.00
0005435007149	5432	Economy	9800.00
0005435007146	5432	Economy	9800.00
0005435040114	5432	Economy	9800.00
0005435040128	5432	Economy	9800.00
0005435007151	5432	Economy	9800.00
0005435040111	5432	Economy	9800.00
0005435040106	5432	Economy	9800.00
0005432125486	5432	Economy	9800.00
0005435040071	5432	Economy	9800.00
0005435040072	5432	Economy	9800.00
0005435040094	5432	Economy	9800.00
0005434229165	5432	Economy	9800.00
0005435007157	5432	Economy	9800.00
0005432125492	5432	Economy	9800.00
0005435007142	5432	Economy	9800.00
0005435043288	5432	Economy	9800.00
0005435040099	5432	Economy	9800.00
0005434229326	5432	Economy	9800.00
0005435040067	5432	Economy	9800.00
0005434229343	5432	Economy	9800.00
0005434229316	5432	Economy	9800.00
0005435040126	5432	Economy	9800.00
0005435040113	5432	Economy	9800.00
0005435007152	5432	Economy	9800.00
0005435040086	5432	Economy	10800.00
0005435040101	5432	Economy	10800.00
0005435040082	5432	Economy	10800.00
0005435040117	5432	Economy	10800.00
0005435040131	5432	Economy	10800.00
0005435040070	5432	Economy	10800.00
0005435040103	5432	Economy	9800.00
0005435040119	5432	Economy	9800.00
0005435007148	5432	Economy	9800.00
0005435040100	5432	Economy	9800.00
0005435040112	5432	Economy	9800.00
0005435040102	5432	Economy	9800.00
0005434229378	5432	Economy	9800.00
0005435007156	5432	Economy	9800.00
0005435007153	5432	Economy	9800.00
0005434229331	5432	Economy	9800.00
0005434229284	5432	Economy	9800.00
0005435040118	5432	Economy	9800.00
0005435007158	5432	Economy	9800.00
0005435040092	5432	Economy	9800.00
0005435040109	5432	Economy	9800.00
0005434229274	5432	Economy	9800.00
0005434229307	5432	Economy	9800.00
0005435040123	5432	Economy	9800.00
0005435040115	5432	Economy	9800.00
0005435040080	5432	Economy	9800.00
0005435040084	5432	Economy	9800.00
0005435040124	5432	Economy	9800.00
0005434229344	5432	Economy	9800.00
0005435040074	5432	Economy	9800.00
0005435040107	5432	Economy	9800.00
0005435040073	5432	Economy	9800.00
0005435040104	5432	Economy	9800.00
0005435040075	5432	Economy	9800.00
0005434229278	5432	Economy	9800.00
0005435040097	5432	Economy	9800.00
0005435040076	5432	Economy	9800.00
0005435040083	5432	Economy	9800.00
0005435040096	5432	Economy	9800.00
0005435043289	5432	Economy	9800.00
0005434229347	5432	Economy	9800.00
0005435040105	5432	Economy	9800.00
0005435040127	5432	Economy	9800.00
0005434229269	5432	Economy	9800.00
0005435040121	5432	Economy	9800.00
0005435040091	5432	Economy	9800.00
0005435040129	5432	Economy	9800.00
0005435040069	5432	Economy	9800.00
0005435040110	5432	Economy	9800.00
0005434229290	5432	Economy	9800.00
0005435040116	5432	Economy	9800.00
0005435040098	5432	Economy	9800.00
0005435007144	5432	Economy	9800.00
0005432125487	5432	Economy	9800.00
0005435040088	5432	Economy	9800.00
0005435007143	5432	Economy	9800.00
0005434229289	5432	Economy	9800.00
0005435040130	5432	Economy	9800.00
0005434229273	5432	Economy	9800.00
0005435040093	5432	Economy	9800.00
0005435040125	5432	Economy	9800.00
0005435040079	5432	Economy	9800.00
0005432125490	5432	Economy	9800.00
0005434229333	5432	Economy	9800.00
0005435040065	5432	Economy	9800.00
0005434229281	5432	Economy	9800.00
0005435040066	5432	Economy	9800.00
0005435007141	5432	Economy	9800.00
0005432125485	5432	Economy	9800.00
0005435040090	5432	Economy	9800.00
0005435007147	5432	Economy	9800.00
0005435042865	5432	Economy	9800.00
0005435040087	5432	Economy	9800.00
0005434229332	5432	Economy	9800.00
0005435007159	5432	Economy	9800.00
0005434229272	5432	Economy	9800.00
0005434229484	12975	Business	29500.00
0005432304420	12975	Business	29500.00
0005435039608	12975	Business	29500.00
0005435006833	12975	Business	29500.00
0005435006969	12975	Business	29500.00
0005435039289	12975	Business	29500.00
0005435006905	12975	Business	29500.00
0005435039711	12975	Business	29500.00
0005435039221	12975	Business	29500.00
0005435039359	12975	Business	29500.00
0005435007012	12975	Business	29500.00
0005435039592	12975	Business	29500.00
0005435039591	12975	Economy	9800.00
0005435039471	12975	Economy	9800.00
0005435006958	12975	Economy	9800.00
0005435039568	12975	Economy	9800.00
0005435039598	12975	Economy	9800.00
0005435042848	12975	Economy	9800.00
0005435039531	12975	Economy	9800.00
0005435039495	12975	Economy	9800.00
0005432304419	12975	Economy	9800.00
0005434229489	12975	Economy	9800.00
0005435006832	12975	Economy	9800.00
0005435039290	12975	Economy	9800.00
0005435039467	12975	Economy	9800.00
0005435006936	12975	Economy	9800.00
0005435039597	12975	Economy	9800.00
0005435039857	12975	Economy	9800.00
0005435039487	12975	Economy	9800.00
0005435006994	12975	Economy	9800.00
0005434229482	12975	Economy	9800.00
0005434229490	12975	Economy	9800.00
0005435006871	12975	Economy	9800.00
0005435006866	12975	Economy	9800.00
0005435042842	12975	Economy	9800.00
0005435039544	12975	Economy	9800.00
0005435006933	12975	Economy	9800.00
0005435039462	12975	Economy	9800.00
0005435039723	12975	Economy	9800.00
0005435006926	12975	Economy	9800.00
0005434229479	12975	Economy	9800.00
0005435007013	12975	Economy	9800.00
0005435039699	12975	Economy	9800.00
0005435006976	12975	Economy	9800.00
0005434229495	12975	Economy	9800.00
0005435039466	12975	Economy	9800.00
0005435039851	12975	Economy	9800.00
0005434229477	12975	Economy	9800.00
0005435039508	12975	Economy	9800.00
0005434229487	12975	Economy	9800.00
0005435039484	12975	Economy	9800.00
0005435006925	12975	Economy	10800.00
0005435006977	12975	Economy	10800.00
0005435039410	12975	Economy	10800.00
0005434229485	12975	Economy	10800.00
0005435039688	12975	Economy	10800.00
0005435039488	12975	Economy	9800.00
0005432304416	12975	Economy	10800.00
0005435039340	12975	Economy	9800.00
0005435039414	12975	Economy	9800.00
0005435039499	12975	Economy	9800.00
0005435039714	12975	Economy	9800.00
0005434229497	12975	Economy	9800.00
0005434229494	12975	Economy	9800.00
0005434229481	12975	Economy	9800.00
0005432304417	12975	Economy	9800.00
0005435006972	12975	Economy	9800.00
0005434229478	12975	Economy	9800.00
0005435039656	12975	Economy	9800.00
0005435039455	12975	Economy	9800.00
0005435039658	12975	Economy	9800.00
0005434229480	12975	Economy	9800.00
0005435039485	12975	Economy	9800.00
0005435039541	12975	Economy	9800.00
0005434229496	12975	Economy	9800.00
0005435039498	12975	Economy	9800.00
0005435039434	12975	Economy	9800.00
0005435006891	12975	Economy	9800.00
0005434229475	12975	Economy	9800.00
0005435006901	12975	Economy	9800.00
0005435039497	12975	Economy	9800.00
0005435039587	12975	Economy	9800.00
0005435006971	12975	Economy	9800.00
0005435039596	12975	Economy	9800.00
0005434229476	12975	Economy	9800.00
0005434229488	12975	Economy	9800.00
0005435039291	12975	Economy	9800.00
0005435007003	12975	Economy	9800.00
0005435039609	12975	Economy	9800.00
0005435039512	12975	Economy	9800.00
0005435039490	12975	Economy	9800.00
0005435006993	12975	Economy	9800.00
0005434229493	12975	Economy	9800.00
0005435006986	12975	Economy	9800.00
0005435039510	12975	Economy	9800.00
0005434229491	12975	Economy	9800.00
0005435039444	12975	Economy	9800.00
0005435039435	12975	Economy	9800.00
0005434229486	12975	Economy	9800.00
0005435039339	12975	Economy	9800.00
0005435039657	12975	Economy	9800.00
0005435039465	12975	Economy	9800.00
0005435039540	12975	Economy	9800.00
0005435006978	12975	Economy	9800.00
0005435039660	12975	Economy	9800.00
0005435006964	12975	Economy	9800.00
0005435039595	12975	Economy	9800.00
0005435006947	12975	Economy	9800.00
0005434229483	12975	Economy	9800.00
0005435039689	12975	Economy	9800.00
0005432304418	12975	Economy	9800.00
0005435039605	12975	Economy	9800.00
0005434229492	12975	Economy	9800.00
0005435039713	12975	Economy	9800.00
0005435039715	12975	Economy	9800.00
0005435043282	12975	Economy	9800.00
0005435039441	12975	Economy	9800.00
0005435039850	12975	Economy	9800.00
0005435039712	12975	Economy	9800.00
0005435006946	12975	Economy	9800.00
0005435006902	12975	Economy	9800.00
0005435006892	12975	Economy	9800.00
0005435039511	12975	Economy	9800.00
0005435039486	12975	Economy	9800.00
0005435039411	12975	Economy	9800.00
0005435039661	12975	Economy	9800.00
0005435039358	12975	Economy	9800.00
0005435039433	12975	Economy	9800.00
0005435039556	12975	Economy	9800.00
0005435554154	14906	Business	52900.00
0005435902591	14906	Business	52900.00
0005434426747	14906	Business	52900.00
0005434411796	14906	Business	52900.00
0005435554184	14906	Business	52900.00
0005432188621	14906	Business	52900.00
0005434426731	14906	Business	52900.00
0005434426733	14906	Economy	17600.00
0005435902561	14906	Economy	17600.00
0005434426724	14906	Economy	17600.00
0005435554167	14906	Economy	17600.00
0005434426741	14906	Economy	17600.00
0005434426740	14906	Economy	17600.00
0005434426730	14906	Economy	17600.00
0005435902720	14906	Economy	17600.00
0005434426721	14906	Economy	19400.00
0005434426735	14906	Economy	19400.00
0005434426727	14906	Economy	17600.00
0005434426743	14906	Economy	17600.00
0005432188622	14906	Economy	17600.00
0005434426739	14906	Economy	17600.00
0005434426725	14906	Economy	17600.00
0005434411797	14906	Economy	17600.00
0005434426720	14906	Economy	17600.00
0005435554157	14906	Economy	17600.00
0005434426734	14906	Economy	17600.00
0005434426745	14906	Economy	17600.00
0005434426722	14906	Economy	17600.00
0005434426737	14906	Economy	17600.00
0005434426744	14906	Economy	17600.00
0005435902626	14906	Economy	17600.00
0005435902599	14906	Economy	17600.00
0005434426738	14906	Economy	17600.00
0005434426729	14906	Economy	17600.00
0005435554185	14906	Economy	17600.00
0005434426726	14906	Economy	17600.00
0005434426719	14906	Economy	17600.00
0005434426742	14906	Economy	17600.00
0005435554159	14906	Economy	17600.00
0005435554180	14906	Economy	17600.00
0005434426732	14906	Economy	17600.00
0005434411794	14906	Economy	17600.00
0005435554155	14906	Economy	17600.00
0005434426723	14906	Economy	17600.00
0005435902673	14906	Economy	17600.00
0005434411795	14906	Economy	17600.00
0005434426736	14906	Economy	17600.00
0005434426728	14906	Economy	17600.00
0005435902672	14906	Economy	17600.00
0005435902539	14906	Economy	17600.00
0005435902590	14906	Economy	17600.00
0005435902692	14906	Economy	17600.00
0005434426746	14906	Economy	17600.00
0005435902700	14906	Economy	17600.00
0005435554212	20210	Business	52900.00
0005434426545	20210	Business	52900.00
0005434426477	20210	Business	52900.00
0005434426610	20210	Business	52900.00
0005434426570	20210	Business	52900.00
0005434426654	20210	Business	52900.00
0005435554215	20210	Economy	17600.00
0005434426542	20210	Economy	17600.00
0005435902787	20210	Economy	17600.00
0005434426555	20210	Economy	19400.00
0005434426487	20210	Economy	19400.00
0005434426435	20210	Economy	17600.00
0005435902793	20210	Economy	17600.00
0005434426523	20210	Economy	17600.00
0005434426587	20210	Economy	17600.00
0005434426492	20210	Economy	17600.00
0005435902802	20210	Economy	17600.00
0005435902797	20210	Economy	17600.00
0005435554214	20210	Economy	17600.00
0005434411765	20210	Economy	17600.00
0005434426378	20210	Economy	17600.00
0005435902799	20210	Economy	17600.00
0005434426395	20210	Economy	17600.00
0005435902791	20210	Economy	17600.00
0005432059515	20210	Economy	17600.00
0005434426618	20210	Economy	17600.00
0005435902792	20210	Economy	17600.00
0005435902789	20210	Economy	17600.00
0005434426568	20210	Economy	17600.00
0005434426566	20210	Economy	17600.00
0005434426436	20210	Economy	17600.00
0005434426473	20210	Economy	17600.00
0005434426491	20210	Economy	17600.00
0005435902785	20210	Economy	17600.00
0005435902801	20210	Economy	17600.00
0005434426571	20210	Economy	17600.00
0005435902794	20210	Economy	17600.00
0005435554213	20210	Economy	17600.00
0005434426510	20210	Economy	17600.00
0005435902800	20210	Economy	17600.00
0005435902803	20210	Economy	17600.00
0005435902786	20210	Economy	17600.00
0005434426653	20210	Economy	17600.00
0005434426569	20210	Economy	17600.00
0005435902790	20210	Economy	17600.00
0005435554216	20210	Economy	17600.00
0005435554217	20210	Economy	17600.00
0005434426522	20210	Economy	17600.00
0005435902795	20210	Economy	17600.00
0005434426521	20210	Economy	17600.00
0005434411747	20210	Economy	17600.00
0005435902788	20210	Economy	17600.00
0005435902796	20210	Economy	17600.00
0005434426588	20210	Economy	17600.00
0005435902798	20210	Economy	17600.00
0005433726084	21656	Business	91700.00
0005433726064	21656	Business	91700.00
0005433726078	21656	Business	91700.00
0005433726080	21656	Business	91700.00
0005433726082	21656	Economy	30600.00
0005433726074	21656	Economy	30600.00
0005433726083	21656	Economy	30600.00
0005433726088	21656	Economy	30600.00
0005433726075	21656	Economy	30600.00
0005433726085	21656	Economy	33600.00
0005433726090	21656	Economy	30600.00
0005433726065	21656	Economy	30600.00
0005433726089	21656	Economy	30600.00
0005433726087	21656	Economy	30600.00
0005433726092	21656	Economy	30600.00
0005433726073	21656	Economy	30600.00
0005433726077	21656	Economy	30600.00
0005433726081	21656	Economy	30600.00
0005433726091	21656	Economy	30600.00
0005433434591	26537	Business	18500.00
0005435982499	26537	Business	18500.00
0005432300286	26537	Business	18500.00
0005432300289	26537	Business	18500.00
0005433434606	26537	Business	18500.00
0005435982491	26537	Business	18500.00
0005435982487	26537	Business	18500.00
0005434270205	26537	Business	18500.00
0005434273065	26537	Business	18500.00
0005435982514	26537	Business	18500.00
0005433434498	26537	Business	18500.00
0005434270196	26537	Economy	6200.00
0005435982488	26537	Economy	6200.00
0005433434667	26537	Economy	6200.00
0005433434568	26537	Economy	6200.00
0005435982507	26537	Economy	6200.00
0005435982490	26537	Economy	6200.00
0005435982512	26537	Economy	6200.00
0005433434626	26537	Economy	6200.00
0005432300285	26537	Economy	6200.00
0005435982485	26537	Economy	6800.00
0005435982509	26537	Economy	6800.00
0005433434590	26537	Economy	6800.00
0005434270190	26537	Economy	6800.00
0005433434593	26537	Economy	6800.00
0005434273066	26537	Economy	6200.00
0005432300290	26537	Economy	6200.00
0005433434497	26537	Economy	6200.00
0005435982520	26537	Economy	6200.00
0005433434458	26537	Economy	6200.00
0005433434564	26537	Economy	6200.00
0005435982526	26537	Economy	6200.00
0005435982498	26537	Economy	6200.00
0005433434524	26537	Economy	6200.00
0005435982500	26537	Economy	6200.00
0005435982515	26537	Economy	6200.00
0005433434480	26537	Economy	6200.00
0005435982516	26537	Economy	6200.00
0005435982494	26537	Economy	6200.00
0005433434565	26537	Economy	6200.00
0005435982505	26537	Economy	6200.00
0005433434479	26537	Economy	6200.00
0005433434589	26537	Economy	6200.00
0005433434492	26537	Economy	6200.00
0005433434514	26537	Economy	6200.00
0005434270198	26537	Economy	6200.00
0005434270197	26537	Economy	6200.00
0005435982501	26537	Economy	6200.00
0005433434499	26537	Economy	6200.00
0005435982503	26537	Economy	6200.00
0005434270204	26537	Economy	6200.00
0005435982496	26537	Economy	6200.00
0005435982521	26537	Economy	6200.00
0005435982502	26537	Economy	6200.00
0005432300288	26537	Economy	6200.00
0005432300287	26537	Economy	6200.00
0005433434592	26537	Economy	6200.00
0005435982524	26537	Economy	6200.00
0005433434576	26537	Economy	6200.00
0005434270199	26537	Economy	6200.00
0005433434588	26537	Economy	6200.00
0005435982497	26537	Economy	6200.00
0005435982525	26537	Economy	6200.00
0005435982513	26537	Economy	6200.00
0005435982518	26537	Economy	6200.00
0005435982508	26537	Economy	6200.00
0005435982489	26537	Economy	6200.00
0005435982517	26537	Economy	6200.00
0005435982522	26537	Economy	6200.00
0005433434566	26537	Economy	6200.00
0005435982486	26537	Economy	6200.00
0005435982493	26537	Economy	6200.00
0005433434523	26537	Economy	6200.00
0005433434515	26537	Economy	6200.00
0005435982511	26537	Economy	6200.00
0005435982495	26537	Economy	6200.00
0005435982492	26537	Economy	6200.00
0005433434607	26537	Economy	6200.00
0005433434625	26537	Economy	6200.00
0005435982519	26537	Economy	6200.00
0005433434559	26537	Economy	6200.00
0005435982510	26537	Economy	6200.00
0005435982504	26537	Economy	6200.00
0005435982523	26537	Economy	6200.00
0005433434567	26537	Economy	6200.00
0005433434518	26537	Economy	6200.00
0005435982506	26537	Economy	6200.00
0005435982184	26701	Business	18500.00
0005435982156	26701	Business	18500.00
0005433434839	26701	Business	18500.00
0005433434838	26701	Business	18500.00
0005433434836	26701	Business	18500.00
0005435982192	26701	Business	18500.00
0005432051145	26701	Business	18500.00
0005435982108	26701	Business	18500.00
0005435982023	26701	Business	18500.00
0005434271323	26701	Business	18500.00
0005435982215	26701	Business	18500.00
0005435982135	26701	Economy	6200.00
0005435982187	26701	Economy	6200.00
0005434270217	26701	Economy	6200.00
0005435982131	26701	Economy	6200.00
0005435982163	26701	Economy	6200.00
0005435982095	26701	Economy	6200.00
0005435982222	26701	Economy	6200.00
0005433434815	26701	Economy	6200.00
0005435982109	26701	Economy	6200.00
0005433434840	26701	Economy	6800.00
0005433434830	26701	Economy	6800.00
0005435982185	26701	Economy	6800.00
0005435982133	26701	Economy	6800.00
0005435982391	26701	Economy	6200.00
0005433434823	26701	Economy	6200.00
0005435982026	26701	Economy	6200.00
0005433434819	26701	Economy	6200.00
0005433434820	26701	Economy	6200.00
0005434271322	26701	Economy	6200.00
0005432051144	26701	Economy	6200.00
0005435982099	26701	Economy	6200.00
0005435982162	26701	Economy	6200.00
0005435982153	26701	Economy	6200.00
0005435982116	26701	Economy	6200.00
0005433434824	26701	Economy	6200.00
0005433434821	26701	Economy	6200.00
0005435982194	26701	Economy	6200.00
0005433434817	26701	Economy	6200.00
0005435982137	26701	Economy	6200.00
0005432051143	26701	Economy	6200.00
0005433434818	26701	Economy	6200.00
0005434270218	26701	Economy	6200.00
0005435982193	26701	Economy	6200.00
0005433434816	26701	Economy	6200.00
0005435982003	26701	Economy	6200.00
0005433434831	26701	Economy	6200.00
0005435982165	26701	Economy	6200.00
0005435982188	26701	Economy	6200.00
0005435982121	26701	Economy	6200.00
0005435982138	26701	Economy	6200.00
0005433434822	26701	Economy	6200.00
0005435982065	26701	Economy	6200.00
0005433434832	26701	Economy	6200.00
0005434269114	26701	Economy	6200.00
0005435982092	26701	Economy	6200.00
0005433434841	26701	Economy	6200.00
0005435982231	26701	Economy	6200.00
0005435982120	26701	Economy	6200.00
0005433434825	26701	Economy	6200.00
0005435982055	26701	Economy	6200.00
0005433434835	26701	Economy	6200.00
0005433434813	26701	Economy	6200.00
0005435982132	26701	Economy	6200.00
0005435982230	26701	Economy	6200.00
0005433434834	26701	Economy	6200.00
0005435982094	26701	Economy	6200.00
0005435982148	26701	Economy	6200.00
0005435982186	26701	Economy	6200.00
0005435982178	26701	Economy	6200.00
0005435982392	26701	Economy	6200.00
0005435982195	26701	Economy	6200.00
0005435982189	26701	Economy	6200.00
0005435982122	26701	Economy	6200.00
0005433434827	26701	Economy	6200.00
0005435981992	26701	Economy	6200.00
0005435982091	26701	Economy	6200.00
0005433434828	26701	Economy	6200.00
0005433434826	26701	Economy	6200.00
0005433434829	26701	Economy	6200.00
0005435982136	26701	Economy	6200.00
0005434269115	26701	Economy	6200.00
0005435982144	26701	Economy	6200.00
0005433434814	26701	Economy	6200.00
0005435982145	26701	Economy	6200.00
0005433434833	26701	Economy	6200.00
0005433434837	26701	Economy	6200.00
0005435982134	26701	Economy	6200.00
0005432584171	3188	Economy	11100.00
0005432584174	3188	Economy	11100.00
0005432584173	3188	Economy	11100.00
0005432584164	3188	Economy	10100.00
0005432858014	3188	Economy	10100.00
0005432584159	3188	Economy	10100.00
0005432584162	3188	Economy	10100.00
0005432584158	3188	Economy	10100.00
0005432858012	3188	Economy	10100.00
0005432857999	3188	Economy	10100.00
0005432584151	3188	Economy	10100.00
0005432584160	3188	Economy	10100.00
0005432858045	3188	Economy	10100.00
0005432216287	3188	Economy	10100.00
0005432584152	3188	Economy	10100.00
0005432584167	3188	Economy	10100.00
0005432584153	3188	Economy	10100.00
0005432584163	3188	Economy	10100.00
0005432858020	3188	Economy	10100.00
0005432584172	3188	Economy	10100.00
0005432584154	3188	Economy	10100.00
0005432858010	3188	Economy	10100.00
0005432858006	3188	Economy	10100.00
0005432858015	3188	Economy	10100.00
0005432584168	3188	Economy	10100.00
0005432858005	3188	Economy	10100.00
0005432584166	3188	Economy	10100.00
0005432584157	3188	Economy	10100.00
0005432858011	3188	Economy	10100.00
0005432216286	3188	Economy	10100.00
0005432858044	3188	Economy	10100.00
0005432584155	3188	Economy	10100.00
0005432584156	3188	Economy	10100.00
0005432584169	3188	Economy	10100.00
0005432216288	3188	Economy	10100.00
0005432584161	3188	Economy	10100.00
0005432584175	3188	Economy	10100.00
0005432584170	3188	Economy	10100.00
0005432858004	3188	Economy	10100.00
0005432584165	3188	Economy	10100.00
0005432216285	3188	Economy	10100.00
0005432583916	31513	Economy	11100.00
0005432858127	31513	Economy	11100.00
0005432584021	31513	Economy	10100.00
0005432858132	31513	Economy	10100.00
0005432858123	31513	Economy	10100.00
0005432858133	31513	Economy	10100.00
0005432858126	31513	Economy	10100.00
0005432583872	31513	Economy	10100.00
0005432858128	31513	Economy	10100.00
0005432583970	31513	Economy	10100.00
0005432858134	31513	Economy	10100.00
0005432583958	31513	Economy	10100.00
0005432858131	31513	Economy	10100.00
0005432584000	31513	Economy	10100.00
0005432858125	31513	Economy	10100.00
0005432583941	31513	Economy	10100.00
0005432583868	31513	Economy	10100.00
0005432583917	31513	Economy	10100.00
0005432584019	31513	Economy	10100.00
0005432583960	31513	Economy	10100.00
0005432583867	31513	Economy	10100.00
0005432583972	31513	Economy	10100.00
0005432583871	31513	Economy	10100.00
0005432583959	31513	Economy	10100.00
0005432583942	31513	Economy	10100.00
0005432858130	31513	Economy	10100.00
0005432858129	31513	Economy	10100.00
0005432584013	31513	Economy	10100.00
0005432583971	31513	Economy	10100.00
0005432583869	31513	Economy	10100.00
0005432858124	31513	Economy	10100.00
0005432583973	31513	Economy	10100.00
0005434943396	902	Economy	8300.00
0005434943401	902	Economy	7500.00
0005434943397	902	Economy	7500.00
0005434943394	902	Economy	7500.00
0005433255111	902	Economy	7500.00
0005434943400	902	Economy	7500.00
0005433255098	902	Economy	7500.00
0005433255084	902	Economy	7500.00
0005434943402	902	Economy	7500.00
0005434943393	902	Economy	7500.00
0005433255097	902	Economy	7500.00
0005434943398	902	Economy	7500.00
0005434943399	902	Economy	7500.00
0005434943395	902	Economy	7500.00
0005434943354	16245	Economy	8300.00
0005434943355	16245	Economy	8300.00
0005433255148	16245	Economy	7500.00
0005433255146	16245	Economy	7500.00
0005433255149	16245	Economy	7500.00
0005434943344	16245	Economy	7500.00
0005434943347	16245	Economy	7500.00
0005434943323	16245	Economy	7500.00
0005434943343	16245	Economy	7500.00
0005433255147	16245	Economy	7500.00
0005433811625	14358	Economy	4400.00
0005433811631	14358	Economy	4400.00
0005433811624	14358	Economy	4400.00
0005433811628	14358	Economy	4400.00
0005435653248	21777	Business	9800.00
0005433367750	21777	Business	9800.00
0005433367672	21777	Business	9800.00
0005433367748	21777	Business	9800.00
0005433367711	21777	Business	9800.00
0005435653251	21777	Business	9800.00
0005433367718	21777	Business	9800.00
0005433367855	21777	Business	9800.00
0005433367770	21777	Business	9800.00
0005433367790	21777	Business	9800.00
0005433367731	21777	Economy	3300.00
0005433367659	21777	Economy	3300.00
0005435653242	21777	Economy	3300.00
0005433367758	21777	Economy	3300.00
0005435653244	21777	Economy	3300.00
0005433367734	21777	Economy	3300.00
0005433367733	21777	Economy	3300.00
0005433367505	21777	Economy	3300.00
0005433367673	21777	Economy	3300.00
0005433367817	21777	Economy	3600.00
0005435653245	21777	Economy	3600.00
0005435653257	21777	Economy	3600.00
0005433367751	21777	Economy	3600.00
0005433367776	21777	Economy	3300.00
0005435653254	21777	Economy	3300.00
0005433367506	21777	Economy	3300.00
0005433367717	21777	Economy	3300.00
0005433367693	21777	Economy	3300.00
0005433367604	21777	Economy	3300.00
0005433367691	21777	Economy	3300.00
0005433367712	21777	Economy	3300.00
0005433367703	21777	Economy	3300.00
0005433367682	21777	Economy	3300.00
0005435653241	21777	Economy	3300.00
0005433367732	21777	Economy	3300.00
0005433367605	21777	Economy	3300.00
0005433367808	21777	Economy	3300.00
0005433367766	21777	Economy	3300.00
0005435653253	21777	Economy	3300.00
0005435653247	21777	Economy	3300.00
0005433367724	21777	Economy	3300.00
0005435653255	21777	Economy	3300.00
0005433367856	21777	Economy	3300.00
0005433367753	21777	Economy	3300.00
0005435653260	21777	Economy	3300.00
0005433367694	21777	Economy	3300.00
0005435653258	21777	Economy	3300.00
0005433367775	21777	Economy	3300.00
0005433367656	21777	Economy	3300.00
0005433367683	21777	Economy	3300.00
0005433367853	21777	Economy	3300.00
0005435653256	21777	Economy	3300.00
0005433367692	21777	Economy	3300.00
0005433367729	21777	Economy	3300.00
0005435653261	21777	Economy	3300.00
0005433367769	21777	Economy	3300.00
0005433367765	21777	Economy	3300.00
0005435653243	21777	Economy	3300.00
0005433367789	21777	Economy	3300.00
0005433367574	21777	Economy	3300.00
0005435653252	21777	Economy	3300.00
0005435653238	21777	Economy	3300.00
0005435653246	21777	Economy	3300.00
0005435653239	21777	Economy	3300.00
0005435653259	21777	Economy	3300.00
0005433367679	21777	Economy	3300.00
0005435653249	21777	Economy	3300.00
0005435653250	21777	Economy	3300.00
0005433367749	21777	Economy	3300.00
0005433367818	21777	Economy	3300.00
0005433367852	21777	Economy	3300.00
0005435653240	21777	Economy	3300.00
0005433367807	21777	Economy	3300.00
0005433367627	21777	Economy	3300.00
0005433367798	21777	Economy	3300.00
0005435653237	21777	Economy	3300.00
0005433785131	9344	Business	186200.00
0005433785151	9344	Business	186200.00
0005433805552	9344	Business	186200.00
0005433805571	9344	Business	186200.00
0005433805549	9344	Business	186200.00
0005434170980	9344	Business	186200.00
0005433805542	9344	Business	186200.00
0005433763275	9344	Business	186200.00
0005433763285	9344	Business	186200.00
0005433785148	9344	Business	186200.00
0005433785146	9344	Business	186200.00
0005433785130	9344	Business	186200.00
0005433805547	9344	Business	186200.00
0005433805553	9344	Business	186200.00
0005433805541	9344	Economy	68300.00
0005432657465	9344	Economy	68300.00
0005433785129	9344	Economy	68300.00
0005433763277	9344	Economy	62100.00
0005433785144	9344	Economy	62100.00
0005433805565	9344	Economy	62100.00
0005432657463	9344	Economy	62100.00
0005433785117	9344	Economy	62100.00
0005433785112	9344	Economy	62100.00
0005433805563	9344	Economy	62100.00
0005432665284	9344	Economy	62100.00
0005433763282	9344	Economy	62100.00
0005433805548	9344	Economy	62100.00
0005435269695	9344	Economy	62100.00
0005433785122	9344	Economy	62100.00
0005435269709	9344	Economy	62100.00
0005435269708	9344	Economy	62100.00
0005434273072	9344	Economy	62100.00
0005433785110	9344	Economy	62100.00
0005433785124	9344	Economy	62100.00
0005433785120	9344	Economy	62100.00
0005433785147	9344	Economy	62100.00
0005433805551	9344	Economy	62100.00
0005433805538	9344	Economy	62100.00
0005435269724	9344	Economy	62100.00
0005433805546	9344	Economy	62100.00
0005434171008	9344	Economy	62100.00
0005433785134	9344	Economy	62100.00
0005434171006	9344	Economy	62100.00
0005433763284	9344	Economy	62100.00
0005434170929	9344	Economy	62100.00
0005433805560	9344	Economy	62100.00
0005434171042	9344	Economy	62100.00
0005433805539	9344	Economy	62100.00
0005433805545	9344	Economy	62100.00
0005433785139	9344	Economy	62100.00
0005433785125	9344	Economy	62100.00
0005433805568	9344	Economy	62100.00
0005434151691	9344	Economy	62100.00
0005433763274	9344	Economy	62100.00
0005435269713	9344	Economy	62100.00
0005435269706	9344	Economy	62100.00
0005433805537	9344	Economy	62100.00
0005434171039	9344	Economy	62100.00
0005433785115	9344	Economy	62100.00
0005434171045	9344	Economy	62100.00
0005433763280	9344	Economy	62100.00
0005432657464	9344	Economy	62100.00
0005433805561	9344	Economy	62100.00
0005433785140	9344	Economy	62100.00
0005433785136	9344	Economy	62100.00
0005433785116	9344	Economy	62100.00
0005433785143	9344	Economy	62100.00
0005432666399	9344	Economy	62100.00
0005433785142	9344	Economy	62100.00
0005433805558	9344	Economy	62100.00
0005433785118	9344	Economy	62100.00
0005433805554	9344	Economy	62100.00
0005433805564	9344	Economy	62100.00
0005433785121	9344	Economy	62100.00
0005433785145	9344	Economy	62100.00
0005434170979	9344	Economy	62100.00
0005433805540	9344	Economy	68300.00
0005433763286	9344	Economy	68300.00
0005435269723	9344	Economy	62100.00
0005433805544	9344	Economy	62100.00
0005435269722	9344	Economy	62100.00
0005433805570	9344	Economy	62100.00
0005434171090	9344	Economy	62100.00
0005433785141	9344	Economy	62100.00
0005433785138	9344	Economy	62100.00
0005432665285	9344	Economy	62100.00
0005433763276	9344	Economy	62100.00
0005433785111	9344	Economy	62100.00
0005433805559	9344	Economy	62100.00
0005433785132	9344	Economy	62100.00
0005434273074	9344	Economy	62100.00
0005433805543	9344	Economy	62100.00
0005433763283	9344	Economy	62100.00
0005435269707	9344	Economy	62100.00
0005433805569	9344	Economy	62100.00
0005433763281	9344	Economy	62100.00
0005433785126	9344	Economy	62100.00
0005434151699	9344	Economy	62100.00
0005435269718	9344	Economy	62100.00
0005433785119	9344	Economy	62100.00
0005433785135	9344	Economy	62100.00
0005433785114	9344	Economy	62100.00
0005433805572	9344	Economy	62100.00
0005435269693	9344	Economy	62100.00
0005433805556	9344	Economy	62100.00
0005433785113	9344	Economy	62100.00
0005433805550	9344	Economy	62100.00
0005433785150	9344	Economy	62100.00
0005434171007	9344	Economy	62100.00
0005433763279	9344	Economy	62100.00
0005433785123	9344	Economy	62100.00
0005433763278	9344	Economy	62100.00
0005433763273	9344	Economy	62100.00
0005433805557	9344	Economy	62100.00
0005434273073	9344	Economy	62100.00
0005433763272	9344	Economy	62100.00
0005433805562	9344	Economy	62100.00
0005432667464	9344	Economy	62100.00
0005433785152	9344	Economy	62100.00
0005435269719	9344	Economy	62100.00
0005433805567	9344	Economy	62100.00
0005433785133	9344	Economy	62100.00
0005433805555	9344	Economy	62100.00
0005433785137	9344	Economy	62100.00
0005433785127	9344	Economy	62100.00
0005433805536	9344	Economy	62100.00
0005434170930	9344	Economy	62100.00
0005433785149	9344	Economy	62100.00
0005433785128	9344	Economy	62100.00
0005433805566	9344	Economy	62100.00
0005433805133	26240	Business	186200.00
0005433784768	26240	Business	186200.00
0005433763110	26240	Business	186200.00
0005433763125	26240	Business	186200.00
0005433784828	26240	Business	186200.00
0005433784807	26240	Business	186200.00
0005434171126	26240	Business	186200.00
0005433805210	26240	Business	186200.00
0005433784957	26240	Business	186200.00
0005432659698	26240	Business	186200.00
0005433784729	26240	Business	186200.00
0005434171129	26240	Business	186200.00
0005433805397	26240	Business	186200.00
0005434171130	26240	Business	186200.00
0005433763148	26240	Business	186200.00
0005434270216	26240	Business	186200.00
0005433763157	26240	Business	186200.00
0005433784717	26240	Business	186200.00
0005434171134	26240	Economy	68300.00
0005434151717	26240	Economy	68300.00
0005433805224	26240	Economy	68300.00
0005433805088	26240	Economy	62100.00
0005435269774	26240	Economy	62100.00
0005432659693	26240	Economy	62100.00
0005434151718	26240	Economy	62100.00
0005433763129	26240	Economy	62100.00
0005435269775	26240	Economy	62100.00
0005433784865	26240	Economy	62100.00
0005433805251	26240	Economy	62100.00
0005433784778	26240	Economy	62100.00
0005434171124	26240	Economy	62100.00
0005433784773	26240	Economy	62100.00
0005434171123	26240	Economy	62100.00
0005434171122	26240	Economy	62100.00
0005432657427	26240	Economy	62100.00
0005432666387	26240	Economy	62100.00
0005433784823	26240	Economy	62100.00
0005433763132	26240	Economy	62100.00
0005433805250	26240	Economy	62100.00
0005433784774	26240	Economy	62100.00
0005433784816	26240	Economy	62100.00
0005433805275	26240	Economy	62100.00
0005433784919	26240	Economy	62100.00
0005433784526	26240	Economy	62100.00
0005433784968	26240	Economy	62100.00
0005433784772	26240	Economy	62100.00
0005434151719	26240	Economy	62100.00
0005433784877	26240	Economy	62100.00
0005433805414	26240	Economy	62100.00
0005433805160	26240	Economy	62100.00
0005433805226	26240	Economy	62100.00
0005434171127	26240	Economy	62100.00
0005433784918	26240	Economy	62100.00
0005433763109	26240	Economy	62100.00
0005433805322	26240	Economy	62100.00
0005433784689	26240	Economy	62100.00
0005434171132	26240	Economy	62100.00
0005434171131	26240	Economy	62100.00
0005434171133	26240	Economy	62100.00
0005433763126	26240	Economy	62100.00
0005433763128	26240	Economy	62100.00
0005432657442	26240	Economy	62100.00
0005433805298	26240	Economy	62100.00
0005435269776	26240	Economy	62100.00
0005433805184	26240	Economy	62100.00
0005433763149	26240	Economy	62100.00
0005433805357	26240	Economy	62100.00
0005433763173	26240	Economy	62100.00
0005433784829	26240	Economy	62100.00
0005433763181	26240	Economy	62100.00
0005432666379	26240	Economy	62100.00
0005433763133	26240	Economy	62100.00
0005434271321	26240	Economy	62100.00
0005432657428	26240	Economy	62100.00
0005433805348	26240	Economy	62100.00
0005433805193	26240	Economy	62100.00
0005433784866	26240	Economy	68300.00
0005433784956	26240	Economy	62100.00
0005433805183	26240	Economy	62100.00
0005433784815	26240	Economy	68300.00
0005433784730	26240	Economy	62100.00
0005433805248	26240	Economy	62100.00
0005433763179	26240	Economy	62100.00
0005434271320	26240	Economy	62100.00
0005434171135	26240	Economy	62100.00
0005432659692	26240	Economy	62100.00
0005433805191	26240	Economy	62100.00
0005433805174	26240	Economy	62100.00
0005433805211	26240	Economy	62100.00
0005434270215	26240	Economy	62100.00
0005432666378	26240	Economy	62100.00
0005433784767	26240	Economy	62100.00
0005432659694	26240	Economy	62100.00
0005433784821	26240	Economy	62100.00
0005434269113	26240	Economy	62100.00
0005433784902	26240	Economy	62100.00
0005433805252	26240	Economy	62100.00
0005433784723	26240	Economy	62100.00
0005433784814	26240	Economy	62100.00
0005432666377	26240	Economy	62100.00
0005433763153	26240	Economy	62100.00
0005433805087	26240	Economy	62100.00
0005433805229	26240	Economy	62100.00
0005433784833	26240	Economy	62100.00
0005433805382	26240	Economy	62100.00
0005434269112	26240	Economy	62100.00
0005433784859	26240	Economy	62100.00
0005432657426	26240	Economy	62100.00
0005433805283	26240	Economy	62100.00
0005433784899	26240	Economy	62100.00
0005433784721	26240	Economy	62100.00
0005433805225	26240	Economy	62100.00
0005432666366	26240	Economy	62100.00
0005433805209	26240	Economy	62100.00
0005433784722	26240	Economy	62100.00
0005434151720	26240	Economy	62100.00
0005433784680	26240	Economy	62100.00
0005434171128	26240	Economy	62100.00
0005432659697	26240	Economy	62100.00
0005433784895	26240	Economy	62100.00
0005434171125	26240	Economy	62100.00
0005432657441	26240	Economy	62100.00
0005433763124	26240	Economy	62100.00
0005433805192	26240	Economy	62100.00
0005433784969	26240	Economy	62100.00
0005433784943	26240	Economy	62100.00
0005433785021	26240	Economy	62100.00
0005433805325	26240	Economy	62100.00
0005434269111	26240	Economy	62100.00
0005433784808	26240	Economy	62100.00
0005435929635	4929	Economy	5900.00
0005435135695	4929	Economy	5300.00
0005435929638	4929	Economy	5300.00
0005435135692	4929	Economy	5300.00
0005435929627	4929	Economy	5300.00
0005435929626	4929	Economy	5300.00
0005435929623	4929	Economy	5300.00
0005435135696	4929	Economy	5300.00
0005435135694	4929	Economy	5300.00
0005435135693	4929	Economy	5300.00
0005435135666	33032	Economy	5900.00
0005435135649	33032	Economy	5900.00
0005435929656	33032	Economy	5300.00
0005435135665	33032	Economy	5300.00
0005435929658	33032	Economy	5300.00
0005435135651	33032	Economy	5300.00
0005435135650	33032	Economy	5300.00
0005435135627	33032	Economy	5300.00
0005435929657	33032	Economy	5300.00
0005435135652	33032	Economy	5300.00
0005435135675	33032	Economy	5300.00
0005435135658	33032	Economy	5300.00
0005434217951	9501	Economy	19700.00
0005434983316	9501	Economy	17900.00
0005434217945	9501	Economy	17900.00
0005434217932	9501	Economy	17900.00
0005434983315	9501	Economy	17900.00
0005434983314	9501	Economy	17900.00
0005434983313	9501	Economy	17900.00
0005434983312	9501	Economy	17900.00
0005434983311	9501	Economy	17900.00
0005434217950	9501	Economy	17900.00
0005434217989	27342	Economy	17900.00
0005434983254	27342	Economy	17900.00
0005434983276	27342	Economy	17900.00
0005434217990	27342	Economy	17900.00
0005434217988	27342	Economy	17900.00
0005434983277	27342	Economy	17900.00
0005434983253	27342	Economy	17900.00
0005433960567	24261	Business	36400.00
0005433960486	24261	Business	36400.00
0005433985652	24261	Business	36400.00
0005433960590	24261	Business	36400.00
0005433960645	24261	Business	36400.00
0005433960266	24261	Business	36400.00
0005433985753	24261	Business	36400.00
0005433985714	24261	Business	36400.00
0005433960643	24261	Business	36400.00
0005433985691	24261	Business	36400.00
0005433985693	24261	Business	36400.00
0005433960647	24261	Business	36400.00
0005433985677	24261	Business	36400.00
0005433960338	24261	Economy	13400.00
0005433960491	24261	Economy	13400.00
0005433960636	24261	Economy	12100.00
0005433960662	24261	Economy	12100.00
0005433960656	24261	Economy	12100.00
0005433960601	24261	Economy	12100.00
0005433960602	24261	Economy	12100.00
0005433960384	24261	Economy	12100.00
0005433960638	24261	Economy	12100.00
0005433960447	24261	Economy	12100.00
0005433985651	24261	Economy	12100.00
0005433960576	24261	Economy	12100.00
0005433985680	24261	Economy	12100.00
0005433960578	24261	Economy	12100.00
0005433960444	24261	Economy	12100.00
0005433960614	24261	Economy	12100.00
0005433960577	24261	Economy	12100.00
0005433960627	24261	Economy	12100.00
0005433985685	24261	Economy	12100.00
0005433960640	24261	Economy	12100.00
0005433960644	24261	Economy	12100.00
0005433985722	24261	Economy	12100.00
0005433960403	24261	Economy	12100.00
0005433985476	24261	Economy	12100.00
0005433960598	24261	Economy	12100.00
0005433960630	24261	Economy	12100.00
0005433960496	24261	Economy	12100.00
0005433960591	24261	Economy	12100.00
0005433960515	24261	Economy	12100.00
0005433960485	24261	Economy	12100.00
0005433960587	24261	Economy	12100.00
0005433960445	24261	Economy	12100.00
0005433960566	24261	Economy	12100.00
0005433985686	24261	Economy	12100.00
0005433985687	24261	Economy	12100.00
0005433960655	24261	Economy	12100.00
0005433960420	24261	Economy	12100.00
0005433960589	24261	Economy	12100.00
0005433985590	24261	Economy	12100.00
0005433985431	24261	Economy	12100.00
0005433960616	24261	Economy	12100.00
0005433960497	24261	Economy	12100.00
0005433985667	24261	Economy	12100.00
0005433985678	24261	Economy	12100.00
0005433960537	24261	Economy	12100.00
0005433985755	24261	Economy	12100.00
0005433985684	24261	Economy	12100.00
0005433960613	24261	Economy	12100.00
0005433985689	24261	Economy	12100.00
0005433985569	24261	Economy	12100.00
0005433960554	24261	Economy	12100.00
0005433985668	24261	Economy	13400.00
0005433960498	24261	Economy	13400.00
0005433960637	24261	Economy	12100.00
0005433985475	24261	Economy	13400.00
0005433960540	24261	Economy	12100.00
0005433960389	24261	Economy	12100.00
0005433960514	24261	Economy	12100.00
0005433985534	24261	Economy	12100.00
0005433985624	24261	Economy	12100.00
0005433985713	24261	Economy	12100.00
0005433960536	24261	Economy	12100.00
0005433960385	24261	Economy	12100.00
0005433960446	24261	Economy	12100.00
0005433985535	24261	Economy	12100.00
0005433960463	24261	Economy	12100.00
0005433985648	24261	Economy	12100.00
0005433985432	24261	Economy	12100.00
0005433960492	24261	Economy	12100.00
0005433960484	24261	Economy	12100.00
0005433985542	24261	Economy	12100.00
0005433960337	24261	Economy	12100.00
0005433960639	24261	Economy	12100.00
0005433960573	24261	Economy	12100.00
0005433960412	24261	Economy	12100.00
0005433985679	24261	Economy	12100.00
0005433985692	24261	Economy	12100.00
0005433985737	24261	Economy	12100.00
0005433960572	24261	Economy	12100.00
0005433960606	24261	Economy	12100.00
0005433960539	24261	Economy	12100.00
0005433985688	24261	Economy	12100.00
0005433985585	24261	Economy	12100.00
0005433960608	24261	Economy	12100.00
0005433985560	24261	Economy	12100.00
0005433985752	24261	Economy	12100.00
0005433960657	24261	Economy	12100.00
0005433960654	24261	Economy	12100.00
0005433985709	24261	Economy	12100.00
0005433985672	24261	Economy	12100.00
0005433960617	24261	Economy	12100.00
0005433960615	24261	Economy	12100.00
0005433985712	24261	Economy	12100.00
0005433985541	24261	Economy	12100.00
0005433960501	24261	Economy	12100.00
0005433961139	25960	Business	36400.00
0005433961146	25960	Business	36400.00
0005433961143	25960	Business	36400.00
0005433961154	25960	Business	36400.00
0005433986166	25960	Business	36400.00
0005433986146	25960	Business	36400.00
0005433986152	25960	Business	36400.00
0005433986172	25960	Business	36400.00
0005433986140	25960	Business	36400.00
0005433961125	25960	Business	36400.00
0005433961132	25960	Business	36400.00
0005433986139	25960	Business	36400.00
0005433961115	25960	Business	36400.00
0005433986132	25960	Business	36400.00
0005433986168	25960	Business	36400.00
0005433961160	25960	Economy	13400.00
0005433961150	25960	Economy	12100.00
0005433986134	25960	Economy	12100.00
0005433986160	25960	Economy	12100.00
0005433986174	25960	Economy	12100.00
0005433961120	25960	Economy	12100.00
0005433961111	25960	Economy	12100.00
0005433986161	25960	Economy	12100.00
0005433986131	25960	Economy	12100.00
0005433986159	25960	Economy	12100.00
0005433961141	25960	Economy	12100.00
0005433961137	25960	Economy	12100.00
0005433961148	25960	Economy	12100.00
0005433986138	25960	Economy	12100.00
0005433986155	25960	Economy	12100.00
0005433986167	25960	Economy	12100.00
0005433961153	25960	Economy	12100.00
0005433986141	25960	Economy	12100.00
0005433961145	25960	Economy	12100.00
0005433961147	25960	Economy	12100.00
0005433961138	25960	Economy	12100.00
0005433961161	25960	Economy	12100.00
0005433961122	25960	Economy	12100.00
0005433986162	25960	Economy	12100.00
0005433986173	25960	Economy	12100.00
0005433986156	25960	Economy	12100.00
0005433986169	25960	Economy	12100.00
0005433961156	25960	Economy	12100.00
0005433961126	25960	Economy	12100.00
0005433986157	25960	Economy	12100.00
0005433961134	25960	Economy	12100.00
0005433961110	25960	Economy	12100.00
0005433986144	25960	Economy	12100.00
0005433961142	25960	Economy	12100.00
0005433986130	25960	Economy	12100.00
0005433986164	25960	Economy	12100.00
0005433961130	25960	Economy	12100.00
0005433961114	25960	Economy	12100.00
0005433986145	25960	Economy	12100.00
0005433961121	25960	Economy	12100.00
0005433986136	25960	Economy	12100.00
0005433961116	25960	Economy	12100.00
0005433961123	25960	Economy	12100.00
0005433961129	25960	Economy	12100.00
0005433961124	25960	Economy	12100.00
0005433986150	25960	Economy	12100.00
0005433986149	25960	Economy	12100.00
0005433961117	25960	Economy	12100.00
0005433961164	25960	Economy	13400.00
0005433961119	25960	Economy	12100.00
0005433986143	25960	Economy	12100.00
0005433961127	25960	Economy	12100.00
0005433961157	25960	Economy	12100.00
0005433961113	25960	Economy	12100.00
0005433961135	25960	Economy	12100.00
0005433961149	25960	Economy	12100.00
0005433961128	25960	Economy	12100.00
0005433986133	25960	Economy	12100.00
0005433986135	25960	Economy	12100.00
0005433961159	25960	Economy	12100.00
0005433986170	25960	Economy	12100.00
0005433986158	25960	Economy	12100.00
0005433986147	25960	Economy	12100.00
0005433986163	25960	Economy	12100.00
0005433961136	25960	Economy	12100.00
0005433961163	25960	Economy	12100.00
0005433961131	25960	Economy	12100.00
0005433986151	25960	Economy	12100.00
0005433986137	25960	Economy	12100.00
0005433961155	25960	Economy	12100.00
0005433986148	25960	Economy	12100.00
0005433961133	25960	Economy	12100.00
0005433961140	25960	Economy	12100.00
0005433961144	25960	Economy	12100.00
0005433961112	25960	Economy	12100.00
0005433986165	25960	Economy	12100.00
0005433986153	25960	Economy	12100.00
0005433961158	25960	Economy	12100.00
0005433986171	25960	Economy	12100.00
0005433961162	25960	Economy	12100.00
0005433986142	25960	Economy	12100.00
0005433961152	25960	Economy	12100.00
0005433986154	25960	Economy	12100.00
0005433986175	25960	Economy	12100.00
0005433961151	25960	Economy	12100.00
0005433961118	25960	Economy	12100.00
0005433165902	947	Economy	25400.00
0005434480464	947	Economy	25400.00
0005434480458	947	Economy	25400.00
0005433165857	947	Economy	25400.00
0005434480456	947	Economy	23100.00
0005433165809	947	Economy	23100.00
0005434480448	947	Economy	23100.00
0005433165835	947	Economy	23100.00
0005434480446	947	Economy	23100.00
0005434480452	947	Economy	23100.00
0005432269509	947	Economy	23100.00
0005434480453	947	Economy	23100.00
0005434480451	947	Economy	23100.00
0005433165834	947	Economy	23100.00
0005433165836	947	Economy	23100.00
0005432269510	947	Economy	23100.00
0005433165858	947	Economy	23100.00
0005433165891	947	Economy	23100.00
0005434480466	947	Economy	23100.00
0005433165908	947	Economy	23100.00
0005434480463	947	Economy	23100.00
0005433165833	947	Economy	23100.00
0005434480460	947	Economy	23100.00
0005433165897	947	Economy	23100.00
0005434480454	947	Economy	23100.00
0005434480455	947	Economy	23100.00
0005433165846	947	Economy	23100.00
0005434480449	947	Economy	23100.00
0005433165916	947	Economy	23100.00
0005434480447	947	Economy	23100.00
0005433165915	947	Economy	23100.00
0005433165907	947	Economy	23100.00
0005433165845	947	Economy	23100.00
0005434480462	947	Economy	23100.00
0005434480459	947	Economy	23100.00
0005433165808	947	Economy	23100.00
0005434480469	947	Economy	23100.00
0005434480457	947	Economy	23100.00
0005434480467	947	Economy	23100.00
0005434480468	947	Economy	23100.00
0005434480450	947	Economy	23100.00
0005433165898	947	Economy	23100.00
0005432269508	947	Economy	23100.00
0005434480461	947	Economy	23100.00
0005434480465	947	Economy	23100.00
0005433165807	947	Economy	23100.00
0005433165906	947	Economy	23100.00
0005433165853	947	Economy	23100.00
0005434480188	16551	Economy	25400.00
0005434480336	16551	Economy	25400.00
0005433165965	16551	Economy	23100.00
0005434480187	16551	Economy	23100.00
0005434480298	16551	Economy	23100.00
0005434480265	16551	Economy	23100.00
0005433165976	16551	Economy	23100.00
0005433165974	16551	Economy	23100.00
0005433165966	16551	Economy	23100.00
0005433165967	16551	Economy	23100.00
0005433165969	16551	Economy	23100.00
0005434480169	16551	Economy	23100.00
0005433165971	16551	Economy	23100.00
0005434480280	16551	Economy	23100.00
0005434480239	16551	Economy	23100.00
0005434480173	16551	Economy	23100.00
0005433165973	16551	Economy	23100.00
0005433165975	16551	Economy	23100.00
0005433165964	16551	Economy	23100.00
0005434480272	16551	Economy	23100.00
0005434480328	16551	Economy	23100.00
0005434480128	16551	Economy	23100.00
0005434480266	16551	Economy	23100.00
0005434480267	16551	Economy	23100.00
0005433165968	16551	Economy	23100.00
0005433165963	16551	Economy	23100.00
0005434480225	16551	Economy	23100.00
0005434480192	16551	Economy	23100.00
0005434480279	16551	Economy	23100.00
0005434480278	16551	Economy	23100.00
0005434480233	16551	Economy	23100.00
0005434480174	16551	Economy	23100.00
0005433165970	16551	Economy	23100.00
0005433165972	16551	Economy	23100.00
0005435150088	10352	Economy	17000.00
0005435386555	10352	Economy	17000.00
0005433289794	10352	Economy	17000.00
0005435150087	10352	Economy	17000.00
0005435142634	10352	Economy	15400.00
0005435386564	10352	Economy	15400.00
0005435150091	10352	Economy	15400.00
0005435386535	10352	Economy	15400.00
0005435142631	10352	Economy	15400.00
0005435142638	10352	Economy	15400.00
0005433289818	10352	Economy	15400.00
0005433289793	10352	Economy	15400.00
0005435386552	10352	Economy	15400.00
0005435142632	10352	Economy	15400.00
0005435150089	10352	Economy	15400.00
0005435142629	10352	Economy	15400.00
0005435386540	10352	Economy	15400.00
0005435386553	10352	Economy	15400.00
0005435150090	10352	Economy	15400.00
0005435142637	10352	Economy	15400.00
0005435386556	10352	Economy	15400.00
0005435150082	10352	Economy	15400.00
0005433289832	10352	Economy	15400.00
0005435142626	10352	Economy	15400.00
0005433289808	10352	Economy	15400.00
0005435150092	10352	Economy	15400.00
0005435150086	10352	Economy	15400.00
0005435386539	10352	Economy	15400.00
0005435142627	10352	Economy	15400.00
0005435386522	10352	Economy	15400.00
0005435142636	10352	Economy	15400.00
0005435150085	10352	Economy	15400.00
0005435142635	10352	Economy	15400.00
0005435386574	10352	Economy	15400.00
0005435142639	10352	Economy	15400.00
0005435142628	10352	Economy	15400.00
0005435142630	10352	Economy	15400.00
0005433289815	10352	Economy	15400.00
0005435142633	10352	Economy	15400.00
0005435150084	10352	Economy	15400.00
0005435150083	10352	Economy	15400.00
0005433289894	21936	Economy	17000.00
0005433289889	21936	Economy	17000.00
0005435149955	21936	Economy	17000.00
0005435149924	21936	Economy	17000.00
0005435150025	21936	Economy	15400.00
0005435149970	21936	Economy	15400.00
0005435149959	21936	Economy	15400.00
0005435149981	21936	Economy	15400.00
0005435149982	21936	Economy	15400.00
0005433289887	21936	Economy	15400.00
0005435386602	21936	Economy	15400.00
0005435386598	21936	Economy	15400.00
0005433289892	21936	Economy	15400.00
0005435149958	21936	Economy	15400.00
0005435150007	21936	Economy	15400.00
0005435149980	21936	Economy	15400.00
0005433289891	21936	Economy	15400.00
0005435149969	21936	Economy	15400.00
0005435142532	21936	Economy	15400.00
0005435386600	21936	Economy	15400.00
0005435149983	21936	Economy	15400.00
0005435142506	21936	Economy	15400.00
0005435142503	21936	Economy	15400.00
0005435386599	21936	Economy	15400.00
0005435386601	21936	Economy	15400.00
0005435386604	21936	Economy	15400.00
0005435149968	21936	Economy	15400.00
0005435142504	21936	Economy	15400.00
0005435149925	21936	Economy	15400.00
0005435142610	21936	Economy	15400.00
0005433289893	21936	Economy	15400.00
0005435149967	21936	Economy	15400.00
0005435142551	21936	Economy	15400.00
0005435386603	21936	Economy	15400.00
0005433289890	21936	Economy	15400.00
0005435142518	21936	Economy	15400.00
0005433289888	21936	Economy	15400.00
0005435150004	21936	Economy	15400.00
0005435142533	21936	Economy	15400.00
0005435502197	11205	Business	57200.00
0005435502289	11205	Business	57200.00
0005435545682	11205	Business	57200.00
0005435319549	11205	Business	57200.00
0005435502244	11205	Business	57200.00
0005435502253	11205	Business	57200.00
0005435529150	11205	Business	57200.00
0005435502245	11205	Business	57200.00
0005434573408	11205	Economy	19100.00
0005435502129	11205	Economy	19100.00
0005435502282	11205	Economy	19100.00
0005434573417	11205	Economy	19100.00
0005435529148	11205	Economy	19100.00
0005435502199	11205	Economy	19100.00
0005434573406	11205	Economy	19100.00
0005435529090	11205	Economy	19100.00
0005435502177	11205	Economy	19100.00
0005435502297	11205	Economy	21000.00
0005435529114	11205	Economy	21000.00
0005435545685	11205	Economy	21000.00
0005435502248	11205	Economy	21000.00
0005435502221	11205	Economy	19100.00
0005435545702	11205	Economy	19100.00
0005435319524	11205	Economy	19100.00
0005435502236	11205	Economy	19100.00
0005435529175	11205	Economy	19100.00
0005435502256	11205	Economy	19100.00
0005435529185	11205	Economy	19100.00
0005435502366	11205	Economy	19100.00
0005435502243	11205	Economy	19100.00
0005435545700	11205	Economy	19100.00
0005435529184	11205	Economy	19100.00
0005435319571	11205	Economy	19100.00
0005435529233	11205	Economy	19100.00
0005434573415	11205	Economy	19100.00
0005435319558	11205	Economy	19100.00
0005435545675	11205	Economy	19100.00
0005435502255	11205	Economy	19100.00
0005435529174	11205	Economy	19100.00
0005435529149	11205	Economy	19100.00
0005435502142	11205	Economy	19100.00
0005435319550	11205	Economy	19100.00
0005434573407	11205	Economy	19100.00
0005434573411	11205	Economy	19100.00
0005435529232	11205	Economy	19100.00
0005435529206	11205	Economy	19100.00
0005435502313	11205	Economy	19100.00
0005434573404	11205	Economy	19100.00
0005434573414	11205	Economy	19100.00
0005435502143	11205	Economy	19100.00
0005435502287	11205	Economy	19100.00
0005434573412	11205	Economy	19100.00
0005434573405	11205	Economy	19100.00
0005435502235	11205	Economy	19100.00
0005435529158	11205	Economy	19100.00
0005435319557	11205	Economy	19100.00
0005435529187	11205	Economy	19100.00
0005435545693	11205	Economy	19100.00
0005435502268	11205	Economy	19100.00
0005435529119	11205	Economy	19100.00
0005435529089	11205	Economy	19100.00
0005435545701	11205	Economy	19100.00
0005434573409	11205	Economy	19100.00
0005435502335	11205	Economy	19100.00
0005435502222	11205	Economy	19100.00
0005434573416	11205	Economy	19100.00
0005435502200	11205	Economy	19100.00
0005435502308	11205	Economy	19100.00
0005435545676	11205	Economy	19100.00
0005434573418	11205	Economy	19100.00
0005435502229	11205	Economy	19100.00
0005435502317	11205	Economy	19100.00
0005434573410	11205	Economy	19100.00
0005435529097	11205	Economy	19100.00
0005434573413	11205	Economy	19100.00
0005435502340	11205	Economy	19100.00
0005435529225	11205	Economy	19100.00
0005435517981	20910	Business	57200.00
0005435502400	20910	Business	57200.00
0005435517993	20910	Business	57200.00
0005435517996	20910	Business	57200.00
0005435319623	20910	Business	57200.00
0005435502407	20910	Business	57200.00
0005435517990	20910	Business	57200.00
0005435502410	20910	Economy	19100.00
0005435319630	20910	Economy	19100.00
0005435517991	20910	Economy	19100.00
0005435517989	20910	Economy	19100.00
0005435517985	20910	Economy	19100.00
0005435517987	20910	Economy	19100.00
0005435517980	20910	Economy	21000.00
0005434573273	20910	Economy	21000.00
0005435502411	20910	Economy	19100.00
0005434573309	20910	Economy	19100.00
0005435319624	20910	Economy	19100.00
0005435502414	20910	Economy	19100.00
0005435502409	20910	Economy	19100.00
0005435508400	20910	Economy	19100.00
0005435517979	20910	Economy	19100.00
0005435508401	20910	Economy	19100.00
0005434573293	20910	Economy	19100.00
0005435502404	20910	Economy	19100.00
0005435508402	20910	Economy	19100.00
0005435502413	20910	Economy	19100.00
0005435502398	20910	Economy	19100.00
0005435517986	20910	Economy	19100.00
0005435517977	20910	Economy	19100.00
0005434573346	20910	Economy	19100.00
0005434573282	20910	Economy	19100.00
0005435508405	20910	Economy	19100.00
0005435502419	20910	Economy	19100.00
0005435502402	20910	Economy	19100.00
0005435502397	20910	Economy	19100.00
0005435502417	20910	Economy	19100.00
0005435502403	20910	Economy	19100.00
0005435319626	20910	Economy	19100.00
0005435502401	20910	Economy	19100.00
0005435517988	20910	Economy	19100.00
0005434573257	20910	Economy	19100.00
0005435508403	20910	Economy	19100.00
0005435319631	20910	Economy	19100.00
0005434573307	20910	Economy	19100.00
0005434573265	20910	Economy	19100.00
0005435319629	20910	Economy	19100.00
0005435517982	20910	Economy	19100.00
0005435319625	20910	Economy	19100.00
0005435319627	20910	Economy	19100.00
0005435517983	20910	Economy	19100.00
0005435517994	20910	Economy	19100.00
0005435517992	20910	Economy	19100.00
0005434573270	20910	Economy	19100.00
0005434573289	20910	Economy	19100.00
0005435502399	20910	Economy	19100.00
0005435502415	20910	Economy	19100.00
0005435508404	20910	Economy	19100.00
0005434573287	20910	Economy	19100.00
0005435502406	20910	Economy	19100.00
0005434573255	20910	Economy	19100.00
0005435502416	20910	Economy	19100.00
0005434573256	20910	Economy	19100.00
0005434573313	20910	Economy	19100.00
0005435319628	20910	Economy	19100.00
0005435502405	20910	Economy	19100.00
0005435502418	20910	Economy	19100.00
0005435517995	20910	Economy	19100.00
0005435517984	20910	Economy	19100.00
0005435502408	20910	Economy	19100.00
0005432291941	20910	Economy	19100.00
0005434573345	20910	Economy	19100.00
0005435502412	20910	Economy	19100.00
0005435517978	20910	Economy	19100.00
0005432692827	2984	Business	10300.00
0005432693046	2984	Business	10300.00
0005432692898	2984	Business	10300.00
0005432692784	2984	Business	10300.00
0005432692990	2984	Business	10300.00
0005432692853	2984	Economy	3400.00
0005432692984	2984	Economy	3400.00
0005432692894	2984	Economy	3400.00
0005432692929	2984	Economy	3400.00
0005432692839	2984	Economy	3400.00
0005432692906	2984	Economy	3800.00
0005432692935	2984	Economy	3400.00
0005432692694	2984	Economy	3400.00
0005432692840	2984	Economy	3400.00
0005432692787	2984	Economy	3400.00
0005432692786	2984	Economy	3400.00
0005432692897	2984	Economy	3400.00
0005432692900	2984	Economy	3400.00
0005432692785	2984	Economy	3400.00
0005432692980	2984	Economy	3400.00
0005432692969	2984	Economy	3400.00
0005432692826	2984	Economy	3400.00
0005432692946	2984	Economy	3400.00
0005432692937	2984	Economy	3400.00
0005432692986	2984	Economy	3400.00
0005432692848	2984	Economy	3400.00
0005432693006	2984	Economy	3400.00
0005432692854	2984	Economy	3400.00
0005432693000	2984	Economy	3400.00
0005432692934	2984	Economy	3400.00
0005432692991	2984	Economy	3400.00
0005432692925	2984	Economy	3400.00
0005433194834	2987	Business	10300.00
0005432880800	2987	Business	10300.00
0005433123843	2987	Business	10300.00
0005432706894	2987	Business	10300.00
0005432706908	2987	Business	10300.00
0005433123891	2987	Business	10300.00
0005432880789	2987	Business	10300.00
0005432880716	2987	Business	10300.00
0005432880756	2987	Business	10300.00
0005433123805	2987	Business	10300.00
0005432706901	2987	Economy	3400.00
0005433123832	2987	Economy	3400.00
0005432706886	2987	Economy	3400.00
0005433123810	2987	Economy	3400.00
0005433194857	2987	Economy	3400.00
0005433123870	2987	Economy	3400.00
0005432217792	2987	Economy	3400.00
0005433194836	2987	Economy	3800.00
0005432217790	2987	Economy	3800.00
0005432880766	2987	Economy	3800.00
0005432706884	2987	Economy	3400.00
0005432880725	2987	Economy	3400.00
0005433123844	2987	Economy	3400.00
0005432706898	2987	Economy	3400.00
0005432706896	2987	Economy	3400.00
0005432706887	2987	Economy	3400.00
0005433123816	2987	Economy	3400.00
0005432706892	2987	Economy	3400.00
0005432706891	2987	Economy	3400.00
0005433194847	2987	Economy	3400.00
0005432706905	2987	Economy	3400.00
0005432706903	2987	Economy	3400.00
0005433123753	2987	Economy	3400.00
0005433123759	2987	Economy	3400.00
0005432880722	2987	Economy	3400.00
0005432706899	2987	Economy	3400.00
0005432706888	2987	Economy	3400.00
0005433123822	2987	Economy	3400.00
0005432706895	2987	Economy	3400.00
0005433123833	2987	Economy	3400.00
0005432706909	2987	Economy	3400.00
0005433123889	2987	Economy	3400.00
0005433194845	2987	Economy	3400.00
0005432706890	2987	Economy	3400.00
0005432706889	2987	Economy	3400.00
0005433123835	2987	Economy	3400.00
0005432706893	2987	Economy	3400.00
0005432706897	2987	Economy	3400.00
0005432706902	2987	Economy	3400.00
0005433123752	2987	Economy	3400.00
0005432706907	2987	Economy	3400.00
0005432880749	2987	Economy	3400.00
0005432706906	2987	Economy	3400.00
0005432880801	2987	Economy	3400.00
0005432880724	2987	Economy	3400.00
0005432880784	2987	Economy	3400.00
0005433123910	2987	Economy	3400.00
0005433123905	2987	Economy	3400.00
0005432880767	2987	Economy	3400.00
0005432706885	2987	Economy	3400.00
0005432706900	2987	Economy	3400.00
0005433123890	2987	Economy	3400.00
0005432217791	2987	Economy	3400.00
0005432217789	2987	Economy	3400.00
0005433123817	2987	Economy	3400.00
0005432880768	2987	Economy	3400.00
0005432706904	2987	Economy	3400.00
0005432693237	29927	Business	10300.00
0005432880895	29927	Business	10300.00
0005432693250	29927	Business	10300.00
0005432706765	29927	Business	10300.00
0005432706829	29927	Business	10300.00
0005432693225	29927	Business	10300.00
0005432706805	29927	Business	10300.00
0005432706713	29927	Business	10300.00
0005433124026	29927	Business	10300.00
0005432706626	29927	Business	10300.00
0005432706794	29927	Business	10300.00
0005433124025	29927	Business	10300.00
0005432880889	29927	Economy	3400.00
0005432706749	29927	Economy	3400.00
0005432706699	29927	Economy	3400.00
0005432880892	29927	Economy	3400.00
0005432693224	29927	Economy	3400.00
0005432706647	29927	Economy	3400.00
0005432706742	29927	Economy	3400.00
0005433124019	29927	Economy	3400.00
0005432693228	29927	Economy	3400.00
0005432706620	29927	Economy	3400.00
0005432693246	29927	Economy	3800.00
0005432880883	29927	Economy	3800.00
0005432693229	29927	Economy	3800.00
0005432693241	29927	Economy	3800.00
0005432706674	29927	Economy	3800.00
0005432693242	29927	Economy	3400.00
0005432706729	29927	Economy	3400.00
0005432706828	29927	Economy	3400.00
0005432706698	29927	Economy	3400.00
0005432880886	29927	Economy	3400.00
0005432706804	29927	Economy	3400.00
0005432693248	29927	Economy	3400.00
0005432706736	29927	Economy	3400.00
0005432706760	29927	Economy	3400.00
0005432706743	29927	Economy	3400.00
0005433124021	29927	Economy	3400.00
0005433124023	29927	Economy	3400.00
0005432693247	29927	Economy	3400.00
0005432880887	29927	Economy	3400.00
0005432706657	29927	Economy	3400.00
0005432693227	29927	Economy	3400.00
0005433124015	29927	Economy	3400.00
0005432693240	29927	Economy	3400.00
0005432706658	29927	Economy	3400.00
0005432693243	29927	Economy	3400.00
0005432706788	29927	Economy	3400.00
0005432706730	29927	Economy	3400.00
0005432706673	29927	Economy	3400.00
0005433124024	29927	Economy	3400.00
0005432706741	29927	Economy	3400.00
0005432706766	29927	Economy	3400.00
0005432693232	29927	Economy	3400.00
0005433124016	29927	Economy	3400.00
0005433124017	29927	Economy	3400.00
0005433124022	29927	Economy	3400.00
0005432706676	29927	Economy	3400.00
0005433124018	29927	Economy	3400.00
0005432880891	29927	Economy	3400.00
0005432880890	29927	Economy	3400.00
0005432693244	29927	Economy	3400.00
0005432706799	29927	Economy	3400.00
0005432706747	29927	Economy	3400.00
0005432880885	29927	Economy	3400.00
0005432706775	29927	Economy	3400.00
0005432880882	29927	Economy	3400.00
0005432706806	29927	Economy	3400.00
0005432693238	29927	Economy	3400.00
0005432706714	29927	Economy	3400.00
0005432693234	29927	Economy	3400.00
0005433124020	29927	Economy	3400.00
0005432693236	29927	Economy	3400.00
0005432693251	29927	Economy	3400.00
0005432693223	29927	Economy	3400.00
0005432880884	29927	Economy	3400.00
0005432706679	29927	Economy	3400.00
0005432706827	29927	Economy	3400.00
0005432880893	29927	Economy	3400.00
0005432693249	29927	Economy	3400.00
0005432880888	29927	Economy	3400.00
0005432706735	29927	Economy	3400.00
0005432693239	29927	Economy	3400.00
0005432693226	29927	Economy	3400.00
0005432693245	29927	Economy	3400.00
0005432706664	29927	Economy	3400.00
0005432693252	29927	Economy	3400.00
0005432693235	29927	Economy	3400.00
0005433124014	29927	Economy	3400.00
0005432706680	29927	Economy	3400.00
0005432880896	29927	Economy	3400.00
0005432880894	29927	Economy	3400.00
0005432693233	29927	Economy	3400.00
0005432693231	29927	Economy	3400.00
0005432693230	29927	Economy	3400.00
0005434979926	23665	Economy	4000.00
0005434988789	23665	Economy	4000.00
0005434979898	23665	Economy	4000.00
0005434979907	23665	Economy	3600.00
0005434979908	23665	Economy	3600.00
0005434979921	23665	Economy	3600.00
0005434979911	23665	Economy	3600.00
0005434979927	23665	Economy	3600.00
0005434979923	23665	Economy	3600.00
0005434988790	23665	Economy	3600.00
0005434988787	23665	Economy	3600.00
0005434979901	23665	Economy	3600.00
0005434979913	23665	Economy	3600.00
0005434979917	23665	Economy	3600.00
0005434979925	23665	Economy	3600.00
0005434979915	23665	Economy	3600.00
0005434979909	23665	Economy	3600.00
0005434979924	23665	Economy	3600.00
0005434979918	23665	Economy	3600.00
0005434979905	23665	Economy	3600.00
0005434979899	23665	Economy	3600.00
0005434979906	23665	Economy	3600.00
0005434979910	23665	Economy	3600.00
0005434979900	23665	Economy	3600.00
0005434979928	23665	Economy	3600.00
0005434979916	23665	Economy	3600.00
0005434988786	23665	Economy	3600.00
0005434979904	23665	Economy	3600.00
0005434988784	23665	Economy	3600.00
0005434979903	23665	Economy	3600.00
0005434979902	23665	Economy	3600.00
0005434988785	23665	Economy	3600.00
0005434979914	23665	Economy	3600.00
0005434979920	23665	Economy	3600.00
0005434979919	23665	Economy	3600.00
0005434979912	23665	Economy	3600.00
0005434979922	23665	Economy	3600.00
0005434988788	23665	Economy	3600.00
0005434979628	27576	Economy	4000.00
0005434979558	27576	Economy	4000.00
0005434979726	27576	Economy	4000.00
0005434988676	27576	Economy	4000.00
0005434988662	27576	Economy	3600.00
0005434979601	27576	Economy	3600.00
0005434979673	27576	Economy	3600.00
0005434979697	27576	Economy	3600.00
0005434979639	27576	Economy	3600.00
0005434988670	27576	Economy	3600.00
0005434979848	27576	Economy	3600.00
0005434979761	27576	Economy	3600.00
0005434988673	27576	Economy	3600.00
0005434979638	27576	Economy	3600.00
0005434979675	27576	Economy	3600.00
0005434979579	27576	Economy	3600.00
0005434979698	27576	Economy	3600.00
0005434988672	27576	Economy	3600.00
0005434979674	27576	Economy	3600.00
0005434988699	27576	Economy	3600.00
0005434979692	27576	Economy	3600.00
0005434988663	27576	Economy	3600.00
0005434979633	27576	Economy	3600.00
0005434979622	27576	Economy	3600.00
0005434979702	27576	Economy	3600.00
0005434979632	27576	Economy	3600.00
0005434979758	27576	Economy	3600.00
0005434979600	27576	Economy	3600.00
0005434988698	27576	Economy	3600.00
0005434979693	27576	Economy	3600.00
0005434979605	27576	Economy	3600.00
0005434988700	27576	Economy	3600.00
0005434988701	27576	Economy	3600.00
0005434988637	27576	Economy	3600.00
0005434979843	27576	Economy	3600.00
0005434979659	27576	Economy	3600.00
0005434988689	27576	Economy	3600.00
0005434979663	27576	Economy	3600.00
0005434988669	27576	Economy	3600.00
0005434979627	27576	Economy	3600.00
0005434979711	27576	Economy	3600.00
0005434988691	27576	Economy	3600.00
0005433113527	10260	Economy	19700.00
0005434302475	10260	Economy	19700.00
0005433111498	10260	Economy	19700.00
0005434302477	10260	Economy	19700.00
0005434302476	10260	Economy	19700.00
0005433111483	10260	Economy	19700.00
0005434302478	10260	Economy	19700.00
0005433113536	10260	Economy	19700.00
0005433113532	10260	Economy	19700.00
0005433113528	10260	Economy	19700.00
0005433111484	10260	Economy	19700.00
0005433113547	19599	Economy	21600.00
0005433113546	19599	Economy	19700.00
0005434302438	19599	Economy	19700.00
0005434302454	19599	Economy	19700.00
0005434302430	19599	Economy	19700.00
0005434302453	19599	Economy	19700.00
0005434302446	19599	Economy	19700.00
0005434302443	19599	Economy	19700.00
0005434302447	19599	Economy	19700.00
0005434302455	19599	Economy	19700.00
0005435069324	3535	Business	26900.00
0005435069363	3535	Business	26900.00
0005435925250	3535	Business	26900.00
0005435069339	3535	Business	26900.00
0005435925249	3535	Business	26900.00
0005435069340	3535	Business	26900.00
0005435069372	3535	Business	26900.00
0005435069344	3535	Business	26900.00
0005435718985	3535	Business	26900.00
0005435069355	3535	Economy	9000.00
0005435069332	3535	Economy	9000.00
0005435069328	3535	Economy	9000.00
0005435069346	3535	Economy	9000.00
0005435925221	3535	Economy	9000.00
0005435069366	3535	Economy	9000.00
0005435069342	3535	Economy	9000.00
0005435925245	3535	Economy	9000.00
0005435069330	3535	Economy	9000.00
0005435069338	3535	Economy	9900.00
0005435069359	3535	Economy	9900.00
0005435925268	3535	Economy	9900.00
0005435069357	3535	Economy	9000.00
0005435069349	3535	Economy	9000.00
0005435069343	3535	Economy	9000.00
0005435069348	3535	Economy	9000.00
0005435069370	3535	Economy	9000.00
0005435925222	3535	Economy	9000.00
0005435718980	3535	Economy	9000.00
0005435069334	3535	Economy	9000.00
0005435925270	3535	Economy	9000.00
0005435069351	3535	Economy	9000.00
0005435925209	3535	Economy	9000.00
0005435925246	3535	Economy	9000.00
0005435069353	3535	Economy	9000.00
0005435069373	3535	Economy	9000.00
0005435718983	3535	Economy	9000.00
0005435925256	3535	Economy	9000.00
0005435069369	3535	Economy	9000.00
0005435069362	3535	Economy	9000.00
0005435069336	3535	Economy	9000.00
0005435925207	3535	Economy	9000.00
0005435069335	3535	Economy	9000.00
0005435069367	3535	Economy	9000.00
0005435939872	3535	Economy	9000.00
0005435069350	3535	Economy	9000.00
0005435925252	3535	Economy	9000.00
0005435718986	3535	Economy	9000.00
0005435718984	3535	Economy	9000.00
0005435925269	3535	Economy	9000.00
0005435069358	3535	Economy	9000.00
0005435925247	3535	Economy	9000.00
0005435069333	3535	Economy	9000.00
0005435718981	3535	Economy	9000.00
0005435069365	3535	Economy	9000.00
0005435069345	3535	Economy	9000.00
0005435069374	3535	Economy	9000.00
0005435925239	3535	Economy	9000.00
0005435069361	3535	Economy	9000.00
0005435069347	3535	Economy	9000.00
0005435718982	3535	Economy	9000.00
0005435925244	3535	Economy	9000.00
0005435069352	3535	Economy	9000.00
0005435069356	3535	Economy	9000.00
0005435069360	3535	Economy	9000.00
0005435069325	3535	Economy	9000.00
0005435069368	3535	Economy	9000.00
0005435069341	3535	Economy	9000.00
0005435069371	3535	Economy	9000.00
0005435069329	3535	Economy	9000.00
0005435069376	3535	Economy	9000.00
0005435069364	3535	Economy	9000.00
0005435069327	3535	Economy	9000.00
0005435925208	3535	Economy	9000.00
0005435939871	3535	Economy	9000.00
0005435069354	3535	Economy	9000.00
0005435069337	3535	Economy	9000.00
0005435069375	3535	Economy	9000.00
0005435069326	3535	Economy	9000.00
0005435069331	3535	Economy	9000.00
0005435068739	15330	Business	26900.00
0005435068755	15330	Business	26900.00
0005435068790	15330	Business	26900.00
0005435068998	15330	Business	26900.00
0005435068793	15330	Business	26900.00
0005435068848	15330	Business	26900.00
0005435068885	15330	Business	26900.00
0005435068411	15330	Economy	9000.00
0005435069062	15330	Economy	9000.00
0005435925363	15330	Economy	9000.00
0005435068808	15330	Economy	9000.00
0005435068667	15330	Economy	9000.00
0005435068938	15330	Economy	9000.00
0005435925361	15330	Economy	9000.00
0005435068847	15330	Economy	9000.00
0005435925362	15330	Economy	9900.00
0005435068881	15330	Economy	9900.00
0005435068816	15330	Economy	9900.00
0005435925357	15330	Economy	9900.00
0005435068410	15330	Economy	9900.00
0005435068913	15330	Economy	9000.00
0005435068814	15330	Economy	9000.00
0005435068798	15330	Economy	9000.00
0005435068674	15330	Economy	9000.00
0005435068719	15330	Economy	9000.00
0005435068791	15330	Economy	9000.00
0005435068997	15330	Economy	9000.00
0005435068675	15330	Economy	9000.00
0005435069159	15330	Economy	9000.00
0005435069158	15330	Economy	9000.00
0005435068949	15330	Economy	9000.00
0005435068935	15330	Economy	9000.00
0005435068841	15330	Economy	9000.00
0005435068740	15330	Economy	9000.00
0005435068801	15330	Economy	9000.00
0005435925359	15330	Economy	9000.00
0005435068756	15330	Economy	9000.00
0005435068933	15330	Economy	9000.00
0005435068813	15330	Economy	9000.00
0005435068810	15330	Economy	9000.00
0005435068840	15330	Economy	9000.00
0005435069007	15330	Economy	9000.00
0005435068993	15330	Economy	9000.00
0005435068953	15330	Economy	9000.00
0005435068811	15330	Economy	9000.00
0005435068629	15330	Economy	9000.00
0005435068720	15330	Economy	9000.00
0005435068934	15330	Economy	9000.00
0005435068839	15330	Economy	9000.00
0005435068857	15330	Economy	9000.00
0005435925364	15330	Economy	9000.00
0005435068628	15330	Economy	9000.00
0005435068866	15330	Economy	9000.00
0005435068638	15330	Economy	9000.00
0005435925360	15330	Economy	9000.00
0005435068954	15330	Economy	9000.00
0005435068856	15330	Economy	9000.00
0005435068880	15330	Economy	9000.00
0005435068950	15330	Economy	9000.00
0005435925358	15330	Economy	9000.00
0005435068854	15330	Economy	9000.00
0005435068921	15330	Economy	9000.00
0005435068800	15330	Economy	9000.00
0005435068807	15330	Economy	9000.00
0005435068792	15330	Economy	9000.00
0005435068815	15330	Economy	9000.00
0005435068855	15330	Economy	9000.00
0005435069045	15330	Economy	9000.00
0005435068980	15330	Economy	9000.00
0005435068752	15330	Economy	9000.00
0005435068637	15330	Economy	9000.00
0005435069074	15330	Economy	9000.00
0005435068858	15330	Economy	9000.00
0005432660828	18117	Economy	5900.00
0005432659718	18117	Economy	5900.00
0005432660827	18117	Economy	5900.00
0005432658600	18117	Economy	5900.00
0005432658601	18117	Economy	5900.00
0005432659717	18117	Economy	5900.00
0005432659716	18117	Economy	5900.00
0005432660802	26363	Economy	5900.00
0005432667445	26363	Economy	5900.00
0005432667449	26363	Economy	5900.00
0005432667448	26363	Economy	5900.00
0005432667440	26363	Economy	5900.00
0005432667446	26363	Economy	5900.00
0005432660806	26363	Economy	5900.00
0005432664125	26363	Economy	5900.00
0005432901515	36	Business	20000.00
0005433101858	36	Business	20000.00
0005433101992	36	Business	20000.00
0005433101896	36	Business	20000.00
0005432157502	36	Business	20000.00
0005433102002	36	Business	20000.00
0005432901571	36	Business	20000.00
0005433102006	36	Business	20000.00
0005432901594	36	Business	20000.00
0005433102007	36	Business	20000.00
0005433101854	36	Business	20000.00
0005433101997	36	Business	20000.00
0005433101882	36	Business	20000.00
0005433101955	36	Business	20000.00
0005432677537	36	Business	20000.00
0005433101953	36	Business	20000.00
0005432901545	36	Economy	7300.00
0005432901566	36	Economy	7300.00
0005433101790	36	Economy	7300.00
0005433102005	36	Economy	7300.00
0005433101958	36	Economy	6700.00
0005433101907	36	Economy	6700.00
0005433101983	36	Economy	6700.00
0005433101945	36	Economy	6700.00
0005432901514	36	Economy	6700.00
0005432919758	36	Economy	6700.00
0005432919768	36	Economy	6700.00
0005432919808	36	Economy	6700.00
0005432919772	36	Economy	6700.00
0005433101897	36	Economy	6700.00
0005433101908	36	Economy	6700.00
0005433101987	36	Economy	6700.00
0005433101894	36	Economy	6700.00
0005432901593	36	Economy	6700.00
0005433101927	36	Economy	6700.00
0005432919799	36	Economy	6700.00
0005432919869	36	Economy	6700.00
0005433101951	36	Economy	6700.00
0005432677560	36	Economy	6700.00
0005432677544	36	Economy	6700.00
0005433101956	36	Economy	6700.00
0005433101957	36	Economy	6700.00
0005432919857	36	Economy	6700.00
0005433101779	36	Economy	6700.00
0005433101922	36	Economy	6700.00
0005433101973	36	Economy	6700.00
0005433101888	36	Economy	6700.00
0005433101925	36	Economy	6700.00
0005433101932	36	Economy	6700.00
0005433101712	36	Economy	6700.00
0005432919773	36	Economy	6700.00
0005432901592	36	Economy	6700.00
0005432919754	36	Economy	6700.00
0005433102001	36	Economy	6700.00
0005433101889	36	Economy	6700.00
0005433101954	36	Economy	6700.00
0005432919868	36	Economy	6700.00
0005433101940	36	Economy	6700.00
0005432901555	36	Economy	6700.00
0005433101905	36	Economy	6700.00
0005432919813	36	Economy	7300.00
0005432919793	36	Economy	7300.00
0005433101681	36	Economy	7300.00
0005433101959	36	Economy	7300.00
0005432677538	36	Economy	7300.00
0005433101989	36	Economy	6700.00
0005433101926	36	Economy	6700.00
0005433102012	36	Economy	6700.00
0005432919757	36	Economy	6700.00
0005433101971	36	Economy	6700.00
0005433101974	36	Economy	6700.00
0005433101988	36	Economy	6700.00
0005433101869	36	Economy	6700.00
0005432919858	36	Economy	6700.00
0005433101921	36	Economy	6700.00
0005432919874	36	Economy	6700.00
0005432919800	36	Economy	6700.00
0005433101765	36	Economy	6700.00
0005433102011	36	Economy	6700.00
0005432919770	36	Economy	6700.00
0005433102008	36	Economy	6700.00
0005432919776	36	Economy	6700.00
0005433101713	36	Economy	6700.00
0005432919763	36	Economy	6700.00
0005432919755	36	Economy	6700.00
0005433101904	36	Economy	6700.00
0005432919760	36	Economy	6700.00
0005432677561	36	Economy	6700.00
0005433101764	36	Economy	6700.00
0005433101931	36	Economy	6700.00
0005432901573	36	Economy	6700.00
0005433101944	36	Economy	6700.00
0005432901544	36	Economy	6700.00
0005432901481	36	Economy	6700.00
0005433101995	36	Economy	6700.00
0005433101963	36	Economy	6700.00
0005432901570	36	Economy	6700.00
0005433101939	36	Economy	6700.00
0005432262120	37	Business	20000.00
0005432262127	37	Business	20000.00
0005432262139	37	Business	20000.00
0005432262130	37	Business	20000.00
0005432262147	37	Business	20000.00
0005433690924	37	Business	20000.00
0005432262136	37	Business	20000.00
0005432817625	37	Business	20000.00
0005432262140	37	Business	20000.00
0005432207672	37	Business	20000.00
0005432262132	37	Business	20000.00
0005432262153	37	Business	20000.00
0005432262152	37	Economy	7300.00
0005432262137	37	Economy	7300.00
0005432262159	37	Economy	7300.00
0005432262154	37	Economy	7300.00
0005432289002	37	Economy	7300.00
0005432262133	37	Economy	6700.00
0005432289004	37	Economy	6700.00
0005432262161	37	Economy	6700.00
0005432262155	37	Economy	6700.00
0005432817626	37	Economy	6700.00
0005432262131	37	Economy	6700.00
0005433687699	37	Economy	6700.00
0005432262134	37	Economy	6700.00
0005432262148	37	Economy	6700.00
0005432756824	37	Economy	6700.00
0005432262126	37	Economy	6700.00
0005432262160	37	Economy	6700.00
0005432817623	37	Economy	6700.00
0005432817613	37	Economy	6700.00
0005432262125	37	Economy	6700.00
0005432262143	37	Economy	6700.00
0005433687698	37	Economy	6700.00
0005432817608	37	Economy	6700.00
0005432817635	37	Economy	6700.00
0005432262158	37	Economy	6700.00
0005432262135	37	Economy	6700.00
0005432262146	37	Economy	6700.00
0005432262124	37	Economy	6700.00
0005432817615	37	Economy	6700.00
0005432817622	37	Economy	6700.00
0005432756822	37	Economy	6700.00
0005433690923	37	Economy	6700.00
0005432817632	37	Economy	6700.00
0005433690917	37	Economy	6700.00
0005432262116	37	Economy	6700.00
0005432817631	37	Economy	6700.00
0005432262122	37	Economy	6700.00
0005432756823	37	Economy	6700.00
0005432817614	37	Economy	6700.00
0005432207673	37	Economy	6700.00
0005432817627	37	Economy	6700.00
0005432262157	37	Economy	6700.00
0005433687700	37	Economy	7300.00
0005432262150	37	Economy	7300.00
0005432262156	37	Economy	7300.00
0005432262141	37	Economy	7300.00
0005432817620	37	Economy	6700.00
0005432817633	37	Economy	6700.00
0005432207671	37	Economy	7300.00
0005432817607	37	Economy	6700.00
0005432262142	37	Economy	6700.00
0005432756827	37	Economy	6700.00
0005432817618	37	Economy	6700.00
0005432756817	37	Economy	6700.00
0005432262123	37	Economy	6700.00
0005432289001	37	Economy	6700.00
0005432817617	37	Economy	6700.00
0005432817630	37	Economy	6700.00
0005432817612	37	Economy	6700.00
0005432817624	37	Economy	6700.00
0005432262118	37	Economy	6700.00
0005432756816	37	Economy	6700.00
0005432817619	37	Economy	6700.00
0005432817611	37	Economy	6700.00
0005432262129	37	Economy	6700.00
0005432262162	37	Economy	6700.00
0005432262145	37	Economy	6700.00
0005432817634	37	Economy	6700.00
0005432262128	37	Economy	6700.00
0005433687689	37	Economy	6700.00
0005432262144	37	Economy	6700.00
0005432817629	37	Economy	6700.00
0005432262149	37	Economy	6700.00
0005432817616	37	Economy	6700.00
0005432753289	37	Economy	6700.00
0005432262117	37	Economy	6700.00
0005433690918	37	Economy	6700.00
0005432262119	37	Economy	6700.00
0005432817609	37	Economy	6700.00
0005432262121	37	Economy	6700.00
0005432817610	37	Economy	6700.00
0005433687693	37	Economy	6700.00
0005432262138	37	Economy	6700.00
0005432289003	37	Economy	6700.00
0005432817621	37	Economy	6700.00
0005432817628	37	Economy	6700.00
0005432817606	37	Economy	6700.00
0005432262151	37	Economy	6700.00
0005433102438	7918	Business	20000.00
0005432919965	7918	Business	20000.00
0005432392017	7918	Business	20000.00
0005432919960	7918	Business	20000.00
0005432919957	7918	Business	20000.00
0005433102403	7918	Business	20000.00
0005432020405	7918	Business	20000.00
0005433102434	7918	Business	20000.00
0005433102431	7918	Business	20000.00
0005433102420	7918	Business	20000.00
0005433102440	7918	Business	20000.00
0005432020403	7918	Business	20000.00
0005433102400	7918	Business	20000.00
0005432020387	7918	Business	20000.00
0005433102399	7918	Business	20000.00
0005433102422	7918	Business	20000.00
0005432020404	7918	Business	20000.00
0005433102429	7918	Business	20000.00
0005433102427	7918	Business	20000.00
0005433102421	7918	Business	20000.00
0005433102397	7918	Business	20000.00
0005433102407	7918	Economy	7300.00
0005432919954	7918	Economy	7300.00
0005433102412	7918	Economy	7300.00
0005432753319	7918	Economy	7300.00
0005432919956	7918	Economy	7300.00
0005432919966	7918	Economy	6700.00
0005432020398	7918	Economy	6700.00
0005433102428	7918	Economy	6700.00
0005432392014	7918	Economy	6700.00
0005432753318	7918	Economy	6700.00
0005432020386	7918	Economy	6700.00
0005433102411	7918	Economy	6700.00
0005433102416	7918	Economy	6700.00
0005432919968	7918	Economy	6700.00
0005432392016	7918	Economy	6700.00
0005433102441	7918	Economy	6700.00
0005432020392	7918	Economy	6700.00
0005432020396	7918	Economy	6700.00
0005432919964	7918	Economy	6700.00
0005432020389	7918	Economy	6700.00
0005433102402	7918	Economy	6700.00
0005433102414	7918	Economy	6700.00
0005432045623	7918	Economy	6700.00
0005432020390	7918	Economy	6700.00
0005433102413	7918	Economy	6700.00
0005432919973	7918	Economy	6700.00
0005433102418	7918	Economy	6700.00
0005433102436	7918	Economy	6700.00
0005432020393	7918	Economy	6700.00
0005433102425	7918	Economy	6700.00
0005432020397	7918	Economy	6700.00
0005432020391	7918	Economy	6700.00
0005433102435	7918	Economy	6700.00
0005433102405	7918	Economy	6700.00
0005433102404	7918	Economy	6700.00
0005432919955	7918	Economy	6700.00
0005432919971	7918	Economy	6700.00
0005432753317	7918	Economy	6700.00
0005432751544	7918	Economy	6700.00
0005432919963	7918	Economy	6700.00
0005433102408	7918	Economy	6700.00
0005432919952	7918	Economy	6700.00
0005433102401	7918	Economy	6700.00
0005433102395	7918	Economy	6700.00
0005432045624	7918	Economy	6700.00
0005433102439	7918	Economy	7300.00
0005432677595	7918	Economy	7300.00
0005433102423	7918	Economy	6700.00
0005433102430	7918	Economy	6700.00
0005432919953	7918	Economy	6700.00
0005433102396	7918	Economy	6700.00
0005432751543	7918	Economy	6700.00
0005433102424	7918	Economy	6700.00
0005432020401	7918	Economy	6700.00
0005433102419	7918	Economy	6700.00
0005432020385	7918	Economy	6700.00
0005432919970	7918	Economy	6700.00
0005432020399	7918	Economy	6700.00
0005432919972	7918	Economy	6700.00
0005432020388	7918	Economy	6700.00
0005433102406	7918	Economy	6700.00
0005432020409	7918	Economy	6700.00
0005433102398	7918	Economy	6700.00
0005432919962	7918	Economy	6700.00
0005432020394	7918	Economy	6700.00
0005432677594	7918	Economy	6700.00
0005432751542	7918	Economy	6700.00
0005433102410	7918	Economy	6700.00
0005432392015	7918	Economy	6700.00
0005433102394	7918	Economy	6700.00
0005433102415	7918	Economy	6700.00
0005432919969	7918	Economy	6700.00
0005432020408	7918	Economy	6700.00
0005432919967	7918	Economy	6700.00
0005432919961	7918	Economy	6700.00
0005432020402	7918	Economy	6700.00
0005432020395	7918	Economy	6700.00
0005432020407	7918	Economy	6700.00
0005433102417	7918	Economy	6700.00
0005433102409	7918	Economy	6700.00
0005432677596	7918	Economy	6700.00
0005433102426	7918	Economy	6700.00
0005432919959	7918	Economy	6700.00
0005432020400	7918	Economy	6700.00
0005433102437	7918	Economy	6700.00
0005432020384	7918	Economy	6700.00
0005432044539	7918	Economy	6700.00
0005433102432	7918	Economy	6700.00
0005432919958	7918	Economy	6700.00
0005433102433	7918	Economy	6700.00
0005432751545	7918	Economy	6700.00
0005432753320	7918	Economy	6700.00
0005432020406	7918	Economy	6700.00
0005432901692	8099	Business	20000.00
0005432002087	8099	Business	20000.00
0005432901694	8099	Business	20000.00
0005432817345	8099	Business	20000.00
0005432817396	8099	Business	20000.00
0005432817465	8099	Business	20000.00
0005432901691	8099	Business	20000.00
0005432817295	8099	Economy	6700.00
0005432817304	8099	Economy	6700.00
0005432817279	8099	Economy	6700.00
0005432817395	8099	Economy	6700.00
0005432901695	8099	Economy	6700.00
0005432817459	8099	Economy	6700.00
0005432817377	8099	Economy	6700.00
0005432817355	8099	Economy	6700.00
0005432817344	8099	Economy	6700.00
0005432817508	8099	Economy	6700.00
0005432817424	8099	Economy	6700.00
0005432817277	8099	Economy	6700.00
0005432901693	8099	Economy	6700.00
0005432817338	8099	Economy	6700.00
0005432817408	8099	Economy	6700.00
0005432817429	8099	Economy	6700.00
0005432817318	8099	Economy	6700.00
0005432817305	8099	Economy	7300.00
0005432901703	8099	Economy	7300.00
0005432817412	8099	Economy	6700.00
0005432817340	8099	Economy	7300.00
0005432817460	8099	Economy	6700.00
0005432901704	8099	Economy	6700.00
0005432817373	8099	Economy	6700.00
0005432002086	8099	Economy	6700.00
0005432817420	8099	Economy	6700.00
0005432817422	8099	Economy	6700.00
0005432901702	8099	Economy	6700.00
0005432901699	8099	Economy	6700.00
0005432817278	8099	Economy	6700.00
0005432901700	8099	Economy	6700.00
0005432901690	8099	Economy	6700.00
0005432817319	8099	Economy	6700.00
0005432817423	8099	Economy	6700.00
0005432901701	8099	Economy	6700.00
0005432817220	8099	Economy	6700.00
0005432817466	8099	Economy	6700.00
0005432901706	8099	Economy	6700.00
0005432901698	8099	Economy	6700.00
0005432817456	8099	Economy	6700.00
0005432817187	8099	Economy	6700.00
0005432817339	8099	Economy	6700.00
0005432901696	8099	Economy	6700.00
0005432901697	8099	Economy	6700.00
0005432901705	8099	Economy	6700.00
0005432817252	8099	Economy	6700.00
0005432901689	8099	Economy	6700.00
0005434175725	9639	Economy	6900.00
0005434175715	9639	Economy	6900.00
0005433870742	9639	Economy	6900.00
0005434175729	9639	Economy	6900.00
0005434175733	9639	Economy	6900.00
0005433870718	32320	Economy	6900.00
0005433870719	32320	Economy	6900.00
0005434175774	32320	Economy	6900.00
0005434175776	32320	Economy	6900.00
0005433870724	32320	Economy	6900.00
0005434175775	32320	Economy	6900.00
0005434175773	32320	Economy	6900.00
0005433870717	32320	Economy	6900.00
0005434878679	3510	Business	35000.00
0005434878728	3510	Business	35000.00
0005434938249	3510	Business	35000.00
0005434878721	3510	Business	35000.00
0005434938246	3510	Business	35000.00
0005432799593	3510	Business	35000.00
0005434878762	3510	Business	35000.00
0005434426753	3510	Business	35000.00
0005434938242	3510	Business	35000.00
0005434938235	3510	Business	35000.00
0005435902578	3510	Business	35000.00
0005434878760	3510	Business	35000.00
0005434426763	3510	Business	35000.00
0005435126582	3510	Business	35000.00
0005432613882	3510	Business	35000.00
0005434938236	3510	Business	35000.00
0005434878696	3510	Business	35000.00
0005435126581	3510	Business	35000.00
0005434878697	3510	Comfort	19900.00
0005434878727	3510	Comfort	19900.00
0005434938245	3510	Comfort	19900.00
0005434878759	3510	Comfort	19900.00
0005435126563	3510	Comfort	19900.00
0005434938244	3510	Comfort	19900.00
0005435902643	3510	Comfort	19900.00
0005434878690	3510	Comfort	19900.00
0005434426752	3510	Comfort	19900.00
0005434878723	3510	Comfort	19900.00
0005434426750	3510	Comfort	19900.00
0005435126567	3510	Comfort	19900.00
0005434878758	3510	Comfort	19900.00
0005434938237	3510	Comfort	19900.00
0005435126596	3510	Comfort	19900.00
0005435902681	3510	Comfort	19900.00
0005435626282	3510	Comfort	19900.00
0005434878687	3510	Comfort	19900.00
0005435902663	3510	Comfort	19900.00
0005435902549	3510	Comfort	19900.00
0005435626267	3510	Comfort	19900.00
0005432799597	3510	Comfort	19900.00
0005435626268	3510	Comfort	19900.00
0005434878689	3510	Comfort	19900.00
0005434878706	3510	Comfort	19900.00
0005435902613	3510	Comfort	19900.00
0005435902635	3510	Comfort	19900.00
0005435126597	3510	Comfort	19900.00
0005432799604	3510	Comfort	19900.00
0005432799611	3510	Comfort	19900.00
0005434878672	3510	Comfort	19900.00
0005434878765	3510	Economy	11700.00
0005434878710	3510	Economy	11700.00
0005434938247	3510	Economy	11700.00
0005434878731	3510	Economy	11700.00
0005434878742	3510	Economy	11700.00
0005434878753	3510	Economy	11700.00
0005434426764	3510	Economy	11700.00
0005434878743	3510	Economy	11700.00
0005434878717	3510	Economy	11700.00
0005434878763	3510	Economy	11700.00
0005435902628	3510	Economy	11700.00
0005434878699	3510	Economy	11700.00
0005434426770	3510	Economy	11700.00
0005434878693	3510	Economy	11700.00
0005435126572	3510	Economy	11700.00
0005434878707	3510	Economy	11700.00
0005434878766	3510	Economy	11700.00
0005435126599	3510	Economy	11700.00
0005434878757	3510	Economy	11700.00
0005435626273	3510	Economy	11700.00
0005435126570	3510	Economy	11700.00
0005434878730	3510	Economy	11700.00
0005432799591	3510	Economy	11700.00
0005432188624	3510	Economy	11700.00
0005435126591	3510	Economy	11700.00
0005434878673	3510	Economy	11700.00
0005434938241	3510	Economy	11700.00
0005435126598	3510	Economy	11700.00
0005435126566	3510	Economy	11700.00
0005435626285	3510	Economy	11700.00
0005434426760	3510	Economy	11700.00
0005432799598	3510	Economy	11700.00
0005434938234	3510	Economy	11700.00
0005432799607	3510	Economy	11700.00
0005434426749	3510	Economy	11700.00
0005432611732	3510	Economy	11700.00
0005434878749	3510	Economy	11700.00
0005435126586	3510	Economy	11700.00
0005434426759	3510	Economy	11700.00
0005434426774	3510	Economy	11700.00
0005432799610	3510	Economy	11700.00
0005435126600	3510	Economy	11700.00
0005434426748	3510	Economy	11700.00
0005434878719	3510	Economy	11700.00
0005434426754	3510	Economy	11700.00
0005434878708	3510	Economy	11700.00
0005434878751	3510	Economy	11700.00
0005435626281	3510	Economy	11700.00
0005434878755	3510	Economy	11700.00
0005434878737	3510	Economy	11700.00
0005434426762	3510	Economy	11700.00
0005434878741	3510	Economy	12800.00
0005434878745	3510	Economy	12800.00
0005435626278	3510	Economy	12800.00
0005435126604	3510	Economy	11700.00
0005435126601	3510	Economy	11700.00
0005434938239	3510	Economy	11700.00
0005432799590	3510	Economy	11700.00
0005435126588	3510	Economy	12800.00
0005434426757	3510	Economy	11700.00
0005435126575	3510	Economy	11700.00
0005434878674	3510	Economy	11700.00
0005435902668	3510	Economy	11700.00
0005434878705	3510	Economy	11700.00
0005435902669	3510	Economy	11700.00
0005434878744	3510	Economy	11700.00
0005434878720	3510	Economy	11700.00
0005435126574	3510	Economy	11700.00
0005434878702	3510	Economy	11700.00
0005435126579	3510	Economy	11700.00
0005435126573	3510	Economy	11700.00
0005434938251	3510	Economy	11700.00
0005435126568	3510	Economy	11700.00
0005435902683	3510	Economy	11700.00
0005435126583	3510	Economy	11700.00
0005432799616	3510	Economy	11700.00
0005435902575	3510	Economy	11700.00
0005434878695	3510	Economy	11700.00
0005434878682	3510	Economy	11700.00
0005435126564	3510	Economy	11700.00
0005435626283	3510	Economy	11700.00
0005434938252	3510	Economy	11700.00
0005434878683	3510	Economy	11700.00
0005434878722	3510	Economy	11700.00
0005435902636	3510	Economy	11700.00
0005434426766	3510	Economy	11700.00
0005434878726	3510	Economy	11700.00
0005435626269	3510	Economy	11700.00
0005435626272	3510	Economy	11700.00
0005435902660	3510	Economy	11700.00
0005432799615	3510	Economy	11700.00
0005434426773	3510	Economy	11700.00
0005435626274	3510	Economy	11700.00
0005432799606	3510	Economy	11700.00
0005435126595	3510	Economy	11700.00
0005432799595	3510	Economy	11700.00
0005435126585	3510	Economy	11700.00
0005434426776	3510	Economy	11700.00
0005435626271	3510	Economy	11700.00
0005435902684	3510	Economy	11700.00
0005434938243	3510	Economy	11700.00
0005434878748	3510	Economy	11700.00
0005432799613	3510	Economy	11700.00
0005434878750	3510	Economy	11700.00
0005434878698	3510	Economy	11700.00
0005432799608	3510	Economy	11700.00
0005434878714	3510	Economy	11700.00
0005435902670	3510	Economy	11700.00
0005434878735	3510	Economy	11700.00
0005434938238	3510	Economy	11700.00
0005432613883	3510	Economy	11700.00
0005435126578	3510	Economy	11700.00
0005434878732	3510	Economy	11700.00
0005432799603	3510	Economy	11700.00
0005432799599	3510	Economy	11700.00
0005434426765	3510	Economy	11700.00
0005434878680	3510	Economy	11700.00
0005435913919	3510	Economy	11700.00
0005434878718	3510	Economy	11700.00
0005435626276	3510	Economy	11700.00
0005435626279	3510	Economy	11700.00
0005435126569	3510	Economy	11700.00
0005434878703	3510	Economy	11700.00
0005434426771	3510	Economy	11700.00
0005435626277	3510	Economy	11700.00
0005432188623	3510	Economy	11700.00
0005434878725	3510	Economy	11700.00
0005434426751	3510	Economy	11700.00
0005432613884	3510	Economy	11700.00
0005435126602	3510	Economy	11700.00
0005434878712	3510	Economy	11700.00
0005434878761	3510	Economy	11700.00
0005435626286	3510	Economy	11700.00
0005435126565	3510	Economy	11700.00
0005435902657	3510	Economy	11700.00
0005434938233	3510	Economy	11700.00
0005434878740	3510	Economy	11700.00
0005435126577	3510	Economy	11700.00
0005435126593	3510	Economy	11700.00
0005434426769	3510	Economy	11700.00
0005435841090	3510	Economy	12800.00
0005432799589	3510	Economy	11700.00
0005434426761	3510	Economy	12800.00
0005435626284	3510	Economy	11700.00
0005434878734	3510	Economy	11700.00
0005434878752	3510	Economy	11700.00
0005432799602	3510	Economy	11700.00
0005434878724	3510	Economy	11700.00
0005432799596	3510	Economy	11700.00
0005434426767	3510	Economy	11700.00
0005435126589	3510	Economy	11700.00
0005434878691	3510	Economy	11700.00
0005435902576	3510	Economy	11700.00
0005432799592	3510	Economy	11700.00
0005434878694	3510	Economy	11700.00
0005434878681	3510	Economy	11700.00
0005435902577	3510	Economy	11700.00
0005435626280	3510	Economy	11700.00
0005434878736	3510	Economy	11700.00
0005434878688	3510	Economy	11700.00
0005435126594	3510	Economy	11700.00
0005432611731	3510	Economy	11700.00
0005435626270	3510	Economy	11700.00
0005434878756	3510	Economy	11700.00
0005434878701	3510	Economy	11700.00
0005432799614	3510	Economy	11700.00
0005435902685	3510	Economy	11700.00
0005432799594	3510	Economy	11700.00
0005432799605	3510	Economy	11700.00
0005432188625	3510	Economy	11700.00
0005434878692	3510	Economy	11700.00
0005435126603	3510	Economy	11700.00
0005434878709	3510	Economy	11700.00
0005435126587	3510	Economy	11700.00
0005434878711	3510	Economy	11700.00
0005434938250	3510	Economy	11700.00
0005434878678	3510	Economy	11700.00
0005434878704	3510	Economy	11700.00
0005432799601	3510	Economy	11700.00
0005435126576	3510	Economy	11700.00
0005434426758	3510	Economy	11700.00
0005435841819	3510	Economy	11700.00
0005435626266	3510	Economy	11700.00
0005434878716	3510	Economy	11700.00
0005434878754	3510	Economy	11700.00
0005434426768	3510	Economy	11700.00
0005434878685	3510	Economy	11700.00
0005434878739	3510	Economy	11700.00
0005434878733	3510	Economy	11700.00
0005434938248	3510	Economy	11700.00
0005435902658	3510	Economy	11700.00
0005432799612	3510	Economy	11700.00
0005434426755	3510	Economy	11700.00
0005434878729	3510	Economy	11700.00
0005434426772	3510	Economy	11700.00
0005432183478	3510	Economy	11700.00
0005434878713	3510	Economy	11700.00
0005434878715	3510	Economy	11700.00
0005434878675	3510	Economy	11700.00
0005435126584	3510	Economy	11700.00
0005434878700	3510	Economy	11700.00
0005432611733	3510	Economy	11700.00
0005434426777	3510	Economy	11700.00
0005435913896	3510	Economy	11700.00
0005434426756	3510	Economy	11700.00
0005435126590	3510	Economy	11700.00
0005435126571	3510	Economy	11700.00
0005434878677	3510	Economy	11700.00
0005434426775	3510	Economy	11700.00
0005435126580	3510	Economy	11700.00
0005434878684	3510	Economy	11700.00
0005435626275	3510	Economy	11700.00
0005435902627	3510	Economy	11700.00
0005434878686	3510	Economy	11700.00
0005434878747	3510	Economy	11700.00
0005434878738	3510	Economy	11700.00
0005434878746	3510	Economy	11700.00
0005432799600	3510	Economy	11700.00
0005435902637	3510	Economy	11700.00
0005432799609	3510	Economy	11700.00
0005434878676	3510	Economy	11700.00
0005434938240	3510	Economy	11700.00
0005435902630	3510	Economy	11700.00
0005432799617	3510	Economy	11700.00
0005434878764	3510	Economy	11700.00
0005435126592	3510	Economy	11700.00
0005432607548	14571	Business	35000.00
0005434878199	14571	Business	35000.00
0005434426521	14571	Business	35000.00
0005435626093	14571	Business	35000.00
0005434426570	14571	Business	35000.00
0005434878003	14571	Business	35000.00
0005435902786	14571	Business	35000.00
0005435626129	14571	Business	35000.00
0005432799312	14571	Business	35000.00
0005432799274	14571	Business	35000.00
0005434877751	14571	Business	35000.00
0005434938071	14571	Business	35000.00
0005434877821	14571	Business	35000.00
0005434878174	14571	Business	35000.00
0005434937959	14571	Business	35000.00
0005435126002	14571	Business	35000.00
0005432611711	14571	Comfort	19900.00
0005432799359	14571	Business	35000.00
0005434938072	14571	Comfort	19900.00
0005434877881	14571	Comfort	19900.00
0005435902803	14571	Comfort	19900.00
0005434877780	14571	Comfort	19900.00
0005434426542	14571	Comfort	19900.00
0005432799437	14571	Comfort	19900.00
0005432799311	14571	Comfort	19900.00
0005435902788	14571	Comfort	19900.00
0005435913947	14571	Comfort	19900.00
0005435126222	14571	Comfort	19900.00
0005434877747	14571	Comfort	19900.00
0005435626089	14571	Comfort	19900.00
0005434878018	14571	Comfort	19900.00
0005434878056	14571	Comfort	19900.00
0005432799227	14571	Comfort	19900.00
0005434878085	14571	Comfort	19900.00
0005435626072	14571	Comfort	19900.00
0005435626047	14571	Comfort	19900.00
0005434877696	14571	Comfort	19900.00
0005434426522	14571	Comfort	19900.00
0005434426588	14571	Comfort	19900.00
0005434877947	14571	Comfort	19900.00
0005434877720	14571	Comfort	19900.00
0005435126073	14571	Comfort	19900.00
0005435126169	14571	Comfort	19900.00
0005435913954	14571	Comfort	19900.00
0005432799308	14571	Comfort	19900.00
0005432611707	14571	Comfort	19900.00
0005434878026	14571	Comfort	19900.00
0005432799341	14571	Comfort	19900.00
0005434877882	14571	Economy	11700.00
0005435913951	14571	Economy	11700.00
0005435902802	14571	Economy	11700.00
0005435626115	14571	Economy	11700.00
0005434877443	14571	Economy	11700.00
0005432799368	14571	Economy	11700.00
0005432799330	14571	Economy	11700.00
0005434877822	14571	Economy	11700.00
0005432799361	14571	Economy	11700.00
0005434878332	14571	Economy	11700.00
0005435626116	14571	Economy	11700.00
0005434938027	14571	Economy	11700.00
0005434878433	14571	Economy	11700.00
0005432799352	14571	Economy	11700.00
0005434877536	14571	Economy	11700.00
0005435126183	14571	Economy	11700.00
0005435902793	14571	Economy	11700.00
0005434877354	14571	Economy	11700.00
0005435626136	14571	Economy	11700.00
0005435902795	14571	Economy	11700.00
0005434877750	14571	Economy	11700.00
0005432799334	14571	Economy	11700.00
0005434878132	14571	Economy	11700.00
0005432799332	14571	Economy	11700.00
0005434878087	14571	Economy	11700.00
0005435126003	14571	Economy	11700.00
0005435626046	14571	Economy	11700.00
0005435126176	14571	Economy	11700.00
0005434878175	14571	Economy	11700.00
0005432799249	14571	Economy	11700.00
0005432799415	14571	Economy	11700.00
0005435914700	14571	Economy	11700.00
0005434877458	14571	Economy	11700.00
0005435902800	14571	Economy	11700.00
0005432799350	14571	Economy	11700.00
0005435902789	14571	Economy	11700.00
0005434877944	14571	Economy	11700.00
0005434877909	14571	Economy	11700.00
0005435126184	14571	Economy	11700.00
0005435626105	14571	Economy	11700.00
0005435126190	14571	Economy	12800.00
0005435126191	14571	Economy	12800.00
0005434878221	14571	Economy	11700.00
0005434878001	14571	Economy	11700.00
0005435913948	14571	Economy	11700.00
0005434878075	14571	Economy	12800.00
0005435913950	14571	Economy	11700.00
0005435902791	14571	Economy	11700.00
0005434878202	14571	Economy	11700.00
0005434877705	14571	Economy	11700.00
0005432611702	14571	Economy	11700.00
0005435126177	14571	Economy	11700.00
0005434426545	14571	Economy	11700.00
0005435902796	14571	Economy	11700.00
0005432799239	14571	Economy	11700.00
0005434877761	14571	Economy	11700.00
0005434426569	14571	Economy	11700.00
0005434426477	14571	Economy	11700.00
0005434938088	14571	Economy	11700.00
0005432799224	14571	Economy	11700.00
0005432607553	14571	Economy	11700.00
0005434878027	14571	Economy	11700.00
0005434877719	14571	Economy	11700.00
0005435126174	14571	Economy	11700.00
0005432799421	14571	Economy	11700.00
0005435626117	14571	Economy	11700.00
0005434878002	14571	Economy	11700.00
0005434426587	14571	Economy	11700.00
0005435626051	14571	Economy	11700.00
0005432799384	14571	Economy	11700.00
0005434878295	14571	Economy	11700.00
0005434426378	14571	Economy	11700.00
0005434878167	14571	Economy	11700.00
0005434877704	14571	Economy	11700.00
0005432799223	14571	Economy	11700.00
0005432611692	14571	Economy	11700.00
0005434426653	14571	Economy	11700.00
0005435126109	14571	Economy	11700.00
0005434877686	14571	Economy	11700.00
0005435902792	14571	Economy	11700.00
0005434877788	14571	Economy	11700.00
0005434426436	14571	Economy	11700.00
0005432799439	14571	Economy	11700.00
0005435126072	14571	Economy	11700.00
0005432799385	14571	Economy	11700.00
0005435126185	14571	Economy	11700.00
0005435126085	14571	Economy	11700.00
0005432607545	14571	Economy	11700.00
0005435126319	14571	Economy	11700.00
0005435126166	14571	Economy	11700.00
0005435902785	14571	Economy	11700.00
0005435626085	14571	Economy	11700.00
0005435126083	14571	Economy	11700.00
0005434426523	14571	Economy	11700.00
0005435913952	14571	Economy	11700.00
0005434426491	14571	Economy	11700.00
0005434878354	14571	Economy	11700.00
0005434877697	14571	Economy	11700.00
0005435902790	14571	Economy	11700.00
0005435126233	14571	Economy	11700.00
0005435126110	14571	Economy	11700.00
0005434426435	14571	Economy	11700.00
0005432611701	14571	Economy	11700.00
0005432799280	14571	Economy	11700.00
0005434878024	14571	Economy	11700.00
0005434878023	14571	Economy	11700.00
0005432799400	14571	Economy	11700.00
0005435902787	14571	Economy	11700.00
0005434426566	14571	Economy	11700.00
0005434878173	14571	Economy	11700.00
0005432799295	14571	Economy	11700.00
0005435125941	14571	Economy	11700.00
0005435626073	14571	Economy	11700.00
0005434426571	14571	Economy	11700.00
0005435902801	14571	Economy	11700.00
0005434877910	14571	Economy	11700.00
0005435902799	14571	Economy	11700.00
0005434877785	14571	Economy	11700.00
0005434426473	14571	Economy	11700.00
0005434878220	14571	Economy	11700.00
0005435913949	14571	Economy	11700.00
0005432799349	14571	Economy	11700.00
0005432799240	14571	Economy	11700.00
0005432607560	14571	Economy	11700.00
0005434877695	14571	Economy	11700.00
0005434877837	14571	Economy	12800.00
0005434877966	14571	Economy	12800.00
0005435126194	14571	Economy	12800.00
0005434426654	14571	Economy	11700.00
0005434938180	14571	Economy	11700.00
0005434938086	14571	Economy	11700.00
0005434938022	14571	Economy	11700.00
0005435126167	14571	Economy	11700.00
0005434938026	14571	Economy	11700.00
0005434426568	14571	Economy	11700.00
0005432799491	14571	Economy	11700.00
0005435626130	14571	Economy	11700.00
0005434877784	14571	Economy	11700.00
0005434877537	14571	Economy	11700.00
0005435126269	14571	Economy	11700.00
0005434877164	14571	Economy	11700.00
0005434877907	14571	Economy	11700.00
0005432799226	14571	Economy	11700.00
0005434878096	14571	Economy	11700.00
0005434878198	14571	Economy	11700.00
0005432607549	14571	Economy	11700.00
0005434877933	14571	Economy	11700.00
0005434938179	14571	Economy	11700.00
0005432799327	14571	Economy	11700.00
0005434878086	14571	Economy	11700.00
0005432799195	14571	Economy	11700.00
0005434877956	14571	Economy	11700.00
0005435902794	14571	Economy	11700.00
0005435626111	14571	Economy	11700.00
0005434877848	14571	Economy	11700.00
0005434877923	14571	Economy	11700.00
0005434877698	14571	Economy	11700.00
0005435902797	14571	Economy	11700.00
0005434877353	14571	Economy	11700.00
0005434426610	14571	Economy	11700.00
0005434938055	14571	Economy	11700.00
0005434878250	14571	Economy	11700.00
0005434426395	14571	Economy	11700.00
0005435126350	14571	Economy	11700.00
0005432799383	14571	Economy	11700.00
0005432799196	14571	Economy	11700.00
0005434426487	14571	Economy	11700.00
0005435126234	14571	Economy	11700.00
0005434878009	14571	Economy	11700.00
0005434426492	14571	Economy	11700.00
0005434878333	14571	Economy	11700.00
0005434878081	14571	Economy	11700.00
0005434877899	14571	Economy	11700.00
0005432611710	14571	Economy	11700.00
0005434877626	14571	Economy	11700.00
0005432799426	14571	Economy	11700.00
0005432799490	14571	Economy	11700.00
0005434878170	14571	Economy	11700.00
0005432799331	14571	Economy	11700.00
0005432799194	14571	Economy	11700.00
0005435902798	14571	Economy	11700.00
0005435626029	14571	Economy	11700.00
0005435126175	14571	Economy	11700.00
0005435913953	14571	Economy	11700.00
0005434426510	14571	Economy	11700.00
0005434878251	14571	Economy	11700.00
0005432059515	14571	Economy	11700.00
0005434426555	14571	Economy	11700.00
0005432799313	14571	Economy	11700.00
0005434877703	14571	Economy	11700.00
0005434877945	14571	Economy	11700.00
0005435126301	14571	Economy	11700.00
0005432799538	14571	Economy	11700.00
0005434877661	14571	Economy	11700.00
0005434878249	14571	Economy	11700.00
0005432799333	14571	Economy	11700.00
0005434877948	14571	Economy	11700.00
0005434878055	14571	Economy	11700.00
0005434426618	14571	Economy	11700.00
0005434878432	14571	Economy	11700.00
0005434878117	14571	Economy	11700.00
0005432611691	14571	Economy	11700.00
0005435126192	14571	Economy	11700.00
0005434312329	3620	Economy	14800.00
0005434325714	3620	Economy	14800.00
0005434325706	3620	Economy	14800.00
0005434325715	3620	Economy	14800.00
0005434325713	3620	Economy	14800.00
0005434325709	3620	Economy	14800.00
0005435889849	3620	Economy	14800.00
0005434325705	3620	Economy	14800.00
0005434312330	3620	Economy	14800.00
0005434325712	3620	Economy	14800.00
0005434325703	3620	Economy	14800.00
0005434325704	3620	Economy	14800.00
0005434325716	3620	Economy	14800.00
0005435889864	3620	Economy	14800.00
0005434325711	3620	Economy	14800.00
0005434325707	3620	Economy	14800.00
0005434312328	3620	Economy	14800.00
0005434325710	3620	Economy	14800.00
0005434325708	3620	Economy	14800.00
0005434325614	15594	Economy	16300.00
0005435889928	15594	Economy	16300.00
0005434325615	15594	Economy	16300.00
0005434325624	15594	Economy	14800.00
0005434325654	15594	Economy	14800.00
0005434325603	15594	Economy	14800.00
0005435889927	15594	Economy	14800.00
0005435889925	15594	Economy	14800.00
0005434325660	15594	Economy	14800.00
0005434325608	15594	Economy	14800.00
0005435889926	15594	Economy	14800.00
0005434325607	15594	Economy	14800.00
0005434325633	15594	Economy	14800.00
0005434325632	15594	Economy	14800.00
0005434325577	15594	Economy	14800.00
0005434325601	15594	Economy	14800.00
0005434325602	15594	Economy	14800.00
0005435889930	15594	Economy	14800.00
0005435889929	15594	Economy	14800.00
0005435957783	635	Economy	4500.00
0005433420366	635	Economy	4500.00
0005435957777	635	Economy	4500.00
0005433420361	635	Economy	4100.00
0005435957778	635	Economy	4100.00
0005433420367	635	Economy	4100.00
0005435957779	635	Economy	4100.00
0005433420359	635	Economy	4100.00
0005433420382	635	Economy	4100.00
0005435957784	635	Economy	4100.00
0005435957776	635	Economy	4100.00
0005435957781	635	Economy	4100.00
0005435957773	635	Economy	4100.00
0005435957782	635	Economy	4100.00
0005433420358	635	Economy	4100.00
0005435957775	635	Economy	4100.00
0005433420374	635	Economy	4100.00
0005435957772	635	Economy	4100.00
0005433420375	635	Economy	4100.00
0005433420376	635	Economy	4100.00
0005433420357	635	Economy	4100.00
0005435957780	635	Economy	4100.00
0005435957771	635	Economy	4100.00
0005435957785	635	Economy	4100.00
0005435957774	635	Economy	4100.00
0005433420360	635	Economy	4100.00
0005433420443	15154	Economy	4500.00
0005435957702	15154	Economy	4100.00
0005435957652	15154	Economy	4100.00
0005435957658	15154	Economy	4100.00
0005433420444	15154	Economy	4100.00
0005435957622	15154	Economy	4100.00
0005435957703	15154	Economy	4100.00
0005435957653	15154	Economy	4100.00
0005435957623	15154	Economy	4100.00
0005435957663	15154	Economy	4100.00
0005435957648	15154	Economy	4100.00
0005433420446	15154	Economy	4100.00
0005433420442	15154	Economy	4100.00
0005433420447	15154	Economy	4100.00
0005433420445	15154	Economy	4100.00
0005435957662	15154	Economy	4100.00
0005433420449	15154	Economy	4100.00
0005435957661	15154	Economy	4100.00
0005435957659	15154	Economy	4100.00
0005435957649	15154	Economy	4100.00
0005435957664	15154	Economy	4100.00
0005433420448	15154	Economy	4100.00
0005434995287	23997	Business	94000.00
0005434995294	23997	Economy	31300.00
0005434995295	23997	Economy	31300.00
0005434995293	23997	Economy	31300.00
0005434995291	23997	Economy	31300.00
0005434995292	23997	Economy	31300.00
0005434995296	23997	Economy	31300.00
0005434995290	23997	Economy	31300.00
0005434995284	23997	Economy	31300.00
0005434995308	23997	Economy	31300.00
0005434995289	23997	Economy	31300.00
0005434995286	23997	Economy	31300.00
0005434995285	23997	Economy	31300.00
0005434995288	23997	Economy	31300.00
0005434995309	23997	Economy	31300.00
0005434247141	8924	Economy	10400.00
0005434247144	8924	Economy	10400.00
0005434247146	8924	Economy	10400.00
0005434247142	8924	Economy	10400.00
0005435629395	16107	Economy	10400.00
0005434247161	16107	Economy	10400.00
0005434247159	16107	Economy	10400.00
0005434247160	16107	Economy	10400.00
0005435797542	2851	Business	12600.00
0005435797553	2851	Business	12600.00
0005435797547	2851	Business	12600.00
0005435797540	2851	Economy	4200.00
0005435797548	2851	Economy	4200.00
0005433404807	2851	Economy	4600.00
0005435797541	2851	Economy	4600.00
0005433404817	2851	Economy	4600.00
0005433404776	2851	Economy	4200.00
0005433404778	2851	Economy	4200.00
0005433404816	2851	Economy	4200.00
0005435797551	2851	Economy	4200.00
0005435797552	2851	Economy	4200.00
0005435797546	2851	Economy	4200.00
0005435797550	2851	Economy	4200.00
0005433404818	2851	Economy	4200.00
0005433404779	2851	Economy	4200.00
0005435797549	2851	Economy	4200.00
0005435797545	2851	Economy	4200.00
0005433404796	2851	Economy	4200.00
0005435797544	2851	Economy	4200.00
0005435797554	2851	Economy	4200.00
0005433404781	2851	Economy	4200.00
0005435797543	2851	Economy	4200.00
0005435797436	29353	Business	12600.00
0005435797444	29353	Business	12600.00
0005433404849	29353	Economy	4200.00
0005435797448	29353	Economy	4200.00
0005435797471	29353	Economy	4200.00
0005433404852	29353	Economy	4600.00
0005433404846	29353	Economy	4600.00
0005435797454	29353	Economy	4600.00
0005435797369	29353	Economy	4200.00
0005433404845	29353	Economy	4200.00
0005435797453	29353	Economy	4200.00
0005435797431	29353	Economy	4200.00
0005433404850	29353	Economy	4200.00
0005435797449	29353	Economy	4200.00
0005435797441	29353	Economy	4200.00
0005435797359	29353	Economy	4200.00
0005435797443	29353	Economy	4200.00
0005435797483	29353	Economy	4200.00
0005433404851	29353	Economy	4200.00
0005435797477	29353	Economy	4200.00
0005435797482	29353	Economy	4200.00
0005433404847	29353	Economy	4200.00
0005433404844	29353	Economy	4200.00
0005435797430	29353	Economy	4200.00
0005435797478	29353	Economy	4200.00
0005433404848	29353	Economy	4200.00
0005435797428	29353	Economy	4200.00
0005435797442	29353	Economy	4200.00
0005435797440	29353	Economy	4200.00
0005435797358	29353	Economy	4200.00
0005434948057	5848	Economy	6800.00
0005434948055	5848	Economy	6800.00
0005434948058	5848	Economy	6800.00
0005434948063	5848	Economy	6800.00
0005434948061	5848	Economy	6800.00
0005434948060	5848	Economy	6800.00
0005434948059	5848	Economy	6800.00
0005434948062	5848	Economy	6800.00
0005434948056	5848	Economy	6800.00
0005435376364	16338	Economy	6800.00
0005435376363	16338	Economy	6800.00
0005434947996	16338	Economy	6800.00
0005434947999	16338	Economy	6800.00
0005435376361	16338	Economy	6800.00
0005435376362	16338	Economy	6800.00
0005434947997	16338	Economy	6800.00
0005435376365	16338	Economy	6800.00
0005434948014	16338	Economy	6800.00
0005433961200	6944	Business	21400.00
0005433961204	6944	Business	21400.00
0005433961207	6944	Business	21400.00
0005433961198	6944	Business	21400.00
0005433961197	6944	Business	21400.00
0005433961208	6944	Economy	7100.00
0005433961179	6944	Economy	7100.00
0005433961199	6944	Economy	7100.00
0005433961170	6944	Economy	7100.00
0005433961196	6944	Economy	7800.00
0005433961178	6944	Economy	7800.00
0005433961181	6944	Economy	7800.00
0005433961182	6944	Economy	7100.00
0005433961180	6944	Economy	7100.00
0005433961167	6944	Economy	7100.00
0005433961205	6944	Economy	7100.00
0005433961177	6944	Economy	7100.00
0005433961171	6944	Economy	7100.00
0005433961190	6944	Economy	7100.00
0005433961172	6944	Economy	7100.00
0005433961210	6944	Economy	7100.00
0005433961211	6944	Economy	7100.00
0005433961175	6944	Economy	7100.00
0005433961194	6944	Economy	7100.00
0005433961209	6944	Economy	7100.00
0005433961174	6944	Economy	7100.00
0005433961193	6944	Economy	7100.00
0005433961186	6944	Economy	7100.00
0005433961184	6944	Economy	7100.00
0005433961189	6944	Economy	7100.00
0005433961187	6944	Economy	7100.00
0005433961202	6944	Economy	7100.00
0005433961195	6944	Economy	7100.00
0005433961166	6944	Economy	7100.00
0005433961185	6944	Economy	7100.00
0005433961201	6944	Economy	7100.00
0005433961192	6944	Economy	7100.00
0005433961191	6944	Economy	7100.00
0005433961203	6944	Economy	7100.00
0005433961169	6944	Economy	7100.00
0005433961176	6944	Economy	7100.00
0005433961206	6944	Economy	7100.00
0005433961173	6944	Economy	7100.00
0005433961183	6944	Economy	7100.00
0005433961188	6944	Economy	7100.00
0005433961165	6944	Economy	7100.00
0005433961168	6944	Economy	7100.00
0005433960605	25771	Business	21400.00
0005433960401	25771	Business	21400.00
0005433960592	25771	Business	21400.00
0005433960468	25771	Business	21400.00
0005433960494	25771	Business	21400.00
0005433960556	25771	Business	21400.00
0005433960465	25771	Economy	7100.00
0005433960358	25771	Economy	7100.00
0005433960508	25771	Economy	7100.00
0005433960482	25771	Economy	7100.00
0005433960449	25771	Economy	7100.00
0005433960558	25771	Economy	7100.00
0005433960580	25771	Economy	7100.00
0005433960477	25771	Economy	7800.00
0005433960464	25771	Economy	7800.00
0005433960609	25771	Economy	7800.00
0005433960571	25771	Economy	7100.00
0005433960490	25771	Economy	7100.00
0005433960507	25771	Economy	7100.00
0005433960557	25771	Economy	7100.00
0005433960448	25771	Economy	7100.00
0005433960331	25771	Economy	7100.00
0005433960404	25771	Economy	7100.00
0005433960443	25771	Economy	7100.00
0005433960395	25771	Economy	7100.00
0005433960541	25771	Economy	7100.00
0005433960582	25771	Economy	7100.00
0005433960559	25771	Economy	7100.00
0005433960534	25771	Economy	7100.00
0005433960467	25771	Economy	7100.00
0005433960625	25771	Economy	7100.00
0005433960478	25771	Economy	7100.00
0005433960565	25771	Economy	7100.00
0005433960330	25771	Economy	7100.00
0005433960386	25771	Economy	7100.00
0005433960472	25771	Economy	7100.00
0005433960281	25771	Economy	7100.00
0005433960476	25771	Economy	7100.00
0005433960542	25771	Economy	7100.00
0005433960469	25771	Economy	7100.00
0005433960388	25771	Economy	7100.00
0005433960332	25771	Economy	7100.00
0005433960489	25771	Economy	7100.00
0005433960509	25771	Economy	7100.00
0005433960493	25771	Economy	7100.00
0005433960470	25771	Economy	7100.00
0005433960579	25771	Economy	7100.00
0005433960555	25771	Economy	7100.00
0005433960411	25771	Economy	7100.00
0005433960289	25771	Economy	7100.00
0005433960583	25771	Economy	7100.00
0005433960375	25771	Economy	7100.00
0005433960479	25771	Economy	7100.00
0005433960394	25771	Economy	7100.00
0005433960568	25771	Economy	7100.00
0005433960393	25771	Economy	7100.00
0005433960535	25771	Economy	7100.00
0005433960392	25771	Economy	7100.00
0005433960359	25771	Economy	7100.00
0005435082720	24463	Economy	3900.00
0005435082782	24463	Economy	3900.00
0005435082685	24463	Economy	3900.00
0005435082783	24463	Economy	3900.00
0005435082686	24463	Economy	3900.00
0005435082773	24463	Economy	3900.00
0005435082777	24463	Economy	3900.00
0005435082769	24463	Economy	3900.00
0005435082747	24463	Economy	3900.00
0005435082813	26111	Economy	3900.00
0005435082819	26111	Economy	3900.00
0005435082820	26111	Economy	3900.00
0005435082821	26111	Economy	3900.00
0005435082814	26111	Economy	3900.00
0005435082816	26111	Economy	3900.00
0005435082818	26111	Economy	3900.00
0005435082815	26111	Economy	3900.00
0005435082817	26111	Economy	3900.00
0005435082822	26111	Economy	3900.00
0005435286620	4950	Business	18000.00
0005435286623	4950	Business	18000.00
0005434245132	4950	Business	18000.00
0005433534487	4950	Business	18000.00
0005434245139	4950	Business	18000.00
0005435286621	4950	Business	18000.00
0005434245129	4950	Business	18000.00
0005434245122	4950	Business	18000.00
0005435286622	4950	Economy	6000.00
0005434245135	4950	Economy	6000.00
0005434245128	4950	Economy	6000.00
0005432166919	4950	Economy	6000.00
0005434245136	4950	Economy	6000.00
0005434245116	4950	Economy	6000.00
0005434245145	4950	Economy	6000.00
0005433534486	4950	Economy	6000.00
0005434245131	4950	Economy	6000.00
0005433534490	4950	Economy	6000.00
0005434245120	4950	Economy	6000.00
0005434245146	4950	Economy	6000.00
0005433534489	4950	Economy	6000.00
0005434245119	4950	Economy	6600.00
0005434245125	4950	Economy	6600.00
0005434245124	4950	Economy	6600.00
0005434245144	4950	Economy	6000.00
0005434245118	4950	Economy	6000.00
0005434245117	4950	Economy	6000.00
0005434245138	4950	Economy	6000.00
0005434245133	4950	Economy	6000.00
0005434245137	4950	Economy	6000.00
0005432166920	4950	Economy	6000.00
0005432166918	4950	Economy	6000.00
0005434245142	4950	Economy	6000.00
0005434245143	4950	Economy	6000.00
0005434245121	4950	Economy	6000.00
0005434245130	4950	Economy	6000.00
0005435286597	4950	Economy	6000.00
0005432166917	4950	Economy	6000.00
0005434245127	4950	Economy	6000.00
0005434245126	4950	Economy	6000.00
0005434245141	4950	Economy	6000.00
0005434245123	4950	Economy	6000.00
0005434245134	4950	Economy	6000.00
0005434245140	4950	Economy	6000.00
0005433785148	4951	Business	18000.00
0005433785134	4951	Business	18000.00
0005432105797	4951	Business	18000.00
0005433785115	4951	Business	18000.00
0005433615042	4951	Business	18000.00
0005433785135	4951	Business	18000.00
0005433615079	4951	Business	18000.00
0005432105817	4951	Business	18000.00
0005433615066	4951	Business	18000.00
0005433615069	4951	Business	18000.00
0005433615085	4951	Business	18000.00
0005432665285	4951	Business	18000.00
0005433615082	4951	Business	18000.00
0005433615103	4951	Business	18000.00
0005433785116	4951	Business	18000.00
0005433615043	4951	Business	18000.00
0005433615036	4951	Business	18000.00
0005433785117	4951	Business	18000.00
0005432105829	4951	Business	18000.00
0005433785144	4951	Business	18000.00
0005432105804	4951	Business	18000.00
0005433785132	4951	Business	18000.00
0005433785125	4951	Business	18000.00
0005432145122	4951	Business	18000.00
0005432105830	4951	Business	18000.00
0005433615102	4951	Business	18000.00
0005433615090	4951	Business	18000.00
0005432105798	4951	Business	18000.00
0005433615047	4951	Economy	6600.00
0005433615053	4951	Economy	6600.00
0005432105836	4951	Economy	6600.00
0005433785131	4951	Economy	6600.00
0005433615048	4951	Economy	6600.00
0005433615084	4951	Economy	6600.00
0005432105801	4951	Economy	6000.00
0005433785113	4951	Economy	6000.00
0005432105794	4951	Economy	6000.00
0005433615097	4951	Economy	6000.00
0005433785142	4951	Economy	6000.00
0005433615104	4951	Economy	6000.00
0005432105833	4951	Economy	6000.00
0005433785127	4951	Economy	6000.00
0005433615051	4951	Economy	6000.00
0005433615093	4951	Economy	6000.00
0005433615107	4951	Economy	6000.00
0005433615096	4951	Economy	6000.00
0005433615092	4951	Economy	6000.00
0005432105818	4951	Economy	6000.00
0005433615068	4951	Economy	6000.00
0005432105795	4951	Economy	6000.00
0005433615039	4951	Economy	6000.00
0005433615070	4951	Economy	6000.00
0005432105813	4951	Economy	6000.00
0005433615105	4951	Economy	6000.00
0005433615076	4951	Economy	6000.00
0005432105828	4951	Economy	6000.00
0005433615049	4951	Economy	6000.00
0005433785151	4951	Economy	6000.00
0005433785114	4951	Economy	6000.00
0005433615041	4951	Economy	6000.00
0005432105793	4951	Economy	6000.00
0005433785128	4951	Economy	6000.00
0005432105812	4951	Economy	6000.00
0005433785120	4951	Economy	6000.00
0005433615098	4951	Economy	6000.00
0005433785136	4951	Economy	6000.00
0005433615040	4951	Economy	6000.00
0005433615054	4951	Economy	6000.00
0005432105823	4951	Economy	6000.00
0005433785124	4951	Economy	6000.00
0005433785119	4951	Economy	6000.00
0005432105791	4951	Economy	6000.00
0005433785126	4951	Economy	6000.00
0005433615062	4951	Economy	6000.00
0005433785139	4951	Economy	6000.00
0005433785133	4951	Economy	6000.00
0005432105810	4951	Economy	6000.00
0005433615059	4951	Economy	6000.00
0005433615056	4951	Economy	6000.00
0005432105832	4951	Economy	6000.00
0005433785110	4951	Economy	6000.00
0005433615081	4951	Economy	6000.00
0005432105809	4951	Economy	6000.00
0005432105796	4951	Economy	6000.00
0005433615037	4951	Economy	6000.00
0005433785111	4951	Economy	6000.00
0005432105827	4951	Economy	6000.00
0005433615091	4951	Economy	6000.00
0005433615100	4951	Economy	6000.00
0005433615072	4951	Economy	6000.00
0005433615045	4951	Economy	6000.00
0005433615052	4951	Economy	6000.00
0005432105799	4951	Economy	6000.00
0005433615094	4951	Economy	6000.00
0005433785112	4951	Economy	6600.00
0005433615067	4951	Economy	6600.00
0005432105789	4951	Economy	6600.00
0005432105831	4951	Economy	6600.00
0005433785130	4951	Economy	6000.00
0005433615038	4951	Economy	6600.00
0005432105811	4951	Economy	6000.00
0005433615071	4951	Economy	6000.00
0005433615063	4951	Economy	6000.00
0005433615057	4951	Economy	6600.00
0005433615080	4951	Economy	6000.00
0005433615086	4951	Economy	6000.00
0005433615073	4951	Economy	6000.00
0005432105814	4951	Economy	6000.00
0005433615095	4951	Economy	6000.00
0005433615044	4951	Economy	6000.00
0005433785150	4951	Economy	6000.00
0005432105825	4951	Economy	6000.00
0005433615078	4951	Economy	6000.00
0005433785146	4951	Economy	6000.00
0005433785143	4951	Economy	6000.00
0005432105815	4951	Economy	6000.00
0005433615101	4951	Economy	6000.00
0005433615046	4951	Economy	6000.00
0005433615061	4951	Economy	6000.00
0005433785152	4951	Economy	6000.00
0005432666399	4951	Economy	6000.00
0005432105808	4951	Economy	6000.00
0005432105807	4951	Economy	6000.00
0005433785147	4951	Economy	6000.00
0005433785141	4951	Economy	6000.00
0005432665284	4951	Economy	6000.00
0005433785138	4951	Economy	6000.00
0005433615077	4951	Economy	6000.00
0005432105800	4951	Economy	6000.00
0005433615074	4951	Economy	6000.00
0005433785145	4951	Economy	6000.00
0005433615089	4951	Economy	6000.00
0005432105806	4951	Economy	6000.00
0005433785122	4951	Economy	6000.00
0005433785118	4951	Economy	6000.00
0005433785140	4951	Economy	6000.00
0005432105802	4951	Economy	6000.00
0005432105826	4951	Economy	6000.00
0005432105835	4951	Economy	6000.00
0005432105790	4951	Economy	6000.00
0005433615035	4951	Economy	6000.00
0005433615106	4951	Economy	6000.00
0005432105792	4951	Economy	6000.00
0005432667464	4951	Economy	6000.00
0005433615034	4951	Economy	6000.00
0005433615087	4951	Economy	6000.00
0005433615058	4951	Economy	6000.00
0005432105816	4951	Economy	6000.00
0005433615050	4951	Economy	6000.00
0005433615075	4951	Economy	6000.00
0005432105805	4951	Economy	6000.00
0005433785123	4951	Economy	6000.00
0005433615088	4951	Economy	6000.00
0005433785149	4951	Economy	6000.00
0005433615060	4951	Economy	6000.00
0005433615064	4951	Economy	6000.00
0005432105824	4951	Economy	6000.00
0005433615055	4951	Economy	6000.00
0005432105819	4951	Economy	6000.00
0005433785137	4951	Economy	6000.00
0005432105834	4951	Economy	6000.00
0005432105803	4951	Economy	6000.00
0005433785121	4951	Economy	6000.00
0005433615083	4951	Economy	6000.00
0005433785129	4951	Economy	6000.00
0005432105820	4951	Economy	6000.00
0005432105821	4951	Economy	6000.00
0005432105822	4951	Economy	6000.00
0005433615065	4951	Economy	6000.00
0005433615099	4951	Economy	6000.00
0005435006871	4953	Business	18000.00
0005434229482	4953	Business	18000.00
0005433688807	4953	Business	18000.00
0005434229475	4953	Business	18000.00
0005434229476	4953	Business	18000.00
0005434265261	4953	Business	18000.00
0005435006901	4953	Business	18000.00
0005435006964	4953	Business	18000.00
0005434229484	4953	Business	18000.00
0005435006866	4953	Business	18000.00
0005435007013	4953	Business	18000.00
0005434311209	4953	Business	18000.00
0005435006902	4953	Business	18000.00
0005435269700	4953	Business	18000.00
0005435006994	4953	Business	18000.00
0005435269735	4953	Business	18000.00
0005435269734	4953	Business	18000.00
0005434265279	4953	Business	18000.00
0005434229478	4953	Business	18000.00
0005434265259	4953	Business	18000.00
0005434265263	4953	Business	18000.00
0005434265282	4953	Economy	6600.00
0005434149790	4953	Economy	6600.00
0005434265262	4953	Economy	6600.00
0005435006925	4953	Economy	6600.00
0005435006986	4953	Economy	6000.00
0005434265276	4953	Economy	6000.00
0005434229479	4953	Economy	6000.00
0005434265258	4953	Economy	6000.00
0005433688806	4953	Economy	6000.00
0005434229494	4953	Economy	6000.00
0005434229493	4953	Economy	6000.00
0005435269740	4953	Economy	6000.00
0005434229490	4953	Economy	6000.00
0005434229481	4953	Economy	6000.00
0005435006993	4953	Economy	6000.00
0005434265266	4953	Economy	6000.00
0005432336036	4953	Economy	6000.00
0005434265267	4953	Economy	6000.00
0005432335976	4953	Economy	6000.00
0005434265269	4953	Economy	6000.00
0005434229488	4953	Economy	6000.00
0005435269725	4953	Economy	6000.00
0005434173538	4953	Economy	6000.00
0005432336031	4953	Economy	6000.00
0005435269737	4953	Economy	6000.00
0005434149789	4953	Economy	6000.00
0005435006971	4953	Economy	6000.00
0005435006969	4953	Economy	6000.00
0005435269710	4953	Economy	6000.00
0005435006936	4953	Economy	6000.00
0005434149795	4953	Economy	6000.00
0005434173541	4953	Economy	6000.00
0005434265265	4953	Economy	6000.00
0005435269730	4953	Economy	6000.00
0005434312312	4953	Economy	6000.00
0005435269711	4953	Economy	6000.00
0005434265268	4953	Economy	6000.00
0005435006958	4953	Economy	6000.00
0005434229497	4953	Economy	6000.00
0005435269692	4953	Economy	6000.00
0005434265270	4953	Economy	6000.00
0005435006978	4953	Economy	6000.00
0005432336044	4953	Economy	6000.00
0005434149791	4953	Economy	6000.00
0005434229492	4953	Economy	6000.00
0005435006891	4953	Economy	6000.00
0005435269739	4953	Economy	6000.00
0005435006833	4953	Economy	6000.00
0005432336005	4953	Economy	6600.00
0005435007012	4953	Economy	6600.00
0005434173540	4953	Economy	6600.00
0005433685519	4953	Economy	6600.00
0005434265274	4953	Economy	6000.00
0005432336043	4953	Economy	6000.00
0005432336003	4953	Economy	6000.00
0005435006972	4953	Economy	6000.00
0005434149786	4953	Economy	6000.00
0005435006946	4953	Economy	6000.00
0005435269701	4953	Economy	6000.00
0005434229489	4953	Economy	6000.00
0005432336030	4953	Economy	6000.00
0005434149796	4953	Economy	6000.00
0005435006977	4953	Economy	6000.00
0005434265272	4953	Economy	6000.00
0005435006832	4953	Economy	6000.00
0005435006933	4953	Economy	6000.00
0005434149785	4953	Economy	6000.00
0005435269738	4953	Economy	6000.00
0005435006976	4953	Economy	6000.00
0005435006892	4953	Economy	6000.00
0005434229485	4953	Economy	6000.00
0005434265280	4953	Economy	6000.00
0005434173542	4953	Economy	6000.00
0005434149794	4953	Economy	6000.00
0005435006926	4953	Economy	6000.00
0005432335931	4953	Economy	6000.00
0005434265275	4953	Economy	6000.00
0005434265273	4953	Economy	6000.00
0005434173539	4953	Economy	6000.00
0005434265278	4953	Economy	6000.00
0005434149788	4953	Economy	6000.00
0005435006947	4953	Economy	6000.00
0005433688792	4953	Economy	6000.00
0005434229496	4953	Economy	6000.00
0005434265277	4953	Economy	6000.00
0005434265281	4953	Economy	6000.00
0005434229480	4953	Economy	6000.00
0005432336004	4953	Economy	6000.00
0005435269736	4953	Economy	6000.00
0005434229487	4953	Economy	6000.00
0005434229495	4953	Economy	6000.00
0005434312313	4953	Economy	6000.00
0005434311216	4953	Economy	6000.00
0005435269699	4953	Economy	6000.00
0005434265271	4953	Economy	6000.00
0005434265264	4953	Economy	6000.00
0005435007003	4953	Economy	6000.00
0005434229477	4953	Economy	6000.00
0005432335998	4953	Economy	6000.00
0005434149792	4953	Economy	6000.00
0005434149787	4953	Economy	6000.00
0005434229483	4953	Economy	6000.00
0005434149793	4953	Economy	6000.00
0005434265283	4953	Economy	6000.00
0005435006905	4953	Economy	6000.00
0005434265260	4953	Economy	6000.00
0005434229491	4953	Economy	6000.00
0005434229486	4953	Economy	6000.00
0005435269712	4953	Economy	6000.00
0005434244923	8550	Business	18000.00
0005434245013	8550	Business	18000.00
0005433784918	8550	Business	18000.00
0005434244748	8550	Business	18000.00
0005432659698	8550	Business	18000.00
0005434244943	8550	Business	18000.00
0005433784816	8550	Business	18000.00
0005434244924	8550	Business	18000.00
0005433784828	8550	Business	18000.00
0005434244895	8550	Business	18000.00
0005434244918	8550	Business	18000.00
0005433784723	8550	Business	18000.00
0005433784943	8550	Business	18000.00
0005433784730	8550	Economy	6600.00
0005433784968	8550	Economy	6600.00
0005434244811	8550	Economy	6600.00
0005433784808	8550	Economy	6000.00
0005434244933	8550	Economy	6000.00
0005433784774	8550	Economy	6000.00
0005433784902	8550	Economy	6000.00
0005432666387	8550	Economy	6000.00
0005432666377	8550	Economy	6000.00
0005433785021	8550	Economy	6000.00
0005434244886	8550	Economy	6000.00
0005433784772	8550	Economy	6000.00
0005433784767	8550	Economy	6000.00
0005433784969	8550	Economy	6000.00
0005434244855	8550	Economy	6000.00
0005434244835	8550	Economy	6000.00
0005434244951	8550	Economy	6000.00
0005434244928	8550	Economy	6000.00
0005432666366	8550	Economy	6000.00
0005434244879	8550	Economy	6000.00
0005432659692	8550	Economy	6000.00
0005433784877	8550	Economy	6000.00
0005432659697	8550	Economy	6000.00
0005433784823	8550	Economy	6000.00
0005433784717	8550	Economy	6000.00
0005433784956	8550	Economy	6000.00
0005434244875	8550	Economy	6000.00
0005433784689	8550	Economy	6000.00
0005435269774	8550	Economy	6000.00
0005432659693	8550	Economy	6000.00
0005434244934	8550	Economy	6000.00
0005434244812	8550	Economy	6000.00
0005433784895	8550	Economy	6600.00
0005433784957	8550	Economy	6600.00
0005433784829	8550	Economy	6000.00
0005433784778	8550	Economy	6000.00
0005434244849	8550	Economy	6000.00
0005433784526	8550	Economy	6000.00
0005433784919	8550	Economy	6000.00
0005433784815	8550	Economy	6000.00
0005434245003	8550	Economy	6000.00
0005434244740	8550	Economy	6000.00
0005433784899	8550	Economy	6000.00
0005433784768	8550	Economy	6000.00
0005433784721	8550	Economy	6000.00
0005435269775	8550	Economy	6000.00
0005434244942	8550	Economy	6000.00
0005434244885	8550	Economy	6000.00
0005433784807	8550	Economy	6000.00
0005433784773	8550	Economy	6000.00
0005434244826	8550	Economy	6000.00
0005433784865	8550	Economy	6000.00
0005432659694	8550	Economy	6000.00
0005434244856	8550	Economy	6000.00
0005435269776	8550	Economy	6000.00
0005434245004	8550	Economy	6000.00
0005433784729	8550	Economy	6000.00
0005433784814	8550	Economy	6000.00
0005432666379	8550	Economy	6000.00
0005434244848	8550	Economy	6000.00
0005433784680	8550	Economy	6000.00
0005434244847	8550	Economy	6000.00
0005433784833	8550	Economy	6000.00
0005433784722	8550	Economy	6000.00
0005433784821	8550	Economy	6000.00
0005432666378	8550	Economy	6000.00
0005434244739	8550	Economy	6000.00
0005433784866	8550	Economy	6000.00
0005434244894	8550	Economy	6000.00
0005433784859	8550	Economy	6000.00
0005434244878	8550	Economy	6000.00
0005433614399	8551	Business	18000.00
0005433614413	8551	Business	18000.00
0005433614432	8551	Business	18000.00
0005433614570	8551	Business	18000.00
0005433614252	8551	Business	18000.00
0005433613995	8551	Business	18000.00
0005433614656	8551	Business	18000.00
0005433614419	8551	Business	18000.00
0005433614431	8551	Business	18000.00
0005433614190	8551	Economy	6600.00
0005433614612	8551	Economy	6600.00
0005433614256	8551	Economy	6000.00
0005433614411	8551	Economy	6000.00
0005433614465	8551	Economy	6000.00
0005433614345	8551	Economy	6000.00
0005433614616	8551	Economy	6000.00
0005433614609	8551	Economy	6000.00
0005433614478	8551	Economy	6000.00
0005433614402	8551	Economy	6000.00
0005433614267	8551	Economy	6000.00
0005433614468	8551	Economy	6000.00
0005433614648	8551	Economy	6000.00
0005433614343	8551	Economy	6000.00
0005433614526	8551	Economy	6000.00
0005433614390	8551	Economy	6000.00
0005433614117	8551	Economy	6000.00
0005433614613	8551	Economy	6000.00
0005433614467	8551	Economy	6000.00
0005433614571	8551	Economy	6000.00
0005433614410	8551	Economy	6000.00
0005433614414	8551	Economy	6000.00
0005433614191	8551	Economy	6000.00
0005433614342	8551	Economy	6000.00
0005433614396	8551	Economy	6000.00
0005433614251	8551	Economy	6000.00
0005433614274	8551	Economy	6000.00
0005433614011	8551	Economy	6000.00
0005433614370	8551	Economy	6600.00
0005433614352	8551	Economy	6600.00
0005433614368	8551	Economy	6600.00
0005433614403	8551	Economy	6600.00
0005433614346	8551	Economy	6000.00
0005433614459	8551	Economy	6000.00
0005433614714	8551	Economy	6000.00
0005433614420	8551	Economy	6000.00
0005433614367	8551	Economy	6000.00
0005433614404	8551	Economy	6000.00
0005433614361	8551	Economy	6000.00
0005433614360	8551	Economy	6000.00
0005433614466	8551	Economy	6000.00
0005433614212	8551	Economy	6000.00
0005433614394	8551	Economy	6000.00
0005433614393	8551	Economy	6000.00
0005433614489	8551	Economy	6000.00
0005433614728	8551	Economy	6000.00
0005433614273	8551	Economy	6000.00
0005433614362	8551	Economy	6000.00
0005433614730	8551	Economy	6000.00
0005433614573	8551	Economy	6000.00
0005433614649	8551	Economy	6000.00
0005433614729	8551	Economy	6000.00
0005433614250	8551	Economy	6000.00
0005433614160	8551	Economy	6000.00
0005433614369	8551	Economy	6000.00
0005433614203	8551	Economy	6000.00
0005433614344	8551	Economy	6000.00
0005433614458	8551	Economy	6000.00
0005433614488	8551	Economy	6000.00
0005433614713	8551	Economy	6000.00
0005434149675	8552	Business	18000.00
0005434264950	8552	Business	18000.00
0005432336099	8552	Business	18000.00
0005432047569	8552	Business	18000.00
0005434265006	8552	Business	18000.00
0005432035080	8552	Business	18000.00
0005434311232	8552	Business	18000.00
0005435286658	8552	Business	18000.00
0005434229344	8552	Business	18000.00
0005432035094	8552	Business	18000.00
0005435286657	8552	Business	18000.00
0005435007139	8552	Business	18000.00
0005434265009	8552	Business	18000.00
0005432035076	8552	Business	18000.00
0005433688819	8552	Business	18000.00
0005434229378	8552	Business	18000.00
0005435007147	8552	Business	18000.00
0005434229297	8552	Business	18000.00
0005432035083	8552	Business	18000.00
0005432336095	8552	Business	18000.00
0005435007141	8552	Business	18000.00
0005434149684	8552	Business	18000.00
0005432035093	8552	Business	18000.00
0005432035103	8552	Business	18000.00
0005433815413	8552	Business	18000.00
0005435007145	8552	Economy	6600.00
0005434173514	8552	Economy	6600.00
0005432035097	8552	Economy	6600.00
0005434173508	8552	Economy	6600.00
0005434265042	8552	Economy	6600.00
0005434265010	8552	Economy	6000.00
0005435007159	8552	Economy	6600.00
0005432035081	8552	Economy	6000.00
0005434264877	8552	Economy	6000.00
0005432035102	8552	Economy	6000.00
0005433815410	8552	Economy	6000.00
0005432035099	8552	Economy	6000.00
0005432035086	8552	Economy	6000.00
0005434229317	8552	Economy	6000.00
0005434173502	8552	Economy	6000.00
0005435007143	8552	Economy	6000.00
0005435007146	8552	Economy	6000.00
0005435286652	8552	Economy	6000.00
0005434264970	8552	Economy	6000.00
0005435007157	8552	Economy	6000.00
0005435007156	8552	Economy	6000.00
0005432035101	8552	Economy	6000.00
0005435286659	8552	Economy	6000.00
0005434265028	8552	Economy	6000.00
0005435007160	8552	Economy	6000.00
0005432035078	8552	Economy	6000.00
0005434229343	8552	Economy	6000.00
0005432035098	8552	Economy	6000.00
0005434229278	8552	Economy	6000.00
0005433815412	8552	Economy	6000.00
0005434265041	8552	Economy	6000.00
0005434265113	8552	Economy	6000.00
0005435007154	8552	Economy	6000.00
0005432035087	8552	Economy	6000.00
0005434265088	8552	Economy	6000.00
0005432035091	8552	Economy	6000.00
0005433690935	8552	Economy	6000.00
0005432035092	8552	Economy	6000.00
0005434311229	8552	Economy	6000.00
0005433534510	8552	Economy	6000.00
0005434264951	8552	Economy	6000.00
0005434229284	8552	Economy	6000.00
0005433688820	8552	Economy	6000.00
0005432047568	8552	Economy	6000.00
0005434149630	8552	Economy	6000.00
0005432035096	8552	Economy	6000.00
0005434311231	8552	Economy	6000.00
0005432336096	8552	Economy	6000.00
0005432035084	8552	Economy	6000.00
0005433815409	8552	Economy	6000.00
0005434229281	8552	Economy	6000.00
0005434264976	8552	Economy	6000.00
0005434265116	8552	Economy	6000.00
0005432035082	8552	Economy	6000.00
0005433815411	8552	Economy	6000.00
0005433689922	8552	Economy	6000.00
0005434229331	8552	Economy	6000.00
0005432047570	8552	Economy	6000.00
0005434149662	8552	Economy	6000.00
0005432336101	8552	Economy	6000.00
0005434265016	8552	Economy	6000.00
0005433534509	8552	Economy	6000.00
0005435007142	8552	Economy	6600.00
0005433534508	8552	Economy	6600.00
0005434265035	8552	Economy	6600.00
0005434265126	8552	Economy	6600.00
0005434265015	8552	Economy	6600.00
0005434265127	8552	Economy	6000.00
0005435007140	8552	Economy	6000.00
0005435007153	8552	Economy	6000.00
0005435007144	8552	Economy	6000.00
0005434229165	8552	Economy	6600.00
0005435007149	8552	Economy	6000.00
0005432336098	8552	Economy	6000.00
0005432035095	8552	Economy	6000.00
0005432336094	8552	Economy	6000.00
0005433690936	8552	Economy	6000.00
0005435007155	8552	Economy	6000.00
0005434229326	8552	Economy	6000.00
0005434264998	8552	Economy	6000.00
0005432035104	8552	Economy	6000.00
0005432035100	8552	Economy	6000.00
0005432035085	8552	Economy	6000.00
0005434264879	8552	Economy	6000.00
0005434311230	8552	Economy	6000.00
0005435007150	8552	Economy	6000.00
0005434229289	8552	Economy	6000.00
0005432035077	8552	Economy	6000.00
0005434265099	8552	Economy	6000.00
0005434264952	8552	Economy	6000.00
0005434229327	8552	Economy	6000.00
0005435007137	8552	Economy	6000.00
0005435286654	8552	Economy	6000.00
0005434265089	8552	Economy	6000.00
0005432336097	8552	Economy	6000.00
0005432035088	8552	Economy	6000.00
0005434264989	8552	Economy	6000.00
0005434229332	8552	Economy	6000.00
0005435286653	8552	Economy	6000.00
0005435286656	8552	Economy	6000.00
0005432336100	8552	Economy	6000.00
0005434229269	8552	Economy	6000.00
0005432035089	8552	Economy	6000.00
0005432035079	8552	Economy	6000.00
0005434265112	8552	Economy	6000.00
0005434229316	8552	Economy	6000.00
0005434229290	8552	Economy	6000.00
0005434264878	8552	Economy	6000.00
0005434229333	8552	Economy	6000.00
0005434173488	8552	Economy	6000.00
0005434229272	8552	Economy	6000.00
0005435007138	8552	Economy	6000.00
0005432336093	8552	Economy	6000.00
0005434264975	8552	Economy	6000.00
0005434173503	8552	Economy	6000.00
0005432336092	8552	Economy	6000.00
0005434173500	8552	Economy	6000.00
0005432035090	8552	Economy	6000.00
0005434229198	8552	Economy	6000.00
0005433689921	8552	Economy	6000.00
0005435007158	8552	Economy	6000.00
0005435007151	8552	Economy	6000.00
0005434229287	8552	Economy	6000.00
0005435286655	8552	Economy	6000.00
0005435007148	8552	Economy	6000.00
0005435007152	8552	Economy	6000.00
0005434265087	8552	Economy	6000.00
0005434229274	8552	Economy	6000.00
0005434229273	8552	Economy	6000.00
0005434229307	8552	Economy	6000.00
0005434229347	8552	Economy	6000.00
0005434639101	12619	Economy	16200.00
0005434639280	12619	Economy	16200.00
0005434639298	12619	Economy	14800.00
0005434639206	12619	Economy	14800.00
0005434639305	12619	Economy	14800.00
0005434639256	12619	Economy	14800.00
0005433202449	12619	Economy	14800.00
0005433202443	12619	Economy	14800.00
0005434639211	12619	Economy	14800.00
0005433202446	12619	Economy	14800.00
0005434639184	12619	Economy	14800.00
0005434639304	12619	Economy	14800.00
0005434639361	12619	Economy	14800.00
0005434639167	12619	Economy	14800.00
0005433202445	12619	Economy	14800.00
0005433202440	12619	Economy	14800.00
0005433202444	12619	Economy	14800.00
0005433202448	12619	Economy	14800.00
0005434639251	12619	Economy	14800.00
0005433202439	12619	Economy	14800.00
0005433202441	12619	Economy	14800.00
0005434639282	12619	Economy	14800.00
0005433202437	12619	Economy	14800.00
0005434639067	12619	Economy	14800.00
0005434639271	12619	Economy	14800.00
0005434639281	12619	Economy	14800.00
0005434639265	12619	Economy	14800.00
0005433202435	12619	Economy	14800.00
0005434639183	12619	Economy	14800.00
0005433202450	12619	Economy	14800.00
0005434639123	12619	Economy	14800.00
0005434639261	12619	Economy	14800.00
0005433202447	12619	Economy	14800.00
0005433202442	12619	Economy	14800.00
0005434639122	12619	Economy	14800.00
0005434639100	12619	Economy	14800.00
0005433202436	12619	Economy	14800.00
0005433202438	12619	Economy	14800.00
0005434639424	23365	Economy	16200.00
0005433202209	23365	Economy	16200.00
0005433202300	23365	Economy	16200.00
0005433202266	23365	Economy	16200.00
0005433202208	23365	Economy	14800.00
0005432290645	23365	Economy	14800.00
0005434639422	23365	Economy	14800.00
0005434639440	23365	Economy	14800.00
0005434639428	23365	Economy	14800.00
0005434639445	23365	Economy	14800.00
0005433202311	23365	Economy	14800.00
0005434639427	23365	Economy	14800.00
0005434639441	23365	Economy	14800.00
0005433202288	23365	Economy	14800.00
0005434639436	23365	Economy	14800.00
0005434639437	23365	Economy	14800.00
0005433202301	23365	Economy	14800.00
0005432290646	23365	Economy	14800.00
0005434639431	23365	Economy	14800.00
0005434639430	23365	Economy	14800.00
0005432290647	23365	Economy	14800.00
0005433202265	23365	Economy	14800.00
0005434639434	23365	Economy	14800.00
0005433202286	23365	Economy	14800.00
0005434639439	23365	Economy	14800.00
0005434639438	23365	Economy	14800.00
0005434639423	23365	Economy	14800.00
0005434639432	23365	Economy	14800.00
0005434639435	23365	Economy	14800.00
0005433202264	23365	Economy	14800.00
0005434639433	23365	Economy	14800.00
0005433202239	23365	Economy	14800.00
0005433202308	23365	Economy	14800.00
0005433202269	23365	Economy	14800.00
0005434639442	23365	Economy	14800.00
0005434639447	23365	Economy	14800.00
0005433202214	23365	Economy	14800.00
0005433202394	23365	Economy	14800.00
0005434639446	23365	Economy	14800.00
0005433202253	23365	Economy	14800.00
0005434639426	23365	Economy	14800.00
0005434639443	23365	Economy	14800.00
0005434639429	23365	Economy	14800.00
0005433202268	23365	Economy	14800.00
0005433202270	23365	Economy	14800.00
0005434639448	23365	Economy	14800.00
0005434639444	23365	Economy	14800.00
0005434639449	23365	Economy	14800.00
0005434639425	23365	Economy	14800.00
0005432328414	21102	Business	18900.00
0005432328543	21102	Business	18900.00
0005432382975	21102	Business	18900.00
0005432328377	21102	Business	18900.00
0005432328627	21102	Business	18900.00
0005432328438	21102	Business	18900.00
0005432382990	21102	Business	18900.00
0005432328576	21102	Business	18900.00
0005432382981	21102	Business	18900.00
0005432382887	21102	Business	18900.00
0005432328683	21102	Business	18900.00
0005432383010	21102	Business	18900.00
0005432328439	21102	Economy	6300.00
0005432328446	21102	Economy	6300.00
0005432382810	21102	Economy	6300.00
0005432328479	21102	Economy	6300.00
0005432328586	21102	Economy	6300.00
0005432383023	21102	Economy	6300.00
0005432328492	21102	Economy	6300.00
0005432383080	21102	Economy	6300.00
0005432382997	21102	Economy	6300.00
0005432328669	21102	Economy	6300.00
0005432328535	21102	Economy	6900.00
0005432383037	21102	Economy	6900.00
0005432328625	21102	Economy	6900.00
0005432382934	21102	Economy	6900.00
0005432328485	21102	Economy	6900.00
0005432328545	21102	Economy	6300.00
0005432383024	21102	Economy	6300.00
0005432382886	21102	Economy	6300.00
0005432383028	21102	Economy	6300.00
0005432382917	21102	Economy	6300.00
0005432382960	21102	Economy	6300.00
0005432382982	21102	Economy	6300.00
0005432328508	21102	Economy	6300.00
0005432328468	21102	Economy	6300.00
0005432054318	21102	Economy	6300.00
0005432328404	21102	Economy	6300.00
0005432328529	21102	Economy	6300.00
0005432328403	21102	Economy	6300.00
0005432328551	21102	Economy	6300.00
0005432383025	21102	Economy	6300.00
0005432382931	21102	Economy	6300.00
0005432382872	21102	Economy	6300.00
0005432328337	21102	Economy	6300.00
0005432328525	21102	Economy	6300.00
0005432383081	21102	Economy	6300.00
0005432328517	21102	Economy	6300.00
0005432328530	21102	Economy	6300.00
0005432054320	21102	Economy	6300.00
0005432328539	21102	Economy	6300.00
0005432383038	21102	Economy	6300.00
0005432328293	21102	Economy	6300.00
0005432328458	21102	Economy	6300.00
0005432328452	21102	Economy	6300.00
0005432328534	21102	Economy	6300.00
0005432382885	21102	Economy	6300.00
0005432382892	21102	Economy	6300.00
0005432383021	21102	Economy	6300.00
0005432328453	21102	Economy	6300.00
0005432054319	21102	Economy	6300.00
0005432328544	21102	Economy	6300.00
0005432328624	21102	Economy	6300.00
0005432383029	21102	Economy	6300.00
0005432383085	21102	Economy	6300.00
0005432328565	21102	Economy	6300.00
0005432328637	21102	Economy	6300.00
0005432382916	21102	Economy	6300.00
0005432328560	21102	Economy	6300.00
0005432328484	21102	Economy	6300.00
0005432382852	21102	Economy	6300.00
0005432328668	21102	Economy	6300.00
0005432383056	21102	Economy	6300.00
0005432328555	21102	Economy	6300.00
0005432382976	21102	Economy	6300.00
0005432328552	21102	Economy	6300.00
0005432328556	21102	Economy	6300.00
0005432328569	21102	Economy	6300.00
0005432054322	21102	Economy	6300.00
0005432328501	21102	Economy	6300.00
0005432328451	21102	Economy	6300.00
0005432328533	21102	Economy	6300.00
0005432328537	21102	Economy	6300.00
0005432328587	21102	Economy	6300.00
0005432382851	21102	Economy	6300.00
0005432328629	21102	Economy	6300.00
0005432054321	21102	Economy	6300.00
0005432383031	21102	Economy	6300.00
0005432328521	21102	Economy	6300.00
0005432328561	21102	Economy	6300.00
0005432328524	21102	Economy	6300.00
0005432328497	21102	Economy	6300.00
0005432382870	21102	Economy	6300.00
0005432383032	21102	Economy	6300.00
0005432382869	21102	Economy	6300.00
0005432383060	21102	Economy	6300.00
0005432328467	21102	Economy	6300.00
0005432328925	31221	Business	18900.00
0005432383355	31221	Business	18900.00
0005432287210	31221	Business	18900.00
0005432383333	31221	Business	18900.00
0005432383325	31221	Business	18900.00
0005432328883	31221	Business	18900.00
0005432287211	31221	Business	18900.00
0005432383334	31221	Business	18900.00
0005432328885	31221	Business	18900.00
0005432383347	31221	Business	18900.00
0005432328903	31221	Business	18900.00
0005432328914	31221	Business	18900.00
0005432287212	31221	Economy	6300.00
0005432383340	31221	Economy	6300.00
0005432328896	31221	Economy	6300.00
0005432383331	31221	Economy	6300.00
0005432328918	31221	Economy	6300.00
0005432328911	31221	Economy	6300.00
0005432328894	31221	Economy	6300.00
0005432383335	31221	Economy	6300.00
0005432383330	31221	Economy	6300.00
0005432383356	31221	Economy	6300.00
0005432328912	31221	Economy	6900.00
0005432328920	31221	Economy	6900.00
0005432328882	31221	Economy	6900.00
0005432328897	31221	Economy	6900.00
0005432383337	31221	Economy	6900.00
0005432328886	31221	Economy	6300.00
0005432328884	31221	Economy	6300.00
0005432328879	31221	Economy	6300.00
0005432383343	31221	Economy	6300.00
0005432383348	31221	Economy	6300.00
0005432383318	31221	Economy	6300.00
0005432328877	31221	Economy	6300.00
0005432328895	31221	Economy	6300.00
0005432328893	31221	Economy	6300.00
0005432328922	31221	Economy	6300.00
0005432383326	31221	Economy	6300.00
0005432328878	31221	Economy	6300.00
0005432383339	31221	Economy	6300.00
0005432328890	31221	Economy	6300.00
0005432383320	31221	Economy	6300.00
0005432383322	31221	Economy	6300.00
0005432328909	31221	Economy	6300.00
0005432383324	31221	Economy	6300.00
0005432383329	31221	Economy	6300.00
0005432383328	31221	Economy	6300.00
0005432383321	31221	Economy	6300.00
0005432383353	31221	Economy	6300.00
0005432383345	31221	Economy	6300.00
0005432328923	31221	Economy	6300.00
0005432287213	31221	Economy	6300.00
0005432328888	31221	Economy	6300.00
0005432383319	31221	Economy	6300.00
0005432383354	31221	Economy	6300.00
0005432383341	31221	Economy	6300.00
0005432383327	31221	Economy	6300.00
0005432383338	31221	Economy	6300.00
0005432328906	31221	Economy	6300.00
0005432328900	31221	Economy	6300.00
0005432328910	31221	Economy	6300.00
0005432328915	31221	Economy	6300.00
0005432328889	31221	Economy	6300.00
0005432328916	31221	Economy	6300.00
0005432328908	31221	Economy	6300.00
0005432383323	31221	Economy	6300.00
0005432328880	31221	Economy	6300.00
0005432328891	31221	Economy	6300.00
0005432328905	31221	Economy	6300.00
0005432383342	31221	Economy	6300.00
0005432328917	31221	Economy	6300.00
0005432328919	31221	Economy	6300.00
0005432383358	31221	Economy	6300.00
0005432328904	31221	Economy	6300.00
0005432328881	31221	Economy	6300.00
0005432383317	31221	Economy	6300.00
0005432328921	31221	Economy	6300.00
0005432328902	31221	Economy	6300.00
0005432328924	31221	Economy	6300.00
0005432328907	31221	Economy	6300.00
0005432328887	31221	Economy	6300.00
0005432383346	31221	Economy	6300.00
0005432328898	31221	Economy	6300.00
0005432383349	31221	Economy	6300.00
0005432383336	31221	Economy	6300.00
0005432383351	31221	Economy	6300.00
0005432328899	31221	Economy	6300.00
0005432328892	31221	Economy	6300.00
0005432328913	31221	Economy	6300.00
0005432383350	31221	Economy	6300.00
0005432383344	31221	Economy	6300.00
0005432383352	31221	Economy	6300.00
0005432328901	31221	Economy	6300.00
0005432383332	31221	Economy	6300.00
0005432383357	31221	Economy	6300.00
0005432424652	13355	Business	12700.00
0005432424666	13355	Business	12700.00
0005432424612	13355	Business	12700.00
0005432424646	13355	Business	12700.00
0005432424641	13355	Business	12700.00
0005432424644	13355	Business	12700.00
0005432424610	13355	Business	12700.00
0005432424616	13355	Business	12700.00
0005432424647	13355	Business	12700.00
0005432424640	13355	Economy	4200.00
0005432424611	13355	Economy	4200.00
0005432424613	13355	Economy	4200.00
0005432424654	13355	Economy	4200.00
0005432424660	13355	Economy	4200.00
0005432424653	13355	Economy	4200.00
0005432424648	13355	Economy	4200.00
0005432424658	13355	Economy	4700.00
0005432424617	13355	Economy	4700.00
0005432424620	13355	Economy	4700.00
0005432424631	13355	Economy	4700.00
0005432424615	13355	Economy	4200.00
0005432424625	13355	Economy	4200.00
0005432424628	13355	Economy	4200.00
0005432424636	13355	Economy	4200.00
0005432424639	13355	Economy	4200.00
0005432424667	13355	Economy	4200.00
0005432424650	13355	Economy	4200.00
0005432424656	13355	Economy	4200.00
0005432424627	13355	Economy	4200.00
0005432424614	13355	Economy	4200.00
0005432424632	13355	Economy	4200.00
0005432424642	13355	Economy	4200.00
0005432424626	13355	Economy	4200.00
0005432424622	13355	Economy	4200.00
0005432424637	13355	Economy	4200.00
0005432424621	13355	Economy	4200.00
0005432424645	13355	Economy	4200.00
0005432424619	13355	Economy	4200.00
0005432424633	13355	Economy	4200.00
0005432424623	13355	Economy	4200.00
0005432424659	13355	Economy	4200.00
0005432424649	13355	Economy	4200.00
0005432424665	13355	Economy	4200.00
0005432424638	13355	Economy	4200.00
0005432424651	13355	Economy	4200.00
0005432424630	13355	Economy	4200.00
0005432424661	13355	Economy	4200.00
0005432424657	13355	Economy	4200.00
0005432424618	13355	Economy	4200.00
0005432424663	13355	Economy	4200.00
0005432424635	13355	Economy	4200.00
0005432424624	13355	Economy	4200.00
0005432424629	13355	Economy	4200.00
0005432424662	13355	Economy	4200.00
0005432424664	13355	Economy	4200.00
0005432424634	13355	Economy	4200.00
0005432424655	13355	Economy	4200.00
0005432424643	13355	Economy	4200.00
0005432424236	30705	Business	12700.00
0005432424251	30705	Business	12700.00
0005432424217	30705	Business	12700.00
0005432424266	30705	Business	12700.00
0005432424276	30705	Business	12700.00
0005432424208	30705	Business	12700.00
0005432424244	30705	Business	12700.00
0005432424238	30705	Business	12700.00
0005432424280	30705	Business	12700.00
0005432424130	30705	Business	12700.00
0005432424311	30705	Business	12700.00
0005432424168	30705	Economy	4200.00
0005432424221	30705	Economy	4200.00
0005432424142	30705	Economy	4200.00
0005432424071	30705	Economy	4200.00
0005432424222	30705	Economy	4200.00
0005432424206	30705	Economy	4200.00
0005432424235	30705	Economy	4700.00
0005432424176	30705	Economy	4700.00
0005432424106	30705	Economy	4700.00
0005432424248	30705	Economy	4700.00
0005432424279	30705	Economy	4200.00
0005432424249	30705	Economy	4200.00
0005432424155	30705	Economy	4200.00
0005432424164	30705	Economy	4200.00
0005432424131	30705	Economy	4200.00
0005432424290	30705	Economy	4200.00
0005432424141	30705	Economy	4200.00
0005432424190	30705	Economy	4200.00
0005432424199	30705	Economy	4200.00
0005432424250	30705	Economy	4200.00
0005432424177	30705	Economy	4200.00
0005432424287	30705	Economy	4200.00
0005432424271	30705	Economy	4200.00
0005432424220	30705	Economy	4200.00
0005432424185	30705	Economy	4200.00
0005432424316	30705	Economy	4200.00
0005432424245	30705	Economy	4200.00
0005432424269	30705	Economy	4200.00
0005432424237	30705	Economy	4200.00
0005432424070	30705	Economy	4200.00
0005432424132	30705	Economy	4200.00
0005432424085	30705	Economy	4200.00
0005432424211	30705	Economy	4200.00
0005432424215	30705	Economy	4200.00
0005432424064	30705	Economy	4200.00
0005432424023	30705	Economy	4200.00
0005432424288	30705	Economy	4200.00
0005432424087	30705	Economy	4200.00
0005432424289	30705	Economy	4200.00
0005432424246	30705	Economy	4200.00
0005432424182	30705	Economy	4200.00
0005432424140	30705	Economy	4200.00
0005432424317	30705	Economy	4200.00
0005432424186	30705	Economy	4200.00
0005432424253	30705	Economy	4200.00
0005432424264	30705	Economy	4200.00
0005432424212	30705	Economy	4200.00
0005432424086	30705	Economy	4200.00
0005432424270	30705	Economy	4200.00
0005432424265	30705	Economy	4200.00
0005432424216	30705	Economy	4200.00
0005432424255	30705	Economy	4200.00
0005432424165	30705	Economy	4200.00
0005432424282	30705	Economy	4200.00
0005432424283	30705	Economy	4200.00
0005432817619	9621	Business	32600.00
0005432817630	9621	Business	32600.00
0005432822245	9621	Business	32600.00
0005432817632	9621	Business	32600.00
0005432822241	9621	Business	32600.00
0005432901564	9621	Economy	10900.00
0005432817623	9621	Economy	10900.00
0005432817608	9621	Economy	10900.00
0005432901611	9621	Economy	10900.00
0005432901462	9621	Economy	10900.00
0005432817631	9621	Economy	10900.00
0005432817606	9621	Economy	11900.00
0005432817610	9621	Economy	11900.00
0005432817614	9621	Economy	11900.00
0005432817624	9621	Economy	10900.00
0005432817627	9621	Economy	10900.00
0005432289003	9621	Economy	10900.00
0005432901610	9621	Economy	10900.00
0005432817621	9621	Economy	10900.00
0005432817633	9621	Economy	10900.00
0005432817609	9621	Economy	10900.00
0005434448332	9621	Economy	10900.00
0005434186180	9621	Economy	10900.00
0005434448333	9621	Economy	10900.00
0005432289004	9621	Economy	10900.00
0005434186200	9621	Economy	10900.00
0005432901562	9621	Economy	10900.00
0005432817607	9621	Economy	10900.00
0005434157445	9621	Economy	10900.00
0005432822239	9621	Economy	10900.00
0005432817629	9621	Economy	10900.00
0005432289001	9621	Economy	10900.00
0005434448334	9621	Economy	10900.00
0005432817612	9621	Economy	10900.00
0005432901575	9621	Economy	10900.00
0005432901527	9621	Economy	10900.00
0005432817616	9621	Economy	10900.00
0005434157446	9621	Economy	10900.00
0005432817615	9621	Economy	10900.00
0005432901595	9621	Economy	10900.00
0005434186203	9621	Economy	10900.00
0005432901558	9621	Economy	10900.00
0005432901494	9621	Economy	10900.00
0005432822238	9621	Economy	10900.00
0005432822243	9621	Economy	10900.00
0005432901598	9621	Economy	10900.00
0005432901547	9621	Economy	10900.00
0005432901559	9621	Economy	10900.00
0005432822242	9621	Economy	10900.00
0005432817613	9621	Economy	10900.00
0005432822244	9621	Economy	10900.00
0005432817622	9621	Economy	10900.00
0005432817617	9621	Economy	10900.00
0005432817634	9621	Economy	10900.00
0005432817628	9621	Economy	10900.00
0005432901597	9621	Economy	10900.00
0005432901546	9621	Economy	10900.00
0005432289002	9621	Economy	10900.00
0005432901513	9621	Economy	10900.00
0005432817611	9621	Economy	10900.00
0005432817620	9621	Economy	10900.00
0005432817626	9621	Economy	10900.00
0005432817635	9621	Economy	10900.00
0005432901600	9621	Economy	10900.00
0005432817625	9621	Economy	10900.00
0005432817618	9621	Economy	10900.00
0005432822240	9621	Economy	10900.00
0005432901563	9621	Economy	10900.00
0005432901697	28965	Business	32600.00
0005432901701	28965	Business	32600.00
0005432817459	28965	Business	32600.00
0005432817395	28965	Business	32600.00
0005432817344	28965	Business	32600.00
0005432817187	28965	Business	32600.00
0005432817422	28965	Business	32600.00
0005432817377	28965	Economy	10900.00
0005432817423	28965	Economy	10900.00
0005432817278	28965	Economy	10900.00
0005432901696	28965	Economy	10900.00
0005432817396	28965	Economy	10900.00
0005432822179	28965	Economy	10900.00
0005434157519	28965	Economy	10900.00
0005432817318	28965	Economy	10900.00
0005432901691	28965	Economy	11900.00
0005432822177	28965	Economy	11900.00
0005432817279	28965	Economy	11900.00
0005432822174	28965	Economy	11900.00
0005434186211	28965	Economy	10900.00
0005432817220	28965	Economy	10900.00
0005432822180	28965	Economy	10900.00
0005434448319	28965	Economy	10900.00
0005432817295	28965	Economy	10900.00
0005432817340	28965	Economy	10900.00
0005432822175	28965	Economy	10900.00
0005432901704	28965	Economy	10900.00
0005432817277	28965	Economy	10900.00
0005432002086	28965	Economy	10900.00
0005432901698	28965	Economy	10900.00
0005432822176	28965	Economy	10900.00
0005434448288	28965	Economy	10900.00
0005432817412	28965	Economy	10900.00
0005432901705	28965	Economy	10900.00
0005432901699	28965	Economy	10900.00
0005432822185	28965	Economy	10900.00
0005432817465	28965	Economy	10900.00
0005434448291	28965	Economy	10900.00
0005432817420	28965	Economy	10900.00
0005432901689	28965	Economy	10900.00
0005434157518	28965	Economy	10900.00
0005432817304	28965	Economy	10900.00
0005434157520	28965	Economy	10900.00
0005432817460	28965	Economy	10900.00
0005432817338	28965	Economy	10900.00
0005432817466	28965	Economy	10900.00
0005432817345	28965	Economy	10900.00
0005432901703	28965	Economy	10900.00
0005432822193	28965	Economy	10900.00
0005432002087	28965	Economy	10900.00
0005434186213	28965	Economy	10900.00
0005432901695	28965	Economy	10900.00
0005432901692	28965	Economy	10900.00
0005432901690	28965	Economy	10900.00
0005432817319	28965	Economy	10900.00
0005432817456	28965	Economy	10900.00
0005434448292	28965	Economy	10900.00
0005432901694	28965	Economy	10900.00
0005432817424	28965	Economy	10900.00
0005432817373	28965	Economy	10900.00
0005432817429	28965	Economy	10900.00
0005432817508	28965	Economy	10900.00
0005432901706	28965	Economy	10900.00
0005432817305	28965	Economy	10900.00
0005432901700	28965	Economy	10900.00
0005432817355	28965	Economy	10900.00
0005434186212	28965	Economy	10900.00
0005432822184	28965	Economy	10900.00
0005432901693	28965	Economy	10900.00
0005432901702	28965	Economy	10900.00
0005434157522	28965	Economy	10900.00
0005432817339	28965	Economy	10900.00
0005434448289	28965	Economy	10900.00
0005432817408	28965	Economy	10900.00
0005434157521	28965	Economy	10900.00
0005432817252	28965	Economy	10900.00
0005432613884	15091	Economy	11000.00
0005432611732	15091	Economy	11000.00
0005435841819	15091	Economy	11000.00
0005432611731	15091	Economy	11000.00
0005435841090	15091	Economy	11000.00
0005432613882	15091	Economy	11000.00
0005432611733	15091	Economy	11000.00
0005432613883	15091	Economy	11000.00
0005432607560	31573	Economy	11000.00
0005432611710	31573	Economy	11000.00
0005432611692	31573	Economy	11000.00
0005432607548	31573	Economy	11000.00
0005432611707	31573	Economy	11000.00
0005432611691	31573	Economy	11000.00
0005432611702	31573	Economy	11000.00
0005432607553	31573	Economy	11000.00
0005432607545	31573	Economy	11000.00
0005432611711	31573	Economy	11000.00
0005432611701	31573	Economy	11000.00
0005432607549	31573	Economy	11000.00
0005433569346	11860	Business	105900.00
0005432948150	11860	Business	105900.00
0005433569347	11860	Business	105900.00
0005432948151	11860	Business	105900.00
0005433569342	11860	Business	105900.00
0005433569359	11860	Business	105900.00
0005433569329	11860	Business	105900.00
0005432948229	11860	Business	105900.00
0005432948219	11860	Business	105900.00
0005433569350	11860	Business	105900.00
0005432948314	11860	Business	105900.00
0005432948290	11860	Business	105900.00
0005433569317	11860	Business	105900.00
0005433569336	11860	Business	105900.00
0005433569316	11860	Business	105900.00
0005432948372	11860	Business	105900.00
0005432948166	11860	Business	105900.00
0005433569348	11860	Economy	35300.00
0005432948269	11860	Economy	35300.00
0005432948291	11860	Economy	35300.00
0005433569319	11860	Economy	35300.00
0005433569310	11860	Economy	35300.00
0005432948335	11860	Economy	35300.00
0005433569321	11860	Economy	35300.00
0005432948220	11860	Economy	35300.00
0005432948144	11860	Economy	35300.00
0005433569314	11860	Economy	35300.00
0005433569311	11860	Economy	35300.00
0005433569339	11860	Economy	35300.00
0005433569351	11860	Economy	38800.00
0005433569326	11860	Economy	38800.00
0005433569324	11860	Economy	38800.00
0005432948315	11860	Economy	35300.00
0005433569313	11860	Economy	38800.00
0005433569343	11860	Economy	35300.00
0005432948174	11860	Economy	35300.00
0005433569334	11860	Economy	35300.00
0005432948370	11860	Economy	35300.00
0005433569332	11860	Economy	35300.00
0005432948228	11860	Economy	35300.00
0005432948271	11860	Economy	35300.00
0005433569304	11860	Economy	35300.00
0005433569309	11860	Economy	35300.00
0005432948452	11860	Economy	35300.00
0005433569331	11860	Economy	35300.00
0005433569312	11860	Economy	35300.00
0005433569353	11860	Economy	35300.00
0005433569355	11860	Economy	35300.00
0005433569300	11860	Economy	35300.00
0005433569302	11860	Economy	35300.00
0005433569341	11860	Economy	35300.00
0005433569335	11860	Economy	35300.00
0005432948383	11860	Economy	35300.00
0005433569303	11860	Economy	35300.00
0005433569358	11860	Economy	35300.00
0005433569338	11860	Economy	35300.00
0005432948273	11860	Economy	35300.00
0005432948165	11860	Economy	35300.00
0005433569349	11860	Economy	35300.00
0005433569315	11860	Economy	35300.00
0005432948236	11860	Economy	35300.00
0005433569340	11860	Economy	35300.00
0005432948227	11860	Economy	35300.00
0005432948205	11860	Economy	35300.00
0005432948263	11860	Economy	35300.00
0005433569323	11860	Economy	35300.00
0005433569327	11860	Economy	35300.00
0005433569344	11860	Economy	35300.00
0005433569308	11860	Economy	35300.00
0005433569322	11860	Economy	35300.00
0005432948173	11860	Economy	35300.00
0005432948167	11860	Economy	35300.00
0005433569306	11860	Economy	35300.00
0005433569325	11860	Economy	35300.00
0005433569357	11860	Economy	35300.00
0005433569354	11860	Economy	35300.00
0005433569318	11860	Economy	35300.00
0005432948130	11860	Economy	35300.00
0005432948099	11860	Economy	35300.00
0005432948347	11860	Economy	35300.00
0005432948168	11860	Economy	35300.00
0005432948453	11860	Economy	35300.00
0005433569337	11860	Economy	35300.00
0005433569356	11860	Economy	35300.00
0005433569301	11860	Economy	35300.00
0005433569328	11860	Economy	35300.00
0005433569330	11860	Economy	35300.00
0005432948285	11860	Economy	35300.00
0005432948226	11860	Economy	35300.00
0005432948204	11860	Economy	35300.00
0005432948237	11860	Economy	35300.00
0005433569307	11860	Economy	35300.00
0005433569352	11860	Economy	35300.00
0005432948170	11860	Economy	35300.00
0005432948169	11860	Economy	35300.00
0005433569345	11860	Economy	35300.00
0005433569333	11860	Economy	35300.00
0005433569305	11860	Economy	35300.00
0005433569320	11860	Economy	35300.00
0005432948712	25306	Business	105900.00
0005433568870	25306	Business	105900.00
0005433568704	25306	Business	105900.00
0005432948714	25306	Business	105900.00
0005432948697	25306	Business	105900.00
0005433568720	25306	Business	105900.00
0005432948716	25306	Business	105900.00
0005432948720	25306	Business	105900.00
0005433568747	25306	Business	105900.00
0005433568684	25306	Business	105900.00
0005433568655	25306	Business	105900.00
0005433568778	25306	Business	105900.00
0005433568639	25306	Business	105900.00
0005433568459	25306	Business	105900.00
0005432948701	25306	Business	105900.00
0005432948695	25306	Business	105900.00
0005433568792	25306	Business	105900.00
0005433568888	25306	Business	105900.00
0005432948722	25306	Business	105900.00
0005433568689	25306	Economy	35300.00
0005433568656	25306	Business	105900.00
0005432948717	25306	Economy	35300.00
0005433568818	25306	Economy	35300.00
0005433568491	25306	Economy	35300.00
0005433568742	25306	Economy	35300.00
0005433568815	25306	Economy	35300.00
0005433568833	25306	Economy	35300.00
0005433568673	25306	Economy	35300.00
0005433568584	25306	Economy	35300.00
0005433568887	25306	Economy	35300.00
0005432948690	25306	Economy	35300.00
0005432948702	25306	Economy	38800.00
0005432948685	25306	Economy	38800.00
0005433568817	25306	Economy	38800.00
0005433568744	25306	Economy	35300.00
0005432948689	25306	Economy	35300.00
0005432948705	25306	Economy	35300.00
0005432948684	25306	Economy	35300.00
0005433568714	25306	Economy	35300.00
0005433568625	25306	Economy	35300.00
0005433568909	25306	Economy	35300.00
0005433568627	25306	Economy	35300.00
0005432948681	25306	Economy	35300.00
0005432948699	25306	Economy	35300.00
0005432948719	25306	Economy	35300.00
0005432948682	25306	Economy	35300.00
0005433568816	25306	Economy	35300.00
0005433568860	25306	Economy	35300.00
0005433568795	25306	Economy	35300.00
0005432948686	25306	Economy	35300.00
0005432948710	25306	Economy	35300.00
0005433568910	25306	Economy	35300.00
0005432948708	25306	Economy	35300.00
0005432948715	25306	Economy	35300.00
0005433568760	25306	Economy	35300.00
0005432948713	25306	Economy	35300.00
0005433568797	25306	Economy	35300.00
0005432948711	25306	Economy	35300.00
0005433568806	25306	Economy	35300.00
0005432948691	25306	Economy	35300.00
0005432948688	25306	Economy	35300.00
0005433568791	25306	Economy	35300.00
0005433568640	25306	Economy	35300.00
0005432948706	25306	Economy	35300.00
0005433568722	25306	Economy	35300.00
0005433568779	25306	Economy	35300.00
0005432948696	25306	Economy	35300.00
0005432948709	25306	Economy	35300.00
0005433568798	25306	Economy	35300.00
0005433568622	25306	Economy	35300.00
0005432948700	25306	Economy	35300.00
0005433568800	25306	Economy	35300.00
0005433568920	25306	Economy	35300.00
0005432948703	25306	Economy	35300.00
0005433568748	25306	Economy	35300.00
0005433568710	25306	Economy	35300.00
0005433568669	25306	Economy	35300.00
0005432948693	25306	Economy	35300.00
0005433568803	25306	Economy	35300.00
0005433568761	25306	Economy	35300.00
0005433568659	25306	Economy	35300.00
0005433568626	25306	Economy	35300.00
0005432948707	25306	Economy	35300.00
0005432948694	25306	Economy	35300.00
0005432948698	25306	Economy	35300.00
0005432948721	25306	Economy	35300.00
0005433568711	25306	Economy	35300.00
0005433568696	25306	Economy	35300.00
0005433568804	25306	Economy	35300.00
0005433568719	25306	Economy	35300.00
0005432948683	25306	Economy	35300.00
0005433568827	25306	Economy	35300.00
0005433568871	25306	Economy	35300.00
0005432948692	25306	Economy	35300.00
0005433568866	25306	Economy	35300.00
0005433568777	25306	Economy	35300.00
0005433568762	25306	Economy	35300.00
0005433568741	25306	Economy	35300.00
0005432948687	25306	Economy	35300.00
0005432948718	25306	Economy	35300.00
0005432948704	25306	Economy	35300.00
0005433568850	25306	Economy	35300.00
0005433568849	25306	Economy	35300.00
0005433811619	27942	Business	105400.00
0005433811625	27942	Economy	35100.00
0005433811631	27942	Economy	35100.00
0005433811620	27942	Economy	35100.00
0005433811624	27942	Economy	35100.00
0005433811622	27942	Economy	35100.00
0005433811616	27942	Economy	35100.00
0005433811632	27942	Economy	35100.00
0005433811617	27942	Economy	35100.00
0005433811623	27942	Economy	35100.00
0005433811621	27942	Economy	35100.00
0005433811628	27942	Economy	35100.00
0005433811618	27942	Economy	35100.00
0005433811630	27942	Economy	35100.00
0005434654837	5396	Business	67200.00
0005434654826	5396	Business	67200.00
0005434654822	5396	Business	67200.00
0005434654823	5396	Business	67200.00
0005434654842	5396	Business	67200.00
0005435340238	5396	Business	67200.00
0005432114220	5396	Business	67200.00
0005434654833	5396	Business	67200.00
0005435340166	5396	Economy	22400.00
0005434654828	5396	Economy	22400.00
0005435340161	5396	Economy	22400.00
0005434654845	5396	Economy	22400.00
0005434654838	5396	Economy	22400.00
0005434654821	5396	Economy	22400.00
0005434654839	5396	Economy	22400.00
0005434654820	5396	Economy	22400.00
0005435340217	5396	Economy	24600.00
0005434654843	5396	Economy	24600.00
0005435340210	5396	Economy	24600.00
0005435340226	5396	Economy	22400.00
0005432114219	5396	Economy	22400.00
0005434656567	5396	Economy	22400.00
0005435340239	5396	Economy	22400.00
0005434654817	5396	Economy	22400.00
0005434654844	5396	Economy	22400.00
0005435340218	5396	Economy	22400.00
0005434654825	5396	Economy	22400.00
0005434654831	5396	Economy	22400.00
0005435340205	5396	Economy	22400.00
0005434654819	5396	Economy	22400.00
0005432114218	5396	Economy	22400.00
0005434656568	5396	Economy	22400.00
0005435340221	5396	Economy	22400.00
0005434654846	5396	Economy	22400.00
0005434654827	5396	Economy	22400.00
0005435340253	5396	Economy	22400.00
0005435555360	5396	Economy	22400.00
0005434654847	5396	Economy	22400.00
0005435340215	5396	Economy	22400.00
0005435340222	5396	Economy	22400.00
0005435340158	5396	Economy	22400.00
0005434654832	5396	Economy	22400.00
0005435340202	5396	Economy	22400.00
0005435555361	5396	Economy	22400.00
0005434654840	5396	Economy	22400.00
0005434654834	5396	Economy	22400.00
0005434654829	5396	Economy	22400.00
0005434654836	5396	Economy	22400.00
0005434656566	5396	Economy	22400.00
0005434654818	5396	Economy	22400.00
0005434654824	5396	Economy	22400.00
0005434654835	5396	Economy	22400.00
0005434654841	5396	Economy	22400.00
0005434654830	5396	Economy	22400.00
0005435340175	5396	Economy	22400.00
0005435340341	12527	Business	67200.00
0005434654620	12527	Business	67200.00
0005435340342	12527	Business	67200.00
0005434654574	12527	Business	67200.00
0005434654666	12527	Business	67200.00
0005434654628	12527	Business	67200.00
0005434654519	12527	Economy	22400.00
0005434654603	12527	Economy	22400.00
0005434654618	12527	Economy	22400.00
0005434654619	12527	Economy	22400.00
0005435340333	12527	Economy	22400.00
0005434654640	12527	Economy	22400.00
0005435340344	12527	Economy	22400.00
0005434654660	12527	Economy	22400.00
0005434654491	12527	Economy	24600.00
0005435340339	12527	Economy	24600.00
0005434654667	12527	Economy	24600.00
0005434654492	12527	Economy	24600.00
0005434654624	12527	Economy	24600.00
0005435340337	12527	Economy	22400.00
0005435340346	12527	Economy	22400.00
0005434654565	12527	Economy	22400.00
0005434654639	12527	Economy	22400.00
0005435340345	12527	Economy	22400.00
0005434654683	12527	Economy	22400.00
0005434654604	12527	Economy	22400.00
0005434654411	12527	Economy	22400.00
0005434654556	12527	Economy	22400.00
0005435340335	12527	Economy	22400.00
0005434654659	12527	Economy	22400.00
0005434654664	12527	Economy	22400.00
0005434654634	12527	Economy	22400.00
0005435340340	12527	Economy	22400.00
0005434654410	12527	Economy	22400.00
0005435340338	12527	Economy	22400.00
0005434654520	12527	Economy	22400.00
0005434654638	12527	Economy	22400.00
0005434654589	12527	Economy	22400.00
0005434654672	12527	Economy	22400.00
0005434654412	12527	Economy	22400.00
0005434654437	12527	Economy	22400.00
0005434654725	12527	Economy	22400.00
0005434654575	12527	Economy	22400.00
0005434654621	12527	Economy	22400.00
0005434654673	12527	Economy	22400.00
0005435340343	12527	Economy	22400.00
0005434654521	12527	Economy	22400.00
0005435340334	12527	Economy	22400.00
0005434654605	12527	Economy	22400.00
0005434654493	12527	Economy	22400.00
0005435340336	12527	Economy	22400.00
0005434654590	12527	Economy	22400.00
0005434654724	12527	Economy	22400.00
0005434654625	12527	Economy	22400.00
0005434654606	12527	Economy	22400.00
0005435340347	12527	Economy	22400.00
0005434654518	12527	Economy	22400.00
0005434654592	12527	Economy	22400.00
0005434654637	12527	Economy	22400.00
0005432428912	7447	Business	32000.00
0005433716222	7447	Business	32000.00
0005433690934	7447	Business	32000.00
0005435266121	7447	Business	32000.00
0005433716233	7447	Business	32000.00
0005433716215	7447	Business	32000.00
0005433716232	7447	Business	32000.00
0005433722253	7447	Business	32000.00
0005435266129	7447	Business	32000.00
0005435266128	7447	Business	32000.00
0005433716213	7447	Business	32000.00
0005433716227	7447	Economy	10700.00
0005433716196	7447	Economy	10700.00
0005433716220	7447	Economy	10700.00
0005433716207	7447	Economy	10700.00
0005433716192	7447	Economy	10700.00
0005433716236	7447	Economy	10700.00
0005433722247	7447	Economy	10700.00
0005433716202	7447	Economy	10700.00
0005433716239	7447	Economy	10700.00
0005433716208	7447	Economy	10700.00
0005432078136	7447	Economy	10700.00
0005433716214	7447	Economy	10700.00
0005433716229	7447	Economy	10700.00
0005433719156	7447	Economy	10700.00
0005433716228	7447	Economy	10700.00
0005433716200	7447	Economy	10700.00
0005433716195	7447	Economy	10700.00
0005433722249	7447	Economy	10700.00
0005433716210	7447	Economy	10700.00
0005432428911	7447	Economy	10700.00
0005433716242	7447	Economy	10700.00
0005433716225	7447	Economy	10700.00
0005435266132	7447	Economy	10700.00
0005433722246	7447	Economy	10700.00
0005433689920	7447	Economy	10700.00
0005433716212	7447	Economy	11700.00
0005433716204	7447	Economy	11700.00
0005432078137	7447	Economy	11700.00
0005433716241	7447	Economy	11700.00
0005433688817	7447	Economy	10700.00
0005433716240	7447	Economy	10700.00
0005433716221	7447	Economy	10700.00
0005433716194	7447	Economy	10700.00
0005433722251	7447	Economy	10700.00
0005433716237	7447	Economy	10700.00
0005433690933	7447	Economy	10700.00
0005433719154	7447	Economy	10700.00
0005433722248	7447	Economy	10700.00
0005433716197	7447	Economy	10700.00
0005433716216	7447	Economy	10700.00
0005435266118	7447	Economy	10700.00
0005432078134	7447	Economy	10700.00
0005433716205	7447	Economy	10700.00
0005432078135	7447	Economy	10700.00
0005433716218	7447	Economy	10700.00
0005433716198	7447	Economy	10700.00
0005433716231	7447	Economy	10700.00
0005433719155	7447	Economy	10700.00
0005433716226	7447	Economy	10700.00
0005435266133	7447	Economy	10700.00
0005433656684	7447	Economy	10700.00
0005435266127	7447	Economy	10700.00
0005433716206	7447	Economy	10700.00
0005433716203	7447	Economy	10700.00
0005433716193	7447	Economy	10700.00
0005432078138	7447	Economy	10700.00
0005433716211	7447	Economy	10700.00
0005433716223	7447	Economy	10700.00
0005433716209	7447	Economy	10700.00
0005433716201	7447	Economy	10700.00
0005432078133	7447	Economy	10700.00
0005433656686	7447	Economy	10700.00
0005433716235	7447	Economy	10700.00
0005433716238	7447	Economy	10700.00
0005433656685	7447	Economy	10700.00
0005433716217	7447	Economy	10700.00
0005433722250	7447	Economy	10700.00
0005433722252	7447	Economy	10700.00
0005433716230	7447	Economy	10700.00
0005435266130	7447	Economy	10700.00
0005433716199	7447	Economy	10700.00
0005433716234	7447	Economy	10700.00
0005433716219	7447	Economy	10700.00
0005433716224	7447	Economy	10700.00
0005433688818	7447	Economy	10700.00
0005433689919	7447	Economy	10700.00
0005433722218	29238	Business	32000.00
0005433715799	29238	Business	32000.00
0005433715972	29238	Business	32000.00
0005433715816	29238	Business	32000.00
0005433685519	29238	Business	32000.00
0005433722219	29238	Business	32000.00
0005435266165	29238	Economy	10700.00
0005433715694	29238	Economy	10700.00
0005433715496	29238	Economy	10700.00
0005433715864	29238	Economy	10700.00
0005435266159	29238	Economy	10700.00
0005433715800	29238	Economy	10700.00
0005433715497	29238	Economy	10700.00
0005433715585	29238	Economy	10700.00
0005432428947	29238	Economy	10700.00
0005433715563	29238	Economy	10700.00
0005433722220	29238	Economy	10700.00
0005432006775	29238	Economy	10700.00
0005432428946	29238	Economy	10700.00
0005433656656	29238	Economy	10700.00
0005435266162	29238	Economy	10700.00
0005433715719	29238	Economy	10700.00
0005433715498	29238	Economy	10700.00
0005433722172	29238	Economy	10700.00
0005433722186	29238	Economy	10700.00
0005433715718	29238	Economy	10700.00
0005433722224	29238	Economy	10700.00
0005433656659	29238	Economy	10700.00
0005433715877	29238	Economy	10700.00
0005433722213	29238	Economy	10700.00
0005433715861	29238	Economy	10700.00
0005433715928	29238	Economy	11700.00
0005433722184	29238	Economy	11700.00
0005433722195	29238	Economy	11700.00
0005433715820	29238	Economy	11700.00
0005435266163	29238	Economy	11700.00
0005433715787	29238	Economy	10700.00
0005433722208	29238	Economy	10700.00
0005433715801	29238	Economy	10700.00
0005433722171	29238	Economy	10700.00
0005433715653	29238	Economy	10700.00
0005433688792	29238	Economy	10700.00
0005433719122	29238	Economy	10700.00
0005433722221	29238	Economy	10700.00
0005433715545	29238	Economy	10700.00
0005433722207	29238	Economy	10700.00
0005433715821	29238	Economy	10700.00
0005433722210	29238	Economy	10700.00
0005433722214	29238	Economy	10700.00
0005433715720	29238	Economy	10700.00
0005433715846	29238	Economy	10700.00
0005433715973	29238	Economy	10700.00
0005433656651	29238	Economy	10700.00
0005433715495	29238	Economy	10700.00
0005433715487	29238	Economy	10700.00
0005433688807	29238	Economy	10700.00
0005433715745	29238	Economy	10700.00
0005435266166	29238	Economy	10700.00
0005435266161	29238	Economy	10700.00
0005435266160	29238	Economy	10700.00
0005433715865	29238	Economy	10700.00
0005432428945	29238	Economy	10700.00
0005433715728	29238	Economy	10700.00
0005433715693	29238	Economy	10700.00
0005432006778	29238	Economy	10700.00
0005433656652	29238	Economy	10700.00
0005433715729	29238	Economy	10700.00
0005433656646	29238	Economy	10700.00
0005433715828	29238	Economy	10700.00
0005433715904	29238	Economy	10700.00
0005432006777	29238	Economy	10700.00
0005433722182	29238	Economy	10700.00
0005432006776	29238	Economy	10700.00
0005435266164	29238	Economy	10700.00
0005433688806	29238	Economy	10700.00
0005433722185	29238	Economy	10700.00
0005433722203	29238	Economy	10700.00
0005433715712	29238	Economy	10700.00
0005433715819	29238	Economy	10700.00
0005433715845	29238	Economy	10700.00
0005433715640	29238	Economy	10700.00
0005435266167	29238	Economy	10700.00
0005434182104	8696	Business	36500.00
0005434095341	8696	Business	36500.00
0005434095355	8696	Business	36500.00
0005434095354	8696	Business	36500.00
0005434182141	8696	Economy	12200.00
0005434182131	8696	Economy	12200.00
0005434182149	8696	Economy	12200.00
0005434184660	8696	Economy	12200.00
0005434182181	8696	Economy	12200.00
0005434182156	8696	Economy	12200.00
0005434095352	8696	Economy	13400.00
0005434184662	8696	Economy	13400.00
0005434182188	8696	Economy	13400.00
0005434182147	8696	Economy	12200.00
0005434182130	8696	Economy	12200.00
0005434182118	8696	Economy	12200.00
0005434184661	8696	Economy	12200.00
0005434182126	8696	Economy	12200.00
0005434182187	8696	Economy	12200.00
0005434095349	8696	Economy	12200.00
0005434095347	8696	Economy	12200.00
0005434182164	8696	Economy	12200.00
0005434095342	8696	Economy	12200.00
0005434182174	8696	Economy	12200.00
0005434095343	8696	Economy	12200.00
0005434182196	8696	Economy	12200.00
0005434095350	8696	Economy	12200.00
0005434095356	8696	Economy	12200.00
0005434095348	8696	Economy	12200.00
0005434095345	8696	Economy	12200.00
0005434095340	8696	Economy	12200.00
0005434182153	8696	Economy	12200.00
0005434182154	8696	Economy	12200.00
0005434095351	8696	Economy	12200.00
0005434182152	8696	Economy	12200.00
0005434095346	8696	Economy	12200.00
0005434182173	8696	Economy	12200.00
0005434095353	8696	Economy	12200.00
0005434095344	8696	Economy	12200.00
0005434182148	8696	Economy	12200.00
0005434182142	8696	Economy	12200.00
0005434182103	8696	Economy	12200.00
0005434095209	11682	Business	36500.00
0005434182247	11682	Business	36500.00
0005434095196	11682	Business	36500.00
0005434183588	11682	Business	36500.00
0005434182246	11682	Economy	12200.00
0005434095136	11682	Economy	12200.00
0005434095197	11682	Economy	13400.00
0005434095221	11682	Economy	13400.00
0005434184674	11682	Economy	13400.00
0005434182248	11682	Economy	12200.00
0005434143717	11682	Economy	12200.00
0005434095223	11682	Economy	12200.00
0005434095186	11682	Economy	12200.00
0005434182241	11682	Economy	12200.00
0005434095255	11682	Economy	12200.00
0005434182243	11682	Economy	12200.00
0005434095222	11682	Economy	12200.00
0005434095185	11682	Economy	12200.00
0005434182245	11682	Economy	12200.00
0005434095254	11682	Economy	12200.00
0005434183589	11682	Economy	12200.00
0005434095257	11682	Economy	12200.00
0005434095178	11682	Economy	12200.00
0005434095177	11682	Economy	12200.00
0005434182249	11682	Economy	12200.00
0005434182252	11682	Economy	12200.00
0005434184673	11682	Economy	12200.00
0005434143711	11682	Economy	12200.00
0005434183587	11682	Economy	12200.00
0005434143724	11682	Economy	12200.00
0005434095220	11682	Economy	12200.00
0005434182251	11682	Economy	12200.00
0005434182244	11682	Economy	12200.00
0005434182250	11682	Economy	12200.00
0005434143710	11682	Economy	12200.00
0005434182242	11682	Economy	12200.00
0005433397885	1453	Business	33000.00
0005433398050	1453	Business	33000.00
0005433397770	1453	Business	33000.00
0005433397934	1453	Business	33000.00
0005433397843	1453	Business	33000.00
0005433397954	1453	Business	33000.00
0005433397865	1453	Business	33000.00
0005433397964	1453	Business	33000.00
0005433456990	1453	Business	33000.00
0005433397935	1453	Business	33000.00
0005433397828	1453	Economy	11000.00
0005433456992	1453	Economy	11000.00
0005433398080	1453	Economy	11000.00
0005433397949	1453	Economy	11000.00
0005432906520	1453	Economy	11000.00
0005433397953	1453	Economy	12100.00
0005433397878	1453	Economy	12100.00
0005433456993	1453	Economy	12100.00
0005433398015	1453	Economy	12100.00
0005433397871	1453	Economy	11000.00
0005433397872	1453	Economy	11000.00
0005433397943	1453	Economy	11000.00
0005433397857	1453	Economy	11000.00
0005433397814	1453	Economy	11000.00
0005433397950	1453	Economy	11000.00
0005433398168	1453	Economy	11000.00
0005433397895	1453	Economy	11000.00
0005433397778	1453	Economy	11000.00
0005433397909	1453	Economy	11000.00
0005433397910	1453	Economy	11000.00
0005433397875	1453	Economy	11000.00
0005432297291	1453	Economy	11000.00
0005433397860	1453	Economy	11000.00
0005433397861	1453	Economy	11000.00
0005432906528	1453	Economy	11000.00
0005433397911	1453	Economy	11000.00
0005433397782	1453	Economy	11000.00
0005433398072	1453	Economy	11000.00
0005433456991	1453	Economy	11000.00
0005433397858	1453	Economy	11000.00
0005433397846	1453	Economy	11000.00
0005433397894	1453	Economy	11000.00
0005433398067	1453	Economy	11000.00
0005433397783	1453	Economy	11000.00
0005433398040	1453	Economy	11000.00
0005433397815	1453	Economy	11000.00
0005433397893	1453	Economy	11000.00
0005432297289	1453	Economy	11000.00
0005433397750	1453	Economy	11000.00
0005433398074	1453	Economy	11000.00
0005433397751	1453	Economy	11000.00
0005433397981	1453	Economy	11000.00
0005433398073	1453	Economy	11000.00
0005433397779	1453	Economy	11000.00
0005433397884	1453	Economy	11000.00
0005433397816	1453	Economy	11000.00
0005433397687	1453	Economy	11000.00
0005433397821	1453	Economy	11000.00
0005432297290	1453	Economy	11000.00
0005433397889	1453	Economy	11000.00
0005433397888	1453	Economy	11000.00
0005433397459	1453	Economy	11000.00
0005433456989	1453	Economy	11000.00
0005433398032	1453	Economy	11000.00
0005433397838	1453	Economy	11000.00
0005432906529	1453	Economy	11000.00
0005433456988	1453	Economy	11000.00
0005433397890	1453	Economy	11000.00
0005433397866	1453	Economy	11000.00
0005433397892	1453	Economy	11000.00
0005433397929	1453	Economy	11000.00
0005433397912	1453	Economy	11000.00
0005433398281	19255	Business	33000.00
0005433398274	19255	Business	33000.00
0005433398276	19255	Business	33000.00
0005433398279	19255	Business	33000.00
0005433398278	19255	Business	33000.00
0005433398302	19255	Business	33000.00
0005433456959	19255	Business	33000.00
0005433398306	19255	Business	33000.00
0005433398305	19255	Business	33000.00
0005433398301	19255	Economy	11000.00
0005433398284	19255	Economy	11000.00
0005435732237	19255	Economy	11000.00
0005435732293	19255	Economy	11000.00
0005433398296	19255	Economy	11000.00
0005433398311	19255	Economy	12100.00
0005433398283	19255	Economy	12100.00
0005433398317	19255	Economy	12100.00
0005433398286	19255	Economy	12100.00
0005433398292	19255	Economy	11000.00
0005433398303	19255	Economy	11000.00
0005433398316	19255	Economy	11000.00
0005435732313	19255	Economy	11000.00
0005433398308	19255	Economy	11000.00
0005433398320	19255	Economy	11000.00
0005435732238	19255	Economy	11000.00
0005435732294	19255	Economy	11000.00
0005435732239	19255	Economy	11000.00
0005433398304	19255	Economy	11000.00
0005433398299	19255	Economy	11000.00
0005433456948	19255	Economy	11000.00
0005433398290	19255	Economy	11000.00
0005433398321	19255	Economy	11000.00
0005435732263	19255	Economy	11000.00
0005433398289	19255	Economy	11000.00
0005433398309	19255	Economy	11000.00
0005433398294	19255	Economy	11000.00
0005435732250	19255	Economy	11000.00
0005433398282	19255	Economy	11000.00
0005433398287	19255	Economy	11000.00
0005433398297	19255	Economy	11000.00
0005433398293	19255	Economy	11000.00
0005433398273	19255	Economy	11000.00
0005435732260	19255	Economy	11000.00
0005433398272	19255	Economy	11000.00
0005433398310	19255	Economy	11000.00
0005433398300	19255	Economy	11000.00
0005433398285	19255	Economy	11000.00
0005433398315	19255	Economy	11000.00
0005435732315	19255	Economy	11000.00
0005435732314	19255	Economy	11000.00
0005433398277	19255	Economy	11000.00
0005433398314	19255	Economy	11000.00
0005433398291	19255	Economy	11000.00
0005433398280	19255	Economy	11000.00
0005435732236	19255	Economy	11000.00
0005433398288	19255	Economy	11000.00
0005433398319	19255	Economy	11000.00
0005433398313	19255	Economy	11000.00
0005433398318	19255	Economy	11000.00
0005433398295	19255	Economy	11000.00
0005433398298	19255	Economy	11000.00
0005433398275	19255	Economy	11000.00
0005433398307	19255	Economy	11000.00
0005433456947	19255	Economy	11000.00
0005435732271	19255	Economy	11000.00
0005435732251	19255	Economy	11000.00
0005433398312	19255	Economy	11000.00
0005434443660	17337	Economy	15600.00
0005434443633	17337	Economy	15600.00
0005434443606	17337	Economy	14100.00
0005434443569	17337	Economy	14100.00
0005434443605	17337	Economy	14100.00
0005434443722	17337	Economy	14100.00
0005434443641	17337	Economy	14100.00
0005434443700	17337	Economy	14100.00
0005434443667	17337	Economy	14100.00
0005434443583	17337	Economy	14100.00
0005434443708	17337	Economy	14100.00
0005434443584	17337	Economy	14100.00
0005434443581	17337	Economy	14100.00
0005434443580	17337	Economy	14100.00
0005434443647	17337	Economy	14100.00
0005434443644	17337	Economy	14100.00
0005434443552	17337	Economy	14100.00
0005434443632	17337	Economy	14100.00
0005434443668	17337	Economy	14100.00
0005434443779	20600	Economy	15600.00
0005434443782	20600	Economy	14100.00
0005434443772	20600	Economy	14100.00
0005434443781	20600	Economy	14100.00
0005434443773	20600	Economy	14100.00
0005434443778	20600	Economy	14100.00
0005434443784	20600	Economy	14100.00
0005434443775	20600	Economy	14100.00
0005434443786	20600	Economy	14100.00
0005434443776	20600	Economy	14100.00
0005434443783	20600	Economy	14100.00
0005434443785	20600	Economy	14100.00
0005434443777	20600	Economy	14100.00
0005434443774	20600	Economy	14100.00
0005434443771	20600	Economy	14100.00
0005434443780	20600	Economy	14100.00
0005434954627	7258	Economy	5800.00
0005435377569	7258	Economy	5800.00
0005435377576	7258	Economy	5800.00
0005434954630	7258	Economy	5800.00
0005435377568	7258	Economy	5800.00
0005434954628	7258	Economy	5800.00
0005434954629	7258	Economy	5800.00
0005434954604	28310	Economy	5800.00
0005434954598	28310	Economy	5800.00
0005434954593	28310	Economy	5800.00
0005435377591	28310	Economy	5800.00
0005434954592	28310	Economy	5800.00
0005435377592	28310	Economy	5800.00
0005434954606	28310	Economy	5800.00
0005434954605	28310	Economy	5800.00
0005435893618	4479	Economy	15400.00
0005434351753	4479	Economy	14000.00
0005434351759	4479	Economy	14000.00
0005435893602	4479	Economy	14000.00
0005435893609	4479	Economy	14000.00
0005434351752	4479	Economy	14000.00
0005434351764	4479	Economy	14000.00
0005434351762	4479	Economy	14000.00
0005435893603	4479	Economy	14000.00
0005434183567	4479	Economy	14000.00
0005434351763	4479	Economy	14000.00
0005434351754	4479	Economy	14000.00
0005434351760	4479	Economy	14000.00
0005434351756	4479	Economy	14000.00
0005434351757	4479	Economy	14000.00
0005434351761	4479	Economy	14000.00
0005434351755	4479	Economy	14000.00
0005435893608	4479	Economy	14000.00
0005434351758	4479	Economy	14000.00
0005434183566	4479	Economy	14000.00
0005434351628	29686	Economy	15400.00
0005434351627	29686	Economy	14000.00
0005434351617	29686	Economy	14000.00
0005434351695	29686	Economy	14000.00
0005434351657	29686	Economy	14000.00
0005435893665	29686	Economy	14000.00
0005434351629	29686	Economy	14000.00
0005435893668	29686	Economy	14000.00
0005435893667	29686	Economy	14000.00
0005435893664	29686	Economy	14000.00
0005434351635	29686	Economy	14000.00
0005434351626	29686	Economy	14000.00
0005434351636	29686	Economy	14000.00
0005435893670	29686	Economy	14000.00
0005435893669	29686	Economy	14000.00
0005434351656	29686	Economy	14000.00
0005435893663	29686	Economy	14000.00
0005434351625	29686	Economy	14000.00
0005435893666	29686	Economy	14000.00
0005434351618	29686	Economy	14000.00
0005434445256	1086	Business	30600.00
0005433342365	1086	Business	30600.00
0005433342932	1086	Business	30600.00
0005433342945	1086	Business	30600.00
0005433342611	1086	Business	30600.00
0005433343091	1086	Business	30600.00
0005435545780	1086	Business	30600.00
0005433159310	1086	Business	30600.00
0005433342051	1086	Business	30600.00
0005433159311	1086	Business	30600.00
0005433342997	1086	Business	30600.00
0005433342435	1086	Business	30600.00
0005433342567	1086	Business	30600.00
0005433342732	1086	Economy	11200.00
0005433342662	1086	Economy	11200.00
0005435545771	1086	Economy	10200.00
0005434446532	1086	Economy	10200.00
0005435545774	1086	Economy	10200.00
0005433342684	1086	Economy	10200.00
0005433342853	1086	Economy	10200.00
0005433342685	1086	Economy	10200.00
0005432293220	1086	Economy	10200.00
0005433342531	1086	Economy	10200.00
0005433342996	1086	Economy	10200.00
0005433342343	1086	Economy	10200.00
0005435545778	1086	Economy	10200.00
0005433342734	1086	Economy	10200.00
0005433342748	1086	Economy	10200.00
0005433342805	1086	Economy	10200.00
0005433342411	1086	Economy	10200.00
0005433342568	1086	Economy	10200.00
0005433342329	1086	Economy	10200.00
0005433342987	1086	Economy	10200.00
0005433158121	1086	Economy	10200.00
0005434445257	1086	Economy	10200.00
0005435092119	1086	Economy	10200.00
0005435545782	1086	Economy	10200.00
0005433342801	1086	Economy	10200.00
0005433342328	1086	Economy	10200.00
0005433342314	1086	Economy	10200.00
0005433269694	1086	Economy	10200.00
0005433343095	1086	Economy	10200.00
0005433342728	1086	Economy	10200.00
0005433342723	1086	Economy	10200.00
0005433342463	1086	Economy	10200.00
0005433342729	1086	Economy	10200.00
0005435092123	1086	Economy	10200.00
0005434446529	1086	Economy	10200.00
0005435092121	1086	Economy	10200.00
0005435092127	1086	Economy	10200.00
0005435545772	1086	Economy	10200.00
0005433343186	1086	Economy	10200.00
0005433342803	1086	Economy	10200.00
0005433342724	1086	Economy	10200.00
0005433342407	1086	Economy	10200.00
0005433342810	1086	Economy	10200.00
0005433342774	1086	Economy	10200.00
0005435092122	1086	Economy	10200.00
0005433342741	1086	Economy	10200.00
0005433342769	1086	Economy	10200.00
0005433342207	1086	Economy	10200.00
0005435092120	1086	Economy	10200.00
0005433463912	1086	Economy	10200.00
0005433342851	1086	Economy	10200.00
0005433342295	1086	Economy	10200.00
0005433342458	1086	Economy	10200.00
0005433342804	1086	Economy	10200.00
0005433342208	1086	Economy	10200.00
0005433342811	1086	Economy	10200.00
0005433342806	1086	Economy	10200.00
0005433342588	1086	Economy	10200.00
0005433342981	1086	Economy	10200.00
0005433342434	1086	Economy	11200.00
0005435092118	1086	Economy	11200.00
0005433342944	1086	Economy	10200.00
0005433342377	1086	Economy	10200.00
0005433343048	1086	Economy	10200.00
0005435092124	1086	Economy	11200.00
0005435545770	1086	Economy	11200.00
0005433342800	1086	Economy	10200.00
0005433342612	1086	Economy	10200.00
0005435092126	1086	Economy	10200.00
0005433342802	1086	Economy	10200.00
0005433342686	1086	Economy	10200.00
0005433342852	1086	Economy	10200.00
0005435545781	1086	Economy	10200.00
0005435545783	1086	Economy	10200.00
0005433342968	1086	Economy	10200.00
0005433462758	1086	Economy	10200.00
0005433342749	1086	Economy	10200.00
0005433342797	1086	Economy	10200.00
0005433342733	1086	Economy	10200.00
0005433342566	1086	Economy	10200.00
0005433342453	1086	Economy	10200.00
0005433342823	1086	Economy	10200.00
0005433342874	1086	Economy	10200.00
0005433343185	1086	Economy	10200.00
0005433342742	1086	Economy	10200.00
0005435545775	1086	Economy	10200.00
0005433342513	1086	Economy	10200.00
0005433342589	1086	Economy	10200.00
0005433342998	1086	Economy	10200.00
0005433342992	1086	Economy	10200.00
0005433342873	1086	Economy	10200.00
0005433342647	1086	Economy	10200.00
0005435092125	1086	Economy	10200.00
0005433342584	1086	Economy	10200.00
0005433342452	1086	Economy	10200.00
0005433269692	1086	Economy	10200.00
0005435545777	1086	Economy	10200.00
0005432293221	1086	Economy	10200.00
0005433342597	1086	Economy	10200.00
0005435545773	1086	Economy	10200.00
0005433342808	1086	Economy	10200.00
0005433342645	1086	Economy	10200.00
0005435545784	1086	Economy	10200.00
0005433342898	1086	Economy	10200.00
0005433342798	1086	Economy	10200.00
0005433158120	1086	Economy	10200.00
0005434446530	1086	Economy	10200.00
0005433269693	1086	Economy	10200.00
0005433342547	1086	Economy	10200.00
0005433462757	1086	Economy	10200.00
0005433342988	1086	Economy	10200.00
0005433342406	1086	Economy	10200.00
0005433343001	1086	Economy	10200.00
0005433463911	1086	Economy	10200.00
0005433342610	1086	Economy	10200.00
0005433342991	1086	Economy	10200.00
0005433342357	1086	Economy	10200.00
0005433342050	1086	Economy	10200.00
0005433342745	1086	Economy	10200.00
0005434446531	1086	Economy	10200.00
0005435545776	1086	Economy	10200.00
0005433342540	1086	Economy	10200.00
0005435545779	1086	Economy	10200.00
0005433342809	1086	Economy	10200.00
0005433343536	17023	Business	30600.00
0005433343600	17023	Business	30600.00
0005433343544	17023	Business	30600.00
0005433343597	17023	Business	30600.00
0005433343580	17023	Business	30600.00
0005433343589	17023	Business	30600.00
0005433343551	17023	Business	30600.00
0005433343534	17023	Business	30600.00
0005433343530	17023	Business	30600.00
0005433343520	17023	Business	30600.00
0005433343606	17023	Business	30600.00
0005433343572	17023	Business	30600.00
0005433343531	17023	Business	30600.00
0005433343547	17023	Business	30600.00
0005435092059	17023	Business	30600.00
0005433343614	17023	Business	30600.00
0005433343575	17023	Business	30600.00
0005433343542	17023	Business	30600.00
0005433343557	17023	Business	30600.00
0005433343616	17023	Business	30600.00
0005433343527	17023	Business	30600.00
0005433343539	17023	Business	30600.00
0005433343535	17023	Business	30600.00
0005433343540	17023	Business	30600.00
0005433269747	17023	Economy	11200.00
0005433343574	17023	Economy	11200.00
0005433343608	17023	Economy	10200.00
0005433343529	17023	Economy	10200.00
0005433343594	17023	Economy	10200.00
0005433343582	17023	Economy	10200.00
0005435092042	17023	Economy	10200.00
0005435508252	17023	Economy	10200.00
0005435508274	17023	Economy	10200.00
0005435092019	17023	Economy	10200.00
0005433343565	17023	Economy	10200.00
0005433343543	17023	Economy	10200.00
0005433343553	17023	Economy	10200.00
0005433343590	17023	Economy	10200.00
0005433343605	17023	Economy	10200.00
0005435508292	17023	Economy	10200.00
0005433343577	17023	Economy	10200.00
0005433343515	17023	Economy	10200.00
0005433343538	17023	Economy	10200.00
0005433343607	17023	Economy	10200.00
0005433343550	17023	Economy	10200.00
0005433343613	17023	Economy	10200.00
0005433343554	17023	Economy	10200.00
0005433343555	17023	Economy	10200.00
0005433343609	17023	Economy	10200.00
0005433343588	17023	Economy	10200.00
0005433343581	17023	Economy	10200.00
0005433343591	17023	Economy	10200.00
0005433343556	17023	Economy	10200.00
0005433343528	17023	Economy	10200.00
0005433343592	17023	Economy	10200.00
0005433343562	17023	Economy	10200.00
0005435092062	17023	Economy	10200.00
0005435508284	17023	Economy	10200.00
0005433343585	17023	Economy	10200.00
0005435092044	17023	Economy	10200.00
0005433343519	17023	Economy	10200.00
0005435508285	17023	Economy	10200.00
0005433343601	17023	Economy	10200.00
0005433343566	17023	Economy	10200.00
0005433343525	17023	Economy	10200.00
0005433343602	17023	Economy	10200.00
0005433343599	17023	Economy	10200.00
0005433343516	17023	Economy	10200.00
0005433343532	17023	Economy	10200.00
0005433343545	17023	Economy	10200.00
0005433343579	17023	Economy	10200.00
0005433343593	17023	Economy	10200.00
0005433343604	17023	Economy	10200.00
0005433343563	17023	Economy	10200.00
0005433343596	17023	Economy	10200.00
0005435092008	17023	Economy	10200.00
0005433343523	17023	Economy	10200.00
0005435092014	17023	Economy	10200.00
0005433343549	17023	Economy	10200.00
0005435508280	17023	Economy	10200.00
0005433343564	17023	Economy	10200.00
0005433343595	17023	Economy	10200.00
0005433343584	17023	Economy	10200.00
0005435508293	17023	Economy	10200.00
0005433343611	17023	Economy	10200.00
0005433343561	17023	Economy	10200.00
0005435508288	17023	Economy	10200.00
0005433343552	17023	Economy	10200.00
0005433343526	17023	Economy	10200.00
0005435092024	17023	Economy	10200.00
0005433343576	17023	Economy	10200.00
0005433343570	17023	Economy	10200.00
0005433343603	17023	Economy	10200.00
0005433343568	17023	Economy	10200.00
0005433343560	17023	Economy	10200.00
0005435092027	17023	Economy	10200.00
0005433343517	17023	Economy	10200.00
0005433343573	17023	Economy	10200.00
0005433343533	17023	Economy	10200.00
0005433343558	17023	Economy	10200.00
0005435092045	17023	Economy	10200.00
0005433269743	17023	Economy	10200.00
0005433159322	17023	Economy	10200.00
0005433343559	17023	Economy	10200.00
0005435092025	17023	Economy	10200.00
0005433343571	17023	Economy	10200.00
0005433343598	17023	Economy	10200.00
0005433343615	17023	Economy	10200.00
0005433159323	17023	Economy	10200.00
0005433343612	17023	Economy	10200.00
0005433343587	17023	Economy	10200.00
0005433343541	17023	Economy	10200.00
0005433343567	17023	Economy	10200.00
0005433343586	17023	Economy	10200.00
0005433343537	17023	Economy	10200.00
0005435092026	17023	Economy	10200.00
0005433343521	17023	Economy	10200.00
0005433269745	17023	Economy	10200.00
0005433343583	17023	Economy	10200.00
0005433343522	17023	Economy	10200.00
0005433269742	17023	Economy	10200.00
0005433343518	17023	Economy	10200.00
0005433343546	17023	Economy	10200.00
0005433269744	17023	Economy	10200.00
0005433343578	17023	Economy	10200.00
0005433269746	17023	Economy	10200.00
0005433343569	17023	Economy	10200.00
0005435508253	17023	Economy	10200.00
0005433343548	17023	Economy	10200.00
0005433343610	17023	Economy	10200.00
0005433343524	17023	Economy	10200.00
0005434067178	12795	Business	40300.00
0005434067374	12795	Business	40300.00
0005434067242	12795	Business	40300.00
0005434067060	12795	Business	40300.00
0005434067217	12795	Business	40300.00
0005434067341	12795	Business	40300.00
0005434081811	12795	Business	40300.00
0005434067167	12795	Business	40300.00
0005434026693	12795	Business	40300.00
0005434067080	12795	Business	40300.00
0005434026697	12795	Business	40300.00
0005434067244	12795	Business	40300.00
0005434067220	12795	Economy	13400.00
0005432161163	12795	Economy	13400.00
0005434067261	12795	Economy	13400.00
0005434081743	12795	Economy	13400.00
0005434081728	12795	Economy	13400.00
0005434067123	12795	Economy	13400.00
0005434067116	12795	Economy	13400.00
0005434067079	12795	Economy	13400.00
0005434067211	12795	Economy	13400.00
0005434067227	12795	Economy	13400.00
0005434067418	12795	Economy	13400.00
0005434067149	12795	Economy	13400.00
0005434067331	12795	Economy	13400.00
0005434067587	12795	Economy	13400.00
0005432433708	12795	Economy	13400.00
0005434067219	12795	Economy	13400.00
0005434081812	12795	Economy	13400.00
0005433812911	12795	Economy	13400.00
0005434067304	12795	Economy	13400.00
0005433812912	12795	Economy	13400.00
0005434067173	12795	Economy	13400.00
0005432433706	12795	Economy	13400.00
0005434067303	12795	Economy	13400.00
0005434067315	12795	Economy	13400.00
0005434067371	12795	Economy	13400.00
0005434067039	12795	Economy	13400.00
0005434067205	12795	Economy	13400.00
0005434067216	12795	Economy	13400.00
0005434081847	12795	Economy	13400.00
0005434067188	12795	Economy	13400.00
0005434067543	12795	Economy	13400.00
0005434067474	12795	Economy	13400.00
0005434067268	12795	Economy	13400.00
0005432159880	12795	Economy	13400.00
0005434067305	12795	Economy	13400.00
0005434081734	12795	Economy	13400.00
0005434067335	12795	Economy	13400.00
0005434067286	12795	Economy	13400.00
0005433812913	12795	Economy	14800.00
0005434067313	12795	Economy	14800.00
0005432159879	12795	Economy	14800.00
0005434067325	12795	Economy	14800.00
0005434081825	12795	Economy	14800.00
0005434067273	12795	Economy	14800.00
0005434067499	12795	Economy	13400.00
0005434081775	12795	Economy	13400.00
0005434067599	12795	Economy	13400.00
0005434067373	12795	Economy	13400.00
0005434081809	12795	Economy	13400.00
0005434067588	12795	Economy	13400.00
0005434081824	12795	Economy	13400.00
0005434026694	12795	Economy	13400.00
0005434067222	12795	Economy	13400.00
0005434066961	12795	Economy	13400.00
0005434081802	12795	Economy	13400.00
0005434067031	12795	Economy	13400.00
0005434067537	12795	Economy	13400.00
0005432433705	12795	Economy	13400.00
0005434067168	12795	Economy	13400.00
0005434067127	12795	Economy	13400.00
0005434081803	12795	Economy	13400.00
0005434081818	12795	Economy	13400.00
0005434067187	12795	Economy	13400.00
0005434067260	12795	Economy	13400.00
0005434067568	12795	Economy	13400.00
0005432433704	12795	Economy	13400.00
0005434067284	12795	Economy	13400.00
0005434067243	12795	Economy	13400.00
0005434081770	12795	Economy	13400.00
0005434067506	12795	Economy	13400.00
0005434067175	12795	Economy	13400.00
0005434067536	12795	Economy	13400.00
0005434066962	12795	Economy	13400.00
0005434081846	12795	Economy	13400.00
0005434067412	12795	Economy	13400.00
0005434081774	12795	Economy	13400.00
0005434081776	12795	Economy	13400.00
0005434067411	12795	Economy	13400.00
0005434067224	12795	Economy	13400.00
0005434067332	12795	Economy	13400.00
0005434067008	12795	Economy	13400.00
0005434067314	12795	Economy	13400.00
0005434067267	12795	Economy	13400.00
0005432159882	12795	Economy	13400.00
0005434081808	12795	Economy	13400.00
0005433989747	12795	Economy	13400.00
0005432433707	12795	Economy	13400.00
0005434067285	12795	Economy	13400.00
0005434067363	12795	Economy	13400.00
0005434067417	12795	Economy	13400.00
0005434067117	12795	Economy	13400.00
0005434067215	12795	Economy	13400.00
0005434067545	12795	Economy	13400.00
0005434067326	12795	Economy	13400.00
0005433989744	12795	Economy	13400.00
0005434081827	12795	Economy	13400.00
0005434067110	12795	Economy	13400.00
0005434081807	12795	Economy	13400.00
0005434067226	12795	Economy	13400.00
0005434067225	12795	Economy	13400.00
0005434067452	12795	Economy	13400.00
0005434067485	12795	Economy	13400.00
0005434067480	12795	Economy	13400.00
0005434067221	12795	Economy	13400.00
0005434067544	12795	Economy	13400.00
0005434081757	12795	Economy	13400.00
0005432161164	12795	Economy	13400.00
0005433989755	12795	Economy	13400.00
0005434067316	12795	Economy	13400.00
0005434067327	12795	Economy	13400.00
0005432159881	12795	Economy	13400.00
0005434067625	12795	Economy	13400.00
0005434067566	12795	Economy	13400.00
0005432150224	30674	Business	40300.00
0005433989788	30674	Business	40300.00
0005434067883	30674	Business	40300.00
0005434067849	30674	Business	40300.00
0005434026713	30674	Business	40300.00
0005433989791	30674	Business	40300.00
0005434067859	30674	Business	40300.00
0005434082007	30674	Business	40300.00
0005433812889	30674	Business	40300.00
0005434082005	30674	Business	40300.00
0005434081993	30674	Business	40300.00
0005434067839	30674	Business	40300.00
0005434067853	30674	Economy	13400.00
0005434082006	30674	Economy	13400.00
0005434067870	30674	Economy	13400.00
0005434067886	30674	Economy	13400.00
0005432186884	30674	Economy	13400.00
0005434067829	30674	Economy	13400.00
0005433812892	30674	Economy	13400.00
0005434067847	30674	Economy	13400.00
0005434067820	30674	Economy	13400.00
0005434067830	30674	Economy	13400.00
0005434067857	30674	Economy	13400.00
0005434067878	30674	Economy	13400.00
0005434082003	30674	Economy	13400.00
0005434067841	30674	Economy	13400.00
0005434067867	30674	Economy	13400.00
0005432433641	30674	Economy	13400.00
0005432150226	30674	Economy	13400.00
0005434067876	30674	Economy	13400.00
0005434067879	30674	Economy	13400.00
0005434067850	30674	Economy	13400.00
0005434081986	30674	Economy	13400.00
0005434067871	30674	Economy	13400.00
0005433989792	30674	Economy	13400.00
0005434067888	30674	Economy	13400.00
0005434067887	30674	Economy	13400.00
0005434067832	30674	Economy	13400.00
0005433989789	30674	Economy	13400.00
0005433812885	30674	Economy	13400.00
0005434067824	30674	Economy	13400.00
0005434067825	30674	Economy	13400.00
0005433812891	30674	Economy	13400.00
0005434026711	30674	Economy	13400.00
0005434067882	30674	Economy	13400.00
0005432150227	30674	Economy	13400.00
0005434082000	30674	Economy	13400.00
0005432186883	30674	Economy	13400.00
0005434067891	30674	Economy	13400.00
0005434081998	30674	Economy	13400.00
0005434067873	30674	Economy	13400.00
0005434081999	30674	Economy	13400.00
0005434067826	30674	Economy	14800.00
0005434067872	30674	Economy	14800.00
0005434081990	30674	Economy	14800.00
0005434067846	30674	Economy	14800.00
0005434067822	30674	Economy	14800.00
0005434067827	30674	Economy	14800.00
0005434067845	30674	Economy	13400.00
0005434081989	30674	Economy	13400.00
0005434082001	30674	Economy	13400.00
0005433989793	30674	Economy	13400.00
0005434081991	30674	Economy	13400.00
0005434067885	30674	Economy	13400.00
0005434067865	30674	Economy	13400.00
0005434067855	30674	Economy	13400.00
0005434081992	30674	Economy	13400.00
0005433989790	30674	Economy	13400.00
0005434067884	30674	Economy	13400.00
0005434067860	30674	Economy	13400.00
0005434067836	30674	Economy	13400.00
0005432186882	30674	Economy	13400.00
0005432150225	30674	Economy	13400.00
0005434067874	30674	Economy	13400.00
0005434067852	30674	Economy	13400.00
0005434067837	30674	Economy	13400.00
0005432150229	30674	Economy	13400.00
0005434026709	30674	Economy	13400.00
0005434081994	30674	Economy	13400.00
0005434067889	30674	Economy	13400.00
0005434067831	30674	Economy	13400.00
0005432433680	30674	Economy	13400.00
0005434067828	30674	Economy	13400.00
0005434082004	30674	Economy	13400.00
0005434067848	30674	Economy	13400.00
0005432433670	30674	Economy	13400.00
0005434067834	30674	Economy	13400.00
0005434067866	30674	Economy	13400.00
0005434081985	30674	Economy	13400.00
0005432150223	30674	Economy	13400.00
0005434067890	30674	Economy	13400.00
0005433812884	30674	Economy	13400.00
0005434067877	30674	Economy	13400.00
0005434067862	30674	Economy	13400.00
0005433812888	30674	Economy	13400.00
0005434081996	30674	Economy	13400.00
0005434081988	30674	Economy	13400.00
0005432150228	30674	Economy	13400.00
0005434067864	30674	Economy	13400.00
0005434067838	30674	Economy	13400.00
0005434067856	30674	Economy	13400.00
0005434067842	30674	Economy	13400.00
0005433812890	30674	Economy	13400.00
0005434081987	30674	Economy	13400.00
0005434067861	30674	Economy	13400.00
0005432150230	30674	Economy	13400.00
0005434067863	30674	Economy	13400.00
0005434082002	30674	Economy	13400.00
0005434067868	30674	Economy	13400.00
0005434067835	30674	Economy	13400.00
0005434067881	30674	Economy	13400.00
0005434067833	30674	Economy	13400.00
0005434067821	30674	Economy	13400.00
0005434081997	30674	Economy	13400.00
0005434067843	30674	Economy	13400.00
0005434067844	30674	Economy	13400.00
0005434067854	30674	Economy	13400.00
0005434067840	30674	Economy	13400.00
0005434067858	30674	Economy	13400.00
0005434081995	30674	Economy	13400.00
0005434026714	30674	Economy	13400.00
0005434026712	30674	Economy	13400.00
0005434067880	30674	Economy	13400.00
0005432150231	30674	Economy	13400.00
0005434067875	30674	Economy	13400.00
0005434026710	30674	Economy	13400.00
0005432186885	30674	Economy	13400.00
0005434067823	30674	Economy	13400.00
0005434067851	30674	Economy	13400.00
0005434067869	30674	Economy	13400.00
0005435766518	5486	Business	35300.00
0005435766556	5486	Business	35300.00
0005435462395	5486	Business	35300.00
0005435725624	5486	Business	35300.00
0005435766550	5486	Business	35300.00
0005435723054	5486	Business	35300.00
0005435735156	5486	Business	35300.00
0005434831104	5486	Business	35300.00
0005435766532	5486	Business	35300.00
0005432535801	5486	Business	35300.00
0005435766547	5486	Business	35300.00
0005435766535	5486	Business	35300.00
0005435462408	5486	Business	35300.00
0005435462265	5486	Business	35300.00
0005435766538	5486	Business	35300.00
0005435766513	5486	Business	35300.00
0005435720826	5486	Business	35300.00
0005433527285	5486	Business	35300.00
0005435766520	5486	Business	35300.00
0005435723056	5486	Business	35300.00
0005432535827	5486	Business	35300.00
0005435462373	5486	Business	35300.00
0005435766504	5486	Business	35300.00
0005435725623	5486	Business	35300.00
0005433529298	5486	Business	35300.00
0005435766527	5486	Business	35300.00
0005435766559	5486	Economy	12900.00
0005434265142	5486	Economy	12900.00
0005435462388	5486	Economy	11800.00
0005435766533	5486	Economy	12900.00
0005435735157	5486	Economy	11800.00
0005434265046	5486	Economy	11800.00
0005434831110	5486	Economy	11800.00
0005435723055	5486	Economy	11800.00
0005434265084	5486	Economy	11800.00
0005435766549	5486	Economy	11800.00
0005432140488	5486	Economy	11800.00
0005434831128	5486	Economy	11800.00
0005435462253	5486	Economy	11800.00
0005435766508	5486	Economy	11800.00
0005434831125	5486	Economy	11800.00
0005433529299	5486	Economy	11800.00
0005435766522	5486	Economy	11800.00
0005435766506	5486	Economy	11800.00
0005434831107	5486	Economy	11800.00
0005435735158	5486	Economy	11800.00
0005435766526	5486	Economy	11800.00
0005434265012	5486	Economy	11800.00
0005435766530	5486	Economy	11800.00
0005435462205	5486	Economy	11800.00
0005434831124	5486	Economy	11800.00
0005435462320	5486	Economy	11800.00
0005433527286	5486	Economy	11800.00
0005435766539	5486	Economy	11800.00
0005435766548	5486	Economy	11800.00
0005435725622	5486	Economy	11800.00
0005435723057	5486	Economy	11800.00
0005435766540	5486	Economy	11800.00
0005435462429	5486	Economy	11800.00
0005434265168	5486	Economy	11800.00
0005435766544	5486	Economy	11800.00
0005435766536	5486	Economy	11800.00
0005432140491	5486	Economy	11800.00
0005434264966	5486	Economy	11800.00
0005435766560	5486	Economy	11800.00
0005435766557	5486	Economy	11800.00
0005435766534	5486	Economy	11800.00
0005434264997	5486	Economy	11800.00
0005435766511	5486	Economy	11800.00
0005435462319	5486	Economy	11800.00
0005435462279	5486	Economy	11800.00
0005435766529	5486	Economy	11800.00
0005435462280	5486	Economy	11800.00
0005435462255	5486	Economy	11800.00
0005435462296	5486	Economy	11800.00
0005435462315	5486	Economy	11800.00
0005435462366	5486	Economy	11800.00
0005435766553	5486	Economy	11800.00
0005435766555	5486	Economy	11800.00
0005435462370	5486	Economy	11800.00
0005432140489	5486	Economy	11800.00
0005435766519	5486	Economy	11800.00
0005432140484	5486	Economy	11800.00
0005434264908	5486	Economy	11800.00
0005435766542	5486	Economy	11800.00
0005434265021	5486	Economy	11800.00
0005435462386	5486	Economy	11800.00
0005435766505	5486	Economy	11800.00
0005434265167	5486	Economy	11800.00
0005435766537	5486	Economy	11800.00
0005435462424	5486	Economy	11800.00
0005434265118	5486	Economy	11800.00
0005435766517	5486	Economy	11800.00
0005433529296	5486	Economy	11800.00
0005434831105	5486	Economy	11800.00
0005432140486	5486	Economy	11800.00
0005434264942	5486	Economy	11800.00
0005435722067	5486	Economy	11800.00
0005435766507	5486	Economy	11800.00
0005432535815	5486	Economy	11800.00
0005435043283	5486	Economy	11800.00
0005434265141	5486	Economy	11800.00
0005435462277	5486	Economy	11800.00
0005435462316	5486	Economy	11800.00
0005434264996	5486	Economy	11800.00
0005435462385	5486	Economy	11800.00
0005435735154	5486	Economy	11800.00
0005432140485	5486	Economy	11800.00
0005432535832	5486	Economy	12900.00
0005435766509	5486	Economy	12900.00
0005434265033	5486	Economy	11800.00
0005435766521	5486	Economy	11800.00
0005435462089	5486	Economy	11800.00
0005434265095	5486	Economy	12900.00
0005435766523	5486	Economy	11800.00
0005433527288	5486	Economy	11800.00
0005435462194	5486	Economy	11800.00
0005434265062	5486	Economy	11800.00
0005435462239	5486	Economy	11800.00
0005434265032	5486	Economy	11800.00
0005434265078	5486	Economy	11800.00
0005433527287	5486	Economy	11800.00
0005435766512	5486	Economy	11800.00
0005435766510	5486	Economy	11800.00
0005434265131	5486	Economy	11800.00
0005434264967	5486	Economy	11800.00
0005434265059	5486	Economy	11800.00
0005435725620	5486	Economy	11800.00
0005435766552	5486	Economy	11800.00
0005434265083	5486	Economy	11800.00
0005434265117	5486	Economy	11800.00
0005434264914	5486	Economy	11800.00
0005435043285	5486	Economy	11800.00
0005435766543	5486	Economy	11800.00
0005434265169	5486	Economy	11800.00
0005435766525	5486	Economy	11800.00
0005435462381	5486	Economy	11800.00
0005435725619	5486	Economy	11800.00
0005435725621	5486	Economy	11800.00
0005435735155	5486	Economy	11800.00
0005434264915	5486	Economy	11800.00
0005435735153	5486	Economy	11800.00
0005434265091	5486	Economy	11800.00
0005432535799	5486	Economy	11800.00
0005435766515	5486	Economy	11800.00
0005434264999	5486	Economy	11800.00
0005435462191	5486	Economy	11800.00
0005434265092	5486	Economy	11800.00
0005432140487	5486	Economy	11800.00
0005435766545	5486	Economy	11800.00
0005435462283	5486	Economy	11800.00
0005432535816	5486	Economy	11800.00
0005434831132	5486	Economy	11800.00
0005434831127	5486	Economy	11800.00
0005434264932	5486	Economy	11800.00
0005434265054	5486	Economy	11800.00
0005434265034	5486	Economy	11800.00
0005435462300	5486	Economy	11800.00
0005434265047	5486	Economy	11800.00
0005435462007	5486	Economy	11800.00
0005435766514	5486	Economy	11800.00
0005432535800	5486	Economy	11800.00
0005434831108	5486	Economy	11800.00
0005434265020	5486	Economy	11800.00
0005435766551	5486	Economy	11800.00
0005432140492	5486	Economy	11800.00
0005435766546	5486	Economy	11800.00
0005435766528	5486	Economy	11800.00
0005433529297	5486	Economy	11800.00
0005435766541	5486	Economy	11800.00
0005435766524	5486	Economy	11800.00
0005434265061	5486	Economy	11800.00
0005435766558	5486	Economy	11800.00
0005434265053	5486	Economy	11800.00
0005435766531	5486	Economy	11800.00
0005435462198	5486	Economy	11800.00
0005435766554	5486	Economy	11800.00
0005435766516	5486	Economy	11800.00
0005432140490	5486	Economy	11800.00
0005435462346	5486	Economy	11800.00
0005434265258	13497	Business	35300.00
0005433533301	13497	Business	35300.00
0005435766076	13497	Business	35300.00
0005435765893	13497	Business	35300.00
0005435766001	13497	Business	35300.00
0005435766085	13497	Business	35300.00
0005435462642	13497	Business	35300.00
0005435462612	13497	Business	35300.00
0005435462640	13497	Business	35300.00
0005435462615	13497	Business	35300.00
0005434265272	13497	Business	35300.00
0005435462618	13497	Business	35300.00
0005433533265	13497	Business	35300.00
0005432194529	13497	Business	35300.00
0005434265275	13497	Business	35300.00
0005432535860	13497	Business	35300.00
0005435765870	13497	Business	35300.00
0005435765842	13497	Business	35300.00
0005435462637	13497	Business	35300.00
0005435765918	13497	Business	35300.00
0005435462630	13497	Business	35300.00
0005433529247	13497	Business	35300.00
0005435765773	13497	Business	35300.00
0005433529232	13497	Business	35300.00
0005434265266	13497	Economy	12900.00
0005435720131	13497	Economy	12900.00
0005435765830	13497	Economy	12900.00
0005435462644	13497	Economy	11800.00
0005435462610	13497	Economy	12900.00
0005435462616	13497	Economy	11800.00
0005434265276	13497	Economy	11800.00
0005434265283	13497	Economy	11800.00
0005433529237	13497	Economy	11800.00
0005435765964	13497	Economy	11800.00
0005435462639	13497	Economy	11800.00
0005435462628	13497	Economy	11800.00
0005435765975	13497	Economy	11800.00
0005434831177	13497	Economy	11800.00
0005432194531	13497	Economy	11800.00
0005434265277	13497	Economy	11800.00
0005435765974	13497	Economy	11800.00
0005434265262	13497	Economy	11800.00
0005435462632	13497	Economy	11800.00
0005433529263	13497	Economy	11800.00
0005433533305	13497	Economy	11800.00
0005435462620	13497	Economy	11800.00
0005435462614	13497	Economy	11800.00
0005435462606	13497	Economy	11800.00
0005435766071	13497	Economy	11800.00
0005435766093	13497	Economy	11800.00
0005433533294	13497	Economy	11800.00
0005434831175	13497	Economy	11800.00
0005435765791	13497	Economy	11800.00
0005435462633	13497	Economy	11800.00
0005435462635	13497	Economy	11800.00
0005435766015	13497	Economy	11800.00
0005435462617	13497	Economy	11800.00
0005435765915	13497	Economy	11800.00
0005433533290	13497	Economy	11800.00
0005434831174	13497	Economy	11800.00
0005435765871	13497	Economy	11800.00
0005435765929	13497	Economy	11800.00
0005435765865	13497	Economy	11800.00
0005435722053	13497	Economy	11800.00
0005435765968	13497	Economy	11800.00
0005432535861	13497	Economy	11800.00
0005435766043	13497	Economy	11800.00
0005432535858	13497	Economy	11800.00
0005432194533	13497	Economy	11800.00
0005434265270	13497	Economy	11800.00
0005435735117	13497	Economy	11800.00
0005435462638	13497	Economy	11800.00
0005433533283	13497	Economy	11800.00
0005435766026	13497	Economy	11800.00
0005435765896	13497	Economy	11800.00
0005435735129	13497	Economy	11800.00
0005434265264	13497	Economy	11800.00
0005435765990	13497	Economy	11800.00
0005433533277	13497	Economy	11800.00
0005435462609	13497	Economy	11800.00
0005434265280	13497	Economy	11800.00
0005435766090	13497	Economy	11800.00
0005435735122	13497	Economy	11800.00
0005435765894	13497	Economy	11800.00
0005435765774	13497	Economy	11800.00
0005433529246	13497	Economy	11800.00
0005435765834	13497	Economy	11800.00
0005434265259	13497	Economy	11800.00
0005435462627	13497	Economy	11800.00
0005433533284	13497	Economy	11800.00
0005435766091	13497	Economy	11800.00
0005434265269	13497	Economy	11800.00
0005435462641	13497	Economy	11800.00
0005432194532	13497	Economy	11800.00
0005435722052	13497	Economy	11800.00
0005435462619	13497	Economy	11800.00
0005433529252	13497	Economy	11800.00
0005435462629	13497	Economy	11800.00
0005435766088	13497	Economy	11800.00
0005435462622	13497	Economy	11800.00
0005435765931	13497	Economy	11800.00
0005434265282	13497	Economy	11800.00
0005433533276	13497	Economy	11800.00
0005434265273	13497	Economy	11800.00
0005433533278	13497	Economy	11800.00
0005435766094	13497	Economy	11800.00
0005435766087	13497	Economy	11800.00
0005435765883	13497	Economy	11800.00
0005435766089	13497	Economy	11800.00
0005435765895	13497	Economy	11800.00
0005435735127	13497	Economy	11800.00
0005434265278	13497	Economy	11800.00
0005434265261	13497	Economy	11800.00
0005435765942	13497	Economy	12900.00
0005435462643	13497	Economy	12900.00
0005434265265	13497	Economy	11800.00
0005435766047	13497	Economy	11800.00
0005435462631	13497	Economy	12900.00
0005433533295	13497	Economy	12900.00
0005435735138	13497	Economy	11800.00
0005433529233	13497	Economy	11800.00
0005435765901	13497	Economy	11800.00
0005435462611	13497	Economy	11800.00
0005434265263	13497	Economy	11800.00
0005433529243	13497	Economy	11800.00
0005435766096	13497	Economy	11800.00
0005432535859	13497	Economy	11800.00
0005435766083	13497	Economy	11800.00
0005434265260	13497	Economy	11800.00
0005435735133	13497	Economy	11800.00
0005435723036	13497	Economy	11800.00
0005433533272	13497	Economy	11800.00
0005434265271	13497	Economy	11800.00
0005435765991	13497	Economy	11800.00
0005435723035	13497	Economy	11800.00
0005435462607	13497	Economy	11800.00
0005435462626	13497	Economy	11800.00
0005435766072	13497	Economy	11800.00
0005435765936	13497	Economy	11800.00
0005435766086	13497	Economy	11800.00
0005432194530	13497	Economy	11800.00
0005435766084	13497	Economy	11800.00
0005435765940	13497	Economy	11800.00
0005435462613	13497	Economy	11800.00
0005433529238	13497	Economy	11800.00
0005433529245	13497	Economy	11800.00
0005435766075	13497	Economy	11800.00
0005434265267	13497	Economy	11800.00
0005435765989	13497	Economy	11800.00
0005433529248	13497	Economy	11800.00
0005435765930	13497	Economy	11800.00
0005435462624	13497	Economy	11800.00
0005435462625	13497	Economy	11800.00
0005435735124	13497	Economy	11800.00
0005435462621	13497	Economy	11800.00
0005435043289	13497	Economy	11800.00
0005435462636	13497	Economy	11800.00
0005435735130	13497	Economy	11800.00
0005433529230	13497	Economy	11800.00
0005435043288	13497	Economy	11800.00
0005434265281	13497	Economy	11800.00
0005433529253	13497	Economy	11800.00
0005433533306	13497	Economy	11800.00
0005433529234	13497	Economy	11800.00
0005435766077	13497	Economy	11800.00
0005435766092	13497	Economy	11800.00
0005435462623	13497	Economy	11800.00
0005433529225	13497	Economy	11800.00
0005435766044	13497	Economy	11800.00
0005435765775	13497	Economy	11800.00
0005434265279	13497	Economy	11800.00
0005435735123	13497	Economy	11800.00
0005435462608	13497	Economy	11800.00
0005435462634	13497	Economy	11800.00
0005433529242	13497	Economy	11800.00
0005434265268	13497	Economy	11800.00
0005433533302	13497	Economy	11800.00
0005433533273	13497	Economy	11800.00
0005434831176	13497	Economy	11800.00
0005434265274	13497	Economy	11800.00
0005433529264	13497	Economy	11800.00
0005435765973	13497	Economy	11800.00
0005435725577	13497	Economy	11800.00
0005434602898	18690	Economy	3300.00
0005434602897	18690	Economy	3300.00
0005434602891	18690	Economy	3300.00
0005434604883	18683	Economy	3300.00
0005434604887	18683	Economy	3300.00
0005434604884	18683	Economy	3300.00
0005434514979	18683	Economy	3300.00
0005434604885	18683	Economy	3300.00
0005434514978	18683	Economy	3300.00
0005434604880	18683	Economy	3300.00
0005434514966	19217	Economy	3300.00
0005434514967	19217	Economy	3300.00
0005434514968	19217	Economy	3300.00
0005435846239	4118	Business	88300.00
0005435846237	4118	Business	88300.00
0005432649431	4118	Business	88300.00
0005435846249	4118	Business	88300.00
0005435844307	4118	Business	88300.00
0005432649427	4118	Business	88300.00
0005432632782	4118	Economy	29400.00
0005435844303	4118	Economy	29400.00
0005435846230	4118	Economy	29400.00
0005432632776	4118	Economy	29400.00
0005435844311	4118	Economy	29400.00
0005432649430	4118	Economy	29400.00
0005435846228	4118	Economy	29400.00
0005435844301	4118	Economy	32400.00
0005435846231	4118	Economy	29400.00
0005432632777	4118	Economy	29400.00
0005432632779	4118	Economy	29400.00
0005432632772	4118	Economy	29400.00
0005432632773	4118	Economy	29400.00
0005435846229	4118	Economy	29400.00
0005432632771	4118	Economy	29400.00
0005432649429	4118	Economy	29400.00
0005432649435	4118	Economy	29400.00
0005435846235	4118	Economy	29400.00
0005435844289	4118	Economy	29400.00
0005435844302	4118	Economy	29400.00
0005432632775	4118	Economy	29400.00
0005432649437	4118	Economy	29400.00
0005432632774	4118	Economy	29400.00
0005435844308	4118	Economy	29400.00
0005435846248	4118	Economy	29400.00
0005432632769	4118	Economy	29400.00
0005435846227	4118	Economy	29400.00
0005432632768	4118	Economy	29400.00
0005435844288	4118	Economy	29400.00
0005432649434	4118	Economy	29400.00
0005432649432	4118	Economy	29400.00
0005435844300	4118	Economy	29400.00
0005432632778	4118	Economy	29400.00
0005435844309	4118	Economy	29400.00
0005432632781	4118	Economy	29400.00
0005432649436	4118	Economy	29400.00
0005435846238	4118	Economy	29400.00
0005435844285	4118	Economy	29400.00
0005432649433	4118	Economy	29400.00
0005432632780	4118	Economy	29400.00
0005432632770	4118	Economy	29400.00
0005435844312	4118	Economy	29400.00
0005432649428	4118	Economy	29400.00
0005433285090	1795	Business	48700.00
0005433008597	1795	Business	48700.00
0005433285243	1795	Business	48700.00
0005433285251	1795	Business	48700.00
0005433008363	1795	Business	48700.00
0005433285232	1795	Business	48700.00
0005433008588	1795	Business	48700.00
0005433810574	1795	Business	48700.00
0005433285266	1795	Business	48700.00
0005433008462	1795	Economy	16200.00
0005433008514	1795	Economy	16200.00
0005433008522	1795	Economy	16200.00
0005433008598	1795	Economy	16200.00
0005432295892	1795	Economy	16200.00
0005433008267	1795	Economy	16200.00
0005433285267	1795	Economy	16200.00
0005433285148	1795	Economy	17900.00
0005433008285	1795	Economy	17900.00
0005433810573	1795	Economy	17900.00
0005433008607	1795	Economy	17900.00
0005433008252	1795	Economy	16200.00
0005433285086	1795	Economy	16200.00
0005433285320	1795	Economy	16200.00
0005433008574	1795	Economy	16200.00
0005433285142	1795	Economy	16200.00
0005433008165	1795	Economy	16200.00
0005433285111	1795	Economy	16200.00
0005433810576	1795	Economy	16200.00
0005433008476	1795	Economy	16200.00
0005433285252	1795	Economy	16200.00
0005433810575	1795	Economy	16200.00
0005433285304	1795	Economy	16200.00
0005433008450	1795	Economy	16200.00
0005433008400	1795	Economy	16200.00
0005433008493	1795	Economy	16200.00
0005433008251	1795	Economy	16200.00
0005433285356	1795	Economy	16200.00
0005433008166	1795	Economy	16200.00
0005433285165	1795	Economy	16200.00
0005433285305	1795	Economy	16200.00
0005433285175	1795	Economy	16200.00
0005433285091	1795	Economy	16200.00
0005433285224	1795	Economy	16200.00
0005433285178	1795	Economy	16200.00
0005433285180	1795	Economy	16200.00
0005433285302	1795	Economy	16200.00
0005432295893	1795	Economy	16200.00
0005433285144	1795	Economy	16200.00
0005433285143	1795	Economy	16200.00
0005433008565	1795	Economy	16200.00
0005433008445	1795	Economy	16200.00
0005433285138	1795	Economy	16200.00
0005433285117	1795	Economy	16200.00
0005433285157	1795	Economy	16200.00
0005433285176	1795	Economy	16200.00
0005433285139	1795	Economy	16200.00
0005433285290	1795	Economy	16200.00
0005433008425	1795	Economy	16200.00
0005433810572	1795	Economy	16200.00
0005433008268	1795	Economy	16200.00
0005433008558	1795	Economy	16200.00
0005433008576	1795	Economy	16200.00
0005433008672	1795	Economy	16200.00
0005433285209	1795	Economy	16200.00
0005433285116	1795	Economy	16200.00
0005433285355	1795	Economy	16200.00
0005433008417	1795	Economy	16200.00
0005433008244	1795	Economy	16200.00
0005433285319	1795	Economy	16200.00
0005433810577	1795	Economy	16200.00
0005433285149	1795	Economy	16200.00
0005433285146	1795	Economy	16200.00
0005433008653	1795	Economy	16200.00
0005433008652	1795	Economy	16200.00
0005433008262	1795	Economy	16200.00
0005433008261	1795	Economy	16200.00
0005433285177	1795	Economy	16200.00
0005433285166	1795	Economy	16200.00
0005433008692	1795	Economy	16200.00
0005433008465	1795	Economy	16200.00
0005433008489	1795	Economy	16200.00
0005433008843	22525	Business	48700.00
0005433285436	22525	Business	48700.00
0005433008803	22525	Business	48700.00
0005433008840	22525	Business	48700.00
0005433008807	22525	Business	48700.00
0005433810514	22525	Business	48700.00
0005433008802	22525	Business	48700.00
0005433285427	22525	Business	48700.00
0005433008832	22525	Business	48700.00
0005433285446	22525	Business	48700.00
0005433285430	22525	Economy	16200.00
0005433008823	22525	Economy	16200.00
0005433008813	22525	Economy	16200.00
0005433008824	22525	Economy	16200.00
0005433008814	22525	Economy	16200.00
0005433008805	22525	Economy	16200.00
0005433008812	22525	Economy	16200.00
0005433285443	22525	Economy	16200.00
0005433285424	22525	Economy	17900.00
0005433008818	22525	Economy	17900.00
0005433285438	22525	Economy	17900.00
0005433008841	22525	Economy	17900.00
0005433008804	22525	Economy	16200.00
0005433008798	22525	Economy	16200.00
0005433285454	22525	Economy	16200.00
0005433285442	22525	Economy	16200.00
0005433008816	22525	Economy	16200.00
0005433285450	22525	Economy	16200.00
0005433285440	22525	Economy	16200.00
0005433285428	22525	Economy	16200.00
0005433008837	22525	Economy	16200.00
0005433008815	22525	Economy	16200.00
0005433008808	22525	Economy	16200.00
0005433285451	22525	Economy	16200.00
0005433008838	22525	Economy	16200.00
0005433285447	22525	Economy	16200.00
0005433008835	22525	Economy	16200.00
0005433008799	22525	Economy	16200.00
0005433008828	22525	Economy	16200.00
0005433285431	22525	Economy	16200.00
0005433285455	22525	Economy	16200.00
0005433008800	22525	Economy	16200.00
0005433008829	22525	Economy	16200.00
0005433008797	22525	Economy	16200.00
0005433008825	22525	Economy	16200.00
0005433285434	22525	Economy	16200.00
0005433008834	22525	Economy	16200.00
0005433008810	22525	Economy	16200.00
0005433008819	22525	Economy	16200.00
0005433008821	22525	Economy	16200.00
0005433008801	22525	Economy	16200.00
0005433285437	22525	Economy	16200.00
0005433285433	22525	Economy	16200.00
0005433285444	22525	Economy	16200.00
0005433008836	22525	Economy	16200.00
0005433285439	22525	Economy	16200.00
0005433285432	22525	Economy	16200.00
0005433008842	22525	Economy	16200.00
0005433008827	22525	Economy	16200.00
0005433008811	22525	Economy	16200.00
0005433285435	22525	Economy	16200.00
0005433810512	22525	Economy	16200.00
0005433285429	22525	Economy	16200.00
0005433008822	22525	Economy	16200.00
0005433008830	22525	Economy	16200.00
0005433008826	22525	Economy	16200.00
0005433008806	22525	Economy	16200.00
0005433008809	22525	Economy	16200.00
0005433285425	22525	Economy	16200.00
0005433008839	22525	Economy	16200.00
0005433008817	22525	Economy	16200.00
0005433285452	22525	Economy	16200.00
0005433285445	22525	Economy	16200.00
0005433285448	22525	Economy	16200.00
0005433285426	22525	Economy	16200.00
0005433008833	22525	Economy	16200.00
0005433008820	22525	Economy	16200.00
0005433285449	22525	Economy	16200.00
0005433285441	22525	Economy	16200.00
0005433810513	22525	Economy	16200.00
0005433285453	22525	Economy	16200.00
0005433008831	22525	Economy	16200.00
0005433846986	5549	Business	99800.00
0005435282410	5549	Business	99800.00
0005435282444	5549	Business	99800.00
0005433846995	5549	Business	99800.00
0005433847020	5549	Business	99800.00
0005433847000	5549	Business	99800.00
0005435282423	5549	Business	99800.00
0005434173504	5549	Business	99800.00
0005433846984	5549	Business	99800.00
0005433847013	5549	Business	99800.00
0005433847001	5549	Business	99800.00
0005433847008	5549	Business	99800.00
0005435282319	5549	Business	99800.00
0005433847035	5549	Business	99800.00
0005435282441	5549	Business	99800.00
0005435282383	5549	Business	99800.00
0005435282411	5549	Business	99800.00
0005435282396	5549	Business	99800.00
0005433847023	5549	Business	99800.00
0005433846989	5549	Economy	33300.00
0005433815408	5549	Economy	33300.00
0005433847003	5549	Economy	33300.00
0005433847010	5549	Economy	33300.00
0005433847018	5549	Economy	33300.00
0005433847037	5549	Economy	33300.00
0005435282457	5549	Economy	33300.00
0005433846988	5549	Economy	33300.00
0005432081543	5549	Economy	33300.00
0005433847036	5549	Economy	33300.00
0005433815404	5549	Economy	33300.00
0005435282412	5549	Economy	33300.00
0005433846979	5549	Economy	33300.00
0005433846987	5549	Economy	36600.00
0005433847028	5549	Economy	36600.00
0005433847009	5549	Economy	36600.00
0005433815405	5549	Economy	36600.00
0005433847022	5549	Economy	33300.00
0005432081539	5549	Economy	33300.00
0005433846978	5549	Economy	33300.00
0005433847030	5549	Economy	33300.00
0005433846994	5549	Economy	33300.00
0005433846999	5549	Economy	33300.00
0005432081542	5549	Economy	33300.00
0005435282407	5549	Economy	33300.00
0005435282397	5549	Economy	33300.00
0005435282310	5549	Economy	33300.00
0005435282288	5549	Economy	33300.00
0005433847027	5549	Economy	33300.00
0005435282456	5549	Economy	33300.00
0005434173501	5549	Economy	33300.00
0005435282503	5549	Economy	33300.00
0005435282421	5549	Economy	33300.00
0005433846997	5549	Economy	33300.00
0005432081545	5549	Economy	33300.00
0005433847016	5549	Economy	33300.00
0005435282422	5549	Economy	33300.00
0005433847029	5549	Economy	33300.00
0005433847015	5549	Economy	33300.00
0005433847034	5549	Economy	33300.00
0005435282473	5549	Economy	33300.00
0005433846982	5549	Economy	33300.00
0005433847005	5549	Economy	33300.00
0005435282394	5549	Economy	33300.00
0005433846985	5549	Economy	33300.00
0005435282320	5549	Economy	33300.00
0005433846993	5549	Economy	33300.00
0005433815406	5549	Economy	33300.00
0005434173505	5549	Economy	33300.00
0005433847004	5549	Economy	33300.00
0005433846981	5549	Economy	33300.00
0005433847002	5549	Economy	33300.00
0005433846991	5549	Economy	33300.00
0005433846980	5549	Economy	33300.00
0005435282370	5549	Economy	33300.00
0005435282400	5549	Economy	33300.00
0005435282492	5549	Economy	33300.00
0005433847012	5549	Economy	33300.00
0005435282293	5549	Economy	33300.00
0005435282318	5549	Economy	33300.00
0005433847011	5549	Economy	33300.00
0005435282500	5549	Economy	33300.00
0005433847024	5549	Economy	33300.00
0005433846983	5549	Economy	33300.00
0005432081541	5549	Economy	33300.00
0005433847006	5549	Economy	33300.00
0005433846998	5549	Economy	33300.00
0005435282493	5549	Economy	33300.00
0005435282472	5549	Economy	33300.00
0005433815407	5549	Economy	33300.00
0005433846990	5549	Economy	33300.00
0005433847033	5549	Economy	33300.00
0005433847021	5549	Economy	33300.00
0005433847026	5549	Economy	33300.00
0005433846992	5549	Economy	33300.00
0005433847032	5549	Economy	33300.00
0005433847031	5549	Economy	33300.00
0005435282408	5549	Economy	33300.00
0005435282510	5549	Economy	33300.00
0005435282369	5549	Economy	33300.00
0005433847019	5549	Economy	33300.00
0005432081540	5549	Economy	33300.00
0005435282388	5549	Economy	33300.00
0005433846996	5549	Economy	33300.00
0005435282395	5549	Economy	33300.00
0005433847007	5549	Economy	33300.00
0005433847014	5549	Economy	33300.00
0005433847017	5549	Economy	33300.00
0005435282420	5549	Economy	33300.00
0005435282401	5549	Economy	33300.00
0005433847025	5549	Economy	33300.00
0005432081544	5549	Economy	33300.00
0005433846619	13840	Business	99800.00
0005433846302	13840	Business	99800.00
0005433846499	13840	Business	99800.00
0005433846588	13840	Business	99800.00
0005433846407	13840	Business	99800.00
0005433846394	13840	Business	99800.00
0005433846604	13840	Business	99800.00
0005433846497	13840	Business	99800.00
0005432003716	13840	Business	99800.00
0005433846542	13840	Business	99800.00
0005432003718	13840	Business	99800.00
0005435282642	13840	Business	99800.00
0005433846369	13840	Business	99800.00
0005435282634	13840	Business	99800.00
0005433846476	13840	Business	99800.00
0005432003717	13840	Business	99800.00
0005435282623	13840	Business	99800.00
0005433846648	13840	Business	99800.00
0005433846618	13840	Business	99800.00
0005435282625	13840	Economy	33300.00
0005433846586	13840	Economy	33300.00
0005435282618	13840	Economy	33300.00
0005433846724	13840	Economy	33300.00
0005433846415	13840	Economy	33300.00
0005433846594	13840	Economy	33300.00
0005433846734	13840	Economy	33300.00
0005433846486	13840	Economy	33300.00
0005433846541	13840	Economy	33300.00
0005433846421	13840	Economy	33300.00
0005433846392	13840	Economy	33300.00
0005433846587	13840	Economy	33300.00
0005435282639	13840	Economy	36600.00
0005433846307	13840	Economy	36600.00
0005435282627	13840	Economy	36600.00
0005433846423	13840	Economy	36600.00
0005433846370	13840	Economy	33300.00
0005435282626	13840	Economy	33300.00
0005433846631	13840	Economy	33300.00
0005433846525	13840	Economy	33300.00
0005433846408	13840	Economy	33300.00
0005435282640	13840	Economy	33300.00
0005433846489	13840	Economy	33300.00
0005433846647	13840	Economy	33300.00
0005435282630	13840	Economy	33300.00
0005433846439	13840	Economy	33300.00
0005435282633	13840	Economy	33300.00
0005435282636	13840	Economy	33300.00
0005433846589	13840	Economy	33300.00
0005435282644	13840	Economy	33300.00
0005433846552	13840	Economy	33300.00
0005435282619	13840	Economy	33300.00
0005433846271	13840	Economy	33300.00
0005433846617	13840	Economy	33300.00
0005433846632	13840	Economy	33300.00
0005434173540	13840	Economy	33300.00
0005433846641	13840	Economy	33300.00
0005435282629	13840	Economy	33300.00
0005435282643	13840	Economy	33300.00
0005433846460	13840	Economy	33300.00
0005434173542	13840	Economy	33300.00
0005433846477	13840	Economy	33300.00
0005433846680	13840	Economy	33300.00
0005433846681	13840	Economy	33300.00
0005433846491	13840	Economy	33300.00
0005435282621	13840	Economy	33300.00
0005433846442	13840	Economy	33300.00
0005433846471	13840	Economy	33300.00
0005433846495	13840	Economy	33300.00
0005433846516	13840	Economy	33300.00
0005435282638	13840	Economy	33300.00
0005433846566	13840	Economy	33300.00
0005433846521	13840	Economy	33300.00
0005433846622	13840	Economy	33300.00
0005433846567	13840	Economy	33300.00
0005433846480	13840	Economy	33300.00
0005433846469	13840	Economy	33300.00
0005433846306	13840	Economy	33300.00
0005435282632	13840	Economy	33300.00
0005433846488	13840	Economy	33300.00
0005435282620	13840	Economy	33300.00
0005435282635	13840	Economy	33300.00
0005434173539	13840	Economy	33300.00
0005433846590	13840	Economy	33300.00
0005433846642	13840	Economy	33300.00
0005435282637	13840	Economy	33300.00
0005432003719	13840	Economy	33300.00
0005435282622	13840	Economy	33300.00
0005433846509	13840	Economy	33300.00
0005433846595	13840	Economy	33300.00
0005433846303	13840	Economy	33300.00
0005435282628	13840	Economy	33300.00
0005433846550	13840	Economy	33300.00
0005433846323	13840	Economy	33300.00
0005435282624	13840	Economy	33300.00
0005435282641	13840	Economy	33300.00
0005434173541	13840	Economy	33300.00
0005433846496	13840	Economy	33300.00
0005433846762	13840	Economy	33300.00
0005433846468	13840	Economy	33300.00
0005433846761	13840	Economy	33300.00
0005433846551	13840	Economy	33300.00
0005434173538	13840	Economy	33300.00
0005433846459	13840	Economy	33300.00
0005435282631	13840	Economy	33300.00
0005432003715	13840	Economy	33300.00
0005433846498	13840	Economy	33300.00
0005433846419	13840	Economy	33300.00
0005434620702	7807	Economy	16600.00
0005432112526	7807	Economy	16600.00
0005435332344	7807	Economy	16600.00
0005435332342	7807	Economy	15100.00
0005435332270	7807	Economy	15100.00
0005432112527	7807	Economy	15100.00
0005434620693	7807	Economy	15100.00
0005434620700	7807	Economy	15100.00
0005434620697	7807	Economy	15100.00
0005434620692	7807	Economy	15100.00
0005434620694	7807	Economy	15100.00
0005434620696	7807	Economy	15100.00
0005434620705	7807	Economy	15100.00
0005434620699	7807	Economy	15100.00
0005434620704	7807	Economy	15100.00
0005434620687	7807	Economy	15100.00
0005435332334	7807	Economy	15100.00
0005432112528	7807	Economy	15100.00
0005434620695	7807	Economy	15100.00
0005434620690	7807	Economy	15100.00
0005434620686	7807	Economy	15100.00
0005434620689	7807	Economy	15100.00
0005435332269	7807	Economy	15100.00
0005435332296	7807	Economy	15100.00
0005434620698	7807	Economy	15100.00
0005435332333	7807	Economy	15100.00
0005435332271	7807	Economy	15100.00
0005435332343	7807	Economy	15100.00
0005434620701	7807	Economy	15100.00
0005434620691	7807	Economy	15100.00
0005434620703	7807	Economy	15100.00
0005434620688	7807	Economy	15100.00
0005434620523	32984	Economy	16600.00
0005435332382	32984	Economy	16600.00
0005434620467	32984	Economy	16600.00
0005434620475	32984	Economy	15100.00
0005434620574	32984	Economy	15100.00
0005434620541	32984	Economy	15100.00
0005434620521	32984	Economy	15100.00
0005435332386	32984	Economy	15100.00
0005434620621	32984	Economy	15100.00
0005434620406	32984	Economy	15100.00
0005434620527	32984	Economy	15100.00
0005434620573	32984	Economy	15100.00
0005435332385	32984	Economy	15100.00
0005435332387	32984	Economy	15100.00
0005434620481	32984	Economy	15100.00
0005434620528	32984	Economy	15100.00
0005435332390	32984	Economy	15100.00
0005434620548	32984	Economy	15100.00
0005434620438	32984	Economy	15100.00
0005434620502	32984	Economy	15100.00
0005435332388	32984	Economy	15100.00
0005434620526	32984	Economy	15100.00
0005434620530	32984	Economy	15100.00
0005434620554	32984	Economy	15100.00
0005434620522	32984	Economy	15100.00
0005434620486	32984	Economy	15100.00
0005434620456	32984	Economy	15100.00
0005434620520	32984	Economy	15100.00
0005435332383	32984	Economy	15100.00
0005435332389	32984	Economy	15100.00
0005434620584	32984	Economy	15100.00
0005434620474	32984	Economy	15100.00
0005434620546	32984	Economy	15100.00
0005434620518	32984	Economy	15100.00
0005435332381	32984	Economy	15100.00
0005435332384	32984	Economy	15100.00
0005434620501	32984	Economy	15100.00
0005434620457	32984	Economy	15100.00
0005435785515	4310	Business	38000.00
0005435785535	4310	Business	38000.00
0005435785510	4310	Business	38000.00
0005434994076	4310	Business	38000.00
0005432190651	4310	Business	38000.00
0005432190647	4310	Business	38000.00
0005435785524	4310	Business	38000.00
0005435785542	4310	Business	38000.00
0005435785529	4310	Business	38000.00
0005435785534	4310	Economy	12700.00
0005434994070	4310	Economy	12700.00
0005435785513	4310	Economy	12700.00
0005435785527	4310	Economy	12700.00
0005435937354	4310	Economy	12700.00
0005435918671	4310	Economy	12700.00
0005435785519	4310	Economy	13900.00
0005435785511	4310	Economy	13900.00
0005434994074	4310	Economy	13900.00
0005432190649	4310	Economy	12700.00
0005435785520	4310	Economy	12700.00
0005435785536	4310	Economy	12700.00
0005434994068	4310	Economy	12700.00
0005435785508	4310	Economy	12700.00
0005435918640	4310	Economy	12700.00
0005434994065	4310	Economy	12700.00
0005435785530	4310	Economy	12700.00
0005435918639	4310	Economy	12700.00
0005432190650	4310	Economy	12700.00
0005435937360	4310	Economy	12700.00
0005434994066	4310	Economy	12700.00
0005435785540	4310	Economy	12700.00
0005435785516	4310	Economy	12700.00
0005432190646	4310	Economy	12700.00
0005435918625	4310	Economy	12700.00
0005435785528	4310	Economy	12700.00
0005432190648	4310	Economy	12700.00
0005435785521	4310	Economy	12700.00
0005435785531	4310	Economy	12700.00
0005434994071	4310	Economy	12700.00
0005435918653	4310	Economy	12700.00
0005435787365	4310	Economy	12700.00
0005435785514	4310	Economy	12700.00
0005435785541	4310	Economy	12700.00
0005435785512	4310	Economy	12700.00
0005434994073	4310	Economy	12700.00
0005434994067	4310	Economy	12700.00
0005435785518	4310	Economy	12700.00
0005435785507	4310	Economy	12700.00
0005435785522	4310	Economy	12700.00
0005434994069	4310	Economy	12700.00
0005434994072	4310	Economy	12700.00
0005435785517	4310	Economy	12700.00
0005435785538	4310	Economy	12700.00
0005435937361	4310	Economy	12700.00
0005435785532	4310	Economy	12700.00
0005435785523	4310	Economy	12700.00
0005435785526	4310	Economy	12700.00
0005435785509	4310	Economy	12700.00
0005435785539	4310	Economy	12700.00
0005435785525	4310	Economy	12700.00
0005435937355	4310	Economy	12700.00
0005435785533	4310	Economy	12700.00
0005434994075	4310	Economy	12700.00
0005435785537	4310	Economy	12700.00
0005432195703	27331	Business	38000.00
0005434993985	27331	Business	38000.00
0005435785238	27331	Business	38000.00
0005435785044	27331	Business	38000.00
0005435785012	27331	Business	38000.00
0005435785124	27331	Business	38000.00
0005435785215	27331	Business	38000.00
0005435785103	27331	Business	38000.00
0005435785213	27331	Economy	12700.00
0005434994002	27331	Economy	12700.00
0005435785157	27331	Economy	12700.00
0005435918680	27331	Economy	12700.00
0005432195702	27331	Economy	12700.00
0005435784892	27331	Economy	12700.00
0005434993984	27331	Economy	12700.00
0005435785195	27331	Economy	13900.00
0005435785083	27331	Economy	13900.00
0005434993969	27331	Economy	13900.00
0005435785214	27331	Economy	13900.00
0005434993952	27331	Economy	13900.00
0005432195701	27331	Economy	12700.00
0005435785094	27331	Economy	12700.00
0005435785104	27331	Economy	12700.00
0005435918679	27331	Economy	12700.00
0005435785222	27331	Economy	12700.00
0005435785024	27331	Economy	12700.00
0005435785278	27331	Economy	12700.00
0005435787334	27331	Economy	12700.00
0005435785217	27331	Economy	12700.00
0005435785087	27331	Economy	12700.00
0005434994015	27331	Economy	12700.00
0005435785253	27331	Economy	12700.00
0005435785061	27331	Economy	12700.00
0005435785076	27331	Economy	12700.00
0005434993990	27331	Economy	12700.00
0005435785120	27331	Economy	12700.00
0005435785142	27331	Economy	12700.00
0005434993991	27331	Economy	12700.00
0005435787342	27331	Economy	12700.00
0005435785212	27331	Economy	12700.00
0005435785125	27331	Economy	12700.00
0005434993983	27331	Economy	12700.00
0005435785134	27331	Economy	12700.00
0005435785158	27331	Economy	12700.00
0005435785025	27331	Economy	12700.00
0005435785148	27331	Economy	12700.00
0005434994000	27331	Economy	12700.00
0005434994003	27331	Economy	12700.00
0005434993988	27331	Economy	12700.00
0005434993953	27331	Economy	12700.00
0005434994011	27331	Economy	12700.00
0005435785304	27331	Economy	12700.00
0005435785043	27331	Economy	12700.00
0005435785088	27331	Economy	12700.00
0005435785239	27331	Economy	12700.00
0005435785302	27331	Economy	12700.00
0005435785066	27331	Economy	12700.00
0005435785156	27331	Economy	12700.00
0005435918678	27331	Economy	12700.00
0005435918681	27331	Economy	12700.00
0005434993954	27331	Economy	12700.00
0005435785117	27331	Economy	12700.00
0005435785312	27331	Economy	12700.00
0005435785093	27331	Economy	12700.00
0005435785313	27331	Economy	12700.00
0005435785303	27331	Economy	12700.00
0005435785116	27331	Economy	12700.00
0005435785221	27331	Economy	12700.00
0005434993970	27331	Economy	12700.00
0005434993989	27331	Economy	12700.00
0005435785279	27331	Economy	12700.00
0005432146207	19898	Economy	12800.00
0005432146208	19898	Economy	12800.00
0005432567919	4712	Business	40900.00
0005434082029	4712	Business	40900.00
0005432460111	4712	Business	40900.00
0005432571339	4712	Business	40900.00
0005432567931	4712	Business	40900.00
0005434082020	4712	Business	40900.00
0005432567923	4712	Business	40900.00
0005432567943	4712	Business	40900.00
0005434082019	4712	Business	40900.00
0005432567911	4712	Business	40900.00
0005432567905	4712	Business	40900.00
0005432460118	4712	Business	40900.00
0005432460123	4712	Business	40900.00
0005432460083	4712	Business	40900.00
0005432460108	4712	Business	40900.00
0005432170421	4712	Business	40900.00
0005432460109	4712	Business	40900.00
0005432460124	4712	Business	40900.00
0005432460131	4712	Business	40900.00
0005432460093	4712	Business	40900.00
0005432186891	4712	Business	40900.00
0005432567963	4712	Business	40900.00
0005432567951	4712	Business	40900.00
0005432460099	4712	Business	40900.00
0005434082022	4712	Economy	15000.00
0005432460125	4712	Economy	15000.00
0005432460100	4712	Economy	15000.00
0005434082030	4712	Economy	15000.00
0005432186890	4712	Economy	13600.00
0005432567946	4712	Economy	13600.00
0005432567940	4712	Economy	13600.00
0005434082018	4712	Economy	13600.00
0005432460119	4712	Economy	13600.00
0005432567932	4712	Economy	13600.00
0005434082013	4712	Economy	13600.00
0005432567937	4712	Economy	13600.00
0005432186888	4712	Economy	13600.00
0005434082016	4712	Economy	13600.00
0005432460115	4712	Economy	13600.00
0005432571341	4712	Economy	13600.00
0005432571338	4712	Economy	13600.00
0005433726116	4712	Economy	13600.00
0005432567955	4712	Economy	13600.00
0005432460106	4712	Economy	13600.00
0005432567958	4712	Economy	13600.00
0005432460102	4712	Economy	13600.00
0005433451629	4712	Economy	13600.00
0005432567906	4712	Economy	13600.00
0005432460079	4712	Economy	13600.00
0005432567957	4712	Economy	13600.00
0005433726115	4712	Economy	13600.00
0005432567941	4712	Economy	13600.00
0005432567918	4712	Economy	13600.00
0005432567947	4712	Economy	13600.00
0005434082026	4712	Economy	13600.00
0005434082028	4712	Economy	13600.00
0005434082011	4712	Economy	13600.00
0005432567928	4712	Economy	13600.00
0005432170419	4712	Economy	13600.00
0005432460110	4712	Economy	13600.00
0005432567945	4712	Economy	13600.00
0005434082032	4712	Economy	13600.00
0005432567913	4712	Economy	13600.00
0005432460081	4712	Economy	13600.00
0005432460092	4712	Economy	13600.00
0005434082009	4712	Economy	13600.00
0005432460130	4712	Economy	13600.00
0005432460107	4712	Economy	13600.00
0005432460084	4712	Economy	13600.00
0005433726114	4712	Economy	13600.00
0005432567915	4712	Economy	13600.00
0005432460126	4712	Economy	13600.00
0005432460098	4712	Economy	13600.00
0005432567917	4712	Economy	13600.00
0005432460121	4712	Economy	13600.00
0005432460088	4712	Economy	13600.00
0005432567953	4712	Economy	13600.00
0005432567926	4712	Economy	13600.00
0005432567956	4712	Economy	13600.00
0005432460117	4712	Economy	13600.00
0005432567930	4712	Economy	13600.00
0005432460096	4712	Economy	13600.00
0005432460090	4712	Economy	13600.00
0005432460116	4712	Economy	13600.00
0005432567934	4712	Economy	13600.00
0005433451630	4712	Economy	13600.00
0005432567949	4712	Economy	13600.00
0005432186889	4712	Economy	13600.00
0005432460129	4712	Economy	13600.00
0005434082010	4712	Economy	13600.00
0005434082031	4712	Economy	13600.00
0005432567929	4712	Economy	13600.00
0005432567909	4712	Economy	13600.00
0005432460127	4712	Economy	13600.00
0005432460085	4712	Economy	13600.00
0005434082027	4712	Economy	13600.00
0005432567962	4712	Economy	13600.00
0005432460128	4712	Economy	13600.00
0005432460101	4712	Economy	13600.00
0005432460097	4712	Economy	13600.00
0005432567916	4712	Economy	13600.00
0005432567927	4712	Economy	13600.00
0005432567903	4712	Economy	13600.00
0005434082023	4712	Economy	13600.00
0005432460089	4712	Economy	13600.00
0005432567904	4712	Economy	15000.00
0005434082008	4712	Economy	13600.00
0005432567959	4712	Economy	15000.00
0005432460113	4712	Economy	13600.00
0005432567914	4712	Economy	13600.00
0005434082033	4712	Economy	15000.00
0005432460080	4712	Economy	15000.00
0005432567938	4712	Economy	13600.00
0005434082014	4712	Economy	13600.00
0005434082021	4712	Economy	13600.00
0005432567961	4712	Economy	13600.00
0005432460078	4712	Economy	13600.00
0005432186887	4712	Economy	13600.00
0005432460086	4712	Economy	13600.00
0005433451628	4712	Economy	13600.00
0005432567924	4712	Economy	13600.00
0005432460095	4712	Economy	13600.00
0005432567908	4712	Economy	13600.00
0005432567960	4712	Economy	13600.00
0005432567925	4712	Economy	13600.00
0005432567954	4712	Economy	13600.00
0005432186886	4712	Economy	13600.00
0005432460091	4712	Economy	13600.00
0005433452750	4712	Economy	13600.00
0005432460112	4712	Economy	13600.00
0005432567948	4712	Economy	13600.00
0005432567910	4712	Economy	13600.00
0005432170417	4712	Economy	13600.00
0005434082015	4712	Economy	13600.00
0005432567921	4712	Economy	13600.00
0005432170422	4712	Economy	13600.00
0005432567942	4712	Economy	13600.00
0005432460122	4712	Economy	13600.00
0005432460087	4712	Economy	13600.00
0005432567935	4712	Economy	13600.00
0005432567950	4712	Economy	13600.00
0005434082012	4712	Economy	13600.00
0005432170420	4712	Economy	13600.00
0005434082025	4712	Economy	13600.00
0005432567933	4712	Economy	13600.00
0005432460120	4712	Economy	13600.00
0005432571340	4712	Economy	13600.00
0005432567907	4712	Economy	13600.00
0005432460103	4712	Economy	13600.00
0005432460104	4712	Economy	13600.00
0005432567944	4712	Economy	13600.00
0005432460114	4712	Economy	13600.00
0005432567920	4712	Economy	13600.00
0005432567902	4712	Economy	13600.00
0005434082017	4712	Economy	13600.00
0005432567939	4712	Economy	13600.00
0005432567952	4712	Economy	13600.00
0005432460082	4712	Economy	13600.00
0005434082024	4712	Economy	13600.00
0005433452749	4712	Economy	13600.00
0005432567936	4712	Economy	13600.00
0005432170423	4712	Economy	13600.00
0005432567922	4712	Economy	13600.00
0005432460105	4712	Economy	13600.00
0005432567912	4712	Economy	13600.00
0005432170418	4712	Economy	13600.00
0005432460094	4712	Economy	13600.00
0005432567394	30517	Business	40900.00
0005432459751	30517	Business	40900.00
0005432567268	30517	Business	40900.00
0005434081775	30517	Business	40900.00
0005432567576	30517	Business	40900.00
0005434081809	30517	Business	40900.00
0005432567731	30517	Business	40900.00
0005432213624	30517	Business	40900.00
0005432459675	30517	Business	40900.00
0005434081824	30517	Business	40900.00
0005432567543	30517	Business	40900.00
0005432459647	30517	Business	40900.00
0005432459626	30517	Business	40900.00
0005432161164	30517	Business	40900.00
0005434081757	30517	Business	40900.00
0005432459786	30517	Business	40900.00
0005432567529	30517	Business	40900.00
0005434081847	30517	Economy	15000.00
0005432459714	30517	Economy	15000.00
0005432567269	30517	Economy	15000.00
0005432459785	30517	Economy	13600.00
0005432459855	30517	Economy	13600.00
0005432567604	30517	Economy	13600.00
0005432459482	30517	Economy	13600.00
0005432567605	30517	Economy	13600.00
0005432567414	30517	Economy	13600.00
0005432459673	30517	Economy	13600.00
0005432567418	30517	Economy	13600.00
0005432567477	30517	Economy	13600.00
0005434081825	30517	Economy	13600.00
0005432459651	30517	Economy	13600.00
0005432567586	30517	Economy	13600.00
0005432567645	30517	Economy	13600.00
0005432567742	30517	Economy	13600.00
0005432567431	30517	Economy	13600.00
0005432567573	30517	Economy	13600.00
0005432459770	30517	Economy	13600.00
0005432567610	30517	Economy	13600.00
0005432567333	30517	Economy	13600.00
0005432571317	30517	Economy	13600.00
0005432459736	30517	Economy	13600.00
0005432459715	30517	Economy	13600.00
0005432567309	30517	Economy	13600.00
0005432567481	30517	Economy	13600.00
0005434081846	30517	Economy	13600.00
0005434081743	30517	Economy	13600.00
0005432567555	30517	Economy	13600.00
0005434081728	30517	Economy	13600.00
0005432567723	30517	Economy	13600.00
0005432567271	30517	Economy	13600.00
0005432567272	30517	Economy	13600.00
0005432459625	30517	Economy	13600.00
0005432459776	30517	Economy	13600.00
0005432567575	30517	Economy	13600.00
0005432571321	30517	Economy	13600.00
0005434081811	30517	Economy	13600.00
0005432459566	30517	Economy	13600.00
0005432459827	30517	Economy	13600.00
0005434081803	30517	Economy	13600.00
0005432567743	30517	Economy	13600.00
0005432567565	30517	Economy	13600.00
0005432571319	30517	Economy	13600.00
0005432567391	30517	Economy	13600.00
0005432567432	30517	Economy	13600.00
0005434081802	30517	Economy	13600.00
0005432459854	30517	Economy	13600.00
0005432567417	30517	Economy	13600.00
0005434081776	30517	Economy	13600.00
0005432567509	30517	Economy	13600.00
0005432567574	30517	Economy	13600.00
0005432213625	30517	Economy	13600.00
0005432459541	30517	Economy	13600.00
0005432567395	30517	Economy	13600.00
0005432459737	30517	Economy	13600.00
0005432459555	30517	Economy	13600.00
0005432567303	30517	Economy	13600.00
0005432459483	30517	Economy	13600.00
0005432567524	30517	Economy	13600.00
0005432567311	30517	Economy	13600.00
0005432567337	30517	Economy	13600.00
0005432567499	30517	Economy	13600.00
0005432567470	30517	Economy	13600.00
0005432459720	30517	Economy	13600.00
0005432571297	30517	Economy	15000.00
0005432571318	30517	Economy	13600.00
0005432459648	30517	Economy	15000.00
0005434081774	30517	Economy	15000.00
0005432460055	30517	Economy	13600.00
0005432459835	30517	Economy	13600.00
0005434081807	30517	Economy	13600.00
0005434081770	30517	Economy	13600.00
0005432459745	30517	Economy	13600.00
0005432567504	30517	Economy	13600.00
0005434081734	30517	Economy	13600.00
0005432567482	30517	Economy	13600.00
0005432459567	30517	Economy	13600.00
0005432459674	30517	Economy	13600.00
0005432459739	30517	Economy	13600.00
0005432567488	30517	Economy	13600.00
0005432567392	30517	Economy	13600.00
0005432459738	30517	Economy	13600.00
0005432459772	30517	Economy	13600.00
0005432567323	30517	Economy	13600.00
0005432567566	30517	Economy	13600.00
0005432459503	30517	Economy	13600.00
0005434081827	30517	Economy	13600.00
0005434081818	30517	Economy	13600.00
0005432567501	30517	Economy	13600.00
0005432567510	30517	Economy	13600.00
0005432567578	30517	Economy	13600.00
0005432459769	30517	Economy	13600.00
0005432567217	30517	Economy	13600.00
0005432567609	30517	Economy	13600.00
0005432459795	30517	Economy	13600.00
0005432459775	30517	Economy	13600.00
0005432459729	30517	Economy	13600.00
0005434081812	30517	Economy	13600.00
0005432567585	30517	Economy	13600.00
0005432571320	30517	Economy	13600.00
0005434081808	30517	Economy	13600.00
0005432213626	30517	Economy	13600.00
0005432567490	30517	Economy	13600.00
0005433454875	30517	Economy	13600.00
0005433454874	30517	Economy	13600.00
0005432567500	30517	Economy	13600.00
0005432567699	30517	Economy	13600.00
0005432567308	30517	Economy	13600.00
0005432567567	30517	Economy	13600.00
0005432161163	30517	Economy	13600.00
0005435722067	13616	Economy	9900.00
0005435720826	13616	Economy	9900.00
0005435722050	21131	Economy	9900.00
0005435722049	21131	Economy	9900.00
0005435722046	21131	Economy	9900.00
0005435722048	21131	Economy	9900.00
0005432295892	22814	Economy	8800.00
0005432295893	22814	Economy	8800.00
0005433343624	11073	Business	23600.00
0005433343626	11073	Business	23600.00
0005433343691	11073	Business	23600.00
0005433343628	11073	Business	23600.00
0005435097246	11073	Business	23600.00
0005433343650	11073	Business	23600.00
0005433343700	11073	Business	23600.00
0005433343637	11073	Business	23600.00
0005433343652	11073	Business	23600.00
0005433343630	11073	Business	23600.00
0005433343712	11073	Business	23600.00
0005433343695	11073	Economy	7900.00
0005433343669	11073	Economy	7900.00
0005433343707	11073	Economy	7900.00
0005433343642	11073	Economy	7900.00
0005435508316	11073	Economy	7900.00
0005433343689	11073	Economy	7900.00
0005433343617	11073	Economy	7900.00
0005433343682	11073	Economy	7900.00
0005433343658	11073	Economy	7900.00
0005433343618	11073	Economy	7900.00
0005433343640	11073	Economy	7900.00
0005433343713	11073	Economy	7900.00
0005433343715	11073	Economy	7900.00
0005435508324	11073	Economy	7900.00
0005433343622	11073	Economy	7900.00
0005433343690	11073	Economy	7900.00
0005433343638	11073	Economy	7900.00
0005433343688	11073	Economy	7900.00
0005433343673	11073	Economy	7900.00
0005433343716	11073	Economy	7900.00
0005433343701	11073	Economy	7900.00
0005435508347	11073	Economy	7900.00
0005435380264	11073	Economy	7900.00
0005433343625	11073	Economy	7900.00
0005433343681	11073	Economy	7900.00
0005433343703	11073	Economy	7900.00
0005435097241	11073	Economy	7900.00
0005433343680	11073	Economy	7900.00
0005433343668	11073	Economy	7900.00
0005435508348	11073	Economy	7900.00
0005433343623	11073	Economy	7900.00
0005433343675	11073	Economy	7900.00
0005435508317	11073	Economy	7900.00
0005435097244	11073	Economy	7900.00
0005433343678	11073	Economy	7900.00
0005433343662	11073	Economy	7900.00
0005433343671	11073	Economy	7900.00
0005433343631	11073	Economy	7900.00
0005433343645	11073	Economy	7900.00
0005433343709	11073	Economy	8600.00
0005433343704	11073	Economy	7900.00
0005433343664	11073	Economy	8600.00
0005433343717	11073	Economy	8600.00
0005433343670	11073	Economy	8600.00
0005433343651	11073	Economy	8600.00
0005433343653	11073	Economy	7900.00
0005433343683	11073	Economy	7900.00
0005435097237	11073	Economy	7900.00
0005433343698	11073	Economy	7900.00
0005433343687	11073	Economy	7900.00
0005435380276	11073	Economy	7900.00
0005433343656	11073	Economy	7900.00
0005433343710	11073	Economy	7900.00
0005435508340	11073	Economy	7900.00
0005433343644	11073	Economy	7900.00
0005433343632	11073	Economy	7900.00
0005433343641	11073	Economy	7900.00
0005435508339	11073	Economy	7900.00
0005435097242	11073	Economy	7900.00
0005433343646	11073	Economy	7900.00
0005433343665	11073	Economy	7900.00
0005433343696	11073	Economy	7900.00
0005433343699	11073	Economy	7900.00
0005433343679	11073	Economy	7900.00
0005435380265	11073	Economy	7900.00
0005433343676	11073	Economy	7900.00
0005433343620	11073	Economy	7900.00
0005433343659	11073	Economy	7900.00
0005433343667	11073	Economy	7900.00
0005433343643	11073	Economy	7900.00
0005433343660	11073	Economy	7900.00
0005433343634	11073	Economy	7900.00
0005433343706	11073	Economy	7900.00
0005433343684	11073	Economy	7900.00
0005433343686	11073	Economy	7900.00
0005435097243	11073	Economy	7900.00
0005435508337	11073	Economy	7900.00
0005433343619	11073	Economy	7900.00
0005433343627	11073	Economy	7900.00
0005433343639	11073	Economy	7900.00
0005433343693	11073	Economy	7900.00
0005433343705	11073	Economy	7900.00
0005433343663	11073	Economy	7900.00
0005435380275	11073	Economy	7900.00
0005433343647	11073	Economy	7900.00
0005433343692	11073	Economy	7900.00
0005433343685	11073	Economy	7900.00
0005433343702	11073	Economy	7900.00
0005433343694	11073	Economy	7900.00
0005433343655	11073	Economy	7900.00
0005433343666	11073	Economy	7900.00
0005435508345	11073	Economy	7900.00
0005433343697	11073	Economy	7900.00
0005435097240	11073	Economy	7900.00
0005433343648	11073	Economy	7900.00
0005435508344	11073	Economy	7900.00
0005433343677	11073	Economy	7900.00
0005433343714	11073	Economy	7900.00
0005433343621	11073	Economy	7900.00
0005433343672	11073	Economy	7900.00
0005433343711	11073	Economy	7900.00
0005435097239	11073	Economy	7900.00
0005435097245	11073	Economy	7900.00
0005435508315	11073	Economy	7900.00
0005433343661	11073	Economy	7900.00
0005433343629	11073	Economy	7900.00
0005435508350	11073	Economy	7900.00
0005433343708	11073	Economy	7900.00
0005433343633	11073	Economy	7900.00
0005433343649	11073	Economy	7900.00
0005435097236	11073	Economy	7900.00
0005433343636	11073	Economy	7900.00
0005433343635	11073	Economy	7900.00
0005433343657	11073	Economy	7900.00
0005435097238	11073	Economy	7900.00
0005433343674	11073	Economy	7900.00
0005433343654	11073	Economy	7900.00
0005433342357	17099	Business	23600.00
0005433342610	17099	Business	23600.00
0005433342806	17099	Business	23600.00
0005433342996	17099	Business	23600.00
0005433342407	17099	Business	23600.00
0005433342749	17099	Business	23600.00
0005433342328	17099	Business	23600.00
0005433342932	17099	Business	23600.00
0005433342981	17099	Business	23600.00
0005433343185	17099	Business	23600.00
0005435545778	17099	Business	23600.00
0005433342662	17099	Business	23600.00
0005433342874	17099	Economy	7900.00
0005435545782	17099	Economy	7900.00
0005435380320	17099	Economy	7900.00
0005433342329	17099	Economy	7900.00
0005433342314	17099	Economy	7900.00
0005433343091	17099	Economy	7900.00
0005433343186	17099	Economy	7900.00
0005433342732	17099	Economy	7900.00
0005433342434	17099	Economy	7900.00
0005433342724	17099	Economy	7900.00
0005433342208	17099	Economy	7900.00
0005433342798	17099	Economy	7900.00
0005433342540	17099	Economy	7900.00
0005433342873	17099	Economy	7900.00
0005433342809	17099	Economy	7900.00
0005433342612	17099	Economy	7900.00
0005435380317	17099	Economy	7900.00
0005433342988	17099	Economy	7900.00
0005433342453	17099	Economy	7900.00
0005433342945	17099	Economy	7900.00
0005433342295	17099	Economy	7900.00
0005433343001	17099	Economy	7900.00
0005433342597	17099	Economy	7900.00
0005432293221	17099	Economy	7900.00
0005433342463	17099	Economy	7900.00
0005433342997	17099	Economy	7900.00
0005433342774	17099	Economy	7900.00
0005433342584	17099	Economy	7900.00
0005433342531	17099	Economy	7900.00
0005433342685	17099	Economy	7900.00
0005435097194	17099	Economy	7900.00
0005433342568	17099	Economy	7900.00
0005433342728	17099	Economy	7900.00
0005433342801	17099	Economy	7900.00
0005433342797	17099	Economy	7900.00
0005433343095	17099	Economy	7900.00
0005433342050	17099	Economy	7900.00
0005433342748	17099	Economy	8600.00
0005433342853	17099	Economy	8600.00
0005433342823	17099	Economy	8600.00
0005433342645	17099	Economy	8600.00
0005433342733	17099	Economy	8600.00
0005433342734	17099	Economy	7900.00
0005433342647	17099	Economy	8600.00
0005433342808	17099	Economy	7900.00
0005433342742	17099	Economy	7900.00
0005435097170	17099	Economy	7900.00
0005433342458	17099	Economy	7900.00
0005433342377	17099	Economy	7900.00
0005433342810	17099	Economy	7900.00
0005435097184	17099	Economy	7900.00
0005433342452	17099	Economy	7900.00
0005435545784	17099	Economy	7900.00
0005435545776	17099	Economy	7900.00
0005435380321	17099	Economy	7900.00
0005433342588	17099	Economy	7900.00
0005435545779	17099	Economy	7900.00
0005435545774	17099	Economy	7900.00
0005435545771	17099	Economy	7900.00
0005433342411	17099	Economy	7900.00
0005433342741	17099	Economy	7900.00
0005433342800	17099	Economy	7900.00
0005435097153	17099	Economy	7900.00
0005433342723	17099	Economy	7900.00
0005433342684	17099	Economy	7900.00
0005433342805	17099	Economy	7900.00
0005433342769	17099	Economy	7900.00
0005433342547	17099	Economy	7900.00
0005435380319	17099	Economy	7900.00
0005433342513	17099	Economy	7900.00
0005435097183	17099	Economy	7900.00
0005433342435	17099	Economy	7900.00
0005435097160	17099	Economy	7900.00
0005435097133	17099	Economy	7900.00
0005433342802	17099	Economy	7900.00
0005433342567	17099	Economy	7900.00
0005433342803	17099	Economy	7900.00
0005433342343	17099	Economy	7900.00
0005433342686	17099	Economy	7900.00
0005433342811	17099	Economy	7900.00
0005433342207	17099	Economy	7900.00
0005433342851	17099	Economy	7900.00
0005435380316	17099	Economy	7900.00
0005433342968	17099	Economy	7900.00
0005433342987	17099	Economy	7900.00
0005433342611	17099	Economy	7900.00
0005433342998	17099	Economy	7900.00
0005435545775	17099	Economy	7900.00
0005432293220	17099	Economy	7900.00
0005433342566	17099	Economy	7900.00
0005433342589	17099	Economy	7900.00
0005433342992	17099	Economy	7900.00
0005435545772	17099	Economy	7900.00
0005435545781	17099	Economy	7900.00
0005435545773	17099	Economy	7900.00
0005433342804	17099	Economy	7900.00
0005435545780	17099	Economy	7900.00
0005433342898	17099	Economy	7900.00
0005433342852	17099	Economy	7900.00
0005435545777	17099	Economy	7900.00
0005433342745	17099	Economy	7900.00
0005435380318	17099	Economy	7900.00
0005433342729	17099	Economy	7900.00
0005433342365	17099	Economy	7900.00
0005433343048	17099	Economy	7900.00
0005433342991	17099	Economy	7900.00
0005433342051	17099	Economy	7900.00
0005433342944	17099	Economy	7900.00
0005435545783	17099	Economy	7900.00
0005435097185	17099	Economy	7900.00
0005435380322	17099	Economy	7900.00
0005433342406	17099	Economy	7900.00
0005435545770	17099	Economy	7900.00
0005432919748	9071	Business	26600.00
0005432919735	9071	Business	26600.00
0005433507270	9071	Business	26600.00
0005433507279	9071	Business	26600.00
0005432919806	9071	Business	26600.00
0005432919851	9071	Business	26600.00
0005433507280	9071	Business	26600.00
0005433507275	9071	Business	26600.00
0005433507271	9071	Business	26600.00
0005433481204	9071	Economy	8900.00
0005432919807	9071	Economy	8900.00
0005433507273	9071	Economy	8900.00
0005432919749	9071	Economy	8900.00
0005432919805	9071	Economy	8900.00
0005432919811	9071	Economy	8900.00
0005432919842	9071	Economy	9800.00
0005432919878	9071	Economy	8900.00
0005432919828	9071	Economy	8900.00
0005434158967	9071	Economy	8900.00
0005432919859	9071	Economy	8900.00
0005432919852	9071	Economy	8900.00
0005432919759	9071	Economy	8900.00
0005432919829	9071	Economy	8900.00
0005433507278	9071	Economy	8900.00
0005433507282	9071	Economy	8900.00
0005433481210	9071	Economy	8900.00
0005433507286	9071	Economy	8900.00
0005433481207	9071	Economy	8900.00
0005433507283	9071	Economy	8900.00
0005432919667	9071	Economy	8900.00
0005432919788	9071	Economy	8900.00
0005432919873	9071	Economy	8900.00
0005432919860	9071	Economy	8900.00
0005432919823	9071	Economy	8900.00
0005433507277	9071	Economy	8900.00
0005433507272	9071	Economy	8900.00
0005433507281	9071	Economy	8900.00
0005433481206	9071	Economy	8900.00
0005433507285	9071	Economy	8900.00
0005432919704	9071	Economy	8900.00
0005433507284	9071	Economy	8900.00
0005433481208	9071	Economy	8900.00
0005432919810	9071	Economy	8900.00
0005433481209	9071	Economy	8900.00
0005433507274	9071	Economy	8900.00
0005433481203	9071	Economy	8900.00
0005433507269	9071	Economy	8900.00
0005433481205	9071	Economy	8900.00
0005433507276	9071	Economy	8900.00
0005432919803	9071	Economy	8900.00
0005432919983	20492	Business	26600.00
0005432919976	20492	Business	26600.00
0005432919987	20492	Business	26600.00
0005433481140	20492	Business	26600.00
0005433507044	20492	Business	26600.00
0005432919994	20492	Business	26600.00
0005433481142	20492	Economy	8900.00
0005434158988	20492	Economy	8900.00
0005432919992	20492	Economy	8900.00
0005433507151	20492	Economy	8900.00
0005433481127	20492	Economy	8900.00
0005433507081	20492	Economy	8900.00
0005433507129	20492	Economy	8900.00
0005433481148	20492	Economy	8900.00
0005433507121	20492	Economy	9800.00
0005434158985	20492	Economy	9800.00
0005434158989	20492	Economy	9800.00
0005433481137	20492	Economy	9800.00
0005432919995	20492	Economy	8900.00
0005432919980	20492	Economy	8900.00
0005433507138	20492	Economy	8900.00
0005433481151	20492	Economy	8900.00
0005432919985	20492	Economy	8900.00
0005432919975	20492	Economy	8900.00
0005432919978	20492	Economy	8900.00
0005433481150	20492	Economy	8900.00
0005434158984	20492	Economy	8900.00
0005433507114	20492	Economy	8900.00
0005433507115	20492	Economy	8900.00
0005432919977	20492	Economy	8900.00
0005433507099	20492	Economy	8900.00
0005432919991	20492	Economy	8900.00
0005433481149	20492	Economy	8900.00
0005434158987	20492	Economy	8900.00
0005432919984	20492	Economy	8900.00
0005433507152	20492	Economy	8900.00
0005433507101	20492	Economy	8900.00
0005433507137	20492	Economy	8900.00
0005433507168	20492	Economy	8900.00
0005433507227	20492	Economy	8900.00
0005433507093	20492	Economy	8900.00
0005433507112	20492	Economy	8900.00
0005433507228	20492	Economy	8900.00
0005432919986	20492	Economy	8900.00
0005433507070	20492	Economy	8900.00
0005432919989	20492	Economy	8900.00
0005432919990	20492	Economy	8900.00
0005433507131	20492	Economy	8900.00
0005433481125	20492	Economy	8900.00
0005434158986	20492	Economy	8900.00
0005432919982	20492	Economy	8900.00
0005432919974	20492	Economy	8900.00
0005433481141	20492	Economy	8900.00
0005433481134	20492	Economy	8900.00
0005432919988	20492	Economy	8900.00
0005432919981	20492	Economy	8900.00
0005433481154	20492	Economy	8900.00
0005432919993	20492	Economy	8900.00
0005432919979	20492	Economy	8900.00
0005432396261	10163	Economy	5800.00
0005432396260	10163	Economy	5800.00
0005432394123	10163	Economy	5800.00
0005432396259	10163	Economy	5800.00
0005432396258	10163	Economy	5800.00
0005432394122	10163	Economy	5800.00
0005432394121	10163	Economy	5800.00
0005432396229	18388	Economy	5800.00
0005432400098	18388	Economy	5800.00
0005432396234	18388	Economy	5800.00
0005432400105	18388	Economy	5800.00
0005435179398	18388	Economy	5800.00
0005432400106	18388	Economy	5800.00
0005432396226	18388	Economy	5800.00
0005435179697	18388	Economy	5800.00
0005432400099	18388	Economy	5800.00
0005432396227	18388	Economy	5800.00
0005435126169	10946	Business	9500.00
0005435626105	10946	Business	9500.00
0005435626115	10946	Business	9500.00
0005435126222	10946	Business	9500.00
0005435554169	10946	Business	9500.00
0005435626072	10946	Business	9500.00
0005435126190	10946	Business	9500.00
0005435126003	10946	Economy	3200.00
0005435126072	10946	Economy	3200.00
0005435126234	10946	Economy	3200.00
0005435554150	10946	Economy	3500.00
0005435626111	10946	Economy	3500.00
0005435554171	10946	Economy	3500.00
0005435626129	10946	Economy	3500.00
0005435126109	10946	Economy	3200.00
0005435126085	10946	Economy	3200.00
0005435126167	10946	Economy	3200.00
0005435126073	10946	Economy	3200.00
0005435626085	10946	Economy	3200.00
0005435126083	10946	Economy	3200.00
0005435126184	10946	Economy	3200.00
0005435554165	10946	Economy	3200.00
0005435126350	10946	Economy	3200.00
0005435626130	10946	Economy	3200.00
0005434411803	10946	Economy	3200.00
0005434411800	10946	Economy	3200.00
0005435556695	10946	Economy	3200.00
0005435126301	10946	Economy	3200.00
0005434411802	10946	Economy	3200.00
0005435554149	10946	Economy	3200.00
0005435125941	10946	Economy	3200.00
0005435626116	10946	Economy	3200.00
0005435626046	10946	Economy	3200.00
0005435626073	10946	Economy	3200.00
0005435126194	10946	Economy	3200.00
0005435126269	10946	Economy	3200.00
0005434411801	10946	Economy	3200.00
0005435126175	10946	Economy	3200.00
0005435626089	10946	Economy	3200.00
0005435626136	10946	Economy	3200.00
0005435126319	10946	Economy	3200.00
0005435126176	10946	Economy	3200.00
0005435554172	10946	Economy	3200.00
0005435126191	10946	Economy	3200.00
0005435554170	10946	Economy	3200.00
0005435126185	10946	Economy	3200.00
0005435626093	10946	Economy	3200.00
0005435126177	10946	Economy	3200.00
0005434411798	10946	Economy	3200.00
0005435554152	10946	Economy	3200.00
0005435126002	10946	Economy	3200.00
0005434928315	10946	Economy	3200.00
0005435126110	10946	Economy	3200.00
0005435554168	10946	Economy	3200.00
0005434928313	10946	Economy	3200.00
0005435126233	10946	Economy	3200.00
0005435554151	10946	Economy	3200.00
0005435126183	10946	Economy	3200.00
0005435554177	10946	Economy	3200.00
0005434411799	10946	Economy	3200.00
0005435626047	10946	Economy	3200.00
0005435126166	10946	Economy	3200.00
0005435626051	10946	Economy	3200.00
0005435554166	10946	Economy	3200.00
0005435126174	10946	Economy	3200.00
0005435556696	10946	Economy	3200.00
0005435626029	10946	Economy	3200.00
0005435126192	10946	Economy	3200.00
0005435626117	10946	Economy	3200.00
0005434928314	10946	Economy	3200.00
0005435554208	14735	Business	9500.00
0005435126585	14735	Business	9500.00
0005435126591	14735	Business	9500.00
0005434928292	14735	Business	9500.00
0005435126571	14735	Business	9500.00
0005435626275	14735	Business	9500.00
0005435126587	14735	Business	9500.00
0005435126586	14735	Business	9500.00
0005434411758	14735	Business	9500.00
0005435626282	14735	Business	9500.00
0005435556705	14735	Business	9500.00
0005435126602	14735	Economy	3200.00
0005434411753	14735	Economy	3200.00
0005435126568	14735	Economy	3200.00
0005435626280	14735	Economy	3200.00
0005435126596	14735	Economy	3200.00
0005435626277	14735	Economy	3200.00
0005434411751	14735	Economy	3200.00
0005435626267	14735	Economy	3500.00
0005435126604	14735	Economy	3500.00
0005435126576	14735	Economy	3500.00
0005434928297	14735	Economy	3500.00
0005435126601	14735	Economy	3200.00
0005435126577	14735	Economy	3200.00
0005435554209	14735	Economy	3200.00
0005435626284	14735	Economy	3200.00
0005435626271	14735	Economy	3200.00
0005435626276	14735	Economy	3200.00
0005435126583	14735	Economy	3200.00
0005434928299	14735	Economy	3200.00
0005435626269	14735	Economy	3200.00
0005435126579	14735	Economy	3200.00
0005435126572	14735	Economy	3200.00
0005435554207	14735	Economy	3200.00
0005435554211	14735	Economy	3200.00
0005435126570	14735	Economy	3200.00
0005435126584	14735	Economy	3200.00
0005435626278	14735	Economy	3200.00
0005435126603	14735	Economy	3200.00
0005435626274	14735	Economy	3200.00
0005435126599	14735	Economy	3200.00
0005435126594	14735	Economy	3200.00
0005435126592	14735	Economy	3200.00
0005434411759	14735	Economy	3200.00
0005435626272	14735	Economy	3200.00
0005435556706	14735	Economy	3200.00
0005435126566	14735	Economy	3200.00
0005434411741	14735	Economy	3200.00
0005435626270	14735	Economy	3200.00
0005435126567	14735	Economy	3200.00
0005435126578	14735	Economy	3200.00
0005435626266	14735	Economy	3200.00
0005435126574	14735	Economy	3200.00
0005435126565	14735	Economy	3200.00
0005435626286	14735	Economy	3200.00
0005435126569	14735	Economy	3200.00
0005435126589	14735	Economy	3200.00
0005435626283	14735	Economy	3200.00
0005435126593	14735	Economy	3200.00
0005435126564	14735	Economy	3200.00
0005435126590	14735	Economy	3200.00
0005435126573	14735	Economy	3200.00
0005435126581	14735	Economy	3200.00
0005435126575	14735	Economy	3200.00
0005435626281	14735	Economy	3200.00
0005435126582	14735	Economy	3200.00
0005435626273	14735	Economy	3200.00
0005434928298	14735	Economy	3200.00
0005435126563	14735	Economy	3200.00
0005435554210	14735	Economy	3200.00
0005435126595	14735	Economy	3200.00
0005435626285	14735	Economy	3200.00
0005435626279	14735	Economy	3200.00
0005435126598	14735	Economy	3200.00
0005435126597	14735	Economy	3200.00
0005435626268	14735	Economy	3200.00
0005435126588	14735	Economy	3200.00
0005434411752	14735	Economy	3200.00
0005435126580	14735	Economy	3200.00
0005435126600	14735	Economy	3200.00
0005435443221	7143	Business	86900.00
0005435715554	7143	Business	86900.00
0005435221050	7143	Business	86900.00
0005435221051	7143	Business	86900.00
0005432400145	7143	Business	86900.00
0005435715548	7143	Economy	29000.00
0005435715550	7143	Economy	29000.00
0005435715551	7143	Economy	29000.00
0005432400146	7143	Economy	29000.00
0005435443317	7143	Economy	29000.00
0005435715557	7143	Economy	29000.00
0005435715553	7143	Economy	31900.00
0005435443305	7143	Economy	31900.00
0005435715559	7143	Economy	29000.00
0005435178491	7143	Economy	29000.00
0005435443310	7143	Economy	29000.00
0005432398216	7143	Economy	29000.00
0005435715547	7143	Economy	29000.00
0005435715560	7143	Economy	29000.00
0005435443304	7143	Economy	29000.00
0005435715552	7143	Economy	29000.00
0005435443275	7143	Economy	29000.00
0005435715563	7143	Economy	29000.00
0005435443296	7143	Economy	29000.00
0005435715556	7143	Economy	29000.00
0005435715562	7143	Economy	29000.00
0005435443253	7143	Economy	29000.00
0005435715561	7143	Economy	29000.00
0005435715558	7143	Economy	29000.00
0005435715555	7143	Economy	29000.00
0005435443302	7143	Economy	29000.00
0005435443308	7143	Economy	29000.00
0005432398217	7143	Economy	29000.00
0005435178492	7143	Economy	29000.00
0005432400144	7143	Economy	29000.00
0005435715549	7143	Economy	29000.00
0005435443318	7143	Economy	29000.00
0005435443301	7143	Economy	29000.00
0005432398218	7143	Economy	29000.00
0005435219196	7143	Economy	29000.00
0005432400143	7143	Economy	29000.00
0005435216593	27104	Business	86900.00
0005432394073	27104	Business	86900.00
0005435715373	27104	Business	86900.00
0005435216598	27104	Business	86900.00
0005435715395	27104	Business	86900.00
0005435216592	27104	Business	86900.00
0005435715318	27104	Economy	29000.00
0005432394087	27104	Economy	29000.00
0005435216594	27104	Economy	29000.00
0005432394086	27104	Economy	29000.00
0005435443361	27104	Economy	29000.00
0005435217718	27104	Economy	29000.00
0005435218116	27104	Economy	31900.00
0005435218119	27104	Economy	31900.00
0005432394074	27104	Economy	29000.00
0005435443363	27104	Economy	29000.00
0005435218120	27104	Economy	29000.00
0005435443359	27104	Economy	29000.00
0005432394085	27104	Economy	29000.00
0005435216599	27104	Economy	29000.00
0005432398182	27104	Economy	29000.00
0005435217720	27104	Economy	29000.00
0005435218118	27104	Economy	29000.00
0005435715389	27104	Economy	29000.00
0005435217719	27104	Economy	29000.00
0005435715317	27104	Economy	29000.00
0005435443364	27104	Economy	29000.00
0005435443362	27104	Economy	29000.00
0005435216597	27104	Economy	29000.00
0005435715379	27104	Economy	29000.00
0005435218117	27104	Economy	29000.00
0005435217721	27104	Economy	29000.00
0005435217723	27104	Economy	29000.00
0005432398183	27104	Economy	29000.00
0005432394084	27104	Economy	29000.00
0005432394094	27104	Economy	29000.00
0005432394096	27104	Economy	29000.00
0005435715396	27104	Economy	29000.00
0005435443365	27104	Economy	29000.00
0005432394095	27104	Economy	29000.00
0005435715413	27104	Economy	29000.00
0005435443360	27104	Economy	29000.00
0005435217717	27104	Economy	29000.00
0005435443358	27104	Economy	29000.00
0005435217716	27104	Economy	29000.00
0005435216596	27104	Economy	29000.00
0005435715372	27104	Economy	29000.00
0005435216595	27104	Economy	29000.00
0005435217722	27104	Economy	29000.00
0005432398179	27104	Economy	29000.00
0005433060419	2708	Economy	7700.00
0005434084953	2708	Economy	7700.00
0005434084954	2708	Economy	7700.00
0005433060402	2708	Economy	7700.00
0005433060395	2708	Economy	7700.00
0005433060418	2708	Economy	7700.00
0005434084957	2708	Economy	7700.00
0005434084956	2708	Economy	7700.00
0005433060398	2708	Economy	7700.00
0005434084955	2708	Economy	7700.00
0005434084917	28509	Economy	7700.00
0005433060427	28509	Economy	7700.00
0005434084919	28509	Economy	7700.00
0005433060426	28509	Economy	7700.00
0005435548455	11176	Economy	27100.00
0005435548466	11176	Economy	27100.00
0005433788233	11176	Economy	27100.00
0005435548469	11176	Economy	24600.00
0005433788220	11176	Economy	24600.00
0005433788225	11176	Economy	24600.00
0005435548474	11176	Economy	24600.00
0005435548462	11176	Economy	24600.00
0005435548465	11176	Economy	24600.00
0005433788231	11176	Economy	24600.00
0005433788227	11176	Economy	24600.00
0005435548461	11176	Economy	24600.00
0005435548456	11176	Economy	24600.00
0005435548470	11176	Economy	24600.00
0005433788223	11176	Economy	24600.00
0005433788230	11176	Economy	24600.00
0005433788222	11176	Economy	24600.00
0005435548468	11176	Economy	24600.00
0005433788232	11176	Economy	24600.00
0005433788234	11176	Economy	24600.00
0005435548451	11176	Economy	24600.00
0005433788229	11176	Economy	24600.00
0005433788228	11176	Economy	24600.00
0005435548450	11176	Economy	24600.00
0005435548457	11176	Economy	24600.00
0005435548458	11176	Economy	24600.00
0005433788219	11176	Economy	24600.00
0005433788226	11176	Economy	24600.00
0005433788221	11176	Economy	24600.00
0005433788224	11176	Economy	24600.00
0005435548506	20671	Economy	27100.00
0005433788176	20671	Economy	24600.00
0005435548511	20671	Economy	24600.00
0005433788180	20671	Economy	24600.00
0005433788161	20671	Economy	24600.00
0005435548508	20671	Economy	24600.00
0005435548510	20671	Economy	24600.00
0005433788189	20671	Economy	24600.00
0005433788178	20671	Economy	24600.00
0005435548509	20671	Economy	24600.00
0005435548512	20671	Economy	24600.00
0005435548505	20671	Economy	24600.00
0005433788162	20671	Economy	24600.00
0005433788169	20671	Economy	24600.00
0005435548513	20671	Economy	24600.00
0005433788164	20671	Economy	24600.00
0005433788163	20671	Economy	24600.00
0005433788179	20671	Economy	24600.00
0005435548507	20671	Economy	24600.00
0005435517945	11394	Business	20200.00
0005435517910	11394	Business	20200.00
0005435517822	11394	Business	20200.00
0005435540943	11394	Business	20200.00
0005435540941	11394	Economy	6700.00
0005435517818	11394	Economy	6700.00
0005435517830	11394	Economy	6700.00
0005435540964	11394	Economy	6700.00
0005435517931	11394	Economy	7400.00
0005435540896	11394	Economy	7400.00
0005435517786	11394	Economy	6700.00
0005435540855	11394	Economy	6700.00
0005435540940	11394	Economy	6700.00
0005435540960	11394	Economy	6700.00
0005435517840	11394	Economy	6700.00
0005435540897	11394	Economy	6700.00
0005435517911	11394	Economy	6700.00
0005435517759	11394	Economy	6700.00
0005435540967	11394	Economy	6700.00
0005435517758	11394	Economy	6700.00
0005435517930	11394	Economy	6700.00
0005435517832	11394	Economy	6700.00
0005435517839	11394	Economy	6700.00
0005435517831	11394	Economy	6700.00
0005435517826	11394	Economy	6700.00
0005435517892	11394	Economy	6700.00
0005435517881	11394	Economy	6700.00
0005435517879	11394	Economy	6700.00
0005435540918	11394	Economy	6700.00
0005435541076	11394	Economy	6700.00
0005435540895	11394	Economy	6700.00
0005435540919	11394	Economy	6700.00
0005435540973	11394	Economy	6700.00
0005435540835	11394	Economy	6700.00
0005435541094	22234	Business	20200.00
0005435541102	22234	Business	20200.00
0005435529351	22234	Business	20200.00
0005435529348	22234	Business	20200.00
0005435541096	22234	Business	20200.00
0005435541091	22234	Business	20200.00
0005435541099	22234	Business	20200.00
0005435529355	22234	Economy	6700.00
0005435541105	22234	Economy	6700.00
0005435541089	22234	Economy	6700.00
0005435529356	22234	Economy	6700.00
0005435541092	22234	Economy	7400.00
0005435541108	22234	Economy	6700.00
0005435541093	22234	Economy	6700.00
0005435529347	22234	Economy	6700.00
0005435541100	22234	Economy	6700.00
0005435529350	22234	Economy	6700.00
0005435529354	22234	Economy	6700.00
0005435529353	22234	Economy	6700.00
0005435541101	22234	Economy	6700.00
0005435529362	22234	Economy	6700.00
0005435529363	22234	Economy	6700.00
0005435541098	22234	Economy	6700.00
0005435529365	22234	Economy	6700.00
0005435529346	22234	Economy	6700.00
0005435529359	22234	Economy	6700.00
0005432294498	22234	Economy	6700.00
0005435529352	22234	Economy	6700.00
0005435529349	22234	Economy	6700.00
0005435541104	22234	Economy	6700.00
0005435541107	22234	Economy	6700.00
0005435529345	22234	Economy	6700.00
0005435529358	22234	Economy	6700.00
0005435529364	22234	Economy	6700.00
0005435541090	22234	Economy	6700.00
0005435541095	22234	Economy	6700.00
0005435529357	22234	Economy	6700.00
0005435529344	22234	Economy	6700.00
0005435541109	22234	Economy	6700.00
0005435541103	22234	Economy	6700.00
0005435541106	22234	Economy	6700.00
0005435529361	22234	Economy	6700.00
0005435541097	22234	Economy	6700.00
0005435529360	22234	Economy	6700.00
0005434907592	2314	Business	20200.00
0005434907573	2314	Business	20200.00
0005433251377	2314	Business	20200.00
0005433251452	2314	Business	20200.00
0005433251327	2314	Business	20200.00
0005434907555	2314	Business	20200.00
0005434907589	2314	Business	20200.00
0005433251460	2314	Business	20200.00
0005434907568	2314	Business	20200.00
0005434907562	2314	Business	20200.00
0005434907549	2314	Economy	6700.00
0005434907551	2314	Economy	6700.00
0005434907582	2314	Economy	6700.00
0005434907584	2314	Economy	6700.00
0005434907543	2314	Economy	6700.00
0005434907546	2314	Economy	6700.00
0005434907559	2314	Economy	6700.00
0005434907576	2314	Economy	6700.00
0005433400977	2314	Economy	7400.00
0005434907541	2314	Economy	7400.00
0005434907577	2314	Economy	7400.00
0005434907593	2314	Economy	7400.00
0005433251518	2314	Economy	7400.00
0005433251482	2314	Economy	6700.00
0005434907548	2314	Economy	6700.00
0005434907585	2314	Economy	6700.00
0005434907547	2314	Economy	6700.00
0005434907534	2314	Economy	6700.00
0005434907542	2314	Economy	6700.00
0005434907550	2314	Economy	6700.00
0005434907597	2314	Economy	6700.00
0005433251409	2314	Economy	6700.00
0005433251483	2314	Economy	6700.00
0005434907565	2314	Economy	6700.00
0005434907567	2314	Economy	6700.00
0005434907563	2314	Economy	6700.00
0005433251371	2314	Economy	6700.00
0005434907536	2314	Economy	6700.00
0005434907553	2314	Economy	6700.00
0005434907586	2314	Economy	6700.00
0005434907561	2314	Economy	6700.00
0005434907544	2314	Economy	6700.00
0005434907569	2314	Economy	6700.00
0005434907538	2314	Economy	6700.00
0005433251339	2314	Economy	6700.00
0005434907583	2314	Economy	6700.00
0005434907588	2314	Economy	6700.00
0005434907578	2314	Economy	6700.00
0005434907535	2314	Economy	6700.00
0005434907539	2314	Economy	6700.00
0005434907566	2314	Economy	6700.00
0005434907572	2314	Economy	6700.00
0005434907596	2314	Economy	6700.00
0005434907574	2314	Economy	6700.00
0005434907552	2314	Economy	6700.00
0005434907570	2314	Economy	6700.00
0005433251341	2314	Economy	6700.00
0005434907571	2314	Economy	6700.00
0005433251522	2314	Economy	6700.00
0005434907545	2314	Economy	6700.00
0005434907556	2314	Economy	6700.00
0005433251391	2314	Economy	6700.00
0005434907581	2314	Economy	6700.00
0005433251416	2314	Economy	6700.00
0005434907537	2314	Economy	6700.00
0005434907564	2314	Economy	6700.00
0005434907575	2314	Economy	6700.00
0005433251397	2314	Economy	6700.00
0005433400979	2314	Economy	6700.00
0005434907590	2314	Economy	6700.00
0005433251380	2314	Economy	6700.00
0005434907587	2314	Economy	6700.00
0005434907591	2314	Economy	6700.00
0005434907580	2314	Economy	6700.00
0005434907594	2314	Economy	6700.00
0005434907554	2314	Economy	6700.00
0005434907579	2314	Economy	6700.00
0005434907557	2314	Economy	6700.00
0005433251272	2314	Economy	6700.00
0005434907560	2314	Economy	6700.00
0005434907540	2314	Economy	6700.00
0005434907595	2314	Economy	6700.00
0005433251379	2314	Economy	6700.00
0005434907558	2314	Economy	6700.00
0005433251639	25586	Business	20200.00
0005434907029	25586	Business	20200.00
0005433251640	25586	Business	20200.00
0005433251625	25586	Business	20200.00
0005434907053	25586	Business	20200.00
0005433251646	25586	Business	20200.00
0005434907039	25586	Business	20200.00
0005434906884	25586	Business	20200.00
0005434906967	25586	Business	20200.00
0005434906936	25586	Business	20200.00
0005434907128	25586	Business	20200.00
0005434906778	25586	Business	20200.00
0005434907086	25586	Economy	6700.00
0005433251650	25586	Economy	6700.00
0005434906962	25586	Economy	6700.00
0005434907070	25586	Economy	6700.00
0005433251631	25586	Economy	6700.00
0005434906883	25586	Economy	6700.00
0005434907110	25586	Economy	6700.00
0005433251637	25586	Economy	6700.00
0005434906735	25586	Economy	6700.00
0005434907027	25586	Economy	6700.00
0005433251647	25586	Economy	7400.00
0005434907097	25586	Economy	7400.00
0005434907024	25586	Economy	7400.00
0005434906979	25586	Economy	7400.00
0005433251652	25586	Economy	6700.00
0005434907109	25586	Economy	6700.00
0005433251630	25586	Economy	6700.00
0005433251634	25586	Economy	6700.00
0005434907146	25586	Economy	6700.00
0005433400998	25586	Economy	6700.00
0005434907096	25586	Economy	6700.00
0005434906975	25586	Economy	6700.00
0005433251628	25586	Economy	6700.00
0005434907073	25586	Economy	6700.00
0005433251641	25586	Economy	6700.00
0005434906932	25586	Economy	6700.00
0005434906841	25586	Economy	6700.00
0005434906961	25586	Economy	6700.00
0005434906888	25586	Economy	6700.00
0005434907051	25586	Economy	6700.00
0005434907085	25586	Economy	6700.00
0005434907142	25586	Economy	6700.00
0005433251644	25586	Economy	6700.00
0005434906974	25586	Economy	6700.00
0005433251629	25586	Economy	6700.00
0005434907078	25586	Economy	6700.00
0005434907107	25586	Economy	6700.00
0005433251635	25586	Economy	6700.00
0005434906920	25586	Economy	6700.00
0005434906960	25586	Economy	6700.00
0005434906969	25586	Economy	6700.00
0005433251627	25586	Economy	6700.00
0005434907145	25586	Economy	6700.00
0005433400999	25586	Economy	6700.00
0005433251633	25586	Economy	6700.00
0005434907087	25586	Economy	6700.00
0005434906937	25586	Economy	6700.00
0005433251648	25586	Economy	6700.00
0005433251624	25586	Economy	6700.00
0005433251651	25586	Economy	6700.00
0005434907032	25586	Economy	6700.00
0005433251645	25586	Economy	6700.00
0005433251642	25586	Economy	6700.00
0005434907098	25586	Economy	6700.00
0005433251649	25586	Economy	6700.00
0005434906842	25586	Economy	6700.00
0005434907050	25586	Economy	6700.00
0005434906861	25586	Economy	6700.00
0005433251636	25586	Economy	6700.00
0005433251643	25586	Economy	6700.00
0005433401000	25586	Economy	6700.00
0005433401001	25586	Economy	6700.00
0005434906968	25586	Economy	6700.00
0005433251653	25586	Economy	6700.00
0005434907141	25586	Economy	6700.00
0005434907091	25586	Economy	6700.00
0005433251626	25586	Economy	6700.00
0005434907077	25586	Economy	6700.00
0005434907132	25586	Economy	6700.00
0005433251638	25586	Economy	6700.00
0005434907106	25586	Economy	6700.00
0005434907028	25586	Economy	6700.00
0005433251632	25586	Economy	6700.00
0005434906897	25586	Economy	6700.00
0005434907043	25586	Economy	6700.00
0005434906994	25586	Economy	6700.00
0005432621109	2536	Economy	13600.00
0005432621118	2536	Economy	13600.00
0005432621117	2536	Economy	12400.00
0005432621105	2536	Economy	12400.00
0005432621110	2536	Economy	12400.00
0005432621107	2536	Economy	12400.00
0005432621113	2536	Economy	12400.00
0005432862295	2536	Economy	12400.00
0005432862292	2536	Economy	12400.00
0005432621112	2536	Economy	12400.00
0005432621116	2536	Economy	12400.00
0005432862274	2536	Economy	12400.00
0005432621104	2536	Economy	12400.00
0005432621114	2536	Economy	12400.00
0005432862291	2536	Economy	12400.00
0005432621111	2536	Economy	12400.00
0005432621106	2536	Economy	12400.00
0005432862311	2536	Economy	12400.00
0005432621108	2536	Economy	12400.00
0005432621115	2536	Economy	12400.00
0005432862345	28046	Economy	12400.00
0005432862343	28046	Economy	12400.00
0005432621009	28046	Economy	12400.00
0005432620989	28046	Economy	12400.00
0005432862338	28046	Economy	12400.00
0005432620976	28046	Economy	12400.00
0005432620956	28046	Economy	12400.00
0005432620990	28046	Economy	12400.00
0005432862344	28046	Economy	12400.00
0005432620952	28046	Economy	12400.00
0005432862341	28046	Economy	12400.00
0005432620955	28046	Economy	12400.00
0005432862340	28046	Economy	12400.00
0005432621010	28046	Economy	12400.00
0005432862342	28046	Economy	12400.00
0005432862339	28046	Economy	12400.00
0005432620962	28046	Economy	12400.00
0005432620898	28046	Economy	12400.00
0005432620972	28046	Economy	12400.00
0005434097482	13041	Economy	11300.00
0005434097483	13041	Economy	11300.00
0005433452749	30983	Economy	8400.00
0005433452750	30983	Economy	8400.00
0005433451628	30983	Economy	8400.00
0005433451629	30983	Economy	8400.00
0005433451630	30983	Economy	8400.00
0005433454875	31401	Economy	8400.00
0005433454874	31401	Economy	8400.00
0005433129264	12023	Economy	7200.00
0005433129262	12023	Economy	7200.00
0005433134111	12023	Economy	6600.00
0005433134131	12023	Economy	6600.00
0005434142607	12023	Economy	6600.00
0005434142603	12023	Economy	6600.00
0005433129268	12023	Economy	6600.00
0005434142608	12023	Economy	6600.00
0005434142588	12023	Economy	6600.00
0005433129265	12023	Economy	6600.00
0005434142605	12023	Economy	6600.00
0005434142606	12023	Economy	6600.00
0005434142604	12023	Economy	6600.00
0005434142628	29809	Economy	7200.00
0005433134160	29809	Economy	7200.00
0005433134162	29809	Economy	7200.00
0005433131733	29809	Economy	6600.00
0005434184675	29809	Economy	6600.00
0005433134161	29809	Economy	6600.00
0005433134163	29809	Economy	6600.00
0005434326270	29809	Economy	6600.00
0005434326266	29809	Economy	6600.00
0005434326267	29809	Economy	6600.00
0005433134159	29809	Economy	6600.00
0005434142626	29809	Economy	6600.00
0005434184676	29809	Economy	6600.00
0005433131732	29809	Economy	6600.00
0005434183590	29809	Economy	6600.00
0005434326271	29809	Economy	6600.00
0005433131730	29809	Economy	6600.00
0005433131731	29809	Economy	6600.00
0005434142629	29809	Economy	6600.00
0005433131729	29809	Economy	6600.00
0005434142627	29809	Economy	6600.00
0005435798924	21301	Economy	17200.00
0005435798942	21301	Economy	17200.00
0005435798921	21301	Economy	15700.00
0005435798931	21301	Economy	15700.00
0005435798928	21301	Economy	15700.00
0005435798941	21301	Economy	15700.00
0005435798918	21301	Economy	15700.00
0005435798920	21301	Economy	15700.00
0005435798939	21301	Economy	15700.00
0005435798940	21301	Economy	15700.00
0005435798917	21301	Economy	15700.00
0005435798932	21301	Economy	15700.00
0005435798929	21301	Economy	15700.00
0005435798916	21301	Economy	15700.00
0005435697464	16467	Economy	18100.00
0005435935048	16467	Economy	18100.00
0005435697467	16467	Economy	18100.00
0005435697452	16467	Economy	18100.00
0005435697466	16467	Economy	18100.00
0005435697447	16467	Economy	18100.00
0005435697465	16467	Economy	18100.00
0005435697460	16467	Economy	18100.00
0005435697470	16467	Economy	18100.00
0005435697454	16467	Economy	18100.00
0005435697471	16467	Economy	18100.00
0005435697448	16467	Economy	18100.00
0005435697473	16467	Economy	18100.00
0005435697449	16467	Economy	18100.00
0005435697472	16467	Economy	18100.00
0005435697463	16467	Economy	18100.00
0005435697450	16467	Economy	18100.00
0005435697461	16467	Economy	18100.00
0005435697453	16467	Economy	18100.00
0005435697458	16467	Economy	18100.00
0005435697456	16467	Economy	18100.00
0005435697459	16467	Economy	18100.00
0005435697462	16467	Economy	18100.00
0005435697446	16467	Economy	18100.00
0005435697451	16467	Economy	18100.00
0005435697468	16467	Economy	18100.00
0005435697469	16467	Economy	18100.00
0005435697457	16467	Economy	18100.00
0005435697455	16467	Economy	18100.00
0005435935035	16467	Economy	18100.00
0005435697265	24714	Economy	19900.00
0005435697212	24714	Economy	18100.00
0005435697236	24714	Economy	18100.00
0005435697145	24714	Economy	18100.00
0005435697245	24714	Economy	18100.00
0005435697111	24714	Economy	18100.00
0005435935063	24714	Economy	18100.00
0005435697178	24714	Economy	18100.00
0005435697307	24714	Economy	18100.00
0005435697292	24714	Economy	18100.00
0005435697208	24714	Economy	18100.00
0005435697050	24714	Economy	18100.00
0005435697181	24714	Economy	18100.00
0005435697027	24714	Economy	18100.00
0005435697252	24714	Economy	18100.00
0005435697177	24714	Economy	18100.00
0005435697306	24714	Economy	18100.00
0005435697281	24714	Economy	18100.00
0005435697210	24714	Economy	18100.00
0005435697211	24714	Economy	18100.00
0005435697051	24714	Economy	18100.00
0005435697235	24714	Economy	18100.00
0005435697112	24714	Economy	18100.00
0005435697185	24714	Economy	18100.00
0005435935064	24714	Economy	18100.00
0005435697174	24714	Economy	18100.00
0005435935062	24714	Economy	18100.00
0005435697313	24714	Economy	18100.00
0005435697182	24714	Economy	18100.00
0005435697333	24714	Economy	18100.00
0005435697209	24714	Economy	18100.00
0005433724825	18763	Economy	4400.00
0005433724823	18763	Economy	4400.00
0005433724822	18763	Economy	4400.00
0005432968838	18763	Economy	4400.00
0005433724824	18763	Economy	4400.00
0005433724803	21604	Economy	4400.00
0005433724805	21604	Economy	4400.00
0005433724816	21604	Economy	4400.00
0005433724774	21604	Economy	4400.00
0005432968853	21604	Economy	4400.00
0005432968854	21604	Economy	4400.00
0005433724804	21604	Economy	4400.00
0005434138567	7296	Business	23100.00
0005434138580	7296	Business	23100.00
0005434138617	7296	Business	23100.00
0005434138626	7296	Business	23100.00
0005434138586	7296	Business	23100.00
0005434138631	7296	Business	23100.00
0005434138583	7296	Business	23100.00
0005434138612	7296	Business	23100.00
0005434138597	7296	Business	23100.00
0005434138576	7296	Economy	7700.00
0005434138590	7296	Economy	7700.00
0005434138606	7296	Economy	7700.00
0005434087537	7296	Economy	7700.00
0005434087539	7296	Economy	7700.00
0005434138577	7296	Economy	7700.00
0005434138592	7296	Economy	7700.00
0005434138573	7296	Economy	7700.00
0005434138614	7296	Economy	7700.00
0005434138623	7296	Economy	8500.00
0005434138553	7296	Economy	8500.00
0005434138578	7296	Economy	8500.00
0005434138599	7296	Economy	8500.00
0005434138610	7296	Economy	8500.00
0005434138595	7296	Economy	7700.00
0005434087541	7296	Economy	7700.00
0005434138600	7296	Economy	7700.00
0005434138559	7296	Economy	7700.00
0005434138579	7296	Economy	7700.00
0005434138594	7296	Economy	7700.00
0005434138574	7296	Economy	7700.00
0005434138568	7296	Economy	7700.00
0005434138570	7296	Economy	7700.00
0005434138563	7296	Economy	7700.00
0005434138628	7296	Economy	7700.00
0005434138565	7296	Economy	7700.00
0005434138621	7296	Economy	7700.00
0005434138615	7296	Economy	7700.00
0005434138571	7296	Economy	7700.00
0005434138584	7296	Economy	7700.00
0005434138608	7296	Economy	7700.00
0005434138601	7296	Economy	7700.00
0005434138591	7296	Economy	7700.00
0005434087540	7296	Economy	7700.00
0005434138619	7296	Economy	7700.00
0005434138604	7296	Economy	7700.00
0005434138555	7296	Economy	7700.00
0005434138607	7296	Economy	7700.00
0005434138575	7296	Economy	7700.00
0005434138620	7296	Economy	7700.00
0005434138557	7296	Economy	7700.00
0005434138582	7296	Economy	7700.00
0005434138603	7296	Economy	7700.00
0005434138624	7296	Economy	7700.00
0005434138564	7296	Economy	7700.00
0005434138622	7296	Economy	7700.00
0005434138605	7296	Economy	7700.00
0005434138556	7296	Economy	7700.00
0005434087542	7296	Economy	7700.00
0005434138587	7296	Economy	7700.00
0005434138593	7296	Economy	7700.00
0005434138566	7296	Economy	7700.00
0005434138588	7296	Economy	7700.00
0005434138611	7296	Economy	7700.00
0005434138609	7296	Economy	7700.00
0005434138581	7296	Economy	7700.00
0005434138558	7296	Economy	7700.00
0005434138596	7296	Economy	7700.00
0005434138627	7296	Economy	7700.00
0005434138569	7296	Economy	7700.00
0005434138625	7296	Economy	7700.00
0005434138554	7296	Economy	7700.00
0005434138562	7296	Economy	7700.00
0005434138572	7296	Economy	7700.00
0005434138602	7296	Economy	7700.00
0005434138616	7296	Economy	7700.00
0005434138630	7296	Economy	7700.00
0005434138585	7296	Economy	7700.00
0005434138589	7296	Economy	7700.00
0005434138613	7296	Economy	7700.00
0005434087538	7296	Economy	7700.00
0005434138629	7296	Economy	7700.00
0005434138618	7296	Economy	7700.00
0005434138561	7296	Economy	7700.00
0005434138598	7296	Economy	7700.00
0005434138560	7296	Economy	7700.00
0005434137649	28537	Business	23100.00
0005434137496	28537	Business	23100.00
0005434137751	28537	Business	23100.00
0005434137661	28537	Business	23100.00
0005434137866	28537	Business	23100.00
0005434137410	28537	Business	23100.00
0005434137475	28537	Business	23100.00
0005434137409	28537	Business	23100.00
0005434137678	28537	Business	23100.00
0005434137760	28537	Business	23100.00
0005434137720	28537	Business	23100.00
0005434137753	28537	Economy	7700.00
0005434137719	28537	Economy	7700.00
0005434138068	28537	Economy	7700.00
0005434137830	28537	Economy	7700.00
0005434137617	28537	Economy	7700.00
0005434137663	28537	Economy	7700.00
0005434137485	28537	Economy	7700.00
0005434137541	28537	Economy	7700.00
0005434138001	28537	Economy	7700.00
0005434137545	28537	Economy	7700.00
0005434137713	28537	Economy	8500.00
0005434137723	28537	Economy	8500.00
0005434137768	28537	Economy	8500.00
0005434137486	28537	Economy	8500.00
0005434137961	28537	Economy	8500.00
0005434137550	28537	Economy	7700.00
0005434137974	28537	Economy	7700.00
0005434137578	28537	Economy	7700.00
0005434137767	28537	Economy	7700.00
0005434137856	28537	Economy	7700.00
0005434137625	28537	Economy	7700.00
0005434137307	28537	Economy	7700.00
0005434137952	28537	Economy	7700.00
0005434137894	28537	Economy	7700.00
0005434137497	28537	Economy	7700.00
0005434137787	28537	Economy	7700.00
0005434137669	28537	Economy	7700.00
0005434137944	28537	Economy	7700.00
0005434137626	28537	Economy	7700.00
0005434137549	28537	Economy	7700.00
0005434137620	28537	Economy	7700.00
0005434137877	28537	Economy	7700.00
0005434138015	28537	Economy	7700.00
0005434087492	28537	Economy	7700.00
0005434137777	28537	Economy	7700.00
0005434137769	28537	Economy	7700.00
0005434137981	28537	Economy	7700.00
0005434137759	28537	Economy	7700.00
0005434137662	28537	Economy	7700.00
0005434137975	28537	Economy	7700.00
0005434137776	28537	Economy	7700.00
0005434137931	28537	Economy	7700.00
0005434137631	28537	Economy	7700.00
0005434137941	28537	Economy	7700.00
0005434137871	28537	Economy	7700.00
0005434137996	28537	Economy	7700.00
0005434137616	28537	Economy	7700.00
0005434137621	28537	Economy	7700.00
0005434137798	28537	Economy	7700.00
0005434137721	28537	Economy	7700.00
0005434137829	28537	Economy	7700.00
0005434137542	28537	Economy	7700.00
0005434137885	28537	Economy	7700.00
0005434137886	28537	Economy	7700.00
0005434137929	28537	Economy	7700.00
0005434137995	28537	Economy	7700.00
0005434137577	28537	Economy	7700.00
0005434137612	28537	Economy	7700.00
0005434137576	28537	Economy	7700.00
0005434137619	28537	Economy	7700.00
0005434137766	28537	Economy	7700.00
0005434137618	28537	Economy	7700.00
0005434137322	28537	Economy	7700.00
0005434137358	28537	Economy	7700.00
0005434137632	28537	Economy	7700.00
0005434137722	28537	Economy	7700.00
0005434137726	28537	Economy	7700.00
0005434137306	28537	Economy	7700.00
0005434137630	28537	Economy	7700.00
0005434137932	28537	Economy	7700.00
0005434137646	28537	Economy	7700.00
0005434137724	28537	Economy	7700.00
0005434137647	28537	Economy	7700.00
0005434137848	28537	Economy	7700.00
0005434137969	28537	Economy	7700.00
0005434137624	28537	Economy	7700.00
0005434137305	28537	Economy	7700.00
0005434087491	28537	Economy	7700.00
0005434138020	28537	Economy	7700.00
0005434138014	28537	Economy	7700.00
0005434087511	28537	Economy	7700.00
0005434137740	28537	Economy	7700.00
0005434137321	28537	Economy	7700.00
0005434137893	28537	Economy	7700.00
0005435808292	1936	Economy	23900.00
0005434610249	1936	Economy	23900.00
0005433407541	1936	Economy	21700.00
0005435808289	1936	Economy	21700.00
0005434610247	1936	Economy	21700.00
0005433407542	1936	Economy	21700.00
0005435808290	1936	Economy	21700.00
0005435808285	1936	Economy	21700.00
0005433407530	1936	Economy	21700.00
0005434610248	1936	Economy	21700.00
0005435808288	1936	Economy	21700.00
0005435808287	1936	Economy	21700.00
0005433407563	1936	Economy	21700.00
0005435808293	1936	Economy	21700.00
0005435808291	1936	Economy	21700.00
0005434610246	1936	Economy	21700.00
0005433407544	1936	Economy	21700.00
0005433407538	1936	Economy	21700.00
0005433407518	1936	Economy	21700.00
0005435808284	1936	Economy	21700.00
0005433407561	1936	Economy	21700.00
0005435808294	1936	Economy	21700.00
0005433407531	1936	Economy	21700.00
0005433407562	1936	Economy	21700.00
0005433407543	1936	Economy	21700.00
0005435808286	1936	Economy	21700.00
0005435808090	23084	Economy	23900.00
0005435808160	23084	Economy	23900.00
0005434610209	23084	Economy	23900.00
0005435808172	23084	Economy	23900.00
0005435808203	23084	Economy	21700.00
0005433407591	23084	Economy	21700.00
0005433407581	23084	Economy	21700.00
0005434610197	23084	Economy	21700.00
0005435808157	23084	Economy	21700.00
0005435808151	23084	Economy	21700.00
0005433407585	23084	Economy	21700.00
0005433407579	23084	Economy	21700.00
0005433407584	23084	Economy	21700.00
0005435808202	23084	Economy	21700.00
0005435808206	23084	Economy	21700.00
0005435808171	23084	Economy	21700.00
0005433407577	23084	Economy	21700.00
0005433407586	23084	Economy	21700.00
0005433407583	23084	Economy	21700.00
0005433407589	23084	Economy	21700.00
0005435808089	23084	Economy	21700.00
0005433407580	23084	Economy	21700.00
0005435808149	23084	Economy	21700.00
0005433407575	23084	Economy	21700.00
0005435808156	23084	Economy	21700.00
0005435808170	23084	Economy	21700.00
0005435808143	23084	Economy	21700.00
0005433407588	23084	Economy	21700.00
0005435808128	23084	Economy	21700.00
0005434610221	23084	Economy	21700.00
0005435808205	23084	Economy	21700.00
0005435808177	23084	Economy	21700.00
0005435808174	23084	Economy	21700.00
0005435808158	23084	Economy	21700.00
0005435808152	23084	Economy	21700.00
0005435808150	23084	Economy	21700.00
0005433407578	23084	Economy	21700.00
0005433407582	23084	Economy	21700.00
0005435808207	23084	Economy	21700.00
0005433407576	23084	Economy	21700.00
0005435808142	23084	Economy	21700.00
0005433407590	23084	Economy	21700.00
0005435808164	23084	Economy	21700.00
0005433407587	23084	Economy	21700.00
0005434503966	16702	Economy	7600.00
0005434503896	16702	Economy	7600.00
0005434503948	16702	Economy	6900.00
0005434503794	16702	Economy	6900.00
0005434504101	16702	Economy	6900.00
0005434503991	16702	Economy	6900.00
0005434504089	16702	Economy	6900.00
0005434504059	16702	Economy	6900.00
0005434504027	16702	Economy	6900.00
0005434503923	16702	Economy	6900.00
0005434504032	16702	Economy	6900.00
0005434504098	16702	Economy	6900.00
0005434504090	16702	Economy	6900.00
0005434504053	16702	Economy	6900.00
0005434503897	16702	Economy	6900.00
0005434503837	16702	Economy	6900.00
0005434503929	16702	Economy	6900.00
0005434503833	16702	Economy	6900.00
0005434504052	16702	Economy	6900.00
0005434504085	16702	Economy	6900.00
0005434504136	16702	Economy	6900.00
0005434503962	16702	Economy	6900.00
0005434504164	16702	Economy	6900.00
0005434504000	16702	Economy	6900.00
0005434503930	16702	Economy	6900.00
0005434504094	16702	Economy	6900.00
0005434504096	16702	Economy	6900.00
0005434504028	16702	Economy	6900.00
0005434504031	16702	Economy	6900.00
0005434503919	16702	Economy	6900.00
0005434503741	16702	Economy	6900.00
0005434503999	16702	Economy	6900.00
0005434504060	16702	Economy	6900.00
0005434504335	22925	Economy	7600.00
0005434504303	22925	Economy	7600.00
0005434504301	22925	Economy	7600.00
0005434504330	22925	Economy	7600.00
0005434504315	22925	Economy	6900.00
0005434504320	22925	Economy	6900.00
0005434504316	22925	Economy	6900.00
0005434504321	22925	Economy	6900.00
0005434504307	22925	Economy	6900.00
0005434504337	22925	Economy	6900.00
0005434504334	22925	Economy	6900.00
0005434504323	22925	Economy	6900.00
0005434504311	22925	Economy	6900.00
0005434504327	22925	Economy	6900.00
0005434504338	22925	Economy	6900.00
0005434504313	22925	Economy	6900.00
0005434504333	22925	Economy	6900.00
0005434504319	22925	Economy	6900.00
0005434504332	22925	Economy	6900.00
0005434504309	22925	Economy	6900.00
0005434504318	22925	Economy	6900.00
0005434504341	22925	Economy	6900.00
0005434504322	22925	Economy	6900.00
0005434504336	22925	Economy	6900.00
0005434504314	22925	Economy	6900.00
0005434504310	22925	Economy	6900.00
0005434504308	22925	Economy	6900.00
0005434504326	22925	Economy	6900.00
0005434504304	22925	Economy	6900.00
0005434504302	22925	Economy	6900.00
0005434504312	22925	Economy	6900.00
0005434504331	22925	Economy	6900.00
0005434504328	22925	Economy	6900.00
0005434504340	22925	Economy	6900.00
0005434504329	22925	Economy	6900.00
0005434504305	22925	Economy	6900.00
0005434504317	22925	Economy	6900.00
0005434504325	22925	Economy	6900.00
0005434504324	22925	Economy	6900.00
0005434504306	22925	Economy	6900.00
0005434504339	22925	Economy	6900.00
0005433266704	2214	Economy	7700.00
0005435078420	2214	Economy	7000.00
0005433266728	2214	Economy	7000.00
0005435078422	2214	Economy	7000.00
0005435078415	2214	Economy	7000.00
0005435078416	2214	Economy	7000.00
0005433266713	2214	Economy	7000.00
0005433266690	2214	Economy	7000.00
0005435078414	2214	Economy	7000.00
0005435078427	2214	Economy	7000.00
0005435078418	2214	Economy	7000.00
0005435078419	2214	Economy	7000.00
0005433266686	2214	Economy	7000.00
0005435078428	2214	Economy	7000.00
0005435078423	2214	Economy	7000.00
0005435078417	2214	Economy	7000.00
0005433266674	2214	Economy	7000.00
0005435078424	2214	Economy	7000.00
0005433266714	2214	Economy	7000.00
0005435078425	2214	Economy	7000.00
0005435078429	2214	Economy	7000.00
0005433266705	2214	Economy	7000.00
0005435078426	2214	Economy	7000.00
0005433266727	2214	Economy	7000.00
0005433266691	2214	Economy	7000.00
0005433266656	2214	Economy	7000.00
0005435078421	2214	Economy	7000.00
0005435078313	24335	Economy	7700.00
0005433266769	24335	Economy	7000.00
0005435078301	24335	Economy	7000.00
0005435078251	24335	Economy	7000.00
0005433266773	24335	Economy	7000.00
0005435078289	24335	Economy	7000.00
0005433266771	24335	Economy	7000.00
0005435078374	24335	Economy	7000.00
0005433266768	24335	Economy	7000.00
0005435078315	24335	Economy	7000.00
0005435078349	24335	Economy	7000.00
0005435078305	24335	Economy	7000.00
0005433266770	24335	Economy	7000.00
0005433266774	24335	Economy	7000.00
0005435078253	24335	Economy	7000.00
0005435078232	24335	Economy	7000.00
0005435078295	24335	Economy	7000.00
0005433266772	24335	Economy	7000.00
0005433266766	24335	Economy	7000.00
0005435078234	24335	Economy	7000.00
0005435078300	24335	Economy	7000.00
0005433266775	24335	Economy	7000.00
0005435078332	24335	Economy	7000.00
0005433266767	24335	Economy	7000.00
0005435078252	24335	Economy	7000.00
0005435078233	24335	Economy	7000.00
0005435078333	24335	Economy	7000.00
0005435464498	6612	Economy	10800.00
0005434988798	6612	Economy	10800.00
0005434988793	6612	Economy	9800.00
0005435464501	6612	Economy	9800.00
0005434988799	6612	Economy	9800.00
0005435464504	6612	Economy	9800.00
0005435464503	6612	Economy	9800.00
0005434988796	6612	Economy	9800.00
0005435803277	6612	Economy	9800.00
0005434988795	6612	Economy	9800.00
0005434988797	6612	Economy	9800.00
0005435464502	6612	Economy	9800.00
0005434988792	6612	Economy	9800.00
0005435803278	6612	Economy	9800.00
0005434988791	6612	Economy	9800.00
0005434988794	6612	Economy	9800.00
0005434988658	23616	Economy	9800.00
0005434988647	23616	Economy	9800.00
0005434988635	23616	Economy	9800.00
0005434988613	23616	Economy	9800.00
0005434988627	23616	Economy	9800.00
0005434988640	23616	Economy	9800.00
0005435464517	23616	Economy	9800.00
0005434988628	23616	Economy	9800.00
0005435464516	23616	Economy	9800.00
0005434988649	23616	Economy	9800.00
0005434988639	23616	Economy	9800.00
0005435803249	23616	Economy	9800.00
0005434988648	23616	Economy	9800.00
0005435803252	23616	Economy	9800.00
0005435464518	23616	Economy	9800.00
0005433450092	30491	Business	9900.00
0005432383380	30491	Business	9900.00
0005432383360	30491	Business	9900.00
0005432383376	30491	Business	9900.00
0005433453771	30491	Business	9900.00
0005433450074	30491	Business	9900.00
0005432383398	30491	Business	9900.00
0005432383391	30491	Economy	3300.00
0005433454887	30491	Economy	3300.00
0005432383397	30491	Economy	3300.00
0005433450075	30491	Economy	3300.00
0005433450090	30491	Economy	3300.00
0005432383399	30491	Economy	3300.00
0005433450089	30491	Economy	3300.00
0005432383369	30491	Economy	3300.00
0005432383362	30491	Economy	3600.00
0005432383383	30491	Economy	3300.00
0005432383393	30491	Economy	3300.00
0005432383382	30491	Economy	3300.00
0005432383395	30491	Economy	3300.00
0005432383373	30491	Economy	3300.00
0005433450095	30491	Economy	3300.00
0005432383386	30491	Economy	3300.00
0005432383401	30491	Economy	3300.00
0005433450078	30491	Economy	3300.00
0005433453770	30491	Economy	3300.00
0005433450079	30491	Economy	3300.00
0005432383400	30491	Economy	3300.00
0005432383367	30491	Economy	3300.00
0005432383364	30491	Economy	3300.00
0005432383371	30491	Economy	3300.00
0005433450082	30491	Economy	3300.00
0005432383378	30491	Economy	3300.00
0005433450083	30491	Economy	3300.00
0005432383385	30491	Economy	3300.00
0005432383389	30491	Economy	3300.00
0005433450094	30491	Economy	3300.00
0005433450091	30491	Economy	3300.00
0005432383363	30491	Economy	3300.00
0005432383359	30491	Economy	3300.00
0005432383377	30491	Economy	3300.00
0005432383375	30491	Economy	3300.00
0005432383384	30491	Economy	3300.00
0005432383392	30491	Economy	3300.00
0005433450093	30491	Economy	3300.00
0005432383366	30491	Economy	3300.00
0005432383394	30491	Economy	3300.00
0005433450081	30491	Economy	3300.00
0005432383396	30491	Economy	3300.00
0005433450076	30491	Economy	3300.00
0005432383390	30491	Economy	3300.00
0005433450086	30491	Economy	3300.00
0005433450084	30491	Economy	3300.00
0005432383379	30491	Economy	3300.00
0005432383388	30491	Economy	3300.00
0005433450080	30491	Economy	3300.00
0005433450085	30491	Economy	3300.00
0005432383365	30491	Economy	3300.00
0005432383370	30491	Economy	3300.00
0005433450077	30491	Economy	3300.00
0005432383372	30491	Economy	3300.00
0005433450088	30491	Economy	3300.00
0005432383368	30491	Economy	3300.00
0005432383381	30491	Economy	3300.00
0005432383361	30491	Economy	3300.00
0005432383374	30491	Economy	3300.00
0005433450087	30491	Economy	3300.00
0005432383387	30491	Economy	3300.00
0005433449919	31318	Business	9900.00
0005432382897	31318	Business	9900.00
0005433453744	31318	Business	9900.00
0005432383120	31318	Business	9900.00
0005433449951	31318	Business	9900.00
0005432382950	31318	Business	9900.00
0005433449859	31318	Economy	3300.00
0005432382907	31318	Economy	3300.00
0005432382933	31318	Economy	3300.00
0005432382929	31318	Economy	3300.00
0005432382952	31318	Economy	3300.00
0005433449852	31318	Economy	3300.00
0005433449925	31318	Economy	3300.00
0005433453743	31318	Economy	3600.00
0005433449920	31318	Economy	3600.00
0005432383065	31318	Economy	3600.00
0005433449845	31318	Economy	3300.00
0005432383091	31318	Economy	3300.00
0005432382826	31318	Economy	3300.00
0005432382984	31318	Economy	3300.00
0005433449952	31318	Economy	3300.00
0005432383066	31318	Economy	3300.00
0005433451608	31318	Economy	3300.00
0005433449863	31318	Economy	3300.00
0005432382911	31318	Economy	3300.00
0005433449903	31318	Economy	3300.00
0005433449800	31318	Economy	3300.00
0005432382905	31318	Economy	3300.00
0005432382962	31318	Economy	3300.00
0005432382868	31318	Economy	3300.00
0005433449854	31318	Economy	3300.00
0005432382867	31318	Economy	3300.00
0005432382985	31318	Economy	3300.00
0005432382889	31318	Economy	3300.00
0005433449853	31318	Economy	3300.00
0005433449891	31318	Economy	3300.00
0005432382936	31318	Economy	3300.00
0005433449975	31318	Economy	3300.00
0005432382935	31318	Economy	3300.00
0005433453750	31318	Economy	3300.00
0005433449851	31318	Economy	3300.00
0005433449907	31318	Economy	3300.00
0005433449824	31318	Economy	3300.00
0005432383073	31318	Economy	3300.00
0005433449906	31318	Economy	3300.00
0005433449823	31318	Economy	3300.00
0005432382937	31318	Economy	3300.00
0005433449904	31318	Economy	3300.00
0005432382838	31318	Economy	3300.00
0005433449860	31318	Economy	3300.00
0005432382964	31318	Economy	3300.00
0005433449918	31318	Economy	3300.00
0005433449873	31318	Economy	3300.00
0005432382963	31318	Economy	3300.00
0005432382862	31318	Economy	3300.00
0005432382861	31318	Economy	3300.00
0005433126824	10800	Economy	17100.00
0005435299772	10800	Economy	15600.00
0005435304130	10800	Economy	15600.00
0005433131693	10800	Economy	15600.00
0005435304150	10800	Economy	15600.00
0005435299756	10800	Economy	15600.00
0005435299757	10800	Economy	15600.00
0005435299773	10800	Economy	15600.00
0005435299744	10800	Economy	15600.00
0005435299761	10800	Economy	15600.00
0005433126841	10800	Economy	15600.00
0005435299745	10800	Economy	15600.00
0005435302228	29713	Economy	17100.00
0005435299804	29713	Economy	17100.00
0005433129304	29713	Economy	17100.00
0005433126873	29713	Economy	17100.00
0005435302227	29713	Economy	15600.00
0005433129306	29713	Economy	15600.00
0005433129303	29713	Economy	15600.00
0005433126874	29713	Economy	15600.00
0005435299803	29713	Economy	15600.00
0005435299806	29713	Economy	15600.00
0005433129302	29713	Economy	15600.00
0005435299805	29713	Economy	15600.00
0005433129305	29713	Economy	15600.00
0005435302225	29713	Economy	15600.00
0005433129301	29713	Economy	15600.00
0005435302226	29713	Economy	15600.00
0005433126872	29713	Economy	15600.00
0005433126871	29713	Economy	15600.00
0005434287393	2418	Economy	17200.00
0005434287404	2418	Economy	17200.00
0005434287403	2418	Economy	17200.00
0005433110002	2418	Economy	15700.00
0005434287400	2418	Economy	15700.00
0005434287409	2418	Economy	15700.00
0005433110092	2418	Economy	15700.00
0005433109965	2418	Economy	15700.00
0005434287398	2418	Economy	15700.00
0005434287399	2418	Economy	15700.00
0005432264487	2418	Economy	15700.00
0005433110013	2418	Economy	15700.00
0005434287407	2418	Economy	15700.00
0005432264488	2418	Economy	15700.00
0005433109964	2418	Economy	15700.00
0005433110053	2418	Economy	15700.00
0005433110004	2418	Economy	15700.00
0005434287405	2418	Economy	15700.00
0005434287401	2418	Economy	15700.00
0005434287396	2418	Economy	15700.00
0005433110056	2418	Economy	15700.00
0005434287413	2418	Economy	15700.00
0005433110024	2418	Economy	15700.00
0005434287414	2418	Economy	15700.00
0005434287397	2418	Economy	15700.00
0005433110057	2418	Economy	15700.00
0005433110093	2418	Economy	15700.00
0005434287410	2418	Economy	15700.00
0005433110003	2418	Economy	15700.00
0005434287394	2418	Economy	15700.00
0005434287395	2418	Economy	15700.00
0005434287402	2418	Economy	15700.00
0005434287408	2418	Economy	15700.00
0005433110062	2418	Economy	15700.00
0005434287411	2418	Economy	15700.00
0005434287406	2418	Economy	15700.00
0005434287412	2418	Economy	15700.00
0005434287110	26833	Economy	17200.00
0005434287272	26833	Economy	17200.00
0005433110114	26833	Economy	15700.00
0005434287285	26833	Economy	15700.00
0005434287239	26833	Economy	15700.00
0005433110120	26833	Economy	15700.00
0005434287203	26833	Economy	15700.00
0005434287274	26833	Economy	15700.00
0005434287284	26833	Economy	15700.00
0005434287273	26833	Economy	15700.00
0005434287141	26833	Economy	15700.00
0005433110121	26833	Economy	15700.00
0005434287236	26833	Economy	15700.00
0005433110115	26833	Economy	15700.00
0005434287201	26833	Economy	15700.00
0005434287288	26833	Economy	15700.00
0005434287083	26833	Economy	15700.00
0005433110111	26833	Economy	15700.00
0005434287205	26833	Economy	15700.00
0005433110117	26833	Economy	15700.00
0005434287187	26833	Economy	15700.00
0005434287207	26833	Economy	15700.00
0005433110118	26833	Economy	15700.00
0005433110112	26833	Economy	15700.00
0005434287109	26833	Economy	15700.00
0005434287212	26833	Economy	15700.00
0005433110119	26833	Economy	15700.00
0005434287140	26833	Economy	15700.00
0005433110113	26833	Economy	15700.00
0005433110110	26833	Economy	15700.00
0005434287139	26833	Economy	15700.00
0005434287194	26833	Economy	15700.00
0005434287204	26833	Economy	15700.00
0005433110116	26833	Economy	15700.00
0005435856225	25460	Economy	22800.00
0005434269087	25460	Economy	22800.00
0005435856226	25460	Economy	22800.00
0005435856224	25460	Economy	22800.00
0005434272185	25460	Economy	22800.00
0005435856228	25460	Economy	22800.00
0005435856227	25460	Economy	22800.00
0005434272186	25460	Economy	22800.00
0005435856173	26662	Economy	25000.00
0005435854053	26662	Economy	22800.00
0005435854050	26662	Economy	22800.00
0005434272199	26662	Economy	22800.00
0005434273085	26662	Economy	22800.00
0005435856158	26662	Economy	22800.00
0005435854054	26662	Economy	22800.00
0005434273084	26662	Economy	22800.00
0005435854049	26662	Economy	22800.00
0005434272200	26662	Economy	22800.00
0005435854052	26662	Economy	22800.00
0005433868641	4808	Economy	19400.00
0005433868650	4808	Economy	19400.00
0005433868632	4808	Economy	17600.00
0005433868653	4808	Economy	19400.00
0005433868654	4808	Economy	17600.00
0005433868644	4808	Economy	17600.00
0005433868655	4808	Economy	17600.00
0005433868659	4808	Economy	17600.00
0005433868663	4808	Economy	17600.00
0005433868666	4808	Economy	17600.00
0005435860477	4808	Economy	17600.00
0005433868631	4808	Economy	17600.00
0005433868664	4808	Economy	17600.00
0005433868661	4808	Economy	17600.00
0005435860462	4808	Economy	17600.00
0005433868667	4808	Economy	17600.00
0005435860476	4808	Economy	17600.00
0005433868634	4808	Economy	17600.00
0005433868652	4808	Economy	17600.00
0005435860472	4808	Economy	17600.00
0005433868640	4808	Economy	17600.00
0005433868642	4808	Economy	17600.00
0005433868665	4808	Economy	17600.00
0005433868638	4808	Economy	17600.00
0005433868657	4808	Economy	17600.00
0005435860475	4808	Economy	17600.00
0005433868669	4808	Economy	17600.00
0005433868643	4808	Economy	17600.00
0005433868647	4808	Economy	17600.00
0005433868636	4808	Economy	17600.00
0005433868658	4808	Economy	17600.00
0005433868649	4808	Economy	17600.00
0005433868648	4808	Economy	17600.00
0005433868635	4808	Economy	17600.00
0005433868630	4808	Economy	17600.00
0005433868639	4808	Economy	17600.00
0005433868660	4808	Economy	17600.00
0005433868668	4808	Economy	17600.00
0005433868645	4808	Economy	17600.00
0005433868637	4808	Economy	17600.00
0005433868633	4808	Economy	17600.00
0005433868646	4808	Economy	17600.00
0005433868662	4808	Economy	17600.00
0005435860471	4808	Economy	17600.00
0005433868656	4808	Economy	17600.00
0005433868651	4808	Economy	17600.00
0005433868179	32583	Economy	19400.00
0005433868220	32583	Economy	19400.00
0005433868201	32583	Economy	19400.00
0005433868024	32583	Economy	19400.00
0005433868393	32583	Economy	17600.00
0005435860506	32583	Economy	17600.00
0005433868324	32583	Economy	17600.00
0005433868316	32583	Economy	17600.00
0005433868402	32583	Economy	17600.00
0005433868251	32583	Economy	17600.00
0005433868290	32583	Economy	17600.00
0005433868266	32583	Economy	17600.00
0005433868056	32583	Economy	17600.00
0005433868413	32583	Economy	17600.00
0005433868255	32583	Economy	17600.00
0005433868128	32583	Economy	17600.00
0005433868264	32583	Economy	17600.00
0005433868145	32583	Economy	17600.00
0005433868033	32583	Economy	17600.00
0005435860504	32583	Economy	17600.00
0005433868221	32583	Economy	17600.00
0005433868211	32583	Economy	17600.00
0005433868122	32583	Economy	17600.00
0005433868254	32583	Economy	17600.00
0005435860505	32583	Economy	17600.00
0005433868217	32583	Economy	17600.00
0005433868200	32583	Economy	17600.00
0005433868219	32583	Economy	17600.00
0005435860507	32583	Economy	17600.00
0005433868267	32583	Economy	17600.00
0005433868150	32583	Economy	17600.00
0005433868223	32583	Economy	17600.00
0005433868180	32583	Economy	17600.00
0005433868325	32583	Economy	17600.00
0005433868212	32583	Economy	17600.00
0005433868034	32583	Economy	17600.00
0005433868224	32583	Economy	17600.00
0005433868268	32583	Economy	17600.00
0005433868235	32583	Economy	17600.00
0005433868265	32583	Economy	17600.00
0005433868228	32583	Economy	17600.00
0005433868291	32583	Economy	17600.00
0005433868412	32583	Economy	17600.00
0005433868025	32583	Economy	17600.00
0005435911430	3410	Economy	24800.00
0005435911454	3410	Economy	24800.00
0005434663479	3410	Economy	22600.00
0005435911403	3410	Economy	22600.00
0005434663472	3410	Economy	22600.00
0005435911402	3410	Economy	22600.00
0005435911407	3410	Economy	22600.00
0005434663477	3410	Economy	22600.00
0005434663485	3410	Economy	22600.00
0005435911431	3410	Economy	22600.00
0005434461658	3410	Economy	22600.00
0005434663475	3410	Economy	22600.00
0005434663474	3410	Economy	22600.00
0005434663482	3410	Economy	22600.00
0005434663473	3410	Economy	22600.00
0005434663484	3410	Economy	22600.00
0005434461659	3410	Economy	22600.00
0005435911446	3410	Economy	22600.00
0005434663478	3410	Economy	22600.00
0005435911465	3410	Economy	22600.00
0005434663480	3410	Economy	22600.00
0005434663481	3410	Economy	22600.00
0005434461657	3410	Economy	22600.00
0005434663476	3410	Economy	22600.00
0005434663483	3410	Economy	22600.00
0005434460517	3410	Economy	22600.00
0005434663361	12495	Economy	24800.00
0005434663322	12495	Economy	22600.00
0005434663352	12495	Economy	22600.00
0005435911490	12495	Economy	22600.00
0005435911491	12495	Economy	22600.00
0005435911487	12495	Economy	22600.00
0005434663383	12495	Economy	22600.00
0005435911492	12495	Economy	22600.00
0005435911494	12495	Economy	22600.00
0005435911488	12495	Economy	22600.00
0005434663360	12495	Economy	22600.00
0005435911493	12495	Economy	22600.00
0005434663336	12495	Economy	22600.00
0005434663323	12495	Economy	22600.00
0005435911489	12495	Economy	22600.00
0005433868211	14475	Economy	18500.00
0005433868217	14475	Economy	18500.00
0005433868254	14475	Economy	18500.00
0005433868255	14475	Economy	18500.00
0005433868393	14475	Economy	16800.00
0005433868265	14475	Economy	16800.00
0005433868056	14475	Economy	16800.00
0005435860506	14475	Economy	16800.00
0005433868180	14475	Economy	16800.00
0005433868266	14475	Economy	16800.00
0005433868122	14475	Economy	16800.00
0005433868145	14475	Economy	16800.00
0005433868201	14475	Economy	16800.00
0005433868220	14475	Economy	16800.00
0005433868267	14475	Economy	16800.00
0005433868290	14475	Economy	16800.00
0005433868219	14475	Economy	16800.00
0005433868402	14475	Economy	16800.00
0005433868128	14475	Economy	16800.00
0005433868235	14475	Economy	16800.00
0005435860505	14475	Economy	16800.00
0005433868224	14475	Economy	16800.00
0005433868324	14475	Economy	16800.00
0005433868034	14475	Economy	16800.00
0005433868025	14475	Economy	16800.00
0005433868033	14475	Economy	16800.00
0005433868221	14475	Economy	16800.00
0005433868264	14475	Economy	16800.00
0005435860507	14475	Economy	16800.00
0005433868316	14475	Economy	16800.00
0005433868024	14475	Economy	16800.00
0005433868179	14475	Economy	16800.00
0005433868413	14475	Economy	16800.00
0005433868200	14475	Economy	16800.00
0005433868251	14475	Economy	16800.00
0005433868325	14475	Economy	16800.00
0005433868150	14475	Economy	16800.00
0005433868212	14475	Economy	16800.00
0005433868412	14475	Economy	16800.00
0005433868228	14475	Economy	16800.00
0005433868268	14475	Economy	16800.00
0005433868291	14475	Economy	16800.00
0005433868223	14475	Economy	16800.00
0005435860504	14475	Economy	16800.00
0005433868599	32677	Economy	18500.00
0005433868619	32677	Economy	18500.00
0005433868627	32677	Economy	18500.00
0005433868601	32677	Economy	16800.00
0005433868629	32677	Economy	16800.00
0005433868628	32677	Economy	16800.00
0005433868603	32677	Economy	16800.00
0005433868617	32677	Economy	16800.00
0005433868622	32677	Economy	16800.00
0005433868618	32677	Economy	16800.00
0005435860455	32677	Economy	16800.00
0005433868600	32677	Economy	16800.00
0005433868604	32677	Economy	16800.00
0005433868620	32677	Economy	16800.00
0005433868605	32677	Economy	16800.00
0005433868624	32677	Economy	16800.00
0005433868607	32677	Economy	16800.00
0005433868609	32677	Economy	16800.00
0005433868623	32677	Economy	16800.00
0005433868612	32677	Economy	16800.00
0005433868594	32677	Economy	16800.00
0005433868613	32677	Economy	16800.00
0005433868621	32677	Economy	16800.00
0005433868597	32677	Economy	16800.00
0005433868611	32677	Economy	16800.00
0005433868616	32677	Economy	16800.00
0005433868608	32677	Economy	16800.00
0005433868606	32677	Economy	16800.00
0005433868614	32677	Economy	16800.00
0005433868610	32677	Economy	16800.00
0005433868602	32677	Economy	16800.00
0005433868615	32677	Economy	16800.00
0005433868598	32677	Economy	16800.00
0005433868626	32677	Economy	16800.00
0005433868625	32677	Economy	16800.00
0005435860469	32677	Economy	16800.00
0005433868595	32677	Economy	16800.00
0005433868596	32677	Economy	16800.00
0005432799439	12104	Economy	4900.00
0005432799308	12104	Economy	4900.00
0005432799350	12104	Economy	4900.00
0005432799333	12104	Economy	4400.00
0005432799368	12104	Economy	4400.00
0005432799194	12104	Economy	4400.00
0005432799332	12104	Economy	4400.00
0005432799415	12104	Economy	4400.00
0005432799341	12104	Economy	4400.00
0005432799195	12104	Economy	4400.00
0005432799384	12104	Economy	4400.00
0005432799311	12104	Economy	4400.00
0005432799385	12104	Economy	4400.00
0005432799295	12104	Economy	4400.00
0005432799426	12104	Economy	4400.00
0005432799421	12104	Economy	4400.00
0005432799239	12104	Economy	4400.00
0005432799330	12104	Economy	4400.00
0005432799327	12104	Economy	4400.00
0005432799226	12104	Economy	4400.00
0005432799240	12104	Economy	4400.00
0005432799349	12104	Economy	4400.00
0005432799491	12104	Economy	4400.00
0005432799359	12104	Economy	4400.00
0005432799352	12104	Economy	4400.00
0005432799313	12104	Economy	4400.00
0005432799227	12104	Economy	4400.00
0005432799274	12104	Economy	4400.00
0005432799196	12104	Economy	4400.00
0005432799334	12104	Economy	4400.00
0005432799312	12104	Economy	4400.00
0005432799224	12104	Economy	4400.00
0005432799249	12104	Economy	4400.00
0005432799400	12104	Economy	4400.00
0005432799437	12104	Economy	4400.00
0005432799331	12104	Economy	4400.00
0005432799280	12104	Economy	4400.00
0005432799361	12104	Economy	4400.00
0005432799538	12104	Economy	4400.00
0005432799490	12104	Economy	4400.00
0005432799223	12104	Economy	4400.00
0005432799383	12104	Economy	4400.00
0005432799570	14820	Economy	4900.00
0005432799579	14820	Economy	4400.00
0005432799566	14820	Economy	4400.00
0005432799588	14820	Economy	4400.00
0005432799580	14820	Economy	4400.00
0005432799587	14820	Economy	4400.00
0005432799564	14820	Economy	4400.00
0005432799578	14820	Economy	4400.00
0005432799576	14820	Economy	4400.00
0005432799563	14820	Economy	4400.00
0005432799581	14820	Economy	4400.00
0005432799584	14820	Economy	4400.00
0005432799572	14820	Economy	4400.00
0005432799575	14820	Economy	4400.00
0005432799577	14820	Economy	4400.00
0005432799565	14820	Economy	4400.00
0005432799568	14820	Economy	4400.00
0005432799569	14820	Economy	4400.00
0005432799586	14820	Economy	4400.00
0005432799562	14820	Economy	4400.00
0005432799573	14820	Economy	4400.00
0005432799583	14820	Economy	4400.00
0005432799582	14820	Economy	4400.00
0005432799574	14820	Economy	4400.00
0005432799567	14820	Economy	4400.00
0005432799571	14820	Economy	4400.00
0005432799585	14820	Economy	4400.00
0005434408076	7089	Business	49100.00
0005435310997	7089	Business	49100.00
0005434408060	7089	Business	49100.00
0005434299691	7089	Business	49100.00
0005434408113	7089	Business	49100.00
0005435310975	7089	Business	49100.00
0005434408081	7089	Business	49100.00
0005434408084	7089	Business	49100.00
0005432153972	7089	Business	49100.00
0005432108263	7089	Business	49100.00
0005432153976	7089	Business	49100.00
0005434408118	7089	Business	49100.00
0005434299675	7089	Economy	16400.00
0005434408062	7089	Economy	16400.00
0005434299681	7089	Economy	16400.00
0005434408121	7089	Economy	16400.00
0005434408119	7089	Economy	16400.00
0005434408071	7089	Economy	16400.00
0005434408085	7089	Economy	16400.00
0005434299686	7089	Economy	16400.00
0005435311012	7089	Economy	16400.00
0005434408082	7089	Economy	16400.00
0005434299682	7089	Economy	16400.00
0005434408125	7089	Economy	16400.00
0005432153977	7089	Economy	16400.00
0005434408120	7089	Economy	16400.00
0005434299688	7089	Economy	16400.00
0005435293235	7089	Economy	16400.00
0005434408069	7089	Economy	16400.00
0005432153971	7089	Economy	16400.00
0005434299689	7089	Economy	16400.00
0005434408103	7089	Economy	16400.00
0005434299676	7089	Economy	16400.00
0005434408075	7089	Economy	16400.00
0005434408122	7089	Economy	16400.00
0005435311005	7089	Economy	16400.00
0005435293199	7089	Economy	16400.00
0005434408115	7089	Economy	16400.00
0005435293212	7089	Economy	16400.00
0005434408083	7089	Economy	16400.00
0005434408073	7089	Economy	16400.00
0005435293202	7089	Economy	16400.00
0005435310964	7089	Economy	16400.00
0005434299685	7089	Economy	16400.00
0005434408104	7089	Economy	16400.00
0005435293240	7089	Economy	16400.00
0005434408101	7089	Economy	16400.00
0005434408111	7089	Economy	16400.00
0005434408098	7089	Economy	16400.00
0005435293229	7089	Economy	16400.00
0005434408091	7089	Economy	16400.00
0005432153974	7089	Economy	16400.00
0005434299680	7089	Economy	18000.00
0005435310974	7089	Economy	18000.00
0005434408067	7089	Economy	18000.00
0005434408096	7089	Economy	18000.00
0005434299673	7089	Economy	18000.00
0005434299677	7089	Economy	18000.00
0005434408089	7089	Economy	16400.00
0005435293200	7089	Economy	16400.00
0005434299684	7089	Economy	16400.00
0005434299679	7089	Economy	16400.00
0005435293205	7089	Economy	16400.00
0005435310995	7089	Economy	16400.00
0005434299678	7089	Economy	16400.00
0005435311011	7089	Economy	16400.00
0005434299672	7089	Economy	16400.00
0005434408099	7089	Economy	16400.00
0005432153978	7089	Economy	16400.00
0005434408063	7089	Economy	16400.00
0005434408064	7089	Economy	16400.00
0005434408077	7089	Economy	16400.00
0005432108264	7089	Economy	16400.00
0005435311007	7089	Economy	16400.00
0005434299674	7089	Economy	16400.00
0005435310994	7089	Economy	16400.00
0005435311000	7089	Economy	16400.00
0005434408110	7089	Economy	16400.00
0005435311009	7089	Economy	16400.00
0005435311016	7089	Economy	16400.00
0005434408068	7089	Economy	16400.00
0005434408079	7089	Economy	16400.00
0005434408093	7089	Economy	16400.00
0005434299683	7089	Economy	16400.00
0005434408112	7089	Economy	16400.00
0005434408097	7089	Economy	16400.00
0005434408092	7089	Economy	16400.00
0005434408106	7089	Economy	16400.00
0005434408124	7089	Economy	16400.00
0005434299693	7089	Economy	16400.00
0005434408102	7089	Economy	16400.00
0005434408105	7089	Economy	16400.00
0005435293201	7089	Economy	16400.00
0005434408107	7089	Economy	16400.00
0005434408114	7089	Economy	16400.00
0005434408087	7089	Economy	16400.00
0005434408072	7089	Economy	16400.00
0005434408123	7089	Economy	16400.00
0005434408117	7089	Economy	16400.00
0005434408070	7089	Economy	16400.00
0005432153975	7089	Economy	16400.00
0005434408116	7089	Economy	16400.00
0005434408108	7089	Economy	16400.00
0005434408078	7089	Economy	16400.00
0005434408074	7089	Economy	16400.00
0005434299670	7089	Economy	16400.00
0005434408086	7089	Economy	16400.00
0005434408066	7089	Economy	16400.00
0005434408094	7089	Economy	16400.00
0005434408090	7089	Economy	16400.00
0005435293209	7089	Economy	16400.00
0005434408061	7089	Economy	16400.00
0005434299687	7089	Economy	16400.00
0005434408109	7089	Economy	16400.00
0005434299692	7089	Economy	16400.00
0005434408080	7089	Economy	16400.00
0005434408088	7089	Economy	16400.00
0005434299671	7089	Economy	16400.00
0005435310965	7089	Economy	16400.00
0005435293241	7089	Economy	16400.00
0005434408065	7089	Economy	16400.00
0005435310978	7089	Economy	16400.00
0005435293204	7089	Economy	16400.00
0005435311017	7089	Economy	16400.00
0005432108262	7089	Economy	16400.00
0005434408100	7089	Economy	16400.00
0005435293228	7089	Economy	16400.00
0005434408095	7089	Economy	16400.00
0005434299690	7089	Economy	16400.00
0005432153973	7089	Economy	16400.00
0005432058401	26909	Business	49100.00
0005435293322	26909	Business	49100.00
0005434299541	26909	Business	49100.00
0005434299514	26909	Business	49100.00
0005434407545	26909	Business	49100.00
0005434407491	26909	Business	49100.00
0005435311113	26909	Business	49100.00
0005434299432	26909	Business	49100.00
0005434299491	26909	Business	49100.00
0005434299425	26909	Business	49100.00
0005435311105	26909	Economy	16400.00
0005434407445	26909	Economy	16400.00
0005434299553	26909	Economy	16400.00
0005434407604	26909	Economy	16400.00
0005434407602	26909	Economy	16400.00
0005434407501	26909	Economy	16400.00
0005434407360	26909	Economy	16400.00
0005434299535	26909	Economy	16400.00
0005434407560	26909	Economy	16400.00
0005434407361	26909	Economy	16400.00
0005434407776	26909	Economy	16400.00
0005434407590	26909	Economy	16400.00
0005435311106	26909	Economy	16400.00
0005434407667	26909	Economy	16400.00
0005434407335	26909	Economy	16400.00
0005434407368	26909	Economy	16400.00
0005435311108	26909	Economy	16400.00
0005434407726	26909	Economy	16400.00
0005434407493	26909	Economy	16400.00
0005434407739	26909	Economy	16400.00
0005434407241	26909	Economy	16400.00
0005434299467	26909	Economy	16400.00
0005432058399	26909	Economy	16400.00
0005434299460	26909	Economy	16400.00
0005435293319	26909	Economy	16400.00
0005434407259	26909	Economy	16400.00
0005434299461	26909	Economy	16400.00
0005434299544	26909	Economy	16400.00
0005434299550	26909	Economy	16400.00
0005434299574	26909	Economy	16400.00
0005435293318	26909	Economy	16400.00
0005434407350	26909	Economy	16400.00
0005435311107	26909	Economy	16400.00
0005434407513	26909	Economy	16400.00
0005434407652	26909	Economy	16400.00
0005434407592	26909	Economy	16400.00
0005434407473	26909	Economy	16400.00
0005434407364	26909	Economy	16400.00
0005434407503	26909	Economy	18000.00
0005434299533	26909	Economy	18000.00
0005435311112	26909	Economy	18000.00
0005434299438	26909	Economy	18000.00
0005434407263	26909	Economy	18000.00
0005434299552	26909	Economy	16400.00
0005434407621	26909	Economy	16400.00
0005434407668	26909	Economy	16400.00
0005435311114	26909	Economy	16400.00
0005435293314	26909	Economy	16400.00
0005434407345	26909	Economy	16400.00
0005435293317	26909	Economy	16400.00
0005434299545	26909	Economy	16400.00
0005435311111	26909	Economy	16400.00
0005434407382	26909	Economy	16400.00
0005434407498	26909	Economy	16400.00
0005434407488	26909	Economy	16400.00
0005434407357	26909	Economy	16400.00
0005435311110	26909	Economy	16400.00
0005434407554	26909	Economy	16400.00
0005434407416	26909	Economy	16400.00
0005434407417	26909	Economy	16400.00
0005434299518	26909	Economy	16400.00
0005434407521	26909	Economy	16400.00
0005434407250	26909	Economy	16400.00
0005434407462	26909	Economy	16400.00
0005435293313	26909	Economy	16400.00
0005434407519	26909	Economy	16400.00
0005435293312	26909	Economy	16400.00
0005434407265	26909	Economy	16400.00
0005434407472	26909	Economy	16400.00
0005434407504	26909	Economy	16400.00
0005434299481	26909	Economy	16400.00
0005434299549	26909	Economy	16400.00
0005434407591	26909	Economy	16400.00
0005434407381	26909	Economy	16400.00
0005434407603	26909	Economy	16400.00
0005435311109	26909	Economy	16400.00
0005434407358	26909	Economy	16400.00
0005434407582	26909	Economy	16400.00
0005434407193	26909	Economy	16400.00
0005434407264	26909	Economy	16400.00
0005434407369	26909	Economy	16400.00
0005434299494	26909	Economy	16400.00
0005434407355	26909	Economy	16400.00
0005435293315	26909	Economy	16400.00
0005434407455	26909	Economy	16400.00
0005434407598	26909	Economy	16400.00
0005434299479	26909	Economy	16400.00
0005435293320	26909	Economy	16400.00
0005435293323	26909	Economy	16400.00
0005434407518	26909	Economy	16400.00
0005435293321	26909	Economy	16400.00
0005434407492	26909	Economy	16400.00
0005434407551	26909	Economy	16400.00
0005434299490	26909	Economy	16400.00
0005434407546	26909	Economy	16400.00
0005435293324	26909	Economy	16400.00
0005434407512	26909	Economy	16400.00
0005432058400	26909	Economy	16400.00
0005434407533	26909	Economy	16400.00
0005432058398	26909	Economy	16400.00
0005435293316	26909	Economy	16400.00
0005434407484	26909	Economy	16400.00
0005434407502	26909	Economy	16400.00
0005434407497	26909	Economy	16400.00
0005432604552	6429	Economy	16500.00
0005432604540	6429	Economy	16500.00
0005432604575	6429	Economy	16500.00
0005432604564	6429	Economy	16500.00
0005432604566	6429	Economy	15000.00
0005434512135	6429	Economy	15000.00
0005432604538	6429	Economy	15000.00
0005432604563	6429	Economy	15000.00
0005432604560	6429	Economy	15000.00
0005432604535	6429	Economy	15000.00
0005432604556	6429	Economy	15000.00
0005432604570	6429	Economy	15000.00
0005434512133	6429	Economy	15000.00
0005432604569	6429	Economy	15000.00
0005432604568	6429	Economy	15000.00
0005432604551	6429	Economy	15000.00
0005432604555	6429	Economy	15000.00
0005432604546	6429	Economy	15000.00
0005432604565	6429	Economy	15000.00
0005432604548	6429	Economy	15000.00
0005432604574	6429	Economy	15000.00
0005432604572	6429	Economy	15000.00
0005432604547	6429	Economy	15000.00
0005432604544	6429	Economy	15000.00
0005432604549	6429	Economy	15000.00
0005432604553	6429	Economy	15000.00
0005432604571	6429	Economy	15000.00
0005432604550	6429	Economy	15000.00
0005432604545	6429	Economy	15000.00
0005432604554	6429	Economy	15000.00
0005432604567	6429	Economy	15000.00
0005432604559	6429	Economy	15000.00
0005432604542	6429	Economy	15000.00
0005434512134	6429	Economy	15000.00
0005432604573	6429	Economy	15000.00
0005432604562	6429	Economy	15000.00
0005432604576	6429	Economy	15000.00
0005432604558	6429	Economy	15000.00
0005432604541	6429	Economy	15000.00
0005432604537	6429	Economy	15000.00
0005432604543	6429	Economy	15000.00
0005432604561	6429	Economy	15000.00
0005432604536	6429	Economy	15000.00
0005432604534	6429	Economy	15000.00
0005432604557	6429	Economy	15000.00
0005432604539	6429	Economy	15000.00
0005435221521	21392	Economy	16500.00
0005435221061	21392	Economy	16500.00
0005432604327	21392	Economy	16500.00
0005432604202	21392	Economy	16500.00
0005432603991	21392	Economy	15000.00
0005432604187	21392	Economy	15000.00
0005432604328	21392	Economy	15000.00
0005432604189	21392	Economy	15000.00
0005432604251	21392	Economy	15000.00
0005432604217	21392	Economy	15000.00
0005434512101	21392	Economy	15000.00
0005434512104	21392	Economy	15000.00
0005434512102	21392	Economy	15000.00
0005432604165	21392	Economy	15000.00
0005434512103	21392	Economy	15000.00
0005432604075	21392	Economy	15000.00
0005432604176	21392	Economy	15000.00
0005432604124	21392	Economy	15000.00
0005432604164	21392	Economy	15000.00
0005435221060	21392	Economy	15000.00
0005432604089	21392	Economy	15000.00
0005432603940	21392	Economy	15000.00
0005432604123	21392	Economy	15000.00
0005432604125	21392	Economy	15000.00
0005432604312	21392	Economy	15000.00
0005432604173	21392	Economy	15000.00
0005432604126	21392	Economy	15000.00
0005432604215	21392	Economy	15000.00
0005434512081	21392	Economy	15000.00
0005435221520	21392	Economy	15000.00
0005432604250	21392	Economy	15000.00
0005432604116	21392	Economy	15000.00
0005432604188	21392	Economy	15000.00
0005432604163	21392	Economy	15000.00
0005432604088	21392	Economy	15000.00
0005432604321	21392	Economy	15000.00
0005432604174	21392	Economy	15000.00
0005432604216	21392	Economy	15000.00
0005432604203	21392	Economy	15000.00
0005432604150	21392	Economy	15000.00
0005432604115	21392	Economy	15000.00
0005434512105	21392	Economy	15000.00
0005432604254	21392	Economy	15000.00
0005432604255	21392	Economy	15000.00
0005433251637	15000	Business	18900.00
0005433251641	15000	Business	18900.00
0005433251649	15000	Business	18900.00
0005434906960	15000	Business	18900.00
0005434907107	15000	Business	18900.00
0005433251640	15000	Business	18900.00
0005434907029	15000	Business	18900.00
0005433251631	15000	Business	18900.00
0005434907110	15000	Business	18900.00
0005434906968	15000	Business	18900.00
0005434907132	15000	Business	18900.00
0005434907091	15000	Business	18900.00
0005434907097	15000	Economy	6300.00
0005433251626	15000	Economy	6300.00
0005434907078	15000	Economy	6300.00
0005434907145	15000	Economy	6300.00
0005434906936	15000	Economy	6300.00
0005434906778	15000	Economy	6300.00
0005434907087	15000	Economy	6300.00
0005434907098	15000	Economy	6900.00
0005434907032	15000	Economy	6300.00
0005434906937	15000	Economy	6900.00
0005433251629	15000	Economy	6900.00
0005434906735	15000	Economy	6900.00
0005433251636	15000	Economy	6900.00
0005433251646	15000	Economy	6300.00
0005434906841	15000	Economy	6300.00
0005434906994	15000	Economy	6300.00
0005434906974	15000	Economy	6300.00
0005433251650	15000	Economy	6300.00
0005434907053	15000	Economy	6300.00
0005434906961	15000	Economy	6300.00
0005434906962	15000	Economy	6300.00
0005434907073	15000	Economy	6300.00
0005434907027	15000	Economy	6300.00
0005434907128	15000	Economy	6300.00
0005434907039	15000	Economy	6300.00
0005434906920	15000	Economy	6300.00
0005434906969	15000	Economy	6300.00
0005433251639	15000	Economy	6300.00
0005433251651	15000	Economy	6300.00
0005433251643	15000	Economy	6300.00
0005434907024	15000	Economy	6300.00
0005434907086	15000	Economy	6300.00
0005433251635	15000	Economy	6300.00
0005433251645	15000	Economy	6300.00
0005434907146	15000	Economy	6300.00
0005433251624	15000	Economy	6300.00
0005433251647	15000	Economy	6300.00
0005433251642	15000	Economy	6300.00
0005434906883	15000	Economy	6300.00
0005433251652	15000	Economy	6300.00
0005434906975	15000	Economy	6300.00
0005433251630	15000	Economy	6300.00
0005434907050	15000	Economy	6300.00
0005434907070	15000	Economy	6300.00
0005433251627	15000	Economy	6300.00
0005434907109	15000	Economy	6300.00
0005434906897	15000	Economy	6300.00
0005434907028	15000	Economy	6300.00
0005434907096	15000	Economy	6300.00
0005433251628	15000	Economy	6300.00
0005434906967	15000	Economy	6300.00
0005434907106	15000	Economy	6300.00
0005434906842	15000	Economy	6300.00
0005433251638	15000	Economy	6300.00
0005433251634	15000	Economy	6300.00
0005433251653	15000	Economy	6300.00
0005434907051	15000	Economy	6300.00
0005433251644	15000	Economy	6300.00
0005434907077	15000	Economy	6300.00
0005433251632	15000	Economy	6300.00
0005434906979	15000	Economy	6300.00
0005434907141	15000	Economy	6300.00
0005434906884	15000	Economy	6300.00
0005433251633	15000	Economy	6300.00
0005434907085	15000	Economy	6300.00
0005433251625	15000	Economy	6300.00
0005434906888	15000	Economy	6300.00
0005433251648	15000	Economy	6300.00
0005434906861	15000	Economy	6300.00
0005434907142	15000	Economy	6300.00
0005434907043	15000	Economy	6300.00
0005434906932	15000	Economy	6300.00
0005433251429	25869	Business	18900.00
0005433251444	25869	Business	18900.00
0005433251303	25869	Business	18900.00
0005434907504	25869	Business	18900.00
0005434907489	25869	Business	18900.00
0005434907502	25869	Business	18900.00
0005434907508	25869	Business	18900.00
0005434907488	25869	Business	18900.00
0005433251259	25869	Business	18900.00
0005434907527	25869	Business	18900.00
0005434907522	25869	Business	18900.00
0005433251406	25869	Economy	6300.00
0005433251396	25869	Economy	6300.00
0005433251235	25869	Economy	6300.00
0005434907520	25869	Economy	6300.00
0005434907512	25869	Economy	6300.00
0005434907530	25869	Economy	6300.00
0005433251344	25869	Economy	6300.00
0005433251311	25869	Economy	6300.00
0005433251310	25869	Economy	6300.00
0005434907495	25869	Economy	6900.00
0005434907509	25869	Economy	6900.00
0005434907510	25869	Economy	6900.00
0005434907529	25869	Economy	6900.00
0005433251356	25869	Economy	6900.00
0005433251157	25869	Economy	6300.00
0005433251332	25869	Economy	6300.00
0005434907498	25869	Economy	6300.00
0005433251312	25869	Economy	6300.00
0005433251299	25869	Economy	6300.00
0005433251258	25869	Economy	6300.00
0005433251431	25869	Economy	6300.00
0005433251315	25869	Economy	6300.00
0005434907518	25869	Economy	6300.00
0005434907487	25869	Economy	6300.00
0005434907492	25869	Economy	6300.00
0005434907526	25869	Economy	6300.00
0005433251457	25869	Economy	6300.00
0005434907533	25869	Economy	6300.00
0005434907497	25869	Economy	6300.00
0005434907528	25869	Economy	6300.00
0005434907499	25869	Economy	6300.00
0005434907490	25869	Economy	6300.00
0005433251351	25869	Economy	6300.00
0005434907513	25869	Economy	6300.00
0005434907521	25869	Economy	6300.00
0005433251398	25869	Economy	6300.00
0005434907531	25869	Economy	6300.00
0005434907507	25869	Economy	6300.00
0005433251222	25869	Economy	6300.00
0005434907511	25869	Economy	6300.00
0005434907506	25869	Economy	6300.00
0005433251355	25869	Economy	6300.00
0005434907524	25869	Economy	6300.00
0005433251415	25869	Economy	6300.00
0005434907523	25869	Economy	6300.00
0005433251438	25869	Economy	6300.00
0005434907494	25869	Economy	6300.00
0005434907515	25869	Economy	6300.00
0005434907514	25869	Economy	6300.00
0005433251424	25869	Economy	6300.00
0005434907503	25869	Economy	6300.00
0005434907486	25869	Economy	6300.00
0005434907519	25869	Economy	6300.00
0005433251260	25869	Economy	6300.00
0005433251366	25869	Economy	6300.00
0005433251314	25869	Economy	6300.00
0005433251399	25869	Economy	6300.00
0005434907491	25869	Economy	6300.00
0005434907532	25869	Economy	6300.00
0005433251432	25869	Economy	6300.00
0005434907496	25869	Economy	6300.00
0005433251430	25869	Economy	6300.00
0005434907493	25869	Economy	6300.00
0005433251446	25869	Economy	6300.00
0005434907505	25869	Economy	6300.00
0005433251400	25869	Economy	6300.00
0005433251313	25869	Economy	6300.00
0005433251316	25869	Economy	6300.00
0005434907500	25869	Economy	6300.00
0005434907517	25869	Economy	6300.00
0005434907501	25869	Economy	6300.00
0005433251437	25869	Economy	6300.00
0005434907516	25869	Economy	6300.00
0005434907525	25869	Economy	6300.00
0005433251345	25869	Economy	6300.00
0005433008855	14179	Business	52300.00
0005433008873	14179	Business	52300.00
0005433008881	14179	Business	52300.00
0005433008878	14179	Business	52300.00
0005433008887	14179	Business	52300.00
0005433008868	14179	Economy	17400.00
0005433008859	14179	Economy	17400.00
0005433008858	14179	Economy	17400.00
0005433008860	14179	Economy	17400.00
0005433008880	14179	Economy	17400.00
0005433008850	14179	Economy	17400.00
0005433008867	14179	Economy	19200.00
0005433008844	14179	Economy	19200.00
0005433008871	14179	Economy	17400.00
0005433008863	14179	Economy	17400.00
0005433008862	14179	Economy	17400.00
0005433008856	14179	Economy	17400.00
0005433008847	14179	Economy	17400.00
0005433008866	14179	Economy	17400.00
0005433008845	14179	Economy	17400.00
0005433008876	14179	Economy	17400.00
0005433008854	14179	Economy	17400.00
0005433008888	14179	Economy	17400.00
0005433008848	14179	Economy	17400.00
0005433008874	14179	Economy	17400.00
0005433008879	14179	Economy	17400.00
0005433008889	14179	Economy	17400.00
0005433008877	14179	Economy	17400.00
0005433008852	14179	Economy	17400.00
0005433008864	14179	Economy	17400.00
0005433008872	14179	Economy	17400.00
0005433008875	14179	Economy	17400.00
0005433008846	14179	Economy	17400.00
0005433008865	14179	Economy	17400.00
0005433810517	14179	Economy	17400.00
0005433008883	14179	Economy	17400.00
0005433008851	14179	Economy	17400.00
0005433008857	14179	Economy	17400.00
0005433008861	14179	Economy	17400.00
0005433008886	14179	Economy	17400.00
0005433008849	14179	Economy	17400.00
0005433008869	14179	Economy	17400.00
0005433008853	14179	Economy	17400.00
0005433008870	14179	Economy	17400.00
0005433008885	14179	Economy	17400.00
0005433008882	14179	Economy	17400.00
0005433008884	14179	Economy	17400.00
0005433008326	22851	Business	52300.00
0005433008307	22851	Business	52300.00
0005433008478	22851	Business	52300.00
0005433008358	22851	Business	52300.00
0005433008352	22851	Business	52300.00
0005433008509	22851	Business	52300.00
0005433008486	22851	Economy	17400.00
0005433008384	22851	Economy	17400.00
0005433008411	22851	Economy	17400.00
0005433008517	22851	Economy	17400.00
0005433008253	22851	Economy	17400.00
0005433008458	22851	Economy	17400.00
0005433008477	22851	Economy	17400.00
0005433008413	22851	Economy	17400.00
0005433008368	22851	Economy	19200.00
0005433008608	22851	Economy	19200.00
0005433008339	22851	Economy	17400.00
0005433008350	22851	Economy	17400.00
0005433810571	22851	Economy	17400.00
0005433008385	22851	Economy	17400.00
0005433008414	22851	Economy	17400.00
0005433008609	22851	Economy	17400.00
0005433008351	22851	Economy	17400.00
0005433008281	22851	Economy	17400.00
0005433810569	22851	Economy	17400.00
0005433008386	22851	Economy	17400.00
0005433008467	22851	Economy	17400.00
0005433008579	22851	Economy	17400.00
0005433008446	22851	Economy	17400.00
0005433008472	22851	Economy	17400.00
0005433008322	22851	Economy	17400.00
0005433008510	22851	Economy	17400.00
0005433008390	22851	Economy	17400.00
0005433008389	22851	Economy	17400.00
0005433008447	22851	Economy	17400.00
0005433008443	22851	Economy	17400.00
0005433008547	22851	Economy	17400.00
0005433008248	22851	Economy	17400.00
0005433810568	22851	Economy	17400.00
0005433810567	22851	Economy	17400.00
0005433008349	22851	Economy	17400.00
0005433008323	22851	Economy	17400.00
0005433008369	22851	Economy	17400.00
0005433008208	22851	Economy	17400.00
0005433008525	22851	Economy	17400.00
0005433008459	22851	Economy	17400.00
0005433810570	22851	Economy	17400.00
0005433008397	22851	Economy	17400.00
0005433008412	22851	Economy	17400.00
0005433008249	22851	Economy	17400.00
0005433008395	22851	Economy	17400.00
0005433008393	22851	Economy	17400.00
0005433008523	22851	Economy	17400.00
0005433008548	22851	Economy	17400.00
0005433008394	22851	Economy	17400.00
0005433008468	22851	Economy	17400.00
0005435718926	15519	Business	85200.00
0005435718965	15519	Business	85200.00
0005435718950	15519	Business	85200.00
0005435718975	15519	Business	85200.00
0005435718958	15519	Business	85200.00
0005435718973	15519	Business	85200.00
0005435718938	15519	Business	85200.00
0005435718978	15519	Economy	28400.00
0005435718930	15519	Economy	28400.00
0005435718941	15519	Economy	28400.00
0005435718960	15519	Economy	28400.00
0005435718927	15519	Economy	28400.00
0005435718925	15519	Economy	28400.00
0005435718933	15519	Economy	28400.00
0005435718951	15519	Economy	31200.00
0005435718946	15519	Economy	31200.00
0005435718952	15519	Economy	28400.00
0005435718954	15519	Economy	28400.00
0005435718970	15519	Economy	28400.00
0005435718979	15519	Economy	28400.00
0005435718939	15519	Economy	28400.00
0005435718942	15519	Economy	28400.00
0005435718961	15519	Economy	28400.00
0005435718976	15519	Economy	28400.00
0005435718953	15519	Economy	28400.00
0005435718967	15519	Economy	28400.00
0005435718969	15519	Economy	28400.00
0005435718966	15519	Economy	28400.00
0005435718948	15519	Economy	28400.00
0005435718945	15519	Economy	28400.00
0005435718957	15519	Economy	28400.00
0005435718932	15519	Economy	28400.00
0005435718962	15519	Economy	28400.00
0005435718923	15519	Economy	28400.00
0005435718971	15519	Economy	28400.00
0005435718972	15519	Economy	28400.00
0005435718934	15519	Economy	28400.00
0005435718974	15519	Economy	28400.00
0005435718963	15519	Economy	28400.00
0005435718955	15519	Economy	28400.00
0005435718928	15519	Economy	28400.00
0005435718924	15519	Economy	28400.00
0005435718931	15519	Economy	28400.00
0005435718956	15519	Economy	28400.00
0005435718947	15519	Economy	28400.00
0005435718943	15519	Economy	28400.00
0005435718921	15519	Economy	28400.00
0005435718949	15519	Economy	28400.00
0005435718964	15519	Economy	28400.00
0005435718929	15519	Economy	28400.00
0005435718940	15519	Economy	28400.00
0005435718922	15519	Economy	28400.00
0005435718937	15519	Economy	28400.00
0005435718935	15519	Economy	28400.00
0005435718944	15519	Economy	28400.00
0005435718936	15519	Economy	28400.00
0005435718959	15519	Economy	28400.00
0005435718968	15519	Economy	28400.00
0005435718977	15519	Economy	28400.00
0005434925519	14913	Business	22900.00
0005434925628	14913	Business	22900.00
0005434925705	14913	Economy	7600.00
0005434925672	14913	Economy	7600.00
0005434925701	14913	Economy	7600.00
0005434925637	14913	Economy	8400.00
0005434925702	14913	Economy	8400.00
0005434925477	14913	Economy	8400.00
0005434925670	14913	Economy	8400.00
0005434925550	14913	Economy	7600.00
0005434925682	14913	Economy	7600.00
0005434925700	14913	Economy	7600.00
0005434925631	14913	Economy	7600.00
0005434925706	14913	Economy	7600.00
0005434925629	14913	Economy	7600.00
0005434925653	14913	Economy	7600.00
0005434925579	14913	Economy	7600.00
0005434925478	14913	Economy	7600.00
0005434925616	14913	Economy	7600.00
0005434925614	14913	Economy	7600.00
0005434925581	14913	Economy	7600.00
0005434925615	14913	Economy	7600.00
0005434925633	14913	Economy	7600.00
0005434925634	14913	Economy	7600.00
0005434925671	14913	Economy	7600.00
0005434925630	14913	Economy	7600.00
0005434925535	14913	Economy	7600.00
0005434925549	14913	Economy	7600.00
0005434925496	14913	Economy	7600.00
0005434925528	14913	Economy	7600.00
0005434925632	14913	Economy	7600.00
0005434925617	14913	Economy	7600.00
0005434925551	14913	Economy	7600.00
0005434925526	14913	Economy	7600.00
0005434925942	20553	Business	22900.00
0005434925950	20553	Business	22900.00
0005434925959	20553	Business	22900.00
0005434925938	20553	Business	22900.00
0005434925936	20553	Economy	7600.00
0005434925961	20553	Economy	7600.00
0005434925934	20553	Economy	7600.00
0005434925958	20553	Economy	7600.00
0005434925957	20553	Economy	7600.00
0005434925928	20553	Economy	7600.00
0005434925951	20553	Economy	8400.00
0005434925953	20553	Economy	8400.00
0005434925954	20553	Economy	7600.00
0005434925924	20553	Economy	7600.00
0005434925939	20553	Economy	7600.00
0005434925923	20553	Economy	7600.00
0005434925940	20553	Economy	7600.00
0005434925935	20553	Economy	7600.00
0005434925945	20553	Economy	7600.00
0005434925949	20553	Economy	7600.00
0005434925933	20553	Economy	7600.00
0005434925932	20553	Economy	7600.00
0005434925948	20553	Economy	7600.00
0005434925929	20553	Economy	7600.00
0005434925931	20553	Economy	7600.00
0005434925925	20553	Economy	7600.00
0005434925962	20553	Economy	7600.00
0005434925941	20553	Economy	7600.00
0005434925956	20553	Economy	7600.00
0005434925937	20553	Economy	7600.00
0005434925930	20553	Economy	7600.00
0005434925947	20553	Economy	7600.00
0005434925955	20553	Economy	7600.00
0005434925926	20553	Economy	7600.00
0005434925952	20553	Economy	7600.00
0005434925946	20553	Economy	7600.00
0005434925927	20553	Economy	7600.00
0005434925943	20553	Economy	7600.00
0005434925944	20553	Economy	7600.00
0005434925960	20553	Economy	7600.00
0005435487958	15847	Economy	8900.00
0005435999185	15847	Economy	8900.00
0005435487946	15847	Economy	8900.00
0005435487962	15847	Economy	8100.00
0005435487957	15847	Economy	8100.00
0005435487955	15847	Economy	8100.00
0005435487950	15847	Economy	8100.00
0005435487951	15847	Economy	8100.00
0005435487953	15847	Economy	8100.00
0005435487942	15847	Economy	8100.00
0005435999140	15847	Economy	8100.00
0005435999148	15847	Economy	8100.00
0005435487959	15847	Economy	8100.00
0005435487947	15847	Economy	8100.00
0005435999147	15847	Economy	8100.00
0005435487944	15847	Economy	8100.00
0005435487943	15847	Economy	8100.00
0005435487945	15847	Economy	8100.00
0005435487961	15847	Economy	8100.00
0005435487956	15847	Economy	8100.00
0005435999130	15847	Economy	8100.00
0005435999132	15847	Economy	8100.00
0005435999131	15847	Economy	8100.00
0005435999184	15847	Economy	8100.00
0005435487963	15847	Economy	8100.00
0005435487949	15847	Economy	8100.00
0005435999190	15847	Economy	8100.00
0005435999173	15847	Economy	8100.00
0005435487960	15847	Economy	8100.00
0005435487954	15847	Economy	8100.00
0005435487952	15847	Economy	8100.00
0005435999189	15847	Economy	8100.00
0005435999144	15847	Economy	8100.00
0005435487948	15847	Economy	8100.00
0005435487941	15847	Economy	8100.00
0005435487723	19704	Economy	8900.00
0005435487692	19704	Economy	8900.00
0005435487730	19704	Economy	8100.00
0005435999325	19704	Economy	8100.00
0005435999334	19704	Economy	8100.00
0005435999327	19704	Economy	8100.00
0005435487829	19704	Economy	8100.00
0005435999333	19704	Economy	8100.00
0005435487737	19704	Economy	8100.00
0005435999324	19704	Economy	8100.00
0005435487594	19704	Economy	8100.00
0005435999332	19704	Economy	8100.00
0005435999331	19704	Economy	8100.00
0005435487724	19704	Economy	8100.00
0005435999330	19704	Economy	8100.00
0005435999329	19704	Economy	8100.00
0005435487771	19704	Economy	8100.00
0005435487722	19704	Economy	8100.00
0005435999328	19704	Economy	8100.00
0005435487792	19704	Economy	8100.00
0005435487630	19704	Economy	8100.00
0005435487793	19704	Economy	8100.00
0005435487805	19704	Economy	8100.00
0005435999323	19704	Economy	8100.00
0005435487719	19704	Economy	8100.00
0005435487736	19704	Economy	8100.00
0005435487721	19704	Economy	8100.00
0005435487712	19704	Economy	8100.00
0005435999326	19704	Economy	8100.00
0005435487593	19704	Economy	8100.00
0005435487729	19704	Economy	8100.00
0005435487654	19704	Economy	8100.00
0005435487653	19704	Economy	8100.00
0005435839610	5977	Business	199300.00
0005435839616	5977	Business	199300.00
0005435472693	5977	Business	199300.00
0005435472680	5977	Business	199300.00
0005435839599	5977	Business	199300.00
0005432660830	5977	Business	199300.00
0005435839596	5977	Business	199300.00
0005435839620	5977	Business	199300.00
0005432658604	5977	Business	199300.00
0005435839619	5977	Business	199300.00
0005432142269	5977	Business	199300.00
0005435839613	5977	Economy	66400.00
0005435472694	5977	Economy	66400.00
0005435839602	5977	Economy	66400.00
0005432659719	5977	Economy	66400.00
0005435839612	5977	Economy	73100.00
0005435839617	5977	Economy	73100.00
0005435839601	5977	Economy	66400.00
0005432658605	5977	Economy	66400.00
0005432142268	5977	Economy	66400.00
0005435839595	5977	Economy	66400.00
0005435472681	5977	Economy	66400.00
0005435839591	5977	Economy	66400.00
0005435839607	5977	Economy	66400.00
0005435839605	5977	Economy	66400.00
0005432537053	5977	Economy	66400.00
0005435472679	5977	Economy	66400.00
0005435839604	5977	Economy	66400.00
0005432658602	5977	Economy	66400.00
0005432537057	5977	Economy	66400.00
0005435839609	5977	Economy	66400.00
0005435839615	5977	Economy	66400.00
0005432658603	5977	Economy	66400.00
0005435472785	5977	Economy	66400.00
0005435839603	5977	Economy	66400.00
0005435839608	5977	Economy	66400.00
0005432660829	5977	Economy	66400.00
0005435839618	5977	Economy	66400.00
0005435472755	5977	Economy	66400.00
0005435839598	5977	Economy	66400.00
0005435472663	5977	Economy	66400.00
0005435839600	5977	Economy	66400.00
0005435839614	5977	Economy	66400.00
0005435839611	5977	Economy	66400.00
0005435839593	5977	Economy	66400.00
0005435839592	5977	Economy	66400.00
0005435839594	5977	Economy	66400.00
0005435839606	5977	Economy	66400.00
0005435839597	5977	Economy	66400.00
0005435839450	18082	Business	199300.00
0005435472886	18082	Business	199300.00
0005435839431	18082	Business	199300.00
0005435839454	18082	Business	199300.00
0005435472884	18082	Business	199300.00
0005435839314	18082	Business	199300.00
0005435839352	18082	Economy	66400.00
0005435839364	18082	Economy	66400.00
0005432660796	18082	Economy	66400.00
0005435472897	18082	Economy	66400.00
0005435839426	18082	Economy	66400.00
0005435839384	18082	Economy	66400.00
0005435472888	18082	Economy	66400.00
0005435839313	18082	Economy	73100.00
0005435839414	18082	Economy	73100.00
0005435839288	18082	Economy	73100.00
0005435839435	18082	Economy	66400.00
0005435472899	18082	Economy	66400.00
0005435472887	18082	Economy	66400.00
0005435839345	18082	Economy	66400.00
0005435839336	18082	Economy	66400.00
0005432664119	18082	Economy	66400.00
0005435472895	18082	Economy	66400.00
0005435472892	18082	Economy	66400.00
0005435472894	18082	Economy	66400.00
0005435472896	18082	Economy	66400.00
0005435839451	18082	Economy	66400.00
0005435472891	18082	Economy	66400.00
0005432664128	18082	Economy	66400.00
0005435839344	18082	Economy	66400.00
0005432660807	18082	Economy	66400.00
0005435839430	18082	Economy	66400.00
0005435839316	18082	Economy	66400.00
0005432667437	18082	Economy	66400.00
0005435472890	18082	Economy	66400.00
0005432667438	18082	Economy	66400.00
0005435839404	18082	Economy	66400.00
0005435839406	18082	Economy	66400.00
0005435472883	18082	Economy	66400.00
0005435839405	18082	Economy	66400.00
0005432664118	18082	Economy	66400.00
0005435472898	18082	Economy	66400.00
0005435472893	18082	Economy	66400.00
0005435472885	18082	Economy	66400.00
0005435839438	18082	Economy	66400.00
0005432537071	18082	Economy	66400.00
0005432667447	18082	Economy	66400.00
0005435839351	18082	Economy	66400.00
0005435472889	18082	Economy	66400.00
0005433285355	23026	Business	15700.00
0005433285177	23026	Business	15700.00
0005433285320	23026	Economy	5200.00
0005433285209	23026	Economy	5200.00
0005433285251	23026	Economy	5200.00
0005433285143	23026	Economy	5200.00
0005435103962	23026	Economy	5200.00
0005433285305	23026	Economy	5200.00
0005433285304	23026	Economy	5200.00
0005433285146	23026	Economy	5200.00
0005433285086	23026	Economy	5200.00
0005433285266	23026	Economy	5200.00
0005435103965	23026	Economy	5200.00
0005435103966	23026	Economy	5200.00
0005433285116	23026	Economy	5200.00
0005433285319	23026	Economy	5700.00
0005433285165	23026	Economy	5200.00
0005433285166	23026	Economy	5200.00
0005433285180	23026	Economy	5200.00
0005433285178	23026	Economy	5200.00
0005435103963	23026	Economy	5200.00
0005433285232	23026	Economy	5200.00
0005433285157	23026	Economy	5200.00
0005433285090	23026	Economy	5200.00
0005433285176	23026	Economy	5200.00
0005433285117	23026	Economy	5200.00
0005433285290	23026	Economy	5200.00
0005433285267	23026	Economy	5200.00
0005433285139	23026	Economy	5200.00
0005433285224	23026	Economy	5200.00
0005433285302	23026	Economy	5200.00
0005433285175	23026	Economy	5200.00
0005433285149	23026	Economy	5200.00
0005433285138	23026	Economy	5200.00
0005433285144	23026	Economy	5200.00
0005433285148	23026	Economy	5200.00
0005433285252	23026	Economy	5200.00
0005435103964	23026	Economy	5200.00
0005433285142	23026	Economy	5200.00
0005433285091	23026	Economy	5200.00
0005433285111	23026	Economy	5200.00
0005433285356	23026	Economy	5200.00
0005435103967	23026	Economy	5200.00
0005433285243	23026	Economy	5200.00
0005433285483	32077	Business	15700.00
0005435103883	32077	Business	15700.00
0005433285478	32077	Business	15700.00
0005435103889	32077	Business	15700.00
0005433285480	32077	Business	15700.00
0005433285467	32077	Economy	5200.00
0005435103897	32077	Economy	5200.00
0005433285463	32077	Economy	5200.00
0005435103900	32077	Economy	5200.00
0005433285460	32077	Economy	5200.00
0005433285471	32077	Economy	5200.00
0005435103890	32077	Economy	5200.00
0005433285476	32077	Economy	5200.00
0005435103858	32077	Economy	5200.00
0005433285464	32077	Economy	5200.00
0005433285456	32077	Economy	5200.00
0005433285466	32077	Economy	5200.00
0005433285462	32077	Economy	5200.00
0005433285475	32077	Economy	5200.00
0005435103894	32077	Economy	5200.00
0005433285458	32077	Economy	5200.00
0005433285487	32077	Economy	5200.00
0005433285474	32077	Economy	5200.00
0005433285459	32077	Economy	5200.00
0005433285469	32077	Economy	5200.00
0005435103895	32077	Economy	5200.00
0005433285484	32077	Economy	5200.00
0005433285465	32077	Economy	5200.00
0005433285468	32077	Economy	5200.00
0005435103882	32077	Economy	5200.00
0005435103892	32077	Economy	5200.00
0005433285472	32077	Economy	5200.00
0005435103898	32077	Economy	5200.00
0005433285486	32077	Economy	5200.00
0005433285457	32077	Economy	5200.00
0005433285485	32077	Economy	5200.00
0005435103875	32077	Economy	5200.00
0005435103874	32077	Economy	5200.00
0005433285482	32077	Economy	5200.00
0005433285481	32077	Economy	5200.00
0005433285473	32077	Economy	5200.00
0005433285461	32077	Economy	5200.00
0005433285479	32077	Economy	5200.00
0005435103857	32077	Economy	5200.00
0005433285477	32077	Economy	5200.00
0005433285470	32077	Economy	5200.00
0005432892742	1475	Business	150400.00
0005432802504	1475	Business	150400.00
0005432892752	1475	Business	150400.00
0005432802503	1475	Business	150400.00
0005432892743	1475	Business	150400.00
0005432802530	1475	Business	150400.00
0005432892749	1475	Business	150400.00
0005432802528	1475	Economy	50100.00
0005432892730	1475	Economy	50100.00
0005432802515	1475	Economy	50100.00
0005432802519	1475	Economy	50100.00
0005432802505	1475	Economy	50100.00
0005433112351	1475	Economy	50100.00
0005432802506	1475	Economy	50100.00
0005432802525	1475	Economy	50100.00
0005432892735	1475	Economy	55200.00
0005432892734	1475	Economy	55200.00
0005433112355	1475	Economy	50100.00
0005432892738	1475	Economy	50100.00
0005433112356	1475	Economy	50100.00
0005432802501	1475	Economy	50100.00
0005432802529	1475	Economy	50100.00
0005432892748	1475	Economy	50100.00
0005433112360	1475	Economy	50100.00
0005432802527	1475	Economy	50100.00
0005432802514	1475	Economy	50100.00
0005432802522	1475	Economy	50100.00
0005432802513	1475	Economy	50100.00
0005432892727	1475	Economy	50100.00
0005432892741	1475	Economy	50100.00
0005432802523	1475	Economy	50100.00
0005432892744	1475	Economy	50100.00
0005432892731	1475	Economy	50100.00
0005432802509	1475	Economy	50100.00
0005432892726	1475	Economy	50100.00
0005432802517	1475	Economy	50100.00
0005432802520	1475	Economy	50100.00
0005432892733	1475	Economy	50100.00
0005432802526	1475	Economy	50100.00
0005432892728	1475	Economy	50100.00
0005432892736	1475	Economy	50100.00
0005432802516	1475	Economy	50100.00
0005432892737	1475	Economy	50100.00
0005432892751	1475	Economy	50100.00
0005432892739	1475	Economy	50100.00
0005433112353	1475	Economy	50100.00
0005432802531	1475	Economy	50100.00
0005432802511	1475	Economy	50100.00
0005432892750	1475	Economy	50100.00
0005433112358	1475	Economy	50100.00
0005432802521	1475	Economy	50100.00
0005433112357	1475	Economy	50100.00
0005433112359	1475	Economy	50100.00
0005432892740	1475	Economy	50100.00
0005432802510	1475	Economy	50100.00
0005433112354	1475	Economy	50100.00
0005432802512	1475	Economy	50100.00
0005433112361	1475	Economy	50100.00
0005432802502	1475	Economy	50100.00
0005432892732	1475	Economy	50100.00
0005433112352	1475	Economy	50100.00
0005432802518	1475	Economy	50100.00
0005432802524	1475	Economy	50100.00
0005432802507	1475	Economy	50100.00
0005432802508	1475	Economy	50100.00
0005433475686	23858	Economy	13500.00
0005433475680	23858	Economy	13500.00
0005435852590	23858	Economy	13500.00
0005433475689	23858	Economy	12300.00
0005433475677	23858	Economy	12300.00
0005435852585	23858	Economy	12300.00
0005435852589	23858	Economy	12300.00
0005433475697	23858	Economy	12300.00
0005433475695	23858	Economy	12300.00
0005433475704	23858	Economy	12300.00
0005433475679	23858	Economy	12300.00
0005433475694	23858	Economy	12300.00
0005435852593	23858	Economy	12300.00
0005433475685	23858	Economy	12300.00
0005433475690	23858	Economy	12300.00
0005433475703	23858	Economy	12300.00
0005433475691	23858	Economy	12300.00
0005435852587	23858	Economy	12300.00
0005435852588	23858	Economy	12300.00
0005435852592	23858	Economy	12300.00
0005433475676	23858	Economy	12300.00
0005435852591	23858	Economy	12300.00
0005433475696	23858	Economy	12300.00
0005433475702	23858	Economy	12300.00
0005435852586	23858	Economy	12300.00
0005435852584	23858	Economy	12300.00
0005432533275	30633	Business	42100.00
0005435213970	30633	Business	42100.00
0005432527813	30633	Business	42100.00
0005434067115	30633	Business	42100.00
0005432527534	30633	Business	42100.00
0005432527676	30633	Business	42100.00
0005434067415	30633	Business	42100.00
0005432527789	30633	Business	42100.00
0005432527822	30633	Business	42100.00
0005435213934	30633	Business	42100.00
0005432211546	30633	Business	42100.00
0005434067259	30633	Business	42100.00
0005434067596	30633	Business	42100.00
0005432527293	30633	Business	42100.00
0005432528147	30633	Business	42100.00
0005435213981	30633	Business	42100.00
0005432159887	30633	Business	42100.00
0005434067489	30633	Business	42100.00
0005435213982	30633	Business	42100.00
0005432527272	30633	Business	42100.00
0005435213989	30633	Comfort	23900.00
0005434067155	30633	Comfort	23900.00
0005432535809	30633	Comfort	23900.00
0005432527462	30633	Comfort	23900.00
0005434067416	30633	Comfort	23900.00
0005432527776	30633	Comfort	23900.00
0005434067177	30633	Comfort	23900.00
0005435213968	30633	Comfort	23900.00
0005432535821	30633	Comfort	23900.00
0005435213945	30633	Comfort	23900.00
0005432527265	30633	Comfort	23900.00
0005434067322	30633	Comfort	23900.00
0005432527351	30633	Comfort	23900.00
0005432527006	30633	Comfort	23900.00
0005435213977	30633	Comfort	23900.00
0005435213966	30633	Comfort	23900.00
0005434067255	30633	Comfort	23900.00
0005432159884	30633	Comfort	23900.00
0005435213991	30633	Comfort	23900.00
0005432535823	30633	Comfort	23900.00
0005432527867	30633	Comfort	23900.00
0005432527091	30633	Comfort	23900.00
0005434067214	30633	Comfort	23900.00
0005432159883	30633	Comfort	23900.00
0005435213949	30633	Comfort	23900.00
0005432527982	30633	Comfort	23900.00
0005435213979	30633	Comfort	23900.00
0005432527514	30633	Comfort	23900.00
0005432527523	30633	Comfort	23900.00
0005432527553	30633	Comfort	23900.00
0005434067431	30633	Comfort	23900.00
0005432527513	30633	Comfort	23900.00
0005435213937	30633	Comfort	23900.00
0005435213974	30633	Comfort	23900.00
0005434067094	30633	Comfort	23900.00
0005432527452	30633	Comfort	23900.00
0005434067277	30633	Comfort	23900.00
0005432527484	30633	Comfort	23900.00
0005432527812	30633	Comfort	23900.00
0005432533290	30633	Comfort	23900.00
0005435213976	30633	Comfort	23900.00
0005434067497	30633	Comfort	23900.00
0005432527143	30633	Comfort	23900.00
0005432527836	30633	Economy	14000.00
0005435213944	30633	Economy	14000.00
0005435213990	30633	Economy	14000.00
0005432527428	30633	Economy	14000.00
0005434067228	30633	Economy	14000.00
0005432527711	30633	Economy	14000.00
0005435213983	30633	Economy	14000.00
0005435213933	30633	Economy	14000.00
0005432528254	30633	Economy	14000.00
0005432527561	30633	Economy	14000.00
0005435213972	30633	Economy	14000.00
0005432527764	30633	Economy	14000.00
0005432527560	30633	Economy	14000.00
0005434067594	30633	Economy	14000.00
0005435213950	30633	Economy	14000.00
0005432527593	30633	Economy	14000.00
0005434067104	30633	Economy	14000.00
0005432527629	30633	Economy	14000.00
0005432527841	30633	Economy	14000.00
0005432527352	30633	Economy	14000.00
0005432527740	30633	Economy	14000.00
0005432535820	30633	Economy	14000.00
0005434067247	30633	Economy	14000.00
0005432527705	30633	Economy	14000.00
0005432527610	30633	Economy	14000.00
0005434067278	30633	Economy	14000.00
0005435213951	30633	Economy	14000.00
0005432533280	30633	Economy	14000.00
0005432535817	30633	Economy	14000.00
0005432527621	30633	Economy	14000.00
0005434067390	30633	Economy	14000.00
0005432527505	30633	Economy	14000.00
0005432527850	30633	Economy	14000.00
0005432528253	30633	Economy	14000.00
0005432527739	30633	Economy	14000.00
0005432527738	30633	Economy	14000.00
0005432527420	30633	Economy	14000.00
0005432527271	30633	Economy	14000.00
0005432528177	30633	Economy	14000.00
0005432211548	30633	Economy	14000.00
0005432527837	30633	Economy	14000.00
0005434067245	30633	Economy	14000.00
0005435725631	30633	Economy	14000.00
0005435213958	30633	Economy	14000.00
0005432527623	30633	Economy	14000.00
0005434067444	30633	Economy	14000.00
0005432528229	30633	Economy	14000.00
0005435213973	30633	Economy	14000.00
0005434067038	30633	Economy	14000.00
0005432527004	30633	Economy	15400.00
0005432527455	30633	Economy	14000.00
0005434067240	30633	Economy	15400.00
0005435213924	30633	Economy	14000.00
0005435213935	30633	Economy	14000.00
0005432527349	30633	Economy	14000.00
0005432527942	30633	Economy	15400.00
0005435630986	30633	Economy	15400.00
0005434067195	30633	Economy	15400.00
0005432527540	30633	Economy	14000.00
0005435213929	30633	Economy	14000.00
0005435213992	30633	Economy	14000.00
0005432527811	30633	Economy	14000.00
0005432527763	30633	Economy	14000.00
0005432527541	30633	Economy	14000.00
0005432527395	30633	Economy	14000.00
0005435630987	30633	Economy	14000.00
0005435213941	30633	Economy	14000.00
0005434067145	30633	Economy	14000.00
0005432527820	30633	Economy	14000.00
0005432527760	30633	Economy	14000.00
0005435213936	30633	Economy	14000.00
0005432527943	30633	Economy	14000.00
0005434067365	30633	Economy	14000.00
0005434067423	30633	Economy	14000.00
0005434067252	30633	Economy	14000.00
0005432527516	30633	Economy	14000.00
0005434067424	30633	Economy	14000.00
0005432428913	30633	Economy	14000.00
0005432527761	30633	Economy	14000.00
0005432527937	30633	Economy	14000.00
0005432527404	30633	Economy	14000.00
0005435213931	30633	Economy	14000.00
0005434067309	30633	Economy	14000.00
0005435213930	30633	Economy	14000.00
0005432159886	30633	Economy	14000.00
0005432211547	30633	Economy	14000.00
0005432526894	30633	Economy	14000.00
0005435213932	30633	Economy	14000.00
0005435213946	30633	Economy	14000.00
0005435213954	30633	Economy	14000.00
0005435213986	30633	Economy	14000.00
0005435725632	30633	Economy	14000.00
0005435213939	30633	Economy	14000.00
0005435213987	30633	Economy	14000.00
0005432527796	30633	Economy	14000.00
0005432528083	30633	Economy	14000.00
0005435213953	30633	Economy	14000.00
0005432527913	30633	Economy	14000.00
0005434067007	30633	Economy	14000.00
0005435213928	30633	Economy	14000.00
0005432527821	30633	Economy	14000.00
0005435213940	30633	Economy	14000.00
0005434067317	30633	Economy	14000.00
0005432527877	30633	Economy	14000.00
0005435213985	30633	Economy	14000.00
0005432527483	30633	Economy	14000.00
0005432527122	30633	Economy	14000.00
0005432527409	30633	Economy	14000.00
0005434067085	30633	Economy	14000.00
0005432527408	30633	Economy	14000.00
0005432527494	30633	Economy	14000.00
0005435213926	30633	Economy	14000.00
0005432528134	30633	Economy	14000.00
0005432527407	30633	Economy	14000.00
0005435213961	30633	Economy	14000.00
0005432527266	30633	Economy	14000.00
0005433656692	30633	Economy	14000.00
0005434067484	30633	Economy	14000.00
0005435213925	30633	Economy	14000.00
0005432527522	30633	Economy	14000.00
0005432533285	30633	Economy	14000.00
0005432428892	30633	Economy	14000.00
0005435213938	30633	Economy	14000.00
0005434067385	30633	Economy	14000.00
0005435213960	30633	Economy	14000.00
0005435630985	30633	Economy	14000.00
0005435213927	30633	Economy	14000.00
0005432527825	30633	Economy	14000.00
0005434067447	30633	Economy	14000.00
0005434067408	30633	Economy	14000.00
0005434067493	30633	Economy	14000.00
0005432527394	30633	Economy	14000.00
0005432527269	30633	Economy	14000.00
0005432528136	30633	Economy	14000.00
0005432527616	30633	Economy	14000.00
0005434067176	30633	Economy	14000.00
0005432527609	30633	Economy	14000.00
0005432527704	30633	Economy	14000.00
0005432527539	30633	Economy	14000.00
0005435725629	30633	Economy	14000.00
0005434067448	30633	Economy	14000.00
0005432535822	30633	Economy	14000.00
0005435213984	30633	Economy	15400.00
0005432527533	30633	Economy	15400.00
0005435213969	30633	Economy	15400.00
0005435213957	30633	Economy	14000.00
0005434067397	30633	Economy	14000.00
0005434067229	30633	Economy	14000.00
0005432527909	30633	Economy	14000.00
0005435213952	30633	Economy	14000.00
0005432527392	30633	Economy	14000.00
0005432527832	30633	Economy	14000.00
0005432527524	30633	Economy	14000.00
0005432211543	30633	Economy	14000.00
0005435213962	30633	Economy	14000.00
0005432527245	30633	Economy	14000.00
0005434067384	30633	Economy	14000.00
0005432527350	30633	Economy	14000.00
0005432211549	30633	Economy	14000.00
0005434067445	30633	Economy	14000.00
0005432527970	30633	Economy	14000.00
0005432527759	30633	Economy	14000.00
0005435213965	30633	Economy	14000.00
0005432535826	30633	Economy	14000.00
0005435213943	30633	Economy	14000.00
0005432528082	30633	Economy	14000.00
0005434067037	30633	Economy	14000.00
0005432527819	30633	Economy	14000.00
0005432527457	30633	Economy	14000.00
0005432527559	30633	Economy	14000.00
0005435213955	30633	Economy	14000.00
0005432535818	30633	Economy	14000.00
0005432527454	30633	Economy	14000.00
0005435213948	30633	Economy	14000.00
0005432527622	30633	Economy	14000.00
0005434066762	30633	Economy	14000.00
0005434067571	30633	Economy	14000.00
0005432527735	30633	Economy	14000.00
0005432527453	30633	Economy	14000.00
0005432533281	30633	Economy	14000.00
0005432527971	30633	Economy	14000.00
0005432527878	30633	Economy	14000.00
0005432527489	30633	Economy	14000.00
0005432527981	30633	Economy	14000.00
0005432428893	30633	Economy	14000.00
0005432527653	30633	Economy	14000.00
0005435213964	30633	Economy	14000.00
0005432527005	30633	Economy	14000.00
0005432527644	30633	Economy	14000.00
0005432211544	30633	Economy	14000.00
0005434067296	30633	Economy	14000.00
0005435213967	30633	Economy	14000.00
0005432528158	30633	Economy	14000.00
0005432527628	30633	Economy	14000.00
0005432527944	30633	Economy	14000.00
0005435213947	30633	Economy	14000.00
0005432535825	30633	Economy	14000.00
0005434067321	30633	Economy	14000.00
0005434067232	30633	Economy	14000.00
0005435725630	30633	Economy	14000.00
0005432527657	30633	Economy	14000.00
0005432527922	30633	Economy	14000.00
0005435213975	30633	Economy	14000.00
0005434067407	30633	Economy	14000.00
0005432527528	30633	Economy	14000.00
0005432527429	30633	Economy	14000.00
0005432527829	30633	Economy	14000.00
0005435213988	30633	Economy	14000.00
0005432533286	30633	Economy	14000.00
0005434067297	30633	Economy	14000.00
0005433656691	30633	Economy	14000.00
0005435213980	30633	Economy	14000.00
0005432527262	30633	Economy	14000.00
0005432527259	30633	Economy	14000.00
0005435213971	30633	Economy	14000.00
0005432528095	30633	Economy	14000.00
0005432527530	30633	Economy	14000.00
0005432159885	30633	Economy	14000.00
0005432528133	30633	Economy	14000.00
0005432527427	30633	Economy	14000.00
0005434067395	30633	Economy	14000.00
0005432528005	30633	Economy	14000.00
0005432211545	30633	Economy	14000.00
0005432527295	30633	Economy	14000.00
0005434067318	30633	Economy	14000.00
0005435213963	30633	Economy	14000.00
0005435213942	30633	Economy	14000.00
0005432533289	30633	Economy	14000.00
0005432527419	30633	Economy	14000.00
0005435213978	30633	Economy	14000.00
0005432527294	30633	Economy	14000.00
0005434067392	30633	Economy	14000.00
0005435213959	30633	Economy	14000.00
0005432527270	30633	Economy	14000.00
0005435725633	30633	Economy	14000.00
0005434067276	30633	Economy	14000.00
0005434067334	30633	Economy	14000.00
0005434067351	30633	Economy	14000.00
0005433656693	30633	Economy	14000.00
0005432527904	30633	Economy	14000.00
0005435213956	30633	Economy	14000.00
0005435652752	24865	Business	9800.00
0005435652883	24865	Business	9800.00
0005433368129	24865	Business	9800.00
0005433368137	24865	Business	9800.00
0005433368126	24865	Business	9800.00
0005435652874	24865	Business	9800.00
0005435652983	24865	Business	9800.00
0005435652973	24865	Business	9800.00
0005433368104	24865	Business	9800.00
0005433368118	24865	Business	9800.00
0005435652594	24865	Business	9800.00
0005433368110	24865	Economy	3300.00
0005435652964	24865	Economy	3300.00
0005433368116	24865	Economy	3300.00
0005435652971	24865	Economy	3300.00
0005435652951	24865	Economy	3300.00
0005435652960	24865	Economy	3300.00
0005433368130	24865	Economy	3300.00
0005435652873	24865	Economy	3300.00
0005435652884	24865	Economy	3300.00
0005433368124	24865	Economy	3300.00
0005435652929	24865	Economy	3600.00
0005435652861	24865	Economy	3600.00
0005435652968	24865	Economy	3600.00
0005433368114	24865	Economy	3600.00
0005433368103	24865	Economy	3600.00
0005435652916	24865	Economy	3300.00
0005433368132	24865	Economy	3300.00
0005433368115	24865	Economy	3300.00
0005435652871	24865	Economy	3300.00
0005433368122	24865	Economy	3300.00
0005435652838	24865	Economy	3300.00
0005435652857	24865	Economy	3300.00
0005433368139	24865	Economy	3300.00
0005435652946	24865	Economy	3300.00
0005433368121	24865	Economy	3300.00
0005433368120	24865	Economy	3300.00
0005435652875	24865	Economy	3300.00
0005433368113	24865	Economy	3300.00
0005435652693	24865	Economy	3300.00
0005433368138	24865	Economy	3300.00
0005435652900	24865	Economy	3300.00
0005433368134	24865	Economy	3300.00
0005435652970	24865	Economy	3300.00
0005433368128	24865	Economy	3300.00
0005435652921	24865	Economy	3300.00
0005433368108	24865	Economy	3300.00
0005435652753	24865	Economy	3300.00
0005435652978	24865	Economy	3300.00
0005435652950	24865	Economy	3300.00
0005435652942	24865	Economy	3300.00
0005435652757	24865	Economy	3300.00
0005435652949	24865	Economy	3300.00
0005433368106	24865	Economy	3300.00
0005433368125	24865	Economy	3300.00
0005435652799	24865	Economy	3300.00
0005433368136	24865	Economy	3300.00
0005433368135	24865	Economy	3300.00
0005435652979	24865	Economy	3300.00
0005435652798	24865	Economy	3300.00
0005433368131	24865	Economy	3300.00
0005435652980	24865	Economy	3300.00
0005435652927	24865	Economy	3300.00
0005435652928	24865	Economy	3300.00
0005435652767	24865	Economy	3300.00
0005433368111	24865	Economy	3300.00
0005433368117	24865	Economy	3300.00
0005435652987	24865	Economy	3300.00
0005435652870	24865	Economy	3300.00
0005435652890	24865	Economy	3300.00
0005435652977	24865	Economy	3300.00
0005435652879	24865	Economy	3300.00
0005435652969	24865	Economy	3300.00
0005435652915	24865	Economy	3300.00
0005433368123	24865	Economy	3300.00
0005433368112	24865	Economy	3300.00
0005433368107	24865	Economy	3300.00
0005433368109	24865	Economy	3300.00
0005435652858	24865	Economy	3300.00
0005435652954	24865	Economy	3300.00
0005435652877	24865	Economy	3300.00
0005433368127	24865	Economy	3300.00
0005433368119	24865	Economy	3300.00
0005433368133	24865	Economy	3300.00
0005435652876	24865	Economy	3300.00
0005435652899	24865	Economy	3300.00
0005433368105	24865	Economy	3300.00
0005435652593	24865	Economy	3300.00
0005434979971	2070	Economy	10500.00
0005434979973	2070	Economy	10500.00
0005434979974	2070	Economy	9500.00
0005434979979	2070	Economy	9500.00
0005434979981	2070	Economy	9500.00
0005435801714	2070	Economy	9500.00
0005434979964	2070	Economy	9500.00
0005434979967	2070	Economy	9500.00
0005434979987	2070	Economy	9500.00
0005434979963	2070	Economy	9500.00
0005434979978	2070	Economy	9500.00
0005434979980	2070	Economy	9500.00
0005434979970	2070	Economy	9500.00
0005434979972	2070	Economy	9500.00
0005434979988	2070	Economy	9500.00
0005434979989	2070	Economy	9500.00
0005434979982	2070	Economy	9500.00
0005434979977	2070	Economy	9500.00
0005434979984	2070	Economy	9500.00
0005434979961	2070	Economy	9500.00
0005434979968	2070	Economy	9500.00
0005434979985	2070	Economy	9500.00
0005434979990	2070	Economy	9500.00
0005434979962	2070	Economy	9500.00
0005434979986	2070	Economy	9500.00
0005434979966	2070	Economy	9500.00
0005434979976	2070	Economy	9500.00
0005435801715	2070	Economy	9500.00
0005434979983	2070	Economy	9500.00
0005434979960	2070	Economy	9500.00
0005434979975	2070	Economy	9500.00
0005434979965	2070	Economy	9500.00
0005434979969	2070	Economy	9500.00
0005434979663	23533	Economy	10500.00
0005434979628	23533	Economy	10500.00
0005434979848	23533	Economy	10500.00
0005434979692	23533	Economy	9500.00
0005435801686	23533	Economy	9500.00
0005434979674	23533	Economy	9500.00
0005434979600	23533	Economy	9500.00
0005434979758	23533	Economy	9500.00
0005434979843	23533	Economy	9500.00
0005434979659	23533	Economy	9500.00
0005434979627	23533	Economy	9500.00
0005434979632	23533	Economy	9500.00
0005435801681	23533	Economy	9500.00
0005434979675	23533	Economy	9500.00
0005434979633	23533	Economy	9500.00
0005434979673	23533	Economy	9500.00
0005434979761	23533	Economy	9500.00
0005434979702	23533	Economy	9500.00
0005434979605	23533	Economy	9500.00
0005434979601	23533	Economy	9500.00
0005434979697	23533	Economy	9500.00
0005434979638	23533	Economy	9500.00
0005434979639	23533	Economy	9500.00
0005434979622	23533	Economy	9500.00
0005435801685	23533	Economy	9500.00
0005434979579	23533	Economy	9500.00
0005434979711	23533	Economy	9500.00
0005434979693	23533	Economy	9500.00
0005435801682	23533	Economy	9500.00
0005434979698	23533	Economy	9500.00
0005434979726	23533	Economy	9500.00
0005434979558	23533	Economy	9500.00
0005434952555	2627	Economy	5300.00
0005434952554	2627	Economy	5300.00
0005434952552	2627	Economy	5300.00
0005434952553	2627	Economy	5300.00
0005433256424	2596	Economy	5300.00
0005434952501	28236	Economy	5300.00
0005434952522	28236	Economy	5300.00
0005433256436	28236	Economy	5300.00
0005434302866	19731	Economy	8700.00
0005434302868	19731	Economy	8700.00
0005434302872	19731	Economy	8700.00
0005433112384	19731	Economy	8700.00
0005434302865	19731	Economy	8700.00
0005434302867	19731	Economy	8700.00
0005433112385	19731	Economy	8700.00
0005434302871	19731	Economy	8700.00
0005433111520	19731	Economy	8700.00
0005433112351	20024	Economy	8700.00
0005433112356	20024	Economy	8700.00
0005433112357	20024	Economy	8700.00
0005433112359	20024	Economy	8700.00
0005433112361	20024	Economy	8700.00
0005433112358	20024	Economy	8700.00
0005433112354	20024	Economy	8700.00
0005433112355	20024	Economy	8700.00
0005433112360	20024	Economy	8700.00
0005433112353	20024	Economy	8700.00
0005433112352	20024	Economy	8700.00
0005434138147	11971	Business	9700.00
0005434137950	11971	Business	9700.00
0005434137821	11971	Business	9700.00
0005434137938	11971	Business	9700.00
0005434138171	11971	Business	9700.00
0005434137888	11971	Business	9700.00
0005434137765	11971	Business	9700.00
0005434138024	11971	Business	9700.00
0005434138174	11971	Business	9700.00
0005434137701	11971	Business	9700.00
0005434138260	11971	Business	9700.00
0005434137746	11971	Business	9700.00
0005434137928	11971	Economy	3200.00
0005434137593	11971	Economy	3200.00
0005434137942	11971	Economy	3200.00
0005434137793	11971	Economy	3200.00
0005434137927	11971	Economy	3200.00
0005434138246	11971	Economy	3200.00
0005434137909	11971	Economy	3200.00
0005434138123	11971	Economy	3200.00
0005434138120	11971	Economy	3200.00
0005434137775	11971	Economy	3200.00
0005434137749	11971	Economy	3500.00
0005434137991	11971	Economy	3500.00
0005434137979	11971	Economy	3500.00
0005434138051	11971	Economy	3500.00
0005434138146	11971	Economy	3500.00
0005434138217	11971	Economy	3200.00
0005434137772	11971	Economy	3200.00
0005434137861	11971	Economy	3200.00
0005434137810	11971	Economy	3200.00
0005434137908	11971	Economy	3200.00
0005434137828	11971	Economy	3200.00
0005434137864	11971	Economy	3200.00
0005434137811	11971	Economy	3200.00
0005434137945	11971	Economy	3200.00
0005434137833	11971	Economy	3200.00
0005434137574	11971	Economy	3200.00
0005434137897	11971	Economy	3200.00
0005434138057	11971	Economy	3200.00
0005434138005	11971	Economy	3200.00
0005434137956	11971	Economy	3200.00
0005434137887	11971	Economy	3200.00
0005434137946	11971	Economy	3200.00
0005434137806	11971	Economy	3200.00
0005434137728	11971	Economy	3200.00
0005434137666	11971	Economy	3200.00
0005434137980	11971	Economy	3200.00
0005434137844	11971	Economy	3200.00
0005434137838	11971	Economy	3200.00
0005434137884	11971	Economy	3200.00
0005434137914	11971	Economy	3200.00
0005434137820	11971	Economy	3200.00
0005434138070	11971	Economy	3200.00
0005434138241	11971	Economy	3200.00
0005434138038	11971	Economy	3200.00
0005434137832	11971	Economy	3200.00
0005434137943	11971	Economy	3200.00
0005434137819	11971	Economy	3200.00
0005434137774	11971	Economy	3200.00
0005434138129	11971	Economy	3200.00
0005434137937	11971	Economy	3200.00
0005434137702	11971	Economy	3200.00
0005434138177	11971	Economy	3200.00
0005434137700	11971	Economy	3200.00
0005434137790	11971	Economy	3200.00
0005434138178	11971	Economy	3200.00
0005434137770	11971	Economy	3200.00
0005434138067	11971	Economy	3200.00
0005434137955	11971	Economy	3200.00
0005434137907	11971	Economy	3200.00
0005434138058	11971	Economy	3200.00
0005434138022	11971	Economy	3200.00
0005434138327	11971	Economy	3200.00
0005434138329	11971	Economy	3200.00
0005434137973	11971	Economy	3200.00
0005434137604	11971	Economy	3200.00
0005434137935	11971	Economy	3200.00
0005434137826	11971	Economy	3200.00
0005434138066	11971	Economy	3200.00
0005434138115	11971	Economy	3200.00
0005434137982	11971	Economy	3200.00
0005434137913	11971	Economy	3200.00
0005434138175	11971	Economy	3200.00
0005434138004	11971	Economy	3200.00
0005434137750	11971	Economy	3200.00
0005434138170	11971	Economy	3200.00
0005434138563	28754	Business	9700.00
0005434138621	28754	Business	9700.00
0005434138570	28754	Business	9700.00
0005434138619	28754	Business	9700.00
0005434138604	28754	Business	9700.00
0005434138624	28754	Business	9700.00
0005434138579	28754	Business	9700.00
0005434138603	28754	Business	9700.00
0005434138626	28754	Economy	3200.00
0005434138622	28754	Economy	3200.00
0005434138628	28754	Economy	3200.00
0005434138584	28754	Economy	3200.00
0005434138589	28754	Economy	3200.00
0005434138593	28754	Economy	3200.00
0005434138630	28754	Economy	3200.00
0005434138564	28754	Economy	3200.00
0005434138559	28754	Economy	3500.00
0005434138598	28754	Economy	3500.00
0005434138565	28754	Economy	3500.00
0005434138573	28754	Economy	3500.00
0005434138557	28754	Economy	3500.00
0005434138614	28754	Economy	3200.00
0005434138609	28754	Economy	3200.00
0005434138562	28754	Economy	3200.00
0005434138576	28754	Economy	3200.00
0005434138595	28754	Economy	3200.00
0005434138586	28754	Economy	3200.00
0005434138590	28754	Economy	3200.00
0005434138601	28754	Economy	3200.00
0005434138578	28754	Economy	3200.00
0005434138567	28754	Economy	3200.00
0005434138611	28754	Economy	3200.00
0005434138597	28754	Economy	3200.00
0005434138561	28754	Economy	3200.00
0005434138558	28754	Economy	3200.00
0005434138613	28754	Economy	3200.00
0005434138554	28754	Economy	3200.00
0005434138599	28754	Economy	3200.00
0005434138582	28754	Economy	3200.00
0005434138560	28754	Economy	3200.00
0005434138623	28754	Economy	3200.00
0005434138587	28754	Economy	3200.00
0005434138585	28754	Economy	3200.00
0005434138588	28754	Economy	3200.00
0005434138615	28754	Economy	3200.00
0005434138606	28754	Economy	3200.00
0005434138555	28754	Economy	3200.00
0005434138602	28754	Economy	3200.00
0005434138625	28754	Economy	3200.00
0005434138577	28754	Economy	3200.00
0005434138594	28754	Economy	3200.00
0005434138592	28754	Economy	3200.00
0005434138612	28754	Economy	3200.00
0005434138610	28754	Economy	3200.00
0005434138575	28754	Economy	3200.00
0005434138574	28754	Economy	3200.00
0005434138607	28754	Economy	3200.00
0005434138581	28754	Economy	3200.00
0005434138566	28754	Economy	3200.00
0005434138553	28754	Economy	3200.00
0005434138600	28754	Economy	3200.00
0005434138618	28754	Economy	3200.00
0005434138620	28754	Economy	3200.00
0005434138556	28754	Economy	3200.00
0005434138627	28754	Economy	3200.00
0005434138583	28754	Economy	3200.00
0005434138617	28754	Economy	3200.00
0005434138605	28754	Economy	3200.00
0005434138596	28754	Economy	3200.00
0005434138572	28754	Economy	3200.00
0005434138591	28754	Economy	3200.00
0005434138568	28754	Economy	3200.00
0005434138608	28754	Economy	3200.00
0005434138580	28754	Economy	3200.00
0005434138631	28754	Economy	3200.00
0005434138569	28754	Economy	3200.00
0005434138571	28754	Economy	3200.00
0005434138616	28754	Economy	3200.00
0005434138629	28754	Economy	3200.00
0005434466483	6590	Economy	23000.00
0005434466488	6590	Economy	20900.00
0005434466485	6590	Economy	20900.00
0005435312794	6590	Economy	20900.00
0005435312798	6590	Economy	20900.00
0005434466478	6590	Economy	20900.00
0005434466489	6590	Economy	20900.00
0005435312801	6590	Economy	20900.00
0005434466484	6590	Economy	20900.00
0005435312793	6590	Economy	20900.00
0005434466486	6590	Economy	20900.00
0005434466487	6590	Economy	20900.00
0005435312795	6590	Economy	20900.00
0005435312792	6590	Economy	20900.00
0005434466480	6590	Economy	20900.00
0005434466482	6590	Economy	20900.00
0005435312803	6590	Economy	20900.00
0005435312802	6590	Economy	20900.00
0005434466492	6590	Economy	20900.00
0005434466491	6590	Economy	20900.00
0005435312797	6590	Economy	20900.00
0005434466481	6590	Economy	20900.00
0005434466490	6590	Economy	20900.00
0005434466479	6590	Economy	20900.00
0005435312796	6590	Economy	20900.00
0005434466493	6590	Economy	20900.00
0005433534512	6810	Economy	10900.00
0005435259735	6810	Economy	9900.00
0005433538926	6810	Economy	9900.00
0005435259745	6810	Economy	9900.00
0005433538921	6810	Economy	9900.00
0005433538925	6810	Economy	9900.00
0005435259751	6810	Economy	9900.00
0005435259744	6810	Economy	9900.00
0005435259736	6810	Economy	9900.00
0005433538920	6810	Economy	9900.00
0005433538927	6810	Economy	9900.00
0005433538924	6810	Economy	9900.00
0005435259753	6810	Economy	9900.00
0005433538922	6810	Economy	9900.00
0005433538923	6810	Economy	9900.00
0005435259752	6810	Economy	9900.00
0005433534511	6810	Economy	9900.00
0005433538835	25050	Economy	10900.00
0005433538839	25050	Economy	9900.00
0005433538842	25050	Economy	9900.00
0005433538871	25050	Economy	9900.00
0005433534492	25050	Economy	9900.00
0005433538877	25050	Economy	9900.00
0005433538873	25050	Economy	9900.00
0005435259782	25050	Economy	9900.00
0005433534497	25050	Economy	9900.00
0005433538836	25050	Economy	9900.00
0005435259784	25050	Economy	9900.00
0005433534488	25050	Economy	9900.00
0005433538840	25050	Economy	9900.00
0005433538838	25050	Economy	9900.00
0005433534500	25050	Economy	9900.00
0005433538874	25050	Economy	9900.00
0005435259785	25050	Economy	9900.00
0005435259783	25050	Economy	9900.00
0005433512000	834	Economy	16100.00
0005432922514	834	Economy	16100.00
0005432922509	834	Economy	14600.00
0005433512005	834	Economy	14600.00
0005433512004	834	Economy	14600.00
0005433512002	834	Economy	14600.00
0005433511999	834	Economy	14600.00
0005433512006	834	Economy	14600.00
0005433512001	834	Economy	14600.00
0005433512003	834	Economy	14600.00
0005432922510	834	Economy	14600.00
0005433512007	834	Economy	14600.00
0005433511952	16171	Economy	16100.00
0005433511939	16171	Economy	16100.00
0005433511906	16171	Economy	14600.00
0005432922548	16171	Economy	14600.00
0005433511930	16171	Economy	14600.00
0005433511922	16171	Economy	14600.00
0005433511931	16171	Economy	14600.00
0005432922549	16171	Economy	14600.00
0005433511946	16171	Economy	14600.00
0005432922550	16171	Economy	14600.00
0005433511938	16171	Economy	14600.00
0005433511951	16171	Economy	14600.00
0005432922551	16171	Economy	14600.00
0005432922553	16171	Economy	14600.00
0005433511907	16171	Economy	14600.00
0005432922552	16171	Economy	14600.00
0005433475735	4036	Economy	13500.00
0005435852554	4036	Economy	12300.00
0005433475728	4036	Economy	12300.00
0005433475736	4036	Economy	12300.00
0005433475731	4036	Economy	12300.00
0005433475729	4036	Economy	12300.00
0005435852577	4036	Economy	12300.00
0005433475733	4036	Economy	12300.00
0005433475732	4036	Economy	12300.00
0005435852576	4036	Economy	12300.00
0005433475734	4036	Economy	12300.00
0005435852578	4036	Economy	12300.00
0005433475730	4036	Economy	12300.00
0005435697524	3677	Economy	7900.00
0005435697507	3677	Economy	7200.00
0005435697528	3677	Economy	7200.00
0005435697514	3677	Economy	7200.00
0005434950555	3677	Economy	7200.00
0005435697512	3677	Economy	7200.00
0005434950559	3677	Economy	7200.00
0005435697504	3677	Economy	7200.00
0005435697516	3677	Economy	7200.00
0005435916152	3677	Economy	7200.00
0005435697520	3677	Economy	7200.00
0005435697522	3677	Economy	7200.00
0005435935047	3677	Economy	7200.00
0005435697515	3677	Economy	7200.00
0005435916153	3677	Economy	7200.00
0005435697510	3677	Economy	7200.00
0005435697531	3677	Economy	7200.00
0005435935054	3677	Economy	7200.00
0005434950557	3677	Economy	7200.00
0005435697506	3677	Economy	7200.00
0005435697530	3677	Economy	7200.00
0005435697519	3677	Economy	7200.00
0005435697527	3677	Economy	7200.00
0005435935042	3677	Economy	7200.00
0005435697508	3677	Economy	7200.00
0005434950558	3677	Economy	7200.00
0005435697521	3677	Economy	7200.00
0005435697526	3677	Economy	7200.00
0005435916160	3677	Economy	7200.00
0005435697505	3677	Economy	7200.00
0005435697509	3677	Economy	7200.00
0005435697511	3677	Economy	7200.00
0005435697525	3677	Economy	7200.00
0005435697523	3677	Economy	7200.00
0005435697518	3677	Economy	7200.00
0005435697517	3677	Economy	7200.00
0005435697529	3677	Economy	7200.00
0005435697513	3677	Economy	7200.00
0005434950556	3677	Economy	7200.00
0005434950508	16280	Economy	7900.00
0005435697051	16280	Economy	7900.00
0005434950504	16280	Economy	7900.00
0005435697111	16280	Economy	7900.00
0005434950497	16280	Economy	7200.00
0005435916185	16280	Economy	7200.00
0005435697050	16280	Economy	7200.00
0005435916186	16280	Economy	7200.00
0005435697211	16280	Economy	7200.00
0005435697292	16280	Economy	7200.00
0005435697235	16280	Economy	7200.00
0005435697265	16280	Economy	7200.00
0005435697306	16280	Economy	7200.00
0005435697182	16280	Economy	7200.00
0005435697177	16280	Economy	7200.00
0005435697212	16280	Economy	7200.00
0005435697185	16280	Economy	7200.00
0005435697236	16280	Economy	7200.00
0005435697208	16280	Economy	7200.00
0005435935062	16280	Economy	7200.00
0005434950506	16280	Economy	7200.00
0005434950486	16280	Economy	7200.00
0005434950505	16280	Economy	7200.00
0005435935064	16280	Economy	7200.00
0005435935063	16280	Economy	7200.00
0005435697145	16280	Economy	7200.00
0005435697333	16280	Economy	7200.00
0005435697112	16280	Economy	7200.00
0005435697210	16280	Economy	7200.00
0005434950496	16280	Economy	7200.00
0005435697174	16280	Economy	7200.00
0005434950518	16280	Economy	7200.00
0005435697307	16280	Economy	7200.00
0005435916184	16280	Economy	7200.00
0005435916187	16280	Economy	7200.00
0005435697313	16280	Economy	7200.00
0005435916188	16280	Economy	7200.00
0005435697252	16280	Economy	7200.00
0005435697181	16280	Economy	7200.00
0005435697209	16280	Economy	7200.00
0005434950503	16280	Economy	7200.00
0005434950514	16280	Economy	7200.00
0005435697281	16280	Economy	7200.00
0005435697027	16280	Economy	7200.00
0005435697178	16280	Economy	7200.00
0005435697245	16280	Economy	7200.00
0005432607592	3959	Economy	21300.00
0005433519486	3959	Economy	19300.00
0005432609757	3959	Economy	19300.00
0005432609755	3959	Economy	19300.00
0005433519487	3959	Economy	19300.00
0005432609756	3959	Economy	19300.00
0005434604918	3959	Economy	19300.00
0005433519488	3959	Economy	19300.00
0005433519484	3959	Economy	19300.00
0005434606850	3959	Economy	19300.00
0005432607591	3959	Economy	19300.00
0005432607590	3959	Economy	19300.00
0005435842326	3959	Economy	19300.00
0005434606848	3959	Economy	19300.00
0005434604919	3959	Economy	19300.00
0005432609758	3959	Economy	19300.00
0005432609759	3959	Economy	19300.00
0005434606849	3959	Economy	19300.00
0005432607593	3959	Economy	19300.00
0005433519485	3959	Economy	19300.00
0005434606851	3959	Economy	19300.00
0005434606803	22065	Economy	21300.00
0005433519440	22065	Economy	21300.00
0005435853621	22065	Economy	21300.00
0005433519464	22065	Economy	19300.00
0005433519463	22065	Economy	19300.00
0005433519443	22065	Economy	19300.00
0005433519438	22065	Economy	19300.00
0005434606817	22065	Economy	19300.00
0005434606812	22065	Economy	19300.00
0005435853622	22065	Economy	19300.00
0005433519459	22065	Economy	19300.00
0005434606818	22065	Economy	19300.00
0005434606813	22065	Economy	19300.00
0005434606805	22065	Economy	19300.00
0005434603019	22065	Economy	19300.00
0005433519437	22065	Economy	19300.00
0005435853623	22065	Economy	19300.00
0005434606804	22065	Economy	19300.00
0005434606789	22065	Economy	19300.00
0005433519444	22065	Economy	19300.00
0005435628743	770	Economy	3700.00
0005433348965	770	Economy	3700.00
0005433348959	770	Economy	3700.00
0005435628740	770	Economy	3700.00
0005433348953	770	Economy	3700.00
0005435628739	770	Economy	3700.00
0005435628741	770	Economy	3700.00
0005435628742	770	Economy	3700.00
0005433348979	770	Economy	3700.00
0005433348966	770	Economy	3700.00
0005433348970	770	Economy	3700.00
0005435628709	15956	Economy	3700.00
0005433349026	15956	Economy	3700.00
0005435628712	15956	Economy	3700.00
0005433349027	15956	Economy	3700.00
0005433349028	15956	Economy	3700.00
0005433349024	15956	Economy	3700.00
0005433349025	15956	Economy	3700.00
0005433349023	15956	Economy	3700.00
0005435628710	15956	Economy	3700.00
0005434445257	17161	Economy	7100.00
0005433158120	17161	Economy	7100.00
0005433159311	17161	Economy	7100.00
0005434446530	17161	Economy	7100.00
0005433158121	17161	Economy	7100.00
0005434446532	17161	Economy	7100.00
0005434446529	17161	Economy	7100.00
0005434445256	17161	Economy	7100.00
0005433159310	17161	Economy	7100.00
0005434446531	17161	Economy	7100.00
0005434445231	17646	Economy	7100.00
0005434445232	17646	Economy	7100.00
0005433159328	17646	Economy	7100.00
0005435383131	7885	Economy	5900.00
0005435383136	7885	Economy	5900.00
0005435383125	7885	Economy	5400.00
0005435383139	7885	Economy	5400.00
0005435383145	7885	Economy	5400.00
0005435132951	7885	Economy	5400.00
0005435383144	7885	Economy	5400.00
0005435132952	7885	Economy	5400.00
0005435383151	7885	Economy	5400.00
0005435132953	7885	Economy	5400.00
0005435132950	7885	Economy	5400.00
0005435383152	7885	Economy	5400.00
0005435132949	7885	Economy	5400.00
0005435383120	7885	Economy	5400.00
0005435383124	7885	Economy	5400.00
0005435383130	7885	Economy	5400.00
0005435132948	7885	Economy	5400.00
0005435132943	7885	Economy	5400.00
0005435132944	7885	Economy	5400.00
0005435132946	7885	Economy	5400.00
0005435132945	7885	Economy	5400.00
0005435132947	7885	Economy	5400.00
0005435383185	33115	Economy	5900.00
0005435132845	33115	Economy	5900.00
0005435132854	33115	Economy	5400.00
0005435132848	33115	Economy	5400.00
0005435132859	33115	Economy	5400.00
0005435132842	33115	Economy	5400.00
0005435132849	33115	Economy	5400.00
0005435132846	33115	Economy	5400.00
0005435132870	33115	Economy	5400.00
0005435383186	33115	Economy	5400.00
0005435383184	33115	Economy	5400.00
0005435132869	33115	Economy	5400.00
0005435132862	33115	Economy	5400.00
0005435132860	33115	Economy	5400.00
0005435132847	33115	Economy	5400.00
0005435132873	33115	Economy	5400.00
0005435383183	33115	Economy	5400.00
0005435132841	33115	Economy	5400.00
0005435132863	33115	Economy	5400.00
0005435132820	33115	Economy	5400.00
0005435160370	7489	Economy	13800.00
0005435160372	7489	Economy	12500.00
0005435160377	7489	Economy	12500.00
0005435160368	7489	Economy	12500.00
0005435160367	7489	Economy	12500.00
0005435160376	7489	Economy	12500.00
0005435160373	7489	Economy	12500.00
0005435390227	7489	Economy	12500.00
0005435390205	7489	Economy	12500.00
0005435390241	7489	Economy	12500.00
0005435160375	7489	Economy	12500.00
0005435390242	7489	Economy	12500.00
0005435160374	7489	Economy	12500.00
0005435390219	7489	Economy	12500.00
0005435390226	7489	Economy	12500.00
0005435160369	7489	Economy	12500.00
0005435160371	7489	Economy	12500.00
0005435390206	7489	Economy	12500.00
0005435160297	29565	Economy	12500.00
0005435160338	29565	Economy	12500.00
0005435390283	29565	Economy	12500.00
0005435160312	29565	Economy	12500.00
0005435160304	29565	Economy	12500.00
0005435390281	29565	Economy	12500.00
0005435390282	29565	Economy	12500.00
0005435390280	29565	Economy	12500.00
0005435390285	29565	Economy	12500.00
0005435390286	29565	Economy	12500.00
0005435160277	29565	Economy	12500.00
0005435160311	29565	Economy	12500.00
0005435160270	29565	Economy	12500.00
0005435160269	29565	Economy	12500.00
0005435390284	29565	Economy	12500.00
0005435160310	29565	Economy	12500.00
0005435160220	29565	Economy	12500.00
0005435160298	29565	Economy	12500.00
0005435160303	29565	Economy	12500.00
0005432398186	18466	Economy	4900.00
0005432394088	18466	Economy	4900.00
0005432394083	18466	Economy	4900.00
0005432398180	18466	Economy	4900.00
0005432394101	18466	Economy	4900.00
0005432398193	18466	Economy	4900.00
0005432398192	18466	Economy	4900.00
0005435178505	18466	Economy	4900.00
0005432398187	18466	Economy	4900.00
0005435178504	18466	Economy	4900.00
0005432398195	18466	Economy	4900.00
0005435178491	27151	Economy	4900.00
0005432400143	27151	Economy	4900.00
0005432400144	27151	Economy	4900.00
0005435178492	27151	Economy	4900.00
0005432398218	27151	Economy	4900.00
0005432400146	27151	Economy	4900.00
0005432400145	27151	Economy	4900.00
0005432398217	27151	Economy	4900.00
0005432398216	27151	Economy	4900.00
0005432639206	2233	Business	87300.00
0005432639201	2233	Business	87300.00
0005432865978	2233	Business	87300.00
0005432639213	2233	Business	87300.00
0005432865960	2233	Business	87300.00
0005432866003	2233	Business	87300.00
0005432865972	2233	Business	87300.00
0005432639216	2233	Business	87300.00
0005432639193	2233	Economy	29100.00
0005432639212	2233	Economy	29100.00
0005432866004	2233	Economy	29100.00
0005432639209	2233	Economy	29100.00
0005432639184	2233	Economy	29100.00
0005432866024	2233	Economy	29100.00
0005432639211	2233	Economy	29100.00
0005432639200	2233	Economy	29100.00
0005432865969	2233	Economy	29100.00
0005432866000	2233	Economy	32000.00
0005432865951	2233	Economy	29100.00
0005432639219	2233	Economy	29100.00
0005432866005	2233	Economy	29100.00
0005432639215	2233	Economy	29100.00
0005432865990	2233	Economy	29100.00
0005432866029	2233	Economy	29100.00
0005432865986	2233	Economy	29100.00
0005432639192	2233	Economy	29100.00
0005432639196	2233	Economy	29100.00
0005432639183	2233	Economy	29100.00
0005432639187	2233	Economy	29100.00
0005432639188	2233	Economy	29100.00
0005432865964	2233	Economy	29100.00
0005432865966	2233	Economy	29100.00
0005432639204	2233	Economy	29100.00
0005432639197	2233	Economy	29100.00
0005432639191	2233	Economy	29100.00
0005432865947	2233	Economy	29100.00
0005432865965	2233	Economy	29100.00
0005432639186	2233	Economy	29100.00
0005432639208	2233	Economy	29100.00
0005432866001	2233	Economy	29100.00
0005432866002	2233	Economy	29100.00
0005432639189	2233	Economy	29100.00
0005432865989	2233	Economy	29100.00
0005432639205	2233	Economy	29100.00
0005432865979	2233	Economy	29100.00
0005432639218	2233	Economy	29100.00
0005432639217	2233	Economy	29100.00
0005432865981	2233	Economy	29100.00
0005432639195	2233	Economy	29100.00
0005432639203	2233	Economy	29100.00
0005432865997	2233	Economy	29100.00
0005432865974	2233	Economy	29100.00
0005432865987	2233	Economy	29100.00
0005432639202	2233	Economy	29100.00
0005432865988	2233	Economy	29100.00
0005432639190	2233	Economy	29100.00
0005432639194	2233	Economy	29100.00
0005432639185	2233	Economy	29100.00
0005432865980	2233	Economy	29100.00
0005432639207	2233	Economy	29100.00
0005432639199	2233	Economy	29100.00
0005432639210	2233	Economy	29100.00
0005432639214	2233	Economy	29100.00
0005432639198	2233	Economy	29100.00
0005432865973	2233	Economy	29100.00
0005432865982	2233	Economy	29100.00
0005434191265	9755	Economy	4400.00
0005434191263	9755	Economy	4400.00
0005434191264	9755	Economy	4400.00
0005435103982	6527	Business	48400.00
0005434504422	6527	Business	48400.00
0005434504399	6527	Business	48400.00
0005434504423	6527	Business	48400.00
0005435103981	6527	Business	48400.00
0005434504417	6527	Economy	16100.00
0005434504419	6527	Economy	16100.00
0005434504392	6527	Economy	16100.00
0005434504385	6527	Economy	16100.00
0005434504401	6527	Economy	17800.00
0005434504388	6527	Economy	17800.00
0005434504396	6527	Economy	17800.00
0005434504420	6527	Economy	17800.00
0005434504415	6527	Economy	16100.00
0005434504404	6527	Economy	16100.00
0005435103979	6527	Economy	16100.00
0005434504390	6527	Economy	16100.00
0005434504403	6527	Economy	16100.00
0005434504414	6527	Economy	16100.00
0005434504402	6527	Economy	16100.00
0005434504411	6527	Economy	16100.00
0005434504384	6527	Economy	16100.00
0005434504410	6527	Economy	16100.00
0005434504387	6527	Economy	16100.00
0005434504400	6527	Economy	16100.00
0005434504394	6527	Economy	16100.00
0005434504406	6527	Economy	16100.00
0005434504391	6527	Economy	16100.00
0005434504421	6527	Economy	16100.00
0005434504407	6527	Economy	16100.00
0005434504398	6527	Economy	16100.00
0005434504393	6527	Economy	16100.00
0005434504386	6527	Economy	16100.00
0005434504416	6527	Economy	16100.00
0005434504389	6527	Economy	16100.00
0005434504418	6527	Economy	16100.00
0005434504412	6527	Economy	16100.00
0005435103980	6527	Economy	16100.00
0005434504408	6527	Economy	16100.00
0005434504413	6527	Economy	16100.00
0005434504395	6527	Economy	16100.00
0005434504409	6527	Economy	16100.00
0005434504383	6527	Economy	16100.00
0005434504397	6527	Economy	16100.00
0005434504405	6527	Economy	16100.00
0005434504164	22670	Business	48400.00
0005434504031	22670	Business	48400.00
0005434503837	22670	Business	48400.00
0005435103889	22670	Business	48400.00
0005435103895	22670	Business	48400.00
0005434503966	22670	Business	48400.00
0005435103874	22670	Business	48400.00
0005434503833	22670	Economy	16100.00
0005434503741	22670	Economy	16100.00
0005435103892	22670	Economy	16100.00
0005434504052	22670	Economy	16100.00
0005435103894	22670	Economy	16100.00
0005434503896	22670	Economy	16100.00
0005434503948	22670	Economy	17800.00
0005434503991	22670	Economy	16100.00
0005434503929	22670	Economy	16100.00
0005434504096	22670	Economy	16100.00
0005435103883	22670	Economy	16100.00
0005435103890	22670	Economy	16100.00
0005434503794	22670	Economy	16100.00
0005434503923	22670	Economy	16100.00
0005434504000	22670	Economy	16100.00
0005434504089	22670	Economy	16100.00
0005435103900	22670	Economy	16100.00
0005434504060	22670	Economy	16100.00
0005434504094	22670	Economy	16100.00
0005435103897	22670	Economy	16100.00
0005435103898	22670	Economy	16100.00
0005434503999	22670	Economy	16100.00
0005435103875	22670	Economy	16100.00
0005434504028	22670	Economy	16100.00
0005435103882	22670	Economy	16100.00
0005434504032	22670	Economy	16100.00
0005434504090	22670	Economy	16100.00
0005434504085	22670	Economy	16100.00
0005434503897	22670	Economy	16100.00
0005434504098	22670	Economy	16100.00
0005434504136	22670	Economy	16100.00
0005434503930	22670	Economy	16100.00
0005434504059	22670	Economy	16100.00
0005435103858	22670	Economy	16100.00
0005434504053	22670	Economy	16100.00
0005435103857	22670	Economy	16100.00
0005434503962	22670	Economy	16100.00
0005434504101	22670	Economy	16100.00
0005434503919	22670	Economy	16100.00
0005434504027	22670	Economy	16100.00
0005435800117	6426	Economy	16800.00
0005435800113	6426	Economy	15300.00
0005435800125	6426	Economy	15300.00
0005435800123	6426	Economy	15300.00
0005435800120	6426	Economy	15300.00
0005435800127	6426	Economy	15300.00
0005435800114	6426	Economy	15300.00
0005435800119	6426	Economy	15300.00
0005435800118	6426	Economy	15300.00
0005435800121	6426	Economy	15300.00
0005435800116	6426	Economy	15300.00
0005435800128	6426	Economy	15300.00
0005435800122	6426	Economy	15300.00
0005435800124	6426	Economy	15300.00
0005435800126	6426	Economy	15300.00
0005435800115	6426	Economy	15300.00
0005435653305	1651	Business	50000.00
0005433367773	1651	Business	50000.00
0005435653342	1651	Business	50000.00
0005435653314	1651	Business	50000.00
0005435653337	1651	Business	50000.00
0005433367763	1651	Business	50000.00
0005435653327	1651	Business	50000.00
0005435653301	1651	Business	50000.00
0005435653340	1651	Business	50000.00
0005435653312	1651	Economy	16700.00
0005435653303	1651	Economy	16700.00
0005435653332	1651	Economy	16700.00
0005435653309	1651	Economy	16700.00
0005433367902	1651	Economy	16700.00
0005435653298	1651	Economy	16700.00
0005435653299	1651	Economy	16700.00
0005435653297	1651	Economy	16700.00
0005435653320	1651	Economy	18300.00
0005433367924	1651	Economy	18300.00
0005435653341	1651	Economy	18300.00
0005435653344	1651	Economy	18300.00
0005435653333	1651	Economy	16700.00
0005433367788	1651	Economy	16700.00
0005435653302	1651	Economy	16700.00
0005435653329	1651	Economy	16700.00
0005435653313	1651	Economy	16700.00
0005435653346	1651	Economy	16700.00
0005435653323	1651	Economy	16700.00
0005435653338	1651	Economy	16700.00
0005433367886	1651	Economy	16700.00
0005433367617	1651	Economy	16700.00
0005433367767	1651	Economy	16700.00
0005433367762	1651	Economy	16700.00
0005435653330	1651	Economy	16700.00
0005435653306	1651	Economy	16700.00
0005435653315	1651	Economy	16700.00
0005435653331	1651	Economy	16700.00
0005433367735	1651	Economy	16700.00
0005435653322	1651	Economy	16700.00
0005433367768	1651	Economy	16700.00
0005435653319	1651	Economy	16700.00
0005433367684	1651	Economy	16700.00
0005433367847	1651	Economy	16700.00
0005433367618	1651	Economy	16700.00
0005435653307	1651	Economy	16700.00
0005435653295	1651	Economy	16700.00
0005435653343	1651	Economy	16700.00
0005435653336	1651	Economy	16700.00
0005435653321	1651	Economy	16700.00
0005433367738	1651	Economy	16700.00
0005435653304	1651	Economy	16700.00
0005433367810	1651	Economy	16700.00
0005435653345	1651	Economy	16700.00
0005435653308	1651	Economy	16700.00
0005433367846	1651	Economy	16700.00
0005435653310	1651	Economy	16700.00
0005433367802	1651	Economy	16700.00
0005435653347	1651	Economy	16700.00
0005435653335	1651	Economy	16700.00
0005435653348	1651	Economy	16700.00
0005435653316	1651	Economy	16700.00
0005433367685	1651	Economy	16700.00
0005435653317	1651	Economy	16700.00
0005435653318	1651	Economy	16700.00
0005433367887	1651	Economy	16700.00
0005433367756	1651	Economy	16700.00
0005435653328	1651	Economy	16700.00
0005435653324	1651	Economy	16700.00
0005433367698	1651	Economy	16700.00
0005435653296	1651	Economy	16700.00
0005435653300	1651	Economy	16700.00
0005435653339	1651	Economy	16700.00
0005433367809	1651	Economy	16700.00
0005433367934	1651	Economy	16700.00
0005435653325	1651	Economy	16700.00
0005435653311	1651	Economy	16700.00
0005435653326	1651	Economy	16700.00
0005435653334	1651	Economy	16700.00
0005435652949	21691	Business	50000.00
0005435652594	21691	Business	50000.00
0005435652883	21691	Business	50000.00
0005435652983	21691	Business	50000.00
0005435652928	21691	Business	50000.00
0005435652767	21691	Business	50000.00
0005433368113	21691	Business	50000.00
0005433368127	21691	Business	50000.00
0005435652929	21691	Business	50000.00
0005435652900	21691	Business	50000.00
0005435652858	21691	Business	50000.00
0005435652752	21691	Economy	16700.00
0005433368114	21691	Economy	16700.00
0005433368111	21691	Economy	16700.00
0005435652884	21691	Economy	16700.00
0005433368138	21691	Economy	16700.00
0005433368139	21691	Economy	16700.00
0005435652921	21691	Economy	16700.00
0005435652593	21691	Economy	18300.00
0005435652876	21691	Economy	18300.00
0005435652877	21691	Economy	18300.00
0005435652799	21691	Economy	18300.00
0005435652942	21691	Economy	18300.00
0005433368118	21691	Economy	16700.00
0005433368117	21691	Economy	16700.00
0005435652970	21691	Economy	16700.00
0005433368135	21691	Economy	16700.00
0005433368115	21691	Economy	16700.00
0005435652890	21691	Economy	16700.00
0005435652693	21691	Economy	16700.00
0005435652946	21691	Economy	16700.00
0005433368122	21691	Economy	16700.00
0005435652873	21691	Economy	16700.00
0005435652954	21691	Economy	16700.00
0005433368121	21691	Economy	16700.00
0005435652971	21691	Economy	16700.00
0005435652870	21691	Economy	16700.00
0005435652960	21691	Economy	16700.00
0005433368126	21691	Economy	16700.00
0005435652927	21691	Economy	16700.00
0005433368125	21691	Economy	16700.00
0005435652964	21691	Economy	16700.00
0005433368137	21691	Economy	16700.00
0005433368119	21691	Economy	16700.00
0005435652915	21691	Economy	16700.00
0005433368124	21691	Economy	16700.00
0005435652838	21691	Economy	16700.00
0005433368131	21691	Economy	16700.00
0005435652968	21691	Economy	16700.00
0005433368136	21691	Economy	16700.00
0005435652874	21691	Economy	16700.00
0005435652977	21691	Economy	16700.00
0005435652757	21691	Economy	16700.00
0005433368112	21691	Economy	16700.00
0005435652950	21691	Economy	16700.00
0005433368109	21691	Economy	16700.00
0005435652979	21691	Economy	16700.00
0005433368116	21691	Economy	16700.00
0005433368110	21691	Economy	16700.00
0005435652857	21691	Economy	16700.00
0005435652879	21691	Economy	16700.00
0005435652978	21691	Economy	16700.00
0005433368120	21691	Economy	16700.00
0005433368132	21691	Economy	16700.00
0005435652753	21691	Economy	16700.00
0005433368134	21691	Economy	16700.00
0005435652951	21691	Economy	16700.00
0005435652875	21691	Economy	16700.00
0005433368123	21691	Economy	16700.00
0005433368128	21691	Economy	16700.00
0005433368104	21691	Economy	16700.00
0005435652798	21691	Economy	16700.00
0005433368130	21691	Economy	16700.00
0005435652987	21691	Economy	16700.00
0005435652980	21691	Economy	16700.00
0005435652969	21691	Economy	16700.00
0005435652861	21691	Economy	16700.00
0005435652973	21691	Economy	16700.00
0005433368107	21691	Economy	16700.00
0005433368106	21691	Economy	16700.00
0005433368108	21691	Economy	16700.00
0005433368103	21691	Economy	16700.00
0005435652871	21691	Economy	16700.00
0005435652916	21691	Economy	16700.00
0005433368133	21691	Economy	16700.00
0005433368105	21691	Economy	16700.00
0005433368129	21691	Economy	16700.00
0005435652899	21691	Economy	16700.00
0005435627118	23809	Economy	11200.00
0005435312822	23223	Economy	23000.00
0005434466456	23223	Economy	23000.00
0005434466481	23223	Economy	20900.00
0005434466457	23223	Economy	20900.00
0005434466443	23223	Economy	20900.00
0005435312820	23223	Economy	20900.00
0005434466450	23223	Economy	20900.00
0005434466455	23223	Economy	20900.00
0005434466439	23223	Economy	20900.00
0005434466433	23223	Economy	20900.00
0005435312821	23223	Economy	20900.00
0005434466454	23223	Economy	20900.00
0005435312819	23223	Economy	20900.00
0005434466434	23223	Economy	20900.00
0005434466444	23223	Economy	20900.00
0005435312818	23223	Economy	20900.00
0005434466440	23223	Economy	20900.00
0005435312817	23223	Economy	20900.00
0005435788786	4155	Business	21500.00
0005433986233	4155	Business	21500.00
0005433986252	4155	Business	21500.00
0005433986247	4155	Business	21500.00
0005435788788	4155	Business	21500.00
0005433986229	4155	Business	21500.00
0005433986242	4155	Business	21500.00
0005433986228	4155	Business	21500.00
0005433986223	4155	Business	21500.00
0005433986239	4155	Business	21500.00
0005433986243	4155	Economy	7200.00
0005433986225	4155	Economy	7200.00
0005433986234	4155	Economy	7200.00
0005433986220	4155	Economy	7200.00
0005433986224	4155	Economy	7200.00
0005435788789	4155	Economy	7900.00
0005433986250	4155	Economy	7900.00
0005433986240	4155	Economy	7200.00
0005433986251	4155	Economy	7200.00
0005433986227	4155	Economy	7200.00
0005433986258	4155	Economy	7200.00
0005433986245	4155	Economy	7200.00
0005433986222	4155	Economy	7200.00
0005433986231	4155	Economy	7200.00
0005433986241	4155	Economy	7200.00
0005433986232	4155	Economy	7200.00
0005433986238	4155	Economy	7200.00
0005433986249	4155	Economy	7200.00
0005433986236	4155	Economy	7200.00
0005433986255	4155	Economy	7200.00
0005433986246	4155	Economy	7200.00
0005433986219	4155	Economy	7200.00
0005433986254	4155	Economy	7200.00
0005433986253	4155	Economy	7200.00
0005433986248	4155	Economy	7200.00
0005433986256	4155	Economy	7200.00
0005433986230	4155	Economy	7200.00
0005433986257	4155	Economy	7200.00
0005433986244	4155	Economy	7200.00
0005433986235	4155	Economy	7200.00
0005433986221	4155	Economy	7200.00
0005433986237	4155	Economy	7200.00
0005435788787	4155	Economy	7200.00
0005433986226	4155	Economy	7200.00
0005433985809	25681	Business	21500.00
0005433985707	25681	Business	21500.00
0005433985828	25681	Business	21500.00
0005433985810	25681	Business	21500.00
0005433985700	25681	Business	21500.00
0005433985633	25681	Economy	7200.00
0005433985928	25681	Economy	7200.00
0005433985634	25681	Economy	7200.00
0005433985732	25681	Economy	7200.00
0005433985696	25681	Economy	7200.00
0005433985655	25681	Economy	7200.00
0005433985716	25681	Economy	7900.00
0005433985858	25681	Economy	7900.00
0005433985841	25681	Economy	7900.00
0005433985871	25681	Economy	7200.00
0005433985731	25681	Economy	7200.00
0005433985629	25681	Economy	7200.00
0005433985730	25681	Economy	7200.00
0005433985695	25681	Economy	7200.00
0005433985811	25681	Economy	7200.00
0005433985607	25681	Economy	7200.00
0005433985628	25681	Economy	7200.00
0005433985807	25681	Economy	7200.00
0005433985855	25681	Economy	7200.00
0005433986021	25681	Economy	7200.00
0005433985729	25681	Economy	7200.00
0005433985708	25681	Economy	7200.00
0005433985872	25681	Economy	7200.00
0005433985706	25681	Economy	7200.00
0005433985818	25681	Economy	7200.00
0005435788766	25681	Economy	7200.00
0005433985870	25681	Economy	7200.00
0005433985608	25681	Economy	7200.00
0005433985723	25681	Economy	7200.00
0005433985833	25681	Economy	7200.00
0005433985641	25681	Economy	7200.00
0005433985773	25681	Economy	7200.00
0005433985719	25681	Economy	7200.00
0005433985654	25681	Economy	7200.00
0005433985694	25681	Economy	7200.00
0005433985739	25681	Economy	7200.00
0005433985759	25681	Economy	7200.00
0005433985622	25681	Economy	7200.00
0005433985701	25681	Economy	7200.00
0005433985635	25681	Economy	7200.00
0005433985814	25681	Economy	7200.00
0005433985930	25681	Economy	7200.00
0005433985819	25681	Economy	7200.00
0005433986040	25681	Economy	7200.00
0005434509115	21337	Economy	17000.00
0005434509108	21337	Economy	17000.00
0005434509142	21337	Economy	17000.00
0005434509148	21337	Economy	17000.00
0005434509140	21337	Economy	15500.00
0005434509138	21337	Economy	15500.00
0005434509114	21337	Economy	15500.00
0005434509123	21337	Economy	15500.00
0005434509120	21337	Economy	15500.00
0005434509143	21337	Economy	15500.00
0005434509127	21337	Economy	15500.00
0005434509141	21337	Economy	15500.00
0005433168396	21337	Economy	15500.00
0005434509136	21337	Economy	15500.00
0005433168397	21337	Economy	15500.00
0005433168393	21337	Economy	15500.00
0005433168399	21337	Economy	15500.00
0005434509111	21337	Economy	15500.00
0005434509117	21337	Economy	15500.00
0005433168400	21337	Economy	15500.00
0005433168395	21337	Economy	15500.00
0005433168398	21337	Economy	15500.00
0005434509147	21337	Economy	15500.00
0005433168401	21337	Economy	15500.00
0005434509112	21337	Economy	15500.00
0005433168394	21337	Economy	15500.00
0005434509137	21337	Economy	15500.00
0005434509129	21337	Economy	15500.00
0005434509126	21337	Economy	15500.00
0005434509128	21337	Economy	15500.00
0005434509121	21337	Economy	15500.00
0005432655482	17820	Business	18000.00
0005432667450	17820	Business	18000.00
0005432655508	17820	Business	18000.00
0005432661914	17820	Business	18000.00
0005432661915	17820	Business	18000.00
0005432869568	17820	Business	18000.00
0005434151725	17820	Business	18000.00
0005432655485	17820	Business	18000.00
0005432655502	17820	Business	18000.00
0005434151724	17820	Economy	6000.00
0005432869571	17820	Economy	6000.00
0005432660813	17820	Economy	6000.00
0005432657448	17820	Economy	6600.00
0005432659696	17820	Economy	6000.00
0005432655490	17820	Economy	6000.00
0005432869570	17820	Economy	6000.00
0005432659705	17820	Economy	6000.00
0005432657450	17820	Economy	6000.00
0005432655544	17820	Economy	6000.00
0005432655510	17820	Economy	6000.00
0005432655532	17820	Economy	6000.00
0005432655545	17820	Economy	6000.00
0005432655507	17820	Economy	6000.00
0005432658587	17820	Economy	6000.00
0005432655487	17820	Economy	6000.00
0005434151723	17820	Economy	6000.00
0005432661923	17820	Economy	6000.00
0005432869569	17820	Economy	6000.00
0005432655491	17820	Economy	6000.00
0005432655486	17820	Economy	6000.00
0005432667452	17820	Economy	6000.00
0005432655509	17820	Economy	6000.00
0005432655514	17820	Economy	6000.00
0005432655467	17820	Economy	6000.00
0005432659695	17820	Economy	6000.00
0005432658589	17820	Economy	6000.00
0005432655483	17820	Economy	6000.00
0005432660814	17820	Economy	6000.00
0005432660818	17820	Economy	6000.00
0005432655503	17820	Economy	6000.00
0005432655501	17820	Economy	6000.00
0005432658585	17820	Economy	6000.00
0005432660817	17820	Economy	6000.00
0005432667451	17820	Economy	6000.00
0005432666380	17820	Economy	6000.00
0005432655533	17820	Economy	6000.00
0005432655500	17820	Economy	6000.00
0005432658586	17820	Economy	6000.00
0005432659706	17820	Economy	6000.00
0005432869572	17820	Economy	6000.00
0005434151691	26306	Business	18000.00
0005432667464	26306	Business	18000.00
0005432658600	26306	Business	18000.00
0005432659718	26306	Business	18000.00
0005432660828	26306	Economy	6000.00
0005432655583	26306	Economy	6000.00
0005432659716	26306	Economy	6000.00
0005432659717	26306	Economy	6600.00
0005432655586	26306	Economy	6600.00
0005432657465	26306	Economy	6600.00
0005432665284	26306	Economy	6000.00
0005434151699	26306	Economy	6000.00
0005432655591	26306	Economy	6000.00
0005432655585	26306	Economy	6000.00
0005432657464	26306	Economy	6000.00
0005432658601	26306	Economy	6000.00
0005432869481	26306	Economy	6000.00
0005432655594	26306	Economy	6000.00
0005432657463	26306	Economy	6000.00
0005432655587	26306	Economy	6000.00
0005432655584	26306	Economy	6000.00
0005432655589	26306	Economy	6000.00
0005432655593	26306	Economy	6000.00
0005432655588	26306	Economy	6000.00
0005432660827	26306	Economy	6000.00
0005432665285	26306	Economy	6000.00
0005432655590	26306	Economy	6000.00
0005432666399	26306	Economy	6000.00
0005432655592	26306	Economy	6000.00
0005433438928	3070	Business	16100.00
0005432328971	3070	Business	16100.00
0005432328994	3070	Business	16100.00
0005432287219	3070	Business	16100.00
0005433438935	3070	Business	16100.00
0005432328976	3070	Business	16100.00
0005433438932	3070	Business	16100.00
0005432329017	3070	Economy	5400.00
0005432328986	3070	Economy	5400.00
0005432905099	3070	Economy	5400.00
0005433438933	3070	Economy	5400.00
0005432328972	3070	Economy	5400.00
0005432329013	3070	Economy	5400.00
0005432328983	3070	Economy	5400.00
0005432329003	3070	Economy	5400.00
0005432328992	3070	Economy	5900.00
0005432328984	3070	Economy	5900.00
0005432329001	3070	Economy	5400.00
0005432329012	3070	Economy	5400.00
0005433438934	3070	Economy	5400.00
0005432287224	3070	Economy	5400.00
0005432329004	3070	Economy	5400.00
0005432329007	3070	Economy	5400.00
0005432328979	3070	Economy	5400.00
0005432328995	3070	Economy	5400.00
0005432328981	3070	Economy	5400.00
0005432328998	3070	Economy	5400.00
0005432328978	3070	Economy	5400.00
0005432328987	3070	Economy	5400.00
0005433438930	3070	Economy	5400.00
0005432329015	3070	Economy	5400.00
0005432329008	3070	Economy	5400.00
0005432329016	3070	Economy	5400.00
0005432328996	3070	Economy	5400.00
0005432328990	3070	Economy	5400.00
0005432329002	3070	Economy	5400.00
0005432287220	3070	Economy	5400.00
0005432329014	3070	Economy	5400.00
0005433438926	3070	Economy	5400.00
0005432329000	3070	Economy	5400.00
0005432328989	3070	Economy	5400.00
0005432328975	3070	Economy	5400.00
0005432329010	3070	Economy	5400.00
0005433438929	3070	Economy	5400.00
0005432329009	3070	Economy	5400.00
0005433438931	3070	Economy	5400.00
0005432287222	3070	Economy	5400.00
0005432329011	3070	Economy	5400.00
0005433438936	3070	Economy	5400.00
0005432905118	3070	Economy	5400.00
0005432287221	3070	Economy	5400.00
0005432905127	3070	Economy	5400.00
0005432328980	3070	Economy	5400.00
0005432328982	3070	Economy	5400.00
0005432328973	3070	Economy	5400.00
0005433438927	3070	Economy	5400.00
0005432287225	3070	Economy	5400.00
0005432328977	3070	Economy	5400.00
0005432329006	3070	Economy	5400.00
0005432328985	3070	Economy	5400.00
0005432328991	3070	Economy	5400.00
0005432328999	3070	Economy	5400.00
0005432328993	3070	Economy	5400.00
0005432328974	3070	Economy	5400.00
0005432328988	3070	Economy	5400.00
0005432287223	3070	Economy	5400.00
0005432329005	3070	Economy	5400.00
0005432328997	3070	Economy	5400.00
0005432328638	31125	Business	16100.00
0005432328675	31125	Business	16100.00
0005432328527	31125	Business	16100.00
0005432905161	31125	Business	16100.00
0005432328591	31125	Business	16100.00
0005432328597	31125	Business	16100.00
0005432328677	31125	Business	16100.00
0005432905164	31125	Business	16100.00
0005432328578	31125	Business	16100.00
0005432328577	31125	Business	16100.00
0005432328548	31125	Economy	5400.00
0005432328674	31125	Economy	5400.00
0005432328461	31125	Economy	5400.00
0005432328433	31125	Economy	5400.00
0005432054323	31125	Economy	5400.00
0005432905162	31125	Economy	5400.00
0005432328596	31125	Economy	5400.00
0005433438879	31125	Economy	5400.00
0005432328520	31125	Economy	5900.00
0005432328413	31125	Economy	5900.00
0005432328614	31125	Economy	5400.00
0005433438841	31125	Economy	5400.00
0005432328526	31125	Economy	5400.00
0005432054325	31125	Economy	5400.00
0005432328603	31125	Economy	5400.00
0005432328488	31125	Economy	5400.00
0005432328636	31125	Economy	5400.00
0005432328686	31125	Economy	5400.00
0005432328460	31125	Economy	5400.00
0005432328678	31125	Economy	5400.00
0005432905163	31125	Economy	5400.00
0005432328374	31125	Economy	5400.00
0005432328547	31125	Economy	5400.00
0005432328613	31125	Economy	5400.00
0005432328622	31125	Economy	5400.00
0005432328713	31125	Economy	5400.00
0005432328368	31125	Economy	5400.00
0005432328764	31125	Economy	5400.00
0005432328371	31125	Economy	5400.00
0005432328581	31125	Economy	5400.00
0005432328590	31125	Economy	5400.00
0005432905160	31125	Economy	5400.00
0005432328523	31125	Economy	5400.00
0005432328573	31125	Economy	5400.00
0005432328522	31125	Economy	5400.00
0005432054324	31125	Economy	5400.00
0005432328437	31125	Economy	5400.00
0005432328667	31125	Economy	5400.00
0005432328685	31125	Economy	5400.00
0005432328334	31125	Economy	5400.00
0005432328434	31125	Economy	5400.00
0005432905159	31125	Economy	5400.00
0005433438851	31125	Economy	5400.00
0005432328661	31125	Economy	5400.00
0005432328602	31125	Economy	5400.00
0005432328704	31125	Economy	5400.00
0005432328482	31125	Economy	5400.00
0005432328628	31125	Economy	5400.00
0005432328705	31125	Economy	5400.00
0005432328594	31125	Economy	5400.00
0005432328666	31125	Economy	5400.00
0005433438859	31125	Economy	5400.00
0005432328694	31125	Economy	5400.00
0005433438880	31125	Economy	5400.00
0005432328549	31125	Economy	5400.00
0005433438865	31125	Economy	5400.00
0005435487788	6184	Business	124600.00
0005434309835	6184	Business	124600.00
0005435999357	6184	Business	124600.00
0005432146213	6184	Business	124600.00
0005434309833	6184	Business	124600.00
0005435487727	6184	Business	124600.00
0005434309824	6184	Business	124600.00
0005434309834	6184	Business	124600.00
0005435487741	6184	Business	124600.00
0005435487787	6184	Economy	41500.00
0005435297029	6184	Economy	41500.00
0005434309822	6184	Economy	41500.00
0005435999377	6184	Economy	41500.00
0005434309825	6184	Economy	41500.00
0005435999366	6184	Economy	41500.00
0005434309829	6184	Economy	41500.00
0005435999362	6184	Economy	41500.00
0005435999363	6184	Economy	41500.00
0005435297045	6184	Economy	41500.00
0005435297044	6184	Economy	41500.00
0005435999364	6184	Economy	41500.00
0005435487755	6184	Economy	41500.00
0005435487820	6184	Economy	41500.00
0005435297054	6184	Economy	41500.00
0005435999369	6184	Economy	41500.00
0005435999371	6184	Economy	41500.00
0005435999370	6184	Economy	45700.00
0005435297057	6184	Economy	45700.00
0005435487818	6184	Economy	41500.00
0005435999367	6184	Economy	41500.00
0005435999365	6184	Economy	41500.00
0005435999360	6184	Economy	41500.00
0005434309823	6184	Economy	41500.00
0005434309826	6184	Economy	41500.00
0005435487821	6184	Economy	41500.00
0005435297030	6184	Economy	41500.00
0005435999378	6184	Economy	41500.00
0005435487689	6184	Economy	41500.00
0005434309827	6184	Economy	41500.00
0005435999373	6184	Economy	41500.00
0005435999368	6184	Economy	41500.00
0005435999379	6184	Economy	41500.00
0005435487696	6184	Economy	41500.00
0005435487676	6184	Economy	41500.00
0005435999358	6184	Economy	41500.00
0005435487701	6184	Economy	41500.00
0005435999376	6184	Economy	41500.00
0005435999361	6184	Economy	41500.00
0005435487806	6184	Economy	41500.00
0005434309832	6184	Economy	41500.00
0005435487742	6184	Economy	41500.00
0005434309828	6184	Economy	41500.00
0005432146212	6184	Economy	41500.00
0005435487749	6184	Economy	41500.00
0005435999380	6184	Economy	41500.00
0005435999375	6184	Economy	41500.00
0005435999374	6184	Economy	41500.00
0005435487807	6184	Economy	41500.00
0005435999372	6184	Economy	41500.00
0005435487770	6184	Economy	41500.00
0005434309830	6184	Economy	41500.00
0005435487746	6184	Economy	41500.00
0005434309831	6184	Economy	41500.00
0005435999359	6184	Economy	41500.00
0005435487955	19572	Business	124600.00
0005435999189	19572	Business	124600.00
0005435487947	19572	Business	124600.00
0005435297104	19572	Business	124600.00
0005435487949	19572	Business	124600.00
0005434309681	19572	Business	124600.00
0005434309682	19572	Economy	41500.00
0005434309690	19572	Economy	41500.00
0005435297102	19572	Economy	41500.00
0005435487945	19572	Economy	41500.00
0005435487944	19572	Economy	41500.00
0005435487953	19572	Economy	41500.00
0005434309751	19572	Economy	41500.00
0005434309696	19572	Economy	41500.00
0005435487959	19572	Economy	41500.00
0005435999130	19572	Economy	41500.00
0005435487954	19572	Economy	41500.00
0005435487960	19572	Economy	41500.00
0005434309687	19572	Economy	41500.00
0005435297103	19572	Economy	41500.00
0005435487948	19572	Economy	41500.00
0005434309663	19572	Economy	41500.00
0005435487950	19572	Economy	41500.00
0005434309686	19572	Economy	41500.00
0005434309679	19572	Economy	41500.00
0005435999184	19572	Economy	41500.00
0005435487956	19572	Economy	41500.00
0005435297099	19572	Economy	41500.00
0005435487961	19572	Economy	41500.00
0005434309747	19572	Economy	41500.00
0005435999173	19572	Economy	45700.00
0005435999185	19572	Economy	45700.00
0005434309674	19572	Economy	41500.00
0005435999132	19572	Economy	41500.00
0005435297101	19572	Economy	41500.00
0005434309743	19572	Economy	41500.00
0005435487946	19572	Economy	41500.00
0005435487957	19572	Economy	41500.00
0005435487963	19572	Economy	41500.00
0005435297100	19572	Economy	41500.00
0005435999148	19572	Economy	41500.00
0005435487962	19572	Economy	41500.00
0005434309742	19572	Economy	41500.00
0005434309750	19572	Economy	41500.00
0005434309732	19572	Economy	41500.00
0005435999131	19572	Economy	41500.00
0005435487942	19572	Economy	41500.00
0005435487958	19572	Economy	41500.00
0005435297106	19572	Economy	41500.00
0005435487941	19572	Economy	41500.00
0005435297105	19572	Economy	41500.00
0005435487952	19572	Economy	41500.00
0005435999147	19572	Economy	41500.00
0005435999190	19572	Economy	41500.00
0005435999140	19572	Economy	41500.00
0005435487951	19572	Economy	41500.00
0005435487943	19572	Economy	41500.00
0005435999144	19572	Economy	41500.00
0005434309664	19572	Economy	41500.00
0005434446509	17554	Economy	12300.00
0005433158144	17554	Economy	12300.00
0005433158143	17554	Economy	12300.00
0005434446508	17554	Economy	12300.00
0005434446515	17554	Economy	12300.00
0005433158145	17554	Economy	12300.00
0005434446507	17554	Economy	12300.00
0005433158142	17554	Economy	12300.00
0005434446510	17554	Economy	12300.00
0005433158146	17554	Economy	12300.00
0005435502445	1545	Business	86000.00
0005434565995	1545	Business	86000.00
0005435508423	1545	Business	86000.00
0005434566005	1545	Business	86000.00
0005434566007	1545	Business	86000.00
0005435518019	1545	Business	86000.00
0005435518020	1545	Business	86000.00
0005433186090	1545	Business	86000.00
0005434566001	1545	Business	86000.00
0005435502452	1545	Business	86000.00
0005435518026	1545	Economy	28700.00
0005435508424	1545	Economy	28700.00
0005434566003	1545	Economy	28700.00
0005435502456	1545	Economy	28700.00
0005435502444	1545	Economy	28700.00
0005434565997	1545	Economy	28700.00
0005435502459	1545	Economy	28700.00
0005433186092	1545	Economy	28700.00
0005435508419	1545	Economy	31500.00
0005433186083	1545	Economy	31500.00
0005435502462	1545	Economy	31500.00
0005434566004	1545	Economy	28700.00
0005434565996	1545	Economy	28700.00
0005435518017	1545	Economy	28700.00
0005433186114	1545	Economy	28700.00
0005435518027	1545	Economy	28700.00
0005434565998	1545	Economy	28700.00
0005435508417	1545	Economy	28700.00
0005432291947	1545	Economy	28700.00
0005435508420	1545	Economy	28700.00
0005435508426	1545	Economy	28700.00
0005434565994	1545	Economy	28700.00
0005432291945	1545	Economy	28700.00
0005435518024	1545	Economy	28700.00
0005435518018	1545	Economy	28700.00
0005432291946	1545	Economy	28700.00
0005434566006	1545	Economy	28700.00
0005435508425	1545	Economy	28700.00
0005435502448	1545	Economy	28700.00
0005435518022	1545	Economy	28700.00
0005435518023	1545	Economy	28700.00
0005435502457	1545	Economy	28700.00
0005435502460	1545	Economy	28700.00
0005435502461	1545	Economy	28700.00
0005435502449	1545	Economy	28700.00
0005435502451	1545	Economy	28700.00
0005435518025	1545	Economy	28700.00
0005435502441	1545	Economy	28700.00
0005435502442	1545	Economy	28700.00
0005435508421	1545	Economy	28700.00
0005435508429	1545	Economy	28700.00
0005433186082	1545	Economy	28700.00
0005432291944	1545	Economy	28700.00
0005435502450	1545	Economy	28700.00
0005435508422	1545	Economy	28700.00
0005433186111	1545	Economy	28700.00
0005435518021	1545	Economy	28700.00
0005435508418	1545	Economy	28700.00
0005435502458	1545	Economy	28700.00
0005435518016	1545	Economy	28700.00
0005433186116	1545	Economy	28700.00
0005435508428	1545	Economy	28700.00
0005433186100	1545	Economy	28700.00
0005435502446	1545	Economy	28700.00
0005434566002	1545	Economy	28700.00
0005434566000	1545	Economy	28700.00
0005435502447	1545	Economy	28700.00
0005435508427	1545	Economy	28700.00
0005435502454	1545	Economy	28700.00
0005433186115	1545	Economy	28700.00
0005434565999	1545	Economy	28700.00
0005433186105	1545	Economy	28700.00
0005435502443	1545	Economy	28700.00
0005435502455	1545	Economy	28700.00
0005435502453	1545	Economy	28700.00
0005433186104	1545	Economy	28700.00
0005435502268	20876	Business	86000.00
0005435502243	20876	Business	86000.00
0005435502197	20876	Business	86000.00
0005435529114	20876	Business	86000.00
0005435502289	20876	Business	86000.00
0005435529150	20876	Business	86000.00
0005435545700	20876	Business	86000.00
0005435529148	20876	Business	86000.00
0005433186170	20876	Business	86000.00
0005435545693	20876	Business	86000.00
0005435502221	20876	Economy	28700.00
0005433186173	20876	Economy	28700.00
0005435502200	20876	Economy	28700.00
0005435545701	20876	Economy	28700.00
0005435502142	20876	Economy	28700.00
0005434565881	20876	Economy	28700.00
0005435529174	20876	Economy	28700.00
0005435502143	20876	Economy	28700.00
0005435529089	20876	Economy	31500.00
0005435502317	20876	Economy	31500.00
0005435502308	20876	Economy	31500.00
0005435529149	20876	Economy	31500.00
0005434565880	20876	Economy	31500.00
0005435529225	20876	Economy	28700.00
0005433186176	20876	Economy	28700.00
0005435502236	20876	Economy	28700.00
0005435545702	20876	Economy	28700.00
0005433186169	20876	Economy	28700.00
0005435502282	20876	Economy	28700.00
0005434565910	20876	Economy	28700.00
0005435502229	20876	Economy	28700.00
0005433186174	20876	Economy	28700.00
0005435502245	20876	Economy	28700.00
0005435545675	20876	Economy	28700.00
0005435502340	20876	Economy	28700.00
0005435529090	20876	Economy	28700.00
0005435502287	20876	Economy	28700.00
0005434565909	20876	Economy	28700.00
0005435502248	20876	Economy	28700.00
0005433186171	20876	Economy	28700.00
0005435502256	20876	Economy	28700.00
0005435502235	20876	Economy	28700.00
0005434565929	20876	Economy	28700.00
0005435502255	20876	Economy	28700.00
0005434565879	20876	Economy	28700.00
0005433186177	20876	Economy	28700.00
0005435529175	20876	Economy	28700.00
0005435529185	20876	Economy	28700.00
0005435502297	20876	Economy	28700.00
0005435502129	20876	Economy	28700.00
0005435502335	20876	Economy	28700.00
0005434565917	20876	Economy	28700.00
0005435529158	20876	Economy	28700.00
0005435529206	20876	Economy	28700.00
0005434565918	20876	Economy	28700.00
0005435502244	20876	Economy	28700.00
0005435502222	20876	Economy	28700.00
0005435545682	20876	Economy	28700.00
0005435529232	20876	Economy	28700.00
0005435545676	20876	Economy	28700.00
0005434565908	20876	Economy	28700.00
0005434565856	20876	Economy	28700.00
0005433186172	20876	Economy	28700.00
0005435502366	20876	Economy	28700.00
0005435529184	20876	Economy	28700.00
0005435529187	20876	Economy	28700.00
0005434565855	20876	Economy	28700.00
0005435502199	20876	Economy	28700.00
0005435529097	20876	Economy	28700.00
0005435502177	20876	Economy	28700.00
0005434565832	20876	Economy	28700.00
0005435529119	20876	Economy	28700.00
0005434565831	20876	Economy	28700.00
0005435502253	20876	Economy	28700.00
0005435529233	20876	Economy	28700.00
0005435545685	20876	Economy	28700.00
0005433186175	20876	Economy	28700.00
0005435502313	20876	Economy	28700.00
0005435153783	3924	Economy	19700.00
0005435931585	3924	Economy	19700.00
0005435153781	3924	Economy	19700.00
0005435153786	3924	Economy	19700.00
0005435153784	3924	Economy	19700.00
0005435931591	3924	Economy	19700.00
0005435153788	3924	Economy	19700.00
0005435153787	3924	Economy	19700.00
0005435931584	3924	Economy	19700.00
0005435153789	3924	Economy	19700.00
0005435153782	3924	Economy	19700.00
0005435153785	3924	Economy	19700.00
0005435153714	21871	Economy	21600.00
0005435931626	21871	Economy	19700.00
0005435153713	21871	Economy	19700.00
0005435153731	21871	Economy	19700.00
0005435153725	21871	Economy	19700.00
0005435153728	21871	Economy	19700.00
0005435931625	21871	Economy	19700.00
0005435931624	21871	Economy	19700.00
0005435153745	21871	Economy	19700.00
0005432628947	7192	Economy	14300.00
0005432628943	7192	Economy	14300.00
0005432628948	7192	Economy	13000.00
0005432628936	7192	Economy	13000.00
0005435225554	7192	Economy	13000.00
0005435225575	7192	Economy	13000.00
0005435225560	7192	Economy	13000.00
0005432628938	7192	Economy	13000.00
0005432628946	7192	Economy	13000.00
0005432628941	7192	Economy	13000.00
0005432628939	7192	Economy	13000.00
0005432628940	7192	Economy	13000.00
0005432628944	7192	Economy	13000.00
0005432628937	7192	Economy	13000.00
0005432628942	7192	Economy	13000.00
0005432628935	7192	Economy	13000.00
0005435225582	7192	Economy	13000.00
0005432628945	7192	Economy	13000.00
0005432628804	28102	Economy	14300.00
0005432628814	28102	Economy	14300.00
0005432628898	28102	Economy	14300.00
0005432628822	28102	Economy	14300.00
0005432628771	28102	Economy	13000.00
0005435225635	28102	Economy	13000.00
0005432628803	28102	Economy	13000.00
0005432628802	28102	Economy	13000.00
0005432628815	28102	Economy	13000.00
0005432628830	28102	Economy	13000.00
0005432628784	28102	Economy	13000.00
0005432628897	28102	Economy	13000.00
0005435225639	28102	Economy	13000.00
0005432628857	28102	Economy	13000.00
0005432628772	28102	Economy	13000.00
0005432628879	28102	Economy	13000.00
0005432628827	28102	Economy	13000.00
0005432628805	28102	Economy	13000.00
0005432628823	28102	Economy	13000.00
0005435225636	28102	Economy	13000.00
0005432628853	28102	Economy	13000.00
0005435225638	28102	Economy	13000.00
0005435225634	28102	Economy	13000.00
0005432628851	28102	Economy	13000.00
0005435225633	28102	Economy	13000.00
0005432628816	28102	Economy	13000.00
0005435225637	28102	Economy	13000.00
0005432628806	28102	Economy	13000.00
0005432628836	28102	Economy	13000.00
0005432628862	28102	Economy	13000.00
0005432628844	28102	Economy	13000.00
0005432628775	28102	Economy	13000.00
0005435960075	8730	Economy	11500.00
0005435960076	8730	Economy	10500.00
0005434267960	8730	Economy	10500.00
0005434267948	8730	Economy	10500.00
0005435960074	8730	Economy	10500.00
0005434267975	15229	Economy	10500.00
0005435960049	15229	Economy	10500.00
0005434267974	15229	Economy	10500.00
0005435960032	15229	Economy	10500.00
0005435960036	15229	Economy	10500.00
0005432693225	1219	Business	115000.00
0005432693234	1219	Business	115000.00
0005432675227	1219	Business	115000.00
0005432693247	1219	Business	115000.00
0005432693252	1219	Business	115000.00
0005432693242	1219	Business	115000.00
0005432677595	1219	Business	115000.00
0005432693245	1219	Business	115000.00
0005432873310	1219	Business	115000.00
0005432675230	1219	Business	115000.00
0005432693250	1219	Economy	38300.00
0005432693238	1219	Economy	38300.00
0005432675223	1219	Economy	38300.00
0005432675231	1219	Economy	38300.00
0005432693249	1219	Economy	38300.00
0005432873274	1219	Economy	38300.00
0005432693243	1219	Economy	38300.00
0005432675222	1219	Economy	38300.00
0005432693226	1219	Economy	42200.00
0005432873288	1219	Economy	38300.00
0005432693227	1219	Economy	38300.00
0005432693246	1219	Economy	38300.00
0005432693232	1219	Economy	38300.00
0005432675232	1219	Economy	38300.00
0005432675228	1219	Economy	38300.00
0005432693223	1219	Economy	38300.00
0005432693244	1219	Economy	38300.00
0005432675226	1219	Economy	38300.00
0005432693248	1219	Economy	38300.00
0005432693228	1219	Economy	38300.00
0005432693231	1219	Economy	38300.00
0005432675224	1219	Economy	38300.00
0005432677594	1219	Economy	38300.00
0005432693230	1219	Economy	38300.00
0005432693233	1219	Economy	38300.00
0005432693237	1219	Economy	38300.00
0005432675233	1219	Economy	38300.00
0005432675225	1219	Economy	38300.00
0005432693241	1219	Economy	38300.00
0005432693224	1219	Economy	38300.00
0005432693229	1219	Economy	38300.00
0005432675235	1219	Economy	38300.00
0005432675234	1219	Economy	38300.00
0005432677596	1219	Economy	38300.00
0005432693251	1219	Economy	38300.00
0005432693239	1219	Economy	38300.00
0005432675229	1219	Economy	38300.00
0005432693236	1219	Economy	38300.00
0005432693240	1219	Economy	38300.00
0005432693235	1219	Economy	38300.00
0005432873335	17466	Business	115000.00
0005432692953	17466	Business	115000.00
0005432693001	17466	Business	115000.00
0005432693026	17466	Business	115000.00
0005432675116	17466	Business	115000.00
0005432693065	17466	Business	115000.00
0005432692930	17466	Business	115000.00
0005432675142	17466	Business	115000.00
0005432873336	17466	Economy	38300.00
0005432873337	17466	Economy	38300.00
0005432675093	17466	Economy	38300.00
0005432692904	17466	Economy	38300.00
0005432873339	17466	Economy	38300.00
0005432693023	17466	Economy	38300.00
0005432692978	17466	Economy	42200.00
0005432692907	17466	Economy	42200.00
0005432692908	17466	Economy	38300.00
0005432675135	17466	Economy	38300.00
0005432873338	17466	Economy	38300.00
0005432693088	17466	Economy	38300.00
0005432692981	17466	Economy	38300.00
0005432693057	17466	Economy	38300.00
0005432692979	17466	Economy	38300.00
0005432675115	17466	Economy	38300.00
0005432693025	17466	Economy	38300.00
0005432692864	17466	Economy	38300.00
0005432693084	17466	Economy	38300.00
0005432692971	17466	Economy	38300.00
0005432693027	17466	Economy	38300.00
0005432873340	17466	Economy	38300.00
0005432693041	17466	Economy	38300.00
0005432692773	17466	Economy	38300.00
0005432675088	17466	Economy	38300.00
0005432693087	17466	Economy	38300.00
0005432692977	17466	Economy	38300.00
0005432692896	17466	Economy	38300.00
0005432675080	17466	Economy	38300.00
0005432692952	17466	Economy	38300.00
0005432675153	17466	Economy	38300.00
0005432692970	17466	Economy	38300.00
0005432692999	17466	Economy	38300.00
0005432677577	17466	Economy	38300.00
0005432873334	17466	Economy	38300.00
0005432692909	17466	Economy	38300.00
0005432693010	17466	Economy	38300.00
0005432675081	17466	Economy	38300.00
0005432692960	17466	Economy	38300.00
0005432692998	17466	Economy	38300.00
0005432675129	17466	Economy	38300.00
0005432693002	17466	Economy	38300.00
0005432692931	17466	Economy	38300.00
0005432675099	17466	Economy	38300.00
0005432675141	17466	Economy	38300.00
0005432693030	17466	Economy	38300.00
0005432693060	17466	Economy	38300.00
0005432693040	17466	Economy	38300.00
0005433156756	1114	Economy	13900.00
0005434435272	1114	Economy	13900.00
0005434435282	1114	Economy	13900.00
0005434435278	1114	Economy	13900.00
0005433156720	1114	Economy	13900.00
0005434435283	1114	Economy	13900.00
0005434435276	1114	Economy	13900.00
0005434435281	1114	Economy	13900.00
0005434435284	1114	Economy	13900.00
0005433156751	1114	Economy	13900.00
0005434435277	1114	Economy	13900.00
0005434435273	1114	Economy	13900.00
0005433156752	1114	Economy	13900.00
0005433156757	1114	Economy	13900.00
0005433156738	1114	Economy	13900.00
0005433156748	1114	Economy	13900.00
0005434435286	1114	Economy	13900.00
0005434435279	1114	Economy	13900.00
0005434435274	1114	Economy	13900.00
0005434435280	1114	Economy	13900.00
0005433156721	1114	Economy	13900.00
0005434435285	1114	Economy	13900.00
0005433156737	1114	Economy	13900.00
0005434435275	1114	Economy	13900.00
0005433156750	1114	Economy	13900.00
0005433156806	17307	Economy	15200.00
0005433156805	17307	Economy	13900.00
0005433156804	17307	Economy	13900.00
0005434435137	17307	Economy	13900.00
0005434435110	17307	Economy	13900.00
0005434435109	17307	Economy	13900.00
0005433156807	17307	Economy	13900.00
0005434435072	17307	Economy	13900.00
0005434435173	17307	Economy	13900.00
0005433156808	17307	Economy	13900.00
0005434435161	17307	Economy	13900.00
0005434435193	17307	Economy	13900.00
0005434435164	17307	Economy	13900.00
0005434435133	17307	Economy	13900.00
0005433156803	17307	Economy	13900.00
0005434435134	17307	Economy	13900.00
0005434435154	17307	Economy	13900.00
0005433156801	17307	Economy	13900.00
0005434435145	17307	Economy	13900.00
0005434435132	17307	Economy	13900.00
0005434435185	17307	Economy	13900.00
0005434435146	17307	Economy	13900.00
0005433156800	17307	Economy	13900.00
0005433156802	17307	Economy	13900.00
0005434435194	17307	Economy	13900.00
0005434435165	17307	Economy	13900.00
0005435928151	4085	Economy	7500.00
0005435086880	4085	Economy	7500.00
0005435928141	4085	Economy	7500.00
0005435928142	4085	Economy	7500.00
0005435928150	4085	Economy	7500.00
0005435928143	4085	Economy	7500.00
0005435086881	4085	Economy	7500.00
0005435928127	4085	Economy	7500.00
0005435086883	4085	Economy	7500.00
0005435086884	4085	Economy	7500.00
0005435086882	4085	Economy	7500.00
0005435086885	4085	Economy	7500.00
0005435928174	24430	Economy	8200.00
0005435086771	24430	Economy	8200.00
0005435086853	24430	Economy	7500.00
0005435086818	24430	Economy	7500.00
0005435086820	24430	Economy	7500.00
0005435086798	24430	Economy	7500.00
0005435086823	24430	Economy	7500.00
0005435928173	24430	Economy	7500.00
0005435086816	24430	Economy	7500.00
0005435928175	24430	Economy	7500.00
0005435086817	24430	Economy	7500.00
0005433373521	2454	Business	86800.00
0005435706463	2454	Business	86800.00
0005433373513	2454	Business	86800.00
0005435706469	2454	Business	86800.00
0005433373490	2454	Business	86800.00
0005435706449	2454	Business	86800.00
0005435706493	2454	Business	86800.00
0005435706470	2454	Business	86800.00
0005435706460	2454	Business	86800.00
0005435706480	2454	Economy	28900.00
0005435706466	2454	Economy	28900.00
0005435706453	2454	Economy	28900.00
0005435706477	2454	Economy	28900.00
0005433373514	2454	Economy	28900.00
0005435706482	2454	Economy	28900.00
0005433373500	2454	Economy	28900.00
0005433373528	2454	Economy	28900.00
0005433373476	2454	Economy	28900.00
0005433373520	2454	Economy	31800.00
0005435706462	2454	Economy	31800.00
0005435706478	2454	Economy	31800.00
0005433373560	2454	Economy	31800.00
0005435706465	2454	Economy	31800.00
0005433373458	2454	Economy	28900.00
0005435706455	2454	Economy	28900.00
0005433373512	2454	Economy	28900.00
0005435706474	2454	Economy	28900.00
0005435706456	2454	Economy	28900.00
0005435706481	2454	Economy	28900.00
0005435706498	2454	Economy	28900.00
0005435706450	2454	Economy	28900.00
0005433373487	2454	Economy	28900.00
0005435706497	2454	Economy	28900.00
0005435706492	2454	Economy	28900.00
0005435706483	2454	Economy	28900.00
0005435706454	2454	Economy	28900.00
0005433373488	2454	Economy	28900.00
0005433373489	2454	Economy	28900.00
0005435706491	2454	Economy	28900.00
0005433373501	2454	Economy	28900.00
0005433373525	2454	Economy	28900.00
0005435706458	2454	Economy	28900.00
0005435706461	2454	Economy	28900.00
0005433373526	2454	Economy	28900.00
0005435706471	2454	Economy	28900.00
0005435706475	2454	Economy	28900.00
0005433373559	2454	Economy	28900.00
0005435706489	2454	Economy	28900.00
0005435706476	2454	Economy	28900.00
0005435706495	2454	Economy	28900.00
0005435706467	2454	Economy	28900.00
0005433373446	2454	Economy	28900.00
0005435706490	2454	Economy	28900.00
0005433373496	2454	Economy	28900.00
0005433373504	2454	Economy	28900.00
0005433373552	2454	Economy	28900.00
0005435706459	2454	Economy	28900.00
0005433373515	2454	Economy	28900.00
0005433373503	2454	Economy	28900.00
0005435706484	2454	Economy	28900.00
0005435706494	2454	Economy	28900.00
0005435706486	2454	Economy	28900.00
0005433373477	2454	Economy	28900.00
0005435706488	2454	Economy	28900.00
0005435706472	2454	Economy	28900.00
0005435706479	2454	Economy	28900.00
0005435706485	2454	Economy	28900.00
0005433373522	2454	Economy	28900.00
0005435706457	2454	Economy	28900.00
0005435706452	2454	Economy	28900.00
0005433373475	2454	Economy	28900.00
0005433373494	2454	Economy	28900.00
0005433373516	2454	Economy	28900.00
0005435706464	2454	Economy	28900.00
0005435706496	2454	Economy	28900.00
0005435706451	2454	Economy	28900.00
0005435706468	2454	Economy	28900.00
0005433373527	2454	Economy	28900.00
0005435706473	2454	Economy	28900.00
0005435706487	2454	Economy	28900.00
0005433373502	2454	Economy	28900.00
0005435706297	27043	Business	86800.00
0005435706315	27043	Business	86800.00
0005433373594	27043	Business	86800.00
0005435706347	27043	Business	86800.00
0005433373591	27043	Business	86800.00
0005435706311	27043	Business	86800.00
0005433373597	27043	Economy	28900.00
0005433373573	27043	Economy	28900.00
0005433373587	27043	Economy	28900.00
0005435706384	27043	Economy	28900.00
0005435706427	27043	Economy	28900.00
0005435706404	27043	Economy	28900.00
0005433373593	27043	Economy	28900.00
0005435706351	27043	Economy	28900.00
0005433373589	27043	Economy	31800.00
0005435706428	27043	Economy	31800.00
0005435706285	27043	Economy	31800.00
0005435706340	27043	Economy	28900.00
0005435706292	27043	Economy	28900.00
0005435706379	27043	Economy	28900.00
0005435706408	27043	Economy	28900.00
0005433373575	27043	Economy	28900.00
0005435706308	27043	Economy	28900.00
0005433373596	27043	Economy	28900.00
0005433373582	27043	Economy	28900.00
0005435706310	27043	Economy	28900.00
0005435706306	27043	Economy	28900.00
0005435706334	27043	Economy	28900.00
0005435706339	27043	Economy	28900.00
0005433373581	27043	Economy	28900.00
0005435706323	27043	Economy	28900.00
0005435706269	27043	Economy	28900.00
0005433373580	27043	Economy	28900.00
0005433373584	27043	Economy	28900.00
0005435706358	27043	Economy	28900.00
0005433373574	27043	Economy	28900.00
0005433373585	27043	Economy	28900.00
0005435706426	27043	Economy	28900.00
0005433373590	27043	Economy	28900.00
0005433373577	27043	Economy	28900.00
0005435706378	27043	Economy	28900.00
0005433373592	27043	Economy	28900.00
0005435706270	27043	Economy	28900.00
0005435706369	27043	Economy	28900.00
0005435706333	27043	Economy	28900.00
0005435706268	27043	Economy	28900.00
0005435706392	27043	Economy	28900.00
0005435706391	27043	Economy	28900.00
0005433373598	27043	Economy	28900.00
0005435706350	27043	Economy	28900.00
0005435706330	27043	Economy	28900.00
0005433373576	27043	Economy	28900.00
0005435706290	27043	Economy	28900.00
0005433373588	27043	Economy	28900.00
0005435706277	27043	Economy	28900.00
0005433373572	27043	Economy	28900.00
0005435706380	27043	Economy	28900.00
0005435706385	27043	Economy	28900.00
0005433373595	27043	Economy	28900.00
0005435706393	27043	Economy	28900.00
0005435706394	27043	Economy	28900.00
0005435706356	27043	Economy	28900.00
0005435706370	27043	Economy	28900.00
0005433373586	27043	Economy	28900.00
0005433373579	27043	Economy	28900.00
0005435706291	27043	Economy	28900.00
0005435706307	27043	Economy	28900.00
0005435706327	27043	Economy	28900.00
0005433373583	27043	Economy	28900.00
0005433373578	27043	Economy	28900.00
0005435907503	4824	Business	44200.00
0005435907485	4824	Business	44200.00
0005433194845	4824	Business	44200.00
0005434626021	4824	Business	44200.00
0005433194847	4824	Business	44200.00
0005435907481	4824	Business	44200.00
0005435907494	4824	Business	44200.00
0005434626020	4824	Economy	14700.00
0005433194857	4824	Economy	14700.00
0005435907514	4824	Economy	14700.00
0005433194836	4824	Economy	14700.00
0005435907506	4824	Economy	14700.00
0005434626024	4824	Economy	16200.00
0005434626019	4824	Economy	14700.00
0005435907513	4824	Economy	14700.00
0005434626022	4824	Economy	14700.00
0005434626023	4824	Economy	14700.00
0005434626026	4824	Economy	14700.00
0005434626025	4824	Economy	14700.00
0005434626018	4824	Economy	14700.00
0005435907504	4824	Economy	14700.00
0005434626017	4824	Economy	14700.00
0005433194834	4824	Economy	14700.00
0005434625936	32905	Business	44200.00
0005435907537	32905	Economy	14700.00
0005433194874	32905	Economy	14700.00
0005435907532	32905	Economy	14700.00
0005435907535	32905	Economy	14700.00
0005433194869	32905	Economy	16200.00
0005433194863	32905	Economy	16200.00
0005434625950	32905	Economy	14700.00
0005433194870	32905	Economy	14700.00
0005434625985	32905	Economy	14700.00
0005435907533	32905	Economy	14700.00
0005433194875	32905	Economy	14700.00
0005433194868	32905	Economy	14700.00
0005433194873	32905	Economy	14700.00
0005433194866	32905	Economy	14700.00
0005434625984	32905	Economy	14700.00
0005433194871	32905	Economy	14700.00
0005434625983	32905	Economy	14700.00
0005433194864	32905	Economy	14700.00
0005434625956	32905	Economy	14700.00
0005434625942	32905	Economy	14700.00
0005434625955	32905	Economy	14700.00
0005434625943	32905	Economy	14700.00
0005433194872	32905	Economy	14700.00
0005435907534	32905	Economy	14700.00
0005433194867	32905	Economy	14700.00
0005435907536	32905	Economy	14700.00
0005434625949	32905	Economy	14700.00
0005433194862	32905	Economy	14700.00
0005433194865	32905	Economy	14700.00
0005434625940	32905	Economy	14700.00
0005435785357	13798	Economy	3400.00
0005435785306	13798	Economy	3400.00
0005435785305	13798	Economy	3400.00
0005435785352	13798	Economy	3100.00
0005435785185	13798	Economy	3100.00
0005435785159	13798	Economy	3100.00
0005435787350	13798	Economy	3100.00
0005435785257	13798	Economy	3100.00
0005435937404	13798	Economy	3100.00
0005435785192	13798	Economy	3100.00
0005435937403	13798	Economy	3100.00
0005435785272	13798	Economy	3100.00
0005435937405	13798	Economy	3100.00
0005435785358	13798	Economy	3100.00
0005435785351	13798	Economy	3100.00
0005432195706	13798	Economy	3100.00
0005435937409	13798	Economy	3100.00
0005435787343	13798	Economy	3100.00
0005435785178	13798	Economy	3100.00
0005435785209	13798	Economy	3100.00
0005432195707	13798	Economy	3100.00
0005435785175	13798	Economy	3100.00
0005432195705	13798	Economy	3100.00
0005435785291	13798	Economy	3100.00
0005435785147	13798	Economy	3100.00
0005435785184	13798	Economy	3100.00
0005435785258	13798	Economy	3100.00
0005435937402	13798	Economy	3100.00
0005435785395	13798	Economy	3100.00
0005435785190	13798	Economy	3100.00
0005435785189	13798	Economy	3100.00
0005435785311	13798	Economy	3100.00
0005435785205	13798	Economy	3100.00
0005435785292	13798	Economy	3100.00
0005435785307	13798	Economy	3100.00
0005435937406	13798	Economy	3100.00
0005435937408	13798	Economy	3100.00
0005435785206	13798	Economy	3100.00
0005435785262	13798	Economy	3100.00
0005435785237	13798	Economy	3100.00
0005435937407	13798	Economy	3100.00
0005435785271	13798	Economy	3100.00
0005435785520	27406	Economy	3400.00
0005435785517	27406	Economy	3400.00
0005435785521	27406	Economy	3400.00
0005435785531	27406	Economy	3400.00
0005435785541	27406	Economy	3100.00
0005435785519	27406	Economy	3100.00
0005432190648	27406	Economy	3100.00
0005435785512	27406	Economy	3100.00
0005435785539	27406	Economy	3100.00
0005435785514	27406	Economy	3100.00
0005435785538	27406	Economy	3100.00
0005432190650	27406	Economy	3100.00
0005435785537	27406	Economy	3100.00
0005435785508	27406	Economy	3100.00
0005435785527	27406	Economy	3100.00
0005435785511	27406	Economy	3100.00
0005435937360	27406	Economy	3100.00
0005435785528	27406	Economy	3100.00
0005435785542	27406	Economy	3100.00
0005435787365	27406	Economy	3100.00
0005435785509	27406	Economy	3100.00
0005435785530	27406	Economy	3100.00
0005435785533	27406	Economy	3100.00
0005435785526	27406	Economy	3100.00
0005435785529	27406	Economy	3100.00
0005435785518	27406	Economy	3100.00
0005435785540	27406	Economy	3100.00
0005435785524	27406	Economy	3100.00
0005432190646	27406	Economy	3100.00
0005435785534	27406	Economy	3100.00
0005435937355	27406	Economy	3100.00
0005435937361	27406	Economy	3100.00
0005432190647	27406	Economy	3100.00
0005435785507	27406	Economy	3100.00
0005432190651	27406	Economy	3100.00
0005435785510	27406	Economy	3100.00
0005435785532	27406	Economy	3100.00
0005435785535	27406	Economy	3100.00
0005435785516	27406	Economy	3100.00
0005435785523	27406	Economy	3100.00
0005435937354	27406	Economy	3100.00
0005435785513	27406	Economy	3100.00
0005435785515	27406	Economy	3100.00
0005435785525	27406	Economy	3100.00
0005432190649	27406	Economy	3100.00
0005435785536	27406	Economy	3100.00
0005435785522	27406	Economy	3100.00
0005434407576	20292	Business	12000.00
0005434407475	20292	Business	12000.00
0005434407760	20292	Business	12000.00
0005434407795	20292	Business	12000.00
0005434407691	20292	Business	12000.00
0005435311138	20292	Business	12000.00
0005434407594	20292	Business	12000.00
0005434407730	20292	Business	12000.00
0005434407536	20292	Business	12000.00
0005434407506	20292	Business	12000.00
0005434407581	20292	Business	12000.00
0005434407430	20292	Economy	4000.00
0005434407755	20292	Economy	4000.00
0005434407523	20292	Economy	4000.00
0005434407836	20292	Economy	4000.00
0005434407466	20292	Economy	4000.00
0005434407790	20292	Economy	4000.00
0005434407535	20292	Economy	4000.00
0005434407788	20292	Economy	4000.00
0005434407434	20292	Economy	4000.00
0005434407399	20292	Economy	4000.00
0005434407284	20292	Economy	4400.00
0005434407285	20292	Economy	4400.00
0005434407572	20292	Economy	4400.00
0005434407166	20292	Economy	4400.00
0005434407524	20292	Economy	4000.00
0005434407690	20292	Economy	4000.00
0005434407921	20292	Economy	4000.00
0005434407367	20292	Economy	4000.00
0005434407674	20292	Economy	4000.00
0005434407985	20292	Economy	4000.00
0005434407843	20292	Economy	4000.00
0005434407329	20292	Economy	4000.00
0005434407666	20292	Economy	4000.00
0005434407507	20292	Economy	4000.00
0005434407465	20292	Economy	4000.00
0005434407612	20292	Economy	4000.00
0005434407565	20292	Economy	4000.00
0005434407645	20292	Economy	4000.00
0005434407520	20292	Economy	4000.00
0005434407764	20292	Economy	4000.00
0005434407653	20292	Economy	4000.00
0005434407734	20292	Economy	4000.00
0005434407842	20292	Economy	4000.00
0005434407812	20292	Economy	4000.00
0005434407669	20292	Economy	4000.00
0005434407750	20292	Economy	4000.00
0005434407559	20292	Economy	4000.00
0005434407283	20292	Economy	4000.00
0005434407387	20292	Economy	4000.00
0005434407660	20292	Economy	4000.00
0005434407366	20292	Economy	4000.00
0005434407464	20292	Economy	4000.00
0005434407625	20292	Economy	4000.00
0005434407735	20292	Economy	4000.00
0005434407692	20292	Economy	4000.00
0005434407435	20292	Economy	4000.00
0005434407327	20292	Economy	4000.00
0005434407505	20292	Economy	4000.00
0005434407398	20292	Economy	4000.00
0005434407282	20292	Economy	4000.00
0005434407490	20292	Economy	4000.00
0005434407326	20292	Economy	4000.00
0005434407639	20292	Economy	4000.00
0005434407828	20292	Economy	4000.00
0005434407901	20292	Economy	4000.00
0005434407665	20292	Economy	4000.00
0005432058405	20292	Economy	4000.00
0005432058408	20292	Economy	4000.00
0005434407763	20292	Economy	4000.00
0005434408036	20292	Economy	4000.00
0005434407710	20292	Economy	4000.00
0005432058407	20292	Economy	4000.00
0005434407414	20292	Economy	4000.00
0005432058406	20292	Economy	4000.00
0005434407837	20292	Economy	4000.00
0005434407789	20292	Economy	4000.00
0005434407446	20292	Economy	4000.00
0005434407386	20292	Economy	4000.00
0005434407431	20292	Economy	4000.00
0005434407325	20292	Economy	4000.00
0005434407711	20292	Economy	4000.00
0005434407696	20292	Economy	4000.00
0005434407768	20292	Economy	4000.00
0005434407723	20292	Economy	4000.00
0005434407221	20292	Economy	4000.00
0005434407429	20292	Economy	4000.00
0005434408164	26968	Business	12000.00
0005434408188	26968	Business	12000.00
0005432153984	26968	Business	12000.00
0005434408153	26968	Business	12000.00
0005434408169	26968	Business	12000.00
0005434408183	26968	Business	12000.00
0005434408174	26968	Business	12000.00
0005434408167	26968	Business	12000.00
0005434408168	26968	Economy	4000.00
0005435311036	26968	Economy	4000.00
0005434408152	26968	Economy	4000.00
0005434408127	26968	Economy	4000.00
0005432153980	26968	Economy	4000.00
0005434408161	26968	Economy	4000.00
0005434408144	26968	Economy	4000.00
0005434408150	26968	Economy	4000.00
0005434408170	26968	Economy	4000.00
0005435311013	26968	Economy	4400.00
0005434408159	26968	Economy	4400.00
0005434408133	26968	Economy	4400.00
0005434408175	26968	Economy	4400.00
0005434408149	26968	Economy	4000.00
0005434408180	26968	Economy	4000.00
0005435311034	26968	Economy	4000.00
0005434408129	26968	Economy	4000.00
0005434408148	26968	Economy	4000.00
0005432153981	26968	Economy	4000.00
0005434408156	26968	Economy	4000.00
0005434408140	26968	Economy	4000.00
0005434408178	26968	Economy	4000.00
0005434408160	26968	Economy	4000.00
0005435310988	26968	Economy	4000.00
0005434408130	26968	Economy	4000.00
0005434408158	26968	Economy	4000.00
0005434408171	26968	Economy	4000.00
0005434408137	26968	Economy	4000.00
0005434408126	26968	Economy	4000.00
0005434408157	26968	Economy	4000.00
0005434408181	26968	Economy	4000.00
0005432153983	26968	Economy	4000.00
0005434408138	26968	Economy	4000.00
0005434408151	26968	Economy	4000.00
0005434408184	26968	Economy	4000.00
0005434408142	26968	Economy	4000.00
0005434408176	26968	Economy	4000.00
0005434408141	26968	Economy	4000.00
0005435311033	26968	Economy	4000.00
0005435311029	26968	Economy	4000.00
0005434408173	26968	Economy	4000.00
0005434408146	26968	Economy	4000.00
0005434408165	26968	Economy	4000.00
0005434408143	26968	Economy	4000.00
0005434408155	26968	Economy	4000.00
0005434408162	26968	Economy	4000.00
0005435311026	26968	Economy	4000.00
0005434408179	26968	Economy	4000.00
0005434408172	26968	Economy	4000.00
0005434408135	26968	Economy	4000.00
0005434408163	26968	Economy	4000.00
0005434408166	26968	Economy	4000.00
0005434408186	26968	Economy	4000.00
0005434408134	26968	Economy	4000.00
0005434408147	26968	Economy	4000.00
0005434408139	26968	Economy	4000.00
0005434408185	26968	Economy	4000.00
0005434408177	26968	Economy	4000.00
0005434408136	26968	Economy	4000.00
0005434408182	26968	Economy	4000.00
0005434408145	26968	Economy	4000.00
0005435311035	26968	Economy	4000.00
0005435311045	26968	Economy	4000.00
0005432153982	26968	Economy	4000.00
0005434408154	26968	Economy	4000.00
0005432153979	26968	Economy	4000.00
0005435311022	26968	Economy	4000.00
0005434408132	26968	Economy	4000.00
0005434408128	26968	Economy	4000.00
0005434408131	26968	Economy	4000.00
0005434408187	26968	Economy	4000.00
0005434319502	5719	Business	43300.00
0005434319491	5719	Business	43300.00
0005433123862	5719	Business	43300.00
0005433123857	5719	Business	43300.00
0005434319497	5719	Business	43300.00
0005433123869	5719	Economy	14400.00
0005433123892	5719	Economy	14400.00
0005433123968	5719	Economy	14400.00
0005433123977	5719	Economy	14400.00
0005433123836	5719	Economy	14400.00
0005434319501	5719	Economy	15900.00
0005434319493	5719	Economy	15900.00
0005433123903	5719	Economy	14400.00
0005434319492	5719	Economy	14400.00
0005433123880	5719	Economy	14400.00
0005434319496	5719	Economy	14400.00
0005434319499	5719	Economy	14400.00
0005434319500	5719	Economy	14400.00
0005433123913	5719	Economy	14400.00
0005434319495	5719	Economy	14400.00
0005433123976	5719	Economy	14400.00
0005433123825	5719	Economy	14400.00
0005434319488	5719	Economy	14400.00
0005433123837	5719	Economy	14400.00
0005433123860	5719	Economy	14400.00
0005433123824	5719	Economy	14400.00
0005432109720	5719	Economy	14400.00
0005433123859	5719	Economy	14400.00
0005433123803	5719	Economy	14400.00
0005434311233	5719	Economy	14400.00
0005433123904	5719	Economy	14400.00
0005433123887	5719	Economy	14400.00
0005433123879	5719	Economy	14400.00
0005433123864	5719	Economy	14400.00
0005434319494	5719	Economy	14400.00
0005434319503	5719	Economy	14400.00
0005434319490	5719	Economy	14400.00
0005434319498	5719	Economy	14400.00
0005433123896	5719	Economy	14400.00
0005433123861	5719	Economy	14400.00
0005434319489	5719	Economy	14400.00
0005433123852	5719	Economy	14400.00
0005433123898	5719	Economy	14400.00
0005433123888	5719	Economy	14400.00
0005433123893	5719	Economy	14400.00
0005432109719	5719	Economy	14400.00
0005432109721	5719	Economy	14400.00
0005433123882	5719	Economy	14400.00
0005434312309	15681	Business	43300.00
0005434319376	15681	Business	43300.00
0005433124062	15681	Business	43300.00
0005434319393	15681	Business	43300.00
0005433124071	15681	Business	43300.00
0005434319382	15681	Business	43300.00
0005434311213	15681	Economy	14400.00
0005434319324	15681	Economy	15900.00
0005434319374	15681	Economy	15900.00
0005434311214	15681	Economy	15900.00
0005433124067	15681	Economy	15900.00
0005433124053	15681	Economy	14400.00
0005433124052	15681	Economy	14400.00
0005433124063	15681	Economy	14400.00
0005433124068	15681	Economy	14400.00
0005433124061	15681	Economy	14400.00
0005433124072	15681	Economy	14400.00
0005433124065	15681	Economy	14400.00
0005433124060	15681	Economy	14400.00
0005434319244	15681	Economy	14400.00
0005434319375	15681	Economy	14400.00
0005433124069	15681	Economy	14400.00
0005433124058	15681	Economy	14400.00
0005433124070	15681	Economy	14400.00
0005434312310	15681	Economy	14400.00
0005434319377	15681	Economy	14400.00
0005433124057	15681	Economy	14400.00
0005433124051	15681	Economy	14400.00
0005433124055	15681	Economy	14400.00
0005434319340	15681	Economy	14400.00
0005434319323	15681	Economy	14400.00
0005433124073	15681	Economy	14400.00
0005433124059	15681	Economy	14400.00
0005433124054	15681	Economy	14400.00
0005434319367	15681	Economy	14400.00
0005433124056	15681	Economy	14400.00
0005433124066	15681	Economy	14400.00
0005434311215	15681	Economy	14400.00
0005433124064	15681	Economy	14400.00
0005435220333	31738	Economy	15500.00
0005435220331	31738	Economy	15500.00
0005435220334	31738	Economy	15500.00
0005435219215	31738	Economy	15500.00
0005435220332	31738	Economy	15500.00
0005435219212	31738	Economy	15500.00
0005435220492	31738	Economy	15500.00
0005435219214	31738	Economy	15500.00
0005435219213	31738	Economy	15500.00
0005434484387	8985	Economy	27400.00
0005434484386	8985	Economy	27400.00
0005434484392	8985	Economy	24900.00
0005434189152	8985	Economy	24900.00
0005434189176	8985	Economy	24900.00
0005434189175	8985	Economy	24900.00
0005434484393	8985	Economy	24900.00
0005434189169	8985	Economy	24900.00
0005434189173	8985	Economy	24900.00
0005434189174	8985	Economy	24900.00
0005434189167	8985	Economy	24900.00
0005434189172	8985	Economy	24900.00
0005434189168	8985	Economy	24900.00
0005434484389	8985	Economy	24900.00
0005434484388	8985	Economy	24900.00
0005434189177	8985	Economy	24900.00
0005434484391	8985	Economy	24900.00
0005434484390	8985	Economy	24900.00
0005434484304	16640	Economy	27400.00
0005434484338	16640	Economy	27400.00
0005434189215	16640	Economy	27400.00
0005434484341	16640	Economy	24900.00
0005434484351	16640	Economy	24900.00
0005434189217	16640	Economy	24900.00
0005434484346	16640	Economy	24900.00
0005434484321	16640	Economy	24900.00
0005434484342	16640	Economy	24900.00
0005434189216	16640	Economy	24900.00
0005434189214	16640	Economy	24900.00
0005434484313	16640	Economy	24900.00
0005434484306	16640	Economy	24900.00
0005434484333	16640	Economy	24900.00
0005434189213	16640	Economy	24900.00
0005434484305	16640	Economy	24900.00
0005434484320	16640	Economy	24900.00
0005434189212	16640	Economy	24900.00
0005433124069	7624	Business	11100.00
0005433124058	7624	Business	11100.00
0005433124064	7624	Business	11100.00
0005433124054	7624	Business	11100.00
0005433124072	7624	Economy	3700.00
0005433124068	7624	Economy	3700.00
0005433124063	7624	Economy	3700.00
0005433124051	7624	Economy	4100.00
0005433722189	7624	Economy	4100.00
0005433722198	7624	Economy	3700.00
0005433124067	7624	Economy	3700.00
0005433124057	7624	Economy	3700.00
0005433124062	7624	Economy	3700.00
0005433124052	7624	Economy	3700.00
0005433722177	7624	Economy	3700.00
0005433124070	7624	Economy	3700.00
0005433124073	7624	Economy	3700.00
0005433722168	7624	Economy	3700.00
0005433722190	7624	Economy	3700.00
0005433124059	7624	Economy	3700.00
0005433722188	7624	Economy	3700.00
0005433124055	7624	Economy	3700.00
0005433124061	7624	Economy	3700.00
0005433124065	7624	Economy	3700.00
0005433124056	7624	Economy	3700.00
0005433124053	7624	Economy	3700.00
0005433124066	7624	Economy	3700.00
0005433124060	7624	Economy	3700.00
0005433722197	7624	Economy	3700.00
0005433124071	7624	Economy	3700.00
0005432721062	7625	Business	11100.00
0005432721065	7625	Business	11100.00
0005432721064	7625	Business	11100.00
0005432721072	7625	Business	11100.00
0005432071592	7625	Business	11100.00
0005432693254	7625	Business	11100.00
0005432693276	7625	Business	11100.00
0005433450101	7625	Business	11100.00
0005432721071	7625	Business	11100.00
0005432693257	7625	Business	11100.00
0005433450109	7625	Economy	3700.00
0005433450103	7625	Economy	3700.00
0005432693269	7625	Economy	3700.00
0005432721073	7625	Economy	3700.00
0005432693272	7625	Economy	3700.00
0005433450096	7625	Economy	3700.00
0005432693262	7625	Economy	3700.00
0005432693277	7625	Economy	3700.00
0005432693270	7625	Economy	4100.00
0005432721068	7625	Economy	4100.00
0005432721085	7625	Economy	4100.00
0005433450100	7625	Economy	4100.00
0005432721076	7625	Economy	3700.00
0005432721083	7625	Economy	3700.00
0005432693271	7625	Economy	3700.00
0005432693280	7625	Economy	3700.00
0005432721060	7625	Economy	3700.00
0005432693275	7625	Economy	3700.00
0005432721069	7625	Economy	3700.00
0005433450104	7625	Economy	3700.00
0005432721066	7625	Economy	3700.00
0005433450097	7625	Economy	3700.00
0005432721061	7625	Economy	3700.00
0005432693281	7625	Economy	3700.00
0005432721074	7625	Economy	3700.00
0005432721070	7625	Economy	3700.00
0005432693264	7625	Economy	3700.00
0005433450105	7625	Economy	3700.00
0005432721079	7625	Economy	3700.00
0005432693278	7625	Economy	3700.00
0005432721080	7625	Economy	3700.00
0005433450111	7625	Economy	3700.00
0005432071591	7625	Economy	3700.00
0005433450113	7625	Economy	3700.00
0005432693279	7625	Economy	3700.00
0005432693256	7625	Economy	3700.00
0005433450108	7625	Economy	3700.00
0005432693255	7625	Economy	3700.00
0005432693261	7625	Economy	3700.00
0005432721078	7625	Economy	3700.00
0005432693253	7625	Economy	3700.00
0005432721084	7625	Economy	3700.00
0005432693259	7625	Economy	3700.00
0005433450114	7625	Economy	3700.00
0005433450110	7625	Economy	3700.00
0005433450118	7625	Economy	3700.00
0005433450106	7625	Economy	3700.00
0005432721077	7625	Economy	3700.00
0005432693263	7625	Economy	3700.00
0005432693267	7625	Economy	3700.00
0005433450099	7625	Economy	3700.00
0005432693268	7625	Economy	3700.00
0005432071593	7625	Economy	3700.00
0005433450116	7625	Economy	3700.00
0005432721081	7625	Economy	3700.00
0005432693265	7625	Economy	3700.00
0005432693284	7625	Economy	3700.00
0005433450098	7625	Economy	3700.00
0005432721063	7625	Economy	3700.00
0005432721075	7625	Economy	3700.00
0005432693282	7625	Economy	3700.00
0005433450115	7625	Economy	3700.00
0005432721082	7625	Economy	3700.00
0005433450117	7625	Economy	3700.00
0005432693258	7625	Economy	3700.00
0005433450102	7625	Economy	3700.00
0005432693266	7625	Economy	3700.00
0005432693260	7625	Economy	3700.00
0005432693273	7625	Economy	3700.00
0005432693283	7625	Economy	3700.00
0005432721086	7625	Economy	3700.00
0005432721067	7625	Economy	3700.00
0005433450107	7625	Economy	3700.00
0005433450112	7625	Economy	3700.00
0005432693274	7625	Economy	3700.00
0005432693084	30287	Business	11100.00
0005433449981	30287	Business	11100.00
0005433449926	30287	Business	11100.00
0005433449880	30287	Business	11100.00
0005432693087	30287	Business	11100.00
0005432692931	30287	Business	11100.00
0005433449973	30287	Economy	3700.00
0005432692978	30287	Economy	3700.00
0005433449930	30287	Economy	3700.00
0005432692907	30287	Economy	3700.00
0005433449910	30287	Economy	3700.00
0005432692981	30287	Economy	4100.00
0005432693057	30287	Economy	4100.00
0005432692896	30287	Economy	4100.00
0005432692953	30287	Economy	3700.00
0005432693088	30287	Economy	3700.00
0005433449970	30287	Economy	3700.00
0005433450005	30287	Economy	3700.00
0005432693040	30287	Economy	3700.00
0005433449969	30287	Economy	3700.00
0005432692864	30287	Economy	3700.00
0005432693001	30287	Economy	3700.00
0005432692904	30287	Economy	3700.00
0005433450002	30287	Economy	3700.00
0005432693010	30287	Economy	3700.00
0005432692960	30287	Economy	3700.00
0005432693065	30287	Economy	3700.00
0005432693060	30287	Economy	3700.00
0005433449913	30287	Economy	3700.00
0005432692971	30287	Economy	3700.00
0005432693030	30287	Economy	3700.00
0005433449909	30287	Economy	3700.00
0005432692930	30287	Economy	3700.00
0005432692970	30287	Economy	3700.00
0005433449980	30287	Economy	3700.00
0005432692979	30287	Economy	3700.00
0005432692977	30287	Economy	3700.00
0005432692998	30287	Economy	3700.00
0005432693023	30287	Economy	3700.00
0005432692909	30287	Economy	3700.00
0005432693002	30287	Economy	3700.00
0005432692773	30287	Economy	3700.00
0005433449927	30287	Economy	3700.00
0005432693041	30287	Economy	3700.00
0005432692908	30287	Economy	3700.00
0005433449929	30287	Economy	3700.00
0005433449965	30287	Economy	3700.00
0005432692952	30287	Economy	3700.00
0005433449972	30287	Economy	3700.00
0005433450001	30287	Economy	3700.00
0005432692999	30287	Economy	3700.00
0005432693025	30287	Economy	3700.00
0005432693026	30287	Economy	3700.00
0005433449908	30287	Economy	3700.00
0005432693027	30287	Economy	3700.00
0005433123977	30288	Business	11100.00
0005432720830	30288	Business	11100.00
0005433123879	30288	Business	11100.00
0005432720943	30288	Business	11100.00
0005433123880	30288	Economy	3700.00
0005433123888	30288	Economy	3700.00
0005433123836	30288	Economy	3700.00
0005432720886	30288	Economy	3700.00
0005433123857	30288	Economy	3700.00
0005432720907	30288	Economy	3700.00
0005432720711	30288	Economy	3700.00
0005433722271	30288	Economy	3700.00
0005433123824	30288	Economy	3700.00
0005432720878	30288	Economy	4100.00
0005432720816	30288	Economy	4100.00
0005432720905	30288	Economy	3700.00
0005433123803	30288	Economy	3700.00
0005433123896	30288	Economy	3700.00
0005433123837	30288	Economy	3700.00
0005433123869	30288	Economy	3700.00
0005432720747	30288	Economy	3700.00
0005433123882	30288	Economy	3700.00
0005433123861	30288	Economy	3700.00
0005432720889	30288	Economy	3700.00
0005433722270	30288	Economy	3700.00
0005433123893	30288	Economy	3700.00
0005433123968	30288	Economy	3700.00
0005433123862	30288	Economy	3700.00
0005433123903	30288	Economy	3700.00
0005433123913	30288	Economy	3700.00
0005433123825	30288	Economy	3700.00
0005433123892	30288	Economy	3700.00
0005432720874	30288	Economy	3700.00
0005432720834	30288	Economy	3700.00
0005433123887	30288	Economy	3700.00
0005432720831	30288	Economy	3700.00
0005433123859	30288	Economy	3700.00
0005432720858	30288	Economy	3700.00
0005432720823	30288	Economy	3700.00
0005432720890	30288	Economy	3700.00
0005432720829	30288	Economy	3700.00
0005433123852	30288	Economy	3700.00
0005433123904	30288	Economy	3700.00
0005432720912	30288	Economy	3700.00
0005432720822	30288	Economy	3700.00
0005432720903	30288	Economy	3700.00
0005433123898	30288	Economy	3700.00
0005432720835	30288	Economy	3700.00
0005432720906	30288	Economy	3700.00
0005433123864	30288	Economy	3700.00
0005433123976	30288	Economy	3700.00
0005433123860	30288	Economy	3700.00
0005432271023	1371	Business	70400.00
0005434586778	1371	Business	70400.00
0005433724831	1371	Business	70400.00
0005433193027	1371	Business	70400.00
0005433525102	1371	Business	70400.00
0005434514984	1371	Business	70400.00
0005434586777	1371	Business	70400.00
0005433525112	1371	Business	70400.00
0005434586772	1371	Business	70400.00
0005433525104	1371	Economy	23500.00
0005434514985	1371	Economy	23500.00
0005432927977	1371	Economy	23500.00
0005434513595	1371	Economy	23500.00
0005434586787	1371	Economy	23500.00
0005433525106	1371	Economy	23500.00
0005434586770	1371	Economy	23500.00
0005434586775	1371	Economy	25800.00
0005433724835	1371	Economy	25800.00
0005434586774	1371	Economy	25800.00
0005434586782	1371	Economy	23500.00
0005434586766	1371	Economy	23500.00
0005434586780	1371	Economy	23500.00
0005432927962	1371	Economy	23500.00
0005434586785	1371	Economy	23500.00
0005433525110	1371	Economy	23500.00
0005432927963	1371	Economy	23500.00
0005433193000	1371	Economy	23500.00
0005434586776	1371	Economy	23500.00
0005433193057	1371	Economy	23500.00
0005434586763	1371	Economy	23500.00
0005433525105	1371	Economy	23500.00
0005433193028	1371	Economy	23500.00
0005434586788	1371	Economy	23500.00
0005433525109	1371	Economy	23500.00
0005432271022	1371	Economy	23500.00
0005432968837	1371	Economy	23500.00
0005434586781	1371	Economy	23500.00
0005433724832	1371	Economy	23500.00
0005432927961	1371	Economy	23500.00
0005434586771	1371	Economy	23500.00
0005433193029	1371	Economy	23500.00
0005433525108	1371	Economy	23500.00
0005432271021	1371	Economy	23500.00
0005434586786	1371	Economy	23500.00
0005434586768	1371	Economy	23500.00
0005434513597	1371	Economy	23500.00
0005434586764	1371	Economy	23500.00
0005434586765	1371	Economy	23500.00
0005434586783	1371	Economy	23500.00
0005433525103	1371	Economy	23500.00
0005433525111	1371	Economy	23500.00
0005432927998	1371	Economy	23500.00
0005434586779	1371	Economy	23500.00
0005433724834	1371	Economy	23500.00
0005433193059	1371	Economy	23500.00
0005434586767	1371	Economy	23500.00
0005434586769	1371	Economy	23500.00
0005432927997	1371	Economy	23500.00
0005433193018	1371	Economy	23500.00
0005434513596	1371	Economy	23500.00
0005433724833	1371	Economy	23500.00
0005434586784	1371	Economy	23500.00
0005432927960	1371	Economy	23500.00
0005433193058	1371	Economy	23500.00
0005433525107	1371	Economy	23500.00
0005434586773	1371	Economy	23500.00
0005433524995	18525	Business	70400.00
0005434586556	18525	Business	70400.00
0005433193133	18525	Business	70400.00
0005432928011	18525	Business	70400.00
0005433525009	18525	Business	70400.00
0005434586606	18525	Business	70400.00
0005433724804	18525	Economy	23500.00
0005433524974	18525	Economy	23500.00
0005434586594	18525	Economy	23500.00
0005434586590	18525	Economy	23500.00
0005433193136	18525	Economy	23500.00
0005432928016	18525	Economy	23500.00
0005433193126	18525	Economy	25800.00
0005434586585	18525	Economy	25800.00
0005432928015	18525	Economy	25800.00
0005433193134	18525	Economy	25800.00
0005434586558	18525	Economy	23500.00
0005433525024	18525	Economy	23500.00
0005432928013	18525	Economy	23500.00
0005433724803	18525	Economy	23500.00
0005433524979	18525	Economy	23500.00
0005433193124	18525	Economy	23500.00
0005434586544	18525	Economy	23500.00
0005433724774	18525	Economy	23500.00
0005433524993	18525	Economy	23500.00
0005434514966	18525	Economy	23500.00
0005434586545	18525	Economy	23500.00
0005433193127	18525	Economy	23500.00
0005433525015	18525	Economy	23500.00
0005433193128	18525	Economy	23500.00
0005433193135	18525	Economy	23500.00
0005433193130	18525	Economy	23500.00
0005433193129	18525	Economy	23500.00
0005434586521	18525	Economy	23500.00
0005434514968	18525	Economy	23500.00
0005433524975	18525	Economy	23500.00
0005433193137	18525	Economy	23500.00
0005434586578	18525	Economy	23500.00
0005432968853	18525	Economy	23500.00
0005432928014	18525	Economy	23500.00
0005434586557	18525	Economy	23500.00
0005434586549	18525	Economy	23500.00
0005433724805	18525	Economy	23500.00
0005434586592	18525	Economy	23500.00
0005433524991	18525	Economy	23500.00
0005434586553	18525	Economy	23500.00
0005434586484	18525	Economy	23500.00
0005432928012	18525	Economy	23500.00
0005434586548	18525	Economy	23500.00
0005432968854	18525	Economy	23500.00
0005434586512	18525	Economy	23500.00
0005434586543	18525	Economy	23500.00
0005433193132	18525	Economy	23500.00
0005433193131	18525	Economy	23500.00
0005433193125	18525	Economy	23500.00
0005433524992	18525	Economy	23500.00
0005432928017	18525	Economy	23500.00
0005434514967	18525	Economy	23500.00
0005433724816	18525	Economy	23500.00
0005434586483	18525	Economy	23500.00
0005433525010	18525	Economy	23500.00
0005433525014	18525	Economy	23500.00
0005434344436	11453	Economy	4300.00
0005434344402	11453	Economy	4300.00
0005434344399	11453	Economy	4300.00
0005434344410	11453	Economy	4300.00
0005434344431	11453	Economy	4000.00
0005434142639	11453	Economy	4000.00
0005434344421	11453	Economy	4000.00
0005434344433	11453	Economy	4000.00
0005434344434	11453	Economy	4000.00
0005434344411	11453	Economy	4000.00
0005434344412	11453	Economy	4000.00
0005434344400	11453	Economy	4000.00
0005435302188	11453	Economy	4000.00
0005434344423	11453	Economy	4000.00
0005434344426	11453	Economy	4000.00
0005434344419	11453	Economy	4000.00
0005434344414	11453	Economy	4000.00
0005435302184	11453	Economy	4000.00
0005435302167	11453	Economy	4000.00
0005434344418	11453	Economy	4000.00
0005434344408	11453	Economy	4000.00
0005434344416	11453	Economy	4000.00
0005434344422	11453	Economy	4000.00
0005434344427	11453	Economy	4000.00
0005434344401	11453	Economy	4000.00
0005434344404	11453	Economy	4000.00
0005435302164	11453	Economy	4000.00
0005434344415	11453	Economy	4000.00
0005434344405	11453	Economy	4000.00
0005434344407	11453	Economy	4000.00
0005434344429	11453	Economy	4000.00
0005434344435	11453	Economy	4000.00
0005434344413	11453	Economy	4000.00
0005435302187	11453	Economy	4000.00
0005434344406	11453	Economy	4000.00
0005434142636	11453	Economy	4000.00
0005434344417	11453	Economy	4000.00
0005434344403	11453	Economy	4000.00
0005434344424	11453	Economy	4000.00
0005434344420	11453	Economy	4000.00
0005435302183	11453	Economy	4000.00
0005434142637	11453	Economy	4000.00
0005434344432	11453	Economy	4000.00
0005435302182	11453	Economy	4000.00
0005434344428	11453	Economy	4000.00
0005434344425	11453	Economy	4000.00
0005434142635	11453	Economy	4000.00
0005434344430	11453	Economy	4000.00
0005434142638	11453	Economy	4000.00
0005434344409	11453	Economy	4000.00
0005434142607	29761	Economy	4300.00
0005434343977	29761	Economy	4300.00
0005434142604	29761	Economy	4300.00
0005434344055	29761	Economy	4300.00
0005434343969	29761	Economy	4000.00
0005434344176	29761	Economy	4000.00
0005434344034	29761	Economy	4000.00
0005434344079	29761	Economy	4000.00
0005434142605	29761	Economy	4000.00
0005434142606	29761	Economy	4000.00
0005434344167	29761	Economy	4000.00
0005434344007	29761	Economy	4000.00
0005434344134	29761	Economy	4000.00
0005434344091	29761	Economy	4000.00
0005434344056	29761	Economy	4000.00
0005434344069	29761	Economy	4000.00
0005434344114	29761	Economy	4000.00
0005434344092	29761	Economy	4000.00
0005434344181	29761	Economy	4000.00
0005434344086	29761	Economy	4000.00
0005434344029	29761	Economy	4000.00
0005434344168	29761	Economy	4000.00
0005434344084	29761	Economy	4000.00
0005434344160	29761	Economy	4000.00
0005434343928	29761	Economy	4000.00
0005434344064	29761	Economy	4000.00
0005434344163	29761	Economy	4000.00
0005434344146	29761	Economy	4000.00
0005434344141	29761	Economy	4000.00
0005434344216	29761	Economy	4000.00
0005434344148	29761	Economy	4000.00
0005434344161	29761	Economy	4000.00
0005434344008	29761	Economy	4000.00
0005434344109	29761	Economy	4000.00
0005434344001	29761	Economy	4000.00
0005434344020	29761	Economy	4000.00
0005434142603	29761	Economy	4000.00
0005434344036	29761	Economy	4000.00
0005434344143	29761	Economy	4000.00
0005434344119	29761	Economy	4000.00
0005434344144	29761	Economy	4000.00
0005434142588	29761	Economy	4000.00
0005434344215	29761	Economy	4000.00
0005434344203	29761	Economy	4000.00
0005434344147	29761	Economy	4000.00
0005435304187	29761	Economy	4000.00
0005434344035	29761	Economy	4000.00
0005434142608	29761	Economy	4000.00
0005434344090	29761	Economy	4000.00
0005434344065	29761	Economy	4000.00
0005435824806	1281	Business	199800.00
0005435824805	1281	Business	199800.00
0005435824785	1281	Business	199800.00
0005435824786	1281	Business	199800.00
0005435824788	1281	Business	199800.00
0005433415605	1281	Business	199800.00
0005433415673	1281	Business	199800.00
0005435824783	1281	Economy	66600.00
0005435824802	1281	Economy	66600.00
0005433415558	1281	Economy	66600.00
0005435824807	1281	Economy	66600.00
0005435824800	1281	Economy	73200.00
0005435824790	1281	Economy	66600.00
0005435824801	1281	Economy	66600.00
0005432284576	1281	Economy	66600.00
0005435824794	1281	Economy	66600.00
0005433415622	1281	Economy	66600.00
0005435824793	1281	Economy	66600.00
0005435824799	1281	Economy	66600.00
0005435824797	1281	Economy	66600.00
0005435824808	1281	Economy	66600.00
0005435824789	1281	Economy	66600.00
0005435824809	1281	Economy	66600.00
0005433415587	1281	Economy	66600.00
0005435824798	1281	Economy	66600.00
0005432284578	1281	Economy	66600.00
0005435824803	1281	Economy	66600.00
0005435824795	1281	Economy	66600.00
0005433415668	1281	Economy	66600.00
0005435824792	1281	Economy	66600.00
0005432284577	1281	Economy	66600.00
0005433415588	1281	Economy	66600.00
0005435824791	1281	Economy	66600.00
0005433415560	1281	Economy	66600.00
0005433415559	1281	Economy	66600.00
0005433415632	1281	Economy	66600.00
0005435824784	1281	Economy	66600.00
0005435824796	1281	Economy	66600.00
0005435824787	1281	Economy	66600.00
0005433415631	1281	Economy	66600.00
0005435824804	1281	Economy	66600.00
0005435824528	17972	Business	199800.00
0005433415760	17972	Business	199800.00
0005433415754	17972	Business	199800.00
0005433415765	17972	Business	199800.00
0005435824561	17972	Business	199800.00
0005435824517	17972	Economy	66600.00
0005433415767	17972	Economy	66600.00
0005435824491	17972	Economy	66600.00
0005435824535	17972	Economy	66600.00
0005433415768	17972	Economy	66600.00
0005433415753	17972	Economy	66600.00
0005435824661	17972	Economy	73200.00
0005435824595	17972	Economy	66600.00
0005435824710	17972	Economy	66600.00
0005433415758	17972	Economy	66600.00
0005435824605	17972	Economy	66600.00
0005435824396	17972	Economy	66600.00
0005435824610	17972	Economy	66600.00
0005435824557	17972	Economy	66600.00
0005435824465	17972	Economy	66600.00
0005435824709	17972	Economy	66600.00
0005435824466	17972	Economy	66600.00
0005435824636	17972	Economy	66600.00
0005433415762	17972	Economy	66600.00
0005435824569	17972	Economy	66600.00
0005435824679	17972	Economy	66600.00
0005433415761	17972	Economy	66600.00
0005433415759	17972	Economy	66600.00
0005433415763	17972	Economy	66600.00
0005433415766	17972	Economy	66600.00
0005435824613	17972	Economy	66600.00
0005435824609	17972	Economy	66600.00
0005435824562	17972	Economy	66600.00
0005433415764	17972	Economy	66600.00
0005435824594	17972	Economy	66600.00
0005433415755	17972	Economy	66600.00
0005433415757	17972	Economy	66600.00
0005435824665	17972	Economy	66600.00
0005433415756	17972	Economy	66600.00
0005435824587	17972	Economy	66600.00
0005435242556	5631	Business	27800.00
0005432784151	5631	Business	27800.00
0005435476735	5631	Business	27800.00
0005432784126	5631	Business	27800.00
0005432784120	5631	Business	27800.00
0005432784108	5631	Business	27800.00
0005432784136	5631	Business	27800.00
0005432784155	5631	Business	27800.00
0005432784129	5631	Business	27800.00
0005435242777	5631	Business	27800.00
0005435476742	5631	Economy	9300.00
0005432784114	5631	Economy	9300.00
0005432784121	5631	Economy	9300.00
0005435242796	5631	Economy	9300.00
0005432784119	5631	Economy	9300.00
0005432784118	5631	Economy	9300.00
0005432784140	5631	Economy	9300.00
0005435476681	5631	Economy	9300.00
0005432784122	5631	Economy	10200.00
0005435242705	5631	Economy	10200.00
0005432784134	5631	Economy	10200.00
0005435242642	5631	Economy	10200.00
0005435476733	5631	Economy	10200.00
0005435242731	5631	Economy	9300.00
0005432784146	5631	Economy	9300.00
0005435242841	5631	Economy	9300.00
0005435242652	5631	Economy	9300.00
0005432784138	5631	Economy	9300.00
0005432784158	5631	Economy	9300.00
0005432784159	5631	Economy	9300.00
0005432784112	5631	Economy	9300.00
0005432784124	5631	Economy	9300.00
0005432784109	5631	Economy	9300.00
0005435242848	5631	Economy	9300.00
0005432784148	5631	Economy	9300.00
0005435242784	5631	Economy	9300.00
0005432784116	5631	Economy	9300.00
0005432144008	5631	Economy	9300.00
0005432784110	5631	Economy	9300.00
0005432784123	5631	Economy	9300.00
0005435242795	5631	Economy	9300.00
0005432784128	5631	Economy	9300.00
0005432784139	5631	Economy	9300.00
0005435242693	5631	Economy	9300.00
0005435242814	5631	Economy	9300.00
0005435242741	5631	Economy	9300.00
0005432784115	5631	Economy	9300.00
0005432784133	5631	Economy	9300.00
0005435242876	5631	Economy	9300.00
0005432784157	5631	Economy	9300.00
0005432784142	5631	Economy	9300.00
0005432784117	5631	Economy	9300.00
0005432784135	5631	Economy	9300.00
0005435242707	5631	Economy	9300.00
0005435242730	5631	Economy	9300.00
0005432784152	5631	Economy	9300.00
0005432784111	5631	Economy	9300.00
0005432784147	5631	Economy	9300.00
0005435242783	5631	Economy	9300.00
0005435476741	5631	Economy	9300.00
0005432784143	5631	Economy	9300.00
0005435242729	5631	Economy	9300.00
0005432784125	5631	Economy	9300.00
0005432784131	5631	Economy	9300.00
0005432144009	5631	Economy	9300.00
0005432784130	5631	Economy	9300.00
0005432784153	5631	Economy	9300.00
0005435242813	5631	Economy	9300.00
0005432784132	5631	Economy	9300.00
0005432784149	5631	Economy	9300.00
0005432784106	5631	Economy	9300.00
0005432784107	5631	Economy	9300.00
0005432784144	5631	Economy	9300.00
0005435476734	5631	Economy	9300.00
0005435242726	5631	Economy	9300.00
0005435476726	5631	Economy	9300.00
0005435242776	5631	Economy	9300.00
0005435476752	5631	Economy	9300.00
0005432784113	5631	Economy	9300.00
0005432784127	5631	Economy	9300.00
0005432784154	5631	Economy	9300.00
0005432784156	5631	Economy	9300.00
0005435242725	5631	Economy	9300.00
0005435242817	5631	Economy	9300.00
0005432784137	5631	Economy	9300.00
0005432784141	5631	Economy	9300.00
0005435242692	5631	Economy	9300.00
0005432784150	5631	Economy	9300.00
0005432784145	5631	Economy	9300.00
0005432783739	15379	Business	27800.00
0005432783725	15379	Business	27800.00
0005435243014	15379	Business	27800.00
0005432783504	15379	Business	27800.00
0005432783366	15379	Business	27800.00
0005432783651	15379	Business	27800.00
0005435243001	15379	Business	27800.00
0005432783530	15379	Business	27800.00
0005432783475	15379	Business	27800.00
0005432783556	15379	Business	27800.00
0005435243015	15379	Business	27800.00
0005435243011	15379	Business	27800.00
0005432783414	15379	Economy	9300.00
0005432783854	15379	Economy	9300.00
0005435243009	15379	Economy	9300.00
0005432783502	15379	Economy	9300.00
0005435242995	15379	Economy	9300.00
0005432783625	15379	Economy	9300.00
0005432783773	15379	Economy	9300.00
0005432783496	15379	Economy	9300.00
0005435243006	15379	Economy	9300.00
0005432783551	15379	Economy	10200.00
0005435243000	15379	Economy	10200.00
0005432783233	15379	Economy	10200.00
0005435476794	15379	Economy	10200.00
0005435476795	15379	Economy	10200.00
0005435243002	15379	Economy	9300.00
0005435243013	15379	Economy	9300.00
0005435242997	15379	Economy	9300.00
0005435476796	15379	Economy	9300.00
0005435243016	15379	Economy	9300.00
0005432783694	15379	Economy	9300.00
0005432783763	15379	Economy	9300.00
0005435476798	15379	Economy	9300.00
0005432783673	15379	Economy	9300.00
0005432783693	15379	Economy	9300.00
0005435242999	15379	Economy	9300.00
0005432783700	15379	Economy	9300.00
0005432783497	15379	Economy	9300.00
0005432783696	15379	Economy	9300.00
0005432783577	15379	Economy	9300.00
0005435243012	15379	Economy	9300.00
0005435243005	15379	Economy	9300.00
0005432783695	15379	Economy	9300.00
0005432783324	15379	Economy	9300.00
0005432783752	15379	Economy	9300.00
0005432783762	15379	Economy	9300.00
0005435476802	15379	Economy	9300.00
0005435243017	15379	Economy	9300.00
0005432783490	15379	Economy	9300.00
0005432783323	15379	Economy	9300.00
0005435476792	15379	Economy	9300.00
0005432783634	15379	Economy	9300.00
0005432783322	15379	Economy	9300.00
0005432783671	15379	Economy	9300.00
0005435476797	15379	Economy	9300.00
0005435242994	15379	Economy	9300.00
0005432783692	15379	Economy	9300.00
0005432783798	15379	Economy	9300.00
0005435242993	15379	Economy	9300.00
0005432783922	15379	Economy	9300.00
0005435243007	15379	Economy	9300.00
0005435476793	15379	Economy	9300.00
0005432783552	15379	Economy	9300.00
0005435243018	15379	Economy	9300.00
0005435243008	15379	Economy	9300.00
0005432783656	15379	Economy	9300.00
0005435243004	15379	Economy	9300.00
0005435243003	15379	Economy	9300.00
0005432783672	15379	Economy	9300.00
0005435242996	15379	Economy	9300.00
0005435476799	15379	Economy	9300.00
0005435242991	15379	Economy	9300.00
0005432783813	15379	Economy	9300.00
0005435476801	15379	Economy	9300.00
0005435243010	15379	Economy	9300.00
0005432783505	15379	Economy	9300.00
0005435242992	15379	Economy	9300.00
0005432783557	15379	Economy	9300.00
0005435476800	15379	Economy	9300.00
0005435242998	15379	Economy	9300.00
0005432783379	15379	Economy	9300.00
0005432783578	15379	Economy	9300.00
0005432783548	15379	Economy	9300.00
0005432783503	15379	Economy	9300.00
0005435850925	4392	Economy	7000.00
0005432848406	4392	Economy	7000.00
0005432848398	4392	Economy	6300.00
0005435850912	4392	Economy	6300.00
0005432848404	4392	Economy	6300.00
0005432848401	4392	Economy	6300.00
0005432848409	4392	Economy	6300.00
0005432848397	4392	Economy	6300.00
0005434463943	4392	Economy	6300.00
0005432848405	4392	Economy	6300.00
0005435850904	4392	Economy	6300.00
0005434462804	4392	Economy	6300.00
0005432848408	4392	Economy	6300.00
0005435850913	4392	Economy	6300.00
0005432848402	4392	Economy	6300.00
0005432848403	4392	Economy	6300.00
0005435850831	4392	Economy	6300.00
0005434463942	4392	Economy	6300.00
0005432848400	4392	Economy	6300.00
0005432848399	4392	Economy	6300.00
0005435850884	4392	Economy	6300.00
0005435850914	4392	Economy	6300.00
0005432848407	4392	Economy	6300.00
0005432848410	4392	Economy	6300.00
0005434463917	28835	Economy	7000.00
0005435850971	28835	Economy	7000.00
0005435850969	28835	Economy	7000.00
0005435850965	28835	Economy	6300.00
0005432848164	28835	Economy	6300.00
0005434463916	28835	Economy	6300.00
0005435850964	28835	Economy	6300.00
0005432848308	28835	Economy	6300.00
0005432848297	28835	Economy	6300.00
0005434463929	28835	Economy	6300.00
0005432848314	28835	Economy	6300.00
0005432848258	28835	Economy	6300.00
0005435850966	28835	Economy	6300.00
0005432848263	28835	Economy	6300.00
0005435850967	28835	Economy	6300.00
0005434463921	28835	Economy	6300.00
0005432848257	28835	Economy	6300.00
0005432848284	28835	Economy	6300.00
0005435850968	28835	Economy	6300.00
0005432848262	28835	Economy	6300.00
0005435850972	28835	Economy	6300.00
0005435850970	28835	Economy	6300.00
0005432848315	28835	Economy	6300.00
0005434463915	28835	Economy	6300.00
0005432848303	28835	Economy	6300.00
0005432848259	28835	Economy	6300.00
0005434463926	28835	Economy	6300.00
0005433497178	6258	Business	11900.00
0005434443812	6258	Business	11900.00
0005433497160	6258	Business	11900.00
0005433497161	6258	Business	11900.00
0005434926019	6258	Business	11900.00
0005433497184	6258	Business	11900.00
0005434443807	6258	Business	11900.00
0005433497177	6258	Business	11900.00
0005433497156	6258	Business	11900.00
0005434925990	6258	Business	11900.00
0005434925999	6258	Business	11900.00
0005434443810	6258	Business	11900.00
0005434925991	6258	Economy	4000.00
0005433497167	6258	Economy	4000.00
0005433497166	6258	Economy	4000.00
0005433497164	6258	Economy	4000.00
0005434443809	6258	Economy	4000.00
0005434925998	6258	Economy	4000.00
0005433497158	6258	Economy	4000.00
0005433497159	6258	Economy	4000.00
0005433497182	6258	Economy	4400.00
0005434443806	6258	Economy	4400.00
0005433497162	6258	Economy	4400.00
0005433497175	6258	Economy	4400.00
0005434926022	6258	Economy	4400.00
0005433497157	6258	Economy	4000.00
0005433497180	6258	Economy	4000.00
0005434926021	6258	Economy	4000.00
0005433497179	6258	Economy	4000.00
0005433497176	6258	Economy	4000.00
0005434926010	6258	Economy	4000.00
0005433497170	6258	Economy	4000.00
0005434925993	6258	Economy	4000.00
0005434925992	6258	Economy	4000.00
0005434926008	6258	Economy	4000.00
0005434926007	6258	Economy	4000.00
0005434443808	6258	Economy	4000.00
0005434926006	6258	Economy	4000.00
0005433497154	6258	Economy	4000.00
0005434926015	6258	Economy	4000.00
0005433497165	6258	Economy	4000.00
0005434443817	6258	Economy	4000.00
0005433497185	6258	Economy	4000.00
0005434443811	6258	Economy	4000.00
0005434926002	6258	Economy	4000.00
0005433497169	6258	Economy	4000.00
0005434925997	6258	Economy	4000.00
0005434926011	6258	Economy	4000.00
0005433497163	6258	Economy	4000.00
0005434926023	6258	Economy	4000.00
0005434926001	6258	Economy	4000.00
0005434926020	6258	Economy	4000.00
0005433497172	6258	Economy	4000.00
0005433497155	6258	Economy	4000.00
0005433497168	6258	Economy	4000.00
0005434926000	6258	Economy	4000.00
0005433497183	6258	Economy	4000.00
0005434926016	6258	Economy	4000.00
0005433497173	6258	Economy	4000.00
0005434925994	6258	Economy	4000.00
0005434925989	6258	Economy	4000.00
0005433497171	6258	Economy	4000.00
0005434926013	6258	Economy	4000.00
0005433497174	6258	Economy	4000.00
0005433497181	6258	Economy	4000.00
0005434926003	6258	Economy	4000.00
0005434926024	6258	Economy	4000.00
0005434925996	6258	Economy	4000.00
0005434443816	6258	Economy	4000.00
0005434443813	6258	Economy	4000.00
0005432075252	6258	Economy	4000.00
0005434926014	6258	Economy	4000.00
0005434926004	6258	Economy	4000.00
0005434926009	6258	Economy	4000.00
0005434926005	6258	Economy	4000.00
0005434443805	6258	Economy	4000.00
0005434443814	6258	Economy	4000.00
0005434926018	6258	Economy	4000.00
0005434926025	6258	Economy	4000.00
0005434925995	6258	Economy	4000.00
0005434443815	6258	Economy	4000.00
0005432075253	6258	Economy	4000.00
0005434443818	6258	Economy	4000.00
0005434926017	6258	Economy	4000.00
0005434926012	6258	Economy	4000.00
0005434443819	6258	Economy	4000.00
0005433496905	20357	Business	11900.00
0005434925595	20357	Business	11900.00
0005433496954	20357	Business	11900.00
0005434925729	20357	Business	11900.00
0005434925740	20357	Business	11900.00
0005433496870	20357	Business	11900.00
0005433496977	20357	Business	11900.00
0005434925665	20357	Business	11900.00
0005433496882	20357	Business	11900.00
0005434443620	20357	Business	11900.00
0005434443619	20357	Business	11900.00
0005433496976	20357	Business	11900.00
0005433496943	20357	Economy	4000.00
0005434443621	20357	Economy	4000.00
0005433496899	20357	Economy	4000.00
0005434925704	20357	Economy	4000.00
0005433496896	20357	Economy	4000.00
0005433496960	20357	Economy	4000.00
0005434925735	20357	Economy	4000.00
0005433497001	20357	Economy	4000.00
0005434925741	20357	Economy	4000.00
0005434925693	20357	Economy	4000.00
0005434443662	20357	Economy	4400.00
0005433496875	20357	Economy	4400.00
0005434443610	20357	Economy	4400.00
0005434443691	20357	Economy	4400.00
0005433496982	20357	Economy	4400.00
0005434925694	20357	Economy	4000.00
0005434925541	20357	Economy	4000.00
0005434443652	20357	Economy	4000.00
0005434443613	20357	Economy	4000.00
0005433496929	20357	Economy	4000.00
0005434925544	20357	Economy	4000.00
0005433496879	20357	Economy	4000.00
0005433496911	20357	Economy	4000.00
0005434443653	20357	Economy	4000.00
0005434925624	20357	Economy	4000.00
0005434443685	20357	Economy	4000.00
0005433496959	20357	Economy	4000.00
0005434925728	20357	Economy	4000.00
0005434443618	20357	Economy	4000.00
0005433496941	20357	Economy	4000.00
0005434443686	20357	Economy	4000.00
0005434443646	20357	Economy	4000.00
0005434925677	20357	Economy	4000.00
0005434925727	20357	Economy	4000.00
0005433496874	20357	Economy	4000.00
0005433496900	20357	Economy	4000.00
0005433496981	20357	Economy	4000.00
0005433496961	20357	Economy	4000.00
0005433496909	20357	Economy	4000.00
0005434925724	20357	Economy	4000.00
0005434443642	20357	Economy	4000.00
0005434925652	20357	Economy	4000.00
0005434443612	20357	Economy	4000.00
0005434925732	20357	Economy	4000.00
0005433496942	20357	Economy	4000.00
0005434925713	20357	Economy	4000.00
0005433496978	20357	Economy	4000.00
0005434925667	20357	Economy	4000.00
0005434443640	20357	Economy	4000.00
0005433496784	20357	Economy	4000.00
0005434925580	20357	Economy	4000.00
0005434443656	20357	Economy	4000.00
0005434443661	20357	Economy	4000.00
0005433496914	20357	Economy	4000.00
0005434443664	20357	Economy	4000.00
0005433496912	20357	Economy	4000.00
0005434925625	20357	Economy	4000.00
0005433496810	20357	Economy	4000.00
0005433496940	20357	Economy	4000.00
0005434443611	20357	Economy	4000.00
0005434925721	20357	Economy	4000.00
0005434925678	20357	Economy	4000.00
0005433496956	20357	Economy	4000.00
0005433496780	20357	Economy	4000.00
0005434443682	20357	Economy	4000.00
0005434443643	20357	Economy	4000.00
0005433496797	20357	Economy	4000.00
0005434925676	20357	Economy	4000.00
0005434925540	20357	Economy	4000.00
0005433497056	20357	Economy	4000.00
0005434443715	20357	Economy	4000.00
0005434925707	20357	Economy	4000.00
0005434925685	20357	Economy	4000.00
0005434443609	20357	Economy	4000.00
0005434443736	20357	Economy	4000.00
0005435243033	12212	Business	41200.00
0005435243022	12212	Business	41200.00
0005432783736	12212	Business	41200.00
0005432783766	12212	Business	41200.00
0005432783698	12212	Business	41200.00
0005435243036	12212	Business	41200.00
0005432783462	12212	Business	41200.00
0005432783614	12212	Business	41200.00
0005432783648	12212	Business	41200.00
0005432783709	12212	Business	41200.00
0005432783558	12212	Business	41200.00
0005432783611	12212	Business	41200.00
0005435243025	12212	Economy	13700.00
0005432783606	12212	Economy	13700.00
0005432783539	12212	Economy	13700.00
0005432783610	12212	Economy	13700.00
0005432783615	12212	Economy	13700.00
0005435243038	12212	Economy	13700.00
0005432783677	12212	Economy	13700.00
0005435243021	12212	Economy	13700.00
0005435243043	12212	Economy	13700.00
0005432783697	12212	Economy	13700.00
0005432783650	12212	Economy	15100.00
0005432783802	12212	Economy	15100.00
0005435243039	12212	Economy	15100.00
0005432783354	12212	Economy	15100.00
0005432783604	12212	Economy	15100.00
0005432783602	12212	Economy	13700.00
0005435243023	12212	Economy	13700.00
0005435243040	12212	Economy	13700.00
0005435243019	12212	Economy	13700.00
0005432783814	12212	Economy	13700.00
0005435243028	12212	Economy	13700.00
0005432783619	12212	Economy	13700.00
0005432783767	12212	Economy	13700.00
0005435243037	12212	Economy	13700.00
0005432783832	12212	Economy	13700.00
0005432783601	12212	Economy	13700.00
0005432783760	12212	Economy	13700.00
0005432783600	12212	Economy	13700.00
0005432783544	12212	Economy	13700.00
0005432783674	12212	Economy	13700.00
0005432783815	12212	Economy	13700.00
0005432783593	12212	Economy	13700.00
0005432783649	12212	Economy	13700.00
0005432783665	12212	Economy	13700.00
0005432783771	12212	Economy	13700.00
0005432783605	12212	Economy	13700.00
0005432783790	12212	Economy	13700.00
0005435243045	12212	Economy	13700.00
0005432783907	12212	Economy	13700.00
0005435243026	12212	Economy	13700.00
0005435243031	12212	Economy	13700.00
0005432783720	12212	Economy	13700.00
0005432783759	12212	Economy	13700.00
0005432783747	12212	Economy	13700.00
0005432783737	12212	Economy	13700.00
0005435243032	12212	Economy	13700.00
0005432783594	12212	Economy	13700.00
0005435243035	12212	Economy	13700.00
0005432783777	12212	Economy	13700.00
0005432783670	12212	Economy	13700.00
0005432783738	12212	Economy	13700.00
0005432783733	12212	Economy	13700.00
0005432783522	12212	Economy	13700.00
0005432783532	12212	Economy	13700.00
0005435243029	12212	Economy	13700.00
0005432783451	12212	Economy	13700.00
0005432783554	12212	Economy	13700.00
0005435243027	12212	Economy	13700.00
0005432783856	12212	Economy	13700.00
0005432783452	12212	Economy	13700.00
0005435243034	12212	Economy	13700.00
0005435243044	12212	Economy	13700.00
0005432783908	12212	Economy	13700.00
0005435243041	12212	Economy	13700.00
0005432783523	12212	Economy	13700.00
0005432783710	12212	Economy	13700.00
0005432783878	12212	Economy	13700.00
0005432783816	12212	Economy	13700.00
0005432783796	12212	Economy	13700.00
0005435243020	12212	Economy	13700.00
0005432783666	12212	Economy	13700.00
0005435243042	12212	Economy	13700.00
0005435243024	12212	Economy	13700.00
0005435243030	12212	Economy	13700.00
0005432784075	15432	Business	41200.00
0005432784071	15432	Business	41200.00
0005432784050	15432	Business	41200.00
0005432784059	15432	Business	41200.00
0005432784056	15432	Business	41200.00
0005435242807	15432	Business	41200.00
0005432784078	15432	Business	41200.00
0005432784095	15432	Business	41200.00
0005432784072	15432	Business	41200.00
0005435242755	15432	Business	41200.00
0005432784067	15432	Business	41200.00
0005432784084	15432	Economy	13700.00
0005432784104	15432	Economy	13700.00
0005432784079	15432	Economy	13700.00
0005435242590	15432	Economy	13700.00
0005432784097	15432	Economy	13700.00
0005432784105	15432	Economy	13700.00
0005432784077	15432	Economy	13700.00
0005432784080	15432	Economy	13700.00
0005432784065	15432	Economy	13700.00
0005432784063	15432	Economy	13700.00
0005432784099	15432	Economy	15100.00
0005432784073	15432	Economy	15100.00
0005432784092	15432	Economy	15100.00
0005432784093	15432	Economy	13700.00
0005435242799	15432	Economy	13700.00
0005435242805	15432	Economy	13700.00
0005432784066	15432	Economy	13700.00
0005432784053	15432	Economy	13700.00
0005435242757	15432	Economy	13700.00
0005432784090	15432	Economy	13700.00
0005432784100	15432	Economy	13700.00
0005432784054	15432	Economy	13700.00
0005435242744	15432	Economy	13700.00
0005435242739	15432	Economy	13700.00
0005435242710	15432	Economy	13700.00
0005435242840	15432	Economy	13700.00
0005432784069	15432	Economy	13700.00
0005435242819	15432	Economy	13700.00
0005435242740	15432	Economy	13700.00
0005432784096	15432	Economy	13700.00
0005432784098	15432	Economy	13700.00
0005432784101	15432	Economy	13700.00
0005435242818	15432	Economy	13700.00
0005435242804	15432	Economy	13700.00
0005435242735	15432	Economy	13700.00
0005432784074	15432	Economy	13700.00
0005435242704	15432	Economy	13700.00
0005432784076	15432	Economy	13700.00
0005432784070	15432	Economy	13700.00
0005432784085	15432	Economy	13700.00
0005435242831	15432	Economy	13700.00
0005435242767	15432	Economy	13700.00
0005435242700	15432	Economy	13700.00
0005432784055	15432	Economy	13700.00
0005432784094	15432	Economy	13700.00
0005435242703	15432	Economy	13700.00
0005432784060	15432	Economy	13700.00
0005435242701	15432	Economy	13700.00
0005432784089	15432	Economy	13700.00
0005432784058	15432	Economy	13700.00
0005432784088	15432	Economy	13700.00
0005435242736	15432	Economy	13700.00
0005432784081	15432	Economy	13700.00
0005432784052	15432	Economy	13700.00
0005432784061	15432	Economy	13700.00
0005435242699	15432	Economy	13700.00
0005435242832	15432	Economy	13700.00
0005432784103	15432	Economy	13700.00
0005432784091	15432	Economy	13700.00
0005432784064	15432	Economy	13700.00
0005432784068	15432	Economy	13700.00
0005432784087	15432	Economy	13700.00
0005432784051	15432	Economy	13700.00
0005435242734	15432	Economy	13700.00
0005432784083	15432	Economy	13700.00
0005432784086	15432	Economy	13700.00
0005432784102	15432	Economy	13700.00
0005435242702	15432	Economy	13700.00
0005432784057	15432	Economy	13700.00
0005432784062	15432	Economy	13700.00
0005435242758	15432	Economy	13700.00
0005432784082	15432	Economy	13700.00
0005434878069	10068	Business	49700.00
0005434878286	10068	Business	49700.00
0005434878204	10068	Business	49700.00
0005434877926	10068	Business	49700.00
0005434878091	10068	Business	49700.00
0005434877959	10068	Business	49700.00
0005434878036	10068	Business	49700.00
0005434877955	10068	Business	49700.00
0005434878052	10068	Business	49700.00
0005434877949	10068	Business	49700.00
0005434878019	10068	Business	49700.00
0005434878256	10068	Business	49700.00
0005434877916	10068	Business	49700.00
0005434877997	10068	Business	49700.00
0005434877644	10068	Business	49700.00
0005434758897	10068	Business	49700.00
0005434758889	10068	Business	49700.00
0005434877958	10068	Business	49700.00
0005434877671	10068	Business	49700.00
0005434877840	10068	Business	49700.00
0005434877911	10068	Economy	16600.00
0005434877889	10068	Economy	16600.00
0005434877940	10068	Economy	16600.00
0005434878095	10068	Economy	16600.00
0005434877968	10068	Economy	16600.00
0005434878025	10068	Economy	16600.00
0005434878017	10068	Economy	16600.00
0005434878129	10068	Economy	16600.00
0005434877654	10068	Economy	16600.00
0005434878183	10068	Economy	16600.00
0005434877813	10068	Economy	16600.00
0005434877815	10068	Economy	16600.00
0005434877935	10068	Economy	16600.00
0005434877652	10068	Economy	18200.00
0005434758890	10068	Economy	18200.00
0005434877996	10068	Economy	18200.00
0005434877814	10068	Economy	18200.00
0005434758884	10068	Economy	16600.00
0005434878046	10068	Economy	16600.00
0005434878157	10068	Economy	16600.00
0005434878300	10068	Economy	16600.00
0005434878066	10068	Economy	16600.00
0005434878016	10068	Economy	16600.00
0005434878064	10068	Economy	16600.00
0005434878098	10068	Economy	16600.00
0005434878112	10068	Economy	16600.00
0005434878299	10068	Economy	16600.00
0005434878193	10068	Economy	16600.00
0005434878094	10068	Economy	16600.00
0005434878065	10068	Economy	16600.00
0005434878047	10068	Economy	16600.00
0005434877795	10068	Economy	16600.00
0005434878045	10068	Economy	16600.00
0005434758896	10068	Economy	16600.00
0005434877180	10068	Economy	16600.00
0005434878130	10068	Economy	16600.00
0005434758898	10068	Economy	16600.00
0005434878186	10068	Economy	16600.00
0005434877455	10068	Economy	16600.00
0005434878038	10068	Economy	16600.00
0005434878285	10068	Economy	16600.00
0005434878111	10068	Economy	16600.00
0005434877963	10068	Economy	16600.00
0005434877888	10068	Economy	16600.00
0005434877934	10068	Economy	16600.00
0005434878279	10068	Economy	16600.00
0005434877962	10068	Economy	16600.00
0005434877590	10068	Economy	16600.00
0005434878253	10068	Economy	16600.00
0005434877998	10068	Economy	16600.00
0005434878171	10068	Economy	16600.00
0005434878059	10068	Economy	16600.00
0005434877770	10068	Economy	16600.00
0005434877798	10068	Economy	16600.00
0005434877591	10068	Economy	16600.00
0005434877939	10068	Economy	16600.00
0005434877181	10068	Economy	16600.00
0005434877927	10068	Economy	16600.00
0005434877930	10068	Economy	16600.00
0005434877938	10068	Economy	16600.00
0005434877513	10068	Economy	16600.00
0005434878106	10068	Economy	16600.00
0005434877954	10068	Economy	16600.00
0005434877925	10068	Economy	16600.00
0005434877924	10068	Economy	16600.00
0005434758891	10068	Economy	16600.00
0005434878101	10068	Economy	16600.00
0005434758895	10068	Economy	16600.00
0005434877846	10068	Economy	16600.00
0005434877984	10068	Economy	16600.00
0005434877812	10068	Economy	16600.00
0005434877891	10068	Economy	16600.00
0005434877771	10068	Economy	16600.00
0005434878093	10068	Economy	16600.00
0005434877970	10068	Economy	16600.00
0005434878099	10068	Economy	16600.00
0005434877512	10068	Economy	16600.00
0005434878260	10068	Economy	16600.00
0005434878037	10068	Economy	16600.00
0005434877912	10068	Economy	16600.00
0005434878137	10068	Economy	16600.00
0005434878136	10068	Economy	16600.00
0005434877676	10068	Economy	16600.00
0005434877836	10068	Economy	16600.00
0005434878145	10068	Economy	16600.00
0005434877799	10068	Economy	16600.00
0005434877946	10068	Economy	16600.00
0005434878118	10068	Economy	16600.00
0005434878252	10068	Economy	16600.00
0005434877887	10068	Economy	16600.00
0005434877835	10068	Economy	16600.00
0005434878050	10068	Economy	16600.00
0005434877779	10068	Economy	16600.00
0005434878053	10068	Economy	16600.00
0005434878851	14629	Business	49700.00
0005434878822	14629	Business	49700.00
0005434878845	14629	Business	49700.00
0005434878773	14629	Business	49700.00
0005434878776	14629	Business	49700.00
0005434878792	14629	Business	49700.00
0005434878839	14629	Business	49700.00
0005434878815	14629	Business	49700.00
0005434878802	14629	Business	49700.00
0005434878789	14629	Business	49700.00
0005434910107	14629	Business	49700.00
0005434878861	14629	Business	49700.00
0005434878794	14629	Business	49700.00
0005434878826	14629	Business	49700.00
0005434878781	14629	Business	49700.00
0005434878779	14629	Business	49700.00
0005434878827	14629	Business	49700.00
0005434878820	14629	Business	49700.00
0005434878846	14629	Business	49700.00
0005434878836	14629	Economy	16600.00
0005434878806	14629	Economy	16600.00
0005434878787	14629	Economy	16600.00
0005435913903	14629	Economy	16600.00
0005434878830	14629	Economy	16600.00
0005434878767	14629	Economy	16600.00
0005434878803	14629	Economy	16600.00
0005434878854	14629	Economy	16600.00
0005434878807	14629	Economy	16600.00
0005434878837	14629	Economy	16600.00
0005434878831	14629	Economy	16600.00
0005434878850	14629	Economy	18200.00
0005434878770	14629	Economy	18200.00
0005434878771	14629	Economy	18200.00
0005434878777	14629	Economy	16600.00
0005434878805	14629	Economy	16600.00
0005434878808	14629	Economy	16600.00
0005434878813	14629	Economy	16600.00
0005434878823	14629	Economy	16600.00
0005434878844	14629	Economy	16600.00
0005434878848	14629	Economy	16600.00
0005434878798	14629	Economy	16600.00
0005434878772	14629	Economy	16600.00
0005434878790	14629	Economy	16600.00
0005434878838	14629	Economy	16600.00
0005434878811	14629	Economy	16600.00
0005434878849	14629	Economy	16600.00
0005434878818	14629	Economy	16600.00
0005434878821	14629	Economy	16600.00
0005434878804	14629	Economy	16600.00
0005434878856	14629	Economy	16600.00
0005434878793	14629	Economy	16600.00
0005435913915	14629	Economy	16600.00
0005434878833	14629	Economy	16600.00
0005434878858	14629	Economy	16600.00
0005434878853	14629	Economy	16600.00
0005434878814	14629	Economy	16600.00
0005434878783	14629	Economy	16600.00
0005434878788	14629	Economy	16600.00
0005434878817	14629	Economy	16600.00
0005434878840	14629	Economy	16600.00
0005434878810	14629	Economy	16600.00
0005434878835	14629	Economy	16600.00
0005434878801	14629	Economy	16600.00
0005434878780	14629	Economy	16600.00
0005434878828	14629	Economy	16600.00
0005434878843	14629	Economy	16600.00
0005434878799	14629	Economy	16600.00
0005434878829	14629	Economy	16600.00
0005434878855	14629	Economy	16600.00
0005434878812	14629	Economy	16600.00
0005434878769	14629	Economy	16600.00
0005435913909	14629	Economy	16600.00
0005434878784	14629	Economy	16600.00
0005434878809	14629	Economy	16600.00
0005434878791	14629	Economy	16600.00
0005434878797	14629	Economy	16600.00
0005434878785	14629	Economy	16600.00
0005435913914	14629	Economy	16600.00
0005434758908	14629	Economy	16600.00
0005434878795	14629	Economy	16600.00
0005434878775	14629	Economy	16600.00
0005434878825	14629	Economy	16600.00
0005434878860	14629	Economy	16600.00
0005434878774	14629	Economy	16600.00
0005434878816	14629	Economy	16600.00
0005434758907	14629	Economy	16600.00
0005434878841	14629	Economy	16600.00
0005434878857	14629	Economy	16600.00
0005434878847	14629	Economy	16600.00
0005434878796	14629	Economy	16600.00
0005434878768	14629	Economy	16600.00
0005434878824	14629	Economy	16600.00
0005434878859	14629	Economy	16600.00
0005434878852	14629	Economy	16600.00
0005434878832	14629	Economy	16600.00
0005434878800	14629	Economy	16600.00
0005435913904	14629	Economy	16600.00
0005435913916	14629	Economy	16600.00
0005434878782	14629	Economy	16600.00
0005434878778	14629	Economy	16600.00
0005434878842	14629	Economy	16600.00
0005434878819	14629	Economy	16600.00
0005434878834	14629	Economy	16600.00
0005434878786	14629	Economy	16600.00
0005435660210	9251	Economy	22400.00
0005435660211	9251	Economy	22400.00
0005435660206	9251	Economy	20300.00
0005435660204	9251	Economy	20300.00
0005434251903	9251	Economy	20300.00
0005434251957	9251	Economy	20300.00
0005435660209	9251	Economy	20300.00
0005434251952	9251	Economy	20300.00
0005435660205	9251	Economy	20300.00
0005434251936	9251	Economy	20300.00
0005434251971	9251	Economy	20300.00
0005434251956	9251	Economy	20300.00
0005434251932	9251	Economy	20300.00
0005434251955	9251	Economy	20300.00
0005434251967	9251	Economy	20300.00
0005434251953	9251	Economy	20300.00
0005435660208	9251	Economy	20300.00
0005435660202	9251	Economy	20300.00
0005434251935	9251	Economy	20300.00
0005435660203	9251	Economy	20300.00
0005435660207	9251	Economy	20300.00
0005434251933	9251	Economy	20300.00
0005435660212	9251	Economy	20300.00
0005435660116	24670	Economy	22400.00
0005434252028	24670	Economy	20300.00
0005435660143	24670	Economy	20300.00
0005434252024	24670	Economy	20300.00
0005435660144	24670	Economy	20300.00
0005435660148	24670	Economy	20300.00
0005435660130	24670	Economy	20300.00
0005434252023	24670	Economy	20300.00
0005435660141	24670	Economy	20300.00
0005434252027	24670	Economy	20300.00
0005435660151	24670	Economy	20300.00
0005434252026	24670	Economy	20300.00
0005435660117	24670	Economy	20300.00
0005435660095	24670	Economy	20300.00
0005434252022	24670	Economy	20300.00
0005434252025	24670	Economy	20300.00
0005434252021	24670	Economy	20300.00
0005434252019	24670	Economy	20300.00
0005435660097	24670	Economy	20300.00
0005435660096	24670	Economy	20300.00
0005434252020	24670	Economy	20300.00
0005435660140	24670	Economy	20300.00
0005433680846	2806	Business	33000.00
0005433680851	2806	Business	33000.00
0005433680838	2806	Business	33000.00
0005433680874	2806	Business	33000.00
0005433680857	2806	Business	33000.00
0005433680872	2806	Business	33000.00
0005433680873	2806	Business	33000.00
0005433680871	2806	Business	33000.00
0005432966973	2806	Business	33000.00
0005432222812	2806	Business	33000.00
0005432966946	2806	Economy	11000.00
0005432966831	2806	Economy	11000.00
0005432966834	2806	Economy	11000.00
0005432966899	2806	Economy	11000.00
0005432966893	2806	Economy	11000.00
0005432966833	2806	Economy	11000.00
0005433680875	2806	Economy	11000.00
0005433680849	2806	Economy	11000.00
0005433680850	2806	Economy	12100.00
0005433680860	2806	Economy	12100.00
0005433680843	2806	Economy	12100.00
0005433680877	2806	Economy	12100.00
0005433680853	2806	Economy	12100.00
0005432222813	2806	Economy	11000.00
0005433684432	2806	Economy	11000.00
0005433680866	2806	Economy	11000.00
0005432966947	2806	Economy	11000.00
0005433680848	2806	Economy	11000.00
0005432222814	2806	Economy	11000.00
0005432966814	2806	Economy	11000.00
0005433680847	2806	Economy	11000.00
0005433680845	2806	Economy	11000.00
0005433680839	2806	Economy	11000.00
0005433680844	2806	Economy	11000.00
0005432966934	2806	Economy	11000.00
0005432966823	2806	Economy	11000.00
0005433680865	2806	Economy	11000.00
0005433680842	2806	Economy	11000.00
0005432966943	2806	Economy	11000.00
0005433680878	2806	Economy	11000.00
0005433680880	2806	Economy	11000.00
0005432966867	2806	Economy	11000.00
0005433680864	2806	Economy	11000.00
0005433680861	2806	Economy	11000.00
0005433680835	2806	Economy	11000.00
0005433680834	2806	Economy	11000.00
0005432966876	2806	Economy	11000.00
0005433680840	2806	Economy	11000.00
0005432966862	2806	Economy	11000.00
0005433680841	2806	Economy	11000.00
0005432222816	2806	Economy	11000.00
0005433680855	2806	Economy	11000.00
0005433680836	2806	Economy	11000.00
0005433684431	2806	Economy	11000.00
0005433680837	2806	Economy	11000.00
0005432966813	2806	Economy	11000.00
0005433680854	2806	Economy	11000.00
0005433680869	2806	Economy	11000.00
0005433680876	2806	Economy	11000.00
0005433680858	2806	Economy	11000.00
0005432966875	2806	Economy	11000.00
0005432966849	2806	Economy	11000.00
0005432966858	2806	Economy	11000.00
0005433680879	2806	Economy	11000.00
0005433680862	2806	Economy	11000.00
0005432966807	2806	Economy	11000.00
0005432967018	2806	Economy	11000.00
0005433680870	2806	Economy	11000.00
0005433680852	2806	Economy	11000.00
0005432966881	2806	Economy	11000.00
0005433680867	2806	Economy	11000.00
0005432966922	2806	Economy	11000.00
0005433680881	2806	Economy	11000.00
0005433680856	2806	Economy	11000.00
0005432966895	2806	Economy	11000.00
0005432222815	2806	Economy	11000.00
0005433680863	2806	Economy	11000.00
0005433680859	2806	Economy	11000.00
0005432966894	2806	Economy	11000.00
0005433680868	2806	Economy	11000.00
0005433680492	29183	Business	33000.00
0005433680347	29183	Business	33000.00
0005433680253	29183	Business	33000.00
0005433680775	29183	Business	33000.00
0005432967098	29183	Business	33000.00
0005433680541	29183	Business	33000.00
0005432967094	29183	Business	33000.00
0005432967092	29183	Business	33000.00
0005433680314	29183	Economy	11000.00
0005432967097	29183	Economy	11000.00
0005433680307	29183	Economy	11000.00
0005433680513	29183	Economy	11000.00
0005433680510	29183	Economy	11000.00
0005433680560	29183	Economy	11000.00
0005432967100	29183	Economy	11000.00
0005433680499	29183	Economy	11000.00
0005433680402	29183	Economy	11000.00
0005433680631	29183	Economy	12100.00
0005432967087	29183	Economy	12100.00
0005432967090	29183	Economy	12100.00
0005432967081	29183	Economy	12100.00
0005433680292	29183	Economy	11000.00
0005432967096	29183	Economy	11000.00
0005432967085	29183	Economy	11000.00
0005432967102	29183	Economy	11000.00
0005432005230	29183	Economy	11000.00
0005433680157	29183	Economy	11000.00
0005433680568	29183	Economy	11000.00
0005433680666	29183	Economy	11000.00
0005433680256	29183	Economy	11000.00
0005432967093	29183	Economy	11000.00
0005432967101	29183	Economy	11000.00
0005433680561	29183	Economy	11000.00
0005432967089	29183	Economy	11000.00
0005433680567	29183	Economy	11000.00
0005433680537	29183	Economy	11000.00
0005432967086	29183	Economy	11000.00
0005433680474	29183	Economy	11000.00
0005432967083	29183	Economy	11000.00
0005433687690	29183	Economy	11000.00
0005432967095	29183	Economy	11000.00
0005433680572	29183	Economy	11000.00
0005432967103	29183	Economy	11000.00
0005433680436	29183	Economy	11000.00
0005433680500	29183	Economy	11000.00
0005433680664	29183	Economy	11000.00
0005433680477	29183	Economy	11000.00
0005433680291	29183	Economy	11000.00
0005433680254	29183	Economy	11000.00
0005433680573	29183	Economy	11000.00
0005432967084	29183	Economy	11000.00
0005433680637	29183	Economy	11000.00
0005432967099	29183	Economy	11000.00
0005432967104	29183	Economy	11000.00
0005432967105	29183	Economy	11000.00
0005432967080	29183	Economy	11000.00
0005433680495	29183	Economy	11000.00
0005433680536	29183	Economy	11000.00
0005433680494	29183	Economy	11000.00
0005433680509	29183	Economy	11000.00
0005432005231	29183	Economy	11000.00
0005433680725	29183	Economy	11000.00
0005433680255	29183	Economy	11000.00
0005433687691	29183	Economy	11000.00
0005433680697	29183	Economy	11000.00
0005433680475	29183	Economy	11000.00
0005433680540	29183	Economy	11000.00
0005433680665	29183	Economy	11000.00
0005433680630	29183	Economy	11000.00
0005432967091	29183	Economy	11000.00
0005432967106	29183	Economy	11000.00
0005432967082	29183	Economy	11000.00
0005432967088	29183	Economy	11000.00
0005433680290	29183	Economy	11000.00
0005434269092	9299	Business	132900.00
0005433634004	9299	Business	132900.00
0005433633993	9299	Business	132900.00
0005433633988	9299	Business	132900.00
0005434163565	9299	Business	132900.00
0005433615056	9299	Business	132900.00
0005434269101	9299	Business	132900.00
0005434163611	9299	Business	132900.00
0005433634013	9299	Business	132900.00
0005433577888	9299	Business	132900.00
0005434163603	9299	Business	132900.00
0005433633989	9299	Business	132900.00
0005433634003	9299	Business	132900.00
0005433577894	9299	Business	132900.00
0005433577890	9299	Business	132900.00
0005433615106	9299	Business	132900.00
0005433615084	9299	Business	132900.00
0005433615059	9299	Business	132900.00
0005433577886	9299	Business	132900.00
0005433615102	9299	Economy	48700.00
0005433633994	9299	Economy	48700.00
0005433633997	9299	Economy	48700.00
0005433615099	9299	Economy	48700.00
0005433615034	9299	Economy	48700.00
0005433615103	9299	Economy	48700.00
0005433615098	9299	Economy	44300.00
0005433615067	9299	Economy	44300.00
0005433615040	9299	Economy	44300.00
0005432145122	9299	Economy	44300.00
0005433615047	9299	Economy	44300.00
0005433615048	9299	Economy	44300.00
0005433615085	9299	Economy	44300.00
0005433615045	9299	Economy	44300.00
0005433615071	9299	Economy	44300.00
0005433577882	9299	Economy	44300.00
0005433634014	9299	Economy	44300.00
0005433634010	9299	Economy	44300.00
0005433615064	9299	Economy	44300.00
0005433633996	9299	Economy	44300.00
0005433615065	9299	Economy	44300.00
0005433615080	9299	Economy	44300.00
0005433634009	9299	Economy	44300.00
0005433633983	9299	Economy	44300.00
0005433615038	9299	Economy	44300.00
0005434163605	9299	Economy	44300.00
0005433577893	9299	Economy	44300.00
0005433615073	9299	Economy	44300.00
0005434163612	9299	Economy	44300.00
0005433615052	9299	Economy	44300.00
0005433633991	9299	Economy	44300.00
0005433615046	9299	Economy	44300.00
0005434272183	9299	Economy	44300.00
0005433633987	9299	Economy	44300.00
0005432756866	9299	Economy	44300.00
0005433615043	9299	Economy	44300.00
0005433577883	9299	Economy	44300.00
0005432755096	9299	Economy	44300.00
0005433615101	9299	Economy	44300.00
0005433615042	9299	Economy	44300.00
0005433634002	9299	Economy	44300.00
0005433615037	9299	Economy	44300.00
0005433615089	9299	Economy	44300.00
0005433615095	9299	Economy	44300.00
0005433615036	9299	Economy	44300.00
0005433615070	9299	Economy	44300.00
0005432755094	9299	Economy	44300.00
0005433634011	9299	Economy	44300.00
0005433615083	9299	Economy	44300.00
0005433615082	9299	Economy	44300.00
0005433633992	9299	Economy	44300.00
0005433634008	9299	Economy	44300.00
0005433615041	9299	Economy	44300.00
0005433634000	9299	Economy	44300.00
0005433633984	9299	Economy	44300.00
0005433633985	9299	Economy	44300.00
0005433615075	9299	Economy	44300.00
0005433615044	9299	Economy	44300.00
0005433615057	9299	Economy	48700.00
0005433615104	9299	Economy	48700.00
0005433633986	9299	Economy	48700.00
0005433615088	9299	Economy	48700.00
0005432756868	9299	Economy	48700.00
0005433615100	9299	Economy	44300.00
0005432755095	9299	Economy	44300.00
0005433634012	9299	Economy	44300.00
0005433633995	9299	Economy	44300.00
0005433577895	9299	Economy	48700.00
0005432756867	9299	Economy	44300.00
0005433615093	9299	Economy	44300.00
0005433615096	9299	Economy	44300.00
0005433633982	9299	Economy	44300.00
0005433615078	9299	Economy	44300.00
0005433615058	9299	Economy	44300.00
0005434163597	9299	Economy	44300.00
0005433577891	9299	Economy	44300.00
0005433615035	9299	Economy	44300.00
0005433615090	9299	Economy	44300.00
0005433615066	9299	Economy	44300.00
0005433615074	9299	Economy	44300.00
0005433615097	9299	Economy	44300.00
0005433615092	9299	Economy	44300.00
0005433615039	9299	Economy	44300.00
0005434163587	9299	Economy	44300.00
0005434163602	9299	Economy	44300.00
0005433634006	9299	Economy	44300.00
0005433615072	9299	Economy	44300.00
0005433615055	9299	Economy	44300.00
0005433615060	9299	Economy	44300.00
0005433633990	9299	Economy	44300.00
0005433615053	9299	Economy	44300.00
0005434163598	9299	Economy	44300.00
0005433615068	9299	Economy	44300.00
0005433633999	9299	Economy	44300.00
0005433577884	9299	Economy	44300.00
0005433577892	9299	Economy	44300.00
0005433615076	9299	Economy	44300.00
0005433634007	9299	Economy	44300.00
0005433615063	9299	Economy	44300.00
0005433615079	9299	Economy	44300.00
0005433615061	9299	Economy	44300.00
0005433577887	9299	Economy	44300.00
0005433615051	9299	Economy	44300.00
0005433615094	9299	Economy	44300.00
0005433615049	9299	Economy	44300.00
0005433615081	9299	Economy	44300.00
0005433615086	9299	Economy	44300.00
0005433615069	9299	Economy	44300.00
0005433615054	9299	Economy	44300.00
0005433634001	9299	Economy	44300.00
0005433577889	9299	Economy	44300.00
0005433615087	9299	Economy	44300.00
0005433634005	9299	Economy	44300.00
0005433615062	9299	Economy	44300.00
0005433634015	9299	Economy	44300.00
0005433615107	9299	Economy	44300.00
0005433577885	9299	Economy	44300.00
0005433615105	9299	Economy	44300.00
0005433615077	9299	Economy	44300.00
0005433615050	9299	Economy	44300.00
0005433633998	9299	Economy	44300.00
0005434163604	9299	Economy	44300.00
0005434153527	9299	Economy	44300.00
0005433615091	9299	Economy	44300.00
0005433614100	25248	Business	132900.00
0005434163665	25248	Business	132900.00
0005434272199	25248	Business	132900.00
0005433614289	25248	Business	132900.00
0005433633539	25248	Business	132900.00
0005433633860	25248	Business	132900.00
0005433577727	25248	Business	132900.00
0005433633821	25248	Business	132900.00
0005433577785	25248	Business	132900.00
0005433577749	25248	Business	132900.00
0005433614363	25248	Business	132900.00
0005433633746	25248	Business	132900.00
0005433577740	25248	Business	132900.00
0005433577798	25248	Business	132900.00
0005433614501	25248	Business	132900.00
0005433577801	25248	Business	132900.00
0005433614275	25248	Business	132900.00
0005433614338	25248	Business	132900.00
0005433614237	25248	Business	132900.00
0005433577756	25248	Business	132900.00
0005433614327	25248	Business	132900.00
0005433614642	25248	Business	132900.00
0005434273084	25248	Business	132900.00
0005433614425	25248	Business	132900.00
0005434163659	25248	Business	132900.00
0005433614183	25248	Economy	48700.00
0005433614225	25248	Economy	48700.00
0005433614463	25248	Economy	48700.00
0005433633666	25248	Economy	48700.00
0005434163663	25248	Economy	44300.00
0005433633584	25248	Economy	44300.00
0005433577787	25248	Economy	44300.00
0005433614333	25248	Economy	44300.00
0005433614286	25248	Economy	44300.00
0005433633783	25248	Economy	44300.00
0005433577739	25248	Economy	44300.00
0005433614562	25248	Economy	44300.00
0005433577732	25248	Economy	44300.00
0005434163669	25248	Economy	44300.00
0005433614374	25248	Economy	44300.00
0005433577789	25248	Economy	44300.00
0005434163668	25248	Economy	44300.00
0005433577737	25248	Economy	44300.00
0005433633761	25248	Economy	44300.00
0005433577800	25248	Economy	44300.00
0005433633606	25248	Economy	44300.00
0005433614161	25248	Economy	44300.00
0005433614641	25248	Economy	44300.00
0005433614603	25248	Economy	44300.00
0005434163664	25248	Economy	44300.00
0005433614539	25248	Economy	44300.00
0005433577674	25248	Economy	44300.00
0005433633602	25248	Economy	44300.00
0005433614498	25248	Economy	44300.00
0005435854061	25248	Economy	44300.00
0005433614307	25248	Economy	44300.00
0005433633859	25248	Economy	44300.00
0005433614387	25248	Economy	44300.00
0005433614326	25248	Economy	44300.00
0005433614381	25248	Economy	44300.00
0005433614653	25248	Economy	44300.00
0005433614224	25248	Economy	44300.00
0005433577758	25248	Economy	44300.00
0005433614389	25248	Economy	44300.00
0005433614494	25248	Economy	44300.00
0005433577682	25248	Economy	44300.00
0005434163666	25248	Economy	44300.00
0005433614619	25248	Economy	44300.00
0005433614305	25248	Economy	44300.00
0005433633864	25248	Economy	44300.00
0005433633671	25248	Economy	44300.00
0005433614412	25248	Economy	44300.00
0005433633622	25248	Economy	44300.00
0005433633400	25248	Economy	44300.00
0005433633679	25248	Economy	48700.00
0005433614415	25248	Economy	48700.00
0005433633695	25248	Economy	48700.00
0005435854062	25248	Economy	48700.00
0005433633570	25248	Economy	44300.00
0005433614443	25248	Economy	44300.00
0005433614328	25248	Economy	44300.00
0005434163660	25248	Economy	48700.00
0005433614421	25248	Economy	44300.00
0005433633605	25248	Economy	44300.00
0005433633734	25248	Economy	44300.00
0005433614496	25248	Economy	44300.00
0005433614375	25248	Economy	44300.00
0005433614515	25248	Economy	44300.00
0005433577761	25248	Economy	44300.00
0005433633749	25248	Economy	44300.00
0005434273085	25248	Economy	44300.00
0005433614288	25248	Economy	44300.00
0005433614332	25248	Economy	44300.00
0005433614652	25248	Economy	44300.00
0005433577786	25248	Economy	44300.00
0005433614301	25248	Economy	44300.00
0005433614236	25248	Economy	44300.00
0005433577759	25248	Economy	44300.00
0005433614382	25248	Economy	44300.00
0005433614433	25248	Economy	44300.00
0005433633577	25248	Economy	44300.00
0005433614618	25248	Economy	44300.00
0005433577728	25248	Economy	44300.00
0005433577733	25248	Economy	44300.00
0005433633747	25248	Economy	44300.00
0005433614287	25248	Economy	44300.00
0005433614495	25248	Economy	44300.00
0005433633861	25248	Economy	44300.00
0005433633603	25248	Economy	44300.00
0005433577738	25248	Economy	44300.00
0005433577821	25248	Economy	44300.00
0005433614462	25248	Economy	44300.00
0005433577763	25248	Economy	44300.00
0005433614582	25248	Economy	44300.00
0005433614497	25248	Economy	44300.00
0005433614424	25248	Economy	44300.00
0005434163661	25248	Economy	44300.00
0005434272200	25248	Economy	44300.00
0005433633743	25248	Economy	44300.00
0005433633782	25248	Economy	44300.00
0005433614383	25248	Economy	44300.00
0005434163667	25248	Economy	44300.00
0005433577762	25248	Economy	44300.00
0005433577752	25248	Economy	44300.00
0005434163662	25248	Economy	44300.00
0005433614388	25248	Economy	44300.00
0005433614397	25248	Economy	44300.00
0005433614019	25248	Economy	44300.00
0005433633769	25248	Economy	44300.00
0005433577751	25248	Economy	44300.00
0005433633651	25248	Economy	44300.00
0005433614101	25248	Economy	44300.00
0005435856170	4218	Business	193100.00
0005435947189	4218	Business	193100.00
0005434271302	4218	Business	193100.00
0005435947249	4218	Business	193100.00
0005435947252	4218	Economy	64400.00
0005435856174	4218	Economy	64400.00
0005432571318	4218	Economy	64400.00
0005435787351	4218	Economy	64400.00
0005435986800	4218	Economy	64400.00
0005435856190	4218	Economy	64400.00
0005435856175	4218	Economy	64400.00
0005435947202	4218	Economy	64400.00
0005435947250	4218	Economy	64400.00
0005434271307	4218	Economy	64400.00
0005435856193	4218	Economy	64400.00
0005435787327	4218	Economy	64400.00
0005435856192	4218	Economy	64400.00
0005434271303	4218	Economy	64400.00
0005435787352	4218	Economy	64400.00
0005432571319	4218	Economy	64400.00
0005432571321	4218	Economy	64400.00
0005432184967	4218	Economy	64400.00
0005435947224	4218	Economy	64400.00
0005435947263	4218	Economy	64400.00
0005435787337	4218	Economy	64400.00
0005432571320	4218	Economy	64400.00
0005432571297	4218	Economy	64400.00
0005435947248	4218	Economy	64400.00
0005432571317	4218	Economy	64400.00
0005435947179	4218	Economy	64400.00
0005435787353	4218	Economy	64400.00
0005435787336	4218	Economy	64400.00
0005432184969	4218	Economy	64400.00
0005432184968	4218	Economy	64400.00
0005435787341	4218	Economy	64400.00
0005435856231	26575	Business	193100.00
0005432571346	26575	Business	193100.00
0005435986720	26575	Business	193100.00
0005435986719	26575	Business	193100.00
0005435947351	26575	Economy	64400.00
0005435947344	26575	Economy	64400.00
0005435986739	26575	Economy	64400.00
0005432571350	26575	Economy	64400.00
0005435947352	26575	Economy	64400.00
0005435947345	26575	Economy	64400.00
0005435947353	26575	Economy	64400.00
0005432571349	26575	Economy	64400.00
0005435856230	26575	Economy	64400.00
0005435947350	26575	Economy	64400.00
0005435787370	26575	Economy	64400.00
0005435947348	26575	Economy	64400.00
0005435856229	26575	Economy	64400.00
0005435986726	26575	Economy	64400.00
0005432571348	26575	Economy	64400.00
0005435856232	26575	Economy	64400.00
0005435787368	26575	Economy	64400.00
0005435947347	26575	Economy	64400.00
0005435947346	26575	Economy	64400.00
0005432571347	26575	Economy	64400.00
0005435986717	26575	Economy	64400.00
0005435787369	26575	Economy	64400.00
0005435947349	26575	Economy	64400.00
0005435947340	26575	Economy	64400.00
0005435986716	26575	Economy	64400.00
0005435947342	26575	Economy	64400.00
0005435947341	26575	Economy	64400.00
0005435947343	26575	Economy	64400.00
0005433074778	355	Business	21500.00
0005433569438	355	Business	21500.00
0005433074584	355	Business	21500.00
0005433129259	355	Business	21500.00
0005433569447	355	Business	21500.00
0005433074555	355	Business	21500.00
0005432948328	355	Business	21500.00
0005432948421	355	Business	21500.00
0005432948258	355	Business	21500.00
0005432948305	355	Business	21500.00
0005433074601	355	Business	21500.00
0005432948386	355	Business	21500.00
0005433569455	355	Business	21500.00
0005433129267	355	Business	21500.00
0005432948479	355	Business	21500.00
0005432948320	355	Business	21500.00
0005433074635	355	Business	21500.00
0005432948377	355	Business	21500.00
0005432948215	355	Business	21500.00
0005433569468	355	Business	21500.00
0005433074591	355	Business	21500.00
0005433074560	355	Business	21500.00
0005433074659	355	Business	21500.00
0005433074636	355	Business	21500.00
0005433074690	355	Business	21500.00
0005433074644	355	Economy	7900.00
0005433569434	355	Economy	7900.00
0005432948399	355	Economy	7900.00
0005432948380	355	Economy	7900.00
0005433569461	355	Economy	7900.00
0005433134127	355	Economy	7200.00
0005432948388	355	Economy	7200.00
0005432238979	355	Economy	7200.00
0005433569462	355	Economy	7200.00
0005433134128	355	Economy	7200.00
0005433569444	355	Economy	7200.00
0005432948295	355	Economy	7200.00
0005432948433	355	Economy	7200.00
0005433134115	355	Economy	7200.00
0005432948331	355	Economy	7200.00
0005433569432	355	Economy	7200.00
0005432948332	355	Economy	7200.00
0005433569436	355	Economy	7200.00
0005433569457	355	Economy	7200.00
0005432948460	355	Economy	7200.00
0005433569456	355	Economy	7200.00
0005433569454	355	Economy	7200.00
0005432948488	355	Economy	7200.00
0005433569431	355	Economy	7200.00
0005432238974	355	Economy	7200.00
0005433569453	355	Economy	7200.00
0005433569460	355	Economy	7200.00
0005433074799	355	Economy	7200.00
0005432948214	355	Economy	7200.00
0005433569445	355	Economy	7200.00
0005433569459	355	Economy	7200.00
0005432948304	355	Economy	7200.00
0005433129242	355	Economy	7200.00
0005432948201	355	Economy	7200.00
0005432948239	355	Economy	7200.00
0005432948303	355	Economy	7200.00
0005433569463	355	Economy	7200.00
0005433129263	355	Economy	7200.00
0005432948327	355	Economy	7200.00
0005433074585	355	Economy	7200.00
0005433074614	355	Economy	7200.00
0005433569446	355	Economy	7200.00
0005433129283	355	Economy	7200.00
0005433074576	355	Economy	7200.00
0005433569442	355	Economy	7200.00
0005432948251	355	Economy	7200.00
0005433569469	355	Economy	7200.00
0005433569443	355	Economy	7200.00
0005432948469	355	Economy	7200.00
0005432948323	355	Economy	7200.00
0005433569471	355	Economy	7200.00
0005432948486	355	Economy	7200.00
0005432948324	355	Economy	7200.00
0005432948362	355	Economy	7200.00
0005433074495	355	Economy	7200.00
0005433569441	355	Economy	7200.00
0005433074564	355	Economy	7200.00
0005433074738	355	Economy	7200.00
0005433569470	355	Economy	7900.00
0005432948487	355	Economy	7900.00
0005433569439	355	Economy	7900.00
0005432948287	355	Economy	7900.00
0005433129241	355	Economy	7200.00
0005433074577	355	Economy	7200.00
0005433569448	355	Economy	7200.00
0005433074454	355	Economy	7200.00
0005432948325	355	Economy	7200.00
0005432948361	355	Economy	7200.00
0005432948403	355	Economy	7200.00
0005433134122	355	Economy	7200.00
0005432948517	355	Economy	7200.00
0005433569449	355	Economy	7200.00
0005433074727	355	Economy	7200.00
0005433074615	355	Economy	7200.00
0005432948276	355	Economy	7200.00
0005433129282	355	Economy	7200.00
0005433569435	355	Economy	7200.00
0005432948302	355	Economy	7200.00
0005432948404	355	Economy	7200.00
0005433074496	355	Economy	7200.00
0005432948189	355	Economy	7200.00
0005433569452	355	Economy	7200.00
0005432238976	355	Economy	7200.00
0005432948252	355	Economy	7200.00
0005432948319	355	Economy	7200.00
0005432948200	355	Economy	7200.00
0005433569450	355	Economy	7200.00
0005433569440	355	Economy	7200.00
0005433569466	355	Economy	7200.00
0005432948199	355	Economy	7200.00
0005433569467	355	Economy	7200.00
0005433074647	355	Economy	7200.00
0005433074561	355	Economy	7200.00
0005432238978	355	Economy	7200.00
0005433074632	355	Economy	7200.00
0005433074800	355	Economy	7200.00
0005432948307	355	Economy	7200.00
0005432948257	355	Economy	7200.00
0005432948277	355	Economy	7200.00
0005433074737	355	Economy	7200.00
0005433129258	355	Economy	7200.00
0005433569465	355	Economy	7200.00
0005433569430	355	Economy	7200.00
0005432238973	355	Economy	7200.00
0005433569433	355	Economy	7200.00
0005432948398	355	Economy	7200.00
0005433134114	355	Economy	7200.00
0005433569464	355	Economy	7200.00
0005433569437	355	Economy	7200.00
0005432948387	355	Economy	7200.00
0005433074658	355	Economy	7200.00
0005433074648	355	Economy	7200.00
0005432948278	355	Economy	7200.00
0005432948333	355	Economy	7200.00
0005432238975	355	Economy	7200.00
0005433569451	355	Economy	7200.00
0005433129257	355	Economy	7200.00
0005433569428	355	Economy	7200.00
0005432948438	355	Economy	7200.00
0005432948354	355	Economy	7200.00
0005433134116	355	Economy	7200.00
0005432238977	355	Economy	7200.00
0005432948440	355	Economy	7200.00
0005433074646	355	Economy	7200.00
0005433134107	355	Economy	7200.00
0005433569458	355	Economy	7200.00
0005432948439	355	Economy	7200.00
0005433074736	355	Economy	7200.00
0005433074728	355	Economy	7200.00
0005433569429	355	Economy	7200.00
0005433568804	11596	Business	21500.00
0005433568696	11596	Business	21500.00
0005432948721	11596	Business	21500.00
0005433568815	11596	Business	21500.00
0005433568778	11596	Business	21500.00
0005433131737	11596	Business	21500.00
0005433568871	11596	Business	21500.00
0005433568795	11596	Business	21500.00
0005433074893	11596	Business	21500.00
0005432948683	11596	Business	21500.00
0005433074894	11596	Business	21500.00
0005432948691	11596	Business	21500.00
0005433134164	11596	Business	21500.00
0005433568792	11596	Business	21500.00
0005432948704	11596	Business	21500.00
0005433568797	11596	Business	21500.00
0005433074867	11596	Business	21500.00
0005433568625	11596	Business	21500.00
0005433074884	11596	Business	21500.00
0005433568849	11596	Business	21500.00
0005433074878	11596	Business	21500.00
0005433568684	11596	Business	21500.00
0005433568817	11596	Business	21500.00
0005433568920	11596	Business	21500.00
0005433568850	11596	Economy	7900.00
0005432948710	11596	Economy	7900.00
0005433568711	11596	Economy	7900.00
0005433568710	11596	Economy	7900.00
0005433568673	11596	Economy	7900.00
0005433131735	11596	Economy	7200.00
0005433134167	11596	Economy	7200.00
0005433074868	11596	Economy	7200.00
0005433074871	11596	Economy	7200.00
0005433074876	11596	Economy	7200.00
0005433074888	11596	Economy	7200.00
0005432192339	11596	Economy	7200.00
0005433074887	11596	Economy	7200.00
0005433568622	11596	Economy	7200.00
0005432192338	11596	Economy	7200.00
0005433074886	11596	Economy	7200.00
0005432948693	11596	Economy	7200.00
0005433568798	11596	Economy	7200.00
0005433074869	11596	Economy	7200.00
0005433074880	11596	Economy	7200.00
0005432948711	11596	Economy	7200.00
0005433568720	11596	Economy	7200.00
0005433568860	11596	Economy	7200.00
0005433568640	11596	Economy	7200.00
0005433568909	11596	Economy	7200.00
0005433568800	11596	Economy	7200.00
0005432948688	11596	Economy	7200.00
0005433568741	11596	Economy	7200.00
0005433568627	11596	Economy	7200.00
0005432192340	11596	Economy	7200.00
0005432948718	11596	Economy	7200.00
0005433568584	11596	Economy	7200.00
0005433074870	11596	Economy	7200.00
0005433568803	11596	Economy	7200.00
0005432948696	11596	Economy	7200.00
0005433568626	11596	Economy	7200.00
0005432948714	11596	Economy	7200.00
0005433134166	11596	Economy	7200.00
0005433568818	11596	Economy	7200.00
0005433568655	11596	Economy	7200.00
0005433568491	11596	Economy	7200.00
0005433074883	11596	Economy	7200.00
0005433131736	11596	Economy	7200.00
0005433568744	11596	Economy	7200.00
0005433568866	11596	Economy	7200.00
0005432948684	11596	Economy	7200.00
0005433074885	11596	Economy	7200.00
0005433074873	11596	Economy	7200.00
0005433568887	11596	Economy	7200.00
0005432948690	11596	Economy	7200.00
0005432948707	11596	Economy	7200.00
0005433131734	11596	Economy	7200.00
0005432948712	11596	Economy	7200.00
0005433568459	11596	Economy	7200.00
0005433568639	11596	Economy	7200.00
0005432948685	11596	Economy	7200.00
0005433568747	11596	Economy	7200.00
0005433568656	11596	Economy	7900.00
0005433568910	11596	Economy	7900.00
0005432948713	11596	Economy	7900.00
0005433074872	11596	Economy	7900.00
0005432948720	11596	Economy	7900.00
0005433134165	11596	Economy	7200.00
0005432948697	11596	Economy	7200.00
0005432948705	11596	Economy	7200.00
0005433568704	11596	Economy	7900.00
0005433568659	11596	Economy	7200.00
0005433131738	11596	Economy	7200.00
0005433568827	11596	Economy	7200.00
0005433568777	11596	Economy	7200.00
0005432948703	11596	Economy	7200.00
0005432948701	11596	Economy	7200.00
0005432948719	11596	Economy	7200.00
0005433074877	11596	Economy	7200.00
0005432948717	11596	Economy	7200.00
0005433568791	11596	Economy	7200.00
0005433074875	11596	Economy	7200.00
0005433074889	11596	Economy	7200.00
0005433074882	11596	Economy	7200.00
0005433134168	11596	Economy	7200.00
0005433568761	11596	Economy	7200.00
0005433074896	11596	Economy	7200.00
0005432948687	11596	Economy	7200.00
0005432948695	11596	Economy	7200.00
0005432948709	11596	Economy	7200.00
0005433568669	11596	Economy	7200.00
0005433568870	11596	Economy	7200.00
0005432948694	11596	Economy	7200.00
0005433568722	11596	Economy	7200.00
0005433568888	11596	Economy	7200.00
0005433568779	11596	Economy	7200.00
0005433568760	11596	Economy	7200.00
0005433568742	11596	Economy	7200.00
0005433568806	11596	Economy	7200.00
0005432948689	11596	Economy	7200.00
0005432948700	11596	Economy	7200.00
0005433568689	11596	Economy	7200.00
0005432948681	11596	Economy	7200.00
0005432948686	11596	Economy	7200.00
0005432948699	11596	Economy	7200.00
0005432948715	11596	Economy	7200.00
0005433568748	11596	Economy	7200.00
0005432948708	11596	Economy	7200.00
0005433074881	11596	Economy	7200.00
0005433074874	11596	Economy	7200.00
0005432948702	11596	Economy	7200.00
0005432948722	11596	Economy	7200.00
0005433568714	11596	Economy	7200.00
0005433074879	11596	Economy	7200.00
0005433074895	11596	Economy	7200.00
0005432948692	11596	Economy	7200.00
0005432948706	11596	Economy	7200.00
0005432948682	11596	Economy	7200.00
0005433568833	11596	Economy	7200.00
0005433074891	11596	Economy	7200.00
0005433568816	11596	Economy	7200.00
0005433568719	11596	Economy	7200.00
0005433074890	11596	Economy	7200.00
0005432948716	11596	Economy	7200.00
0005433568762	11596	Economy	7200.00
0005433074892	11596	Economy	7200.00
0005432948698	11596	Economy	7200.00
0005433817493	10007	Economy	6300.00
0005433817492	10007	Economy	6300.00
0005433817494	10007	Economy	6300.00
0005433817495	10007	Economy	6300.00
0005433817448	13895	Economy	6300.00
0005434733004	13895	Economy	6300.00
0005434733003	13895	Economy	6300.00
0005434733001	13895	Economy	6300.00
0005433817464	13895	Economy	6300.00
0005434733002	13895	Economy	6300.00
0005433817467	13895	Economy	6300.00
0005435982590	2346	Business	184500.00
0005433434645	2346	Business	184500.00
0005433754553	2346	Business	184500.00
0005432984909	2346	Business	184500.00
0005433434615	2346	Business	184500.00
0005432985111	2346	Business	184500.00
0005433754558	2346	Business	184500.00
0005435982605	2346	Business	184500.00
0005433754591	2346	Business	184500.00
0005432985037	2346	Business	184500.00
0005435982597	2346	Business	184500.00
0005435982606	2346	Business	184500.00
0005432985130	2346	Business	184500.00
0005435982609	2346	Business	184500.00
0005435982603	2346	Business	184500.00
0005433754564	2346	Business	184500.00
0005433434600	2346	Business	184500.00
0005435982598	2346	Business	184500.00
0005433754569	2346	Business	184500.00
0005432985025	2346	Business	184500.00
0005435982574	2346	Business	184500.00
0005432985122	2346	Business	184500.00
0005432655618	2346	Business	184500.00
0005433764693	2346	Business	184500.00
0005432985126	2346	Economy	67700.00
0005433434520	2346	Economy	67700.00
0005435982610	2346	Economy	67700.00
0005433754593	2346	Economy	61500.00
0005432869516	2346	Economy	61500.00
0005433434669	2346	Economy	61500.00
0005433434601	2346	Economy	61500.00
0005435982594	2346	Economy	61500.00
0005433754599	2346	Economy	61500.00
0005435982615	2346	Economy	61500.00
0005433434608	2346	Economy	61500.00
0005433754567	2346	Economy	61500.00
0005432300301	2346	Economy	61500.00
0005433434476	2346	Economy	61500.00
0005433434577	2346	Economy	61500.00
0005432984780	2346	Economy	61500.00
0005435982602	2346	Economy	61500.00
0005434731156	2346	Economy	61500.00
0005435982593	2346	Economy	61500.00
0005432655614	2346	Economy	61500.00
0005433434666	2346	Economy	61500.00
0005432985125	2346	Economy	61500.00
0005435982572	2346	Economy	61500.00
0005435982580	2346	Economy	61500.00
0005433434474	2346	Economy	61500.00
0005435982595	2346	Economy	61500.00
0005434731159	2346	Economy	61500.00
0005433754552	2346	Economy	61500.00
0005432985043	2346	Economy	61500.00
0005432985078	2346	Economy	61500.00
0005433434496	2346	Economy	61500.00
0005432655612	2346	Economy	61500.00
0005433754582	2346	Economy	61500.00
0005433434719	2346	Economy	61500.00
0005432985121	2346	Economy	61500.00
0005433754600	2346	Economy	61500.00
0005433754556	2346	Economy	61500.00
0005432985100	2346	Economy	61500.00
0005435982607	2346	Economy	61500.00
0005432300302	2346	Economy	61500.00
0005435982577	2346	Economy	61500.00
0005433434617	2346	Economy	61500.00
0005435982589	2346	Economy	61500.00
0005435982579	2346	Economy	61500.00
0005432985129	2346	Economy	61500.00
0005433754549	2346	Economy	61500.00
0005433754560	2346	Economy	61500.00
0005432226098	2346	Economy	61500.00
0005433434495	2346	Economy	61500.00
0005432985092	2346	Economy	61500.00
0005432985079	2346	Economy	61500.00
0005435982611	2346	Economy	61500.00
0005433434686	2346	Economy	61500.00
0005433754576	2346	Economy	61500.00
0005433754583	2346	Economy	61500.00
0005434731144	2346	Economy	61500.00
0005435982617	2346	Economy	61500.00
0005433754566	2346	Economy	61500.00
0005433766665	2346	Economy	61500.00
0005435982618	2346	Economy	61500.00
0005432985044	2346	Economy	61500.00
0005432985036	2346	Economy	61500.00
0005432984966	2346	Economy	61500.00
0005433434542	2346	Economy	61500.00
0005435982619	2346	Economy	61500.00
0005433754581	2346	Economy	61500.00
0005432985024	2346	Economy	61500.00
0005432655610	2346	Economy	61500.00
0005432226097	2346	Economy	61500.00
0005433754559	2346	Economy	61500.00
0005432985131	2346	Economy	61500.00
0005435982600	2346	Economy	61500.00
0005433754568	2346	Economy	61500.00
0005432300300	2346	Economy	61500.00
0005432226096	2346	Economy	61500.00
0005433754589	2346	Economy	61500.00
0005433434578	2346	Economy	61500.00
0005435982571	2346	Economy	61500.00
0005432984910	2346	Economy	61500.00
0005435982601	2346	Economy	61500.00
0005432655615	2346	Economy	61500.00
0005433754565	2346	Economy	61500.00
0005435982612	2346	Economy	61500.00
0005435982604	2346	Economy	61500.00
0005433434703	2346	Economy	61500.00
0005434731137	2346	Economy	61500.00
0005433754551	2346	Economy	61500.00
0005433754585	2346	Economy	61500.00
0005435982578	2346	Economy	61500.00
0005435982614	2346	Economy	61500.00
0005433754580	2346	Economy	61500.00
0005432984779	2346	Economy	61500.00
0005435982576	2346	Economy	61500.00
0005433754555	2346	Economy	67700.00
0005435982581	2346	Economy	67700.00
0005433754579	2346	Economy	61500.00
0005435982584	2346	Economy	61500.00
0005435982591	2346	Economy	61500.00
0005435982599	2346	Economy	67700.00
0005433434718	2346	Economy	67700.00
0005433766662	2346	Economy	61500.00
0005433754571	2346	Economy	61500.00
0005435982608	2346	Economy	61500.00
0005432655609	2346	Economy	61500.00
0005435982586	2346	Economy	61500.00
0005432300298	2346	Economy	61500.00
0005435982592	2346	Economy	61500.00
0005433754557	2346	Economy	61500.00
0005433434665	2346	Economy	61500.00
0005433754584	2346	Economy	61500.00
0005433754601	2346	Economy	61500.00
0005433434475	2346	Economy	61500.00
0005433754573	2346	Economy	61500.00
0005432226094	2346	Economy	61500.00
0005432984959	2346	Economy	61500.00
0005433754546	2346	Economy	61500.00
0005433754598	2346	Economy	61500.00
0005433754596	2346	Economy	61500.00
0005433754586	2346	Economy	61500.00
0005435982585	2346	Economy	61500.00
0005433754574	2346	Economy	61500.00
0005432655613	2346	Economy	61500.00
0005433754590	2346	Economy	61500.00
0005432226095	2346	Economy	61500.00
0005433754578	2346	Economy	61500.00
0005433766664	2346	Economy	61500.00
0005434731143	2346	Economy	61500.00
0005432300299	2346	Economy	61500.00
0005435982583	2346	Economy	61500.00
0005433754587	2346	Economy	61500.00
0005435982616	2346	Economy	61500.00
0005433434560	2346	Economy	61500.00
0005433754577	2346	Economy	61500.00
0005433754547	2346	Economy	61500.00
0005432984919	2346	Economy	61500.00
0005432869506	2346	Economy	61500.00
0005432655611	2346	Economy	61500.00
0005435982587	2346	Economy	61500.00
0005432300297	2346	Economy	61500.00
0005433754588	2346	Economy	61500.00
0005432985005	2346	Economy	61500.00
0005435982575	2346	Economy	61500.00
0005433766663	2346	Economy	61500.00
0005433754572	2346	Economy	61500.00
0005435982588	2346	Economy	61500.00
0005434731152	2346	Economy	61500.00
0005433764692	2346	Economy	61500.00
0005433754548	2346	Economy	61500.00
0005433754575	2346	Economy	61500.00
0005433754554	2346	Economy	61500.00
0005433754561	2346	Economy	61500.00
0005433754550	2346	Economy	61500.00
0005432984949	2346	Economy	61500.00
0005433434525	2346	Economy	61500.00
0005435982582	2346	Economy	61500.00
0005432655617	2346	Economy	61500.00
0005435982613	2346	Economy	61500.00
0005433754594	2346	Economy	61500.00
0005435982573	2346	Economy	61500.00
0005434731158	2346	Economy	61500.00
0005432869505	2346	Economy	61500.00
0005432655607	2346	Economy	61500.00
0005433754592	2346	Economy	61500.00
0005435982596	2346	Economy	61500.00
0005432985006	2346	Economy	61500.00
0005432655616	2346	Economy	61500.00
0005433754562	2346	Economy	61500.00
0005433754597	2346	Economy	61500.00
0005432655608	2346	Economy	61500.00
0005433754570	2346	Economy	61500.00
0005433754563	2346	Economy	61500.00
0005433754595	2346	Economy	61500.00
0005432655497	26158	Business	184500.00
0005433434870	26158	Business	184500.00
0005433753862	26158	Business	184500.00
0005432985267	26158	Business	184500.00
0005432985281	26158	Business	184500.00
0005433434861	26158	Business	184500.00
0005432985291	26158	Business	184500.00
0005432869565	26158	Business	184500.00
0005432869567	26158	Business	184500.00
0005435982093	26158	Business	184500.00
0005435982214	26158	Business	184500.00
0005435982181	26158	Business	184500.00
0005433754145	26158	Business	184500.00
0005432985283	26158	Business	184500.00
0005432985286	26158	Business	184500.00
0005432985275	26158	Business	184500.00
0005435982237	26158	Business	184500.00
0005432985270	26158	Business	184500.00
0005432655518	26158	Business	184500.00
0005433766620	26158	Business	184500.00
0005433434860	26158	Business	184500.00
0005433753909	26158	Business	184500.00
0005433754205	26158	Business	184500.00
0005433754137	26158	Business	184500.00
0005433434866	26158	Business	184500.00
0005433434851	26158	Business	184500.00
0005432655517	26158	Business	184500.00
0005432051147	26158	Business	184500.00
0005433434862	26158	Economy	67700.00
0005432985288	26158	Economy	67700.00
0005434731197	26158	Economy	67700.00
0005432049487	26158	Economy	61500.00
0005433434846	26158	Economy	67700.00
0005433754239	26158	Economy	61500.00
0005435982238	26158	Economy	61500.00
0005435982130	26158	Economy	61500.00
0005432655505	26158	Economy	61500.00
0005435982182	26158	Economy	61500.00
0005433434859	26158	Economy	61500.00
0005433434854	26158	Economy	61500.00
0005435982073	26158	Economy	61500.00
0005433753806	26158	Economy	61500.00
0005433434843	26158	Economy	61500.00
0005432985266	26158	Economy	61500.00
0005433753807	26158	Economy	61500.00
0005432051148	26158	Economy	61500.00
0005433754086	26158	Economy	61500.00
0005433753958	26158	Economy	61500.00
0005432985278	26158	Economy	61500.00
0005432985295	26158	Economy	61500.00
0005435982281	26158	Economy	61500.00
0005432985289	26158	Economy	61500.00
0005432051149	26158	Economy	61500.00
0005433434848	26158	Economy	61500.00
0005435982075	26158	Economy	61500.00
0005435982101	26158	Economy	61500.00
0005432985293	26158	Economy	61500.00
0005432985282	26158	Economy	61500.00
0005432655498	26158	Economy	61500.00
0005433434855	26158	Economy	61500.00
0005435982157	26158	Economy	61500.00
0005435982282	26158	Economy	61500.00
0005432985284	26158	Economy	61500.00
0005433766631	26158	Economy	61500.00
0005433754079	26158	Economy	61500.00
0005433754155	26158	Economy	61500.00
0005435982269	26158	Economy	61500.00
0005433753965	26158	Economy	61500.00
0005432985274	26158	Economy	61500.00
0005434731199	26158	Economy	61500.00
0005435982127	26158	Economy	61500.00
0005432655493	26158	Economy	61500.00
0005432655447	26158	Economy	61500.00
0005435982125	26158	Economy	61500.00
0005433434857	26158	Economy	61500.00
0005435982098	26158	Economy	61500.00
0005433753918	26158	Economy	61500.00
0005432985287	26158	Economy	61500.00
0005435982090	26158	Economy	61500.00
0005432985268	26158	Economy	61500.00
0005433753959	26158	Economy	61500.00
0005433434842	26158	Economy	61500.00
0005435982225	26158	Economy	61500.00
0005433754154	26158	Economy	61500.00
0005433754261	26158	Economy	61500.00
0005432985280	26158	Economy	61500.00
0005435982196	26158	Economy	61500.00
0005433434863	26158	Economy	61500.00
0005435981972	26158	Economy	61500.00
0005435982126	26158	Economy	61500.00
0005433754138	26158	Economy	61500.00
0005433754087	26158	Economy	61500.00
0005433434844	26158	Economy	61500.00
0005433753804	26158	Economy	61500.00
0005433754134	26158	Economy	61500.00
0005432655481	26158	Economy	61500.00
0005433766619	26158	Economy	61500.00
0005433754242	26158	Economy	61500.00
0005433753910	26158	Economy	61500.00
0005433434847	26158	Economy	61500.00
0005433754272	26158	Economy	61500.00
0005435982113	26158	Economy	61500.00
0005435982262	26158	Economy	61500.00
0005433753919	26158	Economy	61500.00
0005433754198	26158	Economy	61500.00
0005433754168	26158	Economy	61500.00
0005435982052	26158	Economy	61500.00
0005432655448	26158	Economy	61500.00
0005435982076	26158	Economy	61500.00
0005432049486	26158	Economy	61500.00
0005433434865	26158	Economy	61500.00
0005432869562	26158	Economy	61500.00
0005432869561	26158	Economy	61500.00
0005433754022	26158	Economy	61500.00
0005432869566	26158	Economy	61500.00
0005432869560	26158	Economy	61500.00
0005433753985	26158	Economy	61500.00
0005433434867	26158	Economy	61500.00
0005432985273	26158	Economy	61500.00
0005435982197	26158	Economy	61500.00
0005435981971	26158	Economy	61500.00
0005433754271	26158	Economy	61500.00
0005433754196	26158	Economy	61500.00
0005435982059	26158	Economy	61500.00
0005432985292	26158	Economy	67700.00
0005432985294	26158	Economy	67700.00
0005435982285	26158	Economy	61500.00
0005433753941	26158	Economy	61500.00
0005435982205	26158	Economy	61500.00
0005432051146	26158	Economy	67700.00
0005433754021	26158	Economy	67700.00
0005433434856	26158	Economy	61500.00
0005435982057	26158	Economy	61500.00
0005433434858	26158	Economy	61500.00
0005433753855	26158	Economy	61500.00
0005433754102	26158	Economy	61500.00
0005433434849	26158	Economy	61500.00
0005433754189	26158	Economy	61500.00
0005435981919	26158	Economy	61500.00
0005433434853	26158	Economy	61500.00
0005432985272	26158	Economy	61500.00
0005433754000	26158	Economy	61500.00
0005433754038	26158	Economy	61500.00
0005434731196	26158	Economy	61500.00
0005432985277	26158	Economy	61500.00
0005433766616	26158	Economy	61500.00
0005435982183	26158	Economy	61500.00
0005432985269	26158	Economy	61500.00
0005435982018	26158	Economy	61500.00
0005432869564	26158	Economy	61500.00
0005433434845	26158	Economy	61500.00
0005433754139	26158	Economy	61500.00
0005435981988	26158	Economy	61500.00
0005433434864	26158	Economy	61500.00
0005435982315	26158	Economy	61500.00
0005435982286	26158	Economy	61500.00
0005433766632	26158	Economy	61500.00
0005435982204	26158	Economy	61500.00
0005432985276	26158	Economy	61500.00
0005432049484	26158	Economy	61500.00
0005435982161	26158	Economy	61500.00
0005433434852	26158	Economy	61500.00
0005435982206	26158	Economy	61500.00
0005433434868	26158	Economy	61500.00
0005433753854	26158	Economy	61500.00
0005433434869	26158	Economy	61500.00
0005433754036	26158	Economy	61500.00
0005434731195	26158	Economy	61500.00
0005433766615	26158	Economy	61500.00
0005433754254	26158	Economy	61500.00
0005433753917	26158	Economy	61500.00
0005432985271	26158	Economy	61500.00
0005435982084	26158	Economy	61500.00
0005432985264	26158	Economy	61500.00
0005433753803	26158	Economy	61500.00
0005433754135	26158	Economy	61500.00
0005433753946	26158	Economy	61500.00
0005432985279	26158	Economy	61500.00
0005433754144	26158	Economy	61500.00
0005433753884	26158	Economy	61500.00
0005435982058	26158	Economy	61500.00
0005432655455	26158	Economy	61500.00
0005432985285	26158	Economy	61500.00
0005433754023	26158	Economy	61500.00
0005432655488	26158	Economy	61500.00
0005432985265	26158	Economy	61500.00
0005432655504	26158	Economy	61500.00
0005435982271	26158	Economy	61500.00
0005435982314	26158	Economy	61500.00
0005432985290	26158	Economy	61500.00
0005435982171	26158	Economy	61500.00
0005435982270	26158	Economy	61500.00
0005435982053	26158	Economy	61500.00
0005435982229	26158	Economy	61500.00
0005433754210	26158	Economy	61500.00
0005432049485	26158	Economy	61500.00
0005432655492	26158	Economy	61500.00
0005435982158	26158	Economy	61500.00
0005433753945	26158	Economy	61500.00
0005432869563	26158	Economy	61500.00
0005433434850	26158	Economy	61500.00
0005435982100	26158	Economy	61500.00
0005434731198	26158	Economy	61500.00
0005434374931	1483	Business	38900.00
0005434374940	1483	Business	38900.00
0005432267939	1483	Business	38900.00
0005434374909	1483	Business	38900.00
0005434374922	1483	Business	38900.00
0005433460450	1483	Business	38900.00
0005434374896	1483	Business	38900.00
0005433764669	1483	Economy	13000.00
0005434374902	1483	Economy	13000.00
0005434374913	1483	Economy	13000.00
0005433151400	1483	Economy	13000.00
0005433764670	1483	Economy	13000.00
0005434374930	1483	Economy	13000.00
0005433461602	1483	Economy	13000.00
0005432267937	1483	Economy	13000.00
0005434374945	1483	Economy	13000.00
0005434374918	1483	Economy	13000.00
0005434374923	1483	Economy	13000.00
0005432267940	1483	Economy	13000.00
0005433151353	1483	Economy	13000.00
0005434374899	1483	Economy	13000.00
0005434374914	1483	Economy	13000.00
0005433151354	1483	Economy	13000.00
0005432267934	1483	Economy	13000.00
0005434374915	1483	Economy	13000.00
0005433151329	1483	Economy	13000.00
0005434374924	1483	Economy	13000.00
0005434374933	1483	Economy	13000.00
0005432267938	1483	Economy	13000.00
0005434374900	1483	Economy	13000.00
0005433151258	1483	Economy	13000.00
0005434374950	1483	Economy	13000.00
0005433151503	1483	Economy	13000.00
0005434374938	1483	Economy	13000.00
0005433151211	1483	Economy	13000.00
0005433151330	1483	Economy	13000.00
0005434029645	1483	Economy	13000.00
0005433460449	1483	Economy	13000.00
0005434374932	1483	Economy	13000.00
0005433151420	1483	Economy	14300.00
0005433151331	1483	Economy	14300.00
0005434374907	1483	Economy	14300.00
0005433151477	1483	Economy	14300.00
0005433151410	1483	Economy	14300.00
0005433151409	1483	Economy	14300.00
0005434374943	1483	Economy	13000.00
0005434374936	1483	Economy	13000.00
0005433931444	1483	Economy	13000.00
0005433151482	1483	Economy	13000.00
0005434374905	1483	Economy	13000.00
0005434374946	1483	Economy	13000.00
0005434374941	1483	Economy	13000.00
0005434374908	1483	Economy	13000.00
0005432267935	1483	Economy	13000.00
0005433151413	1483	Economy	13000.00
0005434374935	1483	Economy	13000.00
0005434374919	1483	Economy	13000.00
0005433151350	1483	Economy	13000.00
0005433151395	1483	Economy	13000.00
0005434374948	1483	Economy	13000.00
0005433151358	1483	Economy	13000.00
0005434374921	1483	Economy	13000.00
0005434374904	1483	Economy	13000.00
0005433151504	1483	Economy	13000.00
0005434374901	1483	Economy	13000.00
0005433151374	1483	Economy	13000.00
0005433151455	1483	Economy	13000.00
0005433151328	1483	Economy	13000.00
0005433151414	1483	Economy	13000.00
0005434374947	1483	Economy	13000.00
0005433151373	1483	Economy	13000.00
0005433151525	1483	Economy	13000.00
0005434374917	1483	Economy	13000.00
0005434374928	1483	Economy	13000.00
0005433151327	1483	Economy	13000.00
0005434374949	1483	Economy	13000.00
0005434374920	1483	Economy	13000.00
0005434374916	1483	Economy	13000.00
0005434029641	1483	Economy	13000.00
0005434374903	1483	Economy	13000.00
0005433931460	1483	Economy	13000.00
0005434374927	1483	Economy	13000.00
0005434374906	1483	Economy	13000.00
0005434374910	1483	Economy	13000.00
0005433151441	1483	Economy	13000.00
0005434374911	1483	Economy	13000.00
0005434374944	1483	Economy	13000.00
0005434374898	1483	Economy	13000.00
0005434374939	1483	Economy	13000.00
0005434374937	1483	Economy	13000.00
0005434374929	1483	Economy	13000.00
0005432267936	1483	Economy	13000.00
0005433764676	1483	Economy	13000.00
0005434374894	1483	Economy	13000.00
0005434374926	1483	Economy	13000.00
0005434374912	1483	Economy	13000.00
0005433151210	1483	Economy	13000.00
0005433151442	1483	Economy	13000.00
0005434374934	1483	Economy	13000.00
0005433151401	1483	Economy	13000.00
0005434374895	1483	Economy	13000.00
0005434374897	1483	Economy	13000.00
0005434374925	1483	Economy	13000.00
0005434374942	1483	Economy	13000.00
0005433151604	20105	Business	38900.00
0005433931483	20105	Business	38900.00
0005433151602	20105	Business	38900.00
0005434374607	20105	Business	38900.00
0005434029672	20105	Business	38900.00
0005434374556	20105	Business	38900.00
0005433151612	20105	Business	38900.00
0005433151621	20105	Business	38900.00
0005433151634	20105	Business	38900.00
0005434374346	20105	Economy	13000.00
0005433151633	20105	Economy	13000.00
0005434029671	20105	Economy	13000.00
0005433151616	20105	Economy	13000.00
0005434374446	20105	Economy	13000.00
0005433151617	20105	Economy	13000.00
0005433151624	20105	Economy	13000.00
0005434374664	20105	Economy	13000.00
0005434374393	20105	Economy	13000.00
0005433151618	20105	Economy	13000.00
0005434374490	20105	Economy	13000.00
0005434374540	20105	Economy	13000.00
0005433151607	20105	Economy	13000.00
0005433151620	20105	Economy	13000.00
0005434374606	20105	Economy	13000.00
0005434374554	20105	Economy	13000.00
0005434374692	20105	Economy	13000.00
0005434374778	20105	Economy	13000.00
0005434374676	20105	Economy	13000.00
0005433151629	20105	Economy	13000.00
0005433151608	20105	Economy	13000.00
0005434374261	20105	Economy	13000.00
0005433151630	20105	Economy	13000.00
0005434374347	20105	Economy	13000.00
0005433151613	20105	Economy	13000.00
0005434029673	20105	Economy	13000.00
0005434374263	20105	Economy	13000.00
0005434374423	20105	Economy	14300.00
0005433151631	20105	Economy	14300.00
0005434374625	20105	Economy	14300.00
0005433151606	20105	Economy	14300.00
0005433151632	20105	Economy	13000.00
0005434374670	20105	Economy	13000.00
0005434374526	20105	Economy	13000.00
0005433151610	20105	Economy	13000.00
0005433151615	20105	Economy	13000.00
0005434374429	20105	Economy	13000.00
0005433151619	20105	Economy	13000.00
0005433931482	20105	Economy	13000.00
0005434374557	20105	Economy	13000.00
0005432056322	20105	Economy	13000.00
0005434374439	20105	Economy	13000.00
0005433931484	20105	Economy	13000.00
0005434374579	20105	Economy	13000.00
0005434374499	20105	Economy	13000.00
0005434374580	20105	Economy	13000.00
0005433151611	20105	Economy	13000.00
0005434374496	20105	Economy	13000.00
0005434374589	20105	Economy	13000.00
0005433151623	20105	Economy	13000.00
0005434374583	20105	Economy	13000.00
0005433151636	20105	Economy	13000.00
0005434374498	20105	Economy	13000.00
0005432056321	20105	Economy	13000.00
0005433151628	20105	Economy	13000.00
0005433764693	20105	Economy	13000.00
0005434374418	20105	Economy	13000.00
0005433151614	20105	Economy	13000.00
0005433151626	20105	Economy	13000.00
0005434374691	20105	Economy	13000.00
0005432056324	20105	Economy	13000.00
0005434374654	20105	Economy	13000.00
0005434374584	20105	Economy	13000.00
0005432056323	20105	Economy	13000.00
0005433151637	20105	Economy	13000.00
0005434374613	20105	Economy	13000.00
0005433151603	20105	Economy	13000.00
0005433764692	20105	Economy	13000.00
0005434374527	20105	Economy	13000.00
0005433151605	20105	Economy	13000.00
0005434374262	20105	Economy	13000.00
0005434374560	20105	Economy	13000.00
0005433151627	20105	Economy	13000.00
0005434374541	20105	Economy	13000.00
0005434374591	20105	Economy	13000.00
0005433151635	20105	Economy	13000.00
0005434374609	20105	Economy	13000.00
0005434374428	20105	Economy	13000.00
0005433151609	20105	Economy	13000.00
0005433151625	20105	Economy	13000.00
0005434374558	20105	Economy	13000.00
0005434374500	20105	Economy	13000.00
0005434374245	20105	Economy	13000.00
0005434374608	20105	Economy	13000.00
0005434374602	20105	Economy	13000.00
0005433151622	20105	Economy	13000.00
0005432424756	534	Business	27500.00
0005432424775	534	Business	27500.00
0005432282907	534	Business	27500.00
0005432424773	534	Business	27500.00
0005432282911	534	Business	27500.00
0005432282908	534	Business	27500.00
0005432282912	534	Business	27500.00
0005432424753	534	Business	27500.00
0005432424761	534	Business	27500.00
0005432424762	534	Economy	10100.00
0005432424752	534	Economy	10100.00
0005432424764	534	Economy	10100.00
0005432424759	534	Economy	10100.00
0005432424738	534	Economy	9200.00
0005432282909	534	Economy	9200.00
0005432424723	534	Economy	9200.00
0005432424748	534	Economy	9200.00
0005432424732	534	Economy	9200.00
0005432424725	534	Economy	9200.00
0005432424719	534	Economy	9200.00
0005432282906	534	Economy	9200.00
0005432424742	534	Economy	9200.00
0005432424749	534	Economy	9200.00
0005432424727	534	Economy	9200.00
0005432424720	534	Economy	9200.00
0005432424734	534	Economy	9200.00
0005432424770	534	Economy	9200.00
0005432424754	534	Economy	9200.00
0005432424746	534	Economy	9200.00
0005432424772	534	Economy	9200.00
0005432424724	534	Economy	9200.00
0005432424750	534	Economy	9200.00
0005432424763	534	Economy	9200.00
0005432424733	534	Economy	9200.00
0005432424765	534	Economy	9200.00
0005432424717	534	Economy	9200.00
0005432424729	534	Economy	9200.00
0005432424736	534	Economy	9200.00
0005432424744	534	Economy	9200.00
0005432424726	534	Economy	9200.00
0005432424747	534	Economy	9200.00
0005432424740	534	Economy	10100.00
0005432424728	534	Economy	9200.00
0005432424758	534	Economy	9200.00
0005432424760	534	Economy	9200.00
0005432424767	534	Economy	9200.00
0005432424721	534	Economy	9200.00
0005432424737	534	Economy	9200.00
0005432424731	534	Economy	9200.00
0005432424741	534	Economy	9200.00
0005432282913	534	Economy	9200.00
0005432424735	534	Economy	9200.00
0005432424769	534	Economy	9200.00
0005432424766	534	Economy	9200.00
0005432282905	534	Economy	9200.00
0005432282910	534	Economy	9200.00
0005432424715	534	Economy	9200.00
0005432424739	534	Economy	9200.00
0005432424722	534	Economy	9200.00
0005432424718	534	Economy	9200.00
0005432424755	534	Economy	9200.00
0005432424768	534	Economy	9200.00
0005432424771	534	Economy	9200.00
0005432424716	534	Economy	9200.00
0005432424751	534	Economy	9200.00
0005432424745	534	Economy	9200.00
0005432424774	534	Economy	9200.00
0005432424743	534	Economy	9200.00
0005432424757	534	Economy	9200.00
0005432424730	534	Economy	9200.00
0005434446509	12869	Business	27500.00
0005434446515	12869	Business	27500.00
0005434446507	12869	Business	27500.00
0005432302353	12869	Economy	10100.00
0005433158142	12869	Economy	9200.00
0005434446510	12869	Economy	9200.00
0005433158146	12869	Economy	9200.00
0005432302355	12869	Economy	9200.00
0005432302354	12869	Economy	9200.00
0005433158144	12869	Economy	9200.00
0005433158145	12869	Economy	9200.00
0005434446508	12869	Economy	9200.00
0005433158143	12869	Economy	9200.00
0005432424187	12866	Business	27500.00
0005432424305	12866	Business	27500.00
0005432424242	12866	Business	27500.00
0005432424254	12866	Economy	9200.00
0005432424195	12866	Economy	9200.00
0005432424200	12866	Economy	9200.00
0005432424299	12866	Economy	9200.00
0005432424278	12866	Economy	9200.00
0005432424125	12866	Economy	9200.00
0005432424296	12866	Economy	9200.00
0005432424321	12866	Economy	9200.00
0005432424302	12866	Economy	9200.00
0005432424181	12866	Economy	9200.00
0005432424126	12866	Economy	9200.00
0005432424194	12866	Economy	9200.00
0005432424295	12866	Economy	9200.00
0005432424319	12866	Economy	9200.00
0005432424259	12866	Economy	9200.00
0005432424239	12866	Economy	9200.00
0005432424088	12866	Economy	9200.00
0005432424101	12866	Economy	9200.00
0005432424183	12866	Economy	9200.00
0005432424306	12866	Economy	9200.00
0005432424300	12866	Economy	9200.00
0005432424100	12866	Economy	9200.00
0005432424256	12866	Economy	10100.00
0005432424260	12866	Economy	9200.00
0005432424117	12866	Economy	9200.00
0005432424267	12866	Economy	9200.00
0005432424241	12866	Economy	9200.00
0005432424118	12866	Economy	9200.00
0005432424257	12866	Economy	9200.00
0005432424124	12866	Economy	9200.00
0005432424098	12866	Economy	9200.00
0005432424314	12866	Economy	9200.00
0005432424154	12866	Economy	9200.00
0005432424045	12866	Economy	9200.00
0005432424099	12866	Economy	9200.00
0005432424286	12866	Economy	9200.00
0005432424292	12866	Economy	9200.00
0005432424322	12866	Economy	9200.00
0005432424323	12866	Economy	9200.00
0005432424307	12866	Economy	9200.00
0005432424301	12866	Economy	9200.00
0005432424202	12866	Economy	9200.00
0005432424285	12866	Economy	9200.00
0005432424193	12866	Economy	9200.00
0005432424180	12866	Economy	9200.00
0005434024129	479	Business	24500.00
0005433057756	479	Business	24500.00
0005433057721	479	Business	24500.00
0005434024121	479	Business	24500.00
0005434024135	479	Business	24500.00
0005433929594	479	Business	24500.00
0005434024143	479	Business	24500.00
0005433057838	479	Business	24500.00
0005433057824	479	Business	24500.00
0005434024104	479	Business	24500.00
0005433057791	479	Business	24500.00
0005434024147	479	Business	24500.00
0005433057702	479	Business	24500.00
0005434024151	479	Business	24500.00
0005433057813	479	Business	24500.00
0005433057938	479	Business	24500.00
0005433057952	479	Business	24500.00
0005434024100	479	Business	24500.00
0005433057879	479	Business	24500.00
0005433057823	479	Business	24500.00
0005434024120	479	Business	24500.00
0005434024162	479	Business	24500.00
0005433057800	479	Business	24500.00
0005434024138	479	Business	24500.00
0005433057977	479	Economy	9000.00
0005434029670	479	Economy	9000.00
0005434024140	479	Economy	8200.00
0005434032048	479	Economy	8200.00
0005434032051	479	Economy	8200.00
0005433057784	479	Economy	8200.00
0005434024125	479	Economy	8200.00
0005433057724	479	Economy	8200.00
0005434024119	479	Economy	8200.00
0005434024157	479	Economy	8200.00
0005432235681	479	Economy	8200.00
0005432235684	479	Economy	8200.00
0005433057660	479	Economy	8200.00
0005434024154	479	Economy	8200.00
0005434024161	479	Economy	8200.00
0005432235687	479	Economy	8200.00
0005433057676	479	Economy	8200.00
0005434032047	479	Economy	8200.00
0005433057897	479	Economy	8200.00
0005433057939	479	Economy	8200.00
0005434024099	479	Economy	8200.00
0005434024131	479	Economy	8200.00
0005433057847	479	Economy	8200.00
0005434032050	479	Economy	8200.00
0005434024123	479	Economy	8200.00
0005434024139	479	Economy	8200.00
0005434024106	479	Economy	8200.00
0005434024105	479	Economy	8200.00
0005434024134	479	Economy	8200.00
0005433057632	479	Economy	8200.00
0005433057822	479	Economy	8200.00
0005433058053	479	Economy	8200.00
0005433057907	479	Economy	8200.00
0005433058005	479	Economy	8200.00
0005434024124	479	Economy	8200.00
0005434024110	479	Economy	8200.00
0005434735657	479	Economy	8200.00
0005432235683	479	Economy	8200.00
0005432235688	479	Economy	8200.00
0005434028313	479	Economy	8200.00
0005434024126	479	Economy	8200.00
0005434024164	479	Economy	8200.00
0005434024158	479	Economy	8200.00
0005434024159	479	Economy	8200.00
0005433057713	479	Economy	8200.00
0005434735666	479	Economy	8200.00
0005433057699	479	Economy	8200.00
0005434024116	479	Economy	8200.00
0005433058041	479	Economy	8200.00
0005434024146	479	Economy	8200.00
0005433929610	479	Economy	8200.00
0005433057799	479	Economy	8200.00
0005433057793	479	Economy	8200.00
0005433057798	479	Economy	8200.00
0005433057862	479	Economy	8200.00
0005434024156	479	Economy	8200.00
0005434024111	479	Economy	8200.00
0005434024149	479	Economy	8200.00
0005434024097	479	Economy	8200.00
0005434735663	479	Economy	8200.00
0005433929602	479	Economy	8200.00
0005433057951	479	Economy	8200.00
0005433057856	479	Economy	8200.00
0005434024132	479	Economy	8200.00
0005434024101	479	Economy	8200.00
0005433057860	479	Economy	8200.00
0005434024108	479	Economy	8200.00
0005434024107	479	Economy	8200.00
0005434024153	479	Economy	8200.00
0005434024102	479	Economy	8200.00
0005434024145	479	Economy	8200.00
0005433057880	479	Economy	8200.00
0005434024103	479	Economy	9000.00
0005434024150	479	Economy	9000.00
0005434024160	479	Economy	8200.00
0005434024117	479	Economy	8200.00
0005434024148	479	Economy	8200.00
0005434024114	479	Economy	9000.00
0005433057861	479	Economy	8200.00
0005434024113	479	Economy	8200.00
0005433057782	479	Economy	8200.00
0005433057698	479	Economy	8200.00
0005434024137	479	Economy	8200.00
0005434024152	479	Economy	8200.00
0005434024155	479	Economy	8200.00
0005434028312	479	Economy	8200.00
0005434028311	479	Economy	8200.00
0005434024127	479	Economy	8200.00
0005434024133	479	Economy	8200.00
0005433684417	479	Economy	8200.00
0005434032049	479	Economy	8200.00
0005433929600	479	Economy	8200.00
0005433057832	479	Economy	8200.00
0005433684418	479	Economy	8200.00
0005434024130	479	Economy	8200.00
0005434024109	479	Economy	8200.00
0005433057928	479	Economy	8200.00
0005433057849	479	Economy	8200.00
0005433057787	479	Economy	8200.00
0005434024122	479	Economy	8200.00
0005433057931	479	Economy	8200.00
0005433058042	479	Economy	8200.00
0005432235686	479	Economy	8200.00
0005433057633	479	Economy	8200.00
0005433057792	479	Economy	8200.00
0005434024163	479	Economy	8200.00
0005433057959	479	Economy	8200.00
0005432235682	479	Economy	8200.00
0005434024112	479	Economy	8200.00
0005433057723	479	Economy	8200.00
0005433057644	479	Economy	8200.00
0005434735664	479	Economy	8200.00
0005434029669	479	Economy	8200.00
0005433929595	479	Economy	8200.00
0005433057957	479	Economy	8200.00
0005434024142	479	Economy	8200.00
0005432235685	479	Economy	8200.00
0005434024144	479	Economy	8200.00
0005433057755	479	Economy	8200.00
0005434735665	479	Economy	8200.00
0005434024115	479	Economy	8200.00
0005434024118	479	Economy	8200.00
0005433057805	479	Economy	8200.00
0005433057786	479	Economy	8200.00
0005434024136	479	Economy	8200.00
0005434024128	479	Economy	8200.00
0005434024098	479	Economy	8200.00
0005432045624	479	Economy	8200.00
0005434024141	479	Economy	8200.00
0005433057857	479	Economy	8200.00
0005433057785	479	Economy	8200.00
0005432045623	479	Economy	8200.00
0005434023594	12663	Business	24500.00
0005433058118	12663	Business	24500.00
0005433058126	12663	Business	24500.00
0005432156397	12663	Business	24500.00
0005434023584	12663	Business	24500.00
0005433058145	12663	Business	24500.00
0005433929639	12663	Business	24500.00
0005434023618	12663	Business	24500.00
0005433058134	12663	Business	24500.00
0005434023670	12663	Business	24500.00
0005434023492	12663	Business	24500.00
0005433058133	12663	Business	24500.00
0005433058127	12663	Business	24500.00
0005433058147	12663	Business	24500.00
0005434023427	12663	Business	24500.00
0005434023314	12663	Business	24500.00
0005434023550	12663	Business	24500.00
0005434023740	12663	Economy	9000.00
0005433058122	12663	Economy	8200.00
0005434023315	12663	Economy	8200.00
0005433058139	12663	Economy	8200.00
0005433058136	12663	Economy	8200.00
0005433058116	12663	Economy	8200.00
0005434023317	12663	Economy	8200.00
0005432156391	12663	Economy	8200.00
0005434023544	12663	Economy	8200.00
0005433929641	12663	Economy	8200.00
0005434023590	12663	Economy	8200.00
0005433684433	12663	Economy	8200.00
0005433684434	12663	Economy	8200.00
0005434735723	12663	Economy	8200.00
0005434023591	12663	Economy	8200.00
0005434023622	12663	Economy	8200.00
0005434023535	12663	Economy	8200.00
0005434023664	12663	Economy	8200.00
0005433058141	12663	Economy	8200.00
0005433058129	12663	Economy	8200.00
0005434023808	12663	Economy	8200.00
0005434029641	12663	Economy	8200.00
0005434023674	12663	Economy	8200.00
0005433058149	12663	Economy	8200.00
0005432156396	12663	Economy	8200.00
0005434023728	12663	Economy	8200.00
0005434023803	12663	Economy	8200.00
0005433058146	12663	Economy	8200.00
0005433058153	12663	Economy	8200.00
0005434023577	12663	Economy	8200.00
0005433058143	12663	Economy	8200.00
0005434023621	12663	Economy	8200.00
0005434023534	12663	Economy	8200.00
0005434032024	12663	Economy	8200.00
0005434032023	12663	Economy	8200.00
0005434023671	12663	Economy	8200.00
0005434032017	12663	Economy	8200.00
0005433058148	12663	Economy	8200.00
0005433058119	12663	Economy	8200.00
0005434735720	12663	Economy	8200.00
0005434023846	12663	Economy	8200.00
0005434023504	12663	Economy	8200.00
0005433058123	12663	Economy	8200.00
0005434023633	12663	Economy	8200.00
0005434735721	12663	Economy	8200.00
0005433929637	12663	Economy	8200.00
0005434023845	12663	Economy	8200.00
0005434023413	12663	Economy	8200.00
0005433058135	12663	Economy	8200.00
0005434023135	12663	Economy	8200.00
0005434023612	12663	Economy	8200.00
0005434023578	12663	Economy	8200.00
0005433058132	12663	Economy	8200.00
0005434023691	12663	Economy	8200.00
0005432156395	12663	Economy	8200.00
0005432157504	12663	Economy	8200.00
0005434023587	12663	Economy	8200.00
0005433058140	12663	Economy	8200.00
0005434032014	12663	Economy	8200.00
0005434023491	12663	Economy	8200.00
0005434023540	12663	Economy	8200.00
0005434023312	12663	Economy	8200.00
0005433058138	12663	Economy	9000.00
0005433929640	12663	Economy	9000.00
0005434023551	12663	Economy	8200.00
0005434032018	12663	Economy	8200.00
0005434032016	12663	Economy	9000.00
0005434023610	12663	Economy	9000.00
0005434023597	12663	Economy	8200.00
0005433929638	12663	Economy	8200.00
0005434032022	12663	Economy	8200.00
0005434023466	12663	Economy	8200.00
0005434023505	12663	Economy	8200.00
0005434023134	12663	Economy	8200.00
0005434023611	12663	Economy	8200.00
0005434735722	12663	Economy	8200.00
0005433058121	12663	Economy	8200.00
0005434023615	12663	Economy	8200.00
0005434735724	12663	Economy	8200.00
0005434023585	12663	Economy	8200.00
0005434023807	12663	Economy	8200.00
0005434023477	12663	Economy	8200.00
0005434023440	12663	Economy	8200.00
0005433058128	12663	Economy	8200.00
0005434023508	12663	Economy	8200.00
0005434023554	12663	Economy	8200.00
0005433058144	12663	Economy	8200.00
0005434023762	12663	Economy	8200.00
0005433058124	12663	Economy	8200.00
0005434023729	12663	Economy	8200.00
0005432156393	12663	Economy	8200.00
0005433058152	12663	Economy	8200.00
0005432156392	12663	Economy	8200.00
0005433058115	12663	Economy	8200.00
0005434023555	12663	Economy	8200.00
0005432157503	12663	Economy	8200.00
0005434023478	12663	Economy	8200.00
0005433058131	12663	Economy	8200.00
0005434023530	12663	Economy	8200.00
0005434023583	12663	Economy	8200.00
0005434023316	12663	Economy	8200.00
0005434023572	12663	Economy	8200.00
0005433058150	12663	Economy	8200.00
0005433058142	12663	Economy	8200.00
0005433058114	12663	Economy	8200.00
0005433058130	12663	Economy	8200.00
0005434023802	12663	Economy	8200.00
0005434023442	12663	Economy	8200.00
0005434023595	12663	Economy	8200.00
0005434032030	12663	Economy	8200.00
0005433058120	12663	Economy	8200.00
0005433058117	12663	Economy	8200.00
0005434029645	12663	Economy	8200.00
0005434023675	12663	Economy	8200.00
0005433058151	12663	Economy	8200.00
0005434023443	12663	Economy	8200.00
0005434023634	12663	Economy	8200.00
0005434023665	12663	Economy	8200.00
0005434023582	12663	Economy	8200.00
0005432156394	12663	Economy	8200.00
0005434032029	12663	Economy	8200.00
0005433058125	12663	Economy	8200.00
0005434023600	12663	Economy	8200.00
0005433058137	12663	Economy	8200.00
0005433923852	2120	Business	34700.00
0005433036206	2120	Business	34700.00
0005433923905	2120	Business	34700.00
0005433923938	2120	Business	34700.00
0005433036205	2120	Business	34700.00
0005433923937	2120	Business	34700.00
0005433923917	2120	Business	34700.00
0005433923929	2120	Business	34700.00
0005433923888	2120	Business	34700.00
0005433036311	2120	Business	34700.00
0005433923921	2120	Business	34700.00
0005433036131	2120	Business	34700.00
0005433923920	2120	Business	34700.00
0005433923863	2120	Business	34700.00
0005433036081	2120	Business	34700.00
0005433923849	2120	Business	34700.00
0005432231629	2120	Business	34700.00
0005433036207	2120	Business	34700.00
0005433036169	2120	Business	34700.00
0005433923902	2120	Business	34700.00
0005433035938	2120	Business	34700.00
0005432231631	2120	Business	34700.00
0005433036128	2120	Business	34700.00
0005433036211	2120	Business	34700.00
0005433923940	2120	Business	34700.00
0005433875390	2120	Business	34700.00
0005433036296	2120	Business	34700.00
0005433923893	2120	Economy	12700.00
0005433036260	2120	Economy	12700.00
0005433036266	2120	Economy	12700.00
0005433923855	2120	Economy	12700.00
0005433923862	2120	Economy	11600.00
0005432231626	2120	Economy	11600.00
0005433036013	2120	Economy	11600.00
0005433923927	2120	Economy	11600.00
0005433036368	2120	Economy	11600.00
0005433035899	2120	Economy	11600.00
0005433923934	2120	Economy	11600.00
0005433923898	2120	Economy	11600.00
0005433036183	2120	Economy	11600.00
0005433923922	2120	Economy	11600.00
0005433923880	2120	Economy	11600.00
0005433923890	2120	Economy	11600.00
0005433036367	2120	Economy	11600.00
0005433923892	2120	Economy	11600.00
0005433923887	2120	Economy	11600.00
0005433923909	2120	Economy	11600.00
0005433036056	2120	Economy	11600.00
0005433923907	2120	Economy	11600.00
0005433036023	2120	Economy	11600.00
0005433923848	2120	Economy	11600.00
0005433923926	2120	Economy	11600.00
0005433036195	2120	Economy	11600.00
0005433923924	2120	Economy	11600.00
0005433923912	2120	Economy	11600.00
0005433923856	2120	Economy	11600.00
0005433036290	2120	Economy	11600.00
0005433923896	2120	Economy	11600.00
0005433929639	2120	Economy	11600.00
0005433036016	2120	Economy	11600.00
0005433923911	2120	Economy	11600.00
0005433036224	2120	Economy	11600.00
0005433036407	2120	Economy	11600.00
0005433875389	2120	Economy	11600.00
0005433923901	2120	Economy	11600.00
0005433036059	2120	Economy	11600.00
0005433923861	2120	Economy	11600.00
0005433923919	2120	Economy	11600.00
0005433923857	2120	Economy	11600.00
0005433923864	2120	Economy	11600.00
0005433923941	2120	Economy	11600.00
0005433923889	2120	Economy	11600.00
0005433036228	2120	Economy	11600.00
0005433923868	2120	Economy	11600.00
0005433923908	2120	Economy	11600.00
0005433036342	2120	Economy	11600.00
0005433923870	2120	Economy	11600.00
0005432044541	2120	Economy	11600.00
0005433036295	2120	Economy	11600.00
0005432231632	2120	Economy	11600.00
0005433036201	2120	Economy	11600.00
0005433923923	2120	Economy	11600.00
0005433923875	2120	Economy	11600.00
0005433923895	2120	Economy	11600.00
0005433036068	2120	Economy	11600.00
0005433036242	2120	Economy	11600.00
0005433036240	2120	Economy	11600.00
0005433923867	2120	Economy	11600.00
0005433923858	2120	Economy	11600.00
0005433923915	2120	Economy	11600.00
0005433036216	2120	Economy	11600.00
0005433036012	2120	Economy	11600.00
0005433923891	2120	Economy	11600.00
0005433036176	2120	Economy	11600.00
0005432231625	2120	Economy	11600.00
0005433923865	2120	Economy	11600.00
0005433923885	2120	Economy	11600.00
0005433923913	2120	Economy	11600.00
0005433923914	2120	Economy	11600.00
0005433036291	2120	Economy	11600.00
0005433923886	2120	Economy	11600.00
0005433929641	2120	Economy	11600.00
0005433923899	2120	Economy	11600.00
0005433923866	2120	Economy	11600.00
0005433036223	2120	Economy	11600.00
0005433036049	2120	Economy	11600.00
0005433036355	2120	Economy	11600.00
0005433036259	2120	Economy	12700.00
0005433923854	2120	Economy	11600.00
0005433923932	2120	Economy	12700.00
0005433923910	2120	Economy	11600.00
0005433923846	2120	Economy	11600.00
0005433923851	2120	Economy	12700.00
0005433036178	2120	Economy	12700.00
0005433923928	2120	Economy	11600.00
0005433036124	2120	Economy	11600.00
0005433923903	2120	Economy	11600.00
0005432044540	2120	Economy	11600.00
0005432231627	2120	Economy	11600.00
0005433931482	2120	Economy	11600.00
0005433036217	2120	Economy	11600.00
0005433036132	2120	Economy	11600.00
0005433923860	2120	Economy	11600.00
0005433923882	2120	Economy	11600.00
0005433923897	2120	Economy	11600.00
0005433923935	2120	Economy	11600.00
0005433923884	2120	Economy	11600.00
0005433923859	2120	Economy	11600.00
0005433036050	2120	Economy	11600.00
0005433036239	2120	Economy	11600.00
0005433923874	2120	Economy	11600.00
0005433923925	2120	Economy	11600.00
0005433929640	2120	Economy	11600.00
0005433923906	2120	Economy	11600.00
0005433929637	2120	Economy	11600.00
0005433036200	2120	Economy	11600.00
0005433923871	2120	Economy	11600.00
0005433923883	2120	Economy	11600.00
0005433036210	2120	Economy	11600.00
0005433923904	2120	Economy	11600.00
0005433036168	2120	Economy	11600.00
0005433036289	2120	Economy	11600.00
0005433923879	2120	Economy	11600.00
0005433036051	2120	Economy	11600.00
0005432231633	2120	Economy	11600.00
0005433035791	2120	Economy	11600.00
0005433923930	2120	Economy	11600.00
0005433923853	2120	Economy	11600.00
0005433923873	2120	Economy	11600.00
0005433931483	2120	Economy	11600.00
0005432044542	2120	Economy	11600.00
0005433923850	2120	Economy	11600.00
0005433929638	2120	Economy	11600.00
0005433035937	2120	Economy	11600.00
0005433923876	2120	Economy	11600.00
0005433923900	2120	Economy	11600.00
0005433036085	2120	Economy	11600.00
0005433923918	2120	Economy	11600.00
0005433923916	2120	Economy	11600.00
0005433923894	2120	Economy	11600.00
0005433923933	2120	Economy	11600.00
0005433036379	2120	Economy	11600.00
0005433036184	2120	Economy	11600.00
0005433923878	2120	Economy	11600.00
0005433036294	2120	Economy	11600.00
0005433923872	2120	Economy	11600.00
0005432231635	2120	Economy	11600.00
0005432231630	2120	Economy	11600.00
0005433923847	2120	Economy	11600.00
0005433923931	2120	Economy	11600.00
0005433923936	2120	Economy	11600.00
0005433923881	2120	Economy	11600.00
0005433036215	2120	Economy	11600.00
0005433931484	2120	Economy	11600.00
0005433036378	2120	Economy	11600.00
0005433923942	2120	Economy	11600.00
0005433035936	2120	Economy	11600.00
0005433923939	2120	Economy	11600.00
0005433036022	2120	Economy	11600.00
0005433036129	2120	Economy	11600.00
0005432231628	2120	Economy	11600.00
0005433923869	2120	Economy	11600.00
0005432231634	2120	Economy	11600.00
0005433923877	2120	Economy	11600.00
0005433923467	24123	Business	34700.00
0005432207677	24123	Business	34700.00
0005433923468	24123	Business	34700.00
0005433036646	24123	Business	34700.00
0005433036602	24123	Business	34700.00
0005433923277	24123	Business	34700.00
0005433923190	24123	Business	34700.00
0005433923472	24123	Business	34700.00
0005433923113	24123	Business	34700.00
0005433875375	24123	Business	34700.00
0005433036616	24123	Business	34700.00
0005433922971	24123	Business	34700.00
0005433923126	24123	Business	34700.00
0005433036624	24123	Business	34700.00
0005433922976	24123	Business	34700.00
0005433923127	24123	Business	34700.00
0005433036649	24123	Business	34700.00
0005433036635	24123	Business	34700.00
0005433922879	24123	Business	34700.00
0005433922894	24123	Business	34700.00
0005433922979	24123	Business	34700.00
0005432749799	24123	Business	34700.00
0005433036608	24123	Business	34700.00
0005433923471	24123	Business	34700.00
0005433036603	24123	Business	34700.00
0005433931458	24123	Business	34700.00
0005433923147	24123	Business	34700.00
0005433931459	24123	Economy	12700.00
0005433923218	24123	Economy	12700.00
0005433036650	24123	Economy	11600.00
0005433922959	24123	Economy	11600.00
0005432206229	24123	Economy	11600.00
0005433922641	24123	Economy	11600.00
0005433922941	24123	Economy	11600.00
0005433923087	24123	Economy	11600.00
0005434028315	24123	Economy	11600.00
0005433923369	24123	Economy	11600.00
0005433036621	24123	Economy	11600.00
0005433922878	24123	Economy	11600.00
0005433036652	24123	Economy	11600.00
0005433923358	24123	Economy	11600.00
0005433923012	24123	Economy	11600.00
0005433923265	24123	Economy	11600.00
0005433036642	24123	Economy	11600.00
0005433923112	24123	Economy	11600.00
0005433923285	24123	Economy	11600.00
0005433036610	24123	Economy	11600.00
0005432206231	24123	Economy	11600.00
0005433923189	24123	Economy	11600.00
0005433922925	24123	Economy	11600.00
0005433922586	24123	Economy	11600.00
0005433922587	24123	Economy	11600.00
0005433036631	24123	Economy	11600.00
0005432206232	24123	Economy	11600.00
0005433923125	24123	Economy	11600.00
0005433036640	24123	Economy	11600.00
0005433036644	24123	Economy	11600.00
0005433923175	24123	Economy	11600.00
0005433923181	24123	Economy	11600.00
0005433923146	24123	Economy	11600.00
0005433036622	24123	Economy	11600.00
0005433923260	24123	Economy	11600.00
0005434028314	24123	Economy	11600.00
0005433036634	24123	Economy	11600.00
0005433036648	24123	Economy	11600.00
0005433922964	24123	Economy	11600.00
0005433922846	24123	Economy	11600.00
0005433923188	24123	Economy	11600.00
0005433923217	24123	Economy	11600.00
0005433923234	24123	Economy	11600.00
0005433923182	24123	Economy	11600.00
0005433036627	24123	Economy	11600.00
0005433036619	24123	Economy	11600.00
0005433923523	24123	Economy	11600.00
0005433036615	24123	Economy	11600.00
0005433036643	24123	Economy	11600.00
0005433036617	24123	Economy	11600.00
0005433923362	24123	Economy	11600.00
0005433922944	24123	Economy	11600.00
0005433036641	24123	Economy	11600.00
0005433923366	24123	Economy	11600.00
0005433036636	24123	Economy	11600.00
0005433923252	24123	Economy	11600.00
0005433923524	24123	Economy	11600.00
0005433923165	24123	Economy	11600.00
0005433922956	24123	Economy	11600.00
0005433036598	24123	Economy	11600.00
0005433923264	24123	Economy	11600.00
0005433929858	24123	Economy	11600.00
0005433036630	24123	Economy	11600.00
0005433923076	24123	Economy	11600.00
0005433923077	24123	Economy	11600.00
0005433036639	24123	Economy	11600.00
0005433922960	24123	Economy	11600.00
0005433036605	24123	Economy	11600.00
0005433923302	24123	Economy	11600.00
0005433036620	24123	Economy	11600.00
0005433036599	24123	Economy	11600.00
0005433036647	24123	Economy	11600.00
0005432207678	24123	Economy	11600.00
0005433036612	24123	Economy	11600.00
0005433922942	24123	Economy	11600.00
0005433923097	24123	Economy	11600.00
0005433923078	24123	Economy	11600.00
0005433922937	24123	Economy	12700.00
0005433922863	24123	Economy	12700.00
0005433923459	24123	Economy	11600.00
0005433036600	24123	Economy	11600.00
0005433923133	24123	Economy	12700.00
0005433036611	24123	Economy	11600.00
0005433923029	24123	Economy	11600.00
0005433922875	24123	Economy	11600.00
0005433922889	24123	Economy	11600.00
0005433036623	24123	Economy	11600.00
0005433923516	24123	Economy	11600.00
0005433036604	24123	Economy	11600.00
0005433036618	24123	Economy	11600.00
0005433036632	24123	Economy	11600.00
0005433922625	24123	Economy	11600.00
0005433923235	24123	Economy	11600.00
0005433923037	24123	Economy	11600.00
0005433923445	24123	Economy	11600.00
0005433923026	24123	Economy	11600.00
0005432206230	24123	Economy	11600.00
0005433036613	24123	Economy	11600.00
0005433922818	24123	Economy	11600.00
0005433923096	24123	Economy	11600.00
0005433036637	24123	Economy	11600.00
0005433923296	24123	Economy	11600.00
0005433036628	24123	Economy	11600.00
0005433036638	24123	Economy	11600.00
0005433923068	24123	Economy	11600.00
0005433875376	24123	Economy	11600.00
0005433922561	24123	Economy	11600.00
0005433923517	24123	Economy	11600.00
0005433923073	24123	Economy	11600.00
0005433036607	24123	Economy	11600.00
0005433923449	24123	Economy	11600.00
0005433922966	24123	Economy	11600.00
0005433036633	24123	Economy	11600.00
0005433923161	24123	Economy	11600.00
0005432206234	24123	Economy	11600.00
0005433922895	24123	Economy	11600.00
0005433922967	24123	Economy	11600.00
0005433922705	24123	Economy	11600.00
0005433036614	24123	Economy	11600.00
0005433036625	24123	Economy	11600.00
0005432206233	24123	Economy	11600.00
0005433036626	24123	Economy	11600.00
0005433922961	24123	Economy	11600.00
0005433923280	24123	Economy	11600.00
0005433922977	24123	Economy	11600.00
0005433036606	24123	Economy	11600.00
0005433922936	24123	Economy	11600.00
0005433036629	24123	Economy	11600.00
0005433923075	24123	Economy	11600.00
0005433923250	24123	Economy	11600.00
0005433923275	24123	Economy	11600.00
0005433036601	24123	Economy	11600.00
0005433875374	24123	Economy	11600.00
0005433923261	24123	Economy	11600.00
0005433036651	24123	Economy	11600.00
0005433923081	24123	Economy	11600.00
0005433036645	24123	Economy	11600.00
0005433036609	24123	Economy	11600.00
0005433922820	24123	Economy	11600.00
0005433923458	24123	Economy	11600.00
0005433289829	276	Business	83700.00
0005432277886	276	Business	83700.00
0005433233995	276	Business	83700.00
0005433234095	276	Business	83700.00
0005433234045	276	Business	83700.00
0005434726259	276	Business	83700.00
0005433233911	276	Business	83700.00
0005433181002	276	Business	83700.00
0005434551555	276	Business	83700.00
0005434726227	276	Business	83700.00
0005433234051	276	Business	83700.00
0005433234359	276	Business	83700.00
0005433234164	276	Business	83700.00
0005433234035	276	Business	83700.00
0005434726265	276	Business	83700.00
0005433233930	276	Business	83700.00
0005433126831	276	Business	83700.00
0005433233719	276	Business	83700.00
0005434726179	276	Business	83700.00
0005434551592	276	Business	83700.00
0005434551593	276	Business	83700.00
0005433233986	276	Business	83700.00
0005434731194	276	Business	83700.00
0005434726219	276	Business	83700.00
0005434032007	276	Business	83700.00
0005432277885	276	Business	83700.00
0005434726256	276	Business	83700.00
0005434551550	276	Business	83700.00
0005434726260	276	Comfort	47400.00
0005433234000	276	Business	83700.00
0005433233999	276	Comfort	47400.00
0005433234129	276	Comfort	47400.00
0005434551581	276	Comfort	47400.00
0005434726178	276	Comfort	47400.00
0005433234385	276	Comfort	47400.00
0005434551602	276	Comfort	47400.00
0005434726170	276	Comfort	47400.00
0005433181035	276	Comfort	47400.00
0005433234034	276	Comfort	47400.00
0005433181031	276	Comfort	47400.00
0005434302484	276	Comfort	47400.00
0005434726245	276	Comfort	47400.00
0005434726172	276	Comfort	47400.00
0005434726275	276	Comfort	47400.00
0005434726189	276	Comfort	47400.00
0005434726218	276	Comfort	47400.00
0005433289807	276	Comfort	47400.00
0005434726210	276	Comfort	47400.00
0005434726217	276	Comfort	47400.00
0005435142667	276	Comfort	47400.00
0005433126847	276	Comfort	47400.00
0005433234074	276	Comfort	47400.00
0005432277892	276	Comfort	47400.00
0005434551562	276	Comfort	47400.00
0005434726205	276	Comfort	47400.00
0005434726184	276	Comfort	47400.00
0005434726237	276	Comfort	47400.00
0005434726276	276	Comfort	47400.00
0005434302486	276	Comfort	47400.00
0005433181124	276	Comfort	47400.00
0005434726258	276	Comfort	47400.00
0005434726221	276	Comfort	47400.00
0005434551580	276	Comfort	47400.00
0005434551598	276	Comfort	47400.00
0005433234013	276	Comfort	47400.00
0005434551563	276	Comfort	47400.00
0005434032010	276	Comfort	47400.00
0005434726255	276	Comfort	47400.00
0005433234006	276	Comfort	47400.00
0005434726162	276	Comfort	47400.00
0005433234109	276	Economy	27900.00
0005433181026	276	Comfort	47400.00
0005434551594	276	Economy	27900.00
0005434551560	276	Economy	27900.00
0005434735716	276	Economy	27900.00
0005433181061	276	Economy	27900.00
0005433234363	276	Economy	27900.00
0005432277897	276	Economy	27900.00
0005434551582	276	Economy	27900.00
0005434551600	276	Economy	27900.00
0005435142659	276	Economy	27900.00
0005433131685	276	Economy	27900.00
0005433181034	276	Economy	27900.00
0005434731191	276	Economy	27900.00
0005434726263	276	Economy	27900.00
0005434726261	276	Economy	27900.00
0005433234025	276	Economy	27900.00
0005433234072	276	Economy	27900.00
0005434551577	276	Economy	27900.00
0005433233755	276	Economy	27900.00
0005434726246	276	Economy	27900.00
0005434726212	276	Economy	27900.00
0005434726161	276	Economy	27900.00
0005434551569	276	Economy	27900.00
0005433234165	276	Economy	27900.00
0005433234046	276	Economy	27900.00
0005435142663	276	Economy	27900.00
0005434726229	276	Economy	27900.00
0005433233887	276	Economy	27900.00
0005434726166	276	Economy	27900.00
0005434551558	276	Economy	27900.00
0005434726249	276	Economy	27900.00
0005434726171	276	Economy	27900.00
0005433233783	276	Economy	27900.00
0005433289805	276	Economy	27900.00
0005433126836	276	Economy	27900.00
0005433126828	276	Economy	27900.00
0005433234364	276	Economy	27900.00
0005433234149	276	Economy	27900.00
0005434726198	276	Economy	27900.00
0005433234258	276	Economy	27900.00
0005433181057	276	Economy	27900.00
0005434726163	276	Economy	27900.00
0005433233994	276	Economy	27900.00
0005434726234	276	Economy	27900.00
0005434726206	276	Economy	27900.00
0005433289826	276	Economy	27900.00
0005434726266	276	Economy	27900.00
0005434551567	276	Economy	27900.00
0005434726282	276	Economy	27900.00
0005433234110	276	Economy	27900.00
0005434726196	276	Economy	27900.00
0005433131687	276	Economy	27900.00
0005433181030	276	Economy	27900.00
0005433233973	276	Economy	27900.00
0005434726213	276	Economy	27900.00
0005435142662	276	Economy	27900.00
0005434551578	276	Economy	27900.00
0005434726277	276	Economy	27900.00
0005434726200	276	Economy	27900.00
0005434726180	276	Economy	27900.00
0005435142657	276	Economy	27900.00
0005434726225	276	Economy	30700.00
0005434726223	276	Economy	30700.00
0005434551571	276	Economy	27900.00
0005434726204	276	Economy	30700.00
0005434726201	276	Economy	27900.00
0005434726267	276	Economy	27900.00
0005434726250	276	Economy	27900.00
0005434726199	276	Economy	30700.00
0005434551586	276	Economy	30700.00
0005432277893	276	Economy	27900.00
0005434731192	276	Economy	27900.00
0005434551579	276	Economy	27900.00
0005433766633	276	Economy	27900.00
0005433180994	276	Economy	27900.00
0005434726190	276	Economy	27900.00
0005434726175	276	Economy	27900.00
0005434726220	276	Economy	27900.00
0005435142665	276	Economy	27900.00
0005435142654	276	Economy	27900.00
0005433233756	276	Economy	27900.00
0005434726203	276	Economy	27900.00
0005433180945	276	Economy	27900.00
0005434726244	276	Economy	27900.00
0005432277890	276	Economy	27900.00
0005434726243	276	Economy	27900.00
0005433234362	276	Economy	27900.00
0005433181060	276	Economy	27900.00
0005433234162	276	Economy	27900.00
0005434726183	276	Economy	27900.00
0005434726242	276	Economy	27900.00
0005434726202	276	Economy	27900.00
0005435142660	276	Economy	27900.00
0005434551603	276	Economy	27900.00
0005433289824	276	Economy	27900.00
0005433234097	276	Economy	27900.00
0005434551604	276	Economy	27900.00
0005433233983	276	Economy	27900.00
0005434551554	276	Economy	27900.00
0005433234111	276	Economy	27900.00
0005434726207	276	Economy	27900.00
0005433233996	276	Economy	27900.00
0005434726247	276	Economy	27900.00
0005433289828	276	Economy	27900.00
0005433234026	276	Economy	27900.00
0005433131700	276	Economy	27900.00
0005434726269	276	Economy	27900.00
0005433181074	276	Economy	27900.00
0005433233891	276	Economy	27900.00
0005434551576	276	Economy	27900.00
0005434551552	276	Economy	27900.00
0005434551561	276	Economy	27900.00
0005434726191	276	Economy	27900.00
0005434726284	276	Economy	27900.00
0005433289825	276	Economy	27900.00
0005433234259	276	Economy	27900.00
0005433233972	276	Economy	27900.00
0005434726273	276	Economy	27900.00
0005434032012	276	Economy	27900.00
0005434726278	276	Economy	27900.00
0005433126835	276	Economy	27900.00
0005434551584	276	Economy	27900.00
0005434726231	276	Economy	27900.00
0005434551559	276	Economy	27900.00
0005434735719	276	Economy	27900.00
0005433181006	276	Economy	27900.00
0005435142666	276	Economy	27900.00
0005434726224	276	Economy	27900.00
0005432277891	276	Economy	27900.00
0005434726214	276	Economy	27900.00
0005434726174	276	Economy	27900.00
0005433233888	276	Economy	27900.00
0005434726187	276	Economy	27900.00
0005433234052	276	Economy	27900.00
0005433234059	276	Economy	27900.00
0005433289823	276	Economy	27900.00
0005434726192	276	Economy	27900.00
0005434726194	276	Economy	27900.00
0005433234044	276	Economy	27900.00
0005435142658	276	Economy	27900.00
0005433234365	276	Economy	27900.00
0005434726215	276	Economy	27900.00
0005433131688	276	Economy	27900.00
0005433233860	276	Economy	27900.00
0005433111502	276	Economy	27900.00
0005434726195	276	Economy	27900.00
0005434551551	276	Economy	27900.00
0005433234360	276	Economy	27900.00
0005434551589	276	Economy	27900.00
0005434726286	276	Economy	27900.00
0005434726239	276	Economy	27900.00
0005433131684	276	Economy	27900.00
0005433234130	276	Economy	27900.00
0005434726252	276	Economy	27900.00
0005433181033	276	Economy	27900.00
0005434731193	276	Economy	27900.00
0005433180946	276	Economy	27900.00
0005434551599	276	Economy	27900.00
0005434726254	276	Economy	27900.00
0005434726233	276	Economy	27900.00
0005432277887	276	Economy	27900.00
0005434726240	276	Economy	27900.00
0005434551585	276	Economy	27900.00
0005434551595	276	Economy	27900.00
0005434726248	276	Economy	27900.00
0005434726197	276	Economy	27900.00
0005434726176	276	Economy	27900.00
0005433234050	276	Economy	27900.00
0005434726193	276	Economy	27900.00
0005434302487	276	Economy	27900.00
0005434551590	276	Economy	27900.00
0005434726285	276	Economy	27900.00
0005434551601	276	Economy	27900.00
0005434726208	276	Economy	27900.00
0005434551553	276	Economy	30700.00
0005433289804	276	Economy	27900.00
0005434726209	276	Economy	30700.00
0005435142661	276	Economy	30700.00
0005433234335	276	Economy	30700.00
0005433233750	276	Economy	30700.00
0005434726270	276	Economy	27900.00
0005432277895	276	Economy	27900.00
0005434726222	276	Economy	27900.00
0005433234064	276	Economy	27900.00
0005434551588	276	Economy	27900.00
0005433131698	276	Economy	27900.00
0005433181027	276	Economy	27900.00
0005434551587	276	Economy	27900.00
0005434726235	276	Economy	27900.00
0005433233929	276	Economy	27900.00
0005434032013	276	Economy	27900.00
0005434726268	276	Economy	27900.00
0005434726279	276	Economy	27900.00
0005434726232	276	Economy	27900.00
0005434551575	276	Economy	27900.00
0005433181025	276	Economy	27900.00
0005433131686	276	Economy	27900.00
0005434551570	276	Economy	27900.00
0005433181073	276	Economy	27900.00
0005432277896	276	Economy	27900.00
0005433233985	276	Economy	27900.00
0005435142656	276	Economy	27900.00
0005434551574	276	Economy	27900.00
0005434551596	276	Economy	27900.00
0005433234043	276	Economy	27900.00
0005434726262	276	Economy	27900.00
0005434726216	276	Economy	27900.00
0005433766634	276	Economy	27900.00
0005433126827	276	Economy	27900.00
0005433180965	276	Economy	27900.00
0005433233799	276	Economy	27900.00
0005432277898	276	Economy	27900.00
0005434726167	276	Economy	27900.00
0005433181029	276	Economy	27900.00
0005433181021	276	Economy	27900.00
0005434735717	276	Economy	27900.00
0005434726185	276	Economy	27900.00
0005433233859	276	Economy	27900.00
0005434726281	276	Economy	27900.00
0005434726251	276	Economy	27900.00
0005434551565	276	Economy	27900.00
0005434726257	276	Economy	27900.00
0005434726165	276	Economy	27900.00
0005434726280	276	Economy	27900.00
0005434726182	276	Economy	27900.00
0005434726271	276	Economy	27900.00
0005434551583	276	Economy	27900.00
0005434735718	276	Economy	27900.00
0005434726186	276	Economy	27900.00
0005433234057	276	Economy	27900.00
0005433181058	276	Economy	27900.00
0005433234163	276	Economy	27900.00
0005434551591	276	Economy	27900.00
0005434551557	276	Economy	27900.00
0005434726238	276	Economy	27900.00
0005432277889	276	Economy	27900.00
0005435142655	276	Economy	27900.00
0005434551568	276	Economy	27900.00
0005433131699	276	Economy	27900.00
0005433289806	276	Economy	27900.00
0005434726168	276	Economy	27900.00
0005433181028	276	Economy	27900.00
0005433234172	276	Economy	27900.00
0005434726181	276	Economy	27900.00
0005433181014	276	Economy	27900.00
0005433234071	276	Economy	27900.00
0005433233976	276	Economy	27900.00
0005434726272	276	Economy	27900.00
0005434032011	276	Economy	27900.00
0005434726226	276	Economy	27900.00
0005433234257	276	Economy	27900.00
0005434726264	276	Economy	27900.00
0005434551566	276	Economy	27900.00
0005434735715	276	Economy	27900.00
0005433234336	276	Economy	27900.00
0005434726236	276	Economy	27900.00
0005433234171	276	Economy	27900.00
0005432277888	276	Economy	27900.00
0005434726211	276	Economy	27900.00
0005433233875	276	Economy	27900.00
0005434551573	276	Economy	27900.00
0005434726164	276	Economy	27900.00
0005433180960	276	Economy	27900.00
0005432277894	276	Economy	27900.00
0005434551597	276	Economy	27900.00
0005434726283	276	Economy	27900.00
0005434726188	276	Economy	27900.00
0005433234161	276	Economy	27900.00
0005434726230	276	Economy	27900.00
0005433181003	276	Economy	27900.00
0005434551556	276	Economy	27900.00
0005434551564	276	Economy	27900.00
0005434726241	276	Economy	27900.00
0005434726253	276	Economy	27900.00
0005434302485	276	Economy	27900.00
0005434726228	276	Economy	27900.00
0005434726169	276	Economy	27900.00
0005433113539	276	Economy	27900.00
0005435142664	276	Economy	27900.00
0005434551572	276	Economy	27900.00
0005434726274	276	Economy	27900.00
0005434726173	276	Economy	27900.00
0005434726177	276	Economy	27900.00
0005433126846	276	Economy	27900.00
0005434725956	9878	Business	83700.00
0005434725252	9878	Business	83700.00
0005433234569	9878	Business	83700.00
0005434724360	9878	Business	83700.00
0005433113618	9878	Business	83700.00
0005434725418	9878	Business	83700.00
0005434724843	9878	Business	83700.00
0005432199293	9878	Business	83700.00
0005434725303	9878	Business	83700.00
0005433234615	9878	Business	83700.00
0005434551026	9878	Business	83700.00
0005433113548	9878	Business	83700.00
0005434550856	9878	Business	83700.00
0005433181255	9878	Business	83700.00
0005433234567	9878	Business	83700.00
0005434725446	9878	Business	83700.00
0005432199290	9878	Business	83700.00
0005433234613	9878	Business	83700.00
0005433181253	9878	Business	83700.00
0005433234563	9878	Business	83700.00
0005434551308	9878	Business	83700.00
0005434551116	9878	Business	83700.00
0005433234610	9878	Business	83700.00
0005434725417	9878	Business	83700.00
0005434551181	9878	Business	83700.00
0005434551182	9878	Comfort	47400.00
0005434550821	9878	Comfort	47400.00
0005433181249	9878	Comfort	47400.00
0005434550982	9878	Comfort	47400.00
0005434032052	9878	Comfort	47400.00
0005434725647	9878	Comfort	47400.00
0005433234578	9878	Comfort	47400.00
0005434551262	9878	Comfort	47400.00
0005434550925	9878	Comfort	47400.00
0005434725362	9878	Comfort	47400.00
0005434550945	9878	Comfort	47400.00
0005434302444	9878	Comfort	47400.00
0005433234598	9878	Comfort	47400.00
0005434725260	9878	Comfort	47400.00
0005434550827	9878	Comfort	47400.00
0005434550988	9878	Comfort	47400.00
0005433234607	9878	Comfort	47400.00
0005434550981	9878	Comfort	47400.00
0005434724867	9878	Comfort	47400.00
0005434724938	9878	Comfort	47400.00
0005434550973	9878	Comfort	47400.00
0005433289888	9878	Comfort	47400.00
0005433234605	9878	Comfort	47400.00
0005434725527	9878	Comfort	47400.00
0005433113550	9878	Comfort	47400.00
0005433234599	9878	Comfort	47400.00
0005434551220	9878	Comfort	47400.00
0005434725074	9878	Comfort	47400.00
0005434725536	9878	Comfort	47400.00
0005433766662	9878	Comfort	47400.00
0005433289891	9878	Comfort	47400.00
0005434725052	9878	Comfort	47400.00
0005433181243	9878	Comfort	47400.00
0005434725470	9878	Comfort	47400.00
0005434735696	9878	Comfort	47400.00
0005433234576	9878	Comfort	47400.00
0005433234591	9878	Comfort	47400.00
0005433234621	9878	Comfort	47400.00
0005433181244	9878	Comfort	47400.00
0005433234606	9878	Comfort	47400.00
0005433234617	9878	Comfort	47400.00
0005433181251	9878	Economy	27900.00
0005434735681	9878	Comfort	47400.00
0005433181246	9878	Economy	27900.00
0005434551196	9878	Economy	27900.00
0005434725684	9878	Economy	27900.00
0005433234596	9878	Economy	27900.00
0005434725305	9878	Economy	27900.00
0005434551022	9878	Economy	27900.00
0005434725153	9878	Economy	27900.00
0005432199287	9878	Economy	27900.00
0005434550938	9878	Economy	27900.00
0005434550900	9878	Economy	27900.00
0005434725010	9878	Economy	27900.00
0005434551137	9878	Economy	27900.00
0005433234566	9878	Economy	27900.00
0005433234594	9878	Economy	27900.00
0005433289893	9878	Economy	27900.00
0005434302448	9878	Economy	27900.00
0005434725611	9878	Economy	27900.00
0005433234565	9878	Economy	27900.00
0005434724904	9878	Economy	27900.00
0005434724899	9878	Economy	27900.00
0005434551010	9878	Economy	27900.00
0005433234618	9878	Economy	27900.00
0005433126873	9878	Economy	27900.00
0005434551117	9878	Economy	27900.00
0005434725639	9878	Economy	27900.00
0005434725509	9878	Economy	27900.00
0005434725379	9878	Economy	27900.00
0005434725311	9878	Economy	27900.00
0005435142518	9878	Economy	27900.00
0005434725063	9878	Economy	27900.00
0005434725558	9878	Economy	27900.00
0005434302442	9878	Economy	27900.00
0005434302456	9878	Economy	27900.00
0005433234590	9878	Economy	27900.00
0005432199291	9878	Economy	27900.00
0005434724705	9878	Economy	27900.00
0005435142532	9878	Economy	27900.00
0005434735695	9878	Economy	27900.00
0005433234625	9878	Economy	27900.00
0005434551206	9878	Economy	27900.00
0005434724829	9878	Economy	27900.00
0005433289892	9878	Economy	27900.00
0005434550999	9878	Economy	27900.00
0005433181264	9878	Economy	27900.00
0005434725129	9878	Economy	27900.00
0005434725366	9878	Economy	27900.00
0005433234604	9878	Economy	27900.00
0005434725448	9878	Economy	27900.00
0005434725180	9878	Economy	27900.00
0005434725281	9878	Economy	27900.00
0005434724943	9878	Economy	27900.00
0005433234611	9878	Economy	27900.00
0005434725055	9878	Economy	27900.00
0005434302457	9878	Economy	27900.00
0005435142503	9878	Economy	30700.00
0005434551205	9878	Economy	27900.00
0005434551136	9878	Economy	30700.00
0005434551135	9878	Economy	27900.00
0005434551195	9878	Economy	30700.00
0005433234561	9878	Economy	27900.00
0005433181263	9878	Economy	27900.00
0005433129301	9878	Economy	30700.00
0005433234579	9878	Economy	27900.00
0005434725577	9878	Economy	30700.00
0005434731156	9878	Economy	27900.00
0005434550983	9878	Economy	30700.00
0005434724359	9878	Economy	27900.00
0005433234572	9878	Economy	27900.00
0005434725648	9878	Economy	27900.00
0005433181247	9878	Economy	27900.00
0005434551106	9878	Economy	27900.00
0005433234585	9878	Economy	27900.00
0005433234595	9878	Economy	27900.00
0005433766663	9878	Economy	27900.00
0005434551138	9878	Economy	27900.00
0005434550937	9878	Economy	27900.00
0005434550899	9878	Economy	27900.00
0005434725626	9878	Economy	27900.00
0005433234609	9878	Economy	27900.00
0005434735682	9878	Economy	27900.00
0005433129305	9878	Economy	27900.00
0005434725387	9878	Economy	27900.00
0005434724717	9878	Economy	27900.00
0005433181261	9878	Economy	27900.00
0005434725261	9878	Economy	27900.00
0005434725610	9878	Economy	27900.00
0005434725515	9878	Economy	27900.00
0005434551096	9878	Economy	27900.00
0005435142504	9878	Economy	27900.00
0005434731159	9878	Economy	27900.00
0005433129306	9878	Economy	27900.00
0005433234583	9878	Economy	27900.00
0005433181265	9878	Economy	27900.00
0005433126871	9878	Economy	27900.00
0005433234619	9878	Economy	27900.00
0005434725363	9878	Economy	27900.00
0005434725612	9878	Economy	27900.00
0005433234581	9878	Economy	27900.00
0005432199292	9878	Economy	27900.00
0005433234562	9878	Economy	27900.00
0005434724929	9878	Economy	27900.00
0005434550901	9878	Economy	27900.00
0005433234564	9878	Economy	27900.00
0005433181259	9878	Economy	27900.00
0005433234577	9878	Economy	27900.00
0005433181267	9878	Economy	27900.00
0005434724851	9878	Economy	27900.00
0005434731137	9878	Economy	27900.00
0005434724813	9878	Economy	27900.00
0005433181260	9878	Economy	27900.00
0005434724814	9878	Economy	27900.00
0005434725073	9878	Economy	27900.00
0005434724708	9878	Economy	27900.00
0005434725395	9878	Economy	27900.00
0005433181257	9878	Economy	27900.00
0005434725140	9878	Economy	27900.00
0005434725537	9878	Economy	27900.00
0005434725636	9878	Economy	27900.00
0005434724973	9878	Economy	27900.00
0005434724828	9878	Economy	27900.00
0005435142610	9878	Economy	27900.00
0005434724944	9878	Economy	27900.00
0005434725514	9878	Economy	27900.00
0005433234570	9878	Economy	27900.00
0005434725627	9878	Economy	27900.00
0005434731158	9878	Economy	27900.00
0005433766665	9878	Economy	27900.00
0005433181245	9878	Economy	27900.00
0005434724703	9878	Economy	27900.00
0005434731152	9878	Economy	27900.00
0005433234584	9878	Economy	27900.00
0005433113549	9878	Economy	27900.00
0005434550963	9878	Economy	27900.00
0005433234620	9878	Economy	27900.00
0005434724883	9878	Economy	27900.00
0005434725458	9878	Economy	27900.00
0005434725456	9878	Economy	27900.00
0005434724941	9878	Economy	27900.00
0005434725166	9878	Economy	27900.00
0005433234601	9878	Economy	27900.00
0005434551066	9878	Economy	27900.00
0005434725805	9878	Economy	27900.00
0005434725336	9878	Economy	27900.00
0005433126874	9878	Economy	27900.00
0005434725312	9878	Economy	27900.00
0005434725457	9878	Economy	27900.00
0005433129302	9878	Economy	27900.00
0005433129304	9878	Economy	27900.00
0005434550966	9878	Economy	27900.00
0005434550869	9878	Economy	27900.00
0005434551199	9878	Economy	27900.00
0005433234622	9878	Economy	27900.00
0005433234587	9878	Economy	27900.00
0005434731144	9878	Economy	27900.00
0005433289887	9878	Economy	27900.00
0005433234586	9878	Economy	27900.00
0005433234600	9878	Economy	27900.00
0005433234614	9878	Economy	27900.00
0005433181256	9878	Economy	27900.00
0005433234573	9878	Economy	27900.00
0005434725154	9878	Economy	27900.00
0005434725132	9878	Economy	27900.00
0005433234623	9878	Economy	27900.00
0005434725640	9878	Economy	27900.00
0005434725066	9878	Economy	27900.00
0005434725559	9878	Economy	27900.00
0005432199288	9878	Economy	27900.00
0005434724932	9878	Economy	27900.00
0005435142506	9878	Economy	27900.00
0005433234571	9878	Economy	27900.00
0005434550820	9878	Economy	27900.00
0005434551207	9878	Economy	27900.00
0005433126872	9878	Economy	30700.00
0005434725469	9878	Economy	30700.00
0005434725259	9878	Economy	30700.00
0005435142533	9878	Economy	30700.00
0005433181258	9878	Economy	30700.00
0005434551180	9878	Economy	27900.00
0005433181250	9878	Economy	27900.00
0005434724897	9878	Economy	27900.00
0005433181254	9878	Economy	27900.00
0005434302441	9878	Economy	27900.00
0005434725466	9878	Economy	27900.00
0005434725434	9878	Economy	27900.00
0005434725338	9878	Economy	27900.00
0005434725337	9878	Economy	27900.00
0005434724969	9878	Economy	27900.00
0005434725447	9878	Economy	27900.00
0005434725306	9878	Economy	27900.00
0005434731143	9878	Economy	27900.00
0005433181252	9878	Economy	27900.00
0005435142551	9878	Economy	27900.00
0005433181248	9878	Economy	27900.00
0005434725403	9878	Economy	27900.00
0005434724683	9878	Economy	27900.00
0005434724970	9878	Economy	27900.00
0005434551021	9878	Economy	27900.00
0005434735694	9878	Economy	27900.00
0005433129303	9878	Economy	27900.00
0005434725375	9878	Economy	27900.00
0005434725253	9878	Economy	27900.00
0005434724934	9878	Economy	27900.00
0005433234592	9878	Economy	27900.00
0005434725326	9878	Economy	27900.00
0005434551167	9878	Economy	27900.00
0005433234574	9878	Economy	27900.00
0005434551095	9878	Economy	27900.00
0005434725179	9878	Economy	27900.00
0005434551143	9878	Economy	27900.00
0005434550936	9878	Economy	27900.00
0005434725150	9878	Economy	27900.00
0005434725380	9878	Economy	27900.00
0005434725302	9878	Economy	27900.00
0005434725396	9878	Economy	27900.00
0005434724898	9878	Economy	27900.00
0005434725181	9878	Economy	27900.00
0005432199294	9878	Economy	27900.00
0005434032053	9878	Economy	27900.00
0005434725404	9878	Economy	27900.00
0005433234580	9878	Economy	27900.00
0005434725122	9878	Economy	27900.00
0005434725613	9878	Economy	27900.00
0005434724704	9878	Economy	27900.00
0005433289889	9878	Economy	27900.00
0005433766664	9878	Economy	27900.00
0005434725423	9878	Economy	27900.00
0005434724933	9878	Economy	27900.00
0005433234597	9878	Economy	27900.00
0005434550919	9878	Economy	27900.00
0005434725208	9878	Economy	27900.00
0005434725307	9878	Economy	27900.00
0005434725079	9878	Economy	27900.00
0005433234575	9878	Economy	27900.00
0005434725175	9878	Economy	27900.00
0005433234589	9878	Economy	27900.00
0005434551131	9878	Economy	27900.00
0005434551105	9878	Economy	27900.00
0005434550967	9878	Economy	27900.00
0005433234602	9878	Economy	27900.00
0005434550918	9878	Economy	27900.00
0005433234568	9878	Economy	27900.00
0005433181262	9878	Economy	27900.00
0005433181266	9878	Economy	27900.00
0005434032054	9878	Economy	27900.00
0005434725384	9878	Economy	27900.00
0005434724990	9878	Economy	27900.00
0005433234582	9878	Economy	27900.00
0005434725370	9878	Economy	27900.00
0005434725578	9878	Economy	27900.00
0005434725141	9878	Economy	27900.00
0005434725080	9878	Economy	27900.00
0005433234603	9878	Economy	27900.00
0005432199289	9878	Economy	27900.00
0005434725278	9878	Economy	27900.00
0005434725242	9878	Economy	27900.00
0005433234593	9878	Economy	27900.00
0005433234612	9878	Economy	27900.00
0005433234616	9878	Economy	27900.00
0005434725383	9878	Economy	27900.00
0005434032055	9878	Economy	27900.00
0005434724894	9878	Economy	27900.00
0005434725270	9878	Economy	27900.00
0005434725415	9878	Economy	27900.00
0005434550916	9878	Economy	27900.00
0005434724719	9878	Economy	27900.00
0005434725335	9878	Economy	27900.00
0005433234588	9878	Economy	27900.00
0005433234608	9878	Economy	27900.00
0005434725530	9878	Economy	27900.00
0005434725243	9878	Economy	27900.00
0005434724942	9878	Economy	27900.00
0005434725121	9878	Economy	27900.00
0005433234624	9878	Economy	27900.00
0005434724939	9878	Economy	27900.00
0005434725388	9878	Economy	27900.00
0005434551253	9878	Economy	27900.00
0005433289894	9878	Economy	27900.00
0005433289890	9878	Economy	27900.00
0005435213486	7749	Business	42100.00
0005432528757	7749	Business	42100.00
0005432528783	7749	Business	42100.00
0005432528852	7749	Business	42100.00
0005435630959	7749	Business	42100.00
0005432150246	7749	Business	42100.00
0005434067976	7749	Business	42100.00
0005435725584	7749	Business	42100.00
0005432150241	7749	Business	42100.00
0005434067970	7749	Business	42100.00
0005432528781	7749	Business	42100.00
0005434067997	7749	Business	42100.00
0005434068000	7749	Business	42100.00
0005435630956	7749	Business	42100.00
0005432528740	7749	Business	42100.00
0005432528730	7749	Business	42100.00
0005434068021	7749	Business	42100.00
0005432528844	7749	Business	42100.00
0005435213419	7749	Business	42100.00
0005432069741	7749	Business	42100.00
0005435213387	7749	Business	42100.00
0005432528747	7749	Business	42100.00
0005432528851	7749	Business	42100.00
0005434068037	7749	Comfort	23900.00
0005435725554	7749	Comfort	23900.00
0005432528846	7749	Comfort	23900.00
0005432528762	7749	Comfort	23900.00
0005435213352	7749	Comfort	23900.00
0005432528733	7749	Comfort	23900.00
0005432528736	7749	Comfort	23900.00
0005432528843	7749	Comfort	23900.00
0005435213348	7749	Comfort	23900.00
0005434068036	7749	Comfort	23900.00
0005432528832	7749	Comfort	23900.00
0005432528820	7749	Comfort	23900.00
0005432528774	7749	Comfort	23900.00
0005435630962	7749	Comfort	23900.00
0005432528776	7749	Comfort	23900.00
0005432528735	7749	Comfort	23900.00
0005435213632	7749	Comfort	23900.00
0005435213403	7749	Comfort	23900.00
0005434068016	7749	Comfort	23900.00
0005433656667	7749	Comfort	23900.00
0005432528744	7749	Comfort	23900.00
0005434067998	7749	Comfort	23900.00
0005435213582	7749	Comfort	23900.00
0005432528777	7749	Comfort	23900.00
0005432528773	7749	Comfort	23900.00
0005432528800	7749	Comfort	23900.00
0005435213510	7749	Comfort	23900.00
0005432528780	7749	Comfort	23900.00
0005434068033	7749	Comfort	23900.00
0005432535864	7749	Comfort	23900.00
0005434067972	7749	Comfort	23900.00
0005432528842	7749	Comfort	23900.00
0005432528761	7749	Comfort	23900.00
0005435213667	7749	Comfort	23900.00
0005432528763	7749	Comfort	23900.00
0005435213043	7749	Comfort	23900.00
0005435213606	7749	Comfort	23900.00
0005432528739	7749	Comfort	23900.00
0005434067966	7749	Comfort	23900.00
0005432428948	7749	Comfort	23900.00
0005432533310	7749	Comfort	23900.00
0005435213334	7749	Economy	14000.00
0005432528818	7749	Economy	14000.00
0005432528750	7749	Economy	14000.00
0005432528791	7749	Economy	14000.00
0005435213386	7749	Economy	14000.00
0005434068008	7749	Economy	14000.00
0005435213260	7749	Economy	14000.00
0005434067994	7749	Economy	14000.00
0005432069740	7749	Economy	14000.00
0005432528837	7749	Economy	14000.00
0005432528766	7749	Economy	14000.00
0005435213023	7749	Economy	14000.00
0005432528797	7749	Economy	14000.00
0005435213713	7749	Economy	14000.00
0005435213338	7749	Economy	14000.00
0005435213293	7749	Economy	14000.00
0005432528792	7749	Economy	14000.00
0005432428950	7749	Economy	14000.00
0005434068032	7749	Economy	14000.00
0005434067985	7749	Economy	14000.00
0005435213218	7749	Economy	14000.00
0005435213024	7749	Economy	14000.00
0005432528812	7749	Economy	14000.00
0005432528787	7749	Economy	14000.00
0005435213315	7749	Economy	14000.00
0005432528795	7749	Economy	14000.00
0005432528821	7749	Economy	14000.00
0005432528748	7749	Economy	14000.00
0005432069746	7749	Economy	14000.00
0005435725583	7749	Economy	14000.00
0005432528804	7749	Economy	14000.00
0005432528726	7749	Economy	14000.00
0005432150243	7749	Economy	14000.00
0005432528802	7749	Economy	14000.00
0005432528725	7749	Economy	14000.00
0005432528807	7749	Economy	14000.00
0005432528848	7749	Economy	14000.00
0005434067993	7749	Economy	14000.00
0005434068012	7749	Economy	14000.00
0005432069748	7749	Economy	14000.00
0005432535865	7749	Economy	14000.00
0005432069745	7749	Economy	14000.00
0005432528723	7749	Economy	14000.00
0005435213436	7749	Economy	14000.00
0005432069744	7749	Economy	14000.00
0005432528788	7749	Economy	14000.00
0005432528764	7749	Economy	14000.00
0005432528790	7749	Economy	14000.00
0005435213506	7749	Economy	14000.00
0005435213438	7749	Economy	14000.00
0005432528721	7749	Economy	14000.00
0005432528793	7749	Economy	14000.00
0005432528728	7749	Economy	14000.00
0005432069747	7749	Economy	15400.00
0005432528823	7749	Economy	14000.00
0005432528720	7749	Economy	15400.00
0005434067999	7749	Economy	15400.00
0005434067967	7749	Economy	14000.00
0005435213192	7749	Economy	14000.00
0005432528732	7749	Economy	14000.00
0005432528769	7749	Economy	15400.00
0005432528786	7749	Economy	14000.00
0005432533311	7749	Economy	14000.00
0005434067969	7749	Economy	14000.00
0005434068027	7749	Economy	14000.00
0005432528845	7749	Economy	14000.00
0005435212810	7749	Economy	14000.00
0005435213525	7749	Economy	14000.00
0005432528779	7749	Economy	14000.00
0005432528840	7749	Economy	14000.00
0005432069739	7749	Economy	14000.00
0005435213267	7749	Economy	14000.00
0005435725587	7749	Economy	14000.00
0005434068014	7749	Economy	14000.00
0005432150242	7749	Economy	14000.00
0005432528841	7749	Economy	14000.00
0005432069751	7749	Economy	14000.00
0005432528778	7749	Economy	14000.00
0005432528847	7749	Economy	14000.00
0005432528731	7749	Economy	14000.00
0005434068010	7749	Economy	14000.00
0005434067980	7749	Economy	14000.00
0005434067984	7749	Economy	14000.00
0005434068024	7749	Economy	14000.00
0005432528767	7749	Economy	14000.00
0005434068007	7749	Economy	14000.00
0005435213322	7749	Economy	14000.00
0005432528752	7749	Economy	14000.00
0005435213263	7749	Economy	14000.00
0005432528816	7749	Economy	14000.00
0005435213232	7749	Economy	14000.00
0005432528834	7749	Economy	14000.00
0005432533308	7749	Economy	14000.00
0005435213376	7749	Economy	14000.00
0005432528819	7749	Economy	14000.00
0005432528826	7749	Economy	14000.00
0005432528724	7749	Economy	14000.00
0005432428951	7749	Economy	14000.00
0005435213618	7749	Economy	14000.00
0005432528734	7749	Economy	14000.00
0005432528772	7749	Economy	14000.00
0005432528755	7749	Economy	14000.00
0005435725549	7749	Economy	14000.00
0005432150240	7749	Economy	14000.00
0005435213238	7749	Economy	14000.00
0005432528836	7749	Economy	14000.00
0005432528799	7749	Economy	14000.00
0005432528737	7749	Economy	14000.00
0005435213351	7749	Economy	14000.00
0005434068035	7749	Economy	14000.00
0005435213178	7749	Economy	14000.00
0005432528759	7749	Economy	14000.00
0005432528850	7749	Economy	14000.00
0005434067974	7749	Economy	14000.00
0005432528782	7749	Economy	14000.00
0005432528727	7749	Economy	14000.00
0005435213708	7749	Economy	14000.00
0005434067992	7749	Economy	14000.00
0005434067995	7749	Economy	14000.00
0005432150244	7749	Economy	14000.00
0005434068030	7749	Economy	14000.00
0005435213420	7749	Economy	14000.00
0005435213301	7749	Economy	14000.00
0005432528738	7749	Economy	14000.00
0005434067982	7749	Economy	14000.00
0005434067971	7749	Economy	14000.00
0005432528745	7749	Economy	14000.00
0005435213393	7749	Economy	14000.00
0005432528796	7749	Economy	14000.00
0005432528751	7749	Economy	14000.00
0005434068034	7749	Economy	14000.00
0005432528805	7749	Economy	14000.00
0005434067987	7749	Economy	14000.00
0005434068013	7749	Economy	14000.00
0005432528839	7749	Economy	14000.00
0005435213617	7749	Economy	14000.00
0005432528775	7749	Economy	14000.00
0005435213524	7749	Economy	14000.00
0005433656662	7749	Economy	14000.00
0005434067988	7749	Economy	14000.00
0005432528815	7749	Economy	14000.00
0005432533309	7749	Economy	14000.00
0005432528771	7749	Economy	14000.00
0005433656660	7749	Economy	14000.00
0005434067977	7749	Economy	14000.00
0005434067975	7749	Economy	14000.00
0005435213622	7749	Economy	14000.00
0005432528849	7749	Economy	14000.00
0005432528753	7749	Economy	14000.00
0005434068015	7749	Economy	14000.00
0005433656669	7749	Economy	14000.00
0005432528817	7749	Economy	14000.00
0005432528827	7749	Economy	14000.00
0005432528765	7749	Economy	14000.00
0005433656661	7749	Economy	14000.00
0005432528808	7749	Economy	14000.00
0005434068011	7749	Economy	14000.00
0005432528746	7749	Economy	14000.00
0005434068005	7749	Economy	14000.00
0005435213111	7749	Economy	15400.00
0005434067991	7749	Economy	14000.00
0005434068001	7749	Economy	15400.00
0005434068025	7749	Economy	15400.00
0005432069743	7749	Economy	15400.00
0005434068004	7749	Economy	15400.00
0005432528789	7749	Economy	15400.00
0005432528741	7749	Economy	14000.00
0005435725588	7749	Economy	14000.00
0005435725589	7749	Economy	14000.00
0005432528806	7749	Economy	14000.00
0005432528798	7749	Economy	14000.00
0005432528809	7749	Economy	14000.00
0005434068022	7749	Economy	14000.00
0005432528811	7749	Economy	14000.00
0005432528760	7749	Economy	14000.00
0005432528722	7749	Economy	14000.00
0005434068029	7749	Economy	14000.00
0005432528758	7749	Economy	14000.00
0005432428949	7749	Economy	14000.00
0005432535862	7749	Economy	14000.00
0005432528729	7749	Economy	14000.00
0005434067978	7749	Economy	14000.00
0005434068026	7749	Economy	14000.00
0005432528801	7749	Economy	14000.00
0005435213044	7749	Economy	14000.00
0005434067986	7749	Economy	14000.00
0005432528749	7749	Economy	14000.00
0005434067973	7749	Economy	14000.00
0005435213177	7749	Economy	14000.00
0005435213412	7749	Economy	14000.00
0005435213435	7749	Economy	14000.00
0005432528829	7749	Economy	14000.00
0005434068017	7749	Economy	14000.00
0005432069750	7749	Economy	14000.00
0005432528794	7749	Economy	14000.00
0005435213426	7749	Economy	14000.00
0005432528838	7749	Economy	14000.00
0005434067979	7749	Economy	14000.00
0005434068002	7749	Economy	14000.00
0005435213303	7749	Economy	14000.00
0005434067989	7749	Economy	14000.00
0005432069742	7749	Economy	14000.00
0005432528756	7749	Economy	14000.00
0005432528742	7749	Economy	14000.00
0005434068028	7749	Economy	14000.00
0005432069749	7749	Economy	14000.00
0005432528825	7749	Economy	14000.00
0005434068018	7749	Economy	14000.00
0005435213581	7749	Economy	14000.00
0005432528743	7749	Economy	14000.00
0005434068020	7749	Economy	14000.00
0005435213288	7749	Economy	14000.00
0005434068009	7749	Economy	14000.00
0005435213292	7749	Economy	14000.00
0005432528833	7749	Economy	14000.00
0005432528828	7749	Economy	14000.00
0005432528835	7749	Economy	14000.00
0005435213297	7749	Economy	14000.00
0005434068023	7749	Economy	14000.00
0005435213390	7749	Economy	14000.00
0005434068006	7749	Economy	14000.00
0005432528814	7749	Economy	14000.00
0005435213437	7749	Economy	14000.00
0005432528785	7749	Economy	14000.00
0005434067965	7749	Economy	14000.00
0005432537071	7749	Economy	14000.00
0005432528810	7749	Economy	14000.00
0005435213349	7749	Economy	14000.00
0005435213427	7749	Economy	14000.00
0005432528822	7749	Economy	14000.00
0005434067996	7749	Economy	14000.00
0005432528784	7749	Economy	14000.00
0005432528830	7749	Economy	14000.00
0005434068019	7749	Economy	14000.00
0005435213456	7749	Economy	14000.00
0005435213576	7749	Economy	14000.00
0005434068031	7749	Economy	14000.00
0005432528831	7749	Economy	14000.00
0005432528768	7749	Economy	14000.00
0005432528754	7749	Economy	14000.00
0005435213560	7749	Economy	14000.00
0005432528813	7749	Economy	14000.00
0005432528803	7749	Economy	14000.00
0005434067968	7749	Economy	14000.00
0005435630955	7749	Economy	14000.00
0005432535863	7749	Economy	14000.00
0005432150245	7749	Economy	14000.00
0005434067983	7749	Economy	14000.00
0005434068003	7749	Economy	14000.00
0005432528824	7749	Economy	14000.00
0005435213465	7749	Economy	14000.00
0005434067981	7749	Economy	14000.00
0005435213266	7749	Economy	14000.00
0005432069738	7749	Economy	14000.00
0005435213439	7749	Economy	14000.00
0005432528719	7749	Economy	14000.00
0005432528770	7749	Economy	14000.00
0005434067990	7749	Economy	14000.00
0005433656650	7749	Economy	14000.00
0005435614369	5355	Business	43100.00
0005435614405	5355	Business	43100.00
0005432363418	5355	Business	43100.00
0005435490252	5355	Business	43100.00
0005435614395	5355	Business	43100.00
0005435424956	5355	Business	43100.00
0005432133297	5355	Business	43100.00
0005434573440	5355	Business	43100.00
0005435424756	5355	Business	43100.00
0005434344462	5355	Business	43100.00
0005435424480	5355	Business	43100.00
0005435424627	5355	Business	43100.00
0005435424743	5355	Business	43100.00
0005435614321	5355	Business	43100.00
0005435614409	5355	Business	43100.00
0005435424739	5355	Business	43100.00
0005434244812	5355	Business	43100.00
0005435424754	5355	Business	43100.00
0005435614368	5355	Business	43100.00
0005434244918	5355	Business	43100.00
0005435614378	5355	Business	43100.00
0005435424875	5355	Business	43100.00
0005435042848	5355	Business	43100.00
0005435614367	5355	Business	43100.00
0005435614316	5355	Business	43100.00
0005435424784	5355	Business	43100.00
0005435424648	5355	Business	43100.00
0005435614317	5355	Comfort	24400.00
0005435424901	5355	Comfort	24400.00
0005435614353	5355	Comfort	24400.00
0005432133303	5355	Comfort	24400.00
0005435319567	5355	Comfort	24400.00
0005434344461	5355	Comfort	24400.00
0005434573438	5355	Comfort	24400.00
0005435424508	5355	Comfort	24400.00
0005435614370	5355	Comfort	24400.00
0005435614318	5355	Comfort	24400.00
0005435424867	5355	Comfort	24400.00
0005435424752	5355	Comfort	24400.00
0005435424700	5355	Comfort	24400.00
0005434244928	5355	Comfort	24400.00
0005434344457	5355	Comfort	24400.00
0005435614351	5355	Comfort	24400.00
0005434573434	5355	Comfort	24400.00
0005434573442	5355	Comfort	24400.00
0005435424625	5355	Comfort	24400.00
0005432133310	5355	Comfort	24400.00
0005434344437	5355	Comfort	24400.00
0005432841006	5355	Comfort	24400.00
0005435424872	5355	Comfort	24400.00
0005434573436	5355	Comfort	24400.00
0005434244923	5355	Comfort	24400.00
0005435614354	5355	Comfort	24400.00
0005435614413	5355	Comfort	24400.00
0005434244894	5355	Comfort	24400.00
0005435614343	5355	Comfort	24400.00
0005435614383	5355	Comfort	24400.00
0005434244856	5355	Comfort	24400.00
0005435424593	5355	Comfort	24400.00
0005435491450	5355	Comfort	24400.00
0005435614381	5355	Comfort	24400.00
0005435614336	5355	Comfort	24400.00
0005435424510	5355	Comfort	24400.00
0005434244849	5355	Comfort	24400.00
0005435424765	5355	Comfort	24400.00
0005432841003	5355	Comfort	24400.00
0005435614394	5355	Comfort	24400.00
0005434244811	5355	Comfort	24400.00
0005434573447	5355	Economy	14400.00
0005434244885	5355	Economy	14400.00
0005435614337	5355	Economy	14400.00
0005435424880	5355	Economy	14400.00
0005432133311	5355	Economy	14400.00
0005434344469	5355	Economy	14400.00
0005435424735	5355	Economy	14400.00
0005435614332	5355	Economy	14400.00
0005432133304	5355	Economy	14400.00
0005435302207	5355	Economy	14400.00
0005435424923	5355	Economy	14400.00
0005435424745	5355	Economy	14400.00
0005432133308	5355	Economy	14400.00
0005435614333	5355	Economy	14400.00
0005435097264	5355	Economy	14400.00
0005435424482	5355	Economy	14400.00
0005435319560	5355	Economy	14400.00
0005434244855	5355	Economy	14400.00
0005435097267	5355	Economy	14400.00
0005435614359	5355	Economy	14400.00
0005435097260	5355	Economy	14400.00
0005435614322	5355	Economy	14400.00
0005435319578	5355	Economy	14400.00
0005435614382	5355	Economy	14400.00
0005434573437	5355	Economy	14400.00
0005435614360	5355	Economy	14400.00
0005435614356	5355	Economy	14400.00
0005435614358	5355	Economy	14400.00
0005435491452	5355	Economy	14400.00
0005435614392	5355	Economy	14400.00
0005435614371	5355	Economy	14400.00
0005434245013	5355	Economy	14400.00
0005435097258	5355	Economy	14400.00
0005434344446	5355	Economy	14400.00
0005435424788	5355	Economy	14400.00
0005434344456	5355	Economy	14400.00
0005432841015	5355	Economy	14400.00
0005435424532	5355	Economy	14400.00
0005435614403	5355	Economy	14400.00
0005432133309	5355	Economy	14400.00
0005434573441	5355	Economy	14400.00
0005434344442	5355	Economy	14400.00
0005434344447	5355	Economy	14400.00
0005435614417	5355	Economy	14400.00
0005435614404	5355	Economy	14400.00
0005435614365	5355	Economy	14400.00
0005435424874	5355	Economy	14400.00
0005435614376	5355	Economy	14400.00
0005435424782	5355	Economy	14400.00
0005435614397	5355	Economy	14400.00
0005432047574	5355	Economy	14400.00
0005432047575	5355	Economy	14400.00
0005435425035	5355	Economy	14400.00
0005435424734	5355	Economy	14400.00
0005434245004	5355	Economy	14400.00
0005435424561	5355	Economy	14400.00
0005435614340	5355	Economy	14400.00
0005435302193	5355	Economy	14400.00
0005435424683	5355	Economy	14400.00
0005432363419	5355	Economy	14400.00
0005435614372	5355	Economy	14400.00
0005434344450	5355	Economy	14400.00
0005434344438	5355	Economy	14400.00
0005435424792	5355	Economy	14400.00
0005435097259	5355	Economy	14400.00
0005435614374	5355	Economy	14400.00
0005435614389	5355	Economy	15800.00
0005435614325	5355	Economy	15800.00
0005435424501	5355	Economy	14400.00
0005435424695	5355	Economy	14400.00
0005432363407	5355	Economy	14400.00
0005435614388	5355	Economy	15800.00
0005434344465	5355	Economy	14400.00
0005434344455	5355	Economy	15800.00
0005434573435	5355	Economy	14400.00
0005435614414	5355	Economy	14400.00
0005434344468	5355	Economy	14400.00
0005435614386	5355	Economy	14400.00
0005434244895	5355	Economy	14400.00
0005435424591	5355	Economy	14400.00
0005435614418	5355	Economy	14400.00
0005435042842	5355	Economy	14400.00
0005435614348	5355	Economy	14400.00
0005435424639	5355	Economy	14400.00
0005435424071	5355	Economy	14400.00
0005435614320	5355	Economy	14400.00
0005435097266	5355	Economy	14400.00
0005432133301	5355	Economy	14400.00
0005434344458	5355	Economy	14400.00
0005432133305	5355	Economy	14400.00
0005432047573	5355	Economy	14400.00
0005435097262	5355	Economy	14400.00
0005435302170	5355	Economy	14400.00
0005435614364	5355	Economy	14400.00
0005435319540	5355	Economy	14400.00
0005435424753	5355	Economy	14400.00
0005435424619	5355	Economy	14400.00
0005435490251	5355	Economy	14400.00
0005434344444	5355	Economy	14400.00
0005435614363	5355	Economy	14400.00
0005435424580	5355	Economy	14400.00
0005432363422	5355	Economy	14400.00
0005435319539	5355	Economy	14400.00
0005435319538	5355	Economy	14400.00
0005435614412	5355	Economy	14400.00
0005435097257	5355	Economy	14400.00
0005434244875	5355	Economy	14400.00
0005435424690	5355	Economy	14400.00
0005432363420	5355	Economy	14400.00
0005435614390	5355	Economy	14400.00
0005435614352	5355	Economy	14400.00
0005435424866	5355	Economy	14400.00
0005434573444	5355	Economy	14400.00
0005434244951	5355	Economy	14400.00
0005432363401	5355	Economy	14400.00
0005435614402	5355	Economy	14400.00
0005432047571	5355	Economy	14400.00
0005435319577	5355	Economy	14400.00
0005434244943	5355	Economy	14400.00
0005434573445	5355	Economy	14400.00
0005434344439	5355	Economy	14400.00
0005434344459	5355	Economy	14400.00
0005435614406	5355	Economy	14400.00
0005435614366	5355	Economy	14400.00
0005434244748	5355	Economy	14400.00
0005435424626	5355	Economy	14400.00
0005434244886	5355	Economy	14400.00
0005435424905	5355	Economy	14400.00
0005434244942	5355	Economy	14400.00
0005435424842	5355	Economy	14400.00
0005435614335	5355	Economy	14400.00
0005435614407	5355	Economy	14400.00
0005432363408	5355	Economy	14400.00
0005435614342	5355	Economy	14400.00
0005435302171	5355	Economy	14400.00
0005435614396	5355	Economy	14400.00
0005435614357	5355	Economy	14400.00
0005435424385	5355	Economy	14400.00
0005435424646	5355	Economy	14400.00
0005435424693	5355	Economy	14400.00
0005435424620	5355	Economy	14400.00
0005435424706	5355	Economy	14400.00
0005434244848	5355	Economy	14400.00
0005435614410	5355	Economy	14400.00
0005435424433	5355	Economy	14400.00
0005435614344	5355	Economy	14400.00
0005435424618	5355	Economy	14400.00
0005435319559	5355	Economy	14400.00
0005433719122	5355	Economy	14400.00
0005435424879	5355	Economy	14400.00
0005435424786	5355	Economy	14400.00
0005435614400	5355	Economy	14400.00
0005435424846	5355	Economy	14400.00
0005434245003	5355	Economy	14400.00
0005434244924	5355	Economy	14400.00
0005434244933	5355	Economy	14400.00
0005435491451	5355	Economy	14400.00
0005435614346	5355	Economy	14400.00
0005435614384	5355	Economy	14400.00
0005435614334	5355	Economy	14400.00
0005435424787	5355	Economy	14400.00
0005435097265	5355	Economy	14400.00
0005434344443	5355	Economy	14400.00
0005435424922	5355	Economy	14400.00
0005435614327	5355	Economy	14400.00
0005434244878	5355	Economy	14400.00
0005435614373	5355	Economy	14400.00
0005434244739	5355	Economy	14400.00
0005434244835	5355	Economy	14400.00
0005435302190	5355	Economy	14400.00
0005435424647	5355	Economy	14400.00
0005435424785	5355	Economy	14400.00
0005434244740	5355	Economy	14400.00
0005435614401	5355	Economy	14400.00
0005435424317	5355	Economy	14400.00
0005435424741	5355	Economy	14400.00
0005434573443	5355	Economy	15800.00
0005434344445	5355	Economy	15800.00
0005432363410	5355	Economy	15800.00
0005435424707	5355	Economy	15800.00
0005432133300	5355	Economy	14400.00
0005432133302	5355	Economy	14400.00
0005434344452	5355	Economy	14400.00
0005435425034	5355	Economy	14400.00
0005435302192	5355	Economy	14400.00
0005434573446	5355	Economy	14400.00
0005435424761	5355	Economy	14400.00
0005435302206	5355	Economy	14400.00
0005435614380	5355	Economy	14400.00
0005432363421	5355	Economy	14400.00
0005434244879	5355	Economy	14400.00
0005435424640	5355	Economy	14400.00
0005435614330	5355	Economy	14400.00
0005435614345	5355	Economy	14400.00
0005435319566	5355	Economy	14400.00
0005435319574	5355	Economy	14400.00
0005435614341	5355	Economy	14400.00
0005435490249	5355	Economy	14400.00
0005435614419	5355	Economy	14400.00
0005434344467	5355	Economy	14400.00
0005435097263	5355	Economy	14400.00
0005434344448	5355	Economy	14400.00
0005435424481	5355	Economy	14400.00
0005435424873	5355	Economy	14400.00
0005435614331	5355	Economy	14400.00
0005434344464	5355	Economy	14400.00
0005435614347	5355	Economy	14400.00
0005435424906	5355	Economy	14400.00
0005435614324	5355	Economy	14400.00
0005435424579	5355	Economy	14400.00
0005432363406	5355	Economy	14400.00
0005434344463	5355	Economy	14400.00
0005435614398	5355	Economy	14400.00
0005435614323	5355	Economy	14400.00
0005435614361	5355	Economy	14400.00
0005434244934	5355	Economy	14400.00
0005435614393	5355	Economy	14400.00
0005432133306	5355	Economy	14400.00
0005435614385	5355	Economy	14400.00
0005435614377	5355	Economy	14400.00
0005435424736	5355	Economy	14400.00
0005435614375	5355	Economy	14400.00
0005434344454	5355	Economy	14400.00
0005435614338	5355	Economy	14400.00
0005435614391	5355	Economy	14400.00
0005435302191	5355	Economy	14400.00
0005435424831	5355	Economy	14400.00
0005435614399	5355	Economy	14400.00
0005435614339	5355	Economy	14400.00
0005435614319	5355	Economy	14400.00
0005434344451	5355	Economy	14400.00
0005435424506	5355	Economy	14400.00
0005434244826	5355	Economy	14400.00
0005435424689	5355	Economy	14400.00
0005432133299	5355	Economy	14400.00
0005435614329	5355	Economy	14400.00
0005434244847	5355	Economy	14400.00
0005435424779	5355	Economy	14400.00
0005435614350	5355	Economy	14400.00
0005435424509	5355	Economy	14400.00
0005432047572	5355	Economy	14400.00
0005435424072	5355	Economy	14400.00
0005435424507	5355	Economy	14400.00
0005435614349	5355	Economy	14400.00
0005432363411	5355	Economy	14400.00
0005434344441	5355	Economy	14400.00
0005434344453	5355	Economy	14400.00
0005435614362	5355	Economy	14400.00
0005435302189	5355	Economy	14400.00
0005435424777	5355	Economy	14400.00
0005432133307	5355	Economy	14400.00
0005435424744	5355	Economy	14400.00
0005435424705	5355	Economy	14400.00
0005434344440	5355	Economy	14400.00
0005435614408	5355	Economy	14400.00
0005435424789	5355	Economy	14400.00
0005435614326	5355	Economy	14400.00
0005434344449	5355	Economy	14400.00
0005435424660	5355	Economy	14400.00
0005435614328	5355	Economy	14400.00
0005435424497	5355	Economy	14400.00
0005435424957	5355	Economy	14400.00
0005435097261	5355	Economy	14400.00
0005435614379	5355	Economy	14400.00
0005434573439	5355	Economy	14400.00
0005435614416	5355	Economy	14400.00
0005435424781	5355	Economy	14400.00
0005435614355	5355	Economy	14400.00
0005435424692	5355	Economy	14400.00
0005432133298	5355	Economy	14400.00
0005435614387	5355	Economy	14400.00
0005434344460	5355	Economy	14400.00
0005434344466	5355	Economy	14400.00
0005435490250	5355	Economy	14400.00
0005435614415	5355	Economy	14400.00
0005435614411	5355	Economy	14400.00
0005435424633	5355	Economy	14400.00
0005435424592	5355	Economy	14400.00
0005434245169	10914	Business	43100.00
0005435613044	10914	Business	43100.00
0005435319626	10914	Business	43100.00
0005435613759	10914	Business	43100.00
0005435613182	10914	Business	43100.00
0005435304186	10914	Business	43100.00
0005434344060	10914	Business	43100.00
0005435613404	10914	Business	43100.00
0005435425208	10914	Business	43100.00
0005435613551	10914	Business	43100.00
0005434245163	10914	Business	43100.00
0005434245164	10914	Business	43100.00
0005435613539	10914	Business	43100.00
0005435555371	10914	Business	43100.00
0005435613294	10914	Business	43100.00
0005435425240	10914	Business	43100.00
0005435425231	10914	Business	43100.00
0005434343995	10914	Business	43100.00
0005435613615	10914	Business	43100.00
0005434343919	10914	Business	43100.00
0005435613277	10914	Business	43100.00
0005435042870	10914	Business	43100.00
0005435425228	10914	Business	43100.00
0005434343999	10914	Business	43100.00
0005434573346	10914	Business	43100.00
0005435380318	10914	Business	43100.00
0005435555373	10914	Comfort	24400.00
0005434245176	10914	Business	43100.00
0005435613691	10914	Comfort	24400.00
0005435425218	10914	Comfort	24400.00
0005435380319	10914	Comfort	24400.00
0005435613650	10914	Comfort	24400.00
0005435612892	10914	Comfort	24400.00
0005434245147	10914	Comfort	24400.00
0005435613405	10914	Comfort	24400.00
0005432166922	10914	Comfort	24400.00
0005435425247	10914	Comfort	24400.00
0005434343935	10914	Comfort	24400.00
0005435425227	10914	Comfort	24400.00
0005435425230	10914	Comfort	24400.00
0005435425236	10914	Comfort	24400.00
0005435425263	10914	Comfort	24400.00
0005435425243	10914	Comfort	24400.00
0005432166921	10914	Comfort	24400.00
0005432165088	10914	Comfort	24400.00
0005434344053	10914	Comfort	24400.00
0005435555365	10914	Comfort	24400.00
0005435613718	10914	Comfort	24400.00
0005434573287	10914	Comfort	24400.00
0005435613332	10914	Comfort	24400.00
0005434344073	10914	Comfort	24400.00
0005435097153	10914	Comfort	24400.00
0005435380317	10914	Comfort	24400.00
0005435425225	10914	Comfort	24400.00
0005434245175	10914	Comfort	24400.00
0005435613334	10914	Comfort	24400.00
0005435613505	10914	Comfort	24400.00
0005435319631	10914	Comfort	24400.00
0005435613051	10914	Comfort	24400.00
0005435613087	10914	Comfort	24400.00
0005435425256	10914	Comfort	24400.00
0005434245158	10914	Comfort	24400.00
0005434344068	10914	Comfort	24400.00
0005435425214	10914	Comfort	24400.00
0005435425202	10914	Comfort	24400.00
0005434343988	10914	Economy	14400.00
0005435425220	10914	Economy	14400.00
0005435613568	10914	Economy	14400.00
0005435613124	10914	Economy	14400.00
0005435425200	10914	Economy	14400.00
0005435425234	10914	Economy	14400.00
0005435425252	10914	Economy	14400.00
0005435425249	10914	Economy	14400.00
0005435425217	10914	Economy	14400.00
0005435613728	10914	Economy	14400.00
0005435613268	10914	Economy	14400.00
0005432165084	10914	Economy	14400.00
0005435613537	10914	Economy	14400.00
0005434344175	10914	Economy	14400.00
0005435305024	10914	Economy	14400.00
0005435097185	10914	Economy	14400.00
0005434344024	10914	Economy	14400.00
0005435097184	10914	Economy	14400.00
0005435613285	10914	Economy	14400.00
0005435425224	10914	Economy	14400.00
0005435613574	10914	Economy	14400.00
0005435613133	10914	Economy	14400.00
0005434344121	10914	Economy	14400.00
0005435319628	10914	Economy	14400.00
0005432841026	10914	Economy	14400.00
0005434344107	10914	Economy	14400.00
0005434344000	10914	Economy	14400.00
0005434344047	10914	Economy	14400.00
0005435425264	10914	Economy	14400.00
0005435613625	10914	Economy	14400.00
0005432363437	10914	Economy	14400.00
0005435613760	10914	Economy	14400.00
0005435425255	10914	Economy	14400.00
0005435613407	10914	Economy	14400.00
0005435613316	10914	Economy	14400.00
0005435425211	10914	Economy	14400.00
0005435425209	10914	Economy	14400.00
0005435425206	10914	Economy	14400.00
0005435425199	10914	Economy	14400.00
0005434343842	10914	Economy	14400.00
0005435613457	10914	Economy	14400.00
0005434344062	10914	Economy	14400.00
0005435613552	10914	Economy	14400.00
0005435613450	10914	Economy	14400.00
0005435425242	10914	Economy	14400.00
0005434344251	10914	Economy	14400.00
0005435613425	10914	Economy	14400.00
0005435613369	10914	Economy	14400.00
0005435613134	10914	Economy	14400.00
0005435304184	10914	Economy	14400.00
0005435555370	10914	Economy	14400.00
0005435613261	10914	Economy	14400.00
0005434344173	10914	Economy	14400.00
0005435097133	10914	Economy	14400.00
0005433719163	10914	Economy	14400.00
0005435613270	10914	Economy	14400.00
0005435425237	10914	Economy	14400.00
0005435319627	10914	Economy	15800.00
0005434245153	10914	Economy	15800.00
0005435613547	10914	Economy	14400.00
0005435613579	10914	Economy	14400.00
0005435613147	10914	Economy	15800.00
0005432165082	10914	Economy	14400.00
0005435614003	10914	Economy	15800.00
0005434344019	10914	Economy	14400.00
0005435425245	10914	Economy	15800.00
0005435613573	10914	Economy	14400.00
0005435425213	10914	Economy	14400.00
0005432363434	10914	Economy	14400.00
0005435425207	10914	Economy	14400.00
0005435425210	10914	Economy	14400.00
0005435425216	10914	Economy	14400.00
0005435425198	10914	Economy	14400.00
0005435612703	10914	Economy	14400.00
0005432363436	10914	Economy	14400.00
0005435613227	10914	Economy	14400.00
0005435425266	10914	Economy	14400.00
0005435305023	10914	Economy	14400.00
0005435305025	10914	Economy	14400.00
0005435612838	10914	Economy	14400.00
0005435042869	10914	Economy	14400.00
0005434573257	10914	Economy	14400.00
0005434245173	10914	Economy	14400.00
0005435613192	10914	Economy	14400.00
0005435613586	10914	Economy	14400.00
0005435042867	10914	Economy	14400.00
0005435613333	10914	Economy	14400.00
0005434344040	10914	Economy	14400.00
0005435613506	10914	Economy	14400.00
0005435425233	10914	Economy	14400.00
0005435097194	10914	Economy	14400.00
0005434344072	10914	Economy	14400.00
0005435380316	10914	Economy	14400.00
0005434343918	10914	Economy	14400.00
0005434573293	10914	Economy	14400.00
0005434245167	10914	Economy	14400.00
0005435613538	10914	Economy	14400.00
0005435425212	10914	Economy	14400.00
0005432166923	10914	Economy	14400.00
0005435425241	10914	Economy	14400.00
0005435425221	10914	Economy	14400.00
0005435612857	10914	Economy	14400.00
0005435613661	10914	Economy	14400.00
0005432165085	10914	Economy	14400.00
0005435425248	10914	Economy	14400.00
0005434245166	10914	Economy	14400.00
0005435491434	10914	Economy	14400.00
0005435425259	10914	Economy	14400.00
0005435613092	10914	Economy	14400.00
0005435042866	10914	Economy	14400.00
0005434344234	10914	Economy	14400.00
0005435613689	10914	Economy	14400.00
0005435425257	10914	Economy	14400.00
0005435614029	10914	Economy	14400.00
0005434245149	10914	Economy	14400.00
0005434245161	10914	Economy	14400.00
0005435613300	10914	Economy	14400.00
0005435612957	10914	Economy	14400.00
0005434343972	10914	Economy	14400.00
0005435425215	10914	Economy	14400.00
0005435425205	10914	Economy	14400.00
0005435613536	10914	Economy	14400.00
0005434245172	10914	Economy	14400.00
0005434656570	10914	Economy	14400.00
0005434245151	10914	Economy	14400.00
0005435614030	10914	Economy	14400.00
0005432165083	10914	Economy	14400.00
0005435613340	10914	Economy	14400.00
0005435319630	10914	Economy	14400.00
0005434344046	10914	Economy	14400.00
0005434573265	10914	Economy	14400.00
0005435613076	10914	Economy	14400.00
0005435612854	10914	Economy	14400.00
0005434245155	10914	Economy	14400.00
0005435613317	10914	Economy	14400.00
0005435380320	10914	Economy	14400.00
0005435612811	10914	Economy	14400.00
0005435425219	10914	Economy	14400.00
0005435555366	10914	Economy	14400.00
0005435613578	10914	Economy	14400.00
0005435613507	10914	Economy	14400.00
0005435613597	10914	Economy	14400.00
0005434344130	10914	Economy	14400.00
0005434245170	10914	Economy	14400.00
0005435097183	10914	Economy	14400.00
0005434344122	10914	Economy	14400.00
0005434344123	10914	Economy	14400.00
0005435613360	10914	Economy	14400.00
0005433719161	10914	Economy	14400.00
0005435613378	10914	Economy	14400.00
0005434573282	10914	Economy	14400.00
0005435613379	10914	Economy	14400.00
0005435613614	10914	Economy	14400.00
0005434245152	10914	Economy	14400.00
0005435380321	10914	Economy	14400.00
0005435613426	10914	Economy	14400.00
0005435613410	10914	Economy	14400.00
0005434245148	10914	Economy	14400.00
0005435613156	10914	Economy	14400.00
0005435425258	10914	Economy	14400.00
0005432363435	10914	Economy	14400.00
0005434344115	10914	Economy	14400.00
0005434573289	10914	Economy	14400.00
0005434573345	10914	Economy	14400.00
0005434344012	10914	Economy	14400.00
0005435613752	10914	Economy	14400.00
0005434245168	10914	Economy	14400.00
0005435425250	10914	Economy	14400.00
0005434344103	10914	Economy	14400.00
0005435613662	10914	Economy	14400.00
0005434245160	10914	Economy	15800.00
0005435425226	10914	Economy	14400.00
0005434344108	10914	Economy	15800.00
0005435425253	10914	Economy	15800.00
0005435319624	10914	Economy	15800.00
0005435613262	10914	Economy	15800.00
0005434343994	10914	Economy	14400.00
0005432165087	10914	Economy	14400.00
0005435613780	10914	Economy	14400.00
0005435613678	10914	Economy	14400.00
0005435613624	10914	Economy	14400.00
0005434656569	10914	Economy	14400.00
0005435319625	10914	Economy	14400.00
0005435613401	10914	Economy	14400.00
0005435304185	10914	Economy	14400.00
0005435613357	10914	Economy	14400.00
0005435613223	10914	Economy	14400.00
0005435612893	10914	Economy	14400.00
0005435613308	10914	Economy	14400.00
0005435319629	10914	Economy	14400.00
0005435425239	10914	Economy	14400.00
0005435613293	10914	Economy	14400.00
0005435425203	10914	Economy	14400.00
0005434245150	10914	Economy	14400.00
0005434344252	10914	Economy	14400.00
0005435613374	10914	Economy	14400.00
0005435613677	10914	Economy	14400.00
0005435613311	10914	Economy	14400.00
0005435425223	10914	Economy	14400.00
0005435613201	10914	Economy	14400.00
0005432165086	10914	Economy	14400.00
0005434573309	10914	Economy	14400.00
0005434573256	10914	Economy	14400.00
0005435613727	10914	Economy	14400.00
0005435425229	10914	Economy	14400.00
0005435613427	10914	Economy	14400.00
0005435425201	10914	Economy	14400.00
0005435613286	10914	Economy	14400.00
0005435613259	10914	Economy	14400.00
0005435425238	10914	Economy	14400.00
0005435613375	10914	Economy	14400.00
0005435613290	10914	Economy	14400.00
0005434573273	10914	Economy	14400.00
0005435425261	10914	Economy	14400.00
0005435425244	10914	Economy	14400.00
0005435613576	10914	Economy	14400.00
0005435613312	10914	Economy	14400.00
0005432165081	10914	Economy	14400.00
0005432841027	10914	Economy	14400.00
0005435380322	10914	Economy	14400.00
0005435042868	10914	Economy	14400.00
0005435613511	10914	Economy	14400.00
0005435425254	10914	Economy	14400.00
0005435425260	10914	Economy	14400.00
0005434245159	10914	Economy	14400.00
0005434573313	10914	Economy	14400.00
0005435097170	10914	Economy	14400.00
0005435425251	10914	Economy	14400.00
0005435613211	10914	Economy	14400.00
0005435613644	10914	Economy	14400.00
0005435613789	10914	Economy	14400.00
0005434343934	10914	Economy	14400.00
0005435613651	10914	Economy	14400.00
0005435425222	10914	Economy	14400.00
0005434245162	10914	Economy	14400.00
0005434344131	10914	Economy	14400.00
0005435425235	10914	Economy	14400.00
0005435613645	10914	Economy	14400.00
0005435613415	10914	Economy	14400.00
0005432841025	10914	Economy	14400.00
0005435613781	10914	Economy	14400.00
0005435490222	10914	Economy	14400.00
0005434245156	10914	Economy	14400.00
0005435612891	10914	Economy	14400.00
0005435613441	10914	Economy	14400.00
0005435613530	10914	Economy	14400.00
0005435097160	10914	Economy	14400.00
0005434573307	10914	Economy	14400.00
0005435613337	10914	Economy	14400.00
0005435613445	10914	Economy	14400.00
0005435425262	10914	Economy	14400.00
0005434245171	10914	Economy	14400.00
0005435613155	10914	Economy	14400.00
0005433719162	10914	Economy	14400.00
0005434245165	10914	Economy	14400.00
0005435613549	10914	Economy	14400.00
0005435613428	10914	Economy	14400.00
0005434344124	10914	Economy	14400.00
0005434573270	10914	Economy	14400.00
0005434245157	10914	Economy	14400.00
0005435613471	10914	Economy	14400.00
0005435613496	10914	Economy	14400.00
0005435319623	10914	Economy	14400.00
0005435425204	10914	Economy	14400.00
0005435425265	10914	Economy	14400.00
0005435613458	10914	Economy	14400.00
0005435613565	10914	Economy	14400.00
0005434344104	10914	Economy	14400.00
0005434245174	10914	Economy	14400.00
0005435613692	10914	Economy	14400.00
0005435613695	10914	Economy	14400.00
0005434573255	10914	Economy	14400.00
0005434245154	10914	Economy	14400.00
0005435425232	10914	Economy	14400.00
0005435613585	10914	Economy	14400.00
0005435613486	10914	Economy	14400.00
0005435613510	10914	Economy	14400.00
0005435425246	10914	Economy	14400.00
0005433805600	3257	Business	18800.00
0005433507294	3257	Business	18800.00
0005433805599	3257	Business	18800.00
0005433805588	3257	Business	18800.00
0005432459647	3257	Business	18800.00
0005432181856	3257	Business	18800.00
0005432459736	3257	Business	18800.00
0005432459651	3257	Business	18800.00
0005434143740	3257	Business	18800.00
0005433805579	3257	Business	18800.00
0005433634037	3257	Business	18800.00
0005433805587	3257	Business	18800.00
0005432181847	3257	Business	18800.00
0005432459625	3257	Business	18800.00
0005432459785	3257	Business	18800.00
0005433805578	3257	Business	18800.00
0005433634046	3257	Business	18800.00
0005432181850	3257	Business	18800.00
0005432459835	3257	Business	18800.00
0005432459729	3257	Business	18800.00
0005433634029	3257	Business	18800.00
0005433634035	3257	Business	18800.00
0005433634041	3257	Business	18800.00
0005433507299	3257	Business	18800.00
0005432181865	3257	Business	18800.00
0005432181848	3257	Business	18800.00
0005433634020	3257	Business	18800.00
0005432459769	3257	Business	18800.00
0005433507298	3257	Economy	6900.00
0005434143733	3257	Economy	6900.00
0005432459648	3257	Economy	6900.00
0005432459855	3257	Economy	6900.00
0005433805605	3257	Economy	6900.00
0005432459745	3257	Economy	6900.00
0005432459626	3257	Economy	6300.00
0005433805596	3257	Economy	6300.00
0005433507300	3257	Economy	6300.00
0005432181859	3257	Economy	6300.00
0005434143736	3257	Economy	6300.00
0005432459786	3257	Economy	6300.00
0005432181846	3257	Economy	6300.00
0005434143738	3257	Economy	6300.00
0005433805595	3257	Economy	6300.00
0005433805608	3257	Economy	6300.00
0005433507297	3257	Economy	6300.00
0005433634040	3257	Economy	6300.00
0005434143737	3257	Economy	6300.00
0005433507288	3257	Economy	6300.00
0005432181849	3257	Economy	6300.00
0005433507289	3257	Economy	6300.00
0005433805583	3257	Economy	6300.00
0005432459673	3257	Economy	6300.00
0005432459737	3257	Economy	6300.00
0005433805592	3257	Economy	6300.00
0005433634049	3257	Economy	6300.00
0005433634047	3257	Economy	6300.00
0005433634045	3257	Economy	6300.00
0005433805586	3257	Economy	6300.00
0005433805577	3257	Economy	6300.00
0005433634018	3257	Economy	6300.00
0005432459482	3257	Economy	6300.00
0005433507296	3257	Economy	6300.00
0005433507290	3257	Economy	6300.00
0005433634042	3257	Economy	6300.00
0005432459555	3257	Economy	6300.00
0005433805574	3257	Economy	6300.00
0005433805582	3257	Economy	6300.00
0005432459738	3257	Economy	6300.00
0005433634026	3257	Economy	6300.00
0005432459675	3257	Economy	6300.00
0005433634025	3257	Economy	6300.00
0005433805590	3257	Economy	6300.00
0005433634036	3257	Economy	6300.00
0005432181852	3257	Economy	6300.00
0005433805598	3257	Economy	6300.00
0005433805589	3257	Economy	6300.00
0005433805610	3257	Economy	6300.00
0005433634033	3257	Economy	6300.00
0005433507295	3257	Economy	6300.00
0005433634017	3257	Economy	6300.00
0005433805573	3257	Economy	6300.00
0005433634019	3257	Economy	6300.00
0005433634016	3257	Economy	6300.00
0005433805581	3257	Economy	6300.00
0005434143739	3257	Economy	6300.00
0005433507291	3257	Economy	6300.00
0005433805593	3257	Economy	6300.00
0005432181862	3257	Economy	6300.00
0005432181845	3257	Economy	6300.00
0005432459714	3257	Economy	6300.00
0005433805603	3257	Economy	6300.00
0005432459720	3257	Economy	6300.00
0005432181857	3257	Economy	6900.00
0005434143731	3257	Economy	6900.00
0005433507293	3257	Economy	6900.00
0005432459674	3257	Economy	6900.00
0005432459775	3257	Economy	6300.00
0005433634032	3257	Economy	6900.00
0005433507287	3257	Economy	6300.00
0005432459715	3257	Economy	6300.00
0005433634039	3257	Economy	6300.00
0005433634044	3257	Economy	6300.00
0005432181855	3257	Economy	6300.00
0005432459483	3257	Economy	6300.00
0005433634050	3257	Economy	6300.00
0005432459795	3257	Economy	6300.00
0005433634048	3257	Economy	6300.00
0005432460055	3257	Economy	6300.00
0005433805575	3257	Economy	6300.00
0005432181854	3257	Economy	6300.00
0005432459739	3257	Economy	6300.00
0005432181853	3257	Economy	6300.00
0005432459566	3257	Economy	6300.00
0005432459854	3257	Economy	6300.00
0005433634038	3257	Economy	6300.00
0005433805585	3257	Economy	6300.00
0005433634023	3257	Economy	6300.00
0005433805591	3257	Economy	6300.00
0005433805580	3257	Economy	6300.00
0005433805611	3257	Economy	6300.00
0005433805576	3257	Economy	6300.00
0005433805609	3257	Economy	6300.00
0005432459776	3257	Economy	6300.00
0005433634024	3257	Economy	6300.00
0005433805615	3257	Economy	6300.00
0005433634031	3257	Economy	6300.00
0005433805614	3257	Economy	6300.00
0005433805601	3257	Economy	6300.00
0005434143735	3257	Economy	6300.00
0005432181864	3257	Economy	6300.00
0005433805612	3257	Economy	6300.00
0005433507301	3257	Economy	6300.00
0005433805597	3257	Economy	6300.00
0005434143734	3257	Economy	6300.00
0005434143732	3257	Economy	6300.00
0005432181843	3257	Economy	6300.00
0005433634021	3257	Economy	6300.00
0005433805584	3257	Economy	6300.00
0005433805607	3257	Economy	6300.00
0005433805594	3257	Economy	6300.00
0005433634027	3257	Economy	6300.00
0005432181863	3257	Economy	6300.00
0005433805606	3257	Economy	6300.00
0005432459541	3257	Economy	6300.00
0005432181851	3257	Economy	6300.00
0005432181861	3257	Economy	6300.00
0005432459503	3257	Economy	6300.00
0005432459751	3257	Economy	6300.00
0005432181858	3257	Economy	6300.00
0005433634034	3257	Economy	6300.00
0005432459770	3257	Economy	6300.00
0005432181844	3257	Economy	6300.00
0005432459567	3257	Economy	6300.00
0005433507292	3257	Economy	6300.00
0005432181860	3257	Economy	6300.00
0005433634022	3257	Economy	6300.00
0005433634028	3257	Economy	6300.00
0005433805613	3257	Economy	6300.00
0005432459772	3257	Economy	6300.00
0005433634030	3257	Economy	6300.00
0005433805604	3257	Economy	6300.00
0005433634043	3257	Economy	6300.00
0005432459827	3257	Economy	6300.00
0005433805602	3257	Economy	6300.00
0005435885141	3256	Business	18800.00
0005435885101	3256	Business	18800.00
0005435885327	3256	Business	18800.00
0005435885246	3256	Business	18800.00
0005435885346	3256	Business	18800.00
0005435885295	3256	Business	18800.00
0005435885254	3256	Business	18800.00
0005435885126	3256	Business	18800.00
0005435885207	3256	Business	18800.00
0005435885159	3256	Business	18800.00
0005435885502	3256	Economy	6900.00
0005435885238	3256	Economy	6900.00
0005435885117	3256	Economy	6900.00
0005435885068	3256	Economy	6300.00
0005435885099	3256	Economy	6300.00
0005435885145	3256	Economy	6300.00
0005435885187	3256	Economy	6300.00
0005435885185	3256	Economy	6300.00
0005435885164	3256	Economy	6300.00
0005435885154	3256	Economy	6300.00
0005435885305	3256	Economy	6300.00
0005435885146	3256	Economy	6300.00
0005435885315	3256	Economy	6300.00
0005435885194	3256	Economy	6300.00
0005435885311	3256	Economy	6300.00
0005435885087	3256	Economy	6300.00
0005435884906	3256	Economy	6300.00
0005435885056	3256	Economy	6300.00
0005435885503	3256	Economy	6300.00
0005435885124	3256	Economy	6300.00
0005435885310	3256	Economy	6300.00
0005435885175	3256	Economy	6300.00
0005435885321	3256	Economy	6300.00
0005435885127	3256	Economy	6300.00
0005435885121	3256	Economy	6900.00
0005435885203	3256	Economy	6900.00
0005435885184	3256	Economy	6900.00
0005435885208	3256	Economy	6300.00
0005435885122	3256	Economy	6300.00
0005435885245	3256	Economy	6300.00
0005435885142	3256	Economy	6300.00
0005435885100	3256	Economy	6300.00
0005435885280	3256	Economy	6300.00
0005435885104	3256	Economy	6300.00
0005435885328	3256	Economy	6300.00
0005435885193	3256	Economy	6300.00
0005435885118	3256	Economy	6300.00
0005435885264	3256	Economy	6300.00
0005435885163	3256	Economy	6300.00
0005435885349	3256	Economy	6300.00
0005435885088	3256	Economy	6300.00
0005435885108	3256	Economy	6300.00
0005435885260	3256	Economy	6300.00
0005435885050	3256	Economy	6300.00
0005435885322	3256	Economy	6300.00
0005435885155	3256	Economy	6300.00
0005435885158	3256	Economy	6300.00
0005435885236	3256	Economy	6300.00
0005435885538	8282	Business	18800.00
0005435885548	8282	Business	18800.00
0005433507044	8282	Business	18800.00
0005432460190	8282	Business	18800.00
0005435885546	8282	Business	18800.00
0005432460229	8282	Business	18800.00
0005435885534	8282	Business	18800.00
0005435885573	8282	Business	18800.00
0005432460230	8282	Business	18800.00
0005435885547	8282	Business	18800.00
0005433507115	8282	Business	18800.00
0005435885537	8282	Business	18800.00
0005435885535	8282	Business	18800.00
0005433507152	8282	Business	18800.00
0005432460196	8282	Business	18800.00
0005435885539	8282	Business	18800.00
0005433507093	8282	Business	18800.00
0005432460231	8282	Business	18800.00
0005435885556	8282	Business	18800.00
0005433507168	8282	Business	18800.00
0005435885550	8282	Business	18800.00
0005433507081	8282	Business	18800.00
0005433507121	8282	Economy	6900.00
0005432460200	8282	Economy	6900.00
0005432460235	8282	Economy	6900.00
0005432460232	8282	Economy	6300.00
0005433507129	8282	Economy	6300.00
0005432042808	8282	Economy	6300.00
0005435885553	8282	Economy	6300.00
0005432460218	8282	Economy	6300.00
0005433507131	8282	Economy	6300.00
0005435885542	8282	Economy	6300.00
0005435885551	8282	Economy	6300.00
0005432460202	8282	Economy	6300.00
0005435885532	8282	Economy	6300.00
0005432460226	8282	Economy	6300.00
0005432460198	8282	Economy	6300.00
0005432042799	8282	Economy	6300.00
0005435885530	8282	Economy	6300.00
0005435885569	8282	Economy	6300.00
0005432460227	8282	Economy	6300.00
0005435885543	8282	Economy	6300.00
0005435885557	8282	Economy	6300.00
0005435885552	8282	Economy	6300.00
0005435885565	8282	Economy	6300.00
0005432460221	8282	Economy	6300.00
0005433507112	8282	Economy	6300.00
0005432460203	8282	Economy	6300.00
0005432460191	8282	Economy	6300.00
0005435885570	8282	Economy	6300.00
0005434312334	8282	Economy	6300.00
0005435885533	8282	Economy	6300.00
0005435885549	8282	Economy	6300.00
0005432460205	8282	Economy	6300.00
0005432042806	8282	Economy	6300.00
0005435885568	8282	Economy	6300.00
0005432460233	8282	Economy	6300.00
0005433507228	8282	Economy	6300.00
0005432460201	8282	Economy	6300.00
0005435885545	8282	Economy	6300.00
0005432460219	8282	Economy	6300.00
0005432460222	8282	Economy	6300.00
0005432460220	8282	Economy	6300.00
0005435885554	8282	Economy	6300.00
0005432042797	8282	Economy	6300.00
0005432460216	8282	Economy	6300.00
0005435885541	8282	Economy	6300.00
0005435885562	8282	Economy	6300.00
0005433507099	8282	Economy	6300.00
0005433507070	8282	Economy	6300.00
0005432042796	8282	Economy	6300.00
0005434312335	8282	Economy	6300.00
0005432460194	8282	Economy	6300.00
0005432460217	8282	Economy	6300.00
0005432460236	8282	Economy	6900.00
0005432460237	8282	Economy	6900.00
0005432460192	8282	Economy	6300.00
0005435885561	8282	Economy	6300.00
0005432042809	8282	Economy	6300.00
0005432460213	8282	Economy	6900.00
0005432460207	8282	Economy	6300.00
0005432460208	8282	Economy	6300.00
0005435885559	8282	Economy	6300.00
0005433507138	8282	Economy	6300.00
0005432460195	8282	Economy	6300.00
0005432460186	8282	Economy	6300.00
0005433507227	8282	Economy	6300.00
0005432042805	8282	Economy	6300.00
0005432460211	8282	Economy	6300.00
0005435885536	8282	Economy	6300.00
0005435885558	8282	Economy	6300.00
0005432460225	8282	Economy	6300.00
0005435885567	8282	Economy	6300.00
0005432042798	8282	Economy	6300.00
0005433507101	8282	Economy	6300.00
0005433507114	8282	Economy	6300.00
0005433507137	8282	Economy	6300.00
0005432460214	8282	Economy	6300.00
0005435885540	8282	Economy	6300.00
0005432460210	8282	Economy	6300.00
0005432460209	8282	Economy	6300.00
0005432460212	8282	Economy	6300.00
0005435885564	8282	Economy	6300.00
0005432460193	8282	Economy	6300.00
0005432460197	8282	Economy	6300.00
0005435885566	8282	Economy	6300.00
0005432460223	8282	Economy	6300.00
0005432460188	8282	Economy	6300.00
0005432042803	8282	Economy	6300.00
0005434312333	8282	Economy	6300.00
0005432460206	8282	Economy	6300.00
0005432460199	8282	Economy	6300.00
0005435885572	8282	Economy	6300.00
0005435885563	8282	Economy	6300.00
0005432042807	8282	Economy	6300.00
0005432460224	8282	Economy	6300.00
0005432460187	8282	Economy	6300.00
0005432042801	8282	Economy	6300.00
0005432042800	8282	Economy	6300.00
0005432042804	8282	Economy	6300.00
0005432460228	8282	Economy	6300.00
0005432042802	8282	Economy	6300.00
0005435885571	8282	Economy	6300.00
0005432460234	8282	Economy	6300.00
0005432460185	8282	Economy	6300.00
0005432460204	8282	Economy	6300.00
0005435885544	8282	Economy	6300.00
0005435885531	8282	Economy	6300.00
0005432460215	8282	Economy	6300.00
0005435885555	8282	Economy	6300.00
0005435885560	8282	Economy	6300.00
0005432460189	8282	Economy	6300.00
0005433507151	8282	Economy	6300.00
0005433633671	8275	Business	18800.00
0005433633584	8275	Business	18800.00
0005433805344	8275	Business	18800.00
0005433633577	8275	Business	18800.00
0005433805236	8275	Business	18800.00
0005433805310	8275	Business	18800.00
0005433805499	8275	Business	18800.00
0005433633606	8275	Business	18800.00
0005433805235	8275	Business	18800.00
0005433805176	8275	Business	18800.00
0005435854061	8275	Economy	6900.00
0005433805135	8275	Economy	6900.00
0005433805182	8275	Economy	6900.00
0005433633749	8275	Economy	6300.00
0005433633761	8275	Economy	6300.00
0005433633782	8275	Economy	6300.00
0005433633679	8275	Economy	6300.00
0005433805361	8275	Economy	6300.00
0005433633622	8275	Economy	6300.00
0005433805295	8275	Economy	6300.00
0005433805500	8275	Economy	6300.00
0005433633746	8275	Economy	6300.00
0005433805294	8275	Economy	6300.00
0005433633651	8275	Economy	6300.00
0005433805282	8275	Economy	6300.00
0005433633859	8275	Economy	6300.00
0005433633821	8275	Economy	6300.00
0005435854062	8275	Economy	6300.00
0005433805327	8275	Economy	6300.00
0005433805398	8275	Economy	6300.00
0005433805301	8275	Economy	6300.00
0005433805300	8275	Economy	6300.00
0005433805360	8275	Economy	6300.00
0005433805332	8275	Economy	6300.00
0005433805148	8275	Economy	6300.00
0005433633747	8275	Economy	6300.00
0005433805462	8275	Economy	6300.00
0005433633734	8275	Economy	6300.00
0005433805274	8275	Economy	6300.00
0005433633783	8275	Economy	6300.00
0005433633570	8275	Economy	6300.00
0005433805269	8275	Economy	6300.00
0005433633539	8275	Economy	6900.00
0005433633743	8275	Economy	6300.00
0005433805338	8275	Economy	6300.00
0005433805204	8275	Economy	6300.00
0005433805264	8275	Economy	6300.00
0005433633860	8275	Economy	6300.00
0005433633602	8275	Economy	6300.00
0005433633861	8275	Economy	6300.00
0005433805346	8275	Economy	6300.00
0005433633864	8275	Economy	6300.00
0005433805178	8275	Economy	6300.00
0005433805237	8275	Economy	6300.00
0005433805305	8275	Economy	6300.00
0005433633695	8275	Economy	6300.00
0005433805304	8275	Economy	6300.00
0005433633603	8275	Economy	6300.00
0005433805281	8275	Economy	6300.00
0005433805217	8275	Economy	6300.00
0005433805161	8275	Economy	6300.00
0005433805132	8275	Economy	6300.00
0005433633666	8275	Economy	6300.00
0005433805331	8275	Economy	6300.00
0005433805345	8275	Economy	6300.00
0005433805270	8275	Economy	6300.00
0005433633400	8275	Economy	6300.00
0005433805359	8275	Economy	6300.00
0005433633769	8275	Economy	6300.00
0005433805293	8275	Economy	6300.00
0005433805177	8275	Economy	6300.00
0005433633605	8275	Economy	6300.00
0005434183574	8264	Economy	6300.00
0005434183575	8264	Economy	6300.00
0005434183576	8264	Economy	6900.00
0005432383443	4562	Business	9900.00
0005432383433	4562	Business	9900.00
0005432383421	4562	Business	9900.00
0005432383436	4562	Business	9900.00
0005432728016	4562	Business	9900.00
0005432383437	4562	Business	9900.00
0005432728012	4562	Business	9900.00
0005432383411	4562	Business	9900.00
0005432728023	4562	Business	9900.00
0005432728018	4562	Economy	3300.00
0005432383442	4562	Economy	3300.00
0005433722271	4562	Economy	3300.00
0005432383427	4562	Economy	3300.00
0005432383406	4562	Economy	3300.00
0005432383408	4562	Economy	3300.00
0005432728017	4562	Economy	3300.00
0005432728011	4562	Economy	3600.00
0005432383424	4562	Economy	3600.00
0005432383431	4562	Economy	3600.00
0005432728013	4562	Economy	3600.00
0005432728020	4562	Economy	3300.00
0005432728022	4562	Economy	3300.00
0005433454888	4562	Economy	3300.00
0005432383409	4562	Economy	3300.00
0005432383438	4562	Economy	3300.00
0005432383415	4562	Economy	3300.00
0005433453772	4562	Economy	3300.00
0005432383412	4562	Economy	3300.00
0005433454890	4562	Economy	3300.00
0005432383435	4562	Economy	3300.00
0005432383403	4562	Economy	3300.00
0005432383432	4562	Economy	3300.00
0005432383413	4562	Economy	3300.00
0005432383434	4562	Economy	3300.00
0005432383407	4562	Economy	3300.00
0005433454889	4562	Economy	3300.00
0005432383430	4562	Economy	3300.00
0005432383422	4562	Economy	3300.00
0005432728019	4562	Economy	3300.00
0005432383429	4562	Economy	3300.00
0005432383439	4562	Economy	3300.00
0005432728014	4562	Economy	3300.00
0005432383404	4562	Economy	3300.00
0005432383423	4562	Economy	3300.00
0005432383425	4562	Economy	3300.00
0005432383410	4562	Economy	3300.00
0005433454891	4562	Economy	3300.00
0005432383419	4562	Economy	3300.00
0005432383420	4562	Economy	3300.00
0005432383426	4562	Economy	3300.00
0005432383402	4562	Economy	3300.00
0005432383441	4562	Economy	3300.00
0005432728015	4562	Economy	3300.00
0005432728021	4562	Economy	3300.00
0005432383405	4562	Economy	3300.00
0005432383418	4562	Economy	3300.00
0005433722270	4562	Economy	3300.00
0005432383428	4562	Economy	3300.00
0005432383440	4562	Economy	3300.00
0005432383416	4562	Economy	3300.00
0005433194861	4562	Economy	3300.00
0005432383414	4562	Economy	3300.00
0005432383417	4562	Economy	3300.00
0005433453750	30101	Business	9900.00
0005433194845	30101	Business	9900.00
0005432382929	30101	Business	9900.00
0005433194847	30101	Business	9900.00
0005433722186	30101	Business	9900.00
0005433722184	30101	Business	9900.00
0005432382964	30101	Business	9900.00
0005433722182	30101	Economy	3300.00
0005433722214	30101	Economy	3300.00
0005432727904	30101	Economy	3300.00
0005432382838	30101	Economy	3300.00
0005432382889	30101	Economy	3300.00
0005433722221	30101	Economy	3300.00
0005432383073	30101	Economy	3300.00
0005432382861	30101	Economy	3600.00
0005432382862	30101	Economy	3600.00
0005432382985	30101	Economy	3600.00
0005432382962	30101	Economy	3600.00
0005432383066	30101	Economy	3300.00
0005433722185	30101	Economy	3300.00
0005432383065	30101	Economy	3300.00
0005433722171	30101	Economy	3300.00
0005433194857	30101	Economy	3300.00
0005432382905	30101	Economy	3300.00
0005433722219	30101	Economy	3300.00
0005432382950	30101	Economy	3300.00
0005433722208	30101	Economy	3300.00
0005432727886	30101	Economy	3300.00
0005432382868	30101	Economy	3300.00
0005432382984	30101	Economy	3300.00
0005433722195	30101	Economy	3300.00
0005433194834	30101	Economy	3300.00
0005432382952	30101	Economy	3300.00
0005433722203	30101	Economy	3300.00
0005433453744	30101	Economy	3300.00
0005432382963	30101	Economy	3300.00
0005432382933	30101	Economy	3300.00
0005432382897	30101	Economy	3300.00
0005432382826	30101	Economy	3300.00
0005433451608	30101	Economy	3300.00
0005433722207	30101	Economy	3300.00
0005432383091	30101	Economy	3300.00
0005433453743	30101	Economy	3300.00
0005432383120	30101	Economy	3300.00
0005432727893	30101	Economy	3300.00
0005433722218	30101	Economy	3300.00
0005433722210	30101	Economy	3300.00
0005433722220	30101	Economy	3300.00
0005432727908	30101	Economy	3300.00
0005432382936	30101	Economy	3300.00
0005432382911	30101	Economy	3300.00
0005432382907	30101	Economy	3300.00
0005433722172	30101	Economy	3300.00
0005433194836	30101	Economy	3300.00
0005433722224	30101	Economy	3300.00
0005432727894	30101	Economy	3300.00
0005432382867	30101	Economy	3300.00
0005432382937	30101	Economy	3300.00
0005432382935	30101	Economy	3300.00
0005432727909	30101	Economy	3300.00
0005433722213	30101	Economy	3300.00
0005432925009	1735	Business	57200.00
0005433516950	1735	Business	57200.00
0005432294503	1735	Business	57200.00
0005435529392	1735	Business	57200.00
0005435529402	1735	Business	57200.00
0005435541139	1735	Business	57200.00
0005435529393	1735	Business	57200.00
0005435529388	1735	Economy	19100.00
0005433516945	1735	Economy	19100.00
0005435529401	1735	Economy	19100.00
0005433516946	1735	Economy	19100.00
0005435541148	1735	Economy	19100.00
0005435529394	1735	Economy	21000.00
0005433516948	1735	Economy	21000.00
0005435529391	1735	Economy	21000.00
0005435541149	1735	Economy	19100.00
0005435529408	1735	Economy	19100.00
0005435529398	1735	Economy	19100.00
0005435529396	1735	Economy	19100.00
0005435529404	1735	Economy	19100.00
0005435541136	1735	Economy	19100.00
0005433516947	1735	Economy	19100.00
0005433516941	1735	Economy	19100.00
0005435529410	1735	Economy	19100.00
0005435529403	1735	Economy	19100.00
0005435541137	1735	Economy	19100.00
0005435541146	1735	Economy	19100.00
0005435529407	1735	Economy	19100.00
0005435541132	1735	Economy	19100.00
0005435541147	1735	Economy	19100.00
0005435541145	1735	Economy	19100.00
0005432925017	1735	Economy	19100.00
0005435541138	1735	Economy	19100.00
0005433516942	1735	Economy	19100.00
0005435529399	1735	Economy	19100.00
0005435541143	1735	Economy	19100.00
0005435541142	1735	Economy	19100.00
0005435529406	1735	Economy	19100.00
0005432925018	1735	Economy	19100.00
0005435541151	1735	Economy	19100.00
0005435541150	1735	Economy	19100.00
0005435529397	1735	Economy	19100.00
0005435541153	1735	Economy	19100.00
0005435541133	1735	Economy	19100.00
0005435541140	1735	Economy	19100.00
0005435529395	1735	Economy	19100.00
0005435541135	1735	Economy	19100.00
0005433516944	1735	Economy	19100.00
0005435541141	1735	Economy	19100.00
0005435541144	1735	Economy	19100.00
0005435529389	1735	Economy	19100.00
0005435541152	1735	Economy	19100.00
0005435541134	1735	Economy	19100.00
0005435529390	1735	Economy	19100.00
0005435529405	1735	Economy	19100.00
0005433516943	1735	Economy	19100.00
0005432925019	1735	Economy	19100.00
0005432294502	1735	Economy	19100.00
0005433516949	1735	Economy	19100.00
0005435529400	1735	Economy	19100.00
0005435529409	1735	Economy	19100.00
0005435517786	21974	Business	57200.00
0005435540919	21974	Business	57200.00
0005435540941	21974	Business	57200.00
0005433516865	21974	Business	57200.00
0005433516864	21974	Business	57200.00
0005435517831	21974	Economy	19100.00
0005435517826	21974	Economy	19100.00
0005435517892	21974	Economy	21000.00
0005432925065	21974	Economy	21000.00
0005432925066	21974	Economy	19100.00
0005435540960	21974	Economy	19100.00
0005435517758	21974	Economy	19100.00
0005435517822	21974	Economy	19100.00
0005435540897	21974	Economy	19100.00
0005435540940	21974	Economy	19100.00
0005435540964	21974	Economy	19100.00
0005435517910	21974	Economy	19100.00
0005435517830	21974	Economy	19100.00
0005435517832	21974	Economy	19100.00
0005435541076	21974	Economy	19100.00
0005435517759	21974	Economy	19100.00
0005435540918	21974	Economy	19100.00
0005435540855	21974	Economy	19100.00
0005435540973	21974	Economy	19100.00
0005435540895	21974	Economy	19100.00
0005435517839	21974	Economy	19100.00
0005435517911	21974	Economy	19100.00
0005435517930	21974	Economy	19100.00
0005435540943	21974	Economy	19100.00
0005435517881	21974	Economy	19100.00
0005433516863	21974	Economy	19100.00
0005432925068	21974	Economy	19100.00
0005432925067	21974	Economy	19100.00
0005435517931	21974	Economy	19100.00
0005435540835	21974	Economy	19100.00
0005435517945	21974	Economy	19100.00
0005435540896	21974	Economy	19100.00
0005435517879	21974	Economy	19100.00
0005435540967	21974	Economy	19100.00
0005435517840	21974	Economy	19100.00
0005435517818	21974	Economy	19100.00
0005434458936	7363	Business	18500.00
0005434664958	7363	Business	18500.00
0005435252586	7363	Business	18500.00
0005435252599	7363	Business	18500.00
0005432839238	7363	Business	18500.00
0005432839228	7363	Business	18500.00
0005432073413	7363	Business	18500.00
0005434458924	7363	Business	18500.00
0005434458929	7363	Business	18500.00
0005434458944	7363	Business	18500.00
0005434664956	7363	Business	18500.00
0005432839230	7363	Business	18500.00
0005432839225	7363	Economy	6200.00
0005435252676	7363	Economy	6200.00
0005432841024	7363	Economy	6200.00
0005435252572	7363	Economy	6200.00
0005432839221	7363	Economy	6200.00
0005432839215	7363	Economy	6200.00
0005435252584	7363	Economy	6200.00
0005434458925	7363	Economy	6200.00
0005434458942	7363	Economy	6200.00
0005435252618	7363	Economy	6200.00
0005435252585	7363	Economy	6800.00
0005432839244	7363	Economy	6800.00
0005435252656	7363	Economy	6800.00
0005432839229	7363	Economy	6800.00
0005434458937	7363	Economy	6800.00
0005435252613	7363	Economy	6200.00
0005432839233	7363	Economy	6200.00
0005435252703	7363	Economy	6200.00
0005432841023	7363	Economy	6200.00
0005432839234	7363	Economy	6200.00
0005432839216	7363	Economy	6200.00
0005435252729	7363	Economy	6200.00
0005432839232	7363	Economy	6200.00
0005432073410	7363	Economy	6200.00
0005434458932	7363	Economy	6200.00
0005432839220	7363	Economy	6200.00
0005434458941	7363	Economy	6200.00
0005432839212	7363	Economy	6200.00
0005434458940	7363	Economy	6200.00
0005435252682	7363	Economy	6200.00
0005432839242	7363	Economy	6200.00
0005435252614	7363	Economy	6200.00
0005432839224	7363	Economy	6200.00
0005432073411	7363	Economy	6200.00
0005435252654	7363	Economy	6200.00
0005434458928	7363	Economy	6200.00
0005435252615	7363	Economy	6200.00
0005435252687	7363	Economy	6200.00
0005432839236	7363	Economy	6200.00
0005435252545	7363	Economy	6200.00
0005434458931	7363	Economy	6200.00
0005434458930	7363	Economy	6200.00
0005434458943	7363	Economy	6200.00
0005435491431	7363	Economy	6200.00
0005434458927	7363	Economy	6200.00
0005435491429	7363	Economy	6200.00
0005435252624	7363	Economy	6200.00
0005432839241	7363	Economy	6200.00
0005432073412	7363	Economy	6200.00
0005435491433	7363	Economy	6200.00
0005434458938	7363	Economy	6200.00
0005434458935	7363	Economy	6200.00
0005434458933	7363	Economy	6200.00
0005432839235	7363	Economy	6200.00
0005432839213	7363	Economy	6200.00
0005434458926	7363	Economy	6200.00
0005432839239	7363	Economy	6200.00
0005432839237	7363	Economy	6200.00
0005435252681	7363	Economy	6200.00
0005432839214	7363	Economy	6200.00
0005432839218	7363	Economy	6200.00
0005435252707	7363	Economy	6200.00
0005432839240	7363	Economy	6200.00
0005434664959	7363	Economy	6200.00
0005435252617	7363	Economy	6200.00
0005432839219	7363	Economy	6200.00
0005434458946	7363	Economy	6200.00
0005435252660	7363	Economy	6200.00
0005432839227	7363	Economy	6200.00
0005434458934	7363	Economy	6200.00
0005432839222	7363	Economy	6200.00
0005435252673	7363	Economy	6200.00
0005432839243	7363	Economy	6200.00
0005432839223	7363	Economy	6200.00
0005435252730	7363	Economy	6200.00
0005432839217	7363	Economy	6200.00
0005435252671	7363	Economy	6200.00
0005434458945	7363	Economy	6200.00
0005432839226	7363	Economy	6200.00
0005432823461	7363	Economy	6200.00
0005432839231	7363	Economy	6200.00
0005434458939	7363	Economy	6200.00
0005434458679	28898	Business	18500.00
0005434458765	28898	Business	18500.00
0005434458770	28898	Business	18500.00
0005435491453	28898	Business	18500.00
0005432838795	28898	Business	18500.00
0005434458729	28898	Business	18500.00
0005434458724	28898	Business	18500.00
0005434458812	28898	Business	18500.00
0005435252818	28898	Business	18500.00
0005432839069	28898	Business	18500.00
0005432839013	28898	Business	18500.00
0005434664975	28898	Economy	6200.00
0005432839138	28898	Economy	6200.00
0005432838962	28898	Economy	6200.00
0005435252819	28898	Economy	6200.00
0005434458728	28898	Economy	6200.00
0005432838786	28898	Economy	6200.00
0005434458730	28898	Economy	6200.00
0005432841004	28898	Economy	6200.00
0005432839071	28898	Economy	6800.00
0005432839137	28898	Economy	6800.00
0005432839064	28898	Economy	6800.00
0005432838918	28898	Economy	6200.00
0005434458691	28898	Economy	6200.00
0005434458722	28898	Economy	6200.00
0005435252805	28898	Economy	6200.00
0005432839011	28898	Economy	6200.00
0005435252813	28898	Economy	6200.00
0005432839093	28898	Economy	6200.00
0005432838997	28898	Economy	6200.00
0005432838796	28898	Economy	6200.00
0005432838986	28898	Economy	6200.00
0005432001036	28898	Economy	6200.00
0005435252806	28898	Economy	6200.00
0005434458795	28898	Economy	6200.00
0005432839058	28898	Economy	6200.00
0005432838998	28898	Economy	6200.00
0005432839014	28898	Economy	6200.00
0005432823440	28898	Economy	6200.00
0005432841005	28898	Economy	6200.00
0005432838916	28898	Economy	6200.00
0005432838917	28898	Economy	6200.00
0005434458816	28898	Economy	6200.00
0005432838860	28898	Economy	6200.00
0005432839017	28898	Economy	6200.00
0005435252807	28898	Economy	6200.00
0005432838958	28898	Economy	6200.00
0005432838945	28898	Economy	6200.00
0005432838785	28898	Economy	6200.00
0005435252808	28898	Economy	6200.00
0005432838925	28898	Economy	6200.00
0005435252811	28898	Economy	6200.00
0005434458739	28898	Economy	6200.00
0005434458740	28898	Economy	6200.00
0005434664974	28898	Economy	6200.00
0005434458738	28898	Economy	6200.00
0005435252817	28898	Economy	6200.00
0005432839034	28898	Economy	6200.00
0005435252815	28898	Economy	6200.00
0005434458723	28898	Economy	6200.00
0005435252816	28898	Economy	6200.00
0005434458784	28898	Economy	6200.00
0005435252812	28898	Economy	6200.00
0005432838919	28898	Economy	6200.00
0005435491454	28898	Economy	6200.00
0005435252820	28898	Economy	6200.00
0005435252803	28898	Economy	6200.00
0005434458743	28898	Economy	6200.00
0005435252810	28898	Economy	6200.00
0005432838938	28898	Economy	6200.00
0005432839072	28898	Economy	6200.00
0005434458707	28898	Economy	6200.00
0005434458692	28898	Economy	6200.00
0005432838957	28898	Economy	6200.00
0005434458850	28898	Economy	6200.00
0005435252814	28898	Economy	6200.00
0005432839033	28898	Economy	6200.00
0005434458830	28898	Economy	6200.00
0005435252809	28898	Economy	6200.00
0005435252804	28898	Economy	6200.00
0005434458721	28898	Economy	6200.00
0005434276026	8772	Business	145300.00
0005434276025	8772	Business	145300.00
0005435990671	8772	Business	145300.00
0005435990669	8772	Economy	48400.00
0005435990667	8772	Economy	48400.00
0005435990666	8772	Economy	48400.00
0005435990665	8772	Economy	48400.00
0005435990670	8772	Economy	48400.00
0005435990668	8772	Economy	48400.00
0005434275995	8772	Economy	48400.00
0005434276032	8772	Economy	48400.00
0005435990664	8772	Economy	48400.00
0005434276062	15711	Business	145300.00
0005435990587	15711	Business	145300.00
0005435990633	15711	Economy	48400.00
0005435990600	15711	Economy	48400.00
0005435990632	15711	Economy	53300.00
0005435990609	15711	Economy	48400.00
0005434276064	15711	Economy	48400.00
0005435990601	15711	Economy	48400.00
0005434276060	15711	Economy	48400.00
0005434276063	15711	Economy	48400.00
0005435990610	15711	Economy	48400.00
0005435990634	15711	Economy	48400.00
0005435990577	15711	Economy	48400.00
0005434276065	15711	Economy	48400.00
0005435990576	15711	Economy	48400.00
0005434276061	15711	Economy	48400.00
0005433468393	2093	Economy	13300.00
0005433468394	2093	Economy	13300.00
0005433468392	2093	Economy	12100.00
0005432909260	2093	Economy	12100.00
0005433468387	2093	Economy	12100.00
0005433468397	2093	Economy	12100.00
0005433468384	2093	Economy	12100.00
0005433468383	2093	Economy	12100.00
0005432909292	2093	Economy	12100.00
0005432909251	2093	Economy	12100.00
0005433468395	2093	Economy	12100.00
0005433468388	2093	Economy	12100.00
0005432909267	2093	Economy	12100.00
0005433468390	2093	Economy	12100.00
0005433468391	2093	Economy	12100.00
0005433468398	2093	Economy	12100.00
0005432909256	2093	Economy	12100.00
0005433468386	2093	Economy	12100.00
0005432909277	2093	Economy	12100.00
0005433468382	2093	Economy	12100.00
0005432909259	2093	Economy	12100.00
0005433468385	2093	Economy	12100.00
0005433468389	2093	Economy	12100.00
0005433468396	2093	Economy	12100.00
0005432909268	2093	Economy	12100.00
0005432909314	23849	Economy	13300.00
0005432909313	23849	Economy	13300.00
0005432909306	23849	Economy	13300.00
0005433468308	23849	Economy	12100.00
0005432909316	23849	Economy	12100.00
0005432909310	23849	Economy	12100.00
0005433468287	23849	Economy	12100.00
0005433468310	23849	Economy	12100.00
0005433468359	23849	Economy	12100.00
0005433468301	23849	Economy	12100.00
0005433468297	23849	Economy	12100.00
0005433468292	23849	Economy	12100.00
0005433468313	23849	Economy	12100.00
0005433468335	23849	Economy	12100.00
0005433468324	23849	Economy	12100.00
0005432909305	23849	Economy	12100.00
0005433468291	23849	Economy	12100.00
0005433468306	23849	Economy	12100.00
0005433468299	23849	Economy	12100.00
0005433468302	23849	Economy	12100.00
0005433468317	23849	Economy	12100.00
0005433468329	23849	Economy	12100.00
0005433468325	23849	Economy	12100.00
0005433468282	23849	Economy	12100.00
0005433468285	23849	Economy	12100.00
0005432909309	23849	Economy	12100.00
0005433468307	23849	Economy	12100.00
0005433468283	23849	Economy	12100.00
0005433468271	23849	Economy	12100.00
0005432909319	23849	Economy	12100.00
0005432909311	23849	Economy	12100.00
0005432909308	23849	Economy	12100.00
0005433468296	23849	Economy	12100.00
0005432909317	23849	Economy	12100.00
0005433468303	23849	Economy	12100.00
0005433468322	23849	Economy	12100.00
0005432909315	23849	Economy	12100.00
0005432909312	23849	Economy	12100.00
0005432909318	23849	Economy	12100.00
0005433468281	23849	Economy	12100.00
0005433468312	23849	Economy	12100.00
0005433468272	23849	Economy	12100.00
0005433468333	23849	Economy	12100.00
0005432909307	23849	Economy	12100.00
0005433468305	23849	Economy	12100.00
0005433468298	23849	Economy	12100.00
0005433468358	23849	Economy	12100.00
0005432909320	23849	Economy	12100.00
0005433468334	23849	Economy	12100.00
0005432360655	6408	Business	36600.00
0005432360646	6408	Business	36600.00
0005435177126	6408	Business	36600.00
0005435177042	6408	Business	36600.00
0005435490222	6408	Business	36600.00
0005435177003	6408	Business	36600.00
0005432360662	6408	Business	36600.00
0005432360660	6408	Business	36600.00
0005432360656	6408	Business	36600.00
0005434149702	6408	Business	36600.00
0005432062263	6408	Business	36600.00
0005432336107	6408	Business	36600.00
0005432336110	6408	Economy	12200.00
0005432360650	6408	Economy	12200.00
0005432360665	6408	Economy	12200.00
0005432360684	6408	Economy	12200.00
0005435177146	6408	Economy	12200.00
0005435176972	6408	Economy	12200.00
0005435176979	6408	Economy	12200.00
0005432360667	6408	Economy	12200.00
0005435177047	6408	Economy	12200.00
0005432360680	6408	Economy	12200.00
0005432360679	6408	Economy	12200.00
0005432336102	6408	Economy	12200.00
0005435177067	6408	Economy	12200.00
0005432336109	6408	Economy	12200.00
0005432336106	6408	Economy	12200.00
0005432062260	6408	Economy	12200.00
0005435177120	6408	Economy	12200.00
0005432360678	6408	Economy	12200.00
0005434149689	6408	Economy	12200.00
0005432360676	6408	Economy	12200.00
0005432360649	6408	Economy	12200.00
0005432360675	6408	Economy	12200.00
0005435177082	6408	Economy	12200.00
0005434149629	6408	Economy	12200.00
0005435177145	6408	Economy	12200.00
0005432336113	6408	Economy	12200.00
0005432363434	6408	Economy	12200.00
0005432360670	6408	Economy	12200.00
0005432360659	6408	Economy	12200.00
0005432360651	6408	Economy	12200.00
0005435177004	6408	Economy	12200.00
0005432360654	6408	Economy	12200.00
0005434149688	6408	Economy	12200.00
0005435177089	6408	Economy	12200.00
0005435177026	6408	Economy	13400.00
0005432363436	6408	Economy	13400.00
0005432360641	6408	Economy	13400.00
0005432360685	6408	Economy	13400.00
0005435176977	6408	Economy	13400.00
0005432062262	6408	Economy	12200.00
0005435176939	6408	Economy	12200.00
0005435177168	6408	Economy	12200.00
0005432360647	6408	Economy	12200.00
0005434149699	6408	Economy	12200.00
0005432336105	6408	Economy	12200.00
0005432336111	6408	Economy	12200.00
0005435177051	6408	Economy	12200.00
0005432360671	6408	Economy	12200.00
0005434149678	6408	Economy	12200.00
0005435176978	6408	Economy	12200.00
0005434149694	6408	Economy	12200.00
0005432336104	6408	Economy	12200.00
0005435177048	6408	Economy	12200.00
0005432360686	6408	Economy	12200.00
0005435177107	6408	Economy	12200.00
0005432360657	6408	Economy	12200.00
0005432336112	6408	Economy	12200.00
0005435177121	6408	Economy	12200.00
0005432360644	6408	Economy	12200.00
0005432360645	6408	Economy	12200.00
0005435177081	6408	Economy	12200.00
0005435177153	6408	Economy	12200.00
0005432360681	6408	Economy	12200.00
0005434149693	6408	Economy	12200.00
0005432360663	6408	Economy	12200.00
0005432062261	6408	Economy	12200.00
0005432336103	6408	Economy	12200.00
0005435177060	6408	Economy	12200.00
0005432360682	6408	Economy	12200.00
0005435723040	6408	Economy	12200.00
0005432360677	6408	Economy	12200.00
0005432360653	6408	Economy	12200.00
0005434149672	6408	Economy	12200.00
0005432360643	6408	Economy	12200.00
0005432363437	6408	Economy	12200.00
0005432360661	6408	Economy	12200.00
0005432360673	6408	Economy	12200.00
0005435177021	6408	Economy	12200.00
0005432336114	6408	Economy	12200.00
0005432062264	6408	Economy	12200.00
0005434149685	6408	Economy	12200.00
0005434149718	6408	Economy	12200.00
0005432363435	6408	Economy	12200.00
0005432360639	6408	Economy	12200.00
0005435177058	6408	Economy	12200.00
0005432360642	6408	Economy	12200.00
0005432360658	6408	Economy	12200.00
0005435177049	6408	Economy	12200.00
0005435177050	6408	Economy	12200.00
0005432360668	6408	Economy	12200.00
0005435177062	6408	Economy	12200.00
0005432360664	6408	Economy	12200.00
0005432360648	6408	Economy	12200.00
0005432360683	6408	Economy	12200.00
0005432360672	6408	Economy	12200.00
0005434149703	6408	Economy	12200.00
0005432360666	6408	Economy	12200.00
0005432336108	6408	Economy	12200.00
0005432360652	6408	Economy	12200.00
0005435177022	6408	Economy	12200.00
0005432360674	6408	Economy	12200.00
0005432360640	6408	Economy	12200.00
0005432360669	6408	Economy	12200.00
0005432336063	21031	Business	36600.00
0005432360128	21031	Business	36600.00
0005435177255	21031	Business	36600.00
0005435490256	21031	Business	36600.00
0005432360183	21031	Business	36600.00
0005435177241	21031	Business	36600.00
0005435177259	21031	Business	36600.00
0005432360200	21031	Business	36600.00
0005434149808	21031	Business	36600.00
0005432052766	21031	Business	36600.00
0005432360165	21031	Business	36600.00
0005434149800	21031	Economy	12200.00
0005432360140	21031	Economy	12200.00
0005435723060	21031	Economy	12200.00
0005432360356	21031	Economy	12200.00
0005434149797	21031	Economy	12200.00
0005435490253	21031	Economy	12200.00
0005435177236	21031	Economy	12200.00
0005434149799	21031	Economy	12200.00
0005435177239	21031	Economy	12200.00
0005434149806	21031	Economy	12200.00
0005432360117	21031	Economy	12200.00
0005432336013	21031	Economy	12200.00
0005435177245	21031	Economy	12200.00
0005434149804	21031	Economy	12200.00
0005435177252	21031	Economy	12200.00
0005432360139	21031	Economy	12200.00
0005432360172	21031	Economy	12200.00
0005432360439	21031	Economy	12200.00
0005435177233	21031	Economy	12200.00
0005434149801	21031	Economy	12200.00
0005432336012	21031	Economy	12200.00
0005435177234	21031	Economy	12200.00
0005432336048	21031	Economy	12200.00
0005435177260	21031	Economy	12200.00
0005432360197	21031	Economy	12200.00
0005435177246	21031	Economy	12200.00
0005432360173	21031	Economy	12200.00
0005432336009	21031	Economy	12200.00
0005432360177	21031	Economy	12200.00
0005432360230	21031	Economy	12200.00
0005432360312	21031	Economy	13400.00
0005435177247	21031	Economy	12200.00
0005435177250	21031	Economy	13400.00
0005435177238	21031	Economy	13400.00
0005434149798	21031	Economy	13400.00
0005435177257	21031	Economy	13400.00
0005432360355	21031	Economy	12200.00
0005432360063	21031	Economy	12200.00
0005434149802	21031	Economy	12200.00
0005435490255	21031	Economy	12200.00
0005432359964	21031	Economy	12200.00
0005432360166	21031	Economy	12200.00
0005435177237	21031	Economy	12200.00
0005434149807	21031	Economy	12200.00
0005432360261	21031	Economy	12200.00
0005432360036	21031	Economy	12200.00
0005432052763	21031	Economy	12200.00
0005432360234	21031	Economy	12200.00
0005432360292	21031	Economy	12200.00
0005435177249	21031	Economy	12200.00
0005432360317	21031	Economy	12200.00
0005432360222	21031	Economy	12200.00
0005435177242	21031	Economy	12200.00
0005435177235	21031	Economy	12200.00
0005432360201	21031	Economy	12200.00
0005432360296	21031	Economy	12200.00
0005432360035	21031	Economy	12200.00
0005432360175	21031	Economy	12200.00
0005432363412	21031	Economy	12200.00
0005432360214	21031	Economy	12200.00
0005432360061	21031	Economy	12200.00
0005432360259	21031	Economy	12200.00
0005432360119	21031	Economy	12200.00
0005435490257	21031	Economy	12200.00
0005435177240	21031	Economy	12200.00
0005432360224	21031	Economy	12200.00
0005432360167	21031	Economy	12200.00
0005432360316	21031	Economy	12200.00
0005435177243	21031	Economy	12200.00
0005432360185	21031	Economy	12200.00
0005435177244	21031	Economy	12200.00
0005432360209	21031	Economy	12200.00
0005432363417	21031	Economy	12200.00
0005435177248	21031	Economy	12200.00
0005432052765	21031	Economy	12200.00
0005435723058	21031	Economy	12200.00
0005432052764	21031	Economy	12200.00
0005435177251	21031	Economy	12200.00
0005432360252	21031	Economy	12200.00
0005435177256	21031	Economy	12200.00
0005435177258	21031	Economy	12200.00
0005434149805	21031	Economy	12200.00
0005432360215	21031	Economy	12200.00
0005435723059	21031	Economy	12200.00
0005432360032	21031	Economy	12200.00
0005432336010	21031	Economy	12200.00
0005432360269	21031	Economy	12200.00
0005435490254	21031	Economy	12200.00
0005432360080	21031	Economy	12200.00
0005432359965	21031	Economy	12200.00
0005434149803	21031	Economy	12200.00
0005432360361	21031	Economy	12200.00
0005432335979	21031	Economy	12200.00
0005432360238	21031	Economy	12200.00
0005432360389	21031	Economy	12200.00
0005432360179	21031	Economy	12200.00
0005435177253	21031	Economy	12200.00
0005432360060	21031	Economy	12200.00
0005432360176	21031	Economy	12200.00
0005435177254	21031	Economy	12200.00
0005432360334	21031	Economy	12200.00
0005434448298	17704	Economy	3400.00
0005434458819	17704	Economy	3400.00
0005434458814	17704	Economy	3400.00
0005434186218	17704	Economy	3400.00
0005434448297	17704	Economy	3100.00
0005434186217	17704	Economy	3100.00
0005434458833	17704	Economy	3100.00
0005434458807	17704	Economy	3100.00
0005434458763	17704	Economy	3100.00
0005434458736	17704	Economy	3100.00
0005434458766	17704	Economy	3100.00
0005434458798	17704	Economy	3100.00
0005434186216	17704	Economy	3100.00
0005434458852	17704	Economy	3100.00
0005434458764	17704	Economy	3100.00
0005434458794	17704	Economy	3100.00
0005434461639	17704	Economy	3100.00
0005434458797	17704	Economy	3100.00
0005434458832	17704	Economy	3100.00
0005434458820	17704	Economy	3100.00
0005434458854	17704	Economy	3100.00
0005434458793	17704	Economy	3100.00
0005434458792	17704	Economy	3100.00
0005434458742	17704	Economy	3100.00
0005434448299	17704	Economy	3100.00
0005434458829	17704	Economy	3100.00
0005434458755	17704	Economy	3100.00
0005434458753	17704	Economy	3100.00
0005434458853	17704	Economy	3100.00
0005434458735	17704	Economy	3100.00
0005434458741	17704	Economy	3100.00
0005434458808	17704	Economy	3100.00
0005434458734	17704	Economy	3100.00
0005434458828	17704	Economy	3100.00
0005434458733	17704	Economy	3100.00
0005434458815	17704	Economy	3100.00
0005434458777	17704	Economy	3100.00
0005434458690	17704	Economy	3100.00
0005434458767	17704	Economy	3100.00
0005434458754	17704	Economy	3100.00
0005434458818	17704	Economy	3100.00
0005434458809	17704	Economy	3100.00
0005434458858	17704	Economy	3100.00
0005434458926	29097	Economy	3400.00
0005434463941	29097	Economy	3400.00
0005434458933	29097	Economy	3400.00
0005434458944	29097	Economy	3100.00
0005434458927	29097	Economy	3100.00
0005434462803	29097	Economy	3100.00
0005434463940	29097	Economy	3100.00
0005434458938	29097	Economy	3100.00
0005434458945	29097	Economy	3100.00
0005434458928	29097	Economy	3100.00
0005434458941	29097	Economy	3100.00
0005434458935	29097	Economy	3100.00
0005434186203	29097	Economy	3100.00
0005434448332	29097	Economy	3100.00
0005434458930	29097	Economy	3100.00
0005434458929	29097	Economy	3100.00
0005434462802	29097	Economy	3100.00
0005434458940	29097	Economy	3100.00
0005434186200	29097	Economy	3100.00
0005434458942	29097	Economy	3100.00
0005434458931	29097	Economy	3100.00
0005434458924	29097	Economy	3100.00
0005434458937	29097	Economy	3100.00
0005434458925	29097	Economy	3100.00
0005434458946	29097	Economy	3100.00
0005434458943	29097	Economy	3100.00
0005434186180	29097	Economy	3100.00
0005434458936	29097	Economy	3100.00
0005434458939	29097	Economy	3100.00
0005434458932	29097	Economy	3100.00
0005434448334	29097	Economy	3100.00
0005434448333	29097	Economy	3100.00
0005434458934	29097	Economy	3100.00
0005432604557	21424	Economy	7300.00
0005432604565	21424	Economy	7300.00
0005432604549	21424	Economy	7300.00
0005432604547	21424	Economy	7300.00
0005432604571	21424	Economy	6600.00
0005432604575	21424	Economy	6600.00
0005432604564	21424	Economy	6600.00
0005432604558	21424	Economy	6600.00
0005432604542	21424	Economy	6600.00
0005432604544	21424	Economy	6600.00
0005432604554	21424	Economy	6600.00
0005432604550	21424	Economy	6600.00
0005432604561	21424	Economy	6600.00
0005432604567	21424	Economy	6600.00
0005432604559	21424	Economy	6600.00
0005432604560	21424	Economy	6600.00
0005432604540	21424	Economy	6600.00
0005432604551	21424	Economy	6600.00
0005432604576	21424	Economy	6600.00
0005432604538	21424	Economy	6600.00
0005432604534	21424	Economy	6600.00
0005432604566	21424	Economy	6600.00
0005432604546	21424	Economy	6600.00
0005432604548	21424	Economy	6600.00
0005432604537	21424	Economy	6600.00
0005432604543	21424	Economy	6600.00
0005432604574	21424	Economy	6600.00
0005432604553	21424	Economy	6600.00
0005432604555	21424	Economy	6600.00
0005432604536	21424	Economy	6600.00
0005432604556	21424	Economy	6600.00
0005432604535	21424	Economy	6600.00
0005432604562	21424	Economy	6600.00
0005432604552	21424	Economy	6600.00
0005432604568	21424	Economy	6600.00
0005432604563	21424	Economy	6600.00
0005432604572	21424	Economy	6600.00
0005432604545	21424	Economy	6600.00
0005432604573	21424	Economy	6600.00
0005432604541	21424	Economy	6600.00
0005432604569	21424	Economy	6600.00
0005432604570	21424	Economy	6600.00
0005432604539	21424	Economy	6600.00
0005432604238	31701	Economy	7300.00
0005432604057	31701	Economy	7300.00
0005435221063	31701	Economy	6600.00
0005432604362	31701	Economy	6600.00
0005432604305	31701	Economy	6600.00
0005435221523	31701	Economy	6600.00
0005432604198	31701	Economy	6600.00
0005432604249	31701	Economy	6600.00
0005435221522	31701	Economy	6600.00
0005432604178	31701	Economy	6600.00
0005432604272	31701	Economy	6600.00
0005432604261	31701	Economy	6600.00
0005432604136	31701	Economy	6600.00
0005432604135	31701	Economy	6600.00
0005432604205	31701	Economy	6600.00
0005432604012	31701	Economy	6600.00
0005432604175	31701	Economy	6600.00
0005432604361	31701	Economy	6600.00
0005435221062	31701	Economy	6600.00
0005432604204	31701	Economy	6600.00
0005432604199	31701	Economy	6600.00
0005432604368	31701	Economy	6600.00
0005432604230	31701	Economy	6600.00
0005432604071	31701	Economy	6600.00
0005432604351	31701	Economy	6600.00
0005432604206	31701	Economy	6600.00
0005432604129	31701	Economy	6600.00
0005432604257	31701	Economy	6600.00
0005432604262	31701	Economy	6600.00
0005432604298	31701	Economy	6600.00
0005432604241	31701	Economy	6600.00
0005432604128	31701	Economy	6600.00
0005432604317	31701	Economy	6600.00
0005432604200	31701	Economy	6600.00
0005432604158	31701	Economy	6600.00
0005433293300	29601	Economy	19500.00
0005433293293	29601	Economy	17800.00
0005433293287	29601	Economy	17800.00
0005433293296	29601	Economy	17800.00
0005433293297	29601	Economy	17800.00
0005433293295	29601	Economy	17800.00
0005433293291	29601	Economy	17800.00
0005433293288	29601	Economy	17800.00
0005433293289	29601	Economy	17800.00
0005433293286	29601	Economy	17800.00
0005433293298	29601	Economy	17800.00
0005433293299	29601	Economy	17800.00
0005433293290	29601	Economy	17800.00
0005433293292	29601	Economy	17800.00
0005433293294	29601	Economy	17800.00
0005433473311	6689	Economy	14000.00
0005435257222	6689	Economy	14000.00
0005433473313	6689	Economy	12700.00
0005433473318	6689	Economy	12700.00
0005433473314	6689	Economy	12700.00
0005435257209	6689	Economy	12700.00
0005435257232	6689	Economy	12700.00
0005433473323	6689	Economy	12700.00
0005433473310	6689	Economy	12700.00
0005433473316	6689	Economy	12700.00
0005433473321	6689	Economy	12700.00
0005433473325	6689	Economy	12700.00
0005433473328	6689	Economy	12700.00
0005433473309	6689	Economy	12700.00
0005433473317	6689	Economy	12700.00
0005435257241	6689	Economy	12700.00
0005435257240	6689	Economy	12700.00
0005433473324	6689	Economy	12700.00
0005435257242	6689	Economy	12700.00
0005433473315	6689	Economy	12700.00
0005433473320	6689	Economy	12700.00
0005435257210	6689	Economy	12700.00
0005433473312	6689	Economy	12700.00
0005433473326	6689	Economy	12700.00
0005433473327	6689	Economy	12700.00
0005435257212	6689	Economy	12700.00
0005433473322	6689	Economy	12700.00
0005433473319	6689	Economy	12700.00
0005433473216	23898	Economy	14000.00
0005435257269	23898	Economy	14000.00
0005433473195	23898	Economy	14000.00
0005433473237	23898	Economy	12700.00
0005435257268	23898	Economy	12700.00
0005433473196	23898	Economy	12700.00
0005435257273	23898	Economy	12700.00
0005433473227	23898	Economy	12700.00
0005435257261	23898	Economy	12700.00
0005433473226	23898	Economy	12700.00
0005433473250	23898	Economy	12700.00
0005433473305	23898	Economy	12700.00
0005433473198	23898	Economy	12700.00
0005433473219	23898	Economy	12700.00
0005435257266	23898	Economy	12700.00
0005435257265	23898	Economy	12700.00
0005435257271	23898	Economy	12700.00
0005433473218	23898	Economy	12700.00
0005435257274	23898	Economy	12700.00
0005435257270	23898	Economy	12700.00
0005435257258	23898	Economy	12700.00
0005433473206	23898	Economy	12700.00
0005435257267	23898	Economy	12700.00
0005433473203	23898	Economy	12700.00
0005435257263	23898	Economy	12700.00
0005435257259	23898	Economy	12700.00
0005433473260	23898	Economy	12700.00
0005433473215	23898	Economy	12700.00
0005433473217	23898	Economy	12700.00
0005433473213	23898	Economy	12700.00
0005435257260	23898	Economy	12700.00
0005433473238	23898	Economy	12700.00
0005433473232	23898	Economy	12700.00
0005433473228	23898	Economy	12700.00
0005435257262	23898	Economy	12700.00
0005433473306	23898	Economy	12700.00
0005433473204	23898	Economy	12700.00
0005433473197	23898	Economy	12700.00
0005433473185	23898	Economy	12700.00
0005435257264	23898	Economy	12700.00
0005433473194	23898	Economy	12700.00
0005435257272	23898	Economy	12700.00
0005433473221	23898	Economy	12700.00
0005435904899	18836	Economy	6600.00
0005435904898	18836	Economy	6600.00
0005434606814	18836	Economy	6600.00
0005434606846	22326	Economy	6600.00
0005435904705	22326	Economy	6600.00
0005434606847	22326	Economy	6600.00
0005434604916	22326	Economy	6600.00
0005434604915	22326	Economy	6600.00
0005434606845	22326	Economy	6600.00
0005434604917	22326	Economy	6600.00
0005434602911	3842	Economy	24900.00
0005434522465	3842	Economy	22600.00
0005434522462	3842	Economy	22600.00
0005434602915	3842	Economy	22600.00
0005434522468	3842	Economy	22600.00
0005434522463	3842	Economy	22600.00
0005434602914	3842	Economy	22600.00
0005434522464	3842	Economy	22600.00
0005434522469	3842	Economy	22600.00
0005434522461	3842	Economy	22600.00
0005434522467	3842	Economy	22600.00
0005434522466	3842	Economy	22600.00
0005435904393	3842	Economy	22600.00
0005434602912	3842	Economy	22600.00
0005435904398	3842	Economy	22600.00
0005434602916	3842	Economy	22600.00
0005434522460	3842	Economy	22600.00
0005434522470	3842	Economy	22600.00
0005435904391	3842	Economy	22600.00
0005435904403	3842	Economy	22600.00
0005434602913	3842	Economy	22600.00
0005435904397	3842	Economy	22600.00
0005434522435	19046	Economy	24900.00
0005434522434	19046	Economy	24900.00
0005434522432	19046	Economy	24900.00
0005434604875	19046	Economy	24900.00
0005434604880	19046	Economy	22600.00
0005434522439	19046	Economy	22600.00
0005434522442	19046	Economy	22600.00
0005435904418	19046	Economy	22600.00
0005434604883	19046	Economy	22600.00
0005434522428	19046	Economy	22600.00
0005434602894	19046	Economy	22600.00
0005434604879	19046	Economy	22600.00
0005435904419	19046	Economy	22600.00
0005434602891	19046	Economy	22600.00
0005434604891	19046	Economy	22600.00
0005435904421	19046	Economy	22600.00
0005434522443	19046	Economy	22600.00
0005434602882	19046	Economy	22600.00
0005434604885	19046	Economy	22600.00
0005434602888	19046	Economy	22600.00
0005434602883	19046	Economy	22600.00
0005434602897	19046	Economy	22600.00
0005434522429	19046	Economy	22600.00
0005434602886	19046	Economy	22600.00
0005434604894	19046	Economy	22600.00
0005434522437	19046	Economy	22600.00
0005434522436	19046	Economy	22600.00
0005434604876	19046	Economy	22600.00
0005435904420	19046	Economy	22600.00
0005434522438	19046	Economy	22600.00
0005434522433	19046	Economy	22600.00
0005434604884	19046	Economy	22600.00
0005434602898	19046	Economy	22600.00
0005434604878	19046	Economy	22600.00
0005435904422	19046	Economy	22600.00
0005434604877	19046	Economy	22600.00
0005434604887	19046	Economy	22600.00
0005434522424	19046	Economy	22600.00
0005432747776	385	Business	44500.00
0005432747785	385	Business	44500.00
0005432891026	385	Business	44500.00
0005432890973	385	Business	44500.00
0005432747778	385	Business	44500.00
0005432891015	385	Business	44500.00
0005432747788	385	Business	44500.00
0005432747774	385	Business	44500.00
0005432747787	385	Business	44500.00
0005432891000	385	Business	44500.00
0005432751542	385	Business	44500.00
0005432747791	385	Business	44500.00
0005432890987	385	Economy	14800.00
0005432220027	385	Economy	14800.00
0005432747809	385	Economy	14800.00
0005432747798	385	Economy	14800.00
0005432747777	385	Economy	14800.00
0005432747780	385	Economy	14800.00
0005432747807	385	Economy	14800.00
0005432753318	385	Economy	14800.00
0005432891004	385	Economy	14800.00
0005432890924	385	Economy	14800.00
0005432747792	385	Economy	16300.00
0005432747781	385	Economy	16300.00
0005432890925	385	Economy	16300.00
0005432747806	385	Economy	16300.00
0005432220028	385	Economy	16300.00
0005432890907	385	Economy	14800.00
0005432747782	385	Economy	14800.00
0005432890918	385	Economy	14800.00
0005433293229	385	Economy	14800.00
0005432891005	385	Economy	14800.00
0005432890943	385	Economy	14800.00
0005432890984	385	Economy	14800.00
0005432749798	385	Economy	14800.00
0005432890962	385	Economy	14800.00
0005432749796	385	Economy	14800.00
0005432890919	385	Economy	14800.00
0005432890946	385	Economy	14800.00
0005432220029	385	Economy	14800.00
0005432220026	385	Economy	14800.00
0005432747804	385	Economy	14800.00
0005432753317	385	Economy	14800.00
0005432890974	385	Economy	14800.00
0005432890905	385	Economy	14800.00
0005432891040	385	Economy	14800.00
0005432891001	385	Economy	14800.00
0005432747800	385	Economy	14800.00
0005432890948	385	Economy	14800.00
0005432747789	385	Economy	14800.00
0005432890961	385	Economy	14800.00
0005432747790	385	Economy	14800.00
0005432747775	385	Economy	14800.00
0005432747801	385	Economy	14800.00
0005432890897	385	Economy	14800.00
0005432753320	385	Economy	14800.00
0005432747773	385	Economy	14800.00
0005432747786	385	Economy	14800.00
0005432747795	385	Economy	14800.00
0005432890938	385	Economy	14800.00
0005432747779	385	Economy	14800.00
0005432747793	385	Economy	14800.00
0005432751543	385	Economy	14800.00
0005432890939	385	Economy	14800.00
0005432220030	385	Economy	14800.00
0005432891016	385	Economy	14800.00
0005432747797	385	Economy	14800.00
0005432891007	385	Economy	14800.00
0005432890940	385	Economy	14800.00
0005432890942	385	Economy	14800.00
0005432747772	385	Economy	14800.00
0005432890947	385	Economy	14800.00
0005432890900	385	Economy	14800.00
0005432747805	385	Economy	14800.00
0005432890998	385	Economy	14800.00
0005432891027	385	Economy	14800.00
0005432751544	385	Economy	14800.00
0005433293228	385	Economy	14800.00
0005432890991	385	Economy	14800.00
0005432747784	385	Economy	14800.00
0005432749797	385	Economy	14800.00
0005432891003	385	Economy	14800.00
0005432753319	385	Economy	14800.00
0005432890996	385	Economy	14800.00
0005432747810	385	Economy	14800.00
0005432890941	385	Economy	14800.00
0005432747803	385	Economy	14800.00
0005432747794	385	Economy	14800.00
0005432890988	385	Economy	14800.00
0005432747808	385	Economy	14800.00
0005432747783	385	Economy	14800.00
0005432747796	385	Economy	14800.00
0005432890906	385	Economy	14800.00
0005432747799	385	Economy	14800.00
0005432747802	385	Economy	14800.00
0005432890899	385	Economy	14800.00
0005432751545	385	Economy	14800.00
0005432747461	12068	Business	44500.00
0005432747553	12068	Business	44500.00
0005432747572	12068	Business	44500.00
0005432747262	12068	Business	44500.00
0005432747482	12068	Business	44500.00
0005432747528	12068	Business	44500.00
0005432891143	12068	Business	44500.00
0005432891144	12068	Business	44500.00
0005432891133	12068	Economy	14800.00
0005434153539	12068	Economy	14800.00
0005432747347	12068	Economy	14800.00
0005432753287	12068	Economy	14800.00
0005432747436	12068	Economy	14800.00
0005432891132	12068	Economy	14800.00
0005432747485	12068	Economy	14800.00
0005432747563	12068	Economy	14800.00
0005432747486	12068	Economy	14800.00
0005432891146	12068	Economy	16300.00
0005432747487	12068	Economy	16300.00
0005433875391	12068	Economy	16300.00
0005432747362	12068	Economy	14800.00
0005433875392	12068	Economy	14800.00
0005432891147	12068	Economy	14800.00
0005432891145	12068	Economy	14800.00
0005432891148	12068	Economy	14800.00
0005432891139	12068	Economy	14800.00
0005432747452	12068	Economy	14800.00
0005432756841	12068	Economy	14800.00
0005432891136	12068	Economy	14800.00
0005432214817	12068	Economy	14800.00
0005432747494	12068	Economy	14800.00
0005432756832	12068	Economy	14800.00
0005432747463	12068	Economy	14800.00
0005432891138	12068	Economy	14800.00
0005432747522	12068	Economy	14800.00
0005432747464	12068	Economy	14800.00
0005432747479	12068	Economy	14800.00
0005432753290	12068	Economy	14800.00
0005432747453	12068	Economy	14800.00
0005432891131	12068	Economy	14800.00
0005432747495	12068	Economy	14800.00
0005434153540	12068	Economy	14800.00
0005435627118	12068	Economy	14800.00
0005432756838	12068	Economy	14800.00
0005432747552	12068	Economy	14800.00
0005432747424	12068	Economy	14800.00
0005432756833	12068	Economy	14800.00
0005432747496	12068	Economy	14800.00
0005434153541	12068	Economy	14800.00
0005432891142	12068	Economy	14800.00
0005432891140	12068	Economy	14800.00
0005432747394	12068	Economy	14800.00
0005432756831	12068	Economy	14800.00
0005432747620	12068	Economy	14800.00
0005432753308	12068	Economy	14800.00
0005432753286	12068	Economy	14800.00
0005432756839	12068	Economy	14800.00
0005432753293	12068	Economy	14800.00
0005432214818	12068	Economy	14800.00
0005432891137	12068	Economy	14800.00
0005432747529	12068	Economy	14800.00
0005432747425	12068	Economy	14800.00
0005432747530	12068	Economy	14800.00
0005432756813	12068	Economy	14800.00
0005432891134	12068	Economy	14800.00
0005432747476	12068	Economy	14800.00
0005432747564	12068	Economy	14800.00
0005432891141	12068	Economy	14800.00
0005432747478	12068	Economy	14800.00
0005432891149	12068	Economy	14800.00
0005432747263	12068	Economy	14800.00
0005432891135	12068	Economy	14800.00
0005433525101	18975	Economy	28200.00
0005432927980	18975	Economy	28200.00
0005433533326	18975	Economy	25700.00
0005433531313	18975	Economy	25700.00
0005433533330	18975	Economy	25700.00
0005433531311	18975	Economy	25700.00
0005433525094	18975	Economy	25700.00
0005432927953	18975	Economy	25700.00
0005433533327	18975	Economy	25700.00
0005433525100	18975	Economy	25700.00
0005432927979	18975	Economy	25700.00
0005433525097	18975	Economy	25700.00
0005432927959	18975	Economy	25700.00
0005433525096	18975	Economy	25700.00
0005433525099	18975	Economy	25700.00
0005433525095	18975	Economy	25700.00
0005433531312	18975	Economy	25700.00
0005433533329	18975	Economy	25700.00
0005433525093	18975	Economy	25700.00
0005433533328	18975	Economy	25700.00
0005432927958	18975	Economy	25700.00
0005433531314	18975	Economy	25700.00
0005432927974	18975	Economy	25700.00
0005433525098	18975	Economy	25700.00
0005432928019	32466	Economy	28200.00
0005432928021	32466	Economy	28200.00
0005433524996	32466	Economy	25700.00
0005432928018	32466	Economy	25700.00
0005433527230	32466	Economy	25700.00
0005433525019	32466	Economy	25700.00
0005433525020	32466	Economy	25700.00
0005433527229	32466	Economy	25700.00
0005433525021	32466	Economy	25700.00
0005433525022	32466	Economy	25700.00
0005432928022	32466	Economy	25700.00
0005433525001	32466	Economy	25700.00
0005433527245	32466	Economy	25700.00
0005433527251	32466	Economy	25700.00
0005432928020	32466	Economy	25700.00
0005433531286	32466	Economy	25700.00
0005433527246	32466	Economy	25700.00
0005433525002	32466	Economy	25700.00
0005433527239	32466	Economy	25700.00
0005433524968	32466	Economy	25700.00
0005433527240	32466	Economy	25700.00
0005435372949	5299	Business	84000.00
0005435735130	5299	Business	84000.00
0005435735138	5299	Business	84000.00
0005434824299	5299	Business	84000.00
0005434824350	5299	Business	84000.00
0005434824381	5299	Business	84000.00
0005434558332	5299	Business	84000.00
0005435150111	5299	Business	84000.00
0005434824390	5299	Business	84000.00
0005435372961	5299	Business	84000.00
0005432121415	5299	Business	84000.00
0005434831176	5299	Business	84000.00
0005434824323	5299	Business	84000.00
0005434824401	5299	Business	84000.00
0005434824306	5299	Business	84000.00
0005434824402	5299	Business	84000.00
0005435373166	5299	Business	84000.00
0005434824366	5299	Business	84000.00
0005435373138	5299	Business	84000.00
0005432121427	5299	Business	84000.00
0005434828711	5299	Comfort	47600.00
0005435372992	5299	Comfort	47600.00
0005432121419	5299	Comfort	47600.00
0005434824356	5299	Comfort	47600.00
0005435179691	5299	Comfort	47600.00
0005435372943	5299	Comfort	47600.00
0005434824314	5299	Comfort	47600.00
0005434824385	5299	Comfort	47600.00
0005435150114	5299	Comfort	47600.00
0005435373096	5299	Comfort	47600.00
0005434824426	5299	Comfort	47600.00
0005434824325	5299	Comfort	47600.00
0005435372974	5299	Comfort	47600.00
0005434824346	5299	Comfort	47600.00
0005434824335	5299	Comfort	47600.00
0005435661923	5299	Comfort	47600.00
0005434558331	5299	Comfort	47600.00
0005434824413	5299	Comfort	47600.00
0005435661926	5299	Comfort	47600.00
0005435372975	5299	Comfort	47600.00
0005434824311	5299	Comfort	47600.00
0005434824347	5299	Comfort	47600.00
0005435386561	5299	Comfort	47600.00
0005434824359	5299	Comfort	47600.00
0005435372999	5299	Comfort	47600.00
0005434824375	5299	Comfort	47600.00
0005434664973	5299	Comfort	47600.00
0005434558329	5299	Comfort	47600.00
0005434824362	5299	Comfort	47600.00
0005435386548	5299	Comfort	47600.00
0005434824409	5299	Comfort	47600.00
0005434824319	5299	Comfort	47600.00
0005434824379	5299	Comfort	47600.00
0005434824397	5299	Comfort	47600.00
0005435373176	5299	Comfort	47600.00
0005434824361	5299	Comfort	47600.00
0005434824393	5299	Comfort	47600.00
0005435373148	5299	Comfort	47600.00
0005434558333	5299	Economy	28000.00
0005432823437	5299	Economy	28000.00
0005434828712	5299	Economy	28000.00
0005435372929	5299	Economy	28000.00
0005435373313	5299	Economy	28000.00
0005435372876	5299	Economy	28000.00
0005434824406	5299	Economy	28000.00
0005434558325	5299	Economy	28000.00
0005434824339	5299	Economy	28000.00
0005434824343	5299	Economy	28000.00
0005435373358	5299	Economy	28000.00
0005434824348	5299	Economy	28000.00
0005434824321	5299	Economy	28000.00
0005432121428	5299	Economy	28000.00
0005434824367	5299	Economy	28000.00
0005435299780	5299	Economy	28000.00
0005435373314	5299	Economy	28000.00
0005435373026	5299	Economy	28000.00
0005434824317	5299	Economy	28000.00
0005434831177	5299	Economy	28000.00
0005434824327	5299	Economy	28000.00
0005435373238	5299	Economy	28000.00
0005434824322	5299	Economy	28000.00
0005435373206	5299	Economy	28000.00
0005435373035	5299	Economy	28000.00
0005435373090	5299	Economy	28000.00
0005435150115	5299	Economy	28000.00
0005435372843	5299	Economy	28000.00
0005435373208	5299	Economy	28000.00
0005435150106	5299	Economy	28000.00
0005434824352	5299	Economy	28000.00
0005435735117	5299	Economy	28000.00
0005434824318	5299	Economy	28000.00
0005435372916	5299	Economy	28000.00
0005435372851	5299	Economy	28000.00
0005434824326	5299	Economy	28000.00
0005434824341	5299	Economy	28000.00
0005434824332	5299	Economy	28000.00
0005435373123	5299	Economy	28000.00
0005435373177	5299	Economy	28000.00
0005435373347	5299	Economy	28000.00
0005434824382	5299	Economy	28000.00
0005432121425	5299	Economy	28000.00
0005434824357	5299	Economy	28000.00
0005435735133	5299	Economy	28000.00
0005434824383	5299	Economy	30800.00
0005434824304	5299	Economy	28000.00
0005435372973	5299	Economy	30800.00
0005434824353	5299	Economy	28000.00
0005435386550	5299	Economy	30800.00
0005434824303	5299	Economy	28000.00
0005435373059	5299	Economy	28000.00
0005434824360	5299	Economy	28000.00
0005435373361	5299	Economy	30800.00
0005432121422	5299	Economy	30800.00
0005435372941	5299	Economy	30800.00
0005435372867	5299	Economy	28000.00
0005434824307	5299	Economy	28000.00
0005435373329	5299	Economy	28000.00
0005434824369	5299	Economy	28000.00
0005434824399	5299	Economy	28000.00
0005434824424	5299	Economy	28000.00
0005435661922	5299	Economy	28000.00
0005435372950	5299	Economy	28000.00
0005434824403	5299	Economy	28000.00
0005434824340	5299	Economy	28000.00
0005435373195	5299	Economy	28000.00
0005434824309	5299	Economy	28000.00
0005432121418	5299	Economy	28000.00
0005434824342	5299	Economy	28000.00
0005435372996	5299	Economy	28000.00
0005435373296	5299	Economy	28000.00
0005435178989	5299	Economy	28000.00
0005434824345	5299	Economy	28000.00
0005435373219	5299	Economy	28000.00
0005432121426	5299	Economy	28000.00
0005435373020	5299	Economy	28000.00
0005435373192	5299	Economy	28000.00
0005435299779	5299	Economy	28000.00
0005435735124	5299	Economy	28000.00
0005434824377	5299	Economy	28000.00
0005435150117	5299	Economy	28000.00
0005434824338	5299	Economy	28000.00
0005434831175	5299	Economy	28000.00
0005435150108	5299	Economy	28000.00
0005435150113	5299	Economy	28000.00
0005435299778	5299	Economy	28000.00
0005434824300	5299	Economy	28000.00
0005435373125	5299	Economy	28000.00
0005434664971	5299	Economy	28000.00
0005434558330	5299	Economy	28000.00
0005434824313	5299	Economy	28000.00
0005434824312	5299	Economy	28000.00
0005432121417	5299	Economy	28000.00
0005435373217	5299	Economy	28000.00
0005434824427	5299	Economy	28000.00
0005434824405	5299	Economy	28000.00
0005434824410	5299	Economy	28000.00
0005434664972	5299	Economy	28000.00
0005434824315	5299	Economy	28000.00
0005435150119	5299	Economy	28000.00
0005435735122	5299	Economy	28000.00
0005434824330	5299	Economy	28000.00
0005434824407	5299	Economy	28000.00
0005434824310	5299	Economy	28000.00
0005434824380	5299	Economy	28000.00
0005435735123	5299	Economy	28000.00
0005434824414	5299	Economy	28000.00
0005435373137	5299	Economy	28000.00
0005435373186	5299	Economy	28000.00
0005432121414	5299	Economy	28000.00
0005434824324	5299	Economy	28000.00
0005435373097	5299	Economy	28000.00
0005434824351	5299	Economy	28000.00
0005434824384	5299	Economy	28000.00
0005434824374	5299	Economy	28000.00
0005434824302	5299	Economy	28000.00
0005434824376	5299	Economy	28000.00
0005435372942	5299	Economy	28000.00
0005435372755	5299	Economy	28000.00
0005434824301	5299	Economy	28000.00
0005435372819	5299	Economy	28000.00
0005432396268	5299	Economy	28000.00
0005434824336	5299	Economy	28000.00
0005434824412	5299	Economy	28000.00
0005432121421	5299	Economy	28000.00
0005434824368	5299	Economy	28000.00
0005434824371	5299	Economy	28000.00
0005435373091	5299	Economy	28000.00
0005432394130	5299	Economy	28000.00
0005432394128	5299	Economy	28000.00
0005434824398	5299	Economy	28000.00
0005435373167	5299	Economy	28000.00
0005434824333	5299	Economy	28000.00
0005434831174	5299	Economy	28000.00
0005434558327	5299	Economy	28000.00
0005434824372	5299	Economy	28000.00
0005435150107	5299	Economy	28000.00
0005435150118	5299	Economy	28000.00
0005432396267	5299	Economy	30800.00
0005434824417	5299	Economy	30800.00
0005434824388	5299	Economy	30800.00
0005432121420	5299	Economy	30800.00
0005435373044	5299	Economy	28000.00
0005434824411	5299	Economy	28000.00
0005435373277	5299	Economy	28000.00
0005435150109	5299	Economy	28000.00
0005434824400	5299	Economy	28000.00
0005434824344	5299	Economy	28000.00
0005432396270	5299	Economy	28000.00
0005434824354	5299	Economy	28000.00
0005434824331	5299	Economy	28000.00
0005434824329	5299	Economy	28000.00
0005435373237	5299	Economy	28000.00
0005434558326	5299	Economy	28000.00
0005434824404	5299	Economy	28000.00
0005435373295	5299	Economy	28000.00
0005434824355	5299	Economy	28000.00
0005435373075	5299	Economy	28000.00
0005435661927	5299	Economy	28000.00
0005435299774	5299	Economy	28000.00
0005434824421	5299	Economy	28000.00
0005434558328	5299	Economy	28000.00
0005435373136	5299	Economy	28000.00
0005434824386	5299	Economy	28000.00
0005434824305	5299	Economy	28000.00
0005434824396	5299	Economy	28000.00
0005434824365	5299	Economy	28000.00
0005432394129	5299	Economy	28000.00
0005434824408	5299	Economy	28000.00
0005434824423	5299	Economy	28000.00
0005434824337	5299	Economy	28000.00
0005434824425	5299	Economy	28000.00
0005434824363	5299	Economy	28000.00
0005432121416	5299	Economy	28000.00
0005434824422	5299	Economy	28000.00
0005434824316	5299	Economy	28000.00
0005434824389	5299	Economy	28000.00
0005435373045	5299	Economy	28000.00
0005434824419	5299	Economy	28000.00
0005435373362	5299	Economy	28000.00
0005434824416	5299	Economy	28000.00
0005435735127	5299	Economy	28000.00
0005435373042	5299	Economy	28000.00
0005434824392	5299	Economy	28000.00
0005435372764	5299	Economy	28000.00
0005435373058	5299	Economy	28000.00
0005434824358	5299	Economy	28000.00
0005434824378	5299	Economy	28000.00
0005434824373	5299	Economy	28000.00
0005434824387	5299	Economy	28000.00
0005435372960	5299	Economy	28000.00
0005434824415	5299	Economy	28000.00
0005435372995	5299	Economy	28000.00
0005435373183	5299	Economy	28000.00
0005432396269	5299	Economy	28000.00
0005435386551	5299	Economy	28000.00
0005434824395	5299	Economy	28000.00
0005434824334	5299	Economy	28000.00
0005432121424	5299	Economy	28000.00
0005435304151	5299	Economy	28000.00
0005434824418	5299	Economy	28000.00
0005435150116	5299	Economy	28000.00
0005435373359	5299	Economy	28000.00
0005432121423	5299	Economy	28000.00
0005434824370	5299	Economy	28000.00
0005435373057	5299	Economy	28000.00
0005434824394	5299	Economy	28000.00
0005435299754	5299	Economy	28000.00
0005435735129	5299	Economy	28000.00
0005435150110	5299	Economy	28000.00
0005435150112	5299	Economy	28000.00
0005435373198	5299	Economy	28000.00
0005434824364	5299	Economy	28000.00
0005432823438	5299	Economy	28000.00
0005434824308	5299	Economy	28000.00
0005434824320	5299	Economy	28000.00
0005434824391	5299	Economy	28000.00
0005434824328	5299	Economy	28000.00
0005434824420	5299	Economy	28000.00
0005435373218	5299	Economy	28000.00
0005435373178	5299	Economy	28000.00
0005434824349	5299	Economy	28000.00
0005435299755	5299	Economy	28000.00
0005434823599	9908	Business	84000.00
0005434823132	9908	Business	84000.00
0005434823133	9908	Business	84000.00
0005435149972	9908	Business	84000.00
0005434823340	9908	Business	84000.00
0005434828690	9908	Business	84000.00
0005434823360	9908	Business	84000.00
0005434823420	9908	Business	84000.00
0005435373672	9908	Business	84000.00
0005432203106	9908	Business	84000.00
0005435386606	9908	Business	84000.00
0005434823682	9908	Business	84000.00
0005434664953	9908	Business	84000.00
0005434823259	9908	Business	84000.00
0005435373688	9908	Business	84000.00
0005435373655	9908	Business	84000.00
0005434831148	9908	Business	84000.00
0005434823116	9908	Business	84000.00
0005435373630	9908	Business	84000.00
0005435373679	9908	Business	84000.00
0005434664949	9908	Business	84000.00
0005435150008	9908	Business	84000.00
0005435373667	9908	Business	84000.00
0005434823733	9908	Comfort	47600.00
0005434823433	9908	Comfort	47600.00
0005434823233	9908	Comfort	47600.00
0005434823342	9908	Comfort	47600.00
0005434823354	9908	Comfort	47600.00
0005435373677	9908	Comfort	47600.00
0005432396225	9908	Comfort	47600.00
0005432203107	9908	Comfort	47600.00
0005435373671	9908	Comfort	47600.00
0005435373647	9908	Comfort	47600.00
0005434823214	9908	Comfort	47600.00
0005435373685	9908	Comfort	47600.00
0005434823653	9908	Comfort	47600.00
0005434823596	9908	Comfort	47600.00
0005434823400	9908	Comfort	47600.00
0005434822710	9908	Comfort	47600.00
0005434823652	9908	Comfort	47600.00
0005434823256	9908	Comfort	47600.00
0005434822709	9908	Comfort	47600.00
0005434823260	9908	Comfort	47600.00
0005435373651	9908	Comfort	47600.00
0005434823207	9908	Comfort	47600.00
0005434823027	9908	Comfort	47600.00
0005435302228	9908	Comfort	47600.00
0005434823730	9908	Comfort	47600.00
0005434823179	9908	Comfort	47600.00
0005435373641	9908	Comfort	47600.00
0005435373632	9908	Comfort	47600.00
0005435149920	9908	Comfort	47600.00
0005435373638	9908	Comfort	47600.00
0005434823181	9908	Comfort	47600.00
0005434823428	9908	Comfort	47600.00
0005434823870	9908	Comfort	47600.00
0005435661950	9908	Comfort	47600.00
0005435373673	9908	Comfort	47600.00
0005435373642	9908	Comfort	47600.00
0005435373652	9908	Comfort	47600.00
0005435373687	9908	Comfort	47600.00
0005434823049	9908	Economy	28000.00
0005435373649	9908	Economy	28000.00
0005435179399	9908	Economy	28000.00
0005435149921	9908	Economy	28000.00
0005434831149	9908	Economy	28000.00
0005435373693	9908	Economy	28000.00
0005434823353	9908	Economy	28000.00
0005434823888	9908	Economy	28000.00
0005435373680	9908	Economy	28000.00
0005435373674	9908	Economy	28000.00
0005434823349	9908	Economy	28000.00
0005434831150	9908	Economy	28000.00
0005434822909	9908	Economy	28000.00
0005435373663	9908	Economy	28000.00
0005435373644	9908	Economy	28000.00
0005434823371	9908	Economy	28000.00
0005435373648	9908	Economy	28000.00
0005434823134	9908	Economy	28000.00
0005435299803	9908	Economy	28000.00
0005432203104	9908	Economy	28000.00
0005434823997	9908	Economy	28000.00
0005434823591	9908	Economy	28000.00
0005434823028	9908	Economy	28000.00
0005435373665	9908	Economy	28000.00
0005434823998	9908	Economy	28000.00
0005432396224	9908	Economy	28000.00
0005434823089	9908	Economy	28000.00
0005435373659	9908	Economy	28000.00
0005435299804	9908	Economy	28000.00
0005434822781	9908	Economy	28000.00
0005434822806	9908	Economy	28000.00
0005434823252	9908	Economy	28000.00
0005435150018	9908	Economy	28000.00
0005434823423	9908	Economy	28000.00
0005435373645	9908	Economy	28000.00
0005434823210	9908	Economy	28000.00
0005435661951	9908	Economy	28000.00
0005435302226	9908	Economy	28000.00
0005434823575	9908	Economy	28000.00
0005432823462	9908	Economy	30800.00
0005435373660	9908	Economy	30800.00
0005435373670	9908	Economy	30800.00
0005435299805	9908	Economy	28000.00
0005434823287	9908	Economy	28000.00
0005435299806	9908	Economy	30800.00
0005432396231	9908	Economy	28000.00
0005435373690	9908	Economy	30800.00
0005434823776	9908	Economy	28000.00
0005434664950	9908	Economy	28000.00
0005434823871	9908	Economy	28000.00
0005434823620	9908	Economy	28000.00
0005435373678	9908	Economy	28000.00
0005434823212	9908	Economy	28000.00
0005434823640	9908	Economy	28000.00
0005434822969	9908	Economy	28000.00
0005435373692	9908	Economy	28000.00
0005434822943	9908	Economy	28000.00
0005434823273	9908	Economy	28000.00
0005434822919	9908	Economy	28000.00
0005434822825	9908	Economy	28000.00
0005435661948	9908	Economy	28000.00
0005434822966	9908	Economy	28000.00
0005434823115	9908	Economy	28000.00
0005435373656	9908	Economy	28000.00
0005435661949	9908	Economy	28000.00
0005434823015	9908	Economy	28000.00
0005434823475	9908	Economy	28000.00
0005434823180	9908	Economy	28000.00
0005435149974	9908	Economy	28000.00
0005434822944	9908	Economy	28000.00
0005434823203	9908	Economy	28000.00
0005434823142	9908	Economy	28000.00
0005434823359	9908	Economy	28000.00
0005434823213	9908	Economy	28000.00
0005435373629	9908	Economy	28000.00
0005434823651	9908	Economy	28000.00
0005434823639	9908	Economy	28000.00
0005434823384	9908	Economy	28000.00
0005434822901	9908	Economy	28000.00
0005434823262	9908	Economy	28000.00
0005432203108	9908	Economy	28000.00
0005434823434	9908	Economy	28000.00
0005435149964	9908	Economy	28000.00
0005435149979	9908	Economy	28000.00
0005432823463	9908	Economy	28000.00
0005434822650	9908	Economy	28000.00
0005432203109	9908	Economy	28000.00
0005435150015	9908	Economy	28000.00
0005434823543	9908	Economy	28000.00
0005434822682	9908	Economy	28000.00
0005435386612	9908	Economy	28000.00
0005434823263	9908	Economy	28000.00
0005434823026	9908	Economy	28000.00
0005434823225	9908	Economy	28000.00
0005434822663	9908	Economy	28000.00
0005435373689	9908	Economy	28000.00
0005434823104	9908	Economy	28000.00
0005435735165	9908	Economy	28000.00
0005435373634	9908	Economy	28000.00
0005434823408	9908	Economy	28000.00
0005435373664	9908	Economy	28000.00
0005434822967	9908	Economy	28000.00
0005434822763	9908	Economy	28000.00
0005432400117	9908	Economy	28000.00
0005435149973	9908	Economy	28000.00
0005434823061	9908	Economy	28000.00
0005434823185	9908	Economy	28000.00
0005435373662	9908	Economy	28000.00
0005435373669	9908	Economy	28000.00
0005434823401	9908	Economy	28000.00
0005434823729	9908	Economy	28000.00
0005434823206	9908	Economy	28000.00
0005435386610	9908	Economy	28000.00
0005435149943	9908	Economy	28000.00
0005434822711	9908	Economy	28000.00
0005434823544	9908	Economy	28000.00
0005435373631	9908	Economy	28000.00
0005435373650	9908	Economy	28000.00
0005434822906	9908	Economy	28000.00
0005435373639	9908	Economy	28000.00
0005435373691	9908	Economy	28000.00
0005434822807	9908	Economy	28000.00
0005434823247	9908	Economy	28000.00
0005435735163	9908	Economy	28000.00
0005434823013	9908	Economy	28000.00
0005435373633	9908	Economy	28000.00
0005435735167	9908	Economy	28000.00
0005434823291	9908	Economy	28000.00
0005432203105	9908	Economy	28000.00
0005432203110	9908	Economy	28000.00
0005435373637	9908	Economy	28000.00
0005434823339	9908	Economy	28000.00
0005435373666	9908	Economy	28000.00
0005435386609	9908	Economy	30800.00
0005434823215	9908	Economy	30800.00
0005434823771	9908	Economy	30800.00
0005434823659	9908	Economy	30800.00
0005434823276	9908	Economy	30800.00
0005435386607	9908	Economy	28000.00
0005434823700	9908	Economy	28000.00
0005434823224	9908	Economy	28000.00
0005434823598	9908	Economy	28000.00
0005434823719	9908	Economy	28000.00
0005434823739	9908	Economy	28000.00
0005435373675	9908	Economy	28000.00
0005434823318	9908	Economy	28000.00
0005434823683	9908	Economy	28000.00
0005435373653	9908	Economy	28000.00
0005434823264	9908	Economy	28000.00
0005434823416	9908	Economy	28000.00
0005434823449	9908	Economy	28000.00
0005434822990	9908	Economy	28000.00
0005435386611	9908	Economy	28000.00
0005432396236	9908	Economy	28000.00
0005434823641	9908	Economy	28000.00
0005435373661	9908	Economy	28000.00
0005435373643	9908	Economy	28000.00
0005432396248	9908	Economy	28000.00
0005435373658	9908	Economy	28000.00
0005434823205	9908	Economy	28000.00
0005434823051	9908	Economy	28000.00
0005434822649	9908	Economy	28000.00
0005435373657	9908	Economy	28000.00
0005435302225	9908	Economy	28000.00
0005435373683	9908	Economy	28000.00
0005434823517	9908	Economy	28000.00
0005434823014	9908	Economy	28000.00
0005434823775	9908	Economy	28000.00
0005434823314	9908	Economy	28000.00
0005435386608	9908	Economy	28000.00
0005435735164	9908	Economy	28000.00
0005434823217	9908	Economy	28000.00
0005435373635	9908	Economy	28000.00
0005435373682	9908	Economy	28000.00
0005434823178	9908	Economy	28000.00
0005434822900	9908	Economy	28000.00
0005434823246	9908	Economy	28000.00
0005434823204	9908	Economy	28000.00
0005435386605	9908	Economy	28000.00
0005435373684	9908	Economy	28000.00
0005434822683	9908	Economy	28000.00
0005434823508	9908	Economy	28000.00
0005434823448	9908	Economy	28000.00
0005432396233	9908	Economy	28000.00
0005434822736	9908	Economy	28000.00
0005435373686	9908	Economy	28000.00
0005435149965	9908	Economy	28000.00
0005435179699	9908	Economy	28000.00
0005435373668	9908	Economy	28000.00
0005434822737	9908	Economy	28000.00
0005434823140	9908	Economy	28000.00
0005435373646	9908	Economy	28000.00
0005434823507	9908	Economy	28000.00
0005434558263	9908	Economy	28000.00
0005434823366	9908	Economy	28000.00
0005435373654	9908	Economy	28000.00
0005434823024	9908	Economy	28000.00
0005434828686	9908	Economy	28000.00
0005434823052	9908	Economy	28000.00
0005434823035	9908	Economy	28000.00
0005434823272	9908	Economy	28000.00
0005434822772	9908	Economy	28000.00
0005434823455	9908	Economy	28000.00
0005435302227	9908	Economy	28000.00
0005435373636	9908	Economy	28000.00
0005435373694	9908	Economy	28000.00
0005435179698	9908	Economy	28000.00
0005434823258	9908	Economy	28000.00
0005435373681	9908	Economy	28000.00
0005434823025	9908	Economy	28000.00
0005434823114	9908	Economy	28000.00
0005435373676	9908	Economy	28000.00
0005435373640	9908	Economy	28000.00
0005434822662	9908	Economy	28000.00
0005435373628	9908	Economy	28000.00
0005434823777	9908	Economy	28000.00
0005435735166	9908	Economy	28000.00
0005435082832	6984	Economy	7400.00
0005435082835	6984	Economy	7400.00
0005435082834	6984	Economy	7400.00
0005435790323	6984	Economy	7400.00
0005435082840	6984	Economy	7400.00
0005435790324	6984	Economy	7400.00
0005435082839	6984	Economy	7400.00
0005435082836	6984	Economy	7400.00
0005435082837	6984	Economy	7400.00
0005435082838	6984	Economy	7400.00
0005435790325	6984	Economy	7400.00
0005435082833	6984	Economy	7400.00
0005435082751	25995	Economy	8200.00
0005435082742	25995	Economy	7400.00
0005435082763	25995	Economy	7400.00
0005435790304	25995	Economy	7400.00
0005435082762	25995	Economy	7400.00
0005435082739	25995	Economy	7400.00
0005434214417	9518	Business	32800.00
0005434756688	9518	Business	32800.00
0005434756685	9518	Business	32800.00
0005434756681	9518	Business	32800.00
0005434214294	9518	Business	32800.00
0005434214432	9518	Business	32800.00
0005434214304	9518	Business	32800.00
0005434756669	9518	Business	32800.00
0005434214181	9518	Business	32800.00
0005434756698	9518	Economy	10900.00
0005434756680	9518	Economy	10900.00
0005434756666	9518	Economy	10900.00
0005434756682	9518	Economy	10900.00
0005434756676	9518	Economy	10900.00
0005434214274	9518	Economy	10900.00
0005434214391	9518	Economy	10900.00
0005434756705	9518	Economy	10900.00
0005434756671	9518	Economy	10900.00
0005434214322	9518	Economy	12000.00
0005434756678	9518	Economy	12000.00
0005434756707	9518	Economy	12000.00
0005434756670	9518	Economy	12000.00
0005434756711	9518	Economy	10900.00
0005434214382	9518	Economy	10900.00
0005434214400	9518	Economy	10900.00
0005434214522	9518	Economy	10900.00
0005434214390	9518	Economy	10900.00
0005434214418	9518	Economy	10900.00
0005434214341	9518	Economy	10900.00
0005434756703	9518	Economy	10900.00
0005434756704	9518	Economy	10900.00
0005434756665	9518	Economy	10900.00
0005434756679	9518	Economy	10900.00
0005434756702	9518	Economy	10900.00
0005434214302	9518	Economy	10900.00
0005434214545	9518	Economy	10900.00
0005434214307	9518	Economy	10900.00
0005434214257	9518	Economy	10900.00
0005434214163	9518	Economy	10900.00
0005434214295	9518	Economy	10900.00
0005434756691	9518	Economy	10900.00
0005434756667	9518	Economy	10900.00
0005434756674	9518	Economy	10900.00
0005434756684	9518	Economy	10900.00
0005434756686	9518	Economy	10900.00
0005434214303	9518	Economy	10900.00
0005434214389	9518	Economy	10900.00
0005434214313	9518	Economy	10900.00
0005434214399	9518	Economy	10900.00
0005434756710	9518	Economy	10900.00
0005434214273	9518	Economy	10900.00
0005434756696	9518	Economy	10900.00
0005434756700	9518	Economy	10900.00
0005434214269	9518	Economy	10900.00
0005434214293	9518	Economy	10900.00
0005434756675	9518	Economy	10900.00
0005434756699	9518	Economy	10900.00
0005434756673	9518	Economy	10900.00
0005434756697	9518	Economy	10900.00
0005434214362	9518	Economy	10900.00
0005434214336	9518	Economy	10900.00
0005434756693	9518	Economy	10900.00
0005434756668	9518	Economy	10900.00
0005434756706	9518	Economy	10900.00
0005434214340	9518	Economy	10900.00
0005434214437	9518	Economy	10900.00
0005434756692	9518	Economy	10900.00
0005434756709	9518	Economy	10900.00
0005434756690	9518	Economy	10900.00
0005434214361	9518	Economy	10900.00
0005434756708	9518	Economy	10900.00
0005434214270	9518	Economy	10900.00
0005434756683	9518	Economy	10900.00
0005434214472	9518	Economy	10900.00
0005434214301	9518	Economy	10900.00
0005434756695	9518	Economy	10900.00
0005434214356	9518	Economy	10900.00
0005434756677	9518	Economy	10900.00
0005434756694	9518	Economy	10900.00
0005434214547	9518	Economy	10900.00
0005434756689	9518	Economy	10900.00
0005434214471	9518	Economy	10900.00
0005434214548	9518	Economy	10900.00
0005434214383	9518	Economy	10900.00
0005434756687	9518	Economy	10900.00
0005434756672	9518	Economy	10900.00
0005434756701	9518	Economy	10900.00
0005434214305	9518	Economy	10900.00
0005434214770	28621	Business	32800.00
0005434214757	28621	Business	32800.00
0005434214745	28621	Business	32800.00
0005434756220	28621	Business	32800.00
0005434214783	28621	Business	32800.00
0005434214777	28621	Business	32800.00
0005434214754	28621	Business	32800.00
0005434214780	28621	Business	32800.00
0005434214760	28621	Business	32800.00
0005434756204	28621	Business	32800.00
0005434756226	28621	Business	32800.00
0005434214769	28621	Business	32800.00
0005434756281	28621	Economy	10900.00
0005434214785	28621	Economy	10900.00
0005434214779	28621	Economy	10900.00
0005434214746	28621	Economy	10900.00
0005434756176	28621	Economy	10900.00
0005434214772	28621	Economy	10900.00
0005434214788	28621	Economy	10900.00
0005434756123	28621	Economy	10900.00
0005434214759	28621	Economy	10900.00
0005434214764	28621	Economy	10900.00
0005434756310	28621	Economy	12000.00
0005434756241	28621	Economy	12000.00
0005434756194	28621	Economy	12000.00
0005434214748	28621	Economy	10900.00
0005434214786	28621	Economy	10900.00
0005434756278	28621	Economy	10900.00
0005434214765	28621	Economy	10900.00
0005434756203	28621	Economy	10900.00
0005434756137	28621	Economy	10900.00
0005434214787	28621	Economy	10900.00
0005434214751	28621	Economy	10900.00
0005434214773	28621	Economy	10900.00
0005434214776	28621	Economy	10900.00
0005434214763	28621	Economy	10900.00
0005434214790	28621	Economy	10900.00
0005434756291	28621	Economy	10900.00
0005434756081	28621	Economy	10900.00
0005434214753	28621	Economy	10900.00
0005434756234	28621	Economy	10900.00
0005434756213	28621	Economy	10900.00
0005434214766	28621	Economy	10900.00
0005434214755	28621	Economy	10900.00
0005434214778	28621	Economy	10900.00
0005434756225	28621	Economy	10900.00
0005434756212	28621	Economy	10900.00
0005434214784	28621	Economy	10900.00
0005434756175	28621	Economy	10900.00
0005434214758	28621	Economy	10900.00
0005434214781	28621	Economy	10900.00
0005434214771	28621	Economy	10900.00
0005434214749	28621	Economy	10900.00
0005434756309	28621	Economy	10900.00
0005434756080	28621	Economy	10900.00
0005434214750	28621	Economy	10900.00
0005434756214	28621	Economy	10900.00
0005434756208	28621	Economy	10900.00
0005434214792	28621	Economy	10900.00
0005434214747	28621	Economy	10900.00
0005434756189	28621	Economy	10900.00
0005434214782	28621	Economy	10900.00
0005434214767	28621	Economy	10900.00
0005434756304	28621	Economy	10900.00
0005434756166	28621	Economy	10900.00
0005434756303	28621	Economy	10900.00
0005434756198	28621	Economy	10900.00
0005434756132	28621	Economy	10900.00
0005434214791	28621	Economy	10900.00
0005434756147	28621	Economy	10900.00
0005434214761	28621	Economy	10900.00
0005434214775	28621	Economy	10900.00
0005434756277	28621	Economy	10900.00
0005434214789	28621	Economy	10900.00
0005434756165	28621	Economy	10900.00
0005434214756	28621	Economy	10900.00
0005434214768	28621	Economy	10900.00
0005434756206	28621	Economy	10900.00
0005434756199	28621	Economy	10900.00
0005434756224	28621	Economy	10900.00
0005434214774	28621	Economy	10900.00
0005434756207	28621	Economy	10900.00
0005434214762	28621	Economy	10900.00
0005434214752	28621	Economy	10900.00
0005434756192	28621	Economy	10900.00
0005434756131	28621	Economy	10900.00
0005435100144	10814	Economy	9800.00
0005434760194	10814	Economy	9800.00
0005434760181	10814	Economy	9800.00
0005435100140	10814	Economy	8900.00
0005435100142	10814	Economy	8900.00
0005434760192	10814	Economy	8900.00
0005435100143	10814	Economy	8900.00
0005435100141	10814	Economy	8900.00
0005435100114	31846	Economy	8900.00
0005434760213	31846	Economy	8900.00
0005434760211	31846	Economy	8900.00
0005435100115	31846	Economy	8900.00
0005434760214	31846	Economy	8900.00
0005434760212	31846	Economy	8900.00
0005435100119	31846	Economy	8900.00
0005435100126	31846	Economy	8900.00
0005434639482	1975	Economy	20900.00
0005434639481	1975	Economy	20900.00
0005433202314	1975	Economy	20900.00
0005432290653	1975	Economy	20900.00
0005434639490	1975	Economy	19000.00
0005434639489	1975	Economy	19000.00
0005434639486	1975	Economy	19000.00
0005433202353	1975	Economy	19000.00
0005433202333	1975	Economy	19000.00
0005434639485	1975	Economy	19000.00
0005433202380	1975	Economy	19000.00
0005434639492	1975	Economy	19000.00
0005433202362	1975	Economy	19000.00
0005433202339	1975	Economy	19000.00
0005434639484	1975	Economy	19000.00
0005433202258	1975	Economy	19000.00
0005434639477	1975	Economy	19000.00
0005434639478	1975	Economy	19000.00
0005433202352	1975	Economy	19000.00
0005434639498	1975	Economy	19000.00
0005433202367	1975	Economy	19000.00
0005433202363	1975	Economy	19000.00
0005434639496	1975	Economy	19000.00
0005433202315	1975	Economy	19000.00
0005432290652	1975	Economy	19000.00
0005433202284	1975	Economy	19000.00
0005434639497	1975	Economy	19000.00
0005433202382	1975	Economy	19000.00
0005434639480	1975	Economy	19000.00
0005434639494	1975	Economy	19000.00
0005433202397	1975	Economy	19000.00
0005433202388	1975	Economy	19000.00
0005434639487	1975	Economy	19000.00
0005434639479	1975	Economy	19000.00
0005433202381	1975	Economy	19000.00
0005434639495	1975	Economy	19000.00
0005434639491	1975	Economy	19000.00
0005433202396	1975	Economy	19000.00
0005433202305	1975	Economy	19000.00
0005433202304	1975	Economy	19000.00
0005433202387	1975	Economy	19000.00
0005434639493	1975	Economy	19000.00
0005432290651	1975	Economy	19000.00
0005434639488	1975	Economy	19000.00
0005433202364	1975	Economy	19000.00
0005433202379	1975	Economy	19000.00
0005434639483	1975	Economy	19000.00
0005434639298	23282	Economy	20900.00
0005433202436	23282	Economy	20900.00
0005433202448	23282	Economy	19000.00
0005434639167	23282	Economy	19000.00
0005433202443	23282	Economy	19000.00
0005433202441	23282	Economy	19000.00
0005433202447	23282	Economy	19000.00
0005433202446	23282	Economy	19000.00
0005434639280	23282	Economy	19000.00
0005434639067	23282	Economy	19000.00
0005434639183	23282	Economy	19000.00
0005433202437	23282	Economy	19000.00
0005434639122	23282	Economy	19000.00
0005433202444	23282	Economy	19000.00
0005433202450	23282	Economy	19000.00
0005434639265	23282	Economy	19000.00
0005433202438	23282	Economy	19000.00
0005434639101	23282	Economy	19000.00
0005434639361	23282	Economy	19000.00
0005433202442	23282	Economy	19000.00
0005434639211	23282	Economy	19000.00
0005434639281	23282	Economy	19000.00
0005433202449	23282	Economy	19000.00
0005434639305	23282	Economy	19000.00
0005433202439	23282	Economy	19000.00
0005433202435	23282	Economy	19000.00
0005434639261	23282	Economy	19000.00
0005434639206	23282	Economy	19000.00
0005434639100	23282	Economy	19000.00
0005433202445	23282	Economy	19000.00
0005434639184	23282	Economy	19000.00
0005433202440	23282	Economy	19000.00
0005434639251	23282	Economy	19000.00
0005434639282	23282	Economy	19000.00
0005434639304	23282	Economy	19000.00
0005434639123	23282	Economy	19000.00
0005434639271	23282	Economy	19000.00
0005434639256	23282	Economy	19000.00
0005433533333	6057	Business	69700.00
0005435326606	6057	Business	69700.00
0005434600968	6057	Business	69700.00
0005434600978	6057	Business	69700.00
0005434600966	6057	Economy	23200.00
0005434600975	6057	Economy	23200.00
0005433531318	6057	Economy	23200.00
0005434600986	6057	Economy	25600.00
0005434600971	6057	Economy	25600.00
0005434600970	6057	Economy	23200.00
0005434600981	6057	Economy	23200.00
0005434600987	6057	Economy	23200.00
0005434600980	6057	Economy	23200.00
0005435326702	6057	Economy	23200.00
0005434600964	6057	Economy	23200.00
0005434600977	6057	Economy	23200.00
0005432111298	6057	Economy	23200.00
0005434600967	6057	Economy	23200.00
0005435326739	6057	Economy	23200.00
0005434600985	6057	Economy	23200.00
0005434600976	6057	Economy	23200.00
0005434600963	6057	Economy	23200.00
0005432111297	6057	Economy	23200.00
0005433531317	6057	Economy	23200.00
0005435326701	6057	Economy	23200.00
0005434600988	6057	Economy	23200.00
0005435326700	6057	Economy	23200.00
0005433531315	6057	Economy	23200.00
0005433531319	6057	Economy	23200.00
0005434600983	6057	Economy	23200.00
0005435326740	6057	Economy	23200.00
0005433531316	6057	Economy	23200.00
0005434600972	6057	Economy	23200.00
0005435326732	6057	Economy	23200.00
0005433533331	6057	Economy	23200.00
0005435326677	6057	Economy	23200.00
0005434600969	6057	Economy	23200.00
0005434600965	6057	Economy	23200.00
0005434600982	6057	Economy	23200.00
0005432111299	6057	Economy	23200.00
0005434600979	6057	Economy	23200.00
0005434600974	6057	Economy	23200.00
0005435326607	6057	Economy	23200.00
0005433533332	6057	Economy	23200.00
0005435326705	6057	Economy	23200.00
0005434600984	6057	Economy	23200.00
0005434600973	6057	Economy	23200.00
0005435326685	6057	Economy	23200.00
0005435326811	6057	Economy	23200.00
0005435326723	6057	Economy	23200.00
0005435326834	18559	Business	69700.00
0005434600660	18559	Business	69700.00
0005434600795	18559	Business	69700.00
0005434600788	18559	Business	69700.00
0005434600820	18559	Business	69700.00
0005434600759	18559	Business	69700.00
0005433527244	18559	Economy	23200.00
0005435326833	18559	Economy	23200.00
0005435326830	18559	Economy	23200.00
0005434600673	18559	Economy	23200.00
0005434600710	18559	Economy	23200.00
0005435326837	18559	Economy	25600.00
0005435326825	18559	Economy	23200.00
0005434600756	18559	Economy	23200.00
0005433527243	18559	Economy	23200.00
0005433531281	18559	Economy	23200.00
0005434600768	18559	Economy	23200.00
0005434600757	18559	Economy	23200.00
0005435326828	18559	Economy	23200.00
0005434600687	18559	Economy	23200.00
0005433527236	18559	Economy	23200.00
0005435326835	18559	Economy	23200.00
0005434600723	18559	Economy	23200.00
0005433531302	18559	Economy	23200.00
0005435326832	18559	Economy	23200.00
0005435326827	18559	Economy	23200.00
0005435326829	18559	Economy	23200.00
0005434600659	18559	Economy	23200.00
0005433531289	18559	Economy	23200.00
0005434600822	18559	Economy	23200.00
0005434600770	18559	Economy	23200.00
0005435326824	18559	Economy	23200.00
0005434600651	18559	Economy	23200.00
0005435326836	18559	Economy	23200.00
0005433531303	18559	Economy	23200.00
0005434600745	18559	Economy	23200.00
0005434600771	18559	Economy	23200.00
0005434600686	18559	Economy	23200.00
0005434600774	18559	Economy	23200.00
0005434600661	18559	Economy	23200.00
0005434600761	18559	Economy	23200.00
0005433527235	18559	Economy	23200.00
0005433531283	18559	Economy	23200.00
0005435326823	18559	Economy	23200.00
0005434600789	18559	Economy	23200.00
0005435326826	18559	Economy	23200.00
0005433531273	18559	Economy	23200.00
0005435326831	18559	Economy	23200.00
0005434600665	18559	Economy	23200.00
0005433181048	10564	Business	9100.00
0005433180977	10564	Business	9100.00
0005434558312	10564	Business	9100.00
0005433180921	10564	Business	9100.00
0005433180983	10564	Business	9100.00
0005434558311	10564	Business	9100.00
0005434558319	10564	Business	9100.00
0005434551534	10564	Business	9100.00
0005434558314	10564	Business	9100.00
0005434551529	10564	Business	9100.00
0005434551537	10564	Business	9100.00
0005434551542	10564	Economy	3000.00
0005434551545	10564	Economy	3000.00
0005434551516	10564	Economy	3000.00
0005434551527	10564	Economy	3000.00
0005434551502	10564	Economy	3000.00
0005434551517	10564	Economy	3000.00
0005434551525	10564	Economy	3000.00
0005434551520	10564	Economy	3000.00
0005434558313	10564	Economy	3000.00
0005434551536	10564	Economy	3000.00
0005434558317	10564	Economy	3300.00
0005434551544	10564	Economy	3300.00
0005434551531	10564	Economy	3300.00
0005434551523	10564	Economy	3300.00
0005434558310	10564	Economy	3300.00
0005434558321	10564	Economy	3000.00
0005434551515	10564	Economy	3000.00
0005434551506	10564	Economy	3000.00
0005434558315	10564	Economy	3000.00
0005434551511	10564	Economy	3000.00
0005434551547	10564	Economy	3000.00
0005434551543	10564	Economy	3000.00
0005434558316	10564	Economy	3000.00
0005434551519	10564	Economy	3000.00
0005433181095	10564	Economy	3000.00
0005434551533	10564	Economy	3000.00
0005433180997	10564	Economy	3000.00
0005434551535	10564	Economy	3000.00
0005434551509	10564	Economy	3000.00
0005434551539	10564	Economy	3000.00
0005434558318	10564	Economy	3000.00
0005433181100	10564	Economy	3000.00
0005434558322	10564	Economy	3000.00
0005434551504	10564	Economy	3000.00
0005434551546	10564	Economy	3000.00
0005434551497	10564	Economy	3000.00
0005434551521	10564	Economy	3000.00
0005434554077	10564	Economy	3000.00
0005434551549	10564	Economy	3000.00
0005434551500	10564	Economy	3000.00
0005434558324	10564	Economy	3000.00
0005434551524	10564	Economy	3000.00
0005434551538	10564	Economy	3000.00
0005434551528	10564	Economy	3000.00
0005434558323	10564	Economy	3000.00
0005434551494	10564	Economy	3000.00
0005434551499	10564	Economy	3000.00
0005433180984	10564	Economy	3000.00
0005434551548	10564	Economy	3000.00
0005434551505	10564	Economy	3000.00
0005433181043	10564	Economy	3000.00
0005434551541	10564	Economy	3000.00
0005434558320	10564	Economy	3000.00
0005434551507	10564	Economy	3000.00
0005434551498	10564	Economy	3000.00
0005434551513	10564	Economy	3000.00
0005434551522	10564	Economy	3000.00
0005434551501	10564	Economy	3000.00
0005434554078	10564	Economy	3000.00
0005434551496	10564	Economy	3000.00
0005434551532	10564	Economy	3000.00
0005433181046	10564	Economy	3000.00
0005434551508	10564	Economy	3000.00
0005434551512	10564	Economy	3000.00
0005434551540	10564	Economy	3000.00
0005433180949	10564	Economy	3000.00
0005434551526	10564	Economy	3000.00
0005434551510	10564	Economy	3000.00
0005433180998	10564	Economy	3000.00
0005434551495	10564	Economy	3000.00
0005434551518	10564	Economy	3000.00
0005433180948	10564	Economy	3000.00
0005434551503	10564	Economy	3000.00
0005434551514	10564	Economy	3000.00
0005433181047	10564	Economy	3000.00
0005433181022	10564	Economy	3000.00
0005434558309	10564	Economy	3000.00
0005434551530	10564	Economy	3000.00
0005433181250	27782	Business	9100.00
0005433181262	27782	Business	9100.00
0005433181267	27782	Business	9100.00
0005433181260	27782	Economy	3000.00
0005433181265	27782	Economy	3000.00
0005433181251	27782	Economy	3000.00
0005433181261	27782	Economy	3000.00
0005433181252	27782	Economy	3300.00
0005433181259	27782	Economy	3000.00
0005433181263	27782	Economy	3000.00
0005433181247	27782	Economy	3000.00
0005433181264	27782	Economy	3000.00
0005433181266	27782	Economy	3000.00
0005433181248	27782	Economy	3000.00
0005433181246	27782	Economy	3000.00
0005433181245	27782	Economy	3000.00
0005433181249	27782	Economy	3000.00
0005433181256	27782	Economy	3000.00
0005433181257	27782	Economy	3000.00
0005433181255	27782	Economy	3000.00
0005433181244	27782	Economy	3000.00
0005433181253	27782	Economy	3000.00
0005433181258	27782	Economy	3000.00
0005433181254	27782	Economy	3000.00
0005433181243	27782	Economy	3000.00
0005434551126	27783	Business	9100.00
0005434558238	27783	Business	9100.00
0005434551184	27783	Business	9100.00
0005434551104	27783	Business	9100.00
0005434551144	27783	Business	9100.00
0005434551327	27783	Business	9100.00
0005434550868	27783	Business	9100.00
0005434551151	27783	Business	9100.00
0005434551127	27783	Economy	3000.00
0005434550951	27783	Economy	3000.00
0005434550980	27783	Economy	3000.00
0005434558233	27783	Economy	3000.00
0005434551098	27783	Economy	3000.00
0005434558249	27783	Economy	3000.00
0005434551192	27783	Economy	3000.00
0005434550946	27783	Economy	3300.00
0005434551228	27783	Economy	3300.00
0005434550917	27783	Economy	3000.00
0005434551006	27783	Economy	3000.00
0005434550915	27783	Economy	3000.00
0005434551174	27783	Economy	3000.00
0005434551063	27783	Economy	3000.00
0005434551326	27783	Economy	3000.00
0005434550878	27783	Economy	3000.00
0005434551189	27783	Economy	3000.00
0005434558241	27783	Economy	3000.00
0005434551097	27783	Economy	3000.00
0005434551162	27783	Economy	3000.00
0005434551311	27783	Economy	3000.00
0005434558250	27783	Economy	3000.00
0005434551001	27783	Economy	3000.00
0005434551377	27783	Economy	3000.00
0005434551281	27783	Economy	3000.00
0005434558240	27783	Economy	3000.00
0005434558260	27783	Economy	3000.00
0005434558243	27783	Economy	3000.00
0005434551202	27783	Economy	3000.00
0005434551048	27783	Economy	3000.00
0005434551190	27783	Economy	3000.00
0005434550964	27783	Economy	3000.00
0005434551007	27783	Economy	3000.00
0005434551000	27783	Economy	3000.00
0005434551075	27783	Economy	3000.00
0005434551268	27783	Economy	3000.00
0005434551059	27783	Economy	3000.00
0005434551280	27783	Economy	3000.00
0005434551058	27783	Economy	3000.00
0005434550935	27783	Economy	3000.00
0005434558237	27783	Economy	3000.00
0005434551064	27783	Economy	3000.00
0005434558247	27783	Economy	3000.00
0005434558236	27783	Economy	3000.00
0005434558232	27783	Economy	3000.00
0005434558242	27783	Economy	3000.00
0005434551152	27783	Economy	3000.00
0005434551145	27783	Economy	3000.00
0005434551191	27783	Economy	3000.00
0005434551219	27783	Economy	3000.00
0005434558246	27783	Economy	3000.00
0005434550998	27783	Economy	3000.00
0005435254471	6137	Economy	11700.00
0005435254460	6137	Economy	11700.00
0005435254459	6137	Economy	11700.00
0005435254476	6137	Economy	11700.00
0005435254462	6137	Economy	11700.00
0005433459243	6137	Economy	11700.00
0005435254472	6137	Economy	11700.00
0005435254461	6137	Economy	11700.00
0005433459246	6137	Economy	11700.00
0005433459245	6137	Economy	11700.00
0005433459244	6137	Economy	11700.00
0005435254477	6137	Economy	11700.00
0005433459214	19324	Economy	11700.00
0005433459210	19324	Economy	11700.00
0005433459215	19324	Economy	11700.00
0005435254489	19324	Economy	11700.00
0005435254488	19324	Economy	11700.00
0005435682376	6717	Business	51100.00
0005435682404	6717	Business	51100.00
0005435682390	6717	Business	51100.00
0005434828688	6717	Business	51100.00
0005435437858	6717	Business	51100.00
0005435437897	6717	Business	51100.00
0005435682379	6717	Business	51100.00
0005435630984	6717	Business	51100.00
0005435682372	6717	Business	51100.00
0005435437896	6717	Business	51100.00
0005435720140	6717	Business	51100.00
0005435682370	6717	Economy	17000.00
0005435437935	6717	Economy	17000.00
0005435682389	6717	Economy	17000.00
0005435682388	6717	Economy	17000.00
0005435682396	6717	Economy	17000.00
0005435682395	6717	Economy	17000.00
0005435437903	6717	Economy	17000.00
0005435437949	6717	Economy	17000.00
0005435682397	6717	Economy	17000.00
0005435437871	6717	Economy	18700.00
0005435682367	6717	Economy	18700.00
0005435682365	6717	Economy	18700.00
0005435719569	6717	Economy	18700.00
0005435661947	6717	Economy	17000.00
0005435661946	6717	Economy	17000.00
0005435437902	6717	Economy	17000.00
0005435682392	6717	Economy	17000.00
0005435682383	6717	Economy	17000.00
0005435682368	6717	Economy	17000.00
0005435437979	6717	Economy	17000.00
0005435682378	6717	Economy	17000.00
0005435682394	6717	Economy	17000.00
0005435682369	6717	Economy	17000.00
0005432136199	6717	Economy	17000.00
0005435220313	6717	Economy	17000.00
0005435682400	6717	Economy	17000.00
0005435682374	6717	Economy	17000.00
0005435682384	6717	Economy	17000.00
0005435682407	6717	Economy	17000.00
0005435682366	6717	Economy	17000.00
0005435682382	6717	Economy	17000.00
0005432136198	6717	Economy	17000.00
0005435437895	6717	Economy	17000.00
0005432136197	6717	Economy	17000.00
0005434828697	6717	Economy	17000.00
0005435682377	6717	Economy	17000.00
0005435682402	6717	Economy	17000.00
0005432533273	6717	Economy	17000.00
0005435682403	6717	Economy	17000.00
0005435682381	6717	Economy	17000.00
0005435682380	6717	Economy	17000.00
0005432136200	6717	Economy	17000.00
0005435682393	6717	Economy	17000.00
0005435437908	6717	Economy	17000.00
0005435437950	6717	Economy	17000.00
0005435682385	6717	Economy	17000.00
0005435682362	6717	Economy	17000.00
0005432136201	6717	Economy	17000.00
0005435682399	6717	Economy	17000.00
0005435437890	6717	Economy	17000.00
0005435682405	6717	Economy	17000.00
0005435682401	6717	Economy	17000.00
0005435630983	6717	Economy	17000.00
0005435682406	6717	Economy	17000.00
0005435630982	6717	Economy	17000.00
0005434828689	6717	Economy	17000.00
0005434828687	6717	Economy	17000.00
0005435682398	6717	Economy	17000.00
0005435437938	6717	Economy	17000.00
0005435682387	6717	Economy	17000.00
0005435682375	6717	Economy	17000.00
0005435682391	6717	Economy	17000.00
0005435682364	6717	Economy	17000.00
0005435682371	6717	Economy	17000.00
0005435437932	6717	Economy	17000.00
0005435682363	6717	Economy	17000.00
0005434828685	6717	Economy	17000.00
0005435682373	6717	Economy	17000.00
0005435682386	6717	Economy	17000.00
0005435438079	24576	Business	51100.00
0005435681898	24576	Business	51100.00
0005435661920	24576	Business	51100.00
0005435681940	24576	Business	51100.00
0005435682105	24576	Business	51100.00
0005435681909	24576	Business	51100.00
0005435681966	24576	Business	51100.00
0005435682050	24576	Business	51100.00
0005435438086	24576	Business	51100.00
0005432533310	24576	Business	51100.00
0005435681894	24576	Business	51100.00
0005435438094	24576	Business	51100.00
0005435681933	24576	Economy	17000.00
0005435682079	24576	Economy	17000.00
0005435681943	24576	Economy	17000.00
0005432533311	24576	Economy	17000.00
0005435630962	24576	Economy	17000.00
0005435720821	24576	Economy	17000.00
0005435681994	24576	Economy	17000.00
0005435682010	24576	Economy	17000.00
0005435681863	24576	Economy	17000.00
0005435682051	24576	Economy	17000.00
0005435438093	24576	Economy	18700.00
0005435438074	24576	Economy	18700.00
0005435682187	24576	Economy	18700.00
0005434828714	24576	Economy	18700.00
0005435438085	24576	Economy	17000.00
0005435681989	24576	Economy	17000.00
0005435682019	24576	Economy	17000.00
0005435438080	24576	Economy	17000.00
0005434828715	24576	Economy	17000.00
0005435682038	24576	Economy	17000.00
0005432533309	24576	Economy	17000.00
0005435682142	24576	Economy	17000.00
0005435682067	24576	Economy	17000.00
0005435682144	24576	Economy	17000.00
0005435438090	24576	Economy	17000.00
0005435682178	24576	Economy	17000.00
0005435681969	24576	Economy	17000.00
0005435682049	24576	Economy	17000.00
0005435720820	24576	Economy	17000.00
0005435681899	24576	Economy	17000.00
0005435681897	24576	Economy	17000.00
0005435682011	24576	Economy	17000.00
0005435682119	24576	Economy	17000.00
0005435682179	24576	Economy	17000.00
0005435681827	24576	Economy	17000.00
0005432305764	24576	Economy	17000.00
0005435719563	24576	Economy	17000.00
0005435681906	24576	Economy	17000.00
0005435438076	24576	Economy	17000.00
0005435438077	24576	Economy	17000.00
0005435438092	24576	Economy	17000.00
0005435438083	24576	Economy	17000.00
0005435682145	24576	Economy	17000.00
0005435682126	24576	Economy	17000.00
0005435681968	24576	Economy	17000.00
0005434828713	24576	Economy	17000.00
0005435438075	24576	Economy	17000.00
0005435682020	24576	Economy	17000.00
0005435438078	24576	Economy	17000.00
0005435630956	24576	Economy	17000.00
0005435681990	24576	Economy	17000.00
0005435438095	24576	Economy	17000.00
0005435438089	24576	Economy	17000.00
0005435438084	24576	Economy	17000.00
0005435438091	24576	Economy	17000.00
0005435682235	24576	Economy	17000.00
0005432533308	24576	Economy	17000.00
0005435719565	24576	Economy	17000.00
0005435682048	24576	Economy	17000.00
0005435681868	24576	Economy	17000.00
0005435438081	24576	Economy	17000.00
0005435438087	24576	Economy	17000.00
0005435438096	24576	Economy	17000.00
0005435630959	24576	Economy	17000.00
0005435681983	24576	Economy	17000.00
0005435682080	24576	Economy	17000.00
0005435681984	24576	Economy	17000.00
0005435438082	24576	Economy	17000.00
0005435681939	24576	Economy	17000.00
0005432305763	24576	Economy	17000.00
0005435661919	24576	Economy	17000.00
0005435630955	24576	Economy	17000.00
0005435681826	24576	Economy	17000.00
0005435438097	24576	Economy	17000.00
0005435681942	24576	Economy	17000.00
0005435438088	24576	Economy	17000.00
0005435126592	11522	Business	26400.00
0005435105999	11522	Business	26400.00
0005435126590	11522	Business	26400.00
0005435126576	11522	Business	26400.00
0005435126602	11522	Business	26400.00
0005435126597	11522	Business	26400.00
0005435126600	11522	Business	26400.00
0005435126569	11522	Economy	8800.00
0005435126572	11522	Economy	8800.00
0005435126594	11522	Economy	8800.00
0005435126583	11522	Economy	8800.00
0005435126599	11522	Economy	8800.00
0005435126577	11522	Economy	8800.00
0005435126581	11522	Economy	9700.00
0005435126584	11522	Economy	8800.00
0005435126570	11522	Economy	8800.00
0005435126596	11522	Economy	8800.00
0005435558072	11522	Economy	8800.00
0005435126579	11522	Economy	8800.00
0005435126589	11522	Economy	8800.00
0005435126565	11522	Economy	8800.00
0005435126580	11522	Economy	8800.00
0005435126587	11522	Economy	8800.00
0005435106001	11522	Economy	8800.00
0005435106000	11522	Economy	8800.00
0005435126595	11522	Economy	8800.00
0005435126575	11522	Economy	8800.00
0005435126588	11522	Economy	8800.00
0005435126567	11522	Economy	8800.00
0005435126582	11522	Economy	8800.00
0005435126568	11522	Economy	8800.00
0005435126574	11522	Economy	8800.00
0005435126566	11522	Economy	8800.00
0005435126564	11522	Economy	8800.00
0005435126603	11522	Economy	8800.00
0005435105998	11522	Economy	8800.00
0005435126586	11522	Economy	8800.00
0005435126598	11522	Economy	8800.00
0005435126563	11522	Economy	8800.00
0005435126591	11522	Economy	8800.00
0005435126571	11522	Economy	8800.00
0005435126578	11522	Economy	8800.00
0005435126585	11522	Economy	8800.00
0005435126601	11522	Economy	8800.00
0005435126593	11522	Economy	8800.00
0005435558085	11522	Economy	8800.00
0005435126573	11522	Economy	8800.00
0005435126604	11522	Economy	8800.00
0005435105997	11522	Economy	8800.00
0005435558073	11522	Economy	8800.00
0005435126157	31857	Business	26400.00
0005435126440	31857	Business	26400.00
0005435126383	31857	Economy	8800.00
0005435126171	31857	Economy	8800.00
0005435558101	31857	Economy	9700.00
0005435126127	31857	Economy	9700.00
0005435126317	31857	Economy	9700.00
0005435126289	31857	Economy	8800.00
0005435126152	31857	Economy	8800.00
0005435126401	31857	Economy	8800.00
0005435126235	31857	Economy	8800.00
0005435126153	31857	Economy	8800.00
0005435558102	31857	Economy	8800.00
0005435126219	31857	Economy	8800.00
0005435126442	31857	Economy	8800.00
0005435126357	31857	Economy	8800.00
0005435126356	31857	Economy	8800.00
0005435126300	31857	Economy	8800.00
0005435126172	31857	Economy	8800.00
0005435126239	31857	Economy	8800.00
0005435126400	31857	Economy	8800.00
0005435126355	31857	Economy	8800.00
0005435126297	31857	Economy	8800.00
0005435126208	31857	Economy	8800.00
0005435126551	31857	Economy	8800.00
0005435126315	31857	Economy	8800.00
0005435105975	31857	Economy	8800.00
0005435558103	31857	Economy	8800.00
0005435126243	31857	Economy	8800.00
0005435126288	31857	Economy	8800.00
0005435126298	31857	Economy	8800.00
0005435126382	31857	Economy	8800.00
0005435126128	31857	Economy	8800.00
0005435126417	31857	Economy	8800.00
0005435126316	31857	Economy	8800.00
0005435126257	31857	Economy	8800.00
0005435126125	31857	Economy	8800.00
0005435126299	31857	Economy	8800.00
0005435126318	31857	Economy	8800.00
0005435126162	31857	Economy	8800.00
0005435126236	31857	Economy	8800.00
0005435126158	31857	Economy	8800.00
0005435126314	31857	Economy	8800.00
0005435126284	31857	Economy	8800.00
0005435126237	31857	Economy	8800.00
0005433398361	13506	Business	36600.00
0005435732309	13506	Business	36600.00
0005433398362	13506	Business	36600.00
0005433398358	13506	Business	36600.00
0005435732296	13506	Business	36600.00
0005433398364	13506	Economy	12200.00
0005433398365	13506	Economy	12200.00
0005433398333	13506	Economy	12200.00
0005433398353	13506	Economy	12200.00
0005433398344	13506	Economy	12200.00
0005433398369	13506	Economy	12200.00
0005433398345	13506	Economy	12200.00
0005433398342	13506	Economy	13400.00
0005433398334	13506	Economy	13400.00
0005433398351	13506	Economy	13400.00
0005433398356	13506	Economy	13400.00
0005433398355	13506	Economy	12200.00
0005433398343	13506	Economy	12200.00
0005435732310	13506	Economy	12200.00
0005435732312	13506	Economy	12200.00
0005433398347	13506	Economy	12200.00
0005435732307	13506	Economy	12200.00
0005433398327	13506	Economy	12200.00
0005433398346	13506	Economy	12200.00
0005433398331	13506	Economy	12200.00
0005433398336	13506	Economy	12200.00
0005433398341	13506	Economy	12200.00
0005433398352	13506	Economy	12200.00
0005433398372	13506	Economy	12200.00
0005435732308	13506	Economy	12200.00
0005433398324	13506	Economy	12200.00
0005433398354	13506	Economy	12200.00
0005433398328	13506	Economy	12200.00
0005433398368	13506	Economy	12200.00
0005433398323	13506	Economy	12200.00
0005433398326	13506	Economy	12200.00
0005435732295	13506	Economy	12200.00
0005433398322	13506	Economy	12200.00
0005433398359	13506	Economy	12200.00
0005435732297	13506	Economy	12200.00
0005433398338	13506	Economy	12200.00
0005433398329	13506	Economy	12200.00
0005433398366	13506	Economy	12200.00
0005433398360	13506	Economy	12200.00
0005433398371	13506	Economy	12200.00
0005433398332	13506	Economy	12200.00
0005433398349	13506	Economy	12200.00
0005433398335	13506	Economy	12200.00
0005433398363	13506	Economy	12200.00
0005435732316	13506	Economy	12200.00
0005433398348	13506	Economy	12200.00
0005433398350	13506	Economy	12200.00
0005433398325	13506	Economy	12200.00
0005433398357	13506	Economy	12200.00
0005433398330	13506	Economy	12200.00
0005433398337	13506	Economy	12200.00
0005433398339	13506	Economy	12200.00
0005433398340	13506	Economy	12200.00
0005433398370	13506	Economy	12200.00
0005433398367	13506	Economy	12200.00
0005433398089	19420	Business	36600.00
0005433398254	19420	Business	36600.00
0005433398115	19420	Business	36600.00
0005433397813	19420	Business	36600.00
0005433397688	19420	Business	36600.00
0005433397874	19420	Business	36600.00
0005433397844	19420	Business	36600.00
0005433397726	19420	Economy	12200.00
0005433398116	19420	Economy	12200.00
0005433397812	19420	Economy	12200.00
0005433397969	19420	Economy	12200.00
0005433397867	19420	Economy	12200.00
0005433397979	19420	Economy	12200.00
0005433397974	19420	Economy	13400.00
0005433398094	19420	Economy	13400.00
0005433398255	19420	Economy	13400.00
0005433397948	19420	Economy	13400.00
0005433397996	19420	Economy	12200.00
0005433397968	19420	Economy	12200.00
0005433398093	19420	Economy	12200.00
0005435732392	19420	Economy	12200.00
0005433397947	19420	Economy	12200.00
0005433398014	19420	Economy	12200.00
0005433397842	19420	Economy	12200.00
0005433398033	19420	Economy	12200.00
0005432297292	19420	Economy	12200.00
0005433397958	19420	Economy	12200.00
0005435732394	19420	Economy	12200.00
0005433397785	19420	Economy	12200.00
0005433397901	19420	Economy	12200.00
0005433397959	19420	Economy	12200.00
0005432297293	19420	Economy	12200.00
0005433398012	19420	Economy	12200.00
0005433397819	19420	Economy	12200.00
0005433397940	19420	Economy	12200.00
0005432297294	19420	Economy	12200.00
0005435732390	19420	Economy	12200.00
0005433397938	19420	Economy	12200.00
0005433398071	19420	Economy	12200.00
0005435732393	19420	Economy	12200.00
0005433398020	19420	Economy	12200.00
0005433397973	19420	Economy	12200.00
0005433397900	19420	Economy	12200.00
0005433397854	19420	Economy	12200.00
0005433398023	19420	Economy	12200.00
0005433397811	19420	Economy	12200.00
0005433397939	19420	Economy	12200.00
0005433397781	19420	Economy	12200.00
0005433397962	19420	Economy	12200.00
0005433398035	19420	Economy	12200.00
0005435732391	19420	Economy	12200.00
0005433397721	19420	Economy	12200.00
0005433397936	19420	Economy	12200.00
0005433397899	19420	Economy	12200.00
0005433397873	19420	Economy	12200.00
0005433398016	19420	Economy	12200.00
0005433397749	19420	Economy	12200.00
0005433397851	19420	Economy	12200.00
0005433398017	19420	Economy	12200.00
0005433397951	19420	Economy	12200.00
0005433397980	19420	Economy	12200.00
0005433397841	19420	Economy	12200.00
0005435068912	13153	Business	11300.00
0005435069037	13153	Business	11300.00
0005435925373	13153	Business	11300.00
0005435068984	13153	Business	11300.00
0005435068818	13153	Business	11300.00
0005435069071	13153	Business	11300.00
0005435925367	13153	Business	11300.00
0005435068812	13153	Business	11300.00
0005435068636	13153	Economy	3800.00
0005435069070	13153	Economy	3800.00
0005435068905	13153	Economy	3800.00
0005435069012	13153	Economy	3800.00
0005435925374	13153	Economy	3800.00
0005435925372	13153	Economy	3800.00
0005435069008	13153	Economy	3800.00
0005435068766	13153	Economy	3800.00
0005435068844	13153	Economy	4100.00
0005435925366	13153	Economy	4100.00
0005435068796	13153	Economy	4100.00
0005435925384	13153	Economy	4100.00
0005435068892	13153	Economy	3800.00
0005435069038	13153	Economy	3800.00
0005435925386	13153	Economy	3800.00
0005435069035	13153	Economy	3800.00
0005435069097	13153	Economy	3800.00
0005435068946	13153	Economy	3800.00
0005435068981	13153	Economy	3800.00
0005435069152	13153	Economy	3800.00
0005435069009	13153	Economy	3800.00
0005435068961	13153	Economy	3800.00
0005435925383	13153	Economy	3800.00
0005435068825	13153	Economy	3800.00
0005435068883	13153	Economy	3800.00
0005435068863	13153	Economy	3800.00
0005435068797	13153	Economy	3800.00
0005435068876	13153	Economy	3800.00
0005435069054	13153	Economy	3800.00
0005435068890	13153	Economy	3800.00
0005435068904	13153	Economy	3800.00
0005435068783	13153	Economy	3800.00
0005435068837	13153	Economy	3800.00
0005435925378	13153	Economy	3800.00
0005435925365	13153	Economy	3800.00
0005435068869	13153	Economy	3800.00
0005435925381	13153	Economy	3800.00
0005435068824	13153	Economy	3800.00
0005435068983	13153	Economy	3800.00
0005435925369	13153	Economy	3800.00
0005435925370	13153	Economy	3800.00
0005435925375	13153	Economy	3800.00
0005435068635	13153	Economy	3800.00
0005435925376	13153	Economy	3800.00
0005435925379	13153	Economy	3800.00
0005435068776	13153	Economy	3800.00
0005435068862	13153	Economy	3800.00
0005435925385	13153	Economy	3800.00
0005435068990	13153	Economy	3800.00
0005435925377	13153	Economy	3800.00
0005435925371	13153	Economy	3800.00
0005435925382	13153	Economy	3800.00
0005435068928	13153	Economy	3800.00
0005435925368	13153	Economy	3800.00
0005435068877	13153	Economy	3800.00
0005435068875	13153	Economy	3800.00
0005435068767	13153	Economy	3800.00
0005435069096	13153	Economy	3800.00
0005435068871	13153	Economy	3800.00
0005435925380	13153	Economy	3800.00
0005435069026	13153	Economy	3800.00
0005435068977	13153	Economy	3800.00
0005435068962	13153	Economy	3800.00
0005435068652	13153	Economy	3800.00
0005435068956	13153	Economy	3800.00
0005435068775	13153	Economy	3800.00
0005435068845	13153	Economy	3800.00
0005435069362	15507	Business	11300.00
0005435069347	15507	Business	11300.00
0005435069353	15507	Business	11300.00
0005435925244	15507	Business	11300.00
0005435925270	15507	Business	11300.00
0005435069325	15507	Business	11300.00
0005435925250	15507	Business	11300.00
0005435925249	15507	Business	11300.00
0005435069352	15507	Business	11300.00
0005435069346	15507	Economy	3800.00
0005435069355	15507	Economy	3800.00
0005435069373	15507	Economy	3800.00
0005435069343	15507	Economy	3800.00
0005435069330	15507	Economy	3800.00
0005435069367	15507	Economy	3800.00
0005435925247	15507	Economy	3800.00
0005435069332	15507	Economy	4100.00
0005435069349	15507	Economy	4100.00
0005435925207	15507	Economy	4100.00
0005435069375	15507	Economy	4100.00
0005435069333	15507	Economy	3800.00
0005435925269	15507	Economy	3800.00
0005435069339	15507	Economy	3800.00
0005435069329	15507	Economy	3800.00
0005435069327	15507	Economy	3800.00
0005435069360	15507	Economy	3800.00
0005435069348	15507	Economy	3800.00
0005435069345	15507	Economy	3800.00
0005435069335	15507	Economy	3800.00
0005435069341	15507	Economy	3800.00
0005435069365	15507	Economy	3800.00
0005435069370	15507	Economy	3800.00
0005435069376	15507	Economy	3800.00
0005435069328	15507	Economy	3800.00
0005435069351	15507	Economy	3800.00
0005435069342	15507	Economy	3800.00
0005435069324	15507	Economy	3800.00
0005435069350	15507	Economy	3800.00
0005435069358	15507	Economy	3800.00
0005435069371	15507	Economy	3800.00
0005435069344	15507	Economy	3800.00
0005435925221	15507	Economy	3800.00
0005435069337	15507	Economy	3800.00
0005435069338	15507	Economy	3800.00
0005435069369	15507	Economy	3800.00
0005435925256	15507	Economy	3800.00
0005435925209	15507	Economy	3800.00
0005435069374	15507	Economy	3800.00
0005435069357	15507	Economy	3800.00
0005435069363	15507	Economy	3800.00
0005435925222	15507	Economy	3800.00
0005435069372	15507	Economy	3800.00
0005435925208	15507	Economy	3800.00
0005435925239	15507	Economy	3800.00
0005435069354	15507	Economy	3800.00
0005435069334	15507	Economy	3800.00
0005435925268	15507	Economy	3800.00
0005435069356	15507	Economy	3800.00
0005435069364	15507	Economy	3800.00
0005435069368	15507	Economy	3800.00
0005435925246	15507	Economy	3800.00
0005435069366	15507	Economy	3800.00
0005435069340	15507	Economy	3800.00
0005435069331	15507	Economy	3800.00
0005435925252	15507	Economy	3800.00
0005435069359	15507	Economy	3800.00
0005435069361	15507	Economy	3800.00
0005435925245	15507	Economy	3800.00
0005435069326	15507	Economy	3800.00
0005435069336	15507	Economy	3800.00
0005433407592	29489	Economy	27100.00
0005435808210	29489	Economy	27100.00
0005435808176	29489	Economy	27100.00
0005435808167	29489	Economy	24700.00
0005435808208	29489	Economy	24700.00
0005435808153	29489	Economy	24700.00
0005435808230	29489	Economy	24700.00
0005435808140	29489	Economy	24700.00
0005433407599	29489	Economy	24700.00
0005433407596	29489	Economy	24700.00
0005433407595	29489	Economy	24700.00
0005435808211	29489	Economy	24700.00
0005435808144	29489	Economy	24700.00
0005433407600	29489	Economy	24700.00
0005435808184	29489	Economy	24700.00
0005435808181	29489	Economy	24700.00
0005435808229	29489	Economy	24700.00
0005435808261	29489	Economy	24700.00
0005435808209	29489	Economy	24700.00
0005433407598	29489	Economy	24700.00
0005435808260	29489	Economy	24700.00
0005435808191	29489	Economy	24700.00
0005435808162	29489	Economy	24700.00
0005435808186	29489	Economy	24700.00
0005435808192	29489	Economy	24700.00
0005435808166	29489	Economy	24700.00
0005435808136	29489	Economy	24700.00
0005435808183	29489	Economy	24700.00
0005435808185	29489	Economy	24700.00
0005433407593	29489	Economy	24700.00
0005433407594	29489	Economy	24700.00
0005433407597	29489	Economy	24700.00
0005435808141	29489	Economy	24700.00
0005434214797	10712	Business	61300.00
0005434214795	10712	Business	61300.00
0005434214801	10712	Business	61300.00
0005434756195	10712	Business	61300.00
0005434756231	10712	Business	61300.00
0005434756306	10712	Business	61300.00
0005434756305	10712	Business	61300.00
0005434214824	10712	Business	61300.00
0005434756289	10712	Business	61300.00
0005434214822	10712	Business	61300.00
0005434214819	10712	Business	61300.00
0005434756326	10712	Business	61300.00
0005434214820	10712	Economy	20400.00
0005434214823	10712	Economy	20400.00
0005434756215	10712	Economy	20400.00
0005434756256	10712	Economy	20400.00
0005434756320	10712	Economy	20400.00
0005434756216	10712	Economy	20400.00
0005434214832	10712	Economy	20400.00
0005434214833	10712	Economy	20400.00
0005434214814	10712	Economy	20400.00
0005434214794	10712	Economy	22500.00
0005434214827	10712	Economy	22500.00
0005434756293	10712	Economy	22500.00
0005434756349	10712	Economy	22500.00
0005434756196	10712	Economy	22500.00
0005434214838	10712	Economy	20400.00
0005434214818	10712	Economy	20400.00
0005434756240	10712	Economy	20400.00
0005434756265	10712	Economy	20400.00
0005434214808	10712	Economy	20400.00
0005434214811	10712	Economy	20400.00
0005434214839	10712	Economy	20400.00
0005434214821	10712	Economy	20400.00
0005434756335	10712	Economy	20400.00
0005434756187	10712	Economy	20400.00
0005434756332	10712	Economy	20400.00
0005434214793	10712	Economy	20400.00
0005434214807	10712	Economy	20400.00
0005434756156	10712	Economy	20400.00
0005434756247	10712	Economy	20400.00
0005434756334	10712	Economy	20400.00
0005434214825	10712	Economy	20400.00
0005434214802	10712	Economy	20400.00
0005434756313	10712	Economy	20400.00
0005434214809	10712	Economy	20400.00
0005434214815	10712	Economy	20400.00
0005434214817	10712	Economy	20400.00
0005434214836	10712	Economy	20400.00
0005434756319	10712	Economy	20400.00
0005434756283	10712	Economy	20400.00
0005434214812	10712	Economy	20400.00
0005434756188	10712	Economy	20400.00
0005434756154	10712	Economy	20400.00
0005434756257	10712	Economy	20400.00
0005434755984	10712	Economy	20400.00
0005434214830	10712	Economy	20400.00
0005434214798	10712	Economy	20400.00
0005434756333	10712	Economy	20400.00
0005434214799	10712	Economy	20400.00
0005434214834	10712	Economy	20400.00
0005434756246	10712	Economy	20400.00
0005434214806	10712	Economy	20400.00
0005434214803	10712	Economy	20400.00
0005434214831	10712	Economy	20400.00
0005434756350	10712	Economy	20400.00
0005434214816	10712	Economy	20400.00
0005434756351	10712	Economy	20400.00
0005434214828	10712	Economy	20400.00
0005434756327	10712	Economy	20400.00
0005434756155	10712	Economy	20400.00
0005434756235	10712	Economy	20400.00
0005434756090	10712	Economy	20400.00
0005434214813	10712	Economy	20400.00
0005434214800	10712	Economy	20400.00
0005434214804	10712	Economy	20400.00
0005434756201	10712	Economy	20400.00
0005434214835	10712	Economy	20400.00
0005434756321	10712	Economy	20400.00
0005434756345	10712	Economy	20400.00
0005434214810	10712	Economy	20400.00
0005434214805	10712	Economy	20400.00
0005434214826	10712	Economy	20400.00
0005434214796	10712	Economy	20400.00
0005434214829	10712	Economy	20400.00
0005434756282	10712	Economy	20400.00
0005434756331	10712	Economy	20400.00
0005434214837	10712	Economy	20400.00
0005434756625	28662	Business	61300.00
0005434756638	28662	Business	61300.00
0005434214462	28662	Business	61300.00
0005434756648	28662	Business	61300.00
0005434756652	28662	Business	61300.00
0005434214191	28662	Business	61300.00
0005434214265	28662	Business	61300.00
0005434756630	28662	Business	61300.00
0005434214461	28662	Business	61300.00
0005434756623	28662	Business	61300.00
0005434756653	28662	Business	61300.00
0005434214450	28662	Business	61300.00
0005434756655	28662	Economy	20400.00
0005434214113	28662	Economy	20400.00
0005434756642	28662	Economy	20400.00
0005434756650	28662	Economy	20400.00
0005434214256	28662	Economy	20400.00
0005434756633	28662	Economy	20400.00
0005434214180	28662	Economy	20400.00
0005434214297	28662	Economy	20400.00
0005434214323	28662	Economy	20400.00
0005434214292	28662	Economy	20400.00
0005434214151	28662	Economy	22500.00
0005434756656	28662	Economy	22500.00
0005434756624	28662	Economy	22500.00
0005434756657	28662	Economy	22500.00
0005434214155	28662	Economy	22500.00
0005434214147	28662	Economy	20400.00
0005434756640	28662	Economy	20400.00
0005434214370	28662	Economy	20400.00
0005434756645	28662	Economy	20400.00
0005434756632	28662	Economy	20400.00
0005434214458	28662	Economy	20400.00
0005434756637	28662	Economy	20400.00
0005434756649	28662	Economy	20400.00
0005434214263	28662	Economy	20400.00
0005434214435	28662	Economy	20400.00
0005434214345	28662	Economy	20400.00
0005434214359	28662	Economy	20400.00
0005434756631	28662	Economy	20400.00
0005434756651	28662	Economy	20400.00
0005434756614	28662	Economy	20400.00
0005434214244	28662	Economy	20400.00
0005434214296	28662	Economy	20400.00
0005434214169	28662	Economy	20400.00
0005434756658	28662	Economy	20400.00
0005434214429	28662	Economy	20400.00
0005434756661	28662	Economy	20400.00
0005434214451	28662	Economy	20400.00
0005434214321	28662	Economy	20400.00
0005434756628	28662	Economy	20400.00
0005434214324	28662	Economy	20400.00
0005434756643	28662	Economy	20400.00
0005434214136	28662	Economy	20400.00
0005434214408	28662	Economy	20400.00
0005434756618	28662	Economy	20400.00
0005434756613	28662	Economy	20400.00
0005434756647	28662	Economy	20400.00
0005434756619	28662	Economy	20400.00
0005434756621	28662	Economy	20400.00
0005434756659	28662	Economy	20400.00
0005434756627	28662	Economy	20400.00
0005434756646	28662	Economy	20400.00
0005434214347	28662	Economy	20400.00
0005434214135	28662	Economy	20400.00
0005434756634	28662	Economy	20400.00
0005434214371	28662	Economy	20400.00
0005434214570	28662	Economy	20400.00
0005434214452	28662	Economy	20400.00
0005434756654	28662	Economy	20400.00
0005434214168	28662	Economy	20400.00
0005434756622	28662	Economy	20400.00
0005434756662	28662	Economy	20400.00
0005434214344	28662	Economy	20400.00
0005434214283	28662	Economy	20400.00
0005434756644	28662	Economy	20400.00
0005434756617	28662	Economy	20400.00
0005434214477	28662	Economy	20400.00
0005434756615	28662	Economy	20400.00
0005434214282	28662	Economy	20400.00
0005434756616	28662	Economy	20400.00
0005434756636	28662	Economy	20400.00
0005434756660	28662	Economy	20400.00
0005434756664	28662	Economy	20400.00
0005434214434	28662	Economy	20400.00
0005434214134	28662	Economy	20400.00
0005434756639	28662	Economy	20400.00
0005434756641	28662	Economy	20400.00
0005434756620	28662	Economy	20400.00
0005434214279	28662	Economy	20400.00
0005434756663	28662	Economy	20400.00
0005434756629	28662	Economy	20400.00
0005434756635	28662	Economy	20400.00
0005434756626	28662	Economy	20400.00
0005435040140	5458	Business	29500.00
0005435040155	5458	Business	29500.00
0005435040178	5458	Business	29500.00
0005435007176	5458	Business	29500.00
0005434229230	5458	Business	29500.00
0005435040146	5458	Business	29500.00
0005435040171	5458	Business	29500.00
0005435040190	5458	Business	29500.00
0005435007161	5458	Business	29500.00
0005435040151	5458	Business	29500.00
0005435042867	5458	Business	29500.00
0005435040137	5458	Business	29500.00
0005435040153	5458	Economy	9800.00
0005435007163	5458	Economy	9800.00
0005434229295	5458	Economy	9800.00
0005435040135	5458	Economy	9800.00
0005435040139	5458	Economy	9800.00
0005435042866	5458	Economy	9800.00
0005435007177	5458	Economy	9800.00
0005435042868	5458	Economy	9800.00
0005434229321	5458	Economy	9800.00
0005435040188	5458	Economy	9800.00
0005435040133	5458	Economy	9800.00
0005435040165	5458	Economy	9800.00
0005435007167	5458	Economy	9800.00
0005435040159	5458	Economy	9800.00
0005434229291	5458	Economy	9800.00
0005435040192	5458	Economy	9800.00
0005435040169	5458	Economy	9800.00
0005435040149	5458	Economy	9800.00
0005435040193	5458	Economy	9800.00
0005435040145	5458	Economy	9800.00
0005435040182	5458	Economy	9800.00
0005435040144	5458	Economy	9800.00
0005435040181	5458	Economy	9800.00
0005434229310	5458	Economy	9800.00
0005434229309	5458	Economy	9800.00
0005432125496	5458	Economy	9800.00
0005435040154	5458	Economy	9800.00
0005435007166	5458	Economy	9800.00
0005435007169	5458	Economy	9800.00
0005435040175	5458	Economy	9800.00
0005435040186	5458	Economy	9800.00
0005435042869	5458	Economy	10800.00
0005435040162	5458	Economy	10800.00
0005435043290	5458	Economy	10800.00
0005435040158	5458	Economy	10800.00
0005435040166	5458	Economy	9800.00
0005435040142	5458	Economy	9800.00
0005435007165	5458	Economy	9800.00
0005435040185	5458	Economy	9800.00
0005435040136	5458	Economy	9800.00
0005434229325	5458	Economy	9800.00
0005435040148	5458	Economy	9800.00
0005434229288	5458	Economy	9800.00
0005435007171	5458	Economy	9800.00
0005435040150	5458	Economy	9800.00
0005432125499	5458	Economy	9800.00
0005435040157	5458	Economy	9800.00
0005435040168	5458	Economy	9800.00
0005434229300	5458	Economy	9800.00
0005434229374	5458	Economy	9800.00
0005435007175	5458	Economy	9800.00
0005435040187	5458	Economy	9800.00
0005435040179	5458	Economy	9800.00
0005432125498	5458	Economy	9800.00
0005435040132	5458	Economy	9800.00
0005435040174	5458	Economy	9800.00
0005435040170	5458	Economy	9800.00
0005435040141	5458	Economy	9800.00
0005435040176	5458	Economy	9800.00
0005434229387	5458	Economy	9800.00
0005435040147	5458	Economy	9800.00
0005435040183	5458	Economy	9800.00
0005434229355	5458	Economy	9800.00
0005434229202	5458	Economy	9800.00
0005435040173	5458	Economy	9800.00
0005435042870	5458	Economy	9800.00
0005432125493	5458	Economy	9800.00
0005434229324	5458	Economy	9800.00
0005435040172	5458	Economy	9800.00
0005435043291	5458	Economy	9800.00
0005435007172	5458	Economy	9800.00
0005435040161	5458	Economy	9800.00
0005432125497	5458	Economy	9800.00
0005435040156	5458	Economy	9800.00
0005435377902	5458	Economy	9800.00
0005435040180	5458	Economy	9800.00
0005434229201	5458	Economy	9800.00
0005435040184	5458	Economy	9800.00
0005432125495	5458	Economy	9800.00
0005435007174	5458	Economy	9800.00
0005435040138	5458	Economy	9800.00
0005435040134	5458	Economy	9800.00
0005435040143	5458	Economy	9800.00
0005432125494	5458	Economy	9800.00
0005435040194	5458	Economy	9800.00
0005435007162	5458	Economy	9800.00
0005435007164	5458	Economy	9800.00
0005435007173	5458	Economy	9800.00
0005435377903	5458	Economy	9800.00
0005435040163	5458	Economy	9800.00
0005434229348	5458	Economy	9800.00
0005435007170	5458	Economy	9800.00
0005435040152	5458	Economy	9800.00
0005435040177	5458	Economy	9800.00
0005435040167	5458	Economy	9800.00
0005435007168	5458	Economy	9800.00
0005435040189	5458	Economy	9800.00
0005435040191	5458	Economy	9800.00
0005435377901	5458	Economy	9800.00
0005435040164	5458	Economy	9800.00
0005435040160	5458	Economy	9800.00
0005435006918	12965	Business	29500.00
0005435039350	12965	Business	29500.00
0005434229499	12965	Business	29500.00
0005435039579	12965	Business	29500.00
0005435006960	12965	Business	29500.00
0005434229517	12965	Business	29500.00
0005435039545	12965	Business	29500.00
0005435039561	12965	Business	29500.00
0005435039532	12965	Business	29500.00
0005435039906	12965	Business	29500.00
0005435006961	12965	Business	29500.00
0005434229513	12965	Economy	9800.00
0005435039383	12965	Economy	9800.00
0005435039775	12965	Economy	9800.00
0005435039803	12965	Economy	9800.00
0005435039491	12965	Economy	9800.00
0005435039629	12965	Economy	9800.00
0005435006975	12965	Economy	9800.00
0005435039428	12965	Economy	9800.00
0005435039573	12965	Economy	9800.00
0005435039710	12965	Economy	9800.00
0005435006917	12965	Economy	9800.00
0005435039767	12965	Economy	9800.00
0005435039389	12965	Economy	9800.00
0005435039624	12965	Economy	9800.00
0005435006895	12965	Economy	9800.00
0005432304422	12965	Economy	9800.00
0005434229515	12965	Economy	9800.00
0005435039773	12965	Economy	9800.00
0005435006940	12965	Economy	9800.00
0005434229507	12965	Economy	9800.00
0005435039801	12965	Economy	9800.00
0005435039724	12965	Economy	9800.00
0005435039625	12965	Economy	9800.00
0005435039732	12965	Economy	9800.00
0005435006957	12965	Economy	9800.00
0005435039818	12965	Economy	9800.00
0005435006990	12965	Economy	9800.00
0005435006939	12965	Economy	9800.00
0005435039652	12965	Economy	9800.00
0005434229520	12965	Economy	9800.00
0005435039861	12965	Economy	9800.00
0005434229511	12965	Economy	9800.00
0005434229519	12965	Economy	9800.00
0005434229509	12965	Economy	9800.00
0005432304423	12965	Economy	9800.00
0005435039804	12965	Economy	9800.00
0005435039270	12965	Economy	9800.00
0005435039517	12965	Economy	9800.00
0005435007002	12965	Economy	9800.00
0005435039769	12965	Economy	9800.00
0005434229508	12965	Economy	10800.00
0005435039607	12965	Economy	10800.00
0005434229500	12965	Economy	10800.00
0005435039384	12965	Economy	10800.00
0005435039580	12965	Economy	10800.00
0005432304421	12965	Economy	10800.00
0005435039647	12965	Economy	9800.00
0005435039787	12965	Economy	9800.00
0005435039650	12965	Economy	9800.00
0005435039765	12965	Economy	9800.00
0005435039800	12965	Economy	9800.00
0005435039642	12965	Economy	9800.00
0005434229518	12965	Economy	9800.00
0005435039563	12965	Economy	9800.00
0005435039518	12965	Economy	9800.00
0005435039492	12965	Economy	9800.00
0005434229514	12965	Economy	9800.00
0005435039838	12965	Economy	9800.00
0005434229512	12965	Economy	9800.00
0005435039562	12965	Economy	9800.00
0005435039860	12965	Economy	9800.00
0005434229504	12965	Economy	9800.00
0005435006984	12965	Economy	9800.00
0005435039651	12965	Economy	9800.00
0005435039837	12965	Economy	9800.00
0005435039477	12965	Economy	9800.00
0005434229502	12965	Economy	9800.00
0005435039667	12965	Economy	9800.00
0005434229503	12965	Economy	9800.00
0005435039456	12965	Economy	9800.00
0005435039760	12965	Economy	9800.00
0005435039516	12965	Economy	9800.00
0005435039450	12965	Economy	9800.00
0005435039777	12965	Economy	9800.00
0005435039478	12965	Economy	9800.00
0005435039817	12965	Economy	9800.00
0005434229510	12965	Economy	9800.00
0005435039863	12965	Economy	9800.00
0005435039266	12965	Economy	9800.00
0005435039774	12965	Economy	9800.00
0005435039468	12965	Economy	9800.00
0005435039678	12965	Economy	9800.00
0005435006995	12965	Economy	9800.00
0005435039489	12965	Economy	9800.00
0005435039263	12965	Economy	9800.00
0005435042846	12965	Economy	9800.00
0005435006974	12965	Economy	9800.00
0005435039603	12965	Economy	9800.00
0005435039725	12965	Economy	9800.00
0005435039786	12965	Economy	9800.00
0005434229501	12965	Economy	9800.00
0005435039416	12965	Economy	9800.00
0005435039824	12965	Economy	9800.00
0005435039655	12965	Economy	9800.00
0005435006953	12965	Economy	9800.00
0005435039630	12965	Economy	9800.00
0005435039833	12965	Economy	9800.00
0005435039668	12965	Economy	9800.00
0005435039785	12965	Economy	9800.00
0005434229498	12965	Economy	9800.00
0005435039604	12965	Economy	9800.00
0005435006956	12965	Economy	9800.00
0005435039726	12965	Economy	9800.00
0005435006888	12965	Economy	9800.00
0005435039697	12965	Economy	9800.00
0005434229506	12965	Economy	9800.00
0005435039653	12965	Economy	9800.00
0005435039519	12965	Economy	9800.00
0005435039731	12965	Economy	9800.00
0005435007025	12965	Economy	9800.00
0005435039311	12965	Economy	9800.00
0005435039271	12965	Economy	9800.00
0005434229516	12965	Economy	9800.00
0005435039548	12965	Economy	9800.00
0005434229505	12965	Economy	9800.00
0005435039496	12965	Economy	9800.00
0005435039654	12965	Economy	9800.00
0005435039768	12965	Economy	9800.00
0005435902663	14894	Business	52900.00
0005434411798	14894	Business	52900.00
0005435554149	14894	Business	52900.00
0005435902684	14894	Business	52900.00
0005434426763	14894	Business	52900.00
0005434426767	14894	Business	52900.00
0005435554166	14894	Business	52900.00
0005435554151	14894	Business	52900.00
0005434426750	14894	Economy	17600.00
0005434411800	14894	Economy	17600.00
0005435902668	14894	Economy	17600.00
0005434426773	14894	Economy	17600.00
0005432188624	14894	Economy	17600.00
0005434426766	14894	Economy	17600.00
0005434426753	14894	Economy	17600.00
0005435902670	14894	Economy	17600.00
0005435902575	14894	Economy	17600.00
0005435554169	14894	Economy	19400.00
0005435902643	14894	Economy	19400.00
0005434426752	14894	Economy	19400.00
0005434426774	14894	Economy	17600.00
0005435902658	14894	Economy	17600.00
0005435902549	14894	Economy	17600.00
0005435902660	14894	Economy	17600.00
0005434426777	14894	Economy	17600.00
0005435554177	14894	Economy	17600.00
0005434426760	14894	Economy	17600.00
0005434426748	14894	Economy	17600.00
0005434426761	14894	Economy	17600.00
0005434411803	14894	Economy	17600.00
0005435902683	14894	Economy	17600.00
0005434426758	14894	Economy	17600.00
0005434426756	14894	Economy	17600.00
0005435902637	14894	Economy	17600.00
0005434426754	14894	Economy	17600.00
0005435554152	14894	Economy	17600.00
0005434426775	14894	Economy	17600.00
0005435902630	14894	Economy	17600.00
0005434426759	14894	Economy	17600.00
0005434411799	14894	Economy	17600.00
0005434426770	14894	Economy	17600.00
0005434426769	14894	Economy	17600.00
0005434426755	14894	Economy	17600.00
0005435902627	14894	Economy	17600.00
0005434426771	14894	Economy	17600.00
0005435554168	14894	Economy	17600.00
0005435902576	14894	Economy	17600.00
0005435902669	14894	Economy	17600.00
0005435902685	14894	Economy	17600.00
0005435902628	14894	Economy	17600.00
0005435902578	14894	Economy	17600.00
0005434426772	14894	Economy	17600.00
0005435554172	14894	Economy	17600.00
0005435902577	14894	Economy	17600.00
0005434426762	14894	Economy	17600.00
0005434411801	14894	Economy	17600.00
0005434426768	14894	Economy	17600.00
0005432188623	14894	Economy	17600.00
0005435554165	14894	Economy	17600.00
0005434426764	14894	Economy	17600.00
0005434426776	14894	Economy	17600.00
0005432188625	14894	Economy	17600.00
0005435902657	14894	Economy	17600.00
0005435902613	14894	Economy	17600.00
0005435902681	14894	Economy	17600.00
0005434426749	14894	Economy	17600.00
0005435554171	14894	Economy	17600.00
0005434426765	14894	Economy	17600.00
0005434426757	14894	Economy	17600.00
0005435554170	14894	Economy	17600.00
0005434411802	14894	Economy	17600.00
0005434426751	14894	Economy	17600.00
0005435554150	14894	Economy	17600.00
0005435902636	14894	Economy	17600.00
0005435902635	14894	Economy	17600.00
0005435902804	20190	Business	52900.00
0005434426572	20190	Business	52900.00
0005434426517	20190	Business	52900.00
0005435902807	20190	Business	52900.00
0005434411766	20190	Business	52900.00
0005434426526	20190	Business	52900.00
0005432059517	20190	Business	52900.00
0005434426438	20190	Economy	17600.00
0005435554219	20190	Economy	17600.00
0005434426499	20190	Economy	17600.00
0005435902813	20190	Economy	17600.00
0005434411773	20190	Economy	17600.00
0005434426498	20190	Economy	19400.00
0005435902808	20190	Economy	19400.00
0005435902817	20190	Economy	19400.00
0005434426500	20190	Economy	17600.00
0005435902820	20190	Economy	17600.00
0005434426516	20190	Economy	17600.00
0005434426646	20190	Economy	17600.00
0005434426551	20190	Economy	17600.00
0005434426645	20190	Economy	17600.00
0005434426652	20190	Economy	17600.00
0005435902811	20190	Economy	17600.00
0005434426515	20190	Economy	17600.00
0005434426519	20190	Economy	17600.00
0005435902806	20190	Economy	17600.00
0005434426623	20190	Economy	17600.00
0005434411772	20190	Economy	17600.00
0005434426638	20190	Economy	17600.00
0005434426642	20190	Economy	17600.00
0005434426482	20190	Economy	17600.00
0005435902815	20190	Economy	17600.00
0005434426524	20190	Economy	17600.00
0005434426525	20190	Economy	17600.00
0005434426548	20190	Economy	17600.00
0005434426489	20190	Economy	17600.00
0005435554218	20190	Economy	17600.00
0005435902809	20190	Economy	17600.00
0005434426656	20190	Economy	17600.00
0005435554221	20190	Economy	17600.00
0005434426616	20190	Economy	17600.00
0005434426583	20190	Economy	17600.00
0005434426622	20190	Economy	17600.00
0005432059516	20190	Economy	17600.00
0005435902805	20190	Economy	17600.00
0005435554220	20190	Economy	17600.00
0005434426518	20190	Economy	17600.00
0005434426428	20190	Economy	17600.00
0005434426577	20190	Economy	17600.00
0005435902810	20190	Economy	17600.00
0005434426639	20190	Economy	17600.00
0005434426481	20190	Economy	17600.00
0005435902818	20190	Economy	17600.00
0005434426644	20190	Economy	17600.00
0005434426490	20190	Economy	17600.00
0005434426538	20190	Economy	17600.00
0005435902814	20190	Economy	17600.00
0005434426567	20190	Economy	17600.00
0005434426643	20190	Economy	17600.00
0005435902812	20190	Economy	17600.00
0005435902816	20190	Economy	17600.00
0005435902819	20190	Economy	17600.00
0005434426630	20190	Economy	17600.00
0005434426488	20190	Economy	17600.00
0005434411767	20190	Economy	17600.00
0005434523768	28009	Business	106800.00
0005432462528	28009	Business	106800.00
0005434523752	28009	Economy	35600.00
0005434523763	28009	Economy	35600.00
0005434523772	28009	Economy	35600.00
0005434523765	28009	Economy	35600.00
0005434523764	28009	Economy	35600.00
0005434523762	28009	Economy	35600.00
0005432462527	28009	Economy	35600.00
0005432462526	28009	Economy	35600.00
0005434523749	28009	Economy	35600.00
0005434523773	28009	Economy	35600.00
0005434523766	28009	Economy	35600.00
0005432462524	28009	Economy	35600.00
0005432462525	28009	Economy	35600.00
0005434523761	28009	Economy	35600.00
0005435982567	26553	Business	18500.00
0005435982553	26553	Business	18500.00
0005433434449	26553	Business	18500.00
0005433434629	26553	Business	18500.00
0005433434573	26553	Business	18500.00
0005433434662	26553	Business	18500.00
0005433434572	26553	Business	18500.00
0005435982544	26553	Business	18500.00
0005433434619	26553	Business	18500.00
0005433434554	26553	Business	18500.00
0005433434450	26553	Economy	6200.00
0005435982549	26553	Economy	6200.00
0005435982562	26553	Economy	6200.00
0005435982560	26553	Economy	6200.00
0005433434630	26553	Economy	6200.00
0005435982566	26553	Economy	6200.00
0005435982555	26553	Economy	6200.00
0005435982558	26553	Economy	6200.00
0005435982552	26553	Economy	6200.00
0005435982547	26553	Economy	6200.00
0005432300296	26553	Economy	6800.00
0005433434636	26553	Economy	6800.00
0005434273072	26553	Economy	6800.00
0005433434527	26553	Economy	6800.00
0005435982534	26553	Economy	6200.00
0005435982528	26553	Economy	6200.00
0005435982569	26553	Economy	6200.00
0005433434596	26553	Economy	6200.00
0005435982542	26553	Economy	6200.00
0005435982538	26553	Economy	6200.00
0005432300294	26553	Economy	6200.00
0005433434580	26553	Economy	6200.00
0005433434470	26553	Economy	6200.00
0005433434587	26553	Economy	6200.00
0005433434471	26553	Economy	6200.00
0005433434526	26553	Economy	6200.00
0005433434620	26553	Economy	6200.00
0005435982564	26553	Economy	6200.00
0005435982568	26553	Economy	6200.00
0005435982554	26553	Economy	6200.00
0005435982530	26553	Economy	6200.00
0005432300295	26553	Economy	6200.00
0005435982565	26553	Economy	6200.00
0005433434562	26553	Economy	6200.00
0005433434483	26553	Economy	6200.00
0005435982551	26553	Economy	6200.00
0005435982548	26553	Economy	6200.00
0005433434715	26553	Economy	6200.00
0005435982536	26553	Economy	6200.00
0005435982532	26553	Economy	6200.00
0005433434621	26553	Economy	6200.00
0005435982545	26553	Economy	6200.00
0005435982561	26553	Economy	6200.00
0005435982541	26553	Economy	6200.00
0005435982557	26553	Economy	6200.00
0005433434597	26553	Economy	6200.00
0005433434563	26553	Economy	6200.00
0005433434594	26553	Economy	6200.00
0005432300291	26553	Economy	6200.00
0005433434561	26553	Economy	6200.00
0005435982543	26553	Economy	6200.00
0005435982546	26553	Economy	6200.00
0005433434599	26553	Economy	6200.00
0005435982539	26553	Economy	6200.00
0005433434575	26553	Economy	6200.00
0005435982556	26553	Economy	6200.00
0005433434595	26553	Economy	6200.00
0005435982533	26553	Economy	6200.00
0005435982527	26553	Economy	6200.00
0005435982537	26553	Economy	6200.00
0005435982531	26553	Economy	6200.00
0005434273074	26553	Economy	6200.00
0005435982563	26553	Economy	6200.00
0005435982570	26553	Economy	6200.00
0005435982550	26553	Economy	6200.00
0005433434482	26553	Economy	6200.00
0005432300293	26553	Economy	6200.00
0005433434674	26553	Economy	6200.00
0005434273073	26553	Economy	6200.00
0005435982559	26553	Economy	6200.00
0005433434574	26553	Economy	6200.00
0005435982540	26553	Economy	6200.00
0005435982529	26553	Economy	6200.00
0005432300292	26553	Economy	6200.00
0005435982535	26553	Economy	6200.00
0005435982197	26695	Business	18500.00
0005435982126	26695	Business	18500.00
0005435982183	26695	Business	18500.00
0005435982075	26695	Business	18500.00
0005435982073	26695	Business	18500.00
0005435981919	26695	Business	18500.00
0005432051149	26695	Business	18500.00
0005435981971	26695	Business	18500.00
0005434270220	26695	Business	18500.00
0005433434850	26695	Business	18500.00
0005435982130	26695	Business	18500.00
0005435982196	26695	Economy	6200.00
0005435982058	26695	Economy	6200.00
0005435982286	26695	Economy	6200.00
0005434271324	26695	Economy	6200.00
0005433434849	26695	Economy	6200.00
0005434271326	26695	Economy	6200.00
0005433434845	26695	Economy	6200.00
0005433434865	26695	Economy	6200.00
0005433434847	26695	Economy	6200.00
0005435982090	26695	Economy	6800.00
0005433434844	26695	Economy	6800.00
0005435982281	26695	Economy	6800.00
0005435982225	26695	Economy	6800.00
0005433434862	26695	Economy	6800.00
0005433434863	26695	Economy	6200.00
0005435981972	26695	Economy	6200.00
0005433434846	26695	Economy	6200.00
0005433434848	26695	Economy	6200.00
0005433434868	26695	Economy	6200.00
0005434269117	26695	Economy	6200.00
0005433434852	26695	Economy	6200.00
0005432051146	26695	Economy	6200.00
0005435982053	26695	Economy	6200.00
0005435982057	26695	Economy	6200.00
0005433434864	26695	Economy	6200.00
0005433434854	26695	Economy	6200.00
0005435982269	26695	Economy	6200.00
0005435982315	26695	Economy	6200.00
0005435982052	26695	Economy	6200.00
0005435982018	26695	Economy	6200.00
0005433434866	26695	Economy	6200.00
0005435982158	26695	Economy	6200.00
0005435982125	26695	Economy	6200.00
0005435982282	26695	Economy	6200.00
0005432051147	26695	Economy	6200.00
0005435982113	26695	Economy	6200.00
0005434271325	26695	Economy	6200.00
0005435982262	26695	Economy	6200.00
0005435982204	26695	Economy	6200.00
0005433434853	26695	Economy	6200.00
0005433434855	26695	Economy	6200.00
0005435981988	26695	Economy	6200.00
0005435982084	26695	Economy	6200.00
0005435982171	26695	Economy	6200.00
0005435982314	26695	Economy	6200.00
0005435982182	26695	Economy	6200.00
0005433434851	26695	Economy	6200.00
0005435982238	26695	Economy	6200.00
0005433434842	26695	Economy	6200.00
0005435982270	26695	Economy	6200.00
0005435982237	26695	Economy	6200.00
0005434270219	26695	Economy	6200.00
0005435982271	26695	Economy	6200.00
0005433434861	26695	Economy	6200.00
0005435982205	26695	Economy	6200.00
0005435982206	26695	Economy	6200.00
0005435982101	26695	Economy	6200.00
0005435982157	26695	Economy	6200.00
0005435982229	26695	Economy	6200.00
0005433434843	26695	Economy	6200.00
0005435982181	26695	Economy	6200.00
0005435982098	26695	Economy	6200.00
0005435982214	26695	Economy	6200.00
0005433434870	26695	Economy	6200.00
0005435982076	26695	Economy	6200.00
0005433434859	26695	Economy	6200.00
0005435982161	26695	Economy	6200.00
0005435982127	26695	Economy	6200.00
0005435982059	26695	Economy	6200.00
0005433434856	26695	Economy	6200.00
0005433434867	26695	Economy	6200.00
0005433434858	26695	Economy	6200.00
0005435982285	26695	Economy	6200.00
0005435982100	26695	Economy	6200.00
0005432051148	26695	Economy	6200.00
0005435982093	26695	Economy	6200.00
0005433434869	26695	Economy	6200.00
0005433434860	26695	Economy	6200.00
0005433434857	26695	Economy	6200.00
0005434269116	26695	Economy	6200.00
0005433686628	29270	Economy	19100.00
0005433686626	29270	Economy	19100.00
0005433689899	29270	Economy	19100.00
0005433686630	29270	Economy	19100.00
0005433686625	29270	Economy	19100.00
0005433689910	29270	Economy	19100.00
0005433686608	29270	Economy	19100.00
0005433686629	29270	Economy	19100.00
0005433689909	29270	Economy	19100.00
0005433689898	29270	Economy	19100.00
0005432858052	3145	Economy	11100.00
0005432857986	3145	Economy	11100.00
0005432584194	3145	Economy	11100.00
0005432584176	3145	Economy	11100.00
0005432584192	3145	Economy	10100.00
0005432858018	3145	Economy	10100.00
0005432584177	3145	Economy	10100.00
0005432584193	3145	Economy	10100.00
0005432584179	3145	Economy	10100.00
0005432584178	3145	Economy	10100.00
0005432216289	3145	Economy	10100.00
0005432584197	3145	Economy	10100.00
0005432584198	3145	Economy	10100.00
0005432216290	3145	Economy	10100.00
0005432584199	3145	Economy	10100.00
0005432584200	3145	Economy	10100.00
0005432584180	3145	Economy	10100.00
0005432584186	3145	Economy	10100.00
0005432584183	3145	Economy	10100.00
0005432584196	3145	Economy	10100.00
0005432858055	3145	Economy	10100.00
0005432584195	3145	Economy	10100.00
0005432858050	3145	Economy	10100.00
0005432857987	3145	Economy	10100.00
0005432584188	3145	Economy	10100.00
0005432584189	3145	Economy	10100.00
0005432858053	3145	Economy	10100.00
0005432858039	3145	Economy	10100.00
0005432584181	3145	Economy	10100.00
0005432584185	3145	Economy	10100.00
0005432584190	3145	Economy	10100.00
0005432584191	3145	Economy	10100.00
0005432858041	3145	Economy	10100.00
0005432858070	3145	Economy	10100.00
0005432584187	3145	Economy	10100.00
0005432858115	3145	Economy	10100.00
0005432584184	3145	Economy	10100.00
0005432216291	3145	Economy	10100.00
0005432584182	3145	Economy	10100.00
0005432583875	31521	Economy	11100.00
0005432583962	31521	Economy	11100.00
0005432858143	31521	Economy	10100.00
0005432584079	31521	Economy	10100.00
0005432583947	31521	Economy	10100.00
0005432858139	31521	Economy	10100.00
0005432584005	31521	Economy	10100.00
0005432858142	31521	Economy	10100.00
0005432584023	31521	Economy	10100.00
0005432583874	31521	Economy	10100.00
0005432584084	31521	Economy	10100.00
0005432858137	31521	Economy	10100.00
0005432583948	31521	Economy	10100.00
0005432583979	31521	Economy	10100.00
0005432584078	31521	Economy	10100.00
0005432583946	31521	Economy	10100.00
0005432584081	31521	Economy	10100.00
0005432584085	31521	Economy	10100.00
0005432858140	31521	Economy	10100.00
0005432584051	31521	Economy	10100.00
0005432858145	31521	Economy	10100.00
0005432583961	31521	Economy	10100.00
0005432858146	31521	Economy	10100.00
0005432584015	31521	Economy	10100.00
0005432858141	31521	Economy	10100.00
0005432584034	31521	Economy	10100.00
0005432584022	31521	Economy	10100.00
0005432858144	31521	Economy	10100.00
0005432584080	31521	Economy	10100.00
0005432583881	31521	Economy	10100.00
0005432584047	31521	Economy	10100.00
0005432858135	31521	Economy	10100.00
0005432583976	31521	Economy	10100.00
0005432583975	31521	Economy	10100.00
0005432858147	31521	Economy	10100.00
0005432858136	31521	Economy	10100.00
0005432858138	31521	Economy	10100.00
0005432583999	31521	Economy	10100.00
0005434943410	907	Economy	8300.00
0005434943409	907	Economy	7500.00
0005433255078	907	Economy	7500.00
0005433255104	907	Economy	7500.00
0005433255099	907	Economy	7500.00
0005433255089	907	Economy	7500.00
0005434943411	907	Economy	7500.00
0005433255103	907	Economy	7500.00
0005434943404	907	Economy	7500.00
0005434943403	907	Economy	7500.00
0005434943407	907	Economy	7500.00
0005434943408	907	Economy	7500.00
0005434943405	907	Economy	7500.00
0005434943406	907	Economy	7500.00
0005433255151	16234	Economy	7500.00
0005434943363	16234	Economy	7500.00
0005433255154	16234	Economy	7500.00
0005434943321	16234	Economy	7500.00
0005434943322	16234	Economy	7500.00
0005434943320	16234	Economy	7500.00
0005433255153	16234	Economy	7500.00
0005433255152	16234	Economy	7500.00
0005434943302	16234	Economy	7500.00
0005434943316	16234	Economy	7500.00
0005433255150	16234	Economy	7500.00
0005434943364	16234	Economy	7500.00
0005434943377	16234	Economy	7500.00
0005434943334	16234	Economy	7500.00
0005434943378	16234	Economy	7500.00
0005435653291	21751	Business	9800.00
0005435653278	21751	Business	9800.00
0005433367726	21751	Business	9800.00
0005435653283	21751	Business	9800.00
0005435653273	21751	Business	9800.00
0005433367857	21751	Business	9800.00
0005433367826	21751	Business	9800.00
0005435653284	21751	Business	9800.00
0005435653262	21751	Business	9800.00
0005435653269	21751	Economy	3300.00
0005433367825	21751	Economy	3300.00
0005433367819	21751	Economy	3300.00
0005435653268	21751	Economy	3300.00
0005435653290	21751	Economy	3300.00
0005433367649	21751	Economy	3300.00
0005433367704	21751	Economy	3300.00
0005433367849	21751	Economy	3300.00
0005435653263	21751	Economy	3600.00
0005435653279	21751	Economy	3600.00
0005435653288	21751	Economy	3600.00
0005433367611	21751	Economy	3600.00
0005433367571	21751	Economy	3300.00
0005433367745	21751	Economy	3300.00
0005435653281	21751	Economy	3300.00
0005433367688	21751	Economy	3300.00
0005435653287	21751	Economy	3300.00
0005433367722	21751	Economy	3300.00
0005435653264	21751	Economy	3300.00
0005433367706	21751	Economy	3300.00
0005433367744	21751	Economy	3300.00
0005433367867	21751	Economy	3300.00
0005433367628	21751	Economy	3300.00
0005433367752	21751	Economy	3300.00
0005435653289	21751	Economy	3300.00
0005433367705	21751	Economy	3300.00
0005435653270	21751	Economy	3300.00
0005433367643	21751	Economy	3300.00
0005435653266	21751	Economy	3300.00
0005435653285	21751	Economy	3300.00
0005435653294	21751	Economy	3300.00
0005433367572	21751	Economy	3300.00
0005433367850	21751	Economy	3300.00
0005433367823	21751	Economy	3300.00
0005435653271	21751	Economy	3300.00
0005435653274	21751	Economy	3300.00
0005435653277	21751	Economy	3300.00
0005435653267	21751	Economy	3300.00
0005433367607	21751	Economy	3300.00
0005433367760	21751	Economy	3300.00
0005435653280	21751	Economy	3300.00
0005433367687	21751	Economy	3300.00
0005433367832	21751	Economy	3300.00
0005435653293	21751	Economy	3300.00
0005435653272	21751	Economy	3300.00
0005433367721	21751	Economy	3300.00
0005433367796	21751	Economy	3300.00
0005435653265	21751	Economy	3300.00
0005433367822	21751	Economy	3300.00
0005435653282	21751	Economy	3300.00
0005435653275	21751	Economy	3300.00
0005433367727	21751	Economy	3300.00
0005433367821	21751	Economy	3300.00
0005433367845	21751	Economy	3300.00
0005435653286	21751	Economy	3300.00
0005433367606	21751	Economy	3300.00
0005433367854	21751	Economy	3300.00
0005433367759	21751	Economy	3300.00
0005433367907	21751	Economy	3300.00
0005435653292	21751	Economy	3300.00
0005433367700	21751	Economy	3300.00
0005433367602	21751	Economy	3300.00
0005435653276	21751	Economy	3300.00
0005433805593	9340	Business	186200.00
0005433805586	9340	Business	186200.00
0005433763293	9340	Business	186200.00
0005434273071	9340	Business	186200.00
0005435269700	9340	Business	186200.00
0005435269737	9340	Business	186200.00
0005433805595	9340	Business	186200.00
0005432667465	9340	Business	186200.00
0005433805606	9340	Business	186200.00
0005433805613	9340	Business	186200.00
0005433785169	9340	Business	186200.00
0005433785159	9340	Business	186200.00
0005433785154	9340	Business	186200.00
0005432667466	9340	Business	186200.00
0005434171100	9340	Business	186200.00
0005432657466	9340	Business	186200.00
0005434171092	9340	Business	186200.00
0005435269736	9340	Business	186200.00
0005433763290	9340	Economy	68300.00
0005433805609	9340	Economy	68300.00
0005433805605	9340	Economy	68300.00
0005435269712	9340	Economy	62100.00
0005433805588	9340	Economy	62100.00
0005433785177	9340	Economy	62100.00
0005433805591	9340	Economy	62100.00
0005433805597	9340	Economy	62100.00
0005433785160	9340	Economy	62100.00
0005433785172	9340	Economy	62100.00
0005433785175	9340	Economy	62100.00
0005434171028	9340	Economy	62100.00
0005433785157	9340	Economy	62100.00
0005434273069	9340	Economy	62100.00
0005433763294	9340	Economy	62100.00
0005433805590	9340	Economy	62100.00
0005433805583	9340	Economy	62100.00
0005433785168	9340	Economy	62100.00
0005434171057	9340	Economy	62100.00
0005432667468	9340	Economy	62100.00
0005433785183	9340	Economy	62100.00
0005435269738	9340	Economy	62100.00
0005433763301	9340	Economy	62100.00
0005434171016	9340	Economy	62100.00
0005433805601	9340	Economy	62100.00
0005433785186	9340	Economy	62100.00
0005433805598	9340	Economy	62100.00
0005435269710	9340	Economy	62100.00
0005433785158	9340	Economy	62100.00
0005433805582	9340	Economy	62100.00
0005433805573	9340	Economy	62100.00
0005433785184	9340	Economy	62100.00
0005433785171	9340	Economy	62100.00
0005434171099	9340	Economy	62100.00
0005433763299	9340	Economy	62100.00
0005433805592	9340	Economy	62100.00
0005433763300	9340	Economy	62100.00
0005433805584	9340	Economy	62100.00
0005434270209	9340	Economy	62100.00
0005433805600	9340	Economy	62100.00
0005434171020	9340	Economy	62100.00
0005433805589	9340	Economy	62100.00
0005433763291	9340	Economy	62100.00
0005433805599	9340	Economy	62100.00
0005433763297	9340	Economy	62100.00
0005433785185	9340	Economy	62100.00
0005433785174	9340	Economy	62100.00
0005434171021	9340	Economy	62100.00
0005435269735	9340	Economy	62100.00
0005433805587	9340	Economy	62100.00
0005435269739	9340	Economy	62100.00
0005433785176	9340	Economy	62100.00
0005433805580	9340	Economy	62100.00
0005434171027	9340	Economy	62100.00
0005434171094	9340	Economy	62100.00
0005432667467	9340	Economy	62100.00
0005433785162	9340	Economy	62100.00
0005434171024	9340	Economy	62100.00
0005434171026	9340	Economy	62100.00
0005435269701	9340	Economy	62100.00
0005434171019	9340	Economy	62100.00
0005433805614	9340	Economy	62100.00
0005433785156	9340	Economy	62100.00
0005433785179	9340	Economy	62100.00
0005433785178	9340	Economy	62100.00
0005433763288	9340	Economy	62100.00
0005433785187	9340	Economy	62100.00
0005432666402	9340	Economy	62100.00
0005433785163	9340	Economy	62100.00
0005433805615	9340	Economy	68300.00
0005432665286	9340	Economy	68300.00
0005433805612	9340	Economy	68300.00
0005433763295	9340	Economy	68300.00
0005434171015	9340	Economy	62100.00
0005435269740	9340	Economy	62100.00
0005433785181	9340	Economy	62100.00
0005433805585	9340	Economy	62100.00
0005433763298	9340	Economy	62100.00
0005433805594	9340	Economy	62100.00
0005433785155	9340	Economy	62100.00
0005433785180	9340	Economy	62100.00
0005433763292	9340	Economy	62100.00
0005433805607	9340	Economy	62100.00
0005433805577	9340	Economy	62100.00
0005433805604	9340	Economy	62100.00
0005433785170	9340	Economy	62100.00
0005433785167	9340	Economy	62100.00
0005434151683	9340	Economy	62100.00
0005433785153	9340	Economy	62100.00
0005433805608	9340	Economy	62100.00
0005433805611	9340	Economy	62100.00
0005434151707	9340	Economy	62100.00
0005433805610	9340	Economy	62100.00
0005433805576	9340	Economy	62100.00
0005435269699	9340	Economy	62100.00
0005432657467	9340	Economy	62100.00
0005434171025	9340	Economy	62100.00
0005433785164	9340	Economy	62100.00
0005432665287	9340	Economy	62100.00
0005433785166	9340	Economy	62100.00
0005433763296	9340	Economy	62100.00
0005433763287	9340	Economy	62100.00
0005435269711	9340	Economy	62100.00
0005432666400	9340	Economy	62100.00
0005434270203	9340	Economy	62100.00
0005433805603	9340	Economy	62100.00
0005435269734	9340	Economy	62100.00
0005434171093	9340	Economy	62100.00
0005433785165	9340	Economy	62100.00
0005433785173	9340	Economy	62100.00
0005433785182	9340	Economy	62100.00
0005433805596	9340	Economy	62100.00
0005435269730	9340	Economy	62100.00
0005432666401	9340	Economy	62100.00
0005433805579	9340	Economy	62100.00
0005433805574	9340	Economy	62100.00
0005433805581	9340	Economy	62100.00
0005434270195	9340	Economy	62100.00
0005433805575	9340	Economy	62100.00
0005433763289	9340	Economy	62100.00
0005433805578	9340	Economy	62100.00
0005433805602	9340	Economy	62100.00
0005432657468	9340	Economy	62100.00
0005433785161	9340	Economy	62100.00
0005434171022	9340	Economy	62100.00
0005435269692	9340	Economy	62100.00
0005435269725	9340	Economy	62100.00
0005433763169	26220	Business	186200.00
0005433805274	26220	Business	186200.00
0005433784961	26220	Business	186200.00
0005433785034	26220	Business	186200.00
0005433763212	26220	Business	186200.00
0005433784858	26220	Business	186200.00
0005434269115	26220	Business	186200.00
0005433805360	26220	Business	186200.00
0005433784842	26220	Business	186200.00
0005433784841	26220	Business	186200.00
0005435269777	26220	Business	186200.00
0005433763117	26220	Business	186200.00
0005432663016	26220	Business	186200.00
0005433784864	26220	Business	186200.00
0005433785042	26220	Business	186200.00
0005434171136	26220	Business	186200.00
0005433763140	26220	Economy	68300.00
0005433784800	26220	Economy	68300.00
0005434171142	26220	Economy	68300.00
0005435269783	26220	Economy	62100.00
0005433805270	26220	Economy	62100.00
0005434171144	26220	Economy	62100.00
0005433805264	26220	Economy	62100.00
0005433784934	26220	Economy	62100.00
0005433763137	26220	Economy	62100.00
0005433805310	26220	Economy	62100.00
0005433805346	26220	Economy	62100.00
0005433805361	26220	Economy	62100.00
0005434171145	26220	Economy	62100.00
0005433805293	26220	Economy	62100.00
0005433805235	26220	Economy	62100.00
0005433784940	26220	Economy	62100.00
0005434151721	26220	Economy	62100.00
0005433784840	26220	Economy	62100.00
0005434269114	26220	Economy	62100.00
0005433805217	26220	Economy	62100.00
0005433763159	26220	Economy	62100.00
0005433763195	26220	Economy	62100.00
0005433763180	26220	Economy	62100.00
0005433763116	26220	Economy	62100.00
0005434271323	26220	Economy	62100.00
0005433784812	26220	Economy	62100.00
0005434171143	26220	Economy	62100.00
0005433805178	26220	Economy	62100.00
0005433805398	26220	Economy	62100.00
0005433805282	26220	Economy	62100.00
0005433805301	26220	Economy	62100.00
0005433805269	26220	Economy	62100.00
0005435269780	26220	Economy	62100.00
0005435269782	26220	Economy	62100.00
0005433784960	26220	Economy	62100.00
0005433805344	26220	Economy	62100.00
0005435269781	26220	Economy	62100.00
0005432659703	26220	Economy	62100.00
0005433805304	26220	Economy	62100.00
0005433784724	26220	Economy	62100.00
0005433805359	26220	Economy	62100.00
0005434171148	26220	Economy	62100.00
0005433763131	26220	Economy	62100.00
0005433763171	26220	Economy	62100.00
0005433784839	26220	Economy	62100.00
0005434171146	26220	Economy	62100.00
0005433805161	26220	Economy	62100.00
0005433784853	26220	Economy	62100.00
0005433805237	26220	Economy	62100.00
0005433805204	26220	Economy	62100.00
0005434151722	26220	Economy	62100.00
0005433784827	26220	Economy	62100.00
0005433805281	26220	Economy	62100.00
0005433784921	26220	Economy	62100.00
0005433805177	26220	Economy	62100.00
0005433784889	26220	Economy	62100.00
0005433784922	26220	Economy	62100.00
0005433805462	26220	Economy	62100.00
0005433763194	26220	Economy	62100.00
0005433805332	26220	Economy	62100.00
0005433784811	26220	Economy	68300.00
0005434171147	26220	Economy	62100.00
0005433805182	26220	Economy	62100.00
0005433805294	26220	Economy	62100.00
0005433784852	26220	Economy	62100.00
0005434171139	26220	Economy	62100.00
0005433784939	26220	Economy	62100.00
0005433805345	26220	Economy	62100.00
0005434270217	26220	Economy	62100.00
0005435269784	26220	Economy	62100.00
0005433784894	26220	Economy	62100.00
0005433805135	26220	Economy	62100.00
0005433805338	26220	Economy	62100.00
0005433805295	26220	Economy	62100.00
0005433805148	26220	Economy	62100.00
0005433805300	26220	Economy	62100.00
0005435269779	26220	Economy	62100.00
0005434171141	26220	Economy	62100.00
0005433805236	26220	Economy	62100.00
0005433805176	26220	Economy	62100.00
0005434171138	26220	Economy	62100.00
0005435269778	26220	Economy	62100.00
0005433763193	26220	Economy	62100.00
0005433805305	26220	Economy	62100.00
0005434271322	26220	Economy	62100.00
0005434171137	26220	Economy	62100.00
0005433805331	26220	Economy	62100.00
0005433805500	26220	Economy	62100.00
0005435269785	26220	Economy	62100.00
0005433763211	26220	Economy	62100.00
0005432659704	26220	Economy	62100.00
0005433784946	26220	Economy	62100.00
0005433784878	26220	Economy	62100.00
0005434171140	26220	Economy	62100.00
0005433805327	26220	Economy	62100.00
0005433784725	26220	Economy	62100.00
0005434270218	26220	Economy	62100.00
0005433805499	26220	Economy	62100.00
0005433763170	26220	Economy	62100.00
0005433784843	26220	Economy	62100.00
0005433805132	26220	Economy	62100.00
0005433784728	26220	Economy	62100.00
0005432666374	26220	Economy	62100.00
0005435929631	4919	Economy	5900.00
0005435929633	4919	Economy	5300.00
0005435135699	4919	Economy	5300.00
0005435135701	4919	Economy	5300.00
0005435929649	4919	Economy	5300.00
0005435135698	4919	Economy	5300.00
0005435929632	4919	Economy	5300.00
0005435135697	4919	Economy	5300.00
0005435135700	4919	Economy	5300.00
0005435929660	33011	Economy	5300.00
0005435135670	33011	Economy	5300.00
0005435929661	33011	Economy	5300.00
0005435929659	33011	Economy	5300.00
0005435135674	33011	Economy	5300.00
0005435135662	33011	Economy	5300.00
0005435135669	33011	Economy	5300.00
0005435135673	33011	Economy	5300.00
0005434983317	9466	Economy	17900.00
0005434983320	9466	Economy	17900.00
0005434983318	9466	Economy	17900.00
0005434983319	9466	Economy	17900.00
0005434983321	9466	Economy	17900.00
0005434217995	27361	Economy	19700.00
0005434983293	27361	Economy	19700.00
0005434217991	27361	Economy	17900.00
0005434983270	27361	Economy	17900.00
0005434217992	27361	Economy	17900.00
0005434983265	27361	Economy	17900.00
0005434983290	27361	Economy	17900.00
0005434983294	27361	Economy	17900.00
0005434983292	27361	Economy	17900.00
0005434983285	27361	Economy	17900.00
0005434217994	27361	Economy	17900.00
0005434983286	27361	Economy	17900.00
0005434983261	27361	Economy	17900.00
0005434217993	27361	Economy	17900.00
0005433960726	24233	Business	36400.00
0005433960532	24233	Business	36400.00
0005433960730	24233	Business	36400.00
0005433960624	24233	Business	36400.00
0005433985855	24233	Business	36400.00
0005433960607	24233	Business	36400.00
0005433960672	24233	Business	36400.00
0005433960524	24233	Business	36400.00
0005433985729	24233	Business	36400.00
0005433985809	24233	Business	36400.00
0005433960461	24233	Business	36400.00
0005433985716	24233	Business	36400.00
0005433960652	24233	Business	36400.00
0005433960544	24233	Business	36400.00
0005433985814	24233	Economy	13400.00
0005433960346	24233	Economy	12100.00
0005433960414	24233	Economy	12100.00
0005433960347	24233	Economy	12100.00
0005433985818	24233	Economy	12100.00
0005433960634	24233	Economy	12100.00
0005433985641	24233	Economy	12100.00
0005433985819	24233	Economy	12100.00
0005433960597	24233	Economy	12100.00
0005433960696	24233	Economy	12100.00
0005433960704	24233	Economy	12100.00
0005433985833	24233	Economy	12100.00
0005433985719	24233	Economy	12100.00
0005433960690	24233	Economy	12100.00
0005433960626	24233	Economy	12100.00
0005433985858	24233	Economy	12100.00
0005433985759	24233	Economy	12100.00
0005433985635	24233	Economy	12100.00
0005433985608	24233	Economy	12100.00
0005433985723	24233	Economy	12100.00
0005433960677	24233	Economy	12100.00
0005433985622	24233	Economy	12100.00
0005433985628	24233	Economy	12100.00
0005433985654	24233	Economy	12100.00
0005433960695	24233	Economy	12100.00
0005433960499	24233	Economy	12100.00
0005433960526	24233	Economy	12100.00
0005433960681	24233	Economy	12100.00
0005433985695	24233	Economy	12100.00
0005433985629	24233	Economy	12100.00
0005433960545	24233	Economy	12100.00
0005433960543	24233	Economy	12100.00
0005433960727	24233	Economy	12100.00
0005433960714	24233	Economy	12100.00
0005433960697	24233	Economy	12100.00
0005433985810	24233	Economy	12100.00
0005433985696	24233	Economy	12100.00
0005433985871	24233	Economy	12100.00
0005433960553	24233	Economy	12100.00
0005433985739	24233	Economy	12100.00
0005433960689	24233	Economy	12100.00
0005433960354	24233	Economy	12100.00
0005433985930	24233	Economy	12100.00
0005433960648	24233	Economy	12100.00
0005433960646	24233	Economy	12100.00
0005433985731	24233	Economy	12100.00
0005433985872	24233	Economy	12100.00
0005433985807	24233	Economy	12100.00
0005433985928	24233	Economy	12100.00
0005433960585	24233	Economy	12100.00
0005433986040	24233	Economy	12100.00
0005433960529	24233	Economy	12100.00
0005433960547	24233	Economy	12100.00
0005433985732	24233	Economy	12100.00
0005433960603	24233	Economy	12100.00
0005433960453	24233	Economy	12100.00
0005433985707	24233	Economy	12100.00
0005433960452	24233	Economy	12100.00
0005433960343	24233	Economy	12100.00
0005433960390	24233	Economy	12100.00
0005433985633	24233	Economy	12100.00
0005433985828	24233	Economy	12100.00
0005433985730	24233	Economy	12100.00
0005433985870	24233	Economy	13400.00
0005433960495	24233	Economy	13400.00
0005433960471	24233	Economy	13400.00
0005433960525	24233	Economy	13400.00
0005433960722	24233	Economy	12100.00
0005433985694	24233	Economy	12100.00
0005433960653	24233	Economy	12100.00
0005433960683	24233	Economy	12100.00
0005433960669	24233	Economy	12100.00
0005433985841	24233	Economy	12100.00
0005433960599	24233	Economy	12100.00
0005433985811	24233	Economy	12100.00
0005433960668	24233	Economy	12100.00
0005433960713	24233	Economy	12100.00
0005433960500	24233	Economy	12100.00
0005433960533	24233	Economy	12100.00
0005433960584	24233	Economy	12100.00
0005433960415	24233	Economy	12100.00
0005433985706	24233	Economy	12100.00
0005433960633	24233	Economy	12100.00
0005433960738	24233	Economy	12100.00
0005433986021	24233	Economy	12100.00
0005433960418	24233	Economy	12100.00
0005433960701	24233	Economy	12100.00
0005433960304	24233	Economy	12100.00
0005433985634	24233	Economy	12100.00
0005433960692	24233	Economy	12100.00
0005433985700	24233	Economy	12100.00
0005433985655	24233	Economy	12100.00
0005433960586	24233	Economy	12100.00
0005433985773	24233	Economy	12100.00
0005433960691	24233	Economy	12100.00
0005433985701	24233	Economy	12100.00
0005433960700	24233	Economy	12100.00
0005433960546	24233	Economy	12100.00
0005433985607	24233	Economy	12100.00
0005433960419	24233	Economy	12100.00
0005433960723	24233	Economy	12100.00
0005433960715	24233	Economy	12100.00
0005433960731	24233	Economy	12100.00
0005433985708	24233	Economy	12100.00
0005433960649	24233	Economy	12100.00
0005433986176	25921	Business	36400.00
0005433961168	25921	Business	36400.00
0005433961188	25921	Business	36400.00
0005433961183	25921	Business	36400.00
0005433986194	25921	Business	36400.00
0005433961186	25921	Business	36400.00
0005433961165	25921	Business	36400.00
0005433986191	25921	Business	36400.00
0005433961177	25921	Business	36400.00
0005433961170	25921	Business	36400.00
0005433986192	25921	Economy	13400.00
0005433961197	25921	Economy	12100.00
0005433961173	25921	Economy	12100.00
0005433961187	25921	Economy	12100.00
0005433961206	25921	Economy	12100.00
0005433961196	25921	Economy	12100.00
0005433961180	25921	Economy	12100.00
0005433986190	25921	Economy	12100.00
0005433961178	25921	Economy	12100.00
0005433986204	25921	Economy	12100.00
0005433961207	25921	Economy	12100.00
0005433986213	25921	Economy	12100.00
0005433986210	25921	Economy	12100.00
0005433986182	25921	Economy	12100.00
0005433986203	25921	Economy	12100.00
0005433961182	25921	Economy	12100.00
0005433961179	25921	Economy	12100.00
0005433961204	25921	Economy	12100.00
0005433961203	25921	Economy	12100.00
0005433961166	25921	Economy	12100.00
0005433961171	25921	Economy	12100.00
0005433986207	25921	Economy	12100.00
0005433961199	25921	Economy	12100.00
0005433961201	25921	Economy	12100.00
0005433986215	25921	Economy	12100.00
0005433961202	25921	Economy	12100.00
0005433986187	25921	Economy	12100.00
0005433986218	25921	Economy	12100.00
0005433961185	25921	Economy	12100.00
0005433986186	25921	Economy	12100.00
0005433986211	25921	Economy	12100.00
0005433986189	25921	Economy	12100.00
0005433986201	25921	Economy	12100.00
0005433986183	25921	Economy	12100.00
0005433986193	25921	Economy	12100.00
0005433986188	25921	Economy	12100.00
0005433961194	25921	Economy	12100.00
0005433986195	25921	Economy	12100.00
0005433986206	25921	Economy	12100.00
0005433961172	25921	Economy	12100.00
0005433986202	25921	Economy	12100.00
0005433961176	25921	Economy	12100.00
0005433986181	25921	Economy	12100.00
0005433961189	25921	Economy	13400.00
0005433961209	25921	Economy	13400.00
0005433961191	25921	Economy	12100.00
0005433986177	25921	Economy	12100.00
0005433986178	25921	Economy	13400.00
0005433961195	25921	Economy	13400.00
0005433986184	25921	Economy	12100.00
0005433986179	25921	Economy	12100.00
0005433986217	25921	Economy	12100.00
0005433986198	25921	Economy	12100.00
0005433986208	25921	Economy	12100.00
0005433961200	25921	Economy	12100.00
0005433986185	25921	Economy	12100.00
0005433986209	25921	Economy	12100.00
0005433961208	25921	Economy	12100.00
0005433986205	25921	Economy	12100.00
0005433961175	25921	Economy	12100.00
0005433961181	25921	Economy	12100.00
0005433986196	25921	Economy	12100.00
0005433961198	25921	Economy	12100.00
0005433961193	25921	Economy	12100.00
0005433986197	25921	Economy	12100.00
0005433986199	25921	Economy	12100.00
0005433986180	25921	Economy	12100.00
0005433961167	25921	Economy	12100.00
0005433961205	25921	Economy	12100.00
0005433986200	25921	Economy	12100.00
0005433961210	25921	Economy	12100.00
0005433986212	25921	Economy	12100.00
0005433961169	25921	Economy	12100.00
0005433986214	25921	Economy	12100.00
0005433961211	25921	Economy	12100.00
0005433961184	25921	Economy	12100.00
0005433986216	25921	Economy	12100.00
0005433961192	25921	Economy	12100.00
0005433961174	25921	Economy	12100.00
0005433961190	25921	Economy	12100.00
0005434480478	951	Economy	25400.00
0005432269512	951	Economy	25400.00
0005434480472	951	Economy	25400.00
0005433165873	951	Economy	23100.00
0005434480493	951	Economy	23100.00
0005434480494	951	Economy	23100.00
0005434480481	951	Economy	23100.00
0005433165888	951	Economy	23100.00
0005434480480	951	Economy	23100.00
0005434480479	951	Economy	23100.00
0005433165919	951	Economy	23100.00
0005434480484	951	Economy	23100.00
0005433165868	951	Economy	23100.00
0005434480470	951	Economy	23100.00
0005433165895	951	Economy	23100.00
0005433165901	951	Economy	23100.00
0005434480477	951	Economy	23100.00
0005434480491	951	Economy	23100.00
0005433165869	951	Economy	23100.00
0005434480474	951	Economy	23100.00
0005434480473	951	Economy	23100.00
0005433165879	951	Economy	23100.00
0005433165860	951	Economy	23100.00
0005433165917	951	Economy	23100.00
0005434480490	951	Economy	23100.00
0005433165927	951	Economy	23100.00
0005432269511	951	Economy	23100.00
0005434480487	951	Economy	23100.00
0005434480488	951	Economy	23100.00
0005434480476	951	Economy	23100.00
0005434480475	951	Economy	23100.00
0005434480486	951	Economy	23100.00
0005432269513	951	Economy	23100.00
0005434480489	951	Economy	23100.00
0005434480471	951	Economy	23100.00
0005434480482	951	Economy	23100.00
0005433165925	951	Economy	23100.00
0005434480485	951	Economy	23100.00
0005434480492	951	Economy	23100.00
0005434480495	951	Economy	23100.00
0005434480483	951	Economy	23100.00
0005434480244	16571	Economy	25400.00
0005433165987	16571	Economy	25400.00
0005434480108	16571	Economy	25400.00
0005434480240	16571	Economy	23100.00
0005434480310	16571	Economy	23100.00
0005434480139	16571	Economy	23100.00
0005434480212	16571	Economy	23100.00
0005433165984	16571	Economy	23100.00
0005434480295	16571	Economy	23100.00
0005433165989	16571	Economy	23100.00
0005434480213	16571	Economy	23100.00
0005434480138	16571	Economy	23100.00
0005433165978	16571	Economy	23100.00
0005434480305	16571	Economy	23100.00
0005433165981	16571	Economy	23100.00
0005434480354	16571	Economy	23100.00
0005433165980	16571	Economy	23100.00
0005433165979	16571	Economy	23100.00
0005434480320	16571	Economy	23100.00
0005434480268	16571	Economy	23100.00
0005434480306	16571	Economy	23100.00
0005434480190	16571	Economy	23100.00
0005433165982	16571	Economy	23100.00
0005434480319	16571	Economy	23100.00
0005434480311	16571	Economy	23100.00
0005433165988	16571	Economy	23100.00
0005433165977	16571	Economy	23100.00
0005434480289	16571	Economy	23100.00
0005433165985	16571	Economy	23100.00
0005434480232	16571	Economy	23100.00
0005434480269	16571	Economy	23100.00
0005434480241	16571	Economy	23100.00
0005433165986	16571	Economy	23100.00
0005434480291	16571	Economy	23100.00
0005434480170	16571	Economy	23100.00
0005433165983	16571	Economy	23100.00
0005434480195	16571	Economy	23100.00
0005434480264	16571	Economy	23100.00
0005434480355	16571	Economy	23100.00
0005433872503	3199	Economy	17200.00
0005433872505	3199	Economy	17200.00
0005433872507	3199	Economy	17200.00
0005433872504	3199	Economy	17200.00
0005433872508	3199	Economy	17200.00
0005433872506	3199	Economy	17200.00
0005433872487	32551	Economy	17200.00
0005433872478	32551	Economy	17200.00
0005433872472	32551	Economy	17200.00
0005433872490	32551	Economy	17200.00
0005435150103	10337	Economy	17000.00
0005433289820	10337	Economy	17000.00
0005435150094	10337	Economy	17000.00
0005435142650	10337	Economy	17000.00
0005435142649	10337	Economy	15400.00
0005435142642	10337	Economy	15400.00
0005435142648	10337	Economy	15400.00
0005435150095	10337	Economy	15400.00
0005435386563	10337	Economy	15400.00
0005435386546	10337	Economy	15400.00
0005435150101	10337	Economy	15400.00
0005435150097	10337	Economy	15400.00
0005433289817	10337	Economy	15400.00
0005435142643	10337	Economy	15400.00
0005435150098	10337	Economy	15400.00
0005435386554	10337	Economy	15400.00
0005435142641	10337	Economy	15400.00
0005435150105	10337	Economy	15400.00
0005435386547	10337	Economy	15400.00
0005435150096	10337	Economy	15400.00
0005435142653	10337	Economy	15400.00
0005435142647	10337	Economy	15400.00
0005433289821	10337	Economy	15400.00
0005435142644	10337	Economy	15400.00
0005435386562	10337	Economy	15400.00
0005435386536	10337	Economy	15400.00
0005435150093	10337	Economy	15400.00
0005435386549	10337	Economy	15400.00
0005435142640	10337	Economy	15400.00
0005435142652	10337	Economy	15400.00
0005433289849	10337	Economy	15400.00
0005435142646	10337	Economy	15400.00
0005435150102	10337	Economy	15400.00
0005435150100	10337	Economy	15400.00
0005435142645	10337	Economy	15400.00
0005435142651	10337	Economy	15400.00
0005435150099	10337	Economy	15400.00
0005435150104	10337	Economy	15400.00
0005435142480	21957	Economy	17000.00
0005435149964	21957	Economy	17000.00
0005435150018	21957	Economy	17000.00
0005435149973	21957	Economy	17000.00
0005435386610	21957	Economy	15400.00
0005435386608	21957	Economy	15400.00
0005433289898	21957	Economy	15400.00
0005435142488	21957	Economy	15400.00
0005435150008	21957	Economy	15400.00
0005435149979	21957	Economy	15400.00
0005435142589	21957	Economy	15400.00
0005433289900	21957	Economy	15400.00
0005435386607	21957	Economy	15400.00
0005435149943	21957	Economy	15400.00
0005435150015	21957	Economy	15400.00
0005433289897	21957	Economy	15400.00
0005435149920	21957	Economy	15400.00
0005433289899	21957	Economy	15400.00
0005435142557	21957	Economy	15400.00
0005435142536	21957	Economy	15400.00
0005435386606	21957	Economy	15400.00
0005435386612	21957	Economy	15400.00
0005435142552	21957	Economy	15400.00
0005435386609	21957	Economy	15400.00
0005435149921	21957	Economy	15400.00
0005435149972	21957	Economy	15400.00
0005433289896	21957	Economy	15400.00
0005435142547	21957	Economy	15400.00
0005435142567	21957	Economy	15400.00
0005435142501	21957	Economy	15400.00
0005435142549	21957	Economy	15400.00
0005435149974	21957	Economy	15400.00
0005433289895	21957	Economy	15400.00
0005435142479	21957	Economy	15400.00
0005433289901	21957	Economy	15400.00
0005435386605	21957	Economy	15400.00
0005435142572	21957	Economy	15400.00
0005435142573	21957	Economy	15400.00
0005435142571	21957	Economy	15400.00
0005435142502	21957	Economy	15400.00
0005435142553	21957	Economy	15400.00
0005435386611	21957	Economy	15400.00
0005435142540	21957	Economy	15400.00
0005435149965	21957	Economy	15400.00
0005435142541	21957	Economy	15400.00
0005435529127	11208	Business	57200.00
0005435319582	11208	Business	57200.00
0005435502262	11208	Business	57200.00
0005434573419	11208	Business	57200.00
0005435545744	11208	Business	57200.00
0005434573428	11208	Business	57200.00
0005435502261	11208	Business	57200.00
0005434573421	11208	Business	57200.00
0005435529217	11208	Business	57200.00
0005435529216	11208	Economy	19100.00
0005435319580	11208	Economy	19100.00
0005435529249	11208	Economy	19100.00
0005435529243	11208	Economy	19100.00
0005434573423	11208	Economy	19100.00
0005435502320	11208	Economy	19100.00
0005435545725	11208	Economy	19100.00
0005435502355	11208	Economy	19100.00
0005435529274	11208	Economy	21000.00
0005434573429	11208	Economy	21000.00
0005435319581	11208	Economy	21000.00
0005434573430	11208	Economy	21000.00
0005435502312	11208	Economy	21000.00
0005435545743	11208	Economy	19100.00
0005434573433	11208	Economy	19100.00
0005435502270	11208	Economy	19100.00
0005435502273	11208	Economy	19100.00
0005435502246	11208	Economy	19100.00
0005435529197	11208	Economy	19100.00
0005435529136	11208	Economy	19100.00
0005435319527	11208	Economy	19100.00
0005435545681	11208	Economy	19100.00
0005435529177	11208	Economy	19100.00
0005435529273	11208	Economy	19100.00
0005434573426	11208	Economy	19100.00
0005435529262	11208	Economy	19100.00
0005435529171	11208	Economy	19100.00
0005435502314	11208	Economy	19100.00
0005435502247	11208	Economy	19100.00
0005435529209	11208	Economy	19100.00
0005435529194	11208	Economy	19100.00
0005435502259	11208	Economy	19100.00
0005435529123	11208	Economy	19100.00
0005435529203	11208	Economy	19100.00
0005435529124	11208	Economy	19100.00
0005435545726	11208	Economy	19100.00
0005435502319	11208	Economy	19100.00
0005435529176	11208	Economy	19100.00
0005435529178	11208	Economy	19100.00
0005435529229	11208	Economy	19100.00
0005434573431	11208	Economy	19100.00
0005434573432	11208	Economy	19100.00
0005435319596	11208	Economy	19100.00
0005435502354	11208	Economy	19100.00
0005435502178	11208	Economy	19100.00
0005434573424	11208	Economy	19100.00
0005435529228	11208	Economy	19100.00
0005434573422	11208	Economy	19100.00
0005435545691	11208	Economy	19100.00
0005435319573	11208	Economy	19100.00
0005435319476	11208	Economy	19100.00
0005435545733	11208	Economy	19100.00
0005435545709	11208	Economy	19100.00
0005435319477	11208	Economy	19100.00
0005435529159	11208	Economy	19100.00
0005435529196	11208	Economy	19100.00
0005434573420	11208	Economy	19100.00
0005435502258	11208	Economy	19100.00
0005434573425	11208	Economy	19100.00
0005435545735	11208	Economy	19100.00
0005434573427	11208	Economy	19100.00
0005435529183	11208	Economy	19100.00
0005435529215	11208	Economy	19100.00
0005435529248	11208	Economy	19100.00
0005435502274	11208	Economy	19100.00
0005435502428	20955	Business	57200.00
0005435508412	20955	Business	57200.00
0005435508415	20955	Business	57200.00
0005435518001	20955	Business	57200.00
0005435502422	20955	Business	57200.00
0005434573340	20955	Business	57200.00
0005434573290	20955	Business	57200.00
0005435518003	20955	Business	57200.00
0005435502429	20955	Business	57200.00
0005435319637	20955	Business	57200.00
0005435518011	20955	Economy	19100.00
0005434573298	20955	Economy	19100.00
0005435517997	20955	Economy	19100.00
0005435518006	20955	Economy	19100.00
0005435319641	20955	Economy	19100.00
0005435518005	20955	Economy	19100.00
0005435502424	20955	Economy	19100.00
0005435502431	20955	Economy	19100.00
0005435319638	20955	Economy	21000.00
0005435319634	20955	Economy	21000.00
0005435502425	20955	Economy	21000.00
0005435508411	20955	Economy	21000.00
0005435502440	20955	Economy	19100.00
0005435319640	20955	Economy	19100.00
0005434573291	20955	Economy	19100.00
0005435518010	20955	Economy	19100.00
0005435517999	20955	Economy	19100.00
0005434573299	20955	Economy	19100.00
0005435502433	20955	Economy	19100.00
0005434573341	20955	Economy	19100.00
0005435319632	20955	Economy	19100.00
0005435508409	20955	Economy	19100.00
0005435502439	20955	Economy	19100.00
0005435319642	20955	Economy	19100.00
0005434573320	20955	Economy	19100.00
0005434573321	20955	Economy	19100.00
0005435508416	20955	Economy	19100.00
0005434573322	20955	Economy	19100.00
0005435319633	20955	Economy	19100.00
0005435508413	20955	Economy	19100.00
0005435518007	20955	Economy	19100.00
0005434573326	20955	Economy	19100.00
0005435517998	20955	Economy	19100.00
0005435502420	20955	Economy	19100.00
0005435518012	20955	Economy	19100.00
0005435502427	20955	Economy	19100.00
0005432291942	20955	Economy	19100.00
0005435518008	20955	Economy	19100.00
0005434573294	20955	Economy	19100.00
0005435518014	20955	Economy	19100.00
0005435502430	20955	Economy	19100.00
0005435518000	20955	Economy	19100.00
0005434573360	20955	Economy	19100.00
0005434573285	20955	Economy	19100.00
0005435518004	20955	Economy	19100.00
0005435502423	20955	Economy	19100.00
0005435502435	20955	Economy	19100.00
0005434573277	20955	Economy	19100.00
0005435319636	20955	Economy	19100.00
0005435502432	20955	Economy	19100.00
0005435508410	20955	Economy	19100.00
0005434573337	20955	Economy	19100.00
0005434573212	20955	Economy	19100.00
0005435508408	20955	Economy	19100.00
0005435508414	20955	Economy	19100.00
0005435508407	20955	Economy	19100.00
0005435502438	20955	Economy	19100.00
0005435502436	20955	Economy	19100.00
0005434573328	20955	Economy	19100.00
0005435319635	20955	Economy	19100.00
0005432291943	20955	Economy	19100.00
0005435502437	20955	Economy	19100.00
0005435518015	20955	Economy	19100.00
0005434573252	20955	Economy	19100.00
0005435502421	20955	Economy	19100.00
0005435518009	20955	Economy	19100.00
0005435518002	20955	Economy	19100.00
0005435502426	20955	Economy	19100.00
0005434573325	20955	Economy	19100.00
0005435319639	20955	Economy	19100.00
0005435502434	20955	Economy	19100.00
0005434573249	20955	Economy	19100.00
0005434573336	20955	Economy	19100.00
0005434573311	20955	Economy	19100.00
0005435518013	20955	Economy	19100.00
0005435508406	20955	Economy	19100.00
0005432693088	3068	Business	10300.00
0005432692864	3068	Business	10300.00
0005432692979	3068	Business	10300.00
0005432693065	3068	Economy	3400.00
0005432693002	3068	Economy	3400.00
0005432692999	3068	Economy	3400.00
0005432692978	3068	Economy	3400.00
0005432693040	3068	Economy	3800.00
0005432693084	3068	Economy	3800.00
0005432693041	3068	Economy	3400.00
0005432692998	3068	Economy	3400.00
0005432693087	3068	Economy	3400.00
0005432693001	3068	Economy	3400.00
0005432693023	3068	Economy	3400.00
0005432692931	3068	Economy	3400.00
0005432692953	3068	Economy	3400.00
0005432693030	3068	Economy	3400.00
0005432692977	3068	Economy	3400.00
0005432692896	3068	Economy	3400.00
0005432692907	3068	Economy	3400.00
0005432692981	3068	Economy	3400.00
0005432693010	3068	Economy	3400.00
0005432692960	3068	Economy	3400.00
0005432693027	3068	Economy	3400.00
0005432693060	3068	Economy	3400.00
0005432692909	3068	Economy	3400.00
0005432692773	3068	Economy	3400.00
0005432692904	3068	Economy	3400.00
0005432693025	3068	Economy	3400.00
0005432692930	3068	Economy	3400.00
0005432692908	3068	Economy	3400.00
0005432692952	3068	Economy	3400.00
0005432693026	3068	Economy	3400.00
0005432692970	3068	Economy	3400.00
0005432692971	3068	Economy	3400.00
0005432693057	3068	Economy	3400.00
0005432706913	2888	Business	10300.00
0005432880795	2888	Business	10300.00
0005432706926	2888	Business	10300.00
0005432880833	2888	Business	10300.00
0005432880793	2888	Business	10300.00
0005432880790	2888	Business	10300.00
0005432706929	2888	Business	10300.00
0005432706916	2888	Business	10300.00
0005432706923	2888	Business	10300.00
0005432880803	2888	Business	10300.00
0005433123913	2888	Business	10300.00
0005432706932	2888	Business	10300.00
0005432706922	2888	Economy	3400.00
0005432880802	2888	Economy	3400.00
0005432706911	2888	Economy	3400.00
0005432706928	2888	Economy	3400.00
0005433123976	2888	Economy	3400.00
0005432880762	2888	Economy	3400.00
0005433123861	2888	Economy	3400.00
0005432706912	2888	Economy	3400.00
0005432706917	2888	Economy	3400.00
0005432706934	2888	Economy	3400.00
0005432706921	2888	Economy	3800.00
0005433123887	2888	Economy	3800.00
0005433123836	2888	Economy	3800.00
0005432880748	2888	Economy	3800.00
0005433123903	2888	Economy	3800.00
0005432880747	2888	Economy	3400.00
0005432880848	2888	Economy	3400.00
0005433123904	2888	Economy	3400.00
0005432706918	2888	Economy	3400.00
0005432880783	2888	Economy	3400.00
0005433123824	2888	Economy	3400.00
0005432880838	2888	Economy	3400.00
0005433123896	2888	Economy	3400.00
0005432880847	2888	Economy	3400.00
0005433123879	2888	Economy	3400.00
0005433123892	2888	Economy	3400.00
0005432706933	2888	Economy	3400.00
0005432706930	2888	Economy	3400.00
0005432217793	2888	Economy	3400.00
0005433123825	2888	Economy	3400.00
0005432880777	2888	Economy	3400.00
0005433123869	2888	Economy	3400.00
0005433123859	2888	Economy	3400.00
0005433123898	2888	Economy	3400.00
0005432706920	2888	Economy	3400.00
0005432880805	2888	Economy	3400.00
0005433194828	2888	Economy	3400.00
0005432880746	2888	Economy	3400.00
0005432706925	2888	Economy	3400.00
0005433123803	2888	Economy	3400.00
0005432880701	2888	Economy	3400.00
0005432880775	2888	Economy	3400.00
0005433123893	2888	Economy	3400.00
0005432706910	2888	Economy	3400.00
0005432880776	2888	Economy	3400.00
0005432706915	2888	Economy	3400.00
0005433123864	2888	Economy	3400.00
0005432880816	2888	Economy	3400.00
0005433123880	2888	Economy	3400.00
0005433123968	2888	Economy	3400.00
0005433123888	2888	Economy	3400.00
0005432880836	2888	Economy	3400.00
0005433123977	2888	Economy	3400.00
0005432706931	2888	Economy	3400.00
0005432706927	2888	Economy	3400.00
0005433123862	2888	Economy	3400.00
0005432706924	2888	Economy	3400.00
0005433123882	2888	Economy	3400.00
0005433123852	2888	Economy	3400.00
0005432706919	2888	Economy	3400.00
0005433123857	2888	Economy	3400.00
0005432880778	2888	Economy	3400.00
0005433123837	2888	Economy	3400.00
0005433123860	2888	Economy	3400.00
0005432880794	2888	Economy	3400.00
0005432880739	2888	Economy	3400.00
0005432880702	2888	Economy	3400.00
0005432706935	2888	Economy	3400.00
0005432706914	2888	Economy	3400.00
0005432880763	2888	Economy	3400.00
0005433124037	29992	Business	10300.00
0005432693266	29992	Business	10300.00
0005432706777	29992	Business	10300.00
0005432693255	29992	Business	10300.00
0005432880906	29992	Business	10300.00
0005433124049	29992	Business	10300.00
0005432693264	29992	Business	10300.00
0005432693269	29992	Business	10300.00
0005432693280	29992	Business	10300.00
0005432706717	29992	Business	10300.00
0005432706795	29992	Business	10300.00
0005432706826	29992	Business	10300.00
0005432880904	29992	Economy	3400.00
0005432706710	29992	Economy	3400.00
0005432706797	29992	Economy	3400.00
0005433124030	29992	Economy	3400.00
0005432880910	29992	Economy	3400.00
0005432880900	29992	Economy	3400.00
0005432693282	29992	Economy	3400.00
0005432880909	29992	Economy	3400.00
0005432706597	29992	Economy	3400.00
0005432706731	29992	Economy	3400.00
0005432706689	29992	Economy	3800.00
0005432706778	29992	Economy	3800.00
0005432693259	29992	Economy	3800.00
0005432880897	29992	Economy	3800.00
0005432693276	29992	Economy	3800.00
0005432706598	29992	Economy	3400.00
0005432880902	29992	Economy	3400.00
0005433124033	29992	Economy	3400.00
0005432693283	29992	Economy	3400.00
0005433124036	29992	Economy	3400.00
0005433124048	29992	Economy	3400.00
0005433124039	29992	Economy	3400.00
0005433124040	29992	Economy	3400.00
0005432693279	29992	Economy	3400.00
0005432693256	29992	Economy	3400.00
0005432706803	29992	Economy	3400.00
0005433124043	29992	Economy	3400.00
0005432880908	29992	Economy	3400.00
0005432693274	29992	Economy	3400.00
0005432706691	29992	Economy	3400.00
0005432706791	29992	Economy	3400.00
0005432693254	29992	Economy	3400.00
0005432693284	29992	Economy	3400.00
0005433124050	29992	Economy	3400.00
0005433124028	29992	Economy	3400.00
0005433124027	29992	Economy	3400.00
0005432706748	29992	Economy	3400.00
0005432706790	29992	Economy	3400.00
0005432880907	29992	Economy	3400.00
0005433124034	29992	Economy	3400.00
0005432693271	29992	Economy	3400.00
0005433124032	29992	Economy	3400.00
0005432693258	29992	Economy	3400.00
0005432706724	29992	Economy	3400.00
0005432693257	29992	Economy	3400.00
0005433124031	29992	Economy	3400.00
0005432693272	29992	Economy	3400.00
0005433124042	29992	Economy	3400.00
0005433124044	29992	Economy	3400.00
0005433124047	29992	Economy	3400.00
0005432706821	29992	Economy	3400.00
0005432693267	29992	Economy	3400.00
0005432693263	29992	Economy	3400.00
0005432693275	29992	Economy	3400.00
0005433124029	29992	Economy	3400.00
0005432880898	29992	Economy	3400.00
0005432693253	29992	Economy	3400.00
0005432693260	29992	Economy	3400.00
0005432693262	29992	Economy	3400.00
0005432693278	29992	Economy	3400.00
0005432693277	29992	Economy	3400.00
0005432693273	29992	Economy	3400.00
0005432880899	29992	Economy	3400.00
0005432693265	29992	Economy	3400.00
0005432693281	29992	Economy	3400.00
0005433124038	29992	Economy	3400.00
0005433124041	29992	Economy	3400.00
0005432880905	29992	Economy	3400.00
0005433124045	29992	Economy	3400.00
0005432706690	29992	Economy	3400.00
0005432706683	29992	Economy	3400.00
0005432706577	29992	Economy	3400.00
0005432706754	29992	Economy	3400.00
0005432706739	29992	Economy	3400.00
0005433194861	29992	Economy	3400.00
0005432693268	29992	Economy	3400.00
0005432880903	29992	Economy	3400.00
0005432706704	29992	Economy	3400.00
0005432693270	29992	Economy	3400.00
0005432693261	29992	Economy	3400.00
0005433124035	29992	Economy	3400.00
0005432880901	29992	Economy	3400.00
0005433124046	29992	Economy	3400.00
0005432706768	29992	Economy	3400.00
0005434979949	23675	Economy	4000.00
0005434979943	23675	Economy	4000.00
0005434979958	23675	Economy	4000.00
0005434979954	23675	Economy	3600.00
0005434979944	23675	Economy	3600.00
0005434979929	23675	Economy	3600.00
0005434979939	23675	Economy	3600.00
0005434979937	23675	Economy	3600.00
0005434979931	23675	Economy	3600.00
0005434979946	23675	Economy	3600.00
0005434979935	23675	Economy	3600.00
0005434979957	23675	Economy	3600.00
0005434988799	23675	Economy	3600.00
0005434979938	23675	Economy	3600.00
0005434988796	23675	Economy	3600.00
0005434979945	23675	Economy	3600.00
0005434988797	23675	Economy	3600.00
0005434988795	23675	Economy	3600.00
0005434979959	23675	Economy	3600.00
0005434988792	23675	Economy	3600.00
0005434979948	23675	Economy	3600.00
0005434979950	23675	Economy	3600.00
0005434979941	23675	Economy	3600.00
0005434988793	23675	Economy	3600.00
0005434979951	23675	Economy	3600.00
0005434988791	23675	Economy	3600.00
0005434979936	23675	Economy	3600.00
0005434988794	23675	Economy	3600.00
0005434979955	23675	Economy	3600.00
0005434979933	23675	Economy	3600.00
0005434979934	23675	Economy	3600.00
0005434979947	23675	Economy	3600.00
0005434979932	23675	Economy	3600.00
0005434979956	23675	Economy	3600.00
0005434979930	23675	Economy	3600.00
0005434979953	23675	Economy	3600.00
0005434988798	23675	Economy	3600.00
0005434979952	23675	Economy	3600.00
0005434979942	23675	Economy	3600.00
0005434979940	23675	Economy	3600.00
0005434979714	27530	Economy	4000.00
0005434979752	27530	Economy	4000.00
0005434979591	27530	Economy	4000.00
0005434979592	27530	Economy	3600.00
0005434979696	27530	Economy	3600.00
0005434979842	27530	Economy	3600.00
0005434979649	27530	Economy	3600.00
0005434988653	27530	Economy	3600.00
0005434979733	27530	Economy	3600.00
0005434979694	27530	Economy	3600.00
0005434988668	27530	Economy	3600.00
0005434979685	27530	Economy	3600.00
0005434979590	27530	Economy	3600.00
0005434979677	27530	Economy	3600.00
0005434979529	27530	Economy	3600.00
0005434988688	27530	Economy	3600.00
0005434988690	27530	Economy	3600.00
0005434979785	27530	Economy	3600.00
0005434979728	27530	Economy	3600.00
0005434979668	27530	Economy	3600.00
0005434988657	27530	Economy	3600.00
0005434979613	27530	Economy	3600.00
0005434988680	27530	Economy	3600.00
0005434979594	27530	Economy	3600.00
0005434979730	27530	Economy	3600.00
0005434979672	27530	Economy	3600.00
0005434988681	27530	Economy	3600.00
0005434979841	27530	Economy	3600.00
0005434988682	27530	Economy	3600.00
0005434979652	27530	Economy	3600.00
0005434979589	27530	Economy	3600.00
0005434979695	27530	Economy	3600.00
0005434979614	27530	Economy	3600.00
0005434979719	27530	Economy	3600.00
0005434979734	27530	Economy	3600.00
0005434979578	27530	Economy	3600.00
0005434979784	27530	Economy	3600.00
0005434979686	27530	Economy	3600.00
0005434979593	27530	Economy	3600.00
0005434979667	27530	Economy	3600.00
0005434979751	27530	Economy	3600.00
0005434979720	27530	Economy	3600.00
0005434979729	27530	Economy	3600.00
0005434979708	27530	Economy	3600.00
0005434988687	27530	Economy	3600.00
0005433113531	10297	Economy	21600.00
0005434302481	10297	Economy	21600.00
0005434302483	10297	Economy	19700.00
0005433111500	10297	Economy	19700.00
0005433111501	10297	Economy	19700.00
0005434302479	10297	Economy	19700.00
0005434302480	10297	Economy	19700.00
0005433111496	10297	Economy	19700.00
0005434302482	10297	Economy	19700.00
0005433111499	10297	Economy	19700.00
0005434302441	19627	Economy	19700.00
0005434302448	19627	Economy	19700.00
0005433113550	19627	Economy	19700.00
0005434302456	19627	Economy	19700.00
0005434302442	19627	Economy	19700.00
0005433113548	19627	Economy	19700.00
0005433113549	19627	Economy	19700.00
0005434302444	19627	Economy	19700.00
0005433113618	19627	Economy	19700.00
0005434302457	19627	Economy	19700.00
0005435069406	3527	Business	26900.00
0005435069385	3527	Business	26900.00
0005435925273	3527	Business	26900.00
0005435069396	3527	Business	26900.00
0005435925286	3527	Business	26900.00
0005435069382	3527	Business	26900.00
0005435925285	3527	Business	26900.00
0005435069403	3527	Business	26900.00
0005435069387	3527	Business	26900.00
0005435069401	3527	Business	26900.00
0005435925231	3527	Economy	9000.00
0005435069421	3527	Economy	9000.00
0005435069414	3527	Economy	9000.00
0005435069381	3527	Economy	9000.00
0005435069399	3527	Economy	9000.00
0005435069393	3527	Economy	9000.00
0005435069416	3527	Economy	9900.00
0005435069377	3527	Economy	9900.00
0005435925289	3527	Economy	9900.00
0005435069380	3527	Economy	9000.00
0005435925281	3527	Economy	9000.00
0005435069418	3527	Economy	9000.00
0005435069390	3527	Economy	9000.00
0005435069378	3527	Economy	9000.00
0005435069400	3527	Economy	9000.00
0005435069422	3527	Economy	9000.00
0005435069420	3527	Economy	9000.00
0005435069407	3527	Economy	9000.00
0005435069423	3527	Economy	9000.00
0005435069392	3527	Economy	9000.00
0005435069398	3527	Economy	9000.00
0005435069417	3527	Economy	9000.00
0005435718987	3527	Economy	9000.00
0005435069429	3527	Economy	9000.00
0005435069404	3527	Economy	9000.00
0005435069419	3527	Economy	9000.00
0005435925280	3527	Economy	9000.00
0005435069391	3527	Economy	9000.00
0005435069425	3527	Economy	9000.00
0005435069394	3527	Economy	9000.00
0005435069402	3527	Economy	9000.00
0005435069415	3527	Economy	9000.00
0005435925287	3527	Economy	9000.00
0005435069397	3527	Economy	9000.00
0005435069405	3527	Economy	9000.00
0005435069411	3527	Economy	9000.00
0005435069413	3527	Economy	9000.00
0005435069428	3527	Economy	9000.00
0005435069410	3527	Economy	9000.00
0005435069395	3527	Economy	9000.00
0005435925234	3527	Economy	9000.00
0005435925255	3527	Economy	9000.00
0005435069383	3527	Economy	9000.00
0005435069386	3527	Economy	9000.00
0005435069388	3527	Economy	9000.00
0005435925210	3527	Economy	9000.00
0005435069379	3527	Economy	9000.00
0005435069408	3527	Economy	9000.00
0005435069389	3527	Economy	9000.00
0005435069424	3527	Economy	9000.00
0005435925263	3527	Economy	9000.00
0005435925265	3527	Economy	9000.00
0005435069412	3527	Economy	9000.00
0005435069409	3527	Economy	9000.00
0005435069427	3527	Economy	9000.00
0005435069426	3527	Economy	9000.00
0005435925290	3527	Economy	9000.00
0005435925251	3527	Economy	9000.00
0005435925264	3527	Economy	9000.00
0005435069384	3527	Economy	9000.00
0005435939894	15279	Business	26900.00
0005435068776	15279	Business	26900.00
0005435068812	15279	Business	26900.00
0005435068652	15279	Business	26900.00
0005435068796	15279	Business	26900.00
0005435068869	15279	Business	26900.00
0005435068862	15279	Business	26900.00
0005435068956	15279	Business	26900.00
0005435069152	15279	Business	26900.00
0005435068962	15279	Business	26900.00
0005435069054	15279	Business	26900.00
0005435925365	15279	Economy	9000.00
0005435925385	15279	Economy	9000.00
0005435069008	15279	Economy	9000.00
0005435069026	15279	Economy	9000.00
0005435068783	15279	Economy	9000.00
0005435069070	15279	Economy	9000.00
0005435069037	15279	Economy	9000.00
0005435068863	15279	Economy	9900.00
0005435068928	15279	Economy	9900.00
0005435068845	15279	Economy	9900.00
0005435939891	15279	Economy	9000.00
0005435068983	15279	Economy	9000.00
0005435068766	15279	Economy	9000.00
0005435925369	15279	Economy	9000.00
0005435068875	15279	Economy	9000.00
0005435068767	15279	Economy	9000.00
0005435925367	15279	Economy	9000.00
0005435925373	15279	Economy	9000.00
0005435069009	15279	Economy	9000.00
0005435069097	15279	Economy	9000.00
0005435068883	15279	Economy	9000.00
0005435068984	15279	Economy	9000.00
0005435925371	15279	Economy	9000.00
0005435068904	15279	Economy	9000.00
0005435069035	15279	Economy	9000.00
0005435069096	15279	Economy	9000.00
0005435068636	15279	Economy	9000.00
0005435069071	15279	Economy	9000.00
0005435068946	15279	Economy	9000.00
0005435925372	15279	Economy	9000.00
0005435069038	15279	Economy	9000.00
0005435925370	15279	Economy	9000.00
0005435925386	15279	Economy	9000.00
0005435068871	15279	Economy	9000.00
0005435925380	15279	Economy	9000.00
0005435939892	15279	Economy	9000.00
0005435068775	15279	Economy	9000.00
0005435068818	15279	Economy	9000.00
0005435925378	15279	Economy	9000.00
0005435068892	15279	Economy	9000.00
0005435068981	15279	Economy	9000.00
0005435925374	15279	Economy	9000.00
0005435068844	15279	Economy	9000.00
0005435068824	15279	Economy	9000.00
0005435068877	15279	Economy	9000.00
0005435068825	15279	Economy	9000.00
0005435925377	15279	Economy	9000.00
0005435068961	15279	Economy	9000.00
0005435925366	15279	Economy	9000.00
0005435068990	15279	Economy	9000.00
0005435939893	15279	Economy	9000.00
0005435925381	15279	Economy	9000.00
0005435068912	15279	Economy	9000.00
0005435068797	15279	Economy	9000.00
0005435925382	15279	Economy	9000.00
0005435068905	15279	Economy	9000.00
0005435068977	15279	Economy	9000.00
0005435069012	15279	Economy	9000.00
0005435068635	15279	Economy	9000.00
0005435068837	15279	Economy	9000.00
0005435925375	15279	Economy	9000.00
0005435925368	15279	Economy	9000.00
0005435068876	15279	Economy	9000.00
0005435925376	15279	Economy	9000.00
0005435925383	15279	Economy	9000.00
0005435925379	15279	Economy	9000.00
0005435925384	15279	Economy	9000.00
0005435068890	15279	Economy	9000.00
0005432658604	18140	Economy	5900.00
0005432658603	18140	Economy	5900.00
0005432660830	18140	Economy	5900.00
0005432658605	18140	Economy	5900.00
0005432660829	18140	Economy	5900.00
0005432659719	18140	Economy	5900.00
0005432658602	18140	Economy	5900.00
0005432660809	26368	Economy	5900.00
0005432667454	26368	Economy	5900.00
0005432664122	26368	Economy	5900.00
0005432660810	26368	Economy	5900.00
0005432667455	26368	Economy	5900.00
0005432667444	26368	Economy	5900.00
0005432919781	52	Business	20000.00
0005433102000	52	Business	20000.00
0005433101880	52	Business	20000.00
0005432901590	52	Business	20000.00
0005432919785	52	Business	20000.00
0005433102066	52	Business	20000.00
0005433101990	52	Business	20000.00
0005432919855	52	Business	20000.00
0005433102057	52	Business	20000.00
0005432901591	52	Business	20000.00
0005432919831	52	Business	20000.00
0005432919864	52	Business	20000.00
0005433101848	52	Business	20000.00
0005432919816	52	Business	20000.00
0005432919761	52	Business	20000.00
0005433101917	52	Business	20000.00
0005432919784	52	Business	20000.00
0005433101994	52	Business	20000.00
0005433101942	52	Economy	7300.00
0005433102029	52	Economy	7300.00
0005432157504	52	Economy	7300.00
0005433101849	52	Economy	7300.00
0005432901596	52	Economy	6700.00
0005432919863	52	Economy	6700.00
0005432901542	52	Economy	6700.00
0005433102004	52	Economy	6700.00
0005433101947	52	Economy	6700.00
0005433102035	52	Economy	6700.00
0005433102058	52	Economy	6700.00
0005433101966	52	Economy	6700.00
0005433102060	52	Economy	6700.00
0005432901630	52	Economy	6700.00
0005432919856	52	Economy	6700.00
0005433101912	52	Economy	6700.00
0005433102010	52	Economy	6700.00
0005432919817	52	Economy	6700.00
0005433101901	52	Economy	6700.00
0005433102097	52	Economy	6700.00
0005432157503	52	Economy	6700.00
0005433102018	52	Economy	6700.00
0005433102090	52	Economy	6700.00
0005433102056	52	Economy	6700.00
0005433101960	52	Economy	6700.00
0005433101985	52	Economy	6700.00
0005433102023	52	Economy	6700.00
0005432919844	52	Economy	6700.00
0005432901589	52	Economy	6700.00
0005433102013	52	Economy	6700.00
0005432919879	52	Economy	6700.00
0005432919880	52	Economy	6700.00
0005433101924	52	Economy	6700.00
0005433101861	52	Economy	6700.00
0005432919832	52	Economy	6700.00
0005433102028	52	Economy	6700.00
0005432901580	52	Economy	7300.00
0005433102079	52	Economy	7300.00
0005432901579	52	Economy	7300.00
0005432901620	52	Economy	6700.00
0005433102003	52	Economy	6700.00
0005432901588	52	Economy	7300.00
0005433102052	52	Economy	6700.00
0005432919862	52	Economy	6700.00
0005433101933	52	Economy	6700.00
0005433101786	52	Economy	6700.00
0005432919833	52	Economy	6700.00
0005433102089	52	Economy	6700.00
0005433101787	52	Economy	6700.00
0005433101890	52	Economy	6700.00
0005432901518	52	Economy	6700.00
0005432919801	52	Economy	6700.00
0005433101991	52	Economy	6700.00
0005432919783	52	Economy	6700.00
0005433101847	52	Economy	6700.00
0005433101965	52	Economy	6700.00
0005432919782	52	Economy	6700.00
0005432919762	52	Economy	6700.00
0005433101785	52	Economy	6700.00
0005432901619	52	Economy	6700.00
0005433101788	52	Economy	6700.00
0005432901587	52	Economy	6700.00
0005433102046	52	Economy	6700.00
0005433101910	52	Economy	6700.00
0005433102059	52	Economy	6700.00
0005432919818	52	Economy	6700.00
0005433102009	52	Economy	6700.00
0005433101871	52	Economy	6700.00
0005433101961	52	Economy	6700.00
0005433101941	52	Economy	6700.00
0005433101891	52	Economy	6700.00
0005433101948	52	Economy	6700.00
0005432901550	52	Economy	6700.00
0005432677577	52	Economy	6700.00
0005433102014	52	Economy	6700.00
0005433101860	52	Economy	6700.00
0005433102124	52	Economy	6700.00
0005433102047	52	Economy	6700.00
0005433102048	52	Economy	6700.00
0005433101909	52	Economy	6700.00
0005432262169	53	Business	20000.00
0005432817661	53	Business	20000.00
0005432817667	53	Business	20000.00
0005432262203	53	Business	20000.00
0005432262168	53	Business	20000.00
0005432262207	53	Business	20000.00
0005432817638	53	Business	20000.00
0005432262178	53	Business	20000.00
0005432289006	53	Business	20000.00
0005432817636	53	Business	20000.00
0005432817654	53	Business	20000.00
0005432817648	53	Business	20000.00
0005432262204	53	Business	20000.00
0005432262179	53	Business	20000.00
0005432262172	53	Business	20000.00
0005432817637	53	Business	20000.00
0005432262185	53	Business	20000.00
0005432817665	53	Business	20000.00
0005432753298	53	Business	20000.00
0005432262175	53	Business	20000.00
0005432753279	53	Economy	7300.00
0005432262181	53	Economy	7300.00
0005432817646	53	Economy	6700.00
0005432262195	53	Economy	6700.00
0005432262201	53	Economy	6700.00
0005432262182	53	Economy	6700.00
0005432817642	53	Economy	6700.00
0005432817655	53	Economy	6700.00
0005432817649	53	Economy	6700.00
0005432262187	53	Economy	6700.00
0005432262194	53	Economy	6700.00
0005432262173	53	Economy	6700.00
0005432817647	53	Economy	6700.00
0005432817639	53	Economy	6700.00
0005432817666	53	Economy	6700.00
0005432289008	53	Economy	6700.00
0005432756834	53	Economy	6700.00
0005432817653	53	Economy	6700.00
0005432817641	53	Economy	6700.00
0005432262183	53	Economy	6700.00
0005432262190	53	Economy	6700.00
0005432817645	53	Economy	6700.00
0005432817663	53	Economy	6700.00
0005432262209	53	Economy	6700.00
0005432817652	53	Economy	6700.00
0005432262192	53	Economy	6700.00
0005432817644	53	Economy	6700.00
0005432262171	53	Economy	6700.00
0005432262198	53	Economy	6700.00
0005432817660	53	Economy	6700.00
0005432262205	53	Economy	6700.00
0005432817640	53	Economy	6700.00
0005432262202	53	Economy	6700.00
0005432262200	53	Economy	7300.00
0005432817657	53	Economy	7300.00
0005432262180	53	Economy	7300.00
0005432262193	53	Economy	6700.00
0005432262165	53	Economy	6700.00
0005432262191	53	Economy	6700.00
0005432262176	53	Economy	6700.00
0005432817664	53	Economy	6700.00
0005432262164	53	Economy	6700.00
0005432207676	53	Economy	6700.00
0005432262188	53	Economy	6700.00
0005432262177	53	Economy	6700.00
0005432817650	53	Economy	6700.00
0005432262174	53	Economy	6700.00
0005432817659	53	Economy	6700.00
0005432262163	53	Economy	6700.00
0005432262184	53	Economy	6700.00
0005432262206	53	Economy	6700.00
0005432262199	53	Economy	6700.00
0005432817651	53	Economy	6700.00
0005432262166	53	Economy	6700.00
0005432262196	53	Economy	6700.00
0005432207674	53	Economy	6700.00
0005432817656	53	Economy	6700.00
0005432817668	53	Economy	6700.00
0005432817658	53	Economy	6700.00
0005432207675	53	Economy	6700.00
0005432289005	53	Economy	6700.00
0005432262197	53	Economy	6700.00
0005432262208	53	Economy	6700.00
0005432262167	53	Economy	6700.00
0005432262170	53	Economy	6700.00
0005432262189	53	Economy	6700.00
0005432817643	53	Economy	6700.00
0005432262186	53	Economy	6700.00
0005432289007	53	Economy	6700.00
0005432817662	53	Economy	6700.00
0005432020417	7998	Business	20000.00
0005432919995	7998	Business	20000.00
0005432919991	7998	Business	20000.00
0005433102460	7998	Business	20000.00
0005433102444	7998	Business	20000.00
0005432045625	7998	Business	20000.00
0005432020422	7998	Business	20000.00
0005432020423	7998	Business	20000.00
0005433102468	7998	Business	20000.00
0005432919986	7998	Business	20000.00
0005433102469	7998	Business	20000.00
0005432392020	7998	Business	20000.00
0005432020434	7998	Business	20000.00
0005433102473	7998	Business	20000.00
0005432751546	7998	Business	20000.00
0005433102453	7998	Business	20000.00
0005432020430	7998	Business	20000.00
0005432392019	7998	Economy	7300.00
0005432020426	7998	Economy	7300.00
0005432020433	7998	Economy	7300.00
0005432020431	7998	Economy	7300.00
0005433102457	7998	Economy	7300.00
0005433102467	7998	Economy	6700.00
0005433102450	7998	Economy	6700.00
0005432919978	7998	Economy	6700.00
0005432020412	7998	Economy	6700.00
0005432919989	7998	Economy	6700.00
0005432919975	7998	Economy	6700.00
0005432020418	7998	Economy	6700.00
0005433102471	7998	Economy	6700.00
0005432020415	7998	Economy	6700.00
0005433102461	7998	Economy	6700.00
0005432919990	7998	Economy	6700.00
0005433102443	7998	Economy	6700.00
0005432919981	7998	Economy	6700.00
0005433102466	7998	Economy	6700.00
0005432919983	7998	Economy	6700.00
0005433102458	7998	Economy	6700.00
0005432751548	7998	Economy	6700.00
0005432677597	7998	Economy	6700.00
0005433102472	7998	Economy	6700.00
0005432919980	7998	Economy	6700.00
0005432677600	7998	Economy	6700.00
0005433102446	7998	Economy	6700.00
0005432392018	7998	Economy	6700.00
0005433102475	7998	Economy	6700.00
0005432020421	7998	Economy	6700.00
0005433102452	7998	Economy	6700.00
0005432751547	7998	Economy	6700.00
0005432020425	7998	Economy	6700.00
0005432020432	7998	Economy	6700.00
0005433102465	7998	Economy	6700.00
0005432919993	7998	Economy	6700.00
0005432919992	7998	Economy	6700.00
0005432020414	7998	Economy	7300.00
0005432919979	7998	Economy	7300.00
0005432919982	7998	Economy	7300.00
0005433102462	7998	Economy	6700.00
0005433102455	7998	Economy	7300.00
0005433102474	7998	Economy	6700.00
0005432020429	7998	Economy	6700.00
0005432753323	7998	Economy	6700.00
0005432020424	7998	Economy	7300.00
0005433102464	7998	Economy	6700.00
0005432753322	7998	Economy	6700.00
0005432044541	7998	Economy	6700.00
0005432919976	7998	Economy	6700.00
0005432020427	7998	Economy	6700.00
0005432020435	7998	Economy	6700.00
0005432044540	7998	Economy	6700.00
0005432919984	7998	Economy	6700.00
0005433102463	7998	Economy	6700.00
0005432677601	7998	Economy	6700.00
0005433102442	7998	Economy	6700.00
0005432020420	7998	Economy	6700.00
0005432020437	7998	Economy	6700.00
0005432020436	7998	Economy	6700.00
0005432919988	7998	Economy	6700.00
0005432020413	7998	Economy	6700.00
0005432045626	7998	Economy	6700.00
0005433102451	7998	Economy	6700.00
0005432919977	7998	Economy	6700.00
0005432677598	7998	Economy	6700.00
0005432677599	7998	Economy	6700.00
0005432753321	7998	Economy	6700.00
0005433102448	7998	Economy	6700.00
0005433102447	7998	Economy	6700.00
0005433102477	7998	Economy	6700.00
0005432020411	7998	Economy	6700.00
0005433102476	7998	Economy	6700.00
0005432044542	7998	Economy	6700.00
0005432020419	7998	Economy	6700.00
0005433102470	7998	Economy	6700.00
0005433102445	7998	Economy	6700.00
0005433102449	7998	Economy	6700.00
0005432919987	7998	Economy	6700.00
0005432045627	7998	Economy	6700.00
0005432020428	7998	Economy	6700.00
0005433102454	7998	Economy	6700.00
0005432020410	7998	Economy	6700.00
0005432020416	7998	Economy	6700.00
0005432919994	7998	Economy	6700.00
0005432919974	7998	Economy	6700.00
0005433102456	7998	Economy	6700.00
0005432919985	7998	Economy	6700.00
0005433102459	7998	Economy	6700.00
0005432817387	7993	Business	20000.00
0005432901715	7993	Business	20000.00
0005432817337	7993	Business	20000.00
0005432817386	7993	Business	20000.00
0005432817477	7993	Business	20000.00
0005432817334	7993	Business	20000.00
0005432817476	7993	Business	20000.00
0005432901717	7993	Business	20000.00
0005432901710	7993	Business	20000.00
0005432817303	7993	Business	20000.00
0005432817426	7993	Business	20000.00
0005432901709	7993	Business	20000.00
0005432817372	7993	Economy	7300.00
0005432901723	7993	Economy	7300.00
0005432002089	7993	Economy	6700.00
0005432817499	7993	Economy	6700.00
0005432817378	7993	Economy	6700.00
0005432817302	7993	Economy	6700.00
0005432817379	7993	Economy	6700.00
0005432817371	7993	Economy	6700.00
0005432817254	7993	Economy	6700.00
0005432817498	7993	Economy	6700.00
0005432817335	7993	Economy	6700.00
0005432817428	7993	Economy	6700.00
0005432901711	7993	Economy	6700.00
0005432002088	7993	Economy	6700.00
0005432817480	7993	Economy	6700.00
0005432817239	7993	Economy	6700.00
0005432817451	7993	Economy	6700.00
0005432817400	7993	Economy	6700.00
0005432817365	7993	Economy	6700.00
0005432817368	7993	Economy	6700.00
0005432817270	7993	Economy	6700.00
0005432901707	7993	Economy	6700.00
0005432817288	7993	Economy	6700.00
0005432901712	7993	Economy	6700.00
0005432817222	7993	Economy	6700.00
0005432817457	7993	Economy	6700.00
0005432817327	7993	Economy	7300.00
0005432901716	7993	Economy	6700.00
0005432817407	7993	Economy	6700.00
0005432817409	7993	Economy	6700.00
0005432901719	7993	Economy	6700.00
0005432901713	7993	Economy	6700.00
0005432901721	7993	Economy	6700.00
0005432901714	7993	Economy	6700.00
0005432817223	7993	Economy	6700.00
0005432901718	7993	Economy	6700.00
0005432901708	7993	Economy	6700.00
0005432817336	7993	Economy	6700.00
0005432901720	7993	Economy	6700.00
0005432901724	7993	Economy	6700.00
0005432901722	7993	Economy	6700.00
0005434175732	9677	Economy	6900.00
0005433870745	9677	Economy	6900.00
0005433870743	9677	Economy	6900.00
0005434175735	9677	Economy	6900.00
0005434175743	9677	Economy	6900.00
0005434175736	9677	Economy	6900.00
0005434175742	9677	Economy	6900.00
0005434175734	9677	Economy	6900.00
0005433870744	9677	Economy	6900.00
0005434175779	32360	Economy	6900.00
0005434175780	32360	Economy	6900.00
0005434175778	32360	Economy	6900.00
0005434175777	32360	Economy	6900.00
0005434878777	3517	Business	35000.00
0005434426794	3517	Business	35000.00
0005435626301	3517	Business	35000.00
0005432799632	3517	Business	35000.00
0005434878772	3517	Business	35000.00
0005434426799	3517	Business	35000.00
0005434878826	3517	Business	35000.00
0005434878848	3517	Business	35000.00
0005434426802	3517	Business	35000.00
0005434878812	3517	Business	35000.00
0005432188628	3517	Business	35000.00
0005432799633	3517	Business	35000.00
0005434938256	3517	Business	35000.00
0005434878814	3517	Business	35000.00
0005434878846	3517	Business	35000.00
0005432799641	3517	Business	35000.00
0005434426805	3517	Business	35000.00
0005434878831	3517	Business	35000.00
0005435126614	3517	Business	35000.00
0005435626289	3517	Business	35000.00
0005435126610	3517	Business	35000.00
0005434878769	3517	Business	35000.00
0005435902721	3517	Business	35000.00
0005434878850	3517	Comfort	19900.00
0005434426778	3517	Comfort	19900.00
0005435902607	3517	Comfort	19900.00
0005435626303	3517	Comfort	19900.00
0005434938258	3517	Comfort	19900.00
0005432799625	3517	Comfort	19900.00
0005435913904	3517	Comfort	19900.00
0005435902555	3517	Comfort	19900.00
0005434878860	3517	Comfort	19900.00
0005434938272	3517	Comfort	19900.00
0005434426795	3517	Comfort	19900.00
0005435902666	3517	Comfort	19900.00
0005435902661	3517	Comfort	19900.00
0005434878803	3517	Comfort	19900.00
0005432799628	3517	Comfort	19900.00
0005434938264	3517	Comfort	19900.00
0005434938267	3517	Comfort	19900.00
0005432611737	3517	Comfort	19900.00
0005434878822	3517	Comfort	19900.00
0005434878773	3517	Comfort	19900.00
0005434878855	3517	Comfort	19900.00
0005435902569	3517	Comfort	19900.00
0005434938255	3517	Comfort	19900.00
0005432799623	3517	Comfort	19900.00
0005432799630	3517	Comfort	19900.00
0005434878824	3517	Comfort	19900.00
0005434426791	3517	Comfort	19900.00
0005435626292	3517	Comfort	19900.00
0005434938254	3517	Comfort	19900.00
0005434878797	3517	Comfort	19900.00
0005432613886	3517	Comfort	19900.00
0005435913903	3517	Comfort	19900.00
0005432799624	3517	Comfort	19900.00
0005435126627	3517	Comfort	19900.00
0005434426800	3517	Economy	11700.00
0005432799636	3517	Economy	11700.00
0005432799619	3517	Economy	11700.00
0005432799621	3517	Economy	11700.00
0005432799627	3517	Economy	11700.00
0005434878856	3517	Economy	11700.00
0005435126621	3517	Economy	11700.00
0005435902747	3517	Economy	11700.00
0005434878853	3517	Economy	11700.00
0005435126642	3517	Economy	11700.00
0005434878805	3517	Economy	11700.00
0005435126632	3517	Economy	11700.00
0005435126629	3517	Economy	11700.00
0005435126634	3517	Economy	11700.00
0005432799644	3517	Economy	11700.00
0005435126643	3517	Economy	11700.00
0005434878786	3517	Economy	11700.00
0005434878815	3517	Economy	11700.00
0005434426781	3517	Economy	11700.00
0005434878804	3517	Economy	11700.00
0005432183480	3517	Economy	11700.00
0005435626299	3517	Economy	11700.00
0005434426790	3517	Economy	11700.00
0005435902728	3517	Economy	11700.00
0005435126625	3517	Economy	11700.00
0005434426804	3517	Economy	11700.00
0005435626287	3517	Economy	11700.00
0005435126608	3517	Economy	11700.00
0005434426792	3517	Economy	11700.00
0005432799642	3517	Economy	11700.00
0005434878823	3517	Economy	11700.00
0005434426807	3517	Economy	11700.00
0005434878778	3517	Economy	11700.00
0005435126641	3517	Economy	11700.00
0005435902554	3517	Economy	11700.00
0005435913909	3517	Economy	11700.00
0005434426801	3517	Economy	11700.00
0005434878791	3517	Economy	11700.00
0005435626294	3517	Economy	11700.00
0005434426786	3517	Economy	11700.00
0005434878825	3517	Economy	11700.00
0005434878774	3517	Economy	11700.00
0005434878851	3517	Economy	11700.00
0005435902617	3517	Economy	11700.00
0005432799645	3517	Economy	11700.00
0005432183479	3517	Economy	11700.00
0005435126609	3517	Economy	11700.00
0005434878845	3517	Economy	11700.00
0005434878839	3517	Economy	11700.00
0005434938260	3517	Economy	11700.00
0005435126624	3517	Economy	11700.00
0005435126618	3517	Economy	11700.00
0005435126633	3517	Economy	11700.00
0005432799646	3517	Economy	12800.00
0005434878806	3517	Economy	12800.00
0005432799640	3517	Economy	12800.00
0005434878858	3517	Economy	11700.00
0005434878792	3517	Economy	11700.00
0005434426787	3517	Economy	11700.00
0005434878775	3517	Economy	12800.00
0005434878852	3517	Economy	11700.00
0005434878784	3517	Economy	12800.00
0005434878829	3517	Economy	12800.00
0005435126605	3517	Economy	11700.00
0005434878783	3517	Economy	11700.00
0005434878811	3517	Economy	11700.00
0005434878820	3517	Economy	11700.00
0005434426784	3517	Economy	11700.00
0005435126613	3517	Economy	11700.00
0005434878802	3517	Economy	11700.00
0005434878782	3517	Economy	11700.00
0005435626291	3517	Economy	11700.00
0005434878843	3517	Economy	11700.00
0005435626302	3517	Economy	11700.00
0005434878813	3517	Economy	11700.00
0005432799626	3517	Economy	11700.00
0005434878821	3517	Economy	11700.00
0005432799622	3517	Economy	11700.00
0005435913914	3517	Economy	11700.00
0005432799635	3517	Economy	11700.00
0005435626288	3517	Economy	11700.00
0005435902571	3517	Economy	11700.00
0005434426785	3517	Economy	11700.00
0005434878834	3517	Economy	11700.00
0005434878809	3517	Economy	11700.00
0005434878800	3517	Economy	11700.00
0005434878780	3517	Economy	11700.00
0005435126640	3517	Economy	11700.00
0005435126607	3517	Economy	11700.00
0005434426783	3517	Economy	11700.00
0005435626304	3517	Economy	11700.00
0005434878835	3517	Economy	11700.00
0005435126630	3517	Economy	11700.00
0005435126606	3517	Economy	11700.00
0005434878841	3517	Economy	11700.00
0005434938257	3517	Economy	11700.00
0005434878785	3517	Economy	11700.00
0005435913915	3517	Economy	11700.00
0005435626290	3517	Economy	11700.00
0005434878818	3517	Economy	11700.00
0005432188626	3517	Economy	11700.00
0005434938262	3517	Economy	11700.00
0005434426779	3517	Economy	11700.00
0005434878798	3517	Economy	11700.00
0005432188629	3517	Economy	11700.00
0005435126644	3517	Economy	11700.00
0005434938261	3517	Economy	11700.00
0005434426797	3517	Economy	11700.00
0005435126635	3517	Economy	11700.00
0005434938266	3517	Economy	11700.00
0005434426789	3517	Economy	11700.00
0005435626298	3517	Economy	11700.00
0005432799629	3517	Economy	11700.00
0005434878788	3517	Economy	11700.00
0005435126637	3517	Economy	11700.00
0005432183481	3517	Economy	11700.00
0005434426796	3517	Economy	11700.00
0005434878795	3517	Economy	11700.00
0005435902746	3517	Economy	11700.00
0005434878830	3517	Economy	11700.00
0005435126615	3517	Economy	11700.00
0005432611734	3517	Economy	11700.00
0005434938268	3517	Economy	11700.00
0005434878832	3517	Economy	11700.00
0005435126626	3517	Economy	11700.00
0005435126611	3517	Economy	11700.00
0005435902729	3517	Economy	11700.00
0005434878799	3517	Economy	11700.00
0005434426798	3517	Economy	11700.00
0005434878827	3517	Economy	11700.00
0005434938263	3517	Economy	11700.00
0005434878819	3517	Economy	11700.00
0005434878787	3517	Economy	11700.00
0005432799637	3517	Economy	11700.00
0005435902570	3517	Economy	11700.00
0005435626293	3517	Economy	11700.00
0005434878817	3517	Economy	11700.00
0005434938270	3517	Economy	11700.00
0005435626300	3517	Economy	11700.00
0005434878833	3517	Economy	11700.00
0005434938265	3517	Economy	11700.00
0005434878779	3517	Economy	11700.00
0005434878838	3517	Economy	12800.00
0005434878861	3517	Economy	11700.00
0005432799620	3517	Economy	12800.00
0005434878801	3517	Economy	11700.00
0005434878849	3517	Economy	11700.00
0005434878767	3517	Economy	11700.00
0005434426788	3517	Economy	11700.00
0005434878781	3517	Economy	11700.00
0005434878796	3517	Economy	11700.00
0005434426782	3517	Economy	11700.00
0005432799638	3517	Economy	11700.00
0005432799643	3517	Economy	11700.00
0005434878828	3517	Economy	11700.00
0005434938271	3517	Economy	11700.00
0005435126612	3517	Economy	11700.00
0005434878770	3517	Economy	11700.00
0005432613888	3517	Economy	11700.00
0005435126617	3517	Economy	11700.00
0005432799618	3517	Economy	11700.00
0005434878859	3517	Economy	11700.00
0005434878810	3517	Economy	11700.00
0005434426803	3517	Economy	11700.00
0005435626305	3517	Economy	11700.00
0005435626297	3517	Economy	11700.00
0005435913916	3517	Economy	11700.00
0005434878793	3517	Economy	11700.00
0005435902625	3517	Economy	11700.00
0005435126628	3517	Economy	11700.00
0005435902624	3517	Economy	11700.00
0005435902665	3517	Economy	11700.00
0005434878857	3517	Economy	11700.00
0005434878842	3517	Economy	11700.00
0005435126616	3517	Economy	11700.00
0005435126639	3517	Economy	11700.00
0005435126638	3517	Economy	11700.00
0005435126620	3517	Economy	11700.00
0005434878776	3517	Economy	11700.00
0005435902556	3517	Economy	11700.00
0005432611736	3517	Economy	11700.00
0005432611735	3517	Economy	11700.00
0005432799634	3517	Economy	11700.00
0005434878807	3517	Economy	11700.00
0005432613887	3517	Economy	11700.00
0005434878854	3517	Economy	11700.00
0005432613889	3517	Economy	11700.00
0005435626296	3517	Economy	11700.00
0005434426808	3517	Economy	11700.00
0005434938259	3517	Economy	11700.00
0005435126645	3517	Economy	11700.00
0005434878789	3517	Economy	11700.00
0005434938253	3517	Economy	11700.00
0005435126619	3517	Economy	11700.00
0005432613885	3517	Economy	11700.00
0005435126636	3517	Economy	11700.00
0005434878840	3517	Economy	11700.00
0005434878844	3517	Economy	11700.00
0005434426806	3517	Economy	11700.00
0005434878808	3517	Economy	11700.00
0005432799631	3517	Economy	11700.00
0005434878837	3517	Economy	11700.00
0005434878768	3517	Economy	11700.00
0005434938269	3517	Economy	11700.00
0005434878816	3517	Economy	11700.00
0005434878771	3517	Economy	11700.00
0005435126623	3517	Economy	11700.00
0005435626295	3517	Economy	11700.00
0005435841098	3517	Economy	11700.00
0005435126622	3517	Economy	11700.00
0005434878847	3517	Economy	11700.00
0005432188627	3517	Economy	11700.00
0005432799639	3517	Economy	11700.00
0005434426780	3517	Economy	11700.00
0005434878836	3517	Economy	11700.00
0005434426793	3517	Economy	11700.00
0005435126631	3517	Economy	11700.00
0005435902618	3517	Economy	11700.00
0005434878790	3517	Economy	11700.00
0005434878794	3517	Economy	11700.00
0005434938141	14590	Business	35000.00
0005434878099	14590	Business	35000.00
0005435126378	14590	Business	35000.00
0005435126287	14590	Business	35000.00
0005434878256	14590	Business	35000.00
0005432799471	14590	Business	35000.00
0005434878193	14590	Business	35000.00
0005434878095	14590	Business	35000.00
0005435902820	14590	Business	35000.00
0005435126328	14590	Business	35000.00
0005435902809	14590	Business	35000.00
0005435902812	14590	Business	35000.00
0005432799282	14590	Business	35000.00
0005435126203	14590	Business	35000.00
0005435126248	14590	Business	35000.00
0005432607547	14590	Business	35000.00
0005434877813	14590	Business	35000.00
0005432799377	14590	Business	35000.00
0005434938092	14590	Business	35000.00
0005434426616	14590	Business	35000.00
0005435126263	14590	Business	35000.00
0005434426482	14590	Business	35000.00
0005434878098	14590	Business	35000.00
0005432799529	14590	Business	35000.00
0005434878299	14590	Comfort	19900.00
0005434877591	14590	Comfort	19900.00
0005434938120	14590	Comfort	19900.00
0005435126163	14590	Comfort	19900.00
0005435902804	14590	Comfort	19900.00
0005435126211	14590	Comfort	19900.00
0005434938081	14590	Comfort	19900.00
0005432799354	14590	Comfort	19900.00
0005432059516	14590	Comfort	19900.00
0005435902806	14590	Comfort	19900.00
0005432799394	14590	Comfort	19900.00
0005434938133	14590	Comfort	19900.00
0005434426583	14590	Comfort	19900.00
0005432611713	14590	Comfort	19900.00
0005434938107	14590	Comfort	19900.00
0005435902810	14590	Comfort	19900.00
0005434426488	14590	Comfort	19900.00
0005432799440	14590	Comfort	19900.00
0005434877970	14590	Comfort	19900.00
0005434877181	14590	Comfort	19900.00
0005435902819	14590	Comfort	19900.00
0005435126304	14590	Comfort	19900.00
0005435126296	14590	Comfort	19900.00
0005434426567	14590	Comfort	19900.00
0005435126338	14590	Comfort	19900.00
0005434877795	14590	Comfort	19900.00
0005432799395	14590	Comfort	19900.00
0005434878046	14590	Comfort	19900.00
0005435626096	14590	Comfort	19900.00
0005434878300	14590	Comfort	19900.00
0005435126086	14590	Comfort	19900.00
0005435126308	14590	Comfort	19900.00
0005434878016	14590	Comfort	19900.00
0005435126087	14590	Comfort	19900.00
0005435126170	14590	Comfort	19900.00
0005435126273	14590	Comfort	19900.00
0005432799435	14590	Comfort	19900.00
0005434938053	14590	Economy	11700.00
0005435126130	14590	Comfort	19900.00
0005432799521	14590	Economy	11700.00
0005434877887	14590	Economy	11700.00
0005435626108	14590	Economy	11700.00
0005434878093	14590	Economy	11700.00
0005434426516	14590	Economy	11700.00
0005434938198	14590	Economy	11700.00
0005432607537	14590	Economy	11700.00
0005434878036	14590	Economy	11700.00
0005434426656	14590	Economy	11700.00
0005434878129	14590	Economy	11700.00
0005434877998	14590	Economy	11700.00
0005432799378	14590	Economy	11700.00
0005435126121	14590	Economy	11700.00
0005434878064	14590	Economy	11700.00
0005434877652	14590	Economy	11700.00
0005434877770	14590	Economy	11700.00
0005434426428	14590	Economy	11700.00
0005434426638	14590	Economy	11700.00
0005435126165	14590	Economy	11700.00
0005434877959	14590	Economy	11700.00
0005435126129	14590	Economy	11700.00
0005434878045	14590	Economy	11700.00
0005432799266	14590	Economy	11700.00
0005434878038	14590	Economy	11700.00
0005434877946	14590	Economy	11700.00
0005435126390	14590	Economy	11700.00
0005434426519	14590	Economy	11700.00
0005434426489	14590	Economy	11700.00
0005434426526	14590	Economy	11700.00
0005434937996	14590	Economy	11700.00
0005435126122	14590	Economy	11700.00
0005434938168	14590	Economy	11700.00
0005432799369	14590	Economy	11700.00
0005434877955	14590	Economy	11700.00
0005434878106	14590	Economy	11700.00
0005434877916	14590	Economy	11700.00
0005432799438	14590	Economy	11700.00
0005434878157	14590	Economy	11700.00
0005434426538	14590	Economy	11700.00
0005434878279	14590	Economy	11700.00
0005434877925	14590	Economy	11700.00
0005434426646	14590	Economy	11700.00
0005432799387	14590	Economy	11700.00
0005434938096	14590	Economy	11700.00
0005435126023	14590	Economy	11700.00
0005432799322	14590	Economy	11700.00
0005434877954	14590	Economy	11700.00
0005434877644	14590	Economy	11700.00
0005434877180	14590	Economy	11700.00
0005435126345	14590	Economy	11700.00
0005432799406	14590	Economy	11700.00
0005434426630	14590	Economy	11700.00
0005434938097	14590	Economy	12800.00
0005434878186	14590	Economy	12800.00
0005434426642	14590	Economy	12800.00
0005435126377	14590	Economy	11700.00
0005434877455	14590	Economy	11700.00
0005434877938	14590	Economy	12800.00
0005435902805	14590	Economy	11700.00
0005432799340	14590	Economy	11700.00
0005435626133	14590	Economy	11700.00
0005435902815	14590	Economy	11700.00
0005435626107	14590	Economy	11700.00
0005434426572	14590	Economy	11700.00
0005434426499	14590	Economy	11700.00
0005435902814	14590	Economy	11700.00
0005434877997	14590	Economy	11700.00
0005434938091	14590	Economy	11700.00
0005434878050	14590	Economy	11700.00
0005434877798	14590	Economy	11700.00
0005434426500	14590	Economy	11700.00
0005435902817	14590	Economy	11700.00
0005435902807	14590	Economy	11700.00
0005434877984	14590	Economy	11700.00
0005434878112	14590	Economy	11700.00
0005435126186	14590	Economy	11700.00
0005434877799	14590	Economy	11700.00
0005432611683	14590	Economy	11700.00
0005435126139	14590	Economy	11700.00
0005434878017	14590	Economy	11700.00
0005434426551	14590	Economy	11700.00
0005434878037	14590	Economy	11700.00
0005435126164	14590	Economy	11700.00
0005434878252	14590	Economy	11700.00
0005432607538	14590	Economy	11700.00
0005435126329	14590	Economy	11700.00
0005434878260	14590	Economy	11700.00
0005434877846	14590	Economy	11700.00
0005434937995	14590	Economy	11700.00
0005434878094	14590	Economy	11700.00
0005435902818	14590	Economy	11700.00
0005435126261	14590	Economy	11700.00
0005435126309	14590	Economy	11700.00
0005434938112	14590	Economy	11700.00
0005434877671	14590	Economy	11700.00
0005432799472	14590	Economy	11700.00
0005435902816	14590	Economy	11700.00
0005434878130	14590	Economy	11700.00
0005434426498	14590	Economy	11700.00
0005435126024	14590	Economy	11700.00
0005432607565	14590	Economy	11700.00
0005432799252	14590	Economy	11700.00
0005435126218	14590	Economy	11700.00
0005434877939	14590	Economy	11700.00
0005434877836	14590	Economy	11700.00
0005434878025	14590	Economy	11700.00
0005434877835	14590	Economy	11700.00
0005434877996	14590	Economy	11700.00
0005434877924	14590	Economy	11700.00
0005432799393	14590	Economy	11700.00
0005434426518	14590	Economy	11700.00
0005434426644	14590	Economy	11700.00
0005434877779	14590	Economy	11700.00
0005432799470	14590	Economy	11700.00
0005434877940	14590	Economy	11700.00
0005435902813	14590	Economy	11700.00
0005434877949	14590	Economy	11700.00
0005432799339	14590	Economy	11700.00
0005434426481	14590	Economy	11700.00
0005434878019	14590	Economy	11700.00
0005434877958	14590	Economy	11700.00
0005435902808	14590	Economy	11700.00
0005434426623	14590	Economy	11700.00
0005432799353	14590	Economy	11700.00
0005434877814	14590	Economy	11700.00
0005434938117	14590	Economy	11700.00
0005432799267	14590	Economy	11700.00
0005434878136	14590	Economy	11700.00
0005434938177	14590	Economy	11700.00
0005434426643	14590	Economy	11700.00
0005434877889	14590	Economy	11700.00
0005434877911	14590	Economy	11700.00
0005434878118	14590	Economy	11700.00
0005434878111	14590	Economy	11700.00
0005434878091	14590	Economy	11700.00
0005434878183	14590	Economy	11700.00
0005434426577	14590	Economy	11700.00
0005434426515	14590	Economy	11700.00
0005434877676	14590	Economy	11700.00
0005434877934	14590	Economy	11700.00
0005432607555	14590	Economy	11700.00
0005432607564	14590	Economy	12800.00
0005434877590	14590	Economy	12800.00
0005434938034	14590	Economy	12800.00
0005434426438	14590	Economy	12800.00
0005434877935	14590	Economy	12800.00
0005434878286	14590	Economy	11700.00
0005434878285	14590	Economy	11700.00
0005434938080	14590	Economy	11700.00
0005432799283	14590	Economy	11700.00
0005434878066	14590	Economy	11700.00
0005432799379	14590	Economy	11700.00
0005435126279	14590	Economy	11700.00
0005434878204	14590	Economy	11700.00
0005434877888	14590	Economy	11700.00
0005434877926	14590	Economy	11700.00
0005434877930	14590	Economy	11700.00
0005434878052	14590	Economy	11700.00
0005434938140	14590	Economy	11700.00
0005434938095	14590	Economy	11700.00
0005435626137	14590	Economy	11700.00
0005434877840	14590	Economy	11700.00
0005434877891	14590	Economy	11700.00
0005434877654	14590	Economy	11700.00
0005434878065	14590	Economy	11700.00
0005434878137	14590	Economy	11700.00
0005434878069	14590	Economy	11700.00
0005432799409	14590	Economy	11700.00
0005434878047	14590	Economy	11700.00
0005434877812	14590	Economy	11700.00
0005435125936	14590	Economy	11700.00
0005434878101	14590	Economy	11700.00
0005435126323	14590	Economy	11700.00
0005434877963	14590	Economy	11700.00
0005434426524	14590	Economy	11700.00
0005434877927	14590	Economy	11700.00
0005435902811	14590	Economy	11700.00
0005432799373	14590	Economy	11700.00
0005435126343	14590	Economy	11700.00
0005434878171	14590	Economy	11700.00
0005435126150	14590	Economy	11700.00
0005435126439	14590	Economy	11700.00
0005435126418	14590	Economy	11700.00
0005434938139	14590	Economy	11700.00
0005435626079	14590	Economy	11700.00
0005434878145	14590	Economy	11700.00
0005434878253	14590	Economy	11700.00
0005432607554	14590	Economy	11700.00
0005435626045	14590	Economy	11700.00
0005435126344	14590	Economy	11700.00
0005434878059	14590	Economy	11700.00
0005435126402	14590	Economy	11700.00
0005434938113	14590	Economy	11700.00
0005432799441	14590	Economy	11700.00
0005434877815	14590	Economy	11700.00
0005432799390	14590	Economy	11700.00
0005434938118	14590	Economy	11700.00
0005435126262	14590	Economy	11700.00
0005435126202	14590	Economy	11700.00
0005434426490	14590	Economy	11700.00
0005434877512	14590	Economy	11700.00
0005435126179	14590	Economy	11700.00
0005434426652	14590	Economy	11700.00
0005432607536	14590	Economy	11700.00
0005432611706	14590	Economy	11700.00
0005435126224	14590	Economy	11700.00
0005435126260	14590	Economy	11700.00
0005434877968	14590	Economy	11700.00
0005432799427	14590	Economy	11700.00
0005432799410	14590	Economy	11700.00
0005434877771	14590	Economy	11700.00
0005434426622	14590	Economy	11700.00
0005434426639	14590	Economy	11700.00
0005434877912	14590	Economy	11700.00
0005432059517	14590	Economy	11700.00
0005435126282	14590	Economy	11700.00
0005435626097	14590	Economy	11700.00
0005434426645	14590	Economy	11700.00
0005434426525	14590	Economy	11700.00
0005435126403	14590	Economy	11700.00
0005434877513	14590	Economy	11700.00
0005434877962	14590	Economy	11700.00
0005434878053	14590	Economy	11700.00
0005435126305	14590	Economy	11700.00
0005434938054	14590	Economy	11700.00
0005434426548	14590	Economy	11700.00
0005434938033	14590	Economy	11700.00
0005434426517	14590	Economy	11700.00
0005435889851	3642	Economy	16300.00
0005435889905	3642	Economy	16300.00
0005434325717	3642	Economy	14800.00
0005434312331	3642	Economy	14800.00
0005434312332	3642	Economy	14800.00
0005434325725	3642	Economy	14800.00
0005434325724	3642	Economy	14800.00
0005434325721	3642	Economy	14800.00
0005434325726	3642	Economy	14800.00
0005435889860	3642	Economy	14800.00
0005435889859	3642	Economy	14800.00
0005435889887	3642	Economy	14800.00
0005434325720	3642	Economy	14800.00
0005435889892	3642	Economy	14800.00
0005435889850	3642	Economy	14800.00
0005435889883	3642	Economy	14800.00
0005435889857	3642	Economy	14800.00
0005434325722	3642	Economy	14800.00
0005434325723	3642	Economy	14800.00
0005434325718	3642	Economy	14800.00
0005434325719	3642	Economy	14800.00
0005434325606	15606	Economy	16300.00
0005434325635	15606	Economy	16300.00
0005435889933	15606	Economy	14800.00
0005435889932	15606	Economy	14800.00
0005435889936	15606	Economy	14800.00
0005434325592	15606	Economy	14800.00
0005434325630	15606	Economy	14800.00
0005434325595	15606	Economy	14800.00
0005434325677	15606	Economy	14800.00
0005435889931	15606	Economy	14800.00
0005434325631	15606	Economy	14800.00
0005435889934	15606	Economy	14800.00
0005435889935	15606	Economy	14800.00
0005433420353	628	Economy	4500.00
0005435957790	628	Economy	4100.00
0005435957787	628	Economy	4100.00
0005435957799	628	Economy	4100.00
0005435957791	628	Economy	4100.00
0005435957793	628	Economy	4100.00
0005435957797	628	Economy	4100.00
0005435957794	628	Economy	4100.00
0005435957796	628	Economy	4100.00
0005435957786	628	Economy	4100.00
0005435957789	628	Economy	4100.00
0005435957792	628	Economy	4100.00
0005433420383	628	Economy	4100.00
0005433420372	628	Economy	4100.00
0005433420423	628	Economy	4100.00
0005435957788	628	Economy	4100.00
0005433420406	628	Economy	4100.00
0005433420354	628	Economy	4100.00
0005433420387	628	Economy	4100.00
0005435957795	628	Economy	4100.00
0005435957800	628	Economy	4100.00
0005433420388	628	Economy	4100.00
0005435957798	628	Economy	4100.00
0005433420373	628	Economy	4100.00
0005433420389	628	Economy	4100.00
0005435957642	15202	Economy	4500.00
0005435957619	15202	Economy	4100.00
0005433420458	15202	Economy	4100.00
0005433420455	15202	Economy	4100.00
0005433420452	15202	Economy	4100.00
0005433420459	15202	Economy	4100.00
0005435957643	15202	Economy	4100.00
0005435957593	15202	Economy	4100.00
0005435957587	15202	Economy	4100.00
0005433420451	15202	Economy	4100.00
0005433420450	15202	Economy	4100.00
0005433420457	15202	Economy	4100.00
0005435957666	15202	Economy	4100.00
0005433420456	15202	Economy	4100.00
0005433420453	15202	Economy	4100.00
0005435957620	15202	Economy	4100.00
0005433420454	15202	Economy	4100.00
0005435629411	8910	Economy	10400.00
0005434247136	8910	Economy	10400.00
0005434247132	8910	Economy	10400.00
0005435629410	8910	Economy	10400.00
0005435629403	16081	Economy	10400.00
0005434247164	16081	Economy	10400.00
0005435629402	16081	Economy	10400.00
0005434247163	16081	Economy	10400.00
0005434247162	16081	Economy	10400.00
0005434096734	11823	Economy	13400.00
0005434096730	11823	Economy	13400.00
0005434096735	11823	Economy	13400.00
0005434096737	11823	Economy	13400.00
0005434096731	11823	Economy	13400.00
0005434096728	11823	Economy	13400.00
0005434096733	11823	Economy	13400.00
0005435933437	4437	Economy	12200.00
0005435933440	4437	Economy	12200.00
0005435163267	4437	Economy	12200.00
0005435933455	4437	Economy	12200.00
0005435163263	4437	Economy	12200.00
0005435933452	4437	Economy	12200.00
0005435163262	4437	Economy	12200.00
0005435163261	4437	Economy	12200.00
0005435933454	4437	Economy	12200.00
0005435163257	4437	Economy	12200.00
0005435163259	4437	Economy	12200.00
0005435163258	4437	Economy	12200.00
0005435933453	4437	Economy	12200.00
0005435163265	4437	Economy	12200.00
0005435933446	4437	Economy	12200.00
0005435933439	4437	Economy	12200.00
0005435933451	4437	Economy	12200.00
0005435933450	4437	Economy	12200.00
0005435933447	4437	Economy	12200.00
0005435163266	4437	Economy	12200.00
0005435163264	4437	Economy	12200.00
0005435163260	4437	Economy	12200.00
0005435163235	29511	Economy	13400.00
0005435163234	29511	Economy	12200.00
0005435933473	29511	Economy	12200.00
0005435163221	29511	Economy	12200.00
0005435163229	29511	Economy	12200.00
0005435933475	29511	Economy	12200.00
0005435933474	29511	Economy	12200.00
0005435163217	29511	Economy	12200.00
0005435933476	29511	Economy	12200.00
0005435163205	29511	Economy	12200.00
0005435933471	29511	Economy	12200.00
0005435163206	29511	Economy	12200.00
0005435163218	29511	Economy	12200.00
0005435933477	29511	Economy	12200.00
0005435933472	29511	Economy	12200.00
0005435163233	29511	Economy	12200.00
0005435163211	29511	Economy	12200.00
0005435163230	29511	Economy	12200.00
0005433404775	2839	Business	12600.00
0005435797566	2839	Business	12600.00
0005435797561	2839	Business	12600.00
0005435797564	2839	Economy	4200.00
0005433404789	2839	Economy	4200.00
0005433404771	2839	Economy	4600.00
0005435797560	2839	Economy	4600.00
0005435797558	2839	Economy	4200.00
0005433404788	2839	Economy	4200.00
0005435797563	2839	Economy	4200.00
0005435797565	2839	Economy	4200.00
0005435797562	2839	Economy	4200.00
0005435797568	2839	Economy	4200.00
0005435797556	2839	Economy	4200.00
0005433404799	2839	Economy	4200.00
0005435797567	2839	Economy	4200.00
0005435797555	2839	Economy	4200.00
0005435797559	2839	Economy	4200.00
0005435797557	2839	Economy	4200.00
0005435797460	29334	Business	12600.00
0005435797509	29334	Business	12600.00
0005433404856	29334	Economy	4200.00
0005433404858	29334	Economy	4600.00
0005435797415	29334	Economy	4200.00
0005435797508	29334	Economy	4200.00
0005433404855	29334	Economy	4200.00
0005433404853	29334	Economy	4200.00
0005433404860	29334	Economy	4200.00
0005435797416	29334	Economy	4200.00
0005433404859	29334	Economy	4200.00
0005435797503	29334	Economy	4200.00
0005435797502	29334	Economy	4200.00
0005435797427	29334	Economy	4200.00
0005435797481	29334	Economy	4200.00
0005433404854	29334	Economy	4200.00
0005433404857	29334	Economy	4200.00
0005435797476	29334	Economy	4200.00
0005435797461	29334	Economy	4200.00
0005435797475	29334	Economy	4200.00
0005435376348	5839	Economy	6800.00
0005434948064	5831	Economy	6800.00
0005434948070	5831	Economy	6800.00
0005434948072	5831	Economy	6800.00
0005434948073	5831	Economy	6800.00
0005434948067	5831	Economy	6800.00
0005434948068	5831	Economy	6800.00
0005434948069	5831	Economy	6800.00
0005434948066	5831	Economy	6800.00
0005434948071	5831	Economy	6800.00
0005434948065	5831	Economy	6800.00
0005434948022	16334	Economy	6800.00
0005434948020	16334	Economy	6800.00
0005435376366	16334	Economy	6800.00
0005435376368	16334	Economy	6800.00
0005434948026	16334	Economy	6800.00
0005434948021	16334	Economy	6800.00
0005434947995	16334	Economy	6800.00
0005434947968	16334	Economy	6800.00
0005435376367	16334	Economy	6800.00
0005434947969	16334	Economy	6800.00
0005433961239	6920	Business	21400.00
0005433961251	6920	Business	21400.00
0005433961223	6920	Business	21400.00
0005433961234	6920	Business	21400.00
0005433961261	6920	Business	21400.00
0005433961259	6920	Business	21400.00
0005433961250	6920	Business	21400.00
0005433961229	6920	Business	21400.00
0005433961258	6920	Business	21400.00
0005433961219	6920	Economy	7100.00
0005433961244	6920	Economy	7100.00
0005433961238	6920	Economy	7100.00
0005433961245	6920	Economy	7800.00
0005433961232	6920	Economy	7800.00
0005433961257	6920	Economy	7800.00
0005433961242	6920	Economy	7800.00
0005433961225	6920	Economy	7100.00
0005433961235	6920	Economy	7100.00
0005433961256	6920	Economy	7100.00
0005433961249	6920	Economy	7100.00
0005433961248	6920	Economy	7100.00
0005433961220	6920	Economy	7100.00
0005433961214	6920	Economy	7100.00
0005433961236	6920	Economy	7100.00
0005433961218	6920	Economy	7100.00
0005433961215	6920	Economy	7100.00
0005433961240	6920	Economy	7100.00
0005433961221	6920	Economy	7100.00
0005433961243	6920	Economy	7100.00
0005433961237	6920	Economy	7100.00
0005433961241	6920	Economy	7100.00
0005433961222	6920	Economy	7100.00
0005433961253	6920	Economy	7100.00
0005433961213	6920	Economy	7100.00
0005433961233	6920	Economy	7100.00
0005433961230	6920	Economy	7100.00
0005433961262	6920	Economy	7100.00
0005433961231	6920	Economy	7100.00
0005433961252	6920	Economy	7100.00
0005433961247	6920	Economy	7100.00
0005433961255	6920	Economy	7100.00
0005433961216	6920	Economy	7100.00
0005433961217	6920	Economy	7100.00
0005433961254	6920	Economy	7100.00
0005433961228	6920	Economy	7100.00
0005433961212	6920	Economy	7100.00
0005433961224	6920	Economy	7100.00
0005433961260	6920	Economy	7100.00
0005433961227	6920	Economy	7100.00
0005433961226	6920	Economy	7100.00
0005433961246	6920	Economy	7100.00
0005433960447	25810	Business	21400.00
0005433960540	25810	Business	21400.00
0005433960445	25810	Business	21400.00
0005433960639	25810	Business	21400.00
0005433960587	25810	Business	21400.00
0005433960491	25810	Economy	7100.00
0005433960567	25810	Economy	7100.00
0005433960640	25810	Economy	7100.00
0005433960446	25810	Economy	7100.00
0005433960615	25810	Economy	7100.00
0005433960515	25810	Economy	7100.00
0005433960657	25810	Economy	7100.00
0005433960614	25810	Economy	7800.00
0005433960601	25810	Economy	7800.00
0005433960577	25810	Economy	7800.00
0005433960589	25810	Economy	7800.00
0005433960444	25810	Economy	7800.00
0005433960501	25810	Economy	7100.00
0005433960606	25810	Economy	7100.00
0005433960384	25810	Economy	7100.00
0005433960578	25810	Economy	7100.00
0005433960662	25810	Economy	7100.00
0005433960463	25810	Economy	7100.00
0005433960338	25810	Economy	7100.00
0005433960598	25810	Economy	7100.00
0005433960636	25810	Economy	7100.00
0005433960613	25810	Economy	7100.00
0005433960647	25810	Economy	7100.00
0005433960486	25810	Economy	7100.00
0005433960496	25810	Economy	7100.00
0005433960602	25810	Economy	7100.00
0005433960630	25810	Economy	7100.00
0005433960497	25810	Economy	7100.00
0005433960554	25810	Economy	7100.00
0005433960539	25810	Economy	7100.00
0005433960616	25810	Economy	7100.00
0005433960403	25810	Economy	7100.00
0005433960590	25810	Economy	7100.00
0005433960608	25810	Economy	7100.00
0005433960537	25810	Economy	7100.00
0005433960485	25810	Economy	7100.00
0005433960627	25810	Economy	7100.00
0005433960656	25810	Economy	7100.00
0005433960645	25810	Economy	7100.00
0005433960654	25810	Economy	7100.00
0005433960492	25810	Economy	7100.00
0005433960385	25810	Economy	7100.00
0005433960266	25810	Economy	7100.00
0005433960643	25810	Economy	7100.00
0005433960536	25810	Economy	7100.00
0005433960573	25810	Economy	7100.00
0005433960514	25810	Economy	7100.00
0005433960420	25810	Economy	7100.00
0005433960484	25810	Economy	7100.00
0005433960566	25810	Economy	7100.00
0005433960655	25810	Economy	7100.00
0005433960637	25810	Economy	7100.00
0005433960591	25810	Economy	7100.00
0005433960389	25810	Economy	7100.00
0005433960498	25810	Economy	7100.00
0005433960576	25810	Economy	7100.00
0005433960337	25810	Economy	7100.00
0005433960617	25810	Economy	7100.00
0005433960644	25810	Economy	7100.00
0005433960638	25810	Economy	7100.00
0005433960412	25810	Economy	7100.00
0005433960572	25810	Economy	7100.00
0005435082763	24485	Economy	3900.00
0005435082739	24485	Economy	3900.00
0005435082742	24485	Economy	3900.00
0005435082762	24485	Economy	3900.00
0005435082751	24485	Economy	3900.00
0005435082827	26070	Economy	3900.00
0005435082825	26070	Economy	3900.00
0005435082823	26070	Economy	3900.00
0005435082824	26070	Economy	3900.00
0005435082829	26070	Economy	3900.00
0005435082831	26070	Economy	3900.00
0005435082828	26070	Economy	3900.00
0005435082826	26070	Economy	3900.00
0005435082830	26070	Economy	3900.00
0005435286625	5026	Business	18000.00
0005433534500	5026	Business	18000.00
0005434245169	5026	Business	18000.00
0005434245171	5026	Business	18000.00
0005434245170	5026	Economy	6600.00
0005432166923	5026	Economy	6600.00
0005435286627	5026	Economy	6000.00
0005434245156	5026	Economy	6000.00
0005434245165	5026	Economy	6000.00
0005433534488	5026	Economy	6000.00
0005434245161	5026	Economy	6000.00
0005434245162	5026	Economy	6000.00
0005434245152	5026	Economy	6000.00
0005434245166	5026	Economy	6000.00
0005432166922	5026	Economy	6000.00
0005434245150	5026	Economy	6000.00
0005435286615	5026	Economy	6000.00
0005435286617	5026	Economy	6000.00
0005435286624	5026	Economy	6000.00
0005432166921	5026	Economy	6000.00
0005434245147	5026	Economy	6000.00
0005434245159	5026	Economy	6000.00
0005434245172	5026	Economy	6600.00
0005434245155	5026	Economy	6000.00
0005434245154	5026	Economy	6600.00
0005434245149	5026	Economy	6000.00
0005434245168	5026	Economy	6000.00
0005434245151	5026	Economy	6000.00
0005434245176	5026	Economy	6000.00
0005433534497	5026	Economy	6000.00
0005434245167	5026	Economy	6000.00
0005434245153	5026	Economy	6000.00
0005435286614	5026	Economy	6000.00
0005434245173	5026	Economy	6000.00
0005434245174	5026	Economy	6000.00
0005434245148	5026	Economy	6000.00
0005434245160	5026	Economy	6000.00
0005434245164	5026	Economy	6000.00
0005434245158	5026	Economy	6000.00
0005435286613	5026	Economy	6000.00
0005434245163	5026	Economy	6000.00
0005433534492	5026	Economy	6000.00
0005434245175	5026	Economy	6000.00
0005434245157	5026	Economy	6000.00
0005433785184	5027	Business	18000.00
0005433615139	5027	Business	18000.00
0005433615135	5027	Business	18000.00
0005433615113	5027	Business	18000.00
0005433785180	5027	Business	18000.00
0005433615132	5027	Business	18000.00
0005432667467	5027	Business	18000.00
0005432105864	5027	Business	18000.00
0005433615108	5027	Business	18000.00
0005433615129	5027	Business	18000.00
0005432105849	5027	Business	18000.00
0005433785174	5027	Business	18000.00
0005432105869	5027	Business	18000.00
0005432105875	5027	Business	18000.00
0005432667466	5027	Business	18000.00
0005433785187	5027	Business	18000.00
0005433785177	5027	Business	18000.00
0005433615122	5027	Business	18000.00
0005432105883	5027	Business	18000.00
0005433785182	5027	Business	18000.00
0005433785179	5027	Business	18000.00
0005433615131	5027	Business	18000.00
0005433615110	5027	Business	18000.00
0005432105879	5027	Business	18000.00
0005433615172	5027	Business	18000.00
0005433615140	5027	Business	18000.00
0005432105838	5027	Business	18000.00
0005432105874	5027	Business	18000.00
0005433615124	5027	Economy	6600.00
0005433785156	5027	Economy	6600.00
0005432105881	5027	Economy	6600.00
0005433785161	5027	Economy	6600.00
0005433615171	5027	Economy	6600.00
0005433615152	5027	Economy	6600.00
0005433615155	5027	Economy	6000.00
0005432105873	5027	Economy	6000.00
0005432105853	5027	Economy	6000.00
0005433615133	5027	Economy	6000.00
0005432105844	5027	Economy	6000.00
0005433615137	5027	Economy	6000.00
0005433615125	5027	Economy	6000.00
0005432145124	5027	Economy	6000.00
0005433615114	5027	Economy	6000.00
0005432105880	5027	Economy	6000.00
0005432105847	5027	Economy	6000.00
0005432105841	5027	Economy	6000.00
0005433615181	5027	Economy	6000.00
0005432666400	5027	Economy	6000.00
0005433615162	5027	Economy	6000.00
0005432105878	5027	Economy	6000.00
0005433615150	5027	Economy	6000.00
0005433785162	5027	Economy	6000.00
0005433615136	5027	Economy	6000.00
0005432667468	5027	Economy	6000.00
0005433615168	5027	Economy	6000.00
0005433615119	5027	Economy	6000.00
0005433615121	5027	Economy	6000.00
0005433785160	5027	Economy	6000.00
0005433785168	5027	Economy	6000.00
0005433785163	5027	Economy	6000.00
0005433615160	5027	Economy	6000.00
0005433615180	5027	Economy	6000.00
0005433615151	5027	Economy	6000.00
0005433615146	5027	Economy	6000.00
0005433615128	5027	Economy	6000.00
0005433785178	5027	Economy	6000.00
0005432105856	5027	Economy	6000.00
0005432105843	5027	Economy	6000.00
0005433615169	5027	Economy	6000.00
0005433615115	5027	Economy	6000.00
0005433615144	5027	Economy	6000.00
0005432666402	5027	Economy	6000.00
0005433615120	5027	Economy	6000.00
0005432105870	5027	Economy	6000.00
0005433785158	5027	Economy	6000.00
0005432105846	5027	Economy	6000.00
0005433785164	5027	Economy	6000.00
0005433785181	5027	Economy	6000.00
0005433615111	5027	Economy	6000.00
0005433785155	5027	Economy	6000.00
0005432105868	5027	Economy	6000.00
0005433785186	5027	Economy	6000.00
0005433785183	5027	Economy	6000.00
0005433615170	5027	Economy	6000.00
0005433785166	5027	Economy	6000.00
0005433615173	5027	Economy	6000.00
0005432105857	5027	Economy	6000.00
0005433615179	5027	Economy	6000.00
0005433785165	5027	Economy	6000.00
0005433785171	5027	Economy	6000.00
0005433615118	5027	Economy	6000.00
0005433615112	5027	Economy	6000.00
0005432105863	5027	Economy	6000.00
0005433615126	5027	Economy	6000.00
0005433615116	5027	Economy	6600.00
0005432105859	5027	Economy	6600.00
0005432665287	5027	Economy	6600.00
0005433615182	5027	Economy	6600.00
0005432105858	5027	Economy	6600.00
0005432105862	5027	Economy	6000.00
0005433615134	5027	Economy	6000.00
0005432105851	5027	Economy	6000.00
0005433615127	5027	Economy	6000.00
0005432105861	5027	Economy	6600.00
0005432105837	5027	Economy	6000.00
0005432667465	5027	Economy	6000.00
0005432105885	5027	Economy	6000.00
0005433615159	5027	Economy	6000.00
0005432105845	5027	Economy	6000.00
0005432666401	5027	Economy	6000.00
0005433785154	5027	Economy	6000.00
0005433615166	5027	Economy	6000.00
0005433615158	5027	Economy	6000.00
0005433615149	5027	Economy	6000.00
0005433615130	5027	Economy	6000.00
0005433785169	5027	Economy	6000.00
0005432105877	5027	Economy	6000.00
0005433615163	5027	Economy	6000.00
0005433785153	5027	Economy	6000.00
0005433785157	5027	Economy	6000.00
0005433615153	5027	Economy	6000.00
0005433615148	5027	Economy	6000.00
0005433785176	5027	Economy	6000.00
0005433615109	5027	Economy	6000.00
0005432105882	5027	Economy	6000.00
0005432105839	5027	Economy	6000.00
0005433615138	5027	Economy	6000.00
0005433615142	5027	Economy	6000.00
0005433615165	5027	Economy	6000.00
0005433615141	5027	Economy	6000.00
0005432105860	5027	Economy	6000.00
0005433615123	5027	Economy	6000.00
0005433785185	5027	Economy	6000.00
0005432105840	5027	Economy	6000.00
0005433785170	5027	Economy	6000.00
0005433785173	5027	Economy	6000.00
0005433615156	5027	Economy	6000.00
0005432665286	5027	Economy	6000.00
0005432105872	5027	Economy	6000.00
0005432105854	5027	Economy	6000.00
0005432145123	5027	Economy	6000.00
0005432105867	5027	Economy	6000.00
0005432105842	5027	Economy	6000.00
0005433615161	5027	Economy	6000.00
0005433615175	5027	Economy	6000.00
0005433615147	5027	Economy	6000.00
0005433615164	5027	Economy	6000.00
0005433615176	5027	Economy	6000.00
0005433615177	5027	Economy	6000.00
0005433615145	5027	Economy	6000.00
0005433615143	5027	Economy	6000.00
0005432105866	5027	Economy	6000.00
0005433615174	5027	Economy	6000.00
0005432105876	5027	Economy	6000.00
0005433615154	5027	Economy	6000.00
0005432105871	5027	Economy	6000.00
0005433785172	5027	Economy	6000.00
0005433785159	5027	Economy	6000.00
0005433615157	5027	Economy	6000.00
0005432105850	5027	Economy	6000.00
0005433785167	5027	Economy	6000.00
0005432105855	5027	Economy	6000.00
0005433615167	5027	Economy	6000.00
0005432105884	5027	Economy	6000.00
0005433615117	5027	Economy	6000.00
0005432105852	5027	Economy	6000.00
0005432105848	5027	Economy	6000.00
0005433615178	5027	Economy	6000.00
0005433785175	5027	Economy	6000.00
0005432105865	5027	Economy	6000.00
0005432335979	5029	Business	18000.00
0005434265286	5029	Business	18000.00
0005434149807	5029	Business	18000.00
0005434229509	5029	Business	18000.00
0005434149806	5029	Business	18000.00
0005434265291	5029	Business	18000.00
0005434149802	5029	Business	18000.00
0005435006953	5029	Business	18000.00
0005434173546	5029	Business	18000.00
0005435006957	5029	Business	18000.00
0005434229511	5029	Business	18000.00
0005435269673	5029	Business	18000.00
0005434229513	5029	Business	18000.00
0005434229520	5029	Business	18000.00
0005432336048	5029	Business	18000.00
0005432336012	5029	Business	18000.00
0005434149804	5029	Business	18000.00
0005435006939	5029	Business	18000.00
0005434265293	5029	Business	18000.00
0005435006960	5029	Economy	6600.00
0005434265285	5029	Economy	6600.00
0005434229517	5029	Economy	6600.00
0005435269672	5029	Economy	6600.00
0005433685509	5029	Economy	6000.00
0005434149805	5029	Economy	6600.00
0005434265300	5029	Economy	6000.00
0005433815371	5029	Economy	6000.00
0005434265299	5029	Economy	6000.00
0005433815369	5029	Economy	6000.00
0005434229498	5029	Economy	6000.00
0005435006984	5029	Economy	6000.00
0005433685511	5029	Economy	6000.00
0005434149801	5029	Economy	6000.00
0005434312310	5029	Economy	6000.00
0005432336063	5029	Economy	6000.00
0005434229499	5029	Economy	6000.00
0005435007025	5029	Economy	6000.00
0005435006888	5029	Economy	6000.00
0005434149803	5029	Economy	6000.00
0005433815361	5029	Economy	6000.00
0005435006940	5029	Economy	6000.00
0005433815368	5029	Economy	6000.00
0005434149800	5029	Economy	6000.00
0005435006956	5029	Economy	6000.00
0005434265294	5029	Economy	6000.00
0005434311213	5029	Economy	6000.00
0005434149799	5029	Economy	6000.00
0005435006895	5029	Economy	6000.00
0005435006975	5029	Economy	6000.00
0005433815372	5029	Economy	6000.00
0005434173543	5029	Economy	6000.00
0005432336010	5029	Economy	6000.00
0005434173545	5029	Economy	6000.00
0005435006990	5029	Economy	6000.00
0005434312309	5029	Economy	6000.00
0005434265302	5029	Economy	6000.00
0005434149797	5029	Economy	6000.00
0005434229501	5029	Economy	6000.00
0005434265303	5029	Economy	6000.00
0005434265295	5029	Economy	6000.00
0005434265308	5029	Economy	6000.00
0005434229504	5029	Economy	6000.00
0005435006961	5029	Economy	6000.00
0005434265288	5029	Economy	6000.00
0005434265287	5029	Economy	6000.00
0005435007002	5029	Economy	6000.00
0005434173544	5029	Economy	6600.00
0005435006918	5029	Economy	6600.00
0005434311215	5029	Economy	6600.00
0005434265307	5029	Economy	6600.00
0005433815364	5029	Economy	6000.00
0005434229510	5029	Economy	6000.00
0005434265289	5029	Economy	6000.00
0005435006974	5029	Economy	6000.00
0005434149798	5029	Economy	6000.00
0005434265306	5029	Economy	6000.00
0005434229507	5029	Economy	6000.00
0005434229515	5029	Economy	6000.00
0005434265305	5029	Economy	6000.00
0005433815370	5029	Economy	6000.00
0005434265296	5029	Economy	6000.00
0005434265297	5029	Economy	6000.00
0005434311214	5029	Economy	6000.00
0005434229518	5029	Economy	6000.00
0005434265284	5029	Economy	6000.00
0005434265290	5029	Economy	6000.00
0005434229502	5029	Economy	6000.00
0005434265301	5029	Economy	6000.00
0005435006995	5029	Economy	6000.00
0005434265309	5029	Economy	6000.00
0005434229516	5029	Economy	6000.00
0005434229512	5029	Economy	6000.00
0005432336013	5029	Economy	6000.00
0005434229514	5029	Economy	6000.00
0005434229506	5029	Economy	6000.00
0005435006917	5029	Economy	6000.00
0005433815373	5029	Economy	6000.00
0005434149808	5029	Economy	6000.00
0005434265304	5029	Economy	6000.00
0005434265292	5029	Economy	6000.00
0005434229500	5029	Economy	6000.00
0005432336009	5029	Economy	6000.00
0005434229519	5029	Economy	6000.00
0005433685510	5029	Economy	6000.00
0005434229508	5029	Economy	6000.00
0005434229505	5029	Economy	6000.00
0005434265298	5029	Economy	6000.00
0005434229503	5029	Economy	6000.00
0005433785042	8565	Business	18000.00
0005433784800	8565	Business	18000.00
0005433784921	8565	Business	18000.00
0005435269780	8565	Business	18000.00
0005433784934	8565	Business	18000.00
0005434244983	8565	Business	18000.00
0005433784864	8565	Business	18000.00
0005432659703	8565	Business	18000.00
0005433784878	8565	Economy	6600.00
0005434244935	8565	Economy	6000.00
0005433784889	8565	Economy	6000.00
0005434244948	8565	Economy	6000.00
0005433784843	8565	Economy	6000.00
0005432666374	8565	Economy	6000.00
0005434244865	8565	Economy	6000.00
0005433784812	8565	Economy	6000.00
0005435269785	8565	Economy	6000.00
0005432659704	8565	Economy	6000.00
0005434245005	8565	Economy	6000.00
0005433784842	8565	Economy	6000.00
0005433784724	8565	Economy	6000.00
0005434244955	8565	Economy	6000.00
0005433784940	8565	Economy	6000.00
0005434244984	8565	Economy	6000.00
0005433784827	8565	Economy	6000.00
0005434244981	8565	Economy	6000.00
0005433784728	8565	Economy	6000.00
0005434244953	8565	Economy	6000.00
0005435269778	8565	Economy	6000.00
0005435269783	8565	Economy	6000.00
0005434244893	8565	Economy	6000.00
0005433784811	8565	Economy	6000.00
0005434244916	8565	Economy	6000.00
0005434244941	8565	Economy	6000.00
0005435269779	8565	Economy	6000.00
0005434244930	8565	Economy	6000.00
0005433784841	8565	Economy	6600.00
0005434244954	8565	Economy	6600.00
0005433785034	8565	Economy	6000.00
0005434245016	8565	Economy	6000.00
0005433784960	8565	Economy	6000.00
0005433784725	8565	Economy	6000.00
0005434244973	8565	Economy	6000.00
0005433784961	8565	Economy	6000.00
0005433784852	8565	Economy	6000.00
0005434244945	8565	Economy	6000.00
0005434244929	8565	Economy	6000.00
0005434245017	8565	Economy	6000.00
0005433784922	8565	Economy	6000.00
0005433784853	8565	Economy	6000.00
0005435269777	8565	Economy	6000.00
0005433784839	8565	Economy	6000.00
0005432663016	8565	Economy	6000.00
0005433784946	8565	Economy	6000.00
0005434244932	8565	Economy	6000.00
0005435269784	8565	Economy	6000.00
0005434244861	8565	Economy	6000.00
0005434244952	8565	Economy	6000.00
0005434244947	8565	Economy	6000.00
0005434245038	8565	Economy	6000.00
0005433784939	8565	Economy	6000.00
0005434244962	8565	Economy	6000.00
0005435269781	8565	Economy	6000.00
0005434244985	8565	Economy	6000.00
0005433784840	8565	Economy	6000.00
0005435269782	8565	Economy	6000.00
0005434244980	8565	Economy	6000.00
0005433784858	8565	Economy	6000.00
0005434244931	8565	Economy	6000.00
0005434244946	8565	Economy	6000.00
0005433784894	8565	Economy	6000.00
0005434245039	8565	Economy	6000.00
0005434244925	8565	Economy	6000.00
0005434244972	8565	Economy	6000.00
0005434244852	8565	Economy	6000.00
0005433614495	8566	Business	18000.00
0005433614443	8566	Business	18000.00
0005433614389	8566	Business	18000.00
0005433614582	8566	Business	18000.00
0005433614287	8566	Business	18000.00
0005433614425	8566	Business	18000.00
0005433614412	8566	Business	18000.00
0005433614101	8566	Business	18000.00
0005433614382	8566	Economy	6600.00
0005433614100	8566	Economy	6600.00
0005433614618	8566	Economy	6600.00
0005433614383	8566	Economy	6600.00
0005433614433	8566	Economy	6000.00
0005433614305	8566	Economy	6000.00
0005433614462	8566	Economy	6000.00
0005433614539	8566	Economy	6000.00
0005433614415	8566	Economy	6000.00
0005433614183	8566	Economy	6000.00
0005433614326	8566	Economy	6000.00
0005433614562	8566	Economy	6000.00
0005433614641	8566	Economy	6000.00
0005433614501	8566	Economy	6000.00
0005433614603	8566	Economy	6000.00
0005433614237	8566	Economy	6000.00
0005433614496	8566	Economy	6000.00
0005433614363	8566	Economy	6000.00
0005433614019	8566	Economy	6000.00
0005433614301	8566	Economy	6000.00
0005433614288	8566	Economy	6000.00
0005433614161	8566	Economy	6000.00
0005433614307	8566	Economy	6000.00
0005433614338	8566	Economy	6600.00
0005433614619	8566	Economy	6600.00
0005433614374	8566	Economy	6600.00
0005433614494	8566	Economy	6000.00
0005433614642	8566	Economy	6000.00
0005433614275	8566	Economy	6000.00
0005433614327	8566	Economy	6000.00
0005433614333	8566	Economy	6000.00
0005433614498	8566	Economy	6000.00
0005433614515	8566	Economy	6000.00
0005433614424	8566	Economy	6000.00
0005433614497	8566	Economy	6000.00
0005433614652	8566	Economy	6000.00
0005433614328	8566	Economy	6000.00
0005433614653	8566	Economy	6000.00
0005433614397	8566	Economy	6000.00
0005433614225	8566	Economy	6000.00
0005433614421	8566	Economy	6000.00
0005433614463	8566	Economy	6000.00
0005433614286	8566	Economy	6000.00
0005433614289	8566	Economy	6000.00
0005433614375	8566	Economy	6000.00
0005433614388	8566	Economy	6000.00
0005433614381	8566	Economy	6000.00
0005433614236	8566	Economy	6000.00
0005433614332	8566	Economy	6000.00
0005433614387	8566	Economy	6000.00
0005433614224	8566	Economy	6000.00
0005434265119	8567	Business	18000.00
0005432035120	8567	Business	18000.00
0005433689924	8567	Business	18000.00
0005432035124	8567	Business	18000.00
0005434265051	8567	Business	18000.00
0005432047573	8567	Business	18000.00
0005432035118	8567	Business	18000.00
0005434264972	8567	Business	18000.00
0005432336107	8567	Business	18000.00
0005434265072	8567	Business	18000.00
0005434265156	8567	Business	18000.00
0005433534511	8567	Business	18000.00
0005433815415	8567	Business	18000.00
0005434264992	8567	Business	18000.00
0005432047574	8567	Business	18000.00
0005435007169	8567	Business	18000.00
0005434149693	8567	Business	18000.00
0005435007165	8567	Business	18000.00
0005435007173	8567	Business	18000.00
0005433690937	8567	Business	18000.00
0005432035111	8567	Business	18000.00
0005434264973	8567	Business	18000.00
0005432336105	8567	Business	18000.00
0005434149718	8567	Business	18000.00
0005433689923	8567	Economy	6600.00
0005434265111	8567	Economy	6600.00
0005433688823	8567	Economy	6600.00
0005434311233	8567	Economy	6600.00
0005434229324	8567	Economy	6600.00
0005432035114	8567	Economy	6600.00
0005435007172	8567	Economy	6000.00
0005432336113	8567	Economy	6000.00
0005434173524	8567	Economy	6000.00
0005434265152	8567	Economy	6000.00
0005434229348	8567	Economy	6000.00
0005432035122	8567	Economy	6000.00
0005434265109	8567	Economy	6000.00
0005434229309	8567	Economy	6000.00
0005432336114	8567	Economy	6000.00
0005434265073	8567	Economy	6000.00
0005434229288	8567	Economy	6000.00
0005435007177	8567	Economy	6000.00
0005434265066	8567	Economy	6000.00
0005434173493	8567	Economy	6000.00
0005434229295	8567	Economy	6000.00
0005434173498	8567	Economy	6000.00
0005434173527	8567	Economy	6000.00
0005432035115	8567	Economy	6000.00
0005434265077	8567	Economy	6000.00
0005432035117	8567	Economy	6000.00
0005434265075	8567	Economy	6000.00
0005435007164	8567	Economy	6000.00
0005432035131	8567	Economy	6000.00
0005434229321	8567	Economy	6000.00
0005432336111	8567	Economy	6000.00
0005434229202	8567	Economy	6000.00
0005432035112	8567	Economy	6000.00
0005434265139	8567	Economy	6000.00
0005432035130	8567	Economy	6000.00
0005434265037	8567	Economy	6000.00
0005432336104	8567	Economy	6000.00
0005432035106	8567	Economy	6000.00
0005434265130	8567	Economy	6000.00
0005434149678	8567	Economy	6000.00
0005434149689	8567	Economy	6000.00
0005434265067	8567	Economy	6000.00
0005434149672	8567	Economy	6000.00
0005433690938	8567	Economy	6000.00
0005432047575	8567	Economy	6000.00
0005434265052	8567	Economy	6000.00
0005432035110	8567	Economy	6000.00
0005435007162	8567	Economy	6000.00
0005434265211	8567	Economy	6000.00
0005433815419	8567	Economy	6000.00
0005434229291	8567	Economy	6000.00
0005432035127	8567	Economy	6000.00
0005432035126	8567	Economy	6000.00
0005434229230	8567	Economy	6000.00
0005434265155	8567	Economy	6000.00
0005434265094	8567	Economy	6000.00
0005434264977	8567	Economy	6000.00
0005434229325	8567	Economy	6000.00
0005434265025	8567	Economy	6000.00
0005435007161	8567	Economy	6000.00
0005434173513	8567	Economy	6600.00
0005432047571	8567	Economy	6600.00
0005432035108	8567	Economy	6600.00
0005432035107	8567	Economy	6600.00
0005432336106	8567	Economy	6000.00
0005434229310	8567	Economy	6600.00
0005435007175	8567	Economy	6000.00
0005434265120	8567	Economy	6000.00
0005435007174	8567	Economy	6600.00
0005435007171	8567	Economy	6000.00
0005435007176	8567	Economy	6000.00
0005433815418	8567	Economy	6000.00
0005432336103	8567	Economy	6000.00
0005434149688	8567	Economy	6000.00
0005432035113	8567	Economy	6000.00
0005432035121	8567	Economy	6000.00
0005434229355	8567	Economy	6000.00
0005432336102	8567	Economy	6000.00
0005432336109	8567	Economy	6000.00
0005434265019	8567	Economy	6000.00
0005432035116	8567	Economy	6000.00
0005435007170	8567	Economy	6000.00
0005432035119	8567	Economy	6000.00
0005433815414	8567	Economy	6000.00
0005434265018	8567	Economy	6000.00
0005434265137	8567	Economy	6000.00
0005434264993	8567	Economy	6000.00
0005432047572	8567	Economy	6000.00
0005434229387	8567	Economy	6000.00
0005432035123	8567	Economy	6000.00
0005434149703	8567	Economy	6000.00
0005434229201	8567	Economy	6000.00
0005432035128	8567	Economy	6000.00
0005432035105	8567	Economy	6000.00
0005432336112	8567	Economy	6000.00
0005432336108	8567	Economy	6000.00
0005434173494	8567	Economy	6000.00
0005434149702	8567	Economy	6000.00
0005433688821	8567	Economy	6000.00
0005433815416	8567	Economy	6000.00
0005434229300	8567	Economy	6000.00
0005434265071	8567	Economy	6000.00
0005434265076	8567	Economy	6000.00
0005434265093	8567	Economy	6000.00
0005432035132	8567	Economy	6000.00
0005434149629	8567	Economy	6000.00
0005435007168	8567	Economy	6000.00
0005435007166	8567	Economy	6000.00
0005432035125	8567	Economy	6000.00
0005434265114	8567	Economy	6000.00
0005435007163	8567	Economy	6000.00
0005433534512	8567	Economy	6000.00
0005434149694	8567	Economy	6000.00
0005434265060	8567	Economy	6000.00
0005432035109	8567	Economy	6000.00
0005435007167	8567	Economy	6000.00
0005434265133	8567	Economy	6000.00
0005434265110	8567	Economy	6000.00
0005434265026	8567	Economy	6000.00
0005433815417	8567	Economy	6000.00
0005434149685	8567	Economy	6000.00
0005434149699	8567	Economy	6000.00
0005433688822	8567	Economy	6000.00
0005432336110	8567	Economy	6000.00
0005432035129	8567	Economy	6000.00
0005434265154	8567	Economy	6000.00
0005434229374	8567	Economy	6000.00
0005434265068	8567	Economy	6000.00
0005434265023	8567	Economy	6000.00
0005433202451	12603	Economy	16200.00
0005434639216	12603	Economy	16200.00
0005434639266	12603	Economy	16200.00
0005434639303	12603	Economy	16200.00
0005433202457	12603	Economy	14800.00
0005434639134	12603	Economy	14800.00
0005434639296	12603	Economy	14800.00
0005433202459	12603	Economy	14800.00
0005434639192	12603	Economy	14800.00
0005434639283	12603	Economy	14800.00
0005434639252	12603	Economy	14800.00
0005434639311	12603	Economy	14800.00
0005434639274	12603	Economy	14800.00
0005434639318	12603	Economy	14800.00
0005433202458	12603	Economy	14800.00
0005434639310	12603	Economy	14800.00
0005433202461	12603	Economy	14800.00
0005433202455	12603	Economy	14800.00
0005434639321	12603	Economy	14800.00
0005434639354	12603	Economy	14800.00
0005433202463	12603	Economy	14800.00
0005434639130	12603	Economy	14800.00
0005434639317	12603	Economy	14800.00
0005434639370	12603	Economy	14800.00
0005434639309	12603	Economy	14800.00
0005434639353	12603	Economy	14800.00
0005433202452	12603	Economy	14800.00
0005434639163	12603	Economy	14800.00
0005433202460	12603	Economy	14800.00
0005433202454	12603	Economy	14800.00
0005434639156	12603	Economy	14800.00
0005434639164	12603	Economy	14800.00
0005434639358	12603	Economy	14800.00
0005433202453	12603	Economy	14800.00
0005434639357	12603	Economy	14800.00
0005434639109	12603	Economy	14800.00
0005434639253	12603	Economy	14800.00
0005433202456	12603	Economy	14800.00
0005434639135	12603	Economy	14800.00
0005434639215	12603	Economy	14800.00
0005434639254	12603	Economy	14800.00
0005433202462	12603	Economy	14800.00
0005434639263	12603	Economy	14800.00
0005434639294	12603	Economy	14800.00
0005434639249	12603	Economy	14800.00
0005434639217	12603	Economy	14800.00
0005434639306	12603	Economy	14800.00
0005434639264	12603	Economy	14800.00
0005434639275	12603	Economy	14800.00
0005434639463	23384	Economy	16200.00
0005433202326	23384	Economy	16200.00
0005434639467	23384	Economy	16200.00
0005433202294	23384	Economy	14800.00
0005434639464	23384	Economy	14800.00
0005434639451	23384	Economy	14800.00
0005433202287	23384	Economy	14800.00
0005432290649	23384	Economy	14800.00
0005432290650	23384	Economy	14800.00
0005433202328	23384	Economy	14800.00
0005434639470	23384	Economy	14800.00
0005434639465	23384	Economy	14800.00
0005434639476	23384	Economy	14800.00
0005433202289	23384	Economy	14800.00
0005433202327	23384	Economy	14800.00
0005434639475	23384	Economy	14800.00
0005434639455	23384	Economy	14800.00
0005434639456	23384	Economy	14800.00
0005433202312	23384	Economy	14800.00
0005434639459	23384	Economy	14800.00
0005432290648	23384	Economy	14800.00
0005434639457	23384	Economy	14800.00
0005433202310	23384	Economy	14800.00
0005434639466	23384	Economy	14800.00
0005433202272	23384	Economy	14800.00
0005434639468	23384	Economy	14800.00
0005434639474	23384	Economy	14800.00
0005434639452	23384	Economy	14800.00
0005434639454	23384	Economy	14800.00
0005433202292	23384	Economy	14800.00
0005434639469	23384	Economy	14800.00
0005433202271	23384	Economy	14800.00
0005433202307	23384	Economy	14800.00
0005433202337	23384	Economy	14800.00
0005434639460	23384	Economy	14800.00
0005433202291	23384	Economy	14800.00
0005434639458	23384	Economy	14800.00
0005434639461	23384	Economy	14800.00
0005434639473	23384	Economy	14800.00
0005434639453	23384	Economy	14800.00
0005434639450	23384	Economy	14800.00
0005434639472	23384	Economy	14800.00
0005434639471	23384	Economy	14800.00
0005434639462	23384	Economy	14800.00
0005432382848	21110	Business	18900.00
0005432328523	21110	Business	18900.00
0005432382955	21110	Business	18900.00
0005432328713	21110	Business	18900.00
0005432328705	21110	Business	18900.00
0005432382991	21110	Business	18900.00
0005432328368	21110	Business	18900.00
0005432328636	21110	Business	18900.00
0005432328460	21110	Business	18900.00
0005432328678	21110	Business	18900.00
0005432328374	21110	Business	18900.00
0005432328520	21110	Business	18900.00
0005432382895	21110	Economy	6300.00
0005432328488	21110	Economy	6300.00
0005432328547	21110	Economy	6300.00
0005432328704	21110	Economy	6300.00
0005432383039	21110	Economy	6300.00
0005432328578	21110	Economy	6300.00
0005432383054	21110	Economy	6300.00
0005432328603	21110	Economy	6300.00
0005432328675	21110	Economy	6300.00
0005432328581	21110	Economy	6300.00
0005432383019	21110	Economy	6900.00
0005432383040	21110	Economy	6900.00
0005432328596	21110	Economy	6900.00
0005432383033	21110	Economy	6900.00
0005432328549	21110	Economy	6900.00
0005432328661	21110	Economy	6300.00
0005432328482	21110	Economy	6300.00
0005432383083	21110	Economy	6300.00
0005432382856	21110	Economy	6300.00
0005432382932	21110	Economy	6300.00
0005432383052	21110	Economy	6300.00
0005432382942	21110	Economy	6300.00
0005432328548	21110	Economy	6300.00
0005432382904	21110	Economy	6300.00
0005432054324	21110	Economy	6300.00
0005432383009	21110	Economy	6300.00
0005432328527	21110	Economy	6300.00
0005432382896	21110	Economy	6300.00
0005432383045	21110	Economy	6300.00
0005432328613	21110	Economy	6300.00
0005432328522	21110	Economy	6300.00
0005432328666	21110	Economy	6300.00
0005432328437	21110	Economy	6300.00
0005432328590	21110	Economy	6300.00
0005432328674	21110	Economy	6300.00
0005432328677	21110	Economy	6300.00
0005432328597	21110	Economy	6300.00
0005432382965	21110	Economy	6300.00
0005432383030	21110	Economy	6300.00
0005432382951	21110	Economy	6300.00
0005432383006	21110	Economy	6300.00
0005432328628	21110	Economy	6300.00
0005432383046	21110	Economy	6300.00
0005432328461	21110	Economy	6300.00
0005432383018	21110	Economy	6300.00
0005432383051	21110	Economy	6300.00
0005432328371	21110	Economy	6300.00
0005432328434	21110	Economy	6300.00
0005432328591	21110	Economy	6300.00
0005432383063	21110	Economy	6300.00
0005432383086	21110	Economy	6300.00
0005432328614	21110	Economy	6300.00
0005432054325	21110	Economy	6300.00
0005432382992	21110	Economy	6300.00
0005432382974	21110	Economy	6300.00
0005432054323	21110	Economy	6300.00
0005432328686	21110	Economy	6300.00
0005432383007	21110	Economy	6300.00
0005432328334	21110	Economy	6300.00
0005432328602	21110	Economy	6300.00
0005432328577	21110	Economy	6300.00
0005432328594	21110	Economy	6300.00
0005432328526	21110	Economy	6300.00
0005432383055	21110	Economy	6300.00
0005432328764	21110	Economy	6300.00
0005432383053	21110	Economy	6300.00
0005432328667	21110	Economy	6300.00
0005432383044	21110	Economy	6300.00
0005432383082	21110	Economy	6300.00
0005432383078	21110	Economy	6300.00
0005432383020	21110	Economy	6300.00
0005432328622	21110	Economy	6300.00
0005432328573	21110	Economy	6300.00
0005432328685	21110	Economy	6300.00
0005432382973	21110	Economy	6300.00
0005432383000	21110	Economy	6300.00
0005432383048	21110	Economy	6300.00
0005432328413	21110	Economy	6300.00
0005432383076	21110	Economy	6300.00
0005432382980	21110	Economy	6300.00
0005432328638	21110	Economy	6300.00
0005432383008	21110	Economy	6300.00
0005432328433	21110	Economy	6300.00
0005432328694	21110	Economy	6300.00
0005432383366	31277	Business	18900.00
0005432328939	31277	Business	18900.00
0005432328961	31277	Business	18900.00
0005432328936	31277	Business	18900.00
0005432328964	31277	Business	18900.00
0005432383359	31277	Business	18900.00
0005432383385	31277	Business	18900.00
0005432328970	31277	Business	18900.00
0005432328956	31277	Business	18900.00
0005432383361	31277	Business	18900.00
0005432328929	31277	Economy	6300.00
0005432287218	31277	Economy	6300.00
0005432383371	31277	Economy	6300.00
0005432328945	31277	Economy	6300.00
0005432328948	31277	Economy	6300.00
0005432383382	31277	Economy	6300.00
0005432383363	31277	Economy	6300.00
0005432328952	31277	Economy	6300.00
0005432287214	31277	Economy	6300.00
0005432328942	31277	Economy	6300.00
0005432328926	31277	Economy	6900.00
0005432383393	31277	Economy	6900.00
0005432328966	31277	Economy	6900.00
0005432383374	31277	Economy	6900.00
0005432383368	31277	Economy	6300.00
0005432383373	31277	Economy	6300.00
0005432383399	31277	Economy	6300.00
0005432328931	31277	Economy	6300.00
0005432383387	31277	Economy	6300.00
0005432383396	31277	Economy	6300.00
0005432383398	31277	Economy	6300.00
0005432328930	31277	Economy	6300.00
0005432328959	31277	Economy	6300.00
0005432328927	31277	Economy	6300.00
0005432383372	31277	Economy	6300.00
0005432328949	31277	Economy	6300.00
0005432383362	31277	Economy	6300.00
0005432383383	31277	Economy	6300.00
0005432328957	31277	Economy	6300.00
0005432383364	31277	Economy	6300.00
0005432383390	31277	Economy	6300.00
0005432383380	31277	Economy	6300.00
0005432287217	31277	Economy	6300.00
0005432383384	31277	Economy	6300.00
0005432328937	31277	Economy	6300.00
0005432383360	31277	Economy	6300.00
0005432328932	31277	Economy	6300.00
0005432328940	31277	Economy	6300.00
0005432383388	31277	Economy	6300.00
0005432383370	31277	Economy	6300.00
0005432383367	31277	Economy	6300.00
0005432328955	31277	Economy	6300.00
0005432328954	31277	Economy	6300.00
0005432383369	31277	Economy	6300.00
0005432383381	31277	Economy	6300.00
0005432328950	31277	Economy	6300.00
0005432287215	31277	Economy	6300.00
0005432328965	31277	Economy	6300.00
0005432383386	31277	Economy	6300.00
0005432328953	31277	Economy	6300.00
0005432383377	31277	Economy	6300.00
0005432328951	31277	Economy	6300.00
0005432328935	31277	Economy	6300.00
0005432328944	31277	Economy	6300.00
0005432328969	31277	Economy	6300.00
0005432383389	31277	Economy	6300.00
0005432328960	31277	Economy	6300.00
0005432383400	31277	Economy	6300.00
0005432328941	31277	Economy	6300.00
0005432328933	31277	Economy	6300.00
0005432328928	31277	Economy	6300.00
0005432328934	31277	Economy	6300.00
0005432328967	31277	Economy	6300.00
0005432328968	31277	Economy	6300.00
0005432328958	31277	Economy	6300.00
0005432383401	31277	Economy	6300.00
0005432383376	31277	Economy	6300.00
0005432287216	31277	Economy	6300.00
0005432328963	31277	Economy	6300.00
0005432383365	31277	Economy	6300.00
0005432383378	31277	Economy	6300.00
0005432328943	31277	Economy	6300.00
0005432383379	31277	Economy	6300.00
0005432383397	31277	Economy	6300.00
0005432383392	31277	Economy	6300.00
0005432383394	31277	Economy	6300.00
0005432328938	31277	Economy	6300.00
0005432328947	31277	Economy	6300.00
0005432383375	31277	Economy	6300.00
0005432383395	31277	Economy	6300.00
0005432328946	31277	Economy	6300.00
0005432383391	31277	Economy	6300.00
0005432328962	31277	Economy	6300.00
0005433642423	2469	Business	89600.00
0005433642438	2469	Business	89600.00
0005433642435	2469	Business	89600.00
0005433642413	2469	Business	89600.00
0005433642437	2469	Business	89600.00
0005433642430	2469	Business	89600.00
0005433642445	2469	Business	89600.00
0005432953933	2469	Economy	29900.00
0005433642417	2469	Economy	29900.00
0005433642442	2469	Economy	29900.00
0005433642424	2469	Economy	29900.00
0005433642425	2469	Economy	29900.00
0005433642421	2469	Economy	32800.00
0005432953932	2469	Economy	29900.00
0005433642432	2469	Economy	29900.00
0005432953915	2469	Economy	29900.00
0005433642426	2469	Economy	29900.00
0005432953923	2469	Economy	29900.00
0005433642433	2469	Economy	29900.00
0005433642419	2469	Economy	29900.00
0005433642443	2469	Economy	29900.00
0005433642428	2469	Economy	29900.00
0005433642429	2469	Economy	29900.00
0005433642427	2469	Economy	29900.00
0005433642422	2469	Economy	29900.00
0005432953922	2469	Economy	29900.00
0005433642418	2469	Economy	29900.00
0005432953909	2469	Economy	29900.00
0005432953924	2469	Economy	29900.00
0005433642444	2469	Economy	29900.00
0005432953926	2469	Economy	29900.00
0005433642440	2469	Economy	29900.00
0005433642416	2469	Economy	29900.00
0005433642436	2469	Economy	29900.00
0005433642414	2469	Economy	29900.00
0005432953925	2469	Economy	29900.00
0005433642431	2469	Economy	29900.00
0005433642420	2469	Economy	29900.00
0005433642441	2469	Economy	29900.00
0005433642412	2469	Economy	29900.00
0005433642434	2469	Economy	29900.00
0005433642415	2469	Economy	29900.00
0005433642439	2469	Economy	29900.00
0005432953972	27586	Business	89600.00
0005433642311	27586	Business	89600.00
0005433642206	27586	Business	89600.00
0005432953977	27586	Business	89600.00
0005433642292	27586	Business	89600.00
0005433642282	27586	Business	89600.00
0005433642322	27586	Business	89600.00
0005433642298	27586	Business	89600.00
0005432953987	27586	Business	89600.00
0005433642261	27586	Business	89600.00
0005432953986	27586	Economy	29900.00
0005433642304	27586	Economy	29900.00
0005432953984	27586	Economy	29900.00
0005433642198	27586	Economy	29900.00
0005433642290	27586	Economy	29900.00
0005432953989	27586	Economy	29900.00
0005433642265	27586	Economy	29900.00
0005433642301	27586	Economy	32800.00
0005432953983	27586	Economy	32800.00
0005433642316	27586	Economy	32800.00
0005432953976	27586	Economy	32800.00
0005433642267	27586	Economy	32800.00
0005432953982	27586	Economy	29900.00
0005432953992	27586	Economy	29900.00
0005432953990	27586	Economy	29900.00
0005433642299	27586	Economy	29900.00
0005433642305	27586	Economy	29900.00
0005433642315	27586	Economy	29900.00
0005433642221	27586	Economy	29900.00
0005433642224	27586	Economy	29900.00
0005432953981	27586	Economy	29900.00
0005433642293	27586	Economy	29900.00
0005433642286	27586	Economy	29900.00
0005433642259	27586	Economy	29900.00
0005433642266	27586	Economy	29900.00
0005433642171	27586	Economy	29900.00
0005433642334	27586	Economy	29900.00
0005433642210	27586	Economy	29900.00
0005433642262	27586	Economy	29900.00
0005433642269	27586	Economy	29900.00
0005433642225	27586	Economy	29900.00
0005432953978	27586	Economy	29900.00
0005433642323	27586	Economy	29900.00
0005433642276	27586	Economy	29900.00
0005432953975	27586	Economy	29900.00
0005432953970	27586	Economy	29900.00
0005432953988	27586	Economy	29900.00
0005432953979	27586	Economy	29900.00
0005433642255	27586	Economy	29900.00
0005433642300	27586	Economy	29900.00
0005433642278	27586	Economy	29900.00
0005433642172	27586	Economy	29900.00
0005433642283	27586	Economy	29900.00
0005433642366	27586	Economy	29900.00
0005433642268	27586	Economy	29900.00
0005432953969	27586	Economy	29900.00
0005433642185	27586	Economy	29900.00
0005433642333	27586	Economy	29900.00
0005433642260	27586	Economy	29900.00
0005432953993	27586	Economy	29900.00
0005432953985	27586	Economy	29900.00
0005433642274	27586	Economy	29900.00
0005432953980	27586	Economy	29900.00
0005432953974	27586	Economy	29900.00
0005432953971	27586	Economy	29900.00
0005433642272	27586	Economy	29900.00
0005433642275	27586	Economy	29900.00
0005433642309	27586	Economy	29900.00
0005432953973	27586	Economy	29900.00
0005433642318	27586	Economy	29900.00
0005433642317	27586	Economy	29900.00
0005432953991	27586	Economy	29900.00
0005433642289	27586	Economy	29900.00
0005433642365	27586	Economy	29900.00
0005433642310	27586	Economy	29900.00
0005433642280	27586	Economy	29900.00
0005433642297	27586	Economy	29900.00
0005433642294	27586	Economy	29900.00
0005433642277	27586	Economy	29900.00
0005432424698	13311	Business	12700.00
0005432424689	13311	Business	12700.00
0005432424709	13311	Business	12700.00
0005432424670	13311	Business	12700.00
0005432424685	13311	Business	12700.00
0005432424668	13311	Business	12700.00
0005432424695	13311	Business	12700.00
0005432424683	13311	Business	12700.00
0005432424703	13311	Economy	4200.00
0005432424684	13311	Economy	4200.00
0005432424699	13311	Economy	4200.00
0005432424677	13311	Economy	4700.00
0005432424692	13311	Economy	4700.00
0005432424712	13311	Economy	4700.00
0005432424679	13311	Economy	4200.00
0005432424676	13311	Economy	4200.00
0005432424714	13311	Economy	4200.00
0005432424694	13311	Economy	4200.00
0005432424678	13311	Economy	4200.00
0005432424706	13311	Economy	4200.00
0005432424680	13311	Economy	4200.00
0005432424690	13311	Economy	4200.00
0005432424707	13311	Economy	4200.00
0005432424669	13311	Economy	4200.00
0005432424675	13311	Economy	4200.00
0005432424704	13311	Economy	4200.00
0005432424691	13311	Economy	4200.00
0005432424701	13311	Economy	4200.00
0005432424682	13311	Economy	4200.00
0005432424700	13311	Economy	4200.00
0005432424708	13311	Economy	4200.00
0005432424713	13311	Economy	4200.00
0005432424674	13311	Economy	4200.00
0005432424687	13311	Economy	4200.00
0005432424710	13311	Economy	4200.00
0005432424693	13311	Economy	4200.00
0005432424681	13311	Economy	4200.00
0005432424673	13311	Economy	4200.00
0005432424705	13311	Economy	4200.00
0005432424702	13311	Economy	4200.00
0005432424696	13311	Economy	4200.00
0005432424686	13311	Economy	4200.00
0005432424671	13311	Economy	4200.00
0005432424711	13311	Economy	4200.00
0005432424672	13311	Economy	4200.00
0005432424688	13311	Economy	4200.00
0005432424697	13311	Economy	4200.00
0005432424239	30697	Business	12700.00
0005432424125	30697	Business	12700.00
0005432424099	30697	Business	12700.00
0005432424300	30697	Business	12700.00
0005432424124	30697	Economy	4200.00
0005432424241	30697	Economy	4200.00
0005432424202	30697	Economy	4200.00
0005432424319	30697	Economy	4200.00
0005432424118	30697	Economy	4200.00
0005432424286	30697	Economy	4700.00
0005432424254	30697	Economy	4700.00
0005432424200	30697	Economy	4200.00
0005432424100	30697	Economy	4200.00
0005432424098	30697	Economy	4200.00
0005432424126	30697	Economy	4200.00
0005432424045	30697	Economy	4200.00
0005432424257	30697	Economy	4200.00
0005432424242	30697	Economy	4200.00
0005432424101	30697	Economy	4200.00
0005432424292	30697	Economy	4200.00
0005432424195	30697	Economy	4200.00
0005432424259	30697	Economy	4200.00
0005432424307	30697	Economy	4200.00
0005432424302	30697	Economy	4200.00
0005432424306	30697	Economy	4200.00
0005432424256	30697	Economy	4200.00
0005432424154	30697	Economy	4200.00
0005432424117	30697	Economy	4200.00
0005432424321	30697	Economy	4200.00
0005432424278	30697	Economy	4200.00
0005432424260	30697	Economy	4200.00
0005432424301	30697	Economy	4200.00
0005432424183	30697	Economy	4200.00
0005432424295	30697	Economy	4200.00
0005432424180	30697	Economy	4200.00
0005432424193	30697	Economy	4200.00
0005432424088	30697	Economy	4200.00
0005432424323	30697	Economy	4200.00
0005432424194	30697	Economy	4200.00
0005432424187	30697	Economy	4200.00
0005432424305	30697	Economy	4200.00
0005432424267	30697	Economy	4200.00
0005432424181	30697	Economy	4200.00
0005432424322	30697	Economy	4200.00
0005432424296	30697	Economy	4200.00
0005432424299	30697	Economy	4200.00
0005432424285	30697	Economy	4200.00
0005432424314	30697	Economy	4200.00
0005432817663	9592	Business	32600.00
0005432822249	9592	Business	32600.00
0005432289005	9592	Business	32600.00
0005432901481	9592	Business	32600.00
0005432817652	9592	Business	32600.00
0005434448336	9592	Business	32600.00
0005432817636	9592	Business	32600.00
0005432822252	9592	Business	32600.00
0005432817668	9592	Business	32600.00
0005432901570	9592	Business	32600.00
0005432901594	9592	Economy	10900.00
0005432817659	9592	Economy	10900.00
0005434157483	9592	Economy	10900.00
0005432817658	9592	Economy	10900.00
0005432817650	9592	Economy	10900.00
0005432817655	9592	Economy	10900.00
0005434157463	9592	Economy	11900.00
0005432822251	9592	Economy	11900.00
0005434157438	9592	Economy	11900.00
0005434186199	9592	Economy	11900.00
0005432817639	9592	Economy	10900.00
0005434157439	9592	Economy	10900.00
0005432817654	9592	Economy	10900.00
0005432289008	9592	Economy	10900.00
0005432289007	9592	Economy	10900.00
0005432817664	9592	Economy	10900.00
0005434157451	9592	Economy	10900.00
0005432901545	9592	Economy	10900.00
0005432822246	9592	Economy	10900.00
0005434157469	9592	Economy	10900.00
0005432822248	9592	Economy	10900.00
0005432901592	9592	Economy	10900.00
0005432817646	9592	Economy	10900.00
0005432901573	9592	Economy	10900.00
0005434448335	9592	Economy	10900.00
0005432817645	9592	Economy	10900.00
0005432817667	9592	Economy	10900.00
0005432901555	9592	Economy	10900.00
0005432817653	9592	Economy	10900.00
0005434157462	9592	Economy	10900.00
0005434448337	9592	Economy	10900.00
0005432817642	9592	Economy	10900.00
0005432817661	9592	Economy	10900.00
0005432817644	9592	Economy	10900.00
0005432901544	9592	Economy	10900.00
0005432817649	9592	Economy	10900.00
0005432817660	9592	Economy	10900.00
0005432822247	9592	Economy	10900.00
0005434157461	9592	Economy	10900.00
0005432817643	9592	Economy	10900.00
0005434157482	9592	Economy	10900.00
0005432817638	9592	Economy	10900.00
0005432817666	9592	Economy	10900.00
0005432901514	9592	Economy	10900.00
0005432817657	9592	Economy	10900.00
0005432817640	9592	Economy	10900.00
0005432817647	9592	Economy	10900.00
0005432817641	9592	Economy	10900.00
0005432901566	9592	Economy	10900.00
0005432817651	9592	Economy	10900.00
0005432817656	9592	Economy	10900.00
0005432901593	9592	Economy	10900.00
0005432822250	9592	Economy	10900.00
0005432289006	9592	Economy	10900.00
0005432817665	9592	Economy	10900.00
0005432822253	9592	Economy	10900.00
0005434157450	9592	Economy	10900.00
0005434157474	9592	Economy	10900.00
0005432817648	9592	Economy	10900.00
0005432901515	9592	Economy	10900.00
0005432817662	9592	Economy	10900.00
0005432901571	9592	Economy	10900.00
0005432817637	9592	Economy	10900.00
0005432817334	28992	Business	32600.00
0005432817222	28992	Business	32600.00
0005432817372	28992	Business	32600.00
0005432901716	28992	Business	32600.00
0005432817499	28992	Business	32600.00
0005432901722	28992	Business	32600.00
0005434157530	28992	Business	32600.00
0005432817365	28992	Economy	10900.00
0005432817378	28992	Economy	10900.00
0005434157531	28992	Economy	10900.00
0005432817480	28992	Economy	10900.00
0005432822190	28992	Economy	10900.00
0005434157526	28992	Economy	10900.00
0005434157525	28992	Economy	10900.00
0005432817379	28992	Economy	10900.00
0005432822196	28992	Economy	10900.00
0005434448296	28992	Economy	10900.00
0005432901710	28992	Economy	11900.00
0005432822186	28992	Economy	11900.00
0005432901715	28992	Economy	11900.00
0005432817302	28992	Economy	10900.00
0005432817451	28992	Economy	10900.00
0005432822171	28992	Economy	10900.00
0005432817428	28992	Economy	10900.00
0005434448312	28992	Economy	10900.00
0005432822187	28992	Economy	10900.00
0005434186214	28992	Economy	10900.00
0005432817407	28992	Economy	10900.00
0005432822188	28992	Economy	10900.00
0005432822191	28992	Economy	10900.00
0005432901723	28992	Economy	10900.00
0005432901709	28992	Economy	10900.00
0005432817303	28992	Economy	10900.00
0005434157529	28992	Economy	10900.00
0005432901708	28992	Economy	10900.00
0005432901717	28992	Economy	10900.00
0005434157528	28992	Economy	10900.00
0005432901711	28992	Economy	10900.00
0005432822189	28992	Economy	10900.00
0005434157523	28992	Economy	10900.00
0005432901718	28992	Economy	10900.00
0005432002088	28992	Economy	10900.00
0005434186215	28992	Economy	10900.00
0005432901707	28992	Economy	10900.00
0005432817336	28992	Economy	10900.00
0005432817409	28992	Economy	10900.00
0005434157527	28992	Economy	10900.00
0005432817368	28992	Economy	10900.00
0005432901713	28992	Economy	10900.00
0005432817387	28992	Economy	10900.00
0005432817239	28992	Economy	10900.00
0005432901724	28992	Economy	10900.00
0005432817476	28992	Economy	10900.00
0005432817457	28992	Economy	10900.00
0005432901721	28992	Economy	10900.00
0005432817371	28992	Economy	10900.00
0005432817386	28992	Economy	10900.00
0005432002089	28992	Economy	10900.00
0005432822168	28992	Economy	10900.00
0005432817426	28992	Economy	10900.00
0005432817337	28992	Economy	10900.00
0005432817254	28992	Economy	10900.00
0005432901720	28992	Economy	10900.00
0005432817223	28992	Economy	10900.00
0005432817288	28992	Economy	10900.00
0005432822199	28992	Economy	10900.00
0005432901714	28992	Economy	10900.00
0005432901719	28992	Economy	10900.00
0005432817400	28992	Economy	10900.00
0005432817335	28992	Economy	10900.00
0005432817327	28992	Economy	10900.00
0005432817477	28992	Economy	10900.00
0005434157524	28992	Economy	10900.00
0005432901712	28992	Economy	10900.00
0005432817498	28992	Economy	10900.00
0005432817270	28992	Economy	10900.00
0005432613887	15055	Economy	11000.00
0005432613885	15055	Economy	11000.00
0005435841098	15055	Economy	11000.00
0005432613886	15055	Economy	11000.00
0005432611736	15055	Economy	11000.00
0005432611735	15055	Economy	11000.00
0005432611737	15055	Economy	11000.00
0005432613889	15055	Economy	11000.00
0005432611734	15055	Economy	11000.00
0005432613888	15055	Economy	11000.00
0005432607537	31589	Economy	11000.00
0005432607565	31589	Economy	11000.00
0005432607536	31589	Economy	11000.00
0005432607555	31589	Economy	11000.00
0005432611713	31589	Economy	11000.00
0005432607547	31589	Economy	11000.00
0005432607564	31589	Economy	11000.00
0005432611706	31589	Economy	11000.00
0005432607538	31589	Economy	11000.00
0005432607554	31589	Economy	11000.00
0005432611683	31589	Economy	11000.00
0005432948124	11867	Business	105900.00
0005432948342	11867	Business	105900.00
0005432948245	11867	Business	105900.00
0005433569385	11867	Business	105900.00
0005433569360	11867	Business	105900.00
0005432948349	11867	Business	105900.00
0005432948356	11867	Business	105900.00
0005432948351	11867	Business	105900.00
0005432948413	11867	Business	105900.00
0005432948221	11867	Business	105900.00
0005432948275	11867	Business	105900.00
0005433569421	11867	Business	105900.00
0005433569398	11867	Business	105900.00
0005433569419	11867	Business	105900.00
0005433569410	11867	Business	105900.00
0005432948212	11867	Business	105900.00
0005433569401	11867	Business	105900.00
0005433569407	11867	Business	105900.00
0005433569366	11867	Economy	35300.00
0005433569381	11867	Economy	35300.00
0005433569413	11867	Economy	35300.00
0005433569371	11867	Economy	35300.00
0005432948233	11867	Economy	35300.00
0005433569427	11867	Economy	35300.00
0005432948360	11867	Economy	35300.00
0005433569391	11867	Economy	35300.00
0005433569370	11867	Economy	35300.00
0005432948282	11867	Economy	35300.00
0005433569422	11867	Economy	35300.00
0005433569416	11867	Economy	38800.00
0005433569384	11867	Economy	38800.00
0005432948355	11867	Economy	38800.00
0005432948371	11867	Economy	35300.00
0005432948363	11867	Economy	38800.00
0005433569376	11867	Economy	35300.00
0005433569373	11867	Economy	35300.00
0005432948436	11867	Economy	35300.00
0005433569393	11867	Economy	35300.00
0005433569377	11867	Economy	35300.00
0005432948382	11867	Economy	35300.00
0005433569382	11867	Economy	35300.00
0005433569426	11867	Economy	35300.00
0005432948343	11867	Economy	35300.00
0005432948357	11867	Economy	35300.00
0005433569406	11867	Economy	35300.00
0005433569378	11867	Economy	35300.00
0005433569369	11867	Economy	35300.00
0005433569405	11867	Economy	35300.00
0005432948344	11867	Economy	35300.00
0005433569402	11867	Economy	35300.00
0005433569363	11867	Economy	35300.00
0005432948334	11867	Economy	35300.00
0005433569372	11867	Economy	35300.00
0005432948241	11867	Economy	35300.00
0005433569390	11867	Economy	35300.00
0005432948385	11867	Economy	35300.00
0005433569400	11867	Economy	35300.00
0005432948350	11867	Economy	35300.00
0005433569364	11867	Economy	35300.00
0005433569386	11867	Economy	35300.00
0005432948123	11867	Economy	35300.00
0005433569387	11867	Economy	35300.00
0005433569380	11867	Economy	35300.00
0005432948299	11867	Economy	35300.00
0005433569411	11867	Economy	35300.00
0005433569425	11867	Economy	35300.00
0005432948316	11867	Economy	35300.00
0005433569414	11867	Economy	35300.00
0005432948213	11867	Economy	35300.00
0005433569392	11867	Economy	35300.00
0005433569389	11867	Economy	35300.00
0005433569415	11867	Economy	35300.00
0005432948240	11867	Economy	35300.00
0005433569417	11867	Economy	35300.00
0005433569397	11867	Economy	35300.00
0005433569395	11867	Economy	35300.00
0005432948330	11867	Economy	35300.00
0005433569368	11867	Economy	35300.00
0005433569408	11867	Economy	35300.00
0005433569418	11867	Economy	35300.00
0005433569420	11867	Economy	35300.00
0005433569403	11867	Economy	35300.00
0005433569423	11867	Economy	35300.00
0005433569412	11867	Economy	35300.00
0005433569367	11867	Economy	35300.00
0005432948348	11867	Economy	35300.00
0005433569379	11867	Economy	35300.00
0005432948157	11867	Economy	35300.00
0005433569362	11867	Economy	35300.00
0005433569383	11867	Economy	35300.00
0005432948384	11867	Economy	35300.00
0005432948353	11867	Economy	35300.00
0005432948249	11867	Economy	35300.00
0005433569404	11867	Economy	35300.00
0005432948443	11867	Economy	35300.00
0005433569365	11867	Economy	35300.00
0005433569374	11867	Economy	35300.00
0005433569409	11867	Economy	35300.00
0005432948326	11867	Economy	35300.00
0005433569388	11867	Economy	35300.00
0005433569396	11867	Economy	35300.00
0005433569361	11867	Economy	35300.00
0005433569375	11867	Economy	35300.00
0005433569394	11867	Economy	35300.00
0005432948234	11867	Economy	35300.00
0005432948301	11867	Economy	35300.00
0005433569399	11867	Economy	35300.00
0005432948125	11867	Economy	35300.00
0005433569424	11867	Economy	35300.00
0005432948274	11867	Economy	35300.00
0005433568908	25307	Business	105900.00
0005432948726	25307	Business	105900.00
0005432948736	25307	Business	105900.00
0005433568852	25307	Business	105900.00
0005432948740	25307	Business	105900.00
0005432948745	25307	Business	105900.00
0005433568813	25307	Business	105900.00
0005432948739	25307	Business	105900.00
0005433568921	25307	Business	105900.00
0005433568767	25307	Business	105900.00
0005433568834	25307	Business	105900.00
0005432948758	25307	Business	105900.00
0005432948746	25307	Business	105900.00
0005433568680	25307	Business	105900.00
0005433568864	25307	Business	105900.00
0005433568751	25307	Business	105900.00
0005433568653	25307	Economy	35300.00
0005433568904	25307	Business	105900.00
0005433568905	25307	Economy	35300.00
0005433568822	25307	Economy	35300.00
0005433568835	25307	Economy	35300.00
0005432948741	25307	Economy	35300.00
0005433568851	25307	Economy	35300.00
0005433568846	25307	Economy	35300.00
0005432948735	25307	Economy	35300.00
0005432948727	25307	Economy	35300.00
0005432948737	25307	Economy	35300.00
0005432948753	25307	Economy	35300.00
0005433568820	25307	Economy	35300.00
0005432948749	25307	Economy	35300.00
0005432948765	25307	Economy	38800.00
0005433568790	25307	Economy	38800.00
0005433568940	25307	Economy	38800.00
0005433568844	25307	Economy	38800.00
0005432948757	25307	Economy	35300.00
0005433568933	25307	Economy	35300.00
0005433568819	25307	Economy	35300.00
0005433568807	25307	Economy	35300.00
0005433568824	25307	Economy	35300.00
0005432948744	25307	Economy	35300.00
0005433568900	25307	Economy	35300.00
0005432948762	25307	Economy	35300.00
0005433568768	25307	Economy	35300.00
0005433568889	25307	Economy	35300.00
0005432948732	25307	Economy	35300.00
0005433568899	25307	Economy	35300.00
0005432948747	25307	Economy	35300.00
0005433568770	25307	Economy	35300.00
0005433568832	25307	Economy	35300.00
0005433568842	25307	Economy	35300.00
0005433568939	25307	Economy	35300.00
0005433568911	25307	Economy	35300.00
0005433568906	25307	Economy	35300.00
0005432948752	25307	Economy	35300.00
0005432948748	25307	Economy	35300.00
0005432948756	25307	Economy	35300.00
0005432948728	25307	Economy	35300.00
0005433568515	25307	Economy	35300.00
0005433568750	25307	Economy	35300.00
0005433568764	25307	Economy	35300.00
0005433568865	25307	Economy	35300.00
0005433568638	25307	Economy	35300.00
0005432948733	25307	Economy	35300.00
0005432948763	25307	Economy	35300.00
0005432948734	25307	Economy	35300.00
0005432948764	25307	Economy	35300.00
0005433568801	25307	Economy	35300.00
0005433568896	25307	Economy	35300.00
0005433568752	25307	Economy	35300.00
0005433568799	25307	Economy	35300.00
0005433568578	25307	Economy	35300.00
0005432948730	25307	Economy	35300.00
0005433568763	25307	Economy	35300.00
0005432948738	25307	Economy	35300.00
0005433568514	25307	Economy	35300.00
0005433568863	25307	Economy	35300.00
0005433568941	25307	Economy	35300.00
0005432948759	25307	Economy	35300.00
0005432948754	25307	Economy	35300.00
0005433568831	25307	Economy	35300.00
0005433568903	25307	Economy	35300.00
0005433568893	25307	Economy	35300.00
0005432948760	25307	Economy	35300.00
0005433568743	25307	Economy	35300.00
0005433568853	25307	Economy	35300.00
0005433568898	25307	Economy	35300.00
0005433568765	25307	Economy	35300.00
0005433568907	25307	Economy	35300.00
0005433568814	25307	Economy	35300.00
0005433568843	25307	Economy	35300.00
0005433568644	25307	Economy	35300.00
0005432948742	25307	Economy	35300.00
0005432948761	25307	Economy	35300.00
0005433568825	25307	Economy	35300.00
0005433568845	25307	Economy	35300.00
0005433568753	25307	Economy	35300.00
0005432948731	25307	Economy	35300.00
0005433568582	25307	Economy	35300.00
0005432948743	25307	Economy	35300.00
0005432948750	25307	Economy	35300.00
0005432948725	25307	Economy	35300.00
0005432948723	25307	Economy	35300.00
0005432948729	25307	Economy	35300.00
0005432948751	25307	Economy	35300.00
0005432948755	25307	Economy	35300.00
0005433568894	25307	Economy	35300.00
0005433568772	25307	Economy	35300.00
0005432948724	25307	Economy	35300.00
0005433568771	25307	Economy	35300.00
0005433568930	25307	Economy	35300.00
0005434654856	5385	Business	67200.00
0005432114221	5385	Business	67200.00
0005434654874	5385	Business	67200.00
0005435340198	5385	Business	67200.00
0005434654853	5385	Business	67200.00
0005434654866	5385	Business	67200.00
0005435340250	5385	Business	67200.00
0005435340207	5385	Business	67200.00
0005435340181	5385	Business	67200.00
0005435340233	5385	Business	67200.00
0005434654868	5385	Economy	22400.00
0005435340189	5385	Economy	22400.00
0005434654859	5385	Economy	22400.00
0005434654860	5385	Economy	22400.00
0005435340264	5385	Economy	22400.00
0005435555371	5385	Economy	22400.00
0005435340219	5385	Economy	22400.00
0005434656569	5385	Economy	24600.00
0005435340214	5385	Economy	24600.00
0005434654877	5385	Economy	24600.00
0005434654876	5385	Economy	24600.00
0005435340195	5385	Economy	24600.00
0005434654861	5385	Economy	22400.00
0005434654862	5385	Economy	22400.00
0005434654867	5385	Economy	22400.00
0005434654865	5385	Economy	22400.00
0005435340252	5385	Economy	22400.00
0005435340143	5385	Economy	22400.00
0005435340199	5385	Economy	22400.00
0005434654863	5385	Economy	22400.00
0005434654851	5385	Economy	22400.00
0005434654849	5385	Economy	22400.00
0005434654869	5385	Economy	22400.00
0005434654872	5385	Economy	22400.00
0005432114222	5385	Economy	22400.00
0005434654864	5385	Economy	22400.00
0005432114223	5385	Economy	22400.00
0005435340220	5385	Economy	22400.00
0005434656570	5385	Economy	22400.00
0005434654855	5385	Economy	22400.00
0005435340258	5385	Economy	22400.00
0005435555365	5385	Economy	22400.00
0005435340256	5385	Economy	22400.00
0005434654870	5385	Economy	22400.00
0005434654852	5385	Economy	22400.00
0005435340262	5385	Economy	22400.00
0005435555373	5385	Economy	22400.00
0005435555370	5385	Economy	22400.00
0005434654875	5385	Economy	22400.00
0005434654850	5385	Economy	22400.00
0005434654848	5385	Economy	22400.00
0005435340133	5385	Economy	22400.00
0005435340227	5385	Economy	22400.00
0005434654873	5385	Economy	22400.00
0005432114224	5385	Economy	22400.00
0005435555366	5385	Economy	22400.00
0005434654857	5385	Economy	22400.00
0005435340216	5385	Economy	22400.00
0005434654858	5385	Economy	22400.00
0005435340251	5385	Economy	22400.00
0005434654854	5385	Economy	22400.00
0005435340266	5385	Economy	22400.00
0005435340257	5385	Economy	22400.00
0005434654871	5385	Economy	22400.00
0005435340134	5385	Economy	22400.00
0005435340353	12526	Business	67200.00
0005434654716	12526	Business	67200.00
0005435340362	12526	Business	67200.00
0005434654581	12526	Business	67200.00
0005434654554	12526	Business	67200.00
0005434656549	12526	Economy	22400.00
0005435340360	12526	Economy	22400.00
0005435340361	12526	Economy	22400.00
0005435340350	12526	Economy	22400.00
0005435555382	12526	Economy	22400.00
0005434654622	12526	Economy	22400.00
0005435555384	12526	Economy	22400.00
0005434654717	12526	Economy	24600.00
0005434654736	12526	Economy	24600.00
0005434654591	12526	Economy	24600.00
0005435340358	12526	Economy	22400.00
0005434654563	12526	Economy	22400.00
0005435340356	12526	Economy	22400.00
0005434654608	12526	Economy	22400.00
0005434654623	12526	Economy	22400.00
0005435340349	12526	Economy	22400.00
0005435555383	12526	Economy	22400.00
0005434654598	12526	Economy	22400.00
0005434654607	12526	Economy	22400.00
0005435340355	12526	Economy	22400.00
0005435340354	12526	Economy	22400.00
0005435340359	12526	Economy	22400.00
0005434654627	12526	Economy	22400.00
0005434654702	12526	Economy	22400.00
0005434654557	12526	Economy	22400.00
0005434654743	12526	Economy	22400.00
0005434654534	12526	Economy	22400.00
0005435340352	12526	Economy	22400.00
0005435340351	12526	Economy	22400.00
0005434656548	12526	Economy	22400.00
0005435340348	12526	Economy	22400.00
0005434654550	12526	Economy	22400.00
0005434656547	12526	Economy	22400.00
0005434654564	12526	Economy	22400.00
0005435340357	12526	Economy	22400.00
0005433719158	7427	Business	32000.00
0005433716284	7427	Business	32000.00
0005433716279	7427	Business	32000.00
0005433716293	7427	Business	32000.00
0005433722256	7427	Business	32000.00
0005433716268	7427	Business	32000.00
0005433719159	7427	Business	32000.00
0005433716248	7427	Business	32000.00
0005432078139	7427	Business	32000.00
0005433716290	7427	Economy	10700.00
0005433716288	7427	Economy	10700.00
0005433716267	7427	Economy	10700.00
0005433716277	7427	Economy	10700.00
0005433690935	7427	Economy	10700.00
0005433716247	7427	Economy	10700.00
0005433716269	7427	Economy	10700.00
0005433716255	7427	Economy	10700.00
0005433716291	7427	Economy	10700.00
0005433716276	7427	Economy	10700.00
0005433716275	7427	Economy	10700.00
0005433688820	7427	Economy	10700.00
0005433722263	7427	Economy	10700.00
0005433722254	7427	Economy	10700.00
0005435266134	7427	Economy	10700.00
0005433716251	7427	Economy	10700.00
0005435266135	7427	Economy	10700.00
0005433716253	7427	Economy	10700.00
0005433688819	7427	Economy	10700.00
0005433722268	7427	Economy	10700.00
0005432078142	7427	Economy	10700.00
0005433716285	7427	Economy	10700.00
0005433716264	7427	Economy	10700.00
0005433656690	7427	Economy	10700.00
0005433722259	7427	Economy	10700.00
0005432078140	7427	Economy	10700.00
0005433716262	7427	Economy	10700.00
0005433716256	7427	Economy	10700.00
0005433656687	7427	Economy	11700.00
0005433716260	7427	Economy	11700.00
0005433716250	7427	Economy	11700.00
0005433722267	7427	Economy	10700.00
0005432078143	7427	Economy	10700.00
0005433719157	7427	Economy	10700.00
0005433722258	7427	Economy	10700.00
0005433716246	7427	Economy	10700.00
0005433719160	7427	Economy	10700.00
0005433716274	7427	Economy	10700.00
0005435266124	7427	Economy	10700.00
0005433716272	7427	Economy	10700.00
0005433722265	7427	Economy	10700.00
0005433716273	7427	Economy	10700.00
0005433716292	7427	Economy	10700.00
0005433656688	7427	Economy	10700.00
0005433716280	7427	Economy	10700.00
0005433716258	7427	Economy	10700.00
0005433716263	7427	Economy	10700.00
0005433716265	7427	Economy	10700.00
0005433722269	7427	Economy	10700.00
0005433716244	7427	Economy	10700.00
0005433716271	7427	Economy	10700.00
0005433716245	7427	Economy	10700.00
0005433716286	7427	Economy	10700.00
0005433689922	7427	Economy	10700.00
0005433716266	7427	Economy	10700.00
0005433722264	7427	Economy	10700.00
0005433722266	7427	Economy	10700.00
0005433689921	7427	Economy	10700.00
0005432078141	7427	Economy	10700.00
0005433716252	7427	Economy	10700.00
0005433722260	7427	Economy	10700.00
0005433722262	7427	Economy	10700.00
0005433716257	7427	Economy	10700.00
0005433716282	7427	Economy	10700.00
0005433716254	7427	Economy	10700.00
0005433716287	7427	Economy	10700.00
0005433722261	7427	Economy	10700.00
0005433690936	7427	Economy	10700.00
0005433656689	7427	Economy	10700.00
0005433716294	7427	Economy	10700.00
0005433716243	7427	Economy	10700.00
0005433716289	7427	Economy	10700.00
0005433716270	7427	Economy	10700.00
0005432078144	7427	Economy	10700.00
0005433722255	7427	Economy	10700.00
0005433716281	7427	Economy	10700.00
0005435266141	7427	Economy	10700.00
0005433716283	7427	Economy	10700.00
0005433716278	7427	Economy	10700.00
0005433716249	7427	Economy	10700.00
0005433716261	7427	Economy	10700.00
0005432078145	7427	Economy	10700.00
0005433722257	7427	Economy	10700.00
0005433716259	7427	Economy	10700.00
0005433715868	29210	Business	32000.00
0005433715851	29210	Business	32000.00
0005433715925	29210	Business	32000.00
0005435266168	29210	Business	32000.00
0005433685509	29210	Business	32000.00
0005433715793	29210	Business	32000.00
0005433715786	29210	Business	32000.00
0005433715835	29210	Business	32000.00
0005433715780	29210	Business	32000.00
0005432428951	29210	Business	32000.00
0005433715790	29210	Economy	10700.00
0005433715982	29210	Economy	10700.00
0005433715875	29210	Economy	10700.00
0005433715987	29210	Economy	10700.00
0005435266171	29210	Economy	10700.00
0005433715709	29210	Economy	10700.00
0005433715794	29210	Economy	10700.00
0005433722197	29210	Economy	10700.00
0005433685511	29210	Economy	10700.00
0005433716024	29210	Economy	10700.00
0005435266170	29210	Economy	10700.00
0005433715797	29210	Economy	10700.00
0005433715841	29210	Economy	10700.00
0005433715879	29210	Economy	10700.00
0005433715710	29210	Economy	10700.00
0005433656660	29210	Economy	10700.00
0005433685510	29210	Economy	10700.00
0005433656669	29210	Economy	10700.00
0005433719133	29210	Economy	10700.00
0005433715781	29210	Economy	10700.00
0005433656662	29210	Economy	10700.00
0005433715798	29210	Economy	10700.00
0005433715649	29210	Economy	10700.00
0005433715659	29210	Economy	11700.00
0005433715959	29210	Economy	11700.00
0005433656667	29210	Economy	10700.00
0005433715791	29210	Economy	10700.00
0005433722168	29210	Economy	10700.00
0005433715660	29210	Economy	10700.00
0005433715836	29210	Economy	10700.00
0005433722188	29210	Economy	10700.00
0005433715700	29210	Economy	10700.00
0005433719132	29210	Economy	10700.00
0005435266169	29210	Economy	10700.00
0005433715983	29210	Economy	10700.00
0005433715862	29210	Economy	10700.00
0005433656650	29210	Economy	10700.00
0005433715921	29210	Economy	10700.00
0005433656661	29210	Economy	10700.00
0005433715772	29210	Economy	10700.00
0005433719131	29210	Economy	10700.00
0005433722189	29210	Economy	10700.00
0005432428949	29210	Economy	10700.00
0005433722190	29210	Economy	10700.00
0005435266172	29210	Economy	10700.00
0005433715648	29210	Economy	10700.00
0005432428950	29210	Economy	10700.00
0005433715775	29210	Economy	10700.00
0005433715727	29210	Economy	10700.00
0005433722177	29210	Economy	10700.00
0005433715863	29210	Economy	10700.00
0005432428948	29210	Economy	10700.00
0005433715880	29210	Economy	10700.00
0005433715869	29210	Economy	10700.00
0005433715984	29210	Economy	10700.00
0005433715647	29210	Economy	10700.00
0005433715792	29210	Economy	10700.00
0005433715872	29210	Economy	10700.00
0005433715773	29210	Economy	10700.00
0005433715782	29210	Economy	10700.00
0005433722198	29210	Economy	10700.00
0005432006779	29210	Economy	10700.00
0005434095365	8675	Business	36500.00
0005434143736	8675	Business	36500.00
0005434143731	8675	Business	36500.00
0005434182172	8675	Business	36500.00
0005434182139	8675	Business	36500.00
0005434095358	8675	Business	36500.00
0005434182119	8675	Business	36500.00
0005434182136	8675	Economy	12200.00
0005434143739	8675	Economy	12200.00
0005434095361	8675	Economy	12200.00
0005434184658	8675	Economy	12200.00
0005434182170	8675	Economy	12200.00
0005434143737	8675	Economy	12200.00
0005434095363	8675	Economy	12200.00
0005434184657	8675	Economy	12200.00
0005434095364	8675	Economy	12200.00
0005434095370	8675	Economy	12200.00
0005434143738	8675	Economy	12200.00
0005434182180	8675	Economy	12200.00
0005434095360	8675	Economy	12200.00
0005434182120	8675	Economy	12200.00
0005434182184	8675	Economy	12200.00
0005434143733	8675	Economy	12200.00
0005434184667	8675	Economy	12200.00
0005434182146	8675	Economy	12200.00
0005434182179	8675	Economy	12200.00
0005434095366	8675	Economy	12200.00
0005434095369	8675	Economy	12200.00
0005434095367	8675	Economy	12200.00
0005434143732	8675	Economy	12200.00
0005434182101	8675	Economy	12200.00
0005434095357	8675	Economy	12200.00
0005434143735	8675	Economy	12200.00
0005434143734	8675	Economy	12200.00
0005434182133	8675	Economy	12200.00
0005434095359	8675	Economy	12200.00
0005434184652	8675	Economy	12200.00
0005434095368	8675	Economy	12200.00
0005434095362	8675	Economy	12200.00
0005434182100	8675	Economy	12200.00
0005434143740	8675	Economy	12200.00
0005434182178	8675	Economy	12200.00
0005434095226	11624	Business	36500.00
0005434095210	11624	Business	36500.00
0005434095227	11624	Business	36500.00
0005434183590	11624	Business	36500.00
0005434182265	11624	Business	36500.00
0005434184676	11624	Economy	12200.00
0005434095228	11624	Economy	12200.00
0005434182264	11624	Economy	13400.00
0005434095297	11624	Economy	12200.00
0005434182256	11624	Economy	12200.00
0005434095233	11624	Economy	12200.00
0005434182263	11624	Economy	12200.00
0005434182254	11624	Economy	12200.00
0005434095256	11624	Economy	12200.00
0005434182257	11624	Economy	12200.00
0005434095211	11624	Economy	12200.00
0005434182255	11624	Economy	12200.00
0005434182259	11624	Economy	12200.00
0005434095273	11624	Economy	12200.00
0005434095212	11624	Economy	12200.00
0005434326266	11624	Economy	12200.00
0005434182258	11624	Economy	12200.00
0005434095213	11624	Economy	12200.00
0005434095248	11624	Economy	12200.00
0005434184675	11624	Economy	12200.00
0005434095243	11624	Economy	12200.00
0005434326267	11624	Economy	12200.00
0005434182262	11624	Economy	12200.00
0005434326271	11624	Economy	12200.00
0005434182253	11624	Economy	12200.00
0005434095242	11624	Economy	12200.00
0005434095247	11624	Economy	12200.00
0005434095148	11624	Economy	12200.00
0005434182260	11624	Economy	12200.00
0005434182261	11624	Economy	12200.00
0005434326270	11624	Economy	12200.00
0005433397854	1445	Business	33000.00
0005432906523	1445	Business	33000.00
0005433397938	1445	Business	33000.00
0005433397968	1445	Business	33000.00
0005433398033	1445	Business	33000.00
0005433398035	1445	Business	33000.00
0005435732393	1445	Business	33000.00
0005433397899	1445	Business	33000.00
0005433397813	1445	Business	33000.00
0005433397974	1445	Business	33000.00
0005433456996	1445	Business	33000.00
0005433398115	1445	Economy	11000.00
0005433397811	1445	Economy	11000.00
0005433398116	1445	Economy	11000.00
0005433398023	1445	Economy	11000.00
0005433397851	1445	Economy	11000.00
0005433397973	1445	Economy	11000.00
0005433398020	1445	Economy	11000.00
0005433456995	1445	Economy	12100.00
0005433397996	1445	Economy	12100.00
0005433397785	1445	Economy	12100.00
0005432297294	1445	Economy	12100.00
0005433397812	1445	Economy	11000.00
0005435732391	1445	Economy	11000.00
0005432297292	1445	Economy	11000.00
0005433397979	1445	Economy	11000.00
0005433397936	1445	Economy	11000.00
0005433398089	1445	Economy	11000.00
0005433397842	1445	Economy	11000.00
0005433397962	1445	Economy	11000.00
0005433397958	1445	Economy	11000.00
0005433398071	1445	Economy	11000.00
0005433397947	1445	Economy	11000.00
0005433397721	1445	Economy	11000.00
0005433397969	1445	Economy	11000.00
0005432906535	1445	Economy	11000.00
0005433397900	1445	Economy	11000.00
0005433397844	1445	Economy	11000.00
0005433397940	1445	Economy	11000.00
0005432906538	1445	Economy	11000.00
0005433398254	1445	Economy	11000.00
0005433397951	1445	Economy	11000.00
0005432906531	1445	Economy	11000.00
0005433397841	1445	Economy	11000.00
0005433397688	1445	Economy	11000.00
0005432297293	1445	Economy	11000.00
0005433398014	1445	Economy	11000.00
0005433398012	1445	Economy	11000.00
0005433397901	1445	Economy	11000.00
0005433397939	1445	Economy	11000.00
0005433397781	1445	Economy	11000.00
0005433398093	1445	Economy	11000.00
0005433398017	1445	Economy	11000.00
0005433397726	1445	Economy	11000.00
0005433397867	1445	Economy	11000.00
0005433397874	1445	Economy	11000.00
0005433397749	1445	Economy	11000.00
0005433397980	1445	Economy	11000.00
0005435732392	1445	Economy	11000.00
0005433397948	1445	Economy	11000.00
0005433398255	1445	Economy	11000.00
0005435732394	1445	Economy	11000.00
0005433397873	1445	Economy	11000.00
0005433398016	1445	Economy	11000.00
0005433456994	1445	Economy	11000.00
0005435732390	1445	Economy	11000.00
0005433398094	1445	Economy	11000.00
0005432906522	1445	Economy	11000.00
0005432906540	1445	Economy	11000.00
0005432906539	1445	Economy	11000.00
0005433397819	1445	Economy	11000.00
0005433397959	1445	Economy	11000.00
0005433398371	19271	Business	33000.00
0005433398325	19271	Business	33000.00
0005433398330	19271	Business	33000.00
0005432906550	19271	Business	33000.00
0005433398360	19271	Business	33000.00
0005433398347	19271	Business	33000.00
0005433398353	19271	Business	33000.00
0005433398324	19271	Economy	11000.00
0005433398372	19271	Economy	11000.00
0005433398344	19271	Economy	11000.00
0005433398341	19271	Economy	11000.00
0005433398339	19271	Economy	11000.00
0005433398363	19271	Economy	12100.00
0005433398334	19271	Economy	12100.00
0005433398327	19271	Economy	11000.00
0005433398357	19271	Economy	11000.00
0005433398328	19271	Economy	11000.00
0005433398335	19271	Economy	11000.00
0005433398361	19271	Economy	11000.00
0005433398346	19271	Economy	11000.00
0005433398342	19271	Economy	11000.00
0005433398326	19271	Economy	11000.00
0005435732308	19271	Economy	11000.00
0005433398338	19271	Economy	11000.00
0005433398366	19271	Economy	11000.00
0005433398340	19271	Economy	11000.00
0005435732309	19271	Economy	11000.00
0005433398322	19271	Economy	11000.00
0005435732316	19271	Economy	11000.00
0005433398348	19271	Economy	11000.00
0005433398370	19271	Economy	11000.00
0005433398367	19271	Economy	11000.00
0005435732310	19271	Economy	11000.00
0005433398358	19271	Economy	11000.00
0005433398336	19271	Economy	11000.00
0005433398345	19271	Economy	11000.00
0005435732297	19271	Economy	11000.00
0005433398343	19271	Economy	11000.00
0005433398362	19271	Economy	11000.00
0005433398351	19271	Economy	11000.00
0005435732312	19271	Economy	11000.00
0005435732307	19271	Economy	11000.00
0005433398368	19271	Economy	11000.00
0005435732296	19271	Economy	11000.00
0005433456970	19271	Economy	11000.00
0005433398352	19271	Economy	11000.00
0005433398349	19271	Economy	11000.00
0005433398355	19271	Economy	11000.00
0005433398332	19271	Economy	11000.00
0005435732295	19271	Economy	11000.00
0005433398323	19271	Economy	11000.00
0005433398364	19271	Economy	11000.00
0005433398333	19271	Economy	11000.00
0005433456958	19271	Economy	11000.00
0005433398350	19271	Economy	11000.00
0005433398331	19271	Economy	11000.00
0005433398365	19271	Economy	11000.00
0005432906549	19271	Economy	11000.00
0005433398356	19271	Economy	11000.00
0005433398329	19271	Economy	11000.00
0005433398359	19271	Economy	11000.00
0005433398354	19271	Economy	11000.00
0005433398337	19271	Economy	11000.00
0005433398369	19271	Economy	11000.00
0005432906551	19271	Economy	11000.00
0005434443682	17340	Economy	15600.00
0005434443715	17340	Economy	15600.00
0005434443664	17340	Economy	15600.00
0005434443609	17340	Economy	14100.00
0005434443685	17340	Economy	14100.00
0005434443640	17340	Economy	14100.00
0005434443686	17340	Economy	14100.00
0005434443652	17340	Economy	14100.00
0005434443662	17340	Economy	14100.00
0005434443619	17340	Economy	14100.00
0005434443642	17340	Economy	14100.00
0005434443610	17340	Economy	14100.00
0005434443643	17340	Economy	14100.00
0005434443620	17340	Economy	14100.00
0005434443613	17340	Economy	14100.00
0005434443621	17340	Economy	14100.00
0005434443736	17340	Economy	14100.00
0005434443691	17340	Economy	14100.00
0005434443653	17340	Economy	14100.00
0005434443656	17340	Economy	14100.00
0005434443646	17340	Economy	14100.00
0005434443612	17340	Economy	14100.00
0005434443661	17340	Economy	14100.00
0005434443611	17340	Economy	14100.00
0005434443618	17340	Economy	14100.00
0005434443788	20577	Economy	15600.00
0005434443800	20577	Economy	15600.00
0005434443796	20577	Economy	14100.00
0005434443787	20577	Economy	14100.00
0005434443789	20577	Economy	14100.00
0005434443803	20577	Economy	14100.00
0005434443798	20577	Economy	14100.00
0005434443801	20577	Economy	14100.00
0005434443799	20577	Economy	14100.00
0005434443795	20577	Economy	14100.00
0005434443804	20577	Economy	14100.00
0005434443792	20577	Economy	14100.00
0005434443797	20577	Economy	14100.00
0005434443794	20577	Economy	14100.00
0005434443802	20577	Economy	14100.00
0005434443791	20577	Economy	14100.00
0005434443790	20577	Economy	14100.00
0005434443793	20577	Economy	14100.00
0005435377581	7245	Economy	5800.00
0005434954631	7245	Economy	5800.00
0005434954633	7245	Economy	5800.00
0005435377579	7245	Economy	5800.00
0005434954632	7245	Economy	5800.00
0005434954596	28317	Economy	5800.00
0005434954599	28317	Economy	5800.00
0005435377594	28317	Economy	5800.00
0005434954586	28317	Economy	5800.00
0005435377593	28317	Economy	5800.00
0005434954587	28317	Economy	5800.00
0005434954597	28317	Economy	5800.00
0005434954595	28317	Economy	5800.00
0005434954608	28317	Economy	5800.00
0005434954590	28317	Economy	5800.00
0005435377595	28317	Economy	5800.00
0005434351765	4487	Economy	15400.00
0005434351766	4487	Economy	15400.00
0005434351776	4487	Economy	14000.00
0005435893640	4487	Economy	14000.00
0005434351772	4487	Economy	14000.00
0005435893621	4487	Economy	14000.00
0005434351768	4487	Economy	14000.00
0005434351767	4487	Economy	14000.00
0005435893632	4487	Economy	14000.00
0005434351770	4487	Economy	14000.00
0005434351774	4487	Economy	14000.00
0005434351775	4487	Economy	14000.00
0005434351769	4487	Economy	14000.00
0005434183573	4487	Economy	14000.00
0005434351777	4487	Economy	14000.00
0005434183580	4487	Economy	14000.00
0005434351771	4487	Economy	14000.00
0005435893622	4487	Economy	14000.00
0005434351773	4487	Economy	14000.00
0005434351676	29646	Economy	15400.00
0005434351622	29646	Economy	14000.00
0005435893676	29646	Economy	14000.00
0005434351674	29646	Economy	14000.00
0005434351631	29646	Economy	14000.00
0005434351642	29646	Economy	14000.00
0005434351664	29646	Economy	14000.00
0005435893675	29646	Economy	14000.00
0005434351606	29646	Economy	14000.00
0005435893673	29646	Economy	14000.00
0005434351646	29646	Economy	14000.00
0005434351662	29646	Economy	14000.00
0005434351719	29646	Economy	14000.00
0005434351685	29646	Economy	14000.00
0005435893677	29646	Economy	14000.00
0005434351699	29646	Economy	14000.00
0005434351669	29646	Economy	14000.00
0005435893671	29646	Economy	14000.00
0005434351687	29646	Economy	14000.00
0005434351660	29646	Economy	14000.00
0005435893674	29646	Economy	14000.00
0005434351675	29646	Economy	14000.00
0005434351658	29646	Economy	14000.00
0005434351630	29646	Economy	14000.00
0005434351661	29646	Economy	14000.00
0005434351641	29646	Economy	14000.00
0005435893672	29646	Economy	14000.00
0005433342864	1062	Business	30600.00
0005433342606	1062	Business	30600.00
0005433342818	1062	Business	30600.00
0005435545787	1062	Business	30600.00
0005433342786	1062	Business	30600.00
0005433343093	1062	Business	30600.00
0005433343138	1062	Business	30600.00
0005433342982	1062	Business	30600.00
0005435092133	1062	Business	30600.00
0005433342498	1062	Business	30600.00
0005433342815	1062	Business	30600.00
0005433462760	1062	Business	30600.00
0005433342950	1062	Business	30600.00
0005435545786	1062	Business	30600.00
0005433342861	1062	Business	30600.00
0005435545789	1062	Business	30600.00
0005433342573	1062	Business	30600.00
0005433342427	1062	Business	30600.00
0005433159302	1062	Economy	11200.00
0005433342592	1062	Economy	11200.00
0005433342922	1062	Economy	11200.00
0005433342719	1062	Economy	11200.00
0005433342793	1062	Economy	10200.00
0005433159314	1062	Economy	10200.00
0005433342789	1062	Economy	10200.00
0005433342890	1062	Economy	10200.00
0005433342817	1062	Economy	10200.00
0005433342954	1062	Economy	10200.00
0005433342465	1062	Economy	10200.00
0005433343059	1062	Economy	10200.00
0005433342408	1062	Economy	10200.00
0005433342875	1062	Economy	10200.00
0005433342537	1062	Economy	10200.00
0005435092136	1062	Economy	10200.00
0005433342428	1062	Economy	10200.00
0005433342307	1062	Economy	10200.00
0005433342556	1062	Economy	10200.00
0005433269706	1062	Economy	10200.00
0005435092129	1062	Economy	10200.00
0005435092138	1062	Economy	10200.00
0005433342863	1062	Economy	10200.00
0005433342819	1062	Economy	10200.00
0005433343157	1062	Economy	10200.00
0005435092139	1062	Economy	10200.00
0005433342505	1062	Economy	10200.00
0005433342571	1062	Economy	10200.00
0005433342909	1062	Economy	10200.00
0005433342842	1062	Economy	10200.00
0005433342746	1062	Economy	10200.00
0005433342750	1062	Economy	10200.00
0005433342649	1062	Economy	10200.00
0005433342607	1062	Economy	10200.00
0005433342417	1062	Economy	10200.00
0005433342608	1062	Economy	10200.00
0005433342860	1062	Economy	10200.00
0005433343015	1062	Economy	10200.00
0005435092135	1062	Economy	10200.00
0005433343045	1062	Economy	10200.00
0005433342938	1062	Economy	10200.00
0005433342598	1062	Economy	10200.00
0005433342368	1062	Economy	10200.00
0005433343025	1062	Economy	10200.00
0005433343181	1062	Economy	10200.00
0005433159316	1062	Economy	10200.00
0005433342912	1062	Economy	10200.00
0005433159303	1062	Economy	10200.00
0005433343162	1062	Economy	10200.00
0005433343102	1062	Economy	10200.00
0005433342555	1062	Economy	10200.00
0005433342813	1062	Economy	10200.00
0005433343103	1062	Economy	10200.00
0005433342788	1062	Economy	10200.00
0005433343021	1062	Economy	10200.00
0005433342962	1062	Economy	10200.00
0005433342536	1062	Economy	10200.00
0005433342862	1062	Economy	10200.00
0005433343004	1062	Economy	10200.00
0005433159315	1062	Economy	10200.00
0005433158129	1062	Economy	10200.00
0005433343017	1062	Economy	10200.00
0005433342956	1062	Economy	10200.00
0005433342829	1062	Economy	10200.00
0005433158130	1062	Economy	10200.00
0005433342816	1062	Economy	10200.00
0005434445258	1062	Economy	10200.00
0005433342516	1062	Economy	10200.00
0005433158124	1062	Economy	10200.00
0005435092137	1062	Economy	10200.00
0005435092128	1062	Economy	10200.00
0005432293222	1062	Economy	11200.00
0005433343044	1062	Economy	10200.00
0005435545788	1062	Economy	11200.00
0005435092134	1062	Economy	11200.00
0005433342658	1062	Economy	10200.00
0005433342908	1062	Economy	10200.00
0005433343022	1062	Economy	10200.00
0005435545785	1062	Economy	10200.00
0005433342935	1062	Economy	10200.00
0005435092130	1062	Economy	10200.00
0005433342585	1062	Economy	10200.00
0005433342367	1062	Economy	10200.00
0005433158125	1062	Economy	10200.00
0005433342844	1062	Economy	10200.00
0005433342784	1062	Economy	10200.00
0005433342646	1062	Economy	10200.00
0005433269700	1062	Economy	10200.00
0005433269687	1062	Economy	10200.00
0005433342689	1062	Economy	10200.00
0005433462759	1062	Economy	10200.00
0005432293224	1062	Economy	10200.00
0005433463914	1062	Economy	10200.00
0005435092132	1062	Economy	10200.00
0005433342569	1062	Economy	10200.00
0005433269688	1062	Economy	10200.00
0005435545790	1062	Economy	10200.00
0005433342974	1062	Economy	10200.00
0005433269721	1062	Economy	10200.00
0005433342941	1062	Economy	10200.00
0005434445259	1062	Economy	10200.00
0005433342623	1062	Economy	10200.00
0005433343295	1062	Economy	10200.00
0005433342936	1062	Economy	10200.00
0005433342572	1062	Economy	10200.00
0005433342670	1062	Economy	10200.00
0005433342843	1062	Economy	10200.00
0005433342854	1062	Economy	10200.00
0005433342661	1062	Economy	10200.00
0005433342409	1062	Economy	10200.00
0005435092131	1062	Economy	10200.00
0005433342957	1062	Economy	10200.00
0005433342913	1062	Economy	10200.00
0005433343066	1062	Economy	10200.00
0005435545791	1062	Economy	10200.00
0005433342883	1062	Economy	10200.00
0005433342225	1062	Economy	10200.00
0005433342605	1062	Economy	10200.00
0005433342436	1062	Economy	10200.00
0005433343035	1062	Economy	10200.00
0005433342574	1062	Economy	10200.00
0005433342973	1062	Economy	10200.00
0005433342688	1062	Economy	10200.00
0005433342437	1062	Economy	10200.00
0005433343154	1062	Economy	10200.00
0005433342687	1062	Economy	10200.00
0005433342454	1062	Economy	10200.00
0005433463913	1062	Economy	10200.00
0005433342975	1062	Economy	10200.00
0005433342655	1062	Economy	10200.00
0005433269720	1062	Economy	10200.00
0005433343274	1062	Economy	10200.00
0005432293223	1062	Economy	10200.00
0005435092009	17075	Business	30600.00
0005433343716	17075	Business	30600.00
0005435508339	17075	Business	30600.00
0005434445241	17075	Business	30600.00
0005433269749	17075	Business	30600.00
0005433343713	17075	Business	30600.00
0005433343623	17075	Business	30600.00
0005433343650	17075	Business	30600.00
0005433343660	17075	Business	30600.00
0005433343663	17075	Business	30600.00
0005435508315	17075	Business	30600.00
0005433343690	17075	Business	30600.00
0005433343697	17075	Business	30600.00
0005433343649	17075	Business	30600.00
0005433343670	17075	Business	30600.00
0005433343645	17075	Business	30600.00
0005435092012	17075	Business	30600.00
0005433343638	17075	Business	30600.00
0005435092070	17075	Business	30600.00
0005433343700	17075	Economy	11200.00
0005433159324	17075	Economy	11200.00
0005433343702	17075	Economy	11200.00
0005433343707	17075	Economy	10200.00
0005433343676	17075	Economy	10200.00
0005433343679	17075	Economy	10200.00
0005433343684	17075	Economy	10200.00
0005433343681	17075	Economy	10200.00
0005433343641	17075	Economy	10200.00
0005433343680	17075	Economy	10200.00
0005433343651	17075	Economy	10200.00
0005433343629	17075	Economy	10200.00
0005433343654	17075	Economy	10200.00
0005433343696	17075	Economy	10200.00
0005433343710	17075	Economy	10200.00
0005433269750	17075	Economy	10200.00
0005435508324	17075	Economy	10200.00
0005433343644	17075	Economy	10200.00
0005433343687	17075	Economy	10200.00
0005433343643	17075	Economy	10200.00
0005433343658	17075	Economy	10200.00
0005433343632	17075	Economy	10200.00
0005433343698	17075	Economy	10200.00
0005433343648	17075	Economy	10200.00
0005433343665	17075	Economy	10200.00
0005433343671	17075	Economy	10200.00
0005433343693	17075	Economy	10200.00
0005435092033	17075	Economy	10200.00
0005433343708	17075	Economy	10200.00
0005435508337	17075	Economy	10200.00
0005433343625	17075	Economy	10200.00
0005435508344	17075	Economy	10200.00
0005433343621	17075	Economy	10200.00
0005433159326	17075	Economy	10200.00
0005435508348	17075	Economy	10200.00
0005433343709	17075	Economy	10200.00
0005435092051	17075	Economy	10200.00
0005433343657	17075	Economy	10200.00
0005433343653	17075	Economy	10200.00
0005435508347	17075	Economy	10200.00
0005433343705	17075	Economy	10200.00
0005433343677	17075	Economy	10200.00
0005435508317	17075	Economy	10200.00
0005433343628	17075	Economy	10200.00
0005433343627	17075	Economy	10200.00
0005434445242	17075	Economy	10200.00
0005435508345	17075	Economy	10200.00
0005433343711	17075	Economy	10200.00
0005435092034	17075	Economy	10200.00
0005433343618	17075	Economy	10200.00
0005433343634	17075	Economy	10200.00
0005433343636	17075	Economy	10200.00
0005433343712	17075	Economy	10200.00
0005433343655	17075	Economy	10200.00
0005433343703	17075	Economy	10200.00
0005433343617	17075	Economy	10200.00
0005433343667	17075	Economy	10200.00
0005433343695	17075	Economy	10200.00
0005435092043	17075	Economy	10200.00
0005433343631	17075	Economy	10200.00
0005433343624	17075	Economy	10200.00
0005433343692	17075	Economy	10200.00
0005434445229	17075	Economy	10200.00
0005433269753	17075	Economy	11200.00
0005433343699	17075	Economy	11200.00
0005435508350	17075	Economy	10200.00
0005433343706	17075	Economy	10200.00
0005433343664	17075	Economy	11200.00
0005433269751	17075	Economy	10200.00
0005433343683	17075	Economy	10200.00
0005433343694	17075	Economy	10200.00
0005433343656	17075	Economy	10200.00
0005433343639	17075	Economy	10200.00
0005435092050	17075	Economy	10200.00
0005433343672	17075	Economy	10200.00
0005433343673	17075	Economy	10200.00
0005433343637	17075	Economy	10200.00
0005433343669	17075	Economy	10200.00
0005435508316	17075	Economy	10200.00
0005433343678	17075	Economy	10200.00
0005433343668	17075	Economy	10200.00
0005433343619	17075	Economy	10200.00
0005435092003	17075	Economy	10200.00
0005433343642	17075	Economy	10200.00
0005433343647	17075	Economy	10200.00
0005433343661	17075	Economy	10200.00
0005433269752	17075	Economy	10200.00
0005433269748	17075	Economy	10200.00
0005433343662	17075	Economy	10200.00
0005433343622	17075	Economy	10200.00
0005433343675	17075	Economy	10200.00
0005435092094	17075	Economy	10200.00
0005433343659	17075	Economy	10200.00
0005433343646	17075	Economy	10200.00
0005433343691	17075	Economy	10200.00
0005433343704	17075	Economy	10200.00
0005435092066	17075	Economy	10200.00
0005433343688	17075	Economy	10200.00
0005433343674	17075	Economy	10200.00
0005433343630	17075	Economy	10200.00
0005433343652	17075	Economy	10200.00
0005435508340	17075	Economy	10200.00
0005435092081	17075	Economy	10200.00
0005433343682	17075	Economy	10200.00
0005433343635	17075	Economy	10200.00
0005433343717	17075	Economy	10200.00
0005433343620	17075	Economy	10200.00
0005433343633	17075	Economy	10200.00
0005433343626	17075	Economy	10200.00
0005433343701	17075	Economy	10200.00
0005433343715	17075	Economy	10200.00
0005433343685	17075	Economy	10200.00
0005433343686	17075	Economy	10200.00
0005433343714	17075	Economy	10200.00
0005433343689	17075	Economy	10200.00
0005433343640	17075	Economy	10200.00
0005433343666	17075	Economy	10200.00
0005433159325	17075	Economy	10200.00
0005433159327	17075	Economy	10200.00
0005432390204	1350	Business	101000.00
0005432390215	1350	Business	101000.00
0005432851908	1350	Business	101000.00
0005432851922	1350	Business	101000.00
0005432392008	1350	Business	101000.00
0005432390192	1350	Business	101000.00
0005432392016	1350	Business	101000.00
0005432390213	1350	Business	101000.00
0005432390199	1350	Business	101000.00
0005432390196	1350	Business	101000.00
0005432390198	1350	Business	101000.00
0005432851883	1350	Business	101000.00
0005432390189	1350	Business	101000.00
0005432390193	1350	Economy	33700.00
0005432390208	1350	Economy	33700.00
0005432390190	1350	Economy	33700.00
0005432390188	1350	Economy	33700.00
0005432390212	1350	Economy	33700.00
0005432392017	1350	Economy	33700.00
0005432851899	1350	Economy	33700.00
0005432390191	1350	Economy	37000.00
0005432390194	1350	Economy	37000.00
0005432390187	1350	Economy	33700.00
0005432390210	1350	Economy	33700.00
0005432390211	1350	Economy	33700.00
0005432390200	1350	Economy	33700.00
0005432851906	1350	Economy	33700.00
0005432851884	1350	Economy	33700.00
0005432851907	1350	Economy	33700.00
0005432392013	1350	Economy	33700.00
0005432392011	1350	Economy	33700.00
0005432390184	1350	Economy	33700.00
0005432851885	1350	Economy	33700.00
0005432851897	1350	Economy	33700.00
0005432392012	1350	Economy	33700.00
0005432392007	1350	Economy	33700.00
0005432390207	1350	Economy	33700.00
0005432851923	1350	Economy	33700.00
0005432390203	1350	Economy	33700.00
0005432392015	1350	Economy	33700.00
0005432392014	1350	Economy	33700.00
0005432851890	1350	Economy	33700.00
0005432851924	1350	Economy	33700.00
0005432390209	1350	Economy	33700.00
0005432390183	1350	Economy	33700.00
0005432390195	1350	Economy	33700.00
0005432390185	1350	Economy	33700.00
0005432392009	1350	Economy	33700.00
0005432390205	1350	Economy	33700.00
0005432390216	1350	Economy	33700.00
0005432851946	1350	Economy	33700.00
0005432390197	1350	Economy	33700.00
0005432390186	1350	Economy	33700.00
0005432390217	1350	Economy	33700.00
0005432392010	1350	Economy	33700.00
0005432851909	1350	Economy	33700.00
0005432390206	1350	Economy	33700.00
0005432851896	1350	Economy	33700.00
0005432390214	1350	Economy	33700.00
0005432390202	1350	Economy	33700.00
0005432851905	1350	Economy	33700.00
0005432390201	1350	Economy	33700.00
0005434067318	12811	Business	40300.00
0005434067385	12811	Business	40300.00
0005433989756	12811	Business	40300.00
0005434067448	12811	Business	40300.00
0005434067445	12811	Business	40300.00
0005434067392	12811	Business	40300.00
0005432159884	12811	Business	40300.00
0005434067278	12811	Business	40300.00
0005434067214	12811	Business	40300.00
0005434067228	12811	Business	40300.00
0005432433713	12811	Business	40300.00
0005434067408	12811	Economy	13400.00
0005432433714	12811	Economy	13400.00
0005434067240	12811	Economy	13400.00
0005434067424	12811	Economy	13400.00
0005434067447	12811	Economy	13400.00
0005434067309	12811	Economy	13400.00
0005433989749	12811	Economy	13400.00
0005434081754	12811	Economy	13400.00
0005434067493	12811	Economy	13400.00
0005434026700	12811	Economy	13400.00
0005433989757	12811	Economy	13400.00
0005432433711	12811	Economy	13400.00
0005434081854	12811	Economy	13400.00
0005434067277	12811	Economy	13400.00
0005434067390	12811	Economy	13400.00
0005434067229	12811	Economy	13400.00
0005433812914	12811	Economy	13400.00
0005434081894	12811	Economy	13400.00
0005434081893	12811	Economy	13400.00
0005434081753	12811	Economy	13400.00
0005434081835	12811	Economy	13400.00
0005432433710	12811	Economy	13400.00
0005434067259	12811	Economy	13400.00
0005434067255	12811	Economy	13400.00
0005434026690	12811	Economy	13400.00
0005434067317	12811	Economy	13400.00
0005434067571	12811	Economy	13400.00
0005434067423	12811	Economy	13400.00
0005434067232	12811	Economy	13400.00
0005434067416	12811	Economy	13400.00
0005434081904	12811	Economy	13400.00
0005434081731	12811	Economy	13400.00
0005434067444	12811	Economy	14800.00
0005434067395	12811	Economy	14800.00
0005434067038	12811	Economy	14800.00
0005433989754	12811	Economy	14800.00
0005434067247	12811	Economy	14800.00
0005434067596	12811	Economy	13400.00
0005434067176	12811	Economy	13400.00
0005434067334	12811	Economy	13400.00
0005434067297	12811	Economy	13400.00
0005434067365	12811	Economy	13400.00
0005434067094	12811	Economy	13400.00
0005434067007	12811	Economy	13400.00
0005434081914	12811	Economy	13400.00
0005434067037	12811	Economy	13400.00
0005432433712	12811	Economy	13400.00
0005434067155	12811	Economy	13400.00
0005434081913	12811	Economy	13400.00
0005434081768	12811	Economy	13400.00
0005434066762	12811	Economy	13400.00
0005434067195	12811	Economy	13400.00
0005434081806	12811	Economy	13400.00
0005432159887	12811	Economy	13400.00
0005432161165	12811	Economy	13400.00
0005434081732	12811	Economy	13400.00
0005432159885	12811	Economy	13400.00
0005434026695	12811	Economy	13400.00
0005432433709	12811	Economy	13400.00
0005434067594	12811	Economy	13400.00
0005434067145	12811	Economy	13400.00
0005434081810	12811	Economy	13400.00
0005434067177	12811	Economy	13400.00
0005434067245	12811	Economy	13400.00
0005434067415	12811	Economy	13400.00
0005434081926	12811	Economy	13400.00
0005433989753	12811	Economy	13400.00
0005434067085	12811	Economy	13400.00
0005434067489	12811	Economy	13400.00
0005434067322	12811	Economy	13400.00
0005432159883	12811	Economy	13400.00
0005434081755	12811	Economy	13400.00
0005434067397	12811	Economy	13400.00
0005434067321	12811	Economy	13400.00
0005433989748	12811	Economy	13400.00
0005434081771	12811	Economy	13400.00
0005433812915	12811	Economy	13400.00
0005434081901	12811	Economy	13400.00
0005434067384	12811	Economy	13400.00
0005434081861	12811	Economy	13400.00
0005434067407	12811	Economy	13400.00
0005434081798	12811	Economy	13400.00
0005432161166	12811	Economy	13400.00
0005434067252	12811	Economy	13400.00
0005434081839	12811	Economy	13400.00
0005434081859	12811	Economy	13400.00
0005434067276	12811	Economy	13400.00
0005434067484	12811	Economy	13400.00
0005434081860	12811	Economy	13400.00
0005432159886	12811	Economy	13400.00
0005434067104	12811	Economy	13400.00
0005434067115	12811	Economy	13400.00
0005434067296	12811	Economy	13400.00
0005434067431	12811	Economy	13400.00
0005434067351	12811	Economy	13400.00
0005434067497	12811	Economy	13400.00
0005434081892	12811	Economy	13400.00
0005434067899	30672	Business	40300.00
0005434082033	30672	Business	40300.00
0005434067927	30672	Business	40300.00
0005434067953	30672	Business	40300.00
0005434067903	30672	Business	40300.00
0005434067960	30672	Business	40300.00
0005434082014	30672	Business	40300.00
0005432186886	30672	Business	40300.00
0005434067944	30672	Business	40300.00
0005434067958	30672	Business	40300.00
0005432433682	30672	Business	40300.00
0005434067946	30672	Economy	13400.00
0005434082016	30672	Economy	13400.00
0005434082032	30672	Economy	13400.00
0005434067961	30672	Economy	13400.00
0005434067932	30672	Economy	13400.00
0005434082030	30672	Economy	13400.00
0005434067963	30672	Economy	13400.00
0005434067950	30672	Economy	13400.00
0005434082026	30672	Economy	13400.00
0005434067931	30672	Economy	13400.00
0005434067921	30672	Economy	13400.00
0005434067906	30672	Economy	13400.00
0005434067894	30672	Economy	13400.00
0005432186887	30672	Economy	13400.00
0005434067945	30672	Economy	13400.00
0005434067910	30672	Economy	13400.00
0005434067920	30672	Economy	13400.00
0005434082031	30672	Economy	13400.00
0005434082013	30672	Economy	13400.00
0005434067948	30672	Economy	13400.00
0005434082018	30672	Economy	13400.00
0005434067942	30672	Economy	13400.00
0005434067893	30672	Economy	13400.00
0005434067904	30672	Economy	13400.00
0005434067952	30672	Economy	13400.00
0005434067949	30672	Economy	13400.00
0005434082025	30672	Economy	13400.00
0005434067936	30672	Economy	13400.00
0005434067908	30672	Economy	13400.00
0005434067912	30672	Economy	13400.00
0005434067954	30672	Economy	13400.00
0005434082017	30672	Economy	13400.00
0005434082010	30672	Economy	13400.00
0005434067900	30672	Economy	13400.00
0005434067913	30672	Economy	13400.00
0005434082023	30672	Economy	13400.00
0005434067917	30672	Economy	13400.00
0005434067902	30672	Economy	14800.00
0005434082019	30672	Economy	14800.00
0005432150238	30672	Economy	14800.00
0005434067933	30672	Economy	14800.00
0005434082021	30672	Economy	14800.00
0005433989797	30672	Economy	14800.00
0005434082008	30672	Economy	13400.00
0005434067892	30672	Economy	13400.00
0005434067919	30672	Economy	13400.00
0005434067941	30672	Economy	13400.00
0005434067934	30672	Economy	13400.00
0005434082009	30672	Economy	13400.00
0005432150233	30672	Economy	13400.00
0005434082028	30672	Economy	13400.00
0005432150237	30672	Economy	13400.00
0005432433654	30672	Economy	13400.00
0005434067940	30672	Economy	13400.00
0005434067897	30672	Economy	13400.00
0005434067918	30672	Economy	13400.00
0005432186891	30672	Economy	13400.00
0005432150235	30672	Economy	13400.00
0005434067915	30672	Economy	13400.00
0005434082027	30672	Economy	13400.00
0005434067938	30672	Economy	13400.00
0005434067923	30672	Economy	13400.00
0005434067896	30672	Economy	13400.00
0005434067911	30672	Economy	13400.00
0005434067909	30672	Economy	13400.00
0005433989796	30672	Economy	13400.00
0005434067937	30672	Economy	13400.00
0005432150234	30672	Economy	13400.00
0005432433685	30672	Economy	13400.00
0005432186890	30672	Economy	13400.00
0005432150236	30672	Economy	13400.00
0005434067924	30672	Economy	13400.00
0005434082024	30672	Economy	13400.00
0005434067930	30672	Economy	13400.00
0005434082029	30672	Economy	13400.00
0005434082022	30672	Economy	13400.00
0005434067895	30672	Economy	13400.00
0005434067907	30672	Economy	13400.00
0005433989795	30672	Economy	13400.00
0005434067939	30672	Economy	13400.00
0005434067957	30672	Economy	13400.00
0005434082011	30672	Economy	13400.00
0005434067916	30672	Economy	13400.00
0005434067922	30672	Economy	13400.00
0005434067955	30672	Economy	13400.00
0005434067925	30672	Economy	13400.00
0005434067935	30672	Economy	13400.00
0005434067959	30672	Economy	13400.00
0005434067928	30672	Economy	13400.00
0005432186888	30672	Economy	13400.00
0005434067901	30672	Economy	13400.00
0005434067898	30672	Economy	13400.00
0005434067956	30672	Economy	13400.00
0005434067905	30672	Economy	13400.00
0005434067926	30672	Economy	13400.00
0005432433655	30672	Economy	13400.00
0005434082015	30672	Economy	13400.00
0005434067914	30672	Economy	13400.00
0005432150239	30672	Economy	13400.00
0005433989794	30672	Economy	13400.00
0005432186889	30672	Economy	13400.00
0005434067947	30672	Economy	13400.00
0005434067962	30672	Economy	13400.00
0005432150232	30672	Economy	13400.00
0005434067951	30672	Economy	13400.00
0005434067943	30672	Economy	13400.00
0005434082012	30672	Economy	13400.00
0005434082020	30672	Economy	13400.00
0005434067964	30672	Economy	13400.00
0005434067929	30672	Economy	13400.00
0005435462139	5509	Business	35300.00
0005435462482	5509	Business	35300.00
0005435766610	5509	Business	35300.00
0005435766571	5509	Business	35300.00
0005435462404	5509	Business	35300.00
0005435766589	5509	Business	35300.00
0005434265112	5509	Business	35300.00
0005435766583	5509	Business	35300.00
0005435766570	5509	Business	35300.00
0005435766585	5509	Business	35300.00
0005435735159	5509	Business	35300.00
0005435462345	5509	Business	35300.00
0005435766613	5509	Business	35300.00
0005435462234	5509	Business	35300.00
0005435766588	5509	Business	35300.00
0005435462317	5509	Business	35300.00
0005435766582	5509	Business	35300.00
0005434265089	5509	Business	35300.00
0005435766604	5509	Business	35300.00
0005435462233	5509	Business	35300.00
0005435766614	5509	Business	35300.00
0005435722069	5509	Business	35300.00
0005435766612	5509	Business	35300.00
0005435462260	5509	Business	35300.00
0005435766577	5509	Business	35300.00
0005435722070	5509	Business	35300.00
0005435462220	5509	Business	35300.00
0005432140498	5509	Economy	12900.00
0005435766561	5509	Economy	12900.00
0005435722068	5509	Economy	12900.00
0005434265116	5509	Economy	11800.00
0005435462423	5509	Economy	11800.00
0005434265006	5509	Economy	11800.00
0005435462273	5509	Economy	11800.00
0005435725628	5509	Economy	11800.00
0005435462192	5509	Economy	11800.00
0005435462393	5509	Economy	11800.00
0005435766600	5509	Economy	11800.00
0005433529300	5509	Economy	11800.00
0005435766578	5509	Economy	11800.00
0005435766568	5509	Economy	11800.00
0005434265113	5509	Economy	11800.00
0005434264878	5509	Economy	11800.00
0005435766569	5509	Economy	11800.00
0005435462254	5509	Economy	11800.00
0005433529303	5509	Economy	11800.00
0005434265088	5509	Economy	11800.00
0005435462337	5509	Economy	11800.00
0005435462259	5509	Economy	11800.00
0005434265099	5509	Economy	11800.00
0005435462263	5509	Economy	11800.00
0005435766574	5509	Economy	11800.00
0005435766598	5509	Economy	11800.00
0005435766599	5509	Economy	11800.00
0005435725627	5509	Economy	11800.00
0005434831136	5509	Economy	11800.00
0005435720827	5509	Economy	11800.00
0005435462278	5509	Economy	11800.00
0005435462368	5509	Economy	11800.00
0005433527289	5509	Economy	11800.00
0005434265009	5509	Economy	11800.00
0005435766572	5509	Economy	11800.00
0005435766608	5509	Economy	11800.00
0005434831131	5509	Economy	11800.00
0005435766576	5509	Economy	11800.00
0005432140495	5509	Economy	11800.00
0005435462512	5509	Economy	11800.00
0005435462185	5509	Economy	11800.00
0005435462349	5509	Economy	11800.00
0005435766597	5509	Economy	11800.00
0005432535797	5509	Economy	11800.00
0005435462303	5509	Economy	11800.00
0005434264952	5509	Economy	11800.00
0005432535796	5509	Economy	11800.00
0005434265127	5509	Economy	11800.00
0005434264879	5509	Economy	11800.00
0005435462256	5509	Economy	11800.00
0005435462483	5509	Economy	11800.00
0005434265015	5509	Economy	11800.00
0005432140494	5509	Economy	11800.00
0005434265035	5509	Economy	11800.00
0005435766606	5509	Economy	11800.00
0005434265028	5509	Economy	11800.00
0005434264951	5509	Economy	11800.00
0005435766596	5509	Economy	11800.00
0005432140493	5509	Economy	11800.00
0005435766586	5509	Economy	11800.00
0005435720828	5509	Economy	11800.00
0005435766579	5509	Economy	11800.00
0005435462357	5509	Economy	11800.00
0005434265042	5509	Economy	11800.00
0005434264976	5509	Economy	11800.00
0005432535828	5509	Economy	11800.00
0005433527291	5509	Economy	11800.00
0005435766607	5509	Economy	11800.00
0005435462162	5509	Economy	11800.00
0005432140496	5509	Economy	11800.00
0005434264998	5509	Economy	11800.00
0005435766609	5509	Economy	11800.00
0005435462372	5509	Economy	12900.00
0005433529301	5509	Economy	11800.00
0005435725626	5509	Economy	12900.00
0005435766594	5509	Economy	11800.00
0005434831130	5509	Economy	11800.00
0005433529302	5509	Economy	11800.00
0005435766564	5509	Economy	11800.00
0005435766573	5509	Economy	11800.00
0005434264970	5509	Economy	11800.00
0005435462257	5509	Economy	11800.00
0005432140497	5509	Economy	11800.00
0005435462348	5509	Economy	11800.00
0005432140500	5509	Economy	11800.00
0005435766595	5509	Economy	11800.00
0005435043282	5509	Economy	11800.00
0005435766591	5509	Economy	11800.00
0005435766575	5509	Economy	11800.00
0005434831141	5509	Economy	11800.00
0005434265016	5509	Economy	11800.00
0005435462312	5509	Economy	11800.00
0005435766592	5509	Economy	11800.00
0005435766563	5509	Economy	11800.00
0005432535812	5509	Economy	11800.00
0005435766581	5509	Economy	11800.00
0005435766601	5509	Economy	11800.00
0005435462377	5509	Economy	11800.00
0005435766566	5509	Economy	11800.00
0005434265126	5509	Economy	11800.00
0005434831129	5509	Economy	11800.00
0005435766567	5509	Economy	11800.00
0005435766584	5509	Economy	11800.00
0005435766565	5509	Economy	11800.00
0005435766605	5509	Economy	11800.00
0005433527292	5509	Economy	11800.00
0005434264975	5509	Economy	11800.00
0005435766611	5509	Economy	11800.00
0005435722071	5509	Economy	11800.00
0005435462369	5509	Economy	11800.00
0005434264950	5509	Economy	11800.00
0005434264877	5509	Economy	11800.00
0005434264989	5509	Economy	11800.00
0005435766587	5509	Economy	11800.00
0005435735162	5509	Economy	11800.00
0005435462193	5509	Economy	11800.00
0005435462163	5509	Economy	11800.00
0005435766593	5509	Economy	11800.00
0005435462318	5509	Economy	11800.00
0005435462243	5509	Economy	11800.00
0005435462458	5509	Economy	11800.00
0005435735161	5509	Economy	11800.00
0005435766590	5509	Economy	11800.00
0005435766580	5509	Economy	11800.00
0005433527290	5509	Economy	11800.00
0005435735160	5509	Economy	11800.00
0005434265087	5509	Economy	11800.00
0005434265041	5509	Economy	11800.00
0005435462292	5509	Economy	11800.00
0005435462235	5509	Economy	11800.00
0005435766603	5509	Economy	11800.00
0005435462384	5509	Economy	11800.00
0005435766562	5509	Economy	11800.00
0005435725625	5509	Economy	11800.00
0005434265010	5509	Economy	11800.00
0005432535802	5509	Economy	11800.00
0005435766602	5509	Economy	11800.00
0005432140499	5509	Economy	11800.00
0005435462394	5509	Economy	11800.00
0005434265299	13454	Business	35300.00
0005435766199	13454	Business	35300.00
0005435766223	13454	Business	35300.00
0005434265291	13454	Business	35300.00
0005435765825	13454	Business	35300.00
0005435766163	13454	Business	35300.00
0005435765822	13454	Business	35300.00
0005435462676	13454	Business	35300.00
0005435765993	13454	Business	35300.00
0005435462669	13454	Business	35300.00
0005435765952	13454	Business	35300.00
0005435735126	13454	Business	35300.00
0005435462674	13454	Business	35300.00
0005435462672	13454	Business	35300.00
0005435766276	13454	Business	35300.00
0005435462671	13454	Business	35300.00
0005435766102	13454	Business	35300.00
0005435462648	13454	Business	35300.00
0005435462666	13454	Business	35300.00
0005434265284	13454	Business	35300.00
0005434265301	13454	Business	35300.00
0005435462654	13454	Economy	12900.00
0005435462661	13454	Economy	12900.00
0005432194537	13454	Economy	12900.00
0005435735113	13454	Economy	11800.00
0005434265285	13454	Economy	11800.00
0005435735102	13454	Economy	11800.00
0005435765708	13454	Economy	11800.00
0005435765994	13454	Economy	11800.00
0005435766169	13454	Economy	11800.00
0005435462647	13454	Economy	11800.00
0005435766006	13454	Economy	11800.00
0005434265289	13454	Economy	11800.00
0005435462662	13454	Economy	11800.00
0005435462667	13454	Economy	11800.00
0005434265295	13454	Economy	11800.00
0005432535863	13454	Economy	11800.00
0005435462649	13454	Economy	11800.00
0005434265305	13454	Economy	11800.00
0005435462651	13454	Economy	11800.00
0005435462680	13454	Economy	11800.00
0005435766316	13454	Economy	11800.00
0005434265309	13454	Economy	11800.00
0005435765969	13454	Economy	11800.00
0005435766289	13454	Economy	11800.00
0005435462677	13454	Economy	11800.00
0005435766198	13454	Economy	11800.00
0005435766036	13454	Economy	11800.00
0005432535864	13454	Economy	11800.00
0005435725587	13454	Economy	11800.00
0005434265287	13454	Economy	11800.00
0005435725554	13454	Economy	11800.00
0005434265308	13454	Economy	11800.00
0005435766027	13454	Economy	11800.00
0005435766140	13454	Economy	11800.00
0005435462665	13454	Economy	11800.00
0005435766323	13454	Economy	11800.00
0005435766175	13454	Economy	11800.00
0005434265302	13454	Economy	11800.00
0005435766056	13454	Economy	11800.00
0005435725588	13454	Economy	11800.00
0005434265290	13454	Economy	11800.00
0005435766061	13454	Economy	11800.00
0005435462668	13454	Economy	11800.00
0005435766037	13454	Economy	11800.00
0005434265296	13454	Economy	11800.00
0005435462655	13454	Economy	11800.00
0005435462678	13454	Economy	11800.00
0005435725589	13454	Economy	11800.00
0005435462682	13454	Economy	11800.00
0005435462675	13454	Economy	11800.00
0005435766120	13454	Economy	11800.00
0005435766176	13454	Economy	11800.00
0005435725583	13454	Economy	11800.00
0005432535862	13454	Economy	11800.00
0005435766122	13454	Economy	11800.00
0005434831179	13454	Economy	11800.00
0005435766134	13454	Economy	11800.00
0005435766236	13454	Economy	11800.00
0005435462663	13454	Economy	11800.00
0005435735119	13454	Economy	11800.00
0005435765821	13454	Economy	11800.00
0005434831182	13454	Economy	11800.00
0005434265298	13454	Economy	11800.00
0005434265292	13454	Economy	11800.00
0005435043291	13454	Economy	11800.00
0005435462683	13454	Economy	11800.00
0005434831181	13454	Economy	11800.00
0005435766060	13454	Economy	11800.00
0005435766250	13454	Economy	11800.00
0005432194534	13454	Economy	11800.00
0005435766062	13454	Economy	11800.00
0005435766280	13454	Economy	11800.00
0005435766282	13454	Economy	11800.00
0005435765815	13454	Economy	11800.00
0005435766193	13454	Economy	11800.00
0005435766063	13454	Economy	11800.00
0005435766192	13454	Economy	12900.00
0005435725549	13454	Economy	12900.00
0005434265294	13454	Economy	11800.00
0005434265286	13454	Economy	11800.00
0005432194536	13454	Economy	11800.00
0005435462646	13454	Economy	12900.00
0005435462673	13454	Economy	11800.00
0005435766115	13454	Economy	11800.00
0005435765978	13454	Economy	11800.00
0005435766275	13454	Economy	11800.00
0005435462657	13454	Economy	11800.00
0005435766185	13454	Economy	11800.00
0005434265307	13454	Economy	11800.00
0005435462652	13454	Economy	11800.00
0005432535865	13454	Economy	11800.00
0005435765824	13454	Economy	11800.00
0005435722050	13454	Economy	11800.00
0005435462645	13454	Economy	11800.00
0005435735118	13454	Economy	11800.00
0005435765951	13454	Economy	11800.00
0005434831180	13454	Economy	11800.00
0005434265293	13454	Economy	11800.00
0005435766121	13454	Economy	11800.00
0005435766032	13454	Economy	11800.00
0005435462679	13454	Economy	11800.00
0005434831178	13454	Economy	11800.00
0005435462659	13454	Economy	11800.00
0005435462664	13454	Economy	11800.00
0005435766249	13454	Economy	11800.00
0005432194535	13454	Economy	11800.00
0005435722049	13454	Economy	11800.00
0005435766291	13454	Economy	11800.00
0005435766201	13454	Economy	11800.00
0005435462658	13454	Economy	11800.00
0005435722048	13454	Economy	11800.00
0005434265303	13454	Economy	11800.00
0005435462681	13454	Economy	11800.00
0005435766290	13454	Economy	11800.00
0005435766170	13454	Economy	11800.00
0005435766048	13454	Economy	11800.00
0005435462660	13454	Economy	11800.00
0005435462670	13454	Economy	11800.00
0005435766007	13454	Economy	11800.00
0005435722046	13454	Economy	11800.00
0005435766244	13454	Economy	11800.00
0005435766194	13454	Economy	11800.00
0005435723040	13454	Economy	11800.00
0005434265306	13454	Economy	11800.00
0005434265288	13454	Economy	11800.00
0005435043290	13454	Economy	11800.00
0005435766243	13454	Economy	11800.00
0005435462650	13454	Economy	11800.00
0005435462656	13454	Economy	11800.00
0005435765977	13454	Economy	11800.00
0005434265300	13454	Economy	11800.00
0005434265297	13454	Economy	11800.00
0005434265304	13454	Economy	11800.00
0005435725584	13454	Economy	11800.00
0005435462653	13454	Economy	11800.00
0005434602885	18732	Economy	3300.00
0005434602892	18732	Economy	3300.00
0005434602893	18732	Economy	3300.00
0005434602899	18732	Economy	3300.00
0005434602887	18732	Economy	3300.00
0005434513592	18755	Economy	3300.00
0005434514981	18755	Economy	3300.00
0005434604876	18755	Economy	3300.00
0005434514982	18755	Economy	3300.00
0005434514980	18755	Economy	3300.00
0005434514983	18755	Economy	3300.00
0005434513594	18755	Economy	3300.00
0005434513593	18755	Economy	3300.00
0005434604891	18755	Economy	3300.00
0005434604894	18755	Economy	3300.00
0005434514958	19140	Economy	3300.00
0005434514959	19140	Economy	3300.00
0005434514960	19140	Economy	3300.00
0005434514961	19140	Economy	3300.00
0005432649360	25098	Business	88300.00
0005432649362	25098	Business	88300.00
0005435846275	25098	Economy	29400.00
0005432649370	25098	Economy	29400.00
0005432649405	25098	Economy	29400.00
0005435846272	25098	Economy	29400.00
0005435846276	25098	Economy	29400.00
0005432649364	25098	Economy	29400.00
0005432649388	25098	Economy	29400.00
0005432649401	25098	Economy	29400.00
0005435846270	25098	Economy	29400.00
0005432649361	25098	Economy	29400.00
0005432649377	25098	Economy	29400.00
0005435846273	25098	Economy	29400.00
0005432649367	25098	Economy	29400.00
0005435846271	25098	Economy	29400.00
0005432649378	25098	Economy	29400.00
0005435846274	25098	Economy	29400.00
0005432649387	25098	Economy	29400.00
0005432649402	25098	Economy	29400.00
0005433285154	1828	Business	48700.00
0005433008151	1828	Business	48700.00
0005433285197	1828	Business	48700.00
0005433008455	1828	Business	48700.00
0005433008659	1828	Business	48700.00
0005433008452	1828	Business	48700.00
0005433008630	1828	Business	48700.00
0005433285210	1828	Business	48700.00
0005433008432	1828	Business	48700.00
0005433285193	1828	Economy	16200.00
0005433008441	1828	Economy	16200.00
0005433008553	1828	Economy	16200.00
0005433285194	1828	Economy	16200.00
0005433008552	1828	Economy	16200.00
0005433285269	1828	Economy	16200.00
0005433008415	1828	Economy	16200.00
0005432295895	1828	Economy	16200.00
0005433008499	1828	Economy	16200.00
0005433008392	1828	Economy	16200.00
0005433285255	1828	Economy	17900.00
0005433008640	1828	Economy	17900.00
0005433008646	1828	Economy	17900.00
0005433285254	1828	Economy	17900.00
0005433008444	1828	Economy	16200.00
0005433008578	1828	Economy	16200.00
0005433008521	1828	Economy	16200.00
0005433008635	1828	Economy	16200.00
0005433285112	1828	Economy	16200.00
0005433285205	1828	Economy	16200.00
0005433285271	1828	Economy	16200.00
0005433008150	1828	Economy	16200.00
0005433285276	1828	Economy	16200.00
0005433285306	1828	Economy	16200.00
0005433285164	1828	Economy	16200.00
0005433008332	1828	Economy	16200.00
0005433008453	1828	Economy	16200.00
0005433008528	1828	Economy	16200.00
0005433285211	1828	Economy	16200.00
0005433008498	1828	Economy	16200.00
0005433285044	1828	Economy	16200.00
0005433285282	1828	Economy	16200.00
0005433285270	1828	Economy	16200.00
0005433285160	1828	Economy	16200.00
0005433285110	1828	Economy	16200.00
0005433008641	1828	Economy	16200.00
0005433008449	1828	Economy	16200.00
0005433008587	1828	Economy	16200.00
0005433008535	1828	Economy	16200.00
0005433008391	1828	Economy	16200.00
0005433285274	1828	Economy	16200.00
0005433008799	1828	Economy	16200.00
0005433008549	1828	Economy	16200.00
0005433008800	1828	Economy	16200.00
0005433008582	1828	Economy	16200.00
0005433285281	1828	Economy	16200.00
0005433008331	1828	Economy	16200.00
0005433008433	1828	Economy	16200.00
0005433008556	1828	Economy	16200.00
0005433285163	1828	Economy	16200.00
0005433008610	1828	Economy	16200.00
0005433008348	1828	Economy	16200.00
0005432295894	1828	Economy	16200.00
0005433285273	1828	Economy	16200.00
0005433008801	1828	Economy	16200.00
0005433008554	1828	Economy	16200.00
0005433008487	1828	Economy	16200.00
0005433008434	1828	Economy	16200.00
0005433285260	1828	Economy	16200.00
0005433008454	1828	Economy	16200.00
0005433008488	1828	Economy	16200.00
0005433008473	1828	Economy	16200.00
0005433008511	1828	Economy	16200.00
0005433008456	1828	Economy	16200.00
0005433008345	1828	Economy	16200.00
0005433008232	1828	Economy	16200.00
0005433285153	1828	Economy	16200.00
0005433285307	1828	Economy	16200.00
0005433285220	1828	Economy	16200.00
0005433008520	1828	Economy	16200.00
0005433285201	1828	Economy	16200.00
0005433008645	1828	Economy	16200.00
0005432295896	1828	Economy	16200.00
0005433008318	1828	Economy	16200.00
0005433008448	1828	Economy	16200.00
0005433008650	1828	Economy	16200.00
0005433008527	1828	Economy	16200.00
0005433008638	1828	Economy	16200.00
0005433008534	1828	Economy	16200.00
0005433008850	22535	Business	48700.00
0005433008852	22535	Business	48700.00
0005433008844	22535	Business	48700.00
0005433285485	22535	Business	48700.00
0005433285466	22535	Business	48700.00
0005433285486	22535	Business	48700.00
0005433285470	22535	Business	48700.00
0005433008871	22535	Economy	16200.00
0005433285463	22535	Economy	16200.00
0005433008856	22535	Economy	16200.00
0005433008883	22535	Economy	16200.00
0005433008874	22535	Economy	16200.00
0005433008851	22535	Economy	16200.00
0005433285475	22535	Economy	16200.00
0005433008864	22535	Economy	16200.00
0005433008857	22535	Economy	17900.00
0005433008877	22535	Economy	17900.00
0005433008847	22535	Economy	17900.00
0005433285487	22535	Economy	17900.00
0005433285483	22535	Economy	16200.00
0005433008884	22535	Economy	16200.00
0005433008879	22535	Economy	16200.00
0005433285477	22535	Economy	16200.00
0005433008870	22535	Economy	16200.00
0005433285461	22535	Economy	16200.00
0005433285476	22535	Economy	16200.00
0005433008848	22535	Economy	16200.00
0005433008876	22535	Economy	16200.00
0005433285472	22535	Economy	16200.00
0005433008873	22535	Economy	16200.00
0005433008853	22535	Economy	16200.00
0005433008888	22535	Economy	16200.00
0005433285473	22535	Economy	16200.00
0005433008846	22535	Economy	16200.00
0005433008881	22535	Economy	16200.00
0005433008868	22535	Economy	16200.00
0005433285471	22535	Economy	16200.00
0005433008887	22535	Economy	16200.00
0005433285481	22535	Economy	16200.00
0005433285469	22535	Economy	16200.00
0005433285460	22535	Economy	16200.00
0005433285484	22535	Economy	16200.00
0005433285480	22535	Economy	16200.00
0005433285456	22535	Economy	16200.00
0005433008863	22535	Economy	16200.00
0005433285467	22535	Economy	16200.00
0005433008845	22535	Economy	16200.00
0005433008859	22535	Economy	16200.00
0005433008880	22535	Economy	16200.00
0005433008854	22535	Economy	16200.00
0005433008866	22535	Economy	16200.00
0005433008867	22535	Economy	16200.00
0005433810517	22535	Economy	16200.00
0005433008882	22535	Economy	16200.00
0005433008872	22535	Economy	16200.00
0005433285468	22535	Economy	16200.00
0005433008886	22535	Economy	16200.00
0005433008889	22535	Economy	16200.00
0005433285457	22535	Economy	16200.00
0005433008849	22535	Economy	16200.00
0005433008885	22535	Economy	16200.00
0005433008861	22535	Economy	16200.00
0005433008865	22535	Economy	16200.00
0005433008878	22535	Economy	16200.00
0005433008858	22535	Economy	16200.00
0005433008860	22535	Economy	16200.00
0005433008875	22535	Economy	16200.00
0005433285459	22535	Economy	16200.00
0005433008869	22535	Economy	16200.00
0005433285465	22535	Economy	16200.00
0005433285458	22535	Economy	16200.00
0005433285474	22535	Economy	16200.00
0005433285482	22535	Economy	16200.00
0005433008862	22535	Economy	16200.00
0005433285462	22535	Economy	16200.00
0005433008855	22535	Economy	16200.00
0005433285479	22535	Economy	16200.00
0005433285464	22535	Economy	16200.00
0005433285478	22535	Economy	16200.00
0005432755069	12277	Business	83800.00
0005432755061	12277	Business	83800.00
0005432755070	12277	Business	83800.00
0005434152795	12277	Business	83800.00
0005432751526	12277	Business	83800.00
0005432751504	12277	Business	83800.00
0005432755064	12277	Business	83800.00
0005432755065	12277	Economy	27900.00
0005432755050	12277	Economy	27900.00
0005434152801	12277	Economy	27900.00
0005432751510	12277	Economy	27900.00
0005432751505	12277	Economy	27900.00
0005434152799	12277	Economy	30700.00
0005434152800	12277	Economy	27900.00
0005432751532	12277	Economy	27900.00
0005432755053	12277	Economy	27900.00
0005432751517	12277	Economy	27900.00
0005432751506	12277	Economy	27900.00
0005432751511	12277	Economy	27900.00
0005434152797	12277	Economy	27900.00
0005434152793	12277	Economy	27900.00
0005432751503	12277	Economy	27900.00
0005434152794	12277	Economy	27900.00
0005432751509	12277	Economy	27900.00
0005432755052	12277	Economy	27900.00
0005434152802	12277	Economy	27900.00
0005432755055	12277	Economy	27900.00
0005432755044	12277	Economy	27900.00
0005434152796	12277	Economy	27900.00
0005432755049	12277	Economy	27900.00
0005434152798	12277	Economy	27900.00
0005432755043	12277	Economy	27900.00
0005432751520	12277	Economy	27900.00
0005432755072	12277	Economy	27900.00
0005432081549	5554	Business	99800.00
0005433847054	5554	Business	99800.00
0005432081546	5554	Business	99800.00
0005433847068	5554	Business	99800.00
0005433847080	5554	Business	99800.00
0005432081547	5554	Business	99800.00
0005432081548	5554	Business	99800.00
0005433847061	5554	Business	99800.00
0005434173488	5554	Business	99800.00
0005432081550	5554	Business	99800.00
0005433815410	5554	Business	99800.00
0005434173502	5554	Business	99800.00
0005433847069	5554	Business	99800.00
0005433847055	5554	Business	99800.00
0005435282537	5554	Business	99800.00
0005433847091	5554	Business	99800.00
0005435282432	5554	Business	99800.00
0005435282376	5554	Economy	33300.00
0005433847072	5554	Economy	33300.00
0005435282487	5554	Economy	33300.00
0005432081552	5554	Economy	33300.00
0005433847046	5554	Economy	33300.00
0005433847082	5554	Economy	33300.00
0005433847039	5554	Economy	33300.00
0005433847078	5554	Economy	33300.00
0005435282536	5554	Economy	33300.00
0005433847058	5554	Economy	33300.00
0005433847088	5554	Economy	33300.00
0005433847049	5554	Economy	33300.00
0005433847066	5554	Economy	33300.00
0005433847092	5554	Economy	36600.00
0005433815412	5554	Economy	36600.00
0005435282385	5554	Economy	33300.00
0005433847038	5554	Economy	33300.00
0005433847086	5554	Economy	33300.00
0005433847097	5554	Economy	33300.00
0005433847063	5554	Economy	33300.00
0005435282455	5554	Economy	33300.00
0005433847073	5554	Economy	33300.00
0005433847043	5554	Economy	33300.00
0005433847041	5554	Economy	33300.00
0005433847083	5554	Economy	33300.00
0005432081551	5554	Economy	33300.00
0005434173514	5554	Economy	33300.00
0005435282440	5554	Economy	33300.00
0005433847053	5554	Economy	33300.00
0005433847084	5554	Economy	33300.00
0005433847050	5554	Economy	33300.00
0005433847079	5554	Economy	33300.00
0005433847056	5554	Economy	33300.00
0005433847074	5554	Economy	33300.00
0005433847040	5554	Economy	33300.00
0005433847064	5554	Economy	33300.00
0005435282443	5554	Economy	33300.00
0005435282398	5554	Economy	33300.00
0005433847057	5554	Economy	33300.00
0005433847077	5554	Economy	33300.00
0005433815413	5554	Economy	33300.00
0005435282479	5554	Economy	33300.00
0005433815411	5554	Economy	33300.00
0005433847065	5554	Economy	33300.00
0005433847076	5554	Economy	33300.00
0005433847060	5554	Economy	33300.00
0005433847071	5554	Economy	33300.00
0005433847059	5554	Economy	33300.00
0005435282478	5554	Economy	33300.00
0005433847089	5554	Economy	33300.00
0005433847085	5554	Economy	33300.00
0005433847096	5554	Economy	33300.00
0005433847081	5554	Economy	33300.00
0005433847045	5554	Economy	33300.00
0005433847047	5554	Economy	33300.00
0005433847094	5554	Economy	33300.00
0005433847062	5554	Economy	33300.00
0005435282375	5554	Economy	33300.00
0005433847070	5554	Economy	33300.00
0005435282384	5554	Economy	33300.00
0005433815409	5554	Economy	33300.00
0005433847048	5554	Economy	33300.00
0005433847051	5554	Economy	33300.00
0005433847042	5554	Economy	33300.00
0005433847090	5554	Economy	33300.00
0005433847044	5554	Economy	33300.00
0005434173508	5554	Economy	33300.00
0005435282488	5554	Economy	33300.00
0005433847095	5554	Economy	33300.00
0005433847087	5554	Economy	33300.00
0005433847052	5554	Economy	33300.00
0005433847075	5554	Economy	33300.00
0005433847067	5554	Economy	33300.00
0005434173503	5554	Economy	33300.00
0005433847093	5554	Economy	33300.00
0005435282334	5554	Economy	33300.00
0005434173500	5554	Economy	33300.00
0005433846057	13878	Business	99800.00
0005435282659	13878	Business	99800.00
0005433846655	13878	Business	99800.00
0005433846503	13878	Business	99800.00
0005433846676	13878	Business	99800.00
0005433846581	13878	Business	99800.00
0005433846777	13878	Business	99800.00
0005433846504	13878	Business	99800.00
0005435282646	13878	Business	99800.00
0005433846492	13878	Business	99800.00
0005433815361	13878	Business	99800.00
0005435282648	13878	Business	99800.00
0005435282660	13878	Business	99800.00
0005433846740	13878	Business	99800.00
0005433846739	13878	Business	99800.00
0005433846450	13878	Business	99800.00
0005435282658	13878	Business	99800.00
0005433846707	13878	Economy	33300.00
0005433846809	13878	Economy	33300.00
0005435282671	13878	Economy	33300.00
0005435282663	13878	Economy	33300.00
0005433815371	13878	Economy	33300.00
0005433846501	13878	Economy	33300.00
0005435282666	13878	Economy	33300.00
0005433846822	13878	Economy	33300.00
0005433846558	13878	Economy	33300.00
0005433846490	13878	Economy	33300.00
0005435282665	13878	Economy	33300.00
0005433846494	13878	Economy	33300.00
0005435282664	13878	Economy	36600.00
0005433846781	13878	Economy	36600.00
0005435282668	13878	Economy	36600.00
0005433846362	13878	Economy	36600.00
0005433846672	13878	Economy	33300.00
0005433846764	13878	Economy	33300.00
0005433846577	13878	Economy	33300.00
0005434173545	13878	Economy	33300.00
0005435282670	13878	Economy	33300.00
0005435282667	13878	Economy	33300.00
0005435282655	13878	Economy	33300.00
0005433846472	13878	Economy	33300.00
0005433815372	13878	Economy	33300.00
0005433846502	13878	Economy	33300.00
0005435282672	13878	Economy	33300.00
0005433846559	13878	Economy	33300.00
0005433846573	13878	Economy	33300.00
0005433846056	13878	Economy	33300.00
0005435282650	13878	Economy	33300.00
0005434173544	13878	Economy	33300.00
0005435282656	13878	Economy	33300.00
0005433846608	13878	Economy	33300.00
0005433815369	13878	Economy	33300.00
0005433846449	13878	Economy	33300.00
0005433846484	13878	Economy	33300.00
0005433846623	13878	Economy	33300.00
0005433846778	13878	Economy	33300.00
0005433846532	13878	Economy	33300.00
0005433846518	13878	Economy	33300.00
0005433846517	13878	Economy	33300.00
0005435282657	13878	Economy	33300.00
0005433846776	13878	Economy	33300.00
0005435282669	13878	Economy	33300.00
0005435282654	13878	Economy	33300.00
0005433815370	13878	Economy	33300.00
0005433815373	13878	Economy	33300.00
0005434173546	13878	Economy	33300.00
0005435282649	13878	Economy	33300.00
0005435282652	13878	Economy	33300.00
0005432003720	13878	Economy	33300.00
0005433846625	13878	Economy	33300.00
0005433846561	13878	Economy	33300.00
0005433846347	13878	Economy	33300.00
0005435282661	13878	Economy	33300.00
0005433846782	13878	Economy	33300.00
0005433846624	13878	Economy	33300.00
0005433815364	13878	Economy	33300.00
0005433846569	13878	Economy	33300.00
0005433846750	13878	Economy	33300.00
0005433846575	13878	Economy	33300.00
0005435282647	13878	Economy	33300.00
0005433846452	13878	Economy	33300.00
0005433846562	13878	Economy	33300.00
0005432003721	13878	Economy	33300.00
0005434173543	13878	Economy	33300.00
0005435282645	13878	Economy	33300.00
0005433846538	13878	Economy	33300.00
0005435282662	13878	Economy	33300.00
0005433846692	13878	Economy	33300.00
0005433815368	13878	Economy	33300.00
0005435282653	13878	Economy	33300.00
0005433846671	13878	Economy	33300.00
0005433846810	13878	Economy	33300.00
0005433846607	13878	Economy	33300.00
0005433846711	13878	Economy	33300.00
0005433846533	13878	Economy	33300.00
0005435282651	13878	Economy	33300.00
0005433846650	13878	Economy	33300.00
0005435332321	7817	Economy	16600.00
0005434620724	7817	Economy	16600.00
0005435332290	7817	Economy	16600.00
0005434620716	7817	Economy	15100.00
0005435332287	7817	Economy	15100.00
0005434620718	7817	Economy	15100.00
0005435332305	7817	Economy	15100.00
0005435332314	7817	Economy	15100.00
0005432112530	7817	Economy	15100.00
0005435332322	7817	Economy	15100.00
0005434620720	7817	Economy	15100.00
0005435332316	7817	Economy	15100.00
0005435332301	7817	Economy	15100.00
0005434620710	7817	Economy	15100.00
0005435332283	7817	Economy	15100.00
0005435332332	7817	Economy	15100.00
0005434620715	7817	Economy	15100.00
0005434620713	7817	Economy	15100.00
0005434620726	7817	Economy	15100.00
0005434620712	7817	Economy	15100.00
0005434620711	7817	Economy	15100.00
0005434620706	7817	Economy	15100.00
0005435332323	7817	Economy	15100.00
0005434620714	7817	Economy	15100.00
0005435332330	7817	Economy	15100.00
0005434620723	7817	Economy	15100.00
0005435332313	7817	Economy	15100.00
0005434620708	7817	Economy	15100.00
0005435332306	7817	Economy	15100.00
0005435332315	7817	Economy	15100.00
0005434620721	7817	Economy	15100.00
0005435332320	7817	Economy	15100.00
0005435332294	7817	Economy	15100.00
0005435332288	7817	Economy	15100.00
0005434620717	7817	Economy	15100.00
0005435332311	7817	Economy	15100.00
0005435332293	7817	Economy	15100.00
0005432112529	7817	Economy	15100.00
0005434620707	7817	Economy	15100.00
0005434620709	7817	Economy	15100.00
0005434620725	7817	Economy	15100.00
0005434620719	7817	Economy	15100.00
0005435332302	7817	Economy	15100.00
0005435332285	7817	Economy	15100.00
0005435332312	7817	Economy	15100.00
0005434620722	7817	Economy	15100.00
0005435332317	7817	Economy	15100.00
0005434620393	32991	Economy	16600.00
0005435332397	32991	Economy	16600.00
0005435332393	32991	Economy	15100.00
0005435332402	32991	Economy	15100.00
0005434620507	32991	Economy	15100.00
0005434620508	32991	Economy	15100.00
0005435332399	32991	Economy	15100.00
0005435332401	32991	Economy	15100.00
0005435332391	32991	Economy	15100.00
0005435332398	32991	Economy	15100.00
0005434620609	32991	Economy	15100.00
0005434620619	32991	Economy	15100.00
0005435332392	32991	Economy	15100.00
0005434620488	32991	Economy	15100.00
0005434620580	32991	Economy	15100.00
0005434620570	32991	Economy	15100.00
0005434620550	32991	Economy	15100.00
0005435332396	32991	Economy	15100.00
0005434620539	32991	Economy	15100.00
0005434620451	32991	Economy	15100.00
0005434620549	32991	Economy	15100.00
0005435332400	32991	Economy	15100.00
0005435332395	32991	Economy	15100.00
0005434620461	32991	Economy	15100.00
0005434620585	32991	Economy	15100.00
0005434620591	32991	Economy	15100.00
0005434620517	32991	Economy	15100.00
0005435332394	32991	Economy	15100.00
0005435785574	4279	Business	38000.00
0005435785561	4279	Business	38000.00
0005435918663	4279	Business	38000.00
0005435937345	4279	Business	38000.00
0005434994078	4279	Business	38000.00
0005435937358	4279	Business	38000.00
0005434994079	4279	Business	38000.00
0005435937344	4279	Economy	12700.00
0005435785553	4279	Economy	12700.00
0005435785566	4279	Economy	12700.00
0005435918641	4279	Economy	12700.00
0005435918660	4279	Economy	12700.00
0005435785562	4279	Economy	12700.00
0005434994077	4279	Economy	12700.00
0005435937364	4279	Economy	12700.00
0005435785558	4279	Economy	13900.00
0005435785572	4279	Economy	13900.00
0005435787366	4279	Economy	12700.00
0005435785545	4279	Economy	12700.00
0005435918649	4279	Economy	12700.00
0005435937371	4279	Economy	12700.00
0005432190653	4279	Economy	12700.00
0005435785544	4279	Economy	12700.00
0005435785543	4279	Economy	12700.00
0005432190652	4279	Economy	12700.00
0005435785548	4279	Economy	12700.00
0005435937370	4279	Economy	12700.00
0005435785577	4279	Economy	12700.00
0005435785567	4279	Economy	12700.00
0005435785575	4279	Economy	12700.00
0005435785552	4279	Economy	12700.00
0005435785554	4279	Economy	12700.00
0005435787367	4279	Economy	12700.00
0005435785549	4279	Economy	12700.00
0005434994081	4279	Economy	12700.00
0005435785557	4279	Economy	12700.00
0005435937350	4279	Economy	12700.00
0005435785563	4279	Economy	12700.00
0005435785555	4279	Economy	12700.00
0005435785550	4279	Economy	12700.00
0005435785551	4279	Economy	12700.00
0005435937372	4279	Economy	12700.00
0005435785569	4279	Economy	12700.00
0005435785571	4279	Economy	12700.00
0005435785568	4279	Economy	12700.00
0005434994080	4279	Economy	12700.00
0005435785570	4279	Economy	12700.00
0005434994082	4279	Economy	12700.00
0005435918638	4279	Economy	12700.00
0005435785576	4279	Economy	12700.00
0005435785556	4279	Economy	12700.00
0005435785560	4279	Economy	12700.00
0005435918654	4279	Economy	12700.00
0005435918628	4279	Economy	12700.00
0005435785547	4279	Economy	12700.00
0005435918655	4279	Economy	12700.00
0005435785546	4279	Economy	12700.00
0005435918659	4279	Economy	12700.00
0005435785564	4279	Economy	12700.00
0005435937385	4279	Economy	12700.00
0005435785565	4279	Economy	12700.00
0005435785559	4279	Economy	12700.00
0005435937386	4279	Economy	12700.00
0005434994084	4279	Economy	12700.00
0005435785573	4279	Economy	12700.00
0005434994083	4279	Economy	12700.00
0005435785236	27300	Business	38000.00
0005435785241	27300	Business	38000.00
0005434993993	27300	Business	38000.00
0005435785191	27300	Business	38000.00
0005434993992	27300	Business	38000.00
0005435785029	27300	Business	38000.00
0005435785280	27300	Business	38000.00
0005435918682	27300	Business	38000.00
0005435787336	27300	Business	38000.00
0005435785141	27300	Economy	12700.00
0005434994009	27300	Economy	12700.00
0005435787351	27300	Economy	12700.00
0005435785324	27300	Economy	12700.00
0005435785200	27300	Economy	12700.00
0005435918685	27300	Economy	12700.00
0005435785265	27300	Economy	12700.00
0005434993995	27300	Economy	12700.00
0005435785231	27300	Economy	13900.00
0005434993996	27300	Economy	13900.00
0005435787353	27300	Economy	13900.00
0005435785255	27300	Economy	12700.00
0005435787341	27300	Economy	12700.00
0005435785234	27300	Economy	12700.00
0005435918683	27300	Economy	12700.00
0005434994036	27300	Economy	12700.00
0005435785180	27300	Economy	12700.00
0005435785233	27300	Economy	12700.00
0005434994012	27300	Economy	12700.00
0005435787337	27300	Economy	12700.00
0005435785229	27300	Economy	12700.00
0005434993994	27300	Economy	12700.00
0005435785256	27300	Economy	12700.00
0005435785079	27300	Economy	12700.00
0005435784991	27300	Economy	12700.00
0005435785164	27300	Economy	12700.00
0005435785198	27300	Economy	12700.00
0005435785160	27300	Economy	12700.00
0005435787352	27300	Economy	12700.00
0005435785068	27300	Economy	12700.00
0005434993986	27300	Economy	12700.00
0005435785232	27300	Economy	12700.00
0005435785030	27300	Economy	12700.00
0005434994035	27300	Economy	12700.00
0005435785197	27300	Economy	12700.00
0005434994029	27300	Economy	12700.00
0005435785072	27300	Economy	12700.00
0005435785163	27300	Economy	12700.00
0005435785174	27300	Economy	12700.00
0005435918684	27300	Economy	12700.00
0005435785154	27300	Economy	12700.00
0005435785155	27300	Economy	12700.00
0005435785186	27300	Economy	12700.00
0005435937400	27300	Economy	12700.00
0005435785139	27300	Economy	12700.00
0005435785140	27300	Economy	12700.00
0005435787327	27300	Economy	12700.00
0005435785073	27300	Economy	12700.00
0005434994034	27300	Economy	12700.00
0005434993987	27300	Economy	12700.00
0005435785080	27300	Economy	12700.00
0005435785266	27300	Economy	12700.00
0005435785235	27300	Economy	12700.00
0005435785069	27300	Economy	12700.00
0005435785165	27300	Economy	12700.00
0005432195704	27300	Economy	12700.00
0005435937401	27300	Economy	12700.00
0005432146211	19864	Economy	12800.00
0005432146210	19864	Economy	12800.00
0005432146209	19864	Economy	12800.00
0005432460132	4741	Business	40900.00
0005432460139	4741	Business	40900.00
0005432460157	4741	Business	40900.00
0005432460136	4741	Business	40900.00
0005432170427	4741	Business	40900.00
0005432567999	4741	Business	40900.00
0005432568020	4741	Business	40900.00
0005432460180	4741	Business	40900.00
0005434082054	4741	Business	40900.00
0005432460164	4741	Business	40900.00
0005432567998	4741	Business	40900.00
0005432460166	4741	Business	40900.00
0005432567976	4741	Business	40900.00
0005432460175	4741	Business	40900.00
0005432568019	4741	Business	40900.00
0005432567970	4741	Business	40900.00
0005432170430	4741	Business	40900.00
0005432460150	4741	Business	40900.00
0005434082048	4741	Business	40900.00
0005432567983	4741	Business	40900.00
0005434082042	4741	Business	40900.00
0005432567995	4741	Economy	15000.00
0005432460171	4741	Economy	15000.00
0005432460142	4741	Economy	15000.00
0005432170425	4741	Economy	13600.00
0005432460168	4741	Economy	13600.00
0005432567985	4741	Economy	13600.00
0005432567984	4741	Economy	13600.00
0005432568024	4741	Economy	13600.00
0005434082041	4741	Economy	13600.00
0005432567987	4741	Economy	13600.00
0005432460153	4741	Economy	13600.00
0005432567967	4741	Economy	13600.00
0005433452751	4741	Economy	13600.00
0005432568001	4741	Economy	13600.00
0005432460134	4741	Economy	13600.00
0005432460184	4741	Economy	13600.00
0005435840359	4741	Economy	13600.00
0005432460143	4741	Economy	13600.00
0005434082058	4741	Economy	13600.00
0005432460178	4741	Economy	13600.00
0005432568006	4741	Economy	13600.00
0005432460146	4741	Economy	13600.00
0005432186892	4741	Economy	13600.00
0005432568003	4741	Economy	13600.00
0005432170428	4741	Economy	13600.00
0005434082039	4741	Economy	13600.00
0005432567992	4741	Economy	13600.00
0005432460182	4741	Economy	13600.00
0005432568012	4741	Economy	13600.00
0005432460154	4741	Economy	13600.00
0005434082052	4741	Economy	13600.00
0005432460137	4741	Economy	13600.00
0005432568015	4741	Economy	13600.00
0005432460149	4741	Economy	13600.00
0005432567971	4741	Economy	13600.00
0005434082050	4741	Economy	13600.00
0005432567966	4741	Economy	13600.00
0005432567978	4741	Economy	13600.00
0005433452752	4741	Economy	13600.00
0005434082055	4741	Economy	13600.00
0005432567979	4741	Economy	13600.00
0005432460140	4741	Economy	13600.00
0005432567980	4741	Economy	13600.00
0005432571342	4741	Economy	13600.00
0005432460148	4741	Economy	13600.00
0005432567982	4741	Economy	13600.00
0005434082046	4741	Economy	13600.00
0005432568022	4741	Economy	13600.00
0005432460152	4741	Economy	13600.00
0005432567991	4741	Economy	13600.00
0005432460172	4741	Economy	13600.00
0005432567988	4741	Economy	13600.00
0005432460167	4741	Economy	13600.00
0005432568026	4741	Economy	13600.00
0005434082035	4741	Economy	13600.00
0005434082056	4741	Economy	13600.00
0005432567994	4741	Economy	13600.00
0005432571345	4741	Economy	13600.00
0005433726117	4741	Economy	13600.00
0005432460155	4741	Economy	13600.00
0005432571344	4741	Economy	13600.00
0005432567972	4741	Economy	13600.00
0005432567990	4741	Economy	13600.00
0005432460135	4741	Economy	13600.00
0005432567997	4741	Economy	13600.00
0005432460133	4741	Economy	13600.00
0005432568013	4741	Economy	13600.00
0005432170424	4741	Economy	13600.00
0005432567964	4741	Economy	13600.00
0005432460169	4741	Economy	13600.00
0005432460170	4741	Economy	13600.00
0005432460179	4741	Economy	13600.00
0005432567969	4741	Economy	13600.00
0005432460160	4741	Economy	13600.00
0005434082040	4741	Economy	13600.00
0005434082044	4741	Economy	13600.00
0005432568025	4741	Economy	13600.00
0005432568010	4741	Economy	13600.00
0005432460177	4741	Economy	13600.00
0005433451632	4741	Economy	15000.00
0005432568007	4741	Economy	13600.00
0005432170429	4741	Economy	13600.00
0005434082043	4741	Economy	15000.00
0005432567974	4741	Economy	15000.00
0005432460144	4741	Economy	13600.00
0005434082045	4741	Economy	13600.00
0005432567986	4741	Economy	13600.00
0005432186893	4741	Economy	13600.00
0005432460145	4741	Economy	13600.00
0005434082057	4741	Economy	13600.00
0005432568014	4741	Economy	13600.00
0005432567989	4741	Economy	13600.00
0005432460159	4741	Economy	13600.00
0005432460162	4741	Economy	13600.00
0005432460174	4741	Economy	13600.00
0005432460163	4741	Economy	13600.00
0005432567977	4741	Economy	13600.00
0005434082047	4741	Economy	13600.00
0005432460181	4741	Economy	13600.00
0005434082037	4741	Economy	13600.00
0005432567965	4741	Economy	13600.00
0005432568009	4741	Economy	13600.00
0005432568011	4741	Economy	13600.00
0005432568002	4741	Economy	13600.00
0005433726118	4741	Economy	13600.00
0005432567996	4741	Economy	13600.00
0005432567973	4741	Economy	13600.00
0005432460161	4741	Economy	13600.00
0005434082038	4741	Economy	13600.00
0005432460156	4741	Economy	13600.00
0005433451631	4741	Economy	13600.00
0005432460183	4741	Economy	13600.00
0005432567981	4741	Economy	13600.00
0005432567993	4741	Economy	13600.00
0005432170426	4741	Economy	13600.00
0005434082053	4741	Economy	13600.00
0005432568016	4741	Economy	13600.00
0005432460176	4741	Economy	13600.00
0005432460173	4741	Economy	13600.00
0005432571343	4741	Economy	13600.00
0005432567975	4741	Economy	13600.00
0005432568005	4741	Economy	13600.00
0005432568004	4741	Economy	13600.00
0005434082036	4741	Economy	13600.00
0005434082049	4741	Economy	13600.00
0005432460138	4741	Economy	13600.00
0005432568023	4741	Economy	13600.00
0005432568021	4741	Economy	13600.00
0005432460141	4741	Economy	13600.00
0005432568008	4741	Economy	13600.00
0005432568000	4741	Economy	13600.00
0005432460165	4741	Economy	13600.00
0005432460158	4741	Economy	13600.00
0005432568018	4741	Economy	13600.00
0005432568017	4741	Economy	13600.00
0005432567968	4741	Economy	13600.00
0005434082051	4741	Economy	13600.00
0005432460151	4741	Economy	13600.00
0005432460147	4741	Economy	13600.00
0005432568027	4741	Economy	13600.00
0005434082034	4741	Economy	13600.00
0005432459873	30537	Business	40900.00
0005433726082	30537	Business	40900.00
0005433452734	30537	Business	40900.00
0005432459688	30537	Business	40900.00
0005432459493	30537	Business	40900.00
0005432567487	30537	Business	40900.00
0005432459777	30537	Business	40900.00
0005432567531	30537	Business	40900.00
0005432459516	30537	Business	40900.00
0005432567620	30537	Business	40900.00
0005432459611	30537	Business	40900.00
0005433726083	30537	Business	40900.00
0005432567572	30537	Business	40900.00
0005433726078	30537	Business	40900.00
0005432567434	30537	Business	40900.00
0005432567344	30537	Business	40900.00
0005432459763	30537	Business	40900.00
0005432459594	30537	Business	40900.00
0005433726092	30537	Business	40900.00
0005433726077	30537	Business	40900.00
0005434081904	30537	Business	40900.00
0005432459919	30537	Business	40900.00
0005432460072	30537	Business	40900.00
0005432459807	30537	Economy	15000.00
0005432571309	30537	Business	40900.00
0005432459874	30537	Economy	15000.00
0005434081861	30537	Economy	15000.00
0005432567245	30537	Economy	15000.00
0005432567686	30537	Economy	13600.00
0005432161165	30537	Economy	13600.00
0005432459660	30537	Economy	13600.00
0005432567404	30537	Economy	13600.00
0005434081913	30537	Economy	13600.00
0005432567629	30537	Economy	13600.00
0005432213627	30537	Economy	13600.00
0005432567463	30537	Economy	13600.00
0005432459610	30537	Economy	13600.00
0005432459750	30537	Economy	13600.00
0005432459894	30537	Economy	13600.00
0005433454872	30537	Economy	13600.00
0005433726089	30537	Economy	13600.00
0005434081860	30537	Economy	13600.00
0005432459766	30537	Economy	13600.00
0005432459920	30537	Economy	13600.00
0005434081806	30537	Economy	13600.00
0005434081754	30537	Economy	13600.00
0005432567627	30537	Economy	13600.00
0005432459547	30537	Economy	13600.00
0005433726084	30537	Economy	13600.00
0005432459867	30537	Economy	13600.00
0005432459548	30537	Economy	13600.00
0005432567635	30537	Economy	13600.00
0005432567707	30537	Economy	13600.00
0005432460121	30537	Economy	13600.00
0005432567514	30537	Economy	13600.00
0005432567641	30537	Economy	13600.00
0005432571323	30537	Economy	13600.00
0005433726064	30537	Economy	13600.00
0005432567298	30537	Economy	13600.00
0005432567642	30537	Economy	13600.00
0005432459981	30537	Economy	13600.00
0005432571322	30537	Economy	13600.00
0005434081894	30537	Economy	13600.00
0005432459780	30537	Economy	13600.00
0005432567405	30537	Economy	13600.00
0005433726087	30537	Economy	13600.00
0005432567658	30537	Economy	13600.00
0005432567489	30537	Economy	13600.00
0005432459980	30537	Economy	13600.00
0005432567528	30537	Economy	13600.00
0005434081839	30537	Economy	13600.00
0005432567461	30537	Economy	13600.00
0005432161166	30537	Economy	13600.00
0005432567346	30537	Economy	13600.00
0005432571329	30537	Economy	13600.00
0005432459754	30537	Economy	13600.00
0005434081914	30537	Economy	13600.00
0005432567306	30537	Economy	13600.00
0005432571312	30537	Economy	13600.00
0005432571324	30537	Economy	13600.00
0005432459982	30537	Economy	13600.00
0005432567698	30537	Economy	13600.00
0005432567165	30537	Economy	13600.00
0005434081892	30537	Economy	13600.00
0005434081926	30537	Economy	13600.00
0005433452736	30537	Economy	13600.00
0005432571315	30537	Economy	13600.00
0005432567659	30537	Economy	13600.00
0005432567241	30537	Economy	13600.00
0005432459741	30537	Economy	13600.00
0005432459685	30537	Economy	13600.00
0005432567697	30537	Economy	13600.00
0005432459684	30537	Economy	13600.00
0005432459806	30537	Economy	13600.00
0005433452733	30537	Economy	13600.00
0005432459492	30537	Economy	13600.00
0005432567541	30537	Economy	13600.00
0005432459623	30537	Economy	13600.00
0005432459762	30537	Economy	13600.00
0005432567626	30537	Economy	13600.00
0005432567807	30537	Economy	13600.00
0005432459941	30537	Economy	13600.00
0005432567530	30537	Economy	13600.00
0005432571314	30537	Economy	13600.00
0005432459725	30537	Economy	13600.00
0005434081771	30537	Economy	13600.00
0005432567644	30537	Economy	13600.00
0005432459689	30537	Economy	13600.00
0005432213630	30537	Economy	13600.00
0005433726075	30537	Economy	13600.00
0005432567630	30537	Economy	13600.00
0005432567353	30537	Economy	13600.00
0005432567623	30537	Economy	13600.00
0005432459292	30537	Economy	13600.00
0005434081901	30537	Economy	15000.00
0005432459546	30537	Economy	15000.00
0005432567654	30537	Economy	13600.00
0005434081731	30537	Economy	15000.00
0005434081755	30537	Economy	15000.00
0005432459612	30537	Economy	13600.00
0005433726081	30537	Economy	13600.00
0005432459897	30537	Economy	13600.00
0005432567297	30537	Economy	13600.00
0005432567624	30537	Economy	13600.00
0005432459888	30537	Economy	13600.00
0005432459661	30537	Economy	13600.00
0005432567708	30537	Economy	13600.00
0005432567462	30537	Economy	13600.00
0005432459617	30537	Economy	13600.00
0005432567437	30537	Economy	13600.00
0005433726065	30537	Economy	13600.00
0005433726085	30537	Economy	13600.00
0005432571330	30537	Economy	13600.00
0005432567486	30537	Economy	13600.00
0005434081835	30537	Economy	13600.00
0005432459837	30537	Economy	13600.00
0005432567801	30537	Economy	13600.00
0005432567403	30537	Economy	13600.00
0005432459727	30537	Economy	13600.00
0005432213628	30537	Economy	13600.00
0005432567402	30537	Economy	13600.00
0005432459726	30537	Economy	13600.00
0005432459850	30537	Economy	13600.00
0005434081854	30537	Economy	13600.00
0005432567643	30537	Economy	13600.00
0005433726080	30537	Economy	13600.00
0005432459805	30537	Economy	13600.00
0005432567705	30537	Economy	13600.00
0005434081810	30537	Economy	13600.00
0005433726090	30537	Economy	13600.00
0005434081732	30537	Economy	13600.00
0005433726074	30537	Economy	13600.00
0005432567471	30537	Economy	13600.00
0005432459629	30537	Economy	13600.00
0005434081859	30537	Economy	13600.00
0005434081768	30537	Economy	13600.00
0005432459598	30537	Economy	13600.00
0005433726091	30537	Economy	13600.00
0005432460071	30537	Economy	13600.00
0005432459622	30537	Economy	13600.00
0005432459597	30537	Economy	13600.00
0005432459851	30537	Economy	13600.00
0005434081893	30537	Economy	13600.00
0005432459613	30537	Economy	13600.00
0005432213629	30537	Economy	13600.00
0005433726073	30537	Economy	13600.00
0005433452737	30537	Economy	13600.00
0005432459742	30537	Economy	13600.00
0005432459690	30537	Economy	13600.00
0005432567704	30537	Economy	13600.00
0005432459735	30537	Economy	13600.00
0005432567638	30537	Economy	13600.00
0005432459804	30537	Economy	13600.00
0005434081753	30537	Economy	13600.00
0005433454871	30537	Economy	13600.00
0005432567583	30537	Economy	13600.00
0005432567694	30537	Economy	13600.00
0005432567513	30537	Economy	13600.00
0005434081798	30537	Economy	13600.00
0005432571313	30537	Economy	13600.00
0005432567665	30537	Economy	13600.00
0005432459721	30537	Economy	13600.00
0005433726088	30537	Economy	13600.00
0005435722070	13579	Economy	9900.00
0005435722071	13579	Economy	9900.00
0005435720827	13579	Economy	9900.00
0005435722068	13579	Economy	9900.00
0005435720828	13579	Economy	9900.00
0005435722069	13579	Economy	9900.00
0005435722042	21167	Economy	9900.00
0005435722040	21167	Economy	9900.00
0005435722047	21167	Economy	9900.00
0005435722041	21167	Economy	9900.00
0005432295894	22803	Economy	8800.00
0005432295896	22803	Economy	8800.00
0005432295895	22803	Economy	8800.00
0005433343814	11102	Business	23600.00
0005435508309	11102	Business	23600.00
0005433343784	11102	Business	23600.00
0005433343721	11102	Business	23600.00
0005433343746	11102	Business	23600.00
0005433343724	11102	Business	23600.00
0005433343769	11102	Business	23600.00
0005433343728	11102	Business	23600.00
0005435097255	11102	Business	23600.00
0005433343767	11102	Business	23600.00
0005433343795	11102	Business	23600.00
0005433343790	11102	Business	23600.00
0005435380287	11102	Economy	7900.00
0005433343749	11102	Economy	7900.00
0005433343766	11102	Economy	7900.00
0005433343729	11102	Economy	7900.00
0005435508368	11102	Economy	7900.00
0005435508375	11102	Economy	7900.00
0005433343802	11102	Economy	7900.00
0005435097251	11102	Economy	7900.00
0005433343738	11102	Economy	7900.00
0005433343781	11102	Economy	7900.00
0005435508328	11102	Economy	7900.00
0005435097254	11102	Economy	7900.00
0005433343740	11102	Economy	7900.00
0005433343754	11102	Economy	7900.00
0005433343780	11102	Economy	7900.00
0005433343725	11102	Economy	7900.00
0005433343778	11102	Economy	7900.00
0005433343806	11102	Economy	7900.00
0005433343745	11102	Economy	7900.00
0005433343756	11102	Economy	7900.00
0005435508287	11102	Economy	7900.00
0005435097256	11102	Economy	7900.00
0005433343811	11102	Economy	7900.00
0005433343751	11102	Economy	7900.00
0005435508327	11102	Economy	7900.00
0005433343750	11102	Economy	7900.00
0005433343747	11102	Economy	7900.00
0005433343819	11102	Economy	7900.00
0005433343762	11102	Economy	7900.00
0005433343775	11102	Economy	7900.00
0005433343785	11102	Economy	7900.00
0005433343768	11102	Economy	7900.00
0005433343748	11102	Economy	7900.00
0005433343757	11102	Economy	7900.00
0005435097249	11102	Economy	7900.00
0005433343777	11102	Economy	7900.00
0005433343772	11102	Economy	7900.00
0005433343799	11102	Economy	7900.00
0005435508270	11102	Economy	7900.00
0005433343759	11102	Economy	7900.00
0005433343739	11102	Economy	8600.00
0005435508393	11102	Economy	8600.00
0005433343719	11102	Economy	8600.00
0005433343718	11102	Economy	8600.00
0005433343755	11102	Economy	8600.00
0005433343737	11102	Economy	8600.00
0005433343764	11102	Economy	7900.00
0005433343760	11102	Economy	7900.00
0005433343731	11102	Economy	7900.00
0005435529973	11102	Economy	7900.00
0005433343741	11102	Economy	7900.00
0005435508360	11102	Economy	7900.00
0005435097250	11102	Economy	7900.00
0005435097248	11102	Economy	7900.00
0005433343722	11102	Economy	7900.00
0005433343786	11102	Economy	7900.00
0005435380286	11102	Economy	7900.00
0005433343770	11102	Economy	7900.00
0005435508312	11102	Economy	7900.00
0005435097253	11102	Economy	7900.00
0005433343773	11102	Economy	7900.00
0005433343817	11102	Economy	7900.00
0005435508367	11102	Economy	7900.00
0005433343818	11102	Economy	7900.00
0005433343776	11102	Economy	7900.00
0005433343720	11102	Economy	7900.00
0005433343742	11102	Economy	7900.00
0005433343804	11102	Economy	7900.00
0005433343789	11102	Economy	7900.00
0005433343812	11102	Economy	7900.00
0005433343793	11102	Economy	7900.00
0005433343753	11102	Economy	7900.00
0005433343810	11102	Economy	7900.00
0005433343761	11102	Economy	7900.00
0005433343774	11102	Economy	7900.00
0005433343743	11102	Economy	7900.00
0005433343726	11102	Economy	7900.00
0005433343808	11102	Economy	7900.00
0005433343813	11102	Economy	7900.00
0005433343800	11102	Economy	7900.00
0005433343797	11102	Economy	7900.00
0005433343732	11102	Economy	7900.00
0005433343783	11102	Economy	7900.00
0005433343730	11102	Economy	7900.00
0005433343792	11102	Economy	7900.00
0005433343733	11102	Economy	7900.00
0005433343727	11102	Economy	7900.00
0005435508305	11102	Economy	7900.00
0005433343787	11102	Economy	7900.00
0005433343796	11102	Economy	7900.00
0005435508286	11102	Economy	7900.00
0005433343788	11102	Economy	7900.00
0005433343723	11102	Economy	7900.00
0005433343807	11102	Economy	7900.00
0005433343736	11102	Economy	7900.00
0005435097252	11102	Economy	7900.00
0005433343765	11102	Economy	7900.00
0005433343744	11102	Economy	7900.00
0005433343782	11102	Economy	7900.00
0005433343734	11102	Economy	7900.00
0005433343779	11102	Economy	7900.00
0005433343815	11102	Economy	7900.00
0005433343798	11102	Economy	7900.00
0005433343758	11102	Economy	7900.00
0005433343791	11102	Economy	7900.00
0005435508392	11102	Economy	7900.00
0005433343805	11102	Economy	7900.00
0005433343794	11102	Economy	7900.00
0005433343771	11102	Economy	7900.00
0005433343735	11102	Economy	7900.00
0005435097247	11102	Economy	7900.00
0005433343816	11102	Economy	7900.00
0005433343803	11102	Economy	7900.00
0005433343763	11102	Economy	7900.00
0005433343809	11102	Economy	7900.00
0005433343801	11102	Economy	7900.00
0005435508325	11102	Economy	7900.00
0005433343752	11102	Economy	7900.00
0005433342454	17109	Business	23600.00
0005433342875	17109	Business	23600.00
0005435545790	17109	Business	23600.00
0005435545785	17109	Business	23600.00
0005433342498	17109	Business	23600.00
0005433342598	17109	Business	23600.00
0005433342367	17109	Business	23600.00
0005433343035	17109	Business	23600.00
0005435097155	17109	Business	23600.00
0005433342829	17109	Business	23600.00
0005433342890	17109	Business	23600.00
0005433342789	17109	Economy	7900.00
0005433342658	17109	Business	23600.00
0005435545787	17109	Economy	7900.00
0005435545789	17109	Economy	7900.00
0005433342860	17109	Economy	7900.00
0005433342689	17109	Economy	7900.00
0005433342842	17109	Economy	7900.00
0005433342661	17109	Economy	7900.00
0005433342982	17109	Economy	7900.00
0005433343162	17109	Economy	7900.00
0005433342913	17109	Economy	7900.00
0005433342912	17109	Economy	7900.00
0005433342585	17109	Economy	7900.00
0005433342844	17109	Economy	7900.00
0005435380327	17109	Economy	7900.00
0005433343022	17109	Economy	7900.00
0005433342536	17109	Economy	7900.00
0005433342793	17109	Economy	7900.00
0005435380325	17109	Economy	7900.00
0005433342750	17109	Economy	7900.00
0005433342962	17109	Economy	7900.00
0005433342883	17109	Economy	7900.00
0005435097180	17109	Economy	7900.00
0005433342688	17109	Economy	7900.00
0005433342784	17109	Economy	7900.00
0005433343066	17109	Economy	7900.00
0005433343102	17109	Economy	7900.00
0005435097154	17109	Economy	7900.00
0005433342670	17109	Economy	7900.00
0005433343093	17109	Economy	7900.00
0005433342957	17109	Economy	7900.00
0005435097152	17109	Economy	7900.00
0005433343295	17109	Economy	7900.00
0005433342307	17109	Economy	7900.00
0005433342408	17109	Economy	7900.00
0005433342861	17109	Economy	7900.00
0005433342465	17109	Economy	7900.00
0005433342922	17109	Economy	7900.00
0005435380326	17109	Economy	7900.00
0005433342427	17109	Economy	7900.00
0005433343015	17109	Economy	7900.00
0005432293224	17109	Economy	8600.00
0005433342819	17109	Economy	8600.00
0005433342817	17109	Economy	8600.00
0005433342646	17109	Economy	8600.00
0005433342956	17109	Economy	8600.00
0005433342788	17109	Economy	8600.00
0005433343045	17109	Economy	7900.00
0005433342556	17109	Economy	7900.00
0005435545786	17109	Economy	7900.00
0005433342862	17109	Economy	7900.00
0005433342605	17109	Economy	7900.00
0005433342975	17109	Economy	7900.00
0005433342225	17109	Economy	7900.00
0005433342786	17109	Economy	7900.00
0005433342954	17109	Economy	7900.00
0005433342572	17109	Economy	7900.00
0005433342813	17109	Economy	7900.00
0005433342816	17109	Economy	7900.00
0005432293222	17109	Economy	7900.00
0005433342623	17109	Economy	7900.00
0005433342854	17109	Economy	7900.00
0005433342436	17109	Economy	7900.00
0005433342655	17109	Economy	7900.00
0005433342555	17109	Economy	7900.00
0005433342863	17109	Economy	7900.00
0005433342573	17109	Economy	7900.00
0005433343274	17109	Economy	7900.00
0005435097158	17109	Economy	7900.00
0005433342908	17109	Economy	7900.00
0005433342505	17109	Economy	7900.00
0005433343157	17109	Economy	7900.00
0005435097156	17109	Economy	7900.00
0005433342571	17109	Economy	7900.00
0005433343138	17109	Economy	7900.00
0005433342608	17109	Economy	7900.00
0005433342437	17109	Economy	7900.00
0005433342974	17109	Economy	7900.00
0005433343004	17109	Economy	7900.00
0005435380323	17109	Economy	7900.00
0005433343103	17109	Economy	7900.00
0005433343044	17109	Economy	7900.00
0005433342936	17109	Economy	7900.00
0005433343059	17109	Economy	7900.00
0005433342941	17109	Economy	7900.00
0005433343021	17109	Economy	7900.00
0005433342909	17109	Economy	7900.00
0005433343181	17109	Economy	7900.00
0005433342537	17109	Economy	7900.00
0005433342746	17109	Economy	7900.00
0005432293223	17109	Economy	7900.00
0005433342516	17109	Economy	7900.00
0005433342864	17109	Economy	7900.00
0005433342409	17109	Economy	7900.00
0005433342574	17109	Economy	7900.00
0005435545788	17109	Economy	7900.00
0005433342569	17109	Economy	7900.00
0005433343025	17109	Economy	7900.00
0005433342428	17109	Economy	7900.00
0005433342368	17109	Economy	7900.00
0005433342938	17109	Economy	7900.00
0005433342649	17109	Economy	7900.00
0005433342815	17109	Economy	7900.00
0005433342606	17109	Economy	7900.00
0005433342818	17109	Economy	7900.00
0005433342935	17109	Economy	7900.00
0005433342687	17109	Economy	7900.00
0005433343017	17109	Economy	7900.00
0005433342607	17109	Economy	7900.00
0005433342592	17109	Economy	7900.00
0005433342843	17109	Economy	7900.00
0005435545791	17109	Economy	7900.00
0005433342973	17109	Economy	7900.00
0005433343154	17109	Economy	7900.00
0005433342950	17109	Economy	7900.00
0005433342719	17109	Economy	7900.00
0005435380324	17109	Economy	7900.00
0005433342417	17109	Economy	7900.00
0005433507297	9090	Business	26600.00
0005433481214	9090	Business	26600.00
0005433481216	9090	Business	26600.00
0005432919808	9090	Business	26600.00
0005433481213	9090	Business	26600.00
0005433507295	9090	Business	26600.00
0005433481215	9090	Business	26600.00
0005433507294	9090	Business	26600.00
0005432919773	9090	Economy	8900.00
0005432919813	9090	Economy	8900.00
0005432919754	9090	Economy	8900.00
0005434158981	9090	Economy	8900.00
0005433507287	9090	Economy	8900.00
0005432919869	9090	Economy	8900.00
0005433507300	9090	Economy	9800.00
0005433481211	9090	Economy	9800.00
0005433481212	9090	Economy	8900.00
0005433507292	9090	Economy	8900.00
0005432919874	9090	Economy	8900.00
0005433507299	9090	Economy	8900.00
0005432919868	9090	Economy	8900.00
0005432919772	9090	Economy	8900.00
0005432919793	9090	Economy	8900.00
0005433507290	9090	Economy	8900.00
0005432919760	9090	Economy	8900.00
0005433507298	9090	Economy	8900.00
0005432919768	9090	Economy	8900.00
0005433507301	9090	Economy	8900.00
0005432919755	9090	Economy	8900.00
0005432919858	9090	Economy	8900.00
0005433507288	9090	Economy	8900.00
0005432919770	9090	Economy	8900.00
0005432919757	9090	Economy	8900.00
0005433481217	9090	Economy	8900.00
0005432919857	9090	Economy	8900.00
0005432919799	9090	Economy	8900.00
0005434158968	9090	Economy	8900.00
0005432919763	9090	Economy	8900.00
0005433507293	9090	Economy	8900.00
0005434158982	9090	Economy	8900.00
0005433507296	9090	Economy	8900.00
0005432919800	9090	Economy	8900.00
0005433507291	9090	Economy	8900.00
0005433507289	9090	Economy	8900.00
0005434158970	9090	Economy	8900.00
0005432919776	9090	Economy	8900.00
0005432919758	9090	Economy	8900.00
0005432920010	20442	Business	26600.00
0005433507135	20442	Business	26600.00
0005433507128	20442	Business	26600.00
0005433481122	20442	Business	26600.00
0005433507159	20442	Business	26600.00
0005433507139	20442	Business	26600.00
0005433507088	20442	Business	26600.00
0005432920005	20442	Economy	8900.00
0005433481139	20442	Economy	8900.00
0005432920013	20442	Economy	8900.00
0005432920001	20442	Economy	9800.00
0005433507155	20442	Economy	9800.00
0005432920014	20442	Economy	9800.00
0005433481161	20442	Economy	8900.00
0005433507142	20442	Economy	8900.00
0005432920002	20442	Economy	8900.00
0005432919999	20442	Economy	8900.00
0005433507160	20442	Economy	8900.00
0005432920016	20442	Economy	8900.00
0005433507136	20442	Economy	8900.00
0005433481145	20442	Economy	8900.00
0005433507140	20442	Economy	8900.00
0005433507175	20442	Economy	8900.00
0005433481146	20442	Economy	8900.00
0005433507162	20442	Economy	8900.00
0005433507146	20442	Economy	8900.00
0005433507043	20442	Economy	8900.00
0005433507154	20442	Economy	8900.00
0005433481160	20442	Economy	8900.00
0005432920015	20442	Economy	8900.00
0005433481138	20442	Economy	8900.00
0005433507064	20442	Economy	8900.00
0005432920000	20442	Economy	8900.00
0005432920009	20442	Economy	8900.00
0005432919998	20442	Economy	8900.00
0005432920007	20442	Economy	8900.00
0005433481176	20442	Economy	8900.00
0005432920003	20442	Economy	8900.00
0005433481198	20442	Economy	8900.00
0005433507141	20442	Economy	8900.00
0005432919997	20442	Economy	8900.00
0005433507158	20442	Economy	8900.00
0005432920006	20442	Economy	8900.00
0005432920008	20442	Economy	8900.00
0005433507147	20442	Economy	8900.00
0005432919996	20442	Economy	8900.00
0005433507145	20442	Economy	8900.00
0005432920011	20442	Economy	8900.00
0005433507165	20442	Economy	8900.00
0005433507153	20442	Economy	8900.00
0005432920012	20442	Economy	8900.00
0005432920004	20442	Economy	8900.00
0005433507095	20442	Economy	8900.00
0005435179689	10148	Economy	5800.00
0005432394125	10148	Economy	5800.00
0005432396264	10148	Economy	5800.00
0005432394126	10148	Economy	5800.00
0005432396265	10148	Economy	5800.00
0005432396262	10148	Economy	5800.00
0005432396263	10148	Economy	5800.00
0005432394124	10148	Economy	5800.00
0005435178990	10148	Economy	5800.00
0005432394127	10148	Economy	5800.00
0005432396266	10148	Economy	5800.00
0005432396225	18387	Economy	5800.00
0005432396231	18387	Economy	5800.00
0005432396224	18387	Economy	5800.00
0005432400117	18387	Economy	5800.00
0005435179699	18387	Economy	5800.00
0005432396236	18387	Economy	5800.00
0005435179698	18387	Economy	5800.00
0005435179399	18387	Economy	5800.00
0005432396233	18387	Economy	5800.00
0005432396248	18387	Economy	5800.00
0005435126329	10942	Business	9500.00
0005435126139	10942	Business	9500.00
0005435126279	10942	Business	9500.00
0005435126121	10942	Business	9500.00
0005435126087	10942	Business	9500.00
0005434411805	10942	Business	9500.00
0005435126309	10942	Business	9500.00
0005435126129	10942	Business	9500.00
0005435126261	10942	Business	9500.00
0005435554179	10942	Economy	3200.00
0005435126328	10942	Economy	3200.00
0005434411804	10942	Economy	3200.00
0005435626108	10942	Economy	3200.00
0005435126273	10942	Economy	3200.00
0005435126164	10942	Economy	3200.00
0005435626097	10942	Economy	3200.00
0005435126260	10942	Economy	3200.00
0005435126165	10942	Economy	3200.00
0005435126378	10942	Economy	3500.00
0005435126287	10942	Economy	3500.00
0005435126023	10942	Economy	3500.00
0005435556685	10942	Economy	3500.00
0005435126179	10942	Economy	3200.00
0005435126345	10942	Economy	3200.00
0005435626096	10942	Economy	3200.00
0005435126304	10942	Economy	3200.00
0005434928316	10942	Economy	3200.00
0005435126338	10942	Economy	3200.00
0005435126263	10942	Economy	3200.00
0005435126211	10942	Economy	3200.00
0005435126439	10942	Economy	3200.00
0005434411806	10942	Economy	3200.00
0005435126150	10942	Economy	3200.00
0005435126418	10942	Economy	3200.00
0005435626045	10942	Economy	3200.00
0005435126344	10942	Economy	3200.00
0005435126402	10942	Economy	3200.00
0005434928317	10942	Economy	3200.00
0005435126163	10942	Economy	3200.00
0005435126282	10942	Economy	3200.00
0005435126377	10942	Economy	3200.00
0005435126218	10942	Economy	3200.00
0005435126262	10942	Economy	3200.00
0005435126024	10942	Economy	3200.00
0005435126202	10942	Economy	3200.00
0005435126390	10942	Economy	3200.00
0005435126086	10942	Economy	3200.00
0005435126248	10942	Economy	3200.00
0005435125936	10942	Economy	3200.00
0005435126296	10942	Economy	3200.00
0005435126224	10942	Economy	3200.00
0005435126122	10942	Economy	3200.00
0005435556684	10942	Economy	3200.00
0005435126305	10942	Economy	3200.00
0005435126186	10942	Economy	3200.00
0005435126308	10942	Economy	3200.00
0005435626107	10942	Economy	3200.00
0005435126203	10942	Economy	3200.00
0005435626079	10942	Economy	3200.00
0005434928318	10942	Economy	3200.00
0005435626133	10942	Economy	3200.00
0005435126130	10942	Economy	3200.00
0005435626137	10942	Economy	3200.00
0005435126323	10942	Economy	3200.00
0005435126170	10942	Economy	3200.00
0005435126403	10942	Economy	3200.00
0005435126343	10942	Economy	3200.00
0005435556687	10942	Economy	3200.00
0005435556686	10942	Economy	3200.00
0005435126627	14723	Business	9500.00
0005435126621	14723	Business	9500.00
0005435626300	14723	Business	9500.00
0005435126609	14723	Business	9500.00
0005435126624	14723	Business	9500.00
0005435126636	14723	Business	9500.00
0005435626291	14723	Business	9500.00
0005435126605	14723	Business	9500.00
0005435626290	14723	Business	9500.00
0005435126637	14723	Business	9500.00
0005435126631	14723	Business	9500.00
0005435126618	14723	Economy	3200.00
0005435126626	14723	Economy	3200.00
0005435554213	14723	Economy	3200.00
0005435126606	14723	Economy	3200.00
0005435126633	14723	Economy	3200.00
0005435126622	14723	Economy	3200.00
0005435126615	14723	Economy	3200.00
0005435126629	14723	Economy	3200.00
0005435626297	14723	Economy	3200.00
0005435626287	14723	Economy	3500.00
0005435626288	14723	Economy	3500.00
0005435626303	14723	Economy	3500.00
0005435126644	14723	Economy	3500.00
0005435126611	14723	Economy	3200.00
0005435126620	14723	Economy	3200.00
0005435126639	14723	Economy	3200.00
0005435126616	14723	Economy	3200.00
0005435626305	14723	Economy	3200.00
0005435126612	14723	Economy	3200.00
0005435126623	14723	Economy	3200.00
0005435626295	14723	Economy	3200.00
0005435126625	14723	Economy	3200.00
0005435126613	14723	Economy	3200.00
0005435126632	14723	Economy	3200.00
0005435126628	14723	Economy	3200.00
0005434928300	14723	Economy	3200.00
0005435126640	14723	Economy	3200.00
0005435126610	14723	Economy	3200.00
0005435554216	14723	Economy	3200.00
0005434411765	14723	Economy	3200.00
0005435626301	14723	Economy	3200.00
0005435626302	14723	Economy	3200.00
0005435556707	14723	Economy	3200.00
0005435126617	14723	Economy	3200.00
0005435126638	14723	Economy	3200.00
0005435626296	14723	Economy	3200.00
0005435626292	14723	Economy	3200.00
0005435126614	14723	Economy	3200.00
0005435626293	14723	Economy	3200.00
0005435626294	14723	Economy	3200.00
0005434411747	14723	Economy	3200.00
0005435126607	14723	Economy	3200.00
0005435554214	14723	Economy	3200.00
0005434928288	14723	Economy	3200.00
0005435626304	14723	Economy	3200.00
0005435554217	14723	Economy	3200.00
0005435126645	14723	Economy	3200.00
0005435626299	14723	Economy	3200.00
0005435126635	14723	Economy	3200.00
0005435626289	14723	Economy	3200.00
0005435126608	14723	Economy	3200.00
0005435554212	14723	Economy	3200.00
0005435126642	14723	Economy	3200.00
0005435126619	14723	Economy	3200.00
0005435126641	14723	Economy	3200.00
0005435556709	14723	Economy	3200.00
0005435126630	14723	Economy	3200.00
0005435126634	14723	Economy	3200.00
0005435626298	14723	Economy	3200.00
0005435556708	14723	Economy	3200.00
0005435126643	14723	Economy	3200.00
0005435554215	14723	Economy	3200.00
0005435715565	7135	Business	86900.00
0005432398219	7135	Business	86900.00
0005435715570	7135	Business	86900.00
0005435715568	7135	Business	86900.00
0005432398220	7135	Business	86900.00
0005435715577	7135	Business	86900.00
0005435715575	7135	Business	86900.00
0005435715567	7135	Business	86900.00
0005435216572	7135	Business	86900.00
0005435443279	7135	Economy	29000.00
0005435715572	7135	Economy	29000.00
0005435443272	7135	Economy	29000.00
0005432400151	7135	Economy	29000.00
0005435715579	7135	Economy	29000.00
0005432400152	7135	Economy	29000.00
0005435715574	7135	Economy	31900.00
0005435715581	7135	Economy	29000.00
0005432400148	7135	Economy	29000.00
0005435715564	7135	Economy	29000.00
0005435715566	7135	Economy	29000.00
0005432400149	7135	Economy	29000.00
0005432398222	7135	Economy	29000.00
0005432400150	7135	Economy	29000.00
0005435219181	7135	Economy	29000.00
0005435443291	7135	Economy	29000.00
0005435443261	7135	Economy	29000.00
0005435715578	7135	Economy	29000.00
0005435715571	7135	Economy	29000.00
0005435715573	7135	Economy	29000.00
0005435178493	7135	Economy	29000.00
0005435443271	7135	Economy	29000.00
0005435221054	7135	Economy	29000.00
0005435216573	7135	Economy	29000.00
0005432398221	7135	Economy	29000.00
0005435715580	7135	Economy	29000.00
0005435715576	7135	Economy	29000.00
0005435443262	7135	Economy	29000.00
0005435715569	7135	Economy	29000.00
0005435443280	7135	Economy	29000.00
0005432400147	7135	Economy	29000.00
0005435443285	7135	Economy	29000.00
0005435443307	7135	Economy	29000.00
0005435443303	7135	Economy	29000.00
0005435443375	27049	Business	86900.00
0005435443366	27049	Business	86900.00
0005432398184	27049	Business	86900.00
0005435715397	27049	Business	86900.00
0005435715462	27049	Economy	29000.00
0005435715412	27049	Economy	29000.00
0005435715423	27049	Economy	29000.00
0005435715331	27049	Economy	31900.00
0005435715419	27049	Economy	31900.00
0005435443374	27049	Economy	31900.00
0005432394089	27049	Economy	29000.00
0005435443367	27049	Economy	29000.00
0005435443372	27049	Economy	29000.00
0005435443368	27049	Economy	29000.00
0005435715410	27049	Economy	29000.00
0005435715449	27049	Economy	29000.00
0005435443376	27049	Economy	29000.00
0005435715401	27049	Economy	29000.00
0005432398185	27049	Economy	29000.00
0005435715411	27049	Economy	29000.00
0005435443373	27049	Economy	29000.00
0005435178503	27049	Economy	29000.00
0005435715420	27049	Economy	29000.00
0005435715435	27049	Economy	29000.00
0005435715386	27049	Economy	29000.00
0005435443370	27049	Economy	29000.00
0005435715430	27049	Economy	29000.00
0005435443371	27049	Economy	29000.00
0005435715377	27049	Economy	29000.00
0005435715445	27049	Economy	29000.00
0005435178502	27049	Economy	29000.00
0005435715424	27049	Economy	29000.00
0005435715376	27049	Economy	29000.00
0005435443369	27049	Economy	29000.00
0005433060407	2720	Economy	7700.00
0005434084960	2720	Economy	7700.00
0005434084959	2720	Economy	7700.00
0005434084958	2720	Economy	7700.00
0005433060432	28469	Economy	7700.00
0005433060429	28469	Economy	7700.00
0005433060430	28469	Economy	7700.00
0005433060433	28469	Economy	7700.00
0005433060431	28469	Economy	7700.00
0005434084916	28469	Economy	7700.00
0005434084915	28469	Economy	7700.00
0005433060428	28469	Economy	7700.00
0005435541044	11399	Business	20200.00
0005435540963	11399	Business	20200.00
0005435540951	11399	Business	20200.00
0005435541009	11399	Business	20200.00
0005435540956	11399	Business	20200.00
0005435541010	11399	Business	20200.00
0005435517890	11399	Business	20200.00
0005435517851	11399	Economy	6700.00
0005435540971	11399	Economy	6700.00
0005435541045	11399	Economy	6700.00
0005435517792	11399	Economy	6700.00
0005435517912	11399	Economy	6700.00
0005435517869	11399	Economy	6700.00
0005435517918	11399	Economy	7400.00
0005435540873	11399	Economy	7400.00
0005435540950	11399	Economy	7400.00
0005435540996	11399	Economy	7400.00
0005435517844	11399	Economy	6700.00
0005435517898	11399	Economy	6700.00
0005435517921	11399	Economy	6700.00
0005435540970	11399	Economy	6700.00
0005435540907	11399	Economy	6700.00
0005435540906	11399	Economy	6700.00
0005435517893	11399	Economy	6700.00
0005435517891	11399	Economy	6700.00
0005435540957	11399	Economy	6700.00
0005435540839	11399	Economy	6700.00
0005435540838	11399	Economy	6700.00
0005435540914	11399	Economy	6700.00
0005435517957	11399	Economy	6700.00
0005435517922	11399	Economy	6700.00
0005435517904	11399	Economy	6700.00
0005435517846	11399	Economy	6700.00
0005435517913	11399	Economy	6700.00
0005435517845	11399	Economy	6700.00
0005435540936	11399	Economy	6700.00
0005435540980	11399	Economy	6700.00
0005435517829	11399	Economy	6700.00
0005435517828	11399	Economy	6700.00
0005435541061	11399	Economy	6700.00
0005435529377	22255	Business	20200.00
0005435541113	22255	Business	20200.00
0005435541123	22255	Business	20200.00
0005435529378	22255	Business	20200.00
0005435541118	22255	Business	20200.00
0005435529367	22255	Business	20200.00
0005435529379	22255	Business	20200.00
0005435541129	22255	Economy	6700.00
0005435541127	22255	Economy	6700.00
0005435529369	22255	Economy	6700.00
0005435529384	22255	Economy	7400.00
0005435541130	22255	Economy	7400.00
0005435529371	22255	Economy	7400.00
0005435529373	22255	Economy	6700.00
0005435541121	22255	Economy	6700.00
0005435541122	22255	Economy	6700.00
0005435529381	22255	Economy	6700.00
0005435529368	22255	Economy	6700.00
0005435541128	22255	Economy	6700.00
0005435541125	22255	Economy	6700.00
0005435529380	22255	Economy	6700.00
0005435529385	22255	Economy	6700.00
0005435529387	22255	Economy	6700.00
0005435541131	22255	Economy	6700.00
0005435529370	22255	Economy	6700.00
0005435529382	22255	Economy	6700.00
0005432294501	22255	Economy	6700.00
0005435541114	22255	Economy	6700.00
0005435529374	22255	Economy	6700.00
0005435541119	22255	Economy	6700.00
0005435541116	22255	Economy	6700.00
0005435541112	22255	Economy	6700.00
0005435541110	22255	Economy	6700.00
0005432294500	22255	Economy	6700.00
0005435529372	22255	Economy	6700.00
0005435541126	22255	Economy	6700.00
0005435541124	22255	Economy	6700.00
0005435541120	22255	Economy	6700.00
0005435541117	22255	Economy	6700.00
0005435541111	22255	Economy	6700.00
0005435529386	22255	Economy	6700.00
0005435529376	22255	Economy	6700.00
0005435529383	22255	Economy	6700.00
0005432294499	22255	Economy	6700.00
0005435529375	22255	Economy	6700.00
0005435529366	22255	Economy	6700.00
0005435541115	22255	Economy	6700.00
0005434907614	2267	Business	20200.00
0005434907611	2267	Business	20200.00
0005433251383	2267	Business	20200.00
0005433251336	2267	Business	20200.00
0005433251388	2267	Business	20200.00
0005433251405	2267	Business	20200.00
0005434907601	2267	Business	20200.00
0005434907598	2267	Business	20200.00
0005434907634	2267	Business	20200.00
0005434907647	2267	Business	20200.00
0005434907613	2267	Business	20200.00
0005433251501	2267	Economy	6700.00
0005434907632	2267	Economy	6700.00
0005433251408	2267	Economy	6700.00
0005434907653	2267	Economy	6700.00
0005434907626	2267	Economy	6700.00
0005434907650	2267	Economy	6700.00
0005433251471	2267	Economy	6700.00
0005434907604	2267	Economy	6700.00
0005434907639	2267	Economy	6700.00
0005434907617	2267	Economy	6700.00
0005434907645	2267	Economy	7400.00
0005434907643	2267	Economy	7400.00
0005433251382	2267	Economy	7400.00
0005433251461	2267	Economy	7400.00
0005433251575	2267	Economy	7400.00
0005434907608	2267	Economy	6700.00
0005434907649	2267	Economy	6700.00
0005434907640	2267	Economy	6700.00
0005434907600	2267	Economy	6700.00
0005433251504	2267	Economy	6700.00
0005434907628	2267	Economy	6700.00
0005433251567	2267	Economy	6700.00
0005434907636	2267	Economy	6700.00
0005434907624	2267	Economy	6700.00
0005433251407	2267	Economy	6700.00
0005434907644	2267	Economy	6700.00
0005433251537	2267	Economy	6700.00
0005434907627	2267	Economy	6700.00
0005434907625	2267	Economy	6700.00
0005434907633	2267	Economy	6700.00
0005433251325	2267	Economy	6700.00
0005434907607	2267	Economy	6700.00
0005434907642	2267	Economy	6700.00
0005433251502	2267	Economy	6700.00
0005433251530	2267	Economy	6700.00
0005434907612	2267	Economy	6700.00
0005433251568	2267	Economy	6700.00
0005434907648	2267	Economy	6700.00
0005433251515	2267	Economy	6700.00
0005433251421	2267	Economy	6700.00
0005434907620	2267	Economy	6700.00
0005434907652	2267	Economy	6700.00
0005433251538	2267	Economy	6700.00
0005434907609	2267	Economy	6700.00
0005433251324	2267	Economy	6700.00
0005434907621	2267	Economy	6700.00
0005434907606	2267	Economy	6700.00
0005434907638	2267	Economy	6700.00
0005434907623	2267	Economy	6700.00
0005434907603	2267	Economy	6700.00
0005433251576	2267	Economy	6700.00
0005433251387	2267	Economy	6700.00
0005434907635	2267	Economy	6700.00
0005433251386	2267	Economy	6700.00
0005433251532	2267	Economy	6700.00
0005434907646	2267	Economy	6700.00
0005434907610	2267	Economy	6700.00
0005434907622	2267	Economy	6700.00
0005434907618	2267	Economy	6700.00
0005433251472	2267	Economy	6700.00
0005433251535	2267	Economy	6700.00
0005434907619	2267	Economy	6700.00
0005433251493	2267	Economy	6700.00
0005433251319	2267	Economy	6700.00
0005434907615	2267	Economy	6700.00
0005434907629	2267	Economy	6700.00
0005433251492	2267	Economy	6700.00
0005433251410	2267	Economy	6700.00
0005434907599	2267	Economy	6700.00
0005434907651	2267	Economy	6700.00
0005434907602	2267	Economy	6700.00
0005434907605	2267	Economy	6700.00
0005434907631	2267	Economy	6700.00
0005433251549	2267	Economy	6700.00
0005434907616	2267	Economy	6700.00
0005433251282	2267	Economy	6700.00
0005433251321	2267	Economy	6700.00
0005434907641	2267	Economy	6700.00
0005433251462	2267	Economy	6700.00
0005433251516	2267	Economy	6700.00
0005434907637	2267	Economy	6700.00
0005433251486	2267	Economy	6700.00
0005434907630	2267	Economy	6700.00
0005433251330	2267	Economy	6700.00
0005433400969	2267	Economy	6700.00
0005434907101	25585	Business	20200.00
0005433251681	25585	Business	20200.00
0005433251667	25585	Business	20200.00
0005434906953	25585	Business	20200.00
0005434907100	25585	Business	20200.00
0005434907138	25585	Business	20200.00
0005433251659	25585	Business	20200.00
0005434907214	25585	Economy	6700.00
0005434907015	25585	Economy	6700.00
0005433251675	25585	Economy	6700.00
0005433251683	25585	Economy	6700.00
0005434906909	25585	Economy	6700.00
0005433251679	25585	Economy	6700.00
0005434907061	25585	Economy	6700.00
0005434907136	25585	Economy	6700.00
0005433251662	25585	Economy	6700.00
0005434906924	25585	Economy	7400.00
0005434906981	25585	Economy	7400.00
0005433251666	25585	Economy	7400.00
0005434907173	25585	Economy	7400.00
0005434907067	25585	Economy	6700.00
0005433251685	25585	Economy	6700.00
0005433251661	25585	Economy	6700.00
0005433251674	25585	Economy	6700.00
0005434906854	25585	Economy	6700.00
0005434907305	25585	Economy	6700.00
0005434907068	25585	Economy	6700.00
0005433251672	25585	Economy	6700.00
0005433251680	25585	Economy	6700.00
0005434907156	25585	Economy	6700.00
0005434907139	25585	Economy	6700.00
0005434907060	25585	Economy	6700.00
0005433251676	25585	Economy	6700.00
0005434907182	25585	Economy	6700.00
0005434907140	25585	Economy	6700.00
0005434907065	25585	Economy	6700.00
0005433251656	25585	Economy	6700.00
0005434906866	25585	Economy	6700.00
0005433251678	25585	Economy	6700.00
0005433251677	25585	Economy	6700.00
0005434907084	25585	Economy	6700.00
0005434907149	25585	Economy	6700.00
0005434906908	25585	Economy	6700.00
0005434907075	25585	Economy	6700.00
0005433251684	25585	Economy	6700.00
0005433401003	25585	Economy	6700.00
0005434907066	25585	Economy	6700.00
0005433251668	25585	Economy	6700.00
0005434907102	25585	Economy	6700.00
0005434907288	25585	Economy	6700.00
0005434907233	25585	Economy	6700.00
0005433401004	25585	Economy	6700.00
0005433251660	25585	Economy	6700.00
0005433251670	25585	Economy	6700.00
0005434906999	25585	Economy	6700.00
0005434906998	25585	Economy	6700.00
0005434906963	25585	Economy	6700.00
0005433251669	25585	Economy	6700.00
0005434907154	25585	Economy	6700.00
0005434906966	25585	Economy	6700.00
0005433251673	25585	Economy	6700.00
0005433251654	25585	Economy	6700.00
0005433251682	25585	Economy	6700.00
0005433251664	25585	Economy	6700.00
0005433401002	25585	Economy	6700.00
0005433251671	25585	Economy	6700.00
0005433251655	25585	Economy	6700.00
0005433251663	25585	Economy	6700.00
0005433251657	25585	Economy	6700.00
0005434906943	25585	Economy	6700.00
0005433251665	25585	Economy	6700.00
0005434907289	25585	Economy	6700.00
0005434906980	25585	Economy	6700.00
0005433251658	25585	Economy	6700.00
0005434907143	25585	Economy	6700.00
0005434906867	25585	Economy	6700.00
0005434907239	25585	Economy	6700.00
0005432862273	2512	Economy	13600.00
0005432621122	2512	Economy	13600.00
0005432621126	2512	Economy	13600.00
0005432862296	2512	Economy	13600.00
0005432621123	2512	Economy	12400.00
0005432621130	2512	Economy	12400.00
0005432862262	2512	Economy	12400.00
0005432621119	2512	Economy	12400.00
0005432621124	2512	Economy	12400.00
0005432862276	2512	Economy	12400.00
0005432862307	2512	Economy	12400.00
0005432862303	2512	Economy	12400.00
0005432862315	2512	Economy	12400.00
0005432862299	2512	Economy	12400.00
0005432862300	2512	Economy	12400.00
0005432862316	2512	Economy	12400.00
0005432621127	2512	Economy	12400.00
0005432862272	2512	Economy	12400.00
0005432621131	2512	Economy	12400.00
0005432621132	2512	Economy	12400.00
0005432862308	2512	Economy	12400.00
0005432862306	2512	Economy	12400.00
0005432621125	2512	Economy	12400.00
0005432862263	2512	Economy	12400.00
0005432621129	2512	Economy	12400.00
0005432862255	2512	Economy	12400.00
0005432621120	2512	Economy	12400.00
0005432621128	2512	Economy	12400.00
0005432621121	2512	Economy	12400.00
0005432621036	28034	Economy	13600.00
0005432862348	28034	Economy	12400.00
0005432862351	28034	Economy	12400.00
0005432862353	28034	Economy	12400.00
0005432862352	28034	Economy	12400.00
0005432621037	28034	Economy	12400.00
0005432621054	28034	Economy	12400.00
0005432620977	28034	Economy	12400.00
0005432621002	28034	Economy	12400.00
0005432620970	28034	Economy	12400.00
0005432620942	28034	Economy	12400.00
0005432862347	28034	Economy	12400.00
0005432862346	28034	Economy	12400.00
0005432862350	28034	Economy	12400.00
0005432621022	28034	Economy	12400.00
0005432862349	28034	Economy	12400.00
0005432620992	28034	Economy	12400.00
0005432620943	28034	Economy	12400.00
0005434097484	13117	Economy	11300.00
0005434097485	13117	Economy	11300.00
0005433452752	31025	Economy	8400.00
0005433451632	31025	Economy	8400.00
0005433451631	31025	Economy	8400.00
0005433452751	31025	Economy	8400.00
0005433454871	31440	Economy	8400.00
0005433452733	31440	Economy	8400.00
0005433452734	31440	Economy	8400.00
0005433452736	31440	Economy	8400.00
0005433452737	31440	Economy	8400.00
0005433454872	31440	Economy	8400.00
0005433134127	11987	Economy	7200.00
0005433129282	11987	Economy	6600.00
0005433134116	11987	Economy	6600.00
0005434142598	11987	Economy	6600.00
0005434142600	11987	Economy	6600.00
0005433134128	11987	Economy	6600.00
0005433129267	11987	Economy	6600.00
0005433129259	11987	Economy	6600.00
0005433129263	11987	Economy	6600.00
0005434184662	11987	Economy	6600.00
0005433129241	11987	Economy	6600.00
0005434184660	11987	Economy	6600.00
0005433129257	11987	Economy	6600.00
0005433134115	11987	Economy	6600.00
0005433134122	11987	Economy	6600.00
0005433134107	11987	Economy	6600.00
0005433129242	11987	Economy	6600.00
0005433129258	11987	Economy	6600.00
0005433134114	11987	Economy	6600.00
0005434184661	11987	Economy	6600.00
0005434142601	11987	Economy	6600.00
0005434142602	11987	Economy	6600.00
0005433129283	11987	Economy	6600.00
0005433134165	29833	Economy	7200.00
0005434142630	29833	Economy	7200.00
0005434183592	29833	Economy	6600.00
0005434184677	29833	Economy	6600.00
0005434142631	29833	Economy	6600.00
0005433131735	29833	Economy	6600.00
0005434142633	29833	Economy	6600.00
0005434184678	29833	Economy	6600.00
0005434142632	29833	Economy	6600.00
0005433131736	29833	Economy	6600.00
0005433131738	29833	Economy	6600.00
0005433134164	29833	Economy	6600.00
0005433134168	29833	Economy	6600.00
0005433131734	29833	Economy	6600.00
0005434142634	29833	Economy	6600.00
0005434183591	29833	Economy	6600.00
0005433131737	29833	Economy	6600.00
0005433134166	29833	Economy	6600.00
0005433134167	29833	Economy	6600.00
0005435697477	16472	Economy	19900.00
0005435697486	16472	Economy	18100.00
0005435697487	16472	Economy	18100.00
0005435697489	16472	Economy	18100.00
0005435697482	16472	Economy	18100.00
0005435697484	16472	Economy	18100.00
0005435697495	16472	Economy	18100.00
0005435697488	16472	Economy	18100.00
0005435697499	16472	Economy	18100.00
0005435935021	16472	Economy	18100.00
0005435697494	16472	Economy	18100.00
0005435697490	16472	Economy	18100.00
0005435697475	16472	Economy	18100.00
0005435697485	16472	Economy	18100.00
0005435697491	16472	Economy	18100.00
0005435697500	16472	Economy	18100.00
0005435697501	16472	Economy	18100.00
0005435697481	16472	Economy	18100.00
0005435697498	16472	Economy	18100.00
0005435697476	16472	Economy	18100.00
0005435935033	16472	Economy	18100.00
0005435697493	16472	Economy	18100.00
0005435697492	16472	Economy	18100.00
0005435697503	16472	Economy	18100.00
0005435697502	16472	Economy	18100.00
0005435935034	16472	Economy	18100.00
0005435697474	16472	Economy	18100.00
0005435697497	16472	Economy	18100.00
0005435697479	16472	Economy	18100.00
0005435697480	16472	Economy	18100.00
0005435697483	16472	Economy	18100.00
0005435697496	16472	Economy	18100.00
0005435697478	16472	Economy	18100.00
0005435697325	24701	Economy	19900.00
0005435697150	24701	Economy	19900.00
0005435697326	24701	Economy	19900.00
0005435697215	24701	Economy	19900.00
0005435697274	24701	Economy	18100.00
0005435697384	24701	Economy	18100.00
0005435697273	24701	Economy	18100.00
0005435697380	24701	Economy	18100.00
0005435697240	24701	Economy	18100.00
0005435697324	24701	Economy	18100.00
0005435697225	24701	Economy	18100.00
0005435697263	24701	Economy	18100.00
0005435697151	24701	Economy	18100.00
0005435697379	24701	Economy	18100.00
0005435697254	24701	Economy	18100.00
0005435697152	24701	Economy	18100.00
0005435697337	24701	Economy	18100.00
0005435697287	24701	Economy	18100.00
0005435697294	24701	Economy	18100.00
0005435697382	24701	Economy	18100.00
0005435697319	24701	Economy	18100.00
0005435697246	24701	Economy	18100.00
0005435697253	24701	Economy	18100.00
0005435697331	24701	Economy	18100.00
0005435697272	24701	Economy	18100.00
0005435697342	24701	Economy	18100.00
0005435697234	24701	Economy	18100.00
0005435697269	24701	Economy	18100.00
0005435697233	24701	Economy	18100.00
0005435697202	24701	Economy	18100.00
0005435697220	24701	Economy	18100.00
0005435697293	24701	Economy	18100.00
0005435697279	24701	Economy	18100.00
0005435697291	24701	Economy	18100.00
0005435697216	24701	Economy	18100.00
0005435697270	24701	Economy	18100.00
0005435697190	24701	Economy	18100.00
0005435697359	24701	Economy	18100.00
0005435697305	24701	Economy	18100.00
0005435697219	24701	Economy	18100.00
0005435697280	24701	Economy	18100.00
0005435697341	24701	Economy	18100.00
0005435697262	24701	Economy	18100.00
0005435697203	24701	Economy	18100.00
0005433724827	18794	Economy	4400.00
0005433724829	18794	Economy	4400.00
0005433724826	18794	Economy	4400.00
0005433724830	18794	Economy	4400.00
0005433724828	18794	Economy	4400.00
0005433724807	21625	Economy	4400.00
0005432968855	21625	Economy	4400.00
0005432968856	21625	Economy	4400.00
0005432968857	21625	Economy	4400.00
0005434138638	7317	Business	23100.00
0005434138666	7317	Business	23100.00
0005434138671	7317	Business	23100.00
0005434138678	7317	Business	23100.00
0005434138639	7317	Business	23100.00
0005434138644	7317	Business	23100.00
0005434138705	7317	Business	23100.00
0005434138707	7317	Business	23100.00
0005434138704	7317	Business	23100.00
0005434138665	7317	Business	23100.00
0005434138657	7317	Business	23100.00
0005434138642	7317	Economy	7700.00
0005434138640	7317	Economy	7700.00
0005434138684	7317	Economy	7700.00
0005434138674	7317	Economy	7700.00
0005434138646	7317	Economy	7700.00
0005434138710	7317	Economy	7700.00
0005434138655	7317	Economy	7700.00
0005434138694	7317	Economy	7700.00
0005434138715	7317	Economy	8500.00
0005434138712	7317	Economy	8500.00
0005434138690	7317	Economy	8500.00
0005434138667	7317	Economy	8500.00
0005434138700	7317	Economy	8500.00
0005434138696	7317	Economy	7700.00
0005434087546	7317	Economy	7700.00
0005434138633	7317	Economy	7700.00
0005434138682	7317	Economy	7700.00
0005434138702	7317	Economy	7700.00
0005434138651	7317	Economy	7700.00
0005434138692	7317	Economy	7700.00
0005434138649	7317	Economy	7700.00
0005434138685	7317	Economy	7700.00
0005434138675	7317	Economy	7700.00
0005434138634	7317	Economy	7700.00
0005434087544	7317	Economy	7700.00
0005434138711	7317	Economy	7700.00
0005434138654	7317	Economy	7700.00
0005434138688	7317	Economy	7700.00
0005434138661	7317	Economy	7700.00
0005434138659	7317	Economy	7700.00
0005434138648	7317	Economy	7700.00
0005434138683	7317	Economy	7700.00
0005434138681	7317	Economy	7700.00
0005434138695	7317	Economy	7700.00
0005434138670	7317	Economy	7700.00
0005434138706	7317	Economy	7700.00
0005434138643	7317	Economy	7700.00
0005434138687	7317	Economy	7700.00
0005434138697	7317	Economy	7700.00
0005434138635	7317	Economy	7700.00
0005434138714	7317	Economy	7700.00
0005434138650	7317	Economy	7700.00
0005434138658	7317	Economy	7700.00
0005434138703	7317	Economy	7700.00
0005434138656	7317	Economy	7700.00
0005434138679	7317	Economy	7700.00
0005434138632	7317	Economy	7700.00
0005434138693	7317	Economy	7700.00
0005434138698	7317	Economy	7700.00
0005434138641	7317	Economy	7700.00
0005434138636	7317	Economy	7700.00
0005434138691	7317	Economy	7700.00
0005434138664	7317	Economy	7700.00
0005434138680	7317	Economy	7700.00
0005434138668	7317	Economy	7700.00
0005434138699	7317	Economy	7700.00
0005434138663	7317	Economy	7700.00
0005434138686	7317	Economy	7700.00
0005434138673	7317	Economy	7700.00
0005434138653	7317	Economy	7700.00
0005434138689	7317	Economy	7700.00
0005434138677	7317	Economy	7700.00
0005434138647	7317	Economy	7700.00
0005434138637	7317	Economy	7700.00
0005434138708	7317	Economy	7700.00
0005434138669	7317	Economy	7700.00
0005434138645	7317	Economy	7700.00
0005434138709	7317	Economy	7700.00
0005434087545	7317	Economy	7700.00
0005434138652	7317	Economy	7700.00
0005434138672	7317	Economy	7700.00
0005434138662	7317	Economy	7700.00
0005434138701	7317	Economy	7700.00
0005434087543	7317	Economy	7700.00
0005434138660	7317	Economy	7700.00
0005434138713	7317	Economy	7700.00
0005434138676	7317	Economy	7700.00
0005434137812	28542	Business	23100.00
0005434137813	28542	Business	23100.00
0005434137917	28542	Business	23100.00
0005434137390	28542	Business	23100.00
0005434137730	28542	Business	23100.00
0005434137911	28542	Business	23100.00
0005434138265	28542	Business	23100.00
0005434138003	28542	Business	23100.00
0005434137748	28542	Business	23100.00
0005434137988	28542	Business	23100.00
0005434137709	28542	Economy	7700.00
0005434137710	28542	Economy	7700.00
0005434137756	28542	Economy	7700.00
0005434138033	28542	Economy	7700.00
0005434137816	28542	Economy	7700.00
0005434137771	28542	Economy	7700.00
0005434138040	28542	Economy	7700.00
0005434137644	28542	Economy	7700.00
0005434137984	28542	Economy	8500.00
0005434137987	28542	Economy	8500.00
0005434137683	28542	Economy	8500.00
0005434138086	28542	Economy	8500.00
0005434137685	28542	Economy	8500.00
0005434137714	28542	Economy	7700.00
0005434137684	28542	Economy	7700.00
0005434087520	28542	Economy	7700.00
0005434137933	28542	Economy	7700.00
0005434137705	28542	Economy	7700.00
0005434137779	28542	Economy	7700.00
0005434137642	28542	Economy	7700.00
0005434137846	28542	Economy	7700.00
0005434137967	28542	Economy	7700.00
0005434138019	28542	Economy	7700.00
0005434138085	28542	Economy	7700.00
0005434137883	28542	Economy	7700.00
0005434138008	28542	Economy	7700.00
0005434138093	28542	Economy	7700.00
0005434137780	28542	Economy	7700.00
0005434137881	28542	Economy	7700.00
0005434138092	28542	Economy	7700.00
0005434137706	28542	Economy	7700.00
0005434138009	28542	Economy	7700.00
0005434137716	28542	Economy	7700.00
0005434138200	28542	Economy	7700.00
0005434138097	28542	Economy	7700.00
0005434137747	28542	Economy	7700.00
0005434138124	28542	Economy	7700.00
0005434137304	28542	Economy	7700.00
0005434138191	28542	Economy	7700.00
0005434137949	28542	Economy	7700.00
0005434138101	28542	Economy	7700.00
0005434138221	28542	Economy	7700.00
0005434137682	28542	Economy	7700.00
0005434137882	28542	Economy	7700.00
0005434137704	28542	Economy	7700.00
0005434137843	28542	Economy	7700.00
0005434087505	28542	Economy	7700.00
0005434138100	28542	Economy	7700.00
0005434137742	28542	Economy	7700.00
0005434087521	28542	Economy	7700.00
0005434137715	28542	Economy	7700.00
0005434137968	28542	Economy	7700.00
0005434138134	28542	Economy	7700.00
0005434137934	28542	Economy	7700.00
0005434138012	28542	Economy	7700.00
0005434137873	28542	Economy	7700.00
0005434138199	28542	Economy	7700.00
0005434137643	28542	Economy	7700.00
0005434137990	28542	Economy	7700.00
0005434138011	28542	Economy	7700.00
0005434138010	28542	Economy	7700.00
0005434138126	28542	Economy	7700.00
0005434138021	28542	Economy	7700.00
0005434137815	28542	Economy	7700.00
0005434137912	28542	Economy	7700.00
0005434137989	28542	Economy	7700.00
0005434137680	28542	Economy	7700.00
0005434137729	28542	Economy	7700.00
0005434087496	28542	Economy	7700.00
0005434137951	28542	Economy	7700.00
0005434137985	28542	Economy	7700.00
0005434137983	28542	Economy	7700.00
0005434137814	28542	Economy	7700.00
0005434137731	28542	Economy	7700.00
0005434137717	28542	Economy	7700.00
0005435808298	1945	Economy	23900.00
0005435808299	1945	Economy	21700.00
0005435808297	1945	Economy	21700.00
0005434610254	1945	Economy	21700.00
0005435808301	1945	Economy	21700.00
0005435808302	1945	Economy	21700.00
0005435808304	1945	Economy	21700.00
0005434610252	1945	Economy	21700.00
0005435808296	1945	Economy	21700.00
0005434610253	1945	Economy	21700.00
0005435808295	1945	Economy	21700.00
0005435808303	1945	Economy	21700.00
0005433407565	1945	Economy	21700.00
0005435808300	1945	Economy	21700.00
0005434610250	1945	Economy	21700.00
0005434610251	1945	Economy	21700.00
0005434610216	23118	Economy	21700.00
0005434610220	23118	Economy	21700.00
0005434504038	16694	Economy	7600.00
0005434504088	16694	Economy	7600.00
0005434504100	16694	Economy	7600.00
0005434503947	16694	Economy	6900.00
0005434503901	16694	Economy	6900.00
0005434504126	16694	Economy	6900.00
0005434503977	16694	Economy	6900.00
0005434504254	16694	Economy	6900.00
0005434504099	16694	Economy	6900.00
0005434504024	16694	Economy	6900.00
0005434503882	16694	Economy	6900.00
0005434503902	16694	Economy	6900.00
0005434503995	16694	Economy	6900.00
0005434504003	16694	Economy	6900.00
0005434504002	16694	Economy	6900.00
0005434503946	16694	Economy	6900.00
0005434504093	16694	Economy	6900.00
0005434504022	16694	Economy	6900.00
0005434504036	16694	Economy	6900.00
0005434504019	16694	Economy	6900.00
0005434504068	16694	Economy	6900.00
0005434503819	16694	Economy	6900.00
0005434504081	16694	Economy	6900.00
0005434504046	16694	Economy	6900.00
0005434503976	16694	Economy	6900.00
0005434504037	16694	Economy	6900.00
0005434503853	16694	Economy	6900.00
0005434504360	22893	Economy	7600.00
0005434504349	22893	Economy	7600.00
0005434504344	22893	Economy	7600.00
0005434504356	22893	Economy	6900.00
0005434504351	22893	Economy	6900.00
0005434504379	22893	Economy	6900.00
0005434504367	22893	Economy	6900.00
0005434504361	22893	Economy	6900.00
0005434504371	22893	Economy	6900.00
0005434504377	22893	Economy	6900.00
0005434504374	22893	Economy	6900.00
0005434504346	22893	Economy	6900.00
0005434504342	22893	Economy	6900.00
0005434504368	22893	Economy	6900.00
0005434504362	22893	Economy	6900.00
0005434504376	22893	Economy	6900.00
0005434504358	22893	Economy	6900.00
0005434504354	22893	Economy	6900.00
0005434504375	22893	Economy	6900.00
0005434504343	22893	Economy	6900.00
0005434504359	22893	Economy	6900.00
0005434504373	22893	Economy	6900.00
0005434504347	22893	Economy	6900.00
0005434504366	22893	Economy	6900.00
0005434504365	22893	Economy	6900.00
0005434504363	22893	Economy	6900.00
0005434504348	22893	Economy	6900.00
0005434504372	22893	Economy	6900.00
0005434504382	22893	Economy	6900.00
0005434504353	22893	Economy	6900.00
0005434504380	22893	Economy	6900.00
0005434504369	22893	Economy	6900.00
0005434504370	22893	Economy	6900.00
0005434504357	22893	Economy	6900.00
0005434504381	22893	Economy	6900.00
0005434504345	22893	Economy	6900.00
0005434504364	22893	Economy	6900.00
0005434504355	22893	Economy	6900.00
0005434504352	22893	Economy	6900.00
0005434504378	22893	Economy	6900.00
0005434504350	22893	Economy	6900.00
0005433266734	2178	Economy	7700.00
0005435078432	2178	Economy	7000.00
0005435078437	2178	Economy	7000.00
0005433266710	2178	Economy	7000.00
0005433266685	2178	Economy	7000.00
0005435078430	2178	Economy	7000.00
0005433266684	2178	Economy	7000.00
0005435078434	2178	Economy	7000.00
0005433266711	2178	Economy	7000.00
0005435078435	2178	Economy	7000.00
0005435078442	2178	Economy	7000.00
0005435078436	2178	Economy	7000.00
0005433266676	2178	Economy	7000.00
0005435078438	2178	Economy	7000.00
0005433266702	2178	Economy	7000.00
0005435078443	2178	Economy	7000.00
0005435078439	2178	Economy	7000.00
0005435078445	2178	Economy	7000.00
0005435078441	2178	Economy	7000.00
0005433266660	2178	Economy	7000.00
0005435078433	2178	Economy	7000.00
0005435078431	2178	Economy	7000.00
0005433266701	2178	Economy	7000.00
0005435078440	2178	Economy	7000.00
0005435078444	2178	Economy	7000.00
0005435078285	24345	Economy	7700.00
0005435078321	24345	Economy	7700.00
0005433266776	24345	Economy	7700.00
0005433266779	24345	Economy	7000.00
0005435078309	24345	Economy	7000.00
0005435078320	24345	Economy	7000.00
0005435078282	24345	Economy	7000.00
0005435078354	24345	Economy	7000.00
0005435078316	24345	Economy	7000.00
0005433266777	24345	Economy	7000.00
0005435078291	24345	Economy	7000.00
0005435078318	24345	Economy	7000.00
0005435078262	24345	Economy	7000.00
0005433266783	24345	Economy	7000.00
0005435078263	24345	Economy	7000.00
0005433266780	24345	Economy	7000.00
0005433266785	24345	Economy	7000.00
0005433266784	24345	Economy	7000.00
0005433266782	24345	Economy	7000.00
0005435078331	24345	Economy	7000.00
0005433266778	24345	Economy	7000.00
0005435078317	24345	Economy	7000.00
0005435078286	24345	Economy	7000.00
0005435078355	24345	Economy	7000.00
0005435078279	24345	Economy	7000.00
0005435078280	24345	Economy	7000.00
0005435078274	24345	Economy	7000.00
0005435078330	24345	Economy	7000.00
0005435078361	24345	Economy	7000.00
0005435078299	24345	Economy	7000.00
0005433266781	24345	Economy	7000.00
0005434988800	6665	Economy	10800.00
0005434988807	6665	Economy	9800.00
0005434988802	6665	Economy	9800.00
0005435803280	6665	Economy	9800.00
0005434988805	6665	Economy	9800.00
0005435803282	6665	Economy	9800.00
0005434988811	6665	Economy	9800.00
0005434988809	6665	Economy	9800.00
0005435803281	6665	Economy	9800.00
0005434988804	6665	Economy	9800.00
0005434988801	6665	Economy	9800.00
0005434988810	6665	Economy	9800.00
0005434988803	6665	Economy	9800.00
0005434988808	6665	Economy	9800.00
0005434988806	6665	Economy	9800.00
0005435803279	6665	Economy	9800.00
0005434988669	23587	Economy	10800.00
0005434988691	23587	Economy	10800.00
0005434988700	23587	Economy	10800.00
0005434988663	23587	Economy	9800.00
0005434988673	23587	Economy	9800.00
0005434988699	23587	Economy	9800.00
0005434988662	23587	Economy	9800.00
0005435464520	23587	Economy	9800.00
0005434988698	23587	Economy	9800.00
0005434988689	23587	Economy	9800.00
0005434988701	23587	Economy	9800.00
0005434988676	23587	Economy	9800.00
0005435464519	23587	Economy	9800.00
0005435803267	23587	Economy	9800.00
0005434988637	23587	Economy	9800.00
0005434988670	23587	Economy	9800.00
0005434988672	23587	Economy	9800.00
0005432383425	30498	Business	9900.00
0005432383440	30498	Business	9900.00
0005433450104	30498	Business	9900.00
0005432383416	30498	Business	9900.00
0005432383426	30498	Business	9900.00
0005432383442	30498	Business	9900.00
0005433450099	30498	Business	9900.00
0005433450101	30498	Business	9900.00
0005433450115	30498	Business	9900.00
0005433450096	30498	Business	9900.00
0005433450114	30498	Economy	3300.00
0005432383430	30498	Economy	3300.00
0005432383443	30498	Economy	3300.00
0005432383427	30498	Economy	3300.00
0005432383419	30498	Economy	3300.00
0005433450118	30498	Economy	3300.00
0005433450107	30498	Economy	3300.00
0005432383424	30498	Economy	3300.00
0005432383423	30498	Economy	3600.00
0005432383428	30498	Economy	3600.00
0005432383409	30498	Economy	3600.00
0005433450111	30498	Economy	3600.00
0005432383433	30498	Economy	3600.00
0005433450103	30498	Economy	3300.00
0005433450116	30498	Economy	3300.00
0005433450113	30498	Economy	3300.00
0005433454890	30498	Economy	3300.00
0005433454891	30498	Economy	3300.00
0005432383406	30498	Economy	3300.00
0005433454889	30498	Economy	3300.00
0005432383422	30498	Economy	3300.00
0005432383437	30498	Economy	3300.00
0005432383438	30498	Economy	3300.00
0005433450109	30498	Economy	3300.00
0005433450098	30498	Economy	3300.00
0005432383408	30498	Economy	3300.00
0005433450097	30498	Economy	3300.00
0005432383421	30498	Economy	3300.00
0005433450100	30498	Economy	3300.00
0005432383418	30498	Economy	3300.00
0005432383411	30498	Economy	3300.00
0005432383407	30498	Economy	3300.00
0005432383432	30498	Economy	3300.00
0005432383436	30498	Economy	3300.00
0005432383439	30498	Economy	3300.00
0005433450112	30498	Economy	3300.00
0005432383431	30498	Economy	3300.00
0005432383417	30498	Economy	3300.00
0005432383412	30498	Economy	3300.00
0005432383410	30498	Economy	3300.00
0005432383415	30498	Economy	3300.00
0005432383403	30498	Economy	3300.00
0005433450117	30498	Economy	3300.00
0005433450105	30498	Economy	3300.00
0005432383404	30498	Economy	3300.00
0005432383420	30498	Economy	3300.00
0005432383402	30498	Economy	3300.00
0005433450110	30498	Economy	3300.00
0005432383414	30498	Economy	3300.00
0005433453772	30498	Economy	3300.00
0005433450102	30498	Economy	3300.00
0005433450108	30498	Economy	3300.00
0005433450106	30498	Economy	3300.00
0005432383405	30498	Economy	3300.00
0005433454888	30498	Economy	3300.00
0005432383435	30498	Economy	3300.00
0005432383413	30498	Economy	3300.00
0005432383429	30498	Economy	3300.00
0005432383441	30498	Economy	3300.00
0005432383434	30498	Economy	3300.00
0005432382982	31320	Business	9900.00
0005432382870	31320	Business	9900.00
0005432383025	31320	Business	9900.00
0005433449965	31320	Business	9900.00
0005433449913	31320	Business	9900.00
0005432383032	31320	Business	9900.00
0005433451615	31320	Economy	3300.00
0005432382931	31320	Economy	3300.00
0005432383085	31320	Economy	3300.00
0005432382990	31320	Economy	3300.00
0005433450001	31320	Economy	3300.00
0005433449980	31320	Economy	3300.00
0005433449910	31320	Economy	3300.00
0005433451614	31320	Economy	3600.00
0005432382886	31320	Economy	3600.00
0005432382852	31320	Economy	3600.00
0005433449969	31320	Economy	3600.00
0005432383037	31320	Economy	3600.00
0005432383023	31320	Economy	3300.00
0005432382885	31320	Economy	3300.00
0005432382975	31320	Economy	3300.00
0005432383031	31320	Economy	3300.00
0005432382916	31320	Economy	3300.00
0005432382997	31320	Economy	3300.00
0005433450005	31320	Economy	3300.00
0005432382872	31320	Economy	3300.00
0005432382976	31320	Economy	3300.00
0005433449927	31320	Economy	3300.00
0005433451613	31320	Economy	3300.00
0005432383024	31320	Economy	3300.00
0005432382851	31320	Economy	3300.00
0005432383028	31320	Economy	3300.00
0005432382810	31320	Economy	3300.00
0005432382934	31320	Economy	3300.00
0005432383060	31320	Economy	3300.00
0005433449930	31320	Economy	3300.00
0005432383080	31320	Economy	3300.00
0005432383010	31320	Economy	3300.00
0005432382887	31320	Economy	3300.00
0005432383081	31320	Economy	3300.00
0005432383056	31320	Economy	3300.00
0005432383021	31320	Economy	3300.00
0005433449929	31320	Economy	3300.00
0005433449970	31320	Economy	3300.00
0005433449926	31320	Economy	3300.00
0005433449981	31320	Economy	3300.00
0005432382960	31320	Economy	3300.00
0005433449973	31320	Economy	3300.00
0005432382981	31320	Economy	3300.00
0005433449908	31320	Economy	3300.00
0005432382869	31320	Economy	3300.00
0005433449972	31320	Economy	3300.00
0005432383029	31320	Economy	3300.00
0005432382917	31320	Economy	3300.00
0005432382892	31320	Economy	3300.00
0005432383038	31320	Economy	3300.00
0005433449909	31320	Economy	3300.00
0005433450002	31320	Economy	3300.00
0005433449880	31320	Economy	3300.00
0005433788227	20817	Economy	26200.00
0005435548456	20817	Economy	26200.00
0005433788230	20817	Economy	23800.00
0005435548457	20817	Economy	23800.00
0005435548468	20817	Economy	23800.00
0005435548461	20817	Economy	23800.00
0005433788223	20817	Economy	23800.00
0005435548465	20817	Economy	23800.00
0005433788233	20817	Economy	23800.00
0005433788221	20817	Economy	23800.00
0005433788229	20817	Economy	23800.00
0005435548470	20817	Economy	23800.00
0005435548462	20817	Economy	23800.00
0005435548450	20817	Economy	23800.00
0005433788231	20817	Economy	23800.00
0005433788222	20817	Economy	23800.00
0005433788228	20817	Economy	23800.00
0005433788225	20817	Economy	23800.00
0005433788226	20817	Economy	23800.00
0005435548455	20817	Economy	23800.00
0005435548474	20817	Economy	23800.00
0005433788224	20817	Economy	23800.00
0005435548451	20817	Economy	23800.00
0005433788220	20817	Economy	23800.00
0005433788232	20817	Economy	23800.00
0005433788234	20817	Economy	23800.00
0005433788219	20817	Economy	23800.00
0005435548466	20817	Economy	23800.00
0005435548469	20817	Economy	23800.00
0005435548458	20817	Economy	23800.00
0005435548522	26486	Economy	26200.00
0005435548517	26486	Economy	26200.00
0005435548521	26486	Economy	23800.00
0005435548516	26486	Economy	23800.00
0005435548527	26486	Economy	23800.00
0005433788187	26486	Economy	23800.00
0005433788202	26486	Economy	23800.00
0005435548515	26486	Economy	23800.00
0005433788203	26486	Economy	23800.00
0005435548525	26486	Economy	23800.00
0005435548520	26486	Economy	23800.00
0005435548519	26486	Economy	23800.00
0005433788188	26486	Economy	23800.00
0005435548526	26486	Economy	23800.00
0005435548528	26486	Economy	23800.00
0005433788166	26486	Economy	23800.00
0005435548524	26486	Economy	23800.00
0005435548523	26486	Economy	23800.00
0005433788190	26486	Economy	23800.00
0005433788186	26486	Economy	23800.00
0005435548514	26486	Economy	23800.00
0005435548518	26486	Economy	23800.00
0005433788185	26486	Economy	23800.00
0005433788201	26486	Economy	23800.00
0005433126825	10773	Economy	17100.00
0005435304140	10773	Economy	15600.00
0005435299769	10773	Economy	15600.00
0005435299758	10773	Economy	15600.00
0005433126839	10773	Economy	15600.00
0005435299765	10773	Economy	15600.00
0005435299775	10773	Economy	15600.00
0005433126840	10773	Economy	15600.00
0005435304145	10773	Economy	15600.00
0005433126826	10773	Economy	15600.00
0005435299776	10773	Economy	15600.00
0005435299760	10773	Economy	15600.00
0005435299752	10773	Economy	15600.00
0005433131691	10773	Economy	15600.00
0005433131689	10773	Economy	15600.00
0005433126817	10773	Economy	15600.00
0005435299768	10773	Economy	15600.00
0005433131670	10773	Economy	15600.00
0005435299733	10773	Economy	15600.00
0005435299763	10773	Economy	15600.00
0005435299782	10773	Economy	15600.00
0005435304139	10773	Economy	15600.00
0005433131690	10773	Economy	15600.00
0005435299751	10773	Economy	15600.00
0005435299759	10773	Economy	15600.00
0005435304141	10773	Economy	15600.00
0005433126816	10773	Economy	15600.00
0005435299764	10773	Economy	15600.00
0005435299753	10773	Economy	15600.00
0005435302230	29738	Economy	15600.00
0005435302233	29738	Economy	15600.00
0005435299811	29738	Economy	15600.00
0005433129310	29738	Economy	15600.00
0005435302234	29738	Economy	15600.00
0005435299810	29738	Economy	15600.00
0005435302229	29738	Economy	15600.00
0005433129309	29738	Economy	15600.00
0005433129307	29738	Economy	15600.00
0005433126875	29738	Economy	15600.00
0005435302232	29738	Economy	15600.00
0005435299809	29738	Economy	15600.00
0005435299808	29738	Economy	15600.00
0005435299807	29738	Economy	15600.00
0005433126877	29738	Economy	15600.00
0005433126876	29738	Economy	15600.00
0005433126878	29738	Economy	15600.00
0005433126879	29738	Economy	15600.00
0005433129308	29738	Economy	15600.00
0005435302231	29738	Economy	15600.00
0005434287432	2414	Economy	17200.00
0005434287420	2414	Economy	17200.00
0005434287429	2414	Economy	17200.00
0005433110020	2414	Economy	15700.00
0005432264491	2414	Economy	15700.00
0005434287431	2414	Economy	15700.00
0005433110029	2414	Economy	15700.00
0005434287425	2414	Economy	15700.00
0005434287422	2414	Economy	15700.00
0005433110008	2414	Economy	15700.00
0005434287421	2414	Economy	15700.00
0005434287419	2414	Economy	15700.00
0005434287430	2414	Economy	15700.00
0005434287437	2414	Economy	15700.00
0005434287423	2414	Economy	15700.00
0005433110030	2414	Economy	15700.00
0005434287424	2414	Economy	15700.00
0005434287426	2414	Economy	15700.00
0005434287434	2414	Economy	15700.00
0005433110081	2414	Economy	15700.00
0005434287435	2414	Economy	15700.00
0005434287417	2414	Economy	15700.00
0005434287418	2414	Economy	15700.00
0005434287416	2414	Economy	15700.00
0005432264490	2414	Economy	15700.00
0005434287433	2414	Economy	15700.00
0005434287428	2414	Economy	15700.00
0005433110028	2414	Economy	15700.00
0005433109999	2414	Economy	15700.00
0005432264489	2414	Economy	15700.00
0005434287415	2414	Economy	15700.00
0005434287427	2414	Economy	15700.00
0005434287438	2414	Economy	15700.00
0005433110038	2414	Economy	15700.00
0005433109998	2414	Economy	15700.00
0005434287436	2414	Economy	15700.00
0005434287439	2414	Economy	15700.00
0005434287301	26838	Economy	17200.00
0005434287255	26838	Economy	17200.00
0005434287276	26838	Economy	17200.00
0005434287195	26838	Economy	17200.00
0005433110129	26838	Economy	15700.00
0005433110134	26838	Economy	15700.00
0005434287189	26838	Economy	15700.00
0005433110125	26838	Economy	15700.00
0005433110126	26838	Economy	15700.00
0005434287256	26838	Economy	15700.00
0005434287297	26838	Economy	15700.00
0005434287257	26838	Economy	15700.00
0005433110127	26838	Economy	15700.00
0005434287331	26838	Economy	15700.00
0005434287247	26838	Economy	15700.00
0005434287263	26838	Economy	15700.00
0005434287299	26838	Economy	15700.00
0005434287222	26838	Economy	15700.00
0005433110132	26838	Economy	15700.00
0005434287289	26838	Economy	15700.00
0005434287300	26838	Economy	15700.00
0005434287221	26838	Economy	15700.00
0005433110133	26838	Economy	15700.00
0005434287302	26838	Economy	15700.00
0005433110131	26838	Economy	15700.00
0005433110124	26838	Economy	15700.00
0005434287298	26838	Economy	15700.00
0005434287248	26838	Economy	15700.00
0005434287176	26838	Economy	15700.00
0005433110123	26838	Economy	15700.00
0005434287268	26838	Economy	15700.00
0005433110128	26838	Economy	15700.00
0005433110130	26838	Economy	15700.00
0005434287260	26838	Economy	15700.00
0005434287266	26838	Economy	15700.00
0005434287188	26838	Economy	15700.00
0005433110122	26838	Economy	15700.00
0005434287290	26838	Economy	15700.00
0005434287275	26838	Economy	15700.00
0005434287209	26838	Economy	15700.00
0005434272184	25485	Economy	22800.00
0005435856232	25485	Economy	22800.00
0005435856231	25485	Economy	22800.00
0005435856229	25485	Economy	22800.00
0005435856230	25485	Economy	22800.00
0005434272203	26650	Economy	22800.00
0005434272202	26650	Economy	22800.00
0005434273087	26650	Economy	22800.00
0005434273086	26650	Economy	22800.00
0005434272201	26650	Economy	22800.00
0005435856196	26650	Economy	22800.00
0005435314820	6107	Economy	24600.00
0005434520311	6107	Economy	24600.00
0005435314821	6107	Economy	24600.00
0005434520315	6107	Economy	22300.00
0005434520308	6107	Economy	22300.00
0005434520330	6107	Economy	22300.00
0005435314802	6107	Economy	22300.00
0005434520313	6107	Economy	22300.00
0005434520325	6107	Economy	22300.00
0005434520322	6107	Economy	22300.00
0005435314811	6107	Economy	22300.00
0005434520319	6107	Economy	22300.00
0005435314818	6107	Economy	22300.00
0005434520316	6107	Economy	22300.00
0005434520328	6107	Economy	22300.00
0005434520306	6107	Economy	22300.00
0005435314812	6107	Economy	22300.00
0005434520326	6107	Economy	22300.00
0005434520324	6107	Economy	22300.00
0005434520317	6107	Economy	22300.00
0005434520309	6107	Economy	22300.00
0005434520310	6107	Economy	22300.00
0005434520318	6107	Economy	22300.00
0005435314810	6107	Economy	22300.00
0005435314837	6107	Economy	22300.00
0005434520305	6107	Economy	22300.00
0005435314836	6107	Economy	22300.00
0005435314805	6107	Economy	22300.00
0005434520323	6107	Economy	22300.00
0005435314819	6107	Economy	22300.00
0005434520327	6107	Economy	22300.00
0005434520314	6107	Economy	22300.00
0005435314828	6107	Economy	22300.00
0005434520321	6107	Economy	22300.00
0005434520329	6107	Economy	22300.00
0005434520307	6107	Economy	22300.00
0005434520312	6107	Economy	22300.00
0005434520320	6107	Economy	22300.00
0005434520304	6107	Economy	22300.00
0005435314814	6107	Economy	22300.00
0005435263597	7153	Business	89800.00
0005433650740	7153	Business	89800.00
0005433650748	7153	Business	89800.00
0005435263580	7153	Business	89800.00
0005433650695	7153	Business	89800.00
0005435263594	7153	Business	89800.00
0005435263511	7153	Business	89800.00
0005435263596	7153	Business	89800.00
0005433650736	7153	Business	89800.00
0005435263553	7153	Business	89800.00
0005433650739	7153	Business	89800.00
0005433650720	7153	Business	89800.00
0005433650750	7153	Economy	29900.00
0005435263590	7153	Economy	29900.00
0005435263606	7153	Economy	29900.00
0005435263567	7153	Economy	29900.00
0005433650749	7153	Economy	29900.00
0005433650698	7153	Economy	29900.00
0005433650726	7153	Economy	29900.00
0005433650751	7153	Economy	29900.00
0005435263582	7153	Economy	29900.00
0005433650737	7153	Economy	29900.00
0005433650719	7153	Economy	32900.00
0005433650712	7153	Economy	32900.00
0005433650716	7153	Economy	32900.00
0005435263554	7153	Economy	32900.00
0005433650738	7153	Economy	32900.00
0005433650699	7153	Economy	29900.00
0005433650692	7153	Economy	29900.00
0005433650724	7153	Economy	29900.00
0005433650702	7153	Economy	29900.00
0005433650721	7153	Economy	29900.00
0005433650723	7153	Economy	29900.00
0005433650705	7153	Economy	29900.00
0005435263603	7153	Economy	29900.00
0005433650700	7153	Economy	29900.00
0005433650746	7153	Economy	29900.00
0005433650701	7153	Economy	29900.00
0005433650713	7153	Economy	29900.00
0005433650697	7153	Economy	29900.00
0005433650735	7153	Economy	29900.00
0005435263607	7153	Economy	29900.00
0005433650728	7153	Economy	29900.00
0005435263604	7153	Economy	29900.00
0005433650744	7153	Economy	29900.00
0005433650743	7153	Economy	29900.00
0005435263608	7153	Economy	29900.00
0005435263538	7153	Economy	29900.00
0005433650691	7153	Economy	29900.00
0005435263599	7153	Economy	29900.00
0005433650725	7153	Economy	29900.00
0005435263569	7153	Economy	29900.00
0005433650731	7153	Economy	29900.00
0005433650730	7153	Economy	29900.00
0005435263593	7153	Economy	29900.00
0005435263584	7153	Economy	29900.00
0005433650747	7153	Economy	29900.00
0005435263589	7153	Economy	29900.00
0005435263578	7153	Economy	29900.00
0005433650696	7153	Economy	29900.00
0005433650690	7153	Economy	29900.00
0005435263583	7153	Economy	29900.00
0005435263579	7153	Economy	29900.00
0005433650727	7153	Economy	29900.00
0005435263600	7153	Economy	29900.00
0005433650709	7153	Economy	29900.00
0005433650729	7153	Economy	29900.00
0005435263610	7153	Economy	29900.00
0005435263588	7153	Economy	29900.00
0005433650745	7153	Economy	29900.00
0005433650741	7153	Economy	29900.00
0005435263611	7153	Economy	29900.00
0005433650694	7153	Economy	29900.00
0005433650711	7153	Economy	29900.00
0005433650732	7153	Economy	29900.00
0005433650706	7153	Economy	29900.00
0005433650693	7153	Economy	29900.00
0005433650707	7153	Economy	29900.00
0005435263595	7153	Economy	29900.00
0005433650718	7153	Economy	29900.00
0005435263577	7153	Economy	29900.00
0005435263564	7153	Economy	29900.00
0005433650704	7153	Economy	29900.00
0005433650734	7153	Economy	29900.00
0005433650722	7153	Economy	29900.00
0005435263605	7153	Economy	29900.00
0005435263598	7153	Economy	29900.00
0005433650710	7153	Economy	29900.00
0005433650708	7153	Economy	29900.00
0005433650714	7153	Economy	29900.00
0005433650717	7153	Economy	29900.00
0005433650733	7153	Economy	29900.00
0005433650715	7153	Economy	29900.00
0005435263581	7153	Economy	29900.00
0005433650703	7153	Economy	29900.00
0005433650742	7153	Economy	29900.00
0005435263666	27623	Business	89800.00
0005435263670	27623	Business	89800.00
0005433650666	27623	Business	89800.00
0005433650487	27623	Business	89800.00
0005433650477	27623	Business	89800.00
0005433650578	27623	Business	89800.00
0005435263653	27623	Business	89800.00
0005435263655	27623	Economy	29900.00
0005435263676	27623	Economy	29900.00
0005433650599	27623	Economy	29900.00
0005435263665	27623	Economy	29900.00
0005433650622	27623	Economy	29900.00
0005433650558	27623	Economy	29900.00
0005435263663	27623	Economy	29900.00
0005435263664	27623	Economy	29900.00
0005433650562	27623	Economy	29900.00
0005435263657	27623	Economy	32900.00
0005433650612	27623	Economy	32900.00
0005433650474	27623	Economy	32900.00
0005433650561	27623	Economy	32900.00
0005433650559	27623	Economy	29900.00
0005433650534	27623	Economy	29900.00
0005433650672	27623	Economy	29900.00
0005435263669	27623	Economy	29900.00
0005435263678	27623	Economy	29900.00
0005435263658	27623	Economy	29900.00
0005435263660	27623	Economy	29900.00
0005433650568	27623	Economy	29900.00
0005433650555	27623	Economy	29900.00
0005435263668	27623	Economy	29900.00
0005435263659	27623	Economy	29900.00
0005433650565	27623	Economy	29900.00
0005433650473	27623	Economy	29900.00
0005433650570	27623	Economy	29900.00
0005435263656	27623	Economy	29900.00
0005433650547	27623	Economy	29900.00
0005435263672	27623	Economy	29900.00
0005433650531	27623	Economy	29900.00
0005433650533	27623	Economy	29900.00
0005435263675	27623	Economy	29900.00
0005435263674	27623	Economy	29900.00
0005433650571	27623	Economy	29900.00
0005435263661	27623	Economy	29900.00
0005435263671	27623	Economy	29900.00
0005433650634	27623	Economy	29900.00
0005433650523	27623	Economy	29900.00
0005433650591	27623	Economy	29900.00
0005435263654	27623	Economy	29900.00
0005433650553	27623	Economy	29900.00
0005433650600	27623	Economy	29900.00
0005433650564	27623	Economy	29900.00
0005435263662	27623	Economy	29900.00
0005433650620	27623	Economy	29900.00
0005433650592	27623	Economy	29900.00
0005433650605	27623	Economy	29900.00
0005433650560	27623	Economy	29900.00
0005435263677	27623	Economy	29900.00
0005433650486	27623	Economy	29900.00
0005433650613	27623	Economy	29900.00
0005433650554	27623	Economy	29900.00
0005435263652	27623	Economy	29900.00
0005433650621	27623	Economy	29900.00
0005435263667	27623	Economy	29900.00
0005435263673	27623	Economy	29900.00
0005433650532	27623	Economy	29900.00
0005433868679	4805	Economy	19400.00
0005433868672	4805	Economy	19400.00
0005433868675	4805	Economy	19400.00
0005433868673	4805	Economy	19400.00
0005433868670	4805	Economy	17600.00
0005433868695	4805	Economy	17600.00
0005433868702	4805	Economy	17600.00
0005433868693	4805	Economy	17600.00
0005433868699	4805	Economy	17600.00
0005433868678	4805	Economy	17600.00
0005433868680	4805	Economy	17600.00
0005433868691	4805	Economy	17600.00
0005433868684	4805	Economy	17600.00
0005433868696	4805	Economy	17600.00
0005433868687	4805	Economy	17600.00
0005433868671	4805	Economy	17600.00
0005433868700	4805	Economy	17600.00
0005433868707	4805	Economy	17600.00
0005433868710	4805	Economy	17600.00
0005433868676	4805	Economy	17600.00
0005433868674	4805	Economy	17600.00
0005433868706	4805	Economy	17600.00
0005433868701	4805	Economy	17600.00
0005433868708	4805	Economy	17600.00
0005433868683	4805	Economy	17600.00
0005433868689	4805	Economy	17600.00
0005433868677	4805	Economy	17600.00
0005433868686	4805	Economy	17600.00
0005433868704	4805	Economy	17600.00
0005433868688	4805	Economy	17600.00
0005435860468	4805	Economy	17600.00
0005433868690	4805	Economy	17600.00
0005433868697	4805	Economy	17600.00
0005433868709	4805	Economy	17600.00
0005433868681	4805	Economy	17600.00
0005433868694	4805	Economy	17600.00
0005433868698	4805	Economy	17600.00
0005435860480	4805	Economy	17600.00
0005433868692	4805	Economy	17600.00
0005433868682	4805	Economy	17600.00
0005433868705	4805	Economy	17600.00
0005433868703	4805	Economy	17600.00
0005433868685	4805	Economy	17600.00
0005433868410	32586	Economy	19400.00
0005433868186	32586	Economy	19400.00
0005433868305	32586	Economy	19400.00
0005433868269	32586	Economy	17600.00
0005433868317	32586	Economy	17600.00
0005433868387	32586	Economy	17600.00
0005433868127	32586	Economy	17600.00
0005433868406	32586	Economy	17600.00
0005433868428	32586	Economy	17600.00
0005433868386	32586	Economy	17600.00
0005435860509	32586	Economy	17600.00
0005433868349	32586	Economy	17600.00
0005433868318	32586	Economy	17600.00
0005433868330	32586	Economy	17600.00
0005433868262	32586	Economy	17600.00
0005433868288	32586	Economy	17600.00
0005433868289	32586	Economy	17600.00
0005433868385	32586	Economy	17600.00
0005433868361	32586	Economy	17600.00
0005435860510	32586	Economy	17600.00
0005433868140	32586	Economy	17600.00
0005435860508	32586	Economy	17600.00
0005433868295	32586	Economy	17600.00
0005433868427	32586	Economy	17600.00
0005433868356	32586	Economy	17600.00
0005433868336	32586	Economy	17600.00
0005434663498	3445	Economy	24800.00
0005434663499	3445	Economy	24800.00
0005435911413	3445	Economy	24800.00
0005434663487	3445	Economy	24800.00
0005434663497	3445	Economy	22600.00
0005434663490	3445	Economy	22600.00
0005434663501	3445	Economy	22600.00
0005434460519	3445	Economy	22600.00
0005434460520	3445	Economy	22600.00
0005434663489	3445	Economy	22600.00
0005434663486	3445	Economy	22600.00
0005434663491	3445	Economy	22600.00
0005434663496	3445	Economy	22600.00
0005434461660	3445	Economy	22600.00
0005435911438	3445	Economy	22600.00
0005434460518	3445	Economy	22600.00
0005434663495	3445	Economy	22600.00
0005434663493	3445	Economy	22600.00
0005435911412	3445	Economy	22600.00
0005434461661	3445	Economy	22600.00
0005434663494	3445	Economy	22600.00
0005434663500	3445	Economy	22600.00
0005434663492	3445	Economy	22600.00
0005435911436	3445	Economy	22600.00
0005434663488	3445	Economy	22600.00
0005435911498	12474	Economy	24800.00
0005434663343	12474	Economy	22600.00
0005435911500	12474	Economy	22600.00
0005434663446	12474	Economy	22600.00
0005434663350	12474	Economy	22600.00
0005434663447	12474	Economy	22600.00
0005435911497	12474	Economy	22600.00
0005435911502	12474	Economy	22600.00
0005434663382	12474	Economy	22600.00
0005434663398	12474	Economy	22600.00
0005434663363	12474	Economy	22600.00
0005434663395	12474	Economy	22600.00
0005435911496	12474	Economy	22600.00
0005435911501	12474	Economy	22600.00
0005434663399	12474	Economy	22600.00
0005434663362	12474	Economy	22600.00
0005435911495	12474	Economy	22600.00
0005434663385	12474	Economy	22600.00
0005434663321	12474	Economy	22600.00
0005435911499	12474	Economy	22600.00
0005434663351	12474	Economy	22600.00
0005434663344	12474	Economy	22600.00
0005433868385	14487	Economy	18500.00
0005433868386	14487	Economy	18500.00
0005433868356	14487	Economy	18500.00
0005435860509	14487	Economy	16800.00
0005433868317	14487	Economy	16800.00
0005433868295	14487	Economy	16800.00
0005433868318	14487	Economy	16800.00
0005433868428	14487	Economy	16800.00
0005433868186	14487	Economy	16800.00
0005435860510	14487	Economy	16800.00
0005433868361	14487	Economy	16800.00
0005433868289	14487	Economy	16800.00
0005433868288	14487	Economy	16800.00
0005433868269	14487	Economy	16800.00
0005433868140	14487	Economy	16800.00
0005433868427	14487	Economy	16800.00
0005433868349	14487	Economy	16800.00
0005433868127	14487	Economy	16800.00
0005433868262	14487	Economy	16800.00
0005435860508	14487	Economy	16800.00
0005433868330	14487	Economy	16800.00
0005433868305	14487	Economy	16800.00
0005433868336	14487	Economy	16800.00
0005433868406	14487	Economy	16800.00
0005433868387	14487	Economy	16800.00
0005433868410	14487	Economy	16800.00
0005433868632	32686	Economy	18500.00
0005433868653	32686	Economy	18500.00
0005433868647	32686	Economy	18500.00
0005433868656	32686	Economy	18500.00
0005433868667	32686	Economy	16800.00
0005435860471	32686	Economy	16800.00
0005433868633	32686	Economy	16800.00
0005435860477	32686	Economy	16800.00
0005433868654	32686	Economy	16800.00
0005433868669	32686	Economy	16800.00
0005433868634	32686	Economy	16800.00
0005433868643	32686	Economy	16800.00
0005433868657	32686	Economy	16800.00
0005435860476	32686	Economy	16800.00
0005433868649	32686	Economy	16800.00
0005433868638	32686	Economy	16800.00
0005433868635	32686	Economy	16800.00
0005433868655	32686	Economy	16800.00
0005435860462	32686	Economy	16800.00
0005433868636	32686	Economy	16800.00
0005433868645	32686	Economy	16800.00
0005433868637	32686	Economy	16800.00
0005433868652	32686	Economy	16800.00
0005433868659	32686	Economy	16800.00
0005435860472	32686	Economy	16800.00
0005433868648	32686	Economy	16800.00
0005433868644	32686	Economy	16800.00
0005433868641	32686	Economy	16800.00
0005433868650	32686	Economy	16800.00
0005433868642	32686	Economy	16800.00
0005433868665	32686	Economy	16800.00
0005433868662	32686	Economy	16800.00
0005433868646	32686	Economy	16800.00
0005433868651	32686	Economy	16800.00
0005433868660	32686	Economy	16800.00
0005433868664	32686	Economy	16800.00
0005435860475	32686	Economy	16800.00
0005433868658	32686	Economy	16800.00
0005433868630	32686	Economy	16800.00
0005433868666	32686	Economy	16800.00
0005433868668	32686	Economy	16800.00
0005433868663	32686	Economy	16800.00
0005433868639	32686	Economy	16800.00
0005433868661	32686	Economy	16800.00
0005433868631	32686	Economy	16800.00
0005433868640	32686	Economy	16800.00
0005432799340	12101	Economy	4900.00
0005432799393	12101	Economy	4900.00
0005432799529	12101	Economy	4900.00
0005432799521	12101	Economy	4400.00
0005432799470	12101	Economy	4400.00
0005432799267	12101	Economy	4400.00
0005432799282	12101	Economy	4400.00
0005432799354	12101	Economy	4400.00
0005432799406	12101	Economy	4400.00
0005432799322	12101	Economy	4400.00
0005432799283	12101	Economy	4400.00
0005432799377	12101	Economy	4400.00
0005432799440	12101	Economy	4400.00
0005432799472	12101	Economy	4400.00
0005432799379	12101	Economy	4400.00
0005432799390	12101	Economy	4400.00
0005432799387	12101	Economy	4400.00
0005432799266	12101	Economy	4400.00
0005432799471	12101	Economy	4400.00
0005432799378	12101	Economy	4400.00
0005432799409	12101	Economy	4400.00
0005432799438	12101	Economy	4400.00
0005432799435	12101	Economy	4400.00
0005432799427	12101	Economy	4400.00
0005432799441	12101	Economy	4400.00
0005432799373	12101	Economy	4400.00
0005432799252	12101	Economy	4400.00
0005432799353	12101	Economy	4400.00
0005432799395	12101	Economy	4400.00
0005432799369	12101	Economy	4400.00
0005432799394	12101	Economy	4400.00
0005432799339	12101	Economy	4400.00
0005432799410	12101	Economy	4400.00
0005432799594	14790	Economy	4900.00
0005432799604	14790	Economy	4900.00
0005432799612	14790	Economy	4900.00
0005432799608	14790	Economy	4400.00
0005432799606	14790	Economy	4400.00
0005432799599	14790	Economy	4400.00
0005432799595	14790	Economy	4400.00
0005432799596	14790	Economy	4400.00
0005432799598	14790	Economy	4400.00
0005432799611	14790	Economy	4400.00
0005432799591	14790	Economy	4400.00
0005432799617	14790	Economy	4400.00
0005432799590	14790	Economy	4400.00
0005432799616	14790	Economy	4400.00
0005432799592	14790	Economy	4400.00
0005432799609	14790	Economy	4400.00
0005432799603	14790	Economy	4400.00
0005432799613	14790	Economy	4400.00
0005432799597	14790	Economy	4400.00
0005432799602	14790	Economy	4400.00
0005432799593	14790	Economy	4400.00
0005432799600	14790	Economy	4400.00
0005432799607	14790	Economy	4400.00
0005432799605	14790	Economy	4400.00
0005432799614	14790	Economy	4400.00
0005432799610	14790	Economy	4400.00
0005432799601	14790	Economy	4400.00
0005432799615	14790	Economy	4400.00
0005432799589	14790	Economy	4400.00
0005434408173	7044	Business	49100.00
0005434299703	7044	Business	49100.00
0005434408131	7044	Business	49100.00
0005435311035	7044	Business	49100.00
0005434408144	7044	Business	49100.00
0005435293258	7044	Business	49100.00
0005434408129	7044	Business	49100.00
0005434408181	7044	Business	49100.00
0005434408142	7044	Business	49100.00
0005435311022	7044	Business	49100.00
0005434299715	7044	Economy	16400.00
0005434408154	7044	Economy	16400.00
0005434408176	7044	Economy	16400.00
0005434299716	7044	Economy	16400.00
0005434408169	7044	Economy	16400.00
0005434408145	7044	Economy	16400.00
0005434408126	7044	Economy	16400.00
0005434408157	7044	Economy	16400.00
0005434408132	7044	Economy	16400.00
0005434408161	7044	Economy	16400.00
0005435293255	7044	Economy	16400.00
0005434408184	7044	Economy	16400.00
0005434408140	7044	Economy	16400.00
0005434408165	7044	Economy	16400.00
0005434408166	7044	Economy	16400.00
0005435293259	7044	Economy	16400.00
0005432153980	7044	Economy	16400.00
0005435293189	7044	Economy	16400.00
0005434408159	7044	Economy	16400.00
0005434408188	7044	Economy	16400.00
0005432108266	7044	Economy	16400.00
0005435293250	7044	Economy	16400.00
0005435311033	7044	Economy	16400.00
0005434408130	7044	Economy	16400.00
0005434408139	7044	Economy	16400.00
0005434408172	7044	Economy	16400.00
0005434408138	7044	Economy	16400.00
0005432153982	7044	Economy	16400.00
0005435293238	7044	Economy	16400.00
0005435311036	7044	Economy	16400.00
0005434408148	7044	Economy	16400.00
0005434299709	7044	Economy	16400.00
0005434299711	7044	Economy	16400.00
0005434408153	7044	Economy	16400.00
0005434299695	7044	Economy	16400.00
0005434408163	7044	Economy	16400.00
0005434408150	7044	Economy	16400.00
0005434408136	7044	Economy	18000.00
0005435311034	7044	Economy	18000.00
0005434299702	7044	Economy	18000.00
0005434408171	7044	Economy	18000.00
0005432153984	7044	Economy	18000.00
0005434408135	7044	Economy	18000.00
0005434299704	7044	Economy	16400.00
0005434408156	7044	Economy	16400.00
0005434408152	7044	Economy	16400.00
0005434408158	7044	Economy	16400.00
0005434408182	7044	Economy	16400.00
0005434299712	7044	Economy	16400.00
0005434408168	7044	Economy	16400.00
0005434299697	7044	Economy	16400.00
0005434408179	7044	Economy	16400.00
0005434299710	7044	Economy	16400.00
0005434299708	7044	Economy	16400.00
0005434299696	7044	Economy	16400.00
0005434408187	7044	Economy	16400.00
0005434408160	7044	Economy	16400.00
0005434299713	7044	Economy	16400.00
0005434408186	7044	Economy	16400.00
0005432153981	7044	Economy	16400.00
0005435293254	7044	Economy	16400.00
0005434408127	7044	Economy	16400.00
0005434408178	7044	Economy	16400.00
0005434408141	7044	Economy	16400.00
0005432108267	7044	Economy	16400.00
0005434299714	7044	Economy	16400.00
0005434408177	7044	Economy	16400.00
0005434408170	7044	Economy	16400.00
0005435310988	7044	Economy	16400.00
0005434408180	7044	Economy	16400.00
0005434408175	7044	Economy	16400.00
0005435293195	7044	Economy	16400.00
0005434408133	7044	Economy	16400.00
0005435293167	7044	Economy	16400.00
0005435311013	7044	Economy	16400.00
0005435311026	7044	Economy	16400.00
0005434408151	7044	Economy	16400.00
0005432153983	7044	Economy	16400.00
0005434408183	7044	Economy	16400.00
0005434408162	7044	Economy	16400.00
0005435293188	7044	Economy	16400.00
0005434408137	7044	Economy	16400.00
0005435293197	7044	Economy	16400.00
0005434299694	7044	Economy	16400.00
0005434299700	7044	Economy	16400.00
0005434408134	7044	Economy	16400.00
0005434408185	7044	Economy	16400.00
0005435311029	7044	Economy	16400.00
0005434299705	7044	Economy	16400.00
0005435293213	7044	Economy	16400.00
0005435311045	7044	Economy	16400.00
0005434408128	7044	Economy	16400.00
0005435293252	7044	Economy	16400.00
0005434299698	7044	Economy	16400.00
0005435293196	7044	Economy	16400.00
0005434408167	7044	Economy	16400.00
0005434408155	7044	Economy	16400.00
0005432108265	7044	Economy	16400.00
0005434299699	7044	Economy	16400.00
0005434299701	7044	Economy	16400.00
0005434408174	7044	Economy	16400.00
0005434408149	7044	Economy	16400.00
0005434408146	7044	Economy	16400.00
0005434408147	7044	Economy	16400.00
0005434299707	7044	Economy	16400.00
0005434299717	7044	Economy	16400.00
0005434408143	7044	Economy	16400.00
0005432153979	7044	Economy	16400.00
0005434299706	7044	Economy	16400.00
0005435293253	7044	Economy	16400.00
0005434408164	7044	Economy	16400.00
0005435311125	26931	Business	49100.00
0005434407531	26931	Business	49100.00
0005434407662	26931	Business	49100.00
0005434407606	26931	Business	49100.00
0005435311130	26931	Business	49100.00
0005434299487	26931	Business	49100.00
0005434407548	26931	Business	49100.00
0005434407415	26931	Business	49100.00
0005434299484	26931	Business	49100.00
0005435311120	26931	Business	49100.00
0005434299459	26931	Business	49100.00
0005434407424	26931	Economy	16400.00
0005434407393	26931	Business	49100.00
0005434407511	26931	Economy	16400.00
0005434407705	26931	Economy	16400.00
0005434299604	26931	Economy	16400.00
0005434407482	26931	Economy	16400.00
0005434407522	26931	Economy	16400.00
0005435293326	26931	Economy	16400.00
0005435311119	26931	Economy	16400.00
0005434299653	26931	Economy	16400.00
0005435311116	26931	Economy	16400.00
0005434299485	26931	Economy	16400.00
0005434407580	26931	Economy	16400.00
0005434407701	26931	Economy	16400.00
0005434407547	26931	Economy	16400.00
0005434407425	26931	Economy	16400.00
0005434407716	26931	Economy	16400.00
0005434407469	26931	Economy	16400.00
0005434299546	26931	Economy	16400.00
0005435311124	26931	Economy	16400.00
0005434407356	26931	Economy	16400.00
0005434407654	26931	Economy	16400.00
0005434407532	26931	Economy	16400.00
0005432058402	26931	Economy	16400.00
0005435311122	26931	Economy	16400.00
0005435293334	26931	Economy	16400.00
0005432058403	26931	Economy	16400.00
0005434299486	26931	Economy	16400.00
0005435311137	26931	Economy	16400.00
0005434407579	26931	Economy	16400.00
0005434407578	26931	Economy	16400.00
0005434407732	26931	Economy	16400.00
0005434407338	26931	Economy	16400.00
0005435293336	26931	Economy	16400.00
0005434407655	26931	Economy	16400.00
0005434407607	26931	Economy	16400.00
0005435311126	26931	Economy	18000.00
0005435311118	26931	Economy	18000.00
0005434407306	26931	Economy	18000.00
0005434407514	26931	Economy	18000.00
0005434299455	26931	Economy	18000.00
0005434299548	26931	Economy	18000.00
0005434407664	26931	Economy	16400.00
0005434407733	26931	Economy	16400.00
0005434407574	26931	Economy	16400.00
0005434299536	26931	Economy	16400.00
0005434299581	26931	Economy	16400.00
0005434407614	26931	Economy	16400.00
0005435311131	26931	Economy	16400.00
0005435293330	26931	Economy	16400.00
0005435293327	26931	Economy	16400.00
0005435293331	26931	Economy	16400.00
0005434407526	26931	Economy	16400.00
0005434299469	26931	Economy	16400.00
0005434407605	26931	Economy	16400.00
0005435293332	26931	Economy	16400.00
0005435311123	26931	Economy	16400.00
0005434299489	26931	Economy	16400.00
0005434299530	26931	Economy	16400.00
0005435293335	26931	Economy	16400.00
0005434407615	26931	Economy	16400.00
0005434299547	26931	Economy	16400.00
0005434407737	26931	Economy	16400.00
0005434407704	26931	Economy	16400.00
0005435311134	26931	Economy	16400.00
0005435311132	26931	Economy	16400.00
0005434407349	26931	Economy	16400.00
0005434407575	26931	Economy	16400.00
0005435311115	26931	Economy	16400.00
0005434407617	26931	Economy	16400.00
0005434299540	26931	Economy	16400.00
0005435311133	26931	Economy	16400.00
0005434407432	26931	Economy	16400.00
0005434299488	26931	Economy	16400.00
0005434407600	26931	Economy	16400.00
0005434299503	26931	Economy	16400.00
0005434407556	26931	Economy	16400.00
0005434407339	26931	Economy	16400.00
0005435311136	26931	Economy	16400.00
0005434299470	26931	Economy	16400.00
0005434407746	26931	Economy	16400.00
0005435293329	26931	Economy	16400.00
0005434407567	26931	Economy	16400.00
0005435293328	26931	Economy	16400.00
0005435311129	26931	Economy	16400.00
0005435311127	26931	Economy	16400.00
0005434407534	26931	Economy	16400.00
0005434407468	26931	Economy	16400.00
0005435311128	26931	Economy	16400.00
0005434407405	26931	Economy	16400.00
0005434299580	26931	Economy	16400.00
0005434407544	26931	Economy	16400.00
0005434299579	26931	Economy	16400.00
0005434407336	26931	Economy	16400.00
0005432058404	26931	Economy	16400.00
0005434407406	26931	Economy	16400.00
0005434299522	26931	Economy	16400.00
0005435311121	26931	Economy	16400.00
0005435311117	26931	Economy	16400.00
0005434407712	26931	Economy	16400.00
0005434407731	26931	Economy	16400.00
0005434299521	26931	Economy	16400.00
0005434407717	26931	Economy	16400.00
0005435293325	26931	Economy	16400.00
0005434299539	26931	Economy	16400.00
0005434407419	26931	Economy	16400.00
0005434407599	26931	Economy	16400.00
0005434299573	26931	Economy	16400.00
0005435293333	26931	Economy	16400.00
0005434299551	26931	Economy	16400.00
0005435311135	26931	Economy	16400.00
0005432604598	6476	Economy	16500.00
0005432604578	6476	Economy	16500.00
0005432604610	6476	Economy	15000.00
0005432604602	6476	Economy	15000.00
0005432604595	6476	Economy	15000.00
0005432604609	6476	Economy	15000.00
0005432604584	6476	Economy	15000.00
0005432604591	6476	Economy	15000.00
0005435220490	6476	Economy	15000.00
0005432604596	6476	Economy	15000.00
0005432604579	6476	Economy	15000.00
0005432604605	6476	Economy	15000.00
0005432604588	6476	Economy	15000.00
0005432604589	6476	Economy	15000.00
0005432604611	6476	Economy	15000.00
0005432604593	6476	Economy	15000.00
0005434512140	6476	Economy	15000.00
0005432604607	6476	Economy	15000.00
0005432604603	6476	Economy	15000.00
0005434512141	6476	Economy	15000.00
0005432604590	6476	Economy	15000.00
0005432604580	6476	Economy	15000.00
0005432604604	6476	Economy	15000.00
0005432604594	6476	Economy	15000.00
0005432604582	6476	Economy	15000.00
0005432604612	6476	Economy	15000.00
0005432604583	6476	Economy	15000.00
0005432604586	6476	Economy	15000.00
0005432604613	6476	Economy	15000.00
0005434512142	6476	Economy	15000.00
0005432604585	6476	Economy	15000.00
0005432604599	6476	Economy	15000.00
0005432604614	6476	Economy	15000.00
0005434512138	6476	Economy	15000.00
0005432604601	6476	Economy	15000.00
0005432604577	6476	Economy	15000.00
0005432604597	6476	Economy	15000.00
0005432604587	6476	Economy	15000.00
0005432604608	6476	Economy	15000.00
0005432604592	6476	Economy	15000.00
0005432604600	6476	Economy	15000.00
0005434512136	6476	Economy	15000.00
0005432604606	6476	Economy	15000.00
0005435218114	6476	Economy	15000.00
0005434512139	6476	Economy	15000.00
0005434512137	6476	Economy	15000.00
0005432604581	6476	Economy	15000.00
0005432604362	21359	Economy	16500.00
0005432604199	21359	Economy	16500.00
0005432604249	21359	Economy	16500.00
0005432604158	21359	Economy	15000.00
0005432604200	21359	Economy	15000.00
0005432604230	21359	Economy	15000.00
0005432604317	21359	Economy	15000.00
0005434512124	21359	Economy	15000.00
0005434512083	21359	Economy	15000.00
0005435221523	21359	Economy	15000.00
0005434512122	21359	Economy	15000.00
0005432604205	21359	Economy	15000.00
0005432604241	21359	Economy	15000.00
0005432604305	21359	Economy	15000.00
0005432604272	21359	Economy	15000.00
0005432604135	21359	Economy	15000.00
0005432604298	21359	Economy	15000.00
0005432604198	21359	Economy	15000.00
0005432604129	21359	Economy	15000.00
0005432604261	21359	Economy	15000.00
0005432604257	21359	Economy	15000.00
0005432604262	21359	Economy	15000.00
0005432604368	21359	Economy	15000.00
0005432604206	21359	Economy	15000.00
0005432604238	21359	Economy	15000.00
0005432604128	21359	Economy	15000.00
0005434512120	21359	Economy	15000.00
0005435221062	21359	Economy	15000.00
0005432604361	21359	Economy	15000.00
0005432604204	21359	Economy	15000.00
0005432604071	21359	Economy	15000.00
0005432604175	21359	Economy	15000.00
0005432604351	21359	Economy	15000.00
0005432604012	21359	Economy	15000.00
0005434512121	21359	Economy	15000.00
0005432604136	21359	Economy	15000.00
0005434512123	21359	Economy	15000.00
0005435221063	21359	Economy	15000.00
0005432604178	21359	Economy	15000.00
0005432604057	21359	Economy	15000.00
0005435221522	21359	Economy	15000.00
0005433251672	15029	Business	18900.00
0005433251661	15029	Business	18900.00
0005434906966	15029	Business	18900.00
0005434907100	15029	Business	18900.00
0005434907136	15029	Business	18900.00
0005433251663	15029	Business	18900.00
0005434907138	15029	Business	18900.00
0005434907061	15029	Business	18900.00
0005433251671	15029	Business	18900.00
0005434907101	15029	Economy	6300.00
0005434907154	15029	Economy	6300.00
0005433251680	15029	Economy	6300.00
0005434907015	15029	Economy	6300.00
0005434907289	15029	Economy	6300.00
0005434907182	15029	Economy	6300.00
0005434906924	15029	Economy	6300.00
0005433251654	15029	Economy	6300.00
0005433251669	15029	Economy	6900.00
0005433251660	15029	Economy	6900.00
0005433251673	15029	Economy	6300.00
0005433251674	15029	Economy	6300.00
0005433251682	15029	Economy	6300.00
0005434906854	15029	Economy	6300.00
0005434906943	15029	Economy	6300.00
0005434907066	15029	Economy	6300.00
0005433251666	15029	Economy	6300.00
0005433251683	15029	Economy	6300.00
0005433251668	15029	Economy	6300.00
0005434906908	15029	Economy	6300.00
0005433251658	15029	Economy	6300.00
0005433251681	15029	Economy	6300.00
0005433251667	15029	Economy	6300.00
0005434907060	15029	Economy	6300.00
0005434906980	15029	Economy	6300.00
0005434907239	15029	Economy	6300.00
0005433251676	15029	Economy	6300.00
0005434907214	15029	Economy	6300.00
0005434906998	15029	Economy	6300.00
0005434907065	15029	Economy	6300.00
0005433251675	15029	Economy	6300.00
0005434906867	15029	Economy	6300.00
0005433251662	15029	Economy	6300.00
0005433251659	15029	Economy	6300.00
0005434906999	15029	Economy	6300.00
0005434906981	15029	Economy	6300.00
0005434906866	15029	Economy	6300.00
0005434907075	15029	Economy	6300.00
0005433251670	15029	Economy	6300.00
0005434907156	15029	Economy	6300.00
0005434906953	15029	Economy	6300.00
0005434907143	15029	Economy	6300.00
0005433251665	15029	Economy	6300.00
0005434907149	15029	Economy	6300.00
0005434906909	15029	Economy	6300.00
0005433251656	15029	Economy	6300.00
0005434907102	15029	Economy	6300.00
0005433251657	15029	Economy	6300.00
0005434907305	15029	Economy	6300.00
0005433251679	15029	Economy	6300.00
0005434907288	15029	Economy	6300.00
0005433251678	15029	Economy	6300.00
0005433251655	15029	Economy	6300.00
0005433251664	15029	Economy	6300.00
0005434906963	15029	Economy	6300.00
0005433251677	15029	Economy	6300.00
0005433251685	15029	Economy	6300.00
0005434907233	15029	Economy	6300.00
0005434907173	15029	Economy	6300.00
0005434907084	15029	Economy	6300.00
0005434907068	15029	Economy	6300.00
0005434907139	15029	Economy	6300.00
0005433251684	15029	Economy	6300.00
0005434907067	15029	Economy	6300.00
0005434907140	15029	Economy	6300.00
0005434907552	25831	Business	18900.00
0005434907572	25831	Business	18900.00
0005434907559	25831	Business	18900.00
0005433251482	25831	Business	18900.00
0005434907534	25831	Business	18900.00
0005433251327	25831	Business	18900.00
0005434907597	25831	Business	18900.00
0005434907549	25831	Business	18900.00
0005434907596	25831	Business	18900.00
0005434907537	25831	Business	18900.00
0005434907554	25831	Business	18900.00
0005434907569	25831	Economy	6300.00
0005434907550	25831	Economy	6300.00
0005433251416	25831	Economy	6300.00
0005434907575	25831	Economy	6300.00
0005434907576	25831	Economy	6300.00
0005434907579	25831	Economy	6300.00
0005434907536	25831	Economy	6900.00
0005434907563	25831	Economy	6900.00
0005434907540	25831	Economy	6900.00
0005434907580	25831	Economy	6900.00
0005433251460	25831	Economy	6300.00
0005434907594	25831	Economy	6300.00
0005434907561	25831	Economy	6300.00
0005434907568	25831	Economy	6300.00
0005434907578	25831	Economy	6300.00
0005434907544	25831	Economy	6300.00
0005434907588	25831	Economy	6300.00
0005434907591	25831	Economy	6300.00
0005433251380	25831	Economy	6300.00
0005434907543	25831	Economy	6300.00
0005433251409	25831	Economy	6300.00
0005434907590	25831	Economy	6300.00
0005434907595	25831	Economy	6300.00
0005434907577	25831	Economy	6300.00
0005433251397	25831	Economy	6300.00
0005433251518	25831	Economy	6300.00
0005434907593	25831	Economy	6300.00
0005434907584	25831	Economy	6300.00
0005434907553	25831	Economy	6300.00
0005434907542	25831	Economy	6300.00
0005434907589	25831	Economy	6300.00
0005434907535	25831	Economy	6300.00
0005433251371	25831	Economy	6300.00
0005433251452	25831	Economy	6300.00
0005433251483	25831	Economy	6300.00
0005434907570	25831	Economy	6300.00
0005434907538	25831	Economy	6300.00
0005434907562	25831	Economy	6300.00
0005433251377	25831	Economy	6300.00
0005434907545	25831	Economy	6300.00
0005434907585	25831	Economy	6300.00
0005434907548	25831	Economy	6300.00
0005434907564	25831	Economy	6300.00
0005434907539	25831	Economy	6300.00
0005434907546	25831	Economy	6300.00
0005434907592	25831	Economy	6300.00
0005434907582	25831	Economy	6300.00
0005433251339	25831	Economy	6300.00
0005434907566	25831	Economy	6300.00
0005434907555	25831	Economy	6300.00
0005433251272	25831	Economy	6300.00
0005434907587	25831	Economy	6300.00
0005434907573	25831	Economy	6300.00
0005434907560	25831	Economy	6300.00
0005434907567	25831	Economy	6300.00
0005434907583	25831	Economy	6300.00
0005434907556	25831	Economy	6300.00
0005433251341	25831	Economy	6300.00
0005433251391	25831	Economy	6300.00
0005434907581	25831	Economy	6300.00
0005434907541	25831	Economy	6300.00
0005434907571	25831	Economy	6300.00
0005433251522	25831	Economy	6300.00
0005434907586	25831	Economy	6300.00
0005434907574	25831	Economy	6300.00
0005433251379	25831	Economy	6300.00
0005434907547	25831	Economy	6300.00
0005434907558	25831	Economy	6300.00
0005434907557	25831	Economy	6300.00
0005434907565	25831	Economy	6300.00
0005434907551	25831	Economy	6300.00
0005433008926	14149	Business	52300.00
0005433008918	14149	Business	52300.00
0005433008929	14149	Business	52300.00
0005433008920	14149	Business	52300.00
0005433008901	14149	Business	52300.00
0005433008913	14149	Business	52300.00
0005433810518	14149	Business	52300.00
0005433008898	14149	Economy	17400.00
0005433008923	14149	Economy	17400.00
0005433008906	14149	Economy	17400.00
0005433008912	14149	Economy	17400.00
0005433008907	14149	Economy	19200.00
0005433008916	14149	Economy	19200.00
0005433008917	14149	Economy	19200.00
0005433008937	14149	Economy	19200.00
0005433008936	14149	Economy	19200.00
0005433008924	14149	Economy	17400.00
0005433008930	14149	Economy	17400.00
0005433008899	14149	Economy	17400.00
0005433008931	14149	Economy	17400.00
0005433008914	14149	Economy	17400.00
0005433008927	14149	Economy	17400.00
0005433008905	14149	Economy	17400.00
0005433008925	14149	Economy	17400.00
0005433008922	14149	Economy	17400.00
0005433008904	14149	Economy	17400.00
0005433008910	14149	Economy	17400.00
0005433008903	14149	Economy	17400.00
0005433008919	14149	Economy	17400.00
0005433008933	14149	Economy	17400.00
0005433008932	14149	Economy	17400.00
0005433008928	14149	Economy	17400.00
0005433810519	14149	Economy	17400.00
0005433008895	14149	Economy	17400.00
0005433008902	14149	Economy	17400.00
0005433008892	14149	Economy	17400.00
0005433008909	14149	Economy	17400.00
0005433008915	14149	Economy	17400.00
0005433008890	14149	Economy	17400.00
0005433008891	14149	Economy	17400.00
0005433008921	14149	Economy	17400.00
0005433008911	14149	Economy	17400.00
0005433008897	14149	Economy	17400.00
0005433008893	14149	Economy	17400.00
0005433008896	14149	Economy	17400.00
0005433810520	14149	Economy	17400.00
0005433008908	14149	Economy	17400.00
0005433008934	14149	Economy	17400.00
0005433008935	14149	Economy	17400.00
0005433008894	14149	Economy	17400.00
0005433008900	14149	Economy	17400.00
0005433008251	22857	Business	52300.00
0005433008489	22857	Business	52300.00
0005433008165	22857	Business	52300.00
0005433008267	22857	Business	52300.00
0005433810573	22857	Economy	17400.00
0005433008417	22857	Economy	17400.00
0005433008574	22857	Economy	17400.00
0005433008400	22857	Economy	17400.00
0005433008558	22857	Economy	19200.00
0005433008450	22857	Economy	19200.00
0005433008576	22857	Economy	17400.00
0005433810574	22857	Economy	17400.00
0005433008565	22857	Economy	17400.00
0005433008522	22857	Economy	17400.00
0005433008597	22857	Economy	17400.00
0005433008285	22857	Economy	17400.00
0005433008244	22857	Economy	17400.00
0005433008268	22857	Economy	17400.00
0005433810576	22857	Economy	17400.00
0005433008652	22857	Economy	17400.00
0005433008653	22857	Economy	17400.00
0005433008425	22857	Economy	17400.00
0005433810577	22857	Economy	17400.00
0005433008462	22857	Economy	17400.00
0005433008672	22857	Economy	17400.00
0005433008363	22857	Economy	17400.00
0005433008261	22857	Economy	17400.00
0005433008262	22857	Economy	17400.00
0005433008465	22857	Economy	17400.00
0005433008252	22857	Economy	17400.00
0005433008588	22857	Economy	17400.00
0005433008476	22857	Economy	17400.00
0005433008445	22857	Economy	17400.00
0005433008598	22857	Economy	17400.00
0005433810575	22857	Economy	17400.00
0005433008514	22857	Economy	17400.00
0005433008607	22857	Economy	17400.00
0005433008166	22857	Economy	17400.00
0005433008493	22857	Economy	17400.00
0005433810572	22857	Economy	17400.00
0005433008692	22857	Economy	17400.00
0005435718909	27120	Business	85200.00
0005435718884	27120	Business	85200.00
0005435718903	27120	Business	85200.00
0005435718864	27120	Business	85200.00
0005435718910	27120	Business	85200.00
0005435718911	27120	Business	85200.00
0005435718838	27120	Economy	28400.00
0005435718844	27120	Economy	28400.00
0005435718850	27120	Economy	28400.00
0005435718912	27120	Economy	28400.00
0005435718833	27120	Economy	28400.00
0005435718851	27120	Economy	31200.00
0005435718916	27120	Economy	31200.00
0005435718879	27120	Economy	28400.00
0005435718917	27120	Economy	28400.00
0005435718889	27120	Economy	28400.00
0005435718876	27120	Economy	28400.00
0005435718915	27120	Economy	28400.00
0005435718892	27120	Economy	28400.00
0005435718859	27120	Economy	28400.00
0005435718897	27120	Economy	28400.00
0005435718914	27120	Economy	28400.00
0005435718896	27120	Economy	28400.00
0005435718904	27120	Economy	28400.00
0005435718900	27120	Economy	28400.00
0005435718913	27120	Economy	28400.00
0005435718832	27120	Economy	28400.00
0005435718899	27120	Economy	28400.00
0005435718918	27120	Economy	28400.00
0005435718901	27120	Economy	28400.00
0005435718866	27120	Economy	28400.00
0005435718842	27120	Economy	28400.00
0005435718890	27120	Economy	28400.00
0005435718891	27120	Economy	28400.00
0005435718860	27120	Economy	28400.00
0005435718908	27120	Economy	28400.00
0005435718845	27120	Economy	28400.00
0005435718905	27120	Economy	28400.00
0005435718893	27120	Economy	28400.00
0005435718902	27120	Economy	28400.00
0005435718887	27120	Economy	28400.00
0005435718919	27120	Economy	28400.00
0005434925732	14959	Business	22900.00
0005434925652	14959	Business	22900.00
0005434925540	14959	Business	22900.00
0005434925721	14959	Business	22900.00
0005434925678	14959	Business	22900.00
0005434925727	14959	Economy	7600.00
0005434925625	14959	Economy	7600.00
0005434925735	14959	Economy	7600.00
0005434925707	14959	Economy	8400.00
0005434925694	14959	Economy	8400.00
0005434925676	14959	Economy	7600.00
0005434925740	14959	Economy	7600.00
0005434925677	14959	Economy	7600.00
0005434925713	14959	Economy	7600.00
0005434925741	14959	Economy	7600.00
0005434925665	14959	Economy	7600.00
0005434925728	14959	Economy	7600.00
0005434925685	14959	Economy	7600.00
0005434925704	14959	Economy	7600.00
0005434925541	14959	Economy	7600.00
0005434925729	14959	Economy	7600.00
0005434925595	14959	Economy	7600.00
0005434925693	14959	Economy	7600.00
0005434925724	14959	Economy	7600.00
0005434925667	14959	Economy	7600.00
0005434925544	14959	Economy	7600.00
0005434925580	14959	Economy	7600.00
0005434925624	14959	Economy	7600.00
0005434925969	20526	Business	22900.00
0005434925968	20526	Business	22900.00
0005434925981	20526	Business	22900.00
0005434925975	20526	Economy	7600.00
0005434925982	20526	Economy	7600.00
0005434925977	20526	Economy	8400.00
0005434925974	20526	Economy	8400.00
0005434925970	20526	Economy	8400.00
0005434925985	20526	Economy	7600.00
0005434925976	20526	Economy	7600.00
0005434925988	20526	Economy	7600.00
0005434925979	20526	Economy	7600.00
0005434925983	20526	Economy	7600.00
0005434925987	20526	Economy	7600.00
0005434925965	20526	Economy	7600.00
0005434925971	20526	Economy	7600.00
0005434925966	20526	Economy	7600.00
0005434925963	20526	Economy	7600.00
0005434925972	20526	Economy	7600.00
0005434925980	20526	Economy	7600.00
0005434925986	20526	Economy	7600.00
0005434925967	20526	Economy	7600.00
0005434925964	20526	Economy	7600.00
0005434925984	20526	Economy	7600.00
0005434925973	20526	Economy	7600.00
0005434925978	20526	Economy	7600.00
0005435487966	15827	Economy	8900.00
0005435487965	15827	Economy	8900.00
0005435999206	15827	Economy	8900.00
0005435999207	15827	Economy	8100.00
0005435487968	15827	Economy	8100.00
0005435487971	15827	Economy	8100.00
0005435999210	15827	Economy	8100.00
0005435487976	15827	Economy	8100.00
0005435999179	15827	Economy	8100.00
0005435487969	15827	Economy	8100.00
0005435487978	15827	Economy	8100.00
0005435999175	15827	Economy	8100.00
0005435487975	15827	Economy	8100.00
0005435999178	15827	Economy	8100.00
0005435999174	15827	Economy	8100.00
0005435487970	15827	Economy	8100.00
0005435487981	15827	Economy	8100.00
0005435999205	15827	Economy	8100.00
0005435999187	15827	Economy	8100.00
0005435487973	15827	Economy	8100.00
0005435487980	15827	Economy	8100.00
0005435999199	15827	Economy	8100.00
0005435487967	15827	Economy	8100.00
0005435487977	15827	Economy	8100.00
0005435487979	15827	Economy	8100.00
0005435999202	15827	Economy	8100.00
0005435999192	15827	Economy	8100.00
0005435999182	15827	Economy	8100.00
0005435999188	15827	Economy	8100.00
0005435999127	15827	Economy	8100.00
0005435487974	15827	Economy	8100.00
0005435487983	15827	Economy	8100.00
0005435999204	15827	Economy	8100.00
0005435487984	15827	Economy	8100.00
0005435487972	15827	Economy	8100.00
0005435999198	15827	Economy	8100.00
0005435487982	15827	Economy	8100.00
0005435999227	15827	Economy	8100.00
0005435487964	15827	Economy	8100.00
0005435487763	19710	Economy	8900.00
0005435999344	19710	Economy	8900.00
0005435999352	19710	Economy	8900.00
0005435487803	19710	Economy	8100.00
0005435487760	19710	Economy	8100.00
0005435999356	19710	Economy	8100.00
0005435999346	19710	Economy	8100.00
0005435999348	19710	Economy	8100.00
0005435999355	19710	Economy	8100.00
0005435487752	19710	Economy	8100.00
0005435487661	19710	Economy	8100.00
0005435999339	19710	Economy	8100.00
0005435487664	19710	Economy	8100.00
0005435999340	19710	Economy	8100.00
0005435487759	19710	Economy	8100.00
0005435999335	19710	Economy	8100.00
0005435999343	19710	Economy	8100.00
0005435999338	19710	Economy	8100.00
0005435999336	19710	Economy	8100.00
0005435999351	19710	Economy	8100.00
0005435487713	19710	Economy	8100.00
0005435487726	19710	Economy	8100.00
0005435487690	19710	Economy	8100.00
0005435999349	19710	Economy	8100.00
0005435487728	19710	Economy	8100.00
0005435999350	19710	Economy	8100.00
0005435999341	19710	Economy	8100.00
0005435487837	19710	Economy	8100.00
0005435999354	19710	Economy	8100.00
0005435487780	19710	Economy	8100.00
0005435487743	19710	Economy	8100.00
0005435487678	19710	Economy	8100.00
0005435999337	19710	Economy	8100.00
0005435999347	19710	Economy	8100.00
0005435487725	19710	Economy	8100.00
0005435487705	19710	Economy	8100.00
0005435999345	19710	Economy	8100.00
0005435999353	19710	Economy	8100.00
0005435487753	19710	Economy	8100.00
0005435999342	19710	Economy	8100.00
0005435487665	19710	Economy	8100.00
0005435487838	19710	Economy	8100.00
0005432660833	5976	Business	199300.00
0005435839639	5976	Business	199300.00
0005435839623	5976	Business	199300.00
0005432658608	5976	Business	199300.00
0005432660831	5976	Business	199300.00
0005435472813	5976	Business	199300.00
0005435472792	5976	Business	199300.00
0005432659720	5976	Business	199300.00
0005435839631	5976	Business	199300.00
0005435839641	5976	Business	199300.00
0005435839630	5976	Business	199300.00
0005435839634	5976	Business	199300.00
0005435839640	5976	Business	199300.00
0005435839625	5976	Business	199300.00
0005435839647	5976	Business	199300.00
0005435839643	5976	Economy	66400.00
0005435472789	5976	Economy	66400.00
0005435839644	5976	Economy	66400.00
0005432660834	5976	Economy	66400.00
0005435472797	5976	Economy	66400.00
0005432537063	5976	Economy	73100.00
0005432537049	5976	Economy	73100.00
0005435472852	5976	Economy	73100.00
0005435472791	5976	Economy	66400.00
0005435839636	5976	Economy	66400.00
0005435839635	5976	Economy	66400.00
0005435472809	5976	Economy	66400.00
0005432658606	5976	Economy	66400.00
0005435472770	5976	Economy	66400.00
0005435472713	5976	Economy	66400.00
0005432142272	5976	Economy	66400.00
0005435839632	5976	Economy	66400.00
0005435472810	5976	Economy	66400.00
0005432142273	5976	Economy	66400.00
0005435472716	5976	Economy	66400.00
0005432537052	5976	Economy	66400.00
0005432659721	5976	Economy	66400.00
0005432537050	5976	Economy	66400.00
0005435472777	5976	Economy	66400.00
0005435839645	5976	Economy	66400.00
0005432658607	5976	Economy	66400.00
0005435472851	5976	Economy	66400.00
0005435839646	5976	Economy	66400.00
0005432660832	5976	Economy	66400.00
0005435839648	5976	Economy	66400.00
0005432142271	5976	Economy	66400.00
0005435839621	5976	Economy	66400.00
0005435472796	5976	Economy	66400.00
0005435472776	5976	Economy	66400.00
0005435839624	5976	Economy	66400.00
0005432537047	5976	Economy	66400.00
0005435839633	5976	Economy	66400.00
0005432537051	5976	Economy	66400.00
0005435472802	5976	Economy	66400.00
0005435472801	5976	Economy	66400.00
0005435839642	5976	Economy	66400.00
0005432537048	5976	Economy	66400.00
0005435472808	5976	Economy	66400.00
0005432142270	5976	Economy	66400.00
0005432537046	5976	Economy	66400.00
0005435839627	5976	Economy	66400.00
0005435839629	5976	Economy	66400.00
0005435839628	5976	Economy	66400.00
0005435839626	5976	Economy	66400.00
0005432537064	5976	Economy	66400.00
0005435839622	5976	Economy	66400.00
0005435839638	5976	Economy	66400.00
0005435472800	5976	Economy	66400.00
0005432142274	5976	Economy	66400.00
0005435839637	5976	Economy	66400.00
0005435839473	18064	Business	199300.00
0005435839293	18064	Business	199300.00
0005435839463	18064	Business	199300.00
0005435472907	18064	Business	199300.00
0005435839390	18064	Business	199300.00
0005435472902	18064	Economy	66400.00
0005432667440	18064	Economy	66400.00
0005435472910	18064	Economy	66400.00
0005435839427	18064	Economy	66400.00
0005435472909	18064	Economy	66400.00
0005435839429	18064	Economy	73100.00
0005435472900	18064	Economy	73100.00
0005435472905	18064	Economy	66400.00
0005435839365	18064	Economy	66400.00
0005435839411	18064	Economy	66400.00
0005435472906	18064	Economy	66400.00
0005435839521	18064	Economy	66400.00
0005432537072	18064	Economy	66400.00
0005435472903	18064	Economy	66400.00
0005432660806	18064	Economy	66400.00
0005432667448	18064	Economy	66400.00
0005435839428	18064	Economy	66400.00
0005435472908	18064	Economy	66400.00
0005432660802	18064	Economy	66400.00
0005435839376	18064	Economy	66400.00
0005435839357	18064	Economy	66400.00
0005435839348	18064	Economy	66400.00
0005435839467	18064	Economy	66400.00
0005435472915	18064	Economy	66400.00
0005432667449	18064	Economy	66400.00
0005432664125	18064	Economy	66400.00
0005432667446	18064	Economy	66400.00
0005435472904	18064	Economy	66400.00
0005435472914	18064	Economy	66400.00
0005435839522	18064	Economy	66400.00
0005432537073	18064	Economy	66400.00
0005435472913	18064	Economy	66400.00
0005432667445	18064	Economy	66400.00
0005435839292	18064	Economy	66400.00
0005435839466	18064	Economy	66400.00
0005435472911	18064	Economy	66400.00
0005435472912	18064	Economy	66400.00
0005435839366	18064	Economy	66400.00
0005435472901	18064	Economy	66400.00
0005435839368	18064	Economy	66400.00
0005435839419	18064	Economy	66400.00
0005435472916	18064	Economy	66400.00
0005433462733	19915	Business	146400.00
0005433462741	19915	Business	146400.00
0005433460417	19915	Business	146400.00
0005433462737	19915	Economy	48800.00
0005433460416	19915	Economy	48800.00
0005433462728	19915	Economy	48800.00
0005433460422	19915	Economy	48800.00
0005433460420	19915	Economy	48800.00
0005433462732	19915	Economy	48800.00
0005433460421	19915	Economy	48800.00
0005433462731	19915	Economy	48800.00
0005433462739	19915	Economy	48800.00
0005433460424	19915	Economy	48800.00
0005433462738	19915	Economy	48800.00
0005433462740	19915	Economy	48800.00
0005433460418	19915	Economy	48800.00
0005433460423	19915	Economy	48800.00
0005433462730	19915	Economy	48800.00
0005433460425	19915	Economy	48800.00
0005433460411	19915	Economy	48800.00
0005433462729	19915	Economy	48800.00
0005433462725	19915	Economy	48800.00
0005433460415	19915	Economy	48800.00
0005433462722	19915	Economy	48800.00
0005433462736	19915	Economy	48800.00
0005433285194	23017	Business	15700.00
0005435103973	23017	Business	15700.00
0005433285274	23017	Business	15700.00
0005435103975	23017	Business	15700.00
0005433285154	23017	Business	15700.00
0005433285281	23017	Business	15700.00
0005433285164	23017	Economy	5200.00
0005433285220	23017	Economy	5200.00
0005435103968	23017	Economy	5200.00
0005433285276	23017	Economy	5200.00
0005433285273	23017	Economy	5200.00
0005435103969	23017	Economy	5200.00
0005435103976	23017	Economy	5200.00
0005435103974	23017	Economy	5200.00
0005433285260	23017	Economy	5200.00
0005433285205	23017	Economy	5200.00
0005433285211	23017	Economy	5200.00
0005433285270	23017	Economy	5200.00
0005433285193	23017	Economy	5200.00
0005433285254	23017	Economy	5200.00
0005435103972	23017	Economy	5200.00
0005435103977	23017	Economy	5200.00
0005433285153	23017	Economy	5200.00
0005433285160	23017	Economy	5200.00
0005435103970	23017	Economy	5200.00
0005435103971	23017	Economy	5200.00
0005433285271	23017	Economy	5200.00
0005433285044	23017	Economy	5200.00
0005433285201	23017	Economy	5200.00
0005435103978	23017	Economy	5200.00
0005433285210	23017	Economy	5200.00
0005433285255	23017	Economy	5200.00
0005433285306	23017	Economy	5200.00
0005433285110	23017	Economy	5200.00
0005433285307	23017	Economy	5200.00
0005433285269	23017	Economy	5200.00
0005433285112	23017	Economy	5200.00
0005433285282	23017	Economy	5200.00
0005433285163	23017	Economy	5200.00
0005433285197	23017	Economy	5200.00
0005435103896	32055	Business	15700.00
0005433285507	32055	Business	15700.00
0005435103891	32055	Business	15700.00
0005435103904	32055	Business	15700.00
0005435103860	32055	Business	15700.00
0005435103888	32055	Economy	5200.00
0005435103907	32055	Economy	5200.00
0005433285504	32055	Economy	5200.00
0005435103901	32055	Economy	5200.00
0005433285493	32055	Economy	5200.00
0005433285490	32055	Economy	5200.00
0005435103893	32055	Economy	5200.00
0005435103886	32055	Economy	5200.00
0005433285489	32055	Economy	5200.00
0005435103885	32055	Economy	5200.00
0005433285491	32055	Economy	5200.00
0005433285517	32055	Economy	5200.00
0005435103863	32055	Economy	5700.00
0005433285495	32055	Economy	5700.00
0005433285516	32055	Economy	5200.00
0005435103867	32055	Economy	5200.00
0005433285506	32055	Economy	5200.00
0005435103903	32055	Economy	5200.00
0005433285512	32055	Economy	5200.00
0005433285488	32055	Economy	5200.00
0005433285515	32055	Economy	5200.00
0005435103899	32055	Economy	5200.00
0005433285510	32055	Economy	5200.00
0005433285505	32055	Economy	5200.00
0005433285496	32055	Economy	5200.00
0005433285508	32055	Economy	5200.00
0005433285511	32055	Economy	5200.00
0005433285514	32055	Economy	5200.00
0005433285509	32055	Economy	5200.00
0005433285492	32055	Economy	5200.00
0005433285499	32055	Economy	5200.00
0005435103902	32055	Economy	5200.00
0005433285513	32055	Economy	5200.00
0005433285494	32055	Economy	5200.00
0005433285501	32055	Economy	5200.00
0005435103868	32055	Economy	5200.00
0005433285497	32055	Economy	5200.00
0005435103869	32055	Economy	5200.00
0005433285503	32055	Economy	5200.00
0005433285498	32055	Economy	5200.00
0005435103861	32055	Economy	5200.00
0005433285502	32055	Economy	5200.00
0005433285500	32055	Economy	5200.00
0005432802447	19948	Business	150400.00
0005432892760	19948	Business	150400.00
0005433111509	19948	Business	150400.00
0005432892773	19948	Business	150400.00
0005432802474	19948	Business	150400.00
0005432802466	19948	Business	150400.00
0005432802455	19948	Business	150400.00
0005432802437	19948	Business	150400.00
0005432892766	19948	Business	150400.00
0005432802489	19948	Business	150400.00
0005433112378	19948	Business	150400.00
0005433112379	19948	Business	150400.00
0005432802497	19948	Economy	50100.00
0005432802494	19948	Economy	50100.00
0005433112374	19948	Economy	50100.00
0005432802481	19948	Economy	50100.00
0005432892769	19948	Economy	50100.00
0005433112377	19948	Economy	50100.00
0005432802439	19948	Economy	50100.00
0005433112380	19948	Economy	50100.00
0005432892765	19948	Economy	50100.00
0005432802443	19948	Economy	50100.00
0005432802450	19948	Economy	50100.00
0005433112373	19948	Economy	55200.00
0005433111510	19948	Economy	55200.00
0005432802454	19948	Economy	55200.00
0005432892768	19948	Economy	50100.00
0005432892775	19948	Economy	50100.00
0005433111506	19948	Economy	50100.00
0005432802469	19948	Economy	50100.00
0005432892764	19948	Economy	50100.00
0005432802459	19948	Economy	50100.00
0005433112382	19948	Economy	50100.00
0005432802441	19948	Economy	50100.00
0005433112375	19948	Economy	50100.00
0005432802500	19948	Economy	50100.00
0005433111518	19948	Economy	50100.00
0005432802445	19948	Economy	50100.00
0005432802470	19948	Economy	50100.00
0005432802440	19948	Economy	50100.00
0005432892770	19948	Economy	50100.00
0005432802436	19948	Economy	50100.00
0005432802467	19948	Economy	50100.00
0005433111519	19948	Economy	50100.00
0005433111512	19948	Economy	50100.00
0005433111516	19948	Economy	50100.00
0005432802438	19948	Economy	50100.00
0005432892774	19948	Economy	50100.00
0005433111508	19948	Economy	50100.00
0005432892772	19948	Economy	50100.00
0005432802471	19948	Economy	50100.00
0005433112376	19948	Economy	50100.00
0005433112383	19948	Economy	50100.00
0005433111513	19948	Economy	50100.00
0005433111505	19948	Economy	50100.00
0005432802465	19948	Economy	50100.00
0005432892762	19948	Economy	50100.00
0005432802453	19948	Economy	50100.00
0005433111517	19948	Economy	50100.00
0005432802479	19948	Economy	50100.00
0005433111504	19948	Economy	50100.00
0005433111511	19948	Economy	50100.00
0005432802452	19948	Economy	50100.00
0005432802480	19948	Economy	50100.00
0005432802487	19948	Economy	50100.00
0005432892761	19948	Economy	50100.00
0005432802451	19948	Economy	50100.00
0005433112381	19948	Economy	50100.00
0005433111514	19948	Economy	50100.00
0005433112372	19948	Economy	50100.00
0005432802473	19948	Economy	50100.00
0005432802446	19948	Economy	50100.00
0005432892771	19948	Economy	50100.00
0005432802499	19948	Economy	50100.00
0005433111515	19948	Economy	50100.00
0005432802442	19948	Economy	50100.00
0005432802490	19948	Economy	50100.00
0005432892763	19948	Economy	50100.00
0005433111507	19948	Economy	50100.00
0005432892767	19948	Economy	50100.00
0005433112371	19948	Economy	50100.00
0005432802472	19948	Economy	50100.00
0005432892759	19948	Economy	50100.00
0005432802488	19948	Economy	50100.00
0005432802468	19948	Economy	50100.00
0005433111503	19948	Economy	50100.00
0005435214041	30620	Business	42100.00
0005432428924	30620	Business	42100.00
0005432527604	30620	Business	42100.00
0005432527255	30620	Business	42100.00
0005434067488	30620	Business	42100.00
0005432527855	30620	Business	42100.00
0005435213999	30620	Business	42100.00
0005435214061	30620	Business	42100.00
0005432527803	30620	Business	42100.00
0005434067550	30620	Business	42100.00
0005432527802	30620	Business	42100.00
0005432528187	30620	Business	42100.00
0005432528356	30620	Business	42100.00
0005432528359	30620	Business	42100.00
0005435214045	30620	Business	42100.00
0005432428916	30620	Business	42100.00
0005435214000	30620	Business	42100.00
0005434067498	30620	Business	42100.00
0005435725638	30620	Business	42100.00
0005434067708	30620	Business	42100.00
0005432527718	30620	Business	42100.00
0005432527673	30620	Business	42100.00
0005432527574	30620	Business	42100.00
0005435214044	30620	Business	42100.00
0005432528293	30620	Business	42100.00
0005432527688	30620	Business	42100.00
0005434067709	30620	Comfort	23900.00
0005432527786	30620	Comfort	23900.00
0005434067359	30620	Comfort	23900.00
0005435214002	30620	Comfort	23900.00
0005435214032	30620	Comfort	23900.00
0005432528132	30620	Comfort	23900.00
0005435214048	30620	Comfort	23900.00
0005432527388	30620	Comfort	23900.00
0005434067461	30620	Comfort	23900.00
0005435214005	30620	Comfort	23900.00
0005432527398	30620	Comfort	23900.00
0005432528015	30620	Comfort	23900.00
0005432211558	30620	Comfort	23900.00
0005432527726	30620	Comfort	23900.00
0005432527664	30620	Comfort	23900.00
0005434066987	30620	Comfort	23900.00
0005432527326	30620	Comfort	23900.00
0005435213996	30620	Comfort	23900.00
0005432527488	30620	Comfort	23900.00
0005434067234	30620	Comfort	23900.00
0005432527597	30620	Comfort	23900.00
0005435214025	30620	Comfort	23900.00
0005435214037	30620	Comfort	23900.00
0005432528044	30620	Comfort	23900.00
0005432527672	30620	Comfort	23900.00
0005432528096	30620	Comfort	23900.00
0005432159889	30620	Comfort	23900.00
0005432527470	30620	Comfort	23900.00
0005435214014	30620	Comfort	23900.00
0005434067191	30620	Comfort	23900.00
0005432527549	30620	Comfort	23900.00
0005432527518	30620	Comfort	23900.00
0005435213995	30620	Comfort	23900.00
0005435214038	30620	Comfort	23900.00
0005432527681	30620	Comfort	23900.00
0005432528003	30620	Comfort	23900.00
0005432528038	30620	Comfort	23900.00
0005432528021	30620	Comfort	23900.00
0005433656694	30620	Comfort	23900.00
0005432527901	30620	Comfort	23900.00
0005434067441	30620	Comfort	23900.00
0005434067420	30620	Economy	14000.00
0005435214023	30620	Economy	14000.00
0005432527503	30620	Economy	14000.00
0005432527680	30620	Economy	14000.00
0005432527537	30620	Economy	14000.00
0005432527378	30620	Economy	14000.00
0005432211551	30620	Economy	14000.00
0005435630989	30620	Economy	14000.00
0005434067101	30620	Economy	14000.00
0005432527772	30620	Economy	14000.00
0005432527079	30620	Economy	14000.00
0005432527733	30620	Economy	14000.00
0005432527894	30620	Economy	14000.00
0005432527827	30620	Economy	14000.00
0005432528004	30620	Economy	14000.00
0005432527801	30620	Economy	14000.00
0005434067589	30620	Economy	14000.00
0005432527413	30620	Economy	14000.00
0005432527852	30620	Economy	14000.00
0005435214015	30620	Economy	14000.00
0005435214012	30620	Economy	14000.00
0005435214047	30620	Economy	14000.00
0005432527969	30620	Economy	14000.00
0005432527753	30620	Economy	14000.00
0005435214008	30620	Economy	14000.00
0005432527674	30620	Economy	14000.00
0005432527399	30620	Economy	14000.00
0005435214027	30620	Economy	14000.00
0005432527618	30620	Economy	14000.00
0005434067462	30620	Economy	14000.00
0005434067421	30620	Economy	14000.00
0005432527244	30620	Economy	14000.00
0005432211553	30620	Economy	14000.00
0005432527225	30620	Economy	14000.00
0005434067355	30620	Economy	14000.00
0005432527686	30620	Economy	14000.00
0005435214033	30620	Economy	14000.00
0005435214053	30620	Economy	14000.00
0005432527517	30620	Economy	14000.00
0005435725635	30620	Economy	14000.00
0005432528167	30620	Economy	14000.00
0005435214026	30620	Economy	14000.00
0005434067350	30620	Economy	14000.00
0005432527810	30620	Economy	14000.00
0005435214051	30620	Economy	14000.00
0005435214006	30620	Economy	14000.00
0005432527679	30620	Economy	14000.00
0005432527866	30620	Economy	14000.00
0005432527649	30620	Economy	14000.00
0005432527389	30620	Economy	14000.00
0005432211557	30620	Economy	14000.00
0005432527592	30620	Economy	14000.00
0005434067473	30620	Economy	14000.00
0005432527993	30620	Economy	14000.00
0005432527256	30620	Economy	14000.00
0005432527647	30620	Economy	14000.00
0005435214011	30620	Economy	14000.00
0005435213998	30620	Economy	14000.00
0005435214049	30620	Economy	15400.00
0005435214030	30620	Economy	14000.00
0005435214028	30620	Economy	15400.00
0005432527277	30620	Economy	15400.00
0005432527853	30620	Economy	14000.00
0005432527411	30620	Economy	14000.00
0005432527641	30620	Economy	15400.00
0005432527671	30620	Economy	14000.00
0005434067585	30620	Economy	14000.00
0005432527532	30620	Economy	15400.00
0005432528227	30620	Economy	14000.00
0005435214039	30620	Economy	14000.00
0005434067354	30620	Economy	14000.00
0005435214052	30620	Economy	14000.00
0005434067613	30620	Economy	14000.00
0005432527683	30620	Economy	14000.00
0005435214021	30620	Economy	14000.00
0005432527734	30620	Economy	14000.00
0005432428933	30620	Economy	14000.00
0005435214003	30620	Economy	14000.00
0005434067213	30620	Economy	14000.00
0005432527425	30620	Economy	14000.00
0005432528019	30620	Economy	14000.00
0005432527469	30620	Economy	14000.00
0005434067563	30620	Economy	14000.00
0005435214043	30620	Economy	14000.00
0005432528152	30620	Economy	14000.00
0005432527701	30620	Economy	14000.00
0005434067269	30620	Economy	14000.00
0005432526976	30620	Economy	14000.00
0005434067333	30620	Economy	14000.00
0005432527538	30620	Economy	14000.00
0005432527762	30620	Economy	14000.00
0005435214022	30620	Economy	14000.00
0005435213994	30620	Economy	14000.00
0005435630990	30620	Economy	14000.00
0005432527562	30620	Economy	14000.00
0005432527677	30620	Economy	14000.00
0005432527658	30620	Economy	14000.00
0005435725637	30620	Economy	14000.00
0005432527700	30620	Economy	14000.00
0005432528153	30620	Economy	14000.00
0005435630988	30620	Economy	14000.00
0005434067650	30620	Economy	14000.00
0005432527876	30620	Economy	14000.00
0005432537044	30620	Economy	14000.00
0005434067330	30620	Economy	14000.00
0005432527940	30620	Economy	14000.00
0005434067433	30620	Economy	14000.00
0005432527619	30620	Economy	14000.00
0005432527687	30620	Economy	14000.00
0005434067144	30620	Economy	14000.00
0005432528358	30620	Economy	14000.00
0005435214034	30620	Economy	14000.00
0005435214019	30620	Economy	14000.00
0005432527650	30620	Economy	14000.00
0005435214050	30620	Economy	14000.00
0005435214035	30620	Economy	14000.00
0005432527550	30620	Economy	14000.00
0005435214007	30620	Economy	14000.00
0005432527167	30620	Economy	14000.00
0005435214024	30620	Economy	14000.00
0005432211550	30620	Economy	14000.00
0005432527747	30620	Economy	14000.00
0005435214058	30620	Economy	14000.00
0005432527598	30620	Economy	14000.00
0005432527959	30620	Economy	14000.00
0005432527941	30620	Economy	14000.00
0005432428909	30620	Economy	14000.00
0005432211552	30620	Economy	14000.00
0005435214055	30620	Economy	14000.00
0005434067586	30620	Economy	14000.00
0005435214040	30620	Economy	14000.00
0005434067342	30620	Economy	14000.00
0005432527573	30620	Economy	14000.00
0005432527659	30620	Economy	14000.00
0005432527724	30620	Economy	14000.00
0005434067381	30620	Economy	14000.00
0005435214060	30620	Economy	14000.00
0005434067233	30620	Economy	14000.00
0005434067608	30620	Economy	14000.00
0005432528034	30620	Economy	14000.00
0005435213993	30620	Economy	14000.00
0005433656696	30620	Economy	14000.00
0005434067434	30620	Economy	14000.00
0005432527899	30620	Economy	14000.00
0005432527663	30620	Economy	14000.00
0005432527300	30620	Economy	14000.00
0005432528113	30620	Economy	14000.00
0005432527468	30620	Economy	14000.00
0005432159888	30620	Economy	14000.00
0005432528020	30620	Economy	14000.00
0005432527426	30620	Economy	14000.00
0005432537058	30620	Economy	14000.00
0005435214009	30620	Economy	14000.00
0005434067614	30620	Economy	14000.00
0005432527954	30620	Economy	14000.00
0005432533282	30620	Economy	14000.00
0005435214031	30620	Economy	14000.00
0005432527385	30620	Economy	14000.00
0005433656695	30620	Economy	14000.00
0005432428923	30620	Economy	14000.00
0005432527600	30620	Economy	14000.00
0005434067361	30620	Economy	14000.00
0005434067391	30620	Economy	14000.00
0005432211554	30620	Economy	14000.00
0005432527900	30620	Economy	14000.00
0005432527787	30620	Economy	14000.00
0005434067490	30620	Economy	14000.00
0005432527178	30620	Economy	14000.00
0005432527608	30620	Economy	14000.00
0005435214010	30620	Economy	14000.00
0005432527719	30620	Economy	14000.00
0005434067257	30620	Economy	15400.00
0005432528292	30620	Economy	14000.00
0005435214042	30620	Economy	15400.00
0005432527723	30620	Economy	15400.00
0005434067422	30620	Economy	14000.00
0005435214004	30620	Economy	14000.00
0005432527980	30620	Economy	14000.00
0005432527640	30620	Economy	14000.00
0005432528128	30620	Economy	14000.00
0005434067538	30620	Economy	14000.00
0005434067072	30620	Economy	14000.00
0005432526977	30620	Economy	14000.00
0005432527939	30620	Economy	14000.00
0005432527475	30620	Economy	14000.00
0005434067440	30620	Economy	14000.00
0005432211555	30620	Economy	14000.00
0005435214054	30620	Economy	14000.00
0005432527752	30620	Economy	14000.00
0005432528035	30620	Economy	14000.00
0005432527646	30620	Economy	14000.00
0005434067106	30620	Economy	14000.00
0005432535806	30620	Economy	14000.00
0005435725636	30620	Economy	14000.00
0005435214017	30620	Economy	14000.00
0005432528154	30620	Economy	14000.00
0005432527476	30620	Economy	14000.00
0005435214046	30620	Economy	14000.00
0005432527665	30620	Economy	14000.00
0005435214056	30620	Economy	14000.00
0005432527684	30620	Economy	14000.00
0005432527893	30620	Economy	14000.00
0005434067126	30620	Economy	14000.00
0005434067190	30620	Economy	14000.00
0005432159890	30620	Economy	14000.00
0005432527406	30620	Economy	14000.00
0005432527276	30620	Economy	14000.00
0005435213997	30620	Economy	14000.00
0005432527817	30620	Economy	14000.00
0005432537055	30620	Economy	14000.00
0005434067525	30620	Economy	14000.00
0005434067465	30620	Economy	14000.00
0005434067380	30620	Economy	14000.00
0005434067097	30620	Economy	14000.00
0005432159891	30620	Economy	14000.00
0005432527474	30620	Economy	14000.00
0005434067555	30620	Economy	14000.00
0005432528357	30620	Economy	14000.00
0005435214036	30620	Economy	14000.00
0005435214001	30620	Economy	14000.00
0005432428929	30620	Economy	14000.00
0005432527504	30620	Economy	14000.00
0005432527624	30620	Economy	14000.00
0005434067251	30620	Economy	14000.00
0005435214020	30620	Economy	14000.00
0005435214059	30620	Economy	14000.00
0005432527301	30620	Economy	14000.00
0005432528228	30620	Economy	14000.00
0005432527666	30620	Economy	14000.00
0005434067329	30620	Economy	14000.00
0005432527842	30620	Economy	14000.00
0005432428915	30620	Economy	14000.00
0005435214057	30620	Economy	14000.00
0005434067272	30620	Economy	14000.00
0005434067328	30620	Economy	14000.00
0005434067143	30620	Economy	14000.00
0005432528039	30620	Economy	14000.00
0005432527828	30620	Economy	14000.00
0005434067096	30620	Economy	14000.00
0005434067357	30620	Economy	14000.00
0005432528102	30620	Economy	14000.00
0005435214018	30620	Economy	14000.00
0005435725634	30620	Economy	14000.00
0005432527605	30620	Economy	14000.00
0005435214013	30620	Economy	14000.00
0005432527384	30620	Economy	14000.00
0005432527765	30620	Economy	14000.00
0005432527678	30620	Economy	14000.00
0005432528258	30620	Economy	14000.00
0005434067472	30620	Economy	14000.00
0005432528257	30620	Economy	14000.00
0005434067459	30620	Economy	14000.00
0005432428920	30620	Economy	14000.00
0005432533284	30620	Economy	14000.00
0005432527303	30620	Economy	14000.00
0005434067514	30620	Economy	14000.00
0005434067492	30620	Economy	14000.00
0005434067084	30620	Economy	14000.00
0005432527758	30620	Economy	14000.00
0005434067510	30620	Economy	14000.00
0005434067491	30620	Economy	14000.00
0005432527662	30620	Economy	14000.00
0005432527797	30620	Economy	14000.00
0005432535805	30620	Economy	14000.00
0005432527186	30620	Economy	14000.00
0005434067358	30620	Economy	14000.00
0005432527748	30620	Economy	14000.00
0005432537056	30620	Economy	14000.00
0005432533283	30620	Economy	14000.00
0005435214029	30620	Economy	14000.00
0005432211556	30620	Economy	14000.00
0005432428934	30620	Economy	14000.00
0005435214016	30620	Economy	14000.00
0005434067595	30620	Economy	14000.00
0005433368144	24820	Business	9800.00
0005433368142	24820	Business	9800.00
0005435652807	24820	Business	9800.00
0005433368149	24820	Business	9800.00
0005435652797	24820	Business	9800.00
0005433368148	24820	Business	9800.00
0005433368166	24820	Business	9800.00
0005435652645	24820	Business	9800.00
0005433368146	24820	Business	9800.00
0005433368150	24820	Business	9800.00
0005433368169	24820	Business	9800.00
0005433368164	24820	Economy	3300.00
0005435652814	24820	Economy	3300.00
0005435652897	24820	Economy	3300.00
0005433368161	24820	Economy	3300.00
0005433368152	24820	Economy	3300.00
0005433368167	24820	Economy	3300.00
0005435652889	24820	Economy	3300.00
0005433368155	24820	Economy	3300.00
0005433368145	24820	Economy	3300.00
0005433368160	24820	Economy	3300.00
0005435652930	24820	Economy	3600.00
0005435652821	24820	Economy	3600.00
0005435653068	24820	Economy	3600.00
0005433368176	24820	Economy	3600.00
0005435652863	24820	Economy	3300.00
0005435653045	24820	Economy	3300.00
0005433368147	24820	Economy	3300.00
0005435653046	24820	Economy	3300.00
0005433368177	24820	Economy	3300.00
0005433368141	24820	Economy	3300.00
0005433368168	24820	Economy	3300.00
0005435652646	24820	Economy	3300.00
0005435652975	24820	Economy	3300.00
0005435652782	24820	Economy	3300.00
0005435652943	24820	Economy	3300.00
0005433368173	24820	Economy	3300.00
0005433368157	24820	Economy	3300.00
0005435652924	24820	Economy	3300.00
0005435652926	24820	Economy	3300.00
0005433368151	24820	Economy	3300.00
0005435652878	24820	Economy	3300.00
0005435652967	24820	Economy	3300.00
0005435652925	24820	Economy	3300.00
0005433368154	24820	Economy	3300.00
0005433368159	24820	Economy	3300.00
0005433368174	24820	Economy	3300.00
0005435652864	24820	Economy	3300.00
0005433368140	24820	Economy	3300.00
0005435652795	24820	Economy	3300.00
0005435652896	24820	Economy	3300.00
0005435652808	24820	Economy	3300.00
0005435652932	24820	Economy	3300.00
0005435652809	24820	Economy	3300.00
0005433368163	24820	Economy	3300.00
0005433368153	24820	Economy	3300.00
0005435653059	24820	Economy	3300.00
0005435652894	24820	Economy	3300.00
0005435652796	24820	Economy	3300.00
0005433368175	24820	Economy	3300.00
0005435652895	24820	Economy	3300.00
0005435653037	24820	Economy	3300.00
0005433368165	24820	Economy	3300.00
0005433368156	24820	Economy	3300.00
0005435652868	24820	Economy	3300.00
0005435653002	24820	Economy	3300.00
0005433368170	24820	Economy	3300.00
0005433368172	24820	Economy	3300.00
0005433368158	24820	Economy	3300.00
0005433368143	24820	Economy	3300.00
0005433368162	24820	Economy	3300.00
0005435652958	24820	Economy	3300.00
0005435652867	24820	Economy	3300.00
0005435652966	24820	Economy	3300.00
0005435652788	24820	Economy	3300.00
0005435653058	24820	Economy	3300.00
0005433368171	24820	Economy	3300.00
0005435652917	24820	Economy	3300.00
0005435653040	24820	Economy	3300.00
0005435653054	24820	Economy	3300.00
0005435949797	6602	Economy	20600.00
0005435949801	6602	Economy	18700.00
0005435949794	6602	Economy	18700.00
0005435949804	6602	Economy	18700.00
0005435949796	6602	Economy	18700.00
0005435949800	6602	Economy	18700.00
0005435949793	6602	Economy	18700.00
0005435949799	6602	Economy	18700.00
0005435949798	6602	Economy	18700.00
0005435949802	6602	Economy	18700.00
0005435949792	6602	Economy	18700.00
0005435949795	6602	Economy	18700.00
0005435949803	6602	Economy	18700.00
0005434979992	2074	Economy	10500.00
0005434980019	2074	Economy	10500.00
0005434980001	2074	Economy	10500.00
0005434980013	2074	Economy	10500.00
0005434979996	2074	Economy	9500.00
0005434979994	2074	Economy	9500.00
0005434980014	2074	Economy	9500.00
0005434980017	2074	Economy	9500.00
0005434980005	2074	Economy	9500.00
0005434979998	2074	Economy	9500.00
0005434980015	2074	Economy	9500.00
0005434980008	2074	Economy	9500.00
0005434980010	2074	Economy	9500.00
0005435801717	2074	Economy	9500.00
0005435801718	2074	Economy	9500.00
0005434980000	2074	Economy	9500.00
0005434980009	2074	Economy	9500.00
0005434980018	2074	Economy	9500.00
0005434979995	2074	Economy	9500.00
0005434980020	2074	Economy	9500.00
0005434980004	2074	Economy	9500.00
0005435801716	2074	Economy	9500.00
0005434980011	2074	Economy	9500.00
0005434980006	2074	Economy	9500.00
0005435801719	2074	Economy	9500.00
0005434979997	2074	Economy	9500.00
0005434979991	2074	Economy	9500.00
0005434980002	2074	Economy	9500.00
0005434980003	2074	Economy	9500.00
0005434980016	2074	Economy	9500.00
0005434980007	2074	Economy	9500.00
0005434979993	2074	Economy	9500.00
0005434980012	2074	Economy	9500.00
0005434979999	2074	Economy	9500.00
0005434979842	23546	Economy	10500.00
0005434979591	23546	Economy	10500.00
0005434979529	23546	Economy	10500.00
0005434979592	23546	Economy	10500.00
0005434979685	23546	Economy	9500.00
0005434979695	23546	Economy	9500.00
0005434979708	23546	Economy	9500.00
0005434979719	23546	Economy	9500.00
0005434979594	23546	Economy	9500.00
0005434979728	23546	Economy	9500.00
0005434979613	23546	Economy	9500.00
0005434979652	23546	Economy	9500.00
0005434979784	23546	Economy	9500.00
0005434979667	23546	Economy	9500.00
0005434979593	23546	Economy	9500.00
0005434979696	23546	Economy	9500.00
0005434979714	23546	Economy	9500.00
0005434979729	23546	Economy	9500.00
0005434979694	23546	Economy	9500.00
0005434979677	23546	Economy	9500.00
0005434979668	23546	Economy	9500.00
0005434979785	23546	Economy	9500.00
0005435801709	23546	Economy	9500.00
0005434979649	23546	Economy	9500.00
0005434979751	23546	Economy	9500.00
0005434979752	23546	Economy	9500.00
0005434979578	23546	Economy	9500.00
0005434979686	23546	Economy	9500.00
0005434979733	23546	Economy	9500.00
0005434979589	23546	Economy	9500.00
0005434979720	23546	Economy	9500.00
0005434979734	23546	Economy	9500.00
0005435801695	23546	Economy	9500.00
0005434979672	23546	Economy	9500.00
0005434979614	23546	Economy	9500.00
0005434979730	23546	Economy	9500.00
0005434979841	23546	Economy	9500.00
0005434979590	23546	Economy	9500.00
0005434952558	2671	Economy	5300.00
0005434952559	2671	Economy	5300.00
0005434952556	2671	Economy	5300.00
0005434952557	2671	Economy	5300.00
0005433256426	2672	Economy	5300.00
0005433256422	2672	Economy	5300.00
0005433256415	2672	Economy	5300.00
0005433256421	2672	Economy	5300.00
0005434952508	28282	Economy	5300.00
0005434952538	28282	Economy	5300.00
0005433256437	28282	Economy	5300.00
0005434952521	28282	Economy	5300.00
0005434952525	28282	Economy	5300.00
0005434952536	28282	Economy	5300.00
0005433256438	28282	Economy	5300.00
0005434952526	28282	Economy	5300.00
0005434952520	28282	Economy	5300.00
0005434952524	28282	Economy	5300.00
0005433256439	28282	Economy	5300.00
0005434302855	19724	Economy	8700.00
0005433112386	19724	Economy	8700.00
0005433111523	19724	Economy	8700.00
0005433111522	19724	Economy	8700.00
0005434302856	19724	Economy	8700.00
0005433111521	19724	Economy	8700.00
0005433112387	19724	Economy	8700.00
0005434138096	11954	Business	9700.00
0005434138258	11954	Business	9700.00
0005434138034	11954	Business	9700.00
0005434138245	11954	Business	9700.00
0005434138094	11954	Business	9700.00
0005434138349	11954	Business	9700.00
0005434138422	11954	Business	9700.00
0005434138113	11954	Business	9700.00
0005434138111	11954	Business	9700.00
0005434137827	11954	Business	9700.00
0005434138013	11954	Business	9700.00
0005434138095	11954	Economy	3200.00
0005434138157	11954	Economy	3200.00
0005434138028	11954	Economy	3200.00
0005434137797	11954	Economy	3200.00
0005434138072	11954	Economy	3200.00
0005434138035	11954	Economy	3200.00
0005434138262	11954	Economy	3200.00
0005434137957	11954	Economy	3200.00
0005434138212	11954	Economy	3500.00
0005434137867	11954	Economy	3500.00
0005434137936	11954	Economy	3500.00
0005434137902	11954	Economy	3500.00
0005434138454	11954	Economy	3200.00
0005434138205	11954	Economy	3200.00
0005434137825	11954	Economy	3200.00
0005434138271	11954	Economy	3200.00
0005434137712	11954	Economy	3200.00
0005434137959	11954	Economy	3200.00
0005434138216	11954	Economy	3200.00
0005434138027	11954	Economy	3200.00
0005434137977	11954	Economy	3200.00
0005434138082	11954	Economy	3200.00
0005434138369	11954	Economy	3200.00
0005434137900	11954	Economy	3200.00
0005434138052	11954	Economy	3200.00
0005434137954	11954	Economy	3200.00
0005434138247	11954	Economy	3200.00
0005434138139	11954	Economy	3200.00
0005434138179	11954	Economy	3200.00
0005434137986	11954	Economy	3200.00
0005434137645	11954	Economy	3200.00
0005434138071	11954	Economy	3200.00
0005434137965	11954	Economy	3200.00
0005434138158	11954	Economy	3200.00
0005434137958	11954	Economy	3200.00
0005434137971	11954	Economy	3200.00
0005434137963	11954	Economy	3200.00
0005434138209	11954	Economy	3200.00
0005434137899	11954	Economy	3200.00
0005434138426	11954	Economy	3200.00
0005434138305	11954	Economy	3200.00
0005434138135	11954	Economy	3200.00
0005434137890	11954	Economy	3200.00
0005434138081	11954	Economy	3200.00
0005434137868	11954	Economy	3200.00
0005434137904	11954	Economy	3200.00
0005434137708	11954	Economy	3200.00
0005434138244	11954	Economy	3200.00
0005434138107	11954	Economy	3200.00
0005434137294	11954	Economy	3200.00
0005434138053	11954	Economy	3200.00
0005434137711	11954	Economy	3200.00
0005434137901	11954	Economy	3200.00
0005434138323	11954	Economy	3200.00
0005434138408	11954	Economy	3200.00
0005434137295	11954	Economy	3200.00
0005434138348	11954	Economy	3200.00
0005434138427	11954	Economy	3200.00
0005434138324	11954	Economy	3200.00
0005434137855	11954	Economy	3200.00
0005434137976	11954	Economy	3200.00
0005434137796	11954	Economy	3200.00
0005434138122	11954	Economy	3200.00
0005434138451	11954	Economy	3200.00
0005434138065	11954	Economy	3200.00
0005434138208	11954	Economy	3200.00
0005434137962	11954	Economy	3200.00
0005434137679	11954	Economy	3200.00
0005434137822	11954	Economy	3200.00
0005434138121	11954	Economy	3200.00
0005434137997	11954	Economy	3200.00
0005434138450	11954	Economy	3200.00
0005434137903	11954	Economy	3200.00
0005434138702	28729	Business	9700.00
0005434138700	28729	Business	9700.00
0005434138684	28729	Business	9700.00
0005434138671	28729	Business	9700.00
0005434138642	28729	Business	9700.00
0005434138695	28729	Business	9700.00
0005434138704	28729	Business	9700.00
0005434138668	28729	Business	9700.00
0005434138701	28729	Economy	3200.00
0005434138682	28729	Economy	3200.00
0005434138698	28729	Economy	3200.00
0005434138640	28729	Economy	3200.00
0005434138680	28729	Economy	3200.00
0005434138648	28729	Economy	3200.00
0005434138686	28729	Economy	3200.00
0005434138633	28729	Economy	3200.00
0005434138689	28729	Economy	3200.00
0005434138662	28729	Economy	3200.00
0005434138656	28729	Economy	3500.00
0005434138707	28729	Economy	3500.00
0005434138632	28729	Economy	3500.00
0005434138713	28729	Economy	3500.00
0005434138645	28729	Economy	3200.00
0005434138692	28729	Economy	3200.00
0005434138675	28729	Economy	3200.00
0005434138676	28729	Economy	3200.00
0005434138715	28729	Economy	3200.00
0005434138683	28729	Economy	3200.00
0005434138659	28729	Economy	3200.00
0005434138653	28729	Economy	3200.00
0005434138688	28729	Economy	3200.00
0005434138644	28729	Economy	3200.00
0005434138703	28729	Economy	3200.00
0005434138706	28729	Economy	3200.00
0005434138699	28729	Economy	3200.00
0005434138655	28729	Economy	3200.00
0005434138712	28729	Economy	3200.00
0005434138664	28729	Economy	3200.00
0005434138667	28729	Economy	3200.00
0005434138636	28729	Economy	3200.00
0005434138681	28729	Economy	3200.00
0005434138643	28729	Economy	3200.00
0005434138678	28729	Economy	3200.00
0005434138663	28729	Economy	3200.00
0005434138691	28729	Economy	3200.00
0005434138637	28729	Economy	3200.00
0005434138638	28729	Economy	3200.00
0005434138651	28729	Economy	3200.00
0005434138654	28729	Economy	3200.00
0005434138641	28729	Economy	3200.00
0005434138639	28729	Economy	3200.00
0005434138709	28729	Economy	3200.00
0005434138696	28729	Economy	3200.00
0005434138673	28729	Economy	3200.00
0005434138697	28729	Economy	3200.00
0005434138661	28729	Economy	3200.00
0005434138693	28729	Economy	3200.00
0005434138670	28729	Economy	3200.00
0005434138657	28729	Economy	3200.00
0005434138635	28729	Economy	3200.00
0005434138679	28729	Economy	3200.00
0005434138666	28729	Economy	3200.00
0005434138658	28729	Economy	3200.00
0005434138694	28729	Economy	3200.00
0005434138711	28729	Economy	3200.00
0005434138705	28729	Economy	3200.00
0005434138669	28729	Economy	3200.00
0005434138714	28729	Economy	3200.00
0005434138660	28729	Economy	3200.00
0005434138690	28729	Economy	3200.00
0005434138687	28729	Economy	3200.00
0005434138649	28729	Economy	3200.00
0005434138672	28729	Economy	3200.00
0005434138652	28729	Economy	3200.00
0005434138674	28729	Economy	3200.00
0005434138710	28729	Economy	3200.00
0005434138685	28729	Economy	3200.00
0005434138646	28729	Economy	3200.00
0005434138665	28729	Economy	3200.00
0005434138650	28729	Economy	3200.00
0005434138634	28729	Economy	3200.00
0005434138647	28729	Economy	3200.00
0005434138708	28729	Economy	3200.00
0005434138677	28729	Economy	3200.00
0005433538932	6771	Economy	10900.00
0005433538937	6771	Economy	9900.00
0005433538928	6771	Economy	9900.00
0005433534514	6771	Economy	9900.00
0005433538934	6771	Economy	9900.00
0005435259773	6771	Economy	9900.00
0005435259766	6771	Economy	9900.00
0005435259743	6771	Economy	9900.00
0005433534513	6771	Economy	9900.00
0005433538933	6771	Economy	9900.00
0005433538930	6771	Economy	9900.00
0005435259737	6771	Economy	9900.00
0005433538936	6771	Economy	9900.00
0005433538935	6771	Economy	9900.00
0005433538931	6771	Economy	9900.00
0005433538929	6771	Economy	9900.00
0005435259746	6771	Economy	9900.00
0005435259790	25010	Economy	10900.00
0005433534499	25010	Economy	10900.00
0005435259789	25010	Economy	9900.00
0005435259786	25010	Economy	9900.00
0005433538891	25010	Economy	9900.00
0005433538860	25010	Economy	9900.00
0005433538849	25010	Economy	9900.00
0005433534498	25010	Economy	9900.00
0005435259787	25010	Economy	9900.00
0005435259788	25010	Economy	9900.00
0005433538892	25010	Economy	9900.00
0005433538854	25010	Economy	9900.00
0005433538851	25010	Economy	9900.00
0005433534491	25010	Economy	9900.00
0005433512014	835	Economy	16100.00
0005433512016	835	Economy	14600.00
0005433512010	835	Economy	14600.00
0005433512009	835	Economy	14600.00
0005432922521	835	Economy	14600.00
0005432922508	835	Economy	14600.00
0005432922529	835	Economy	14600.00
0005433512012	835	Economy	14600.00
0005433512008	835	Economy	14600.00
0005433512011	835	Economy	14600.00
0005433512015	835	Economy	14600.00
0005433512013	835	Economy	14600.00
0005432922507	835	Economy	14600.00
0005433511957	16143	Economy	14600.00
0005433511935	16143	Economy	14600.00
0005432922555	16143	Economy	14600.00
0005433511934	16143	Economy	14600.00
0005432922556	16143	Economy	14600.00
0005432922557	16143	Economy	14600.00
0005433511959	16143	Economy	14600.00
0005433511958	16143	Economy	14600.00
0005433511954	16143	Economy	14600.00
0005433511956	16143	Economy	14600.00
0005432922554	16143	Economy	14600.00
0005433511937	16143	Economy	14600.00
0005434950564	3676	Economy	7900.00
0005434950560	3676	Economy	7900.00
0005435697537	3676	Economy	7900.00
0005435697550	3676	Economy	7900.00
0005435697541	3676	Economy	7200.00
0005435697545	3676	Economy	7200.00
0005435697549	3676	Economy	7200.00
0005435935030	3676	Economy	7200.00
0005435697553	3676	Economy	7200.00
0005435697544	3676	Economy	7200.00
0005435697540	3676	Economy	7200.00
0005434950563	3676	Economy	7200.00
0005435697542	3676	Economy	7200.00
0005435916171	3676	Economy	7200.00
0005435697535	3676	Economy	7200.00
0005435697552	3676	Economy	7200.00
0005435697555	3676	Economy	7200.00
0005435697558	3676	Economy	7200.00
0005435697547	3676	Economy	7200.00
0005435697532	3676	Economy	7200.00
0005435697554	3676	Economy	7200.00
0005435697539	3676	Economy	7200.00
0005434950562	3676	Economy	7200.00
0005435697551	3676	Economy	7200.00
0005435697559	3676	Economy	7200.00
0005435697543	3676	Economy	7200.00
0005435935049	3676	Economy	7200.00
0005435697534	3676	Economy	7200.00
0005435697556	3676	Economy	7200.00
0005435697548	3676	Economy	7200.00
0005435697557	3676	Economy	7200.00
0005435916167	3676	Economy	7200.00
0005435697560	3676	Economy	7200.00
0005435697536	3676	Economy	7200.00
0005435697533	3676	Economy	7200.00
0005434950561	3676	Economy	7200.00
0005435697538	3676	Economy	7200.00
0005435697546	3676	Economy	7200.00
0005435916170	3676	Economy	7200.00
0005434950520	16289	Economy	7900.00
0005435697382	16289	Economy	7900.00
0005435697190	16289	Economy	7900.00
0005435697225	16289	Economy	7900.00
0005435697273	16289	Economy	7200.00
0005435697319	16289	Economy	7200.00
0005435697359	16289	Economy	7200.00
0005435697152	16289	Economy	7200.00
0005435697379	16289	Economy	7200.00
0005435697305	16289	Economy	7200.00
0005435697202	16289	Economy	7200.00
0005435697324	16289	Economy	7200.00
0005435697326	16289	Economy	7200.00
0005434950525	16289	Economy	7200.00
0005435697325	16289	Economy	7200.00
0005435697280	16289	Economy	7200.00
0005435697291	16289	Economy	7200.00
0005435697341	16289	Economy	7200.00
0005434950532	16289	Economy	7200.00
0005435697287	16289	Economy	7200.00
0005434950522	16289	Economy	7200.00
0005435697233	16289	Economy	7200.00
0005435697380	16289	Economy	7200.00
0005435697151	16289	Economy	7200.00
0005435697219	16289	Economy	7200.00
0005435697203	16289	Economy	7200.00
0005435697270	16289	Economy	7200.00
0005435697262	16289	Economy	7200.00
0005435697279	16289	Economy	7200.00
0005434950521	16289	Economy	7200.00
0005435697246	16289	Economy	7200.00
0005435697293	16289	Economy	7200.00
0005435697294	16289	Economy	7200.00
0005435697220	16289	Economy	7200.00
0005435697269	16289	Economy	7200.00
0005435697331	16289	Economy	7200.00
0005435697274	16289	Economy	7200.00
0005435697263	16289	Economy	7200.00
0005435697384	16289	Economy	7200.00
0005435697150	16289	Economy	7200.00
0005434950538	16289	Economy	7200.00
0005435697215	16289	Economy	7200.00
0005435697240	16289	Economy	7200.00
0005435697234	16289	Economy	7200.00
0005435697272	16289	Economy	7200.00
0005435697254	16289	Economy	7200.00
0005435697216	16289	Economy	7200.00
0005435697337	16289	Economy	7200.00
0005435697253	16289	Economy	7200.00
0005435697342	16289	Economy	7200.00
0005434604923	3971	Economy	21300.00
0005432607594	3971	Economy	19300.00
0005434604924	3971	Economy	19300.00
0005435853619	3971	Economy	19300.00
0005435904707	3971	Economy	19300.00
0005434606855	3971	Economy	19300.00
0005432607597	3971	Economy	19300.00
0005434606853	3971	Economy	19300.00
0005433519491	3971	Economy	19300.00
0005434604921	3971	Economy	19300.00
0005434604922	3971	Economy	19300.00
0005435853613	3971	Economy	19300.00
0005435853618	3971	Economy	19300.00
0005434606856	3971	Economy	19300.00
0005435842327	3971	Economy	19300.00
0005434606852	3971	Economy	19300.00
0005433519490	3971	Economy	19300.00
0005434606854	3971	Economy	19300.00
0005434604920	3971	Economy	19300.00
0005432609761	3971	Economy	19300.00
0005432609762	3971	Economy	19300.00
0005434606857	3971	Economy	19300.00
0005432607596	3971	Economy	19300.00
0005433519493	3971	Economy	19300.00
0005433519492	3971	Economy	19300.00
0005432607595	3971	Economy	19300.00
0005433519489	3971	Economy	19300.00
0005432609760	3971	Economy	19300.00
0005435853616	3971	Economy	19300.00
0005435853624	22038	Economy	21300.00
0005435853625	22038	Economy	21300.00
0005433519455	22038	Economy	21300.00
0005433519451	22038	Economy	19300.00
0005434606814	22038	Economy	19300.00
0005435904899	22038	Economy	19300.00
0005433519452	22038	Economy	19300.00
0005433519453	22038	Economy	19300.00
0005433519454	22038	Economy	19300.00
0005433519441	22038	Economy	19300.00
0005435904898	22038	Economy	19300.00
0005433519476	22038	Economy	19300.00
0005433519450	22038	Economy	19300.00
0005433519434	22038	Economy	19300.00
0005433519449	22038	Economy	19300.00
0005435628745	712	Economy	3700.00
0005433348999	712	Economy	3700.00
0005433348997	712	Economy	3700.00
0005435628748	712	Economy	3700.00
0005435628747	712	Economy	3700.00
0005433348998	712	Economy	3700.00
0005435628744	712	Economy	3700.00
0005435628746	712	Economy	3700.00
0005435628711	15957	Economy	3700.00
0005433349032	15957	Economy	3700.00
0005433349030	15957	Economy	3700.00
0005433349034	15957	Economy	3700.00
0005433349031	15957	Economy	3700.00
0005433349033	15957	Economy	3700.00
0005433349029	15957	Economy	3700.00
0005434445258	17206	Economy	7100.00
0005433159302	17206	Economy	7100.00
0005433158129	17206	Economy	7100.00
0005433159316	17206	Economy	7100.00
0005433159314	17206	Economy	7100.00
0005433159303	17206	Economy	7100.00
0005433158125	17206	Economy	7100.00
0005433158124	17206	Economy	7100.00
0005433158130	17206	Economy	7100.00
0005433159315	17206	Economy	7100.00
0005434445259	17206	Economy	7100.00
0005433159330	17589	Economy	7100.00
0005433159332	17589	Economy	7100.00
0005433159331	17589	Economy	7100.00
0005433159329	17589	Economy	7100.00
0005435132964	7915	Economy	5900.00
0005435132954	7915	Economy	5400.00
0005435383158	7915	Economy	5400.00
0005435132956	7915	Economy	5400.00
0005435132955	7915	Economy	5400.00
0005435132957	7915	Economy	5400.00
0005435132960	7915	Economy	5400.00
0005435383142	7915	Economy	5400.00
0005435132962	7915	Economy	5400.00
0005435132961	7915	Economy	5400.00
0005435132963	7915	Economy	5400.00
0005435132959	7915	Economy	5400.00
0005435132958	7915	Economy	5400.00
0005435383141	7915	Economy	5400.00
0005435132853	33069	Economy	5400.00
0005435132885	33069	Economy	5400.00
0005435132874	33069	Economy	5400.00
0005435132852	33069	Economy	5400.00
0005435132867	33069	Economy	5400.00
0005435132899	33069	Economy	5400.00
0005435383192	33069	Economy	5400.00
0005435383188	33069	Economy	5400.00
0005435132932	33069	Economy	5400.00
0005435383187	33069	Economy	5400.00
0005435132877	33069	Economy	5400.00
0005435383190	33069	Economy	5400.00
0005435383191	33069	Economy	5400.00
0005435132844	33069	Economy	5400.00
0005435383189	33069	Economy	5400.00
0005435132831	33069	Economy	5400.00
0005435132886	33069	Economy	5400.00
0005435390235	7487	Economy	13800.00
0005435390237	7487	Economy	13800.00
0005435390236	7487	Economy	12500.00
0005435160380	7487	Economy	12500.00
0005435160381	7487	Economy	12500.00
0005435160388	7487	Economy	12500.00
0005435160389	7487	Economy	12500.00
0005435390229	7487	Economy	12500.00
0005435160386	7487	Economy	12500.00
0005435390233	7487	Economy	12500.00
0005435160387	7487	Economy	12500.00
0005435160385	7487	Economy	12500.00
0005435160384	7487	Economy	12500.00
0005435390211	7487	Economy	12500.00
0005435160378	7487	Economy	12500.00
0005435160383	7487	Economy	12500.00
0005435390243	7487	Economy	12500.00
0005435390244	7487	Economy	12500.00
0005435160382	7487	Economy	12500.00
0005435160379	7487	Economy	12500.00
0005435390213	7487	Economy	12500.00
0005435160321	29582	Economy	13800.00
0005435160275	29582	Economy	13800.00
0005435390291	29582	Economy	12500.00
0005435160274	29582	Economy	12500.00
0005435390292	29582	Economy	12500.00
0005435390294	29582	Economy	12500.00
0005435160333	29582	Economy	12500.00
0005435160302	29582	Economy	12500.00
0005435390293	29582	Economy	12500.00
0005435160329	29582	Economy	12500.00
0005435390288	29582	Economy	12500.00
0005435390287	29582	Economy	12500.00
0005435160330	29582	Economy	12500.00
0005435160327	29582	Economy	12500.00
0005435390289	29582	Economy	12500.00
0005435160292	29582	Economy	12500.00
0005435390290	29582	Economy	12500.00
0005432394108	18485	Economy	4900.00
0005432394079	18485	Economy	4900.00
0005432394107	18485	Economy	4900.00
0005435178506	18485	Economy	4900.00
0005432394077	18485	Economy	4900.00
0005435178999	18485	Economy	4900.00
0005432398190	18485	Economy	4900.00
0005435178507	18485	Economy	4900.00
0005432394078	18485	Economy	4900.00
0005435178998	18485	Economy	4900.00
0005432398222	27149	Economy	4900.00
0005432400149	27149	Economy	4900.00
0005432398220	27149	Economy	4900.00
0005432400151	27149	Economy	4900.00
0005432400147	27149	Economy	4900.00
0005435178493	27149	Economy	4900.00
0005432400148	27149	Economy	4900.00
0005432400150	27149	Economy	4900.00
0005432400152	27149	Economy	4900.00
0005432398221	27149	Economy	4900.00
0005432398219	27149	Economy	4900.00
0005434191273	9768	Economy	4400.00
0005432661932	21846	Business	92200.00
0005432664145	21846	Business	92200.00
0005432663055	21846	Business	92200.00
0005432663045	21846	Business	92200.00
0005432663046	21846	Business	92200.00
0005432664148	21846	Business	92200.00
0005432661930	21846	Business	92200.00
0005432661939	21846	Economy	30700.00
0005432664152	21846	Economy	30700.00
0005432663042	21846	Economy	30700.00
0005432664149	21846	Economy	30700.00
0005432661933	21846	Economy	30700.00
0005432661934	21846	Economy	30700.00
0005432664154	21846	Economy	30700.00
0005432664150	21846	Economy	30700.00
0005432663054	21846	Economy	33800.00
0005432661937	21846	Economy	33800.00
0005432664146	21846	Economy	33800.00
0005432663050	21846	Economy	30700.00
0005432664156	21846	Economy	30700.00
0005432663049	21846	Economy	30700.00
0005432663044	21846	Economy	30700.00
0005432664155	21846	Economy	30700.00
0005432661942	21846	Economy	30700.00
0005432664147	21846	Economy	30700.00
0005432661936	21846	Economy	30700.00
0005432663047	21846	Economy	30700.00
0005432663048	21846	Economy	30700.00
0005432661928	21846	Economy	30700.00
0005432664144	21846	Economy	30700.00
0005432663041	21846	Economy	30700.00
0005432663053	21846	Economy	30700.00
0005432661931	21846	Economy	30700.00
0005432661929	21846	Economy	30700.00
0005432661935	21846	Economy	30700.00
0005432664157	21846	Economy	30700.00
0005432661943	21846	Economy	30700.00
0005432661940	21846	Economy	30700.00
0005432664151	21846	Economy	30700.00
0005432663051	21846	Economy	30700.00
0005432664153	21846	Economy	30700.00
0005432664143	21846	Economy	30700.00
0005432663052	21846	Economy	30700.00
0005432661941	21846	Economy	30700.00
0005432661938	21846	Economy	30700.00
0005432663043	21846	Economy	30700.00
0005434504450	6553	Business	48400.00
0005434504455	6553	Business	48400.00
0005435103984	6553	Business	48400.00
0005434504429	6553	Economy	16100.00
0005434504443	6553	Economy	16100.00
0005434504442	6553	Economy	16100.00
0005434504457	6553	Economy	16100.00
0005434504427	6553	Economy	17800.00
0005434504433	6553	Economy	17800.00
0005434504449	6553	Economy	16100.00
0005434504460	6553	Economy	16100.00
0005434504451	6553	Economy	16100.00
0005434504456	6553	Economy	16100.00
0005434504452	6553	Economy	16100.00
0005434504462	6553	Economy	16100.00
0005434504446	6553	Economy	16100.00
0005434504425	6553	Economy	16100.00
0005434504434	6553	Economy	16100.00
0005434504461	6553	Economy	16100.00
0005434504431	6553	Economy	16100.00
0005434504424	6553	Economy	16100.00
0005434504458	6553	Economy	16100.00
0005434504454	6553	Economy	16100.00
0005434504430	6553	Economy	16100.00
0005434504435	6553	Economy	16100.00
0005434504453	6553	Economy	16100.00
0005435103985	6553	Economy	16100.00
0005434504428	6553	Economy	16100.00
0005434504447	6553	Economy	16100.00
0005434504438	6553	Economy	16100.00
0005434504445	6553	Economy	16100.00
0005435103986	6553	Economy	16100.00
0005434504437	6553	Economy	16100.00
0005435103983	6553	Economy	16100.00
0005434504432	6553	Economy	16100.00
0005434504439	6553	Economy	16100.00
0005434504441	6553	Economy	16100.00
0005434504444	6553	Economy	16100.00
0005434504459	6553	Economy	16100.00
0005434504436	6553	Economy	16100.00
0005434504426	6553	Economy	16100.00
0005434504448	6553	Economy	16100.00
0005434504440	6553	Economy	16100.00
0005434504463	6553	Economy	16100.00
0005434504038	22660	Business	48400.00
0005434503902	22660	Business	48400.00
0005434504019	22660	Business	48400.00
0005434503853	22660	Business	48400.00
0005434504024	22660	Business	48400.00
0005434503819	22660	Business	48400.00
0005435103868	22660	Business	48400.00
0005434504093	22660	Business	48400.00
0005435103893	22660	Economy	16100.00
0005434503995	22660	Economy	16100.00
0005434503882	22660	Economy	16100.00
0005435103907	22660	Economy	16100.00
0005434504022	22660	Economy	16100.00
0005435103888	22660	Economy	17800.00
0005435103899	22660	Economy	17800.00
0005434504068	22660	Economy	16100.00
0005435103885	22660	Economy	16100.00
0005435103886	22660	Economy	16100.00
0005435103904	22660	Economy	16100.00
0005434504254	22660	Economy	16100.00
0005435103903	22660	Economy	16100.00
0005435103901	22660	Economy	16100.00
0005434503977	22660	Economy	16100.00
0005434503976	22660	Economy	16100.00
0005434503947	22660	Economy	16100.00
0005434504099	22660	Economy	16100.00
0005434504003	22660	Economy	16100.00
0005434504088	22660	Economy	16100.00
0005434504081	22660	Economy	16100.00
0005434504037	22660	Economy	16100.00
0005435103860	22660	Economy	16100.00
0005435103867	22660	Economy	16100.00
0005435103891	22660	Economy	16100.00
0005435103861	22660	Economy	16100.00
0005434504126	22660	Economy	16100.00
0005435103896	22660	Economy	16100.00
0005434504046	22660	Economy	16100.00
0005434504002	22660	Economy	16100.00
0005434504100	22660	Economy	16100.00
0005434503901	22660	Economy	16100.00
0005435103902	22660	Economy	16100.00
0005435103869	22660	Economy	16100.00
0005435103863	22660	Economy	16100.00
0005434503946	22660	Economy	16100.00
0005434504036	22660	Economy	16100.00
0005435653404	1675	Business	50000.00
0005435653383	1675	Business	50000.00
0005433367741	1675	Business	50000.00
0005435653374	1675	Business	50000.00
0005435653369	1675	Business	50000.00
0005433367669	1675	Business	50000.00
0005435653380	1675	Business	50000.00
0005433367858	1675	Business	50000.00
0005433367754	1675	Business	50000.00
0005433367914	1675	Business	50000.00
0005435653392	1675	Business	50000.00
0005433367720	1675	Business	50000.00
0005433367939	1675	Economy	16700.00
0005435653361	1675	Economy	16700.00
0005435653354	1675	Economy	16700.00
0005435653355	1675	Economy	16700.00
0005435653402	1675	Economy	16700.00
0005435653397	1675	Economy	16700.00
0005433367851	1675	Economy	16700.00
0005433367880	1675	Economy	16700.00
0005435653365	1675	Economy	16700.00
0005433368041	1675	Economy	16700.00
0005435653398	1675	Economy	18300.00
0005435653370	1675	Economy	18300.00
0005435653360	1675	Economy	18300.00
0005433367967	1675	Economy	18300.00
0005433367794	1675	Economy	16700.00
0005435653375	1675	Economy	16700.00
0005433367861	1675	Economy	16700.00
0005433367843	1675	Economy	16700.00
0005435653387	1675	Economy	16700.00
0005435653400	1675	Economy	16700.00
0005435653394	1675	Economy	16700.00
0005433367881	1675	Economy	16700.00
0005435653364	1675	Economy	16700.00
0005433367909	1675	Economy	16700.00
0005433367827	1675	Economy	16700.00
0005435653351	1675	Economy	16700.00
0005435653356	1675	Economy	16700.00
0005435653403	1675	Economy	16700.00
0005435653393	1675	Economy	16700.00
0005433368013	1675	Economy	16700.00
0005435653359	1675	Economy	16700.00
0005435653381	1675	Economy	16700.00
0005433367966	1675	Economy	16700.00
0005435653377	1675	Economy	16700.00
0005435653363	1675	Economy	16700.00
0005435653395	1675	Economy	16700.00
0005435653386	1675	Economy	16700.00
0005433367743	1675	Economy	16700.00
0005435653358	1675	Economy	16700.00
0005433367742	1675	Economy	16700.00
0005435653368	1675	Economy	16700.00
0005435653372	1675	Economy	16700.00
0005435653371	1675	Economy	16700.00
0005435653376	1675	Economy	16700.00
0005433367755	1675	Economy	16700.00
0005435653384	1675	Economy	16700.00
0005435653388	1675	Economy	16700.00
0005433367910	1675	Economy	16700.00
0005435653366	1675	Economy	16700.00
0005435653382	1675	Economy	16700.00
0005435653391	1675	Economy	16700.00
0005435653357	1675	Economy	16700.00
0005435653390	1675	Economy	16700.00
0005433367723	1675	Economy	16700.00
0005433367668	1675	Economy	16700.00
0005435653362	1675	Economy	16700.00
0005433367537	1675	Economy	16700.00
0005435653379	1675	Economy	16700.00
0005435653373	1675	Economy	16700.00
0005435653385	1675	Economy	16700.00
0005435653396	1675	Economy	16700.00
0005433367536	1675	Economy	16700.00
0005433367793	1675	Economy	16700.00
0005433367603	1675	Economy	16700.00
0005433367904	1675	Economy	16700.00
0005435653350	1675	Economy	16700.00
0005435653352	1675	Economy	16700.00
0005435653399	1675	Economy	16700.00
0005433367977	1675	Economy	16700.00
0005435653349	1675	Economy	16700.00
0005433367787	1675	Economy	16700.00
0005433367915	1675	Economy	16700.00
0005435653401	1675	Economy	16700.00
0005433367690	1675	Economy	16700.00
0005435653367	1675	Economy	16700.00
0005435653353	1675	Economy	16700.00
0005435653378	1675	Economy	16700.00
0005433367860	1675	Economy	16700.00
0005433367670	1675	Economy	16700.00
0005433367792	1675	Economy	16700.00
0005435653389	1675	Economy	16700.00
0005433367774	1675	Economy	16700.00
0005433367882	1675	Economy	16700.00
0005435652958	21687	Business	50000.00
0005435652967	21687	Business	50000.00
0005435652889	21687	Business	50000.00
0005433368151	21687	Business	50000.00
0005433368160	21687	Business	50000.00
0005435653054	21687	Business	50000.00
0005435652645	21687	Business	50000.00
0005433368172	21687	Business	50000.00
0005435652926	21687	Business	50000.00
0005435652924	21687	Business	50000.00
0005433368166	21687	Business	50000.00
0005433368156	21687	Economy	16700.00
0005435652943	21687	Economy	16700.00
0005435652896	21687	Economy	16700.00
0005433368143	21687	Economy	16700.00
0005433368162	21687	Economy	16700.00
0005435652932	21687	Economy	16700.00
0005433368164	21687	Economy	16700.00
0005433368146	21687	Economy	16700.00
0005435653002	21687	Economy	18300.00
0005435652864	21687	Economy	18300.00
0005433368174	21687	Economy	18300.00
0005435652863	21687	Economy	18300.00
0005433368165	21687	Economy	16700.00
0005435653059	21687	Economy	16700.00
0005435652782	21687	Economy	16700.00
0005433368157	21687	Economy	16700.00
0005433368168	21687	Economy	16700.00
0005435652795	21687	Economy	16700.00
0005433368144	21687	Economy	16700.00
0005435652878	21687	Economy	16700.00
0005435652894	21687	Economy	16700.00
0005435652975	21687	Economy	16700.00
0005435653040	21687	Economy	16700.00
0005433368145	21687	Economy	16700.00
0005435652796	21687	Economy	16700.00
0005433368154	21687	Economy	16700.00
0005435652925	21687	Economy	16700.00
0005435652646	21687	Economy	16700.00
0005435652897	21687	Economy	16700.00
0005435652867	21687	Economy	16700.00
0005435653046	21687	Economy	16700.00
0005433368155	21687	Economy	16700.00
0005433368149	21687	Economy	16700.00
0005433368169	21687	Economy	16700.00
0005435652808	21687	Economy	16700.00
0005433368161	21687	Economy	16700.00
0005433368158	21687	Economy	16700.00
0005435652821	21687	Economy	16700.00
0005433368140	21687	Economy	16700.00
0005435653058	21687	Economy	16700.00
0005435653045	21687	Economy	16700.00
0005435653068	21687	Economy	16700.00
0005435652797	21687	Economy	16700.00
0005435652930	21687	Economy	16700.00
0005433368177	21687	Economy	16700.00
0005435652788	21687	Economy	16700.00
0005435652895	21687	Economy	16700.00
0005433368173	21687	Economy	16700.00
0005433368148	21687	Economy	16700.00
0005435652917	21687	Economy	16700.00
0005433368152	21687	Economy	16700.00
0005435652809	21687	Economy	16700.00
0005433368153	21687	Economy	16700.00
0005433368141	21687	Economy	16700.00
0005433368167	21687	Economy	16700.00
0005433368170	21687	Economy	16700.00
0005435652807	21687	Economy	16700.00
0005433368159	21687	Economy	16700.00
0005435653037	21687	Economy	16700.00
0005433368176	21687	Economy	16700.00
0005433368175	21687	Economy	16700.00
0005433368150	21687	Economy	16700.00
0005435652868	21687	Economy	16700.00
0005435652966	21687	Economy	16700.00
0005433368147	21687	Economy	16700.00
0005433368142	21687	Economy	16700.00
0005435652814	21687	Economy	16700.00
0005433368163	21687	Economy	16700.00
0005433368171	21687	Economy	16700.00
0005433986269	4166	Business	21500.00
0005433986267	4166	Business	21500.00
0005433986275	4166	Business	21500.00
0005433986302	4166	Business	21500.00
0005433986303	4166	Business	21500.00
0005433986289	4166	Business	21500.00
0005433986270	4166	Business	21500.00
0005433986286	4166	Business	21500.00
0005433986263	4166	Business	21500.00
0005435788790	4166	Economy	7200.00
0005433986268	4166	Economy	7200.00
0005433986277	4166	Economy	7200.00
0005433986299	4166	Economy	7200.00
0005433986305	4166	Economy	7200.00
0005433986265	4166	Economy	7200.00
0005433986283	4166	Economy	7200.00
0005433986259	4166	Economy	7200.00
0005433986274	4166	Economy	7200.00
0005433986301	4166	Economy	7200.00
0005433986281	4166	Economy	7200.00
0005433986297	4166	Economy	7200.00
0005433986285	4166	Economy	7200.00
0005433986300	4166	Economy	7200.00
0005433986296	4166	Economy	7200.00
0005433986280	4166	Economy	7200.00
0005433986292	4166	Economy	7200.00
0005433986260	4166	Economy	7200.00
0005433986272	4166	Economy	7200.00
0005433986287	4166	Economy	7200.00
0005433986273	4166	Economy	7200.00
0005433986278	4166	Economy	7200.00
0005433986271	4166	Economy	7200.00
0005433986284	4166	Economy	7200.00
0005433986290	4166	Economy	7200.00
0005433986304	4166	Economy	7200.00
0005433986291	4166	Economy	7200.00
0005433986282	4166	Economy	7200.00
0005433986293	4166	Economy	7200.00
0005433986261	4166	Economy	7200.00
0005433986295	4166	Economy	7200.00
0005433986262	4166	Economy	7200.00
0005433986266	4166	Economy	7200.00
0005433986288	4166	Economy	7200.00
0005433986279	4166	Economy	7200.00
0005433986294	4166	Economy	7200.00
0005433986276	4166	Economy	7200.00
0005433986298	4166	Economy	7200.00
0005433986264	4166	Economy	7200.00
0005433985877	25666	Business	21500.00
0005433985799	25666	Business	21500.00
0005433986020	25666	Business	21500.00
0005433985936	25666	Business	21500.00
0005433985850	25666	Business	21500.00
0005433985735	25666	Economy	7200.00
0005433985804	25666	Economy	7200.00
0005433985862	25666	Economy	7200.00
0005433985780	25666	Economy	7200.00
0005433985802	25666	Economy	7200.00
0005433985588	25666	Economy	7200.00
0005433985637	25666	Economy	7900.00
0005433985875	25666	Economy	7900.00
0005433985783	25666	Economy	7900.00
0005435788767	25666	Economy	7200.00
0005433985792	25666	Economy	7200.00
0005433985874	25666	Economy	7200.00
0005433985832	25666	Economy	7200.00
0005433985852	25666	Economy	7200.00
0005433985910	25666	Economy	7200.00
0005433985837	25666	Economy	7200.00
0005433985638	25666	Economy	7200.00
0005433985876	25666	Economy	7200.00
0005433985838	25666	Economy	7200.00
0005433985772	25666	Economy	7200.00
0005433985702	25666	Economy	7200.00
0005433985839	25666	Economy	7200.00
0005433985873	25666	Economy	7200.00
0005433985765	25666	Economy	7200.00
0005433985998	25666	Economy	7200.00
0005433985803	25666	Economy	7200.00
0005433985851	25666	Economy	7200.00
0005433985857	25666	Economy	7200.00
0005433986214	25666	Economy	7200.00
0005433985796	25666	Economy	7200.00
0005433985736	25666	Economy	7200.00
0005433985926	25666	Economy	7200.00
0005433985842	25666	Economy	7200.00
0005433985919	25666	Economy	7200.00
0005435788760	25666	Economy	7200.00
0005433985863	25666	Economy	7200.00
0005433985879	25666	Economy	7200.00
0005433985798	25666	Economy	7200.00
0005433985747	25666	Economy	7200.00
0005433985791	25666	Economy	7200.00
0005433985867	25666	Economy	7200.00
0005433985856	25666	Economy	7200.00
0005433985900	25666	Economy	7200.00
0005433985935	25666	Economy	7200.00
0005433985806	25666	Economy	7200.00
0005433985776	25666	Economy	7200.00
0005433985813	25666	Economy	7200.00
0005433985673	25666	Economy	7200.00
0005433985779	25666	Economy	7200.00
0005433985915	25666	Economy	7200.00
0005433985878	25666	Economy	7200.00
0005435719566	21293	Economy	9400.00
0005435719569	24764	Economy	9400.00
0005435720140	24764	Economy	9400.00
0005434516095	9029	Economy	26000.00
0005434190406	9029	Economy	23600.00
0005434516090	9029	Economy	23600.00
0005434190398	9029	Economy	23600.00
0005434190397	9029	Economy	23600.00
0005434190408	9029	Economy	23600.00
0005434190404	9029	Economy	23600.00
0005434516089	9029	Economy	23600.00
0005434516088	9029	Economy	23600.00
0005434190389	9029	Economy	23600.00
0005434516096	9029	Economy	23600.00
0005434516091	9029	Economy	23600.00
0005434516094	9029	Economy	23600.00
0005434190396	9029	Economy	23600.00
0005434516093	9029	Economy	23600.00
0005434516092	9029	Economy	23600.00
0005434190407	9029	Economy	23600.00
0005432869573	17862	Business	18000.00
0005432663036	17862	Business	18000.00
0005434151728	17862	Business	18000.00
0005432663033	17862	Business	18000.00
0005432664142	17862	Business	18000.00
0005432655474	17862	Economy	6000.00
0005432655528	17862	Economy	6000.00
0005434151727	17862	Economy	6000.00
0005432655554	17862	Economy	6000.00
0005432664141	17862	Economy	6000.00
0005432655525	17862	Economy	6000.00
0005432655462	17862	Economy	6000.00
0005432665272	17862	Economy	6600.00
0005432660820	17862	Economy	6600.00
0005432655516	17862	Economy	6600.00
0005432655527	17862	Economy	6000.00
0005432664136	17862	Economy	6000.00
0005432657432	17862	Economy	6000.00
0005432655519	17862	Economy	6000.00
0005432869575	17862	Economy	6000.00
0005432664114	17862	Economy	6000.00
0005432655461	17862	Economy	6000.00
0005432657449	17862	Economy	6000.00
0005434151726	17862	Economy	6000.00
0005432663035	17862	Economy	6000.00
0005434151729	17862	Economy	6000.00
0005432658590	17862	Economy	6000.00
0005432657418	17862	Economy	6000.00
0005432869574	17862	Economy	6000.00
0005432655473	17862	Economy	6000.00
0005432657446	17862	Economy	6000.00
0005432655446	17862	Economy	6000.00
0005432869576	17862	Economy	6000.00
0005432665269	17862	Economy	6000.00
0005432657452	17862	Economy	6000.00
0005432667456	17862	Economy	6000.00
0005432869579	17862	Economy	6000.00
0005432663031	17862	Economy	6000.00
0005432655499	17862	Economy	6000.00
0005432869577	17862	Economy	6000.00
0005432869578	17862	Economy	6000.00
0005432663032	17862	Economy	6000.00
0005432663040	17862	Economy	6000.00
0005432664137	17862	Economy	6000.00
0005432655472	17862	Economy	6000.00
0005432658602	26299	Business	18000.00
0005432655595	26299	Business	18000.00
0005432655606	26299	Business	18000.00
0005432658605	26299	Business	18000.00
0005434151683	26299	Business	18000.00
0005432658604	26299	Business	18000.00
0005432667467	26299	Business	18000.00
0005432665287	26299	Economy	6000.00
0005432666400	26299	Economy	6000.00
0005432655597	26299	Economy	6000.00
0005432666401	26299	Economy	6000.00
0005432869491	26299	Economy	6000.00
0005432655596	26299	Economy	6600.00
0005432869489	26299	Economy	6600.00
0005432655604	26299	Economy	6000.00
0005432869510	26299	Economy	6000.00
0005434151707	26299	Economy	6000.00
0005432657466	26299	Economy	6000.00
0005432657467	26299	Economy	6000.00
0005432655603	26299	Economy	6000.00
0005432667465	26299	Economy	6000.00
0005432665286	26299	Economy	6000.00
0005432869519	26299	Economy	6000.00
0005432655601	26299	Economy	6000.00
0005432660830	26299	Economy	6000.00
0005432666402	26299	Economy	6000.00
0005432660829	26299	Economy	6000.00
0005432869490	26299	Economy	6000.00
0005432869511	26299	Economy	6000.00
0005432667466	26299	Economy	6000.00
0005432655599	26299	Economy	6000.00
0005432658603	26299	Economy	6000.00
0005432655600	26299	Economy	6000.00
0005432655598	26299	Economy	6000.00
0005432667468	26299	Economy	6000.00
0005432657468	26299	Economy	6000.00
0005432869520	26299	Economy	6000.00
0005432655605	26299	Economy	6000.00
0005432659719	26299	Economy	6000.00
0005432869504	26299	Economy	6000.00
0005432655602	26299	Economy	6000.00
0005433438939	3117	Business	16100.00
0005432329056	3117	Business	16100.00
0005432287229	3117	Business	16100.00
0005432905133	3117	Business	16100.00
0005432329023	3117	Business	16100.00
0005432329046	3117	Business	16100.00
0005432329063	3117	Business	16100.00
0005432329034	3117	Business	16100.00
0005432329022	3117	Business	16100.00
0005432329036	3117	Business	16100.00
0005432329048	3117	Economy	5400.00
0005432329043	3117	Economy	5400.00
0005432329018	3117	Economy	5400.00
0005432329031	3117	Economy	5400.00
0005432329040	3117	Economy	5400.00
0005432329041	3117	Economy	5400.00
0005432329028	3117	Economy	5400.00
0005432329065	3117	Economy	5400.00
0005432329050	3117	Economy	5900.00
0005433438941	3117	Economy	5900.00
0005432329035	3117	Economy	5900.00
0005432329045	3117	Economy	5900.00
0005432287227	3117	Economy	5400.00
0005432329052	3117	Economy	5400.00
0005432329049	3117	Economy	5400.00
0005432329044	3117	Economy	5400.00
0005432329047	3117	Economy	5400.00
0005432905125	3117	Economy	5400.00
0005432329029	3117	Economy	5400.00
0005432329057	3117	Economy	5400.00
0005432329038	3117	Economy	5400.00
0005432905126	3117	Economy	5400.00
0005432329051	3117	Economy	5400.00
0005432905119	3117	Economy	5400.00
0005432329019	3117	Economy	5400.00
0005433438938	3117	Economy	5400.00
0005432329032	3117	Economy	5400.00
0005433438944	3117	Economy	5400.00
0005432329053	3117	Economy	5400.00
0005432287228	3117	Economy	5400.00
0005432329064	3117	Economy	5400.00
0005432329055	3117	Economy	5400.00
0005432329024	3117	Economy	5400.00
0005432329039	3117	Economy	5400.00
0005433438940	3117	Economy	5400.00
0005432329026	3117	Economy	5400.00
0005432329059	3117	Economy	5400.00
0005433438937	3117	Economy	5400.00
0005432329030	3117	Economy	5400.00
0005432329037	3117	Economy	5400.00
0005432329062	3117	Economy	5400.00
0005432329054	3117	Economy	5400.00
0005432329042	3117	Economy	5400.00
0005432329021	3117	Economy	5400.00
0005433438943	3117	Economy	5400.00
0005433438942	3117	Economy	5400.00
0005432329027	3117	Economy	5400.00
0005432329020	3117	Economy	5400.00
0005432329060	3117	Economy	5400.00
0005432905120	3117	Economy	5400.00
0005432329058	3117	Economy	5400.00
0005432287226	3117	Economy	5400.00
0005432329033	3117	Economy	5400.00
0005432329061	3117	Economy	5400.00
0005432329025	3117	Economy	5400.00
0005432328542	31147	Business	16100.00
0005432328592	31147	Business	16100.00
0005432328826	31147	Business	16100.00
0005433438911	31147	Business	16100.00
0005432328510	31147	Business	16100.00
0005432328506	31147	Business	16100.00
0005432905168	31147	Economy	5400.00
0005432905169	31147	Economy	5400.00
0005432328754	31147	Economy	5400.00
0005432328326	31147	Economy	5400.00
0005432328753	31147	Economy	5400.00
0005433438866	31147	Economy	5400.00
0005432328612	31147	Economy	5900.00
0005432905167	31147	Economy	5900.00
0005432328599	31147	Economy	5900.00
0005432328645	31147	Economy	5900.00
0005433438844	31147	Economy	5400.00
0005432328806	31147	Economy	5400.00
0005432328650	31147	Economy	5400.00
0005433438921	31147	Economy	5400.00
0005432328752	31147	Economy	5400.00
0005432328820	31147	Economy	5400.00
0005432328511	31147	Economy	5400.00
0005432328828	31147	Economy	5400.00
0005432328362	31147	Economy	5400.00
0005433438848	31147	Economy	5400.00
0005432328327	31147	Economy	5400.00
0005432905165	31147	Economy	5400.00
0005432905170	31147	Economy	5400.00
0005432328688	31147	Economy	5400.00
0005432328471	31147	Economy	5400.00
0005433438910	31147	Economy	5400.00
0005432328605	31147	Economy	5400.00
0005432328470	31147	Economy	5400.00
0005433438920	31147	Economy	5400.00
0005433438867	31147	Economy	5400.00
0005432328450	31147	Economy	5400.00
0005433438855	31147	Economy	5400.00
0005432328595	31147	Economy	5400.00
0005432328827	31147	Economy	5400.00
0005432328567	31147	Economy	5400.00
0005432328366	31147	Economy	5400.00
0005432328727	31147	Economy	5400.00
0005432328733	31147	Economy	5400.00
0005432328690	31147	Economy	5400.00
0005432328505	31147	Economy	5400.00
0005432905166	31147	Economy	5400.00
0005432328475	31147	Economy	5400.00
0005432328626	31147	Economy	5400.00
0005432328646	31147	Economy	5400.00
0005432054327	31147	Economy	5400.00
0005432328643	31147	Economy	5400.00
0005432328598	31147	Economy	5400.00
0005432328676	31147	Economy	5400.00
0005432054326	31147	Economy	5400.00
0005432328623	31147	Economy	5400.00
0005432328449	31147	Economy	5400.00
0005433438868	31147	Economy	5400.00
0005432905171	31147	Economy	5400.00
0005432328494	31147	Economy	5400.00
0005433438875	31147	Economy	5400.00
0005433438909	31147	Economy	5400.00
0005435999383	6227	Business	124600.00
0005435297055	6227	Business	124600.00
0005432146214	6227	Business	124600.00
0005435297040	6227	Business	124600.00
0005435487802	6227	Economy	41500.00
0005434309845	6227	Economy	41500.00
0005435999384	6227	Economy	41500.00
0005435487682	6227	Economy	41500.00
0005434309847	6227	Economy	41500.00
0005435999382	6227	Economy	41500.00
0005434309840	6227	Economy	41500.00
0005435487681	6227	Economy	41500.00
0005434309846	6227	Economy	41500.00
0005434309843	6227	Economy	41500.00
0005435487795	6227	Economy	41500.00
0005435487775	6227	Economy	41500.00
0005435487772	6227	Economy	41500.00
0005434309841	6227	Economy	41500.00
0005435487768	6227	Economy	41500.00
0005435487919	6227	Economy	41500.00
0005435999381	6227	Economy	41500.00
0005435487800	6227	Economy	41500.00
0005434309838	6227	Economy	41500.00
0005435487777	6227	Economy	41500.00
0005435487812	6227	Economy	41500.00
0005435487756	6227	Economy	45700.00
0005435487779	6227	Economy	45700.00
0005434309839	6227	Economy	45700.00
0005435487747	6227	Economy	45700.00
0005435487839	6227	Economy	41500.00
0005435487886	6227	Economy	41500.00
0005435487827	6227	Economy	41500.00
0005435487668	6227	Economy	41500.00
0005435487799	6227	Economy	41500.00
0005435487887	6227	Economy	41500.00
0005435487804	6227	Economy	41500.00
0005435487811	6227	Economy	41500.00
0005435487767	6227	Economy	41500.00
0005435487794	6227	Economy	41500.00
0005435487718	6227	Economy	41500.00
0005435487680	6227	Economy	41500.00
0005434309842	6227	Economy	41500.00
0005434309844	6227	Economy	41500.00
0005435487710	6227	Economy	41500.00
0005435487796	6227	Economy	41500.00
0005434309849	6227	Economy	41500.00
0005435487773	6227	Economy	41500.00
0005435487885	6227	Economy	41500.00
0005434309836	6227	Economy	41500.00
0005435487778	6227	Economy	41500.00
0005435487754	6227	Economy	41500.00
0005434309837	6227	Economy	41500.00
0005435487711	6227	Economy	41500.00
0005434309848	6227	Economy	41500.00
0005435487776	6227	Economy	41500.00
0005435487977	19574	Business	124600.00
0005435999199	19574	Business	124600.00
0005435487975	19574	Business	124600.00
0005435487967	19574	Business	124600.00
0005435487979	19574	Business	124600.00
0005434309717	19574	Business	124600.00
0005435297112	19574	Economy	41500.00
0005434309713	19574	Economy	41500.00
0005435999188	19574	Economy	41500.00
0005434309724	19574	Economy	41500.00
0005435999202	19574	Economy	41500.00
0005434309714	19574	Economy	41500.00
0005435999182	19574	Economy	41500.00
0005435297107	19574	Economy	41500.00
0005435999179	19574	Economy	41500.00
0005434309692	19574	Economy	41500.00
0005435999127	19574	Economy	41500.00
0005435297108	19574	Economy	41500.00
0005435487970	19574	Economy	41500.00
0005435999206	19574	Economy	45700.00
0005435487974	19574	Economy	41500.00
0005435487964	19574	Economy	41500.00
0005435487983	19574	Economy	41500.00
0005435999192	19574	Economy	41500.00
0005435297109	19574	Economy	41500.00
0005435999227	19574	Economy	41500.00
0005434309700	19574	Economy	41500.00
0005435999174	19574	Economy	41500.00
0005435999198	19574	Economy	41500.00
0005435487969	19574	Economy	41500.00
0005435487976	19574	Economy	41500.00
0005435999175	19574	Economy	41500.00
0005435297110	19574	Economy	41500.00
0005435487980	19574	Economy	41500.00
0005435487978	19574	Economy	41500.00
0005435999204	19574	Economy	41500.00
0005434309737	19574	Economy	41500.00
0005435297111	19574	Economy	41500.00
0005435999205	19574	Economy	41500.00
0005435999187	19574	Economy	41500.00
0005434309727	19574	Economy	41500.00
0005435487966	19574	Economy	41500.00
0005435999207	19574	Economy	41500.00
0005435487972	19574	Economy	41500.00
0005435487982	19574	Economy	41500.00
0005435487984	19574	Economy	41500.00
0005434309723	19574	Economy	41500.00
0005434309709	19574	Economy	41500.00
0005435487981	19574	Economy	41500.00
0005435487968	19574	Economy	41500.00
0005435487971	19574	Economy	41500.00
0005435999210	19574	Economy	41500.00
0005434309712	19574	Economy	41500.00
0005435999178	19574	Economy	41500.00
0005435487973	19574	Economy	41500.00
0005435487965	19574	Economy	41500.00
0005434566021	1570	Business	86000.00
0005435508446	1570	Business	86000.00
0005435508435	1570	Business	86000.00
0005435508441	1570	Business	86000.00
0005435518045	1570	Business	86000.00
0005433186113	1570	Business	86000.00
0005435502474	1570	Business	86000.00
0005435508430	1570	Business	86000.00
0005435518030	1570	Business	86000.00
0005434566014	1570	Business	86000.00
0005435508437	1570	Business	86000.00
0005435508433	1570	Business	86000.00
0005433186112	1570	Economy	28700.00
0005432291949	1570	Economy	28700.00
0005434566017	1570	Economy	28700.00
0005435502472	1570	Economy	28700.00
0005433186138	1570	Economy	28700.00
0005435518033	1570	Economy	28700.00
0005435502480	1570	Economy	28700.00
0005433186089	1570	Economy	28700.00
0005435518036	1570	Economy	31500.00
0005435508439	1570	Economy	31500.00
0005435518042	1570	Economy	31500.00
0005435508431	1570	Economy	31500.00
0005435502479	1570	Economy	31500.00
0005434566022	1570	Economy	28700.00
0005435518047	1570	Economy	28700.00
0005435518041	1570	Economy	28700.00
0005435518035	1570	Economy	28700.00
0005434566012	1570	Economy	28700.00
0005434566010	1570	Economy	28700.00
0005435518043	1570	Economy	28700.00
0005434566020	1570	Economy	28700.00
0005435502477	1570	Economy	28700.00
0005435518031	1570	Economy	28700.00
0005435502484	1570	Economy	28700.00
0005435518044	1570	Economy	28700.00
0005435502465	1570	Economy	28700.00
0005435502471	1570	Economy	28700.00
0005435502483	1570	Economy	28700.00
0005435508442	1570	Economy	28700.00
0005434566019	1570	Economy	28700.00
0005434566011	1570	Economy	28700.00
0005435508436	1570	Economy	28700.00
0005435518046	1570	Economy	28700.00
0005435508438	1570	Economy	28700.00
0005435518040	1570	Economy	28700.00
0005435502464	1570	Economy	28700.00
0005435502467	1570	Economy	28700.00
0005435502463	1570	Economy	28700.00
0005435518034	1570	Economy	28700.00
0005434566008	1570	Economy	28700.00
0005435508443	1570	Economy	28700.00
0005435502466	1570	Economy	28700.00
0005435508444	1570	Economy	28700.00
0005433186121	1570	Economy	28700.00
0005434566018	1570	Economy	28700.00
0005435502475	1570	Economy	28700.00
0005435502469	1570	Economy	28700.00
0005433186137	1570	Economy	28700.00
0005434566015	1570	Economy	28700.00
0005432291948	1570	Economy	28700.00
0005435502473	1570	Economy	28700.00
0005435508432	1570	Economy	28700.00
0005434566013	1570	Economy	28700.00
0005435518032	1570	Economy	28700.00
0005435502476	1570	Economy	28700.00
0005435518039	1570	Economy	28700.00
0005435518029	1570	Economy	28700.00
0005435502482	1570	Economy	28700.00
0005435502468	1570	Economy	28700.00
0005433186136	1570	Economy	28700.00
0005435502470	1570	Economy	28700.00
0005435502478	1570	Economy	28700.00
0005435518048	1570	Economy	28700.00
0005435518028	1570	Economy	28700.00
0005434566009	1570	Economy	28700.00
0005435508445	1570	Economy	28700.00
0005435518038	1570	Economy	28700.00
0005435508434	1570	Economy	28700.00
0005435502481	1570	Economy	28700.00
0005434566016	1570	Economy	28700.00
0005435508440	1570	Economy	28700.00
0005435518037	1570	Economy	28700.00
0005435529248	20852	Business	86000.00
0005435529159	20852	Business	86000.00
0005435545709	20852	Business	86000.00
0005434565925	20852	Business	86000.00
0005435502314	20852	Business	86000.00
0005433186184	20852	Business	86000.00
0005435529194	20852	Business	86000.00
0005434565924	20852	Business	86000.00
0005434565915	20852	Business	86000.00
0005435545744	20852	Economy	28700.00
0005433186181	20852	Economy	28700.00
0005435529216	20852	Economy	28700.00
0005434565903	20852	Economy	28700.00
0005435502273	20852	Economy	28700.00
0005435502262	20852	Economy	28700.00
0005434565911	20852	Economy	28700.00
0005434565864	20852	Economy	28700.00
0005435529136	20852	Economy	28700.00
0005434565950	20852	Economy	31500.00
0005435529176	20852	Economy	31500.00
0005434565843	20852	Economy	31500.00
0005435502355	20852	Economy	28700.00
0005435502319	20852	Economy	28700.00
0005435502178	20852	Economy	28700.00
0005435545681	20852	Economy	28700.00
0005435529262	20852	Economy	28700.00
0005434565914	20852	Economy	28700.00
0005435529127	20852	Economy	28700.00
0005435529215	20852	Economy	28700.00
0005435502247	20852	Economy	28700.00
0005435529243	20852	Economy	28700.00
0005435529274	20852	Economy	28700.00
0005435545691	20852	Economy	28700.00
0005435502274	20852	Economy	28700.00
0005434565923	20852	Economy	28700.00
0005435529228	20852	Economy	28700.00
0005435545726	20852	Economy	28700.00
0005435545743	20852	Economy	28700.00
0005435529178	20852	Economy	28700.00
0005435529196	20852	Economy	28700.00
0005435502354	20852	Economy	28700.00
0005435545733	20852	Economy	28700.00
0005435545725	20852	Economy	28700.00
0005433186179	20852	Economy	28700.00
0005433186183	20852	Economy	28700.00
0005433186182	20852	Economy	28700.00
0005434565949	20852	Economy	28700.00
0005435529217	20852	Economy	28700.00
0005435502258	20852	Economy	28700.00
0005435529124	20852	Economy	28700.00
0005435529171	20852	Economy	28700.00
0005435529183	20852	Economy	28700.00
0005435502261	20852	Economy	28700.00
0005435529249	20852	Economy	28700.00
0005433186180	20852	Economy	28700.00
0005435529197	20852	Economy	28700.00
0005435502320	20852	Economy	28700.00
0005435529177	20852	Economy	28700.00
0005433186186	20852	Economy	28700.00
0005434565912	20852	Economy	28700.00
0005435502259	20852	Economy	28700.00
0005435545735	20852	Economy	28700.00
0005433186185	20852	Economy	28700.00
0005434565907	20852	Economy	28700.00
0005433186178	20852	Economy	28700.00
0005435502312	20852	Economy	28700.00
0005434565913	20852	Economy	28700.00
0005435529273	20852	Economy	28700.00
0005435529229	20852	Economy	28700.00
0005435502246	20852	Economy	28700.00
0005435529123	20852	Economy	28700.00
0005435529209	20852	Economy	28700.00
0005435529203	20852	Economy	28700.00
0005435502270	20852	Economy	28700.00
0005435931600	3907	Economy	21600.00
0005435153795	3907	Economy	19700.00
0005435153790	3907	Economy	19700.00
0005435153792	3907	Economy	19700.00
0005435153791	3907	Economy	19700.00
0005435153794	3907	Economy	19700.00
0005435153793	3907	Economy	19700.00
0005435153732	21872	Economy	19700.00
0005435931628	21872	Economy	19700.00
0005435153741	21872	Economy	19700.00
0005435153733	21872	Economy	19700.00
0005435931627	21872	Economy	19700.00
0005435153740	21872	Economy	19700.00
0005435931629	21872	Economy	19700.00
0005435931630	21872	Economy	19700.00
0005432628950	7189	Economy	13000.00
0005435225587	7189	Economy	13000.00
0005435225588	7189	Economy	13000.00
0005435225590	7189	Economy	13000.00
0005432628958	7189	Economy	13000.00
0005435225568	7189	Economy	13000.00
0005432628952	7189	Economy	13000.00
0005432628951	7189	Economy	13000.00
0005432628962	7189	Economy	13000.00
0005432628953	7189	Economy	13000.00
0005432628955	7189	Economy	13000.00
0005432628957	7189	Economy	13000.00
0005432628959	7189	Economy	13000.00
0005435225581	7189	Economy	13000.00
0005432628963	7189	Economy	13000.00
0005432628954	7189	Economy	13000.00
0005432628960	7189	Economy	13000.00
0005435225561	7189	Economy	13000.00
0005432628961	7189	Economy	13000.00
0005435225603	7189	Economy	13000.00
0005432628949	7189	Economy	13000.00
0005432628956	7189	Economy	13000.00
0005435225640	28138	Economy	14300.00
0005432628777	28138	Economy	14300.00
0005432628883	28138	Economy	13000.00
0005435225649	28138	Economy	13000.00
0005432628915	28138	Economy	13000.00
0005435225644	28138	Economy	13000.00
0005435225645	28138	Economy	13000.00
0005432628738	28138	Economy	13000.00
0005432628739	28138	Economy	13000.00
0005432628866	28138	Economy	13000.00
0005432628841	28138	Economy	13000.00
0005432628801	28138	Economy	13000.00
0005435225642	28138	Economy	13000.00
0005432628886	28138	Economy	13000.00
0005435225641	28138	Economy	13000.00
0005435225646	28138	Economy	13000.00
0005432628843	28138	Economy	13000.00
0005435225648	28138	Economy	13000.00
0005435225643	28138	Economy	13000.00
0005432628914	28138	Economy	13000.00
0005435225647	28138	Economy	13000.00
0005432628846	28138	Economy	13000.00
0005432628811	28138	Economy	13000.00
0005432628842	28138	Economy	13000.00
0005432628819	28138	Economy	13000.00
0005432628776	28138	Economy	13000.00
0005435960077	8738	Economy	10500.00
0005434267933	8738	Economy	10500.00
0005435960080	8738	Economy	10500.00
0005435960078	8738	Economy	10500.00
0005434267934	8738	Economy	10500.00
0005435960079	8738	Economy	10500.00
0005434267939	8738	Economy	10500.00
0005434267967	8738	Economy	10500.00
0005434267935	8738	Economy	10500.00
0005434267980	15220	Economy	11500.00
0005435960058	15220	Economy	10500.00
0005435960038	15220	Economy	10500.00
0005434267976	15220	Economy	10500.00
0005434267977	15220	Economy	10500.00
0005434267978	15220	Economy	10500.00
0005435960039	15220	Economy	10500.00
0005435960053	15220	Economy	10500.00
0005434267979	15220	Economy	10500.00
0005432693278	1202	Business	115000.00
0005432675242	1202	Business	115000.00
0005432677600	1202	Business	115000.00
0005432693275	1202	Business	115000.00
0005432693281	1202	Business	115000.00
0005432693276	1202	Business	115000.00
0005432693273	1202	Economy	38300.00
0005432677597	1202	Economy	38300.00
0005432693269	1202	Economy	38300.00
0005432693283	1202	Economy	38300.00
0005432675241	1202	Economy	38300.00
0005432693261	1202	Economy	38300.00
0005432693282	1202	Economy	42200.00
0005432675239	1202	Economy	42200.00
0005432675237	1202	Economy	38300.00
0005432675244	1202	Economy	38300.00
0005432693272	1202	Economy	38300.00
0005432675246	1202	Economy	38300.00
0005432693254	1202	Economy	38300.00
0005432693268	1202	Economy	38300.00
0005432693279	1202	Economy	38300.00
0005432675250	1202	Economy	38300.00
0005432693260	1202	Economy	38300.00
0005432693257	1202	Economy	38300.00
0005432693277	1202	Economy	38300.00
0005432675240	1202	Economy	38300.00
0005432675251	1202	Economy	38300.00
0005432675249	1202	Economy	38300.00
0005432675252	1202	Economy	38300.00
0005432873282	1202	Economy	38300.00
0005432693255	1202	Economy	38300.00
0005432693267	1202	Economy	38300.00
0005432693270	1202	Economy	38300.00
0005432675248	1202	Economy	38300.00
0005432693274	1202	Economy	38300.00
0005432693258	1202	Economy	38300.00
0005432693265	1202	Economy	38300.00
0005432677599	1202	Economy	38300.00
0005432677601	1202	Economy	38300.00
0005432675236	1202	Economy	38300.00
0005432675245	1202	Economy	38300.00
0005432675243	1202	Economy	38300.00
0005432873284	1202	Economy	38300.00
0005432677598	1202	Economy	38300.00
0005432873260	1202	Economy	38300.00
0005432693253	1202	Economy	38300.00
0005432693263	1202	Economy	38300.00
0005432693256	1202	Economy	38300.00
0005432693271	1202	Economy	38300.00
0005432873283	1202	Economy	38300.00
0005432675247	1202	Economy	38300.00
0005432693280	1202	Economy	38300.00
0005432693284	1202	Economy	38300.00
0005432693262	1202	Economy	38300.00
0005432675238	1202	Economy	38300.00
0005432693266	1202	Economy	38300.00
0005432693264	1202	Economy	38300.00
0005432693259	1202	Economy	38300.00
0005432873300	1202	Economy	38300.00
0005432873347	17481	Business	115000.00
0005432675151	17481	Business	115000.00
0005432693008	17481	Business	115000.00
0005432675059	17481	Business	115000.00
0005432693033	17481	Business	115000.00
0005432693113	17481	Business	115000.00
0005432675152	17481	Business	115000.00
0005432873344	17481	Business	115000.00
0005432677570	17481	Business	115000.00
0005432873346	17481	Business	115000.00
0005432873342	17481	Economy	38300.00
0005432693039	17481	Economy	38300.00
0005432693063	17481	Economy	38300.00
0005432677562	17481	Economy	38300.00
0005432677583	17481	Economy	38300.00
0005432693143	17481	Economy	42200.00
0005432675138	17481	Economy	38300.00
0005432675084	17481	Economy	42200.00
0005432677582	17481	Economy	38300.00
0005432873343	17481	Economy	38300.00
0005432675124	17481	Economy	38300.00
0005432675114	17481	Economy	38300.00
0005432675175	17481	Economy	38300.00
0005432677555	17481	Economy	38300.00
0005432692972	17481	Economy	38300.00
0005432692987	17481	Economy	38300.00
0005432693005	17481	Economy	38300.00
0005432675162	17481	Economy	38300.00
0005432693034	17481	Economy	38300.00
0005432677563	17481	Economy	38300.00
0005432693032	17481	Economy	38300.00
0005432873345	17481	Economy	38300.00
0005432693050	17481	Economy	38300.00
0005432675117	17481	Economy	38300.00
0005432677558	17481	Economy	38300.00
0005432692852	17481	Economy	38300.00
0005432693004	17481	Economy	38300.00
0005432677559	17481	Economy	38300.00
0005432675126	17481	Economy	38300.00
0005432677566	17481	Economy	38300.00
0005432677571	17481	Economy	38300.00
0005432693024	17481	Economy	38300.00
0005432675160	17481	Economy	38300.00
0005432675134	17481	Economy	38300.00
0005432675125	17481	Economy	38300.00
0005432692949	17481	Economy	38300.00
0005432675161	17481	Economy	38300.00
0005432675157	17481	Economy	38300.00
0005432693007	17481	Economy	38300.00
0005432675060	17481	Economy	38300.00
0005432693123	17481	Economy	38300.00
0005432873341	17481	Economy	38300.00
0005432677584	17481	Economy	38300.00
0005434435298	1158	Economy	15200.00
0005433156767	1158	Economy	13900.00
0005434435290	1158	Economy	13900.00
0005434435294	1158	Economy	13900.00
0005433156725	1158	Economy	13900.00
0005434435295	1158	Economy	13900.00
0005433156754	1158	Economy	13900.00
0005434435297	1158	Economy	13900.00
0005434435300	1158	Economy	13900.00
0005433156712	1158	Economy	13900.00
0005434435301	1158	Economy	13900.00
0005434435303	1158	Economy	13900.00
0005433156753	1158	Economy	13900.00
0005434435302	1158	Economy	13900.00
0005433156755	1158	Economy	13900.00
0005434435289	1158	Economy	13900.00
0005433156770	1158	Economy	13900.00
0005433156766	1158	Economy	13900.00
0005434435291	1158	Economy	13900.00
0005434435293	1158	Economy	13900.00
0005433156733	1158	Economy	13900.00
0005434435288	1158	Economy	13900.00
0005434435292	1158	Economy	13900.00
0005434435299	1158	Economy	13900.00
0005433156711	1158	Economy	13900.00
0005434435296	1158	Economy	13900.00
0005434435287	1158	Economy	13900.00
0005433156777	1158	Economy	13900.00
0005434435190	17316	Economy	15200.00
0005434435159	17316	Economy	15200.00
0005434435104	17316	Economy	15200.00
0005433156809	17316	Economy	13900.00
0005434435200	17316	Economy	13900.00
0005433156810	17316	Economy	13900.00
0005433156813	17316	Economy	13900.00
0005434435152	17316	Economy	13900.00
0005433156814	17316	Economy	13900.00
0005434435125	17316	Economy	13900.00
0005433156812	17316	Economy	13900.00
0005434435225	17316	Economy	13900.00
0005434435174	17316	Economy	13900.00
0005434435198	17316	Economy	13900.00
0005434435249	17316	Economy	13900.00
0005434435124	17316	Economy	13900.00
0005433156815	17316	Economy	13900.00
0005434435189	17316	Economy	13900.00
0005433156811	17316	Economy	13900.00
0005433156818	17316	Economy	13900.00
0005434435103	17316	Economy	13900.00
0005433156816	17316	Economy	13900.00
0005434435175	17316	Economy	13900.00
0005434435153	17316	Economy	13900.00
0005434435158	17316	Economy	13900.00
0005434435166	17316	Economy	13900.00
0005434435201	17316	Economy	13900.00
0005433156817	17316	Economy	13900.00
0005434435199	17316	Economy	13900.00
0005434435169	17316	Economy	13900.00
0005435086887	4104	Economy	8200.00
0005435928116	4104	Economy	7500.00
0005435086888	4104	Economy	7500.00
0005435928115	4104	Economy	7500.00
0005435086891	4104	Economy	7500.00
0005435928114	4104	Economy	7500.00
0005435086892	4104	Economy	7500.00
0005435928138	4104	Economy	7500.00
0005435086893	4104	Economy	7500.00
0005435086890	4104	Economy	7500.00
0005435928147	4104	Economy	7500.00
0005435086889	4104	Economy	7500.00
0005435928137	4104	Economy	7500.00
0005435086886	4104	Economy	7500.00
0005435928180	24409	Economy	7500.00
0005435928176	24409	Economy	7500.00
0005435928178	24409	Economy	7500.00
0005435086826	24409	Economy	7500.00
0005435086841	24409	Economy	7500.00
0005435928179	24409	Economy	7500.00
0005435928177	24409	Economy	7500.00
0005435086827	24409	Economy	7500.00
0005435086837	24409	Economy	7500.00
0005435086838	24409	Economy	7500.00
0005435928181	24409	Economy	7500.00
0005435086831	24409	Economy	7500.00
0005435551558	11065	Business	144300.00
0005435551559	11065	Business	144300.00
0005435098541	11065	Business	144300.00
0005435098550	11065	Business	144300.00
0005435551543	11065	Business	144300.00
0005435098549	11065	Business	144300.00
0005435551588	11065	Economy	48100.00
0005435098547	11065	Economy	48100.00
0005435551580	11065	Economy	48100.00
0005435098543	11065	Economy	48100.00
0005435551585	11065	Economy	48100.00
0005435551562	11065	Economy	48100.00
0005435551553	11065	Economy	48100.00
0005435551586	11065	Economy	48100.00
0005435551564	11065	Economy	48100.00
0005435551614	11065	Economy	48100.00
0005435551544	11065	Economy	48100.00
0005435551551	11065	Economy	48100.00
0005435551590	11065	Economy	48100.00
0005435551538	11065	Economy	48100.00
0005435098548	11065	Economy	48100.00
0005435551566	11065	Economy	48100.00
0005435551567	11065	Economy	48100.00
0005435551584	11065	Economy	48100.00
0005435551545	11065	Economy	48100.00
0005435551550	11065	Economy	48100.00
0005435551557	11065	Economy	48100.00
0005435551589	11065	Economy	52900.00
0005435551546	11065	Economy	48100.00
0005435098556	11065	Economy	48100.00
0005435551605	11065	Economy	48100.00
0005435551579	11065	Economy	48100.00
0005435551613	11065	Economy	48100.00
0005435551568	11065	Economy	48100.00
0005435551530	11065	Economy	48100.00
0005435551563	11065	Economy	48100.00
0005435551542	11065	Economy	48100.00
0005435551552	11065	Economy	48100.00
0005435098542	11065	Economy	48100.00
0005435551577	11065	Economy	48100.00
0005435551594	11065	Economy	48100.00
0005435551547	11065	Economy	48100.00
0005435551576	11065	Economy	48100.00
0005435551622	17014	Business	144300.00
0005435551630	17014	Business	144300.00
0005435098574	17014	Business	144300.00
0005435551640	17014	Business	144300.00
0005435551641	17014	Business	144300.00
0005435098570	17014	Economy	48100.00
0005435551628	17014	Economy	48100.00
0005435551633	17014	Economy	48100.00
0005435551624	17014	Economy	48100.00
0005435551632	17014	Economy	48100.00
0005435551635	17014	Economy	48100.00
0005435098572	17014	Economy	48100.00
0005435551623	17014	Economy	48100.00
0005435098571	17014	Economy	48100.00
0005435551629	17014	Economy	48100.00
0005435551631	17014	Economy	48100.00
0005435098575	17014	Economy	48100.00
0005435098573	17014	Economy	48100.00
0005435551638	17014	Economy	48100.00
0005435551636	17014	Economy	48100.00
0005435551634	17014	Economy	48100.00
0005435551637	17014	Economy	48100.00
0005435551639	17014	Economy	48100.00
0005435551625	17014	Economy	48100.00
0005435551626	17014	Economy	48100.00
0005435551627	17014	Economy	48100.00
0005434964077	18257	Business	203300.00
0005433261632	18257	Business	203300.00
0005433261634	18257	Business	203300.00
0005433261647	18257	Business	203300.00
0005434964232	18257	Business	203300.00
0005433261638	18257	Business	203300.00
0005434964258	18257	Business	203300.00
0005433261644	18257	Business	203300.00
0005434964191	18257	Business	203300.00
0005434964161	18257	Economy	74500.00
0005434964179	18257	Economy	74500.00
0005434964184	18257	Economy	67800.00
0005433261645	18257	Economy	67800.00
0005433261633	18257	Economy	67800.00
0005433261635	18257	Economy	67800.00
0005434964207	18257	Economy	67800.00
0005434964156	18257	Economy	67800.00
0005433261639	18257	Economy	67800.00
0005433261637	18257	Economy	67800.00
0005434964123	18257	Economy	67800.00
0005434964192	18257	Economy	67800.00
0005434964254	18257	Economy	67800.00
0005433261628	18257	Economy	67800.00
0005434964131	18257	Economy	67800.00
0005434964172	18257	Economy	67800.00
0005434964223	18257	Economy	67800.00
0005434964201	18257	Economy	67800.00
0005434964159	18257	Economy	67800.00
0005434964236	18257	Economy	67800.00
0005434964177	18257	Economy	67800.00
0005434964218	18257	Economy	67800.00
0005434964124	18257	Economy	67800.00
0005434964162	18257	Economy	67800.00
0005433261636	18257	Economy	67800.00
0005434964219	18257	Economy	67800.00
0005434964214	18257	Economy	67800.00
0005433261640	18257	Economy	67800.00
0005433261629	18257	Economy	67800.00
0005433261627	18257	Economy	67800.00
0005433261646	18257	Economy	74500.00
0005433261643	18257	Economy	67800.00
0005434964234	18257	Economy	67800.00
0005433261642	18257	Economy	67800.00
0005434964204	18257	Economy	67800.00
0005434964240	18257	Economy	67800.00
0005434964173	18257	Economy	67800.00
0005434964149	18257	Economy	67800.00
0005434964235	18257	Economy	67800.00
0005434964239	18257	Economy	67800.00
0005433261641	18257	Economy	67800.00
0005434964216	18257	Economy	67800.00
0005433261631	18257	Economy	67800.00
0005434964233	18257	Economy	67800.00
0005434964076	18257	Economy	67800.00
0005434964157	18257	Economy	67800.00
0005433261630	18257	Economy	67800.00
0005434964200	18257	Economy	67800.00
0005434964217	18257	Economy	67800.00
0005434964213	18257	Economy	67800.00
0005434964206	18257	Economy	67800.00
0005433194828	4867	Business	44200.00
0005434626031	4867	Business	44200.00
0005434626028	4867	Economy	14700.00
0005434626033	4867	Economy	14700.00
0005435907480	4867	Economy	14700.00
0005434626030	4867	Economy	14700.00
0005435907484	4867	Economy	14700.00
0005434626029	4867	Economy	14700.00
0005435907510	4867	Economy	14700.00
0005434626034	4867	Economy	14700.00
0005434626027	4867	Economy	14700.00
0005435907497	4867	Economy	14700.00
0005434626035	4867	Economy	14700.00
0005434626036	4867	Economy	14700.00
0005434626032	4867	Economy	14700.00
0005435907502	4867	Economy	14700.00
0005435907483	4867	Economy	14700.00
0005435907511	4867	Economy	14700.00
0005434625989	32921	Business	44200.00
0005434625968	32921	Business	44200.00
0005434625911	32921	Economy	14700.00
0005435907539	32921	Economy	16200.00
0005434625958	32921	Economy	14700.00
0005435907541	32921	Economy	14700.00
0005434625912	32921	Economy	14700.00
0005434625993	32921	Economy	14700.00
0005434625969	32921	Economy	14700.00
0005435907540	32921	Economy	14700.00
0005434625992	32921	Economy	14700.00
0005435907538	32921	Economy	14700.00
0005433194876	32921	Economy	14700.00
0005434625915	32921	Economy	14700.00
0005434625988	32921	Economy	14700.00
0005435785295	13765	Economy	3400.00
0005435785204	13765	Economy	3400.00
0005435785251	13765	Economy	3100.00
0005435937414	13765	Economy	3100.00
0005435787348	13765	Economy	3100.00
0005435785203	13765	Economy	3100.00
0005435937411	13765	Economy	3100.00
0005435785287	13765	Economy	3100.00
0005435785070	13765	Economy	3100.00
0005435785224	13765	Economy	3100.00
0005435785283	13765	Economy	3100.00
0005435785260	13765	Economy	3100.00
0005435785296	13765	Economy	3100.00
0005432195708	13765	Economy	3100.00
0005435785150	13765	Economy	3100.00
0005435785337	13765	Economy	3100.00
0005435785181	13765	Economy	3100.00
0005435785290	13765	Economy	3100.00
0005435785375	13765	Economy	3100.00
0005435937415	13765	Economy	3100.00
0005435785286	13765	Economy	3100.00
0005435937413	13765	Economy	3100.00
0005435785298	13765	Economy	3100.00
0005435785268	13765	Economy	3100.00
0005435785149	13765	Economy	3100.00
0005435785130	13765	Economy	3100.00
0005435785294	13765	Economy	3100.00
0005435785282	13765	Economy	3100.00
0005435787347	13765	Economy	3100.00
0005435785301	13765	Economy	3100.00
0005435785293	13765	Economy	3100.00
0005432195709	13765	Economy	3100.00
0005435937412	13765	Economy	3100.00
0005435937410	13765	Economy	3100.00
0005435785199	13765	Economy	3100.00
0005435785309	13765	Economy	3100.00
0005435785242	13765	Economy	3100.00
0005435785289	13765	Economy	3100.00
0005435785261	13765	Economy	3100.00
0005432190653	27443	Economy	3400.00
0005435785543	27443	Economy	3400.00
0005435937364	27443	Economy	3400.00
0005435785546	27443	Economy	3400.00
0005435785572	27443	Economy	3100.00
0005435785563	27443	Economy	3100.00
0005435785555	27443	Economy	3100.00
0005435785547	27443	Economy	3100.00
0005435785559	27443	Economy	3100.00
0005435785544	27443	Economy	3100.00
0005435937350	27443	Economy	3100.00
0005435787366	27443	Economy	3100.00
0005435785562	27443	Economy	3100.00
0005435785565	27443	Economy	3100.00
0005435785574	27443	Economy	3100.00
0005435785564	27443	Economy	3100.00
0005435785549	27443	Economy	3100.00
0005435785545	27443	Economy	3100.00
0005435785567	27443	Economy	3100.00
0005435785575	27443	Economy	3100.00
0005435785550	27443	Economy	3100.00
0005435785553	27443	Economy	3100.00
0005435785576	27443	Economy	3100.00
0005435785561	27443	Economy	3100.00
0005435937358	27443	Economy	3100.00
0005435785568	27443	Economy	3100.00
0005435937345	27443	Economy	3100.00
0005435785551	27443	Economy	3100.00
0005435785569	27443	Economy	3100.00
0005435785554	27443	Economy	3100.00
0005435785558	27443	Economy	3100.00
0005435937372	27443	Economy	3100.00
0005435785573	27443	Economy	3100.00
0005435785566	27443	Economy	3100.00
0005435937370	27443	Economy	3100.00
0005435785557	27443	Economy	3100.00
0005435937371	27443	Economy	3100.00
0005435785571	27443	Economy	3100.00
0005435937385	27443	Economy	3100.00
0005435937344	27443	Economy	3100.00
0005435785552	27443	Economy	3100.00
0005435785560	27443	Economy	3100.00
0005435785548	27443	Economy	3100.00
0005435785577	27443	Economy	3100.00
0005435787367	27443	Economy	3100.00
0005435937386	27443	Economy	3100.00
0005435785556	27443	Economy	3100.00
0005432190652	27443	Economy	3100.00
0005435785570	27443	Economy	3100.00
0005434407728	20259	Business	12000.00
0005434407725	20259	Business	12000.00
0005434407702	20259	Business	12000.00
0005435311141	20259	Business	12000.00
0005434407845	20259	Business	12000.00
0005434408010	20259	Business	12000.00
0005434407724	20259	Business	12000.00
0005435311149	20259	Business	12000.00
0005434408011	20259	Business	12000.00
0005434408056	20259	Economy	4000.00
0005435311153	20259	Economy	4000.00
0005434407677	20259	Economy	4000.00
0005435311147	20259	Economy	4000.00
0005435311139	20259	Economy	4000.00
0005434407686	20259	Economy	4000.00
0005432058411	20259	Economy	4000.00
0005434407402	20259	Economy	4400.00
0005434407689	20259	Economy	4400.00
0005434407697	20259	Economy	4400.00
0005434407447	20259	Economy	4400.00
0005434407784	20259	Economy	4400.00
0005434407613	20259	Economy	4000.00
0005434407403	20259	Economy	4000.00
0005434407246	20259	Economy	4000.00
0005435311150	20259	Economy	4000.00
0005434407568	20259	Economy	4000.00
0005435311143	20259	Economy	4000.00
0005434407391	20259	Economy	4000.00
0005434407620	20259	Economy	4000.00
0005434407849	20259	Economy	4000.00
0005435311152	20259	Economy	4000.00
0005432058410	20259	Economy	4000.00
0005434407695	20259	Economy	4000.00
0005432058409	20259	Economy	4000.00
0005434407793	20259	Economy	4000.00
0005435311156	20259	Economy	4000.00
0005434407718	20259	Economy	4000.00
0005435311145	20259	Economy	4000.00
0005434407846	20259	Economy	4000.00
0005434407902	20259	Economy	4000.00
0005435311140	20259	Economy	4000.00
0005435311142	20259	Economy	4000.00
0005434407651	20259	Economy	4000.00
0005434407698	20259	Economy	4000.00
0005434407618	20259	Economy	4000.00
0005435311144	20259	Economy	4000.00
0005434407456	20259	Economy	4000.00
0005434407713	20259	Economy	4000.00
0005434407452	20259	Economy	4000.00
0005434407573	20259	Economy	4000.00
0005432058412	20259	Economy	4000.00
0005434407442	20259	Economy	4000.00
0005435311155	20259	Economy	4000.00
0005434407796	20259	Economy	4000.00
0005434407703	20259	Economy	4000.00
0005434407608	20259	Economy	4000.00
0005434407699	20259	Economy	4000.00
0005434407619	20259	Economy	4000.00
0005434407629	20259	Economy	4000.00
0005435311151	20259	Economy	4000.00
0005435311154	20259	Economy	4000.00
0005434407685	20259	Economy	4000.00
0005434407844	20259	Economy	4000.00
0005435311146	20259	Economy	4000.00
0005434407555	20259	Economy	4000.00
0005434407794	20259	Economy	4000.00
0005434407783	20259	Economy	4000.00
0005434407443	20259	Economy	4000.00
0005434407682	20259	Economy	4000.00
0005434407628	20259	Economy	4000.00
0005435311148	20259	Economy	4000.00
0005434407650	20259	Economy	4000.00
0005434407474	20259	Economy	4000.00
0005434407318	20259	Economy	4000.00
0005434407609	20259	Economy	4000.00
0005434408198	26982	Business	12000.00
0005434408232	26982	Business	12000.00
0005434408209	26982	Business	12000.00
0005432153988	26982	Business	12000.00
0005434408203	26982	Business	12000.00
0005434408225	26982	Business	12000.00
0005434408219	26982	Business	12000.00
0005434408206	26982	Business	12000.00
0005434408242	26982	Business	12000.00
0005434408210	26982	Business	12000.00
0005435311032	26982	Economy	4000.00
0005435311025	26982	Economy	4000.00
0005435310998	26982	Economy	4000.00
0005435310979	26982	Economy	4000.00
0005434408216	26982	Economy	4000.00
0005434408220	26982	Economy	4000.00
0005434408200	26982	Economy	4400.00
0005434408204	26982	Economy	4400.00
0005435310981	26982	Economy	4400.00
0005434408222	26982	Economy	4400.00
0005434408244	26982	Economy	4400.00
0005434408230	26982	Economy	4000.00
0005434408229	26982	Economy	4000.00
0005434408238	26982	Economy	4000.00
0005434408195	26982	Economy	4000.00
0005435311018	26982	Economy	4000.00
0005432153986	26982	Economy	4000.00
0005434408201	26982	Economy	4000.00
0005434408214	26982	Economy	4000.00
0005435311024	26982	Economy	4000.00
0005432153992	26982	Economy	4000.00
0005434408189	26982	Economy	4000.00
0005434408215	26982	Economy	4000.00
0005434408247	26982	Economy	4000.00
0005434408248	26982	Economy	4000.00
0005434408236	26982	Economy	4000.00
0005434408249	26982	Economy	4000.00
0005435311019	26982	Economy	4000.00
0005434408237	26982	Economy	4000.00
0005434408235	26982	Economy	4000.00
0005435311010	26982	Economy	4000.00
0005432153989	26982	Economy	4000.00
0005432153991	26982	Economy	4000.00
0005434408243	26982	Economy	4000.00
0005434408233	26982	Economy	4000.00
0005434408221	26982	Economy	4000.00
0005432153985	26982	Economy	4000.00
0005434408226	26982	Economy	4000.00
0005434408196	26982	Economy	4000.00
0005434408199	26982	Economy	4000.00
0005434408191	26982	Economy	4000.00
0005434408194	26982	Economy	4000.00
0005434408208	26982	Economy	4000.00
0005432153987	26982	Economy	4000.00
0005434408252	26982	Economy	4000.00
0005434408250	26982	Economy	4000.00
0005434408234	26982	Economy	4000.00
0005434408245	26982	Economy	4000.00
0005434408217	26982	Economy	4000.00
0005432153990	26982	Economy	4000.00
0005434408213	26982	Economy	4000.00
0005434408240	26982	Economy	4000.00
0005434408212	26982	Economy	4000.00
0005434408241	26982	Economy	4000.00
0005434408251	26982	Economy	4000.00
0005434408253	26982	Economy	4000.00
0005434408246	26982	Economy	4000.00
0005434408239	26982	Economy	4000.00
0005434408218	26982	Economy	4000.00
0005434408223	26982	Economy	4000.00
0005434408197	26982	Economy	4000.00
0005434408205	26982	Economy	4000.00
0005434408224	26982	Economy	4000.00
0005434408193	26982	Economy	4000.00
0005434408231	26982	Economy	4000.00
0005434408192	26982	Economy	4000.00
0005434408211	26982	Economy	4000.00
0005434408207	26982	Economy	4000.00
0005434408190	26982	Economy	4000.00
0005434408202	26982	Economy	4000.00
0005434408227	26982	Economy	4000.00
0005434408228	26982	Economy	4000.00
0005434311236	5720	Business	43300.00
0005433124010	5720	Business	43300.00
0005433123751	5720	Business	43300.00
0005432109722	5720	Business	43300.00
0005433123841	5720	Economy	14400.00
0005434319505	5720	Economy	14400.00
0005434319506	5720	Economy	14400.00
0005434319508	5720	Economy	14400.00
0005433123750	5720	Economy	14400.00
0005433123907	5720	Economy	15900.00
0005433123875	5720	Economy	15900.00
0005433123883	5720	Economy	14400.00
0005433123856	5720	Economy	14400.00
0005433123966	5720	Economy	14400.00
0005433123842	5720	Economy	14400.00
0005433123838	5720	Economy	14400.00
0005434319509	5720	Economy	14400.00
0005433123850	5720	Economy	14400.00
0005434311235	5720	Economy	14400.00
0005433123909	5720	Economy	14400.00
0005433123901	5720	Economy	14400.00
0005433123762	5720	Economy	14400.00
0005434319504	5720	Economy	14400.00
0005433123921	5720	Economy	14400.00
0005433123902	5720	Economy	14400.00
0005433123938	5720	Economy	14400.00
0005433123855	5720	Economy	14400.00
0005433123900	5720	Economy	14400.00
0005433124011	5720	Economy	14400.00
0005432109723	5720	Economy	14400.00
0005432109724	5720	Economy	14400.00
0005434319507	5720	Economy	14400.00
0005433123849	5720	Economy	14400.00
0005433123877	5720	Economy	14400.00
0005433123937	5720	Economy	14400.00
0005433123851	5720	Economy	14400.00
0005433123839	5720	Economy	14400.00
0005433123967	5720	Economy	14400.00
0005433123872	5720	Economy	14400.00
0005433123867	5720	Economy	14400.00
0005433123969	5720	Economy	14400.00
0005433123908	5720	Economy	14400.00
0005434311234	5720	Economy	14400.00
0005433124093	15654	Business	43300.00
0005434319403	15654	Business	43300.00
0005433124085	15654	Business	43300.00
0005434311212	15654	Business	43300.00
0005433124082	15654	Economy	14400.00
0005433124078	15654	Economy	14400.00
0005434311204	15654	Economy	15900.00
0005433124086	15654	Economy	14400.00
0005434319345	15654	Economy	14400.00
0005433124090	15654	Economy	14400.00
0005433124087	15654	Economy	14400.00
0005434319373	15654	Economy	14400.00
0005433124094	15654	Economy	14400.00
0005433124095	15654	Economy	14400.00
0005433124077	15654	Economy	14400.00
0005433124074	15654	Economy	14400.00
0005433124089	15654	Economy	14400.00
0005434319370	15654	Economy	14400.00
0005434319344	15654	Economy	14400.00
0005433124081	15654	Economy	14400.00
0005433124076	15654	Economy	14400.00
0005433124075	15654	Economy	14400.00
0005433124084	15654	Economy	14400.00
0005433124079	15654	Economy	14400.00
0005433124088	15654	Economy	14400.00
0005433124083	15654	Economy	14400.00
0005434319318	15654	Economy	14400.00
0005434311205	15654	Economy	14400.00
0005433124080	15654	Economy	14400.00
0005434319371	15654	Economy	14400.00
0005433124096	15654	Economy	14400.00
0005433124091	15654	Economy	14400.00
0005434319346	15654	Economy	14400.00
0005433124092	15654	Economy	14400.00
0005435217701	24969	Economy	17100.00
0005435220305	24969	Economy	15500.00
0005435220314	24969	Economy	15500.00
0005435220315	24969	Economy	15500.00
0005435220313	24969	Economy	15500.00
0005435221513	24969	Economy	15500.00
0005435217702	24969	Economy	15500.00
0005435220311	24969	Economy	15500.00
0005435217703	24969	Economy	15500.00
0005434189170	8961	Economy	27400.00
0005434484397	8961	Economy	24900.00
0005434189193	8961	Economy	24900.00
0005434189159	8961	Economy	24900.00
0005434189171	8961	Economy	24900.00
0005434484394	8961	Economy	24900.00
0005434189166	8961	Economy	24900.00
0005434484398	8961	Economy	24900.00
0005434484395	8961	Economy	24900.00
0005434484399	8961	Economy	24900.00
0005434484396	8961	Economy	24900.00
0005434484344	16618	Economy	27400.00
0005434484345	16618	Economy	24900.00
0005434484337	16618	Economy	24900.00
0005434189219	16618	Economy	24900.00
0005434189221	16618	Economy	24900.00
0005434189223	16618	Economy	24900.00
0005434484326	16618	Economy	24900.00
0005434189218	16618	Economy	24900.00
0005434189220	16618	Economy	24900.00
0005434484325	16618	Economy	24900.00
0005434189222	16618	Economy	24900.00
0005434189224	16618	Economy	24900.00
0005434484340	16618	Economy	24900.00
0005434484347	16618	Economy	24900.00
0005434189225	16618	Economy	24900.00
0005433124076	7681	Business	11100.00
0005433124087	7681	Business	11100.00
0005433124075	7681	Business	11100.00
0005433124078	7681	Business	11100.00
0005433722192	7681	Business	11100.00
0005433722193	7681	Economy	3700.00
0005433124092	7681	Economy	3700.00
0005433124083	7681	Economy	3700.00
0005433124084	7681	Economy	3700.00
0005433124095	7681	Economy	4100.00
0005433124081	7681	Economy	3700.00
0005433124091	7681	Economy	3700.00
0005433124079	7681	Economy	3700.00
0005433124093	7681	Economy	3700.00
0005433124080	7681	Economy	3700.00
0005433124089	7681	Economy	3700.00
0005433722187	7681	Economy	3700.00
0005433124086	7681	Economy	3700.00
0005433124088	7681	Economy	3700.00
0005433124094	7681	Economy	3700.00
0005433124082	7681	Economy	3700.00
0005433124085	7681	Economy	3700.00
0005433124090	7681	Economy	3700.00
0005433124096	7681	Economy	3700.00
0005433124074	7681	Economy	3700.00
0005433124077	7681	Economy	3700.00
0005432721100	7683	Business	11100.00
0005433450121	7683	Business	11100.00
0005432721097	7683	Business	11100.00
0005432721110	7683	Business	11100.00
0005433450137	7683	Business	11100.00
0005432693312	7683	Business	11100.00
0005432693294	7683	Business	11100.00
0005433450139	7683	Business	11100.00
0005432721113	7683	Business	11100.00
0005432721107	7683	Business	11100.00
0005433450119	7683	Economy	3700.00
0005432693314	7683	Economy	3700.00
0005432693292	7683	Economy	3700.00
0005432693301	7683	Economy	3700.00
0005432693290	7683	Economy	3700.00
0005432071595	7683	Economy	3700.00
0005433450132	7683	Economy	3700.00
0005433450129	7683	Economy	3700.00
0005432721092	7683	Economy	4100.00
0005433450135	7683	Economy	4100.00
0005432693299	7683	Economy	4100.00
0005433450140	7683	Economy	4100.00
0005433450133	7683	Economy	4100.00
0005432721114	7683	Economy	3700.00
0005432721103	7683	Economy	3700.00
0005432693297	7683	Economy	3700.00
0005432721096	7683	Economy	3700.00
0005432693311	7683	Economy	3700.00
0005432721112	7683	Economy	3700.00
0005432693309	7683	Economy	3700.00
0005433450138	7683	Economy	3700.00
0005432721099	7683	Economy	3700.00
0005432693302	7683	Economy	3700.00
0005432693286	7683	Economy	3700.00
0005432693315	7683	Economy	3700.00
0005433450134	7683	Economy	3700.00
0005432721098	7683	Economy	3700.00
0005432721088	7683	Economy	3700.00
0005432721108	7683	Economy	3700.00
0005433450123	7683	Economy	3700.00
0005432721106	7683	Economy	3700.00
0005432071594	7683	Economy	3700.00
0005432693313	7683	Economy	3700.00
0005432721091	7683	Economy	3700.00
0005432693293	7683	Economy	3700.00
0005432693285	7683	Economy	3700.00
0005433450125	7683	Economy	3700.00
0005432721093	7683	Economy	3700.00
0005432693303	7683	Economy	3700.00
0005432693287	7683	Economy	3700.00
0005432721094	7683	Economy	3700.00
0005432693300	7683	Economy	3700.00
0005433450131	7683	Economy	3700.00
0005432071597	7683	Economy	3700.00
0005432693307	7683	Economy	3700.00
0005433450124	7683	Economy	3700.00
0005432693289	7683	Economy	3700.00
0005432693310	7683	Economy	3700.00
0005433450122	7683	Economy	3700.00
0005432693308	7683	Economy	3700.00
0005432721095	7683	Economy	3700.00
0005433450127	7683	Economy	3700.00
0005433450128	7683	Economy	3700.00
0005432693296	7683	Economy	3700.00
0005432693305	7683	Economy	3700.00
0005432721101	7683	Economy	3700.00
0005432693288	7683	Economy	3700.00
0005432721109	7683	Economy	3700.00
0005432693304	7683	Economy	3700.00
0005432693295	7683	Economy	3700.00
0005433450136	7683	Economy	3700.00
0005432721090	7683	Economy	3700.00
0005432721104	7683	Economy	3700.00
0005432721102	7683	Economy	3700.00
0005433450126	7683	Economy	3700.00
0005432721111	7683	Economy	3700.00
0005432721087	7683	Economy	3700.00
0005433450130	7683	Economy	3700.00
0005432721089	7683	Economy	3700.00
0005432693291	7683	Economy	3700.00
0005432721105	7683	Economy	3700.00
0005433450120	7683	Economy	3700.00
0005432693298	7683	Economy	3700.00
0005432693306	7683	Economy	3700.00
0005432721115	7683	Economy	3700.00
0005432071596	7683	Economy	3700.00
0005433449905	30299	Business	11100.00
0005432693007	30299	Business	11100.00
0005432693063	30299	Business	11100.00
0005432693050	30299	Business	11100.00
0005433449954	30299	Business	11100.00
0005433450037	30299	Business	11100.00
0005432693008	30299	Economy	3700.00
0005432693113	30299	Economy	3700.00
0005433449963	30299	Economy	3700.00
0005432692852	30299	Economy	3700.00
0005432693033	30299	Economy	3700.00
0005432692949	30299	Economy	3700.00
0005432692972	30299	Economy	4100.00
0005433449933	30299	Economy	4100.00
0005433449998	30299	Economy	3700.00
0005433449892	30299	Economy	3700.00
0005432693004	30299	Economy	3700.00
0005433449921	30299	Economy	3700.00
0005432692987	30299	Economy	3700.00
0005433449968	30299	Economy	3700.00
0005433450044	30299	Economy	3700.00
0005433449976	30299	Economy	3700.00
0005432693032	30299	Economy	3700.00
0005433449894	30299	Economy	3700.00
0005432693039	30299	Economy	3700.00
0005433449900	30299	Economy	3700.00
0005432693024	30299	Economy	3700.00
0005433449962	30299	Economy	3700.00
0005432693005	30299	Economy	3700.00
0005433449961	30299	Economy	3700.00
0005432693143	30299	Economy	3700.00
0005432693034	30299	Economy	3700.00
0005433449893	30299	Economy	3700.00
0005433450041	30299	Economy	3700.00
0005432693123	30299	Economy	3700.00
0005433123841	30300	Business	11100.00
0005433123900	30300	Business	11100.00
0005433722272	30300	Business	11100.00
0005432720854	30300	Business	11100.00
0005432720814	30300	Business	11100.00
0005432720953	30300	Business	11100.00
0005433123967	30300	Business	11100.00
0005432720975	30300	Business	11100.00
0005432720857	30300	Business	11100.00
0005433123938	30300	Business	11100.00
0005433123856	30300	Business	11100.00
0005432720908	30300	Business	11100.00
0005433123850	30300	Economy	3700.00
0005432720759	30300	Economy	3700.00
0005432720841	30300	Economy	3700.00
0005432720856	30300	Economy	3700.00
0005432721001	30300	Economy	3700.00
0005432720962	30300	Economy	4100.00
0005433123908	30300	Economy	4100.00
0005433123851	30300	Economy	4100.00
0005432720845	30300	Economy	4100.00
0005433123902	30300	Economy	3700.00
0005432720899	30300	Economy	3700.00
0005433123966	30300	Economy	3700.00
0005432720929	30300	Economy	3700.00
0005433123883	30300	Economy	3700.00
0005433123901	30300	Economy	3700.00
0005433123875	30300	Economy	3700.00
0005432720872	30300	Economy	3700.00
0005433722275	30300	Economy	3700.00
0005433722276	30300	Economy	3700.00
0005432720901	30300	Economy	3700.00
0005433123867	30300	Economy	3700.00
0005432720898	30300	Economy	3700.00
0005432720961	30300	Economy	3700.00
0005432720758	30300	Economy	3700.00
0005433123921	30300	Economy	3700.00
0005433123842	30300	Economy	3700.00
0005432720855	30300	Economy	3700.00
0005433123849	30300	Economy	3700.00
0005432720930	30300	Economy	3700.00
0005432720964	30300	Economy	3700.00
0005433124010	30300	Economy	3700.00
0005432720820	30300	Economy	3700.00
0005433123839	30300	Economy	3700.00
0005432720949	30300	Economy	3700.00
0005432720863	30300	Economy	3700.00
0005433123937	30300	Economy	3700.00
0005432720842	30300	Economy	3700.00
0005433722274	30300	Economy	3700.00
0005432720862	30300	Economy	3700.00
0005432720846	30300	Economy	3700.00
0005432720828	30300	Economy	3700.00
0005433123838	30300	Economy	3700.00
0005433123969	30300	Economy	3700.00
0005432720922	30300	Economy	3700.00
0005433722273	30300	Economy	3700.00
0005433123872	30300	Economy	3700.00
0005433123750	30300	Economy	3700.00
0005433123877	30300	Economy	3700.00
0005432720888	30300	Economy	3700.00
0005433123909	30300	Economy	3700.00
0005433124011	30300	Economy	3700.00
0005433123751	30300	Economy	3700.00
0005433123907	30300	Economy	3700.00
0005433123855	30300	Economy	3700.00
0005433123762	30300	Economy	3700.00
0005432927972	1385	Business	70400.00
0005433525124	1385	Business	70400.00
0005434586808	1385	Business	70400.00
0005434586806	1385	Business	70400.00
0005432927992	1385	Business	70400.00
0005434586799	1385	Business	70400.00
0005433724838	1385	Business	70400.00
0005432927973	1385	Business	70400.00
0005432271027	1385	Business	70400.00
0005433525115	1385	Business	70400.00
0005434586810	1385	Business	70400.00
0005433525116	1385	Business	70400.00
0005434586791	1385	Economy	23500.00
0005433193040	1385	Economy	23500.00
0005434586796	1385	Economy	23500.00
0005432271025	1385	Economy	23500.00
0005432968845	1385	Economy	23500.00
0005434586812	1385	Economy	23500.00
0005434514987	1385	Economy	25800.00
0005434513598	1385	Economy	25800.00
0005433525123	1385	Economy	25800.00
0005434513599	1385	Economy	25800.00
0005432271024	1385	Economy	23500.00
0005434514986	1385	Economy	23500.00
0005433525118	1385	Economy	23500.00
0005434586805	1385	Economy	23500.00
0005433193054	1385	Economy	23500.00
0005433525114	1385	Economy	23500.00
0005433193056	1385	Economy	23500.00
0005433724837	1385	Economy	23500.00
0005434586804	1385	Economy	23500.00
0005434586797	1385	Economy	23500.00
0005433193039	1385	Economy	23500.00
0005434586801	1385	Economy	23500.00
0005434586789	1385	Economy	23500.00
0005434586792	1385	Economy	23500.00
0005433724839	1385	Economy	23500.00
0005433525121	1385	Economy	23500.00
0005434586798	1385	Economy	23500.00
0005432968835	1385	Economy	23500.00
0005434586800	1385	Economy	23500.00
0005432968839	1385	Economy	23500.00
0005433724836	1385	Economy	23500.00
0005432927969	1385	Economy	23500.00
0005433193006	1385	Economy	23500.00
0005433193041	1385	Economy	23500.00
0005433525113	1385	Economy	23500.00
0005434586811	1385	Economy	23500.00
0005432927951	1385	Economy	23500.00
0005432271026	1385	Economy	23500.00
0005434586790	1385	Economy	23500.00
0005433525119	1385	Economy	23500.00
0005432927989	1385	Economy	23500.00
0005433525125	1385	Economy	23500.00
0005433525120	1385	Economy	23500.00
0005432968834	1385	Economy	23500.00
0005434586809	1385	Economy	23500.00
0005434586807	1385	Economy	23500.00
0005433724841	1385	Economy	23500.00
0005434513600	1385	Economy	23500.00
0005433525117	1385	Economy	23500.00
0005434586802	1385	Economy	23500.00
0005434586795	1385	Economy	23500.00
0005432927985	1385	Economy	23500.00
0005433193085	1385	Economy	23500.00
0005433193043	1385	Economy	23500.00
0005432927976	1385	Economy	23500.00
0005432968836	1385	Economy	23500.00
0005434586803	1385	Economy	23500.00
0005432927975	1385	Economy	23500.00
0005434586813	1385	Economy	23500.00
0005433724840	1385	Economy	23500.00
0005432927982	1385	Economy	23500.00
0005433193055	1385	Economy	23500.00
0005433193046	1385	Economy	23500.00
0005434586814	1385	Economy	23500.00
0005434586794	1385	Economy	23500.00
0005433192995	1385	Economy	23500.00
0005433193025	1385	Economy	23500.00
0005433525122	1385	Economy	23500.00
0005434586793	1385	Economy	23500.00
0005433193149	18518	Business	70400.00
0005434586701	18518	Business	70400.00
0005434586667	18518	Business	70400.00
0005434586523	18518	Business	70400.00
0005434586552	18518	Business	70400.00
0005433193147	18518	Business	70400.00
0005433525002	18518	Economy	23500.00
0005433193140	18518	Economy	23500.00
0005434586598	18518	Economy	23500.00
0005434586577	18518	Economy	23500.00
0005434586599	18518	Economy	23500.00
0005434514958	18518	Economy	23500.00
0005434586529	18518	Economy	23500.00
0005434586628	18518	Economy	23500.00
0005433193142	18518	Economy	25800.00
0005433524996	18518	Economy	25800.00
0005434586568	18518	Economy	23500.00
0005434586497	18518	Economy	23500.00
0005432968857	18518	Economy	23500.00
0005433193150	18518	Economy	23500.00
0005432968855	18518	Economy	23500.00
0005434514960	18518	Economy	23500.00
0005433724807	18518	Economy	23500.00
0005433193148	18518	Economy	23500.00
0005434586634	18518	Economy	23500.00
0005433525020	18518	Economy	23500.00
0005433193144	18518	Economy	23500.00
0005433193139	18518	Economy	23500.00
0005433193146	18518	Economy	23500.00
0005434586635	18518	Economy	23500.00
0005434586670	18518	Economy	23500.00
0005432968856	18518	Economy	23500.00
0005434586429	18518	Economy	23500.00
0005434586522	18518	Economy	23500.00
0005433193143	18518	Economy	23500.00
0005432928019	18518	Economy	23500.00
0005433525022	18518	Economy	23500.00
0005434586643	18518	Economy	23500.00
0005434586735	18518	Economy	23500.00
0005433524968	18518	Economy	23500.00
0005433193141	18518	Economy	23500.00
0005433193138	18518	Economy	23500.00
0005432928018	18518	Economy	23500.00
0005433525001	18518	Economy	23500.00
0005433525019	18518	Economy	23500.00
0005434586613	18518	Economy	23500.00
0005432928022	18518	Economy	23500.00
0005434586703	18518	Economy	23500.00
0005434586672	18518	Economy	23500.00
0005434514959	18518	Economy	23500.00
0005434586567	18518	Economy	23500.00
0005434586579	18518	Economy	23500.00
0005433525021	18518	Economy	23500.00
0005434586671	18518	Economy	23500.00
0005434586511	18518	Economy	23500.00
0005433193145	18518	Economy	23500.00
0005434514961	18518	Economy	23500.00
0005432928020	18518	Economy	23500.00
0005432928021	18518	Economy	23500.00
0005434586734	18518	Economy	23500.00
0005434586510	18518	Economy	23500.00
0005434344448	11478	Economy	4300.00
0005434344441	11478	Economy	4300.00
0005434344467	11478	Economy	4300.00
0005434344463	11478	Economy	4300.00
0005434344469	11478	Economy	4000.00
0005434344452	11478	Economy	4000.00
0005434344457	11478	Economy	4000.00
0005435302170	11478	Economy	4000.00
0005434344453	11478	Economy	4000.00
0005434344442	11478	Economy	4000.00
0005434344445	11478	Economy	4000.00
0005435302191	11478	Economy	4000.00
0005435302171	11478	Economy	4000.00
0005434344458	11478	Economy	4000.00
0005435302192	11478	Economy	4000.00
0005434344443	11478	Economy	4000.00
0005434344446	11478	Economy	4000.00
0005435302206	11478	Economy	4000.00
0005434344444	11478	Economy	4000.00
0005434344437	11478	Economy	4000.00
0005434344460	11478	Economy	4000.00
0005434344447	11478	Economy	4000.00
0005434344459	11478	Economy	4000.00
0005434142642	11478	Economy	4000.00
0005434344468	11478	Economy	4000.00
0005434142641	11478	Economy	4000.00
0005435302190	11478	Economy	4000.00
0005434344464	11478	Economy	4000.00
0005434344466	11478	Economy	4000.00
0005434344451	11478	Economy	4000.00
0005434344439	11478	Economy	4000.00
0005434344461	11478	Economy	4000.00
0005434344438	11478	Economy	4000.00
0005434344465	11478	Economy	4000.00
0005434344454	11478	Economy	4000.00
0005434344455	11478	Economy	4000.00
0005435302189	11478	Economy	4000.00
0005434142640	11478	Economy	4000.00
0005434344462	11478	Economy	4000.00
0005434344456	11478	Economy	4000.00
0005435302207	11478	Economy	4000.00
0005435302193	11478	Economy	4000.00
0005434344449	11478	Economy	4000.00
0005434344440	11478	Economy	4000.00
0005434344450	11478	Economy	4000.00
0005434344137	29772	Economy	4300.00
0005434344241	29772	Economy	4300.00
0005434142602	29772	Economy	4300.00
0005434344089	29772	Economy	4300.00
0005434344075	29772	Economy	4000.00
0005434344088	29772	Economy	4000.00
0005434142598	29772	Economy	4000.00
0005434142601	29772	Economy	4000.00
0005435304191	29772	Economy	4000.00
0005434344066	29772	Economy	4000.00
0005434344113	29772	Economy	4000.00
0005434344269	29772	Economy	4000.00
0005434344132	29772	Economy	4000.00
0005434344184	29772	Economy	4000.00
0005434344057	29772	Economy	4000.00
0005434344102	29772	Economy	4000.00
0005434344186	29772	Economy	4000.00
0005434344063	29772	Economy	4000.00
0005434344197	29772	Economy	4000.00
0005434142600	29772	Economy	4000.00
0005434344185	29772	Economy	4000.00
0005434344087	29772	Economy	4000.00
0005434344194	29772	Economy	4000.00
0005435304188	29772	Economy	4000.00
0005434344058	29772	Economy	4000.00
0005434343964	29772	Economy	4000.00
0005435305027	29772	Economy	4000.00
0005435304190	29772	Economy	4000.00
0005434344043	29772	Economy	4000.00
0005434344076	29772	Economy	4000.00
0005434344135	29772	Economy	4000.00
0005435304189	29772	Economy	4000.00
0005434343965	29772	Economy	4000.00
0005434344233	29772	Economy	4000.00
0005434344074	29772	Economy	4000.00
0005435304192	29772	Economy	4000.00
0005434344099	29772	Economy	4000.00
0005434344051	29772	Economy	4000.00
0005434344268	29772	Economy	4000.00
0005434344085	29772	Economy	4000.00
0005434344112	29772	Economy	4000.00
0005434343971	29772	Economy	4000.00
0005435305026	29772	Economy	4000.00
0005434344240	29772	Economy	4000.00
0005434344044	29772	Economy	4000.00
0005434344246	29772	Economy	4000.00
0005434344120	29772	Economy	4000.00
0005435824823	1296	Business	199800.00
0005435824837	1296	Business	199800.00
0005435824832	1296	Business	199800.00
0005433415568	1296	Business	199800.00
0005433415619	1296	Business	199800.00
0005432284580	1296	Business	199800.00
0005435824826	1296	Business	199800.00
0005433415567	1296	Business	199800.00
0005435824824	1296	Business	199800.00
0005435824813	1296	Economy	66600.00
0005435824816	1296	Economy	66600.00
0005435824825	1296	Economy	66600.00
0005432284579	1296	Economy	66600.00
0005435824834	1296	Economy	66600.00
0005435824827	1296	Economy	73200.00
0005433415593	1296	Economy	73200.00
0005433415546	1296	Economy	66600.00
0005435824812	1296	Economy	66600.00
0005435824817	1296	Economy	66600.00
0005435824811	1296	Economy	66600.00
0005433415639	1296	Economy	66600.00
0005433415685	1296	Economy	66600.00
0005435824836	1296	Economy	66600.00
0005433415633	1296	Economy	66600.00
0005433415545	1296	Economy	66600.00
0005433415688	1296	Economy	66600.00
0005433415689	1296	Economy	66600.00
0005435824819	1296	Economy	66600.00
0005435824818	1296	Economy	66600.00
0005435824821	1296	Economy	66600.00
0005433415636	1296	Economy	66600.00
0005433415686	1296	Economy	66600.00
0005435824829	1296	Economy	66600.00
0005435824810	1296	Economy	66600.00
0005435824828	1296	Economy	66600.00
0005435824833	1296	Economy	66600.00
0005435824830	1296	Economy	66600.00
0005435824822	1296	Economy	66600.00
0005433415638	1296	Economy	66600.00
0005435824831	1296	Economy	66600.00
0005435824835	1296	Economy	66600.00
0005435824814	1296	Economy	66600.00
0005435824820	1296	Economy	66600.00
0005433415684	1296	Economy	66600.00
0005435824815	1296	Economy	66600.00
0005432284581	1296	Economy	66600.00
0005435824542	18013	Business	199800.00
0005435824677	18013	Business	199800.00
0005435824537	18013	Business	199800.00
0005435824616	18013	Business	199800.00
0005435824642	18013	Business	199800.00
0005433415778	18013	Business	199800.00
0005435824619	18013	Business	199800.00
0005433415782	18013	Business	199800.00
0005435824583	18013	Business	199800.00
0005433415776	18013	Business	199800.00
0005435824614	18013	Economy	66600.00
0005435824543	18013	Economy	66600.00
0005435824530	18013	Economy	66600.00
0005433415775	18013	Economy	66600.00
0005435824536	18013	Economy	66600.00
0005433415784	18013	Economy	66600.00
0005435824618	18013	Economy	73200.00
0005433415771	18013	Economy	66600.00
0005435824590	18013	Economy	66600.00
0005435824456	18013	Economy	66600.00
0005433415773	18013	Economy	66600.00
0005435824565	18013	Economy	66600.00
0005435824655	18013	Economy	66600.00
0005435824477	18013	Economy	66600.00
0005435824630	18013	Economy	66600.00
0005433415780	18013	Economy	66600.00
0005435824566	18013	Economy	66600.00
0005435824719	18013	Economy	66600.00
0005433415777	18013	Economy	66600.00
0005435824584	18013	Economy	66600.00
0005435824544	18013	Economy	66600.00
0005435824506	18013	Economy	66600.00
0005433415769	18013	Economy	66600.00
0005433415781	18013	Economy	66600.00
0005435824545	18013	Economy	66600.00
0005435824678	18013	Economy	66600.00
0005435824577	18013	Economy	66600.00
0005435824641	18013	Economy	66600.00
0005433415785	18013	Economy	66600.00
0005435824581	18013	Economy	66600.00
0005435824589	18013	Economy	66600.00
0005433415770	18013	Economy	66600.00
0005433415772	18013	Economy	66600.00
0005433415779	18013	Economy	66600.00
0005435824547	18013	Economy	66600.00
0005435824576	18013	Economy	66600.00
0005435824529	18013	Economy	66600.00
0005433415774	18013	Economy	66600.00
0005435824556	18013	Economy	66600.00
0005435824510	18013	Economy	66600.00
0005433415783	18013	Economy	66600.00
0005435824623	18013	Economy	66600.00
0005435824617	18013	Economy	66600.00
0005435824656	18013	Economy	66600.00
0005435824622	18013	Economy	66600.00
0005435824457	18013	Economy	66600.00
0005435824554	18013	Economy	66600.00
0005434460490	17519	Economy	14800.00
0005434460492	17519	Economy	13500.00
0005434462789	17519	Economy	13500.00
0005434460499	17519	Economy	13500.00
0005434462783	17519	Economy	13500.00
0005434460489	17519	Economy	13500.00
0005434462786	17519	Economy	13500.00
0005434460488	17519	Economy	13500.00
0005434462785	17519	Economy	13500.00
0005434460498	17519	Economy	13500.00
0005434462773	17519	Economy	13500.00
0005434460491	17519	Economy	13500.00
0005434460505	17519	Economy	13500.00
0005434462780	17519	Economy	13500.00
0005432784167	5610	Business	27800.00
0005432784176	5610	Business	27800.00
0005432784207	5610	Business	27800.00
0005435476720	5610	Business	27800.00
0005432784213	5610	Business	27800.00
0005435242874	5610	Business	27800.00
0005435242691	5610	Business	27800.00
0005435242839	5610	Business	27800.00
0005435242747	5610	Business	27800.00
0005432784212	5610	Business	27800.00
0005432784174	5610	Business	27800.00
0005432784210	5610	Business	27800.00
0005432784201	5610	Economy	9300.00
0005435242750	5610	Economy	9300.00
0005432784216	5610	Economy	9300.00
0005432784166	5610	Economy	9300.00
0005432784196	5610	Economy	9300.00
0005432144010	5610	Economy	9300.00
0005432784214	5610	Economy	9300.00
0005432784206	5610	Economy	9300.00
0005432144012	5610	Economy	9300.00
0005432784191	5610	Economy	9300.00
0005432784182	5610	Economy	10200.00
0005432784187	5610	Economy	10200.00
0005435242809	5610	Economy	10200.00
0005435242810	5610	Economy	10200.00
0005435242837	5610	Economy	10200.00
0005432784169	5610	Economy	9300.00
0005432784188	5610	Economy	9300.00
0005432784178	5610	Economy	9300.00
0005435242830	5610	Economy	9300.00
0005432784203	5610	Economy	9300.00
0005432784200	5610	Economy	9300.00
0005432784165	5610	Economy	9300.00
0005432784198	5610	Economy	9300.00
0005435242774	5610	Economy	9300.00
0005432784170	5610	Economy	9300.00
0005432784202	5610	Economy	9300.00
0005435242717	5610	Economy	9300.00
0005432784164	5610	Economy	9300.00
0005432784186	5610	Economy	9300.00
0005432784205	5610	Economy	9300.00
0005435242815	5610	Economy	9300.00
0005435242877	5610	Economy	9300.00
0005432784189	5610	Economy	9300.00
0005432784190	5610	Economy	9300.00
0005432144011	5610	Economy	9300.00
0005435242829	5610	Economy	9300.00
0005435242871	5610	Economy	9300.00
0005435242851	5610	Economy	9300.00
0005432784177	5610	Economy	9300.00
0005435242759	5610	Economy	9300.00
0005435242540	5610	Economy	9300.00
0005432784185	5610	Economy	9300.00
0005435242763	5610	Economy	9300.00
0005432784172	5610	Economy	9300.00
0005435242845	5610	Economy	9300.00
0005435242637	5610	Economy	9300.00
0005432784211	5610	Economy	9300.00
0005435242695	5610	Economy	9300.00
0005435476732	5610	Economy	9300.00
0005432784175	5610	Economy	9300.00
0005432784197	5610	Economy	9300.00
0005435476717	5610	Economy	9300.00
0005432784208	5610	Economy	9300.00
0005432784162	5610	Economy	9300.00
0005432784168	5610	Economy	9300.00
0005435242811	5610	Economy	9300.00
0005432784161	5610	Economy	9300.00
0005432784179	5610	Economy	9300.00
0005435242838	5610	Economy	9300.00
0005432784194	5610	Economy	9300.00
0005432784209	5610	Economy	9300.00
0005432784199	5610	Economy	9300.00
0005432784192	5610	Economy	9300.00
0005432784160	5610	Economy	9300.00
0005432784171	5610	Economy	9300.00
0005435242825	5610	Economy	9300.00
0005435242875	5610	Economy	9300.00
0005435242801	5610	Economy	9300.00
0005435242696	5610	Economy	9300.00
0005432784180	5610	Economy	9300.00
0005432784173	5610	Economy	9300.00
0005432784195	5610	Economy	9300.00
0005435242775	5610	Economy	9300.00
0005435242846	5610	Economy	9300.00
0005432784181	5610	Economy	9300.00
0005432784184	5610	Economy	9300.00
0005435242872	5610	Economy	9300.00
0005432784193	5610	Economy	9300.00
0005432784183	5610	Economy	9300.00
0005432784204	5610	Economy	9300.00
0005432784215	5610	Economy	9300.00
0005432784163	5610	Economy	9300.00
0005435476721	5610	Economy	9300.00
0005435476808	15378	Business	27800.00
0005435476809	15378	Business	27800.00
0005432783532	15378	Business	27800.00
0005432783814	15378	Business	27800.00
0005432783604	15378	Business	27800.00
0005432783733	15378	Business	27800.00
0005432783802	15378	Business	27800.00
0005435243037	15378	Business	27800.00
0005435243036	15378	Business	27800.00
0005435476810	15378	Business	27800.00
0005432783648	15378	Business	27800.00
0005435476807	15378	Business	27800.00
0005435243021	15378	Economy	9300.00
0005432783354	15378	Economy	9300.00
0005432783558	15378	Economy	9300.00
0005432783670	15378	Economy	9300.00
0005432783554	15378	Economy	9300.00
0005435243045	15378	Economy	9300.00
0005432783674	15378	Economy	9300.00
0005432783856	15378	Economy	9300.00
0005435243042	15378	Economy	9300.00
0005435243041	15378	Economy	9300.00
0005435243027	15378	Economy	10200.00
0005435243039	15378	Economy	10200.00
0005432783544	15378	Economy	10200.00
0005435476806	15378	Economy	10200.00
0005435243029	15378	Economy	10200.00
0005435476812	15378	Economy	9300.00
0005435243019	15378	Economy	9300.00
0005435243032	15378	Economy	9300.00
0005432783649	15378	Economy	9300.00
0005435476805	15378	Economy	9300.00
0005432783816	15378	Economy	9300.00
0005432783462	15378	Economy	9300.00
0005432783777	15378	Economy	9300.00
0005435243034	15378	Economy	9300.00
0005435243033	15378	Economy	9300.00
0005432783709	15378	Economy	9300.00
0005435243022	15378	Economy	9300.00
0005432783767	15378	Economy	9300.00
0005435243040	15378	Economy	9300.00
0005432783615	15378	Economy	9300.00
0005432783736	15378	Economy	9300.00
0005432783796	15378	Economy	9300.00
0005432783539	15378	Economy	9300.00
0005432783832	15378	Economy	9300.00
0005432783522	15378	Economy	9300.00
0005432783759	15378	Economy	9300.00
0005432783650	15378	Economy	9300.00
0005432783619	15378	Economy	9300.00
0005432783614	15378	Economy	9300.00
0005432783610	15378	Economy	9300.00
0005432783738	15378	Economy	9300.00
0005432783601	15378	Economy	9300.00
0005432783611	15378	Economy	9300.00
0005432783666	15378	Economy	9300.00
0005432783766	15378	Economy	9300.00
0005435243020	15378	Economy	9300.00
0005435476804	15378	Economy	9300.00
0005435243028	15378	Economy	9300.00
0005435243044	15378	Economy	9300.00
0005432783593	15378	Economy	9300.00
0005435476811	15378	Economy	9300.00
0005432783665	15378	Economy	9300.00
0005432783907	15378	Economy	9300.00
0005432783771	15378	Economy	9300.00
0005435243024	15378	Economy	9300.00
0005432783605	15378	Economy	9300.00
0005432783451	15378	Economy	9300.00
0005435243043	15378	Economy	9300.00
0005432783760	15378	Economy	9300.00
0005432783697	15378	Economy	9300.00
0005432783606	15378	Economy	9300.00
0005435243035	15378	Economy	9300.00
0005435243025	15378	Economy	9300.00
0005432783677	15378	Economy	9300.00
0005432783600	15378	Economy	9300.00
0005435243031	15378	Economy	9300.00
0005432783908	15378	Economy	9300.00
0005432783602	15378	Economy	9300.00
0005432783452	15378	Economy	9300.00
0005435243038	15378	Economy	9300.00
0005432783710	15378	Economy	9300.00
0005432783698	15378	Economy	9300.00
0005432783790	15378	Economy	9300.00
0005432783815	15378	Economy	9300.00
0005435476803	15378	Economy	9300.00
0005432783737	15378	Economy	9300.00
0005432783720	15378	Economy	9300.00
0005432783523	15378	Economy	9300.00
0005432783594	15378	Economy	9300.00
0005435243026	15378	Economy	9300.00
0005432783878	15378	Economy	9300.00
0005435243023	15378	Economy	9300.00
0005432783747	15378	Economy	9300.00
0005435243030	15378	Economy	9300.00
0005435850922	4378	Economy	7000.00
0005432848421	4378	Economy	7000.00
0005432848424	4378	Economy	7000.00
0005435850898	4378	Economy	7000.00
0005432848417	4378	Economy	6300.00
0005434462806	4378	Economy	6300.00
0005435850897	4378	Economy	6300.00
0005432848412	4378	Economy	6300.00
0005435850934	4378	Economy	6300.00
0005432848423	4378	Economy	6300.00
0005434463945	4378	Economy	6300.00
0005432848419	4378	Economy	6300.00
0005432848425	4378	Economy	6300.00
0005434462808	4378	Economy	6300.00
0005432848416	4378	Economy	6300.00
0005434462805	4378	Economy	6300.00
0005432848414	4378	Economy	6300.00
0005435850939	4378	Economy	6300.00
0005435850923	4378	Economy	6300.00
0005435850906	4378	Economy	6300.00
0005432848422	4378	Economy	6300.00
0005432848415	4378	Economy	6300.00
0005432848413	4378	Economy	6300.00
0005435850957	4378	Economy	6300.00
0005435850900	4378	Economy	6300.00
0005434463944	4378	Economy	6300.00
0005432848418	4378	Economy	6300.00
0005435850958	4378	Economy	6300.00
0005435850956	4378	Economy	6300.00
0005432848411	4378	Economy	6300.00
0005435850899	4378	Economy	6300.00
0005434462807	4378	Economy	6300.00
0005432848420	4378	Economy	6300.00
0005435850975	28867	Economy	7000.00
0005432848260	28867	Economy	7000.00
0005432848218	28867	Economy	7000.00
0005435850976	28867	Economy	6300.00
0005432848289	28867	Economy	6300.00
0005432848239	28867	Economy	6300.00
0005435850978	28867	Economy	6300.00
0005435850973	28867	Economy	6300.00
0005434461639	28867	Economy	6300.00
0005435850981	28867	Economy	6300.00
0005435850979	28867	Economy	6300.00
0005432848278	28867	Economy	6300.00
0005435850977	28867	Economy	6300.00
0005432848290	28867	Economy	6300.00
0005432848302	28867	Economy	6300.00
0005432848261	28867	Economy	6300.00
0005432848331	28867	Economy	6300.00
0005432848283	28867	Economy	6300.00
0005435850974	28867	Economy	6300.00
0005435850980	28867	Economy	6300.00
0005432848332	28867	Economy	6300.00
0005432848240	28867	Economy	6300.00
0005432848279	28867	Economy	6300.00
0005433497217	6327	Business	11900.00
0005434443828	6327	Business	11900.00
0005433497200	6327	Business	11900.00
0005434443825	6327	Business	11900.00
0005434926053	6327	Business	11900.00
0005434443821	6327	Business	11900.00
0005433497191	6327	Business	11900.00
0005434443829	6327	Economy	4000.00
0005434926058	6327	Economy	4000.00
0005434926048	6327	Economy	4000.00
0005433497212	6327	Economy	4000.00
0005434926034	6327	Economy	4000.00
0005434443827	6327	Economy	4000.00
0005433497197	6327	Economy	4000.00
0005434443831	6327	Economy	4000.00
0005434443836	6327	Economy	4400.00
0005432075255	6327	Economy	4400.00
0005434926059	6327	Economy	4400.00
0005432075256	6327	Economy	4400.00
0005434926056	6327	Economy	4400.00
0005433497188	6327	Economy	4000.00
0005434926027	6327	Economy	4000.00
0005434443832	6327	Economy	4000.00
0005434926057	6327	Economy	4000.00
0005433497214	6327	Economy	4000.00
0005433497190	6327	Economy	4000.00
0005433497207	6327	Economy	4000.00
0005434926038	6327	Economy	4000.00
0005434926031	6327	Economy	4000.00
0005433497199	6327	Economy	4000.00
0005434926054	6327	Economy	4000.00
0005434926051	6327	Economy	4000.00
0005433497210	6327	Economy	4000.00
0005433497194	6327	Economy	4000.00
0005433497206	6327	Economy	4000.00
0005434926033	6327	Economy	4000.00
0005434926049	6327	Economy	4000.00
0005434443820	6327	Economy	4000.00
0005434443824	6327	Economy	4000.00
0005434926037	6327	Economy	4000.00
0005433497202	6327	Economy	4000.00
0005434443823	6327	Economy	4000.00
0005433497192	6327	Economy	4000.00
0005434926047	6327	Economy	4000.00
0005433497201	6327	Economy	4000.00
0005434926043	6327	Economy	4000.00
0005433497213	6327	Economy	4000.00
0005434443830	6327	Economy	4000.00
0005434443822	6327	Economy	4000.00
0005434443826	6327	Economy	4000.00
0005434443835	6327	Economy	4000.00
0005432075257	6327	Economy	4000.00
0005433497198	6327	Economy	4000.00
0005434926050	6327	Economy	4000.00
0005434926046	6327	Economy	4000.00
0005434926028	6327	Economy	4000.00
0005433497193	6327	Economy	4000.00
0005434926029	6327	Economy	4000.00
0005433497186	6327	Economy	4000.00
0005434926039	6327	Economy	4000.00
0005434926055	6327	Economy	4000.00
0005432075254	6327	Economy	4000.00
0005433497208	6327	Economy	4000.00
0005433497205	6327	Economy	4000.00
0005434926040	6327	Economy	4000.00
0005434926032	6327	Economy	4000.00
0005433497195	6327	Economy	4000.00
0005434926052	6327	Economy	4000.00
0005434926041	6327	Economy	4000.00
0005434926042	6327	Economy	4000.00
0005434926036	6327	Economy	4000.00
0005433497196	6327	Economy	4000.00
0005434926044	6327	Economy	4000.00
0005434443834	6327	Economy	4000.00
0005434926026	6327	Economy	4000.00
0005434926035	6327	Economy	4000.00
0005434926030	6327	Economy	4000.00
0005433497215	6327	Economy	4000.00
0005433497211	6327	Economy	4000.00
0005434926045	6327	Economy	4000.00
0005433497187	6327	Economy	4000.00
0005433497216	6327	Economy	4000.00
0005434443833	6327	Economy	4000.00
0005433497203	6327	Economy	4000.00
0005433497204	6327	Economy	4000.00
0005433497209	6327	Economy	4000.00
0005433497189	6327	Economy	4000.00
0005434925748	20386	Business	11900.00
0005433497039	20386	Business	11900.00
0005434925658	20386	Business	11900.00
0005433496939	20386	Business	11900.00
0005434443702	20386	Business	11900.00
0005434443687	20386	Business	11900.00
0005433496980	20386	Business	11900.00
0005433497059	20386	Business	11900.00
0005434443648	20386	Business	11900.00
0005434925749	20386	Business	11900.00
0005434925687	20386	Economy	4000.00
0005433496903	20386	Economy	4000.00
0005434443666	20386	Economy	4000.00
0005434925699	20386	Economy	4000.00
0005433497014	20386	Economy	4000.00
0005434925657	20386	Economy	4000.00
0005433496920	20386	Economy	4000.00
0005434925736	20386	Economy	4000.00
0005433496868	20386	Economy	4000.00
0005434925613	20386	Economy	4400.00
0005434925681	20386	Economy	4400.00
0005433497036	20386	Economy	4400.00
0005434443659	20386	Economy	4400.00
0005433496866	20386	Economy	4400.00
0005433497052	20386	Economy	4000.00
0005434925720	20386	Economy	4000.00
0005434925722	20386	Economy	4000.00
0005434925767	20386	Economy	4000.00
0005434925659	20386	Economy	4000.00
0005434925737	20386	Economy	4000.00
0005434925739	20386	Economy	4000.00
0005434925775	20386	Economy	4000.00
0005434925646	20386	Economy	4000.00
0005433496983	20386	Economy	4000.00
0005433496970	20386	Economy	4000.00
0005433496844	20386	Economy	4000.00
0005434443657	20386	Economy	4000.00
0005433497005	20386	Economy	4000.00
0005434443607	20386	Economy	4000.00
0005433496864	20386	Economy	4000.00
0005433497015	20386	Economy	4000.00
0005434925686	20386	Economy	4000.00
0005433497006	20386	Economy	4000.00
0005433496819	20386	Economy	4000.00
0005433497022	20386	Economy	4000.00
0005434443649	20386	Economy	4000.00
0005433496995	20386	Economy	4000.00
0005433496795	20386	Economy	4000.00
0005434925647	20386	Economy	4000.00
0005434925774	20386	Economy	4000.00
0005433496877	20386	Economy	4000.00
0005433497047	20386	Economy	4000.00
0005433496867	20386	Economy	4000.00
0005433496904	20386	Economy	4000.00
0005434925675	20386	Economy	4000.00
0005434925710	20386	Economy	4000.00
0005434443669	20386	Economy	4000.00
0005433496895	20386	Economy	4000.00
0005434925608	20386	Economy	4000.00
0005434925605	20386	Economy	4000.00
0005433496847	20386	Economy	4000.00
0005434925680	20386	Economy	4000.00
0005433497023	20386	Economy	4000.00
0005433496817	20386	Economy	4000.00
0005433496894	20386	Economy	4000.00
0005433496852	20386	Economy	4000.00
0005433496892	20386	Economy	4000.00
0005433497016	20386	Economy	4000.00
0005433497035	20386	Economy	4000.00
0005434925773	20386	Economy	4000.00
0005433497070	20386	Economy	4000.00
0005433497098	20386	Economy	4000.00
0005433497000	20386	Economy	4000.00
0005433496859	20386	Economy	4000.00
0005434925703	20386	Economy	4000.00
0005433496901	20386	Economy	4000.00
0005433496902	20386	Economy	4000.00
0005433496891	20386	Economy	4000.00
0005433496984	20386	Economy	4000.00
0005434443750	20386	Economy	4000.00
0005433496845	20386	Economy	4000.00
0005434443665	20386	Economy	4000.00
0005433497007	20386	Economy	4000.00
0005433497048	20386	Economy	4000.00
0005434925723	20386	Economy	4000.00
0005433496876	20386	Economy	4000.00
0005434925679	20386	Economy	4000.00
0005434443658	20386	Economy	4000.00
0005434925772	20386	Economy	4000.00
0005433497051	20386	Economy	4000.00
0005434925719	20386	Economy	4000.00
0005432783659	12181	Business	41200.00
0005432783587	12181	Business	41200.00
0005432783691	12181	Business	41200.00
0005432783429	12181	Business	41200.00
0005432783707	12181	Business	41200.00
0005432783877	12181	Business	41200.00
0005432783851	12181	Business	41200.00
0005432783662	12181	Business	41200.00
0005432783746	12181	Business	41200.00
0005432783447	12181	Business	41200.00
0005432783378	12181	Economy	13700.00
0005432783588	12181	Economy	13700.00
0005432783858	12181	Economy	13700.00
0005435243066	12181	Economy	13700.00
0005432783664	12181	Economy	13700.00
0005432783761	12181	Economy	13700.00
0005435243067	12181	Economy	13700.00
0005432783842	12181	Economy	13700.00
0005435243060	12181	Economy	13700.00
0005435243050	12181	Economy	15100.00
0005435243068	12181	Economy	15100.00
0005435243046	12181	Economy	15100.00
0005432783998	12181	Economy	15100.00
0005432783835	12181	Economy	15100.00
0005432783859	12181	Economy	13700.00
0005435243064	12181	Economy	13700.00
0005435243049	12181	Economy	13700.00
0005432783430	12181	Economy	13700.00
0005435243047	12181	Economy	13700.00
0005432783654	12181	Economy	13700.00
0005435243063	12181	Economy	13700.00
0005432783644	12181	Economy	13700.00
0005432783756	12181	Economy	13700.00
0005432783867	12181	Economy	13700.00
0005435243048	12181	Economy	13700.00
0005435243065	12181	Economy	13700.00
0005432783775	12181	Economy	13700.00
0005435243069	12181	Economy	13700.00
0005432783620	12181	Economy	13700.00
0005435243061	12181	Economy	13700.00
0005435243070	12181	Economy	13700.00
0005432783708	12181	Economy	13700.00
0005432783661	12181	Economy	13700.00
0005432783616	12181	Economy	13700.00
0005435243073	12181	Economy	13700.00
0005435243052	12181	Economy	13700.00
0005432783764	12181	Economy	13700.00
0005435243053	12181	Economy	13700.00
0005432783781	12181	Economy	13700.00
0005435243059	12181	Economy	13700.00
0005432783868	12181	Economy	13700.00
0005432783801	12181	Economy	13700.00
0005435243051	12181	Economy	13700.00
0005432783721	12181	Economy	13700.00
0005432783514	12181	Economy	13700.00
0005435243072	12181	Economy	13700.00
0005435243056	12181	Economy	13700.00
0005435243062	12181	Economy	13700.00
0005432783549	12181	Economy	13700.00
0005432783774	12181	Economy	13700.00
0005432783542	12181	Economy	13700.00
0005432783957	12181	Economy	13700.00
0005432783501	12181	Economy	13700.00
0005435243071	12181	Economy	13700.00
0005432783663	12181	Economy	13700.00
0005435243054	12181	Economy	13700.00
0005432783997	12181	Economy	13700.00
0005435243057	12181	Economy	13700.00
0005432783852	12181	Economy	13700.00
0005432783724	12181	Economy	13700.00
0005432783680	12181	Economy	13700.00
0005432783857	12181	Economy	13700.00
0005432783653	12181	Economy	13700.00
0005432783755	12181	Economy	13700.00
0005432783617	12181	Economy	13700.00
0005432783847	12181	Economy	13700.00
0005435243055	12181	Economy	13700.00
0005435243058	12181	Economy	13700.00
0005432783861	12181	Economy	13700.00
0005432783645	12181	Economy	13700.00
0005432783723	12181	Economy	13700.00
0005432783826	12181	Economy	13700.00
0005432783827	12181	Economy	13700.00
0005435242556	15433	Business	41200.00
0005432784141	15433	Business	41200.00
0005432784113	15433	Business	41200.00
0005432784127	15433	Business	41200.00
0005432784138	15433	Business	41200.00
0005435242783	15433	Business	41200.00
0005432784148	15433	Business	41200.00
0005432784123	15433	Business	41200.00
0005432784133	15433	Business	41200.00
0005432784111	15433	Business	41200.00
0005432784124	15433	Economy	13700.00
0005435242652	15433	Economy	13700.00
0005435242777	15433	Economy	13700.00
0005432784106	15433	Economy	13700.00
0005432784119	15433	Economy	13700.00
0005432784118	15433	Economy	13700.00
0005435242817	15433	Economy	13700.00
0005432784122	15433	Economy	13700.00
0005432784107	15433	Economy	13700.00
0005432784139	15433	Economy	15100.00
0005435242741	15433	Economy	15100.00
0005432784143	15433	Economy	15100.00
0005432784131	15433	Economy	15100.00
0005435242693	15433	Economy	15100.00
0005432784121	15433	Economy	13700.00
0005435242796	15433	Economy	13700.00
0005432784130	15433	Economy	13700.00
0005435242795	15433	Economy	13700.00
0005432784158	15433	Economy	13700.00
0005432784153	15433	Economy	13700.00
0005432784152	15433	Economy	13700.00
0005432784146	15433	Economy	13700.00
0005432784126	15433	Economy	13700.00
0005435242707	15433	Economy	13700.00
0005432784112	15433	Economy	13700.00
0005432784150	15433	Economy	13700.00
0005435242725	15433	Economy	13700.00
0005432784145	15433	Economy	13700.00
0005435242776	15433	Economy	13700.00
0005435242813	15433	Economy	13700.00
0005432784116	15433	Economy	13700.00
0005432784129	15433	Economy	13700.00
0005432784142	15433	Economy	13700.00
0005432784120	15433	Economy	13700.00
0005435242848	15433	Economy	13700.00
0005432784151	15433	Economy	13700.00
0005435242729	15433	Economy	13700.00
0005432784128	15433	Economy	13700.00
0005432784140	15433	Economy	13700.00
0005432784149	15433	Economy	13700.00
0005435242876	15433	Economy	13700.00
0005432784115	15433	Economy	13700.00
0005432784157	15433	Economy	13700.00
0005432784109	15433	Economy	13700.00
0005435242841	15433	Economy	13700.00
0005435242731	15433	Economy	13700.00
0005432784114	15433	Economy	13700.00
0005432784135	15433	Economy	13700.00
0005432784137	15433	Economy	13700.00
0005435242730	15433	Economy	13700.00
0005435242705	15433	Economy	13700.00
0005432784156	15433	Economy	13700.00
0005432784154	15433	Economy	13700.00
0005432784110	15433	Economy	13700.00
0005432784108	15433	Economy	13700.00
0005432784117	15433	Economy	13700.00
0005432784136	15433	Economy	13700.00
0005432784147	15433	Economy	13700.00
0005432784134	15433	Economy	13700.00
0005435242642	15433	Economy	13700.00
0005432784125	15433	Economy	13700.00
0005432784155	15433	Economy	13700.00
0005435242814	15433	Economy	13700.00
0005435242726	15433	Economy	13700.00
0005432784144	15433	Economy	13700.00
0005432784132	15433	Economy	13700.00
0005435242692	15433	Economy	13700.00
0005432784159	15433	Economy	13700.00
0005435242784	15433	Economy	13700.00
0005434877632	10096	Business	49700.00
0005434878408	10096	Business	49700.00
0005434878496	10096	Business	49700.00
0005434878162	10096	Business	49700.00
0005434877976	10096	Business	49700.00
0005434878636	10096	Business	49700.00
0005434878414	10096	Business	49700.00
0005434878149	10096	Business	49700.00
0005434877987	10096	Business	49700.00
0005434877842	10096	Business	49700.00
0005434877972	10096	Business	49700.00
0005434878567	10096	Business	49700.00
0005434878264	10096	Business	49700.00
0005434877919	10096	Business	49700.00
0005434877869	10096	Business	49700.00
0005434877579	10096	Business	49700.00
0005434878357	10096	Business	49700.00
0005434877884	10096	Business	49700.00
0005434878011	10096	Business	49700.00
0005434877942	10096	Business	49700.00
0005434878568	10096	Economy	16600.00
0005434878282	10096	Economy	16600.00
0005434877708	10096	Economy	16600.00
0005434877991	10096	Economy	16600.00
0005434878163	10096	Economy	16600.00
0005434878150	10096	Economy	16600.00
0005434878274	10096	Economy	16600.00
0005434877841	10096	Economy	16600.00
0005434878635	10096	Economy	16600.00
0005434878089	10096	Economy	16600.00
0005434878223	10096	Economy	16600.00
0005434878420	10096	Economy	16600.00
0005434758893	10096	Economy	16600.00
0005434878214	10096	Economy	18200.00
0005434877977	10096	Economy	18200.00
0005434877992	10096	Economy	18200.00
0005434878390	10096	Economy	18200.00
0005434878358	10096	Economy	16600.00
0005434878071	10096	Economy	16600.00
0005434878135	10096	Economy	16600.00
0005434878114	10096	Economy	16600.00
0005434878398	10096	Economy	16600.00
0005434910129	10096	Economy	16600.00
0005434878043	10096	Economy	16600.00
0005434878399	10096	Economy	16600.00
0005434910131	10096	Economy	16600.00
0005434878277	10096	Economy	16600.00
0005434878418	10096	Economy	16600.00
0005434878365	10096	Economy	16600.00
0005434758892	10096	Economy	16600.00
0005434878315	10096	Economy	16600.00
0005434878222	10096	Economy	16600.00
0005434878290	10096	Economy	16600.00
0005434877469	10096	Economy	16600.00
0005434878180	10096	Economy	16600.00
0005434877871	10096	Economy	16600.00
0005434877971	10096	Economy	16600.00
0005434877941	10096	Economy	16600.00
0005434878176	10096	Economy	16600.00
0005434878103	10096	Economy	16600.00
0005434878254	10096	Economy	16600.00
0005434878413	10096	Economy	16600.00
0005434878148	10096	Economy	16600.00
0005434878177	10096	Economy	16600.00
0005434877915	10096	Economy	16600.00
0005434878219	10096	Economy	16600.00
0005434877578	10096	Economy	16600.00
0005434878058	10096	Economy	16600.00
0005434877429	10096	Economy	16600.00
0005434878276	10096	Economy	16600.00
0005434877786	10096	Economy	16600.00
0005434878407	10096	Economy	16600.00
0005434878421	10096	Economy	16600.00
0005434877902	10096	Economy	16600.00
0005434878122	10096	Economy	16600.00
0005434878370	10096	Economy	16600.00
0005434878321	10096	Economy	16600.00
0005434877957	10096	Economy	16600.00
0005434878717	10096	Economy	16600.00
0005434878067	10096	Economy	16600.00
0005434877979	10096	Economy	16600.00
0005434910130	10096	Economy	16600.00
0005434878108	10096	Economy	16600.00
0005434878179	10096	Economy	16600.00
0005434877920	10096	Economy	16600.00
0005434878267	10096	Economy	16600.00
0005434877950	10096	Economy	16600.00
0005434877669	10096	Economy	16600.00
0005434877852	10096	Economy	16600.00
0005434878456	10096	Economy	16600.00
0005434878102	10096	Economy	16600.00
0005434878209	10096	Economy	16600.00
0005434878210	10096	Economy	16600.00
0005434877819	10096	Economy	16600.00
0005434877978	10096	Economy	16600.00
0005434878015	10096	Economy	16600.00
0005434758883	10096	Economy	16600.00
0005434878314	10096	Economy	16600.00
0005434878144	10096	Economy	16600.00
0005434878211	10096	Economy	16600.00
0005434877951	10096	Economy	16600.00
0005434877707	10096	Economy	16600.00
0005434758885	10096	Economy	16600.00
0005434878007	10096	Economy	16600.00
0005434878363	10096	Economy	16600.00
0005434758879	10096	Economy	16600.00
0005434878115	10096	Economy	16600.00
0005434877868	10096	Economy	16600.00
0005434877787	10096	Economy	16600.00
0005434877668	10096	Economy	16600.00
0005434878109	10096	Economy	16600.00
0005434878275	10096	Economy	16600.00
0005434878391	10096	Economy	16600.00
0005434878929	14649	Business	49700.00
0005434878913	14649	Business	49700.00
0005434878924	14649	Business	49700.00
0005434878920	14649	Business	49700.00
0005434878895	14649	Business	49700.00
0005434878863	14649	Business	49700.00
0005434878907	14649	Business	49700.00
0005434878898	14649	Business	49700.00
0005434758910	14649	Business	49700.00
0005434878891	14649	Business	49700.00
0005435913927	14649	Business	49700.00
0005434878947	14649	Business	49700.00
0005434878936	14649	Business	49700.00
0005434910108	14649	Business	49700.00
0005434878953	14649	Business	49700.00
0005434878923	14649	Business	49700.00
0005434878874	14649	Business	49700.00
0005434878922	14649	Business	49700.00
0005434878890	14649	Economy	16600.00
0005434878942	14649	Economy	16600.00
0005434878919	14649	Economy	16600.00
0005434878948	14649	Economy	16600.00
0005434878875	14649	Economy	16600.00
0005434878914	14649	Economy	16600.00
0005434878926	14649	Economy	16600.00
0005434878918	14649	Economy	16600.00
0005434878866	14649	Economy	16600.00
0005434878881	14649	Economy	16600.00
0005434878899	14649	Economy	18200.00
0005434878928	14649	Economy	18200.00
0005434878939	14649	Economy	18200.00
0005434878909	14649	Economy	18200.00
0005434878908	14649	Economy	16600.00
0005434878903	14649	Economy	16600.00
0005435913926	14649	Economy	16600.00
0005434878872	14649	Economy	16600.00
0005434878925	14649	Economy	16600.00
0005434878905	14649	Economy	16600.00
0005434878889	14649	Economy	16600.00
0005434878954	14649	Economy	16600.00
0005434878950	14649	Economy	16600.00
0005434878901	14649	Economy	16600.00
0005434878878	14649	Economy	16600.00
0005434878915	14649	Economy	16600.00
0005434878951	14649	Economy	16600.00
0005434910116	14649	Economy	16600.00
0005434878880	14649	Economy	16600.00
0005434878864	14649	Economy	16600.00
0005434878900	14649	Economy	16600.00
0005434878897	14649	Economy	16600.00
0005434878940	14649	Economy	16600.00
0005434878910	14649	Economy	16600.00
0005434878931	14649	Economy	16600.00
0005434878938	14649	Economy	16600.00
0005434758911	14649	Economy	16600.00
0005434878952	14649	Economy	16600.00
0005434878870	14649	Economy	16600.00
0005434878917	14649	Economy	16600.00
0005434878930	14649	Economy	16600.00
0005434878937	14649	Economy	16600.00
0005434878949	14649	Economy	16600.00
0005434878879	14649	Economy	16600.00
0005434878943	14649	Economy	16600.00
0005434878882	14649	Economy	16600.00
0005434878941	14649	Economy	16600.00
0005434878957	14649	Economy	16600.00
0005434878927	14649	Economy	16600.00
0005434878955	14649	Economy	16600.00
0005434878935	14649	Economy	16600.00
0005434878904	14649	Economy	16600.00
0005434878883	14649	Economy	16600.00
0005434878887	14649	Economy	16600.00
0005434878916	14649	Economy	16600.00
0005434878934	14649	Economy	16600.00
0005434878888	14649	Economy	16600.00
0005434878932	14649	Economy	16600.00
0005434878946	14649	Economy	16600.00
0005434878867	14649	Economy	16600.00
0005434878893	14649	Economy	16600.00
0005434878921	14649	Economy	16600.00
0005434878945	14649	Economy	16600.00
0005434878884	14649	Economy	16600.00
0005434878906	14649	Economy	16600.00
0005434878894	14649	Economy	16600.00
0005434878933	14649	Economy	16600.00
0005434878862	14649	Economy	16600.00
0005434878885	14649	Economy	16600.00
0005434878892	14649	Economy	16600.00
0005434878871	14649	Economy	16600.00
0005434878865	14649	Economy	16600.00
0005434878886	14649	Economy	16600.00
0005434878912	14649	Economy	16600.00
0005434878896	14649	Economy	16600.00
0005434878956	14649	Economy	16600.00
0005434878877	14649	Economy	16600.00
0005434878876	14649	Economy	16600.00
0005434878868	14649	Economy	16600.00
0005434878902	14649	Economy	16600.00
0005435913925	14649	Economy	16600.00
0005434878944	14649	Economy	16600.00
0005434878869	14649	Economy	16600.00
0005434758909	14649	Economy	16600.00
0005434878873	14649	Economy	16600.00
0005434878911	14649	Economy	16600.00
0005435660214	9235	Economy	22400.00
0005435660219	9235	Economy	22400.00
0005434251924	9235	Economy	20300.00
0005434251972	9235	Economy	20300.00
0005435660220	9235	Economy	20300.00
0005435660216	9235	Economy	20300.00
0005434251943	9235	Economy	20300.00
0005435660223	9235	Economy	20300.00
0005435660224	9235	Economy	20300.00
0005435660221	9235	Economy	20300.00
0005434251920	9235	Economy	20300.00
0005435660215	9235	Economy	20300.00
0005434251923	9235	Economy	20300.00
0005435660213	9235	Economy	20300.00
0005434251973	9235	Economy	20300.00
0005434251864	9235	Economy	20300.00
0005435660222	9235	Economy	20300.00
0005435660218	9235	Economy	20300.00
0005434251976	9235	Economy	20300.00
0005434251962	9235	Economy	20300.00
0005434251944	9235	Economy	20300.00
0005434251863	9235	Economy	20300.00
0005434251947	9235	Economy	20300.00
0005434251942	9235	Economy	20300.00
0005434251982	9235	Economy	20300.00
0005435660217	9235	Economy	20300.00
0005435660104	24653	Economy	22400.00
0005435660163	24653	Economy	20300.00
0005434252031	24653	Economy	20300.00
0005435660135	24653	Economy	20300.00
0005435660164	24653	Economy	20300.00
0005435660109	24653	Economy	20300.00
0005435660134	24653	Economy	20300.00
0005435660077	24653	Economy	20300.00
0005434252033	24653	Economy	20300.00
0005435660162	24653	Economy	20300.00
0005434252029	24653	Economy	20300.00
0005434252030	24653	Economy	20300.00
0005435660110	24653	Economy	20300.00
0005434252036	24653	Economy	20300.00
0005435660078	24653	Economy	20300.00
0005434252034	24653	Economy	20300.00
0005434252032	24653	Economy	20300.00
0005434252037	24653	Economy	20300.00
0005435660142	24653	Economy	20300.00
0005434252035	24653	Economy	20300.00
0005435660125	24653	Economy	20300.00
0005433680898	2765	Business	33000.00
0005432966940	2765	Business	33000.00
0005432966992	2765	Business	33000.00
0005433680906	2765	Business	33000.00
0005433680924	2765	Business	33000.00
0005433680908	2765	Business	33000.00
0005433680903	2765	Business	33000.00
0005433680918	2765	Business	33000.00
0005432966935	2765	Business	33000.00
0005433680884	2765	Business	33000.00
0005433684433	2765	Economy	11000.00
0005433680895	2765	Economy	11000.00
0005433680917	2765	Economy	11000.00
0005433680889	2765	Economy	11000.00
0005432222822	2765	Economy	11000.00
0005433680896	2765	Economy	11000.00
0005432967002	2765	Economy	11000.00
0005433680923	2765	Economy	11000.00
0005432966753	2765	Economy	11000.00
0005432966781	2765	Economy	12100.00
0005433680904	2765	Economy	12100.00
0005432966901	2765	Economy	12100.00
0005432966929	2765	Economy	12100.00
0005432966944	2765	Economy	12100.00
0005433680929	2765	Economy	11000.00
0005432966860	2765	Economy	11000.00
0005433680931	2765	Economy	11000.00
0005432222820	2765	Economy	11000.00
0005433684434	2765	Economy	11000.00
0005433680888	2765	Economy	11000.00
0005432966927	2765	Economy	11000.00
0005433680899	2765	Economy	11000.00
0005433680915	2765	Economy	11000.00
0005433680913	2765	Economy	11000.00
0005433680911	2765	Economy	11000.00
0005432966896	2765	Economy	11000.00
0005433680925	2765	Economy	11000.00
0005432966775	2765	Economy	11000.00
0005433680897	2765	Economy	11000.00
0005432222821	2765	Economy	11000.00
0005433680909	2765	Economy	11000.00
0005432222819	2765	Economy	11000.00
0005432966852	2765	Economy	11000.00
0005433680910	2765	Economy	11000.00
0005433680893	2765	Economy	11000.00
0005433680891	2765	Economy	11000.00
0005433680887	2765	Economy	11000.00
0005433680926	2765	Economy	11000.00
0005433680892	2765	Economy	11000.00
0005433680900	2765	Economy	11000.00
0005433680930	2765	Economy	11000.00
0005432966764	2765	Economy	11000.00
0005433680882	2765	Economy	11000.00
0005432967003	2765	Economy	11000.00
0005433680916	2765	Economy	11000.00
0005433680890	2765	Economy	11000.00
0005432966928	2765	Economy	11000.00
0005433680920	2765	Economy	11000.00
0005432222817	2765	Economy	11000.00
0005433680907	2765	Economy	11000.00
0005433680883	2765	Economy	11000.00
0005433680902	2765	Economy	11000.00
0005433680912	2765	Economy	11000.00
0005433680921	2765	Economy	11000.00
0005433680932	2765	Economy	11000.00
0005433680922	2765	Economy	11000.00
0005433680928	2765	Economy	11000.00
0005432967015	2765	Economy	11000.00
0005433680919	2765	Economy	11000.00
0005433680886	2765	Economy	11000.00
0005433680905	2765	Economy	11000.00
0005432966859	2765	Economy	11000.00
0005433680914	2765	Economy	11000.00
0005433680901	2765	Economy	11000.00
0005433680894	2765	Economy	11000.00
0005432222818	2765	Economy	11000.00
0005433680885	2765	Economy	11000.00
0005432966861	2765	Economy	11000.00
0005433680927	2765	Economy	11000.00
0005433680359	29148	Business	33000.00
0005433680677	29148	Business	33000.00
0005433680676	29148	Business	33000.00
0005433680400	29148	Business	33000.00
0005433680511	29148	Business	33000.00
0005433680465	29148	Business	33000.00
0005432005234	29148	Business	33000.00
0005433680468	29148	Business	33000.00
0005432967121	29148	Business	33000.00
0005433680566	29148	Business	33000.00
0005433680462	29148	Business	33000.00
0005433680534	29148	Economy	11000.00
0005433680656	29148	Economy	11000.00
0005432967116	29148	Economy	11000.00
0005433680407	29148	Economy	11000.00
0005433680315	29148	Economy	11000.00
0005433680535	29148	Economy	11000.00
0005433680598	29148	Economy	11000.00
0005433680507	29148	Economy	11000.00
0005432005233	29148	Economy	11000.00
0005433680569	29148	Economy	12100.00
0005433680657	29148	Economy	12100.00
0005433680565	29148	Economy	12100.00
0005432967115	29148	Economy	12100.00
0005433680585	29148	Economy	12100.00
0005433680525	29148	Economy	11000.00
0005432967114	29148	Economy	11000.00
0005432967113	29148	Economy	11000.00
0005432967130	29148	Economy	11000.00
0005433680608	29148	Economy	11000.00
0005433680361	29148	Economy	11000.00
0005432967108	29148	Economy	11000.00
0005433680488	29148	Economy	11000.00
0005432967118	29148	Economy	11000.00
0005433680621	29148	Economy	11000.00
0005433680403	29148	Economy	11000.00
0005433680551	29148	Economy	11000.00
0005433680771	29148	Economy	11000.00
0005433680711	29148	Economy	11000.00
0005433680467	29148	Economy	11000.00
0005433680696	29148	Economy	11000.00
0005433680695	29148	Economy	11000.00
0005433680518	29148	Economy	11000.00
0005432967124	29148	Economy	11000.00
0005433680575	29148	Economy	11000.00
0005433680574	29148	Economy	11000.00
0005432967107	29148	Economy	11000.00
0005433680521	29148	Economy	11000.00
0005432967117	29148	Economy	11000.00
0005432967119	29148	Economy	11000.00
0005432967128	29148	Economy	11000.00
0005433680316	29148	Economy	11000.00
0005432967112	29148	Economy	11000.00
0005433680549	29148	Economy	11000.00
0005433680570	29148	Economy	11000.00
0005432967127	29148	Economy	11000.00
0005432967122	29148	Economy	11000.00
0005433680770	29148	Economy	11000.00
0005433680550	29148	Economy	11000.00
0005433680589	29148	Economy	11000.00
0005432967111	29148	Economy	11000.00
0005433680620	29148	Economy	11000.00
0005433680675	29148	Economy	11000.00
0005433680401	29148	Economy	11000.00
0005432967132	29148	Economy	11000.00
0005432967131	29148	Economy	11000.00
0005433680443	29148	Economy	11000.00
0005433680732	29148	Economy	11000.00
0005433680708	29148	Economy	11000.00
0005433680453	29148	Economy	11000.00
0005433687697	29148	Economy	11000.00
0005432967129	29148	Economy	11000.00
0005433680613	29148	Economy	11000.00
0005432967110	29148	Economy	11000.00
0005433680625	29148	Economy	11000.00
0005433680452	29148	Economy	11000.00
0005433680783	29148	Economy	11000.00
0005433680707	29148	Economy	11000.00
0005433680586	29148	Economy	11000.00
0005433680489	29148	Economy	11000.00
0005432967123	29148	Economy	11000.00
0005433680712	29148	Economy	11000.00
0005433680297	29148	Economy	11000.00
0005433680622	29148	Economy	11000.00
0005433680548	29148	Economy	11000.00
0005432005232	29148	Economy	11000.00
0005433680599	29148	Economy	11000.00
0005432967125	29148	Economy	11000.00
0005432967109	29148	Economy	11000.00
0005432967126	29148	Economy	11000.00
0005432967120	29148	Economy	11000.00
0005433615120	9329	Business	132900.00
0005433615170	9329	Business	132900.00
0005433634030	9329	Business	132900.00
0005433615138	9329	Business	132900.00
0005433577896	9329	Business	132900.00
0005433615125	9329	Business	132900.00
0005433577899	9329	Business	132900.00
0005434269097	9329	Business	132900.00
0005434163571	9329	Business	132900.00
0005433615109	9329	Business	132900.00
0005433615124	9329	Business	132900.00
0005433634033	9329	Business	132900.00
0005433615121	9329	Business	132900.00
0005433634050	9329	Business	132900.00
0005433615175	9329	Business	132900.00
0005432755097	9329	Business	132900.00
0005433615172	9329	Business	132900.00
0005433634034	9329	Business	132900.00
0005433615166	9329	Business	132900.00
0005433634038	9329	Business	132900.00
0005433615113	9329	Business	132900.00
0005433615133	9329	Business	132900.00
0005434152781	9329	Economy	48700.00
0005433577906	9329	Economy	48700.00
0005434163551	9329	Economy	48700.00
0005433634026	9329	Economy	48700.00
0005433634049	9329	Economy	48700.00
0005433634041	9329	Economy	44300.00
0005433615157	9329	Economy	44300.00
0005434272188	9329	Economy	44300.00
0005434163608	9329	Economy	44300.00
0005433577900	9329	Economy	44300.00
0005433615127	9329	Economy	44300.00
0005433615126	9329	Economy	44300.00
0005433615180	9329	Economy	44300.00
0005433615128	9329	Economy	44300.00
0005433577907	9329	Economy	44300.00
0005433615130	9329	Economy	44300.00
0005433634028	9329	Economy	44300.00
0005433615134	9329	Economy	44300.00
0005434272192	9329	Economy	44300.00
0005433615110	9329	Economy	44300.00
0005433615151	9329	Economy	44300.00
0005433615119	9329	Economy	44300.00
0005433634039	9329	Economy	44300.00
0005433615173	9329	Economy	44300.00
0005433577898	9329	Economy	44300.00
0005433577905	9329	Economy	44300.00
0005434269088	9329	Economy	44300.00
0005433615163	9329	Economy	44300.00
0005433634029	9329	Economy	44300.00
0005433615115	9329	Economy	44300.00
0005433615162	9329	Economy	44300.00
0005433615108	9329	Economy	44300.00
0005433615156	9329	Economy	44300.00
0005433634045	9329	Economy	44300.00
0005433634018	9329	Economy	44300.00
0005433615136	9329	Economy	44300.00
0005433634046	9329	Economy	44300.00
0005433634031	9329	Economy	44300.00
0005434163601	9329	Economy	44300.00
0005433615176	9329	Economy	44300.00
0005433634036	9329	Economy	44300.00
0005433615178	9329	Economy	44300.00
0005433615149	9329	Economy	44300.00
0005433634017	9329	Economy	44300.00
0005434163580	9329	Economy	44300.00
0005433615155	9329	Economy	44300.00
0005433615150	9329	Economy	44300.00
0005433615174	9329	Economy	44300.00
0005433634043	9329	Economy	44300.00
0005433615167	9329	Economy	44300.00
0005433634025	9329	Economy	44300.00
0005433615154	9329	Economy	44300.00
0005433615148	9329	Economy	44300.00
0005434153530	9329	Economy	44300.00
0005433577903	9329	Economy	44300.00
0005433634022	9329	Economy	44300.00
0005433615171	9329	Economy	44300.00
0005433615177	9329	Economy	44300.00
0005433615144	9329	Economy	48700.00
0005433615123	9329	Economy	48700.00
0005433634024	9329	Economy	48700.00
0005433615182	9329	Economy	48700.00
0005433615141	9329	Economy	44300.00
0005432756871	9329	Economy	44300.00
0005433615117	9329	Economy	44300.00
0005433615114	9329	Economy	44300.00
0005434269099	9329	Economy	48700.00
0005433634019	9329	Economy	44300.00
0005433634040	9329	Economy	44300.00
0005433634037	9329	Economy	44300.00
0005433615153	9329	Economy	44300.00
0005433615122	9329	Economy	44300.00
0005433615112	9329	Economy	44300.00
0005433577904	9329	Economy	44300.00
0005433634044	9329	Economy	44300.00
0005432755098	9329	Economy	44300.00
0005433615160	9329	Economy	44300.00
0005433634027	9329	Economy	44300.00
0005433615143	9329	Economy	44300.00
0005433634047	9329	Economy	44300.00
0005434153535	9329	Economy	44300.00
0005433615158	9329	Economy	44300.00
0005433634035	9329	Economy	44300.00
0005433615165	9329	Economy	44300.00
0005433615145	9329	Economy	44300.00
0005433615137	9329	Economy	44300.00
0005433615140	9329	Economy	44300.00
0005433615135	9329	Economy	44300.00
0005433634021	9329	Economy	44300.00
0005433577908	9329	Economy	44300.00
0005433615131	9329	Economy	44300.00
0005433615111	9329	Economy	44300.00
0005433634020	9329	Economy	44300.00
0005432756872	9329	Economy	44300.00
0005434269098	9329	Economy	44300.00
0005433615168	9329	Economy	44300.00
0005434272187	9329	Economy	44300.00
0005433615129	9329	Economy	44300.00
0005433615159	9329	Economy	44300.00
0005433615146	9329	Economy	44300.00
0005433615147	9329	Economy	44300.00
0005433615179	9329	Economy	44300.00
0005432755099	9329	Economy	44300.00
0005433577901	9329	Economy	44300.00
0005433615139	9329	Economy	44300.00
0005433615164	9329	Economy	44300.00
0005433634016	9329	Economy	44300.00
0005432756870	9329	Economy	44300.00
0005433615161	9329	Economy	44300.00
0005433615181	9329	Economy	44300.00
0005433634048	9329	Economy	44300.00
0005432756869	9329	Economy	44300.00
0005433577909	9329	Economy	44300.00
0005433577897	9329	Economy	44300.00
0005433634042	9329	Economy	44300.00
0005433615169	9329	Economy	44300.00
0005433634032	9329	Economy	44300.00
0005432145124	9329	Economy	44300.00
0005433615118	9329	Economy	44300.00
0005433615116	9329	Economy	44300.00
0005433615132	9329	Economy	44300.00
0005433577902	9329	Economy	44300.00
0005432145123	9329	Economy	44300.00
0005433615142	9329	Economy	44300.00
0005433634023	9329	Economy	44300.00
0005433615152	9329	Economy	44300.00
0005433614334	25261	Business	132900.00
0005432755072	25261	Business	132900.00
0005433614408	25261	Business	132900.00
0005433614151	25261	Business	132900.00
0005433614371	25261	Business	132900.00
0005433614047	25261	Business	132900.00
0005433614753	25261	Business	132900.00
0005432755070	25261	Business	132900.00
0005433577827	25261	Business	132900.00
0005433614604	25261	Business	132900.00
0005433614409	25261	Business	132900.00
0005433614481	25261	Business	132900.00
0005433614826	25261	Business	132900.00
0005433614377	25261	Business	132900.00
0005432751505	25261	Business	132900.00
0005433614719	25261	Business	132900.00
0005433614482	25261	Business	132900.00
0005433633763	25261	Business	132900.00
0005432755069	25261	Business	132900.00
0005434163681	25261	Business	132900.00
0005433614705	25261	Business	132900.00
0005433614692	25261	Business	132900.00
0005433614290	25261	Business	132900.00
0005434163674	25261	Business	132900.00
0005433614575	25261	Business	132900.00
0005434152794	25261	Business	132900.00
0005433614164	25261	Economy	48700.00
0005433614581	25261	Business	132900.00
0005434163677	25261	Economy	48700.00
0005433633727	25261	Economy	48700.00
0005432751509	25261	Economy	48700.00
0005433614430	25261	Economy	48700.00
0005433614156	25261	Economy	48700.00
0005433633552	25261	Economy	44300.00
0005433633846	25261	Economy	44300.00
0005433614157	25261	Economy	44300.00
0005433633667	25261	Economy	44300.00
0005433614507	25261	Economy	44300.00
0005434272202	25261	Economy	44300.00
0005433614722	25261	Economy	44300.00
0005433614206	25261	Economy	44300.00
0005434152797	25261	Economy	44300.00
0005433614329	25261	Economy	44300.00
0005434163678	25261	Economy	44300.00
0005433633857	25261	Economy	44300.00
0005434152802	25261	Economy	44300.00
0005433614505	25261	Economy	44300.00
0005433614568	25261	Economy	44300.00
0005434152800	25261	Economy	44300.00
0005434163676	25261	Economy	44300.00
0005433614438	25261	Economy	44300.00
0005433614448	25261	Economy	44300.00
0005433633643	25261	Economy	44300.00
0005434152799	25261	Economy	44300.00
0005433633762	25261	Economy	44300.00
0005433614192	25261	Economy	44300.00
0005433577793	25261	Economy	44300.00
0005434152796	25261	Economy	44300.00
0005434152793	25261	Economy	44300.00
0005433614931	25261	Economy	44300.00
0005432751526	25261	Economy	44300.00
0005433614230	25261	Economy	44300.00
0005433633645	25261	Economy	44300.00
0005432751510	25261	Economy	44300.00
0005433633640	25261	Economy	44300.00
0005433633688	25261	Economy	44300.00
0005434152798	25261	Economy	44300.00
0005433614754	25261	Economy	44300.00
0005432755043	25261	Economy	44300.00
0005434163672	25261	Economy	44300.00
0005432755052	25261	Economy	44300.00
0005433614365	25261	Economy	44300.00
0005432751532	25261	Economy	44300.00
0005433614547	25261	Economy	44300.00
0005433614602	25261	Economy	44300.00
0005432751504	25261	Economy	44300.00
0005433614500	25261	Economy	44300.00
0005433633719	25261	Economy	44300.00
0005433614300	25261	Economy	44300.00
0005432751503	25261	Economy	44300.00
0005432755065	25261	Economy	44300.00
0005433614364	25261	Economy	44300.00
0005433614665	25261	Economy	44300.00
0005433614213	25261	Economy	44300.00
0005433614313	25261	Economy	44300.00
0005433614510	25261	Economy	44300.00
0005433614643	25261	Economy	44300.00
0005433633725	25261	Economy	48700.00
0005433633796	25261	Economy	48700.00
0005433633553	25261	Economy	48700.00
0005433614551	25261	Economy	48700.00
0005433633847	25261	Economy	48700.00
0005432755064	25261	Economy	44300.00
0005433614512	25261	Economy	44300.00
0005433633798	25261	Economy	44300.00
0005433633687	25261	Economy	44300.00
0005433614437	25261	Economy	48700.00
0005433614601	25261	Economy	44300.00
0005432751517	25261	Economy	44300.00
0005433614229	25261	Economy	44300.00
0005433633720	25261	Economy	44300.00
0005433614544	25261	Economy	44300.00
0005433614376	25261	Economy	44300.00
0005434163675	25261	Economy	44300.00
0005432751506	25261	Economy	44300.00
0005434163671	25261	Economy	44300.00
0005432755044	25261	Economy	44300.00
0005434273087	25261	Economy	44300.00
0005433633642	25261	Economy	44300.00
0005433633797	25261	Economy	44300.00
0005434152801	25261	Economy	44300.00
0005433614693	25261	Economy	44300.00
0005433614447	25261	Economy	44300.00
0005434163680	25261	Economy	44300.00
0005434152795	25261	Economy	44300.00
0005433633732	25261	Economy	44300.00
0005433614667	25261	Economy	44300.00
0005433614449	25261	Economy	44300.00
0005432755061	25261	Economy	44300.00
0005433614351	25261	Economy	44300.00
0005433633614	25261	Economy	44300.00
0005433633899	25261	Economy	44300.00
0005433633854	25261	Economy	44300.00
0005433614543	25261	Economy	44300.00
0005433633745	25261	Economy	44300.00
0005433633731	25261	Economy	44300.00
0005433614666	25261	Economy	44300.00
0005433577826	25261	Economy	44300.00
0005433614405	25261	Economy	44300.00
0005433633764	25261	Economy	44300.00
0005433614508	25261	Economy	44300.00
0005434163670	25261	Economy	44300.00
0005432751511	25261	Economy	44300.00
0005432755050	25261	Economy	44300.00
0005433633754	25261	Economy	44300.00
0005432755055	25261	Economy	44300.00
0005433614537	25261	Economy	44300.00
0005433614422	25261	Economy	44300.00
0005433633848	25261	Economy	44300.00
0005433614048	25261	Economy	44300.00
0005433614694	25261	Economy	44300.00
0005432755053	25261	Economy	44300.00
0005434163673	25261	Economy	44300.00
0005433577743	25261	Economy	44300.00
0005433633685	25261	Economy	44300.00
0005432751520	25261	Economy	44300.00
0005434163679	25261	Economy	44300.00
0005433614686	25261	Economy	44300.00
0005434272201	25261	Economy	44300.00
0005432755049	25261	Economy	44300.00
0005433633709	25261	Economy	44300.00
0005433614776	25261	Economy	44300.00
0005433633644	25261	Economy	44300.00
0005433633686	25261	Economy	44300.00
0005434273086	25261	Economy	44300.00
0005433614723	25261	Economy	44300.00
0005434272203	25261	Economy	44300.00
0005433633898	25261	Economy	44300.00
0005433614548	25261	Economy	44300.00
0005435947194	4230	Business	193100.00
0005432571309	4230	Business	193100.00
0005435854059	4230	Business	193100.00
0005435947251	4230	Business	193100.00
0005435947198	4230	Business	193100.00
0005432184973	4230	Economy	70800.00
0005435986803	4230	Economy	64400.00
0005432571315	4230	Economy	64400.00
0005435856198	4230	Economy	64400.00
0005432184972	4230	Economy	64400.00
0005432184975	4230	Economy	64400.00
0005435947308	4230	Economy	64400.00
0005435856187	4230	Economy	64400.00
0005432571329	4230	Economy	64400.00
0005432571322	4230	Economy	64400.00
0005435986804	4230	Economy	64400.00
0005432571323	4230	Economy	64400.00
0005435947199	4230	Economy	64400.00
0005435856181	4230	Economy	64400.00
0005435947239	4230	Economy	64400.00
0005435986802	4230	Economy	64400.00
0005432184971	4230	Economy	64400.00
0005435787350	4230	Economy	64400.00
0005432571330	4230	Economy	64400.00
0005432571312	4230	Economy	64400.00
0005435947235	4230	Economy	64400.00
0005432184970	4230	Economy	64400.00
0005435787343	4230	Economy	64400.00
0005435986801	4230	Economy	64400.00
0005432571324	4230	Economy	64400.00
0005435986805	4230	Economy	64400.00
0005432184974	4230	Economy	64400.00
0005432571314	4230	Economy	64400.00
0005435947262	4230	Economy	64400.00
0005432571313	4230	Economy	64400.00
0005435947367	26581	Business	193100.00
0005435947362	26581	Business	193100.00
0005435947364	26581	Business	193100.00
0005432571353	26581	Economy	64400.00
0005435856236	26581	Economy	64400.00
0005435947355	26581	Economy	64400.00
0005435947368	26581	Economy	64400.00
0005435986731	26581	Economy	64400.00
0005435947366	26581	Economy	64400.00
0005435947361	26581	Economy	64400.00
0005435947356	26581	Economy	64400.00
0005435986725	26581	Economy	64400.00
0005435856234	26581	Economy	64400.00
0005435947357	26581	Economy	64400.00
0005435947360	26581	Economy	64400.00
0005435947359	26581	Economy	70800.00
0005435947358	26581	Economy	64400.00
0005432571351	26581	Economy	64400.00
0005435986732	26581	Economy	64400.00
0005435947354	26581	Economy	64400.00
0005435856235	26581	Economy	64400.00
0005435947365	26581	Economy	64400.00
0005432571352	26581	Economy	64400.00
0005435947363	26581	Economy	64400.00
0005435787371	26581	Economy	64400.00
0005435856233	26581	Economy	64400.00
0005435986730	26581	Economy	64400.00
0005433074743	357	Business	21500.00
0005433569496	357	Business	21500.00
0005433134124	357	Business	21500.00
0005432948587	357	Business	21500.00
0005433074671	357	Business	21500.00
0005433074678	357	Business	21500.00
0005432948493	357	Business	21500.00
0005433569525	357	Business	21500.00
0005433569489	357	Business	21500.00
0005433569494	357	Business	21500.00
0005432948407	357	Business	21500.00
0005433569531	357	Business	21500.00
0005432948336	357	Business	21500.00
0005433569505	357	Business	21500.00
0005433569503	357	Business	21500.00
0005432238981	357	Business	21500.00
0005433074605	357	Business	21500.00
0005432948467	357	Business	21500.00
0005432948468	357	Business	21500.00
0005432948391	357	Business	21500.00
0005433569482	357	Business	21500.00
0005432948513	357	Business	21500.00
0005433074682	357	Business	21500.00
0005433074833	357	Business	21500.00
0005432948471	357	Economy	7900.00
0005433569477	357	Economy	7900.00
0005433074720	357	Economy	7900.00
0005433569514	357	Economy	7900.00
0005433569484	357	Economy	7900.00
0005432948711	357	Economy	7900.00
0005433569501	357	Economy	7200.00
0005433569491	357	Economy	7200.00
0005433569498	357	Economy	7200.00
0005432948286	357	Economy	7200.00
0005432948373	357	Economy	7200.00
0005433569509	357	Economy	7200.00
0005433569479	357	Economy	7200.00
0005433074616	357	Economy	7200.00
0005433569517	357	Economy	7200.00
0005433569493	357	Economy	7200.00
0005433569518	357	Economy	7200.00
0005433074633	357	Economy	7200.00
0005433569508	357	Economy	7200.00
0005433569510	357	Economy	7200.00
0005432948420	357	Economy	7200.00
0005432948425	357	Economy	7200.00
0005433129256	357	Economy	7200.00
0005433569515	357	Economy	7200.00
0005433074628	357	Economy	7200.00
0005433134147	357	Economy	7200.00
0005433569483	357	Economy	7200.00
0005433569535	357	Economy	7200.00
0005432948511	357	Economy	7200.00
0005433074611	357	Economy	7200.00
0005433569490	357	Economy	7200.00
0005433074607	357	Economy	7200.00
0005433569516	357	Economy	7200.00
0005433569522	357	Economy	7200.00
0005433569527	357	Economy	7200.00
0005432948523	357	Economy	7200.00
0005433569511	357	Economy	7200.00
0005433929858	357	Economy	7200.00
0005433569520	357	Economy	7200.00
0005432948378	357	Economy	7200.00
0005433569475	357	Economy	7200.00
0005433074666	357	Economy	7200.00
0005433569504	357	Economy	7200.00
0005433569532	357	Economy	7200.00
0005432948389	357	Economy	7200.00
0005433569523	357	Economy	7200.00
0005433074619	357	Economy	7200.00
0005433569521	357	Economy	7200.00
0005433569480	357	Economy	7200.00
0005433569499	357	Economy	7200.00
0005433569486	357	Economy	7200.00
0005433074741	357	Economy	7200.00
0005433074677	357	Economy	7200.00
0005433569495	357	Economy	7200.00
0005433569488	357	Economy	7200.00
0005433074641	357	Economy	7200.00
0005433129280	357	Economy	7200.00
0005433074731	357	Economy	7200.00
0005433129266	357	Economy	7200.00
0005433074742	357	Economy	7200.00
0005433569526	357	Economy	7900.00
0005433569533	357	Economy	7900.00
0005432948422	357	Economy	7900.00
0005433074732	357	Economy	7900.00
0005432948437	357	Economy	7900.00
0005433074719	357	Economy	7200.00
0005432948588	357	Economy	7200.00
0005433074630	357	Economy	7200.00
0005433569500	357	Economy	7900.00
0005433569487	357	Economy	7200.00
0005433134125	357	Economy	7200.00
0005433569536	357	Economy	7200.00
0005432948423	357	Economy	7200.00
0005433569529	357	Economy	7200.00
0005433569513	357	Economy	7200.00
0005433074832	357	Economy	7200.00
0005433569512	357	Economy	7200.00
0005433569497	357	Economy	7200.00
0005433074606	357	Economy	7200.00
0005433074629	357	Economy	7200.00
0005433569481	357	Economy	7200.00
0005432948473	357	Economy	7200.00
0005432948424	357	Economy	7200.00
0005432238982	357	Economy	7200.00
0005432948345	357	Economy	7200.00
0005432948306	357	Economy	7200.00
0005433074571	357	Economy	7200.00
0005433569528	357	Economy	7200.00
0005432948390	357	Economy	7200.00
0005433569474	357	Economy	7200.00
0005433569519	357	Economy	7200.00
0005433074631	357	Economy	7200.00
0005432948369	357	Economy	7200.00
0005433569537	357	Economy	7200.00
0005433569472	357	Economy	7200.00
0005432948482	357	Economy	7200.00
0005433074697	357	Economy	7200.00
0005433569502	357	Economy	7200.00
0005433569530	357	Economy	7200.00
0005432948397	357	Economy	7200.00
0005433569478	357	Economy	7200.00
0005432238983	357	Economy	7200.00
0005432948512	357	Economy	7200.00
0005433569506	357	Economy	7200.00
0005433569476	357	Economy	7200.00
0005433569507	357	Economy	7200.00
0005433569492	357	Economy	7200.00
0005432948508	357	Economy	7200.00
0005433569524	357	Economy	7200.00
0005432238980	357	Economy	7200.00
0005433074642	357	Economy	7200.00
0005433569534	357	Economy	7200.00
0005433569485	357	Economy	7200.00
0005432948415	357	Economy	7200.00
0005433569473	357	Economy	7200.00
0005432948426	357	Economy	7200.00
0005432948406	357	Economy	7200.00
0005432948461	357	Economy	7200.00
0005432948346	357	Economy	7200.00
0005432948268	357	Economy	7200.00
0005433568638	11572	Business	21500.00
0005432948728	11572	Business	21500.00
0005433568752	11572	Business	21500.00
0005433568843	11572	Business	21500.00
0005432948758	11572	Business	21500.00
0005433568644	11572	Business	21500.00
0005432948724	11572	Business	21500.00
0005433568906	11572	Business	21500.00
0005432948749	11572	Business	21500.00
0005432948726	11572	Business	21500.00
0005432948732	11572	Business	21500.00
0005432948738	11572	Business	21500.00
0005433568898	11572	Business	21500.00
0005433074914	11572	Business	21500.00
0005432192342	11572	Business	21500.00
0005433568578	11572	Business	21500.00
0005433074898	11572	Business	21500.00
0005432948764	11572	Business	21500.00
0005433568908	11572	Business	21500.00
0005433568835	11572	Business	21500.00
0005432948759	11572	Business	21500.00
0005433074902	11572	Business	21500.00
0005433074912	11572	Business	21500.00
0005433074901	11572	Business	21500.00
0005433568763	11572	Business	21500.00
0005432948733	11572	Business	21500.00
0005433568768	11572	Business	21500.00
0005433568751	11572	Economy	7900.00
0005433131741	11572	Economy	7900.00
0005433568813	11572	Economy	7900.00
0005433568765	11572	Economy	7900.00
0005433074907	11572	Economy	7900.00
0005433074916	11572	Economy	7200.00
0005433568911	11572	Economy	7200.00
0005433074913	11572	Economy	7200.00
0005432948737	11572	Economy	7200.00
0005432948765	11572	Economy	7200.00
0005433568582	11572	Economy	7200.00
0005433134171	11572	Economy	7200.00
0005432192343	11572	Economy	7200.00
0005432948763	11572	Economy	7200.00
0005433568834	11572	Economy	7200.00
0005433568825	11572	Economy	7200.00
0005433074921	11572	Economy	7200.00
0005433568863	11572	Economy	7200.00
0005433568844	11572	Economy	7200.00
0005433568889	11572	Economy	7200.00
0005432192341	11572	Economy	7200.00
0005433568819	11572	Economy	7200.00
0005433568853	11572	Economy	7200.00
0005432948739	11572	Economy	7200.00
0005433568842	11572	Economy	7200.00
0005432948753	11572	Economy	7200.00
0005433568807	11572	Economy	7200.00
0005433568852	11572	Economy	7200.00
0005433568903	11572	Economy	7200.00
0005433568864	11572	Economy	7200.00
0005433074904	11572	Economy	7200.00
0005432948750	11572	Economy	7200.00
0005433568845	11572	Economy	7200.00
0005432948761	11572	Economy	7200.00
0005432948735	11572	Economy	7200.00
0005432948748	11572	Economy	7200.00
0005432948756	11572	Economy	7200.00
0005432948762	11572	Economy	7200.00
0005433131740	11572	Economy	7200.00
0005433074924	11572	Economy	7200.00
0005432948745	11572	Economy	7200.00
0005432948729	11572	Economy	7200.00
0005433568921	11572	Economy	7200.00
0005433568851	11572	Economy	7200.00
0005433568680	11572	Economy	7200.00
0005433074909	11572	Economy	7200.00
0005433568904	11572	Economy	7200.00
0005432948751	11572	Economy	7200.00
0005433074923	11572	Economy	7200.00
0005433568930	11572	Economy	7200.00
0005433074910	11572	Economy	7200.00
0005433568822	11572	Economy	7200.00
0005433568894	11572	Economy	7200.00
0005433568790	11572	Economy	7200.00
0005433568933	11572	Economy	7200.00
0005433568764	11572	Economy	7200.00
0005433568750	11572	Economy	7200.00
0005433074917	11572	Economy	7200.00
0005432948725	11572	Economy	7200.00
0005433134170	11572	Economy	7900.00
0005432948731	11572	Economy	7900.00
0005433074922	11572	Economy	7900.00
0005432948752	11572	Economy	7900.00
0005432948736	11572	Economy	7900.00
0005433568799	11572	Economy	7200.00
0005432948760	11572	Economy	7200.00
0005432948744	11572	Economy	7200.00
0005433074899	11572	Economy	7200.00
0005432948740	11572	Economy	7900.00
0005433568653	11572	Economy	7200.00
0005433568907	11572	Economy	7200.00
0005433134169	11572	Economy	7200.00
0005433074903	11572	Economy	7200.00
0005433134172	11572	Economy	7200.00
0005433568832	11572	Economy	7200.00
0005432948743	11572	Economy	7200.00
0005432948734	11572	Economy	7200.00
0005432948727	11572	Economy	7200.00
0005432948757	11572	Economy	7200.00
0005433568865	11572	Economy	7200.00
0005433568770	11572	Economy	7200.00
0005433074908	11572	Economy	7200.00
0005433568899	11572	Economy	7200.00
0005433568820	11572	Economy	7200.00
0005433074905	11572	Economy	7200.00
0005433568905	11572	Economy	7200.00
0005433568941	11572	Economy	7200.00
0005432948747	11572	Economy	7200.00
0005433131739	11572	Economy	7200.00
0005433568767	11572	Economy	7200.00
0005433074918	11572	Economy	7200.00
0005433568814	11572	Economy	7200.00
0005433568824	11572	Economy	7200.00
0005433568896	11572	Economy	7200.00
0005432948723	11572	Economy	7200.00
0005433074915	11572	Economy	7200.00
0005433074906	11572	Economy	7200.00
0005433131742	11572	Economy	7200.00
0005432948746	11572	Economy	7200.00
0005433568514	11572	Economy	7200.00
0005432948742	11572	Economy	7200.00
0005433074919	11572	Economy	7200.00
0005433074897	11572	Economy	7200.00
0005433568753	11572	Economy	7200.00
0005432948754	11572	Economy	7200.00
0005433074900	11572	Economy	7200.00
0005433568771	11572	Economy	7200.00
0005433568939	11572	Economy	7200.00
0005433568772	11572	Economy	7200.00
0005433568846	11572	Economy	7200.00
0005433074920	11572	Economy	7200.00
0005433568515	11572	Economy	7200.00
0005432948741	11572	Economy	7200.00
0005433568831	11572	Economy	7200.00
0005433568900	11572	Economy	7200.00
0005433568743	11572	Economy	7200.00
0005432948730	11572	Economy	7200.00
0005433568893	11572	Economy	7200.00
0005433568801	11572	Economy	7200.00
0005433568940	11572	Economy	7200.00
0005433074911	11572	Economy	7200.00
0005432948755	11572	Economy	7200.00
0005433817501	10013	Economy	6300.00
0005433817496	10013	Economy	6300.00
0005433817500	10013	Economy	6300.00
0005433817499	10013	Economy	6300.00
0005433817497	10013	Economy	6300.00
0005433817498	10013	Economy	6300.00
0005434732981	10013	Economy	6300.00
0005434733005	13936	Economy	6300.00
0005434733006	13936	Economy	6300.00
0005433817471	13936	Economy	6300.00
0005433817472	13936	Economy	6300.00
0005433817457	13936	Economy	6300.00
0005434733007	13936	Economy	6300.00
0005433817456	13936	Economy	6300.00
0005435982644	2322	Business	184500.00
0005433754615	2322	Business	184500.00
0005433754637	2322	Business	184500.00
0005432984935	2322	Business	184500.00
0005433434648	2322	Business	184500.00
0005433766666	2322	Business	184500.00
0005433764695	2322	Business	184500.00
0005433754652	2322	Business	184500.00
0005433434642	2322	Business	184500.00
0005435982632	2322	Business	184500.00
0005432985017	2322	Business	184500.00
0005432984768	2322	Business	184500.00
0005432300304	2322	Business	184500.00
0005433764694	2322	Business	184500.00
0005433754635	2322	Business	184500.00
0005432985084	2322	Business	184500.00
0005433434509	2322	Business	184500.00
0005433754656	2322	Business	184500.00
0005432985115	2322	Business	184500.00
0005435982623	2322	Business	184500.00
0005432985042	2322	Business	184500.00
0005432655628	2322	Business	184500.00
0005435982653	2322	Business	184500.00
0005433754649	2322	Business	184500.00
0005432985127	2322	Business	184500.00
0005435982655	2322	Business	184500.00
0005432655619	2322	Business	184500.00
0005433754602	2322	Business	184500.00
0005433434633	2322	Economy	67700.00
0005433434727	2322	Economy	67700.00
0005433766669	2322	Economy	67700.00
0005434731153	2322	Economy	67700.00
0005433754644	2322	Economy	61500.00
0005433434643	2322	Economy	61500.00
0005435982637	2322	Economy	61500.00
0005435982648	2322	Economy	61500.00
0005432300307	2322	Economy	61500.00
0005435982624	2322	Economy	61500.00
0005433754603	2322	Economy	61500.00
0005435982622	2322	Economy	61500.00
0005433434581	2322	Economy	61500.00
0005435982625	2322	Economy	61500.00
0005432985026	2322	Economy	61500.00
0005435982652	2322	Economy	61500.00
0005433434688	2322	Economy	61500.00
0005432655631	2322	Economy	61500.00
0005432985062	2322	Economy	61500.00
0005435982630	2322	Economy	61500.00
0005433434634	2322	Economy	61500.00
0005433754640	2322	Economy	61500.00
0005433754628	2322	Economy	61500.00
0005433754642	2322	Economy	61500.00
0005432655621	2322	Economy	61500.00
0005435982658	2322	Economy	61500.00
0005433754646	2322	Economy	61500.00
0005433754629	2322	Economy	61500.00
0005432226104	2322	Economy	61500.00
0005433434585	2322	Economy	61500.00
0005432985022	2322	Economy	61500.00
0005433754607	2322	Economy	61500.00
0005433754654	2322	Economy	61500.00
0005433434651	2322	Economy	61500.00
0005433754651	2322	Economy	61500.00
0005432985040	2322	Economy	61500.00
0005432985001	2322	Economy	61500.00
0005433754647	2322	Economy	61500.00
0005435982626	2322	Economy	61500.00
0005432655624	2322	Economy	61500.00
0005433754659	2322	Economy	61500.00
0005432869509	2322	Economy	61500.00
0005433754653	2322	Economy	61500.00
0005432300305	2322	Economy	61500.00
0005433754610	2322	Economy	61500.00
0005433434652	2322	Economy	61500.00
0005435982631	2322	Economy	61500.00
0005433754638	2322	Economy	61500.00
0005435982621	2322	Economy	61500.00
0005435982635	2322	Economy	61500.00
0005432985015	2322	Economy	61500.00
0005432985047	2322	Economy	61500.00
0005433754622	2322	Economy	61500.00
0005432985106	2322	Economy	61500.00
0005435982659	2322	Economy	61500.00
0005433754657	2322	Economy	61500.00
0005433754617	2322	Economy	61500.00
0005432985085	2322	Economy	61500.00
0005435982654	2322	Economy	61500.00
0005435982642	2322	Economy	61500.00
0005435982633	2322	Economy	61500.00
0005432985027	2322	Economy	61500.00
0005432985000	2322	Economy	61500.00
0005433434635	2322	Economy	61500.00
0005433434653	2322	Economy	61500.00
0005435982649	2322	Economy	61500.00
0005432985087	2322	Economy	61500.00
0005433754612	2322	Economy	61500.00
0005432226103	2322	Economy	61500.00
0005433754604	2322	Economy	61500.00
0005432985225	2322	Economy	61500.00
0005433434647	2322	Economy	61500.00
0005433434555	2322	Economy	61500.00
0005433434735	2322	Economy	61500.00
0005433434654	2322	Economy	61500.00
0005433754645	2322	Economy	61500.00
0005432869521	2322	Economy	61500.00
0005432655629	2322	Economy	61500.00
0005432985056	2322	Economy	61500.00
0005433754633	2322	Economy	61500.00
0005433754623	2322	Economy	61500.00
0005433754648	2322	Economy	61500.00
0005432655627	2322	Economy	61500.00
0005433754624	2322	Economy	61500.00
0005432226099	2322	Economy	61500.00
0005433434649	2322	Economy	61500.00
0005432984899	2322	Economy	61500.00
0005432655630	2322	Economy	61500.00
0005433434632	2322	Economy	61500.00
0005433754630	2322	Economy	61500.00
0005432984917	2322	Economy	61500.00
0005432985094	2322	Economy	61500.00
0005432985072	2322	Economy	61500.00
0005432869508	2322	Economy	61500.00
0005433754621	2322	Economy	61500.00
0005433754643	2322	Economy	61500.00
0005432985068	2322	Economy	61500.00
0005432985073	2322	Economy	61500.00
0005433754616	2322	Economy	61500.00
0005435982660	2322	Economy	61500.00
0005435982662	2322	Economy	67700.00
0005433754634	2322	Economy	67700.00
0005432300306	2322	Economy	61500.00
0005433434737	2322	Economy	61500.00
0005435982634	2322	Economy	61500.00
0005432655620	2322	Economy	67700.00
0005433754605	2322	Economy	67700.00
0005433754625	2322	Economy	61500.00
0005435982636	2322	Economy	61500.00
0005435982656	2322	Economy	61500.00
0005435982620	2322	Economy	61500.00
0005435982645	2322	Economy	61500.00
0005432869522	2322	Economy	61500.00
0005433754611	2322	Economy	61500.00
0005435982661	2322	Economy	61500.00
0005435982640	2322	Economy	61500.00
0005432985013	2322	Economy	61500.00
0005433766668	2322	Economy	61500.00
0005435982647	2322	Economy	61500.00
0005432226100	2322	Economy	61500.00
0005432984767	2322	Economy	61500.00
0005433754613	2322	Economy	61500.00
0005432655623	2322	Economy	61500.00
0005432655622	2322	Economy	61500.00
0005432985023	2322	Economy	61500.00
0005435982650	2322	Economy	61500.00
0005432984766	2322	Economy	61500.00
0005432985083	2322	Economy	61500.00
0005435982628	2322	Economy	61500.00
0005433434673	2322	Economy	61500.00
0005435982664	2322	Economy	61500.00
0005435982638	2322	Economy	61500.00
0005433754655	2322	Economy	61500.00
0005433754618	2322	Economy	61500.00
0005432226101	2322	Economy	61500.00
0005433434697	2322	Economy	61500.00
0005435982646	2322	Economy	61500.00
0005433754631	2322	Economy	61500.00
0005433754641	2322	Economy	61500.00
0005435982641	2322	Economy	61500.00
0005433754606	2322	Economy	61500.00
0005433754636	2322	Economy	61500.00
0005433754614	2322	Economy	61500.00
0005433434698	2322	Economy	61500.00
0005435982663	2322	Economy	61500.00
0005433434510	2322	Economy	61500.00
0005432869531	2322	Economy	61500.00
0005433434650	2322	Economy	61500.00
0005433754627	2322	Economy	61500.00
0005432985093	2322	Economy	61500.00
0005435982657	2322	Economy	61500.00
0005435982627	2322	Economy	61500.00
0005432984971	2322	Economy	61500.00
0005433754639	2322	Economy	61500.00
0005434731157	2322	Economy	61500.00
0005432985014	2322	Economy	61500.00
0005433434582	2322	Economy	61500.00
0005433754632	2322	Economy	61500.00
0005433754620	2322	Economy	61500.00
0005433434740	2322	Economy	61500.00
0005432226102	2322	Economy	61500.00
0005435982651	2322	Economy	61500.00
0005435982643	2322	Economy	61500.00
0005432655626	2322	Economy	61500.00
0005432226105	2322	Economy	61500.00
0005432985021	2322	Economy	61500.00
0005432985118	2322	Economy	61500.00
0005433766667	2322	Economy	61500.00
0005433754619	2322	Economy	61500.00
0005432300308	2322	Economy	61500.00
0005432300303	2322	Economy	61500.00
0005433754650	2322	Economy	61500.00
0005433434657	2322	Economy	61500.00
0005433754608	2322	Economy	61500.00
0005432984998	2322	Economy	61500.00
0005433754658	2322	Economy	61500.00
0005433754626	2322	Economy	61500.00
0005433754609	2322	Economy	61500.00
0005435982629	2322	Economy	61500.00
0005433434699	2322	Economy	61500.00
0005435982639	2322	Economy	61500.00
0005432869507	2322	Economy	61500.00
0005432655625	2322	Economy	61500.00
0005435982236	26201	Business	184500.00
0005432985313	26201	Business	184500.00
0005435982254	26201	Business	184500.00
0005435982275	26201	Business	184500.00
0005433434873	26201	Business	184500.00
0005435982255	26201	Business	184500.00
0005432985302	26201	Business	184500.00
0005435982211	26201	Business	184500.00
0005433753927	26201	Business	184500.00
0005432655544	26201	Business	184500.00
0005434731200	26201	Business	184500.00
0005435981975	26201	Business	184500.00
0005435982362	26201	Business	184500.00
0005433754199	26201	Business	184500.00
0005433434894	26201	Business	184500.00
0005433434886	26201	Business	184500.00
0005432655545	26201	Business	184500.00
0005432985321	26201	Business	184500.00
0005432985314	26201	Business	184500.00
0005435982276	26201	Business	184500.00
0005432985296	26201	Business	184500.00
0005433754106	26201	Business	184500.00
0005433754202	26201	Business	184500.00
0005433754367	26201	Business	184500.00
0005433434895	26201	Business	184500.00
0005432985305	26201	Business	184500.00
0005433434890	26201	Business	184500.00
0005432655509	26201	Business	184500.00
0005432985310	26201	Business	184500.00
0005433754147	26201	Business	184500.00
0005435982307	26201	Economy	67700.00
0005433434887	26201	Economy	67700.00
0005433754049	26201	Economy	67700.00
0005433753979	26201	Economy	67700.00
0005432051152	26201	Economy	61500.00
0005433754293	26201	Economy	61500.00
0005432985303	26201	Economy	61500.00
0005433754203	26201	Economy	61500.00
0005432985297	26201	Economy	61500.00
0005435982071	26201	Economy	61500.00
0005432655491	26201	Economy	61500.00
0005433754478	26201	Economy	61500.00
0005432049490	26201	Economy	61500.00
0005435982173	26201	Economy	61500.00
0005433754151	26201	Economy	61500.00
0005433434880	26201	Economy	61500.00
0005433434897	26201	Economy	61500.00
0005432051150	26201	Economy	61500.00
0005432985315	26201	Economy	61500.00
0005433434889	26201	Economy	61500.00
0005433766635	26201	Economy	61500.00
0005433754298	26201	Economy	61500.00
0005433754146	26201	Economy	61500.00
0005432985298	26201	Economy	61500.00
0005432985308	26201	Economy	61500.00
0005433434896	26201	Economy	61500.00
0005432655482	26201	Economy	61500.00
0005435982056	26201	Economy	61500.00
0005435982190	26201	Economy	61500.00
0005432869569	26201	Economy	61500.00
0005435982168	26201	Economy	61500.00
0005433434879	26201	Economy	61500.00
0005432985318	26201	Economy	61500.00
0005433754470	26201	Economy	61500.00
0005432985311	26201	Economy	61500.00
0005433754126	26201	Economy	61500.00
0005433754082	26201	Economy	61500.00
0005433754224	26201	Economy	61500.00
0005433754128	26201	Economy	61500.00
0005435982217	26201	Economy	61500.00
0005432869572	26201	Economy	61500.00
0005434731203	26201	Economy	61500.00
0005433754191	26201	Economy	61500.00
0005435982208	26201	Economy	61500.00
0005434731202	26201	Economy	61500.00
0005432655485	26201	Economy	61500.00
0005433753967	26201	Economy	61500.00
0005433754103	26201	Economy	61500.00
0005432869570	26201	Economy	61500.00
0005432869568	26201	Economy	61500.00
0005435982046	26201	Economy	61500.00
0005432985306	26201	Economy	61500.00
0005435981981	26201	Economy	61500.00
0005432655487	26201	Economy	61500.00
0005435982212	26201	Economy	61500.00
0005432985319	26201	Economy	61500.00
0005435982256	26201	Economy	61500.00
0005435982096	26201	Economy	61500.00
0005432985322	26201	Economy	61500.00
0005433754051	26201	Economy	61500.00
0005433434881	26201	Economy	61500.00
0005435982129	26201	Economy	61500.00
0005432985327	26201	Economy	61500.00
0005432985307	26201	Economy	61500.00
0005435982372	26201	Economy	61500.00
0005433434877	26201	Economy	61500.00
0005435982110	26201	Economy	61500.00
0005433434885	26201	Economy	61500.00
0005432655486	26201	Economy	61500.00
0005435982284	26201	Economy	61500.00
0005433754328	26201	Economy	61500.00
0005435982213	26201	Economy	61500.00
0005432655467	26201	Economy	61500.00
0005433754176	26201	Economy	61500.00
0005433754070	26201	Economy	61500.00
0005433754222	26201	Economy	61500.00
0005433434872	26201	Economy	61500.00
0005433753999	26201	Economy	61500.00
0005433434874	26201	Economy	61500.00
0005433754105	26201	Economy	61500.00
0005433434883	26201	Economy	61500.00
0005432985304	26201	Economy	61500.00
0005432985326	26201	Economy	61500.00
0005433754056	26201	Economy	61500.00
0005435982240	26201	Economy	61500.00
0005432049491	26201	Economy	61500.00
0005433754335	26201	Economy	61500.00
0005432655490	26201	Economy	61500.00
0005435982333	26201	Economy	61500.00
0005433754123	26201	Economy	61500.00
0005432655500	26201	Economy	61500.00
0005432985328	26201	Economy	61500.00
0005435981916	26201	Economy	61500.00
0005433754046	26201	Economy	61500.00
0005433434871	26201	Economy	61500.00
0005433764680	26201	Economy	61500.00
0005433754122	26201	Economy	61500.00
0005435982170	26201	Economy	67700.00
0005435982268	26201	Economy	67700.00
0005432985299	26201	Economy	61500.00
0005435982246	26201	Economy	61500.00
0005433434882	26201	Economy	67700.00
0005433754050	26201	Economy	67700.00
0005435982218	26201	Economy	61500.00
0005433754294	26201	Economy	61500.00
0005432985301	26201	Economy	61500.00
0005432985323	26201	Economy	61500.00
0005435982146	26201	Economy	61500.00
0005433753971	26201	Economy	61500.00
0005432655501	26201	Economy	61500.00
0005435982309	26201	Economy	61500.00
0005432985320	26201	Economy	61500.00
0005435982283	26201	Economy	61500.00
0005433766638	26201	Economy	61500.00
0005435982253	26201	Economy	61500.00
0005435982147	26201	Economy	61500.00
0005432985316	26201	Economy	61500.00
0005433766642	26201	Economy	61500.00
0005432655502	26201	Economy	61500.00
0005433754107	26201	Economy	61500.00
0005432655483	26201	Economy	61500.00
0005432985300	26201	Economy	61500.00
0005433434892	26201	Economy	61500.00
0005433434888	26201	Economy	61500.00
0005433754173	26201	Economy	61500.00
0005433754071	26201	Economy	61500.00
0005433434891	26201	Economy	61500.00
0005435982267	26201	Economy	61500.00
0005432051151	26201	Economy	61500.00
0005432655514	26201	Economy	61500.00
0005433434876	26201	Economy	61500.00
0005435982363	26201	Economy	61500.00
0005433434884	26201	Economy	61500.00
0005433434893	26201	Economy	61500.00
0005433754042	26201	Economy	61500.00
0005432985317	26201	Economy	61500.00
0005433754052	26201	Economy	61500.00
0005433754378	26201	Economy	61500.00
0005435982174	26201	Economy	61500.00
0005433754177	26201	Economy	61500.00
0005432985309	26201	Economy	61500.00
0005432049489	26201	Economy	61500.00
0005435981974	26201	Economy	61500.00
0005433754190	26201	Economy	61500.00
0005433766617	26201	Economy	61500.00
0005432985325	26201	Economy	61500.00
0005432985324	26201	Economy	61500.00
0005433754334	26201	Economy	61500.00
0005432655510	26201	Economy	61500.00
0005433754477	26201	Economy	61500.00
0005432655532	26201	Economy	61500.00
0005432655507	26201	Economy	61500.00
0005433434898	26201	Economy	61500.00
0005432655503	26201	Economy	61500.00
0005432985312	26201	Economy	61500.00
0005435982191	26201	Economy	61500.00
0005434731201	26201	Economy	61500.00
0005435982047	26201	Economy	61500.00
0005432869571	26201	Economy	61500.00
0005433754083	26201	Economy	61500.00
0005432655533	26201	Economy	61500.00
0005433434875	26201	Economy	61500.00
0005435982221	26201	Economy	61500.00
0005433434878	26201	Economy	61500.00
0005435982169	26201	Economy	61500.00
0005435982207	26201	Economy	61500.00
0005433754299	26201	Economy	61500.00
0005435982261	26201	Economy	61500.00
0005435982070	26201	Economy	61500.00
0005433754057	26201	Economy	61500.00
0005433754248	26201	Economy	61500.00
0005433754259	26201	Economy	61500.00
0005433754368	26201	Economy	61500.00
0005435982167	26201	Economy	61500.00
0005433754240	26201	Economy	61500.00
0005432655508	26201	Economy	61500.00
0005432049488	26201	Economy	61500.00
0005433754186	26201	Economy	61500.00
0005434374999	1537	Business	38900.00
0005433151385	1537	Business	38900.00
0005434374971	1537	Business	38900.00
0005434374986	1537	Business	38900.00
0005434375006	1537	Business	38900.00
0005433151301	1537	Business	38900.00
0005434029654	1537	Business	38900.00
0005434374972	1537	Business	38900.00
0005433151464	1537	Economy	13000.00
0005434374991	1537	Economy	13000.00
0005434374968	1537	Economy	13000.00
0005433461603	1537	Economy	13000.00
0005434375010	1537	Economy	13000.00
0005434374954	1537	Economy	13000.00
0005434374959	1537	Economy	13000.00
0005434374974	1537	Economy	13000.00
0005434374960	1537	Economy	13000.00
0005432267947	1537	Economy	13000.00
0005433151197	1537	Economy	13000.00
0005434374965	1537	Economy	13000.00
0005434374955	1537	Economy	13000.00
0005433151366	1537	Economy	13000.00
0005434374985	1537	Economy	13000.00
0005433151544	1537	Economy	13000.00
0005434374966	1537	Economy	13000.00
0005433151397	1537	Economy	13000.00
0005434374951	1537	Economy	13000.00
0005434375009	1537	Economy	13000.00
0005434374978	1537	Economy	13000.00
0005434374982	1537	Economy	13000.00
0005434374996	1537	Economy	13000.00
0005434375000	1537	Economy	13000.00
0005433151522	1537	Economy	13000.00
0005434029646	1537	Economy	13000.00
0005434374987	1537	Economy	13000.00
0005434375005	1537	Economy	13000.00
0005434374995	1537	Economy	13000.00
0005433151399	1537	Economy	13000.00
0005433460452	1537	Economy	14300.00
0005433151431	1537	Economy	14300.00
0005433931459	1537	Economy	14300.00
0005433151362	1537	Economy	14300.00
0005434374975	1537	Economy	14300.00
0005434374981	1537	Economy	14300.00
0005433151261	1537	Economy	13000.00
0005434374963	1537	Economy	13000.00
0005434374964	1537	Economy	13000.00
0005433151288	1537	Economy	13000.00
0005434374970	1537	Economy	13000.00
0005432267941	1537	Economy	13000.00
0005434374961	1537	Economy	13000.00
0005434375008	1537	Economy	13000.00
0005433461604	1537	Economy	13000.00
0005434374984	1537	Economy	13000.00
0005434374993	1537	Economy	13000.00
0005433931458	1537	Economy	13000.00
0005433151315	1537	Economy	13000.00
0005434029651	1537	Economy	13000.00
0005434374957	1537	Economy	13000.00
0005434374967	1537	Economy	13000.00
0005434375011	1537	Economy	13000.00
0005433151398	1537	Economy	13000.00
0005432267944	1537	Economy	13000.00
0005433151430	1537	Economy	13000.00
0005434374998	1537	Economy	13000.00
0005434375004	1537	Economy	13000.00
0005432267945	1537	Economy	13000.00
0005434375007	1537	Economy	13000.00
0005432267943	1537	Economy	13000.00
0005433151411	1537	Economy	13000.00
0005434374989	1537	Economy	13000.00
0005434029653	1537	Economy	13000.00
0005434374979	1537	Economy	13000.00
0005434374988	1537	Economy	13000.00
0005433151376	1537	Economy	13000.00
0005434375002	1537	Economy	13000.00
0005433151439	1537	Economy	13000.00
0005434374992	1537	Economy	13000.00
0005432267942	1537	Economy	13000.00
0005432267946	1537	Economy	13000.00
0005434374976	1537	Economy	13000.00
0005434374956	1537	Economy	13000.00
0005434374953	1537	Economy	13000.00
0005433460451	1537	Economy	13000.00
0005434375001	1537	Economy	13000.00
0005434374973	1537	Economy	13000.00
0005433151262	1537	Economy	13000.00
0005433151294	1537	Economy	13000.00
0005434374983	1537	Economy	13000.00
0005433151349	1537	Economy	13000.00
0005433151432	1537	Economy	13000.00
0005434029652	1537	Economy	13000.00
0005434374952	1537	Economy	13000.00
0005434374994	1537	Economy	13000.00
0005433151440	1537	Economy	13000.00
0005434374962	1537	Economy	13000.00
0005434374997	1537	Economy	13000.00
0005433151252	1537	Economy	13000.00
0005434374977	1537	Economy	13000.00
0005434375003	1537	Economy	13000.00
0005434374980	1537	Economy	13000.00
0005434374969	1537	Economy	13000.00
0005433151545	1537	Economy	13000.00
0005434374958	1537	Economy	13000.00
0005434374990	1537	Economy	13000.00
0005433151372	1537	Economy	13000.00
0005433151652	20104	Business	38900.00
0005434374685	20104	Business	38900.00
0005433151653	20104	Business	38900.00
0005434374574	20104	Business	38900.00
0005433151654	20104	Business	38900.00
0005434374547	20104	Business	38900.00
0005434029674	20104	Business	38900.00
0005434374598	20104	Business	38900.00
0005433151655	20104	Business	38900.00
0005433151667	20104	Business	38900.00
0005434029675	20104	Economy	13000.00
0005434374575	20104	Economy	13000.00
0005434374647	20104	Economy	13000.00
0005433151642	20104	Economy	13000.00
0005434374619	20104	Economy	13000.00
0005433151645	20104	Economy	13000.00
0005433931486	20104	Economy	13000.00
0005434374516	20104	Economy	13000.00
0005433151658	20104	Economy	13000.00
0005433931487	20104	Economy	13000.00
0005433151639	20104	Economy	13000.00
0005434374763	20104	Economy	13000.00
0005434374623	20104	Economy	13000.00
0005433151648	20104	Economy	13000.00
0005433151661	20104	Economy	13000.00
0005434374743	20104	Economy	13000.00
0005434374754	20104	Economy	13000.00
0005433151663	20104	Economy	13000.00
0005434374438	20104	Economy	13000.00
0005434374641	20104	Economy	13000.00
0005434374485	20104	Economy	13000.00
0005434374569	20104	Economy	13000.00
0005434374638	20104	Economy	13000.00
0005434374671	20104	Economy	13000.00
0005434374537	20104	Economy	13000.00
0005434374712	20104	Economy	13000.00
0005433151647	20104	Economy	13000.00
0005434374618	20104	Economy	13000.00
0005434374639	20104	Economy	13000.00
0005434374620	20104	Economy	13000.00
0005434374585	20104	Economy	13000.00
0005433151671	20104	Economy	14300.00
0005433764694	20104	Economy	14300.00
0005432056325	20104	Economy	14300.00
0005433151662	20104	Economy	14300.00
0005434374445	20104	Economy	14300.00
0005434374626	20104	Economy	13000.00
0005434374753	20104	Economy	13000.00
0005434374680	20104	Economy	13000.00
0005432056328	20104	Economy	13000.00
0005433151649	20104	Economy	13000.00
0005433151657	20104	Economy	13000.00
0005434374605	20104	Economy	13000.00
0005433151672	20104	Economy	13000.00
0005433151644	20104	Economy	13000.00
0005434374568	20104	Economy	13000.00
0005433931485	20104	Economy	13000.00
0005434374713	20104	Economy	13000.00
0005433151646	20104	Economy	13000.00
0005432056326	20104	Economy	13000.00
0005434374687	20104	Economy	13000.00
0005434374588	20104	Economy	13000.00
0005433151668	20104	Economy	13000.00
0005433764695	20104	Economy	13000.00
0005433151669	20104	Economy	13000.00
0005433151656	20104	Economy	13000.00
0005434374471	20104	Economy	13000.00
0005434374546	20104	Economy	13000.00
0005433151638	20104	Economy	13000.00
0005434374535	20104	Economy	13000.00
0005433151641	20104	Economy	13000.00
0005433151640	20104	Economy	13000.00
0005433151665	20104	Economy	13000.00
0005434374622	20104	Economy	13000.00
0005433151670	20104	Economy	13000.00
0005434374470	20104	Economy	13000.00
0005433151664	20104	Economy	13000.00
0005434374645	20104	Economy	13000.00
0005433151643	20104	Economy	13000.00
0005433151666	20104	Economy	13000.00
0005434374646	20104	Economy	13000.00
0005434374621	20104	Economy	13000.00
0005434374331	20104	Economy	13000.00
0005433931488	20104	Economy	13000.00
0005433931489	20104	Economy	13000.00
0005433151651	20104	Economy	13000.00
0005433151659	20104	Economy	13000.00
0005434374656	20104	Economy	13000.00
0005434374536	20104	Economy	13000.00
0005434374595	20104	Economy	13000.00
0005434374642	20104	Economy	13000.00
0005432056327	20104	Economy	13000.00
0005433151650	20104	Economy	13000.00
0005434374366	20104	Economy	13000.00
0005433151660	20104	Economy	13000.00
0005434374782	20104	Economy	13000.00
0005434374637	20104	Economy	13000.00
0005432424800	525	Business	27500.00
0005432424791	525	Business	27500.00
0005432424801	525	Business	27500.00
0005432424812	525	Business	27500.00
0005432424779	525	Business	27500.00
0005432424798	525	Business	27500.00
0005432424782	525	Business	27500.00
0005432282915	525	Business	27500.00
0005432424777	525	Economy	10100.00
0005432424820	525	Economy	9200.00
0005432424786	525	Economy	9200.00
0005432424810	525	Economy	9200.00
0005432424811	525	Economy	9200.00
0005432424803	525	Economy	9200.00
0005432424783	525	Economy	9200.00
0005432424793	525	Economy	9200.00
0005432424807	525	Economy	9200.00
0005432424790	525	Economy	9200.00
0005432424813	525	Economy	9200.00
0005432424795	525	Economy	9200.00
0005432424792	525	Economy	9200.00
0005432424780	525	Economy	9200.00
0005432424814	525	Economy	9200.00
0005432424784	525	Economy	9200.00
0005432424789	525	Economy	9200.00
0005432424797	525	Economy	9200.00
0005432424776	525	Economy	9200.00
0005432282918	525	Economy	9200.00
0005432424778	525	Economy	9200.00
0005432282917	525	Economy	9200.00
0005432424806	525	Economy	9200.00
0005432424802	525	Economy	9200.00
0005432424804	525	Economy	9200.00
0005432424816	525	Economy	9200.00
0005432424819	525	Economy	9200.00
0005432282914	525	Economy	9200.00
0005432424799	525	Economy	9200.00
0005432282916	525	Economy	9200.00
0005432282919	525	Economy	9200.00
0005432424787	525	Economy	9200.00
0005432424796	525	Economy	9200.00
0005432424781	525	Economy	9200.00
0005432424821	525	Economy	9200.00
0005432424785	525	Economy	9200.00
0005432424788	525	Economy	9200.00
0005432424809	525	Economy	9200.00
0005432424805	525	Economy	9200.00
0005432424818	525	Economy	9200.00
0005432424817	525	Economy	9200.00
0005432424815	525	Economy	9200.00
0005432424808	525	Economy	9200.00
0005432424794	525	Economy	9200.00
0005432302357	12834	Business	27500.00
0005432302358	12834	Economy	9200.00
0005432302359	12834	Economy	9200.00
0005432302356	12834	Economy	9200.00
0005432424281	12842	Business	27500.00
0005432424082	12842	Business	27500.00
0005432424291	12842	Business	27500.00
0005432424360	12842	Business	27500.00
0005432424272	12842	Business	27500.00
0005432424330	12842	Business	27500.00
0005432424353	12842	Business	27500.00
0005432424327	12842	Economy	10100.00
0005432424240	12842	Economy	10100.00
0005432424233	12842	Economy	9200.00
0005432424334	12842	Economy	9200.00
0005432424354	12842	Economy	9200.00
0005432424247	12842	Economy	9200.00
0005432424151	12842	Economy	9200.00
0005432424350	12842	Economy	9200.00
0005432424382	12842	Economy	9200.00
0005432424368	12842	Economy	9200.00
0005432424234	12842	Economy	9200.00
0005432424226	12842	Economy	9200.00
0005432424339	12842	Economy	9200.00
0005432424384	12842	Economy	9200.00
0005432423947	12842	Economy	9200.00
0005432424243	12842	Economy	9200.00
0005432424367	12842	Economy	9200.00
0005432424343	12842	Economy	9200.00
0005432424150	12842	Economy	10100.00
0005432424227	12842	Economy	9200.00
0005432424297	12842	Economy	9200.00
0005432424383	12842	Economy	9200.00
0005432424355	12842	Economy	9200.00
0005432424284	12842	Economy	9200.00
0005432424381	12842	Economy	9200.00
0005432424352	12842	Economy	9200.00
0005432424369	12842	Economy	9200.00
0005432424252	12842	Economy	9200.00
0005432424333	12842	Economy	9200.00
0005432424371	12842	Economy	9200.00
0005432424083	12842	Economy	9200.00
0005432424370	12842	Economy	9200.00
0005432424268	12842	Economy	9200.00
0005432424326	12842	Economy	9200.00
0005432424351	12842	Economy	9200.00
0005433057984	429	Business	24500.00
0005434024169	429	Business	24500.00
0005432235692	429	Business	24500.00
0005434024225	429	Business	24500.00
0005434024172	429	Business	24500.00
0005432235696	429	Business	24500.00
0005434024226	429	Business	24500.00
0005434024186	429	Business	24500.00
0005433057891	429	Business	24500.00
0005434024185	429	Business	24500.00
0005433057992	429	Business	24500.00
0005434024231	429	Business	24500.00
0005433057979	429	Business	24500.00
0005432045627	429	Business	24500.00
0005432235690	429	Economy	9000.00
0005434024217	429	Economy	9000.00
0005433057845	429	Economy	9000.00
0005433057806	429	Economy	9000.00
0005434024198	429	Economy	8200.00
0005434024177	429	Economy	8200.00
0005434735682	429	Economy	8200.00
0005433057749	429	Economy	8200.00
0005434024194	429	Economy	8200.00
0005433058056	429	Economy	8200.00
0005434024232	429	Economy	8200.00
0005433057921	429	Economy	8200.00
0005434024233	429	Economy	8200.00
0005434024209	429	Economy	8200.00
0005432235694	429	Economy	8200.00
0005434024216	429	Economy	8200.00
0005434024180	429	Economy	8200.00
0005433057881	429	Economy	8200.00
0005434024208	429	Economy	8200.00
0005434032053	429	Economy	8200.00
0005434024173	429	Economy	8200.00
0005434029671	429	Economy	8200.00
0005434032055	429	Economy	8200.00
0005432045626	429	Economy	8200.00
0005434024167	429	Economy	8200.00
0005432235693	429	Economy	8200.00
0005433057961	429	Economy	8200.00
0005434024192	429	Economy	8200.00
0005433057892	429	Economy	8200.00
0005434024197	429	Economy	8200.00
0005434735681	429	Economy	8200.00
0005433057890	429	Economy	8200.00
0005433058057	429	Economy	8200.00
0005433057980	429	Economy	8200.00
0005433057962	429	Economy	8200.00
0005434029673	429	Economy	8200.00
0005434024210	429	Economy	8200.00
0005434024218	429	Economy	8200.00
0005434024178	429	Economy	8200.00
0005434028315	429	Economy	8200.00
0005433057908	429	Economy	8200.00
0005434024234	429	Economy	8200.00
0005434024188	429	Economy	8200.00
0005434024171	429	Economy	8200.00
0005434024176	429	Economy	8200.00
0005434024183	429	Economy	8200.00
0005434024199	429	Economy	8200.00
0005434024211	429	Economy	8200.00
0005434024201	429	Economy	8200.00
0005434024220	429	Economy	8200.00
0005434024207	429	Economy	8200.00
0005433057707	429	Economy	8200.00
0005433057898	429	Economy	8200.00
0005434024181	429	Economy	8200.00
0005434024230	429	Economy	8200.00
0005433057978	429	Economy	8200.00
0005434024195	429	Economy	8200.00
0005434024203	429	Economy	8200.00
0005433057922	429	Economy	8200.00
0005434032054	429	Economy	8200.00
0005434024223	429	Economy	8200.00
0005434024206	429	Economy	8200.00
0005433057991	429	Economy	8200.00
0005434024212	429	Economy	8200.00
0005434024190	429	Economy	8200.00
0005434024227	429	Economy	8200.00
0005433057990	429	Economy	8200.00
0005434024191	429	Economy	8200.00
0005432045625	429	Economy	9000.00
0005433057963	429	Economy	9000.00
0005433057844	429	Economy	8200.00
0005434029672	429	Economy	8200.00
0005433057899	429	Economy	9000.00
0005433057968	429	Economy	9000.00
0005433058068	429	Economy	8200.00
0005434024170	429	Economy	8200.00
0005433057810	429	Economy	8200.00
0005434024205	429	Economy	8200.00
0005434024179	429	Economy	8200.00
0005434028314	429	Economy	8200.00
0005434024184	429	Economy	8200.00
0005433057989	429	Economy	8200.00
0005434024168	429	Economy	8200.00
0005434024213	429	Economy	8200.00
0005434024224	429	Economy	8200.00
0005434024189	429	Economy	8200.00
0005434735694	429	Economy	8200.00
0005434024204	429	Economy	8200.00
0005434024222	429	Economy	8200.00
0005432235695	429	Economy	8200.00
0005434032052	429	Economy	8200.00
0005434024187	429	Economy	8200.00
0005433057706	429	Economy	8200.00
0005434735695	429	Economy	8200.00
0005433058013	429	Economy	8200.00
0005433057705	429	Economy	8200.00
0005434024182	429	Economy	8200.00
0005433057882	429	Economy	8200.00
0005434735696	429	Economy	8200.00
0005433057811	429	Economy	8200.00
0005434024200	429	Economy	8200.00
0005433058069	429	Economy	8200.00
0005433058070	429	Economy	8200.00
0005434024214	429	Economy	8200.00
0005434024228	429	Economy	8200.00
0005434024229	429	Economy	8200.00
0005432235689	429	Economy	8200.00
0005433057982	429	Economy	8200.00
0005434024175	429	Economy	8200.00
0005434024202	429	Economy	8200.00
0005433057750	429	Economy	8200.00
0005433057983	429	Economy	8200.00
0005434024221	429	Economy	8200.00
0005433057893	429	Economy	8200.00
0005433057981	429	Economy	8200.00
0005434024219	429	Economy	8200.00
0005434024166	429	Economy	8200.00
0005434024165	429	Economy	8200.00
0005433057807	429	Economy	8200.00
0005433058012	429	Economy	8200.00
0005434024196	429	Economy	8200.00
0005434024193	429	Economy	8200.00
0005434024174	429	Economy	8200.00
0005432235691	429	Economy	8200.00
0005434024215	429	Economy	8200.00
0005433057967	429	Economy	8200.00
0005434023841	12678	Business	24500.00
0005433058168	12678	Business	24500.00
0005433058182	12678	Business	24500.00
0005433058170	12678	Business	24500.00
0005434735725	12678	Business	24500.00
0005433058167	12678	Business	24500.00
0005434023662	12678	Business	24500.00
0005433058157	12678	Business	24500.00
0005434023291	12678	Business	24500.00
0005433058159	12678	Business	24500.00
0005434023851	12678	Business	24500.00
0005434023766	12678	Business	24500.00
0005434023853	12678	Business	24500.00
0005433058173	12678	Business	24500.00
0005434023694	12678	Business	24500.00
0005432156398	12678	Business	24500.00
0005433058169	12678	Business	24500.00
0005434023772	12678	Business	24500.00
0005434023543	12678	Business	24500.00
0005434023703	12678	Business	24500.00
0005433058165	12678	Economy	9000.00
0005433058179	12678	Economy	9000.00
0005434023852	12678	Economy	8200.00
0005434023882	12678	Economy	8200.00
0005433058194	12678	Economy	8200.00
0005433929643	12678	Economy	8200.00
0005434023759	12678	Economy	8200.00
0005433058154	12678	Economy	8200.00
0005434029653	12678	Economy	8200.00
0005434023747	12678	Economy	8200.00
0005434023720	12678	Economy	8200.00
0005433058156	12678	Economy	8200.00
0005434023765	12678	Economy	8200.00
0005434023693	12678	Economy	8200.00
0005434023606	12678	Economy	8200.00
0005433058162	12678	Economy	8200.00
0005434023576	12678	Economy	8200.00
0005434028284	12678	Economy	8200.00
0005433058177	12678	Economy	8200.00
0005433058175	12678	Economy	8200.00
0005433929644	12678	Economy	8200.00
0005434023445	12678	Economy	8200.00
0005434028291	12678	Economy	8200.00
0005434023804	12678	Economy	8200.00
0005434023575	12678	Economy	8200.00
0005434735729	12678	Economy	8200.00
0005434023760	12678	Economy	8200.00
0005433058187	12678	Economy	8200.00
0005434023657	12678	Economy	8200.00
0005433058190	12678	Economy	8200.00
0005434735728	12678	Economy	8200.00
0005434023744	12678	Economy	8200.00
0005434023805	12678	Economy	8200.00
0005432157505	12678	Economy	8200.00
0005434023414	12678	Economy	8200.00
0005433058186	12678	Economy	8200.00
0005434023653	12678	Economy	8200.00
0005433058172	12678	Economy	8200.00
0005433684436	12678	Economy	8200.00
0005434031974	12678	Economy	8200.00
0005434028293	12678	Economy	8200.00
0005434023815	12678	Economy	8200.00
0005434023559	12678	Economy	8200.00
0005434023651	12678	Economy	8200.00
0005434023432	12678	Economy	8200.00
0005434023292	12678	Economy	8200.00
0005434023661	12678	Economy	8200.00
0005433058166	12678	Economy	8200.00
0005434023644	12678	Economy	8200.00
0005433058181	12678	Economy	8200.00
0005433058189	12678	Economy	8200.00
0005434023497	12678	Economy	8200.00
0005434023524	12678	Economy	8200.00
0005434023560	12678	Economy	8200.00
0005434023756	12678	Economy	8200.00
0005434023881	12678	Economy	8200.00
0005433058188	12678	Economy	8200.00
0005433058180	12678	Economy	8200.00
0005433058178	12678	Economy	8200.00
0005434735726	12678	Economy	8200.00
0005434029651	12678	Economy	9000.00
0005434023656	12678	Economy	8200.00
0005434023872	12678	Economy	8200.00
0005434023660	12678	Economy	8200.00
0005433058164	12678	Economy	8200.00
0005432157506	12678	Economy	8200.00
0005434023467	12678	Economy	8200.00
0005434023757	12678	Economy	8200.00
0005434023558	12678	Economy	8200.00
0005433058171	12678	Economy	8200.00
0005433058174	12678	Economy	8200.00
0005433684437	12678	Economy	8200.00
0005433929645	12678	Economy	8200.00
0005434023652	12678	Economy	8200.00
0005434023735	12678	Economy	8200.00
0005433058176	12678	Economy	8200.00
0005434023453	12678	Economy	8200.00
0005434023565	12678	Economy	8200.00
0005433058155	12678	Economy	8200.00
0005434023746	12678	Economy	8200.00
0005434735730	12678	Economy	8200.00
0005434029646	12678	Economy	8200.00
0005433058163	12678	Economy	8200.00
0005433684435	12678	Economy	8200.00
0005433058158	12678	Economy	8200.00
0005432157507	12678	Economy	8200.00
0005433058184	12678	Economy	8200.00
0005434023823	12678	Economy	8200.00
0005433058183	12678	Economy	8200.00
0005433058191	12678	Economy	8200.00
0005434023732	12678	Economy	8200.00
0005434023755	12678	Economy	8200.00
0005434735727	12678	Economy	8200.00
0005434023386	12678	Economy	8200.00
0005434029654	12678	Economy	8200.00
0005434023377	12678	Economy	8200.00
0005434023842	12678	Economy	8200.00
0005433058161	12678	Economy	8200.00
0005433058160	12678	Economy	8200.00
0005433929642	12678	Economy	8200.00
0005434023692	12678	Economy	8200.00
0005434023616	12678	Economy	8200.00
0005434028282	12678	Economy	8200.00
0005434028292	12678	Economy	8200.00
0005433684438	12678	Economy	8200.00
0005434023719	12678	Economy	8200.00
0005432156399	12678	Economy	8200.00
0005434023617	12678	Economy	8200.00
0005434029652	12678	Economy	8200.00
0005434023531	12678	Economy	8200.00
0005434023712	12678	Economy	8200.00
0005433058193	12678	Economy	8200.00
0005434023645	12678	Economy	8200.00
0005434023822	12678	Economy	8200.00
0005434023784	12678	Economy	8200.00
0005433058185	12678	Economy	8200.00
0005433058192	12678	Economy	8200.00
0005433529296	13813	Business	111600.00
0005433527288	13813	Business	111600.00
0005433527284	13813	Business	111600.00
0005433527286	13813	Business	111600.00
0005433529297	13813	Business	111600.00
0005433529298	13813	Economy	37200.00
0005433529301	13813	Economy	37200.00
0005433527289	13813	Economy	37200.00
0005433527282	13813	Economy	40900.00
0005433527292	13813	Economy	37200.00
0005433529292	13813	Economy	37200.00
0005433529299	13813	Economy	37200.00
0005433529294	13813	Economy	37200.00
0005433529300	13813	Economy	37200.00
0005433529302	13813	Economy	37200.00
0005433527290	13813	Economy	37200.00
0005433529303	13813	Economy	37200.00
0005433529295	13813	Economy	37200.00
0005433527285	13813	Economy	37200.00
0005433529293	13813	Economy	37200.00
0005433527287	13813	Economy	37200.00
0005433527283	13813	Economy	37200.00
0005433527291	13813	Economy	37200.00
0005433533296	32447	Business	111600.00
0005433533285	32447	Business	111600.00
0005433529274	32447	Business	111600.00
0005433533291	32447	Business	111600.00
0005433533287	32447	Business	111600.00
0005433529265	32447	Economy	37200.00
0005433533292	32447	Economy	40900.00
0005433529266	32447	Economy	37200.00
0005433533293	32447	Economy	37200.00
0005433529267	32447	Economy	37200.00
0005433529258	32447	Economy	37200.00
0005433529269	32447	Economy	37200.00
0005433533298	32447	Economy	37200.00
0005433529249	32447	Economy	37200.00
0005433533307	32447	Economy	37200.00
0005433529273	32447	Economy	37200.00
0005433533299	32447	Economy	37200.00
0005433533286	32447	Economy	37200.00
0005433533297	32447	Economy	37200.00
0005433529259	32447	Economy	37200.00
0005433533308	32447	Economy	37200.00
0005433529257	32447	Economy	37200.00
0005433529268	32447	Economy	37200.00
0005433924018	2154	Business	34700.00
0005433929644	2154	Business	34700.00
0005433923962	2154	Business	34700.00
0005433036313	2154	Business	34700.00
0005433924037	2154	Business	34700.00
0005433036243	2154	Business	34700.00
0005433036415	2154	Business	34700.00
0005432231641	2154	Business	34700.00
0005434028292	2154	Business	34700.00
0005433923952	2154	Business	34700.00
0005433924002	2154	Business	34700.00
0005433923982	2154	Business	34700.00
0005433036254	2154	Business	34700.00
0005433924023	2154	Business	34700.00
0005433924041	2154	Business	34700.00
0005432044543	2154	Business	34700.00
0005433036282	2154	Business	34700.00
0005433875391	2154	Business	34700.00
0005433931485	2154	Business	34700.00
0005433924001	2154	Business	34700.00
0005433923960	2154	Business	34700.00
0005433924000	2154	Business	34700.00
0005433036388	2154	Business	34700.00
0005432231645	2154	Business	34700.00
0005433036190	2154	Business	34700.00
0005433036034	2154	Business	34700.00
0005433924034	2154	Economy	12700.00
0005433923971	2154	Economy	12700.00
0005433923979	2154	Economy	12700.00
0005433929645	2154	Economy	11600.00
0005433036237	2154	Economy	11600.00
0005434028293	2154	Economy	11600.00
0005433923987	2154	Economy	11600.00
0005433924025	2154	Economy	11600.00
0005433924008	2154	Economy	11600.00
0005433924026	2154	Economy	11600.00
0005433923964	2154	Economy	11600.00
0005433036253	2154	Economy	11600.00
0005432044546	2154	Economy	11600.00
0005433036136	2154	Economy	11600.00
0005432231640	2154	Economy	11600.00
0005433924007	2154	Economy	11600.00
0005433923994	2154	Economy	11600.00
0005433923950	2154	Economy	11600.00
0005433036116	2154	Economy	11600.00
0005433931487	2154	Economy	11600.00
0005434028282	2154	Economy	11600.00
0005433931489	2154	Economy	11600.00
0005433923958	2154	Economy	11600.00
0005433923974	2154	Economy	11600.00
0005433923972	2154	Economy	11600.00
0005432044544	2154	Economy	11600.00
0005434028291	2154	Economy	11600.00
0005433036248	2154	Economy	11600.00
0005433923946	2154	Economy	11600.00
0005433036315	2154	Economy	11600.00
0005433923951	2154	Economy	11600.00
0005433923983	2154	Economy	11600.00
0005433923995	2154	Economy	11600.00
0005433929642	2154	Economy	11600.00
0005433923967	2154	Economy	11600.00
0005433036238	2154	Economy	11600.00
0005433931486	2154	Economy	11600.00
0005433923959	2154	Economy	11600.00
0005433036338	2154	Economy	11600.00
0005433036451	2154	Economy	11600.00
0005433923948	2154	Economy	11600.00
0005433923975	2154	Economy	11600.00
0005434028284	2154	Economy	11600.00
0005433924011	2154	Economy	11600.00
0005433036312	2154	Economy	11600.00
0005433924012	2154	Economy	11600.00
0005433036343	2154	Economy	11600.00
0005433923989	2154	Economy	11600.00
0005433036314	2154	Economy	11600.00
0005433924020	2154	Economy	11600.00
0005433036231	2154	Economy	11600.00
0005433924013	2154	Economy	11600.00
0005433923986	2154	Economy	11600.00
0005433923957	2154	Economy	11600.00
0005433036033	2154	Economy	11600.00
0005433923996	2154	Economy	11600.00
0005433036380	2154	Economy	11600.00
0005433924021	2154	Economy	11600.00
0005433036174	2154	Economy	11600.00
0005433923984	2154	Economy	11600.00
0005433924006	2154	Economy	11600.00
0005433923990	2154	Economy	11600.00
0005432231644	2154	Economy	11600.00
0005433036232	2154	Economy	11600.00
0005433036389	2154	Economy	11600.00
0005433036335	2154	Economy	11600.00
0005433036117	2154	Economy	11600.00
0005432231639	2154	Economy	11600.00
0005433036344	2154	Economy	11600.00
0005433923956	2154	Economy	11600.00
0005433036189	2154	Economy	11600.00
0005433923970	2154	Economy	11600.00
0005433036402	2154	Economy	11600.00
0005433923954	2154	Economy	11600.00
0005433875392	2154	Economy	11600.00
0005433923981	2154	Economy	11600.00
0005433036360	2154	Economy	11600.00
0005433924033	2154	Economy	11600.00
0005433924036	2154	Economy	11600.00
0005433036005	2154	Economy	11600.00
0005433924005	2154	Economy	11600.00
0005433923968	2154	Economy	11600.00
0005433931488	2154	Economy	11600.00
0005433923943	2154	Economy	11600.00
0005433923965	2154	Economy	11600.00
0005433923991	2154	Economy	12700.00
0005433923998	2154	Economy	11600.00
0005433923988	2154	Economy	11600.00
0005433923955	2154	Economy	12700.00
0005433923977	2154	Economy	12700.00
0005433036135	2154	Economy	11600.00
0005432231638	2154	Economy	11600.00
0005432231636	2154	Economy	11600.00
0005433036063	2154	Economy	11600.00
0005433923985	2154	Economy	11600.00
0005433036004	2154	Economy	11600.00
0005433924003	2154	Economy	11600.00
0005433923999	2154	Economy	11600.00
0005432231637	2154	Economy	11600.00
0005433924022	2154	Economy	11600.00
0005433923953	2154	Economy	11600.00
0005433923973	2154	Economy	11600.00
0005433036283	2154	Economy	11600.00
0005433924040	2154	Economy	11600.00
0005433924004	2154	Economy	11600.00
0005433923978	2154	Economy	11600.00
0005433036359	2154	Economy	11600.00
0005433924032	2154	Economy	11600.00
0005433923997	2154	Economy	11600.00
0005433924029	2154	Economy	11600.00
0005432231643	2154	Economy	11600.00
0005433923963	2154	Economy	11600.00
0005433036428	2154	Economy	11600.00
0005433923961	2154	Economy	11600.00
0005433924030	2154	Economy	11600.00
0005433924031	2154	Economy	11600.00
0005433923969	2154	Economy	11600.00
0005433923992	2154	Economy	11600.00
0005433036241	2154	Economy	11600.00
0005433929643	2154	Economy	11600.00
0005433036403	2154	Economy	11600.00
0005433923976	2154	Economy	11600.00
0005433924028	2154	Economy	11600.00
0005433924010	2154	Economy	11600.00
0005432231646	2154	Economy	11600.00
0005433924015	2154	Economy	11600.00
0005433036352	2154	Economy	11600.00
0005433924014	2154	Economy	11600.00
0005433036351	2154	Economy	11600.00
0005433924016	2154	Economy	11600.00
0005433923949	2154	Economy	11600.00
0005432044545	2154	Economy	11600.00
0005433924009	2154	Economy	11600.00
0005433924035	2154	Economy	11600.00
0005433036420	2154	Economy	11600.00
0005433924038	2154	Economy	11600.00
0005433036134	2154	Economy	11600.00
0005432231642	2154	Economy	11600.00
0005433923944	2154	Economy	11600.00
0005433036066	2154	Economy	11600.00
0005433036188	2154	Economy	11600.00
0005433036280	2154	Economy	11600.00
0005433924027	2154	Economy	11600.00
0005433036304	2154	Economy	11600.00
0005433923980	2154	Economy	11600.00
0005433036507	2154	Economy	11600.00
0005433036279	2154	Economy	11600.00
0005433036182	2154	Economy	11600.00
0005433923966	2154	Economy	11600.00
0005433036187	2154	Economy	11600.00
0005433924039	2154	Economy	11600.00
0005433924017	2154	Economy	11600.00
0005433923945	2154	Economy	11600.00
0005433924024	2154	Economy	11600.00
0005433036204	2154	Economy	11600.00
0005433923947	2154	Economy	11600.00
0005433924019	2154	Economy	11600.00
0005433923993	2154	Economy	11600.00
0005433036222	2154	Economy	11600.00
0005433036681	24110	Business	34700.00
0005433036706	24110	Business	34700.00
0005433036656	24110	Business	34700.00
0005433923196	24110	Business	34700.00
0005433923490	24110	Business	34700.00
0005433036680	24110	Business	34700.00
0005433036690	24110	Business	34700.00
0005433923238	24110	Business	34700.00
0005433922962	24110	Business	34700.00
0005433922802	24110	Business	34700.00
0005433036688	24110	Business	34700.00
0005433036698	24110	Business	34700.00
0005433923308	24110	Business	34700.00
0005433036675	24110	Business	34700.00
0005433036705	24110	Business	34700.00
0005433922963	24110	Business	34700.00
0005433923557	24110	Business	34700.00
0005433923199	24110	Business	34700.00
0005433923288	24110	Business	34700.00
0005432206239	24110	Business	34700.00
0005433923450	24110	Business	34700.00
0005433922456	24110	Business	34700.00
0005432207681	24110	Economy	12700.00
0005432207679	24110	Business	34700.00
0005433036694	24110	Economy	12700.00
0005433923376	24110	Economy	12700.00
0005433036655	24110	Economy	12700.00
0005433923580	24110	Economy	11600.00
0005432207680	24110	Economy	11600.00
0005433923417	24110	Economy	11600.00
0005433923042	24110	Economy	11600.00
0005433923343	24110	Economy	11600.00
0005433923599	24110	Economy	11600.00
0005433922978	24110	Economy	11600.00
0005433923061	24110	Economy	11600.00
0005433923122	24110	Economy	11600.00
0005433923448	24110	Economy	11600.00
0005433036673	24110	Economy	11600.00
0005433036670	24110	Economy	11600.00
0005433923295	24110	Economy	11600.00
0005433922970	24110	Economy	11600.00
0005432206236	24110	Economy	11600.00
0005433923248	24110	Economy	11600.00
0005433036686	24110	Economy	11600.00
0005433923466	24110	Economy	11600.00
0005432207682	24110	Economy	11600.00
0005433923377	24110	Economy	11600.00
0005433036701	24110	Economy	11600.00
0005433923180	24110	Economy	11600.00
0005433922529	24110	Economy	11600.00
0005432749801	24110	Economy	11600.00
0005433036667	24110	Economy	11600.00
0005433923349	24110	Economy	11600.00
0005433036671	24110	Economy	11600.00
0005433922991	24110	Economy	11600.00
0005432206240	24110	Economy	11600.00
0005433923227	24110	Economy	11600.00
0005433036661	24110	Economy	11600.00
0005433923152	24110	Economy	11600.00
0005433922842	24110	Economy	11600.00
0005433922885	24110	Economy	11600.00
0005433923451	24110	Economy	11600.00
0005433923151	24110	Economy	11600.00
0005433931457	24110	Economy	11600.00
0005433036685	24110	Economy	11600.00
0005433922884	24110	Economy	11600.00
0005433923259	24110	Economy	11600.00
0005432206235	24110	Economy	11600.00
0005432206238	24110	Economy	11600.00
0005433036699	24110	Economy	11600.00
0005433923173	24110	Economy	11600.00
0005433922998	24110	Economy	11600.00
0005433036693	24110	Economy	11600.00
0005433923332	24110	Economy	11600.00
0005433923104	24110	Economy	11600.00
0005433922911	24110	Economy	11600.00
0005433036666	24110	Economy	11600.00
0005433922986	24110	Economy	11600.00
0005433923054	24110	Economy	11600.00
0005433923263	24110	Economy	11600.00
0005433923169	24110	Economy	11600.00
0005433923174	24110	Economy	11600.00
0005433923101	24110	Economy	11600.00
0005433036672	24110	Economy	11600.00
0005433923247	24110	Economy	11600.00
0005433923032	24110	Economy	11600.00
0005433923225	24110	Economy	11600.00
0005433923404	24110	Economy	11600.00
0005433923581	24110	Economy	11600.00
0005433923253	24110	Economy	11600.00
0005433036697	24110	Economy	11600.00
0005433036679	24110	Economy	11600.00
0005433923243	24110	Economy	11600.00
0005433923056	24110	Economy	11600.00
0005433036696	24110	Economy	11600.00
0005433923256	24110	Economy	11600.00
0005433923226	24110	Economy	11600.00
0005433923307	24110	Economy	11600.00
0005433036677	24110	Economy	11600.00
0005433923398	24110	Economy	11600.00
0005433923057	24110	Economy	11600.00
0005433036702	24110	Economy	11600.00
0005433923339	24110	Economy	11600.00
0005433923000	24110	Economy	11600.00
0005433036684	24110	Economy	11600.00
0005433923041	24110	Economy	11600.00
0005433036703	24110	Economy	11600.00
0005432749800	24110	Economy	11600.00
0005433923403	24110	Economy	11600.00
0005433036687	24110	Economy	11600.00
0005433923415	24110	Economy	11600.00
0005433923102	24110	Economy	12700.00
0005433922999	24110	Economy	11600.00
0005433923244	24110	Economy	11600.00
0005433922833	24110	Economy	11600.00
0005432206237	24110	Economy	12700.00
0005433923033	24110	Economy	12700.00
0005433923231	24110	Economy	11600.00
0005433923011	24110	Economy	11600.00
0005433922636	24110	Economy	11600.00
0005433922759	24110	Economy	11600.00
0005432207683	24110	Economy	11600.00
0005433036674	24110	Economy	11600.00
0005433036678	24110	Economy	11600.00
0005433036662	24110	Economy	11600.00
0005433923080	24110	Economy	11600.00
0005433929596	24110	Economy	11600.00
0005433036660	24110	Economy	11600.00
0005433923053	24110	Economy	11600.00
0005433923103	24110	Economy	11600.00
0005433036700	24110	Economy	11600.00
0005433923208	24110	Economy	11600.00
0005433923464	24110	Economy	11600.00
0005433923447	24110	Economy	11600.00
0005433923055	24110	Economy	11600.00
0005433036657	24110	Economy	11600.00
0005433036659	24110	Economy	11600.00
0005433036663	24110	Economy	11600.00
0005433923043	24110	Economy	11600.00
0005433922801	24110	Economy	11600.00
0005433923155	24110	Economy	11600.00
0005433923511	24110	Economy	11600.00
0005433922834	24110	Economy	11600.00
0005434028317	24110	Economy	11600.00
0005433036654	24110	Economy	11600.00
0005433036676	24110	Economy	11600.00
0005433036669	24110	Economy	11600.00
0005433036658	24110	Economy	11600.00
0005433036691	24110	Economy	11600.00
0005433036692	24110	Economy	11600.00
0005433923367	24110	Economy	11600.00
0005433036682	24110	Economy	11600.00
0005433922880	24110	Economy	11600.00
0005433922704	24110	Economy	11600.00
0005433923666	24110	Economy	11600.00
0005433036683	24110	Economy	11600.00
0005433036665	24110	Economy	11600.00
0005433036704	24110	Economy	11600.00
0005433923397	24110	Economy	11600.00
0005433923331	24110	Economy	11600.00
0005433923121	24110	Economy	11600.00
0005433923197	24110	Economy	11600.00
0005433923342	24110	Economy	11600.00
0005433923299	24110	Economy	11600.00
0005433923205	24110	Economy	11600.00
0005433923416	24110	Economy	11600.00
0005433036664	24110	Economy	11600.00
0005433036653	24110	Economy	11600.00
0005433923300	24110	Economy	11600.00
0005433923341	24110	Economy	11600.00
0005433036668	24110	Economy	11600.00
0005433036695	24110	Economy	11600.00
0005433923279	24110	Economy	11600.00
0005433923209	24110	Economy	11600.00
0005434028316	24110	Economy	11600.00
0005433036689	24110	Economy	11600.00
0005433923350	24110	Economy	11600.00
0005433923491	24110	Economy	11600.00
0005433923340	24110	Economy	11600.00
0005433923230	24110	Economy	11600.00
0005433234344	301	Business	83700.00
0005434726335	301	Business	83700.00
0005434551620	301	Business	83700.00
0005433234122	301	Business	83700.00
0005434551610	301	Business	83700.00
0005433181117	301	Business	83700.00
0005434551656	301	Business	83700.00
0005432277906	301	Business	83700.00
0005435142675	301	Business	83700.00
0005434726312	301	Business	83700.00
0005432277908	301	Business	83700.00
0005434726345	301	Business	83700.00
0005433181094	301	Business	83700.00
0005433233867	301	Business	83700.00
0005434726347	301	Business	83700.00
0005434551643	301	Business	83700.00
0005434726330	301	Business	83700.00
0005434726326	301	Business	83700.00
0005434726362	301	Business	83700.00
0005434726372	301	Business	83700.00
0005434735720	301	Business	83700.00
0005434726304	301	Business	83700.00
0005434726370	301	Business	83700.00
0005434551609	301	Business	83700.00
0005432277912	301	Comfort	47400.00
0005434726339	301	Comfort	47400.00
0005434726381	301	Comfort	47400.00
0005433234227	301	Comfort	47400.00
0005434551647	301	Comfort	47400.00
0005434032030	301	Comfort	47400.00
0005434551622	301	Comfort	47400.00
0005434726311	301	Comfort	47400.00
0005433233968	301	Comfort	47400.00
0005434032029	301	Comfort	47400.00
0005434551615	301	Comfort	47400.00
0005432277911	301	Comfort	47400.00
0005433181040	301	Comfort	47400.00
0005434726301	301	Comfort	47400.00
0005433181155	301	Comfort	47400.00
0005434726331	301	Comfort	47400.00
0005433181138	301	Comfort	47400.00
0005433234021	301	Comfort	47400.00
0005434726317	301	Comfort	47400.00
0005434726405	301	Comfort	47400.00
0005434726313	301	Comfort	47400.00
0005434551637	301	Comfort	47400.00
0005434726302	301	Comfort	47400.00
0005434551624	301	Comfort	47400.00
0005434551640	301	Comfort	47400.00
0005434302491	301	Comfort	47400.00
0005434551625	301	Comfort	47400.00
0005433181053	301	Comfort	47400.00
0005434551638	301	Comfort	47400.00
0005433126823	301	Comfort	47400.00
0005434726307	301	Comfort	47400.00
0005434726290	301	Comfort	47400.00
0005435142670	301	Comfort	47400.00
0005434735722	301	Comfort	47400.00
0005434726288	301	Comfort	47400.00
0005433234007	301	Comfort	47400.00
0005434726400	301	Comfort	47400.00
0005434726388	301	Comfort	47400.00
0005432277907	301	Comfort	47400.00
0005433111497	301	Comfort	47400.00
0005434726294	301	Comfort	47400.00
0005434551642	301	Comfort	47400.00
0005433181051	301	Comfort	47400.00
0005433181111	301	Comfort	47400.00
0005433181120	301	Comfort	47400.00
0005433181001	301	Economy	27900.00
0005434726309	301	Economy	27900.00
0005434726376	301	Economy	27900.00
0005433234192	301	Economy	27900.00
0005434551616	301	Economy	27900.00
0005434302492	301	Economy	27900.00
0005433181007	301	Economy	27900.00
0005434032023	301	Economy	27900.00
0005433233753	301	Economy	27900.00
0005434726402	301	Economy	27900.00
0005432277904	301	Economy	27900.00
0005433766616	301	Economy	27900.00
0005433766615	301	Economy	27900.00
0005434726337	301	Economy	27900.00
0005433234128	301	Economy	27900.00
0005434726394	301	Economy	27900.00
0005433233919	301	Economy	27900.00
0005434551653	301	Economy	27900.00
0005433181000	301	Economy	27900.00
0005434726369	301	Economy	27900.00
0005434551605	301	Economy	27900.00
0005435142677	301	Economy	27900.00
0005433181052	301	Economy	27900.00
0005434726287	301	Economy	27900.00
0005434731196	301	Economy	27900.00
0005434726378	301	Economy	27900.00
0005433234177	301	Economy	27900.00
0005433181012	301	Economy	27900.00
0005434302490	301	Economy	27900.00
0005434726296	301	Economy	27900.00
0005432277905	301	Economy	27900.00
0005433234187	301	Economy	27900.00
0005433181197	301	Economy	27900.00
0005433181067	301	Economy	27900.00
0005434726289	301	Economy	27900.00
0005435142679	301	Economy	27900.00
0005434551612	301	Economy	27900.00
0005433131694	301	Economy	27900.00
0005433289833	301	Economy	27900.00
0005433234135	301	Economy	27900.00
0005434726390	301	Economy	27900.00
0005433181118	301	Economy	27900.00
0005435142672	301	Economy	27900.00
0005434551618	301	Economy	27900.00
0005433181137	301	Economy	27900.00
0005433234066	301	Economy	27900.00
0005433181154	301	Economy	27900.00
0005433233764	301	Economy	27900.00
0005434551650	301	Economy	27900.00
0005434726359	301	Economy	27900.00
0005434726396	301	Economy	27900.00
0005433181129	301	Economy	27900.00
0005433181153	301	Economy	27900.00
0005432277909	301	Economy	27900.00
0005434726363	301	Economy	27900.00
0005434726348	301	Economy	27900.00
0005433181068	301	Economy	27900.00
0005434302488	301	Economy	27900.00
0005433181109	301	Economy	30700.00
0005435142671	301	Economy	30700.00
0005434726354	301	Economy	30700.00
0005433234250	301	Economy	27900.00
0005433234048	301	Economy	27900.00
0005433234311	301	Economy	27900.00
0005433181063	301	Economy	30700.00
0005435142678	301	Economy	27900.00
0005433234093	301	Economy	30700.00
0005433234251	301	Economy	30700.00
0005433111490	301	Economy	27900.00
0005434726329	301	Economy	27900.00
0005434726397	301	Economy	27900.00
0005433234193	301	Economy	27900.00
0005434726406	301	Economy	27900.00
0005434726319	301	Economy	27900.00
0005433131709	301	Economy	27900.00
0005434726353	301	Economy	27900.00
0005433234170	301	Economy	27900.00
0005434551648	301	Economy	27900.00
0005435142673	301	Economy	27900.00
0005434726383	301	Economy	27900.00
0005434726373	301	Economy	27900.00
0005433234126	301	Economy	27900.00
0005434551657	301	Economy	27900.00
0005433234294	301	Economy	27900.00
0005434726350	301	Economy	27900.00
0005433289799	301	Economy	27900.00
0005434726395	301	Economy	27900.00
0005434551649	301	Economy	27900.00
0005433234234	301	Economy	27900.00
0005435142674	301	Economy	27900.00
0005433289834	301	Economy	27900.00
0005433131695	301	Economy	27900.00
0005433289830	301	Economy	27900.00
0005435142668	301	Economy	27900.00
0005434551634	301	Economy	27900.00
0005434551619	301	Economy	27900.00
0005434032024	301	Economy	27900.00
0005434551630	301	Economy	27900.00
0005433234076	301	Economy	27900.00
0005435142681	301	Economy	27900.00
0005433233969	301	Economy	27900.00
0005434726316	301	Economy	27900.00
0005434726338	301	Economy	27900.00
0005433233898	301	Economy	27900.00
0005434551654	301	Economy	27900.00
0005434726365	301	Economy	27900.00
0005433289800	301	Economy	27900.00
0005433234090	301	Economy	27900.00
0005434726320	301	Economy	27900.00
0005433234230	301	Economy	27900.00
0005434726333	301	Economy	27900.00
0005433233754	301	Economy	27900.00
0005434726368	301	Economy	27900.00
0005434726340	301	Economy	27900.00
0005433234433	301	Economy	27900.00
0005434551629	301	Economy	27900.00
0005434726291	301	Economy	27900.00
0005433126842	301	Economy	27900.00
0005434551652	301	Economy	27900.00
0005433234224	301	Economy	27900.00
0005433181085	301	Economy	27900.00
0005434726341	301	Economy	27900.00
0005434726327	301	Economy	27900.00
0005434551608	301	Economy	27900.00
0005434726308	301	Economy	27900.00
0005433234121	301	Economy	27900.00
0005433766631	301	Economy	27900.00
0005434726377	301	Economy	27900.00
0005435142676	301	Economy	27900.00
0005434551611	301	Economy	27900.00
0005434726299	301	Economy	27900.00
0005434726315	301	Economy	27900.00
0005434032017	301	Economy	27900.00
0005434726324	301	Economy	27900.00
0005434726314	301	Economy	27900.00
0005433181018	301	Economy	27900.00
0005433233848	301	Economy	27900.00
0005434731199	301	Economy	27900.00
0005432277899	301	Economy	27900.00
0005433234065	301	Economy	27900.00
0005434726392	301	Economy	27900.00
0005434726323	301	Economy	27900.00
0005434551607	301	Economy	27900.00
0005433234407	301	Economy	27900.00
0005434726328	301	Economy	27900.00
0005434731195	301	Economy	27900.00
0005434726303	301	Economy	27900.00
0005433234235	301	Economy	27900.00
0005433234075	301	Economy	27900.00
0005434726292	301	Economy	27900.00
0005434551651	301	Economy	27900.00
0005434726355	301	Economy	27900.00
0005433234176	301	Economy	27900.00
0005434726298	301	Economy	27900.00
0005432277910	301	Economy	27900.00
0005434726399	301	Economy	27900.00
0005434551621	301	Economy	27900.00
0005434726321	301	Economy	27900.00
0005434726310	301	Economy	27900.00
0005434726366	301	Economy	27900.00
0005433111491	301	Economy	27900.00
0005433766620	301	Economy	27900.00
0005433234092	301	Economy	27900.00
0005434726398	301	Economy	27900.00
0005434726385	301	Economy	27900.00
0005433766632	301	Economy	27900.00
0005433234091	301	Economy	27900.00
0005433180914	301	Economy	27900.00
0005434726297	301	Economy	27900.00
0005434735724	301	Economy	27900.00
0005434735721	301	Economy	27900.00
0005434726318	301	Economy	27900.00
0005434726336	301	Economy	27900.00
0005434726389	301	Economy	27900.00
0005434726384	301	Economy	27900.00
0005433181198	301	Economy	30700.00
0005433180913	301	Economy	30700.00
0005433181119	301	Economy	30700.00
0005434726408	301	Economy	30700.00
0005434726300	301	Economy	27900.00
0005433126843	301	Economy	27900.00
0005434726295	301	Economy	27900.00
0005434726374	301	Economy	27900.00
0005434726361	301	Economy	27900.00
0005434726403	301	Economy	27900.00
0005434032022	301	Economy	27900.00
0005434551641	301	Economy	27900.00
0005433234396	301	Economy	27900.00
0005432277903	301	Economy	27900.00
0005433233967	301	Economy	27900.00
0005434551632	301	Economy	27900.00
0005434551628	301	Economy	27900.00
0005433289831	301	Economy	27900.00
0005434551617	301	Economy	27900.00
0005434726367	301	Economy	27900.00
0005433233920	301	Economy	27900.00
0005434551631	301	Economy	27900.00
0005434726386	301	Economy	27900.00
0005434551646	301	Economy	27900.00
0005434726305	301	Economy	27900.00
0005434032016	301	Economy	27900.00
0005433233918	301	Economy	27900.00
0005434551614	301	Economy	27900.00
0005434726325	301	Economy	27900.00
0005434726371	301	Economy	27900.00
0005433126838	301	Economy	27900.00
0005434726343	301	Economy	27900.00
0005434032014	301	Economy	27900.00
0005433181110	301	Economy	27900.00
0005434726349	301	Economy	27900.00
0005434726344	301	Economy	27900.00
0005433181015	301	Economy	27900.00
0005434735723	301	Economy	27900.00
0005433181055	301	Economy	27900.00
0005435142680	301	Economy	27900.00
0005433234083	301	Economy	27900.00
0005433233866	301	Economy	27900.00
0005434726293	301	Economy	27900.00
0005434726393	301	Economy	27900.00
0005434726346	301	Economy	27900.00
0005433126837	301	Economy	27900.00
0005433181019	301	Economy	27900.00
0005434726322	301	Economy	27900.00
0005433131710	301	Economy	27900.00
0005433233897	301	Economy	27900.00
0005433181041	301	Economy	27900.00
0005433233917	301	Economy	27900.00
0005433181016	301	Economy	27900.00
0005434726332	301	Economy	27900.00
0005434726306	301	Economy	27900.00
0005434726351	301	Economy	27900.00
0005434726379	301	Economy	27900.00
0005433234408	301	Economy	27900.00
0005434726357	301	Economy	27900.00
0005434726401	301	Economy	27900.00
0005434551626	301	Economy	27900.00
0005433131715	301	Economy	27900.00
0005433234367	301	Economy	27900.00
0005434726407	301	Economy	27900.00
0005432277900	301	Economy	27900.00
0005434302489	301	Economy	27900.00
0005434032018	301	Economy	27900.00
0005433234226	301	Economy	27900.00
0005434726404	301	Economy	27900.00
0005434726375	301	Economy	27900.00
0005434726360	301	Economy	27900.00
0005433289814	301	Economy	27900.00
0005433131706	301	Economy	27900.00
0005434726409	301	Economy	27900.00
0005434726358	301	Economy	27900.00
0005434731198	301	Economy	27900.00
0005432277901	301	Economy	27900.00
0005434731197	301	Economy	27900.00
0005434726382	301	Economy	27900.00
0005434726364	301	Economy	27900.00
0005434551627	301	Economy	27900.00
0005433181128	301	Economy	27900.00
0005434551645	301	Economy	27900.00
0005433181013	301	Economy	27900.00
0005434726352	301	Economy	27900.00
0005434726391	301	Economy	27900.00
0005433180925	301	Economy	27900.00
0005433233921	301	Economy	27900.00
0005433233776	301	Economy	27900.00
0005434551606	301	Economy	27900.00
0005434726380	301	Economy	27900.00
0005433181075	301	Economy	27900.00
0005434551644	301	Economy	27900.00
0005434726356	301	Economy	27900.00
0005434551636	301	Economy	27900.00
0005433233777	301	Economy	27900.00
0005433181086	301	Economy	27900.00
0005435142669	301	Economy	27900.00
0005434551655	301	Economy	27900.00
0005434726334	301	Economy	27900.00
0005432277902	301	Economy	27900.00
0005433181024	301	Economy	27900.00
0005434551633	301	Economy	27900.00
0005433766619	301	Economy	27900.00
0005433234131	301	Economy	27900.00
0005434551635	301	Economy	27900.00
0005434551639	301	Economy	27900.00
0005434726387	301	Economy	27900.00
0005434551623	301	Economy	27900.00
0005433181062	301	Economy	27900.00
0005434551613	301	Economy	27900.00
0005434726342	301	Economy	27900.00
0005433113533	301	Economy	27900.00
0005433181269	9860	Business	83700.00
0005434551189	9860	Business	83700.00
0005435142549	9860	Business	83700.00
0005433234643	9860	Business	83700.00
0005433234676	9860	Business	83700.00
0005433234689	9860	Business	83700.00
0005433126878	9860	Business	83700.00
0005433234668	9860	Business	83700.00
0005434725245	9860	Business	83700.00
0005434725725	9860	Business	83700.00
0005434725658	9860	Business	83700.00
0005433234642	9860	Business	83700.00
0005433126875	9860	Business	83700.00
0005433234679	9860	Business	83700.00
0005433181268	9860	Business	83700.00
0005434725649	9860	Business	83700.00
0005434725503	9860	Business	83700.00
0005434724889	9860	Business	83700.00
0005434725740	9860	Business	83700.00
0005434725251	9860	Business	83700.00
0005434725791	9860	Business	83700.00
0005434551377	9860	Business	83700.00
0005435142553	9860	Business	83700.00
0005433126876	9860	Business	83700.00
0005434725215	9860	Business	83700.00
0005434551001	9860	Business	83700.00
0005435142488	9860	Comfort	47400.00
0005434551064	9860	Comfort	47400.00
0005434551059	9860	Comfort	47400.00
0005434724901	9860	Comfort	47400.00
0005433234660	9860	Comfort	47400.00
0005434725228	9860	Comfort	47400.00
0005433234682	9860	Comfort	47400.00
0005434725738	9860	Comfort	47400.00
0005433181293	9860	Comfort	47400.00
0005434551058	9860	Comfort	47400.00
0005434725552	9860	Comfort	47400.00
0005435142501	9860	Comfort	47400.00
0005434550935	9860	Comfort	47400.00
0005433129310	9860	Comfort	47400.00
0005433234678	9860	Comfort	47400.00
0005434725059	9860	Comfort	47400.00
0005434551174	9860	Comfort	47400.00
0005434725032	9860	Comfort	47400.00
0005433289897	9860	Comfort	47400.00
0005433234685	9860	Comfort	47400.00
0005434550917	9860	Comfort	47400.00
0005433181277	9860	Comfort	47400.00
0005433181288	9860	Comfort	47400.00
0005434551280	9860	Comfort	47400.00
0005433234657	9860	Comfort	47400.00
0005434725605	9860	Comfort	47400.00
0005434725220	9860	Comfort	47400.00
0005434731153	9860	Comfort	47400.00
0005434551126	9860	Comfort	47400.00
0005434725194	9860	Comfort	47400.00
0005434725060	9860	Comfort	47400.00
0005434725016	9860	Comfort	47400.00
0005433234638	9860	Comfort	47400.00
0005434725048	9860	Comfort	47400.00
0005434725660	9860	Comfort	47400.00
0005433234637	9860	Comfort	47400.00
0005434735675	9860	Comfort	47400.00
0005434551281	9860	Comfort	47400.00
0005434725314	9860	Economy	27900.00
0005434725203	9860	Economy	27900.00
0005434725345	9860	Economy	27900.00
0005434725737	9860	Economy	27900.00
0005435142572	9860	Economy	27900.00
0005433234661	9860	Economy	27900.00
0005434724911	9860	Economy	27900.00
0005433181283	9860	Economy	27900.00
0005434725147	9860	Economy	27900.00
0005434551191	9860	Economy	27900.00
0005433113553	9860	Economy	27900.00
0005433234634	9860	Economy	27900.00
0005434731157	9860	Economy	27900.00
0005433234654	9860	Economy	27900.00
0005433234687	9860	Economy	27900.00
0005432199301	9860	Economy	27900.00
0005434725726	9860	Economy	27900.00
0005433289900	9860	Economy	27900.00
0005435142571	9860	Economy	27900.00
0005434725201	9860	Economy	27900.00
0005434551311	9860	Economy	27900.00
0005434551063	9860	Economy	27900.00
0005434725487	9860	Economy	27900.00
0005433181284	9860	Economy	27900.00
0005434725501	9860	Economy	27900.00
0005434551228	9860	Economy	27900.00
0005434725489	9860	Economy	27900.00
0005434725845	9860	Economy	27900.00
0005433234670	9860	Economy	27900.00
0005434551151	9860	Economy	27900.00
0005433181278	9860	Economy	27900.00
0005434725145	9860	Economy	27900.00
0005433234672	9860	Economy	27900.00
0005433234641	9860	Economy	27900.00
0005434551152	9860	Economy	27900.00
0005433234640	9860	Economy	27900.00
0005434551192	9860	Economy	27900.00
0005433181280	9860	Economy	27900.00
0005434725575	9860	Economy	27900.00
0005434725562	9860	Economy	27900.00
0005433234674	9860	Economy	27900.00
0005433289901	9860	Economy	27900.00
0005434551007	9860	Economy	27900.00
0005433234645	9860	Economy	27900.00
0005433234649	9860	Economy	27900.00
0005434725177	9860	Economy	27900.00
0005433234651	9860	Economy	27900.00
0005433181270	9860	Economy	27900.00
0005433234626	9860	Economy	27900.00
0005434725146	9860	Economy	27900.00
0005433234650	9860	Economy	27900.00
0005434725813	9860	Economy	27900.00
0005434725053	9860	Economy	27900.00
0005434725563	9860	Economy	27900.00
0005433181273	9860	Economy	27900.00
0005434725164	9860	Economy	27900.00
0005434725459	9860	Economy	27900.00
0005434725584	9860	Economy	27900.00
0005433234647	9860	Economy	30700.00
0005434550964	9860	Economy	27900.00
0005434551006	9860	Economy	30700.00
0005433234666	9860	Economy	27900.00
0005433234631	9860	Economy	30700.00
0005433234659	9860	Economy	27900.00
0005434302429	9860	Economy	27900.00
0005434550868	9860	Economy	27900.00
0005433234675	9860	Economy	30700.00
0005433766666	9860	Economy	30700.00
0005433181281	9860	Economy	27900.00
0005434725077	9860	Economy	27900.00
0005434551326	9860	Economy	27900.00
0005433129308	9860	Economy	27900.00
0005433181290	9860	Economy	27900.00
0005434724789	9860	Economy	27900.00
0005433234644	9860	Economy	27900.00
0005435142540	9860	Economy	27900.00
0005434551162	9860	Economy	27900.00
0005434725654	9860	Economy	27900.00
0005433234652	9860	Economy	27900.00
0005434724902	9860	Economy	27900.00
0005435142573	9860	Economy	27900.00
0005433181271	9860	Economy	27900.00
0005434725125	9860	Economy	27900.00
0005434551144	9860	Economy	27900.00
0005434725138	9860	Economy	27900.00
0005433181287	9860	Economy	27900.00
0005434725296	9860	Economy	27900.00
0005434725344	9860	Economy	27900.00
0005434725126	9860	Economy	27900.00
0005435142479	9860	Economy	27900.00
0005433234665	9860	Economy	27900.00
0005434725797	9860	Economy	27900.00
0005434725299	9860	Economy	27900.00
0005434725751	9860	Economy	27900.00
0005434724729	9860	Economy	27900.00
0005434725142	9860	Economy	27900.00
0005433289899	9860	Economy	27900.00
0005434725411	9860	Economy	27900.00
0005434725319	9860	Economy	27900.00
0005433766667	9860	Economy	27900.00
0005434725410	9860	Economy	27900.00
0005433234636	9860	Economy	27900.00
0005433234627	9860	Economy	27900.00
0005434735672	9860	Economy	27900.00
0005434725148	9860	Economy	27900.00
0005433181286	9860	Economy	27900.00
0005434551145	9860	Economy	27900.00
0005434725095	9860	Economy	27900.00
0005434724788	9860	Economy	27900.00
0005433234664	9860	Economy	27900.00
0005433766668	9860	Economy	27900.00
0005434725313	9860	Economy	27900.00
0005434725295	9860	Economy	27900.00
0005434725127	9860	Economy	27900.00
0005434725096	9860	Economy	27900.00
0005434725139	9860	Economy	27900.00
0005433181285	9860	Economy	27900.00
0005434724910	9860	Economy	27900.00
0005433234681	9860	Economy	27900.00
0005434724972	9860	Economy	27900.00
0005432199298	9860	Economy	27900.00
0005434735693	9860	Economy	27900.00
0005434725812	9860	Economy	27900.00
0005434725484	9860	Economy	27900.00
0005433234677	9860	Economy	27900.00
0005433181294	9860	Economy	27900.00
0005433289895	9860	Economy	27900.00
0005433181282	9860	Economy	27900.00
0005433234663	9860	Economy	27900.00
0005434725331	9860	Economy	27900.00
0005434550915	9860	Economy	27900.00
0005433234671	9860	Economy	27900.00
0005434550980	9860	Economy	27900.00
0005432199299	9860	Economy	27900.00
0005434725280	9860	Economy	27900.00
0005434551104	9860	Economy	27900.00
0005434725739	9860	Economy	27900.00
0005433234628	9860	Economy	27900.00
0005434551097	9860	Economy	27900.00
0005433234656	9860	Economy	27900.00
0005433234684	9860	Economy	27900.00
0005434725685	9860	Economy	27900.00
0005434725906	9860	Economy	27900.00
0005434551098	9860	Economy	27900.00
0005434724994	9860	Economy	27900.00
0005434725017	9860	Economy	27900.00
0005434551327	9860	Economy	27900.00
0005434725534	9860	Economy	27900.00
0005434032057	9860	Economy	27900.00
0005434725619	9860	Economy	27900.00
0005433234630	9860	Economy	27900.00
0005434551184	9860	Economy	27900.00
0005434725233	9860	Economy	27900.00
0005433289898	9860	Economy	27900.00
0005433234683	9860	Economy	27900.00
0005434032056	9860	Economy	27900.00
0005435142502	9860	Economy	27900.00
0005435142589	9860	Economy	27900.00
0005434725428	9860	Economy	27900.00
0005434551202	9860	Economy	27900.00
0005435142480	9860	Economy	27900.00
0005434724658	9860	Economy	27900.00
0005433234632	9860	Economy	27900.00
0005432199296	9860	Economy	27900.00
0005434550946	9860	Economy	27900.00
0005434725902	9860	Economy	27900.00
0005433234655	9860	Economy	30700.00
0005433234648	9860	Economy	30700.00
0005433234629	9860	Economy	30700.00
0005433181289	9860	Economy	30700.00
0005433289896	9860	Economy	27900.00
0005434725870	9860	Economy	27900.00
0005434550998	9860	Economy	27900.00
0005433234688	9860	Economy	27900.00
0005433181295	9860	Economy	27900.00
0005434725209	9860	Economy	27900.00
0005434725460	9860	Economy	27900.00
0005434550951	9860	Economy	27900.00
0005433234653	9860	Economy	27900.00
0005435142567	9860	Economy	27900.00
0005433113551	9860	Economy	27900.00
0005434725325	9860	Economy	27900.00
0005434725131	9860	Economy	27900.00
0005434724993	9860	Economy	27900.00
0005434725202	9860	Economy	27900.00
0005434725393	9860	Economy	27900.00
0005434725502	9860	Economy	27900.00
0005434725452	9860	Economy	27900.00
0005434725385	9860	Economy	27900.00
0005433181291	9860	Economy	27900.00
0005433181279	9860	Economy	27900.00
0005435142541	9860	Economy	27900.00
0005434725594	9860	Economy	27900.00
0005433234646	9860	Economy	27900.00
0005435142536	9860	Economy	27900.00
0005433126879	9860	Economy	27900.00
0005434551219	9860	Economy	27900.00
0005433181272	9860	Economy	27900.00
0005434550878	9860	Economy	27900.00
0005432199295	9860	Economy	27900.00
0005434725618	9860	Economy	27900.00
0005434725346	9860	Economy	27900.00
0005434725072	9860	Economy	27900.00
0005433126877	9860	Economy	27900.00
0005434725232	9860	Economy	27900.00
0005434725143	9860	Economy	27900.00
0005434551000	9860	Economy	27900.00
0005434725695	9860	Economy	27900.00
0005434725178	9860	Economy	27900.00
0005434725003	9860	Economy	27900.00
0005433234686	9860	Economy	27900.00
0005434725655	9860	Economy	27900.00
0005433766669	9860	Economy	27900.00
0005434725058	9860	Economy	27900.00
0005433129309	9860	Economy	27900.00
0005435142547	9860	Economy	27900.00
0005434725846	9860	Economy	27900.00
0005433234667	9860	Economy	27900.00
0005434725483	9860	Economy	27900.00
0005434725392	9860	Economy	27900.00
0005433181292	9860	Economy	27900.00
0005435142557	9860	Economy	27900.00
0005433234662	9860	Economy	27900.00
0005433234635	9860	Economy	27900.00
0005434725033	9860	Economy	27900.00
0005433181276	9860	Economy	27900.00
0005434735674	9860	Economy	27900.00
0005433113552	9860	Economy	27900.00
0005434032060	9860	Economy	27900.00
0005433234633	9860	Economy	27900.00
0005433234680	9860	Economy	27900.00
0005433234658	9860	Economy	27900.00
0005434725390	9860	Economy	27900.00
0005434725891	9860	Economy	27900.00
0005433234639	9860	Economy	27900.00
0005433181274	9860	Economy	27900.00
0005433129307	9860	Economy	27900.00
0005433234669	9860	Economy	27900.00
0005433181275	9860	Economy	27900.00
0005434551127	9860	Economy	27900.00
0005434551048	9860	Economy	27900.00
0005434551190	9860	Economy	27900.00
0005434725165	9860	Economy	27900.00
0005434725533	9860	Economy	27900.00
0005435142552	9860	Economy	27900.00
0005434725350	9860	Economy	27900.00
0005432199297	9860	Economy	27900.00
0005434725246	9860	Economy	27900.00
0005434032059	9860	Economy	27900.00
0005434302428	9860	Economy	27900.00
0005434551075	9860	Economy	27900.00
0005433234673	9860	Economy	27900.00
0005434724659	9860	Economy	27900.00
0005434725504	9860	Economy	27900.00
0005432199300	9860	Economy	27900.00
0005434032058	9860	Economy	27900.00
0005434551268	9860	Economy	27900.00
0005432528944	7776	Business	42100.00
0005434068090	7776	Business	42100.00
0005432528939	7776	Business	42100.00
0005434068069	7776	Business	42100.00
0005434068054	7776	Business	42100.00
0005435213314	7776	Business	42100.00
0005435725595	7776	Business	42100.00
0005432528866	7776	Business	42100.00
0005432528909	7776	Business	42100.00
0005435213643	7776	Business	42100.00
0005432528938	7776	Business	42100.00
0005432528855	7776	Business	42100.00
0005432528979	7776	Business	42100.00
0005432150248	7776	Business	42100.00
0005432528877	7776	Business	42100.00
0005434068046	7776	Business	42100.00
0005435725590	7776	Business	42100.00
0005434068095	7776	Business	42100.00
0005435725596	7776	Business	42100.00
0005432150247	7776	Business	42100.00
0005434068040	7776	Business	42100.00
0005434068089	7776	Business	42100.00
0005434068085	7776	Business	42100.00
0005432428952	7776	Comfort	23900.00
0005432528941	7776	Comfort	23900.00
0005432528881	7776	Comfort	23900.00
0005432528959	7776	Comfort	23900.00
0005435212977	7776	Comfort	23900.00
0005432528915	7776	Comfort	23900.00
0005432528965	7776	Comfort	23900.00
0005432428953	7776	Comfort	23900.00
0005434068103	7776	Comfort	23900.00
0005434068101	7776	Comfort	23900.00
0005432528964	7776	Comfort	23900.00
0005433656675	7776	Comfort	23900.00
0005435213596	7776	Comfort	23900.00
0005435725570	7776	Comfort	23900.00
0005432528890	7776	Comfort	23900.00
0005432528930	7776	Comfort	23900.00
0005435630977	7776	Comfort	23900.00
0005432528872	7776	Comfort	23900.00
0005432528950	7776	Comfort	23900.00
0005432150251	7776	Comfort	23900.00
0005435213557	7776	Comfort	23900.00
0005434068075	7776	Comfort	23900.00
0005432528880	7776	Comfort	23900.00
0005435213104	7776	Comfort	23900.00
0005434068048	7776	Comfort	23900.00
0005432528986	7776	Comfort	23900.00
0005435213646	7776	Comfort	23900.00
0005432528883	7776	Comfort	23900.00
0005432528894	7776	Comfort	23900.00
0005432528926	7776	Comfort	23900.00
0005432528958	7776	Comfort	23900.00
0005435213684	7776	Comfort	23900.00
0005435213508	7776	Comfort	23900.00
0005434068086	7776	Comfort	23900.00
0005432528898	7776	Comfort	23900.00
0005434068056	7776	Comfort	23900.00
0005435213630	7776	Comfort	23900.00
0005432528864	7776	Economy	14000.00
0005432528901	7776	Economy	14000.00
0005432528936	7776	Economy	14000.00
0005435213407	7776	Economy	14000.00
0005434068073	7776	Economy	14000.00
0005432528940	7776	Economy	14000.00
0005435725566	7776	Economy	14000.00
0005435213498	7776	Economy	14000.00
0005435213635	7776	Economy	14000.00
0005432528935	7776	Economy	14000.00
0005432533313	7776	Economy	14000.00
0005434068108	7776	Economy	14000.00
0005432528934	7776	Economy	14000.00
0005432528924	7776	Economy	14000.00
0005434068041	7776	Economy	14000.00
0005432528956	7776	Economy	14000.00
0005435725574	7776	Economy	14000.00
0005432528884	7776	Economy	14000.00
0005434068051	7776	Economy	14000.00
0005435213358	7776	Economy	14000.00
0005432535870	7776	Economy	14000.00
0005432528857	7776	Economy	14000.00
0005435213696	7776	Economy	14000.00
0005435725597	7776	Economy	14000.00
0005434068083	7776	Economy	14000.00
0005432528953	7776	Economy	14000.00
0005432528954	7776	Economy	14000.00
0005434068076	7776	Economy	14000.00
0005432528922	7776	Economy	14000.00
0005432150252	7776	Economy	14000.00
0005432535871	7776	Economy	14000.00
0005432528963	7776	Economy	14000.00
0005432069758	7776	Economy	14000.00
0005432528960	7776	Economy	14000.00
0005435213513	7776	Economy	14000.00
0005435213091	7776	Economy	14000.00
0005432528900	7776	Economy	14000.00
0005435213491	7776	Economy	14000.00
0005432069754	7776	Economy	14000.00
0005432528987	7776	Economy	14000.00
0005432528942	7776	Economy	14000.00
0005434068057	7776	Economy	14000.00
0005435725575	7776	Economy	14000.00
0005432528875	7776	Economy	14000.00
0005432069759	7776	Economy	14000.00
0005435213467	7776	Economy	14000.00
0005432528917	7776	Economy	14000.00
0005434068047	7776	Economy	14000.00
0005432528955	7776	Economy	14000.00
0005432528951	7776	Economy	14000.00
0005434068065	7776	Economy	14000.00
0005434068100	7776	Economy	14000.00
0005435213430	7776	Economy	14000.00
0005434068094	7776	Economy	14000.00
0005432069755	7776	Economy	14000.00
0005434068061	7776	Economy	14000.00
0005432528908	7776	Economy	14000.00
0005432069756	7776	Economy	14000.00
0005435213298	7776	Economy	14000.00
0005434068093	7776	Economy	14000.00
0005435213256	7776	Economy	14000.00
0005432528906	7776	Economy	14000.00
0005434068045	7776	Economy	14000.00
0005435725576	7776	Economy	15400.00
0005434068068	7776	Economy	14000.00
0005434068074	7776	Economy	15400.00
0005435213201	7776	Economy	14000.00
0005432535868	7776	Economy	14000.00
0005432528949	7776	Economy	15400.00
0005435213539	7776	Economy	14000.00
0005432528978	7776	Economy	14000.00
0005432528905	7776	Economy	14000.00
0005432528985	7776	Economy	14000.00
0005435213533	7776	Economy	14000.00
0005433656676	7776	Economy	14000.00
0005432528911	7776	Economy	14000.00
0005432528899	7776	Economy	14000.00
0005432069760	7776	Economy	14000.00
0005432528980	7776	Economy	14000.00
0005432528929	7776	Economy	14000.00
0005432528867	7776	Economy	14000.00
0005434068043	7776	Economy	14000.00
0005435213610	7776	Economy	14000.00
0005432528871	7776	Economy	14000.00
0005435213316	7776	Economy	14000.00
0005432528919	7776	Economy	14000.00
0005434068039	7776	Economy	14000.00
0005432069752	7776	Economy	14000.00
0005435725593	7776	Economy	14000.00
0005432537073	7776	Economy	14000.00
0005435213532	7776	Economy	14000.00
0005432528948	7776	Economy	14000.00
0005432528932	7776	Economy	14000.00
0005434068077	7776	Economy	14000.00
0005432528969	7776	Economy	14000.00
0005432528897	7776	Economy	14000.00
0005432428954	7776	Economy	14000.00
0005434068063	7776	Economy	14000.00
0005432528957	7776	Economy	14000.00
0005432069765	7776	Economy	14000.00
0005432528892	7776	Economy	14000.00
0005432528983	7776	Economy	14000.00
0005432528927	7776	Economy	14000.00
0005432528876	7776	Economy	14000.00
0005432528914	7776	Economy	14000.00
0005435213540	7776	Economy	14000.00
0005435213392	7776	Economy	14000.00
0005432528856	7776	Economy	14000.00
0005432528981	7776	Economy	14000.00
0005432528885	7776	Economy	14000.00
0005435213644	7776	Economy	14000.00
0005434068066	7776	Economy	14000.00
0005435725567	7776	Economy	14000.00
0005432528863	7776	Economy	14000.00
0005435213551	7776	Economy	14000.00
0005432528891	7776	Economy	14000.00
0005434068096	7776	Economy	14000.00
0005432528887	7776	Economy	14000.00
0005432528896	7776	Economy	14000.00
0005435630966	7776	Economy	14000.00
0005434068104	7776	Economy	14000.00
0005435213362	7776	Economy	14000.00
0005435213783	7776	Economy	14000.00
0005432528918	7776	Economy	14000.00
0005432528859	7776	Economy	14000.00
0005432069761	7776	Economy	14000.00
0005435213535	7776	Economy	14000.00
0005435213782	7776	Economy	14000.00
0005432528961	7776	Economy	14000.00
0005432528902	7776	Economy	14000.00
0005434068081	7776	Economy	14000.00
0005434068091	7776	Economy	14000.00
0005432528886	7776	Economy	14000.00
0005434068084	7776	Economy	14000.00
0005432528976	7776	Economy	14000.00
0005432535866	7776	Economy	14000.00
0005434068049	7776	Economy	14000.00
0005432535869	7776	Economy	14000.00
0005434068105	7776	Economy	14000.00
0005432528869	7776	Economy	14000.00
0005435213468	7776	Economy	14000.00
0005435213634	7776	Economy	14000.00
0005432528862	7776	Economy	14000.00
0005435213382	7776	Economy	14000.00
0005434068050	7776	Economy	14000.00
0005434068052	7776	Economy	14000.00
0005432528925	7776	Economy	14000.00
0005435630965	7776	Economy	14000.00
0005432537072	7776	Economy	14000.00
0005434068058	7776	Economy	14000.00
0005435213340	7776	Economy	14000.00
0005434068059	7776	Economy	14000.00
0005432528967	7776	Economy	14000.00
0005435213685	7776	Economy	14000.00
0005432528928	7776	Economy	14000.00
0005434068079	7776	Economy	14000.00
0005432528943	7776	Economy	14000.00
0005432528920	7776	Economy	14000.00
0005432528912	7776	Economy	14000.00
0005432528952	7776	Economy	14000.00
0005434068072	7776	Economy	14000.00
0005432528937	7776	Economy	14000.00
0005434068042	7776	Economy	14000.00
0005432528946	7776	Economy	14000.00
0005435213631	7776	Economy	14000.00
0005434068053	7776	Economy	14000.00
0005432150254	7776	Economy	14000.00
0005435213885	7776	Economy	14000.00
0005432528973	7776	Economy	14000.00
0005435213466	7776	Economy	14000.00
0005432150249	7776	Economy	15400.00
0005435725571	7776	Economy	14000.00
0005434068067	7776	Economy	15400.00
0005432528868	7776	Economy	15400.00
0005432528893	7776	Economy	15400.00
0005432528870	7776	Economy	15400.00
0005435213621	7776	Economy	14000.00
0005435213507	7776	Economy	14000.00
0005435213478	7776	Economy	14000.00
0005434068087	7776	Economy	14000.00
0005435213395	7776	Economy	14000.00
0005432150253	7776	Economy	14000.00
0005432528962	7776	Economy	14000.00
0005435213580	7776	Economy	14000.00
0005432528904	7776	Economy	14000.00
0005434068107	7776	Economy	14000.00
0005432528916	7776	Economy	14000.00
0005432069763	7776	Economy	14000.00
0005432069766	7776	Economy	14000.00
0005434068082	7776	Economy	14000.00
0005432528982	7776	Economy	14000.00
0005435213544	7776	Economy	14000.00
0005432069757	7776	Economy	14000.00
0005432528933	7776	Economy	14000.00
0005434068098	7776	Economy	14000.00
0005432069753	7776	Economy	14000.00
0005435630948	7776	Economy	14000.00
0005432069764	7776	Economy	14000.00
0005434068062	7776	Economy	14000.00
0005435213443	7776	Economy	14000.00
0005432528975	7776	Economy	14000.00
0005432528971	7776	Economy	14000.00
0005435213145	7776	Economy	14000.00
0005435725585	7776	Economy	14000.00
0005432533312	7776	Economy	14000.00
0005432528861	7776	Economy	14000.00
0005434068106	7776	Economy	14000.00
0005432528882	7776	Economy	14000.00
0005434068088	7776	Economy	14000.00
0005435213552	7776	Economy	14000.00
0005432528970	7776	Economy	14000.00
0005432528874	7776	Economy	14000.00
0005434068078	7776	Economy	14000.00
0005435213326	7776	Economy	14000.00
0005432528931	7776	Economy	14000.00
0005432528889	7776	Economy	14000.00
0005432528910	7776	Economy	14000.00
0005432150250	7776	Economy	14000.00
0005435213444	7776	Economy	14000.00
0005432528860	7776	Economy	14000.00
0005435213069	7776	Economy	14000.00
0005434068055	7776	Economy	14000.00
0005435213448	7776	Economy	14000.00
0005435213687	7776	Economy	14000.00
0005432528977	7776	Economy	14000.00
0005432528984	7776	Economy	14000.00
0005434068060	7776	Economy	14000.00
0005434068099	7776	Economy	14000.00
0005432528865	7776	Economy	14000.00
0005432528921	7776	Economy	14000.00
0005435630967	7776	Economy	14000.00
0005433656670	7776	Economy	14000.00
0005434068044	7776	Economy	14000.00
0005432528974	7776	Economy	14000.00
0005432528945	7776	Economy	14000.00
0005435213408	7776	Economy	14000.00
0005434068038	7776	Economy	14000.00
0005435213548	7776	Economy	14000.00
0005432528972	7776	Economy	14000.00
0005432528879	7776	Economy	14000.00
0005432528878	7776	Economy	14000.00
0005432528858	7776	Economy	14000.00
0005434068092	7776	Economy	14000.00
0005432528966	7776	Economy	14000.00
0005435213697	7776	Economy	14000.00
0005432528853	7776	Economy	14000.00
0005434068070	7776	Economy	14000.00
0005432528913	7776	Economy	14000.00
0005434068102	7776	Economy	14000.00
0005432528895	7776	Economy	14000.00
0005434068080	7776	Economy	14000.00
0005434068071	7776	Economy	14000.00
0005435213490	7776	Economy	14000.00
0005432528873	7776	Economy	14000.00
0005435213499	7776	Economy	14000.00
0005432528923	7776	Economy	14000.00
0005432069762	7776	Economy	14000.00
0005432528888	7776	Economy	14000.00
0005435213375	7776	Economy	14000.00
0005435213595	7776	Economy	14000.00
0005432528903	7776	Economy	14000.00
0005435213543	7776	Economy	14000.00
0005435213359	7776	Economy	14000.00
0005432528907	7776	Economy	14000.00
0005435725598	7776	Economy	14000.00
0005432528968	7776	Economy	14000.00
0005432535867	7776	Economy	14000.00
0005432528854	7776	Economy	14000.00
0005432528947	7776	Economy	14000.00
0005434068097	7776	Economy	14000.00
0005435213706	7776	Economy	14000.00
0005435213492	7776	Economy	14000.00
0005434068109	7776	Economy	14000.00
0005434068064	7776	Economy	14000.00
0005435319529	5332	Business	43100.00
0005435614434	5332	Business	43100.00
0005435614421	5332	Business	43100.00
0005435319542	5332	Business	43100.00
0005435424914	5332	Business	43100.00
0005432133325	5332	Business	43100.00
0005435614458	5332	Business	43100.00
0005435424737	5332	Business	43100.00
0005435380304	5332	Business	43100.00
0005435614502	5332	Business	43100.00
0005432133320	5332	Business	43100.00
0005435319544	5332	Business	43100.00
0005435302186	5332	Business	43100.00
0005435424672	5332	Business	43100.00
0005435614466	5332	Business	43100.00
0005435614440	5332	Business	43100.00
0005435614487	5332	Business	43100.00
0005434245039	5332	Business	43100.00
0005435614437	5332	Business	43100.00
0005432841005	5332	Business	43100.00
0005435491454	5332	Business	43100.00
0005432133313	5332	Business	43100.00
0005434244931	5332	Business	43100.00
0005435614517	5332	Business	43100.00
0005435614479	5332	Comfort	24400.00
0005432133319	5332	Business	43100.00
0005435614500	5332	Comfort	24400.00
0005435614427	5332	Comfort	24400.00
0005434344496	5332	Comfort	24400.00
0005434244952	5332	Comfort	24400.00
0005433719133	5332	Comfort	24400.00
0005435424823	5332	Comfort	24400.00
0005435614477	5332	Comfort	24400.00
0005435424828	5332	Comfort	24400.00
0005432133323	5332	Comfort	24400.00
0005435424562	5332	Comfort	24400.00
0005435424931	5332	Comfort	24400.00
0005435424673	5332	Comfort	24400.00
0005435424838	5332	Comfort	24400.00
0005435614463	5332	Comfort	24400.00
0005435424915	5332	Comfort	24400.00
0005435424963	5332	Comfort	24400.00
0005435490256	5332	Comfort	24400.00
0005434244948	5332	Comfort	24400.00
0005435614478	5332	Comfort	24400.00
0005435614503	5332	Comfort	24400.00
0005435380274	5332	Comfort	24400.00
0005435614452	5332	Comfort	24400.00
0005435614514	5332	Comfort	24400.00
0005435424731	5332	Comfort	24400.00
0005434244954	5332	Comfort	24400.00
0005435614442	5332	Comfort	24400.00
0005435424829	5332	Comfort	24400.00
0005435424678	5332	Comfort	24400.00
0005435424807	5332	Comfort	24400.00
0005435380273	5332	Comfort	24400.00
0005435424642	5332	Comfort	24400.00
0005434344475	5332	Comfort	24400.00
0005435424714	5332	Comfort	24400.00
0005435614481	5332	Comfort	24400.00
0005432133317	5332	Comfort	24400.00
0005435305008	5332	Comfort	24400.00
0005435490253	5332	Comfort	24400.00
0005435614483	5332	Comfort	24400.00
0005435424827	5332	Economy	14400.00
0005435424748	5332	Economy	14400.00
0005434573455	5332	Economy	14400.00
0005435380303	5332	Economy	14400.00
0005434344495	5332	Economy	14400.00
0005435302180	5332	Economy	14400.00
0005435614432	5332	Economy	14400.00
0005435424755	5332	Economy	14400.00
0005435424826	5332	Economy	14400.00
0005435424932	5332	Economy	14400.00
0005434244983	5332	Economy	14400.00
0005435614454	5332	Economy	14400.00
0005432133324	5332	Economy	14400.00
0005435097273	5332	Economy	14400.00
0005435424900	5332	Economy	14400.00
0005432047578	5332	Economy	14400.00
0005432133326	5332	Economy	14400.00
0005434344483	5332	Economy	14400.00
0005435424916	5332	Economy	14400.00
0005435424772	5332	Economy	14400.00
0005434244935	5332	Economy	14400.00
0005435614422	5332	Economy	14400.00
0005434344488	5332	Economy	14400.00
0005435614495	5332	Economy	14400.00
0005435305009	5332	Economy	14400.00
0005435614464	5332	Economy	14400.00
0005432363412	5332	Economy	14400.00
0005435614439	5332	Economy	14400.00
0005435614497	5332	Economy	14400.00
0005434344487	5332	Economy	14400.00
0005435614509	5332	Economy	14400.00
0005435614526	5332	Economy	14400.00
0005434245017	5332	Economy	14400.00
0005435424729	5332	Economy	14400.00
0005435614527	5332	Economy	14400.00
0005435424590	5332	Economy	14400.00
0005434344477	5332	Economy	14400.00
0005435614446	5332	Economy	14400.00
0005435424609	5332	Economy	14400.00
0005435490254	5332	Economy	14400.00
0005435614435	5332	Economy	14400.00
0005435097279	5332	Economy	14400.00
0005434573452	5332	Economy	14400.00
0005435424783	5332	Economy	14400.00
0005435555384	5332	Economy	14400.00
0005434244947	5332	Economy	14400.00
0005435614507	5332	Economy	14400.00
0005435424698	5332	Economy	14400.00
0005435614426	5332	Economy	14400.00
0005435614508	5332	Economy	14400.00
0005435424653	5332	Economy	14400.00
0005434344489	5332	Economy	14400.00
0005435424793	5332	Economy	14400.00
0005435614445	5332	Economy	14400.00
0005435614428	5332	Economy	14400.00
0005435614493	5332	Economy	14400.00
0005435614499	5332	Economy	15800.00
0005435614453	5332	Economy	15800.00
0005435614484	5332	Economy	14400.00
0005435614438	5332	Economy	14400.00
0005435614450	5332	Economy	14400.00
0005435380292	5332	Economy	15800.00
0005435424851	5332	Economy	14400.00
0005435614529	5332	Economy	14400.00
0005432133322	5332	Economy	14400.00
0005434573451	5332	Economy	14400.00
0005435614511	5332	Economy	14400.00
0005435424713	5332	Economy	14400.00
0005434244932	5332	Economy	14400.00
0005435424602	5332	Economy	14400.00
0005432133316	5332	Economy	14400.00
0005434573458	5332	Economy	14400.00
0005435614482	5332	Economy	14400.00
0005435614485	5332	Economy	14400.00
0005435424808	5332	Economy	14400.00
0005435614510	5332	Economy	14400.00
0005435614431	5332	Economy	14400.00
0005435097277	5332	Economy	14400.00
0005434244941	5332	Economy	14400.00
0005435614480	5332	Economy	14400.00
0005434344474	5332	Economy	14400.00
0005435614473	5332	Economy	14400.00
0005435042846	5332	Economy	14400.00
0005432047577	5332	Economy	14400.00
0005432133318	5332	Economy	14400.00
0005435424443	5332	Economy	14400.00
0005434573454	5332	Economy	14400.00
0005434344481	5332	Economy	14400.00
0005435424670	5332	Economy	14400.00
0005435614433	5332	Economy	14400.00
0005435424564	5332	Economy	14400.00
0005435614451	5332	Economy	14400.00
0005434656549	5332	Economy	14400.00
0005434244953	5332	Economy	14400.00
0005434573460	5332	Economy	14400.00
0005435424876	5332	Economy	14400.00
0005435424890	5332	Economy	14400.00
0005435380290	5332	Economy	14400.00
0005435302213	5332	Economy	14400.00
0005432841004	5332	Economy	14400.00
0005433719132	5332	Economy	14400.00
0005434344494	5332	Economy	14400.00
0005435614472	5332	Economy	14400.00
0005434244865	5332	Economy	14400.00
0005435424496	5332	Economy	14400.00
0005435614519	5332	Economy	14400.00
0005435424675	5332	Economy	14400.00
0005435424674	5332	Economy	14400.00
0005435305010	5332	Economy	14400.00
0005435424601	5332	Economy	14400.00
0005434344498	5332	Economy	14400.00
0005435424584	5332	Economy	14400.00
0005434244852	5332	Economy	14400.00
0005435424794	5332	Economy	14400.00
0005434344471	5332	Economy	14400.00
0005434344486	5332	Economy	14400.00
0005435424563	5332	Economy	14400.00
0005435614521	5332	Economy	14400.00
0005435614522	5332	Economy	14400.00
0005435302181	5332	Economy	14400.00
0005435380272	5332	Economy	14400.00
0005435614476	5332	Economy	14400.00
0005434573459	5332	Economy	14400.00
0005435614424	5332	Economy	14400.00
0005432133312	5332	Economy	14400.00
0005435380285	5332	Economy	14400.00
0005434344493	5332	Economy	14400.00
0005435614489	5332	Economy	14400.00
0005434344479	5332	Economy	14400.00
0005435614475	5332	Economy	14400.00
0005435614491	5332	Economy	14400.00
0005435380291	5332	Economy	14400.00
0005434244925	5332	Economy	14400.00
0005435614506	5332	Economy	14400.00
0005435614513	5332	Economy	14400.00
0005434245038	5332	Economy	14400.00
0005435380289	5332	Economy	14400.00
0005435614420	5332	Economy	14400.00
0005435424444	5332	Economy	14400.00
0005435424810	5332	Economy	14400.00
0005435097269	5332	Economy	14400.00
0005435614496	5332	Economy	14400.00
0005435614460	5332	Economy	14400.00
0005435614468	5332	Economy	14400.00
0005435614447	5332	Economy	14400.00
0005434573449	5332	Economy	14400.00
0005435614505	5332	Economy	14400.00
0005434244893	5332	Economy	14400.00
0005435424824	5332	Economy	14400.00
0005434244929	5332	Economy	14400.00
0005435424771	5332	Economy	14400.00
0005434344480	5332	Economy	14400.00
0005434573450	5332	Economy	14400.00
0005435614528	5332	Economy	14400.00
0005435424608	5332	Economy	14400.00
0005435424699	5332	Economy	14400.00
0005435097276	5332	Economy	14400.00
0005435614467	5332	Economy	14400.00
0005435490255	5332	Economy	14400.00
0005434245016	5332	Economy	14400.00
0005435614425	5332	Economy	14400.00
0005434344472	5332	Economy	15800.00
0005434245005	5332	Economy	14400.00
0005435614471	5332	Economy	15800.00
0005435614469	5332	Economy	15800.00
0005435424822	5332	Economy	15800.00
0005435424921	5332	Economy	15800.00
0005435614486	5332	Economy	15800.00
0005435424715	5332	Economy	14400.00
0005432133321	5332	Economy	14400.00
0005435614470	5332	Economy	14400.00
0005435614518	5332	Economy	14400.00
0005434244980	5332	Economy	14400.00
0005434344470	5332	Economy	14400.00
0005434344492	5332	Economy	14400.00
0005435614474	5332	Economy	14400.00
0005434244981	5332	Economy	14400.00
0005435614455	5332	Economy	14400.00
0005434344476	5332	Economy	14400.00
0005435424730	5332	Economy	14400.00
0005435614512	5332	Economy	14400.00
0005435097278	5332	Economy	14400.00
0005435424825	5332	Economy	14400.00
0005434344482	5332	Economy	14400.00
0005435424543	5332	Economy	14400.00
0005435424738	5332	Economy	14400.00
0005435614494	5332	Economy	14400.00
0005435614520	5332	Economy	14400.00
0005435614449	5332	Economy	14400.00
0005434244946	5332	Economy	14400.00
0005434344490	5332	Economy	14400.00
0005434244930	5332	Economy	14400.00
0005432133315	5332	Economy	14400.00
0005435614461	5332	Economy	14400.00
0005435614436	5332	Economy	14400.00
0005435319585	5332	Economy	14400.00
0005435614465	5332	Economy	14400.00
0005434344497	5332	Economy	14400.00
0005434573461	5332	Economy	14400.00
0005432133314	5332	Economy	14400.00
0005435097275	5332	Economy	14400.00
0005434573457	5332	Economy	14400.00
0005434244985	5332	Economy	14400.00
0005432047576	5332	Economy	14400.00
0005434244972	5332	Economy	14400.00
0005435614462	5332	Economy	14400.00
0005434573448	5332	Economy	14400.00
0005432363417	5332	Economy	14400.00
0005435614443	5332	Economy	14400.00
0005435614444	5332	Economy	14400.00
0005435614441	5332	Economy	14400.00
0005434344491	5332	Economy	14400.00
0005435614524	5332	Economy	14400.00
0005435305011	5332	Economy	14400.00
0005435614504	5332	Economy	14400.00
0005435491453	5332	Economy	14400.00
0005434573456	5332	Economy	14400.00
0005435614457	5332	Economy	14400.00
0005434656548	5332	Economy	14400.00
0005435555383	5332	Economy	14400.00
0005435424816	5332	Economy	14400.00
0005434244945	5332	Economy	14400.00
0005434244962	5332	Economy	14400.00
0005434244955	5332	Economy	14400.00
0005435614459	5332	Economy	14400.00
0005435097268	5332	Economy	14400.00
0005435490257	5332	Economy	14400.00
0005432133327	5332	Economy	14400.00
0005435424815	5332	Economy	14400.00
0005435614456	5332	Economy	14400.00
0005433719131	5332	Economy	14400.00
0005435614430	5332	Economy	14400.00
0005435319541	5332	Economy	14400.00
0005435614498	5332	Economy	14400.00
0005434244973	5332	Economy	14400.00
0005434344484	5332	Economy	14400.00
0005435097272	5332	Economy	14400.00
0005435424887	5332	Economy	14400.00
0005434573453	5332	Economy	14400.00
0005435424994	5332	Economy	14400.00
0005434244984	5332	Economy	14400.00
0005435614490	5332	Economy	14400.00
0005434344478	5332	Economy	14400.00
0005435614448	5332	Economy	14400.00
0005435614429	5332	Economy	14400.00
0005435302185	5332	Economy	14400.00
0005435425013	5332	Economy	14400.00
0005435097271	5332	Economy	14400.00
0005435614488	5332	Economy	14400.00
0005434344485	5332	Economy	14400.00
0005435614501	5332	Economy	14400.00
0005434344473	5332	Economy	14400.00
0005435097270	5332	Economy	14400.00
0005435614525	5332	Economy	14400.00
0005434244916	5332	Economy	14400.00
0005435614492	5332	Economy	14400.00
0005434656547	5332	Economy	14400.00
0005435614423	5332	Economy	14400.00
0005435614516	5332	Economy	14400.00
0005435614515	5332	Economy	14400.00
0005435097274	5332	Economy	14400.00
0005435555382	5332	Economy	14400.00
0005435424583	5332	Economy	14400.00
0005435614523	5332	Economy	14400.00
0005434244861	5332	Economy	14400.00
0005435424837	5332	Economy	14400.00
0005435613398	10915	Business	43100.00
0005435425304	10915	Business	43100.00
0005434344163	10915	Business	43100.00
0005435613029	10915	Business	43100.00
0005435425297	10915	Business	43100.00
0005435425315	10915	Business	43100.00
0005434344001	10915	Business	43100.00
0005434344146	10915	Business	43100.00
0005435613523	10915	Business	43100.00
0005435425329	10915	Business	43100.00
0005435613266	10915	Business	43100.00
0005435425292	10915	Business	43100.00
0005435425284	10915	Business	43100.00
0005434573360	10915	Business	43100.00
0005435380323	10915	Business	43100.00
0005434344007	10915	Business	43100.00
0005435425336	10915	Business	43100.00
0005435613422	10915	Business	43100.00
0005435425271	10915	Business	43100.00
0005435425269	10915	Business	43100.00
0005435613177	10915	Comfort	24400.00
0005434344090	10915	Business	43100.00
0005435613648	10915	Comfort	24400.00
0005435425299	10915	Comfort	24400.00
0005433719164	10915	Comfort	24400.00
0005435613463	10915	Comfort	24400.00
0005434245197	10915	Comfort	24400.00
0005435613497	10915	Comfort	24400.00
0005435613214	10915	Comfort	24400.00
0005435613322	10915	Comfort	24400.00
0005435613476	10915	Comfort	24400.00
0005432363440	10915	Comfort	24400.00
0005434573341	10915	Comfort	24400.00
0005435613069	10915	Comfort	24400.00
0005435613068	10915	Comfort	24400.00
0005434344035	10915	Comfort	24400.00
0005435304187	10915	Comfort	24400.00
0005435613421	10915	Comfort	24400.00
0005435613684	10915	Comfort	24400.00
0005434245200	10915	Comfort	24400.00
0005435425268	10915	Comfort	24400.00
0005435319639	10915	Comfort	24400.00
0005435425331	10915	Comfort	24400.00
0005435613464	10915	Comfort	24400.00
0005435425314	10915	Comfort	24400.00
0005434344008	10915	Comfort	24400.00
0005434344114	10915	Comfort	24400.00
0005435097155	10915	Comfort	24400.00
0005435555367	10915	Comfort	24400.00
0005435097154	10915	Comfort	24400.00
0005435613075	10915	Comfort	24400.00
0005435613680	10915	Comfort	24400.00
0005434344168	10915	Comfort	24400.00
0005435319640	10915	Comfort	24400.00
0005435425278	10915	Comfort	24400.00
0005435425275	10915	Comfort	24400.00
0005435613059	10915	Comfort	24400.00
0005435613103	10915	Comfort	24400.00
0005434573340	10915	Comfort	24400.00
0005432363439	10915	Comfort	24400.00
0005434344065	10915	Comfort	24400.00
0005435613297	10915	Economy	14400.00
0005435425318	10915	Comfort	24400.00
0005434245193	10915	Economy	14400.00
0005435425326	10915	Economy	14400.00
0005435613477	10915	Economy	14400.00
0005435613451	10915	Economy	14400.00
0005435425296	10915	Economy	14400.00
0005435613440	10915	Economy	14400.00
0005435613196	10915	Economy	14400.00
0005434344034	10915	Economy	14400.00
0005435555362	10915	Economy	14400.00
0005435319637	10915	Economy	14400.00
0005435613235	10915	Economy	14400.00
0005435613475	10915	Economy	14400.00
0005435613442	10915	Economy	14400.00
0005435490201	10915	Economy	14400.00
0005434573299	10915	Economy	14400.00
0005434245198	10915	Economy	14400.00
0005435613646	10915	Economy	14400.00
0005435380324	10915	Economy	14400.00
0005433719167	10915	Economy	14400.00
0005433719166	10915	Economy	14400.00
0005435319641	10915	Economy	14400.00
0005435613543	10915	Economy	14400.00
0005434573277	10915	Economy	14400.00
0005435613679	10915	Economy	14400.00
0005434344144	10915	Economy	14400.00
0005435613634	10915	Economy	14400.00
0005432165096	10915	Economy	14400.00
0005435425327	10915	Economy	14400.00
0005432363441	10915	Economy	14400.00
0005435319634	10915	Economy	14400.00
0005434344181	10915	Economy	14400.00
0005435425312	10915	Economy	14400.00
0005435613438	10915	Economy	14400.00
0005435380326	10915	Economy	14400.00
0005435613642	10915	Economy	14400.00
0005434344069	10915	Economy	14400.00
0005434344036	10915	Economy	14400.00
0005435425295	10915	Economy	14400.00
0005435613097	10915	Economy	14400.00
0005435613488	10915	Economy	14400.00
0005435613151	10915	Economy	14400.00
0005435613205	10915	Economy	14400.00
0005434245180	10915	Economy	14400.00
0005435425321	10915	Economy	14400.00
0005435425309	10915	Economy	14400.00
0005435425302	10915	Economy	14400.00
0005434343928	10915	Economy	14400.00
0005435613566	10915	Economy	14400.00
0005435425300	10915	Economy	14400.00
0005435425328	10915	Economy	14400.00
0005434344203	10915	Economy	14400.00
0005434245187	10915	Economy	14400.00
0005435613420	10915	Economy	14400.00
0005434573249	10915	Economy	14400.00
0005435425325	10915	Economy	14400.00
0005434245207	10915	Economy	14400.00
0005435425283	10915	Economy	14400.00
0005434245179	10915	Economy	14400.00
0005434245191	10915	Economy	15800.00
0005435319638	10915	Economy	14400.00
0005434245199	10915	Economy	15800.00
0005435425285	10915	Economy	14400.00
0005434344029	10915	Economy	15800.00
0005435425274	10915	Economy	14400.00
0005435613636	10915	Economy	14400.00
0005434245201	10915	Economy	15800.00
0005435613512	10915	Economy	15800.00
0005434573290	10915	Economy	15800.00
0005435425335	10915	Economy	14400.00
0005434344119	10915	Economy	14400.00
0005435425323	10915	Economy	14400.00
0005435613647	10915	Economy	14400.00
0005435613049	10915	Economy	14400.00
0005435042871	10915	Economy	14400.00
0005435425311	10915	Economy	14400.00
0005434343977	10915	Economy	14400.00
0005435613437	10915	Economy	14400.00
0005435425273	10915	Economy	14400.00
0005432165093	10915	Economy	14400.00
0005435613593	10915	Economy	14400.00
0005435613681	10915	Economy	14400.00
0005435613643	10915	Economy	14400.00
0005435425322	10915	Economy	14400.00
0005435613478	10915	Economy	14400.00
0005434344161	10915	Economy	14400.00
0005432165089	10915	Economy	14400.00
0005434344176	10915	Economy	14400.00
0005434344143	10915	Economy	14400.00
0005435319632	10915	Economy	14400.00
0005435613542	10915	Economy	14400.00
0005435613557	10915	Economy	14400.00
0005435425279	10915	Economy	14400.00
0005435612959	10915	Economy	14400.00
0005435613513	10915	Economy	14400.00
0005434344215	10915	Economy	14400.00
0005435613462	10915	Economy	14400.00
0005435425291	10915	Economy	14400.00
0005435425303	10915	Economy	14400.00
0005435425313	10915	Economy	14400.00
0005434245178	10915	Economy	14400.00
0005435613596	10915	Economy	14400.00
0005435613412	10915	Economy	14400.00
0005434573252	10915	Economy	14400.00
0005435425308	10915	Economy	14400.00
0005432841028	10915	Economy	14400.00
0005435613074	10915	Economy	14400.00
0005435613685	10915	Economy	14400.00
0005435613416	10915	Economy	14400.00
0005435425334	10915	Economy	14400.00
0005435425330	10915	Economy	14400.00
0005435613299	10915	Economy	14400.00
0005435425317	10915	Economy	14400.00
0005435613413	10915	Economy	14400.00
0005435097180	10915	Economy	14400.00
0005434573328	10915	Economy	14400.00
0005434245203	10915	Economy	14400.00
0005435613500	10915	Economy	14400.00
0005435613382	10915	Economy	14400.00
0005434344079	10915	Economy	14400.00
0005435425282	10915	Economy	14400.00
0005434573291	10915	Economy	14400.00
0005435425267	10915	Economy	14400.00
0005435613419	10915	Economy	14400.00
0005435613236	10915	Economy	14400.00
0005432165091	10915	Economy	14400.00
0005435425319	10915	Economy	14400.00
0005435425288	10915	Economy	14400.00
0005435380327	10915	Economy	14400.00
0005432165094	10915	Economy	14400.00
0005435613383	10915	Economy	14400.00
0005435425333	10915	Economy	14400.00
0005435425316	10915	Economy	14400.00
0005434573285	10915	Economy	14400.00
0005435613522	10915	Economy	14400.00
0005435612679	10915	Economy	14400.00
0005434344020	10915	Economy	14400.00
0005435425307	10915	Economy	14400.00
0005432841030	10915	Economy	14400.00
0005434344056	10915	Economy	14400.00
0005435613508	10915	Economy	14400.00
0005435613558	10915	Economy	14400.00
0005434344091	10915	Economy	14400.00
0005435613234	10915	Economy	14400.00
0005435613305	10915	Economy	14400.00
0005434245185	10915	Economy	14400.00
0005435613630	10915	Economy	14400.00
0005435613043	10915	Economy	14400.00
0005435491438	10915	Economy	14400.00
0005434344055	10915	Economy	14400.00
0005432841029	10915	Economy	14400.00
0005435613399	10915	Economy	14400.00
0005435613682	10915	Economy	14400.00
0005434344092	10915	Economy	14400.00
0005435613453	10915	Economy	14400.00
0005434245202	10915	Economy	14400.00
0005435490216	10915	Economy	14400.00
0005435613417	10915	Economy	14400.00
0005434245186	10915	Economy	14400.00
0005435613396	10915	Economy	14400.00
0005434573212	10915	Economy	14400.00
0005435097158	10915	Economy	14400.00
0005435613132	10915	Economy	14400.00
0005435613077	10915	Economy	14400.00
0005435613499	10915	Economy	14400.00
0005435425301	10915	Economy	14400.00
0005434245205	10915	Economy	14400.00
0005435425332	10915	Economy	14400.00
0005435319636	10915	Economy	15800.00
0005435612961	10915	Economy	15800.00
0005435613531	10915	Economy	15800.00
0005434344064	10915	Economy	15800.00
0005435613060	10915	Economy	14400.00
0005435613702	10915	Economy	15800.00
0005434573311	10915	Economy	15800.00
0005434245183	10915	Economy	14400.00
0005435613381	10915	Economy	14400.00
0005435425337	10915	Economy	14400.00
0005435319633	10915	Economy	14400.00
0005435613298	10915	Economy	14400.00
0005434573322	10915	Economy	14400.00
0005435425293	10915	Economy	14400.00
0005435425298	10915	Economy	14400.00
0005435613540	10915	Economy	14400.00
0005435613541	10915	Economy	14400.00
0005435613701	10915	Economy	14400.00
0005435425310	10915	Economy	14400.00
0005435612964	10915	Economy	14400.00
0005434573320	10915	Economy	14400.00
0005434245181	10915	Economy	14400.00
0005435425272	10915	Economy	14400.00
0005435613185	10915	Economy	14400.00
0005434344160	10915	Economy	14400.00
0005435425324	10915	Economy	14400.00
0005434245182	10915	Economy	14400.00
0005435425276	10915	Economy	14400.00
0005435425305	10915	Economy	14400.00
0005434245204	10915	Economy	14400.00
0005435613443	10915	Economy	14400.00
0005434573298	10915	Economy	14400.00
0005435097156	10915	Economy	14400.00
0005434245192	10915	Economy	14400.00
0005434245177	10915	Economy	14400.00
0005435613104	10915	Economy	14400.00
0005434573336	10915	Economy	14400.00
0005435613265	10915	Economy	14400.00
0005435490229	10915	Economy	14400.00
0005435613281	10915	Economy	14400.00
0005432165092	10915	Economy	14400.00
0005434344134	10915	Economy	14400.00
0005434343969	10915	Economy	14400.00
0005434245194	10915	Economy	14400.00
0005435425294	10915	Economy	14400.00
0005434344167	10915	Economy	14400.00
0005432166926	10915	Economy	14400.00
0005434245189	10915	Economy	14400.00
0005432166925	10915	Economy	14400.00
0005434573294	10915	Economy	14400.00
0005435380325	10915	Economy	14400.00
0005435425270	10915	Economy	14400.00
0005434573337	10915	Economy	14400.00
0005435319642	10915	Economy	14400.00
0005434344147	10915	Economy	14400.00
0005432165090	10915	Economy	14400.00
0005435613637	10915	Economy	14400.00
0005435425281	10915	Economy	14400.00
0005435613501	10915	Economy	14400.00
0005434344086	10915	Economy	14400.00
0005432165095	10915	Economy	14400.00
0005434573326	10915	Economy	14400.00
0005435613197	10915	Economy	14400.00
0005435319635	10915	Economy	14400.00
0005434245196	10915	Economy	14400.00
0005434344141	10915	Economy	14400.00
0005434245188	10915	Economy	14400.00
0005434344148	10915	Economy	14400.00
0005435491437	10915	Economy	14400.00
0005435613023	10915	Economy	14400.00
0005435613380	10915	Economy	14400.00
0005435097152	10915	Economy	14400.00
0005434573325	10915	Economy	14400.00
0005432363438	10915	Economy	14400.00
0005434573321	10915	Economy	14400.00
0005435613454	10915	Economy	14400.00
0005435425286	10915	Economy	14400.00
0005435613629	10915	Economy	14400.00
0005435425277	10915	Economy	14400.00
0005434656571	10915	Economy	14400.00
0005434344109	10915	Economy	14400.00
0005435613635	10915	Economy	14400.00
0005434344084	10915	Economy	14400.00
0005434245184	10915	Economy	14400.00
0005435491435	10915	Economy	14400.00
0005433719165	10915	Economy	14400.00
0005435612987	10915	Economy	14400.00
0005435613509	10915	Economy	14400.00
0005434245190	10915	Economy	14400.00
0005434245206	10915	Economy	14400.00
0005435425306	10915	Economy	14400.00
0005434344216	10915	Economy	14400.00
0005435613489	10915	Economy	14400.00
0005434245195	10915	Economy	14400.00
0005435425320	10915	Economy	14400.00
0005432166924	10915	Economy	14400.00
0005435425287	10915	Economy	14400.00
0005435613145	10915	Economy	14400.00
0005435425290	10915	Economy	14400.00
0005435425280	10915	Economy	14400.00
0005435425289	10915	Economy	14400.00
0005433805616	3251	Business	18800.00
0005432459742	3251	Business	18800.00
0005432459611	3251	Business	18800.00
0005432181881	3251	Business	18800.00
0005432181879	3251	Business	18800.00
0005433805628	3251	Business	18800.00
0005433507304	3251	Business	18800.00
0005433634067	3251	Business	18800.00
0005432459805	3251	Business	18800.00
0005433805623	3251	Business	18800.00
0005433634069	3251	Business	18800.00
0005433634058	3251	Business	18800.00
0005432459777	3251	Business	18800.00
0005433634053	3251	Business	18800.00
0005433634051	3251	Business	18800.00
0005432181868	3251	Business	18800.00
0005432181883	3251	Business	18800.00
0005433634060	3251	Business	18800.00
0005433634055	3251	Business	18800.00
0005433805634	3251	Business	18800.00
0005432459623	3251	Business	18800.00
0005433507305	3251	Business	18800.00
0005433634075	3251	Business	18800.00
0005432181884	3251	Business	18800.00
0005432459613	3251	Business	18800.00
0005432181870	3251	Business	18800.00
0005433507318	3251	Business	18800.00
0005432459920	3251	Business	18800.00
0005433805617	3251	Economy	6900.00
0005433507317	3251	Economy	6900.00
0005433805638	3251	Economy	6900.00
0005432459546	3251	Economy	6900.00
0005432181873	3251	Economy	6900.00
0005432459727	3251	Economy	6900.00
0005432181875	3251	Economy	6300.00
0005432459894	3251	Economy	6300.00
0005433507310	3251	Economy	6300.00
0005432459754	3251	Economy	6300.00
0005432181876	3251	Economy	6300.00
0005432181888	3251	Economy	6300.00
0005433634076	3251	Economy	6300.00
0005432459661	3251	Economy	6300.00
0005433634059	3251	Economy	6300.00
0005432459941	3251	Economy	6300.00
0005433507312	3251	Economy	6300.00
0005432459780	3251	Economy	6300.00
0005433805635	3251	Economy	6300.00
0005433507316	3251	Economy	6300.00
0005433634085	3251	Economy	6300.00
0005433805619	3251	Economy	6300.00
0005432459867	3251	Economy	6300.00
0005433507319	3251	Economy	6300.00
0005432459516	3251	Economy	6300.00
0005432459919	3251	Economy	6300.00
0005433507306	3251	Economy	6300.00
0005432181874	3251	Economy	6300.00
0005433805633	3251	Economy	6300.00
0005432181878	3251	Economy	6300.00
0005432181869	3251	Economy	6300.00
0005433805640	3251	Economy	6300.00
0005432460121	3251	Economy	6300.00
0005432459688	3251	Economy	6300.00
0005433507320	3251	Economy	6300.00
0005432459897	3251	Economy	6300.00
0005432459684	3251	Economy	6300.00
0005432181885	3251	Economy	6300.00
0005432181880	3251	Economy	6300.00
0005432181886	3251	Economy	6300.00
0005433634081	3251	Economy	6300.00
0005433634072	3251	Economy	6300.00
0005433634083	3251	Economy	6300.00
0005433507308	3251	Economy	6300.00
0005432459493	3251	Economy	6300.00
0005433805629	3251	Economy	6300.00
0005432459292	3251	Economy	6300.00
0005432459725	3251	Economy	6300.00
0005433634064	3251	Economy	6300.00
0005433507303	3251	Economy	6300.00
0005433805637	3251	Economy	6300.00
0005432459735	3251	Economy	6300.00
0005433805642	3251	Economy	6300.00
0005433507313	3251	Economy	6300.00
0005433805622	3251	Economy	6300.00
0005432459612	3251	Economy	6300.00
0005432181889	3251	Economy	6300.00
0005432459617	3251	Economy	6300.00
0005433634063	3251	Economy	6300.00
0005433634068	3251	Economy	6300.00
0005432459980	3251	Economy	6300.00
0005433805618	3251	Economy	6300.00
0005432459851	3251	Economy	6300.00
0005432459547	3251	Economy	6300.00
0005433634084	3251	Economy	6300.00
0005433634062	3251	Economy	6900.00
0005433634052	3251	Economy	6900.00
0005433507321	3251	Economy	6900.00
0005432459762	3251	Economy	6900.00
0005432459837	3251	Economy	6900.00
0005433634080	3251	Economy	6300.00
0005432459873	3251	Economy	6300.00
0005432459807	3251	Economy	6300.00
0005433634077	3251	Economy	6300.00
0005433507309	3251	Economy	6900.00
0005432181871	3251	Economy	6300.00
0005433805621	3251	Economy	6300.00
0005432460071	3251	Economy	6300.00
0005433634066	3251	Economy	6300.00
0005432459610	3251	Economy	6300.00
0005432459622	3251	Economy	6300.00
0005432459750	3251	Economy	6300.00
0005433634082	3251	Economy	6300.00
0005432459594	3251	Economy	6300.00
0005433507314	3251	Economy	6300.00
0005432459721	3251	Economy	6300.00
0005433634057	3251	Economy	6300.00
0005432459598	3251	Economy	6300.00
0005432459763	3251	Economy	6300.00
0005433805632	3251	Economy	6300.00
0005432459981	3251	Economy	6300.00
0005432460072	3251	Economy	6300.00
0005432459548	3251	Economy	6300.00
0005432459806	3251	Economy	6300.00
0005433805630	3251	Economy	6300.00
0005432459660	3251	Economy	6300.00
0005432459689	3251	Economy	6300.00
0005433634074	3251	Economy	6300.00
0005433805639	3251	Economy	6300.00
0005433805636	3251	Economy	6300.00
0005432459766	3251	Economy	6300.00
0005432459690	3251	Economy	6300.00
0005433805624	3251	Economy	6300.00
0005433805620	3251	Economy	6300.00
0005433507311	3251	Economy	6300.00
0005433634071	3251	Economy	6300.00
0005433805641	3251	Economy	6300.00
0005433634061	3251	Economy	6300.00
0005433805643	3251	Economy	6300.00
0005433634054	3251	Economy	6300.00
0005433805626	3251	Economy	6300.00
0005432181882	3251	Economy	6300.00
0005433634079	3251	Economy	6300.00
0005432459629	3251	Economy	6300.00
0005432181887	3251	Economy	6300.00
0005433634078	3251	Economy	6300.00
0005432459874	3251	Economy	6300.00
0005432459804	3251	Economy	6300.00
0005433507315	3251	Economy	6300.00
0005432459492	3251	Economy	6300.00
0005432459726	3251	Economy	6300.00
0005433634073	3251	Economy	6300.00
0005433634070	3251	Economy	6300.00
0005433805625	3251	Economy	6300.00
0005433805627	3251	Economy	6300.00
0005432459888	3251	Economy	6300.00
0005432181877	3251	Economy	6300.00
0005433634056	3251	Economy	6300.00
0005432181866	3251	Economy	6300.00
0005433805631	3251	Economy	6300.00
0005432181872	3251	Economy	6300.00
0005432459850	3251	Economy	6300.00
0005433634065	3251	Economy	6300.00
0005432459597	3251	Economy	6300.00
0005432459741	3251	Economy	6300.00
0005432181867	3251	Economy	6300.00
0005433507307	3251	Economy	6300.00
0005432459982	3251	Economy	6300.00
0005432459685	3251	Economy	6300.00
0005433507302	3251	Economy	6300.00
0005435885446	3250	Business	18800.00
0005435885036	3250	Business	18800.00
0005435885218	3250	Business	18800.00
0005435885151	3250	Business	18800.00
0005435885262	3250	Business	18800.00
0005435885265	3250	Business	18800.00
0005435885025	3250	Business	18800.00
0005435885240	3250	Business	18800.00
0005435885166	3250	Economy	6900.00
0005435885294	3250	Economy	6900.00
0005435885150	3250	Economy	6900.00
0005435885452	3250	Economy	6300.00
0005435885026	3250	Economy	6300.00
0005435885241	3250	Economy	6300.00
0005435885217	3250	Economy	6300.00
0005435885221	3250	Economy	6300.00
0005435885131	3250	Economy	6300.00
0005435885263	3250	Economy	6300.00
0005435884928	3250	Economy	6300.00
0005435885162	3250	Economy	6300.00
0005435885275	3250	Economy	6300.00
0005435885427	3250	Economy	6300.00
0005435885120	3250	Economy	6300.00
0005435885149	3250	Economy	6300.00
0005435885268	3250	Economy	6300.00
0005435885332	3250	Economy	6300.00
0005435885114	3250	Economy	6300.00
0005435885357	3250	Economy	6300.00
0005435885063	3250	Economy	6300.00
0005435885267	3250	Economy	6300.00
0005435885255	3250	Economy	6900.00
0005435885281	3250	Economy	6900.00
0005435885197	3250	Economy	6300.00
0005435885066	3250	Economy	6900.00
0005435885216	3250	Economy	6300.00
0005435885074	3250	Economy	6300.00
0005435885266	3250	Economy	6300.00
0005435885202	3250	Economy	6300.00
0005435885091	3250	Economy	6300.00
0005435885198	3250	Economy	6300.00
0005435885107	3250	Economy	6300.00
0005435885051	3250	Economy	6300.00
0005435885220	3250	Economy	6300.00
0005435885242	3250	Economy	6300.00
0005435885065	3250	Economy	6300.00
0005435885219	3250	Economy	6300.00
0005435885171	3250	Economy	6300.00
0005435885426	3250	Economy	6300.00
0005435885451	3250	Economy	6300.00
0005435885092	3250	Economy	6300.00
0005435885119	3250	Economy	6300.00
0005435885292	3250	Economy	6300.00
0005435885064	3250	Economy	6300.00
0005435885293	3250	Economy	6300.00
0005432460258	8231	Business	18800.00
0005435885588	8231	Business	18800.00
0005433507088	8231	Business	18800.00
0005432460264	8231	Business	18800.00
0005432042817	8231	Business	18800.00
0005432042820	8231	Business	18800.00
0005432460248	8231	Business	18800.00
0005432460242	8231	Business	18800.00
0005432460284	8231	Business	18800.00
0005432460291	8231	Business	18800.00
0005432460271	8231	Business	18800.00
0005432460263	8231	Business	18800.00
0005435885611	8231	Business	18800.00
0005435885587	8231	Business	18800.00
0005435885598	8231	Business	18800.00
0005435885583	8231	Business	18800.00
0005432460254	8231	Business	18800.00
0005432460270	8231	Business	18800.00
0005432042819	8231	Business	18800.00
0005435885584	8231	Business	18800.00
0005433507154	8231	Business	18800.00
0005432042816	8231	Economy	6900.00
0005432460278	8231	Economy	6900.00
0005432460279	8231	Economy	6900.00
0005435885574	8231	Economy	6900.00
0005432042814	8231	Economy	6900.00
0005435885593	8231	Economy	6300.00
0005432460283	8231	Economy	6300.00
0005432460245	8231	Economy	6300.00
0005433507145	8231	Economy	6300.00
0005432460265	8231	Economy	6300.00
0005432460256	8231	Economy	6300.00
0005433507142	8231	Economy	6300.00
0005435885613	8231	Economy	6300.00
0005435885614	8231	Economy	6300.00
0005434312336	8231	Economy	6300.00
0005433507175	8231	Economy	6300.00
0005432460288	8231	Economy	6300.00
0005435885602	8231	Economy	6300.00
0005435885606	8231	Economy	6300.00
0005432460249	8231	Economy	6300.00
0005435885579	8231	Economy	6300.00
0005435885591	8231	Economy	6300.00
0005432460268	8231	Economy	6300.00
0005435885607	8231	Economy	6300.00
0005435885590	8231	Economy	6300.00
0005432460250	8231	Economy	6300.00
0005432460251	8231	Economy	6300.00
0005433507128	8231	Economy	6300.00
0005432460253	8231	Economy	6300.00
0005432460276	8231	Economy	6300.00
0005435885608	8231	Economy	6300.00
0005432042818	8231	Economy	6300.00
0005435885594	8231	Economy	6300.00
0005433507140	8231	Economy	6300.00
0005432460274	8231	Economy	6300.00
0005435885612	8231	Economy	6300.00
0005435885604	8231	Economy	6300.00
0005435885586	8231	Economy	6300.00
0005432460285	8231	Economy	6300.00
0005432460286	8231	Economy	6300.00
0005433507155	8231	Economy	6300.00
0005435885616	8231	Economy	6300.00
0005435885601	8231	Economy	6300.00
0005432460259	8231	Economy	6300.00
0005433507095	8231	Economy	6300.00
0005435885599	8231	Economy	6300.00
0005432042821	8231	Economy	6300.00
0005432042823	8231	Economy	6300.00
0005435885589	8231	Economy	6300.00
0005435885582	8231	Economy	6300.00
0005435885595	8231	Economy	6300.00
0005435885580	8231	Economy	6300.00
0005433507043	8231	Economy	6300.00
0005432460238	8231	Economy	6300.00
0005435885621	8231	Economy	6900.00
0005432460269	8231	Economy	6900.00
0005435885585	8231	Economy	6900.00
0005432460262	8231	Economy	6900.00
0005432042812	8231	Economy	6300.00
0005432460273	8231	Economy	6300.00
0005435885575	8231	Economy	6900.00
0005433507146	8231	Economy	6300.00
0005435885597	8231	Economy	6300.00
0005435885603	8231	Economy	6300.00
0005433507160	8231	Economy	6300.00
0005432460266	8231	Economy	6300.00
0005432460289	8231	Economy	6300.00
0005432460252	8231	Economy	6300.00
0005435885600	8231	Economy	6300.00
0005432460239	8231	Economy	6300.00
0005433507136	8231	Economy	6300.00
0005432042810	8231	Economy	6300.00
0005433507141	8231	Economy	6300.00
0005432460244	8231	Economy	6300.00
0005432460246	8231	Economy	6300.00
0005435885610	8231	Economy	6300.00
0005435885618	8231	Economy	6300.00
0005435885581	8231	Economy	6300.00
0005432460260	8231	Economy	6300.00
0005432460275	8231	Economy	6300.00
0005433507139	8231	Economy	6300.00
0005432460240	8231	Economy	6300.00
0005435885617	8231	Economy	6300.00
0005433507147	8231	Economy	6300.00
0005433507064	8231	Economy	6300.00
0005435885605	8231	Economy	6300.00
0005432042815	8231	Economy	6300.00
0005432460280	8231	Economy	6300.00
0005435885609	8231	Economy	6300.00
0005433507159	8231	Economy	6300.00
0005432042813	8231	Economy	6300.00
0005432460277	8231	Economy	6300.00
0005434312337	8231	Economy	6300.00
0005432460243	8231	Economy	6300.00
0005435885577	8231	Economy	6300.00
0005432460247	8231	Economy	6300.00
0005435885619	8231	Economy	6300.00
0005435885576	8231	Economy	6300.00
0005432460241	8231	Economy	6300.00
0005433507158	8231	Economy	6300.00
0005435885578	8231	Economy	6300.00
0005432460261	8231	Economy	6300.00
0005435885592	8231	Economy	6300.00
0005432042811	8231	Economy	6300.00
0005432460290	8231	Economy	6300.00
0005432460287	8231	Economy	6300.00
0005435885596	8231	Economy	6300.00
0005432460281	8231	Economy	6300.00
0005433507162	8231	Economy	6300.00
0005432042822	8231	Economy	6300.00
0005435885615	8231	Economy	6300.00
0005432460255	8231	Economy	6300.00
0005433507165	8231	Economy	6300.00
0005432460282	8231	Economy	6300.00
0005432460257	8231	Economy	6300.00
0005432460267	8231	Economy	6300.00
0005433507135	8231	Economy	6300.00
0005433507153	8231	Economy	6300.00
0005435885620	8231	Economy	6300.00
0005432460272	8231	Economy	6300.00
0005433805356	8241	Business	18800.00
0005433805253	8241	Business	18800.00
0005433805329	8241	Business	18800.00
0005433633686	8241	Business	18800.00
0005433633725	8241	Business	18800.00
0005433633764	8241	Business	18800.00
0005433633731	8241	Business	18800.00
0005433633847	8241	Business	18800.00
0005433805402	8241	Business	18800.00
0005433633687	8241	Business	18800.00
0005433805272	8241	Business	18800.00
0005433633763	8241	Business	18800.00
0005434143722	8241	Business	18800.00
0005433805307	8241	Business	18800.00
0005433633727	8241	Economy	6900.00
0005433633688	8241	Economy	6900.00
0005433633732	8241	Economy	6900.00
0005433633854	8241	Economy	6900.00
0005433805273	8241	Economy	6300.00
0005433633745	8241	Economy	6300.00
0005433633644	8241	Economy	6300.00
0005433805378	8241	Economy	6300.00
0005433805432	8241	Economy	6300.00
0005433805371	8241	Economy	6300.00
0005433805429	8241	Economy	6300.00
0005433633762	8241	Economy	6300.00
0005433633642	8241	Economy	6300.00
0005433805400	8241	Economy	6300.00
0005433805370	8241	Economy	6300.00
0005433805276	8241	Economy	6300.00
0005433805433	8241	Economy	6300.00
0005433633798	8241	Economy	6300.00
0005433805323	8241	Economy	6300.00
0005433805261	8241	Economy	6300.00
0005433805427	8241	Economy	6300.00
0005433633643	8241	Economy	6300.00
0005433633645	8241	Economy	6300.00
0005433805302	8241	Economy	6300.00
0005433805297	8241	Economy	6300.00
0005433633857	8241	Economy	6300.00
0005433805328	8241	Economy	6300.00
0005433633797	8241	Economy	6300.00
0005433805343	8241	Economy	6300.00
0005433805362	8241	Economy	6300.00
0005433805318	8241	Economy	6300.00
0005433805303	8241	Economy	6300.00
0005433633846	8241	Economy	6300.00
0005433805401	8241	Economy	6300.00
0005433633796	8241	Economy	6300.00
0005433633685	8241	Economy	6300.00
0005433805368	8241	Economy	6300.00
0005433805390	8241	Economy	6300.00
0005433633719	8241	Economy	6300.00
0005433805342	8241	Economy	6300.00
0005433633899	8241	Economy	6300.00
0005433633640	8241	Economy	6300.00
0005433805383	8241	Economy	6300.00
0005433633552	8241	Economy	6300.00
0005433633754	8241	Economy	6300.00
0005433633898	8241	Economy	6300.00
0005433805399	8241	Economy	6300.00
0005433805384	8241	Economy	6300.00
0005433805347	8241	Economy	6300.00
0005433805256	8241	Economy	6300.00
0005433633709	8241	Economy	6300.00
0005433805428	8241	Economy	6300.00
0005433633553	8241	Economy	6300.00
0005433633667	8241	Economy	6300.00
0005433805306	8241	Economy	6300.00
0005433633848	8241	Economy	6300.00
0005433805262	8241	Economy	6300.00
0005433633614	8241	Economy	6300.00
0005433633720	8241	Economy	6300.00
0005434183583	8242	Economy	6300.00
0005434183582	8242	Economy	6300.00
0005432383463	4605	Business	9900.00
0005432728035	4605	Business	9900.00
0005432383469	4605	Business	9900.00
0005432728030	4605	Business	9900.00
0005433722274	4605	Business	9900.00
0005432383453	4605	Business	9900.00
0005432383448	4605	Business	9900.00
0005433194864	4605	Business	9900.00
0005432383446	4605	Business	9900.00
0005433194870	4605	Business	9900.00
0005432383447	4605	Business	9900.00
0005432728029	4605	Economy	3300.00
0005433194866	4605	Economy	3300.00
0005433194867	4605	Economy	3300.00
0005433194863	4605	Economy	3300.00
0005432383483	4605	Economy	3300.00
0005433194869	4605	Economy	3300.00
0005433453774	4605	Economy	3300.00
0005432728032	4605	Economy	3300.00
0005432383456	4605	Economy	3300.00
0005432383457	4605	Economy	3600.00
0005432383452	4605	Economy	3600.00
0005432383449	4605	Economy	3600.00
0005432383467	4605	Economy	3300.00
0005433194875	4605	Economy	3300.00
0005433194874	4605	Economy	3300.00
0005432383445	4605	Economy	3300.00
0005432383486	4605	Economy	3300.00
0005432383458	4605	Economy	3300.00
0005433194868	4605	Economy	3300.00
0005432383473	4605	Economy	3300.00
0005432383482	4605	Economy	3300.00
0005433722276	4605	Economy	3300.00
0005432383478	4605	Economy	3300.00
0005433194872	4605	Economy	3300.00
0005432383468	4605	Economy	3300.00
0005433453773	4605	Economy	3300.00
0005432728028	4605	Economy	3300.00
0005432383460	4605	Economy	3300.00
0005433722275	4605	Economy	3300.00
0005432728024	4605	Economy	3300.00
0005432383476	4605	Economy	3300.00
0005432383479	4605	Economy	3300.00
0005432383464	4605	Economy	3300.00
0005432383444	4605	Economy	3300.00
0005432728026	4605	Economy	3300.00
0005432383450	4605	Economy	3300.00
0005432383477	4605	Economy	3300.00
0005432383481	4605	Economy	3300.00
0005433722273	4605	Economy	3300.00
0005432383466	4605	Economy	3300.00
0005432728031	4605	Economy	3300.00
0005432383474	4605	Economy	3300.00
0005432383485	4605	Economy	3300.00
0005433194873	4605	Economy	3300.00
0005432383459	4605	Economy	3300.00
0005432383472	4605	Economy	3300.00
0005432728034	4605	Economy	3300.00
0005432383484	4605	Economy	3300.00
0005432728025	4605	Economy	3300.00
0005432383480	4605	Economy	3300.00
0005432383487	4605	Economy	3300.00
0005432383465	4605	Economy	3300.00
0005432383451	4605	Economy	3300.00
0005433194862	4605	Economy	3300.00
0005432728033	4605	Economy	3300.00
0005432383471	4605	Economy	3300.00
0005432728036	4605	Economy	3300.00
0005432383475	4605	Economy	3300.00
0005432383470	4605	Economy	3300.00
0005432383461	4605	Economy	3300.00
0005433194865	4605	Economy	3300.00
0005432383462	4605	Economy	3300.00
0005432383455	4605	Economy	3300.00
0005432728027	4605	Economy	3300.00
0005432383454	4605	Economy	3300.00
0005433194871	4605	Economy	3300.00
0005433722272	4605	Economy	3300.00
0005433451614	30115	Business	9900.00
0005433722188	30115	Business	9900.00
0005432383029	30115	Business	9900.00
0005433722189	30115	Business	9900.00
0005432382916	30115	Business	9900.00
0005432727958	30115	Business	9900.00
0005433722168	30115	Business	9900.00
0005432382960	30115	Business	9900.00
0005432382872	30115	Economy	3300.00
0005432382887	30115	Economy	3300.00
0005432727931	30115	Economy	3300.00
0005432382931	30115	Economy	3300.00
0005432383032	30115	Economy	3300.00
0005432383037	30115	Economy	3300.00
0005433451613	30115	Economy	3600.00
0005432383080	30115	Economy	3600.00
0005432382934	30115	Economy	3600.00
0005432727890	30115	Economy	3600.00
0005432382982	30115	Economy	3300.00
0005432727897	30115	Economy	3300.00
0005433451615	30115	Economy	3300.00
0005432382892	30115	Economy	3300.00
0005432382997	30115	Economy	3300.00
0005432382851	30115	Economy	3300.00
0005432382885	30115	Economy	3300.00
0005432383038	30115	Economy	3300.00
0005432382810	30115	Economy	3300.00
0005432727907	30115	Economy	3300.00
0005432382852	30115	Economy	3300.00
0005432727944	30115	Economy	3300.00
0005432727915	30115	Economy	3300.00
0005432383023	30115	Economy	3300.00
0005432383010	30115	Economy	3300.00
0005432383085	30115	Economy	3300.00
0005432382976	30115	Economy	3300.00
0005432727898	30115	Economy	3300.00
0005432382990	30115	Economy	3300.00
0005432382917	30115	Economy	3300.00
0005432383025	30115	Economy	3300.00
0005432727912	30115	Economy	3300.00
0005432383028	30115	Economy	3300.00
0005432727902	30115	Economy	3300.00
0005433722197	30115	Economy	3300.00
0005432383060	30115	Economy	3300.00
0005432727932	30115	Economy	3300.00
0005432727927	30115	Economy	3300.00
0005433722177	30115	Economy	3300.00
0005433722190	30115	Economy	3300.00
0005433722198	30115	Economy	3300.00
0005432382981	30115	Economy	3300.00
0005432383056	30115	Economy	3300.00
0005432382975	30115	Economy	3300.00
0005432383031	30115	Economy	3300.00
0005433194828	30115	Economy	3300.00
0005432382886	30115	Economy	3300.00
0005432382869	30115	Economy	3300.00
0005432727911	30115	Economy	3300.00
0005432382870	30115	Economy	3300.00
0005432383024	30115	Economy	3300.00
0005432727901	30115	Economy	3300.00
0005432383081	30115	Economy	3300.00
0005432383021	30115	Economy	3300.00
0005433516956	1728	Business	57200.00
0005433516959	1728	Business	57200.00
0005435529418	1728	Business	57200.00
0005435529429	1728	Business	57200.00
0005435541164	1728	Business	57200.00
0005435529420	1728	Business	57200.00
0005435541163	1728	Business	57200.00
0005435541157	1728	Economy	19100.00
0005432925035	1728	Economy	19100.00
0005435529414	1728	Economy	19100.00
0005435541171	1728	Economy	19100.00
0005433516955	1728	Economy	19100.00
0005435529430	1728	Economy	19100.00
0005433516953	1728	Economy	19100.00
0005435529415	1728	Economy	19100.00
0005435529425	1728	Economy	19100.00
0005433516951	1728	Economy	21000.00
0005435541160	1728	Economy	21000.00
0005435541159	1728	Economy	21000.00
0005435529413	1728	Economy	21000.00
0005435541156	1728	Economy	19100.00
0005433516954	1728	Economy	19100.00
0005435529428	1728	Economy	19100.00
0005435541155	1728	Economy	19100.00
0005435529427	1728	Economy	19100.00
0005435541154	1728	Economy	19100.00
0005435541169	1728	Economy	19100.00
0005435529417	1728	Economy	19100.00
0005432925011	1728	Economy	19100.00
0005432294506	1728	Economy	19100.00
0005435529431	1728	Economy	19100.00
0005435529424	1728	Economy	19100.00
0005435541170	1728	Economy	19100.00
0005435541174	1728	Economy	19100.00
0005435529419	1728	Economy	19100.00
0005433516957	1728	Economy	19100.00
0005435541175	1728	Economy	19100.00
0005432925040	1728	Economy	19100.00
0005432925028	1728	Economy	19100.00
0005435529422	1728	Economy	19100.00
0005435529426	1728	Economy	19100.00
0005435529412	1728	Economy	19100.00
0005435529421	1728	Economy	19100.00
0005435541166	1728	Economy	19100.00
0005435529411	1728	Economy	19100.00
0005435541168	1728	Economy	19100.00
0005435541161	1728	Economy	19100.00
0005433516958	1728	Economy	19100.00
0005435541172	1728	Economy	19100.00
0005432925027	1728	Economy	19100.00
0005432294504	1728	Economy	19100.00
0005433516952	1728	Economy	19100.00
0005435529423	1728	Economy	19100.00
0005435529416	1728	Economy	19100.00
0005435541167	1728	Economy	19100.00
0005432925041	1728	Economy	19100.00
0005432294505	1728	Economy	19100.00
0005435541173	1728	Economy	19100.00
0005435541158	1728	Economy	19100.00
0005435541162	1728	Economy	19100.00
0005432925010	1728	Economy	19100.00
0005435541165	1728	Economy	19100.00
0005435541061	22017	Business	57200.00
0005432925071	22017	Business	57200.00
0005435517922	22017	Business	57200.00
0005433516892	22017	Business	57200.00
0005435517828	22017	Business	57200.00
0005433516870	22017	Business	57200.00
0005435517893	22017	Business	57200.00
0005433516908	22017	Economy	19100.00
0005435517869	22017	Economy	19100.00
0005433516869	22017	Economy	19100.00
0005435517846	22017	Economy	19100.00
0005435540914	22017	Economy	19100.00
0005433516862	22017	Economy	21000.00
0005435540873	22017	Economy	21000.00
0005435540996	22017	Economy	21000.00
0005435541010	22017	Economy	19100.00
0005435517792	22017	Economy	19100.00
0005435540980	22017	Economy	19100.00
0005435517890	22017	Economy	19100.00
0005435517918	22017	Economy	19100.00
0005433516851	22017	Economy	19100.00
0005435517912	22017	Economy	19100.00
0005435517851	22017	Economy	19100.00
0005435540951	22017	Economy	19100.00
0005435517844	22017	Economy	19100.00
0005435540936	22017	Economy	19100.00
0005435540971	22017	Economy	19100.00
0005435517904	22017	Economy	19100.00
0005435517845	22017	Economy	19100.00
0005432925072	22017	Economy	19100.00
0005435541045	22017	Economy	19100.00
0005435517957	22017	Economy	19100.00
0005433516878	22017	Economy	19100.00
0005432925070	22017	Economy	19100.00
0005435517913	22017	Economy	19100.00
0005435541009	22017	Economy	19100.00
0005435517891	22017	Economy	19100.00
0005435540838	22017	Economy	19100.00
0005432925073	22017	Economy	19100.00
0005435540839	22017	Economy	19100.00
0005435517921	22017	Economy	19100.00
0005435540970	22017	Economy	19100.00
0005433516891	22017	Economy	19100.00
0005435540957	22017	Economy	19100.00
0005432925069	22017	Economy	19100.00
0005435540907	22017	Economy	19100.00
0005433516852	22017	Economy	19100.00
0005435517829	22017	Economy	19100.00
0005433516827	22017	Economy	19100.00
0005433516879	22017	Economy	19100.00
0005435540950	22017	Economy	19100.00
0005435517898	22017	Economy	19100.00
0005435540906	22017	Economy	19100.00
0005435540963	22017	Economy	19100.00
0005435541044	22017	Economy	19100.00
0005435540956	22017	Economy	19100.00
0005432073416	7366	Business	18500.00
0005432839254	7366	Business	18500.00
0005432839248	7366	Business	18500.00
0005432839268	7366	Business	18500.00
0005432839250	7366	Business	18500.00
0005432073415	7366	Business	18500.00
0005434458951	7366	Economy	6200.00
0005432073414	7366	Economy	6200.00
0005432823463	7366	Economy	6200.00
0005432839252	7366	Economy	6200.00
0005432839271	7366	Economy	6200.00
0005432839272	7366	Economy	6200.00
0005435252693	7366	Economy	6200.00
0005434458957	7366	Economy	6200.00
0005432839253	7366	Economy	6200.00
0005434458959	7366	Economy	6800.00
0005434458952	7366	Economy	6800.00
0005435252611	7366	Economy	6800.00
0005435252711	7366	Economy	6800.00
0005434458958	7366	Economy	6200.00
0005434458963	7366	Economy	6200.00
0005435252710	7366	Economy	6200.00
0005432839255	7366	Economy	6200.00
0005434458961	7366	Economy	6200.00
0005432839256	7366	Economy	6200.00
0005434458955	7366	Economy	6200.00
0005435491434	7366	Economy	6200.00
0005435252662	7366	Economy	6200.00
0005432841025	7366	Economy	6200.00
0005432839270	7366	Economy	6200.00
0005432839245	7366	Economy	6200.00
0005432839257	7366	Economy	6200.00
0005432839265	7366	Economy	6200.00
0005434458964	7366	Economy	6200.00
0005432839275	7366	Economy	6200.00
0005435252653	7366	Economy	6200.00
0005435252621	7366	Economy	6200.00
0005434458949	7366	Economy	6200.00
0005434458962	7366	Economy	6200.00
0005435252661	7366	Economy	6200.00
0005432839269	7366	Economy	6200.00
0005435252694	7366	Economy	6200.00
0005432839262	7366	Economy	6200.00
0005432841026	7366	Economy	6200.00
0005435252674	7366	Economy	6200.00
0005434664953	7366	Economy	6200.00
0005435252751	7366	Economy	6200.00
0005432823462	7366	Economy	6200.00
0005432073417	7366	Economy	6200.00
0005432841027	7366	Economy	6200.00
0005432839264	7366	Economy	6200.00
0005432839266	7366	Economy	6200.00
0005432839258	7366	Economy	6200.00
0005434458960	7366	Economy	6200.00
0005434664949	7366	Economy	6200.00
0005434458953	7366	Economy	6200.00
0005434458965	7366	Economy	6200.00
0005435252740	7366	Economy	6200.00
0005432839274	7366	Economy	6200.00
0005434458950	7366	Economy	6200.00
0005432839261	7366	Economy	6200.00
0005432839273	7366	Economy	6200.00
0005432839259	7366	Economy	6200.00
0005435252670	7366	Economy	6200.00
0005432839251	7366	Economy	6200.00
0005434458954	7366	Economy	6200.00
0005432839247	7366	Economy	6200.00
0005432839267	7366	Economy	6200.00
0005435252741	7366	Economy	6200.00
0005432839260	7366	Economy	6200.00
0005432839263	7366	Economy	6200.00
0005434458948	7366	Economy	6200.00
0005432839246	7366	Economy	6200.00
0005434664950	7366	Economy	6200.00
0005432839249	7366	Economy	6200.00
0005435252663	7366	Economy	6200.00
0005434458947	7366	Economy	6200.00
0005435252717	7366	Economy	6200.00
0005434458956	7366	Economy	6200.00
0005432823445	28921	Business	18500.00
0005432839047	28921	Business	18500.00
0005432001038	28921	Business	18500.00
0005434664977	28921	Business	18500.00
0005434458852	28921	Business	18500.00
0005432839059	28921	Business	18500.00
0005432841009	28921	Business	18500.00
0005432839009	28921	Business	18500.00
0005432841008	28921	Business	18500.00
0005434458818	28921	Business	18500.00
0005434458858	28921	Business	18500.00
0005434458793	28921	Business	18500.00
0005434458798	28921	Economy	6200.00
0005434458690	28921	Economy	6200.00
0005434458753	28921	Economy	6200.00
0005434458807	28921	Economy	6200.00
0005434458734	28921	Economy	6200.00
0005432839073	28921	Economy	6200.00
0005434458832	28921	Economy	6200.00
0005435252830	28921	Economy	6200.00
0005434458767	28921	Economy	6200.00
0005435252832	28921	Economy	6200.00
0005434664978	28921	Economy	6800.00
0005435252835	28921	Economy	6800.00
0005434458833	28921	Economy	6800.00
0005435252821	28921	Economy	6800.00
0005434458809	28921	Economy	6800.00
0005432839154	28921	Economy	6200.00
0005434458733	28921	Economy	6200.00
0005434458853	28921	Economy	6200.00
0005432838862	28921	Economy	6200.00
0005432839057	28921	Economy	6200.00
0005432839096	28921	Economy	6200.00
0005435252825	28921	Economy	6200.00
0005434458763	28921	Economy	6200.00
0005432839004	28921	Economy	6200.00
0005434458814	28921	Economy	6200.00
0005434458736	28921	Economy	6200.00
0005434458797	28921	Economy	6200.00
0005432823447	28921	Economy	6200.00
0005435252826	28921	Economy	6200.00
0005434458754	28921	Economy	6200.00
0005432841007	28921	Economy	6200.00
0005434458819	28921	Economy	6200.00
0005432839039	28921	Economy	6200.00
0005432839005	28921	Economy	6200.00
0005432839077	28921	Economy	6200.00
0005432841010	28921	Economy	6200.00
0005432838996	28921	Economy	6200.00
0005432839040	28921	Economy	6200.00
0005432838969	28921	Economy	6200.00
0005432838995	28921	Economy	6200.00
0005432839098	28921	Economy	6200.00
0005434458854	28921	Economy	6200.00
0005434458808	28921	Economy	6200.00
0005432839048	28921	Economy	6200.00
0005432839076	28921	Economy	6200.00
0005434458741	28921	Economy	6200.00
0005434458755	28921	Economy	6200.00
0005432838987	28921	Economy	6200.00
0005432839155	28921	Economy	6200.00
0005432823446	28921	Economy	6200.00
0005434458829	28921	Economy	6200.00
0005432839082	28921	Economy	6200.00
0005435252827	28921	Economy	6200.00
0005435252834	28921	Economy	6200.00
0005435252822	28921	Economy	6200.00
0005435252823	28921	Economy	6200.00
0005434664976	28921	Economy	6200.00
0005432839019	28921	Economy	6200.00
0005432839097	28921	Economy	6200.00
0005434458828	28921	Economy	6200.00
0005434458764	28921	Economy	6200.00
0005432839036	28921	Economy	6200.00
0005432839029	28921	Economy	6200.00
0005432838944	28921	Economy	6200.00
0005435252824	28921	Economy	6200.00
0005434458794	28921	Economy	6200.00
0005434458815	28921	Economy	6200.00
0005435252836	28921	Economy	6200.00
0005432839055	28921	Economy	6200.00
0005435252833	28921	Economy	6200.00
0005435252829	28921	Economy	6200.00
0005434458820	28921	Economy	6200.00
0005432838943	28921	Economy	6200.00
0005432838976	28921	Economy	6200.00
0005432001037	28921	Economy	6200.00
0005434458777	28921	Economy	6200.00
0005434458735	28921	Economy	6200.00
0005434458742	28921	Economy	6200.00
0005435252828	28921	Economy	6200.00
0005434458766	28921	Economy	6200.00
0005432839056	28921	Economy	6200.00
0005434458792	28921	Economy	6200.00
0005435252831	28921	Economy	6200.00
0005432823450	28921	Economy	6200.00
0005432839081	28921	Economy	6200.00
0005434276017	8812	Business	145300.00
0005435990672	8812	Economy	48400.00
0005435990673	8812	Economy	48400.00
0005435990675	8812	Economy	48400.00
0005435990679	8812	Economy	48400.00
0005435990676	8812	Economy	53300.00
0005435990677	8812	Economy	48400.00
0005435990674	8812	Economy	48400.00
0005435990678	8812	Economy	48400.00
0005434276033	8812	Economy	48400.00
0005434276069	15721	Business	145300.00
0005434276068	15721	Business	145300.00
0005435990614	15721	Economy	48400.00
0005435990620	15721	Economy	48400.00
0005434276066	15721	Economy	48400.00
0005435990621	15721	Economy	48400.00
0005435990597	15721	Economy	48400.00
0005435990624	15721	Economy	48400.00
0005434276071	15721	Economy	48400.00
0005434276067	15721	Economy	48400.00
0005434276070	15721	Economy	48400.00
0005432427155	20624	Economy	14500.00
0005433476886	20624	Economy	14500.00
0005433476894	20624	Economy	14500.00
0005433476885	20624	Economy	14500.00
0005432427157	20624	Economy	14500.00
0005433476884	20624	Economy	14500.00
0005432427158	20624	Economy	14500.00
0005432427156	20624	Economy	14500.00
0005433476895	20624	Economy	14500.00
0005434149742	6359	Business	36600.00
0005432360698	6359	Business	36600.00
0005435177099	6359	Business	36600.00
0005432360724	6359	Business	36600.00
0005432360715	6359	Business	36600.00
0005432360729	6359	Business	36600.00
0005432360713	6359	Business	36600.00
0005435490201	6359	Business	36600.00
0005435177040	6359	Business	36600.00
0005435177073	6359	Business	36600.00
0005435176932	6359	Economy	12200.00
0005435490229	6359	Economy	12200.00
0005432360717	6359	Economy	12200.00
0005434149739	6359	Economy	12200.00
0005435177114	6359	Economy	12200.00
0005432360710	6359	Economy	12200.00
0005432363441	6359	Economy	12200.00
0005432336116	6359	Economy	12200.00
0005432360732	6359	Economy	12200.00
0005434149741	6359	Economy	12200.00
0005432360701	6359	Economy	12200.00
0005432336118	6359	Economy	12200.00
0005435490216	6359	Economy	12200.00
0005432360707	6359	Economy	12200.00
0005432363440	6359	Economy	12200.00
0005432360692	6359	Economy	12200.00
0005432360733	6359	Economy	12200.00
0005435177072	6359	Economy	12200.00
0005435177039	6359	Economy	12200.00
0005432336119	6359	Economy	12200.00
0005432336123	6359	Economy	12200.00
0005432360706	6359	Economy	12200.00
0005432336124	6359	Economy	12200.00
0005435177088	6359	Economy	12200.00
0005435177094	6359	Economy	12200.00
0005432360702	6359	Economy	12200.00
0005435723049	6359	Economy	12200.00
0005435177134	6359	Economy	12200.00
0005432360723	6359	Economy	12200.00
0005435723039	6359	Economy	12200.00
0005435176983	6359	Economy	12200.00
0005432360735	6359	Economy	12200.00
0005435177119	6359	Economy	12200.00
0005434149729	6359	Economy	12200.00
0005435177118	6359	Economy	12200.00
0005432360687	6359	Economy	12200.00
0005432360736	6359	Economy	12200.00
0005432360712	6359	Economy	13400.00
0005432336117	6359	Economy	13400.00
0005435176910	6359	Economy	13400.00
0005432360709	6359	Economy	13400.00
0005435177155	6359	Economy	13400.00
0005432360711	6359	Economy	12200.00
0005432360719	6359	Economy	12200.00
0005435177175	6359	Economy	12200.00
0005434149697	6359	Economy	12200.00
0005435177086	6359	Economy	12200.00
0005432062267	6359	Economy	12200.00
0005432360691	6359	Economy	12200.00
0005432360688	6359	Economy	12200.00
0005435177029	6359	Economy	12200.00
0005432360728	6359	Economy	12200.00
0005435723051	6359	Economy	12200.00
0005432336120	6359	Economy	12200.00
0005432336122	6359	Economy	12200.00
0005435177084	6359	Economy	12200.00
0005432360697	6359	Economy	12200.00
0005432336125	6359	Economy	12200.00
0005434149728	6359	Economy	12200.00
0005434149700	6359	Economy	12200.00
0005432360704	6359	Economy	12200.00
0005432360731	6359	Economy	12200.00
0005435723052	6359	Economy	12200.00
0005435177116	6359	Economy	12200.00
0005432360730	6359	Economy	12200.00
0005432360695	6359	Economy	12200.00
0005434149674	6359	Economy	12200.00
0005432360726	6359	Economy	12200.00
0005432363439	6359	Economy	12200.00
0005434149715	6359	Economy	12200.00
0005432336115	6359	Economy	12200.00
0005432062266	6359	Economy	12200.00
0005432360689	6359	Economy	12200.00
0005435177041	6359	Economy	12200.00
0005435177098	6359	Economy	12200.00
0005432336121	6359	Economy	12200.00
0005432360716	6359	Economy	12200.00
0005435177111	6359	Economy	12200.00
0005432360705	6359	Economy	12200.00
0005432062268	6359	Economy	12200.00
0005432360727	6359	Economy	12200.00
0005435177085	6359	Economy	12200.00
0005432360722	6359	Economy	12200.00
0005435177176	6359	Economy	12200.00
0005432360703	6359	Economy	12200.00
0005432360714	6359	Economy	12200.00
0005434149746	6359	Economy	12200.00
0005432062265	6359	Economy	12200.00
0005432363438	6359	Economy	12200.00
0005432360699	6359	Economy	12200.00
0005432360708	6359	Economy	12200.00
0005432360690	6359	Economy	12200.00
0005435177139	6359	Economy	12200.00
0005435177205	6359	Economy	12200.00
0005435176933	6359	Economy	12200.00
0005435176982	6359	Economy	12200.00
0005432360693	6359	Economy	12200.00
0005432360734	6359	Economy	12200.00
0005432360718	6359	Economy	12200.00
0005432360720	6359	Economy	12200.00
0005432360696	6359	Economy	12200.00
0005432360694	6359	Economy	12200.00
0005435177115	6359	Economy	12200.00
0005432062269	6359	Economy	12200.00
0005432360725	6359	Economy	12200.00
0005435177140	6359	Economy	12200.00
0005434149644	6359	Economy	12200.00
0005432360700	6359	Economy	12200.00
0005434149747	6359	Economy	12200.00
0005432336126	6359	Economy	12200.00
0005432360721	6359	Economy	12200.00
0005434149818	21025	Business	36600.00
0005432360517	21025	Business	36600.00
0005435177272	21025	Business	36600.00
0005432360135	21025	Business	36600.00
0005434149812	21025	Business	36600.00
0005435177269	21025	Business	36600.00
0005432360191	21025	Business	36600.00
0005432360326	21025	Business	36600.00
0005432336021	21025	Business	36600.00
0005435490259	21025	Business	36600.00
0005432360265	21025	Economy	12200.00
0005432336050	21025	Economy	12200.00
0005432335965	21025	Economy	12200.00
0005432360120	21025	Economy	12200.00
0005432360253	21025	Economy	12200.00
0005432360466	21025	Economy	12200.00
0005432360308	21025	Economy	12200.00
0005432052767	21025	Economy	12200.00
0005432360353	21025	Economy	12200.00
0005435177282	21025	Economy	12200.00
0005432360231	21025	Economy	12200.00
0005435177271	21025	Economy	12200.00
0005432360205	21025	Economy	12200.00
0005435177285	21025	Economy	12200.00
0005435177286	21025	Economy	12200.00
0005432336018	21025	Economy	12200.00
0005432360325	21025	Economy	12200.00
0005432336049	21025	Economy	12200.00
0005432360321	21025	Economy	12200.00
0005434149811	21025	Economy	12200.00
0005435177284	21025	Economy	12200.00
0005432360207	21025	Economy	12200.00
0005435177281	21025	Economy	12200.00
0005435177265	21025	Economy	12200.00
0005432360365	21025	Economy	12200.00
0005435177279	21025	Economy	12200.00
0005435177275	21025	Economy	12200.00
0005432336011	21025	Economy	12200.00
0005434149809	21025	Economy	12200.00
0005432360068	21025	Economy	12200.00
0005432335993	21025	Economy	12200.00
0005432360297	21025	Economy	12200.00
0005434149814	21025	Economy	12200.00
0005432360208	21025	Economy	13400.00
0005435177276	21025	Economy	13400.00
0005432335995	21025	Economy	13400.00
0005435177267	21025	Economy	13400.00
0005435177288	21025	Economy	13400.00
0005434149819	21025	Economy	13400.00
0005432360168	21025	Economy	12200.00
0005432360518	21025	Economy	12200.00
0005435177266	21025	Economy	12200.00
0005434149815	21025	Economy	12200.00
0005432360415	21025	Economy	12200.00
0005432360064	21025	Economy	12200.00
0005432360414	21025	Economy	12200.00
0005434149816	21025	Economy	12200.00
0005432360164	21025	Economy	12200.00
0005432052768	21025	Economy	12200.00
0005432360264	21025	Economy	12200.00
0005432360560	21025	Economy	12200.00
0005432360266	21025	Economy	12200.00
0005432360324	21025	Economy	12200.00
0005435177270	21025	Economy	12200.00
0005432360337	21025	Economy	12200.00
0005432336016	21025	Economy	12200.00
0005432360258	21025	Economy	12200.00
0005432363409	21025	Economy	12200.00
0005432335991	21025	Economy	12200.00
0005435177273	21025	Economy	12200.00
0005435177287	21025	Economy	12200.00
0005435177262	21025	Economy	12200.00
0005434149820	21025	Economy	12200.00
0005432360221	21025	Economy	12200.00
0005432363415	21025	Economy	12200.00
0005435177274	21025	Economy	12200.00
0005434149821	21025	Economy	12200.00
0005435177283	21025	Economy	12200.00
0005434149813	21025	Economy	12200.00
0005432360298	21025	Economy	12200.00
0005435177278	21025	Economy	12200.00
0005435177261	21025	Economy	12200.00
0005432052769	21025	Economy	12200.00
0005432360309	21025	Economy	12200.00
0005432360338	21025	Economy	12200.00
0005432360067	21025	Economy	12200.00
0005432360206	21025	Economy	12200.00
0005435490258	21025	Economy	12200.00
0005432336017	21025	Economy	12200.00
0005434149817	21025	Economy	12200.00
0005435177263	21025	Economy	12200.00
0005432360146	21025	Economy	12200.00
0005432360376	21025	Economy	12200.00
0005432360257	21025	Economy	12200.00
0005435177277	21025	Economy	12200.00
0005435723061	21025	Economy	12200.00
0005435177280	21025	Economy	12200.00
0005435177268	21025	Economy	12200.00
0005432363398	21025	Economy	12200.00
0005432360162	21025	Economy	12200.00
0005432360134	21025	Economy	12200.00
0005434149810	21025	Economy	12200.00
0005432360268	21025	Economy	12200.00
0005432360163	21025	Economy	12200.00
0005432336006	21025	Economy	12200.00
0005432363399	21025	Economy	12200.00
0005435177264	21025	Economy	12200.00
0005432335992	21025	Economy	12200.00
0005432360233	21025	Economy	12200.00
0005432360267	21025	Economy	12200.00
0005434448311	17728	Economy	3400.00
0005434448307	17728	Economy	3400.00
0005434186219	17728	Economy	3400.00
0005434458779	17728	Economy	3100.00
0005434458681	17728	Economy	3100.00
0005434458873	17728	Economy	3100.00
0005434458837	17728	Economy	3100.00
0005434458757	17728	Economy	3100.00
0005434458804	17728	Economy	3100.00
0005434463918	17728	Economy	3100.00
0005434458836	17728	Economy	3100.00
0005434448316	17728	Economy	3100.00
0005434458605	17728	Economy	3100.00
0005434461643	17728	Economy	3100.00
0005434458682	17728	Economy	3100.00
0005434458780	17728	Economy	3100.00
0005434461642	17728	Economy	3100.00
0005434458756	17728	Economy	3100.00
0005434458831	17728	Economy	3100.00
0005434463928	17728	Economy	3100.00
0005434458786	17728	Economy	3100.00
0005434461638	17728	Economy	3100.00
0005434448315	17728	Economy	3100.00
0005434458785	17728	Economy	3100.00
0005434458867	17728	Economy	3100.00
0005434461644	17728	Economy	3100.00
0005434186221	17728	Economy	3100.00
0005434458759	17728	Economy	3100.00
0005434463919	17728	Economy	3100.00
0005434186220	17728	Economy	3100.00
0005434448308	17728	Economy	3100.00
0005434448310	17728	Economy	3100.00
0005434463927	17728	Economy	3100.00
0005434458604	17728	Economy	3100.00
0005434461648	17728	Economy	3100.00
0005434461649	17728	Economy	3100.00
0005434463942	29129	Economy	3400.00
0005434463943	29129	Economy	3400.00
0005434458956	29129	Economy	3100.00
0005434458960	29129	Economy	3100.00
0005434458961	29129	Economy	3100.00
0005434458947	29129	Economy	3100.00
0005434458952	29129	Economy	3100.00
0005434458953	29129	Economy	3100.00
0005434458962	29129	Economy	3100.00
0005434458958	29129	Economy	3100.00
0005434458954	29129	Economy	3100.00
0005434458959	29129	Economy	3100.00
0005434458964	29129	Economy	3100.00
0005434458951	29129	Economy	3100.00
0005434458965	29129	Economy	3100.00
0005434186199	29129	Economy	3100.00
0005434458955	29129	Economy	3100.00
0005434458957	29129	Economy	3100.00
0005434458950	29129	Economy	3100.00
0005434448336	29129	Economy	3100.00
0005434448335	29129	Economy	3100.00
0005434458963	29129	Economy	3100.00
0005434448337	29129	Economy	3100.00
0005434462804	29129	Economy	3100.00
0005434458948	29129	Economy	3100.00
0005434458949	29129	Economy	3100.00
0005432604604	21414	Economy	7300.00
0005432604588	21414	Economy	7300.00
0005432604599	21414	Economy	7300.00
0005432604584	21414	Economy	6600.00
0005432604589	21414	Economy	6600.00
0005432604613	21414	Economy	6600.00
0005432604610	21414	Economy	6600.00
0005432604586	21414	Economy	6600.00
0005432604587	21414	Economy	6600.00
0005432604612	21414	Economy	6600.00
0005432604579	21414	Economy	6600.00
0005432604590	21414	Economy	6600.00
0005435220490	21414	Economy	6600.00
0005432604606	21414	Economy	6600.00
0005432604581	21414	Economy	6600.00
0005432604605	21414	Economy	6600.00
0005432604596	21414	Economy	6600.00
0005432604614	21414	Economy	6600.00
0005432604602	21414	Economy	6600.00
0005432604607	21414	Economy	6600.00
0005432604585	21414	Economy	6600.00
0005432604591	21414	Economy	6600.00
0005432604592	21414	Economy	6600.00
0005432604578	21414	Economy	6600.00
0005432604598	21414	Economy	6600.00
0005432604594	21414	Economy	6600.00
0005432604603	21414	Economy	6600.00
0005432604582	21414	Economy	6600.00
0005432604583	21414	Economy	6600.00
0005432604601	21414	Economy	6600.00
0005432604608	21414	Economy	6600.00
0005432604595	21414	Economy	6600.00
0005435218114	21414	Economy	6600.00
0005432604580	21414	Economy	6600.00
0005432604597	21414	Economy	6600.00
0005432604609	21414	Economy	6600.00
0005432604611	21414	Economy	6600.00
0005432604577	21414	Economy	6600.00
0005432604593	21414	Economy	6600.00
0005432604600	21414	Economy	6600.00
0005432604331	31697	Economy	7300.00
0005432604330	31697	Economy	7300.00
0005432604314	31697	Economy	7300.00
0005432604218	31697	Economy	7300.00
0005432604252	31697	Economy	6600.00
0005432604235	31697	Economy	6600.00
0005432604169	31697	Economy	6600.00
0005432604100	31697	Economy	6600.00
0005432604288	31697	Economy	6600.00
0005432604363	31697	Economy	6600.00
0005432604378	31697	Economy	6600.00
0005432604263	31697	Economy	6600.00
0005432604391	31697	Economy	6600.00
0005432604411	31697	Economy	6600.00
0005432604276	31697	Economy	6600.00
0005432604339	31697	Economy	6600.00
0005432604160	31697	Economy	6600.00
0005432604476	31697	Economy	6600.00
0005432604106	31697	Economy	6600.00
0005432604264	31697	Economy	6600.00
0005432604247	31697	Economy	6600.00
0005432604290	31697	Economy	6600.00
0005432604364	31697	Economy	6600.00
0005432604248	31697	Economy	6600.00
0005432604350	31697	Economy	6600.00
0005432603985	31697	Economy	6600.00
0005432604214	31697	Economy	6600.00
0005432604289	31697	Economy	6600.00
0005432604269	31697	Economy	6600.00
0005432604286	31697	Economy	6600.00
0005432604232	31697	Economy	6600.00
0005432604234	31697	Economy	6600.00
0005432604233	31697	Economy	6600.00
0005432604099	31697	Economy	6600.00
0005432604477	31697	Economy	6600.00
0005432604377	31697	Economy	6600.00
0005432604159	31697	Economy	6600.00
0005432604284	31697	Economy	6600.00
0005432604195	31697	Economy	6600.00
0005432604253	31697	Economy	6600.00
0005432604005	31697	Economy	6600.00
0005432604236	31697	Economy	6600.00
0005432604151	31697	Economy	6600.00
0005432604231	31697	Economy	6600.00
0005432604152	31697	Economy	6600.00
0005432604101	31697	Economy	6600.00
0005432604285	31697	Economy	6600.00
0005432604177	31697	Economy	6600.00
0005432604275	31697	Economy	6600.00
0005432603968	31697	Economy	6600.00
0005433293214	12300	Economy	19500.00
0005433293239	12300	Economy	17800.00
0005433293241	12300	Economy	17800.00
0005435154600	12300	Economy	17800.00
0005433293229	12300	Economy	17800.00
0005433293232	12300	Economy	17800.00
0005433293219	12300	Economy	17800.00
0005433293228	12300	Economy	17800.00
0005433293215	12300	Economy	17800.00
0005433293234	12300	Economy	17800.00
0005433293216	12300	Economy	17800.00
0005433293233	12300	Economy	17800.00
0005433293240	12300	Economy	17800.00
0005433293230	12300	Economy	17800.00
0005433293235	12300	Economy	17800.00
0005435154601	12300	Economy	17800.00
0005434606811	18911	Economy	6600.00
0005434606810	18911	Economy	6600.00
0005434606851	22349	Economy	6600.00
0005434604919	22349	Economy	6600.00
0005434606849	22349	Economy	6600.00
0005434606848	22349	Economy	6600.00
0005434606850	22349	Economy	6600.00
0005434604918	22349	Economy	6600.00
0005432747842	381	Business	44500.00
0005432747811	381	Business	44500.00
0005432747824	381	Business	44500.00
0005432747837	381	Business	44500.00
0005432751547	381	Business	44500.00
0005432747814	381	Business	44500.00
0005433293224	381	Business	44500.00
0005433875375	381	Business	44500.00
0005435154604	381	Business	44500.00
0005432891011	381	Business	44500.00
0005432753321	381	Economy	14800.00
0005432890986	381	Economy	14800.00
0005433875374	381	Economy	14800.00
0005432891028	381	Economy	14800.00
0005432891006	381	Economy	14800.00
0005432747841	381	Economy	14800.00
0005432891008	381	Economy	14800.00
0005432747813	381	Economy	16300.00
0005432891024	381	Economy	16300.00
0005432747829	381	Economy	16300.00
0005432747843	381	Economy	16300.00
0005432747815	381	Economy	14800.00
0005432220033	381	Economy	14800.00
0005432747826	381	Economy	14800.00
0005432747849	381	Economy	14800.00
0005432220031	381	Economy	14800.00
0005432747833	381	Economy	14800.00
0005432747832	381	Economy	14800.00
0005432753323	381	Economy	14800.00
0005432747848	381	Economy	14800.00
0005432890985	381	Economy	14800.00
0005432753322	381	Economy	14800.00
0005432747819	381	Economy	14800.00
0005432749799	381	Economy	14800.00
0005432747817	381	Economy	14800.00
0005432220034	381	Economy	14800.00
0005432747850	381	Economy	14800.00
0005432747830	381	Economy	14800.00
0005432747834	381	Economy	14800.00
0005432891002	381	Economy	14800.00
0005433293212	381	Economy	14800.00
0005432747846	381	Economy	14800.00
0005432747823	381	Economy	14800.00
0005432747827	381	Economy	14800.00
0005432747828	381	Economy	14800.00
0005432747839	381	Economy	14800.00
0005432890978	381	Economy	14800.00
0005433875376	381	Economy	14800.00
0005432747840	381	Economy	14800.00
0005432891013	381	Economy	14800.00
0005432751546	381	Economy	14800.00
0005432747844	381	Economy	14800.00
0005435154605	381	Economy	14800.00
0005432747818	381	Economy	14800.00
0005432891056	381	Economy	14800.00
0005432747821	381	Economy	14800.00
0005432747847	381	Economy	14800.00
0005432747822	381	Economy	14800.00
0005432891025	381	Economy	14800.00
0005432747816	381	Economy	14800.00
0005432747831	381	Economy	14800.00
0005435154603	381	Economy	14800.00
0005432747825	381	Economy	14800.00
0005432747845	381	Economy	14800.00
0005432747812	381	Economy	14800.00
0005435154602	381	Economy	14800.00
0005432747820	381	Economy	14800.00
0005433293251	381	Economy	14800.00
0005432747836	381	Economy	14800.00
0005432890979	381	Economy	14800.00
0005432747838	381	Economy	14800.00
0005432220032	381	Economy	14800.00
0005432751548	381	Economy	14800.00
0005432747835	381	Economy	14800.00
0005433293299	12077	Business	44500.00
0005432747715	12077	Business	44500.00
0005432747516	12077	Business	44500.00
0005433293294	12077	Business	44500.00
0005432747645	12077	Business	44500.00
0005432747427	12077	Business	44500.00
0005432747633	12077	Business	44500.00
0005433293288	12077	Business	44500.00
0005432747628	12077	Business	44500.00
0005432747360	12077	Business	44500.00
0005432747627	12077	Business	44500.00
0005433293296	12077	Economy	14800.00
0005432891160	12077	Economy	14800.00
0005433293292	12077	Economy	14800.00
0005432753292	12077	Economy	14800.00
0005432891169	12077	Economy	14800.00
0005432747254	12077	Economy	14800.00
0005432747596	12077	Economy	14800.00
0005432747569	12077	Economy	14800.00
0005432747484	12077	Economy	14800.00
0005432891163	12077	Economy	16300.00
0005432747646	12077	Economy	16300.00
0005432891165	12077	Economy	16300.00
0005432747443	12077	Economy	16300.00
0005432747558	12077	Economy	14800.00
0005432756825	12077	Economy	14800.00
0005432214820	12077	Economy	14800.00
0005432749779	12077	Economy	14800.00
0005432747716	12077	Economy	14800.00
0005432747570	12077	Economy	14800.00
0005433293298	12077	Economy	14800.00
0005432747571	12077	Economy	14800.00
0005432891166	12077	Economy	14800.00
0005433293300	12077	Economy	14800.00
0005432747605	12077	Economy	14800.00
0005432756821	12077	Economy	14800.00
0005432747649	12077	Economy	14800.00
0005432891151	12077	Economy	14800.00
0005432747468	12077	Economy	14800.00
0005432891156	12077	Economy	14800.00
0005432747644	12077	Economy	14800.00
0005432891153	12077	Economy	14800.00
0005432891152	12077	Economy	14800.00
0005432747654	12077	Economy	14800.00
0005432749786	12077	Economy	14800.00
0005432747490	12077	Economy	14800.00
0005432747477	12077	Economy	14800.00
0005432747709	12077	Economy	14800.00
0005432747542	12077	Economy	14800.00
0005432747647	12077	Economy	14800.00
0005432891164	12077	Economy	14800.00
0005432747617	12077	Economy	14800.00
0005432747632	12077	Economy	14800.00
0005432214819	12077	Economy	14800.00
0005433293286	12077	Economy	14800.00
0005432891155	12077	Economy	14800.00
0005432749785	12077	Economy	14800.00
0005432747451	12077	Economy	14800.00
0005432747643	12077	Economy	14800.00
0005432891159	12077	Economy	14800.00
0005432747426	12077	Economy	14800.00
0005432749780	12077	Economy	14800.00
0005432891167	12077	Economy	14800.00
0005432747598	12077	Economy	14800.00
0005433293297	12077	Economy	14800.00
0005432747473	12077	Economy	14800.00
0005432747629	12077	Economy	14800.00
0005432747491	12077	Economy	14800.00
0005432891162	12077	Economy	14800.00
0005432891158	12077	Economy	14800.00
0005432891157	12077	Economy	14800.00
0005432891161	12077	Economy	14800.00
0005432747430	12077	Economy	14800.00
0005432747361	12077	Economy	14800.00
0005433293290	12077	Economy	14800.00
0005432891154	12077	Economy	14800.00
0005432747502	12077	Economy	14800.00
0005432747503	12077	Economy	14800.00
0005432747459	12077	Economy	14800.00
0005432891168	12077	Economy	14800.00
0005433293293	12077	Economy	14800.00
0005433293287	12077	Economy	14800.00
0005432747458	12077	Economy	14800.00
0005432753297	12077	Economy	14800.00
0005432891150	12077	Economy	14800.00
0005432753291	12077	Economy	14800.00
0005432747655	12077	Economy	14800.00
0005433293291	12077	Economy	14800.00
0005432747543	12077	Economy	14800.00
0005433293295	12077	Economy	14800.00
0005433293289	12077	Economy	14800.00
0005432747565	12077	Economy	14800.00
0005433533332	18986	Economy	28200.00
0005433525104	18986	Economy	28200.00
0005432927997	18986	Economy	25700.00
0005433525102	18986	Economy	25700.00
0005432927961	18986	Economy	25700.00
0005433525111	18986	Economy	25700.00
0005433525112	18986	Economy	25700.00
0005433531319	18986	Economy	25700.00
0005433533333	18986	Economy	25700.00
0005433525108	18986	Economy	25700.00
0005433531317	18986	Economy	25700.00
0005432927998	18986	Economy	25700.00
0005433525109	18986	Economy	25700.00
0005433531315	18986	Economy	25700.00
0005432927977	18986	Economy	25700.00
0005433525106	18986	Economy	25700.00
0005433525110	18986	Economy	25700.00
0005433531316	18986	Economy	25700.00
0005433533331	18986	Economy	25700.00
0005433525107	18986	Economy	25700.00
0005433525105	18986	Economy	25700.00
0005432927963	18986	Economy	25700.00
0005433531318	18986	Economy	25700.00
0005432927962	18986	Economy	25700.00
0005433525103	18986	Economy	25700.00
0005432927960	18986	Economy	25700.00
0005432928026	32464	Economy	28200.00
0005432928027	32464	Economy	28200.00
0005433527252	32464	Economy	28200.00
0005432928028	32464	Economy	25700.00
0005433525043	32464	Economy	25700.00
0005432928025	32464	Economy	25700.00
0005433531278	32464	Economy	25700.00
0005433527253	32464	Economy	25700.00
0005432928024	32464	Economy	25700.00
0005433531282	32464	Economy	25700.00
0005433531291	32464	Economy	25700.00
0005432928023	32464	Economy	25700.00
0005433525008	32464	Economy	25700.00
0005433524945	32464	Economy	25700.00
0005435373130	5290	Business	84000.00
0005435661919	5290	Business	84000.00
0005435373240	5290	Business	84000.00
0005434824551	5290	Business	84000.00
0005434824460	5290	Business	84000.00
0005434824540	5290	Business	84000.00
0005434824537	5290	Business	84000.00
0005435373288	5290	Business	84000.00
0005434824452	5290	Business	84000.00
0005432121436	5290	Business	84000.00
0005435373463	5290	Business	84000.00
0005434824548	5290	Business	84000.00
0005434824445	5290	Business	84000.00
0005434824461	5290	Business	84000.00
0005435372837	5290	Business	84000.00
0005435373145	5290	Business	84000.00
0005434824454	5290	Business	84000.00
0005434831178	5290	Business	84000.00
0005434824539	5290	Business	84000.00
0005434824458	5290	Business	84000.00
0005434824484	5290	Business	84000.00
0005434824503	5290	Business	84000.00
0005432121429	5290	Business	84000.00
0005434824513	5290	Comfort	47600.00
0005435373232	5290	Comfort	47600.00
0005434828715	5290	Comfort	47600.00
0005435373315	5290	Comfort	47600.00
0005434824433	5290	Comfort	47600.00
0005435373061	5290	Comfort	47600.00
0005435373233	5290	Comfort	47600.00
0005434824545	5290	Comfort	47600.00
0005432121430	5290	Comfort	47600.00
0005434824518	5290	Comfort	47600.00
0005435373095	5290	Comfort	47600.00
0005435373129	5290	Comfort	47600.00
0005435386565	5290	Comfort	47600.00
0005434824520	5290	Comfort	47600.00
0005434824488	5290	Comfort	47600.00
0005434824509	5290	Comfort	47600.00
0005434824453	5290	Comfort	47600.00
0005434824456	5290	Comfort	47600.00
0005435373261	5290	Comfort	47600.00
0005434824481	5290	Comfort	47600.00
0005435373080	5290	Comfort	47600.00
0005434824441	5290	Comfort	47600.00
0005434824480	5290	Comfort	47600.00
0005432396274	5290	Comfort	47600.00
0005434824489	5290	Comfort	47600.00
0005432396271	5290	Comfort	47600.00
0005435150129	5290	Comfort	47600.00
0005435373199	5290	Comfort	47600.00
0005434824526	5290	Comfort	47600.00
0005435735119	5290	Comfort	47600.00
0005435373180	5290	Comfort	47600.00
0005434824442	5290	Comfort	47600.00
0005434824435	5290	Comfort	47600.00
0005434824487	5290	Comfort	47600.00
0005434824429	5290	Comfort	47600.00
0005432394136	5290	Economy	28000.00
0005434824517	5290	Economy	28000.00
0005435372886	5290	Economy	28000.00
0005434824437	5290	Economy	28000.00
0005434824443	5290	Economy	28000.00
0005432394133	5290	Economy	28000.00
0005435373339	5290	Economy	28000.00
0005435373342	5290	Economy	28000.00
0005434824493	5290	Economy	28000.00
0005435304185	5290	Economy	28000.00
0005435386558	5290	Economy	28000.00
0005435373133	5290	Economy	28000.00
0005434824464	5290	Economy	28000.00
0005434824504	5290	Economy	28000.00
0005435373406	5290	Economy	28000.00
0005434824495	5290	Economy	28000.00
0005435150126	5290	Economy	28000.00
0005435373523	5290	Economy	28000.00
0005435150131	5290	Economy	28000.00
0005434824538	5290	Economy	28000.00
0005434824486	5290	Economy	28000.00
0005435735113	5290	Economy	28000.00
0005435373149	5290	Economy	28000.00
0005434824505	5290	Economy	28000.00
0005434824439	5290	Economy	28000.00
0005434824469	5290	Economy	28000.00
0005434824436	5290	Economy	28000.00
0005434824512	5290	Economy	28000.00
0005434824470	5290	Economy	28000.00
0005434824500	5290	Economy	28000.00
0005435373464	5290	Economy	28000.00
0005434824438	5290	Economy	28000.00
0005434824490	5290	Economy	28000.00
0005435373291	5290	Economy	28000.00
0005434824544	5290	Economy	28000.00
0005432121438	5290	Economy	28000.00
0005434824514	5290	Economy	28000.00
0005434824546	5290	Economy	28000.00
0005432396272	5290	Economy	28000.00
0005434824491	5290	Economy	28000.00
0005434831182	5290	Economy	28000.00
0005434824552	5290	Economy	28000.00
0005435372967	5290	Economy	28000.00
0005435150121	5290	Economy	28000.00
0005434824496	5290	Economy	28000.00
0005435372909	5290	Economy	28000.00
0005434824447	5290	Economy	28000.00
0005434824477	5290	Economy	30800.00
0005434824530	5290	Economy	30800.00
0005434824475	5290	Economy	28000.00
0005435386559	5290	Economy	30800.00
0005434831181	5290	Economy	28000.00
0005434824459	5290	Economy	30800.00
0005434824473	5290	Economy	28000.00
0005432121442	5290	Economy	28000.00
0005434828713	5290	Economy	28000.00
0005434824455	5290	Economy	28000.00
0005434824451	5290	Economy	28000.00
0005434824468	5290	Economy	28000.00
0005434824492	5290	Economy	28000.00
0005432121431	5290	Economy	28000.00
0005435373265	5290	Economy	28000.00
0005435373051	5290	Economy	28000.00
0005435661920	5290	Economy	28000.00
0005432121435	5290	Economy	28000.00
0005435150123	5290	Economy	28000.00
0005434824444	5290	Economy	28000.00
0005432394132	5290	Economy	28000.00
0005435150132	5290	Economy	28000.00
0005434824478	5290	Economy	28000.00
0005432121433	5290	Economy	28000.00
0005435150122	5290	Economy	28000.00
0005435373507	5290	Economy	28000.00
0005434824450	5290	Economy	28000.00
0005434824516	5290	Economy	28000.00
0005434824494	5290	Economy	28000.00
0005434824498	5290	Economy	28000.00
0005434824474	5290	Economy	28000.00
0005435735126	5290	Economy	28000.00
0005435373069	5290	Economy	28000.00
0005434824483	5290	Economy	28000.00
0005435373006	5290	Economy	28000.00
0005434824479	5290	Economy	28000.00
0005435373216	5290	Economy	28000.00
0005434824543	5290	Economy	28000.00
0005434824524	5290	Economy	28000.00
0005434824535	5290	Economy	28000.00
0005435372938	5290	Economy	28000.00
0005434824446	5290	Economy	28000.00
0005435373506	5290	Economy	28000.00
0005434824430	5290	Economy	28000.00
0005435150120	5290	Economy	28000.00
0005435304157	5290	Economy	28000.00
0005435373235	5290	Economy	28000.00
0005435150124	5290	Economy	28000.00
0005435373598	5290	Economy	28000.00
0005434824463	5290	Economy	28000.00
0005435373202	5290	Economy	28000.00
0005434824467	5290	Economy	28000.00
0005434824547	5290	Economy	28000.00
0005435150130	5290	Economy	28000.00
0005434824525	5290	Economy	28000.00
0005434824510	5290	Economy	28000.00
0005435373081	5290	Economy	28000.00
0005434824522	5290	Economy	28000.00
0005434664975	5290	Economy	28000.00
0005435373128	5290	Economy	28000.00
0005434824542	5290	Economy	28000.00
0005434824515	5290	Economy	28000.00
0005434824557	5290	Economy	28000.00
0005435373356	5290	Economy	28000.00
0005434824431	5290	Economy	28000.00
0005435150133	5290	Economy	28000.00
0005435299786	5290	Economy	28000.00
0005432121432	5290	Economy	28000.00
0005435373264	5290	Economy	28000.00
0005434824499	5290	Economy	28000.00
0005434824549	5290	Economy	28000.00
0005434824511	5290	Economy	28000.00
0005434664974	5290	Economy	28000.00
0005435373112	5290	Economy	28000.00
0005435150125	5290	Economy	28000.00
0005435372896	5290	Economy	28000.00
0005434824462	5290	Economy	28000.00
0005435373260	5290	Economy	28000.00
0005435150127	5290	Economy	28000.00
0005434824534	5290	Economy	28000.00
0005434824550	5290	Economy	28000.00
0005434831180	5290	Economy	30800.00
0005435373041	5290	Economy	30800.00
0005434824533	5290	Economy	30800.00
0005434824501	5290	Economy	30800.00
0005435735118	5290	Economy	28000.00
0005435304148	5290	Economy	28000.00
0005432394135	5290	Economy	28000.00
0005432121434	5290	Economy	28000.00
0005435373407	5290	Economy	28000.00
0005434824556	5290	Economy	28000.00
0005435373052	5290	Economy	28000.00
0005434824528	5290	Economy	28000.00
0005434824482	5290	Economy	28000.00
0005435373028	5290	Economy	28000.00
0005435150128	5290	Economy	28000.00
0005434824541	5290	Economy	28000.00
0005434828714	5290	Economy	28000.00
0005435735102	5290	Economy	28000.00
0005434824508	5290	Economy	28000.00
0005434824536	5290	Economy	28000.00
0005435373127	5290	Economy	28000.00
0005434824471	5290	Economy	28000.00
0005434824527	5290	Economy	28000.00
0005435150134	5290	Economy	28000.00
0005432823440	5290	Economy	28000.00
0005434824529	5290	Economy	28000.00
0005434831179	5290	Economy	28000.00
0005434824531	5290	Economy	28000.00
0005432121440	5290	Economy	28000.00
0005435386557	5290	Economy	28000.00
0005434824506	5290	Economy	28000.00
0005434824457	5290	Economy	28000.00
0005435373207	5290	Economy	28000.00
0005434824448	5290	Economy	28000.00
0005435299787	5290	Economy	28000.00
0005434824555	5290	Economy	28000.00
0005434824553	5290	Economy	28000.00
0005434824432	5290	Economy	28000.00
0005435373027	5290	Economy	28000.00
0005435373290	5290	Economy	28000.00
0005434824465	5290	Economy	28000.00
0005432394134	5290	Economy	28000.00
0005435373056	5290	Economy	28000.00
0005435373107	5290	Economy	28000.00
0005432121439	5290	Economy	28000.00
0005432121441	5290	Economy	28000.00
0005435373179	5290	Economy	28000.00
0005432396273	5290	Economy	28000.00
0005434824497	5290	Economy	28000.00
0005434824466	5290	Economy	28000.00
0005434824440	5290	Economy	28000.00
0005432394131	5290	Economy	28000.00
0005435372968	5290	Economy	28000.00
0005434824449	5290	Economy	28000.00
0005434824476	5290	Economy	28000.00
0005435386569	5290	Economy	28000.00
0005434824532	5290	Economy	28000.00
0005435386568	5290	Economy	28000.00
0005435372887	5290	Economy	28000.00
0005434824523	5290	Economy	28000.00
0005432121437	5290	Economy	28000.00
0005435373126	5290	Economy	28000.00
0005435372927	5290	Economy	28000.00
0005434824428	5290	Economy	28000.00
0005435386567	5290	Economy	28000.00
0005434824507	5290	Economy	28000.00
0005435373258	5290	Economy	28000.00
0005434824554	5290	Economy	28000.00
0005434824434	5290	Economy	28000.00
0005434824521	5290	Economy	28000.00
0005434824502	5290	Economy	28000.00
0005434824472	5290	Economy	28000.00
0005435372833	5290	Economy	28000.00
0005435373150	5290	Economy	28000.00
0005435373065	5290	Economy	28000.00
0005434824485	5290	Economy	28000.00
0005434824519	5290	Economy	28000.00
0005434823770	9882	Business	84000.00
0005435149941	9882	Business	84000.00
0005435373713	9882	Business	84000.00
0005434823490	9882	Business	84000.00
0005434822823	9882	Business	84000.00
0005434823438	9882	Business	84000.00
0005434823172	9882	Business	84000.00
0005434823411	9882	Business	84000.00
0005434828694	9882	Business	84000.00
0005435373716	9882	Business	84000.00
0005435373757	9882	Business	84000.00
0005434558237	9882	Business	84000.00
0005435373720	9882	Business	84000.00
0005435373727	9882	Business	84000.00
0005434823605	9882	Business	84000.00
0005435373730	9882	Business	84000.00
0005435373695	9882	Business	84000.00
0005434558247	9882	Business	84000.00
0005432400120	9882	Business	84000.00
0005434822891	9882	Business	84000.00
0005435373751	9882	Business	84000.00
0005434823378	9882	Business	84000.00
0005435150003	9882	Comfort	47600.00
0005434823176	9882	Comfort	47600.00
0005435373759	9882	Comfort	47600.00
0005434823302	9882	Comfort	47600.00
0005435373741	9882	Comfort	47600.00
0005432396239	9882	Comfort	47600.00
0005435386614	9882	Comfort	47600.00
0005435373728	9882	Comfort	47600.00
0005435373749	9882	Comfort	47600.00
0005435373745	9882	Comfort	47600.00
0005435149994	9882	Comfort	47600.00
0005434823480	9882	Comfort	47600.00
0005434823769	9882	Comfort	47600.00
0005435386619	9882	Comfort	47600.00
0005434558233	9882	Comfort	47600.00
0005432400110	9882	Comfort	47600.00
0005435386620	9882	Comfort	47600.00
0005435373696	9882	Comfort	47600.00
0005435373711	9882	Comfort	47600.00
0005435373715	9882	Comfort	47600.00
0005435149984	9882	Comfort	47600.00
0005432203118	9882	Comfort	47600.00
0005434823053	9882	Comfort	47600.00
0005434823821	9882	Comfort	47600.00
0005435373705	9882	Comfort	47600.00
0005434823175	9882	Comfort	47600.00
0005435373697	9882	Comfort	47600.00
0005435302229	9882	Economy	28000.00
0005434823430	9882	Comfort	47600.00
0005435149986	9882	Economy	28000.00
0005434823764	9882	Economy	28000.00
0005435373743	9882	Economy	28000.00
0005435302234	9882	Economy	28000.00
0005434823538	9882	Economy	28000.00
0005432203115	9882	Economy	28000.00
0005432823465	9882	Economy	28000.00
0005435373750	9882	Economy	28000.00
0005434823440	9882	Economy	28000.00
0005435386615	9882	Economy	28000.00
0005434823147	9882	Economy	28000.00
0005434824040	9882	Economy	28000.00
0005434823601	9882	Economy	28000.00
0005435299808	9882	Economy	28000.00
0005434823704	9882	Economy	28000.00
0005434823728	9882	Economy	28000.00
0005434823294	9882	Economy	28000.00
0005434823680	9882	Economy	28000.00
0005435179401	9882	Economy	28000.00
0005435373735	9882	Economy	28000.00
0005434823043	9882	Economy	28000.00
0005435150012	9882	Economy	28000.00
0005435373726	9882	Economy	28000.00
0005434823504	9882	Economy	28000.00
0005434822824	9882	Economy	28000.00
0005434823978	9882	Economy	28000.00
0005434823323	9882	Economy	28000.00
0005434831153	9882	Economy	28000.00
0005434824041	9882	Economy	28000.00
0005435149995	9882	Economy	28000.00
0005434823576	9882	Economy	28000.00
0005434823173	9882	Economy	28000.00
0005434823745	9882	Economy	28000.00
0005435373701	9882	Economy	28000.00
0005434823609	9882	Economy	28000.00
0005434558240	9882	Economy	28000.00
0005435373733	9882	Economy	28000.00
0005435149997	9882	Economy	28000.00
0005434823300	9882	Economy	28000.00
0005435302230	9882	Economy	28000.00
0005434823697	9882	Economy	28000.00
0005435302231	9882	Economy	28000.00
0005434558260	9882	Economy	28000.00
0005434823365	9882	Economy	28000.00
0005435373712	9882	Economy	28000.00
0005434823424	9882	Economy	28000.00
0005435373734	9882	Economy	28000.00
0005434822777	9882	Economy	28000.00
0005434828691	9882	Economy	28000.00
0005435373704	9882	Economy	28000.00
0005435149940	9882	Economy	30800.00
0005435661953	9882	Economy	28000.00
0005435373755	9882	Economy	30800.00
0005432396243	9882	Economy	28000.00
0005434823848	9882	Economy	28000.00
0005435373732	9882	Economy	28000.00
0005435373725	9882	Economy	28000.00
0005435386618	9882	Economy	28000.00
0005434823506	9882	Economy	28000.00
0005435373754	9882	Economy	28000.00
0005434823505	9882	Economy	28000.00
0005434823762	9882	Economy	28000.00
0005434823638	9882	Economy	28000.00
0005435373699	9882	Economy	28000.00
0005434823226	9882	Economy	28000.00
0005434823412	9882	Economy	28000.00
0005434823952	9882	Economy	28000.00
0005435735169	9882	Economy	28000.00
0005434823496	9882	Economy	28000.00
0005432400118	9882	Economy	28000.00
0005434822892	9882	Economy	28000.00
0005435150053	9882	Economy	28000.00
0005435373760	9882	Economy	28000.00
0005434558250	9882	Economy	28000.00
0005435373747	9882	Economy	28000.00
0005435373761	9882	Economy	28000.00
0005435373739	9882	Economy	28000.00
0005435373703	9882	Economy	28000.00
0005434823393	9882	Economy	28000.00
0005435373752	9882	Economy	28000.00
0005435373714	9882	Economy	28000.00
0005434823060	9882	Economy	28000.00
0005434823631	9882	Economy	28000.00
0005434823391	9882	Economy	28000.00
0005435150050	9882	Economy	28000.00
0005434828693	9882	Economy	28000.00
0005434823431	9882	Economy	28000.00
0005434823437	9882	Economy	28000.00
0005434823681	9882	Economy	28000.00
0005435373744	9882	Economy	28000.00
0005435373702	9882	Economy	28000.00
0005434822902	9882	Economy	28000.00
0005435661952	9882	Economy	28000.00
0005434664954	9882	Economy	28000.00
0005435373762	9882	Economy	28000.00
0005435302232	9882	Economy	28000.00
0005435299809	9882	Economy	28000.00
0005434558236	9882	Economy	28000.00
0005435373719	9882	Economy	28000.00
0005435386616	9882	Economy	28000.00
0005435373700	9882	Economy	28000.00
0005434823705	9882	Economy	28000.00
0005434831154	9882	Economy	28000.00
0005434823781	9882	Economy	28000.00
0005435373722	9882	Economy	28000.00
0005434822811	9882	Economy	28000.00
0005434823385	9882	Economy	28000.00
0005435735172	9882	Economy	28000.00
0005434823044	9882	Economy	28000.00
0005434823392	9882	Economy	28000.00
0005435150002	9882	Economy	28000.00
0005435150051	9882	Economy	28000.00
0005434823628	9882	Economy	28000.00
0005434823612	9882	Economy	28000.00
0005435373724	9882	Economy	28000.00
0005435373717	9882	Economy	28000.00
0005435735170	9882	Economy	28000.00
0005434823573	9882	Economy	28000.00
0005434823635	9882	Economy	28000.00
0005434823858	9882	Economy	28000.00
0005435373729	9882	Economy	28000.00
0005434823388	9882	Economy	28000.00
0005434823189	9882	Economy	28000.00
0005434831152	9882	Economy	28000.00
0005434823799	9882	Economy	28000.00
0005434558246	9882	Economy	28000.00
0005434558249	9882	Economy	28000.00
0005434823047	9882	Economy	28000.00
0005434822968	9882	Economy	28000.00
0005434823510	9882	Economy	28000.00
0005434823066	9882	Economy	28000.00
0005435735171	9882	Economy	28000.00
0005434831159	9882	Economy	28000.00
0005432203113	9882	Economy	28000.00
0005432203111	9882	Economy	28000.00
0005434828692	9882	Economy	28000.00
0005434823303	9882	Economy	28000.00
0005435373709	9882	Economy	28000.00
0005434823001	9882	Economy	30800.00
0005434823293	9882	Economy	30800.00
0005435373706	9882	Economy	30800.00
0005435179400	9882	Economy	28000.00
0005434823265	9882	Economy	28000.00
0005435373721	9882	Economy	28000.00
0005435373723	9882	Economy	28000.00
0005432203119	9882	Economy	28000.00
0005434823156	9882	Economy	28000.00
0005435373738	9882	Economy	28000.00
0005435373710	9882	Economy	28000.00
0005432203116	9882	Economy	28000.00
0005432203114	9882	Economy	28000.00
0005434664957	9882	Economy	28000.00
0005432203112	9882	Economy	28000.00
0005434822907	9882	Economy	28000.00
0005434823389	9882	Economy	28000.00
0005435373707	9882	Economy	28000.00
0005434823627	9882	Economy	28000.00
0005434823425	9882	Economy	28000.00
0005435373740	9882	Economy	28000.00
0005434823602	9882	Economy	28000.00
0005434823604	9882	Economy	28000.00
0005434823439	9882	Economy	28000.00
0005434823610	9882	Economy	28000.00
0005434823465	9882	Economy	28000.00
0005435373758	9882	Economy	28000.00
0005434823577	9882	Economy	28000.00
0005434822908	9882	Economy	28000.00
0005435150010	9882	Economy	28000.00
0005434823489	9882	Economy	28000.00
0005434823780	9882	Economy	28000.00
0005434558232	9882	Economy	28000.00
0005435373737	9882	Economy	28000.00
0005434823761	9882	Economy	28000.00
0005432400114	9882	Economy	28000.00
0005435373748	9882	Economy	28000.00
0005435373746	9882	Economy	28000.00
0005435373708	9882	Economy	28000.00
0005435386617	9882	Economy	28000.00
0005432400121	9882	Economy	28000.00
0005434823853	9882	Economy	28000.00
0005434558238	9882	Economy	28000.00
0005435386613	9882	Economy	28000.00
0005434558241	9882	Economy	28000.00
0005435373753	9882	Economy	28000.00
0005435373736	9882	Economy	28000.00
0005435299810	9882	Economy	28000.00
0005434823814	9882	Economy	28000.00
0005434823160	9882	Economy	28000.00
0005434823304	9882	Economy	28000.00
0005434558243	9882	Economy	28000.00
0005434823637	9882	Economy	28000.00
0005434823894	9882	Economy	28000.00
0005434823466	9882	Economy	28000.00
0005434823046	9882	Economy	28000.00
0005434823820	9882	Economy	28000.00
0005434823813	9882	Economy	28000.00
0005435302233	9882	Economy	28000.00
0005434823188	9882	Economy	28000.00
0005435735168	9882	Economy	28000.00
0005434823048	9882	Economy	28000.00
0005434824139	9882	Economy	28000.00
0005435150009	9882	Economy	28000.00
0005434831158	9882	Economy	28000.00
0005435373731	9882	Economy	28000.00
0005434823216	9882	Economy	28000.00
0005432823464	9882	Economy	28000.00
0005434823290	9882	Economy	28000.00
0005435299807	9882	Economy	28000.00
0005434823849	9882	Economy	28000.00
0005434558242	9882	Economy	28000.00
0005435373742	9882	Economy	28000.00
0005432203117	9882	Economy	28000.00
0005435299811	9882	Economy	28000.00
0005435373718	9882	Economy	28000.00
0005435373756	9882	Economy	28000.00
0005434823227	9882	Economy	28000.00
0005434823497	9882	Economy	28000.00
0005434828695	9882	Economy	28000.00
0005435373698	9882	Economy	28000.00
0005432823466	9882	Economy	28000.00
0005434823509	9882	Economy	28000.00
0005435082846	7025	Economy	8200.00
0005435790327	7025	Economy	7400.00
0005435082842	7025	Economy	7400.00
0005435082849	7025	Economy	7400.00
0005435082845	7025	Economy	7400.00
0005435082841	7025	Economy	7400.00
0005435790326	7025	Economy	7400.00
0005435082843	7025	Economy	7400.00
0005435082850	7025	Economy	7400.00
0005435790328	7025	Economy	7400.00
0005435082848	7025	Economy	7400.00
0005435082844	7025	Economy	7400.00
0005435082847	7025	Economy	7400.00
0005435082780	26023	Economy	7400.00
0005435082770	26023	Economy	7400.00
0005434756722	9561	Business	32800.00
0005434756726	9561	Business	32800.00
0005434756729	9561	Business	32800.00
0005434756745	9561	Business	32800.00
0005434756717	9561	Business	32800.00
0005434214428	9561	Business	32800.00
0005434214444	9561	Business	32800.00
0005434756734	9561	Business	32800.00
0005434756744	9561	Business	32800.00
0005434214481	9561	Business	32800.00
0005434214416	9561	Economy	10900.00
0005434214342	9561	Economy	10900.00
0005434756715	9561	Economy	10900.00
0005434214530	9561	Economy	10900.00
0005434756713	9561	Economy	10900.00
0005434214500	9561	Economy	10900.00
0005434214384	9561	Economy	10900.00
0005434214578	9561	Economy	10900.00
0005434756733	9561	Economy	10900.00
0005434214482	9561	Economy	12000.00
0005434214531	9561	Economy	12000.00
0005434214393	9561	Economy	12000.00
0005434214357	9561	Economy	12000.00
0005434214339	9561	Economy	12000.00
0005434756741	9561	Economy	10900.00
0005434214483	9561	Economy	10900.00
0005434756731	9561	Economy	10900.00
0005434214315	9561	Economy	10900.00
0005434756740	9561	Economy	10900.00
0005434214348	9561	Economy	10900.00
0005434214460	9561	Economy	10900.00
0005434756730	9561	Economy	10900.00
0005434214590	9561	Economy	10900.00
0005434214405	9561	Economy	10900.00
0005434214365	9561	Economy	10900.00
0005434756714	9561	Economy	10900.00
0005434756743	9561	Economy	10900.00
0005434214328	9561	Economy	10900.00
0005434756721	9561	Economy	10900.00
0005434756727	9561	Economy	10900.00
0005434756732	9561	Economy	10900.00
0005434756716	9561	Economy	10900.00
0005434756742	9561	Economy	10900.00
0005434214364	9561	Economy	10900.00
0005434756735	9561	Economy	10900.00
0005434214441	9561	Economy	10900.00
0005434214410	9561	Economy	10900.00
0005434214334	9561	Economy	10900.00
0005434756739	9561	Economy	10900.00
0005434756746	9561	Economy	10900.00
0005434214579	9561	Economy	10900.00
0005434214459	9561	Economy	10900.00
0005434756724	9561	Economy	10900.00
0005434756728	9561	Economy	10900.00
0005434756720	9561	Economy	10900.00
0005434214396	9561	Economy	10900.00
0005434214503	9561	Economy	10900.00
0005434214496	9561	Economy	10900.00
0005434214402	9561	Economy	10900.00
0005434214407	9561	Economy	10900.00
0005434214406	9561	Economy	10900.00
0005434214469	9561	Economy	10900.00
0005434756712	9561	Economy	10900.00
0005434214343	9561	Economy	10900.00
0005434214392	9561	Economy	10900.00
0005434756738	9561	Economy	10900.00
0005434756725	9561	Economy	10900.00
0005434214316	9561	Economy	10900.00
0005434214394	9561	Economy	10900.00
0005434756723	9561	Economy	10900.00
0005434214415	9561	Economy	10900.00
0005434214422	9561	Economy	10900.00
0005434214248	9561	Economy	10900.00
0005434214385	9561	Economy	10900.00
0005434214311	9561	Economy	10900.00
0005434214495	9561	Economy	10900.00
0005434214395	9561	Economy	10900.00
0005434756719	9561	Economy	10900.00
0005434756736	9561	Economy	10900.00
0005434214386	9561	Economy	10900.00
0005434756737	9561	Economy	10900.00
0005434214475	9561	Economy	10900.00
0005434756718	9561	Economy	10900.00
0005434214401	9561	Economy	10900.00
0005434756188	28596	Business	32800.00
0005434214820	28596	Business	32800.00
0005434756257	28596	Business	32800.00
0005434214812	28596	Business	32800.00
0005434214798	28596	Business	32800.00
0005434756293	28596	Business	32800.00
0005434214794	28596	Business	32800.00
0005434214827	28596	Business	32800.00
0005434756240	28596	Business	32800.00
0005434756305	28596	Business	32800.00
0005434756155	28596	Business	32800.00
0005434756332	28596	Economy	10900.00
0005434756326	28596	Economy	10900.00
0005434214795	28596	Economy	10900.00
0005434756154	28596	Economy	10900.00
0005434214833	28596	Economy	10900.00
0005434756349	28596	Economy	10900.00
0005434214800	28596	Economy	10900.00
0005434214830	28596	Economy	10900.00
0005434214832	28596	Economy	12000.00
0005434756351	28596	Economy	12000.00
0005434756187	28596	Economy	12000.00
0005434214828	28596	Economy	12000.00
0005434214793	28596	Economy	10900.00
0005434756350	28596	Economy	10900.00
0005434756246	28596	Economy	10900.00
0005434756283	28596	Economy	10900.00
0005434214811	28596	Economy	10900.00
0005434214807	28596	Economy	10900.00
0005434756289	28596	Economy	10900.00
0005434756333	28596	Economy	10900.00
0005434214803	28596	Economy	10900.00
0005434756327	28596	Economy	10900.00
0005434214825	28596	Economy	10900.00
0005434756313	28596	Economy	10900.00
0005434214801	28596	Economy	10900.00
0005434214806	28596	Economy	10900.00
0005434214816	28596	Economy	10900.00
0005434756256	28596	Economy	10900.00
0005434214838	28596	Economy	10900.00
0005434214797	28596	Economy	10900.00
0005434214829	28596	Economy	10900.00
0005434756335	28596	Economy	10900.00
0005434214831	28596	Economy	10900.00
0005434214796	28596	Economy	10900.00
0005434214836	28596	Economy	10900.00
0005434214839	28596	Economy	10900.00
0005434214815	28596	Economy	10900.00
0005434756201	28596	Economy	10900.00
0005434756265	28596	Economy	10900.00
0005434756334	28596	Economy	10900.00
0005434214823	28596	Economy	10900.00
0005434756215	28596	Economy	10900.00
0005434756282	28596	Economy	10900.00
0005434756321	28596	Economy	10900.00
0005434214821	28596	Economy	10900.00
0005434756090	28596	Economy	10900.00
0005434755984	28596	Economy	10900.00
0005434756247	28596	Economy	10900.00
0005434756331	28596	Economy	10900.00
0005434756231	28596	Economy	10900.00
0005434756156	28596	Economy	10900.00
0005434214814	28596	Economy	10900.00
0005434214824	28596	Economy	10900.00
0005434756320	28596	Economy	10900.00
0005434214808	28596	Economy	10900.00
0005434756216	28596	Economy	10900.00
0005434756345	28596	Economy	10900.00
0005434756195	28596	Economy	10900.00
0005434214809	28596	Economy	10900.00
0005434756319	28596	Economy	10900.00
0005434214810	28596	Economy	10900.00
0005434756196	28596	Economy	10900.00
0005434756235	28596	Economy	10900.00
0005434214799	28596	Economy	10900.00
0005434214805	28596	Economy	10900.00
0005434214826	28596	Economy	10900.00
0005434214802	28596	Economy	10900.00
0005434214837	28596	Economy	10900.00
0005434214835	28596	Economy	10900.00
0005434214817	28596	Economy	10900.00
0005434214818	28596	Economy	10900.00
0005434214834	28596	Economy	10900.00
0005434214819	28596	Economy	10900.00
0005434214822	28596	Economy	10900.00
0005434756306	28596	Economy	10900.00
0005434214804	28596	Economy	10900.00
0005434214813	28596	Economy	10900.00
0005435100145	10815	Economy	9800.00
0005434760179	10815	Economy	8900.00
0005434760199	10815	Economy	8900.00
0005434760177	10815	Economy	8900.00
0005434760178	10815	Economy	8900.00
0005434760198	10815	Economy	8900.00
0005435100110	31831	Economy	9800.00
0005434760215	31831	Economy	9800.00
0005434760216	31831	Economy	8900.00
0005435100127	31831	Economy	8900.00
0005435100122	31831	Economy	8900.00
0005434639499	2013	Economy	20900.00
0005434639519	2013	Economy	20900.00
0005433202348	2013	Economy	20900.00
0005433202254	2013	Economy	19000.00
0005433202365	2013	Economy	19000.00
0005433202306	2013	Economy	19000.00
0005434639510	2013	Economy	19000.00
0005433202313	2013	Economy	19000.00
0005434639507	2013	Economy	19000.00
0005433202256	2013	Economy	19000.00
0005433202341	2013	Economy	19000.00
0005432290654	2013	Economy	19000.00
0005434639516	2013	Economy	19000.00
0005433202344	2013	Economy	19000.00
0005433202335	2013	Economy	19000.00
0005434639520	2013	Economy	19000.00
0005433202340	2013	Economy	19000.00
0005433202321	2013	Economy	19000.00
0005433202255	2013	Economy	19000.00
0005434639502	2013	Economy	19000.00
0005434639521	2013	Economy	19000.00
0005433202345	2013	Economy	19000.00
0005434639508	2013	Economy	19000.00
0005434639500	2013	Economy	19000.00
0005434639505	2013	Economy	19000.00
0005434639503	2013	Economy	19000.00
0005434639506	2013	Economy	19000.00
0005433202347	2013	Economy	19000.00
0005433202320	2013	Economy	19000.00
0005432290657	2013	Economy	19000.00
0005434639517	2013	Economy	19000.00
0005434639501	2013	Economy	19000.00
0005434639509	2013	Economy	19000.00
0005434639513	2013	Economy	19000.00
0005433202274	2013	Economy	19000.00
0005433202336	2013	Economy	19000.00
0005434639512	2013	Economy	19000.00
0005434639511	2013	Economy	19000.00
0005434639504	2013	Economy	19000.00
0005434639518	2013	Economy	19000.00
0005434639514	2013	Economy	19000.00
0005432290656	2013	Economy	19000.00
0005432290655	2013	Economy	19000.00
0005434639515	2013	Economy	19000.00
0005435948333	2013	Economy	19000.00
0005434639317	23273	Economy	20900.00
0005433202461	23273	Economy	20900.00
0005434639215	23273	Economy	20900.00
0005434639318	23273	Economy	20900.00
0005434639266	23273	Economy	19000.00
0005433202455	23273	Economy	19000.00
0005434639296	23273	Economy	19000.00
0005434639357	23273	Economy	19000.00
0005434639217	23273	Economy	19000.00
0005434639274	23273	Economy	19000.00
0005434639216	23273	Economy	19000.00
0005434639294	23273	Economy	19000.00
0005433202462	23273	Economy	19000.00
0005434639309	23273	Economy	19000.00
0005434639358	23273	Economy	19000.00
0005434639252	23273	Economy	19000.00
0005434639163	23273	Economy	19000.00
0005433202454	23273	Economy	19000.00
0005434639353	23273	Economy	19000.00
0005433202451	23273	Economy	19000.00
0005433202459	23273	Economy	19000.00
0005433202456	23273	Economy	19000.00
0005434639370	23273	Economy	19000.00
0005434639135	23273	Economy	19000.00
0005434639253	23273	Economy	19000.00
0005434639303	23273	Economy	19000.00
0005434639275	23273	Economy	19000.00
0005434639264	23273	Economy	19000.00
0005433202458	23273	Economy	19000.00
0005434639134	23273	Economy	19000.00
0005434639130	23273	Economy	19000.00
0005434639310	23273	Economy	19000.00
0005433202457	23273	Economy	19000.00
0005433202463	23273	Economy	19000.00
0005434639263	23273	Economy	19000.00
0005434639354	23273	Economy	19000.00
0005434639254	23273	Economy	19000.00
0005434639192	23273	Economy	19000.00
0005434639321	23273	Economy	19000.00
0005434639156	23273	Economy	19000.00
0005434639249	23273	Economy	19000.00
0005433202460	23273	Economy	19000.00
0005434639311	23273	Economy	19000.00
0005433202452	23273	Economy	19000.00
0005434639283	23273	Economy	19000.00
0005434639109	23273	Economy	19000.00
0005434639164	23273	Economy	19000.00
0005434639306	23273	Economy	19000.00
0005433202453	23273	Economy	19000.00
0005434601001	6046	Business	69700.00
0005433533335	6046	Business	69700.00
0005435326669	6046	Business	69700.00
0005434601004	6046	Business	69700.00
0005433533337	6046	Business	69700.00
0005435326753	6046	Business	69700.00
0005434600994	6046	Economy	23200.00
0005433531320	6046	Economy	23200.00
0005434600999	6046	Economy	23200.00
0005434601009	6046	Economy	23200.00
0005434601014	6046	Economy	23200.00
0005434600992	6046	Economy	23200.00
0005434600998	6046	Economy	25600.00
0005435326750	6046	Economy	25600.00
0005435326691	6046	Economy	25600.00
0005434600989	6046	Economy	25600.00
0005432111301	6046	Economy	25600.00
0005434601007	6046	Economy	23200.00
0005435326736	6046	Economy	23200.00
0005433533334	6046	Economy	23200.00
0005433531323	6046	Economy	23200.00
0005435326754	6046	Economy	23200.00
0005434601008	6046	Economy	23200.00
0005435326770	6046	Economy	23200.00
0005434600996	6046	Economy	23200.00
0005435326734	6046	Economy	23200.00
0005433531321	6046	Economy	23200.00
0005434600991	6046	Economy	23200.00
0005435326792	6046	Economy	23200.00
0005435326671	6046	Economy	23200.00
0005433533336	6046	Economy	23200.00
0005434601003	6046	Economy	23200.00
0005434600993	6046	Economy	23200.00
0005434601011	6046	Economy	23200.00
0005434601002	6046	Economy	23200.00
0005433531322	6046	Economy	23200.00
0005434600995	6046	Economy	23200.00
0005434601006	6046	Economy	23200.00
0005434600990	6046	Economy	23200.00
0005434601015	6046	Economy	23200.00
0005434601013	6046	Economy	23200.00
0005432111302	6046	Economy	23200.00
0005435326670	6046	Economy	23200.00
0005435326686	6046	Economy	23200.00
0005434601000	6046	Economy	23200.00
0005434600997	6046	Economy	23200.00
0005435326741	6046	Economy	23200.00
0005435326742	6046	Economy	23200.00
0005434601010	6046	Economy	23200.00
0005434601005	6046	Economy	23200.00
0005432111300	6046	Economy	23200.00
0005435326737	6046	Economy	23200.00
0005434601012	6046	Economy	23200.00
0005434600849	18560	Business	69700.00
0005434600667	18560	Business	69700.00
0005434600814	18560	Business	69700.00
0005435326848	18560	Business	69700.00
0005434600794	18560	Business	69700.00
0005434600751	18560	Economy	23200.00
0005434600792	18560	Economy	23200.00
0005435326850	18560	Economy	23200.00
0005434600752	18560	Economy	23200.00
0005435326844	18560	Economy	23200.00
0005434600626	18560	Economy	25600.00
0005434600813	18560	Economy	25600.00
0005433527245	18560	Economy	25600.00
0005435326843	18560	Economy	25600.00
0005433527230	18560	Economy	23200.00
0005434600769	18560	Economy	23200.00
0005434600682	18560	Economy	23200.00
0005433527239	18560	Economy	23200.00
0005434600852	18560	Economy	23200.00
0005434600889	18560	Economy	23200.00
0005435326845	18560	Economy	23200.00
0005434600728	18560	Economy	23200.00
0005435326839	18560	Economy	23200.00
0005434600908	18560	Economy	23200.00
0005434600740	18560	Economy	23200.00
0005434600793	18560	Economy	23200.00
0005433527229	18560	Economy	23200.00
0005435326847	18560	Economy	23200.00
0005434600888	18560	Economy	23200.00
0005434600749	18560	Economy	23200.00
0005435326841	18560	Economy	23200.00
0005434600909	18560	Economy	23200.00
0005434600729	18560	Economy	23200.00
0005434600760	18560	Economy	23200.00
0005435326842	18560	Economy	23200.00
0005434600693	18560	Economy	23200.00
0005433531286	18560	Economy	23200.00
0005433527240	18560	Economy	23200.00
0005434600739	18560	Economy	23200.00
0005435326838	18560	Economy	23200.00
0005433527251	18560	Economy	23200.00
0005433527246	18560	Economy	23200.00
0005435326849	18560	Economy	23200.00
0005434600733	18560	Economy	23200.00
0005435326846	18560	Economy	23200.00
0005434600727	18560	Economy	23200.00
0005435326851	18560	Economy	23200.00
0005434600750	18560	Economy	23200.00
0005435326852	18560	Economy	23200.00
0005434600694	18560	Economy	23200.00
0005435326840	18560	Economy	23200.00
0005434600622	18560	Economy	23200.00
0005434600621	18560	Economy	23200.00
0005434551552	10667	Business	9100.00
0005433181029	10667	Business	9100.00
0005433181014	10667	Business	9100.00
0005434551580	10667	Business	9100.00
0005433181002	10667	Business	9100.00
0005434551585	10667	Business	9100.00
0005434551574	10667	Business	9100.00
0005434558325	10667	Business	9100.00
0005434551575	10667	Business	9100.00
0005433181025	10667	Business	9100.00
0005434551602	10667	Economy	3000.00
0005434558328	10667	Economy	3000.00
0005434551603	10667	Economy	3000.00
0005434551599	10667	Economy	3000.00
0005434551563	10667	Economy	3000.00
0005434551595	10667	Economy	3000.00
0005434551581	10667	Economy	3000.00
0005433181061	10667	Economy	3000.00
0005433180965	10667	Economy	3000.00
0005434551590	10667	Economy	3000.00
0005433180946	10667	Economy	3300.00
0005434551570	10667	Economy	3300.00
0005434551555	10667	Economy	3300.00
0005434558327	10667	Economy	3300.00
0005434551578	10667	Economy	3300.00
0005434551550	10667	Economy	3000.00
0005434558326	10667	Economy	3000.00
0005434551566	10667	Economy	3000.00
0005433181073	10667	Economy	3000.00
0005433181031	10667	Economy	3000.00
0005433181057	10667	Economy	3000.00
0005433181058	10667	Economy	3000.00
0005434551573	10667	Economy	3000.00
0005434551604	10667	Economy	3000.00
0005434551572	10667	Economy	3000.00
0005434551583	10667	Economy	3000.00
0005434551551	10667	Economy	3000.00
0005434551597	10667	Economy	3000.00
0005434558330	10667	Economy	3000.00
0005433181030	10667	Economy	3000.00
0005433181028	10667	Economy	3000.00
0005434551561	10667	Economy	3000.00
0005434551562	10667	Economy	3000.00
0005433181027	10667	Economy	3000.00
0005433180994	10667	Economy	3000.00
0005433180960	10667	Economy	3000.00
0005434551579	10667	Economy	3000.00
0005434551567	10667	Economy	3000.00
0005433181006	10667	Economy	3000.00
0005434551557	10667	Economy	3000.00
0005433181026	10667	Economy	3000.00
0005434551564	10667	Economy	3000.00
0005434551560	10667	Economy	3000.00
0005434551559	10667	Economy	3000.00
0005434551587	10667	Economy	3000.00
0005434558331	10667	Economy	3000.00
0005434551568	10667	Economy	3000.00
0005433181034	10667	Economy	3000.00
0005434551582	10667	Economy	3000.00
0005434558333	10667	Economy	3000.00
0005434551598	10667	Economy	3000.00
0005433181060	10667	Economy	3000.00
0005434551600	10667	Economy	3000.00
0005434558329	10667	Economy	3000.00
0005433181035	10667	Economy	3000.00
0005434551588	10667	Economy	3000.00
0005434551591	10667	Economy	3000.00
0005434554079	10667	Economy	3000.00
0005434551589	10667	Economy	3000.00
0005434551593	10667	Economy	3000.00
0005434551554	10667	Economy	3000.00
0005433180945	10667	Economy	3000.00
0005434551569	10667	Economy	3000.00
0005433181124	10667	Economy	3000.00
0005434551586	10667	Economy	3000.00
0005434551577	10667	Economy	3000.00
0005434551594	10667	Economy	3000.00
0005434551556	10667	Economy	3000.00
0005433181033	10667	Economy	3000.00
0005434551558	10667	Economy	3000.00
0005434551576	10667	Economy	3000.00
0005434551565	10667	Economy	3000.00
0005433181021	10667	Economy	3000.00
0005434551601	10667	Economy	3000.00
0005433181074	10667	Economy	3000.00
0005434558332	10667	Economy	3000.00
0005434551584	10667	Economy	3000.00
0005434551571	10667	Economy	3000.00
0005433181003	10667	Economy	3000.00
0005434551553	10667	Economy	3000.00
0005434551596	10667	Economy	3000.00
0005434551592	10667	Economy	3000.00
0005433181280	27754	Business	9100.00
0005433181277	27754	Business	9100.00
0005433181295	27754	Business	9100.00
0005433181274	27754	Business	9100.00
0005433181285	27754	Economy	3000.00
0005433181282	27754	Economy	3000.00
0005433181269	27754	Economy	3300.00
0005433181272	27754	Economy	3000.00
0005433181287	27754	Economy	3000.00
0005433181288	27754	Economy	3000.00
0005433181289	27754	Economy	3000.00
0005433181284	27754	Economy	3000.00
0005433181290	27754	Economy	3000.00
0005433181268	27754	Economy	3000.00
0005433181275	27754	Economy	3000.00
0005433181276	27754	Economy	3000.00
0005433181279	27754	Economy	3000.00
0005433181283	27754	Economy	3000.00
0005433181273	27754	Economy	3000.00
0005433181278	27754	Economy	3000.00
0005433181291	27754	Economy	3000.00
0005433181294	27754	Economy	3000.00
0005433181293	27754	Economy	3000.00
0005433181270	27754	Economy	3000.00
0005433181292	27754	Economy	3000.00
0005433181286	27754	Economy	3000.00
0005433181271	27754	Economy	3000.00
0005433181281	27754	Economy	3000.00
0005434554067	27753	Business	9100.00
0005434558255	27753	Business	9100.00
0005434551188	27753	Business	9100.00
0005434551429	27753	Business	9100.00
0005434550948	27753	Business	9100.00
0005434551335	27753	Business	9100.00
0005434558254	27753	Business	9100.00
0005434551110	27753	Business	9100.00
0005434551288	27753	Economy	3000.00
0005434551029	27753	Economy	3000.00
0005434551055	27753	Economy	3000.00
0005434551242	27753	Economy	3000.00
0005434551056	27753	Economy	3000.00
0005434551169	27753	Economy	3000.00
0005434551069	27753	Economy	3000.00
0005434551316	27753	Economy	3300.00
0005434550902	27753	Economy	3300.00
0005434551121	27753	Economy	3300.00
0005434551111	27753	Economy	3300.00
0005434554061	27753	Economy	3000.00
0005434550890	27753	Economy	3000.00
0005434551264	27753	Economy	3000.00
0005434551261	27753	Economy	3000.00
0005434551120	27753	Economy	3000.00
0005434554062	27753	Economy	3000.00
0005434551473	27753	Economy	3000.00
0005434551065	27753	Economy	3000.00
0005434551024	27753	Economy	3000.00
0005434551185	27753	Economy	3000.00
0005434551241	27753	Economy	3000.00
0005434554070	27753	Economy	3000.00
0005434558265	27753	Economy	3000.00
0005434551300	27753	Economy	3000.00
0005434551292	27753	Economy	3000.00
0005434558239	27753	Economy	3000.00
0005434551186	27753	Economy	3000.00
0005434551057	27753	Economy	3000.00
0005434551243	27753	Economy	3000.00
0005434550949	27753	Economy	3000.00
0005434551393	27753	Economy	3000.00
0005434551317	27753	Economy	3000.00
0005434551008	27753	Economy	3000.00
0005434551028	27753	Economy	3000.00
0005434551046	27753	Economy	3000.00
0005434551334	27753	Economy	3000.00
0005434551047	27753	Economy	3000.00
0005434551017	27753	Economy	3000.00
0005434550905	27753	Economy	3000.00
0005434551293	27753	Economy	3000.00
0005434551266	27753	Economy	3000.00
0005434550867	27753	Economy	3000.00
0005434558244	27753	Economy	3000.00
0005434551101	27753	Economy	3000.00
0005434558266	27753	Economy	3000.00
0005434551031	27753	Economy	3000.00
0005434558229	27753	Economy	3000.00
0005434551231	27753	Economy	3000.00
0005434551030	27753	Economy	3000.00
0005434551168	27753	Economy	3000.00
0005434551187	27753	Economy	3000.00
0005434551265	27753	Economy	3000.00
0005434550969	27753	Economy	3000.00
0005434554065	27753	Economy	3000.00
0005434550737	27753	Economy	3000.00
0005434551119	27753	Economy	3000.00
0005434551336	27753	Economy	3000.00
0005434550970	27753	Economy	3000.00
0005434558267	27753	Economy	3000.00
0005433459250	6159	Economy	11700.00
0005433459248	6159	Economy	11700.00
0005433459251	6159	Economy	11700.00
0005433459247	6159	Economy	11700.00
0005435254466	6159	Economy	11700.00
0005435254467	6159	Economy	11700.00
0005435254468	6159	Economy	11700.00
0005433459249	6159	Economy	11700.00
0005435254490	19326	Economy	11700.00
0005433459209	19326	Economy	11700.00
0005433459225	19326	Economy	11700.00
0005433459218	19326	Economy	11700.00
0005435254491	19326	Economy	11700.00
0005435254492	19326	Economy	11700.00
0005435437934	6741	Business	51100.00
0005435682441	6741	Business	51100.00
0005435682438	6741	Business	51100.00
0005435437993	6741	Business	51100.00
0005432136206	6741	Business	51100.00
0005435438028	6741	Business	51100.00
0005432136204	6741	Business	51100.00
0005435661951	6741	Business	51100.00
0005435217700	6741	Business	51100.00
0005435437957	6741	Business	51100.00
0005435682413	6741	Business	51100.00
0005435682450	6741	Business	51100.00
0005435682451	6741	Economy	17000.00
0005435682420	6741	Economy	17000.00
0005432533286	6741	Economy	17000.00
0005435437724	6741	Economy	17000.00
0005435682437	6741	Economy	17000.00
0005435437919	6741	Economy	17000.00
0005435437886	6741	Economy	17000.00
0005435437944	6741	Economy	17000.00
0005435682423	6741	Economy	17000.00
0005435437725	6741	Economy	17000.00
0005435437956	6741	Economy	18700.00
0005435220307	6741	Economy	18700.00
0005435682418	6741	Economy	18700.00
0005435661949	6741	Economy	18700.00
0005435682415	6741	Economy	18700.00
0005435682447	6741	Economy	17000.00
0005435682432	6741	Economy	17000.00
0005435682445	6741	Economy	17000.00
0005435661948	6741	Economy	17000.00
0005435217704	6741	Economy	17000.00
0005435682425	6741	Economy	17000.00
0005435682426	6741	Economy	17000.00
0005435437958	6741	Economy	17000.00
0005435682408	6741	Economy	17000.00
0005435437943	6741	Economy	17000.00
0005432533285	6741	Economy	17000.00
0005435437945	6741	Economy	17000.00
0005435630986	6741	Economy	17000.00
0005435682444	6741	Economy	17000.00
0005432533281	6741	Economy	17000.00
0005435437994	6741	Economy	17000.00
0005435682412	6741	Economy	17000.00
0005432533280	6741	Economy	17000.00
0005435682421	6741	Economy	17000.00
0005432533290	6741	Economy	17000.00
0005435682452	6741	Economy	17000.00
0005435682434	6741	Economy	17000.00
0005435682422	6741	Economy	17000.00
0005435682419	6741	Economy	17000.00
0005435682449	6741	Economy	17000.00
0005435682417	6741	Economy	17000.00
0005435437959	6741	Economy	17000.00
0005435682435	6741	Economy	17000.00
0005435682414	6741	Economy	17000.00
0005434828686	6741	Economy	17000.00
0005435682409	6741	Economy	17000.00
0005435682416	6741	Economy	17000.00
0005435682424	6741	Economy	17000.00
0005432533289	6741	Economy	17000.00
0005435682427	6741	Economy	17000.00
0005435682439	6741	Economy	17000.00
0005435437933	6741	Economy	17000.00
0005435682440	6741	Economy	17000.00
0005435437904	6741	Economy	17000.00
0005435630985	6741	Economy	17000.00
0005432533275	6741	Economy	17000.00
0005435437983	6741	Economy	17000.00
0005435682428	6741	Economy	17000.00
0005435437853	6741	Economy	17000.00
0005432136202	6741	Economy	17000.00
0005435682410	6741	Economy	17000.00
0005435682429	6741	Economy	17000.00
0005432136205	6741	Economy	17000.00
0005435682431	6741	Economy	17000.00
0005434828690	6741	Economy	17000.00
0005435682446	6741	Economy	17000.00
0005435682411	6741	Economy	17000.00
0005435682433	6741	Economy	17000.00
0005435630987	6741	Economy	17000.00
0005435682436	6741	Economy	17000.00
0005435217706	6741	Economy	17000.00
0005432136203	6741	Economy	17000.00
0005435217707	6741	Economy	17000.00
0005435661950	6741	Economy	17000.00
0005435221511	6741	Economy	17000.00
0005435437917	6741	Economy	17000.00
0005435682453	6741	Economy	17000.00
0005435682443	6741	Economy	17000.00
0005435437918	6741	Economy	17000.00
0005435682442	6741	Economy	17000.00
0005435682448	6741	Economy	17000.00
0005435682430	6741	Economy	17000.00
0005435682166	24567	Business	51100.00
0005435682058	24567	Business	51100.00
0005435220492	24567	Business	51100.00
0005435661924	24567	Business	51100.00
0005435682012	24567	Business	51100.00
0005434828720	24567	Business	51100.00
0005435681835	24567	Business	51100.00
0005435438113	24567	Business	51100.00
0005435438104	24567	Economy	17000.00
0005435438106	24567	Economy	17000.00
0005435630977	24567	Economy	17000.00
0005435438099	24567	Economy	17000.00
0005435682078	24567	Economy	17000.00
0005435681986	24567	Economy	17000.00
0005435630948	24567	Economy	17000.00
0005435682074	24567	Economy	17000.00
0005435438117	24567	Economy	17000.00
0005435682022	24567	Economy	17000.00
0005435438098	24567	Economy	18700.00
0005435219213	24567	Economy	18700.00
0005435438118	24567	Economy	18700.00
0005435682133	24567	Economy	18700.00
0005435438105	24567	Economy	18700.00
0005432533313	24567	Economy	17000.00
0005435681917	24567	Economy	17000.00
0005435220332	24567	Economy	17000.00
0005435682148	24567	Economy	17000.00
0005435681988	24567	Economy	17000.00
0005435438116	24567	Economy	17000.00
0005435681975	24567	Economy	17000.00
0005435682167	24567	Economy	17000.00
0005435682176	24567	Economy	17000.00
0005435682030	24567	Economy	17000.00
0005435220334	24567	Economy	17000.00
0005435438112	24567	Economy	17000.00
0005435682006	24567	Economy	17000.00
0005435438100	24567	Economy	17000.00
0005435681871	24567	Economy	17000.00
0005435220333	24567	Economy	17000.00
0005435681987	24567	Economy	17000.00
0005435220331	24567	Economy	17000.00
0005435438101	24567	Economy	17000.00
0005435630966	24567	Economy	17000.00
0005435438120	24567	Economy	17000.00
0005435682003	24567	Economy	17000.00
0005435682013	24567	Economy	17000.00
0005435682131	24567	Economy	17000.00
0005435682136	24567	Economy	17000.00
0005435438119	24567	Economy	17000.00
0005435438108	24567	Economy	17000.00
0005435681998	24567	Economy	17000.00
0005434828717	24567	Economy	17000.00
0005435438102	24567	Economy	17000.00
0005435682021	24567	Economy	17000.00
0005432305766	24567	Economy	17000.00
0005435219212	24567	Economy	17000.00
0005435630967	24567	Economy	17000.00
0005435630965	24567	Economy	17000.00
0005435681974	24567	Economy	17000.00
0005435438114	24567	Economy	17000.00
0005435682157	24567	Economy	17000.00
0005435682132	24567	Economy	17000.00
0005432305765	24567	Economy	17000.00
0005435219214	24567	Economy	17000.00
0005432533312	24567	Economy	17000.00
0005435438115	24567	Economy	17000.00
0005435682113	24567	Economy	17000.00
0005435682001	24567	Economy	17000.00
0005435438111	24567	Economy	17000.00
0005434828719	24567	Economy	17000.00
0005435682177	24567	Economy	17000.00
0005435682108	24567	Economy	17000.00
0005434828716	24567	Economy	17000.00
0005434828718	24567	Economy	17000.00
0005435438110	24567	Economy	17000.00
0005432305767	24567	Economy	17000.00
0005435681963	24567	Economy	17000.00
0005435681959	24567	Economy	17000.00
0005435682073	24567	Economy	17000.00
0005435219215	24567	Economy	17000.00
0005435438107	24567	Economy	17000.00
0005435438103	24567	Economy	17000.00
0005435682141	24567	Economy	17000.00
0005435682077	24567	Economy	17000.00
0005435438109	24567	Economy	17000.00
0005435682130	24567	Economy	17000.00
0005435126620	11556	Business	26400.00
0005435126613	11556	Business	26400.00
0005435126614	11556	Business	26400.00
0005435126618	11556	Business	26400.00
0005435126627	11556	Business	26400.00
0005435558084	11556	Business	26400.00
0005435126634	11556	Economy	8800.00
0005435558086	11556	Economy	8800.00
0005435558075	11556	Economy	8800.00
0005435126636	11556	Economy	8800.00
0005435126626	11556	Economy	8800.00
0005435126625	11556	Economy	8800.00
0005435558074	11556	Economy	8800.00
0005435126639	11556	Economy	9700.00
0005435126629	11556	Economy	9700.00
0005435126616	11556	Economy	9700.00
0005435126608	11556	Economy	8800.00
0005435126606	11556	Economy	8800.00
0005435126638	11556	Economy	8800.00
0005435106003	11556	Economy	8800.00
0005435126631	11556	Economy	8800.00
0005435126632	11556	Economy	8800.00
0005435126630	11556	Economy	8800.00
0005435126642	11556	Economy	8800.00
0005435126637	11556	Economy	8800.00
0005435126633	11556	Economy	8800.00
0005435126612	11556	Economy	8800.00
0005435126615	11556	Economy	8800.00
0005435126607	11556	Economy	8800.00
0005435126617	11556	Economy	8800.00
0005435126605	11556	Economy	8800.00
0005435126644	11556	Economy	8800.00
0005435558082	11556	Economy	8800.00
0005435126640	11556	Economy	8800.00
0005435126621	11556	Economy	8800.00
0005435126643	11556	Economy	8800.00
0005435558081	11556	Economy	8800.00
0005435126619	11556	Economy	8800.00
0005435126609	11556	Economy	8800.00
0005435126623	11556	Economy	8800.00
0005435126628	11556	Economy	8800.00
0005435126635	11556	Economy	8800.00
0005435126624	11556	Economy	8800.00
0005435126641	11556	Economy	8800.00
0005435126645	11556	Economy	8800.00
0005435126622	11556	Economy	8800.00
0005435558089	11556	Economy	8800.00
0005435126611	11556	Economy	8800.00
0005435106002	11556	Economy	8800.00
0005435126610	11556	Economy	8800.00
0005435126240	31865	Business	26400.00
0005435126290	31865	Business	26400.00
0005435126267	31865	Business	26400.00
0005435126244	31865	Business	26400.00
0005435126313	31865	Business	26400.00
0005435126437	31865	Business	26400.00
0005435098551	31865	Business	26400.00
0005435098539	31865	Business	26400.00
0005435126278	31865	Economy	8800.00
0005435126431	31865	Economy	8800.00
0005435098560	31865	Economy	8800.00
0005435126255	31865	Economy	8800.00
0005435126241	31865	Economy	8800.00
0005435126189	31865	Economy	8800.00
0005435126232	31865	Economy	9700.00
0005435098559	31865	Economy	9700.00
0005435126188	31865	Economy	9700.00
0005435126393	31865	Economy	9700.00
0005435126266	31865	Economy	9700.00
0005435126294	31865	Economy	8800.00
0005435126360	31865	Economy	8800.00
0005435126242	31865	Economy	8800.00
0005435098552	31865	Economy	8800.00
0005435126231	31865	Economy	8800.00
0005435126250	31865	Economy	8800.00
0005435126254	31865	Economy	8800.00
0005435126415	31865	Economy	8800.00
0005435126249	31865	Economy	8800.00
0005435126379	31865	Economy	8800.00
0005435098553	31865	Economy	8800.00
0005435126517	31865	Economy	8800.00
0005435558105	31865	Economy	8800.00
0005435126307	31865	Economy	8800.00
0005435126247	31865	Economy	8800.00
0005435558106	31865	Economy	8800.00
0005435098554	31865	Economy	8800.00
0005435126339	31865	Economy	8800.00
0005435126097	31865	Economy	8800.00
0005435126330	31865	Economy	8800.00
0005435126369	31865	Economy	8800.00
0005435126469	31865	Economy	8800.00
0005435126168	31865	Economy	8800.00
0005435126327	31865	Economy	8800.00
0005435126312	31865	Economy	8800.00
0005435105976	31865	Economy	8800.00
0005435126293	31865	Economy	8800.00
0005435126277	31865	Economy	8800.00
0005435098538	31865	Economy	8800.00
0005435126341	31865	Economy	8800.00
0005435126212	31865	Economy	8800.00
0005435126292	31865	Economy	8800.00
0005435558104	31865	Economy	8800.00
0005435126096	31865	Economy	8800.00
0005435126414	31865	Economy	8800.00
0005435126151	31865	Economy	8800.00
0005435126434	31865	Economy	8800.00
0005435126370	31865	Economy	8800.00
0005435105982	31865	Economy	8800.00
0005435105983	31865	Economy	8800.00
0005435126245	31865	Economy	8800.00
0005435126420	31865	Economy	8800.00
0005435098558	31865	Economy	8800.00
0005435126215	31865	Economy	8800.00
0005435126265	31865	Economy	8800.00
0005435126223	31865	Economy	8800.00
0005435126213	31865	Economy	8800.00
0005435098555	31865	Economy	8800.00
0005435126246	31865	Economy	8800.00
0005435126214	31865	Economy	8800.00
0005433398412	13524	Business	36600.00
0005433398380	13524	Business	36600.00
0005433398386	13524	Business	36600.00
0005435732323	13524	Business	36600.00
0005433398393	13524	Business	36600.00
0005433398398	13524	Business	36600.00
0005433398381	13524	Economy	12200.00
0005433398404	13524	Economy	12200.00
0005433398395	13524	Economy	12200.00
0005433398406	13524	Economy	12200.00
0005433398418	13524	Economy	13400.00
0005433398402	13524	Economy	13400.00
0005433398387	13524	Economy	12200.00
0005433398409	13524	Economy	12200.00
0005433398390	13524	Economy	12200.00
0005435732324	13524	Economy	12200.00
0005435732303	13524	Economy	12200.00
0005433398416	13524	Economy	12200.00
0005433398419	13524	Economy	12200.00
0005433398414	13524	Economy	12200.00
0005435732362	13524	Economy	12200.00
0005433398391	13524	Economy	12200.00
0005433398399	13524	Economy	12200.00
0005433398408	13524	Economy	12200.00
0005433398376	13524	Economy	12200.00
0005435732361	13524	Economy	12200.00
0005433398374	13524	Economy	12200.00
0005433398401	13524	Economy	12200.00
0005433398382	13524	Economy	12200.00
0005433398389	13524	Economy	12200.00
0005433398420	13524	Economy	12200.00
0005433398411	13524	Economy	12200.00
0005433398417	13524	Economy	12200.00
0005435732290	13524	Economy	12200.00
0005433398415	13524	Economy	12200.00
0005433398379	13524	Economy	12200.00
0005433398410	13524	Economy	12200.00
0005433398397	13524	Economy	12200.00
0005433398377	13524	Economy	12200.00
0005433398383	13524	Economy	12200.00
0005433398385	13524	Economy	12200.00
0005433398400	13524	Economy	12200.00
0005433398392	13524	Economy	12200.00
0005433398378	13524	Economy	12200.00
0005435732304	13524	Economy	12200.00
0005433398394	13524	Economy	12200.00
0005433398384	13524	Economy	12200.00
0005433398375	13524	Economy	12200.00
0005433398373	13524	Economy	12200.00
0005433398388	13524	Economy	12200.00
0005433398407	13524	Economy	12200.00
0005433398396	13524	Economy	12200.00
0005433398405	13524	Economy	12200.00
0005433398403	13524	Economy	12200.00
0005435732359	13524	Economy	12200.00
0005433398413	13524	Economy	12200.00
0005433397809	19395	Business	36600.00
0005435732409	19395	Business	36600.00
0005435732405	19395	Business	36600.00
0005433397989	19395	Business	36600.00
0005435732413	19395	Business	36600.00
0005435732402	19395	Business	36600.00
0005435732400	19395	Business	36600.00
0005435732408	19395	Economy	12200.00
0005433397836	19395	Economy	12200.00
0005435732415	19395	Economy	12200.00
0005433398044	19395	Economy	12200.00
0005433397886	19395	Economy	12200.00
0005433397855	19395	Economy	13400.00
0005435732395	19395	Economy	13400.00
0005433397987	19395	Economy	12200.00
0005435732411	19395	Economy	12200.00
0005432297295	19395	Economy	12200.00
0005433398029	19395	Economy	12200.00
0005435732407	19395	Economy	12200.00
0005433397990	19395	Economy	12200.00
0005435732419	19395	Economy	12200.00
0005433398024	19395	Economy	12200.00
0005435732412	19395	Economy	12200.00
0005435732397	19395	Economy	12200.00
0005433397887	19395	Economy	12200.00
0005432297298	19395	Economy	12200.00
0005432297297	19395	Economy	12200.00
0005433397856	19395	Economy	12200.00
0005435732417	19395	Economy	12200.00
0005435732404	19395	Economy	12200.00
0005435732401	19395	Economy	12200.00
0005435732416	19395	Economy	12200.00
0005433398028	19395	Economy	12200.00
0005435732418	19395	Economy	12200.00
0005435732414	19395	Economy	12200.00
0005433397917	19395	Economy	12200.00
0005433397933	19395	Economy	12200.00
0005433397831	19395	Economy	12200.00
0005433397930	19395	Economy	12200.00
0005433398034	19395	Economy	12200.00
0005435732396	19395	Economy	12200.00
0005435732410	19395	Economy	12200.00
0005433397891	19395	Economy	12200.00
0005435732398	19395	Economy	12200.00
0005433397946	19395	Economy	12200.00
0005433397908	19395	Economy	12200.00
0005433397952	19395	Economy	12200.00
0005435732399	19395	Economy	12200.00
0005435732406	19395	Economy	12200.00
0005432297296	19395	Economy	12200.00
0005433398144	19395	Economy	12200.00
0005435732403	19395	Economy	12200.00
0005433398037	19395	Economy	12200.00
0005435068838	13166	Business	11300.00
0005435068795	13166	Business	11300.00
0005435069057	13166	Business	11300.00
0005435069105	13166	Business	11300.00
0005435068822	13166	Business	11300.00
0005435068647	13166	Business	11300.00
0005435068748	13166	Economy	3800.00
0005435068888	13166	Economy	3800.00
0005435068971	13166	Economy	3800.00
0005435068897	13166	Economy	3800.00
0005435068967	13166	Economy	3800.00
0005435068829	13166	Economy	3800.00
0005435069028	13166	Economy	3800.00
0005435068991	13166	Economy	4100.00
0005435069041	13166	Economy	4100.00
0005435069016	13166	Economy	4100.00
0005435068868	13166	Economy	4100.00
0005435069106	13166	Economy	3800.00
0005435068853	13166	Economy	3800.00
0005435068852	13166	Economy	3800.00
0005435069042	13166	Economy	3800.00
0005435069055	13166	Economy	3800.00
0005435068988	13166	Economy	3800.00
0005435068765	13166	Economy	3800.00
0005435068828	13166	Economy	3800.00
0005435068709	13166	Economy	3800.00
0005435069017	13166	Economy	3800.00
0005435068894	13166	Economy	3800.00
0005435069018	13166	Economy	3800.00
0005435069186	13166	Economy	3800.00
0005435068889	13166	Economy	3800.00
0005435069001	13166	Economy	3800.00
0005435068898	13166	Economy	3800.00
0005435068992	13166	Economy	3800.00
0005435068746	13166	Economy	3800.00
0005435068851	13166	Economy	3800.00
0005435068942	13166	Economy	3800.00
0005435068911	13166	Economy	3800.00
0005435069015	13166	Economy	3800.00
0005435068895	13166	Economy	3800.00
0005435068874	13166	Economy	3800.00
0005435068747	13166	Economy	3800.00
0005435068919	13166	Economy	3800.00
0005435068864	13166	Economy	3800.00
0005435068982	13166	Economy	3800.00
0005435068922	13166	Economy	3800.00
0005435068987	13166	Economy	3800.00
0005435068906	13166	Economy	3800.00
0005435068754	13166	Economy	3800.00
0005435068899	13166	Economy	3800.00
0005435068966	13166	Economy	3800.00
0005435068900	13166	Economy	3800.00
0005435069003	13166	Economy	3800.00
0005435068708	13166	Economy	3800.00
0005435069396	15509	Business	11300.00
0005435925234	15509	Business	11300.00
0005435925273	15509	Business	11300.00
0005435069399	15509	Business	11300.00
0005435925263	15509	Business	11300.00
0005435069410	15509	Business	11300.00
0005435069404	15509	Business	11300.00
0005435925286	15509	Business	11300.00
0005435069385	15509	Economy	3800.00
0005435069414	15509	Economy	3800.00
0005435925289	15509	Economy	3800.00
0005435069429	15509	Economy	3800.00
0005435069397	15509	Economy	3800.00
0005435069378	15509	Economy	4100.00
0005435069415	15509	Economy	4100.00
0005435069418	15509	Economy	4100.00
0005435069424	15509	Economy	4100.00
0005435069392	15509	Economy	3800.00
0005435069417	15509	Economy	3800.00
0005435069411	15509	Economy	3800.00
0005435069401	15509	Economy	3800.00
0005435069391	15509	Economy	3800.00
0005435069400	15509	Economy	3800.00
0005435069420	15509	Economy	3800.00
0005435069382	15509	Economy	3800.00
0005435069393	15509	Economy	3800.00
0005435069419	15509	Economy	3800.00
0005435069428	15509	Economy	3800.00
0005435069413	15509	Economy	3800.00
0005435069407	15509	Economy	3800.00
0005435069394	15509	Economy	3800.00
0005435069412	15509	Economy	3800.00
0005435069423	15509	Economy	3800.00
0005435069405	15509	Economy	3800.00
0005435069425	15509	Economy	3800.00
0005435925264	15509	Economy	3800.00
0005435069406	15509	Economy	3800.00
0005435925251	15509	Economy	3800.00
0005435069377	15509	Economy	3800.00
0005435069384	15509	Economy	3800.00
0005435069409	15509	Economy	3800.00
0005435925285	15509	Economy	3800.00
0005435069427	15509	Economy	3800.00
0005435925290	15509	Economy	3800.00
0005435069408	15509	Economy	3800.00
0005435069383	15509	Economy	3800.00
0005435925280	15509	Economy	3800.00
0005435069380	15509	Economy	3800.00
0005435925281	15509	Economy	3800.00
0005435069381	15509	Economy	3800.00
0005435069422	15509	Economy	3800.00
0005435069388	15509	Economy	3800.00
0005435069379	15509	Economy	3800.00
0005435069398	15509	Economy	3800.00
0005435925265	15509	Economy	3800.00
0005435925231	15509	Economy	3800.00
0005435069402	15509	Economy	3800.00
0005435069389	15509	Economy	3800.00
0005435069386	15509	Economy	3800.00
0005435069395	15509	Economy	3800.00
0005435069387	15509	Economy	3800.00
0005435925210	15509	Economy	3800.00
0005435069421	15509	Economy	3800.00
0005435069390	15509	Economy	3800.00
0005435069416	15509	Economy	3800.00
0005435925255	15509	Economy	3800.00
0005435069426	15509	Economy	3800.00
0005435069403	15509	Economy	3800.00
0005435925287	15509	Economy	3800.00
0005433407561	23187	Economy	27100.00
0005433407518	23187	Economy	24700.00
0005435808297	23187	Economy	24700.00
0005433407541	23187	Economy	24700.00
0005435808294	23187	Economy	24700.00
0005435808289	23187	Economy	24700.00
0005433407542	23187	Economy	24700.00
0005435808299	23187	Economy	24700.00
0005435808301	23187	Economy	24700.00
0005435808296	23187	Economy	24700.00
0005433407562	23187	Economy	24700.00
0005435808295	23187	Economy	24700.00
0005435808300	23187	Economy	24700.00
0005435808292	23187	Economy	24700.00
0005435808286	23187	Economy	24700.00
0005433407538	23187	Economy	24700.00
0005435808290	23187	Economy	24700.00
0005435808303	23187	Economy	24700.00
0005433407531	23187	Economy	24700.00
0005433407544	23187	Economy	24700.00
0005435808298	23187	Economy	24700.00
0005435808287	23187	Economy	24700.00
0005433407565	23187	Economy	24700.00
0005435808291	23187	Economy	24700.00
0005435808288	23187	Economy	24700.00
0005435808284	23187	Economy	24700.00
0005435808285	23187	Economy	24700.00
0005435808293	23187	Economy	24700.00
0005435808304	23187	Economy	24700.00
0005433407563	23187	Economy	24700.00
0005433407530	23187	Economy	24700.00
0005433407543	23187	Economy	24700.00
0005435808302	23187	Economy	24700.00
0005434756397	10722	Business	61300.00
0005434756296	10722	Business	61300.00
0005434756302	10722	Business	61300.00
0005434756280	10722	Business	61300.00
0005434214860	10722	Business	61300.00
0005434214857	10722	Business	61300.00
0005434756325	10722	Business	61300.00
0005434214885	10722	Business	61300.00
0005434756299	10722	Business	61300.00
0005434756324	10722	Business	61300.00
0005434214868	10722	Business	61300.00
0005434756315	10722	Business	61300.00
0005434756279	10722	Economy	20400.00
0005434756249	10722	Economy	20400.00
0005434214852	10722	Economy	20400.00
0005434756259	10722	Economy	20400.00
0005434756160	10722	Economy	20400.00
0005434214862	10722	Economy	20400.00
0005434756248	10722	Economy	20400.00
0005434756295	10722	Economy	22500.00
0005434214855	10722	Economy	22500.00
0005434214859	10722	Economy	22500.00
0005434756365	10722	Economy	22500.00
0005434214867	10722	Economy	22500.00
0005434214880	10722	Economy	20400.00
0005434214844	10722	Economy	20400.00
0005434214871	10722	Economy	20400.00
0005434756260	10722	Economy	20400.00
0005434214842	10722	Economy	20400.00
0005434214848	10722	Economy	20400.00
0005434756347	10722	Economy	20400.00
0005434214874	10722	Economy	20400.00
0005434214858	10722	Economy	20400.00
0005434214886	10722	Economy	20400.00
0005434756391	10722	Economy	20400.00
0005434214887	10722	Economy	20400.00
0005434214865	10722	Economy	20400.00
0005434214850	10722	Economy	20400.00
0005434756236	10722	Economy	20400.00
0005434214845	10722	Economy	20400.00
0005434214882	10722	Economy	20400.00
0005434756223	10722	Economy	20400.00
0005434214846	10722	Economy	20400.00
0005434214869	10722	Economy	20400.00
0005434214884	10722	Economy	20400.00
0005434214870	10722	Economy	20400.00
0005434756395	10722	Economy	20400.00
0005434214863	10722	Economy	20400.00
0005434756314	10722	Economy	20400.00
0005434756266	10722	Economy	20400.00
0005434214877	10722	Economy	20400.00
0005434214878	10722	Economy	20400.00
0005434214849	10722	Economy	20400.00
0005434756288	10722	Economy	20400.00
0005434214851	10722	Economy	20400.00
0005434756219	10722	Economy	20400.00
0005434214861	10722	Economy	20400.00
0005434756271	10722	Economy	20400.00
0005434214872	10722	Economy	20400.00
0005434214864	10722	Economy	20400.00
0005434756209	10722	Economy	20400.00
0005434214879	10722	Economy	20400.00
0005434756218	10722	Economy	20400.00
0005434756328	10722	Economy	20400.00
0005434214875	10722	Economy	20400.00
0005434756221	10722	Economy	20400.00
0005434214840	10722	Economy	20400.00
0005434756341	10722	Economy	20400.00
0005434214854	10722	Economy	20400.00
0005434756394	10722	Economy	20400.00
0005434214853	10722	Economy	20400.00
0005434756287	10722	Economy	20400.00
0005434214847	10722	Economy	20400.00
0005434756222	10722	Economy	20400.00
0005434214873	10722	Economy	20400.00
0005434214883	10722	Economy	20400.00
0005434214843	10722	Economy	20400.00
0005434214866	10722	Economy	20400.00
0005434214841	10722	Economy	20400.00
0005434214856	10722	Economy	20400.00
0005434756342	10722	Economy	20400.00
0005434756364	10722	Economy	20400.00
0005434214876	10722	Economy	20400.00
0005434214881	10722	Economy	20400.00
0005434214336	28673	Business	61300.00
0005434214303	28673	Business	61300.00
0005434756695	28673	Business	61300.00
0005434756700	28673	Business	61300.00
0005434756682	28673	Business	61300.00
0005434756688	28673	Business	61300.00
0005434214400	28673	Business	61300.00
0005434214269	28673	Business	61300.00
0005434214472	28673	Business	61300.00
0005434756672	28673	Business	61300.00
0005434756668	28673	Business	61300.00
0005434756685	28673	Economy	20400.00
0005434756683	28673	Economy	20400.00
0005434756708	28673	Economy	20400.00
0005434214545	28673	Economy	20400.00
0005434214547	28673	Economy	20400.00
0005434756693	28673	Economy	20400.00
0005434756673	28673	Economy	20400.00
0005434214437	28673	Economy	20400.00
0005434214361	28673	Economy	20400.00
0005434214274	28673	Economy	20400.00
0005434214418	28673	Economy	22500.00
0005434756702	28673	Economy	22500.00
0005434756709	28673	Economy	22500.00
0005434214341	28673	Economy	22500.00
0005434756699	28673	Economy	22500.00
0005434214294	28673	Economy	20400.00
0005434756697	28673	Economy	20400.00
0005434756704	28673	Economy	20400.00
0005434214522	28673	Economy	20400.00
0005434214417	28673	Economy	20400.00
0005434756670	28673	Economy	20400.00
0005434756696	28673	Economy	20400.00
0005434214313	28673	Economy	20400.00
0005434214304	28673	Economy	20400.00
0005434756679	28673	Economy	20400.00
0005434756703	28673	Economy	20400.00
0005434756665	28673	Economy	20400.00
0005434756706	28673	Economy	20400.00
0005434214548	28673	Economy	20400.00
0005434756681	28673	Economy	20400.00
0005434214356	28673	Economy	20400.00
0005434756689	28673	Economy	20400.00
0005434214293	28673	Economy	20400.00
0005434214382	28673	Economy	20400.00
0005434756667	28673	Economy	20400.00
0005434214163	28673	Economy	20400.00
0005434756674	28673	Economy	20400.00
0005434214362	28673	Economy	20400.00
0005434756707	28673	Economy	20400.00
0005434214270	28673	Economy	20400.00
0005434756701	28673	Economy	20400.00
0005434756692	28673	Economy	20400.00
0005434756687	28673	Economy	20400.00
0005434756677	28673	Economy	20400.00
0005434756705	28673	Economy	20400.00
0005434214340	28673	Economy	20400.00
0005434214257	28673	Economy	20400.00
0005434756684	28673	Economy	20400.00
0005434756710	28673	Economy	20400.00
0005434756711	28673	Economy	20400.00
0005434214295	28673	Economy	20400.00
0005434214389	28673	Economy	20400.00
0005434214391	28673	Economy	20400.00
0005434756686	28673	Economy	20400.00
0005434756676	28673	Economy	20400.00
0005434756691	28673	Economy	20400.00
0005434214432	28673	Economy	20400.00
0005434214305	28673	Economy	20400.00
0005434756666	28673	Economy	20400.00
0005434214301	28673	Economy	20400.00
0005434214390	28673	Economy	20400.00
0005434214471	28673	Economy	20400.00
0005434756694	28673	Economy	20400.00
0005434756698	28673	Economy	20400.00
0005434756671	28673	Economy	20400.00
0005434756680	28673	Economy	20400.00
0005434756678	28673	Economy	20400.00
0005434214322	28673	Economy	20400.00
0005434214273	28673	Economy	20400.00
0005434756675	28673	Economy	20400.00
0005434214302	28673	Economy	20400.00
0005434214181	28673	Economy	20400.00
0005434756669	28673	Economy	20400.00
0005434214399	28673	Economy	20400.00
0005434214383	28673	Economy	20400.00
0005434756690	28673	Economy	20400.00
0005434214307	28673	Economy	20400.00
0005434229271	5453	Business	29500.00
0005435007195	5453	Business	29500.00
0005434229392	5453	Business	29500.00
0005432125502	5453	Business	29500.00
0005435040212	5453	Business	29500.00
0005432125506	5453	Business	29500.00
0005435007185	5453	Business	29500.00
0005435040208	5453	Business	29500.00
0005432125507	5453	Business	29500.00
0005435040245	5453	Business	29500.00
0005435040237	5453	Business	29500.00
0005432125504	5453	Economy	9800.00
0005435040227	5453	Economy	9800.00
0005435040215	5453	Economy	9800.00
0005434229357	5453	Economy	9800.00
0005435040238	5453	Economy	9800.00
0005434229400	5453	Economy	9800.00
0005435040229	5453	Economy	9800.00
0005435007180	5453	Economy	9800.00
0005434229353	5453	Economy	9800.00
0005434229299	5453	Economy	9800.00
0005434229217	5453	Economy	9800.00
0005435040230	5453	Economy	9800.00
0005434229275	5453	Economy	9800.00
0005435040195	5453	Economy	9800.00
0005434229372	5453	Economy	9800.00
0005434229328	5453	Economy	9800.00
0005435007178	5453	Economy	9800.00
0005435040244	5453	Economy	9800.00
0005435040234	5453	Economy	9800.00
0005434229267	5453	Economy	9800.00
0005434229430	5453	Economy	9800.00
0005435040231	5453	Economy	9800.00
0005435007183	5453	Economy	9800.00
0005435040251	5453	Economy	9800.00
0005435040198	5453	Economy	9800.00
0005434229329	5453	Economy	9800.00
0005435040225	5453	Economy	9800.00
0005435040210	5453	Economy	9800.00
0005432125500	5453	Economy	9800.00
0005435040233	5453	Economy	9800.00
0005432125503	5453	Economy	9800.00
0005434229313	5453	Economy	9800.00
0005435040247	5453	Economy	9800.00
0005435007184	5453	Economy	9800.00
0005434229337	5453	Economy	9800.00
0005435040202	5453	Economy	9800.00
0005432125501	5453	Economy	9800.00
0005435007198	5453	Economy	10800.00
0005435040236	5453	Economy	10800.00
0005434229358	5453	Economy	10800.00
0005435040252	5453	Economy	10800.00
0005435040199	5453	Economy	10800.00
0005435007186	5453	Economy	9800.00
0005434229351	5453	Economy	9800.00
0005435007182	5453	Economy	9800.00
0005434229352	5453	Economy	9800.00
0005435007189	5453	Economy	9800.00
0005434229338	5453	Economy	9800.00
0005435040209	5453	Economy	9800.00
0005435040220	5453	Economy	9800.00
0005435040235	5453	Economy	9800.00
0005435040221	5453	Economy	9800.00
0005435040205	5453	Economy	9800.00
0005435007200	5453	Economy	9800.00
0005435007181	5453	Economy	9800.00
0005435040253	5453	Economy	9800.00
0005435040250	5453	Economy	9800.00
0005435040243	5453	Economy	9800.00
0005434229334	5453	Economy	9800.00
0005434229398	5453	Economy	9800.00
0005435040242	5453	Economy	9800.00
0005432125505	5453	Economy	9800.00
0005435042871	5453	Economy	9800.00
0005435040197	5453	Economy	9800.00
0005435007196	5453	Economy	9800.00
0005435040241	5453	Economy	9800.00
0005434229399	5453	Economy	9800.00
0005435040218	5453	Economy	9800.00
0005435007199	5453	Economy	9800.00
0005435007194	5453	Economy	9800.00
0005434229314	5453	Economy	9800.00
0005435007193	5453	Economy	9800.00
0005435040203	5453	Economy	9800.00
0005435040222	5453	Economy	9800.00
0005434229270	5453	Economy	9800.00
0005435040224	5453	Economy	9800.00
0005435007197	5453	Economy	9800.00
0005435007190	5453	Economy	9800.00
0005435040213	5453	Economy	9800.00
0005434229315	5453	Economy	9800.00
0005435040217	5453	Economy	9800.00
0005435040223	5453	Economy	9800.00
0005435040240	5453	Economy	9800.00
0005435040246	5453	Economy	9800.00
0005434229266	5453	Economy	9800.00
0005434229365	5453	Economy	9800.00
0005435040248	5453	Economy	9800.00
0005435040216	5453	Economy	9800.00
0005435040249	5453	Economy	9800.00
0005435040232	5453	Economy	9800.00
0005435040204	5453	Economy	9800.00
0005435040226	5453	Economy	9800.00
0005435040219	5453	Economy	9800.00
0005435040196	5453	Economy	9800.00
0005434229306	5453	Economy	9800.00
0005435007179	5453	Economy	9800.00
0005435040206	5453	Economy	9800.00
0005435040211	5453	Economy	9800.00
0005435040201	5453	Economy	9800.00
0005435007191	5453	Economy	9800.00
0005435040207	5453	Economy	9800.00
0005435007192	5453	Economy	9800.00
0005435007201	5453	Economy	9800.00
0005435040214	5453	Economy	9800.00
0005435040228	5453	Economy	9800.00
0005435007187	5453	Economy	9800.00
0005435040239	5453	Economy	9800.00
0005435040200	5453	Economy	9800.00
0005435007188	5453	Economy	9800.00
0005435006932	13001	Business	29500.00
0005435039708	13001	Business	29500.00
0005435039717	13001	Business	29500.00
0005435039690	13001	Business	29500.00
0005435039631	13001	Business	29500.00
0005435039226	13001	Business	29500.00
0005434229537	13001	Business	29500.00
0005435006973	13001	Business	29500.00
0005435039348	13001	Business	29500.00
0005435039616	13001	Business	29500.00
0005434229542	13001	Business	29500.00
0005435039734	13001	Business	29500.00
0005435007004	13001	Economy	9800.00
0005435039805	13001	Economy	9800.00
0005435006848	13001	Economy	9800.00
0005435039720	13001	Economy	9800.00
0005434229527	13001	Economy	9800.00
0005435039612	13001	Economy	9800.00
0005435006915	13001	Economy	9800.00
0005435039578	13001	Economy	9800.00
0005435039751	13001	Economy	9800.00
0005435039635	13001	Economy	9800.00
0005435006931	13001	Economy	9800.00
0005435039766	13001	Economy	9800.00
0005434229534	13001	Economy	9800.00
0005435039412	13001	Economy	9800.00
0005434229526	13001	Economy	9800.00
0005434229524	13001	Economy	9800.00
0005435007009	13001	Economy	9800.00
0005435039719	13001	Economy	9800.00
0005435039558	13001	Economy	9800.00
0005435039687	13001	Economy	9800.00
0005435007011	13001	Economy	9800.00
0005434229541	13001	Economy	9800.00
0005435006881	13001	Economy	9800.00
0005435007019	13001	Economy	9800.00
0005435039686	13001	Economy	9800.00
0005435039707	13001	Economy	9800.00
0005435039735	13001	Economy	9800.00
0005434229535	13001	Economy	9800.00
0005434229521	13001	Economy	9800.00
0005435039363	13001	Economy	9800.00
0005435039365	13001	Economy	9800.00
0005435039329	13001	Economy	9800.00
0005434229539	13001	Economy	9800.00
0005435039752	13001	Economy	9800.00
0005435039841	13001	Economy	9800.00
0005435039521	13001	Economy	9800.00
0005435039700	13001	Economy	9800.00
0005435039443	13001	Economy	9800.00
0005435039525	13001	Economy	9800.00
0005435006928	13001	Economy	9800.00
0005435039550	13001	Economy	10800.00
0005435007022	13001	Economy	10800.00
0005435039669	13001	Economy	10800.00
0005435006882	13001	Economy	10800.00
0005435039360	13001	Economy	10800.00
0005435039619	13001	Economy	10800.00
0005435007020	13001	Economy	9800.00
0005435039842	13001	Economy	9800.00
0005434229528	13001	Economy	9800.00
0005435039227	13001	Economy	9800.00
0005432304425	13001	Economy	9800.00
0005435039835	13001	Economy	9800.00
0005435007010	13001	Economy	9800.00
0005434229532	13001	Economy	9800.00
0005435039567	13001	Economy	9800.00
0005435039679	13001	Economy	9800.00
0005435039602	13001	Economy	9800.00
0005435039737	13001	Economy	9800.00
0005435039859	13001	Economy	9800.00
0005434229536	13001	Economy	9800.00
0005435039663	13001	Economy	9800.00
0005435039854	13001	Economy	9800.00
0005434229525	13001	Economy	9800.00
0005432304427	13001	Economy	9800.00
0005435039718	13001	Economy	9800.00
0005435039793	13001	Economy	9800.00
0005435039533	13001	Economy	9800.00
0005435039639	13001	Economy	9800.00
0005434229523	13001	Economy	9800.00
0005435039676	13001	Economy	9800.00
0005435006962	13001	Economy	9800.00
0005435039617	13001	Economy	9800.00
0005434229544	13001	Economy	9800.00
0005434229533	13001	Economy	9800.00
0005435039633	13001	Economy	9800.00
0005435039422	13001	Economy	9800.00
0005434229530	13001	Economy	9800.00
0005435039618	13001	Economy	9800.00
0005435039794	13001	Economy	9800.00
0005434229531	13001	Economy	9800.00
0005435039476	13001	Economy	9800.00
0005435006927	13001	Economy	9800.00
0005434229543	13001	Economy	9800.00
0005435039586	13001	Economy	9800.00
0005435039641	13001	Economy	9800.00
0005435039640	13001	Economy	9800.00
0005434229522	13001	Economy	9800.00
0005435039645	13001	Economy	9800.00
0005435039753	13001	Economy	9800.00
0005435039328	13001	Economy	9800.00
0005435039797	13001	Economy	9800.00
0005435039685	13001	Economy	9800.00
0005435039865	13001	Economy	9800.00
0005435039357	13001	Economy	9800.00
0005435039364	13001	Economy	9800.00
0005435039502	13001	Economy	9800.00
0005435039209	13001	Economy	9800.00
0005435006944	13001	Economy	9800.00
0005435039733	13001	Economy	9800.00
0005435039500	13001	Economy	9800.00
0005435006954	13001	Economy	9800.00
0005435039566	13001	Economy	9800.00
0005435007084	13001	Economy	9800.00
0005435007075	13001	Economy	9800.00
0005435006914	13001	Economy	9800.00
0005432304424	13001	Economy	9800.00
0005434229540	13001	Economy	9800.00
0005432304426	13001	Economy	9800.00
0005435039210	13001	Economy	9800.00
0005435007066	13001	Economy	9800.00
0005435007067	13001	Economy	9800.00
0005435039522	13001	Economy	9800.00
0005434229529	13001	Economy	9800.00
0005435007036	13001	Economy	9800.00
0005435007076	13001	Economy	9800.00
0005434229538	13001	Economy	9800.00
0005435039442	13001	Economy	9800.00
0005435902729	14902	Business	52900.00
0005434426800	14902	Business	52900.00
0005435902554	14902	Business	52900.00
0005435902728	14902	Business	52900.00
0005434426783	14902	Business	52900.00
0005434426808	14902	Business	52900.00
0005435902747	14902	Business	52900.00
0005432188628	14902	Business	52900.00
0005435902721	14902	Economy	17600.00
0005434426792	14902	Economy	17600.00
0005434426788	14902	Economy	17600.00
0005435902618	14902	Economy	17600.00
0005432188629	14902	Economy	17600.00
0005435902624	14902	Economy	17600.00
0005434426796	14902	Economy	19400.00
0005434426780	14902	Economy	19400.00
0005434426806	14902	Economy	17600.00
0005434411806	14902	Economy	17600.00
0005434426804	14902	Economy	17600.00
0005435554179	14902	Economy	17600.00
0005434426785	14902	Economy	17600.00
0005435902661	14902	Economy	17600.00
0005434426807	14902	Economy	17600.00
0005435902570	14902	Economy	17600.00
0005435902746	14902	Economy	17600.00
0005435902607	14902	Economy	17600.00
0005434426778	14902	Economy	17600.00
0005434426797	14902	Economy	17600.00
0005435902625	14902	Economy	17600.00
0005434426793	14902	Economy	17600.00
0005434426803	14902	Economy	17600.00
0005435902571	14902	Economy	17600.00
0005435902666	14902	Economy	17600.00
0005435902555	14902	Economy	17600.00
0005434411805	14902	Economy	17600.00
0005435902617	14902	Economy	17600.00
0005434426781	14902	Economy	17600.00
0005434426790	14902	Economy	17600.00
0005434426784	14902	Economy	17600.00
0005434426801	14902	Economy	17600.00
0005434426786	14902	Economy	17600.00
0005434426805	14902	Economy	17600.00
0005434426798	14902	Economy	17600.00
0005432188626	14902	Economy	17600.00
0005434411804	14902	Economy	17600.00
0005434426794	14902	Economy	17600.00
0005434426791	14902	Economy	17600.00
0005435902665	14902	Economy	17600.00
0005435902569	14902	Economy	17600.00
0005435902556	14902	Economy	17600.00
0005432188627	14902	Economy	17600.00
0005434426782	14902	Economy	17600.00
0005434426802	14902	Economy	17600.00
0005434426795	14902	Economy	17600.00
0005434426799	14902	Economy	17600.00
0005434426787	14902	Economy	17600.00
0005434426789	14902	Economy	17600.00
0005434426779	14902	Economy	17600.00
0005434426550	20199	Business	52900.00
0005434411761	20199	Business	52900.00
0005434426472	20199	Business	52900.00
0005434426553	20199	Business	52900.00
0005434426593	20199	Business	52900.00
0005434426532	20199	Business	52900.00
0005434426594	20199	Business	52900.00
0005435902840	20199	Business	52900.00
0005435902829	20199	Business	52900.00
0005435902832	20199	Economy	17600.00
0005435902831	20199	Economy	17600.00
0005435554222	20199	Economy	17600.00
0005435902833	20199	Economy	17600.00
0005434426480	20199	Economy	17600.00
0005434426541	20199	Economy	19400.00
0005435902828	20199	Economy	19400.00
0005435902834	20199	Economy	19400.00
0005434426672	20199	Economy	17600.00
0005435554224	20199	Economy	17600.00
0005434426564	20199	Economy	17600.00
0005435554226	20199	Economy	17600.00
0005434426592	20199	Economy	17600.00
0005434426609	20199	Economy	17600.00
0005434426617	20199	Economy	17600.00
0005435554223	20199	Economy	17600.00
0005435902835	20199	Economy	17600.00
0005434426479	20199	Economy	17600.00
0005434411787	20199	Economy	17600.00
0005434426573	20199	Economy	17600.00
0005434426533	20199	Economy	17600.00
0005432059519	20199	Economy	17600.00
0005435902822	20199	Economy	17600.00
0005434426565	20199	Economy	17600.00
0005435902824	20199	Economy	17600.00
0005434426495	20199	Economy	17600.00
0005435902837	20199	Economy	17600.00
0005434426552	20199	Economy	17600.00
0005434426531	20199	Economy	17600.00
0005435902826	20199	Economy	17600.00
0005434426512	20199	Economy	17600.00
0005434411760	20199	Economy	17600.00
0005434426725	20199	Economy	17600.00
0005435902823	20199	Economy	17600.00
0005435554225	20199	Economy	17600.00
0005435902839	20199	Economy	17600.00
0005434426614	20199	Economy	17600.00
0005435902821	20199	Economy	17600.00
0005435902825	20199	Economy	17600.00
0005434426635	20199	Economy	17600.00
0005435902830	20199	Economy	17600.00
0005435902836	20199	Economy	17600.00
0005434426613	20199	Economy	17600.00
0005434426708	20199	Economy	17600.00
0005435902827	20199	Economy	17600.00
0005432059518	20199	Economy	17600.00
0005435902838	20199	Economy	17600.00
0005434426563	20199	Economy	17600.00
0005434426520	20199	Economy	17600.00
0005434426460	20199	Economy	17600.00
0005434426608	20199	Economy	17600.00
0005434426634	20199	Economy	17600.00
0005432462511	30892	Business	106800.00
0005434559097	30892	Economy	35600.00
0005432462513	30892	Economy	35600.00
0005432462508	30892	Economy	35600.00
0005434523789	30892	Economy	35600.00
0005434523787	30892	Economy	35600.00
0005434559098	30892	Economy	35600.00
0005434523790	30892	Economy	35600.00
0005432462502	30892	Economy	35600.00
0005434523784	30892	Economy	35600.00
0005434559096	30892	Economy	39200.00
0005434523783	30892	Economy	35600.00
0005434523786	30892	Economy	35600.00
0005432462517	30892	Economy	35600.00
0005432462509	30892	Economy	35600.00
0005432462501	30892	Economy	35600.00
0005434523791	30892	Economy	35600.00
0005434523788	30892	Economy	35600.00
0005434559099	30892	Economy	35600.00
0005432462500	30892	Economy	35600.00
0005434523785	30892	Economy	35600.00
0005434523792	30892	Economy	35600.00
0005432462503	30892	Economy	35600.00
0005432462518	30892	Economy	35600.00
0005432462504	30892	Economy	35600.00
0005433434474	26513	Business	18500.00
0005432300300	26513	Business	18500.00
0005435982612	26513	Business	18500.00
0005435982602	26513	Business	18500.00
0005435982615	26513	Business	18500.00
0005435982596	26513	Business	18500.00
0005435982581	26513	Business	18500.00
0005435982617	26513	Business	18500.00
0005435982613	26513	Business	18500.00
0005435982607	26513	Business	18500.00
0005435982600	26513	Business	18500.00
0005433434666	26513	Economy	6200.00
0005433434669	26513	Economy	6200.00
0005435982594	26513	Economy	6200.00
0005435982592	26513	Economy	6200.00
0005435982595	26513	Economy	6200.00
0005435982589	26513	Economy	6200.00
0005435982611	26513	Economy	6200.00
0005433434719	26513	Economy	6200.00
0005433434665	26513	Economy	6200.00
0005435982593	26513	Economy	6200.00
0005435982572	26513	Economy	6800.00
0005433434608	26513	Economy	6800.00
0005435982585	26513	Economy	6800.00
0005435982587	26513	Economy	6800.00
0005432300298	26513	Economy	6200.00
0005433434686	26513	Economy	6200.00
0005433434703	26513	Economy	6200.00
0005435982575	26513	Economy	6200.00
0005435982603	26513	Economy	6200.00
0005433434615	26513	Economy	6200.00
0005432300297	26513	Economy	6200.00
0005435982582	26513	Economy	6200.00
0005432300301	26513	Economy	6200.00
0005435982619	26513	Economy	6200.00
0005433434645	26513	Economy	6200.00
0005435982580	26513	Economy	6200.00
0005435982588	26513	Economy	6200.00
0005435982579	26513	Economy	6200.00
0005435982573	26513	Economy	6200.00
0005432300299	26513	Economy	6200.00
0005432300302	26513	Economy	6200.00
0005435982571	26513	Economy	6200.00
0005435982610	26513	Economy	6200.00
0005434270195	26513	Economy	6200.00
0005433434600	26513	Economy	6200.00
0005433434520	26513	Economy	6200.00
0005433434560	26513	Economy	6200.00
0005435982609	26513	Economy	6200.00
0005433434617	26513	Economy	6200.00
0005433434718	26513	Economy	6200.00
0005435982583	26513	Economy	6200.00
0005435982614	26513	Economy	6200.00
0005434270203	26513	Economy	6200.00
0005433434601	26513	Economy	6200.00
0005435982618	26513	Economy	6200.00
0005434270209	26513	Economy	6200.00
0005435982591	26513	Economy	6200.00
0005433434542	26513	Economy	6200.00
0005435982584	26513	Economy	6200.00
0005435982604	26513	Economy	6200.00
0005434273071	26513	Economy	6200.00
0005435982605	26513	Economy	6200.00
0005435982590	26513	Economy	6200.00
0005433434496	26513	Economy	6200.00
0005433434577	26513	Economy	6200.00
0005435982599	26513	Economy	6200.00
0005434273069	26513	Economy	6200.00
0005433434475	26513	Economy	6200.00
0005433434525	26513	Economy	6200.00
0005435982616	26513	Economy	6200.00
0005435982576	26513	Economy	6200.00
0005435982608	26513	Economy	6200.00
0005435982578	26513	Economy	6200.00
0005435982574	26513	Economy	6200.00
0005433434578	26513	Economy	6200.00
0005433434495	26513	Economy	6200.00
0005435982577	26513	Economy	6200.00
0005435982601	26513	Economy	6200.00
0005435982586	26513	Economy	6200.00
0005435982597	26513	Economy	6200.00
0005433434476	26513	Economy	6200.00
0005435982598	26513	Economy	6200.00
0005435982606	26513	Economy	6200.00
0005435982191	26713	Business	18500.00
0005435982246	26713	Business	18500.00
0005435982309	26713	Business	18500.00
0005433434874	26713	Business	18500.00
0005433434897	26713	Business	18500.00
0005435982129	26713	Business	18500.00
0005435982212	26713	Business	18500.00
0005433434894	26713	Business	18500.00
0005435982267	26713	Business	18500.00
0005433434878	26713	Business	18500.00
0005434269119	26713	Business	18500.00
0005435981916	26713	Economy	6200.00
0005435982253	26713	Economy	6200.00
0005433434892	26713	Economy	6200.00
0005434271327	26713	Economy	6200.00
0005433434880	26713	Economy	6200.00
0005435982256	26713	Economy	6200.00
0005433434884	26713	Economy	6200.00
0005433434898	26713	Economy	6200.00
0005435982213	26713	Economy	6200.00
0005433434883	26713	Economy	6200.00
0005433434891	26713	Economy	6800.00
0005433434888	26713	Economy	6800.00
0005435982240	26713	Economy	6800.00
0005435982217	26713	Economy	6800.00
0005435982221	26713	Economy	6200.00
0005433434876	26713	Economy	6200.00
0005434269118	26713	Economy	6200.00
0005435982372	26713	Economy	6200.00
0005435982275	26713	Economy	6200.00
0005435981975	26713	Economy	6200.00
0005433434885	26713	Economy	6200.00
0005435982333	26713	Economy	6200.00
0005435982146	26713	Economy	6200.00
0005435982363	26713	Economy	6200.00
0005435982071	26713	Economy	6200.00
0005434271328	26713	Economy	6200.00
0005435982047	26713	Economy	6200.00
0005433434873	26713	Economy	6200.00
0005435982254	26713	Economy	6200.00
0005435982147	26713	Economy	6200.00
0005433434886	26713	Economy	6200.00
0005435982362	26713	Economy	6200.00
0005432051150	26713	Economy	6200.00
0005433434875	26713	Economy	6200.00
0005435982283	26713	Economy	6200.00
0005435982218	26713	Economy	6200.00
0005433434889	26713	Economy	6200.00
0005433434877	26713	Economy	6200.00
0005434270221	26713	Economy	6200.00
0005435982110	26713	Economy	6200.00
0005435982307	26713	Economy	6200.00
0005435982261	26713	Economy	6200.00
0005435982046	26713	Economy	6200.00
0005432051152	26713	Economy	6200.00
0005433434882	26713	Economy	6200.00
0005435982268	26713	Economy	6200.00
0005435982211	26713	Economy	6200.00
0005435982170	26713	Economy	6200.00
0005435982276	26713	Economy	6200.00
0005435982284	26713	Economy	6200.00
0005435982190	26713	Economy	6200.00
0005434270222	26713	Economy	6200.00
0005435982208	26713	Economy	6200.00
0005433434890	26713	Economy	6200.00
0005433434887	26713	Economy	6200.00
0005435982173	26713	Economy	6200.00
0005435982168	26713	Economy	6200.00
0005435981981	26713	Economy	6200.00
0005433434896	26713	Economy	6200.00
0005433434881	26713	Economy	6200.00
0005433434879	26713	Economy	6200.00
0005435981974	26713	Economy	6200.00
0005434269120	26713	Economy	6200.00
0005435982207	26713	Economy	6200.00
0005433434893	26713	Economy	6200.00
0005435982174	26713	Economy	6200.00
0005433434871	26713	Economy	6200.00
0005433434872	26713	Economy	6200.00
0005435982070	26713	Economy	6200.00
0005435982096	26713	Economy	6200.00
0005435982255	26713	Economy	6200.00
0005435982169	26713	Economy	6200.00
0005435982236	26713	Economy	6200.00
0005433434895	26713	Economy	6200.00
0005435982056	26713	Economy	6200.00
0005435982167	26713	Economy	6200.00
0005432051151	26713	Economy	6200.00
0005432858096	3149	Economy	11100.00
0005432584221	3149	Economy	11100.00
0005432584222	3149	Economy	11100.00
0005432584205	3149	Economy	10100.00
0005432584227	3149	Economy	10100.00
0005432858062	3149	Economy	10100.00
0005432584214	3149	Economy	10100.00
0005432584211	3149	Economy	10100.00
0005432584219	3149	Economy	10100.00
0005432858104	3149	Economy	10100.00
0005432216293	3149	Economy	10100.00
0005432858056	3149	Economy	10100.00
0005432858064	3149	Economy	10100.00
0005432584204	3149	Economy	10100.00
0005432858097	3149	Economy	10100.00
0005432584208	3149	Economy	10100.00
0005432216292	3149	Economy	10100.00
0005432584226	3149	Economy	10100.00
0005432858024	3149	Economy	10100.00
0005432858093	3149	Economy	10100.00
0005432584201	3149	Economy	10100.00
0005432858054	3149	Economy	10100.00
0005432584207	3149	Economy	10100.00
0005432584213	3149	Economy	10100.00
0005432584218	3149	Economy	10100.00
0005432584225	3149	Economy	10100.00
0005432584224	3149	Economy	10100.00
0005432584220	3149	Economy	10100.00
0005432584223	3149	Economy	10100.00
0005432584212	3149	Economy	10100.00
0005432584203	3149	Economy	10100.00
0005432858007	3149	Economy	10100.00
0005432584210	3149	Economy	10100.00
0005432858035	3149	Economy	10100.00
0005432584217	3149	Economy	10100.00
0005432584202	3149	Economy	10100.00
0005432584209	3149	Economy	10100.00
0005432584215	3149	Economy	10100.00
0005432584216	3149	Economy	10100.00
0005432858105	3149	Economy	10100.00
0005432584206	3149	Economy	10100.00
0005432858149	31466	Economy	11100.00
0005432584004	31466	Economy	11100.00
0005432584060	31466	Economy	11100.00
0005432583996	31466	Economy	11100.00
0005432584038	31466	Economy	10100.00
0005432584003	31466	Economy	10100.00
0005432858151	31466	Economy	10100.00
0005432583897	31466	Economy	10100.00
0005432584095	31466	Economy	10100.00
0005432584002	31466	Economy	10100.00
0005432584017	31466	Economy	10100.00
0005432858156	31466	Economy	10100.00
0005432858150	31466	Economy	10100.00
0005432858159	31466	Economy	10100.00
0005432584016	31466	Economy	10100.00
0005432584050	31466	Economy	10100.00
0005432858153	31466	Economy	10100.00
0005432584012	31466	Economy	10100.00
0005432584039	31466	Economy	10100.00
0005432583998	31466	Economy	10100.00
0005432584059	31466	Economy	10100.00
0005432584029	31466	Economy	10100.00
0005432858157	31466	Economy	10100.00
0005432584030	31466	Economy	10100.00
0005432858158	31466	Economy	10100.00
0005432858155	31466	Economy	10100.00
0005432583950	31466	Economy	10100.00
0005432858154	31466	Economy	10100.00
0005432583949	31466	Economy	10100.00
0005432858148	31466	Economy	10100.00
0005432584094	31466	Economy	10100.00
0005432584061	31466	Economy	10100.00
0005432584001	31466	Economy	10100.00
0005432583995	31466	Economy	10100.00
0005432584171	31466	Economy	10100.00
0005432583945	31466	Economy	10100.00
0005432858152	31466	Economy	10100.00
0005432584018	31466	Economy	10100.00
0005432583937	31466	Economy	10100.00
0005432584011	31466	Economy	10100.00
0005432584025	31466	Economy	10100.00
0005434943414	855	Economy	7500.00
0005434943413	855	Economy	7500.00
0005434943416	855	Economy	7500.00
0005434943417	855	Economy	7500.00
0005433255115	855	Economy	7500.00
0005434943419	855	Economy	7500.00
0005434943412	855	Economy	7500.00
0005434943421	855	Economy	7500.00
0005434943418	855	Economy	7500.00
0005433255114	855	Economy	7500.00
0005434943415	855	Economy	7500.00
0005434943420	855	Economy	7500.00
0005434943360	16223	Economy	8300.00
0005434943372	16223	Economy	7500.00
0005434943371	16223	Economy	7500.00
0005434943353	16223	Economy	7500.00
0005433255160	16223	Economy	7500.00
0005434943359	16223	Economy	7500.00
0005433255158	16223	Economy	7500.00
0005433255159	16223	Economy	7500.00
0005433255156	16223	Economy	7500.00
0005434943350	16223	Economy	7500.00
0005433255157	16223	Economy	7500.00
0005433255162	16223	Economy	7500.00
0005434943331	16223	Economy	7500.00
0005434943345	16223	Economy	7500.00
0005434943349	16223	Economy	7500.00
0005434943346	16223	Economy	7500.00
0005434943312	16223	Economy	7500.00
0005433255155	16223	Economy	7500.00
0005434943340	16223	Economy	7500.00
0005433255161	16223	Economy	7500.00
0005433654750	27618	Business	90500.00
0005433654713	27618	Business	90500.00
0005435858589	27618	Business	90500.00
0005433654715	27618	Business	90500.00
0005433654737	27618	Business	90500.00
0005433654716	27618	Business	90500.00
0005435858580	27618	Economy	30200.00
0005435858584	27618	Economy	30200.00
0005435858590	27618	Economy	30200.00
0005435858592	27618	Economy	30200.00
0005433654759	27618	Economy	30200.00
0005433654711	27618	Economy	30200.00
0005433654753	27618	Economy	30200.00
0005433654749	27618	Economy	33200.00
0005433654714	27618	Economy	33200.00
0005433654767	27618	Economy	33200.00
0005435858594	27618	Economy	30200.00
0005433654740	27618	Economy	30200.00
0005435858587	27618	Economy	30200.00
0005433654780	27618	Economy	30200.00
0005433654771	27618	Economy	30200.00
0005433654741	27618	Economy	30200.00
0005433654738	27618	Economy	30200.00
0005435858579	27618	Economy	30200.00
0005433654758	27618	Economy	30200.00
0005435858582	27618	Economy	30200.00
0005433654756	27618	Economy	30200.00
0005433654742	27618	Economy	30200.00
0005433654751	27618	Economy	30200.00
0005433654712	27618	Economy	30200.00
0005435858585	27618	Economy	30200.00
0005433654743	27618	Economy	30200.00
0005435858586	27618	Economy	30200.00
0005433654773	27618	Economy	30200.00
0005433654752	27618	Economy	30200.00
0005433654776	27618	Economy	30200.00
0005433654754	27618	Economy	30200.00
0005433654739	27618	Economy	30200.00
0005435858591	27618	Economy	30200.00
0005433654745	27618	Economy	30200.00
0005435858581	27618	Economy	30200.00
0005435858593	27618	Economy	30200.00
0005433654762	27618	Economy	30200.00
0005435858583	27618	Economy	30200.00
0005433654757	27618	Economy	30200.00
0005435858588	27618	Economy	30200.00
0005435653345	21735	Business	9800.00
0005435653307	21735	Business	9800.00
0005435653344	21735	Business	9800.00
0005433367698	21735	Business	9800.00
0005433367810	21735	Business	9800.00
0005433367924	21735	Business	9800.00
0005433367617	21735	Business	9800.00
0005435653348	21735	Business	9800.00
0005435653336	21735	Business	9800.00
0005435653331	21735	Business	9800.00
0005433367767	21735	Business	9800.00
0005435653342	21735	Business	9800.00
0005435653304	21735	Economy	3300.00
0005435653334	21735	Economy	3300.00
0005433367788	21735	Economy	3300.00
0005435653303	21735	Economy	3300.00
0005433367846	21735	Economy	3300.00
0005433367887	21735	Economy	3300.00
0005435653338	21735	Economy	3300.00
0005435653306	21735	Economy	3600.00
0005435653296	21735	Economy	3600.00
0005435653346	21735	Economy	3600.00
0005435653347	21735	Economy	3300.00
0005435653327	21735	Economy	3300.00
0005435653299	21735	Economy	3300.00
0005433367738	21735	Economy	3300.00
0005435653324	21735	Economy	3300.00
0005433367756	21735	Economy	3300.00
0005435653329	21735	Economy	3300.00
0005435653332	21735	Economy	3300.00
0005435653339	21735	Economy	3300.00
0005435653325	21735	Economy	3300.00
0005433367735	21735	Economy	3300.00
0005433367763	21735	Economy	3300.00
0005435653310	21735	Economy	3300.00
0005435653317	21735	Economy	3300.00
0005435653343	21735	Economy	3300.00
0005435653323	21735	Economy	3300.00
0005435653297	21735	Economy	3300.00
0005433367768	21735	Economy	3300.00
0005435653311	21735	Economy	3300.00
0005435653326	21735	Economy	3300.00
0005435653340	21735	Economy	3300.00
0005435653301	21735	Economy	3300.00
0005435653305	21735	Economy	3300.00
0005435653300	21735	Economy	3300.00
0005433367685	21735	Economy	3300.00
0005435653298	21735	Economy	3300.00
0005435653322	21735	Economy	3300.00
0005433367802	21735	Economy	3300.00
0005435653313	21735	Economy	3300.00
0005435653312	21735	Economy	3300.00
0005435653333	21735	Economy	3300.00
0005435653309	21735	Economy	3300.00
0005433367773	21735	Economy	3300.00
0005433367809	21735	Economy	3300.00
0005435653337	21735	Economy	3300.00
0005433367934	21735	Economy	3300.00
0005435653341	21735	Economy	3300.00
0005435653295	21735	Economy	3300.00
0005435653315	21735	Economy	3300.00
0005433367684	21735	Economy	3300.00
0005435653321	21735	Economy	3300.00
0005433367762	21735	Economy	3300.00
0005435653318	21735	Economy	3300.00
0005435653316	21735	Economy	3300.00
0005433367847	21735	Economy	3300.00
0005435653328	21735	Economy	3300.00
0005435653320	21735	Economy	3300.00
0005435653330	21735	Economy	3300.00
0005435653335	21735	Economy	3300.00
0005435653319	21735	Economy	3300.00
0005435653314	21735	Economy	3300.00
0005435653302	21735	Economy	3300.00
0005433367902	21735	Economy	3300.00
0005435653308	21735	Economy	3300.00
0005433367618	21735	Economy	3300.00
0005433367886	21735	Economy	3300.00
0005433785220	9362	Business	186200.00
0005433785195	9362	Business	186200.00
0005433763312	9362	Business	186200.00
0005434273070	9362	Business	186200.00
0005433785218	9362	Business	186200.00
0005434151708	9362	Business	186200.00
0005433785202	9362	Business	186200.00
0005434171049	9362	Business	186200.00
0005433785222	9362	Business	186200.00
0005434151687	9362	Business	186200.00
0005433763305	9362	Business	186200.00
0005432657472	9362	Business	186200.00
0005433763303	9362	Business	186200.00
0005433805621	9362	Business	186200.00
0005434270212	9362	Business	186200.00
0005433785197	9362	Business	186200.00
0005433785212	9362	Business	186200.00
0005432665290	9362	Business	186200.00
0005433785215	9362	Economy	68300.00
0005434171044	9362	Economy	68300.00
0005433805622	9362	Economy	62100.00
0005433763313	9362	Economy	62100.00
0005433785192	9362	Economy	62100.00
0005434170990	9362	Economy	62100.00
0005434170977	9362	Economy	62100.00
0005433805626	9362	Economy	62100.00
0005433805620	9362	Economy	62100.00
0005433785198	9362	Economy	62100.00
0005433785201	9362	Economy	62100.00
0005433805623	9362	Economy	62100.00
0005432657470	9362	Economy	62100.00
0005434170978	9362	Economy	62100.00
0005433785190	9362	Economy	62100.00
0005433805633	9362	Economy	62100.00
0005433805616	9362	Economy	62100.00
0005433785199	9362	Economy	62100.00
0005433805625	9362	Economy	62100.00
0005434171004	9362	Economy	62100.00
0005434171034	9362	Economy	62100.00
0005434171048	9362	Economy	62100.00
0005433785211	9362	Economy	62100.00
0005433785209	9362	Economy	62100.00
0005433785216	9362	Economy	62100.00
0005433785213	9362	Economy	62100.00
0005434171018	9362	Economy	62100.00
0005434171071	9362	Economy	62100.00
0005433763308	9362	Economy	62100.00
0005433763306	9362	Economy	62100.00
0005434171055	9362	Economy	62100.00
0005433763302	9362	Economy	62100.00
0005433785188	9362	Economy	62100.00
0005433805641	9362	Economy	62100.00
0005433805635	9362	Economy	62100.00
0005433763309	9362	Economy	62100.00
0005433785204	9362	Economy	62100.00
0005433785196	9362	Economy	62100.00
0005433805631	9362	Economy	62100.00
0005432657471	9362	Economy	62100.00
0005433805636	9362	Economy	62100.00
0005432666404	9362	Economy	62100.00
0005432667469	9362	Economy	62100.00
0005433805629	9362	Economy	62100.00
0005434171035	9362	Economy	62100.00
0005433763311	9362	Economy	62100.00
0005433785205	9362	Economy	62100.00
0005433785207	9362	Economy	62100.00
0005433763310	9362	Economy	62100.00
0005434171017	9362	Economy	62100.00
0005433805638	9362	Economy	62100.00
0005432657469	9362	Economy	62100.00
0005433805618	9362	Economy	62100.00
0005433763307	9362	Economy	62100.00
0005433805617	9362	Economy	62100.00
0005434171088	9362	Economy	62100.00
0005433805619	9362	Economy	62100.00
0005433785206	9362	Economy	62100.00
0005434171097	9362	Economy	62100.00
0005433785214	9362	Economy	62100.00
0005433805628	9362	Economy	62100.00
0005433805643	9362	Economy	62100.00
0005432667470	9362	Economy	68300.00
0005434171009	9362	Economy	62100.00
0005434170976	9362	Economy	62100.00
0005433785217	9362	Economy	62100.00
0005432665288	9362	Economy	62100.00
0005433785208	9362	Economy	62100.00
0005434151686	9362	Economy	62100.00
0005433785221	9362	Economy	62100.00
0005433805642	9362	Economy	62100.00
0005434270208	9362	Economy	62100.00
0005434171003	9362	Economy	62100.00
0005433785210	9362	Economy	62100.00
0005432666403	9362	Economy	62100.00
0005433805632	9362	Economy	62100.00
0005433785203	9362	Economy	62100.00
0005433805637	9362	Economy	62100.00
0005433785219	9362	Economy	62100.00
0005433763316	9362	Economy	62100.00
0005435269672	9362	Economy	62100.00
0005433805640	9362	Economy	62100.00
0005434171089	9362	Economy	62100.00
0005434171072	9362	Economy	62100.00
0005433763304	9362	Economy	62100.00
0005434171073	9362	Economy	62100.00
0005434171014	9362	Economy	62100.00
0005433805624	9362	Economy	62100.00
0005433805634	9362	Economy	62100.00
0005433763314	9362	Economy	62100.00
0005433805630	9362	Economy	62100.00
0005433785194	9362	Economy	62100.00
0005432665289	9362	Economy	62100.00
0005435269673	9362	Economy	62100.00
0005433785200	9362	Economy	62100.00
0005433785193	9362	Economy	62100.00
0005434151688	9362	Economy	62100.00
0005433805639	9362	Economy	62100.00
0005433785189	9362	Economy	62100.00
0005433763315	9362	Economy	62100.00
0005433805627	9362	Economy	62100.00
0005433785191	9362	Economy	62100.00
0005434170989	9362	Economy	62100.00
0005434171153	26267	Business	186200.00
0005433784830	26267	Business	186200.00
0005434171161	26267	Business	186200.00
0005433784875	26267	Business	186200.00
0005433784813	26267	Business	186200.00
0005433784747	26267	Business	186200.00
0005434171152	26267	Business	186200.00
0005433805307	26267	Business	186200.00
0005433785027	26267	Business	186200.00
0005435269791	26267	Business	186200.00
0005433784795	26267	Business	186200.00
0005433763167	26267	Business	186200.00
0005434271326	26267	Business	186200.00
0005433785003	26267	Business	186200.00
0005433805429	26267	Economy	68300.00
0005433805378	26267	Economy	68300.00
0005435269793	26267	Economy	68300.00
0005434270220	26267	Economy	62100.00
0005433784880	26267	Economy	62100.00
0005435269787	26267	Economy	62100.00
0005434269116	26267	Economy	62100.00
0005434171163	26267	Economy	62100.00
0005433785026	26267	Economy	62100.00
0005433805368	26267	Economy	62100.00
0005433784917	26267	Economy	62100.00
0005435269794	26267	Economy	62100.00
0005433805342	26267	Economy	62100.00
0005433784797	26267	Economy	62100.00
0005434171154	26267	Economy	62100.00
0005433805329	26267	Economy	62100.00
0005434270219	26267	Economy	62100.00
0005433805356	26267	Economy	62100.00
0005433784845	26267	Economy	62100.00
0005433784970	26267	Economy	62100.00
0005434151725	26267	Economy	62100.00
0005433805370	26267	Economy	62100.00
0005433805432	26267	Economy	62100.00
0005433784905	26267	Economy	62100.00
0005433784796	26267	Economy	62100.00
0005433805427	26267	Economy	62100.00
0005433805371	26267	Economy	62100.00
0005435269790	26267	Economy	62100.00
0005433784911	26267	Economy	62100.00
0005433763218	26267	Economy	62100.00
0005435269788	26267	Economy	62100.00
0005434171156	26267	Economy	62100.00
0005433805272	26267	Economy	62100.00
0005433784935	26267	Economy	62100.00
0005435269786	26267	Economy	62100.00
0005433763183	26267	Economy	62100.00
0005434171162	26267	Economy	62100.00
0005433805402	26267	Economy	62100.00
0005434271325	26267	Economy	62100.00
0005433805262	26267	Economy	62100.00
0005433805433	26267	Economy	62100.00
0005433763166	26267	Economy	62100.00
0005435269792	26267	Economy	62100.00
0005434269117	26267	Economy	62100.00
0005433805343	26267	Economy	62100.00
0005433785002	26267	Economy	62100.00
0005433763219	26267	Economy	62100.00
0005434171149	26267	Economy	62100.00
0005433784900	26267	Economy	62100.00
0005433805256	26267	Economy	62100.00
0005433805347	26267	Economy	62100.00
0005433784746	26267	Economy	62100.00
0005434171157	26267	Economy	62100.00
0005433805306	26267	Economy	62100.00
0005433805384	26267	Economy	62100.00
0005433805328	26267	Economy	62100.00
0005433784937	26267	Economy	62100.00
0005433805399	26267	Economy	62100.00
0005433763184	26267	Economy	62100.00
0005433805323	26267	Economy	62100.00
0005433784806	26267	Economy	62100.00
0005433784879	26267	Economy	62100.00
0005433805261	26267	Economy	62100.00
0005433784862	26267	Economy	62100.00
0005434171150	26267	Economy	62100.00
0005433784955	26267	Economy	62100.00
0005432657450	26267	Economy	62100.00
0005432659706	26267	Economy	68300.00
0005433784916	26267	Economy	62100.00
0005432659705	26267	Economy	68300.00
0005433784920	26267	Economy	62100.00
0005433805390	26267	Economy	62100.00
0005433805253	26267	Economy	62100.00
0005433805383	26267	Economy	62100.00
0005433784928	26267	Economy	62100.00
0005433763237	26267	Economy	62100.00
0005433805302	26267	Economy	62100.00
0005434271324	26267	Economy	62100.00
0005433784888	26267	Economy	62100.00
0005433805297	26267	Economy	62100.00
0005433805362	26267	Economy	62100.00
0005433805401	26267	Economy	62100.00
0005433784977	26267	Economy	62100.00
0005434151724	26267	Economy	62100.00
0005433805273	26267	Economy	62100.00
0005433763168	26267	Economy	62100.00
0005433784927	26267	Economy	62100.00
0005433805318	26267	Economy	62100.00
0005433784936	26267	Economy	62100.00
0005434171160	26267	Economy	62100.00
0005433763165	26267	Economy	62100.00
0005432659695	26267	Economy	62100.00
0005433763139	26267	Economy	62100.00
0005433805303	26267	Economy	62100.00
0005434171151	26267	Economy	62100.00
0005434151723	26267	Economy	62100.00
0005433784844	26267	Economy	62100.00
0005433784781	26267	Economy	62100.00
0005435269789	26267	Economy	62100.00
0005433805276	26267	Economy	62100.00
0005435269795	26267	Economy	62100.00
0005434171158	26267	Economy	62100.00
0005432657448	26267	Economy	62100.00
0005434171159	26267	Economy	62100.00
0005433763238	26267	Economy	62100.00
0005433805428	26267	Economy	62100.00
0005433784782	26267	Economy	62100.00
0005433784944	26267	Economy	62100.00
0005432666380	26267	Economy	62100.00
0005432659696	26267	Economy	62100.00
0005433805400	26267	Economy	62100.00
0005433784846	26267	Economy	62100.00
0005434171155	26267	Economy	62100.00
0005433784973	26267	Economy	62100.00
0005433784720	26267	Economy	62100.00
0005435135703	4936	Economy	5900.00
0005435135706	4936	Economy	5300.00
0005435135702	4936	Economy	5300.00
0005435929644	4936	Economy	5300.00
0005435135705	4936	Economy	5300.00
0005435135704	4936	Economy	5300.00
0005435929641	4936	Economy	5300.00
0005435929663	33048	Economy	5900.00
0005435929662	33048	Economy	5300.00
0005435135653	33048	Economy	5300.00
0005435135656	33048	Economy	5300.00
0005435135654	33048	Economy	5300.00
0005435929664	33048	Economy	5300.00
0005434217938	9508	Economy	17900.00
0005434217956	9508	Economy	17900.00
0005434983326	9508	Economy	17900.00
0005434983323	9508	Economy	17900.00
0005434217957	9508	Economy	17900.00
0005434217955	9508	Economy	17900.00
0005434983325	9508	Economy	17900.00
0005434983324	9508	Economy	17900.00
0005434217954	9508	Economy	17900.00
0005434217948	9508	Economy	17900.00
0005434217949	9508	Economy	17900.00
0005434983322	9508	Economy	17900.00
0005434983327	9508	Economy	17900.00
0005434217939	9508	Economy	17900.00
0005434217958	9508	Economy	17900.00
0005434217996	27365	Economy	17900.00
0005434217997	27365	Economy	17900.00
0005434983284	27365	Economy	17900.00
0005434217998	27365	Economy	17900.00
0005434983291	27365	Economy	17900.00
0005434983287	27365	Economy	17900.00
0005433960410	24286	Business	36400.00
0005433960678	24286	Business	36400.00
0005433960519	24286	Business	36400.00
0005433985772	24286	Business	36400.00
0005433985852	24286	Business	36400.00
0005433985791	24286	Business	36400.00
0005433985926	24286	Business	36400.00
0005433985735	24286	Business	36400.00
0005433960628	24286	Business	36400.00
0005433985863	24286	Business	36400.00
0005433985813	24286	Business	36400.00
0005433985637	24286	Business	36400.00
0005433960786	24286	Business	36400.00
0005433960774	24286	Business	36400.00
0005433960595	24286	Business	36400.00
0005433960621	24286	Economy	13400.00
0005433985839	24286	Economy	13400.00
0005433960725	24286	Economy	13400.00
0005433985747	24286	Economy	13400.00
0005433985879	24286	Economy	12100.00
0005433985874	24286	Economy	12100.00
0005433960663	24286	Economy	12100.00
0005433985857	24286	Economy	12100.00
0005433985806	24286	Economy	12100.00
0005433960488	24286	Economy	12100.00
0005433960709	24286	Economy	12100.00
0005433985783	24286	Economy	12100.00
0005433960604	24286	Economy	12100.00
0005433960474	24286	Economy	12100.00
0005433960473	24286	Economy	12100.00
0005433985900	24286	Economy	12100.00
0005433985798	24286	Economy	12100.00
0005433960596	24286	Economy	12100.00
0005433960779	24286	Economy	12100.00
0005433960560	24286	Economy	12100.00
0005433960564	24286	Economy	12100.00
0005433960789	24286	Economy	12100.00
0005433960561	24286	Economy	12100.00
0005433985850	24286	Economy	12100.00
0005433960680	24286	Economy	12100.00
0005433960659	24286	Economy	12100.00
0005433960708	24286	Economy	12100.00
0005433985838	24286	Economy	12100.00
0005433985638	24286	Economy	12100.00
0005433985802	24286	Economy	12100.00
0005433985765	24286	Economy	12100.00
0005433960679	24286	Economy	12100.00
0005433960744	24286	Economy	12100.00
0005433985935	24286	Economy	12100.00
0005433960780	24286	Economy	12100.00
0005433960660	24286	Economy	12100.00
0005433985832	24286	Economy	12100.00
0005433960743	24286	Economy	12100.00
0005433985799	24286	Economy	12100.00
0005433960623	24286	Economy	12100.00
0005433960569	24286	Economy	12100.00
0005433985780	24286	Economy	12100.00
0005433985998	24286	Economy	12100.00
0005433960635	24286	Economy	12100.00
0005433985910	24286	Economy	12100.00
0005433985776	24286	Economy	12100.00
0005433985875	24286	Economy	12100.00
0005433985779	24286	Economy	13400.00
0005433960675	24286	Economy	12100.00
0005433960758	24286	Economy	12100.00
0005433960706	24286	Economy	12100.00
0005433960676	24286	Economy	12100.00
0005433960570	24286	Economy	12100.00
0005433985736	24286	Economy	12100.00
0005433960707	24286	Economy	12100.00
0005433960661	24286	Economy	12100.00
0005433985936	24286	Economy	12100.00
0005433985673	24286	Economy	12100.00
0005433960641	24286	Economy	12100.00
0005433985837	24286	Economy	12100.00
0005433986020	24286	Economy	12100.00
0005433960773	24286	Economy	12100.00
0005433985876	24286	Economy	12100.00
0005433985862	24286	Economy	12100.00
0005433960629	24286	Economy	12100.00
0005433985792	24286	Economy	12100.00
0005433960622	24286	Economy	12100.00
0005433985915	24286	Economy	12100.00
0005433960562	24286	Economy	12100.00
0005433960658	24286	Economy	12100.00
0005433985851	24286	Economy	12100.00
0005433985867	24286	Economy	12100.00
0005433986214	24286	Economy	12100.00
0005433960620	24286	Economy	12100.00
0005433985919	24286	Economy	12100.00
0005433985796	24286	Economy	12100.00
0005433960790	24286	Economy	12100.00
0005433985804	24286	Economy	12100.00
0005433985588	24286	Economy	12100.00
0005433960502	24286	Economy	12100.00
0005433985842	24286	Economy	12100.00
0005433960619	24286	Economy	12100.00
0005433985803	24286	Economy	12100.00
0005433960618	24286	Economy	12100.00
0005433985877	24286	Economy	12100.00
0005433985856	24286	Economy	12100.00
0005433960762	24286	Economy	12100.00
0005433960785	24286	Economy	12100.00
0005433985878	24286	Economy	12100.00
0005433985873	24286	Economy	12100.00
0005433985702	24286	Economy	12100.00
0005433961217	25941	Business	36400.00
0005433986226	25941	Business	36400.00
0005433961236	25941	Business	36400.00
0005433986234	25941	Business	36400.00
0005433986244	25941	Business	36400.00
0005433986241	25941	Business	36400.00
0005433986245	25941	Business	36400.00
0005433961251	25941	Business	36400.00
0005433986253	25941	Business	36400.00
0005433986231	25941	Business	36400.00
0005433986237	25941	Business	36400.00
0005433986221	25941	Business	36400.00
0005433961232	25941	Business	36400.00
0005433961238	25941	Business	36400.00
0005433961215	25941	Business	36400.00
0005433961218	25941	Economy	13400.00
0005433961260	25941	Economy	12100.00
0005433986249	25941	Economy	12100.00
0005433961262	25941	Economy	12100.00
0005433986240	25941	Economy	12100.00
0005433961245	25941	Economy	12100.00
0005433961213	25941	Economy	12100.00
0005433961250	25941	Economy	12100.00
0005433961252	25941	Economy	12100.00
0005433961216	25941	Economy	12100.00
0005433961229	25941	Economy	12100.00
0005433961220	25941	Economy	12100.00
0005433961249	25941	Economy	12100.00
0005433986243	25941	Economy	12100.00
0005433986224	25941	Economy	12100.00
0005433986223	25941	Economy	12100.00
0005433961244	25941	Economy	12100.00
0005433986230	25941	Economy	12100.00
0005433961256	25941	Economy	12100.00
0005433961248	25941	Economy	12100.00
0005433986239	25941	Economy	12100.00
0005433986235	25941	Economy	12100.00
0005433986256	25941	Economy	12100.00
0005433961235	25941	Economy	12100.00
0005433961221	25941	Economy	12100.00
0005433986219	25941	Economy	12100.00
0005433961261	25941	Economy	12100.00
0005433961231	25941	Economy	12100.00
0005433961257	25941	Economy	12100.00
0005433986236	25941	Economy	12100.00
0005433986250	25941	Economy	12100.00
0005433961225	25941	Economy	12100.00
0005433961214	25941	Economy	12100.00
0005433986247	25941	Economy	12100.00
0005433961240	25941	Economy	12100.00
0005433961254	25941	Economy	12100.00
0005433986257	25941	Economy	12100.00
0005433986233	25941	Economy	12100.00
0005433986258	25941	Economy	12100.00
0005433961242	25941	Economy	12100.00
0005433961226	25941	Economy	13400.00
0005433961239	25941	Economy	13400.00
0005433961234	25941	Economy	12100.00
0005433986254	25941	Economy	12100.00
0005433961243	25941	Economy	12100.00
0005433961228	25941	Economy	12100.00
0005433961230	25941	Economy	12100.00
0005433961258	25941	Economy	12100.00
0005433961212	25941	Economy	12100.00
0005433986227	25941	Economy	12100.00
0005433961222	25941	Economy	12100.00
0005433986229	25941	Economy	12100.00
0005433986242	25941	Economy	12100.00
0005433986228	25941	Economy	12100.00
0005433986222	25941	Economy	12100.00
0005433986220	25941	Economy	12100.00
0005433961259	25941	Economy	12100.00
0005433986251	25941	Economy	12100.00
0005433961247	25941	Economy	12100.00
0005433961237	25941	Economy	12100.00
0005433986252	25941	Economy	12100.00
0005433986255	25941	Economy	12100.00
0005433986232	25941	Economy	12100.00
0005433986246	25941	Economy	12100.00
0005433961253	25941	Economy	12100.00
0005433961227	25941	Economy	12100.00
0005433961219	25941	Economy	12100.00
0005433961224	25941	Economy	12100.00
0005433986248	25941	Economy	12100.00
0005433986225	25941	Economy	12100.00
0005433961233	25941	Economy	12100.00
0005433961223	25941	Economy	12100.00
0005433961255	25941	Economy	12100.00
0005433986238	25941	Economy	12100.00
0005433961246	25941	Economy	12100.00
0005433961241	25941	Economy	12100.00
0005434480515	939	Economy	25400.00
0005433165926	939	Economy	25400.00
0005434480512	939	Economy	25400.00
0005434480511	939	Economy	25400.00
0005433165884	939	Economy	23100.00
0005433165880	939	Economy	23100.00
0005434480507	939	Economy	23100.00
0005432269515	939	Economy	23100.00
0005433165876	939	Economy	23100.00
0005433165847	939	Economy	23100.00
0005433165848	939	Economy	23100.00
0005432269516	939	Economy	23100.00
0005434480517	939	Economy	23100.00
0005434480521	939	Economy	23100.00
0005434480509	939	Economy	23100.00
0005434480519	939	Economy	23100.00
0005434480505	939	Economy	23100.00
0005433165910	939	Economy	23100.00
0005434480510	939	Economy	23100.00
0005434480502	939	Economy	23100.00
0005434480516	939	Economy	23100.00
0005433165899	939	Economy	23100.00
0005433165900	939	Economy	23100.00
0005432269514	939	Economy	23100.00
0005434480498	939	Economy	23100.00
0005434480503	939	Economy	23100.00
0005433165909	939	Economy	23100.00
0005434480508	939	Economy	23100.00
0005434480501	939	Economy	23100.00
0005433165844	939	Economy	23100.00
0005434480504	939	Economy	23100.00
0005433165881	939	Economy	23100.00
0005434480496	939	Economy	23100.00
0005434480497	939	Economy	23100.00
0005434480522	939	Economy	23100.00
0005434480506	939	Economy	23100.00
0005434480499	939	Economy	23100.00
0005434480518	939	Economy	23100.00
0005434480520	939	Economy	23100.00
0005434480513	939	Economy	23100.00
0005434480514	939	Economy	23100.00
0005433165921	939	Economy	23100.00
0005434480500	939	Economy	23100.00
0005433165991	16583	Economy	25400.00
0005434480401	16583	Economy	25400.00
0005434480286	16583	Economy	25400.00
0005434480304	16583	Economy	25400.00
0005433165992	16583	Economy	23100.00
0005433165993	16583	Economy	23100.00
0005433165999	16583	Economy	23100.00
0005433166002	16583	Economy	23100.00
0005433166000	16583	Economy	23100.00
0005434480294	16583	Economy	23100.00
0005434480350	16583	Economy	23100.00
0005433166001	16583	Economy	23100.00
0005434480402	16583	Economy	23100.00
0005434480215	16583	Economy	23100.00
0005434480334	16583	Economy	23100.00
0005434480209	16583	Economy	23100.00
0005434480277	16583	Economy	23100.00
0005433165990	16583	Economy	23100.00
0005433165997	16583	Economy	23100.00
0005434480166	16583	Economy	23100.00
0005433165994	16583	Economy	23100.00
0005433165996	16583	Economy	23100.00
0005434480303	16583	Economy	23100.00
0005434480335	16583	Economy	23100.00
0005434480367	16583	Economy	23100.00
0005434480287	16583	Economy	23100.00
0005434480316	16583	Economy	23100.00
0005434480349	16583	Economy	23100.00
0005434480214	16583	Economy	23100.00
0005434480191	16583	Economy	23100.00
0005434480293	16583	Economy	23100.00
0005434480254	16583	Economy	23100.00
0005434480227	16583	Economy	23100.00
0005434480357	16583	Economy	23100.00
0005434480208	16583	Economy	23100.00
0005433165998	16583	Economy	23100.00
0005434480366	16583	Economy	23100.00
0005433165995	16583	Economy	23100.00
0005434480165	16583	Economy	23100.00
0005434480391	16583	Economy	23100.00
0005434480317	16583	Economy	23100.00
0005434480368	16583	Economy	23100.00
0005435150119	10368	Economy	17000.00
0005435150113	10368	Economy	17000.00
0005435150106	10368	Economy	17000.00
0005435150111	10368	Economy	15400.00
0005435142657	10368	Economy	15400.00
0005433289805	10368	Economy	15400.00
0005435142659	10368	Economy	15400.00
0005435150117	10368	Economy	15400.00
0005435142655	10368	Economy	15400.00
0005435150112	10368	Economy	15400.00
0005435142660	10368	Economy	15400.00
0005433289826	10368	Economy	15400.00
0005433289806	10368	Economy	15400.00
0005435386550	10368	Economy	15400.00
0005435386548	10368	Economy	15400.00
0005435386551	10368	Economy	15400.00
0005435150108	10368	Economy	15400.00
0005435142666	10368	Economy	15400.00
0005435142654	10368	Economy	15400.00
0005435142662	10368	Economy	15400.00
0005433289823	10368	Economy	15400.00
0005433289829	10368	Economy	15400.00
0005435142665	10368	Economy	15400.00
0005435142664	10368	Economy	15400.00
0005433289828	10368	Economy	15400.00
0005435150109	10368	Economy	15400.00
0005435386561	10368	Economy	15400.00
0005433289824	10368	Economy	15400.00
0005433289825	10368	Economy	15400.00
0005435150110	10368	Economy	15400.00
0005435150114	10368	Economy	15400.00
0005435150107	10368	Economy	15400.00
0005435142658	10368	Economy	15400.00
0005433289807	10368	Economy	15400.00
0005435150115	10368	Economy	15400.00
0005435142663	10368	Economy	15400.00
0005435142661	10368	Economy	15400.00
0005435150116	10368	Economy	15400.00
0005435150118	10368	Economy	15400.00
0005435142667	10368	Economy	15400.00
0005435142656	10368	Economy	15400.00
0005433289804	10368	Economy	15400.00
0005433289904	21919	Economy	17000.00
0005435142585	21919	Economy	17000.00
0005435142561	21919	Economy	17000.00
0005435149995	21919	Economy	15400.00
0005433289903	21919	Economy	15400.00
0005435142582	21919	Economy	15400.00
0005433289905	21919	Economy	15400.00
0005435150003	21919	Economy	15400.00
0005435386617	21919	Economy	15400.00
0005435386619	21919	Economy	15400.00
0005435142515	21919	Economy	15400.00
0005433289910	21919	Economy	15400.00
0005435142584	21919	Economy	15400.00
0005435150051	21919	Economy	15400.00
0005435142516	21919	Economy	15400.00
0005435150050	21919	Economy	15400.00
0005435386615	21919	Economy	15400.00
0005435142534	21919	Economy	15400.00
0005435150002	21919	Economy	15400.00
0005433289907	21919	Economy	15400.00
0005433289908	21919	Economy	15400.00
0005435386614	21919	Economy	15400.00
0005435386613	21919	Economy	15400.00
0005433289902	21919	Economy	15400.00
0005435386620	21919	Economy	15400.00
0005435150012	21919	Economy	15400.00
0005435386616	21919	Economy	15400.00
0005433289909	21919	Economy	15400.00
0005435142517	21919	Economy	15400.00
0005435149984	21919	Economy	15400.00
0005435142562	21919	Economy	15400.00
0005435386618	21919	Economy	15400.00
0005435142535	21919	Economy	15400.00
0005435142558	21919	Economy	15400.00
0005435149941	21919	Economy	15400.00
0005435150010	21919	Economy	15400.00
0005435149986	21919	Economy	15400.00
0005435149994	21919	Economy	15400.00
0005435150053	21919	Economy	15400.00
0005433289906	21919	Economy	15400.00
0005435149997	21919	Economy	15400.00
0005435149940	21919	Economy	15400.00
0005435150009	21919	Economy	15400.00
0005435545697	11201	Business	57200.00
0005435529173	11201	Business	57200.00
0005435319577	11201	Business	57200.00
0005435319560	11201	Business	57200.00
0005435502360	11201	Business	57200.00
0005435529182	11201	Business	57200.00
0005434573444	11201	Business	57200.00
0005434573441	11201	Business	57200.00
0005434573435	11201	Business	57200.00
0005435319578	11201	Business	57200.00
0005435502294	11201	Business	57200.00
0005434573439	11201	Economy	19100.00
0005435502311	11201	Economy	19100.00
0005434573434	11201	Economy	19100.00
0005435529164	11201	Economy	19100.00
0005435502315	11201	Economy	19100.00
0005435545719	11201	Economy	19100.00
0005435529193	11201	Economy	19100.00
0005434573445	11201	Economy	21000.00
0005435502226	11201	Economy	21000.00
0005434573443	11201	Economy	21000.00
0005434573438	11201	Economy	21000.00
0005434573440	11201	Economy	19100.00
0005435319540	11201	Economy	19100.00
0005435529189	11201	Economy	19100.00
0005435545677	11201	Economy	19100.00
0005435502263	11201	Economy	19100.00
0005434573437	11201	Economy	19100.00
0005435319574	11201	Economy	19100.00
0005434573447	11201	Economy	19100.00
0005435502228	11201	Economy	19100.00
0005435529147	11201	Economy	19100.00
0005435502237	11201	Economy	19100.00
0005435529154	11201	Economy	19100.00
0005434573436	11201	Economy	19100.00
0005435529257	11201	Economy	19100.00
0005435319559	11201	Economy	19100.00
0005435319539	11201	Economy	19100.00
0005435545699	11201	Economy	19100.00
0005435529231	11201	Economy	19100.00
0005435529204	11201	Economy	19100.00
0005435545704	11201	Economy	19100.00
0005435502292	11201	Economy	19100.00
0005435529221	11201	Economy	19100.00
0005435502368	11201	Economy	19100.00
0005435529186	11201	Economy	19100.00
0005435529192	11201	Economy	19100.00
0005435502219	11201	Economy	19100.00
0005435502293	11201	Economy	19100.00
0005435529169	11201	Economy	19100.00
0005435502281	11201	Economy	19100.00
0005435319566	11201	Economy	19100.00
0005435502238	11201	Economy	19100.00
0005435529246	11201	Economy	19100.00
0005435529270	11201	Economy	19100.00
0005435502227	11201	Economy	19100.00
0005435545721	11201	Economy	19100.00
0005435529220	11201	Economy	19100.00
0005435319538	11201	Economy	19100.00
0005435319567	11201	Economy	19100.00
0005435529172	11201	Economy	19100.00
0005435502362	11201	Economy	19100.00
0005435502264	11201	Economy	19100.00
0005434573446	11201	Economy	19100.00
0005434573442	11201	Economy	19100.00
0005435502339	11201	Economy	19100.00
0005435545720	11201	Economy	19100.00
0005435545698	11201	Economy	19100.00
0005435502367	11201	Economy	19100.00
0005435502257	11201	Economy	19100.00
0005435502443	20954	Business	57200.00
0005434573306	20954	Business	57200.00
0005432291947	20954	Business	57200.00
0005435502446	20954	Business	57200.00
0005435502455	20954	Business	57200.00
0005435502453	20954	Business	57200.00
0005435502450	20954	Business	57200.00
0005434573300	20954	Business	57200.00
0005434573327	20954	Business	57200.00
0005435518016	20954	Economy	19100.00
0005434573259	20954	Economy	19100.00
0005435319646	20954	Economy	19100.00
0005432291945	20954	Economy	19100.00
0005435502456	20954	Economy	19100.00
0005435502448	20954	Economy	19100.00
0005435508422	20954	Economy	19100.00
0005435319645	20954	Economy	19100.00
0005435502441	20954	Economy	21000.00
0005435508419	20954	Economy	21000.00
0005435502445	20954	Economy	19100.00
0005435518024	20954	Economy	19100.00
0005435502451	20954	Economy	19100.00
0005432291944	20954	Economy	19100.00
0005435518022	20954	Economy	19100.00
0005435319647	20954	Economy	19100.00
0005435502452	20954	Economy	19100.00
0005435319643	20954	Economy	19100.00
0005435502454	20954	Economy	19100.00
0005435319648	20954	Economy	19100.00
0005435508423	20954	Economy	19100.00
0005435518020	20954	Economy	19100.00
0005434573304	20954	Economy	19100.00
0005435508421	20954	Economy	19100.00
0005435518019	20954	Economy	19100.00
0005435518026	20954	Economy	19100.00
0005435502447	20954	Economy	19100.00
0005435518021	20954	Economy	19100.00
0005435502459	20954	Economy	19100.00
0005434573301	20954	Economy	19100.00
0005434573344	20954	Economy	19100.00
0005435319644	20954	Economy	19100.00
0005435508428	20954	Economy	19100.00
0005435508427	20954	Economy	19100.00
0005435502458	20954	Economy	19100.00
0005435508420	20954	Economy	19100.00
0005434573319	20954	Economy	19100.00
0005435502457	20954	Economy	19100.00
0005434573244	20954	Economy	19100.00
0005435508425	20954	Economy	19100.00
0005432291946	20954	Economy	19100.00
0005434573305	20954	Economy	19100.00
0005435508418	20954	Economy	19100.00
0005435502462	20954	Economy	19100.00
0005434573243	20954	Economy	19100.00
0005435518025	20954	Economy	19100.00
0005435518027	20954	Economy	19100.00
0005435508424	20954	Economy	19100.00
0005435319649	20954	Economy	19100.00
0005435502442	20954	Economy	19100.00
0005435518023	20954	Economy	19100.00
0005434573260	20954	Economy	19100.00
0005435508417	20954	Economy	19100.00
0005435502444	20954	Economy	19100.00
0005435508429	20954	Economy	19100.00
0005435502449	20954	Economy	19100.00
0005434573245	20954	Economy	19100.00
0005435518017	20954	Economy	19100.00
0005435508426	20954	Economy	19100.00
0005435518018	20954	Economy	19100.00
0005435502461	20954	Economy	19100.00
0005435502460	20954	Economy	19100.00
0005433683353	24316	Economy	18800.00
0005433683356	24316	Economy	17100.00
0005433927422	24316	Economy	17100.00
0005433683355	24316	Economy	17100.00
0005433683358	24316	Economy	17100.00
0005433927426	24316	Economy	17100.00
0005433683352	24316	Economy	17100.00
0005433927438	24316	Economy	17100.00
0005433927442	24316	Economy	17100.00
0005433683357	24316	Economy	17100.00
0005433927439	24316	Economy	17100.00
0005433927431	24316	Economy	17100.00
0005433683354	24316	Economy	17100.00
0005433927440	24316	Economy	17100.00
0005433927443	24316	Economy	17100.00
0005433927441	24316	Economy	17100.00
0005433683326	29288	Economy	18800.00
0005433683334	29288	Economy	18800.00
0005433927459	29288	Economy	18800.00
0005433927458	29288	Economy	17100.00
0005433683338	29288	Economy	17100.00
0005433683340	29288	Economy	17100.00
0005433683314	29288	Economy	17100.00
0005433683320	29288	Economy	17100.00
0005433927454	29288	Economy	17100.00
0005433683324	29288	Economy	17100.00
0005433683321	29288	Economy	17100.00
0005433683325	29288	Economy	17100.00
0005433927455	29288	Economy	17100.00
0005433683336	29288	Economy	17100.00
0005433683328	29288	Economy	17100.00
0005433927456	29288	Economy	17100.00
0005433927461	29288	Economy	17100.00
0005433683337	29288	Economy	17100.00
0005433683339	29288	Economy	17100.00
0005433927457	29288	Economy	17100.00
0005433927460	29288	Economy	17100.00
0005433683322	29288	Economy	17100.00
0005432693004	3035	Business	10300.00
0005432693007	3035	Business	10300.00
0005432693113	3035	Economy	3400.00
0005432692949	3035	Economy	3800.00
0005432693050	3035	Economy	3800.00
0005432692972	3035	Economy	3800.00
0005432692852	3035	Economy	3400.00
0005432693024	3035	Economy	3400.00
0005432693039	3035	Economy	3400.00
0005432693005	3035	Economy	3400.00
0005432693143	3035	Economy	3400.00
0005432692987	3035	Economy	3400.00
0005432693123	3035	Economy	3400.00
0005432693063	3035	Economy	3400.00
0005432693008	3035	Economy	3400.00
0005432693032	3035	Economy	3400.00
0005432693034	3035	Economy	3400.00
0005432693033	3035	Economy	3400.00
0005432706940	3032	Business	10300.00
0005432706959	3032	Business	10300.00
0005433123762	3032	Business	10300.00
0005432706950	3032	Business	10300.00
0005432706937	3032	Business	10300.00
0005433123838	3032	Business	10300.00
0005433123751	3032	Business	10300.00
0005433123849	3032	Business	10300.00
0005432706957	3032	Business	10300.00
0005433123867	3032	Economy	3400.00
0005432880787	3032	Economy	3400.00
0005432880791	3032	Economy	3400.00
0005433123856	3032	Economy	3400.00
0005432880875	3032	Economy	3400.00
0005433123967	3032	Economy	3400.00
0005432880832	3032	Economy	3400.00
0005433123851	3032	Economy	3800.00
0005432880761	3032	Economy	3800.00
0005433123872	3032	Economy	3800.00
0005433194851	3032	Economy	3800.00
0005433123750	3032	Economy	3400.00
0005432706951	3032	Economy	3400.00
0005433123855	3032	Economy	3400.00
0005433123900	3032	Economy	3400.00
0005433124011	3032	Economy	3400.00
0005432706943	3032	Economy	3400.00
0005433124010	3032	Economy	3400.00
0005433123908	3032	Economy	3400.00
0005433123969	3032	Economy	3400.00
0005433123839	3032	Economy	3400.00
0005432706955	3032	Economy	3400.00
0005432217795	3032	Economy	3400.00
0005432217794	3032	Economy	3400.00
0005432706960	3032	Economy	3400.00
0005433123841	3032	Economy	3400.00
0005433123875	3032	Economy	3400.00
0005433123902	3032	Economy	3400.00
0005432880779	3032	Economy	3400.00
0005433123907	3032	Economy	3400.00
0005432706956	3032	Economy	3400.00
0005433123883	3032	Economy	3400.00
0005433123842	3032	Economy	3400.00
0005432880807	3032	Economy	3400.00
0005433123966	3032	Economy	3400.00
0005433123909	3032	Economy	3400.00
0005432706945	3032	Economy	3400.00
0005432706936	3032	Economy	3400.00
0005432706947	3032	Economy	3400.00
0005432880738	3032	Economy	3400.00
0005433123937	3032	Economy	3400.00
0005432706942	3032	Economy	3400.00
0005432706944	3032	Economy	3400.00
0005432706958	3032	Economy	3400.00
0005432880782	3032	Economy	3400.00
0005432880753	3032	Economy	3400.00
0005432880781	3032	Economy	3400.00
0005433123938	3032	Economy	3400.00
0005433123901	3032	Economy	3400.00
0005432706953	3032	Economy	3400.00
0005432706941	3032	Economy	3400.00
0005433123850	3032	Economy	3400.00
0005432706952	3032	Economy	3400.00
0005432706961	3032	Economy	3400.00
0005432706948	3032	Economy	3400.00
0005432706938	3032	Economy	3400.00
0005432706946	3032	Economy	3400.00
0005432880754	3032	Economy	3400.00
0005432880755	3032	Economy	3400.00
0005432706949	3032	Economy	3400.00
0005433123921	3032	Economy	3400.00
0005432706962	3032	Economy	3400.00
0005432880780	3032	Economy	3400.00
0005432217796	3032	Economy	3400.00
0005433123877	3032	Economy	3400.00
0005432706954	3032	Economy	3400.00
0005432706939	3032	Economy	3400.00
0005432693307	29921	Business	10300.00
0005432880923	29921	Business	10300.00
0005432880919	29921	Business	10300.00
0005432693292	29921	Business	10300.00
0005433124062	29921	Business	10300.00
0005432693298	29921	Business	10300.00
0005433194874	29921	Business	10300.00
0005433124052	29921	Business	10300.00
0005433124066	29921	Business	10300.00
0005432706675	29921	Business	10300.00
0005432693302	29921	Business	10300.00
0005432706802	29921	Business	10300.00
0005433124054	29921	Economy	3400.00
0005432706763	29921	Economy	3400.00
0005432706755	29921	Economy	3400.00
0005433124060	29921	Economy	3400.00
0005432693314	29921	Economy	3400.00
0005433194872	29921	Economy	3400.00
0005432693296	29921	Economy	3400.00
0005433124069	29921	Economy	3400.00
0005432693293	29921	Economy	3400.00
0005433124073	29921	Economy	3400.00
0005433124067	29921	Economy	3800.00
0005432706732	29921	Economy	3800.00
0005432706740	29921	Economy	3800.00
0005433194867	29921	Economy	3800.00
0005432880918	29921	Economy	3800.00
0005433194869	29921	Economy	3400.00
0005433124070	29921	Economy	3400.00
0005433124061	29921	Economy	3400.00
0005432693295	29921	Economy	3400.00
0005433194866	29921	Economy	3400.00
0005432880920	29921	Economy	3400.00
0005432693309	29921	Economy	3400.00
0005433124065	29921	Economy	3400.00
0005432693287	29921	Economy	3400.00
0005432880915	29921	Economy	3400.00
0005432693306	29921	Economy	3400.00
0005432693291	29921	Economy	3400.00
0005432706697	29921	Economy	3400.00
0005432693294	29921	Economy	3400.00
0005433194875	29921	Economy	3400.00
0005432693289	29921	Economy	3400.00
0005432706728	29921	Economy	3400.00
0005433194863	29921	Economy	3400.00
0005432693312	29921	Economy	3400.00
0005433194870	29921	Economy	3400.00
0005432880921	29921	Economy	3400.00
0005432880911	29921	Economy	3400.00
0005432706708	29921	Economy	3400.00
0005433124059	29921	Economy	3400.00
0005433124056	29921	Economy	3400.00
0005433124058	29921	Economy	3400.00
0005432693305	29921	Economy	3400.00
0005432693297	29921	Economy	3400.00
0005433124064	29921	Economy	3400.00
0005432880922	29921	Economy	3400.00
0005433124063	29921	Economy	3400.00
0005432693308	29921	Economy	3400.00
0005433124072	29921	Economy	3400.00
0005432693310	29921	Economy	3400.00
0005432693299	29921	Economy	3400.00
0005432693290	29921	Economy	3400.00
0005432880925	29921	Economy	3400.00
0005432706883	29921	Economy	3400.00
0005433194868	29921	Economy	3400.00
0005432693301	29921	Economy	3400.00
0005432880912	29921	Economy	3400.00
0005432693288	29921	Economy	3400.00
0005433194873	29921	Economy	3400.00
0005432693313	29921	Economy	3400.00
0005433124055	29921	Economy	3400.00
0005433124051	29921	Economy	3400.00
0005432880916	29921	Economy	3400.00
0005432706733	29921	Economy	3400.00
0005433194862	29921	Economy	3400.00
0005432693286	29921	Economy	3400.00
0005433124053	29921	Economy	3400.00
0005432706709	29921	Economy	3400.00
0005433124068	29921	Economy	3400.00
0005432693304	29921	Economy	3400.00
0005432693311	29921	Economy	3400.00
0005432706816	29921	Economy	3400.00
0005432693300	29921	Economy	3400.00
0005433194871	29921	Economy	3400.00
0005432880914	29921	Economy	3400.00
0005432880913	29921	Economy	3400.00
0005432880917	29921	Economy	3400.00
0005432880924	29921	Economy	3400.00
0005433124071	29921	Economy	3400.00
0005432693315	29921	Economy	3400.00
0005433194864	29921	Economy	3400.00
0005433124057	29921	Economy	3400.00
0005432693303	29921	Economy	3400.00
0005433194865	29921	Economy	3400.00
0005432693285	29921	Economy	3400.00
0005434979966	23670	Economy	4000.00
0005434988800	23670	Economy	4000.00
0005434979970	23670	Economy	4000.00
0005434988804	23670	Economy	3600.00
0005434979969	23670	Economy	3600.00
0005434979988	23670	Economy	3600.00
0005434979983	23670	Economy	3600.00
0005434979985	23670	Economy	3600.00
0005434979982	23670	Economy	3600.00
0005434979973	23670	Economy	3600.00
0005434979976	23670	Economy	3600.00
0005434988807	23670	Economy	3600.00
0005434979980	23670	Economy	3600.00
0005434979974	23670	Economy	3600.00
0005434988805	23670	Economy	3600.00
0005434988803	23670	Economy	3600.00
0005434979961	23670	Economy	3600.00
0005434979972	23670	Economy	3600.00
0005434988810	23670	Economy	3600.00
0005434979984	23670	Economy	3600.00
0005434988811	23670	Economy	3600.00
0005434979990	23670	Economy	3600.00
0005434979979	23670	Economy	3600.00
0005434979962	23670	Economy	3600.00
0005434979971	23670	Economy	3600.00
0005434988801	23670	Economy	3600.00
0005434988806	23670	Economy	3600.00
0005434988808	23670	Economy	3600.00
0005434979989	23670	Economy	3600.00
0005434988802	23670	Economy	3600.00
0005434979964	23670	Economy	3600.00
0005434988809	23670	Economy	3600.00
0005434979975	23670	Economy	3600.00
0005434979981	23670	Economy	3600.00
0005434979987	23670	Economy	3600.00
0005434979965	23670	Economy	3600.00
0005434979960	23670	Economy	3600.00
0005434979963	23670	Economy	3600.00
0005434979986	23670	Economy	3600.00
0005434979968	23670	Economy	3600.00
0005434979978	23670	Economy	3600.00
0005434979977	23670	Economy	3600.00
0005434979967	23670	Economy	3600.00
0005434979744	27537	Economy	4000.00
0005434988686	27537	Economy	4000.00
0005434979803	27537	Economy	4000.00
0005434988708	27537	Economy	3600.00
0005434979746	27537	Economy	3600.00
0005434988704	27537	Economy	3600.00
0005434979722	27537	Economy	3600.00
0005434979701	27537	Economy	3600.00
0005434979671	27537	Economy	3600.00
0005434988709	27537	Economy	3600.00
0005434979794	27537	Economy	3600.00
0005434979805	27537	Economy	3600.00
0005434979679	27537	Economy	3600.00
0005434979611	27537	Economy	3600.00
0005434988667	27537	Economy	3600.00
0005434979825	27537	Economy	3600.00
0005434979707	27537	Economy	3600.00
0005434979732	27537	Economy	3600.00
0005434979626	27537	Economy	3600.00
0005434979793	27537	Economy	3600.00
0005434988671	27537	Economy	3600.00
0005434988703	27537	Economy	3600.00
0005434979670	27537	Economy	3600.00
0005434979660	27537	Economy	3600.00
0005434979824	27537	Economy	3600.00
0005434979716	27537	Economy	3600.00
0005434979745	27537	Economy	3600.00
0005434979658	27537	Economy	3600.00
0005434988674	27537	Economy	3600.00
0005434979662	27537	Economy	3600.00
0005434988696	27537	Economy	3600.00
0005434988697	27537	Economy	3600.00
0005434979802	27537	Economy	3600.00
0005434979727	27537	Economy	3600.00
0005434988675	27537	Economy	3600.00
0005434979661	27537	Economy	3600.00
0005434988679	27537	Economy	3600.00
0005434979678	27537	Economy	3600.00
0005434988678	27537	Economy	3600.00
0005434979764	27537	Economy	3600.00
0005434979706	27537	Economy	3600.00
0005434979610	27537	Economy	3600.00
0005434979741	27537	Economy	3600.00
0005434979765	27537	Economy	3600.00
0005434979625	27537	Economy	3600.00
0005434979669	27537	Economy	3600.00
0005434302486	10254	Economy	21600.00
0005434302487	10254	Economy	19700.00
0005434302484	10254	Economy	19700.00
0005434302485	10254	Economy	19700.00
0005433111502	10254	Economy	19700.00
0005433113539	10254	Economy	19700.00
0005433113551	19636	Economy	19700.00
0005434302429	19636	Economy	19700.00
0005434302428	19636	Economy	19700.00
0005433113553	19636	Economy	19700.00
0005433113552	19636	Economy	19700.00
0005435069478	3571	Business	26900.00
0005435069456	3571	Business	26900.00
0005435069439	3571	Business	26900.00
0005435069459	3571	Business	26900.00
0005435069452	3571	Business	26900.00
0005435069472	3571	Business	26900.00
0005435069432	3571	Business	26900.00
0005435925259	3571	Business	26900.00
0005435069463	3571	Business	26900.00
0005435069462	3571	Business	26900.00
0005435925248	3571	Business	26900.00
0005435069464	3571	Economy	9000.00
0005435925258	3571	Economy	9000.00
0005435069448	3571	Economy	9000.00
0005435069437	3571	Economy	9000.00
0005435925212	3571	Economy	9000.00
0005435069451	3571	Economy	9000.00
0005435069471	3571	Economy	9900.00
0005435069449	3571	Economy	9900.00
0005435718989	3571	Economy	9900.00
0005435069458	3571	Economy	9900.00
0005435069445	3571	Economy	9000.00
0005435069476	3571	Economy	9000.00
0005435069431	3571	Economy	9000.00
0005435925254	3571	Economy	9000.00
0005435925193	3571	Economy	9000.00
0005435069466	3571	Economy	9000.00
0005435069438	3571	Economy	9000.00
0005435069461	3571	Economy	9000.00
0005435069479	3571	Economy	9000.00
0005435925262	3571	Economy	9000.00
0005435069477	3571	Economy	9000.00
0005435925233	3571	Economy	9000.00
0005435069468	3571	Economy	9000.00
0005435069470	3571	Economy	9000.00
0005435069481	3571	Economy	9000.00
0005435925271	3571	Economy	9000.00
0005435925179	3571	Economy	9000.00
0005435925223	3571	Economy	9000.00
0005435069469	3571	Economy	9000.00
0005435069465	3571	Economy	9000.00
0005435069454	3571	Economy	9000.00
0005435069435	3571	Economy	9000.00
0005435069473	3571	Economy	9000.00
0005435069442	3571	Economy	9000.00
0005435069475	3571	Economy	9000.00
0005435069433	3571	Economy	9000.00
0005435069457	3571	Economy	9000.00
0005435069434	3571	Economy	9000.00
0005435069446	3571	Economy	9000.00
0005435718991	3571	Economy	9000.00
0005435069450	3571	Economy	9000.00
0005435069467	3571	Economy	9000.00
0005435069436	3571	Economy	9000.00
0005435069453	3571	Economy	9000.00
0005435718988	3571	Economy	9000.00
0005435069474	3571	Economy	9000.00
0005435069480	3571	Economy	9000.00
0005435069460	3571	Economy	9000.00
0005435925243	3571	Economy	9000.00
0005435069455	3571	Economy	9000.00
0005435925242	3571	Economy	9000.00
0005435069443	3571	Economy	9000.00
0005435925261	3571	Economy	9000.00
0005435069444	3571	Economy	9000.00
0005435925224	3571	Economy	9000.00
0005435069441	3571	Economy	9000.00
0005435069482	3571	Economy	9000.00
0005435925227	3571	Economy	9000.00
0005435069430	3571	Economy	9000.00
0005435069440	3571	Economy	9000.00
0005435925228	3571	Economy	9000.00
0005435718990	3571	Economy	9000.00
0005435925232	3571	Economy	9000.00
0005435925192	3571	Economy	9000.00
0005435069447	3571	Economy	9000.00
0005435068966	15313	Business	26900.00
0005435718845	15313	Business	26900.00
0005435718864	15313	Business	26900.00
0005435718905	15313	Business	26900.00
0005435069105	15313	Business	26900.00
0005435069186	15313	Business	26900.00
0005435718908	15313	Business	26900.00
0005435718917	15313	Business	26900.00
0005435068868	15313	Business	26900.00
0005435068897	15313	Business	26900.00
0005435718914	15313	Business	26900.00
0005435718887	15313	Business	26900.00
0005435068748	15313	Economy	9000.00
0005435718859	15313	Economy	9000.00
0005435068991	15313	Economy	9000.00
0005435068971	15313	Economy	9000.00
0005435718915	15313	Economy	9000.00
0005435068988	15313	Economy	9000.00
0005435069018	15313	Economy	9000.00
0005435068708	15313	Economy	9000.00
0005435068906	15313	Economy	9000.00
0005435718833	15313	Economy	9000.00
0005435069041	15313	Economy	9900.00
0005435069015	15313	Economy	9900.00
0005435068828	15313	Economy	9900.00
0005435718891	15313	Economy	9900.00
0005435718893	15313	Economy	9900.00
0005435718903	15313	Economy	9000.00
0005435068889	15313	Economy	9000.00
0005435068895	15313	Economy	9000.00
0005435718918	15313	Economy	9000.00
0005435068899	15313	Economy	9000.00
0005435069042	15313	Economy	9000.00
0005435718866	15313	Economy	9000.00
0005435718842	15313	Economy	9000.00
0005435069057	15313	Economy	9000.00
0005435068765	15313	Economy	9000.00
0005435068874	15313	Economy	9000.00
0005435068851	15313	Economy	9000.00
0005435718832	15313	Economy	9000.00
0005435068746	15313	Economy	9000.00
0005435068894	15313	Economy	9000.00
0005435068911	15313	Economy	9000.00
0005435718911	15313	Economy	9000.00
0005435068922	15313	Economy	9000.00
0005435718892	15313	Economy	9000.00
0005435718904	15313	Economy	9000.00
0005435068709	15313	Economy	9000.00
0005435068942	15313	Economy	9000.00
0005435068795	15313	Economy	9000.00
0005435068982	15313	Economy	9000.00
0005435718851	15313	Economy	9000.00
0005435718850	15313	Economy	9000.00
0005435068900	15313	Economy	9000.00
0005435068829	15313	Economy	9000.00
0005435069106	15313	Economy	9000.00
0005435068919	15313	Economy	9000.00
0005435068852	15313	Economy	9000.00
0005435068647	15313	Economy	9000.00
0005435068992	15313	Economy	9000.00
0005435718890	15313	Economy	9000.00
0005435068898	15313	Economy	9000.00
0005435718879	15313	Economy	9000.00
0005435068987	15313	Economy	9000.00
0005435069017	15313	Economy	9000.00
0005435718901	15313	Economy	9000.00
0005435718876	15313	Economy	9000.00
0005435069001	15313	Economy	9000.00
0005435068967	15313	Economy	9000.00
0005435718896	15313	Economy	9000.00
0005435718900	15313	Economy	9000.00
0005435068754	15313	Economy	9000.00
0005435069003	15313	Economy	9000.00
0005435068747	15313	Economy	9000.00
0005435718909	15313	Economy	9000.00
0005435718889	15313	Economy	9000.00
0005435718913	15313	Economy	9000.00
0005435718902	15313	Economy	9000.00
0005435069028	15313	Economy	9000.00
0005435718916	15313	Economy	9000.00
0005435069055	15313	Economy	9000.00
0005435068888	15313	Economy	9000.00
0005435718899	15313	Economy	9000.00
0005435068864	15313	Economy	9000.00
0005435718844	15313	Economy	9000.00
0005435718884	15313	Economy	9000.00
0005435069016	15313	Economy	9000.00
0005435718860	15313	Economy	9000.00
0005435718897	15313	Economy	9000.00
0005435068853	15313	Economy	9000.00
0005435068838	15313	Economy	9000.00
0005435718838	15313	Economy	9000.00
0005435718919	15313	Economy	9000.00
0005435718910	15313	Economy	9000.00
0005435068822	15313	Economy	9000.00
0005435718912	15313	Economy	9000.00
0005432659720	18217	Economy	5900.00
0005432659721	18217	Economy	5900.00
0005432660831	18217	Economy	5900.00
0005432660833	18217	Economy	5900.00
0005432658607	18217	Economy	5900.00
0005432658606	18217	Economy	5900.00
0005432660834	18217	Economy	5900.00
0005432660832	18217	Economy	5900.00
0005432658608	18217	Economy	5900.00
0005432660817	26375	Economy	5900.00
0005432667450	26375	Economy	5900.00
0005432660818	26375	Economy	5900.00
0005432660813	26375	Economy	5900.00
0005432667452	26375	Economy	5900.00
0005432660814	26375	Economy	5900.00
0005432667451	26375	Economy	5900.00
0005432901576	74	Business	20000.00
0005432919838	74	Business	20000.00
0005432677584	74	Business	20000.00
0005432901534	74	Business	20000.00
0005432901517	74	Business	20000.00
0005433102116	74	Business	20000.00
0005432901560	74	Business	20000.00
0005432391987	74	Business	20000.00
0005432919906	74	Business	20000.00
0005433101868	74	Business	20000.00
0005432919841	74	Business	20000.00
0005433102112	74	Business	20000.00
0005432901625	74	Business	20000.00
0005432919795	74	Business	20000.00
0005432901623	74	Business	20000.00
0005433101930	74	Business	20000.00
0005433102037	74	Business	20000.00
0005432677582	74	Business	20000.00
0005433101928	74	Business	20000.00
0005433102080	74	Business	20000.00
0005432391989	74	Business	20000.00
0005433101936	74	Business	20000.00
0005433102081	74	Economy	7300.00
0005433102093	74	Economy	7300.00
0005433102042	74	Economy	7300.00
0005432901627	74	Economy	7300.00
0005433102115	74	Economy	7300.00
0005432901581	74	Economy	6700.00
0005432901516	74	Economy	6700.00
0005433102015	74	Economy	6700.00
0005432919870	74	Economy	6700.00
0005433102050	74	Economy	6700.00
0005432919845	74	Economy	6700.00
0005432677559	74	Economy	6700.00
0005433102051	74	Economy	6700.00
0005432901585	74	Economy	6700.00
0005433102038	74	Economy	6700.00
0005433102088	74	Economy	6700.00
0005432919907	74	Economy	6700.00
0005433102034	74	Economy	6700.00
0005432677566	74	Economy	6700.00
0005432901521	74	Economy	6700.00
0005432901572	74	Economy	6700.00
0005432677563	74	Economy	6700.00
0005433102075	74	Economy	6700.00
0005433102031	74	Economy	6700.00
0005432677583	74	Economy	6700.00
0005433102049	74	Economy	6700.00
0005433102118	74	Economy	6700.00
0005433101937	74	Economy	6700.00
0005433102022	74	Economy	6700.00
0005433102030	74	Economy	6700.00
0005432919846	74	Economy	6700.00
0005433102103	74	Economy	6700.00
0005433102106	74	Economy	6700.00
0005432901665	74	Economy	6700.00
0005432919951	74	Economy	6700.00
0005432901632	74	Economy	6700.00
0005433102077	74	Economy	6700.00
0005433102033	74	Economy	6700.00
0005432157507	74	Economy	6700.00
0005432919837	74	Economy	6700.00
0005432901552	74	Economy	6700.00
0005433101967	74	Economy	6700.00
0005432919888	74	Economy	6700.00
0005433101980	74	Economy	6700.00
0005433101970	74	Economy	6700.00
0005433101975	74	Economy	6700.00
0005433102020	74	Economy	6700.00
0005432677555	74	Economy	6700.00
0005433101981	74	Economy	6700.00
0005433102036	74	Economy	7300.00
0005432901626	74	Economy	7300.00
0005433102043	74	Economy	6700.00
0005432677558	74	Economy	6700.00
0005433101969	74	Economy	7300.00
0005432901613	74	Economy	6700.00
0005432677570	74	Economy	6700.00
0005433102025	74	Economy	6700.00
0005432901614	74	Economy	6700.00
0005433102065	74	Economy	6700.00
0005432901672	74	Economy	6700.00
0005433101993	74	Economy	6700.00
0005432919839	74	Economy	6700.00
0005433102078	74	Economy	6700.00
0005432157506	74	Economy	6700.00
0005433101842	74	Economy	6700.00
0005432901549	74	Economy	6700.00
0005433102039	74	Economy	6700.00
0005432901649	74	Economy	6700.00
0005432901631	74	Economy	6700.00
0005432677562	74	Economy	6700.00
0005433102016	74	Economy	6700.00
0005432919747	74	Economy	6700.00
0005432919825	74	Economy	6700.00
0005432919746	74	Economy	6700.00
0005433102024	74	Economy	6700.00
0005433102109	74	Economy	6700.00
0005433101915	74	Economy	6700.00
0005433102069	74	Economy	6700.00
0005432901612	74	Economy	6700.00
0005433102094	74	Economy	6700.00
0005433101976	74	Economy	6700.00
0005433101968	74	Economy	6700.00
0005432901503	74	Economy	6700.00
0005432901561	74	Economy	6700.00
0005433102040	74	Economy	6700.00
0005433102072	74	Economy	6700.00
0005433101870	74	Economy	6700.00
0005433102032	74	Economy	6700.00
0005432157505	74	Economy	6700.00
0005432919872	74	Economy	6700.00
0005433102071	74	Economy	6700.00
0005433102041	74	Economy	6700.00
0005433102087	74	Economy	6700.00
0005433102021	74	Economy	6700.00
0005433101979	74	Economy	6700.00
0005432901548	74	Economy	6700.00
0005432901715	74	Economy	6700.00
0005432677571	74	Economy	6700.00
0005433101851	74	Economy	6700.00
0005433101929	74	Economy	6700.00
0005433102017	74	Economy	6700.00
0005433101806	74	Economy	6700.00
0005432901565	74	Economy	6700.00
0005432901714	74	Economy	6700.00
0005432817693	75	Business	20000.00
0005432262252	75	Business	20000.00
0005433687690	75	Business	20000.00
0005432817685	75	Business	20000.00
0005432262237	75	Business	20000.00
0005432262217	75	Business	20000.00
0005432817695	75	Business	20000.00
0005432262228	75	Business	20000.00
0005432817691	75	Business	20000.00
0005432817682	75	Business	20000.00
0005432262225	75	Business	20000.00
0005432262213	75	Business	20000.00
0005432753287	75	Business	20000.00
0005432817689	75	Economy	7300.00
0005432756831	75	Economy	7300.00
0005432753293	75	Economy	7300.00
0005432817697	75	Economy	7300.00
0005432262232	75	Economy	6700.00
0005432262220	75	Economy	6700.00
0005432262221	75	Economy	6700.00
0005432262227	75	Economy	6700.00
0005432262251	75	Economy	6700.00
0005432817680	75	Economy	6700.00
0005432817687	75	Economy	6700.00
0005432262229	75	Economy	6700.00
0005432817674	75	Economy	6700.00
0005432817672	75	Economy	6700.00
0005432753290	75	Economy	6700.00
0005432753308	75	Economy	6700.00
0005432262253	75	Economy	6700.00
0005432817692	75	Economy	6700.00
0005432262222	75	Economy	6700.00
0005432262243	75	Economy	6700.00
0005432262244	75	Economy	6700.00
0005432262211	75	Economy	6700.00
0005432817696	75	Economy	6700.00
0005432262236	75	Economy	6700.00
0005432817675	75	Economy	6700.00
0005432753286	75	Economy	6700.00
0005432262215	75	Economy	6700.00
0005432289010	75	Economy	6700.00
0005432756832	75	Economy	6700.00
0005432262250	75	Economy	6700.00
0005432262249	75	Economy	6700.00
0005432262210	75	Economy	6700.00
0005432817688	75	Economy	6700.00
0005432756833	75	Economy	6700.00
0005432262241	75	Economy	6700.00
0005433687691	75	Economy	6700.00
0005432817678	75	Economy	6700.00
0005432817669	75	Economy	6700.00
0005432262240	75	Economy	7300.00
0005432262246	75	Economy	7300.00
0005432262239	75	Economy	7300.00
0005434153541	75	Economy	6700.00
0005432262234	75	Economy	6700.00
0005432262224	75	Economy	6700.00
0005432756813	75	Economy	7300.00
0005432817684	75	Economy	6700.00
0005432207678	75	Economy	6700.00
0005432817690	75	Economy	6700.00
0005432262256	75	Economy	6700.00
0005432817671	75	Economy	6700.00
0005432262231	75	Economy	6700.00
0005432817670	75	Economy	6700.00
0005432262235	75	Economy	6700.00
0005432817677	75	Economy	6700.00
0005432817683	75	Economy	6700.00
0005432262245	75	Economy	6700.00
0005432262218	75	Economy	6700.00
0005432262214	75	Economy	6700.00
0005432262223	75	Economy	6700.00
0005432207677	75	Economy	6700.00
0005432262226	75	Economy	6700.00
0005432289009	75	Economy	6700.00
0005432262219	75	Economy	6700.00
0005432817694	75	Economy	6700.00
0005432817679	75	Economy	6700.00
0005432262248	75	Economy	6700.00
0005432262216	75	Economy	6700.00
0005434153539	75	Economy	6700.00
0005432262242	75	Economy	6700.00
0005432262212	75	Economy	6700.00
0005432262238	75	Economy	6700.00
0005432817686	75	Economy	6700.00
0005432262255	75	Economy	6700.00
0005432262233	75	Economy	6700.00
0005432262230	75	Economy	6700.00
0005432262254	75	Economy	6700.00
0005432817676	75	Economy	6700.00
0005432817681	75	Economy	6700.00
0005432817673	75	Economy	6700.00
0005432756838	75	Economy	6700.00
0005434153540	75	Economy	6700.00
0005432756841	75	Economy	6700.00
0005432756839	75	Economy	6700.00
0005432262247	75	Economy	6700.00
0005433102491	7926	Business	20000.00
0005433102490	7926	Business	20000.00
0005432753326	7926	Business	20000.00
0005433102500	7926	Business	20000.00
0005432920010	7926	Business	20000.00
0005433102524	7926	Business	20000.00
0005433102516	7926	Business	20000.00
0005432020438	7926	Business	20000.00
0005432392021	7926	Business	20000.00
0005432920001	7926	Business	20000.00
0005433102501	7926	Business	20000.00
0005432020445	7926	Business	20000.00
0005432920015	7926	Business	20000.00
0005433102488	7926	Business	20000.00
0005432753325	7926	Business	20000.00
0005432751551	7926	Business	20000.00
0005433102504	7926	Business	20000.00
0005433102507	7926	Economy	7300.00
0005432020441	7926	Economy	7300.00
0005432020459	7926	Economy	7300.00
0005432020463	7926	Economy	6700.00
0005432920008	7926	Economy	6700.00
0005432920009	7926	Economy	6700.00
0005432020447	7926	Economy	6700.00
0005433102486	7926	Economy	6700.00
0005432677602	7926	Economy	6700.00
0005433102478	7926	Economy	6700.00
0005433102511	7926	Economy	6700.00
0005432020453	7926	Economy	6700.00
0005433102527	7926	Economy	6700.00
0005432751552	7926	Economy	6700.00
0005433102499	7926	Economy	6700.00
0005433102513	7926	Economy	6700.00
0005432020462	7926	Economy	6700.00
0005432677603	7926	Economy	6700.00
0005433102495	7926	Economy	6700.00
0005432020449	7926	Economy	6700.00
0005433102521	7926	Economy	6700.00
0005432920005	7926	Economy	6700.00
0005432020458	7926	Economy	6700.00
0005432919999	7926	Economy	6700.00
0005432020464	7926	Economy	6700.00
0005433102517	7926	Economy	6700.00
0005433102484	7926	Economy	6700.00
0005433102510	7926	Economy	6700.00
0005432044545	7926	Economy	6700.00
0005433102520	7926	Economy	6700.00
0005433102526	7926	Economy	6700.00
0005432045628	7926	Economy	6700.00
0005433102485	7926	Economy	6700.00
0005432020456	7926	Economy	6700.00
0005432020448	7926	Economy	6700.00
0005433102482	7926	Economy	6700.00
0005432020455	7926	Economy	6700.00
0005432020452	7926	Economy	6700.00
0005433102509	7926	Economy	6700.00
0005433102505	7926	Economy	6700.00
0005433102489	7926	Economy	6700.00
0005433102523	7926	Economy	6700.00
0005432753324	7926	Economy	6700.00
0005432020457	7926	Economy	6700.00
0005432919997	7926	Economy	6700.00
0005432920013	7926	Economy	6700.00
0005432920007	7926	Economy	7300.00
0005433102514	7926	Economy	7300.00
0005432751550	7926	Economy	7300.00
0005432751549	7926	Economy	7300.00
0005432020451	7926	Economy	6700.00
0005433102525	7926	Economy	6700.00
0005432919996	7926	Economy	6700.00
0005432920014	7926	Economy	7300.00
0005432392022	7926	Economy	6700.00
0005433102480	7926	Economy	6700.00
0005432920000	7926	Economy	6700.00
0005432020442	7926	Economy	6700.00
0005432020461	7926	Economy	6700.00
0005433102479	7926	Economy	6700.00
0005433102496	7926	Economy	6700.00
0005433102494	7926	Economy	6700.00
0005432020446	7926	Economy	6700.00
0005433102502	7926	Economy	6700.00
0005433102512	7926	Economy	6700.00
0005433102498	7926	Economy	6700.00
0005433102515	7926	Economy	6700.00
0005433102506	7926	Economy	6700.00
0005433102522	7926	Economy	6700.00
0005432919998	7926	Economy	6700.00
0005433102492	7926	Economy	6700.00
0005432045629	7926	Economy	6700.00
0005432020444	7926	Economy	6700.00
0005432920002	7926	Economy	6700.00
0005432920012	7926	Economy	6700.00
0005432677604	7926	Economy	6700.00
0005432020454	7926	Economy	6700.00
0005433102503	7926	Economy	6700.00
0005432020439	7926	Economy	6700.00
0005433102508	7926	Economy	6700.00
0005433102487	7926	Economy	6700.00
0005433102481	7926	Economy	6700.00
0005433102497	7926	Economy	6700.00
0005433102483	7926	Economy	6700.00
0005433102519	7926	Economy	6700.00
0005432044544	7926	Economy	6700.00
0005432020443	7926	Economy	6700.00
0005433102518	7926	Economy	6700.00
0005432920016	7926	Economy	6700.00
0005432044546	7926	Economy	6700.00
0005432044543	7926	Economy	6700.00
0005432020450	7926	Economy	6700.00
0005432920004	7926	Economy	6700.00
0005432020440	7926	Economy	6700.00
0005432020460	7926	Economy	6700.00
0005432920003	7926	Economy	6700.00
0005432920006	7926	Economy	6700.00
0005433102493	7926	Economy	6700.00
0005432920011	7926	Economy	6700.00
0005432817441	7925	Business	20000.00
0005432817414	7925	Business	20000.00
0005432817484	7925	Business	20000.00
0005432817453	7925	Business	20000.00
0005432817486	7925	Business	20000.00
0005432817328	7925	Business	20000.00
0005432901742	7925	Business	20000.00
0005432817471	7925	Business	20000.00
0005432817479	7925	Business	20000.00
0005432817468	7925	Economy	7300.00
0005432817358	7925	Economy	7300.00
0005432817549	7925	Economy	7300.00
0005432817470	7925	Economy	6700.00
0005432901726	7925	Economy	6700.00
0005432817398	7925	Economy	6700.00
0005432817463	7925	Economy	6700.00
0005432817436	7925	Economy	6700.00
0005432817392	7925	Economy	6700.00
0005432817404	7925	Economy	6700.00
0005432817391	7925	Economy	6700.00
0005432817390	7925	Economy	6700.00
0005432002091	7925	Economy	6700.00
0005432817481	7925	Economy	6700.00
0005432002090	7925	Economy	6700.00
0005432817469	7925	Economy	6700.00
0005432901739	7925	Economy	6700.00
0005432817502	7925	Economy	6700.00
0005432817393	7925	Economy	6700.00
0005432817455	7925	Economy	6700.00
0005432817405	7925	Economy	6700.00
0005432901740	7925	Economy	6700.00
0005432817443	7925	Economy	6700.00
0005432901741	7925	Economy	6700.00
0005432901731	7925	Economy	6700.00
0005432901728	7925	Economy	6700.00
0005432817548	7925	Economy	6700.00
0005432817488	7925	Economy	6700.00
0005432817421	7925	Economy	7300.00
0005432901736	7925	Economy	7300.00
0005432817435	7925	Economy	7300.00
0005432817509	7925	Economy	6700.00
0005432817352	7925	Economy	6700.00
0005432901727	7925	Economy	6700.00
0005432817450	7925	Economy	6700.00
0005432817331	7925	Economy	6700.00
0005432817415	7925	Economy	6700.00
0005432817367	7925	Economy	6700.00
0005432901738	7925	Economy	6700.00
0005432817416	7925	Economy	6700.00
0005432817458	7925	Economy	6700.00
0005432817399	7925	Economy	6700.00
0005432901725	7925	Economy	6700.00
0005432817389	7925	Economy	6700.00
0005432817513	7925	Economy	6700.00
0005432817487	7925	Economy	6700.00
0005432817485	7925	Economy	6700.00
0005432901734	7925	Economy	6700.00
0005432901735	7925	Economy	6700.00
0005432901732	7925	Economy	6700.00
0005432817370	7925	Economy	6700.00
0005432901733	7925	Economy	6700.00
0005432817442	7925	Economy	6700.00
0005432817427	7925	Economy	6700.00
0005432817482	7925	Economy	6700.00
0005432901729	7925	Economy	6700.00
0005432901737	7925	Economy	6700.00
0005432901730	7925	Economy	6700.00
0005432817364	7925	Economy	6700.00
0005434175750	9664	Economy	6900.00
0005434175727	9664	Economy	6900.00
0005434175728	9664	Economy	6900.00
0005434175751	9664	Economy	6900.00
0005433870746	9664	Economy	6900.00
0005434175760	9664	Economy	6900.00
0005433870747	9664	Economy	6900.00
0005434175783	32349	Economy	6900.00
0005434175784	32349	Economy	6900.00
0005434175782	32349	Economy	6900.00
0005434175781	32349	Economy	6900.00
0005434426812	3463	Business	35000.00
0005434426837	3463	Business	35000.00
0005435902667	3463	Business	35000.00
0005434878924	3463	Business	35000.00
0005432188630	3463	Business	35000.00
0005432799664	3463	Business	35000.00
0005435126686	3463	Business	35000.00
0005434878892	3463	Business	35000.00
0005434878864	3463	Business	35000.00
0005434426825	3463	Business	35000.00
0005434878874	3463	Business	35000.00
0005434878922	3463	Business	35000.00
0005434878886	3463	Business	35000.00
0005434878957	3463	Business	35000.00
0005434878887	3463	Business	35000.00
0005435126661	3463	Business	35000.00
0005434426835	3463	Business	35000.00
0005434878866	3463	Business	35000.00
0005435902770	3463	Business	35000.00
0005434426819	3463	Business	35000.00
0005434878948	3463	Business	35000.00
0005435126668	3463	Business	35000.00
0005432799673	3463	Business	35000.00
0005432799647	3463	Comfort	19900.00
0005435902693	3463	Comfort	19900.00
0005434878953	3463	Comfort	19900.00
0005435902631	3463	Comfort	19900.00
0005435626314	3463	Comfort	19900.00
0005435126651	3463	Comfort	19900.00
0005432799672	3463	Comfort	19900.00
0005434878930	3463	Comfort	19900.00
0005435126646	3463	Comfort	19900.00
0005434878868	3463	Comfort	19900.00
0005434878919	3463	Comfort	19900.00
0005434878883	3463	Comfort	19900.00
0005434878879	3463	Comfort	19900.00
0005434878911	3463	Comfort	19900.00
0005432183483	3463	Comfort	19900.00
0005434938274	3463	Comfort	19900.00
0005434878944	3463	Comfort	19900.00
0005432799670	3463	Comfort	19900.00
0005435126665	3463	Comfort	19900.00
0005432613891	3463	Comfort	19900.00
0005434878915	3463	Comfort	19900.00
0005434938276	3463	Comfort	19900.00
0005432799649	3463	Comfort	19900.00
0005432611741	3463	Comfort	19900.00
0005435126650	3463	Comfort	19900.00
0005434426821	3463	Comfort	19900.00
0005434878898	3463	Comfort	19900.00
0005435126657	3463	Comfort	19900.00
0005434878949	3463	Comfort	19900.00
0005435902691	3463	Comfort	19900.00
0005434878945	3463	Comfort	19900.00
0005434878894	3463	Economy	11700.00
0005434426830	3463	Economy	11700.00
0005434426813	3463	Economy	11700.00
0005432183482	3463	Economy	11700.00
0005435126685	3463	Economy	11700.00
0005435126649	3463	Economy	11700.00
0005434938280	3463	Economy	11700.00
0005435126663	3463	Economy	11700.00
0005432613890	3463	Economy	11700.00
0005435902646	3463	Economy	11700.00
0005432613892	3463	Economy	11700.00
0005435902705	3463	Economy	11700.00
0005435126687	3463	Economy	11700.00
0005434878946	3463	Economy	11700.00
0005435902650	3463	Economy	11700.00
0005432799668	3463	Economy	11700.00
0005435126662	3463	Economy	11700.00
0005434878863	3463	Economy	11700.00
0005434878878	3463	Economy	11700.00
0005432799652	3463	Economy	11700.00
0005432611739	3463	Economy	11700.00
0005434426828	3463	Economy	11700.00
0005434938283	3463	Economy	11700.00
0005435126682	3463	Economy	11700.00
0005435902706	3463	Economy	11700.00
0005434426810	3463	Economy	11700.00
0005434878921	3463	Economy	11700.00
0005434878906	3463	Economy	11700.00
0005434878865	3463	Economy	11700.00
0005435126659	3463	Economy	11700.00
0005435902675	3463	Economy	11700.00
0005434878884	3463	Economy	11700.00
0005434426832	3463	Economy	11700.00
0005434426814	3463	Economy	11700.00
0005435626309	3463	Economy	11700.00
0005435626315	3463	Economy	11700.00
0005434426811	3463	Economy	11700.00
0005434878936	3463	Economy	11700.00
0005434878914	3463	Economy	11700.00
0005434938290	3463	Economy	11700.00
0005434878950	3463	Economy	11700.00
0005435913926	3463	Economy	11700.00
0005434878917	3463	Economy	11700.00
0005434878913	3463	Economy	11700.00
0005432799657	3463	Economy	11700.00
0005434938279	3463	Economy	11700.00
0005434878881	3463	Economy	11700.00
0005435126674	3463	Economy	11700.00
0005435126676	3463	Economy	11700.00
0005432799659	3463	Economy	11700.00
0005434938277	3463	Economy	11700.00
0005434878889	3463	Economy	11700.00
0005434878923	3463	Economy	11700.00
0005434878925	3463	Economy	11700.00
0005434878947	3463	Economy	12800.00
0005435126680	3463	Economy	12800.00
0005434878901	3463	Economy	11700.00
0005434878929	3463	Economy	11700.00
0005434878916	3463	Economy	11700.00
0005435902621	3463	Economy	12800.00
0005435126670	3463	Economy	11700.00
0005432799669	3463	Economy	11700.00
0005434878910	3463	Economy	11700.00
0005434878928	3463	Economy	11700.00
0005432611740	3463	Economy	11700.00
0005434878940	3463	Economy	11700.00
0005434878903	3463	Economy	11700.00
0005434426815	3463	Economy	11700.00
0005432799650	3463	Economy	11700.00
0005434878897	3463	Economy	11700.00
0005434878871	3463	Economy	11700.00
0005434878939	3463	Economy	11700.00
0005435913925	3463	Economy	11700.00
0005434878876	3463	Economy	11700.00
0005434426822	3463	Economy	11700.00
0005435126656	3463	Economy	11700.00
0005435126652	3463	Economy	11700.00
0005434426836	3463	Economy	11700.00
0005434938292	3463	Economy	11700.00
0005434878935	3463	Economy	11700.00
0005435126666	3463	Economy	11700.00
0005434938273	3463	Economy	11700.00
0005435626308	3463	Economy	11700.00
0005434878938	3463	Economy	11700.00
0005432799662	3463	Economy	11700.00
0005435126658	3463	Economy	11700.00
0005434878908	3463	Economy	11700.00
0005435626310	3463	Economy	11700.00
0005434426823	3463	Economy	11700.00
0005435126655	3463	Economy	11700.00
0005434878900	3463	Economy	11700.00
0005435902662	3463	Economy	11700.00
0005434878934	3463	Economy	11700.00
0005435126648	3463	Economy	11700.00
0005435902724	3463	Economy	11700.00
0005432799653	3463	Economy	11700.00
0005432799667	3463	Economy	11700.00
0005435126654	3463	Economy	11700.00
0005434878954	3463	Economy	11700.00
0005434878912	3463	Economy	11700.00
0005435626311	3463	Economy	11700.00
0005434878941	3463	Economy	11700.00
0005434878931	3463	Economy	11700.00
0005434938287	3463	Economy	11700.00
0005434426816	3463	Economy	11700.00
0005435126683	3463	Economy	11700.00
0005434878942	3463	Economy	11700.00
0005434878869	3463	Economy	11700.00
0005435902676	3463	Economy	11700.00
0005434938286	3463	Economy	11700.00
0005435126669	3463	Economy	11700.00
0005435902698	3463	Economy	11700.00
0005434878920	3463	Economy	11700.00
0005435126677	3463	Economy	11700.00
0005434878932	3463	Economy	11700.00
0005434878904	3463	Economy	11700.00
0005435902664	3463	Economy	11700.00
0005434878907	3463	Economy	11700.00
0005434878951	3463	Economy	11700.00
0005434878905	3463	Economy	11700.00
0005434938289	3463	Economy	11700.00
0005435902644	3463	Economy	11700.00
0005434938288	3463	Economy	11700.00
0005435126675	3463	Economy	11700.00
0005434878891	3463	Economy	11700.00
0005434878888	3463	Economy	11700.00
0005434426834	3463	Economy	11700.00
0005435626307	3463	Economy	11700.00
0005434938291	3463	Economy	11700.00
0005434938281	3463	Economy	11700.00
0005434938284	3463	Economy	11700.00
0005435126660	3463	Economy	12800.00
0005434878933	3463	Economy	12800.00
0005434878909	3463	Economy	12800.00
0005435126678	3463	Economy	11700.00
0005434878867	3463	Economy	11700.00
0005434878895	3463	Economy	11700.00
0005435902674	3463	Economy	11700.00
0005435126679	3463	Economy	11700.00
0005432613893	3463	Economy	11700.00
0005434878870	3463	Economy	11700.00
0005434426833	3463	Economy	11700.00
0005432799675	3463	Economy	11700.00
0005432188631	3463	Economy	11700.00
0005435902739	3463	Economy	11700.00
0005434426829	3463	Economy	11700.00
0005434426831	3463	Economy	11700.00
0005434878952	3463	Economy	11700.00
0005432799656	3463	Economy	11700.00
0005434878956	3463	Economy	11700.00
0005435126653	3463	Economy	11700.00
0005434878926	3463	Economy	11700.00
0005435902725	3463	Economy	11700.00
0005435841822	3463	Economy	11700.00
0005432611738	3463	Economy	11700.00
0005435126681	3463	Economy	11700.00
0005434426820	3463	Economy	11700.00
0005434878873	3463	Economy	11700.00
0005435126684	3463	Economy	11700.00
0005432799651	3463	Economy	11700.00
0005432799654	3463	Economy	11700.00
0005434878890	3463	Economy	11700.00
0005435626306	3463	Economy	11700.00
0005434426818	3463	Economy	11700.00
0005432799660	3463	Economy	11700.00
0005435626312	3463	Economy	11700.00
0005434878896	3463	Economy	11700.00
0005432188632	3463	Economy	11700.00
0005434878918	3463	Economy	11700.00
0005434426826	3463	Economy	11700.00
0005434878902	3463	Economy	11700.00
0005434878893	3463	Economy	11700.00
0005432799661	3463	Economy	11700.00
0005434878880	3463	Economy	11700.00
0005434878862	3463	Economy	11700.00
0005434426827	3463	Economy	11700.00
0005435126673	3463	Economy	11700.00
0005432799674	3463	Economy	11700.00
0005434878927	3463	Economy	11700.00
0005432799665	3463	Economy	11700.00
0005432799671	3463	Economy	11700.00
0005434878937	3463	Economy	11700.00
0005432799655	3463	Economy	11700.00
0005432799648	3463	Economy	11700.00
0005434938275	3463	Economy	11700.00
0005435126667	3463	Economy	11700.00
0005435126671	3463	Economy	11700.00
0005435126664	3463	Economy	11700.00
0005435626313	3463	Economy	11700.00
0005432799663	3463	Economy	11700.00
0005434878955	3463	Economy	11700.00
0005434426824	3463	Economy	11700.00
0005434878875	3463	Economy	11700.00
0005434938282	3463	Economy	11700.00
0005435126672	3463	Economy	11700.00
0005434938285	3463	Economy	11700.00
0005432799658	3463	Economy	11700.00
0005434878882	3463	Economy	11700.00
0005435913927	3463	Economy	11700.00
0005434426809	3463	Economy	11700.00
0005434878899	3463	Economy	11700.00
0005434878885	3463	Economy	11700.00
0005434878877	3463	Economy	11700.00
0005435902699	3463	Economy	11700.00
0005434426817	3463	Economy	11700.00
0005434938278	3463	Economy	11700.00
0005435126647	3463	Economy	11700.00
0005434878943	3463	Economy	11700.00
0005434878872	3463	Economy	11700.00
0005432799666	3463	Economy	11700.00
0005435902645	3463	Economy	11700.00
0005434878122	14552	Business	35000.00
0005434878636	14552	Business	35000.00
0005434938172	14552	Business	35000.00
0005435626095	14552	Business	35000.00
0005434426592	14552	Business	35000.00
0005432799363	14552	Business	35000.00
0005434426552	14552	Business	35000.00
0005432799510	14552	Business	35000.00
0005434878274	14552	Business	35000.00
0005435626074	14552	Business	35000.00
0005434878015	14552	Business	35000.00
0005435902834	14552	Business	35000.00
0005434878115	14552	Business	35000.00
0005434878144	14552	Business	35000.00
0005432611703	14552	Business	35000.00
0005435902830	14552	Business	35000.00
0005434878149	14552	Business	35000.00
0005435626101	14552	Business	35000.00
0005434426563	14552	Business	35000.00
0005432799380	14552	Business	35000.00
0005434878717	14552	Comfort	19900.00
0005435126315	14552	Comfort	19900.00
0005435902840	14552	Comfort	19900.00
0005434877841	14552	Comfort	19900.00
0005434878135	14552	Comfort	19900.00
0005434938076	14552	Comfort	19900.00
0005434877972	14552	Comfort	19900.00
0005435902831	14552	Comfort	19900.00
0005432799381	14552	Comfort	19900.00
0005434878413	14552	Comfort	19900.00
0005434938065	14552	Comfort	19900.00
0005434878418	14552	Comfort	19900.00
0005434877819	14552	Comfort	19900.00
0005434878282	14552	Comfort	19900.00
0005435626109	14552	Comfort	19900.00
0005435126288	14552	Comfort	19900.00
0005434878420	14552	Comfort	19900.00
0005434878421	14552	Comfort	19900.00
0005434426512	14552	Comfort	19900.00
0005432799442	14552	Comfort	19900.00
0005434878011	14552	Comfort	19900.00
0005434878176	14552	Comfort	19900.00
0005434878043	14552	Comfort	19900.00
0005434878089	14552	Comfort	19900.00
0005434937981	14552	Comfort	19900.00
0005432799443	14552	Comfort	19900.00
0005435126317	14552	Comfort	19900.00
0005435126289	14552	Economy	11700.00
0005435902823	14552	Economy	11700.00
0005434426564	14552	Economy	11700.00
0005435841826	14552	Economy	11700.00
0005434878067	14552	Economy	11700.00
0005434878214	14552	Economy	11700.00
0005434426593	14552	Economy	11700.00
0005434877991	14552	Economy	11700.00
0005434426613	14552	Economy	11700.00
0005434938161	14552	Economy	11700.00
0005434878102	14552	Economy	11700.00
0005435126243	14552	Economy	11700.00
0005434877868	14552	Economy	11700.00
0005434938029	14552	Economy	11700.00
0005434426708	14552	Economy	11700.00
0005435126551	14552	Economy	11700.00
0005434426480	14552	Economy	11700.00
0005432059518	14552	Economy	11700.00
0005434426608	14552	Economy	11700.00
0005434877919	14552	Economy	11700.00
0005434938138	14552	Economy	11700.00
0005434426573	14552	Economy	11700.00
0005435126171	14552	Economy	11700.00
0005432799456	14552	Economy	11700.00
0005434938123	14552	Economy	11700.00
0005435126316	14552	Economy	11700.00
0005434877976	14552	Economy	11700.00
0005435126284	14552	Economy	11700.00
0005434426520	14552	Economy	11700.00
0005434938143	14552	Economy	11700.00
0005434426635	14552	Economy	11700.00
0005434877987	14552	Economy	11700.00
0005435126172	14552	Economy	11700.00
0005435626098	14552	Economy	11700.00
0005432611705	14552	Economy	11700.00
0005434877979	14552	Economy	11700.00
0005434877786	14552	Economy	11700.00
0005435126298	14552	Economy	11700.00
0005435126400	14552	Economy	11700.00
0005432799428	14552	Economy	11700.00
0005432799473	14552	Economy	11700.00
0005434878315	14552	Economy	11700.00
0005435626123	14552	Economy	11700.00
0005434877852	14552	Economy	11700.00
0005432799495	14552	Economy	11700.00
0005434938036	14552	Economy	11700.00
0005434938144	14552	Economy	11700.00
0005434877977	14552	Economy	11700.00
0005432611725	14552	Economy	11700.00
0005434877884	14552	Economy	11700.00
0005435126440	14552	Economy	11700.00
0005434938132	14552	Economy	11700.00
0005434877668	14552	Economy	11700.00
0005434426472	14552	Economy	12800.00
0005434878179	14552	Economy	12800.00
0005435126257	14552	Economy	11700.00
0005432611704	14552	Economy	12800.00
0005434938028	14552	Economy	11700.00
0005432611700	14552	Economy	11700.00
0005435126297	14552	Economy	11700.00
0005434938114	14552	Economy	12800.00
0005434877950	14552	Economy	11700.00
0005434426565	14552	Economy	11700.00
0005435126162	14552	Economy	11700.00
0005434878222	14552	Economy	11700.00
0005435126383	14552	Economy	11700.00
0005434426725	14552	Economy	11700.00
0005434938108	14552	Economy	11700.00
0005432799436	14552	Economy	11700.00
0005435126355	14552	Economy	11700.00
0005434877992	14552	Economy	11700.00
0005435902838	14552	Economy	11700.00
0005434878276	14552	Economy	11700.00
0005434938173	14552	Economy	11700.00
0005434877871	14552	Economy	11700.00
0005432607543	14552	Economy	11700.00
0005432799465	14552	Economy	11700.00
0005435126235	14552	Economy	11700.00
0005434878219	14552	Economy	11700.00
0005434877941	14552	Economy	11700.00
0005435126208	14552	Economy	11700.00
0005434878496	14552	Economy	11700.00
0005432799362	14552	Economy	11700.00
0005434878407	14552	Economy	11700.00
0005434878357	14552	Economy	11700.00
0005434878007	14552	Economy	11700.00
0005435902829	14552	Economy	11700.00
0005434426531	14552	Economy	11700.00
0005434878148	14552	Economy	11700.00
0005435126401	14552	Economy	11700.00
0005435626091	14552	Economy	11700.00
0005435126357	14552	Economy	11700.00
0005434878365	14552	Economy	11700.00
0005434878398	14552	Economy	11700.00
0005435126318	14552	Economy	11700.00
0005434426634	14552	Economy	11700.00
0005434878321	14552	Economy	11700.00
0005434878568	14552	Economy	11700.00
0005432799323	14552	Economy	11700.00
0005434877579	14552	Economy	11700.00
0005435126299	14552	Economy	11700.00
0005434878210	14552	Economy	11700.00
0005434878211	14552	Economy	11700.00
0005434878109	14552	Economy	11700.00
0005434878358	14552	Economy	11700.00
0005435126239	14552	Economy	11700.00
0005434878180	14552	Economy	11700.00
0005435902821	14552	Economy	11700.00
0005432059519	14552	Economy	11700.00
0005432799433	14552	Economy	11700.00
0005434426672	14552	Economy	11700.00
0005434938124	14552	Economy	11700.00
0005434878414	14552	Economy	11700.00
0005435126300	14552	Economy	11700.00
0005434877951	14552	Economy	11700.00
0005434877578	14552	Economy	11700.00
0005434878223	14552	Economy	11700.00
0005434938136	14552	Economy	11700.00
0005434426609	14552	Economy	11700.00
0005435126128	14552	Economy	11700.00
0005434878209	14552	Economy	11700.00
0005434878277	14552	Economy	11700.00
0005435626075	14552	Economy	11700.00
0005434938066	14552	Economy	11700.00
0005434878314	14552	Economy	11700.00
0005435902839	14552	Economy	11700.00
0005434878071	14552	Economy	11700.00
0005435126152	14552	Economy	11700.00
0005434878177	14552	Economy	11700.00
0005434878370	14552	Economy	11700.00
0005434878390	14552	Economy	11700.00
0005434426495	14552	Economy	11700.00
0005434878103	14552	Economy	11700.00
0005434878408	14552	Economy	11700.00
0005435626114	14552	Economy	11700.00
0005434878163	14552	Economy	11700.00
0005434878275	14552	Economy	11700.00
0005435626094	14552	Economy	11700.00
0005435902833	14552	Economy	11700.00
0005435626099	14552	Economy	11700.00
0005434426550	14552	Economy	11700.00
0005434878162	14552	Economy	12800.00
0005434877971	14552	Economy	12800.00
0005434426533	14552	Economy	12800.00
0005434877842	14552	Economy	11700.00
0005434878399	14552	Economy	11700.00
0005435626100	14552	Economy	11700.00
0005432799501	14552	Economy	11700.00
0005434938135	14552	Economy	11700.00
0005435626049	14552	Economy	11700.00
0005435902822	14552	Economy	11700.00
0005434878363	14552	Economy	11700.00
0005435126125	14552	Economy	11700.00
0005435126127	14552	Economy	11700.00
0005434877915	14552	Economy	11700.00
0005434426594	14552	Economy	11700.00
0005435126382	14552	Economy	11700.00
0005434877869	14552	Economy	11700.00
0005435902826	14552	Economy	11700.00
0005432799401	14552	Economy	11700.00
0005434938137	14552	Economy	11700.00
0005435126157	14552	Economy	11700.00
0005434426460	14552	Economy	11700.00
0005434878058	14552	Economy	11700.00
0005435902824	14552	Economy	11700.00
0005434878108	14552	Economy	11700.00
0005435126314	14552	Economy	11700.00
0005434877632	14552	Economy	11700.00
0005434877902	14552	Economy	11700.00
0005434878290	14552	Economy	11700.00
0005434878391	14552	Economy	11700.00
0005432611699	14552	Economy	11700.00
0005435126237	14552	Economy	11700.00
0005434878114	14552	Economy	11700.00
0005435126442	14552	Economy	11700.00
0005435902825	14552	Economy	11700.00
0005434877707	14552	Economy	11700.00
0005434877708	14552	Economy	11700.00
0005435902832	14552	Economy	11700.00
0005432611712	14552	Economy	11700.00
0005432799452	14552	Economy	11700.00
0005434426479	14552	Economy	11700.00
0005432799420	14552	Economy	11700.00
0005435902837	14552	Economy	11700.00
0005435626092	14552	Economy	11700.00
0005434878456	14552	Economy	11700.00
0005435902836	14552	Economy	11700.00
0005434938115	14552	Economy	11700.00
0005434878254	14552	Economy	11700.00
0005435626080	14552	Economy	11700.00
0005434877469	14552	Economy	11700.00
0005434878567	14552	Economy	11700.00
0005435126158	14552	Economy	11700.00
0005432611724	14552	Economy	11700.00
0005435902828	14552	Economy	11700.00
0005434426617	14552	Economy	11700.00
0005435126219	14552	Economy	11700.00
0005434878264	14552	Economy	11700.00
0005435626070	14552	Economy	11700.00
0005434877920	14552	Economy	11700.00
0005434426553	14552	Economy	11700.00
0005434877978	14552	Economy	11700.00
0005434426532	14552	Economy	11700.00
0005435626106	14552	Economy	11700.00
0005434878635	14552	Economy	11700.00
0005435126236	14552	Economy	11700.00
0005432799432	14552	Economy	11700.00
0005434877669	14552	Economy	11700.00
0005435126356	14552	Economy	11700.00
0005432799419	14552	Economy	11700.00
0005435902835	14552	Economy	11700.00
0005434877429	14552	Economy	11700.00
0005432799338	14552	Economy	11700.00
0005432799496	14552	Economy	11700.00
0005435902827	14552	Economy	11700.00
0005435126417	14552	Economy	11700.00
0005434426614	14552	Economy	11700.00
0005434877957	14552	Economy	11700.00
0005434938075	14552	Economy	11700.00
0005434938145	14552	Economy	11700.00
0005434426541	14552	Economy	11700.00
0005432607540	14552	Economy	11700.00
0005434877942	14552	Economy	11700.00
0005435126153	14552	Economy	11700.00
0005435626055	14552	Economy	11700.00
0005434878150	14552	Economy	11700.00
0005435626056	14552	Economy	11700.00
0005432799457	14552	Economy	11700.00
0005434878267	14552	Economy	11700.00
0005434938030	14552	Economy	11700.00
0005434877787	14552	Economy	11700.00
0005435889885	3627	Economy	16300.00
0005435889891	3627	Economy	16300.00
0005435889884	3627	Economy	16300.00
0005434325733	3627	Economy	14800.00
0005435889882	3627	Economy	14800.00
0005435889890	3627	Economy	14800.00
0005434325730	3627	Economy	14800.00
0005435889898	3627	Economy	14800.00
0005434325728	3627	Economy	14800.00
0005434325734	3627	Economy	14800.00
0005434325727	3627	Economy	14800.00
0005434312335	3627	Economy	14800.00
0005434325737	3627	Economy	14800.00
0005435889897	3627	Economy	14800.00
0005434325735	3627	Economy	14800.00
0005434312334	3627	Economy	14800.00
0005435889858	3627	Economy	14800.00
0005434325729	3627	Economy	14800.00
0005434312333	3627	Economy	14800.00
0005434325731	3627	Economy	14800.00
0005434325738	3627	Economy	14800.00
0005434325736	3627	Economy	14800.00
0005435889873	3627	Economy	14800.00
0005434325732	3627	Economy	14800.00
0005435889904	3627	Economy	14800.00
0005434325663	15598	Economy	16300.00
0005434325623	15598	Economy	14800.00
0005434325659	15598	Economy	14800.00
0005435889940	15598	Economy	14800.00
0005434325609	15598	Economy	14800.00
0005435889939	15598	Economy	14800.00
0005434325652	15598	Economy	14800.00
0005434325671	15598	Economy	14800.00
0005434325651	15598	Economy	14800.00
0005435889937	15598	Economy	14800.00
0005434325664	15598	Economy	14800.00
0005434325627	15598	Economy	14800.00
0005435889941	15598	Economy	14800.00
0005435889938	15598	Economy	14800.00
0005434325640	15598	Economy	14800.00
0005434325650	15598	Economy	14800.00
0005434325666	15598	Economy	14800.00
0005435889942	15598	Economy	14800.00
0005434325626	15598	Economy	14800.00
0005434325639	15598	Economy	14800.00
0005434325642	15598	Economy	14800.00
0005434325670	15598	Economy	14800.00
0005434325665	15598	Economy	14800.00
0005434325658	15598	Economy	14800.00
0005434325647	15598	Economy	14800.00
0005434325621	15598	Economy	14800.00
0005434325641	15598	Economy	14800.00
0005434325656	15598	Economy	14800.00
0005434325657	15598	Economy	14800.00
0005435957806	667	Economy	4500.00
0005435957805	667	Economy	4500.00
0005435957802	667	Economy	4100.00
0005435957804	667	Economy	4100.00
0005435957803	667	Economy	4100.00
0005435957811	667	Economy	4100.00
0005435957812	667	Economy	4100.00
0005433420369	667	Economy	4100.00
0005433420365	667	Economy	4100.00
0005433420401	667	Economy	4100.00
0005435957810	667	Economy	4100.00
0005433420355	667	Economy	4100.00
0005435957809	667	Economy	4100.00
0005435957808	667	Economy	4100.00
0005433420386	667	Economy	4100.00
0005435957814	667	Economy	4100.00
0005433420403	667	Economy	4100.00
0005435957816	667	Economy	4100.00
0005435957801	667	Economy	4100.00
0005435957813	667	Economy	4100.00
0005433420370	667	Economy	4100.00
0005435957815	667	Economy	4100.00
0005435957807	667	Economy	4100.00
0005435957674	15172	Economy	4500.00
0005435957645	15172	Economy	4500.00
0005433420464	15172	Economy	4500.00
0005433420462	15172	Economy	4100.00
0005433420468	15172	Economy	4100.00
0005433420463	15172	Economy	4100.00
0005435957739	15172	Economy	4100.00
0005435957684	15172	Economy	4100.00
0005435957672	15172	Economy	4100.00
0005435957705	15172	Economy	4100.00
0005435957647	15172	Economy	4100.00
0005435957613	15172	Economy	4100.00
0005435957671	15172	Economy	4100.00
0005433420466	15172	Economy	4100.00
0005435957668	15172	Economy	4100.00
0005435957693	15172	Economy	4100.00
0005435957676	15172	Economy	4100.00
0005435957675	15172	Economy	4100.00
0005433420461	15172	Economy	4100.00
0005435957704	15172	Economy	4100.00
0005435957695	15172	Economy	4100.00
0005435957698	15172	Economy	4100.00
0005433420467	15172	Economy	4100.00
0005435957692	15172	Economy	4100.00
0005435957646	15172	Economy	4100.00
0005435957696	15172	Economy	4100.00
0005435957670	15172	Economy	4100.00
0005435957667	15172	Economy	4100.00
0005435957607	15172	Economy	4100.00
0005433420465	15172	Economy	4100.00
0005433420460	15172	Economy	4100.00
0005435957694	15172	Economy	4100.00
0005435957669	15172	Economy	4100.00
0005435218122	31786	Economy	28100.00
0005435217725	31786	Economy	25500.00
0005435216600	31786	Economy	25500.00
0005435216603	31786	Economy	25500.00
0005435217726	31786	Economy	25500.00
0005435216606	31786	Economy	25500.00
0005435216601	31786	Economy	25500.00
0005435217727	31786	Economy	25500.00
0005435216604	31786	Economy	25500.00
0005435216602	31786	Economy	25500.00
0005435217729	31786	Economy	25500.00
0005435217728	31786	Economy	25500.00
0005435216605	31786	Economy	25500.00
0005435217730	31786	Economy	25500.00
0005435217724	31786	Economy	25500.00
0005435218121	31786	Economy	25500.00
0005434995311	6702	Business	94000.00
0005434995317	6702	Business	94000.00
0005434995319	6702	Economy	31300.00
0005434995320	6702	Economy	31300.00
0005434995313	6702	Economy	31300.00
0005434995312	6702	Economy	31300.00
0005434995315	6702	Economy	31300.00
0005434995314	6702	Economy	31300.00
0005434995325	6702	Economy	31300.00
0005434995318	6702	Economy	31300.00
0005434995322	6702	Economy	31300.00
0005434995324	6702	Economy	31300.00
0005434995310	6702	Economy	31300.00
0005434995321	6702	Economy	31300.00
0005434995316	6702	Economy	31300.00
0005434995323	6702	Economy	31300.00
0005434247143	8888	Economy	10400.00
0005435629412	8888	Economy	10400.00
0005434247156	8888	Economy	10400.00
0005434247165	16066	Economy	10400.00
0005434247166	16066	Economy	10400.00
0005434247167	16066	Economy	10400.00
0005434467779	4009	Economy	21200.00
0005434467781	4009	Economy	21200.00
0005434467777	4009	Economy	21200.00
0005434467778	4009	Economy	21200.00
0005434467776	4009	Economy	21200.00
0005434467780	4009	Economy	21200.00
0005434467775	4009	Economy	21200.00
0005434467745	23212	Economy	23400.00
0005434467758	23212	Economy	21200.00
0005434467744	23212	Economy	21200.00
0005434467762	23212	Economy	21200.00
0005434467754	23212	Economy	21200.00
0005434096756	20164	Economy	14700.00
0005434096750	20164	Economy	13400.00
0005434096755	20164	Economy	13400.00
0005434096754	20164	Economy	13400.00
0005434096753	20164	Economy	13400.00
0005434096752	20164	Economy	13400.00
0005434096751	20164	Economy	13400.00
0005434096757	20164	Economy	13400.00
0005432646052	6838	Business	87700.00
0005432646058	6838	Business	87700.00
0005432646053	6838	Business	87700.00
0005432646091	6838	Business	87700.00
0005435229411	6838	Business	87700.00
0005432646066	6838	Business	87700.00
0005432646086	6838	Economy	29200.00
0005432646063	6838	Economy	29200.00
0005432646057	6838	Economy	29200.00
0005432646065	6838	Economy	29200.00
0005432646056	6838	Economy	29200.00
0005435229405	6838	Economy	32200.00
0005435229413	6838	Economy	32200.00
0005435229392	6838	Economy	32200.00
0005432646071	6838	Economy	29200.00
0005432646059	6838	Economy	29200.00
0005435229412	6838	Economy	29200.00
0005432646075	6838	Economy	29200.00
0005435229356	6838	Economy	29200.00
0005432646062	6838	Economy	29200.00
0005432646087	6838	Economy	29200.00
0005432646083	6838	Economy	29200.00
0005432646064	6838	Economy	29200.00
0005432646081	6838	Economy	29200.00
0005432646077	6838	Economy	29200.00
0005432646073	6838	Economy	29200.00
0005432646089	6838	Economy	29200.00
0005435229386	6838	Economy	29200.00
0005432646069	6838	Economy	29200.00
0005432646074	6838	Economy	29200.00
0005432646070	6838	Economy	29200.00
0005435229359	6838	Economy	29200.00
0005432646076	6838	Economy	29200.00
0005435229430	6838	Economy	29200.00
0005435229414	6838	Economy	29200.00
0005432646084	6838	Economy	29200.00
0005432646061	6838	Economy	29200.00
0005435229432	6838	Economy	29200.00
0005432646060	6838	Economy	29200.00
0005435229406	6838	Economy	29200.00
0005435229404	6838	Economy	29200.00
0005432646054	6838	Economy	29200.00
0005432646072	6838	Economy	29200.00
0005432646085	6838	Economy	29200.00
0005432646090	6838	Economy	29200.00
0005435229390	6838	Economy	29200.00
0005432646078	6838	Economy	29200.00
0005432646068	6838	Economy	29200.00
0005432646079	6838	Economy	29200.00
0005432646088	6838	Economy	29200.00
0005432646082	6838	Economy	29200.00
0005432646055	6838	Economy	29200.00
0005435229391	6838	Economy	29200.00
0005432646080	6838	Economy	29200.00
0005432646067	6838	Economy	29200.00
0005435229460	25104	Business	87700.00
0005432645922	25104	Business	87700.00
0005432645930	25104	Business	87700.00
0005435229483	25104	Business	87700.00
0005435229474	25104	Business	87700.00
0005435229471	25104	Business	87700.00
0005432645917	25104	Business	87700.00
0005435229478	25104	Business	87700.00
0005432645959	25104	Business	87700.00
0005435229469	25104	Business	87700.00
0005435229458	25104	Business	87700.00
0005435229482	25104	Economy	29200.00
0005432645911	25104	Economy	29200.00
0005432645927	25104	Economy	29200.00
0005432645925	25104	Economy	29200.00
0005435229457	25104	Economy	29200.00
0005432645891	25104	Economy	29200.00
0005432645968	25104	Economy	32200.00
0005432645964	25104	Economy	32200.00
0005432645948	25104	Economy	32200.00
0005432645949	25104	Economy	32200.00
0005432645979	25104	Economy	32200.00
0005432645957	25104	Economy	29200.00
0005435229459	25104	Economy	29200.00
0005432645937	25104	Economy	29200.00
0005432645985	25104	Economy	29200.00
0005432645907	25104	Economy	29200.00
0005435229466	25104	Economy	29200.00
0005435229470	25104	Economy	29200.00
0005435229479	25104	Economy	29200.00
0005432645914	25104	Economy	29200.00
0005432645916	25104	Economy	29200.00
0005435229463	25104	Economy	29200.00
0005432645938	25104	Economy	29200.00
0005432645926	25104	Economy	29200.00
0005432645892	25104	Economy	29200.00
0005432645923	25104	Economy	29200.00
0005432645982	25104	Economy	29200.00
0005435229484	25104	Economy	29200.00
0005435229473	25104	Economy	29200.00
0005435229468	25104	Economy	29200.00
0005432645919	25104	Economy	29200.00
0005432645893	25104	Economy	29200.00
0005435229465	25104	Economy	29200.00
0005435229481	25104	Economy	29200.00
0005435229475	25104	Economy	29200.00
0005432645889	25104	Economy	29200.00
0005432645913	25104	Economy	29200.00
0005435229485	25104	Economy	29200.00
0005435229486	25104	Economy	29200.00
0005435229477	25104	Economy	29200.00
0005435229472	25104	Economy	29200.00
0005432645924	25104	Economy	29200.00
0005435229476	25104	Economy	29200.00
0005432645939	25104	Economy	29200.00
0005432645918	25104	Economy	29200.00
0005432645908	25104	Economy	29200.00
0005432645936	25104	Economy	29200.00
0005435229467	25104	Economy	29200.00
0005432645942	25104	Economy	29200.00
0005432645929	25104	Economy	29200.00
0005432645886	25104	Economy	29200.00
0005432645873	25104	Economy	29200.00
0005432645955	25104	Economy	29200.00
0005435229461	25104	Economy	29200.00
0005435229464	25104	Economy	29200.00
0005435229480	25104	Economy	29200.00
0005432645954	25104	Economy	29200.00
0005432645941	25104	Economy	29200.00
0005432645928	25104	Economy	29200.00
0005432645934	25104	Economy	29200.00
0005432645920	25104	Economy	29200.00
0005435229462	25104	Economy	29200.00
0005432645940	25104	Economy	29200.00
0005432645944	25104	Economy	29200.00
0005432645956	25104	Economy	29200.00
0005432645906	25104	Economy	29200.00
0005435797582	2866	Business	12600.00
0005435797572	2866	Business	12600.00
0005435797578	2866	Business	12600.00
0005435797574	2866	Economy	4200.00
0005435797573	2866	Economy	4200.00
0005433404777	2866	Economy	4200.00
0005433404760	2866	Economy	4600.00
0005435797575	2866	Economy	4200.00
0005435797581	2866	Economy	4200.00
0005435797576	2866	Economy	4200.00
0005433404786	2866	Economy	4200.00
0005435797583	2866	Economy	4200.00
0005435797580	2866	Economy	4200.00
0005435797571	2866	Economy	4200.00
0005433404761	2866	Economy	4200.00
0005435797569	2866	Economy	4200.00
0005435797579	2866	Economy	4200.00
0005435797577	2866	Economy	4200.00
0005435797570	2866	Economy	4200.00
0005433404806	2866	Economy	4200.00
0005433404787	2866	Economy	4200.00
0005435797497	29342	Business	12600.00
0005435797401	29342	Business	12600.00
0005435797467	29342	Economy	4200.00
0005433404864	29342	Economy	4200.00
0005435797529	29342	Economy	4200.00
0005435797469	29342	Economy	4200.00
0005435797400	29342	Economy	4200.00
0005433404862	29342	Economy	4200.00
0005433404866	29342	Economy	4200.00
0005433404861	29342	Economy	4200.00
0005433404865	29342	Economy	4200.00
0005435797528	29342	Economy	4200.00
0005435797451	29342	Economy	4200.00
0005435797498	29342	Economy	4200.00
0005435797480	29342	Economy	4200.00
0005433404863	29342	Economy	4200.00
0005435797445	29342	Economy	4200.00
0005435797470	29342	Economy	4200.00
0005435797450	29342	Economy	4200.00
0005435376357	5804	Economy	6800.00
0005435376351	5804	Economy	6800.00
0005435376352	5804	Economy	6800.00
0005435376346	5804	Economy	6800.00
0005435376347	5804	Economy	6800.00
0005434948082	5749	Economy	6800.00
0005434948080	5749	Economy	6800.00
0005434948076	5749	Economy	6800.00
0005434948077	5749	Economy	6800.00
0005434948081	5749	Economy	6800.00
0005434948083	5749	Economy	6800.00
0005434948074	5749	Economy	6800.00
0005434948075	5749	Economy	6800.00
0005434948078	5749	Economy	6800.00
0005434948079	5749	Economy	6800.00
0005434948005	16330	Economy	6800.00
0005434948031	16330	Economy	6800.00
0005434948008	16330	Economy	6800.00
0005434947992	16330	Economy	6800.00
0005434948034	16330	Economy	6800.00
0005434948010	16330	Economy	6800.00
0005434948030	16330	Economy	6800.00
0005434948032	16330	Economy	6800.00
0005434948009	16330	Economy	6800.00
0005434948033	16330	Economy	6800.00
0005434948007	16330	Economy	6800.00
0005433961279	6913	Business	21400.00
0005433961314	6913	Business	21400.00
0005433961287	6913	Business	21400.00
0005433961290	6913	Business	21400.00
0005433961317	6913	Business	21400.00
0005433961285	6913	Business	21400.00
0005433961307	6913	Economy	7100.00
0005433961298	6913	Economy	7100.00
0005433961326	6913	Economy	7100.00
0005433961294	6913	Economy	7100.00
0005433961302	6913	Economy	7100.00
0005433961316	6913	Economy	7100.00
0005433961282	6913	Economy	7100.00
0005433961325	6913	Economy	7100.00
0005433961322	6913	Economy	7800.00
0005433961269	6913	Economy	7800.00
0005433961295	6913	Economy	7800.00
0005433961311	6913	Economy	7100.00
0005433961286	6913	Economy	7100.00
0005433961319	6913	Economy	7100.00
0005433961306	6913	Economy	7100.00
0005433961283	6913	Economy	7100.00
0005433961310	6913	Economy	7100.00
0005433961320	6913	Economy	7100.00
0005433961305	6913	Economy	7100.00
0005433961289	6913	Economy	7100.00
0005433961308	6913	Economy	7100.00
0005433961309	6913	Economy	7100.00
0005433961318	6913	Economy	7100.00
0005433961270	6913	Economy	7100.00
0005433961296	6913	Economy	7100.00
0005433961264	6913	Economy	7100.00
0005433961280	6913	Economy	7100.00
0005433961292	6913	Economy	7100.00
0005433961277	6913	Economy	7100.00
0005433961272	6913	Economy	7100.00
0005433961297	6913	Economy	7100.00
0005433961303	6913	Economy	7100.00
0005433961313	6913	Economy	7100.00
0005433961293	6913	Economy	7100.00
0005433961300	6913	Economy	7100.00
0005433961312	6913	Economy	7100.00
0005433961273	6913	Economy	7100.00
0005433961328	6913	Economy	7100.00
0005433961288	6913	Economy	7100.00
0005433961263	6913	Economy	7100.00
0005433961323	6913	Economy	7100.00
0005433961315	6913	Economy	7100.00
0005433961276	6913	Economy	7100.00
0005433961266	6913	Economy	7100.00
0005433961299	6913	Economy	7100.00
0005433961271	6913	Economy	7100.00
0005433961267	6913	Economy	7100.00
0005433961274	6913	Economy	7100.00
0005433961291	6913	Economy	7100.00
0005433961324	6913	Economy	7100.00
0005433961265	6913	Economy	7100.00
0005433961327	6913	Economy	7100.00
0005433961284	6913	Economy	7100.00
0005433961278	6913	Economy	7100.00
0005433961275	6913	Economy	7100.00
0005433961304	6913	Economy	7100.00
0005433961301	6913	Economy	7100.00
0005433961281	6913	Economy	7100.00
0005433961321	6913	Economy	7100.00
0005433961268	6913	Economy	7100.00
0005433960452	25770	Business	21400.00
0005433960343	25770	Business	21400.00
0005433960346	25770	Business	21400.00
0005433960607	25770	Business	21400.00
0005433960584	25770	Business	21400.00
0005433960390	25770	Business	21400.00
0005433960526	25770	Economy	7100.00
0005433960727	25770	Economy	7100.00
0005433960626	25770	Economy	7100.00
0005433960603	25770	Economy	7100.00
0005433960544	25770	Economy	7100.00
0005433960704	25770	Economy	7100.00
0005433960461	25770	Economy	7100.00
0005433960714	25770	Economy	7100.00
0005433960525	25770	Economy	7800.00
0005433960545	25770	Economy	7800.00
0005433960304	25770	Economy	7800.00
0005433960692	25770	Economy	7800.00
0005433960624	25770	Economy	7100.00
0005433960677	25770	Economy	7100.00
0005433960648	25770	Economy	7100.00
0005433960681	25770	Economy	7100.00
0005433960730	25770	Economy	7100.00
0005433960701	25770	Economy	7100.00
0005433960500	25770	Economy	7100.00
0005433960731	25770	Economy	7100.00
0005433960597	25770	Economy	7100.00
0005433960715	25770	Economy	7100.00
0005433960354	25770	Economy	7100.00
0005433960586	25770	Economy	7100.00
0005433960547	25770	Economy	7100.00
0005433960532	25770	Economy	7100.00
0005433960683	25770	Economy	7100.00
0005433960419	25770	Economy	7100.00
0005433960499	25770	Economy	7100.00
0005433960726	25770	Economy	7100.00
0005433960347	25770	Economy	7100.00
0005433960599	25770	Economy	7100.00
0005433960690	25770	Economy	7100.00
0005433960722	25770	Economy	7100.00
0005433960700	25770	Economy	7100.00
0005433960672	25770	Economy	7100.00
0005433960633	25770	Economy	7100.00
0005433960691	25770	Economy	7100.00
0005433960689	25770	Economy	7100.00
0005433960669	25770	Economy	7100.00
0005433960696	25770	Economy	7100.00
0005433960697	25770	Economy	7100.00
0005433960529	25770	Economy	7100.00
0005433960634	25770	Economy	7100.00
0005433960653	25770	Economy	7100.00
0005433960652	25770	Economy	7100.00
0005433960713	25770	Economy	7100.00
0005433960533	25770	Economy	7100.00
0005433960585	25770	Economy	7100.00
0005433960546	25770	Economy	7100.00
0005433960553	25770	Economy	7100.00
0005433960668	25770	Economy	7100.00
0005433960695	25770	Economy	7100.00
0005433960418	25770	Economy	7100.00
0005433960524	25770	Economy	7100.00
0005433960414	25770	Economy	7100.00
0005433960738	25770	Economy	7100.00
0005433960495	25770	Economy	7100.00
0005433960453	25770	Economy	7100.00
0005433960723	25770	Economy	7100.00
0005433960415	25770	Economy	7100.00
0005433960649	25770	Economy	7100.00
0005433960471	25770	Economy	7100.00
0005433960646	25770	Economy	7100.00
0005433960543	25770	Economy	7100.00
0005435082770	24506	Economy	3900.00
0005435082780	24506	Economy	3900.00
0005435082840	26110	Economy	3900.00
0005435082835	26110	Economy	3900.00
0005435082838	26110	Economy	3900.00
0005435082834	26110	Economy	3900.00
0005435082839	26110	Economy	3900.00
0005435082833	26110	Economy	3900.00
0005435082837	26110	Economy	3900.00
0005435082836	26110	Economy	3900.00
0005435082832	26110	Economy	3900.00
0005432166925	5087	Business	18000.00
0005434245204	5087	Business	18000.00
0005434245180	5087	Business	18000.00
0005434245196	5087	Business	18000.00
0005434245195	5087	Business	18000.00
0005434245201	5087	Business	18000.00
0005434245189	5087	Business	18000.00
0005434245207	5087	Economy	6600.00
0005434245203	5087	Economy	6000.00
0005434245198	5087	Economy	6000.00
0005434245205	5087	Economy	6000.00
0005434245191	5087	Economy	6000.00
0005434245194	5087	Economy	6000.00
0005432166924	5087	Economy	6000.00
0005432166926	5087	Economy	6000.00
0005433534499	5087	Economy	6000.00
0005434245182	5087	Economy	6000.00
0005434245200	5087	Economy	6000.00
0005435286616	5087	Economy	6000.00
0005434245181	5087	Economy	6000.00
0005434245177	5087	Economy	6600.00
0005434245186	5087	Economy	6600.00
0005434245190	5087	Economy	6000.00
0005434245187	5087	Economy	6000.00
0005435286612	5087	Economy	6000.00
0005433534491	5087	Economy	6000.00
0005434245183	5087	Economy	6000.00
0005434245197	5087	Economy	6000.00
0005434245178	5087	Economy	6000.00
0005434245193	5087	Economy	6000.00
0005434245206	5087	Economy	6000.00
0005434245179	5087	Economy	6000.00
0005434245199	5087	Economy	6000.00
0005433534498	5087	Economy	6000.00
0005434245188	5087	Economy	6000.00
0005434245192	5087	Economy	6000.00
0005434245184	5087	Economy	6000.00
0005434245185	5087	Economy	6000.00
0005434245202	5087	Economy	6000.00
0005432105900	5088	Business	18000.00
0005433615220	5088	Business	18000.00
0005432105929	5088	Business	18000.00
0005433615215	5088	Business	18000.00
0005433615254	5088	Business	18000.00
0005433785193	5088	Business	18000.00
0005433785210	5088	Business	18000.00
0005432105911	5088	Business	18000.00
0005433615217	5088	Business	18000.00
0005433615256	5088	Business	18000.00
0005433615250	5088	Business	18000.00
0005433785200	5088	Business	18000.00
0005433615212	5088	Business	18000.00
0005432105898	5088	Business	18000.00
0005432105893	5088	Business	18000.00
0005433785191	5088	Business	18000.00
0005433615198	5088	Business	18000.00
0005433615227	5088	Business	18000.00
0005433615224	5088	Business	18000.00
0005432105912	5088	Business	18000.00
0005432145126	5088	Business	18000.00
0005433615194	5088	Business	18000.00
0005433615248	5088	Business	18000.00
0005432666404	5088	Business	18000.00
0005433615186	5088	Business	18000.00
0005433615196	5088	Business	18000.00
0005433615185	5088	Business	18000.00
0005433615246	5088	Business	18000.00
0005433615213	5088	Economy	6600.00
0005433615219	5088	Economy	6600.00
0005432105916	5088	Economy	6600.00
0005433785201	5088	Economy	6600.00
0005433615189	5088	Economy	6600.00
0005432667469	5088	Economy	6600.00
0005433615244	5088	Economy	6000.00
0005432105910	5088	Economy	6000.00
0005433615231	5088	Economy	6000.00
0005433615193	5088	Economy	6000.00
0005433615188	5088	Economy	6000.00
0005432105917	5088	Economy	6000.00
0005432105887	5088	Economy	6000.00
0005432105914	5088	Economy	6000.00
0005432105915	5088	Economy	6000.00
0005432105928	5088	Economy	6000.00
0005433615208	5088	Economy	6000.00
0005433785207	5088	Economy	6000.00
0005433615202	5088	Economy	6000.00
0005433615206	5088	Economy	6000.00
0005433785196	5088	Economy	6000.00
0005432105888	5088	Economy	6000.00
0005432105897	5088	Economy	6000.00
0005433615245	5088	Economy	6000.00
0005433785220	5088	Economy	6000.00
0005433615184	5088	Economy	6000.00
0005433615243	5088	Economy	6000.00
0005432105923	5088	Economy	6000.00
0005433785203	5088	Economy	6000.00
0005433615232	5088	Economy	6000.00
0005433615209	5088	Economy	6000.00
0005432145125	5088	Economy	6000.00
0005433785192	5088	Economy	6000.00
0005432105894	5088	Economy	6000.00
0005432105926	5088	Economy	6000.00
0005433785205	5088	Economy	6000.00
0005432105903	5088	Economy	6000.00
0005433785218	5088	Economy	6000.00
0005432105920	5088	Economy	6000.00
0005433615257	5088	Economy	6000.00
0005433615236	5088	Economy	6000.00
0005432105906	5088	Economy	6000.00
0005432105922	5088	Economy	6000.00
0005432105896	5088	Economy	6000.00
0005432105891	5088	Economy	6000.00
0005433785194	5088	Economy	6000.00
0005432105901	5088	Economy	6000.00
0005433615240	5088	Economy	6000.00
0005433785222	5088	Economy	6000.00
0005433615203	5088	Economy	6000.00
0005433615195	5088	Economy	6000.00
0005433615183	5088	Economy	6000.00
0005433615235	5088	Economy	6000.00
0005432105930	5088	Economy	6000.00
0005432105932	5088	Economy	6000.00
0005433785219	5088	Economy	6000.00
0005432665289	5088	Economy	6000.00
0005432105918	5088	Economy	6000.00
0005432105934	5088	Economy	6000.00
0005433615211	5088	Economy	6000.00
0005432105907	5088	Economy	6000.00
0005432105886	5088	Economy	6000.00
0005433615201	5088	Economy	6000.00
0005433615214	5088	Economy	6000.00
0005432105895	5088	Economy	6000.00
0005433615210	5088	Economy	6000.00
0005433615233	5088	Economy	6600.00
0005433785199	5088	Economy	6600.00
0005432105933	5088	Economy	6600.00
0005433785221	5088	Economy	6600.00
0005432105919	5088	Economy	6600.00
0005432105909	5088	Economy	6000.00
0005433785215	5088	Economy	6000.00
0005433615191	5088	Economy	6000.00
0005432105927	5088	Economy	6000.00
0005432105925	5088	Economy	6600.00
0005432105924	5088	Economy	6000.00
0005433785206	5088	Economy	6000.00
0005433615205	5088	Economy	6000.00
0005433615234	5088	Economy	6000.00
0005433615199	5088	Economy	6000.00
0005433615218	5088	Economy	6000.00
0005433615259	5088	Economy	6000.00
0005433785209	5088	Economy	6000.00
0005433615252	5088	Economy	6000.00
0005433615226	5088	Economy	6000.00
0005433615225	5088	Economy	6000.00
0005432105921	5088	Economy	6000.00
0005433785216	5088	Economy	6000.00
0005432105931	5088	Economy	6000.00
0005433615197	5088	Economy	6000.00
0005433785189	5088	Economy	6000.00
0005433785214	5088	Economy	6000.00
0005432105892	5088	Economy	6000.00
0005432105908	5088	Economy	6000.00
0005432105902	5088	Economy	6000.00
0005432105890	5088	Economy	6000.00
0005433615190	5088	Economy	6000.00
0005433615249	5088	Economy	6000.00
0005433615222	5088	Economy	6000.00
0005432666403	5088	Economy	6000.00
0005433615200	5088	Economy	6000.00
0005432105913	5088	Economy	6000.00
0005433785204	5088	Economy	6000.00
0005433615241	5088	Economy	6000.00
0005433615247	5088	Economy	6000.00
0005433785198	5088	Economy	6000.00
0005433615216	5088	Economy	6000.00
0005433615221	5088	Economy	6000.00
0005433615204	5088	Economy	6000.00
0005432665288	5088	Economy	6000.00
0005433785202	5088	Economy	6000.00
0005433615230	5088	Economy	6000.00
0005433615239	5088	Economy	6000.00
0005432667470	5088	Economy	6000.00
0005433785217	5088	Economy	6000.00
0005433615255	5088	Economy	6000.00
0005433785197	5088	Economy	6000.00
0005432105904	5088	Economy	6000.00
0005432665290	5088	Economy	6000.00
0005433615187	5088	Economy	6000.00
0005433615229	5088	Economy	6000.00
0005433785213	5088	Economy	6000.00
0005433785212	5088	Economy	6000.00
0005432105899	5088	Economy	6000.00
0005432105889	5088	Economy	6000.00
0005433785211	5088	Economy	6000.00
0005433615242	5088	Economy	6000.00
0005433615258	5088	Economy	6000.00
0005433615237	5088	Economy	6000.00
0005433615253	5088	Economy	6000.00
0005433785195	5088	Economy	6000.00
0005433615251	5088	Economy	6000.00
0005432105905	5088	Economy	6000.00
0005433615223	5088	Economy	6000.00
0005433785188	5088	Economy	6000.00
0005433785190	5088	Economy	6000.00
0005433615192	5088	Economy	6000.00
0005433615207	5088	Economy	6000.00
0005433615238	5088	Economy	6000.00
0005433615228	5088	Economy	6000.00
0005433785208	5088	Economy	6000.00
0005434265327	5090	Business	18000.00
0005434149812	5090	Business	18000.00
0005435269728	5090	Business	18000.00
0005434229527	5090	Business	18000.00
0005434149816	5090	Business	18000.00
0005432335992	5090	Business	18000.00
0005434229534	5090	Business	18000.00
0005434265323	5090	Business	18000.00
0005435007022	5090	Business	18000.00
0005434149820	5090	Business	18000.00
0005434229540	5090	Business	18000.00
0005435007075	5090	Business	18000.00
0005435007084	5090	Business	18000.00
0005435007036	5090	Business	18000.00
0005432336018	5090	Business	18000.00
0005434229530	5090	Business	18000.00
0005434265325	5090	Business	18000.00
0005434265322	5090	Business	18000.00
0005434311204	5090	Business	18000.00
0005435007020	5090	Economy	6600.00
0005434265316	5090	Economy	6600.00
0005434265330	5090	Economy	6600.00
0005434265314	5090	Economy	6600.00
0005434149817	5090	Economy	6000.00
0005434265329	5090	Economy	6000.00
0005434173550	5090	Economy	6000.00
0005434265317	5090	Economy	6000.00
0005435269743	5090	Economy	6000.00
0005434265332	5090	Economy	6000.00
0005434265312	5090	Economy	6000.00
0005432336021	5090	Economy	6000.00
0005435006932	5090	Economy	6000.00
0005434265331	5090	Economy	6000.00
0005434265326	5090	Economy	6000.00
0005432336006	5090	Economy	6000.00
0005435006881	5090	Economy	6000.00
0005434229535	5090	Economy	6000.00
0005434229543	5090	Economy	6000.00
0005435007076	5090	Economy	6000.00
0005434265310	5090	Economy	6000.00
0005434265313	5090	Economy	6000.00
0005435006927	5090	Economy	6000.00
0005434229542	5090	Economy	6000.00
0005433685513	5090	Economy	6000.00
0005434229526	5090	Economy	6000.00
0005434311212	5090	Economy	6000.00
0005435007067	5090	Economy	6000.00
0005435007011	5090	Economy	6000.00
0005434229521	5090	Economy	6000.00
0005435006973	5090	Economy	6000.00
0005432335965	5090	Economy	6000.00
0005432336016	5090	Economy	6000.00
0005434265333	5090	Economy	6000.00
0005435269729	5090	Economy	6000.00
0005434229532	5090	Economy	6000.00
0005433685512	5090	Economy	6000.00
0005434265321	5090	Economy	6000.00
0005435007009	5090	Economy	6000.00
0005435006962	5090	Economy	6000.00
0005435006928	5090	Economy	6000.00
0005434311205	5090	Economy	6000.00
0005433685514	5090	Economy	6000.00
0005434265311	5090	Economy	6000.00
0005434229544	5090	Economy	6000.00
0005434229528	5090	Economy	6000.00
0005434229537	5090	Economy	6600.00
0005435007066	5090	Economy	6600.00
0005435006914	5090	Economy	6600.00
0005434229524	5090	Economy	6600.00
0005434265319	5090	Economy	6000.00
0005434149815	5090	Economy	6000.00
0005434229523	5090	Economy	6000.00
0005435006915	5090	Economy	6600.00
0005433815381	5090	Economy	6000.00
0005435007004	5090	Economy	6000.00
0005435007019	5090	Economy	6000.00
0005435006944	5090	Economy	6000.00
0005432336049	5090	Economy	6000.00
0005434173547	5090	Economy	6000.00
0005434265334	5090	Economy	6000.00
0005434229525	5090	Economy	6000.00
0005433685516	5090	Economy	6000.00
0005434265324	5090	Economy	6000.00
0005434229541	5090	Economy	6000.00
0005435269733	5090	Economy	6000.00
0005434265328	5090	Economy	6000.00
0005435007010	5090	Economy	6000.00
0005434149811	5090	Economy	6000.00
0005432335993	5090	Economy	6000.00
0005435006848	5090	Economy	6000.00
0005434149819	5090	Economy	6000.00
0005434173548	5090	Economy	6000.00
0005432336050	5090	Economy	6000.00
0005434229538	5090	Economy	6000.00
0005434229536	5090	Economy	6000.00
0005432335995	5090	Economy	6000.00
0005434229529	5090	Economy	6000.00
0005434229533	5090	Economy	6000.00
0005434229539	5090	Economy	6000.00
0005435006882	5090	Economy	6000.00
0005434149821	5090	Economy	6000.00
0005435006931	5090	Economy	6000.00
0005435006954	5090	Economy	6000.00
0005432335991	5090	Economy	6000.00
0005433815382	5090	Economy	6000.00
0005434229522	5090	Economy	6000.00
0005434265335	5090	Economy	6000.00
0005434229531	5090	Economy	6000.00
0005434265336	5090	Economy	6000.00
0005434173551	5090	Economy	6000.00
0005434149809	5090	Economy	6000.00
0005434265315	5090	Economy	6000.00
0005432336017	5090	Economy	6000.00
0005434265320	5090	Economy	6000.00
0005432336011	5090	Economy	6000.00
0005434149814	5090	Economy	6000.00
0005434265318	5090	Economy	6000.00
0005434149818	5090	Economy	6000.00
0005434149810	5090	Economy	6000.00
0005433685515	5090	Economy	6000.00
0005434149813	5090	Economy	6000.00
0005434173549	5090	Economy	6000.00
0005433785027	8580	Business	18000.00
0005433784782	8580	Business	18000.00
0005435269791	8580	Business	18000.00
0005434244880	8580	Business	18000.00
0005435269788	8580	Business	18000.00
0005433784781	8580	Business	18000.00
0005433784862	8580	Business	18000.00
0005434244958	8580	Business	18000.00
0005433784875	8580	Business	18000.00
0005434244998	8580	Business	18000.00
0005433784879	8580	Business	18000.00
0005434244842	8580	Business	18000.00
0005433784830	8580	Business	18000.00
0005434244956	8580	Business	18000.00
0005433784973	8580	Business	18000.00
0005434244982	8580	Business	18000.00
0005433784928	8580	Economy	6600.00
0005435269794	8580	Economy	6600.00
0005434244832	8580	Economy	6600.00
0005432659695	8580	Economy	6600.00
0005434244858	8580	Economy	6000.00
0005434244971	8580	Economy	6000.00
0005434244818	8580	Economy	6000.00
0005432659696	8580	Economy	6000.00
0005433784795	8580	Economy	6000.00
0005434244957	8580	Economy	6000.00
0005433784806	8580	Economy	6000.00
0005433784911	8580	Economy	6000.00
0005435269786	8580	Economy	6000.00
0005435269795	8580	Economy	6000.00
0005433784937	8580	Economy	6000.00
0005434244911	8580	Economy	6000.00
0005434244889	8580	Economy	6000.00
0005433784905	8580	Economy	6000.00
0005432659706	8580	Economy	6000.00
0005434244970	8580	Economy	6000.00
0005435269790	8580	Economy	6000.00
0005435269793	8580	Economy	6000.00
0005433784944	8580	Economy	6000.00
0005433785026	8580	Economy	6000.00
0005434244912	8580	Economy	6000.00
0005434244864	8580	Economy	6000.00
0005434244877	8580	Economy	6000.00
0005434244859	8580	Economy	6000.00
0005432666380	8580	Economy	6000.00
0005433785002	8580	Economy	6000.00
0005435269792	8580	Economy	6000.00
0005433784917	8580	Economy	6000.00
0005433784927	8580	Economy	6600.00
0005434244887	8580	Economy	6600.00
0005433784846	8580	Economy	6000.00
0005432659705	8580	Economy	6000.00
0005433785003	8580	Economy	6000.00
0005434244921	8580	Economy	6000.00
0005433784936	8580	Economy	6000.00
0005433784720	8580	Economy	6000.00
0005433784845	8580	Economy	6000.00
0005433784888	8580	Economy	6000.00
0005433784880	8580	Economy	6000.00
0005433784796	8580	Economy	6000.00
0005434244959	8580	Economy	6000.00
0005434244831	8580	Economy	6000.00
0005433784797	8580	Economy	6000.00
0005433784977	8580	Economy	6000.00
0005433784970	8580	Economy	6000.00
0005433784747	8580	Economy	6000.00
0005434244920	8580	Economy	6000.00
0005435269787	8580	Economy	6000.00
0005434244997	8580	Economy	6000.00
0005434244914	8580	Economy	6000.00
0005433784844	8580	Economy	6000.00
0005434244850	8580	Economy	6000.00
0005435269789	8580	Economy	6000.00
0005433784920	8580	Economy	6000.00
0005434244888	8580	Economy	6000.00
0005433784955	8580	Economy	6000.00
0005433784900	8580	Economy	6000.00
0005433784935	8580	Economy	6000.00
0005433784813	8580	Economy	6000.00
0005433784916	8580	Economy	6000.00
0005433784746	8580	Economy	6000.00
0005433614351	8581	Business	18000.00
0005433614206	8581	Business	18000.00
0005433614543	8581	Business	18000.00
0005433614438	8581	Business	18000.00
0005433614601	8581	Business	18000.00
0005433614547	8581	Business	18000.00
0005433614500	8581	Business	18000.00
0005433614048	8581	Business	18000.00
0005433614047	8581	Business	18000.00
0005433614447	8581	Business	18000.00
0005433614300	8581	Economy	6600.00
0005433614157	8581	Economy	6600.00
0005433614290	8581	Economy	6600.00
0005433614604	8581	Economy	6600.00
0005433614430	8581	Economy	6000.00
0005433614826	8581	Economy	6000.00
0005433614230	8581	Economy	6000.00
0005433614422	8581	Economy	6000.00
0005433614722	8581	Economy	6000.00
0005433614507	8581	Economy	6000.00
0005433614551	8581	Economy	6000.00
0005433614753	8581	Economy	6000.00
0005433614481	8581	Economy	6000.00
0005433614693	8581	Economy	6000.00
0005433614694	8581	Economy	6000.00
0005433614508	8581	Economy	6000.00
0005433614643	8581	Economy	6000.00
0005433614229	8581	Economy	6000.00
0005433614602	8581	Economy	6000.00
0005433614376	8581	Economy	6000.00
0005433614329	8581	Economy	6000.00
0005433614449	8581	Economy	6000.00
0005433614505	8581	Economy	6000.00
0005433614364	8581	Economy	6000.00
0005433614448	8581	Economy	6000.00
0005433614776	8581	Economy	6000.00
0005433614544	8581	Economy	6600.00
0005433614377	8581	Economy	6600.00
0005433614512	8581	Economy	6600.00
0005433614666	8581	Economy	6000.00
0005433614405	8581	Economy	6000.00
0005433614665	8581	Economy	6000.00
0005433614667	8581	Economy	6000.00
0005433614482	8581	Economy	6000.00
0005433614581	8581	Economy	6000.00
0005433614510	8581	Economy	6000.00
0005433614754	8581	Economy	6000.00
0005433614409	8581	Economy	6000.00
0005433614164	8581	Economy	6000.00
0005433614192	8581	Economy	6000.00
0005433614365	8581	Economy	6000.00
0005433614692	8581	Economy	6000.00
0005433614371	8581	Economy	6000.00
0005433614156	8581	Economy	6000.00
0005433614723	8581	Economy	6000.00
0005433614213	8581	Economy	6000.00
0005433614151	8581	Economy	6000.00
0005433614719	8581	Economy	6000.00
0005433614408	8581	Economy	6000.00
0005433614313	8581	Economy	6000.00
0005433614686	8581	Economy	6000.00
0005433614437	8581	Economy	6000.00
0005433614537	8581	Economy	6000.00
0005433614575	8581	Economy	6000.00
0005433614931	8581	Economy	6000.00
0005433614334	8581	Economy	6000.00
0005433614568	8581	Economy	6000.00
0005433614705	8581	Economy	6000.00
0005433614548	8581	Economy	6000.00
0005435007182	8582	Business	18000.00
0005432035151	8582	Business	18000.00
0005433688826	8582	Business	18000.00
0005434229267	8582	Business	18000.00
0005434149747	8582	Business	18000.00
0005432035150	8582	Business	18000.00
0005434229399	8582	Business	18000.00
0005432336121	8582	Business	18000.00
0005434149715	8582	Business	18000.00
0005432035144	8582	Business	18000.00
0005433534513	8582	Business	18000.00
0005435007187	8582	Business	18000.00
0005433689927	8582	Business	18000.00
0005435007199	8582	Business	18000.00
0005434229400	8582	Business	18000.00
0005435007186	8582	Business	18000.00
0005434229357	8582	Business	18000.00
0005434229358	8582	Business	18000.00
0005435007194	8582	Business	18000.00
0005433688824	8582	Business	18000.00
0005432336122	8582	Business	18000.00
0005434149644	8582	Business	18000.00
0005434265173	8582	Business	18000.00
0005434265172	8582	Business	18000.00
0005432035156	8582	Business	18000.00
0005432336118	8582	Business	18000.00
0005434311235	8582	Economy	6600.00
0005434265101	8582	Economy	6600.00
0005434229329	8582	Economy	6600.00
0005432336115	8582	Economy	6600.00
0005433815422	8582	Economy	6600.00
0005434265231	8582	Economy	6600.00
0005432336117	8582	Economy	6000.00
0005432035133	8582	Economy	6000.00
0005434173522	8582	Economy	6000.00
0005434229351	8582	Economy	6000.00
0005432336119	8582	Economy	6000.00
0005435007183	8582	Economy	6000.00
0005435007198	8582	Economy	6000.00
0005435007201	8582	Economy	6000.00
0005433689925	8582	Economy	6000.00
0005435007195	8582	Economy	6000.00
0005434173512	8582	Economy	6000.00
0005433689926	8582	Economy	6000.00
0005434229313	8582	Economy	6000.00
0005434265162	8582	Economy	6000.00
0005432035159	8582	Economy	6000.00
0005434149674	8582	Economy	6000.00
0005432336123	8582	Economy	6000.00
0005435007181	8582	Economy	6000.00
0005435007197	8582	Economy	6000.00
0005434149700	8582	Economy	6000.00
0005434229315	8582	Economy	6000.00
0005432035158	8582	Economy	6000.00
0005434149739	8582	Economy	6000.00
0005434229306	8582	Economy	6000.00
0005432035138	8582	Economy	6000.00
0005434149741	8582	Economy	6000.00
0005432035155	8582	Economy	6000.00
0005432035148	8582	Economy	6000.00
0005432035143	8582	Economy	6000.00
0005434173499	8582	Economy	6000.00
0005434265143	8582	Economy	6000.00
0005432035153	8582	Economy	6000.00
0005433815421	8582	Economy	6000.00
0005432035142	8582	Economy	6000.00
0005432035145	8582	Economy	6000.00
0005435007185	8582	Economy	6000.00
0005435286661	8582	Economy	6000.00
0005432035136	8582	Economy	6000.00
0005434229271	8582	Economy	6000.00
0005434311236	8582	Economy	6000.00
0005434229372	8582	Economy	6000.00
0005433534514	8582	Economy	6000.00
0005432035141	8582	Economy	6000.00
0005434229275	8582	Economy	6000.00
0005435007188	8582	Economy	6000.00
0005434229314	8582	Economy	6000.00
0005434265098	8582	Economy	6000.00
0005435007192	8582	Economy	6000.00
0005434229266	8582	Economy	6000.00
0005432035140	8582	Economy	6000.00
0005434265230	8582	Economy	6000.00
0005434265030	8582	Economy	6000.00
0005435007200	8582	Economy	6000.00
0005434229217	8582	Economy	6000.00
0005434173486	8582	Economy	6000.00
0005433815420	8582	Economy	6600.00
0005435007178	8582	Economy	6600.00
0005432047578	8582	Economy	6600.00
0005434229352	8582	Economy	6600.00
0005432035134	8582	Economy	6600.00
0005432035160	8582	Economy	6000.00
0005434229334	8582	Economy	6000.00
0005435007193	8582	Economy	6000.00
0005434265097	8582	Economy	6600.00
0005435286660	8582	Economy	6000.00
0005432035137	8582	Economy	6000.00
0005434173523	8582	Economy	6000.00
0005434173487	8582	Economy	6000.00
0005435007191	8582	Economy	6000.00
0005433688825	8582	Economy	6000.00
0005432035149	8582	Economy	6000.00
0005434265157	8582	Economy	6000.00
0005432035139	8582	Economy	6000.00
0005433690940	8582	Economy	6000.00
0005432035135	8582	Economy	6000.00
0005434229353	8582	Economy	6000.00
0005432336116	8582	Economy	6000.00
0005434265134	8582	Economy	6000.00
0005432035146	8582	Economy	6000.00
0005432035154	8582	Economy	6000.00
0005434229299	8582	Economy	6000.00
0005434265100	8582	Economy	6000.00
0005435007196	8582	Economy	6000.00
0005434229365	8582	Economy	6000.00
0005434229337	8582	Economy	6000.00
0005432035157	8582	Economy	6000.00
0005434173496	8582	Economy	6000.00
0005434229398	8582	Economy	6000.00
0005434229392	8582	Economy	6000.00
0005435007179	8582	Economy	6000.00
0005434149742	8582	Economy	6000.00
0005434149728	8582	Economy	6000.00
0005434173517	8582	Economy	6000.00
0005435007190	8582	Economy	6000.00
0005434265140	8582	Economy	6000.00
0005433690939	8582	Economy	6000.00
0005433815424	8582	Economy	6000.00
0005434229338	8582	Economy	6000.00
0005432035152	8582	Economy	6000.00
0005432035147	8582	Economy	6000.00
0005434149697	8582	Economy	6000.00
0005432336120	8582	Economy	6000.00
0005434265096	8582	Economy	6000.00
0005435007180	8582	Economy	6000.00
0005434149729	8582	Economy	6000.00
0005434265070	8582	Economy	6000.00
0005432336126	8582	Economy	6000.00
0005432047577	8582	Economy	6000.00
0005434265176	8582	Economy	6000.00
0005434265147	8582	Economy	6000.00
0005434264968	8582	Economy	6000.00
0005432047576	8582	Economy	6000.00
0005434229328	8582	Economy	6000.00
0005435007184	8582	Economy	6000.00
0005434173497	8582	Economy	6000.00
0005434149746	8582	Economy	6000.00
0005434311234	8582	Economy	6000.00
0005434229430	8582	Economy	6000.00
0005432336124	8582	Economy	6000.00
0005432336125	8582	Economy	6000.00
0005434229270	8582	Economy	6000.00
0005434265146	8582	Economy	6000.00
0005435007189	8582	Economy	6000.00
0005433815423	8582	Economy	6000.00
0005434265232	8582	Economy	6000.00
0005433202467	12591	Economy	16200.00
0005434639288	12591	Economy	16200.00
0005434639131	12591	Economy	16200.00
0005434639218	12591	Economy	14800.00
0005433202469	12591	Economy	14800.00
0005433202474	12591	Economy	14800.00
0005433202471	12591	Economy	14800.00
0005433202464	12591	Economy	14800.00
0005434639308	12591	Economy	14800.00
0005434639158	12591	Economy	14800.00
0005434639307	12591	Economy	14800.00
0005433202465	12591	Economy	14800.00
0005434639248	12591	Economy	14800.00
0005433202466	12591	Economy	14800.00
0005433202472	12591	Economy	14800.00
0005433202477	12591	Economy	14800.00
0005434639232	12591	Economy	14800.00
0005433202470	12591	Economy	14800.00
0005434639289	12591	Economy	14800.00
0005434639236	12591	Economy	14800.00
0005434639246	12591	Economy	14800.00
0005434639247	12591	Economy	14800.00
0005433202468	12591	Economy	14800.00
0005434639159	12591	Economy	14800.00
0005433202478	12591	Economy	14800.00
0005434639166	12591	Economy	14800.00
0005433202473	12591	Economy	14800.00
0005433202476	12591	Economy	14800.00
0005434639132	12591	Economy	14800.00
0005434639258	12591	Economy	14800.00
0005433202475	12591	Economy	14800.00
0005434639157	12591	Economy	14800.00
0005434639495	23399	Economy	16200.00
0005433202305	23399	Economy	16200.00
0005434639481	23399	Economy	16200.00
0005433202353	23399	Economy	16200.00
0005434639487	23399	Economy	14800.00
0005433202304	23399	Economy	14800.00
0005434639493	23399	Economy	14800.00
0005433202380	23399	Economy	14800.00
0005434639497	23399	Economy	14800.00
0005432290653	23399	Economy	14800.00
0005433202388	23399	Economy	14800.00
0005433202381	23399	Economy	14800.00
0005433202363	23399	Economy	14800.00
0005433202367	23399	Economy	14800.00
0005433202396	23399	Economy	14800.00
0005434639483	23399	Economy	14800.00
0005434639496	23399	Economy	14800.00
0005433202333	23399	Economy	14800.00
0005433202314	23399	Economy	14800.00
0005432290651	23399	Economy	14800.00
0005434639479	23399	Economy	14800.00
0005433202284	23399	Economy	14800.00
0005434639478	23399	Economy	14800.00
0005434639477	23399	Economy	14800.00
0005432290652	23399	Economy	14800.00
0005433202258	23399	Economy	14800.00
0005434639482	23399	Economy	14800.00
0005434639486	23399	Economy	14800.00
0005433202362	23399	Economy	14800.00
0005434639498	23399	Economy	14800.00
0005433202339	23399	Economy	14800.00
0005433202364	23399	Economy	14800.00
0005434639494	23399	Economy	14800.00
0005434639491	23399	Economy	14800.00
0005434639485	23399	Economy	14800.00
0005434639490	23399	Economy	14800.00
0005433202397	23399	Economy	14800.00
0005433202387	23399	Economy	14800.00
0005433202382	23399	Economy	14800.00
0005434639492	23399	Economy	14800.00
0005433202352	23399	Economy	14800.00
0005434639488	23399	Economy	14800.00
0005434639480	23399	Economy	14800.00
0005433202315	23399	Economy	14800.00
0005434639489	23399	Economy	14800.00
0005434639484	23399	Economy	14800.00
0005433202379	23399	Economy	14800.00
0005432328471	21106	Business	18900.00
0005432383069	21106	Business	18900.00
0005432383224	21106	Business	18900.00
0005432383103	21106	Business	18900.00
0005432328327	21106	Business	18900.00
0005432383213	21106	Business	18900.00
0005432383070	21106	Business	18900.00
0005432054327	21106	Business	18900.00
0005432383071	21106	Business	18900.00
0005432328505	21106	Business	18900.00
0005432328646	21106	Business	18900.00
0005432328470	21106	Economy	6300.00
0005432328475	21106	Economy	6300.00
0005432383128	21106	Economy	6300.00
0005432328506	21106	Economy	6300.00
0005432328494	21106	Economy	6300.00
0005432328623	21106	Economy	6300.00
0005432328826	21106	Economy	6300.00
0005432383125	21106	Economy	6300.00
0005432383102	21106	Economy	6300.00
0005432383194	21106	Economy	6900.00
0005432328806	21106	Economy	6900.00
0005432383003	21106	Economy	6900.00
0005432383180	21106	Economy	6900.00
0005432054326	21106	Economy	6300.00
0005432328733	21106	Economy	6300.00
0005432383245	21106	Economy	6300.00
0005432383059	21106	Economy	6300.00
0005432383223	21106	Economy	6300.00
0005432383034	21106	Economy	6300.00
0005432328688	21106	Economy	6300.00
0005432328592	21106	Economy	6300.00
0005432328754	21106	Economy	6300.00
0005432383062	21106	Economy	6300.00
0005432328567	21106	Economy	6300.00
0005432328752	21106	Economy	6300.00
0005432383127	21106	Economy	6300.00
0005432383104	21106	Economy	6300.00
0005432328510	21106	Economy	6300.00
0005432328690	21106	Economy	6300.00
0005432328727	21106	Economy	6300.00
0005432328820	21106	Economy	6300.00
0005432328599	21106	Economy	6300.00
0005432383186	21106	Economy	6300.00
0005432328366	21106	Economy	6300.00
0005432382928	21106	Economy	6300.00
0005432382944	21106	Economy	6300.00
0005432328605	21106	Economy	6300.00
0005432328362	21106	Economy	6300.00
0005432328827	21106	Economy	6300.00
0005432382979	21106	Economy	6300.00
0005432383105	21106	Economy	6300.00
0005432328753	21106	Economy	6300.00
0005432328595	21106	Economy	6300.00
0005432383089	21106	Economy	6300.00
0005432328598	21106	Economy	6300.00
0005432383012	21106	Economy	6300.00
0005432328643	21106	Economy	6300.00
0005432383199	21106	Economy	6300.00
0005432328626	21106	Economy	6300.00
0005432328828	21106	Economy	6300.00
0005432383077	21106	Economy	6300.00
0005432383058	21106	Economy	6300.00
0005432383110	21106	Economy	6300.00
0005432383050	21106	Economy	6300.00
0005432328645	21106	Economy	6300.00
0005432328612	21106	Economy	6300.00
0005432383159	21106	Economy	6300.00
0005432328511	21106	Economy	6300.00
0005432383057	21106	Economy	6300.00
0005432383185	21106	Economy	6300.00
0005432383130	21106	Economy	6300.00
0005432383126	21106	Economy	6300.00
0005432328542	21106	Economy	6300.00
0005432383061	21106	Economy	6300.00
0005432328449	21106	Economy	6300.00
0005432328450	21106	Economy	6300.00
0005432383222	21106	Economy	6300.00
0005432383111	21106	Economy	6300.00
0005432328650	21106	Economy	6300.00
0005432328326	21106	Economy	6300.00
0005432328676	21106	Economy	6300.00
0005432329006	31228	Business	18900.00
0005432328976	31228	Business	18900.00
0005432383427	31228	Business	18900.00
0005432328999	31228	Business	18900.00
0005432383417	31228	Business	18900.00
0005432287224	31228	Business	18900.00
0005432383428	31228	Business	18900.00
0005432383434	31228	Business	18900.00
0005432287225	31228	Business	18900.00
0005432329017	31228	Business	18900.00
0005432287220	31228	Business	18900.00
0005432329010	31228	Economy	6300.00
0005432383410	31228	Economy	6300.00
0005432328995	31228	Economy	6300.00
0005432287222	31228	Economy	6300.00
0005432383418	31228	Economy	6300.00
0005432329008	31228	Economy	6300.00
0005432328994	31228	Economy	6300.00
0005432328979	31228	Economy	6300.00
0005432329009	31228	Economy	6300.00
0005432383422	31228	Economy	6300.00
0005432383402	31228	Economy	6900.00
0005432328982	31228	Economy	6900.00
0005432383414	31228	Economy	6900.00
0005432328978	31228	Economy	6900.00
0005432328991	31228	Economy	6900.00
0005432329016	31228	Economy	6300.00
0005432383424	31228	Economy	6300.00
0005432383435	31228	Economy	6300.00
0005432287219	31228	Economy	6300.00
0005432329003	31228	Economy	6300.00
0005432383406	31228	Economy	6300.00
0005432383419	31228	Economy	6300.00
0005432329004	31228	Economy	6300.00
0005432329000	31228	Economy	6300.00
0005432383412	31228	Economy	6300.00
0005432328972	31228	Economy	6300.00
0005432329013	31228	Economy	6300.00
0005432328996	31228	Economy	6300.00
0005432383437	31228	Economy	6300.00
0005432328973	31228	Economy	6300.00
0005432329012	31228	Economy	6300.00
0005432328992	31228	Economy	6300.00
0005432328986	31228	Economy	6300.00
0005432383425	31228	Economy	6300.00
0005432383441	31228	Economy	6300.00
0005432383439	31228	Economy	6300.00
0005432328971	31228	Economy	6300.00
0005432383433	31228	Economy	6300.00
0005432383440	31228	Economy	6300.00
0005432328993	31228	Economy	6300.00
0005432328997	31228	Economy	6300.00
0005432287221	31228	Economy	6300.00
0005432383436	31228	Economy	6300.00
0005432383416	31228	Economy	6300.00
0005432328984	31228	Economy	6300.00
0005432329001	31228	Economy	6300.00
0005432328988	31228	Economy	6300.00
0005432328985	31228	Economy	6300.00
0005432328975	31228	Economy	6300.00
0005432383431	31228	Economy	6300.00
0005432328981	31228	Economy	6300.00
0005432383438	31228	Economy	6300.00
0005432328974	31228	Economy	6300.00
0005432383421	31228	Economy	6300.00
0005432383413	31228	Economy	6300.00
0005432287223	31228	Economy	6300.00
0005432329007	31228	Economy	6300.00
0005432328987	31228	Economy	6300.00
0005432383409	31228	Economy	6300.00
0005432383408	31228	Economy	6300.00
0005432383426	31228	Economy	6300.00
0005432383404	31228	Economy	6300.00
0005432383430	31228	Economy	6300.00
0005432328998	31228	Economy	6300.00
0005432329014	31228	Economy	6300.00
0005432383407	31228	Economy	6300.00
0005432383411	31228	Economy	6300.00
0005432328977	31228	Economy	6300.00
0005432328989	31228	Economy	6300.00
0005432383403	31228	Economy	6300.00
0005432383432	31228	Economy	6300.00
0005432328983	31228	Economy	6300.00
0005432383429	31228	Economy	6300.00
0005432329011	31228	Economy	6300.00
0005432329015	31228	Economy	6300.00
0005432328980	31228	Economy	6300.00
0005432383423	31228	Economy	6300.00
0005432383415	31228	Economy	6300.00
0005432329005	31228	Economy	6300.00
0005432328990	31228	Economy	6300.00
0005432383442	31228	Economy	6300.00
0005432383420	31228	Economy	6300.00
0005432383405	31228	Economy	6300.00
0005432329002	31228	Economy	6300.00
0005432383443	31228	Economy	6300.00
0005432424771	13358	Business	12700.00
0005432424743	13358	Business	12700.00
0005432424751	13358	Business	12700.00
0005432424766	13358	Business	12700.00
0005432424732	13358	Business	12700.00
0005432424750	13358	Business	12700.00
0005432424720	13358	Business	12700.00
0005432424759	13358	Business	12700.00
0005432424725	13358	Business	12700.00
0005432424772	13358	Economy	4200.00
0005432424722	13358	Economy	4200.00
0005432424769	13358	Economy	4200.00
0005432424757	13358	Economy	4200.00
0005432424738	13358	Economy	4200.00
0005432424767	13358	Economy	4200.00
0005432424770	13358	Economy	4200.00
0005432424742	13358	Economy	4700.00
0005432424768	13358	Economy	4700.00
0005432424718	13358	Economy	4200.00
0005432424749	13358	Economy	4200.00
0005432424740	13358	Economy	4200.00
0005432424731	13358	Economy	4200.00
0005432424760	13358	Economy	4200.00
0005432424726	13358	Economy	4200.00
0005432424753	13358	Economy	4200.00
0005432424746	13358	Economy	4200.00
0005432424734	13358	Economy	4200.00
0005432424752	13358	Economy	4200.00
0005432424763	13358	Economy	4200.00
0005432424739	13358	Economy	4200.00
0005432424745	13358	Economy	4200.00
0005432424748	13358	Economy	4200.00
0005432424765	13358	Economy	4200.00
0005432424716	13358	Economy	4200.00
0005432424775	13358	Economy	4200.00
0005432424774	13358	Economy	4200.00
0005432424755	13358	Economy	4200.00
0005432424758	13358	Economy	4200.00
0005432424764	13358	Economy	4200.00
0005432424747	13358	Economy	4200.00
0005432424741	13358	Economy	4200.00
0005432424754	13358	Economy	4200.00
0005432424744	13358	Economy	4200.00
0005432424728	13358	Economy	4200.00
0005432424721	13358	Economy	4200.00
0005432424719	13358	Economy	4200.00
0005432424724	13358	Economy	4200.00
0005432424762	13358	Economy	4200.00
0005432424756	13358	Economy	4200.00
0005432424723	13358	Economy	4200.00
0005432424773	13358	Economy	4200.00
0005432424717	13358	Economy	4200.00
0005432424737	13358	Economy	4200.00
0005432424727	13358	Economy	4200.00
0005432424715	13358	Economy	4200.00
0005432424730	13358	Economy	4200.00
0005432424735	13358	Economy	4200.00
0005432424729	13358	Economy	4200.00
0005432424733	13358	Economy	4200.00
0005432424736	13358	Economy	4200.00
0005432424761	13358	Economy	4200.00
0005432424330	30732	Business	12700.00
0005432424272	30732	Business	12700.00
0005432424350	30732	Business	12700.00
0005432424354	30732	Business	12700.00
0005432424240	30732	Business	12700.00
0005432424268	30732	Economy	4200.00
0005432424291	30732	Economy	4200.00
0005432424382	30732	Economy	4200.00
0005432424352	30732	Economy	4700.00
0005432424247	30732	Economy	4700.00
0005432424151	30732	Economy	4700.00
0005432424343	30732	Economy	4200.00
0005432424297	30732	Economy	4200.00
0005432424360	30732	Economy	4200.00
0005432424351	30732	Economy	4200.00
0005432424334	30732	Economy	4200.00
0005432424243	30732	Economy	4200.00
0005432424370	30732	Economy	4200.00
0005432424227	30732	Economy	4200.00
0005432424284	30732	Economy	4200.00
0005432424150	30732	Economy	4200.00
0005432424281	30732	Economy	4200.00
0005432424383	30732	Economy	4200.00
0005432423947	30732	Economy	4200.00
0005432424384	30732	Economy	4200.00
0005432424355	30732	Economy	4200.00
0005432424367	30732	Economy	4200.00
0005432424082	30732	Economy	4200.00
0005432424083	30732	Economy	4200.00
0005432424368	30732	Economy	4200.00
0005432424369	30732	Economy	4200.00
0005432424353	30732	Economy	4200.00
0005432424371	30732	Economy	4200.00
0005432424226	30732	Economy	4200.00
0005432424326	30732	Economy	4200.00
0005432424233	30732	Economy	4200.00
0005432424234	30732	Economy	4200.00
0005432424333	30732	Economy	4200.00
0005432424339	30732	Economy	4200.00
0005432424252	30732	Economy	4200.00
0005432424327	30732	Economy	4200.00
0005432424381	30732	Economy	4200.00
0005434186184	9577	Business	32600.00
0005432817670	9577	Business	32600.00
0005432817696	9577	Business	32600.00
0005434448342	9577	Business	32600.00
0005432817675	9577	Business	32600.00
0005434448339	9577	Business	32600.00
0005432822262	9577	Business	32600.00
0005432817671	9577	Business	32600.00
0005434448338	9577	Business	32600.00
0005434157487	9577	Business	32600.00
0005432817679	9577	Economy	10900.00
0005434157480	9577	Economy	10900.00
0005432901550	9577	Economy	10900.00
0005432817680	9577	Economy	10900.00
0005432822261	9577	Economy	10900.00
0005434157478	9577	Economy	10900.00
0005432817678	9577	Economy	10900.00
0005432901588	9577	Economy	10900.00
0005432289010	9577	Economy	11900.00
0005434157466	9577	Economy	11900.00
0005432817681	9577	Economy	10900.00
0005432901590	9577	Economy	10900.00
0005432817691	9577	Economy	10900.00
0005432822260	9577	Economy	10900.00
0005432817676	9577	Economy	10900.00
0005432901619	9577	Economy	10900.00
0005432817688	9577	Economy	10900.00
0005432817673	9577	Economy	10900.00
0005432901620	9577	Economy	10900.00
0005432822259	9577	Economy	10900.00
0005432901589	9577	Economy	10900.00
0005432822255	9577	Economy	10900.00
0005432817672	9577	Economy	10900.00
0005432817689	9577	Economy	10900.00
0005432822263	9577	Economy	10900.00
0005432817683	9577	Economy	10900.00
0005434448341	9577	Economy	10900.00
0005432822254	9577	Economy	10900.00
0005432817686	9577	Economy	10900.00
0005432817674	9577	Economy	10900.00
0005434157467	9577	Economy	10900.00
0005432901542	9577	Economy	10900.00
0005432901596	9577	Economy	10900.00
0005432817697	9577	Economy	10900.00
0005432822257	9577	Economy	10900.00
0005432901518	9577	Economy	10900.00
0005434186190	9577	Economy	10900.00
0005432901580	9577	Economy	10900.00
0005432817687	9577	Economy	10900.00
0005432901587	9577	Economy	10900.00
0005432817693	9577	Economy	10900.00
0005432817692	9577	Economy	10900.00
0005434186189	9577	Economy	10900.00
0005432817669	9577	Economy	10900.00
0005432817684	9577	Economy	10900.00
0005434186183	9577	Economy	10900.00
0005432817682	9577	Economy	10900.00
0005434186191	9577	Economy	10900.00
0005432817685	9577	Economy	10900.00
0005432822256	9577	Economy	10900.00
0005432901579	9577	Economy	10900.00
0005432822258	9577	Economy	10900.00
0005434157468	9577	Economy	10900.00
0005432901591	9577	Economy	10900.00
0005432817677	9577	Economy	10900.00
0005432817695	9577	Economy	10900.00
0005434157465	9577	Economy	10900.00
0005432901630	9577	Economy	10900.00
0005434157432	9577	Economy	10900.00
0005432289009	9577	Economy	10900.00
0005434157488	9577	Economy	10900.00
0005432817694	9577	Economy	10900.00
0005432817690	9577	Economy	10900.00
0005434448340	9577	Economy	10900.00
0005434157538	28958	Business	32600.00
0005432817392	28958	Business	32600.00
0005432901741	28958	Business	32600.00
0005432901739	28958	Business	32600.00
0005432822213	28958	Business	32600.00
0005432817399	28958	Business	32600.00
0005432817328	28958	Business	32600.00
0005432822214	28958	Business	32600.00
0005432817367	28958	Business	32600.00
0005434157535	28958	Business	32600.00
0005432822202	28958	Economy	10900.00
0005432817470	28958	Economy	10900.00
0005432817455	28958	Economy	10900.00
0005432817458	28958	Economy	10900.00
0005432817389	28958	Economy	10900.00
0005432817398	28958	Economy	10900.00
0005434157533	28958	Economy	10900.00
0005432901727	28958	Economy	10900.00
0005432817513	28958	Economy	10900.00
0005432817488	28958	Economy	11900.00
0005434157534	28958	Economy	11900.00
0005434186216	28958	Economy	11900.00
0005432817414	28958	Economy	11900.00
0005432901729	28958	Economy	11900.00
0005434186218	28958	Economy	10900.00
0005432002091	28958	Economy	10900.00
0005432901734	28958	Economy	10900.00
0005432901740	28958	Economy	10900.00
0005432817463	28958	Economy	10900.00
0005432901725	28958	Economy	10900.00
0005432817405	28958	Economy	10900.00
0005432901737	28958	Economy	10900.00
0005432901728	28958	Economy	10900.00
0005432822173	28958	Economy	10900.00
0005434157537	28958	Economy	10900.00
0005432817427	28958	Economy	10900.00
0005432817442	28958	Economy	10900.00
0005432817441	28958	Economy	10900.00
0005432817393	28958	Economy	10900.00
0005434448298	28958	Economy	10900.00
0005432901731	28958	Economy	10900.00
0005434157536	28958	Economy	10900.00
0005432817370	28958	Economy	10900.00
0005432817468	28958	Economy	10900.00
0005432901742	28958	Economy	10900.00
0005432901730	28958	Economy	10900.00
0005432817352	28958	Economy	10900.00
0005432901736	28958	Economy	10900.00
0005432822161	28958	Economy	10900.00
0005432901732	28958	Economy	10900.00
0005432817443	28958	Economy	10900.00
0005432817364	28958	Economy	10900.00
0005432822203	28958	Economy	10900.00
0005432901738	28958	Economy	10900.00
0005432901726	28958	Economy	10900.00
0005432817485	28958	Economy	10900.00
0005432822160	28958	Economy	10900.00
0005432817486	28958	Economy	10900.00
0005432817331	28958	Economy	10900.00
0005434448299	28958	Economy	10900.00
0005432817436	28958	Economy	10900.00
0005432817415	28958	Economy	10900.00
0005432817487	28958	Economy	10900.00
0005432822219	28958	Economy	10900.00
0005432817358	28958	Economy	10900.00
0005434186217	28958	Economy	10900.00
0005432817548	28958	Economy	10900.00
0005432817502	28958	Economy	10900.00
0005432817390	28958	Economy	10900.00
0005434448297	28958	Economy	10900.00
0005432817471	28958	Economy	10900.00
0005432817482	28958	Economy	10900.00
0005432002090	28958	Economy	10900.00
0005432817469	28958	Economy	10900.00
0005432817484	28958	Economy	10900.00
0005434157532	28958	Economy	10900.00
0005432817421	28958	Economy	10900.00
0005432901735	28958	Economy	10900.00
0005432817391	28958	Economy	10900.00
0005432817479	28958	Economy	10900.00
0005432817549	28958	Economy	10900.00
0005432817481	28958	Economy	10900.00
0005432817416	28958	Economy	10900.00
0005432817453	28958	Economy	10900.00
0005432817450	28958	Economy	10900.00
0005432901733	28958	Economy	10900.00
0005432817509	28958	Economy	10900.00
0005432817404	28958	Economy	10900.00
0005432817435	28958	Economy	10900.00
0005432611740	15147	Economy	11000.00
0005432613892	15147	Economy	11000.00
0005432613893	15147	Economy	11000.00
0005432613891	15147	Economy	11000.00
0005432611738	15147	Economy	11000.00
0005435841822	15147	Economy	11000.00
0005432613890	15147	Economy	11000.00
0005432611739	15147	Economy	11000.00
0005432611741	15147	Economy	11000.00
0005432611699	31601	Economy	11000.00
0005432611700	31601	Economy	11000.00
0005432611712	31601	Economy	11000.00
0005432611724	31601	Economy	11000.00
0005432607540	31601	Economy	11000.00
0005435841826	31601	Economy	11000.00
0005432611705	31601	Economy	11000.00
0005432611703	31601	Economy	11000.00
0005432607543	31601	Economy	11000.00
0005432611725	31601	Economy	11000.00
0005432611704	31601	Economy	11000.00
0005432948331	11891	Business	105900.00
0005433569449	11891	Business	105900.00
0005433569446	11891	Business	105900.00
0005432948399	11891	Business	105900.00
0005432948324	11891	Business	105900.00
0005433569459	11891	Business	105900.00
0005432948487	11891	Business	105900.00
0005433569457	11891	Business	105900.00
0005432948439	11891	Business	105900.00
0005432948377	11891	Business	105900.00
0005433569469	11891	Business	105900.00
0005433569468	11891	Business	105900.00
0005432948252	11891	Business	105900.00
0005432948189	11891	Business	105900.00
0005432948486	11891	Business	105900.00
0005433569465	11891	Business	105900.00
0005433569442	11891	Business	105900.00
0005433569448	11891	Business	105900.00
0005433569434	11891	Economy	35300.00
0005433569456	11891	Economy	35300.00
0005433569441	11891	Economy	35300.00
0005432948201	11891	Economy	35300.00
0005433569445	11891	Economy	35300.00
0005432948257	11891	Economy	35300.00
0005433569467	11891	Economy	35300.00
0005433569447	11891	Economy	35300.00
0005432948488	11891	Economy	35300.00
0005432948421	11891	Economy	35300.00
0005432948460	11891	Economy	35300.00
0005433569444	11891	Economy	35300.00
0005432948361	11891	Economy	38800.00
0005432948517	11891	Economy	38800.00
0005433569436	11891	Economy	35300.00
0005433569440	11891	Economy	35300.00
0005432948199	11891	Economy	35300.00
0005432948295	11891	Economy	35300.00
0005433569433	11891	Economy	35300.00
0005433569439	11891	Economy	35300.00
0005433569461	11891	Economy	35300.00
0005432948239	11891	Economy	35300.00
0005433569450	11891	Economy	35300.00
0005433569454	11891	Economy	35300.00
0005432948433	11891	Economy	35300.00
0005433569437	11891	Economy	35300.00
0005432948398	11891	Economy	35300.00
0005432948325	11891	Economy	35300.00
0005432948403	11891	Economy	35300.00
0005433569432	11891	Economy	35300.00
0005433569460	11891	Economy	35300.00
0005433569435	11891	Economy	35300.00
0005432948438	11891	Economy	35300.00
0005432948200	11891	Economy	35300.00
0005432948276	11891	Economy	35300.00
0005432948303	11891	Economy	35300.00
0005432948305	11891	Economy	35300.00
0005432948354	11891	Economy	35300.00
0005432948386	11891	Economy	35300.00
0005432948320	11891	Economy	35300.00
0005432948387	11891	Economy	35300.00
0005432948307	11891	Economy	35300.00
0005432948388	11891	Economy	35300.00
0005432948319	11891	Economy	35300.00
0005433569452	11891	Economy	35300.00
0005432948404	11891	Economy	35300.00
0005432948328	11891	Economy	35300.00
0005433569428	11891	Economy	35300.00
0005433569455	11891	Economy	35300.00
0005433569443	11891	Economy	35300.00
0005433569463	11891	Economy	35300.00
0005432948440	11891	Economy	35300.00
0005433569431	11891	Economy	35300.00
0005432948215	11891	Economy	35300.00
0005432948287	11891	Economy	35300.00
0005432948380	11891	Economy	35300.00
0005432948278	11891	Economy	35300.00
0005432948304	11891	Economy	35300.00
0005433569458	11891	Economy	35300.00
0005432948327	11891	Economy	35300.00
0005433569470	11891	Economy	35300.00
0005432948302	11891	Economy	35300.00
0005432948214	11891	Economy	35300.00
0005432948323	11891	Economy	35300.00
0005432948332	11891	Economy	35300.00
0005432948469	11891	Economy	35300.00
0005433569471	11891	Economy	35300.00
0005433569438	11891	Economy	35300.00
0005433569453	11891	Economy	35300.00
0005432948258	11891	Economy	35300.00
0005433569429	11891	Economy	35300.00
0005433569451	11891	Economy	35300.00
0005432948333	11891	Economy	35300.00
0005432948362	11891	Economy	35300.00
0005433569466	11891	Economy	35300.00
0005433569464	11891	Economy	35300.00
0005432948277	11891	Economy	35300.00
0005432948479	11891	Economy	35300.00
0005432948251	11891	Economy	35300.00
0005433569462	11891	Economy	35300.00
0005433569430	11891	Economy	35300.00
0005433569082	25316	Business	105900.00
0005433568912	25316	Business	105900.00
0005433568902	25316	Business	105900.00
0005433569199	25316	Business	105900.00
0005433569200	25316	Business	105900.00
0005432948789	25316	Business	105900.00
0005433568973	25316	Business	105900.00
0005433569000	25316	Business	105900.00
0005432948775	25316	Business	105900.00
0005432948778	25316	Business	105900.00
0005432948782	25316	Business	105900.00
0005433568858	25316	Business	105900.00
0005432948785	25316	Business	105900.00
0005433568966	25316	Business	105900.00
0005433568859	25316	Business	105900.00
0005433568969	25316	Business	105900.00
0005433568956	25316	Economy	35300.00
0005433568980	25316	Economy	35300.00
0005432948804	25316	Economy	35300.00
0005433568970	25316	Economy	35300.00
0005432948766	25316	Economy	35300.00
0005432948788	25316	Economy	35300.00
0005432948767	25316	Economy	35300.00
0005433568901	25316	Economy	35300.00
0005433568709	25316	Economy	35300.00
0005432948787	25316	Economy	35300.00
0005433568925	25316	Economy	38800.00
0005433569094	25316	Economy	38800.00
0005433568885	25316	Economy	38800.00
0005433569016	25316	Economy	35300.00
0005432948799	25316	Economy	35300.00
0005433568810	25316	Economy	35300.00
0005433568892	25316	Economy	35300.00
0005433569114	25316	Economy	35300.00
0005433569017	25316	Economy	35300.00
0005432948773	25316	Economy	35300.00
0005433569041	25316	Economy	35300.00
0005433569155	25316	Economy	35300.00
0005433569092	25316	Economy	35300.00
0005433569009	25316	Economy	35300.00
0005433568884	25316	Economy	35300.00
0005433569113	25316	Economy	35300.00
0005433569081	25316	Economy	35300.00
0005432948790	25316	Economy	35300.00
0005433568641	25316	Economy	35300.00
0005432948793	25316	Economy	35300.00
0005433569093	25316	Economy	35300.00
0005433568949	25316	Economy	35300.00
0005433568708	25316	Economy	35300.00
0005432948779	25316	Economy	35300.00
0005433569106	25316	Economy	35300.00
0005432948798	25316	Economy	35300.00
0005433568812	25316	Economy	35300.00
0005433568948	25316	Economy	35300.00
0005432948768	25316	Economy	35300.00
0005433569010	25316	Economy	35300.00
0005432948770	25316	Economy	35300.00
0005432948791	25316	Economy	35300.00
0005432948783	25316	Economy	35300.00
0005433569056	25316	Economy	35300.00
0005432948772	25316	Economy	35300.00
0005433569067	25316	Economy	35300.00
0005433568698	25316	Economy	35300.00
0005433569112	25316	Economy	35300.00
0005433568841	25316	Economy	35300.00
0005433568877	25316	Economy	35300.00
0005433569105	25316	Economy	35300.00
0005433568854	25316	Economy	35300.00
0005432948802	25316	Economy	35300.00
0005432948774	25316	Economy	35300.00
0005433568934	25316	Economy	35300.00
0005433568878	25316	Economy	35300.00
0005433568868	25316	Economy	35300.00
0005432948784	25316	Economy	35300.00
0005432948777	25316	Economy	35300.00
0005432948795	25316	Economy	35300.00
0005432948800	25316	Economy	35300.00
0005433568879	25316	Economy	35300.00
0005433569055	25316	Economy	35300.00
0005432948801	25316	Economy	35300.00
0005432948803	25316	Economy	35300.00
0005433569024	25316	Economy	35300.00
0005433568891	25316	Economy	35300.00
0005432948796	25316	Economy	35300.00
0005433569335	25316	Economy	35300.00
0005432948781	25316	Economy	35300.00
0005433568738	25316	Economy	35300.00
0005432948786	25316	Economy	35300.00
0005432948805	25316	Economy	35300.00
0005433568957	25316	Economy	35300.00
0005432948794	25316	Economy	35300.00
0005433569001	25316	Economy	35300.00
0005432948769	25316	Economy	35300.00
0005433569042	25316	Economy	35300.00
0005433568979	25316	Economy	35300.00
0005432948792	25316	Economy	35300.00
0005432948771	25316	Economy	35300.00
0005432948797	25316	Economy	35300.00
0005433568847	25316	Economy	35300.00
0005432948776	25316	Economy	35300.00
0005433568890	25316	Economy	35300.00
0005432948780	25316	Economy	35300.00
0005433568480	25316	Economy	35300.00
0005433812911	30831	Business	117400.00
0005434026700	30831	Business	117400.00
0005433808402	30831	Business	117400.00
0005433808398	30831	Business	117400.00
0005432430853	30831	Business	117400.00
0005433812912	30831	Business	117400.00
0005432430856	30831	Economy	39100.00
0005433812915	30831	Economy	39100.00
0005433808401	30831	Economy	39100.00
0005433808400	30831	Economy	43000.00
0005432430848	30831	Economy	39100.00
0005433812914	30831	Economy	39100.00
0005432430844	30831	Economy	39100.00
0005432430852	30831	Economy	39100.00
0005434026691	30831	Economy	39100.00
0005433808403	30831	Economy	39100.00
0005432430845	30831	Economy	39100.00
0005432430831	30831	Economy	39100.00
0005433808396	30831	Economy	39100.00
0005432430841	30831	Economy	39100.00
0005434026697	30831	Economy	39100.00
0005433812910	30831	Economy	39100.00
0005433808399	30831	Economy	39100.00
0005432430870	30831	Economy	39100.00
0005434026695	30831	Economy	39100.00
0005434026690	30831	Economy	39100.00
0005434026694	30831	Economy	39100.00
0005433808393	30831	Economy	39100.00
0005432430857	30831	Economy	39100.00
0005434026692	30831	Economy	39100.00
0005433808397	30831	Economy	39100.00
0005433812913	30831	Economy	39100.00
0005434026693	30831	Economy	39100.00
0005433808394	30831	Economy	39100.00
0005433808395	30831	Economy	39100.00
0005433808404	30831	Economy	39100.00
0005434654891	5409	Business	67200.00
0005434654903	5409	Business	67200.00
0005435555362	5409	Business	67200.00
0005434654885	5409	Business	67200.00
0005432114225	5409	Business	67200.00
0005435340230	5409	Business	67200.00
0005435340182	5409	Business	67200.00
0005434654887	5409	Business	67200.00
0005435340228	5409	Economy	22400.00
0005434654905	5409	Economy	22400.00
0005434654889	5409	Economy	22400.00
0005434654892	5409	Economy	22400.00
0005434654880	5409	Economy	22400.00
0005434654900	5409	Economy	22400.00
0005434654899	5409	Economy	24600.00
0005435340240	5409	Economy	24600.00
0005435555367	5409	Economy	22400.00
0005434654881	5409	Economy	22400.00
0005435340263	5409	Economy	22400.00
0005434654878	5409	Economy	22400.00
0005432114227	5409	Economy	22400.00
0005434654883	5409	Economy	22400.00
0005435340249	5409	Economy	22400.00
0005435340188	5409	Economy	22400.00
0005434654898	5409	Economy	22400.00
0005434654884	5409	Economy	22400.00
0005434654890	5409	Economy	22400.00
0005435340290	5409	Economy	22400.00
0005434654897	5409	Economy	22400.00
0005434654882	5409	Economy	22400.00
0005434654893	5409	Economy	22400.00
0005435340206	5409	Economy	22400.00
0005434654879	5409	Economy	22400.00
0005434654901	5409	Economy	22400.00
0005435340225	5409	Economy	22400.00
0005434654888	5409	Economy	22400.00
0005432114226	5409	Economy	22400.00
0005435340241	5409	Economy	22400.00
0005434654904	5409	Economy	22400.00
0005435340289	5409	Economy	22400.00
0005434654895	5409	Economy	22400.00
0005434654906	5409	Economy	22400.00
0005434654896	5409	Economy	22400.00
0005435340248	5409	Economy	22400.00
0005434654894	5409	Economy	22400.00
0005434654902	5409	Economy	22400.00
0005434654886	5409	Economy	22400.00
0005435340229	5409	Economy	22400.00
0005434656571	5409	Economy	22400.00
0005435340364	12544	Business	67200.00
0005435340366	12544	Business	67200.00
0005434654709	12544	Business	67200.00
0005435340372	12544	Business	67200.00
0005434654651	12544	Business	67200.00
0005434654535	12544	Economy	22400.00
0005435340375	12544	Economy	22400.00
0005435340373	12544	Economy	24600.00
0005434656559	12544	Economy	24600.00
0005434654644	12544	Economy	22400.00
0005435555385	12544	Economy	22400.00
0005435340368	12544	Economy	22400.00
0005434654652	12544	Economy	22400.00
0005435340376	12544	Economy	22400.00
0005435555386	12544	Economy	22400.00
0005434654711	12544	Economy	22400.00
0005434654657	12544	Economy	22400.00
0005435340367	12544	Economy	22400.00
0005434654633	12544	Economy	22400.00
0005434654712	12544	Economy	22400.00
0005434654586	12544	Economy	22400.00
0005435340378	12544	Economy	22400.00
0005434656551	12544	Economy	22400.00
0005434654596	12544	Economy	22400.00
0005435340365	12544	Economy	22400.00
0005434654504	12544	Economy	22400.00
0005434656550	12544	Economy	22400.00
0005434654698	12544	Economy	22400.00
0005435340371	12544	Economy	22400.00
0005434654653	12544	Economy	22400.00
0005435340363	12544	Economy	22400.00
0005435340377	12544	Economy	22400.00
0005434654597	12544	Economy	22400.00
0005434654570	12544	Economy	22400.00
0005434654658	12544	Economy	22400.00
0005434654536	12544	Economy	22400.00
0005434654585	12544	Economy	22400.00
0005435340374	12544	Economy	22400.00
0005434654641	12544	Economy	22400.00
0005435340369	12544	Economy	22400.00
0005435555387	12544	Economy	22400.00
0005434654503	12544	Economy	22400.00
0005434654631	12544	Economy	22400.00
0005434654571	12544	Economy	22400.00
0005434654720	12544	Economy	22400.00
0005434654632	12544	Economy	22400.00
0005435340370	12544	Economy	22400.00
0005434654675	12544	Economy	22400.00
0005434654665	12544	Economy	22400.00
0005432078147	7435	Business	32000.00
0005433689923	7435	Business	32000.00
0005433716300	7435	Business	32000.00
0005432428913	7435	Business	32000.00
0005433716328	7435	Business	32000.00
0005433716325	7435	Business	32000.00
0005432428892	7435	Business	32000.00
0005433716344	7435	Economy	10700.00
0005433716303	7435	Economy	10700.00
0005433690937	7435	Economy	10700.00
0005433716302	7435	Economy	10700.00
0005433716333	7435	Economy	10700.00
0005432078146	7435	Economy	10700.00
0005433716332	7435	Economy	10700.00
0005433716334	7435	Economy	10700.00
0005433716311	7435	Economy	10700.00
0005433716298	7435	Economy	10700.00
0005433716312	7435	Economy	10700.00
0005433716323	7435	Economy	10700.00
0005433688823	7435	Economy	10700.00
0005433716304	7435	Economy	10700.00
0005433716310	7435	Economy	10700.00
0005432428893	7435	Economy	10700.00
0005433716305	7435	Economy	10700.00
0005433716340	7435	Economy	10700.00
0005433719163	7435	Economy	10700.00
0005433690938	7435	Economy	10700.00
0005433716299	7435	Economy	10700.00
0005433656692	7435	Economy	10700.00
0005433716338	7435	Economy	10700.00
0005433716313	7435	Economy	10700.00
0005433716320	7435	Economy	11700.00
0005433716330	7435	Economy	11700.00
0005433716321	7435	Economy	11700.00
0005432078149	7435	Economy	11700.00
0005433716329	7435	Economy	10700.00
0005433689924	7435	Economy	10700.00
0005433719161	7435	Economy	10700.00
0005433716314	7435	Economy	10700.00
0005433716295	7435	Economy	10700.00
0005432078148	7435	Economy	10700.00
0005433688821	7435	Economy	10700.00
0005433716307	7435	Economy	10700.00
0005435266137	7435	Economy	10700.00
0005433716306	7435	Economy	10700.00
0005432078150	7435	Economy	10700.00
0005433716336	7435	Economy	10700.00
0005433688822	7435	Economy	10700.00
0005433719162	7435	Economy	10700.00
0005433716339	7435	Economy	10700.00
0005433716315	7435	Economy	10700.00
0005433716337	7435	Economy	10700.00
0005433716327	7435	Economy	10700.00
0005433716301	7435	Economy	10700.00
0005433722271	7435	Economy	10700.00
0005433656691	7435	Economy	10700.00
0005433716341	7435	Economy	10700.00
0005433716331	7435	Economy	10700.00
0005433716297	7435	Economy	10700.00
0005433716317	7435	Economy	10700.00
0005433716322	7435	Economy	10700.00
0005433716319	7435	Economy	10700.00
0005433716326	7435	Economy	10700.00
0005433716324	7435	Economy	10700.00
0005433716316	7435	Economy	10700.00
0005433716335	7435	Economy	10700.00
0005433656693	7435	Economy	10700.00
0005433716342	7435	Economy	10700.00
0005433716308	7435	Economy	10700.00
0005433716318	7435	Economy	10700.00
0005433716343	7435	Economy	10700.00
0005433722270	7435	Economy	10700.00
0005435266138	7435	Economy	10700.00
0005433716296	7435	Economy	10700.00
0005433716309	7435	Economy	10700.00
0005433715663	29249	Business	32000.00
0005433715891	29249	Business	32000.00
0005433715919	29249	Business	32000.00
0005433715870	29249	Business	32000.00
0005433715913	29249	Business	32000.00
0005433715813	29249	Economy	10700.00
0005435266178	29249	Economy	10700.00
0005433715817	29249	Economy	10700.00
0005433715905	29249	Economy	10700.00
0005432006782	29249	Economy	10700.00
0005433715860	29249	Economy	10700.00
0005435266176	29249	Economy	10700.00
0005433715707	29249	Economy	10700.00
0005433722192	29249	Economy	10700.00
0005433715866	29249	Economy	10700.00
0005433715837	29249	Economy	10700.00
0005433715937	29249	Economy	10700.00
0005433715906	29249	Economy	10700.00
0005432428954	29249	Economy	10700.00
0005433715930	29249	Economy	10700.00
0005435266177	29249	Economy	10700.00
0005433715662	29249	Economy	10700.00
0005433715914	29249	Economy	10700.00
0005433719145	29249	Economy	10700.00
0005433685515	29249	Economy	10700.00
0005433715755	29249	Economy	10700.00
0005432428953	29249	Economy	10700.00
0005433719129	29249	Economy	10700.00
0005432006780	29249	Economy	10700.00
0005433715873	29249	Economy	10700.00
0005433715753	29249	Economy	10700.00
0005433716081	29249	Economy	11700.00
0005433715754	29249	Economy	11700.00
0005433716084	29249	Economy	11700.00
0005435266173	29249	Economy	11700.00
0005433716082	29249	Economy	10700.00
0005433715979	29249	Economy	10700.00
0005433715823	29249	Economy	10700.00
0005433715907	29249	Economy	10700.00
0005433715876	29249	Economy	10700.00
0005433715969	29249	Economy	10700.00
0005433715892	29249	Economy	10700.00
0005433685516	29249	Economy	10700.00
0005433715897	29249	Economy	10700.00
0005433715706	29249	Economy	10700.00
0005433715965	29249	Economy	10700.00
0005433715883	29249	Economy	10700.00
0005433716026	29249	Economy	10700.00
0005433685514	29249	Economy	10700.00
0005432006781	29249	Economy	10700.00
0005433715920	29249	Economy	10700.00
0005435266175	29249	Economy	10700.00
0005432428952	29249	Economy	10700.00
0005433715671	29249	Economy	10700.00
0005433656675	29249	Economy	10700.00
0005433716025	29249	Economy	10700.00
0005433722187	29249	Economy	10700.00
0005433715948	29249	Economy	10700.00
0005435266174	29249	Economy	10700.00
0005433715960	29249	Economy	10700.00
0005433656670	29249	Economy	10700.00
0005433656676	29249	Economy	10700.00
0005433715981	29249	Economy	10700.00
0005433715850	29249	Economy	10700.00
0005433715756	29249	Economy	10700.00
0005433715951	29249	Economy	10700.00
0005433715886	29249	Economy	10700.00
0005433716085	29249	Economy	10700.00
0005433715964	29249	Economy	10700.00
0005435266179	29249	Economy	10700.00
0005433722193	29249	Economy	10700.00
0005433685513	29249	Economy	10700.00
0005433715664	29249	Economy	10700.00
0005433715980	29249	Economy	10700.00
0005433715929	29249	Economy	10700.00
0005433715867	29249	Economy	10700.00
0005433685512	29249	Economy	10700.00
0005433715896	29249	Economy	10700.00
0005433715838	29249	Economy	10700.00
0005434182145	8665	Business	36500.00
0005434095371	8665	Business	36500.00
0005434095372	8665	Business	36500.00
0005434182207	8665	Economy	12200.00
0005434095385	8665	Economy	12200.00
0005434095384	8665	Economy	12200.00
0005434095374	8665	Economy	13400.00
0005434095376	8665	Economy	13400.00
0005434184668	8665	Economy	12200.00
0005434182220	8665	Economy	12200.00
0005434095381	8665	Economy	12200.00
0005434095378	8665	Economy	12200.00
0005434095379	8665	Economy	12200.00
0005434095380	8665	Economy	12200.00
0005434095382	8665	Economy	12200.00
0005434095377	8665	Economy	12200.00
0005434182162	8665	Economy	12200.00
0005434182129	8665	Economy	12200.00
0005434182215	8665	Economy	12200.00
0005434182182	8665	Economy	12200.00
0005434182200	8665	Economy	12200.00
0005434182128	8665	Economy	12200.00
0005434095375	8665	Economy	12200.00
0005434182122	8665	Economy	12200.00
0005434182166	8665	Economy	12200.00
0005434095383	8665	Economy	12200.00
0005434182163	8665	Economy	12200.00
0005434095386	8665	Economy	12200.00
0005434184659	8665	Economy	12200.00
0005434095373	8665	Economy	12200.00
0005434182221	8665	Economy	12200.00
0005434182214	8665	Economy	12200.00
0005434182190	8665	Economy	12200.00
0005434182183	8665	Economy	12200.00
0005434095262	11634	Business	36500.00
0005434182266	11634	Business	36500.00
0005434095252	11634	Economy	12200.00
0005434095234	11634	Economy	12200.00
0005434095308	11634	Economy	12200.00
0005434095241	11634	Economy	13400.00
0005434095299	11634	Economy	13400.00
0005434183591	11634	Economy	13400.00
0005434095200	11634	Economy	12200.00
0005434095253	11634	Economy	12200.00
0005434183592	11634	Economy	12200.00
0005434182274	11634	Economy	12200.00
0005434182267	11634	Economy	12200.00
0005434095231	11634	Economy	12200.00
0005434182270	11634	Economy	12200.00
0005434182271	11634	Economy	12200.00
0005434182278	11634	Economy	12200.00
0005434095235	11634	Economy	12200.00
0005434095298	11634	Economy	12200.00
0005434182268	11634	Economy	12200.00
0005434095229	11634	Economy	12200.00
0005434095260	11634	Economy	12200.00
0005434182269	11634	Economy	12200.00
0005434095216	11634	Economy	12200.00
0005434182273	11634	Economy	12200.00
0005434095309	11634	Economy	12200.00
0005434095295	11634	Economy	12200.00
0005434095230	11634	Economy	12200.00
0005434182277	11634	Economy	12200.00
0005434095274	11634	Economy	12200.00
0005434095264	11634	Economy	12200.00
0005434095215	11634	Economy	12200.00
0005434143722	11634	Economy	12200.00
0005434182275	11634	Economy	12200.00
0005434184678	11634	Economy	12200.00
0005434182276	11634	Economy	12200.00
0005434095240	11634	Economy	12200.00
0005434184677	11634	Economy	12200.00
0005434182272	11634	Economy	12200.00
0005435732395	1414	Business	33000.00
0005433397887	1414	Business	33000.00
0005433397836	1414	Business	33000.00
0005432297297	1414	Business	33000.00
0005435732408	1414	Business	33000.00
0005435732410	1414	Business	33000.00
0005432297298	1414	Business	33000.00
0005435732412	1414	Business	33000.00
0005435732418	1414	Business	33000.00
0005435732419	1414	Economy	11000.00
0005433456997	1414	Economy	11000.00
0005435732407	1414	Economy	11000.00
0005435732415	1414	Economy	11000.00
0005433397933	1414	Economy	11000.00
0005435732399	1414	Economy	12100.00
0005433397855	1414	Economy	11000.00
0005435732414	1414	Economy	11000.00
0005433397809	1414	Economy	11000.00
0005432297295	1414	Economy	11000.00
0005433397886	1414	Economy	11000.00
0005433397831	1414	Economy	11000.00
0005435732403	1414	Economy	11000.00
0005433397908	1414	Economy	11000.00
0005435732416	1414	Economy	11000.00
0005433397989	1414	Economy	11000.00
0005435732413	1414	Economy	11000.00
0005433398037	1414	Economy	11000.00
0005435732405	1414	Economy	11000.00
0005435732396	1414	Economy	11000.00
0005433398024	1414	Economy	11000.00
0005433397917	1414	Economy	11000.00
0005432297296	1414	Economy	11000.00
0005433397987	1414	Economy	11000.00
0005435732400	1414	Economy	11000.00
0005433398144	1414	Economy	11000.00
0005433397930	1414	Economy	11000.00
0005433397856	1414	Economy	11000.00
0005435732404	1414	Economy	11000.00
0005435732417	1414	Economy	11000.00
0005433456999	1414	Economy	11000.00
0005433397952	1414	Economy	11000.00
0005433397946	1414	Economy	11000.00
0005435732411	1414	Economy	11000.00
0005433456998	1414	Economy	11000.00
0005433397990	1414	Economy	11000.00
0005433398034	1414	Economy	11000.00
0005435732409	1414	Economy	11000.00
0005433398028	1414	Economy	11000.00
0005433398029	1414	Economy	11000.00
0005433398044	1414	Economy	11000.00
0005433397891	1414	Economy	11000.00
0005432906526	1414	Economy	11000.00
0005435732397	1414	Economy	11000.00
0005435732401	1414	Economy	11000.00
0005432906527	1414	Economy	11000.00
0005435732406	1414	Economy	11000.00
0005435732398	1414	Economy	11000.00
0005435732402	1414	Economy	11000.00
0005433398404	19261	Business	33000.00
0005433398402	19261	Business	33000.00
0005433456960	19261	Business	33000.00
0005433398413	19261	Business	33000.00
0005433398403	19261	Business	33000.00
0005433398412	19261	Business	33000.00
0005433398378	19261	Business	33000.00
0005433398390	19261	Business	33000.00
0005433398376	19261	Business	33000.00
0005433456952	19261	Business	33000.00
0005433398384	19261	Economy	11000.00
0005432906553	19261	Economy	11000.00
0005433398397	19261	Economy	11000.00
0005433398406	19261	Economy	11000.00
0005433456964	19261	Economy	11000.00
0005433398375	19261	Economy	11000.00
0005433398415	19261	Economy	11000.00
0005433398385	19261	Economy	12100.00
0005433398399	19261	Economy	12100.00
0005433398410	19261	Economy	11000.00
0005435732290	19261	Economy	11000.00
0005433398416	19261	Economy	11000.00
0005432906554	19261	Economy	11000.00
0005433398379	19261	Economy	11000.00
0005433398420	19261	Economy	11000.00
0005433398388	19261	Economy	11000.00
0005433456965	19261	Economy	11000.00
0005433398389	19261	Economy	11000.00
0005433398377	19261	Economy	11000.00
0005433398414	19261	Economy	11000.00
0005433456961	19261	Economy	11000.00
0005433456962	19261	Economy	11000.00
0005432906552	19261	Economy	11000.00
0005433398418	19261	Economy	11000.00
0005433456968	19261	Economy	11000.00
0005435732324	19261	Economy	11000.00
0005435732362	19261	Economy	11000.00
0005433398408	19261	Economy	11000.00
0005433398395	19261	Economy	11000.00
0005435732361	19261	Economy	11000.00
0005435732304	19261	Economy	11000.00
0005433398391	19261	Economy	11000.00
0005433398380	19261	Economy	11000.00
0005433398417	19261	Economy	11000.00
0005433398396	19261	Economy	11000.00
0005433398398	19261	Economy	11000.00
0005435732359	19261	Economy	11000.00
0005433456963	19261	Economy	11000.00
0005433398419	19261	Economy	11000.00
0005433398407	19261	Economy	11000.00
0005433398393	19261	Economy	11000.00
0005433398405	19261	Economy	11000.00
0005433398409	19261	Economy	11000.00
0005433398373	19261	Economy	11000.00
0005433398383	19261	Economy	11000.00
0005433398386	19261	Economy	11000.00
0005433398382	19261	Economy	11000.00
0005433456937	19261	Economy	11000.00
0005435732323	19261	Economy	11000.00
0005435732303	19261	Economy	11000.00
0005433398374	19261	Economy	11000.00
0005433398401	19261	Economy	11000.00
0005433398392	19261	Economy	11000.00
0005433398394	19261	Economy	11000.00
0005433398381	19261	Economy	11000.00
0005433456967	19261	Economy	11000.00
0005433398400	19261	Economy	11000.00
0005433456966	19261	Economy	11000.00
0005433398387	19261	Economy	11000.00
0005433398411	19261	Economy	11000.00
0005434443648	17348	Economy	14100.00
0005434443669	17348	Economy	14100.00
0005434443657	17348	Economy	14100.00
0005434443649	17348	Economy	14100.00
0005434443750	17348	Economy	14100.00
0005434443607	17348	Economy	14100.00
0005434443658	17348	Economy	14100.00
0005434443665	17348	Economy	14100.00
0005434443702	17348	Economy	14100.00
0005434443687	17348	Economy	14100.00
0005434443666	17348	Economy	14100.00
0005434443659	17348	Economy	14100.00
0005434443819	20593	Economy	15600.00
0005434443816	20593	Economy	14100.00
0005434443807	20593	Economy	14100.00
0005434443817	20593	Economy	14100.00
0005434443805	20593	Economy	14100.00
0005434443808	20593	Economy	14100.00
0005434443811	20593	Economy	14100.00
0005434443810	20593	Economy	14100.00
0005434443813	20593	Economy	14100.00
0005434443815	20593	Economy	14100.00
0005434443818	20593	Economy	14100.00
0005434443812	20593	Economy	14100.00
0005434443814	20593	Economy	14100.00
0005434443806	20593	Economy	14100.00
0005434443809	20593	Economy	14100.00
0005435377583	7253	Economy	5800.00
0005434954634	7253	Economy	5800.00
0005434954635	7253	Economy	5800.00
0005434954637	7253	Economy	5800.00
0005435377582	7253	Economy	5800.00
0005434954636	7253	Economy	5800.00
0005435377596	28314	Economy	5800.00
0005435377597	28314	Economy	5800.00
0005435893626	4492	Economy	15400.00
0005434351787	4492	Economy	14000.00
0005435893637	4492	Economy	14000.00
0005435893635	4492	Economy	14000.00
0005434351784	4492	Economy	14000.00
0005435893661	4492	Economy	14000.00
0005434351782	4492	Economy	14000.00
0005435893625	4492	Economy	14000.00
0005435893648	4492	Economy	14000.00
0005434183574	4492	Economy	14000.00
0005434351788	4492	Economy	14000.00
0005435893617	4492	Economy	14000.00
0005434183576	4492	Economy	14000.00
0005434351778	4492	Economy	14000.00
0005434351790	4492	Economy	14000.00
0005434183575	4492	Economy	14000.00
0005434351786	4492	Economy	14000.00
0005435893634	4492	Economy	14000.00
0005434351781	4492	Economy	14000.00
0005434351785	4492	Economy	14000.00
0005434351783	4492	Economy	14000.00
0005434351791	4492	Economy	14000.00
0005434351779	4492	Economy	14000.00
0005435893638	4492	Economy	14000.00
0005434351789	4492	Economy	14000.00
0005434351780	4492	Economy	14000.00
0005435893633	4492	Economy	14000.00
0005435893652	4492	Economy	14000.00
0005435893616	4492	Economy	14000.00
0005435893653	4492	Economy	14000.00
0005435893680	29671	Economy	15400.00
0005434351734	29671	Economy	14000.00
0005434351668	29671	Economy	14000.00
0005434351732	29671	Economy	14000.00
0005435893682	29671	Economy	14000.00
0005434351690	29671	Economy	14000.00
0005434351682	29671	Economy	14000.00
0005435893683	29671	Economy	14000.00
0005435893679	29671	Economy	14000.00
0005434351733	29671	Economy	14000.00
0005435893684	29671	Economy	14000.00
0005434351689	29671	Economy	14000.00
0005435893681	29671	Economy	14000.00
0005435893685	29671	Economy	14000.00
0005434351688	29671	Economy	14000.00
0005435893678	29671	Economy	14000.00
0005434351681	29671	Economy	14000.00
0005432293225	1063	Business	30600.00
0005433343079	1063	Business	30600.00
0005433343246	1063	Business	30600.00
0005433158119	1063	Business	30600.00
0005433342821	1063	Business	30600.00
0005433342778	1063	Business	30600.00
0005433343054	1063	Business	30600.00
0005433342404	1063	Business	30600.00
0005433342937	1063	Business	30600.00
0005433342743	1063	Business	30600.00
0005433342633	1063	Business	30600.00
0005433343000	1063	Business	30600.00
0005433342782	1063	Business	30600.00
0005435092146	1063	Business	30600.00
0005433342603	1063	Business	30600.00
0005433463916	1063	Business	30600.00
0005433342715	1063	Business	30600.00
0005433342920	1063	Business	30600.00
0005433343206	1063	Business	30600.00
0005433159312	1063	Business	30600.00
0005433342720	1063	Business	30600.00
0005432293226	1063	Business	30600.00
0005433159313	1063	Business	30600.00
0005433343085	1063	Economy	11200.00
0005433342163	1063	Economy	11200.00
0005433342756	1063	Economy	11200.00
0005433342388	1063	Economy	10200.00
0005433343226	1063	Economy	10200.00
0005433342632	1063	Economy	10200.00
0005433343257	1063	Economy	10200.00
0005433342876	1063	Economy	10200.00
0005433342856	1063	Economy	10200.00
0005433342529	1063	Economy	10200.00
0005433342985	1063	Economy	10200.00
0005433342833	1063	Economy	10200.00
0005433343098	1063	Economy	10200.00
0005433343058	1063	Economy	10200.00
0005433342641	1063	Economy	10200.00
0005433342716	1063	Economy	10200.00
0005433159309	1063	Economy	10200.00
0005433343071	1063	Economy	10200.00
0005433342528	1063	Economy	10200.00
0005433343207	1063	Economy	10200.00
0005433342835	1063	Economy	10200.00
0005433342927	1063	Economy	10200.00
0005434445260	1063	Economy	10200.00
0005435092143	1063	Economy	10200.00
0005433343057	1063	Economy	10200.00
0005433343191	1063	Economy	10200.00
0005433342224	1063	Economy	10200.00
0005433342777	1063	Economy	10200.00
0005433342162	1063	Economy	10200.00
0005433342696	1063	Economy	10200.00
0005433342677	1063	Economy	10200.00
0005433343258	1063	Economy	10200.00
0005433343308	1063	Economy	10200.00
0005433343096	1063	Economy	10200.00
0005433343063	1063	Economy	10200.00
0005433342799	1063	Economy	10200.00
0005433342970	1063	Economy	10200.00
0005433342706	1063	Economy	10200.00
0005433269704	1063	Economy	10200.00
0005433462762	1063	Economy	10200.00
0005433343309	1063	Economy	10200.00
0005433342673	1063	Economy	10200.00
0005433342668	1063	Economy	10200.00
0005435092147	1063	Economy	10200.00
0005433343074	1063	Economy	10200.00
0005433342721	1063	Economy	10200.00
0005435092144	1063	Economy	10200.00
0005433342766	1063	Economy	10200.00
0005433342807	1063	Economy	10200.00
0005433342767	1063	Economy	10200.00
0005433343140	1063	Economy	10200.00
0005433342164	1063	Economy	10200.00
0005433342583	1063	Economy	10200.00
0005433343078	1063	Economy	10200.00
0005433342682	1063	Economy	10200.00
0005433342986	1063	Economy	10200.00
0005433342831	1063	Economy	10200.00
0005433342602	1063	Economy	10200.00
0005433343038	1063	Economy	10200.00
0005435092140	1063	Economy	10200.00
0005433342755	1063	Economy	10200.00
0005432293227	1063	Economy	10200.00
0005433343183	1063	Economy	10200.00
0005433343303	1063	Economy	10200.00
0005433342983	1063	Economy	10200.00
0005433342959	1063	Economy	10200.00
0005433342678	1063	Economy	10200.00
0005433269696	1063	Economy	10200.00
0005433343256	1063	Economy	10200.00
0005433342771	1063	Economy	10200.00
0005433343141	1063	Economy	10200.00
0005433342877	1063	Economy	10200.00
0005433463915	1063	Economy	10200.00
0005433342946	1063	Economy	11200.00
0005433342995	1063	Economy	11200.00
0005433343208	1063	Economy	10200.00
0005433343097	1063	Economy	10200.00
0005433342559	1063	Economy	10200.00
0005433343299	1063	Economy	11200.00
0005433159308	1063	Economy	11200.00
0005433342217	1063	Economy	10200.00
0005433342872	1063	Economy	10200.00
0005433342841	1063	Economy	10200.00
0005433342680	1063	Economy	10200.00
0005433342918	1063	Economy	10200.00
0005433159306	1063	Economy	10200.00
0005433269698	1063	Economy	10200.00
0005433343072	1063	Economy	10200.00
0005433343030	1063	Economy	10200.00
0005433343075	1063	Economy	10200.00
0005433343061	1063	Economy	10200.00
0005433342577	1063	Economy	10200.00
0005433342919	1063	Economy	10200.00
0005433342700	1063	Economy	10200.00
0005433342727	1063	Economy	10200.00
0005433343298	1063	Economy	10200.00
0005435092145	1063	Economy	10200.00
0005433343158	1063	Economy	10200.00
0005433269705	1063	Economy	10200.00
0005433343099	1063	Economy	10200.00
0005433342783	1063	Economy	10200.00
0005433343064	1063	Economy	10200.00
0005433343115	1063	Economy	10200.00
0005433342768	1063	Economy	10200.00
0005433343247	1063	Economy	10200.00
0005433342969	1063	Economy	10200.00
0005433343190	1063	Economy	10200.00
0005433342960	1063	Economy	10200.00
0005433342683	1063	Economy	10200.00
0005433269699	1063	Economy	10200.00
0005433342761	1063	Economy	10200.00
0005433343062	1063	Economy	10200.00
0005433343128	1063	Economy	10200.00
0005433342634	1063	Economy	10200.00
0005433342757	1063	Economy	10200.00
0005433342895	1063	Economy	10200.00
0005435092141	1063	Economy	10200.00
0005435092142	1063	Economy	10200.00
0005433343286	1063	Economy	10200.00
0005433342371	1063	Economy	10200.00
0005433269695	1063	Economy	10200.00
0005433342812	1063	Economy	10200.00
0005433343116	1063	Economy	10200.00
0005433342984	1063	Economy	10200.00
0005433342896	1063	Economy	10200.00
0005435092148	1063	Economy	10200.00
0005433343124	1063	Economy	10200.00
0005433342772	1063	Economy	10200.00
0005433343152	1063	Economy	10200.00
0005433342820	1063	Economy	10200.00
0005433342834	1063	Economy	10200.00
0005433462761	1063	Economy	10200.00
0005433342744	1063	Economy	10200.00
0005433343772	17027	Business	30600.00
0005433343786	17027	Business	30600.00
0005435092117	17027	Business	30600.00
0005433159328	17027	Business	30600.00
0005433343791	17027	Business	30600.00
0005433343737	17027	Business	30600.00
0005435508328	17027	Business	30600.00
0005433343771	17027	Business	30600.00
0005433343757	17027	Business	30600.00
0005435092061	17027	Business	30600.00
0005433343730	17027	Business	30600.00
0005435092088	17027	Business	30600.00
0005433343817	17027	Business	30600.00
0005433343801	17027	Business	30600.00
0005433269755	17027	Business	30600.00
0005435092030	17027	Business	30600.00
0005435508325	17027	Business	30600.00
0005433343732	17027	Business	30600.00
0005433343766	17027	Business	30600.00
0005433269757	17027	Business	30600.00
0005433343731	17027	Business	30600.00
0005433343727	17027	Business	30600.00
0005433343741	17027	Business	30600.00
0005435508360	17027	Business	30600.00
0005435508286	17027	Business	30600.00
0005433462741	17027	Business	30600.00
0005433343734	17027	Business	30600.00
0005433343798	17027	Economy	11200.00
0005433343728	17027	Economy	11200.00
0005433343781	17027	Economy	11200.00
0005435092075	17027	Economy	11200.00
0005433269754	17027	Economy	10200.00
0005433462738	17027	Economy	10200.00
0005433343725	17027	Economy	10200.00
0005433343760	17027	Economy	10200.00
0005433343795	17027	Economy	10200.00
0005433343799	17027	Economy	10200.00
0005434445232	17027	Economy	10200.00
0005433343811	17027	Economy	10200.00
0005433343752	17027	Economy	10200.00
0005433460421	17027	Economy	10200.00
0005435092074	17027	Economy	10200.00
0005435508392	17027	Economy	10200.00
0005433462731	17027	Economy	10200.00
0005433343726	17027	Economy	10200.00
0005433343753	17027	Economy	10200.00
0005433343807	17027	Economy	10200.00
0005433460416	17027	Economy	10200.00
0005433343719	17027	Economy	10200.00
0005433343733	17027	Economy	10200.00
0005433343750	17027	Economy	10200.00
0005433462729	17027	Economy	10200.00
0005433343746	17027	Economy	10200.00
0005435508287	17027	Economy	10200.00
0005433343765	17027	Economy	10200.00
0005433343774	17027	Economy	10200.00
0005434445231	17027	Economy	10200.00
0005435092057	17027	Economy	10200.00
0005435508393	17027	Economy	10200.00
0005433343806	17027	Economy	10200.00
0005433343755	17027	Economy	10200.00
0005433343773	17027	Economy	10200.00
0005433269758	17027	Economy	10200.00
0005433343740	17027	Economy	10200.00
0005435092079	17027	Economy	10200.00
0005433343769	17027	Economy	10200.00
0005435508367	17027	Economy	10200.00
0005433462739	17027	Economy	10200.00
0005433343722	17027	Economy	10200.00
0005433462728	17027	Economy	10200.00
0005433460424	17027	Economy	10200.00
0005433343749	17027	Economy	10200.00
0005433343721	17027	Economy	10200.00
0005433343819	17027	Economy	10200.00
0005433343735	17027	Economy	10200.00
0005433343804	17027	Economy	10200.00
0005433460423	17027	Economy	10200.00
0005433343747	17027	Economy	10200.00
0005433343818	17027	Economy	10200.00
0005433460411	17027	Economy	10200.00
0005433343784	17027	Economy	10200.00
0005433462733	17027	Economy	10200.00
0005433343761	17027	Economy	10200.00
0005433343723	17027	Economy	10200.00
0005435092058	17027	Economy	10200.00
0005433462730	17027	Economy	10200.00
0005433343810	17027	Economy	10200.00
0005433343767	17027	Economy	10200.00
0005433343763	17027	Economy	10200.00
0005433343815	17027	Economy	10200.00
0005433343724	17027	Economy	10200.00
0005435529973	17027	Economy	10200.00
0005433343796	17027	Economy	10200.00
0005433343803	17027	Economy	10200.00
0005435092087	17027	Economy	10200.00
0005433343775	17027	Economy	10200.00
0005435508368	17027	Economy	10200.00
0005433460415	17027	Economy	10200.00
0005433343797	17027	Economy	10200.00
0005433269756	17027	Economy	10200.00
0005433343754	17027	Economy	10200.00
0005433460420	17027	Economy	10200.00
0005433343808	17027	Economy	10200.00
0005433462725	17027	Economy	11200.00
0005433343812	17027	Economy	10200.00
0005433343736	17027	Economy	10200.00
0005435092015	17027	Economy	10200.00
0005433343718	17027	Economy	10200.00
0005433343743	17027	Economy	10200.00
0005435508309	17027	Economy	10200.00
0005433343738	17027	Economy	10200.00
0005435092078	17027	Economy	10200.00
0005433343742	17027	Economy	10200.00
0005435508375	17027	Economy	10200.00
0005433343788	17027	Economy	10200.00
0005433462722	17027	Economy	10200.00
0005433460417	17027	Economy	10200.00
0005433343779	17027	Economy	10200.00
0005435092046	17027	Economy	10200.00
0005433343768	17027	Economy	10200.00
0005433343783	17027	Economy	10200.00
0005433343770	17027	Economy	10200.00
0005433343776	17027	Economy	10200.00
0005433343780	17027	Economy	10200.00
0005433343789	17027	Economy	10200.00
0005433343800	17027	Economy	10200.00
0005433343777	17027	Economy	10200.00
0005433460425	17027	Economy	10200.00
0005433462736	17027	Economy	10200.00
0005433343792	17027	Economy	10200.00
0005433343739	17027	Economy	10200.00
0005433343756	17027	Economy	10200.00
0005433343745	17027	Economy	10200.00
0005435092080	17027	Economy	10200.00
0005433343748	17027	Economy	10200.00
0005433343744	17027	Economy	10200.00
0005433343751	17027	Economy	10200.00
0005433343793	17027	Economy	10200.00
0005433343729	17027	Economy	10200.00
0005433343764	17027	Economy	10200.00
0005433343814	17027	Economy	10200.00
0005435092056	17027	Economy	10200.00
0005435508305	17027	Economy	10200.00
0005433462740	17027	Economy	10200.00
0005435508312	17027	Economy	10200.00
0005433343759	17027	Economy	10200.00
0005433343813	17027	Economy	10200.00
0005433343782	17027	Economy	10200.00
0005433460422	17027	Economy	10200.00
0005433462737	17027	Economy	10200.00
0005435508270	17027	Economy	10200.00
0005433343809	17027	Economy	10200.00
0005435508327	17027	Economy	10200.00
0005433343816	17027	Economy	10200.00
0005433343785	17027	Economy	10200.00
0005433343802	17027	Economy	10200.00
0005433343790	17027	Economy	10200.00
0005433343762	17027	Economy	10200.00
0005433462732	17027	Economy	10200.00
0005433460418	17027	Economy	10200.00
0005433343805	17027	Economy	10200.00
0005433343778	17027	Economy	10200.00
0005433343758	17027	Economy	10200.00
0005433343720	17027	Economy	10200.00
0005433343787	17027	Economy	10200.00
0005433343794	17027	Economy	10200.00
0005432390072	18276	Business	101000.00
0005432851952	18276	Business	101000.00
0005432390097	18276	Business	101000.00
0005432390130	18276	Business	101000.00
0005432390070	18276	Business	101000.00
0005432390099	18276	Business	101000.00
0005432390068	18276	Business	101000.00
0005432390122	18276	Business	101000.00
0005432390094	18276	Business	101000.00
0005432390096	18276	Business	101000.00
0005432851958	18276	Business	101000.00
0005432390090	18276	Business	101000.00
0005432390082	18276	Business	101000.00
0005432390023	18276	Economy	33700.00
0005432390134	18276	Economy	33700.00
0005432390112	18276	Economy	33700.00
0005432390081	18276	Economy	33700.00
0005432851964	18276	Economy	33700.00
0005432851967	18276	Economy	33700.00
0005432851955	18276	Economy	33700.00
0005432851954	18276	Economy	33700.00
0005432390128	18276	Economy	37000.00
0005432390086	18276	Economy	33700.00
0005432390071	18276	Economy	33700.00
0005432390106	18276	Economy	33700.00
0005432851957	18276	Economy	33700.00
0005432390061	18276	Economy	33700.00
0005432390091	18276	Economy	33700.00
0005432390113	18276	Economy	33700.00
0005432851950	18276	Economy	33700.00
0005432851968	18276	Economy	33700.00
0005432851962	18276	Economy	33700.00
0005432851961	18276	Economy	33700.00
0005432390084	18276	Economy	33700.00
0005432390063	18276	Economy	33700.00
0005432851960	18276	Economy	33700.00
0005432851959	18276	Economy	33700.00
0005432390098	18276	Economy	33700.00
0005432390110	18276	Economy	33700.00
0005432851965	18276	Economy	33700.00
0005432390028	18276	Economy	33700.00
0005432390120	18276	Economy	33700.00
0005432390143	18276	Economy	33700.00
0005432390105	18276	Economy	33700.00
0005432390121	18276	Economy	33700.00
0005432390085	18276	Economy	33700.00
0005432390171	18276	Economy	33700.00
0005432851953	18276	Economy	33700.00
0005432391987	18276	Economy	33700.00
0005432390052	18276	Economy	33700.00
0005432390100	18276	Economy	33700.00
0005432390111	18276	Economy	33700.00
0005432390089	18276	Economy	33700.00
0005432851956	18276	Economy	33700.00
0005432390087	18276	Economy	33700.00
0005432851966	18276	Economy	33700.00
0005432390062	18276	Economy	33700.00
0005432851951	18276	Economy	33700.00
0005432390144	18276	Economy	33700.00
0005432851963	18276	Economy	33700.00
0005432390022	18276	Economy	33700.00
0005432390095	18276	Economy	33700.00
0005432390069	18276	Economy	33700.00
0005432390060	18276	Economy	33700.00
0005432390066	18276	Economy	33700.00
0005432390079	18276	Economy	33700.00
0005432390078	18276	Economy	33700.00
0005432391989	18276	Economy	33700.00
0005434067144	12794	Business	40300.00
0005434067510	12794	Business	40300.00
0005434081773	12794	Business	40300.00
0005434081763	12794	Business	40300.00
0005434067350	12794	Business	40300.00
0005432433718	12794	Business	40300.00
0005434067709	12794	Business	40300.00
0005434067595	12794	Business	40300.00
0005434067355	12794	Business	40300.00
0005432159890	12794	Business	40300.00
0005434067472	12794	Business	40300.00
0005434067342	12794	Business	40300.00
0005433989776	12794	Economy	13400.00
0005434067391	12794	Economy	13400.00
0005434067589	12794	Economy	13400.00
0005434026687	12794	Economy	13400.00
0005434081849	12794	Economy	13400.00
0005432433719	12794	Economy	13400.00
0005434081857	12794	Economy	13400.00
0005433812918	12794	Economy	13400.00
0005434067422	12794	Economy	13400.00
0005434067563	12794	Economy	13400.00
0005434067096	12794	Economy	13400.00
0005434067421	12794	Economy	13400.00
0005434067084	12794	Economy	13400.00
0005432161168	12794	Economy	13400.00
0005434081765	12794	Economy	13400.00
0005432433715	12794	Economy	13400.00
0005434081762	12794	Economy	13400.00
0005434067191	12794	Economy	13400.00
0005432159889	12794	Economy	13400.00
0005434067490	12794	Economy	13400.00
0005434067525	12794	Economy	13400.00
0005434067488	12794	Economy	13400.00
0005434081761	12794	Economy	13400.00
0005434067330	12794	Economy	13400.00
0005434081751	12794	Economy	13400.00
0005434067143	12794	Economy	13400.00
0005434067538	12794	Economy	13400.00
0005434081787	12794	Economy	13400.00
0005434067354	12794	Economy	13400.00
0005434081750	12794	Economy	13400.00
0005434081916	12794	Economy	13400.00
0005434067101	12794	Economy	13400.00
0005434081831	12794	Economy	13400.00
0005434067492	12794	Economy	13400.00
0005434067550	12794	Economy	13400.00
0005432161167	12794	Economy	13400.00
0005432159888	12794	Economy	13400.00
0005434067333	12794	Economy	13400.00
0005434067708	12794	Economy	13400.00
0005434067585	12794	Economy	14800.00
0005434067380	12794	Economy	14800.00
0005434081795	12794	Economy	14800.00
0005434081858	12794	Economy	14800.00
0005434067272	12794	Economy	14800.00
0005433989740	12794	Economy	14800.00
0005434067461	12794	Economy	13400.00
0005434067473	12794	Economy	13400.00
0005434067441	12794	Economy	13400.00
0005434081760	12794	Economy	13400.00
0005434081871	12794	Economy	13400.00
0005434067251	12794	Economy	13400.00
0005434081895	12794	Economy	13400.00
0005434067433	12794	Economy	13400.00
0005434067234	12794	Economy	13400.00
0005432433716	12794	Economy	13400.00
0005433812916	12794	Economy	13400.00
0005434067514	12794	Economy	13400.00
0005434067329	12794	Economy	13400.00
0005434067190	12794	Economy	13400.00
0005434067440	12794	Economy	13400.00
0005434081896	12794	Economy	13400.00
0005434067459	12794	Economy	13400.00
0005432159891	12794	Economy	13400.00
0005434081886	12794	Economy	13400.00
0005434067462	12794	Economy	13400.00
0005434081819	12794	Economy	13400.00
0005434026688	12794	Economy	13400.00
0005434067361	12794	Economy	13400.00
0005434081851	12794	Economy	13400.00
0005434081759	12794	Economy	13400.00
0005434067586	12794	Economy	13400.00
0005434066987	12794	Economy	13400.00
0005434067555	12794	Economy	13400.00
0005434081848	12794	Economy	13400.00
0005433989759	12794	Economy	13400.00
0005433989752	12794	Economy	13400.00
0005434026689	12794	Economy	13400.00
0005434067498	12794	Economy	13400.00
0005434067614	12794	Economy	13400.00
0005433989746	12794	Economy	13400.00
0005434067106	12794	Economy	13400.00
0005434081850	12794	Economy	13400.00
0005434081799	12794	Economy	13400.00
0005434067328	12794	Economy	13400.00
0005432433717	12794	Economy	13400.00
0005434067269	12794	Economy	13400.00
0005434067491	12794	Economy	13400.00
0005434081902	12794	Economy	13400.00
0005434026698	12794	Economy	13400.00
0005434067213	12794	Economy	13400.00
0005434067097	12794	Economy	13400.00
0005434067257	12794	Economy	13400.00
0005433989775	12794	Economy	13400.00
0005434081868	12794	Economy	13400.00
0005433812917	12794	Economy	13400.00
0005434081766	12794	Economy	13400.00
0005434067420	12794	Economy	13400.00
0005434067357	12794	Economy	13400.00
0005434081922	12794	Economy	13400.00
0005434081772	12794	Economy	13400.00
0005434081708	12794	Economy	13400.00
0005434067465	12794	Economy	13400.00
0005434067359	12794	Economy	13400.00
0005434081870	12794	Economy	13400.00
0005434067126	12794	Economy	13400.00
0005434026699	12794	Economy	13400.00
0005434067650	12794	Economy	13400.00
0005434081912	12794	Economy	13400.00
0005434067072	12794	Economy	13400.00
0005434067608	12794	Economy	13400.00
0005434067613	12794	Economy	13400.00
0005434067233	12794	Economy	13400.00
0005434067381	12794	Economy	13400.00
0005434067434	12794	Economy	13400.00
0005434067358	12794	Economy	13400.00
0005433989760	12794	Economy	13400.00
0005434082042	30670	Business	40300.00
0005434068030	30670	Business	40300.00
0005434082054	30670	Business	40300.00
0005434067977	30670	Business	40300.00
0005434082041	30670	Business	40300.00
0005434082039	30670	Business	40300.00
0005434068007	30670	Business	40300.00
0005434068034	30670	Business	40300.00
0005434068015	30670	Business	40300.00
0005434067997	30670	Business	40300.00
0005432433671	30670	Economy	13400.00
0005434067975	30670	Economy	13400.00
0005434068021	30670	Economy	13400.00
0005434067991	30670	Economy	13400.00
0005434068032	30670	Economy	13400.00
0005432186892	30670	Economy	13400.00
0005434067992	30670	Economy	13400.00
0005434067995	30670	Economy	13400.00
0005434068003	30670	Economy	13400.00
0005434068014	30670	Economy	13400.00
0005434068011	30670	Economy	13400.00
0005434068005	30670	Economy	13400.00
0005434082049	30670	Economy	13400.00
0005434068001	30670	Economy	13400.00
0005434067972	30670	Economy	13400.00
0005434067986	30670	Economy	13400.00
0005434067980	30670	Economy	13400.00
0005434067989	30670	Economy	13400.00
0005434067984	30670	Economy	13400.00
0005434068025	30670	Economy	13400.00
0005432433646	30670	Economy	13400.00
0005434082048	30670	Economy	13400.00
0005434082051	30670	Economy	13400.00
0005434082043	30670	Economy	13400.00
0005433989801	30670	Economy	13400.00
0005432150244	30670	Economy	13400.00
0005432433656	30670	Economy	13400.00
0005434082040	30670	Economy	13400.00
0005434068026	30670	Economy	13400.00
0005434067981	30670	Economy	13400.00
0005434067982	30670	Economy	13400.00
0005434068017	30670	Economy	13400.00
0005432433714	30670	Economy	13400.00
0005434068029	30670	Economy	13400.00
0005434068000	30670	Economy	13400.00
0005434067987	30670	Economy	13400.00
0005433989798	30670	Economy	13400.00
0005434068010	30670	Economy	13400.00
0005434068004	30670	Economy	13400.00
0005434067973	30670	Economy	14800.00
0005434068013	30670	Economy	14800.00
0005434067971	30670	Economy	14800.00
0005434082055	30670	Economy	14800.00
0005434068009	30670	Economy	14800.00
0005434068008	30670	Economy	14800.00
0005434067974	30670	Economy	13400.00
0005434082047	30670	Economy	13400.00
0005434082037	30670	Economy	13400.00
0005434067983	30670	Economy	13400.00
0005434082056	30670	Economy	13400.00
0005434067998	30670	Economy	13400.00
0005434068022	30670	Economy	13400.00
0005434082035	30670	Economy	13400.00
0005434082045	30670	Economy	13400.00
0005434067990	30670	Economy	13400.00
0005432150245	30670	Economy	13400.00
0005434068018	30670	Economy	13400.00
0005433989800	30670	Economy	13400.00
0005434067988	30670	Economy	13400.00
0005434068035	30670	Economy	13400.00
0005434067978	30670	Economy	13400.00
0005434082038	30670	Economy	13400.00
0005434068006	30670	Economy	13400.00
0005432433647	30670	Economy	13400.00
0005432150241	30670	Economy	13400.00
0005434082053	30670	Economy	13400.00
0005433989802	30670	Economy	13400.00
0005434068027	30670	Economy	13400.00
0005434068037	30670	Economy	13400.00
0005434067965	30670	Economy	13400.00
0005434067993	30670	Economy	13400.00
0005434067968	30670	Economy	13400.00
0005433989799	30670	Economy	13400.00
0005434068028	30670	Economy	13400.00
0005434082050	30670	Economy	13400.00
0005434067985	30670	Economy	13400.00
0005432150242	30670	Economy	13400.00
0005432433663	30670	Economy	13400.00
0005432150243	30670	Economy	13400.00
0005434067999	30670	Economy	13400.00
0005432150240	30670	Economy	13400.00
0005434082034	30670	Economy	13400.00
0005434067979	30670	Economy	13400.00
0005434068020	30670	Economy	13400.00
0005434082044	30670	Economy	13400.00
0005434068002	30670	Economy	13400.00
0005434068024	30670	Economy	13400.00
0005434068036	30670	Economy	13400.00
0005434067996	30670	Economy	13400.00
0005434067970	30670	Economy	13400.00
0005434068019	30670	Economy	13400.00
0005434067994	30670	Economy	13400.00
0005434082052	30670	Economy	13400.00
0005434082057	30670	Economy	13400.00
0005434067966	30670	Economy	13400.00
0005432150246	30670	Economy	13400.00
0005432186893	30670	Economy	13400.00
0005434082046	30670	Economy	13400.00
0005434068012	30670	Economy	13400.00
0005434067976	30670	Economy	13400.00
0005434082036	30670	Economy	13400.00
0005434082058	30670	Economy	13400.00
0005434068023	30670	Economy	13400.00
0005434068033	30670	Economy	13400.00
0005434068031	30670	Economy	13400.00
0005434068016	30670	Economy	13400.00
0005432433662	30670	Economy	13400.00
0005434067967	30670	Economy	13400.00
0005434067969	30670	Economy	13400.00
0005433685536	9049	Economy	19300.00
0005433686655	9049	Economy	19300.00
0005433685540	9049	Economy	19300.00
0005433686648	9049	Economy	17600.00
0005433687723	9049	Economy	17600.00
0005433686651	9049	Economy	17600.00
0005433685543	9049	Economy	17600.00
0005433687725	9049	Economy	17600.00
0005433685538	9049	Economy	17600.00
0005433686657	9049	Economy	17600.00
0005433686647	9049	Economy	17600.00
0005433686654	9049	Economy	17600.00
0005433685542	9049	Economy	17600.00
0005433685537	9049	Economy	17600.00
0005433685539	9049	Economy	17600.00
0005433686652	9049	Economy	17600.00
0005433686650	9049	Economy	17600.00
0005433686656	9049	Economy	17600.00
0005433687720	9049	Economy	17600.00
0005433687719	9049	Economy	17600.00
0005433687727	9049	Economy	17600.00
0005433685541	9049	Economy	17600.00
0005433686649	9049	Economy	17600.00
0005433687726	9049	Economy	17600.00
0005433687724	9049	Economy	17600.00
0005433686653	9049	Economy	17600.00
0005433687721	9049	Economy	17600.00
0005433687722	9049	Economy	17600.00
0005433527293	5544	Business	35300.00
0005434265111	5544	Business	35300.00
0005434265068	5544	Business	35300.00
0005434265211	5544	Business	35300.00
0005435766619	5544	Business	35300.00
0005435766617	5544	Business	35300.00
0005435462324	5544	Business	35300.00
0005435462426	5544	Business	35300.00
0005433529306	5544	Business	35300.00
0005435462434	5544	Business	35300.00
0005433527296	5544	Business	35300.00
0005435766636	5544	Business	35300.00
0005432535822	5544	Business	35300.00
0005435766658	5544	Business	35300.00
0005435462274	5544	Business	35300.00
0005434265066	5544	Business	35300.00
0005434831148	5544	Business	35300.00
0005435766632	5544	Business	35300.00
0005434265077	5544	Business	35300.00
0005435462387	5544	Business	35300.00
0005435766623	5544	Business	35300.00
0005434264977	5544	Business	35300.00
0005434265051	5544	Business	35300.00
0005435462325	5544	Business	35300.00
0005435462413	5544	Economy	12900.00
0005435462491	5544	Economy	12900.00
0005433527294	5544	Economy	12900.00
0005435720831	5544	Economy	11800.00
0005434265067	5544	Economy	11800.00
0005432140504	5544	Economy	11800.00
0005434264973	5544	Economy	11800.00
0005435766648	5544	Economy	11800.00
0005435462492	5544	Economy	11800.00
0005432140502	5544	Economy	11800.00
0005435766647	5544	Economy	11800.00
0005435725630	5544	Economy	11800.00
0005434264992	5544	Economy	11800.00
0005435766660	5544	Economy	11800.00
0005435766674	5544	Economy	11800.00
0005434265026	5544	Economy	11800.00
0005435766676	5544	Economy	11800.00
0005435735167	5544	Economy	11800.00
0005434265109	5544	Economy	11800.00
0005435462360	5544	Economy	11800.00
0005434265023	5544	Economy	11800.00
0005432535817	5544	Economy	11800.00
0005435725631	5544	Economy	11800.00
0005435766637	5544	Economy	11800.00
0005434265155	5544	Economy	11800.00
0005435462284	5544	Economy	11800.00
0005435766668	5544	Economy	11800.00
0005435735164	5544	Economy	11800.00
0005435462490	5544	Economy	11800.00
0005435462298	5544	Economy	11800.00
0005435720829	5544	Economy	11800.00
0005434265073	5544	Economy	11800.00
0005435766671	5544	Economy	11800.00
0005434265037	5544	Economy	11800.00
0005434265018	5544	Economy	11800.00
0005435462499	5544	Economy	11800.00
0005435462275	5544	Economy	11800.00
0005435766657	5544	Economy	11800.00
0005435720830	5544	Economy	11800.00
0005435723058	5544	Economy	11800.00
0005435766655	5544	Economy	11800.00
0005435766631	5544	Economy	11800.00
0005435766675	5544	Economy	11800.00
0005434265110	5544	Economy	11800.00
0005435462297	5544	Economy	11800.00
0005432140505	5544	Economy	11800.00
0005435766625	5544	Economy	11800.00
0005435766650	5544	Economy	11800.00
0005434265152	5544	Economy	11800.00
0005435462489	5544	Economy	11800.00
0005435766644	5544	Economy	11800.00
0005435766624	5544	Economy	11800.00
0005434265071	5544	Economy	11800.00
0005435766641	5544	Economy	11800.00
0005434265156	5544	Economy	11800.00
0005432535823	5544	Economy	11800.00
0005435766661	5544	Economy	11800.00
0005434265060	5544	Economy	11800.00
0005435766639	5544	Economy	11800.00
0005435766628	5544	Economy	11800.00
0005435462361	5544	Economy	11800.00
0005435766633	5544	Economy	11800.00
0005433527297	5544	Economy	11800.00
0005435766616	5544	Economy	11800.00
0005435462336	5544	Economy	11800.00
0005434264993	5544	Economy	11800.00
0005435462165	5544	Economy	11800.00
0005435723059	5544	Economy	11800.00
0005434831150	5544	Economy	11800.00
0005435462375	5544	Economy	11800.00
0005434265120	5544	Economy	11800.00
0005435766654	5544	Economy	11800.00
0005435766645	5544	Economy	11800.00
0005435462445	5544	Economy	11800.00
0005432535826	5544	Economy	11800.00
0005435462183	5544	Economy	11800.00
0005435766643	5544	Economy	11800.00
0005435766663	5544	Economy	11800.00
0005433529304	5544	Economy	11800.00
0005434265025	5544	Economy	11800.00
0005435725632	5544	Economy	11800.00
0005434265052	5544	Economy	11800.00
0005435766651	5544	Economy	11800.00
0005435766649	5544	Economy	11800.00
0005434265072	5544	Economy	11800.00
0005434265119	5544	Economy	11800.00
0005435766627	5544	Economy	11800.00
0005435462438	5544	Economy	11800.00
0005435462376	5544	Economy	12900.00
0005435735165	5544	Economy	12900.00
0005434265019	5544	Economy	11800.00
0005435766640	5544	Economy	11800.00
0005435766615	5544	Economy	12900.00
0005435766670	5544	Economy	11800.00
0005435766667	5544	Economy	11800.00
0005433529307	5544	Economy	11800.00
0005435766638	5544	Economy	11800.00
0005435735166	5544	Economy	11800.00
0005435766618	5544	Economy	11800.00
0005432140506	5544	Economy	11800.00
0005432535825	5544	Economy	11800.00
0005432140503	5544	Economy	11800.00
0005435766622	5544	Economy	11800.00
0005435766653	5544	Economy	11800.00
0005434265094	5544	Economy	11800.00
0005435766646	5544	Economy	11800.00
0005434265130	5544	Economy	11800.00
0005435766634	5544	Economy	11800.00
0005434264972	5544	Economy	11800.00
0005435766652	5544	Economy	11800.00
0005435462350	5544	Economy	11800.00
0005432140501	5544	Economy	11800.00
0005435462433	5544	Economy	11800.00
0005434265114	5544	Economy	11800.00
0005433529305	5544	Economy	11800.00
0005435766621	5544	Economy	11800.00
0005435766656	5544	Economy	11800.00
0005435462245	5544	Economy	11800.00
0005435766664	5544	Economy	11800.00
0005432535818	5544	Economy	11800.00
0005435766662	5544	Economy	11800.00
0005434265139	5544	Economy	11800.00
0005434831149	5544	Economy	11800.00
0005435462246	5544	Economy	11800.00
0005435766666	5544	Economy	11800.00
0005435462382	5544	Economy	11800.00
0005435766673	5544	Economy	11800.00
0005435766626	5544	Economy	11800.00
0005435725633	5544	Economy	11800.00
0005435766620	5544	Economy	11800.00
0005432535809	5544	Economy	11800.00
0005435766665	5544	Economy	11800.00
0005432535821	5544	Economy	11800.00
0005435766659	5544	Economy	11800.00
0005434265075	5544	Economy	11800.00
0005435723060	5544	Economy	11800.00
0005435766630	5544	Economy	11800.00
0005435766672	5544	Economy	11800.00
0005434265133	5544	Economy	11800.00
0005434265137	5544	Economy	11800.00
0005432140507	5544	Economy	11800.00
0005435462405	5544	Economy	11800.00
0005435766642	5544	Economy	11800.00
0005435735163	5544	Economy	11800.00
0005434265076	5544	Economy	11800.00
0005435766635	5544	Economy	11800.00
0005434265154	5544	Economy	11800.00
0005435766629	5544	Economy	11800.00
0005435722072	5544	Economy	11800.00
0005432140508	5544	Economy	11800.00
0005434265093	5544	Economy	11800.00
0005435462435	5544	Economy	11800.00
0005433527295	5544	Economy	11800.00
0005432535820	5544	Economy	11800.00
0005435725629	5544	Economy	11800.00
0005435462515	5544	Economy	11800.00
0005435766669	5544	Economy	11800.00
0005435462406	5544	Economy	11800.00
0005435765956	13466	Business	35300.00
0005435766118	13466	Business	35300.00
0005435462695	13466	Business	35300.00
0005435765925	13466	Business	35300.00
0005435766380	13466	Business	35300.00
0005434265330	13466	Business	35300.00
0005434265336	13466	Business	35300.00
0005435725596	13466	Business	35300.00
0005435766153	13466	Business	35300.00
0005435462720	13466	Business	35300.00
0005435462689	13466	Business	35300.00
0005434265332	13466	Business	35300.00
0005432535868	13466	Business	35300.00
0005435765851	13466	Business	35300.00
0005435766258	13466	Business	35300.00
0005432535869	13466	Business	35300.00
0005435462707	13466	Business	35300.00
0005435462686	13466	Business	35300.00
0005435765945	13466	Business	35300.00
0005435462693	13466	Business	35300.00
0005434265333	13466	Business	35300.00
0005435725571	13466	Business	35300.00
0005435462687	13466	Business	35300.00
0005435462706	13466	Business	35300.00
0005435725597	13466	Economy	12900.00
0005434265313	13466	Economy	12900.00
0005435462708	13466	Economy	12900.00
0005435462717	13466	Economy	11800.00
0005432194539	13466	Economy	11800.00
0005435462705	13466	Economy	11800.00
0005435725567	13466	Economy	11800.00
0005435725593	13466	Economy	11800.00
0005434265321	13466	Economy	11800.00
0005435766137	13466	Economy	11800.00
0005435462704	13466	Economy	11800.00
0005432535871	13466	Economy	11800.00
0005435462714	13466	Economy	11800.00
0005435462716	13466	Economy	11800.00
0005435766042	13466	Economy	11800.00
0005435766202	13466	Economy	11800.00
0005435462721	13466	Economy	11800.00
0005435735132	13466	Economy	11800.00
0005434265323	13466	Economy	11800.00
0005435735111	13466	Economy	11800.00
0005435766307	13466	Economy	11800.00
0005435462696	13466	Economy	11800.00
0005432194538	13466	Economy	11800.00
0005435723052	13466	Economy	11800.00
0005435766228	13466	Economy	11800.00
0005435722042	13466	Economy	11800.00
0005435462698	13466	Economy	11800.00
0005434265335	13466	Economy	11800.00
0005434265315	13466	Economy	11800.00
0005434265310	13466	Economy	11800.00
0005435766331	13466	Economy	11800.00
0005432194542	13466	Economy	11800.00
0005435735110	13466	Economy	11800.00
0005435766040	13466	Economy	11800.00
0005435725576	13466	Economy	11800.00
0005435462690	13466	Economy	11800.00
0005435766022	13466	Economy	11800.00
0005435766314	13466	Economy	11800.00
0005435462694	13466	Economy	11800.00
0005434265322	13466	Economy	11800.00
0005435462710	13466	Economy	11800.00
0005434831186	13466	Economy	11800.00
0005435766082	13466	Economy	11800.00
0005435725595	13466	Economy	11800.00
0005432535867	13466	Economy	11800.00
0005434831185	13466	Economy	11800.00
0005432194541	13466	Economy	11800.00
0005435766165	13466	Economy	11800.00
0005434265312	13466	Economy	11800.00
0005435462700	13466	Economy	11800.00
0005435723039	13466	Economy	11800.00
0005435766310	13466	Economy	11800.00
0005434265334	13466	Economy	11800.00
0005435725598	13466	Economy	11800.00
0005435462688	13466	Economy	11800.00
0005435725570	13466	Economy	11800.00
0005435725585	13466	Economy	11800.00
0005435766179	13466	Economy	11800.00
0005435462684	13466	Economy	11800.00
0005435462701	13466	Economy	11800.00
0005435765955	13466	Economy	11800.00
0005435766104	13466	Economy	11800.00
0005432535870	13466	Economy	11800.00
0005435725566	13466	Economy	11800.00
0005435766251	13466	Economy	11800.00
0005435462702	13466	Economy	11800.00
0005435766041	13466	Economy	11800.00
0005434831183	13466	Economy	11800.00
0005435766103	13466	Economy	11800.00
0005435723051	13466	Economy	11800.00
0005435765850	13466	Economy	11800.00
0005434265331	13466	Economy	11800.00
0005435725590	13466	Economy	11800.00
0005435735112	13466	Economy	12900.00
0005435723049	13466	Economy	12900.00
0005435766308	13466	Economy	12900.00
0005435462715	13466	Economy	11800.00
0005435462718	13466	Economy	11800.00
0005432535866	13466	Economy	11800.00
0005435766313	13466	Economy	11800.00
0005435766126	13466	Economy	11800.00
0005435766053	13466	Economy	11800.00
0005434831187	13466	Economy	11800.00
0005435765744	13466	Economy	11800.00
0005435462685	13466	Economy	11800.00
0005435766196	13466	Economy	11800.00
0005435462709	13466	Economy	11800.00
0005434265329	13466	Economy	11800.00
0005435766057	13466	Economy	11800.00
0005435735135	13466	Economy	11800.00
0005435462712	13466	Economy	11800.00
0005435766081	13466	Economy	11800.00
0005435766221	13466	Economy	11800.00
0005434265314	13466	Economy	11800.00
0005434265324	13466	Economy	11800.00
0005434265319	13466	Economy	11800.00
0005435766125	13466	Economy	11800.00
0005435462722	13466	Economy	11800.00
0005435462699	13466	Economy	11800.00
0005435725574	13466	Economy	11800.00
0005435766208	13466	Economy	11800.00
0005435766178	13466	Economy	11800.00
0005435725575	13466	Economy	11800.00
0005435722041	13466	Economy	11800.00
0005435766008	13466	Economy	11800.00
0005435735131	13466	Economy	11800.00
0005435765983	13466	Economy	11800.00
0005435462691	13466	Economy	11800.00
0005435766045	13466	Economy	11800.00
0005435462703	13466	Economy	11800.00
0005435766034	13466	Economy	11800.00
0005435765954	13466	Economy	11800.00
0005435766033	13466	Economy	11800.00
0005435462711	13466	Economy	11800.00
0005434265320	13466	Economy	11800.00
0005435462692	13466	Economy	11800.00
0005434265325	13466	Economy	11800.00
0005434265316	13466	Economy	11800.00
0005434265311	13466	Economy	11800.00
0005435722047	13466	Economy	11800.00
0005434265317	13466	Economy	11800.00
0005434265328	13466	Economy	11800.00
0005435766254	13466	Economy	11800.00
0005434265327	13466	Economy	11800.00
0005432194540	13466	Economy	11800.00
0005434831184	13466	Economy	11800.00
0005435462697	13466	Economy	11800.00
0005434265326	13466	Economy	11800.00
0005435462713	13466	Economy	11800.00
0005435722040	13466	Economy	11800.00
0005435462719	13466	Economy	11800.00
0005434265318	13466	Economy	11800.00
0005435766177	13466	Economy	11800.00
0005434602890	18696	Economy	3300.00
0005434604895	18699	Economy	3300.00
0005434513597	18699	Economy	3300.00
0005434604889	18699	Economy	3300.00
0005434604886	18699	Economy	3300.00
0005434514984	18699	Economy	3300.00
0005434513595	18699	Economy	3300.00
0005434604896	18699	Economy	3300.00
0005434604898	18699	Economy	3300.00
0005434514985	18699	Economy	3300.00
0005434513596	18699	Economy	3300.00
0005434602912	19212	Economy	3300.00
0005434602916	19212	Economy	3300.00
0005434602914	19212	Economy	3300.00
0005434602915	19212	Economy	3300.00
0005434602913	19212	Economy	3300.00
0005434602911	19212	Economy	3300.00
0005433008674	1848	Business	48700.00
0005433008786	1848	Business	48700.00
0005433008634	1848	Business	48700.00
0005433008673	1848	Business	48700.00
0005433285256	1848	Business	48700.00
0005433008701	1848	Business	48700.00
0005433810578	1848	Business	48700.00
0005433008570	1848	Business	48700.00
0005433008572	1848	Business	48700.00
0005433008660	1848	Business	48700.00
0005433285253	1848	Economy	16200.00
0005433008675	1848	Economy	16200.00
0005433285268	1848	Economy	16200.00
0005433285393	1848	Economy	16200.00
0005433008557	1848	Economy	16200.00
0005433008593	1848	Economy	16200.00
0005433285204	1848	Economy	16200.00
0005433008546	1848	Economy	16200.00
0005433285298	1848	Economy	16200.00
0005433285248	1848	Economy	16200.00
0005433008524	1848	Economy	17900.00
0005433285313	1848	Economy	17900.00
0005433008409	1848	Economy	17900.00
0005433008551	1848	Economy	17900.00
0005433285259	1848	Economy	17900.00
0005433285208	1848	Economy	16200.00
0005433285235	1848	Economy	16200.00
0005433008622	1848	Economy	16200.00
0005433008537	1848	Economy	16200.00
0005433810579	1848	Economy	16200.00
0005433008702	1848	Economy	16200.00
0005433285257	1848	Economy	16200.00
0005433008540	1848	Economy	16200.00
0005433008451	1848	Economy	16200.00
0005433285265	1848	Economy	16200.00
0005433008410	1848	Economy	16200.00
0005433008430	1848	Economy	16200.00
0005433285215	1848	Economy	16200.00
0005433285140	1848	Economy	16200.00
0005433008483	1848	Economy	16200.00
0005432295899	1848	Economy	16200.00
0005433285364	1848	Economy	16200.00
0005433008387	1848	Economy	16200.00
0005433008428	1848	Economy	16200.00
0005433285249	1848	Economy	16200.00
0005433008567	1848	Economy	16200.00
0005433285114	1848	Economy	16200.00
0005433008407	1848	Economy	16200.00
0005433008406	1848	Economy	16200.00
0005433008516	1848	Economy	16200.00
0005433008629	1848	Economy	16200.00
0005433285343	1848	Economy	16200.00
0005433285289	1848	Economy	16200.00
0005433285245	1848	Economy	16200.00
0005433008531	1848	Economy	16200.00
0005432295898	1848	Economy	16200.00
0005433285159	1848	Economy	16200.00
0005433008529	1848	Economy	16200.00
0005433008328	1848	Economy	16200.00
0005433008620	1848	Economy	16200.00
0005433008621	1848	Economy	16200.00
0005433008497	1848	Economy	16200.00
0005433008566	1848	Economy	16200.00
0005432295897	1848	Economy	16200.00
0005433008431	1848	Economy	16200.00
0005433008596	1848	Economy	16200.00
0005433008617	1848	Economy	16200.00
0005433285141	1848	Economy	16200.00
0005433008611	1848	Economy	16200.00
0005433008539	1848	Economy	16200.00
0005433285264	1848	Economy	16200.00
0005433285363	1848	Economy	16200.00
0005433285102	1848	Economy	16200.00
0005433008785	1848	Economy	16200.00
0005433285418	1848	Economy	16200.00
0005433008388	1848	Economy	16200.00
0005433008573	1848	Economy	16200.00
0005433285326	1848	Economy	16200.00
0005433285098	1848	Economy	16200.00
0005433008427	1848	Economy	16200.00
0005433285250	1848	Economy	16200.00
0005433008484	1848	Economy	16200.00
0005433008602	1848	Economy	16200.00
0005433008485	1848	Economy	16200.00
0005433008594	1848	Economy	16200.00
0005433285504	22543	Business	48700.00
0005433008904	22543	Business	48700.00
0005433810520	22543	Business	48700.00
0005433008916	22543	Business	48700.00
0005433285514	22543	Business	48700.00
0005433285497	22543	Business	48700.00
0005433008928	22543	Business	48700.00
0005433008907	22543	Business	48700.00
0005433008933	22543	Business	48700.00
0005433008927	22543	Business	48700.00
0005433008926	22543	Economy	16200.00
0005433008896	22543	Economy	16200.00
0005433008899	22543	Economy	16200.00
0005433285496	22543	Economy	16200.00
0005433008920	22543	Economy	16200.00
0005433008910	22543	Economy	16200.00
0005433008914	22543	Economy	16200.00
0005433285506	22543	Economy	16200.00
0005433008906	22543	Economy	16200.00
0005433285490	22543	Economy	16200.00
0005433008908	22543	Economy	17900.00
0005433285512	22543	Economy	17900.00
0005433285491	22543	Economy	17900.00
0005433008937	22543	Economy	17900.00
0005433285507	22543	Economy	17900.00
0005433810519	22543	Economy	16200.00
0005433008917	22543	Economy	16200.00
0005433285510	22543	Economy	16200.00
0005433008915	22543	Economy	16200.00
0005433008892	22543	Economy	16200.00
0005433008930	22543	Economy	16200.00
0005433285488	22543	Economy	16200.00
0005433008901	22543	Economy	16200.00
0005433285500	22543	Economy	16200.00
0005433285515	22543	Economy	16200.00
0005433008923	22543	Economy	16200.00
0005433008898	22543	Economy	16200.00
0005433285495	22543	Economy	16200.00
0005433285494	22543	Economy	16200.00
0005433008934	22543	Economy	16200.00
0005433285505	22543	Economy	16200.00
0005433008911	22543	Economy	16200.00
0005433008919	22543	Economy	16200.00
0005433008929	22543	Economy	16200.00
0005433008913	22543	Economy	16200.00
0005433008932	22543	Economy	16200.00
0005433810518	22543	Economy	16200.00
0005433008900	22543	Economy	16200.00
0005433008895	22543	Economy	16200.00
0005433008925	22543	Economy	16200.00
0005433008931	22543	Economy	16200.00
0005433285493	22543	Economy	16200.00
0005433008921	22543	Economy	16200.00
0005433008903	22543	Economy	16200.00
0005433285511	22543	Economy	16200.00
0005433008935	22543	Economy	16200.00
0005433285509	22543	Economy	16200.00
0005433285501	22543	Economy	16200.00
0005433008936	22543	Economy	16200.00
0005433008891	22543	Economy	16200.00
0005433285508	22543	Economy	16200.00
0005433285516	22543	Economy	16200.00
0005433285492	22543	Economy	16200.00
0005433285503	22543	Economy	16200.00
0005433285513	22543	Economy	16200.00
0005433285517	22543	Economy	16200.00
0005433008922	22543	Economy	16200.00
0005433008893	22543	Economy	16200.00
0005433008909	22543	Economy	16200.00
0005433008890	22543	Economy	16200.00
0005433008918	22543	Economy	16200.00
0005433008924	22543	Economy	16200.00
0005433285499	22543	Economy	16200.00
0005433285489	22543	Economy	16200.00
0005433285498	22543	Economy	16200.00
0005433008902	22543	Economy	16200.00
0005433008897	22543	Economy	16200.00
0005433008894	22543	Economy	16200.00
0005433008912	22543	Economy	16200.00
0005433008905	22543	Economy	16200.00
0005433285502	22543	Economy	16200.00
0005432755092	25329	Business	83800.00
0005432755088	25329	Business	83800.00
0005432755093	25329	Business	83800.00
0005432756868	25329	Economy	27900.00
0005432756864	25329	Economy	27900.00
0005432755090	25329	Economy	27900.00
0005432755089	25329	Economy	27900.00
0005432755094	25329	Economy	27900.00
0005434152772	25329	Economy	27900.00
0005432756862	25329	Economy	27900.00
0005432756866	25329	Economy	27900.00
0005432755091	25329	Economy	27900.00
0005432756865	25329	Economy	27900.00
0005434153524	25329	Economy	27900.00
0005432755095	25329	Economy	27900.00
0005432756867	25329	Economy	27900.00
0005434152773	25329	Economy	27900.00
0005434152775	25329	Economy	27900.00
0005434153527	25329	Economy	27900.00
0005432756863	25329	Economy	27900.00
0005432755096	25329	Economy	27900.00
0005432755087	25329	Economy	27900.00
0005432756861	25329	Economy	27900.00
0005433847115	5581	Business	99800.00
0005433847113	5581	Business	99800.00
0005432081554	5581	Business	99800.00
0005433847136	5581	Business	99800.00
0005433847148	5581	Business	99800.00
0005433847104	5581	Business	99800.00
0005432081553	5581	Business	99800.00
0005433847110	5581	Business	99800.00
0005433847135	5581	Business	99800.00
0005433847117	5581	Business	99800.00
0005433847106	5581	Business	99800.00
0005433847128	5581	Business	99800.00
0005433847139	5581	Business	99800.00
0005433847098	5581	Business	99800.00
0005433847107	5581	Business	99800.00
0005433847143	5581	Business	99800.00
0005433815415	5581	Business	99800.00
0005433847133	5581	Economy	33300.00
0005435282373	5581	Economy	33300.00
0005435282461	5581	Economy	33300.00
0005433847116	5581	Economy	33300.00
0005434173527	5581	Economy	33300.00
0005435282501	5581	Economy	33300.00
0005434173513	5581	Economy	33300.00
0005433847112	5581	Economy	33300.00
0005434173524	5581	Economy	33300.00
0005433847152	5581	Economy	33300.00
0005433847102	5581	Economy	33300.00
0005435282484	5581	Economy	36600.00
0005433847125	5581	Economy	36600.00
0005433847119	5581	Economy	36600.00
0005433847101	5581	Economy	33300.00
0005433847124	5581	Economy	33300.00
0005433847114	5581	Economy	33300.00
0005435282436	5581	Economy	33300.00
0005435282415	5581	Economy	33300.00
0005435282486	5581	Economy	33300.00
0005432081555	5581	Economy	33300.00
0005433847155	5581	Economy	33300.00
0005433815418	5581	Economy	33300.00
0005433847111	5581	Economy	33300.00
0005433847130	5581	Economy	33300.00
0005433847109	5581	Economy	33300.00
0005434173494	5581	Economy	33300.00
0005433847138	5581	Economy	33300.00
0005435282439	5581	Economy	33300.00
0005433847105	5581	Economy	33300.00
0005433847134	5581	Economy	33300.00
0005433847140	5581	Economy	33300.00
0005435282438	5581	Economy	33300.00
0005432081557	5581	Economy	33300.00
0005435282406	5581	Economy	33300.00
0005433847103	5581	Economy	33300.00
0005435282502	5581	Economy	33300.00
0005435282458	5581	Economy	33300.00
0005433847131	5581	Economy	33300.00
0005433847100	5581	Economy	33300.00
0005435282399	5581	Economy	33300.00
0005433847149	5581	Economy	33300.00
0005435282485	5581	Economy	33300.00
0005433847129	5581	Economy	33300.00
0005435282416	5581	Economy	33300.00
0005434173498	5581	Economy	33300.00
0005433847132	5581	Economy	33300.00
0005433847121	5581	Economy	33300.00
0005435282491	5581	Economy	33300.00
0005435282462	5581	Economy	33300.00
0005433847151	5581	Economy	33300.00
0005433847142	5581	Economy	33300.00
0005433847154	5581	Economy	33300.00
0005432081556	5581	Economy	33300.00
0005435282513	5581	Economy	33300.00
0005433847146	5581	Economy	33300.00
0005433847127	5581	Economy	33300.00
0005433815417	5581	Economy	33300.00
0005433847118	5581	Economy	33300.00
0005433847122	5581	Economy	33300.00
0005434173493	5581	Economy	33300.00
0005433847108	5581	Economy	33300.00
0005433847147	5581	Economy	33300.00
0005433847126	5581	Economy	33300.00
0005433847120	5581	Economy	33300.00
0005433847153	5581	Economy	33300.00
0005433815414	5581	Economy	33300.00
0005432081558	5581	Economy	33300.00
0005433847150	5581	Economy	33300.00
0005433847145	5581	Economy	33300.00
0005433815416	5581	Economy	33300.00
0005433847099	5581	Economy	33300.00
0005433847123	5581	Economy	33300.00
0005432081559	5581	Economy	33300.00
0005433847141	5581	Economy	33300.00
0005433815419	5581	Economy	33300.00
0005433847144	5581	Economy	33300.00
0005433847137	5581	Economy	33300.00
0005435282463	5581	Economy	33300.00
0005433847156	5581	Economy	33300.00
0005433846560	13869	Business	99800.00
0005433846445	13869	Business	99800.00
0005434173551	13869	Business	99800.00
0005435282686	13869	Business	99800.00
0005433846677	13869	Business	99800.00
0005433846780	13869	Business	99800.00
0005433846649	13869	Business	99800.00
0005435282674	13869	Business	99800.00
0005434173550	13869	Business	99800.00
0005433846611	13869	Business	99800.00
0005435282680	13869	Business	99800.00
0005435282700	13869	Business	99800.00
0005435282702	13869	Business	99800.00
0005433846834	13869	Business	99800.00
0005433846515	13869	Business	99800.00
0005433846461	13869	Business	99800.00
0005432003722	13869	Business	99800.00
0005435282689	13869	Business	99800.00
0005433846630	13869	Economy	33300.00
0005435282675	13869	Economy	33300.00
0005433846846	13869	Economy	33300.00
0005433846485	13869	Economy	33300.00
0005435282699	13869	Economy	33300.00
0005433846773	13869	Economy	33300.00
0005435282696	13869	Economy	33300.00
0005433846593	13869	Economy	33300.00
0005433846658	13869	Economy	33300.00
0005433846556	13869	Economy	33300.00
0005433846557	13869	Economy	33300.00
0005433846568	13869	Economy	33300.00
0005433846760	13869	Economy	36600.00
0005433846790	13869	Economy	36600.00
0005433846601	13869	Economy	36600.00
0005433846585	13869	Economy	36600.00
0005433846414	13869	Economy	33300.00
0005435282681	13869	Economy	33300.00
0005433846401	13869	Economy	33300.00
0005435282691	13869	Economy	33300.00
0005433846602	13869	Economy	33300.00
0005433846691	13869	Economy	33300.00
0005435282684	13869	Economy	33300.00
0005432003725	13869	Economy	33300.00
0005433846584	13869	Economy	33300.00
0005433846779	13869	Economy	33300.00
0005435282677	13869	Economy	33300.00
0005433846343	13869	Economy	33300.00
0005434173549	13869	Economy	33300.00
0005435282701	13869	Economy	33300.00
0005435282690	13869	Economy	33300.00
0005434173547	13869	Economy	33300.00
0005433846402	13869	Economy	33300.00
0005433846701	13869	Economy	33300.00
0005433846627	13869	Economy	33300.00
0005435282673	13869	Economy	33300.00
0005433846462	13869	Economy	33300.00
0005433846609	13869	Economy	33300.00
0005435282678	13869	Economy	33300.00
0005433815381	13869	Economy	33300.00
0005435282698	13869	Economy	33300.00
0005433815382	13869	Economy	33300.00
0005433846555	13869	Economy	33300.00
0005433846628	13869	Economy	33300.00
0005435282688	13869	Economy	33300.00
0005433846909	13869	Economy	33300.00
0005433846574	13869	Economy	33300.00
0005433846487	13869	Economy	33300.00
0005433846794	13869	Economy	33300.00
0005433846745	13869	Economy	33300.00
0005433846583	13869	Economy	33300.00
0005435282685	13869	Economy	33300.00
0005433846539	13869	Economy	33300.00
0005435282694	13869	Economy	33300.00
0005432003724	13869	Economy	33300.00
0005435282693	13869	Economy	33300.00
0005433846344	13869	Economy	33300.00
0005433846626	13869	Economy	33300.00
0005435282676	13869	Economy	33300.00
0005433846759	13869	Economy	33300.00
0005435282687	13869	Economy	33300.00
0005433846579	13869	Economy	33300.00
0005433846413	13869	Economy	33300.00
0005435282692	13869	Economy	33300.00
0005433846789	13869	Economy	33300.00
0005432003723	13869	Economy	33300.00
0005433846441	13869	Economy	33300.00
0005435282682	13869	Economy	33300.00
0005435282697	13869	Economy	33300.00
0005433846578	13869	Economy	33300.00
0005433846580	13869	Economy	33300.00
0005433846422	13869	Economy	33300.00
0005433846526	13869	Economy	33300.00
0005435282683	13869	Economy	33300.00
0005435282695	13869	Economy	33300.00
0005433846440	13869	Economy	33300.00
0005435282679	13869	Economy	33300.00
0005433846716	13869	Economy	33300.00
0005433846400	13869	Economy	33300.00
0005433846704	13869	Economy	33300.00
0005433846463	13869	Economy	33300.00
0005434173548	13869	Economy	33300.00
0005433846540	13869	Economy	33300.00
0005434620744	7823	Economy	16600.00
0005434620746	7823	Economy	15100.00
0005434620742	7823	Economy	15100.00
0005435332272	7823	Economy	15100.00
0005432112531	7823	Economy	15100.00
0005434620743	7823	Economy	15100.00
0005434620737	7823	Economy	15100.00
0005434620739	7823	Economy	15100.00
0005434620730	7823	Economy	15100.00
0005434620734	7823	Economy	15100.00
0005435332282	7823	Economy	15100.00
0005434620747	7823	Economy	15100.00
0005434620729	7823	Economy	15100.00
0005435332355	7823	Economy	15100.00
0005434620728	7823	Economy	15100.00
0005434620736	7823	Economy	15100.00
0005434620738	7823	Economy	15100.00
0005435332345	7823	Economy	15100.00
0005434620741	7823	Economy	15100.00
0005435332331	7823	Economy	15100.00
0005435332281	7823	Economy	15100.00
0005434620731	7823	Economy	15100.00
0005435332273	7823	Economy	15100.00
0005434620727	7823	Economy	15100.00
0005434620732	7823	Economy	15100.00
0005435332325	7823	Economy	15100.00
0005434620740	7823	Economy	15100.00
0005432112532	7823	Economy	15100.00
0005434620733	7823	Economy	15100.00
0005434620735	7823	Economy	15100.00
0005434620745	7823	Economy	15100.00
0005435332324	7823	Economy	15100.00
0005434620582	32950	Economy	16600.00
0005434620606	32950	Economy	16600.00
0005434620587	32950	Economy	15100.00
0005435332407	32950	Economy	15100.00
0005435332403	32950	Economy	15100.00
0005435332409	32950	Economy	15100.00
0005434620547	32950	Economy	15100.00
0005434620607	32950	Economy	15100.00
0005435332411	32950	Economy	15100.00
0005434620657	32950	Economy	15100.00
0005434620608	32950	Economy	15100.00
0005434620553	32950	Economy	15100.00
0005434620434	32950	Economy	15100.00
0005434620556	32950	Economy	15100.00
0005434620551	32950	Economy	15100.00
0005434620595	32950	Economy	15100.00
0005434620552	32950	Economy	15100.00
0005435332405	32950	Economy	15100.00
0005434620605	32950	Economy	15100.00
0005434620536	32950	Economy	15100.00
0005434620588	32950	Economy	15100.00
0005435332404	32950	Economy	15100.00
0005434620577	32950	Economy	15100.00
0005435332406	32950	Economy	15100.00
0005434620537	32950	Economy	15100.00
0005435332408	32950	Economy	15100.00
0005435332410	32950	Economy	15100.00
0005434620555	32950	Economy	15100.00
0005434620494	32950	Economy	15100.00
0005434620545	32950	Economy	15100.00
0005434620583	32950	Economy	15100.00
0005434620493	32950	Economy	15100.00
0005434620658	32950	Economy	15100.00
0005434620578	32950	Economy	15100.00
0005434620581	32950	Economy	15100.00
0005435785605	4316	Business	38000.00
0005435937369	4316	Business	38000.00
0005435785594	4316	Business	38000.00
0005435785595	4316	Business	38000.00
0005434994090	4316	Business	38000.00
0005434994091	4316	Business	38000.00
0005434994086	4316	Business	38000.00
0005435785580	4316	Business	38000.00
0005435937377	4316	Business	38000.00
0005435785613	4316	Business	38000.00
0005435937373	4316	Economy	12700.00
0005435787368	4316	Economy	12700.00
0005435785610	4316	Economy	12700.00
0005434994088	4316	Economy	12700.00
0005432190656	4316	Economy	12700.00
0005435785607	4316	Economy	13900.00
0005435785604	4316	Economy	13900.00
0005435918645	4316	Economy	13900.00
0005434994095	4316	Economy	12700.00
0005432190657	4316	Economy	12700.00
0005432190655	4316	Economy	12700.00
0005435785589	4316	Economy	12700.00
0005432190654	4316	Economy	12700.00
0005435785593	4316	Economy	12700.00
0005435787370	4316	Economy	12700.00
0005434994089	4316	Economy	12700.00
0005435918644	4316	Economy	12700.00
0005435785609	4316	Economy	12700.00
0005435785579	4316	Economy	12700.00
0005435785585	4316	Economy	12700.00
0005434994085	4316	Economy	12700.00
0005435785591	4316	Economy	12700.00
0005435785606	4316	Economy	12700.00
0005435785600	4316	Economy	12700.00
0005435787369	4316	Economy	12700.00
0005435785597	4316	Economy	12700.00
0005435785587	4316	Economy	12700.00
0005435785586	4316	Economy	12700.00
0005434994087	4316	Economy	12700.00
0005435785598	4316	Economy	12700.00
0005435785578	4316	Economy	12700.00
0005435937367	4316	Economy	12700.00
0005435918635	4316	Economy	12700.00
0005435785602	4316	Economy	12700.00
0005435785603	4316	Economy	12700.00
0005435785596	4316	Economy	12700.00
0005435785612	4316	Economy	12700.00
0005434994093	4316	Economy	12700.00
0005434994094	4316	Economy	12700.00
0005435918657	4316	Economy	12700.00
0005435785583	4316	Economy	12700.00
0005435918656	4316	Economy	12700.00
0005435785611	4316	Economy	12700.00
0005435785581	4316	Economy	12700.00
0005435785590	4316	Economy	12700.00
0005435785599	4316	Economy	12700.00
0005435785584	4316	Economy	12700.00
0005434994092	4316	Economy	12700.00
0005435785592	4316	Economy	12700.00
0005435785608	4316	Economy	12700.00
0005435785582	4316	Economy	12700.00
0005435785588	4316	Economy	12700.00
0005435785601	4316	Economy	12700.00
0005435937376	4316	Economy	12700.00
0005435785271	27285	Business	38000.00
0005435918690	27285	Business	38000.00
0005435785206	27285	Business	38000.00
0005435785192	27285	Business	38000.00
0005435937404	27285	Business	38000.00
0005434993976	27285	Business	38000.00
0005435785311	27285	Business	38000.00
0005435918686	27285	Business	38000.00
0005435785257	27285	Economy	12700.00
0005435785351	27285	Economy	12700.00
0005435785175	27285	Economy	12700.00
0005434993982	27285	Economy	12700.00
0005435918687	27285	Economy	12700.00
0005435918688	27285	Economy	13900.00
0005435785262	27285	Economy	13900.00
0005435937405	27285	Economy	12700.00
0005435937407	27285	Economy	12700.00
0005435785291	27285	Economy	12700.00
0005435785306	27285	Economy	12700.00
0005435785190	27285	Economy	12700.00
0005435937403	27285	Economy	12700.00
0005435937409	27285	Economy	12700.00
0005435918689	27285	Economy	12700.00
0005432195706	27285	Economy	12700.00
0005435785352	27285	Economy	12700.00
0005435785184	27285	Economy	12700.00
0005435785358	27285	Economy	12700.00
0005435785178	27285	Economy	12700.00
0005434993975	27285	Economy	12700.00
0005435937402	27285	Economy	12700.00
0005432195705	27285	Economy	12700.00
0005435785147	27285	Economy	12700.00
0005435785357	27285	Economy	12700.00
0005435937406	27285	Economy	12700.00
0005435785258	27285	Economy	12700.00
0005435785159	27285	Economy	12700.00
0005435787350	27285	Economy	12700.00
0005434993977	27285	Economy	12700.00
0005435785307	27285	Economy	12700.00
0005435937408	27285	Economy	12700.00
0005435785292	27285	Economy	12700.00
0005435787343	27285	Economy	12700.00
0005435785272	27285	Economy	12700.00
0005435785237	27285	Economy	12700.00
0005434993965	27285	Economy	12700.00
0005435785205	27285	Economy	12700.00
0005435785305	27285	Economy	12700.00
0005435785209	27285	Economy	12700.00
0005435785185	27285	Economy	12700.00
0005432195707	27285	Economy	12700.00
0005434993981	27285	Economy	12700.00
0005435785395	27285	Economy	12700.00
0005435785189	27285	Economy	12700.00
0005432146213	19891	Economy	12800.00
0005432146212	19891	Economy	12800.00
0005432568064	4715	Business	40900.00
0005432568086	4715	Business	40900.00
0005432460233	4715	Business	40900.00
0005432568074	4715	Business	40900.00
0005434082072	4715	Business	40900.00
0005432460205	4715	Business	40900.00
0005432460237	4715	Business	40900.00
0005434082089	4715	Business	40900.00
0005433726121	4715	Business	40900.00
0005432568069	4715	Business	40900.00
0005432568054	4715	Business	40900.00
0005432568083	4715	Business	40900.00
0005433451633	4715	Business	40900.00
0005432170437	4715	Business	40900.00
0005432460190	4715	Business	40900.00
0005434082071	4715	Business	40900.00
0005432460189	4715	Business	40900.00
0005432460186	4715	Business	40900.00
0005432460192	4715	Business	40900.00
0005432460188	4715	Business	40900.00
0005432568080	4715	Economy	15000.00
0005432568038	4715	Economy	15000.00
0005432568059	4715	Economy	15000.00
0005432460220	4715	Economy	15000.00
0005432568060	4715	Economy	13600.00
0005434082068	4715	Economy	13600.00
0005434559101	4715	Economy	13600.00
0005434082081	4715	Economy	13600.00
0005432460235	4715	Economy	13600.00
0005432460236	4715	Economy	13600.00
0005432568044	4715	Economy	13600.00
0005434082078	4715	Economy	13600.00
0005432460219	4715	Economy	13600.00
0005432568076	4715	Economy	13600.00
0005432568031	4715	Economy	13600.00
0005432568028	4715	Economy	13600.00
0005432170433	4715	Economy	13600.00
0005432568046	4715	Economy	13600.00
0005432568029	4715	Economy	13600.00
0005432186894	4715	Economy	13600.00
0005432460206	4715	Economy	13600.00
0005432460217	4715	Economy	13600.00
0005432568051	4715	Economy	13600.00
0005434082087	4715	Economy	13600.00
0005434082066	4715	Economy	13600.00
0005434082083	4715	Economy	13600.00
0005432568041	4715	Economy	13600.00
0005434082059	4715	Economy	13600.00
0005434082084	4715	Economy	13600.00
0005434082067	4715	Economy	13600.00
0005432571350	4715	Economy	13600.00
0005432571349	4715	Economy	13600.00
0005432568035	4715	Economy	13600.00
0005432460218	4715	Economy	13600.00
0005432568058	4715	Economy	13600.00
0005432568089	4715	Economy	13600.00
0005432460187	4715	Economy	13600.00
0005432460225	4715	Economy	13600.00
0005432568087	4715	Economy	13600.00
0005432568053	4715	Economy	13600.00
0005432460209	4715	Economy	13600.00
0005432460230	4715	Economy	13600.00
0005432460207	4715	Economy	13600.00
0005432571346	4715	Economy	13600.00
0005433451634	4715	Economy	13600.00
0005432460234	4715	Economy	13600.00
0005432460228	4715	Economy	13600.00
0005432460193	4715	Economy	13600.00
0005432568061	4715	Economy	13600.00
0005432568085	4715	Economy	13600.00
0005432460212	4715	Economy	13600.00
0005432460201	4715	Economy	13600.00
0005432568042	4715	Economy	13600.00
0005432460227	4715	Economy	13600.00
0005432568072	4715	Economy	13600.00
0005432568088	4715	Economy	13600.00
0005432460197	4715	Economy	13600.00
0005432568052	4715	Economy	13600.00
0005432568030	4715	Economy	13600.00
0005432571348	4715	Economy	13600.00
0005432568032	4715	Economy	13600.00
0005434082088	4715	Economy	13600.00
0005433726119	4715	Economy	13600.00
0005432568081	4715	Economy	13600.00
0005432460226	4715	Economy	13600.00
0005434082073	4715	Economy	13600.00
0005432460231	4715	Economy	13600.00
0005432568066	4715	Economy	13600.00
0005434082074	4715	Economy	13600.00
0005432568062	4715	Economy	13600.00
0005432568043	4715	Economy	13600.00
0005432460191	4715	Economy	13600.00
0005432568048	4715	Economy	13600.00
0005432460213	4715	Economy	13600.00
0005432460232	4715	Economy	13600.00
0005432568039	4715	Economy	13600.00
0005432568055	4715	Economy	13600.00
0005432568078	4715	Economy	13600.00
0005432568068	4715	Economy	13600.00
0005432460203	4715	Economy	13600.00
0005434082080	4715	Economy	13600.00
0005432460223	4715	Economy	13600.00
0005434082060	4715	Economy	13600.00
0005432460196	4715	Economy	13600.00
0005432568040	4715	Economy	13600.00
0005434082062	4715	Economy	13600.00
0005434082070	4715	Economy	15000.00
0005434559100	4715	Economy	13600.00
0005434082069	4715	Economy	15000.00
0005432170435	4715	Economy	13600.00
0005434082085	4715	Economy	15000.00
0005432568037	4715	Economy	13600.00
0005432568047	4715	Economy	13600.00
0005432460202	4715	Economy	13600.00
0005432460229	4715	Economy	13600.00
0005432568036	4715	Economy	13600.00
0005432460215	4715	Economy	13600.00
0005432568034	4715	Economy	13600.00
0005432568084	4715	Economy	13600.00
0005432460195	4715	Economy	13600.00
0005432568049	4715	Economy	13600.00
0005432170434	4715	Economy	13600.00
0005434082061	4715	Economy	13600.00
0005432568079	4715	Economy	13600.00
0005432460221	4715	Economy	13600.00
0005432568077	4715	Economy	13600.00
0005432568082	4715	Economy	13600.00
0005432170431	4715	Economy	13600.00
0005434082082	4715	Economy	13600.00
0005432170436	4715	Economy	13600.00
0005432568070	4715	Economy	13600.00
0005432460216	4715	Economy	13600.00
0005432568056	4715	Economy	13600.00
0005433452753	4715	Economy	13600.00
0005434082065	4715	Economy	13600.00
0005432460204	4715	Economy	13600.00
0005432460199	4715	Economy	13600.00
0005434082064	4715	Economy	13600.00
0005432460214	4715	Economy	13600.00
0005432186895	4715	Economy	13600.00
0005434082079	4715	Economy	13600.00
0005434082086	4715	Economy	13600.00
0005432460200	4715	Economy	13600.00
0005432571347	4715	Economy	13600.00
0005432568071	4715	Economy	13600.00
0005432568067	4715	Economy	13600.00
0005432568033	4715	Economy	13600.00
0005432460224	4715	Economy	13600.00
0005432568057	4715	Economy	13600.00
0005433726120	4715	Economy	13600.00
0005432460194	4715	Economy	13600.00
0005434082077	4715	Economy	13600.00
0005433451635	4715	Economy	13600.00
0005432568065	4715	Economy	13600.00
0005432568073	4715	Economy	13600.00
0005432568063	4715	Economy	13600.00
0005433452754	4715	Economy	13600.00
0005434082063	4715	Economy	13600.00
0005432186896	4715	Economy	13600.00
0005432170432	4715	Economy	13600.00
0005432568050	4715	Economy	13600.00
0005432460211	4715	Economy	13600.00
0005432568045	4715	Economy	13600.00
0005432460185	4715	Economy	13600.00
0005432460198	4715	Economy	13600.00
0005432568075	4715	Economy	13600.00
0005432460210	4715	Economy	13600.00
0005434082075	4715	Economy	13600.00
0005434082076	4715	Economy	13600.00
0005432460208	4715	Economy	13600.00
0005432460222	4715	Economy	13600.00
0005432567430	30568	Business	40900.00
0005432567734	30568	Business	40900.00
0005432459917	30568	Business	40900.00
0005432567465	30568	Business	40900.00
0005432459905	30568	Business	40900.00
0005434081857	30568	Business	40900.00
0005434081831	30568	Business	40900.00
0005432459614	30568	Business	40900.00
0005432459852	30568	Business	40900.00
0005432567691	30568	Business	40900.00
0005432567293	30568	Business	40900.00
0005434081849	30568	Business	40900.00
0005434081895	30568	Business	40900.00
0005432567496	30568	Business	40900.00
0005432567631	30568	Business	40900.00
0005432567712	30568	Business	40900.00
0005432567619	30568	Business	40900.00
0005432567622	30568	Business	40900.00
0005432459886	30568	Business	40900.00
0005432459853	30568	Business	40900.00
0005432567632	30568	Business	40900.00
0005432567327	30568	Business	40900.00
0005432459709	30568	Business	40900.00
0005432459656	30568	Business	40900.00
0005432459863	30568	Economy	15000.00
0005432567657	30568	Economy	15000.00
0005434081799	30568	Economy	15000.00
0005432567495	30568	Economy	13600.00
0005432567518	30568	Economy	13600.00
0005434081773	30568	Economy	13600.00
0005432567613	30568	Economy	13600.00
0005432213631	30568	Economy	13600.00
0005432567517	30568	Economy	13600.00
0005434081765	30568	Economy	13600.00
0005434081762	30568	Economy	13600.00
0005434081763	30568	Economy	13600.00
0005432567602	30568	Economy	13600.00
0005434081858	30568	Economy	13600.00
0005432567497	30568	Economy	13600.00
0005432213633	30568	Economy	13600.00
0005434081708	30568	Economy	13600.00
0005433454870	30568	Economy	13600.00
0005432567633	30568	Economy	13600.00
0005432459615	30568	Economy	13600.00
0005434081795	30568	Economy	13600.00
0005432567452	30568	Economy	13600.00
0005432567546	30568	Economy	13600.00
0005432459641	30568	Economy	13600.00
0005434081916	30568	Economy	13600.00
0005432459816	30568	Economy	13600.00
0005434081760	30568	Economy	13600.00
0005432567779	30568	Economy	13600.00
0005432567429	30568	Economy	13600.00
0005434081886	30568	Economy	13600.00
0005432567670	30568	Economy	13600.00
0005432459808	30568	Economy	13600.00
0005432567216	30568	Economy	13600.00
0005432567393	30568	Economy	13600.00
0005432161168	30568	Economy	13600.00
0005434081819	30568	Economy	13600.00
0005432567692	30568	Economy	13600.00
0005432459910	30568	Economy	13600.00
0005432459856	30568	Economy	13600.00
0005432459765	30568	Economy	13600.00
0005434081750	30568	Economy	13600.00
0005432459962	30568	Economy	13600.00
0005432567671	30568	Economy	13600.00
0005432567321	30568	Economy	13600.00
0005432567725	30568	Economy	13600.00
0005432459628	30568	Economy	13600.00
0005434081850	30568	Economy	13600.00
0005432567778	30568	Economy	13600.00
0005432459782	30568	Economy	13600.00
0005434081868	30568	Economy	13600.00
0005434081759	30568	Economy	13600.00
0005434081870	30568	Economy	13600.00
0005432567553	30568	Economy	13600.00
0005434081787	30568	Economy	13600.00
0005432567685	30568	Economy	13600.00
0005432459885	30568	Economy	13600.00
0005432567690	30568	Economy	13600.00
0005432567614	30568	Economy	13600.00
0005432567406	30568	Economy	13600.00
0005432567684	30568	Economy	13600.00
0005434081871	30568	Economy	13600.00
0005432460007	30568	Economy	13600.00
0005432459774	30568	Economy	13600.00
0005434081922	30568	Economy	13600.00
0005432459733	30568	Economy	13600.00
0005434081761	30568	Economy	13600.00
0005432459764	30568	Economy	13600.00
0005434081772	30568	Economy	13600.00
0005432567733	30568	Economy	13600.00
0005432567547	30568	Economy	13600.00
0005432460008	30568	Economy	13600.00
0005432567557	30568	Economy	13600.00
0005432213632	30568	Economy	13600.00
0005432567693	30568	Economy	13600.00
0005432459705	30568	Economy	13600.00
0005434081766	30568	Economy	13600.00
0005432161167	30568	Economy	13600.00
0005432459708	30568	Economy	13600.00
0005432567724	30568	Economy	13600.00
0005434081851	30568	Economy	13600.00
0005432459833	30568	Economy	13600.00
0005432567326	30568	Economy	13600.00
0005432567215	30568	Economy	13600.00
0005434081896	30568	Economy	13600.00
0005432567748	30568	Economy	13600.00
0005432567396	30568	Economy	13600.00
0005432567453	30568	Economy	13600.00
0005432459732	30568	Economy	13600.00
0005434081751	30568	Economy	13600.00
0005432459951	30568	Economy	13600.00
0005432459911	30568	Economy	13600.00
0005432459961	30568	Economy	13600.00
0005432567590	30568	Economy	13600.00
0005432459639	30568	Economy	13600.00
0005432567458	30568	Economy	13600.00
0005432567655	30568	Economy	13600.00
0005434081912	30568	Economy	13600.00
0005432459963	30568	Economy	13600.00
0005432567347	30568	Economy	13600.00
0005432460004	30568	Economy	13600.00
0005432567732	30568	Economy	13600.00
0005432567618	30568	Economy	13600.00
0005432459652	30568	Economy	13600.00
0005432460005	30568	Economy	13600.00
0005432459734	30568	Economy	13600.00
0005432459781	30568	Economy	13600.00
0005432459826	30568	Economy	13600.00
0005433452735	30568	Economy	13600.00
0005432459640	30568	Economy	13600.00
0005432567706	30568	Economy	13600.00
0005434081902	30568	Economy	13600.00
0005432567421	30568	Economy	13600.00
0005432567556	30568	Economy	13600.00
0005433454876	30568	Economy	13600.00
0005432459906	30568	Economy	13600.00
0005432567683	30568	Economy	13600.00
0005432459653	30568	Economy	13600.00
0005432459834	30568	Economy	13600.00
0005432567689	30568	Economy	13600.00
0005432567656	30568	Economy	13600.00
0005434081848	30568	Economy	13600.00
0005432567467	30568	Economy	13600.00
0005432460006	30568	Economy	13600.00
0005432567320	30568	Economy	13600.00
0005432571316	30568	Economy	13600.00
0005435720829	13637	Economy	9900.00
0005435720830	13637	Economy	9900.00
0005435722072	13637	Economy	9900.00
0005435720831	13637	Economy	9900.00
0005435722054	21154	Economy	9900.00
0005435722051	21154	Economy	9900.00
0005432295898	22812	Economy	8800.00
0005432295897	22812	Economy	8800.00
0005432295899	22812	Economy	8800.00
0005435508335	11119	Business	23600.00
0005433343864	11119	Business	23600.00
0005433343905	11119	Business	23600.00
0005433343852	11119	Business	23600.00
0005433343916	11119	Business	23600.00
0005435508297	11119	Business	23600.00
0005433343881	11119	Business	23600.00
0005435097258	11119	Business	23600.00
0005435508299	11119	Business	23600.00
0005433343833	11119	Business	23600.00
0005435508364	11119	Business	23600.00
0005433343908	11119	Business	23600.00
0005433343876	11119	Economy	7900.00
0005433343896	11119	Economy	7900.00
0005433343898	11119	Economy	7900.00
0005433343865	11119	Economy	7900.00
0005435508333	11119	Economy	7900.00
0005435508332	11119	Economy	7900.00
0005433343849	11119	Economy	7900.00
0005433343891	11119	Economy	7900.00
0005433343878	11119	Economy	7900.00
0005433343918	11119	Economy	7900.00
0005433343901	11119	Economy	7900.00
0005433343907	11119	Economy	7900.00
0005433343835	11119	Economy	7900.00
0005433343821	11119	Economy	7900.00
0005433343825	11119	Economy	7900.00
0005433343861	11119	Economy	7900.00
0005433343870	11119	Economy	7900.00
0005435097267	11119	Economy	7900.00
0005433343868	11119	Economy	7900.00
0005433343886	11119	Economy	7900.00
0005433343853	11119	Economy	7900.00
0005433343841	11119	Economy	7900.00
0005435097266	11119	Economy	7900.00
0005433343885	11119	Economy	7900.00
0005433343919	11119	Economy	7900.00
0005433343862	11119	Economy	7900.00
0005433343824	11119	Economy	7900.00
0005433343854	11119	Economy	7900.00
0005435508298	11119	Economy	7900.00
0005433343823	11119	Economy	7900.00
0005433343887	11119	Economy	7900.00
0005433343855	11119	Economy	7900.00
0005433343917	11119	Economy	7900.00
0005433343880	11119	Economy	7900.00
0005433343888	11119	Economy	7900.00
0005433343894	11119	Economy	7900.00
0005433343906	11119	Economy	7900.00
0005433343869	11119	Economy	7900.00
0005433343902	11119	Economy	7900.00
0005433343897	11119	Economy	7900.00
0005433343840	11119	Economy	8600.00
0005433343920	11119	Economy	8600.00
0005433343913	11119	Economy	8600.00
0005433343845	11119	Economy	8600.00
0005433343889	11119	Economy	8600.00
0005433343882	11119	Economy	8600.00
0005433343858	11119	Economy	7900.00
0005435097261	11119	Economy	7900.00
0005433343893	11119	Economy	7900.00
0005433343866	11119	Economy	7900.00
0005433343900	11119	Economy	7900.00
0005433343910	11119	Economy	7900.00
0005433343912	11119	Economy	7900.00
0005435097257	11119	Economy	7900.00
0005435508314	11119	Economy	7900.00
0005433343834	11119	Economy	7900.00
0005433343827	11119	Economy	7900.00
0005433343911	11119	Economy	7900.00
0005433343860	11119	Economy	7900.00
0005433343904	11119	Economy	7900.00
0005433343863	11119	Economy	7900.00
0005433343847	11119	Economy	7900.00
0005433343877	11119	Economy	7900.00
0005435097260	11119	Economy	7900.00
0005433343871	11119	Economy	7900.00
0005433343890	11119	Economy	7900.00
0005433343822	11119	Economy	7900.00
0005433343838	11119	Economy	7900.00
0005433343837	11119	Economy	7900.00
0005433343831	11119	Economy	7900.00
0005433343846	11119	Economy	7900.00
0005433343857	11119	Economy	7900.00
0005433343842	11119	Economy	7900.00
0005433343899	11119	Economy	7900.00
0005433343892	11119	Economy	7900.00
0005433343873	11119	Economy	7900.00
0005433343844	11119	Economy	7900.00
0005435508356	11119	Economy	7900.00
0005433343836	11119	Economy	7900.00
0005433343879	11119	Economy	7900.00
0005435508334	11119	Economy	7900.00
0005433343850	11119	Economy	7900.00
0005433343903	11119	Economy	7900.00
0005433343915	11119	Economy	7900.00
0005433343867	11119	Economy	7900.00
0005433343914	11119	Economy	7900.00
0005433343859	11119	Economy	7900.00
0005433343884	11119	Economy	7900.00
0005435508313	11119	Economy	7900.00
0005435097264	11119	Economy	7900.00
0005433343851	11119	Economy	7900.00
0005433343826	11119	Economy	7900.00
0005433343828	11119	Economy	7900.00
0005435097265	11119	Economy	7900.00
0005435508351	11119	Economy	7900.00
0005435508359	11119	Economy	7900.00
0005433343843	11119	Economy	7900.00
0005435508300	11119	Economy	7900.00
0005433343874	11119	Economy	7900.00
0005433343921	11119	Economy	7900.00
0005433343829	11119	Economy	7900.00
0005433343883	11119	Economy	7900.00
0005433343820	11119	Economy	7900.00
0005433343909	11119	Economy	7900.00
0005435097262	11119	Economy	7900.00
0005433343830	11119	Economy	7900.00
0005433343848	11119	Economy	7900.00
0005433343895	11119	Economy	7900.00
0005435097259	11119	Economy	7900.00
0005433343832	11119	Economy	7900.00
0005433343856	11119	Economy	7900.00
0005433343875	11119	Economy	7900.00
0005433343872	11119	Economy	7900.00
0005433343839	11119	Economy	7900.00
0005435508301	11119	Economy	7900.00
0005435097263	11119	Economy	7900.00
0005435508355	11119	Economy	7900.00
0005435508357	11119	Economy	7900.00
0005433342162	17113	Business	23600.00
0005433343116	17113	Business	23600.00
0005433342721	17113	Business	23600.00
0005433342821	17113	Business	23600.00
0005433342969	17113	Business	23600.00
0005433343226	17113	Business	23600.00
0005433342768	17113	Business	23600.00
0005433342163	17113	Business	23600.00
0005433342371	17113	Business	23600.00
0005433343256	17113	Business	23600.00
0005433342715	17113	Business	23600.00
0005433342388	17113	Economy	7900.00
0005433342678	17113	Business	23600.00
0005433342756	17113	Economy	7900.00
0005432293227	17113	Economy	7900.00
0005433343072	17113	Economy	7900.00
0005433342771	17113	Economy	7900.00
0005433343098	17113	Economy	7900.00
0005433342700	17113	Economy	7900.00
0005433343038	17113	Economy	7900.00
0005433342683	17113	Economy	7900.00
0005433342841	17113	Economy	7900.00
0005433342761	17113	Economy	7900.00
0005433342583	17113	Economy	7900.00
0005433342783	17113	Economy	7900.00
0005433343128	17113	Economy	7900.00
0005433342918	17113	Economy	7900.00
0005433343078	17113	Economy	7900.00
0005433343140	17113	Economy	7900.00
0005433343191	17113	Economy	7900.00
0005433342528	17113	Economy	7900.00
0005433343207	17113	Economy	7900.00
0005433343030	17113	Economy	7900.00
0005433343054	17113	Economy	7900.00
0005433342984	17113	Economy	7900.00
0005433342985	17113	Economy	7900.00
0005433342641	17113	Economy	7900.00
0005433342755	17113	Economy	7900.00
0005433342677	17113	Economy	7900.00
0005433343286	17113	Economy	7900.00
0005433342164	17113	Economy	7900.00
0005433342959	17113	Economy	7900.00
0005433342807	17113	Economy	7900.00
0005433342682	17113	Economy	7900.00
0005433342856	17113	Economy	7900.00
0005433343158	17113	Economy	7900.00
0005433342995	17113	Economy	7900.00
0005433343309	17113	Economy	7900.00
0005433343303	17113	Economy	7900.00
0005433342529	17113	Economy	7900.00
0005433343075	17113	Economy	7900.00
0005433343208	17113	Economy	7900.00
0005433342680	17113	Economy	8600.00
0005433342777	17113	Economy	8600.00
0005433343308	17113	Economy	8600.00
0005432293226	17113	Economy	8600.00
0005433342896	17113	Economy	8600.00
0005433342920	17113	Economy	7900.00
0005433342632	17113	Economy	8600.00
0005433342706	17113	Economy	7900.00
0005433343096	17113	Economy	7900.00
0005433342767	17113	Economy	7900.00
0005433343099	17113	Economy	7900.00
0005433343152	17113	Economy	7900.00
0005433343183	17113	Economy	7900.00
0005433342812	17113	Economy	7900.00
0005433343258	17113	Economy	7900.00
0005433342757	17113	Economy	7900.00
0005433343097	17113	Economy	7900.00
0005433342404	17113	Economy	7900.00
0005433342743	17113	Economy	7900.00
0005433343079	17113	Economy	7900.00
0005433342927	17113	Economy	7900.00
0005433343247	17113	Economy	7900.00
0005433342634	17113	Economy	7900.00
0005433343085	17113	Economy	7900.00
0005433343190	17113	Economy	7900.00
0005433343124	17113	Economy	7900.00
0005433342668	17113	Economy	7900.00
0005433343257	17113	Economy	7900.00
0005433342877	17113	Economy	7900.00
0005433343141	17113	Economy	7900.00
0005433342602	17113	Economy	7900.00
0005432293225	17113	Economy	7900.00
0005433343063	17113	Economy	7900.00
0005433342872	17113	Economy	7900.00
0005433342633	17113	Economy	7900.00
0005433342720	17113	Economy	7900.00
0005433342986	17113	Economy	7900.00
0005433343062	17113	Economy	7900.00
0005433342673	17113	Economy	7900.00
0005433342696	17113	Economy	7900.00
0005433342778	17113	Economy	7900.00
0005433342217	17113	Economy	7900.00
0005433342772	17113	Economy	7900.00
0005433343115	17113	Economy	7900.00
0005433342895	17113	Economy	7900.00
0005433343061	17113	Economy	7900.00
0005433342782	17113	Economy	7900.00
0005433342727	17113	Economy	7900.00
0005433343298	17113	Economy	7900.00
0005433343064	17113	Economy	7900.00
0005433343206	17113	Economy	7900.00
0005433342937	17113	Economy	7900.00
0005433343299	17113	Economy	7900.00
0005433342876	17113	Economy	7900.00
0005433343000	17113	Economy	7900.00
0005433343071	17113	Economy	7900.00
0005433342834	17113	Economy	7900.00
0005433342970	17113	Economy	7900.00
0005433342716	17113	Economy	7900.00
0005433342983	17113	Economy	7900.00
0005433343057	17113	Economy	7900.00
0005433342946	17113	Economy	7900.00
0005433342744	17113	Economy	7900.00
0005433342820	17113	Economy	7900.00
0005433342799	17113	Economy	7900.00
0005433342577	17113	Economy	7900.00
0005433342919	17113	Economy	7900.00
0005433343058	17113	Economy	7900.00
0005433342603	17113	Economy	7900.00
0005433342835	17113	Economy	7900.00
0005433342559	17113	Economy	7900.00
0005433342960	17113	Economy	7900.00
0005433342831	17113	Economy	7900.00
0005433343246	17113	Economy	7900.00
0005433343074	17113	Economy	7900.00
0005433342224	17113	Economy	7900.00
0005433342833	17113	Economy	7900.00
0005433342766	17113	Economy	7900.00
0005432919880	9076	Business	26600.00
0005433507314	9076	Business	26600.00
0005433507313	9076	Business	26600.00
0005432919864	9076	Business	26600.00
0005433507311	9076	Business	26600.00
0005432919784	9076	Business	26600.00
0005433507317	9076	Business	26600.00
0005432919785	9076	Economy	8900.00
0005433481218	9076	Economy	8900.00
0005432919844	9076	Economy	8900.00
0005432919761	9076	Economy	8900.00
0005433481223	9076	Economy	9800.00
0005433507319	9076	Economy	9800.00
0005432919832	9076	Economy	9800.00
0005433507303	9076	Economy	8900.00
0005433481220	9076	Economy	8900.00
0005433507321	9076	Economy	8900.00
0005432919831	9076	Economy	8900.00
0005433507302	9076	Economy	8900.00
0005433507310	9076	Economy	8900.00
0005432919818	9076	Economy	8900.00
0005432919862	9076	Economy	8900.00
0005433507312	9076	Economy	8900.00
0005432919856	9076	Economy	8900.00
0005433481219	9076	Economy	8900.00
0005433481225	9076	Economy	8900.00
0005432919801	9076	Economy	8900.00
0005433507304	9076	Economy	8900.00
0005433507316	9076	Economy	8900.00
0005432919781	9076	Economy	8900.00
0005433481222	9076	Economy	8900.00
0005433481224	9076	Economy	8900.00
0005432919782	9076	Economy	8900.00
0005432919783	9076	Economy	8900.00
0005432919762	9076	Economy	8900.00
0005432919816	9076	Economy	8900.00
0005433507318	9076	Economy	8900.00
0005432919855	9076	Economy	8900.00
0005432919817	9076	Economy	8900.00
0005432919863	9076	Economy	8900.00
0005433507309	9076	Economy	8900.00
0005433507305	9076	Economy	8900.00
0005433507315	9076	Economy	8900.00
0005433507308	9076	Economy	8900.00
0005433507306	9076	Economy	8900.00
0005432919833	9076	Economy	8900.00
0005432919879	9076	Economy	8900.00
0005433481221	9076	Economy	8900.00
0005433507320	9076	Economy	8900.00
0005433507307	9076	Economy	8900.00
0005434158992	20488	Business	26600.00
0005433481180	20488	Business	26600.00
0005432920033	20488	Business	26600.00
0005432920027	20488	Business	26600.00
0005432920020	20488	Business	26600.00
0005432920028	20488	Business	26600.00
0005432920017	20488	Business	26600.00
0005433481182	20488	Economy	8900.00
0005433481181	20488	Economy	8900.00
0005433481189	20488	Economy	8900.00
0005433481164	20488	Economy	8900.00
0005434158993	20488	Economy	8900.00
0005433507050	20488	Economy	9800.00
0005432920035	20488	Economy	9800.00
0005433481184	20488	Economy	8900.00
0005432920034	20488	Economy	8900.00
0005432920032	20488	Economy	8900.00
0005432920021	20488	Economy	8900.00
0005433507184	20488	Economy	8900.00
0005433507181	20488	Economy	8900.00
0005433507188	20488	Economy	8900.00
0005432920019	20488	Economy	8900.00
0005433507164	20488	Economy	8900.00
0005432920037	20488	Economy	8900.00
0005433481155	20488	Economy	8900.00
0005433481183	20488	Economy	8900.00
0005433507207	20488	Economy	8900.00
0005433481173	20488	Economy	8900.00
0005434158990	20488	Economy	8900.00
0005433481156	20488	Economy	8900.00
0005433507163	20488	Economy	8900.00
0005432920026	20488	Economy	8900.00
0005432920036	20488	Economy	8900.00
0005433507185	20488	Economy	8900.00
0005432920024	20488	Economy	8900.00
0005432920025	20488	Economy	8900.00
0005433507223	20488	Economy	8900.00
0005432920022	20488	Economy	8900.00
0005432920029	20488	Economy	8900.00
0005434158991	20488	Economy	8900.00
0005432920031	20488	Economy	8900.00
0005433507176	20488	Economy	8900.00
0005433481147	20488	Economy	8900.00
0005432920018	20488	Economy	8900.00
0005432920023	20488	Economy	8900.00
0005433481179	20488	Economy	8900.00
0005432920030	20488	Economy	8900.00
0005433507074	20488	Economy	8900.00
0005435179691	10161	Economy	5800.00
0005432396269	10161	Economy	5800.00
0005432394129	10161	Economy	5800.00
0005432396270	10161	Economy	5800.00
0005432396267	10161	Economy	5800.00
0005432394128	10161	Economy	5800.00
0005432396268	10161	Economy	5800.00
0005435178989	10161	Economy	5800.00
0005432394130	10161	Economy	5800.00
0005432400118	18368	Economy	5800.00
0005432400120	18368	Economy	5800.00
0005432396243	18368	Economy	5800.00
0005435179401	18368	Economy	5800.00
0005432400121	18368	Economy	5800.00
0005432396239	18368	Economy	5800.00
0005435179400	18368	Economy	5800.00
0005432400110	18368	Economy	5800.00
0005432400114	18368	Economy	5800.00
0005435626100	10983	Business	9500.00
0005435126127	10983	Business	9500.00
0005435126382	10983	Business	9500.00
0005435626092	10983	Business	9500.00
0005435626094	10983	Business	9500.00
0005435126128	10983	Business	9500.00
0005435126355	10983	Business	9500.00
0005435126551	10983	Business	9500.00
0005434928319	10983	Business	9500.00
0005434411808	10983	Business	9500.00
0005435626098	10983	Business	9500.00
0005435126383	10983	Economy	3200.00
0005434411807	10983	Economy	3200.00
0005435554173	10983	Economy	3200.00
0005435626095	10983	Economy	3200.00
0005435126171	10983	Economy	3200.00
0005435626101	10983	Economy	3200.00
0005435126401	10983	Economy	3200.00
0005435126284	10983	Economy	3200.00
0005435126158	10983	Economy	3200.00
0005435126239	10983	Economy	3500.00
0005435126236	10983	Economy	3500.00
0005435554162	10983	Economy	3500.00
0005435626106	10983	Economy	3500.00
0005435126299	10983	Economy	3500.00
0005435126315	10983	Economy	3200.00
0005435626049	10983	Economy	3200.00
0005434928321	10983	Economy	3200.00
0005435126208	10983	Economy	3200.00
0005435126317	10983	Economy	3200.00
0005435126257	10983	Economy	3200.00
0005435126440	10983	Economy	3200.00
0005435126442	10983	Economy	3200.00
0005435626074	10983	Economy	3200.00
0005435626099	10983	Economy	3200.00
0005435126153	10983	Economy	3200.00
0005435626109	10983	Economy	3200.00
0005435126316	10983	Economy	3200.00
0005435126219	10983	Economy	3200.00
0005435626056	10983	Economy	3200.00
0005435126289	10983	Economy	3200.00
0005434411809	10983	Economy	3200.00
0005435626070	10983	Economy	3200.00
0005435556681	10983	Economy	3200.00
0005434411810	10983	Economy	3200.00
0005434411811	10983	Economy	3200.00
0005435626114	10983	Economy	3200.00
0005435126298	10983	Economy	3200.00
0005435554178	10983	Economy	3200.00
0005435126237	10983	Economy	3200.00
0005435126235	10983	Economy	3200.00
0005435554161	10983	Economy	3200.00
0005434928320	10983	Economy	3200.00
0005435556698	10983	Economy	3200.00
0005435626080	10983	Economy	3200.00
0005435554163	10983	Economy	3200.00
0005435556680	10983	Economy	3200.00
0005435126400	10983	Economy	3200.00
0005435126162	10983	Economy	3200.00
0005435126243	10983	Economy	3200.00
0005435126357	10983	Economy	3200.00
0005435626075	10983	Economy	3200.00
0005435126297	10983	Economy	3200.00
0005435126157	10983	Economy	3200.00
0005435126356	10983	Economy	3200.00
0005435126318	10983	Economy	3200.00
0005435626123	10983	Economy	3200.00
0005435126152	10983	Economy	3200.00
0005435626055	10983	Economy	3200.00
0005435126288	10983	Economy	3200.00
0005435126314	10983	Economy	3200.00
0005435126417	10983	Economy	3200.00
0005435626091	10983	Economy	3200.00
0005435126125	10983	Economy	3200.00
0005435126172	10983	Economy	3200.00
0005435126300	10983	Economy	3200.00
0005435126679	14701	Business	9500.00
0005435126685	14701	Business	9500.00
0005435126668	14701	Business	9500.00
0005435554219	14701	Business	9500.00
0005435626312	14701	Business	9500.00
0005435626309	14701	Business	9500.00
0005435126661	14701	Business	9500.00
0005435126657	14701	Business	9500.00
0005435126656	14701	Business	9500.00
0005434411773	14701	Economy	3200.00
0005435126667	14701	Economy	3200.00
0005435126669	14701	Economy	3200.00
0005435626311	14701	Economy	3200.00
0005435626306	14701	Economy	3200.00
0005435126676	14701	Economy	3200.00
0005435554220	14701	Economy	3200.00
0005435126646	14701	Economy	3500.00
0005435126670	14701	Economy	3500.00
0005435126666	14701	Economy	3500.00
0005435126648	14701	Economy	3500.00
0005435126652	14701	Economy	3200.00
0005435626315	14701	Economy	3200.00
0005435126659	14701	Economy	3200.00
0005435126686	14701	Economy	3200.00
0005435126678	14701	Economy	3200.00
0005435556710	14701	Economy	3200.00
0005435126649	14701	Economy	3200.00
0005435126687	14701	Economy	3200.00
0005435126662	14701	Economy	3200.00
0005434411772	14701	Economy	3200.00
0005435626310	14701	Economy	3200.00
0005435626313	14701	Economy	3200.00
0005435126674	14701	Economy	3200.00
0005435126654	14701	Economy	3200.00
0005435126671	14701	Economy	3200.00
0005435126681	14701	Economy	3200.00
0005434411767	14701	Economy	3200.00
0005435126673	14701	Economy	3200.00
0005435126665	14701	Economy	3200.00
0005435626307	14701	Economy	3200.00
0005435126658	14701	Economy	3200.00
0005435126680	14701	Economy	3200.00
0005435126677	14701	Economy	3200.00
0005435126675	14701	Economy	3200.00
0005435626314	14701	Economy	3200.00
0005435126672	14701	Economy	3200.00
0005434411766	14701	Economy	3200.00
0005435126651	14701	Economy	3200.00
0005435126647	14701	Economy	3200.00
0005435126683	14701	Economy	3200.00
0005435554221	14701	Economy	3200.00
0005435126660	14701	Economy	3200.00
0005435126650	14701	Economy	3200.00
0005435126684	14701	Economy	3200.00
0005435556711	14701	Economy	3200.00
0005435126664	14701	Economy	3200.00
0005435126655	14701	Economy	3200.00
0005435126653	14701	Economy	3200.00
0005435554218	14701	Economy	3200.00
0005435126682	14701	Economy	3200.00
0005435126663	14701	Economy	3200.00
0005435626308	14701	Economy	3200.00
0005435715594	7109	Business	86900.00
0005435715598	7109	Business	86900.00
0005435443329	7109	Business	86900.00
0005435219193	7109	Business	86900.00
0005432400153	7109	Business	86900.00
0005435443295	7109	Business	86900.00
0005435443290	7109	Economy	29000.00
0005435715589	7109	Economy	29000.00
0005432398223	7109	Economy	29000.00
0005432400154	7109	Economy	29000.00
0005435443306	7109	Economy	31900.00
0005435715587	7109	Economy	31900.00
0005435179394	7109	Economy	31900.00
0005432398226	7109	Economy	29000.00
0005435179393	7109	Economy	29000.00
0005435179392	7109	Economy	29000.00
0005435715591	7109	Economy	29000.00
0005435715586	7109	Economy	29000.00
0005435715585	7109	Economy	29000.00
0005435219204	7109	Economy	29000.00
0005435715584	7109	Economy	29000.00
0005435443313	7109	Economy	29000.00
0005432398225	7109	Economy	29000.00
0005435443312	7109	Economy	29000.00
0005435715582	7109	Economy	29000.00
0005432398224	7109	Economy	29000.00
0005435715593	7109	Economy	29000.00
0005435715599	7109	Economy	29000.00
0005435715597	7109	Economy	29000.00
0005435715596	7109	Economy	29000.00
0005435715590	7109	Economy	29000.00
0005435715588	7109	Economy	29000.00
0005435216579	7109	Economy	29000.00
0005435715592	7109	Economy	29000.00
0005435715583	7109	Economy	29000.00
0005435216578	7109	Economy	29000.00
0005435443281	7109	Economy	29000.00
0005435443311	7109	Economy	29000.00
0005435715600	7109	Economy	29000.00
0005435715595	7109	Economy	29000.00
0005435219201	7109	Economy	29000.00
0005432400155	7109	Economy	29000.00
0005435221052	7109	Economy	29000.00
0005435715473	27085	Business	86900.00
0005435443378	27085	Economy	29000.00
0005435715438	27085	Economy	29000.00
0005432398187	27085	Economy	29000.00
0005435715469	27085	Economy	29000.00
0005435715378	27085	Economy	29000.00
0005435443379	27085	Economy	31900.00
0005435715480	27085	Economy	31900.00
0005432398186	27085	Economy	29000.00
0005432398193	27085	Economy	29000.00
0005435715425	27085	Economy	29000.00
0005432398192	27085	Economy	29000.00
0005435715471	27085	Economy	29000.00
0005432394083	27085	Economy	29000.00
0005432394088	27085	Economy	29000.00
0005435715500	27085	Economy	29000.00
0005432398180	27085	Economy	29000.00
0005435715468	27085	Economy	29000.00
0005435443380	27085	Economy	29000.00
0005435715474	27085	Economy	29000.00
0005435715479	27085	Economy	29000.00
0005435715454	27085	Economy	29000.00
0005435715400	27085	Economy	29000.00
0005435178504	27085	Economy	29000.00
0005435443382	27085	Economy	29000.00
0005435443377	27085	Economy	29000.00
0005435443384	27085	Economy	29000.00
0005435178505	27085	Economy	29000.00
0005435715455	27085	Economy	29000.00
0005432398195	27085	Economy	29000.00
0005435715440	27085	Economy	29000.00
0005435715486	27085	Economy	29000.00
0005435715439	27085	Economy	29000.00
0005435443385	27085	Economy	29000.00
0005435443381	27085	Economy	29000.00
0005435443383	27085	Economy	29000.00
0005432394101	27085	Economy	29000.00
0005434084964	2731	Economy	7700.00
0005434084963	2731	Economy	7700.00
0005434084962	2731	Economy	7700.00
0005433060413	2731	Economy	7700.00
0005434084961	2731	Economy	7700.00
0005433060415	2731	Economy	7700.00
0005433060412	2731	Economy	7700.00
0005434084965	2731	Economy	7700.00
0005434084966	2731	Economy	7700.00
0005433060404	2731	Economy	7700.00
0005434084940	28511	Economy	7700.00
0005432632759	25191	Economy	29000.00
0005432632778	25191	Economy	29000.00
0005435844288	25191	Economy	29000.00
0005432632755	25191	Economy	29000.00
0005432632768	25191	Economy	26400.00
0005435844285	25191	Economy	26400.00
0005432632769	25191	Economy	26400.00
0005435844298	25191	Economy	26400.00
0005435844296	25191	Economy	26400.00
0005432632781	25191	Economy	26400.00
0005432632763	25191	Economy	26400.00
0005435844299	25191	Economy	26400.00
0005432632774	25191	Economy	26400.00
0005435844308	25191	Economy	26400.00
0005432632761	25191	Economy	26400.00
0005435844300	25191	Economy	26400.00
0005435844297	25191	Economy	26400.00
0005432632762	25191	Economy	26400.00
0005432632757	25191	Economy	26400.00
0005432632758	25191	Economy	26400.00
0005432632779	25191	Economy	26400.00
0005432632775	25191	Economy	26400.00
0005432632772	25191	Economy	26400.00
0005435844289	25191	Economy	26400.00
0005435844312	25191	Economy	26400.00
0005432632760	25191	Economy	26400.00
0005432632771	25191	Economy	26400.00
0005435844291	25191	Economy	26400.00
0005432632773	25191	Economy	26400.00
0005435844301	25191	Economy	26400.00
0005432632776	25191	Economy	26400.00
0005432632780	25191	Economy	26400.00
0005435844303	25191	Economy	26400.00
0005432632782	25191	Economy	26400.00
0005432632767	25191	Economy	26400.00
0005435844309	25191	Economy	26400.00
0005432632765	25191	Economy	26400.00
0005435844306	25191	Economy	26400.00
0005432632766	25191	Economy	26400.00
0005435844302	25191	Economy	26400.00
0005432632770	25191	Economy	26400.00
0005435844311	25191	Economy	26400.00
0005432632756	25191	Economy	26400.00
0005432632777	25191	Economy	26400.00
0005435844307	25191	Economy	26400.00
0005432632764	25191	Economy	26400.00
0005435844295	25191	Economy	26400.00
0005432632709	28166	Economy	29000.00
0005432632706	28166	Economy	29000.00
0005435844349	28166	Economy	29000.00
0005432632730	28166	Economy	29000.00
0005432632691	28166	Economy	26400.00
0005432632684	28166	Economy	26400.00
0005435844338	28166	Economy	26400.00
0005432632701	28166	Economy	26400.00
0005435844342	28166	Economy	26400.00
0005435844347	28166	Economy	26400.00
0005432632729	28166	Economy	26400.00
0005432632692	28166	Economy	26400.00
0005432632657	28166	Economy	26400.00
0005432632722	28166	Economy	26400.00
0005432632728	28166	Economy	26400.00
0005432632693	28166	Economy	26400.00
0005432632711	28166	Economy	26400.00
0005432632664	28166	Economy	26400.00
0005432632719	28166	Economy	26400.00
0005435844340	28166	Economy	26400.00
0005432632723	28166	Economy	26400.00
0005432632688	28166	Economy	26400.00
0005432632734	28166	Economy	26400.00
0005432632708	28166	Economy	26400.00
0005432632725	28166	Economy	26400.00
0005432632678	28166	Economy	26400.00
0005435844339	28166	Economy	26400.00
0005435844343	28166	Economy	26400.00
0005435844344	28166	Economy	26400.00
0005432632710	28166	Economy	26400.00
0005432632700	28166	Economy	26400.00
0005435844348	28166	Economy	26400.00
0005435844341	28166	Economy	26400.00
0005432632689	28166	Economy	26400.00
0005435844346	28166	Economy	26400.00
0005432632687	28166	Economy	26400.00
0005432632704	28166	Economy	26400.00
0005435844345	28166	Economy	26400.00
0005432632690	28166	Economy	26400.00
0005432632718	28166	Economy	26400.00
0005432632702	28166	Economy	26400.00
0005432632703	28166	Economy	26400.00
0005432632712	28166	Economy	26400.00
0005432632732	28166	Economy	26400.00
0005432632697	28166	Economy	26400.00
0005432632679	28166	Economy	26400.00
0005432632705	28166	Economy	26400.00
0005432632677	28166	Economy	26400.00
0005432632707	28166	Economy	26400.00
0005435517880	11402	Business	20200.00
0005435540977	11402	Business	20200.00
0005435540858	11402	Business	20200.00
0005435517864	11402	Business	20200.00
0005435517825	11402	Business	20200.00
0005435517863	11402	Business	20200.00
0005435540976	11402	Economy	6700.00
0005435540988	11402	Economy	6700.00
0005435541041	11402	Economy	6700.00
0005435540985	11402	Economy	6700.00
0005435517871	11402	Economy	6700.00
0005435541004	11402	Economy	6700.00
0005435517968	11402	Economy	7400.00
0005435541014	11402	Economy	6700.00
0005435540962	11402	Economy	6700.00
0005435541059	11402	Economy	6700.00
0005435540961	11402	Economy	6700.00
0005435541006	11402	Economy	6700.00
0005435517817	11402	Economy	6700.00
0005435517896	11402	Economy	6700.00
0005435540831	11402	Economy	6700.00
0005435517969	11402	Economy	6700.00
0005435540984	11402	Economy	6700.00
0005435540958	11402	Economy	6700.00
0005435540942	11402	Economy	6700.00
0005435517849	11402	Economy	6700.00
0005435517837	11402	Economy	6700.00
0005435541023	11402	Economy	6700.00
0005435540959	11402	Economy	6700.00
0005435540859	11402	Economy	6700.00
0005435541015	11402	Economy	6700.00
0005435517901	11402	Economy	6700.00
0005435517897	11402	Economy	6700.00
0005435540990	11402	Economy	6700.00
0005435540989	11402	Economy	6700.00
0005435517894	11402	Economy	6700.00
0005435517895	11402	Economy	6700.00
0005435540981	11402	Economy	6700.00
0005432294503	22254	Business	20200.00
0005435541136	22254	Business	20200.00
0005435529402	22254	Business	20200.00
0005435541152	22254	Business	20200.00
0005435529398	22254	Business	20200.00
0005435529391	22254	Business	20200.00
0005435541138	22254	Economy	6700.00
0005435541143	22254	Economy	6700.00
0005435541140	22254	Economy	6700.00
0005435529406	22254	Economy	6700.00
0005435529399	22254	Economy	6700.00
0005435529388	22254	Economy	7400.00
0005435541135	22254	Economy	6700.00
0005435541153	22254	Economy	6700.00
0005435541151	22254	Economy	6700.00
0005435529397	22254	Economy	6700.00
0005435529408	22254	Economy	6700.00
0005435541148	22254	Economy	6700.00
0005435529401	22254	Economy	6700.00
0005435541139	22254	Economy	6700.00
0005435529394	22254	Economy	6700.00
0005435529389	22254	Economy	6700.00
0005435541145	22254	Economy	6700.00
0005435529392	22254	Economy	6700.00
0005435529403	22254	Economy	6700.00
0005435529396	22254	Economy	6700.00
0005435541134	22254	Economy	6700.00
0005435541133	22254	Economy	6700.00
0005435541132	22254	Economy	6700.00
0005432294502	22254	Economy	6700.00
0005435529400	22254	Economy	6700.00
0005435541147	22254	Economy	6700.00
0005435541141	22254	Economy	6700.00
0005435529393	22254	Economy	6700.00
0005435529405	22254	Economy	6700.00
0005435529407	22254	Economy	6700.00
0005435529404	22254	Economy	6700.00
0005435529409	22254	Economy	6700.00
0005435541149	22254	Economy	6700.00
0005435541150	22254	Economy	6700.00
0005435541137	22254	Economy	6700.00
0005435541142	22254	Economy	6700.00
0005435541146	22254	Economy	6700.00
0005435529390	22254	Economy	6700.00
0005435541144	22254	Economy	6700.00
0005435529395	22254	Economy	6700.00
0005435529410	22254	Economy	6700.00
0005434907677	2281	Business	20200.00
0005434907689	2281	Business	20200.00
0005434907696	2281	Business	20200.00
0005433400986	2281	Business	20200.00
0005433251450	2281	Business	20200.00
0005433251442	2281	Business	20200.00
0005434907673	2281	Business	20200.00
0005433251526	2281	Business	20200.00
0005434907659	2281	Business	20200.00
0005434907690	2281	Business	20200.00
0005433251441	2281	Business	20200.00
0005434907695	2281	Business	20200.00
0005434907691	2281	Economy	6700.00
0005434907661	2281	Economy	6700.00
0005434907694	2281	Economy	6700.00
0005433251525	2281	Economy	6700.00
0005433251459	2281	Economy	6700.00
0005434907706	2281	Economy	6700.00
0005433251448	2281	Economy	6700.00
0005434907668	2281	Economy	6700.00
0005433251464	2281	Economy	6700.00
0005433400985	2281	Economy	6700.00
0005433251572	2281	Economy	7400.00
0005433251540	2281	Economy	7400.00
0005433251412	2281	Economy	7400.00
0005433251352	2281	Economy	7400.00
0005433251445	2281	Economy	6700.00
0005434907662	2281	Economy	6700.00
0005434907692	2281	Economy	6700.00
0005433251413	2281	Economy	6700.00
0005434907670	2281	Economy	6700.00
0005433251527	2281	Economy	6700.00
0005434907702	2281	Economy	6700.00
0005433251467	2281	Economy	6700.00
0005434907688	2281	Economy	6700.00
0005433251343	2281	Economy	6700.00
0005433251247	2281	Economy	6700.00
0005434907672	2281	Economy	6700.00
0005434907699	2281	Economy	6700.00
0005433251465	2281	Economy	6700.00
0005433251495	2281	Economy	6700.00
0005434907683	2281	Economy	6700.00
0005434907693	2281	Economy	6700.00
0005434907680	2281	Economy	6700.00
0005434907681	2281	Economy	6700.00
0005434907665	2281	Economy	6700.00
0005434907686	2281	Economy	6700.00
0005434907701	2281	Economy	6700.00
0005433251443	2281	Economy	6700.00
0005434907674	2281	Economy	6700.00
0005434907682	2281	Economy	6700.00
0005434907675	2281	Economy	6700.00
0005433251381	2281	Economy	6700.00
0005433251487	2281	Economy	6700.00
0005434907687	2281	Economy	6700.00
0005434907654	2281	Economy	6700.00
0005433251485	2281	Economy	6700.00
0005434907660	2281	Economy	6700.00
0005433251524	2281	Economy	6700.00
0005434907685	2281	Economy	6700.00
0005434907657	2281	Economy	6700.00
0005434907664	2281	Economy	6700.00
0005434907658	2281	Economy	6700.00
0005434907700	2281	Economy	6700.00
0005434907698	2281	Economy	6700.00
0005433251320	2281	Economy	6700.00
0005433251506	2281	Economy	6700.00
0005433251470	2281	Economy	6700.00
0005433251458	2281	Economy	6700.00
0005433251469	2281	Economy	6700.00
0005433251494	2281	Economy	6700.00
0005434907666	2281	Economy	6700.00
0005434907669	2281	Economy	6700.00
0005434907697	2281	Economy	6700.00
0005434907667	2281	Economy	6700.00
0005434907676	2281	Economy	6700.00
0005434907705	2281	Economy	6700.00
0005434907656	2281	Economy	6700.00
0005434907663	2281	Economy	6700.00
0005433251395	2281	Economy	6700.00
0005434907679	2281	Economy	6700.00
0005434907684	2281	Economy	6700.00
0005434907704	2281	Economy	6700.00
0005434907703	2281	Economy	6700.00
0005434907678	2281	Economy	6700.00
0005433251463	2281	Economy	6700.00
0005433251468	2281	Economy	6700.00
0005434907655	2281	Economy	6700.00
0005434907671	2281	Economy	6700.00
0005433251589	2281	Economy	6700.00
0005433251709	25604	Business	20200.00
0005433251710	25604	Business	20200.00
0005433251698	25604	Business	20200.00
0005434907059	25604	Business	20200.00
0005433251689	25604	Business	20200.00
0005434907193	25604	Business	20200.00
0005434907189	25604	Business	20200.00
0005433251687	25604	Business	20200.00
0005434907111	25604	Business	20200.00
0005433251715	25604	Business	20200.00
0005434906951	25604	Economy	6700.00
0005434907162	25604	Economy	6700.00
0005434907262	25604	Economy	6700.00
0005434906874	25604	Economy	6700.00
0005434907247	25604	Economy	6700.00
0005434907254	25604	Economy	6700.00
0005433251717	25604	Economy	6700.00
0005433251708	25604	Economy	6700.00
0005433251703	25604	Economy	6700.00
0005433251699	25604	Economy	7400.00
0005433251691	25604	Economy	7400.00
0005433251712	25604	Economy	7400.00
0005433251688	25604	Economy	7400.00
0005433251692	25604	Economy	6700.00
0005433251707	25604	Economy	6700.00
0005433251704	25604	Economy	6700.00
0005433251694	25604	Economy	6700.00
0005434907200	25604	Economy	6700.00
0005433401006	25604	Economy	6700.00
0005433251711	25604	Economy	6700.00
0005433251705	25604	Economy	6700.00
0005434906992	25604	Economy	6700.00
0005433401007	25604	Economy	6700.00
0005434907184	25604	Economy	6700.00
0005434907126	25604	Economy	6700.00
0005434906945	25604	Economy	6700.00
0005433401005	25604	Economy	6700.00
0005434907196	25604	Economy	6700.00
0005434907218	25604	Economy	6700.00
0005434907190	25604	Economy	6700.00
0005434907326	25604	Economy	6700.00
0005433251716	25604	Economy	6700.00
0005434907452	25604	Economy	6700.00
0005433251695	25604	Economy	6700.00
0005434907137	25604	Economy	6700.00
0005434907161	25604	Economy	6700.00
0005434907185	25604	Economy	6700.00
0005434906991	25604	Economy	6700.00
0005434907352	25604	Economy	6700.00
0005433251701	25604	Economy	6700.00
0005433251686	25604	Economy	6700.00
0005434907187	25604	Economy	6700.00
0005434907122	25604	Economy	6700.00
0005434907155	25604	Economy	6700.00
0005434907186	25604	Economy	6700.00
0005434907365	25604	Economy	6700.00
0005434907147	25604	Economy	6700.00
0005434907144	25604	Economy	6700.00
0005434907219	25604	Economy	6700.00
0005433251700	25604	Economy	6700.00
0005433251696	25604	Economy	6700.00
0005433251702	25604	Economy	6700.00
0005434907127	25604	Economy	6700.00
0005434906952	25604	Economy	6700.00
0005433251706	25604	Economy	6700.00
0005434907188	25604	Economy	6700.00
0005434907325	25604	Economy	6700.00
0005434907207	25604	Economy	6700.00
0005433251713	25604	Economy	6700.00
0005433251697	25604	Economy	6700.00
0005434907062	25604	Economy	6700.00
0005433251714	25604	Economy	6700.00
0005434907295	25604	Economy	6700.00
0005434907131	25604	Economy	6700.00
0005434907354	25604	Economy	6700.00
0005434907453	25604	Economy	6700.00
0005433251690	25604	Economy	6700.00
0005434907353	25604	Economy	6700.00
0005434907215	25604	Economy	6700.00
0005434907158	25604	Economy	6700.00
0005433251693	25604	Economy	6700.00
0005434907273	25604	Economy	6700.00
0005434907208	25604	Economy	6700.00
0005434906956	25604	Economy	6700.00
0005434907246	25604	Economy	6700.00
0005434907157	25604	Economy	6700.00
0005434907172	25604	Economy	6700.00
0005432862269	2515	Economy	13600.00
0005432862268	2515	Economy	12400.00
0005432862281	2515	Economy	12400.00
0005432621136	2515	Economy	12400.00
0005432621141	2515	Economy	12400.00
0005432621147	2515	Economy	12400.00
0005432621146	2515	Economy	12400.00
0005432862277	2515	Economy	12400.00
0005432621145	2515	Economy	12400.00
0005432862305	2515	Economy	12400.00
0005432621135	2515	Economy	12400.00
0005432621133	2515	Economy	12400.00
0005432621137	2515	Economy	12400.00
0005432621138	2515	Economy	12400.00
0005432621134	2515	Economy	12400.00
0005432621144	2515	Economy	12400.00
0005432862283	2515	Economy	12400.00
0005432862284	2515	Economy	12400.00
0005432621143	2515	Economy	12400.00
0005432621140	2515	Economy	12400.00
0005432862285	2515	Economy	12400.00
0005432621142	2515	Economy	12400.00
0005432621139	2515	Economy	12400.00
0005432862282	2515	Economy	12400.00
0005432621027	28063	Economy	13600.00
0005432862362	28063	Economy	12400.00
0005432862357	28063	Economy	12400.00
0005432862355	28063	Economy	12400.00
0005432620995	28063	Economy	12400.00
0005432621017	28063	Economy	12400.00
0005432621007	28063	Economy	12400.00
0005432621028	28063	Economy	12400.00
0005432620994	28063	Economy	12400.00
0005432862354	28063	Economy	12400.00
0005432621045	28063	Economy	12400.00
0005432621016	28063	Economy	12400.00
0005432621008	28063	Economy	12400.00
0005432621026	28063	Economy	12400.00
0005432621023	28063	Economy	12400.00
0005432862359	28063	Economy	12400.00
0005432621050	28063	Economy	12400.00
0005432862360	28063	Economy	12400.00
0005432862361	28063	Economy	12400.00
0005432862356	28063	Economy	12400.00
0005432620979	28063	Economy	12400.00
0005432620997	28063	Economy	12400.00
0005432862358	28063	Economy	12400.00
0005432621020	28063	Economy	12400.00
0005432620996	28063	Economy	12400.00
0005432621018	28063	Economy	12400.00
0005432621019	28063	Economy	12400.00
0005434097476	11763	Economy	11300.00
0005434097469	11763	Economy	11300.00
0005434097486	13033	Economy	11300.00
0005433452754	31063	Economy	8400.00
0005433452753	31063	Economy	8400.00
0005433451635	31063	Economy	8400.00
0005433451633	31063	Economy	8400.00
0005433451634	31063	Economy	8400.00
0005433454876	31437	Economy	8400.00
0005433452735	31437	Economy	8400.00
0005433454870	31437	Economy	8400.00
0005434184657	12032	Economy	7200.00
0005434142594	12032	Economy	7200.00
0005434184658	12032	Economy	6600.00
0005433129280	12032	Economy	6600.00
0005434184667	12032	Economy	6600.00
0005433134147	12032	Economy	6600.00
0005433129266	12032	Economy	6600.00
0005433134125	12032	Economy	6600.00
0005433134124	12032	Economy	6600.00
0005433129256	12032	Economy	6600.00
0005434184652	12032	Economy	6600.00
0005434183595	29828	Economy	7200.00
0005433134169	29828	Economy	7200.00
0005433131742	29828	Economy	6600.00
0005434142636	29828	Economy	6600.00
0005433134172	29828	Economy	6600.00
0005434142635	29828	Economy	6600.00
0005434142638	29828	Economy	6600.00
0005433131741	29828	Economy	6600.00
0005434184681	29828	Economy	6600.00
0005434142637	29828	Economy	6600.00
0005434142639	29828	Economy	6600.00
0005434326268	29828	Economy	6600.00
0005433131739	29828	Economy	6600.00
0005433134170	29828	Economy	6600.00
0005434184679	29828	Economy	6600.00
0005433134171	29828	Economy	6600.00
0005434183593	29828	Economy	6600.00
0005434183594	29828	Economy	6600.00
0005434184680	29828	Economy	6600.00
0005434326269	29828	Economy	6600.00
0005433131740	29828	Economy	6600.00
0005435697511	16483	Economy	19900.00
0005435697508	16483	Economy	19900.00
0005435697525	16483	Economy	19900.00
0005435697518	16483	Economy	18100.00
0005435697506	16483	Economy	18100.00
0005435697521	16483	Economy	18100.00
0005435697531	16483	Economy	18100.00
0005435697510	16483	Economy	18100.00
0005435697513	16483	Economy	18100.00
0005435935054	16483	Economy	18100.00
0005435697515	16483	Economy	18100.00
0005435697519	16483	Economy	18100.00
0005435697529	16483	Economy	18100.00
0005435697514	16483	Economy	18100.00
0005435935042	16483	Economy	18100.00
0005435697523	16483	Economy	18100.00
0005435697517	16483	Economy	18100.00
0005435697520	16483	Economy	18100.00
0005435697526	16483	Economy	18100.00
0005435697504	16483	Economy	18100.00
0005435697530	16483	Economy	18100.00
0005435935047	16483	Economy	18100.00
0005435697527	16483	Economy	18100.00
0005435697516	16483	Economy	18100.00
0005435697512	16483	Economy	18100.00
0005435697524	16483	Economy	18100.00
0005435697522	16483	Economy	18100.00
0005435697507	16483	Economy	18100.00
0005435697505	16483	Economy	18100.00
0005435697509	16483	Economy	18100.00
0005435697528	16483	Economy	18100.00
0005435697258	24723	Economy	19900.00
0005435697358	24723	Economy	19900.00
0005435697289	24723	Economy	19900.00
0005435697259	24723	Economy	19900.00
0005435697332	24723	Economy	18100.00
0005435697250	24723	Economy	18100.00
0005435697290	24723	Economy	18100.00
0005435697340	24723	Economy	18100.00
0005435697249	24723	Economy	18100.00
0005435697288	24723	Economy	18100.00
0005435935066	24723	Economy	18100.00
0005435697297	24723	Economy	18100.00
0005435697314	24723	Economy	18100.00
0005435697321	24723	Economy	18100.00
0005435697312	24723	Economy	18100.00
0005435697369	24723	Economy	18100.00
0005435697409	24723	Economy	18100.00
0005435697296	24723	Economy	18100.00
0005435697322	24723	Economy	18100.00
0005435697355	24723	Economy	18100.00
0005435935065	24723	Economy	18100.00
0005435697241	24723	Economy	18100.00
0005435697354	24723	Economy	18100.00
0005435935068	24723	Economy	18100.00
0005435697295	24723	Economy	18100.00
0005435697347	24723	Economy	18100.00
0005435697316	24723	Economy	18100.00
0005435697226	24723	Economy	18100.00
0005435697217	24723	Economy	18100.00
0005435697248	24723	Economy	18100.00
0005435697300	24723	Economy	18100.00
0005435697311	24723	Economy	18100.00
0005435935067	24723	Economy	18100.00
0005433724833	18776	Economy	4400.00
0005433724835	18776	Economy	4400.00
0005433724832	18776	Economy	4400.00
0005433724834	18776	Economy	4400.00
0005433724831	18776	Economy	4400.00
0005432968837	18776	Economy	4400.00
0005433724799	21610	Economy	4400.00
0005432968859	21610	Economy	4400.00
0005433724824	21610	Economy	4400.00
0005433724796	21610	Economy	4400.00
0005433724788	21610	Economy	4400.00
0005433724797	21610	Economy	4400.00
0005433724811	21610	Economy	4400.00
0005433724798	21610	Economy	4400.00
0005433724810	21610	Economy	4400.00
0005433724825	21610	Economy	4400.00
0005432968858	21610	Economy	4400.00
0005434138786	7302	Business	23100.00
0005434138784	7302	Business	23100.00
0005434138755	7302	Business	23100.00
0005434138768	7302	Business	23100.00
0005434138763	7302	Business	23100.00
0005434138753	7302	Business	23100.00
0005434138792	7302	Business	23100.00
0005434138734	7302	Business	23100.00
0005434138756	7302	Business	23100.00
0005434138732	7302	Business	23100.00
0005434138773	7302	Business	23100.00
0005434138805	7302	Business	23100.00
0005434138748	7302	Economy	7700.00
0005434138775	7302	Economy	7700.00
0005434138766	7302	Economy	7700.00
0005434138776	7302	Economy	7700.00
0005434138789	7302	Economy	7700.00
0005434138721	7302	Economy	7700.00
0005434138800	7302	Economy	7700.00
0005434138790	7302	Economy	7700.00
0005434138728	7302	Economy	7700.00
0005434138799	7302	Economy	8500.00
0005434087548	7302	Economy	8500.00
0005434138739	7302	Economy	8500.00
0005434138761	7302	Economy	8500.00
0005434138730	7302	Economy	8500.00
0005434138778	7302	Economy	7700.00
0005434138779	7302	Economy	7700.00
0005434138791	7302	Economy	7700.00
0005434138787	7302	Economy	7700.00
0005434138797	7302	Economy	7700.00
0005434138744	7302	Economy	7700.00
0005434138741	7302	Economy	7700.00
0005434138723	7302	Economy	7700.00
0005434138788	7302	Economy	7700.00
0005434138758	7302	Economy	7700.00
0005434138757	7302	Economy	7700.00
0005434138733	7302	Economy	7700.00
0005434087551	7302	Economy	7700.00
0005434138747	7302	Economy	7700.00
0005434138742	7302	Economy	7700.00
0005434138781	7302	Economy	7700.00
0005434138736	7302	Economy	7700.00
0005434138735	7302	Economy	7700.00
0005434138774	7302	Economy	7700.00
0005434138719	7302	Economy	7700.00
0005434138731	7302	Economy	7700.00
0005434138740	7302	Economy	7700.00
0005434138803	7302	Economy	7700.00
0005434138724	7302	Economy	7700.00
0005434138760	7302	Economy	7700.00
0005434138722	7302	Economy	7700.00
0005434138777	7302	Economy	7700.00
0005434138751	7302	Economy	7700.00
0005434138750	7302	Economy	7700.00
0005434138795	7302	Economy	7700.00
0005434138806	7302	Economy	7700.00
0005434138798	7302	Economy	7700.00
0005434138716	7302	Economy	7700.00
0005434138801	7302	Economy	7700.00
0005434138769	7302	Economy	7700.00
0005434138794	7302	Economy	7700.00
0005434138737	7302	Economy	7700.00
0005434138765	7302	Economy	7700.00
0005434087550	7302	Economy	7700.00
0005434138802	7302	Economy	7700.00
0005434138793	7302	Economy	7700.00
0005434138759	7302	Economy	7700.00
0005434087547	7302	Economy	7700.00
0005434138752	7302	Economy	7700.00
0005434087549	7302	Economy	7700.00
0005434138780	7302	Economy	7700.00
0005434138796	7302	Economy	7700.00
0005434138749	7302	Economy	7700.00
0005434138754	7302	Economy	7700.00
0005434138785	7302	Economy	7700.00
0005434138804	7302	Economy	7700.00
0005434138718	7302	Economy	7700.00
0005434138767	7302	Economy	7700.00
0005434138743	7302	Economy	7700.00
0005434138746	7302	Economy	7700.00
0005434138764	7302	Economy	7700.00
0005434138720	7302	Economy	7700.00
0005434138726	7302	Economy	7700.00
0005434138717	7302	Economy	7700.00
0005434138738	7302	Economy	7700.00
0005434138772	7302	Economy	7700.00
0005434138771	7302	Economy	7700.00
0005434138725	7302	Economy	7700.00
0005434138745	7302	Economy	7700.00
0005434138770	7302	Economy	7700.00
0005434138783	7302	Economy	7700.00
0005434138762	7302	Economy	7700.00
0005434138727	7302	Economy	7700.00
0005434138729	7302	Economy	7700.00
0005434138782	7302	Economy	7700.00
0005434137956	28549	Business	23100.00
0005434138217	28549	Business	23100.00
0005434138241	28549	Business	23100.00
0005434137746	28549	Business	23100.00
0005434137982	28549	Business	23100.00
0005434137701	28549	Business	23100.00
0005434137937	28549	Business	23100.00
0005434138170	28549	Business	23100.00
0005434087528	28549	Business	23100.00
0005434138051	28549	Business	23100.00
0005434138147	28549	Business	23100.00
0005434138171	28549	Economy	7700.00
0005434137980	28549	Economy	7700.00
0005434137828	28549	Economy	7700.00
0005434137749	28549	Economy	7700.00
0005434138129	28549	Economy	7700.00
0005434137820	28549	Economy	7700.00
0005434087498	28549	Economy	7700.00
0005434137775	28549	Economy	7700.00
0005434138004	28549	Economy	7700.00
0005434137806	28549	Economy	7700.00
0005434138146	28549	Economy	8500.00
0005434137666	28549	Economy	8500.00
0005434137938	28549	Economy	8500.00
0005434137810	28549	Economy	8500.00
0005434137593	28549	Economy	8500.00
0005434137950	28549	Economy	7700.00
0005434137897	28549	Economy	7700.00
0005434138178	28549	Economy	7700.00
0005434137790	28549	Economy	7700.00
0005434138115	28549	Economy	7700.00
0005434138175	28549	Economy	7700.00
0005434138174	28549	Economy	7700.00
0005434138067	28549	Economy	7700.00
0005434137884	28549	Economy	7700.00
0005434138057	28549	Economy	7700.00
0005434137907	28549	Economy	7700.00
0005434138246	28549	Economy	7700.00
0005434137826	28549	Economy	7700.00
0005434137772	28549	Economy	7700.00
0005434137861	28549	Economy	7700.00
0005434137838	28549	Economy	7700.00
0005434138260	28549	Economy	7700.00
0005434137604	28549	Economy	7700.00
0005434138329	28549	Economy	7700.00
0005434137927	28549	Economy	7700.00
0005434137864	28549	Economy	7700.00
0005434137728	28549	Economy	7700.00
0005434138005	28549	Economy	7700.00
0005434137821	28549	Economy	7700.00
0005434137844	28549	Economy	7700.00
0005434137945	28549	Economy	7700.00
0005434137928	28549	Economy	7700.00
0005434137979	28549	Economy	7700.00
0005434138022	28549	Economy	7700.00
0005434087514	28549	Economy	7700.00
0005434137991	28549	Economy	7700.00
0005434137973	28549	Economy	7700.00
0005434087513	28549	Economy	7700.00
0005434137914	28549	Economy	7700.00
0005434138327	28549	Economy	7700.00
0005434137750	28549	Economy	7700.00
0005434138120	28549	Economy	7700.00
0005434137913	28549	Economy	7700.00
0005434137700	28549	Economy	7700.00
0005434137955	28549	Economy	7700.00
0005434137574	28549	Economy	7700.00
0005434137832	28549	Economy	7700.00
0005434138058	28549	Economy	7700.00
0005434137774	28549	Economy	7700.00
0005434137946	28549	Economy	7700.00
0005434137811	28549	Economy	7700.00
0005434087499	28549	Economy	7700.00
0005434137770	28549	Economy	7700.00
0005434137819	28549	Economy	7700.00
0005434138038	28549	Economy	7700.00
0005434138177	28549	Economy	7700.00
0005434137943	28549	Economy	7700.00
0005434137833	28549	Economy	7700.00
0005434137942	28549	Economy	7700.00
0005434138066	28549	Economy	7700.00
0005434137793	28549	Economy	7700.00
0005434137887	28549	Economy	7700.00
0005434138070	28549	Economy	7700.00
0005434138123	28549	Economy	7700.00
0005434138024	28549	Economy	7700.00
0005434137765	28549	Economy	7700.00
0005434137888	28549	Economy	7700.00
0005434137908	28549	Economy	7700.00
0005434137909	28549	Economy	7700.00
0005434137702	28549	Economy	7700.00
0005434137935	28549	Economy	7700.00
0005435808309	1937	Economy	23900.00
0005435808311	1937	Economy	23900.00
0005433407546	1937	Economy	21700.00
0005433407554	1937	Economy	21700.00
0005433407540	1937	Economy	21700.00
0005435808310	1937	Economy	21700.00
0005433407551	1937	Economy	21700.00
0005433407545	1937	Economy	21700.00
0005435808314	1937	Economy	21700.00
0005434610256	1937	Economy	21700.00
0005435808308	1937	Economy	21700.00
0005435808305	1937	Economy	21700.00
0005435808312	1937	Economy	21700.00
0005434610255	1937	Economy	21700.00
0005435808306	1937	Economy	21700.00
0005435808313	1937	Economy	21700.00
0005433407539	1937	Economy	21700.00
0005435808307	1937	Economy	21700.00
0005435808315	1937	Economy	21700.00
0005433407552	1937	Economy	21700.00
0005435808211	23100	Economy	23900.00
0005435808144	23100	Economy	23900.00
0005433407600	23100	Economy	21700.00
0005434610227	23100	Economy	21700.00
0005433407595	23100	Economy	21700.00
0005434610218	23100	Economy	21700.00
0005435808176	23100	Economy	21700.00
0005435808186	23100	Economy	21700.00
0005434610232	23100	Economy	21700.00
0005435808191	23100	Economy	21700.00
0005435808162	23100	Economy	21700.00
0005435808141	23100	Economy	21700.00
0005435808210	23100	Economy	21700.00
0005435808209	23100	Economy	21700.00
0005433407594	23100	Economy	21700.00
0005435808184	23100	Economy	21700.00
0005435808153	23100	Economy	21700.00
0005434610211	23100	Economy	21700.00
0005435808136	23100	Economy	21700.00
0005435808230	23100	Economy	21700.00
0005435808140	23100	Economy	21700.00
0005435808183	23100	Economy	21700.00
0005434610230	23100	Economy	21700.00
0005435808261	23100	Economy	21700.00
0005435808192	23100	Economy	21700.00
0005435808208	23100	Economy	21700.00
0005434610226	23100	Economy	21700.00
0005433407593	23100	Economy	21700.00
0005433407596	23100	Economy	21700.00
0005433407597	23100	Economy	21700.00
0005433407598	23100	Economy	21700.00
0005433407592	23100	Economy	21700.00
0005435808166	23100	Economy	21700.00
0005434610229	23100	Economy	21700.00
0005435808167	23100	Economy	21700.00
0005435808185	23100	Economy	21700.00
0005435808229	23100	Economy	21700.00
0005435808181	23100	Economy	21700.00
0005435808260	23100	Economy	21700.00
0005433407599	23100	Economy	21700.00
0005434504147	16689	Economy	7600.00
0005434504135	16689	Economy	6900.00
0005434503960	16689	Economy	6900.00
0005434504139	16689	Economy	6900.00
0005434504097	16689	Economy	6900.00
0005434503959	16689	Economy	6900.00
0005434503870	16689	Economy	6900.00
0005434504076	16689	Economy	6900.00
0005434504001	16689	Economy	6900.00
0005434503978	16689	Economy	6900.00
0005434504074	16689	Economy	6900.00
0005434503910	16689	Economy	6900.00
0005434503974	16689	Economy	6900.00
0005434504140	16689	Economy	6900.00
0005434504110	16689	Economy	6900.00
0005434504016	16689	Economy	6900.00
0005434503871	16689	Economy	6900.00
0005434504156	16689	Economy	6900.00
0005434504004	16689	Economy	6900.00
0005434504066	16689	Economy	6900.00
0005434504134	16689	Economy	6900.00
0005434504163	16689	Economy	6900.00
0005434504149	16689	Economy	6900.00
0005434504119	16689	Economy	6900.00
0005434504109	16689	Economy	6900.00
0005434504008	16689	Economy	6900.00
0005434503975	16689	Economy	6900.00
0005434503911	16689	Economy	6900.00
0005434503979	16689	Economy	6900.00
0005434504188	16689	Economy	6900.00
0005434504061	16689	Economy	6900.00
0005434504148	16689	Economy	6900.00
0005434504065	16689	Economy	6900.00
0005434504416	22924	Economy	7600.00
0005434504404	22924	Economy	7600.00
0005434504389	22924	Economy	7600.00
0005434504414	22924	Economy	7600.00
0005434504402	22924	Economy	6900.00
0005434504422	22924	Economy	6900.00
0005434504398	22924	Economy	6900.00
0005434504391	22924	Economy	6900.00
0005434504395	22924	Economy	6900.00
0005434504392	22924	Economy	6900.00
0005434504390	22924	Economy	6900.00
0005434504408	22924	Economy	6900.00
0005434504385	22924	Economy	6900.00
0005434504406	22924	Economy	6900.00
0005434504400	22924	Economy	6900.00
0005434504420	22924	Economy	6900.00
0005434504393	22924	Economy	6900.00
0005434504419	22924	Economy	6900.00
0005434504413	22924	Economy	6900.00
0005434504403	22924	Economy	6900.00
0005434504421	22924	Economy	6900.00
0005434504388	22924	Economy	6900.00
0005434504409	22924	Economy	6900.00
0005434504418	22924	Economy	6900.00
0005434504412	22924	Economy	6900.00
0005434504399	22924	Economy	6900.00
0005434504411	22924	Economy	6900.00
0005434504397	22924	Economy	6900.00
0005434504396	22924	Economy	6900.00
0005434504417	22924	Economy	6900.00
0005434504410	22924	Economy	6900.00
0005434504394	22924	Economy	6900.00
0005434504415	22924	Economy	6900.00
0005434504383	22924	Economy	6900.00
0005434504407	22924	Economy	6900.00
0005434504386	22924	Economy	6900.00
0005434504423	22924	Economy	6900.00
0005434504384	22924	Economy	6900.00
0005434504405	22924	Economy	6900.00
0005434504387	22924	Economy	6900.00
0005434504401	22924	Economy	6900.00
0005433266693	2204	Economy	7700.00
0005435078453	2204	Economy	7700.00
0005433266698	2204	Economy	7000.00
0005433266725	2204	Economy	7000.00
0005433266700	2204	Economy	7000.00
0005435078446	2204	Economy	7000.00
0005433266694	2204	Economy	7000.00
0005435078457	2204	Economy	7000.00
0005435078461	2204	Economy	7000.00
0005435078451	2204	Economy	7000.00
0005435078454	2204	Economy	7000.00
0005435078452	2204	Economy	7000.00
0005435078459	2204	Economy	7000.00
0005435078447	2204	Economy	7000.00
0005435078450	2204	Economy	7000.00
0005433266661	2204	Economy	7000.00
0005435078460	2204	Economy	7000.00
0005435078456	2204	Economy	7000.00
0005433266762	2204	Economy	7000.00
0005435078458	2204	Economy	7000.00
0005433266699	2204	Economy	7000.00
0005433266726	2204	Economy	7000.00
0005435078448	2204	Economy	7000.00
0005435078449	2204	Economy	7000.00
0005435078455	2204	Economy	7000.00
0005435078264	24370	Economy	7700.00
0005435078340	24370	Economy	7000.00
0005433266789	24370	Economy	7000.00
0005433266788	24370	Economy	7000.00
0005435078364	24370	Economy	7000.00
0005433266792	24370	Economy	7000.00
0005435078339	24370	Economy	7000.00
0005433266786	24370	Economy	7000.00
0005433266787	24370	Economy	7000.00
0005435078265	24370	Economy	7000.00
0005433266791	24370	Economy	7000.00
0005435078336	24370	Economy	7000.00
0005435078284	24370	Economy	7000.00
0005435078272	24370	Economy	7000.00
0005435078314	24370	Economy	7000.00
0005435078350	24370	Economy	7000.00
0005435078312	24370	Economy	7000.00
0005435078311	24370	Economy	7000.00
0005433266790	24370	Economy	7000.00
0005435078352	24370	Economy	7000.00
0005435078324	24370	Economy	7000.00
0005435078281	24370	Economy	7000.00
0005435078365	24370	Economy	7000.00
0005433266793	24370	Economy	7000.00
0005433266794	24370	Economy	7000.00
0005434988817	6623	Economy	10800.00
0005435803284	6623	Economy	10800.00
0005434988820	6623	Economy	9800.00
0005434988816	6623	Economy	9800.00
0005434988815	6623	Economy	9800.00
0005434988812	6623	Economy	9800.00
0005435464499	6623	Economy	9800.00
0005435464507	6623	Economy	9800.00
0005434988819	6623	Economy	9800.00
0005435803283	6623	Economy	9800.00
0005434988814	6623	Economy	9800.00
0005435464508	6623	Economy	9800.00
0005435464500	6623	Economy	9800.00
0005434988818	6623	Economy	9800.00
0005435464506	6623	Economy	9800.00
0005434988813	6623	Economy	9800.00
0005435803285	6623	Economy	9800.00
0005434988653	23591	Economy	10800.00
0005435803250	23591	Economy	10800.00
0005435803238	23591	Economy	10800.00
0005434988687	23591	Economy	9800.00
0005434988668	23591	Economy	9800.00
0005434988688	23591	Economy	9800.00
0005435803268	23591	Economy	9800.00
0005435803266	23591	Economy	9800.00
0005434988657	23591	Economy	9800.00
0005435803260	23591	Economy	9800.00
0005434988690	23591	Economy	9800.00
0005435803253	23591	Economy	9800.00
0005434988681	23591	Economy	9800.00
0005435803251	23591	Economy	9800.00
0005435464523	23591	Economy	9800.00
0005435803239	23591	Economy	9800.00
0005435464522	23591	Economy	9800.00
0005434988682	23591	Economy	9800.00
0005435803265	23591	Economy	9800.00
0005434988680	23591	Economy	9800.00
0005435464521	23591	Economy	9800.00
0005433450125	30479	Business	9900.00
0005433450120	30479	Business	9900.00
0005432383472	30479	Business	9900.00
0005432383470	30479	Business	9900.00
0005432383484	30479	Business	9900.00
0005433450121	30479	Business	9900.00
0005432383464	30479	Business	9900.00
0005433450136	30479	Economy	3300.00
0005432383456	30479	Economy	3300.00
0005432383473	30479	Economy	3300.00
0005432383457	30479	Economy	3300.00
0005432383453	30479	Economy	3300.00
0005432383460	30479	Economy	3300.00
0005433450123	30479	Economy	3600.00
0005433453774	30479	Economy	3600.00
0005433450127	30479	Economy	3600.00
0005432383448	30479	Economy	3600.00
0005432383486	30479	Economy	3600.00
0005432383479	30479	Economy	3300.00
0005433450128	30479	Economy	3300.00
0005432383482	30479	Economy	3300.00
0005433450130	30479	Economy	3300.00
0005433450133	30479	Economy	3300.00
0005433450135	30479	Economy	3300.00
0005433450132	30479	Economy	3300.00
0005433450137	30479	Economy	3300.00
0005432383465	30479	Economy	3300.00
0005433450140	30479	Economy	3300.00
0005432383459	30479	Economy	3300.00
0005432383447	30479	Economy	3300.00
0005432383445	30479	Economy	3300.00
0005432383468	30479	Economy	3300.00
0005433450139	30479	Economy	3300.00
0005432383462	30479	Economy	3300.00
0005433450122	30479	Economy	3300.00
0005432383466	30479	Economy	3300.00
0005432383454	30479	Economy	3300.00
0005432383485	30479	Economy	3300.00
0005432383481	30479	Economy	3300.00
0005433450129	30479	Economy	3300.00
0005432383476	30479	Economy	3300.00
0005433450131	30479	Economy	3300.00
0005432383478	30479	Economy	3300.00
0005432383487	30479	Economy	3300.00
0005432383461	30479	Economy	3300.00
0005432383455	30479	Economy	3300.00
0005433450119	30479	Economy	3300.00
0005433450134	30479	Economy	3300.00
0005432383463	30479	Economy	3300.00
0005432383480	30479	Economy	3300.00
0005433450124	30479	Economy	3300.00
0005433450138	30479	Economy	3300.00
0005432383452	30479	Economy	3300.00
0005432383458	30479	Economy	3300.00
0005432383449	30479	Economy	3300.00
0005432383451	30479	Economy	3300.00
0005432383444	30479	Economy	3300.00
0005432383483	30479	Economy	3300.00
0005432383450	30479	Economy	3300.00
0005432383471	30479	Economy	3300.00
0005432383474	30479	Economy	3300.00
0005432383446	30479	Economy	3300.00
0005432383469	30479	Economy	3300.00
0005432383467	30479	Economy	3300.00
0005433453773	30479	Economy	3300.00
0005432383477	30479	Economy	3300.00
0005432383475	30479	Economy	3300.00
0005433450126	30479	Economy	3300.00
0005432382904	31292	Business	9900.00
0005432382980	31292	Business	9900.00
0005433449963	31292	Business	9900.00
0005432383086	31292	Business	9900.00
0005432383051	31292	Business	9900.00
0005432383033	31292	Business	9900.00
0005433449998	31292	Business	9900.00
0005432383044	31292	Business	9900.00
0005433449892	31292	Business	9900.00
0005432382992	31292	Business	9900.00
0005433451620	31292	Economy	3300.00
0005432383083	31292	Economy	3300.00
0005433449954	31292	Economy	3300.00
0005433449900	31292	Economy	3600.00
0005433449933	31292	Economy	3600.00
0005432383019	31292	Economy	3300.00
0005433449905	31292	Economy	3300.00
0005432383008	31292	Economy	3300.00
0005433449962	31292	Economy	3300.00
0005432382848	31292	Economy	3300.00
0005432383052	31292	Economy	3300.00
0005432382942	31292	Economy	3300.00
0005433449893	31292	Economy	3300.00
0005432383007	31292	Economy	3300.00
0005433449968	31292	Economy	3300.00
0005432382973	31292	Economy	3300.00
0005433450037	31292	Economy	3300.00
0005432383009	31292	Economy	3300.00
0005432382856	31292	Economy	3300.00
0005432383045	31292	Economy	3300.00
0005433449961	31292	Economy	3300.00
0005432382951	31292	Economy	3300.00
0005433449921	31292	Economy	3300.00
0005433451617	31292	Economy	3300.00
0005432383076	31292	Economy	3300.00
0005433451619	31292	Economy	3300.00
0005433450044	31292	Economy	3300.00
0005432382932	31292	Economy	3300.00
0005432383053	31292	Economy	3300.00
0005433449976	31292	Economy	3300.00
0005432382974	31292	Economy	3300.00
0005432382991	31292	Economy	3300.00
0005432383018	31292	Economy	3300.00
0005432383082	31292	Economy	3300.00
0005432382965	31292	Economy	3300.00
0005432383030	31292	Economy	3300.00
0005432383063	31292	Economy	3300.00
0005433449894	31292	Economy	3300.00
0005432383000	31292	Economy	3300.00
0005432383046	31292	Economy	3300.00
0005432383048	31292	Economy	3300.00
0005432383006	31292	Economy	3300.00
0005433450041	31292	Economy	3300.00
0005432383040	31292	Economy	3300.00
0005432383078	31292	Economy	3300.00
0005432382955	31292	Economy	3300.00
0005432383055	31292	Economy	3300.00
0005432383039	31292	Economy	3300.00
0005432383054	31292	Economy	3300.00
0005433453758	31292	Economy	3300.00
0005432383020	31292	Economy	3300.00
0005432382895	31292	Economy	3300.00
0005432382896	31292	Economy	3300.00
0005435299780	10790	Economy	17100.00
0005433131700	10790	Economy	17100.00
0005433126827	10790	Economy	15600.00
0005433131699	10790	Economy	15600.00
0005433126831	10790	Economy	15600.00
0005435299755	10790	Economy	15600.00
0005433131686	10790	Economy	15600.00
0005433131684	10790	Economy	15600.00
0005433131698	10790	Economy	15600.00
0005435299778	10790	Economy	15600.00
0005433131688	10790	Economy	15600.00
0005433126836	10790	Economy	15600.00
0005433126828	10790	Economy	15600.00
0005435299774	10790	Economy	15600.00
0005435299754	10790	Economy	15600.00
0005433131685	10790	Economy	15600.00
0005433126835	10790	Economy	15600.00
0005435299779	10790	Economy	15600.00
0005433126846	10790	Economy	15600.00
0005433126847	10790	Economy	15600.00
0005435304151	10790	Economy	15600.00
0005433131687	10790	Economy	15600.00
0005433126883	29731	Economy	17100.00
0005435302237	29731	Economy	15600.00
0005435299813	29731	Economy	15600.00
0005435302235	29731	Economy	15600.00
0005433129315	29731	Economy	15600.00
0005433129312	29731	Economy	15600.00
0005435299812	29731	Economy	15600.00
0005433129311	29731	Economy	15600.00
0005433126884	29731	Economy	15600.00
0005435302238	29731	Economy	15600.00
0005435299814	29731	Economy	15600.00
0005433129313	29731	Economy	15600.00
0005433126882	29731	Economy	15600.00
0005433126881	29731	Economy	15600.00
0005435302236	29731	Economy	15600.00
0005435299815	29731	Economy	15600.00
0005433126880	29731	Economy	15600.00
0005435299816	29731	Economy	15600.00
0005433129314	29731	Economy	15600.00
0005433110074	2405	Economy	17200.00
0005434287450	2405	Economy	17200.00
0005433110007	2405	Economy	17200.00
0005434287440	2405	Economy	17200.00
0005434287448	2405	Economy	15700.00
0005434287452	2405	Economy	15700.00
0005434287459	2405	Economy	15700.00
0005434287461	2405	Economy	15700.00
0005434287444	2405	Economy	15700.00
0005434287451	2405	Economy	15700.00
0005433110048	2405	Economy	15700.00
0005434287454	2405	Economy	15700.00
0005433110018	2405	Economy	15700.00
0005434287449	2405	Economy	15700.00
0005433110049	2405	Economy	15700.00
0005432264493	2405	Economy	15700.00
0005434287443	2405	Economy	15700.00
0005433110073	2405	Economy	15700.00
0005434287453	2405	Economy	15700.00
0005434287455	2405	Economy	15700.00
0005434287447	2405	Economy	15700.00
0005434287457	2405	Economy	15700.00
0005434287441	2405	Economy	15700.00
0005432264494	2405	Economy	15700.00
0005433110051	2405	Economy	15700.00
0005434287456	2405	Economy	15700.00
0005434287442	2405	Economy	15700.00
0005434287445	2405	Economy	15700.00
0005434287460	2405	Economy	15700.00
0005434287446	2405	Economy	15700.00
0005433110054	2405	Economy	15700.00
0005433110055	2405	Economy	15700.00
0005432264492	2405	Economy	15700.00
0005433110017	2405	Economy	15700.00
0005434287458	2405	Economy	15700.00
0005433110139	26859	Economy	17200.00
0005433110143	26859	Economy	17200.00
0005434287259	26859	Economy	17200.00
0005433110146	26859	Economy	15700.00
0005434287227	26859	Economy	15700.00
0005434287228	26859	Economy	15700.00
0005434287208	26859	Economy	15700.00
0005434287258	26859	Economy	15700.00
0005433110145	26859	Economy	15700.00
0005434287245	26859	Economy	15700.00
0005433110144	26859	Economy	15700.00
0005433110136	26859	Economy	15700.00
0005433110142	26859	Economy	15700.00
0005434287280	26859	Economy	15700.00
0005434287193	26859	Economy	15700.00
0005434287127	26859	Economy	15700.00
0005434287233	26859	Economy	15700.00
0005434287250	26859	Economy	15700.00
0005434287254	26859	Economy	15700.00
0005434287281	26859	Economy	15700.00
0005434287237	26859	Economy	15700.00
0005434287232	26859	Economy	15700.00
0005433110141	26859	Economy	15700.00
0005433110140	26859	Economy	15700.00
0005433110137	26859	Economy	15700.00
0005434287231	26859	Economy	15700.00
0005434287251	26859	Economy	15700.00
0005434287202	26859	Economy	15700.00
0005434287265	26859	Economy	15700.00
0005433110138	26859	Economy	15700.00
0005434287215	26859	Economy	15700.00
0005433110135	26859	Economy	15700.00
0005434287190	26859	Economy	15700.00
0005434287126	26859	Economy	15700.00
0005434287264	26859	Economy	15700.00
0005434287226	26859	Economy	15700.00
0005434269092	25458	Economy	25000.00
0005435856235	25458	Economy	22800.00
0005434272183	25458	Economy	22800.00
0005434269101	25458	Economy	22800.00
0005435856234	25458	Economy	22800.00
0005435856233	25458	Economy	22800.00
0005435856236	25458	Economy	22800.00
0005434273089	26643	Economy	22800.00
0005435856189	26643	Economy	22800.00
0005435854056	26643	Economy	22800.00
0005435856200	26643	Economy	22800.00
0005435856188	26643	Economy	22800.00
0005434273090	26643	Economy	22800.00
0005435856184	26643	Economy	22800.00
0005435854055	26643	Economy	22800.00
0005434273088	26643	Economy	22800.00
0005434272204	26643	Economy	22800.00
0005435854058	26643	Economy	22800.00
0005435856201	26643	Economy	22800.00
0005435854057	26643	Economy	22800.00
0005435856183	26643	Economy	22800.00
0005435856199	26643	Economy	22800.00
0005433868731	4767	Economy	19400.00
0005433868715	4767	Economy	19400.00
0005433868724	4767	Economy	19400.00
0005433868748	4767	Economy	19400.00
0005433868740	4767	Economy	17600.00
0005433868718	4767	Economy	17600.00
0005433868747	4767	Economy	17600.00
0005433868736	4767	Economy	17600.00
0005433868730	4767	Economy	17600.00
0005433868745	4767	Economy	17600.00
0005433868727	4767	Economy	17600.00
0005433868711	4767	Economy	17600.00
0005433868751	4767	Economy	17600.00
0005433868741	4767	Economy	17600.00
0005433868733	4767	Economy	17600.00
0005433868737	4767	Economy	17600.00
0005435860473	4767	Economy	17600.00
0005435860478	4767	Economy	17600.00
0005433868725	4767	Economy	17600.00
0005433868722	4767	Economy	17600.00
0005433868734	4767	Economy	17600.00
0005433868713	4767	Economy	17600.00
0005433868712	4767	Economy	17600.00
0005433868746	4767	Economy	17600.00
0005433868743	4767	Economy	17600.00
0005433868721	4767	Economy	17600.00
0005435860474	4767	Economy	17600.00
0005435860479	4767	Economy	17600.00
0005433868728	4767	Economy	17600.00
0005433868739	4767	Economy	17600.00
0005433868729	4767	Economy	17600.00
0005433868726	4767	Economy	17600.00
0005433868723	4767	Economy	17600.00
0005433868744	4767	Economy	17600.00
0005433868750	4767	Economy	17600.00
0005433868714	4767	Economy	17600.00
0005433868717	4767	Economy	17600.00
0005433868752	4767	Economy	17600.00
0005433868742	4767	Economy	17600.00
0005433868719	4767	Economy	17600.00
0005433868716	4767	Economy	17600.00
0005433868735	4767	Economy	17600.00
0005433868720	4767	Economy	17600.00
0005433868732	4767	Economy	17600.00
0005433868738	4767	Economy	17600.00
0005433868749	4767	Economy	17600.00
0005433868238	32598	Economy	19400.00
0005433868449	32598	Economy	19400.00
0005433868507	32598	Economy	19400.00
0005433868191	32598	Economy	19400.00
0005433868307	32598	Economy	17600.00
0005433868374	32598	Economy	17600.00
0005433868332	32598	Economy	17600.00
0005433868313	32598	Economy	17600.00
0005433868240	32598	Economy	17600.00
0005433868409	32598	Economy	17600.00
0005433868340	32598	Economy	17600.00
0005433868426	32598	Economy	17600.00
0005433868459	32598	Economy	17600.00
0005433868433	32598	Economy	17600.00
0005433868377	32598	Economy	17600.00
0005433868237	32598	Economy	17600.00
0005433868506	32598	Economy	17600.00
0005433868424	32598	Economy	17600.00
0005433868301	32598	Economy	17600.00
0005433868273	32598	Economy	17600.00
0005433868378	32598	Economy	17600.00
0005433868458	32598	Economy	17600.00
0005433868239	32598	Economy	17600.00
0005433868384	32598	Economy	17600.00
0005433868303	32598	Economy	17600.00
0005433868425	32598	Economy	17600.00
0005433868183	32598	Economy	17600.00
0005433868311	32598	Economy	17600.00
0005433868277	32598	Economy	17600.00
0005433868375	32598	Economy	17600.00
0005433868508	32598	Economy	17600.00
0005433868244	32598	Economy	17600.00
0005433868373	32598	Economy	17600.00
0005433868297	32598	Economy	17600.00
0005433868394	32598	Economy	17600.00
0005433868294	32598	Economy	17600.00
0005433868383	32598	Economy	17600.00
0005433868455	32598	Economy	17600.00
0005433868438	32598	Economy	17600.00
0005433868418	32598	Economy	17600.00
0005433868423	32598	Economy	17600.00
0005433868274	32598	Economy	17600.00
0005433868522	32598	Economy	17600.00
0005433868312	32598	Economy	17600.00
0005433868302	32598	Economy	17600.00
0005433868193	32598	Economy	17600.00
0005433868182	32598	Economy	17600.00
0005433868304	32598	Economy	17600.00
0005433868293	32598	Economy	17600.00
0005434663503	3438	Economy	24800.00
0005434663509	3438	Economy	22600.00
0005434460521	3438	Economy	22600.00
0005435911460	3438	Economy	22600.00
0005434663507	3438	Economy	22600.00
0005435911452	3438	Economy	22600.00
0005434663504	3438	Economy	22600.00
0005434663508	3438	Economy	22600.00
0005434461662	3438	Economy	22600.00
0005434663512	3438	Economy	22600.00
0005435911426	3438	Economy	22600.00
0005435911451	3438	Economy	22600.00
0005434663505	3438	Economy	22600.00
0005434663502	3438	Economy	22600.00
0005434663511	3438	Economy	22600.00
0005435911453	3438	Economy	22600.00
0005435911479	3438	Economy	22600.00
0005434663510	3438	Economy	22600.00
0005435911439	3438	Economy	22600.00
0005434663506	3438	Economy	22600.00
0005434460522	3438	Economy	22600.00
0005434663513	3438	Economy	22600.00
0005434461663	3438	Economy	22600.00
0005434663370	12459	Economy	24800.00
0005434663369	12459	Economy	24800.00
0005434663384	12459	Economy	24800.00
0005434663353	12459	Economy	22600.00
0005434663422	12459	Economy	22600.00
0005434663419	12459	Economy	22600.00
0005434663400	12459	Economy	22600.00
0005434663401	12459	Economy	22600.00
0005434663371	12459	Economy	22600.00
0005435911503	12459	Economy	22600.00
0005435911506	12459	Economy	22600.00
0005434663391	12459	Economy	22600.00
0005434663392	12459	Economy	22600.00
0005434663421	12459	Economy	22600.00
0005435911504	12459	Economy	22600.00
0005434663397	12459	Economy	22600.00
0005434663355	12459	Economy	22600.00
0005435911510	12459	Economy	22600.00
0005435911509	12459	Economy	22600.00
0005434663408	12459	Economy	22600.00
0005434663427	12459	Economy	22600.00
0005434663354	12459	Economy	22600.00
0005434663386	12459	Economy	22600.00
0005434663423	12459	Economy	22600.00
0005435911508	12459	Economy	22600.00
0005434663412	12459	Economy	22600.00
0005435911505	12459	Economy	22600.00
0005435911507	12459	Economy	22600.00
0005434663428	12459	Economy	22600.00
0005433868240	14483	Economy	18500.00
0005433868239	14483	Economy	18500.00
0005433868426	14483	Economy	18500.00
0005433868303	14483	Economy	18500.00
0005433868191	14483	Economy	16800.00
0005433868424	14483	Economy	16800.00
0005433868507	14483	Economy	16800.00
0005433868332	14483	Economy	16800.00
0005433868374	14483	Economy	16800.00
0005433868373	14483	Economy	16800.00
0005433868425	14483	Economy	16800.00
0005433868455	14483	Economy	16800.00
0005433868274	14483	Economy	16800.00
0005433868304	14483	Economy	16800.00
0005433868193	14483	Economy	16800.00
0005433868394	14483	Economy	16800.00
0005433868340	14483	Economy	16800.00
0005433868459	14483	Economy	16800.00
0005433868438	14483	Economy	16800.00
0005433868377	14483	Economy	16800.00
0005433868458	14483	Economy	16800.00
0005433868449	14483	Economy	16800.00
0005433868237	14483	Economy	16800.00
0005433868244	14483	Economy	16800.00
0005433868312	14483	Economy	16800.00
0005433868183	14483	Economy	16800.00
0005433868383	14483	Economy	16800.00
0005433868297	14483	Economy	16800.00
0005433868506	14483	Economy	16800.00
0005433868384	14483	Economy	16800.00
0005433868375	14483	Economy	16800.00
0005433868294	14483	Economy	16800.00
0005433868508	14483	Economy	16800.00
0005433868302	14483	Economy	16800.00
0005433868273	14483	Economy	16800.00
0005433868182	14483	Economy	16800.00
0005433868311	14483	Economy	16800.00
0005433868293	14483	Economy	16800.00
0005433868522	14483	Economy	16800.00
0005433868238	14483	Economy	16800.00
0005433868313	14483	Economy	16800.00
0005433868277	14483	Economy	16800.00
0005433868409	14483	Economy	16800.00
0005433868301	14483	Economy	16800.00
0005433868433	14483	Economy	16800.00
0005433868307	14483	Economy	16800.00
0005433868378	14483	Economy	16800.00
0005433868423	14483	Economy	16800.00
0005433868418	14483	Economy	16800.00
0005433868672	32660	Economy	18500.00
0005433868701	32660	Economy	18500.00
0005433868703	32660	Economy	18500.00
0005433868683	32660	Economy	18500.00
0005433868673	32660	Economy	16800.00
0005433868704	32660	Economy	16800.00
0005433868706	32660	Economy	16800.00
0005433868699	32660	Economy	16800.00
0005433868709	32660	Economy	16800.00
0005433868671	32660	Economy	16800.00
0005433868681	32660	Economy	16800.00
0005433868698	32660	Economy	16800.00
0005433868688	32660	Economy	16800.00
0005433868678	32660	Economy	16800.00
0005433868682	32660	Economy	16800.00
0005433868705	32660	Economy	16800.00
0005433868670	32660	Economy	16800.00
0005433868689	32660	Economy	16800.00
0005433868680	32660	Economy	16800.00
0005433868690	32660	Economy	16800.00
0005433868675	32660	Economy	16800.00
0005433868674	32660	Economy	16800.00
0005433868684	32660	Economy	16800.00
0005433868677	32660	Economy	16800.00
0005433868710	32660	Economy	16800.00
0005433868687	32660	Economy	16800.00
0005433868694	32660	Economy	16800.00
0005435860468	32660	Economy	16800.00
0005433868695	32660	Economy	16800.00
0005433868686	32660	Economy	16800.00
0005433868685	32660	Economy	16800.00
0005433868697	32660	Economy	16800.00
0005433868676	32660	Economy	16800.00
0005433868696	32660	Economy	16800.00
0005433868702	32660	Economy	16800.00
0005433868700	32660	Economy	16800.00
0005435860480	32660	Economy	16800.00
0005433868692	32660	Economy	16800.00
0005433868693	32660	Economy	16800.00
0005433868691	32660	Economy	16800.00
0005433868708	32660	Economy	16800.00
0005433868679	32660	Economy	16800.00
0005433868707	32660	Economy	16800.00
0005432799380	12100	Economy	4900.00
0005432799419	12100	Economy	4400.00
0005432799452	12100	Economy	4400.00
0005432799428	12100	Economy	4400.00
0005432799401	12100	Economy	4400.00
0005432799457	12100	Economy	4400.00
0005432799338	12100	Economy	4400.00
0005432799432	12100	Economy	4400.00
0005432799436	12100	Economy	4400.00
0005432799323	12100	Economy	4400.00
0005432799363	12100	Economy	4400.00
0005432799433	12100	Economy	4400.00
0005432799456	12100	Economy	4400.00
0005432799442	12100	Economy	4400.00
0005432799496	12100	Economy	4400.00
0005432799473	12100	Economy	4400.00
0005432799465	12100	Economy	4400.00
0005432799420	12100	Economy	4400.00
0005432799381	12100	Economy	4400.00
0005432799362	12100	Economy	4400.00
0005432799443	12100	Economy	4400.00
0005432799501	12100	Economy	4400.00
0005432799510	12100	Economy	4400.00
0005432799495	12100	Economy	4400.00
0005432799637	14836	Economy	4900.00
0005432799619	14836	Economy	4900.00
0005432799627	14836	Economy	4900.00
0005432799630	14836	Economy	4900.00
0005432799633	14836	Economy	4400.00
0005432799641	14836	Economy	4400.00
0005432799635	14836	Economy	4400.00
0005432799618	14836	Economy	4400.00
0005432799634	14836	Economy	4400.00
0005432799632	14836	Economy	4400.00
0005432799631	14836	Economy	4400.00
0005432799642	14836	Economy	4400.00
0005432799645	14836	Economy	4400.00
0005432799620	14836	Economy	4400.00
0005432799625	14836	Economy	4400.00
0005432799629	14836	Economy	4400.00
0005432799621	14836	Economy	4400.00
0005432799644	14836	Economy	4400.00
0005432799640	14836	Economy	4400.00
0005432799638	14836	Economy	4400.00
0005432799639	14836	Economy	4400.00
0005432799622	14836	Economy	4400.00
0005432799636	14836	Economy	4400.00
0005432799626	14836	Economy	4400.00
0005432799646	14836	Economy	4400.00
0005432799628	14836	Economy	4400.00
0005432799643	14836	Economy	4400.00
0005432799624	14836	Economy	4400.00
0005432799623	14836	Economy	4400.00
0005434299726	7055	Business	49100.00
0005434408211	7055	Business	49100.00
0005434299720	7055	Business	49100.00
0005435293225	7055	Business	49100.00
0005434299735	7055	Business	49100.00
0005435311024	7055	Business	49100.00
0005434299731	7055	Business	49100.00
0005435293224	7055	Business	49100.00
0005435293239	7055	Business	49100.00
0005432153992	7055	Business	49100.00
0005434408244	7055	Business	49100.00
0005434408242	7055	Economy	16400.00
0005434299727	7055	Economy	16400.00
0005434408225	7055	Economy	16400.00
0005434408199	7055	Economy	16400.00
0005434299741	7055	Economy	16400.00
0005434408224	7055	Economy	16400.00
0005434408253	7055	Economy	16400.00
0005432153988	7055	Economy	16400.00
0005434408216	7055	Economy	16400.00
0005432153987	7055	Economy	16400.00
0005434299732	7055	Economy	16400.00
0005434299733	7055	Economy	16400.00
0005432108269	7055	Economy	16400.00
0005434408215	7055	Economy	16400.00
0005435293208	7055	Economy	16400.00
0005434408204	7055	Economy	16400.00
0005434299737	7055	Economy	16400.00
0005432153991	7055	Economy	16400.00
0005432108268	7055	Economy	16400.00
0005434408194	7055	Economy	16400.00
0005434408198	7055	Economy	16400.00
0005434408200	7055	Economy	16400.00
0005434408220	7055	Economy	16400.00
0005434299730	7055	Economy	16400.00
0005435293227	7055	Economy	16400.00
0005434408245	7055	Economy	16400.00
0005434408191	7055	Economy	16400.00
0005435293230	7055	Economy	16400.00
0005434408202	7055	Economy	16400.00
0005434408240	7055	Economy	16400.00
0005434408219	7055	Economy	16400.00
0005435293244	7055	Economy	16400.00
0005434408201	7055	Economy	16400.00
0005434299718	7055	Economy	16400.00
0005434408243	7055	Economy	16400.00
0005432153989	7055	Economy	16400.00
0005434408221	7055	Economy	16400.00
0005435310981	7055	Economy	16400.00
0005435310979	7055	Economy	18000.00
0005434408231	7055	Economy	18000.00
0005435311010	7055	Economy	18000.00
0005434408232	7055	Economy	18000.00
0005435293268	7055	Economy	18000.00
0005435293243	7055	Economy	18000.00
0005434408208	7055	Economy	16400.00
0005434408228	7055	Economy	16400.00
0005434299722	7055	Economy	16400.00
0005434299724	7055	Economy	16400.00
0005434299728	7055	Economy	16400.00
0005435293226	7055	Economy	16400.00
0005432153985	7055	Economy	16400.00
0005434408236	7055	Economy	16400.00
0005434408234	7055	Economy	16400.00
0005434408222	7055	Economy	16400.00
0005434408226	7055	Economy	16400.00
0005434408230	7055	Economy	16400.00
0005432153990	7055	Economy	16400.00
0005435293245	7055	Economy	16400.00
0005434408217	7055	Economy	16400.00
0005434408209	7055	Economy	16400.00
0005434408197	7055	Economy	16400.00
0005434408223	7055	Economy	16400.00
0005434408205	7055	Economy	16400.00
0005434408189	7055	Economy	16400.00
0005435311032	7055	Economy	16400.00
0005435293248	7055	Economy	16400.00
0005435293231	7055	Economy	16400.00
0005434408212	7055	Economy	16400.00
0005434408233	7055	Economy	16400.00
0005434408207	7055	Economy	16400.00
0005434408192	7055	Economy	16400.00
0005434408248	7055	Economy	16400.00
0005435311019	7055	Economy	16400.00
0005435311018	7055	Economy	16400.00
0005434408214	7055	Economy	16400.00
0005434408210	7055	Economy	16400.00
0005434408247	7055	Economy	16400.00
0005434408213	7055	Economy	16400.00
0005434408218	7055	Economy	16400.00
0005432153986	7055	Economy	16400.00
0005435293308	7055	Economy	16400.00
0005434299723	7055	Economy	16400.00
0005434299725	7055	Economy	16400.00
0005435310998	7055	Economy	16400.00
0005434408241	7055	Economy	16400.00
0005434408227	7055	Economy	16400.00
0005434408206	7055	Economy	16400.00
0005434408252	7055	Economy	16400.00
0005434299736	7055	Economy	16400.00
0005434299740	7055	Economy	16400.00
0005434408238	7055	Economy	16400.00
0005434408237	7055	Economy	16400.00
0005434299719	7055	Economy	16400.00
0005435293194	7055	Economy	16400.00
0005434408196	7055	Economy	16400.00
0005434408195	7055	Economy	16400.00
0005434408239	7055	Economy	16400.00
0005434408246	7055	Economy	16400.00
0005434408190	7055	Economy	16400.00
0005434408249	7055	Economy	16400.00
0005435293217	7055	Economy	16400.00
0005435293198	7055	Economy	16400.00
0005434408203	7055	Economy	16400.00
0005434408251	7055	Economy	16400.00
0005434408250	7055	Economy	16400.00
0005434299734	7055	Economy	16400.00
0005434408235	7055	Economy	16400.00
0005434299721	7055	Economy	16400.00
0005434299739	7055	Economy	16400.00
0005435293216	7055	Economy	16400.00
0005434299738	7055	Economy	16400.00
0005434299729	7055	Economy	16400.00
0005434408193	7055	Economy	16400.00
0005434408229	7055	Economy	16400.00
0005435311025	7055	Economy	16400.00
0005434299543	26887	Business	49100.00
0005434407828	26887	Business	49100.00
0005435293343	26887	Business	49100.00
0005434299596	26887	Business	49100.00
0005434407284	26887	Business	49100.00
0005434407790	26887	Business	49100.00
0005434407466	26887	Business	49100.00
0005435293344	26887	Business	49100.00
0005434299472	26887	Business	49100.00
0005434407921	26887	Business	49100.00
0005434407594	26887	Business	49100.00
0005434299529	26887	Business	49100.00
0005434407763	26887	Economy	16400.00
0005435293346	26887	Economy	16400.00
0005434407327	26887	Economy	16400.00
0005434299498	26887	Economy	16400.00
0005434407414	26887	Economy	16400.00
0005434407789	26887	Economy	16400.00
0005434299520	26887	Economy	16400.00
0005435311138	26887	Economy	16400.00
0005434299637	26887	Economy	16400.00
0005434407690	26887	Economy	16400.00
0005434299519	26887	Economy	16400.00
0005434407565	26887	Economy	16400.00
0005434407431	26887	Economy	16400.00
0005434407505	26887	Economy	16400.00
0005434299528	26887	Economy	16400.00
0005434299525	26887	Economy	16400.00
0005434407366	26887	Economy	16400.00
0005434299595	26887	Economy	16400.00
0005434407524	26887	Economy	16400.00
0005434407475	26887	Economy	16400.00
0005435293340	26887	Economy	16400.00
0005434407639	26887	Economy	16400.00
0005434407367	26887	Economy	16400.00
0005434299556	26887	Economy	16400.00
0005434407665	26887	Economy	16400.00
0005434407282	26887	Economy	16400.00
0005434407985	26887	Economy	16400.00
0005434407674	26887	Economy	16400.00
0005434299509	26887	Economy	16400.00
0005434407612	26887	Economy	16400.00
0005434299585	26887	Economy	16400.00
0005434407399	26887	Economy	16400.00
0005434407768	26887	Economy	16400.00
0005434407691	26887	Economy	16400.00
0005434407434	26887	Economy	16400.00
0005434407398	26887	Economy	16400.00
0005432058407	26887	Economy	16400.00
0005434407429	26887	Economy	16400.00
0005434299510	26887	Economy	16400.00
0005434407666	26887	Economy	18000.00
0005432058408	26887	Economy	18000.00
0005434299526	26887	Economy	18000.00
0005434407283	26887	Economy	18000.00
0005434407750	26887	Economy	18000.00
0005435293341	26887	Economy	18000.00
0005434407711	26887	Economy	16400.00
0005434407507	26887	Economy	16400.00
0005434407520	26887	Economy	16400.00
0005434407764	26887	Economy	16400.00
0005434407901	26887	Economy	16400.00
0005432058405	26887	Economy	16400.00
0005434407843	26887	Economy	16400.00
0005434407166	26887	Economy	16400.00
0005434407735	26887	Economy	16400.00
0005434407435	26887	Economy	16400.00
0005434407669	26887	Economy	16400.00
0005434299555	26887	Economy	16400.00
0005435293345	26887	Economy	16400.00
0005434407490	26887	Economy	16400.00
0005434407572	26887	Economy	16400.00
0005434407535	26887	Economy	16400.00
0005432058406	26887	Economy	16400.00
0005434407734	26887	Economy	16400.00
0005434407653	26887	Economy	16400.00
0005434299559	26887	Economy	16400.00
0005434299516	26887	Economy	16400.00
0005434407387	26887	Economy	16400.00
0005434407326	26887	Economy	16400.00
0005434407446	26887	Economy	16400.00
0005434299622	26887	Economy	16400.00
0005434407581	26887	Economy	16400.00
0005434407723	26887	Economy	16400.00
0005434407430	26887	Economy	16400.00
0005435293337	26887	Economy	16400.00
0005434407710	26887	Economy	16400.00
0005434407645	26887	Economy	16400.00
0005435293338	26887	Economy	16400.00
0005434407536	26887	Economy	16400.00
0005435293348	26887	Economy	16400.00
0005434407837	26887	Economy	16400.00
0005435293347	26887	Economy	16400.00
0005434407755	26887	Economy	16400.00
0005434407221	26887	Economy	16400.00
0005435293339	26887	Economy	16400.00
0005434299597	26887	Economy	16400.00
0005434299511	26887	Economy	16400.00
0005434407696	26887	Economy	16400.00
0005434407559	26887	Economy	16400.00
0005434299499	26887	Economy	16400.00
0005434407625	26887	Economy	16400.00
0005434407788	26887	Economy	16400.00
0005434407836	26887	Economy	16400.00
0005434407523	26887	Economy	16400.00
0005434299662	26887	Economy	16400.00
0005434407812	26887	Economy	16400.00
0005434407386	26887	Economy	16400.00
0005434407325	26887	Economy	16400.00
0005434407465	26887	Economy	16400.00
0005434407285	26887	Economy	16400.00
0005434408036	26887	Economy	16400.00
0005434299508	26887	Economy	16400.00
0005434407506	26887	Economy	16400.00
0005434407795	26887	Economy	16400.00
0005434299527	26887	Economy	16400.00
0005434407329	26887	Economy	16400.00
0005434407842	26887	Economy	16400.00
0005434407730	26887	Economy	16400.00
0005434299464	26887	Economy	16400.00
0005434407576	26887	Economy	16400.00
0005434407464	26887	Economy	16400.00
0005435293342	26887	Economy	16400.00
0005434407760	26887	Economy	16400.00
0005434407660	26887	Economy	16400.00
0005434299515	26887	Economy	16400.00
0005434407692	26887	Economy	16400.00
0005434512147	6464	Economy	16500.00
0005432604650	6464	Economy	16500.00
0005432604631	6464	Economy	16500.00
0005432604642	6464	Economy	16500.00
0005432604644	6464	Economy	15000.00
0005434512148	6464	Economy	15000.00
0005432604632	6464	Economy	15000.00
0005432604653	6464	Economy	15000.00
0005432604624	6464	Economy	15000.00
0005432604638	6464	Economy	15000.00
0005432604641	6464	Economy	15000.00
0005432604633	6464	Economy	15000.00
0005434512145	6464	Economy	15000.00
0005434512144	6464	Economy	15000.00
0005432604616	6464	Economy	15000.00
0005432604626	6464	Economy	15000.00
0005434512146	6464	Economy	15000.00
0005432604628	6464	Economy	15000.00
0005432604620	6464	Economy	15000.00
0005432604646	6464	Economy	15000.00
0005432604647	6464	Economy	15000.00
0005432604636	6464	Economy	15000.00
0005432604621	6464	Economy	15000.00
0005432604643	6464	Economy	15000.00
0005432604635	6464	Economy	15000.00
0005432604655	6464	Economy	15000.00
0005432604615	6464	Economy	15000.00
0005432604654	6464	Economy	15000.00
0005432604625	6464	Economy	15000.00
0005432604623	6464	Economy	15000.00
0005432604648	6464	Economy	15000.00
0005432604622	6464	Economy	15000.00
0005432604618	6464	Economy	15000.00
0005432604619	6464	Economy	15000.00
0005432604634	6464	Economy	15000.00
0005432604630	6464	Economy	15000.00
0005432604645	6464	Economy	15000.00
0005432604639	6464	Economy	15000.00
0005432604629	6464	Economy	15000.00
0005432604649	6464	Economy	15000.00
0005432604651	6464	Economy	15000.00
0005432604640	6464	Economy	15000.00
0005432604627	6464	Economy	15000.00
0005432604637	6464	Economy	15000.00
0005432604617	6464	Economy	15000.00
0005434512149	6464	Economy	15000.00
0005432604652	6464	Economy	15000.00
0005434512143	6464	Economy	15000.00
0005435218112	6464	Economy	15000.00
0005432603985	21381	Economy	16500.00
0005432604236	21381	Economy	16500.00
0005432604285	21381	Economy	16500.00
0005432604263	21381	Economy	16500.00
0005432604159	21381	Economy	15000.00
0005432604290	21381	Economy	15000.00
0005432604477	21381	Economy	15000.00
0005432604101	21381	Economy	15000.00
0005432604364	21381	Economy	15000.00
0005432604151	21381	Economy	15000.00
0005432604330	21381	Economy	15000.00
0005432604252	21381	Economy	15000.00
0005432604177	21381	Economy	15000.00
0005432604377	21381	Economy	15000.00
0005432604276	21381	Economy	15000.00
0005432604218	21381	Economy	15000.00
0005432604169	21381	Economy	15000.00
0005432604005	21381	Economy	15000.00
0005432604253	21381	Economy	15000.00
0005432604411	21381	Economy	15000.00
0005432604289	21381	Economy	15000.00
0005432604269	21381	Economy	15000.00
0005432604248	21381	Economy	15000.00
0005432604331	21381	Economy	15000.00
0005432604286	21381	Economy	15000.00
0005432604195	21381	Economy	15000.00
0005432604232	21381	Economy	15000.00
0005432604247	21381	Economy	15000.00
0005432604288	21381	Economy	15000.00
0005432604476	21381	Economy	15000.00
0005432604231	21381	Economy	15000.00
0005432604339	21381	Economy	15000.00
0005432604099	21381	Economy	15000.00
0005432604100	21381	Economy	15000.00
0005432604106	21381	Economy	15000.00
0005432604234	21381	Economy	15000.00
0005432603968	21381	Economy	15000.00
0005432604235	21381	Economy	15000.00
0005432604378	21381	Economy	15000.00
0005432604160	21381	Economy	15000.00
0005432604152	21381	Economy	15000.00
0005432604314	21381	Economy	15000.00
0005432604391	21381	Economy	15000.00
0005432604214	21381	Economy	15000.00
0005432604264	21381	Economy	15000.00
0005432604363	21381	Economy	15000.00
0005432604233	21381	Economy	15000.00
0005432604350	21381	Economy	15000.00
0005432604275	21381	Economy	15000.00
0005432604284	21381	Economy	15000.00
0005434907162	14986	Business	18900.00
0005434907207	14986	Business	18900.00
0005433251704	14986	Business	18900.00
0005434907059	14986	Business	18900.00
0005434907111	14986	Business	18900.00
0005434907246	14986	Business	18900.00
0005434907326	14986	Business	18900.00
0005433251692	14986	Business	18900.00
0005433251710	14986	Business	18900.00
0005433251716	14986	Economy	6300.00
0005434907215	14986	Economy	6300.00
0005433251712	14986	Economy	6300.00
0005433251688	14986	Economy	6300.00
0005434907452	14986	Economy	6300.00
0005434907218	14986	Economy	6300.00
0005434907188	14986	Economy	6300.00
0005433251715	14986	Economy	6300.00
0005434907325	14986	Economy	6300.00
0005434907189	14986	Economy	6300.00
0005433251705	14986	Economy	6900.00
0005434907062	14986	Economy	6900.00
0005434907172	14986	Economy	6900.00
0005433251703	14986	Economy	6900.00
0005434907186	14986	Economy	6300.00
0005433251695	14986	Economy	6300.00
0005434907208	14986	Economy	6300.00
0005434906951	14986	Economy	6300.00
0005434907262	14986	Economy	6300.00
0005433251707	14986	Economy	6300.00
0005434907273	14986	Economy	6300.00
0005434907161	14986	Economy	6300.00
0005434907131	14986	Economy	6300.00
0005434907158	14986	Economy	6300.00
0005434907352	14986	Economy	6300.00
0005434907219	14986	Economy	6300.00
0005433251699	14986	Economy	6300.00
0005433251709	14986	Economy	6300.00
0005433251691	14986	Economy	6300.00
0005433251690	14986	Economy	6300.00
0005434906874	14986	Economy	6300.00
0005434907353	14986	Economy	6300.00
0005434907122	14986	Economy	6300.00
0005433251693	14986	Economy	6300.00
0005434907247	14986	Economy	6300.00
0005434906991	14986	Economy	6300.00
0005434907187	14986	Economy	6300.00
0005434907193	14986	Economy	6300.00
0005433251701	14986	Economy	6300.00
0005433251689	14986	Economy	6300.00
0005434907185	14986	Economy	6300.00
0005434907155	14986	Economy	6300.00
0005434907196	14986	Economy	6300.00
0005433251696	14986	Economy	6300.00
0005434907354	14986	Economy	6300.00
0005433251687	14986	Economy	6300.00
0005433251714	14986	Economy	6300.00
0005433251711	14986	Economy	6300.00
0005434907453	14986	Economy	6300.00
0005433251700	14986	Economy	6300.00
0005434907190	14986	Economy	6300.00
0005433251698	14986	Economy	6300.00
0005434907184	14986	Economy	6300.00
0005434907365	14986	Economy	6300.00
0005434906945	14986	Economy	6300.00
0005433251694	14986	Economy	6300.00
0005434906952	14986	Economy	6300.00
0005434907127	14986	Economy	6300.00
0005433251702	14986	Economy	6300.00
0005434907157	14986	Economy	6300.00
0005434907144	14986	Economy	6300.00
0005433251717	14986	Economy	6300.00
0005434907200	14986	Economy	6300.00
0005434906956	14986	Economy	6300.00
0005433251706	14986	Economy	6300.00
0005433251686	14986	Economy	6300.00
0005434907147	14986	Economy	6300.00
0005434907295	14986	Economy	6300.00
0005433251708	14986	Economy	6300.00
0005434907126	14986	Economy	6300.00
0005434906992	14986	Economy	6300.00
0005433251713	14986	Economy	6300.00
0005434907137	14986	Economy	6300.00
0005434907254	14986	Economy	6300.00
0005433251697	14986	Economy	6300.00
0005433251324	25817	Business	18900.00
0005433251408	25817	Business	18900.00
0005434907634	25817	Business	18900.00
0005434907598	25817	Business	18900.00
0005434907612	25817	Business	18900.00
0005433251388	25817	Business	18900.00
0005434907639	25817	Business	18900.00
0005434907606	25817	Business	18900.00
0005434907622	25817	Business	18900.00
0005433251325	25817	Business	18900.00
0005433251530	25817	Business	18900.00
0005433251321	25817	Economy	6300.00
0005433251382	25817	Economy	6300.00
0005434907620	25817	Economy	6300.00
0005434907646	25817	Economy	6300.00
0005433251472	25817	Economy	6300.00
0005434907643	25817	Economy	6300.00
0005433251493	25817	Economy	6300.00
0005433251535	25817	Economy	6300.00
0005434907632	25817	Economy	6300.00
0005434907618	25817	Economy	6300.00
0005433251537	25817	Economy	6900.00
0005434907647	25817	Economy	6900.00
0005434907625	25817	Economy	6900.00
0005434907602	25817	Economy	6900.00
0005434907621	25817	Economy	6900.00
0005433251504	25817	Economy	6300.00
0005434907637	25817	Economy	6300.00
0005434907649	25817	Economy	6300.00
0005433251471	25817	Economy	6300.00
0005434907610	25817	Economy	6300.00
0005433251405	25817	Economy	6300.00
0005434907636	25817	Economy	6300.00
0005433251407	25817	Economy	6300.00
0005433251410	25817	Economy	6300.00
0005434907633	25817	Economy	6300.00
0005433251492	25817	Economy	6300.00
0005433251383	25817	Economy	6300.00
0005433251421	25817	Economy	6300.00
0005434907623	25817	Economy	6300.00
0005433251330	25817	Economy	6300.00
0005434907638	25817	Economy	6300.00
0005434907615	25817	Economy	6300.00
0005434907645	25817	Economy	6300.00
0005433251575	25817	Economy	6300.00
0005434907605	25817	Economy	6300.00
0005433251282	25817	Economy	6300.00
0005433251461	25817	Economy	6300.00
0005434907626	25817	Economy	6300.00
0005433251567	25817	Economy	6300.00
0005434907652	25817	Economy	6300.00
0005434907619	25817	Economy	6300.00
0005434907642	25817	Economy	6300.00
0005434907635	25817	Economy	6300.00
0005434907650	25817	Economy	6300.00
0005434907601	25817	Economy	6300.00
0005433251502	25817	Economy	6300.00
0005434907611	25817	Economy	6300.00
0005433251568	25817	Economy	6300.00
0005433251549	25817	Economy	6300.00
0005433251576	25817	Economy	6300.00
0005433251516	25817	Economy	6300.00
0005434907599	25817	Economy	6300.00
0005434907640	25817	Economy	6300.00
0005434907630	25817	Economy	6300.00
0005434907617	25817	Economy	6300.00
0005434907629	25817	Economy	6300.00
0005434907616	25817	Economy	6300.00
0005434907631	25817	Economy	6300.00
0005433251515	25817	Economy	6300.00
0005434907653	25817	Economy	6300.00
0005434907603	25817	Economy	6300.00
0005433251532	25817	Economy	6300.00
0005434907600	25817	Economy	6300.00
0005434907644	25817	Economy	6300.00
0005434907608	25817	Economy	6300.00
0005433251538	25817	Economy	6300.00
0005434907609	25817	Economy	6300.00
0005433251486	25817	Economy	6300.00
0005433251462	25817	Economy	6300.00
0005433251336	25817	Economy	6300.00
0005434907648	25817	Economy	6300.00
0005434907614	25817	Economy	6300.00
0005434907641	25817	Economy	6300.00
0005434907624	25817	Economy	6300.00
0005434907651	25817	Economy	6300.00
0005434907604	25817	Economy	6300.00
0005434907627	25817	Economy	6300.00
0005434907607	25817	Economy	6300.00
0005433251501	25817	Economy	6300.00
0005433251387	25817	Economy	6300.00
0005434907613	25817	Economy	6300.00
0005433251386	25817	Economy	6300.00
0005434907628	25817	Economy	6300.00
0005433251319	25817	Economy	6300.00
0005432609755	22477	Economy	16400.00
0005432609753	22477	Economy	16400.00
0005435841474	22477	Economy	16400.00
0005432607587	22477	Economy	14900.00
0005432609754	22477	Economy	14900.00
0005432609756	22477	Economy	14900.00
0005435842326	22477	Economy	14900.00
0005432609751	22477	Economy	14900.00
0005432607584	22477	Economy	14900.00
0005435841472	22477	Economy	14900.00
0005432607585	22477	Economy	14900.00
0005432607589	22477	Economy	14900.00
0005432609747	22477	Economy	14900.00
0005435842325	22477	Economy	14900.00
0005432607586	22477	Economy	14900.00
0005432607591	22477	Economy	14900.00
0005435842324	22477	Economy	14900.00
0005432609759	22477	Economy	14900.00
0005432609757	22477	Economy	14900.00
0005432609752	22477	Economy	14900.00
0005432607588	22477	Economy	14900.00
0005432607592	22477	Economy	14900.00
0005432607590	22477	Economy	14900.00
0005432607583	22477	Economy	14900.00
0005432609758	22477	Economy	14900.00
0005432609750	22477	Economy	14900.00
0005432609748	22477	Economy	14900.00
0005432609749	22477	Economy	14900.00
0005435841473	22477	Economy	14900.00
0005432607593	22477	Economy	14900.00
0005432613875	31729	Economy	16400.00
0005432609712	31729	Economy	16400.00
0005432609705	31729	Economy	14900.00
0005432613852	31729	Economy	14900.00
0005435841100	31729	Economy	14900.00
0005432613836	31729	Economy	14900.00
0005432609713	31729	Economy	14900.00
0005432609721	31729	Economy	14900.00
0005432613835	31729	Economy	14900.00
0005435841101	31729	Economy	14900.00
0005435841099	31729	Economy	14900.00
0005432609720	31729	Economy	14900.00
0005432613841	31729	Economy	14900.00
0005432613847	31729	Economy	14900.00
0005432613854	31729	Economy	14900.00
0005432613842	31729	Economy	14900.00
0005432609711	31729	Economy	14900.00
0005432613849	31729	Economy	14900.00
0005432609717	31729	Economy	14900.00
0005432613843	31729	Economy	14900.00
0005432609728	31729	Economy	14900.00
0005432609716	31729	Economy	14900.00
0005432609710	31729	Economy	14900.00
0005432613851	31729	Economy	14900.00
0005432613856	31729	Economy	14900.00
0005432609726	31729	Economy	14900.00
0005432613857	31729	Economy	14900.00
0005432609708	31729	Economy	14900.00
0005432609715	31729	Economy	14900.00
0005432613850	31729	Economy	14900.00
0005432609727	31729	Economy	14900.00
0005433008960	14182	Business	52300.00
0005433008969	14182	Business	52300.00
0005433008957	14182	Business	52300.00
0005433008975	14182	Business	52300.00
0005433008951	14182	Business	52300.00
0005433008968	14182	Business	52300.00
0005433008981	14182	Business	52300.00
0005433008938	14182	Economy	17400.00
0005433008947	14182	Economy	17400.00
0005433008943	14182	Economy	17400.00
0005433008958	14182	Economy	19200.00
0005433008959	14182	Economy	19200.00
0005433008942	14182	Economy	17400.00
0005433810527	14182	Economy	17400.00
0005433008967	14182	Economy	17400.00
0005433008948	14182	Economy	17400.00
0005433008966	14182	Economy	17400.00
0005433008963	14182	Economy	17400.00
0005433008974	14182	Economy	17400.00
0005433008945	14182	Economy	17400.00
0005433810528	14182	Economy	17400.00
0005433008977	14182	Economy	17400.00
0005433008955	14182	Economy	17400.00
0005433008941	14182	Economy	17400.00
0005433008962	14182	Economy	17400.00
0005433008954	14182	Economy	17400.00
0005433008973	14182	Economy	17400.00
0005433008953	14182	Economy	17400.00
0005433008964	14182	Economy	17400.00
0005433008950	14182	Economy	17400.00
0005433008965	14182	Economy	17400.00
0005433008978	14182	Economy	17400.00
0005433008952	14182	Economy	17400.00
0005433810523	14182	Economy	17400.00
0005433008972	14182	Economy	17400.00
0005433008961	14182	Economy	17400.00
0005433008980	14182	Economy	17400.00
0005433008976	14182	Economy	17400.00
0005433008946	14182	Economy	17400.00
0005433008970	14182	Economy	17400.00
0005433008971	14182	Economy	17400.00
0005433810522	14182	Economy	17400.00
0005433008939	14182	Economy	17400.00
0005433008949	14182	Economy	17400.00
0005433008944	14182	Economy	17400.00
0005433008940	14182	Economy	17400.00
0005433008956	14182	Economy	17400.00
0005433008979	14182	Economy	17400.00
0005433008528	22847	Business	52300.00
0005433008441	22847	Business	52300.00
0005433008318	22847	Business	52300.00
0005433008640	22847	Business	52300.00
0005433008150	22847	Business	52300.00
0005433008345	22847	Business	52300.00
0005433008650	22847	Economy	17400.00
0005433008432	22847	Economy	17400.00
0005433008487	22847	Economy	17400.00
0005433008499	22847	Economy	17400.00
0005433008434	22847	Economy	17400.00
0005433008552	22847	Economy	17400.00
0005433008232	22847	Economy	19200.00
0005433008553	22847	Economy	19200.00
0005433008331	22847	Economy	19200.00
0005433008578	22847	Economy	17400.00
0005433008645	22847	Economy	17400.00
0005433008635	22847	Economy	17400.00
0005433008521	22847	Economy	17400.00
0005433008511	22847	Economy	17400.00
0005433008556	22847	Economy	17400.00
0005433008392	22847	Economy	17400.00
0005433008801	22847	Economy	17400.00
0005433008498	22847	Economy	17400.00
0005433008391	22847	Economy	17400.00
0005433008610	22847	Economy	17400.00
0005433008452	22847	Economy	17400.00
0005433008799	22847	Economy	17400.00
0005433008535	22847	Economy	17400.00
0005433008455	22847	Economy	17400.00
0005433008415	22847	Economy	17400.00
0005433008433	22847	Economy	17400.00
0005433008444	22847	Economy	17400.00
0005433008448	22847	Economy	17400.00
0005433008582	22847	Economy	17400.00
0005433008800	22847	Economy	17400.00
0005433008554	22847	Economy	17400.00
0005433008520	22847	Economy	17400.00
0005433008549	22847	Economy	17400.00
0005433008630	22847	Economy	17400.00
0005433008659	22847	Economy	17400.00
0005433008151	22847	Economy	17400.00
0005433008527	22847	Economy	17400.00
0005433008454	22847	Economy	17400.00
0005433008449	22847	Economy	17400.00
0005433008348	22847	Economy	17400.00
0005433008473	22847	Economy	17400.00
0005433008587	22847	Economy	17400.00
0005433008488	22847	Economy	17400.00
0005433008646	22847	Economy	17400.00
0005433008641	22847	Economy	17400.00
0005433008534	22847	Economy	17400.00
0005433008638	22847	Economy	17400.00
0005433008453	22847	Economy	17400.00
0005433008456	22847	Economy	17400.00
0005433008332	22847	Economy	17400.00
0005434925605	14935	Business	22900.00
0005434925773	14935	Economy	7600.00
0005434925687	14935	Economy	7600.00
0005434925737	14935	Economy	8400.00
0005434925703	14935	Economy	8400.00
0005434925719	14935	Economy	7600.00
0005434925647	14935	Economy	7600.00
0005434925749	14935	Economy	7600.00
0005434925657	14935	Economy	7600.00
0005434925613	14935	Economy	7600.00
0005434925646	14935	Economy	7600.00
0005434925775	14935	Economy	7600.00
0005434925659	14935	Economy	7600.00
0005434925681	14935	Economy	7600.00
0005434925723	14935	Economy	7600.00
0005434925686	14935	Economy	7600.00
0005434925679	14935	Economy	7600.00
0005434925722	14935	Economy	7600.00
0005434925767	14935	Economy	7600.00
0005434925658	14935	Economy	7600.00
0005434925736	14935	Economy	7600.00
0005434925748	14935	Economy	7600.00
0005434925699	14935	Economy	7600.00
0005434925675	14935	Economy	7600.00
0005434925772	14935	Economy	7600.00
0005434925774	14935	Economy	7600.00
0005434925739	14935	Economy	7600.00
0005434925720	14935	Economy	7600.00
0005434925608	14935	Economy	7600.00
0005434925710	14935	Economy	7600.00
0005434925680	14935	Economy	7600.00
0005434926000	20531	Business	22900.00
0005434926002	20531	Business	22900.00
0005434926023	20531	Business	22900.00
0005434926001	20531	Business	22900.00
0005434926021	20531	Economy	7600.00
0005434925994	20531	Economy	7600.00
0005434925990	20531	Economy	7600.00
0005434926018	20531	Economy	7600.00
0005434925991	20531	Economy	7600.00
0005434926022	20531	Economy	7600.00
0005434925995	20531	Economy	8400.00
0005434925996	20531	Economy	7600.00
0005434926007	20531	Economy	7600.00
0005434926004	20531	Economy	7600.00
0005434925992	20531	Economy	7600.00
0005434926016	20531	Economy	7600.00
0005434925989	20531	Economy	7600.00
0005434926025	20531	Economy	7600.00
0005434926015	20531	Economy	7600.00
0005434925998	20531	Economy	7600.00
0005434925999	20531	Economy	7600.00
0005434926009	20531	Economy	7600.00
0005434926006	20531	Economy	7600.00
0005434926024	20531	Economy	7600.00
0005434926005	20531	Economy	7600.00
0005434926011	20531	Economy	7600.00
0005434926017	20531	Economy	7600.00
0005434926012	20531	Economy	7600.00
0005434925993	20531	Economy	7600.00
0005434926014	20531	Economy	7600.00
0005434926020	20531	Economy	7600.00
0005434926013	20531	Economy	7600.00
0005434926003	20531	Economy	7600.00
0005434926008	20531	Economy	7600.00
0005434925997	20531	Economy	7600.00
0005434926010	20531	Economy	7600.00
0005434926019	20531	Economy	7600.00
0005435487997	15844	Economy	8900.00
0005435488003	15844	Economy	8900.00
0005435487985	15844	Economy	8900.00
0005435487998	15844	Economy	8100.00
0005435487990	15844	Economy	8100.00
0005435999238	15844	Economy	8100.00
0005435487991	15844	Economy	8100.00
0005435487989	15844	Economy	8100.00
0005435999242	15844	Economy	8100.00
0005435487988	15844	Economy	8100.00
0005435999237	15844	Economy	8100.00
0005435488001	15844	Economy	8100.00
0005435999248	15844	Economy	8100.00
0005435999233	15844	Economy	8100.00
0005435487992	15844	Economy	8100.00
0005435999222	15844	Economy	8100.00
0005435487999	15844	Economy	8100.00
0005435488002	15844	Economy	8100.00
0005435488000	15844	Economy	8100.00
0005435487996	15844	Economy	8100.00
0005435999149	15844	Economy	8100.00
0005435999203	15844	Economy	8100.00
0005435488004	15844	Economy	8100.00
0005435488005	15844	Economy	8100.00
0005435487987	15844	Economy	8100.00
0005435487986	15844	Economy	8100.00
0005435487993	15844	Economy	8100.00
0005435487995	15844	Economy	8100.00
0005435999234	15844	Economy	8100.00
0005435487994	15844	Economy	8100.00
0005435999221	15844	Economy	8100.00
0005435999224	15844	Economy	8100.00
0005435488006	15844	Economy	8100.00
0005435487807	19708	Economy	8900.00
0005435999377	19708	Economy	8900.00
0005435487701	19708	Economy	8900.00
0005435999365	19708	Economy	8900.00
0005435487696	19708	Economy	8100.00
0005435999369	19708	Economy	8100.00
0005435999371	19708	Economy	8100.00
0005435487820	19708	Economy	8100.00
0005435487770	19708	Economy	8100.00
0005435487689	19708	Economy	8100.00
0005435999363	19708	Economy	8100.00
0005435999361	19708	Economy	8100.00
0005435999359	19708	Economy	8100.00
0005435999379	19708	Economy	8100.00
0005435487787	19708	Economy	8100.00
0005435999366	19708	Economy	8100.00
0005435999373	19708	Economy	8100.00
0005435487821	19708	Economy	8100.00
0005435999357	19708	Economy	8100.00
0005435999372	19708	Economy	8100.00
0005435999370	19708	Economy	8100.00
0005435487749	19708	Economy	8100.00
0005435999360	19708	Economy	8100.00
0005435999362	19708	Economy	8100.00
0005435999380	19708	Economy	8100.00
0005435999358	19708	Economy	8100.00
0005435487788	19708	Economy	8100.00
0005435999378	19708	Economy	8100.00
0005435999364	19708	Economy	8100.00
0005435487742	19708	Economy	8100.00
0005435487755	19708	Economy	8100.00
0005435487818	19708	Economy	8100.00
0005435999368	19708	Economy	8100.00
0005435487676	19708	Economy	8100.00
0005435487746	19708	Economy	8100.00
0005435487727	19708	Economy	8100.00
0005435487806	19708	Economy	8100.00
0005435999367	19708	Economy	8100.00
0005435999375	19708	Economy	8100.00
0005435487741	19708	Economy	8100.00
0005435999376	19708	Economy	8100.00
0005435999374	19708	Economy	8100.00
0005432142276	5980	Business	199300.00
0005435472763	5980	Business	199300.00
0005435472762	5980	Business	199300.00
0005435472818	5980	Business	199300.00
0005435839651	5980	Business	199300.00
0005435839649	5980	Business	199300.00
0005435472711	5980	Business	199300.00
0005435839667	5980	Business	199300.00
0005435839657	5980	Economy	66400.00
0005435472814	5980	Economy	66400.00
0005435839666	5980	Economy	66400.00
0005435472816	5980	Economy	66400.00
0005435472788	5980	Economy	66400.00
0005435839650	5980	Economy	66400.00
0005435839664	5980	Economy	66400.00
0005435839658	5980	Economy	73100.00
0005432660836	5980	Economy	73100.00
0005435839654	5980	Economy	66400.00
0005435472778	5980	Economy	66400.00
0005435839675	5980	Economy	66400.00
0005435839670	5980	Economy	66400.00
0005435839662	5980	Economy	66400.00
0005435472821	5980	Economy	66400.00
0005435839656	5980	Economy	66400.00
0005432660835	5980	Economy	66400.00
0005435839652	5980	Economy	66400.00
0005435472783	5980	Economy	66400.00
0005432142275	5980	Economy	66400.00
0005435839671	5980	Economy	66400.00
0005432659724	5980	Economy	66400.00
0005435839661	5980	Economy	66400.00
0005435472710	5980	Economy	66400.00
0005435839663	5980	Economy	66400.00
0005435839668	5980	Economy	66400.00
0005435839673	5980	Economy	66400.00
0005435472784	5980	Economy	66400.00
0005435472764	5980	Economy	66400.00
0005435472742	5980	Economy	66400.00
0005435472817	5980	Economy	66400.00
0005435839669	5980	Economy	66400.00
0005435839659	5980	Economy	66400.00
0005435839655	5980	Economy	66400.00
0005435472805	5980	Economy	66400.00
0005435839672	5980	Economy	66400.00
0005435839676	5980	Economy	66400.00
0005432659723	5980	Economy	66400.00
0005435839674	5980	Economy	66400.00
0005435839665	5980	Economy	66400.00
0005432659722	5980	Economy	66400.00
0005435839660	5980	Economy	66400.00
0005435472745	5980	Economy	66400.00
0005435472824	5980	Economy	66400.00
0005435839653	5980	Economy	66400.00
0005432667454	18039	Business	199300.00
0005432537074	18039	Business	199300.00
0005435472932	18039	Business	199300.00
0005432667444	18039	Business	199300.00
0005435839349	18039	Business	199300.00
0005435472917	18039	Business	199300.00
0005432664122	18039	Business	199300.00
0005435839417	18039	Business	199300.00
0005435839330	18039	Business	199300.00
0005435839458	18039	Economy	66400.00
0005435839475	18039	Economy	66400.00
0005435839360	18039	Economy	66400.00
0005435472925	18039	Economy	66400.00
0005435839359	18039	Economy	73100.00
0005432660810	18039	Economy	66400.00
0005435472926	18039	Economy	66400.00
0005435472922	18039	Economy	66400.00
0005435472930	18039	Economy	66400.00
0005435839383	18039	Economy	66400.00
0005435472927	18039	Economy	66400.00
0005435839409	18039	Economy	66400.00
0005435839447	18039	Economy	66400.00
0005435472933	18039	Economy	66400.00
0005435472919	18039	Economy	66400.00
0005435839282	18039	Economy	66400.00
0005435472921	18039	Economy	66400.00
0005435472928	18039	Economy	66400.00
0005435839517	18039	Economy	66400.00
0005432537075	18039	Economy	66400.00
0005435472918	18039	Economy	66400.00
0005435472929	18039	Economy	66400.00
0005435839465	18039	Economy	66400.00
0005432667455	18039	Economy	66400.00
0005435839410	18039	Economy	66400.00
0005435839416	18039	Economy	66400.00
0005435839472	18039	Economy	66400.00
0005435839350	18039	Economy	66400.00
0005435472924	18039	Economy	66400.00
0005435472931	18039	Economy	66400.00
0005435839503	18039	Economy	66400.00
0005435839358	18039	Economy	66400.00
0005432660809	18039	Economy	66400.00
0005435472920	18039	Economy	66400.00
0005435472923	18039	Economy	66400.00
0005433285289	23032	Business	15700.00
0005435103979	23032	Business	15700.00
0005433285140	23032	Business	15700.00
0005433285264	23032	Business	15700.00
0005433285159	23032	Economy	5200.00
0005433285249	23032	Economy	5200.00
0005433285259	23032	Economy	5200.00
0005433285250	23032	Economy	5200.00
0005433285215	23032	Economy	5200.00
0005433285364	23032	Economy	5200.00
0005433285326	23032	Economy	5200.00
0005433285298	23032	Economy	5200.00
0005435103981	23032	Economy	5200.00
0005433285098	23032	Economy	5200.00
0005433285248	23032	Economy	5700.00
0005433285102	23032	Economy	5200.00
0005435103982	23032	Economy	5200.00
0005433285268	23032	Economy	5200.00
0005433285257	23032	Economy	5200.00
0005433285313	23032	Economy	5200.00
0005435103980	23032	Economy	5200.00
0005433285208	23032	Economy	5200.00
0005433285256	23032	Economy	5200.00
0005433285204	23032	Economy	5200.00
0005433285253	23032	Economy	5200.00
0005433285343	23032	Economy	5200.00
0005433285141	23032	Economy	5200.00
0005433285265	23032	Economy	5200.00
0005433285418	23032	Economy	5200.00
0005433285393	23032	Economy	5200.00
0005433285114	23032	Economy	5200.00
0005433285235	23032	Economy	5200.00
0005433285245	23032	Economy	5200.00
0005433285363	23032	Economy	5200.00
0005433285548	32091	Business	15700.00
0005433285541	32091	Business	15700.00
0005433285546	32091	Business	15700.00
0005433285519	32091	Business	15700.00
0005433285538	32091	Business	15700.00
0005433285525	32091	Economy	5200.00
0005435103880	32091	Economy	5200.00
0005433285527	32091	Economy	5200.00
0005433285529	32091	Economy	5200.00
0005433285520	32091	Economy	5200.00
0005433285539	32091	Economy	5200.00
0005435103881	32091	Economy	5200.00
0005433285521	32091	Economy	5200.00
0005433285536	32091	Economy	5200.00
0005433285531	32091	Economy	5200.00
0005433285540	32091	Economy	5200.00
0005433285535	32091	Economy	5700.00
0005433285532	32091	Economy	5200.00
0005433285528	32091	Economy	5200.00
0005433285545	32091	Economy	5200.00
0005433285549	32091	Economy	5200.00
0005433285526	32091	Economy	5200.00
0005433285530	32091	Economy	5200.00
0005433285543	32091	Economy	5200.00
0005433285537	32091	Economy	5200.00
0005433285544	32091	Economy	5200.00
0005433285533	32091	Economy	5200.00
0005433285524	32091	Economy	5200.00
0005433285542	32091	Economy	5200.00
0005433285522	32091	Economy	5200.00
0005433285518	32091	Economy	5200.00
0005433285534	32091	Economy	5200.00
0005433285550	32091	Economy	5200.00
0005433285547	32091	Economy	5200.00
0005433285523	32091	Economy	5200.00
0005435852596	23861	Economy	13500.00
0005433475699	23861	Economy	12300.00
0005435852597	23861	Economy	12300.00
0005433475698	23861	Economy	12300.00
0005435852598	23861	Economy	12300.00
0005433475701	23861	Economy	12300.00
0005433475711	23861	Economy	12300.00
0005433475692	23861	Economy	12300.00
0005435852595	23861	Economy	12300.00
0005435852599	23861	Economy	12300.00
0005435852594	23861	Economy	12300.00
0005433475700	23861	Economy	12300.00
0005432528317	30626	Business	42100.00
0005432528093	30626	Business	42100.00
0005434067515	30626	Business	42100.00
0005435214078	30626	Business	42100.00
0005434067562	30626	Business	42100.00
0005432527268	30626	Business	42100.00
0005434067659	30626	Business	42100.00
0005434067542	30626	Business	42100.00
0005435214130	30626	Business	42100.00
0005432527725	30626	Business	42100.00
0005435214119	30626	Business	42100.00
0005432527945	30626	Business	42100.00
0005434067262	30626	Business	42100.00
0005435214088	30626	Business	42100.00
0005435214126	30626	Business	42100.00
0005434067636	30626	Business	42100.00
0005432527275	30626	Business	42100.00
0005434067382	30626	Business	42100.00
0005432527274	30626	Business	42100.00
0005435214079	30626	Business	42100.00
0005432528138	30626	Business	42100.00
0005435214092	30626	Business	42100.00
0005433656699	30626	Business	42100.00
0005432528164	30626	Business	42100.00
0005435214086	30626	Business	42100.00
0005432528499	30626	Business	42100.00
0005432527872	30626	Comfort	23900.00
0005432528101	30626	Comfort	23900.00
0005432528165	30626	Comfort	23900.00
0005434067633	30626	Comfort	23900.00
0005432528222	30626	Comfort	23900.00
0005434067052	30626	Comfort	23900.00
0005432528156	30626	Comfort	23900.00
0005432528026	30626	Comfort	23900.00
0005432528053	30626	Comfort	23900.00
0005432528408	30626	Comfort	23900.00
0005435214063	30626	Comfort	23900.00
0005434067627	30626	Comfort	23900.00
0005435214115	30626	Comfort	23900.00
0005434067813	30626	Comfort	23900.00
0005435214093	30626	Comfort	23900.00
0005434067597	30626	Comfort	23900.00
0005435214118	30626	Comfort	23900.00
0005432535836	30626	Comfort	23900.00
0005434067449	30626	Comfort	23900.00
0005432527607	30626	Comfort	23900.00
0005434067655	30626	Comfort	23900.00
0005435214094	30626	Comfort	23900.00
0005432528441	30626	Comfort	23900.00
0005434067677	30626	Comfort	23900.00
0005434067598	30626	Comfort	23900.00
0005432527920	30626	Comfort	23900.00
0005433656698	30626	Comfort	23900.00
0005435214075	30626	Comfort	23900.00
0005432527690	30626	Comfort	23900.00
0005432527921	30626	Comfort	23900.00
0005435214127	30626	Comfort	23900.00
0005432527790	30626	Comfort	23900.00
0005435214077	30626	Comfort	23900.00
0005432211560	30626	Comfort	23900.00
0005434067432	30626	Comfort	23900.00
0005432528017	30626	Comfort	23900.00
0005432528604	30626	Comfort	23900.00
0005432527702	30626	Comfort	23900.00
0005435214071	30626	Comfort	23900.00
0005434067312	30626	Comfort	23900.00
0005432528501	30626	Economy	14000.00
0005434067508	30626	Comfort	23900.00
0005435214070	30626	Economy	14000.00
0005434067463	30626	Economy	14000.00
0005435214102	30626	Economy	14000.00
0005432528467	30626	Economy	14000.00
0005434067292	30626	Economy	14000.00
0005432535837	30626	Economy	14000.00
0005432527883	30626	Economy	14000.00
0005435214113	30626	Economy	14000.00
0005432528247	30626	Economy	14000.00
0005435214068	30626	Economy	14000.00
0005435214120	30626	Economy	14000.00
0005432528139	30626	Economy	14000.00
0005432528260	30626	Economy	14000.00
0005432159892	30626	Economy	14000.00
0005434067502	30626	Economy	14000.00
0005434067171	30626	Economy	14000.00
0005432528088	30626	Economy	14000.00
0005435214129	30626	Economy	14000.00
0005432527930	30626	Economy	14000.00
0005434067624	30626	Economy	14000.00
0005432527923	30626	Economy	14000.00
0005435630992	30626	Economy	14000.00
0005434067814	30626	Economy	14000.00
0005434067486	30626	Economy	14000.00
0005435214076	30626	Economy	14000.00
0005435214122	30626	Economy	14000.00
0005432528074	30626	Economy	14000.00
0005432527805	30626	Economy	14000.00
0005435214073	30626	Economy	14000.00
0005432527580	30626	Economy	14000.00
0005432211559	30626	Economy	14000.00
0005432527535	30626	Economy	14000.00
0005432528178	30626	Economy	14000.00
0005432527703	30626	Economy	14000.00
0005432211562	30626	Economy	14000.00
0005432528061	30626	Economy	14000.00
0005435214100	30626	Economy	14000.00
0005432528068	30626	Economy	14000.00
0005432159893	30626	Economy	14000.00
0005432527818	30626	Economy	14000.00
0005432211563	30626	Economy	14000.00
0005435214109	30626	Economy	14000.00
0005433656697	30626	Economy	14000.00
0005435214111	30626	Economy	14000.00
0005432528094	30626	Economy	14000.00
0005435214097	30626	Economy	14000.00
0005435214114	30626	Economy	14000.00
0005432527951	30626	Economy	14000.00
0005432527267	30626	Economy	14000.00
0005434067311	30626	Economy	14000.00
0005434067728	30626	Economy	14000.00
0005432528155	30626	Economy	14000.00
0005432528045	30626	Economy	14000.00
0005432159894	30626	Economy	14000.00
0005432528041	30626	Economy	14000.00
0005432528166	30626	Economy	14000.00
0005432527985	30626	Economy	14000.00
0005432528062	30626	Economy	14000.00
0005435214087	30626	Economy	14000.00
0005434067279	30626	Economy	15400.00
0005432528048	30626	Economy	14000.00
0005432528223	30626	Economy	15400.00
0005432528012	30626	Economy	14000.00
0005432528242	30626	Economy	14000.00
0005434067504	30626	Economy	14000.00
0005432528602	30626	Economy	14000.00
0005435214124	30626	Economy	15400.00
0005432528046	30626	Economy	15400.00
0005435214067	30626	Economy	15400.00
0005435725643	30626	Economy	14000.00
0005432527897	30626	Economy	14000.00
0005432528108	30626	Economy	14000.00
0005432527938	30626	Economy	14000.00
0005435214085	30626	Economy	14000.00
0005434067505	30626	Economy	14000.00
0005432535830	30626	Economy	14000.00
0005432527627	30626	Economy	14000.00
0005434067559	30626	Economy	14000.00
0005432527935	30626	Economy	14000.00
0005432159896	30626	Economy	14000.00
0005435214106	30626	Economy	14000.00
0005432527545	30626	Economy	14000.00
0005434067451	30626	Economy	14000.00
0005435214101	30626	Economy	14000.00
0005435214095	30626	Economy	14000.00
0005432527446	30626	Economy	14000.00
0005432527743	30626	Economy	14000.00
0005435214099	30626	Economy	14000.00
0005432528250	30626	Economy	14000.00
0005432527581	30626	Economy	14000.00
0005434067383	30626	Economy	14000.00
0005435214116	30626	Economy	14000.00
0005434067547	30626	Economy	14000.00
0005434067729	30626	Economy	14000.00
0005432535850	30626	Economy	14000.00
0005435214123	30626	Economy	14000.00
0005434067282	30626	Economy	14000.00
0005434067733	30626	Economy	14000.00
0005434067675	30626	Economy	14000.00
0005434067687	30626	Economy	14000.00
0005435214125	30626	Economy	14000.00
0005435214090	30626	Economy	14000.00
0005435214117	30626	Economy	14000.00
0005434067577	30626	Economy	14000.00
0005434067300	30626	Economy	14000.00
0005435725641	30626	Economy	14000.00
0005432527816	30626	Economy	14000.00
0005435214064	30626	Economy	14000.00
0005434067649	30626	Economy	14000.00
0005432528367	30626	Economy	14000.00
0005435725642	30626	Economy	14000.00
0005434067352	30626	Economy	14000.00
0005434067467	30626	Economy	14000.00
0005434067622	30626	Economy	14000.00
0005434067686	30626	Economy	14000.00
0005432528233	30626	Economy	14000.00
0005434067399	30626	Economy	14000.00
0005435725639	30626	Economy	14000.00
0005434067291	30626	Economy	14000.00
0005432528444	30626	Economy	14000.00
0005432527791	30626	Economy	14000.00
0005432528438	30626	Economy	14000.00
0005432527519	30626	Economy	14000.00
0005434067364	30626	Economy	14000.00
0005435214096	30626	Economy	14000.00
0005434067336	30626	Economy	14000.00
0005432528023	30626	Economy	14000.00
0005432527882	30626	Economy	14000.00
0005434067503	30626	Economy	14000.00
0005432528043	30626	Economy	14000.00
0005432528161	30626	Economy	14000.00
0005435214084	30626	Economy	14000.00
0005435214103	30626	Economy	14000.00
0005434067172	30626	Economy	14000.00
0005432528286	30626	Economy	14000.00
0005432527744	30626	Economy	14000.00
0005435214108	30626	Economy	14000.00
0005432527717	30626	Economy	14000.00
0005432527606	30626	Economy	14000.00
0005432528058	30626	Economy	14000.00
0005434067734	30626	Economy	14000.00
0005434067122	30626	Economy	14000.00
0005432527588	30626	Economy	14000.00
0005434067051	30626	Economy	14000.00
0005435214082	30626	Economy	14000.00
0005434067628	30626	Economy	14000.00
0005434067430	30626	Economy	14000.00
0005432528295	30626	Economy	14000.00
0005432527614	30626	Economy	14000.00
0005435214121	30626	Economy	14000.00
0005432535792	30626	Economy	14000.00
0005432428930	30626	Economy	14000.00
0005435214065	30626	Economy	14000.00
0005434067521	30626	Economy	14000.00
0005432527785	30626	Economy	14000.00
0005432527890	30626	Economy	14000.00
0005434067561	30626	Economy	14000.00
0005432527929	30626	Economy	14000.00
0005432211566	30626	Economy	14000.00
0005434067507	30626	Economy	14000.00
0005432527804	30626	Economy	14000.00
0005435214128	30626	Economy	14000.00
0005432528436	30626	Economy	14000.00
0005432527884	30626	Economy	14000.00
0005432211565	30626	Economy	14000.00
0005435214112	30626	Economy	14000.00
0005432527814	30626	Economy	14000.00
0005434067676	30626	Economy	14000.00
0005432528142	30626	Economy	14000.00
0005434067660	30626	Economy	15400.00
0005432527928	30626	Economy	15400.00
0005434067674	30626	Economy	15400.00
0005435214062	30626	Economy	15400.00
0005435725640	30626	Economy	15400.00
0005432528092	30626	Economy	14000.00
0005432537061	30626	Economy	15400.00
0005432528040	30626	Economy	14000.00
0005434067319	30626	Economy	14000.00
0005434067283	30626	Economy	14000.00
0005434067541	30626	Economy	14000.00
0005432528106	30626	Economy	14000.00
0005434067632	30626	Economy	14000.00
0005432528318	30626	Economy	14000.00
0005434067280	30626	Economy	14000.00
0005432528100	30626	Economy	14000.00
0005432527950	30626	Economy	14000.00
0005435214110	30626	Economy	14000.00
0005432528466	30626	Economy	14000.00
0005432527757	30626	Economy	14000.00
0005432527986	30626	Economy	14000.00
0005432528493	30626	Economy	14000.00
0005434067799	30626	Economy	14000.00
0005434067466	30626	Economy	14000.00
0005432528248	30626	Economy	14000.00
0005435214083	30626	Economy	14000.00
0005434067792	30626	Economy	14000.00
0005435214105	30626	Economy	14000.00
0005435214098	30626	Economy	14000.00
0005435214107	30626	Economy	14000.00
0005435214080	30626	Economy	14000.00
0005432211561	30626	Economy	14000.00
0005434067345	30626	Economy	14000.00
0005432535829	30626	Economy	14000.00
0005434067735	30626	Economy	14000.00
0005435214069	30626	Economy	14000.00
0005434067703	30626	Economy	14000.00
0005434067183	30626	Economy	14000.00
0005432528042	30626	Economy	14000.00
0005435214081	30626	Economy	14000.00
0005435214091	30626	Economy	14000.00
0005434067479	30626	Economy	14000.00
0005435630991	30626	Economy	14000.00
0005432527830	30626	Economy	14000.00
0005433656700	30626	Economy	14000.00
0005432527589	30626	Economy	14000.00
0005432527873	30626	Economy	14000.00
0005432527960	30626	Economy	14000.00
0005434067344	30626	Economy	14000.00
0005432527854	30626	Economy	14000.00
0005434067339	30626	Economy	14000.00
0005432528603	30626	Economy	14000.00
0005432211564	30626	Economy	14000.00
0005434067663	30626	Economy	14000.00
0005432528409	30626	Economy	14000.00
0005435214072	30626	Economy	14000.00
0005432528221	30626	Economy	14000.00
0005432527891	30626	Economy	14000.00
0005432527961	30626	Economy	14000.00
0005432528437	30626	Economy	14000.00
0005435214074	30626	Economy	14000.00
0005432527755	30626	Economy	14000.00
0005432528028	30626	Economy	14000.00
0005432528217	30626	Economy	14000.00
0005432527952	30626	Economy	14000.00
0005434067600	30626	Economy	14000.00
0005432527756	30626	Economy	14000.00
0005434067274	30626	Economy	14000.00
0005432527780	30626	Economy	14000.00
0005434067524	30626	Economy	14000.00
0005432527525	30626	Economy	14000.00
0005434067050	30626	Economy	14000.00
0005435630993	30626	Economy	14000.00
0005434067246	30626	Economy	14000.00
0005432159895	30626	Economy	14000.00
0005435214104	30626	Economy	14000.00
0005432528500	30626	Economy	14000.00
0005434067192	30626	Economy	14000.00
0005434067454	30626	Economy	14000.00
0005432528033	30626	Economy	14000.00
0005434067477	30626	Economy	14000.00
0005432527984	30626	Economy	14000.00
0005432528277	30626	Economy	14000.00
0005432527617	30626	Economy	14000.00
0005432528073	30626	Economy	14000.00
0005432528160	30626	Economy	14000.00
0005435214066	30626	Economy	14000.00
0005432528243	30626	Economy	14000.00
0005432528107	30626	Economy	14000.00
0005432528191	30626	Economy	14000.00
0005432528261	30626	Economy	14000.00
0005434067478	30626	Economy	14000.00
0005434067450	30626	Economy	14000.00
0005434067509	30626	Economy	14000.00
0005432528614	30626	Economy	14000.00
0005434067366	30626	Economy	14000.00
0005435214089	30626	Economy	14000.00
0005434067727	30626	Economy	14000.00
0005433368209	24843	Business	9800.00
0005433368203	24843	Business	9800.00
0005435653017	24843	Business	9800.00
0005433368208	24843	Business	9800.00
0005435653047	24843	Business	9800.00
0005435652851	24843	Business	9800.00
0005433368178	24843	Business	9800.00
0005435653033	24843	Business	9800.00
0005433368182	24843	Business	9800.00
0005435652743	24843	Economy	3300.00
0005433368187	24843	Economy	3300.00
0005433368204	24843	Economy	3300.00
0005433368188	24843	Economy	3300.00
0005435652850	24843	Economy	3300.00
0005433368181	24843	Economy	3300.00
0005433368206	24843	Economy	3300.00
0005435652945	24843	Economy	3300.00
0005433368186	24843	Economy	3300.00
0005433368200	24843	Economy	3600.00
0005435652881	24843	Economy	3600.00
0005435653013	24843	Economy	3600.00
0005435652880	24843	Economy	3600.00
0005433368214	24843	Economy	3300.00
0005435652974	24843	Economy	3300.00
0005433368192	24843	Economy	3300.00
0005435652944	24843	Economy	3300.00
0005433368189	24843	Economy	3300.00
0005435652961	24843	Economy	3300.00
0005435652939	24843	Economy	3300.00
0005433368215	24843	Economy	3300.00
0005435652933	24843	Economy	3300.00
0005435652985	24843	Economy	3300.00
0005433368184	24843	Economy	3300.00
0005435653009	24843	Economy	3300.00
0005433368202	24843	Economy	3300.00
0005435652940	24843	Economy	3300.00
0005435652919	24843	Economy	3300.00
0005433368207	24843	Economy	3300.00
0005435653025	24843	Economy	3300.00
0005433368211	24843	Economy	3300.00
0005433368191	24843	Economy	3300.00
0005433368196	24843	Economy	3300.00
0005433368197	24843	Economy	3300.00
0005435653012	24843	Economy	3300.00
0005433368198	24843	Economy	3300.00
0005435653036	24843	Economy	3300.00
0005435652920	24843	Economy	3300.00
0005433368180	24843	Economy	3300.00
0005435652849	24843	Economy	3300.00
0005435652948	24843	Economy	3300.00
0005433368201	24843	Economy	3300.00
0005435652906	24843	Economy	3300.00
0005433368190	24843	Economy	3300.00
0005433368183	24843	Economy	3300.00
0005435653032	24843	Economy	3300.00
0005433368216	24843	Economy	3300.00
0005435653027	24843	Economy	3300.00
0005433368194	24843	Economy	3300.00
0005435652908	24843	Economy	3300.00
0005435652787	24843	Economy	3300.00
0005435652907	24843	Economy	3300.00
0005433368212	24843	Economy	3300.00
0005435653028	24843	Economy	3300.00
0005435653026	24843	Economy	3300.00
0005435652972	24843	Economy	3300.00
0005433368205	24843	Economy	3300.00
0005433368199	24843	Economy	3300.00
0005433368185	24843	Economy	3300.00
0005435652837	24843	Economy	3300.00
0005433368195	24843	Economy	3300.00
0005435652905	24843	Economy	3300.00
0005433368213	24843	Economy	3300.00
0005435652986	24843	Economy	3300.00
0005433368179	24843	Economy	3300.00
0005435653003	24843	Economy	3300.00
0005435652904	24843	Economy	3300.00
0005435652938	24843	Economy	3300.00
0005433368193	24843	Economy	3300.00
0005435652742	24843	Economy	3300.00
0005433368210	24843	Economy	3300.00
0005435949776	23318	Economy	20600.00
0005435949775	23318	Economy	18700.00
0005435949777	23318	Economy	18700.00
0005435949766	23318	Economy	18700.00
0005434980032	2026	Economy	10500.00
0005434980043	2026	Economy	10500.00
0005435801720	2026	Economy	10500.00
0005434980025	2026	Economy	9500.00
0005434980051	2026	Economy	9500.00
0005434980050	2026	Economy	9500.00
0005434980029	2026	Economy	9500.00
0005434980037	2026	Economy	9500.00
0005434980041	2026	Economy	9500.00
0005434980031	2026	Economy	9500.00
0005434980030	2026	Economy	9500.00
0005434980034	2026	Economy	9500.00
0005434980033	2026	Economy	9500.00
0005434980022	2026	Economy	9500.00
0005434980047	2026	Economy	9500.00
0005434980036	2026	Economy	9500.00
0005434980044	2026	Economy	9500.00
0005434980045	2026	Economy	9500.00
0005434980040	2026	Economy	9500.00
0005434980046	2026	Economy	9500.00
0005434980049	2026	Economy	9500.00
0005434980042	2026	Economy	9500.00
0005434980028	2026	Economy	9500.00
0005434980048	2026	Economy	9500.00
0005434980035	2026	Economy	9500.00
0005434980039	2026	Economy	9500.00
0005434980027	2026	Economy	9500.00
0005434980024	2026	Economy	9500.00
0005434980021	2026	Economy	9500.00
0005435801722	2026	Economy	9500.00
0005434980023	2026	Economy	9500.00
0005435801721	2026	Economy	9500.00
0005434980038	2026	Economy	9500.00
0005434980026	2026	Economy	9500.00
0005434979671	23564	Economy	10500.00
0005434979825	23564	Economy	10500.00
0005434979793	23564	Economy	10500.00
0005434979741	23564	Economy	10500.00
0005434979722	23564	Economy	9500.00
0005434979626	23564	Economy	9500.00
0005434979658	23564	Economy	9500.00
0005434979716	23564	Economy	9500.00
0005434979669	23564	Economy	9500.00
0005435801700	23564	Economy	9500.00
0005434979661	23564	Economy	9500.00
0005435801689	23564	Economy	9500.00
0005434979662	23564	Economy	9500.00
0005434979611	23564	Economy	9500.00
0005434979764	23564	Economy	9500.00
0005434979679	23564	Economy	9500.00
0005434979678	23564	Economy	9500.00
0005434979610	23564	Economy	9500.00
0005434979802	23564	Economy	9500.00
0005434979706	23564	Economy	9500.00
0005434979625	23564	Economy	9500.00
0005434979746	23564	Economy	9500.00
0005434979805	23564	Economy	9500.00
0005434979803	23564	Economy	9500.00
0005434979670	23564	Economy	9500.00
0005434979727	23564	Economy	9500.00
0005434979765	23564	Economy	9500.00
0005434979732	23564	Economy	9500.00
0005434979707	23564	Economy	9500.00
0005434979744	23564	Economy	9500.00
0005434979794	23564	Economy	9500.00
0005434979660	23564	Economy	9500.00
0005434979745	23564	Economy	9500.00
0005434979701	23564	Economy	9500.00
0005434979824	23564	Economy	9500.00
0005434952562	2572	Economy	5300.00
0005434952563	2572	Economy	5300.00
0005434952560	2572	Economy	5300.00
0005434952561	2572	Economy	5300.00
0005433256420	2573	Economy	5300.00
0005433256416	2573	Economy	5300.00
0005434952527	28221	Economy	5300.00
0005434952539	28221	Economy	5300.00
0005434952534	28221	Economy	5300.00
0005433256441	28221	Economy	5300.00
0005434952535	28221	Economy	5300.00
0005434952532	28221	Economy	5300.00
0005433256440	28221	Economy	5300.00
0005433111525	19741	Economy	8700.00
0005434302869	19741	Economy	8700.00
0005434302857	19741	Economy	8700.00
0005434302858	19741	Economy	8700.00
0005434302854	19741	Economy	8700.00
0005433111524	19741	Economy	8700.00
0005434138264	11939	Business	9700.00
0005434138185	11939	Business	9700.00
0005434138016	11939	Business	9700.00
0005434137869	11939	Business	9700.00
0005434138261	11939	Business	9700.00
0005434138249	11939	Business	9700.00
0005434137972	11939	Business	9700.00
0005434137803	11939	Business	9700.00
0005434137947	11939	Business	9700.00
0005434138076	11939	Business	9700.00
0005434138087	11939	Business	9700.00
0005434138018	11939	Economy	3200.00
0005434137948	11939	Economy	3200.00
0005434137925	11939	Economy	3200.00
0005434137781	11939	Economy	3200.00
0005434138109	11939	Economy	3200.00
0005434138098	11939	Economy	3200.00
0005434138239	11939	Economy	3200.00
0005434138088	11939	Economy	3200.00
0005434137923	11939	Economy	3500.00
0005434138150	11939	Economy	3500.00
0005434138230	11939	Economy	3500.00
0005434138032	11939	Economy	3500.00
0005434138118	11939	Economy	3200.00
0005434138201	11939	Economy	3200.00
0005434138141	11939	Economy	3200.00
0005434137999	11939	Economy	3200.00
0005434137834	11939	Economy	3200.00
0005434137910	11939	Economy	3200.00
0005434138251	11939	Economy	3200.00
0005434137920	11939	Economy	3200.00
0005434138152	11939	Economy	3200.00
0005434137922	11939	Economy	3200.00
0005434137783	11939	Economy	3200.00
0005434138075	11939	Economy	3200.00
0005434137964	11939	Economy	3200.00
0005434138202	11939	Economy	3200.00
0005434138233	11939	Economy	3200.00
0005434138110	11939	Economy	3200.00
0005434138140	11939	Economy	3200.00
0005434137930	11939	Economy	3200.00
0005434138000	11939	Economy	3200.00
0005434137916	11939	Economy	3200.00
0005434138151	11939	Economy	3200.00
0005434138169	11939	Economy	3200.00
0005434137919	11939	Economy	3200.00
0005434138180	11939	Economy	3200.00
0005434138181	11939	Economy	3200.00
0005434138060	11939	Economy	3200.00
0005434138133	11939	Economy	3200.00
0005434137851	11939	Economy	3200.00
0005434138238	11939	Economy	3200.00
0005434138079	11939	Economy	3200.00
0005434138073	11939	Economy	3200.00
0005434137924	11939	Economy	3200.00
0005434138231	11939	Economy	3200.00
0005434137896	11939	Economy	3200.00
0005434138184	11939	Economy	3200.00
0005434138116	11939	Economy	3200.00
0005434137918	11939	Economy	3200.00
0005434137804	11939	Economy	3200.00
0005434137891	11939	Economy	3200.00
0005434137921	11939	Economy	3200.00
0005434137992	11939	Economy	3200.00
0005434138063	11939	Economy	3200.00
0005434137835	11939	Economy	3200.00
0005434138142	11939	Economy	3200.00
0005434137915	11939	Economy	3200.00
0005434138232	11939	Economy	3200.00
0005434138023	11939	Economy	3200.00
0005434138234	11939	Economy	3200.00
0005434138017	11939	Economy	3200.00
0005434138002	11939	Economy	3200.00
0005434138078	11939	Economy	3200.00
0005434138108	11939	Economy	3200.00
0005434137892	11939	Economy	3200.00
0005434138193	11939	Economy	3200.00
0005434137805	11939	Economy	3200.00
0005434138039	11939	Economy	3200.00
0005434137782	11939	Economy	3200.00
0005434138007	11939	Economy	3200.00
0005434138062	11939	Economy	3200.00
0005434137795	11939	Economy	3200.00
0005434138099	11939	Economy	3200.00
0005434138745	28728	Business	9700.00
0005434138798	28728	Business	9700.00
0005434138751	28728	Business	9700.00
0005434138727	28728	Business	9700.00
0005434138766	28728	Business	9700.00
0005434138804	28728	Business	9700.00
0005434138716	28728	Business	9700.00
0005434138797	28728	Business	9700.00
0005434138719	28728	Business	9700.00
0005434138750	28728	Business	9700.00
0005434138764	28728	Business	9700.00
0005434138735	28728	Business	9700.00
0005434138758	28728	Economy	3200.00
0005434138763	28728	Economy	3200.00
0005434138733	28728	Economy	3200.00
0005434138801	28728	Economy	3200.00
0005434138793	28728	Economy	3200.00
0005434138731	28728	Economy	3200.00
0005434138779	28728	Economy	3200.00
0005434138775	28728	Economy	3200.00
0005434138723	28728	Economy	3200.00
0005434138790	28728	Economy	3200.00
0005434138746	28728	Economy	3500.00
0005434138760	28728	Economy	3500.00
0005434138757	28728	Economy	3500.00
0005434138744	28728	Economy	3500.00
0005434138739	28728	Economy	3200.00
0005434138718	28728	Economy	3200.00
0005434138753	28728	Economy	3200.00
0005434138792	28728	Economy	3200.00
0005434138777	28728	Economy	3200.00
0005434138762	28728	Economy	3200.00
0005434138776	28728	Economy	3200.00
0005434138717	28728	Economy	3200.00
0005434138788	28728	Economy	3200.00
0005434138786	28728	Economy	3200.00
0005434138724	28728	Economy	3200.00
0005434138752	28728	Economy	3200.00
0005434138767	28728	Economy	3200.00
0005434138749	28728	Economy	3200.00
0005434138774	28728	Economy	3200.00
0005434138743	28728	Economy	3200.00
0005434138780	28728	Economy	3200.00
0005434138802	28728	Economy	3200.00
0005434138803	28728	Economy	3200.00
0005434138805	28728	Economy	3200.00
0005434138796	28728	Economy	3200.00
0005434138782	28728	Economy	3200.00
0005434138794	28728	Economy	3200.00
0005434138730	28728	Economy	3200.00
0005434138795	28728	Economy	3200.00
0005434138728	28728	Economy	3200.00
0005434138769	28728	Economy	3200.00
0005434138755	28728	Economy	3200.00
0005434138799	28728	Economy	3200.00
0005434138738	28728	Economy	3200.00
0005434138720	28728	Economy	3200.00
0005434138806	28728	Economy	3200.00
0005434138785	28728	Economy	3200.00
0005434138772	28728	Economy	3200.00
0005434138722	28728	Economy	3200.00
0005434138747	28728	Economy	3200.00
0005434138800	28728	Economy	3200.00
0005434138783	28728	Economy	3200.00
0005434138736	28728	Economy	3200.00
0005434138741	28728	Economy	3200.00
0005434138726	28728	Economy	3200.00
0005434138789	28728	Economy	3200.00
0005434138759	28728	Economy	3200.00
0005434138784	28728	Economy	3200.00
0005434138725	28728	Economy	3200.00
0005434138765	28728	Economy	3200.00
0005434138778	28728	Economy	3200.00
0005434138737	28728	Economy	3200.00
0005434138791	28728	Economy	3200.00
0005434138740	28728	Economy	3200.00
0005434138773	28728	Economy	3200.00
0005434138770	28728	Economy	3200.00
0005434138734	28728	Economy	3200.00
0005434138761	28728	Economy	3200.00
0005434138748	28728	Economy	3200.00
0005434138771	28728	Economy	3200.00
0005434138721	28728	Economy	3200.00
0005434138756	28728	Economy	3200.00
0005434138742	28728	Economy	3200.00
0005434138768	28728	Economy	3200.00
0005434138732	28728	Economy	3200.00
0005434138754	28728	Economy	3200.00
0005434138787	28728	Economy	3200.00
0005434138729	28728	Economy	3200.00
0005434138781	28728	Economy	3200.00
0005434466503	6577	Economy	20900.00
0005434466502	6577	Economy	20900.00
0005434466504	6577	Economy	20900.00
0005435312809	6577	Economy	20900.00
0005435312804	6577	Economy	20900.00
0005434466498	6577	Economy	20900.00
0005434466499	6577	Economy	20900.00
0005434466494	6577	Economy	20900.00
0005434466495	6577	Economy	20900.00
0005435312811	6577	Economy	20900.00
0005435312800	6577	Economy	20900.00
0005434466497	6577	Economy	20900.00
0005434466500	6577	Economy	20900.00
0005435312808	6577	Economy	20900.00
0005434466501	6577	Economy	20900.00
0005434466496	6577	Economy	20900.00
0005435312807	6577	Economy	20900.00
0005435312810	6577	Economy	20900.00
0005434516077	19100	Economy	26000.00
0005434513581	19100	Economy	26000.00
0005434516076	19100	Economy	26000.00
0005434513562	19100	Economy	23600.00
0005434190417	19100	Economy	23600.00
0005434513570	19100	Economy	23600.00
0005434516073	19100	Economy	23600.00
0005434513583	19100	Economy	23600.00
0005434513589	19100	Economy	23600.00
0005434513572	19100	Economy	23600.00
0005434513577	19100	Economy	23600.00
0005434190416	19100	Economy	23600.00
0005434513567	19100	Economy	23600.00
0005434513561	19100	Economy	23600.00
0005434513568	19100	Economy	23600.00
0005434190422	19100	Economy	23600.00
0005434513582	19100	Economy	23600.00
0005434190421	19100	Economy	23600.00
0005434190419	19100	Economy	23600.00
0005434513578	19100	Economy	23600.00
0005434516074	19100	Economy	23600.00
0005434516072	19100	Economy	23600.00
0005434190420	19100	Economy	23600.00
0005434513590	19100	Economy	23600.00
0005434513569	19100	Economy	23600.00
0005434513564	19100	Economy	23600.00
0005434513563	19100	Economy	23600.00
0005434513576	19100	Economy	23600.00
0005434190423	19100	Economy	23600.00
0005434190415	19100	Economy	23600.00
0005434513591	19100	Economy	23600.00
0005434513571	19100	Economy	23600.00
0005434513580	19100	Economy	23600.00
0005434190418	19100	Economy	23600.00
0005433534516	6777	Economy	9900.00
0005433538942	6777	Economy	9900.00
0005435259730	6777	Economy	9900.00
0005433538943	6777	Economy	9900.00
0005435259762	6777	Economy	9900.00
0005433538944	6777	Economy	9900.00
0005433538939	6777	Economy	9900.00
0005433538941	6777	Economy	9900.00
0005433538945	6777	Economy	9900.00
0005433538938	6777	Economy	9900.00
0005435259729	6777	Economy	9900.00
0005433534517	6777	Economy	9900.00
0005433538946	6777	Economy	9900.00
0005433534515	6777	Economy	9900.00
0005433538940	6777	Economy	9900.00
0005435259763	6777	Economy	9900.00
0005435259794	25014	Economy	9900.00
0005433538863	25014	Economy	9900.00
0005433538916	25014	Economy	9900.00
0005433538872	25014	Economy	9900.00
0005433538869	25014	Economy	9900.00
0005435259792	25014	Economy	9900.00
0005433538870	25014	Economy	9900.00
0005435259791	25014	Economy	9900.00
0005433534502	25014	Economy	9900.00
0005435259793	25014	Economy	9900.00
0005433538852	25014	Economy	9900.00
0005433512018	843	Economy	14600.00
0005433512022	843	Economy	14600.00
0005433512019	843	Economy	14600.00
0005432922527	843	Economy	14600.00
0005433512021	843	Economy	14600.00
0005433512020	843	Economy	14600.00
0005432922528	843	Economy	14600.00
0005432922533	843	Economy	14600.00
0005433512017	843	Economy	14600.00
0005433512025	843	Economy	14600.00
0005433512023	843	Economy	14600.00
0005433512024	843	Economy	14600.00
0005433512026	843	Economy	14600.00
0005432922525	843	Economy	14600.00
0005432922524	843	Economy	14600.00
0005433511963	16137	Economy	16100.00
0005433511929	16137	Economy	16100.00
0005433511961	16137	Economy	14600.00
0005433511978	16137	Economy	14600.00
0005433511933	16137	Economy	14600.00
0005433511972	16137	Economy	14600.00
0005432922558	16137	Economy	14600.00
0005432922560	16137	Economy	14600.00
0005433511962	16137	Economy	14600.00
0005433511928	16137	Economy	14600.00
0005432922559	16137	Economy	14600.00
0005433511953	16137	Economy	14600.00
0005433511932	16137	Economy	14600.00
0005434950567	3672	Economy	7900.00
0005435697585	3672	Economy	7900.00
0005434950569	3672	Economy	7200.00
0005435697571	3672	Economy	7200.00
0005435935050	3672	Economy	7200.00
0005435697572	3672	Economy	7200.00
0005435697582	3672	Economy	7200.00
0005435697586	3672	Economy	7200.00
0005435697577	3672	Economy	7200.00
0005435697563	3672	Economy	7200.00
0005435935051	3672	Economy	7200.00
0005435935039	3672	Economy	7200.00
0005435697581	3672	Economy	7200.00
0005435697564	3672	Economy	7200.00
0005435697570	3672	Economy	7200.00
0005435697575	3672	Economy	7200.00
0005435697584	3672	Economy	7200.00
0005435697561	3672	Economy	7200.00
0005435697576	3672	Economy	7200.00
0005435935041	3672	Economy	7200.00
0005434950565	3672	Economy	7200.00
0005434950566	3672	Economy	7200.00
0005435697578	3672	Economy	7200.00
0005435697569	3672	Economy	7200.00
0005435697565	3672	Economy	7200.00
0005435697567	3672	Economy	7200.00
0005434950568	3672	Economy	7200.00
0005435697568	3672	Economy	7200.00
0005435697566	3672	Economy	7200.00
0005435697583	3672	Economy	7200.00
0005435935038	3672	Economy	7200.00
0005435697580	3672	Economy	7200.00
0005435697579	3672	Economy	7200.00
0005435697562	3672	Economy	7200.00
0005435697587	3672	Economy	7200.00
0005435935040	3672	Economy	7200.00
0005435697588	3672	Economy	7200.00
0005435697573	3672	Economy	7200.00
0005435697574	3672	Economy	7200.00
0005435697332	16306	Economy	7900.00
0005434950547	16306	Economy	7900.00
0005434950519	16306	Economy	7900.00
0005435697312	16306	Economy	7900.00
0005435697409	16306	Economy	7200.00
0005435697316	16306	Economy	7200.00
0005435697288	16306	Economy	7200.00
0005435697249	16306	Economy	7200.00
0005435697354	16306	Economy	7200.00
0005435697248	16306	Economy	7200.00
0005435935066	16306	Economy	7200.00
0005435935068	16306	Economy	7200.00
0005435697340	16306	Economy	7200.00
0005435916191	16306	Economy	7200.00
0005435697259	16306	Economy	7200.00
0005435697295	16306	Economy	7200.00
0005435697369	16306	Economy	7200.00
0005435697217	16306	Economy	7200.00
0005435935065	16306	Economy	7200.00
0005435697258	16306	Economy	7200.00
0005435935067	16306	Economy	7200.00
0005435697296	16306	Economy	7200.00
0005435697297	16306	Economy	7200.00
0005435697300	16306	Economy	7200.00
0005435697321	16306	Economy	7200.00
0005435697311	16306	Economy	7200.00
0005435697250	16306	Economy	7200.00
0005435697347	16306	Economy	7200.00
0005435697355	16306	Economy	7200.00
0005435697226	16306	Economy	7200.00
0005435697290	16306	Economy	7200.00
0005435916190	16306	Economy	7200.00
0005435697358	16306	Economy	7200.00
0005435697241	16306	Economy	7200.00
0005435697322	16306	Economy	7200.00
0005435916189	16306	Economy	7200.00
0005435697314	16306	Economy	7200.00
0005435697289	16306	Economy	7200.00
0005434950540	16306	Economy	7200.00
0005434606861	3939	Economy	21300.00
0005432607599	3939	Economy	21300.00
0005435853612	3939	Economy	19300.00
0005433519494	3939	Economy	19300.00
0005435853615	3939	Economy	19300.00
0005432607602	3939	Economy	19300.00
0005432609765	3939	Economy	19300.00
0005434606862	3939	Economy	19300.00
0005432607600	3939	Economy	19300.00
0005434606859	3939	Economy	19300.00
0005435853608	3939	Economy	19300.00
0005432609766	3939	Economy	19300.00
0005434606858	3939	Economy	19300.00
0005434604925	3939	Economy	19300.00
0005435853607	3939	Economy	19300.00
0005433519496	3939	Economy	19300.00
0005432607598	3939	Economy	19300.00
0005432609763	3939	Economy	19300.00
0005434604926	3939	Economy	19300.00
0005432609764	3939	Economy	19300.00
0005432607601	3939	Economy	19300.00
0005433519497	3939	Economy	19300.00
0005434604927	3939	Economy	19300.00
0005433519495	3939	Economy	19300.00
0005432609767	3939	Economy	19300.00
0005434606860	3939	Economy	19300.00
0005433519469	22069	Economy	21300.00
0005432609715	22069	Economy	21300.00
0005432613835	22069	Economy	21300.00
0005433519480	22069	Economy	19300.00
0005432609727	22069	Economy	19300.00
0005432613857	22069	Economy	19300.00
0005432609711	22069	Economy	19300.00
0005432613841	22069	Economy	19300.00
0005432613850	22069	Economy	19300.00
0005433519479	22069	Economy	19300.00
0005433519467	22069	Economy	19300.00
0005432613843	22069	Economy	19300.00
0005433519470	22069	Economy	19300.00
0005433519473	22069	Economy	19300.00
0005433519461	22069	Economy	19300.00
0005432613875	22069	Economy	19300.00
0005435841101	22069	Economy	19300.00
0005432613847	22069	Economy	19300.00
0005432609708	22069	Economy	19300.00
0005432613836	22069	Economy	19300.00
0005432609712	22069	Economy	19300.00
0005434606810	22069	Economy	19300.00
0005432609726	22069	Economy	19300.00
0005435841100	22069	Economy	19300.00
0005432609713	22069	Economy	19300.00
0005432609705	22069	Economy	19300.00
0005432609720	22069	Economy	19300.00
0005433519478	22069	Economy	19300.00
0005432613856	22069	Economy	19300.00
0005432613849	22069	Economy	19300.00
0005432609728	22069	Economy	19300.00
0005433519462	22069	Economy	19300.00
0005432613842	22069	Economy	19300.00
0005432609710	22069	Economy	19300.00
0005432613851	22069	Economy	19300.00
0005432609717	22069	Economy	19300.00
0005434606811	22069	Economy	19300.00
0005432609716	22069	Economy	19300.00
0005432613852	22069	Economy	19300.00
0005432613854	22069	Economy	19300.00
0005435841099	22069	Economy	19300.00
0005433519460	22069	Economy	19300.00
0005432609721	22069	Economy	19300.00
0005435628752	672	Economy	3700.00
0005433349016	672	Economy	3700.00
0005435628753	672	Economy	3700.00
0005433348996	672	Economy	3700.00
0005435628751	672	Economy	3700.00
0005433348990	672	Economy	3700.00
0005433348984	672	Economy	3700.00
0005435628750	672	Economy	3700.00
0005435628749	672	Economy	3700.00
0005433348982	672	Economy	3700.00
0005433348994	672	Economy	3700.00
0005433348983	672	Economy	3700.00
0005433349036	15923	Economy	3700.00
0005435628718	15923	Economy	3700.00
0005433349041	15923	Economy	3700.00
0005433349037	15923	Economy	3700.00
0005433349038	15923	Economy	3700.00
0005433349039	15923	Economy	3700.00
0005433349035	15923	Economy	3700.00
0005433349040	15923	Economy	3700.00
0005435628721	15923	Economy	3700.00
0005434445260	17208	Economy	7100.00
0005433159313	17208	Economy	7100.00
0005433159308	17208	Economy	7100.00
0005433159312	17208	Economy	7100.00
0005433159309	17208	Economy	7100.00
0005433158119	17208	Economy	7100.00
0005433159306	17208	Economy	7100.00
0005434445228	17671	Economy	7100.00
0005434445243	17671	Economy	7100.00
0005435132974	7912	Economy	5400.00
0005435132971	7912	Economy	5400.00
0005435132973	7912	Economy	5400.00
0005435383128	7912	Economy	5400.00
0005435132966	7912	Economy	5400.00
0005435132969	7912	Economy	5400.00
0005435132965	7912	Economy	5400.00
0005435383135	7912	Economy	5400.00
0005435132970	7912	Economy	5400.00
0005435132967	7912	Economy	5400.00
0005435132972	7912	Economy	5400.00
0005435132975	7912	Economy	5400.00
0005435132968	7912	Economy	5400.00
0005435383150	7912	Economy	5400.00
0005435132887	33113	Economy	5900.00
0005435132858	33113	Economy	5400.00
0005435132940	33113	Economy	5400.00
0005435383195	33113	Economy	5400.00
0005435132882	33113	Economy	5400.00
0005435132876	33113	Economy	5400.00
0005435383194	33113	Economy	5400.00
0005435132891	33113	Economy	5400.00
0005435383196	33113	Economy	5400.00
0005435132931	33113	Economy	5400.00
0005435132894	33113	Economy	5400.00
0005435132941	33113	Economy	5400.00
0005435132875	33113	Economy	5400.00
0005435132893	33113	Economy	5400.00
0005435383193	33113	Economy	5400.00
0005435132888	33113	Economy	5400.00
0005435132908	33113	Economy	5400.00
0005435132930	33113	Economy	5400.00
0005435383198	33113	Economy	5400.00
0005435383197	33113	Economy	5400.00
0005435132892	33113	Economy	5400.00
0005435811119	4407	Business	133200.00
0005435811112	4407	Business	133200.00
0005435938872	4407	Business	133200.00
0005435938879	4407	Business	133200.00
0005435938881	4407	Business	133200.00
0005435811109	4407	Economy	44400.00
0005435811107	4407	Economy	44400.00
0005435811106	4407	Economy	44400.00
0005435811111	4407	Economy	44400.00
0005435811116	4407	Economy	44400.00
0005435938883	4407	Economy	44400.00
0005435811108	4407	Economy	44400.00
0005435811114	4407	Economy	44400.00
0005435938880	4407	Economy	44400.00
0005435938893	4407	Economy	44400.00
0005435811117	4407	Economy	44400.00
0005435938894	4407	Economy	44400.00
0005435811118	4407	Economy	44400.00
0005435938892	4407	Economy	44400.00
0005435811110	4407	Economy	44400.00
0005435811120	4407	Economy	44400.00
0005435811113	4407	Economy	44400.00
0005435938884	4407	Economy	44400.00
0005435811115	4407	Economy	44400.00
0005435811058	29442	Business	133200.00
0005435811044	29442	Business	133200.00
0005435938904	29442	Business	133200.00
0005435938907	29442	Business	133200.00
0005435938908	29442	Economy	44400.00
0005435811046	29442	Economy	44400.00
0005435938909	29442	Economy	44400.00
0005435938910	29442	Economy	44400.00
0005435811069	29442	Economy	44400.00
0005435811045	29442	Economy	44400.00
0005435811051	29442	Economy	44400.00
0005435811061	29442	Economy	44400.00
0005435811041	29442	Economy	44400.00
0005435811059	29442	Economy	44400.00
0005435811068	29442	Economy	44400.00
0005435811032	29442	Economy	44400.00
0005435811081	29442	Economy	44400.00
0005435811066	29442	Economy	44400.00
0005435938906	29442	Economy	44400.00
0005435938905	29442	Economy	44400.00
0005435811080	29442	Economy	44400.00
0005435390259	7484	Economy	13800.00
0005435160394	7484	Economy	12500.00
0005435390270	7484	Economy	12500.00
0005435160396	7484	Economy	12500.00
0005435160399	7484	Economy	12500.00
0005435390269	7484	Economy	12500.00
0005435390217	7484	Economy	12500.00
0005435160392	7484	Economy	12500.00
0005435160390	7484	Economy	12500.00
0005435160393	7484	Economy	12500.00
0005435160398	7484	Economy	12500.00
0005435160401	7484	Economy	12500.00
0005435160395	7484	Economy	12500.00
0005435160391	7484	Economy	12500.00
0005435390225	7484	Economy	12500.00
0005435390216	7484	Economy	12500.00
0005435160397	7484	Economy	12500.00
0005435160400	7484	Economy	12500.00
0005435390255	7484	Economy	12500.00
0005435390240	7484	Economy	12500.00
0005435390232	7484	Economy	12500.00
0005435160296	29556	Economy	13800.00
0005435160331	29556	Economy	13800.00
0005435160348	29556	Economy	13800.00
0005435160299	29556	Economy	13800.00
0005435160287	29556	Economy	12500.00
0005435160349	29556	Economy	12500.00
0005435390296	29556	Economy	12500.00
0005435390298	29556	Economy	12500.00
0005435160265	29556	Economy	12500.00
0005435390300	29556	Economy	12500.00
0005435160328	29556	Economy	12500.00
0005435390297	29556	Economy	12500.00
0005435160286	29556	Economy	12500.00
0005435390301	29556	Economy	12500.00
0005435160295	29556	Economy	12500.00
0005435390295	29556	Economy	12500.00
0005435160293	29556	Economy	12500.00
0005435390299	29556	Economy	12500.00
0005435160351	29556	Economy	12500.00
0005435160288	29556	Economy	12500.00
0005435160294	29556	Economy	12500.00
0005435160283	29556	Economy	12500.00
0005435160332	29556	Economy	12500.00
0005432398196	18452	Economy	4900.00
0005432394099	18452	Economy	4900.00
0005432394106	18452	Economy	4900.00
0005432398197	18452	Economy	4900.00
0005432394097	18452	Economy	4900.00
0005432394113	18452	Economy	4900.00
0005432398191	18452	Economy	4900.00
0005432394098	18452	Economy	4900.00
0005432394109	18452	Economy	4900.00
0005432394105	18452	Economy	4900.00
0005432398198	18452	Economy	4900.00
0005432398224	27148	Economy	4900.00
0005432398223	27148	Economy	4900.00
0005435179393	27148	Economy	4900.00
0005432400153	27148	Economy	4900.00
0005432400154	27148	Economy	4900.00
0005435179394	27148	Economy	4900.00
0005435179392	27148	Economy	4900.00
0005432398226	27148	Economy	4900.00
0005432400155	27148	Economy	4900.00
0005432398225	27148	Economy	4900.00
0005432639243	2246	Business	87300.00
0005432639227	2246	Business	87300.00
0005432639225	2246	Business	87300.00
0005432866025	2246	Business	87300.00
0005432866013	2246	Business	87300.00
0005432639238	2246	Business	87300.00
0005432639237	2246	Business	87300.00
0005432866026	2246	Economy	29100.00
0005432866020	2246	Economy	29100.00
0005432866007	2246	Economy	29100.00
0005432639233	2246	Economy	32000.00
0005432639222	2246	Economy	29100.00
0005432639234	2246	Economy	29100.00
0005432865992	2246	Economy	29100.00
0005432639235	2246	Economy	29100.00
0005432639244	2246	Economy	29100.00
0005432865998	2246	Economy	29100.00
0005432639221	2246	Economy	29100.00
0005432639242	2246	Economy	29100.00
0005432866021	2246	Economy	29100.00
0005432639241	2246	Economy	29100.00
0005432639239	2246	Economy	29100.00
0005432639232	2246	Economy	29100.00
0005432866008	2246	Economy	29100.00
0005432866019	2246	Economy	29100.00
0005432865983	2246	Economy	29100.00
0005432639228	2246	Economy	29100.00
0005432639236	2246	Economy	29100.00
0005432639226	2246	Economy	29100.00
0005432639231	2246	Economy	29100.00
0005432639230	2246	Economy	29100.00
0005432865984	2246	Economy	29100.00
0005432639223	2246	Economy	29100.00
0005432639220	2246	Economy	29100.00
0005432865985	2246	Economy	29100.00
0005432865991	2246	Economy	29100.00
0005432639224	2246	Economy	29100.00
0005432639229	2246	Economy	29100.00
0005432639240	2246	Economy	29100.00
0005434191283	9814	Economy	4400.00
0005434191284	9814	Economy	4400.00
0005434191282	9814	Economy	4400.00
0005434504473	6558	Business	48400.00
0005434504481	6558	Business	48400.00
0005434504470	6558	Business	48400.00
0005435103991	6558	Business	48400.00
0005435103988	6558	Business	48400.00
0005434504494	6558	Economy	16100.00
0005434504477	6558	Economy	16100.00
0005434504499	6558	Economy	16100.00
0005434504471	6558	Economy	16100.00
0005434504476	6558	Economy	16100.00
0005434504501	6558	Economy	16100.00
0005434504503	6558	Economy	17800.00
0005434504480	6558	Economy	17800.00
0005434504467	6558	Economy	17800.00
0005435103990	6558	Economy	16100.00
0005434504495	6558	Economy	16100.00
0005434504484	6558	Economy	16100.00
0005434504497	6558	Economy	16100.00
0005434504490	6558	Economy	16100.00
0005435103993	6558	Economy	16100.00
0005434504485	6558	Economy	16100.00
0005434504464	6558	Economy	16100.00
0005434504504	6558	Economy	16100.00
0005434504486	6558	Economy	16100.00
0005434504502	6558	Economy	16100.00
0005434504498	6558	Economy	16100.00
0005434504466	6558	Economy	16100.00
0005434504489	6558	Economy	16100.00
0005435103989	6558	Economy	16100.00
0005434504491	6558	Economy	16100.00
0005434504474	6558	Economy	16100.00
0005434504465	6558	Economy	16100.00
0005434504496	6558	Economy	16100.00
0005434504488	6558	Economy	16100.00
0005435103987	6558	Economy	16100.00
0005434504469	6558	Economy	16100.00
0005434504487	6558	Economy	16100.00
0005434504479	6558	Economy	16100.00
0005435103992	6558	Economy	16100.00
0005434504492	6558	Economy	16100.00
0005434504482	6558	Economy	16100.00
0005434504483	6558	Economy	16100.00
0005434504468	6558	Economy	16100.00
0005434504472	6558	Economy	16100.00
0005434504500	6558	Economy	16100.00
0005434504478	6558	Economy	16100.00
0005434504475	6558	Economy	16100.00
0005434504493	6558	Economy	16100.00
0005434503911	22672	Business	48400.00
0005434504110	22672	Business	48400.00
0005434504188	22672	Business	48400.00
0005434504148	22672	Business	48400.00
0005434503910	22672	Economy	16100.00
0005434504135	22672	Economy	16100.00
0005434504109	22672	Economy	16100.00
0005434503979	22672	Economy	17800.00
0005434503870	22672	Economy	17800.00
0005434504147	22672	Economy	17800.00
0005434504156	22672	Economy	16100.00
0005434504074	22672	Economy	16100.00
0005434504140	22672	Economy	16100.00
0005434504001	22672	Economy	16100.00
0005434504016	22672	Economy	16100.00
0005434504004	22672	Economy	16100.00
0005434503978	22672	Economy	16100.00
0005434503974	22672	Economy	16100.00
0005434504076	22672	Economy	16100.00
0005434503871	22672	Economy	16100.00
0005434504139	22672	Economy	16100.00
0005434504119	22672	Economy	16100.00
0005434504061	22672	Economy	16100.00
0005434504149	22672	Economy	16100.00
0005434504008	22672	Economy	16100.00
0005434503960	22672	Economy	16100.00
0005434504134	22672	Economy	16100.00
0005435103881	22672	Economy	16100.00
0005434503975	22672	Economy	16100.00
0005434504163	22672	Economy	16100.00
0005435103880	22672	Economy	16100.00
0005434503959	22672	Economy	16100.00
0005434504065	22672	Economy	16100.00
0005434504066	22672	Economy	16100.00
0005434504097	22672	Economy	16100.00
0005435653441	1688	Business	50000.00
0005433367799	1688	Business	50000.00
0005435653430	1688	Business	50000.00
0005435653453	1688	Business	50000.00
0005433367903	1688	Business	50000.00
0005435653413	1688	Business	50000.00
0005435653412	1688	Business	50000.00
0005435653451	1688	Business	50000.00
0005435653434	1688	Business	50000.00
0005435653416	1688	Business	50000.00
0005433367815	1688	Economy	16700.00
0005435653456	1688	Economy	16700.00
0005435653433	1688	Economy	16700.00
0005435653418	1688	Economy	16700.00
0005435653455	1688	Economy	16700.00
0005433367740	1688	Economy	16700.00
0005435653438	1688	Economy	16700.00
0005435653428	1688	Economy	16700.00
0005433367885	1688	Economy	16700.00
0005433367560	1688	Economy	18300.00
0005433367824	1688	Economy	18300.00
0005435653454	1688	Economy	18300.00
0005435653406	1688	Economy	18300.00
0005435653452	1688	Economy	18300.00
0005433367918	1688	Economy	16700.00
0005435653431	1688	Economy	16700.00
0005435653405	1688	Economy	16700.00
0005435653439	1688	Economy	16700.00
0005433367863	1688	Economy	16700.00
0005435653440	1688	Economy	16700.00
0005433367710	1688	Economy	16700.00
0005433367946	1688	Economy	16700.00
0005435653442	1688	Economy	16700.00
0005435653435	1688	Economy	16700.00
0005435653447	1688	Economy	16700.00
0005435653408	1688	Economy	16700.00
0005435653449	1688	Economy	16700.00
0005435653423	1688	Economy	16700.00
0005433368022	1688	Economy	16700.00
0005435653411	1688	Economy	16700.00
0005435653424	1688	Economy	16700.00
0005433367739	1688	Economy	16700.00
0005435653444	1688	Economy	16700.00
0005435653425	1688	Economy	16700.00
0005435653409	1688	Economy	16700.00
0005433367932	1688	Economy	16700.00
0005435653445	1688	Economy	16700.00
0005433367844	1688	Economy	16700.00
0005435653437	1688	Economy	16700.00
0005435653450	1688	Economy	16700.00
0005433367714	1688	Economy	16700.00
0005433367839	1688	Economy	16700.00
0005433368015	1688	Economy	16700.00
0005435653422	1688	Economy	16700.00
0005435653427	1688	Economy	16700.00
0005435653407	1688	Economy	16700.00
0005435653436	1688	Economy	16700.00
0005433367816	1688	Economy	16700.00
0005433367933	1688	Economy	16700.00
0005435653417	1688	Economy	16700.00
0005435653410	1688	Economy	16700.00
0005433367955	1688	Economy	16700.00
0005435653429	1688	Economy	16700.00
0005435653432	1688	Economy	16700.00
0005433367954	1688	Economy	16700.00
0005435653446	1688	Economy	16700.00
0005433367664	1688	Economy	16700.00
0005433367786	1688	Economy	16700.00
0005433367878	1688	Economy	16700.00
0005433367814	1688	Economy	16700.00
0005435653421	1688	Economy	16700.00
0005433367835	1688	Economy	16700.00
0005433367834	1688	Economy	16700.00
0005435653448	1688	Economy	16700.00
0005433367864	1688	Economy	16700.00
0005433367797	1688	Economy	16700.00
0005433367801	1688	Economy	16700.00
0005433367820	1688	Economy	16700.00
0005433367708	1688	Economy	16700.00
0005435653419	1688	Economy	16700.00
0005435653426	1688	Economy	16700.00
0005433367876	1688	Economy	16700.00
0005435653415	1688	Economy	16700.00
0005435653414	1688	Economy	16700.00
0005435653420	1688	Economy	16700.00
0005433367941	1688	Economy	16700.00
0005433367879	1688	Economy	16700.00
0005435653443	1688	Economy	16700.00
0005435652920	21695	Business	50000.00
0005435652907	21695	Business	50000.00
0005433368213	21695	Business	50000.00
0005433368208	21695	Business	50000.00
0005435652850	21695	Business	50000.00
0005433368205	21695	Business	50000.00
0005435652849	21695	Business	50000.00
0005433368196	21695	Business	50000.00
0005433368210	21695	Business	50000.00
0005435652851	21695	Business	50000.00
0005433368215	21695	Business	50000.00
0005435653026	21695	Economy	16700.00
0005433368203	21695	Economy	16700.00
0005433368182	21695	Economy	16700.00
0005435652919	21695	Economy	16700.00
0005433368212	21695	Economy	16700.00
0005435652933	21695	Economy	16700.00
0005433368216	21695	Economy	16700.00
0005433368191	21695	Economy	16700.00
0005435653036	21695	Economy	18300.00
0005433368181	21695	Economy	18300.00
0005433368209	21695	Economy	18300.00
0005433368214	21695	Economy	18300.00
0005435652742	21695	Economy	16700.00
0005433368200	21695	Economy	16700.00
0005433368189	21695	Economy	16700.00
0005433368195	21695	Economy	16700.00
0005433368179	21695	Economy	16700.00
0005435652948	21695	Economy	16700.00
0005433368180	21695	Economy	16700.00
0005433368202	21695	Economy	16700.00
0005435653032	21695	Economy	16700.00
0005435652743	21695	Economy	16700.00
0005433368201	21695	Economy	16700.00
0005435653027	21695	Economy	16700.00
0005433368186	21695	Economy	16700.00
0005435652961	21695	Economy	16700.00
0005435652904	21695	Economy	16700.00
0005435652938	21695	Economy	16700.00
0005435652945	21695	Economy	16700.00
0005433368178	21695	Economy	16700.00
0005433368183	21695	Economy	16700.00
0005435653017	21695	Economy	16700.00
0005433368207	21695	Economy	16700.00
0005433368197	21695	Economy	16700.00
0005435652881	21695	Economy	16700.00
0005433368193	21695	Economy	16700.00
0005433368188	21695	Economy	16700.00
0005433368199	21695	Economy	16700.00
0005435653028	21695	Economy	16700.00
0005433368198	21695	Economy	16700.00
0005435652944	21695	Economy	16700.00
0005435652986	21695	Economy	16700.00
0005435653013	21695	Economy	16700.00
0005435652974	21695	Economy	16700.00
0005435653009	21695	Economy	16700.00
0005435652906	21695	Economy	16700.00
0005435653003	21695	Economy	16700.00
0005433368190	21695	Economy	16700.00
0005435652985	21695	Economy	16700.00
0005435653033	21695	Economy	16700.00
0005433368184	21695	Economy	16700.00
0005435652880	21695	Economy	16700.00
0005435652939	21695	Economy	16700.00
0005435652787	21695	Economy	16700.00
0005433368206	21695	Economy	16700.00
0005433368187	21695	Economy	16700.00
0005433368211	21695	Economy	16700.00
0005433368204	21695	Economy	16700.00
0005435652905	21695	Economy	16700.00
0005433368185	21695	Economy	16700.00
0005435652972	21695	Economy	16700.00
0005433368194	21695	Economy	16700.00
0005435652837	21695	Economy	16700.00
0005435652908	21695	Economy	16700.00
0005435653047	21695	Economy	16700.00
0005435652940	21695	Economy	16700.00
0005433368192	21695	Economy	16700.00
0005435653025	21695	Economy	16700.00
0005435653012	21695	Economy	16700.00
0005434466447	23231	Economy	23000.00
0005434466432	23231	Economy	23000.00
0005435312826	23231	Economy	20900.00
0005434466461	23231	Economy	20900.00
0005435312827	23231	Economy	20900.00
0005435312823	23231	Economy	20900.00
0005435312824	23231	Economy	20900.00
0005435312825	23231	Economy	20900.00
0005434466431	23231	Economy	20900.00
0005434466445	23231	Economy	20900.00
0005433986324	4174	Business	21500.00
0005433986352	4174	Business	21500.00
0005433986348	4174	Business	21500.00
0005433986337	4174	Business	21500.00
0005433986330	4174	Business	21500.00
0005433986341	4174	Business	21500.00
0005433986318	4174	Business	21500.00
0005433986310	4174	Economy	7200.00
0005433986323	4174	Economy	7200.00
0005433986322	4174	Economy	7200.00
0005433986327	4174	Economy	7200.00
0005433986336	4174	Economy	7200.00
0005435788791	4174	Economy	7900.00
0005433986331	4174	Economy	7900.00
0005433986319	4174	Economy	7900.00
0005433986308	4174	Economy	7200.00
0005433986349	4174	Economy	7200.00
0005433986311	4174	Economy	7200.00
0005433986354	4174	Economy	7200.00
0005433986321	4174	Economy	7200.00
0005435788792	4174	Economy	7200.00
0005433986306	4174	Economy	7200.00
0005433986345	4174	Economy	7200.00
0005433986332	4174	Economy	7200.00
0005433986333	4174	Economy	7200.00
0005433986351	4174	Economy	7200.00
0005433986340	4174	Economy	7200.00
0005433986339	4174	Economy	7200.00
0005433986309	4174	Economy	7200.00
0005433986320	4174	Economy	7200.00
0005433986328	4174	Economy	7200.00
0005433986315	4174	Economy	7200.00
0005433986344	4174	Economy	7200.00
0005433986353	4174	Economy	7200.00
0005433986329	4174	Economy	7200.00
0005433986350	4174	Economy	7200.00
0005433986313	4174	Economy	7200.00
0005433986307	4174	Economy	7200.00
0005433986335	4174	Economy	7200.00
0005433986355	4174	Economy	7200.00
0005433986343	4174	Economy	7200.00
0005433986326	4174	Economy	7200.00
0005433986314	4174	Economy	7200.00
0005433986316	4174	Economy	7200.00
0005433986325	4174	Economy	7200.00
0005433986334	4174	Economy	7200.00
0005435788793	4174	Economy	7200.00
0005433986317	4174	Economy	7200.00
0005433986346	4174	Economy	7200.00
0005433986312	4174	Economy	7200.00
0005433986342	4174	Economy	7200.00
0005433986338	4174	Economy	7200.00
0005433986347	4174	Economy	7200.00
0005433985825	25653	Business	21500.00
0005433985829	25653	Business	21500.00
0005433985883	25653	Business	21500.00
0005433985761	25653	Business	21500.00
0005433985830	25653	Business	21500.00
0005433985824	25653	Business	21500.00
0005433985743	25653	Business	21500.00
0005433985781	25653	Economy	7200.00
0005433985884	25653	Economy	7200.00
0005433985896	25653	Economy	7200.00
0005433985853	25653	Economy	7200.00
0005433985934	25653	Economy	7200.00
0005433985784	25653	Economy	7200.00
0005433985953	25653	Economy	7200.00
0005433986110	25653	Economy	7200.00
0005433986091	25653	Economy	7200.00
0005433985970	25653	Economy	7900.00
0005433985937	25653	Economy	7900.00
0005433985800	25653	Economy	7200.00
0005433985907	25653	Economy	7200.00
0005433985808	25653	Economy	7200.00
0005433985854	25653	Economy	7200.00
0005433986010	25653	Economy	7200.00
0005433985952	25653	Economy	7200.00
0005433985895	25653	Economy	7200.00
0005433985917	25653	Economy	7200.00
0005433985994	25653	Economy	7200.00
0005433986011	25653	Economy	7200.00
0005433985762	25653	Economy	7200.00
0005433985941	25653	Economy	7200.00
0005433985827	25653	Economy	7200.00
0005433985836	25653	Economy	7200.00
0005433985905	25653	Economy	7200.00
0005433986066	25653	Economy	7200.00
0005433985793	25653	Economy	7200.00
0005433985886	25653	Economy	7200.00
0005433985760	25653	Economy	7200.00
0005433985938	25653	Economy	7200.00
0005433986041	25653	Economy	7200.00
0005433985805	25653	Economy	7200.00
0005433985897	25653	Economy	7200.00
0005433986019	25653	Economy	7200.00
0005433985846	25653	Economy	7200.00
0005433985906	25653	Economy	7200.00
0005433985733	25653	Economy	7200.00
0005433985940	25653	Economy	7200.00
0005433985744	25653	Economy	7200.00
0005433985885	25653	Economy	7200.00
0005433985745	25653	Economy	7200.00
0005433985826	25653	Economy	7200.00
0005433985748	25653	Economy	7200.00
0005433986053	25653	Economy	7200.00
0005433985782	25653	Economy	7200.00
0005433461574	19923	Business	201300.00
0005433461555	19923	Business	201300.00
0005433461591	19923	Business	201300.00
0005433461579	19923	Business	201300.00
0005433463887	19923	Business	201300.00
0005433463886	19923	Business	201300.00
0005433461584	19923	Business	201300.00
0005433463884	19923	Business	201300.00
0005433461565	19923	Economy	73800.00
0005433463867	19923	Economy	67100.00
0005433461575	19923	Economy	67100.00
0005433463892	19923	Economy	67100.00
0005433463879	19923	Economy	67100.00
0005433463872	19923	Economy	67100.00
0005433463891	19923	Economy	67100.00
0005433463893	19923	Economy	67100.00
0005433463881	19923	Economy	67100.00
0005433463888	19923	Economy	67100.00
0005433461568	19923	Economy	67100.00
0005433463882	19923	Economy	67100.00
0005433463894	19923	Economy	67100.00
0005433461572	19923	Economy	67100.00
0005433461567	19923	Economy	67100.00
0005433461569	19923	Economy	67100.00
0005433461571	19923	Economy	67100.00
0005433461592	19923	Economy	67100.00
0005433463883	19923	Economy	67100.00
0005433461573	19923	Economy	67100.00
0005433461576	19923	Economy	67100.00
0005433461577	19923	Economy	67100.00
0005433463885	19923	Economy	67100.00
0005433461583	19923	Economy	67100.00
0005433463890	19923	Economy	67100.00
0005433461566	19923	Economy	67100.00
0005433461570	19923	Economy	67100.00
0005433463889	19923	Economy	67100.00
0005433463880	19923	Economy	67100.00
0005433461578	19923	Economy	67100.00
0005434509202	1632	Economy	17000.00
0005434509215	1632	Economy	17000.00
0005434509208	1632	Economy	17000.00
0005434509203	1632	Economy	15500.00
0005434509207	1632	Economy	15500.00
0005434509212	1632	Economy	15500.00
0005433168392	1632	Economy	15500.00
0005434509198	1632	Economy	15500.00
0005434509201	1632	Economy	15500.00
0005434509195	1632	Economy	15500.00
0005434509216	1632	Economy	15500.00
0005434509204	1632	Economy	15500.00
0005434509196	1632	Economy	15500.00
0005434509213	1632	Economy	15500.00
0005434509217	1632	Economy	15500.00
0005434509197	1632	Economy	15500.00
0005433168365	1632	Economy	15500.00
0005434509210	1632	Economy	15500.00
0005434509214	1632	Economy	15500.00
0005434509199	1632	Economy	15500.00
0005434509211	1632	Economy	15500.00
0005434509194	1632	Economy	15500.00
0005434509205	1632	Economy	15500.00
0005433168366	1632	Economy	15500.00
0005434509206	1632	Economy	15500.00
0005434509209	1632	Economy	15500.00
0005434509200	1632	Economy	15500.00
0005432666384	17838	Business	18000.00
0005432664132	17838	Business	18000.00
0005432869588	17838	Business	18000.00
0005432657435	17838	Business	18000.00
0005432869586	17838	Business	18000.00
0005432663034	17838	Economy	6000.00
0005432664134	17838	Economy	6000.00
0005432660822	17838	Economy	6000.00
0005432655471	17838	Economy	6000.00
0005432664133	17838	Economy	6000.00
0005432869584	17838	Economy	6000.00
0005432657447	17838	Economy	6600.00
0005432659702	17838	Economy	6000.00
0005432658588	17838	Economy	6000.00
0005432869587	17838	Economy	6000.00
0005432664138	17838	Economy	6000.00
0005432661919	17838	Economy	6000.00
0005432660821	17838	Economy	6000.00
0005432655466	17838	Economy	6000.00
0005432659699	17838	Economy	6000.00
0005432655451	17838	Economy	6000.00
0005434151730	17838	Economy	6000.00
0005432869580	17838	Economy	6000.00
0005432869582	17838	Economy	6000.00
0005432658582	17838	Economy	6000.00
0005432666386	17838	Economy	6000.00
0005432660811	17838	Economy	6000.00
0005432655465	17838	Economy	6000.00
0005432661918	17838	Economy	6000.00
0005432655494	17838	Economy	6000.00
0005432655547	17838	Economy	6000.00
0005432658584	17838	Economy	6000.00
0005434151731	17838	Economy	6000.00
0005432658583	17838	Economy	6000.00
0005432869585	17838	Economy	6000.00
0005432655565	17838	Economy	6000.00
0005432666383	17838	Economy	6000.00
0005432869583	17838	Economy	6000.00
0005432869581	17838	Economy	6000.00
0005432663039	17838	Economy	6000.00
0005432664156	26294	Business	18000.00
0005434151687	26294	Business	18000.00
0005434151688	26294	Business	18000.00
0005432655609	26294	Business	18000.00
0005432665289	26294	Business	18000.00
0005432664146	26294	Business	18000.00
0005432657472	26294	Business	18000.00
0005432664143	26294	Business	18000.00
0005432657469	26294	Business	18000.00
0005432869516	26294	Business	18000.00
0005434151708	26294	Economy	6000.00
0005432661929	26294	Economy	6000.00
0005432661934	26294	Economy	6000.00
0005432660832	26294	Economy	6000.00
0005432655607	26294	Economy	6000.00
0005432655610	26294	Economy	6000.00
0005432658608	26294	Economy	6000.00
0005432660834	26294	Economy	6000.00
0005432663044	26294	Economy	6600.00
0005432661932	26294	Economy	6600.00
0005432659721	26294	Economy	6600.00
0005432664152	26294	Economy	6600.00
0005432664148	26294	Economy	6600.00
0005432665290	26294	Economy	6000.00
0005432664144	26294	Economy	6000.00
0005432869505	26294	Economy	6000.00
0005434151686	26294	Economy	6000.00
0005432655618	26294	Economy	6000.00
0005432655613	26294	Economy	6000.00
0005432665288	26294	Economy	6000.00
0005432663053	26294	Economy	6000.00
0005432661943	26294	Economy	6000.00
0005432661935	26294	Economy	6000.00
0005432664149	26294	Economy	6000.00
0005432661940	26294	Economy	6000.00
0005432869506	26294	Economy	6000.00
0005432664145	26294	Economy	6000.00
0005432663047	26294	Economy	6000.00
0005432663048	26294	Economy	6000.00
0005432655614	26294	Economy	6000.00
0005432663055	26294	Economy	6000.00
0005432655608	26294	Economy	6000.00
0005432659720	26294	Economy	6000.00
0005432664150	26294	Economy	6000.00
0005432666404	26294	Economy	6000.00
0005432661930	26294	Economy	6000.00
0005432664154	26294	Economy	6000.00
0005432661933	26294	Economy	6000.00
0005432663052	26294	Economy	6000.00
0005432664147	26294	Economy	6000.00
0005432658606	26294	Economy	6000.00
0005432661938	26294	Economy	6000.00
0005432655617	26294	Economy	6000.00
0005432663050	26294	Economy	6000.00
0005432664155	26294	Economy	6000.00
0005432663046	26294	Economy	6000.00
0005432658607	26294	Economy	6000.00
0005432664157	26294	Economy	6000.00
0005432661941	26294	Economy	6000.00
0005432663041	26294	Economy	6000.00
0005432657470	26294	Economy	6000.00
0005432661931	26294	Economy	6000.00
0005432666403	26294	Economy	6000.00
0005432663042	26294	Economy	6000.00
0005432655611	26294	Economy	6000.00
0005432655616	26294	Economy	6000.00
0005432663045	26294	Economy	6000.00
0005432663043	26294	Economy	6000.00
0005432664153	26294	Economy	6000.00
0005432655615	26294	Economy	6000.00
0005432661928	26294	Economy	6000.00
0005432660833	26294	Economy	6000.00
0005432661937	26294	Economy	6000.00
0005432664151	26294	Economy	6000.00
0005432661942	26294	Economy	6000.00
0005432661939	26294	Economy	6000.00
0005432663054	26294	Economy	6000.00
0005432667470	26294	Economy	6000.00
0005432655612	26294	Economy	6000.00
0005432657471	26294	Economy	6000.00
0005432663049	26294	Economy	6000.00
0005432663051	26294	Economy	6000.00
0005432667469	26294	Economy	6000.00
0005432661936	26294	Economy	6000.00
0005432660831	26294	Economy	6000.00
0005432866067	25053	Business	87300.00
0005432639142	25053	Business	87300.00
0005432639112	25053	Business	87300.00
0005432866060	25053	Business	87300.00
0005432866076	25053	Business	87300.00
0005432866069	25053	Business	87300.00
0005432639096	25053	Business	87300.00
0005432866065	25053	Business	87300.00
0005432639130	25053	Business	87300.00
0005432639081	25053	Economy	29100.00
0005432866080	25053	Economy	29100.00
0005432866070	25053	Economy	29100.00
0005432866072	25053	Economy	29100.00
0005432639182	25053	Economy	29100.00
0005432639105	25053	Economy	29100.00
0005432639125	25053	Economy	29100.00
0005432866064	25053	Economy	29100.00
0005432639131	25053	Economy	29100.00
0005432639148	25053	Economy	32000.00
0005432639128	25053	Economy	32000.00
0005432639129	25053	Economy	32000.00
0005432639058	25053	Economy	32000.00
0005432639155	25053	Economy	32000.00
0005432639089	25053	Economy	29100.00
0005432639095	25053	Economy	29100.00
0005432866059	25053	Economy	29100.00
0005432639107	25053	Economy	29100.00
0005432639021	25053	Economy	29100.00
0005432866071	25053	Economy	29100.00
0005432866079	25053	Economy	29100.00
0005432866063	25053	Economy	29100.00
0005432639110	25053	Economy	29100.00
0005432866062	25053	Economy	29100.00
0005432639109	25053	Economy	29100.00
0005432639117	25053	Economy	29100.00
0005432639154	25053	Economy	29100.00
0005432639085	25053	Economy	29100.00
0005432639181	25053	Economy	29100.00
0005432639062	25053	Economy	29100.00
0005432639059	25053	Economy	29100.00
0005432639094	25053	Economy	29100.00
0005432866074	25053	Economy	29100.00
0005432866075	25053	Economy	29100.00
0005432866068	25053	Economy	29100.00
0005432639108	25053	Economy	29100.00
0005432866078	25053	Economy	29100.00
0005432639072	25053	Economy	29100.00
0005432639101	25053	Economy	29100.00
0005432866073	25053	Economy	29100.00
0005432639099	25053	Economy	29100.00
0005432639156	25053	Economy	29100.00
0005432639143	25053	Economy	29100.00
0005432866058	25053	Economy	29100.00
0005432639123	25053	Economy	29100.00
0005432639098	25053	Economy	29100.00
0005432639092	25053	Economy	29100.00
0005432866061	25053	Economy	29100.00
0005432639075	25053	Economy	29100.00
0005432639078	25053	Economy	29100.00
0005432866077	25053	Economy	29100.00
0005432639111	25053	Economy	29100.00
0005432639144	25053	Economy	29100.00
0005432639114	25053	Economy	29100.00
0005432866066	25053	Economy	29100.00
0005432639145	25053	Economy	29100.00
0005432639113	25053	Economy	29100.00
0005432329087	3109	Business	16100.00
0005432329068	3109	Business	16100.00
0005432329090	3109	Business	16100.00
0005432287232	3109	Business	16100.00
0005432329091	3109	Business	16100.00
0005432287231	3109	Economy	5400.00
0005432329089	3109	Economy	5400.00
0005432329070	3109	Economy	5400.00
0005432329084	3109	Economy	5400.00
0005432287230	3109	Economy	5400.00
0005432329079	3109	Economy	5900.00
0005432329083	3109	Economy	5900.00
0005432329069	3109	Economy	5900.00
0005432329099	3109	Economy	5900.00
0005432329100	3109	Economy	5400.00
0005432329076	3109	Economy	5400.00
0005432329107	3109	Economy	5400.00
0005432329109	3109	Economy	5400.00
0005432287233	3109	Economy	5400.00
0005432329102	3109	Economy	5400.00
0005432329104	3109	Economy	5400.00
0005432329088	3109	Economy	5400.00
0005432329110	3109	Economy	5400.00
0005432329103	3109	Economy	5400.00
0005432329066	3109	Economy	5400.00
0005432329072	3109	Economy	5400.00
0005432329078	3109	Economy	5400.00
0005432329111	3109	Economy	5400.00
0005432329094	3109	Economy	5400.00
0005432905121	3109	Economy	5400.00
0005432329085	3109	Economy	5400.00
0005432329074	3109	Economy	5400.00
0005432329081	3109	Economy	5400.00
0005432329082	3109	Economy	5400.00
0005432329086	3109	Economy	5400.00
0005432329075	3109	Economy	5400.00
0005432287234	3109	Economy	5400.00
0005432329073	3109	Economy	5400.00
0005432329095	3109	Economy	5400.00
0005432329097	3109	Economy	5400.00
0005432329067	3109	Economy	5400.00
0005432329098	3109	Economy	5400.00
0005432329096	3109	Economy	5400.00
0005432329105	3109	Economy	5400.00
0005432329108	3109	Economy	5400.00
0005432329080	3109	Economy	5400.00
0005432329093	3109	Economy	5400.00
0005432329106	3109	Economy	5400.00
0005432329077	3109	Economy	5400.00
0005432329071	3109	Economy	5400.00
0005432329092	3109	Economy	5400.00
0005432905130	3109	Economy	5400.00
0005432329101	3109	Economy	5400.00
0005432328579	31104	Business	16100.00
0005432328618	31104	Business	16100.00
0005432328682	31104	Business	16100.00
0005432328673	31104	Business	16100.00
0005432328601	31104	Business	16100.00
0005432328718	31104	Business	16100.00
0005432328803	31104	Business	16100.00
0005432328710	31104	Business	16100.00
0005432328789	31104	Economy	5400.00
0005432328681	31104	Economy	5400.00
0005432328589	31104	Economy	5400.00
0005432328585	31104	Economy	5400.00
0005432328729	31104	Economy	5400.00
0005433438839	31104	Economy	5400.00
0005432328513	31104	Economy	5400.00
0005432328720	31104	Economy	5900.00
0005432328790	31104	Economy	5900.00
0005432905174	31104	Economy	5900.00
0005432328642	31104	Economy	5900.00
0005432328708	31104	Economy	5400.00
0005432328825	31104	Economy	5400.00
0005432328616	31104	Economy	5400.00
0005432328489	31104	Economy	5400.00
0005432328644	31104	Economy	5400.00
0005432054329	31104	Economy	5400.00
0005432328584	31104	Economy	5400.00
0005432328600	31104	Economy	5400.00
0005432328641	31104	Economy	5400.00
0005432328653	31104	Economy	5400.00
0005432328717	31104	Economy	5400.00
0005432328456	31104	Economy	5400.00
0005432328518	31104	Economy	5400.00
0005432328455	31104	Economy	5400.00
0005432328672	31104	Economy	5400.00
0005432328774	31104	Economy	5400.00
0005432328723	31104	Economy	5400.00
0005432905175	31104	Economy	5400.00
0005432328855	31104	Economy	5400.00
0005432054328	31104	Economy	5400.00
0005432328765	31104	Economy	5400.00
0005432905172	31104	Economy	5400.00
0005432328572	31104	Economy	5400.00
0005432328665	31104	Economy	5400.00
0005432905176	31104	Economy	5400.00
0005432328801	31104	Economy	5400.00
0005432328654	31104	Economy	5400.00
0005432328619	31104	Economy	5400.00
0005432328580	31104	Economy	5400.00
0005432328711	31104	Economy	5400.00
0005432328588	31104	Economy	5400.00
0005432328800	31104	Economy	5400.00
0005433438861	31104	Economy	5400.00
0005432328719	31104	Economy	5400.00
0005432328802	31104	Economy	5400.00
0005432328693	31104	Economy	5400.00
0005432328716	31104	Economy	5400.00
0005432905173	31104	Economy	5400.00
0005433438838	31104	Economy	5400.00
0005432328512	31104	Economy	5400.00
0005432328807	31104	Economy	5400.00
0005432328905	31104	Economy	5400.00
0005432328707	31104	Economy	5400.00
0005432328728	31104	Economy	5400.00
0005432328700	31104	Economy	5400.00
0005432328617	31104	Economy	5400.00
0005432328680	31104	Economy	5400.00
0005435487748	6177	Business	124600.00
0005435487781	6177	Business	124600.00
0005435999385	6177	Business	124600.00
0005435999388	6177	Business	124600.00
0005434309853	6177	Business	124600.00
0005434309861	6177	Business	124600.00
0005432146217	6177	Business	124600.00
0005435297051	6177	Economy	41500.00
0005435999396	6177	Economy	41500.00
0005435487825	6177	Economy	41500.00
0005435297027	6177	Economy	41500.00
0005435487790	6177	Economy	41500.00
0005435487782	6177	Economy	41500.00
0005435487706	6177	Economy	41500.00
0005435487766	6177	Economy	41500.00
0005435999397	6177	Economy	41500.00
0005432146216	6177	Economy	41500.00
0005435999402	6177	Economy	41500.00
0005434309857	6177	Economy	41500.00
0005434309854	6177	Economy	41500.00
0005435999399	6177	Economy	41500.00
0005435297081	6177	Economy	41500.00
0005435999394	6177	Economy	41500.00
0005434309863	6177	Economy	41500.00
0005435297065	6177	Economy	41500.00
0005435487824	6177	Economy	41500.00
0005435487888	6177	Economy	41500.00
0005435487852	6177	Economy	41500.00
0005435999395	6177	Economy	41500.00
0005435999389	6177	Economy	41500.00
0005435297048	6177	Economy	45700.00
0005434309860	6177	Economy	45700.00
0005435487847	6177	Economy	45700.00
0005435999387	6177	Economy	45700.00
0005435999393	6177	Economy	41500.00
0005435487786	6177	Economy	41500.00
0005435487849	6177	Economy	41500.00
0005435297043	6177	Economy	41500.00
0005435999390	6177	Economy	41500.00
0005435487789	6177	Economy	41500.00
0005434309858	6177	Economy	41500.00
0005434309855	6177	Economy	41500.00
0005434309856	6177	Economy	41500.00
0005435999403	6177	Economy	41500.00
0005435999398	6177	Economy	41500.00
0005435999401	6177	Economy	41500.00
0005435297064	6177	Economy	41500.00
0005435487764	6177	Economy	41500.00
0005435297082	6177	Economy	41500.00
0005435487826	6177	Economy	41500.00
0005435487893	6177	Economy	41500.00
0005432146215	6177	Economy	41500.00
0005435999386	6177	Economy	41500.00
0005435487765	6177	Economy	41500.00
0005434309862	6177	Economy	41500.00
0005435487850	6177	Economy	41500.00
0005435487783	6177	Economy	41500.00
0005435487873	6177	Economy	41500.00
0005435487750	6177	Economy	41500.00
0005435487892	6177	Economy	41500.00
0005434309852	6177	Economy	41500.00
0005435999400	6177	Economy	41500.00
0005434309859	6177	Economy	41500.00
0005435297068	6177	Economy	41500.00
0005435297028	6177	Economy	41500.00
0005435999404	6177	Economy	41500.00
0005435487851	6177	Economy	41500.00
0005435999392	6177	Economy	41500.00
0005434309851	6177	Economy	41500.00
0005435999391	6177	Economy	41500.00
0005435487864	6177	Economy	41500.00
0005434309850	6177	Economy	41500.00
0005435297113	19531	Business	124600.00
0005435999238	19531	Business	124600.00
0005434309733	19531	Business	124600.00
0005435297119	19531	Business	124600.00
0005435487997	19531	Business	124600.00
0005435487988	19531	Business	124600.00
0005435297114	19531	Economy	41500.00
0005435487995	19531	Economy	41500.00
0005435488005	19531	Economy	41500.00
0005434309729	19531	Economy	41500.00
0005434309749	19531	Economy	41500.00
0005435487993	19531	Economy	41500.00
0005434309763	19531	Economy	41500.00
0005434309697	19531	Economy	41500.00
0005434309797	19531	Economy	41500.00
0005435487999	19531	Economy	41500.00
0005435487991	19531	Economy	41500.00
0005435999222	19531	Economy	41500.00
0005435487996	19531	Economy	41500.00
0005434309796	19531	Economy	41500.00
0005435487994	19531	Economy	41500.00
0005435999234	19531	Economy	45700.00
0005435487987	19531	Economy	45700.00
0005435297115	19531	Economy	45700.00
0005435488002	19531	Economy	41500.00
0005435488003	19531	Economy	41500.00
0005435487986	19531	Economy	41500.00
0005434309770	19531	Economy	41500.00
0005435999224	19531	Economy	41500.00
0005435999221	19531	Economy	41500.00
0005435297117	19531	Economy	41500.00
0005434309719	19531	Economy	41500.00
0005435999248	19531	Economy	41500.00
0005435488006	19531	Economy	41500.00
0005435488001	19531	Economy	41500.00
0005435488000	19531	Economy	41500.00
0005435999203	19531	Economy	41500.00
0005435999233	19531	Economy	41500.00
0005435487990	19531	Economy	41500.00
0005435487992	19531	Economy	41500.00
0005435999149	19531	Economy	41500.00
0005435297120	19531	Economy	41500.00
0005435487989	19531	Economy	41500.00
0005435488004	19531	Economy	41500.00
0005434309699	19531	Economy	41500.00
0005435487998	19531	Economy	41500.00
0005435999242	19531	Economy	41500.00
0005435999237	19531	Economy	41500.00
0005435297118	19531	Economy	41500.00
0005434309756	19531	Economy	41500.00
0005434309698	19531	Economy	41500.00
0005435297116	19531	Economy	41500.00
0005435487985	19531	Economy	41500.00
0005434446517	17551	Economy	13600.00
0005433158148	17551	Economy	12300.00
0005433158151	17551	Economy	12300.00
0005433158147	17551	Economy	12300.00
0005433158149	17551	Economy	12300.00
0005434446521	17551	Economy	12300.00
0005433158150	17551	Economy	12300.00
0005434446514	17551	Economy	12300.00
0005434446522	17551	Economy	12300.00
0005435518049	1595	Business	86000.00
0005435518062	1595	Business	86000.00
0005435502485	1595	Business	86000.00
0005435502494	1595	Business	86000.00
0005434566032	1595	Business	86000.00
0005435502503	1595	Business	86000.00
0005434566024	1595	Business	86000.00
0005435508447	1595	Business	86000.00
0005434566025	1595	Business	86000.00
0005435518070	1595	Business	86000.00
0005434566028	1595	Economy	28700.00
0005435502493	1595	Economy	28700.00
0005435508453	1595	Economy	28700.00
0005435518072	1595	Economy	28700.00
0005435502487	1595	Economy	28700.00
0005435502496	1595	Economy	28700.00
0005435502505	1595	Economy	28700.00
0005435508449	1595	Economy	28700.00
0005435508454	1595	Economy	28700.00
0005435502486	1595	Economy	28700.00
0005435518068	1595	Economy	31500.00
0005433186073	1595	Economy	31500.00
0005435508459	1595	Economy	31500.00
0005435502495	1595	Economy	31500.00
0005435518066	1595	Economy	31500.00
0005433186124	1595	Economy	28700.00
0005435502498	1595	Economy	28700.00
0005435518067	1595	Economy	28700.00
0005434566031	1595	Economy	28700.00
0005435518058	1595	Economy	28700.00
0005434566036	1595	Economy	28700.00
0005435518052	1595	Economy	28700.00
0005434566033	1595	Economy	28700.00
0005434566034	1595	Economy	28700.00
0005435518053	1595	Economy	28700.00
0005435518050	1595	Economy	28700.00
0005435508448	1595	Economy	28700.00
0005435502506	1595	Economy	28700.00
0005435518069	1595	Economy	28700.00
0005434566029	1595	Economy	28700.00
0005435508451	1595	Economy	28700.00
0005435502497	1595	Economy	28700.00
0005435518059	1595	Economy	28700.00
0005435502490	1595	Economy	28700.00
0005435502492	1595	Economy	28700.00
0005435518051	1595	Economy	28700.00
0005435518071	1595	Economy	28700.00
0005435508452	1595	Economy	28700.00
0005435518064	1595	Economy	28700.00
0005434566026	1595	Economy	28700.00
0005432291951	1595	Economy	28700.00
0005435518057	1595	Economy	28700.00
0005435508455	1595	Economy	28700.00
0005435502501	1595	Economy	28700.00
0005435508462	1595	Economy	28700.00
0005435518055	1595	Economy	28700.00
0005433186091	1595	Economy	28700.00
0005435518061	1595	Economy	28700.00
0005435508460	1595	Economy	28700.00
0005434566023	1595	Economy	28700.00
0005435502499	1595	Economy	28700.00
0005435518054	1595	Economy	28700.00
0005435508461	1595	Economy	28700.00
0005435508457	1595	Economy	28700.00
0005435502488	1595	Economy	28700.00
0005435502502	1595	Economy	28700.00
0005435502504	1595	Economy	28700.00
0005435508450	1595	Economy	28700.00
0005434566027	1595	Economy	28700.00
0005435518065	1595	Economy	28700.00
0005435502489	1595	Economy	28700.00
0005435502507	1595	Economy	28700.00
0005432291950	1595	Economy	28700.00
0005435502500	1595	Economy	28700.00
0005434566030	1595	Economy	28700.00
0005435518063	1595	Economy	28700.00
0005435502491	1595	Economy	28700.00
0005435508458	1595	Economy	28700.00
0005435508456	1595	Economy	28700.00
0005435518056	1595	Economy	28700.00
0005434566035	1595	Economy	28700.00
0005435518060	1595	Economy	28700.00
0005435545697	20888	Business	86000.00
0005435502281	20888	Business	86000.00
0005435502264	20888	Business	86000.00
0005435529182	20888	Business	86000.00
0005435502292	20888	Business	86000.00
0005435545677	20888	Business	86000.00
0005435502257	20888	Business	86000.00
0005433186192	20888	Business	86000.00
0005435502311	20888	Economy	28700.00
0005434565951	20888	Economy	28700.00
0005434565857	20888	Economy	28700.00
0005435502263	20888	Economy	28700.00
0005435502339	20888	Economy	28700.00
0005434565894	20888	Economy	28700.00
0005435529221	20888	Economy	28700.00
0005433186189	20888	Economy	28700.00
0005435529192	20888	Economy	31500.00
0005435502368	20888	Economy	31500.00
0005435529270	20888	Economy	31500.00
0005435502362	20888	Economy	28700.00
0005435529246	20888	Economy	28700.00
0005435529189	20888	Economy	28700.00
0005433186195	20888	Economy	28700.00
0005434565851	20888	Economy	28700.00
0005434565850	20888	Economy	28700.00
0005434565938	20888	Economy	28700.00
0005435529173	20888	Economy	28700.00
0005434565871	20888	Economy	28700.00
0005435529169	20888	Economy	28700.00
0005435529154	20888	Economy	28700.00
0005435545719	20888	Economy	28700.00
0005435545721	20888	Economy	28700.00
0005435502227	20888	Economy	28700.00
0005434565876	20888	Economy	28700.00
0005435529257	20888	Economy	28700.00
0005435545720	20888	Economy	28700.00
0005434565887	20888	Economy	28700.00
0005433186188	20888	Economy	28700.00
0005434565860	20888	Economy	28700.00
0005433186193	20888	Economy	28700.00
0005434565933	20888	Economy	28700.00
0005435502238	20888	Economy	28700.00
0005435502293	20888	Economy	28700.00
0005434565952	20888	Economy	28700.00
0005435502219	20888	Economy	28700.00
0005434565976	20888	Economy	28700.00
0005433186187	20888	Economy	28700.00
0005435545704	20888	Economy	28700.00
0005434565867	20888	Economy	28700.00
0005435529172	20888	Economy	28700.00
0005435502315	20888	Economy	28700.00
0005435502226	20888	Economy	28700.00
0005435502360	20888	Economy	28700.00
0005435502367	20888	Economy	28700.00
0005435529147	20888	Economy	28700.00
0005433186194	20888	Economy	28700.00
0005435545699	20888	Economy	28700.00
0005435529220	20888	Economy	28700.00
0005435502294	20888	Economy	28700.00
0005433186190	20888	Economy	28700.00
0005435529164	20888	Economy	28700.00
0005435529204	20888	Economy	28700.00
0005433186191	20888	Economy	28700.00
0005435502228	20888	Economy	28700.00
0005435529193	20888	Economy	28700.00
0005435529186	20888	Economy	28700.00
0005435502237	20888	Economy	28700.00
0005435545698	20888	Economy	28700.00
0005434565977	20888	Economy	28700.00
0005435529231	20888	Economy	28700.00
0005435153800	3895	Economy	19700.00
0005435153796	3895	Economy	19700.00
0005435153798	3895	Economy	19700.00
0005435153801	3895	Economy	19700.00
0005435153797	3895	Economy	19700.00
0005435931592	3895	Economy	19700.00
0005435153799	3895	Economy	19700.00
0005435153746	21873	Economy	21600.00
0005435153729	21873	Economy	19700.00
0005435153742	21873	Economy	19700.00
0005435153765	21873	Economy	19700.00
0005435931631	21873	Economy	19700.00
0005435153730	21873	Economy	19700.00
0005435931632	21873	Economy	19700.00
0005435153747	21873	Economy	19700.00
0005435153749	21873	Economy	19700.00
0005435931634	21873	Economy	19700.00
0005435931633	21873	Economy	19700.00
0005432628976	7184	Economy	14300.00
0005435225595	7184	Economy	13000.00
0005432628973	7184	Economy	13000.00
0005435225553	7184	Economy	13000.00
0005432628974	7184	Economy	13000.00
0005435225577	7184	Economy	13000.00
0005432628977	7184	Economy	13000.00
0005432628970	7184	Economy	13000.00
0005432628972	7184	Economy	13000.00
0005432628965	7184	Economy	13000.00
0005432628969	7184	Economy	13000.00
0005435225579	7184	Economy	13000.00
0005432628978	7184	Economy	13000.00
0005432628968	7184	Economy	13000.00
0005432628967	7184	Economy	13000.00
0005435225593	7184	Economy	13000.00
0005432628966	7184	Economy	13000.00
0005435225592	7184	Economy	13000.00
0005432628964	7184	Economy	13000.00
0005432628971	7184	Economy	13000.00
0005435225591	7184	Economy	13000.00
0005432628975	7184	Economy	13000.00
0005435225600	7184	Economy	13000.00
0005435225594	7184	Economy	13000.00
0005432628874	28091	Economy	13000.00
0005435225655	28091	Economy	13000.00
0005432628903	28091	Economy	13000.00
0005432628831	28091	Economy	13000.00
0005432628885	28091	Economy	13000.00
0005435225651	28091	Economy	13000.00
0005435225650	28091	Economy	13000.00
0005435225653	28091	Economy	13000.00
0005432628884	28091	Economy	13000.00
0005435225654	28091	Economy	13000.00
0005432628919	28091	Economy	13000.00
0005432628864	28091	Economy	13000.00
0005432628920	28091	Economy	13000.00
0005432628858	28091	Economy	13000.00
0005432628852	28091	Economy	13000.00
0005435225652	28091	Economy	13000.00
0005432628832	28091	Economy	13000.00
0005432628902	28091	Economy	13000.00
0005435225656	28091	Economy	13000.00
0005434267943	8752	Economy	11500.00
0005434267932	8752	Economy	11500.00
0005434267956	8752	Economy	11500.00
0005435960082	8752	Economy	10500.00
0005434267941	8752	Economy	10500.00
0005435960081	8752	Economy	10500.00
0005434267955	8752	Economy	10500.00
0005435960084	8752	Economy	10500.00
0005434267942	8752	Economy	10500.00
0005435960085	8752	Economy	10500.00
0005435960083	8752	Economy	10500.00
0005435960045	15237	Economy	11500.00
0005434267981	15237	Economy	10500.00
0005434267984	15237	Economy	10500.00
0005434267982	15237	Economy	10500.00
0005435960048	15237	Economy	10500.00
0005435960044	15237	Economy	10500.00
0005435960046	15237	Economy	10500.00
0005434267983	15237	Economy	10500.00
0005432675265	1186	Business	115000.00
0005432675254	1186	Business	115000.00
0005432873287	1186	Business	115000.00
0005432693298	1186	Business	115000.00
0005432693313	1186	Business	115000.00
0005432693305	1186	Business	115000.00
0005432675267	1186	Business	115000.00
0005432873276	1186	Business	115000.00
0005432693287	1186	Business	115000.00
0005432675255	1186	Business	115000.00
0005432873290	1186	Business	115000.00
0005432677604	1186	Business	115000.00
0005432693289	1186	Economy	38300.00
0005432675257	1186	Economy	38300.00
0005432873289	1186	Economy	38300.00
0005432693291	1186	Economy	38300.00
0005432693302	1186	Economy	38300.00
0005432675264	1186	Economy	38300.00
0005432675262	1186	Economy	38300.00
0005432693293	1186	Economy	38300.00
0005432693286	1186	Economy	38300.00
0005432693310	1186	Economy	38300.00
0005432873297	1186	Economy	38300.00
0005432675259	1186	Economy	38300.00
0005432675260	1186	Economy	38300.00
0005432693290	1186	Economy	38300.00
0005432693315	1186	Economy	38300.00
0005432675266	1186	Economy	38300.00
0005432693294	1186	Economy	38300.00
0005432675258	1186	Economy	38300.00
0005432677603	1186	Economy	38300.00
0005432693297	1186	Economy	38300.00
0005432873275	1186	Economy	38300.00
0005432693285	1186	Economy	38300.00
0005432693307	1186	Economy	38300.00
0005432693312	1186	Economy	38300.00
0005432693300	1186	Economy	38300.00
0005432675263	1186	Economy	38300.00
0005432693308	1186	Economy	38300.00
0005432693309	1186	Economy	38300.00
0005432693301	1186	Economy	38300.00
0005432693314	1186	Economy	38300.00
0005432675253	1186	Economy	38300.00
0005432693296	1186	Economy	38300.00
0005432693311	1186	Economy	38300.00
0005432693288	1186	Economy	38300.00
0005432675256	1186	Economy	38300.00
0005432693306	1186	Economy	38300.00
0005432693292	1186	Economy	38300.00
0005432675261	1186	Economy	38300.00
0005432677602	1186	Economy	38300.00
0005432693303	1186	Economy	38300.00
0005432693304	1186	Economy	38300.00
0005432693299	1186	Economy	38300.00
0005432693295	1186	Economy	38300.00
0005432873296	1186	Economy	38300.00
0005432675192	17505	Business	115000.00
0005432693049	17505	Business	115000.00
0005432692914	17505	Business	115000.00
0005432692948	17505	Business	115000.00
0005432677564	17505	Business	115000.00
0005432677586	17505	Business	115000.00
0005432677557	17505	Business	115000.00
0005432677578	17505	Economy	38300.00
0005432873352	17505	Economy	38300.00
0005432693069	17505	Economy	38300.00
0005432873349	17505	Economy	38300.00
0005432675173	17505	Economy	38300.00
0005432692828	17505	Economy	38300.00
0005432693019	17505	Economy	42200.00
0005432693009	17505	Economy	42200.00
0005432675174	17505	Economy	42200.00
0005432693067	17505	Economy	38300.00
0005432693058	17505	Economy	38300.00
0005432693117	17505	Economy	38300.00
0005432677556	17505	Economy	38300.00
0005432692915	17505	Economy	38300.00
0005432675128	17505	Economy	38300.00
0005432692882	17505	Economy	38300.00
0005432873354	17505	Economy	38300.00
0005432675145	17505	Economy	38300.00
0005432675118	17505	Economy	38300.00
0005432692947	17505	Economy	38300.00
0005432693031	17505	Economy	38300.00
0005432873348	17505	Economy	38300.00
0005432675082	17505	Economy	38300.00
0005432693018	17505	Economy	38300.00
0005432692975	17505	Economy	38300.00
0005432692919	17505	Economy	38300.00
0005432693118	17505	Economy	38300.00
0005432873351	17505	Economy	38300.00
0005432693082	17505	Economy	38300.00
0005432692890	17505	Economy	38300.00
0005432693093	17505	Economy	38300.00
0005432693083	17505	Economy	38300.00
0005432677565	17505	Economy	38300.00
0005432873353	17505	Economy	38300.00
0005432693068	17505	Economy	38300.00
0005432873350	17505	Economy	38300.00
0005432677587	17505	Economy	38300.00
0005432692881	17505	Economy	38300.00
0005432677549	17505	Economy	38300.00
0005432675146	17505	Economy	38300.00
0005433156784	1150	Economy	15200.00
0005434435310	1150	Economy	15200.00
0005433156783	1150	Economy	15200.00
0005434435316	1150	Economy	13900.00
0005433156739	1150	Economy	13900.00
0005434435317	1150	Economy	13900.00
0005433156688	1150	Economy	13900.00
0005434435312	1150	Economy	13900.00
0005434435307	1150	Economy	13900.00
0005434435311	1150	Economy	13900.00
0005434435306	1150	Economy	13900.00
0005433156740	1150	Economy	13900.00
0005434435320	1150	Economy	13900.00
0005434435315	1150	Economy	13900.00
0005434435309	1150	Economy	13900.00
0005434435305	1150	Economy	13900.00
0005434435318	1150	Economy	13900.00
0005434435304	1150	Economy	13900.00
0005433156794	1150	Economy	13900.00
0005434435313	1150	Economy	13900.00
0005433156760	1150	Economy	13900.00
0005434435319	1150	Economy	13900.00
0005433156689	1150	Economy	13900.00
0005434435314	1150	Economy	13900.00
0005434435308	1150	Economy	13900.00
0005433156825	17321	Economy	15200.00
0005434435184	17321	Economy	15200.00
0005433156820	17321	Economy	13900.00
0005434435179	17321	Economy	13900.00
0005434435155	17321	Economy	13900.00
0005434435128	17321	Economy	13900.00
0005434435187	17321	Economy	13900.00
0005434435251	17321	Economy	13900.00
0005434435188	17321	Economy	13900.00
0005434435102	17321	Economy	13900.00
0005434435214	17321	Economy	13900.00
0005434435186	17321	Economy	13900.00
0005433156822	17321	Economy	13900.00
0005434435120	17321	Economy	13900.00
0005434435183	17321	Economy	13900.00
0005434435213	17321	Economy	13900.00
0005433156819	17321	Economy	13900.00
0005434435216	17321	Economy	13900.00
0005434435087	17321	Economy	13900.00
0005433156826	17321	Economy	13900.00
0005434435142	17321	Economy	13900.00
0005434435127	17321	Economy	13900.00
0005433156824	17321	Economy	13900.00
0005434435217	17321	Economy	13900.00
0005434435119	17321	Economy	13900.00
0005434435141	17321	Economy	13900.00
0005434435084	17321	Economy	13900.00
0005434435126	17321	Economy	13900.00
0005433156823	17321	Economy	13900.00
0005433156821	17321	Economy	13900.00
0005434435118	17321	Economy	13900.00
0005435086897	4105	Economy	8200.00
0005435086898	4105	Economy	7500.00
0005435086900	4105	Economy	7500.00
0005435086894	4105	Economy	7500.00
0005435086902	4105	Economy	7500.00
0005435086899	4105	Economy	7500.00
0005435086896	4105	Economy	7500.00
0005435928140	4105	Economy	7500.00
0005435086901	4105	Economy	7500.00
0005435086895	4105	Economy	7500.00
0005435928126	4105	Economy	7500.00
0005435928183	24424	Economy	8200.00
0005435086828	24424	Economy	7500.00
0005435086815	24424	Economy	7500.00
0005435086829	24424	Economy	7500.00
0005435086811	24424	Economy	7500.00
0005435086846	24424	Economy	7500.00
0005435086819	24424	Economy	7500.00
0005435928185	24424	Economy	7500.00
0005435928182	24424	Economy	7500.00
0005435928184	24424	Economy	7500.00
0005435706510	2458	Business	86800.00
0005435706522	2458	Business	86800.00
0005435706499	2458	Business	86800.00
0005433373563	2458	Business	86800.00
0005433373531	2458	Business	86800.00
0005435706505	2458	Economy	28900.00
0005433373536	2458	Economy	28900.00
0005435706528	2458	Economy	28900.00
0005435706500	2458	Economy	28900.00
0005433373555	2458	Economy	31800.00
0005435706507	2458	Economy	31800.00
0005435706524	2458	Economy	31800.00
0005435706517	2458	Economy	31800.00
0005435706526	2458	Economy	31800.00
0005433373537	2458	Economy	28900.00
0005435706503	2458	Economy	28900.00
0005435706508	2458	Economy	28900.00
0005435706523	2458	Economy	28900.00
0005435706513	2458	Economy	28900.00
0005435706511	2458	Economy	28900.00
0005435706506	2458	Economy	28900.00
0005435706518	2458	Economy	28900.00
0005435706525	2458	Economy	28900.00
0005435706504	2458	Economy	28900.00
0005435706532	2458	Economy	28900.00
0005435706512	2458	Economy	28900.00
0005433373506	2458	Economy	28900.00
0005435706515	2458	Economy	28900.00
0005435706509	2458	Economy	28900.00
0005435706519	2458	Economy	28900.00
0005433373551	2458	Economy	28900.00
0005435706527	2458	Economy	28900.00
0005435706531	2458	Economy	28900.00
0005435706530	2458	Economy	28900.00
0005435706501	2458	Economy	28900.00
0005435706514	2458	Economy	28900.00
0005433373517	2458	Economy	28900.00
0005435706502	2458	Economy	28900.00
0005435706516	2458	Economy	28900.00
0005433373480	2458	Economy	28900.00
0005433373510	2458	Economy	28900.00
0005433373505	2458	Economy	28900.00
0005435706521	2458	Economy	28900.00
0005433373540	2458	Economy	28900.00
0005433373524	2458	Economy	28900.00
0005433373546	2458	Economy	28900.00
0005433373470	2458	Economy	28900.00
0005435706529	2458	Economy	28900.00
0005435706520	2458	Economy	28900.00
0005433373529	2458	Economy	28900.00
0005433373562	2458	Economy	28900.00
0005435706329	27032	Business	86800.00
0005435706444	27032	Business	86800.00
0005433373611	27032	Business	86800.00
0005435706316	27032	Business	86800.00
0005435706386	27032	Business	86800.00
0005435706373	27032	Business	86800.00
0005435706389	27032	Business	86800.00
0005435706410	27032	Business	86800.00
0005435706314	27032	Business	86800.00
0005435706372	27032	Economy	28900.00
0005435706412	27032	Economy	28900.00
0005435706390	27032	Economy	28900.00
0005435706446	27032	Economy	28900.00
0005433373616	27032	Economy	28900.00
0005435706313	27032	Economy	31800.00
0005435706332	27032	Economy	31800.00
0005435706338	27032	Economy	28900.00
0005435706345	27032	Economy	28900.00
0005433373613	27032	Economy	28900.00
0005435706371	27032	Economy	28900.00
0005433373617	27032	Economy	28900.00
0005435706357	27032	Economy	28900.00
0005433373602	27032	Economy	28900.00
0005433373610	27032	Economy	28900.00
0005435706355	27032	Economy	28900.00
0005433373607	27032	Economy	28900.00
0005435706361	27032	Economy	28900.00
0005433373604	27032	Economy	28900.00
0005435706328	27032	Economy	28900.00
0005433373599	27032	Economy	28900.00
0005435706376	27032	Economy	28900.00
0005433373600	27032	Economy	28900.00
0005435706344	27032	Economy	28900.00
0005435706398	27032	Economy	28900.00
0005433373606	27032	Economy	28900.00
0005435706445	27032	Economy	28900.00
0005435706365	27032	Economy	28900.00
0005435706364	27032	Economy	28900.00
0005435706309	27032	Economy	28900.00
0005435706319	27032	Economy	28900.00
0005435706337	27032	Economy	28900.00
0005435706413	27032	Economy	28900.00
0005433373609	27032	Economy	28900.00
0005433373601	27032	Economy	28900.00
0005433373603	27032	Economy	28900.00
0005435706318	27032	Economy	28900.00
0005433373615	27032	Economy	28900.00
0005435706322	27032	Economy	28900.00
0005433373605	27032	Economy	28900.00
0005435706331	27032	Economy	28900.00
0005433373612	27032	Economy	28900.00
0005435706360	27032	Economy	28900.00
0005435706317	27032	Economy	28900.00
0005435706375	27032	Economy	28900.00
0005433373614	27032	Economy	28900.00
0005433373608	27032	Economy	28900.00
0005435706346	27032	Economy	28900.00
0005435706387	27032	Economy	28900.00
0005434964391	1324	Business	203300.00
0005433261564	1324	Business	203300.00
0005433261511	1324	Business	203300.00
0005434964371	1324	Business	203300.00
0005434964397	1324	Business	203300.00
0005433261537	1324	Business	203300.00
0005434964401	1324	Business	203300.00
0005434964359	1324	Business	203300.00
0005433261573	1324	Business	203300.00
0005433261549	1324	Business	203300.00
0005432279290	1324	Business	203300.00
0005433261542	1324	Business	203300.00
0005433261572	1324	Business	203300.00
0005434964364	1324	Economy	74500.00
0005433261568	1324	Economy	74500.00
0005433261550	1324	Economy	67800.00
0005434964381	1324	Economy	67800.00
0005434964394	1324	Economy	67800.00
0005433261558	1324	Economy	67800.00
0005433261540	1324	Economy	67800.00
0005434964370	1324	Economy	67800.00
0005434964384	1324	Economy	67800.00
0005434964376	1324	Economy	67800.00
0005434964382	1324	Economy	67800.00
0005433261510	1324	Economy	67800.00
0005434964392	1324	Economy	67800.00
0005432279287	1324	Economy	67800.00
0005434964389	1324	Economy	67800.00
0005434964357	1324	Economy	67800.00
0005432279286	1324	Economy	67800.00
0005432279285	1324	Economy	67800.00
0005433261575	1324	Economy	67800.00
0005433261536	1324	Economy	67800.00
0005433261544	1324	Economy	67800.00
0005434964346	1324	Economy	67800.00
0005434964366	1324	Economy	67800.00
0005434964379	1324	Economy	67800.00
0005434964353	1324	Economy	67800.00
0005433261545	1324	Economy	67800.00
0005433261539	1324	Economy	67800.00
0005434964385	1324	Economy	67800.00
0005433261552	1324	Economy	67800.00
0005434964355	1324	Economy	67800.00
0005434964399	1324	Economy	67800.00
0005434964369	1324	Economy	67800.00
0005433261555	1324	Economy	67800.00
0005434964386	1324	Economy	67800.00
0005434964363	1324	Economy	67800.00
0005433261584	1324	Economy	67800.00
0005434964390	1324	Economy	67800.00
0005433261567	1324	Economy	67800.00
0005434964349	1324	Economy	67800.00
0005433261571	1324	Economy	67800.00
0005434964374	1324	Economy	67800.00
0005433261541	1324	Economy	67800.00
0005434964351	1324	Economy	67800.00
0005434964387	1324	Economy	67800.00
0005433261509	1324	Economy	67800.00
0005434964373	1324	Economy	67800.00
0005433261548	1324	Economy	67800.00
0005434964383	1324	Economy	67800.00
0005434964395	1324	Economy	67800.00
0005434964360	1324	Economy	67800.00
0005434964358	1324	Economy	67800.00
0005434964393	1324	Economy	67800.00
0005434964354	1324	Economy	67800.00
0005434964347	1324	Economy	67800.00
0005434964368	1324	Economy	74500.00
0005433261551	1324	Economy	67800.00
0005434964388	1324	Economy	74500.00
0005434964378	1324	Economy	74500.00
0005434964344	1324	Economy	67800.00
0005434964362	1324	Economy	67800.00
0005433261524	1324	Economy	67800.00
0005434964375	1324	Economy	67800.00
0005433261543	1324	Economy	67800.00
0005434964400	1324	Economy	67800.00
0005434964367	1324	Economy	67800.00
0005434964365	1324	Economy	67800.00
0005434964361	1324	Economy	67800.00
0005433261553	1324	Economy	67800.00
0005434964356	1324	Economy	67800.00
0005434964377	1324	Economy	67800.00
0005433261512	1324	Economy	67800.00
0005434964398	1324	Economy	67800.00
0005434964396	1324	Economy	67800.00
0005433261574	1324	Economy	67800.00
0005434964350	1324	Economy	67800.00
0005434964345	1324	Economy	67800.00
0005433261513	1324	Economy	67800.00
0005434964348	1324	Economy	67800.00
0005432279288	1324	Economy	67800.00
0005434964380	1324	Economy	67800.00
0005434964372	1324	Economy	67800.00
0005434964352	1324	Economy	67800.00
0005433261563	1324	Economy	67800.00
0005432279289	1324	Economy	67800.00
0005434626039	4860	Business	44200.00
0005433194851	4860	Economy	14700.00
0005435907496	4860	Economy	14700.00
0005434626045	4860	Economy	14700.00
0005434626042	4860	Economy	14700.00
0005435907512	4860	Economy	14700.00
0005435907517	4860	Economy	14700.00
0005434626040	4860	Economy	14700.00
0005434626043	4860	Economy	14700.00
0005434626038	4860	Economy	14700.00
0005434626041	4860	Economy	14700.00
0005434626044	4860	Economy	14700.00
0005434626037	4860	Economy	14700.00
0005434625980	32911	Business	44200.00
0005434625990	32911	Business	44200.00
0005434625995	32911	Business	44200.00
0005433194887	32911	Economy	14700.00
0005434625996	32911	Economy	14700.00
0005435907543	32911	Economy	14700.00
0005435907546	32911	Economy	14700.00
0005434625909	32911	Economy	14700.00
0005433194880	32911	Economy	14700.00
0005433194883	32911	Economy	14700.00
0005433194884	32911	Economy	14700.00
0005433194879	32911	Economy	14700.00
0005435907542	32911	Economy	14700.00
0005433194885	32911	Economy	14700.00
0005435907544	32911	Economy	14700.00
0005434625939	32911	Economy	14700.00
0005433194878	32911	Economy	14700.00
0005433194881	32911	Economy	14700.00
0005433194877	32911	Economy	14700.00
0005435907547	32911	Economy	14700.00
0005435907545	32911	Economy	14700.00
0005433194882	32911	Economy	14700.00
0005434625941	32911	Economy	14700.00
0005433194886	32911	Economy	14700.00
0005435785267	13807	Economy	3400.00
0005435787344	13807	Economy	3400.00
0005435785227	13807	Economy	3400.00
0005435785085	13807	Economy	3400.00
0005432195711	13807	Economy	3100.00
0005435785187	13807	Economy	3100.00
0005435787345	13807	Economy	3100.00
0005435785179	13807	Economy	3100.00
0005435785297	13807	Economy	3100.00
0005435785166	13807	Economy	3100.00
0005435937417	13807	Economy	3100.00
0005435785264	13807	Economy	3100.00
0005435785225	13807	Economy	3100.00
0005435787358	13807	Economy	3100.00
0005435785285	13807	Economy	3100.00
0005435785196	13807	Economy	3100.00
0005435785177	13807	Economy	3100.00
0005435785228	13807	Economy	3100.00
0005435785218	13807	Economy	3100.00
0005435785462	13807	Economy	3100.00
0005435785359	13807	Economy	3100.00
0005435785183	13807	Economy	3100.00
0005435785276	13807	Economy	3100.00
0005435785383	13807	Economy	3100.00
0005435785329	13807	Economy	3100.00
0005435785340	13807	Economy	3100.00
0005435787357	13807	Economy	3100.00
0005435785374	13807	Economy	3100.00
0005435937416	13807	Economy	3100.00
0005435785384	13807	Economy	3100.00
0005435785223	13807	Economy	3100.00
0005435785328	13807	Economy	3100.00
0005435785483	13807	Economy	3100.00
0005435785331	13807	Economy	3100.00
0005435785208	13807	Economy	3100.00
0005435785119	13807	Economy	3100.00
0005435785226	13807	Economy	3100.00
0005435785330	13807	Economy	3100.00
0005435787359	13807	Economy	3100.00
0005435785412	13807	Economy	3100.00
0005435787349	13807	Economy	3100.00
0005435785161	13807	Economy	3100.00
0005435785219	13807	Economy	3100.00
0005435785243	13807	Economy	3100.00
0005432195710	13807	Economy	3100.00
0005435785339	13807	Economy	3100.00
0005435785118	13807	Economy	3100.00
0005435785240	13807	Economy	3100.00
0005432190656	27404	Economy	3400.00
0005435785591	27404	Economy	3400.00
0005435785582	27404	Economy	3400.00
0005435937377	27404	Economy	3400.00
0005435785603	27404	Economy	3100.00
0005435937373	27404	Economy	3100.00
0005435785585	27404	Economy	3100.00
0005435785580	27404	Economy	3100.00
0005435785587	27404	Economy	3100.00
0005435785589	27404	Economy	3100.00
0005435785590	27404	Economy	3100.00
0005432190657	27404	Economy	3100.00
0005435785602	27404	Economy	3100.00
0005435785588	27404	Economy	3100.00
0005435937369	27404	Economy	3100.00
0005435787369	27404	Economy	3100.00
0005435785606	27404	Economy	3100.00
0005435787370	27404	Economy	3100.00
0005435785594	27404	Economy	3100.00
0005435785578	27404	Economy	3100.00
0005435785608	27404	Economy	3100.00
0005435785592	27404	Economy	3100.00
0005435785601	27404	Economy	3100.00
0005435785604	27404	Economy	3100.00
0005435785599	27404	Economy	3100.00
0005435785583	27404	Economy	3100.00
0005435785584	27404	Economy	3100.00
0005435785579	27404	Economy	3100.00
0005435785600	27404	Economy	3100.00
0005435785598	27404	Economy	3100.00
0005432190654	27404	Economy	3100.00
0005435785609	27404	Economy	3100.00
0005435785612	27404	Economy	3100.00
0005435785596	27404	Economy	3100.00
0005435785597	27404	Economy	3100.00
0005435785586	27404	Economy	3100.00
0005435785611	27404	Economy	3100.00
0005435937367	27404	Economy	3100.00
0005435785581	27404	Economy	3100.00
0005432190655	27404	Economy	3100.00
0005435787368	27404	Economy	3100.00
0005435785593	27404	Economy	3100.00
0005435785610	27404	Economy	3100.00
0005435785605	27404	Economy	3100.00
0005435785607	27404	Economy	3100.00
0005435937376	27404	Economy	3100.00
0005435785595	27404	Economy	3100.00
0005435785613	27404	Economy	3100.00
0005434407486	20249	Business	12000.00
0005434407426	20249	Business	12000.00
0005434407539	20249	Business	12000.00
0005432058413	20249	Business	12000.00
0005432058417	20249	Business	12000.00
0005432058414	20249	Business	12000.00
0005434407969	20249	Business	12000.00
0005434407754	20249	Economy	4000.00
0005435311157	20249	Economy	4000.00
0005434407927	20249	Economy	4000.00
0005434407873	20249	Economy	4000.00
0005434407857	20249	Economy	4000.00
0005434408023	20249	Economy	4000.00
0005434407780	20249	Economy	4000.00
0005434407557	20249	Economy	4000.00
0005434407644	20249	Economy	4400.00
0005435311161	20249	Economy	4400.00
0005435311162	20249	Economy	4400.00
0005434407951	20249	Economy	4400.00
0005434407577	20249	Economy	4400.00
0005434407738	20249	Economy	4000.00
0005434407540	20249	Economy	4000.00
0005434407858	20249	Economy	4000.00
0005434407856	20249	Economy	4000.00
0005434407878	20249	Economy	4000.00
0005434407748	20249	Economy	4000.00
0005434407753	20249	Economy	4000.00
0005434407549	20249	Economy	4000.00
0005434407758	20249	Economy	4000.00
0005434407762	20249	Economy	4000.00
0005434407771	20249	Economy	4000.00
0005434407494	20249	Economy	4000.00
0005434407957	20249	Economy	4000.00
0005434407601	20249	Economy	4000.00
0005435311160	20249	Economy	4000.00
0005434407896	20249	Economy	4000.00
0005434407584	20249	Economy	4000.00
0005435311159	20249	Economy	4000.00
0005434407772	20249	Economy	4000.00
0005434407675	20249	Economy	4000.00
0005432058415	20249	Economy	4000.00
0005434407678	20249	Economy	4000.00
0005434407855	20249	Economy	4000.00
0005434407928	20249	Economy	4000.00
0005434408024	20249	Economy	4000.00
0005434407874	20249	Economy	4000.00
0005434407939	20249	Economy	4000.00
0005434407879	20249	Economy	4000.00
0005434407898	20249	Economy	4000.00
0005434407714	20249	Economy	4000.00
0005434407741	20249	Economy	4000.00
0005432058416	20249	Economy	4000.00
0005434407495	20249	Economy	4000.00
0005434407583	20249	Economy	4000.00
0005434407838	20249	Economy	4000.00
0005435311158	20249	Economy	4000.00
0005434407630	20249	Economy	4000.00
0005434407631	20249	Economy	4000.00
0005434407859	20249	Economy	4000.00
0005434407715	20249	Economy	4000.00
0005434407679	20249	Economy	4000.00
0005434407791	20249	Economy	4000.00
0005434407815	20249	Economy	4000.00
0005434407773	20249	Economy	4000.00
0005434408025	20249	Economy	4000.00
0005434407781	20249	Economy	4000.00
0005434407792	20249	Economy	4000.00
0005434407740	20249	Economy	4000.00
0005434407564	20249	Economy	4000.00
0005434407561	20249	Economy	4000.00
0005435311064	27002	Business	12000.00
0005434408254	27002	Business	12000.00
0005434408259	27002	Business	12000.00
0005434408301	27002	Business	12000.00
0005434408284	27002	Business	12000.00
0005432153995	27002	Business	12000.00
0005434408294	27002	Business	12000.00
0005432153998	27002	Business	12000.00
0005434408283	27002	Business	12000.00
0005434408268	27002	Business	12000.00
0005434408302	27002	Business	12000.00
0005434408313	27002	Economy	4000.00
0005434408281	27002	Economy	4000.00
0005434408307	27002	Economy	4000.00
0005435311051	27002	Economy	4000.00
0005432153994	27002	Economy	4000.00
0005435311050	27002	Economy	4000.00
0005434408265	27002	Economy	4000.00
0005434408267	27002	Economy	4000.00
0005434408287	27002	Economy	4400.00
0005434408272	27002	Economy	4400.00
0005434408310	27002	Economy	4400.00
0005434408270	27002	Economy	4400.00
0005434408258	27002	Economy	4400.00
0005434408289	27002	Economy	4000.00
0005434408262	27002	Economy	4000.00
0005434408304	27002	Economy	4000.00
0005434408255	27002	Economy	4000.00
0005434408308	27002	Economy	4000.00
0005434408293	27002	Economy	4000.00
0005434408295	27002	Economy	4000.00
0005434408264	27002	Economy	4000.00
0005434408263	27002	Economy	4000.00
0005434408306	27002	Economy	4000.00
0005434408290	27002	Economy	4000.00
0005434408286	27002	Economy	4000.00
0005434408292	27002	Economy	4000.00
0005435311049	27002	Economy	4000.00
0005435311061	27002	Economy	4000.00
0005432153993	27002	Economy	4000.00
0005434408312	27002	Economy	4000.00
0005434408316	27002	Economy	4000.00
0005434408276	27002	Economy	4000.00
0005434408277	27002	Economy	4000.00
0005434408275	27002	Economy	4000.00
0005432153996	27002	Economy	4000.00
0005434408274	27002	Economy	4000.00
0005434408260	27002	Economy	4000.00
0005434408314	27002	Economy	4000.00
0005435311046	27002	Economy	4000.00
0005434408303	27002	Economy	4000.00
0005435311039	27002	Economy	4000.00
0005434408317	27002	Economy	4000.00
0005434408256	27002	Economy	4000.00
0005432153997	27002	Economy	4000.00
0005434408311	27002	Economy	4000.00
0005432153999	27002	Economy	4000.00
0005434408296	27002	Economy	4000.00
0005434408261	27002	Economy	4000.00
0005434408273	27002	Economy	4000.00
0005434408297	27002	Economy	4000.00
0005435311015	27002	Economy	4000.00
0005434408300	27002	Economy	4000.00
0005434408305	27002	Economy	4000.00
0005434408278	27002	Economy	4000.00
0005434408309	27002	Economy	4000.00
0005434408257	27002	Economy	4000.00
0005434408269	27002	Economy	4000.00
0005435311047	27002	Economy	4000.00
0005434408315	27002	Economy	4000.00
0005434408285	27002	Economy	4000.00
0005434408279	27002	Economy	4000.00
0005434408266	27002	Economy	4000.00
0005435311055	27002	Economy	4000.00
0005434408299	27002	Economy	4000.00
0005434408291	27002	Economy	4000.00
0005434408280	27002	Economy	4000.00
0005434408271	27002	Economy	4000.00
0005435311040	27002	Economy	4000.00
0005435311014	27002	Economy	4000.00
0005434408298	27002	Economy	4000.00
0005434408282	27002	Economy	4000.00
0005434408288	27002	Economy	4000.00
0005432109726	5723	Business	43300.00
0005433123942	5723	Business	43300.00
0005434319520	5723	Business	43300.00
0005434319513	5723	Business	43300.00
0005433123914	5723	Business	43300.00
0005434319526	5723	Business	43300.00
0005434319511	5723	Business	43300.00
0005433123854	5723	Economy	14400.00
0005434319524	5723	Economy	14400.00
0005434319518	5723	Economy	14400.00
0005433123866	5723	Economy	15900.00
0005434319522	5723	Economy	15900.00
0005434319512	5723	Economy	14400.00
0005433123944	5723	Economy	14400.00
0005432109725	5723	Economy	14400.00
0005434319519	5723	Economy	14400.00
0005433123965	5723	Economy	14400.00
0005434319516	5723	Economy	14400.00
0005433123912	5723	Economy	14400.00
0005432109727	5723	Economy	14400.00
0005433123915	5723	Economy	14400.00
0005434319527	5723	Economy	14400.00
0005433123948	5723	Economy	14400.00
0005434319525	5723	Economy	14400.00
0005434319517	5723	Economy	14400.00
0005433123943	5723	Economy	14400.00
0005434319510	5723	Economy	14400.00
0005434319515	5723	Economy	14400.00
0005433123947	5723	Economy	14400.00
0005433123884	5723	Economy	14400.00
0005433123923	5723	Economy	14400.00
0005434319514	5723	Economy	14400.00
0005434319521	5723	Economy	14400.00
0005433123927	5723	Economy	14400.00
0005434319528	5723	Economy	14400.00
0005433123848	5723	Economy	14400.00
0005434319523	5723	Economy	14400.00
0005433123885	5723	Economy	14400.00
0005433123911	5723	Economy	14400.00
0005434311237	5723	Economy	14400.00
0005434319349	15656	Business	43300.00
0005433124100	15656	Business	43300.00
0005433124102	15656	Business	43300.00
0005434311211	15656	Business	43300.00
0005433124113	15656	Business	43300.00
0005433124106	15656	Economy	14400.00
0005434319342	15656	Economy	14400.00
0005433124103	15656	Economy	14400.00
0005433124101	15656	Economy	14400.00
0005434319303	15656	Economy	14400.00
0005433124109	15656	Economy	14400.00
0005434312300	15656	Economy	14400.00
0005433124098	15656	Economy	15900.00
0005433124105	15656	Economy	15900.00
0005433124117	15656	Economy	14400.00
0005433124119	15656	Economy	14400.00
0005433124118	15656	Economy	14400.00
0005434311210	15656	Economy	14400.00
0005434319276	15656	Economy	14400.00
0005434319302	15656	Economy	14400.00
0005433124108	15656	Economy	14400.00
0005434319350	15656	Economy	14400.00
0005433124111	15656	Economy	14400.00
0005433124110	15656	Economy	14400.00
0005434311225	15656	Economy	14400.00
0005433124116	15656	Economy	14400.00
0005433124099	15656	Economy	14400.00
0005434311221	15656	Economy	14400.00
0005433124115	15656	Economy	14400.00
0005434319293	15656	Economy	14400.00
0005433124107	15656	Economy	14400.00
0005434312301	15656	Economy	14400.00
0005433124112	15656	Economy	14400.00
0005434319294	15656	Economy	14400.00
0005434319304	15656	Economy	14400.00
0005434312317	15656	Economy	14400.00
0005433124097	15656	Economy	14400.00
0005433124114	15656	Economy	14400.00
0005433124104	15656	Economy	14400.00
0005434311224	15656	Economy	14400.00
0005434312302	15656	Economy	14400.00
0005435219218	31745	Economy	15500.00
0005435220338	31745	Economy	15500.00
0005435220335	31745	Economy	15500.00
0005435219216	31745	Economy	15500.00
0005435220339	31745	Economy	15500.00
0005435220336	31745	Economy	15500.00
0005435219219	31745	Economy	15500.00
0005435220337	31745	Economy	15500.00
0005435219217	31745	Economy	15500.00
0005435219220	31745	Economy	15500.00
0005434189161	8992	Economy	27400.00
0005434189160	8992	Economy	24900.00
0005434484403	8992	Economy	24900.00
0005434484400	8992	Economy	24900.00
0005434484404	8992	Economy	24900.00
0005434484405	8992	Economy	24900.00
0005434189163	8992	Economy	24900.00
0005434484402	8992	Economy	24900.00
0005434189164	8992	Economy	24900.00
0005434189149	8992	Economy	24900.00
0005434484401	8992	Economy	24900.00
0005434484309	16658	Economy	27400.00
0005434484324	16658	Economy	24900.00
0005434189227	16658	Economy	24900.00
0005434484336	16658	Economy	24900.00
0005434484316	16658	Economy	24900.00
0005434484370	16658	Economy	24900.00
0005434484359	16658	Economy	24900.00
0005434189229	16658	Economy	24900.00
0005434189228	16658	Economy	24900.00
0005434484310	16658	Economy	24900.00
0005434484315	16658	Economy	24900.00
0005434484348	16658	Economy	24900.00
0005434189226	16658	Economy	24900.00
0005433124112	7535	Business	11100.00
0005433124101	7535	Business	11100.00
0005433124105	7535	Business	11100.00
0005433124099	7535	Economy	3700.00
0005433124118	7535	Economy	3700.00
0005433722194	7535	Economy	3700.00
0005433124100	7535	Economy	3700.00
0005433124113	7535	Economy	4100.00
0005433722216	7535	Economy	4100.00
0005433124114	7535	Economy	4100.00
0005433124103	7535	Economy	3700.00
0005433124119	7535	Economy	3700.00
0005433124115	7535	Economy	3700.00
0005433124106	7535	Economy	3700.00
0005433124111	7535	Economy	3700.00
0005433722202	7535	Economy	3700.00
0005433722201	7535	Economy	3700.00
0005433124117	7535	Economy	3700.00
0005433124098	7535	Economy	3700.00
0005433722211	7535	Economy	3700.00
0005433124116	7535	Economy	3700.00
0005433124102	7535	Economy	3700.00
0005433124108	7535	Economy	3700.00
0005433722215	7535	Economy	3700.00
0005433722212	7535	Economy	3700.00
0005433124097	7535	Economy	3700.00
0005433124104	7535	Economy	3700.00
0005433124107	7535	Economy	3700.00
0005433124110	7535	Economy	3700.00
0005433124109	7535	Economy	3700.00
0005432693327	7716	Business	11100.00
0005432693342	7716	Business	11100.00
0005432721123	7716	Business	11100.00
0005432071598	7716	Business	11100.00
0005432721119	7716	Business	11100.00
0005432693317	7716	Business	11100.00
0005432721140	7716	Business	11100.00
0005432693319	7716	Business	11100.00
0005432721138	7716	Business	11100.00
0005432693320	7716	Business	11100.00
0005432693323	7716	Economy	3700.00
0005432693331	7716	Economy	3700.00
0005433450155	7716	Economy	3700.00
0005433450151	7716	Economy	3700.00
0005433450160	7716	Economy	3700.00
0005432693347	7716	Economy	3700.00
0005433450158	7716	Economy	3700.00
0005433450143	7716	Economy	3700.00
0005432721136	7716	Economy	4100.00
0005432693333	7716	Economy	4100.00
0005432721129	7716	Economy	4100.00
0005432721141	7716	Economy	4100.00
0005432721139	7716	Economy	3700.00
0005432693321	7716	Economy	3700.00
0005432721128	7716	Economy	3700.00
0005432721142	7716	Economy	3700.00
0005432721137	7716	Economy	3700.00
0005432693345	7716	Economy	3700.00
0005432721132	7716	Economy	3700.00
0005432693340	7716	Economy	3700.00
0005433450147	7716	Economy	3700.00
0005433450156	7716	Economy	3700.00
0005432721121	7716	Economy	3700.00
0005432693337	7716	Economy	3700.00
0005432071600	7716	Economy	3700.00
0005433450142	7716	Economy	3700.00
0005432721130	7716	Economy	3700.00
0005432693316	7716	Economy	3700.00
0005432693332	7716	Economy	3700.00
0005432693322	7716	Economy	3700.00
0005432721120	7716	Economy	3700.00
0005432721133	7716	Economy	3700.00
0005432693325	7716	Economy	3700.00
0005433450148	7716	Economy	3700.00
0005432693344	7716	Economy	3700.00
0005432693335	7716	Economy	3700.00
0005433450157	7716	Economy	3700.00
0005432721124	7716	Economy	3700.00
0005432693343	7716	Economy	3700.00
0005432721134	7716	Economy	3700.00
0005432693326	7716	Economy	3700.00
0005432693339	7716	Economy	3700.00
0005433450146	7716	Economy	3700.00
0005432693346	7716	Economy	3700.00
0005432693328	7716	Economy	3700.00
0005432693324	7716	Economy	3700.00
0005432693329	7716	Economy	3700.00
0005432693336	7716	Economy	3700.00
0005432721116	7716	Economy	3700.00
0005433450162	7716	Economy	3700.00
0005432721135	7716	Economy	3700.00
0005433450153	7716	Economy	3700.00
0005432693334	7716	Economy	3700.00
0005433450161	7716	Economy	3700.00
0005433450149	7716	Economy	3700.00
0005432071599	7716	Economy	3700.00
0005433450141	7716	Economy	3700.00
0005433450154	7716	Economy	3700.00
0005432721127	7716	Economy	3700.00
0005432693318	7716	Economy	3700.00
0005432693330	7716	Economy	3700.00
0005433450152	7716	Economy	3700.00
0005433450145	7716	Economy	3700.00
0005433450159	7716	Economy	3700.00
0005432721117	7716	Economy	3700.00
0005432721131	7716	Economy	3700.00
0005432721118	7716	Economy	3700.00
0005432721125	7716	Economy	3700.00
0005432693341	7716	Economy	3700.00
0005433450150	7716	Economy	3700.00
0005432693338	7716	Economy	3700.00
0005433450144	7716	Economy	3700.00
0005432721126	7716	Economy	3700.00
0005432721122	7716	Economy	3700.00
0005432693083	30311	Business	11100.00
0005432692919	30311	Business	11100.00
0005433449931	30311	Business	11100.00
0005432693069	30311	Business	11100.00
0005432693009	30311	Business	11100.00
0005432693049	30311	Business	11100.00
0005432692948	30311	Business	11100.00
0005433449993	30311	Economy	3700.00
0005433450012	30311	Economy	3700.00
0005432693093	30311	Economy	3700.00
0005432692828	30311	Economy	3700.00
0005432692975	30311	Economy	4100.00
0005432693019	30311	Economy	3700.00
0005432692915	30311	Economy	3700.00
0005432693118	30311	Economy	3700.00
0005432693018	30311	Economy	3700.00
0005432692882	30311	Economy	3700.00
0005433449820	30311	Economy	3700.00
0005432692914	30311	Economy	3700.00
0005433449898	30311	Economy	3700.00
0005432693082	30311	Economy	3700.00
0005433449992	30311	Economy	3700.00
0005432693068	30311	Economy	3700.00
0005433449819	30311	Economy	3700.00
0005433449940	30311	Economy	3700.00
0005433449974	30311	Economy	3700.00
0005432693067	30311	Economy	3700.00
0005432692947	30311	Economy	3700.00
0005432692890	30311	Economy	3700.00
0005432692881	30311	Economy	3700.00
0005432693031	30311	Economy	3700.00
0005432693058	30311	Economy	3700.00
0005432693117	30311	Economy	3700.00
0005433449956	30311	Economy	3700.00
0005433449939	30311	Economy	3700.00
0005433449899	30311	Economy	3700.00
0005432720879	30312	Business	11100.00
0005433123911	30312	Business	11100.00
0005432720927	30312	Business	11100.00
0005433123915	30312	Business	11100.00
0005433123923	30312	Economy	3700.00
0005432720897	30312	Economy	3700.00
0005432721021	30312	Economy	4100.00
0005432720871	30312	Economy	4100.00
0005433722279	30312	Economy	4100.00
0005433123914	30312	Economy	4100.00
0005433722280	30312	Economy	4100.00
0005433123947	30312	Economy	3700.00
0005433123965	30312	Economy	3700.00
0005432720939	30312	Economy	3700.00
0005432720894	30312	Economy	3700.00
0005433123948	30312	Economy	3700.00
0005433123912	30312	Economy	3700.00
0005433123854	30312	Economy	3700.00
0005432720947	30312	Economy	3700.00
0005432721009	30312	Economy	3700.00
0005433722278	30312	Economy	3700.00
0005432720876	30312	Economy	3700.00
0005433123944	30312	Economy	3700.00
0005432721085	30312	Economy	3700.00
0005432720923	30312	Economy	3700.00
0005432720926	30312	Economy	3700.00
0005432720972	30312	Economy	3700.00
0005433123884	30312	Economy	3700.00
0005433123942	30312	Economy	3700.00
0005432720896	30312	Economy	3700.00
0005432720880	30312	Economy	3700.00
0005433123927	30312	Economy	3700.00
0005432720838	30312	Economy	3700.00
0005432720900	30312	Economy	3700.00
0005432720840	30312	Economy	3700.00
0005433123848	30312	Economy	3700.00
0005432720928	30312	Economy	3700.00
0005432720924	30312	Economy	3700.00
0005433722277	30312	Economy	3700.00
0005433123943	30312	Economy	3700.00
0005433722281	30312	Economy	3700.00
0005433123885	30312	Economy	3700.00
0005432720799	30312	Economy	3700.00
0005433123866	30312	Economy	3700.00
0005432720839	30312	Economy	3700.00
0005432720873	30312	Economy	3700.00
0005434586838	1388	Business	70400.00
0005432271028	1388	Business	70400.00
0005433193008	1388	Business	70400.00
0005433525126	1388	Business	70400.00
0005432271029	1388	Business	70400.00
0005433193031	1388	Business	70400.00
0005434586834	1388	Business	70400.00
0005434586827	1388	Business	70400.00
0005433193077	1388	Business	70400.00
0005434586840	1388	Economy	23500.00
0005434586839	1388	Economy	23500.00
0005433193064	1388	Economy	23500.00
0005434586832	1388	Economy	23500.00
0005434586837	1388	Economy	23500.00
0005432968833	1388	Economy	23500.00
0005433193061	1388	Economy	23500.00
0005434586816	1388	Economy	23500.00
0005434586822	1388	Economy	23500.00
0005433525133	1388	Economy	23500.00
0005433525127	1388	Economy	25800.00
0005433525131	1388	Economy	25800.00
0005432927983	1388	Economy	25800.00
0005434586817	1388	Economy	25800.00
0005434586826	1388	Economy	23500.00
0005434586829	1388	Economy	23500.00
0005433724844	1388	Economy	23500.00
0005433193073	1388	Economy	23500.00
0005433193069	1388	Economy	23500.00
0005433193071	1388	Economy	23500.00
0005434586820	1388	Economy	23500.00
0005434514988	1388	Economy	23500.00
0005434586836	1388	Economy	23500.00
0005434586830	1388	Economy	23500.00
0005433193062	1388	Economy	23500.00
0005432271030	1388	Economy	23500.00
0005434586815	1388	Economy	23500.00
0005433193063	1388	Economy	23500.00
0005434586824	1388	Economy	23500.00
0005433525130	1388	Economy	23500.00
0005433724845	1388	Economy	23500.00
0005434586835	1388	Economy	23500.00
0005433724842	1388	Economy	23500.00
0005433525134	1388	Economy	23500.00
0005434586818	1388	Economy	23500.00
0005434586821	1388	Economy	23500.00
0005432968842	1388	Economy	23500.00
0005433525129	1388	Economy	23500.00
0005432927968	1388	Economy	23500.00
0005434586841	1388	Economy	23500.00
0005432927978	1388	Economy	23500.00
0005433193095	1388	Economy	23500.00
0005434514990	1388	Economy	23500.00
0005434586833	1388	Economy	23500.00
0005433193003	1388	Economy	23500.00
0005434514989	1388	Economy	23500.00
0005434513602	1388	Economy	23500.00
0005432927965	1388	Economy	23500.00
0005433193037	1388	Economy	23500.00
0005433193072	1388	Economy	23500.00
0005432968832	1388	Economy	23500.00
0005433193038	1388	Economy	23500.00
0005433193109	1388	Economy	23500.00
0005433525128	1388	Economy	23500.00
0005433193007	1388	Economy	23500.00
0005433724843	1388	Economy	23500.00
0005434513601	1388	Economy	23500.00
0005434586831	1388	Economy	23500.00
0005434586828	1388	Economy	23500.00
0005433525132	1388	Economy	23500.00
0005433525135	1388	Economy	23500.00
0005434586825	1388	Economy	23500.00
0005433193023	1388	Economy	23500.00
0005432927964	1388	Economy	23500.00
0005434586819	1388	Economy	23500.00
0005434586823	1388	Economy	23500.00
0005432968844	1388	Economy	23500.00
0005434586583	18532	Business	70400.00
0005433193157	18532	Business	70400.00
0005434586571	18532	Business	70400.00
0005433193156	18532	Business	70400.00
0005434586649	18532	Business	70400.00
0005434586651	18532	Business	70400.00
0005434586582	18532	Business	70400.00
0005434586620	18532	Business	70400.00
0005434586632	18532	Business	70400.00
0005434586692	18532	Business	70400.00
0005433193155	18532	Business	70400.00
0005432928025	18532	Economy	23500.00
0005432928023	18532	Economy	23500.00
0005433724796	18532	Economy	23500.00
0005434586618	18532	Economy	23500.00
0005433724810	18532	Economy	23500.00
0005434586604	18532	Economy	25800.00
0005434586502	18532	Economy	25800.00
0005434586637	18532	Economy	25800.00
0005434586626	18532	Economy	25800.00
0005433724797	18532	Economy	23500.00
0005434586572	18532	Economy	23500.00
0005434586619	18532	Economy	23500.00
0005433724811	18532	Economy	23500.00
0005432928028	18532	Economy	23500.00
0005432928026	18532	Economy	23500.00
0005433193163	18532	Economy	23500.00
0005434586682	18532	Economy	23500.00
0005432968858	18532	Economy	23500.00
0005434586655	18532	Economy	23500.00
0005434586581	18532	Economy	23500.00
0005433724798	18532	Economy	23500.00
0005434586680	18532	Economy	23500.00
0005433193152	18532	Economy	23500.00
0005433724824	18532	Economy	23500.00
0005433193159	18532	Economy	23500.00
0005434586600	18532	Economy	23500.00
0005433724788	18532	Economy	23500.00
0005433193151	18532	Economy	23500.00
0005432928024	18532	Economy	23500.00
0005433193158	18532	Economy	23500.00
0005434586555	18532	Economy	23500.00
0005433525008	18532	Economy	23500.00
0005434586603	18532	Economy	23500.00
0005432968859	18532	Economy	23500.00
0005433724825	18532	Economy	23500.00
0005434586644	18532	Economy	23500.00
0005433524945	18532	Economy	23500.00
0005434586650	18532	Economy	23500.00
0005433193161	18532	Economy	23500.00
0005434586573	18532	Economy	23500.00
0005433525043	18532	Economy	23500.00
0005433193154	18532	Economy	23500.00
0005433724799	18532	Economy	23500.00
0005434586638	18532	Economy	23500.00
0005432928027	18532	Economy	23500.00
0005433193162	18532	Economy	23500.00
0005434586593	18532	Economy	23500.00
0005434586679	18532	Economy	23500.00
0005434586625	18532	Economy	23500.00
0005433193160	18532	Economy	23500.00
0005434586501	18532	Economy	23500.00
0005434586452	18532	Economy	23500.00
0005434586591	18532	Economy	23500.00
0005434586627	18532	Economy	23500.00
0005434586514	18532	Economy	23500.00
0005433193153	18532	Economy	23500.00
0005434344491	11477	Economy	4300.00
0005434142643	11477	Economy	4300.00
0005434344474	11477	Economy	4300.00
0005434344484	11477	Economy	4300.00
0005435305011	11477	Economy	4000.00
0005434344483	11477	Economy	4000.00
0005434344492	11477	Economy	4000.00
0005435305009	11477	Economy	4000.00
0005434344470	11477	Economy	4000.00
0005434344480	11477	Economy	4000.00
0005434344493	11477	Economy	4000.00
0005435302213	11477	Economy	4000.00
0005434344472	11477	Economy	4000.00
0005434344477	11477	Economy	4000.00
0005434344473	11477	Economy	4000.00
0005434344496	11477	Economy	4000.00
0005435302186	11477	Economy	4000.00
0005434344495	11477	Economy	4000.00
0005434344485	11477	Economy	4000.00
0005434344489	11477	Economy	4000.00
0005434344498	11477	Economy	4000.00
0005435305008	11477	Economy	4000.00
0005435302180	11477	Economy	4000.00
0005435302185	11477	Economy	4000.00
0005434142645	11477	Economy	4000.00
0005434142644	11477	Economy	4000.00
0005435305010	11477	Economy	4000.00
0005434344471	11477	Economy	4000.00
0005434344478	11477	Economy	4000.00
0005434344481	11477	Economy	4000.00
0005434344475	11477	Economy	4000.00
0005434344494	11477	Economy	4000.00
0005434344486	11477	Economy	4000.00
0005434344490	11477	Economy	4000.00
0005434344476	11477	Economy	4000.00
0005434344487	11477	Economy	4000.00
0005434344488	11477	Economy	4000.00
0005435302181	11477	Economy	4000.00
0005434344479	11477	Economy	4000.00
0005434344482	11477	Economy	4000.00
0005434344497	11477	Economy	4000.00
0005434343998	29800	Economy	4300.00
0005435304196	29800	Economy	4300.00
0005435304197	29800	Economy	4300.00
0005434344308	29800	Economy	4300.00
0005434344139	29800	Economy	4000.00
0005434344140	29800	Economy	4000.00
0005434344204	29800	Economy	4000.00
0005434142594	29800	Economy	4000.00
0005434344126	29800	Economy	4000.00
0005434344171	29800	Economy	4000.00
0005434344195	29800	Economy	4000.00
0005434344083	29800	Economy	4000.00
0005435304193	29800	Economy	4000.00
0005434344230	29800	Economy	4000.00
0005434344164	29800	Economy	4000.00
0005434344128	29800	Economy	4000.00
0005434344232	29800	Economy	4000.00
0005435305029	29800	Economy	4000.00
0005434344231	29800	Economy	4000.00
0005434344229	29800	Economy	4000.00
0005434344206	29800	Economy	4000.00
0005434344266	29800	Economy	4000.00
0005434344200	29800	Economy	4000.00
0005434344172	29800	Economy	4000.00
0005435304194	29800	Economy	4000.00
0005434344201	29800	Economy	4000.00
0005434344033	29800	Economy	4000.00
0005434344191	29800	Economy	4000.00
0005434343920	29800	Economy	4000.00
0005434344145	29800	Economy	4000.00
0005434344082	29800	Economy	4000.00
0005434344192	29800	Economy	4000.00
0005434344105	29800	Economy	4000.00
0005434344129	29800	Economy	4000.00
0005435305028	29800	Economy	4000.00
0005434344032	29800	Economy	4000.00
0005435305030	29800	Economy	4000.00
0005434344289	29800	Economy	4000.00
0005434344177	29800	Economy	4000.00
0005434344202	29800	Economy	4000.00
0005435304195	29800	Economy	4000.00
0005434344149	29800	Economy	4000.00
0005434344207	29800	Economy	4000.00
0005434344106	29800	Economy	4000.00
0005435305031	29800	Economy	4000.00
0005435824857	1301	Business	199800.00
0005433415661	1301	Business	199800.00
0005435824843	1301	Business	199800.00
0005433415715	1301	Business	199800.00
0005435824853	1301	Business	199800.00
0005433415655	1301	Business	199800.00
0005433415609	1301	Business	199800.00
0005435824842	1301	Business	199800.00
0005435824849	1301	Economy	66600.00
0005435824860	1301	Economy	66600.00
0005435824861	1301	Economy	66600.00
0005433415646	1301	Economy	66600.00
0005433415629	1301	Economy	66600.00
0005435824852	1301	Economy	73200.00
0005433415654	1301	Economy	73200.00
0005433415694	1301	Economy	66600.00
0005435824851	1301	Economy	66600.00
0005435824839	1301	Economy	66600.00
0005435824848	1301	Economy	66600.00
0005433415693	1301	Economy	66600.00
0005435824846	1301	Economy	66600.00
0005432284582	1301	Economy	66600.00
0005433415699	1301	Economy	66600.00
0005435824855	1301	Economy	66600.00
0005433415644	1301	Economy	66600.00
0005435824844	1301	Economy	66600.00
0005433415713	1301	Economy	66600.00
0005435824841	1301	Economy	66600.00
0005435824850	1301	Economy	66600.00
0005435824864	1301	Economy	66600.00
0005433415634	1301	Economy	66600.00
0005435824845	1301	Economy	66600.00
0005433415687	1301	Economy	66600.00
0005432284583	1301	Economy	66600.00
0005435824838	1301	Economy	66600.00
0005435824840	1301	Economy	66600.00
0005435824847	1301	Economy	66600.00
0005435824854	1301	Economy	66600.00
0005433415628	1301	Economy	66600.00
0005433415667	1301	Economy	66600.00
0005435824862	1301	Economy	66600.00
0005435824858	1301	Economy	66600.00
0005435824863	1301	Economy	66600.00
0005435824856	1301	Economy	66600.00
0005435824859	1301	Economy	66600.00
0005433415714	1301	Economy	66600.00
0005433415660	1301	Economy	66600.00
0005432284584	1301	Economy	66600.00
0005433415795	17971	Business	199800.00
0005435824606	17971	Business	199800.00
0005433415796	17971	Business	199800.00
0005435824683	17971	Business	199800.00
0005435824651	17971	Business	199800.00
0005433415800	17971	Economy	66600.00
0005435824628	17971	Economy	66600.00
0005435824541	17971	Economy	66600.00
0005433415792	17971	Economy	66600.00
0005433415787	17971	Economy	66600.00
0005435824626	17971	Economy	73200.00
0005433415788	17971	Economy	73200.00
0005433415799	17971	Economy	73200.00
0005435824518	17971	Economy	66600.00
0005433415786	17971	Economy	66600.00
0005435824690	17971	Economy	66600.00
0005433415794	17971	Economy	66600.00
0005433415793	17971	Economy	66600.00
0005435824575	17971	Economy	66600.00
0005435824592	17971	Economy	66600.00
0005435824752	17971	Economy	66600.00
0005435824696	17971	Economy	66600.00
0005433415797	17971	Economy	66600.00
0005433415789	17971	Economy	66600.00
0005435824560	17971	Economy	66600.00
0005433415790	17971	Economy	66600.00
0005435824629	17971	Economy	66600.00
0005433415791	17971	Economy	66600.00
0005433415801	17971	Economy	66600.00
0005435824750	17971	Economy	66600.00
0005433415798	17971	Economy	66600.00
0005435824591	17971	Economy	66600.00
0005435824574	17971	Economy	66600.00
0005432784253	5663	Business	27800.00
0005435242833	5663	Business	27800.00
0005432784239	5663	Business	27800.00
0005435242778	5663	Business	27800.00
0005432784249	5663	Business	27800.00
0005432784224	5663	Business	27800.00
0005435476737	5663	Business	27800.00
0005432784247	5663	Business	27800.00
0005432784231	5663	Business	27800.00
0005432784270	5663	Business	27800.00
0005432784255	5663	Business	27800.00
0005435242900	5663	Business	27800.00
0005432784223	5663	Economy	9300.00
0005432784236	5663	Economy	9300.00
0005432784246	5663	Economy	9300.00
0005432784222	5663	Economy	9300.00
0005435242842	5663	Economy	9300.00
0005432784234	5663	Economy	9300.00
0005435242893	5663	Economy	9300.00
0005432784229	5663	Economy	9300.00
0005435242791	5663	Economy	9300.00
0005432784250	5663	Economy	9300.00
0005432784262	5663	Economy	10200.00
0005432784233	5663	Economy	10200.00
0005432784237	5663	Economy	10200.00
0005435242834	5663	Economy	10200.00
0005432784238	5663	Economy	10200.00
0005432784265	5663	Economy	9300.00
0005435242773	5663	Economy	9300.00
0005435242895	5663	Economy	9300.00
0005432784268	5663	Economy	9300.00
0005432784248	5663	Economy	9300.00
0005432784266	5663	Economy	9300.00
0005432784235	5663	Economy	9300.00
0005435242820	5663	Economy	9300.00
0005435242782	5663	Economy	9300.00
0005432784252	5663	Economy	9300.00
0005435242931	5663	Economy	9300.00
0005432784259	5663	Economy	9300.00
0005435242822	5663	Economy	9300.00
0005435242779	5663	Economy	9300.00
0005435242824	5663	Economy	9300.00
0005435242836	5663	Economy	9300.00
0005432784230	5663	Economy	9300.00
0005432784267	5663	Economy	9300.00
0005432784244	5663	Economy	9300.00
0005435242843	5663	Economy	9300.00
0005432784256	5663	Economy	9300.00
0005432144014	5663	Economy	9300.00
0005432784269	5663	Economy	9300.00
0005435242756	5663	Economy	9300.00
0005432784254	5663	Economy	9300.00
0005432784264	5663	Economy	9300.00
0005435242792	5663	Economy	9300.00
0005435242959	5663	Economy	9300.00
0005435242789	5663	Economy	9300.00
0005432784228	5663	Economy	9300.00
0005435242899	5663	Economy	9300.00
0005435242977	5663	Economy	9300.00
0005432784226	5663	Economy	9300.00
0005432784221	5663	Economy	9300.00
0005432784258	5663	Economy	9300.00
0005432144016	5663	Economy	9300.00
0005432784240	5663	Economy	9300.00
0005432784260	5663	Economy	9300.00
0005432144013	5663	Economy	9300.00
0005432784243	5663	Economy	9300.00
0005432784251	5663	Economy	9300.00
0005432784227	5663	Economy	9300.00
0005435242835	5663	Economy	9300.00
0005435242781	5663	Economy	9300.00
0005435242790	5663	Economy	9300.00
0005432144015	5663	Economy	9300.00
0005435476728	5663	Economy	9300.00
0005432784241	5663	Economy	9300.00
0005432784218	5663	Economy	9300.00
0005435242932	5663	Economy	9300.00
0005432784232	5663	Economy	9300.00
0005435242844	5663	Economy	9300.00
0005435242772	5663	Economy	9300.00
0005432784217	5663	Economy	9300.00
0005432784263	5663	Economy	9300.00
0005435242978	5663	Economy	9300.00
0005432784220	5663	Economy	9300.00
0005435476729	5663	Economy	9300.00
0005432784219	5663	Economy	9300.00
0005432784257	5663	Economy	9300.00
0005435242823	5663	Economy	9300.00
0005435242766	5663	Economy	9300.00
0005432784242	5663	Economy	9300.00
0005432784245	5663	Economy	9300.00
0005435242765	5663	Economy	9300.00
0005432784225	5663	Economy	9300.00
0005432784261	5663	Economy	9300.00
0005432783721	15376	Business	27800.00
0005435243049	15376	Business	27800.00
0005432783775	15376	Business	27800.00
0005435476821	15376	Business	27800.00
0005432783542	15376	Business	27800.00
0005435243061	15376	Business	27800.00
0005435476819	15376	Business	27800.00
0005432783764	15376	Business	27800.00
0005435243050	15376	Business	27800.00
0005435476813	15376	Business	27800.00
0005432783868	15376	Business	27800.00
0005432783587	15376	Business	27800.00
0005432783998	15376	Economy	9300.00
0005432783708	15376	Economy	9300.00
0005432783781	15376	Economy	9300.00
0005435476814	15376	Economy	9300.00
0005435243056	15376	Economy	9300.00
0005435243067	15376	Economy	9300.00
0005432783501	15376	Economy	9300.00
0005435243072	15376	Economy	9300.00
0005432783620	15376	Economy	9300.00
0005432783549	15376	Economy	10200.00
0005432783826	15376	Economy	10200.00
0005432783859	15376	Economy	10200.00
0005432783514	15376	Economy	10200.00
0005432783664	15376	Economy	10200.00
0005435243051	15376	Economy	9300.00
0005435243062	15376	Economy	9300.00
0005435243066	15376	Economy	9300.00
0005435243057	15376	Economy	9300.00
0005432783430	15376	Economy	9300.00
0005432783801	15376	Economy	9300.00
0005435243055	15376	Economy	9300.00
0005432783659	15376	Economy	9300.00
0005432783755	15376	Economy	9300.00
0005432783644	15376	Economy	9300.00
0005435243073	15376	Economy	9300.00
0005435243065	15376	Economy	9300.00
0005432783761	15376	Economy	9300.00
0005435243046	15376	Economy	9300.00
0005432783662	15376	Economy	9300.00
0005432783852	15376	Economy	9300.00
0005432783997	15376	Economy	9300.00
0005432783858	15376	Economy	9300.00
0005432783680	15376	Economy	9300.00
0005432783447	15376	Economy	9300.00
0005432783691	15376	Economy	9300.00
0005432783957	15376	Economy	9300.00
0005435476818	15376	Economy	9300.00
0005435243071	15376	Economy	9300.00
0005435243059	15376	Economy	9300.00
0005435243068	15376	Economy	9300.00
0005435243058	15376	Economy	9300.00
0005432783835	15376	Economy	9300.00
0005432783724	15376	Economy	9300.00
0005432783857	15376	Economy	9300.00
0005435243069	15376	Economy	9300.00
0005432783756	15376	Economy	9300.00
0005432783847	15376	Economy	9300.00
0005435476816	15376	Economy	9300.00
0005432783851	15376	Economy	9300.00
0005432783723	15376	Economy	9300.00
0005435243047	15376	Economy	9300.00
0005435243054	15376	Economy	9300.00
0005432783617	15376	Economy	9300.00
0005435476820	15376	Economy	9300.00
0005432783654	15376	Economy	9300.00
0005432783867	15376	Economy	9300.00
0005435243070	15376	Economy	9300.00
0005435243064	15376	Economy	9300.00
0005435243053	15376	Economy	9300.00
0005435243063	15376	Economy	9300.00
0005432783653	15376	Economy	9300.00
0005435243052	15376	Economy	9300.00
0005432783429	15376	Economy	9300.00
0005435476815	15376	Economy	9300.00
0005432783746	15376	Economy	9300.00
0005432783588	15376	Economy	9300.00
0005432783774	15376	Economy	9300.00
0005432783645	15376	Economy	9300.00
0005432783616	15376	Economy	9300.00
0005432783861	15376	Economy	9300.00
0005435243048	15376	Economy	9300.00
0005435243060	15376	Economy	9300.00
0005435476817	15376	Economy	9300.00
0005432783827	15376	Economy	9300.00
0005432783707	15376	Economy	9300.00
0005432783663	15376	Economy	9300.00
0005432783378	15376	Economy	9300.00
0005432783877	15376	Economy	9300.00
0005432783661	15376	Economy	9300.00
0005432783842	15376	Economy	9300.00
0005432848433	4375	Economy	7000.00
0005432848427	4375	Economy	6300.00
0005432848426	4375	Economy	6300.00
0005432848439	4375	Economy	6300.00
0005432848434	4375	Economy	6300.00
0005435850907	4375	Economy	6300.00
0005432848441	4375	Economy	6300.00
0005432848437	4375	Economy	6300.00
0005432848431	4375	Economy	6300.00
0005432848435	4375	Economy	6300.00
0005435850908	4375	Economy	6300.00
0005432848438	4375	Economy	6300.00
0005434463946	4375	Economy	6300.00
0005432848436	4375	Economy	6300.00
0005434463948	4375	Economy	6300.00
0005432848432	4375	Economy	6300.00
0005435850920	4375	Economy	6300.00
0005432848428	4375	Economy	6300.00
0005432848430	4375	Economy	6300.00
0005432848429	4375	Economy	6300.00
0005432848440	4375	Economy	6300.00
0005434463947	4375	Economy	6300.00
0005432848237	28887	Economy	7000.00
0005434463919	28887	Economy	7000.00
0005432848294	28887	Economy	7000.00
0005434463928	28887	Economy	6300.00
0005435850990	28887	Economy	6300.00
0005432848276	28887	Economy	6300.00
0005434461638	28887	Economy	6300.00
0005435850988	28887	Economy	6300.00
0005434461649	28887	Economy	6300.00
0005432848300	28887	Economy	6300.00
0005435850984	28887	Economy	6300.00
0005432848296	28887	Economy	6300.00
0005432848385	28887	Economy	6300.00
0005434461642	28887	Economy	6300.00
0005432848325	28887	Economy	6300.00
0005432848307	28887	Economy	6300.00
0005432848334	28887	Economy	6300.00
0005435850989	28887	Economy	6300.00
0005434461648	28887	Economy	6300.00
0005432848336	28887	Economy	6300.00
0005434461643	28887	Economy	6300.00
0005435850987	28887	Economy	6300.00
0005434463918	28887	Economy	6300.00
0005432848323	28887	Economy	6300.00
0005432848345	28887	Economy	6300.00
0005435850986	28887	Economy	6300.00
0005432848249	28887	Economy	6300.00
0005432848250	28887	Economy	6300.00
0005434461644	28887	Economy	6300.00
0005432848346	28887	Economy	6300.00
0005434463927	28887	Economy	6300.00
0005432848248	28887	Economy	6300.00
0005432848309	28887	Economy	6300.00
0005432848306	28887	Economy	6300.00
0005432848293	28887	Economy	6300.00
0005435850985	28887	Economy	6300.00
0005432848270	28887	Economy	6300.00
0005432848335	28887	Economy	6300.00
0005435850983	28887	Economy	6300.00
0005435850982	28887	Economy	6300.00
0005432848269	28887	Economy	6300.00
0005432848295	28887	Economy	6300.00
0005432075261	6347	Business	11900.00
0005433497247	6347	Business	11900.00
0005434443839	6347	Business	11900.00
0005434926081	6347	Business	11900.00
0005434443847	6347	Business	11900.00
0005433497236	6347	Business	11900.00
0005434443844	6347	Business	11900.00
0005434926089	6347	Business	11900.00
0005434443852	6347	Business	11900.00
0005433497222	6347	Business	11900.00
0005434443838	6347	Business	11900.00
0005434926064	6347	Economy	4000.00
0005434926075	6347	Economy	4000.00
0005434926067	6347	Economy	4000.00
0005432075260	6347	Economy	4000.00
0005433497240	6347	Economy	4000.00
0005434926084	6347	Economy	4000.00
0005432075259	6347	Economy	4000.00
0005433497234	6347	Economy	4000.00
0005434443837	6347	Economy	4400.00
0005434443846	6347	Economy	4400.00
0005433497218	6347	Economy	4400.00
0005433497225	6347	Economy	4400.00
0005433497228	6347	Economy	4000.00
0005434926087	6347	Economy	4000.00
0005433497232	6347	Economy	4000.00
0005434926090	6347	Economy	4000.00
0005434926093	6347	Economy	4000.00
0005434926070	6347	Economy	4000.00
0005433497246	6347	Economy	4000.00
0005434926062	6347	Economy	4000.00
0005434926073	6347	Economy	4000.00
0005434926095	6347	Economy	4000.00
0005434926065	6347	Economy	4000.00
0005434926069	6347	Economy	4000.00
0005432075258	6347	Economy	4000.00
0005434926071	6347	Economy	4000.00
0005434926079	6347	Economy	4000.00
0005434926078	6347	Economy	4000.00
0005433497239	6347	Economy	4000.00
0005434926061	6347	Economy	4000.00
0005433497249	6347	Economy	4000.00
0005434926068	6347	Economy	4000.00
0005433497227	6347	Economy	4000.00
0005434926063	6347	Economy	4000.00
0005434926097	6347	Economy	4000.00
0005433497233	6347	Economy	4000.00
0005434443848	6347	Economy	4000.00
0005434443842	6347	Economy	4000.00
0005434443843	6347	Economy	4000.00
0005433497241	6347	Economy	4000.00
0005433497226	6347	Economy	4000.00
0005433497235	6347	Economy	4000.00
0005434926086	6347	Economy	4000.00
0005434443840	6347	Economy	4000.00
0005433497237	6347	Economy	4000.00
0005434926077	6347	Economy	4000.00
0005434926066	6347	Economy	4000.00
0005434926076	6347	Economy	4000.00
0005434926074	6347	Economy	4000.00
0005434926080	6347	Economy	4000.00
0005434926088	6347	Economy	4000.00
0005433497220	6347	Economy	4000.00
0005433497242	6347	Economy	4000.00
0005434443849	6347	Economy	4000.00
0005434926092	6347	Economy	4000.00
0005433497231	6347	Economy	4000.00
0005433497248	6347	Economy	4000.00
0005433497221	6347	Economy	4000.00
0005434443850	6347	Economy	4000.00
0005433497219	6347	Economy	4000.00
0005434926091	6347	Economy	4000.00
0005434443841	6347	Economy	4000.00
0005434443845	6347	Economy	4000.00
0005434443853	6347	Economy	4000.00
0005433497224	6347	Economy	4000.00
0005433497243	6347	Economy	4000.00
0005434926096	6347	Economy	4000.00
0005434926082	6347	Economy	4000.00
0005433497230	6347	Economy	4000.00
0005434926060	6347	Economy	4000.00
0005434926094	6347	Economy	4000.00
0005434926083	6347	Economy	4000.00
0005434926085	6347	Economy	4000.00
0005434926072	6347	Economy	4000.00
0005433497223	6347	Economy	4000.00
0005433497245	6347	Economy	4000.00
0005433497229	6347	Economy	4000.00
0005433497238	6347	Economy	4000.00
0005433497244	6347	Economy	4000.00
0005434443851	6347	Economy	4000.00
0005433496865	20390	Business	11900.00
0005433497132	20390	Business	11900.00
0005433496958	20390	Business	11900.00
0005433497113	20390	Business	11900.00
0005434925609	20390	Business	11900.00
0005433496855	20390	Business	11900.00
0005434925715	20390	Business	11900.00
0005434925708	20390	Business	11900.00
0005433496933	20390	Business	11900.00
0005434443704	20390	Business	11900.00
0005434925688	20390	Business	11900.00
0005433497145	20390	Business	11900.00
0005434443738	20390	Economy	4000.00
0005433497045	20390	Economy	4000.00
0005434925695	20390	Economy	4000.00
0005433496907	20390	Economy	4000.00
0005434443672	20390	Economy	4000.00
0005433496971	20390	Economy	4000.00
0005434925669	20390	Economy	4000.00
0005433496906	20390	Economy	4000.00
0005434443688	20390	Economy	4000.00
0005434443770	20390	Economy	4000.00
0005434443680	20390	Economy	4400.00
0005434443737	20390	Economy	4400.00
0005434925668	20390	Economy	4400.00
0005434443739	20390	Economy	4400.00
0005433496839	20390	Economy	4400.00
0005434925698	20390	Economy	4000.00
0005433497054	20390	Economy	4000.00
0005433497038	20390	Economy	4000.00
0005433496820	20390	Economy	4000.00
0005434925690	20390	Economy	4000.00
0005433496926	20390	Economy	4000.00
0005433497060	20390	Economy	4000.00
0005433496934	20390	Economy	4000.00
0005434443670	20390	Economy	4000.00
0005433497109	20390	Economy	4000.00
0005434925714	20390	Economy	4000.00
0005433496975	20390	Economy	4000.00
0005433496840	20390	Economy	4000.00
0005433496908	20390	Economy	4000.00
0005433497072	20390	Economy	4000.00
0005434443759	20390	Economy	4000.00
0005434925709	20390	Economy	4000.00
0005434925610	20390	Economy	4000.00
0005433497019	20390	Economy	4000.00
0005434443695	20390	Economy	4000.00
0005434925711	20390	Economy	4000.00
0005433497037	20390	Economy	4000.00
0005433497013	20390	Economy	4000.00
0005433496957	20390	Economy	4000.00
0005433496994	20390	Economy	4000.00
0005433497012	20390	Economy	4000.00
0005433497029	20390	Economy	4000.00
0005433497110	20390	Economy	4000.00
0005434443638	20390	Economy	4000.00
0005434443673	20390	Economy	4000.00
0005434925697	20390	Economy	4000.00
0005433496972	20390	Economy	4000.00
0005434443705	20390	Economy	4000.00
0005433497111	20390	Economy	4000.00
0005434925607	20390	Economy	4000.00
0005433497131	20390	Economy	4000.00
0005433497017	20390	Economy	4000.00
0005433496932	20390	Economy	4000.00
0005434925696	20390	Economy	4000.00
0005433496841	20390	Economy	4000.00
0005434443696	20390	Economy	4000.00
0005433496931	20390	Economy	4000.00
0005434443697	20390	Economy	4000.00
0005433497071	20390	Economy	4000.00
0005433497024	20390	Economy	4000.00
0005434443703	20390	Economy	4000.00
0005434443681	20390	Economy	4000.00
0005434443724	20390	Economy	4000.00
0005433496910	20390	Economy	4000.00
0005433496953	20390	Economy	4000.00
0005433496935	20390	Economy	4000.00
0005433496869	20390	Economy	4000.00
0005433496927	20390	Economy	4000.00
0005433496856	20390	Economy	4000.00
0005433497027	20390	Economy	4000.00
0005434925689	20390	Economy	4000.00
0005434443713	20390	Economy	4000.00
0005433496991	20390	Economy	4000.00
0005434443717	20390	Economy	4000.00
0005434443714	20390	Economy	4000.00
0005434443698	20390	Economy	4000.00
0005433496821	20390	Economy	4000.00
0005434443723	20390	Economy	4000.00
0005433497028	20390	Economy	4000.00
0005433496973	20390	Economy	4000.00
0005435243090	12208	Business	41200.00
0005432783765	12208	Business	41200.00
0005432783598	12208	Business	41200.00
0005432783769	12208	Business	41200.00
0005432783811	12208	Business	41200.00
0005432783751	12208	Business	41200.00
0005432783806	12208	Business	41200.00
0005432783712	12208	Business	41200.00
0005435243095	12208	Business	41200.00
0005432783799	12208	Business	41200.00
0005432783812	12208	Economy	13700.00
0005432783843	12208	Economy	13700.00
0005435243091	12208	Economy	13700.00
0005432783564	12208	Economy	13700.00
0005432783689	12208	Economy	13700.00
0005435243097	12208	Economy	13700.00
0005432783563	12208	Economy	15100.00
0005432783883	12208	Economy	15100.00
0005432783939	12208	Economy	15100.00
0005435243084	12208	Economy	15100.00
0005432783631	12208	Economy	15100.00
0005435243074	12208	Economy	13700.00
0005432783743	12208	Economy	13700.00
0005432783891	12208	Economy	13700.00
0005432783819	12208	Economy	13700.00
0005432783688	12208	Economy	13700.00
0005432783785	12208	Economy	13700.00
0005432783750	12208	Economy	13700.00
0005435243093	12208	Economy	13700.00
0005435243075	12208	Economy	13700.00
0005435243079	12208	Economy	13700.00
0005435243082	12208	Economy	13700.00
0005435243080	12208	Economy	13700.00
0005435243100	12208	Economy	13700.00
0005432784041	12208	Economy	13700.00
0005432783647	12208	Economy	13700.00
0005432784012	12208	Economy	13700.00
0005432783807	12208	Economy	13700.00
0005435243101	12208	Economy	13700.00
0005432784042	12208	Economy	13700.00
0005432783599	12208	Economy	13700.00
0005432783744	12208	Economy	13700.00
0005435243081	12208	Economy	13700.00
0005432783938	12208	Economy	13700.00
0005432783879	12208	Economy	13700.00
0005432783876	12208	Economy	13700.00
0005432783892	12208	Economy	13700.00
0005432783603	12208	Economy	13700.00
0005435243077	12208	Economy	13700.00
0005432783916	12208	Economy	13700.00
0005435243094	12208	Economy	13700.00
0005435243096	12208	Economy	13700.00
0005432784011	12208	Economy	13700.00
0005432784051	12208	Economy	13700.00
0005432783745	12208	Economy	13700.00
0005435243092	12208	Economy	13700.00
0005435243078	12208	Economy	13700.00
0005432783881	12208	Economy	13700.00
0005435243102	12208	Economy	13700.00
0005435243088	12208	Economy	13700.00
0005432784050	12208	Economy	13700.00
0005435243085	12208	Economy	13700.00
0005432783820	12208	Economy	13700.00
0005432783882	12208	Economy	13700.00
0005435243098	12208	Economy	13700.00
0005432783699	12208	Economy	13700.00
0005435243099	12208	Economy	13700.00
0005432783597	12208	Economy	13700.00
0005432783768	12208	Economy	13700.00
0005435243083	12208	Economy	13700.00
0005432783734	12208	Economy	13700.00
0005432783875	12208	Economy	13700.00
0005432783684	12208	Economy	13700.00
0005435243076	12208	Economy	13700.00
0005435243087	12208	Economy	13700.00
0005435243086	12208	Economy	13700.00
0005432783921	12208	Economy	13700.00
0005432783872	12208	Economy	13700.00
0005432783788	12208	Economy	13700.00
0005435243089	12208	Economy	13700.00
0005432783711	12208	Economy	13700.00
0005432783729	12208	Economy	13700.00
0005432783800	12208	Economy	13700.00
0005435242830	15435	Business	41200.00
0005432784195	15435	Business	41200.00
0005435242695	15435	Business	41200.00
0005435242540	15435	Business	41200.00
0005432784182	15435	Business	41200.00
0005435242839	15435	Business	41200.00
0005435242845	15435	Business	41200.00
0005432784206	15435	Business	41200.00
0005432784194	15435	Business	41200.00
0005435242877	15435	Business	41200.00
0005432784207	15435	Business	41200.00
0005435242696	15435	Business	41200.00
0005432784209	15435	Economy	13700.00
0005432784172	15435	Economy	13700.00
0005432784188	15435	Economy	13700.00
0005432784185	15435	Economy	13700.00
0005432784165	15435	Economy	13700.00
0005435242874	15435	Economy	13700.00
0005432784202	15435	Economy	13700.00
0005435242811	15435	Economy	13700.00
0005435242815	15435	Economy	13700.00
0005432784204	15435	Economy	15100.00
0005432784170	15435	Economy	15100.00
0005432784169	15435	Economy	15100.00
0005435242759	15435	Economy	15100.00
0005432784175	15435	Economy	13700.00
0005435242809	15435	Economy	13700.00
0005432784177	15435	Economy	13700.00
0005435242747	15435	Economy	13700.00
0005432784166	15435	Economy	13700.00
0005432784171	15435	Economy	13700.00
0005432784193	15435	Economy	13700.00
0005432784164	15435	Economy	13700.00
0005432784180	15435	Economy	13700.00
0005432784192	15435	Economy	13700.00
0005435242871	15435	Economy	13700.00
0005432784178	15435	Economy	13700.00
0005432784198	15435	Economy	13700.00
0005435242775	15435	Economy	13700.00
0005432784163	15435	Economy	13700.00
0005432784215	15435	Economy	13700.00
0005432784187	15435	Economy	13700.00
0005432784184	15435	Economy	13700.00
0005432784167	15435	Economy	13700.00
0005432784168	15435	Economy	13700.00
0005432784190	15435	Economy	13700.00
0005432784191	15435	Economy	13700.00
0005435242750	15435	Economy	13700.00
0005435242829	15435	Economy	13700.00
0005432784189	15435	Economy	13700.00
0005432784216	15435	Economy	13700.00
0005432784214	15435	Economy	13700.00
0005432784160	15435	Economy	13700.00
0005435242763	15435	Economy	13700.00
0005435242801	15435	Economy	13700.00
0005432784179	15435	Economy	13700.00
0005432784174	15435	Economy	13700.00
0005432784196	15435	Economy	13700.00
0005432784197	15435	Economy	13700.00
0005432784205	15435	Economy	13700.00
0005435242691	15435	Economy	13700.00
0005435242875	15435	Economy	13700.00
0005432784200	15435	Economy	13700.00
0005432784161	15435	Economy	13700.00
0005432784181	15435	Economy	13700.00
0005432784176	15435	Economy	13700.00
0005435242846	15435	Economy	13700.00
0005435242837	15435	Economy	13700.00
0005432784208	15435	Economy	13700.00
0005432784199	15435	Economy	13700.00
0005435242717	15435	Economy	13700.00
0005432784212	15435	Economy	13700.00
0005432784213	15435	Economy	13700.00
0005435242810	15435	Economy	13700.00
0005432784210	15435	Economy	13700.00
0005432784162	15435	Economy	13700.00
0005432784186	15435	Economy	13700.00
0005432784173	15435	Economy	13700.00
0005435242838	15435	Economy	13700.00
0005435242774	15435	Economy	13700.00
0005435242851	15435	Economy	13700.00
0005435242825	15435	Economy	13700.00
0005435242637	15435	Economy	13700.00
0005432784201	15435	Economy	13700.00
0005432784211	15435	Economy	13700.00
0005432784183	15435	Economy	13700.00
0005435242872	15435	Economy	13700.00
0005432784203	15435	Economy	13700.00
0005434877807	10063	Business	49700.00
0005434878343	10063	Business	49700.00
0005434878473	10063	Business	49700.00
0005434878291	10063	Business	49700.00
0005434878416	10063	Business	49700.00
0005434878147	10063	Business	49700.00
0005434878278	10063	Business	49700.00
0005434878100	10063	Business	49700.00
0005434878350	10063	Business	49700.00
0005434877752	10063	Business	49700.00
0005434878188	10063	Business	49700.00
0005434878074	10063	Business	49700.00
0005434878472	10063	Business	49700.00
0005434878054	10063	Business	49700.00
0005435913961	10063	Business	49700.00
0005434878351	10063	Economy	16600.00
0005434878092	10063	Economy	16600.00
0005434878032	10063	Economy	16600.00
0005434877818	10063	Economy	16600.00
0005435913955	10063	Economy	16600.00
0005434878304	10063	Economy	16600.00
0005434878008	10063	Economy	16600.00
0005434878201	10063	Economy	16600.00
0005434878240	10063	Economy	16600.00
0005434878661	10063	Economy	18200.00
0005434878346	10063	Economy	18200.00
0005434878486	10063	Economy	18200.00
0005434878218	10063	Economy	16600.00
0005434878301	10063	Economy	16600.00
0005434878012	10063	Economy	16600.00
0005435913958	10063	Economy	16600.00
0005434878079	10063	Economy	16600.00
0005434878261	10063	Economy	16600.00
0005434878650	10063	Economy	16600.00
0005434877952	10063	Economy	16600.00
0005434878270	10063	Economy	16600.00
0005434878469	10063	Economy	16600.00
0005435913960	10063	Economy	16600.00
0005434878207	10063	Economy	16600.00
0005434877898	10063	Economy	16600.00
0005434878200	10063	Economy	16600.00
0005434910132	10063	Economy	16600.00
0005434878216	10063	Economy	16600.00
0005434877699	10063	Economy	16600.00
0005434878080	10063	Economy	16600.00
0005434878492	10063	Economy	16600.00
0005435913957	10063	Economy	16600.00
0005434878402	10063	Economy	16600.00
0005434878620	10063	Economy	16600.00
0005434758886	10063	Economy	16600.00
0005434910134	10063	Economy	16600.00
0005434878647	10063	Economy	16600.00
0005434878380	10063	Economy	16600.00
0005434878031	10063	Economy	16600.00
0005434878073	10063	Economy	16600.00
0005434758873	10063	Economy	16600.00
0005434878123	10063	Economy	16600.00
0005434878410	10063	Economy	16600.00
0005434878452	10063	Economy	16600.00
0005434878379	10063	Economy	16600.00
0005434878371	10063	Economy	16600.00
0005434877866	10063	Economy	16600.00
0005434877753	10063	Economy	16600.00
0005434878269	10063	Economy	16600.00
0005434910133	10063	Economy	16600.00
0005434878212	10063	Economy	16600.00
0005434878245	10063	Economy	16600.00
0005434877995	10063	Economy	16600.00
0005434878352	10063	Economy	16600.00
0005434878217	10063	Economy	16600.00
0005434877806	10063	Economy	16600.00
0005434878293	10063	Economy	16600.00
0005434877817	10063	Economy	16600.00
0005434878331	10063	Economy	16600.00
0005434877880	10063	Economy	16600.00
0005434877901	10063	Economy	16600.00
0005434878284	10063	Economy	16600.00
0005434878471	10063	Economy	16600.00
0005435913956	10063	Economy	16600.00
0005434878262	10063	Economy	16600.00
0005434878168	10063	Economy	16600.00
0005434878646	10063	Economy	16600.00
0005434878187	10063	Economy	16600.00
0005434878164	10063	Economy	16600.00
0005434878110	10063	Economy	16600.00
0005435913959	10063	Economy	16600.00
0005434878224	10063	Economy	16600.00
0005434878128	10063	Economy	16600.00
0005434910135	10063	Economy	16600.00
0005434878049	10063	Economy	16600.00
0005434878048	10063	Economy	16600.00
0005434879054	14595	Business	49700.00
0005434879017	14595	Business	49700.00
0005434878994	14595	Business	49700.00
0005434879038	14595	Business	49700.00
0005434879031	14595	Business	49700.00
0005434879016	14595	Business	49700.00
0005434879048	14595	Business	49700.00
0005434879043	14595	Business	49700.00
0005434879047	14595	Business	49700.00
0005434878993	14595	Business	49700.00
0005434878997	14595	Business	49700.00
0005435913922	14595	Business	49700.00
0005435913923	14595	Business	49700.00
0005434879007	14595	Business	49700.00
0005434878989	14595	Business	49700.00
0005434879010	14595	Business	49700.00
0005434879024	14595	Business	49700.00
0005434879001	14595	Economy	16600.00
0005434879053	14595	Business	49700.00
0005434879050	14595	Economy	16600.00
0005434878958	14595	Economy	16600.00
0005434878977	14595	Economy	16600.00
0005434878968	14595	Economy	16600.00
0005434878966	14595	Economy	16600.00
0005434879006	14595	Economy	16600.00
0005434878981	14595	Economy	16600.00
0005434879000	14595	Economy	16600.00
0005434878990	14595	Economy	16600.00
0005434878965	14595	Economy	16600.00
0005434910110	14595	Economy	16600.00
0005434879026	14595	Economy	18200.00
0005435913929	14595	Economy	18200.00
0005434879049	14595	Economy	18200.00
0005434879021	14595	Economy	16600.00
0005434878970	14595	Economy	16600.00
0005434879005	14595	Economy	16600.00
0005434879051	14595	Economy	16600.00
0005434910111	14595	Economy	16600.00
0005434879041	14595	Economy	16600.00
0005434878972	14595	Economy	16600.00
0005434910097	14595	Economy	16600.00
0005434879013	14595	Economy	16600.00
0005434879034	14595	Economy	16600.00
0005434878996	14595	Economy	16600.00
0005434878991	14595	Economy	16600.00
0005434879019	14595	Economy	16600.00
0005434879025	14595	Economy	16600.00
0005434878984	14595	Economy	16600.00
0005434879046	14595	Economy	16600.00
0005434878979	14595	Economy	16600.00
0005434878988	14595	Economy	16600.00
0005434879023	14595	Economy	16600.00
0005434879040	14595	Economy	16600.00
0005434879044	14595	Economy	16600.00
0005435913924	14595	Economy	16600.00
0005434879042	14595	Economy	16600.00
0005434878998	14595	Economy	16600.00
0005434879029	14595	Economy	16600.00
0005434879011	14595	Economy	16600.00
0005434879015	14595	Economy	16600.00
0005434878983	14595	Economy	16600.00
0005434879039	14595	Economy	16600.00
0005434879020	14595	Economy	16600.00
0005434878967	14595	Economy	16600.00
0005434878959	14595	Economy	16600.00
0005434879003	14595	Economy	16600.00
0005434910098	14595	Economy	16600.00
0005434879008	14595	Economy	16600.00
0005434878969	14595	Economy	16600.00
0005434879002	14595	Economy	16600.00
0005434878963	14595	Economy	16600.00
0005434878962	14595	Economy	16600.00
0005434879033	14595	Economy	16600.00
0005434879027	14595	Economy	16600.00
0005434910109	14595	Economy	16600.00
0005434878961	14595	Economy	16600.00
0005434878985	14595	Economy	16600.00
0005434878971	14595	Economy	16600.00
0005434879018	14595	Economy	16600.00
0005434879052	14595	Economy	16600.00
0005434879037	14595	Economy	16600.00
0005434878999	14595	Economy	16600.00
0005434879035	14595	Economy	16600.00
0005434878974	14595	Economy	16600.00
0005434878960	14595	Economy	16600.00
0005434879012	14595	Economy	16600.00
0005434878982	14595	Economy	16600.00
0005434878973	14595	Economy	16600.00
0005434879009	14595	Economy	16600.00
0005434878976	14595	Economy	16600.00
0005434879030	14595	Economy	16600.00
0005434878978	14595	Economy	16600.00
0005434879028	14595	Economy	16600.00
0005434879014	14595	Economy	16600.00
0005434878980	14595	Economy	16600.00
0005434878986	14595	Economy	16600.00
0005434878964	14595	Economy	16600.00
0005434879036	14595	Economy	16600.00
0005434758913	14595	Economy	16600.00
0005434878995	14595	Economy	16600.00
0005434879045	14595	Economy	16600.00
0005434758912	14595	Economy	16600.00
0005434879032	14595	Economy	16600.00
0005434879004	14595	Economy	16600.00
0005434879022	14595	Economy	16600.00
0005434878992	14595	Economy	16600.00
0005434878987	14595	Economy	16600.00
0005434878975	14595	Economy	16600.00
0005435660225	9231	Economy	20300.00
0005435660231	9231	Economy	20300.00
0005435660235	9231	Economy	20300.00
0005434251975	9231	Economy	20300.00
0005434251983	9231	Economy	20300.00
0005434251934	9231	Economy	20300.00
0005435660234	9231	Economy	20300.00
0005434251877	9231	Economy	20300.00
0005434251926	9231	Economy	20300.00
0005435660229	9231	Economy	20300.00
0005435660233	9231	Economy	20300.00
0005435660228	9231	Economy	20300.00
0005434251974	9231	Economy	20300.00
0005434251984	9231	Economy	20300.00
0005435660226	9231	Economy	20300.00
0005435660230	9231	Economy	20300.00
0005435660232	9231	Economy	20300.00
0005434251985	9231	Economy	20300.00
0005435660227	9231	Economy	20300.00
0005435660132	24660	Economy	22400.00
0005435660107	24660	Economy	22400.00
0005435660131	24660	Economy	22400.00
0005435660115	24660	Economy	20300.00
0005434252038	24660	Economy	20300.00
0005435660171	24660	Economy	20300.00
0005435660156	24660	Economy	20300.00
0005435660147	24660	Economy	20300.00
0005435660112	24660	Economy	20300.00
0005435660129	24660	Economy	20300.00
0005435660170	24660	Economy	20300.00
0005434252044	24660	Economy	20300.00
0005434252046	24660	Economy	20300.00
0005435660106	24660	Economy	20300.00
0005435660111	24660	Economy	20300.00
0005435660119	24660	Economy	20300.00
0005434252045	24660	Economy	20300.00
0005435660139	24660	Economy	20300.00
0005434252042	24660	Economy	20300.00
0005435660113	24660	Economy	20300.00
0005434252041	24660	Economy	20300.00
0005434252047	24660	Economy	20300.00
0005435660177	24660	Economy	20300.00
0005434252040	24660	Economy	20300.00
0005434252043	24660	Economy	20300.00
0005434252039	24660	Economy	20300.00
0005435660114	24660	Economy	20300.00
0005435660118	24660	Economy	20300.00
0005435660120	24660	Economy	20300.00
0005433684438	2784	Business	33000.00
0005432222826	2784	Business	33000.00
0005433680963	2784	Business	33000.00
0005433680943	2784	Business	33000.00
0005432966931	2784	Business	33000.00
0005433680933	2784	Business	33000.00
0005433680941	2784	Business	33000.00
0005432966988	2784	Business	33000.00
0005432966760	2784	Business	33000.00
0005433680936	2784	Business	33000.00
0005433680962	2784	Business	33000.00
0005433680977	2784	Economy	11000.00
0005432966870	2784	Economy	11000.00
0005433680969	2784	Economy	11000.00
0005433680964	2784	Economy	11000.00
0005432966966	2784	Economy	11000.00
0005433680955	2784	Economy	11000.00
0005433680939	2784	Economy	11000.00
0005432966921	2784	Economy	11000.00
0005433680952	2784	Economy	11000.00
0005432966825	2784	Economy	12100.00
0005433680956	2784	Economy	12100.00
0005432966854	2784	Economy	12100.00
0005433680944	2784	Economy	12100.00
0005433684435	2784	Economy	12100.00
0005433680965	2784	Economy	11000.00
0005432966908	2784	Economy	11000.00
0005432966855	2784	Economy	11000.00
0005432966887	2784	Economy	11000.00
0005433680934	2784	Economy	11000.00
0005433680948	2784	Economy	11000.00
0005432966968	2784	Economy	11000.00
0005432966805	2784	Economy	11000.00
0005433680951	2784	Economy	11000.00
0005432966889	2784	Economy	11000.00
0005433680950	2784	Economy	11000.00
0005432966984	2784	Economy	11000.00
0005432966824	2784	Economy	11000.00
0005432966965	2784	Economy	11000.00
0005433680960	2784	Economy	11000.00
0005433680972	2784	Economy	11000.00
0005433680971	2784	Economy	11000.00
0005433680974	2784	Economy	11000.00
0005433680970	2784	Economy	11000.00
0005432966826	2784	Economy	11000.00
0005433680953	2784	Economy	11000.00
0005433680949	2784	Economy	11000.00
0005432222824	2784	Economy	11000.00
0005433680967	2784	Economy	11000.00
0005433680959	2784	Economy	11000.00
0005433680942	2784	Economy	11000.00
0005433680975	2784	Economy	11000.00
0005433684437	2784	Economy	11000.00
0005433680947	2784	Economy	11000.00
0005432966872	2784	Economy	11000.00
0005433680968	2784	Economy	11000.00
0005432966941	2784	Economy	11000.00
0005432966759	2784	Economy	11000.00
0005433684436	2784	Economy	11000.00
0005433680940	2784	Economy	11000.00
0005432966989	2784	Economy	11000.00
0005432222827	2784	Economy	11000.00
0005433680961	2784	Economy	11000.00
0005432966983	2784	Economy	11000.00
0005433680938	2784	Economy	11000.00
0005433680946	2784	Economy	11000.00
0005433680935	2784	Economy	11000.00
0005433680945	2784	Economy	11000.00
0005432966869	2784	Economy	11000.00
0005433680958	2784	Economy	11000.00
0005432966996	2784	Economy	11000.00
0005433680937	2784	Economy	11000.00
0005433680957	2784	Economy	11000.00
0005432966993	2784	Economy	11000.00
0005432966873	2784	Economy	11000.00
0005432967079	2784	Economy	11000.00
0005433680973	2784	Economy	11000.00
0005432966888	2784	Economy	11000.00
0005432222825	2784	Economy	11000.00
0005432966942	2784	Economy	11000.00
0005433680966	2784	Economy	11000.00
0005433680979	2784	Economy	11000.00
0005432966985	2784	Economy	11000.00
0005433680978	2784	Economy	11000.00
0005433680954	2784	Economy	11000.00
0005432222823	2784	Economy	11000.00
0005433680976	2784	Economy	11000.00
0005432966868	2784	Economy	11000.00
0005433680590	29177	Business	33000.00
0005432967138	29177	Business	33000.00
0005432005238	29177	Business	33000.00
0005433680336	29177	Business	33000.00
0005433684423	29177	Business	33000.00
0005433680557	29177	Business	33000.00
0005433680479	29177	Business	33000.00
0005433680480	29177	Business	33000.00
0005432967156	29177	Business	33000.00
0005433680539	29177	Business	33000.00
0005432967153	29177	Business	33000.00
0005433680680	29177	Economy	11000.00
0005433684419	29177	Economy	11000.00
0005433680345	29177	Economy	11000.00
0005433680670	29177	Economy	11000.00
0005433680605	29177	Economy	11000.00
0005433680396	29177	Economy	11000.00
0005433684415	29177	Economy	11000.00
0005433680699	29177	Economy	11000.00
0005432967140	29177	Economy	12100.00
0005433680650	29177	Economy	12100.00
0005432967142	29177	Economy	12100.00
0005432967154	29177	Economy	12100.00
0005433680576	29177	Economy	12100.00
0005433680600	29177	Economy	11000.00
0005433680483	29177	Economy	11000.00
0005433680591	29177	Economy	11000.00
0005433680700	29177	Economy	11000.00
0005433680411	29177	Economy	11000.00
0005433680571	29177	Economy	11000.00
0005433680601	29177	Economy	11000.00
0005433680531	29177	Economy	11000.00
0005433680607	29177	Economy	11000.00
0005432005236	29177	Economy	11000.00
0005432967148	29177	Economy	11000.00
0005432967133	29177	Economy	11000.00
0005432967149	29177	Economy	11000.00
0005433680606	29177	Economy	11000.00
0005433684431	29177	Economy	11000.00
0005433680603	29177	Economy	11000.00
0005432967151	29177	Economy	11000.00
0005433680773	29177	Economy	11000.00
0005433680577	29177	Economy	11000.00
0005433680369	29177	Economy	11000.00
0005432967155	29177	Economy	11000.00
0005432967146	29177	Economy	11000.00
0005433680370	29177	Economy	11000.00
0005433680334	29177	Economy	11000.00
0005433680335	29177	Economy	11000.00
0005433680692	29177	Economy	11000.00
0005432967152	29177	Economy	11000.00
0005433680555	29177	Economy	11000.00
0005432005237	29177	Economy	11000.00
0005433680484	29177	Economy	11000.00
0005433680594	29177	Economy	11000.00
0005433680596	29177	Economy	11000.00
0005433680654	29177	Economy	11000.00
0005433680592	29177	Economy	11000.00
0005432967143	29177	Economy	11000.00
0005432005235	29177	Economy	11000.00
0005433684420	29177	Economy	11000.00
0005433680595	29177	Economy	11000.00
0005433680694	29177	Economy	11000.00
0005432967137	29177	Economy	11000.00
0005433680395	29177	Economy	11000.00
0005433680738	29177	Economy	11000.00
0005433680739	29177	Economy	11000.00
0005432967157	29177	Economy	11000.00
0005433680693	29177	Economy	11000.00
0005433680556	29177	Economy	11000.00
0005432967139	29177	Economy	11000.00
0005433680587	29177	Economy	11000.00
0005433680454	29177	Economy	11000.00
0005432967144	29177	Economy	11000.00
0005432967150	29177	Economy	11000.00
0005433680671	29177	Economy	11000.00
0005432967147	29177	Economy	11000.00
0005433680597	29177	Economy	11000.00
0005432967135	29177	Economy	11000.00
0005433680602	29177	Economy	11000.00
0005432967145	29177	Economy	11000.00
0005433680353	29177	Economy	11000.00
0005432967141	29177	Economy	11000.00
0005432967136	29177	Economy	11000.00
0005432967134	29177	Economy	11000.00
0005433615224	9298	Business	132900.00
0005433615225	9298	Business	132900.00
0005433615208	9298	Business	132900.00
0005434153528	9298	Business	132900.00
0005433577922	9298	Business	132900.00
0005432756876	9298	Business	132900.00
0005433615249	9298	Business	132900.00
0005433615217	9298	Business	132900.00
0005434163600	9298	Business	132900.00
0005433634055	9298	Business	132900.00
0005433615218	9298	Business	132900.00
0005433615220	9298	Business	132900.00
0005433615211	9298	Business	132900.00
0005433615196	9298	Business	132900.00
0005433615200	9298	Business	132900.00
0005433577916	9298	Business	132900.00
0005433634057	9298	Business	132900.00
0005433615254	9298	Business	132900.00
0005433615214	9298	Business	132900.00
0005432755103	9298	Business	132900.00
0005433615221	9298	Business	132900.00
0005433615236	9298	Business	132900.00
0005433615197	9298	Business	132900.00
0005432145126	9298	Business	132900.00
0005433634069	9298	Business	132900.00
0005433615216	9298	Business	132900.00
0005434272191	9298	Economy	48700.00
0005433615192	9298	Economy	48700.00
0005434163607	9298	Economy	48700.00
0005434163634	9298	Economy	48700.00
0005433634063	9298	Economy	48700.00
0005433615185	9298	Economy	48700.00
0005433615189	9298	Economy	44300.00
0005433634059	9298	Economy	44300.00
0005433615252	9298	Economy	44300.00
0005433615202	9298	Economy	44300.00
0005433615195	9298	Economy	44300.00
0005432755104	9298	Economy	44300.00
0005433634074	9298	Economy	44300.00
0005433634052	9298	Economy	44300.00
0005433615190	9298	Economy	44300.00
0005434163635	9298	Economy	44300.00
0005433634077	9298	Economy	44300.00
0005433634078	9298	Economy	44300.00
0005434269100	9298	Economy	44300.00
0005433615238	9298	Economy	44300.00
0005433615206	9298	Economy	44300.00
0005433634054	9298	Economy	44300.00
0005433615184	9298	Economy	44300.00
0005433615187	9298	Economy	44300.00
0005433615223	9298	Economy	44300.00
0005433615213	9298	Economy	44300.00
0005434163624	9298	Economy	44300.00
0005433615194	9298	Economy	44300.00
0005433615209	9298	Economy	44300.00
0005433577921	9298	Economy	44300.00
0005433615233	9298	Economy	44300.00
0005432145125	9298	Economy	44300.00
0005434272190	9298	Economy	44300.00
0005433577917	9298	Economy	44300.00
0005433615207	9298	Economy	44300.00
0005433577914	9298	Economy	44300.00
0005433615242	9298	Economy	44300.00
0005434163606	9298	Economy	44300.00
0005433615234	9298	Economy	44300.00
0005433615235	9298	Economy	44300.00
0005433577913	9298	Economy	44300.00
0005433615215	9298	Economy	44300.00
0005433615188	9298	Economy	44300.00
0005433615248	9298	Economy	44300.00
0005433615183	9298	Economy	44300.00
0005434269095	9298	Economy	44300.00
0005433634082	9298	Economy	44300.00
0005433615232	9298	Economy	44300.00
0005433615243	9298	Economy	44300.00
0005433615241	9298	Economy	44300.00
0005433577919	9298	Economy	44300.00
0005433634083	9298	Economy	44300.00
0005434163616	9298	Economy	44300.00
0005432755101	9298	Economy	44300.00
0005433615230	9298	Economy	44300.00
0005432756874	9298	Economy	44300.00
0005433615212	9298	Economy	44300.00
0005433634056	9298	Economy	44300.00
0005433634080	9298	Economy	44300.00
0005433615258	9298	Economy	44300.00
0005434163632	9298	Economy	48700.00
0005433615245	9298	Economy	48700.00
0005433577918	9298	Economy	48700.00
0005433634073	9298	Economy	44300.00
0005434163593	9298	Economy	44300.00
0005433577915	9298	Economy	44300.00
0005433615191	9298	Economy	44300.00
0005433634076	9298	Economy	48700.00
0005433615244	9298	Economy	44300.00
0005433615205	9298	Economy	44300.00
0005434269094	9298	Economy	44300.00
0005433634068	9298	Economy	44300.00
0005433634053	9298	Economy	44300.00
0005433615198	9298	Economy	44300.00
0005433615193	9298	Economy	44300.00
0005433615227	9298	Economy	44300.00
0005433634066	9298	Economy	44300.00
0005433615201	9298	Economy	44300.00
0005433634071	9298	Economy	44300.00
0005433615239	9298	Economy	44300.00
0005433615251	9298	Economy	44300.00
0005433634058	9298	Economy	44300.00
0005433615259	9298	Economy	44300.00
0005433615231	9298	Economy	44300.00
0005433615203	9298	Economy	44300.00
0005433634072	9298	Economy	44300.00
0005433634075	9298	Economy	44300.00
0005433615240	9298	Economy	44300.00
0005432756873	9298	Economy	44300.00
0005433615210	9298	Economy	44300.00
0005433634085	9298	Economy	44300.00
0005433615199	9298	Economy	44300.00
0005434163596	9298	Economy	44300.00
0005433634061	9298	Economy	44300.00
0005433634060	9298	Economy	44300.00
0005434163595	9298	Economy	44300.00
0005433615219	9298	Economy	44300.00
0005433634064	9298	Economy	44300.00
0005433634065	9298	Economy	44300.00
0005433615250	9298	Economy	44300.00
0005434163633	9298	Economy	44300.00
0005433634079	9298	Economy	44300.00
0005433615204	9298	Economy	44300.00
0005433615255	9298	Economy	44300.00
0005433615226	9298	Economy	44300.00
0005432755102	9298	Economy	44300.00
0005433634067	9298	Economy	44300.00
0005433615257	9298	Economy	44300.00
0005434272189	9298	Economy	44300.00
0005434163599	9298	Economy	44300.00
0005432756875	9298	Economy	44300.00
0005433615247	9298	Economy	44300.00
0005433634051	9298	Economy	44300.00
0005433615237	9298	Economy	44300.00
0005433615186	9298	Economy	44300.00
0005433577912	9298	Economy	44300.00
0005433615256	9298	Economy	44300.00
0005433634084	9298	Economy	44300.00
0005433577911	9298	Economy	44300.00
0005433615253	9298	Economy	44300.00
0005433615222	9298	Economy	44300.00
0005433634062	9298	Economy	44300.00
0005433615228	9298	Economy	44300.00
0005433577910	9298	Economy	44300.00
0005433634070	9298	Economy	44300.00
0005432755100	9298	Economy	44300.00
0005433615229	9298	Economy	44300.00
0005433634081	9298	Economy	44300.00
0005433615246	9298	Economy	44300.00
0005433577920	9298	Economy	44300.00
0005433614712	25244	Business	132900.00
0005433614801	25244	Business	132900.00
0005433615070	25244	Business	132900.00
0005433615071	25244	Business	132900.00
0005433614480	25244	Business	132900.00
0005433633765	25244	Business	132900.00
0005434163684	25244	Business	132900.00
0005433614487	25244	Business	132900.00
0005433633778	25244	Business	132900.00
0005433614630	25244	Business	132900.00
0005433614711	25244	Business	132900.00
0005434272204	25244	Business	132900.00
0005433577816	25244	Business	132900.00
0005433614474	25244	Business	132900.00
0005433614808	25244	Business	132900.00
0005433633742	25244	Business	132900.00
0005433614628	25244	Business	132900.00
0005433614217	25244	Business	132900.00
0005434273088	25244	Business	132900.00
0005433633738	25244	Business	132900.00
0005434163688	25244	Business	132900.00
0005433614479	25244	Business	132900.00
0005433633876	25244	Business	132900.00
0005433614593	25244	Economy	48700.00
0005433633705	25244	Economy	48700.00
0005433614216	25244	Economy	48700.00
0005433633771	25244	Economy	48700.00
0005433614477	25244	Economy	48700.00
0005433614572	25244	Economy	44300.00
0005433614567	25244	Economy	44300.00
0005433633934	25244	Economy	44300.00
0005433614559	25244	Economy	44300.00
0005433614696	25244	Economy	44300.00
0005434163686	25244	Economy	44300.00
0005433614626	25244	Economy	44300.00
0005433614380	25244	Economy	44300.00
0005433633611	25244	Economy	44300.00
0005433614385	25244	Economy	44300.00
0005433577825	25244	Economy	44300.00
0005433614683	25244	Economy	44300.00
0005434163689	25244	Economy	44300.00
0005433633794	25244	Economy	44300.00
0005433614296	25244	Economy	44300.00
0005434163690	25244	Economy	44300.00
0005433633800	25244	Economy	44300.00
0005433614577	25244	Economy	44300.00
0005433614027	25244	Economy	44300.00
0005433633817	25244	Economy	44300.00
0005433614502	25244	Economy	44300.00
0005433614335	25244	Economy	44300.00
0005433614549	25244	Economy	44300.00
0005433577809	25244	Economy	44300.00
0005433633815	25244	Economy	44300.00
0005433614647	25244	Economy	44300.00
0005433633802	25244	Economy	44300.00
0005433614295	25244	Economy	44300.00
0005433633875	25244	Economy	44300.00
0005433614560	25244	Economy	44300.00
0005433614427	25244	Economy	44300.00
0005434163687	25244	Economy	44300.00
0005433614762	25244	Economy	44300.00
0005433614663	25244	Economy	44300.00
0005434163692	25244	Economy	44300.00
0005434163682	25244	Economy	44300.00
0005433614733	25244	Economy	44300.00
0005433614578	25244	Economy	44300.00
0005433633793	25244	Economy	44300.00
0005433614379	25244	Economy	44300.00
0005433614631	25244	Economy	44300.00
0005433614597	25244	Economy	44300.00
0005433577810	25244	Economy	44300.00
0005433633933	25244	Economy	44300.00
0005434163685	25244	Economy	44300.00
0005433614761	25244	Economy	44300.00
0005433614610	25244	Economy	44300.00
0005433633801	25244	Economy	44300.00
0005433633706	25244	Economy	44300.00
0005433633926	25244	Economy	44300.00
0005433633822	25244	Economy	44300.00
0005433614471	25244	Economy	44300.00
0005433633760	25244	Economy	44300.00
0005433633715	25244	Economy	44300.00
0005433614636	25244	Economy	44300.00
0005433614532	25244	Economy	44300.00
0005433614541	25244	Economy	44300.00
0005433633768	25244	Economy	48700.00
0005433614746	25244	Economy	44300.00
0005433614475	25244	Economy	48700.00
0005433633615	25244	Economy	48700.00
0005433614594	25244	Economy	48700.00
0005433614454	25244	Economy	48700.00
0005433614740	25244	Economy	44300.00
0005433614529	25244	Economy	44300.00
0005433614576	25244	Economy	44300.00
0005433614569	25244	Economy	48700.00
0005433614484	25244	Economy	44300.00
0005433614646	25244	Economy	44300.00
0005433614528	25244	Economy	44300.00
0005433633902	25244	Economy	44300.00
0005433614538	25244	Economy	44300.00
0005433614600	25244	Economy	44300.00
0005433614384	25244	Economy	44300.00
0005433614069	25244	Economy	44300.00
0005433614634	25244	Economy	44300.00
0005433633787	25244	Economy	44300.00
0005433614565	25244	Economy	44300.00
0005433614700	25244	Economy	44300.00
0005433614558	25244	Economy	44300.00
0005433614697	25244	Economy	44300.00
0005433614257	25244	Economy	44300.00
0005433577811	25244	Economy	44300.00
0005433577792	25244	Economy	44300.00
0005433614745	25244	Economy	44300.00
0005433614802	25244	Economy	44300.00
0005434273089	25244	Economy	44300.00
0005433577760	25244	Economy	44300.00
0005433614473	25244	Economy	44300.00
0005433614523	25244	Economy	44300.00
0005433633767	25244	Economy	44300.00
0005433614664	25244	Economy	44300.00
0005433633788	25244	Economy	44300.00
0005433614509	25244	Economy	44300.00
0005433633670	25244	Economy	44300.00
0005433633849	25244	Economy	44300.00
0005433614356	25244	Economy	44300.00
0005433614635	25244	Economy	44300.00
0005433633855	25244	Economy	44300.00
0005434273090	25244	Economy	44300.00
0005433614592	25244	Economy	44300.00
0005433577836	25244	Economy	44300.00
0005433614476	25244	Economy	44300.00
0005433633714	25244	Economy	44300.00
0005433633717	25244	Economy	44300.00
0005433633816	25244	Economy	44300.00
0005433614483	25244	Economy	44300.00
0005433633823	25244	Economy	44300.00
0005433633739	25244	Economy	44300.00
0005433614258	25244	Economy	44300.00
0005433577753	25244	Economy	44300.00
0005433633803	25244	Economy	44300.00
0005433614807	25244	Economy	44300.00
0005433614472	25244	Economy	44300.00
0005433614566	25244	Economy	44300.00
0005433614611	25244	Economy	44300.00
0005433633634	25244	Economy	44300.00
0005433614598	25244	Economy	44300.00
0005434163683	25244	Economy	44300.00
0005433633691	25244	Economy	44300.00
0005434163691	25244	Economy	44300.00
0005433614870	25244	Economy	44300.00
0005433614378	25244	Economy	44300.00
0005433614503	25244	Economy	44300.00
0005433633690	25244	Economy	44300.00
0005435947254	4247	Business	193100.00
0005435947297	4247	Business	193100.00
0005435854060	4247	Business	193100.00
0005435947244	4247	Business	193100.00
0005435947218	4247	Economy	70800.00
0005435986822	4247	Economy	64400.00
0005435947190	4247	Economy	64400.00
0005435986809	4247	Economy	64400.00
0005435947182	4247	Economy	64400.00
0005435947269	4247	Economy	64400.00
0005435856207	4247	Economy	64400.00
0005435856185	4247	Economy	64400.00
0005435986820	4247	Economy	64400.00
0005432571316	4247	Economy	64400.00
0005435947156	4247	Economy	64400.00
0005435787347	4247	Economy	64400.00
0005435986808	4247	Economy	64400.00
0005435986821	4247	Economy	64400.00
0005435947225	4247	Economy	64400.00
0005435986818	4247	Economy	64400.00
0005435986811	4247	Economy	64400.00
0005435947219	4247	Economy	64400.00
0005435947299	4247	Economy	64400.00
0005435787348	4247	Economy	64400.00
0005435986819	4247	Economy	64400.00
0005435986814	4247	Economy	64400.00
0005435947286	4247	Economy	70800.00
0005435947268	4247	Economy	64400.00
0005435986807	4247	Economy	64400.00
0005435856206	4247	Economy	64400.00
0005435856221	4247	Economy	64400.00
0005435986810	4247	Economy	64400.00
0005435986816	4247	Economy	64400.00
0005435947228	4247	Economy	64400.00
0005435986815	4247	Economy	64400.00
0005435986806	4247	Economy	64400.00
0005435986813	4247	Economy	64400.00
0005435986817	4247	Economy	64400.00
0005435986812	4247	Economy	64400.00
0005435856241	26567	Business	193100.00
0005435947378	26567	Business	193100.00
0005432571356	26567	Economy	64400.00
0005435787374	26567	Economy	64400.00
0005435986737	26567	Economy	64400.00
0005435947370	26567	Economy	64400.00
0005435787372	26567	Economy	64400.00
0005435856237	26567	Economy	64400.00
0005435986768	26567	Economy	64400.00
0005435986767	26567	Economy	64400.00
0005435856239	26567	Economy	64400.00
0005435986733	26567	Economy	64400.00
0005435947383	26567	Economy	64400.00
0005435986762	26567	Economy	64400.00
0005432571357	26567	Economy	64400.00
0005435947381	26567	Economy	64400.00
0005435947377	26567	Economy	64400.00
0005435947372	26567	Economy	64400.00
0005435947373	26567	Economy	64400.00
0005435947374	26567	Economy	64400.00
0005435986734	26567	Economy	64400.00
0005435986763	26567	Economy	64400.00
0005435986738	26567	Economy	64400.00
0005435947379	26567	Economy	64400.00
0005435856238	26567	Economy	64400.00
0005435986752	26567	Economy	64400.00
0005435947380	26567	Economy	64400.00
0005432571355	26567	Economy	64400.00
0005435986741	26567	Economy	64400.00
0005435947384	26567	Economy	64400.00
0005435986756	26567	Economy	64400.00
0005435947371	26567	Economy	64400.00
0005435986740	26567	Economy	64400.00
0005435947376	26567	Economy	64400.00
0005435947382	26567	Economy	64400.00
0005435787373	26567	Economy	64400.00
0005435986724	26567	Economy	64400.00
0005435947375	26567	Economy	64400.00
0005435856240	26567	Economy	64400.00
0005432571354	26567	Economy	64400.00
0005435947369	26567	Economy	64400.00
0005432948337	362	Business	21500.00
0005433134135	362	Business	21500.00
0005433569578	362	Business	21500.00
0005433569572	362	Business	21500.00
0005432238989	362	Business	21500.00
0005433569553	362	Business	21500.00
0005432948402	362	Business	21500.00
0005433569549	362	Business	21500.00
0005432948472	362	Business	21500.00
0005432948412	362	Business	21500.00
0005432948411	362	Business	21500.00
0005433569548	362	Business	21500.00
0005433074640	362	Business	21500.00
0005432948448	362	Business	21500.00
0005432948284	362	Business	21500.00
0005433129273	362	Business	21500.00
0005432948283	362	Business	21500.00
0005432948154	362	Business	21500.00
0005432948338	362	Business	21500.00
0005433074680	362	Business	21500.00
0005433569552	362	Business	21500.00
0005433569567	362	Business	21500.00
0005433569559	362	Economy	7900.00
0005432948401	362	Economy	7900.00
0005433074567	362	Economy	7900.00
0005433569577	362	Economy	7900.00
0005433074721	362	Economy	7200.00
0005433569556	362	Economy	7200.00
0005433074686	362	Economy	7200.00
0005433569539	362	Economy	7200.00
0005433569546	362	Economy	7200.00
0005433074739	362	Economy	7200.00
0005432948155	362	Economy	7200.00
0005432948441	362	Economy	7200.00
0005432238988	362	Economy	7200.00
0005433569545	362	Economy	7200.00
0005433569583	362	Economy	7200.00
0005433569555	362	Economy	7200.00
0005433074683	362	Economy	7200.00
0005433569541	362	Economy	7200.00
0005433569571	362	Economy	7200.00
0005432948495	362	Economy	7200.00
0005433569579	362	Economy	7200.00
0005433074529	362	Economy	7200.00
0005432948427	362	Economy	7200.00
0005433074699	362	Economy	7200.00
0005432948379	362	Economy	7200.00
0005433569582	362	Economy	7200.00
0005432948209	362	Economy	7200.00
0005432948417	362	Economy	7200.00
0005433074656	362	Economy	7200.00
0005433569543	362	Economy	7200.00
0005432948547	362	Economy	7200.00
0005433569560	362	Economy	7200.00
0005432948367	362	Economy	7200.00
0005433569564	362	Economy	7200.00
0005433569551	362	Economy	7200.00
0005433134132	362	Economy	7200.00
0005432948414	362	Economy	7200.00
0005433569574	362	Economy	7200.00
0005433129277	362	Economy	7200.00
0005433074705	362	Economy	7200.00
0005432948359	362	Economy	7200.00
0005433074681	362	Economy	7200.00
0005432948548	362	Economy	7200.00
0005433074700	362	Economy	7200.00
0005433569569	362	Economy	7200.00
0005432948294	362	Economy	7200.00
0005432948534	362	Economy	7200.00
0005433134136	362	Economy	7200.00
0005432948652	362	Economy	7200.00
0005433074769	362	Economy	7200.00
0005433569547	362	Economy	7200.00
0005433569557	362	Economy	7900.00
0005432948515	362	Economy	7900.00
0005433569558	362	Economy	7900.00
0005432948311	362	Economy	7900.00
0005433074715	362	Economy	7200.00
0005432948197	362	Economy	7200.00
0005433074740	362	Economy	7200.00
0005433074588	362	Economy	7900.00
0005432948260	362	Economy	7200.00
0005433074704	362	Economy	7200.00
0005433569576	362	Economy	7200.00
0005433074716	362	Economy	7200.00
0005432948310	362	Economy	7200.00
0005433569565	362	Economy	7200.00
0005432948374	362	Economy	7200.00
0005432948358	362	Economy	7200.00
0005433569542	362	Economy	7200.00
0005433569581	362	Economy	7200.00
0005433569563	362	Economy	7200.00
0005433569575	362	Economy	7200.00
0005433074717	362	Economy	7200.00
0005433569580	362	Economy	7200.00
0005432948429	362	Economy	7200.00
0005433074583	362	Economy	7200.00
0005433134137	362	Economy	7200.00
0005432948498	362	Economy	7200.00
0005433569544	362	Economy	7200.00
0005433569561	362	Economy	7200.00
0005432948368	362	Economy	7200.00
0005433569562	362	Economy	7200.00
0005432948434	362	Economy	7200.00
0005432948456	362	Economy	7200.00
0005432238984	362	Economy	7200.00
0005432238987	362	Economy	7200.00
0005433569573	362	Economy	7200.00
0005433074808	362	Economy	7200.00
0005433569554	362	Economy	7200.00
0005432238985	362	Economy	7200.00
0005432948527	362	Economy	7200.00
0005433074664	362	Economy	7200.00
0005432948208	362	Economy	7200.00
0005433074679	362	Economy	7200.00
0005432948293	362	Economy	7200.00
0005432238990	362	Economy	7200.00
0005433569538	362	Economy	7200.00
0005432948259	362	Economy	7200.00
0005433569540	362	Economy	7200.00
0005433569566	362	Economy	7200.00
0005432948533	362	Economy	7200.00
0005433074672	362	Economy	7200.00
0005432948459	362	Economy	7200.00
0005432948499	362	Economy	7200.00
0005433569570	362	Economy	7200.00
0005433569568	362	Economy	7200.00
0005432948428	362	Economy	7200.00
0005432948375	362	Economy	7200.00
0005433569550	362	Economy	7200.00
0005432238986	362	Economy	7200.00
0005432948455	362	Economy	7200.00
0005432948657	362	Economy	7200.00
0005432948792	11576	Business	21500.00
0005433074931	11576	Business	21500.00
0005432948774	11576	Business	21500.00
0005433131744	11576	Business	21500.00
0005432948788	11576	Business	21500.00
0005433568891	11576	Business	21500.00
0005433568980	11576	Business	21500.00
0005432948779	11576	Business	21500.00
0005433569016	11576	Business	21500.00
0005433569112	11576	Business	21500.00
0005433074949	11576	Business	21500.00
0005433074951	11576	Business	21500.00
0005433569200	11576	Business	21500.00
0005433568847	11576	Business	21500.00
0005433568969	11576	Business	21500.00
0005433134177	11576	Business	21500.00
0005432192346	11576	Business	21500.00
0005433131746	11576	Business	21500.00
0005433568877	11576	Business	21500.00
0005432948790	11576	Business	21500.00
0005433568956	11576	Business	21500.00
0005432948768	11576	Business	21500.00
0005432948776	11576	Business	21500.00
0005432948767	11576	Business	21500.00
0005433568709	11576	Business	21500.00
0005433568912	11576	Economy	7900.00
0005433569113	11576	Economy	7900.00
0005433568885	11576	Economy	7900.00
0005433569009	11576	Economy	7900.00
0005433131745	11576	Economy	7200.00
0005432948780	11576	Economy	7900.00
0005433074936	11576	Economy	7200.00
0005433569092	11576	Economy	7200.00
0005433568738	11576	Economy	7200.00
0005433569056	11576	Economy	7200.00
0005432948777	11576	Economy	7200.00
0005432948778	11576	Economy	7200.00
0005433074927	11576	Economy	7200.00
0005432948781	11576	Economy	7200.00
0005433569000	11576	Economy	7200.00
0005433074947	11576	Economy	7200.00
0005433569024	11576	Economy	7200.00
0005433568979	11576	Economy	7200.00
0005433074939	11576	Economy	7200.00
0005433568901	11576	Economy	7200.00
0005433569010	11576	Economy	7200.00
0005433074952	11576	Economy	7200.00
0005432948771	11576	Economy	7200.00
0005433569041	11576	Economy	7200.00
0005433568949	11576	Economy	7200.00
0005433074926	11576	Economy	7200.00
0005433131748	11576	Economy	7200.00
0005433569017	11576	Economy	7200.00
0005433568868	11576	Economy	7200.00
0005432948804	11576	Economy	7200.00
0005433074934	11576	Economy	7200.00
0005432948787	11576	Economy	7200.00
0005433131747	11576	Economy	7200.00
0005433074929	11576	Economy	7200.00
0005433569155	11576	Economy	7200.00
0005433074943	11576	Economy	7200.00
0005432948766	11576	Economy	7200.00
0005433568854	11576	Economy	7200.00
0005433569082	11576	Economy	7200.00
0005432948794	11576	Economy	7200.00
0005433568480	11576	Economy	7200.00
0005433569105	11576	Economy	7200.00
0005433131743	11576	Economy	7200.00
0005433569042	11576	Economy	7200.00
0005433568957	11576	Economy	7200.00
0005433568810	11576	Economy	7200.00
0005433569067	11576	Economy	7200.00
0005433074933	11576	Economy	7200.00
0005432948775	11576	Economy	7200.00
0005432948783	11576	Economy	7200.00
0005433074940	11576	Economy	7200.00
0005433569114	11576	Economy	7200.00
0005432948797	11576	Economy	7200.00
0005433074950	11576	Economy	7200.00
0005432948796	11576	Economy	7200.00
0005433568884	11576	Economy	7200.00
0005432948784	11576	Economy	7200.00
0005432948773	11576	Economy	7200.00
0005433074928	11576	Economy	7200.00
0005433568858	11576	Economy	7900.00
0005432948786	11576	Economy	7900.00
0005432948798	11576	Economy	7900.00
0005432948803	11576	Economy	7200.00
0005433569055	11576	Economy	7200.00
0005433134176	11576	Economy	7200.00
0005433569094	11576	Economy	7900.00
0005433568966	11576	Economy	7200.00
0005432948770	11576	Economy	7200.00
0005433074948	11576	Economy	7200.00
0005433568698	11576	Economy	7200.00
0005433568892	11576	Economy	7200.00
0005433074953	11576	Economy	7200.00
0005433568948	11576	Economy	7200.00
0005433134173	11576	Economy	7200.00
0005433568879	11576	Economy	7200.00
0005433569106	11576	Economy	7200.00
0005433074942	11576	Economy	7200.00
0005432948802	11576	Economy	7200.00
0005433568925	11576	Economy	7200.00
0005433134175	11576	Economy	7200.00
0005433568641	11576	Economy	7200.00
0005433074938	11576	Economy	7200.00
0005433569335	11576	Economy	7200.00
0005433568890	11576	Economy	7200.00
0005433568973	11576	Economy	7200.00
0005432948795	11576	Economy	7200.00
0005433074925	11576	Economy	7200.00
0005433568970	11576	Economy	7200.00
0005433568841	11576	Economy	7200.00
0005433568859	11576	Economy	7200.00
0005433074945	11576	Economy	7200.00
0005432948799	11576	Economy	7200.00
0005432948793	11576	Economy	7200.00
0005433074941	11576	Economy	7200.00
0005432948782	11576	Economy	7200.00
0005432948785	11576	Economy	7200.00
0005433569001	11576	Economy	7200.00
0005433074930	11576	Economy	7200.00
0005433569199	11576	Economy	7200.00
0005432948800	11576	Economy	7200.00
0005433568708	11576	Economy	7200.00
0005432948769	11576	Economy	7200.00
0005433569093	11576	Economy	7200.00
0005432948791	11576	Economy	7200.00
0005432192344	11576	Economy	7200.00
0005433074944	11576	Economy	7200.00
0005433568812	11576	Economy	7200.00
0005433074937	11576	Economy	7200.00
0005433568934	11576	Economy	7200.00
0005433568902	11576	Economy	7200.00
0005433134174	11576	Economy	7200.00
0005433074935	11576	Economy	7200.00
0005432948772	11576	Economy	7200.00
0005433568878	11576	Economy	7200.00
0005432192345	11576	Economy	7200.00
0005433074946	11576	Economy	7200.00
0005433569081	11576	Economy	7200.00
0005432948801	11576	Economy	7200.00
0005432948789	11576	Economy	7200.00
0005432948805	11576	Economy	7200.00
0005433074932	11576	Economy	7200.00
0005433817503	10045	Economy	6300.00
0005434732988	10045	Economy	6300.00
0005433817502	10045	Economy	6300.00
0005434732989	10045	Economy	6300.00
0005434732983	10045	Economy	6300.00
0005434733009	13944	Economy	6300.00
0005434733011	13944	Economy	6300.00
0005433817470	13944	Economy	6300.00
0005434733010	13944	Economy	6300.00
0005434733008	13944	Economy	6300.00
0005433754717	2356	Business	184500.00
0005433754714	2356	Business	184500.00
0005435982665	2356	Business	184500.00
0005435982677	2356	Business	184500.00
0005433434694	2356	Business	184500.00
0005435982688	2356	Business	184500.00
0005435982695	2356	Business	184500.00
0005433754686	2356	Business	184500.00
0005432300312	2356	Business	184500.00
0005433434770	2356	Business	184500.00
0005432985223	2356	Business	184500.00
0005435982674	2356	Business	184500.00
0005433434695	2356	Business	184500.00
0005433766673	2356	Business	184500.00
0005432984938	2356	Business	184500.00
0005433754708	2356	Business	184500.00
0005432655638	2356	Business	184500.00
0005433754702	2356	Business	184500.00
0005435982700	2356	Business	184500.00
0005433434675	2356	Business	184500.00
0005433434705	2356	Business	184500.00
0005435982671	2356	Business	184500.00
0005432226108	2356	Business	184500.00
0005435982685	2356	Business	184500.00
0005435982713	2356	Business	184500.00
0005432985052	2356	Business	184500.00
0005434731167	2356	Business	184500.00
0005432985222	2356	Economy	67700.00
0005433754707	2356	Economy	67700.00
0005433754669	2356	Economy	67700.00
0005435982678	2356	Economy	67700.00
0005435982699	2356	Economy	61500.00
0005433754677	2356	Economy	61500.00
0005433766670	2356	Economy	61500.00
0005432869502	2356	Economy	61500.00
0005435982710	2356	Economy	61500.00
0005432655632	2356	Economy	61500.00
0005435982703	2356	Economy	61500.00
0005433754684	2356	Economy	61500.00
0005433754695	2356	Economy	61500.00
0005435982681	2356	Economy	61500.00
0005435982684	2356	Economy	61500.00
0005432869514	2356	Economy	61500.00
0005432985034	2356	Economy	61500.00
0005435982698	2356	Economy	61500.00
0005433754713	2356	Economy	61500.00
0005433754706	2356	Economy	61500.00
0005432984974	2356	Economy	61500.00
0005433754711	2356	Economy	61500.00
0005432869524	2356	Economy	61500.00
0005432869515	2356	Economy	61500.00
0005433434668	2356	Economy	61500.00
0005433754683	2356	Economy	61500.00
0005433754680	2356	Economy	61500.00
0005433434692	2356	Economy	61500.00
0005432655637	2356	Economy	61500.00
0005433434704	2356	Economy	61500.00
0005432300314	2356	Economy	61500.00
0005435982682	2356	Economy	61500.00
0005432985018	2356	Economy	61500.00
0005433434693	2356	Economy	61500.00
0005433434584	2356	Economy	61500.00
0005432655641	2356	Economy	61500.00
0005435982668	2356	Economy	61500.00
0005433754676	2356	Economy	61500.00
0005435982694	2356	Economy	61500.00
0005432226111	2356	Economy	61500.00
0005433434605	2356	Economy	61500.00
0005432984985	2356	Economy	61500.00
0005433434612	2356	Economy	61500.00
0005435982705	2356	Economy	61500.00
0005432226107	2356	Economy	61500.00
0005432869487	2356	Economy	61500.00
0005433434604	2356	Economy	61500.00
0005434731160	2356	Economy	61500.00
0005432655635	2356	Economy	61500.00
0005435982712	2356	Economy	61500.00
0005432655640	2356	Economy	61500.00
0005433434748	2356	Economy	61500.00
0005432985048	2356	Economy	61500.00
0005433754694	2356	Economy	61500.00
0005433434543	2356	Economy	61500.00
0005432226106	2356	Economy	61500.00
0005432985067	2356	Economy	61500.00
0005435982687	2356	Economy	61500.00
0005433754682	2356	Economy	61500.00
0005432985051	2356	Economy	61500.00
0005435982693	2356	Economy	61500.00
0005435982706	2356	Economy	61500.00
0005433754696	2356	Economy	61500.00
0005432300313	2356	Economy	61500.00
0005433754700	2356	Economy	61500.00
0005433754681	2356	Economy	61500.00
0005433434679	2356	Economy	61500.00
0005433754665	2356	Economy	61500.00
0005432226110	2356	Economy	61500.00
0005433754674	2356	Economy	61500.00
0005435982691	2356	Economy	61500.00
0005435982692	2356	Economy	61500.00
0005433754716	2356	Economy	61500.00
0005435982689	2356	Economy	61500.00
0005433754704	2356	Economy	61500.00
0005432655633	2356	Economy	61500.00
0005435982670	2356	Economy	61500.00
0005432655636	2356	Economy	61500.00
0005433754698	2356	Economy	61500.00
0005433754671	2356	Economy	61500.00
0005435982715	2356	Economy	61500.00
0005433754667	2356	Economy	61500.00
0005435982686	2356	Economy	61500.00
0005433754663	2356	Economy	61500.00
0005433754689	2356	Economy	61500.00
0005433434710	2356	Economy	61500.00
0005433754705	2356	Economy	61500.00
0005432985019	2356	Economy	61500.00
0005433764696	2356	Economy	61500.00
0005433754675	2356	Economy	61500.00
0005434731171	2356	Economy	61500.00
0005432869501	2356	Economy	61500.00
0005435982675	2356	Economy	61500.00
0005433754662	2356	Economy	61500.00
0005433754664	2356	Economy	61500.00
0005433434707	2356	Economy	61500.00
0005435982669	2356	Economy	67700.00
0005433754660	2356	Economy	61500.00
0005433434701	2356	Economy	61500.00
0005433434761	2356	Economy	61500.00
0005432655639	2356	Economy	67700.00
0005435982714	2356	Economy	61500.00
0005433434687	2356	Economy	67700.00
0005433434711	2356	Economy	61500.00
0005433754712	2356	Economy	61500.00
0005432984939	2356	Economy	61500.00
0005435982707	2356	Economy	61500.00
0005432985112	2356	Economy	61500.00
0005435982701	2356	Economy	61500.00
0005432869523	2356	Economy	61500.00
0005433754709	2356	Economy	61500.00
0005432985114	2356	Economy	61500.00
0005432655634	2356	Economy	61500.00
0005432226109	2356	Economy	61500.00
0005432985161	2356	Economy	61500.00
0005432300309	2356	Economy	61500.00
0005433754685	2356	Economy	61500.00
0005433754678	2356	Economy	61500.00
0005432984984	2356	Economy	61500.00
0005433754703	2356	Economy	61500.00
0005433764698	2356	Economy	61500.00
0005433754690	2356	Economy	61500.00
0005433434678	2356	Economy	61500.00
0005435982704	2356	Economy	61500.00
0005435982711	2356	Economy	61500.00
0005433434613	2356	Economy	61500.00
0005433754691	2356	Economy	61500.00
0005433434670	2356	Economy	61500.00
0005433434708	2356	Economy	61500.00
0005433754697	2356	Economy	61500.00
0005433754699	2356	Economy	61500.00
0005432655642	2356	Economy	61500.00
0005433754701	2356	Economy	61500.00
0005435982666	2356	Economy	61500.00
0005433764697	2356	Economy	61500.00
0005435982708	2356	Economy	61500.00
0005433766672	2356	Economy	61500.00
0005435982716	2356	Economy	61500.00
0005433754661	2356	Economy	61500.00
0005435982679	2356	Economy	61500.00
0005435982680	2356	Economy	61500.00
0005432869530	2356	Economy	61500.00
0005435982673	2356	Economy	61500.00
0005433754687	2356	Economy	61500.00
0005433754666	2356	Economy	61500.00
0005434731172	2356	Economy	61500.00
0005433754672	2356	Economy	61500.00
0005432300310	2356	Economy	61500.00
0005435982702	2356	Economy	61500.00
0005432655643	2356	Economy	61500.00
0005435982667	2356	Economy	61500.00
0005435982709	2356	Economy	61500.00
0005435982697	2356	Economy	61500.00
0005433754693	2356	Economy	61500.00
0005435982696	2356	Economy	61500.00
0005432300315	2356	Economy	61500.00
0005433766671	2356	Economy	61500.00
0005433754679	2356	Economy	61500.00
0005435982672	2356	Economy	61500.00
0005432869494	2356	Economy	61500.00
0005433754715	2356	Economy	61500.00
0005432985113	2356	Economy	61500.00
0005435982676	2356	Economy	61500.00
0005435982690	2356	Economy	61500.00
0005435982683	2356	Economy	61500.00
0005433754692	2356	Economy	61500.00
0005432300311	2356	Economy	61500.00
0005433754668	2356	Economy	61500.00
0005433754670	2356	Economy	61500.00
0005433754710	2356	Economy	61500.00
0005433754673	2356	Economy	61500.00
0005433754688	2356	Economy	61500.00
0005432985069	2356	Economy	61500.00
0005434731168	2356	Economy	61500.00
0005433434724	2356	Economy	61500.00
0005433434907	26184	Business	184500.00
0005433754264	26184	Business	184500.00
0005433754026	26184	Business	184500.00
0005433754354	26184	Business	184500.00
0005432985337	26184	Business	184500.00
0005433754330	26184	Business	184500.00
0005432655461	26184	Business	184500.00
0005433754302	26184	Business	184500.00
0005433754136	26184	Business	184500.00
0005435982258	26184	Business	184500.00
0005435982118	26184	Business	184500.00
0005433434920	26184	Business	184500.00
0005435982325	26184	Business	184500.00
0005435982365	26184	Business	184500.00
0005432655525	26184	Business	184500.00
0005433754104	26184	Business	184500.00
0005432985353	26184	Business	184500.00
0005432049492	26184	Business	184500.00
0005435982175	26184	Business	184500.00
0005433766628	26184	Business	184500.00
0005433754273	26184	Business	184500.00
0005432985343	26184	Business	184500.00
0005432051155	26184	Business	184500.00
0005433434921	26184	Business	184500.00
0005433754250	26184	Business	184500.00
0005433754266	26184	Business	184500.00
0005433754158	26184	Business	184500.00
0005433754195	26184	Economy	67700.00
0005433754114	26184	Economy	67700.00
0005434731206	26184	Economy	67700.00
0005433766645	26184	Economy	61500.00
0005433434916	26184	Economy	61500.00
0005432985360	26184	Economy	61500.00
0005433753990	26184	Economy	61500.00
0005432655516	26184	Economy	61500.00
0005433754132	26184	Economy	61500.00
0005435982368	26184	Economy	61500.00
0005435982245	26184	Economy	61500.00
0005432985355	26184	Economy	61500.00
0005435982328	26184	Economy	61500.00
0005432869578	26184	Economy	61500.00
0005433754183	26184	Economy	61500.00
0005435982288	26184	Economy	61500.00
0005432985332	26184	Economy	61500.00
0005433754024	26184	Economy	61500.00
0005433434900	26184	Economy	61500.00
0005435982369	26184	Economy	61500.00
0005435982409	26184	Economy	61500.00
0005433434914	26184	Economy	61500.00
0005433434908	26184	Economy	61500.00
0005432869573	26184	Economy	61500.00
0005435982441	26184	Economy	61500.00
0005435982107	26184	Economy	61500.00
0005433754127	26184	Economy	61500.00
0005433434909	26184	Economy	61500.00
0005432985333	26184	Economy	61500.00
0005433754159	26184	Economy	61500.00
0005433754253	26184	Economy	61500.00
0005435982289	26184	Economy	61500.00
0005432869574	26184	Economy	61500.00
0005433754255	26184	Economy	61500.00
0005432985336	26184	Economy	61500.00
0005435981987	26184	Economy	61500.00
0005433766646	26184	Economy	61500.00
0005433753938	26184	Economy	61500.00
0005432655462	26184	Economy	61500.00
0005433434905	26184	Economy	61500.00
0005432985334	26184	Economy	61500.00
0005433754112	26184	Economy	61500.00
0005433754219	26184	Economy	61500.00
0005433434902	26184	Economy	61500.00
0005434731205	26184	Economy	61500.00
0005435982335	26184	Economy	61500.00
0005432655474	26184	Economy	61500.00
0005435982310	26184	Economy	61500.00
0005435982297	26184	Economy	61500.00
0005433754223	26184	Economy	61500.00
0005433434913	26184	Economy	61500.00
0005432985362	26184	Economy	61500.00
0005433754085	26184	Economy	61500.00
0005433766630	26184	Economy	61500.00
0005432869579	26184	Economy	61500.00
0005433434899	26184	Economy	61500.00
0005435982476	26184	Economy	61500.00
0005433754164	26184	Economy	61500.00
0005432049493	26184	Economy	61500.00
0005433754265	26184	Economy	61500.00
0005435982123	26184	Economy	61500.00
0005432655473	26184	Economy	61500.00
0005435982414	26184	Economy	61500.00
0005432985339	26184	Economy	61500.00
0005432985357	26184	Economy	61500.00
0005432869576	26184	Economy	61500.00
0005432985345	26184	Economy	61500.00
0005432985344	26184	Economy	61500.00
0005435982228	26184	Economy	61500.00
0005433434904	26184	Economy	61500.00
0005433434923	26184	Economy	61500.00
0005432985340	26184	Economy	61500.00
0005435982049	26184	Economy	61500.00
0005432655519	26184	Economy	61500.00
0005433434911	26184	Economy	61500.00
0005432985348	26184	Economy	61500.00
0005433754220	26184	Economy	61500.00
0005432985330	26184	Economy	61500.00
0005433754111	26184	Economy	61500.00
0005433434910	26184	Economy	61500.00
0005435982124	26184	Economy	61500.00
0005435982260	26184	Economy	61500.00
0005433754228	26184	Economy	61500.00
0005433754276	26184	Economy	61500.00
0005433754080	26184	Economy	61500.00
0005433434926	26184	Economy	61500.00
0005432985359	26184	Economy	61500.00
0005435982400	26184	Economy	61500.00
0005433754110	26184	Economy	61500.00
0005433754340	26184	Economy	61500.00
0005432985346	26184	Economy	61500.00
0005432985329	26184	Economy	61500.00
0005433754041	26184	Economy	61500.00
0005433754263	26184	Economy	61500.00
0005433754184	26184	Economy	61500.00
0005432985358	26184	Economy	67700.00
0005433754322	26184	Economy	67700.00
0005435982339	26184	Economy	61500.00
0005433753993	26184	Economy	61500.00
0005435982159	26184	Economy	61500.00
0005433754084	26184	Economy	67700.00
0005435982327	26184	Economy	67700.00
0005435982413	26184	Economy	61500.00
0005433434915	26184	Economy	61500.00
0005433434906	26184	Economy	61500.00
0005433754113	26184	Economy	61500.00
0005433754181	26184	Economy	61500.00
0005435982259	26184	Economy	61500.00
0005432051154	26184	Economy	61500.00
0005432985351	26184	Economy	61500.00
0005432985338	26184	Economy	61500.00
0005432985356	26184	Economy	61500.00
0005433754331	26184	Economy	61500.00
0005432655446	26184	Economy	61500.00
0005432655528	26184	Economy	61500.00
0005433434912	26184	Economy	61500.00
0005433754251	26184	Economy	61500.00
0005433754157	26184	Economy	61500.00
0005433434917	26184	Economy	61500.00
0005433754323	26184	Economy	61500.00
0005435982295	26184	Economy	61500.00
0005432655527	26184	Economy	61500.00
0005433434919	26184	Economy	61500.00
0005433434922	26184	Economy	61500.00
0005432051153	26184	Economy	61500.00
0005432985347	26184	Economy	61500.00
0005433754152	26184	Economy	61500.00
0005433754221	26184	Economy	61500.00
0005432049494	26184	Economy	61500.00
0005433754156	26184	Economy	61500.00
0005432049496	26184	Economy	61500.00
0005435982257	26184	Economy	61500.00
0005432985350	26184	Economy	61500.00
0005433434924	26184	Economy	61500.00
0005433434927	26184	Economy	61500.00
0005433754044	26184	Economy	61500.00
0005432655499	26184	Economy	61500.00
0005433434928	26184	Economy	61500.00
0005432869575	26184	Economy	61500.00
0005433754267	26184	Economy	61500.00
0005432985341	26184	Economy	61500.00
0005432985335	26184	Economy	61500.00
0005433754366	26184	Economy	61500.00
0005433753937	26184	Economy	61500.00
0005435982235	26184	Economy	61500.00
0005433754153	26184	Economy	61500.00
0005433434925	26184	Economy	61500.00
0005433754347	26184	Economy	61500.00
0005433754109	26184	Economy	61500.00
0005433754025	26184	Economy	61500.00
0005432985352	26184	Economy	61500.00
0005435982034	26184	Economy	61500.00
0005432985349	26184	Economy	61500.00
0005435982280	26184	Economy	61500.00
0005432985354	26184	Economy	61500.00
0005433434918	26184	Economy	61500.00
0005433754341	26184	Economy	61500.00
0005435982477	26184	Economy	61500.00
0005434731204	26184	Economy	61500.00
0005433754216	26184	Economy	61500.00
0005433434901	26184	Economy	61500.00
0005432985361	26184	Economy	61500.00
0005433434903	26184	Economy	61500.00
0005432985331	26184	Economy	61500.00
0005434731207	26184	Economy	61500.00
0005432869577	26184	Economy	61500.00
0005435982234	26184	Economy	61500.00
0005433754361	26184	Economy	61500.00
0005433754285	26184	Economy	61500.00
0005432049495	26184	Economy	61500.00
0005433754257	26184	Economy	61500.00
0005432985342	26184	Economy	61500.00
0005433754333	26184	Economy	61500.00
0005433754256	26184	Economy	61500.00
0005432655554	26184	Economy	61500.00
0005432655472	26184	Economy	61500.00
0005433151494	1515	Business	38900.00
0005434375059	1515	Business	38900.00
0005434375053	1515	Business	38900.00
0005434375057	1515	Business	38900.00
0005432267954	1515	Business	38900.00
0005433151446	1515	Business	38900.00
0005434375025	1515	Business	38900.00
0005434375041	1515	Economy	13000.00
0005433151377	1515	Economy	13000.00
0005434375061	1515	Economy	13000.00
0005433151310	1515	Economy	13000.00
0005434375045	1515	Economy	13000.00
0005433151364	1515	Economy	13000.00
0005434375032	1515	Economy	13000.00
0005433151531	1515	Economy	13000.00
0005434375042	1515	Economy	13000.00
0005434375015	1515	Economy	13000.00
0005433151481	1515	Economy	13000.00
0005434375016	1515	Economy	13000.00
0005433151480	1515	Economy	13000.00
0005434375017	1515	Economy	13000.00
0005434375035	1515	Economy	13000.00
0005434375040	1515	Economy	13000.00
0005434375038	1515	Economy	13000.00
0005434375058	1515	Economy	13000.00
0005434375039	1515	Economy	13000.00
0005433151489	1515	Economy	13000.00
0005433151510	1515	Economy	13000.00
0005434029650	1515	Economy	13000.00
0005434375037	1515	Economy	13000.00
0005433151365	1515	Economy	13000.00
0005432267953	1515	Economy	13000.00
0005433151435	1515	Economy	13000.00
0005433151342	1515	Economy	13000.00
0005434375021	1515	Economy	13000.00
0005434375019	1515	Economy	13000.00
0005434375060	1515	Economy	14300.00
0005432267950	1515	Economy	14300.00
0005433461605	1515	Economy	14300.00
0005434375034	1515	Economy	13000.00
0005434375049	1515	Economy	13000.00
0005434375013	1515	Economy	13000.00
0005434375047	1515	Economy	13000.00
0005433461606	1515	Economy	13000.00
0005432267952	1515	Economy	13000.00
0005432267949	1515	Economy	13000.00
0005434375050	1515	Economy	13000.00
0005434375056	1515	Economy	13000.00
0005434375028	1515	Economy	13000.00
0005434375062	1515	Economy	13000.00
0005434375033	1515	Economy	13000.00
0005434375020	1515	Economy	13000.00
0005434375022	1515	Economy	13000.00
0005434375027	1515	Economy	13000.00
0005433460454	1515	Economy	13000.00
0005433764680	1515	Economy	13000.00
0005433151488	1515	Economy	13000.00
0005433151530	1515	Economy	13000.00
0005434375029	1515	Economy	13000.00
0005434375031	1515	Economy	13000.00
0005434375048	1515	Economy	13000.00
0005434375023	1515	Economy	13000.00
0005434375030	1515	Economy	13000.00
0005433151560	1515	Economy	13000.00
0005432267951	1515	Economy	13000.00
0005433151495	1515	Economy	13000.00
0005434375024	1515	Economy	13000.00
0005434375018	1515	Economy	13000.00
0005434375014	1515	Economy	13000.00
0005434375043	1515	Economy	13000.00
0005433151363	1515	Economy	13000.00
0005432267948	1515	Economy	13000.00
0005434375036	1515	Economy	13000.00
0005433151519	1515	Economy	13000.00
0005434375054	1515	Economy	13000.00
0005433460453	1515	Economy	13000.00
0005433931457	1515	Economy	13000.00
0005434375052	1515	Economy	13000.00
0005433151445	1515	Economy	13000.00
0005434375026	1515	Economy	13000.00
0005434375044	1515	Economy	13000.00
0005433151458	1515	Economy	13000.00
0005434375055	1515	Economy	13000.00
0005434375012	1515	Economy	13000.00
0005433151148	1515	Economy	13000.00
0005434375046	1515	Economy	13000.00
0005434375051	1515	Economy	13000.00
0005434374705	20128	Business	38900.00
0005433151701	20128	Business	38900.00
0005434374719	20128	Business	38900.00
0005433151692	20128	Business	38900.00
0005433151694	20128	Business	38900.00
0005433151679	20128	Business	38900.00
0005434376223	20128	Business	38900.00
0005433764698	20128	Economy	13000.00
0005434374652	20128	Economy	13000.00
0005433151675	20128	Economy	13000.00
0005434374636	20128	Economy	13000.00
0005434374624	20128	Economy	13000.00
0005433151697	20128	Economy	13000.00
0005433764697	20128	Economy	13000.00
0005434374573	20128	Economy	13000.00
0005434374675	20128	Economy	13000.00
0005433151682	20128	Economy	13000.00
0005433151681	20128	Economy	13000.00
0005432056330	20128	Economy	13000.00
0005433151699	20128	Economy	13000.00
0005434029678	20128	Economy	13000.00
0005433151706	20128	Economy	13000.00
0005433931492	20128	Economy	13000.00
0005433151705	20128	Economy	13000.00
0005434374776	20128	Economy	13000.00
0005433151674	20128	Economy	13000.00
0005433151680	20128	Economy	13000.00
0005434374612	20128	Economy	13000.00
0005434374629	20128	Economy	13000.00
0005433151688	20128	Economy	13000.00
0005434374616	20128	Economy	13000.00
0005433931491	20128	Economy	14300.00
0005434374493	20128	Economy	14300.00
0005433151677	20128	Economy	14300.00
0005433151683	20128	Economy	13000.00
0005433151695	20128	Economy	14300.00
0005433931490	20128	Economy	13000.00
0005433151690	20128	Economy	13000.00
0005434029677	20128	Economy	13000.00
0005433151696	20128	Economy	13000.00
0005434374492	20128	Economy	13000.00
0005434374828	20128	Economy	13000.00
0005433151700	20128	Economy	13000.00
0005434374504	20128	Economy	13000.00
0005433151691	20128	Economy	13000.00
0005433151702	20128	Economy	13000.00
0005433151678	20128	Economy	13000.00
0005434374491	20128	Economy	13000.00
0005434374651	20128	Economy	13000.00
0005433151687	20128	Economy	13000.00
0005434374594	20128	Economy	13000.00
0005434374744	20128	Economy	13000.00
0005434374856	20128	Economy	13000.00
0005433151707	20128	Economy	13000.00
0005434374653	20128	Economy	13000.00
0005434374640	20128	Economy	13000.00
0005432056331	20128	Economy	13000.00
0005433151704	20128	Economy	13000.00
0005434374748	20128	Economy	13000.00
0005432056329	20128	Economy	13000.00
0005433151703	20128	Economy	13000.00
0005434374857	20128	Economy	13000.00
0005434374483	20128	Economy	13000.00
0005434374482	20128	Economy	13000.00
0005433151685	20128	Economy	13000.00
0005434374752	20128	Economy	13000.00
0005434374549	20128	Economy	13000.00
0005433764696	20128	Economy	13000.00
0005433151693	20128	Economy	13000.00
0005434374633	20128	Economy	13000.00
0005433151689	20128	Economy	13000.00
0005433151673	20128	Economy	13000.00
0005434374611	20128	Economy	13000.00
0005434376224	20128	Economy	13000.00
0005433151676	20128	Economy	13000.00
0005433151684	20128	Economy	13000.00
0005433151686	20128	Economy	13000.00
0005433151698	20128	Economy	13000.00
0005434029676	20128	Economy	13000.00
0005432424839	566	Business	27500.00
0005432282923	566	Business	27500.00
0005432424826	566	Business	27500.00
0005432424842	566	Business	27500.00
0005432424828	566	Business	27500.00
0005432424860	566	Economy	10100.00
0005432424863	566	Economy	9200.00
0005432282922	566	Economy	9200.00
0005432282925	566	Economy	9200.00
0005432424843	566	Economy	9200.00
0005432424829	566	Economy	9200.00
0005432424845	566	Economy	9200.00
0005432424859	566	Economy	9200.00
0005432424861	566	Economy	9200.00
0005432424857	566	Economy	9200.00
0005432424841	566	Economy	9200.00
0005432424836	566	Economy	9200.00
0005432424854	566	Economy	9200.00
0005432424837	566	Economy	9200.00
0005432424844	566	Economy	9200.00
0005432424822	566	Economy	9200.00
0005432424858	566	Economy	9200.00
0005432424862	566	Economy	9200.00
0005432424856	566	Economy	9200.00
0005432424855	566	Economy	10100.00
0005432282920	566	Economy	9200.00
0005432424823	566	Economy	9200.00
0005432424847	566	Economy	9200.00
0005432424824	566	Economy	9200.00
0005432424853	566	Economy	9200.00
0005432424830	566	Economy	9200.00
0005432424850	566	Economy	9200.00
0005432424851	566	Economy	9200.00
0005432424825	566	Economy	9200.00
0005432424846	566	Economy	9200.00
0005432424838	566	Economy	9200.00
0005432282924	566	Economy	9200.00
0005432424852	566	Economy	9200.00
0005432424834	566	Economy	9200.00
0005432424835	566	Economy	9200.00
0005432424849	566	Economy	9200.00
0005432424831	566	Economy	9200.00
0005432424833	566	Economy	9200.00
0005432424848	566	Economy	9200.00
0005432424832	566	Economy	9200.00
0005432424840	566	Economy	9200.00
0005432282921	566	Economy	9200.00
0005432424827	566	Economy	9200.00
0005433158148	12924	Business	27500.00
0005434446517	12924	Business	27500.00
0005432302365	12924	Business	27500.00
0005434446521	12924	Business	27500.00
0005432302361	12924	Business	27500.00
0005434446514	12924	Economy	9200.00
0005433158151	12924	Economy	9200.00
0005433158150	12924	Economy	9200.00
0005433158147	12924	Economy	9200.00
0005434446522	12924	Economy	9200.00
0005432302364	12924	Economy	9200.00
0005432302363	12924	Economy	9200.00
0005432302362	12924	Economy	9200.00
0005433158149	12924	Economy	9200.00
0005432302360	12924	Economy	9200.00
0005432424365	12920	Business	27500.00
0005432424389	12920	Business	27500.00
0005432424303	12920	Business	27500.00
0005432424394	12920	Business	27500.00
0005432424410	12920	Business	27500.00
0005432424403	12920	Economy	10100.00
0005432424399	12920	Economy	9200.00
0005432424329	12920	Economy	9200.00
0005432424263	12920	Economy	9200.00
0005432424357	12920	Economy	9200.00
0005432424341	12920	Economy	9200.00
0005432424358	12920	Economy	9200.00
0005432424408	12920	Economy	9200.00
0005432424388	12920	Economy	9200.00
0005432424375	12920	Economy	9200.00
0005432424310	12920	Economy	9200.00
0005432424346	12920	Economy	9200.00
0005432424189	12920	Economy	9200.00
0005432424262	12920	Economy	9200.00
0005432424337	12920	Economy	9200.00
0005432424364	12920	Economy	10100.00
0005432424196	12920	Economy	10100.00
0005432424336	12920	Economy	9200.00
0005432424404	12920	Economy	9200.00
0005432424342	12920	Economy	9200.00
0005432424373	12920	Economy	9200.00
0005432424356	12920	Economy	9200.00
0005432424347	12920	Economy	9200.00
0005432424348	12920	Economy	9200.00
0005432424304	12920	Economy	9200.00
0005432424385	12920	Economy	9200.00
0005432424411	12920	Economy	9200.00
0005432424258	12920	Economy	9200.00
0005432424372	12920	Economy	9200.00
0005432424409	12920	Economy	9200.00
0005432424324	12920	Economy	9200.00
0005432424340	12920	Economy	9200.00
0005432424395	12920	Economy	9200.00
0005432424325	12920	Economy	9200.00
0005432424374	12920	Economy	9200.00
0005432424163	12920	Economy	9200.00
0005432424298	12920	Economy	9200.00
0005432424345	12920	Economy	9200.00
0005433057997	453	Business	24500.00
0005433929596	453	Business	24500.00
0005432235700	453	Business	24500.00
0005434024293	453	Business	24500.00
0005434028317	453	Business	24500.00
0005434024297	453	Business	24500.00
0005433057947	453	Business	24500.00
0005434024287	453	Business	24500.00
0005433057901	453	Business	24500.00
0005434024299	453	Business	24500.00
0005434735672	453	Business	24500.00
0005434024246	453	Business	24500.00
0005433057902	453	Business	24500.00
0005433057913	453	Business	24500.00
0005434024264	453	Business	24500.00
0005433058023	453	Business	24500.00
0005434024283	453	Business	24500.00
0005433058002	453	Business	24500.00
0005434024294	453	Economy	9000.00
0005434024235	453	Economy	9000.00
0005433057932	453	Economy	8200.00
0005434024253	453	Economy	8200.00
0005434024257	453	Economy	8200.00
0005433057722	453	Economy	8200.00
0005434024288	453	Economy	8200.00
0005434024242	453	Economy	8200.00
0005433057765	453	Economy	8200.00
0005433057896	453	Economy	8200.00
0005434024284	453	Economy	8200.00
0005433057692	453	Economy	8200.00
0005434024261	453	Economy	8200.00
0005434024262	453	Economy	8200.00
0005434024270	453	Economy	8200.00
0005433057754	453	Economy	8200.00
0005433057848	453	Economy	8200.00
0005433057954	453	Economy	8200.00
0005433057900	453	Economy	8200.00
0005434024254	453	Economy	8200.00
0005432235697	453	Economy	8200.00
0005434024255	453	Economy	8200.00
0005434024300	453	Economy	8200.00
0005434024267	453	Economy	8200.00
0005434024263	453	Economy	8200.00
0005433057846	453	Economy	8200.00
0005433058000	453	Economy	8200.00
0005433057820	453	Economy	8200.00
0005432235699	453	Economy	8200.00
0005434024259	453	Economy	8200.00
0005433057876	453	Economy	8200.00
0005434024245	453	Economy	8200.00
0005433057911	453	Economy	8200.00
0005434024277	453	Economy	8200.00
0005433057868	453	Economy	8200.00
0005433057895	453	Economy	8200.00
0005433057920	453	Economy	8200.00
0005432235702	453	Economy	8200.00
0005434024278	453	Economy	8200.00
0005433057821	453	Economy	8200.00
0005433057973	453	Economy	8200.00
0005434024268	453	Economy	8200.00
0005433057918	453	Economy	8200.00
0005434024248	453	Economy	8200.00
0005434024260	453	Economy	8200.00
0005434024256	453	Economy	8200.00
0005434032060	453	Economy	8200.00
0005434024252	453	Economy	8200.00
0005434024266	453	Economy	8200.00
0005434024247	453	Economy	8200.00
0005433057930	453	Economy	8200.00
0005434024236	453	Economy	8200.00
0005434735675	453	Economy	8200.00
0005434024289	453	Economy	8200.00
0005434024286	453	Economy	8200.00
0005434024250	453	Economy	8200.00
0005434024296	453	Economy	8200.00
0005434024292	453	Economy	8200.00
0005434032056	453	Economy	8200.00
0005434735693	453	Economy	8200.00
0005433058025	453	Economy	8200.00
0005433057878	453	Economy	8200.00
0005434024240	453	Economy	8200.00
0005434032058	453	Economy	8200.00
0005432045629	453	Economy	8200.00
0005434024239	453	Economy	8200.00
0005432045628	453	Economy	9000.00
0005433058129	453	Economy	8200.00
0005434735674	453	Economy	8200.00
0005433057912	453	Economy	8200.00
0005433057814	453	Economy	9000.00
0005434024282	453	Economy	8200.00
0005434024301	453	Economy	8200.00
0005433058026	453	Economy	8200.00
0005434032059	453	Economy	8200.00
0005433057919	453	Economy	8200.00
0005433057859	453	Economy	8200.00
0005433057877	453	Economy	8200.00
0005434028316	453	Economy	8200.00
0005434024243	453	Economy	8200.00
0005434024280	453	Economy	8200.00
0005434024281	453	Economy	8200.00
0005434024295	453	Economy	8200.00
0005434024273	453	Economy	8200.00
0005434024291	453	Economy	8200.00
0005434024279	453	Economy	8200.00
0005434024251	453	Economy	8200.00
0005433058001	453	Economy	8200.00
0005433058024	453	Economy	8200.00
0005434024298	453	Economy	8200.00
0005432235698	453	Economy	8200.00
0005433058011	453	Economy	8200.00
0005434024258	453	Economy	8200.00
0005434024241	453	Economy	8200.00
0005433057858	453	Economy	8200.00
0005434024244	453	Economy	8200.00
0005433057996	453	Economy	8200.00
0005434029674	453	Economy	8200.00
0005434024274	453	Economy	8200.00
0005434024303	453	Economy	8200.00
0005433057969	453	Economy	8200.00
0005434024238	453	Economy	8200.00
0005434024237	453	Economy	8200.00
0005434024275	453	Economy	8200.00
0005433057889	453	Economy	8200.00
0005434024249	453	Economy	8200.00
0005434024265	453	Economy	8200.00
0005432235703	453	Economy	8200.00
0005433058052	453	Economy	8200.00
0005434024269	453	Economy	8200.00
0005434024302	453	Economy	8200.00
0005433057964	453	Economy	8200.00
0005432235701	453	Economy	8200.00
0005433057940	453	Economy	8200.00
0005434029675	453	Economy	8200.00
0005434024271	453	Economy	8200.00
0005434024272	453	Economy	8200.00
0005433058059	453	Economy	8200.00
0005433057966	453	Economy	8200.00
0005433057910	453	Economy	8200.00
0005434024285	453	Economy	8200.00
0005433057817	453	Economy	8200.00
0005434032057	453	Economy	8200.00
0005434024276	453	Economy	8200.00
0005434024290	453	Economy	8200.00
0005433057831	453	Economy	8200.00
0005434024086	12684	Business	24500.00
0005433058203	12684	Business	24500.00
0005434023640	12684	Business	24500.00
0005434023533	12684	Business	24500.00
0005434023702	12684	Business	24500.00
0005434024065	12684	Business	24500.00
0005434023876	12684	Business	24500.00
0005432157508	12684	Business	24500.00
0005432156404	12684	Business	24500.00
0005433058196	12684	Business	24500.00
0005434023506	12684	Business	24500.00
0005433058220	12684	Business	24500.00
0005434023359	12684	Business	24500.00
0005433058197	12684	Business	24500.00
0005434023687	12684	Business	24500.00
0005434023631	12684	Business	24500.00
0005434023742	12684	Economy	9000.00
0005433058206	12684	Economy	9000.00
0005433058217	12684	Economy	8200.00
0005434023786	12684	Economy	8200.00
0005434024088	12684	Economy	8200.00
0005434023630	12684	Economy	8200.00
0005434032025	12684	Economy	8200.00
0005432156403	12684	Economy	8200.00
0005433058224	12684	Economy	8200.00
0005434023904	12684	Economy	8200.00
0005434735733	12684	Economy	8200.00
0005434023627	12684	Economy	8200.00
0005434023360	12684	Economy	8200.00
0005434023785	12684	Economy	8200.00
0005434032026	12684	Economy	8200.00
0005433058228	12684	Economy	8200.00
0005434023752	12684	Economy	8200.00
0005433058209	12684	Economy	8200.00
0005432156401	12684	Economy	8200.00
0005434023877	12684	Economy	8200.00
0005434023974	12684	Economy	8200.00
0005434023832	12684	Economy	8200.00
0005434023754	12684	Economy	8200.00
0005432156400	12684	Economy	8200.00
0005434023444	12684	Economy	8200.00
0005434023632	12684	Economy	8200.00
0005434023889	12684	Economy	8200.00
0005433058214	12684	Economy	8200.00
0005434023814	12684	Economy	8200.00
0005434023903	12684	Economy	8200.00
0005434735735	12684	Economy	8200.00
0005434023722	12684	Economy	8200.00
0005434023625	12684	Economy	8200.00
0005434023626	12684	Economy	8200.00
0005433058235	12684	Economy	8200.00
0005434023809	12684	Economy	8200.00
0005433058232	12684	Economy	8200.00
0005433058213	12684	Economy	8200.00
0005434023866	12684	Economy	8200.00
0005433058226	12684	Economy	8200.00
0005433058230	12684	Economy	8200.00
0005433058198	12684	Economy	8200.00
0005434023557	12684	Economy	8200.00
0005434735731	12684	Economy	8200.00
0005434032027	12684	Economy	8200.00
0005434024087	12684	Economy	8200.00
0005433058207	12684	Economy	8200.00
0005434023663	12684	Economy	8200.00
0005434023951	12684	Economy	8200.00
0005434023566	12684	Economy	8200.00
0005433058205	12684	Economy	8200.00
0005433058210	12684	Economy	8200.00
0005434024066	12684	Economy	8200.00
0005434735734	12684	Economy	8200.00
0005433058221	12684	Economy	8200.00
0005432156402	12684	Economy	9000.00
0005433929646	12684	Economy	9000.00
0005434023561	12684	Economy	8200.00
0005433058211	12684	Economy	8200.00
0005434023796	12684	Economy	9000.00
0005433058201	12684	Economy	8200.00
0005434023893	12684	Economy	8200.00
0005433058233	12684	Economy	8200.00
0005433058212	12684	Economy	8200.00
0005433058219	12684	Economy	8200.00
0005434023649	12684	Economy	8200.00
0005434023888	12684	Economy	8200.00
0005433058234	12684	Economy	8200.00
0005433058218	12684	Economy	8200.00
0005433058216	12684	Economy	8200.00
0005434023507	12684	Economy	8200.00
0005434023603	12684	Economy	8200.00
0005434023570	12684	Economy	8200.00
0005433058215	12684	Economy	8200.00
0005433058227	12684	Economy	8200.00
0005434024085	12684	Economy	8200.00
0005433058208	12684	Economy	8200.00
0005433058202	12684	Economy	8200.00
0005434023532	12684	Economy	8200.00
0005434023684	12684	Economy	8200.00
0005434023404	12684	Economy	8200.00
0005433058200	12684	Economy	8200.00
0005433058225	12684	Economy	8200.00
0005433058231	12684	Economy	8200.00
0005433058199	12684	Economy	8200.00
0005433058222	12684	Economy	8200.00
0005434023641	12684	Economy	8200.00
0005434735732	12684	Economy	8200.00
0005434023511	12684	Economy	8200.00
0005434023676	12684	Economy	8200.00
0005434023646	12684	Economy	8200.00
0005434029650	12684	Economy	8200.00
0005434023952	12684	Economy	8200.00
0005434023787	12684	Economy	8200.00
0005433058195	12684	Economy	8200.00
0005434023908	12684	Economy	8200.00
0005434023682	12684	Economy	8200.00
0005433058204	12684	Economy	8200.00
0005433929647	12684	Economy	8200.00
0005433929648	12684	Economy	8200.00
0005434023658	12684	Economy	8200.00
0005433058223	12684	Economy	8200.00
0005434023773	12684	Economy	8200.00
0005434023609	12684	Economy	8200.00
0005434023894	12684	Economy	8200.00
0005434023774	12684	Economy	8200.00
0005434023739	12684	Economy	8200.00
0005433058229	12684	Economy	8200.00
0005434023778	12684	Economy	8200.00
0005433036286	2139	Business	34700.00
0005433924130	2139	Business	34700.00
0005433036346	2139	Business	34700.00
0005433924045	2139	Business	34700.00
0005433924108	2139	Business	34700.00
0005433924049	2139	Business	34700.00
0005433036218	2139	Business	34700.00
0005433924105	2139	Business	34700.00
0005433036424	2139	Business	34700.00
0005433036179	2139	Business	34700.00
0005432749780	2139	Business	34700.00
0005433924092	2139	Business	34700.00
0005433929648	2139	Business	34700.00
0005433924060	2139	Business	34700.00
0005433924110	2139	Business	34700.00
0005433924058	2139	Business	34700.00
0005433924106	2139	Business	34700.00
0005433924086	2139	Business	34700.00
0005433036292	2139	Business	34700.00
0005432749785	2139	Business	34700.00
0005433924104	2139	Business	34700.00
0005433924069	2139	Business	34700.00
0005433924136	2139	Business	34700.00
0005433924053	2139	Business	34700.00
0005433036449	2139	Business	34700.00
0005433924079	2139	Business	34700.00
0005433924076	2139	Business	34700.00
0005433036095	2139	Economy	12700.00
0005433924057	2139	Business	34700.00
0005433924122	2139	Economy	12700.00
0005433036345	2139	Economy	12700.00
0005433036331	2139	Economy	11600.00
0005433924044	2139	Economy	11600.00
0005432231653	2139	Economy	11600.00
0005433924128	2139	Economy	11600.00
0005432231648	2139	Economy	11600.00
0005433924068	2139	Economy	11600.00
0005433924063	2139	Economy	11600.00
0005433036275	2139	Economy	11600.00
0005433924046	2139	Economy	11600.00
0005433924052	2139	Economy	11600.00
0005433924132	2139	Economy	11600.00
0005433924134	2139	Economy	11600.00
0005433036115	2139	Economy	11600.00
0005433924113	2139	Economy	11600.00
0005433924115	2139	Economy	11600.00
0005433924120	2139	Economy	11600.00
0005433924083	2139	Economy	11600.00
0005433036322	2139	Economy	11600.00
0005433036024	2139	Economy	11600.00
0005433924093	2139	Economy	11600.00
0005433036154	2139	Economy	11600.00
0005433036417	2139	Economy	11600.00
0005433924061	2139	Economy	11600.00
0005433924118	2139	Economy	11600.00
0005433931491	2139	Economy	11600.00
0005433036421	2139	Economy	11600.00
0005433036422	2139	Economy	11600.00
0005433931492	2139	Economy	11600.00
0005433924073	2139	Economy	11600.00
0005433924087	2139	Economy	11600.00
0005433036308	2139	Economy	11600.00
0005433924126	2139	Economy	11600.00
0005433924138	2139	Economy	11600.00
0005433924054	2139	Economy	11600.00
0005433924133	2139	Economy	11600.00
0005433924123	2139	Economy	11600.00
0005432231656	2139	Economy	11600.00
0005433924121	2139	Economy	11600.00
0005433924102	2139	Economy	11600.00
0005432231650	2139	Economy	11600.00
0005433924067	2139	Economy	11600.00
0005433924048	2139	Economy	11600.00
0005433036208	2139	Economy	11600.00
0005433924082	2139	Economy	11600.00
0005433931490	2139	Economy	11600.00
0005432749779	2139	Economy	11600.00
0005433036261	2139	Economy	11600.00
0005433036220	2139	Economy	11600.00
0005433036246	2139	Economy	11600.00
0005433924077	2139	Economy	11600.00
0005433036339	2139	Economy	11600.00
0005433036155	2139	Economy	11600.00
0005433924065	2139	Economy	11600.00
0005433924064	2139	Economy	11600.00
0005433036306	2139	Economy	11600.00
0005433924135	2139	Economy	11600.00
0005433036321	2139	Economy	11600.00
0005433924078	2139	Economy	11600.00
0005433924055	2139	Economy	11600.00
0005433036358	2139	Economy	11600.00
0005433929647	2139	Economy	11600.00
0005433924075	2139	Economy	11600.00
0005433924047	2139	Economy	11600.00
0005433924131	2139	Economy	11600.00
0005433924085	2139	Economy	11600.00
0005433924088	2139	Economy	11600.00
0005433036324	2139	Economy	11600.00
0005433924080	2139	Economy	11600.00
0005433924074	2139	Economy	11600.00
0005433929646	2139	Economy	11600.00
0005433924070	2139	Economy	11600.00
0005432231652	2139	Economy	11600.00
0005433036310	2139	Economy	11600.00
0005432044548	2139	Economy	11600.00
0005433924071	2139	Economy	11600.00
0005433924107	2139	Economy	12700.00
0005433036193	2139	Economy	12700.00
0005432231655	2139	Economy	11600.00
0005433924051	2139	Economy	11600.00
0005432231651	2139	Economy	12700.00
0005433036460	2139	Economy	11600.00
0005433036194	2139	Economy	11600.00
0005432749786	2139	Economy	11600.00
0005433036114	2139	Economy	11600.00
0005433036330	2139	Economy	11600.00
0005433035943	2139	Economy	11600.00
0005433924097	2139	Economy	11600.00
0005433924094	2139	Economy	11600.00
0005433924127	2139	Economy	11600.00
0005433036274	2139	Economy	11600.00
0005433924129	2139	Economy	11600.00
0005433924059	2139	Economy	11600.00
0005432231649	2139	Economy	11600.00
0005432044549	2139	Economy	11600.00
0005433924139	2139	Economy	11600.00
0005433924103	2139	Economy	11600.00
0005433924116	2139	Economy	11600.00
0005433924140	2139	Economy	11600.00
0005433924124	2139	Economy	11600.00
0005433036373	2139	Economy	11600.00
0005433924043	2139	Economy	11600.00
0005433924119	2139	Economy	11600.00
0005433924072	2139	Economy	11600.00
0005433924137	2139	Economy	11600.00
0005433036293	2139	Economy	11600.00
0005433036305	2139	Economy	11600.00
0005433924117	2139	Economy	11600.00
0005433924111	2139	Economy	11600.00
0005433924095	2139	Economy	11600.00
0005432231647	2139	Economy	11600.00
0005433036064	2139	Economy	11600.00
0005433036252	2139	Economy	11600.00
0005432231654	2139	Economy	11600.00
0005433924042	2139	Economy	11600.00
0005433924096	2139	Economy	11600.00
0005433924114	2139	Economy	11600.00
0005433924112	2139	Economy	11600.00
0005433924056	2139	Economy	11600.00
0005433924099	2139	Economy	11600.00
0005433036317	2139	Economy	11600.00
0005433924100	2139	Economy	11600.00
0005433924084	2139	Economy	11600.00
0005433036219	2139	Economy	11600.00
0005433924050	2139	Economy	11600.00
0005433924101	2139	Economy	11600.00
0005433924066	2139	Economy	11600.00
0005433036177	2139	Economy	11600.00
0005433036166	2139	Economy	11600.00
0005433036316	2139	Economy	11600.00
0005433036384	2139	Economy	11600.00
0005433924081	2139	Economy	11600.00
0005432044547	2139	Economy	11600.00
0005433924125	2139	Economy	11600.00
0005433036153	2139	Economy	11600.00
0005433924109	2139	Economy	11600.00
0005433924091	2139	Economy	11600.00
0005433924062	2139	Economy	11600.00
0005433036357	2139	Economy	11600.00
0005433924089	2139	Economy	11600.00
0005433924098	2139	Economy	11600.00
0005433924090	2139	Economy	11600.00
0005433036180	2139	Economy	11600.00
0005433036309	2139	Economy	11600.00
0005433922851	24121	Business	34700.00
0005433875372	24121	Business	34700.00
0005433923735	24121	Business	34700.00
0005433923543	24121	Business	34700.00
0005432206246	24121	Business	34700.00
0005433923284	24121	Business	34700.00
0005432207685	24121	Business	34700.00
0005433929857	24121	Business	34700.00
0005433923405	24121	Business	34700.00
0005433923375	24121	Business	34700.00
0005433923427	24121	Business	34700.00
0005433923163	24121	Business	34700.00
0005433036724	24121	Business	34700.00
0005433931470	24121	Business	34700.00
0005433922969	24121	Business	34700.00
0005433036708	24121	Business	34700.00
0005433036714	24121	Business	34700.00
0005433923734	24121	Business	34700.00
0005433036726	24121	Business	34700.00
0005433923282	24121	Business	34700.00
0005433923428	24121	Business	34700.00
0005433036710	24121	Business	34700.00
0005433923346	24121	Business	34700.00
0005433931466	24121	Business	34700.00
0005433036722	24121	Business	34700.00
0005433036728	24121	Business	34700.00
0005433922992	24121	Business	34700.00
0005433036746	24121	Economy	12700.00
0005433923290	24121	Business	34700.00
0005433036727	24121	Economy	12700.00
0005433923021	24121	Economy	12700.00
0005433923312	24121	Economy	11600.00
0005433922839	24121	Economy	11600.00
0005433036751	24121	Economy	11600.00
0005433923478	24121	Economy	11600.00
0005433923323	24121	Economy	11600.00
0005433036718	24121	Economy	11600.00
0005433923316	24121	Economy	11600.00
0005433036754	24121	Economy	11600.00
0005433036755	24121	Economy	11600.00
0005433036723	24121	Economy	11600.00
0005433036748	24121	Economy	11600.00
0005433923315	24121	Economy	11600.00
0005433036758	24121	Economy	11600.00
0005433036720	24121	Economy	11600.00
0005433922923	24121	Economy	11600.00
0005433929627	24121	Economy	11600.00
0005432749803	24121	Economy	11600.00
0005433929628	24121	Economy	11600.00
0005433922994	24121	Economy	11600.00
0005433036735	24121	Economy	11600.00
0005433923408	24121	Economy	11600.00
0005433036759	24121	Economy	11600.00
0005433923120	24121	Economy	11600.00
0005433923399	24121	Economy	11600.00
0005433923018	24121	Economy	11600.00
0005433036711	24121	Economy	11600.00
0005433923407	24121	Economy	11600.00
0005433923203	24121	Economy	11600.00
0005432206241	24121	Economy	11600.00
0005433922968	24121	Economy	11600.00
0005433923202	24121	Economy	11600.00
0005433922922	24121	Economy	11600.00
0005433036730	24121	Economy	11600.00
0005433036745	24121	Economy	11600.00
0005433923214	24121	Economy	11600.00
0005433036713	24121	Economy	11600.00
0005433923495	24121	Economy	11600.00
0005433923321	24121	Economy	11600.00
0005432749802	24121	Economy	11600.00
0005433923210	24121	Economy	11600.00
0005433923119	24121	Economy	11600.00
0005433875377	24121	Economy	11600.00
0005433923020	24121	Economy	11600.00
0005433922852	24121	Economy	11600.00
0005434028319	24121	Economy	11600.00
0005433036712	24121	Economy	11600.00
0005433923352	24121	Economy	11600.00
0005433036709	24121	Economy	11600.00
0005433875373	24121	Economy	11600.00
0005433923019	24121	Economy	11600.00
0005433036736	24121	Economy	11600.00
0005433036732	24121	Economy	11600.00
0005433923384	24121	Economy	11600.00
0005433036731	24121	Economy	11600.00
0005433036738	24121	Economy	11600.00
0005433923388	24121	Economy	11600.00
0005432207684	24121	Economy	11600.00
0005433036737	24121	Economy	11600.00
0005433923297	24121	Economy	11600.00
0005433923028	24121	Economy	11600.00
0005433923162	24121	Economy	11600.00
0005433036750	24121	Economy	11600.00
0005433923023	24121	Economy	11600.00
0005433923395	24121	Economy	11600.00
0005433922881	24121	Economy	11600.00
0005433931465	24121	Economy	11600.00
0005433036729	24121	Economy	11600.00
0005433923289	24121	Economy	11600.00
0005433922927	24121	Economy	11600.00
0005433036716	24121	Economy	11600.00
0005432206245	24121	Economy	11600.00
0005433036715	24121	Economy	11600.00
0005432749804	24121	Economy	11600.00
0005433036760	24121	Economy	11600.00
0005433923426	24121	Economy	11600.00
0005433923213	24121	Economy	11600.00
0005433036747	24121	Economy	11600.00
0005434028320	24121	Economy	11600.00
0005433923117	24121	Economy	12700.00
0005433923158	24121	Economy	11600.00
0005433923025	24121	Economy	12700.00
0005433922965	24121	Economy	11600.00
0005432206243	24121	Economy	12700.00
0005433922826	24121	Economy	12700.00
0005433931471	24121	Economy	11600.00
0005433923536	24121	Economy	11600.00
0005433036719	24121	Economy	11600.00
0005433922827	24121	Economy	11600.00
0005433036744	24121	Economy	11600.00
0005433922781	24121	Economy	11600.00
0005433923351	24121	Economy	11600.00
0005433923345	24121	Economy	11600.00
0005432206242	24121	Economy	11600.00
0005433923317	24121	Economy	11600.00
0005433923533	24121	Economy	11600.00
0005433922791	24121	Economy	11600.00
0005433036756	24121	Economy	11600.00
0005433923696	24121	Economy	11600.00
0005433923168	24121	Economy	11600.00
0005433036743	24121	Economy	11600.00
0005433929601	24121	Economy	11600.00
0005433923383	24121	Economy	11600.00
0005433923374	24121	Economy	11600.00
0005433931463	24121	Economy	11600.00
0005433923251	24121	Economy	11600.00
0005433923368	24121	Economy	11600.00
0005433036734	24121	Economy	11600.00
0005433036757	24121	Economy	11600.00
0005433036707	24121	Economy	11600.00
0005433923150	24121	Economy	11600.00
0005433923432	24121	Economy	11600.00
0005433923258	24121	Economy	11600.00
0005433922792	24121	Economy	11600.00
0005433923149	24121	Economy	11600.00
0005433036741	24121	Economy	11600.00
0005433036733	24121	Economy	11600.00
0005433923164	24121	Economy	11600.00
0005433923394	24121	Economy	11600.00
0005433923479	24121	Economy	11600.00
0005433923262	24121	Economy	11600.00
0005433036749	24121	Economy	11600.00
0005433923446	24121	Economy	11600.00
0005434028318	24121	Economy	11600.00
0005433923292	24121	Economy	11600.00
0005433923439	24121	Economy	11600.00
0005433923246	24121	Economy	11600.00
0005433923069	24121	Economy	11600.00
0005433923144	24121	Economy	11600.00
0005433923400	24121	Economy	11600.00
0005433036725	24121	Economy	11600.00
0005433922780	24121	Economy	11600.00
0005433036753	24121	Economy	11600.00
0005433923545	24121	Economy	11600.00
0005433923024	24121	Economy	11600.00
0005433036717	24121	Economy	11600.00
0005433036740	24121	Economy	11600.00
0005433036721	24121	Economy	11600.00
0005433923027	24121	Economy	11600.00
0005433923505	24121	Economy	11600.00
0005433036739	24121	Economy	11600.00
0005432206244	24121	Economy	11600.00
0005433036742	24121	Economy	11600.00
0005433923052	24121	Economy	11600.00
0005433036752	24121	Economy	11600.00
0005433923532	24121	Economy	11600.00
0005434028321	24121	Economy	11600.00
0005433929626	24121	Economy	11600.00
0005434726450	271	Business	83700.00
0005433234265	271	Business	83700.00
0005434726440	271	Business	83700.00
0005434726424	271	Business	83700.00
0005433234047	271	Business	83700.00
0005433234438	271	Business	83700.00
0005433234308	271	Business	83700.00
0005435142689	271	Business	83700.00
0005434726426	271	Business	83700.00
0005434551690	271	Business	83700.00
0005434726425	271	Business	83700.00
0005434731201	271	Business	83700.00
0005434726467	271	Business	83700.00
0005433233984	271	Business	83700.00
0005433234538	271	Business	83700.00
0005434726468	271	Business	83700.00
0005434551666	271	Business	83700.00
0005434551678	271	Business	83700.00
0005433234267	271	Business	83700.00
0005434726452	271	Business	83700.00
0005434726485	271	Business	83700.00
0005434551697	271	Business	83700.00
0005434726446	271	Business	83700.00
0005434726476	271	Business	83700.00
0005434735728	271	Business	83700.00
0005434302495	271	Business	83700.00
0005434726512	271	Comfort	47400.00
0005432277913	271	Comfort	47400.00
0005434551684	271	Comfort	47400.00
0005434726529	271	Comfort	47400.00
0005433234169	271	Comfort	47400.00
0005434726479	271	Comfort	47400.00
0005434726510	271	Comfort	47400.00
0005433181054	271	Comfort	47400.00
0005433181181	271	Comfort	47400.00
0005434551677	271	Comfort	47400.00
0005433234316	271	Comfort	47400.00
0005433111489	271	Comfort	47400.00
0005434551711	271	Comfort	47400.00
0005432277914	271	Comfort	47400.00
0005434726414	271	Comfort	47400.00
0005433234081	271	Comfort	47400.00
0005434551676	271	Comfort	47400.00
0005434726488	271	Comfort	47400.00
0005433234219	271	Comfort	47400.00
0005434726527	271	Comfort	47400.00
0005433131712	271	Comfort	47400.00
0005434551708	271	Comfort	47400.00
0005433181056	271	Comfort	47400.00
0005434302497	271	Comfort	47400.00
0005434302498	271	Comfort	47400.00
0005433181102	271	Comfort	47400.00
0005434726436	271	Comfort	47400.00
0005433234212	271	Comfort	47400.00
0005434551704	271	Comfort	47400.00
0005434551681	271	Comfort	47400.00
0005434726434	271	Comfort	47400.00
0005434726500	271	Comfort	47400.00
0005434726517	271	Comfort	47400.00
0005434735727	271	Comfort	47400.00
0005434726451	271	Comfort	47400.00
0005433233975	271	Comfort	47400.00
0005434726473	271	Economy	27900.00
0005433234420	271	Economy	27900.00
0005434726435	271	Economy	27900.00
0005434726486	271	Economy	27900.00
0005433234082	271	Economy	27900.00
0005434551709	271	Economy	27900.00
0005433233977	271	Economy	27900.00
0005434726439	271	Economy	27900.00
0005434726457	271	Economy	27900.00
0005434726532	271	Economy	27900.00
0005433234184	271	Economy	27900.00
0005434726432	271	Economy	27900.00
0005434726521	271	Economy	27900.00
0005434726460	271	Economy	27900.00
0005434726438	271	Economy	27900.00
0005434726506	271	Economy	27900.00
0005434726418	271	Economy	27900.00
0005433181103	271	Economy	27900.00
0005433181032	271	Economy	27900.00
0005434551660	271	Economy	27900.00
0005432277923	271	Economy	27900.00
0005435142694	271	Economy	27900.00
0005434551694	271	Economy	27900.00
0005435142691	271	Economy	27900.00
0005434551673	271	Economy	27900.00
0005434726480	271	Economy	27900.00
0005434726475	271	Economy	27900.00
0005432277921	271	Economy	27900.00
0005433113530	271	Economy	27900.00
0005434726490	271	Economy	27900.00
0005434551700	271	Economy	27900.00
0005434735729	271	Economy	27900.00
0005434735730	271	Economy	27900.00
0005434726493	271	Economy	27900.00
0005434726419	271	Economy	27900.00
0005434726433	271	Economy	27900.00
0005434726495	271	Economy	27900.00
0005434551710	271	Economy	27900.00
0005435142683	271	Economy	27900.00
0005434551658	271	Economy	27900.00
0005434726472	271	Economy	27900.00
0005433233989	271	Economy	27900.00
0005433126834	271	Economy	27900.00
0005433234107	271	Economy	27900.00
0005434726483	271	Economy	27900.00
0005434726441	271	Economy	27900.00
0005434731202	271	Economy	27900.00
0005435142690	271	Economy	27900.00
0005433234203	271	Economy	27900.00
0005434726470	271	Economy	27900.00
0005434726477	271	Economy	27900.00
0005433126814	271	Economy	27900.00
0005435142688	271	Economy	27900.00
0005434735725	271	Economy	27900.00
0005434551670	271	Economy	27900.00
0005433234009	271	Economy	27900.00
0005433126832	271	Economy	27900.00
0005434551701	271	Economy	27900.00
0005434726427	271	Economy	27900.00
0005434551695	271	Economy	27900.00
0005434551665	271	Economy	27900.00
0005434302496	271	Economy	30700.00
0005434731200	271	Economy	30700.00
0005434726513	271	Economy	30700.00
0005434726530	271	Economy	27900.00
0005433181091	271	Economy	30700.00
0005434726411	271	Economy	27900.00
0005433181009	271	Economy	30700.00
0005434731203	271	Economy	30700.00
0005434726413	271	Economy	27900.00
0005433234183	271	Economy	27900.00
0005434726449	271	Economy	27900.00
0005434551693	271	Economy	27900.00
0005433181189	271	Economy	27900.00
0005434551699	271	Economy	27900.00
0005434726423	271	Economy	27900.00
0005434726522	271	Economy	27900.00
0005434551712	271	Economy	27900.00
0005433181083	271	Economy	27900.00
0005433113529	271	Economy	27900.00
0005435142684	271	Economy	27900.00
0005434726528	271	Economy	27900.00
0005434726443	271	Economy	27900.00
0005434726421	271	Economy	27900.00
0005435142685	271	Economy	27900.00
0005434726459	271	Economy	27900.00
0005432277922	271	Economy	27900.00
0005433234125	271	Economy	27900.00
0005433234421	271	Economy	27900.00
0005434735726	271	Economy	27900.00
0005434726511	271	Economy	27900.00
0005432277915	271	Economy	27900.00
0005434726471	271	Economy	27900.00
0005434726428	271	Economy	27900.00
0005434551686	271	Economy	27900.00
0005434726507	271	Economy	27900.00
0005432277925	271	Economy	27900.00
0005433181152	271	Economy	27900.00
0005433181008	271	Economy	27900.00
0005434551685	271	Economy	27900.00
0005433234167	271	Economy	27900.00
0005433181179	271	Economy	27900.00
0005434726516	271	Economy	27900.00
0005433234207	271	Economy	27900.00
0005434726515	271	Economy	27900.00
0005433234391	271	Economy	27900.00
0005432277920	271	Economy	27900.00
0005433234218	271	Economy	27900.00
0005434551672	271	Economy	27900.00
0005433234330	271	Economy	27900.00
0005433234058	271	Economy	27900.00
0005433234196	271	Economy	27900.00
0005434726525	271	Economy	27900.00
0005433766642	271	Economy	27900.00
0005433126833	271	Economy	27900.00
0005434726526	271	Economy	27900.00
0005435142687	271	Economy	27900.00
0005433181163	271	Economy	27900.00
0005433234318	271	Economy	27900.00
0005434726417	271	Economy	27900.00
0005434551689	271	Economy	27900.00
0005434726456	271	Economy	27900.00
0005434726481	271	Economy	27900.00
0005433181140	271	Economy	27900.00
0005434726442	271	Economy	27900.00
0005433233974	271	Economy	27900.00
0005434726410	271	Economy	27900.00
0005433766617	271	Economy	27900.00
0005433234361	271	Economy	27900.00
0005434726484	271	Economy	27900.00
0005432277919	271	Economy	27900.00
0005434726503	271	Economy	27900.00
0005432277917	271	Economy	27900.00
0005433233988	271	Economy	27900.00
0005434551667	271	Economy	27900.00
0005434551687	271	Economy	27900.00
0005433234245	271	Economy	27900.00
0005432277916	271	Economy	27900.00
0005433234204	271	Economy	27900.00
0005434726444	271	Economy	27900.00
0005433180992	271	Economy	27900.00
0005434551674	271	Economy	27900.00
0005433234178	271	Economy	27900.00
0005434726458	271	Economy	27900.00
0005434726514	271	Economy	27900.00
0005434551706	271	Economy	27900.00
0005433234317	271	Economy	27900.00
0005433234331	271	Economy	27900.00
0005434302494	271	Economy	27900.00
0005434726524	271	Economy	27900.00
0005434726509	271	Economy	27900.00
0005433181141	271	Economy	27900.00
0005433766638	271	Economy	27900.00
0005435142695	271	Economy	27900.00
0005434726518	271	Economy	27900.00
0005434551662	271	Economy	27900.00
0005434726491	271	Economy	27900.00
0005434551688	271	Economy	27900.00
0005433234315	271	Economy	27900.00
0005434726494	271	Economy	27900.00
0005433234246	271	Economy	27900.00
0005435142692	271	Economy	27900.00
0005434726466	271	Economy	27900.00
0005433234329	271	Economy	27900.00
0005433766635	271	Economy	27900.00
0005434726422	271	Economy	27900.00
0005433234213	271	Economy	27900.00
0005434551696	271	Economy	27900.00
0005433234409	271	Economy	27900.00
0005434726489	271	Economy	27900.00
0005433289841	271	Economy	30700.00
0005433126820	271	Economy	30700.00
0005435142693	271	Economy	30700.00
0005434551682	271	Economy	30700.00
0005433131713	271	Economy	30700.00
0005434726453	271	Economy	30700.00
0005433289838	271	Economy	27900.00
0005434726531	271	Economy	27900.00
0005434726478	271	Economy	27900.00
0005432277924	271	Economy	27900.00
0005434726412	271	Economy	27900.00
0005434726464	271	Economy	27900.00
0005434726416	271	Economy	27900.00
0005434726437	271	Economy	27900.00
0005434726520	271	Economy	27900.00
0005433113534	271	Economy	27900.00
0005434551692	271	Economy	27900.00
0005434726523	271	Economy	27900.00
0005433234322	271	Economy	27900.00
0005434726415	271	Economy	27900.00
0005434551679	271	Economy	27900.00
0005433180993	271	Economy	27900.00
0005433234217	271	Economy	27900.00
0005434551668	271	Economy	27900.00
0005434551680	271	Economy	27900.00
0005434726463	271	Economy	27900.00
0005434726448	271	Economy	27900.00
0005433234197	271	Economy	27900.00
0005433234298	271	Economy	27900.00
0005434726455	271	Economy	27900.00
0005434726519	271	Economy	27900.00
0005434726508	271	Economy	27900.00
0005434726454	271	Economy	27900.00
0005434551707	271	Economy	27900.00
0005433233878	271	Economy	27900.00
0005433234299	271	Economy	27900.00
0005434551675	271	Economy	27900.00
0005433181090	271	Economy	27900.00
0005434302493	271	Economy	27900.00
0005434551671	271	Economy	27900.00
0005433234055	271	Economy	27900.00
0005434726502	271	Economy	27900.00
0005433181010	271	Economy	27900.00
0005434726474	271	Economy	27900.00
0005433234008	271	Economy	27900.00
0005434726462	271	Economy	27900.00
0005433234080	271	Economy	27900.00
0005434726430	271	Economy	27900.00
0005434551702	271	Economy	27900.00
0005434551663	271	Economy	27900.00
0005434726445	271	Economy	27900.00
0005433234067	271	Economy	27900.00
0005434551683	271	Economy	27900.00
0005434551664	271	Economy	27900.00
0005434726431	271	Economy	27900.00
0005433234323	271	Economy	27900.00
0005434726496	271	Economy	27900.00
0005434726498	271	Economy	27900.00
0005434726469	271	Economy	27900.00
0005434726492	271	Economy	27900.00
0005434551669	271	Economy	27900.00
0005433126821	271	Economy	27900.00
0005435142682	271	Economy	27900.00
0005434726420	271	Economy	27900.00
0005434551691	271	Economy	27900.00
0005434726504	271	Economy	27900.00
0005433234096	271	Economy	27900.00
0005434726501	271	Economy	27900.00
0005433234166	271	Economy	27900.00
0005433234220	271	Economy	27900.00
0005434551703	271	Economy	27900.00
0005432277918	271	Economy	27900.00
0005433234273	271	Economy	27900.00
0005434551705	271	Economy	27900.00
0005433181162	271	Economy	27900.00
0005434726487	271	Economy	27900.00
0005434726447	271	Economy	27900.00
0005434726499	271	Economy	27900.00
0005434726497	271	Economy	27900.00
0005434551698	271	Economy	27900.00
0005434726461	271	Economy	27900.00
0005433234244	271	Economy	27900.00
0005433181180	271	Economy	27900.00
0005434726429	271	Economy	27900.00
0005433181113	271	Economy	27900.00
0005435142686	271	Economy	27900.00
0005433126815	271	Economy	27900.00
0005434551661	271	Economy	27900.00
0005433234211	271	Economy	27900.00
0005434726505	271	Economy	27900.00
0005434726465	271	Economy	27900.00
0005434031974	271	Economy	27900.00
0005434551659	271	Economy	27900.00
0005434726482	271	Economy	27900.00
0005434725478	9818	Business	83700.00
0005433181302	9818	Business	83700.00
0005433234746	9818	Business	83700.00
0005434725641	9818	Business	83700.00
0005433129315	9818	Business	83700.00
0005433289903	9818	Business	83700.00
0005434725371	9818	Business	83700.00
0005434551110	9818	Business	83700.00
0005433126884	9818	Business	83700.00
0005434725008	9818	Business	83700.00
0005433234753	9818	Business	83700.00
0005433234738	9818	Business	83700.00
0005433181303	9818	Business	83700.00
0005434724860	9818	Business	83700.00
0005434725722	9818	Business	83700.00
0005434725144	9818	Business	83700.00
0005433234705	9818	Business	83700.00
0005434725727	9818	Business	83700.00
0005433181298	9818	Business	83700.00
0005434726030	9818	Business	83700.00
0005434551029	9818	Business	83700.00
0005434550949	9818	Business	83700.00
0005434551293	9818	Business	83700.00
0005433126881	9818	Comfort	47400.00
0005433181309	9818	Business	83700.00
0005434725451	9818	Comfort	47400.00
0005434551111	9818	Comfort	47400.00
0005434551024	9818	Comfort	47400.00
0005434725212	9818	Comfort	47400.00
0005434735661	9818	Comfort	47400.00
0005434725092	9818	Comfort	47400.00
0005434724961	9818	Comfort	47400.00
0005434725046	9818	Comfort	47400.00
0005434725343	9818	Comfort	47400.00
0005434550948	9818	Comfort	47400.00
0005433234752	9818	Comfort	47400.00
0005434725111	9818	Comfort	47400.00
0005434551288	9818	Comfort	47400.00
0005434550902	9818	Comfort	47400.00
0005433234720	9818	Comfort	47400.00
0005433234692	9818	Comfort	47400.00
0005434725275	9818	Comfort	47400.00
0005434724900	9818	Comfort	47400.00
0005433234723	9818	Comfort	47400.00
0005433234715	9818	Comfort	47400.00
0005434550737	9818	Comfort	47400.00
0005432199308	9818	Comfort	47400.00
0005433234696	9818	Comfort	47400.00
0005434032063	9818	Comfort	47400.00
0005434725642	9818	Comfort	47400.00
0005434725449	9818	Comfort	47400.00
0005433181312	9818	Comfort	47400.00
0005434724861	9818	Comfort	47400.00
0005434725239	9818	Comfort	47400.00
0005434725062	9818	Comfort	47400.00
0005434551168	9818	Comfort	47400.00
0005434551057	9818	Comfort	47400.00
0005433181305	9818	Comfort	47400.00
0005433129312	9818	Comfort	47400.00
0005435142585	9818	Comfort	47400.00
0005434725521	9818	Comfort	47400.00
0005434725462	9818	Comfort	47400.00
0005434551242	9818	Comfort	47400.00
0005433766673	9818	Comfort	47400.00
0005432199305	9818	Comfort	47400.00
0005433234730	9818	Comfort	47400.00
0005435142562	9818	Comfort	47400.00
0005434725294	9818	Economy	27900.00
0005433181314	9818	Economy	27900.00
0005434725297	9818	Economy	27900.00
0005434725671	9818	Economy	27900.00
0005433234749	9818	Economy	27900.00
0005434725491	9818	Economy	27900.00
0005433234690	9818	Economy	27900.00
0005435142582	9818	Economy	27900.00
0005434551473	9818	Economy	27900.00
0005433234722	9818	Economy	27900.00
0005434725699	9818	Economy	27900.00
0005434725214	9818	Economy	27900.00
0005434725736	9818	Economy	27900.00
0005434302440	9818	Economy	27900.00
0005435142584	9818	Economy	27900.00
0005433129314	9818	Economy	27900.00
0005434725696	9818	Economy	27900.00
0005434551055	9818	Economy	27900.00
0005434725450	9818	Economy	27900.00
0005433289907	9818	Economy	27900.00
0005434725267	9818	Economy	27900.00
0005434550890	9818	Economy	27900.00
0005434725508	9818	Economy	27900.00
0005433234701	9818	Economy	27900.00
0005434551056	9818	Economy	27900.00
0005434725009	9818	Economy	27900.00
0005433181313	9818	Economy	27900.00
0005434551300	9818	Economy	27900.00
0005434725149	9818	Economy	27900.00
0005433181296	9818	Economy	27900.00
0005434551186	9818	Economy	27900.00
0005433234727	9818	Economy	27900.00
0005434032061	9818	Economy	27900.00
0005434725254	9818	Economy	27900.00
0005434725433	9818	Economy	27900.00
0005434725723	9818	Economy	27900.00
0005433289904	9818	Economy	27900.00
0005433181318	9818	Economy	27900.00
0005434551243	9818	Economy	27900.00
0005434735670	9818	Economy	27900.00
0005434725490	9818	Economy	27900.00
0005433234736	9818	Economy	27900.00
0005433234694	9818	Economy	27900.00
0005434725374	9818	Economy	27900.00
0005434725793	9818	Economy	27900.00
0005434725506	9818	Economy	27900.00
0005434725674	9818	Economy	27900.00
0005433181304	9818	Economy	27900.00
0005433181315	9818	Economy	27900.00
0005434551120	9818	Economy	27900.00
0005435142517	9818	Economy	27900.00
0005434725193	9818	Economy	27900.00
0005433234729	9818	Economy	27900.00
0005434725735	9818	Economy	27900.00
0005434724928	9818	Economy	27900.00
0005434725768	9818	Economy	27900.00
0005434551335	9818	Economy	27900.00
0005434551187	9818	Economy	27900.00
0005434725694	9818	Economy	27900.00
0005433181297	9818	Economy	30700.00
0005434725887	9818	Economy	30700.00
0005434725794	9818	Economy	27900.00
0005434724974	9818	Economy	27900.00
0005434725673	9818	Economy	27900.00
0005434551317	9818	Economy	30700.00
0005433234731	9818	Economy	30700.00
0005433234702	9818	Economy	30700.00
0005433234735	9818	Economy	27900.00
0005434725541	9818	Economy	27900.00
0005433126882	9818	Economy	27900.00
0005433113554	9818	Economy	27900.00
0005434725767	9818	Economy	27900.00
0005433234706	9818	Economy	27900.00
0005433126883	9818	Economy	27900.00
0005432199306	9818	Economy	27900.00
0005434725571	9818	Economy	27900.00
0005433181307	9818	Economy	27900.00
0005433766671	9818	Economy	27900.00
0005434725430	9818	Economy	27900.00
0005433234718	9818	Economy	27900.00
0005434725414	9818	Economy	27900.00
0005433234710	9818	Economy	27900.00
0005434725453	9818	Economy	27900.00
0005434551030	9818	Economy	27900.00
0005433766670	9818	Economy	27900.00
0005434725061	9818	Economy	27900.00
0005435142534	9818	Economy	27900.00
0005435142535	9818	Economy	27900.00
0005434725807	9818	Economy	27900.00
0005434731171	9818	Economy	27900.00
0005434725652	9818	Economy	27900.00
0005433234709	9818	Economy	27900.00
0005434551261	9818	Economy	27900.00
0005433289910	9818	Economy	27900.00
0005433234742	9818	Economy	27900.00
0005434550969	9818	Economy	27900.00
0005434725604	9818	Economy	27900.00
0005434551069	9818	Economy	27900.00
0005434725250	9818	Economy	27900.00
0005433234700	9818	Economy	27900.00
0005434032062	9818	Economy	27900.00
0005434725317	9818	Economy	27900.00
0005434725535	9818	Economy	27900.00
0005434550970	9818	Economy	27900.00
0005434551008	9818	Economy	27900.00
0005434725110	9818	Economy	27900.00
0005434725329	9818	Economy	27900.00
0005434551231	9818	Economy	27900.00
0005433289906	9818	Economy	27900.00
0005434735680	9818	Economy	27900.00
0005434725520	9818	Economy	27900.00
0005434725798	9818	Economy	27900.00
0005434725454	9818	Economy	27900.00
0005434551264	9818	Economy	27900.00
0005433234724	9818	Economy	27900.00
0005433234737	9818	Economy	27900.00
0005434725176	9818	Economy	27900.00
0005434724935	9818	Economy	27900.00
0005434551169	9818	Economy	27900.00
0005434551185	9818	Economy	27900.00
0005434724765	9818	Economy	27900.00
0005433181300	9818	Economy	27900.00
0005433234704	9818	Economy	27900.00
0005434032064	9818	Economy	27900.00
0005434551265	9818	Economy	27900.00
0005433181308	9818	Economy	27900.00
0005434551393	9818	Economy	27900.00
0005433766672	9818	Economy	27900.00
0005434731168	9818	Economy	27900.00
0005434731167	9818	Economy	27900.00
0005434725507	9818	Economy	27900.00
0005433234740	9818	Economy	27900.00
0005433234743	9818	Economy	27900.00
0005434735662	9818	Economy	27900.00
0005435142558	9818	Economy	27900.00
0005434725315	9818	Economy	27900.00
0005433234712	9818	Economy	27900.00
0005434551065	9818	Economy	27900.00
0005434725301	9818	Economy	27900.00
0005433234750	9818	Economy	27900.00
0005434551046	9818	Economy	27900.00
0005434302439	9818	Economy	27900.00
0005435142515	9818	Economy	27900.00
0005434725213	9818	Economy	27900.00
0005433234716	9818	Economy	27900.00
0005434725224	9818	Economy	27900.00
0005434725064	9818	Economy	27900.00
0005434725523	9818	Economy	27900.00
0005432199303	9818	Economy	27900.00
0005434725262	9818	Economy	27900.00
0005434725581	9818	Economy	27900.00
0005433181301	9818	Economy	27900.00
0005433234713	9818	Economy	27900.00
0005433234703	9818	Economy	27900.00
0005433181317	9818	Economy	27900.00
0005434725435	9818	Economy	27900.00
0005433234697	9818	Economy	27900.00
0005434725192	9818	Economy	27900.00
0005434551031	9818	Economy	27900.00
0005433234695	9818	Economy	27900.00
0005434550905	9818	Economy	30700.00
0005434725461	9818	Economy	27900.00
0005433181310	9818	Economy	30700.00
0005433234734	9818	Economy	30700.00
0005434725888	9818	Economy	30700.00
0005433234739	9818	Economy	30700.00
0005433234725	9818	Economy	27900.00
0005434725593	9818	Economy	27900.00
0005434551266	9818	Economy	27900.00
0005434725542	9818	Economy	27900.00
0005434551101	9818	Economy	27900.00
0005434725719	9818	Economy	27900.00
0005433234748	9818	Economy	27900.00
0005434551121	9818	Economy	27900.00
0005433234691	9818	Economy	27900.00
0005434725391	9818	Economy	27900.00
0005432199304	9818	Economy	27900.00
0005434725065	9818	Economy	27900.00
0005432199302	9818	Economy	27900.00
0005434725247	9818	Economy	27900.00
0005434724983	9818	Economy	27900.00
0005434725573	9818	Economy	27900.00
0005434551047	9818	Economy	27900.00
0005433181306	9818	Economy	27900.00
0005434725373	9818	Economy	27900.00
0005433126880	9818	Economy	27900.00
0005433234721	9818	Economy	27900.00
0005434725653	9818	Economy	27900.00
0005433234733	9818	Economy	27900.00
0005434551336	9818	Economy	27900.00
0005433289908	9818	Economy	27900.00
0005433234711	9818	Economy	27900.00
0005434550867	9818	Economy	27900.00
0005434725480	9818	Economy	27900.00
0005434032065	9818	Economy	27900.00
0005433234707	9818	Economy	27900.00
0005434551188	9818	Economy	27900.00
0005434725108	9818	Economy	27900.00
0005434725274	9818	Economy	27900.00
0005434725118	9818	Economy	27900.00
0005434725091	9818	Economy	27900.00
0005434725266	9818	Economy	27900.00
0005433129311	9818	Economy	27900.00
0005434551334	9818	Economy	27900.00
0005433234732	9818	Economy	27900.00
0005434725135	9818	Economy	27900.00
0005434725330	9818	Economy	27900.00
0005433129313	9818	Economy	27900.00
0005433234754	9818	Economy	27900.00
0005434725225	9818	Economy	27900.00
0005433234747	9818	Economy	27900.00
0005433181316	9818	Economy	27900.00
0005433234728	9818	Economy	27900.00
0005434551429	9818	Economy	27900.00
0005433289905	9818	Economy	27900.00
0005434725892	9818	Economy	27900.00
0005434725638	9818	Economy	27900.00
0005434731172	9818	Economy	27900.00
0005434725637	9818	Economy	27900.00
0005434551119	9818	Economy	27900.00
0005433234693	9818	Economy	27900.00
0005435142561	9818	Economy	27900.00
0005433234741	9818	Economy	27900.00
0005433234719	9818	Economy	27900.00
0005434725123	9818	Economy	27900.00
0005433234751	9818	Economy	27900.00
0005434724962	9818	Economy	27900.00
0005433234745	9818	Economy	27900.00
0005434551017	9818	Economy	27900.00
0005434725485	9818	Economy	27900.00
0005434725479	9818	Economy	27900.00
0005433234698	9818	Economy	27900.00
0005435142516	9818	Economy	27900.00
0005433234726	9818	Economy	27900.00
0005433181311	9818	Economy	27900.00
0005433289902	9818	Economy	27900.00
0005433181319	9818	Economy	27900.00
0005434735669	9818	Economy	27900.00
0005434725300	9818	Economy	27900.00
0005434725724	9818	Economy	27900.00
0005434725334	9818	Economy	27900.00
0005434731160	9818	Economy	27900.00
0005434725586	9818	Economy	27900.00
0005433234708	9818	Economy	27900.00
0005433289909	9818	Economy	27900.00
0005434551292	9818	Economy	27900.00
0005433234744	9818	Economy	27900.00
0005434725431	9818	Economy	27900.00
0005433234717	9818	Economy	27900.00
0005434551028	9818	Economy	27900.00
0005434551316	9818	Economy	27900.00
0005434551241	9818	Economy	27900.00
0005434725316	9818	Economy	27900.00
0005433234699	9818	Economy	27900.00
0005432199307	9818	Economy	27900.00
0005434725598	9818	Economy	27900.00
0005434724925	9818	Economy	27900.00
0005434725432	9818	Economy	27900.00
0005433234714	9818	Economy	27900.00
0005434724892	9818	Economy	27900.00
0005433181299	9818	Economy	27900.00
0005432533315	7748	Business	42100.00
0005432529072	7748	Business	42100.00
0005432529108	7748	Business	42100.00
0005435213276	7748	Business	42100.00
0005435213363	7748	Business	42100.00
0005435213739	7748	Business	42100.00
0005435213651	7748	Business	42100.00
0005432069775	7748	Business	42100.00
0005432529103	7748	Business	42100.00
0005435213870	7748	Business	42100.00
0005434068153	7748	Business	42100.00
0005432529051	7748	Business	42100.00
0005432529106	7748	Business	42100.00
0005434068165	7748	Business	42100.00
0005435213657	7748	Business	42100.00
0005432529005	7748	Business	42100.00
0005434068167	7748	Business	42100.00
0005434068131	7748	Business	42100.00
0005432529067	7748	Business	42100.00
0005432529104	7748	Business	42100.00
0005432528994	7748	Business	42100.00
0005434068160	7748	Business	42100.00
0005432528999	7748	Business	42100.00
0005434068117	7748	Business	42100.00
0005434068112	7748	Business	42100.00
0005432529118	7748	Comfort	23900.00
0005434068155	7748	Business	42100.00
0005432529032	7748	Comfort	23900.00
0005432529063	7748	Comfort	23900.00
0005434068140	7748	Comfort	23900.00
0005432069779	7748	Comfort	23900.00
0005432529041	7748	Comfort	23900.00
0005434068137	7748	Comfort	23900.00
0005432529029	7748	Comfort	23900.00
0005432529115	7748	Comfort	23900.00
0005432069772	7748	Comfort	23900.00
0005432069781	7748	Comfort	23900.00
0005432529052	7748	Comfort	23900.00
0005434068182	7748	Comfort	23900.00
0005432529037	7748	Comfort	23900.00
0005432150261	7748	Comfort	23900.00
0005432529112	7748	Comfort	23900.00
0005435213388	7748	Comfort	23900.00
0005435213489	7748	Comfort	23900.00
0005435213447	7748	Comfort	23900.00
0005435213649	7748	Comfort	23900.00
0005432529074	7748	Comfort	23900.00
0005434068169	7748	Comfort	23900.00
0005432069774	7748	Comfort	23900.00
0005435213339	7748	Comfort	23900.00
0005434068130	7748	Comfort	23900.00
0005432529070	7748	Comfort	23900.00
0005432529113	7748	Comfort	23900.00
0005432533316	7748	Comfort	23900.00
0005432428955	7748	Comfort	23900.00
0005435213476	7748	Comfort	23900.00
0005432529028	7748	Comfort	23900.00
0005435213572	7748	Comfort	23900.00
0005432529100	7748	Comfort	23900.00
0005432533314	7748	Comfort	23900.00
0005432529062	7748	Comfort	23900.00
0005434068173	7748	Comfort	23900.00
0005435725579	7748	Comfort	23900.00
0005432069776	7748	Comfort	23900.00
0005435213477	7748	Economy	14000.00
0005434068157	7748	Comfort	23900.00
0005432529061	7748	Economy	14000.00
0005432150255	7748	Economy	14000.00
0005432069771	7748	Economy	14000.00
0005435213335	7748	Economy	14000.00
0005432529095	7748	Economy	14000.00
0005432529057	7748	Economy	14000.00
0005432529059	7748	Economy	14000.00
0005434068150	7748	Economy	14000.00
0005435725581	7748	Economy	14000.00
0005435213558	7748	Economy	14000.00
0005432069777	7748	Economy	14000.00
0005435213672	7748	Economy	14000.00
0005432428957	7748	Economy	14000.00
0005432529043	7748	Economy	14000.00
0005435213286	7748	Economy	14000.00
0005435213647	7748	Economy	14000.00
0005432529034	7748	Economy	14000.00
0005435213480	7748	Economy	14000.00
0005434068149	7748	Economy	14000.00
0005434068143	7748	Economy	14000.00
0005434068146	7748	Economy	14000.00
0005432529003	7748	Economy	14000.00
0005432529099	7748	Economy	14000.00
0005432529015	7748	Economy	14000.00
0005432529033	7748	Economy	14000.00
0005432529024	7748	Economy	14000.00
0005434068180	7748	Economy	14000.00
0005432069778	7748	Economy	14000.00
0005434068128	7748	Economy	14000.00
0005435725569	7748	Economy	14000.00
0005435213856	7748	Economy	14000.00
0005434068158	7748	Economy	14000.00
0005434068177	7748	Economy	14000.00
0005432529086	7748	Economy	14000.00
0005432535872	7748	Economy	14000.00
0005432529045	7748	Economy	14000.00
0005432529111	7748	Economy	14000.00
0005434068148	7748	Economy	14000.00
0005435213542	7748	Economy	14000.00
0005432529035	7748	Economy	14000.00
0005435213445	7748	Economy	14000.00
0005434068136	7748	Economy	14000.00
0005432529069	7748	Economy	14000.00
0005432535874	7748	Economy	14000.00
0005432529004	7748	Economy	14000.00
0005434068175	7748	Economy	14000.00
0005435213418	7748	Economy	14000.00
0005432150262	7748	Economy	14000.00
0005432529109	7748	Economy	14000.00
0005435213612	7748	Economy	14000.00
0005434068126	7748	Economy	14000.00
0005432529027	7748	Economy	14000.00
0005432150257	7748	Economy	14000.00
0005432069773	7748	Economy	14000.00
0005432529083	7748	Economy	14000.00
0005432529119	7748	Economy	14000.00
0005432529008	7748	Economy	14000.00
0005435213636	7748	Economy	14000.00
0005432528990	7748	Economy	15400.00
0005435213602	7748	Economy	15400.00
0005434068133	7748	Economy	14000.00
0005434068174	7748	Economy	15400.00
0005432529105	7748	Economy	14000.00
0005435213397	7748	Economy	14000.00
0005435725580	7748	Economy	14000.00
0005434068176	7748	Economy	15400.00
0005432529036	7748	Economy	14000.00
0005434068111	7748	Economy	14000.00
0005432535875	7748	Economy	14000.00
0005435213570	7748	Economy	14000.00
0005432537074	7748	Economy	14000.00
0005435630961	7748	Economy	14000.00
0005435213417	7748	Economy	14000.00
0005434068138	7748	Economy	14000.00
0005432529040	7748	Economy	14000.00
0005432529022	7748	Economy	14000.00
0005432529096	7748	Economy	14000.00
0005432529011	7748	Economy	14000.00
0005432529101	7748	Economy	14000.00
0005434068116	7748	Economy	14000.00
0005432529006	7748	Economy	14000.00
0005435630960	7748	Economy	14000.00
0005432529010	7748	Economy	14000.00
0005435213511	7748	Economy	14000.00
0005432528995	7748	Economy	14000.00
0005434068127	7748	Economy	14000.00
0005434068124	7748	Economy	14000.00
0005434068170	7748	Economy	14000.00
0005432529023	7748	Economy	14000.00
0005435213868	7748	Economy	14000.00
0005432529060	7748	Economy	14000.00
0005432529087	7748	Economy	14000.00
0005432535873	7748	Economy	14000.00
0005434068179	7748	Economy	14000.00
0005432069782	7748	Economy	14000.00
0005432069767	7748	Economy	14000.00
0005432529044	7748	Economy	14000.00
0005432529050	7748	Economy	14000.00
0005432069768	7748	Economy	14000.00
0005434068134	7748	Economy	14000.00
0005434068123	7748	Economy	14000.00
0005432529121	7748	Economy	14000.00
0005432529110	7748	Economy	14000.00
0005435213463	7748	Economy	14000.00
0005432529094	7748	Economy	14000.00
0005435213493	7748	Economy	14000.00
0005432529079	7748	Economy	14000.00
0005432529047	7748	Economy	14000.00
0005432537075	7748	Economy	14000.00
0005432529056	7748	Economy	14000.00
0005435213573	7748	Economy	14000.00
0005435213429	7748	Economy	14000.00
0005432529117	7748	Economy	14000.00
0005432529085	7748	Economy	14000.00
0005432529107	7748	Economy	14000.00
0005432529102	7748	Economy	14000.00
0005432528998	7748	Economy	14000.00
0005435213488	7748	Economy	14000.00
0005434068161	7748	Economy	14000.00
0005435213336	7748	Economy	14000.00
0005435213318	7748	Economy	14000.00
0005432529025	7748	Economy	14000.00
0005435213487	7748	Economy	14000.00
0005432529089	7748	Economy	14000.00
0005435213341	7748	Economy	14000.00
0005434068120	7748	Economy	14000.00
0005434068110	7748	Economy	14000.00
0005433656671	7748	Economy	14000.00
0005435725586	7748	Economy	14000.00
0005432529091	7748	Economy	14000.00
0005432529001	7748	Economy	14000.00
0005434068154	7748	Economy	14000.00
0005435213117	7748	Economy	14000.00
0005432529007	7748	Economy	14000.00
0005434068118	7748	Economy	14000.00
0005435213446	7748	Economy	14000.00
0005435213398	7748	Economy	14000.00
0005432528989	7748	Economy	14000.00
0005432529098	7748	Economy	14000.00
0005435213583	7748	Economy	14000.00
0005432529046	7748	Economy	14000.00
0005435213449	7748	Economy	14000.00
0005435213857	7748	Economy	14000.00
0005432428956	7748	Economy	14000.00
0005435213585	7748	Economy	14000.00
0005434068139	7748	Economy	14000.00
0005432529039	7748	Economy	14000.00
0005432529081	7748	Economy	14000.00
0005432529068	7748	Economy	14000.00
0005434068141	7748	Economy	14000.00
0005432529073	7748	Economy	14000.00
0005434068142	7748	Economy	14000.00
0005434068144	7748	Economy	14000.00
0005434068125	7748	Economy	15400.00
0005432529030	7748	Economy	14000.00
0005432529031	7748	Economy	15400.00
0005432529092	7748	Economy	15400.00
0005432529054	7748	Economy	15400.00
0005435213534	7748	Economy	15400.00
0005432528991	7748	Economy	14000.00
0005432529049	7748	Economy	15400.00
0005432069769	7748	Economy	14000.00
0005432529038	7748	Economy	14000.00
0005432529058	7748	Economy	14000.00
0005434068163	7748	Economy	14000.00
0005432529014	7748	Economy	14000.00
0005432529090	7748	Economy	14000.00
0005434068152	7748	Economy	14000.00
0005435213620	7748	Economy	14000.00
0005435213571	7748	Economy	14000.00
0005432150263	7748	Economy	14000.00
0005432529055	7748	Economy	14000.00
0005432150256	7748	Economy	14000.00
0005432529114	7748	Economy	14000.00
0005435213497	7748	Economy	14000.00
0005432529021	7748	Economy	14000.00
0005435213374	7748	Economy	14000.00
0005434068159	7748	Economy	14000.00
0005434068129	7748	Economy	14000.00
0005432150259	7748	Economy	14000.00
0005434068121	7748	Economy	14000.00
0005434068122	7748	Economy	14000.00
0005432150260	7748	Economy	14000.00
0005432529000	7748	Economy	14000.00
0005434068151	7748	Economy	14000.00
0005432529120	7748	Economy	14000.00
0005432528997	7748	Economy	14000.00
0005432529076	7748	Economy	14000.00
0005432529020	7748	Economy	14000.00
0005432529071	7748	Economy	14000.00
0005432528992	7748	Economy	14000.00
0005434068172	7748	Economy	14000.00
0005432528988	7748	Economy	14000.00
0005432529016	7748	Economy	14000.00
0005434068132	7748	Economy	14000.00
0005432529088	7748	Economy	14000.00
0005434068113	7748	Economy	14000.00
0005435213496	7748	Economy	14000.00
0005435213586	7748	Economy	14000.00
0005434068115	7748	Economy	14000.00
0005435213411	7748	Economy	14000.00
0005434068168	7748	Economy	14000.00
0005432529116	7748	Economy	14000.00
0005432529082	7748	Economy	14000.00
0005432529065	7748	Economy	14000.00
0005432529042	7748	Economy	14000.00
0005434068147	7748	Economy	14000.00
0005432529048	7748	Economy	14000.00
0005432528996	7748	Economy	14000.00
0005432529075	7748	Economy	14000.00
0005434068114	7748	Economy	14000.00
0005432529002	7748	Economy	14000.00
0005432529093	7748	Economy	14000.00
0005432529078	7748	Economy	14000.00
0005434068119	7748	Economy	14000.00
0005432428958	7748	Economy	14000.00
0005435213559	7748	Economy	14000.00
0005434068178	7748	Economy	14000.00
0005435212955	7748	Economy	14000.00
0005435213648	7748	Economy	14000.00
0005434068166	7748	Economy	14000.00
0005432069770	7748	Economy	14000.00
0005435213541	7748	Economy	14000.00
0005435213584	7748	Economy	14000.00
0005432529017	7748	Economy	14000.00
0005434068162	7748	Economy	14000.00
0005432529026	7748	Economy	14000.00
0005432529084	7748	Economy	14000.00
0005435213464	7748	Economy	14000.00
0005432529019	7748	Economy	14000.00
0005435213234	7748	Economy	14000.00
0005432529018	7748	Economy	14000.00
0005435213656	7748	Economy	14000.00
0005432529077	7748	Economy	14000.00
0005432529053	7748	Economy	14000.00
0005435213869	7748	Economy	14000.00
0005432529080	7748	Economy	14000.00
0005432529013	7748	Economy	14000.00
0005434068145	7748	Economy	14000.00
0005434068171	7748	Economy	14000.00
0005432529009	7748	Economy	14000.00
0005432069780	7748	Economy	14000.00
0005434068156	7748	Economy	14000.00
0005432150258	7748	Economy	14000.00
0005432529066	7748	Economy	14000.00
0005432529097	7748	Economy	14000.00
0005432529012	7748	Economy	14000.00
0005434068135	7748	Economy	14000.00
0005435213428	7748	Economy	14000.00
0005432528993	7748	Economy	14000.00
0005435213682	7748	Economy	14000.00
0005435213615	7748	Economy	14000.00
0005434068164	7748	Economy	14000.00
0005432529064	7748	Economy	14000.00
0005434068181	7748	Economy	14000.00
0005435614581	5321	Business	43100.00
0005434244888	5321	Business	43100.00
0005434344520	5321	Business	43100.00
0005435425076	5321	Business	43100.00
0005434344522	5321	Business	43100.00
0005432841010	5321	Business	43100.00
0005435424845	5321	Business	43100.00
0005435614606	5321	Business	43100.00
0005435614590	5321	Business	43100.00
0005435424964	5321	Business	43100.00
0005432133341	5321	Business	43100.00
0005435614559	5321	Business	43100.00
0005435614532	5321	Business	43100.00
0005432363409	5321	Business	43100.00
0005435302220	5321	Business	43100.00
0005435424962	5321	Business	43100.00
0005434344501	5321	Business	43100.00
0005435424877	5321	Business	43100.00
0005435424853	5321	Business	43100.00
0005434656559	5321	Business	43100.00
0005434573476	5321	Comfort	24400.00
0005435614616	5321	Comfort	24400.00
0005435614571	5321	Comfort	24400.00
0005432133331	5321	Comfort	24400.00
0005435425021	5321	Comfort	24400.00
0005435614588	5321	Comfort	24400.00
0005432133339	5321	Comfort	24400.00
0005434344518	5321	Comfort	24400.00
0005435614531	5321	Comfort	24400.00
0005434344528	5321	Comfort	24400.00
0005435319620	5321	Comfort	24400.00
0005435614570	5321	Comfort	24400.00
0005434244911	5321	Comfort	24400.00
0005435319619	5321	Comfort	24400.00
0005432841008	5321	Comfort	24400.00
0005434573470	5321	Comfort	24400.00
0005435614533	5321	Comfort	24400.00
0005434244957	5321	Comfort	24400.00
0005434573469	5321	Comfort	24400.00
0005435424926	5321	Comfort	24400.00
0005434244921	5321	Comfort	24400.00
0005435614535	5321	Comfort	24400.00
0005435380298	5321	Comfort	24400.00
0005435424680	5321	Comfort	24400.00
0005435424860	5321	Comfort	24400.00
0005435614622	5321	Comfort	24400.00
0005435097285	5321	Comfort	24400.00
0005435614560	5321	Comfort	24400.00
0005434344513	5321	Comfort	24400.00
0005435614596	5321	Comfort	24400.00
0005435424835	5321	Comfort	24400.00
0005435302214	5321	Comfort	24400.00
0005435424694	5321	Comfort	24400.00
0005434573474	5321	Comfort	24400.00
0005434244850	5321	Comfort	24400.00
0005435614575	5321	Comfort	24400.00
0005435614595	5321	Comfort	24400.00
0005435614541	5321	Comfort	24400.00
0005434344526	5321	Comfort	24400.00
0005434573473	5321	Economy	14400.00
0005435424830	5321	Comfort	24400.00
0005434244880	5321	Economy	14400.00
0005435424966	5321	Economy	14400.00
0005435614573	5321	Economy	14400.00
0005435614542	5321	Economy	14400.00
0005435424891	5321	Economy	14400.00
0005432133336	5321	Economy	14400.00
0005434344516	5321	Economy	14400.00
0005435614547	5321	Economy	14400.00
0005432047581	5321	Economy	14400.00
0005435424844	5321	Economy	14400.00
0005434244877	5321	Economy	14400.00
0005434573467	5321	Economy	14400.00
0005432047583	5321	Economy	14400.00
0005435614566	5321	Economy	14400.00
0005432133334	5321	Economy	14400.00
0005435424611	5321	Economy	14400.00
0005432047582	5321	Economy	14400.00
0005435614613	5321	Economy	14400.00
0005434344514	5321	Economy	14400.00
0005434244912	5321	Economy	14400.00
0005435424958	5321	Economy	14400.00
0005433719145	5321	Economy	14400.00
0005434244887	5321	Economy	14400.00
0005435097282	5321	Economy	14400.00
0005435614580	5321	Economy	14400.00
0005434244831	5321	Economy	14400.00
0005435614565	5321	Economy	14400.00
0005434344524	5321	Economy	14400.00
0005435319587	5321	Economy	14400.00
0005435319617	5321	Economy	14400.00
0005435490259	5321	Economy	14400.00
0005435614552	5321	Economy	14400.00
0005435424641	5321	Economy	14400.00
0005435425042	5321	Economy	14400.00
0005435614608	5321	Economy	14400.00
0005435097281	5321	Economy	14400.00
0005435614554	5321	Economy	14400.00
0005434344508	5321	Economy	14400.00
0005432133332	5321	Economy	14400.00
0005434573468	5321	Economy	14400.00
0005435424925	5321	Economy	14400.00
0005434344519	5321	Economy	14400.00
0005435425075	5321	Economy	14400.00
0005435425010	5321	Economy	14400.00
0005435424892	5321	Economy	14400.00
0005435614603	5321	Economy	14400.00
0005434244998	5321	Economy	14400.00
0005434344507	5321	Economy	14400.00
0005435424911	5321	Economy	14400.00
0005435614539	5321	Economy	14400.00
0005435614589	5321	Economy	14400.00
0005434656550	5321	Economy	14400.00
0005432133330	5321	Economy	14400.00
0005435302173	5321	Economy	14400.00
0005434656551	5321	Economy	14400.00
0005432133329	5321	Economy	14400.00
0005435555387	5321	Economy	14400.00
0005434344515	5321	Economy	14400.00
0005435614562	5321	Economy	15800.00
0005435380305	5321	Economy	15800.00
0005435424960	5321	Economy	14400.00
0005435614567	5321	Economy	14400.00
0005435614540	5321	Economy	14400.00
0005435425046	5321	Economy	14400.00
0005435614601	5321	Economy	15800.00
0005435097289	5321	Economy	15800.00
0005435425036	5321	Economy	14400.00
0005435424795	5321	Economy	15800.00
0005434573462	5321	Economy	14400.00
0005435614563	5321	Economy	14400.00
0005435614537	5321	Economy	14400.00
0005435614605	5321	Economy	14400.00
0005435614550	5321	Economy	14400.00
0005435614548	5321	Economy	14400.00
0005435614568	5321	Economy	14400.00
0005435425101	5321	Economy	14400.00
0005435614556	5321	Economy	14400.00
0005435424908	5321	Economy	14400.00
0005435424587	5321	Economy	14400.00
0005434344510	5321	Economy	14400.00
0005435302196	5321	Economy	14400.00
0005435424981	5321	Economy	14400.00
0005435614583	5321	Economy	14400.00
0005435614593	5321	Economy	14400.00
0005435614577	5321	Economy	14400.00
0005435097283	5321	Economy	14400.00
0005435614549	5321	Economy	14400.00
0005435614572	5321	Economy	14400.00
0005434344503	5321	Economy	14400.00
0005435302210	5321	Economy	14400.00
0005435614614	5321	Economy	14400.00
0005435614620	5321	Economy	14400.00
0005435614551	5321	Economy	14400.00
0005434344529	5321	Economy	14400.00
0005435424913	5321	Economy	14400.00
0005434244959	5321	Economy	14400.00
0005432363399	5321	Economy	14400.00
0005434573471	5321	Economy	14400.00
0005432133342	5321	Economy	14400.00
0005434344512	5321	Economy	14400.00
0005434573466	5321	Economy	14400.00
0005435424912	5321	Economy	14400.00
0005432363415	5321	Economy	14400.00
0005432133335	5321	Economy	14400.00
0005432047580	5321	Economy	14400.00
0005435305013	5321	Economy	14400.00
0005435302215	5321	Economy	14400.00
0005435614604	5321	Economy	14400.00
0005434244864	5321	Economy	14400.00
0005435424909	5321	Economy	14400.00
0005434344521	5321	Economy	14400.00
0005435424841	5321	Economy	14400.00
0005435614569	5321	Economy	14400.00
0005435555386	5321	Economy	14400.00
0005435424959	5321	Economy	14400.00
0005435319588	5321	Economy	14400.00
0005434244970	5321	Economy	14400.00
0005435425069	5321	Economy	14400.00
0005432363398	5321	Economy	14400.00
0005434244842	5321	Economy	14400.00
0005435302195	5321	Economy	14400.00
0005435614624	5321	Economy	14400.00
0005435614597	5321	Economy	14400.00
0005435614599	5321	Economy	14400.00
0005434344506	5321	Economy	14400.00
0005435614576	5321	Economy	14400.00
0005432133338	5321	Economy	14400.00
0005435614607	5321	Economy	14400.00
0005435302194	5321	Economy	14400.00
0005435614592	5321	Economy	14400.00
0005434344509	5321	Economy	14400.00
0005435424696	5321	Economy	14400.00
0005435097287	5321	Economy	14400.00
0005435319575	5321	Economy	14400.00
0005434344527	5321	Economy	14400.00
0005435614617	5321	Economy	14400.00
0005435097280	5321	Economy	14400.00
0005434244958	5321	Economy	14400.00
0005435425022	5321	Economy	14400.00
0005434573475	5321	Economy	14400.00
0005435424766	5321	Economy	14400.00
0005435425248	5321	Economy	14400.00
0005432047579	5321	Economy	14400.00
0005435614598	5321	Economy	14400.00
0005435424836	5321	Economy	14400.00
0005435614623	5321	Economy	14400.00
0005435425016	5321	Economy	14400.00
0005435614574	5321	Economy	14400.00
0005435424840	5321	Economy	14400.00
0005435425017	5321	Economy	14400.00
0005435319616	5321	Economy	14400.00
0005435614585	5321	Economy	14400.00
0005435424733	5321	Economy	14400.00
0005435490258	5321	Economy	14400.00
0005434244982	5321	Economy	14400.00
0005435614564	5321	Economy	14400.00
0005435614600	5321	Economy	14400.00
0005435425172	5321	Economy	14400.00
0005435424852	5321	Economy	15800.00
0005435424749	5321	Economy	14400.00
0005435614618	5321	Economy	15800.00
0005434244858	5321	Economy	15800.00
0005435614610	5321	Economy	15800.00
0005435424843	5321	Economy	15800.00
0005435614555	5321	Economy	15800.00
0005435319569	5321	Economy	14400.00
0005434573465	5321	Economy	14400.00
0005435319556	5321	Economy	14400.00
0005435614621	5321	Economy	14400.00
0005435614612	5321	Economy	14400.00
0005435614538	5321	Economy	14400.00
0005435614530	5321	Economy	14400.00
0005435424650	5321	Economy	14400.00
0005435319583	5321	Economy	14400.00
0005435380283	5321	Economy	14400.00
0005434244859	5321	Economy	14400.00
0005435424630	5321	Economy	14400.00
0005435614543	5321	Economy	14400.00
0005434244956	5321	Economy	14400.00
0005432841007	5321	Economy	14400.00
0005435425070	5321	Economy	14400.00
0005435424967	5321	Economy	14400.00
0005435319563	5321	Economy	14400.00
0005435380284	5321	Economy	14400.00
0005435614584	5321	Economy	14400.00
0005434344531	5321	Economy	14400.00
0005434244920	5321	Economy	14400.00
0005435614536	5321	Economy	14400.00
0005435614582	5321	Economy	14400.00
0005435097284	5321	Economy	14400.00
0005435614611	5321	Economy	14400.00
0005434244818	5321	Economy	14400.00
0005435424319	5321	Economy	14400.00
0005434344504	5321	Economy	14400.00
0005435425011	5321	Economy	14400.00
0005434344525	5321	Economy	14400.00
0005435425087	5321	Economy	14400.00
0005434573463	5321	Economy	14400.00
0005435425249	5321	Economy	14400.00
0005434344530	5321	Economy	14400.00
0005435424878	5321	Economy	14400.00
0005435614586	5321	Economy	14400.00
0005435424769	5321	Economy	14400.00
0005435424318	5321	Economy	14400.00
0005435614619	5321	Economy	14400.00
0005434573464	5321	Economy	14400.00
0005434244889	5321	Economy	14400.00
0005435424802	5321	Economy	14400.00
0005435425002	5321	Economy	14400.00
0005435614587	5321	Economy	14400.00
0005435614602	5321	Economy	14400.00
0005435097286	5321	Economy	14400.00
0005434244914	5321	Economy	14400.00
0005434344532	5321	Economy	14400.00
0005432133333	5321	Economy	14400.00
0005435614561	5321	Economy	14400.00
0005433719129	5321	Economy	14400.00
0005435424910	5321	Economy	14400.00
0005435380306	5321	Economy	14400.00
0005434344502	5321	Economy	14400.00
0005434244832	5321	Economy	14400.00
0005435614615	5321	Economy	14400.00
0005435614558	5321	Economy	14400.00
0005435614557	5321	Economy	14400.00
0005432133337	5321	Economy	14400.00
0005435319570	5321	Economy	14400.00
0005434344523	5321	Economy	14400.00
0005435614609	5321	Economy	14400.00
0005434344505	5321	Economy	14400.00
0005435614534	5321	Economy	14400.00
0005435614594	5321	Economy	14400.00
0005432133340	5321	Economy	14400.00
0005435097288	5321	Economy	14400.00
0005435614578	5321	Economy	14400.00
0005435424684	5321	Economy	14400.00
0005434244971	5321	Economy	14400.00
0005435425019	5321	Economy	14400.00
0005434344500	5321	Economy	14400.00
0005435555385	5321	Economy	14400.00
0005434573472	5321	Economy	14400.00
0005435614591	5321	Economy	14400.00
0005435614579	5321	Economy	14400.00
0005434244997	5321	Economy	14400.00
0005432133328	5321	Economy	14400.00
0005435614553	5321	Economy	14400.00
0005434344511	5321	Economy	14400.00
0005434344517	5321	Economy	14400.00
0005435424989	5321	Economy	14400.00
0005435319584	5321	Economy	14400.00
0005435614546	5321	Economy	14400.00
0005435614545	5321	Economy	14400.00
0005432841009	5321	Economy	14400.00
0005435614544	5321	Economy	14400.00
0005434344499	5321	Economy	14400.00
0005435613669	10896	Business	43100.00
0005435425365	10896	Business	43100.00
0005435613763	10896	Business	43100.00
0005435425405	10896	Business	43100.00
0005434344120	10896	Business	43100.00
0005435425391	10896	Business	43100.00
0005434245234	10896	Business	43100.00
0005435555378	10896	Business	43100.00
0005435613725	10896	Business	43100.00
0005434245224	10896	Business	43100.00
0005434344087	10896	Business	43100.00
0005434573260	10896	Business	43100.00
0005435614137	10896	Business	43100.00
0005432166927	10896	Business	43100.00
0005435613658	10896	Business	43100.00
0005435613868	10896	Business	43100.00
0005432166929	10896	Business	43100.00
0005434344057	10896	Business	43100.00
0005434245236	10896	Business	43100.00
0005434656572	10896	Business	43100.00
0005435305027	10896	Business	43100.00
0005435613611	10896	Business	43100.00
0005435613700	10896	Business	43100.00
0005435042872	10896	Business	43100.00
0005434344269	10896	Comfort	24400.00
0005432165101	10896	Business	43100.00
0005434344135	10896	Comfort	24400.00
0005435613554	10896	Comfort	24400.00
0005435425360	10896	Comfort	24400.00
0005432165099	10896	Comfort	24400.00
0005434656574	10896	Comfort	24400.00
0005435614136	10896	Comfort	24400.00
0005435613638	10896	Comfort	24400.00
0005435425389	10896	Comfort	24400.00
0005434344184	10896	Comfort	24400.00
0005434245228	10896	Comfort	24400.00
0005435425403	10896	Comfort	24400.00
0005435613465	10896	Comfort	24400.00
0005435425369	10896	Comfort	24400.00
0005435425363	10896	Comfort	24400.00
0005434344085	10896	Comfort	24400.00
0005434573245	10896	Comfort	24400.00
0005435613502	10896	Comfort	24400.00
0005435425353	10896	Comfort	24400.00
0005435613785	10896	Comfort	24400.00
0005435613460	10896	Comfort	24400.00
0005432165098	10896	Comfort	24400.00
0005435613992	10896	Comfort	24400.00
0005434344268	10896	Comfort	24400.00
0005435613481	10896	Comfort	24400.00
0005435425384	10896	Comfort	24400.00
0005435425367	10896	Comfort	24400.00
0005434344043	10896	Comfort	24400.00
0005435425351	10896	Comfort	24400.00
0005435425346	10896	Comfort	24400.00
0005434344102	10896	Comfort	24400.00
0005434343965	10896	Comfort	24400.00
0005435613467	10896	Comfort	24400.00
0005434245208	10896	Comfort	24400.00
0005435613814	10896	Comfort	24400.00
0005435613704	10896	Comfort	24400.00
0005434344246	10896	Comfort	24400.00
0005435613745	10896	Comfort	24400.00
0005435613756	10896	Comfort	24400.00
0005434573243	10896	Economy	14400.00
0005434245232	10896	Economy	14400.00
0005434344186	10896	Economy	14400.00
0005434245219	10896	Economy	14400.00
0005433719171	10896	Economy	14400.00
0005434344233	10896	Economy	14400.00
0005435613229	10896	Economy	14400.00
0005435425355	10896	Economy	14400.00
0005435425371	10896	Economy	14400.00
0005434344197	10896	Economy	14400.00
0005432165106	10896	Economy	14400.00
0005435613606	10896	Economy	14400.00
0005435613350	10896	Economy	14400.00
0005435613449	10896	Economy	14400.00
0005435613693	10896	Economy	14400.00
0005435425387	10896	Economy	14400.00
0005435613726	10896	Economy	14400.00
0005435304188	10896	Economy	14400.00
0005435613776	10896	Economy	14400.00
0005435425378	10896	Economy	14400.00
0005434344137	10896	Economy	14400.00
0005434344066	10896	Economy	14400.00
0005434344089	10896	Economy	14400.00
0005435613395	10896	Economy	14400.00
0005435613714	10896	Economy	14400.00
0005434245229	10896	Economy	14400.00
0005434245211	10896	Economy	14400.00
0005435042873	10896	Economy	14400.00
0005435613535	10896	Economy	14400.00
0005435613248	10896	Economy	14400.00
0005434245233	10896	Economy	14400.00
0005435425357	10896	Economy	14400.00
0005434245235	10896	Economy	14400.00
0005435613775	10896	Economy	14400.00
0005432165102	10896	Economy	14400.00
0005435613954	10896	Economy	14400.00
0005434344058	10896	Economy	14400.00
0005434573259	10896	Economy	14400.00
0005435613344	10896	Economy	14400.00
0005432165104	10896	Economy	14400.00
0005435319645	10896	Economy	14400.00
0005435613469	10896	Economy	14400.00
0005435490219	10896	Economy	14400.00
0005435425380	10896	Economy	14400.00
0005432165103	10896	Economy	14400.00
0005432166928	10896	Economy	14400.00
0005434245212	10896	Economy	14400.00
0005435613603	10896	Economy	14400.00
0005435425394	10896	Economy	14400.00
0005435491441	10896	Economy	14400.00
0005435613397	10896	Economy	14400.00
0005435613447	10896	Economy	14400.00
0005435425338	10896	Economy	14400.00
0005434344074	10896	Economy	14400.00
0005432363444	10896	Economy	14400.00
0005434573301	10896	Economy	14400.00
0005435425343	10896	Economy	14400.00
0005435425341	10896	Economy	14400.00
0005433719170	10896	Economy	14400.00
0005435613671	10896	Economy	15800.00
0005434245222	10896	Economy	15800.00
0005434245225	10896	Economy	14400.00
0005434245216	10896	Economy	14400.00
0005435613755	10896	Economy	14400.00
0005435613813	10896	Economy	15800.00
0005435425344	10896	Economy	15800.00
0005435304189	10896	Economy	14400.00
0005435425348	10896	Economy	15800.00
0005435425376	10896	Economy	14400.00
0005435613470	10896	Economy	14400.00
0005435425340	10896	Economy	14400.00
0005435319648	10896	Economy	14400.00
0005434573344	10896	Economy	14400.00
0005435490218	10896	Economy	14400.00
0005435425374	10896	Economy	14400.00
0005435425382	10896	Economy	14400.00
0005435613391	10896	Economy	14400.00
0005434343964	10896	Economy	14400.00
0005435304192	10896	Economy	14400.00
0005434245237	10896	Economy	14400.00
0005435613627	10896	Economy	14400.00
0005435555377	10896	Economy	14400.00
0005434245217	10896	Economy	14400.00
0005434573300	10896	Economy	14400.00
0005435613529	10896	Economy	14400.00
0005435613455	10896	Economy	14400.00
0005432363442	10896	Economy	14400.00
0005435613631	10896	Economy	14400.00
0005434245230	10896	Economy	14400.00
0005435425358	10896	Economy	14400.00
0005435613751	10896	Economy	14400.00
0005435425354	10896	Economy	14400.00
0005435613157	10896	Economy	14400.00
0005435319643	10896	Economy	14400.00
0005435491440	10896	Economy	14400.00
0005434656573	10896	Economy	14400.00
0005435613774	10896	Economy	14400.00
0005435319644	10896	Economy	14400.00
0005435425397	10896	Economy	14400.00
0005435425393	10896	Economy	14400.00
0005435613448	10896	Economy	14400.00
0005435613553	10896	Economy	14400.00
0005435614109	10896	Economy	14400.00
0005435613521	10896	Economy	14400.00
0005435613336	10896	Economy	14400.00
0005435613936	10896	Economy	14400.00
0005435425364	10896	Economy	14400.00
0005435042874	10896	Economy	14400.00
0005435613937	10896	Economy	14400.00
0005435425404	10896	Economy	14400.00
0005434245223	10896	Economy	14400.00
0005435490215	10896	Economy	14400.00
0005434343971	10896	Economy	14400.00
0005434344112	10896	Economy	14400.00
0005435612940	10896	Economy	14400.00
0005434573244	10896	Economy	14400.00
0005435555369	10896	Economy	14400.00
0005435425347	10896	Economy	14400.00
0005435613484	10896	Economy	14400.00
0005435425390	10896	Economy	14400.00
0005435613871	10896	Economy	14400.00
0005435613591	10896	Economy	14400.00
0005435613491	10896	Economy	14400.00
0005434573306	10896	Economy	14400.00
0005434344044	10896	Economy	14400.00
0005435425366	10896	Economy	14400.00
0005435425342	10896	Economy	14400.00
0005435613824	10896	Economy	14400.00
0005435613626	10896	Economy	14400.00
0005435425383	10896	Economy	14400.00
0005435613555	10896	Economy	14400.00
0005435613713	10896	Economy	14400.00
0005435613703	10896	Economy	14400.00
0005434573327	10896	Economy	14400.00
0005434245214	10896	Economy	14400.00
0005435613527	10896	Economy	14400.00
0005432841031	10896	Economy	14400.00
0005435613598	10896	Economy	14400.00
0005435613717	10896	Economy	14400.00
0005435613158	10896	Economy	14400.00
0005434344063	10896	Economy	14400.00
0005434344099	10896	Economy	14400.00
0005435490214	10896	Economy	14400.00
0005434344132	10896	Economy	14400.00
0005435613435	10896	Economy	14400.00
0005435613764	10896	Economy	14400.00
0005434344194	10896	Economy	14400.00
0005435613349	10896	Economy	14400.00
0005434344113	10896	Economy	14400.00
0005434245218	10896	Economy	14400.00
0005435613825	10896	Economy	14400.00
0005434344076	10896	Economy	14400.00
0005435425372	10896	Economy	14400.00
0005435613815	10896	Economy	14400.00
0005435425350	10896	Economy	14400.00
0005435613384	10896	Economy	14400.00
0005435613434	10896	Economy	14400.00
0005434573305	10896	Economy	15800.00
0005435613386	10896	Economy	15800.00
0005435613590	10896	Economy	15800.00
0005435425368	10896	Economy	15800.00
0005434245210	10896	Economy	15800.00
0005435613853	10896	Economy	14400.00
0005435613832	10896	Economy	14400.00
0005435613580	10896	Economy	14400.00
0005435613742	10896	Economy	14400.00
0005435613582	10896	Economy	14400.00
0005434344241	10896	Economy	14400.00
0005435613869	10896	Economy	14400.00
0005435425361	10896	Economy	14400.00
0005435613816	10896	Economy	14400.00
0005435425345	10896	Economy	14400.00
0005435613605	10896	Economy	14400.00
0005435613933	10896	Economy	14400.00
0005435425370	10896	Economy	14400.00
0005435425385	10896	Economy	14400.00
0005434344075	10896	Economy	14400.00
0005435613823	10896	Economy	14400.00
0005435613153	10896	Economy	14400.00
0005435319646	10896	Economy	14400.00
0005435319647	10896	Economy	14400.00
0005434344185	10896	Economy	14400.00
0005435319649	10896	Economy	14400.00
0005435425395	10896	Economy	14400.00
0005435613495	10896	Economy	14400.00
0005435613757	10896	Economy	14400.00
0005435425377	10896	Economy	14400.00
0005435425398	10896	Economy	14400.00
0005435491442	10896	Economy	14400.00
0005435425352	10896	Economy	14400.00
0005435425386	10896	Economy	14400.00
0005435425339	10896	Economy	14400.00
0005434245221	10896	Economy	14400.00
0005435613938	10896	Economy	14400.00
0005435555368	10896	Economy	14400.00
0005435305026	10896	Economy	14400.00
0005434344240	10896	Economy	14400.00
0005435613672	10896	Economy	14400.00
0005435613385	10896	Economy	14400.00
0005435425407	10896	Economy	14400.00
0005435425379	10896	Economy	14400.00
0005435614113	10896	Economy	14400.00
0005434245213	10896	Economy	14400.00
0005435613400	10896	Economy	14400.00
0005434245227	10896	Economy	14400.00
0005434344051	10896	Economy	14400.00
0005433719168	10896	Economy	14400.00
0005435425381	10896	Economy	14400.00
0005435425356	10896	Economy	14400.00
0005435304191	10896	Economy	14400.00
0005435425388	10896	Economy	14400.00
0005435425399	10896	Economy	14400.00
0005435425359	10896	Economy	14400.00
0005435613922	10896	Economy	14400.00
0005435613492	10896	Economy	14400.00
0005435613528	10896	Economy	14400.00
0005435425375	10896	Economy	14400.00
0005435425400	10896	Economy	14400.00
0005435613168	10896	Economy	14400.00
0005434344088	10896	Economy	14400.00
0005435425349	10896	Economy	14400.00
0005435614042	10896	Economy	14400.00
0005435425392	10896	Economy	14400.00
0005435614112	10896	Economy	14400.00
0005435304190	10896	Economy	14400.00
0005435425401	10896	Economy	14400.00
0005435613490	10896	Economy	14400.00
0005432165097	10896	Economy	14400.00
0005435613581	10896	Economy	14400.00
0005435613466	10896	Economy	14400.00
0005434245220	10896	Economy	14400.00
0005432165105	10896	Economy	14400.00
0005435425406	10896	Economy	14400.00
0005434573319	10896	Economy	14400.00
0005435613468	10896	Economy	14400.00
0005433719169	10896	Economy	14400.00
0005435613921	10896	Economy	14400.00
0005435613673	10896	Economy	14400.00
0005434245215	10896	Economy	14400.00
0005434573304	10896	Economy	14400.00
0005434245226	10896	Economy	14400.00
0005435613694	10896	Economy	14400.00
0005435613179	10896	Economy	14400.00
0005435425396	10896	Economy	14400.00
0005435425362	10896	Economy	14400.00
0005434245209	10896	Economy	14400.00
0005432165100	10896	Economy	14400.00
0005435613228	10896	Economy	14400.00
0005435613950	10896	Economy	14400.00
0005435425373	10896	Economy	14400.00
0005435425402	10896	Economy	14400.00
0005435613414	10896	Economy	14400.00
0005432363443	10896	Economy	14400.00
0005435613518	10896	Economy	14400.00
0005435612939	10896	Economy	14400.00
0005434245231	10896	Economy	14400.00
0005435613483	10896	Economy	14400.00
0005435613670	10896	Economy	14400.00
0005433805653	3237	Business	18800.00
0005432459781	3237	Business	18800.00
0005433805656	3237	Business	18800.00
0005432181900	3237	Business	18800.00
0005433634087	3237	Business	18800.00
0005432459653	3237	Business	18800.00
0005432181905	3237	Business	18800.00
0005432459852	3237	Business	18800.00
0005433507333	3237	Business	18800.00
0005433507335	3237	Business	18800.00
0005432459834	3237	Business	18800.00
0005433507326	3237	Business	18800.00
0005432460008	3237	Business	18800.00
0005432459853	3237	Business	18800.00
0005432459911	3237	Business	18800.00
0005432459962	3237	Business	18800.00
0005433634098	3237	Business	18800.00
0005433805672	3237	Business	18800.00
0005432459709	3237	Business	18800.00
0005432181910	3237	Business	18800.00
0005433805661	3237	Business	18800.00
0005433805650	3237	Business	18800.00
0005432459774	3237	Business	18800.00
0005433805658	3237	Business	18800.00
0005433634106	3237	Business	18800.00
0005432459816	3237	Business	18800.00
0005432459640	3237	Economy	6900.00
0005432181904	3237	Economy	6900.00
0005432181901	3237	Economy	6900.00
0005433805651	3237	Economy	6900.00
0005432181909	3237	Economy	6900.00
0005433634119	3237	Economy	6300.00
0005433805654	3237	Economy	6300.00
0005433507329	3237	Economy	6300.00
0005432459732	3237	Economy	6300.00
0005433805673	3237	Economy	6300.00
0005433805657	3237	Economy	6300.00
0005433634118	3237	Economy	6300.00
0005433805678	3237	Economy	6300.00
0005432459863	3237	Economy	6300.00
0005433805644	3237	Economy	6300.00
0005433805683	3237	Economy	6300.00
0005433805674	3237	Economy	6300.00
0005432181897	3237	Economy	6300.00
0005432459708	3237	Economy	6300.00
0005433634103	3237	Economy	6300.00
0005433805676	3237	Economy	6300.00
0005432459963	3237	Economy	6300.00
0005433634097	3237	Economy	6300.00
0005433634090	3237	Economy	6300.00
0005434143741	3237	Economy	6300.00
0005432459808	3237	Economy	6300.00
0005432459615	3237	Economy	6300.00
0005432181892	3237	Economy	6300.00
0005433805666	3237	Economy	6300.00
0005433805659	3237	Economy	6300.00
0005432181894	3237	Economy	6300.00
0005432459961	3237	Economy	6300.00
0005433634104	3237	Economy	6300.00
0005433507331	3237	Economy	6300.00
0005433634113	3237	Economy	6300.00
0005433507325	3237	Economy	6300.00
0005432181890	3237	Economy	6300.00
0005433805646	3237	Economy	6300.00
0005433805645	3237	Economy	6300.00
0005433507337	3237	Economy	6300.00
0005433634116	3237	Economy	6300.00
0005433634092	3237	Economy	6300.00
0005432459705	3237	Economy	6300.00
0005433634111	3237	Economy	6300.00
0005432459614	3237	Economy	6300.00
0005433805671	3237	Economy	6300.00
0005433805679	3237	Economy	6300.00
0005432181903	3237	Economy	6300.00
0005433634105	3237	Economy	6300.00
0005433634109	3237	Economy	6300.00
0005432181908	3237	Economy	6300.00
0005432181899	3237	Economy	6300.00
0005433805670	3237	Economy	6300.00
0005432459886	3237	Economy	6300.00
0005432459641	3237	Economy	6300.00
0005433805668	3237	Economy	6300.00
0005432181895	3237	Economy	6300.00
0005432181896	3237	Economy	6300.00
0005433507332	3237	Economy	6300.00
0005433634100	3237	Economy	6300.00
0005433507334	3237	Economy	6300.00
0005432460005	3237	Economy	6300.00
0005432459764	3237	Economy	6300.00
0005433507336	3237	Economy	6300.00
0005432181902	3237	Economy	6900.00
0005432181907	3237	Economy	6900.00
0005433805681	3237	Economy	6900.00
0005433634095	3237	Economy	6900.00
0005433634088	3237	Economy	6900.00
0005433634094	3237	Economy	6300.00
0005432181891	3237	Economy	6300.00
0005433507323	3237	Economy	6300.00
0005433634089	3237	Economy	6300.00
0005432181911	3237	Economy	6900.00
0005433634101	3237	Economy	6300.00
0005433634107	3237	Economy	6300.00
0005432181912	3237	Economy	6300.00
0005432181893	3237	Economy	6300.00
0005433805663	3237	Economy	6300.00
0005432459856	3237	Economy	6300.00
0005433634112	3237	Economy	6300.00
0005433634114	3237	Economy	6300.00
0005433805684	3237	Economy	6300.00
0005432181906	3237	Economy	6300.00
0005433634110	3237	Economy	6300.00
0005432460004	3237	Economy	6300.00
0005433507339	3237	Economy	6300.00
0005432459628	3237	Economy	6300.00
0005432459733	3237	Economy	6300.00
0005433507328	3237	Economy	6300.00
0005433507327	3237	Economy	6300.00
0005433507340	3237	Economy	6300.00
0005433805662	3237	Economy	6300.00
0005433805680	3237	Economy	6300.00
0005433634102	3237	Economy	6300.00
0005433507324	3237	Economy	6300.00
0005432459639	3237	Economy	6300.00
0005433634091	3237	Economy	6300.00
0005433805652	3237	Economy	6300.00
0005432459765	3237	Economy	6300.00
0005433634115	3237	Economy	6300.00
0005433507330	3237	Economy	6300.00
0005433805665	3237	Economy	6300.00
0005433805675	3237	Economy	6300.00
0005434143743	3237	Economy	6300.00
0005432459782	3237	Economy	6300.00
0005432459951	3237	Economy	6300.00
0005432459906	3237	Economy	6300.00
0005432459652	3237	Economy	6300.00
0005433634099	3237	Economy	6300.00
0005432181898	3237	Economy	6300.00
0005433507322	3237	Economy	6300.00
0005433634093	3237	Economy	6300.00
0005433805649	3237	Economy	6300.00
0005432459734	3237	Economy	6300.00
0005432459905	3237	Economy	6300.00
0005432459656	3237	Economy	6300.00
0005433805664	3237	Economy	6300.00
0005433805655	3237	Economy	6300.00
0005433507338	3237	Economy	6300.00
0005433634086	3237	Economy	6300.00
0005433805648	3237	Economy	6300.00
0005432459910	3237	Economy	6300.00
0005432459917	3237	Economy	6300.00
0005432460007	3237	Economy	6300.00
0005432459833	3237	Economy	6300.00
0005433805647	3237	Economy	6300.00
0005433805667	3237	Economy	6300.00
0005432459885	3237	Economy	6300.00
0005433634108	3237	Economy	6300.00
0005434143742	3237	Economy	6300.00
0005432460006	3237	Economy	6300.00
0005433805669	3237	Economy	6300.00
0005432459826	3237	Economy	6300.00
0005433805682	3237	Economy	6300.00
0005433805660	3237	Economy	6300.00
0005433634117	3237	Economy	6300.00
0005433805677	3237	Economy	6300.00
0005433634096	3237	Economy	6300.00
0005435885247	3236	Business	18800.00
0005435885494	3236	Business	18800.00
0005435885189	3236	Business	18800.00
0005435885204	3236	Business	18800.00
0005435885206	3236	Business	18800.00
0005435885261	3236	Business	18800.00
0005435885085	3236	Business	18800.00
0005435885103	3236	Economy	6900.00
0005435885231	3236	Economy	6900.00
0005435885291	3236	Economy	6300.00
0005435885408	3236	Economy	6300.00
0005435885354	3236	Economy	6300.00
0005435885284	3236	Economy	6300.00
0005435885378	3236	Economy	6300.00
0005435885303	3236	Economy	6300.00
0005435885413	3236	Economy	6300.00
0005435885188	3236	Economy	6300.00
0005435885383	3236	Economy	6300.00
0005435885290	3236	Economy	6300.00
0005435885397	3236	Economy	6300.00
0005435885341	3236	Economy	6300.00
0005435885214	3236	Economy	6300.00
0005435885052	3236	Economy	6300.00
0005435885152	3236	Economy	6300.00
0005435885205	3236	Economy	6300.00
0005435885285	3236	Economy	6300.00
0005435885165	3236	Economy	6300.00
0005435885384	3236	Economy	6300.00
0005435885125	3236	Economy	6300.00
0005435885251	3236	Economy	6300.00
0005435885276	3236	Economy	6300.00
0005435885252	3236	Economy	6300.00
0005435885419	3236	Economy	6300.00
0005435885402	3236	Economy	6300.00
0005435885396	3236	Economy	6300.00
0005435885195	3236	Economy	6300.00
0005435885337	3236	Economy	6300.00
0005435885385	3236	Economy	6300.00
0005435885353	3236	Economy	6300.00
0005435885334	3236	Economy	6300.00
0005435885234	3236	Economy	6300.00
0005435885132	3236	Economy	6300.00
0005435885495	3236	Economy	6300.00
0005435885233	3236	Economy	6300.00
0005435885318	3236	Economy	6300.00
0005435885306	3236	Economy	6300.00
0005435884975	3236	Economy	6300.00
0005435885324	3236	Economy	6300.00
0005435885424	3236	Economy	6300.00
0005435885361	3236	Economy	6300.00
0005435885519	3236	Economy	6300.00
0005435885156	3236	Economy	6300.00
0005435885663	8263	Business	18800.00
0005432460296	8263	Business	18800.00
0005435885627	8263	Business	18800.00
0005435885629	8263	Business	18800.00
0005432042837	8263	Business	18800.00
0005432460319	8263	Business	18800.00
0005435885674	8263	Business	18800.00
0005432460292	8263	Business	18800.00
0005432460326	8263	Business	18800.00
0005433507164	8263	Business	18800.00
0005433507207	8263	Business	18800.00
0005435885667	8263	Business	18800.00
0005432042830	8263	Business	18800.00
0005435885639	8263	Business	18800.00
0005435885637	8263	Business	18800.00
0005433507163	8263	Business	18800.00
0005433507184	8263	Business	18800.00
0005432042829	8263	Business	18800.00
0005432460310	8263	Business	18800.00
0005435885665	8263	Business	18800.00
0005432460298	8263	Business	18800.00
0005435885662	8263	Business	18800.00
0005435885658	8263	Business	18800.00
0005435885670	8263	Business	18800.00
0005435885631	8263	Business	18800.00
0005435885672	8263	Economy	6900.00
0005435885682	8263	Economy	6900.00
0005432460314	8263	Economy	6900.00
0005432460341	8263	Economy	6900.00
0005432460339	8263	Economy	6900.00
0005435885676	8263	Economy	6900.00
0005432460302	8263	Economy	6300.00
0005432460329	8263	Economy	6300.00
0005432460334	8263	Economy	6300.00
0005435885653	8263	Economy	6300.00
0005435885680	8263	Economy	6300.00
0005435885626	8263	Economy	6300.00
0005432460344	8263	Economy	6300.00
0005432460332	8263	Economy	6300.00
0005432042831	8263	Economy	6300.00
0005432460345	8263	Economy	6300.00
0005435885632	8263	Economy	6300.00
0005432460323	8263	Economy	6300.00
0005432460309	8263	Economy	6300.00
0005432460328	8263	Economy	6300.00
0005432042835	8263	Economy	6300.00
0005435885681	8263	Economy	6300.00
0005432460340	8263	Economy	6300.00
0005435885673	8263	Economy	6300.00
0005435885678	8263	Economy	6300.00
0005435885641	8263	Economy	6300.00
0005433507050	8263	Economy	6300.00
0005432460299	8263	Economy	6300.00
0005435885666	8263	Economy	6300.00
0005432460316	8263	Economy	6300.00
0005432460308	8263	Economy	6300.00
0005432042827	8263	Economy	6300.00
0005432460331	8263	Economy	6300.00
0005432042836	8263	Economy	6300.00
0005435885668	8263	Economy	6300.00
0005435885643	8263	Economy	6300.00
0005434312338	8263	Economy	6300.00
0005435885655	8263	Economy	6300.00
0005433507188	8263	Economy	6300.00
0005432460311	8263	Economy	6300.00
0005435885679	8263	Economy	6300.00
0005432460305	8263	Economy	6300.00
0005432042828	8263	Economy	6300.00
0005432460306	8263	Economy	6300.00
0005432460327	8263	Economy	6300.00
0005435885630	8263	Economy	6300.00
0005432460304	8263	Economy	6300.00
0005435885661	8263	Economy	6300.00
0005432460317	8263	Economy	6300.00
0005432042833	8263	Economy	6300.00
0005435885685	8263	Economy	6300.00
0005432460297	8263	Economy	6300.00
0005432460312	8263	Economy	6300.00
0005433507223	8263	Economy	6300.00
0005435885649	8263	Economy	6300.00
0005432460313	8263	Economy	6300.00
0005432460294	8263	Economy	6300.00
0005435885633	8263	Economy	6300.00
0005435885671	8263	Economy	6900.00
0005435885624	8263	Economy	6900.00
0005432460337	8263	Economy	6900.00
0005432460320	8263	Economy	6900.00
0005432460335	8263	Economy	6300.00
0005435885642	8263	Economy	6300.00
0005435885669	8263	Economy	6300.00
0005435885625	8263	Economy	6300.00
0005435885628	8263	Economy	6900.00
0005432042832	8263	Economy	6300.00
0005432460315	8263	Economy	6300.00
0005435885656	8263	Economy	6300.00
0005435885650	8263	Economy	6300.00
0005432460324	8263	Economy	6300.00
0005432460321	8263	Economy	6300.00
0005434312339	8263	Economy	6300.00
0005432460336	8263	Economy	6300.00
0005435885647	8263	Economy	6300.00
0005435885677	8263	Economy	6300.00
0005435885636	8263	Economy	6300.00
0005432460343	8263	Economy	6300.00
0005435885638	8263	Economy	6300.00
0005433507181	8263	Economy	6300.00
0005432460307	8263	Economy	6300.00
0005435885654	8263	Economy	6300.00
0005435885652	8263	Economy	6300.00
0005435885659	8263	Economy	6300.00
0005435885622	8263	Economy	6300.00
0005432042824	8263	Economy	6300.00
0005435885644	8263	Economy	6300.00
0005435885635	8263	Economy	6300.00
0005432460338	8263	Economy	6300.00
0005433507176	8263	Economy	6300.00
0005432460322	8263	Economy	6300.00
0005432042826	8263	Economy	6300.00
0005432460318	8263	Economy	6300.00
0005432460293	8263	Economy	6300.00
0005435885645	8263	Economy	6300.00
0005435885684	8263	Economy	6300.00
0005435885634	8263	Economy	6300.00
0005432460300	8263	Economy	6300.00
0005435885646	8263	Economy	6300.00
0005435885623	8263	Economy	6300.00
0005435885657	8263	Economy	6300.00
0005435885664	8263	Economy	6300.00
0005433507185	8263	Economy	6300.00
0005432460342	8263	Economy	6300.00
0005435885648	8263	Economy	6300.00
0005432460333	8263	Economy	6300.00
0005435885675	8263	Economy	6300.00
0005432460295	8263	Economy	6300.00
0005435885683	8263	Economy	6300.00
0005432460303	8263	Economy	6300.00
0005432042825	8263	Economy	6300.00
0005435885640	8263	Economy	6300.00
0005432460325	8263	Economy	6300.00
0005432460330	8263	Economy	6300.00
0005432042834	8263	Economy	6300.00
0005434326274	8263	Economy	6300.00
0005432460301	8263	Economy	6300.00
0005433507074	8263	Economy	6300.00
0005435885651	8263	Economy	6300.00
0005435885660	8263	Economy	6300.00
0005433805513	8250	Business	18800.00
0005433633714	8250	Business	18800.00
0005433633670	8250	Business	18800.00
0005433633634	8250	Business	18800.00
0005433633875	8250	Business	18800.00
0005433633611	8250	Business	18800.00
0005433633690	8250	Business	18800.00
0005433633822	8250	Business	18800.00
0005433805186	8250	Business	18800.00
0005433633855	8250	Business	18800.00
0005433633739	8250	Business	18800.00
0005433805425	8250	Economy	6900.00
0005433805308	8250	Economy	6900.00
0005433805313	8250	Economy	6300.00
0005433633771	8250	Economy	6300.00
0005433633715	8250	Economy	6300.00
0005433633801	8250	Economy	6300.00
0005433633817	8250	Economy	6300.00
0005433633794	8250	Economy	6300.00
0005433805437	8250	Economy	6300.00
0005433633803	8250	Economy	6300.00
0005433805535	8250	Economy	6300.00
0005433633849	8250	Economy	6300.00
0005433633933	8250	Economy	6300.00
0005433805335	8250	Economy	6300.00
0005433805406	8250	Economy	6300.00
0005433805296	8250	Economy	6300.00
0005434143728	8250	Economy	6300.00
0005433805312	8250	Economy	6300.00
0005433633787	8250	Economy	6300.00
0005433633765	8250	Economy	6300.00
0005433633902	8250	Economy	6300.00
0005433805496	8250	Economy	6300.00
0005433805185	8250	Economy	6300.00
0005433805458	8250	Economy	6300.00
0005433633767	8250	Economy	6300.00
0005433633800	8250	Economy	6300.00
0005433633706	8250	Economy	6300.00
0005433633615	8250	Economy	6300.00
0005433633815	8250	Economy	6300.00
0005433805352	8250	Economy	6900.00
0005433633691	8250	Economy	6900.00
0005433633788	8250	Economy	6300.00
0005433633926	8250	Economy	6900.00
0005433633738	8250	Economy	6300.00
0005433805375	8250	Economy	6300.00
0005433633717	8250	Economy	6300.00
0005433633876	8250	Economy	6300.00
0005433805351	8250	Economy	6300.00
0005434271310	8250	Economy	6300.00
0005433633823	8250	Economy	6300.00
0005434271317	8250	Economy	6300.00
0005433633742	8250	Economy	6300.00
0005433633793	8250	Economy	6300.00
0005433633705	8250	Economy	6300.00
0005433805392	8250	Economy	6300.00
0005433805309	8250	Economy	6300.00
0005433633934	8250	Economy	6300.00
0005433805290	8250	Economy	6300.00
0005433805212	8250	Economy	6300.00
0005433805277	8250	Economy	6300.00
0005433633802	8250	Economy	6300.00
0005433805259	8250	Economy	6300.00
0005433633768	8250	Economy	6300.00
0005433805407	8250	Economy	6300.00
0005433805502	8250	Economy	6300.00
0005433633760	8250	Economy	6300.00
0005433805367	8250	Economy	6300.00
0005433805464	8250	Economy	6300.00
0005433805336	8250	Economy	6300.00
0005433633778	8250	Economy	6300.00
0005433633816	8250	Economy	6300.00
0005433805393	8250	Economy	6300.00
0005433805512	8250	Economy	6300.00
0005434183577	8321	Economy	6300.00
0005434183571	8321	Economy	6300.00
0005434183586	8321	Economy	6300.00
0005432383508	4516	Business	9900.00
0005433454892	4516	Business	9900.00
0005432383521	4516	Business	9900.00
0005432383513	4516	Business	9900.00
0005432383528	4516	Business	9900.00
0005433454893	4516	Business	9900.00
0005433722278	4516	Business	9900.00
0005432728041	4516	Business	9900.00
0005433722281	4516	Economy	3300.00
0005432383526	4516	Economy	3300.00
0005433454894	4516	Economy	3300.00
0005432383516	4516	Economy	3300.00
0005432383504	4516	Economy	3300.00
0005433453776	4516	Economy	3300.00
0005432383530	4516	Economy	3300.00
0005432383527	4516	Economy	3600.00
0005432383490	4516	Economy	3600.00
0005432383489	4516	Economy	3600.00
0005432383519	4516	Economy	3300.00
0005432383501	4516	Economy	3300.00
0005432728046	4516	Economy	3300.00
0005432383499	4516	Economy	3300.00
0005432383518	4516	Economy	3300.00
0005432383494	4516	Economy	3300.00
0005432383520	4516	Economy	3300.00
0005432728038	4516	Economy	3300.00
0005432728044	4516	Economy	3300.00
0005433722279	4516	Economy	3300.00
0005432383500	4516	Economy	3300.00
0005432728039	4516	Economy	3300.00
0005433194876	4516	Economy	3300.00
0005432383491	4516	Economy	3300.00
0005432728048	4516	Economy	3300.00
0005432383523	4516	Economy	3300.00
0005432383506	4516	Economy	3300.00
0005433722277	4516	Economy	3300.00
0005432383514	4516	Economy	3300.00
0005432383502	4516	Economy	3300.00
0005432383531	4516	Economy	3300.00
0005432383524	4516	Economy	3300.00
0005432728045	4516	Economy	3300.00
0005432383515	4516	Economy	3300.00
0005432383492	4516	Economy	3300.00
0005432383525	4516	Economy	3300.00
0005432383488	4516	Economy	3300.00
0005432728042	4516	Economy	3300.00
0005433453775	4516	Economy	3300.00
0005432383522	4516	Economy	3300.00
0005432383517	4516	Economy	3300.00
0005432383510	4516	Economy	3300.00
0005433722280	4516	Economy	3300.00
0005432383496	4516	Economy	3300.00
0005432383497	4516	Economy	3300.00
0005432383529	4516	Economy	3300.00
0005432383505	4516	Economy	3300.00
0005432383507	4516	Economy	3300.00
0005432383509	4516	Economy	3300.00
0005432383532	4516	Economy	3300.00
0005432728043	4516	Economy	3300.00
0005432728040	4516	Economy	3300.00
0005432383512	4516	Economy	3300.00
0005432383498	4516	Economy	3300.00
0005432383503	4516	Economy	3300.00
0005432383511	4516	Economy	3300.00
0005432728047	4516	Economy	3300.00
0005432383495	4516	Economy	3300.00
0005432728037	4516	Economy	3300.00
0005432383493	4516	Economy	3300.00
0005432727956	30129	Business	9900.00
0005432727895	30129	Business	9900.00
0005433451617	30129	Business	9900.00
0005432383048	30129	Business	9900.00
0005432382895	30129	Business	9900.00
0005432383076	30129	Business	9900.00
0005432382942	30129	Business	9900.00
0005433722187	30129	Business	9900.00
0005432383086	30129	Economy	3300.00
0005432383051	30129	Economy	3300.00
0005432383078	30129	Economy	3300.00
0005432383054	30129	Economy	3300.00
0005433722192	30129	Economy	3300.00
0005432727992	30129	Economy	3300.00
0005432382980	30129	Economy	3600.00
0005433453758	30129	Economy	3600.00
0005433451619	30129	Economy	3600.00
0005432383006	30129	Economy	3600.00
0005432727934	30129	Economy	3300.00
0005432383083	30129	Economy	3300.00
0005432383009	30129	Economy	3300.00
0005432382848	30129	Economy	3300.00
0005432382991	30129	Economy	3300.00
0005432727922	30129	Economy	3300.00
0005432383007	30129	Economy	3300.00
0005432382904	30129	Economy	3300.00
0005432382992	30129	Economy	3300.00
0005432383052	30129	Economy	3300.00
0005432382965	30129	Economy	3300.00
0005432727880	30129	Economy	3300.00
0005432383008	30129	Economy	3300.00
0005432383033	30129	Economy	3300.00
0005432727879	30129	Economy	3300.00
0005432383053	30129	Economy	3300.00
0005432382955	30129	Economy	3300.00
0005432727869	30129	Economy	3300.00
0005432383045	30129	Economy	3300.00
0005432383000	30129	Economy	3300.00
0005432727971	30129	Economy	3300.00
0005433722193	30129	Economy	3300.00
0005432383039	30129	Economy	3300.00
0005432383063	30129	Economy	3300.00
0005432382951	30129	Economy	3300.00
0005432383082	30129	Economy	3300.00
0005432382896	30129	Economy	3300.00
0005433194851	30129	Economy	3300.00
0005432383044	30129	Economy	3300.00
0005432383019	30129	Economy	3300.00
0005432383030	30129	Economy	3300.00
0005432383040	30129	Economy	3300.00
0005433451620	30129	Economy	3300.00
0005432383055	30129	Economy	3300.00
0005432382932	30129	Economy	3300.00
0005432383046	30129	Economy	3300.00
0005432383018	30129	Economy	3300.00
0005432727930	30129	Economy	3300.00
0005432382974	30129	Economy	3300.00
0005432382856	30129	Economy	3300.00
0005432727903	30129	Economy	3300.00
0005432383020	30129	Economy	3300.00
0005432382973	30129	Economy	3300.00
0005435529433	1720	Business	57200.00
0005432294507	1720	Business	57200.00
0005435541198	1720	Business	57200.00
0005435529450	1720	Business	57200.00
0005432294508	1720	Business	57200.00
0005435541176	1720	Business	57200.00
0005435541191	1720	Business	57200.00
0005433516966	1720	Business	57200.00
0005435529438	1720	Economy	19100.00
0005435529434	1720	Economy	19100.00
0005435529448	1720	Economy	19100.00
0005435529432	1720	Economy	19100.00
0005435541177	1720	Economy	21000.00
0005435541183	1720	Economy	21000.00
0005435541185	1720	Economy	21000.00
0005435529453	1720	Economy	21000.00
0005435541197	1720	Economy	21000.00
0005435541193	1720	Economy	19100.00
0005435541192	1720	Economy	19100.00
0005435529445	1720	Economy	19100.00
0005435529442	1720	Economy	19100.00
0005435529452	1720	Economy	19100.00
0005432925044	1720	Economy	19100.00
0005433516963	1720	Economy	19100.00
0005433516960	1720	Economy	19100.00
0005435529441	1720	Economy	19100.00
0005432925033	1720	Economy	19100.00
0005435529436	1720	Economy	19100.00
0005435541180	1720	Economy	19100.00
0005433516969	1720	Economy	19100.00
0005435529449	1720	Economy	19100.00
0005435541179	1720	Economy	19100.00
0005435541181	1720	Economy	19100.00
0005435541187	1720	Economy	19100.00
0005432925034	1720	Economy	19100.00
0005435541178	1720	Economy	19100.00
0005433516964	1720	Economy	19100.00
0005433516962	1720	Economy	19100.00
0005435541190	1720	Economy	19100.00
0005435529446	1720	Economy	19100.00
0005433516968	1720	Economy	19100.00
0005435529454	1720	Economy	19100.00
0005435541196	1720	Economy	19100.00
0005433516967	1720	Economy	19100.00
0005435529435	1720	Economy	19100.00
0005435529440	1720	Economy	19100.00
0005435541189	1720	Economy	19100.00
0005435529451	1720	Economy	19100.00
0005433516961	1720	Economy	19100.00
0005435529437	1720	Economy	19100.00
0005435529439	1720	Economy	19100.00
0005435541184	1720	Economy	19100.00
0005433516965	1720	Economy	19100.00
0005435529443	1720	Economy	19100.00
0005435541195	1720	Economy	19100.00
0005435541186	1720	Economy	19100.00
0005435541188	1720	Economy	19100.00
0005435541194	1720	Economy	19100.00
0005435529455	1720	Economy	19100.00
0005435529447	1720	Economy	19100.00
0005435541182	1720	Economy	19100.00
0005435529444	1720	Economy	19100.00
0005435540961	21977	Business	57200.00
0005433516876	21977	Business	57200.00
0005435517968	21977	Economy	19100.00
0005432925078	21977	Economy	19100.00
0005435517837	21977	Economy	19100.00
0005435517895	21977	Economy	19100.00
0005435541006	21977	Economy	19100.00
0005435517817	21977	Economy	21000.00
0005433516894	21977	Economy	21000.00
0005435540958	21977	Economy	21000.00
0005435541004	21977	Economy	21000.00
0005435541059	21977	Economy	21000.00
0005435517825	21977	Economy	19100.00
0005435540981	21977	Economy	19100.00
0005435540859	21977	Economy	19100.00
0005435517871	21977	Economy	19100.00
0005435540988	21977	Economy	19100.00
0005432925075	21977	Economy	19100.00
0005433516889	21977	Economy	19100.00
0005433516914	21977	Economy	19100.00
0005435517896	21977	Economy	19100.00
0005435517894	21977	Economy	19100.00
0005435540831	21977	Economy	19100.00
0005435541023	21977	Economy	19100.00
0005432925074	21977	Economy	19100.00
0005432925077	21977	Economy	19100.00
0005435540984	21977	Economy	19100.00
0005435540962	21977	Economy	19100.00
0005435517969	21977	Economy	19100.00
0005435517864	21977	Economy	19100.00
0005433516875	21977	Economy	19100.00
0005435517897	21977	Economy	19100.00
0005435540977	21977	Economy	19100.00
0005433516877	21977	Economy	19100.00
0005435517863	21977	Economy	19100.00
0005435517880	21977	Economy	19100.00
0005433516858	21977	Economy	19100.00
0005433516881	21977	Economy	19100.00
0005433516888	21977	Economy	19100.00
0005435540858	21977	Economy	19100.00
0005435517901	21977	Economy	19100.00
0005435540976	21977	Economy	19100.00
0005432925079	21977	Economy	19100.00
0005435540942	21977	Economy	19100.00
0005435517849	21977	Economy	19100.00
0005435540990	21977	Economy	19100.00
0005435541014	21977	Economy	19100.00
0005432925076	21977	Economy	19100.00
0005435541041	21977	Economy	19100.00
0005435540985	21977	Economy	19100.00
0005435540989	21977	Economy	19100.00
0005433516880	21977	Economy	19100.00
0005435541015	21977	Economy	19100.00
0005435540959	21977	Economy	19100.00
0005435491438	7392	Business	18500.00
0005432839305	7392	Business	18500.00
0005434458976	7392	Business	18500.00
0005434458983	7392	Business	18500.00
0005432839285	7392	Business	18500.00
0005435252647	7392	Business	18500.00
0005434458977	7392	Business	18500.00
0005432839283	7392	Business	18500.00
0005432841030	7392	Business	18500.00
0005435252672	7392	Business	18500.00
0005432839292	7392	Economy	6200.00
0005434458972	7392	Economy	6200.00
0005435252763	7392	Economy	6200.00
0005432839281	7392	Economy	6200.00
0005435491437	7392	Economy	6200.00
0005432841029	7392	Economy	6200.00
0005435252588	7392	Economy	6200.00
0005432823464	7392	Economy	6200.00
0005432839286	7392	Economy	6200.00
0005432839291	7392	Economy	6800.00
0005434458982	7392	Economy	6800.00
0005432823466	7392	Economy	6800.00
0005432839280	7392	Economy	6800.00
0005435252649	7392	Economy	6200.00
0005432823465	7392	Economy	6200.00
0005432839284	7392	Economy	6200.00
0005434458967	7392	Economy	6200.00
0005434664954	7392	Economy	6200.00
0005432841028	7392	Economy	6200.00
0005432839276	7392	Economy	6200.00
0005434458986	7392	Economy	6200.00
0005435491435	7392	Economy	6200.00
0005434664957	7392	Economy	6200.00
0005434458978	7392	Economy	6200.00
0005432839306	7392	Economy	6200.00
0005434458979	7392	Economy	6200.00
0005434458966	7392	Economy	6200.00
0005434458981	7392	Economy	6200.00
0005435252786	7392	Economy	6200.00
0005432839296	7392	Economy	6200.00
0005434458973	7392	Economy	6200.00
0005432839304	7392	Economy	6200.00
0005434458985	7392	Economy	6200.00
0005432839298	7392	Economy	6200.00
0005432073418	7392	Economy	6200.00
0005432839294	7392	Economy	6200.00
0005432839299	7392	Economy	6200.00
0005432839278	7392	Economy	6200.00
0005432839279	7392	Economy	6200.00
0005432839302	7392	Economy	6200.00
0005435252631	7392	Economy	6200.00
0005434458968	7392	Economy	6200.00
0005432839300	7392	Economy	6200.00
0005432839288	7392	Economy	6200.00
0005432839303	7392	Economy	6200.00
0005434458970	7392	Economy	6200.00
0005435252722	7392	Economy	6200.00
0005432839290	7392	Economy	6200.00
0005432839293	7392	Economy	6200.00
0005435252630	7392	Economy	6200.00
0005434458980	7392	Economy	6200.00
0005434458984	7392	Economy	6200.00
0005435252719	7392	Economy	6200.00
0005432839287	7392	Economy	6200.00
0005435252738	7392	Economy	6200.00
0005432073420	7392	Economy	6200.00
0005435252721	7392	Economy	6200.00
0005434458971	7392	Economy	6200.00
0005432073419	7392	Economy	6200.00
0005432839282	7392	Economy	6200.00
0005434458975	7392	Economy	6200.00
0005434458974	7392	Economy	6200.00
0005435252648	7392	Economy	6200.00
0005432839307	7392	Economy	6200.00
0005434458969	7392	Economy	6200.00
0005435252720	7392	Economy	6200.00
0005432839277	7392	Economy	6200.00
0005435252589	7392	Economy	6200.00
0005432839301	7392	Economy	6200.00
0005432839297	7392	Economy	6200.00
0005432839289	7392	Economy	6200.00
0005432839295	7392	Economy	6200.00
0005432839158	28941	Business	18500.00
0005432839092	28941	Business	18500.00
0005432838926	28941	Business	18500.00
0005432823442	28941	Business	18500.00
0005432838956	28941	Business	18500.00
0005432839108	28941	Business	18500.00
0005432839094	28941	Business	18500.00
0005432823452	28941	Business	18500.00
0005432839132	28941	Business	18500.00
0005435491458	28941	Business	18500.00
0005434458682	28941	Business	18500.00
0005432823444	28941	Business	18500.00
0005435252840	28941	Economy	6200.00
0005435252852	28941	Economy	6200.00
0005434458756	28941	Economy	6200.00
0005432839109	28941	Economy	6200.00
0005432838982	28941	Economy	6200.00
0005432839146	28941	Economy	6200.00
0005434458836	28941	Economy	6200.00
0005434458604	28941	Economy	6200.00
0005432839080	28941	Economy	6200.00
0005434458779	28941	Economy	6800.00
0005435252851	28941	Economy	6800.00
0005435252838	28941	Economy	6800.00
0005432823449	28941	Economy	6800.00
0005432839104	28941	Economy	6800.00
0005435252841	28941	Economy	6200.00
0005434458605	28941	Economy	6200.00
0005432838965	28941	Economy	6200.00
0005432838928	28941	Economy	6200.00
0005435252837	28941	Economy	6200.00
0005434458780	28941	Economy	6200.00
0005434664981	28941	Economy	6200.00
0005432001039	28941	Economy	6200.00
0005432841013	28941	Economy	6200.00
0005432839149	28941	Economy	6200.00
0005432839147	28941	Economy	6200.00
0005432839148	28941	Economy	6200.00
0005434458831	28941	Economy	6200.00
0005435252847	28941	Economy	6200.00
0005432838927	28941	Economy	6200.00
0005435491455	28941	Economy	6200.00
0005435252854	28941	Economy	6200.00
0005432839038	28941	Economy	6200.00
0005435252849	28941	Economy	6200.00
0005434458867	28941	Economy	6200.00
0005432839159	28941	Economy	6200.00
0005434458757	28941	Economy	6200.00
0005432823443	28941	Economy	6200.00
0005432839049	28941	Economy	6200.00
0005435252845	28941	Economy	6200.00
0005432001040	28941	Economy	6200.00
0005432838955	28941	Economy	6200.00
0005435252844	28941	Economy	6200.00
0005432839067	28941	Economy	6200.00
0005432839102	28941	Economy	6200.00
0005434664980	28941	Economy	6200.00
0005435252855	28941	Economy	6200.00
0005432839110	28941	Economy	6200.00
0005432839130	28941	Economy	6200.00
0005432838929	28941	Economy	6200.00
0005432839107	28941	Economy	6200.00
0005435491457	28941	Economy	6200.00
0005434458873	28941	Economy	6200.00
0005435252853	28941	Economy	6200.00
0005432839095	28941	Economy	6200.00
0005435252839	28941	Economy	6200.00
0005434458785	28941	Economy	6200.00
0005432839103	28941	Economy	6200.00
0005435491456	28941	Economy	6200.00
0005434458759	28941	Economy	6200.00
0005435252843	28941	Economy	6200.00
0005432839068	28941	Economy	6200.00
0005432839070	28941	Economy	6200.00
0005434458681	28941	Economy	6200.00
0005435252850	28941	Economy	6200.00
0005434458837	28941	Economy	6200.00
0005435252846	28941	Economy	6200.00
0005432838966	28941	Economy	6200.00
0005434664979	28941	Economy	6200.00
0005435252848	28941	Economy	6200.00
0005432838981	28941	Economy	6200.00
0005432839003	28941	Economy	6200.00
0005435252842	28941	Economy	6200.00
0005434458786	28941	Economy	6200.00
0005432823451	28941	Economy	6200.00
0005434458804	28941	Economy	6200.00
0005432838963	28941	Economy	6200.00
0005432839131	28941	Economy	6200.00
0005432839045	28941	Economy	6200.00
0005434276036	8782	Business	145300.00
0005434276031	8782	Economy	48400.00
0005434276035	8782	Economy	48400.00
0005435990683	8782	Economy	48400.00
0005435990684	8782	Economy	48400.00
0005435990681	8782	Economy	48400.00
0005435990685	8782	Economy	48400.00
0005435990682	8782	Economy	48400.00
0005435990680	8782	Economy	48400.00
0005434276076	15720	Business	145300.00
0005434276072	15720	Economy	48400.00
0005434276073	15720	Economy	48400.00
0005435990618	15720	Economy	48400.00
0005435990623	15720	Economy	48400.00
0005435990626	15720	Economy	48400.00
0005434276074	15720	Economy	48400.00
0005434276077	15720	Economy	48400.00
0005434276075	15720	Economy	48400.00
0005435990622	15720	Economy	48400.00
0005435990599	15720	Economy	48400.00
0005435990613	15720	Economy	48400.00
0005432427141	30847	Economy	14500.00
0005433476907	30847	Economy	14500.00
0005433476912	30847	Economy	14500.00
0005433476909	30847	Economy	14500.00
0005433476910	30847	Economy	14500.00
0005433476908	30847	Economy	14500.00
0005433476911	30847	Economy	14500.00
0005432909323	23850	Economy	13300.00
0005432909325	23850	Economy	13300.00
0005433468352	23850	Economy	13300.00
0005433468289	23850	Economy	12100.00
0005432909330	23850	Economy	12100.00
0005432909324	23850	Economy	12100.00
0005432909322	23850	Economy	12100.00
0005433468346	23850	Economy	12100.00
0005433468328	23850	Economy	12100.00
0005433468332	23850	Economy	12100.00
0005432909321	23850	Economy	12100.00
0005432909329	23850	Economy	12100.00
0005433468319	23850	Economy	12100.00
0005432909328	23850	Economy	12100.00
0005432909326	23850	Economy	12100.00
0005433468316	23850	Economy	12100.00
0005433468330	23850	Economy	12100.00
0005433468304	23850	Economy	12100.00
0005433468321	23850	Economy	12100.00
0005433468357	23850	Economy	12100.00
0005433468327	23850	Economy	12100.00
0005433468323	23850	Economy	12100.00
0005433468320	23850	Economy	12100.00
0005433468337	23850	Economy	12100.00
0005432909327	23850	Economy	12100.00
0005433468355	23850	Economy	12100.00
0005433468351	23850	Economy	12100.00
0005433468347	23850	Economy	12100.00
0005433468326	23850	Economy	12100.00
0005433468318	23850	Economy	12100.00
0005433468356	23850	Economy	12100.00
0005432909331	23850	Economy	12100.00
0005432336133	6379	Business	36600.00
0005432360759	6379	Business	36600.00
0005432360774	6379	Business	36600.00
0005432360744	6379	Business	36600.00
0005434149648	6379	Business	36600.00
0005432360773	6379	Business	36600.00
0005434149649	6379	Business	36600.00
0005435490215	6379	Business	36600.00
0005432363442	6379	Business	36600.00
0005435723034	6379	Business	36600.00
0005434149748	6379	Business	36600.00
0005432336131	6379	Business	36600.00
0005432360765	6379	Economy	12200.00
0005432360783	6379	Economy	12200.00
0005432360737	6379	Economy	12200.00
0005435723046	6379	Economy	12200.00
0005434149717	6379	Economy	12200.00
0005432360755	6379	Economy	12200.00
0005435490219	6379	Economy	12200.00
0005432360776	6379	Economy	12200.00
0005432360746	6379	Economy	12200.00
0005432360761	6379	Economy	12200.00
0005432360764	6379	Economy	12200.00
0005434149692	6379	Economy	12200.00
0005432062274	6379	Economy	12200.00
0005432336127	6379	Economy	12200.00
0005432360780	6379	Economy	12200.00
0005435177150	6379	Economy	12200.00
0005435177038	6379	Economy	12200.00
0005432062271	6379	Economy	12200.00
0005432336137	6379	Economy	12200.00
0005435176968	6379	Economy	12200.00
0005432360741	6379	Economy	12200.00
0005432360756	6379	Economy	12200.00
0005432360782	6379	Economy	12200.00
0005432360763	6379	Economy	12200.00
0005435177151	6379	Economy	12200.00
0005432360766	6379	Economy	12200.00
0005432336134	6379	Economy	12200.00
0005434149707	6379	Economy	12200.00
0005432360775	6379	Economy	12200.00
0005435490214	6379	Economy	12200.00
0005432360738	6379	Economy	12200.00
0005432062273	6379	Economy	12200.00
0005435177141	6379	Economy	12200.00
0005435177177	6379	Economy	12200.00
0005435177053	6379	Economy	12200.00
0005432360758	6379	Economy	12200.00
0005432336138	6379	Economy	13400.00
0005435177130	6379	Economy	13400.00
0005434149708	6379	Economy	13400.00
0005434149727	6379	Economy	13400.00
0005435177124	6379	Economy	13400.00
0005432336132	6379	Economy	13400.00
0005432336136	6379	Economy	12200.00
0005432336130	6379	Economy	12200.00
0005435177044	6379	Economy	12200.00
0005432360762	6379	Economy	12200.00
0005432360768	6379	Economy	12200.00
0005432360742	6379	Economy	12200.00
0005432360760	6379	Economy	12200.00
0005432360752	6379	Economy	12200.00
0005435177037	6379	Economy	12200.00
0005432360769	6379	Economy	12200.00
0005434149679	6379	Economy	12200.00
0005432360771	6379	Economy	12200.00
0005435723033	6379	Economy	12200.00
0005435177070	6379	Economy	12200.00
0005432062270	6379	Economy	12200.00
0005435177071	6379	Economy	12200.00
0005434149745	6379	Economy	12200.00
0005432360757	6379	Economy	12200.00
0005432360778	6379	Economy	12200.00
0005435177090	6379	Economy	12200.00
0005432062276	6379	Economy	12200.00
0005432360740	6379	Economy	12200.00
0005435176967	6379	Economy	12200.00
0005435490218	6379	Economy	12200.00
0005432336135	6379	Economy	12200.00
0005432360767	6379	Economy	12200.00
0005432360743	6379	Economy	12200.00
0005432062272	6379	Economy	12200.00
0005435177102	6379	Economy	12200.00
0005435177011	6379	Economy	12200.00
0005432360745	6379	Economy	12200.00
0005432360784	6379	Economy	12200.00
0005432360749	6379	Economy	12200.00
0005435177076	6379	Economy	12200.00
0005432360750	6379	Economy	12200.00
0005432363443	6379	Economy	12200.00
0005435177161	6379	Economy	12200.00
0005432360753	6379	Economy	12200.00
0005432363444	6379	Economy	12200.00
0005432336129	6379	Economy	12200.00
0005435177129	6379	Economy	12200.00
0005432360779	6379	Economy	12200.00
0005435177083	6379	Economy	12200.00
0005435177192	6379	Economy	12200.00
0005434149680	6379	Economy	12200.00
0005432360781	6379	Economy	12200.00
0005435177167	6379	Economy	12200.00
0005435177149	6379	Economy	12200.00
0005432360739	6379	Economy	12200.00
0005432360751	6379	Economy	12200.00
0005432062275	6379	Economy	12200.00
0005435177055	6379	Economy	12200.00
0005434149706	6379	Economy	12200.00
0005435177069	6379	Economy	12200.00
0005435177052	6379	Economy	12200.00
0005432360754	6379	Economy	12200.00
0005432360770	6379	Economy	12200.00
0005432360772	6379	Economy	12200.00
0005432360748	6379	Economy	12200.00
0005432360777	6379	Economy	12200.00
0005435177054	6379	Economy	12200.00
0005432336128	6379	Economy	12200.00
0005432360747	6379	Economy	12200.00
0005435177316	21037	Business	36600.00
0005435490260	21037	Business	36600.00
0005432335938	21037	Business	36600.00
0005432360314	21037	Business	36600.00
0005432360479	21037	Business	36600.00
0005435723063	21037	Business	36600.00
0005434149832	21037	Business	36600.00
0005432360395	21037	Business	36600.00
0005432360131	21037	Business	36600.00
0005432360480	21037	Business	36600.00
0005432360093	21037	Business	36600.00
0005432360274	21037	Economy	12200.00
0005432360178	21037	Economy	12200.00
0005432336027	21037	Economy	12200.00
0005432360433	21037	Economy	12200.00
0005435177299	21037	Economy	12200.00
0005432360485	21037	Economy	12200.00
0005432360094	21037	Economy	12200.00
0005435177311	21037	Economy	12200.00
0005432336007	21037	Economy	12200.00
0005435177315	21037	Economy	12200.00
0005435177295	21037	Economy	12200.00
0005432360313	21037	Economy	12200.00
0005432360251	21037	Economy	12200.00
0005432360463	21037	Economy	12200.00
0005432360385	21037	Economy	12200.00
0005434149827	21037	Economy	12200.00
0005432360169	21037	Economy	12200.00
0005432360255	21037	Economy	12200.00
0005434149828	21037	Economy	12200.00
0005435177303	21037	Economy	12200.00
0005435490261	21037	Economy	12200.00
0005432360564	21037	Economy	12200.00
0005432360378	21037	Economy	12200.00
0005432360319	21037	Economy	12200.00
0005435177305	21037	Economy	12200.00
0005432363414	21037	Economy	12200.00
0005432336038	21037	Economy	12200.00
0005432336035	21037	Economy	12200.00
0005435177294	21037	Economy	12200.00
0005432363413	21037	Economy	12200.00
0005432360535	21037	Economy	12200.00
0005432336024	21037	Economy	13400.00
0005432360294	21037	Economy	13400.00
0005435177289	21037	Economy	13400.00
0005435723062	21037	Economy	13400.00
0005432360503	21037	Economy	13400.00
0005432360366	21037	Economy	13400.00
0005434149825	21037	Economy	12200.00
0005435177301	21037	Economy	12200.00
0005432360327	21037	Economy	12200.00
0005435177293	21037	Economy	12200.00
0005432360392	21037	Economy	12200.00
0005432336037	21037	Economy	12200.00
0005432336022	21037	Economy	12200.00
0005432335939	21037	Economy	12200.00
0005432360299	21037	Economy	12200.00
0005434149826	21037	Economy	12200.00
0005432336023	21037	Economy	12200.00
0005435177292	21037	Economy	12200.00
0005432360275	21037	Economy	12200.00
0005435177298	21037	Economy	12200.00
0005435177297	21037	Economy	12200.00
0005434149831	21037	Economy	12200.00
0005435177317	21037	Economy	12200.00
0005432360394	21037	Economy	12200.00
0005435177291	21037	Economy	12200.00
0005434149822	21037	Economy	12200.00
0005435177296	21037	Economy	12200.00
0005432360379	21037	Economy	12200.00
0005432360506	21037	Economy	12200.00
0005434149823	21037	Economy	12200.00
0005435177300	21037	Economy	12200.00
0005432360515	21037	Economy	12200.00
0005435177309	21037	Economy	12200.00
0005434149824	21037	Economy	12200.00
0005432336008	21037	Economy	12200.00
0005432336062	21037	Economy	12200.00
0005434149830	21037	Economy	12200.00
0005432052771	21037	Economy	12200.00
0005435177312	21037	Economy	12200.00
0005435177318	21037	Economy	12200.00
0005435723065	21037	Economy	12200.00
0005435177290	21037	Economy	12200.00
0005435490263	21037	Economy	12200.00
0005432360085	21037	Economy	12200.00
0005435177307	21037	Economy	12200.00
0005432336028	21037	Economy	12200.00
0005432360393	21037	Economy	12200.00
0005432360320	21037	Economy	12200.00
0005435177308	21037	Economy	12200.00
0005435177314	21037	Economy	12200.00
0005435177302	21037	Economy	12200.00
0005434149829	21037	Economy	12200.00
0005432360256	21037	Economy	12200.00
0005432052772	21037	Economy	12200.00
0005432052770	21037	Economy	12200.00
0005435177310	21037	Economy	12200.00
0005432360514	21037	Economy	12200.00
0005435177306	21037	Economy	12200.00
0005435723064	21037	Economy	12200.00
0005435490262	21037	Economy	12200.00
0005432360360	21037	Economy	12200.00
0005435177313	21037	Economy	12200.00
0005435177304	21037	Economy	12200.00
0005432335999	21037	Economy	12200.00
0005434463920	17692	Economy	3400.00
0005434458826	17692	Economy	3100.00
0005434458799	17692	Economy	3100.00
0005434458800	17692	Economy	3100.00
0005434458787	17692	Economy	3100.00
0005434458822	17692	Economy	3100.00
0005434458748	17692	Economy	3100.00
0005434458801	17692	Economy	3100.00
0005434458835	17692	Economy	3100.00
0005434458845	17692	Economy	3100.00
0005434448320	17692	Economy	3100.00
0005434458825	17692	Economy	3100.00
0005434461650	17692	Economy	3100.00
0005434458746	17692	Economy	3100.00
0005434458962	17692	Economy	3100.00
0005434458768	17692	Economy	3100.00
0005434458751	17692	Economy	3100.00
0005434458821	17692	Economy	3100.00
0005434186223	17692	Economy	3100.00
0005434458834	17692	Economy	3100.00
0005434458817	17692	Economy	3100.00
0005434458803	17692	Economy	3100.00
0005434458860	17692	Economy	3100.00
0005434186224	17692	Economy	3100.00
0005434458750	17692	Economy	3100.00
0005434458872	17692	Economy	3100.00
0005434186222	17692	Economy	3100.00
0005434458963	17692	Economy	3100.00
0005434458859	17692	Economy	3100.00
0005434458747	17692	Economy	3100.00
0005434186189	29103	Economy	3400.00
0005434458969	29103	Economy	3400.00
0005434462805	29103	Economy	3400.00
0005434458966	29103	Economy	3100.00
0005434458978	29103	Economy	3100.00
0005434186184	29103	Economy	3100.00
0005434458967	29103	Economy	3100.00
0005434458972	29103	Economy	3100.00
0005434462808	29103	Economy	3100.00
0005434458981	29103	Economy	3100.00
0005434458976	29103	Economy	3100.00
0005434458974	29103	Economy	3100.00
0005434458982	29103	Economy	3100.00
0005434448340	29103	Economy	3100.00
0005434458975	29103	Economy	3100.00
0005434463944	29103	Economy	3100.00
0005434448342	29103	Economy	3100.00
0005434458980	29103	Economy	3100.00
0005434458977	29103	Economy	3100.00
0005434458979	29103	Economy	3100.00
0005434462806	29103	Economy	3100.00
0005434463945	29103	Economy	3100.00
0005434186190	29103	Economy	3100.00
0005434458970	29103	Economy	3100.00
0005434458985	29103	Economy	3100.00
0005434458968	29103	Economy	3100.00
0005434448339	29103	Economy	3100.00
0005434458984	29103	Economy	3100.00
0005434458971	29103	Economy	3100.00
0005434186191	29103	Economy	3100.00
0005434186183	29103	Economy	3100.00
0005434462807	29103	Economy	3100.00
0005434448338	29103	Economy	3100.00
0005434448341	29103	Economy	3100.00
0005434458973	29103	Economy	3100.00
0005434458986	29103	Economy	3100.00
0005434458983	29103	Economy	3100.00
0005432658581	21834	Business	185300.00
0005432665259	21834	Business	185300.00
0005432665253	21834	Business	185300.00
0005432665247	21834	Business	185300.00
0005432665251	21834	Business	185300.00
0005432658569	21834	Business	185300.00
0005432658580	21834	Business	185300.00
0005432661904	21834	Business	185300.00
0005432665257	21834	Economy	61800.00
0005432665265	21834	Economy	61800.00
0005432661910	21834	Economy	61800.00
0005432665254	21834	Economy	61800.00
0005432658573	21834	Economy	61800.00
0005432661901	21834	Economy	61800.00
0005432665252	21834	Economy	61800.00
0005432661912	21834	Economy	61800.00
0005432661903	21834	Economy	61800.00
0005432658558	21834	Economy	61800.00
0005432658576	21834	Economy	61800.00
0005432665260	21834	Economy	61800.00
0005432658557	21834	Economy	61800.00
0005432661906	21834	Economy	61800.00
0005432661902	21834	Economy	61800.00
0005432661909	21834	Economy	61800.00
0005432658574	21834	Economy	61800.00
0005432665248	21834	Economy	61800.00
0005432658564	21834	Economy	61800.00
0005432658571	21834	Economy	61800.00
0005432658575	21834	Economy	61800.00
0005432658577	21834	Economy	61800.00
0005432661905	21834	Economy	61800.00
0005432658568	21834	Economy	61800.00
0005432665258	21834	Economy	61800.00
0005432665256	21834	Economy	61800.00
0005432661899	21834	Economy	61800.00
0005432665267	21834	Economy	61800.00
0005432658562	21834	Economy	61800.00
0005432658570	21834	Economy	61800.00
0005432658560	21834	Economy	61800.00
0005432665266	21834	Economy	61800.00
0005432661898	21834	Economy	61800.00
0005432661907	21834	Economy	61800.00
0005432658563	21834	Economy	61800.00
0005432665246	21834	Economy	61800.00
0005432665255	21834	Economy	61800.00
0005432658559	21834	Economy	61800.00
0005432661908	21834	Economy	61800.00
0005432604644	21452	Economy	7300.00
0005432604635	21452	Economy	7300.00
0005432604632	21452	Economy	7300.00
0005432604648	21452	Economy	6600.00
0005432604628	21452	Economy	6600.00
0005432604617	21452	Economy	6600.00
0005432604637	21452	Economy	6600.00
0005432604622	21452	Economy	6600.00
0005432604650	21452	Economy	6600.00
0005432604655	21452	Economy	6600.00
0005432604626	21452	Economy	6600.00
0005432604624	21452	Economy	6600.00
0005432604618	21452	Economy	6600.00
0005432604640	21452	Economy	6600.00
0005432604619	21452	Economy	6600.00
0005432604638	21452	Economy	6600.00
0005432604620	21452	Economy	6600.00
0005432604621	21452	Economy	6600.00
0005432604630	21452	Economy	6600.00
0005432604651	21452	Economy	6600.00
0005432604646	21452	Economy	6600.00
0005432604616	21452	Economy	6600.00
0005432604641	21452	Economy	6600.00
0005432604654	21452	Economy	6600.00
0005432604627	21452	Economy	6600.00
0005432604642	21452	Economy	6600.00
0005432604633	21452	Economy	6600.00
0005432604636	21452	Economy	6600.00
0005432604652	21452	Economy	6600.00
0005432604634	21452	Economy	6600.00
0005432604625	21452	Economy	6600.00
0005432604631	21452	Economy	6600.00
0005432604629	21452	Economy	6600.00
0005432604615	21452	Economy	6600.00
0005432604639	21452	Economy	6600.00
0005432604623	21452	Economy	6600.00
0005432604645	21452	Economy	6600.00
0005432604647	21452	Economy	6600.00
0005435218112	21452	Economy	6600.00
0005432604649	21452	Economy	6600.00
0005432604643	21452	Economy	6600.00
0005432604653	21452	Economy	6600.00
0005432604299	31675	Economy	7300.00
0005432604172	31675	Economy	7300.00
0005432604291	31675	Economy	6600.00
0005432604386	31675	Economy	6600.00
0005432604010	31675	Economy	6600.00
0005432604324	31675	Economy	6600.00
0005432604077	31675	Economy	6600.00
0005432604274	31675	Economy	6600.00
0005432604222	31675	Economy	6600.00
0005432604148	31675	Economy	6600.00
0005432604051	31675	Economy	6600.00
0005432604273	31675	Economy	6600.00
0005432604149	31675	Economy	6600.00
0005432604534	31675	Economy	6600.00
0005432604446	31675	Economy	6600.00
0005432604410	31675	Economy	6600.00
0005432604287	31675	Economy	6600.00
0005432604281	31675	Economy	6600.00
0005432604191	31675	Economy	6600.00
0005432604190	31675	Economy	6600.00
0005432604309	31675	Economy	6600.00
0005432604161	31675	Economy	6600.00
0005432604271	31675	Economy	6600.00
0005432604384	31675	Economy	6600.00
0005432604211	31675	Economy	6600.00
0005432604310	31675	Economy	6600.00
0005432604170	31675	Economy	6600.00
0005432604413	31675	Economy	6600.00
0005432604162	31675	Economy	6600.00
0005432604171	31675	Economy	6600.00
0005432604297	31675	Economy	6600.00
0005432604213	31675	Economy	6600.00
0005432604192	31675	Economy	6600.00
0005432604221	31675	Economy	6600.00
0005432604157	31675	Economy	6600.00
0005432604346	31675	Economy	6600.00
0005432604323	31675	Economy	6600.00
0005432604225	31675	Economy	6600.00
0005432604052	31675	Economy	6600.00
0005432604385	31675	Economy	6600.00
0005432604296	31675	Economy	6600.00
0005432604412	31675	Economy	6600.00
0005432604292	31675	Economy	6600.00
0005432604229	31675	Economy	6600.00
0005433293305	29594	Economy	19500.00
0005433293303	29594	Economy	17800.00
0005435154594	29594	Economy	17800.00
0005433293301	29594	Economy	17800.00
0005433293306	29594	Economy	17800.00
0005433293304	29594	Economy	17800.00
0005433293309	29594	Economy	17800.00
0005433293310	29594	Economy	17800.00
0005433293312	29594	Economy	17800.00
0005435154595	29594	Economy	17800.00
0005433293302	29594	Economy	17800.00
0005433293308	29594	Economy	17800.00
0005433293307	29594	Economy	17800.00
0005435154591	29594	Economy	17800.00
0005433293313	29594	Economy	17800.00
0005435154593	29594	Economy	17800.00
0005435154592	29594	Economy	17800.00
0005433293311	29594	Economy	17800.00
0005433473345	6676	Economy	14000.00
0005433473337	6676	Economy	14000.00
0005435257231	6676	Economy	12700.00
0005433473334	6676	Economy	12700.00
0005435257224	6676	Economy	12700.00
0005433473339	6676	Economy	12700.00
0005435257243	6676	Economy	12700.00
0005435257223	6676	Economy	12700.00
0005433473342	6676	Economy	12700.00
0005435257227	6676	Economy	12700.00
0005435257239	6676	Economy	12700.00
0005433473340	6676	Economy	12700.00
0005435257236	6676	Economy	12700.00
0005435257228	6676	Economy	12700.00
0005435257244	6676	Economy	12700.00
0005433473336	6676	Economy	12700.00
0005435257238	6676	Economy	12700.00
0005433473333	6676	Economy	12700.00
0005433473330	6676	Economy	12700.00
0005433473329	6676	Economy	12700.00
0005433473344	6676	Economy	12700.00
0005433473341	6676	Economy	12700.00
0005433473331	6676	Economy	12700.00
0005433473335	6676	Economy	12700.00
0005433473338	6676	Economy	12700.00
0005435257229	6676	Economy	12700.00
0005435257230	6676	Economy	12700.00
0005433473332	6676	Economy	12700.00
0005433473343	6676	Economy	12700.00
0005435257237	6676	Economy	12700.00
0005433473346	6676	Economy	12700.00
0005435257279	23896	Economy	14000.00
0005435257284	23896	Economy	14000.00
0005433473265	23896	Economy	14000.00
0005433473256	23896	Economy	12700.00
0005433473251	23896	Economy	12700.00
0005433473253	23896	Economy	12700.00
0005433473214	23896	Economy	12700.00
0005435257278	23896	Economy	12700.00
0005435257276	23896	Economy	12700.00
0005433473266	23896	Economy	12700.00
0005433473246	23896	Economy	12700.00
0005435257277	23896	Economy	12700.00
0005433473249	23896	Economy	12700.00
0005433473267	23896	Economy	12700.00
0005435257283	23896	Economy	12700.00
0005433473252	23896	Economy	12700.00
0005433473271	23896	Economy	12700.00
0005433473255	23896	Economy	12700.00
0005433473248	23896	Economy	12700.00
0005435257281	23896	Economy	12700.00
0005435257282	23896	Economy	12700.00
0005433473236	23896	Economy	12700.00
0005435257285	23896	Economy	12700.00
0005435257275	23896	Economy	12700.00
0005435257280	23896	Economy	12700.00
0005433473247	23896	Economy	12700.00
0005434606829	18937	Economy	6600.00
0005434606821	18937	Economy	6600.00
0005434606822	18937	Economy	6600.00
0005434606857	22370	Economy	6600.00
0005434604924	22370	Economy	6600.00
0005434604920	22370	Economy	6600.00
0005434604923	22370	Economy	6600.00
0005435904707	22370	Economy	6600.00
0005434606854	22370	Economy	6600.00
0005434606852	22370	Economy	6600.00
0005434604922	22370	Economy	6600.00
0005434606853	22370	Economy	6600.00
0005434606855	22370	Economy	6600.00
0005434606856	22370	Economy	6600.00
0005434604921	22370	Economy	6600.00
0005434522476	3852	Economy	22600.00
0005435904401	3852	Economy	22600.00
0005434522471	3852	Economy	22600.00
0005434522478	3852	Economy	22600.00
0005435904406	3852	Economy	22600.00
0005434522477	3852	Economy	22600.00
0005434522475	3852	Economy	22600.00
0005434522474	3852	Economy	22600.00
0005434602917	3852	Economy	22600.00
0005434522473	3852	Economy	22600.00
0005434602919	3852	Economy	22600.00
0005434522472	3852	Economy	22600.00
0005434602920	3852	Economy	22600.00
0005434602921	3852	Economy	22600.00
0005435904400	3852	Economy	22600.00
0005434602922	3852	Economy	22600.00
0005435904405	3852	Economy	22600.00
0005435904402	3852	Economy	22600.00
0005435904399	3852	Economy	22600.00
0005434602918	3852	Economy	22600.00
0005434604898	19050	Economy	22600.00
0005434602890	19050	Economy	22600.00
0005434604890	19050	Economy	22600.00
0005435904427	19050	Economy	22600.00
0005434522451	19050	Economy	22600.00
0005434604900	19050	Economy	22600.00
0005434604886	19050	Economy	22600.00
0005434602885	19050	Economy	22600.00
0005435904424	19050	Economy	22600.00
0005435904426	19050	Economy	22600.00
0005434604896	19050	Economy	22600.00
0005435904423	19050	Economy	22600.00
0005435904425	19050	Economy	22600.00
0005434602899	19050	Economy	22600.00
0005434604895	19050	Economy	22600.00
0005434604903	19050	Economy	22600.00
0005434602893	19050	Economy	22600.00
0005434522431	19050	Economy	22600.00
0005434604889	19050	Economy	22600.00
0005434602892	19050	Economy	22600.00
0005434602887	19050	Economy	22600.00
0005435904708	19050	Economy	22600.00
0005432747865	377	Business	44500.00
0005432891009	377	Business	44500.00
0005432747854	377	Business	44500.00
0005432747853	377	Business	44500.00
0005433293258	377	Business	44500.00
0005433293277	377	Business	44500.00
0005432747873	377	Business	44500.00
0005432747878	377	Business	44500.00
0005432747885	377	Business	44500.00
0005432747868	377	Business	44500.00
0005432890955	377	Business	44500.00
0005432220035	377	Economy	14800.00
0005432891057	377	Economy	14800.00
0005432749801	377	Economy	14800.00
0005432751552	377	Economy	14800.00
0005432890972	377	Economy	14800.00
0005432747857	377	Economy	14800.00
0005432747860	377	Economy	14800.00
0005432747861	377	Economy	14800.00
0005432747862	377	Economy	16300.00
0005433293231	377	Economy	16300.00
0005432890982	377	Economy	16300.00
0005432747864	377	Economy	16300.00
0005432749800	377	Economy	16300.00
0005432890980	377	Economy	14800.00
0005432890954	377	Economy	14800.00
0005432220036	377	Economy	14800.00
0005432747869	377	Economy	14800.00
0005432747880	377	Economy	14800.00
0005432751549	377	Economy	14800.00
0005432747863	377	Economy	14800.00
0005432753325	377	Economy	14800.00
0005432747875	377	Economy	14800.00
0005432747883	377	Economy	14800.00
0005432890999	377	Economy	14800.00
0005432890994	377	Economy	14800.00
0005432890976	377	Economy	14800.00
0005432747888	377	Economy	14800.00
0005432747851	377	Economy	14800.00
0005432747858	377	Economy	14800.00
0005435154609	377	Economy	14800.00
0005432747859	377	Economy	14800.00
0005432890981	377	Economy	14800.00
0005432747879	377	Economy	14800.00
0005432890957	377	Economy	14800.00
0005432220037	377	Economy	14800.00
0005432747889	377	Economy	14800.00
0005432747871	377	Economy	14800.00
0005432747886	377	Economy	14800.00
0005433293263	377	Economy	14800.00
0005432891018	377	Economy	14800.00
0005432747874	377	Economy	14800.00
0005432747855	377	Economy	14800.00
0005433293276	377	Economy	14800.00
0005432220039	377	Economy	14800.00
0005432890977	377	Economy	14800.00
0005432747870	377	Economy	14800.00
0005432747882	377	Economy	14800.00
0005432890995	377	Economy	14800.00
0005432890964	377	Economy	14800.00
0005432747881	377	Economy	14800.00
0005432751551	377	Economy	14800.00
0005435154607	377	Economy	14800.00
0005432747884	377	Economy	14800.00
0005432747866	377	Economy	14800.00
0005432747852	377	Economy	14800.00
0005432751550	377	Economy	14800.00
0005432747887	377	Economy	14800.00
0005433293262	377	Economy	14800.00
0005432747856	377	Economy	14800.00
0005435154606	377	Economy	14800.00
0005432890956	377	Economy	14800.00
0005432220040	377	Economy	14800.00
0005432747877	377	Economy	14800.00
0005433293225	377	Economy	14800.00
0005432747872	377	Economy	14800.00
0005432753326	377	Economy	14800.00
0005432747876	377	Economy	14800.00
0005432891020	377	Economy	14800.00
0005432891019	377	Economy	14800.00
0005432747867	377	Economy	14800.00
0005432220038	377	Economy	14800.00
0005435154608	377	Economy	14800.00
0005432753324	377	Economy	14800.00
0005432890903	377	Economy	14800.00
0005432749788	12086	Business	44500.00
0005432747650	12086	Business	44500.00
0005432747345	12086	Business	44500.00
0005432891173	12086	Business	44500.00
0005432756830	12086	Business	44500.00
0005432747610	12086	Business	44500.00
0005432747359	12086	Business	44500.00
0005432891184	12086	Business	44500.00
0005432747676	12086	Business	44500.00
0005432747576	12086	Business	44500.00
0005432747685	12086	Business	44500.00
0005432891189	12086	Economy	14800.00
0005432891176	12086	Economy	14800.00
0005432891170	12086	Economy	14800.00
0005432747358	12086	Economy	14800.00
0005432749784	12086	Economy	14800.00
0005432756840	12086	Economy	14800.00
0005432891187	12086	Economy	14800.00
0005432747567	12086	Economy	14800.00
0005432891179	12086	Economy	14800.00
0005432747341	12086	Economy	16300.00
0005432747686	12086	Economy	16300.00
0005432214821	12086	Economy	16300.00
0005432747439	12086	Economy	14800.00
0005432747455	12086	Economy	14800.00
0005432756849	12086	Economy	14800.00
0005432747663	12086	Economy	14800.00
0005432747554	12086	Economy	14800.00
0005432891181	12086	Economy	14800.00
0005432747575	12086	Economy	14800.00
0005432891171	12086	Economy	14800.00
0005432747615	12086	Economy	14800.00
0005432747606	12086	Economy	14800.00
0005432747583	12086	Economy	14800.00
0005432747619	12086	Economy	14800.00
0005432891185	12086	Economy	14800.00
0005432747599	12086	Economy	14800.00
0005432747607	12086	Economy	14800.00
0005432747560	12086	Economy	14800.00
0005432747555	12086	Economy	14800.00
0005432747582	12086	Economy	14800.00
0005432753305	12086	Economy	14800.00
0005432891180	12086	Economy	14800.00
0005432747651	12086	Economy	14800.00
0005432747521	12086	Economy	14800.00
0005432747566	12086	Economy	14800.00
0005432891186	12086	Economy	14800.00
0005432891188	12086	Economy	14800.00
0005432891183	12086	Economy	14800.00
0005432747556	12086	Economy	14800.00
0005432749777	12086	Economy	14800.00
0005432891178	12086	Economy	14800.00
0005432756850	12086	Economy	14800.00
0005432891172	12086	Economy	14800.00
0005432747581	12086	Economy	14800.00
0005432747549	12086	Economy	14800.00
0005432747525	12086	Economy	14800.00
0005432747640	12086	Economy	14800.00
0005432891182	12086	Economy	14800.00
0005432747559	12086	Economy	14800.00
0005432749776	12086	Economy	14800.00
0005432747505	12086	Economy	14800.00
0005432891175	12086	Economy	14800.00
0005432747557	12086	Economy	14800.00
0005432749771	12086	Economy	14800.00
0005434153542	12086	Economy	14800.00
0005432749781	12086	Economy	14800.00
0005432747541	12086	Economy	14800.00
0005432891174	12086	Economy	14800.00
0005432214822	12086	Economy	14800.00
0005434153543	12086	Economy	14800.00
0005432749775	12086	Economy	14800.00
0005432891177	12086	Economy	14800.00
0005432747641	12086	Economy	14800.00
0005433525122	18997	Economy	28200.00
0005432927969	18997	Economy	25700.00
0005433525116	18997	Economy	25700.00
0005433525124	18997	Economy	25700.00
0005433533334	18997	Economy	25700.00
0005432927976	18997	Economy	25700.00
0005432927982	18997	Economy	25700.00
0005433533335	18997	Economy	25700.00
0005433525114	18997	Economy	25700.00
0005433525123	18997	Economy	25700.00
0005432927973	18997	Economy	25700.00
0005433525120	18997	Economy	25700.00
0005433531320	18997	Economy	25700.00
0005432927951	18997	Economy	25700.00
0005433531321	18997	Economy	25700.00
0005432927985	18997	Economy	25700.00
0005433533337	18997	Economy	25700.00
0005433531322	18997	Economy	25700.00
0005433525119	18997	Economy	25700.00
0005433525113	18997	Economy	25700.00
0005433525117	18997	Economy	25700.00
0005433525125	18997	Economy	25700.00
0005433525121	18997	Economy	25700.00
0005432927992	18997	Economy	25700.00
0005433525118	18997	Economy	25700.00
0005433525115	18997	Economy	25700.00
0005432927972	18997	Economy	25700.00
0005433531323	18997	Economy	25700.00
0005432927989	18997	Economy	25700.00
0005433533336	18997	Economy	25700.00
0005432927975	18997	Economy	25700.00
0005432928033	32476	Economy	28200.00
0005433525056	32476	Economy	28200.00
0005433525047	32476	Economy	25700.00
0005432928032	32476	Economy	25700.00
0005433525061	32476	Economy	25700.00
0005433531314	32476	Economy	25700.00
0005433525038	32476	Economy	25700.00
0005433525005	32476	Economy	25700.00
0005433525006	32476	Economy	25700.00
0005432928031	32476	Economy	25700.00
0005432928030	32476	Economy	25700.00
0005433525003	32476	Economy	25700.00
0005433525048	32476	Economy	25700.00
0005433525029	32476	Economy	25700.00
0005433525026	32476	Economy	25700.00
0005433525027	32476	Economy	25700.00
0005433525025	32476	Economy	25700.00
0005433525037	32476	Economy	25700.00
0005432928029	32476	Economy	25700.00
0005433525041	32476	Economy	25700.00
0005433525030	32476	Economy	25700.00
0005433525034	32476	Economy	25700.00
0005433525028	32476	Economy	25700.00
0005433527241	32476	Economy	25700.00
0005433525004	32476	Economy	25700.00
0005433525036	32476	Economy	25700.00
0005435372952	5284	Business	84000.00
0005434558337	5284	Business	84000.00
0005435178994	5284	Business	84000.00
0005434824586	5284	Business	84000.00
0005435304154	5284	Business	84000.00
0005434824669	5284	Business	84000.00
0005434824574	5284	Business	84000.00
0005435150145	5284	Business	84000.00
0005434824678	5284	Business	84000.00
0005434558344	5284	Business	84000.00
0005435373234	5284	Business	84000.00
0005434824626	5284	Business	84000.00
0005434824640	5284	Business	84000.00
0005434824581	5284	Business	84000.00
0005432396276	5284	Business	84000.00
0005435373029	5284	Business	84000.00
0005435150137	5284	Business	84000.00
0005434824649	5284	Business	84000.00
0005434824561	5284	Business	84000.00
0005434824635	5284	Business	84000.00
0005435373357	5284	Comfort	47600.00
0005434824598	5284	Business	84000.00
0005434824615	5284	Comfort	47600.00
0005435735135	5284	Comfort	47600.00
0005434824655	5284	Comfort	47600.00
0005432121448	5284	Comfort	47600.00
0005435304153	5284	Comfort	47600.00
0005435373411	5284	Comfort	47600.00
0005435150136	5284	Comfort	47600.00
0005434824605	5284	Comfort	47600.00
0005434558341	5284	Comfort	47600.00
0005434824684	5284	Comfort	47600.00
0005434824654	5284	Comfort	47600.00
0005435386577	5284	Comfort	47600.00
0005434824662	5284	Comfort	47600.00
0005435373408	5284	Comfort	47600.00
0005434824580	5284	Comfort	47600.00
0005434824570	5284	Comfort	47600.00
0005435373319	5284	Comfort	47600.00
0005434824596	5284	Comfort	47600.00
0005434824632	5284	Comfort	47600.00
0005434824628	5284	Comfort	47600.00
0005434824562	5284	Comfort	47600.00
0005435373477	5284	Comfort	47600.00
0005434824602	5284	Comfort	47600.00
0005435373196	5284	Comfort	47600.00
0005435372700	5284	Comfort	47600.00
0005434664978	5284	Comfort	47600.00
0005435373404	5284	Comfort	47600.00
0005434824676	5284	Comfort	47600.00
0005434824577	5284	Comfort	47600.00
0005434824671	5284	Comfort	47600.00
0005435386571	5284	Comfort	47600.00
0005435373124	5284	Comfort	47600.00
0005432121450	5284	Comfort	47600.00
0005435373396	5284	Comfort	47600.00
0005434824623	5284	Comfort	47600.00
0005434824588	5284	Economy	28000.00
0005434824590	5284	Comfort	47600.00
0005435373004	5284	Economy	28000.00
0005435386583	5284	Economy	28000.00
0005434824568	5284	Economy	28000.00
0005435373131	5284	Economy	28000.00
0005434824601	5284	Economy	28000.00
0005434824643	5284	Economy	28000.00
0005435735131	5284	Economy	28000.00
0005435373100	5284	Economy	28000.00
0005435178995	5284	Economy	28000.00
0005434664977	5284	Economy	28000.00
0005434824683	5284	Economy	28000.00
0005435735112	5284	Economy	28000.00
0005435373114	5284	Economy	28000.00
0005435150139	5284	Economy	28000.00
0005434831186	5284	Economy	28000.00
0005434824641	5284	Economy	28000.00
0005434824621	5284	Economy	28000.00
0005434824631	5284	Economy	28000.00
0005435373410	5284	Economy	28000.00
0005434828719	5284	Economy	28000.00
0005435373397	5284	Economy	28000.00
0005434824634	5284	Economy	28000.00
0005435373255	5284	Economy	28000.00
0005434824651	5284	Economy	28000.00
0005434828716	5284	Economy	28000.00
0005435373272	5284	Economy	28000.00
0005434824567	5284	Economy	28000.00
0005434824647	5284	Economy	28000.00
0005434558340	5284	Economy	28000.00
0005434824618	5284	Economy	28000.00
0005435373270	5284	Economy	28000.00
0005434824630	5284	Economy	28000.00
0005435373212	5284	Economy	28000.00
0005434824681	5284	Economy	28000.00
0005434824582	5284	Economy	28000.00
0005435373120	5284	Economy	28000.00
0005434824589	5284	Economy	28000.00
0005432121452	5284	Economy	28000.00
0005435735110	5284	Economy	28000.00
0005434824583	5284	Economy	28000.00
0005435373387	5284	Economy	28000.00
0005434824666	5284	Economy	28000.00
0005434824608	5284	Economy	28000.00
0005434558339	5284	Economy	28000.00
0005434824559	5284	Economy	28000.00
0005434824650	5284	Economy	28000.00
0005434824656	5284	Economy	28000.00
0005435150141	5284	Economy	28000.00
0005432121444	5284	Economy	28000.00
0005434824675	5284	Economy	28000.00
0005435150147	5284	Economy	28000.00
0005434824563	5284	Economy	28000.00
0005435373086	5284	Economy	28000.00
0005435150148	5284	Economy	30800.00
0005435150143	5284	Economy	28000.00
0005435373388	5284	Economy	30800.00
0005434824594	5284	Economy	28000.00
0005434824565	5284	Economy	30800.00
0005435373093	5284	Economy	28000.00
0005434824652	5284	Economy	28000.00
0005435373184	5284	Economy	28000.00
0005434824663	5284	Economy	28000.00
0005434824667	5284	Economy	28000.00
0005434824622	5284	Economy	28000.00
0005432121445	5284	Economy	28000.00
0005435386572	5284	Economy	28000.00
0005434824680	5284	Economy	28000.00
0005435373484	5284	Economy	28000.00
0005435373348	5284	Economy	28000.00
0005435373215	5284	Economy	28000.00
0005434824578	5284	Economy	28000.00
0005434824573	5284	Economy	28000.00
0005435661924	5284	Economy	28000.00
0005434824610	5284	Economy	28000.00
0005432121453	5284	Economy	28000.00
0005435373054	5284	Economy	28000.00
0005434824648	5284	Economy	28000.00
0005435372958	5284	Economy	28000.00
0005435735111	5284	Economy	28000.00
0005432823446	5284	Economy	28000.00
0005435373423	5284	Economy	28000.00
0005432394137	5284	Economy	28000.00
0005434824609	5284	Economy	28000.00
0005434824637	5284	Economy	28000.00
0005434558343	5284	Economy	28000.00
0005434824672	5284	Economy	28000.00
0005435373311	5284	Economy	28000.00
0005434824633	5284	Economy	28000.00
0005434824558	5284	Economy	28000.00
0005435373320	5284	Economy	28000.00
0005434824686	5284	Economy	28000.00
0005434824646	5284	Economy	28000.00
0005432823447	5284	Economy	28000.00
0005435372901	5284	Economy	28000.00
0005434824569	5284	Economy	28000.00
0005435373102	5284	Economy	28000.00
0005434824627	5284	Economy	28000.00
0005434831183	5284	Economy	28000.00
0005432396275	5284	Economy	28000.00
0005435373269	5284	Economy	28000.00
0005434824616	5284	Economy	28000.00
0005432121451	5284	Economy	28000.00
0005435373205	5284	Economy	28000.00
0005434824645	5284	Economy	28000.00
0005434824664	5284	Economy	28000.00
0005434558342	5284	Economy	28000.00
0005435179693	5284	Economy	28000.00
0005434824591	5284	Economy	28000.00
0005435735132	5284	Economy	28000.00
0005434824660	5284	Economy	28000.00
0005432396277	5284	Economy	28000.00
0005434824642	5284	Economy	28000.00
0005435373309	5284	Economy	28000.00
0005434824679	5284	Economy	28000.00
0005434824607	5284	Economy	28000.00
0005435150142	5284	Economy	28000.00
0005434824636	5284	Economy	28000.00
0005434824682	5284	Economy	28000.00
0005434824560	5284	Economy	28000.00
0005434824659	5284	Economy	28000.00
0005434824592	5284	Economy	28000.00
0005434824603	5284	Economy	28000.00
0005434824639	5284	Economy	28000.00
0005432121443	5284	Economy	28000.00
0005435373094	5284	Economy	28000.00
0005435373409	5284	Economy	28000.00
0005432121455	5284	Economy	28000.00
0005435150138	5284	Economy	28000.00
0005434824597	5284	Economy	28000.00
0005434824665	5284	Economy	28000.00
0005435373308	5284	Economy	28000.00
0005435304167	5284	Economy	28000.00
0005434824584	5284	Economy	28000.00
0005432394138	5284	Economy	28000.00
0005435304149	5284	Economy	28000.00
0005432121456	5284	Economy	28000.00
0005435373163	5284	Economy	28000.00
0005435373190	5284	Economy	28000.00
0005435386576	5284	Economy	28000.00
0005434824658	5284	Economy	28000.00
0005434824677	5284	Economy	28000.00
0005434824587	5284	Economy	28000.00
0005434824674	5284	Economy	28000.00
0005435373395	5284	Economy	28000.00
0005434824564	5284	Economy	28000.00
0005434824604	5284	Economy	28000.00
0005434824595	5284	Economy	28000.00
0005434824620	5284	Economy	28000.00
0005434828717	5284	Economy	28000.00
0005435373213	5284	Economy	28000.00
0005435373427	5284	Economy	30800.00
0005434824585	5284	Economy	28000.00
0005435373278	5284	Economy	30800.00
0005434824614	5284	Economy	30800.00
0005435373030	5284	Economy	30800.00
0005435386570	5284	Economy	28000.00
0005434824612	5284	Economy	28000.00
0005434824576	5284	Economy	28000.00
0005434831184	5284	Economy	28000.00
0005435373092	5284	Economy	28000.00
0005435373416	5284	Economy	28000.00
0005435373398	5284	Economy	28000.00
0005435372900	5284	Economy	28000.00
0005435150146	5284	Economy	28000.00
0005435373307	5284	Economy	28000.00
0005434558334	5284	Economy	28000.00
0005434558336	5284	Economy	28000.00
0005435373191	5284	Economy	28000.00
0005435373489	5284	Economy	28000.00
0005434824668	5284	Economy	28000.00
0005432121449	5284	Economy	28000.00
0005435373316	5284	Economy	28000.00
0005432121446	5284	Economy	28000.00
0005435373189	5284	Economy	28000.00
0005434824617	5284	Economy	28000.00
0005435373172	5284	Economy	28000.00
0005434824611	5284	Economy	28000.00
0005432121454	5284	Economy	28000.00
0005435373405	5284	Economy	28000.00
0005434824572	5284	Economy	28000.00
0005435179692	5284	Economy	28000.00
0005435373085	5284	Economy	28000.00
0005432823445	5284	Economy	28000.00
0005434824624	5284	Economy	28000.00
0005435373289	5284	Economy	28000.00
0005434824670	5284	Economy	28000.00
0005435373363	5284	Economy	28000.00
0005434824575	5284	Economy	28000.00
0005435150140	5284	Economy	28000.00
0005434828720	5284	Economy	28000.00
0005432121447	5284	Economy	28000.00
0005434664976	5284	Economy	28000.00
0005435373364	5284	Economy	28000.00
0005435373113	5284	Economy	28000.00
0005434824619	5284	Economy	28000.00
0005435373132	5284	Economy	28000.00
0005435299792	5284	Economy	28000.00
0005434824644	5284	Economy	28000.00
0005432823450	5284	Economy	28000.00
0005435150144	5284	Economy	28000.00
0005435373244	5284	Economy	28000.00
0005435150135	5284	Economy	28000.00
0005434828718	5284	Economy	28000.00
0005434824566	5284	Economy	28000.00
0005434558338	5284	Economy	28000.00
0005434824657	5284	Economy	28000.00
0005434824638	5284	Economy	28000.00
0005435373271	5284	Economy	28000.00
0005434831187	5284	Economy	28000.00
0005434824653	5284	Economy	28000.00
0005434824685	5284	Economy	28000.00
0005435373220	5284	Economy	28000.00
0005435373302	5284	Economy	28000.00
0005434824579	5284	Economy	28000.00
0005434824613	5284	Economy	28000.00
0005434558335	5284	Economy	28000.00
0005434824629	5284	Economy	28000.00
0005434824606	5284	Economy	28000.00
0005434831185	5284	Economy	28000.00
0005434824593	5284	Economy	28000.00
0005434824600	5284	Economy	28000.00
0005434824673	5284	Economy	28000.00
0005434824661	5284	Economy	28000.00
0005435373101	5284	Economy	28000.00
0005434824571	5284	Economy	28000.00
0005435304152	5284	Economy	28000.00
0005435373005	5284	Economy	28000.00
0005435373382	5284	Economy	28000.00
0005434824599	5284	Economy	28000.00
0005435372984	5284	Economy	28000.00
0005434558345	5284	Economy	28000.00
0005434824625	5284	Economy	28000.00
0005435373214	5284	Economy	28000.00
0005435386560	5284	Economy	28000.00
0005435373298	5284	Economy	28000.00
0005432203120	9909	Business	84000.00
0005435373779	9909	Business	84000.00
0005435373804	9909	Business	84000.00
0005434823085	9909	Business	84000.00
0005435373771	9909	Business	84000.00
0005434664952	9909	Business	84000.00
0005435373819	9909	Business	84000.00
0005434823571	9909	Business	84000.00
0005435373808	9909	Business	84000.00
0005435373768	9909	Business	84000.00
0005434824059	9909	Business	84000.00
0005435735173	9909	Business	84000.00
0005434823301	9909	Business	84000.00
0005434824029	9909	Business	84000.00
0005435302235	9909	Business	84000.00
0005434823597	9909	Business	84000.00
0005435373787	9909	Business	84000.00
0005434823105	9909	Business	84000.00
0005435373803	9909	Business	84000.00
0005432396244	9909	Business	84000.00
0005434823443	9909	Business	84000.00
0005434823841	9909	Business	84000.00
0005435386624	9909	Business	84000.00
0005434823125	9909	Business	84000.00
0005434823758	9909	Business	84000.00
0005434823472	9909	Comfort	47600.00
0005434823328	9909	Comfort	47600.00
0005435373796	9909	Comfort	47600.00
0005434823850	9909	Comfort	47600.00
0005435373801	9909	Comfort	47600.00
0005434823398	9909	Comfort	47600.00
0005434823644	9909	Comfort	47600.00
0005435735174	9909	Comfort	47600.00
0005434823031	9909	Comfort	47600.00
0005434558254	9909	Comfort	47600.00
0005435373805	9909	Comfort	47600.00
0005434558265	9909	Comfort	47600.00
0005434823908	9909	Comfort	47600.00
0005434823930	9909	Comfort	47600.00
0005434823444	9909	Comfort	47600.00
0005434823345	9909	Comfort	47600.00
0005434823791	9909	Comfort	47600.00
0005435373788	9909	Comfort	47600.00
0005434823170	9909	Comfort	47600.00
0005434558255	9909	Comfort	47600.00
0005434823228	9909	Comfort	47600.00
0005434823893	9909	Comfort	47600.00
0005434823525	9909	Comfort	47600.00
0005434823057	9909	Comfort	47600.00
0005435735177	9909	Comfort	47600.00
0005434823409	9909	Comfort	47600.00
0005435373802	9909	Comfort	47600.00
0005435373813	9909	Comfort	47600.00
0005434558267	9909	Comfort	47600.00
0005435373800	9909	Economy	28000.00
0005434823432	9909	Comfort	47600.00
0005435150024	9909	Economy	28000.00
0005435386621	9909	Economy	28000.00
0005432400125	9909	Economy	28000.00
0005435373829	9909	Economy	28000.00
0005434558244	9909	Economy	28000.00
0005434823320	9909	Economy	28000.00
0005434823199	9909	Economy	28000.00
0005435373793	9909	Economy	28000.00
0005432400116	9909	Economy	28000.00
0005434823447	9909	Economy	28000.00
0005434823843	9909	Economy	28000.00
0005434823917	9909	Economy	28000.00
0005434823886	9909	Economy	28000.00
0005434823012	9909	Economy	28000.00
0005434824079	9909	Economy	28000.00
0005432203123	9909	Economy	28000.00
0005434823197	9909	Economy	28000.00
0005435661955	9909	Economy	28000.00
0005435386629	9909	Economy	28000.00
0005434823462	9909	Economy	28000.00
0005434823549	9909	Economy	28000.00
0005434823473	9909	Economy	28000.00
0005434823194	9909	Economy	28000.00
0005435373820	9909	Economy	28000.00
0005434823316	9909	Economy	28000.00
0005435373823	9909	Economy	28000.00
0005435373794	9909	Economy	28000.00
0005435661957	9909	Economy	28000.00
0005435299812	9909	Economy	28000.00
0005434823675	9909	Economy	28000.00
0005434823317	9909	Economy	28000.00
0005434823478	9909	Economy	28000.00
0005434823399	9909	Economy	28000.00
0005434823749	9909	Economy	28000.00
0005434823343	9909	Economy	28000.00
0005435373776	9909	Economy	28000.00
0005434823056	9909	Economy	28000.00
0005434823196	9909	Economy	28000.00
0005435373825	9909	Economy	28000.00
0005434823086	9909	Economy	28000.00
0005434823011	9909	Economy	28000.00
0005434823678	9909	Economy	28000.00
0005434558239	9909	Economy	28000.00
0005435302238	9909	Economy	28000.00
0005435373786	9909	Economy	28000.00
0005434823660	9909	Economy	28000.00
0005434823840	9909	Economy	28000.00
0005435373773	9909	Economy	28000.00
0005435149996	9909	Economy	28000.00
0005434823859	9909	Economy	30800.00
0005434823649	9909	Economy	30800.00
0005435373797	9909	Economy	28000.00
0005435373775	9909	Economy	28000.00
0005435150047	9909	Economy	28000.00
0005434823526	9909	Economy	28000.00
0005435302236	9909	Economy	30800.00
0005434823344	9909	Economy	28000.00
0005435661958	9909	Economy	30800.00
0005435373817	9909	Economy	28000.00
0005435373763	9909	Economy	28000.00
0005435373799	9909	Economy	28000.00
0005434831155	9909	Economy	28000.00
0005434823648	9909	Economy	28000.00
0005434831151	9909	Economy	28000.00
0005435373790	9909	Economy	28000.00
0005434823587	9909	Economy	28000.00
0005434823766	9909	Economy	28000.00
0005434831146	9909	Economy	28000.00
0005434823825	9909	Economy	28000.00
0005435386628	9909	Economy	28000.00
0005435373789	9909	Economy	28000.00
0005435373777	9909	Economy	28000.00
0005434823315	9909	Economy	28000.00
0005434823879	9909	Economy	28000.00
0005434823356	9909	Economy	28000.00
0005434823992	9909	Economy	28000.00
0005432396228	9909	Economy	28000.00
0005435373809	9909	Economy	28000.00
0005435373764	9909	Economy	28000.00
0005435373785	9909	Economy	28000.00
0005434831147	9909	Economy	28000.00
0005434823211	9909	Economy	28000.00
0005435150017	9909	Economy	28000.00
0005434823668	9909	Economy	28000.00
0005435373798	9909	Economy	28000.00
0005435373821	9909	Economy	28000.00
0005432400113	9909	Economy	28000.00
0005435735176	9909	Economy	28000.00
0005434823117	9909	Economy	28000.00
0005435149987	9909	Economy	28000.00
0005434823461	9909	Economy	28000.00
0005435373818	9909	Economy	28000.00
0005435299815	9909	Economy	28000.00
0005432396256	9909	Economy	28000.00
0005432400128	9909	Economy	28000.00
0005435373827	9909	Economy	28000.00
0005434823321	9909	Economy	28000.00
0005434823582	9909	Economy	28000.00
0005434823479	9909	Economy	28000.00
0005434823563	9909	Economy	28000.00
0005434831145	9909	Economy	28000.00
0005434823352	9909	Economy	28000.00
0005435386622	9909	Economy	28000.00
0005435373811	9909	Economy	28000.00
0005435386625	9909	Economy	28000.00
0005434823738	9909	Economy	28000.00
0005434823555	9909	Economy	28000.00
0005434823355	9909	Economy	28000.00
0005435373816	9909	Economy	28000.00
0005432400119	9909	Economy	28000.00
0005434823357	9909	Economy	28000.00
0005435373769	9909	Economy	28000.00
0005434823890	9909	Economy	28000.00
0005434823837	9909	Economy	28000.00
0005435373792	9909	Economy	28000.00
0005435150016	9909	Economy	28000.00
0005434823661	9909	Economy	28000.00
0005435373781	9909	Economy	28000.00
0005434823477	9909	Economy	28000.00
0005435373810	9909	Economy	28000.00
0005434823581	9909	Economy	28000.00
0005432823467	9909	Economy	28000.00
0005434823943	9909	Economy	28000.00
0005434558266	9909	Economy	28000.00
0005434823016	9909	Economy	28000.00
0005434823470	9909	Economy	28000.00
0005434823257	9909	Economy	28000.00
0005434558229	9909	Economy	28000.00
0005435373815	9909	Economy	28000.00
0005435373784	9909	Economy	28000.00
0005434822749	9909	Economy	28000.00
0005435373770	9909	Economy	28000.00
0005434823561	9909	Economy	28000.00
0005432203124	9909	Economy	28000.00
0005434823002	9909	Economy	28000.00
0005434823488	9909	Economy	28000.00
0005435373765	9909	Economy	30800.00
0005434823564	9909	Economy	30800.00
0005432203125	9909	Economy	30800.00
0005434824158	9909	Economy	30800.00
0005434824159	9909	Economy	30800.00
0005434823643	9909	Economy	30800.00
0005434828696	9909	Economy	28000.00
0005435373822	9909	Economy	28000.00
0005434823131	9909	Economy	28000.00
0005434823459	9909	Economy	28000.00
0005434823669	9909	Economy	28000.00
0005435386623	9909	Economy	28000.00
0005435373772	9909	Economy	28000.00
0005434823765	9909	Economy	28000.00
0005434823471	9909	Economy	28000.00
0005434823907	9909	Economy	28000.00
0005435373795	9909	Economy	28000.00
0005435373767	9909	Economy	28000.00
0005435735178	9909	Economy	28000.00
0005435373783	9909	Economy	28000.00
0005434823463	9909	Economy	28000.00
0005434823374	9909	Economy	28000.00
0005434823562	9909	Economy	28000.00
0005435299813	9909	Economy	28000.00
0005434823708	9909	Economy	28000.00
0005434823403	9909	Economy	28000.00
0005434823767	9909	Economy	28000.00
0005434823611	9909	Economy	28000.00
0005432400124	9909	Economy	28000.00
0005435373828	9909	Economy	28000.00
0005434824172	9909	Economy	28000.00
0005432400130	9909	Economy	28000.00
0005435150019	9909	Economy	28000.00
0005434823327	9909	Economy	28000.00
0005435373778	9909	Economy	28000.00
0005435299816	9909	Economy	28000.00
0005432400129	9909	Economy	28000.00
0005435373782	9909	Economy	28000.00
0005434823351	9909	Economy	28000.00
0005434823503	9909	Economy	28000.00
0005435373791	9909	Economy	28000.00
0005434823150	9909	Economy	28000.00
0005435373780	9909	Economy	28000.00
0005434823363	9909	Economy	28000.00
0005434824032	9909	Economy	28000.00
0005434822999	9909	Economy	28000.00
0005434823054	9909	Economy	28000.00
0005434823319	9909	Economy	28000.00
0005434823030	9909	Economy	28000.00
0005435373807	9909	Economy	28000.00
0005434823785	9909	Economy	28000.00
0005434823402	9909	Economy	28000.00
0005434823322	9909	Economy	28000.00
0005435661954	9909	Economy	28000.00
0005434823860	9909	Economy	28000.00
0005435373766	9909	Economy	28000.00
0005434823201	9909	Economy	28000.00
0005435302237	9909	Economy	28000.00
0005434823617	9909	Economy	28000.00
0005432203126	9909	Economy	28000.00
0005434823931	9909	Economy	28000.00
0005434823418	9909	Economy	28000.00
0005434823891	9909	Economy	28000.00
0005435373826	9909	Economy	28000.00
0005435386627	9909	Economy	28000.00
0005435373774	9909	Economy	28000.00
0005435373806	9909	Economy	28000.00
0005434823500	9909	Economy	28000.00
0005434823586	9909	Economy	28000.00
0005432203122	9909	Economy	28000.00
0005435735175	9909	Economy	28000.00
0005434823662	9909	Economy	28000.00
0005434823529	9909	Economy	28000.00
0005435661956	9909	Economy	28000.00
0005435373824	9909	Economy	28000.00
0005434828700	9909	Economy	28000.00
0005435299814	9909	Economy	28000.00
0005435373812	9909	Economy	28000.00
0005434823390	9909	Economy	28000.00
0005432203121	9909	Economy	28000.00
0005434823679	9909	Economy	28000.00
0005435373814	9909	Economy	28000.00
0005435386626	9909	Economy	28000.00
0005434823658	9909	Economy	28000.00
0005435790329	6993	Economy	7400.00
0005435082852	6993	Economy	7400.00
0005435082854	6993	Economy	7400.00
0005435082853	6993	Economy	7400.00
0005435082855	6993	Economy	7400.00
0005435790330	6993	Economy	7400.00
0005435082851	6993	Economy	7400.00
0005435790331	6993	Economy	7400.00
0005435082856	6993	Economy	7400.00
0005435082741	26001	Economy	8200.00
0005435082766	26001	Economy	7400.00
0005435082764	26001	Economy	7400.00
0005435082746	26001	Economy	7400.00
0005435082767	26001	Economy	7400.00
0005435082745	26001	Economy	7400.00
0005435082743	26001	Economy	7400.00
0005435082776	26001	Economy	7400.00
0005435790303	26001	Economy	7400.00
0005435790315	26001	Economy	7400.00
0005434214633	9568	Business	32800.00
0005434214473	9568	Business	32800.00
0005434756782	9568	Business	32800.00
0005434214599	9568	Business	32800.00
0005434756766	9568	Business	32800.00
0005434214423	9568	Business	32800.00
0005434756779	9568	Business	32800.00
0005434756764	9568	Business	32800.00
0005434214479	9568	Business	32800.00
0005434214354	9568	Business	32800.00
0005434214214	9568	Business	32800.00
0005434214398	9568	Business	32800.00
0005434214536	9568	Economy	10900.00
0005434214480	9568	Economy	10900.00
0005434756778	9568	Economy	10900.00
0005434756763	9568	Economy	10900.00
0005434214326	9568	Economy	10900.00
0005434214327	9568	Economy	10900.00
0005434756762	9568	Economy	10900.00
0005434214353	9568	Economy	10900.00
0005434756781	9568	Economy	10900.00
0005434756759	9568	Economy	12000.00
0005434214443	9568	Economy	12000.00
0005434756756	9568	Economy	12000.00
0005434214627	9568	Economy	12000.00
0005434214376	9568	Economy	12000.00
0005434756757	9568	Economy	10900.00
0005434756783	9568	Economy	10900.00
0005434214433	9568	Economy	10900.00
0005434214352	9568	Economy	10900.00
0005434756765	9568	Economy	10900.00
0005434756786	9568	Economy	10900.00
0005434756780	9568	Economy	10900.00
0005434214634	9568	Economy	10900.00
0005434214598	9568	Economy	10900.00
0005434214397	9568	Economy	10900.00
0005434756771	9568	Economy	10900.00
0005434214517	9568	Economy	10900.00
0005434756784	9568	Economy	10900.00
0005434756748	9568	Economy	10900.00
0005434214556	9568	Economy	10900.00
0005434214379	9568	Economy	10900.00
0005434756753	9568	Economy	10900.00
0005434756769	9568	Economy	10900.00
0005434214594	9568	Economy	10900.00
0005434756761	9568	Economy	10900.00
0005434756760	9568	Economy	10900.00
0005434756755	9568	Economy	10900.00
0005434214555	9568	Economy	10900.00
0005434756758	9568	Economy	10900.00
0005434214333	9568	Economy	10900.00
0005434214442	9568	Economy	10900.00
0005434756750	9568	Economy	10900.00
0005434214332	9568	Economy	10900.00
0005434756772	9568	Economy	10900.00
0005434214612	9568	Economy	10900.00
0005434214533	9568	Economy	10900.00
0005434756747	9568	Economy	10900.00
0005434214474	9568	Economy	10900.00
0005434756752	9568	Economy	10900.00
0005434214489	9568	Economy	10900.00
0005434756775	9568	Economy	10900.00
0005434756767	9568	Economy	10900.00
0005434214476	9568	Economy	10900.00
0005434756774	9568	Economy	10900.00
0005434756785	9568	Economy	10900.00
0005434214470	9568	Economy	10900.00
0005434756773	9568	Economy	10900.00
0005434214377	9568	Economy	10900.00
0005434214561	9568	Economy	10900.00
0005434214515	9568	Economy	10900.00
0005434214298	9568	Economy	10900.00
0005434756749	9568	Economy	10900.00
0005434756777	9568	Economy	10900.00
0005434214478	9568	Economy	10900.00
0005434756754	9568	Economy	10900.00
0005434756776	9568	Economy	10900.00
0005434214537	9568	Economy	10900.00
0005434214539	9568	Economy	10900.00
0005434214426	9568	Economy	10900.00
0005434214554	9568	Economy	10900.00
0005434214227	9568	Economy	10900.00
0005434214445	9568	Economy	10900.00
0005434214607	9568	Economy	10900.00
0005434756768	9568	Economy	10900.00
0005434214366	9568	Economy	10900.00
0005434214680	9568	Economy	10900.00
0005434214421	9568	Economy	10900.00
0005434214320	9568	Economy	10900.00
0005434756770	9568	Economy	10900.00
0005434214512	9568	Economy	10900.00
0005434214355	9568	Economy	10900.00
0005434214558	9568	Economy	10900.00
0005434214420	9568	Economy	10900.00
0005434756751	9568	Economy	10900.00
0005434214848	28645	Business	32800.00
0005434214863	28645	Business	32800.00
0005434214841	28645	Business	32800.00
0005434214868	28645	Business	32800.00
0005434756328	28645	Business	32800.00
0005434214864	28645	Business	32800.00
0005434756342	28645	Business	32800.00
0005434214849	28645	Business	32800.00
0005434214881	28645	Business	32800.00
0005434756279	28645	Economy	10900.00
0005434214879	28645	Economy	10900.00
0005434756223	28645	Economy	10900.00
0005434214857	28645	Economy	10900.00
0005434756260	28645	Economy	10900.00
0005434214886	28645	Economy	10900.00
0005434214856	28645	Economy	10900.00
0005434214847	28645	Economy	10900.00
0005434214876	28645	Economy	10900.00
0005434756347	28645	Economy	10900.00
0005434214854	28645	Economy	12000.00
0005434756236	28645	Economy	12000.00
0005434756249	28645	Economy	12000.00
0005434756365	28645	Economy	12000.00
0005434214873	28645	Economy	10900.00
0005434756218	28645	Economy	10900.00
0005434756287	28645	Economy	10900.00
0005434756266	28645	Economy	10900.00
0005434214844	28645	Economy	10900.00
0005434756222	28645	Economy	10900.00
0005434214853	28645	Economy	10900.00
0005434756324	28645	Economy	10900.00
0005434756259	28645	Economy	10900.00
0005434214862	28645	Economy	10900.00
0005434214850	28645	Economy	10900.00
0005434214855	28645	Economy	10900.00
0005434214885	28645	Economy	10900.00
0005434756271	28645	Economy	10900.00
0005434756280	28645	Economy	10900.00
0005434756302	28645	Economy	10900.00
0005434214846	28645	Economy	10900.00
0005434756248	28645	Economy	10900.00
0005434214840	28645	Economy	10900.00
0005434756391	28645	Economy	10900.00
0005434214887	28645	Economy	10900.00
0005434214858	28645	Economy	10900.00
0005434214851	28645	Economy	10900.00
0005434756341	28645	Economy	10900.00
0005434756160	28645	Economy	10900.00
0005434756394	28645	Economy	10900.00
0005434756315	28645	Economy	10900.00
0005434756288	28645	Economy	10900.00
0005434214861	28645	Economy	10900.00
0005434756325	28645	Economy	10900.00
0005434214860	28645	Economy	10900.00
0005434756219	28645	Economy	10900.00
0005434214882	28645	Economy	10900.00
0005434214843	28645	Economy	10900.00
0005434214884	28645	Economy	10900.00
0005434214859	28645	Economy	10900.00
0005434214875	28645	Economy	10900.00
0005434214872	28645	Economy	10900.00
0005434214865	28645	Economy	10900.00
0005434756299	28645	Economy	10900.00
0005434756395	28645	Economy	10900.00
0005434756209	28645	Economy	10900.00
0005434214880	28645	Economy	10900.00
0005434214883	28645	Economy	10900.00
0005434214870	28645	Economy	10900.00
0005434214842	28645	Economy	10900.00
0005434756221	28645	Economy	10900.00
0005434756295	28645	Economy	10900.00
0005434214874	28645	Economy	10900.00
0005434756314	28645	Economy	10900.00
0005434214852	28645	Economy	10900.00
0005434214867	28645	Economy	10900.00
0005434214869	28645	Economy	10900.00
0005434214871	28645	Economy	10900.00
0005434756397	28645	Economy	10900.00
0005434214866	28645	Economy	10900.00
0005434214878	28645	Economy	10900.00
0005434214845	28645	Economy	10900.00
0005434756296	28645	Economy	10900.00
0005434756364	28645	Economy	10900.00
0005434214877	28645	Economy	10900.00
0005435100148	10850	Economy	8900.00
0005434760187	10850	Economy	8900.00
0005435100147	10850	Economy	8900.00
0005435100146	10850	Economy	8900.00
0005434760186	10850	Economy	8900.00
0005434760185	10850	Economy	8900.00
0005434760217	31842	Economy	8900.00
0005434760218	31842	Economy	8900.00
0005433202330	1990	Economy	20900.00
0005434639526	1990	Economy	20900.00
0005434639534	1990	Economy	20900.00
0005433202322	1990	Economy	20900.00
0005434639537	1990	Economy	19000.00
0005434639547	1990	Economy	19000.00
0005434639532	1990	Economy	19000.00
0005434639535	1990	Economy	19000.00
0005433202343	1990	Economy	19000.00
0005434639539	1990	Economy	19000.00
0005434639544	1990	Economy	19000.00
0005434639522	1990	Economy	19000.00
0005434639542	1990	Economy	19000.00
0005434639538	1990	Economy	19000.00
0005434639546	1990	Economy	19000.00
0005433202319	1990	Economy	19000.00
0005434639524	1990	Economy	19000.00
0005434639531	1990	Economy	19000.00
0005433202383	1990	Economy	19000.00
0005433202346	1990	Economy	19000.00
0005435948335	1990	Economy	19000.00
0005434639541	1990	Economy	19000.00
0005434639525	1990	Economy	19000.00
0005435948334	1990	Economy	19000.00
0005432290658	1990	Economy	19000.00
0005433202435	1990	Economy	19000.00
0005434639523	1990	Economy	19000.00
0005434639543	1990	Economy	19000.00
0005433202331	1990	Economy	19000.00
0005434639533	1990	Economy	19000.00
0005434639545	1990	Economy	19000.00
0005434639536	1990	Economy	19000.00
0005434639548	1990	Economy	19000.00
0005432290659	1990	Economy	19000.00
0005435948336	1990	Economy	19000.00
0005433202334	1990	Economy	19000.00
0005433202329	1990	Economy	19000.00
0005434639528	1990	Economy	19000.00
0005433202436	1990	Economy	19000.00
0005434639540	1990	Economy	19000.00
0005433202318	1990	Economy	19000.00
0005434639529	1990	Economy	19000.00
0005432290660	1990	Economy	19000.00
0005434639530	1990	Economy	19000.00
0005433202338	1990	Economy	19000.00
0005434639527	1990	Economy	19000.00
0005433202478	23261	Economy	20900.00
0005433202471	23261	Economy	20900.00
0005433202468	23261	Economy	19000.00
0005434639308	23261	Economy	19000.00
0005434639248	23261	Economy	19000.00
0005434639159	23261	Economy	19000.00
0005434639289	23261	Economy	19000.00
0005434639131	23261	Economy	19000.00
0005433202467	23261	Economy	19000.00
0005433202476	23261	Economy	19000.00
0005433202464	23261	Economy	19000.00
0005434639157	23261	Economy	19000.00
0005433202474	23261	Economy	19000.00
0005433202466	23261	Economy	19000.00
0005434639218	23261	Economy	19000.00
0005433202477	23261	Economy	19000.00
0005433202470	23261	Economy	19000.00
0005433202472	23261	Economy	19000.00
0005434639246	23261	Economy	19000.00
0005433202469	23261	Economy	19000.00
0005434639247	23261	Economy	19000.00
0005433202465	23261	Economy	19000.00
0005433202475	23261	Economy	19000.00
0005434639236	23261	Economy	19000.00
0005434639307	23261	Economy	19000.00
0005434639166	23261	Economy	19000.00
0005434639288	23261	Economy	19000.00
0005433202473	23261	Economy	19000.00
0005434639258	23261	Economy	19000.00
0005434639232	23261	Economy	19000.00
0005434639132	23261	Economy	19000.00
0005434639158	23261	Economy	19000.00
0005435326722	6044	Business	69700.00
0005434601017	6044	Business	69700.00
0005433531324	6044	Business	69700.00
0005434601028	6044	Business	69700.00
0005434601018	6044	Business	69700.00
0005434601037	6044	Business	69700.00
0005433533338	6044	Economy	23200.00
0005434601043	6044	Economy	23200.00
0005434601023	6044	Economy	23200.00
0005434601016	6044	Economy	23200.00
0005432111304	6044	Economy	23200.00
0005435326773	6044	Economy	23200.00
0005434601041	6044	Economy	25600.00
0005434601021	6044	Economy	25600.00
0005432111303	6044	Economy	23200.00
0005434601020	6044	Economy	23200.00
0005434601029	6044	Economy	23200.00
0005435326748	6044	Economy	23200.00
0005435326720	6044	Economy	23200.00
0005434601038	6044	Economy	23200.00
0005434601026	6044	Economy	23200.00
0005434601025	6044	Economy	23200.00
0005435326721	6044	Economy	23200.00
0005434601035	6044	Economy	23200.00
0005434601024	6044	Economy	23200.00
0005433533340	6044	Economy	23200.00
0005435326761	6044	Economy	23200.00
0005434601042	6044	Economy	23200.00
0005434601034	6044	Economy	23200.00
0005435326774	6044	Economy	23200.00
0005433533339	6044	Economy	23200.00
0005434601019	6044	Economy	23200.00
0005434601031	6044	Economy	23200.00
0005433531325	6044	Economy	23200.00
0005434601039	6044	Economy	23200.00
0005435326749	6044	Economy	23200.00
0005435326698	6044	Economy	23200.00
0005434601027	6044	Economy	23200.00
0005434601040	6044	Economy	23200.00
0005432111305	6044	Economy	23200.00
0005434601036	6044	Economy	23200.00
0005434601022	6044	Economy	23200.00
0005434601032	6044	Economy	23200.00
0005434601030	6044	Economy	23200.00
0005435326699	6044	Economy	23200.00
0005434601033	6044	Economy	23200.00
0005435326730	6044	Economy	23200.00
0005435326864	18578	Business	69700.00
0005435326855	18578	Business	69700.00
0005434600845	18578	Business	69700.00
0005435326859	18578	Business	69700.00
0005435326861	18578	Business	69700.00
0005434600808	18578	Business	69700.00
0005434600876	18578	Business	69700.00
0005435326858	18578	Business	69700.00
0005435326854	18578	Economy	23200.00
0005434600886	18578	Economy	23200.00
0005434600787	18578	Economy	23200.00
0005434600785	18578	Economy	23200.00
0005435326853	18578	Economy	23200.00
0005434600638	18578	Economy	25600.00
0005434600958	18578	Economy	23200.00
0005434600670	18578	Economy	23200.00
0005434600627	18578	Economy	23200.00
0005433531282	18578	Economy	23200.00
0005434600887	18578	Economy	23200.00
0005434600807	18578	Economy	23200.00
0005435326856	18578	Economy	23200.00
0005434600821	18578	Economy	23200.00
0005434600848	18578	Economy	23200.00
0005434600781	18578	Economy	23200.00
0005433531278	18578	Economy	23200.00
0005434600844	18578	Economy	23200.00
0005434600796	18578	Economy	23200.00
0005434600764	18578	Economy	23200.00
0005434600741	18578	Economy	23200.00
0005434600797	18578	Economy	23200.00
0005434600854	18578	Economy	23200.00
0005433527253	18578	Economy	23200.00
0005434600885	18578	Economy	23200.00
0005435326857	18578	Economy	23200.00
0005434600855	18578	Economy	23200.00
0005433527252	18578	Economy	23200.00
0005434600784	18578	Economy	23200.00
0005435326865	18578	Economy	23200.00
0005434600776	18578	Economy	23200.00
0005433531291	18578	Economy	23200.00
0005435326863	18578	Economy	23200.00
0005435326862	18578	Economy	23200.00
0005434600850	18578	Economy	23200.00
0005434600671	18578	Economy	23200.00
0005435326860	18578	Economy	23200.00
0005434551611	10607	Business	9100.00
0005433180913	10607	Business	9100.00
0005434551638	10607	Business	9100.00
0005433181063	10607	Business	9100.00
0005433181155	10607	Business	9100.00
0005434551656	10607	Business	9100.00
0005434551626	10607	Business	9100.00
0005434551644	10607	Business	9100.00
0005434551606	10607	Business	9100.00
0005434551634	10607	Business	9100.00
0005434551652	10607	Business	9100.00
0005434551653	10607	Economy	3000.00
0005433181062	10607	Economy	3000.00
0005433181086	10607	Economy	3000.00
0005433181053	10607	Economy	3000.00
0005433181110	10607	Economy	3000.00
0005434551643	10607	Economy	3000.00
0005433181040	10607	Economy	3000.00
0005433181001	10607	Economy	3000.00
0005433181153	10607	Economy	3000.00
0005433181068	10607	Economy	3000.00
0005434551645	10607	Economy	3300.00
0005434551640	10607	Economy	3300.00
0005434551629	10607	Economy	3300.00
0005433181019	10607	Economy	3300.00
0005434551630	10607	Economy	3300.00
0005434551650	10607	Economy	3000.00
0005433181075	10607	Economy	3000.00
0005434551639	10607	Economy	3000.00
0005433181015	10607	Economy	3000.00
0005434551654	10607	Economy	3000.00
0005433181137	10607	Economy	3000.00
0005433181012	10607	Economy	3000.00
0005433181013	10607	Economy	3000.00
0005434551623	10607	Economy	3000.00
0005434551607	10607	Economy	3000.00
0005434551622	10607	Economy	3000.00
0005433181109	10607	Economy	3000.00
0005434551624	10607	Economy	3000.00
0005434551657	10607	Economy	3000.00
0005433181007	10607	Economy	3000.00
0005434551618	10607	Economy	3000.00
0005433181118	10607	Economy	3000.00
0005434551633	10607	Economy	3000.00
0005434551625	10607	Economy	3000.00
0005433181085	10607	Economy	3000.00
0005434551612	10607	Economy	3000.00
0005434551641	10607	Economy	3000.00
0005433181128	10607	Economy	3000.00
0005434551646	10607	Economy	3000.00
0005433181154	10607	Economy	3000.00
0005433181000	10607	Economy	3000.00
0005433181055	10607	Economy	3000.00
0005433180914	10607	Economy	3000.00
0005434551617	10607	Economy	3000.00
0005434551627	10607	Economy	3000.00
0005434551609	10607	Economy	3000.00
0005433181119	10607	Economy	3000.00
0005433181016	10607	Economy	3000.00
0005434551616	10607	Economy	3000.00
0005433181129	10607	Economy	3000.00
0005434551655	10607	Economy	3000.00
0005434551628	10607	Economy	3000.00
0005434551631	10607	Economy	3000.00
0005434551614	10607	Economy	3000.00
0005434551608	10607	Economy	3000.00
0005433181052	10607	Economy	3000.00
0005433181067	10607	Economy	3000.00
0005434551615	10607	Economy	3000.00
0005434551605	10607	Economy	3000.00
0005433181024	10607	Economy	3000.00
0005433181120	10607	Economy	3000.00
0005433181117	10607	Economy	3000.00
0005434551636	10607	Economy	3000.00
0005434551635	10607	Economy	3000.00
0005434551637	10607	Economy	3000.00
0005434551651	10607	Economy	3000.00
0005433181138	10607	Economy	3000.00
0005433180925	10607	Economy	3000.00
0005434551620	10607	Economy	3000.00
0005434551610	10607	Economy	3000.00
0005433181018	10607	Economy	3000.00
0005434551649	10607	Economy	3000.00
0005434551642	10607	Economy	3000.00
0005434551632	10607	Economy	3000.00
0005433181041	10607	Economy	3000.00
0005433181111	10607	Economy	3000.00
0005434551647	10607	Economy	3000.00
0005434551613	10607	Economy	3000.00
0005434551619	10607	Economy	3000.00
0005434551621	10607	Economy	3000.00
0005433181198	10607	Economy	3000.00
0005433181197	10607	Economy	3000.00
0005433181051	10607	Economy	3000.00
0005434551648	10607	Economy	3000.00
0005433181094	10607	Economy	3000.00
0005433181308	27686	Business	9100.00
0005433181316	27686	Business	9100.00
0005433181313	27686	Business	9100.00
0005433181299	27686	Business	9100.00
0005433181302	27686	Economy	3000.00
0005433181311	27686	Economy	3000.00
0005433181306	27686	Economy	3000.00
0005433181318	27686	Economy	3300.00
0005433181300	27686	Economy	3000.00
0005433181307	27686	Economy	3000.00
0005433181309	27686	Economy	3000.00
0005433181317	27686	Economy	3000.00
0005433181305	27686	Economy	3000.00
0005433181310	27686	Economy	3000.00
0005433181319	27686	Economy	3000.00
0005433181298	27686	Economy	3000.00
0005433181303	27686	Economy	3000.00
0005433181301	27686	Economy	3000.00
0005433181297	27686	Economy	3000.00
0005433181315	27686	Economy	3000.00
0005433181314	27686	Economy	3000.00
0005433181312	27686	Economy	3000.00
0005433181304	27686	Economy	3000.00
0005433181296	27686	Economy	3000.00
0005434551355	27685	Business	9100.00
0005434551133	27685	Business	9100.00
0005434551258	27685	Business	9100.00
0005434558269	27685	Business	9100.00
0005434551124	27685	Business	9100.00
0005434551235	27685	Business	9100.00
0005434551128	27685	Business	9100.00
0005434558248	27685	Economy	3000.00
0005434551287	27685	Economy	3000.00
0005434551247	27685	Economy	3000.00
0005434551342	27685	Economy	3000.00
0005434551431	27685	Economy	3000.00
0005434551323	27685	Economy	3000.00
0005434558268	27685	Economy	3000.00
0005434558252	27685	Economy	3300.00
0005434551234	27685	Economy	3300.00
0005434551348	27685	Economy	3300.00
0005434558251	27685	Economy	3000.00
0005434558253	27685	Economy	3000.00
0005434558273	27685	Economy	3000.00
0005434551310	27685	Economy	3000.00
0005434551294	27685	Economy	3000.00
0005434551103	27685	Economy	3000.00
0005434551213	27685	Economy	3000.00
0005434551232	27685	Economy	3000.00
0005434551209	27685	Economy	3000.00
0005434558272	27685	Economy	3000.00
0005434551003	27685	Economy	3000.00
0005434551129	27685	Economy	3000.00
0005434551221	27685	Economy	3000.00
0005434551014	27685	Economy	3000.00
0005434551296	27685	Economy	3000.00
0005434551297	27685	Economy	3000.00
0005434551130	27685	Economy	3000.00
0005434558271	27685	Economy	3000.00
0005434551027	27685	Economy	3000.00
0005434551372	27685	Economy	3000.00
0005434558262	27685	Economy	3000.00
0005434551165	27685	Economy	3000.00
0005434551255	27685	Economy	3000.00
0005434551223	27685	Economy	3000.00
0005434550881	27685	Economy	3000.00
0005434554058	27685	Economy	3000.00
0005434558261	27685	Economy	3000.00
0005434551210	27685	Economy	3000.00
0005434551125	27685	Economy	3000.00
0005434551172	27685	Economy	3000.00
0005434551171	27685	Economy	3000.00
0005434558270	27685	Economy	3000.00
0005434551236	27685	Economy	3000.00
0005434551204	27685	Economy	3000.00
0005434551222	27685	Economy	3000.00
0005434551373	27685	Economy	3000.00
0005434551286	27685	Economy	3000.00
0005434554069	27685	Economy	3000.00
0005434551170	27685	Economy	3000.00
0005434551257	27685	Economy	3000.00
0005434551256	27685	Economy	3000.00
0005434551134	27685	Economy	3000.00
0005434551354	27685	Economy	3000.00
0005433459252	6160	Economy	11700.00
0005433459253	6160	Economy	11700.00
0005433459254	6160	Economy	11700.00
0005433459255	6160	Economy	11700.00
0005433459256	6160	Economy	11700.00
0005435254493	19299	Economy	11700.00
0005435254496	19299	Economy	11700.00
0005435254495	19299	Economy	11700.00
0005435254494	19299	Economy	11700.00
0005433459228	19299	Economy	11700.00
0005433459226	19299	Economy	11700.00
0005433459227	19299	Economy	11700.00
0005435682454	6738	Business	51100.00
0005435682475	6738	Business	51100.00
0005435682480	6738	Business	51100.00
0005435682484	6738	Business	51100.00
0005435437909	6738	Business	51100.00
0005432136209	6738	Business	51100.00
0005435682477	6738	Business	51100.00
0005435437955	6738	Business	51100.00
0005435682455	6738	Business	51100.00
0005435437913	6738	Business	51100.00
0005434828695	6738	Business	51100.00
0005435682459	6738	Economy	17000.00
0005434828693	6738	Economy	17000.00
0005435682465	6738	Economy	17000.00
0005435438016	6738	Economy	17000.00
0005435217710	6738	Economy	17000.00
0005435437920	6738	Economy	17000.00
0005435682469	6738	Economy	17000.00
0005432136207	6738	Economy	17000.00
0005435630989	6738	Economy	17000.00
0005432136210	6738	Economy	18700.00
0005435630988	6738	Economy	18700.00
0005435217711	6738	Economy	18700.00
0005435682472	6738	Economy	18700.00
0005434828692	6738	Economy	17000.00
0005435437985	6738	Economy	17000.00
0005432533282	6738	Economy	17000.00
0005435220316	6738	Economy	17000.00
0005432533284	6738	Economy	17000.00
0005435682474	6738	Economy	17000.00
0005435682479	6738	Economy	17000.00
0005435437914	6738	Economy	17000.00
0005435437901	6738	Economy	17000.00
0005435682458	6738	Economy	17000.00
0005435437964	6738	Economy	17000.00
0005435682476	6738	Economy	17000.00
0005435437940	6738	Economy	17000.00
0005435437921	6738	Economy	17000.00
0005435682473	6738	Economy	17000.00
0005435437990	6738	Economy	17000.00
0005435682467	6738	Economy	17000.00
0005435437963	6738	Economy	17000.00
0005432136208	6738	Economy	17000.00
0005435661952	6738	Economy	17000.00
0005435437916	6738	Economy	17000.00
0005432136211	6738	Economy	17000.00
0005432533283	6738	Economy	17000.00
0005435682471	6738	Economy	17000.00
0005435661953	6738	Economy	17000.00
0005435437948	6738	Economy	17000.00
0005435437971	6738	Economy	17000.00
0005435682483	6738	Economy	17000.00
0005435682482	6738	Economy	17000.00
0005435437989	6738	Economy	17000.00
0005435630990	6738	Economy	17000.00
0005435682460	6738	Economy	17000.00
0005435437954	6738	Economy	17000.00
0005435682457	6738	Economy	17000.00
0005435217709	6738	Economy	17000.00
0005435682478	6738	Economy	17000.00
0005435217708	6738	Economy	17000.00
0005434828694	6738	Economy	17000.00
0005435438021	6738	Economy	17000.00
0005435682464	6738	Economy	17000.00
0005435682461	6738	Economy	17000.00
0005435438020	6738	Economy	17000.00
0005435437996	6738	Economy	17000.00
0005435437982	6738	Economy	17000.00
0005435682481	6738	Economy	17000.00
0005432136212	6738	Economy	17000.00
0005435221516	6738	Economy	17000.00
0005435682462	6738	Economy	17000.00
0005435437988	6738	Economy	17000.00
0005435682468	6738	Economy	17000.00
0005435682456	6738	Economy	17000.00
0005435682463	6738	Economy	17000.00
0005435220317	6738	Economy	17000.00
0005435437981	6738	Economy	17000.00
0005435437960	6738	Economy	17000.00
0005435682470	6738	Economy	17000.00
0005434828691	6738	Economy	17000.00
0005435682466	6738	Economy	17000.00
0005435437962	6738	Economy	17000.00
0005435438141	24616	Business	51100.00
0005435682135	24616	Business	51100.00
0005435438126	24616	Business	51100.00
0005435682087	24616	Business	51100.00
0005435681854	24616	Business	51100.00
0005435438128	24616	Business	51100.00
0005435438124	24616	Business	51100.00
0005435681855	24616	Business	51100.00
0005435438136	24616	Business	51100.00
0005435682129	24616	Business	51100.00
0005435682238	24616	Business	51100.00
0005435681922	24616	Economy	17000.00
0005432305768	24616	Economy	17000.00
0005435682102	24616	Economy	17000.00
0005435681967	24616	Economy	17000.00
0005435438121	24616	Economy	17000.00
0005435438138	24616	Economy	17000.00
0005435661935	24616	Economy	17000.00
0005435682057	24616	Economy	17000.00
0005435682069	24616	Economy	17000.00
0005435682242	24616	Economy	18700.00
0005435682198	24616	Economy	18700.00
0005435682228	24616	Economy	18700.00
0005435438140	24616	Economy	18700.00
0005435661925	24616	Economy	17000.00
0005435682221	24616	Economy	17000.00
0005435682220	24616	Economy	17000.00
0005435682070	24616	Economy	17000.00
0005435681856	24616	Economy	17000.00
0005435681961	24616	Economy	17000.00
0005435682151	24616	Economy	17000.00
0005435682196	24616	Economy	17000.00
0005432533315	24616	Economy	17000.00
0005435682128	24616	Economy	17000.00
0005435719566	24616	Economy	17000.00
0005435661918	24616	Economy	17000.00
0005435438142	24616	Economy	17000.00
0005435438133	24616	Economy	17000.00
0005435682042	24616	Economy	17000.00
0005435682134	24616	Economy	17000.00
0005435682259	24616	Economy	17000.00
0005435438129	24616	Economy	17000.00
0005435661928	24616	Economy	17000.00
0005435438137	24616	Economy	17000.00
0005435438125	24616	Economy	17000.00
0005435682041	24616	Economy	17000.00
0005435681861	24616	Economy	17000.00
0005432533316	24616	Economy	17000.00
0005435438139	24616	Economy	17000.00
0005435682237	24616	Economy	17000.00
0005435682028	24616	Economy	17000.00
0005435682122	24616	Economy	17000.00
0005435438131	24616	Economy	17000.00
0005435438123	24616	Economy	17000.00
0005435682091	24616	Economy	17000.00
0005435682100	24616	Economy	17000.00
0005432305769	24616	Economy	17000.00
0005435682068	24616	Economy	17000.00
0005435682088	24616	Economy	17000.00
0005435682121	24616	Economy	17000.00
0005435438134	24616	Economy	17000.00
0005435682224	24616	Economy	17000.00
0005435630961	24616	Economy	17000.00
0005435682244	24616	Economy	17000.00
0005435682120	24616	Economy	17000.00
0005434828721	24616	Economy	17000.00
0005435438130	24616	Economy	17000.00
0005435681859	24616	Economy	17000.00
0005435438132	24616	Economy	17000.00
0005435630960	24616	Economy	17000.00
0005435682169	24616	Economy	17000.00
0005435682164	24616	Economy	17000.00
0005435682140	24616	Economy	17000.00
0005432533314	24616	Economy	17000.00
0005435681883	24616	Economy	17000.00
0005435438127	24616	Economy	17000.00
0005435682116	24616	Economy	17000.00
0005435682090	24616	Economy	17000.00
0005435681905	24616	Economy	17000.00
0005435682103	24616	Economy	17000.00
0005435682056	24616	Economy	17000.00
0005435682138	24616	Economy	17000.00
0005435681882	24616	Economy	17000.00
0005435438135	24616	Economy	17000.00
0005435682170	24616	Economy	17000.00
0005435438122	24616	Economy	17000.00
0005435126679	11547	Business	26400.00
0005435126684	11547	Business	26400.00
0005435126648	11547	Business	26400.00
0005435126660	11547	Business	26400.00
0005435126653	11547	Business	26400.00
0005435126670	11547	Business	26400.00
0005435126666	11547	Business	26400.00
0005435126650	11547	Economy	8800.00
0005435126669	11547	Economy	8800.00
0005435126647	11547	Economy	8800.00
0005435558083	11547	Economy	9700.00
0005435126654	11547	Economy	9700.00
0005435126681	11547	Economy	8800.00
0005435126661	11547	Economy	8800.00
0005435126662	11547	Economy	8800.00
0005435098571	11547	Economy	8800.00
0005435098574	11547	Economy	8800.00
0005435098572	11547	Economy	8800.00
0005435126683	11547	Economy	8800.00
0005435126682	11547	Economy	8800.00
0005435126676	11547	Economy	8800.00
0005435126663	11547	Economy	8800.00
0005435126646	11547	Economy	8800.00
0005435126671	11547	Economy	8800.00
0005435126672	11547	Economy	8800.00
0005435126664	11547	Economy	8800.00
0005435126674	11547	Economy	8800.00
0005435126651	11547	Economy	8800.00
0005435126649	11547	Economy	8800.00
0005435126655	11547	Economy	8800.00
0005435106006	11547	Economy	8800.00
0005435126678	11547	Economy	8800.00
0005435126686	11547	Economy	8800.00
0005435126667	11547	Economy	8800.00
0005435126665	11547	Economy	8800.00
0005435126652	11547	Economy	8800.00
0005435126657	11547	Economy	8800.00
0005435126673	11547	Economy	8800.00
0005435126675	11547	Economy	8800.00
0005435126677	11547	Economy	8800.00
0005435098570	11547	Economy	8800.00
0005435126668	11547	Economy	8800.00
0005435098573	11547	Economy	8800.00
0005435126659	11547	Economy	8800.00
0005435126687	11547	Economy	8800.00
0005435106004	11547	Economy	8800.00
0005435126656	11547	Economy	8800.00
0005435126680	11547	Economy	8800.00
0005435126658	11547	Economy	8800.00
0005435098575	11547	Economy	8800.00
0005435126685	11547	Economy	8800.00
0005435106005	11547	Economy	8800.00
0005435126562	31853	Business	26400.00
0005435126395	31853	Business	26400.00
0005435126421	31853	Business	26400.00
0005435126384	31853	Business	26400.00
0005435126519	31853	Business	26400.00
0005435126520	31853	Business	26400.00
0005435126391	31853	Business	26400.00
0005435126256	31853	Economy	8800.00
0005435126275	31853	Economy	8800.00
0005435126353	31853	Economy	8800.00
0005435126361	31853	Economy	8800.00
0005435126306	31853	Economy	8800.00
0005435126561	31853	Economy	8800.00
0005435105973	31853	Economy	8800.00
0005435126468	31853	Economy	9700.00
0005435126334	31853	Economy	9700.00
0005435126419	31853	Economy	8800.00
0005435126286	31853	Economy	8800.00
0005435126251	31853	Economy	8800.00
0005435126452	31853	Economy	8800.00
0005435126366	31853	Economy	8800.00
0005435126555	31853	Economy	8800.00
0005435126385	31853	Economy	8800.00
0005435126326	31853	Economy	8800.00
0005435126372	31853	Economy	8800.00
0005435126346	31853	Economy	8800.00
0005435126276	31853	Economy	8800.00
0005435126453	31853	Economy	8800.00
0005435126531	31853	Economy	8800.00
0005435105974	31853	Economy	8800.00
0005435126258	31853	Economy	8800.00
0005435126416	31853	Economy	8800.00
0005435126325	31853	Economy	8800.00
0005435126274	31853	Economy	8800.00
0005435105972	31853	Economy	8800.00
0005435558107	31853	Economy	8800.00
0005435126324	31853	Economy	8800.00
0005435126347	31853	Economy	8800.00
0005435126259	31853	Economy	8800.00
0005435126321	31853	Economy	8800.00
0005435126438	31853	Economy	8800.00
0005435126075	31853	Economy	8800.00
0005435126396	31853	Economy	8800.00
0005435126492	31853	Economy	8800.00
0005435126554	31853	Economy	8800.00
0005435126210	31853	Economy	8800.00
0005435126532	31853	Economy	8800.00
0005435126407	31853	Economy	8800.00
0005435126397	31853	Economy	8800.00
0005435126371	31853	Economy	8800.00
0005435558108	31853	Economy	8800.00
0005435126333	31853	Economy	8800.00
0005435126365	31853	Economy	8800.00
0005435126467	31853	Economy	8800.00
0005435126340	31853	Economy	8800.00
0005435558110	31853	Economy	8800.00
0005435126422	31853	Economy	8800.00
0005435558109	31853	Economy	8800.00
0005433398427	13510	Business	36600.00
0005433398421	13510	Business	36600.00
0005433398443	13510	Business	36600.00
0005433398467	13510	Business	36600.00
0005433398455	13510	Business	36600.00
0005433398460	13510	Business	36600.00
0005433398444	13510	Business	36600.00
0005433398469	13510	Economy	12200.00
0005433398447	13510	Economy	12200.00
0005433398439	13510	Economy	12200.00
0005433398454	13510	Economy	12200.00
0005433398452	13510	Economy	12200.00
0005433398450	13510	Economy	12200.00
0005433398435	13510	Economy	13400.00
0005435732352	13510	Economy	13400.00
0005433398456	13510	Economy	13400.00
0005433398457	13510	Economy	13400.00
0005435732327	13510	Economy	12200.00
0005433398437	13510	Economy	12200.00
0005433398422	13510	Economy	12200.00
0005433398423	13510	Economy	12200.00
0005433398438	13510	Economy	12200.00
0005433398459	13510	Economy	12200.00
0005433398430	13510	Economy	12200.00
0005435732363	13510	Economy	12200.00
0005433398441	13510	Economy	12200.00
0005433398434	13510	Economy	12200.00
0005433398462	13510	Economy	12200.00
0005433398431	13510	Economy	12200.00
0005435732318	13510	Economy	12200.00
0005435732285	13510	Economy	12200.00
0005433398445	13510	Economy	12200.00
0005433398464	13510	Economy	12200.00
0005433398429	13510	Economy	12200.00
0005433398461	13510	Economy	12200.00
0005433398432	13510	Economy	12200.00
0005433398451	13510	Economy	12200.00
0005433398428	13510	Economy	12200.00
0005435732321	13510	Economy	12200.00
0005433398466	13510	Economy	12200.00
0005433398433	13510	Economy	12200.00
0005433398425	13510	Economy	12200.00
0005433398442	13510	Economy	12200.00
0005433398465	13510	Economy	12200.00
0005435732319	13510	Economy	12200.00
0005433398448	13510	Economy	12200.00
0005433398446	13510	Economy	12200.00
0005435732345	13510	Economy	12200.00
0005433398453	13510	Economy	12200.00
0005433398458	13510	Economy	12200.00
0005433398440	13510	Economy	12200.00
0005433398470	13510	Economy	12200.00
0005433398424	13510	Economy	12200.00
0005433398463	13510	Economy	12200.00
0005435732328	13510	Economy	12200.00
0005433398436	13510	Economy	12200.00
0005433398468	13510	Economy	12200.00
0005433398426	13510	Economy	12200.00
0005435732322	13510	Economy	12200.00
0005433398449	13510	Economy	12200.00
0005433397847	19372	Business	36600.00
0005433397784	19372	Business	36600.00
0005433398096	19372	Business	36600.00
0005433398041	19372	Business	36600.00
0005433398009	19372	Business	36600.00
0005435732428	19372	Business	36600.00
0005433398002	19372	Business	36600.00
0005433397942	19372	Business	36600.00
0005433397995	19372	Economy	12200.00
0005433398086	19372	Economy	12200.00
0005433398155	19372	Economy	12200.00
0005433397957	19372	Economy	12200.00
0005433397876	19372	Economy	12200.00
0005433398253	19372	Economy	12200.00
0005435732427	19372	Economy	12200.00
0005435732438	19372	Economy	12200.00
0005433397956	19372	Economy	13400.00
0005433398075	19372	Economy	13400.00
0005433398090	19372	Economy	13400.00
0005433398042	19372	Economy	12200.00
0005435732437	19372	Economy	12200.00
0005435732422	19372	Economy	12200.00
0005433398251	19372	Economy	12200.00
0005433397827	19372	Economy	12200.00
0005435732440	19372	Economy	12200.00
0005435732436	19372	Economy	12200.00
0005433398003	19372	Economy	12200.00
0005435732430	19372	Economy	12200.00
0005433397880	19372	Economy	12200.00
0005433398055	19372	Economy	12200.00
0005433398122	19372	Economy	12200.00
0005433398008	19372	Economy	12200.00
0005435732431	19372	Economy	12200.00
0005435732420	19372	Economy	12200.00
0005433398065	19372	Economy	12200.00
0005433398091	19372	Economy	12200.00
0005433398234	19372	Economy	12200.00
0005433397965	19372	Economy	12200.00
0005435732423	19372	Economy	12200.00
0005433397941	19372	Economy	12200.00
0005433398006	19372	Economy	12200.00
0005435732425	19372	Economy	12200.00
0005433397859	19372	Economy	12200.00
0005435732421	19372	Economy	12200.00
0005433398142	19372	Economy	12200.00
0005433398252	19372	Economy	12200.00
0005435732429	19372	Economy	12200.00
0005435732433	19372	Economy	12200.00
0005433398007	19372	Economy	12200.00
0005435732435	19372	Economy	12200.00
0005435732424	19372	Economy	12200.00
0005433398233	19372	Economy	12200.00
0005433398235	19372	Economy	12200.00
0005433397902	19372	Economy	12200.00
0005435732426	19372	Economy	12200.00
0005433398076	19372	Economy	12200.00
0005435732439	19372	Economy	12200.00
0005433398054	19372	Economy	12200.00
0005433398021	19372	Economy	12200.00
0005433397882	19372	Economy	12200.00
0005433398123	19372	Economy	12200.00
0005433398056	19372	Economy	12200.00
0005433398143	19372	Economy	12200.00
0005433398092	19372	Economy	12200.00
0005435732432	19372	Economy	12200.00
0005433397966	19372	Economy	12200.00
0005435732434	19372	Economy	12200.00
0005432297299	19372	Economy	12200.00
0005435068920	13139	Business	11300.00
0005435068973	13139	Business	11300.00
0005435925404	13139	Business	11300.00
0005435925390	13139	Business	11300.00
0005435068849	13139	Business	11300.00
0005435069006	13139	Business	11300.00
0005435068887	13139	Business	11300.00
0005435925399	13139	Business	11300.00
0005435068820	13139	Economy	3800.00
0005435068903	13139	Economy	3800.00
0005435925394	13139	Economy	3800.00
0005435068850	13139	Economy	3800.00
0005435069101	13139	Economy	3800.00
0005435068960	13139	Economy	3800.00
0005435068909	13139	Economy	3800.00
0005435068940	13139	Economy	3800.00
0005435069103	13139	Economy	4100.00
0005435068995	13139	Economy	4100.00
0005435069232	13139	Economy	4100.00
0005435068821	13139	Economy	3800.00
0005435068959	13139	Economy	3800.00
0005435925403	13139	Economy	3800.00
0005435069104	13139	Economy	3800.00
0005435069010	13139	Economy	3800.00
0005435068972	13139	Economy	3800.00
0005435069169	13139	Economy	3800.00
0005435069191	13139	Economy	3800.00
0005435069005	13139	Economy	3800.00
0005435925393	13139	Economy	3800.00
0005435925392	13139	Economy	3800.00
0005435068965	13139	Economy	3800.00
0005435068908	13139	Economy	3800.00
0005435925405	13139	Economy	3800.00
0005435068945	13139	Economy	3800.00
0005435068819	13139	Economy	3800.00
0005435068979	13139	Economy	3800.00
0005435068994	13139	Economy	3800.00
0005435925396	13139	Economy	3800.00
0005435069107	13139	Economy	3800.00
0005435925406	13139	Economy	3800.00
0005435068996	13139	Economy	3800.00
0005435925400	13139	Economy	3800.00
0005435068907	13139	Economy	3800.00
0005435925408	13139	Economy	3800.00
0005435925395	13139	Economy	3800.00
0005435069139	13139	Economy	3800.00
0005435925409	13139	Economy	3800.00
0005435925397	13139	Economy	3800.00
0005435925410	13139	Economy	3800.00
0005435068873	13139	Economy	3800.00
0005435068882	13139	Economy	3800.00
0005435068872	13139	Economy	3800.00
0005435925398	13139	Economy	3800.00
0005435925401	13139	Economy	3800.00
0005435925387	13139	Economy	3800.00
0005435925389	13139	Economy	3800.00
0005435069029	13139	Economy	3800.00
0005435068886	13139	Economy	3800.00
0005435069100	13139	Economy	3800.00
0005435069130	13139	Economy	3800.00
0005435068978	13139	Economy	3800.00
0005435925391	13139	Economy	3800.00
0005435068902	13139	Economy	3800.00
0005435925402	13139	Economy	3800.00
0005435069157	13139	Economy	3800.00
0005435069156	13139	Economy	3800.00
0005435068910	13139	Economy	3800.00
0005435068944	13139	Economy	3800.00
0005435925388	13139	Economy	3800.00
0005435925411	13139	Economy	3800.00
0005435069011	13139	Economy	3800.00
0005435069253	13139	Economy	3800.00
0005435069231	13139	Economy	3800.00
0005435925407	13139	Economy	3800.00
0005435069482	15464	Business	11300.00
0005435925258	15464	Business	11300.00
0005435069441	15464	Business	11300.00
0005435069481	15464	Business	11300.00
0005435069442	15464	Business	11300.00
0005435925259	15464	Business	11300.00
0005435069472	15464	Economy	3800.00
0005435069467	15464	Economy	3800.00
0005435069479	15464	Economy	3800.00
0005435069457	15464	Economy	3800.00
0005435069459	15464	Economy	3800.00
0005435069470	15464	Economy	3800.00
0005435069461	15464	Economy	3800.00
0005435069463	15464	Economy	3800.00
0005435069462	15464	Economy	3800.00
0005435069432	15464	Economy	4100.00
0005435069452	15464	Economy	4100.00
0005435069474	15464	Economy	4100.00
0005435069434	15464	Economy	3800.00
0005435069445	15464	Economy	3800.00
0005435925242	15464	Economy	3800.00
0005435069476	15464	Economy	3800.00
0005435069439	15464	Economy	3800.00
0005435925227	15464	Economy	3800.00
0005435069430	15464	Economy	3800.00
0005435069454	15464	Economy	3800.00
0005435925248	15464	Economy	3800.00
0005435069465	15464	Economy	3800.00
0005435069450	15464	Economy	3800.00
0005435925212	15464	Economy	3800.00
0005435069451	15464	Economy	3800.00
0005435069468	15464	Economy	3800.00
0005435925228	15464	Economy	3800.00
0005435069473	15464	Economy	3800.00
0005435069458	15464	Economy	3800.00
0005435069477	15464	Economy	3800.00
0005435925223	15464	Economy	3800.00
0005435069466	15464	Economy	3800.00
0005435069480	15464	Economy	3800.00
0005435069437	15464	Economy	3800.00
0005435069478	15464	Economy	3800.00
0005435925261	15464	Economy	3800.00
0005435069446	15464	Economy	3800.00
0005435925233	15464	Economy	3800.00
0005435069460	15464	Economy	3800.00
0005435925254	15464	Economy	3800.00
0005435925232	15464	Economy	3800.00
0005435069453	15464	Economy	3800.00
0005435925262	15464	Economy	3800.00
0005435069444	15464	Economy	3800.00
0005435069438	15464	Economy	3800.00
0005435925224	15464	Economy	3800.00
0005435069464	15464	Economy	3800.00
0005435069448	15464	Economy	3800.00
0005435069455	15464	Economy	3800.00
0005435069436	15464	Economy	3800.00
0005435069449	15464	Economy	3800.00
0005435069456	15464	Economy	3800.00
0005435069471	15464	Economy	3800.00
0005435925179	15464	Economy	3800.00
0005435069469	15464	Economy	3800.00
0005435069435	15464	Economy	3800.00
0005435925271	15464	Economy	3800.00
0005435069431	15464	Economy	3800.00
0005435069475	15464	Economy	3800.00
0005435069443	15464	Economy	3800.00
0005435925193	15464	Economy	3800.00
0005435925243	15464	Economy	3800.00
0005435069447	15464	Economy	3800.00
0005435069440	15464	Economy	3800.00
0005435069433	15464	Economy	3800.00
0005435925192	15464	Economy	3800.00
0005435808224	29479	Economy	27100.00
0005435808194	29479	Economy	27100.00
0005435808213	29479	Economy	27100.00
0005433407603	29479	Economy	24700.00
0005433407606	29479	Economy	24700.00
0005435808201	29479	Economy	24700.00
0005435808221	29479	Economy	24700.00
0005435808159	29479	Economy	24700.00
0005435808178	29479	Economy	24700.00
0005435808225	29479	Economy	24700.00
0005433407608	29479	Economy	24700.00
0005435808193	29479	Economy	24700.00
0005435808214	29479	Economy	24700.00
0005435808234	29479	Economy	24700.00
0005435808223	29479	Economy	24700.00
0005435808212	29479	Economy	24700.00
0005433407610	29479	Economy	24700.00
0005433407609	29479	Economy	24700.00
0005433407605	29479	Economy	24700.00
0005435808189	29479	Economy	24700.00
0005435808197	29479	Economy	24700.00
0005435808198	29479	Economy	24700.00
0005435808173	29479	Economy	24700.00
0005435808182	29479	Economy	24700.00
0005433407611	29479	Economy	24700.00
0005435808190	29479	Economy	24700.00
0005435808222	29479	Economy	24700.00
0005435808218	29479	Economy	24700.00
0005435808199	29479	Economy	24700.00
0005435808195	29479	Economy	24700.00
0005435808233	29479	Economy	24700.00
0005433407604	29479	Economy	24700.00
0005433407607	29479	Economy	24700.00
0005433407602	29479	Economy	24700.00
0005433407601	29479	Economy	24700.00
0005435808188	29479	Economy	24700.00
0005435808165	29479	Economy	24700.00
0005435808196	29479	Economy	24700.00
0005434756233	10690	Business	61300.00
0005434756312	10690	Business	61300.00
0005434756420	10690	Business	61300.00
0005434756402	10690	Business	61300.00
0005434756378	10690	Business	61300.00
0005434756355	10690	Business	61300.00
0005434214925	10690	Business	61300.00
0005434756261	10690	Business	61300.00
0005434214907	10690	Business	61300.00
0005434756358	10690	Business	61300.00
0005434214921	10690	Business	61300.00
0005434214896	10690	Business	61300.00
0005434214930	10690	Economy	20400.00
0005434214894	10690	Economy	20400.00
0005434214931	10690	Economy	20400.00
0005434756356	10690	Economy	20400.00
0005434214923	10690	Economy	20400.00
0005434756387	10690	Economy	20400.00
0005434214891	10690	Economy	20400.00
0005434214900	10690	Economy	20400.00
0005434214914	10690	Economy	20400.00
0005434756140	10690	Economy	20400.00
0005434756381	10690	Economy	22500.00
0005434756421	10690	Economy	22500.00
0005434214903	10690	Economy	22500.00
0005434756255	10690	Economy	22500.00
0005434756434	10690	Economy	22500.00
0005434214892	10690	Economy	20400.00
0005434214916	10690	Economy	20400.00
0005434756407	10690	Economy	20400.00
0005434214935	10690	Economy	20400.00
0005434214913	10690	Economy	20400.00
0005434214933	10690	Economy	20400.00
0005434214899	10690	Economy	20400.00
0005434756232	10690	Economy	20400.00
0005434214922	10690	Economy	20400.00
0005434214912	10690	Economy	20400.00
0005434756360	10690	Economy	20400.00
0005434756339	10690	Economy	20400.00
0005434756254	10690	Economy	20400.00
0005434214911	10690	Economy	20400.00
0005434756385	10690	Economy	20400.00
0005434214924	10690	Economy	20400.00
0005434756338	10690	Economy	20400.00
0005434756308	10690	Economy	20400.00
0005434756318	10690	Economy	20400.00
0005434756340	10690	Economy	20400.00
0005434214920	10690	Economy	20400.00
0005434756311	10690	Economy	20400.00
0005434214909	10690	Economy	20400.00
0005434214932	10690	Economy	20400.00
0005434756374	10690	Economy	20400.00
0005434214936	10690	Economy	20400.00
0005434756392	10690	Economy	20400.00
0005434214901	10690	Economy	20400.00
0005434756307	10690	Economy	20400.00
0005434214890	10690	Economy	20400.00
0005434756379	10690	Economy	20400.00
0005434214904	10690	Economy	20400.00
0005434756375	10690	Economy	20400.00
0005434756401	10690	Economy	20400.00
0005434756382	10690	Economy	20400.00
0005434214934	10690	Economy	20400.00
0005434756301	10690	Economy	20400.00
0005434756316	10690	Economy	20400.00
0005434214910	10690	Economy	20400.00
0005434214928	10690	Economy	20400.00
0005434214897	10690	Economy	20400.00
0005434214929	10690	Economy	20400.00
0005434756357	10690	Economy	20400.00
0005434756383	10690	Economy	20400.00
0005434214919	10690	Economy	20400.00
0005434756386	10690	Economy	20400.00
0005434214902	10690	Economy	20400.00
0005434756139	10690	Economy	20400.00
0005434214905	10690	Economy	20400.00
0005434214908	10690	Economy	20400.00
0005434214895	10690	Economy	20400.00
0005434214927	10690	Economy	20400.00
0005434756423	10690	Economy	20400.00
0005434214893	10690	Economy	20400.00
0005434756300	10690	Economy	20400.00
0005434756286	10690	Economy	20400.00
0005434756363	10690	Economy	20400.00
0005434756317	10690	Economy	20400.00
0005434214906	10690	Economy	20400.00
0005434214917	10690	Economy	20400.00
0005434214937	10690	Economy	20400.00
0005434756141	10690	Economy	20400.00
0005434214898	10690	Economy	20400.00
0005434214889	10690	Economy	20400.00
0005434214888	10690	Economy	20400.00
0005434756330	10690	Economy	20400.00
0005434214926	10690	Economy	20400.00
0005434214918	10690	Economy	20400.00
0005434214915	10690	Economy	20400.00
0005434756719	28686	Business	61300.00
0005434214460	28686	Business	61300.00
0005434214328	28686	Business	61300.00
0005434214481	28686	Business	61300.00
0005434214482	28686	Business	61300.00
0005434214495	28686	Business	61300.00
0005434214503	28686	Business	61300.00
0005434214475	28686	Business	61300.00
0005434756724	28686	Business	61300.00
0005434756737	28686	Economy	20400.00
0005434756730	28686	Economy	20400.00
0005434214496	28686	Economy	20400.00
0005434756714	28686	Economy	20400.00
0005434214342	28686	Economy	20400.00
0005434214531	28686	Economy	20400.00
0005434214444	28686	Economy	20400.00
0005434756738	28686	Economy	20400.00
0005434214392	28686	Economy	22500.00
0005434214416	28686	Economy	22500.00
0005434756745	28686	Economy	22500.00
0005434214483	28686	Economy	22500.00
0005434214386	28686	Economy	22500.00
0005434756734	28686	Economy	20400.00
0005434756728	28686	Economy	20400.00
0005434214459	28686	Economy	20400.00
0005434214365	28686	Economy	20400.00
0005434214396	28686	Economy	20400.00
0005434214364	28686	Economy	20400.00
0005434756726	28686	Economy	20400.00
0005434214402	28686	Economy	20400.00
0005434756741	28686	Economy	20400.00
0005434756716	28686	Economy	20400.00
0005434756739	28686	Economy	20400.00
0005434756742	28686	Economy	20400.00
0005434756722	28686	Economy	20400.00
0005434214334	28686	Economy	20400.00
0005434214407	28686	Economy	20400.00
0005434214393	28686	Economy	20400.00
0005434756727	28686	Economy	20400.00
0005434756723	28686	Economy	20400.00
0005434214395	28686	Economy	20400.00
0005434214530	28686	Economy	20400.00
0005434214406	28686	Economy	20400.00
0005434214422	28686	Economy	20400.00
0005434214405	28686	Economy	20400.00
0005434756740	28686	Economy	20400.00
0005434756715	28686	Economy	20400.00
0005434214441	28686	Economy	20400.00
0005434214578	28686	Economy	20400.00
0005434214384	28686	Economy	20400.00
0005434214500	28686	Economy	20400.00
0005434214316	28686	Economy	20400.00
0005434214579	28686	Economy	20400.00
0005434214357	28686	Economy	20400.00
0005434756732	28686	Economy	20400.00
0005434756731	28686	Economy	20400.00
0005434214394	28686	Economy	20400.00
0005434756729	28686	Economy	20400.00
0005434214315	28686	Economy	20400.00
0005434756717	28686	Economy	20400.00
0005434214343	28686	Economy	20400.00
0005434756733	28686	Economy	20400.00
0005434756720	28686	Economy	20400.00
0005434214311	28686	Economy	20400.00
0005434214339	28686	Economy	20400.00
0005434756712	28686	Economy	20400.00
0005434756721	28686	Economy	20400.00
0005434756735	28686	Economy	20400.00
0005434214469	28686	Economy	20400.00
0005434756746	28686	Economy	20400.00
0005434214428	28686	Economy	20400.00
0005434214410	28686	Economy	20400.00
0005434756725	28686	Economy	20400.00
0005434214415	28686	Economy	20400.00
0005434756744	28686	Economy	20400.00
0005434214248	28686	Economy	20400.00
0005434756743	28686	Economy	20400.00
0005434756713	28686	Economy	20400.00
0005434214590	28686	Economy	20400.00
0005434756718	28686	Economy	20400.00
0005434756736	28686	Economy	20400.00
0005434214401	28686	Economy	20400.00
0005434214385	28686	Economy	20400.00
0005434214348	28686	Economy	20400.00
0005435040285	5449	Business	29500.00
0005435040255	5449	Business	29500.00
0005435040314	5449	Business	29500.00
0005435007220	5449	Business	29500.00
0005435040257	5449	Business	29500.00
0005435040260	5449	Business	29500.00
0005435007210	5449	Business	29500.00
0005435040288	5449	Business	29500.00
0005435040303	5449	Business	29500.00
0005435040304	5449	Business	29500.00
0005435040273	5449	Business	29500.00
0005435042874	5449	Business	29500.00
0005434229336	5449	Economy	9800.00
0005435040279	5449	Economy	9800.00
0005435040293	5449	Economy	9800.00
0005435040294	5449	Economy	9800.00
0005435040290	5449	Economy	9800.00
0005435040256	5449	Economy	9800.00
0005434229367	5449	Economy	9800.00
0005435040291	5449	Economy	9800.00
0005435040292	5449	Economy	9800.00
0005435040259	5449	Economy	9800.00
0005435040280	5449	Economy	9800.00
0005434229408	5449	Economy	9800.00
0005434229483	5449	Economy	9800.00
0005435007218	5449	Economy	9800.00
0005435007211	5449	Economy	9800.00
0005435007214	5449	Economy	9800.00
0005435040277	5449	Economy	9800.00
0005435007216	5449	Economy	9800.00
0005435040263	5449	Economy	9800.00
0005435040270	5449	Economy	9800.00
0005435040296	5449	Economy	9800.00
0005434229375	5449	Economy	9800.00
0005435040300	5449	Economy	9800.00
0005434229484	5449	Economy	9800.00
0005435040265	5449	Economy	9800.00
0005435007202	5449	Economy	9800.00
0005435040313	5449	Economy	9800.00
0005434229432	5449	Economy	9800.00
0005434229373	5449	Economy	9800.00
0005435040267	5449	Economy	9800.00
0005434229354	5449	Economy	9800.00
0005434229345	5449	Economy	9800.00
0005435040289	5449	Economy	9800.00
0005435040312	5449	Economy	9800.00
0005435040287	5449	Economy	9800.00
0005435040282	5449	Economy	9800.00
0005435040310	5449	Economy	9800.00
0005435007205	5449	Economy	9800.00
0005432125510	5449	Economy	9800.00
0005434229318	5449	Economy	10800.00
0005434229349	5449	Economy	10800.00
0005435007226	5449	Economy	10800.00
0005432125512	5449	Economy	10800.00
0005435007207	5449	Economy	10800.00
0005434229427	5449	Economy	10800.00
0005435040301	5449	Economy	9800.00
0005434229369	5449	Economy	9800.00
0005435040297	5449	Economy	9800.00
0005432125509	5449	Economy	9800.00
0005435040298	5449	Economy	9800.00
0005435040315	5449	Economy	9800.00
0005435040278	5449	Economy	9800.00
0005435007224	5449	Economy	9800.00
0005435040262	5449	Economy	9800.00
0005435040307	5449	Economy	9800.00
0005434229366	5449	Economy	9800.00
0005435040305	5449	Economy	9800.00
0005435040316	5449	Economy	9800.00
0005435040309	5449	Economy	9800.00
0005432125513	5449	Economy	9800.00
0005435007219	5449	Economy	9800.00
0005435042873	5449	Economy	9800.00
0005435007215	5449	Economy	9800.00
0005435040283	5449	Economy	9800.00
0005434229429	5449	Economy	9800.00
0005434229391	5449	Economy	9800.00
0005434229335	5449	Economy	9800.00
0005432125511	5449	Economy	9800.00
0005435040284	5449	Economy	9800.00
0005435040299	5449	Economy	9800.00
0005435040276	5449	Economy	9800.00
0005435040272	5449	Economy	9800.00
0005434229350	5449	Economy	9800.00
0005435007217	5449	Economy	9800.00
0005435040266	5449	Economy	9800.00
0005432125508	5449	Economy	9800.00
0005435040311	5449	Economy	9800.00
0005435007204	5449	Economy	9800.00
0005435040281	5449	Economy	9800.00
0005434229428	5449	Economy	9800.00
0005435040302	5449	Economy	9800.00
0005435040264	5449	Economy	9800.00
0005435040306	5449	Economy	9800.00
0005432125514	5449	Economy	9800.00
0005435040308	5449	Economy	9800.00
0005435040269	5449	Economy	9800.00
0005435040295	5449	Economy	9800.00
0005434229482	5449	Economy	9800.00
0005434229368	5449	Economy	9800.00
0005435040268	5449	Economy	9800.00
0005435007212	5449	Economy	9800.00
0005435040261	5449	Economy	9800.00
0005435007213	5449	Economy	9800.00
0005434229377	5449	Economy	9800.00
0005434229431	5449	Economy	9800.00
0005434229346	5449	Economy	9800.00
0005435040254	5449	Economy	9800.00
0005435007221	5449	Economy	9800.00
0005435007203	5449	Economy	9800.00
0005435040286	5449	Economy	9800.00
0005435040275	5449	Economy	9800.00
0005435007208	5449	Economy	9800.00
0005435040317	5449	Economy	9800.00
0005435007223	5449	Economy	9800.00
0005435040271	5449	Economy	9800.00
0005435040258	5449	Economy	9800.00
0005435007206	5449	Economy	9800.00
0005435042872	5449	Economy	9800.00
0005434229312	5449	Economy	9800.00
0005435007222	5449	Economy	9800.00
0005435007209	5449	Economy	9800.00
0005435040274	5449	Economy	9800.00
0005435007225	5449	Economy	9800.00
0005435006985	12982	Business	29500.00
0005435006952	12982	Business	29500.00
0005435039632	12982	Business	29500.00
0005434229566	12982	Business	29500.00
0005434229550	12982	Business	29500.00
0005432304431	12982	Business	29500.00
0005435006920	12982	Business	29500.00
0005435007008	12982	Business	29500.00
0005435039376	12982	Business	29500.00
0005435007043	12982	Business	29500.00
0005435006979	12982	Business	29500.00
0005434229546	12982	Business	29500.00
0005434229548	12982	Economy	9800.00
0005435040017	12982	Economy	9800.00
0005434229547	12982	Economy	9800.00
0005435039840	12982	Economy	9800.00
0005435007100	12982	Economy	9800.00
0005435007035	12982	Economy	9800.00
0005435039980	12982	Economy	9800.00
0005435039771	12982	Economy	9800.00
0005434229562	12982	Economy	9800.00
0005435039935	12982	Economy	9800.00
0005435039692	12982	Economy	9800.00
0005434229545	12982	Economy	9800.00
0005435039739	12982	Economy	9800.00
0005435039626	12982	Economy	9800.00
0005432304428	12982	Economy	9800.00
0005432304429	12982	Economy	9800.00
0005435039610	12982	Economy	9800.00
0005435006873	12982	Economy	9800.00
0005435039601	12982	Economy	9800.00
0005435039680	12982	Economy	9800.00
0005435039853	12982	Economy	9800.00
0005435007042	12982	Economy	9800.00
0005435042852	12982	Economy	9800.00
0005435006991	12982	Economy	9800.00
0005435039779	12982	Economy	9800.00
0005435007059	12982	Economy	9800.00
0005435039742	12982	Economy	9800.00
0005435006988	12982	Economy	9800.00
0005435039743	12982	Economy	9800.00
0005434229557	12982	Economy	9800.00
0005435039919	12982	Economy	9800.00
0005435039646	12982	Economy	10800.00
0005435039721	12982	Economy	10800.00
0005435006884	12982	Economy	10800.00
0005435039600	12982	Economy	10800.00
0005435007033	12982	Economy	9800.00
0005434229551	12982	Economy	10800.00
0005435039852	12982	Economy	9800.00
0005435039353	12982	Economy	9800.00
0005435039898	12982	Economy	9800.00
0005435007090	12982	Economy	9800.00
0005434229553	12982	Economy	9800.00
0005435039959	12982	Economy	9800.00
0005435006919	12982	Economy	9800.00
0005432304430	12982	Economy	9800.00
0005435039705	12982	Economy	9800.00
0005435006980	12982	Economy	9800.00
0005434229554	12982	Economy	9800.00
0005435039691	12982	Economy	9800.00
0005434229552	12982	Economy	9800.00
0005434229560	12982	Economy	9800.00
0005435006900	12982	Economy	9800.00
0005435039799	12982	Economy	9800.00
0005434229558	12982	Economy	9800.00
0005435039741	12982	Economy	9800.00
0005435039459	12982	Economy	9800.00
0005435039352	12982	Economy	9800.00
0005435007055	12982	Economy	9800.00
0005435039683	12982	Economy	9800.00
0005435039901	12982	Economy	9800.00
0005435039839	12982	Economy	9800.00
0005435039701	12982	Economy	9800.00
0005434229556	12982	Economy	9800.00
0005435007021	12982	Economy	9800.00
0005435039506	12982	Economy	9800.00
0005435006872	12982	Economy	9800.00
0005435039816	12982	Economy	9800.00
0005435039772	12982	Economy	9800.00
0005435039834	12982	Economy	9800.00
0005435042853	12982	Economy	9800.00
0005435006992	12982	Economy	9800.00
0005435039920	12982	Economy	9800.00
0005435039627	12982	Economy	9800.00
0005435039557	12982	Economy	9800.00
0005434229565	12982	Economy	9800.00
0005435039831	12982	Economy	9800.00
0005435039744	12982	Economy	9800.00
0005435039740	12982	Economy	9800.00
0005435040016	12982	Economy	9800.00
0005435006899	12982	Economy	9800.00
0005435007034	12982	Economy	9800.00
0005435039778	12982	Economy	9800.00
0005435039702	12982	Economy	9800.00
0005435043284	12982	Economy	9800.00
0005435039738	12982	Economy	9800.00
0005435039970	12982	Economy	9800.00
0005434229561	12982	Economy	9800.00
0005434229564	12982	Economy	9800.00
0005435007077	12982	Economy	9800.00
0005435039628	12982	Economy	9800.00
0005435007078	12982	Economy	9800.00
0005434229555	12982	Economy	9800.00
0005434229563	12982	Economy	9800.00
0005435039948	12982	Economy	9800.00
0005434229549	12982	Economy	9800.00
0005435039722	12982	Economy	9800.00
0005435006989	12982	Economy	9800.00
0005434229559	12982	Economy	9800.00
0005435902725	14877	Business	52900.00
0005434411810	14877	Business	52900.00
0005435902724	14877	Business	52900.00
0005435902705	14877	Business	52900.00
0005434426822	14877	Business	52900.00
0005434426824	14877	Business	52900.00
0005435902667	14877	Business	52900.00
0005434426809	14877	Business	52900.00
0005434426825	14877	Economy	17600.00
0005434426813	14877	Economy	17600.00
0005435902664	14877	Economy	17600.00
0005434426835	14877	Economy	17600.00
0005435902698	14877	Economy	17600.00
0005434426819	14877	Economy	19400.00
0005434411811	14877	Economy	19400.00
0005434426827	14877	Economy	19400.00
0005434426815	14877	Economy	19400.00
0005434426814	14877	Economy	17600.00
0005434426812	14877	Economy	17600.00
0005434411808	14877	Economy	17600.00
0005435902631	14877	Economy	17600.00
0005434426818	14877	Economy	17600.00
0005434426811	14877	Economy	17600.00
0005435902674	14877	Economy	17600.00
0005434426820	14877	Economy	17600.00
0005434426810	14877	Economy	17600.00
0005435554162	14877	Economy	17600.00
0005432188630	14877	Economy	17600.00
0005434426823	14877	Economy	17600.00
0005432188631	14877	Economy	17600.00
0005434426831	14877	Economy	17600.00
0005434426817	14877	Economy	17600.00
0005434426832	14877	Economy	17600.00
0005435902691	14877	Economy	17600.00
0005435554161	14877	Economy	17600.00
0005432188632	14877	Economy	17600.00
0005434426828	14877	Economy	17600.00
0005435902646	14877	Economy	17600.00
0005435902645	14877	Economy	17600.00
0005435902644	14877	Economy	17600.00
0005435554173	14877	Economy	17600.00
0005434426837	14877	Economy	17600.00
0005435902676	14877	Economy	17600.00
0005435902770	14877	Economy	17600.00
0005434426829	14877	Economy	17600.00
0005434426816	14877	Economy	17600.00
0005434411809	14877	Economy	17600.00
0005434411807	14877	Economy	17600.00
0005434426826	14877	Economy	17600.00
0005435902739	14877	Economy	17600.00
0005435554163	14877	Economy	17600.00
0005435902675	14877	Economy	17600.00
0005434426834	14877	Economy	17600.00
0005434426836	14877	Economy	17600.00
0005434426830	14877	Economy	17600.00
0005435902693	14877	Economy	17600.00
0005434426833	14877	Economy	17600.00
0005435902662	14877	Economy	17600.00
0005435902621	14877	Economy	17600.00
0005435902699	14877	Economy	17600.00
0005434426821	14877	Economy	17600.00
0005435554178	14877	Economy	17600.00
0005435902706	14877	Economy	17600.00
0005435902650	14877	Economy	17600.00
0005435902842	20200	Business	52900.00
0005434426579	20200	Business	52900.00
0005434426453	20200	Business	52900.00
0005435902854	20200	Business	52900.00
0005435902853	20200	Business	52900.00
0005434426688	20200	Business	52900.00
0005432059520	20200	Economy	17600.00
0005435902855	20200	Economy	17600.00
0005434426601	20200	Economy	19400.00
0005435554229	20200	Economy	19400.00
0005435902857	20200	Economy	17600.00
0005434426452	20200	Economy	17600.00
0005434411784	20200	Economy	17600.00
0005434426536	20200	Economy	17600.00
0005435902845	20200	Economy	17600.00
0005434426600	20200	Economy	17600.00
0005434426687	20200	Economy	17600.00
0005435902847	20200	Economy	17600.00
0005434411788	20200	Economy	17600.00
0005434426534	20200	Economy	17600.00
0005435902851	20200	Economy	17600.00
0005435902850	20200	Economy	17600.00
0005435902844	20200	Economy	17600.00
0005432059521	20200	Economy	17600.00
0005434426712	20200	Economy	17600.00
0005435554227	20200	Economy	17600.00
0005435902843	20200	Economy	17600.00
0005435554230	20200	Economy	17600.00
0005435902852	20200	Economy	17600.00
0005434426666	20200	Economy	17600.00
0005434426471	20200	Economy	17600.00
0005434426476	20200	Economy	17600.00
0005434426602	20200	Economy	17600.00
0005434426509	20200	Economy	17600.00
0005434426721	20200	Economy	17600.00
0005434426612	20200	Economy	17600.00
0005434426454	20200	Economy	17600.00
0005435554228	20200	Economy	17600.00
0005435902856	20200	Economy	17600.00
0005434426580	20200	Economy	17600.00
0005434426707	20200	Economy	17600.00
0005434426537	20200	Economy	17600.00
0005434426562	20200	Economy	17600.00
0005435902846	20200	Economy	17600.00
0005435902849	20200	Economy	17600.00
0005434426408	20200	Economy	17600.00
0005434411777	20200	Economy	17600.00
0005435902848	20200	Economy	17600.00
0005434426760	20200	Economy	17600.00
0005434426451	20200	Economy	17600.00
0005435902841	20200	Economy	17600.00
0005434426535	20200	Economy	17600.00
0005435982638	26504	Business	18500.00
0005435982646	26504	Business	18500.00
0005435982648	26504	Business	18500.00
0005435982631	26504	Business	18500.00
0005435982625	26504	Business	18500.00
0005435982641	26504	Business	18500.00
0005432300307	26504	Business	18500.00
0005435982628	26504	Business	18500.00
0005435982627	26504	Business	18500.00
0005433434673	26504	Business	18500.00
0005435982642	26504	Economy	6200.00
0005433434653	26504	Economy	6200.00
0005435982640	26504	Economy	6200.00
0005435982623	26504	Economy	6200.00
0005435982647	26504	Economy	6200.00
0005433434649	26504	Economy	6200.00
0005433434634	26504	Economy	6200.00
0005435982653	26504	Economy	6200.00
0005433434727	26504	Economy	6800.00
0005433434581	26504	Economy	6800.00
0005435982660	26504	Economy	6800.00
0005433434688	26504	Economy	6800.00
0005433434737	26504	Economy	6200.00
0005435982624	26504	Economy	6200.00
0005432300306	26504	Economy	6200.00
0005433434633	26504	Economy	6200.00
0005435982633	26504	Economy	6200.00
0005433434642	26504	Economy	6200.00
0005435982663	26504	Economy	6200.00
0005435982630	26504	Economy	6200.00
0005435982661	26504	Economy	6200.00
0005434270212	26504	Economy	6200.00
0005435982639	26504	Economy	6200.00
0005435982634	26504	Economy	6200.00
0005435982620	26504	Economy	6200.00
0005435982622	26504	Economy	6200.00
0005435982621	26504	Economy	6200.00
0005434273070	26504	Economy	6200.00
0005435982664	26504	Economy	6200.00
0005433434650	26504	Economy	6200.00
0005435982651	26504	Economy	6200.00
0005432300308	26504	Economy	6200.00
0005435982632	26504	Economy	6200.00
0005433434652	26504	Economy	6200.00
0005433434635	26504	Economy	6200.00
0005433434509	26504	Economy	6200.00
0005433434582	26504	Economy	6200.00
0005433434632	26504	Economy	6200.00
0005435982655	26504	Economy	6200.00
0005435982659	26504	Economy	6200.00
0005435982636	26504	Economy	6200.00
0005433434555	26504	Economy	6200.00
0005435982662	26504	Economy	6200.00
0005435982652	26504	Economy	6200.00
0005435982644	26504	Economy	6200.00
0005433434647	26504	Economy	6200.00
0005435982637	26504	Economy	6200.00
0005433434699	26504	Economy	6200.00
0005435982629	26504	Economy	6200.00
0005433434643	26504	Economy	6200.00
0005433434698	26504	Economy	6200.00
0005435982658	26504	Economy	6200.00
0005433434585	26504	Economy	6200.00
0005432300305	26504	Economy	6200.00
0005433434651	26504	Economy	6200.00
0005435982643	26504	Economy	6200.00
0005433434657	26504	Economy	6200.00
0005435982656	26504	Economy	6200.00
0005433434510	26504	Economy	6200.00
0005435982635	26504	Economy	6200.00
0005433434697	26504	Economy	6200.00
0005433434740	26504	Economy	6200.00
0005435982645	26504	Economy	6200.00
0005434270208	26504	Economy	6200.00
0005433434735	26504	Economy	6200.00
0005435982649	26504	Economy	6200.00
0005433434654	26504	Economy	6200.00
0005435982626	26504	Economy	6200.00
0005435982654	26504	Economy	6200.00
0005432300303	26504	Economy	6200.00
0005435982650	26504	Economy	6200.00
0005435982657	26504	Economy	6200.00
0005432300304	26504	Economy	6200.00
0005433434648	26504	Economy	6200.00
0005435982328	26738	Business	18500.00
0005435982288	26738	Business	18500.00
0005435982049	26738	Business	18500.00
0005433434922	26738	Business	18500.00
0005435982327	26738	Business	18500.00
0005435982325	26738	Business	18500.00
0005435981987	26738	Business	18500.00
0005433434911	26738	Business	18500.00
0005433434916	26738	Business	18500.00
0005435982280	26738	Economy	6200.00
0005434271330	26738	Economy	6200.00
0005435982477	26738	Economy	6200.00
0005433434928	26738	Economy	6200.00
0005435982409	26738	Economy	6200.00
0005435982175	26738	Economy	6200.00
0005435982295	26738	Economy	6200.00
0005435982260	26738	Economy	6200.00
0005435982118	26738	Economy	6800.00
0005433434904	26738	Economy	6800.00
0005435982414	26738	Economy	6800.00
0005433434921	26738	Economy	6200.00
0005433434919	26738	Economy	6200.00
0005435982441	26738	Economy	6200.00
0005433434912	26738	Economy	6200.00
0005433434926	26738	Economy	6200.00
0005433434901	26738	Economy	6200.00
0005435982228	26738	Economy	6200.00
0005433434902	26738	Economy	6200.00
0005433434910	26738	Economy	6200.00
0005435982123	26738	Economy	6200.00
0005434271329	26738	Economy	6200.00
0005435982413	26738	Economy	6200.00
0005435982234	26738	Economy	6200.00
0005435982476	26738	Economy	6200.00
0005433434923	26738	Economy	6200.00
0005433434908	26738	Economy	6200.00
0005433434915	26738	Economy	6200.00
0005433434906	26738	Economy	6200.00
0005432051153	26738	Economy	6200.00
0005435982159	26738	Economy	6200.00
0005435982107	26738	Economy	6200.00
0005433434909	26738	Economy	6200.00
0005433434903	26738	Economy	6200.00
0005435982339	26738	Economy	6200.00
0005433434918	26738	Economy	6200.00
0005434269121	26738	Economy	6200.00
0005433434925	26738	Economy	6200.00
0005432051155	26738	Economy	6200.00
0005433434924	26738	Economy	6200.00
0005435982257	26738	Economy	6200.00
0005435982297	26738	Economy	6200.00
0005433434917	26738	Economy	6200.00
0005435982259	26738	Economy	6200.00
0005435982235	26738	Economy	6200.00
0005435982365	26738	Economy	6200.00
0005435982034	26738	Economy	6200.00
0005433434899	26738	Economy	6200.00
0005434270224	26738	Economy	6200.00
0005435982245	26738	Economy	6200.00
0005435982289	26738	Economy	6200.00
0005433434905	26738	Economy	6200.00
0005433434914	26738	Economy	6200.00
0005433434907	26738	Economy	6200.00
0005435982258	26738	Economy	6200.00
0005435982368	26738	Economy	6200.00
0005433434920	26738	Economy	6200.00
0005435982400	26738	Economy	6200.00
0005435982369	26738	Economy	6200.00
0005435982335	26738	Economy	6200.00
0005433434913	26738	Economy	6200.00
0005432051154	26738	Economy	6200.00
0005433434900	26738	Economy	6200.00
0005435982310	26738	Economy	6200.00
0005435982124	26738	Economy	6200.00
0005433434927	26738	Economy	6200.00
0005434270223	26738	Economy	6200.00
0005432584229	3136	Economy	11100.00
0005432584249	3136	Economy	11100.00
0005432584236	3136	Economy	11100.00
0005432584238	3136	Economy	10100.00
0005432858081	3136	Economy	10100.00
0005432584250	3136	Economy	10100.00
0005432858073	3136	Economy	10100.00
0005432584244	3136	Economy	10100.00
0005432858078	3136	Economy	10100.00
0005432858114	3136	Economy	10100.00
0005432584251	3136	Economy	10100.00
0005432584237	3136	Economy	10100.00
0005432584246	3136	Economy	10100.00
0005432858080	3136	Economy	10100.00
0005432858038	3136	Economy	10100.00
0005432584242	3136	Economy	10100.00
0005432584245	3136	Economy	10100.00
0005432584252	3136	Economy	10100.00
0005432584241	3136	Economy	10100.00
0005432584248	3136	Economy	10100.00
0005432216294	3136	Economy	10100.00
0005432216296	3136	Economy	10100.00
0005432584232	3136	Economy	10100.00
0005432584234	3136	Economy	10100.00
0005432216295	3136	Economy	10100.00
0005432858061	3136	Economy	10100.00
0005432584230	3136	Economy	10100.00
0005432858113	3136	Economy	10100.00
0005432584247	3136	Economy	10100.00
0005432858092	3136	Economy	10100.00
0005432584228	3136	Economy	10100.00
0005432584235	3136	Economy	10100.00
0005432584243	3136	Economy	10100.00
0005432858077	3136	Economy	10100.00
0005432858085	3136	Economy	10100.00
0005432584240	3136	Economy	10100.00
0005432584239	3136	Economy	10100.00
0005432584233	3136	Economy	10100.00
0005432584231	3136	Economy	10100.00
0005432858051	3136	Economy	10100.00
0005432584036	31519	Economy	11100.00
0005432584070	31519	Economy	11100.00
0005432584044	31519	Economy	11100.00
0005432584196	31519	Economy	10100.00
0005432584045	31519	Economy	10100.00
0005432858163	31519	Economy	10100.00
0005432858167	31519	Economy	10100.00
0005432584064	31519	Economy	10100.00
0005432858172	31519	Economy	10100.00
0005432583989	31519	Economy	10100.00
0005432584052	31519	Economy	10100.00
0005432858165	31519	Economy	10100.00
0005432858168	31519	Economy	10100.00
0005432584053	31519	Economy	10100.00
0005432858164	31519	Economy	10100.00
0005432584065	31519	Economy	10100.00
0005432858170	31519	Economy	10100.00
0005432584026	31519	Economy	10100.00
0005432584035	31519	Economy	10100.00
0005432584032	31519	Economy	10100.00
0005432584147	31519	Economy	10100.00
0005432584116	31519	Economy	10100.00
0005432584063	31519	Economy	10100.00
0005432584048	31519	Economy	10100.00
0005432858171	31519	Economy	10100.00
0005432584115	31519	Economy	10100.00
0005432584033	31519	Economy	10100.00
0005432858160	31519	Economy	10100.00
0005432858162	31519	Economy	10100.00
0005432583994	31519	Economy	10100.00
0005432584138	31519	Economy	10100.00
0005432858169	31519	Economy	10100.00
0005432584068	31519	Economy	10100.00
0005432584100	31519	Economy	10100.00
0005432584071	31519	Economy	10100.00
0005432858161	31519	Economy	10100.00
0005432858166	31519	Economy	10100.00
0005432584037	31519	Economy	10100.00
0005432584020	31519	Economy	10100.00
0005432584197	31519	Economy	10100.00
0005432584101	31519	Economy	10100.00
0005433255146	886	Economy	7500.00
0005434943429	886	Economy	7500.00
0005433255125	886	Economy	7500.00
0005433255128	886	Economy	7500.00
0005433255112	886	Economy	7500.00
0005434943422	886	Economy	7500.00
0005434943426	886	Economy	7500.00
0005434943423	886	Economy	7500.00
0005434943430	886	Economy	7500.00
0005433255113	886	Economy	7500.00
0005433255106	886	Economy	7500.00
0005433255129	886	Economy	7500.00
0005433255127	886	Economy	7500.00
0005434943425	886	Economy	7500.00
0005434943424	886	Economy	7500.00
0005434943427	886	Economy	7500.00
0005434943428	886	Economy	7500.00
0005434943382	16242	Economy	7500.00
0005433255164	16242	Economy	7500.00
0005433255165	16242	Economy	7500.00
0005433255163	16242	Economy	7500.00
0005434943361	16242	Economy	7500.00
0005433654834	4323	Business	90500.00
0005435858540	4323	Business	90500.00
0005435858519	4323	Business	90500.00
0005433654837	4323	Business	90500.00
0005433654826	4323	Business	90500.00
0005435858560	4323	Economy	30200.00
0005433654818	4323	Economy	30200.00
0005433654827	4323	Economy	30200.00
0005433654829	4323	Economy	33200.00
0005433654828	4323	Economy	33200.00
0005433654815	4323	Economy	30200.00
0005433654821	4323	Economy	30200.00
0005433654838	4323	Economy	30200.00
0005433654820	4323	Economy	30200.00
0005435858518	4323	Economy	30200.00
0005433654819	4323	Economy	30200.00
0005433654816	4323	Economy	30200.00
0005435858561	4323	Economy	30200.00
0005433654823	4323	Economy	30200.00
0005435858520	4323	Economy	30200.00
0005435858556	4323	Economy	30200.00
0005435858547	4323	Economy	30200.00
0005433654840	4323	Economy	30200.00
0005433654817	4323	Economy	30200.00
0005433654842	4323	Economy	30200.00
0005433654830	4323	Economy	30200.00
0005433654833	4323	Economy	30200.00
0005433654843	4323	Economy	30200.00
0005435858533	4323	Economy	30200.00
0005433654835	4323	Economy	30200.00
0005433654836	4323	Economy	30200.00
0005433654841	4323	Economy	30200.00
0005435858537	4323	Economy	30200.00
0005433654822	4323	Economy	30200.00
0005433654814	4323	Economy	30200.00
0005433654825	4323	Economy	30200.00
0005433654831	4323	Economy	30200.00
0005433654824	4323	Economy	30200.00
0005433654832	4323	Economy	30200.00
0005433654839	4323	Economy	30200.00
0005433811629	14406	Economy	4400.00
0005433811626	14406	Economy	4400.00
0005433811627	14406	Economy	4400.00
0005433367537	21724	Business	9800.00
0005433367904	21724	Business	9800.00
0005435653376	21724	Business	9800.00
0005433367909	21724	Business	9800.00
0005435653395	21724	Business	9800.00
0005435653379	21724	Business	9800.00
0005433367881	21724	Business	9800.00
0005435653366	21724	Business	9800.00
0005435653393	21724	Business	9800.00
0005435653375	21724	Business	9800.00
0005435653404	21724	Business	9800.00
0005433367915	21724	Business	9800.00
0005435653397	21724	Economy	3300.00
0005435653377	21724	Economy	3300.00
0005435653361	21724	Economy	3300.00
0005435653380	21724	Economy	3300.00
0005435653402	21724	Economy	3300.00
0005435653382	21724	Economy	3300.00
0005433367603	21724	Economy	3300.00
0005435653358	21724	Economy	3300.00
0005433367536	21724	Economy	3300.00
0005433367977	21724	Economy	3300.00
0005435653369	21724	Economy	3600.00
0005433367858	21724	Economy	3600.00
0005435653365	21724	Economy	3600.00
0005433367851	21724	Economy	3600.00
0005433367774	21724	Economy	3600.00
0005435653349	21724	Economy	3300.00
0005435653360	21724	Economy	3300.00
0005435653396	21724	Economy	3300.00
0005435653391	21724	Economy	3300.00
0005435653350	21724	Economy	3300.00
0005435653364	21724	Economy	3300.00
0005433368013	21724	Economy	3300.00
0005435653394	21724	Economy	3300.00
0005433368041	21724	Economy	3300.00
0005435653362	21724	Economy	3300.00
0005435653363	21724	Economy	3300.00
0005433367690	21724	Economy	3300.00
0005433367939	21724	Economy	3300.00
0005433367743	21724	Economy	3300.00
0005435653357	21724	Economy	3300.00
0005433367787	21724	Economy	3300.00
0005433367966	21724	Economy	3300.00
0005435653386	21724	Economy	3300.00
0005433367755	21724	Economy	3300.00
0005433367723	21724	Economy	3300.00
0005435653356	21724	Economy	3300.00
0005433367967	21724	Economy	3300.00
0005433367754	21724	Economy	3300.00
0005435653374	21724	Economy	3300.00
0005435653371	21724	Economy	3300.00
0005435653373	21724	Economy	3300.00
0005433367792	21724	Economy	3300.00
0005435653383	21724	Economy	3300.00
0005433367914	21724	Economy	3300.00
0005435653370	21724	Economy	3300.00
0005433367860	21724	Economy	3300.00
0005433367669	21724	Economy	3300.00
0005435653384	21724	Economy	3300.00
0005433367742	21724	Economy	3300.00
0005433367882	21724	Economy	3300.00
0005435653353	21724	Economy	3300.00
0005433367670	21724	Economy	3300.00
0005435653372	21724	Economy	3300.00
0005435653387	21724	Economy	3300.00
0005433367793	21724	Economy	3300.00
0005433367861	21724	Economy	3300.00
0005435653401	21724	Economy	3300.00
0005433367880	21724	Economy	3300.00
0005435653368	21724	Economy	3300.00
0005435653399	21724	Economy	3300.00
0005433367741	21724	Economy	3300.00
0005435653352	21724	Economy	3300.00
0005433367794	21724	Economy	3300.00
0005433367720	21724	Economy	3300.00
0005435653381	21724	Economy	3300.00
0005435653398	21724	Economy	3300.00
0005435653388	21724	Economy	3300.00
0005435653351	21724	Economy	3300.00
0005435653400	21724	Economy	3300.00
0005435653354	21724	Economy	3300.00
0005433367910	21724	Economy	3300.00
0005435653359	21724	Economy	3300.00
0005435653403	21724	Economy	3300.00
0005435653355	21724	Economy	3300.00
0005435653385	21724	Economy	3300.00
0005433367827	21724	Economy	3300.00
0005435653367	21724	Economy	3300.00
0005435653390	21724	Economy	3300.00
0005435653378	21724	Economy	3300.00
0005433367668	21724	Economy	3300.00
0005435653389	21724	Economy	3300.00
0005435653392	21724	Economy	3300.00
0005433367843	21724	Economy	3300.00
0005433763323	9334	Business	186200.00
0005433785254	9334	Business	186200.00
0005433805645	9334	Business	186200.00
0005433785258	9334	Business	186200.00
0005433785230	9334	Business	186200.00
0005433785250	9334	Business	186200.00
0005433805661	9334	Business	186200.00
0005433785239	9334	Business	186200.00
0005433763318	9334	Business	186200.00
0005433785259	9334	Business	186200.00
0005433785251	9334	Business	186200.00
0005434151706	9334	Business	186200.00
0005433805676	9334	Business	186200.00
0005433785225	9334	Business	186200.00
0005433785257	9334	Business	186200.00
0005433805662	9334	Business	186200.00
0005433805646	9334	Business	186200.00
0005433785236	9334	Business	186200.00
0005435269733	9334	Business	186200.00
0005434151700	9334	Economy	62100.00
0005433805666	9334	Economy	62100.00
0005433785226	9334	Economy	62100.00
0005433805654	9334	Economy	62100.00
0005433785256	9334	Economy	62100.00
0005433805667	9334	Economy	62100.00
0005434151702	9334	Economy	62100.00
0005433805682	9334	Economy	62100.00
0005434171050	9334	Economy	62100.00
0005435269729	9334	Economy	62100.00
0005433785234	9334	Economy	62100.00
0005433785246	9334	Economy	62100.00
0005433805648	9334	Economy	62100.00
0005433805659	9334	Economy	62100.00
0005433785245	9334	Economy	62100.00
0005434273076	9334	Economy	62100.00
0005432657474	9334	Economy	62100.00
0005433805680	9334	Economy	62100.00
0005433805670	9334	Economy	62100.00
0005433785232	9334	Economy	62100.00
0005432665292	9334	Economy	62100.00
0005432667471	9334	Economy	62100.00
0005433785229	9334	Economy	62100.00
0005434151705	9334	Economy	62100.00
0005433805644	9334	Economy	62100.00
0005433785235	9334	Economy	62100.00
0005433805674	9334	Economy	62100.00
0005433805653	9334	Economy	62100.00
0005434171103	9334	Economy	62100.00
0005434170984	9334	Economy	62100.00
0005433805658	9334	Economy	62100.00
0005433785240	9334	Economy	62100.00
0005433805649	9334	Economy	62100.00
0005434273077	9334	Economy	62100.00
0005433805672	9334	Economy	62100.00
0005433785247	9334	Economy	62100.00
0005432666407	9334	Economy	62100.00
0005434151701	9334	Economy	62100.00
0005433785252	9334	Economy	62100.00
0005433763326	9334	Economy	62100.00
0005434151703	9334	Economy	62100.00
0005432666405	9334	Economy	62100.00
0005432665291	9334	Economy	62100.00
0005434171010	9334	Economy	62100.00
0005434151697	9334	Economy	62100.00
0005433763325	9334	Economy	62100.00
0005433785249	9334	Economy	62100.00
0005433805657	9334	Economy	62100.00
0005433805664	9334	Economy	62100.00
0005433763322	9334	Economy	62100.00
0005433805675	9334	Economy	62100.00
0005433763329	9334	Economy	62100.00
0005433785231	9334	Economy	62100.00
0005433785243	9334	Economy	62100.00
0005434151696	9334	Economy	62100.00
0005434171116	9334	Economy	62100.00
0005433785224	9334	Economy	62100.00
0005433785227	9334	Economy	62100.00
0005433805652	9334	Economy	62100.00
0005433785248	9334	Economy	62100.00
0005434270207	9334	Economy	68300.00
0005433785223	9334	Economy	68300.00
0005433805679	9334	Economy	62100.00
0005434273075	9334	Economy	62100.00
0005433805668	9334	Economy	62100.00
0005433785233	9334	Economy	62100.00
0005433805663	9334	Economy	62100.00
0005433805673	9334	Economy	62100.00
0005433805681	9334	Economy	62100.00
0005435269728	9334	Economy	62100.00
0005433785228	9334	Economy	62100.00
0005432657473	9334	Economy	62100.00
0005432666406	9334	Economy	62100.00
0005433763320	9334	Economy	62100.00
0005433805655	9334	Economy	62100.00
0005433763317	9334	Economy	62100.00
0005433805656	9334	Economy	62100.00
0005433805669	9334	Economy	62100.00
0005434273080	9334	Economy	62100.00
0005434171163	9334	Economy	62100.00
0005433763319	9334	Economy	62100.00
0005434151704	9334	Economy	62100.00
0005433785244	9334	Economy	62100.00
0005433785237	9334	Economy	62100.00
0005433763331	9334	Economy	62100.00
0005434151695	9334	Economy	62100.00
0005432657475	9334	Economy	62100.00
0005433805683	9334	Economy	62100.00
0005433805677	9334	Economy	62100.00
0005433785253	9334	Economy	62100.00
0005433805671	9334	Economy	62100.00
0005433805650	9334	Economy	62100.00
0005432667472	9334	Economy	62100.00
0005433805665	9334	Economy	62100.00
0005433805651	9334	Economy	62100.00
0005435269743	9334	Economy	62100.00
0005434270206	9334	Economy	62100.00
0005433785241	9334	Economy	62100.00
0005433785242	9334	Economy	62100.00
0005433763321	9334	Economy	62100.00
0005433763330	9334	Economy	62100.00
0005433763327	9334	Economy	62100.00
0005433805684	9334	Economy	62100.00
0005433805660	9334	Economy	62100.00
0005433785255	9334	Economy	62100.00
0005433805647	9334	Economy	62100.00
0005433763324	9334	Economy	62100.00
0005433805678	9334	Economy	62100.00
0005433763328	9334	Economy	62100.00
0005433785238	9334	Economy	62100.00
0005435269800	26244	Business	186200.00
0005434171178	26244	Business	186200.00
0005434171167	26244	Business	186200.00
0005433784948	26244	Business	186200.00
0005433763233	26244	Business	186200.00
0005433805464	26244	Business	186200.00
0005432663033	26244	Business	186200.00
0005434270221	26244	Business	186200.00
0005433784967	26244	Business	186200.00
0005433805367	26244	Business	186200.00
0005433805296	26244	Business	186200.00
0005433784712	26244	Business	186200.00
0005432657449	26244	Economy	68300.00
0005433763205	26244	Economy	68300.00
0005434269120	26244	Economy	62100.00
0005434171171	26244	Economy	62100.00
0005433805185	26244	Economy	62100.00
0005433805308	26244	Economy	62100.00
0005433784966	26244	Economy	62100.00
0005433785031	26244	Economy	62100.00
0005435269797	26244	Economy	62100.00
0005433785041	26244	Economy	62100.00
0005434171170	26244	Economy	62100.00
0005433805425	26244	Economy	62100.00
0005433805259	26244	Economy	62100.00
0005433763150	26244	Economy	62100.00
0005433805496	26244	Economy	62100.00
0005433805513	26244	Economy	62100.00
0005433784863	26244	Economy	62100.00
0005433805212	26244	Economy	62100.00
0005433784871	26244	Economy	62100.00
0005433805375	26244	Economy	62100.00
0005434151728	26244	Economy	62100.00
0005434171176	26244	Economy	62100.00
0005435269798	26244	Economy	62100.00
0005434151727	26244	Economy	62100.00
0005434151726	26244	Economy	62100.00
0005432657452	26244	Economy	62100.00
0005433763186	26244	Economy	62100.00
0005433784897	26244	Economy	62100.00
0005433805336	26244	Economy	62100.00
0005433763214	26244	Economy	62100.00
0005432657418	26244	Economy	62100.00
0005433785062	26244	Economy	62100.00
0005433763161	26244	Economy	62100.00
0005433805393	26244	Economy	62100.00
0005435269799	26244	Economy	62100.00
0005433805312	26244	Economy	62100.00
0005432663032	26244	Economy	62100.00
0005434271327	26244	Economy	62100.00
0005433805458	26244	Economy	62100.00
0005433784854	26244	Economy	62100.00
0005433805313	26244	Economy	62100.00
0005433805352	26244	Economy	62100.00
0005433805535	26244	Economy	62100.00
0005433805437	26244	Economy	62100.00
0005433763232	26244	Economy	62100.00
0005433763202	26244	Economy	62100.00
0005433805335	26244	Economy	62100.00
0005433805186	26244	Economy	62100.00
0005434171172	26244	Economy	62100.00
0005434269119	26244	Economy	62100.00
0005434171173	26244	Economy	62100.00
0005433763135	26244	Economy	62100.00
0005433785055	26244	Economy	62100.00
0005433785014	26244	Economy	62100.00
0005434151729	26244	Economy	62100.00
0005433763213	26244	Economy	62100.00
0005433784938	26244	Economy	62100.00
0005433784887	26244	Economy	62100.00
0005432663035	26244	Economy	68300.00
0005434171177	26244	Economy	62100.00
0005435269796	26244	Economy	68300.00
0005433785032	26244	Economy	68300.00
0005433805392	26244	Economy	62100.00
0005435269801	26244	Economy	62100.00
0005433763164	26244	Economy	62100.00
0005434270222	26244	Economy	62100.00
0005433785001	26244	Economy	62100.00
0005432657446	26244	Economy	62100.00
0005433784870	26244	Economy	62100.00
0005433784898	26244	Economy	62100.00
0005432663031	26244	Economy	62100.00
0005434171166	26244	Economy	62100.00
0005434171175	26244	Economy	62100.00
0005433805309	26244	Economy	62100.00
0005433763231	26244	Economy	62100.00
0005434171168	26244	Economy	62100.00
0005434171165	26244	Economy	62100.00
0005433784740	26244	Economy	62100.00
0005433805351	26244	Economy	62100.00
0005433785065	26244	Economy	62100.00
0005433805407	26244	Economy	62100.00
0005433784909	26244	Economy	62100.00
0005433785066	26244	Economy	62100.00
0005433805512	26244	Economy	62100.00
0005433784945	26244	Economy	62100.00
0005433784910	26244	Economy	62100.00
0005433785074	26244	Economy	62100.00
0005433805290	26244	Economy	62100.00
0005433805406	26244	Economy	62100.00
0005434269118	26244	Economy	62100.00
0005433785069	26244	Economy	62100.00
0005432663036	26244	Economy	62100.00
0005433763172	26244	Economy	62100.00
0005432657432	26244	Economy	62100.00
0005433784971	26244	Economy	62100.00
0005433784933	26244	Economy	62100.00
0005434171174	26244	Economy	62100.00
0005433784930	26244	Economy	62100.00
0005434171169	26244	Economy	62100.00
0005434271328	26244	Economy	62100.00
0005433805502	26244	Economy	62100.00
0005433785061	26244	Economy	62100.00
0005433805277	26244	Economy	62100.00
0005434171164	26244	Economy	62100.00
0005432663040	26244	Economy	62100.00
0005435135710	4892	Economy	5300.00
0005435929646	4892	Economy	5300.00
0005435135711	4892	Economy	5300.00
0005435135707	4892	Economy	5300.00
0005435135709	4892	Economy	5300.00
0005435135708	4892	Economy	5300.00
0005435929666	33056	Economy	5300.00
0005435135668	33056	Economy	5300.00
0005435135684	33056	Economy	5300.00
0005435929665	33056	Economy	5300.00
0005434217981	9477	Economy	17900.00
0005434217972	9477	Economy	17900.00
0005434217980	9477	Economy	17900.00
0005434983328	9477	Economy	17900.00
0005434983332	9477	Economy	17900.00
0005434983329	9477	Economy	17900.00
0005434983330	9477	Economy	17900.00
0005434983331	9477	Economy	17900.00
0005434218001	27334	Economy	17900.00
0005434983296	27334	Economy	17900.00
0005434217999	27334	Economy	17900.00
0005434983288	27334	Economy	17900.00
0005434218002	27334	Economy	17900.00
0005434218003	27334	Economy	17900.00
0005434218000	27334	Economy	17900.00
0005434983313	27334	Economy	17900.00
0005434983297	27334	Economy	17900.00
0005433960747	24245	Business	36400.00
0005433960841	24245	Business	36400.00
0005433985744	24245	Business	36400.00
0005433985745	24245	Business	36400.00
0005433985885	24245	Business	36400.00
0005433985827	24245	Business	36400.00
0005433960782	24245	Business	36400.00
0005433960612	24245	Business	36400.00
0005433960685	24245	Business	36400.00
0005433986019	24245	Business	36400.00
0005433960703	24245	Business	36400.00
0005433960745	24245	Business	36400.00
0005433960813	24245	Business	36400.00
0005433985829	24245	Economy	12100.00
0005433985761	24245	Economy	12100.00
0005433985824	24245	Economy	12100.00
0005433960844	24245	Economy	12100.00
0005433960839	24245	Economy	12100.00
0005433960664	24245	Economy	12100.00
0005433985836	24245	Economy	12100.00
0005433960834	24245	Economy	12100.00
0005433985897	24245	Economy	12100.00
0005433985970	24245	Economy	12100.00
0005433986041	24245	Economy	12100.00
0005433960667	24245	Economy	12100.00
0005433985937	24245	Economy	12100.00
0005433960503	24245	Economy	12100.00
0005433960686	24245	Economy	12100.00
0005433960487	24245	Economy	12100.00
0005433985782	24245	Economy	12100.00
0005433960650	24245	Economy	12100.00
0005433985907	24245	Economy	12100.00
0005433985808	24245	Economy	12100.00
0005433960651	24245	Economy	12100.00
0005433960673	24245	Economy	12100.00
0005433985896	24245	Economy	12100.00
0005433986011	24245	Economy	12100.00
0005433985748	24245	Economy	12100.00
0005433985784	24245	Economy	12100.00
0005433985941	24245	Economy	12100.00
0005433960753	24245	Economy	12100.00
0005433985762	24245	Economy	12100.00
0005433985886	24245	Economy	12100.00
0005433985934	24245	Economy	12100.00
0005433960754	24245	Economy	12100.00
0005433960684	24245	Economy	12100.00
0005433986110	24245	Economy	12100.00
0005433985830	24245	Economy	12100.00
0005433960702	24245	Economy	12100.00
0005433986066	24245	Economy	12100.00
0005433986010	24245	Economy	12100.00
0005433960828	24245	Economy	12100.00
0005433985906	24245	Economy	12100.00
0005433985952	24245	Economy	12100.00
0005433960516	24245	Economy	12100.00
0005433960711	24245	Economy	12100.00
0005433985940	24245	Economy	12100.00
0005433985846	24245	Economy	12100.00
0005433960797	24245	Economy	12100.00
0005433960763	24245	Economy	12100.00
0005433986091	24245	Economy	13400.00
0005433960610	24245	Economy	12100.00
0005433986053	24245	Economy	12100.00
0005433960798	24245	Economy	12100.00
0005433985826	24245	Economy	12100.00
0005433985953	24245	Economy	12100.00
0005433960784	24245	Economy	12100.00
0005433960766	24245	Economy	12100.00
0005433960765	24245	Economy	12100.00
0005433985793	24245	Economy	12100.00
0005433985994	24245	Economy	12100.00
0005433960845	24245	Economy	12100.00
0005433960581	24245	Economy	12100.00
0005433960850	24245	Economy	12100.00
0005433960611	24245	Economy	12100.00
0005433960409	24245	Economy	12100.00
0005433985760	24245	Economy	12100.00
0005433960829	24245	Economy	12100.00
0005433985781	24245	Economy	12100.00
0005433985854	24245	Economy	12100.00
0005433985800	24245	Economy	12100.00
0005433985905	24245	Economy	12100.00
0005433960666	24245	Economy	12100.00
0005433985853	24245	Economy	12100.00
0005433985883	24245	Economy	12100.00
0005433985825	24245	Economy	12100.00
0005433960504	24245	Economy	12100.00
0005433985805	24245	Economy	12100.00
0005433960665	24245	Economy	12100.00
0005433985938	24245	Economy	12100.00
0005433985743	24245	Economy	12100.00
0005433960764	24245	Economy	12100.00
0005433960808	24245	Economy	12100.00
0005433985917	24245	Economy	12100.00
0005433985733	24245	Economy	12100.00
0005433985884	24245	Economy	12100.00
0005433960594	24245	Economy	12100.00
0005433960593	24245	Economy	12100.00
0005433985895	24245	Economy	12100.00
0005433961267	25953	Business	36400.00
0005433961310	25953	Business	36400.00
0005433986285	25953	Business	36400.00
0005433961278	25953	Business	36400.00
0005433986290	25953	Business	36400.00
0005433986272	25953	Business	36400.00
0005433961288	25953	Business	36400.00
0005433986289	25953	Business	36400.00
0005433961295	25953	Business	36400.00
0005433961319	25953	Business	36400.00
0005433986282	25953	Business	36400.00
0005433986280	25953	Business	36400.00
0005433986277	25953	Business	36400.00
0005433986299	25953	Business	36400.00
0005433961306	25953	Economy	13400.00
0005433961284	25953	Economy	12100.00
0005433961290	25953	Economy	12100.00
0005433986275	25953	Economy	12100.00
0005433986300	25953	Economy	12100.00
0005433961321	25953	Economy	12100.00
0005433961299	25953	Economy	12100.00
0005433961313	25953	Economy	12100.00
0005433986281	25953	Economy	12100.00
0005433986263	25953	Economy	12100.00
0005433961289	25953	Economy	12100.00
0005433986293	25953	Economy	12100.00
0005433961303	25953	Economy	12100.00
0005433986270	25953	Economy	12100.00
0005433961328	25953	Economy	12100.00
0005433961308	25953	Economy	12100.00
0005433961263	25953	Economy	12100.00
0005433986266	25953	Economy	12100.00
0005433986305	25953	Economy	12100.00
0005433986291	25953	Economy	12100.00
0005433961322	25953	Economy	12100.00
0005433961287	25953	Economy	12100.00
0005433961305	25953	Economy	12100.00
0005433961293	25953	Economy	12100.00
0005433986269	25953	Economy	12100.00
0005433961274	25953	Economy	12100.00
0005433961281	25953	Economy	12100.00
0005433961276	25953	Economy	12100.00
0005433961268	25953	Economy	12100.00
0005433986264	25953	Economy	12100.00
0005433986296	25953	Economy	12100.00
0005433986274	25953	Economy	12100.00
0005433961311	25953	Economy	12100.00
0005433961309	25953	Economy	12100.00
0005433986297	25953	Economy	12100.00
0005433986267	25953	Economy	12100.00
0005433986295	25953	Economy	12100.00
0005433986303	25953	Economy	12100.00
0005433961312	25953	Economy	12100.00
0005433986276	25953	Economy	12100.00
0005433961271	25953	Economy	12100.00
0005433961280	25953	Economy	12100.00
0005433986286	25953	Economy	12100.00
0005433961325	25953	Economy	12100.00
0005433986265	25953	Economy	12100.00
0005433961301	25953	Economy	12100.00
0005433961316	25953	Economy	12100.00
0005433961277	25953	Economy	12100.00
0005433961318	25953	Economy	12100.00
0005433961314	25953	Economy	12100.00
0005433986271	25953	Economy	12100.00
0005433961264	25953	Economy	12100.00
0005433961298	25953	Economy	12100.00
0005433961294	25953	Economy	12100.00
0005433961265	25953	Economy	12100.00
0005433961302	25953	Economy	12100.00
0005433961292	25953	Economy	12100.00
0005433961320	25953	Economy	12100.00
0005433986288	25953	Economy	12100.00
0005433961324	25953	Economy	12100.00
0005433961296	25953	Economy	12100.00
0005433986301	25953	Economy	12100.00
0005433961269	25953	Economy	13400.00
0005433961304	25953	Economy	12100.00
0005433986273	25953	Economy	12100.00
0005433986278	25953	Economy	12100.00
0005433986284	25953	Economy	12100.00
0005433961323	25953	Economy	12100.00
0005433986302	25953	Economy	12100.00
0005433961275	25953	Economy	12100.00
0005433961297	25953	Economy	12100.00
0005433961279	25953	Economy	12100.00
0005433986304	25953	Economy	12100.00
0005433961285	25953	Economy	12100.00
0005433986283	25953	Economy	12100.00
0005433986287	25953	Economy	12100.00
0005433986262	25953	Economy	12100.00
0005433986259	25953	Economy	12100.00
0005433986279	25953	Economy	12100.00
0005433986261	25953	Economy	12100.00
0005433961273	25953	Economy	12100.00
0005433986260	25953	Economy	12100.00
0005433961266	25953	Economy	12100.00
0005433986294	25953	Economy	12100.00
0005433961315	25953	Economy	12100.00
0005433986298	25953	Economy	12100.00
0005433961307	25953	Economy	12100.00
0005433986268	25953	Economy	12100.00
0005433961282	25953	Economy	12100.00
0005433961317	25953	Economy	12100.00
0005433961270	25953	Economy	12100.00
0005433961291	25953	Economy	12100.00
0005433961327	25953	Economy	12100.00
0005433961283	25953	Economy	12100.00
0005433986292	25953	Economy	12100.00
0005433961326	25953	Economy	12100.00
0005433961272	25953	Economy	12100.00
0005433961286	25953	Economy	12100.00
0005433961300	25953	Economy	12100.00
0005434480526	957	Economy	25400.00
0005434480525	957	Economy	25400.00
0005433165871	957	Economy	23100.00
0005434480545	957	Economy	23100.00
0005434480535	957	Economy	23100.00
0005433165870	957	Economy	23100.00
0005434480546	957	Economy	23100.00
0005433165939	957	Economy	23100.00
0005434480534	957	Economy	23100.00
0005432269519	957	Economy	23100.00
0005434480528	957	Economy	23100.00
0005433165930	957	Economy	23100.00
0005434480544	957	Economy	23100.00
0005434480541	957	Economy	23100.00
0005434480529	957	Economy	23100.00
0005433165878	957	Economy	23100.00
0005434480547	957	Economy	23100.00
0005434480532	957	Economy	23100.00
0005432269517	957	Economy	23100.00
0005433165938	957	Economy	23100.00
0005434480536	957	Economy	23100.00
0005433165904	957	Economy	23100.00
0005432269518	957	Economy	23100.00
0005434480537	957	Economy	23100.00
0005434480543	957	Economy	23100.00
0005434480539	957	Economy	23100.00
0005434480542	957	Economy	23100.00
0005434480530	957	Economy	23100.00
0005434480533	957	Economy	23100.00
0005434480540	957	Economy	23100.00
0005434480523	957	Economy	23100.00
0005434480524	957	Economy	23100.00
0005434480531	957	Economy	23100.00
0005433165918	957	Economy	23100.00
0005434480538	957	Economy	23100.00
0005433165905	957	Economy	23100.00
0005434480527	957	Economy	23100.00
0005434480397	16572	Economy	25400.00
0005434480312	16572	Economy	25400.00
0005433166007	16572	Economy	25400.00
0005433166004	16572	Economy	23100.00
0005433166012	16572	Economy	23100.00
0005434480406	16572	Economy	23100.00
0005434480313	16572	Economy	23100.00
0005434480340	16572	Economy	23100.00
0005433166008	16572	Economy	23100.00
0005434480384	16572	Economy	23100.00
0005434480364	16572	Economy	23100.00
0005434480399	16572	Economy	23100.00
0005434480330	16572	Economy	23100.00
0005433166009	16572	Economy	23100.00
0005433166010	16572	Economy	23100.00
0005434480237	16572	Economy	23100.00
0005434480292	16572	Economy	23100.00
0005434480329	16572	Economy	23100.00
0005433166015	16572	Economy	23100.00
0005434480271	16572	Economy	23100.00
0005433166006	16572	Economy	23100.00
0005434480229	16572	Economy	23100.00
0005434480228	16572	Economy	23100.00
0005433166005	16572	Economy	23100.00
0005434480140	16572	Economy	23100.00
0005434480238	16572	Economy	23100.00
0005433166011	16572	Economy	23100.00
0005434480333	16572	Economy	23100.00
0005434480405	16572	Economy	23100.00
0005433166017	16572	Economy	23100.00
0005433166014	16572	Economy	23100.00
0005433166013	16572	Economy	23100.00
0005434480383	16572	Economy	23100.00
0005433166003	16572	Economy	23100.00
0005434480363	16572	Economy	23100.00
0005434480260	16572	Economy	23100.00
0005433166016	16572	Economy	23100.00
0005434480390	16572	Economy	23100.00
0005433872513	3210	Economy	19000.00
0005433872511	3210	Economy	17200.00
0005433872512	3210	Economy	17200.00
0005433872509	3210	Economy	17200.00
0005433872514	3210	Economy	17200.00
0005433872510	3210	Economy	17200.00
0005433872515	3210	Economy	17200.00
0005433872479	32538	Economy	19000.00
0005433872482	32538	Economy	17200.00
0005433872474	32538	Economy	17200.00
0005433872483	32538	Economy	17200.00
0005433872486	32538	Economy	17200.00
0005433289831	10372	Economy	17000.00
0005435386558	10372	Economy	17000.00
0005433289800	10372	Economy	17000.00
0005435142674	10372	Economy	17000.00
0005435142670	10372	Economy	15400.00
0005435386567	10372	Economy	15400.00
0005435150123	10372	Economy	15400.00
0005435386565	10372	Economy	15400.00
0005435150120	10372	Economy	15400.00
0005433289830	10372	Economy	15400.00
0005435142676	10372	Economy	15400.00
0005435142677	10372	Economy	15400.00
0005435142671	10372	Economy	15400.00
0005435142669	10372	Economy	15400.00
0005433289814	10372	Economy	15400.00
0005435150127	10372	Economy	15400.00
0005435386557	10372	Economy	15400.00
0005435150130	10372	Economy	15400.00
0005435150126	10372	Economy	15400.00
0005435142681	10372	Economy	15400.00
0005433289834	10372	Economy	15400.00
0005435150133	10372	Economy	15400.00
0005433289833	10372	Economy	15400.00
0005435142668	10372	Economy	15400.00
0005435386569	10372	Economy	15400.00
0005435150121	10372	Economy	15400.00
0005435386568	10372	Economy	15400.00
0005435142679	10372	Economy	15400.00
0005435142680	10372	Economy	15400.00
0005435142678	10372	Economy	15400.00
0005435142673	10372	Economy	15400.00
0005435150134	10372	Economy	15400.00
0005435150132	10372	Economy	15400.00
0005433289799	10372	Economy	15400.00
0005435142672	10372	Economy	15400.00
0005435150128	10372	Economy	15400.00
0005435150124	10372	Economy	15400.00
0005435150125	10372	Economy	15400.00
0005435386559	10372	Economy	15400.00
0005435150122	10372	Economy	15400.00
0005435150131	10372	Economy	15400.00
0005435150129	10372	Economy	15400.00
0005435142675	10372	Economy	15400.00
0005435150017	21940	Economy	17000.00
0005435142545	21940	Economy	17000.00
0005435142592	21940	Economy	15400.00
0005435150024	21940	Economy	15400.00
0005435149996	21940	Economy	15400.00
0005433289916	21940	Economy	15400.00
0005435386628	21940	Economy	15400.00
0005435142554	21940	Economy	15400.00
0005433289911	21940	Economy	15400.00
0005435149987	21940	Economy	15400.00
0005435142510	21940	Economy	15400.00
0005435150019	21940	Economy	15400.00
0005435142604	21940	Economy	15400.00
0005435386622	21940	Economy	15400.00
0005435142581	21940	Economy	15400.00
0005435142579	21940	Economy	15400.00
0005435386624	21940	Economy	15400.00
0005435386626	21940	Economy	15400.00
0005435142612	21940	Economy	15400.00
0005433289913	21940	Economy	15400.00
0005433289915	21940	Economy	15400.00
0005435386629	21940	Economy	15400.00
0005435386621	21940	Economy	15400.00
0005435142593	21940	Economy	15400.00
0005435386623	21940	Economy	15400.00
0005433289914	21940	Economy	15400.00
0005435142509	21940	Economy	15400.00
0005435142591	21940	Economy	15400.00
0005435386625	21940	Economy	15400.00
0005435142605	21940	Economy	15400.00
0005435150047	21940	Economy	15400.00
0005435142609	21940	Economy	15400.00
0005435386627	21940	Economy	15400.00
0005433289912	21940	Economy	15400.00
0005435142546	21940	Economy	15400.00
0005435150016	21940	Economy	15400.00
0005435142514	21940	Economy	15400.00
0005435502285	11229	Business	57200.00
0005435319541	11229	Business	57200.00
0005434573459	11229	Business	57200.00
0005435502283	11229	Business	57200.00
0005435502252	11229	Business	57200.00
0005435529235	11229	Business	57200.00
0005435502211	11229	Business	57200.00
0005435319542	11229	Business	57200.00
0005434573449	11229	Business	57200.00
0005435529234	11229	Economy	19100.00
0005434573451	11229	Economy	19100.00
0005434573448	11229	Economy	19100.00
0005434573453	11229	Economy	19100.00
0005435502295	11229	Economy	19100.00
0005435502412	11229	Economy	19100.00
0005434573450	11229	Economy	19100.00
0005434573457	11229	Economy	21000.00
0005435545717	11229	Economy	21000.00
0005435545751	11229	Economy	19100.00
0005435529255	11229	Economy	19100.00
0005435545745	11229	Economy	19100.00
0005435545732	11229	Economy	19100.00
0005435502393	11229	Economy	19100.00
0005435545731	11229	Economy	19100.00
0005434573461	11229	Economy	19100.00
0005435529170	11229	Economy	19100.00
0005435529218	11229	Economy	19100.00
0005435529254	11229	Economy	19100.00
0005435502322	11229	Economy	19100.00
0005435529263	11229	Economy	19100.00
0005435545740	11229	Economy	19100.00
0005435529151	11229	Economy	19100.00
0005435319585	11229	Economy	19100.00
0005435502413	11229	Economy	19100.00
0005435529351	11229	Economy	19100.00
0005435502290	11229	Economy	19100.00
0005435502265	11229	Economy	19100.00
0005435502249	11229	Economy	19100.00
0005435529322	11229	Economy	19100.00
0005435319544	11229	Economy	19100.00
0005434573455	11229	Economy	19100.00
0005434573456	11229	Economy	19100.00
0005435529145	11229	Economy	19100.00
0005435502369	11229	Economy	19100.00
0005435502328	11229	Economy	19100.00
0005435502356	11229	Economy	19100.00
0005435529304	11229	Economy	19100.00
0005435502353	11229	Economy	19100.00
0005434573458	11229	Economy	19100.00
0005435502284	11229	Economy	19100.00
0005435529244	11229	Economy	19100.00
0005435502411	11229	Economy	19100.00
0005435319529	11229	Economy	19100.00
0005435502352	11229	Economy	19100.00
0005435529219	11229	Economy	19100.00
0005435529236	11229	Economy	19100.00
0005435545727	11229	Economy	19100.00
0005435545746	11229	Economy	19100.00
0005435502394	11229	Economy	19100.00
0005435502286	11229	Economy	19100.00
0005435529157	11229	Economy	19100.00
0005434573452	11229	Economy	19100.00
0005435545723	11229	Economy	19100.00
0005435502364	11229	Economy	19100.00
0005435529237	11229	Economy	19100.00
0005435529264	11229	Economy	19100.00
0005434573460	11229	Economy	19100.00
0005434573454	11229	Economy	19100.00
0005435529303	11229	Economy	19100.00
0005435502251	11229	Economy	19100.00
0005435529265	11229	Economy	19100.00
0005435502464	20935	Business	57200.00
0005434573330	20935	Business	57200.00
0005435518032	20935	Business	57200.00
0005435518041	20935	Business	57200.00
0005434573365	20935	Business	57200.00
0005435518044	20935	Business	57200.00
0005435518040	20935	Business	57200.00
0005435518047	20935	Business	57200.00
0005435508446	20935	Business	57200.00
0005435502470	20935	Economy	19100.00
0005435518046	20935	Economy	19100.00
0005435518037	20935	Economy	19100.00
0005435502463	20935	Economy	19100.00
0005435502476	20935	Economy	19100.00
0005435502472	20935	Economy	19100.00
0005435502477	20935	Economy	19100.00
0005435508443	20935	Economy	19100.00
0005435319654	20935	Economy	19100.00
0005434573348	20935	Economy	21000.00
0005435518043	20935	Economy	21000.00
0005435319653	20935	Economy	21000.00
0005435319658	20935	Economy	21000.00
0005434573366	20935	Economy	19100.00
0005434573331	20935	Economy	19100.00
0005435508445	20935	Economy	19100.00
0005435508442	20935	Economy	19100.00
0005435508439	20935	Economy	19100.00
0005435502468	20935	Economy	19100.00
0005435502466	20935	Economy	19100.00
0005435508436	20935	Economy	19100.00
0005435508435	20935	Economy	19100.00
0005435518048	20935	Economy	19100.00
0005435518035	20935	Economy	19100.00
0005435502484	20935	Economy	19100.00
0005435508433	20935	Economy	19100.00
0005435508432	20935	Economy	19100.00
0005435319659	20935	Economy	19100.00
0005435508430	20935	Economy	19100.00
0005435502469	20935	Economy	19100.00
0005435508431	20935	Economy	19100.00
0005435502473	20935	Economy	19100.00
0005435319655	20935	Economy	19100.00
0005435502471	20935	Economy	19100.00
0005435518030	20935	Economy	19100.00
0005435502480	20935	Economy	19100.00
0005435319657	20935	Economy	19100.00
0005435518031	20935	Economy	19100.00
0005435502475	20935	Economy	19100.00
0005434573342	20935	Economy	19100.00
0005435518028	20935	Economy	19100.00
0005435502479	20935	Economy	19100.00
0005435508440	20935	Economy	19100.00
0005435508444	20935	Economy	19100.00
0005435319650	20935	Economy	19100.00
0005435502482	20935	Economy	19100.00
0005435319651	20935	Economy	19100.00
0005435502483	20935	Economy	19100.00
0005435518029	20935	Economy	19100.00
0005435319652	20935	Economy	19100.00
0005434573389	20935	Economy	19100.00
0005435508438	20935	Economy	19100.00
0005435518036	20935	Economy	19100.00
0005435319656	20935	Economy	19100.00
0005435508437	20935	Economy	19100.00
0005432291949	20935	Economy	19100.00
0005435502474	20935	Economy	19100.00
0005432291948	20935	Economy	19100.00
0005435502467	20935	Economy	19100.00
0005435508434	20935	Economy	19100.00
0005435502481	20935	Economy	19100.00
0005435518038	20935	Economy	19100.00
0005435502478	20935	Economy	19100.00
0005435502465	20935	Economy	19100.00
0005435518039	20935	Economy	19100.00
0005435508441	20935	Economy	19100.00
0005435518033	20935	Economy	19100.00
0005435518045	20935	Economy	19100.00
0005434573210	20935	Economy	19100.00
0005435518042	20935	Economy	19100.00
0005435518034	20935	Economy	19100.00
0005432692975	2886	Business	10300.00
0005432693019	2886	Business	10300.00
0005432693083	2886	Business	10300.00
0005432692915	2886	Economy	3400.00
0005432693067	2886	Economy	3400.00
0005432693009	2886	Economy	3400.00
0005432693082	2886	Economy	3400.00
0005432692882	2886	Economy	3800.00
0005432692947	2886	Economy	3400.00
0005432692919	2886	Economy	3400.00
0005432693058	2886	Economy	3400.00
0005432692948	2886	Economy	3400.00
0005432692914	2886	Economy	3400.00
0005432693117	2886	Economy	3400.00
0005432693069	2886	Economy	3400.00
0005432693068	2886	Economy	3400.00
0005432692881	2886	Economy	3400.00
0005432692828	2886	Economy	3400.00
0005432693049	2886	Economy	3400.00
0005432693093	2886	Economy	3400.00
0005432693018	2886	Economy	3400.00
0005432692890	2886	Economy	3400.00
0005432693031	2886	Economy	3400.00
0005432693118	2886	Economy	3400.00
0005432706976	2934	Business	10300.00
0005433123914	2934	Business	10300.00
0005433123948	2934	Business	10300.00
0005432706967	2934	Business	10300.00
0005432706980	2934	Business	10300.00
0005432706988	2934	Business	10300.00
0005433123944	2934	Business	10300.00
0005433123915	2934	Business	10300.00
0005432706965	2934	Economy	3400.00
0005433123885	2934	Economy	3400.00
0005432880811	2934	Economy	3400.00
0005432880831	2934	Economy	3400.00
0005433123884	2934	Economy	3800.00
0005432217797	2934	Economy	3800.00
0005433123854	2934	Economy	3800.00
0005432706974	2934	Economy	3400.00
0005433123943	2934	Economy	3400.00
0005432880817	2934	Economy	3400.00
0005432706986	2934	Economy	3400.00
0005432880812	2934	Economy	3400.00
0005433123965	2934	Economy	3400.00
0005432706981	2934	Economy	3400.00
0005432880862	2934	Economy	3400.00
0005432706977	2934	Economy	3400.00
0005432880863	2934	Economy	3400.00
0005433123927	2934	Economy	3400.00
0005432217798	2934	Economy	3400.00
0005432880806	2934	Economy	3400.00
0005432880799	2934	Economy	3400.00
0005432706968	2934	Economy	3400.00
0005432880861	2934	Economy	3400.00
0005432880752	2934	Economy	3400.00
0005432706985	2934	Economy	3400.00
0005432706969	2934	Economy	3400.00
0005432706973	2934	Economy	3400.00
0005432706983	2934	Economy	3400.00
0005433123912	2934	Economy	3400.00
0005432706984	2934	Economy	3400.00
0005432880810	2934	Economy	3400.00
0005432706964	2934	Economy	3400.00
0005432706987	2934	Economy	3400.00
0005432880808	2934	Economy	3400.00
0005433123911	2934	Economy	3400.00
0005433194852	2934	Economy	3400.00
0005432706970	2934	Economy	3400.00
0005432706978	2934	Economy	3400.00
0005432706979	2934	Economy	3400.00
0005432706982	2934	Economy	3400.00
0005433123866	2934	Economy	3400.00
0005433123947	2934	Economy	3400.00
0005433123923	2934	Economy	3400.00
0005432880796	2934	Economy	3400.00
0005432880823	2934	Economy	3400.00
0005432706971	2934	Economy	3400.00
0005432706966	2934	Economy	3400.00
0005433123942	2934	Economy	3400.00
0005433123848	2934	Economy	3400.00
0005432880751	2934	Economy	3400.00
0005432217799	2934	Economy	3400.00
0005432706963	2934	Economy	3400.00
0005432706972	2934	Economy	3400.00
0005432706975	2934	Economy	3400.00
0005432880809	2934	Economy	3400.00
0005432880820	2934	Economy	3400.00
0005432693327	30073	Business	10300.00
0005433124095	30073	Business	10300.00
0005432880939	30073	Business	10300.00
0005432706866	30073	Business	10300.00
0005432693340	30073	Business	10300.00
0005432880937	30073	Business	10300.00
0005432706685	30073	Business	10300.00
0005432706859	30073	Business	10300.00
0005433124091	30073	Business	10300.00
0005432706789	30073	Business	10300.00
0005432706762	30073	Business	10300.00
0005433124090	30073	Business	10300.00
0005432706793	30073	Economy	3400.00
0005432693332	30073	Economy	3400.00
0005432880935	30073	Economy	3400.00
0005432693319	30073	Economy	3400.00
0005432880929	30073	Economy	3400.00
0005432693346	30073	Economy	3400.00
0005433124082	30073	Economy	3400.00
0005432693343	30073	Economy	3400.00
0005433124084	30073	Economy	3400.00
0005433124092	30073	Economy	3400.00
0005432706781	30073	Economy	3800.00
0005432693324	30073	Economy	3800.00
0005433124078	30073	Economy	3800.00
0005432693320	30073	Economy	3800.00
0005433124088	30073	Economy	3800.00
0005432693331	30073	Economy	3400.00
0005433124085	30073	Economy	3400.00
0005432706660	30073	Economy	3400.00
0005432880940	30073	Economy	3400.00
0005432693347	30073	Economy	3400.00
0005433124086	30073	Economy	3400.00
0005432693337	30073	Economy	3400.00
0005432693326	30073	Economy	3400.00
0005432693335	30073	Economy	3400.00
0005432706831	30073	Economy	3400.00
0005432880927	30073	Economy	3400.00
0005432706659	30073	Economy	3400.00
0005432706686	30073	Economy	3400.00
0005433124089	30073	Economy	3400.00
0005433124093	30073	Economy	3400.00
0005432706852	30073	Economy	3400.00
0005432693336	30073	Economy	3400.00
0005432693334	30073	Economy	3400.00
0005432706643	30073	Economy	3400.00
0005432706867	30073	Economy	3400.00
0005433124076	30073	Economy	3400.00
0005432693342	30073	Economy	3400.00
0005432880934	30073	Economy	3400.00
0005432693322	30073	Economy	3400.00
0005432693341	30073	Economy	3400.00
0005432880930	30073	Economy	3400.00
0005432706771	30073	Economy	3400.00
0005432693316	30073	Economy	3400.00
0005432880933	30073	Economy	3400.00
0005432880931	30073	Economy	3400.00
0005432880941	30073	Economy	3400.00
0005433124074	30073	Economy	3400.00
0005432693318	30073	Economy	3400.00
0005433124083	30073	Economy	3400.00
0005433124077	30073	Economy	3400.00
0005432706796	30073	Economy	3400.00
0005432880938	30073	Economy	3400.00
0005432706767	30073	Economy	3400.00
0005432706758	30073	Economy	3400.00
0005433124081	30073	Economy	3400.00
0005432880932	30073	Economy	3400.00
0005432706851	30073	Economy	3400.00
0005432693344	30073	Economy	3400.00
0005432693329	30073	Economy	3400.00
0005432693339	30073	Economy	3400.00
0005432693321	30073	Economy	3400.00
0005432693325	30073	Economy	3400.00
0005433124075	30073	Economy	3400.00
0005432706649	30073	Economy	3400.00
0005432706706	30073	Economy	3400.00
0005432706835	30073	Economy	3400.00
0005432706746	30073	Economy	3400.00
0005433194876	30073	Economy	3400.00
0005432693330	30073	Economy	3400.00
0005432693345	30073	Economy	3400.00
0005432693317	30073	Economy	3400.00
0005433124087	30073	Economy	3400.00
0005432880926	30073	Economy	3400.00
0005432693333	30073	Economy	3400.00
0005432880936	30073	Economy	3400.00
0005432706770	30073	Economy	3400.00
0005433124079	30073	Economy	3400.00
0005433124096	30073	Economy	3400.00
0005432693323	30073	Economy	3400.00
0005432693328	30073	Economy	3400.00
0005432693338	30073	Economy	3400.00
0005433124080	30073	Economy	3400.00
0005432706707	30073	Economy	3400.00
0005433124094	30073	Economy	3400.00
0005432880928	30073	Economy	3400.00
0005434980001	23700	Economy	4000.00
0005434980004	23700	Economy	4000.00
0005434980002	23700	Economy	3600.00
0005434988816	23700	Economy	3600.00
0005434980019	23700	Economy	3600.00
0005434980012	23700	Economy	3600.00
0005434980014	23700	Economy	3600.00
0005434988820	23700	Economy	3600.00
0005434979994	23700	Economy	3600.00
0005434980016	23700	Economy	3600.00
0005434980009	23700	Economy	3600.00
0005434988813	23700	Economy	3600.00
0005434980005	23700	Economy	3600.00
0005434980017	23700	Economy	3600.00
0005434980015	23700	Economy	3600.00
0005434979993	23700	Economy	3600.00
0005434988817	23700	Economy	3600.00
0005434988814	23700	Economy	3600.00
0005434979995	23700	Economy	3600.00
0005434980003	23700	Economy	3600.00
0005434980010	23700	Economy	3600.00
0005434980008	23700	Economy	3600.00
0005434979999	23700	Economy	3600.00
0005434979998	23700	Economy	3600.00
0005434980018	23700	Economy	3600.00
0005434979997	23700	Economy	3600.00
0005434980006	23700	Economy	3600.00
0005434988819	23700	Economy	3600.00
0005434988818	23700	Economy	3600.00
0005434988812	23700	Economy	3600.00
0005434980013	23700	Economy	3600.00
0005434979992	23700	Economy	3600.00
0005434988815	23700	Economy	3600.00
0005434979996	23700	Economy	3600.00
0005434980020	23700	Economy	3600.00
0005434980011	23700	Economy	3600.00
0005434980000	23700	Economy	3600.00
0005434980007	23700	Economy	3600.00
0005434979991	23700	Economy	3600.00
0005434979680	27561	Economy	4000.00
0005434979681	27561	Economy	4000.00
0005434979725	27561	Economy	4000.00
0005434979704	27561	Economy	3600.00
0005434979735	27561	Economy	3600.00
0005434979769	27561	Economy	3600.00
0005434979715	27561	Economy	3600.00
0005434979814	27561	Economy	3600.00
0005434988693	27561	Economy	3600.00
0005434979682	27561	Economy	3600.00
0005434979642	27561	Economy	3600.00
0005434979878	27561	Economy	3600.00
0005434979703	27561	Economy	3600.00
0005434988695	27561	Economy	3600.00
0005434988685	27561	Economy	3600.00
0005434979796	27561	Economy	3600.00
0005434979705	27561	Economy	3600.00
0005434979723	27561	Economy	3600.00
0005434979879	27561	Economy	3600.00
0005434979821	27561	Economy	3600.00
0005434988683	27561	Economy	3600.00
0005434979650	27561	Economy	3600.00
0005434988702	27561	Economy	3600.00
0005434988694	27561	Economy	3600.00
0005434979683	27561	Economy	3600.00
0005434988684	27561	Economy	3600.00
0005434988707	27561	Economy	3600.00
0005434979801	27561	Economy	3600.00
0005434979792	27561	Economy	3600.00
0005434979795	27561	Economy	3600.00
0005434979724	27561	Economy	3600.00
0005434979770	27561	Economy	3600.00
0005434979651	27561	Economy	3600.00
0005434979655	27561	Economy	3600.00
0005434979737	27561	Economy	3600.00
0005434979690	27561	Economy	3600.00
0005434988692	27561	Economy	3600.00
0005434979691	27561	Economy	3600.00
0005434979747	27561	Economy	3600.00
0005434979624	27561	Economy	3600.00
0005434302488	10255	Economy	21600.00
0005433111497	10255	Economy	21600.00
0005433113533	10255	Economy	19700.00
0005434302491	10255	Economy	19700.00
0005434302489	10255	Economy	19700.00
0005434302490	10255	Economy	19700.00
0005433111491	10255	Economy	19700.00
0005434302492	10255	Economy	19700.00
0005433111490	10255	Economy	19700.00
0005433113554	19591	Economy	19700.00
0005434302439	19591	Economy	19700.00
0005434302440	19591	Economy	19700.00
0005435069491	3570	Business	26900.00
0005435069523	3570	Business	26900.00
0005435069485	3570	Business	26900.00
0005435069492	3570	Business	26900.00
0005435069483	3570	Business	26900.00
0005435069487	3570	Business	26900.00
0005435069535	3570	Business	26900.00
0005435069518	3570	Economy	9000.00
0005435069527	3570	Economy	9000.00
0005435069510	3570	Economy	9000.00
0005435069494	3570	Economy	9000.00
0005435925266	3570	Economy	9000.00
0005435069497	3570	Economy	9000.00
0005435925267	3570	Economy	9000.00
0005435925275	3570	Economy	9900.00
0005435069526	3570	Economy	9900.00
0005435069515	3570	Economy	9900.00
0005435718994	3570	Economy	9000.00
0005435069502	3570	Economy	9000.00
0005435069505	3570	Economy	9000.00
0005435069519	3570	Economy	9000.00
0005435925332	3570	Economy	9000.00
0005435925292	3570	Economy	9000.00
0005435069511	3570	Economy	9000.00
0005435069525	3570	Economy	9000.00
0005435069530	3570	Economy	9000.00
0005435069489	3570	Economy	9000.00
0005435069493	3570	Economy	9000.00
0005435069509	3570	Economy	9000.00
0005435069516	3570	Economy	9000.00
0005435069501	3570	Economy	9000.00
0005435069488	3570	Economy	9000.00
0005435069529	3570	Economy	9000.00
0005435925274	3570	Economy	9000.00
0005435069533	3570	Economy	9000.00
0005435939876	3570	Economy	9000.00
0005435718992	3570	Economy	9000.00
0005435925309	3570	Economy	9000.00
0005435925276	3570	Economy	9000.00
0005435069531	3570	Economy	9000.00
0005435069503	3570	Economy	9000.00
0005435069517	3570	Economy	9000.00
0005435069496	3570	Economy	9000.00
0005435069506	3570	Economy	9000.00
0005435069508	3570	Economy	9000.00
0005435925303	3570	Economy	9000.00
0005435925257	3570	Economy	9000.00
0005435069513	3570	Economy	9000.00
0005435069532	3570	Economy	9000.00
0005435069534	3570	Economy	9000.00
0005435069524	3570	Economy	9000.00
0005435925308	3570	Economy	9000.00
0005435925291	3570	Economy	9000.00
0005435069521	3570	Economy	9000.00
0005435069498	3570	Economy	9000.00
0005435069486	3570	Economy	9000.00
0005435069520	3570	Economy	9000.00
0005435069500	3570	Economy	9000.00
0005435069504	3570	Economy	9000.00
0005435069514	3570	Economy	9000.00
0005435925333	3570	Economy	9000.00
0005435069512	3570	Economy	9000.00
0005435069484	3570	Economy	9000.00
0005435069499	3570	Economy	9000.00
0005435069522	3570	Economy	9000.00
0005435069490	3570	Economy	9000.00
0005435069495	3570	Economy	9000.00
0005435069528	3570	Economy	9000.00
0005435925226	3570	Economy	9000.00
0005435718993	3570	Economy	9000.00
0005435069507	3570	Economy	9000.00
0005435068903	15295	Business	26900.00
0005435068909	15295	Business	26900.00
0005435068873	15295	Business	26900.00
0005435925391	15295	Business	26900.00
0005435925392	15295	Business	26900.00
0005435068821	15295	Business	26900.00
0005435925404	15295	Business	26900.00
0005435069253	15295	Business	26900.00
0005435068886	15295	Economy	9000.00
0005435068820	15295	Economy	9000.00
0005435068994	15295	Economy	9000.00
0005435069011	15295	Economy	9000.00
0005435068944	15295	Economy	9000.00
0005435069156	15295	Economy	9000.00
0005435925403	15295	Economy	9900.00
0005435068849	15295	Economy	9900.00
0005435925402	15295	Economy	9900.00
0005435069231	15295	Economy	9900.00
0005435068910	15295	Economy	9900.00
0005435925388	15295	Economy	9000.00
0005435069139	15295	Economy	9000.00
0005435925393	15295	Economy	9000.00
0005435069104	15295	Economy	9000.00
0005435069101	15295	Economy	9000.00
0005435068850	15295	Economy	9000.00
0005435068940	15295	Economy	9000.00
0005435925407	15295	Economy	9000.00
0005435068960	15295	Economy	9000.00
0005435925399	15295	Economy	9000.00
0005435069191	15295	Economy	9000.00
0005435925397	15295	Economy	9000.00
0005435925411	15295	Economy	9000.00
0005435068907	15295	Economy	9000.00
0005435068959	15295	Economy	9000.00
0005435069107	15295	Economy	9000.00
0005435069006	15295	Economy	9000.00
0005435069010	15295	Economy	9000.00
0005435068887	15295	Economy	9000.00
0005435925387	15295	Economy	9000.00
0005435068996	15295	Economy	9000.00
0005435068902	15295	Economy	9000.00
0005435068945	15295	Economy	9000.00
0005435069130	15295	Economy	9000.00
0005435068979	15295	Economy	9000.00
0005435068978	15295	Economy	9000.00
0005435069169	15295	Economy	9000.00
0005435068972	15295	Economy	9000.00
0005435068819	15295	Economy	9000.00
0005435069005	15295	Economy	9000.00
0005435925406	15295	Economy	9000.00
0005435925395	15295	Economy	9000.00
0005435925394	15295	Economy	9000.00
0005435925410	15295	Economy	9000.00
0005435925390	15295	Economy	9000.00
0005435925405	15295	Economy	9000.00
0005435925409	15295	Economy	9000.00
0005435068920	15295	Economy	9000.00
0005435068908	15295	Economy	9000.00
0005435069029	15295	Economy	9000.00
0005435925398	15295	Economy	9000.00
0005435069103	15295	Economy	9000.00
0005435925389	15295	Economy	9000.00
0005435069232	15295	Economy	9000.00
0005435925396	15295	Economy	9000.00
0005435068995	15295	Economy	9000.00
0005435925400	15295	Economy	9000.00
0005435068973	15295	Economy	9000.00
0005435069100	15295	Economy	9000.00
0005435068882	15295	Economy	9000.00
0005435925401	15295	Economy	9000.00
0005435068965	15295	Economy	9000.00
0005435925408	15295	Economy	9000.00
0005435069157	15295	Economy	9000.00
0005435068872	15295	Economy	9000.00
0005432660836	18128	Economy	5900.00
0005432659724	18128	Economy	5900.00
0005432659722	18128	Economy	5900.00
0005432659723	18128	Economy	5900.00
0005432660835	18128	Economy	5900.00
0005432664137	26374	Economy	5900.00
0005432664142	26374	Economy	5900.00
0005432667456	26374	Economy	5900.00
0005432664141	26374	Economy	5900.00
0005432664114	26374	Economy	5900.00
0005432664136	26374	Economy	5900.00
0005432660820	26374	Economy	5900.00
0005433102202	85	Business	20000.00
0005432919866	85	Business	20000.00
0005432919802	85	Business	20000.00
0005432919931	85	Business	20000.00
0005432919766	85	Business	20000.00
0005432919834	85	Business	20000.00
0005432919752	85	Business	20000.00
0005432919892	85	Business	20000.00
0005432901475	85	Business	20000.00
0005432919753	85	Business	20000.00
0005432919927	85	Business	20000.00
0005432901634	85	Business	20000.00
0005433102164	85	Business	20000.00
0005432901692	85	Business	20000.00
0005433102063	85	Business	20000.00
0005433102120	85	Business	20000.00
0005433101998	85	Business	20000.00
0005432677557	85	Business	20000.00
0005432919928	85	Business	20000.00
0005433102132	85	Business	20000.00
0005433102125	85	Business	20000.00
0005433101972	85	Economy	7300.00
0005432919853	85	Economy	7300.00
0005433102135	85	Economy	7300.00
0005432901556	85	Economy	7300.00
0005433102194	85	Economy	6700.00
0005432919843	85	Economy	6700.00
0005433102095	85	Economy	6700.00
0005433102068	85	Economy	6700.00
0005433102154	85	Economy	6700.00
0005432677556	85	Economy	6700.00
0005433102104	85	Economy	6700.00
0005433102091	85	Economy	6700.00
0005432901661	85	Economy	6700.00
0005433102127	85	Economy	6700.00
0005433102221	85	Economy	6700.00
0005433102155	85	Economy	6700.00
0005432677587	85	Economy	6700.00
0005433102134	85	Economy	6700.00
0005433102196	85	Economy	6700.00
0005433101943	85	Economy	6700.00
0005432901618	85	Economy	6700.00
0005432901707	85	Economy	6700.00
0005432919865	85	Economy	6700.00
0005433102137	85	Economy	6700.00
0005433102055	85	Economy	6700.00
0005433102206	85	Economy	6700.00
0005432677565	85	Economy	6700.00
0005433102193	85	Economy	6700.00
0005433102122	85	Economy	6700.00
0005433102233	85	Economy	6700.00
0005432901557	85	Economy	6700.00
0005432901491	85	Economy	6700.00
0005433102195	85	Economy	6700.00
0005432901691	85	Economy	6700.00
0005433101920	85	Economy	6700.00
0005432919914	85	Economy	6700.00
0005433101949	85	Economy	6700.00
0005432919848	85	Economy	6700.00
0005432901617	85	Economy	7300.00
0005433102064	85	Economy	7300.00
0005432677586	85	Economy	6700.00
0005433102179	85	Economy	6700.00
0005433102238	85	Economy	6700.00
0005432901490	85	Economy	6700.00
0005432677549	85	Economy	7300.00
0005432157508	85	Economy	6700.00
0005432677564	85	Economy	6700.00
0005432919881	85	Economy	6700.00
0005433102231	85	Economy	6700.00
0005432919867	85	Economy	6700.00
0005433102176	85	Economy	6700.00
0005433101950	85	Economy	6700.00
0005432901662	85	Economy	6700.00
0005433102165	85	Economy	6700.00
0005432919850	85	Economy	6700.00
0005433102220	85	Economy	6700.00
0005433101999	85	Economy	6700.00
0005433102136	85	Economy	6700.00
0005433102121	85	Economy	6700.00
0005432919847	85	Economy	6700.00
0005433101996	85	Economy	6700.00
0005433102146	85	Economy	6700.00
0005433101986	85	Economy	6700.00
0005432677578	85	Economy	6700.00
0005432919882	85	Economy	6700.00
0005432901685	85	Economy	6700.00
0005433102191	85	Economy	6700.00
0005432901476	85	Economy	6700.00
0005432919849	85	Economy	6700.00
0005433102083	85	Economy	6700.00
0005432901658	85	Economy	6700.00
0005432901633	85	Economy	6700.00
0005432919830	85	Economy	6700.00
0005432919822	85	Economy	6700.00
0005433102084	85	Economy	6700.00
0005433102105	85	Economy	6700.00
0005433102119	85	Economy	6700.00
0005432901607	85	Economy	6700.00
0005432919891	85	Economy	6700.00
0005433102019	85	Economy	6700.00
0005432901604	85	Economy	6700.00
0005433102096	85	Economy	6700.00
0005432817714	86	Business	20000.00
0005432817727	86	Business	20000.00
0005432817726	86	Business	20000.00
0005432817701	86	Business	20000.00
0005432817721	86	Business	20000.00
0005432262268	86	Business	20000.00
0005432817707	86	Business	20000.00
0005432262258	86	Business	20000.00
0005432817698	86	Business	20000.00
0005432262262	86	Business	20000.00
0005432262261	86	Business	20000.00
0005432817706	86	Business	20000.00
0005432262259	86	Economy	7300.00
0005432262267	86	Economy	7300.00
0005432262271	86	Economy	7300.00
0005432262263	86	Economy	7300.00
0005432262297	86	Economy	6700.00
0005432262281	86	Economy	6700.00
0005432817704	86	Economy	6700.00
0005432262280	86	Economy	6700.00
0005432756825	86	Economy	6700.00
0005432817710	86	Economy	6700.00
0005432262288	86	Economy	6700.00
0005432262302	86	Economy	6700.00
0005432262299	86	Economy	6700.00
0005432817711	86	Economy	6700.00
0005432207683	86	Economy	6700.00
0005432207679	86	Economy	6700.00
0005432817700	86	Economy	6700.00
0005433687697	86	Economy	6700.00
0005432817708	86	Economy	6700.00
0005432262275	86	Economy	6700.00
0005432262273	86	Economy	6700.00
0005432817715	86	Economy	6700.00
0005432262293	86	Economy	6700.00
0005432817720	86	Economy	6700.00
0005432817705	86	Economy	6700.00
0005432817713	86	Economy	6700.00
0005432262300	86	Economy	6700.00
0005432262278	86	Economy	6700.00
0005432262284	86	Economy	6700.00
0005432262296	86	Economy	6700.00
0005432262264	86	Economy	6700.00
0005432262289	86	Economy	6700.00
0005432262294	86	Economy	6700.00
0005432817716	86	Economy	6700.00
0005432289012	86	Economy	6700.00
0005432262266	86	Economy	6700.00
0005432262277	86	Economy	6700.00
0005432262260	86	Economy	6700.00
0005432817699	86	Economy	6700.00
0005432753291	86	Economy	6700.00
0005432817718	86	Economy	7300.00
0005432262265	86	Economy	7300.00
0005432753292	86	Economy	7300.00
0005432817709	86	Economy	7300.00
0005432262301	86	Economy	6700.00
0005432817719	86	Economy	6700.00
0005432817703	86	Economy	6700.00
0005432262276	86	Economy	7300.00
0005432262282	86	Economy	6700.00
0005432289014	86	Economy	6700.00
0005432207680	86	Economy	6700.00
0005432207682	86	Economy	6700.00
0005432262269	86	Economy	6700.00
0005432753297	86	Economy	6700.00
0005432817723	86	Economy	6700.00
0005432262257	86	Economy	6700.00
0005432262298	86	Economy	6700.00
0005432207681	86	Economy	6700.00
0005432262272	86	Economy	6700.00
0005432262270	86	Economy	6700.00
0005432262285	86	Economy	6700.00
0005432817725	86	Economy	6700.00
0005432262286	86	Economy	6700.00
0005432262279	86	Economy	6700.00
0005432289011	86	Economy	6700.00
0005432817717	86	Economy	6700.00
0005432756821	86	Economy	6700.00
0005432817724	86	Economy	6700.00
0005432262283	86	Economy	6700.00
0005432289013	86	Economy	6700.00
0005432262287	86	Economy	6700.00
0005432817702	86	Economy	6700.00
0005432262290	86	Economy	6700.00
0005432262295	86	Economy	6700.00
0005432817712	86	Economy	6700.00
0005432262274	86	Economy	6700.00
0005432262291	86	Economy	6700.00
0005432262292	86	Economy	6700.00
0005432817722	86	Economy	6700.00
0005432045630	7941	Business	20000.00
0005433102553	7941	Business	20000.00
0005432020491	7941	Business	20000.00
0005432920019	7941	Business	20000.00
0005433102535	7941	Business	20000.00
0005432044548	7941	Business	20000.00
0005432020481	7941	Business	20000.00
0005432920017	7941	Business	20000.00
0005432920032	7941	Business	20000.00
0005432920037	7941	Business	20000.00
0005433102591	7941	Business	20000.00
0005433102587	7941	Business	20000.00
0005433102545	7941	Business	20000.00
0005433102536	7941	Business	20000.00
0005433102586	7941	Business	20000.00
0005433102571	7941	Business	20000.00
0005433102568	7941	Business	20000.00
0005433102579	7941	Business	20000.00
0005433102566	7941	Business	20000.00
0005433102549	7941	Business	20000.00
0005432677605	7941	Business	20000.00
0005433102561	7941	Business	20000.00
0005432020488	7941	Business	20000.00
0005432020482	7941	Economy	7300.00
0005433102578	7941	Economy	7300.00
0005432392023	7941	Economy	7300.00
0005433102575	7941	Economy	7300.00
0005433102590	7941	Economy	6700.00
0005433102547	7941	Economy	6700.00
0005433102530	7941	Economy	6700.00
0005432920036	7941	Economy	6700.00
0005432920025	7941	Economy	6700.00
0005432753328	7941	Economy	6700.00
0005433102557	7941	Economy	6700.00
0005432753329	7941	Economy	6700.00
0005433102551	7941	Economy	6700.00
0005432020470	7941	Economy	6700.00
0005432751554	7941	Economy	6700.00
0005433102574	7941	Economy	6700.00
0005432020475	7941	Economy	6700.00
0005433102556	7941	Economy	6700.00
0005433102537	7941	Economy	6700.00
0005433102572	7941	Economy	6700.00
0005432044549	7941	Economy	6700.00
0005433102554	7941	Economy	6700.00
0005433102582	7941	Economy	6700.00
0005432020472	7941	Economy	6700.00
0005433102555	7941	Economy	6700.00
0005433102576	7941	Economy	6700.00
0005432020483	7941	Economy	6700.00
0005433102560	7941	Economy	6700.00
0005433102581	7941	Economy	6700.00
0005433102528	7941	Economy	6700.00
0005433102564	7941	Economy	6700.00
0005432920031	7941	Economy	6700.00
0005433102570	7941	Economy	6700.00
0005432753327	7941	Economy	6700.00
0005433102580	7941	Economy	6700.00
0005433102548	7941	Economy	6700.00
0005432920029	7941	Economy	6700.00
0005433102583	7941	Economy	6700.00
0005432020469	7941	Economy	6700.00
0005432677607	7941	Economy	6700.00
0005433102540	7941	Economy	6700.00
0005432020477	7941	Economy	6700.00
0005432020485	7941	Economy	6700.00
0005432392025	7941	Economy	6700.00
0005432920024	7941	Economy	7300.00
0005432920023	7941	Economy	7300.00
0005432020478	7941	Economy	7300.00
0005432920035	7941	Economy	7300.00
0005433102565	7941	Economy	7300.00
0005432920027	7941	Economy	6700.00
0005433102538	7941	Economy	6700.00
0005432020476	7941	Economy	6700.00
0005433102573	7941	Economy	6700.00
0005433102563	7941	Economy	7300.00
0005432020473	7941	Economy	6700.00
0005432920034	7941	Economy	6700.00
0005432020480	7941	Economy	6700.00
0005432044547	7941	Economy	6700.00
0005433102588	7941	Economy	6700.00
0005432020486	7941	Economy	6700.00
0005432020489	7941	Economy	6700.00
0005433102539	7941	Economy	6700.00
0005432020465	7941	Economy	6700.00
0005432677608	7941	Economy	6700.00
0005432753331	7941	Economy	6700.00
0005432677606	7941	Economy	6700.00
0005432392024	7941	Economy	6700.00
0005433102562	7941	Economy	6700.00
0005433102546	7941	Economy	6700.00
0005432920030	7941	Economy	6700.00
0005433102592	7941	Economy	6700.00
0005432920033	7941	Economy	6700.00
0005432920018	7941	Economy	6700.00
0005432920028	7941	Economy	6700.00
0005432020466	7941	Economy	6700.00
0005433102531	7941	Economy	6700.00
0005433102577	7941	Economy	6700.00
0005433102589	7941	Economy	6700.00
0005433102542	7941	Economy	6700.00
0005432020468	7941	Economy	6700.00
0005432751555	7941	Economy	6700.00
0005433102532	7941	Economy	6700.00
0005433102543	7941	Economy	6700.00
0005432920021	7941	Economy	6700.00
0005433102544	7941	Economy	6700.00
0005433102567	7941	Economy	6700.00
0005433102569	7941	Economy	6700.00
0005433102559	7941	Economy	6700.00
0005432753330	7941	Economy	6700.00
0005432751553	7941	Economy	6700.00
0005432020490	7941	Economy	6700.00
0005433102558	7941	Economy	6700.00
0005432020474	7941	Economy	6700.00
0005432920026	7941	Economy	6700.00
0005433102585	7941	Economy	6700.00
0005432020471	7941	Economy	6700.00
0005432020487	7941	Economy	6700.00
0005433102584	7941	Economy	6700.00
0005433102534	7941	Economy	6700.00
0005432920020	7941	Economy	6700.00
0005433102550	7941	Economy	6700.00
0005432020484	7941	Economy	6700.00
0005433102541	7941	Economy	6700.00
0005432020492	7941	Economy	6700.00
0005433102529	7941	Economy	6700.00
0005433102552	7941	Economy	6700.00
0005432920022	7941	Economy	6700.00
0005432020479	7941	Economy	6700.00
0005433102533	7941	Economy	6700.00
0005432020467	7941	Economy	6700.00
0005432901747	7943	Business	20000.00
0005434513569	7943	Business	20000.00
0005432002093	7943	Business	20000.00
0005434513582	7943	Business	20000.00
0005432817662	7943	Business	20000.00
0005432817375	7943	Business	20000.00
0005432817307	7943	Business	20000.00
0005434513561	7943	Business	20000.00
0005432817425	7943	Business	20000.00
0005432901744	7943	Business	20000.00
0005432817524	7943	Business	20000.00
0005434513562	7943	Business	20000.00
0005432817510	7943	Business	20000.00
0005432817461	7943	Business	20000.00
0005432817544	7943	Business	20000.00
0005432901748	7943	Business	20000.00
0005432817369	7943	Business	20000.00
0005434513572	7943	Business	20000.00
0005432901751	7943	Economy	7300.00
0005432901743	7943	Economy	7300.00
0005432901745	7943	Economy	7300.00
0005432901755	7943	Economy	7300.00
0005432817384	7943	Economy	6700.00
0005432901753	7943	Economy	6700.00
0005432901758	7943	Economy	6700.00
0005432817478	7943	Economy	6700.00
0005432901746	7943	Economy	6700.00
0005432901750	7943	Economy	6700.00
0005432901759	7943	Economy	6700.00
0005432817343	7943	Economy	6700.00
0005434513570	7943	Economy	6700.00
0005434513580	7943	Economy	6700.00
0005432817496	7943	Economy	6700.00
0005434513563	7943	Economy	6700.00
0005432817382	7943	Economy	6700.00
0005432817394	7943	Economy	6700.00
0005434513589	7943	Economy	6700.00
0005432817292	7943	Economy	6700.00
0005432817454	7943	Economy	6700.00
0005432817448	7943	Economy	6700.00
0005432817511	7943	Economy	6700.00
0005432817366	7943	Economy	6700.00
0005432002092	7943	Economy	6700.00
0005434513576	7943	Economy	6700.00
0005434513581	7943	Economy	6700.00
0005432817360	7943	Economy	6700.00
0005432817431	7943	Economy	7300.00
0005432817374	7943	Economy	7300.00
0005432817538	7943	Economy	7300.00
0005432817406	7943	Economy	6700.00
0005434513583	7943	Economy	6700.00
0005434513590	7943	Economy	6700.00
0005432817449	7943	Economy	6700.00
0005434513567	7943	Economy	6700.00
0005432817534	7943	Economy	6700.00
0005432817306	7943	Economy	6700.00
0005432817342	7943	Economy	6700.00
0005434513564	7943	Economy	6700.00
0005432901752	7943	Economy	6700.00
0005434513577	7943	Economy	6700.00
0005434513571	7943	Economy	6700.00
0005432901754	7943	Economy	6700.00
0005432901756	7943	Economy	6700.00
0005432901757	7943	Economy	6700.00
0005432817663	7943	Economy	6700.00
0005432901749	7943	Economy	6700.00
0005432817385	7943	Economy	6700.00
0005432817501	7943	Economy	6700.00
0005434513578	7943	Economy	6700.00
0005432817545	7943	Economy	6700.00
0005432901760	7943	Economy	6700.00
0005434513591	7943	Economy	6700.00
0005432817376	7943	Economy	6700.00
0005434513568	7943	Economy	6700.00
0005433870749	9653	Economy	6900.00
0005434175759	9653	Economy	6900.00
0005433870748	9653	Economy	6900.00
0005434175768	9653	Economy	6900.00
0005434175753	9653	Economy	6900.00
0005434175767	9653	Economy	6900.00
0005433870729	32375	Economy	6900.00
0005434175789	32375	Economy	6900.00
0005434175786	32375	Economy	6900.00
0005434175785	32375	Economy	6900.00
0005434175788	32375	Economy	6900.00
0005433870730	32375	Economy	6900.00
0005433870725	32375	Economy	6900.00
0005434175787	32375	Economy	6900.00
0005435626319	3474	Business	35000.00
0005434878964	3474	Business	35000.00
0005434426841	3474	Business	35000.00
0005435913923	3474	Business	35000.00
0005434878991	3474	Business	35000.00
0005435626323	3474	Business	35000.00
0005434879031	3474	Business	35000.00
0005435902659	3474	Business	35000.00
0005434938295	3474	Business	35000.00
0005434878977	3474	Business	35000.00
0005432799690	3474	Business	35000.00
0005435126724	3474	Business	35000.00
0005434938312	3474	Business	35000.00
0005434879016	3474	Business	35000.00
0005435902592	3474	Business	35000.00
0005435902690	3474	Business	35000.00
0005435626320	3474	Business	35000.00
0005432799680	3474	Business	35000.00
0005434938297	3474	Business	35000.00
0005435626318	3474	Business	35000.00
0005435902593	3474	Business	35000.00
0005435626329	3474	Business	35000.00
0005434879021	3474	Comfort	19900.00
0005435126705	3474	Comfort	19900.00
0005435626326	3474	Comfort	19900.00
0005432188635	3474	Comfort	19900.00
0005435626317	3474	Comfort	19900.00
0005435126718	3474	Comfort	19900.00
0005434879011	3474	Comfort	19900.00
0005435126690	3474	Comfort	19900.00
0005434879043	3474	Comfort	19900.00
0005435126710	3474	Comfort	19900.00
0005435126709	3474	Comfort	19900.00
0005435902647	3474	Comfort	19900.00
0005434879044	3474	Comfort	19900.00
0005434879002	3474	Comfort	19900.00
0005435626336	3474	Comfort	19900.00
0005432611743	3474	Comfort	19900.00
0005434879023	3474	Comfort	19900.00
0005434879005	3474	Comfort	19900.00
0005435126699	3474	Comfort	19900.00
0005434938299	3474	Comfort	19900.00
0005435126720	3474	Comfort	19900.00
0005432799679	3474	Comfort	19900.00
0005434878979	3474	Comfort	19900.00
0005432799699	3474	Comfort	19900.00
0005435126707	3474	Comfort	19900.00
0005434879006	3474	Comfort	19900.00
0005435902716	3474	Comfort	19900.00
0005435126729	3474	Comfort	19900.00
0005434426857	3474	Comfort	19900.00
0005434878992	3474	Comfort	19900.00
0005434878990	3474	Economy	11700.00
0005435902688	3474	Economy	11700.00
0005434879019	3474	Economy	11700.00
0005434426860	3474	Economy	11700.00
0005434879042	3474	Economy	11700.00
0005435126711	3474	Economy	11700.00
0005435626322	3474	Economy	11700.00
0005432799696	3474	Economy	11700.00
0005434426861	3474	Economy	11700.00
0005434879029	3474	Economy	11700.00
0005434879038	3474	Economy	11700.00
0005434426863	3474	Economy	11700.00
0005434879015	3474	Economy	11700.00
0005435126715	3474	Economy	11700.00
0005432611748	3474	Economy	11700.00
0005434878980	3474	Economy	11700.00
0005432799697	3474	Economy	11700.00
0005435126706	3474	Economy	11700.00
0005435126698	3474	Economy	11700.00
0005432799702	3474	Economy	11700.00
0005432611745	3474	Economy	11700.00
0005434879007	3474	Economy	11700.00
0005432799676	3474	Economy	11700.00
0005435126700	3474	Economy	11700.00
0005434426869	3474	Economy	11700.00
0005434938308	3474	Economy	11700.00
0005432799685	3474	Economy	11700.00
0005434426842	3474	Economy	11700.00
0005434879051	3474	Economy	11700.00
0005435126689	3474	Economy	11700.00
0005434879024	3474	Economy	11700.00
0005435126692	3474	Economy	11700.00
0005434878997	3474	Economy	11700.00
0005432183484	3474	Economy	11700.00
0005435126731	3474	Economy	11700.00
0005432799692	3474	Economy	11700.00
0005434878966	3474	Economy	11700.00
0005434878998	3474	Economy	11700.00
0005434426851	3474	Economy	11700.00
0005432611744	3474	Economy	11700.00
0005434879022	3474	Economy	11700.00
0005434426838	3474	Economy	11700.00
0005435913924	3474	Economy	11700.00
0005432799694	3474	Economy	11700.00
0005435126702	3474	Economy	11700.00
0005434879045	3474	Economy	11700.00
0005434879041	3474	Economy	11700.00
0005434879014	3474	Economy	11700.00
0005434938307	3474	Economy	11700.00
0005434879032	3474	Economy	11700.00
0005432611742	3474	Economy	11700.00
0005434878988	3474	Economy	11700.00
0005434879036	3474	Economy	11700.00
0005435626316	3474	Economy	11700.00
0005432799704	3474	Economy	12800.00
0005435626325	3474	Economy	11700.00
0005434938302	3474	Economy	12800.00
0005434938303	3474	Economy	12800.00
0005435902731	3474	Economy	11700.00
0005434938306	3474	Economy	11700.00
0005432799678	3474	Economy	11700.00
0005434878962	3474	Economy	12800.00
0005432799703	3474	Economy	11700.00
0005432613895	3474	Economy	11700.00
0005435626338	3474	Economy	11700.00
0005434426867	3474	Economy	11700.00
0005434879047	3474	Economy	11700.00
0005435626339	3474	Economy	11700.00
0005434938304	3474	Economy	11700.00
0005432799701	3474	Economy	11700.00
0005435626328	3474	Economy	11700.00
0005434878969	3474	Economy	11700.00
0005434878981	3474	Economy	11700.00
0005435126696	3474	Economy	11700.00
0005435126695	3474	Economy	11700.00
0005434938298	3474	Economy	11700.00
0005435126723	3474	Economy	11700.00
0005435902714	3474	Economy	11700.00
0005434426856	3474	Economy	11700.00
0005434878986	3474	Economy	11700.00
0005432188634	3474	Economy	11700.00
0005434938311	3474	Economy	11700.00
0005435913929	3474	Economy	11700.00
0005434426850	3474	Economy	11700.00
0005432799700	3474	Economy	11700.00
0005434878985	3474	Economy	11700.00
0005432188636	3474	Economy	11700.00
0005435626333	3474	Economy	11700.00
0005434879001	3474	Economy	11700.00
0005434426839	3474	Economy	11700.00
0005434878972	3474	Economy	11700.00
0005435126697	3474	Economy	11700.00
0005434426864	3474	Economy	11700.00
0005434879028	3474	Economy	11700.00
0005432611747	3474	Economy	11700.00
0005434879039	3474	Economy	11700.00
0005434938300	3474	Economy	11700.00
0005434879049	3474	Economy	11700.00
0005434878976	3474	Economy	11700.00
0005432799688	3474	Economy	11700.00
0005434426865	3474	Economy	11700.00
0005435126725	3474	Economy	11700.00
0005434879030	3474	Economy	11700.00
0005435126728	3474	Economy	11700.00
0005434938309	3474	Economy	11700.00
0005434879052	3474	Economy	11700.00
0005434879048	3474	Economy	11700.00
0005434878971	3474	Economy	11700.00
0005435902781	3474	Economy	11700.00
0005434878989	3474	Economy	11700.00
0005434879018	3474	Economy	11700.00
0005434426866	3474	Economy	11700.00
0005434426846	3474	Economy	11700.00
0005432799687	3474	Economy	11700.00
0005434938301	3474	Economy	11700.00
0005434879009	3474	Economy	11700.00
0005434878994	3474	Economy	11700.00
0005435126713	3474	Economy	11700.00
0005434426844	3474	Economy	11700.00
0005434879050	3474	Economy	11700.00
0005435902696	3474	Economy	11700.00
0005432611746	3474	Economy	11700.00
0005434426852	3474	Economy	11700.00
0005434426862	3474	Economy	11700.00
0005435126716	3474	Economy	11700.00
0005434878970	3474	Economy	11700.00
0005434879053	3474	Economy	11700.00
0005432613897	3474	Economy	11700.00
0005434878973	3474	Economy	11700.00
0005434878961	3474	Economy	11700.00
0005434878958	3474	Economy	11700.00
0005434938293	3474	Economy	11700.00
0005432799695	3474	Economy	11700.00
0005435126730	3474	Economy	11700.00
0005435626331	3474	Economy	11700.00
0005434426858	3474	Economy	11700.00
0005434879027	3474	Economy	11700.00
0005435126708	3474	Economy	11700.00
0005434878959	3474	Economy	11700.00
0005434426849	3474	Economy	11700.00
0005434878987	3474	Economy	11700.00
0005434879040	3474	Economy	11700.00
0005435902730	3474	Economy	12800.00
0005435913922	3474	Economy	12800.00
0005435626327	3474	Economy	12800.00
0005435126714	3474	Economy	12800.00
0005434879003	3474	Economy	12800.00
0005434879012	3474	Economy	12800.00
0005434879054	3474	Economy	11700.00
0005432799689	3474	Economy	11700.00
0005434878960	3474	Economy	11700.00
0005432183485	3474	Economy	11700.00
0005434426854	3474	Economy	11700.00
0005434878967	3474	Economy	11700.00
0005432799691	3474	Economy	11700.00
0005434879025	3474	Economy	11700.00
0005435126727	3474	Economy	11700.00
0005435126719	3474	Economy	11700.00
0005434426855	3474	Economy	11700.00
0005434426847	3474	Economy	11700.00
0005435126717	3474	Economy	11700.00
0005434879034	3474	Economy	11700.00
0005434426853	3474	Economy	11700.00
0005434879017	3474	Economy	11700.00
0005435626330	3474	Economy	11700.00
0005435126704	3474	Economy	11700.00
0005434938313	3474	Economy	11700.00
0005432799693	3474	Economy	11700.00
0005434426848	3474	Economy	11700.00
0005435626324	3474	Economy	11700.00
0005435626321	3474	Economy	11700.00
0005432799705	3474	Economy	11700.00
0005432799698	3474	Economy	11700.00
0005432799706	3474	Economy	11700.00
0005435626337	3474	Economy	11700.00
0005434426840	3474	Economy	11700.00
0005434878993	3474	Economy	11700.00
0005435902738	3474	Economy	11700.00
0005435902733	3474	Economy	11700.00
0005434426843	3474	Economy	11700.00
0005434879013	3474	Economy	11700.00
0005434938310	3474	Economy	11700.00
0005434878982	3474	Economy	11700.00
0005434426845	3474	Economy	11700.00
0005434879004	3474	Economy	11700.00
0005435126722	3474	Economy	11700.00
0005434879000	3474	Economy	11700.00
0005432799684	3474	Economy	11700.00
0005435126688	3474	Economy	11700.00
0005434938305	3474	Economy	11700.00
0005434426859	3474	Economy	11700.00
0005432799683	3474	Economy	11700.00
0005435126703	3474	Economy	11700.00
0005432188633	3474	Economy	11700.00
0005434878995	3474	Economy	11700.00
0005434878965	3474	Economy	11700.00
0005432799686	3474	Economy	11700.00
0005432799677	3474	Economy	11700.00
0005434878999	3474	Economy	11700.00
0005434879033	3474	Economy	11700.00
0005434879035	3474	Economy	11700.00
0005435126701	3474	Economy	11700.00
0005434879046	3474	Economy	11700.00
0005434426868	3474	Economy	11700.00
0005434938296	3474	Economy	11700.00
0005434878975	3474	Economy	11700.00
0005434878983	3474	Economy	11700.00
0005434879008	3474	Economy	11700.00
0005435126721	3474	Economy	11700.00
0005434879037	3474	Economy	11700.00
0005434878978	3474	Economy	11700.00
0005434878984	3474	Economy	11700.00
0005432799681	3474	Economy	11700.00
0005432799682	3474	Economy	11700.00
0005434878963	3474	Economy	11700.00
0005434879010	3474	Economy	11700.00
0005435126691	3474	Economy	11700.00
0005435126726	3474	Economy	11700.00
0005434879020	3474	Economy	11700.00
0005435126693	3474	Economy	11700.00
0005434878968	3474	Economy	11700.00
0005434878974	3474	Economy	11700.00
0005434938294	3474	Economy	11700.00
0005435626335	3474	Economy	11700.00
0005435626332	3474	Economy	11700.00
0005434879026	3474	Economy	11700.00
0005432613896	3474	Economy	11700.00
0005434878996	3474	Economy	11700.00
0005435126694	3474	Economy	11700.00
0005435902707	3474	Economy	11700.00
0005435902715	3474	Economy	11700.00
0005435626334	3474	Economy	11700.00
0005435126712	3474	Economy	11700.00
0005432613894	3474	Economy	11700.00
0005434426537	14537	Business	35000.00
0005435842331	14537	Business	35000.00
0005435126312	14537	Business	35000.00
0005434878048	14537	Business	35000.00
0005435902848	14537	Business	35000.00
0005435126434	14537	Business	35000.00
0005434878201	14537	Business	35000.00
0005434877901	14537	Business	35000.00
0005435126293	14537	Business	35000.00
0005432611722	14537	Business	35000.00
0005434938216	14537	Business	35000.00
0005435126360	14537	Business	35000.00
0005435126330	14537	Business	35000.00
0005432799475	14537	Business	35000.00
0005434938209	14537	Business	35000.00
0005434878352	14537	Business	35000.00
0005435126231	14537	Business	35000.00
0005434426535	14537	Business	35000.00
0005435126247	14537	Comfort	19900.00
0005435126151	14537	Comfort	19900.00
0005434938212	14537	Comfort	19900.00
0005435126277	14537	Comfort	19900.00
0005434426562	14537	Comfort	19900.00
0005435126431	14537	Comfort	19900.00
0005435126370	14537	Comfort	19900.00
0005435902850	14537	Comfort	19900.00
0005434938162	14537	Comfort	19900.00
0005435126292	14537	Comfort	19900.00
0005435126246	14537	Comfort	19900.00
0005434426453	14537	Comfort	19900.00
0005434878123	14537	Comfort	19900.00
0005435126223	14537	Comfort	19900.00
0005434878012	14537	Comfort	19900.00
0005434877753	14537	Comfort	19900.00
0005434878284	14537	Comfort	19900.00
0005435126414	14537	Comfort	19900.00
0005435902842	14537	Comfort	19900.00
0005434878346	14537	Comfort	19900.00
0005435126254	14537	Comfort	19900.00
0005432799386	14537	Comfort	19900.00
0005434426612	14537	Comfort	19900.00
0005435126241	14537	Comfort	19900.00
0005435913955	14537	Comfort	19900.00
0005435626120	14537	Comfort	19900.00
0005434878212	14537	Comfort	19900.00
0005435914701	14537	Comfort	19900.00
0005434878168	14537	Comfort	19900.00
0005434938126	14537	Comfort	19900.00
0005434878343	14537	Comfort	19900.00
0005432799358	14537	Comfort	19900.00
0005435626141	14537	Comfort	19900.00
0005432799463	14537	Comfort	19900.00
0005435913958	14537	Comfort	19900.00
0005432799460	14537	Economy	11700.00
0005435626071	14537	Economy	11700.00
0005435126249	14537	Economy	11700.00
0005434877699	14537	Economy	11700.00
0005435902855	14537	Economy	11700.00
0005434938079	14537	Economy	11700.00
0005435126369	14537	Economy	11700.00
0005434878188	14537	Economy	11700.00
0005434878187	14537	Economy	11700.00
0005434878032	14537	Economy	11700.00
0005434878472	14537	Economy	11700.00
0005434878620	14537	Economy	11700.00
0005434426451	14537	Economy	11700.00
0005435126307	14537	Economy	11700.00
0005434426452	14537	Economy	11700.00
0005435841828	14537	Economy	11700.00
0005434878110	14537	Economy	11700.00
0005434877818	14537	Economy	11700.00
0005434878164	14537	Economy	11700.00
0005435126189	14537	Economy	11700.00
0005435126420	14537	Economy	11700.00
0005435126265	14537	Economy	11700.00
0005434426579	14537	Economy	11700.00
0005434938150	14537	Economy	11700.00
0005434938131	14537	Economy	11700.00
0005434426601	14537	Economy	11700.00
0005434878469	14537	Economy	11700.00
0005435626142	14537	Economy	11700.00
0005435902854	14537	Economy	11700.00
0005434878092	14537	Economy	11700.00
0005434878031	14537	Economy	11700.00
0005434877807	14537	Economy	11700.00
0005435126415	14537	Economy	11700.00
0005434878100	14537	Economy	11700.00
0005434878207	14537	Economy	11700.00
0005435126255	14537	Economy	11700.00
0005434877880	14537	Economy	11700.00
0005434877806	14537	Economy	11700.00
0005434878224	14537	Economy	11700.00
0005434877952	14537	Economy	11700.00
0005435626077	14537	Economy	11700.00
0005434878492	14537	Economy	11700.00
0005434877817	14537	Economy	12800.00
0005434938149	14537	Economy	12800.00
0005434878416	14537	Economy	11700.00
0005435126097	14537	Economy	11700.00
0005434878371	14537	Economy	11700.00
0005435126212	14537	Economy	12800.00
0005434426688	14537	Economy	12800.00
0005434938125	14537	Economy	12800.00
0005435126215	14537	Economy	11700.00
0005435626140	14537	Economy	11700.00
0005434878452	14537	Economy	11700.00
0005432799461	14537	Economy	11700.00
0005434878293	14537	Economy	11700.00
0005435626138	14537	Economy	11700.00
0005432799468	14537	Economy	11700.00
0005432799464	14537	Economy	11700.00
0005434426602	14537	Economy	11700.00
0005435126096	14537	Economy	11700.00
0005434877752	14537	Economy	11700.00
0005435626139	14537	Economy	11700.00
0005435126214	14537	Economy	11700.00
0005432799552	14537	Economy	11700.00
0005434877898	14537	Economy	11700.00
0005435902851	14537	Economy	11700.00
0005435126313	14537	Economy	11700.00
0005434878278	14537	Economy	11700.00
0005434938154	14537	Economy	11700.00
0005434878262	14537	Economy	11700.00
0005435126245	14537	Economy	11700.00
0005435626134	14537	Economy	11700.00
0005435902841	14537	Economy	11700.00
0005434878350	14537	Economy	11700.00
0005434426712	14537	Economy	11700.00
0005432799578	14537	Economy	11700.00
0005434878261	14537	Economy	11700.00
0005435126278	14537	Economy	11700.00
0005435126168	14537	Economy	11700.00
0005435126232	14537	Economy	11700.00
0005434426454	14537	Economy	11700.00
0005435626119	14537	Economy	11700.00
0005434877995	14537	Economy	11700.00
0005432799503	14537	Economy	11700.00
0005434878331	14537	Economy	11700.00
0005434878291	14537	Economy	11700.00
0005434426666	14537	Economy	11700.00
0005434878380	14537	Economy	11700.00
0005434426721	14537	Economy	11700.00
0005435626135	14537	Economy	11700.00
0005434938188	14537	Economy	11700.00
0005434878073	14537	Economy	11700.00
0005434426687	14537	Economy	11700.00
0005434426760	14537	Economy	11700.00
0005434878008	14537	Economy	11700.00
0005435626122	14537	Economy	11700.00
0005435626121	14537	Economy	11700.00
0005432059520	14537	Economy	11700.00
0005432799398	14537	Economy	11700.00
0005432799372	14537	Economy	11700.00
0005435626132	14537	Economy	11700.00
0005434938151	14537	Economy	11700.00
0005434878049	14537	Economy	11700.00
0005434938174	14537	Economy	11700.00
0005434878079	14537	Economy	11700.00
0005434938248	14537	Economy	11700.00
0005432611719	14537	Economy	11700.00
0005434878074	14537	Economy	11700.00
0005434878301	14537	Economy	11700.00
0005434878410	14537	Economy	11700.00
0005434878661	14537	Economy	11700.00
0005432799516	14537	Economy	11700.00
0005434878647	14537	Economy	11700.00
0005435902846	14537	Economy	11700.00
0005434878128	14537	Economy	11700.00
0005432799449	14537	Economy	11700.00
0005435126266	14537	Economy	11700.00
0005434426580	14537	Economy	11700.00
0005432799497	14537	Economy	11700.00
0005435126379	14537	Economy	11700.00
0005432059521	14537	Economy	11700.00
0005434938110	14537	Economy	11700.00
0005432799453	14537	Economy	11700.00
0005434426536	14537	Economy	11700.00
0005434878473	14537	Economy	12800.00
0005434878646	14537	Economy	12800.00
0005434878269	14537	Economy	12800.00
0005434938153	14537	Economy	12800.00
0005435841827	14537	Economy	11700.00
0005432799577	14537	Economy	11700.00
0005434878270	14537	Economy	11700.00
0005434878486	14537	Economy	11700.00
0005434938130	14537	Economy	11700.00
0005435913956	14537	Economy	11700.00
0005432799502	14537	Economy	11700.00
0005434878471	14537	Economy	11700.00
0005435913960	14537	Economy	11700.00
0005434938158	14537	Economy	11700.00
0005434426534	14537	Economy	11700.00
0005434426707	14537	Economy	11700.00
0005434426509	14537	Economy	11700.00
0005435626157	14537	Economy	11700.00
0005434426408	14537	Economy	11700.00
0005434426600	14537	Economy	11700.00
0005435126393	14537	Economy	11700.00
0005435126294	14537	Economy	11700.00
0005434938163	14537	Economy	11700.00
0005435126341	14537	Economy	11700.00
0005435902853	14537	Economy	11700.00
0005435902849	14537	Economy	11700.00
0005435126437	14537	Economy	11700.00
0005432799402	14537	Economy	11700.00
0005432799492	14537	Economy	11700.00
0005434878351	14537	Economy	11700.00
0005435126213	14537	Economy	11700.00
0005435902844	14537	Economy	11700.00
0005434878379	14537	Economy	11700.00
0005435902843	14537	Economy	11700.00
0005432799418	14537	Economy	11700.00
0005432799500	14537	Economy	11700.00
0005432607562	14537	Economy	11700.00
0005435126250	14537	Economy	11700.00
0005435126469	14537	Economy	11700.00
0005435626158	14537	Economy	11700.00
0005435126267	14537	Economy	11700.00
0005435126327	14537	Economy	11700.00
0005435626078	14537	Economy	11700.00
0005434878218	14537	Economy	11700.00
0005434878217	14537	Economy	11700.00
0005435913959	14537	Economy	11700.00
0005434878240	14537	Economy	11700.00
0005434878245	14537	Economy	11700.00
0005435126242	14537	Economy	11700.00
0005435902856	14537	Economy	11700.00
0005435126240	14537	Economy	11700.00
0005434878304	14537	Economy	11700.00
0005434878650	14537	Economy	11700.00
0005435126244	14537	Economy	11700.00
0005434878080	14537	Economy	11700.00
0005432799397	14537	Economy	11700.00
0005434878200	14537	Economy	11700.00
0005435126188	14537	Economy	11700.00
0005435126339	14537	Economy	11700.00
0005432611720	14537	Economy	11700.00
0005434426476	14537	Economy	11700.00
0005435626131	14537	Economy	11700.00
0005432799371	14537	Economy	11700.00
0005434878054	14537	Economy	11700.00
0005432607580	14537	Economy	11700.00
0005435126290	14537	Economy	11700.00
0005435913957	14537	Economy	11700.00
0005435902845	14537	Economy	11700.00
0005434878402	14537	Economy	11700.00
0005434878147	14537	Economy	11700.00
0005432799522	14537	Economy	11700.00
0005435902852	14537	Economy	11700.00
0005434877866	14537	Economy	11700.00
0005435913961	14537	Economy	11700.00
0005435626076	14537	Economy	11700.00
0005435126517	14537	Economy	11700.00
0005434878216	14537	Economy	11700.00
0005435902847	14537	Economy	11700.00
0005435902857	14537	Economy	11700.00
0005434426471	14537	Economy	11700.00
0005434325743	3639	Economy	16300.00
0005434325744	3639	Economy	14800.00
0005435889925	3639	Economy	14800.00
0005435889926	3639	Economy	14800.00
0005434325746	3639	Economy	14800.00
0005435889896	3639	Economy	14800.00
0005434325740	3639	Economy	14800.00
0005434325747	3639	Economy	14800.00
0005434325742	3639	Economy	14800.00
0005434312337	3639	Economy	14800.00
0005434325745	3639	Economy	14800.00
0005434325750	3639	Economy	14800.00
0005434325752	3639	Economy	14800.00
0005434325741	3639	Economy	14800.00
0005434325751	3639	Economy	14800.00
0005434325748	3639	Economy	14800.00
0005434312336	3639	Economy	14800.00
0005434325749	3639	Economy	14800.00
0005435889894	3639	Economy	14800.00
0005434325739	3639	Economy	14800.00
0005435889946	15617	Economy	14800.00
0005435889949	15617	Economy	14800.00
0005434325638	15617	Economy	14800.00
0005434325695	15617	Economy	14800.00
0005434325636	15617	Economy	14800.00
0005434325694	15617	Economy	14800.00
0005434325599	15617	Economy	14800.00
0005434325637	15617	Economy	14800.00
0005435889945	15617	Economy	14800.00
0005434325687	15617	Economy	14800.00
0005434325667	15617	Economy	14800.00
0005435889948	15617	Economy	14800.00
0005435889943	15617	Economy	14800.00
0005434325661	15617	Economy	14800.00
0005435889944	15617	Economy	14800.00
0005435889947	15617	Economy	14800.00
0005435957818	619	Economy	4500.00
0005433420390	619	Economy	4500.00
0005435957819	619	Economy	4500.00
0005433420395	619	Economy	4100.00
0005435957824	619	Economy	4100.00
0005435957823	619	Economy	4100.00
0005435957831	619	Economy	4100.00
0005435957822	619	Economy	4100.00
0005433420415	619	Economy	4100.00
0005433420402	619	Economy	4100.00
0005433420393	619	Economy	4100.00
0005433420394	619	Economy	4100.00
0005435957828	619	Economy	4100.00
0005435957827	619	Economy	4100.00
0005433420416	619	Economy	4100.00
0005435957821	619	Economy	4100.00
0005435957820	619	Economy	4100.00
0005435957829	619	Economy	4100.00
0005435957825	619	Economy	4100.00
0005435957830	619	Economy	4100.00
0005435957817	619	Economy	4100.00
0005433420392	619	Economy	4100.00
0005433420385	619	Economy	4100.00
0005435957826	619	Economy	4100.00
0005433420396	619	Economy	4100.00
0005433420391	619	Economy	4100.00
0005433420472	15153	Economy	4500.00
0005435957633	15153	Economy	4500.00
0005435957719	15153	Economy	4500.00
0005435957688	15153	Economy	4500.00
0005433420477	15153	Economy	4100.00
0005435957678	15153	Economy	4100.00
0005435957750	15153	Economy	4100.00
0005435957708	15153	Economy	4100.00
0005433420473	15153	Economy	4100.00
0005435957679	15153	Economy	4100.00
0005435957709	15153	Economy	4100.00
0005433420469	15153	Economy	4100.00
0005435957713	15153	Economy	4100.00
0005435957651	15153	Economy	4100.00
0005435957632	15153	Economy	4100.00
0005435957707	15153	Economy	4100.00
0005433420471	15153	Economy	4100.00
0005435957680	15153	Economy	4100.00
0005433420476	15153	Economy	4100.00
0005433420470	15153	Economy	4100.00
0005435957710	15153	Economy	4100.00
0005433420475	15153	Economy	4100.00
0005435957677	15153	Economy	4100.00
0005435957673	15153	Economy	4100.00
0005435957718	15153	Economy	4100.00
0005433420474	15153	Economy	4100.00
0005435219193	27271	Economy	28100.00
0005435219202	27271	Economy	28100.00
0005435216579	27271	Economy	25500.00
0005435221051	27271	Economy	25500.00
0005435221052	27271	Economy	25500.00
0005435219204	27271	Economy	25500.00
0005435221050	27271	Economy	25500.00
0005435219201	27271	Economy	25500.00
0005435219181	27271	Economy	25500.00
0005435219203	27271	Economy	25500.00
0005435216573	27271	Economy	25500.00
0005435219187	27271	Economy	25500.00
0005435221054	27271	Economy	25500.00
0005435219196	27271	Economy	25500.00
0005435216578	27271	Economy	25500.00
0005435216572	27271	Economy	25500.00
0005435629414	8872	Economy	10400.00
0005434247150	8872	Economy	10400.00
0005434247149	8872	Economy	10400.00
0005435629413	8872	Economy	10400.00
0005434247148	8872	Economy	10400.00
0005434247170	16054	Economy	10400.00
0005434247168	16054	Economy	10400.00
0005434247169	16054	Economy	10400.00
0005434247171	16054	Economy	10400.00
0005435933459	4435	Economy	13400.00
0005435163271	4435	Economy	12200.00
0005435933457	4435	Economy	12200.00
0005435163277	4435	Economy	12200.00
0005435163273	4435	Economy	12200.00
0005435163272	4435	Economy	12200.00
0005435163270	4435	Economy	12200.00
0005435163268	4435	Economy	12200.00
0005435933448	4435	Economy	12200.00
0005435933470	4435	Economy	12200.00
0005435933463	4435	Economy	12200.00
0005435933458	4435	Economy	12200.00
0005435163269	4435	Economy	12200.00
0005435163274	4435	Economy	12200.00
0005435163275	4435	Economy	12200.00
0005435163278	4435	Economy	12200.00
0005435163276	4435	Economy	12200.00
0005435933456	4435	Economy	12200.00
0005435797595	2840	Business	12600.00
0005433404821	2840	Business	12600.00
0005433404832	2840	Business	12600.00
0005435797584	2840	Economy	4200.00
0005433404800	2840	Economy	4200.00
0005435797591	2840	Economy	4600.00
0005433404814	2840	Economy	4200.00
0005433404826	2840	Economy	4200.00
0005435797586	2840	Economy	4200.00
0005433404813	2840	Economy	4200.00
0005435797593	2840	Economy	4200.00
0005433404801	2840	Economy	4200.00
0005433404822	2840	Economy	4200.00
0005435797587	2840	Economy	4200.00
0005435797585	2840	Economy	4200.00
0005435797589	2840	Economy	4200.00
0005435797596	2840	Economy	4200.00
0005435797594	2840	Economy	4200.00
0005433404764	2840	Economy	4200.00
0005435797597	2840	Economy	4200.00
0005433404763	2840	Economy	4200.00
0005433404795	2840	Economy	4200.00
0005435797588	2840	Economy	4200.00
0005435797590	2840	Economy	4200.00
0005435797592	2840	Economy	4200.00
0005435797468	29348	Business	12600.00
0005435797465	29348	Economy	4200.00
0005433404869	29348	Economy	4200.00
0005435797533	29348	Economy	4200.00
0005435797496	29348	Economy	4600.00
0005435797464	29348	Economy	4200.00
0005435797532	29348	Economy	4200.00
0005435797534	29348	Economy	4200.00
0005433404872	29348	Economy	4200.00
0005433404868	29348	Economy	4200.00
0005435797457	29348	Economy	4200.00
0005435797489	29348	Economy	4200.00
0005435797466	29348	Economy	4200.00
0005433404873	29348	Economy	4200.00
0005435797531	29348	Economy	4200.00
0005435797488	29348	Economy	4200.00
0005433404871	29348	Economy	4200.00
0005435797493	29348	Economy	4200.00
0005433404867	29348	Economy	4200.00
0005433404874	29348	Economy	4200.00
0005433404870	29348	Economy	4200.00
0005434948087	5817	Economy	6800.00
0005434948090	5817	Economy	6800.00
0005434948084	5817	Economy	6800.00
0005434948085	5817	Economy	6800.00
0005434948086	5817	Economy	6800.00
0005434948093	5817	Economy	6800.00
0005434948088	5817	Economy	6800.00
0005434948091	5817	Economy	6800.00
0005434948092	5817	Economy	6800.00
0005434948089	5817	Economy	6800.00
0005434948024	16324	Economy	6800.00
0005434948019	16324	Economy	6800.00
0005434948049	16324	Economy	6800.00
0005434948044	16324	Economy	6800.00
0005434948025	16324	Economy	6800.00
0005434948002	16324	Economy	6800.00
0005434948036	16324	Economy	6800.00
0005434947971	16324	Economy	6800.00
0005434948006	16324	Economy	6800.00
0005434948043	16324	Economy	6800.00
0005434948037	16324	Economy	6800.00
0005433961382	6885	Business	21400.00
0005433961361	6885	Business	21400.00
0005433961355	6885	Business	21400.00
0005433961360	6885	Business	21400.00
0005433961333	6885	Business	21400.00
0005433961356	6885	Economy	7100.00
0005433961335	6885	Economy	7100.00
0005433961380	6885	Economy	7100.00
0005433961364	6885	Economy	7100.00
0005433961352	6885	Economy	7800.00
0005433961337	6885	Economy	7800.00
0005433961353	6885	Economy	7800.00
0005433961373	6885	Economy	7100.00
0005433961366	6885	Economy	7100.00
0005433961346	6885	Economy	7100.00
0005433961357	6885	Economy	7100.00
0005433961363	6885	Economy	7100.00
0005433961371	6885	Economy	7100.00
0005433961368	6885	Economy	7100.00
0005433961367	6885	Economy	7100.00
0005433961378	6885	Economy	7100.00
0005433961384	6885	Economy	7100.00
0005433961347	6885	Economy	7100.00
0005433961348	6885	Economy	7100.00
0005433961345	6885	Economy	7100.00
0005433961354	6885	Economy	7100.00
0005433961341	6885	Economy	7100.00
0005433961383	6885	Economy	7100.00
0005433961359	6885	Economy	7100.00
0005433961358	6885	Economy	7100.00
0005433961330	6885	Economy	7100.00
0005433961350	6885	Economy	7100.00
0005433961372	6885	Economy	7100.00
0005433961379	6885	Economy	7100.00
0005433961336	6885	Economy	7100.00
0005433961377	6885	Economy	7100.00
0005433961329	6885	Economy	7100.00
0005433961370	6885	Economy	7100.00
0005433961351	6885	Economy	7100.00
0005433961334	6885	Economy	7100.00
0005433961344	6885	Economy	7100.00
0005433961340	6885	Economy	7100.00
0005433961369	6885	Economy	7100.00
0005433961338	6885	Economy	7100.00
0005433961376	6885	Economy	7100.00
0005433961374	6885	Economy	7100.00
0005433961331	6885	Economy	7100.00
0005433961362	6885	Economy	7100.00
0005433961342	6885	Economy	7100.00
0005433961332	6885	Economy	7100.00
0005433961375	6885	Economy	7100.00
0005433961349	6885	Economy	7100.00
0005433961381	6885	Economy	7100.00
0005433961339	6885	Economy	7100.00
0005433961343	6885	Economy	7100.00
0005433961365	6885	Economy	7100.00
0005433960758	25695	Business	21400.00
0005433960628	25695	Business	21400.00
0005433960570	25695	Business	21400.00
0005433960629	25695	Business	21400.00
0005433960560	25695	Business	21400.00
0005433960604	25695	Business	21400.00
0005433960661	25695	Business	21400.00
0005433960502	25695	Economy	7100.00
0005433960779	25695	Economy	7100.00
0005433960725	25695	Economy	7100.00
0005433960743	25695	Economy	7100.00
0005433960679	25695	Economy	7100.00
0005433960623	25695	Economy	7800.00
0005433960744	25695	Economy	7800.00
0005433960473	25695	Economy	7100.00
0005433960618	25695	Economy	7100.00
0005433960660	25695	Economy	7100.00
0005433960790	25695	Economy	7100.00
0005433960596	25695	Economy	7100.00
0005433960663	25695	Economy	7100.00
0005433960780	25695	Economy	7100.00
0005433960641	25695	Economy	7100.00
0005433960773	25695	Economy	7100.00
0005433960706	25695	Economy	7100.00
0005433960410	25695	Economy	7100.00
0005433960474	25695	Economy	7100.00
0005433960595	25695	Economy	7100.00
0005433960774	25695	Economy	7100.00
0005433960658	25695	Economy	7100.00
0005433960707	25695	Economy	7100.00
0005433960678	25695	Economy	7100.00
0005433960561	25695	Economy	7100.00
0005433960762	25695	Economy	7100.00
0005433960675	25695	Economy	7100.00
0005433960619	25695	Economy	7100.00
0005433960488	25695	Economy	7100.00
0005433960785	25695	Economy	7100.00
0005433960519	25695	Economy	7100.00
0005433960635	25695	Economy	7100.00
0005433960676	25695	Economy	7100.00
0005433960709	25695	Economy	7100.00
0005433960680	25695	Economy	7100.00
0005433960789	25695	Economy	7100.00
0005433960708	25695	Economy	7100.00
0005433960622	25695	Economy	7100.00
0005433960564	25695	Economy	7100.00
0005433960620	25695	Economy	7100.00
0005433960621	25695	Economy	7100.00
0005433960569	25695	Economy	7100.00
0005433960659	25695	Economy	7100.00
0005433960562	25695	Economy	7100.00
0005433960786	25695	Economy	7100.00
0005435082743	24531	Economy	3900.00
0005435082766	24531	Economy	3900.00
0005435082776	24531	Economy	3900.00
0005435082746	24531	Economy	3900.00
0005435082741	24531	Economy	3900.00
0005435082767	24531	Economy	3900.00
0005435082745	24531	Economy	3900.00
0005435082764	24531	Economy	3900.00
0005435082850	26055	Economy	3900.00
0005435082847	26055	Economy	3900.00
0005435082849	26055	Economy	3900.00
0005435082846	26055	Economy	3900.00
0005435082845	26055	Economy	3900.00
0005435082842	26055	Economy	3900.00
0005435082848	26055	Economy	3900.00
0005435082844	26055	Economy	3900.00
0005435082841	26055	Economy	3900.00
0005435082843	26055	Economy	3900.00
0005434245235	5159	Business	18000.00
0005434245209	5159	Business	18000.00
0005434245212	5159	Business	18000.00
0005434245208	5159	Business	18000.00
0005434245222	5159	Economy	6600.00
0005434245221	5159	Economy	6600.00
0005434245231	5159	Economy	6600.00
0005434245232	5159	Economy	6600.00
0005434245213	5159	Economy	6000.00
0005434245237	5159	Economy	6000.00
0005434245233	5159	Economy	6000.00
0005432166929	5159	Economy	6000.00
0005435286626	5159	Economy	6000.00
0005432166928	5159	Economy	6000.00
0005434245216	5159	Economy	6000.00
0005434245218	5159	Economy	6000.00
0005434245236	5159	Economy	6000.00
0005435286631	5159	Economy	6000.00
0005434245217	5159	Economy	6000.00
0005434245229	5159	Economy	6000.00
0005434245230	5159	Economy	6000.00
0005434245214	5159	Economy	6600.00
0005434245219	5159	Economy	6000.00
0005434245234	5159	Economy	6000.00
0005435286619	5159	Economy	6000.00
0005434245224	5159	Economy	6000.00
0005434245223	5159	Economy	6000.00
0005433534502	5159	Economy	6000.00
0005434245228	5159	Economy	6000.00
0005434245210	5159	Economy	6000.00
0005434245226	5159	Economy	6000.00
0005434245227	5159	Economy	6000.00
0005435286607	5159	Economy	6000.00
0005434245220	5159	Economy	6000.00
0005435286608	5159	Economy	6000.00
0005432166927	5159	Economy	6000.00
0005435286618	5159	Economy	6000.00
0005434245225	5159	Economy	6000.00
0005434245215	5159	Economy	6000.00
0005434245211	5159	Economy	6000.00
0005433615332	5160	Business	18000.00
0005433615317	5160	Business	18000.00
0005433785229	5160	Business	18000.00
0005432665291	5160	Business	18000.00
0005433615265	5160	Business	18000.00
0005433785245	5160	Business	18000.00
0005433615291	5160	Business	18000.00
0005432105962	5160	Business	18000.00
0005433785242	5160	Business	18000.00
0005433615276	5160	Business	18000.00
0005433615268	5160	Business	18000.00
0005433615293	5160	Business	18000.00
0005432105936	5160	Business	18000.00
0005432105954	5160	Business	18000.00
0005433615326	5160	Business	18000.00
0005433615273	5160	Business	18000.00
0005433785227	5160	Business	18000.00
0005432105972	5160	Business	18000.00
0005432105952	5160	Business	18000.00
0005432105953	5160	Business	18000.00
0005433615302	5160	Business	18000.00
0005432105946	5160	Business	18000.00
0005433615296	5160	Business	18000.00
0005433615266	5160	Business	18000.00
0005433785256	5160	Business	18000.00
0005433785253	5160	Business	18000.00
0005433615282	5160	Business	18000.00
0005432666407	5160	Business	18000.00
0005433615304	5160	Economy	6600.00
0005433785246	5160	Economy	6600.00
0005433615316	5160	Economy	6600.00
0005433615275	5160	Economy	6600.00
0005433615289	5160	Economy	6600.00
0005433615277	5160	Economy	6600.00
0005432667472	5160	Economy	6000.00
0005433615267	5160	Economy	6000.00
0005433615313	5160	Economy	6000.00
0005432105965	5160	Economy	6000.00
0005433785248	5160	Economy	6000.00
0005433615307	5160	Economy	6000.00
0005432105947	5160	Economy	6000.00
0005433785230	5160	Economy	6000.00
0005432105981	5160	Economy	6000.00
0005433615324	5160	Economy	6000.00
0005432105958	5160	Economy	6000.00
0005433615285	5160	Economy	6000.00
0005432105980	5160	Economy	6000.00
0005432105955	5160	Economy	6000.00
0005432105957	5160	Economy	6000.00
0005432145128	5160	Economy	6000.00
0005433615303	5160	Economy	6000.00
0005433615272	5160	Economy	6000.00
0005432145129	5160	Economy	6000.00
0005432105961	5160	Economy	6000.00
0005432105978	5160	Economy	6000.00
0005433615261	5160	Economy	6000.00
0005433615297	5160	Economy	6000.00
0005433615263	5160	Economy	6000.00
0005432105963	5160	Economy	6000.00
0005432105949	5160	Economy	6000.00
0005433615262	5160	Economy	6000.00
0005433615301	5160	Economy	6000.00
0005432105976	5160	Economy	6000.00
0005433785241	5160	Economy	6000.00
0005432105967	5160	Economy	6000.00
0005433615287	5160	Economy	6000.00
0005432105974	5160	Economy	6000.00
0005433785226	5160	Economy	6000.00
0005433615299	5160	Economy	6000.00
0005433615323	5160	Economy	6000.00
0005432105984	5160	Economy	6000.00
0005433785249	5160	Economy	6000.00
0005433615278	5160	Economy	6000.00
0005432666405	5160	Economy	6000.00
0005433615321	5160	Economy	6000.00
0005433615286	5160	Economy	6000.00
0005433615288	5160	Economy	6000.00
0005433615322	5160	Economy	6000.00
0005432105945	5160	Economy	6000.00
0005433785231	5160	Economy	6000.00
0005433785247	5160	Economy	6000.00
0005433615306	5160	Economy	6000.00
0005433615294	5160	Economy	6000.00
0005432667471	5160	Economy	6000.00
0005433615315	5160	Economy	6000.00
0005433785223	5160	Economy	6000.00
0005432105937	5160	Economy	6000.00
0005432105938	5160	Economy	6000.00
0005432105950	5160	Economy	6000.00
0005433785228	5160	Economy	6000.00
0005432105935	5160	Economy	6000.00
0005433615284	5160	Economy	6000.00
0005432105970	5160	Economy	6000.00
0005432105964	5160	Economy	6000.00
0005433615260	5160	Economy	6600.00
0005433615269	5160	Economy	6600.00
0005433615310	5160	Economy	6600.00
0005433615300	5160	Economy	6600.00
0005432665292	5160	Economy	6600.00
0005432105983	5160	Economy	6000.00
0005433785243	5160	Economy	6000.00
0005433615279	5160	Economy	6000.00
0005433615328	5160	Economy	6000.00
0005433785254	5160	Economy	6600.00
0005432145127	5160	Economy	6000.00
0005433785233	5160	Economy	6000.00
0005432105977	5160	Economy	6000.00
0005433785238	5160	Economy	6000.00
0005433615320	5160	Economy	6000.00
0005433785234	5160	Economy	6000.00
0005433615329	5160	Economy	6000.00
0005433615283	5160	Economy	6000.00
0005433785259	5160	Economy	6000.00
0005433615298	5160	Economy	6000.00
0005432105941	5160	Economy	6000.00
0005433785239	5160	Economy	6000.00
0005433785225	5160	Economy	6000.00
0005432105943	5160	Economy	6000.00
0005432105973	5160	Economy	6000.00
0005433615264	5160	Economy	6000.00
0005433785258	5160	Economy	6000.00
0005432105939	5160	Economy	6000.00
0005433615281	5160	Economy	6000.00
0005433615274	5160	Economy	6000.00
0005433785255	5160	Economy	6000.00
0005433615309	5160	Economy	6000.00
0005433615308	5160	Economy	6000.00
0005432105951	5160	Economy	6000.00
0005432105966	5160	Economy	6000.00
0005433615331	5160	Economy	6000.00
0005433615292	5160	Economy	6000.00
0005433615311	5160	Economy	6000.00
0005433615330	5160	Economy	6000.00
0005433615312	5160	Economy	6000.00
0005432105969	5160	Economy	6000.00
0005433785236	5160	Economy	6000.00
0005432105942	5160	Economy	6000.00
0005432105979	5160	Economy	6000.00
0005433615280	5160	Economy	6000.00
0005432666406	5160	Economy	6000.00
0005433615305	5160	Economy	6000.00
0005433785224	5160	Economy	6000.00
0005433785244	5160	Economy	6000.00
0005433615318	5160	Economy	6000.00
0005433615271	5160	Economy	6000.00
0005432105975	5160	Economy	6000.00
0005433785235	5160	Economy	6000.00
0005433785251	5160	Economy	6000.00
0005432105960	5160	Economy	6000.00
0005432105968	5160	Economy	6000.00
0005432105982	5160	Economy	6000.00
0005432105971	5160	Economy	6000.00
0005433615319	5160	Economy	6000.00
0005433785240	5160	Economy	6000.00
0005433615270	5160	Economy	6000.00
0005433615314	5160	Economy	6000.00
0005433785250	5160	Economy	6000.00
0005432105959	5160	Economy	6000.00
0005433785252	5160	Economy	6000.00
0005432105956	5160	Economy	6000.00
0005433615295	5160	Economy	6000.00
0005432105944	5160	Economy	6000.00
0005433615290	5160	Economy	6000.00
0005432105948	5160	Economy	6000.00
0005433785257	5160	Economy	6000.00
0005433615325	5160	Economy	6000.00
0005432105940	5160	Economy	6000.00
0005433615327	5160	Economy	6000.00
0005433785237	5160	Economy	6000.00
0005433785232	5160	Economy	6000.00
0005434229550	5162	Business	18000.00
0005434229547	5162	Business	18000.00
0005434312302	5162	Business	18000.00
0005435007042	5162	Business	18000.00
0005435007100	5162	Business	18000.00
0005432335999	5162	Business	18000.00
0005434149829	5162	Business	18000.00
0005434265360	5162	Business	18000.00
0005434265339	5162	Business	18000.00
0005434229566	5162	Business	18000.00
0005434229563	5162	Business	18000.00
0005432336007	5162	Business	18000.00
0005434229564	5162	Business	18000.00
0005434229545	5162	Business	18000.00
0005434229562	5162	Business	18000.00
0005434311224	5162	Business	18000.00
0005434265355	5162	Business	18000.00
0005433815383	5162	Business	18000.00
0005433815379	5162	Business	18000.00
0005434312300	5162	Business	18000.00
0005434265346	5162	Economy	6600.00
0005435006920	5162	Economy	6600.00
0005434229558	5162	Economy	6600.00
0005434149825	5162	Economy	6600.00
0005434265351	5162	Economy	6600.00
0005432336037	5162	Economy	6000.00
0005434265342	5162	Economy	6000.00
0005435006989	5162	Economy	6000.00
0005432336028	5162	Economy	6000.00
0005434265354	5162	Economy	6000.00
0005432336008	5162	Economy	6000.00
0005434229549	5162	Economy	6000.00
0005434265348	5162	Economy	6000.00
0005432336022	5162	Economy	6000.00
0005435007055	5162	Economy	6000.00
0005434265347	5162	Economy	6000.00
0005434265344	5162	Economy	6000.00
0005435006873	5162	Economy	6000.00
0005434265362	5162	Economy	6000.00
0005433685531	5162	Economy	6000.00
0005435007059	5162	Economy	6000.00
0005435007008	5162	Economy	6000.00
0005434265343	5162	Economy	6000.00
0005434265350	5162	Economy	6000.00
0005434229565	5162	Economy	6000.00
0005432336027	5162	Economy	6000.00
0005435007035	5162	Economy	6000.00
0005433688802	5162	Economy	6000.00
0005435006979	5162	Economy	6000.00
0005434229553	5162	Economy	6000.00
0005432336035	5162	Economy	6000.00
0005435006992	5162	Economy	6000.00
0005435006985	5162	Economy	6000.00
0005434312301	5162	Economy	6000.00
0005434311211	5162	Economy	6000.00
0005434149831	5162	Economy	6000.00
0005434229560	5162	Economy	6000.00
0005434229561	5162	Economy	6000.00
0005434265356	5162	Economy	6000.00
0005434229559	5162	Economy	6000.00
0005434312317	5162	Economy	6000.00
0005432336023	5162	Economy	6000.00
0005435006899	5162	Economy	6000.00
0005435007034	5162	Economy	6000.00
0005432335939	5162	Economy	6000.00
0005433688803	5162	Economy	6000.00
0005435006988	5162	Economy	6000.00
0005435006991	5162	Economy	6000.00
0005434149822	5162	Economy	6000.00
0005434229546	5162	Economy	6000.00
0005434265352	5162	Economy	6000.00
0005433688798	5162	Economy	6600.00
0005434265361	5162	Economy	6600.00
0005434311210	5162	Economy	6600.00
0005435007033	5162	Economy	6600.00
0005435007090	5162	Economy	6600.00
0005434173553	5162	Economy	6000.00
0005435006952	5162	Economy	6000.00
0005434149826	5162	Economy	6000.00
0005432336062	5162	Economy	6600.00
0005435006900	5162	Economy	6000.00
0005434265340	5162	Economy	6000.00
0005434265337	5162	Economy	6000.00
0005435006980	5162	Economy	6000.00
0005434229557	5162	Economy	6000.00
0005432335938	5162	Economy	6000.00
0005434265338	5162	Economy	6000.00
0005434149824	5162	Economy	6000.00
0005433815367	5162	Economy	6000.00
0005434229548	5162	Economy	6000.00
0005434311221	5162	Economy	6000.00
0005434265359	5162	Economy	6000.00
0005435006919	5162	Economy	6000.00
0005432336024	5162	Economy	6000.00
0005434149827	5162	Economy	6000.00
0005434265341	5162	Economy	6000.00
0005434149823	5162	Economy	6000.00
0005434265363	5162	Economy	6000.00
0005434149830	5162	Economy	6000.00
0005434265357	5162	Economy	6000.00
0005434229556	5162	Economy	6000.00
0005434229551	5162	Economy	6000.00
0005434311225	5162	Economy	6000.00
0005434229555	5162	Economy	6000.00
0005434173552	5162	Economy	6000.00
0005434173554	5162	Economy	6000.00
0005435006872	5162	Economy	6000.00
0005434149832	5162	Economy	6000.00
0005435007021	5162	Economy	6000.00
0005434265345	5162	Economy	6000.00
0005434149828	5162	Economy	6000.00
0005433815374	5162	Economy	6000.00
0005434229552	5162	Economy	6000.00
0005434265353	5162	Economy	6000.00
0005435006884	5162	Economy	6000.00
0005432336038	5162	Economy	6000.00
0005435007078	5162	Economy	6000.00
0005434229554	5162	Economy	6000.00
0005433688805	5162	Economy	6000.00
0005435007077	5162	Economy	6000.00
0005435007043	5162	Economy	6000.00
0005434265358	5162	Economy	6000.00
0005434265349	5162	Economy	6000.00
0005433685529	5162	Economy	6000.00
0005433815378	5162	Economy	6000.00
0005433685530	5162	Economy	6000.00
0005434244907	8605	Business	18000.00
0005434244936	8605	Business	18000.00
0005434244996	8605	Business	18000.00
0005434245024	8605	Business	18000.00
0005434245047	8605	Business	18000.00
0005433785069	8605	Business	18000.00
0005434244908	8605	Business	18000.00
0005434244949	8605	Business	18000.00
0005434244881	8605	Business	18000.00
0005435269799	8605	Business	18000.00
0005433784967	8605	Business	18000.00
0005434245040	8605	Business	18000.00
0005435269796	8605	Business	18000.00
0005434244994	8605	Business	18000.00
0005433785065	8605	Business	18000.00
0005434245053	8605	Economy	6600.00
0005434245109	8605	Economy	6600.00
0005433785001	8605	Economy	6000.00
0005432663036	8605	Economy	6000.00
0005433784863	8605	Economy	6000.00
0005432663032	8605	Economy	6000.00
0005434245097	8605	Economy	6000.00
0005433784898	8605	Economy	6000.00
0005434245014	8605	Economy	6000.00
0005433784933	8605	Economy	6000.00
0005434245019	8605	Economy	6000.00
0005434244967	8605	Economy	6000.00
0005434245046	8605	Economy	6000.00
0005434244990	8605	Economy	6000.00
0005433784971	8605	Economy	6000.00
0005434244989	8605	Economy	6000.00
0005435269797	8605	Economy	6000.00
0005433784871	8605	Economy	6000.00
0005433784948	8605	Economy	6000.00
0005434245110	8605	Economy	6000.00
0005434244919	8605	Economy	6000.00
0005433784854	8605	Economy	6000.00
0005432663033	8605	Economy	6000.00
0005433784870	8605	Economy	6000.00
0005433785032	8605	Economy	6000.00
0005435269801	8605	Economy	6000.00
0005434244986	8605	Economy	6000.00
0005433785061	8605	Economy	6000.00
0005433784712	8605	Economy	6000.00
0005432663035	8605	Economy	6000.00
0005433784887	8605	Economy	6600.00
0005433785014	8605	Economy	6600.00
0005433784966	8605	Economy	6600.00
0005433785041	8605	Economy	6000.00
0005434245082	8605	Economy	6000.00
0005432663031	8605	Economy	6000.00
0005434245122	8605	Economy	6000.00
0005435269798	8605	Economy	6000.00
0005434244950	8605	Economy	6000.00
0005434244890	8605	Economy	6000.00
0005433785031	8605	Economy	6000.00
0005434244917	8605	Economy	6000.00
0005433784897	8605	Economy	6000.00
0005434245027	8605	Economy	6000.00
0005434245035	8605	Economy	6000.00
0005434244909	8605	Economy	6000.00
0005434244937	8605	Economy	6000.00
0005433784938	8605	Economy	6000.00
0005433784909	8605	Economy	6000.00
0005434245018	8605	Economy	6000.00
0005432663040	8605	Economy	6000.00
0005434245043	8605	Economy	6000.00
0005433785055	8605	Economy	6000.00
0005435269800	8605	Economy	6000.00
0005433784930	8605	Economy	6000.00
0005434245025	8605	Economy	6000.00
0005433785066	8605	Economy	6000.00
0005433785074	8605	Economy	6000.00
0005434245033	8605	Economy	6000.00
0005433785062	8605	Economy	6000.00
0005433784945	8605	Economy	6000.00
0005434244993	8605	Economy	6000.00
0005433784910	8605	Economy	6000.00
0005433784740	8605	Economy	6000.00
0005433614296	8606	Business	18000.00
0005433614746	8606	Business	18000.00
0005433614569	8606	Business	18000.00
0005433614597	8606	Business	18000.00
0005433614356	8606	Business	18000.00
0005433614295	8606	Business	18000.00
0005433614577	8606	Business	18000.00
0005433614473	8606	Business	18000.00
0005433614593	8606	Business	18000.00
0005433614628	8606	Business	18000.00
0005433614594	8606	Business	18000.00
0005433614523	8606	Business	18000.00
0005433614509	8606	Business	18000.00
0005433614549	8606	Economy	6600.00
0005433614480	8606	Business	18000.00
0005433614257	8606	Economy	6600.00
0005433614712	8606	Economy	6600.00
0005433614807	8606	Economy	6600.00
0005433614870	8606	Economy	6000.00
0005433614560	8606	Economy	6000.00
0005433614631	8606	Economy	6000.00
0005433614733	8606	Economy	6000.00
0005433614740	8606	Economy	6000.00
0005433614802	8606	Economy	6000.00
0005433614598	8606	Economy	6000.00
0005433614647	8606	Economy	6000.00
0005433614483	8606	Economy	6000.00
0005433614454	8606	Economy	6000.00
0005433614576	8606	Economy	6000.00
0005433614384	8606	Economy	6000.00
0005433614529	8606	Economy	6000.00
0005433614474	8606	Economy	6000.00
0005433614578	8606	Economy	6000.00
0005433614378	8606	Economy	6000.00
0005433614567	8606	Economy	6000.00
0005433614379	8606	Economy	6000.00
0005433614475	8606	Economy	6000.00
0005433614566	8606	Economy	6000.00
0005433614541	8606	Economy	6000.00
0005433614697	8606	Economy	6000.00
0005433614487	8606	Economy	6000.00
0005433614471	8606	Economy	6000.00
0005433614634	8606	Economy	6000.00
0005433614572	8606	Economy	6000.00
0005433614216	8606	Economy	6000.00
0005433614427	8606	Economy	6000.00
0005433614700	8606	Economy	6000.00
0005433614635	8606	Economy	6600.00
0005433614538	8606	Economy	6600.00
0005433614502	8606	Economy	6600.00
0005433614711	8606	Economy	6600.00
0005433614217	8606	Economy	6600.00
0005433614565	8606	Economy	6000.00
0005433614683	8606	Economy	6000.00
0005433614592	8606	Economy	6000.00
0005433614477	8606	Economy	6000.00
0005433614484	8606	Economy	6000.00
0005433614479	8606	Economy	6000.00
0005433614801	8606	Economy	6000.00
0005433614761	8606	Economy	6000.00
0005433614027	8606	Economy	6000.00
0005433614528	8606	Economy	6000.00
0005433614600	8606	Economy	6000.00
0005433614664	8606	Economy	6000.00
0005433614558	8606	Economy	6000.00
0005433614808	8606	Economy	6000.00
0005433614503	8606	Economy	6000.00
0005433614745	8606	Economy	6000.00
0005433614380	8606	Economy	6000.00
0005433614630	8606	Economy	6000.00
0005433615071	8606	Economy	6000.00
0005433614559	8606	Economy	6000.00
0005433614696	8606	Economy	6000.00
0005433614476	8606	Economy	6000.00
0005433614663	8606	Economy	6000.00
0005433614385	8606	Economy	6000.00
0005433614472	8606	Economy	6000.00
0005433614532	8606	Economy	6000.00
0005433614636	8606	Economy	6000.00
0005433614762	8606	Economy	6000.00
0005433614610	8606	Economy	6000.00
0005433615070	8606	Economy	6000.00
0005433614611	8606	Economy	6000.00
0005433614258	8606	Economy	6000.00
0005433614335	8606	Economy	6000.00
0005433614626	8606	Economy	6000.00
0005433614069	8606	Economy	6000.00
0005433614646	8606	Economy	6000.00
0005433690942	8607	Business	18000.00
0005434265255	8607	Business	18000.00
0005434149727	8607	Business	18000.00
0005432035189	8607	Business	18000.00
0005433815427	8607	Business	18000.00
0005434229375	8607	Business	18000.00
0005435007225	8607	Business	18000.00
0005432336136	8607	Business	18000.00
0005433689928	8607	Business	18000.00
0005434149649	8607	Business	18000.00
0005432047583	8607	Business	18000.00
0005434265206	8607	Business	18000.00
0005434173516	8607	Business	18000.00
0005432035181	8607	Business	18000.00
0005434229354	8607	Business	18000.00
0005434265151	8607	Business	18000.00
0005434229408	8607	Business	18000.00
0005434149748	8607	Business	18000.00
0005433534516	8607	Business	18000.00
0005435286662	8607	Business	18000.00
0005435007212	8607	Business	18000.00
0005432035172	8607	Business	18000.00
0005435007222	8607	Business	18000.00
0005435007202	8607	Business	18000.00
0005434229427	8607	Business	18000.00
0005435007216	8607	Business	18000.00
0005435007214	8607	Economy	6600.00
0005432035167	8607	Economy	6600.00
0005435007223	8607	Economy	6600.00
0005432035173	8607	Economy	6600.00
0005434311237	8607	Economy	6600.00
0005434229369	8607	Economy	6000.00
0005432336131	8607	Economy	6000.00
0005434229482	8607	Economy	6000.00
0005432047580	8607	Economy	6000.00
0005435286663	8607	Economy	6000.00
0005434149648	8607	Economy	6000.00
0005434229368	8607	Economy	6000.00
0005432035182	8607	Economy	6000.00
0005435007219	8607	Economy	6000.00
0005434265106	8607	Economy	6000.00
0005434265191	8607	Economy	6000.00
0005432336127	8607	Economy	6000.00
0005434229345	8607	Economy	6000.00
0005434265267	8607	Economy	6000.00
0005435007224	8607	Economy	6000.00
0005433690941	8607	Economy	6000.00
0005432035168	8607	Economy	6000.00
0005432336134	8607	Economy	6000.00
0005434229367	8607	Economy	6000.00
0005432035171	8607	Economy	6000.00
0005435007221	8607	Economy	6000.00
0005432035185	8607	Economy	6000.00
0005432035183	8607	Economy	6000.00
0005434229318	8607	Economy	6000.00
0005432336130	8607	Economy	6000.00
0005435007205	8607	Economy	6000.00
0005435007204	8607	Economy	6000.00
0005435007220	8607	Economy	6000.00
0005432047579	8607	Economy	6000.00
0005434265122	8607	Economy	6000.00
0005432035180	8607	Economy	6000.00
0005432035164	8607	Economy	6000.00
0005435007207	8607	Economy	6000.00
0005434149680	8607	Economy	6000.00
0005434265210	8607	Economy	6000.00
0005435286665	8607	Economy	6000.00
0005434229377	8607	Economy	6000.00
0005434265045	8607	Economy	6000.00
0005432035170	8607	Economy	6000.00
0005432336132	8607	Economy	6000.00
0005434265178	8607	Economy	6000.00
0005434229312	8607	Economy	6000.00
0005432035163	8607	Economy	6000.00
0005435007203	8607	Economy	6000.00
0005435286666	8607	Economy	6000.00
0005434265121	8607	Economy	6000.00
0005432035187	8607	Economy	6000.00
0005434229391	8607	Economy	6000.00
0005435007217	8607	Economy	6000.00
0005432035169	8607	Economy	6000.00
0005434265195	8607	Economy	6000.00
0005434264988	8607	Economy	6000.00
0005435007211	8607	Economy	6000.00
0005432035175	8607	Economy	6000.00
0005435007209	8607	Economy	6000.00
0005432336129	8607	Economy	6600.00
0005433815426	8607	Economy	6600.00
0005434229429	8607	Economy	6600.00
0005433815425	8607	Economy	6600.00
0005435007208	8607	Economy	6600.00
0005432035177	8607	Economy	6000.00
0005435286664	8607	Economy	6000.00
0005434173515	8607	Economy	6000.00
0005434229431	8607	Economy	6000.00
0005435007206	8607	Economy	6600.00
0005434229346	8607	Economy	6000.00
0005432047582	8607	Economy	6000.00
0005432035162	8607	Economy	6000.00
0005434173526	8607	Economy	6000.00
0005434265199	8607	Economy	6000.00
0005434265132	8607	Economy	6000.00
0005434265085	8607	Economy	6000.00
0005432336135	8607	Economy	6000.00
0005432336138	8607	Economy	6000.00
0005433815428	8607	Economy	6000.00
0005434265074	8607	Economy	6000.00
0005435007215	8607	Economy	6000.00
0005435007218	8607	Economy	6000.00
0005432035186	8607	Economy	6000.00
0005434265177	8607	Economy	6000.00
0005434229336	8607	Economy	6000.00
0005434149717	8607	Economy	6000.00
0005434229366	8607	Economy	6000.00
0005435007210	8607	Economy	6000.00
0005432035179	8607	Economy	6000.00
0005432035184	8607	Economy	6000.00
0005433688827	8607	Economy	6000.00
0005435007213	8607	Economy	6000.00
0005432035165	8607	Economy	6000.00
0005434265055	8607	Economy	6000.00
0005432336133	8607	Economy	6000.00
0005434149706	8607	Economy	6000.00
0005432336128	8607	Economy	6000.00
0005432035178	8607	Economy	6000.00
0005434229483	8607	Economy	6000.00
0005432035188	8607	Economy	6000.00
0005434229432	8607	Economy	6000.00
0005434229335	8607	Economy	6000.00
0005432035174	8607	Economy	6000.00
0005434229350	8607	Economy	6000.00
0005434229428	8607	Economy	6000.00
0005432035166	8607	Economy	6000.00
0005432035161	8607	Economy	6000.00
0005434173521	8607	Economy	6000.00
0005434264987	8607	Economy	6000.00
0005433534517	8607	Economy	6000.00
0005434149745	8607	Economy	6000.00
0005434149679	8607	Economy	6000.00
0005434265202	8607	Economy	6000.00
0005435007226	8607	Economy	6000.00
0005434229484	8607	Economy	6000.00
0005433534515	8607	Economy	6000.00
0005434229349	8607	Economy	6000.00
0005432035176	8607	Economy	6000.00
0005434149708	8607	Economy	6000.00
0005434265031	8607	Economy	6000.00
0005432336137	8607	Economy	6000.00
0005434229373	8607	Economy	6000.00
0005434149692	8607	Economy	6000.00
0005432047581	8607	Economy	6000.00
0005434265138	8607	Economy	6000.00
0005434149707	8607	Economy	6000.00
0005434639299	12622	Economy	16200.00
0005433202491	12622	Economy	16200.00
0005434639379	12622	Economy	16200.00
0005433202485	12622	Economy	14800.00
0005434639319	12622	Economy	14800.00
0005434639381	12622	Economy	14800.00
0005434639238	12622	Economy	14800.00
0005434639391	12622	Economy	14800.00
0005434639300	12622	Economy	14800.00
0005434639338	12622	Economy	14800.00
0005434639336	12622	Economy	14800.00
0005433202492	12622	Economy	14800.00
0005434639386	12622	Economy	14800.00
0005433202490	12622	Economy	14800.00
0005433202482	12622	Economy	14800.00
0005433202487	12622	Economy	14800.00
0005433202479	12622	Economy	14800.00
0005433202484	12622	Economy	14800.00
0005434639417	12622	Economy	14800.00
0005433202481	12622	Economy	14800.00
0005434639389	12622	Economy	14800.00
0005433202493	12622	Economy	14800.00
0005434639380	12622	Economy	14800.00
0005434639219	12622	Economy	14800.00
0005433202489	12622	Economy	14800.00
0005433202480	12622	Economy	14800.00
0005434639337	12622	Economy	14800.00
0005433202488	12622	Economy	14800.00
0005434639290	12622	Economy	14800.00
0005434639314	12622	Economy	14800.00
0005433202483	12622	Economy	14800.00
0005434639394	12622	Economy	14800.00
0005434639342	12622	Economy	14800.00
0005434639390	12622	Economy	14800.00
0005434639324	12622	Economy	14800.00
0005434639255	12622	Economy	14800.00
0005433202486	12622	Economy	14800.00
0005434639387	12622	Economy	14800.00
0005434639291	12622	Economy	14800.00
0005434639502	23352	Economy	16200.00
0005434639506	23352	Economy	16200.00
0005433202321	23352	Economy	16200.00
0005434639515	23352	Economy	14800.00
0005434639504	23352	Economy	14800.00
0005434639521	23352	Economy	14800.00
0005433202365	23352	Economy	14800.00
0005434639500	23352	Economy	14800.00
0005434639510	23352	Economy	14800.00
0005432290657	23352	Economy	14800.00
0005434639520	23352	Economy	14800.00
0005433202274	23352	Economy	14800.00
0005432290656	23352	Economy	14800.00
0005434639517	23352	Economy	14800.00
0005433202313	23352	Economy	14800.00
0005434639503	23352	Economy	14800.00
0005434639514	23352	Economy	14800.00
0005434639508	23352	Economy	14800.00
0005433202347	23352	Economy	14800.00
0005433202320	23352	Economy	14800.00
0005433202336	23352	Economy	14800.00
0005434639505	23352	Economy	14800.00
0005434639499	23352	Economy	14800.00
0005434639511	23352	Economy	14800.00
0005432290655	23352	Economy	14800.00
0005433202254	23352	Economy	14800.00
0005433202255	23352	Economy	14800.00
0005434639501	23352	Economy	14800.00
0005433202345	23352	Economy	14800.00
0005434639519	23352	Economy	14800.00
0005433202341	23352	Economy	14800.00
0005434639516	23352	Economy	14800.00
0005433202256	23352	Economy	14800.00
0005433202306	23352	Economy	14800.00
0005434639509	23352	Economy	14800.00
0005432290654	23352	Economy	14800.00
0005434639513	23352	Economy	14800.00
0005433202335	23352	Economy	14800.00
0005434639507	23352	Economy	14800.00
0005433202344	23352	Economy	14800.00
0005434639512	23352	Economy	14800.00
0005433202340	23352	Economy	14800.00
0005433202348	23352	Economy	14800.00
0005434639518	23352	Economy	14800.00
0005432383146	21071	Business	18900.00
0005432328716	21071	Business	18900.00
0005432383162	21071	Business	18900.00
0005432383098	21071	Business	18900.00
0005432328765	21071	Business	18900.00
0005432383135	21071	Business	18900.00
0005432328711	21071	Business	18900.00
0005432054328	21071	Business	18900.00
0005432328789	21071	Business	18900.00
0005432328723	21071	Business	18900.00
0005432383015	21071	Business	18900.00
0005432382986	21071	Business	18900.00
0005432328774	21071	Economy	6300.00
0005432383092	21071	Economy	6300.00
0005432383014	21071	Economy	6300.00
0005432328790	21071	Economy	6300.00
0005432383049	21071	Economy	6300.00
0005432383179	21071	Economy	6300.00
0005432383097	21071	Economy	6300.00
0005432328455	21071	Economy	6300.00
0005432328580	21071	Economy	6300.00
0005432328653	21071	Economy	6300.00
0005432328588	21071	Economy	6900.00
0005432328654	21071	Economy	6900.00
0005432328644	21071	Economy	6900.00
0005432328572	21071	Economy	6900.00
0005432328618	21071	Economy	6900.00
0005432328642	21071	Economy	6300.00
0005432328601	21071	Economy	6300.00
0005432383137	21071	Economy	6300.00
0005432328672	21071	Economy	6300.00
0005432328905	21071	Economy	6300.00
0005432383169	21071	Economy	6300.00
0005432383143	21071	Economy	6300.00
0005432328513	21071	Economy	6300.00
0005432328708	21071	Economy	6300.00
0005432382970	21071	Economy	6300.00
0005432328807	21071	Economy	6300.00
0005432328584	21071	Economy	6300.00
0005432383094	21071	Economy	6300.00
0005432383142	21071	Economy	6300.00
0005432383004	21071	Economy	6300.00
0005432328589	21071	Economy	6300.00
0005432383022	21071	Economy	6300.00
0005432328616	21071	Economy	6300.00
0005432383173	21071	Economy	6300.00
0005432382998	21071	Economy	6300.00
0005432383138	21071	Economy	6300.00
0005432328717	21071	Economy	6300.00
0005432383112	21071	Economy	6300.00
0005432383005	21071	Economy	6300.00
0005432383068	21071	Economy	6300.00
0005432382994	21071	Economy	6300.00
0005432328729	21071	Economy	6300.00
0005432328720	21071	Economy	6300.00
0005432328801	21071	Economy	6300.00
0005432383101	21071	Economy	6300.00
0005432328802	21071	Economy	6300.00
0005432382987	21071	Economy	6300.00
0005432328680	21071	Economy	6300.00
0005432328641	21071	Economy	6300.00
0005432328489	21071	Economy	6300.00
0005432328456	21071	Economy	6300.00
0005432328682	21071	Economy	6300.00
0005432328518	21071	Economy	6300.00
0005432383093	21071	Economy	6300.00
0005432328579	21071	Economy	6300.00
0005432328825	21071	Economy	6300.00
0005432328673	21071	Economy	6300.00
0005432328728	21071	Economy	6300.00
0005432383131	21071	Economy	6300.00
0005432383017	21071	Economy	6300.00
0005432382993	21071	Economy	6300.00
0005432328619	21071	Economy	6300.00
0005432383187	21071	Economy	6300.00
0005432054329	21071	Economy	6300.00
0005432328681	21071	Economy	6300.00
0005432383141	21071	Economy	6300.00
0005432328665	21071	Economy	6300.00
0005432328512	21071	Economy	6300.00
0005432328693	21071	Economy	6300.00
0005432328719	21071	Economy	6300.00
0005432328617	21071	Economy	6300.00
0005432328700	21071	Economy	6300.00
0005432328585	21071	Economy	6300.00
0005432383013	21071	Economy	6300.00
0005432328803	21071	Economy	6300.00
0005432383188	21071	Economy	6300.00
0005432383167	21071	Economy	6300.00
0005432328800	21071	Economy	6300.00
0005432328707	21071	Economy	6300.00
0005432328718	21071	Economy	6300.00
0005432328600	21071	Economy	6300.00
0005432328855	21071	Economy	6300.00
0005432383067	21071	Economy	6300.00
0005432328710	21071	Economy	6300.00
0005432383174	21071	Economy	6300.00
0005432383457	31261	Business	18900.00
0005432383478	31261	Business	18900.00
0005432287228	31261	Business	18900.00
0005432383469	31261	Business	18900.00
0005432329040	31261	Business	18900.00
0005432329062	31261	Business	18900.00
0005432329041	31261	Business	18900.00
0005432383471	31261	Business	18900.00
0005432329053	31261	Business	18900.00
0005432383486	31261	Business	18900.00
0005432383467	31261	Business	18900.00
0005432383472	31261	Business	18900.00
0005432329058	31261	Economy	6300.00
0005432329023	31261	Economy	6300.00
0005432383474	31261	Economy	6300.00
0005432383487	31261	Economy	6300.00
0005432383476	31261	Economy	6300.00
0005432329034	31261	Economy	6300.00
0005432383453	31261	Economy	6300.00
0005432329043	31261	Economy	6300.00
0005432329042	31261	Economy	6300.00
0005432383444	31261	Economy	6300.00
0005432329061	31261	Economy	6900.00
0005432329045	31261	Economy	6900.00
0005432329052	31261	Economy	6900.00
0005432329036	31261	Economy	6900.00
0005432329027	31261	Economy	6900.00
0005432383454	31261	Economy	6300.00
0005432383460	31261	Economy	6300.00
0005432329054	31261	Economy	6300.00
0005432383461	31261	Economy	6300.00
0005432329064	31261	Economy	6300.00
0005432287226	31261	Economy	6300.00
0005432383464	31261	Economy	6300.00
0005432383485	31261	Economy	6300.00
0005432329032	31261	Economy	6300.00
0005432383475	31261	Economy	6300.00
0005432383463	31261	Economy	6300.00
0005432383477	31261	Economy	6300.00
0005432383466	31261	Economy	6300.00
0005432383484	31261	Economy	6300.00
0005432329063	31261	Economy	6300.00
0005432329029	31261	Economy	6300.00
0005432383448	31261	Economy	6300.00
0005432329055	31261	Economy	6300.00
0005432383482	31261	Economy	6300.00
0005432383452	31261	Economy	6300.00
0005432329033	31261	Economy	6300.00
0005432329019	31261	Economy	6300.00
0005432329035	31261	Economy	6300.00
0005432383481	31261	Economy	6300.00
0005432383449	31261	Economy	6300.00
0005432329020	31261	Economy	6300.00
0005432329038	31261	Economy	6300.00
0005432329021	31261	Economy	6300.00
0005432383473	31261	Economy	6300.00
0005432329060	31261	Economy	6300.00
0005432383459	31261	Economy	6300.00
0005432383480	31261	Economy	6300.00
0005432383446	31261	Economy	6300.00
0005432329049	31261	Economy	6300.00
0005432383462	31261	Economy	6300.00
0005432329018	31261	Economy	6300.00
0005432329030	31261	Economy	6300.00
0005432329047	31261	Economy	6300.00
0005432329056	31261	Economy	6300.00
0005432383451	31261	Economy	6300.00
0005432329031	31261	Economy	6300.00
0005432383479	31261	Economy	6300.00
0005432329028	31261	Economy	6300.00
0005432329065	31261	Economy	6300.00
0005432329050	31261	Economy	6300.00
0005432383456	31261	Economy	6300.00
0005432329026	31261	Economy	6300.00
0005432383447	31261	Economy	6300.00
0005432383455	31261	Economy	6300.00
0005432329051	31261	Economy	6300.00
0005432329046	31261	Economy	6300.00
0005432329048	31261	Economy	6300.00
0005432329022	31261	Economy	6300.00
0005432383445	31261	Economy	6300.00
0005432383483	31261	Economy	6300.00
0005432329057	31261	Economy	6300.00
0005432287229	31261	Economy	6300.00
0005432383450	31261	Economy	6300.00
0005432329025	31261	Economy	6300.00
0005432383458	31261	Economy	6300.00
0005432329044	31261	Economy	6300.00
0005432329059	31261	Economy	6300.00
0005432329037	31261	Economy	6300.00
0005432329024	31261	Economy	6300.00
0005432287227	31261	Economy	6300.00
0005432383468	31261	Economy	6300.00
0005432383465	31261	Economy	6300.00
0005432329039	31261	Economy	6300.00
0005432383470	31261	Economy	6300.00
0005433642452	2468	Business	89600.00
0005432953935	2468	Business	89600.00
0005433642471	2468	Business	89600.00
0005433642458	2468	Business	89600.00
0005432953912	2468	Business	89600.00
0005432953930	2468	Economy	29900.00
0005432953947	2468	Economy	29900.00
0005432953889	2468	Economy	29900.00
0005432953894	2468	Economy	29900.00
0005433642459	2468	Economy	29900.00
0005433642446	2468	Economy	32800.00
0005432953944	2468	Economy	32800.00
0005432953964	2468	Economy	29900.00
0005433642447	2468	Economy	29900.00
0005433642457	2468	Economy	29900.00
0005433642469	2468	Economy	29900.00
0005433642461	2468	Economy	29900.00
0005433642451	2468	Economy	29900.00
0005433642468	2468	Economy	29900.00
0005433642460	2468	Economy	29900.00
0005432953918	2468	Economy	29900.00
0005433642466	2468	Economy	29900.00
0005433642462	2468	Economy	29900.00
0005432953914	2468	Economy	29900.00
0005433642464	2468	Economy	29900.00
0005432953929	2468	Economy	29900.00
0005433642455	2468	Economy	29900.00
0005433642454	2468	Economy	29900.00
0005433642456	2468	Economy	29900.00
0005432953906	2468	Economy	29900.00
0005433642448	2468	Economy	29900.00
0005433642467	2468	Economy	29900.00
0005433642449	2468	Economy	29900.00
0005433642472	2468	Economy	29900.00
0005432953893	2468	Economy	29900.00
0005432953959	2468	Economy	29900.00
0005433642470	2468	Economy	29900.00
0005432953913	2468	Economy	29900.00
0005432953905	2468	Economy	29900.00
0005432953963	2468	Economy	29900.00
0005433642463	2468	Economy	29900.00
0005433642453	2468	Economy	29900.00
0005432953936	2468	Economy	29900.00
0005433642450	2468	Economy	29900.00
0005433642473	2468	Economy	29900.00
0005432953919	2468	Economy	29900.00
0005433642465	2468	Economy	29900.00
0005432954000	27599	Business	89600.00
0005433642201	27599	Business	89600.00
0005432953994	27599	Business	89600.00
0005432954008	27599	Business	89600.00
0005433642353	27599	Business	89600.00
0005432954001	27599	Business	89600.00
0005433642227	27599	Business	89600.00
0005432953995	27599	Economy	29900.00
0005433642345	27599	Economy	29900.00
0005433642296	27599	Economy	29900.00
0005433642295	27599	Economy	29900.00
0005433642361	27599	Economy	29900.00
0005433642346	27599	Economy	29900.00
0005433642202	27599	Economy	29900.00
0005433642270	27599	Economy	29900.00
0005432954006	27599	Economy	32800.00
0005432953998	27599	Economy	32800.00
0005432954009	27599	Economy	29900.00
0005432954011	27599	Economy	29900.00
0005433642273	27599	Economy	29900.00
0005432954005	27599	Economy	29900.00
0005433642287	27599	Economy	29900.00
0005433642319	27599	Economy	29900.00
0005432953999	27599	Economy	29900.00
0005433642228	27599	Economy	29900.00
0005433642303	27599	Economy	29900.00
0005433642306	27599	Economy	29900.00
0005433642364	27599	Economy	29900.00
0005433642359	27599	Economy	29900.00
0005433642344	27599	Economy	29900.00
0005433642352	27599	Economy	29900.00
0005433642354	27599	Economy	29900.00
0005433642226	27599	Economy	29900.00
0005433642331	27599	Economy	29900.00
0005433642363	27599	Economy	29900.00
0005433642263	27599	Economy	29900.00
0005432953996	27599	Economy	29900.00
0005433642339	27599	Economy	29900.00
0005432954003	27599	Economy	29900.00
0005433642249	27599	Economy	29900.00
0005432953997	27599	Economy	29900.00
0005433642281	27599	Economy	29900.00
0005432954002	27599	Economy	29900.00
0005433642321	27599	Economy	29900.00
0005432954004	27599	Economy	29900.00
0005433642360	27599	Economy	29900.00
0005432954007	27599	Economy	29900.00
0005433642347	27599	Economy	29900.00
0005432954010	27599	Economy	29900.00
0005432424803	13377	Business	12700.00
0005432424795	13377	Business	12700.00
0005432424799	13377	Business	12700.00
0005432424787	13377	Business	12700.00
0005432424797	13377	Business	12700.00
0005432424806	13377	Business	12700.00
0005432424785	13377	Business	12700.00
0005432424786	13377	Economy	4200.00
0005432424815	13377	Economy	4200.00
0005432424817	13377	Economy	4200.00
0005432424819	13377	Economy	4200.00
0005432424777	13377	Economy	4200.00
0005432424816	13377	Economy	4200.00
0005432424800	13377	Economy	4200.00
0005432424791	13377	Economy	4200.00
0005432424812	13377	Economy	4700.00
0005432424810	13377	Economy	4700.00
0005432424784	13377	Economy	4200.00
0005432424790	13377	Economy	4200.00
0005432424814	13377	Economy	4200.00
0005432424818	13377	Economy	4200.00
0005432424783	13377	Economy	4200.00
0005432424808	13377	Economy	4200.00
0005432424802	13377	Economy	4200.00
0005432424789	13377	Economy	4200.00
0005432424796	13377	Economy	4200.00
0005432424779	13377	Economy	4200.00
0005432424778	13377	Economy	4200.00
0005432424811	13377	Economy	4200.00
0005432424782	13377	Economy	4200.00
0005432424804	13377	Economy	4200.00
0005432424780	13377	Economy	4200.00
0005432424794	13377	Economy	4200.00
0005432424788	13377	Economy	4200.00
0005432424801	13377	Economy	4200.00
0005432424821	13377	Economy	4200.00
0005432424793	13377	Economy	4200.00
0005432424792	13377	Economy	4200.00
0005432424820	13377	Economy	4200.00
0005432424798	13377	Economy	4200.00
0005432424807	13377	Economy	4200.00
0005432424809	13377	Economy	4200.00
0005432424805	13377	Economy	4200.00
0005432424813	13377	Economy	4200.00
0005432424781	13377	Economy	4200.00
0005432424776	13377	Economy	4200.00
0005432424324	30708	Business	12700.00
0005432424385	30708	Business	12700.00
0005432424357	30708	Business	12700.00
0005432424348	30708	Business	12700.00
0005432424388	30708	Business	12700.00
0005432424408	30708	Business	12700.00
0005432424189	30708	Economy	4200.00
0005432424358	30708	Economy	4200.00
0005432424329	30708	Economy	4200.00
0005432424341	30708	Economy	4200.00
0005432424411	30708	Economy	4200.00
0005432424409	30708	Economy	4700.00
0005432424403	30708	Economy	4700.00
0005432424325	30708	Economy	4700.00
0005432424258	30708	Economy	4200.00
0005432424399	30708	Economy	4200.00
0005432424374	30708	Economy	4200.00
0005432424346	30708	Economy	4200.00
0005432424263	30708	Economy	4200.00
0005432424303	30708	Economy	4200.00
0005432424394	30708	Economy	4200.00
0005432424262	30708	Economy	4200.00
0005432424163	30708	Economy	4200.00
0005432424365	30708	Economy	4200.00
0005432424304	30708	Economy	4200.00
0005432424356	30708	Economy	4200.00
0005432424404	30708	Economy	4200.00
0005432424196	30708	Economy	4200.00
0005432424345	30708	Economy	4200.00
0005432424364	30708	Economy	4200.00
0005432424389	30708	Economy	4200.00
0005432424375	30708	Economy	4200.00
0005432424336	30708	Economy	4200.00
0005432424337	30708	Economy	4200.00
0005432424410	30708	Economy	4200.00
0005432424342	30708	Economy	4200.00
0005432424372	30708	Economy	4200.00
0005432424340	30708	Economy	4200.00
0005432424310	30708	Economy	4200.00
0005432424347	30708	Economy	4200.00
0005432424298	30708	Economy	4200.00
0005432424395	30708	Economy	4200.00
0005432424373	30708	Economy	4200.00
0005434157481	9598	Business	32600.00
0005432817714	9598	Business	32600.00
0005432817720	9598	Business	32600.00
0005432817717	9598	Business	32600.00
0005432817700	9598	Business	32600.00
0005432822269	9598	Business	32600.00
0005434448345	9598	Business	32600.00
0005432817701	9598	Business	32600.00
0005432817715	9598	Business	32600.00
0005432817722	9598	Business	32600.00
0005432901521	9598	Business	32600.00
0005434157494	9598	Business	32600.00
0005432901552	9598	Economy	10900.00
0005432901565	9598	Economy	10900.00
0005432822264	9598	Economy	10900.00
0005432901625	9598	Economy	10900.00
0005432817708	9598	Economy	10900.00
0005434157484	9598	Economy	10900.00
0005434157497	9598	Economy	10900.00
0005432817713	9598	Economy	10900.00
0005432289013	9598	Economy	11900.00
0005432817698	9598	Economy	11900.00
0005432901516	9598	Economy	11900.00
0005432817709	9598	Economy	11900.00
0005434186204	9598	Economy	11900.00
0005434186187	9598	Economy	10900.00
0005432817719	9598	Economy	10900.00
0005432901623	9598	Economy	10900.00
0005432901576	9598	Economy	10900.00
0005432817711	9598	Economy	10900.00
0005432901560	9598	Economy	10900.00
0005434186185	9598	Economy	10900.00
0005432817702	9598	Economy	10900.00
0005432901549	9598	Economy	10900.00
0005432817718	9598	Economy	10900.00
0005434186192	9598	Economy	10900.00
0005432901548	9598	Economy	10900.00
0005432901672	9598	Economy	10900.00
0005432822265	9598	Economy	10900.00
0005432817723	9598	Economy	10900.00
0005432901503	9598	Economy	10900.00
0005434157441	9598	Economy	10900.00
0005432901649	9598	Economy	10900.00
0005432901631	9598	Economy	10900.00
0005432817725	9598	Economy	10900.00
0005432817704	9598	Economy	10900.00
0005432901534	9598	Economy	10900.00
0005434186186	9598	Economy	10900.00
0005432901517	9598	Economy	10900.00
0005432901614	9598	Economy	10900.00
0005432901626	9598	Economy	10900.00
0005434186188	9598	Economy	10900.00
0005432817710	9598	Economy	10900.00
0005432817707	9598	Economy	10900.00
0005432817712	9598	Economy	10900.00
0005432822266	9598	Economy	10900.00
0005432817726	9598	Economy	10900.00
0005434448344	9598	Economy	10900.00
0005432817705	9598	Economy	10900.00
0005432901613	9598	Economy	10900.00
0005432817703	9598	Economy	10900.00
0005432901627	9598	Economy	10900.00
0005432817724	9598	Economy	10900.00
0005432901572	9598	Economy	10900.00
0005432817706	9598	Economy	10900.00
0005432901585	9598	Economy	10900.00
0005432901632	9598	Economy	10900.00
0005432289012	9598	Economy	10900.00
0005434448343	9598	Economy	10900.00
0005432901665	9598	Economy	10900.00
0005434157442	9598	Economy	10900.00
0005434157498	9598	Economy	10900.00
0005432817727	9598	Economy	10900.00
0005434157440	9598	Economy	10900.00
0005432817721	9598	Economy	10900.00
0005432289011	9598	Economy	10900.00
0005432817716	9598	Economy	10900.00
0005432901612	9598	Economy	10900.00
0005432901561	9598	Economy	10900.00
0005432822267	9598	Economy	10900.00
0005432817699	9598	Economy	10900.00
0005432289014	9598	Economy	10900.00
0005432822268	9598	Economy	10900.00
0005432901581	9598	Economy	10900.00
0005432901714	9598	Economy	10900.00
0005434186205	9598	Economy	10900.00
0005432901715	9598	Economy	10900.00
0005434157539	28961	Business	32600.00
0005432817376	28961	Business	32600.00
0005432822159	28961	Business	32600.00
0005434157540	28961	Business	32600.00
0005432817394	28961	Business	32600.00
0005432817510	28961	Business	32600.00
0005434157541	28961	Business	32600.00
0005432901753	28961	Business	32600.00
0005434448308	28961	Business	32600.00
0005432901750	28961	Business	32600.00
0005432822205	28961	Economy	10900.00
0005432817544	28961	Economy	10900.00
0005432822169	28961	Economy	10900.00
0005434186220	28961	Economy	10900.00
0005432817461	28961	Economy	10900.00
0005432901754	28961	Economy	10900.00
0005432817374	28961	Economy	10900.00
0005432817406	28961	Economy	10900.00
0005434157546	28961	Economy	10900.00
0005432901748	28961	Economy	11900.00
0005432901747	28961	Economy	11900.00
0005432901760	28961	Economy	11900.00
0005434157547	28961	Economy	11900.00
0005432901743	28961	Economy	10900.00
0005432822197	28961	Economy	10900.00
0005432817545	28961	Economy	10900.00
0005432817382	28961	Economy	10900.00
0005432817385	28961	Economy	10900.00
0005432901752	28961	Economy	10900.00
0005432817511	28961	Economy	10900.00
0005432817384	28961	Economy	10900.00
0005432817538	28961	Economy	10900.00
0005432817662	28961	Economy	10900.00
0005432002092	28961	Economy	10900.00
0005432817431	28961	Economy	10900.00
0005432817448	28961	Economy	10900.00
0005432817360	28961	Economy	10900.00
0005434448311	28961	Economy	10900.00
0005432817454	28961	Economy	10900.00
0005434448315	28961	Economy	10900.00
0005432817343	28961	Economy	10900.00
0005434157544	28961	Economy	10900.00
0005432901744	28961	Economy	10900.00
0005434186221	28961	Economy	10900.00
0005432901759	28961	Economy	10900.00
0005434186219	28961	Economy	10900.00
0005432901758	28961	Economy	10900.00
0005432817342	28961	Economy	10900.00
0005434448310	28961	Economy	10900.00
0005432817663	28961	Economy	10900.00
0005432817524	28961	Economy	10900.00
0005432817369	28961	Economy	10900.00
0005432822200	28961	Economy	10900.00
0005432901751	28961	Economy	10900.00
0005432822201	28961	Economy	10900.00
0005432901746	28961	Economy	10900.00
0005434157542	28961	Economy	10900.00
0005432822204	28961	Economy	10900.00
0005432817501	28961	Economy	10900.00
0005432901755	28961	Economy	10900.00
0005434157545	28961	Economy	10900.00
0005432817534	28961	Economy	10900.00
0005432901745	28961	Economy	10900.00
0005434157543	28961	Economy	10900.00
0005432817425	28961	Economy	10900.00
0005434448307	28961	Economy	10900.00
0005432901757	28961	Economy	10900.00
0005432817375	28961	Economy	10900.00
0005432817366	28961	Economy	10900.00
0005432817478	28961	Economy	10900.00
0005434448316	28961	Economy	10900.00
0005432817292	28961	Economy	10900.00
0005432817306	28961	Economy	10900.00
0005432817307	28961	Economy	10900.00
0005432901756	28961	Economy	10900.00
0005432817449	28961	Economy	10900.00
0005432002093	28961	Economy	10900.00
0005432901749	28961	Economy	10900.00
0005432822181	28961	Economy	10900.00
0005432817496	28961	Economy	10900.00
0005432611745	15074	Economy	11000.00
0005432613894	15074	Economy	11000.00
0005432613897	15074	Economy	11000.00
0005432613896	15074	Economy	11000.00
0005432611748	15074	Economy	11000.00
0005432611742	15074	Economy	11000.00
0005432611744	15074	Economy	11000.00
0005432611743	15074	Economy	11000.00
0005432611747	15074	Economy	11000.00
0005432611746	15074	Economy	11000.00
0005432613895	15074	Economy	11000.00
0005432607580	31588	Economy	11000.00
0005432611720	31588	Economy	11000.00
0005432611719	31588	Economy	11000.00
0005435841828	31588	Economy	11000.00
0005432607562	31588	Economy	11000.00
0005435841827	31588	Economy	11000.00
0005435842331	31588	Economy	11000.00
0005432611722	31588	Economy	11000.00
0005432948422	11886	Business	105900.00
0005432948512	11886	Business	105900.00
0005433569509	11886	Business	105900.00
0005433569516	11886	Business	105900.00
0005432948513	11886	Business	105900.00
0005432948587	11886	Business	105900.00
0005433569488	11886	Business	105900.00
0005432948415	11886	Business	105900.00
0005433569502	11886	Business	105900.00
0005433569537	11886	Business	105900.00
0005433569505	11886	Business	105900.00
0005432948473	11886	Business	105900.00
0005432948346	11886	Business	105900.00
0005432948378	11886	Business	105900.00
0005433569528	11886	Economy	35300.00
0005432948423	11886	Business	105900.00
0005432948424	11886	Economy	35300.00
0005433569499	11886	Economy	35300.00
0005433569497	11886	Economy	35300.00
0005433569513	11886	Economy	35300.00
0005433569507	11886	Economy	35300.00
0005433569517	11886	Economy	35300.00
0005433569480	11886	Economy	35300.00
0005432948345	11886	Economy	35300.00
0005433569529	11886	Economy	35300.00
0005432948390	11886	Economy	35300.00
0005433569475	11886	Economy	35300.00
0005432948588	11886	Economy	38800.00
0005433569518	11886	Economy	38800.00
0005433569514	11886	Economy	38800.00
0005432948286	11886	Economy	38800.00
0005433569500	11886	Economy	35300.00
0005433569523	11886	Economy	35300.00
0005432948391	11886	Economy	35300.00
0005433569501	11886	Economy	35300.00
0005433569483	11886	Economy	35300.00
0005433569487	11886	Economy	35300.00
0005433569484	11886	Economy	35300.00
0005433569522	11886	Economy	35300.00
0005433569535	11886	Economy	35300.00
0005433569472	11886	Economy	35300.00
0005432948482	11886	Economy	35300.00
0005433569525	11886	Economy	35300.00
0005433569510	11886	Economy	35300.00
0005432948511	11886	Economy	35300.00
0005432948711	11886	Economy	35300.00
0005433569536	11886	Economy	35300.00
0005432948471	11886	Economy	35300.00
0005433569498	11886	Economy	35300.00
0005433569489	11886	Economy	35300.00
0005433569482	11886	Economy	35300.00
0005432948407	11886	Economy	35300.00
0005432948406	11886	Economy	35300.00
0005433569531	11886	Economy	35300.00
0005433569486	11886	Economy	35300.00
0005433569533	11886	Economy	35300.00
0005433569493	11886	Economy	35300.00
0005433569478	11886	Economy	35300.00
0005433569519	11886	Economy	35300.00
0005432948467	11886	Economy	35300.00
0005432948493	11886	Economy	35300.00
0005433569481	11886	Economy	35300.00
0005433569494	11886	Economy	35300.00
0005433569492	11886	Economy	35300.00
0005432948306	11886	Economy	35300.00
0005433569515	11886	Economy	35300.00
0005433569520	11886	Economy	35300.00
0005433569530	11886	Economy	35300.00
0005432948389	11886	Economy	35300.00
0005432948508	11886	Economy	35300.00
0005433569485	11886	Economy	35300.00
0005432948397	11886	Economy	35300.00
0005433569495	11886	Economy	35300.00
0005433569524	11886	Economy	35300.00
0005433569474	11886	Economy	35300.00
0005432948461	11886	Economy	35300.00
0005432948420	11886	Economy	35300.00
0005433569491	11886	Economy	35300.00
0005432948268	11886	Economy	35300.00
0005432948468	11886	Economy	35300.00
0005432948437	11886	Economy	35300.00
0005432948426	11886	Economy	35300.00
0005433569476	11886	Economy	35300.00
0005433569496	11886	Economy	35300.00
0005432948373	11886	Economy	35300.00
0005433569511	11886	Economy	35300.00
0005433569526	11886	Economy	35300.00
0005433569503	11886	Economy	35300.00
0005432948369	11886	Economy	35300.00
0005433569532	11886	Economy	35300.00
0005433569473	11886	Economy	35300.00
0005433569521	11886	Economy	35300.00
0005432948425	11886	Economy	35300.00
0005433569527	11886	Economy	35300.00
0005433569506	11886	Economy	35300.00
0005432948523	11886	Economy	35300.00
0005433569534	11886	Economy	35300.00
0005433569508	11886	Economy	35300.00
0005433569490	11886	Economy	35300.00
0005432948336	11886	Economy	35300.00
0005433569479	11886	Economy	35300.00
0005433569504	11886	Economy	35300.00
0005433569477	11886	Economy	35300.00
0005433569512	11886	Economy	35300.00
0005433568787	25299	Business	105900.00
0005433568999	25299	Business	105900.00
0005432948814	25299	Business	105900.00
0005433568848	25299	Business	105900.00
0005433568628	25299	Business	105900.00
0005433569036	25299	Business	105900.00
0005432948833	25299	Business	105900.00
0005433569037	25299	Business	105900.00
0005432948845	25299	Business	105900.00
0005433569015	25299	Business	105900.00
0005433568917	25299	Business	105900.00
0005433568915	25299	Business	105900.00
0005432948826	25299	Business	105900.00
0005433569111	25299	Business	105900.00
0005433569033	25299	Business	105900.00
0005433568745	25299	Economy	35300.00
0005432948813	25299	Economy	35300.00
0005433568982	25299	Economy	35300.00
0005433569118	25299	Economy	35300.00
0005432948821	25299	Economy	35300.00
0005432948823	25299	Economy	35300.00
0005432948811	25299	Economy	35300.00
0005432948806	25299	Economy	35300.00
0005433568811	25299	Economy	35300.00
0005433568788	25299	Economy	35300.00
0005433568629	25299	Economy	35300.00
0005433569172	25299	Economy	35300.00
0005433568951	25299	Economy	38800.00
0005432948844	25299	Economy	38800.00
0005433568918	25299	Economy	38800.00
0005432948831	25299	Economy	38800.00
0005433569068	25299	Economy	35300.00
0005433569166	25299	Economy	35300.00
0005433569097	25299	Economy	35300.00
0005432948838	25299	Economy	35300.00
0005433568732	25299	Economy	35300.00
0005432948830	25299	Economy	35300.00
0005432948809	25299	Economy	35300.00
0005433569117	25299	Economy	35300.00
0005433568971	25299	Economy	35300.00
0005432948843	25299	Economy	35300.00
0005432948837	25299	Economy	35300.00
0005433568965	25299	Economy	35300.00
0005432948827	25299	Economy	35300.00
0005432948817	25299	Economy	35300.00
0005432948825	25299	Economy	35300.00
0005433568991	25299	Economy	35300.00
0005433569043	25299	Economy	35300.00
0005432948832	25299	Economy	35300.00
0005432948808	25299	Economy	35300.00
0005433568886	25299	Economy	35300.00
0005433568897	25299	Economy	35300.00
0005432948824	25299	Economy	35300.00
0005432948828	25299	Economy	35300.00
0005433569119	25299	Economy	35300.00
0005433568636	25299	Economy	35300.00
0005432948847	25299	Economy	35300.00
0005432948812	25299	Economy	35300.00
0005433569051	25299	Economy	35300.00
0005432948840	25299	Economy	35300.00
0005433568992	25299	Economy	35300.00
0005433569153	25299	Economy	35300.00
0005433568953	25299	Economy	35300.00
0005433568952	25299	Economy	35300.00
0005433569002	25299	Economy	35300.00
0005432948835	25299	Economy	35300.00
0005433568646	25299	Economy	35300.00
0005433568993	25299	Economy	35300.00
0005432948846	25299	Economy	35300.00
0005433568630	25299	Economy	35300.00
0005432948816	25299	Economy	35300.00
0005432948807	25299	Economy	35300.00
0005433568926	25299	Economy	35300.00
0005432948842	25299	Economy	35300.00
0005432948836	25299	Economy	35300.00
0005432948834	25299	Economy	35300.00
0005433569180	25299	Economy	35300.00
0005432948829	25299	Economy	35300.00
0005433569030	25299	Economy	35300.00
0005432948818	25299	Economy	35300.00
0005432948822	25299	Economy	35300.00
0005432948819	25299	Economy	35300.00
0005432948841	25299	Economy	35300.00
0005432948839	25299	Economy	35300.00
0005433568855	25299	Economy	35300.00
0005433568959	25299	Economy	35300.00
0005433569079	25299	Economy	35300.00
0005433568697	25299	Economy	35300.00
0005432948820	25299	Economy	35300.00
0005433569019	25299	Economy	35300.00
0005433569014	25299	Economy	35300.00
0005433568808	25299	Economy	35300.00
0005432948810	25299	Economy	35300.00
0005432948815	25299	Economy	35300.00
0005433569104	25299	Economy	35300.00
0005433568964	25299	Economy	35300.00
0005433568968	25299	Economy	35300.00
0005433568796	25299	Economy	35300.00
0005432430886	14465	Business	117400.00
0005434026718	14465	Business	117400.00
0005432430892	14465	Business	117400.00
0005432430897	14465	Business	117400.00
0005432430889	14465	Business	117400.00
0005433808353	14465	Business	117400.00
0005433812886	14465	Business	117400.00
0005432430887	14465	Business	117400.00
0005434026716	14465	Business	117400.00
0005434026717	14465	Business	117400.00
0005433808358	14465	Economy	39100.00
0005433808341	14465	Economy	39100.00
0005432430896	14465	Economy	39100.00
0005432430883	14465	Economy	39100.00
0005433808369	14465	Economy	39100.00
0005433812881	14465	Economy	39100.00
0005433808339	14465	Economy	39100.00
0005432430893	14465	Economy	43000.00
0005433808356	14465	Economy	43000.00
0005432430895	14465	Economy	39100.00
0005434026723	14465	Economy	43000.00
0005433812883	14465	Economy	39100.00
0005433812882	14465	Economy	39100.00
0005433808340	14465	Economy	39100.00
0005434026720	14465	Economy	39100.00
0005433808367	14465	Economy	39100.00
0005434026715	14465	Economy	39100.00
0005433808364	14465	Economy	39100.00
0005433812887	14465	Economy	39100.00
0005433808350	14465	Economy	39100.00
0005434026721	14465	Economy	39100.00
0005433812879	14465	Economy	39100.00
0005432430894	14465	Economy	39100.00
0005433812893	14465	Economy	39100.00
0005433808372	14465	Economy	39100.00
0005434026719	14465	Economy	39100.00
0005434026722	14465	Economy	39100.00
0005433808354	14465	Economy	39100.00
0005432430884	14465	Economy	39100.00
0005433808371	14465	Economy	39100.00
0005432430891	14465	Economy	39100.00
0005432430890	14465	Economy	39100.00
0005433812880	14465	Economy	39100.00
0005432430885	14465	Economy	39100.00
0005433812878	14465	Economy	39100.00
0005433808391	14465	Economy	39100.00
0005432430888	14465	Economy	39100.00
0005434654907	5383	Business	67200.00
0005435555368	5383	Business	67200.00
0005435340329	5383	Business	67200.00
0005435340232	5383	Business	67200.00
0005434654926	5383	Business	67200.00
0005434654918	5383	Business	67200.00
0005434654928	5383	Business	67200.00
0005434654910	5383	Economy	22400.00
0005435340255	5383	Economy	22400.00
0005434654934	5383	Economy	22400.00
0005435340231	5383	Economy	22400.00
0005432114229	5383	Economy	22400.00
0005434654936	5383	Economy	22400.00
0005435555378	5383	Economy	24600.00
0005435340332	5383	Economy	24600.00
0005435340275	5383	Economy	22400.00
0005435555369	5383	Economy	22400.00
0005434656572	5383	Economy	22400.00
0005434654915	5383	Economy	22400.00
0005434654925	5383	Economy	22400.00
0005434654916	5383	Economy	22400.00
0005434654930	5383	Economy	22400.00
0005434654932	5383	Economy	22400.00
0005434654913	5383	Economy	22400.00
0005435340278	5383	Economy	22400.00
0005432114228	5383	Economy	22400.00
0005434654920	5383	Economy	22400.00
0005434654927	5383	Economy	22400.00
0005434654924	5383	Economy	22400.00
0005434656574	5383	Economy	22400.00
0005435555377	5383	Economy	22400.00
0005434654914	5383	Economy	22400.00
0005435340330	5383	Economy	22400.00
0005432114230	5383	Economy	22400.00
0005434654908	5383	Economy	22400.00
0005435340298	5383	Economy	22400.00
0005434654917	5383	Economy	22400.00
0005434654912	5383	Economy	22400.00
0005434656573	5383	Economy	22400.00
0005435340331	5383	Economy	22400.00
0005434654922	5383	Economy	22400.00
0005434654911	5383	Economy	22400.00
0005434654919	5383	Economy	22400.00
0005434654931	5383	Economy	22400.00
0005434654909	5383	Economy	22400.00
0005434654921	5383	Economy	22400.00
0005434654929	5383	Economy	22400.00
0005434654935	5383	Economy	22400.00
0005434654923	5383	Economy	22400.00
0005434654933	5383	Economy	22400.00
0005434654695	12524	Business	67200.00
0005435340380	12524	Business	67200.00
0005434654781	12524	Business	67200.00
0005435340393	12524	Business	67200.00
0005435340391	12524	Business	67200.00
0005435340381	12524	Business	67200.00
0005435340382	12524	Business	67200.00
0005434654737	12524	Business	67200.00
0005434654630	12524	Economy	22400.00
0005435340385	12524	Economy	22400.00
0005435340384	12524	Economy	22400.00
0005434656552	12524	Economy	22400.00
0005434654688	12524	Economy	22400.00
0005434654668	12524	Economy	24600.00
0005435340394	12524	Economy	24600.00
0005434654787	12524	Economy	24600.00
0005435340389	12524	Economy	22400.00
0005435340387	12524	Economy	22400.00
0005434654611	12524	Economy	22400.00
0005434656553	12524	Economy	22400.00
0005435340383	12524	Economy	22400.00
0005434654615	12524	Economy	22400.00
0005434654614	12524	Economy	22400.00
0005435340390	12524	Economy	22400.00
0005434654714	12524	Economy	22400.00
0005434654687	12524	Economy	22400.00
0005434654710	12524	Economy	22400.00
0005435340386	12524	Economy	22400.00
0005434654677	12524	Economy	22400.00
0005434654768	12524	Economy	22400.00
0005434654629	12524	Economy	22400.00
0005434654505	12524	Economy	22400.00
0005434656554	12524	Economy	22400.00
0005434654580	12524	Economy	22400.00
0005435340379	12524	Economy	22400.00
0005435555388	12524	Economy	22400.00
0005434654696	12524	Economy	22400.00
0005434656555	12524	Economy	22400.00
0005434654738	12524	Economy	22400.00
0005435340392	12524	Economy	22400.00
0005434654795	12524	Economy	22400.00
0005434654786	12524	Economy	22400.00
0005434654782	12524	Economy	22400.00
0005434654678	12524	Economy	22400.00
0005434654778	12524	Economy	22400.00
0005434656557	12524	Economy	22400.00
0005435340388	12524	Economy	22400.00
0005434654783	12524	Economy	22400.00
0005434654771	12524	Economy	22400.00
0005434654800	12524	Economy	22400.00
0005434654676	12524	Economy	22400.00
0005433716365	7425	Business	32000.00
0005433716352	7425	Business	32000.00
0005432428934	7425	Business	32000.00
0005433716353	7425	Business	32000.00
0005432428929	7425	Business	32000.00
0005433716367	7425	Business	32000.00
0005432428909	7425	Economy	10700.00
0005433716363	7425	Economy	10700.00
0005433716390	7425	Economy	10700.00
0005433716372	7425	Economy	10700.00
0005433716385	7425	Economy	10700.00
0005433716361	7425	Economy	10700.00
0005433716373	7425	Economy	10700.00
0005433716386	7425	Economy	10700.00
0005433716396	7425	Economy	10700.00
0005433716346	7425	Economy	10700.00
0005433716378	7425	Economy	10700.00
0005433716349	7425	Economy	10700.00
0005433716359	7425	Economy	10700.00
0005433656694	7425	Economy	10700.00
0005432078156	7425	Economy	10700.00
0005433716388	7425	Economy	10700.00
0005433656696	7425	Economy	10700.00
0005433716355	7425	Economy	10700.00
0005433656695	7425	Economy	10700.00
0005433688825	7425	Economy	10700.00
0005433716392	7425	Economy	10700.00
0005433689925	7425	Economy	10700.00
0005433722275	7425	Economy	10700.00
0005433716360	7425	Economy	10700.00
0005433716358	7425	Economy	10700.00
0005433716381	7425	Economy	10700.00
0005433716345	7425	Economy	10700.00
0005433716347	7425	Economy	10700.00
0005433689926	7425	Economy	10700.00
0005435266139	7425	Economy	11700.00
0005432078155	7425	Economy	11700.00
0005432428916	7425	Economy	11700.00
0005433719166	7425	Economy	11700.00
0005433716371	7425	Economy	11700.00
0005433716394	7425	Economy	11700.00
0005432078153	7425	Economy	10700.00
0005433722274	7425	Economy	10700.00
0005433716395	7425	Economy	10700.00
0005433716384	7425	Economy	10700.00
0005433722272	7425	Economy	10700.00
0005433690939	7425	Economy	10700.00
0005433716369	7425	Economy	10700.00
0005433716391	7425	Economy	10700.00
0005433719165	7425	Economy	10700.00
0005435266140	7425	Economy	10700.00
0005433716383	7425	Economy	10700.00
0005433716380	7425	Economy	10700.00
0005433688826	7425	Economy	10700.00
0005433716375	7425	Economy	10700.00
0005432078151	7425	Economy	10700.00
0005433716387	7425	Economy	10700.00
0005433716364	7425	Economy	10700.00
0005433719164	7425	Economy	10700.00
0005433716356	7425	Economy	10700.00
0005433716351	7425	Economy	10700.00
0005432428924	7425	Economy	10700.00
0005433716376	7425	Economy	10700.00
0005433716377	7425	Economy	10700.00
0005433716366	7425	Economy	10700.00
0005433716370	7425	Economy	10700.00
0005433716354	7425	Economy	10700.00
0005433719167	7425	Economy	10700.00
0005433716382	7425	Economy	10700.00
0005432078154	7425	Economy	10700.00
0005433688824	7425	Economy	10700.00
0005432428915	7425	Economy	10700.00
0005432428933	7425	Economy	10700.00
0005432428923	7425	Economy	10700.00
0005433690940	7425	Economy	10700.00
0005433716348	7425	Economy	10700.00
0005433716393	7425	Economy	10700.00
0005433716368	7425	Economy	10700.00
0005432428920	7425	Economy	10700.00
0005433716379	7425	Economy	10700.00
0005432078152	7425	Economy	10700.00
0005433716357	7425	Economy	10700.00
0005433716350	7425	Economy	10700.00
0005433689927	7425	Economy	10700.00
0005433722276	7425	Economy	10700.00
0005433722273	7425	Economy	10700.00
0005433716362	7425	Economy	10700.00
0005433716374	7425	Economy	10700.00
0005433716389	7425	Economy	10700.00
0005433715950	29233	Business	32000.00
0005433722201	29233	Business	32000.00
0005433716015	29233	Business	32000.00
0005435266183	29233	Business	32000.00
0005433685530	29233	Business	32000.00
0005433716134	29233	Business	32000.00
0005432428955	29233	Economy	10700.00
0005433656671	29233	Economy	10700.00
0005433715839	29233	Economy	10700.00
0005433715881	29233	Economy	10700.00
0005432006784	29233	Economy	10700.00
0005433715922	29233	Economy	10700.00
0005433715975	29233	Economy	10700.00
0005433715894	29233	Economy	10700.00
0005433719144	29233	Economy	10700.00
0005432006783	29233	Economy	10700.00
0005433688798	29233	Economy	10700.00
0005433716019	29233	Economy	10700.00
0005432428956	29233	Economy	10700.00
0005433719118	29233	Economy	10700.00
0005433688805	29233	Economy	10700.00
0005433715853	29233	Economy	10700.00
0005433715888	29233	Economy	10700.00
0005433722211	29233	Economy	10700.00
0005433715779	29233	Economy	10700.00
0005433688802	29233	Economy	10700.00
0005435266184	29233	Economy	10700.00
0005433715953	29233	Economy	10700.00
0005433715887	29233	Economy	11700.00
0005433715831	29233	Economy	11700.00
0005433722212	29233	Economy	10700.00
0005433722194	29233	Economy	10700.00
0005435266180	29233	Economy	10700.00
0005433715942	29233	Economy	10700.00
0005433715916	29233	Economy	10700.00
0005433716072	29233	Economy	10700.00
0005433716031	29233	Economy	10700.00
0005433715807	29233	Economy	10700.00
0005433716135	29233	Economy	10700.00
0005433716076	29233	Economy	10700.00
0005433715952	29233	Economy	10700.00
0005433715895	29233	Economy	10700.00
0005433688803	29233	Economy	10700.00
0005433716063	29233	Economy	10700.00
0005433722215	29233	Economy	10700.00
0005433715924	29233	Economy	10700.00
0005433715945	29233	Economy	10700.00
0005433716064	29233	Economy	10700.00
0005433685531	29233	Economy	10700.00
0005432006785	29233	Economy	10700.00
0005433715954	29233	Economy	10700.00
0005433716077	29233	Economy	10700.00
0005433715803	29233	Economy	10700.00
0005435266181	29233	Economy	10700.00
0005435266182	29233	Economy	10700.00
0005432428957	29233	Economy	10700.00
0005433685529	29233	Economy	10700.00
0005433715804	29233	Economy	10700.00
0005433715918	29233	Economy	10700.00
0005433715938	29233	Economy	10700.00
0005433715889	29233	Economy	10700.00
0005433715923	29233	Economy	10700.00
0005433716075	29233	Economy	10700.00
0005433722202	29233	Economy	10700.00
0005433722216	29233	Economy	10700.00
0005433716095	29233	Economy	10700.00
0005433719128	29233	Economy	10700.00
0005433715840	29233	Economy	10700.00
0005432428958	29233	Economy	10700.00
0005433716054	29233	Economy	10700.00
0005433715703	29233	Economy	10700.00
0005433716071	29233	Economy	10700.00
0005433715917	29233	Economy	10700.00
0005433715802	29233	Economy	10700.00
0005433715785	29233	Economy	10700.00
0005434143741	8691	Business	36500.00
0005434143743	8691	Business	36500.00
0005434095398	8691	Business	36500.00
0005434095390	8691	Business	36500.00
0005434182194	8691	Economy	12200.00
0005434095387	8691	Economy	12200.00
0005434095395	8691	Economy	13400.00
0005434182223	8691	Economy	13400.00
0005434143742	8691	Economy	12200.00
0005434095388	8691	Economy	12200.00
0005434182159	8691	Economy	12200.00
0005434182127	8691	Economy	12200.00
0005434184669	8691	Economy	12200.00
0005434182176	8691	Economy	12200.00
0005434182224	8691	Economy	12200.00
0005434182175	8691	Economy	12200.00
0005434095397	8691	Economy	12200.00
0005434095391	8691	Economy	12200.00
0005434095394	8691	Economy	12200.00
0005434182189	8691	Economy	12200.00
0005434095392	8691	Economy	12200.00
0005434182229	8691	Economy	12200.00
0005434095393	8691	Economy	12200.00
0005434095396	8691	Economy	12200.00
0005434184670	8691	Economy	12200.00
0005434095389	8691	Economy	12200.00
0005434184679	11679	Business	36500.00
0005434095269	11679	Economy	12200.00
0005434095288	11679	Economy	12200.00
0005434095250	11679	Economy	12200.00
0005434182290	11679	Economy	12200.00
0005434095280	11679	Economy	13400.00
0005434182279	11679	Economy	13400.00
0005434182281	11679	Economy	13400.00
0005434143728	11679	Economy	12200.00
0005434095190	11679	Economy	12200.00
0005434095286	11679	Economy	12200.00
0005434182283	11679	Economy	12200.00
0005434183594	11679	Economy	12200.00
0005434183595	11679	Economy	12200.00
0005434182291	11679	Economy	12200.00
0005434182284	11679	Economy	12200.00
0005434182286	11679	Economy	12200.00
0005434326269	11679	Economy	12200.00
0005434183593	11679	Economy	12200.00
0005434095251	11679	Economy	12200.00
0005434182288	11679	Economy	12200.00
0005434182282	11679	Economy	12200.00
0005434182280	11679	Economy	12200.00
0005434182287	11679	Economy	12200.00
0005434182285	11679	Economy	12200.00
0005434326268	11679	Economy	12200.00
0005434095151	11679	Economy	12200.00
0005434095270	11679	Economy	12200.00
0005434095287	11679	Economy	12200.00
0005434182289	11679	Economy	12200.00
0005434184680	11679	Economy	12200.00
0005434184681	11679	Economy	12200.00
0005433398007	1441	Business	33000.00
0005433398002	1441	Business	33000.00
0005433397941	1441	Business	33000.00
0005433398086	1441	Business	33000.00
0005435732438	1441	Business	33000.00
0005435732430	1441	Business	33000.00
0005432297299	1441	Business	33000.00
0005433398233	1441	Business	33000.00
0005433397882	1441	Business	33000.00
0005433398076	1441	Economy	11000.00
0005435732420	1441	Economy	11000.00
0005433457003	1441	Economy	11000.00
0005433398251	1441	Economy	11000.00
0005433398003	1441	Economy	11000.00
0005433398054	1441	Economy	11000.00
0005433397880	1441	Economy	11000.00
0005435732424	1441	Economy	11000.00
0005435732428	1441	Economy	11000.00
0005435732429	1441	Economy	12100.00
0005433398056	1441	Economy	12100.00
0005435732423	1441	Economy	11000.00
0005433398143	1441	Economy	11000.00
0005433398235	1441	Economy	11000.00
0005435732432	1441	Economy	11000.00
0005435732440	1441	Economy	11000.00
0005433398091	1441	Economy	11000.00
0005433398253	1441	Economy	11000.00
0005433398021	1441	Economy	11000.00
0005433397957	1441	Economy	11000.00
0005433398142	1441	Economy	11000.00
0005432906537	1441	Economy	11000.00
0005433397966	1441	Economy	11000.00
0005433397827	1441	Economy	11000.00
0005433398041	1441	Economy	11000.00
0005435732421	1441	Economy	11000.00
0005435732427	1441	Economy	11000.00
0005435732437	1441	Economy	11000.00
0005433457000	1441	Economy	11000.00
0005433398122	1441	Economy	11000.00
0005433397847	1441	Economy	11000.00
0005435732425	1441	Economy	11000.00
0005433457002	1441	Economy	11000.00
0005435732434	1441	Economy	11000.00
0005433398252	1441	Economy	11000.00
0005433398075	1441	Economy	11000.00
0005433457001	1441	Economy	11000.00
0005433397995	1441	Economy	11000.00
0005433397956	1441	Economy	11000.00
0005433397784	1441	Economy	11000.00
0005433397876	1441	Economy	11000.00
0005433398006	1441	Economy	11000.00
0005433397965	1441	Economy	11000.00
0005433398065	1441	Economy	11000.00
0005435732435	1441	Economy	11000.00
0005433398234	1441	Economy	11000.00
0005433397902	1441	Economy	11000.00
0005433398096	1441	Economy	11000.00
0005433398092	1441	Economy	11000.00
0005433398009	1441	Economy	11000.00
0005433397859	1441	Economy	11000.00
0005433398155	1441	Economy	11000.00
0005435732431	1441	Economy	11000.00
0005433397942	1441	Economy	11000.00
0005433398055	1441	Economy	11000.00
0005433398042	1441	Economy	11000.00
0005433398123	1441	Economy	11000.00
0005435732426	1441	Economy	11000.00
0005435732433	1441	Economy	11000.00
0005435732439	1441	Economy	11000.00
0005433398090	1441	Economy	11000.00
0005433398008	1441	Economy	11000.00
0005435732436	1441	Economy	11000.00
0005435732422	1441	Economy	11000.00
0005435732321	19263	Business	33000.00
0005433398455	19263	Business	33000.00
0005433398458	19263	Business	33000.00
0005433398438	19263	Business	33000.00
0005433398442	19263	Business	33000.00
0005433398464	19263	Business	33000.00
0005435732319	19263	Business	33000.00
0005432906555	19263	Business	33000.00
0005435732318	19263	Business	33000.00
0005433398466	19263	Economy	11000.00
0005433398469	19263	Economy	11000.00
0005433398462	19263	Economy	11000.00
0005433398456	19263	Economy	11000.00
0005433398435	19263	Economy	12100.00
0005433398429	19263	Economy	12100.00
0005433398436	19263	Economy	12100.00
0005433398450	19263	Economy	12100.00
0005433398445	19263	Economy	12100.00
0005433398441	19263	Economy	11000.00
0005435732352	19263	Economy	11000.00
0005433398430	19263	Economy	11000.00
0005433398431	19263	Economy	11000.00
0005433398434	19263	Economy	11000.00
0005433398452	19263	Economy	11000.00
0005433398461	19263	Economy	11000.00
0005433456971	19263	Economy	11000.00
0005433398459	19263	Economy	11000.00
0005435732345	19263	Economy	11000.00
0005433456972	19263	Economy	11000.00
0005433398454	19263	Economy	11000.00
0005435732363	19263	Economy	11000.00
0005433398424	19263	Economy	11000.00
0005433456946	19263	Economy	11000.00
0005433398426	19263	Economy	11000.00
0005435732322	19263	Economy	11000.00
0005433398425	19263	Economy	11000.00
0005433398447	19263	Economy	11000.00
0005433398448	19263	Economy	11000.00
0005435732285	19263	Economy	11000.00
0005433398451	19263	Economy	11000.00
0005433398468	19263	Economy	11000.00
0005433398457	19263	Economy	11000.00
0005433456979	19263	Economy	11000.00
0005433398427	19263	Economy	11000.00
0005433398463	19263	Economy	11000.00
0005435732327	19263	Economy	11000.00
0005433398428	19263	Economy	11000.00
0005433456973	19263	Economy	11000.00
0005433398443	19263	Economy	11000.00
0005433398423	19263	Economy	11000.00
0005433398449	19263	Economy	11000.00
0005433398439	19263	Economy	11000.00
0005433398444	19263	Economy	11000.00
0005433398453	19263	Economy	11000.00
0005433398470	19263	Economy	11000.00
0005433398421	19263	Economy	11000.00
0005433456980	19263	Economy	11000.00
0005432906556	19263	Economy	11000.00
0005433398432	19263	Economy	11000.00
0005433398422	19263	Economy	11000.00
0005433398467	19263	Economy	11000.00
0005433398460	19263	Economy	11000.00
0005433398433	19263	Economy	11000.00
0005435732328	19263	Economy	11000.00
0005433398440	19263	Economy	11000.00
0005433398446	19263	Economy	11000.00
0005433398465	19263	Economy	11000.00
0005433398437	19263	Economy	11000.00
0005434443738	17355	Economy	15600.00
0005434443724	17355	Economy	15600.00
0005434443723	17355	Economy	14100.00
0005434443696	17355	Economy	14100.00
0005434443704	17355	Economy	14100.00
0005434443759	17355	Economy	14100.00
0005434443688	17355	Economy	14100.00
0005434443737	17355	Economy	14100.00
0005434443714	17355	Economy	14100.00
0005434443717	17355	Economy	14100.00
0005434443703	17355	Economy	14100.00
0005434443705	17355	Economy	14100.00
0005434443681	17355	Economy	14100.00
0005434443698	17355	Economy	14100.00
0005434443672	17355	Economy	14100.00
0005434443638	17355	Economy	14100.00
0005434443697	17355	Economy	14100.00
0005434443739	17355	Economy	14100.00
0005434443670	17355	Economy	14100.00
0005434443680	17355	Economy	14100.00
0005434443713	17355	Economy	14100.00
0005434443673	17355	Economy	14100.00
0005434443770	17355	Economy	14100.00
0005434443695	17355	Economy	14100.00
0005434443821	20605	Economy	15600.00
0005434443835	20605	Economy	14100.00
0005434443827	20605	Economy	14100.00
0005434443828	20605	Economy	14100.00
0005434443825	20605	Economy	14100.00
0005434443820	20605	Economy	14100.00
0005434443829	20605	Economy	14100.00
0005434443824	20605	Economy	14100.00
0005434443834	20605	Economy	14100.00
0005434443826	20605	Economy	14100.00
0005434443830	20605	Economy	14100.00
0005434443822	20605	Economy	14100.00
0005434443832	20605	Economy	14100.00
0005434443823	20605	Economy	14100.00
0005434443836	20605	Economy	14100.00
0005434443833	20605	Economy	14100.00
0005434443831	20605	Economy	14100.00
0005435377578	7240	Economy	5800.00
0005434954641	7240	Economy	5800.00
0005434954642	7240	Economy	5800.00
0005434954640	7240	Economy	5800.00
0005434954638	7240	Economy	5800.00
0005434954639	7240	Economy	5800.00
0005434954643	7240	Economy	5800.00
0005435377573	7240	Economy	5800.00
0005435377600	28324	Economy	5800.00
0005434954609	28324	Economy	5800.00
0005434954613	28324	Economy	5800.00
0005434954591	28324	Economy	5800.00
0005434954612	28324	Economy	5800.00
0005435377598	28324	Economy	5800.00
0005435377599	28324	Economy	5800.00
0005434954615	28324	Economy	5800.00
0005434954614	28324	Economy	5800.00
0005434351796	4498	Economy	15400.00
0005435893674	4498	Economy	15400.00
0005434351800	4498	Economy	15400.00
0005435893612	4498	Economy	14000.00
0005434326274	4498	Economy	14000.00
0005435893658	4498	Economy	14000.00
0005434351793	4498	Economy	14000.00
0005435893611	4498	Economy	14000.00
0005434351792	4498	Economy	14000.00
0005434351795	4498	Economy	14000.00
0005435893659	4498	Economy	14000.00
0005434351802	4498	Economy	14000.00
0005434351794	4498	Economy	14000.00
0005434351799	4498	Economy	14000.00
0005434183582	4498	Economy	14000.00
0005435893642	4498	Economy	14000.00
0005434351797	4498	Economy	14000.00
0005434351798	4498	Economy	14000.00
0005435893627	4498	Economy	14000.00
0005434351803	4498	Economy	14000.00
0005434351804	4498	Economy	14000.00
0005434351801	4498	Economy	14000.00
0005434183583	4498	Economy	14000.00
0005435893691	29651	Economy	15400.00
0005434351729	29651	Economy	15400.00
0005435893687	29651	Economy	14000.00
0005434351707	29651	Economy	14000.00
0005434351737	29651	Economy	14000.00
0005435893689	29651	Economy	14000.00
0005434351708	29651	Economy	14000.00
0005434351670	29651	Economy	14000.00
0005434351692	29651	Economy	14000.00
0005434351665	29651	Economy	14000.00
0005434351715	29651	Economy	14000.00
0005434351694	29651	Economy	14000.00
0005434351714	29651	Economy	14000.00
0005434351728	29651	Economy	14000.00
0005435893686	29651	Economy	14000.00
0005434351693	29651	Economy	14000.00
0005435893690	29651	Economy	14000.00
0005435893688	29651	Economy	14000.00
0005434351647	29651	Economy	14000.00
0005433343159	1097	Business	30600.00
0005433342891	1097	Business	30600.00
0005433343359	1097	Business	30600.00
0005433342676	1097	Business	30600.00
0005433343142	1097	Business	30600.00
0005433269738	1097	Business	30600.00
0005433342966	1097	Business	30600.00
0005433269722	1097	Business	30600.00
0005433343143	1097	Business	30600.00
0005433343051	1097	Business	30600.00
0005433343117	1097	Business	30600.00
0005433269719	1097	Business	30600.00
0005433463917	1097	Business	30600.00
0005433342642	1097	Business	30600.00
0005433342600	1097	Business	30600.00
0005433343100	1097	Business	30600.00
0005432293228	1097	Business	30600.00
0005433343285	1097	Business	30600.00
0005433342468	1097	Economy	11200.00
0005433342965	1097	Economy	11200.00
0005433462763	1097	Economy	11200.00
0005433269711	1097	Economy	11200.00
0005434446535	1097	Economy	10200.00
0005433343473	1097	Economy	10200.00
0005433342921	1097	Economy	10200.00
0005435545795	1097	Economy	10200.00
0005433158137	1097	Economy	10200.00
0005433343149	1097	Economy	10200.00
0005433343094	1097	Economy	10200.00
0005433343150	1097	Economy	10200.00
0005433343444	1097	Economy	10200.00
0005433342590	1097	Economy	10200.00
0005433342914	1097	Economy	10200.00
0005433342467	1097	Economy	10200.00
0005435092154	1097	Economy	10200.00
0005433343284	1097	Economy	10200.00
0005433269707	1097	Economy	10200.00
0005433342449	1097	Economy	10200.00
0005433342892	1097	Economy	10200.00
0005435092152	1097	Economy	10200.00
0005433342517	1097	Economy	10200.00
0005433343101	1097	Economy	10200.00
0005435545793	1097	Economy	10200.00
0005435545794	1097	Economy	10200.00
0005433343112	1097	Economy	10200.00
0005433343092	1097	Economy	10200.00
0005433343031	1097	Economy	10200.00
0005433343151	1097	Economy	10200.00
0005435092150	1097	Economy	10200.00
0005433343472	1097	Economy	10200.00
0005433343007	1097	Economy	10200.00
0005433269710	1097	Economy	10200.00
0005435092158	1097	Economy	10200.00
0005433463918	1097	Economy	10200.00
0005433343136	1097	Economy	10200.00
0005435092156	1097	Economy	10200.00
0005433343113	1097	Economy	10200.00
0005433343010	1097	Economy	10200.00
0005433343352	1097	Economy	10200.00
0005433343287	1097	Economy	10200.00
0005433342953	1097	Economy	10200.00
0005433342832	1097	Economy	10200.00
0005432293229	1097	Economy	10200.00
0005433342837	1097	Economy	10200.00
0005433342967	1097	Economy	10200.00
0005435092155	1097	Economy	10200.00
0005433343311	1097	Economy	10200.00
0005433343081	1097	Economy	10200.00
0005433342762	1097	Economy	10200.00
0005433343087	1097	Economy	10200.00
0005433343080	1097	Economy	10200.00
0005434445261	1097	Economy	10200.00
0005433342770	1097	Economy	10200.00
0005433343069	1097	Economy	10200.00
0005433343148	1097	Economy	10200.00
0005435092157	1097	Economy	10200.00
0005434446534	1097	Economy	10200.00
0005433462764	1097	Economy	10200.00
0005433343263	1097	Economy	10200.00
0005433343259	1097	Economy	10200.00
0005433342708	1097	Economy	10200.00
0005433343139	1097	Economy	10200.00
0005433342886	1097	Economy	11200.00
0005433343213	1097	Economy	11200.00
0005433343086	1097	Economy	11200.00
0005433342942	1097	Economy	11200.00
0005433343027	1097	Economy	10200.00
0005433343147	1097	Economy	10200.00
0005433269724	1097	Economy	10200.00
0005435092149	1097	Economy	10200.00
0005435092153	1097	Economy	10200.00
0005433342763	1097	Economy	10200.00
0005433343089	1097	Economy	10200.00
0005433342868	1097	Economy	10200.00
0005433342865	1097	Economy	10200.00
0005433342730	1097	Economy	10200.00
0005433343028	1097	Economy	10200.00
0005435545796	1097	Economy	10200.00
0005433342923	1097	Economy	10200.00
0005433342751	1097	Economy	10200.00
0005433343008	1097	Economy	10200.00
0005433343130	1097	Economy	10200.00
0005433343029	1097	Economy	10200.00
0005433343090	1097	Economy	10200.00
0005433342595	1097	Economy	10200.00
0005433343005	1097	Economy	10200.00
0005433342846	1097	Economy	10200.00
0005433343033	1097	Economy	10200.00
0005433342739	1097	Economy	10200.00
0005433342910	1097	Economy	10200.00
0005433269718	1097	Economy	10200.00
0005433342754	1097	Economy	10200.00
0005433269723	1097	Economy	10200.00
0005433343155	1097	Economy	10200.00
0005433342971	1097	Economy	10200.00
0005433342847	1097	Economy	10200.00
0005433269703	1097	Economy	10200.00
0005434446533	1097	Economy	10200.00
0005435545792	1097	Economy	10200.00
0005433343325	1097	Economy	10200.00
0005433269712	1097	Economy	10200.00
0005435092159	1097	Economy	10200.00
0005433342764	1097	Economy	10200.00
0005433269709	1097	Economy	10200.00
0005433343032	1097	Economy	10200.00
0005433343088	1097	Economy	10200.00
0005433343312	1097	Economy	10200.00
0005433342836	1097	Economy	10200.00
0005435092151	1097	Economy	10200.00
0005433343161	1097	Economy	10200.00
0005433343067	1097	Economy	10200.00
0005433342731	1097	Economy	10200.00
0005433269717	1097	Economy	10200.00
0005433343353	1097	Economy	10200.00
0005433269708	1097	Economy	10200.00
0005434446536	1097	Economy	10200.00
0005433343251	1097	Economy	10200.00
0005433342878	1097	Economy	10200.00
0005433342972	1097	Economy	10200.00
0005433342738	1097	Economy	10200.00
0005433343252	1097	Economy	10200.00
0005433158136	1097	Economy	10200.00
0005433343011	1097	Economy	10200.00
0005433342773	1097	Economy	10200.00
0005433343840	17060	Business	30600.00
0005433343846	17060	Business	30600.00
0005433159329	17060	Business	30600.00
0005433343867	17060	Business	30600.00
0005433343837	17060	Business	30600.00
0005433343847	17060	Business	30600.00
0005433343903	17060	Business	30600.00
0005433343851	17060	Business	30600.00
0005435508314	17060	Business	30600.00
0005433343828	17060	Business	30600.00
0005433343832	17060	Business	30600.00
0005433343918	17060	Business	30600.00
0005433343849	17060	Business	30600.00
0005433343857	17060	Business	30600.00
0005435508356	17060	Business	30600.00
0005433343919	17060	Business	30600.00
0005433343854	17060	Business	30600.00
0005433343878	17060	Economy	11200.00
0005435508300	17060	Business	30600.00
0005433159331	17060	Economy	11200.00
0005435508301	17060	Economy	10200.00
0005433343889	17060	Economy	10200.00
0005433343891	17060	Economy	10200.00
0005433343888	17060	Economy	10200.00
0005433343912	17060	Economy	10200.00
0005435092069	17060	Economy	10200.00
0005433343911	17060	Economy	10200.00
0005433343861	17060	Economy	10200.00
0005433343833	17060	Economy	10200.00
0005433343874	17060	Economy	10200.00
0005433343862	17060	Economy	10200.00
0005433343827	17060	Economy	10200.00
0005433343863	17060	Economy	10200.00
0005433343873	17060	Economy	10200.00
0005433343872	17060	Economy	10200.00
0005435508333	17060	Economy	10200.00
0005433343823	17060	Economy	10200.00
0005435508299	17060	Economy	10200.00
0005433343822	17060	Economy	10200.00
0005433343860	17060	Economy	10200.00
0005433343826	17060	Economy	10200.00
0005433343890	17060	Economy	10200.00
0005433343908	17060	Economy	10200.00
0005433343883	17060	Economy	10200.00
0005433343879	17060	Economy	10200.00
0005433343853	17060	Economy	10200.00
0005433343834	17060	Economy	10200.00
0005433343831	17060	Economy	10200.00
0005435508355	17060	Economy	10200.00
0005433343821	17060	Economy	10200.00
0005433343869	17060	Economy	10200.00
0005433269762	17060	Economy	10200.00
0005433343870	17060	Economy	10200.00
0005433343887	17060	Economy	10200.00
0005433269759	17060	Economy	10200.00
0005433343905	17060	Economy	10200.00
0005433343909	17060	Economy	10200.00
0005433343894	17060	Economy	10200.00
0005433343820	17060	Economy	10200.00
0005433343852	17060	Economy	10200.00
0005433343907	17060	Economy	10200.00
0005433343842	17060	Economy	10200.00
0005433343871	17060	Economy	10200.00
0005433343882	17060	Economy	10200.00
0005433343864	17060	Economy	10200.00
0005433343824	17060	Economy	10200.00
0005433343895	17060	Economy	10200.00
0005433343900	17060	Economy	10200.00
0005433269760	17060	Economy	10200.00
0005433343915	17060	Economy	10200.00
0005433343843	17060	Economy	10200.00
0005433343913	17060	Economy	10200.00
0005433343844	17060	Economy	10200.00
0005433343836	17060	Economy	10200.00
0005433343858	17060	Economy	10200.00
0005433343914	17060	Economy	10200.00
0005435508357	17060	Economy	10200.00
0005435508297	17060	Economy	10200.00
0005433343865	17060	Economy	10200.00
0005435092082	17060	Economy	10200.00
0005433343848	17060	Economy	10200.00
0005433343893	17060	Economy	11200.00
0005433343841	17060	Economy	10200.00
0005433343897	17060	Economy	10200.00
0005433343910	17060	Economy	11200.00
0005433343899	17060	Economy	11200.00
0005433269761	17060	Economy	10200.00
0005435508334	17060	Economy	10200.00
0005433343920	17060	Economy	10200.00
0005433343825	17060	Economy	10200.00
0005433343877	17060	Economy	10200.00
0005433343898	17060	Economy	10200.00
0005435508335	17060	Economy	10200.00
0005433343917	17060	Economy	10200.00
0005435092073	17060	Economy	10200.00
0005435092052	17060	Economy	10200.00
0005433269764	17060	Economy	10200.00
0005433343855	17060	Economy	10200.00
0005433343881	17060	Economy	10200.00
0005433343921	17060	Economy	10200.00
0005433343875	17060	Economy	10200.00
0005433343835	17060	Economy	10200.00
0005433343906	17060	Economy	10200.00
0005433343845	17060	Economy	10200.00
0005433269763	17060	Economy	10200.00
0005435508298	17060	Economy	10200.00
0005435092084	17060	Economy	10200.00
0005435508313	17060	Economy	10200.00
0005433343859	17060	Economy	10200.00
0005433343880	17060	Economy	10200.00
0005435092083	17060	Economy	10200.00
0005433343884	17060	Economy	10200.00
0005435508364	17060	Economy	10200.00
0005433343856	17060	Economy	10200.00
0005433159330	17060	Economy	10200.00
0005435092068	17060	Economy	10200.00
0005435508359	17060	Economy	10200.00
0005433343885	17060	Economy	10200.00
0005435508351	17060	Economy	10200.00
0005433343902	17060	Economy	10200.00
0005433343886	17060	Economy	10200.00
0005433343839	17060	Economy	10200.00
0005433343868	17060	Economy	10200.00
0005433343876	17060	Economy	10200.00
0005433343896	17060	Economy	10200.00
0005433269765	17060	Economy	10200.00
0005433343904	17060	Economy	10200.00
0005435508332	17060	Economy	10200.00
0005433343901	17060	Economy	10200.00
0005433343892	17060	Economy	10200.00
0005433343850	17060	Economy	10200.00
0005433343866	17060	Economy	10200.00
0005433343838	17060	Economy	10200.00
0005433159332	17060	Economy	10200.00
0005433343830	17060	Economy	10200.00
0005433343916	17060	Economy	10200.00
0005433343829	17060	Economy	10200.00
0005434067663	12802	Business	40300.00
0005434067507	12802	Business	40300.00
0005434081842	12802	Business	40300.00
0005434067364	12802	Business	40300.00
0005434067300	12802	Business	40300.00
0005434067171	12802	Business	40300.00
0005434067799	12802	Business	40300.00
0005433989758	12802	Business	40300.00
0005432159894	12802	Business	40300.00
0005434067814	12802	Business	40300.00
0005434067282	12802	Business	40300.00
0005434067508	12802	Business	40300.00
0005434067502	12802	Economy	13400.00
0005434067505	12802	Economy	13400.00
0005434067319	12802	Economy	13400.00
0005434067733	12802	Economy	13400.00
0005434067655	12802	Economy	13400.00
0005434067597	12802	Economy	13400.00
0005434067477	12802	Economy	13400.00
0005434067521	12802	Economy	13400.00
0005434067524	12802	Economy	13400.00
0005434067052	12802	Economy	13400.00
0005434067183	12802	Economy	13400.00
0005432433722	12802	Economy	13400.00
0005434067366	12802	Economy	13400.00
0005434067727	12802	Economy	13400.00
0005433989770	12802	Economy	13400.00
0005432161169	12802	Economy	13400.00
0005434067792	12802	Economy	13400.00
0005433812920	12802	Economy	13400.00
0005434067467	12802	Economy	13400.00
0005434067122	12802	Economy	13400.00
0005433989761	12802	Economy	13400.00
0005433989765	12802	Economy	13400.00
0005434067674	12802	Economy	13400.00
0005432433723	12802	Economy	13400.00
0005434081791	12802	Economy	13400.00
0005434067598	12802	Economy	13400.00
0005434067486	12802	Economy	13400.00
0005432159892	12802	Economy	13400.00
0005434067454	12802	Economy	13400.00
0005434067686	12802	Economy	13400.00
0005434067633	12802	Economy	13400.00
0005434067813	12802	Economy	13400.00
0005434067283	12802	Economy	13400.00
0005434067632	12802	Economy	13400.00
0005434067729	12802	Economy	13400.00
0005434067312	12802	Economy	13400.00
0005434067504	12802	Economy	13400.00
0005434067463	12802	Economy	13400.00
0005434067627	12802	Economy	13400.00
0005434067515	12802	Economy	14800.00
0005434067561	12802	Economy	14800.00
0005434067279	12802	Economy	14800.00
0005434067399	12802	Economy	14800.00
0005434067432	12802	Economy	14800.00
0005432159893	12802	Economy	14800.00
0005434067479	12802	Economy	13400.00
0005434081752	12802	Economy	13400.00
0005434067547	12802	Economy	13400.00
0005434067541	12802	Economy	13400.00
0005434067466	12802	Economy	13400.00
0005434067676	12802	Economy	13400.00
0005434067352	12802	Economy	13400.00
0005434067577	12802	Economy	13400.00
0005434067675	12802	Economy	13400.00
0005434067050	12802	Economy	13400.00
0005432159896	12802	Economy	13400.00
0005434067382	12802	Economy	13400.00
0005434081820	12802	Economy	13400.00
0005433989769	12802	Economy	13400.00
0005434067478	12802	Economy	13400.00
0005432433720	12802	Economy	13400.00
0005434067600	12802	Economy	13400.00
0005434067383	12802	Economy	13400.00
0005434067622	12802	Economy	13400.00
0005434067659	12802	Economy	13400.00
0005434067192	12802	Economy	13400.00
0005434067509	12802	Economy	13400.00
0005433989764	12802	Economy	13400.00
0005434067542	12802	Economy	13400.00
0005434067291	12802	Economy	13400.00
0005434067735	12802	Economy	13400.00
0005434067345	12802	Economy	13400.00
0005432433721	12802	Economy	13400.00
0005434067449	12802	Economy	13400.00
0005434067262	12802	Economy	13400.00
0005434081764	12802	Economy	13400.00
0005432161170	12802	Economy	13400.00
0005434067172	12802	Economy	13400.00
0005434067339	12802	Economy	13400.00
0005434067628	12802	Economy	13400.00
0005434067660	12802	Economy	13400.00
0005434067280	12802	Economy	13400.00
0005434067649	12802	Economy	13400.00
0005432433724	12802	Economy	13400.00
0005434067451	12802	Economy	13400.00
0005434067336	12802	Economy	13400.00
0005434067430	12802	Economy	13400.00
0005434067677	12802	Economy	13400.00
0005434067246	12802	Economy	13400.00
0005434067292	12802	Economy	13400.00
0005433812919	12802	Economy	13400.00
0005434081821	12802	Economy	13400.00
0005434067624	12802	Economy	13400.00
0005434067562	12802	Economy	13400.00
0005434067051	12802	Economy	13400.00
0005434067311	12802	Economy	13400.00
0005434067344	12802	Economy	13400.00
0005434067703	12802	Economy	13400.00
0005434081840	12802	Economy	13400.00
0005432433725	12802	Economy	13400.00
0005434067687	12802	Economy	13400.00
0005433989771	12802	Economy	13400.00
0005434067274	12802	Economy	13400.00
0005434067728	12802	Economy	13400.00
0005434081843	12802	Economy	13400.00
0005432159895	12802	Economy	13400.00
0005434081837	12802	Economy	13400.00
0005434067503	12802	Economy	13400.00
0005434081834	12802	Economy	13400.00
0005434067636	12802	Economy	13400.00
0005434081845	12802	Economy	13400.00
0005434081867	12802	Economy	13400.00
0005434067559	12802	Economy	13400.00
0005434067734	12802	Economy	13400.00
0005434067450	12802	Economy	13400.00
0005432161171	12802	Economy	13400.00
0005434082072	30663	Business	40300.00
0005434068086	30663	Business	40300.00
0005434068083	30663	Business	40300.00
0005434068082	30663	Business	40300.00
0005434082078	30663	Business	40300.00
0005434068098	30663	Business	40300.00
0005434068073	30663	Business	40300.00
0005434068047	30663	Business	40300.00
0005434068109	30663	Business	40300.00
0005434068038	30663	Business	40300.00
0005434068093	30663	Business	40300.00
0005432433694	30663	Business	40300.00
0005432433674	30663	Economy	13400.00
0005434068048	30663	Economy	13400.00
0005434068087	30663	Economy	13400.00
0005433989807	30663	Economy	13400.00
0005434068074	30663	Economy	13400.00
0005434082079	30663	Economy	13400.00
0005434068045	30663	Economy	13400.00
0005434068102	30663	Economy	13400.00
0005432433691	30663	Economy	13400.00
0005434068064	30663	Economy	13400.00
0005432186895	30663	Economy	13400.00
0005432186896	30663	Economy	13400.00
0005434068078	30663	Economy	13400.00
0005434068061	30663	Economy	13400.00
0005434068095	30663	Economy	13400.00
0005434068070	30663	Economy	13400.00
0005434068050	30663	Economy	13400.00
0005434082082	30663	Economy	13400.00
0005434082064	30663	Economy	13400.00
0005432433673	30663	Economy	13400.00
0005434068099	30663	Economy	13400.00
0005434068043	30663	Economy	13400.00
0005434068103	30663	Economy	13400.00
0005434068090	30663	Economy	13400.00
0005434082081	30663	Economy	13400.00
0005433989805	30663	Economy	13400.00
0005434068069	30663	Economy	13400.00
0005434068052	30663	Economy	13400.00
0005434082065	30663	Economy	13400.00
0005434082060	30663	Economy	13400.00
0005434068071	30663	Economy	13400.00
0005434082085	30663	Economy	13400.00
0005434068079	30663	Economy	13400.00
0005434068089	30663	Economy	13400.00
0005434068042	30663	Economy	13400.00
0005432433683	30663	Economy	13400.00
0005434068065	30663	Economy	13400.00
0005434068100	30663	Economy	13400.00
0005434068105	30663	Economy	13400.00
0005432433692	30663	Economy	13400.00
0005434068104	30663	Economy	14800.00
0005434082069	30663	Economy	14800.00
0005434068077	30663	Economy	14800.00
0005434082080	30663	Economy	14800.00
0005434068060	30663	Economy	13400.00
0005434068080	30663	Economy	14800.00
0005434068108	30663	Economy	13400.00
0005432150247	30663	Economy	13400.00
0005434082066	30663	Economy	13400.00
0005434068067	30663	Economy	13400.00
0005434068094	30663	Economy	13400.00
0005432150252	30663	Economy	13400.00
0005434068068	30663	Economy	13400.00
0005432186894	30663	Economy	13400.00
0005434068054	30663	Economy	13400.00
0005434082062	30663	Economy	13400.00
0005434082068	30663	Economy	13400.00
0005434068101	30663	Economy	13400.00
0005434082070	30663	Economy	13400.00
0005434068076	30663	Economy	13400.00
0005433989804	30663	Economy	13400.00
0005434082077	30663	Economy	13400.00
0005434068096	30663	Economy	13400.00
0005434082071	30663	Economy	13400.00
0005434068097	30663	Economy	13400.00
0005434068039	30663	Economy	13400.00
0005434068041	30663	Economy	13400.00
0005434068057	30663	Economy	13400.00
0005434082061	30663	Economy	13400.00
0005434068055	30663	Economy	13400.00
0005434068046	30663	Economy	13400.00
0005434068085	30663	Economy	13400.00
0005434082073	30663	Economy	13400.00
0005434082059	30663	Economy	13400.00
0005434082075	30663	Economy	13400.00
0005434068051	30663	Economy	13400.00
0005434068059	30663	Economy	13400.00
0005434082084	30663	Economy	13400.00
0005434068084	30663	Economy	13400.00
0005434068088	30663	Economy	13400.00
0005433989806	30663	Economy	13400.00
0005434082067	30663	Economy	13400.00
0005432433672	30663	Economy	13400.00
0005434068106	30663	Economy	13400.00
0005434068066	30663	Economy	13400.00
0005434068081	30663	Economy	13400.00
0005434068063	30663	Economy	13400.00
0005434068062	30663	Economy	13400.00
0005434082087	30663	Economy	13400.00
0005433989803	30663	Economy	13400.00
0005434068107	30663	Economy	13400.00
0005434068053	30663	Economy	13400.00
0005434082083	30663	Economy	13400.00
0005432150248	30663	Economy	13400.00
0005432150254	30663	Economy	13400.00
0005432150249	30663	Economy	13400.00
0005434082088	30663	Economy	13400.00
0005434082089	30663	Economy	13400.00
0005434082063	30663	Economy	13400.00
0005432150253	30663	Economy	13400.00
0005434068044	30663	Economy	13400.00
0005434068092	30663	Economy	13400.00
0005434082076	30663	Economy	13400.00
0005434082074	30663	Economy	13400.00
0005434068075	30663	Economy	13400.00
0005434068091	30663	Economy	13400.00
0005432150250	30663	Economy	13400.00
0005434068058	30663	Economy	13400.00
0005434068040	30663	Economy	13400.00
0005434068049	30663	Economy	13400.00
0005434068072	30663	Economy	13400.00
0005434068056	30663	Economy	13400.00
0005434082086	30663	Economy	13400.00
0005432150251	30663	Economy	13400.00
0005433689899	19351	Economy	19300.00
0005433686608	19351	Economy	17600.00
0005433689909	19351	Economy	17600.00
0005433689910	19351	Economy	17600.00
0005433686629	19351	Economy	17600.00
0005433686626	19351	Economy	17600.00
0005433686625	19351	Economy	17600.00
0005433689898	19351	Economy	17600.00
0005433686630	19351	Economy	17600.00
0005433686628	19351	Economy	17600.00
0005432140516	5528	Business	35300.00
0005434265172	5528	Business	35300.00
0005434265100	5528	Business	35300.00
0005435735172	5528	Business	35300.00
0005435766701	5528	Business	35300.00
0005435766712	5528	Business	35300.00
0005435462334	5528	Business	35300.00
0005435766745	5528	Business	35300.00
0005435462365	5528	Business	35300.00
0005435766686	5528	Business	35300.00
0005435462378	5528	Business	35300.00
0005435462420	5528	Business	35300.00
0005435462358	5528	Business	35300.00
0005435766698	5528	Business	35300.00
0005432140517	5528	Business	35300.00
0005435725635	5528	Business	35300.00
0005435766751	5528	Business	35300.00
0005435735171	5528	Business	35300.00
0005435766740	5528	Business	35300.00
0005434265134	5528	Business	35300.00
0005435462338	5528	Business	35300.00
0005435766694	5528	Business	35300.00
0005435766749	5528	Business	35300.00
0005435766679	5528	Business	35300.00
0005434831159	5528	Economy	12900.00
0005435766724	5528	Economy	12900.00
0005435462459	5528	Economy	12900.00
0005435462403	5528	Economy	11800.00
0005435766747	5528	Economy	11800.00
0005435462359	5528	Economy	11800.00
0005435766731	5528	Economy	11800.00
0005435766710	5528	Economy	11800.00
0005435766682	5528	Economy	11800.00
0005435462419	5528	Economy	11800.00
0005435766690	5528	Economy	11800.00
0005435722074	5528	Economy	11800.00
0005435766722	5528	Economy	11800.00
0005433527298	5528	Economy	11800.00
0005434265230	5528	Economy	11800.00
0005434831154	5528	Economy	11800.00
0005435766742	5528	Economy	11800.00
0005435725636	5528	Economy	11800.00
0005435462443	5528	Economy	11800.00
0005435766727	5528	Economy	11800.00
0005435462390	5528	Economy	11800.00
0005435766700	5528	Economy	11800.00
0005435462450	5528	Economy	11800.00
0005434831153	5528	Economy	11800.00
0005434265096	5528	Economy	11800.00
0005435766732	5528	Economy	11800.00
0005434265030	5528	Economy	11800.00
0005435766735	5528	Economy	11800.00
0005435462479	5528	Economy	11800.00
0005434265143	5528	Economy	11800.00
0005435766693	5528	Economy	11800.00
0005435766705	5528	Economy	11800.00
0005435766750	5528	Economy	11800.00
0005435462248	5528	Economy	11800.00
0005435766729	5528	Economy	11800.00
0005435462478	5528	Economy	11800.00
0005435766677	5528	Economy	11800.00
0005435766704	5528	Economy	11800.00
0005435462511	5528	Economy	11800.00
0005434265070	5528	Economy	11800.00
0005432140509	5528	Economy	11800.00
0005435766730	5528	Economy	11800.00
0005435722075	5528	Economy	11800.00
0005435766723	5528	Economy	11800.00
0005435462533	5528	Economy	11800.00
0005435766707	5528	Economy	11800.00
0005435766738	5528	Economy	11800.00
0005435766718	5528	Economy	11800.00
0005432140515	5528	Economy	11800.00
0005434265162	5528	Economy	11800.00
0005435462389	5528	Economy	11800.00
0005435462440	5528	Economy	11800.00
0005435735170	5528	Economy	11800.00
0005435766721	5528	Economy	11800.00
0005435766728	5528	Economy	11800.00
0005435766695	5528	Economy	11800.00
0005433527299	5528	Economy	11800.00
0005435766689	5528	Economy	11800.00
0005435462354	5528	Economy	11800.00
0005435735168	5528	Economy	11800.00
0005434265232	5528	Economy	11800.00
0005435766737	5528	Economy	11800.00
0005432535805	5528	Economy	11800.00
0005435766744	5528	Economy	11800.00
0005432140514	5528	Economy	11800.00
0005435462414	5528	Economy	11800.00
0005435766684	5528	Economy	11800.00
0005435766746	5528	Economy	11800.00
0005435766713	5528	Economy	11800.00
0005435766743	5528	Economy	11800.00
0005435766748	5528	Economy	11800.00
0005435462353	5528	Economy	11800.00
0005434265098	5528	Economy	11800.00
0005435725634	5528	Economy	11800.00
0005435766687	5528	Economy	11800.00
0005435766752	5528	Economy	11800.00
0005435766736	5528	Economy	12900.00
0005435725638	5528	Economy	11800.00
0005435766726	5528	Economy	12900.00
0005435766703	5528	Economy	11800.00
0005435766692	5528	Economy	11800.00
0005435462462	5528	Economy	11800.00
0005435766719	5528	Economy	12900.00
0005435462461	5528	Economy	11800.00
0005435766734	5528	Economy	12900.00
0005435766696	5528	Economy	11800.00
0005435766706	5528	Economy	11800.00
0005434264968	5528	Economy	11800.00
0005435462510	5528	Economy	11800.00
0005434265101	5528	Economy	11800.00
0005435462396	5528	Economy	11800.00
0005435766725	5528	Economy	11800.00
0005435766715	5528	Economy	11800.00
0005434831158	5528	Economy	11800.00
0005435766678	5528	Economy	11800.00
0005435766733	5528	Economy	11800.00
0005435766702	5528	Economy	11800.00
0005435766711	5528	Economy	11800.00
0005435462493	5528	Economy	11800.00
0005434265173	5528	Economy	11800.00
0005433529310	5528	Economy	11800.00
0005435766681	5528	Economy	11800.00
0005435462418	5528	Economy	11800.00
0005434265157	5528	Economy	11800.00
0005435462439	5528	Economy	11800.00
0005435462449	5528	Economy	11800.00
0005435766680	5528	Economy	11800.00
0005435766720	5528	Economy	11800.00
0005434265147	5528	Economy	11800.00
0005435462249	5528	Economy	11800.00
0005435766697	5528	Economy	11800.00
0005434265176	5528	Economy	11800.00
0005433529309	5528	Economy	11800.00
0005435722073	5528	Economy	11800.00
0005434831152	5528	Economy	11800.00
0005434265146	5528	Economy	11800.00
0005432535806	5528	Economy	11800.00
0005435723061	5528	Economy	11800.00
0005435766699	5528	Economy	11800.00
0005432140512	5528	Economy	11800.00
0005435766716	5528	Economy	11800.00
0005435766714	5528	Economy	11800.00
0005434265231	5528	Economy	11800.00
0005434265097	5528	Economy	11800.00
0005435766708	5528	Economy	11800.00
0005435766688	5528	Economy	11800.00
0005432140511	5528	Economy	11800.00
0005432140513	5528	Economy	11800.00
0005435766717	5528	Economy	11800.00
0005435766709	5528	Economy	11800.00
0005435725637	5528	Economy	11800.00
0005434265140	5528	Economy	11800.00
0005435766739	5528	Economy	11800.00
0005435766685	5528	Economy	11800.00
0005435766741	5528	Economy	11800.00
0005433529308	5528	Economy	11800.00
0005433529311	5528	Economy	11800.00
0005435735169	5528	Economy	11800.00
0005435766691	5528	Economy	11800.00
0005432140510	5528	Economy	11800.00
0005435766683	5528	Economy	11800.00
0005435462761	13487	Business	35300.00
0005434265349	13487	Business	35300.00
0005434265338	13487	Business	35300.00
0005432194546	13487	Business	35300.00
0005435766189	13487	Business	35300.00
0005435725580	13487	Business	35300.00
0005435462759	13487	Business	35300.00
0005435766052	13487	Business	35300.00
0005434831189	13487	Business	35300.00
0005435766114	13487	Business	35300.00
0005432535873	13487	Business	35300.00
0005435766070	13487	Business	35300.00
0005435462750	13487	Business	35300.00
0005435766020	13487	Business	35300.00
0005435766138	13487	Business	35300.00
0005435766191	13487	Business	35300.00
0005434265355	13487	Business	35300.00
0005434265351	13487	Business	35300.00
0005435462756	13487	Business	35300.00
0005434265342	13487	Business	35300.00
0005433533296	13487	Economy	12900.00
0005435766067	13487	Business	35300.00
0005433529274	13487	Economy	12900.00
0005432194543	13487	Economy	11800.00
0005433533297	13487	Economy	11800.00
0005435766068	13487	Economy	11800.00
0005435722054	13487	Economy	11800.00
0005433533285	13487	Economy	11800.00
0005435766054	13487	Economy	11800.00
0005433533286	13487	Economy	11800.00
0005434831191	13487	Economy	11800.00
0005435766013	13487	Economy	11800.00
0005434265360	13487	Economy	11800.00
0005435462736	13487	Economy	11800.00
0005432194545	13487	Economy	11800.00
0005435462757	13487	Economy	11800.00
0005435766218	13487	Economy	11800.00
0005434265347	13487	Economy	11800.00
0005435462735	13487	Economy	11800.00
0005434265352	13487	Economy	11800.00
0005434265358	13487	Economy	11800.00
0005434831190	13487	Economy	11800.00
0005435462728	13487	Economy	11800.00
0005435765979	13487	Economy	11800.00
0005435766028	13487	Economy	11800.00
0005434831192	13487	Economy	11800.00
0005435765840	13487	Economy	11800.00
0005434265363	13487	Economy	11800.00
0005435765933	13487	Economy	11800.00
0005435462726	13487	Economy	11800.00
0005432535875	13487	Economy	11800.00
0005435462751	13487	Economy	11800.00
0005435765778	13487	Economy	11800.00
0005435462740	13487	Economy	11800.00
0005435462747	13487	Economy	11800.00
0005435766174	13487	Economy	11800.00
0005434265344	13487	Economy	11800.00
0005433533292	13487	Economy	11800.00
0005435765937	13487	Economy	11800.00
0005434831188	13487	Economy	11800.00
0005434265353	13487	Economy	11800.00
0005435766017	13487	Economy	11800.00
0005434265362	13487	Economy	11800.00
0005435765849	13487	Economy	11800.00
0005435766217	13487	Economy	11800.00
0005435766124	13487	Economy	11800.00
0005432535872	13487	Economy	11800.00
0005435462737	13487	Economy	11800.00
0005434265343	13487	Economy	11800.00
0005434265346	13487	Economy	11800.00
0005433529265	13487	Economy	11800.00
0005435723033	13487	Economy	11800.00
0005435766188	13487	Economy	11800.00
0005435462760	13487	Economy	11800.00
0005434265356	13487	Economy	11800.00
0005435462731	13487	Economy	11800.00
0005434265348	13487	Economy	11800.00
0005435462733	13487	Economy	11800.00
0005433533308	13487	Economy	11800.00
0005434265340	13487	Economy	11800.00
0005435765726	13487	Economy	11800.00
0005435766098	13487	Economy	11800.00
0005433529258	13487	Economy	11800.00
0005435462730	13487	Economy	11800.00
0005433533291	13487	Economy	11800.00
0005435766190	13487	Economy	11800.00
0005435617173	13487	Economy	11800.00
0005435462741	13487	Economy	11800.00
0005435766019	13487	Economy	11800.00
0005435462754	13487	Economy	11800.00
0005435462738	13487	Economy	11800.00
0005433529257	13487	Economy	11800.00
0005435766066	13487	Economy	11800.00
0005435462724	13487	Economy	11800.00
0005435766113	13487	Economy	11800.00
0005433533287	13487	Economy	11800.00
0005433529249	13487	Economy	12900.00
0005432194544	13487	Economy	12900.00
0005435462723	13487	Economy	11800.00
0005435462752	13487	Economy	11800.00
0005434265339	13487	Economy	12900.00
0005435725581	13487	Economy	12900.00
0005435766069	13487	Economy	11800.00
0005435765998	13487	Economy	11800.00
0005435765898	13487	Economy	11800.00
0005434265354	13487	Economy	11800.00
0005433529259	13487	Economy	11800.00
0005434265345	13487	Economy	11800.00
0005433529268	13487	Economy	11800.00
0005435462744	13487	Economy	11800.00
0005435766219	13487	Economy	11800.00
0005435765943	13487	Economy	11800.00
0005434265337	13487	Economy	11800.00
0005435723034	13487	Economy	11800.00
0005434265357	13487	Economy	11800.00
0005435462755	13487	Economy	11800.00
0005435765841	13487	Economy	11800.00
0005435462743	13487	Economy	11800.00
0005435462739	13487	Economy	11800.00
0005433529266	13487	Economy	11800.00
0005435462753	13487	Economy	11800.00
0005435462727	13487	Economy	11800.00
0005434265361	13487	Economy	11800.00
0005435462734	13487	Economy	11800.00
0005435766182	13487	Economy	11800.00
0005433529273	13487	Economy	11800.00
0005432535874	13487	Economy	11800.00
0005435462725	13487	Economy	11800.00
0005435766000	13487	Economy	11800.00
0005435766065	13487	Economy	11800.00
0005434265341	13487	Economy	11800.00
0005435462732	13487	Economy	11800.00
0005435462758	13487	Economy	11800.00
0005433533298	13487	Economy	11800.00
0005433529267	13487	Economy	11800.00
0005435766055	13487	Economy	11800.00
0005435725569	13487	Economy	11800.00
0005435462729	13487	Economy	11800.00
0005433533293	13487	Economy	11800.00
0005435462746	13487	Economy	11800.00
0005435722051	13487	Economy	11800.00
0005435462748	13487	Economy	11800.00
0005435766018	13487	Economy	11800.00
0005434265359	13487	Economy	11800.00
0005435765853	13487	Economy	11800.00
0005435462749	13487	Economy	11800.00
0005435765999	13487	Economy	11800.00
0005433533299	13487	Economy	11800.00
0005435765944	13487	Economy	11800.00
0005433529269	13487	Economy	11800.00
0005435725586	13487	Economy	11800.00
0005435725579	13487	Economy	11800.00
0005435766021	13487	Economy	11800.00
0005434265350	13487	Economy	11800.00
0005435462742	13487	Economy	11800.00
0005435766123	13487	Economy	11800.00
0005435766080	13487	Economy	11800.00
0005435723046	13487	Economy	11800.00
0005433533307	13487	Economy	11800.00
0005435462745	13487	Economy	11800.00
0005434602889	18728	Economy	3300.00
0005434513599	18721	Economy	3300.00
0005434513598	18721	Economy	3300.00
0005434604890	18721	Economy	3300.00
0005434604900	18721	Economy	3300.00
0005435904708	18721	Economy	3300.00
0005434514986	18721	Economy	3300.00
0005434514987	18721	Economy	3300.00
0005434513600	18721	Economy	3300.00
0005434604903	18721	Economy	3300.00
0005434514969	19134	Economy	3300.00
0005434514965	19134	Economy	3300.00
0005434514970	19134	Economy	3300.00
0005434514962	19134	Economy	3300.00
0005432632783	4127	Business	88300.00
0005435844310	4127	Business	88300.00
0005435846263	4127	Business	88300.00
0005435844318	4127	Business	88300.00
0005435846234	4127	Business	88300.00
0005432649443	4127	Business	88300.00
0005435846264	4127	Business	88300.00
0005432632788	4127	Business	88300.00
0005432632797	4127	Business	88300.00
0005435846243	4127	Business	88300.00
0005432649444	4127	Business	88300.00
0005435846247	4127	Economy	29400.00
0005432632796	4127	Economy	29400.00
0005435846255	4127	Economy	29400.00
0005435844305	4127	Economy	29400.00
0005435846218	4127	Economy	29400.00
0005435846241	4127	Economy	29400.00
0005435846242	4127	Economy	29400.00
0005432632804	4127	Economy	32400.00
0005432632791	4127	Economy	32400.00
0005432649438	4127	Economy	29400.00
0005432632803	4127	Economy	29400.00
0005432649449	4127	Economy	29400.00
0005432649448	4127	Economy	29400.00
0005435844294	4127	Economy	29400.00
0005432632801	4127	Economy	29400.00
0005435846246	4127	Economy	29400.00
0005432632793	4127	Economy	29400.00
0005432632789	4127	Economy	29400.00
0005432649456	4127	Economy	29400.00
0005432632792	4127	Economy	29400.00
0005432649455	4127	Economy	29400.00
0005432649442	4127	Economy	29400.00
0005432632786	4127	Economy	29400.00
0005435846259	4127	Economy	29400.00
0005432632795	4127	Economy	29400.00
0005435846260	4127	Economy	29400.00
0005432649446	4127	Economy	29400.00
0005432649447	4127	Economy	29400.00
0005435846222	4127	Economy	29400.00
0005432632794	4127	Economy	29400.00
0005432649440	4127	Economy	29400.00
0005432632790	4127	Economy	29400.00
0005432649454	4127	Economy	29400.00
0005435844293	4127	Economy	29400.00
0005432649441	4127	Economy	29400.00
0005432632785	4127	Economy	29400.00
0005435844292	4127	Economy	29400.00
0005432632784	4127	Economy	29400.00
0005432632787	4127	Economy	29400.00
0005435844317	4127	Economy	29400.00
0005432632798	4127	Economy	29400.00
0005432649450	4127	Economy	29400.00
0005432632799	4127	Economy	29400.00
0005435846240	4127	Economy	29400.00
0005432649452	4127	Economy	29400.00
0005432632802	4127	Economy	29400.00
0005432649453	4127	Economy	29400.00
0005432649451	4127	Economy	29400.00
0005432649445	4127	Economy	29400.00
0005435844316	4127	Economy	29400.00
0005432649439	4127	Economy	29400.00
0005432632800	4127	Economy	29400.00
0005435846244	4127	Economy	29400.00
0005433285406	1842	Business	48700.00
0005433285126	1842	Business	48700.00
0005433285391	1842	Business	48700.00
0005433008541	1842	Business	48700.00
0005433008655	1842	Business	48700.00
0005433285207	1842	Business	48700.00
0005433285317	1842	Business	48700.00
0005433008656	1842	Business	48700.00
0005433285286	1842	Business	48700.00
0005433285293	1842	Business	48700.00
0005433285246	1842	Business	48700.00
0005433285328	1842	Business	48700.00
0005433008658	1842	Economy	16200.00
0005433008735	1842	Economy	16200.00
0005433008775	1842	Economy	16200.00
0005432295901	1842	Economy	16200.00
0005433008396	1842	Economy	16200.00
0005433285174	1842	Economy	16200.00
0005433008595	1842	Economy	16200.00
0005433008774	1842	Economy	16200.00
0005433008442	1842	Economy	16200.00
0005433008616	1842	Economy	16200.00
0005433285206	1842	Economy	17900.00
0005433008560	1842	Economy	17900.00
0005432295900	1842	Economy	17900.00
0005433008530	1842	Economy	17900.00
0005433285124	1842	Economy	17900.00
0005433008615	1842	Economy	16200.00
0005433008657	1842	Economy	16200.00
0005433285218	1842	Economy	16200.00
0005433008750	1842	Economy	16200.00
0005433285351	1842	Economy	16200.00
0005433008379	1842	Economy	16200.00
0005433285347	1842	Economy	16200.00
0005433285312	1842	Economy	16200.00
0005433008882	1842	Economy	16200.00
0005433008883	1842	Economy	16200.00
0005433008626	1842	Economy	16200.00
0005433008666	1842	Economy	16200.00
0005433008316	1842	Economy	16200.00
0005433008676	1842	Economy	16200.00
0005433008559	1842	Economy	16200.00
0005433285407	1842	Economy	16200.00
0005433285341	1842	Economy	16200.00
0005433008474	1842	Economy	16200.00
0005433285242	1842	Economy	16200.00
0005433008481	1842	Economy	16200.00
0005433008734	1842	Economy	16200.00
0005433008495	1842	Economy	16200.00
0005433285346	1842	Economy	16200.00
0005433285291	1842	Economy	16200.00
0005433285390	1842	Economy	16200.00
0005433008545	1842	Economy	16200.00
0005433285294	1842	Economy	16200.00
0005433008745	1842	Economy	16200.00
0005433008544	1842	Economy	16200.00
0005433285234	1842	Economy	16200.00
0005433008683	1842	Economy	16200.00
0005433008682	1842	Economy	16200.00
0005433008589	1842	Economy	16200.00
0005433285321	1842	Economy	16200.00
0005433285348	1842	Economy	16200.00
0005433008508	1842	Economy	16200.00
0005433285352	1842	Economy	16200.00
0005433285315	1842	Economy	16200.00
0005433285240	1842	Economy	16200.00
0005433008482	1842	Economy	16200.00
0005433285292	1842	Economy	16200.00
0005433008555	1842	Economy	16200.00
0005433285327	1842	Economy	16200.00
0005433285123	1842	Economy	16200.00
0005433008685	1842	Economy	16200.00
0005433285331	1842	Economy	16200.00
0005433285125	1842	Economy	16200.00
0005433008776	1842	Economy	16200.00
0005433285376	1842	Economy	16200.00
0005433008496	1842	Economy	16200.00
0005433285345	1842	Economy	16200.00
0005433008501	1842	Economy	16200.00
0005433008727	1842	Economy	16200.00
0005433285214	1842	Economy	16200.00
0005433008713	1842	Economy	16200.00
0005433008550	1842	Economy	16200.00
0005433285247	1842	Economy	16200.00
0005433285217	1842	Economy	16200.00
0005433008538	1842	Economy	16200.00
0005433008746	1842	Economy	16200.00
0005433008502	1842	Economy	16200.00
0005433285349	1842	Economy	16200.00
0005433008536	1842	Economy	16200.00
0005432295902	1842	Economy	16200.00
0005433285222	1842	Economy	16200.00
0005433008623	1842	Economy	16200.00
0005433285324	1842	Economy	16200.00
0005433285316	1842	Economy	16200.00
0005433008580	1842	Economy	16200.00
0005433008575	1842	Economy	16200.00
0005433008958	22553	Business	48700.00
0005433285548	22553	Business	48700.00
0005433008956	22553	Business	48700.00
0005433285525	22553	Business	48700.00
0005433008979	22553	Business	48700.00
0005433008972	22553	Business	48700.00
0005433285543	22553	Business	48700.00
0005433008944	22553	Business	48700.00
0005433285530	22553	Business	48700.00
0005433008975	22553	Business	48700.00
0005433008965	22553	Business	48700.00
0005433285527	22553	Economy	16200.00
0005433285542	22553	Economy	16200.00
0005433008949	22553	Economy	16200.00
0005433008968	22553	Economy	16200.00
0005433008953	22553	Economy	16200.00
0005433810528	22553	Economy	16200.00
0005433285528	22553	Economy	16200.00
0005433285545	22553	Economy	16200.00
0005433285540	22553	Economy	16200.00
0005433285541	22553	Economy	17900.00
0005433285546	22553	Economy	17900.00
0005433008980	22553	Economy	17900.00
0005433008971	22553	Economy	17900.00
0005433285538	22553	Economy	17900.00
0005433285535	22553	Economy	16200.00
0005433008976	22553	Economy	16200.00
0005433008967	22553	Economy	16200.00
0005433008945	22553	Economy	16200.00
0005433285519	22553	Economy	16200.00
0005433008970	22553	Economy	16200.00
0005433810523	22553	Economy	16200.00
0005433008962	22553	Economy	16200.00
0005433285549	22553	Economy	16200.00
0005433285521	22553	Economy	16200.00
0005433008950	22553	Economy	16200.00
0005433008981	22553	Economy	16200.00
0005433008964	22553	Economy	16200.00
0005433008939	22553	Economy	16200.00
0005433285544	22553	Economy	16200.00
0005433008938	22553	Economy	16200.00
0005433285539	22553	Economy	16200.00
0005433285532	22553	Economy	16200.00
0005433285536	22553	Economy	16200.00
0005433008969	22553	Economy	16200.00
0005433285537	22553	Economy	16200.00
0005433008946	22553	Economy	16200.00
0005433008955	22553	Economy	16200.00
0005433008942	22553	Economy	16200.00
0005433008973	22553	Economy	16200.00
0005433285518	22553	Economy	16200.00
0005433008941	22553	Economy	16200.00
0005433285523	22553	Economy	16200.00
0005433008947	22553	Economy	16200.00
0005433008951	22553	Economy	16200.00
0005433008960	22553	Economy	16200.00
0005433008943	22553	Economy	16200.00
0005433008952	22553	Economy	16200.00
0005433008966	22553	Economy	16200.00
0005433008940	22553	Economy	16200.00
0005433810527	22553	Economy	16200.00
0005433008954	22553	Economy	16200.00
0005433285526	22553	Economy	16200.00
0005433285550	22553	Economy	16200.00
0005433285533	22553	Economy	16200.00
0005433285534	22553	Economy	16200.00
0005433008961	22553	Economy	16200.00
0005433285524	22553	Economy	16200.00
0005433008963	22553	Economy	16200.00
0005433008977	22553	Economy	16200.00
0005433008959	22553	Economy	16200.00
0005433285547	22553	Economy	16200.00
0005433008948	22553	Economy	16200.00
0005433008957	22553	Economy	16200.00
0005433810522	22553	Economy	16200.00
0005433285522	22553	Economy	16200.00
0005433285529	22553	Economy	16200.00
0005433008974	22553	Economy	16200.00
0005433285520	22553	Economy	16200.00
0005433008978	22553	Economy	16200.00
0005433285531	22553	Economy	16200.00
0005434173487	5551	Business	99800.00
0005433815424	5551	Business	99800.00
0005435282542	5551	Business	99800.00
0005433847186	5551	Business	99800.00
0005433847203	5551	Business	99800.00
0005435282468	5551	Business	99800.00
0005433847202	5551	Business	99800.00
0005433847201	5551	Business	99800.00
0005433847170	5551	Business	99800.00
0005435282526	5551	Business	99800.00
0005433847191	5551	Business	99800.00
0005433847211	5551	Business	99800.00
0005433847215	5551	Business	99800.00
0005433847182	5551	Business	99800.00
0005435282541	5551	Business	99800.00
0005433847204	5551	Business	99800.00
0005433847189	5551	Economy	33300.00
0005433847167	5551	Economy	33300.00
0005433847193	5551	Economy	33300.00
0005433847192	5551	Economy	33300.00
0005435282550	5551	Economy	33300.00
0005433847195	5551	Economy	33300.00
0005433847160	5551	Economy	33300.00
0005433847205	5551	Economy	33300.00
0005433847199	5551	Economy	33300.00
0005433847166	5551	Economy	33300.00
0005433847158	5551	Economy	33300.00
0005433847162	5551	Economy	33300.00
0005432081564	5551	Economy	33300.00
0005432081561	5551	Economy	36600.00
0005433847206	5551	Economy	36600.00
0005434173497	5551	Economy	36600.00
0005435282563	5551	Economy	33300.00
0005433847198	5551	Economy	36600.00
0005432081566	5551	Economy	33300.00
0005432081563	5551	Economy	33300.00
0005433847165	5551	Economy	33300.00
0005435282558	5551	Economy	33300.00
0005435282459	5551	Economy	33300.00
0005433847208	5551	Economy	33300.00
0005435282405	5551	Economy	33300.00
0005433847163	5551	Economy	33300.00
0005433847180	5551	Economy	33300.00
0005433847174	5551	Economy	33300.00
0005433847187	5551	Economy	33300.00
0005435282460	5551	Economy	33300.00
0005435282450	5551	Economy	33300.00
0005435282559	5551	Economy	33300.00
0005433847200	5551	Economy	33300.00
0005433847188	5551	Economy	33300.00
0005433847209	5551	Economy	33300.00
0005434173512	5551	Economy	33300.00
0005433847197	5551	Economy	33300.00
0005433847171	5551	Economy	33300.00
0005435282350	5551	Economy	33300.00
0005434173499	5551	Economy	33300.00
0005433847175	5551	Economy	33300.00
0005433847217	5551	Economy	33300.00
0005434173486	5551	Economy	33300.00
0005433847168	5551	Economy	33300.00
0005433847207	5551	Economy	33300.00
0005435282557	5551	Economy	33300.00
0005433847216	5551	Economy	33300.00
0005432081562	5551	Economy	33300.00
0005433815422	5551	Economy	33300.00
0005433815421	5551	Economy	33300.00
0005433847181	5551	Economy	33300.00
0005432081565	5551	Economy	33300.00
0005433847177	5551	Economy	33300.00
0005433847178	5551	Economy	33300.00
0005433847179	5551	Economy	33300.00
0005435282496	5551	Economy	33300.00
0005435282533	5551	Economy	33300.00
0005433847214	5551	Economy	33300.00
0005433847212	5551	Economy	33300.00
0005433847194	5551	Economy	33300.00
0005433847185	5551	Economy	33300.00
0005435282466	5551	Economy	33300.00
0005433847169	5551	Economy	33300.00
0005435282470	5551	Economy	33300.00
0005435282471	5551	Economy	33300.00
0005433847157	5551	Economy	33300.00
0005433847183	5551	Economy	33300.00
0005433847161	5551	Economy	33300.00
0005433847173	5551	Economy	33300.00
0005434173517	5551	Economy	33300.00
0005435282551	5551	Economy	33300.00
0005433847213	5551	Economy	33300.00
0005433847184	5551	Economy	33300.00
0005433815423	5551	Economy	33300.00
0005434173496	5551	Economy	33300.00
0005435282404	5551	Economy	33300.00
0005433847210	5551	Economy	33300.00
0005433847159	5551	Economy	33300.00
0005433847190	5551	Economy	33300.00
0005433847164	5551	Economy	33300.00
0005432081560	5551	Economy	33300.00
0005433847196	5551	Economy	33300.00
0005435282497	5551	Economy	33300.00
0005435282532	5551	Economy	33300.00
0005433847172	5551	Economy	33300.00
0005433847176	5551	Economy	33300.00
0005435282467	5551	Economy	33300.00
0005434173522	5551	Economy	33300.00
0005435282607	5551	Economy	33300.00
0005434173523	5551	Economy	33300.00
0005433815420	5551	Economy	33300.00
0005435282560	5551	Economy	33300.00
0005433846457	13876	Business	99800.00
0005435282725	13876	Business	99800.00
0005433846766	13876	Business	99800.00
0005435282712	13876	Business	99800.00
0005433846675	13876	Business	99800.00
0005433846732	13876	Business	99800.00
0005433846615	13876	Business	99800.00
0005433846949	13876	Business	99800.00
0005435282716	13876	Business	99800.00
0005433846528	13876	Business	99800.00
0005435282724	13876	Business	99800.00
0005433846920	13876	Business	99800.00
0005433846682	13876	Economy	33300.00
0005433846640	13876	Business	99800.00
0005435282730	13876	Economy	33300.00
0005434173552	13876	Economy	33300.00
0005433846674	13876	Economy	33300.00
0005433846699	13876	Economy	33300.00
0005433846756	13876	Economy	33300.00
0005435282720	13876	Economy	33300.00
0005433815367	13876	Economy	33300.00
0005433846999	13876	Economy	33300.00
0005433846652	13876	Economy	33300.00
0005435282722	13876	Economy	33300.00
0005433846603	13876	Economy	36600.00
0005432003727	13876	Economy	36600.00
0005432003726	13876	Economy	33300.00
0005435282711	13876	Economy	33300.00
0005433846620	13876	Economy	33300.00
0005433846843	13876	Economy	33300.00
0005435282729	13876	Economy	33300.00
0005433846735	13876	Economy	33300.00
0005433846629	13876	Economy	33300.00
0005433846664	13876	Economy	33300.00
0005433846811	13876	Economy	33300.00
0005433846702	13876	Economy	33300.00
0005435282704	13876	Economy	33300.00
0005435282717	13876	Economy	33300.00
0005433846876	13876	Economy	33300.00
0005435282721	13876	Economy	33300.00
0005433846812	13876	Economy	33300.00
0005433846697	13876	Economy	33300.00
0005433846942	13876	Economy	33300.00
0005433846493	13876	Economy	33300.00
0005434173553	13876	Economy	33300.00
0005433846673	13876	Economy	33300.00
0005433846875	13876	Economy	33300.00
0005433815374	13876	Economy	33300.00
0005435282707	13876	Economy	33300.00
0005433846968	13876	Economy	33300.00
0005433846998	13876	Economy	33300.00
0005435282719	13876	Economy	33300.00
0005433846606	13876	Economy	33300.00
0005433815383	13876	Economy	33300.00
0005433846706	13876	Economy	33300.00
0005435282718	13876	Economy	33300.00
0005433846802	13876	Economy	33300.00
0005433846637	13876	Economy	33300.00
0005435282714	13876	Economy	33300.00
0005433846659	13876	Economy	33300.00
0005435282731	13876	Economy	33300.00
0005433846874	13876	Economy	33300.00
0005433846730	13876	Economy	33300.00
0005433846522	13876	Economy	33300.00
0005433846660	13876	Economy	33300.00
0005435282708	13876	Economy	33300.00
0005433846696	13876	Economy	33300.00
0005434173554	13876	Economy	33300.00
0005433846722	13876	Economy	33300.00
0005433846705	13876	Economy	33300.00
0005435282727	13876	Economy	33300.00
0005433846700	13876	Economy	33300.00
0005433846592	13876	Economy	33300.00
0005435282723	13876	Economy	33300.00
0005433846596	13876	Economy	33300.00
0005433846527	13876	Economy	33300.00
0005435282706	13876	Economy	33300.00
0005435282713	13876	Economy	33300.00
0005435282710	13876	Economy	33300.00
0005435282715	13876	Economy	33300.00
0005433846639	13876	Economy	33300.00
0005433846458	13876	Economy	33300.00
0005433846688	13876	Economy	33300.00
0005435282726	13876	Economy	33300.00
0005435282728	13876	Economy	33300.00
0005435282705	13876	Economy	33300.00
0005435282703	13876	Economy	33300.00
0005433815378	13876	Economy	33300.00
0005433846943	13876	Economy	33300.00
0005433815379	13876	Economy	33300.00
0005435282709	13876	Economy	33300.00
0005433846523	13876	Economy	33300.00
0005434620761	7834	Economy	16600.00
0005434620752	7834	Economy	16600.00
0005434620751	7834	Economy	16600.00
0005435332329	7834	Economy	16600.00
0005435332361	7834	Economy	15100.00
0005435332381	7834	Economy	15100.00
0005435332347	7834	Economy	15100.00
0005434620755	7834	Economy	15100.00
0005434620748	7834	Economy	15100.00
0005435332340	7834	Economy	15100.00
0005435332351	7834	Economy	15100.00
0005434620763	7834	Economy	15100.00
0005434620758	7834	Economy	15100.00
0005434620762	7834	Economy	15100.00
0005434620756	7834	Economy	15100.00
0005434620765	7834	Economy	15100.00
0005432112533	7834	Economy	15100.00
0005434620750	7834	Economy	15100.00
0005435332336	7834	Economy	15100.00
0005435332328	7834	Economy	15100.00
0005434620754	7834	Economy	15100.00
0005434620760	7834	Economy	15100.00
0005434620768	7834	Economy	15100.00
0005435332382	7834	Economy	15100.00
0005434620766	7834	Economy	15100.00
0005434620767	7834	Economy	15100.00
0005434620757	7834	Economy	15100.00
0005434620753	7834	Economy	15100.00
0005435332341	7834	Economy	15100.00
0005435332335	7834	Economy	15100.00
0005435332360	7834	Economy	15100.00
0005435332354	7834	Economy	15100.00
0005434620764	7834	Economy	15100.00
0005432112534	7834	Economy	15100.00
0005434620749	7834	Economy	15100.00
0005435332309	7834	Economy	15100.00
0005435332310	7834	Economy	15100.00
0005434620759	7834	Economy	15100.00
0005435332364	7834	Economy	15100.00
0005435332363	7834	Economy	15100.00
0005435332418	32942	Economy	16600.00
0005434620594	32942	Economy	16600.00
0005435332419	32942	Economy	16600.00
0005435332420	32942	Economy	15100.00
0005434620568	32942	Economy	15100.00
0005435332421	32942	Economy	15100.00
0005434620567	32942	Economy	15100.00
0005435332416	32942	Economy	15100.00
0005434620681	32942	Economy	15100.00
0005434620622	32942	Economy	15100.00
0005435332417	32942	Economy	15100.00
0005435332415	32942	Economy	15100.00
0005434620612	32942	Economy	15100.00
0005434620597	32942	Economy	15100.00
0005434620525	32942	Economy	15100.00
0005434620627	32942	Economy	15100.00
0005435332412	32942	Economy	15100.00
0005434620682	32942	Economy	15100.00
0005434620611	32942	Economy	15100.00
0005434620534	32942	Economy	15100.00
0005435332414	32942	Economy	15100.00
0005434620572	32942	Economy	15100.00
0005435332423	32942	Economy	15100.00
0005434620623	32942	Economy	15100.00
0005434620565	32942	Economy	15100.00
0005434620598	32942	Economy	15100.00
0005434620558	32942	Economy	15100.00
0005434620533	32942	Economy	15100.00
0005434620532	32942	Economy	15100.00
0005435332422	32942	Economy	15100.00
0005435332413	32942	Economy	15100.00
0005434620596	32942	Economy	15100.00
0005434620524	32942	Economy	15100.00
0005434620535	32942	Economy	15100.00
0005434620593	32942	Economy	15100.00
0005434620646	32942	Economy	15100.00
0005435785617	4289	Business	38000.00
0005435785646	4289	Business	38000.00
0005435785618	4289	Business	38000.00
0005435785631	4289	Business	38000.00
0005435785622	4289	Business	38000.00
0005434994100	4289	Economy	12700.00
0005435937388	4289	Economy	12700.00
0005435785634	4289	Economy	12700.00
0005435785648	4289	Economy	12700.00
0005435785628	4289	Economy	12700.00
0005432190658	4289	Economy	13900.00
0005435785632	4289	Economy	13900.00
0005435937387	4289	Economy	13900.00
0005435785638	4289	Economy	13900.00
0005435785616	4289	Economy	13900.00
0005435785630	4289	Economy	12700.00
0005435785627	4289	Economy	12700.00
0005435785620	4289	Economy	12700.00
0005435785623	4289	Economy	12700.00
0005435785625	4289	Economy	12700.00
0005435785633	4289	Economy	12700.00
0005435785642	4289	Economy	12700.00
0005435785615	4289	Economy	12700.00
0005434994096	4289	Economy	12700.00
0005435937379	4289	Economy	12700.00
0005434994104	4289	Economy	12700.00
0005435937378	4289	Economy	12700.00
0005435785626	4289	Economy	12700.00
0005434994098	4289	Economy	12700.00
0005435785645	4289	Economy	12700.00
0005434994102	4289	Economy	12700.00
0005434994103	4289	Economy	12700.00
0005435785644	4289	Economy	12700.00
0005435785641	4289	Economy	12700.00
0005435785629	4289	Economy	12700.00
0005435785635	4289	Economy	12700.00
0005432190660	4289	Economy	12700.00
0005434994097	4289	Economy	12700.00
0005435785636	4289	Economy	12700.00
0005435785621	4289	Economy	12700.00
0005432190661	4289	Economy	12700.00
0005435785647	4289	Economy	12700.00
0005435918679	4289	Economy	12700.00
0005435785637	4289	Economy	12700.00
0005435785619	4289	Economy	12700.00
0005434994101	4289	Economy	12700.00
0005435785614	4289	Economy	12700.00
0005432190659	4289	Economy	12700.00
0005435785624	4289	Economy	12700.00
0005435937368	4289	Economy	12700.00
0005435785639	4289	Economy	12700.00
0005435785643	4289	Economy	12700.00
0005435937375	4289	Economy	12700.00
0005435785640	4289	Economy	12700.00
0005434994099	4289	Economy	12700.00
0005435787371	4289	Economy	12700.00
0005434993968	27332	Business	38000.00
0005435785130	27332	Business	38000.00
0005435785296	27332	Business	38000.00
0005435785251	27332	Business	38000.00
0005435785287	27332	Business	38000.00
0005435918693	27332	Economy	12700.00
0005435785309	27332	Economy	12700.00
0005434994004	27332	Economy	12700.00
0005434994043	27332	Economy	12700.00
0005435785294	27332	Economy	12700.00
0005435785289	27332	Economy	12700.00
0005435785283	27332	Economy	13900.00
0005435785282	27332	Economy	13900.00
0005435787347	27332	Economy	13900.00
0005435785203	27332	Economy	12700.00
0005434993999	27332	Economy	12700.00
0005435918695	27332	Economy	12700.00
0005435785301	27332	Economy	12700.00
0005435785290	27332	Economy	12700.00
0005434994027	27332	Economy	12700.00
0005434994019	27332	Economy	12700.00
0005434994023	27332	Economy	12700.00
0005435785260	27332	Economy	12700.00
0005435785181	27332	Economy	12700.00
0005435785150	27332	Economy	12700.00
0005435937411	27332	Economy	12700.00
0005435918692	27332	Economy	12700.00
0005435785204	27332	Economy	12700.00
0005434994028	27332	Economy	12700.00
0005434994005	27332	Economy	12700.00
0005435785070	27332	Economy	12700.00
0005435918694	27332	Economy	12700.00
0005435785375	27332	Economy	12700.00
0005435937413	27332	Economy	12700.00
0005435785295	27332	Economy	12700.00
0005435785199	27332	Economy	12700.00
0005435785268	27332	Economy	12700.00
0005434993998	27332	Economy	12700.00
0005435937415	27332	Economy	12700.00
0005435785286	27332	Economy	12700.00
0005432195708	27332	Economy	12700.00
0005435937412	27332	Economy	12700.00
0005435937414	27332	Economy	12700.00
0005435785149	27332	Economy	12700.00
0005435787348	27332	Economy	12700.00
0005435785242	27332	Economy	12700.00
0005435785298	27332	Economy	12700.00
0005435785293	27332	Economy	12700.00
0005432195709	27332	Economy	12700.00
0005435785224	27332	Economy	12700.00
0005435937410	27332	Economy	12700.00
0005435785261	27332	Economy	12700.00
0005435785337	27332	Economy	12700.00
0005435918691	27332	Economy	12700.00
0005432146214	19896	Economy	12800.00
0005434082108	4696	Business	40900.00
0005432568098	4696	Business	40900.00
0005432460244	4696	Business	40900.00
0005432571351	4696	Business	40900.00
0005432186898	4696	Business	40900.00
0005432460247	4696	Business	40900.00
0005432170438	4696	Business	40900.00
0005432170439	4696	Business	40900.00
0005432568099	4696	Business	40900.00
0005432571352	4696	Business	40900.00
0005432170440	4696	Business	40900.00
0005432460288	4696	Business	40900.00
0005432568107	4696	Business	40900.00
0005432460276	4696	Business	40900.00
0005432460238	4696	Business	40900.00
0005432460272	4696	Business	40900.00
0005432568140	4696	Business	40900.00
0005432460284	4696	Business	40900.00
0005432568142	4696	Business	40900.00
0005432460289	4696	Business	40900.00
0005432170443	4696	Business	40900.00
0005432568127	4696	Business	40900.00
0005432460278	4696	Business	40900.00
0005432460281	4696	Economy	15000.00
0005432568094	4696	Business	40900.00
0005434082098	4696	Economy	15000.00
0005432460291	4696	Economy	13600.00
0005432460287	4696	Economy	15000.00
0005434082104	4696	Economy	13600.00
0005432186897	4696	Economy	13600.00
0005433452756	4696	Economy	13600.00
0005432460255	4696	Economy	13600.00
0005432460266	4696	Economy	13600.00
0005433451636	4696	Economy	13600.00
0005432568104	4696	Economy	13600.00
0005432568103	4696	Economy	13600.00
0005432568101	4696	Economy	13600.00
0005433452755	4696	Economy	13600.00
0005432568130	4696	Economy	13600.00
0005432460275	4696	Economy	13600.00
0005434559103	4696	Economy	13600.00
0005432568112	4696	Economy	13600.00
0005432460283	4696	Economy	13600.00
0005432460268	4696	Economy	13600.00
0005432568092	4696	Economy	13600.00
0005432568091	4696	Economy	13600.00
0005432568137	4696	Economy	13600.00
0005432460261	4696	Economy	13600.00
0005434082103	4696	Economy	13600.00
0005432170442	4696	Economy	13600.00
0005432568118	4696	Economy	13600.00
0005432568125	4696	Economy	13600.00
0005432568113	4696	Economy	13600.00
0005432568138	4696	Economy	13600.00
0005432568139	4696	Economy	13600.00
0005432460282	4696	Economy	13600.00
0005432460260	4696	Economy	13600.00
0005432568144	4696	Economy	13600.00
0005432568145	4696	Economy	13600.00
0005432460263	4696	Economy	13600.00
0005432568102	4696	Economy	13600.00
0005433726124	4696	Economy	13600.00
0005432568096	4696	Economy	13600.00
0005434082100	4696	Economy	13600.00
0005434082106	4696	Economy	13600.00
0005432568141	4696	Economy	13600.00
0005432568122	4696	Economy	13600.00
0005434082093	4696	Economy	13600.00
0005432568143	4696	Economy	13600.00
0005432568110	4696	Economy	13600.00
0005432568136	4696	Economy	13600.00
0005432460285	4696	Economy	13600.00
0005432568148	4696	Economy	13600.00
0005432460252	4696	Economy	13600.00
0005432460239	4696	Economy	13600.00
0005434082094	4696	Economy	13600.00
0005432460243	4696	Economy	13600.00
0005432568149	4696	Economy	13600.00
0005432568134	4696	Economy	13600.00
0005432568105	4696	Economy	13600.00
0005432568124	4696	Economy	13600.00
0005432186901	4696	Economy	13600.00
0005432460251	4696	Economy	13600.00
0005432460250	4696	Economy	13600.00
0005432568151	4696	Economy	13600.00
0005432170444	4696	Economy	13600.00
0005433726122	4696	Economy	13600.00
0005432568115	4696	Economy	13600.00
0005432568120	4696	Economy	13600.00
0005432568093	4696	Economy	13600.00
0005434082105	4696	Economy	13600.00
0005432460280	4696	Economy	13600.00
0005432460242	4696	Economy	13600.00
0005432460270	4696	Economy	13600.00
0005434082096	4696	Economy	13600.00
0005433726123	4696	Economy	13600.00
0005432460248	4696	Economy	13600.00
0005432568109	4696	Economy	15000.00
0005432568121	4696	Economy	15000.00
0005432460274	4696	Economy	13600.00
0005434082107	4696	Economy	13600.00
0005432568146	4696	Economy	15000.00
0005432568097	4696	Economy	13600.00
0005432460290	4696	Economy	15000.00
0005432568117	4696	Economy	13600.00
0005432460279	4696	Economy	13600.00
0005432460257	4696	Economy	13600.00
0005432568123	4696	Economy	13600.00
0005432460241	4696	Economy	13600.00
0005432460246	4696	Economy	13600.00
0005432568116	4696	Economy	13600.00
0005432460259	4696	Economy	13600.00
0005432568114	4696	Economy	13600.00
0005432568132	4696	Economy	13600.00
0005432460258	4696	Economy	13600.00
0005432568100	4696	Economy	13600.00
0005432460245	4696	Economy	13600.00
0005432460265	4696	Economy	13600.00
0005432568111	4696	Economy	13600.00
0005434082101	4696	Economy	13600.00
0005432568133	4696	Economy	13600.00
0005432460273	4696	Economy	13600.00
0005432460269	4696	Economy	13600.00
0005434082092	4696	Economy	13600.00
0005432460277	4696	Economy	13600.00
0005432170441	4696	Economy	13600.00
0005432460286	4696	Economy	13600.00
0005432460249	4696	Economy	13600.00
0005432568135	4696	Economy	13600.00
0005432571353	4696	Economy	13600.00
0005432186899	4696	Economy	13600.00
0005434082099	4696	Economy	13600.00
0005432568119	4696	Economy	13600.00
0005432170445	4696	Economy	13600.00
0005432460271	4696	Economy	13600.00
0005432460264	4696	Economy	13600.00
0005432568095	4696	Economy	13600.00
0005432568106	4696	Economy	13600.00
0005432460254	4696	Economy	13600.00
0005434082091	4696	Economy	13600.00
0005432460253	4696	Economy	13600.00
0005432568108	4696	Economy	13600.00
0005433452757	4696	Economy	13600.00
0005432568090	4696	Economy	13600.00
0005432568147	4696	Economy	13600.00
0005432186900	4696	Economy	13600.00
0005432568126	4696	Economy	13600.00
0005432568129	4696	Economy	13600.00
0005432460267	4696	Economy	13600.00
0005434082102	4696	Economy	13600.00
0005432460240	4696	Economy	13600.00
0005432568131	4696	Economy	13600.00
0005434082097	4696	Economy	13600.00
0005432568150	4696	Economy	13600.00
0005432460262	4696	Economy	13600.00
0005432460256	4696	Economy	13600.00
0005434559104	4696	Economy	13600.00
0005432568128	4696	Economy	13600.00
0005434082090	4696	Economy	13600.00
0005434082095	4696	Economy	13600.00
0005434559102	4696	Economy	13600.00
0005432459949	30565	Business	40900.00
0005432459822	30565	Business	40900.00
0005432459649	30565	Business	40900.00
0005432571331	30565	Business	40900.00
0005432567668	30565	Business	40900.00
0005432567669	30565	Business	40900.00
0005432567349	30565	Business	40900.00
0005432567651	30565	Business	40900.00
0005434081791	30565	Business	40900.00
0005432459987	30565	Business	40900.00
0005432459797	30565	Business	40900.00
0005432567856	30565	Business	40900.00
0005432571310	30565	Business	40900.00
0005432567892	30565	Business	40900.00
0005434081840	30565	Business	40900.00
0005432567493	30565	Business	40900.00
0005432161170	30565	Economy	15000.00
0005432567387	30565	Economy	15000.00
0005432567790	30565	Economy	15000.00
0005432567702	30565	Economy	13600.00
0005432567662	30565	Economy	13600.00
0005432567866	30565	Economy	13600.00
0005432567891	30565	Economy	13600.00
0005432459798	30565	Economy	13600.00
0005432567771	30565	Economy	13600.00
0005432571332	30565	Economy	13600.00
0005432459999	30565	Economy	13600.00
0005432567637	30565	Economy	13600.00
0005434081821	30565	Economy	13600.00
0005432567527	30565	Economy	13600.00
0005432567598	30565	Economy	13600.00
0005432459758	30565	Economy	13600.00
0005434081842	30565	Economy	13600.00
0005432459789	30565	Economy	13600.00
0005432567737	30565	Economy	13600.00
0005432459823	30565	Economy	13600.00
0005432567491	30565	Economy	13600.00
0005432567717	30565	Economy	13600.00
0005432571311	30565	Economy	13600.00
0005432460037	30565	Economy	13600.00
0005432459993	30565	Economy	13600.00
0005434081764	30565	Economy	13600.00
0005432567770	30565	Economy	13600.00
0005433454878	30565	Economy	13600.00
0005432460011	30565	Economy	13600.00
0005432567617	30565	Economy	13600.00
0005432459877	30565	Economy	13600.00
0005434081845	30565	Economy	13600.00
0005432567628	30565	Economy	13600.00
0005432460010	30565	Economy	13600.00
0005432213636	30565	Economy	13600.00
0005432459849	30565	Economy	13600.00
0005432567277	30565	Economy	13600.00
0005432161169	30565	Economy	13600.00
0005432460087	30565	Economy	13600.00
0005432567854	30565	Economy	13600.00
0005432460164	30565	Economy	13600.00
0005432459948	30565	Economy	13600.00
0005434081867	30565	Economy	13600.00
0005432459887	30565	Economy	13600.00
0005432213637	30565	Economy	13600.00
0005432459817	30565	Economy	13600.00
0005432459756	30565	Economy	13600.00
0005432459700	30565	Economy	13600.00
0005432459749	30565	Economy	13600.00
0005432567713	30565	Economy	13600.00
0005432567621	30565	Economy	13600.00
0005432459796	30565	Economy	13600.00
0005432459893	30565	Economy	13600.00
0005432567750	30565	Economy	13600.00
0005432459704	30565	Economy	13600.00
0005432459892	30565	Economy	13600.00
0005432459767	30565	Economy	13600.00
0005432567374	30565	Economy	13600.00
0005434081820	30565	Economy	13600.00
0005432213635	30565	Economy	13600.00
0005432460009	30565	Economy	13600.00
0005432459768	30565	Economy	13600.00
0005432567711	30565	Economy	13600.00
0005432567818	30565	Economy	13600.00
0005432567592	30565	Economy	13600.00
0005432459912	30565	Economy	13600.00
0005432213634	30565	Economy	13600.00
0005432567552	30565	Economy	15000.00
0005432459876	30565	Economy	15000.00
0005432571328	30565	Economy	13600.00
0005432567526	30565	Economy	13600.00
0005432459879	30565	Economy	15000.00
0005432459903	30565	Economy	13600.00
0005432460000	30565	Economy	13600.00
0005432161171	30565	Economy	13600.00
0005432567703	30565	Economy	13600.00
0005432459904	30565	Economy	13600.00
0005432459880	30565	Economy	13600.00
0005432459950	30565	Economy	13600.00
0005432567939	30565	Economy	13600.00
0005432567845	30565	Economy	13600.00
0005432567436	30565	Economy	13600.00
0005434081834	30565	Economy	13600.00
0005432567871	30565	Economy	13600.00
0005432567348	30565	Economy	13600.00
0005432459747	30565	Economy	13600.00
0005432459773	30565	Economy	13600.00
0005432567791	30565	Economy	13600.00
0005432459847	30565	Economy	13600.00
0005432567701	30565	Economy	13600.00
0005432567720	30565	Economy	13600.00
0005432459968	30565	Economy	13600.00
0005432567736	30565	Economy	13600.00
0005432459819	30565	Economy	13600.00
0005432567538	30565	Economy	13600.00
0005432459913	30565	Economy	13600.00
0005434081837	30565	Economy	13600.00
0005432567896	30565	Economy	13600.00
0005432567774	30565	Economy	13600.00
0005432567718	30565	Economy	13600.00
0005432567539	30565	Economy	13600.00
0005432459918	30565	Economy	13600.00
0005432459719	30565	Economy	13600.00
0005432567443	30565	Economy	13600.00
0005432567373	30565	Economy	13600.00
0005432459881	30565	Economy	13600.00
0005432459848	30565	Economy	13600.00
0005432567819	30565	Economy	13600.00
0005432567276	30565	Economy	13600.00
0005432459650	30565	Economy	13600.00
0005434081843	30565	Economy	13600.00
0005432567492	30565	Economy	13600.00
0005432567895	30565	Economy	13600.00
0005432460038	30565	Economy	13600.00
0005432567777	30565	Economy	13600.00
0005434081752	30565	Economy	13600.00
0005432460028	30565	Economy	13600.00
0005432459818	30565	Economy	13600.00
0005432459829	30565	Economy	13600.00
0005432567388	30565	Economy	13600.00
0005432459846	30565	Economy	13600.00
0005432459746	30565	Economy	13600.00
0005433454877	30565	Economy	13600.00
0005432567663	30565	Economy	13600.00
0005432459682	30565	Economy	13600.00
0005435722073	13646	Economy	9900.00
0005435722074	13646	Economy	9900.00
0005435722075	13646	Economy	9900.00
0005435720130	21204	Economy	9900.00
0005432295901	22784	Economy	9700.00
0005432295900	22784	Economy	8800.00
0005432295902	22784	Economy	8800.00
0005433343987	11122	Business	23600.00
0005433343940	11122	Business	23600.00
0005433343998	11122	Business	23600.00
0005433344022	11122	Business	23600.00
0005433343996	11122	Business	23600.00
0005433344004	11122	Business	23600.00
0005433343926	11122	Business	23600.00
0005433343973	11122	Business	23600.00
0005435097275	11122	Business	23600.00
0005433343935	11122	Business	23600.00
0005433344017	11122	Business	23600.00
0005433343969	11122	Business	23600.00
0005433343977	11122	Economy	7900.00
0005433343993	11122	Economy	7900.00
0005433343950	11122	Economy	7900.00
0005433343986	11122	Economy	7900.00
0005433343957	11122	Economy	7900.00
0005433344014	11122	Economy	7900.00
0005435380274	11122	Economy	7900.00
0005433343951	11122	Economy	7900.00
0005433343984	11122	Economy	7900.00
0005435097279	11122	Economy	7900.00
0005435097269	11122	Economy	7900.00
0005435380292	11122	Economy	7900.00
0005433343981	11122	Economy	7900.00
0005433343943	11122	Economy	7900.00
0005433343974	11122	Economy	7900.00
0005433343922	11122	Economy	7900.00
0005435508304	11122	Economy	7900.00
0005433343954	11122	Economy	7900.00
0005433344010	11122	Economy	7900.00
0005433343975	11122	Economy	7900.00
0005433343923	11122	Economy	7900.00
0005435097274	11122	Economy	7900.00
0005435380291	11122	Economy	7900.00
0005433343937	11122	Economy	7900.00
0005435380285	11122	Economy	7900.00
0005433344019	11122	Economy	7900.00
0005433343965	11122	Economy	7900.00
0005433343963	11122	Economy	7900.00
0005435508318	11122	Economy	7900.00
0005433343991	11122	Economy	7900.00
0005435097268	11122	Economy	7900.00
0005435380290	11122	Economy	7900.00
0005433343947	11122	Economy	7900.00
0005435380303	11122	Economy	7900.00
0005433344009	11122	Economy	7900.00
0005433343946	11122	Economy	7900.00
0005433344015	11122	Economy	7900.00
0005433344021	11122	Economy	7900.00
0005433343953	11122	Economy	7900.00
0005433343967	11122	Economy	8600.00
0005433343992	11122	Economy	8600.00
0005433344013	11122	Economy	8600.00
0005433343958	11122	Economy	8600.00
0005433343999	11122	Economy	8600.00
0005433343933	11122	Economy	8600.00
0005433343959	11122	Economy	7900.00
0005435380304	11122	Economy	7900.00
0005433343942	11122	Economy	7900.00
0005433343997	11122	Economy	7900.00
0005435097273	11122	Economy	7900.00
0005433343941	11122	Economy	7900.00
0005433343972	11122	Economy	7900.00
0005433343964	11122	Economy	7900.00
0005433344012	11122	Economy	7900.00
0005433343928	11122	Economy	7900.00
0005435097272	11122	Economy	7900.00
0005433343978	11122	Economy	7900.00
0005433343956	11122	Economy	7900.00
0005433343939	11122	Economy	7900.00
0005433344008	11122	Economy	7900.00
0005435508302	11122	Economy	7900.00
0005435380272	11122	Economy	7900.00
0005433343985	11122	Economy	7900.00
0005433343966	11122	Economy	7900.00
0005433343945	11122	Economy	7900.00
0005433344016	11122	Economy	7900.00
0005433344018	11122	Economy	7900.00
0005433343924	11122	Economy	7900.00
0005433343994	11122	Economy	7900.00
0005435380273	11122	Economy	7900.00
0005433343988	11122	Economy	7900.00
0005433343938	11122	Economy	7900.00
0005433343927	11122	Economy	7900.00
0005433343948	11122	Economy	7900.00
0005433343931	11122	Economy	7900.00
0005433343989	11122	Economy	7900.00
0005433344000	11122	Economy	7900.00
0005433343971	11122	Economy	7900.00
0005435097277	11122	Economy	7900.00
0005433343932	11122	Economy	7900.00
0005433343979	11122	Economy	7900.00
0005433344003	11122	Economy	7900.00
0005433343936	11122	Economy	7900.00
0005433343980	11122	Economy	7900.00
0005435097271	11122	Economy	7900.00
0005433344007	11122	Economy	7900.00
0005433343968	11122	Economy	7900.00
0005433343934	11122	Economy	7900.00
0005433343960	11122	Economy	7900.00
0005435508306	11122	Economy	7900.00
0005433343944	11122	Economy	7900.00
0005433343952	11122	Economy	7900.00
0005433344005	11122	Economy	7900.00
0005433344011	11122	Economy	7900.00
0005433343961	11122	Economy	7900.00
0005433343930	11122	Economy	7900.00
0005433343949	11122	Economy	7900.00
0005435097278	11122	Economy	7900.00
0005433344023	11122	Economy	7900.00
0005433343925	11122	Economy	7900.00
0005433344020	11122	Economy	7900.00
0005433344006	11122	Economy	7900.00
0005433343990	11122	Economy	7900.00
0005433343955	11122	Economy	7900.00
0005433344002	11122	Economy	7900.00
0005435097270	11122	Economy	7900.00
0005433343995	11122	Economy	7900.00
0005433343929	11122	Economy	7900.00
0005433343962	11122	Economy	7900.00
0005433343976	11122	Economy	7900.00
0005435097276	11122	Economy	7900.00
0005435380289	11122	Economy	7900.00
0005433344001	11122	Economy	7900.00
0005433343970	11122	Economy	7900.00
0005433343983	11122	Economy	7900.00
0005435508303	11122	Economy	7900.00
0005433343982	11122	Economy	7900.00
0005433342754	17129	Business	23600.00
0005432293228	17129	Business	23600.00
0005433342751	17129	Business	23600.00
0005433342836	17129	Business	23600.00
0005433343259	17129	Business	23600.00
0005435097238	17129	Business	23600.00
0005435097207	17129	Business	23600.00
0005433342966	17129	Business	23600.00
0005433343007	17129	Business	23600.00
0005433343031	17129	Business	23600.00
0005433342739	17129	Business	23600.00
0005433342910	17129	Economy	7900.00
0005433342847	17129	Business	23600.00
0005433343148	17129	Economy	7900.00
0005433343353	17129	Economy	7900.00
0005433343325	17129	Economy	7900.00
0005433342886	17129	Economy	7900.00
0005433342764	17129	Economy	7900.00
0005435380330	17129	Economy	7900.00
0005433342891	17129	Economy	7900.00
0005433343159	17129	Economy	7900.00
0005433342600	17129	Economy	7900.00
0005433343252	17129	Economy	7900.00
0005433343150	17129	Economy	7900.00
0005435545796	17129	Economy	7900.00
0005433343088	17129	Economy	7900.00
0005433343473	17129	Economy	7900.00
0005433342590	17129	Economy	7900.00
0005433343010	17129	Economy	7900.00
0005433343086	17129	Economy	7900.00
0005433342921	17129	Economy	7900.00
0005435097178	17129	Economy	7900.00
0005433342923	17129	Economy	7900.00
0005433342517	17129	Economy	7900.00
0005435097181	17129	Economy	7900.00
0005433343028	17129	Economy	7900.00
0005435545792	17129	Economy	7900.00
0005433342449	17129	Economy	7900.00
0005435380331	17129	Economy	7900.00
0005433343067	17129	Economy	7900.00
0005433343251	17129	Economy	7900.00
0005433342708	17129	Economy	7900.00
0005433343285	17129	Economy	7900.00
0005433342676	17129	Economy	7900.00
0005433343033	17129	Economy	7900.00
0005433343130	17129	Economy	7900.00
0005433342832	17129	Economy	7900.00
0005433343352	17129	Economy	7900.00
0005433342892	17129	Economy	7900.00
0005433342595	17129	Economy	7900.00
0005433343112	17129	Economy	7900.00
0005433342770	17129	Economy	7900.00
0005433343359	17129	Economy	8600.00
0005435097206	17129	Economy	8600.00
0005433343472	17129	Economy	8600.00
0005433343080	17129	Economy	8600.00
0005433342773	17129	Economy	8600.00
0005433342738	17129	Economy	8600.00
0005433342953	17129	Economy	7900.00
0005433342942	17129	Economy	7900.00
0005433342967	17129	Economy	7900.00
0005435097167	17129	Economy	7900.00
0005433343284	17129	Economy	7900.00
0005432293229	17129	Economy	7900.00
0005433342468	17129	Economy	7900.00
0005435097193	17129	Economy	7900.00
0005435545795	17129	Economy	7900.00
0005433343113	17129	Economy	7900.00
0005433343011	17129	Economy	7900.00
0005435097175	17129	Economy	7900.00
0005433343008	17129	Economy	7900.00
0005433343090	17129	Economy	7900.00
0005433343100	17129	Economy	7900.00
0005433343142	17129	Economy	7900.00
0005435545793	17129	Economy	7900.00
0005433343094	17129	Economy	7900.00
0005433342467	17129	Economy	7900.00
0005433343287	17129	Economy	7900.00
0005433343005	17129	Economy	7900.00
0005433343213	17129	Economy	7900.00
0005433343263	17129	Economy	7900.00
0005433343444	17129	Economy	7900.00
0005435097169	17129	Economy	7900.00
0005433342868	17129	Economy	7900.00
0005433343143	17129	Economy	7900.00
0005433342763	17129	Economy	7900.00
0005433343147	17129	Economy	7900.00
0005435097174	17129	Economy	7900.00
0005433343029	17129	Economy	7900.00
0005433343087	17129	Economy	7900.00
0005433342837	17129	Economy	7900.00
0005435097168	17129	Economy	7900.00
0005433343149	17129	Economy	7900.00
0005433343139	17129	Economy	7900.00
0005435097182	17129	Economy	7900.00
0005433343069	17129	Economy	7900.00
0005433342914	17129	Economy	7900.00
0005433343081	17129	Economy	7900.00
0005433343051	17129	Economy	7900.00
0005433342642	17129	Economy	7900.00
0005433342972	17129	Economy	7900.00
0005435097254	17129	Economy	7900.00
0005433343151	17129	Economy	7900.00
0005435380328	17129	Economy	7900.00
0005433343161	17129	Economy	7900.00
0005433342730	17129	Economy	7900.00
0005433343092	17129	Economy	7900.00
0005433342731	17129	Economy	7900.00
0005433343032	17129	Economy	7900.00
0005433343089	17129	Economy	7900.00
0005435097221	17129	Economy	7900.00
0005433342762	17129	Economy	7900.00
0005435380333	17129	Economy	7900.00
0005433343027	17129	Economy	7900.00
0005433343101	17129	Economy	7900.00
0005435097192	17129	Economy	7900.00
0005433343312	17129	Economy	7900.00
0005433342965	17129	Economy	7900.00
0005433343136	17129	Economy	7900.00
0005433342846	17129	Economy	7900.00
0005435380332	17129	Economy	7900.00
0005433343155	17129	Economy	7900.00
0005433342865	17129	Economy	7900.00
0005433342878	17129	Economy	7900.00
0005435545794	17129	Economy	7900.00
0005435097222	17129	Economy	7900.00
0005433342971	17129	Economy	7900.00
0005433343311	17129	Economy	7900.00
0005433343117	17129	Economy	7900.00
0005435380329	17129	Economy	7900.00
0005433507340	9078	Business	26600.00
0005433507323	9078	Business	26600.00
0005433507327	9078	Business	26600.00
0005433481233	9078	Business	26600.00
0005432919795	9078	Economy	8900.00
0005433507338	9078	Economy	9800.00
0005434158977	9078	Economy	9800.00
0005434158966	9078	Economy	8900.00
0005433507329	9078	Economy	8900.00
0005433481232	9078	Economy	8900.00
0005433507334	9078	Economy	8900.00
0005433507324	9078	Economy	8900.00
0005433507332	9078	Economy	8900.00
0005433481228	9078	Economy	8900.00
0005432919907	9078	Economy	8900.00
0005432919839	9078	Economy	8900.00
0005433507337	9078	Economy	8900.00
0005432919870	9078	Economy	8900.00
0005433507339	9078	Economy	8900.00
0005433481227	9078	Economy	8900.00
0005433481226	9078	Economy	8900.00
0005432919841	9078	Economy	8900.00
0005433507322	9078	Economy	8900.00
0005432919888	9078	Economy	8900.00
0005432919747	9078	Economy	8900.00
0005433481229	9078	Economy	8900.00
0005432919746	9078	Economy	8900.00
0005433507326	9078	Economy	8900.00
0005433507333	9078	Economy	8900.00
0005432919872	9078	Economy	8900.00
0005433507331	9078	Economy	8900.00
0005433507330	9078	Economy	8900.00
0005432919951	9078	Economy	8900.00
0005433507335	9078	Economy	8900.00
0005432919845	9078	Economy	8900.00
0005434158976	9078	Economy	8900.00
0005433507328	9078	Economy	8900.00
0005433507336	9078	Economy	8900.00
0005433481231	9078	Economy	8900.00
0005432919846	9078	Economy	8900.00
0005432919906	9078	Economy	8900.00
0005432919838	9078	Economy	8900.00
0005432919825	9078	Economy	8900.00
0005433481230	9078	Economy	8900.00
0005432919837	9078	Economy	8900.00
0005433507325	9078	Economy	8900.00
0005432920053	20463	Business	26600.00
0005434158995	20463	Business	26600.00
0005432920057	20463	Business	26600.00
0005432920047	20463	Business	26600.00
0005433507186	20463	Business	26600.00
0005432920039	20463	Economy	8900.00
0005432920054	20463	Economy	8900.00
0005433507166	20463	Economy	8900.00
0005432920045	20463	Economy	8900.00
0005432920049	20463	Economy	8900.00
0005433507216	20463	Economy	8900.00
0005433481200	20463	Economy	8900.00
0005433507149	20463	Economy	8900.00
0005433481178	20463	Economy	8900.00
0005432920038	20463	Economy	8900.00
0005433481199	20463	Economy	8900.00
0005432920052	20463	Economy	8900.00
0005433507174	20463	Economy	8900.00
0005432920044	20463	Economy	8900.00
0005433481175	20463	Economy	8900.00
0005432920058	20463	Economy	8900.00
0005433507182	20463	Economy	8900.00
0005432920043	20463	Economy	8900.00
0005433481165	20463	Economy	8900.00
0005432920042	20463	Economy	8900.00
0005434158997	20463	Economy	8900.00
0005433481135	20463	Economy	8900.00
0005434158994	20463	Economy	8900.00
0005432920056	20463	Economy	8900.00
0005433481174	20463	Economy	8900.00
0005433481157	20463	Economy	8900.00
0005432920050	20463	Economy	8900.00
0005432920046	20463	Economy	8900.00
0005432920048	20463	Economy	8900.00
0005433507212	20463	Economy	8900.00
0005432920051	20463	Economy	8900.00
0005432920041	20463	Economy	8900.00
0005433507133	20463	Economy	8900.00
0005433507203	20463	Economy	8900.00
0005434158996	20463	Economy	8900.00
0005433481177	20463	Economy	8900.00
0005433481136	20463	Economy	8900.00
0005432920040	20463	Economy	8900.00
0005432920055	20463	Economy	8900.00
0005433507183	20463	Economy	8900.00
0005433507215	20463	Economy	8900.00
0005432394135	10231	Economy	5800.00
0005432394136	10231	Economy	5800.00
0005432394134	10231	Economy	5800.00
0005432396274	10231	Economy	5800.00
0005432396272	10231	Economy	5800.00
0005432394131	10231	Economy	5800.00
0005432394133	10231	Economy	5800.00
0005432394132	10231	Economy	5800.00
0005432396273	10231	Economy	5800.00
0005432396271	10231	Economy	5800.00
0005432400119	18348	Economy	5800.00
0005432400128	18348	Economy	5800.00
0005432396256	18348	Economy	5800.00
0005432396228	18348	Economy	5800.00
0005432400130	18348	Economy	5800.00
0005432400129	18348	Economy	5800.00
0005432400124	18348	Economy	5800.00
0005432400113	18348	Economy	5800.00
0005432396244	18348	Economy	5800.00
0005432400125	18348	Economy	5800.00
0005432400116	18348	Economy	5800.00
0005435126241	11015	Business	9500.00
0005435626158	11015	Business	9500.00
0005435126393	11015	Business	9500.00
0005435626071	11015	Business	9500.00
0005435126246	11015	Business	9500.00
0005435126370	11015	Business	9500.00
0005435556692	11015	Business	9500.00
0005435626122	11015	Business	9500.00
0005435126213	11015	Business	9500.00
0005434928322	11015	Business	9500.00
0005435126250	11015	Economy	3200.00
0005434411814	11015	Economy	3200.00
0005435126278	11015	Economy	3200.00
0005435126369	11015	Economy	3200.00
0005435126232	11015	Economy	3200.00
0005435126339	11015	Economy	3200.00
0005435126266	11015	Economy	3200.00
0005435126245	11015	Economy	3200.00
0005434411812	11015	Economy	3200.00
0005435554189	11015	Economy	3500.00
0005435626157	11015	Economy	3500.00
0005435126214	11015	Economy	3500.00
0005435126469	11015	Economy	3500.00
0005435126267	11015	Economy	3200.00
0005435126330	11015	Economy	3200.00
0005435554196	11015	Economy	3200.00
0005435126231	11015	Economy	3200.00
0005435126414	11015	Economy	3200.00
0005435626132	11015	Economy	3200.00
0005435126168	11015	Economy	3200.00
0005435126294	11015	Economy	3200.00
0005435554198	11015	Economy	3200.00
0005435626140	11015	Economy	3200.00
0005435626131	11015	Economy	3200.00
0005435126242	11015	Economy	3200.00
0005435626077	11015	Economy	3200.00
0005435626120	11015	Economy	3200.00
0005435126415	11015	Economy	3200.00
0005435554197	11015	Economy	3200.00
0005435126437	11015	Economy	3200.00
0005435126212	11015	Economy	3200.00
0005435126265	11015	Economy	3200.00
0005435126247	11015	Economy	3200.00
0005435126277	11015	Economy	3200.00
0005435126188	11015	Economy	3200.00
0005435126096	11015	Economy	3200.00
0005435626138	11015	Economy	3200.00
0005434928324	11015	Economy	3200.00
0005434411813	11015	Economy	3200.00
0005435126327	11015	Economy	3200.00
0005434411817	11015	Economy	3200.00
0005435126307	11015	Economy	3200.00
0005435626134	11015	Economy	3200.00
0005435126244	11015	Economy	3200.00
0005435126223	11015	Economy	3200.00
0005434411816	11015	Economy	3200.00
0005435626119	11015	Economy	3200.00
0005435626076	11015	Economy	3200.00
0005435626142	11015	Economy	3200.00
0005435126240	11015	Economy	3200.00
0005434411815	11015	Economy	3200.00
0005435126312	11015	Economy	3200.00
0005435126255	11015	Economy	3200.00
0005435126313	11015	Economy	3200.00
0005435126434	11015	Economy	3200.00
0005435626135	11015	Economy	3200.00
0005435126290	11015	Economy	3200.00
0005435126517	11015	Economy	3200.00
0005435126379	11015	Economy	3200.00
0005435626141	11015	Economy	3200.00
0005435126189	11015	Economy	3200.00
0005435126431	11015	Economy	3200.00
0005435126215	11015	Economy	3200.00
0005435126097	11015	Economy	3200.00
0005435126151	11015	Economy	3200.00
0005435626139	11015	Economy	3200.00
0005435126420	11015	Economy	3200.00
0005435126341	11015	Economy	3200.00
0005435126254	11015	Economy	3200.00
0005434928323	11015	Economy	3200.00
0005435626078	11015	Economy	3200.00
0005435126249	11015	Economy	3200.00
0005435126360	11015	Economy	3200.00
0005435126293	11015	Economy	3200.00
0005435126292	11015	Economy	3200.00
0005435626121	11015	Economy	3200.00
0005435556712	14668	Business	9500.00
0005434928285	14668	Business	9500.00
0005435626328	14668	Business	9500.00
0005435126720	14668	Business	9500.00
0005435126722	14668	Business	9500.00
0005435126701	14668	Business	9500.00
0005435626317	14668	Business	9500.00
0005435626337	14668	Business	9500.00
0005435126693	14668	Business	9500.00
0005435626322	14668	Business	9500.00
0005435626327	14668	Economy	3200.00
0005435626318	14668	Economy	3200.00
0005435626320	14668	Economy	3200.00
0005435626329	14668	Economy	3200.00
0005435626334	14668	Economy	3200.00
0005435626333	14668	Economy	3200.00
0005434411760	14668	Economy	3200.00
0005435126707	14668	Economy	3200.00
0005435554226	14668	Economy	3200.00
0005435126688	14668	Economy	3200.00
0005435126726	14668	Economy	3500.00
0005435126702	14668	Economy	3500.00
0005435126725	14668	Economy	3500.00
0005434928313	14668	Economy	3500.00
0005435626339	14668	Economy	3200.00
0005435126717	14668	Economy	3200.00
0005435626332	14668	Economy	3200.00
0005435126713	14668	Economy	3200.00
0005435626316	14668	Economy	3200.00
0005435554223	14668	Economy	3200.00
0005435126705	14668	Economy	3200.00
0005435126698	14668	Economy	3200.00
0005435126714	14668	Economy	3200.00
0005435554224	14668	Economy	3200.00
0005435626321	14668	Economy	3200.00
0005435126704	14668	Economy	3200.00
0005434411787	14668	Economy	3200.00
0005435626338	14668	Economy	3200.00
0005435126712	14668	Economy	3200.00
0005435126731	14668	Economy	3200.00
0005435626325	14668	Economy	3200.00
0005435126724	14668	Economy	3200.00
0005435126697	14668	Economy	3200.00
0005435126710	14668	Economy	3200.00
0005435626324	14668	Economy	3200.00
0005435626326	14668	Economy	3200.00
0005435556713	14668	Economy	3200.00
0005435126729	14668	Economy	3200.00
0005435126699	14668	Economy	3200.00
0005435626330	14668	Economy	3200.00
0005435126696	14668	Economy	3200.00
0005435556714	14668	Economy	3200.00
0005435554225	14668	Economy	3200.00
0005435626323	14668	Economy	3200.00
0005435126711	14668	Economy	3200.00
0005435126721	14668	Economy	3200.00
0005435126709	14668	Economy	3200.00
0005435126715	14668	Economy	3200.00
0005435126723	14668	Economy	3200.00
0005435126706	14668	Economy	3200.00
0005435126718	14668	Economy	3200.00
0005435126728	14668	Economy	3200.00
0005435126703	14668	Economy	3200.00
0005435126689	14668	Economy	3200.00
0005435626331	14668	Economy	3200.00
0005435126727	14668	Economy	3200.00
0005435126708	14668	Economy	3200.00
0005434928306	14668	Economy	3200.00
0005435126694	14668	Economy	3200.00
0005435126691	14668	Economy	3200.00
0005435626335	14668	Economy	3200.00
0005435126692	14668	Economy	3200.00
0005435126719	14668	Economy	3200.00
0005435626319	14668	Economy	3200.00
0005434411761	14668	Economy	3200.00
0005435126716	14668	Economy	3200.00
0005435126730	14668	Economy	3200.00
0005435126690	14668	Economy	3200.00
0005435126695	14668	Economy	3200.00
0005435554222	14668	Economy	3200.00
0005435126700	14668	Economy	3200.00
0005435626336	14668	Economy	3200.00
0005432400158	7099	Business	86900.00
0005435178495	7099	Economy	29000.00
0005435715610	7099	Economy	29000.00
0005435715615	7099	Economy	29000.00
0005432398230	7099	Economy	29000.00
0005435443284	7099	Economy	29000.00
0005435715602	7099	Economy	31900.00
0005435715612	7099	Economy	29000.00
0005435715608	7099	Economy	29000.00
0005435219203	7099	Economy	29000.00
0005435443351	7099	Economy	29000.00
0005435443287	7099	Economy	29000.00
0005435715605	7099	Economy	29000.00
0005435715607	7099	Economy	29000.00
0005432400157	7099	Economy	29000.00
0005435715611	7099	Economy	29000.00
0005435443269	7099	Economy	29000.00
0005435219187	7099	Economy	29000.00
0005435715616	7099	Economy	29000.00
0005435715604	7099	Economy	29000.00
0005435715603	7099	Economy	29000.00
0005435443276	7099	Economy	29000.00
0005435715601	7099	Economy	29000.00
0005435715609	7099	Economy	29000.00
0005432398228	7099	Economy	29000.00
0005435178494	7099	Economy	29000.00
0005432398229	7099	Economy	29000.00
0005435715613	7099	Economy	29000.00
0005435715614	7099	Economy	29000.00
0005435219202	7099	Economy	29000.00
0005435443324	7099	Economy	29000.00
0005435178501	7099	Economy	29000.00
0005432400156	7099	Economy	29000.00
0005435715606	7099	Economy	29000.00
0005435443314	7099	Economy	29000.00
0005432398227	7099	Economy	29000.00
0005435217728	27066	Business	86900.00
0005435216606	27066	Business	86900.00
0005435216603	27066	Business	86900.00
0005435178507	27066	Business	86900.00
0005435217725	27066	Business	86900.00
0005432398190	27066	Economy	29000.00
0005435715458	27066	Economy	29000.00
0005435443394	27066	Economy	29000.00
0005435178999	27066	Economy	31900.00
0005432394107	27066	Economy	31900.00
0005435216602	27066	Economy	31900.00
0005435715429	27066	Economy	29000.00
0005435178506	27066	Economy	29000.00
0005435216605	27066	Economy	29000.00
0005435443391	27066	Economy	29000.00
0005435216601	27066	Economy	29000.00
0005435715453	27066	Economy	29000.00
0005435216604	27066	Economy	29000.00
0005432394077	27066	Economy	29000.00
0005435443387	27066	Economy	29000.00
0005435178998	27066	Economy	29000.00
0005435715472	27066	Economy	29000.00
0005435218122	27066	Economy	29000.00
0005432394108	27066	Economy	29000.00
0005432394079	27066	Economy	29000.00
0005432394078	27066	Economy	29000.00
0005435715494	27066	Economy	29000.00
0005435443392	27066	Economy	29000.00
0005435443388	27066	Economy	29000.00
0005435443386	27066	Economy	29000.00
0005435443390	27066	Economy	29000.00
0005435217727	27066	Economy	29000.00
0005435715427	27066	Economy	29000.00
0005435715399	27066	Economy	29000.00
0005435216600	27066	Economy	29000.00
0005435715426	27066	Economy	29000.00
0005435443393	27066	Economy	29000.00
0005435443395	27066	Economy	29000.00
0005435217730	27066	Economy	29000.00
0005435218121	27066	Economy	29000.00
0005435443389	27066	Economy	29000.00
0005435217724	27066	Economy	29000.00
0005435715484	27066	Economy	29000.00
0005435217726	27066	Economy	29000.00
0005435217729	27066	Economy	29000.00
0005435715354	27066	Economy	29000.00
0005435715483	27066	Economy	29000.00
0005434084970	2757	Economy	7700.00
0005434084968	2757	Economy	7700.00
0005433060408	2757	Economy	7700.00
0005433060416	2757	Economy	7700.00
0005434084967	2757	Economy	7700.00
0005434084969	2757	Economy	7700.00
0005433060417	2757	Economy	7700.00
0005434084918	28517	Economy	7700.00
0005433060436	28517	Economy	7700.00
0005434084941	28517	Economy	7700.00
0005434084921	28517	Economy	7700.00
0005433060434	28517	Economy	7700.00
0005434084920	28517	Economy	7700.00
0005434084905	28517	Economy	7700.00
0005434084942	28517	Economy	7700.00
0005433060435	28517	Economy	7700.00
0005433788246	11174	Economy	27100.00
0005433788240	11174	Economy	27100.00
0005433788236	11174	Economy	27100.00
0005435548471	11174	Economy	24600.00
0005435548478	11174	Economy	24600.00
0005435548492	11174	Economy	24600.00
0005433788247	11174	Economy	24600.00
0005433788237	11174	Economy	24600.00
0005435548472	11174	Economy	24600.00
0005435548490	11174	Economy	24600.00
0005435548488	11174	Economy	24600.00
0005433788241	11174	Economy	24600.00
0005435548475	11174	Economy	24600.00
0005435548484	11174	Economy	24600.00
0005433788245	11174	Economy	24600.00
0005433788244	11174	Economy	24600.00
0005433788239	11174	Economy	24600.00
0005435548459	11174	Economy	24600.00
0005433788243	11174	Economy	24600.00
0005435548477	11174	Economy	24600.00
0005433788248	11174	Economy	24600.00
0005433788238	11174	Economy	24600.00
0005435548463	11174	Economy	24600.00
0005435548493	11174	Economy	24600.00
0005435548489	11174	Economy	24600.00
0005433788235	11174	Economy	24600.00
0005435548473	11174	Economy	24600.00
0005435548476	11174	Economy	24600.00
0005435548485	11174	Economy	24600.00
0005433788242	11174	Economy	24600.00
0005433788192	20675	Economy	27100.00
0005435548523	20675	Economy	27100.00
0005433788191	20675	Economy	27100.00
0005433788200	20675	Economy	27100.00
0005435548525	20675	Economy	24600.00
0005433788196	20675	Economy	24600.00
0005435548526	20675	Economy	24600.00
0005435548528	20675	Economy	24600.00
0005435548532	20675	Economy	24600.00
0005433788193	20675	Economy	24600.00
0005435548514	20675	Economy	24600.00
0005433788186	20675	Economy	24600.00
0005435548515	20675	Economy	24600.00
0005435548534	20675	Economy	24600.00
0005435548531	20675	Economy	24600.00
0005435548524	20675	Economy	24600.00
0005435548516	20675	Economy	24600.00
0005435548518	20675	Economy	24600.00
0005433788190	20675	Economy	24600.00
0005435548527	20675	Economy	24600.00
0005433788188	20675	Economy	24600.00
0005435548520	20675	Economy	24600.00
0005435548536	20675	Economy	24600.00
0005433788202	20675	Economy	24600.00
0005433788185	20675	Economy	24600.00
0005435548535	20675	Economy	24600.00
0005435548529	20675	Economy	24600.00
0005433788166	20675	Economy	24600.00
0005433788187	20675	Economy	24600.00
0005433788203	20675	Economy	24600.00
0005435548522	20675	Economy	24600.00
0005435548530	20675	Economy	24600.00
0005435548519	20675	Economy	24600.00
0005435548537	20675	Economy	24600.00
0005435548517	20675	Economy	24600.00
0005435548533	20675	Economy	24600.00
0005435548521	20675	Economy	24600.00
0005433788201	20675	Economy	24600.00
0005435517902	11411	Business	20200.00
0005435540867	11411	Business	20200.00
0005435541011	11411	Business	20200.00
0005435517905	11411	Business	20200.00
0005435517937	11411	Business	20200.00
0005435541020	11411	Economy	6700.00
0005435540968	11411	Economy	6700.00
0005435541005	11411	Economy	6700.00
0005435541036	11411	Economy	6700.00
0005435517791	11411	Economy	7400.00
0005435517876	11411	Economy	7400.00
0005435540912	11411	Economy	7400.00
0005435540926	11411	Economy	6700.00
0005435541077	11411	Economy	6700.00
0005435541003	11411	Economy	6700.00
0005435517790	11411	Economy	6700.00
0005435541021	11411	Economy	6700.00
0005435541042	11411	Economy	6700.00
0005435540979	11411	Economy	6700.00
0005435517888	11411	Economy	6700.00
0005435517958	11411	Economy	6700.00
0005435517885	11411	Economy	6700.00
0005435517883	11411	Economy	6700.00
0005435541072	11411	Economy	6700.00
0005435517884	11411	Economy	6700.00
0005435517948	11411	Economy	6700.00
0005435517950	11411	Economy	6700.00
0005435517926	11411	Economy	6700.00
0005435517887	11411	Economy	6700.00
0005435517942	11411	Economy	6700.00
0005435517927	11411	Economy	6700.00
0005435540911	11411	Economy	6700.00
0005435517886	11411	Economy	6700.00
0005435540994	11411	Economy	6700.00
0005435540924	11411	Economy	6700.00
0005435541035	11411	Economy	6700.00
0005435517872	11411	Economy	6700.00
0005435517949	11411	Economy	6700.00
0005435540995	11411	Economy	6700.00
0005435517855	11411	Economy	6700.00
0005435517868	11411	Economy	6700.00
0005435540927	11411	Economy	6700.00
0005435541102	11411	Economy	6700.00
0005435540913	11411	Economy	6700.00
0005435541135	11411	Economy	6700.00
0005435540925	11411	Economy	6700.00
0005435541022	11411	Economy	6700.00
0005435529419	22270	Business	20200.00
0005435529421	22270	Business	20200.00
0005432294506	22270	Business	20200.00
0005435529414	22270	Business	20200.00
0005435541154	22270	Economy	6700.00
0005435541172	22270	Economy	6700.00
0005435541156	22270	Economy	6700.00
0005435529415	22270	Economy	6700.00
0005435529417	22270	Economy	6700.00
0005435529429	22270	Economy	6700.00
0005435541165	22270	Economy	6700.00
0005435541171	22270	Economy	7400.00
0005435541166	22270	Economy	7400.00
0005435541173	22270	Economy	7400.00
0005432294505	22270	Economy	6700.00
0005435529428	22270	Economy	6700.00
0005435529413	22270	Economy	6700.00
0005435529431	22270	Economy	6700.00
0005432294504	22270	Economy	6700.00
0005435541167	22270	Economy	6700.00
0005435541164	22270	Economy	6700.00
0005435529426	22270	Economy	6700.00
0005435541157	22270	Economy	6700.00
0005435529425	22270	Economy	6700.00
0005435541158	22270	Economy	6700.00
0005435541160	22270	Economy	6700.00
0005435529423	22270	Economy	6700.00
0005435529430	22270	Economy	6700.00
0005435541175	22270	Economy	6700.00
0005435529416	22270	Economy	6700.00
0005435541168	22270	Economy	6700.00
0005435529424	22270	Economy	6700.00
0005435541169	22270	Economy	6700.00
0005435541155	22270	Economy	6700.00
0005435529411	22270	Economy	6700.00
0005435541162	22270	Economy	6700.00
0005435529412	22270	Economy	6700.00
0005435529427	22270	Economy	6700.00
0005435529418	22270	Economy	6700.00
0005435541174	22270	Economy	6700.00
0005435529420	22270	Economy	6700.00
0005435541170	22270	Economy	6700.00
0005435541163	22270	Economy	6700.00
0005435529422	22270	Economy	6700.00
0005435541159	22270	Economy	6700.00
0005435541161	22270	Economy	6700.00
0005433251562	2303	Business	20200.00
0005433251511	2303	Business	20200.00
0005434907715	2303	Business	20200.00
0005433251480	2303	Business	20200.00
0005434907742	2303	Business	20200.00
0005433251512	2303	Business	20200.00
0005434907707	2303	Business	20200.00
0005433251599	2303	Business	20200.00
0005433400975	2303	Business	20200.00
0005433251496	2303	Business	20200.00
0005433251367	2303	Business	20200.00
0005434907716	2303	Business	20200.00
0005433251593	2303	Economy	6700.00
0005433251433	2303	Economy	6700.00
0005434907713	2303	Economy	6700.00
0005434907735	2303	Economy	6700.00
0005434907724	2303	Economy	6700.00
0005433400974	2303	Economy	6700.00
0005433251389	2303	Economy	6700.00
0005434907726	2303	Economy	6700.00
0005434907736	2303	Economy	6700.00
0005433251418	2303	Economy	6700.00
0005434907712	2303	Economy	7400.00
0005433251435	2303	Economy	7400.00
0005434907718	2303	Economy	7400.00
0005433251611	2303	Economy	7400.00
0005434907725	2303	Economy	6700.00
0005434907720	2303	Economy	6700.00
0005433251481	2303	Economy	6700.00
0005433251434	2303	Economy	6700.00
0005433251553	2303	Economy	6700.00
0005433400982	2303	Economy	6700.00
0005434907730	2303	Economy	6700.00
0005433251338	2303	Economy	6700.00
0005433251592	2303	Economy	6700.00
0005433251455	2303	Economy	6700.00
0005434907708	2303	Economy	6700.00
0005434907727	2303	Economy	6700.00
0005434907741	2303	Economy	6700.00
0005433251456	2303	Economy	6700.00
0005433400987	2303	Economy	6700.00
0005434907728	2303	Economy	6700.00
0005434907744	2303	Economy	6700.00
0005434907740	2303	Economy	6700.00
0005434907719	2303	Economy	6700.00
0005434907723	2303	Economy	6700.00
0005433251447	2303	Economy	6700.00
0005433400988	2303	Economy	6700.00
0005433251510	2303	Economy	6700.00
0005433251600	2303	Economy	6700.00
0005434907738	2303	Economy	6700.00
0005433251488	2303	Economy	6700.00
0005433251392	2303	Economy	6700.00
0005433251505	2303	Economy	6700.00
0005433251548	2303	Economy	6700.00
0005433251544	2303	Economy	6700.00
0005434907734	2303	Economy	6700.00
0005433251514	2303	Economy	6700.00
0005433251454	2303	Economy	6700.00
0005433400973	2303	Economy	6700.00
0005433251428	2303	Economy	6700.00
0005433251489	2303	Economy	6700.00
0005433251466	2303	Economy	6700.00
0005434907743	2303	Economy	6700.00
0005433400992	2303	Economy	6700.00
0005434907739	2303	Economy	6700.00
0005433251594	2303	Economy	6700.00
0005433251347	2303	Economy	6700.00
0005433251561	2303	Economy	6700.00
0005434907733	2303	Economy	6700.00
0005433251498	2303	Economy	6700.00
0005434907722	2303	Economy	6700.00
0005434907714	2303	Economy	6700.00
0005434907709	2303	Economy	6700.00
0005433251390	2303	Economy	6700.00
0005434907711	2303	Economy	6700.00
0005434907745	2303	Economy	6700.00
0005433251453	2303	Economy	6700.00
0005434907737	2303	Economy	6700.00
0005434907729	2303	Economy	6700.00
0005434907721	2303	Economy	6700.00
0005433251420	2303	Economy	6700.00
0005433251346	2303	Economy	6700.00
0005433251534	2303	Economy	6700.00
0005433251414	2303	Economy	6700.00
0005434907717	2303	Economy	6700.00
0005434907732	2303	Economy	6700.00
0005434907731	2303	Economy	6700.00
0005433400993	2303	Economy	6700.00
0005434907710	2303	Economy	6700.00
0005433251491	2303	Economy	6700.00
0005434907203	25629	Business	20200.00
0005434907315	25629	Business	20200.00
0005434907115	25629	Business	20200.00
0005434907033	25629	Business	20200.00
0005433251734	25629	Business	20200.00
0005434907223	25629	Business	20200.00
0005434907036	25629	Business	20200.00
0005434906950	25629	Business	20200.00
0005434907135	25629	Business	20200.00
0005434907237	25629	Business	20200.00
0005433251743	25629	Business	20200.00
0005434907123	25629	Business	20200.00
0005434907057	25629	Economy	6700.00
0005433251729	25629	Economy	6700.00
0005434907092	25629	Economy	6700.00
0005434906929	25629	Economy	6700.00
0005434907206	25629	Economy	6700.00
0005434907034	25629	Economy	6700.00
0005433251727	25629	Economy	6700.00
0005434907220	25629	Economy	6700.00
0005434907063	25629	Economy	6700.00
0005434907150	25629	Economy	7400.00
0005434907229	25629	Economy	7400.00
0005434907113	25629	Economy	7400.00
0005434907195	25629	Economy	7400.00
0005433251732	25629	Economy	7400.00
0005434907103	25629	Economy	6700.00
0005433251741	25629	Economy	6700.00
0005434907083	25629	Economy	6700.00
0005433251731	25629	Economy	6700.00
0005434907168	25629	Economy	6700.00
0005434907171	25629	Economy	6700.00
0005433251736	25629	Economy	6700.00
0005434907035	25629	Economy	6700.00
0005434906995	25629	Economy	6700.00
0005433251718	25629	Economy	6700.00
0005433251744	25629	Economy	6700.00
0005433251747	25629	Economy	6700.00
0005433401009	25629	Economy	6700.00
0005433251721	25629	Economy	6700.00
0005434907121	25629	Economy	6700.00
0005434907164	25629	Economy	6700.00
0005433251726	25629	Economy	6700.00
0005434907179	25629	Economy	6700.00
0005433251742	25629	Economy	6700.00
0005434907238	25629	Economy	6700.00
0005434907082	25629	Economy	6700.00
0005433251725	25629	Economy	6700.00
0005433251738	25629	Economy	6700.00
0005434907099	25629	Economy	6700.00
0005433251737	25629	Economy	6700.00
0005433251723	25629	Economy	6700.00
0005433251735	25629	Economy	6700.00
0005433251748	25629	Economy	6700.00
0005434907151	25629	Economy	6700.00
0005434907231	25629	Economy	6700.00
0005434907278	25629	Economy	6700.00
0005433251739	25629	Economy	6700.00
0005433251720	25629	Economy	6700.00
0005434907221	25629	Economy	6700.00
0005434907064	25629	Economy	6700.00
0005434907283	25629	Economy	6700.00
0005434907240	25629	Economy	6700.00
0005433251724	25629	Economy	6700.00
0005434907125	25629	Economy	6700.00
0005434906949	25629	Economy	6700.00
0005433251722	25629	Economy	6700.00
0005433401008	25629	Economy	6700.00
0005434907212	25629	Economy	6700.00
0005434907183	25629	Economy	6700.00
0005433251746	25629	Economy	6700.00
0005433251719	25629	Economy	6700.00
0005433251728	25629	Economy	6700.00
0005434907236	25629	Economy	6700.00
0005433251730	25629	Economy	6700.00
0005433251745	25629	Economy	6700.00
0005434907058	25629	Economy	6700.00
0005434907194	25629	Economy	6700.00
0005434907133	25629	Economy	6700.00
0005433251740	25629	Economy	6700.00
0005434907124	25629	Economy	6700.00
0005434907163	25629	Economy	6700.00
0005434907114	25629	Economy	6700.00
0005434907204	25629	Economy	6700.00
0005434907112	25629	Economy	6700.00
0005433251733	25629	Economy	6700.00
0005434907232	25629	Economy	6700.00
0005432621150	2548	Economy	13600.00
0005432862312	2548	Economy	12400.00
0005432621152	2548	Economy	12400.00
0005432621160	2548	Economy	12400.00
0005432621149	2548	Economy	12400.00
0005432862290	2548	Economy	12400.00
0005432862324	2548	Economy	12400.00
0005432621156	2548	Economy	12400.00
0005432621159	2548	Economy	12400.00
0005432862325	2548	Economy	12400.00
0005432862286	2548	Economy	12400.00
0005432621158	2548	Economy	12400.00
0005432621155	2548	Economy	12400.00
0005432862293	2548	Economy	12400.00
0005432621148	2548	Economy	12400.00
0005432621153	2548	Economy	12400.00
0005432862346	2548	Economy	12400.00
0005432862294	2548	Economy	12400.00
0005432621161	2548	Economy	12400.00
0005432621151	2548	Economy	12400.00
0005432862287	2548	Economy	12400.00
0005432621157	2548	Economy	12400.00
0005432621154	2548	Economy	12400.00
0005432621065	28069	Economy	13600.00
0005432621047	28069	Economy	13600.00
0005432621046	28069	Economy	13600.00
0005432621015	28069	Economy	13600.00
0005432862365	28069	Economy	12400.00
0005432862363	28069	Economy	12400.00
0005432621048	28069	Economy	12400.00
0005432621058	28069	Economy	12400.00
0005432862366	28069	Economy	12400.00
0005432621066	28069	Economy	12400.00
0005432620974	28069	Economy	12400.00
0005432621049	28069	Economy	12400.00
0005432621041	28069	Economy	12400.00
0005432621024	28069	Economy	12400.00
0005432621059	28069	Economy	12400.00
0005432621001	28069	Economy	12400.00
0005432862367	28069	Economy	12400.00
0005432621021	28069	Economy	12400.00
0005432621074	28069	Economy	12400.00
0005432862369	28069	Economy	12400.00
0005432621000	28069	Economy	12400.00
0005432862368	28069	Economy	12400.00
0005432621044	28069	Economy	12400.00
0005432621064	28069	Economy	12400.00
0005432621042	28069	Economy	12400.00
0005432862364	28069	Economy	12400.00
0005432620998	28069	Economy	12400.00
0005432621043	28069	Economy	12400.00
0005432621025	28069	Economy	12400.00
0005432621072	28069	Economy	12400.00
0005432620999	28069	Economy	12400.00
0005434097470	11799	Economy	11300.00
0005434097471	11799	Economy	11300.00
0005434097487	13027	Economy	11300.00
0005433452757	31020	Economy	8400.00
0005433452756	31020	Economy	8400.00
0005433452755	31020	Economy	8400.00
0005433451636	31020	Economy	8400.00
0005433454878	31364	Economy	8400.00
0005433454877	31364	Economy	8400.00
0005433129273	11978	Economy	7200.00
0005434142599	11978	Economy	7200.00
0005433134136	11978	Economy	6600.00
0005434184668	11978	Economy	6600.00
0005434184659	11978	Economy	6600.00
0005433134137	11978	Economy	6600.00
0005433134135	11978	Economy	6600.00
0005434142612	11978	Economy	6600.00
0005434142595	11978	Economy	6600.00
0005433134132	11978	Economy	6600.00
0005433129277	11978	Economy	6600.00
0005433134176	29824	Economy	7200.00
0005434142641	29824	Economy	7200.00
0005433134177	29824	Economy	7200.00
0005434183597	29824	Economy	6600.00
0005433134173	29824	Economy	6600.00
0005433131746	29824	Economy	6600.00
0005434183596	29824	Economy	6600.00
0005433134174	29824	Economy	6600.00
0005434142642	29824	Economy	6600.00
0005433134175	29824	Economy	6600.00
0005433131744	29824	Economy	6600.00
0005433131748	29824	Economy	6600.00
0005434184682	29824	Economy	6600.00
0005433131743	29824	Economy	6600.00
0005433131747	29824	Economy	6600.00
0005434142640	29824	Economy	6600.00
0005433131745	29824	Economy	6600.00
0005435697537	16482	Economy	19900.00
0005435697560	16482	Economy	19900.00
0005435697558	16482	Economy	19900.00
0005435697559	16482	Economy	19900.00
0005435697551	16482	Economy	18100.00
0005435697540	16482	Economy	18100.00
0005435697539	16482	Economy	18100.00
0005435697553	16482	Economy	18100.00
0005435697543	16482	Economy	18100.00
0005435697536	16482	Economy	18100.00
0005435697556	16482	Economy	18100.00
0005435697534	16482	Economy	18100.00
0005435697557	16482	Economy	18100.00
0005435697541	16482	Economy	18100.00
0005435697535	16482	Economy	18100.00
0005435697544	16482	Economy	18100.00
0005435697545	16482	Economy	18100.00
0005435697554	16482	Economy	18100.00
0005435697532	16482	Economy	18100.00
0005435697542	16482	Economy	18100.00
0005435697552	16482	Economy	18100.00
0005435697533	16482	Economy	18100.00
0005435697549	16482	Economy	18100.00
0005435697547	16482	Economy	18100.00
0005435935049	16482	Economy	18100.00
0005435697548	16482	Economy	18100.00
0005435935030	16482	Economy	18100.00
0005435697546	16482	Economy	18100.00
0005435697538	16482	Economy	18100.00
0005435697555	16482	Economy	18100.00
0005435697550	16482	Economy	18100.00
0005435697394	24728	Economy	19900.00
0005435697443	24728	Economy	19900.00
0005435697404	24728	Economy	19900.00
0005435697329	24728	Economy	19900.00
0005435697349	24728	Economy	18100.00
0005435935070	24728	Economy	18100.00
0005435697390	24728	Economy	18100.00
0005435697362	24728	Economy	18100.00
0005435935071	24728	Economy	18100.00
0005435935072	24728	Economy	18100.00
0005435697363	24728	Economy	18100.00
0005435697501	24728	Economy	18100.00
0005435697398	24728	Economy	18100.00
0005435697257	24728	Economy	18100.00
0005435697360	24728	Economy	18100.00
0005435697361	24728	Economy	18100.00
0005435697330	24728	Economy	18100.00
0005435697213	24728	Economy	18100.00
0005435697229	24728	Economy	18100.00
0005435697442	24728	Economy	18100.00
0005435697334	24728	Economy	18100.00
0005435697393	24728	Economy	18100.00
0005435697500	24728	Economy	18100.00
0005435697417	24728	Economy	18100.00
0005435697392	24728	Economy	18100.00
0005435697323	24728	Economy	18100.00
0005435697378	24728	Economy	18100.00
0005435697372	24728	Economy	18100.00
0005435697383	24728	Economy	18100.00
0005435697416	24728	Economy	18100.00
0005435697327	24728	Economy	18100.00
0005435935069	24728	Economy	18100.00
0005435697328	24728	Economy	18100.00
0005432968839	18801	Economy	4400.00
0005432968836	18801	Economy	4400.00
0005433724839	18801	Economy	4400.00
0005433724840	18801	Economy	4400.00
0005433724837	18801	Economy	4400.00
0005432968835	18801	Economy	4400.00
0005433724836	18801	Economy	4400.00
0005433724838	18801	Economy	4400.00
0005432968845	18801	Economy	4400.00
0005432968834	18801	Economy	4400.00
0005433724841	18801	Economy	4400.00
0005432968862	21611	Economy	4400.00
0005433724783	21611	Economy	4400.00
0005433724785	21611	Economy	4400.00
0005432968863	21611	Economy	4400.00
0005433724784	21611	Economy	4400.00
0005432968860	21611	Economy	4400.00
0005432968861	21611	Economy	4400.00
0005433724802	21611	Economy	4400.00
0005433724808	21611	Economy	4400.00
0005433724782	21611	Economy	4400.00
0005433724809	21611	Economy	4400.00
0005434138825	7337	Business	23100.00
0005434138837	7337	Business	23100.00
0005434138883	7337	Business	23100.00
0005434138823	7337	Business	23100.00
0005434138833	7337	Business	23100.00
0005434138868	7337	Business	23100.00
0005434138874	7337	Business	23100.00
0005434138877	7337	Business	23100.00
0005434138860	7337	Business	23100.00
0005434138831	7337	Business	23100.00
0005434138853	7337	Business	23100.00
0005434138892	7337	Economy	7700.00
0005434138838	7337	Economy	7700.00
0005434138864	7337	Economy	7700.00
0005434138887	7337	Economy	7700.00
0005434138850	7337	Economy	7700.00
0005434138880	7337	Economy	7700.00
0005434138888	7337	Economy	7700.00
0005434138824	7337	Economy	7700.00
0005434138812	7337	Economy	7700.00
0005434138822	7337	Economy	8500.00
0005434138862	7337	Economy	8500.00
0005434138848	7337	Economy	8500.00
0005434138870	7337	Economy	8500.00
0005434138819	7337	Economy	8500.00
0005434138830	7337	Economy	7700.00
0005434138811	7337	Economy	7700.00
0005434087552	7337	Economy	7700.00
0005434138810	7337	Economy	7700.00
0005434138826	7337	Economy	7700.00
0005434138867	7337	Economy	7700.00
0005434138893	7337	Economy	7700.00
0005434138852	7337	Economy	7700.00
0005434138820	7337	Economy	7700.00
0005434087553	7337	Economy	7700.00
0005434138885	7337	Economy	7700.00
0005434087556	7337	Economy	7700.00
0005434138849	7337	Economy	7700.00
0005434138866	7337	Economy	7700.00
0005434138845	7337	Economy	7700.00
0005434138839	7337	Economy	7700.00
0005434138829	7337	Economy	7700.00
0005434138832	7337	Economy	7700.00
0005434138846	7337	Economy	7700.00
0005434138872	7337	Economy	7700.00
0005434138854	7337	Economy	7700.00
0005434138889	7337	Economy	7700.00
0005434138891	7337	Economy	7700.00
0005434138882	7337	Economy	7700.00
0005434138843	7337	Economy	7700.00
0005434087555	7337	Economy	7700.00
0005434138835	7337	Economy	7700.00
0005434138827	7337	Economy	7700.00
0005434138816	7337	Economy	7700.00
0005434138807	7337	Economy	7700.00
0005434138875	7337	Economy	7700.00
0005434138871	7337	Economy	7700.00
0005434138856	7337	Economy	7700.00
0005434138855	7337	Economy	7700.00
0005434138809	7337	Economy	7700.00
0005434138884	7337	Economy	7700.00
0005434138878	7337	Economy	7700.00
0005434138828	7337	Economy	7700.00
0005434138842	7337	Economy	7700.00
0005434138857	7337	Economy	7700.00
0005434138858	7337	Economy	7700.00
0005434138813	7337	Economy	7700.00
0005434138844	7337	Economy	7700.00
0005434138834	7337	Economy	7700.00
0005434138881	7337	Economy	7700.00
0005434138840	7337	Economy	7700.00
0005434138818	7337	Economy	7700.00
0005434138876	7337	Economy	7700.00
0005434138847	7337	Economy	7700.00
0005434138861	7337	Economy	7700.00
0005434138841	7337	Economy	7700.00
0005434087554	7337	Economy	7700.00
0005434138851	7337	Economy	7700.00
0005434138869	7337	Economy	7700.00
0005434138859	7337	Economy	7700.00
0005434138865	7337	Economy	7700.00
0005434138873	7337	Economy	7700.00
0005434138836	7337	Economy	7700.00
0005434138886	7337	Economy	7700.00
0005434138863	7337	Economy	7700.00
0005434138821	7337	Economy	7700.00
0005434138815	7337	Economy	7700.00
0005434138879	7337	Economy	7700.00
0005434138890	7337	Economy	7700.00
0005434138814	7337	Economy	7700.00
0005434138808	7337	Economy	7700.00
0005434138817	7337	Economy	7700.00
0005434138427	28554	Business	23100.00
0005434138065	28554	Business	23100.00
0005434138212	28554	Business	23100.00
0005434137712	28554	Business	23100.00
0005434138205	28554	Business	23100.00
0005434138081	28554	Business	23100.00
0005434138426	28554	Business	23100.00
0005434137796	28554	Business	23100.00
0005434137903	28554	Business	23100.00
0005434138305	28554	Business	23100.00
0005434137962	28554	Business	23100.00
0005434138258	28554	Economy	7700.00
0005434137971	28554	Economy	7700.00
0005434138216	28554	Economy	7700.00
0005434138111	28554	Economy	7700.00
0005434138113	28554	Economy	7700.00
0005434138208	28554	Economy	7700.00
0005434138035	28554	Economy	7700.00
0005434138071	28554	Economy	7700.00
0005434137867	28554	Economy	7700.00
0005434087506	28554	Economy	8500.00
0005434137963	28554	Economy	8500.00
0005434137954	28554	Economy	8500.00
0005434138408	28554	Economy	8500.00
0005434137899	28554	Economy	8500.00
0005434138450	28554	Economy	7700.00
0005434137679	28554	Economy	7700.00
0005434138454	28554	Economy	7700.00
0005434137902	28554	Economy	7700.00
0005434137986	28554	Economy	7700.00
0005434138179	28554	Economy	7700.00
0005434137855	28554	Economy	7700.00
0005434137901	28554	Economy	7700.00
0005434138324	28554	Economy	7700.00
0005434137976	28554	Economy	7700.00
0005434138135	28554	Economy	7700.00
0005434138122	28554	Economy	7700.00
0005434137295	28554	Economy	7700.00
0005434137708	28554	Economy	7700.00
0005434138139	28554	Economy	7700.00
0005434137900	28554	Economy	7700.00
0005434138082	28554	Economy	7700.00
0005434138451	28554	Economy	7700.00
0005434137904	28554	Economy	7700.00
0005434138262	28554	Economy	7700.00
0005434137936	28554	Economy	7700.00
0005434138095	28554	Economy	7700.00
0005434138107	28554	Economy	7700.00
0005434138323	28554	Economy	7700.00
0005434138034	28554	Economy	7700.00
0005434138271	28554	Economy	7700.00
0005434137957	28554	Economy	7700.00
0005434087522	28554	Economy	7700.00
0005434138052	28554	Economy	7700.00
0005434137890	28554	Economy	7700.00
0005434138157	28554	Economy	7700.00
0005434138158	28554	Economy	7700.00
0005434138053	28554	Economy	7700.00
0005434138245	28554	Economy	7700.00
0005434137959	28554	Economy	7700.00
0005434137822	28554	Economy	7700.00
0005434137797	28554	Economy	7700.00
0005434137825	28554	Economy	7700.00
0005434137958	28554	Economy	7700.00
0005434137711	28554	Economy	7700.00
0005434137294	28554	Economy	7700.00
0005434087535	28554	Economy	7700.00
0005434138244	28554	Economy	7700.00
0005434138121	28554	Economy	7700.00
0005434138013	28554	Economy	7700.00
0005434138028	28554	Economy	7700.00
0005434137645	28554	Economy	7700.00
0005434138348	28554	Economy	7700.00
0005434137977	28554	Economy	7700.00
0005434138072	28554	Economy	7700.00
0005434138096	28554	Economy	7700.00
0005434137997	28554	Economy	7700.00
0005434138209	28554	Economy	7700.00
0005434138094	28554	Economy	7700.00
0005434137965	28554	Economy	7700.00
0005434137827	28554	Economy	7700.00
0005434087519	28554	Economy	7700.00
0005434137868	28554	Economy	7700.00
0005434138369	28554	Economy	7700.00
0005434138422	28554	Economy	7700.00
0005434138349	28554	Economy	7700.00
0005434138247	28554	Economy	7700.00
0005434138027	28554	Economy	7700.00
0005435808320	1899	Economy	23900.00
0005435808327	1899	Economy	23900.00
0005435808326	1899	Economy	21700.00
0005435808319	1899	Economy	21700.00
0005435808321	1899	Economy	21700.00
0005434610258	1899	Economy	21700.00
0005433407535	1899	Economy	21700.00
0005434610260	1899	Economy	21700.00
0005434610257	1899	Economy	21700.00
0005435808316	1899	Economy	21700.00
0005435808324	1899	Economy	21700.00
0005435808318	1899	Economy	21700.00
0005435808323	1899	Economy	21700.00
0005435808325	1899	Economy	21700.00
0005434610261	1899	Economy	21700.00
0005434610259	1899	Economy	21700.00
0005435808322	1899	Economy	21700.00
0005433407536	1899	Economy	21700.00
0005435808317	1899	Economy	21700.00
0005434610213	23120	Economy	21700.00
0005434504234	16706	Economy	7600.00
0005434504080	16706	Economy	7600.00
0005434504102	16706	Economy	7600.00
0005434504141	16706	Economy	6900.00
0005434504187	16706	Economy	6900.00
0005434504035	16706	Economy	6900.00
0005434504079	16706	Economy	6900.00
0005434504120	16706	Economy	6900.00
0005434504313	16706	Economy	6900.00
0005434504033	16706	Economy	6900.00
0005434503932	16706	Economy	6900.00
0005434503990	16706	Economy	6900.00
0005434504372	16706	Economy	6900.00
0005434504274	16706	Economy	6900.00
0005434504235	16706	Economy	6900.00
0005434503933	16706	Economy	6900.00
0005434503982	16706	Economy	6900.00
0005434504128	16706	Economy	6900.00
0005434504044	16706	Economy	6900.00
0005434504030	16706	Economy	6900.00
0005434504112	16706	Economy	6900.00
0005434504017	16706	Economy	6900.00
0005434504127	16706	Economy	6900.00
0005434504077	16706	Economy	6900.00
0005434504034	16706	Economy	6900.00
0005434504108	16706	Economy	6900.00
0005434504025	16706	Economy	6900.00
0005434504122	16706	Economy	6900.00
0005434504289	16706	Economy	6900.00
0005434504026	16706	Economy	6900.00
0005434504275	16706	Economy	6900.00
0005434504092	16706	Economy	6900.00
0005434504209	16706	Economy	6900.00
0005434504095	16706	Economy	6900.00
0005434504373	16706	Economy	6900.00
0005434504121	16706	Economy	6900.00
0005434504103	16706	Economy	6900.00
0005434504070	16706	Economy	6900.00
0005434504067	16706	Economy	6900.00
0005434504458	22899	Economy	7600.00
0005434504443	22899	Economy	7600.00
0005434504435	22899	Economy	7600.00
0005434504437	22899	Economy	6900.00
0005434504457	22899	Economy	6900.00
0005434504456	22899	Economy	6900.00
0005434504434	22899	Economy	6900.00
0005434504444	22899	Economy	6900.00
0005434504462	22899	Economy	6900.00
0005434504439	22899	Economy	6900.00
0005434504440	22899	Economy	6900.00
0005434504428	22899	Economy	6900.00
0005434504447	22899	Economy	6900.00
0005434504429	22899	Economy	6900.00
0005434504452	22899	Economy	6900.00
0005434504427	22899	Economy	6900.00
0005434504463	22899	Economy	6900.00
0005434504451	22899	Economy	6900.00
0005434504445	22899	Economy	6900.00
0005434504448	22899	Economy	6900.00
0005434504431	22899	Economy	6900.00
0005434504461	22899	Economy	6900.00
0005434504438	22899	Economy	6900.00
0005434504424	22899	Economy	6900.00
0005434504425	22899	Economy	6900.00
0005434504460	22899	Economy	6900.00
0005434504455	22899	Economy	6900.00
0005434504446	22899	Economy	6900.00
0005434504459	22899	Economy	6900.00
0005434504449	22899	Economy	6900.00
0005434504442	22899	Economy	6900.00
0005434504430	22899	Economy	6900.00
0005434504453	22899	Economy	6900.00
0005434504450	22899	Economy	6900.00
0005434504426	22899	Economy	6900.00
0005434504441	22899	Economy	6900.00
0005434504436	22899	Economy	6900.00
0005434504433	22899	Economy	6900.00
0005434504454	22899	Economy	6900.00
0005434504432	22899	Economy	6900.00
0005435078476	2189	Economy	7700.00
0005435078466	2189	Economy	7700.00
0005435078462	2189	Economy	7700.00
0005435078465	2189	Economy	7000.00
0005433266697	2189	Economy	7000.00
0005433266717	2189	Economy	7000.00
0005433266703	2189	Economy	7000.00
0005435078479	2189	Economy	7000.00
0005435078473	2189	Economy	7000.00
0005433266716	2189	Economy	7000.00
0005433266707	2189	Economy	7000.00
0005435078478	2189	Economy	7000.00
0005433266756	2189	Economy	7000.00
0005435078463	2189	Economy	7000.00
0005435078474	2189	Economy	7000.00
0005435078464	2189	Economy	7000.00
0005433266748	2189	Economy	7000.00
0005435078470	2189	Economy	7000.00
0005435078475	2189	Economy	7000.00
0005435078468	2189	Economy	7000.00
0005433266754	2189	Economy	7000.00
0005433266712	2189	Economy	7000.00
0005435078471	2189	Economy	7000.00
0005435078469	2189	Economy	7000.00
0005435078467	2189	Economy	7000.00
0005435078477	2189	Economy	7000.00
0005435078472	2189	Economy	7000.00
0005435078342	24358	Economy	7700.00
0005433266801	24358	Economy	7700.00
0005435078362	24358	Economy	7000.00
0005433266799	24358	Economy	7000.00
0005433266800	24358	Economy	7000.00
0005435078328	24358	Economy	7000.00
0005433266803	24358	Economy	7000.00
0005435078329	24358	Economy	7000.00
0005435078394	24358	Economy	7000.00
0005435078380	24358	Economy	7000.00
0005433266802	24358	Economy	7000.00
0005435078410	24358	Economy	7000.00
0005435078393	24358	Economy	7000.00
0005435078383	24358	Economy	7000.00
0005433266797	24358	Economy	7000.00
0005435078384	24358	Economy	7000.00
0005433266796	24358	Economy	7000.00
0005433266804	24358	Economy	7000.00
0005435078341	24358	Economy	7000.00
0005433266798	24358	Economy	7000.00
0005435078381	24358	Economy	7000.00
0005433266795	24358	Economy	7000.00
0005434988827	6642	Economy	10800.00
0005435803286	6642	Economy	9800.00
0005434988822	6642	Economy	9800.00
0005434988823	6642	Economy	9800.00
0005434988824	6642	Economy	9800.00
0005435803287	6642	Economy	9800.00
0005434988825	6642	Economy	9800.00
0005434988821	6642	Economy	9800.00
0005434988829	6642	Economy	9800.00
0005434988830	6642	Economy	9800.00
0005434988828	6642	Economy	9800.00
0005434988826	6642	Economy	9800.00
0005434988831	6642	Economy	9800.00
0005435803255	23633	Economy	10800.00
0005434988697	23633	Economy	10800.00
0005434988696	23633	Economy	10800.00
0005434988709	23633	Economy	9800.00
0005434988667	23633	Economy	9800.00
0005434988675	23633	Economy	9800.00
0005434988674	23633	Economy	9800.00
0005434988686	23633	Economy	9800.00
0005434988708	23633	Economy	9800.00
0005434988703	23633	Economy	9800.00
0005435803254	23633	Economy	9800.00
0005435803256	23633	Economy	9800.00
0005435464524	23633	Economy	9800.00
0005434988679	23633	Economy	9800.00
0005435464525	23633	Economy	9800.00
0005434988704	23633	Economy	9800.00
0005435803257	23633	Economy	9800.00
0005434988678	23633	Economy	9800.00
0005434988671	23633	Economy	9800.00
0005433454892	30508	Business	9900.00
0005432383503	30508	Business	9900.00
0005433450159	30508	Business	9900.00
0005432383512	30508	Business	9900.00
0005432383522	30508	Business	9900.00
0005432383517	30508	Business	9900.00
0005432383502	30508	Business	9900.00
0005433450142	30508	Business	9900.00
0005433450143	30508	Business	9900.00
0005433450161	30508	Business	9900.00
0005432383520	30508	Economy	3300.00
0005432383498	30508	Economy	3300.00
0005433450149	30508	Economy	3300.00
0005432383500	30508	Economy	3300.00
0005433450144	30508	Economy	3300.00
0005432383507	30508	Economy	3600.00
0005433450147	30508	Economy	3600.00
0005432383519	30508	Economy	3600.00
0005432383529	30508	Economy	3300.00
0005432383526	30508	Economy	3300.00
0005433450145	30508	Economy	3300.00
0005432383499	30508	Economy	3300.00
0005432383496	30508	Economy	3300.00
0005432383506	30508	Economy	3300.00
0005433450146	30508	Economy	3300.00
0005432383513	30508	Economy	3300.00
0005432383489	30508	Economy	3300.00
0005432383494	30508	Economy	3300.00
0005432383516	30508	Economy	3300.00
0005433450157	30508	Economy	3300.00
0005433450148	30508	Economy	3300.00
0005432383527	30508	Economy	3300.00
0005432383508	30508	Economy	3300.00
0005432383531	30508	Economy	3300.00
0005432383490	30508	Economy	3300.00
0005432383509	30508	Economy	3300.00
0005432383488	30508	Economy	3300.00
0005432383511	30508	Economy	3300.00
0005433450162	30508	Economy	3300.00
0005432383510	30508	Economy	3300.00
0005432383530	30508	Economy	3300.00
0005433450153	30508	Economy	3300.00
0005433450156	30508	Economy	3300.00
0005433454893	30508	Economy	3300.00
0005432383532	30508	Economy	3300.00
0005433454894	30508	Economy	3300.00
0005432383497	30508	Economy	3300.00
0005433450152	30508	Economy	3300.00
0005433453775	30508	Economy	3300.00
0005432383515	30508	Economy	3300.00
0005432383521	30508	Economy	3300.00
0005432383504	30508	Economy	3300.00
0005433450160	30508	Economy	3300.00
0005432383518	30508	Economy	3300.00
0005432383505	30508	Economy	3300.00
0005433450154	30508	Economy	3300.00
0005433450150	30508	Economy	3300.00
0005432383501	30508	Economy	3300.00
0005432383514	30508	Economy	3300.00
0005433450141	30508	Economy	3300.00
0005433450151	30508	Economy	3300.00
0005432383492	30508	Economy	3300.00
0005432383493	30508	Economy	3300.00
0005433450155	30508	Economy	3300.00
0005432383528	30508	Economy	3300.00
0005432383491	30508	Economy	3300.00
0005433450158	30508	Economy	3300.00
0005432383495	30508	Economy	3300.00
0005432383524	30508	Economy	3300.00
0005433453776	30508	Economy	3300.00
0005432383523	30508	Economy	3300.00
0005432383525	30508	Economy	3300.00
0005432382944	31340	Business	9900.00
0005432383159	31340	Business	9900.00
0005432383058	31340	Business	9900.00
0005433449974	31340	Business	9900.00
0005432383034	31340	Business	9900.00
0005433449939	31340	Business	9900.00
0005432383089	31340	Business	9900.00
0005432383185	31340	Economy	3300.00
0005432383104	31340	Economy	3300.00
0005432383213	31340	Economy	3300.00
0005432383071	31340	Economy	3600.00
0005432383111	31340	Economy	3600.00
0005433449993	31340	Economy	3600.00
0005433451618	31340	Economy	3600.00
0005432383110	31340	Economy	3300.00
0005432383126	31340	Economy	3300.00
0005432383186	31340	Economy	3300.00
0005432383069	31340	Economy	3300.00
0005432383180	31340	Economy	3300.00
0005432383061	31340	Economy	3300.00
0005433453761	31340	Economy	3300.00
0005432383130	31340	Economy	3300.00
0005432383103	31340	Economy	3300.00
0005432383050	31340	Economy	3300.00
0005433449898	31340	Economy	3300.00
0005432383125	31340	Economy	3300.00
0005433453755	31340	Economy	3300.00
0005432383127	31340	Economy	3300.00
0005432382928	31340	Economy	3300.00
0005432383062	31340	Economy	3300.00
0005432383012	31340	Economy	3300.00
0005432382979	31340	Economy	3300.00
0005432383077	31340	Economy	3300.00
0005432383105	31340	Economy	3300.00
0005432383102	31340	Economy	3300.00
0005432383128	31340	Economy	3300.00
0005432383194	31340	Economy	3300.00
0005433453756	31340	Economy	3300.00
0005432383070	31340	Economy	3300.00
0005433450012	31340	Economy	3300.00
0005432383224	31340	Economy	3300.00
0005432383003	31340	Economy	3300.00
0005433449819	31340	Economy	3300.00
0005433449820	31340	Economy	3300.00
0005432383059	31340	Economy	3300.00
0005432383057	31340	Economy	3300.00
0005433449931	31340	Economy	3300.00
0005433449940	31340	Economy	3300.00
0005433453757	31340	Economy	3300.00
0005433449899	31340	Economy	3300.00
0005432383222	31340	Economy	3300.00
0005433449956	31340	Economy	3300.00
0005432383199	31340	Economy	3300.00
0005433451621	31340	Economy	3300.00
0005433449992	31340	Economy	3300.00
0005432383223	31340	Economy	3300.00
0005432383245	31340	Economy	3300.00
0005435548532	26473	Economy	23800.00
0005435548530	26473	Economy	23800.00
0005435548531	26473	Economy	23800.00
0005435548529	26473	Economy	23800.00
0005435548534	26473	Economy	23800.00
0005435548536	26473	Economy	23800.00
0005433788193	26473	Economy	23800.00
0005433788191	26473	Economy	23800.00
0005433788196	26473	Economy	23800.00
0005433788200	26473	Economy	23800.00
0005435548533	26473	Economy	23800.00
0005435548537	26473	Economy	23800.00
0005435548535	26473	Economy	23800.00
0005433788192	26473	Economy	23800.00
0005433131706	10794	Economy	17100.00
0005435299787	10794	Economy	17100.00
0005433131715	10794	Economy	15600.00
0005433131695	10794	Economy	15600.00
0005433126842	10794	Economy	15600.00
0005433126823	10794	Economy	15600.00
0005433126837	10794	Economy	15600.00
0005435304185	10794	Economy	15600.00
0005433126843	10794	Economy	15600.00
0005433131694	10794	Economy	15600.00
0005433131710	10794	Economy	15600.00
0005433126838	10794	Economy	15600.00
0005435304148	10794	Economy	15600.00
0005435304157	10794	Economy	15600.00
0005435299786	10794	Economy	15600.00
0005433131709	10794	Economy	15600.00
0005433129318	29705	Economy	17100.00
0005435302243	29705	Economy	17100.00
0005435299817	29705	Economy	17100.00
0005435302239	29705	Economy	15600.00
0005435302240	29705	Economy	15600.00
0005435299818	29705	Economy	15600.00
0005433129319	29705	Economy	15600.00
0005435302241	29705	Economy	15600.00
0005433126887	29705	Economy	15600.00
0005435299820	29705	Economy	15600.00
0005435302244	29705	Economy	15600.00
0005433126885	29705	Economy	15600.00
0005435299821	29705	Economy	15600.00
0005435302242	29705	Economy	15600.00
0005433129317	29705	Economy	15600.00
0005433129316	29705	Economy	15600.00
0005433126886	29705	Economy	15600.00
0005433126888	29705	Economy	15600.00
0005433129320	29705	Economy	15600.00
0005435299819	29705	Economy	15600.00
0005434287463	2383	Economy	17200.00
0005434287472	2383	Economy	17200.00
0005434287470	2383	Economy	15700.00
0005434287482	2383	Economy	15700.00
0005434287479	2383	Economy	15700.00
0005434287467	2383	Economy	15700.00
0005434287469	2383	Economy	15700.00
0005432264495	2383	Economy	15700.00
0005434287462	2383	Economy	15700.00
0005434287477	2383	Economy	15700.00
0005433110080	2383	Economy	15700.00
0005434287481	2383	Economy	15700.00
0005434287465	2383	Economy	15700.00
0005434287483	2383	Economy	15700.00
0005434287474	2383	Economy	15700.00
0005432264496	2383	Economy	15700.00
0005434287466	2383	Economy	15700.00
0005433110015	2383	Economy	15700.00
0005433110086	2383	Economy	15700.00
0005433110114	2383	Economy	15700.00
0005434287464	2383	Economy	15700.00
0005434287475	2383	Economy	15700.00
0005434287473	2383	Economy	15700.00
0005434287471	2383	Economy	15700.00
0005433110122	2383	Economy	15700.00
0005433110072	2383	Economy	15700.00
0005434287476	2383	Economy	15700.00
0005434287468	2383	Economy	15700.00
0005433110071	2383	Economy	15700.00
0005433110079	2383	Economy	15700.00
0005434287478	2383	Economy	15700.00
0005434287480	2383	Economy	15700.00
0005433110043	2383	Economy	15700.00
0005433110064	2383	Economy	15700.00
0005433110108	2383	Economy	15700.00
0005434287235	26830	Economy	17200.00
0005433110158	26830	Economy	17200.00
0005434287328	26830	Economy	17200.00
0005434287329	26830	Economy	15700.00
0005434287234	26830	Economy	15700.00
0005433110156	26830	Economy	15700.00
0005433110153	26830	Economy	15700.00
0005433110157	26830	Economy	15700.00
0005434287218	26830	Economy	15700.00
0005434287330	26830	Economy	15700.00
0005433110147	26830	Economy	15700.00
0005433110154	26830	Economy	15700.00
0005434287293	26830	Economy	15700.00
0005434287230	26830	Economy	15700.00
0005434287325	26830	Economy	15700.00
0005434287243	26830	Economy	15700.00
0005434287244	26830	Economy	15700.00
0005434287177	26830	Economy	15700.00
0005433110155	26830	Economy	15700.00
0005433110148	26830	Economy	15700.00
0005433110151	26830	Economy	15700.00
0005434287327	26830	Economy	15700.00
0005434287283	26830	Economy	15700.00
0005434287361	26830	Economy	15700.00
0005433110150	26830	Economy	15700.00
0005434287294	26830	Economy	15700.00
0005434287360	26830	Economy	15700.00
0005434287311	26830	Economy	15700.00
0005434287312	26830	Economy	15700.00
0005433110152	26830	Economy	15700.00
0005434287238	26830	Economy	15700.00
0005434287229	26830	Economy	15700.00
0005434287178	26830	Economy	15700.00
0005433110149	26830	Economy	15700.00
0005435856240	25499	Economy	25000.00
0005435856239	25499	Economy	22800.00
0005434269088	25499	Economy	22800.00
0005435856241	25499	Economy	22800.00
0005435856238	25499	Economy	22800.00
0005435856237	25499	Economy	22800.00
0005434269098	25499	Economy	22800.00
0005434272188	25499	Economy	22800.00
0005434269097	25499	Economy	22800.00
0005434269099	25499	Economy	22800.00
0005434272187	25499	Economy	22800.00
0005434272192	25499	Economy	22800.00
0005434273091	26630	Economy	25000.00
0005434272205	26630	Economy	22800.00
0005434272206	26630	Economy	22800.00
0005435856192	26630	Economy	22800.00
0005434272207	26630	Economy	22800.00
0005435856170	26630	Economy	22800.00
0005434273092	26630	Economy	22800.00
0005435856175	26630	Economy	22800.00
0005435856193	26630	Economy	22800.00
0005435856174	26630	Economy	22800.00
0005435856190	26630	Economy	22800.00
0005435314873	19078	Economy	24600.00
0005434520260	19078	Economy	24600.00
0005435314869	19078	Economy	22300.00
0005435314861	19078	Economy	22300.00
0005435314870	19078	Economy	22300.00
0005434520218	19078	Economy	22300.00
0005434520255	19078	Economy	22300.00
0005434520228	19078	Economy	22300.00
0005435314867	19078	Economy	22300.00
0005434520205	19078	Economy	22300.00
0005434520258	19078	Economy	22300.00
0005435314866	19078	Economy	22300.00
0005434520261	19078	Economy	22300.00
0005435314859	19078	Economy	22300.00
0005435314872	19078	Economy	22300.00
0005435314865	19078	Economy	22300.00
0005435314860	19078	Economy	22300.00
0005434520201	19078	Economy	22300.00
0005434520249	19078	Economy	22300.00
0005435314863	19078	Economy	22300.00
0005435314868	19078	Economy	22300.00
0005435314871	19078	Economy	22300.00
0005434520242	19078	Economy	22300.00
0005434520224	19078	Economy	22300.00
0005434520251	19078	Economy	22300.00
0005434520234	19078	Economy	22300.00
0005434520200	19078	Economy	22300.00
0005434520219	19078	Economy	22300.00
0005434520265	19078	Economy	22300.00
0005434520257	19078	Economy	22300.00
0005434520248	19078	Economy	22300.00
0005434520223	19078	Economy	22300.00
0005434520250	19078	Economy	22300.00
0005434520252	19078	Economy	22300.00
0005434520214	19078	Economy	22300.00
0005434520259	19078	Economy	22300.00
0005434520247	19078	Economy	22300.00
0005435314864	19078	Economy	22300.00
0005435314862	19078	Economy	22300.00
0005433874375	7788	Economy	19200.00
0005433874381	7788	Economy	19200.00
0005433874373	7788	Economy	17400.00
0005433874376	7788	Economy	17400.00
0005433874379	7788	Economy	17400.00
0005433874370	7788	Economy	17400.00
0005433874378	7788	Economy	17400.00
0005433874371	7788	Economy	17400.00
0005433874383	7788	Economy	17400.00
0005433874372	7788	Economy	17400.00
0005433874380	7788	Economy	17400.00
0005433874377	7788	Economy	17400.00
0005433874382	7788	Economy	17400.00
0005433874374	7788	Economy	17400.00
0005433874358	32625	Economy	17400.00
0005433874348	32625	Economy	17400.00
0005433874341	32625	Economy	17400.00
0005433874355	32625	Economy	17400.00
0005433874352	32625	Economy	17400.00
0005433874349	32625	Economy	17400.00
0005433874351	32625	Economy	17400.00
0005433874347	32625	Economy	17400.00
0005433874359	32625	Economy	17400.00
0005433874350	32625	Economy	17400.00
0005433868757	4791	Economy	19400.00
0005433868796	4791	Economy	19400.00
0005435860481	4791	Economy	19400.00
0005433868761	4791	Economy	19400.00
0005433868795	4791	Economy	17600.00
0005433868767	4791	Economy	17600.00
0005433868784	4791	Economy	17600.00
0005433868783	4791	Economy	17600.00
0005433868758	4791	Economy	17600.00
0005433868766	4791	Economy	17600.00
0005433868753	4791	Economy	17600.00
0005435860470	4791	Economy	17600.00
0005433868764	4791	Economy	17600.00
0005433868773	4791	Economy	17600.00
0005433868772	4791	Economy	17600.00
0005433868760	4791	Economy	17600.00
0005433868777	4791	Economy	17600.00
0005433868768	4791	Economy	17600.00
0005433868765	4791	Economy	17600.00
0005433868792	4791	Economy	17600.00
0005435860489	4791	Economy	17600.00
0005433868781	4791	Economy	17600.00
0005433868771	4791	Economy	17600.00
0005433868785	4791	Economy	17600.00
0005433868782	4791	Economy	17600.00
0005433868755	4791	Economy	17600.00
0005433868793	4791	Economy	17600.00
0005433868780	4791	Economy	17600.00
0005435860488	4791	Economy	17600.00
0005433868769	4791	Economy	17600.00
0005433868789	4791	Economy	17600.00
0005433868778	4791	Economy	17600.00
0005433868762	4791	Economy	17600.00
0005433868770	4791	Economy	17600.00
0005433868759	4791	Economy	17600.00
0005433868794	4791	Economy	17600.00
0005433868779	4791	Economy	17600.00
0005433868791	4791	Economy	17600.00
0005433868788	4791	Economy	17600.00
0005433868774	4791	Economy	17600.00
0005433868756	4791	Economy	17600.00
0005433868775	4791	Economy	17600.00
0005433868754	4791	Economy	17600.00
0005433868790	4791	Economy	17600.00
0005433868787	4791	Economy	17600.00
0005433868763	4791	Economy	17600.00
0005433868786	4791	Economy	17600.00
0005433868776	4791	Economy	17600.00
0005433868500	32617	Economy	19400.00
0005433868203	32617	Economy	17600.00
0005433868352	32617	Economy	17600.00
0005433868528	32617	Economy	17600.00
0005435860512	32617	Economy	17600.00
0005433868471	32617	Economy	17600.00
0005433868260	32617	Economy	17600.00
0005433868391	32617	Economy	17600.00
0005435860511	32617	Economy	17600.00
0005433868321	32617	Economy	17600.00
0005433868494	32617	Economy	17600.00
0005433868392	32617	Economy	17600.00
0005435860513	32617	Economy	17600.00
0005433868181	32617	Economy	17600.00
0005433868470	32617	Economy	17600.00
0005433868495	32617	Economy	17600.00
0005433868502	32617	Economy	17600.00
0005433868353	32617	Economy	17600.00
0005433868452	32617	Economy	17600.00
0005433868435	32617	Economy	17600.00
0005433868359	32617	Economy	17600.00
0005433868360	32617	Economy	17600.00
0005433868322	32617	Economy	17600.00
0005433868278	32617	Economy	17600.00
0005433868261	32617	Economy	17600.00
0005433868420	32617	Economy	17600.00
0005433868348	32617	Economy	17600.00
0005433868320	32617	Economy	17600.00
0005433868501	32617	Economy	17600.00
0005433868557	32617	Economy	17600.00
0005433868550	32617	Economy	17600.00
0005433868279	32617	Economy	17600.00
0005433868601	32617	Economy	17600.00
0005433868358	32617	Economy	17600.00
0005433868131	32617	Economy	17600.00
0005433868558	32617	Economy	17600.00
0005433868381	32617	Economy	17600.00
0005433868364	32617	Economy	17600.00
0005433868551	32617	Economy	17600.00
0005433868472	32617	Economy	17600.00
0005433868323	32617	Economy	17600.00
0005433868315	32617	Economy	17600.00
0005434461665	3429	Economy	24800.00
0005435911441	3429	Economy	22600.00
0005434663518	3429	Economy	22600.00
0005434663522	3429	Economy	22600.00
0005435911455	3429	Economy	22600.00
0005434460523	3429	Economy	22600.00
0005435911440	3429	Economy	22600.00
0005435911427	3429	Economy	22600.00
0005434461664	3429	Economy	22600.00
0005434663527	3429	Economy	22600.00
0005434663519	3429	Economy	22600.00
0005435911469	3429	Economy	22600.00
0005435911470	3429	Economy	22600.00
0005435911422	3429	Economy	22600.00
0005434663514	3429	Economy	22600.00
0005435911421	3429	Economy	22600.00
0005434663516	3429	Economy	22600.00
0005434663526	3429	Economy	22600.00
0005434663521	3429	Economy	22600.00
0005434663517	3429	Economy	22600.00
0005434460524	3429	Economy	22600.00
0005434663515	3429	Economy	22600.00
0005434663520	3429	Economy	22600.00
0005434663525	3429	Economy	22600.00
0005434663523	3429	Economy	22600.00
0005434663524	3429	Economy	22600.00
0005435911512	12485	Economy	24800.00
0005435911518	12485	Economy	24800.00
0005434663440	12485	Economy	24800.00
0005434663375	12485	Economy	22600.00
0005434663390	12485	Economy	22600.00
0005434663394	12485	Economy	22600.00
0005434460488	12485	Economy	22600.00
0005434460498	12485	Economy	22600.00
0005435911514	12485	Economy	22600.00
0005434663389	12485	Economy	22600.00
0005434462783	12485	Economy	22600.00
0005434663346	12485	Economy	22600.00
0005434663441	12485	Economy	22600.00
0005434663411	12485	Economy	22600.00
0005434663456	12485	Economy	22600.00
0005434663393	12485	Economy	22600.00
0005434663414	12485	Economy	22600.00
0005434663293	12485	Economy	22600.00
0005434663373	12485	Economy	22600.00
0005434462773	12485	Economy	22600.00
0005434462780	12485	Economy	22600.00
0005434663410	12485	Economy	22600.00
0005435911511	12485	Economy	22600.00
0005434460492	12485	Economy	22600.00
0005435911519	12485	Economy	22600.00
0005435911517	12485	Economy	22600.00
0005434663374	12485	Economy	22600.00
0005434663430	12485	Economy	22600.00
0005435911516	12485	Economy	22600.00
0005434460489	12485	Economy	22600.00
0005434460505	12485	Economy	22600.00
0005434462785	12485	Economy	22600.00
0005434460490	12485	Economy	22600.00
0005434460491	12485	Economy	22600.00
0005435911513	12485	Economy	22600.00
0005434460499	12485	Economy	22600.00
0005435911515	12485	Economy	22600.00
0005434663292	12485	Economy	22600.00
0005434663388	12485	Economy	22600.00
0005434462789	12485	Economy	22600.00
0005434663372	12485	Economy	22600.00
0005434462786	12485	Economy	22600.00
0005434663367	12485	Economy	22600.00
0005435860511	14517	Economy	18500.00
0005433868359	14517	Economy	18500.00
0005433868279	14517	Economy	16800.00
0005433868452	14517	Economy	16800.00
0005433868557	14517	Economy	16800.00
0005433868494	14517	Economy	16800.00
0005433868181	14517	Economy	16800.00
0005433868381	14517	Economy	16800.00
0005433868364	14517	Economy	16800.00
0005433868278	14517	Economy	16800.00
0005433868391	14517	Economy	16800.00
0005433868472	14517	Economy	16800.00
0005433868321	14517	Economy	16800.00
0005433868353	14517	Economy	16800.00
0005433868358	14517	Economy	16800.00
0005433868320	14517	Economy	16800.00
0005433868420	14517	Economy	16800.00
0005433868495	14517	Economy	16800.00
0005433868323	14517	Economy	16800.00
0005433868501	14517	Economy	16800.00
0005433868352	14517	Economy	16800.00
0005433868203	14517	Economy	16800.00
0005435860512	14517	Economy	16800.00
0005433868260	14517	Economy	16800.00
0005433868500	14517	Economy	16800.00
0005433868471	14517	Economy	16800.00
0005433868550	14517	Economy	16800.00
0005433868322	14517	Economy	16800.00
0005433868435	14517	Economy	16800.00
0005433868360	14517	Economy	16800.00
0005433868528	14517	Economy	16800.00
0005433868558	14517	Economy	16800.00
0005433868261	14517	Economy	16800.00
0005433868315	14517	Economy	16800.00
0005433868131	14517	Economy	16800.00
0005435860513	14517	Economy	16800.00
0005433868502	14517	Economy	16800.00
0005433868601	14517	Economy	16800.00
0005433868348	14517	Economy	16800.00
0005433868392	14517	Economy	16800.00
0005433868470	14517	Economy	16800.00
0005433868551	14517	Economy	16800.00
0005433868751	32699	Economy	18500.00
0005433868732	32699	Economy	18500.00
0005433868743	32699	Economy	18500.00
0005433868740	32699	Economy	18500.00
0005433868730	32699	Economy	16800.00
0005433868731	32699	Economy	16800.00
0005433868726	32699	Economy	16800.00
0005433868727	32699	Economy	16800.00
0005433868719	32699	Economy	16800.00
0005433868741	32699	Economy	16800.00
0005433868750	32699	Economy	16800.00
0005433868722	32699	Economy	16800.00
0005433868713	32699	Economy	16800.00
0005433868717	32699	Economy	16800.00
0005433868745	32699	Economy	16800.00
0005433868725	32699	Economy	16800.00
0005433868720	32699	Economy	16800.00
0005433868739	32699	Economy	16800.00
0005435860479	32699	Economy	16800.00
0005433868712	32699	Economy	16800.00
0005433868721	32699	Economy	16800.00
0005433868718	32699	Economy	16800.00
0005433868714	32699	Economy	16800.00
0005433868716	32699	Economy	16800.00
0005433868723	32699	Economy	16800.00
0005433868747	32699	Economy	16800.00
0005433868711	32699	Economy	16800.00
0005433868729	32699	Economy	16800.00
0005433868733	32699	Economy	16800.00
0005433868746	32699	Economy	16800.00
0005435860478	32699	Economy	16800.00
0005433868738	32699	Economy	16800.00
0005433868715	32699	Economy	16800.00
0005433868748	32699	Economy	16800.00
0005433868735	32699	Economy	16800.00
0005433868752	32699	Economy	16800.00
0005433868734	32699	Economy	16800.00
0005433868737	32699	Economy	16800.00
0005433868736	32699	Economy	16800.00
0005433868744	32699	Economy	16800.00
0005433868728	32699	Economy	16800.00
0005433868742	32699	Economy	16800.00
0005435860474	32699	Economy	16800.00
0005433868724	32699	Economy	16800.00
0005435860473	32699	Economy	16800.00
0005433868749	32699	Economy	16800.00
0005432799402	12134	Economy	4900.00
0005432799398	12134	Economy	4900.00
0005432799460	12134	Economy	4900.00
0005432799500	12134	Economy	4400.00
0005432799358	12134	Economy	4400.00
0005432799371	12134	Economy	4400.00
0005432799497	12134	Economy	4400.00
0005432799386	12134	Economy	4400.00
0005432799372	12134	Economy	4400.00
0005432799468	12134	Economy	4400.00
0005432799464	12134	Economy	4400.00
0005432799577	12134	Economy	4400.00
0005432799449	12134	Economy	4400.00
0005432799397	12134	Economy	4400.00
0005432799578	12134	Economy	4400.00
0005432799453	12134	Economy	4400.00
0005432799463	12134	Economy	4400.00
0005432799516	12134	Economy	4400.00
0005432799552	12134	Economy	4400.00
0005432799461	12134	Economy	4400.00
0005432799502	12134	Economy	4400.00
0005432799503	12134	Economy	4400.00
0005432799475	12134	Economy	4400.00
0005432799522	12134	Economy	4400.00
0005432799492	12134	Economy	4400.00
0005432799418	12134	Economy	4400.00
0005432799651	14824	Economy	4900.00
0005432799653	14824	Economy	4900.00
0005432799648	14824	Economy	4900.00
0005432799650	14824	Economy	4400.00
0005432799666	14824	Economy	4400.00
0005432799649	14824	Economy	4400.00
0005432799665	14824	Economy	4400.00
0005432799675	14824	Economy	4400.00
0005432799663	14824	Economy	4400.00
0005432799669	14824	Economy	4400.00
0005432799647	14824	Economy	4400.00
0005432799662	14824	Economy	4400.00
0005432799659	14824	Economy	4400.00
0005432799657	14824	Economy	4400.00
0005432799655	14824	Economy	4400.00
0005432799673	14824	Economy	4400.00
0005432799674	14824	Economy	4400.00
0005432799667	14824	Economy	4400.00
0005432799672	14824	Economy	4400.00
0005432799652	14824	Economy	4400.00
0005432799660	14824	Economy	4400.00
0005432799670	14824	Economy	4400.00
0005432799671	14824	Economy	4400.00
0005432799658	14824	Economy	4400.00
0005432799664	14824	Economy	4400.00
0005432799656	14824	Economy	4400.00
0005432799661	14824	Economy	4400.00
0005432799654	14824	Economy	4400.00
0005432799668	14824	Economy	4400.00
0005434408254	7061	Business	49100.00
0005434408259	7061	Business	49100.00
0005434408297	7061	Business	49100.00
0005434408301	7061	Business	49100.00
0005434408271	7061	Business	49100.00
0005434408260	7061	Business	49100.00
0005435311051	7061	Business	49100.00
0005434299762	7061	Business	49100.00
0005434408256	7061	Business	49100.00
0005434299752	7061	Business	49100.00
0005435311015	7061	Economy	16400.00
0005434299743	7061	Economy	16400.00
0005434299763	7061	Economy	16400.00
0005435311039	7061	Economy	16400.00
0005434408305	7061	Economy	16400.00
0005435311046	7061	Economy	16400.00
0005434408257	7061	Economy	16400.00
0005434299758	7061	Economy	16400.00
0005434408308	7061	Economy	16400.00
0005432153996	7061	Economy	16400.00
0005434408264	7061	Economy	16400.00
0005434408289	7061	Economy	16400.00
0005434408306	7061	Economy	16400.00
0005434299745	7061	Economy	16400.00
0005434408273	7061	Economy	16400.00
0005434408280	7061	Economy	16400.00
0005434299751	7061	Economy	16400.00
0005434408315	7061	Economy	16400.00
0005434408285	7061	Economy	16400.00
0005434408262	7061	Economy	16400.00
0005434408296	7061	Economy	16400.00
0005434408309	7061	Economy	16400.00
0005434299748	7061	Economy	16400.00
0005432153994	7061	Economy	16400.00
0005434408288	7061	Economy	16400.00
0005434299742	7061	Economy	16400.00
0005435311049	7061	Economy	16400.00
0005434299755	7061	Economy	16400.00
0005434299765	7061	Economy	16400.00
0005432108270	7061	Economy	16400.00
0005434408284	7061	Economy	16400.00
0005434408286	7061	Economy	16400.00
0005434299749	7061	Economy	16400.00
0005434299764	7061	Economy	16400.00
0005435311050	7061	Economy	16400.00
0005434408287	7061	Economy	16400.00
0005434408281	7061	Economy	16400.00
0005432153997	7061	Economy	16400.00
0005434408269	7061	Economy	18000.00
0005434299759	7061	Economy	18000.00
0005434408293	7061	Economy	18000.00
0005434408267	7061	Economy	18000.00
0005434408265	7061	Economy	18000.00
0005435293262	7061	Economy	16400.00
0005434408266	7061	Economy	16400.00
0005434408258	7061	Economy	16400.00
0005434408299	7061	Economy	16400.00
0005434408300	7061	Economy	16400.00
0005434408317	7061	Economy	16400.00
0005434408274	7061	Economy	16400.00
0005432108272	7061	Economy	16400.00
0005434408275	7061	Economy	16400.00
0005434408255	7061	Economy	16400.00
0005432153995	7061	Economy	16400.00
0005435311040	7061	Economy	16400.00
0005434408313	7061	Economy	16400.00
0005432153998	7061	Economy	16400.00
0005434299754	7061	Economy	16400.00
0005432108273	7061	Economy	16400.00
0005434408302	7061	Economy	16400.00
0005434408272	7061	Economy	16400.00
0005434299744	7061	Economy	16400.00
0005434408261	7061	Economy	16400.00
0005434408290	7061	Economy	16400.00
0005435293267	7061	Economy	16400.00
0005434408277	7061	Economy	16400.00
0005432153993	7061	Economy	16400.00
0005434408314	7061	Economy	16400.00
0005434299756	7061	Economy	16400.00
0005434299750	7061	Economy	16400.00
0005435311061	7061	Economy	16400.00
0005434408279	7061	Economy	16400.00
0005434408303	7061	Economy	16400.00
0005434299761	7061	Economy	16400.00
0005435293263	7061	Economy	16400.00
0005434408270	7061	Economy	16400.00
0005434408310	7061	Economy	16400.00
0005435293247	7061	Economy	16400.00
0005434408282	7061	Economy	16400.00
0005434299757	7061	Economy	16400.00
0005432108271	7061	Economy	16400.00
0005434408278	7061	Economy	16400.00
0005435293266	7061	Economy	16400.00
0005432153999	7061	Economy	16400.00
0005434408268	7061	Economy	16400.00
0005435293256	7061	Economy	16400.00
0005434299746	7061	Economy	16400.00
0005434299753	7061	Economy	16400.00
0005435311014	7061	Economy	16400.00
0005434408283	7061	Economy	16400.00
0005434408291	7061	Economy	16400.00
0005434408295	7061	Economy	16400.00
0005434408298	7061	Economy	16400.00
0005434299747	7061	Economy	16400.00
0005434408312	7061	Economy	16400.00
0005435293222	7061	Economy	16400.00
0005434408307	7061	Economy	16400.00
0005434408304	7061	Economy	16400.00
0005434299760	7061	Economy	16400.00
0005435311055	7061	Economy	16400.00
0005434408292	7061	Economy	16400.00
0005434408263	7061	Economy	16400.00
0005434408316	7061	Economy	16400.00
0005435311047	7061	Economy	16400.00
0005434408276	7061	Economy	16400.00
0005435311064	7061	Economy	16400.00
0005434408311	7061	Economy	16400.00
0005434408294	7061	Economy	16400.00
0005434407724	26893	Business	49100.00
0005432058412	26893	Business	49100.00
0005434407618	26893	Business	49100.00
0005435293360	26893	Business	49100.00
0005434407456	26893	Business	49100.00
0005435311149	26893	Business	49100.00
0005434407689	26893	Business	49100.00
0005434407447	26893	Business	49100.00
0005434407703	26893	Business	49100.00
0005434299471	26893	Business	49100.00
0005434407403	26893	Business	49100.00
0005435311143	26893	Business	49100.00
0005435293359	26893	Economy	16400.00
0005434407846	26893	Economy	16400.00
0005435311141	26893	Economy	16400.00
0005434299612	26893	Economy	16400.00
0005434407728	26893	Economy	16400.00
0005435293355	26893	Economy	16400.00
0005434407613	26893	Economy	16400.00
0005434407718	26893	Economy	16400.00
0005434407555	26893	Economy	16400.00
0005435311140	26893	Economy	16400.00
0005434299601	26893	Economy	16400.00
0005435311153	26893	Economy	16400.00
0005434407725	26893	Economy	16400.00
0005434407246	26893	Economy	16400.00
0005434407697	26893	Economy	16400.00
0005434299557	26893	Economy	16400.00
0005434407391	26893	Economy	16400.00
0005434299532	26893	Economy	16400.00
0005435293357	26893	Economy	16400.00
0005434407442	26893	Economy	16400.00
0005434407609	26893	Economy	16400.00
0005434299505	26893	Economy	16400.00
0005434407796	26893	Economy	16400.00
0005434407402	26893	Economy	16400.00
0005434407844	26893	Economy	16400.00
0005434299590	26893	Economy	16400.00
0005434407702	26893	Economy	16400.00
0005434407784	26893	Economy	16400.00
0005434407793	26893	Economy	16400.00
0005435293351	26893	Economy	16400.00
0005434299575	26893	Economy	16400.00
0005434408011	26893	Economy	16400.00
0005434407628	26893	Economy	16400.00
0005435293353	26893	Economy	16400.00
0005435311142	26893	Economy	16400.00
0005434299587	26893	Economy	18000.00
0005432058410	26893	Economy	18000.00
0005434299576	26893	Economy	18000.00
0005434299504	26893	Economy	18000.00
0005435293358	26893	Economy	18000.00
0005434407699	26893	Economy	16400.00
0005434407685	26893	Economy	16400.00
0005434299620	26893	Economy	16400.00
0005435293352	26893	Economy	16400.00
0005434407902	26893	Economy	16400.00
0005434407568	26893	Economy	16400.00
0005434407695	26893	Economy	16400.00
0005434299542	26893	Economy	16400.00
0005434407443	26893	Economy	16400.00
0005435311154	26893	Economy	16400.00
0005434407608	26893	Economy	16400.00
0005434407573	26893	Economy	16400.00
0005434407783	26893	Economy	16400.00
0005434407845	26893	Economy	16400.00
0005435311155	26893	Economy	16400.00
0005434299621	26893	Economy	16400.00
0005434407318	26893	Economy	16400.00
0005432058411	26893	Economy	16400.00
0005435293354	26893	Economy	16400.00
0005435311150	26893	Economy	16400.00
0005435311148	26893	Economy	16400.00
0005434407677	26893	Economy	16400.00
0005434299572	26893	Economy	16400.00
0005434408010	26893	Economy	16400.00
0005434407682	26893	Economy	16400.00
0005435311146	26893	Economy	16400.00
0005434407629	26893	Economy	16400.00
0005434408056	26893	Economy	16400.00
0005434407619	26893	Economy	16400.00
0005435311152	26893	Economy	16400.00
0005434407474	26893	Economy	16400.00
0005434407651	26893	Economy	16400.00
0005434407794	26893	Economy	16400.00
0005434407698	26893	Economy	16400.00
0005432058409	26893	Economy	16400.00
0005435293356	26893	Economy	16400.00
0005435311147	26893	Economy	16400.00
0005434407452	26893	Economy	16400.00
0005434299562	26893	Economy	16400.00
0005434299571	26893	Economy	16400.00
0005434299531	26893	Economy	16400.00
0005435311139	26893	Economy	16400.00
0005435293361	26893	Economy	16400.00
0005434407620	26893	Economy	16400.00
0005434407650	26893	Economy	16400.00
0005434407686	26893	Economy	16400.00
0005434407713	26893	Economy	16400.00
0005435311144	26893	Economy	16400.00
0005434407849	26893	Economy	16400.00
0005435311156	26893	Economy	16400.00
0005435293350	26893	Economy	16400.00
0005435311151	26893	Economy	16400.00
0005435311145	26893	Economy	16400.00
0005435293349	26893	Economy	16400.00
0005432604669	6455	Economy	16500.00
0005432604666	6455	Economy	16500.00
0005432604675	6455	Economy	16500.00
0005432604680	6455	Economy	15000.00
0005432604679	6455	Economy	15000.00
0005432604688	6455	Economy	15000.00
0005432604690	6455	Economy	15000.00
0005432604664	6455	Economy	15000.00
0005432604694	6455	Economy	15000.00
0005432604668	6455	Economy	15000.00
0005432604656	6455	Economy	15000.00
0005432604682	6455	Economy	15000.00
0005432604660	6455	Economy	15000.00
0005432604681	6455	Economy	15000.00
0005435220489	6455	Economy	15000.00
0005432604684	6455	Economy	15000.00
0005432604658	6455	Economy	15000.00
0005432604671	6455	Economy	15000.00
0005432604663	6455	Economy	15000.00
0005432604665	6455	Economy	15000.00
0005432604676	6455	Economy	15000.00
0005432604677	6455	Economy	15000.00
0005432604683	6455	Economy	15000.00
0005432604662	6455	Economy	15000.00
0005432604672	6455	Economy	15000.00
0005432604689	6455	Economy	15000.00
0005432604667	6455	Economy	15000.00
0005434512150	6455	Economy	15000.00
0005432604691	6455	Economy	15000.00
0005432604686	6455	Economy	15000.00
0005432604685	6455	Economy	15000.00
0005432604687	6455	Economy	15000.00
0005432604661	6455	Economy	15000.00
0005432604659	6455	Economy	15000.00
0005432604692	6455	Economy	15000.00
0005432604673	6455	Economy	15000.00
0005432604674	6455	Economy	15000.00
0005432604670	6455	Economy	15000.00
0005432604695	6455	Economy	15000.00
0005432604693	6455	Economy	15000.00
0005435218115	6455	Economy	15000.00
0005432604678	6455	Economy	15000.00
0005432604657	6455	Economy	15000.00
0005435218113	6455	Economy	15000.00
0005432604297	21397	Economy	16500.00
0005432604324	21397	Economy	16500.00
0005432604211	21397	Economy	16500.00
0005432604225	21397	Economy	16500.00
0005432604384	21397	Economy	15000.00
0005432604296	21397	Economy	15000.00
0005432604412	21397	Economy	15000.00
0005432604292	21397	Economy	15000.00
0005432604274	21397	Economy	15000.00
0005434512099	21397	Economy	15000.00
0005432604281	21397	Economy	15000.00
0005432604149	21397	Economy	15000.00
0005432604446	21397	Economy	15000.00
0005432604410	21397	Economy	15000.00
0005432604413	21397	Economy	15000.00
0005432604157	21397	Economy	15000.00
0005432604077	21397	Economy	15000.00
0005434512098	21397	Economy	15000.00
0005432604310	21397	Economy	15000.00
0005432604385	21397	Economy	15000.00
0005432604010	21397	Economy	15000.00
0005432604213	21397	Economy	15000.00
0005432604052	21397	Economy	15000.00
0005432604323	21397	Economy	15000.00
0005432604534	21397	Economy	15000.00
0005432604309	21397	Economy	15000.00
0005432604051	21397	Economy	15000.00
0005432604192	21397	Economy	15000.00
0005432604386	21397	Economy	15000.00
0005432604291	21397	Economy	15000.00
0005432604221	21397	Economy	15000.00
0005432604346	21397	Economy	15000.00
0005432604170	21397	Economy	15000.00
0005432604273	21397	Economy	15000.00
0005432604161	21397	Economy	15000.00
0005432604171	21397	Economy	15000.00
0005432604222	21397	Economy	15000.00
0005432604191	21397	Economy	15000.00
0005432604162	21397	Economy	15000.00
0005432604172	21397	Economy	15000.00
0005434512097	21397	Economy	15000.00
0005432604190	21397	Economy	15000.00
0005432604271	21397	Economy	15000.00
0005432604287	21397	Economy	15000.00
0005432604229	21397	Economy	15000.00
0005432604299	21397	Economy	15000.00
0005432604148	21397	Economy	15000.00
0005434907103	15024	Business	18900.00
0005433251740	15024	Business	18900.00
0005434907121	15024	Business	18900.00
0005433251736	15024	Business	18900.00
0005434907240	15024	Business	18900.00
0005434907183	15024	Business	18900.00
0005433251726	15024	Business	18900.00
0005434907221	15024	Business	18900.00
0005434907112	15024	Business	18900.00
0005434907092	15024	Business	18900.00
0005433251725	15024	Business	18900.00
0005433251719	15024	Business	18900.00
0005434907082	15024	Economy	6300.00
0005434907064	15024	Economy	6300.00
0005434907113	15024	Economy	6300.00
0005434907150	15024	Economy	6300.00
0005434907123	15024	Economy	6300.00
0005434907283	15024	Economy	6300.00
0005433251733	15024	Economy	6300.00
0005434907057	15024	Economy	6300.00
0005434907315	15024	Economy	6900.00
0005434906995	15024	Economy	6900.00
0005434907237	15024	Economy	6900.00
0005434907125	15024	Economy	6900.00
0005433251748	15024	Economy	6900.00
0005433251731	15024	Economy	6300.00
0005434907212	15024	Economy	6300.00
0005433251744	15024	Economy	6300.00
0005434907034	15024	Economy	6300.00
0005433251746	15024	Economy	6300.00
0005433251730	15024	Economy	6300.00
0005434907203	15024	Economy	6300.00
0005434907171	15024	Economy	6300.00
0005434907124	15024	Economy	6300.00
0005434906950	15024	Economy	6300.00
0005433251735	15024	Economy	6300.00
0005433251727	15024	Economy	6300.00
0005434907164	15024	Economy	6300.00
0005434907036	15024	Economy	6300.00
0005434907194	15024	Economy	6300.00
0005434907035	15024	Economy	6300.00
0005433251732	15024	Economy	6300.00
0005433251747	15024	Economy	6300.00
0005434907236	15024	Economy	6300.00
0005434907223	15024	Economy	6300.00
0005434907099	15024	Economy	6300.00
0005434907231	15024	Economy	6300.00
0005434907151	15024	Economy	6300.00
0005434907114	15024	Economy	6300.00
0005433251737	15024	Economy	6300.00
0005433251738	15024	Economy	6300.00
0005433251742	15024	Economy	6300.00
0005433251728	15024	Economy	6300.00
0005433251729	15024	Economy	6300.00
0005433251724	15024	Economy	6300.00
0005433251720	15024	Economy	6300.00
0005433251723	15024	Economy	6300.00
0005433251743	15024	Economy	6300.00
0005434906929	15024	Economy	6300.00
0005433251718	15024	Economy	6300.00
0005434907135	15024	Economy	6300.00
0005434907115	15024	Economy	6300.00
0005434907168	15024	Economy	6300.00
0005433251741	15024	Economy	6300.00
0005434907063	15024	Economy	6300.00
0005434907220	15024	Economy	6300.00
0005434907058	15024	Economy	6300.00
0005434907163	15024	Economy	6300.00
0005434907083	15024	Economy	6300.00
0005433251734	15024	Economy	6300.00
0005434907204	15024	Economy	6300.00
0005433251745	15024	Economy	6300.00
0005433251739	15024	Economy	6300.00
0005434907238	15024	Economy	6300.00
0005434907278	15024	Economy	6300.00
0005433251721	15024	Economy	6300.00
0005434907033	15024	Economy	6300.00
0005434907232	15024	Economy	6300.00
0005434906949	15024	Economy	6300.00
0005434907206	15024	Economy	6300.00
0005434907229	15024	Economy	6300.00
0005434907195	15024	Economy	6300.00
0005434907179	15024	Economy	6300.00
0005433251722	15024	Economy	6300.00
0005434907133	15024	Economy	6300.00
0005434907685	25865	Business	18900.00
0005434907686	25865	Business	18900.00
0005433251442	25865	Business	18900.00
0005434907706	25865	Business	18900.00
0005433251412	25865	Business	18900.00
0005433251572	25865	Business	18900.00
0005434907691	25865	Business	18900.00
0005433251458	25865	Business	18900.00
0005434907678	25865	Business	18900.00
0005434907700	25865	Business	18900.00
0005434907655	25865	Business	18900.00
0005434907657	25865	Business	18900.00
0005434907701	25865	Economy	6300.00
0005434907668	25865	Economy	6300.00
0005433251441	25865	Economy	6300.00
0005433251463	25865	Economy	6300.00
0005433251468	25865	Economy	6300.00
0005434907654	25865	Economy	6300.00
0005434907681	25865	Economy	6300.00
0005433251395	25865	Economy	6300.00
0005434907679	25865	Economy	6300.00
0005434907684	25865	Economy	6300.00
0005433251527	25865	Economy	6900.00
0005434907671	25865	Economy	6900.00
0005433251470	25865	Economy	6900.00
0005434907683	25865	Economy	6900.00
0005434907689	25865	Economy	6900.00
0005433251320	25865	Economy	6300.00
0005434907674	25865	Economy	6300.00
0005433251464	25865	Economy	6300.00
0005433251448	25865	Economy	6300.00
0005434907662	25865	Economy	6300.00
0005433251524	25865	Economy	6300.00
0005433251413	25865	Economy	6300.00
0005433251495	25865	Economy	6300.00
0005434907696	25865	Economy	6300.00
0005434907698	25865	Economy	6300.00
0005433251459	25865	Economy	6300.00
0005434907665	25865	Economy	6300.00
0005434907687	25865	Economy	6300.00
0005434907659	25865	Economy	6300.00
0005434907694	25865	Economy	6300.00
0005434907673	25865	Economy	6300.00
0005433251465	25865	Economy	6300.00
0005434907688	25865	Economy	6300.00
0005434907682	25865	Economy	6300.00
0005433251352	25865	Economy	6300.00
0005433251487	25865	Economy	6300.00
0005434907667	25865	Economy	6300.00
0005434907703	25865	Economy	6300.00
0005434907690	25865	Economy	6300.00
0005434907697	25865	Economy	6300.00
0005433251381	25865	Economy	6300.00
0005433251506	25865	Economy	6300.00
0005434907669	25865	Economy	6300.00
0005433251247	25865	Economy	6300.00
0005434907705	25865	Economy	6300.00
0005434907704	25865	Economy	6300.00
0005433251450	25865	Economy	6300.00
0005434907702	25865	Economy	6300.00
0005433251469	25865	Economy	6300.00
0005434907664	25865	Economy	6300.00
0005433251343	25865	Economy	6300.00
0005434907661	25865	Economy	6300.00
0005434907676	25865	Economy	6300.00
0005433251526	25865	Economy	6300.00
0005433251485	25865	Economy	6300.00
0005434907695	25865	Economy	6300.00
0005434907660	25865	Economy	6300.00
0005433251467	25865	Economy	6300.00
0005433251525	25865	Economy	6300.00
0005434907677	25865	Economy	6300.00
0005434907680	25865	Economy	6300.00
0005434907666	25865	Economy	6300.00
0005433251445	25865	Economy	6300.00
0005434907656	25865	Economy	6300.00
0005434907672	25865	Economy	6300.00
0005434907670	25865	Economy	6300.00
0005433251443	25865	Economy	6300.00
0005434907663	25865	Economy	6300.00
0005434907658	25865	Economy	6300.00
0005434907692	25865	Economy	6300.00
0005433251589	25865	Economy	6300.00
0005433251540	25865	Economy	6300.00
0005434907699	25865	Economy	6300.00
0005433251494	25865	Economy	6300.00
0005434907693	25865	Economy	6300.00
0005434907675	25865	Economy	6300.00
0005433810515	14201	Business	52300.00
0005433008988	14201	Business	52300.00
0005433008989	14201	Business	52300.00
0005433009018	14201	Business	52300.00
0005433008995	14201	Business	52300.00
0005433009022	14201	Business	52300.00
0005433009017	14201	Business	52300.00
0005433008990	14201	Economy	17400.00
0005433009021	14201	Economy	17400.00
0005433008983	14201	Economy	17400.00
0005433009006	14201	Economy	17400.00
0005433008986	14201	Economy	19200.00
0005433008985	14201	Economy	19200.00
0005433009013	14201	Economy	19200.00
0005433009023	14201	Economy	17400.00
0005433009019	14201	Economy	17400.00
0005433009026	14201	Economy	17400.00
0005433009007	14201	Economy	17400.00
0005433009025	14201	Economy	17400.00
0005433009015	14201	Economy	17400.00
0005433009010	14201	Economy	17400.00
0005433810516	14201	Economy	17400.00
0005433009009	14201	Economy	17400.00
0005433810525	14201	Economy	17400.00
0005433009002	14201	Economy	17400.00
0005433009001	14201	Economy	17400.00
0005433008997	14201	Economy	17400.00
0005433009000	14201	Economy	17400.00
0005433009027	14201	Economy	17400.00
0005433009016	14201	Economy	17400.00
0005433009014	14201	Economy	17400.00
0005433008987	14201	Economy	17400.00
0005433009012	14201	Economy	17400.00
0005433009003	14201	Economy	17400.00
0005433008999	14201	Economy	17400.00
0005433008994	14201	Economy	17400.00
0005433009011	14201	Economy	17400.00
0005433009008	14201	Economy	17400.00
0005433009024	14201	Economy	17400.00
0005433008984	14201	Economy	17400.00
0005433008982	14201	Economy	17400.00
0005433008991	14201	Economy	17400.00
0005433008992	14201	Economy	17400.00
0005433009005	14201	Economy	17400.00
0005433008996	14201	Economy	17400.00
0005433009020	14201	Economy	17400.00
0005433008993	14201	Economy	17400.00
0005433009004	14201	Economy	17400.00
0005433008998	14201	Economy	17400.00
0005433810524	14201	Economy	17400.00
0005433008674	22832	Business	52300.00
0005433008516	22832	Business	52300.00
0005433008573	22832	Business	52300.00
0005433008620	22832	Business	52300.00
0005433810578	22832	Business	52300.00
0005433810579	22832	Business	52300.00
0005433008409	22832	Business	52300.00
0005433008557	22832	Economy	17400.00
0005433008485	22832	Economy	17400.00
0005433008427	22832	Economy	17400.00
0005433008531	22832	Economy	17400.00
0005433008621	22832	Economy	17400.00
0005433008660	22832	Economy	17400.00
0005433008387	22832	Economy	17400.00
0005433008551	22832	Economy	17400.00
0005433008675	22832	Economy	19200.00
0005433008629	22832	Economy	19200.00
0005433008617	22832	Economy	17400.00
0005433008431	22832	Economy	17400.00
0005433008702	22832	Economy	17400.00
0005433008566	22832	Economy	17400.00
0005433008546	22832	Economy	17400.00
0005433008570	22832	Economy	17400.00
0005433008593	22832	Economy	17400.00
0005433008673	22832	Economy	17400.00
0005433008786	22832	Economy	17400.00
0005433008410	22832	Economy	17400.00
0005433008701	22832	Economy	17400.00
0005433008596	22832	Economy	17400.00
0005433008524	22832	Economy	17400.00
0005433008484	22832	Economy	17400.00
0005433008451	22832	Economy	17400.00
0005433008407	22832	Economy	17400.00
0005433008540	22832	Economy	17400.00
0005433008483	22832	Economy	17400.00
0005433008497	22832	Economy	17400.00
0005433008622	22832	Economy	17400.00
0005433008572	22832	Economy	17400.00
0005433008567	22832	Economy	17400.00
0005433008537	22832	Economy	17400.00
0005433008406	22832	Economy	17400.00
0005433008634	22832	Economy	17400.00
0005433008388	22832	Economy	17400.00
0005433008594	22832	Economy	17400.00
0005433008328	22832	Economy	17400.00
0005433008430	22832	Economy	17400.00
0005433008602	22832	Economy	17400.00
0005433008539	22832	Economy	17400.00
0005433008428	22832	Economy	17400.00
0005433008529	22832	Economy	17400.00
0005433008785	22832	Economy	17400.00
0005433008611	22832	Economy	17400.00
0005434925607	14929	Business	22900.00
0005434925711	14929	Business	22900.00
0005434925689	14929	Economy	7600.00
0005434925715	14929	Economy	7600.00
0005434925668	14929	Economy	7600.00
0005434925695	14929	Economy	7600.00
0005434925709	14929	Economy	7600.00
0005434925697	14929	Economy	7600.00
0005434925688	14929	Economy	7600.00
0005434925609	14929	Economy	7600.00
0005434925669	14929	Economy	7600.00
0005434925698	14929	Economy	7600.00
0005434925610	14929	Economy	7600.00
0005434925690	14929	Economy	7600.00
0005434925708	14929	Economy	7600.00
0005434925714	14929	Economy	7600.00
0005434925696	14929	Economy	7600.00
0005434926045	20497	Business	22900.00
0005434926040	20497	Economy	7600.00
0005434926042	20497	Economy	7600.00
0005434926046	20497	Economy	7600.00
0005434926043	20497	Economy	8400.00
0005434926050	20497	Economy	8400.00
0005434926055	20497	Economy	7600.00
0005434926048	20497	Economy	7600.00
0005434926037	20497	Economy	7600.00
0005434926056	20497	Economy	7600.00
0005434926053	20497	Economy	7600.00
0005434926034	20497	Economy	7600.00
0005434926044	20497	Economy	7600.00
0005434926027	20497	Economy	7600.00
0005434926041	20497	Economy	7600.00
0005434926030	20497	Economy	7600.00
0005434926058	20497	Economy	7600.00
0005434926029	20497	Economy	7600.00
0005434926026	20497	Economy	7600.00
0005434926033	20497	Economy	7600.00
0005434926039	20497	Economy	7600.00
0005434926028	20497	Economy	7600.00
0005434926049	20497	Economy	7600.00
0005434926038	20497	Economy	7600.00
0005434926054	20497	Economy	7600.00
0005434926051	20497	Economy	7600.00
0005434926047	20497	Economy	7600.00
0005434926032	20497	Economy	7600.00
0005434926036	20497	Economy	7600.00
0005434926059	20497	Economy	7600.00
0005434926052	20497	Economy	7600.00
0005434926057	20497	Economy	7600.00
0005434926035	20497	Economy	7600.00
0005434926031	20497	Economy	7600.00
0005435999218	15826	Economy	8900.00
0005435488025	15826	Economy	8900.00
0005435488028	15826	Economy	8900.00
0005435488016	15826	Economy	8100.00
0005435488013	15826	Economy	8100.00
0005435999191	15826	Economy	8100.00
0005435999220	15826	Economy	8100.00
0005435488018	15826	Economy	8100.00
0005435488019	15826	Economy	8100.00
0005435488026	15826	Economy	8100.00
0005435488014	15826	Economy	8100.00
0005435999208	15826	Economy	8100.00
0005435488021	15826	Economy	8100.00
0005435999250	15826	Economy	8100.00
0005435999209	15826	Economy	8100.00
0005435999243	15826	Economy	8100.00
0005435488007	15826	Economy	8100.00
0005435999244	15826	Economy	8100.00
0005435488027	15826	Economy	8100.00
0005435488012	15826	Economy	8100.00
0005435999251	15826	Economy	8100.00
0005435999225	15826	Economy	8100.00
0005435488010	15826	Economy	8100.00
0005435999247	15826	Economy	8100.00
0005435488031	15826	Economy	8100.00
0005435999245	15826	Economy	8100.00
0005435999232	15826	Economy	8100.00
0005435488009	15826	Economy	8100.00
0005435488015	15826	Economy	8100.00
0005435488020	15826	Economy	8100.00
0005435488008	15826	Economy	8100.00
0005435999183	15826	Economy	8100.00
0005435999219	15826	Economy	8100.00
0005435488029	15826	Economy	8100.00
0005435488023	15826	Economy	8100.00
0005435488011	15826	Economy	8100.00
0005435488024	15826	Economy	8100.00
0005435999239	15826	Economy	8100.00
0005435488030	15826	Economy	8100.00
0005435488017	15826	Economy	8100.00
0005435488022	15826	Economy	8100.00
0005435487754	19693	Economy	8900.00
0005435487772	19693	Economy	8900.00
0005435487779	19693	Economy	8900.00
0005435999381	19693	Economy	8100.00
0005435487681	19693	Economy	8100.00
0005435487775	19693	Economy	8100.00
0005435487800	19693	Economy	8100.00
0005435487802	19693	Economy	8100.00
0005435487680	19693	Economy	8100.00
0005435999384	19693	Economy	8100.00
0005435487885	19693	Economy	8100.00
0005435999383	19693	Economy	8100.00
0005435487767	19693	Economy	8100.00
0005435487804	19693	Economy	8100.00
0005435487773	19693	Economy	8100.00
0005435487711	19693	Economy	8100.00
0005435999382	19693	Economy	8100.00
0005435487710	19693	Economy	8100.00
0005435487682	19693	Economy	8100.00
0005435487778	19693	Economy	8100.00
0005435487796	19693	Economy	8100.00
0005435487839	19693	Economy	8100.00
0005435487776	19693	Economy	8100.00
0005435487827	19693	Economy	8100.00
0005435487811	19693	Economy	8100.00
0005435487887	19693	Economy	8100.00
0005435487886	19693	Economy	8100.00
0005435487668	19693	Economy	8100.00
0005435487747	19693	Economy	8100.00
0005435487718	19693	Economy	8100.00
0005435487795	19693	Economy	8100.00
0005435487794	19693	Economy	8100.00
0005435487756	19693	Economy	8100.00
0005435487812	19693	Economy	8100.00
0005435487768	19693	Economy	8100.00
0005435487777	19693	Economy	8100.00
0005435487919	19693	Economy	8100.00
0005435487799	19693	Economy	8100.00
0005435472843	5985	Business	199300.00
0005435839695	5985	Business	199300.00
0005435472842	5985	Business	199300.00
0005435839702	5985	Business	199300.00
0005435839697	5985	Business	199300.00
0005432537058	5985	Business	199300.00
0005435839698	5985	Business	199300.00
0005435839691	5985	Business	199300.00
0005435839704	5985	Business	199300.00
0005432537055	5985	Business	199300.00
0005435472823	5985	Business	199300.00
0005435472803	5985	Economy	66400.00
0005435839705	5985	Economy	66400.00
0005435839692	5985	Economy	66400.00
0005435472835	5985	Economy	66400.00
0005432537056	5985	Economy	66400.00
0005435839696	5985	Economy	66400.00
0005435839694	5985	Economy	73100.00
0005435839680	5985	Economy	73100.00
0005435472804	5985	Economy	66400.00
0005435839703	5985	Economy	66400.00
0005435839700	5985	Economy	66400.00
0005435472798	5985	Economy	66400.00
0005435839699	5985	Economy	66400.00
0005432658611	5985	Economy	66400.00
0005435472759	5985	Economy	66400.00
0005435472793	5985	Economy	66400.00
0005435839682	5985	Economy	66400.00
0005435839688	5985	Economy	66400.00
0005435472750	5985	Economy	66400.00
0005435839684	5985	Economy	66400.00
0005435839687	5985	Economy	66400.00
0005435839683	5985	Economy	66400.00
0005435472723	5985	Economy	66400.00
0005432658609	5985	Economy	66400.00
0005435839679	5985	Economy	66400.00
0005435839686	5985	Economy	66400.00
0005432659725	5985	Economy	66400.00
0005432660837	5985	Economy	66400.00
0005435472735	5985	Economy	66400.00
0005435839681	5985	Economy	66400.00
0005432142277	5985	Economy	66400.00
0005435472786	5985	Economy	66400.00
0005432537044	5985	Economy	66400.00
0005435839677	5985	Economy	66400.00
0005432142279	5985	Economy	66400.00
0005435839701	5985	Economy	66400.00
0005432142278	5985	Economy	66400.00
0005435839690	5985	Economy	66400.00
0005435472782	5985	Economy	66400.00
0005435472736	5985	Economy	66400.00
0005435839693	5985	Economy	66400.00
0005435839678	5985	Economy	66400.00
0005432658610	5985	Economy	66400.00
0005435472807	5985	Economy	66400.00
0005435472787	5985	Economy	66400.00
0005435472799	5985	Economy	66400.00
0005435839685	5985	Economy	66400.00
0005432660838	5985	Economy	66400.00
0005435839689	5985	Economy	66400.00
0005435472935	18059	Business	199300.00
0005435839481	18059	Business	199300.00
0005435839337	18059	Business	199300.00
0005435839399	18059	Business	199300.00
0005435839492	18059	Business	199300.00
0005435839563	18059	Business	199300.00
0005435839373	18059	Business	199300.00
0005435472941	18059	Business	199300.00
0005435839441	18059	Business	199300.00
0005435839338	18059	Business	199300.00
0005435472947	18059	Business	199300.00
0005435839412	18059	Business	199300.00
0005435472949	18059	Economy	66400.00
0005435839432	18059	Economy	66400.00
0005435472936	18059	Economy	66400.00
0005435472940	18059	Economy	66400.00
0005435839382	18059	Economy	66400.00
0005435472950	18059	Economy	66400.00
0005435472934	18059	Economy	73100.00
0005435472943	18059	Economy	73100.00
0005435839434	18059	Economy	66400.00
0005435472944	18059	Economy	66400.00
0005435472942	18059	Economy	66400.00
0005435839440	18059	Economy	66400.00
0005435472937	18059	Economy	66400.00
0005435839537	18059	Economy	66400.00
0005432537077	18059	Economy	66400.00
0005432660818	18059	Economy	66400.00
0005435839500	18059	Economy	66400.00
0005432667451	18059	Economy	66400.00
0005435472939	18059	Economy	66400.00
0005435472938	18059	Economy	66400.00
0005435839445	18059	Economy	66400.00
0005432537078	18059	Economy	66400.00
0005435472951	18059	Economy	66400.00
0005432537076	18059	Economy	66400.00
0005435839484	18059	Economy	66400.00
0005432660814	18059	Economy	66400.00
0005435839461	18059	Economy	66400.00
0005435839456	18059	Economy	66400.00
0005435839372	18059	Economy	66400.00
0005435472946	18059	Economy	66400.00
0005435839407	18059	Economy	66400.00
0005435839499	18059	Economy	66400.00
0005435839471	18059	Economy	66400.00
0005435839470	18059	Economy	66400.00
0005435839377	18059	Economy	66400.00
0005432660813	18059	Economy	66400.00
0005435839482	18059	Economy	66400.00
0005435472945	18059	Economy	66400.00
0005435839462	18059	Economy	66400.00
0005435839494	18059	Economy	66400.00
0005432660817	18059	Economy	66400.00
0005435839519	18059	Economy	66400.00
0005435839480	18059	Economy	66400.00
0005435839437	18059	Economy	66400.00
0005435839536	18059	Economy	66400.00
0005435472948	18059	Economy	66400.00
0005432667450	18059	Economy	66400.00
0005435839457	18059	Economy	66400.00
0005435839485	18059	Economy	66400.00
0005432667452	18059	Economy	66400.00
0005435839433	18059	Economy	66400.00
0005433285291	23040	Business	15700.00
0005433285240	23040	Business	15700.00
0005433285407	23040	Business	15700.00
0005433285214	23040	Business	15700.00
0005433285222	23040	Economy	5200.00
0005433285234	23040	Economy	5200.00
0005433285349	23040	Economy	5200.00
0005433285123	23040	Economy	5200.00
0005433285207	23040	Economy	5200.00
0005433285331	23040	Economy	5200.00
0005433285286	23040	Economy	5200.00
0005433285345	23040	Economy	5200.00
0005433285247	23040	Economy	5200.00
0005435103984	23040	Economy	5200.00
0005433285406	23040	Economy	5200.00
0005433285348	23040	Economy	5200.00
0005433285315	23040	Economy	5200.00
0005433285126	23040	Economy	5700.00
0005433285351	23040	Economy	5200.00
0005433285390	23040	Economy	5200.00
0005433285174	23040	Economy	5200.00
0005433285324	23040	Economy	5200.00
0005433285347	23040	Economy	5200.00
0005435103985	23040	Economy	5200.00
0005433285352	23040	Economy	5200.00
0005433285242	23040	Economy	5200.00
0005433285328	23040	Economy	5200.00
0005433285292	23040	Economy	5200.00
0005433285346	23040	Economy	5200.00
0005433285217	23040	Economy	5200.00
0005433285321	23040	Economy	5200.00
0005433285124	23040	Economy	5200.00
0005433285391	23040	Economy	5200.00
0005433285294	23040	Economy	5200.00
0005433285312	23040	Economy	5200.00
0005433285317	23040	Economy	5200.00
0005433285316	23040	Economy	5200.00
0005433285206	23040	Economy	5200.00
0005433285246	23040	Economy	5200.00
0005433285293	23040	Economy	5200.00
0005433285341	23040	Economy	5200.00
0005435103986	23040	Economy	5200.00
0005433285327	23040	Economy	5200.00
0005433285376	23040	Economy	5200.00
0005433285125	23040	Economy	5200.00
0005435103983	23040	Economy	5200.00
0005433285218	23040	Economy	5200.00
0005433285554	32085	Business	15700.00
0005433285563	32085	Business	15700.00
0005433285572	32085	Business	15700.00
0005433285568	32085	Business	15700.00
0005433285570	32085	Economy	5200.00
0005433285574	32085	Economy	5200.00
0005435103906	32085	Economy	5200.00
0005435103878	32085	Economy	5200.00
0005435103879	32085	Economy	5200.00
0005433285556	32085	Economy	5200.00
0005433285580	32085	Economy	5200.00
0005433285561	32085	Economy	5200.00
0005433285559	32085	Economy	5200.00
0005433285552	32085	Economy	5200.00
0005433285575	32085	Economy	5200.00
0005433285571	32085	Economy	5200.00
0005433285573	32085	Economy	5200.00
0005433285560	32085	Economy	5200.00
0005433285581	32085	Economy	5200.00
0005433285555	32085	Economy	5200.00
0005433285569	32085	Economy	5200.00
0005435103884	32085	Economy	5200.00
0005433285579	32085	Economy	5200.00
0005433285567	32085	Economy	5200.00
0005433285557	32085	Economy	5200.00
0005433285565	32085	Economy	5200.00
0005433285551	32085	Economy	5200.00
0005433285553	32085	Economy	5200.00
0005433285566	32085	Economy	5200.00
0005433285578	32085	Economy	5200.00
0005433285558	32085	Economy	5200.00
0005433285577	32085	Economy	5200.00
0005433285576	32085	Economy	5200.00
0005435103905	32085	Economy	5200.00
0005433285562	32085	Economy	5200.00
0005433285564	32085	Economy	5200.00
0005432527527	30611	Business	42100.00
0005432528195	30611	Business	42100.00
0005435214197	30611	Business	42100.00
0005434067691	30611	Business	42100.00
0005432527777	30611	Business	42100.00
0005432527615	30611	Business	42100.00
0005432528336	30611	Business	42100.00
0005432528299	30611	Business	42100.00
0005435214198	30611	Business	42100.00
0005434067705	30611	Business	42100.00
0005432527840	30611	Business	42100.00
0005432527714	30611	Business	42100.00
0005432527782	30611	Business	42100.00
0005432528010	30611	Business	42100.00
0005432528818	30611	Business	42100.00
0005435214143	30611	Business	42100.00
0005435214168	30611	Business	42100.00
0005432527918	30611	Business	42100.00
0005434067584	30611	Business	42100.00
0005432528265	30611	Business	42100.00
0005435214133	30611	Business	42100.00
0005432527599	30611	Business	42100.00
0005435214184	30611	Business	42100.00
0005432528287	30611	Business	42100.00
0005434067768	30611	Business	42100.00
0005434067548	30611	Business	42100.00
0005432527865	30611	Comfort	23900.00
0005432528264	30611	Comfort	23900.00
0005432211571	30611	Comfort	23900.00
0005432528650	30611	Comfort	23900.00
0005435214195	30611	Comfort	23900.00
0005435214149	30611	Comfort	23900.00
0005432527863	30611	Comfort	23900.00
0005432527859	30611	Comfort	23900.00
0005432527833	30611	Comfort	23900.00
0005432528306	30611	Comfort	23900.00
0005435214148	30611	Comfort	23900.00
0005432211567	30611	Comfort	23900.00
0005435214164	30611	Comfort	23900.00
0005432527903	30611	Comfort	23900.00
0005435214173	30611	Comfort	23900.00
0005435214169	30611	Comfort	23900.00
0005432527997	30611	Comfort	23900.00
0005435214167	30611	Comfort	23900.00
0005434067405	30611	Comfort	23900.00
0005432528232	30611	Comfort	23900.00
0005432528300	30611	Comfort	23900.00
0005432527742	30611	Comfort	23900.00
0005432527874	30611	Comfort	23900.00
0005432527990	30611	Comfort	23900.00
0005432528304	30611	Comfort	23900.00
0005432527924	30611	Comfort	23900.00
0005432527835	30611	Comfort	23900.00
0005432528697	30611	Comfort	23900.00
0005433656701	30611	Comfort	23900.00
0005434067061	30611	Comfort	23900.00
0005432528297	30611	Comfort	23900.00
0005432527824	30611	Comfort	23900.00
0005434067673	30611	Comfort	23900.00
0005432528329	30611	Comfort	23900.00
0005435214185	30611	Comfort	23900.00
0005434067387	30611	Comfort	23900.00
0005432527741	30611	Economy	14000.00
0005432527544	30611	Comfort	23900.00
0005432527875	30611	Economy	14000.00
0005433656703	30611	Economy	14000.00
0005435214146	30611	Economy	14000.00
0005432528080	30611	Economy	14000.00
0005432527348	30611	Economy	14000.00
0005432527906	30611	Economy	14000.00
0005432528363	30611	Economy	14000.00
0005432528399	30611	Economy	14000.00
0005432527892	30611	Economy	14000.00
0005432211568	30611	Economy	14000.00
0005434067794	30611	Economy	14000.00
0005432528125	30611	Economy	14000.00
0005432528313	30611	Economy	14000.00
0005435214132	30611	Economy	14000.00
0005432527856	30611	Economy	14000.00
0005432528244	30611	Economy	14000.00
0005435214181	30611	Economy	14000.00
0005432528397	30611	Economy	14000.00
0005432528075	30611	Economy	14000.00
0005434067513	30611	Economy	14000.00
0005432527934	30611	Economy	14000.00
0005432537066	30611	Economy	14000.00
0005432528001	30611	Economy	14000.00
0005432528231	30611	Economy	14000.00
0005432527860	30611	Economy	14000.00
0005435214161	30611	Economy	14000.00
0005432527839	30611	Economy	14000.00
0005432537062	30611	Economy	14000.00
0005434067324	30611	Economy	14000.00
0005432528296	30611	Economy	14000.00
0005432527670	30611	Economy	14000.00
0005435214135	30611	Economy	14000.00
0005432527783	30611	Economy	14000.00
0005432527995	30611	Economy	14000.00
0005435725648	30611	Economy	14000.00
0005432528126	30611	Economy	14000.00
0005432533297	30611	Economy	14000.00
0005432528447	30611	Economy	14000.00
0005434067647	30611	Economy	14000.00
0005432535824	30611	Economy	14000.00
0005432527896	30611	Economy	14000.00
0005435214177	30611	Economy	14000.00
0005435214145	30611	Economy	14000.00
0005434067442	30611	Economy	14000.00
0005432535835	30611	Economy	14000.00
0005432527974	30611	Economy	14000.00
0005435214196	30611	Economy	14000.00
0005435214187	30611	Economy	14000.00
0005432527987	30611	Economy	14000.00
0005432527570	30611	Economy	14000.00
0005432211569	30611	Economy	14000.00
0005432527781	30611	Economy	14000.00
0005435214165	30611	Economy	14000.00
0005435630995	30611	Economy	14000.00
0005435214137	30611	Economy	14000.00
0005435630996	30611	Economy	14000.00
0005435214188	30611	Economy	14000.00
0005434067560	30611	Economy	14000.00
0005432528459	30611	Economy	14000.00
0005434067512	30611	Economy	15400.00
0005434067302	30611	Economy	14000.00
0005434067406	30611	Economy	15400.00
0005432527479	30611	Economy	14000.00
0005432528245	30611	Economy	14000.00
0005434067593	30611	Economy	15400.00
0005432428932	30611	Economy	15400.00
0005435214183	30611	Economy	15400.00
0005432528064	30611	Economy	14000.00
0005432428935	30611	Economy	14000.00
0005432527838	30611	Economy	14000.00
0005435214158	30611	Economy	14000.00
0005432528337	30611	Economy	14000.00
0005435214190	30611	Economy	14000.00
0005432159897	30611	Economy	14000.00
0005435214176	30611	Economy	14000.00
0005432527976	30611	Economy	14000.00
0005435725645	30611	Economy	14000.00
0005432428938	30611	Economy	14000.00
0005432528123	30611	Economy	14000.00
0005434067658	30611	Economy	14000.00
0005434067641	30611	Economy	14000.00
0005435214138	30611	Economy	14000.00
0005434067696	30611	Economy	14000.00
0005432528699	30611	Economy	14000.00
0005432527955	30611	Economy	14000.00
0005432527775	30611	Economy	14000.00
0005434067511	30611	Economy	14000.00
0005432527847	30611	Economy	14000.00
0005432527844	30611	Economy	14000.00
0005435214155	30611	Economy	14000.00
0005432528327	30611	Economy	14000.00
0005435214179	30611	Economy	14000.00
0005434067721	30611	Economy	14000.00
0005432527808	30611	Economy	14000.00
0005432528298	30611	Economy	14000.00
0005435214162	30611	Economy	14000.00
0005432527926	30611	Economy	14000.00
0005432428936	30611	Economy	14000.00
0005434067496	30611	Economy	14000.00
0005434067689	30611	Economy	14000.00
0005434067184	30611	Economy	14000.00
0005432535819	30611	Economy	14000.00
0005432527845	30611	Economy	14000.00
0005432528553	30611	Economy	14000.00
0005432528330	30611	Economy	14000.00
0005432528181	30611	Economy	14000.00
0005435214142	30611	Economy	14000.00
0005434067378	30611	Economy	14000.00
0005432528060	30611	Economy	14000.00
0005432537060	30611	Economy	14000.00
0005432535852	30611	Economy	14000.00
0005432527846	30611	Economy	14000.00
0005432527698	30611	Economy	14000.00
0005432535851	30611	Economy	14000.00
0005435214139	30611	Economy	14000.00
0005435725649	30611	Economy	14000.00
0005432428931	30611	Economy	14000.00
0005432527633	30611	Economy	14000.00
0005435214152	30611	Economy	14000.00
0005435214186	30611	Economy	14000.00
0005435214140	30611	Economy	14000.00
0005435725647	30611	Economy	14000.00
0005432528688	30611	Economy	14000.00
0005435214157	30611	Economy	14000.00
0005434067238	30611	Economy	14000.00
0005432527480	30611	Economy	14000.00
0005435214178	30611	Economy	14000.00
0005434067275	30611	Economy	14000.00
0005435214160	30611	Economy	14000.00
0005432159901	30611	Economy	14000.00
0005434067379	30611	Economy	14000.00
0005432527977	30611	Economy	14000.00
0005432528016	30611	Economy	14000.00
0005432527973	30611	Economy	14000.00
0005435214154	30611	Economy	14000.00
0005435214182	30611	Economy	14000.00
0005435214131	30611	Economy	14000.00
0005432528150	30611	Economy	14000.00
0005432528371	30611	Economy	14000.00
0005435214171	30611	Economy	14000.00
0005435214174	30611	Economy	14000.00
0005435214141	30611	Economy	14000.00
0005435214134	30611	Economy	14000.00
0005432528527	30611	Economy	14000.00
0005432527864	30611	Economy	14000.00
0005434067640	30611	Economy	14000.00
0005432528186	30611	Economy	14000.00
0005435214199	30611	Economy	14000.00
0005432528689	30611	Economy	14000.00
0005434067386	30611	Economy	14000.00
0005432527994	30611	Economy	14000.00
0005434067648	30611	Economy	14000.00
0005434067573	30611	Economy	14000.00
0005432527843	30611	Economy	14000.00
0005432528698	30611	Economy	14000.00
0005434067704	30611	Economy	14000.00
0005432527925	30611	Economy	14000.00
0005432159899	30611	Economy	14000.00
0005432528506	30611	Economy	14000.00
0005435214153	30611	Economy	14000.00
0005432528002	30611	Economy	14000.00
0005435725644	30611	Economy	14000.00
0005434067439	30611	Economy	14000.00
0005434067657	30611	Economy	14000.00
0005434067529	30611	Economy	14000.00
0005432528266	30611	Economy	14000.00
0005432528141	30611	Economy	14000.00
0005435214189	30611	Economy	15400.00
0005432528130	30611	Economy	15400.00
0005434067435	30611	Economy	15400.00
0005434067574	30611	Economy	15400.00
0005435214193	30611	Economy	15400.00
0005434067549	30611	Economy	14000.00
0005432527895	30611	Economy	14000.00
0005432211572	30611	Economy	14000.00
0005432528011	30611	Economy	14000.00
0005432537067	30611	Economy	14000.00
0005432528566	30611	Economy	14000.00
0005435214170	30611	Economy	14000.00
0005432211570	30611	Economy	14000.00
0005434067468	30611	Economy	14000.00
0005435214200	30611	Economy	14000.00
0005434067281	30611	Economy	14000.00
0005435214192	30611	Economy	14000.00
0005432528312	30611	Economy	14000.00
0005432527654	30611	Economy	14000.00
0005432528372	30611	Economy	14000.00
0005432527571	30611	Economy	14000.00
0005435214172	30611	Economy	14000.00
0005432528303	30611	Economy	14000.00
0005434067362	30611	Economy	14000.00
0005432527919	30611	Economy	14000.00
0005432528052	30611	Economy	14000.00
0005432528819	30611	Economy	14000.00
0005432528051	30611	Economy	14000.00
0005432537059	30611	Economy	14000.00
0005435214159	30611	Economy	14000.00
0005432527526	30611	Economy	14000.00
0005435214150	30611	Economy	14000.00
0005432528420	30611	Economy	14000.00
0005432535833	30611	Economy	14000.00
0005435214147	30611	Economy	14000.00
0005432528454	30611	Economy	14000.00
0005432527983	30611	Economy	14000.00
0005432527669	30611	Economy	14000.00
0005432528328	30611	Economy	14000.00
0005432528008	30611	Economy	14000.00
0005432528396	30611	Economy	14000.00
0005434067323	30611	Economy	14000.00
0005432528111	30611	Economy	14000.00
0005432159898	30611	Economy	14000.00
0005432527965	30611	Economy	14000.00
0005435214194	30611	Economy	14000.00
0005432528692	30611	Economy	14000.00
0005432528129	30611	Economy	14000.00
0005434067453	30611	Economy	14000.00
0005432159900	30611	Economy	14000.00
0005434067603	30611	Economy	14000.00
0005435214175	30611	Economy	14000.00
0005432527999	30611	Economy	14000.00
0005432528149	30611	Economy	14000.00
0005434067301	30611	Economy	14000.00
0005434067437	30611	Economy	14000.00
0005432527456	30611	Economy	14000.00
0005432528411	30611	Economy	14000.00
0005434067062	30611	Economy	14000.00
0005432528305	30611	Economy	14000.00
0005432528059	30611	Economy	14000.00
0005432528423	30611	Economy	14000.00
0005434067690	30611	Economy	14000.00
0005432527962	30611	Economy	14000.00
0005432528124	30611	Economy	14000.00
0005432528099	30611	Economy	14000.00
0005432211573	30611	Economy	14000.00
0005432428937	30611	Economy	14000.00
0005434067438	30611	Economy	14000.00
0005432527989	30611	Economy	14000.00
0005435214136	30611	Economy	14000.00
0005432528455	30611	Economy	14000.00
0005432528505	30611	Economy	14000.00
0005435214144	30611	Economy	14000.00
0005435214166	30611	Economy	14000.00
0005434067815	30611	Economy	14000.00
0005434067372	30611	Economy	14000.00
0005435214180	30611	Economy	14000.00
0005432527996	30611	Economy	14000.00
0005432527382	30611	Economy	14000.00
0005432527964	30611	Economy	14000.00
0005435725646	30611	Economy	14000.00
0005432528230	30611	Economy	14000.00
0005432528112	30611	Economy	14000.00
0005434067487	30611	Economy	14000.00
0005435214191	30611	Economy	14000.00
0005435630994	30611	Economy	14000.00
0005432527632	30611	Economy	14000.00
0005435214156	30611	Economy	14000.00
0005434067590	30611	Economy	14000.00
0005432528213	30611	Economy	14000.00
0005432527963	30611	Economy	14000.00
0005432528421	30611	Economy	14000.00
0005435214163	30611	Economy	14000.00
0005433656702	30611	Economy	14000.00
0005435214151	30611	Economy	14000.00
0005435653066	24869	Business	9800.00
0005435652941	24869	Business	9800.00
0005435653001	24869	Business	9800.00
0005435653137	24869	Business	9800.00
0005433368239	24869	Business	9800.00
0005435653052	24869	Business	9800.00
0005433368218	24869	Business	9800.00
0005435653039	24869	Business	9800.00
0005435653123	24869	Business	9800.00
0005433368251	24869	Business	9800.00
0005435653124	24869	Business	9800.00
0005435653151	24869	Business	9800.00
0005435653134	24869	Economy	3300.00
0005433368244	24869	Economy	3300.00
0005433368228	24869	Economy	3300.00
0005435653116	24869	Economy	3300.00
0005433368241	24869	Economy	3300.00
0005435652922	24869	Economy	3300.00
0005433368223	24869	Economy	3300.00
0005435652993	24869	Economy	3300.00
0005433368234	24869	Economy	3300.00
0005435653088	24869	Economy	3300.00
0005435653031	24869	Economy	3600.00
0005433368242	24869	Economy	3600.00
0005433368222	24869	Economy	3600.00
0005435653067	24869	Economy	3600.00
0005433368233	24869	Economy	3300.00
0005435652991	24869	Economy	3300.00
0005435653005	24869	Economy	3300.00
0005433368221	24869	Economy	3300.00
0005433368248	24869	Economy	3300.00
0005435652937	24869	Economy	3300.00
0005435653069	24869	Economy	3300.00
0005435652962	24869	Economy	3300.00
0005435653078	24869	Economy	3300.00
0005433368252	24869	Economy	3300.00
0005433368224	24869	Economy	3300.00
0005435652992	24869	Economy	3300.00
0005433368247	24869	Economy	3300.00
0005435653150	24869	Economy	3300.00
0005433368227	24869	Economy	3300.00
0005435653142	24869	Economy	3300.00
0005433368217	24869	Economy	3300.00
0005433368220	24869	Economy	3300.00
0005433368231	24869	Economy	3300.00
0005435652990	24869	Economy	3300.00
0005435653053	24869	Economy	3300.00
0005433368225	24869	Economy	3300.00
0005433368226	24869	Economy	3300.00
0005435653152	24869	Economy	3300.00
0005435652981	24869	Economy	3300.00
0005433368219	24869	Economy	3300.00
0005433368249	24869	Economy	3300.00
0005435653138	24869	Economy	3300.00
0005435653093	24869	Economy	3300.00
0005433368236	24869	Economy	3300.00
0005433368240	24869	Economy	3300.00
0005433368253	24869	Economy	3300.00
0005435653092	24869	Economy	3300.00
0005435653112	24869	Economy	3300.00
0005435653004	24869	Economy	3300.00
0005435653070	24869	Economy	3300.00
0005435653153	24869	Economy	3300.00
0005433368237	24869	Economy	3300.00
0005435653029	24869	Economy	3300.00
0005435653136	24869	Economy	3300.00
0005433368245	24869	Economy	3300.00
0005433368243	24869	Economy	3300.00
0005433368230	24869	Economy	3300.00
0005435652982	24869	Economy	3300.00
0005433368229	24869	Economy	3300.00
0005435653111	24869	Economy	3300.00
0005435653086	24869	Economy	3300.00
0005435653022	24869	Economy	3300.00
0005433368235	24869	Economy	3300.00
0005435653087	24869	Economy	3300.00
0005435653038	24869	Economy	3300.00
0005435652963	24869	Economy	3300.00
0005435653030	24869	Economy	3300.00
0005433368254	24869	Economy	3300.00
0005433368232	24869	Economy	3300.00
0005433368250	24869	Economy	3300.00
0005433368246	24869	Economy	3300.00
0005433368238	24869	Economy	3300.00
0005435801725	2050	Economy	10500.00
0005434980062	2050	Economy	10500.00
0005434980079	2050	Economy	9500.00
0005434980053	2050	Economy	9500.00
0005434980064	2050	Economy	9500.00
0005434980073	2050	Economy	9500.00
0005434980054	2050	Economy	9500.00
0005434980078	2050	Economy	9500.00
0005434980063	2050	Economy	9500.00
0005434980071	2050	Economy	9500.00
0005434980065	2050	Economy	9500.00
0005434980056	2050	Economy	9500.00
0005434980076	2050	Economy	9500.00
0005434980075	2050	Economy	9500.00
0005434980074	2050	Economy	9500.00
0005434980077	2050	Economy	9500.00
0005434980082	2050	Economy	9500.00
0005434980072	2050	Economy	9500.00
0005434980057	2050	Economy	9500.00
0005434980068	2050	Economy	9500.00
0005434980069	2050	Economy	9500.00
0005434980052	2050	Economy	9500.00
0005434980059	2050	Economy	9500.00
0005434980055	2050	Economy	9500.00
0005434980066	2050	Economy	9500.00
0005434980081	2050	Economy	9500.00
0005435801724	2050	Economy	9500.00
0005434980058	2050	Economy	9500.00
0005434980070	2050	Economy	9500.00
0005434980060	2050	Economy	9500.00
0005434980080	2050	Economy	9500.00
0005434980067	2050	Economy	9500.00
0005435801726	2050	Economy	9500.00
0005434980061	2050	Economy	9500.00
0005435801723	2050	Economy	9500.00
0005434979690	23557	Economy	10500.00
0005434979715	23557	Economy	10500.00
0005434979723	23557	Economy	9500.00
0005434979651	23557	Economy	9500.00
0005435801690	23557	Economy	9500.00
0005434979682	23557	Economy	9500.00
0005434979737	23557	Economy	9500.00
0005434979725	23557	Economy	9500.00
0005434979792	23557	Economy	9500.00
0005434979681	23557	Economy	9500.00
0005434979747	23557	Economy	9500.00
0005434979821	23557	Economy	9500.00
0005434979624	23557	Economy	9500.00
0005434979680	23557	Economy	9500.00
0005434979691	23557	Economy	9500.00
0005434979724	23557	Economy	9500.00
0005434979735	23557	Economy	9500.00
0005434979770	23557	Economy	9500.00
0005434979801	23557	Economy	9500.00
0005434979879	23557	Economy	9500.00
0005434979814	23557	Economy	9500.00
0005434979642	23557	Economy	9500.00
0005434979650	23557	Economy	9500.00
0005434979683	23557	Economy	9500.00
0005434979769	23557	Economy	9500.00
0005434979878	23557	Economy	9500.00
0005434979796	23557	Economy	9500.00
0005434979705	23557	Economy	9500.00
0005434979655	23557	Economy	9500.00
0005434979795	23557	Economy	9500.00
0005434979703	23557	Economy	9500.00
0005434979704	23557	Economy	9500.00
0005434952566	2644	Economy	5300.00
0005434952564	2644	Economy	5300.00
0005434952567	2644	Economy	5300.00
0005434952565	2644	Economy	5300.00
0005433256430	2631	Economy	5300.00
0005434952523	28270	Economy	5300.00
0005434952540	28270	Economy	5300.00
0005434952541	28270	Economy	5300.00
0005434952533	28270	Economy	5300.00
0005433256443	28270	Economy	5300.00
0005434952528	28270	Economy	5300.00
0005433256442	28270	Economy	5300.00
0005433112389	19773	Economy	8700.00
0005433111526	19773	Economy	8700.00
0005433112388	19773	Economy	8700.00
0005434302870	19773	Economy	8700.00
0005433111527	19773	Economy	8700.00
0005434302862	19773	Economy	8700.00
0005434137905	11918	Business	9700.00
0005434138031	11918	Business	9700.00
0005434138372	11918	Business	9700.00
0005434138173	11918	Business	9700.00
0005434138091	11918	Business	9700.00
0005434138044	11918	Business	9700.00
0005434138029	11918	Business	9700.00
0005434138036	11918	Business	9700.00
0005434138176	11918	Business	9700.00
0005434138042	11918	Business	9700.00
0005434138055	11918	Business	9700.00
0005434138319	11918	Economy	3200.00
0005434137960	11918	Economy	3200.00
0005434138373	11918	Economy	3200.00
0005434137841	11918	Economy	3200.00
0005434138128	11918	Economy	3200.00
0005434138026	11918	Economy	3200.00
0005434138089	11918	Economy	3200.00
0005434138276	11918	Economy	3200.00
0005434138104	11918	Economy	3200.00
0005434138387	11918	Economy	3500.00
0005434138374	11918	Economy	3500.00
0005434138117	11918	Economy	3500.00
0005434138343	11918	Economy	3500.00
0005434137842	11918	Economy	3500.00
0005434138341	11918	Economy	3200.00
0005434138225	11918	Economy	3200.00
0005434138326	11918	Economy	3200.00
0005434138163	11918	Economy	3200.00
0005434138103	11918	Economy	3200.00
0005434137993	11918	Economy	3200.00
0005434138054	11918	Economy	3200.00
0005434138144	11918	Economy	3200.00
0005434138164	11918	Economy	3200.00
0005434138363	11918	Economy	3200.00
0005434138037	11918	Economy	3200.00
0005434138315	11918	Economy	3200.00
0005434138335	11918	Economy	3200.00
0005434138194	11918	Economy	3200.00
0005434138025	11918	Economy	3200.00
0005434138183	11918	Economy	3200.00
0005434138388	11918	Economy	3200.00
0005434138084	11918	Economy	3200.00
0005434138138	11918	Economy	3200.00
0005434138207	11918	Economy	3200.00
0005434138226	11918	Economy	3200.00
0005434138153	11918	Economy	3200.00
0005434138156	11918	Economy	3200.00
0005434138295	11918	Economy	3200.00
0005434138270	11918	Economy	3200.00
0005434138361	11918	Economy	3200.00
0005434138059	11918	Economy	3200.00
0005434137994	11918	Economy	3200.00
0005434138043	11918	Economy	3200.00
0005434138290	11918	Economy	3200.00
0005434138377	11918	Economy	3200.00
0005434138254	11918	Economy	3200.00
0005434138083	11918	Economy	3200.00
0005434137939	11918	Economy	3200.00
0005434138172	11918	Economy	3200.00
0005434138143	11918	Economy	3200.00
0005434137940	11918	Economy	3200.00
0005434138314	11918	Economy	3200.00
0005434138379	11918	Economy	3200.00
0005434138061	11918	Economy	3200.00
0005434138056	11918	Economy	3200.00
0005434137906	11918	Economy	3200.00
0005434138154	11918	Economy	3200.00
0005434138259	11918	Economy	3200.00
0005434138196	11918	Economy	3200.00
0005434137953	11918	Economy	3200.00
0005434138182	11918	Economy	3200.00
0005434138090	11918	Economy	3200.00
0005434138165	11918	Economy	3200.00
0005434138162	11918	Economy	3200.00
0005434138320	11918	Economy	3200.00
0005434138307	11918	Economy	3200.00
0005434138285	11918	Economy	3200.00
0005434138280	11918	Economy	3200.00
0005434138306	11918	Economy	3200.00
0005434138187	11918	Economy	3200.00
0005434138378	11918	Economy	3200.00
0005434138155	11918	Economy	3200.00
0005434138206	11918	Economy	3200.00
0005434138166	11918	Economy	3200.00
0005434138334	11918	Economy	3200.00
0005434138286	11918	Economy	3200.00
0005434138857	28719	Business	9700.00
0005434138863	28719	Business	9700.00
0005434138885	28719	Business	9700.00
0005434138826	28719	Business	9700.00
0005434138875	28719	Business	9700.00
0005434138887	28719	Business	9700.00
0005434138837	28719	Business	9700.00
0005434138822	28719	Business	9700.00
0005434138859	28719	Business	9700.00
0005434138862	28719	Business	9700.00
0005434138810	28719	Business	9700.00
0005434138866	28719	Business	9700.00
0005434138841	28719	Economy	3200.00
0005434138829	28719	Economy	3200.00
0005434138872	28719	Economy	3200.00
0005434138856	28719	Economy	3200.00
0005434138819	28719	Economy	3200.00
0005434138839	28719	Economy	3200.00
0005434138828	28719	Economy	3200.00
0005434138867	28719	Economy	3200.00
0005434138892	28719	Economy	3200.00
0005434138861	28719	Economy	3500.00
0005434138833	28719	Economy	3500.00
0005434138865	28719	Economy	3500.00
0005434138886	28719	Economy	3500.00
0005434138840	28719	Economy	3200.00
0005434138814	28719	Economy	3200.00
0005434138858	28719	Economy	3200.00
0005434138816	28719	Economy	3200.00
0005434138825	28719	Economy	3200.00
0005434138836	28719	Economy	3200.00
0005434138838	28719	Economy	3200.00
0005434138820	28719	Economy	3200.00
0005434138811	28719	Economy	3200.00
0005434138842	28719	Economy	3200.00
0005434138849	28719	Economy	3200.00
0005434138845	28719	Economy	3200.00
0005434138860	28719	Economy	3200.00
0005434138817	28719	Economy	3200.00
0005434138876	28719	Economy	3200.00
0005434138864	28719	Economy	3200.00
0005434138855	28719	Economy	3200.00
0005434138850	28719	Economy	3200.00
0005434138818	28719	Economy	3200.00
0005434138809	28719	Economy	3200.00
0005434138808	28719	Economy	3200.00
0005434138827	28719	Economy	3200.00
0005434138823	28719	Economy	3200.00
0005434138807	28719	Economy	3200.00
0005434138868	28719	Economy	3200.00
0005434138884	28719	Economy	3200.00
0005434138877	28719	Economy	3200.00
0005434138812	28719	Economy	3200.00
0005434138832	28719	Economy	3200.00
0005434138893	28719	Economy	3200.00
0005434138883	28719	Economy	3200.00
0005434138882	28719	Economy	3200.00
0005434138871	28719	Economy	3200.00
0005434138878	28719	Economy	3200.00
0005434138891	28719	Economy	3200.00
0005434138844	28719	Economy	3200.00
0005434138843	28719	Economy	3200.00
0005434138870	28719	Economy	3200.00
0005434138848	28719	Economy	3200.00
0005434138879	28719	Economy	3200.00
0005434138830	28719	Economy	3200.00
0005434138851	28719	Economy	3200.00
0005434138854	28719	Economy	3200.00
0005434138835	28719	Economy	3200.00
0005434138888	28719	Economy	3200.00
0005434138852	28719	Economy	3200.00
0005434138824	28719	Economy	3200.00
0005434138869	28719	Economy	3200.00
0005434138815	28719	Economy	3200.00
0005434138821	28719	Economy	3200.00
0005434138813	28719	Economy	3200.00
0005434138847	28719	Economy	3200.00
0005434138846	28719	Economy	3200.00
0005434138881	28719	Economy	3200.00
0005434138834	28719	Economy	3200.00
0005434138853	28719	Economy	3200.00
0005434138874	28719	Economy	3200.00
0005434138880	28719	Economy	3200.00
0005434138890	28719	Economy	3200.00
0005434138889	28719	Economy	3200.00
0005434138873	28719	Economy	3200.00
0005434138831	28719	Economy	3200.00
0005433538950	6784	Economy	10900.00
0005433538949	6784	Economy	10900.00
0005433538948	6784	Economy	9900.00
0005433538954	6784	Economy	9900.00
0005435259756	6784	Economy	9900.00
0005433538947	6784	Economy	9900.00
0005435259748	6784	Economy	9900.00
0005435259754	6784	Economy	9900.00
0005433538953	6784	Economy	9900.00
0005433538952	6784	Economy	9900.00
0005435259761	6784	Economy	9900.00
0005433534518	6784	Economy	9900.00
0005435259772	6784	Economy	9900.00
0005433538951	6784	Economy	9900.00
0005435259755	6784	Economy	9900.00
0005433534495	25006	Economy	10900.00
0005435259797	25006	Economy	10900.00
0005433538894	25006	Economy	9900.00
0005433538859	25006	Economy	9900.00
0005433538846	25006	Economy	9900.00
0005433538834	25006	Economy	9900.00
0005435259799	25006	Economy	9900.00
0005435259796	25006	Economy	9900.00
0005435259795	25006	Economy	9900.00
0005433538845	25006	Economy	9900.00
0005433538886	25006	Economy	9900.00
0005435259798	25006	Economy	9900.00
0005433538850	25006	Economy	9900.00
0005433534496	25006	Economy	9900.00
0005433538847	25006	Economy	9900.00
0005432922523	818	Economy	14600.00
0005432922537	818	Economy	14600.00
0005432922545	818	Economy	14600.00
0005432922522	818	Economy	14600.00
0005433512032	818	Economy	14600.00
0005432922536	818	Economy	14600.00
0005433512033	818	Economy	14600.00
0005432922538	818	Economy	14600.00
0005433512028	818	Economy	14600.00
0005433512031	818	Economy	14600.00
0005433512027	818	Economy	14600.00
0005433512030	818	Economy	14600.00
0005433512029	818	Economy	14600.00
0005433511960	16176	Economy	16100.00
0005433511985	16176	Economy	14600.00
0005432922562	16176	Economy	14600.00
0005433511968	16176	Economy	14600.00
0005432922564	16176	Economy	14600.00
0005432922561	16176	Economy	14600.00
0005432922563	16176	Economy	14600.00
0005433511980	16176	Economy	14600.00
0005433511967	16176	Economy	14600.00
0005433511940	16176	Economy	14600.00
0005433511941	16176	Economy	14600.00
0005433511970	16176	Economy	14600.00
0005433511936	16176	Economy	14600.00
0005435852568	4030	Economy	13500.00
0005433475740	4030	Economy	13500.00
0005433475738	4030	Economy	12300.00
0005433475746	4030	Economy	12300.00
0005433475737	4030	Economy	12300.00
0005433475741	4030	Economy	12300.00
0005435852587	4030	Economy	12300.00
0005435852585	4030	Economy	12300.00
0005433475748	4030	Economy	12300.00
0005433475742	4030	Economy	12300.00
0005433475747	4030	Economy	12300.00
0005433475744	4030	Economy	12300.00
0005433475750	4030	Economy	12300.00
0005433475743	4030	Economy	12300.00
0005433475749	4030	Economy	12300.00
0005435852566	4030	Economy	12300.00
0005433475745	4030	Economy	12300.00
0005433475739	4030	Economy	12300.00
0005435852584	4030	Economy	12300.00
0005435935053	3694	Economy	7900.00
0005435697602	3694	Economy	7900.00
0005434950571	3694	Economy	7900.00
0005434950572	3694	Economy	7200.00
0005435697610	3694	Economy	7200.00
0005435697597	3694	Economy	7200.00
0005435697611	3694	Economy	7200.00
0005435697609	3694	Economy	7200.00
0005435697596	3694	Economy	7200.00
0005435697607	3694	Economy	7200.00
0005435697603	3694	Economy	7200.00
0005435697604	3694	Economy	7200.00
0005435697599	3694	Economy	7200.00
0005435697589	3694	Economy	7200.00
0005435935059	3694	Economy	7200.00
0005435916180	3694	Economy	7200.00
0005435697615	3694	Economy	7200.00
0005435935043	3694	Economy	7200.00
0005435916179	3694	Economy	7200.00
0005435697606	3694	Economy	7200.00
0005435697600	3694	Economy	7200.00
0005435697613	3694	Economy	7200.00
0005435697595	3694	Economy	7200.00
0005435697601	3694	Economy	7200.00
0005435697592	3694	Economy	7200.00
0005435916172	3694	Economy	7200.00
0005435697593	3694	Economy	7200.00
0005435697591	3694	Economy	7200.00
0005435935044	3694	Economy	7200.00
0005435935045	3694	Economy	7200.00
0005435697590	3694	Economy	7200.00
0005435697612	3694	Economy	7200.00
0005435697608	3694	Economy	7200.00
0005434950573	3694	Economy	7200.00
0005435697614	3694	Economy	7200.00
0005435697594	3694	Economy	7200.00
0005435935052	3694	Economy	7200.00
0005435697598	3694	Economy	7200.00
0005435697605	3694	Economy	7200.00
0005435697617	3694	Economy	7200.00
0005435697616	3694	Economy	7200.00
0005435916168	3694	Economy	7200.00
0005434950570	3694	Economy	7200.00
0005435697360	16265	Economy	7900.00
0005435916193	16265	Economy	7900.00
0005435697416	16265	Economy	7900.00
0005435697329	16265	Economy	7200.00
0005435697383	16265	Economy	7200.00
0005435697390	16265	Economy	7200.00
0005435697394	16265	Economy	7200.00
0005435697229	16265	Economy	7200.00
0005435916194	16265	Economy	7200.00
0005435697398	16265	Economy	7200.00
0005435697393	16265	Economy	7200.00
0005435935070	16265	Economy	7200.00
0005435935069	16265	Economy	7200.00
0005434950526	16265	Economy	7200.00
0005435697323	16265	Economy	7200.00
0005435697361	16265	Economy	7200.00
0005434950542	16265	Economy	7200.00
0005435697334	16265	Economy	7200.00
0005435935071	16265	Economy	7200.00
0005435935072	16265	Economy	7200.00
0005435697349	16265	Economy	7200.00
0005435697327	16265	Economy	7200.00
0005435697417	16265	Economy	7200.00
0005435916195	16265	Economy	7200.00
0005434950541	16265	Economy	7200.00
0005435697363	16265	Economy	7200.00
0005435697404	16265	Economy	7200.00
0005434950527	16265	Economy	7200.00
0005435697213	16265	Economy	7200.00
0005435697328	16265	Economy	7200.00
0005435697500	16265	Economy	7200.00
0005435916192	16265	Economy	7200.00
0005435697378	16265	Economy	7200.00
0005435697501	16265	Economy	7200.00
0005435697362	16265	Economy	7200.00
0005435697392	16265	Economy	7200.00
0005435697443	16265	Economy	7200.00
0005435697330	16265	Economy	7200.00
0005435697257	16265	Economy	7200.00
0005435697442	16265	Economy	7200.00
0005435697372	16265	Economy	7200.00
0005432607607	3952	Economy	21300.00
0005434606863	3952	Economy	21300.00
0005432607603	3952	Economy	21300.00
0005433519498	3952	Economy	19300.00
0005433519502	3952	Economy	19300.00
0005434604928	3952	Economy	19300.00
0005433519499	3952	Economy	19300.00
0005435853614	3952	Economy	19300.00
0005433519500	3952	Economy	19300.00
0005434606865	3952	Economy	19300.00
0005433519501	3952	Economy	19300.00
0005432607604	3952	Economy	19300.00
0005432609769	3952	Economy	19300.00
0005434604929	3952	Economy	19300.00
0005434606864	3952	Economy	19300.00
0005432607605	3952	Economy	19300.00
0005432609770	3952	Economy	19300.00
0005432607606	3952	Economy	19300.00
0005432609768	3952	Economy	19300.00
0005432609771	3952	Economy	19300.00
0005435853620	3952	Economy	19300.00
0005434606822	22032	Economy	21300.00
0005435853628	22032	Economy	19300.00
0005435853626	22032	Economy	19300.00
0005433519446	22032	Economy	19300.00
0005435853627	22032	Economy	19300.00
0005433519468	22032	Economy	19300.00
0005434606821	22032	Economy	19300.00
0005434606829	22032	Economy	19300.00
0005433519445	22032	Economy	19300.00
0005435628758	781	Economy	3700.00
0005433349009	781	Economy	3700.00
0005433348985	781	Economy	3700.00
0005435628757	781	Economy	3700.00
0005433349010	781	Economy	3700.00
0005433348993	781	Economy	3700.00
0005435628755	781	Economy	3700.00
0005433348986	781	Economy	3700.00
0005433349011	781	Economy	3700.00
0005435628754	781	Economy	3700.00
0005435628756	781	Economy	3700.00
0005433349044	15944	Economy	3700.00
0005433349046	15944	Economy	3700.00
0005433349042	15944	Economy	3700.00
0005433349043	15944	Economy	3700.00
0005433349045	15944	Economy	3700.00
0005435628714	15944	Economy	3700.00
0005435628725	15944	Economy	3700.00
0005435628726	15944	Economy	3700.00
0005435628727	15944	Economy	3700.00
0005434446536	17160	Economy	7100.00
0005433158136	17160	Economy	7100.00
0005434446534	17160	Economy	7100.00
0005434445261	17160	Economy	7100.00
0005434446533	17160	Economy	7100.00
0005433158137	17160	Economy	7100.00
0005434446535	17160	Economy	7100.00
0005433159333	17636	Economy	7100.00
0005433159335	17636	Economy	7100.00
0005433159336	17636	Economy	7100.00
0005434445244	17636	Economy	7100.00
0005433159334	17636	Economy	7100.00
0005435383127	7906	Economy	5900.00
0005435132978	7906	Economy	5400.00
0005435383149	7906	Economy	5400.00
0005435383172	7906	Economy	5400.00
0005435132983	7906	Economy	5400.00
0005435132976	7906	Economy	5400.00
0005435132981	7906	Economy	5400.00
0005435132984	7906	Economy	5400.00
0005435383173	7906	Economy	5400.00
0005435132982	7906	Economy	5400.00
0005435132986	7906	Economy	5400.00
0005435383126	7906	Economy	5400.00
0005435132977	7906	Economy	5400.00
0005435132979	7906	Economy	5400.00
0005435132985	7906	Economy	5400.00
0005435383148	7906	Economy	5400.00
0005435132980	7906	Economy	5400.00
0005435132923	33068	Economy	5900.00
0005435132838	33068	Economy	5900.00
0005435132897	33068	Economy	5900.00
0005435383200	33068	Economy	5400.00
0005435383203	33068	Economy	5400.00
0005435383199	33068	Economy	5400.00
0005435132843	33068	Economy	5400.00
0005435132879	33068	Economy	5400.00
0005435132872	33068	Economy	5400.00
0005435132898	33068	Economy	5400.00
0005435132916	33068	Economy	5400.00
0005435383202	33068	Economy	5400.00
0005435132900	33068	Economy	5400.00
0005435383201	33068	Economy	5400.00
0005435132909	33068	Economy	5400.00
0005435390218	7483	Economy	12500.00
0005435160410	7483	Economy	12500.00
0005435160403	7483	Economy	12500.00
0005435160404	7483	Economy	12500.00
0005435160407	7483	Economy	12500.00
0005435160405	7483	Economy	12500.00
0005435160408	7483	Economy	12500.00
0005435160402	7483	Economy	12500.00
0005435160406	7483	Economy	12500.00
0005435160409	7483	Economy	12500.00
0005435160411	7483	Economy	12500.00
0005435160412	7483	Economy	12500.00
0005435390245	7483	Economy	12500.00
0005435390247	7483	Economy	12500.00
0005435390256	7483	Economy	12500.00
0005435390257	7483	Economy	12500.00
0005435390258	7483	Economy	12500.00
0005435160369	29529	Economy	13800.00
0005435160339	29529	Economy	12500.00
0005435160326	29529	Economy	12500.00
0005435390304	29529	Economy	12500.00
0005435390306	29529	Economy	12500.00
0005435390309	29529	Economy	12500.00
0005435390303	29529	Economy	12500.00
0005435390308	29529	Economy	12500.00
0005435390305	29529	Economy	12500.00
0005435390302	29529	Economy	12500.00
0005435160308	29529	Economy	12500.00
0005435390307	29529	Economy	12500.00
0005435160319	29529	Economy	12500.00
0005435160334	29529	Economy	12500.00
0005435160318	29529	Economy	12500.00
0005432394103	18435	Economy	4900.00
0005432394112	18435	Economy	4900.00
0005432398208	18435	Economy	4900.00
0005432398218	18435	Economy	4900.00
0005435178508	18435	Economy	4900.00
0005432398207	18435	Economy	4900.00
0005435179001	18435	Economy	4900.00
0005435179000	18435	Economy	4900.00
0005432398209	18435	Economy	4900.00
0005432394102	18435	Economy	4900.00
0005435178509	18435	Economy	4900.00
0005435178494	27146	Economy	4900.00
0005435178495	27146	Economy	4900.00
0005435178501	27146	Economy	4900.00
0005432398228	27146	Economy	4900.00
0005432398227	27146	Economy	4900.00
0005432398230	27146	Economy	4900.00
0005432400157	27146	Economy	4900.00
0005432398229	27146	Economy	4900.00
0005432400158	27146	Economy	4900.00
0005432400156	27146	Economy	4900.00
0005434191278	9728	Economy	4400.00
0005434191279	9728	Economy	4400.00
0005434191275	9728	Economy	4400.00
0005434191274	9728	Economy	4400.00
0005434191277	9728	Economy	4400.00
0005434504526	6540	Business	48400.00
0005435104007	6540	Business	48400.00
0005434504510	6540	Business	48400.00
0005434504524	6540	Business	48400.00
0005435104006	6540	Business	48400.00
0005435104000	6540	Business	48400.00
0005435103997	6540	Business	48400.00
0005435103995	6540	Business	48400.00
0005434504505	6540	Business	48400.00
0005435104005	6540	Business	48400.00
0005434504528	6540	Economy	16100.00
0005434504517	6540	Economy	16100.00
0005434504523	6540	Economy	16100.00
0005434504515	6540	Economy	16100.00
0005434504531	6540	Economy	16100.00
0005434504508	6540	Economy	17800.00
0005435104003	6540	Economy	17800.00
0005434504518	6540	Economy	16100.00
0005434504527	6540	Economy	16100.00
0005434504530	6540	Economy	16100.00
0005434504519	6540	Economy	16100.00
0005435104002	6540	Economy	16100.00
0005434504532	6540	Economy	16100.00
0005434504522	6540	Economy	16100.00
0005434504534	6540	Economy	16100.00
0005435103996	6540	Economy	16100.00
0005434504538	6540	Economy	16100.00
0005434504512	6540	Economy	16100.00
0005434504540	6540	Economy	16100.00
0005434504544	6540	Economy	16100.00
0005435104004	6540	Economy	16100.00
0005434504537	6540	Economy	16100.00
0005435104001	6540	Economy	16100.00
0005435103994	6540	Economy	16100.00
0005434504535	6540	Economy	16100.00
0005434504543	6540	Economy	16100.00
0005434504520	6540	Economy	16100.00
0005434504542	6540	Economy	16100.00
0005434504536	6540	Economy	16100.00
0005434504521	6540	Economy	16100.00
0005434504506	6540	Economy	16100.00
0005434504513	6540	Economy	16100.00
0005435103999	6540	Economy	16100.00
0005435104009	6540	Economy	16100.00
0005434504511	6540	Economy	16100.00
0005434504525	6540	Economy	16100.00
0005434504541	6540	Economy	16100.00
0005434504533	6540	Economy	16100.00
0005435103998	6540	Economy	16100.00
0005434504507	6540	Economy	16100.00
0005434504545	6540	Economy	16100.00
0005434504514	6540	Economy	16100.00
0005434504539	6540	Economy	16100.00
0005435104008	6540	Economy	16100.00
0005434504509	6540	Economy	16100.00
0005434504516	6540	Economy	16100.00
0005434504529	6540	Economy	16100.00
0005434503990	22674	Business	48400.00
0005434504080	22674	Business	48400.00
0005434504128	22674	Business	48400.00
0005435103878	22674	Economy	16100.00
0005434504095	22674	Economy	16100.00
0005434504017	22674	Economy	16100.00
0005434503982	22674	Economy	17800.00
0005434504092	22674	Economy	17800.00
0005434504077	22674	Economy	17800.00
0005434504274	22674	Economy	17800.00
0005434504025	22674	Economy	16100.00
0005434504127	22674	Economy	16100.00
0005434504209	22674	Economy	16100.00
0005434504044	22674	Economy	16100.00
0005434504120	22674	Economy	16100.00
0005434503933	22674	Economy	16100.00
0005434504289	22674	Economy	16100.00
0005435103905	22674	Economy	16100.00
0005434504121	22674	Economy	16100.00
0005434504108	22674	Economy	16100.00
0005434504033	22674	Economy	16100.00
0005434504234	22674	Economy	16100.00
0005434504122	22674	Economy	16100.00
0005434504112	22674	Economy	16100.00
0005434504373	22674	Economy	16100.00
0005434504313	22674	Economy	16100.00
0005434504372	22674	Economy	16100.00
0005435103884	22674	Economy	16100.00
0005434504067	22674	Economy	16100.00
0005434504079	22674	Economy	16100.00
0005434504235	22674	Economy	16100.00
0005434503932	22674	Economy	16100.00
0005434504141	22674	Economy	16100.00
0005434504102	22674	Economy	16100.00
0005435103906	22674	Economy	16100.00
0005434504103	22674	Economy	16100.00
0005434504070	22674	Economy	16100.00
0005434504026	22674	Economy	16100.00
0005434504275	22674	Economy	16100.00
0005434504187	22674	Economy	16100.00
0005434504034	22674	Economy	16100.00
0005435103879	22674	Economy	16100.00
0005434504035	22674	Economy	16100.00
0005434504030	22674	Economy	16100.00
0005433367785	1694	Business	50000.00
0005433367877	1694	Business	50000.00
0005435653465	1694	Business	50000.00
0005433368006	1694	Business	50000.00
0005435653481	1694	Business	50000.00
0005433367874	1694	Business	50000.00
0005435653474	1694	Business	50000.00
0005433367990	1694	Business	50000.00
0005433367989	1694	Business	50000.00
0005435653478	1694	Business	50000.00
0005433368005	1694	Business	50000.00
0005433367889	1694	Business	50000.00
0005435653487	1694	Economy	16700.00
0005435653468	1694	Economy	16700.00
0005433367784	1694	Economy	16700.00
0005433367999	1694	Economy	16700.00
0005435653495	1694	Economy	16700.00
0005435653483	1694	Economy	16700.00
0005435653461	1694	Economy	16700.00
0005435653472	1694	Economy	16700.00
0005433367831	1694	Economy	16700.00
0005433368056	1694	Economy	18300.00
0005435653488	1694	Economy	18300.00
0005435653496	1694	Economy	18300.00
0005435653486	1694	Economy	18300.00
0005433368061	1694	Economy	16700.00
0005435653460	1694	Economy	16700.00
0005433367935	1694	Economy	16700.00
0005435653476	1694	Economy	16700.00
0005433368003	1694	Economy	16700.00
0005435653477	1694	Economy	16700.00
0005433367893	1694	Economy	16700.00
0005435653489	1694	Economy	16700.00
0005435653466	1694	Economy	16700.00
0005433367803	1694	Economy	16700.00
0005435653490	1694	Economy	16700.00
0005433367983	1694	Economy	16700.00
0005433367980	1694	Economy	16700.00
0005433367869	1694	Economy	16700.00
0005435653462	1694	Economy	16700.00
0005435653458	1694	Economy	16700.00
0005433367783	1694	Economy	16700.00
0005435653475	1694	Economy	16700.00
0005435653482	1694	Economy	16700.00
0005433367842	1694	Economy	16700.00
0005435653493	1694	Economy	16700.00
0005433367892	1694	Economy	16700.00
0005433367862	1694	Economy	16700.00
0005433367981	1694	Economy	16700.00
0005435653457	1694	Economy	16700.00
0005435653485	1694	Economy	16700.00
0005433367865	1694	Economy	16700.00
0005433367890	1694	Economy	16700.00
0005435653494	1694	Economy	16700.00
0005435653464	1694	Economy	16700.00
0005435653470	1694	Economy	16700.00
0005433368002	1694	Economy	16700.00
0005433367923	1694	Economy	16700.00
0005433367888	1694	Economy	16700.00
0005435653480	1694	Economy	16700.00
0005435653484	1694	Economy	16700.00
0005433367837	1694	Economy	16700.00
0005433367830	1694	Economy	16700.00
0005433367897	1694	Economy	16700.00
0005435653473	1694	Economy	16700.00
0005435653491	1694	Economy	16700.00
0005433368063	1694	Economy	16700.00
0005433367961	1694	Economy	16700.00
0005435653467	1694	Economy	16700.00
0005435653463	1694	Economy	16700.00
0005433367896	1694	Economy	16700.00
0005435653469	1694	Economy	16700.00
0005433367895	1694	Economy	16700.00
0005433367848	1694	Economy	16700.00
0005433367891	1694	Economy	16700.00
0005433367873	1694	Economy	16700.00
0005435653492	1694	Economy	16700.00
0005435653479	1694	Economy	16700.00
0005433367868	1694	Economy	16700.00
0005435653471	1694	Economy	16700.00
0005433367782	1694	Economy	16700.00
0005433367859	1694	Economy	16700.00
0005433367800	1694	Economy	16700.00
0005435653459	1694	Economy	16700.00
0005433367795	1694	Economy	16700.00
0005433367841	1694	Economy	16700.00
0005433368233	21694	Business	50000.00
0005435652992	21694	Business	50000.00
0005435653152	21694	Business	50000.00
0005435653111	21694	Business	50000.00
0005435652981	21694	Business	50000.00
0005433368240	21694	Business	50000.00
0005433368253	21694	Business	50000.00
0005435652937	21694	Business	50000.00
0005433368235	21694	Economy	16700.00
0005433368229	21694	Economy	16700.00
0005433368226	21694	Economy	16700.00
0005433368238	21694	Economy	16700.00
0005433368250	21694	Economy	16700.00
0005433368228	21694	Economy	16700.00
0005433368254	21694	Economy	16700.00
0005435653087	21694	Economy	16700.00
0005435653137	21694	Economy	16700.00
0005433368231	21694	Economy	16700.00
0005433368223	21694	Economy	18300.00
0005435653092	21694	Economy	18300.00
0005435653153	21694	Economy	18300.00
0005433368222	21694	Economy	18300.00
0005433368236	21694	Economy	16700.00
0005435653086	21694	Economy	16700.00
0005435652993	21694	Economy	16700.00
0005435653038	21694	Economy	16700.00
0005433368217	21694	Economy	16700.00
0005433368252	21694	Economy	16700.00
0005433368242	21694	Economy	16700.00
0005435652962	21694	Economy	16700.00
0005433368234	21694	Economy	16700.00
0005435652982	21694	Economy	16700.00
0005435653124	21694	Economy	16700.00
0005433368248	21694	Economy	16700.00
0005433368230	21694	Economy	16700.00
0005435653134	21694	Economy	16700.00
0005433368224	21694	Economy	16700.00
0005435653093	21694	Economy	16700.00
0005435653031	21694	Economy	16700.00
0005433368232	21694	Economy	16700.00
0005435653067	21694	Economy	16700.00
0005433368220	21694	Economy	16700.00
0005433368244	21694	Economy	16700.00
0005435653088	21694	Economy	16700.00
0005435653136	21694	Economy	16700.00
0005435652941	21694	Economy	16700.00
0005433368241	21694	Economy	16700.00
0005435653066	21694	Economy	16700.00
0005433368246	21694	Economy	16700.00
0005433368225	21694	Economy	16700.00
0005433368237	21694	Economy	16700.00
0005435653030	21694	Economy	16700.00
0005435653001	21694	Economy	16700.00
0005433368227	21694	Economy	16700.00
0005435653142	21694	Economy	16700.00
0005435653029	21694	Economy	16700.00
0005435653070	21694	Economy	16700.00
0005435653150	21694	Economy	16700.00
0005433368249	21694	Economy	16700.00
0005435652922	21694	Economy	16700.00
0005433368247	21694	Economy	16700.00
0005435653078	21694	Economy	16700.00
0005433368219	21694	Economy	16700.00
0005435653052	21694	Economy	16700.00
0005435653005	21694	Economy	16700.00
0005433368239	21694	Economy	16700.00
0005433368245	21694	Economy	16700.00
0005435652990	21694	Economy	16700.00
0005435652963	21694	Economy	16700.00
0005433368243	21694	Economy	16700.00
0005435652991	21694	Economy	16700.00
0005433368218	21694	Economy	16700.00
0005435653004	21694	Economy	16700.00
0005435653053	21694	Economy	16700.00
0005433368221	21694	Economy	16700.00
0005435653123	21694	Economy	16700.00
0005435653116	21694	Economy	16700.00
0005435653022	21694	Economy	16700.00
0005435653112	21694	Economy	16700.00
0005435653039	21694	Economy	16700.00
0005435653069	21694	Economy	16700.00
0005433368251	21694	Economy	16700.00
0005435653151	21694	Economy	16700.00
0005435653138	21694	Economy	16700.00
0005433986363	4177	Business	21500.00
0005433986370	4177	Business	21500.00
0005433986371	4177	Business	21500.00
0005435788794	4177	Business	21500.00
0005433986390	4177	Business	21500.00
0005433986381	4177	Business	21500.00
0005433986386	4177	Business	21500.00
0005433986405	4177	Economy	7200.00
0005433986358	4177	Economy	7200.00
0005433986365	4177	Economy	7200.00
0005433986377	4177	Economy	7200.00
0005433986387	4177	Economy	7200.00
0005433986368	4177	Economy	7200.00
0005433986376	4177	Economy	7900.00
0005435788795	4177	Economy	7200.00
0005435788796	4177	Economy	7200.00
0005433986400	4177	Economy	7200.00
0005433986379	4177	Economy	7200.00
0005433986384	4177	Economy	7200.00
0005433986389	4177	Economy	7200.00
0005433986393	4177	Economy	7200.00
0005433986388	4177	Economy	7200.00
0005433986367	4177	Economy	7200.00
0005433986392	4177	Economy	7200.00
0005433986399	4177	Economy	7200.00
0005433986357	4177	Economy	7200.00
0005433986383	4177	Economy	7200.00
0005433986366	4177	Economy	7200.00
0005433986398	4177	Economy	7200.00
0005433986391	4177	Economy	7200.00
0005433986404	4177	Economy	7200.00
0005433986360	4177	Economy	7200.00
0005433986373	4177	Economy	7200.00
0005433986385	4177	Economy	7200.00
0005433986362	4177	Economy	7200.00
0005433986396	4177	Economy	7200.00
0005433986380	4177	Economy	7200.00
0005433986359	4177	Economy	7200.00
0005433986401	4177	Economy	7200.00
0005433986356	4177	Economy	7200.00
0005433986369	4177	Economy	7200.00
0005433986382	4177	Economy	7200.00
0005433986378	4177	Economy	7200.00
0005433986364	4177	Economy	7200.00
0005433986403	4177	Economy	7200.00
0005433986394	4177	Economy	7200.00
0005433986361	4177	Economy	7200.00
0005433986397	4177	Economy	7200.00
0005433986395	4177	Economy	7200.00
0005433986372	4177	Economy	7200.00
0005433986374	4177	Economy	7200.00
0005433986402	4177	Economy	7200.00
0005433986375	4177	Economy	7200.00
0005435788763	25687	Business	21500.00
0005433985969	25687	Business	21500.00
0005433985785	25687	Business	21500.00
0005433985921	25687	Economy	7200.00
0005433985823	25687	Economy	7200.00
0005433985972	25687	Economy	7200.00
0005433985835	25687	Economy	7200.00
0005433985920	25687	Economy	7200.00
0005433985764	25687	Economy	7200.00
0005433985898	25687	Economy	7900.00
0005433985899	25687	Economy	7900.00
0005433985763	25687	Economy	7200.00
0005433985880	25687	Economy	7200.00
0005433985893	25687	Economy	7200.00
0005433985881	25687	Economy	7200.00
0005435788784	25687	Economy	7200.00
0005433985932	25687	Economy	7200.00
0005433985754	25687	Economy	7200.00
0005433985882	25687	Economy	7200.00
0005433985866	25687	Economy	7200.00
0005433985984	25687	Economy	7200.00
0005433985892	25687	Economy	7200.00
0005433985794	25687	Economy	7200.00
0005433985986	25687	Economy	7200.00
0005433985931	25687	Economy	7200.00
0005433985820	25687	Economy	7200.00
0005433985756	25687	Economy	7200.00
0005433985985	25687	Economy	7200.00
0005433985971	25687	Economy	7200.00
0005433985817	25687	Economy	7200.00
0005435788789	25687	Economy	7200.00
0005433985816	25687	Economy	7200.00
0005433985788	25687	Economy	7200.00
0005433985957	25687	Economy	7200.00
0005433985849	25687	Economy	7200.00
0005435788783	25687	Economy	7200.00
0005433985933	25687	Economy	7200.00
0005433985890	25687	Economy	7200.00
0005433985958	25687	Economy	7200.00
0005433985795	25687	Economy	7200.00
0005433985965	25687	Economy	7200.00
0005433985894	25687	Economy	7200.00
0005435788788	25687	Economy	7200.00
0005433985848	25687	Economy	7200.00
0005435788764	25687	Economy	7200.00
0005435720824	21266	Economy	9400.00
0005435720823	21266	Economy	9400.00
0005435720822	21266	Economy	9400.00
0005434509166	21324	Economy	17000.00
0005434509130	21324	Economy	17000.00
0005434509180	21324	Economy	17000.00
0005434509133	21324	Economy	17000.00
0005434509125	21324	Economy	15500.00
0005434509162	21324	Economy	15500.00
0005434509144	21324	Economy	15500.00
0005433168404	21324	Economy	15500.00
0005433168412	21324	Economy	15500.00
0005434509155	21324	Economy	15500.00
0005434509151	21324	Economy	15500.00
0005433168409	21324	Economy	15500.00
0005434509156	21324	Economy	15500.00
0005433168411	21324	Economy	15500.00
0005434509139	21324	Economy	15500.00
0005434509178	21324	Economy	15500.00
0005433168405	21324	Economy	15500.00
0005434509161	21324	Economy	15500.00
0005434509132	21324	Economy	15500.00
0005434509124	21324	Economy	15500.00
0005433168407	21324	Economy	15500.00
0005434509157	21324	Economy	15500.00
0005433168406	21324	Economy	15500.00
0005433168413	21324	Economy	15500.00
0005434509145	21324	Economy	15500.00
0005434509179	21324	Economy	15500.00
0005433168408	21324	Economy	15500.00
0005433168410	21324	Economy	15500.00
0005434509153	21324	Economy	15500.00
0005434509168	21324	Economy	15500.00
0005433168402	21324	Economy	15500.00
0005434509134	21324	Economy	15500.00
0005434509158	21324	Economy	15500.00
0005433168403	21324	Economy	15500.00
0005433168414	21324	Economy	15500.00
0005434509164	21324	Economy	15500.00
0005434509146	21324	Economy	15500.00
0005434509167	21324	Economy	15500.00
0005434509131	21324	Economy	15500.00
0005434509154	21324	Economy	15500.00
0005432655539	17867	Business	18000.00
0005432655495	17867	Business	18000.00
0005434151733	17867	Business	18000.00
0005432661924	17867	Business	18000.00
0005432659708	17867	Business	18000.00
0005432655548	17867	Business	18000.00
0005434151732	17867	Business	18000.00
0005434151734	17867	Economy	6000.00
0005432665278	17867	Economy	6000.00
0005432869590	17867	Economy	6000.00
0005432657458	17867	Economy	6000.00
0005432869591	17867	Economy	6000.00
0005432869593	17867	Economy	6000.00
0005432655582	17867	Economy	6000.00
0005432660815	17867	Economy	6000.00
0005432664131	17867	Economy	6000.00
0005432657445	17867	Economy	6000.00
0005432655549	17867	Economy	6000.00
0005432663029	17867	Economy	6000.00
0005432659707	17867	Economy	6000.00
0005432655541	17867	Economy	6000.00
0005432869592	17867	Economy	6000.00
0005432658600	17867	Economy	6000.00
0005432660808	17867	Economy	6000.00
0005432658591	17867	Economy	6000.00
0005432655555	17867	Economy	6000.00
0005432663028	17867	Economy	6000.00
0005432655586	17867	Economy	6000.00
0005432869589	17867	Economy	6000.00
0005432663027	17867	Economy	6000.00
0005432658601	17867	Economy	6000.00
0005432665279	17867	Economy	6000.00
0005432655521	17867	Economy	6000.00
0005432660812	17867	Economy	6000.00
0005432655512	17867	Economy	6000.00
0005432660816	17867	Economy	6000.00
0005432666381	17867	Economy	6000.00
0005432655513	17867	Economy	6000.00
0005432659701	17867	Economy	6000.00
0005432661922	17867	Economy	6000.00
0005432665270	17867	Economy	6000.00
0005432666394	17867	Economy	6000.00
0005432655522	17867	Economy	6000.00
0005432657459	17867	Economy	6000.00
0005432665271	17867	Economy	6000.00
0005432655551	17867	Economy	6000.00
0005432655540	17867	Economy	6000.00
0005432655524	17867	Economy	6000.00
0005432655619	26334	Business	18000.00
0005432655626	26334	Business	18000.00
0005432655623	26334	Business	18000.00
0005432869531	26334	Business	18000.00
0005434151705	26334	Business	18000.00
0005432666407	26334	Economy	6000.00
0005434151701	26334	Economy	6000.00
0005432659724	26334	Economy	6000.00
0005432655628	26334	Economy	6000.00
0005432869508	26334	Economy	6000.00
0005432655627	26334	Economy	6000.00
0005432667472	26334	Economy	6000.00
0005432666406	26334	Economy	6600.00
0005432660836	26334	Economy	6600.00
0005434151706	26334	Economy	6600.00
0005432659722	26334	Economy	6000.00
0005432869522	26334	Economy	6000.00
0005432667471	26334	Economy	6000.00
0005432655631	26334	Economy	6000.00
0005432660835	26334	Economy	6000.00
0005432869509	26334	Economy	6000.00
0005432655629	26334	Economy	6000.00
0005434151702	26334	Economy	6000.00
0005432655620	26334	Economy	6000.00
0005432869521	26334	Economy	6000.00
0005434151697	26334	Economy	6000.00
0005432657475	26334	Economy	6000.00
0005432657474	26334	Economy	6000.00
0005432655621	26334	Economy	6000.00
0005434151700	26334	Economy	6000.00
0005432666405	26334	Economy	6000.00
0005434151703	26334	Economy	6000.00
0005434151695	26334	Economy	6000.00
0005432657473	26334	Economy	6000.00
0005432869507	26334	Economy	6000.00
0005432655624	26334	Economy	6000.00
0005434151704	26334	Economy	6000.00
0005432655622	26334	Economy	6000.00
0005432659723	26334	Economy	6000.00
0005432665292	26334	Economy	6000.00
0005432655630	26334	Economy	6000.00
0005432655625	26334	Economy	6000.00
0005432665291	26334	Economy	6000.00
0005434151696	26334	Economy	6000.00
0005432329137	3112	Business	16100.00
0005432329157	3112	Business	16100.00
0005432329147	3112	Business	16100.00
0005433438951	3112	Business	16100.00
0005433438950	3112	Business	16100.00
0005432329156	3112	Business	16100.00
0005433438947	3112	Business	16100.00
0005432287237	3112	Economy	5400.00
0005432329153	3112	Economy	5400.00
0005432329122	3112	Economy	5400.00
0005432329116	3112	Economy	5400.00
0005432287239	3112	Economy	5400.00
0005432329113	3112	Economy	5400.00
0005432329158	3112	Economy	5900.00
0005433438949	3112	Economy	5900.00
0005432905149	3112	Economy	5900.00
0005432329140	3112	Economy	5900.00
0005432329128	3112	Economy	5400.00
0005432329114	3112	Economy	5400.00
0005432329151	3112	Economy	5400.00
0005432329124	3112	Economy	5400.00
0005432329155	3112	Economy	5400.00
0005432329144	3112	Economy	5400.00
0005432329132	3112	Economy	5400.00
0005432329131	3112	Economy	5400.00
0005432329130	3112	Economy	5400.00
0005432329115	3112	Economy	5400.00
0005432329129	3112	Economy	5400.00
0005432329145	3112	Economy	5400.00
0005432329149	3112	Economy	5400.00
0005432329136	3112	Economy	5400.00
0005432329139	3112	Economy	5400.00
0005432329142	3112	Economy	5400.00
0005432329141	3112	Economy	5400.00
0005433438945	3112	Economy	5400.00
0005433438953	3112	Economy	5400.00
0005432329152	3112	Economy	5400.00
0005432329133	3112	Economy	5400.00
0005432329138	3112	Economy	5400.00
0005432329120	3112	Economy	5400.00
0005432329150	3112	Economy	5400.00
0005432329148	3112	Economy	5400.00
0005433438948	3112	Economy	5400.00
0005432329118	3112	Economy	5400.00
0005432329117	3112	Economy	5400.00
0005432905137	3112	Economy	5400.00
0005432905150	3112	Economy	5400.00
0005432329127	3112	Economy	5400.00
0005432329143	3112	Economy	5400.00
0005432329126	3112	Economy	5400.00
0005432287238	3112	Economy	5400.00
0005433438952	3112	Economy	5400.00
0005432329135	3112	Economy	5400.00
0005432287235	3112	Economy	5400.00
0005432905148	3112	Economy	5400.00
0005432329123	3112	Economy	5400.00
0005432329146	3112	Economy	5400.00
0005432329154	3112	Economy	5400.00
0005432329134	3112	Economy	5400.00
0005432329119	3112	Economy	5400.00
0005433438954	3112	Economy	5400.00
0005432329121	3112	Economy	5400.00
0005433438946	3112	Economy	5400.00
0005432329112	3112	Economy	5400.00
0005432287236	3112	Economy	5400.00
0005432329125	3112	Economy	5400.00
0005432328655	31126	Business	16100.00
0005432905177	31126	Business	16100.00
0005432328656	31126	Business	16100.00
0005432054330	31126	Business	16100.00
0005432328762	31126	Business	16100.00
0005432328772	31126	Business	16100.00
0005432905182	31126	Business	16100.00
0005432328761	31126	Business	16100.00
0005432328831	31126	Business	16100.00
0005432328566	31126	Economy	5400.00
0005432328559	31126	Economy	5400.00
0005433438874	31126	Economy	5400.00
0005432328609	31126	Economy	5400.00
0005432328739	31126	Economy	5400.00
0005432328639	31126	Economy	5400.00
0005432054331	31126	Economy	5900.00
0005432905178	31126	Economy	5900.00
0005432328491	31126	Economy	5400.00
0005432328657	31126	Economy	5400.00
0005433438873	31126	Economy	5400.00
0005432328870	31126	Economy	5400.00
0005432328536	31126	Economy	5400.00
0005432328615	31126	Economy	5400.00
0005432905181	31126	Economy	5400.00
0005433438895	31126	Economy	5400.00
0005432328611	31126	Economy	5400.00
0005432328775	31126	Economy	5400.00
0005432328411	31126	Economy	5400.00
0005432328568	31126	Economy	5400.00
0005432905180	31126	Economy	5400.00
0005432328633	31126	Economy	5400.00
0005432328383	31126	Economy	5400.00
0005432328782	31126	Economy	5400.00
0005433438863	31126	Economy	5400.00
0005432328786	31126	Economy	5400.00
0005432328751	31126	Economy	5400.00
0005432328608	31126	Economy	5400.00
0005432328767	31126	Economy	5400.00
0005432328763	31126	Economy	5400.00
0005432328490	31126	Economy	5400.00
0005432905179	31126	Economy	5400.00
0005432328814	31126	Economy	5400.00
0005433438896	31126	Economy	5400.00
0005432328746	31126	Economy	5400.00
0005432328731	31126	Economy	5400.00
0005432328769	31126	Economy	5400.00
0005432328714	31126	Economy	5400.00
0005432328755	31126	Economy	5400.00
0005432328919	31126	Economy	5400.00
0005432328684	31126	Economy	5400.00
0005432328783	31126	Economy	5400.00
0005432054333	31126	Economy	5400.00
0005432328631	31126	Economy	5400.00
0005432054332	31126	Economy	5400.00
0005432328730	31126	Economy	5400.00
0005432328741	31126	Economy	5400.00
0005432328791	31126	Economy	5400.00
0005432328658	31126	Economy	5400.00
0005432328771	31126	Economy	5400.00
0005432905183	31126	Economy	5400.00
0005433438854	31126	Economy	5400.00
0005432328781	31126	Economy	5400.00
0005432328745	31126	Economy	5400.00
0005432328632	31126	Economy	5400.00
0005433438860	31126	Economy	5400.00
0005432146218	6195	Business	124600.00
0005435487822	6195	Business	124600.00
0005435999413	6195	Business	124600.00
0005435999410	6195	Business	124600.00
0005435297075	6195	Economy	41500.00
0005435487883	6195	Economy	41500.00
0005435487880	6195	Economy	41500.00
0005435999415	6195	Economy	41500.00
0005434309871	6195	Economy	41500.00
0005435999412	6195	Economy	41500.00
0005435297061	6195	Economy	41500.00
0005435297050	6195	Economy	41500.00
0005435487882	6195	Economy	41500.00
0005435297067	6195	Economy	41500.00
0005435487881	6195	Economy	41500.00
0005435487867	6195	Economy	41500.00
0005435999409	6195	Economy	41500.00
0005435487816	6195	Economy	41500.00
0005435999405	6195	Economy	41500.00
0005435297076	6195	Economy	41500.00
0005435487872	6195	Economy	41500.00
0005434309867	6195	Economy	41500.00
0005435999422	6195	Economy	41500.00
0005435999414	6195	Economy	41500.00
0005434309873	6195	Economy	41500.00
0005435999407	6195	Economy	41500.00
0005435999420	6195	Economy	41500.00
0005435297069	6195	Economy	41500.00
0005434309864	6195	Economy	41500.00
0005434309865	6195	Economy	41500.00
0005435487895	6195	Economy	45700.00
0005435999411	6195	Economy	45700.00
0005435297063	6195	Economy	41500.00
0005435999421	6195	Economy	41500.00
0005435999417	6195	Economy	41500.00
0005435999418	6195	Economy	41500.00
0005435487817	6195	Economy	41500.00
0005435297052	6195	Economy	41500.00
0005435487836	6195	Economy	41500.00
0005435999416	6195	Economy	41500.00
0005434309866	6195	Economy	41500.00
0005434309874	6195	Economy	41500.00
0005435487853	6195	Economy	41500.00
0005435487854	6195	Economy	41500.00
0005435487835	6195	Economy	41500.00
0005434309875	6195	Economy	41500.00
0005435297062	6195	Economy	41500.00
0005435487914	6195	Economy	41500.00
0005434309870	6195	Economy	41500.00
0005435999419	6195	Economy	41500.00
0005434309869	6195	Economy	41500.00
0005434309876	6195	Economy	41500.00
0005435297053	6195	Economy	41500.00
0005434309877	6195	Economy	41500.00
0005435487877	6195	Economy	41500.00
0005435487894	6195	Economy	41500.00
0005435999423	6195	Economy	41500.00
0005435999406	6195	Economy	41500.00
0005435999408	6195	Economy	41500.00
0005434309872	6195	Economy	41500.00
0005435487769	6195	Economy	41500.00
0005434309868	6195	Economy	41500.00
0005434309784	19560	Business	124600.00
0005435999239	19560	Business	124600.00
0005435488028	19560	Business	124600.00
0005435488013	19560	Business	124600.00
0005435488026	19560	Business	124600.00
0005434309741	19560	Business	124600.00
0005435488015	19560	Economy	41500.00
0005435999243	19560	Economy	41500.00
0005435999250	19560	Economy	41500.00
0005435488022	19560	Economy	41500.00
0005435488024	19560	Economy	41500.00
0005435999251	19560	Economy	41500.00
0005435999220	19560	Economy	41500.00
0005434309725	19560	Economy	41500.00
0005435488029	19560	Economy	41500.00
0005435297122	19560	Economy	41500.00
0005435297124	19560	Economy	41500.00
0005435488007	19560	Economy	41500.00
0005434309688	19560	Economy	41500.00
0005435488021	19560	Economy	41500.00
0005434309689	19560	Economy	41500.00
0005435999245	19560	Economy	41500.00
0005435297123	19560	Economy	41500.00
0005435999244	19560	Economy	41500.00
0005435488023	19560	Economy	45700.00
0005435488027	19560	Economy	45700.00
0005435488030	19560	Economy	45700.00
0005434309740	19560	Economy	45700.00
0005435999219	19560	Economy	45700.00
0005435999218	19560	Economy	41500.00
0005435999208	19560	Economy	41500.00
0005435488011	19560	Economy	41500.00
0005435297126	19560	Economy	41500.00
0005435488031	19560	Economy	41500.00
0005435999232	19560	Economy	41500.00
0005435488018	19560	Economy	41500.00
0005434309760	19560	Economy	41500.00
0005434309753	19560	Economy	41500.00
0005435488016	19560	Economy	41500.00
0005435488008	19560	Economy	41500.00
0005435488014	19560	Economy	41500.00
0005435488025	19560	Economy	41500.00
0005435488012	19560	Economy	41500.00
0005434309765	19560	Economy	41500.00
0005435297125	19560	Economy	41500.00
0005435297121	19560	Economy	41500.00
0005435488010	19560	Economy	41500.00
0005435488017	19560	Economy	41500.00
0005435999191	19560	Economy	41500.00
0005435488009	19560	Economy	41500.00
0005435999225	19560	Economy	41500.00
0005435488019	19560	Economy	41500.00
0005435999209	19560	Economy	41500.00
0005435999247	19560	Economy	41500.00
0005435488020	19560	Economy	41500.00
0005435999183	19560	Economy	41500.00
0005434309761	19560	Economy	41500.00
0005433186160	1581	Business	86000.00
0005435508469	1581	Business	86000.00
0005434566039	1581	Business	86000.00
0005432291952	1581	Business	86000.00
0005435508466	1581	Business	86000.00
0005435518093	1581	Business	86000.00
0005435518082	1581	Business	86000.00
0005435518083	1581	Business	86000.00
0005435502511	1581	Economy	28700.00
0005433186118	1581	Economy	28700.00
0005433186126	1581	Economy	28700.00
0005435502514	1581	Economy	28700.00
0005435502524	1581	Economy	28700.00
0005435508472	1581	Economy	28700.00
0005435518091	1581	Economy	28700.00
0005434566042	1581	Economy	31500.00
0005435502528	1581	Economy	31500.00
0005433186142	1581	Economy	31500.00
0005434566040	1581	Economy	28700.00
0005435502520	1581	Economy	28700.00
0005435518079	1581	Economy	28700.00
0005435508464	1581	Economy	28700.00
0005433186117	1581	Economy	28700.00
0005435502517	1581	Economy	28700.00
0005435502519	1581	Economy	28700.00
0005435502529	1581	Economy	28700.00
0005434566047	1581	Economy	28700.00
0005434566041	1581	Economy	28700.00
0005435508467	1581	Economy	28700.00
0005433186144	1581	Economy	28700.00
0005435518074	1581	Economy	28700.00
0005435518077	1581	Economy	28700.00
0005434566044	1581	Economy	28700.00
0005434566038	1581	Economy	28700.00
0005432291953	1581	Economy	28700.00
0005435502515	1581	Economy	28700.00
0005435518084	1581	Economy	28700.00
0005435502527	1581	Economy	28700.00
0005435502526	1581	Economy	28700.00
0005434566049	1581	Economy	28700.00
0005433186159	1581	Economy	28700.00
0005433186143	1581	Economy	28700.00
0005435508465	1581	Economy	28700.00
0005434566043	1581	Economy	28700.00
0005435518080	1581	Economy	28700.00
0005435502521	1581	Economy	28700.00
0005435502512	1581	Economy	28700.00
0005435502508	1581	Economy	28700.00
0005435502516	1581	Economy	28700.00
0005435518078	1581	Economy	28700.00
0005435502510	1581	Economy	28700.00
0005434566046	1581	Economy	28700.00
0005435518076	1581	Economy	28700.00
0005435502522	1581	Economy	28700.00
0005435518088	1581	Economy	28700.00
0005435518092	1581	Economy	28700.00
0005434566048	1581	Economy	28700.00
0005434566045	1581	Economy	28700.00
0005435502518	1581	Economy	28700.00
0005435518081	1581	Economy	28700.00
0005435518086	1581	Economy	28700.00
0005435508468	1581	Economy	28700.00
0005435502523	1581	Economy	28700.00
0005435518090	1581	Economy	28700.00
0005435508470	1581	Economy	28700.00
0005435508471	1581	Economy	28700.00
0005435518073	1581	Economy	28700.00
0005435518085	1581	Economy	28700.00
0005435502513	1581	Economy	28700.00
0005435502525	1581	Economy	28700.00
0005435518087	1581	Economy	28700.00
0005435502509	1581	Economy	28700.00
0005435508463	1581	Economy	28700.00
0005433186102	1581	Economy	28700.00
0005435518075	1581	Economy	28700.00
0005435518089	1581	Economy	28700.00
0005434566037	1581	Economy	28700.00
0005435529218	20885	Business	86000.00
0005435529255	20885	Business	86000.00
0005435502412	20885	Business	86000.00
0005434565936	20885	Business	86000.00
0005434565872	20885	Business	86000.00
0005435502364	20885	Business	86000.00
0005435545723	20885	Business	86000.00
0005435529322	20885	Economy	28700.00
0005435529234	20885	Economy	28700.00
0005434565945	20885	Economy	28700.00
0005435502286	20885	Economy	28700.00
0005435502285	20885	Economy	28700.00
0005435545740	20885	Economy	28700.00
0005433186198	20885	Economy	28700.00
0005435529265	20885	Economy	28700.00
0005433186199	20885	Economy	31500.00
0005435529236	20885	Economy	31500.00
0005435529263	20885	Economy	31500.00
0005433186197	20885	Economy	31500.00
0005435502283	20885	Economy	28700.00
0005435502328	20885	Economy	28700.00
0005435545746	20885	Economy	28700.00
0005435502322	20885	Economy	28700.00
0005435545727	20885	Economy	28700.00
0005435502353	20885	Economy	28700.00
0005434565866	20885	Economy	28700.00
0005435529304	20885	Economy	28700.00
0005435502252	20885	Economy	28700.00
0005433186203	20885	Economy	28700.00
0005433186201	20885	Economy	28700.00
0005435529235	20885	Economy	28700.00
0005435502211	20885	Economy	28700.00
0005435545751	20885	Economy	28700.00
0005435529351	20885	Economy	28700.00
0005435502356	20885	Economy	28700.00
0005435545745	20885	Economy	28700.00
0005434565944	20885	Economy	28700.00
0005435502369	20885	Economy	28700.00
0005434565942	20885	Economy	28700.00
0005435529157	20885	Economy	28700.00
0005435502251	20885	Economy	28700.00
0005435502393	20885	Economy	28700.00
0005435529264	20885	Economy	28700.00
0005433186196	20885	Economy	28700.00
0005435502394	20885	Economy	28700.00
0005434565921	20885	Economy	28700.00
0005433186202	20885	Economy	28700.00
0005435502413	20885	Economy	28700.00
0005435529151	20885	Economy	28700.00
0005434565891	20885	Economy	28700.00
0005434565898	20885	Economy	28700.00
0005434565916	20885	Economy	28700.00
0005435502411	20885	Economy	28700.00
0005433186200	20885	Economy	28700.00
0005435529170	20885	Economy	28700.00
0005434565905	20885	Economy	28700.00
0005435502249	20885	Economy	28700.00
0005435529254	20885	Economy	28700.00
0005435545731	20885	Economy	28700.00
0005435529237	20885	Economy	28700.00
0005435545717	20885	Economy	28700.00
0005435529303	20885	Economy	28700.00
0005434565943	20885	Economy	28700.00
0005434565897	20885	Economy	28700.00
0005435502352	20885	Economy	28700.00
0005435529145	20885	Economy	28700.00
0005435502295	20885	Economy	28700.00
0005435502265	20885	Economy	28700.00
0005434565904	20885	Economy	28700.00
0005435545732	20885	Economy	28700.00
0005435529244	20885	Economy	28700.00
0005435502290	20885	Economy	28700.00
0005435502284	20885	Economy	28700.00
0005435529219	20885	Economy	28700.00
0005434565865	20885	Economy	28700.00
0005435931610	3883	Economy	21600.00
0005435153802	3883	Economy	21600.00
0005435153806	3883	Economy	19700.00
0005435931603	3883	Economy	19700.00
0005435931602	3883	Economy	19700.00
0005435153805	3883	Economy	19700.00
0005435153803	3883	Economy	19700.00
0005435153804	3883	Economy	19700.00
0005435931599	3883	Economy	19700.00
0005435931608	3883	Economy	19700.00
0005435931601	3883	Economy	19700.00
0005435931607	3883	Economy	19700.00
0005435931598	3883	Economy	19700.00
0005435153807	3883	Economy	19700.00
0005435931637	21874	Economy	21600.00
0005435153734	21874	Economy	21600.00
0005435931638	21874	Economy	19700.00
0005435153773	21874	Economy	19700.00
0005435153758	21874	Economy	19700.00
0005435153743	21874	Economy	19700.00
0005435153735	21874	Economy	19700.00
0005435153761	21874	Economy	19700.00
0005435931635	21874	Economy	19700.00
0005435153744	21874	Economy	19700.00
0005435153736	21874	Economy	19700.00
0005435931636	21874	Economy	19700.00
0005435153748	21874	Economy	19700.00
0005432628984	7180	Economy	13000.00
0005435225573	7180	Economy	13000.00
0005435225586	7180	Economy	13000.00
0005432628985	7180	Economy	13000.00
0005435225572	7180	Economy	13000.00
0005435225589	7180	Economy	13000.00
0005432628993	7180	Economy	13000.00
0005435225596	7180	Economy	13000.00
0005432628990	7180	Economy	13000.00
0005432628988	7180	Economy	13000.00
0005435225602	7180	Economy	13000.00
0005432628991	7180	Economy	13000.00
0005432628987	7180	Economy	13000.00
0005432628979	7180	Economy	13000.00
0005432628986	7180	Economy	13000.00
0005432628992	7180	Economy	13000.00
0005432628989	7180	Economy	13000.00
0005435225606	7180	Economy	13000.00
0005432628980	7180	Economy	13000.00
0005435225619	7180	Economy	13000.00
0005432628983	7180	Economy	13000.00
0005432628981	7180	Economy	13000.00
0005432628982	7180	Economy	13000.00
0005435225571	7180	Economy	13000.00
0005435225659	28119	Economy	13000.00
0005432628887	28119	Economy	13000.00
0005435225658	28119	Economy	13000.00
0005435225661	28119	Economy	13000.00
0005435225662	28119	Economy	13000.00
0005435225660	28119	Economy	13000.00
0005432628880	28119	Economy	13000.00
0005432628848	28119	Economy	13000.00
0005435225663	28119	Economy	13000.00
0005432628882	28119	Economy	13000.00
0005432628970	28119	Economy	13000.00
0005432628876	28119	Economy	13000.00
0005435225664	28119	Economy	13000.00
0005432628849	28119	Economy	13000.00
0005432628912	28119	Economy	13000.00
0005435225657	28119	Economy	13000.00
0005432628901	28119	Economy	13000.00
0005432628892	28119	Economy	13000.00
0005432628971	28119	Economy	13000.00
0005432628881	28119	Economy	13000.00
0005435960086	8759	Economy	10500.00
0005435960087	8759	Economy	10500.00
0005435960088	8759	Economy	10500.00
0005435960064	15269	Economy	11500.00
0005435960052	15269	Economy	10500.00
0005434267985	15269	Economy	10500.00
0005434267986	15269	Economy	10500.00
0005435960063	15269	Economy	10500.00
0005434267987	15269	Economy	10500.00
0005432693344	1175	Business	115000.00
0005432693335	1175	Business	115000.00
0005432693339	1175	Business	115000.00
0005432693330	1175	Business	115000.00
0005432675282	1175	Business	115000.00
0005432675281	1175	Business	115000.00
0005432675276	1175	Business	115000.00
0005432693342	1175	Business	115000.00
0005432693324	1175	Business	115000.00
0005432873313	1175	Business	115000.00
0005432675272	1175	Business	115000.00
0005432693323	1175	Business	115000.00
0005432693327	1175	Business	115000.00
0005432675270	1175	Business	115000.00
0005432693329	1175	Economy	38300.00
0005432675280	1175	Economy	38300.00
0005432675277	1175	Economy	38300.00
0005432693321	1175	Economy	38300.00
0005432873315	1175	Economy	38300.00
0005432873316	1175	Economy	38300.00
0005432693326	1175	Economy	38300.00
0005432675271	1175	Economy	42200.00
0005432873305	1175	Economy	38300.00
0005432675278	1175	Economy	38300.00
0005432693317	1175	Economy	38300.00
0005432693345	1175	Economy	38300.00
0005432677605	1175	Economy	38300.00
0005432675268	1175	Economy	38300.00
0005432693332	1175	Economy	38300.00
0005432873285	1175	Economy	38300.00
0005432693325	1175	Economy	38300.00
0005432873301	1175	Economy	38300.00
0005432675275	1175	Economy	38300.00
0005432693331	1175	Economy	38300.00
0005432693318	1175	Economy	38300.00
0005432693341	1175	Economy	38300.00
0005432677608	1175	Economy	38300.00
0005432693328	1175	Economy	38300.00
0005432675279	1175	Economy	38300.00
0005432693337	1175	Economy	38300.00
0005432693338	1175	Economy	38300.00
0005432693320	1175	Economy	38300.00
0005432873312	1175	Economy	38300.00
0005432873311	1175	Economy	38300.00
0005432693340	1175	Economy	38300.00
0005432693347	1175	Economy	38300.00
0005432693333	1175	Economy	38300.00
0005432675274	1175	Economy	38300.00
0005432873317	1175	Economy	38300.00
0005432693319	1175	Economy	38300.00
0005432675269	1175	Economy	38300.00
0005432873304	1175	Economy	38300.00
0005432677607	1175	Economy	38300.00
0005432693322	1175	Economy	38300.00
0005432873286	1175	Economy	38300.00
0005432693334	1175	Economy	38300.00
0005432677606	1175	Economy	38300.00
0005432675273	1175	Economy	38300.00
0005432693343	1175	Economy	38300.00
0005432693346	1175	Economy	38300.00
0005432693316	1175	Economy	38300.00
0005432693336	1175	Economy	38300.00
0005432692891	17502	Business	115000.00
0005432873357	17502	Business	115000.00
0005432677568	17502	Business	115000.00
0005432873356	17502	Business	115000.00
0005432873362	17502	Business	115000.00
0005432873361	17502	Business	115000.00
0005432693168	17502	Business	115000.00
0005432675071	17502	Business	115000.00
0005432675163	17502	Business	115000.00
0005432675102	17502	Business	115000.00
0005432675120	17502	Business	115000.00
0005432693122	17502	Business	115000.00
0005432873360	17502	Business	115000.00
0005432693100	17502	Business	115000.00
0005432675170	17502	Economy	38300.00
0005432693070	17502	Economy	38300.00
0005432873355	17502	Economy	38300.00
0005432693011	17502	Economy	38300.00
0005432693045	17502	Economy	38300.00
0005432675100	17502	Economy	38300.00
0005432693048	17502	Economy	38300.00
0005432677567	17502	Economy	38300.00
0005432693101	17502	Economy	42200.00
0005432675169	17502	Economy	38300.00
0005432693121	17502	Economy	42200.00
0005432675108	17502	Economy	38300.00
0005432692912	17502	Economy	38300.00
0005432675180	17502	Economy	38300.00
0005432693156	17502	Economy	38300.00
0005432693158	17502	Economy	38300.00
0005432693094	17502	Economy	38300.00
0005432693079	17502	Economy	38300.00
0005432675119	17502	Economy	38300.00
0005432675164	17502	Economy	38300.00
0005432675155	17502	Economy	38300.00
0005432692892	17502	Economy	38300.00
0005432692995	17502	Economy	38300.00
0005432693150	17502	Economy	38300.00
0005432693106	17502	Economy	38300.00
0005432677576	17502	Economy	38300.00
0005432692974	17502	Economy	38300.00
0005432873358	17502	Economy	38300.00
0005432693012	17502	Economy	38300.00
0005432693105	17502	Economy	38300.00
0005432693104	17502	Economy	38300.00
0005432693151	17502	Economy	38300.00
0005432677575	17502	Economy	38300.00
0005432693103	17502	Economy	38300.00
0005432693044	17502	Economy	38300.00
0005432675070	17502	Economy	38300.00
0005432677579	17502	Economy	38300.00
0005432693028	17502	Economy	38300.00
0005432675101	17502	Economy	38300.00
0005432873359	17502	Economy	38300.00
0005432693157	17502	Economy	38300.00
0005432693095	17502	Economy	38300.00
0005432675158	17502	Economy	38300.00
0005432693043	17502	Economy	38300.00
0005432693029	17502	Economy	38300.00
0005432692911	17502	Economy	38300.00
0005432675107	17502	Economy	38300.00
0005432693020	17502	Economy	38300.00
0005432692973	17502	Economy	38300.00
0005432675171	17502	Economy	38300.00
0005432675083	17502	Economy	38300.00
0005433156771	1117	Economy	13900.00
0005433156703	1117	Economy	13900.00
0005434435333	1117	Economy	13900.00
0005433156749	1117	Economy	13900.00
0005433156746	1117	Economy	13900.00
0005434435332	1117	Economy	13900.00
0005433156747	1117	Economy	13900.00
0005434435326	1117	Economy	13900.00
0005434435329	1117	Economy	13900.00
0005434435334	1117	Economy	13900.00
0005434435324	1117	Economy	13900.00
0005434435330	1117	Economy	13900.00
0005433156773	1117	Economy	13900.00
0005433156762	1117	Economy	13900.00
0005433156779	1117	Economy	13900.00
0005434435321	1117	Economy	13900.00
0005434435327	1117	Economy	13900.00
0005433156778	1117	Economy	13900.00
0005434435322	1117	Economy	13900.00
0005434435331	1117	Economy	13900.00
0005433156702	1117	Economy	13900.00
0005433156761	1117	Economy	13900.00
0005434435325	1117	Economy	13900.00
0005434435323	1117	Economy	13900.00
0005433156772	1117	Economy	13900.00
0005434435328	1117	Economy	13900.00
0005433156835	17275	Economy	15200.00
0005434435204	17275	Economy	15200.00
0005434435149	17275	Economy	13900.00
0005433156834	17275	Economy	13900.00
0005434435205	17275	Economy	13900.00
0005433156827	17275	Economy	13900.00
0005433156828	17275	Economy	13900.00
0005433156831	17275	Economy	13900.00
0005434435163	17275	Economy	13900.00
0005434435209	17275	Economy	13900.00
0005433156836	17275	Economy	13900.00
0005434435206	17275	Economy	13900.00
0005433156833	17275	Economy	13900.00
0005434435208	17275	Economy	13900.00
0005434435131	17275	Economy	13900.00
0005433156830	17275	Economy	13900.00
0005434435177	17275	Economy	13900.00
0005434435238	17275	Economy	13900.00
0005434435203	17275	Economy	13900.00
0005434435207	17275	Economy	13900.00
0005434435162	17275	Economy	13900.00
0005433156832	17275	Economy	13900.00
0005433156829	17275	Economy	13900.00
0005434435202	17275	Economy	13900.00
0005435928160	4074	Economy	7500.00
0005435928155	4074	Economy	7500.00
0005435086907	4074	Economy	7500.00
0005435928135	4074	Economy	7500.00
0005435928159	4074	Economy	7500.00
0005435086909	4074	Economy	7500.00
0005435086908	4074	Economy	7500.00
0005435086903	4074	Economy	7500.00
0005435086906	4074	Economy	7500.00
0005435086905	4074	Economy	7500.00
0005435086904	4074	Economy	7500.00
0005435928187	24400	Economy	8200.00
0005435086809	24400	Economy	8200.00
0005435086825	24400	Economy	7500.00
0005435086810	24400	Economy	7500.00
0005435928190	24400	Economy	7500.00
0005435086845	24400	Economy	7500.00
0005435086844	24400	Economy	7500.00
0005435086849	24400	Economy	7500.00
0005435086839	24400	Economy	7500.00
0005435086850	24400	Economy	7500.00
0005435928189	24400	Economy	7500.00
0005435928188	24400	Economy	7500.00
0005435086840	24400	Economy	7500.00
0005435928186	24400	Economy	7500.00
0005435086836	24400	Economy	7500.00
0005435907509	4816	Business	44200.00
0005435907515	4816	Business	44200.00
0005434626048	4816	Economy	14700.00
0005434626047	4816	Economy	14700.00
0005434626051	4816	Economy	14700.00
0005435907527	4816	Economy	16200.00
0005434626052	4816	Economy	14700.00
0005434626053	4816	Economy	14700.00
0005435907516	4816	Economy	14700.00
0005434626046	4816	Economy	14700.00
0005434626054	4816	Economy	14700.00
0005434626050	4816	Economy	14700.00
0005435907522	4816	Economy	14700.00
0005433194852	4816	Economy	14700.00
0005434626049	4816	Economy	14700.00
0005434626055	4816	Economy	14700.00
0005435907528	4816	Economy	14700.00
0005433194888	32901	Business	44200.00
0005434625979	32901	Business	44200.00
0005434625981	32901	Economy	14700.00
0005433194891	32901	Economy	14700.00
0005434625962	32901	Economy	14700.00
0005434625961	32901	Economy	16200.00
0005435907551	32901	Economy	14700.00
0005435907548	32901	Economy	14700.00
0005433194890	32901	Economy	14700.00
0005435907549	32901	Economy	14700.00
0005434625970	32901	Economy	14700.00
0005435907550	32901	Economy	14700.00
0005435907553	32901	Economy	14700.00
0005433194889	32901	Economy	14700.00
0005434625978	32901	Economy	14700.00
0005435907552	32901	Economy	14700.00
0005435785299	13757	Economy	3400.00
0005435785453	13757	Economy	3400.00
0005435785249	13757	Economy	3400.00
0005435785353	13757	Economy	3400.00
0005435785356	13757	Economy	3100.00
0005435785454	13757	Economy	3100.00
0005435785365	13757	Economy	3100.00
0005435785250	13757	Economy	3100.00
0005435937422	13757	Economy	3100.00
0005435937428	13757	Economy	3100.00
0005435937426	13757	Economy	3100.00
0005435787356	13757	Economy	3100.00
0005435785355	13757	Economy	3100.00
0005435785274	13757	Economy	3100.00
0005435785432	13757	Economy	3100.00
0005435937418	13757	Economy	3100.00
0005435785220	13757	Economy	3100.00
0005435785436	13757	Economy	3100.00
0005435785435	13757	Economy	3100.00
0005435785467	13757	Economy	3100.00
0005435785344	13757	Economy	3100.00
0005435785350	13757	Economy	3100.00
0005435785273	13757	Economy	3100.00
0005435785270	13757	Economy	3100.00
0005435785379	13757	Economy	3100.00
0005435937423	13757	Economy	3100.00
0005435785367	13757	Economy	3100.00
0005432195713	13757	Economy	3100.00
0005435937427	13757	Economy	3100.00
0005435785193	13757	Economy	3100.00
0005435785360	13757	Economy	3100.00
0005435937420	13757	Economy	3100.00
0005435937424	13757	Economy	3100.00
0005435785269	13757	Economy	3100.00
0005435937419	13757	Economy	3100.00
0005432195712	13757	Economy	3100.00
0005435785380	13757	Economy	3100.00
0005435785354	13757	Economy	3100.00
0005435937425	13757	Economy	3100.00
0005435785366	13757	Economy	3100.00
0005435785318	13757	Economy	3100.00
0005435785361	13757	Economy	3100.00
0005435785288	13757	Economy	3100.00
0005435785323	13757	Economy	3100.00
0005435937421	13757	Economy	3100.00
0005435785284	13757	Economy	3100.00
0005435785645	27440	Economy	3400.00
0005435785630	27440	Economy	3400.00
0005435785629	27440	Economy	3400.00
0005432190660	27440	Economy	3100.00
0005435785639	27440	Economy	3100.00
0005435937379	27440	Economy	3100.00
0005435937388	27440	Economy	3100.00
0005435785646	27440	Economy	3100.00
0005435785628	27440	Economy	3100.00
0005435785638	27440	Economy	3100.00
0005435785635	27440	Economy	3100.00
0005432190661	27440	Economy	3100.00
0005435785621	27440	Economy	3100.00
0005435785616	27440	Economy	3100.00
0005432190658	27440	Economy	3100.00
0005435785627	27440	Economy	3100.00
0005435785623	27440	Economy	3100.00
0005435937378	27440	Economy	3100.00
0005435785632	27440	Economy	3100.00
0005435785648	27440	Economy	3100.00
0005435937387	27440	Economy	3100.00
0005435785631	27440	Economy	3100.00
0005435785634	27440	Economy	3100.00
0005435785615	27440	Economy	3100.00
0005435785640	27440	Economy	3100.00
0005435785636	27440	Economy	3100.00
0005435937368	27440	Economy	3100.00
0005435785619	27440	Economy	3100.00
0005435785620	27440	Economy	3100.00
0005435785625	27440	Economy	3100.00
0005435937375	27440	Economy	3100.00
0005435785618	27440	Economy	3100.00
0005432190659	27440	Economy	3100.00
0005435785642	27440	Economy	3100.00
0005435785624	27440	Economy	3100.00
0005435785617	27440	Economy	3100.00
0005435785633	27440	Economy	3100.00
0005435785614	27440	Economy	3100.00
0005435787371	27440	Economy	3100.00
0005435785644	27440	Economy	3100.00
0005435785641	27440	Economy	3100.00
0005435785637	27440	Economy	3100.00
0005435785643	27440	Economy	3100.00
0005435785626	27440	Economy	3100.00
0005435785647	27440	Economy	3100.00
0005435785622	27440	Economy	3100.00
0005434407707	20296	Business	12000.00
0005434407774	20296	Business	12000.00
0005434407593	20296	Business	12000.00
0005434407708	20296	Business	12000.00
0005434407765	20296	Business	12000.00
0005434407913	20296	Business	12000.00
0005435311166	20296	Business	12000.00
0005435311168	20296	Business	12000.00
0005434407588	20296	Business	12000.00
0005434407861	20296	Business	12000.00
0005434408062	20296	Economy	4000.00
0005435311177	20296	Economy	4000.00
0005434407806	20296	Economy	4000.00
0005434407656	20296	Economy	4000.00
0005434407850	20296	Economy	4000.00
0005434407816	20296	Economy	4000.00
0005435311170	20296	Economy	4000.00
0005434407813	20296	Economy	4000.00
0005434407943	20296	Economy	4400.00
0005434407804	20296	Economy	4400.00
0005434407800	20296	Economy	4000.00
0005434407646	20296	Economy	4000.00
0005434407915	20296	Economy	4000.00
0005434407634	20296	Economy	4000.00
0005435311172	20296	Economy	4000.00
0005434407626	20296	Economy	4000.00
0005434407779	20296	Economy	4000.00
0005434407736	20296	Economy	4000.00
0005435311169	20296	Economy	4000.00
0005434407926	20296	Economy	4000.00
0005434407525	20296	Economy	4000.00
0005434407688	20296	Economy	4000.00
0005434407881	20296	Economy	4000.00
0005434407963	20296	Economy	4000.00
0005435311173	20296	Economy	4000.00
0005434407942	20296	Economy	4000.00
0005434408035	20296	Economy	4000.00
0005434407585	20296	Economy	4000.00
0005432058420	20296	Economy	4000.00
0005434407787	20296	Economy	4000.00
0005432058418	20296	Economy	4000.00
0005434407745	20296	Economy	4000.00
0005434407635	20296	Economy	4000.00
0005434407766	20296	Economy	4000.00
0005434407658	20296	Economy	4000.00
0005434407801	20296	Economy	4000.00
0005434407709	20296	Economy	4000.00
0005434407805	20296	Economy	4000.00
0005435311176	20296	Economy	4000.00
0005434407892	20296	Economy	4000.00
0005434407782	20296	Economy	4000.00
0005434407929	20296	Economy	4000.00
0005434407885	20296	Economy	4000.00
0005434407818	20296	Economy	4000.00
0005435311167	20296	Economy	4000.00
0005435311171	20296	Economy	4000.00
0005434407647	20296	Economy	4000.00
0005435311165	20296	Economy	4000.00
0005434407835	20296	Economy	4000.00
0005434407819	20296	Economy	4000.00
0005434407700	20296	Economy	4000.00
0005432058419	20296	Economy	4000.00
0005434407884	20296	Economy	4000.00
0005434407687	20296	Economy	4000.00
0005434407914	20296	Economy	4000.00
0005434407825	20296	Economy	4000.00
0005435311164	20296	Economy	4000.00
0005434407799	20296	Economy	4000.00
0005434408087	20296	Economy	4000.00
0005434407841	20296	Economy	4000.00
0005435311163	20296	Economy	4000.00
0005434407587	20296	Economy	4000.00
0005434407775	20296	Economy	4000.00
0005435311174	20296	Economy	4000.00
0005434407880	20296	Economy	4000.00
0005434407657	20296	Economy	4000.00
0005434407661	20296	Economy	4000.00
0005435311175	20296	Economy	4000.00
0005434407817	20296	Economy	4000.00
0005434408363	27018	Business	12000.00
0005434408365	27018	Business	12000.00
0005434408350	27018	Business	12000.00
0005432154002	27018	Business	12000.00
0005434408362	27018	Business	12000.00
0005432154004	27018	Business	12000.00
0005434408325	27018	Business	12000.00
0005434408331	27018	Business	12000.00
0005434408346	27018	Business	12000.00
0005434408322	27018	Business	12000.00
0005434408352	27018	Economy	4000.00
0005434408326	27018	Economy	4000.00
0005435311054	27018	Economy	4000.00
0005434408380	27018	Economy	4000.00
0005434408355	27018	Economy	4000.00
0005435311083	27018	Economy	4000.00
0005434408353	27018	Economy	4000.00
0005434408369	27018	Economy	4400.00
0005434408338	27018	Economy	4400.00
0005434408354	27018	Economy	4400.00
0005434408349	27018	Economy	4400.00
0005432154000	27018	Economy	4000.00
0005434408370	27018	Economy	4000.00
0005434408357	27018	Economy	4000.00
0005434408347	27018	Economy	4000.00
0005434408376	27018	Economy	4000.00
0005434408318	27018	Economy	4000.00
0005434408324	27018	Economy	4000.00
0005434408321	27018	Economy	4000.00
0005434408335	27018	Economy	4000.00
0005434408330	27018	Economy	4000.00
0005434408348	27018	Economy	4000.00
0005432154007	27018	Economy	4000.00
0005435311038	27018	Economy	4000.00
0005434408320	27018	Economy	4000.00
0005434408342	27018	Economy	4000.00
0005434408340	27018	Economy	4000.00
0005434408334	27018	Economy	4000.00
0005434408367	27018	Economy	4000.00
0005434408336	27018	Economy	4000.00
0005434408319	27018	Economy	4000.00
0005432154001	27018	Economy	4000.00
0005434408341	27018	Economy	4000.00
0005434408368	27018	Economy	4000.00
0005435311030	27018	Economy	4000.00
0005434408359	27018	Economy	4000.00
0005435311079	27018	Economy	4000.00
0005434408339	27018	Economy	4000.00
0005434408364	27018	Economy	4000.00
0005432154006	27018	Economy	4000.00
0005434408343	27018	Economy	4000.00
0005435311037	27018	Economy	4000.00
0005434408328	27018	Economy	4000.00
0005434408360	27018	Economy	4000.00
0005435311078	27018	Economy	4000.00
0005434408358	27018	Economy	4000.00
0005434408372	27018	Economy	4000.00
0005435311031	27018	Economy	4000.00
0005434408351	27018	Economy	4000.00
0005434408381	27018	Economy	4000.00
0005434408345	27018	Economy	4000.00
0005434408344	27018	Economy	4000.00
0005434408377	27018	Economy	4000.00
0005434408374	27018	Economy	4000.00
0005434408327	27018	Economy	4000.00
0005434408379	27018	Economy	4000.00
0005434408332	27018	Economy	4000.00
0005434408366	27018	Economy	4000.00
0005434408337	27018	Economy	4000.00
0005434408371	27018	Economy	4000.00
0005434408373	27018	Economy	4000.00
0005435311060	27018	Economy	4000.00
0005432154005	27018	Economy	4000.00
0005432154008	27018	Economy	4000.00
0005434408375	27018	Economy	4000.00
0005434408329	27018	Economy	4000.00
0005434408356	27018	Economy	4000.00
0005434408361	27018	Economy	4000.00
0005435311080	27018	Economy	4000.00
0005432154003	27018	Economy	4000.00
0005434408378	27018	Economy	4000.00
0005434408323	27018	Economy	4000.00
0005434408333	27018	Economy	4000.00
0005434319534	5724	Business	43300.00
0005433124015	5724	Business	43300.00
0005433123925	5724	Business	43300.00
0005433123957	5724	Business	43300.00
0005434311238	5724	Economy	14400.00
0005433123930	5724	Economy	14400.00
0005432109729	5724	Economy	14400.00
0005433123899	5724	Economy	14400.00
0005434319531	5724	Economy	15900.00
0005434319530	5724	Economy	15900.00
0005434319539	5724	Economy	14400.00
0005433123926	5724	Economy	14400.00
0005432109730	5724	Economy	14400.00
0005433123808	5724	Economy	14400.00
0005433123853	5724	Economy	14400.00
0005433123962	5724	Economy	14400.00
0005434319541	5724	Economy	14400.00
0005433123807	5724	Economy	14400.00
0005433123897	5724	Economy	14400.00
0005434319538	5724	Economy	14400.00
0005432109728	5724	Economy	14400.00
0005434319533	5724	Economy	14400.00
0005433124016	5724	Economy	14400.00
0005434319529	5724	Economy	14400.00
0005433123997	5724	Economy	14400.00
0005433123876	5724	Economy	14400.00
0005434319535	5724	Economy	14400.00
0005434319532	5724	Economy	14400.00
0005433123895	5724	Economy	14400.00
0005434319540	5724	Economy	14400.00
0005434311239	5724	Economy	14400.00
0005433123956	5724	Economy	14400.00
0005434319536	5724	Economy	14400.00
0005433123963	5724	Economy	14400.00
0005434319537	5724	Economy	14400.00
0005433124133	15677	Business	43300.00
0005433124142	15677	Business	43300.00
0005434319383	15677	Business	43300.00
0005433124120	15677	Business	43300.00
0005434319392	15677	Business	43300.00
0005433124132	15677	Business	43300.00
0005434319394	15677	Business	43300.00
0005434319395	15677	Business	43300.00
0005433124139	15677	Economy	14400.00
0005433124134	15677	Economy	14400.00
0005434319343	15677	Economy	14400.00
0005433124125	15677	Economy	15900.00
0005434319355	15677	Economy	15900.00
0005433124135	15677	Economy	14400.00
0005433124143	15677	Economy	14400.00
0005433124123	15677	Economy	14400.00
0005434319388	15677	Economy	14400.00
0005433124136	15677	Economy	14400.00
0005433124127	15677	Economy	14400.00
0005433124126	15677	Economy	14400.00
0005434319385	15677	Economy	14400.00
0005434319407	15677	Economy	14400.00
0005433124128	15677	Economy	14400.00
0005433124121	15677	Economy	14400.00
0005433124124	15677	Economy	14400.00
0005434319404	15677	Economy	14400.00
0005434319378	15677	Economy	14400.00
0005434319398	15677	Economy	14400.00
0005434312318	15677	Economy	14400.00
0005433124130	15677	Economy	14400.00
0005434319389	15677	Economy	14400.00
0005434319386	15677	Economy	14400.00
0005433124140	15677	Economy	14400.00
0005434312314	15677	Economy	14400.00
0005433124137	15677	Economy	14400.00
0005434319387	15677	Economy	14400.00
0005433124129	15677	Economy	14400.00
0005434319352	15677	Economy	14400.00
0005434311217	15677	Economy	14400.00
0005434319399	15677	Economy	14400.00
0005434319356	15677	Economy	14400.00
0005434319353	15677	Economy	14400.00
0005433124141	15677	Economy	14400.00
0005433124131	15677	Economy	14400.00
0005433124138	15677	Economy	14400.00
0005434311222	15677	Economy	14400.00
0005434319354	15677	Economy	14400.00
0005433124122	15677	Economy	14400.00
0005434319406	15677	Economy	14400.00
0005434189186	8966	Economy	24900.00
0005434484410	8966	Economy	24900.00
0005434484409	8966	Economy	24900.00
0005434484411	8966	Economy	24900.00
0005434189189	8966	Economy	24900.00
0005434189203	8966	Economy	24900.00
0005434189185	8966	Economy	24900.00
0005434484407	8966	Economy	24900.00
0005434484406	8966	Economy	24900.00
0005434189187	8966	Economy	24900.00
0005434484408	8966	Economy	24900.00
0005434189165	8966	Economy	24900.00
0005434484412	8966	Economy	24900.00
0005434189192	8966	Economy	24900.00
0005434484332	16667	Economy	27400.00
0005434189232	16667	Economy	27400.00
0005434484349	16667	Economy	27400.00
0005434484363	16667	Economy	27400.00
0005434189233	16667	Economy	24900.00
0005434484382	16667	Economy	24900.00
0005434189235	16667	Economy	24900.00
0005434189231	16667	Economy	24900.00
0005434189230	16667	Economy	24900.00
0005434484339	16667	Economy	24900.00
0005434484350	16667	Economy	24900.00
0005434189234	16667	Economy	24900.00
0005433124131	7673	Business	11100.00
0005433124129	7673	Economy	3700.00
0005433124121	7673	Economy	3700.00
0005433124127	7673	Economy	3700.00
0005433124125	7673	Economy	4100.00
0005433124137	7673	Economy	4100.00
0005433124123	7673	Economy	4100.00
0005433124143	7673	Economy	3700.00
0005433124126	7673	Economy	3700.00
0005433124135	7673	Economy	3700.00
0005433124120	7673	Economy	3700.00
0005433124140	7673	Economy	3700.00
0005433124136	7673	Economy	3700.00
0005433124128	7673	Economy	3700.00
0005433124142	7673	Economy	3700.00
0005433124124	7673	Economy	3700.00
0005433124122	7673	Economy	3700.00
0005433124139	7673	Economy	3700.00
0005433124130	7673	Economy	3700.00
0005433124132	7673	Economy	3700.00
0005433124134	7673	Economy	3700.00
0005433124141	7673	Economy	3700.00
0005433124138	7673	Economy	3700.00
0005433124133	7673	Economy	3700.00
0005433450170	7672	Business	11100.00
0005432693352	7672	Business	11100.00
0005432721145	7672	Business	11100.00
0005432693366	7672	Business	11100.00
0005432693373	7672	Business	11100.00
0005433450165	7672	Business	11100.00
0005432693374	7672	Business	11100.00
0005432693357	7672	Business	11100.00
0005433450178	7672	Business	11100.00
0005432721144	7672	Business	11100.00
0005432721163	7672	Economy	3700.00
0005432693356	7672	Economy	3700.00
0005432071601	7672	Economy	3700.00
0005432693363	7672	Economy	3700.00
0005433450182	7672	Economy	3700.00
0005432693376	7672	Economy	3700.00
0005433450163	7672	Economy	3700.00
0005432721160	7672	Economy	3700.00
0005433450171	7672	Economy	4100.00
0005432721162	7672	Economy	4100.00
0005432693377	7672	Economy	4100.00
0005432721154	7672	Economy	4100.00
0005432693371	7672	Economy	4100.00
0005433450180	7672	Economy	3700.00
0005432693360	7672	Economy	3700.00
0005433450174	7672	Economy	3700.00
0005432693362	7672	Economy	3700.00
0005432721148	7672	Economy	3700.00
0005433450169	7672	Economy	3700.00
0005432721156	7672	Economy	3700.00
0005432721157	7672	Economy	3700.00
0005432721150	7672	Economy	3700.00
0005433450166	7672	Economy	3700.00
0005432693368	7672	Economy	3700.00
0005433450184	7672	Economy	3700.00
0005433450164	7672	Economy	3700.00
0005433450168	7672	Economy	3700.00
0005432693365	7672	Economy	3700.00
0005432693353	7672	Economy	3700.00
0005432693364	7672	Economy	3700.00
0005432693355	7672	Economy	3700.00
0005432693369	7672	Economy	3700.00
0005432693361	7672	Economy	3700.00
0005433450183	7672	Economy	3700.00
0005432721152	7672	Economy	3700.00
0005432693370	7672	Economy	3700.00
0005432693358	7672	Economy	3700.00
0005432721161	7672	Economy	3700.00
0005432721168	7672	Economy	3700.00
0005432721158	7672	Economy	3700.00
0005433450181	7672	Economy	3700.00
0005433450172	7672	Economy	3700.00
0005432693359	7672	Economy	3700.00
0005433450179	7672	Economy	3700.00
0005432721149	7672	Economy	3700.00
0005432721167	7672	Economy	3700.00
0005432721147	7672	Economy	3700.00
0005432721153	7672	Economy	3700.00
0005432721155	7672	Economy	3700.00
0005433450175	7672	Economy	3700.00
0005432693354	7672	Economy	3700.00
0005433450176	7672	Economy	3700.00
0005432721166	7672	Economy	3700.00
0005432693367	7672	Economy	3700.00
0005432721146	7672	Economy	3700.00
0005432693372	7672	Economy	3700.00
0005432721159	7672	Economy	3700.00
0005433450167	7672	Economy	3700.00
0005433450177	7672	Economy	3700.00
0005432693348	7672	Economy	3700.00
0005433450173	7672	Economy	3700.00
0005432721165	7672	Economy	3700.00
0005432721143	7672	Economy	3700.00
0005432721151	7672	Economy	3700.00
0005432693351	7672	Economy	3700.00
0005432693349	7672	Economy	3700.00
0005432071602	7672	Economy	3700.00
0005432693350	7672	Economy	3700.00
0005432071603	7672	Economy	3700.00
0005432693378	7672	Economy	3700.00
0005432721169	7672	Economy	3700.00
0005432693375	7672	Economy	3700.00
0005432721164	7672	Economy	3700.00
0005432693158	30317	Business	11100.00
0005432693094	30317	Business	11100.00
0005433449967	30317	Business	11100.00
0005432692912	30317	Business	11100.00
0005433450040	30317	Business	11100.00
0005433449923	30317	Business	11100.00
0005432693100	30317	Economy	3700.00
0005433449948	30317	Economy	3700.00
0005433449988	30317	Economy	3700.00
0005432692911	30317	Economy	3700.00
0005432693048	30317	Economy	3700.00
0005432693157	30317	Economy	3700.00
0005432693029	30317	Economy	4100.00
0005433449912	30317	Economy	4100.00
0005433450061	30317	Economy	4100.00
0005432692973	30317	Economy	3700.00
0005433449953	30317	Economy	3700.00
0005432693020	30317	Economy	3700.00
0005433449946	30317	Economy	3700.00
0005433450062	30317	Economy	3700.00
0005432693103	30317	Economy	3700.00
0005433450065	30317	Economy	3700.00
0005432693122	30317	Economy	3700.00
0005433449945	30317	Economy	3700.00
0005433449977	30317	Economy	3700.00
0005433449995	30317	Economy	3700.00
0005432692892	30317	Economy	3700.00
0005432693045	30317	Economy	3700.00
0005432693070	30317	Economy	3700.00
0005433449994	30317	Economy	3700.00
0005432692974	30317	Economy	3700.00
0005433450052	30317	Economy	3700.00
0005433449999	30317	Economy	3700.00
0005432693150	30317	Economy	3700.00
0005433450118	30317	Economy	3700.00
0005433449959	30317	Economy	3700.00
0005432693121	30317	Economy	3700.00
0005432693106	30317	Economy	3700.00
0005432693079	30317	Economy	3700.00
0005433449978	30317	Economy	3700.00
0005432693044	30317	Economy	3700.00
0005433449943	30317	Economy	3700.00
0005432693104	30317	Economy	3700.00
0005432693012	30317	Economy	3700.00
0005432693095	30317	Economy	3700.00
0005432693101	30317	Economy	3700.00
0005432693043	30317	Economy	3700.00
0005432692891	30317	Economy	3700.00
0005433449911	30317	Economy	3700.00
0005433449947	30317	Economy	3700.00
0005433450023	30317	Economy	3700.00
0005433449944	30317	Economy	3700.00
0005433450117	30317	Economy	3700.00
0005433450063	30317	Economy	3700.00
0005432693151	30317	Economy	3700.00
0005432693028	30317	Economy	3700.00
0005432693105	30317	Economy	3700.00
0005432692995	30317	Economy	3700.00
0005432693156	30317	Economy	3700.00
0005433449924	30317	Economy	3700.00
0005432693011	30317	Economy	3700.00
0005433449966	30317	Economy	3700.00
0005433450043	30317	Economy	3700.00
0005432693168	30317	Economy	3700.00
0005432720998	30318	Business	11100.00
0005433123997	30318	Business	11100.00
0005432720976	30318	Business	11100.00
0005432720720	30318	Business	11100.00
0005432720966	30318	Business	11100.00
0005432720918	30318	Business	11100.00
0005432720936	30318	Economy	3700.00
0005433722283	30318	Economy	3700.00
0005432721012	30318	Economy	3700.00
0005432720977	30318	Economy	3700.00
0005433123956	30318	Economy	3700.00
0005432721027	30318	Economy	4100.00
0005432720937	30318	Economy	3700.00
0005432720917	30318	Economy	3700.00
0005433123926	30318	Economy	3700.00
0005432720957	30318	Economy	3700.00
0005433123899	30318	Economy	3700.00
0005433123930	30318	Economy	3700.00
0005433123807	30318	Economy	3700.00
0005432720859	30318	Economy	3700.00
0005432721069	30318	Economy	3700.00
0005432720965	30318	Economy	3700.00
0005433124015	30318	Economy	3700.00
0005433123808	30318	Economy	3700.00
0005433123963	30318	Economy	3700.00
0005432720933	30318	Economy	3700.00
0005432721013	30318	Economy	3700.00
0005433124016	30318	Economy	3700.00
0005432720833	30318	Economy	3700.00
0005432720992	30318	Economy	3700.00
0005432720870	30318	Economy	3700.00
0005433123895	30318	Economy	3700.00
0005432721087	30318	Economy	3700.00
0005432720892	30318	Economy	3700.00
0005433123897	30318	Economy	3700.00
0005433123957	30318	Economy	3700.00
0005432720938	30318	Economy	3700.00
0005433123853	30318	Economy	3700.00
0005433722282	30318	Economy	3700.00
0005432721038	30318	Economy	3700.00
0005432720956	30318	Economy	3700.00
0005432721022	30318	Economy	3700.00
0005433123962	30318	Economy	3700.00
0005432720915	30318	Economy	3700.00
0005432720887	30318	Economy	3700.00
0005433123925	30318	Economy	3700.00
0005432720893	30318	Economy	3700.00
0005433123876	30318	Economy	3700.00
0005432720952	30318	Economy	3700.00
0005432721023	30318	Economy	3700.00
0005432720991	30318	Economy	3700.00
0005433525139	1400	Business	70400.00
0005434514993	1400	Business	70400.00
0005434586848	1400	Business	70400.00
0005434586857	1400	Business	70400.00
0005433193065	1400	Business	70400.00
0005432968849	1400	Business	70400.00
0005434586846	1400	Business	70400.00
0005434513604	1400	Economy	23500.00
0005432271031	1400	Economy	23500.00
0005433724846	1400	Economy	23500.00
0005433193035	1400	Economy	23500.00
0005432968840	1400	Economy	23500.00
0005434586849	1400	Economy	23500.00
0005434513603	1400	Economy	23500.00
0005432927996	1400	Economy	23500.00
0005434586859	1400	Economy	25800.00
0005433525145	1400	Economy	25800.00
0005433724850	1400	Economy	25800.00
0005433193094	1400	Economy	23500.00
0005434586863	1400	Economy	23500.00
0005432968841	1400	Economy	23500.00
0005433193005	1400	Economy	23500.00
0005432927995	1400	Economy	23500.00
0005433193066	1400	Economy	23500.00
0005433525136	1400	Economy	23500.00
0005433193090	1400	Economy	23500.00
0005434586858	1400	Economy	23500.00
0005434586850	1400	Economy	23500.00
0005433193089	1400	Economy	23500.00
0005433193076	1400	Economy	23500.00
0005434586854	1400	Economy	23500.00
0005433525140	1400	Economy	23500.00
0005434586862	1400	Economy	23500.00
0005434513605	1400	Economy	23500.00
0005434586855	1400	Economy	23500.00
0005434514991	1400	Economy	23500.00
0005433193126	1400	Economy	23500.00
0005434586853	1400	Economy	23500.00
0005434586852	1400	Economy	23500.00
0005433724848	1400	Economy	23500.00
0005433193049	1400	Economy	23500.00
0005433525144	1400	Economy	23500.00
0005434514992	1400	Economy	23500.00
0005434586860	1400	Economy	23500.00
0005432271032	1400	Economy	23500.00
0005433193074	1400	Economy	23500.00
0005432968850	1400	Economy	23500.00
0005433193088	1400	Economy	23500.00
0005433724849	1400	Economy	23500.00
0005433193068	1400	Economy	23500.00
0005433193067	1400	Economy	23500.00
0005433525137	1400	Economy	23500.00
0005432928004	1400	Economy	23500.00
0005434586847	1400	Economy	23500.00
0005433525141	1400	Economy	23500.00
0005433193004	1400	Economy	23500.00
0005433724847	1400	Economy	23500.00
0005433193026	1400	Economy	23500.00
0005434586865	1400	Economy	23500.00
0005433525146	1400	Economy	23500.00
0005433193036	1400	Economy	23500.00
0005434586844	1400	Economy	23500.00
0005434586861	1400	Economy	23500.00
0005433525143	1400	Economy	23500.00
0005433525142	1400	Economy	23500.00
0005434586845	1400	Economy	23500.00
0005434586843	1400	Economy	23500.00
0005434586864	1400	Economy	23500.00
0005433525138	1400	Economy	23500.00
0005434586842	1400	Economy	23500.00
0005434586851	1400	Economy	23500.00
0005434586856	1400	Economy	23500.00
0005434586866	1400	Economy	23500.00
0005433525025	18540	Business	70400.00
0005433525037	18540	Business	70400.00
0005434586694	18540	Business	70400.00
0005434586659	18540	Business	70400.00
0005433193178	18540	Business	70400.00
0005433525026	18540	Business	70400.00
0005434586580	18540	Business	70400.00
0005433724783	18540	Business	70400.00
0005432968862	18540	Business	70400.00
0005433193177	18540	Business	70400.00
0005433525038	18540	Economy	23500.00
0005433193169	18540	Economy	23500.00
0005433525005	18540	Economy	23500.00
0005433525034	18540	Economy	23500.00
0005432928032	18540	Economy	23500.00
0005433525041	18540	Economy	23500.00
0005433724782	18540	Economy	23500.00
0005433525029	18540	Economy	23500.00
0005433525027	18540	Economy	23500.00
0005434586589	18540	Economy	25800.00
0005433525061	18540	Economy	25800.00
0005434586622	18540	Economy	25800.00
0005434586660	18540	Economy	25800.00
0005433193164	18540	Economy	25800.00
0005434586693	18540	Economy	23500.00
0005433193165	18540	Economy	23500.00
0005433193176	18540	Economy	23500.00
0005433525036	18540	Economy	23500.00
0005433724802	18540	Economy	23500.00
0005432928033	18540	Economy	23500.00
0005433193175	18540	Economy	23500.00
0005433724809	18540	Economy	23500.00
0005434586596	18540	Economy	23500.00
0005434586752	18540	Economy	23500.00
0005433193174	18540	Economy	23500.00
0005434586630	18540	Economy	23500.00
0005434586645	18540	Economy	23500.00
0005433193166	18540	Economy	23500.00
0005433525048	18540	Economy	23500.00
0005433193172	18540	Economy	23500.00
0005434586647	18540	Economy	23500.00
0005433525047	18540	Economy	23500.00
0005434514970	18540	Economy	23500.00
0005433525030	18540	Economy	23500.00
0005434586526	18540	Economy	23500.00
0005432968860	18540	Economy	23500.00
0005433525056	18540	Economy	23500.00
0005433193171	18540	Economy	23500.00
0005433525004	18540	Economy	23500.00
0005433724784	18540	Economy	23500.00
0005434586621	18540	Economy	23500.00
0005433724785	18540	Economy	23500.00
0005434586654	18540	Economy	23500.00
0005433724808	18540	Economy	23500.00
0005434514965	18540	Economy	23500.00
0005433193173	18540	Economy	23500.00
0005432968863	18540	Economy	23500.00
0005433525006	18540	Economy	23500.00
0005432928029	18540	Economy	23500.00
0005432968861	18540	Economy	23500.00
0005433525028	18540	Economy	23500.00
0005434586648	18540	Economy	23500.00
0005433193170	18540	Economy	23500.00
0005434514962	18540	Economy	23500.00
0005432928031	18540	Economy	23500.00
0005433193168	18540	Economy	23500.00
0005432928030	18540	Economy	23500.00
0005434586646	18540	Economy	23500.00
0005434586584	18540	Economy	23500.00
0005434586595	18540	Economy	23500.00
0005434514969	18540	Economy	23500.00
0005433525003	18540	Economy	23500.00
0005434586746	18540	Economy	23500.00
0005433193167	18540	Economy	23500.00
0005434586528	18540	Economy	23500.00
0005435302194	11435	Economy	4300.00
0005434344520	11435	Economy	4300.00
0005434344527	11435	Economy	4300.00
0005434142647	11435	Economy	4300.00
0005434344505	11435	Economy	4000.00
0005434344503	11435	Economy	4000.00
0005434344499	11435	Economy	4000.00
0005434344514	11435	Economy	4000.00
0005434344516	11435	Economy	4000.00
0005434142649	11435	Economy	4000.00
0005434344528	11435	Economy	4000.00
0005435302214	11435	Economy	4000.00
0005434344517	11435	Economy	4000.00
0005435302196	11435	Economy	4000.00
0005435302173	11435	Economy	4000.00
0005435302195	11435	Economy	4000.00
0005434344511	11435	Economy	4000.00
0005434344500	11435	Economy	4000.00
0005434344524	11435	Economy	4000.00
0005434344522	11435	Economy	4000.00
0005434344510	11435	Economy	4000.00
0005434344531	11435	Economy	4000.00
0005435302215	11435	Economy	4000.00
0005434142648	11435	Economy	4000.00
0005434344521	11435	Economy	4000.00
0005434344526	11435	Economy	4000.00
0005434344506	11435	Economy	4000.00
0005434142646	11435	Economy	4000.00
0005434344502	11435	Economy	4000.00
0005434344508	11435	Economy	4000.00
0005434344509	11435	Economy	4000.00
0005435302210	11435	Economy	4000.00
0005434344525	11435	Economy	4000.00
0005434344504	11435	Economy	4000.00
0005434344512	11435	Economy	4000.00
0005434344519	11435	Economy	4000.00
0005434344529	11435	Economy	4000.00
0005435305013	11435	Economy	4000.00
0005434344532	11435	Economy	4000.00
0005434344507	11435	Economy	4000.00
0005435302220	11435	Economy	4000.00
0005434344513	11435	Economy	4000.00
0005434344523	11435	Economy	4000.00
0005434344501	11435	Economy	4000.00
0005434344530	11435	Economy	4000.00
0005434344515	11435	Economy	4000.00
0005434344518	11435	Economy	4000.00
0005435305034	29806	Economy	4300.00
0005434344199	29806	Economy	4300.00
0005434344152	29806	Economy	4300.00
0005434142612	29806	Economy	4000.00
0005434344162	29806	Economy	4000.00
0005434344261	29806	Economy	4000.00
0005434344154	29806	Economy	4000.00
0005435305032	29806	Economy	4000.00
0005434344236	29806	Economy	4000.00
0005434344217	29806	Economy	4000.00
0005435304199	29806	Economy	4000.00
0005434344405	29806	Economy	4000.00
0005435304200	29806	Economy	4000.00
0005435305033	29806	Economy	4000.00
0005434344373	29806	Economy	4000.00
0005434344222	29806	Economy	4000.00
0005434344265	29806	Economy	4000.00
0005434344225	29806	Economy	4000.00
0005435304201	29806	Economy	4000.00
0005434344244	29806	Economy	4000.00
0005434344311	29806	Economy	4000.00
0005434344273	29806	Economy	4000.00
0005434344312	29806	Economy	4000.00
0005434142595	29806	Economy	4000.00
0005434344190	29806	Economy	4000.00
0005435304198	29806	Economy	4000.00
0005434344198	29806	Economy	4000.00
0005434142599	29806	Economy	4000.00
0005434344469	29806	Economy	4000.00
0005434344243	29806	Economy	4000.00
0005434344242	29806	Economy	4000.00
0005434344138	29806	Economy	4000.00
0005434344372	29806	Economy	4000.00
0005434344153	29806	Economy	4000.00
0005434344030	29806	Economy	4000.00
0005434344183	29806	Economy	4000.00
0005434344221	29806	Economy	4000.00
0005435304202	29806	Economy	4000.00
0005434344182	29806	Economy	4000.00
0005434344285	29806	Economy	4000.00
0005434344280	29806	Economy	4000.00
0005433415725	1258	Business	199800.00
0005435824866	1258	Business	199800.00
0005433415683	1258	Business	199800.00
0005435824876	1258	Business	199800.00
0005435824874	1258	Business	199800.00
0005432284587	1258	Business	199800.00
0005435824879	1258	Business	199800.00
0005435824870	1258	Business	199800.00
0005435824892	1258	Business	199800.00
0005435824880	1258	Economy	66600.00
0005432284585	1258	Economy	66600.00
0005435824875	1258	Economy	73200.00
0005433415698	1258	Economy	73200.00
0005433415738	1258	Economy	66600.00
0005433415727	1258	Economy	66600.00
0005433415665	1258	Economy	66600.00
0005433415643	1258	Economy	66600.00
0005433415596	1258	Economy	66600.00
0005435824872	1258	Economy	66600.00
0005435824889	1258	Economy	66600.00
0005435824890	1258	Economy	66600.00
0005433415597	1258	Economy	66600.00
0005433415709	1258	Economy	66600.00
0005435824878	1258	Economy	66600.00
0005432284586	1258	Economy	66600.00
0005435824868	1258	Economy	66600.00
0005435824888	1258	Economy	66600.00
0005435824867	1258	Economy	66600.00
0005433415666	1258	Economy	66600.00
0005433415678	1258	Economy	66600.00
0005433415674	1258	Economy	66600.00
0005435824881	1258	Economy	66600.00
0005435824886	1258	Economy	66600.00
0005433415732	1258	Economy	66600.00
0005435824885	1258	Economy	66600.00
0005435824887	1258	Economy	66600.00
0005433415642	1258	Economy	66600.00
0005435824871	1258	Economy	66600.00
0005435824873	1258	Economy	66600.00
0005433415680	1258	Economy	66600.00
0005435824869	1258	Economy	66600.00
0005433415679	1258	Economy	66600.00
0005435824877	1258	Economy	66600.00
0005435824882	1258	Economy	66600.00
0005435824883	1258	Economy	66600.00
0005435824865	1258	Economy	66600.00
0005435824884	1258	Economy	66600.00
0005435824891	1258	Economy	66600.00
0005433415728	1258	Economy	66600.00
0005433415691	1258	Economy	66600.00
0005433415612	1258	Economy	66600.00
0005433415616	1258	Economy	66600.00
0005435824648	18027	Business	199800.00
0005433415802	18027	Business	199800.00
0005435824667	18027	Business	199800.00
0005435824724	18027	Business	199800.00
0005435824725	18027	Business	199800.00
0005435824603	18027	Business	199800.00
0005435824612	18027	Business	199800.00
0005433415817	18027	Business	199800.00
0005435824647	18027	Economy	66600.00
0005433415814	18027	Economy	66600.00
0005433415805	18027	Economy	66600.00
0005435824568	18027	Economy	66600.00
0005433415806	18027	Economy	66600.00
0005435824723	18027	Economy	66600.00
0005435824669	18027	Economy	66600.00
0005435824601	18027	Economy	73200.00
0005435824684	18027	Economy	73200.00
0005435824558	18027	Economy	73200.00
0005435824578	18027	Economy	66600.00
0005435824670	18027	Economy	66600.00
0005435824674	18027	Economy	66600.00
0005433415811	18027	Economy	66600.00
0005435824611	18027	Economy	66600.00
0005435824553	18027	Economy	66600.00
0005435824567	18027	Economy	66600.00
0005433415804	18027	Economy	66600.00
0005435824666	18027	Economy	66600.00
0005435824660	18027	Economy	66600.00
0005435824653	18027	Economy	66600.00
0005435824579	18027	Economy	66600.00
0005433415812	18027	Economy	66600.00
0005435824548	18027	Economy	66600.00
0005433415808	18027	Economy	66600.00
0005433415807	18027	Economy	66600.00
0005433415815	18027	Economy	66600.00
0005433415816	18027	Economy	66600.00
0005435824637	18027	Economy	66600.00
0005435824540	18027	Economy	66600.00
0005435824649	18027	Economy	66600.00
0005435824624	18027	Economy	66600.00
0005435824600	18027	Economy	66600.00
0005435824604	18027	Economy	66600.00
0005435824596	18027	Economy	66600.00
0005435824668	18027	Economy	66600.00
0005433415803	18027	Economy	66600.00
0005433415813	18027	Economy	66600.00
0005435824625	18027	Economy	66600.00
0005433415809	18027	Economy	66600.00
0005435824726	18027	Economy	66600.00
0005435824806	18027	Economy	66600.00
0005433415810	18027	Economy	66600.00
0005435824580	18027	Economy	66600.00
0005434460517	12574	Economy	13500.00
0005434461663	12574	Economy	13500.00
0005434461658	12574	Economy	13500.00
0005434461660	12574	Economy	13500.00
0005434460522	12574	Economy	13500.00
0005434460520	12574	Economy	13500.00
0005434460519	12574	Economy	13500.00
0005434460523	12574	Economy	13500.00
0005434461662	12574	Economy	13500.00
0005434461659	12574	Economy	13500.00
0005434460521	12574	Economy	13500.00
0005434461661	12574	Economy	13500.00
0005434461657	12574	Economy	13500.00
0005434460518	12574	Economy	13500.00
0005434461664	12574	Economy	13500.00
0005434461665	12574	Economy	13500.00
0005434460524	12574	Economy	13500.00
0005432784304	5649	Business	27800.00
0005435242859	5649	Business	27800.00
0005435476745	5649	Business	27800.00
0005435242847	5649	Business	27800.00
0005435476746	5649	Business	27800.00
0005432784285	5649	Business	27800.00
0005432784276	5649	Business	27800.00
0005435242956	5649	Business	27800.00
0005435242939	5649	Business	27800.00
0005435242921	5649	Business	27800.00
0005435242946	5649	Business	27800.00
0005432784320	5649	Economy	9300.00
0005432784303	5649	Economy	9300.00
0005432784302	5649	Economy	9300.00
0005435476760	5649	Economy	9300.00
0005432784293	5649	Economy	9300.00
0005432784295	5649	Economy	9300.00
0005435476753	5649	Economy	9300.00
0005432144019	5649	Economy	9300.00
0005432784321	5649	Economy	10200.00
0005432784272	5649	Economy	10200.00
0005435242868	5649	Economy	10200.00
0005432784309	5649	Economy	10200.00
0005432784288	5649	Economy	10200.00
0005435476762	5649	Economy	9300.00
0005432784315	5649	Economy	9300.00
0005432784271	5649	Economy	9300.00
0005435476740	5649	Economy	9300.00
0005435476758	5649	Economy	9300.00
0005432784313	5649	Economy	9300.00
0005435476748	5649	Economy	9300.00
0005432784312	5649	Economy	9300.00
0005432784292	5649	Economy	9300.00
0005432784297	5649	Economy	9300.00
0005435242864	5649	Economy	9300.00
0005432784286	5649	Economy	9300.00
0005432784278	5649	Economy	9300.00
0005432784306	5649	Economy	9300.00
0005435242935	5649	Economy	9300.00
0005432784283	5649	Economy	9300.00
0005432784291	5649	Economy	9300.00
0005432784324	5649	Economy	9300.00
0005435242878	5649	Economy	9300.00
0005435242869	5649	Economy	9300.00
0005432784279	5649	Economy	9300.00
0005435242879	5649	Economy	9300.00
0005432784273	5649	Economy	9300.00
0005432784296	5649	Economy	9300.00
0005432784284	5649	Economy	9300.00
0005432784287	5649	Economy	9300.00
0005432784316	5649	Economy	9300.00
0005435242865	5649	Economy	9300.00
0005432784317	5649	Economy	9300.00
0005432784281	5649	Economy	9300.00
0005432784307	5649	Economy	9300.00
0005432784289	5649	Economy	9300.00
0005432784280	5649	Economy	9300.00
0005432784308	5649	Economy	9300.00
0005432784290	5649	Economy	9300.00
0005432784318	5649	Economy	9300.00
0005435476759	5649	Economy	9300.00
0005432784301	5649	Economy	9300.00
0005435242914	5649	Economy	9300.00
0005435242850	5649	Economy	9300.00
0005435242934	5649	Economy	9300.00
0005432784298	5649	Economy	9300.00
0005432784325	5649	Economy	9300.00
0005432144017	5649	Economy	9300.00
0005432784275	5649	Economy	9300.00
0005432784314	5649	Economy	9300.00
0005432784277	5649	Economy	9300.00
0005432784322	5649	Economy	9300.00
0005432784282	5649	Economy	9300.00
0005432784323	5649	Economy	9300.00
0005432144018	5649	Economy	9300.00
0005435242800	5649	Economy	9300.00
0005432784300	5649	Economy	9300.00
0005432784299	5649	Economy	9300.00
0005435242904	5649	Economy	9300.00
0005435476766	5649	Economy	9300.00
0005432784319	5649	Economy	9300.00
0005435242752	5649	Economy	9300.00
0005432784274	5649	Economy	9300.00
0005432784310	5649	Economy	9300.00
0005435242858	5649	Economy	9300.00
0005432784311	5649	Economy	9300.00
0005435242860	5649	Economy	9300.00
0005432784305	5649	Economy	9300.00
0005432784294	5649	Economy	9300.00
0005435242920	5649	Economy	9300.00
0005432783800	15384	Business	27800.00
0005435243094	15384	Business	27800.00
0005432784011	15384	Business	27800.00
0005432783812	15384	Business	27800.00
0005435243092	15384	Business	27800.00
0005432783921	15384	Business	27800.00
0005432783883	15384	Business	27800.00
0005435243081	15384	Business	27800.00
0005435476823	15384	Business	27800.00
0005432783938	15384	Business	27800.00
0005432783799	15384	Business	27800.00
0005432783876	15384	Economy	9300.00
0005432783689	15384	Economy	9300.00
0005432783939	15384	Economy	9300.00
0005435243077	15384	Economy	9300.00
0005432784012	15384	Economy	9300.00
0005432783647	15384	Economy	9300.00
0005432783751	15384	Economy	9300.00
0005432783768	15384	Economy	9300.00
0005432783916	15384	Economy	10200.00
0005435243079	15384	Economy	10200.00
0005432783729	15384	Economy	10200.00
0005432783603	15384	Economy	10200.00
0005432783872	15384	Economy	9300.00
0005432783699	15384	Economy	9300.00
0005432783788	15384	Economy	9300.00
0005435243097	15384	Economy	9300.00
0005432783892	15384	Economy	9300.00
0005435243102	15384	Economy	9300.00
0005432783879	15384	Economy	9300.00
0005432783744	15384	Economy	9300.00
0005435243099	15384	Economy	9300.00
0005432784041	15384	Economy	9300.00
0005432783597	15384	Economy	9300.00
0005435243091	15384	Economy	9300.00
0005432783711	15384	Economy	9300.00
0005432783769	15384	Economy	9300.00
0005432783684	15384	Economy	9300.00
0005432783598	15384	Economy	9300.00
0005435243090	15384	Economy	9300.00
0005435243075	15384	Economy	9300.00
0005435243078	15384	Economy	9300.00
0005432783743	15384	Economy	9300.00
0005432783734	15384	Economy	9300.00
0005432784050	15384	Economy	9300.00
0005432783750	15384	Economy	9300.00
0005432784042	15384	Economy	9300.00
0005432783819	15384	Economy	9300.00
0005432784051	15384	Economy	9300.00
0005435476825	15384	Economy	9300.00
0005432783688	15384	Economy	9300.00
0005432783881	15384	Economy	9300.00
0005432783563	15384	Economy	9300.00
0005435243088	15384	Economy	9300.00
0005435243101	15384	Economy	9300.00
0005432783882	15384	Economy	9300.00
0005432783785	15384	Economy	9300.00
0005435243100	15384	Economy	9300.00
0005435243089	15384	Economy	9300.00
0005432783820	15384	Economy	9300.00
0005432783807	15384	Economy	9300.00
0005435476826	15384	Economy	9300.00
0005435243076	15384	Economy	9300.00
0005435243080	15384	Economy	9300.00
0005432783631	15384	Economy	9300.00
0005435243085	15384	Economy	9300.00
0005435243086	15384	Economy	9300.00
0005435243093	15384	Economy	9300.00
0005432783806	15384	Economy	9300.00
0005435243082	15384	Economy	9300.00
0005432783843	15384	Economy	9300.00
0005435243095	15384	Economy	9300.00
0005435476824	15384	Economy	9300.00
0005432783765	15384	Economy	9300.00
0005432783811	15384	Economy	9300.00
0005432783891	15384	Economy	9300.00
0005435243074	15384	Economy	9300.00
0005432783745	15384	Economy	9300.00
0005432783712	15384	Economy	9300.00
0005435476822	15384	Economy	9300.00
0005435243096	15384	Economy	9300.00
0005435243087	15384	Economy	9300.00
0005435243084	15384	Economy	9300.00
0005435243098	15384	Economy	9300.00
0005432783599	15384	Economy	9300.00
0005432783875	15384	Economy	9300.00
0005432783564	15384	Economy	9300.00
0005435243083	15384	Economy	9300.00
0005435850926	4391	Economy	7000.00
0005435850889	4391	Economy	6300.00
0005432848446	4391	Economy	6300.00
0005434463949	4391	Economy	6300.00
0005432848456	4391	Economy	6300.00
0005434463951	4391	Economy	6300.00
0005435850910	4391	Economy	6300.00
0005432848447	4391	Economy	6300.00
0005435850931	4391	Economy	6300.00
0005432848454	4391	Economy	6300.00
0005435850932	4391	Economy	6300.00
0005432848442	4391	Economy	6300.00
0005432848452	4391	Economy	6300.00
0005432848448	4391	Economy	6300.00
0005435850953	4391	Economy	6300.00
0005434462810	4391	Economy	6300.00
0005432848445	4391	Economy	6300.00
0005434462811	4391	Economy	6300.00
0005432848444	4391	Economy	6300.00
0005432848455	4391	Economy	6300.00
0005432848451	4391	Economy	6300.00
0005432848443	4391	Economy	6300.00
0005434462809	4391	Economy	6300.00
0005434463950	4391	Economy	6300.00
0005432848453	4391	Economy	6300.00
0005432848449	4391	Economy	6300.00
0005432848450	4391	Economy	6300.00
0005434463920	28871	Economy	7000.00
0005432848330	28871	Economy	7000.00
0005432848316	28871	Economy	6300.00
0005435850998	28871	Economy	6300.00
0005432848329	28871	Economy	6300.00
0005435851000	28871	Economy	6300.00
0005435850993	28871	Economy	6300.00
0005435850992	28871	Economy	6300.00
0005432848321	28871	Economy	6300.00
0005432848277	28871	Economy	6300.00
0005432848236	28871	Economy	6300.00
0005432848286	28871	Economy	6300.00
0005432848285	28871	Economy	6300.00
0005435850994	28871	Economy	6300.00
0005432848299	28871	Economy	6300.00
0005432848313	28871	Economy	6300.00
0005435850999	28871	Economy	6300.00
0005432848281	28871	Economy	6300.00
0005432848322	28871	Economy	6300.00
0005435850997	28871	Economy	6300.00
0005434461650	28871	Economy	6300.00
0005432848318	28871	Economy	6300.00
0005432848317	28871	Economy	6300.00
0005435850996	28871	Economy	6300.00
0005435850991	28871	Economy	6300.00
0005432848310	28871	Economy	6300.00
0005432848319	28871	Economy	6300.00
0005432848280	28871	Economy	6300.00
0005435850995	28871	Economy	6300.00
0005434926120	6318	Business	11900.00
0005434443863	6318	Business	11900.00
0005434443855	6318	Business	11900.00
0005433497265	6318	Business	11900.00
0005434926114	6318	Business	11900.00
0005433497281	6318	Business	11900.00
0005432075262	6318	Business	11900.00
0005434926131	6318	Business	11900.00
0005433497257	6318	Business	11900.00
0005434926104	6318	Business	11900.00
0005433497266	6318	Business	11900.00
0005434926106	6318	Economy	4000.00
0005433497259	6318	Economy	4000.00
0005434926124	6318	Economy	4000.00
0005434926135	6318	Economy	4000.00
0005432075264	6318	Economy	4000.00
0005434443854	6318	Economy	4000.00
0005433497251	6318	Economy	4000.00
0005434926101	6318	Economy	4000.00
0005432075263	6318	Economy	4400.00
0005434443857	6318	Economy	4400.00
0005434443856	6318	Economy	4400.00
0005433497255	6318	Economy	4000.00
0005434443859	6318	Economy	4000.00
0005433497273	6318	Economy	4000.00
0005434926103	6318	Economy	4000.00
0005433497278	6318	Economy	4000.00
0005433497250	6318	Economy	4000.00
0005433497269	6318	Economy	4000.00
0005433497276	6318	Economy	4000.00
0005434926113	6318	Economy	4000.00
0005433497268	6318	Economy	4000.00
0005433497274	6318	Economy	4000.00
0005434926121	6318	Economy	4000.00
0005434926099	6318	Economy	4000.00
0005433497253	6318	Economy	4000.00
0005434926125	6318	Economy	4000.00
0005433497258	6318	Economy	4000.00
0005433497272	6318	Economy	4000.00
0005433497263	6318	Economy	4000.00
0005434926134	6318	Economy	4000.00
0005433497277	6318	Economy	4000.00
0005434443858	6318	Economy	4000.00
0005434926123	6318	Economy	4000.00
0005434443861	6318	Economy	4000.00
0005434443869	6318	Economy	4000.00
0005434443866	6318	Economy	4000.00
0005434926098	6318	Economy	4000.00
0005433497260	6318	Economy	4000.00
0005434926116	6318	Economy	4000.00
0005433497261	6318	Economy	4000.00
0005434443865	6318	Economy	4000.00
0005434926108	6318	Economy	4000.00
0005433497264	6318	Economy	4000.00
0005433497270	6318	Economy	4000.00
0005434926130	6318	Economy	4000.00
0005433497275	6318	Economy	4000.00
0005434443860	6318	Economy	4000.00
0005433497280	6318	Economy	4000.00
0005434926122	6318	Economy	4000.00
0005434443864	6318	Economy	4000.00
0005434926128	6318	Economy	4000.00
0005433497271	6318	Economy	4000.00
0005434926105	6318	Economy	4000.00
0005434926110	6318	Economy	4000.00
0005434926133	6318	Economy	4000.00
0005434443868	6318	Economy	4000.00
0005433497267	6318	Economy	4000.00
0005434926111	6318	Economy	4000.00
0005434926118	6318	Economy	4000.00
0005434926117	6318	Economy	4000.00
0005434443867	6318	Economy	4000.00
0005434926119	6318	Economy	4000.00
0005434926129	6318	Economy	4000.00
0005434926126	6318	Economy	4000.00
0005434926132	6318	Economy	4000.00
0005434926102	6318	Economy	4000.00
0005433497279	6318	Economy	4000.00
0005434926127	6318	Economy	4000.00
0005434926107	6318	Economy	4000.00
0005434926100	6318	Economy	4000.00
0005433497254	6318	Economy	4000.00
0005434926109	6318	Economy	4000.00
0005434926115	6318	Economy	4000.00
0005434926112	6318	Economy	4000.00
0005433497256	6318	Economy	4000.00
0005434443862	6318	Economy	4000.00
0005433497252	6318	Economy	4000.00
0005433497262	6318	Economy	4000.00
0005434925760	20431	Business	11900.00
0005433497032	20431	Business	11900.00
0005434925753	20431	Business	11900.00
0005434925769	20431	Business	11900.00
0005434925824	20431	Business	11900.00
0005433496950	20431	Business	11900.00
0005434443694	20431	Business	11900.00
0005433496964	20431	Business	11900.00
0005434443720	20431	Business	11900.00
0005434925822	20431	Business	11900.00
0005433496987	20431	Business	11900.00
0005433497068	20431	Economy	4000.00
0005434925821	20431	Economy	4000.00
0005433497159	20431	Economy	4000.00
0005433497063	20431	Economy	4000.00
0005433497152	20431	Economy	4000.00
0005434925764	20431	Economy	4000.00
0005434443794	20431	Economy	4000.00
0005433497034	20431	Economy	4400.00
0005433497151	20431	Economy	4400.00
0005434925790	20431	Economy	4400.00
0005434443768	20431	Economy	4000.00
0005433496963	20431	Economy	4000.00
0005433497050	20431	Economy	4000.00
0005434443671	20431	Economy	4000.00
0005434925809	20431	Economy	4000.00
0005434925799	20431	Economy	4000.00
0005434925776	20431	Economy	4000.00
0005434443699	20431	Economy	4000.00
0005433497049	20431	Economy	4000.00
0005434925825	20431	Economy	4000.00
0005433496826	20431	Economy	4000.00
0005434443711	20431	Economy	4000.00
0005434925759	20431	Economy	4000.00
0005434925823	20431	Economy	4000.00
0005434443710	20431	Economy	4000.00
0005434925752	20431	Economy	4000.00
0005434925762	20431	Economy	4000.00
0005434443727	20431	Economy	4000.00
0005433497069	20431	Economy	4000.00
0005433497081	20431	Economy	4000.00
0005434925755	20431	Economy	4000.00
0005433497030	20431	Economy	4000.00
0005434925765	20431	Economy	4000.00
0005433496962	20431	Economy	4000.00
0005433496955	20431	Economy	4000.00
0005434925791	20431	Economy	4000.00
0005434925798	20431	Economy	4000.00
0005434443783	20431	Economy	4000.00
0005433496915	20431	Economy	4000.00
0005433497025	20431	Economy	4000.00
0005434925751	20431	Economy	4000.00
0005434925784	20431	Economy	4000.00
0005433496951	20431	Economy	4000.00
0005434925754	20431	Economy	4000.00
0005434925810	20431	Economy	4000.00
0005434443683	20431	Economy	4000.00
0005434443692	20431	Economy	4000.00
0005433496825	20431	Economy	4000.00
0005434925768	20431	Economy	4000.00
0005434925782	20431	Economy	4000.00
0005433497209	20431	Economy	4000.00
0005433497176	20431	Economy	4000.00
0005434443754	20431	Economy	4000.00
0005434925783	20431	Economy	4000.00
0005433497031	20431	Economy	4000.00
0005433497033	20431	Economy	4000.00
0005433496988	20431	Economy	4000.00
0005433497040	20431	Economy	4000.00
0005433496986	20431	Economy	4000.00
0005434443709	20431	Economy	4000.00
0005434443693	20431	Economy	4000.00
0005434443730	20431	Economy	4000.00
0005434443782	20431	Economy	4000.00
0005434925763	20431	Economy	4000.00
0005433497080	20431	Economy	4000.00
0005433497147	20431	Economy	4000.00
0005434443753	20431	Economy	4000.00
0005433497067	20431	Economy	4000.00
0005432783927	12205	Business	41200.00
0005432783848	12205	Business	41200.00
0005432783906	12205	Business	41200.00
0005435243121	12205	Business	41200.00
0005435243105	12205	Business	41200.00
0005435243124	12205	Economy	13700.00
0005432784049	12205	Economy	13700.00
0005432783888	12205	Economy	13700.00
0005435243103	12205	Economy	13700.00
0005432783952	12205	Economy	13700.00
0005432783887	12205	Economy	13700.00
0005432783668	12205	Economy	15100.00
0005432783583	12205	Economy	13700.00
0005435243111	12205	Economy	13700.00
0005432783678	12205	Economy	13700.00
0005432783897	12205	Economy	13700.00
0005432783898	12205	Economy	13700.00
0005435243113	12205	Economy	13700.00
0005435243127	12205	Economy	13700.00
0005435243106	12205	Economy	13700.00
0005432783994	12205	Economy	13700.00
0005432783948	12205	Economy	13700.00
0005432783780	12205	Economy	13700.00
0005435243128	12205	Economy	13700.00
0005432783735	12205	Economy	13700.00
0005432783713	12205	Economy	13700.00
0005435243125	12205	Economy	13700.00
0005435243119	12205	Economy	13700.00
0005435243108	12205	Economy	13700.00
0005432783926	12205	Economy	13700.00
0005432783779	12205	Economy	13700.00
0005432783988	12205	Economy	13700.00
0005432783995	12205	Economy	13700.00
0005435243112	12205	Economy	13700.00
0005435243118	12205	Economy	13700.00
0005435243107	12205	Economy	13700.00
0005435243110	12205	Economy	13700.00
0005435243109	12205	Economy	13700.00
0005432783667	12205	Economy	13700.00
0005435243120	12205	Economy	13700.00
0005432783942	12205	Economy	13700.00
0005435243126	12205	Economy	13700.00
0005432783855	12205	Economy	13700.00
0005435243115	12205	Economy	13700.00
0005432783929	12205	Economy	13700.00
0005432784003	12205	Economy	13700.00
0005435243114	12205	Economy	13700.00
0005432783949	12205	Economy	13700.00
0005435243122	12205	Economy	13700.00
0005432783702	12205	Economy	13700.00
0005432783778	12205	Economy	13700.00
0005435243104	12205	Economy	13700.00
0005432783941	12205	Economy	13700.00
0005435243117	12205	Economy	13700.00
0005432783849	12205	Economy	13700.00
0005435243116	12205	Economy	13700.00
0005435243123	12205	Economy	13700.00
0005432783553	12205	Economy	13700.00
0005432783714	12205	Economy	13700.00
0005432783928	12205	Economy	13700.00
0005432784253	15436	Business	41200.00
0005432784262	15436	Business	41200.00
0005432784255	15436	Business	41200.00
0005432784261	15436	Business	41200.00
0005435242789	15436	Business	41200.00
0005435242779	15436	Business	41200.00
0005432784233	15436	Business	41200.00
0005432784218	15436	Business	41200.00
0005435242822	15436	Business	41200.00
0005432784268	15436	Business	41200.00
0005435242835	15436	Business	41200.00
0005432784231	15436	Business	41200.00
0005432784222	15436	Economy	13700.00
0005432784246	15436	Economy	13700.00
0005432784248	15436	Economy	13700.00
0005432784232	15436	Economy	13700.00
0005435242791	15436	Economy	13700.00
0005432784242	15436	Economy	13700.00
0005435242792	15436	Economy	13700.00
0005435242824	15436	Economy	13700.00
0005435242834	15436	Economy	15100.00
0005435242765	15436	Economy	15100.00
0005432784217	15436	Economy	15100.00
0005435242842	15436	Economy	15100.00
0005432784228	15436	Economy	15100.00
0005435242931	15436	Economy	13700.00
0005432784256	15436	Economy	13700.00
0005432784254	15436	Economy	13700.00
0005432784266	15436	Economy	13700.00
0005432784263	15436	Economy	13700.00
0005435242766	15436	Economy	13700.00
0005432784220	15436	Economy	13700.00
0005432784237	15436	Economy	13700.00
0005435242833	15436	Economy	13700.00
0005432784258	15436	Economy	13700.00
0005432784269	15436	Economy	13700.00
0005432784259	15436	Economy	13700.00
0005432784270	15436	Economy	13700.00
0005435242844	15436	Economy	13700.00
0005432784244	15436	Economy	13700.00
0005432784240	15436	Economy	13700.00
0005432784260	15436	Economy	13700.00
0005435242820	15436	Economy	13700.00
0005432784224	15436	Economy	13700.00
0005435242790	15436	Economy	13700.00
0005432784225	15436	Economy	13700.00
0005435242836	15436	Economy	13700.00
0005432784267	15436	Economy	13700.00
0005435242772	15436	Economy	13700.00
0005432784251	15436	Economy	13700.00
0005435242977	15436	Economy	13700.00
0005432784230	15436	Economy	13700.00
0005432784234	15436	Economy	13700.00
0005435242773	15436	Economy	13700.00
0005435242778	15436	Economy	13700.00
0005435242895	15436	Economy	13700.00
0005435242843	15436	Economy	13700.00
0005435242893	15436	Economy	13700.00
0005432784223	15436	Economy	13700.00
0005432784236	15436	Economy	13700.00
0005435242900	15436	Economy	13700.00
0005435242978	15436	Economy	13700.00
0005435242823	15436	Economy	13700.00
0005432784252	15436	Economy	13700.00
0005432784241	15436	Economy	13700.00
0005432784249	15436	Economy	13700.00
0005432784239	15436	Economy	13700.00
0005432784226	15436	Economy	13700.00
0005432784221	15436	Economy	13700.00
0005435242899	15436	Economy	13700.00
0005432784265	15436	Economy	13700.00
0005435242782	15436	Economy	13700.00
0005432784243	15436	Economy	13700.00
0005432784229	15436	Economy	13700.00
0005432784250	15436	Economy	13700.00
0005432784227	15436	Economy	13700.00
0005432784238	15436	Economy	13700.00
0005432784245	15436	Economy	13700.00
0005435242959	15436	Economy	13700.00
0005432784247	15436	Economy	13700.00
0005435242781	15436	Economy	13700.00
0005435242756	15436	Economy	13700.00
0005432784219	15436	Economy	13700.00
0005432784257	15436	Economy	13700.00
0005432784235	15436	Economy	13700.00
0005435242932	15436	Economy	13700.00
0005432784264	15436	Economy	13700.00
0005434878215	10113	Business	49700.00
0005434878169	10113	Business	49700.00
0005434878489	10113	Business	49700.00
0005434878272	10113	Business	49700.00
0005434878401	10113	Business	49700.00
0005434878381	10113	Business	49700.00
0005434878243	10113	Business	49700.00
0005434878077	10113	Business	49700.00
0005434878512	10113	Business	49700.00
0005434878294	10113	Business	49700.00
0005434878510	10113	Business	49700.00
0005434878070	10113	Business	49700.00
0005434878329	10113	Business	49700.00
0005434878140	10113	Business	49700.00
0005434878347	10113	Business	49700.00
0005434878259	10113	Business	49700.00
0005434877859	10113	Business	49700.00
0005434878375	10113	Business	49700.00
0005434878158	10113	Business	49700.00
0005434878378	10113	Business	49700.00
0005434878424	10113	Economy	16600.00
0005434878430	10113	Economy	16600.00
0005434878362	10113	Economy	16600.00
0005434878440	10113	Economy	16600.00
0005434878448	10113	Economy	16600.00
0005434878349	10113	Economy	16600.00
0005434877967	10113	Economy	16600.00
0005434878083	10113	Economy	16600.00
0005434878125	10113	Economy	16600.00
0005434878392	10113	Economy	16600.00
0005434878348	10113	Economy	16600.00
0005434878208	10113	Economy	16600.00
0005434878230	10113	Economy	18200.00
0005434878248	10113	Economy	16600.00
0005434878326	10113	Economy	18200.00
0005434878575	10113	Economy	18200.00
0005434877853	10113	Economy	18200.00
0005434878181	10113	Economy	16600.00
0005434878124	10113	Economy	16600.00
0005434878084	10113	Economy	16600.00
0005434878550	10113	Economy	16600.00
0005434878457	10113	Economy	16600.00
0005434878257	10113	Economy	16600.00
0005434877854	10113	Economy	16600.00
0005434878519	10113	Economy	16600.00
0005434877874	10113	Economy	16600.00
0005434878324	10113	Economy	16600.00
0005434877918	10113	Economy	16600.00
0005434878328	10113	Economy	16600.00
0005434878072	10113	Economy	16600.00
0005434878266	10113	Economy	16600.00
0005434878327	10113	Economy	16600.00
0005434878159	10113	Economy	16600.00
0005434877890	10113	Economy	16600.00
0005434877965	10113	Economy	16600.00
0005434877895	10113	Economy	16600.00
0005434878309	10113	Economy	16600.00
0005434878258	10113	Economy	16600.00
0005434878268	10113	Economy	16600.00
0005434877917	10113	Economy	16600.00
0005434878361	10113	Economy	16600.00
0005434878388	10113	Economy	16600.00
0005434877872	10113	Economy	16600.00
0005434878154	10113	Economy	16600.00
0005434878482	10113	Economy	16600.00
0005434878481	10113	Economy	16600.00
0005434878330	10113	Economy	16600.00
0005434878236	10113	Economy	16600.00
0005434878340	10113	Economy	16600.00
0005434878078	10113	Economy	16600.00
0005434877879	10113	Economy	16600.00
0005434878570	10113	Economy	16600.00
0005434878400	10113	Economy	16600.00
0005434878425	10113	Economy	16600.00
0005434878076	10113	Economy	16600.00
0005434878544	10113	Economy	16600.00
0005434878518	10113	Economy	16600.00
0005434878325	10113	Economy	16600.00
0005434878235	10113	Economy	16600.00
0005434877894	10113	Economy	16600.00
0005434878082	10113	Economy	16600.00
0005434878244	10113	Economy	16600.00
0005434878189	10113	Economy	16600.00
0005434878461	10113	Economy	16600.00
0005434878545	10113	Economy	16600.00
0005434878311	10113	Economy	16600.00
0005434878206	10113	Economy	16600.00
0005434878139	10113	Economy	16600.00
0005434878126	10113	Economy	16600.00
0005434878273	10113	Economy	16600.00
0005434878287	10113	Economy	16600.00
0005434878255	10113	Economy	16600.00
0005434878533	10113	Economy	16600.00
0005434878441	10113	Economy	16600.00
0005434878265	10113	Economy	16600.00
0005434878480	10113	Economy	16600.00
0005434878444	10113	Economy	16600.00
0005434878536	10113	Economy	16600.00
0005434878558	10113	Economy	16600.00
0005434878427	10113	Economy	16600.00
0005434877964	10113	Economy	16600.00
0005434878511	10113	Economy	16600.00
0005434878366	10113	Economy	16600.00
0005434878549	10113	Economy	16600.00
0005434878439	10113	Economy	16600.00
0005434878203	10113	Economy	16600.00
0005434878431	10113	Economy	16600.00
0005434878377	10113	Economy	16600.00
0005434878571	10113	Economy	16600.00
0005434877980	10113	Economy	16600.00
0005434878458	10113	Economy	16600.00
0005434878574	10113	Economy	16600.00
0005434877839	10113	Economy	16600.00
0005434877873	10113	Economy	16600.00
0005434878227	10113	Economy	16600.00
0005434879122	14644	Business	49700.00
0005434879128	14644	Business	49700.00
0005434879126	14644	Business	49700.00
0005434879094	14644	Business	49700.00
0005434879132	14644	Business	49700.00
0005434879112	14644	Business	49700.00
0005434879089	14644	Business	49700.00
0005434879058	14644	Business	49700.00
0005435913928	14644	Business	49700.00
0005434879125	14644	Business	49700.00
0005434879090	14644	Business	49700.00
0005434879098	14644	Business	49700.00
0005434879116	14644	Business	49700.00
0005434879093	14644	Business	49700.00
0005434879102	14644	Business	49700.00
0005434879056	14644	Business	49700.00
0005434879143	14644	Business	49700.00
0005434879137	14644	Business	49700.00
0005434879152	14644	Economy	16600.00
0005434758916	14644	Economy	16600.00
0005434879076	14644	Economy	16600.00
0005434879140	14644	Economy	16600.00
0005434879057	14644	Economy	16600.00
0005434879085	14644	Economy	16600.00
0005434879120	14644	Economy	16600.00
0005434879139	14644	Economy	16600.00
0005434879134	14644	Economy	16600.00
0005434879124	14644	Economy	16600.00
0005434879075	14644	Economy	16600.00
0005434879079	14644	Economy	16600.00
0005434910113	14644	Economy	18200.00
0005434879055	14644	Economy	18200.00
0005434879091	14644	Economy	18200.00
0005434879065	14644	Economy	18200.00
0005434910115	14644	Economy	16600.00
0005434879084	14644	Economy	16600.00
0005434879096	14644	Economy	16600.00
0005434879061	14644	Economy	16600.00
0005434879097	14644	Economy	16600.00
0005434879066	14644	Economy	16600.00
0005434879136	14644	Economy	16600.00
0005434879138	14644	Economy	16600.00
0005434879115	14644	Economy	16600.00
0005434879100	14644	Economy	16600.00
0005434758915	14644	Economy	16600.00
0005434879099	14644	Economy	16600.00
0005434879067	14644	Economy	16600.00
0005434879088	14644	Economy	16600.00
0005434879086	14644	Economy	16600.00
0005434879107	14644	Economy	16600.00
0005434879110	14644	Economy	16600.00
0005434879062	14644	Economy	16600.00
0005434879109	14644	Economy	16600.00
0005434879078	14644	Economy	16600.00
0005434910112	14644	Economy	16600.00
0005434879068	14644	Economy	16600.00
0005434879104	14644	Economy	16600.00
0005434879121	14644	Economy	16600.00
0005434879113	14644	Economy	16600.00
0005434879069	14644	Economy	16600.00
0005434879095	14644	Economy	16600.00
0005434879071	14644	Economy	16600.00
0005434879123	14644	Economy	16600.00
0005434879105	14644	Economy	16600.00
0005434879141	14644	Economy	16600.00
0005434879114	14644	Economy	16600.00
0005434879135	14644	Economy	16600.00
0005434879082	14644	Economy	16600.00
0005434879064	14644	Economy	16600.00
0005434879117	14644	Economy	16600.00
0005434879106	14644	Economy	16600.00
0005434879133	14644	Economy	16600.00
0005434879087	14644	Economy	16600.00
0005434879073	14644	Economy	16600.00
0005434879077	14644	Economy	16600.00
0005434879108	14644	Economy	16600.00
0005434879118	14644	Economy	16600.00
0005434879081	14644	Economy	16600.00
0005434879147	14644	Economy	16600.00
0005434879070	14644	Economy	16600.00
0005434879144	14644	Economy	16600.00
0005434879151	14644	Economy	16600.00
0005434879145	14644	Economy	16600.00
0005434879072	14644	Economy	16600.00
0005434879119	14644	Economy	16600.00
0005434879103	14644	Economy	16600.00
0005434879146	14644	Economy	16600.00
0005434879060	14644	Economy	16600.00
0005434879149	14644	Economy	16600.00
0005434879129	14644	Economy	16600.00
0005434879092	14644	Economy	16600.00
0005434879142	14644	Economy	16600.00
0005434879127	14644	Economy	16600.00
0005434879083	14644	Economy	16600.00
0005435913930	14644	Economy	16600.00
0005434879101	14644	Economy	16600.00
0005434879074	14644	Economy	16600.00
0005434879130	14644	Economy	16600.00
0005434879059	14644	Economy	16600.00
0005434879080	14644	Economy	16600.00
0005434879131	14644	Economy	16600.00
0005434879111	14644	Economy	16600.00
0005434879150	14644	Economy	16600.00
0005434879148	14644	Economy	16600.00
0005434879063	14644	Economy	16600.00
0005434758914	14644	Economy	16600.00
0005435660243	9260	Economy	22400.00
0005435660239	9260	Economy	22400.00
0005434251966	9260	Economy	20300.00
0005435660242	9260	Economy	20300.00
0005435660241	9260	Economy	20300.00
0005435660244	9260	Economy	20300.00
0005434251969	9260	Economy	20300.00
0005435660246	9260	Economy	20300.00
0005434251958	9260	Economy	20300.00
0005435660236	9260	Economy	20300.00
0005435660240	9260	Economy	20300.00
0005434251986	9260	Economy	20300.00
0005434251968	9260	Economy	20300.00
0005434251945	9260	Economy	20300.00
0005434251954	9260	Economy	20300.00
0005435660247	9260	Economy	20300.00
0005434251993	9260	Economy	20300.00
0005435660245	9260	Economy	20300.00
0005434252026	9260	Economy	20300.00
0005435660238	9260	Economy	20300.00
0005434251965	9260	Economy	20300.00
0005435660237	9260	Economy	20300.00
0005435660146	24648	Economy	22400.00
0005434252055	24648	Economy	20300.00
0005435660145	24648	Economy	20300.00
0005435660123	24648	Economy	20300.00
0005434252049	24648	Economy	20300.00
0005435660124	24648	Economy	20300.00
0005434252051	24648	Economy	20300.00
0005434252053	24648	Economy	20300.00
0005434252058	24648	Economy	20300.00
0005435660138	24648	Economy	20300.00
0005434252048	24648	Economy	20300.00
0005435660157	24648	Economy	20300.00
0005434252052	24648	Economy	20300.00
0005434252054	24648	Economy	20300.00
0005434252056	24648	Economy	20300.00
0005434252050	24648	Economy	20300.00
0005434252057	24648	Economy	20300.00
0005433681009	2804	Business	33000.00
0005432966936	2804	Business	33000.00
0005433681024	2804	Business	33000.00
0005433680985	2804	Business	33000.00
0005433680991	2804	Business	33000.00
0005433681012	2804	Business	33000.00
0005433681016	2804	Business	33000.00
0005433680994	2804	Business	33000.00
0005433680996	2804	Business	33000.00
0005433680993	2804	Business	33000.00
0005433680988	2804	Business	33000.00
0005432222828	2804	Economy	11000.00
0005433680983	2804	Economy	11000.00
0005432966964	2804	Economy	11000.00
0005432967047	2804	Economy	11000.00
0005433681011	2804	Economy	11000.00
0005432967021	2804	Economy	11000.00
0005433681018	2804	Economy	11000.00
0005432967022	2804	Economy	12100.00
0005433681028	2804	Economy	12100.00
0005432966997	2804	Economy	12100.00
0005432966885	2804	Economy	12100.00
0005433681025	2804	Economy	12100.00
0005433681004	2804	Economy	11000.00
0005433680986	2804	Economy	11000.00
0005433681015	2804	Economy	11000.00
0005432966878	2804	Economy	11000.00
0005433681005	2804	Economy	11000.00
0005433680992	2804	Economy	11000.00
0005433681026	2804	Economy	11000.00
0005433681008	2804	Economy	11000.00
0005432222829	2804	Economy	11000.00
0005432967000	2804	Economy	11000.00
0005432967011	2804	Economy	11000.00
0005432966905	2804	Economy	11000.00
0005432222831	2804	Economy	11000.00
0005433680998	2804	Economy	11000.00
0005432966886	2804	Economy	11000.00
0005433680995	2804	Economy	11000.00
0005432966937	2804	Economy	11000.00
0005433680987	2804	Economy	11000.00
0005433680984	2804	Economy	11000.00
0005433681002	2804	Economy	11000.00
0005433681000	2804	Economy	11000.00
0005432966877	2804	Economy	11000.00
0005433681003	2804	Economy	11000.00
0005433681019	2804	Economy	11000.00
0005433681010	2804	Economy	11000.00
0005433681023	2804	Economy	11000.00
0005433680989	2804	Economy	11000.00
0005433681022	2804	Economy	11000.00
0005432967012	2804	Economy	11000.00
0005432966938	2804	Economy	11000.00
0005433681001	2804	Economy	11000.00
0005432222830	2804	Economy	11000.00
0005432222832	2804	Economy	11000.00
0005433680980	2804	Economy	11000.00
0005433681027	2804	Economy	11000.00
0005432966904	2804	Economy	11000.00
0005433681007	2804	Economy	11000.00
0005433680997	2804	Economy	11000.00
0005432967062	2804	Economy	11000.00
0005433680981	2804	Economy	11000.00
0005433680982	2804	Economy	11000.00
0005433681020	2804	Economy	11000.00
0005432966998	2804	Economy	11000.00
0005432966903	2804	Economy	11000.00
0005433681006	2804	Economy	11000.00
0005433681013	2804	Economy	11000.00
0005432967069	2804	Economy	11000.00
0005433680999	2804	Economy	11000.00
0005432966963	2804	Economy	11000.00
0005432966914	2804	Economy	11000.00
0005432967010	2804	Economy	11000.00
0005433680990	2804	Economy	11000.00
0005433681017	2804	Economy	11000.00
0005432222833	2804	Economy	11000.00
0005432967009	2804	Economy	11000.00
0005433681014	2804	Economy	11000.00
0005433681021	2804	Economy	11000.00
0005432005239	29186	Business	33000.00
0005432967160	29186	Business	33000.00
0005432967183	29186	Business	33000.00
0005433680824	29186	Business	33000.00
0005432967164	29186	Business	33000.00
0005432967159	29186	Business	33000.00
0005432967166	29186	Business	33000.00
0005433680748	29186	Business	33000.00
0005433680688	29186	Business	33000.00
0005432967161	29186	Business	33000.00
0005433680418	29186	Economy	11000.00
0005433680427	29186	Economy	11000.00
0005432967178	29186	Economy	11000.00
0005433680364	29186	Economy	11000.00
0005432967169	29186	Economy	11000.00
0005432967175	29186	Economy	11000.00
0005432967167	29186	Economy	11000.00
0005433680612	29186	Economy	11000.00
0005433680816	29186	Economy	12100.00
0005433680813	29186	Economy	12100.00
0005432967163	29186	Economy	12100.00
0005433680812	29186	Economy	12100.00
0005433680686	29186	Economy	11000.00
0005433680641	29186	Economy	11000.00
0005433680706	29186	Economy	11000.00
0005433680583	29186	Economy	11000.00
0005433687692	29186	Economy	11000.00
0005433680815	29186	Economy	11000.00
0005433680425	29186	Economy	11000.00
0005433680744	29186	Economy	11000.00
0005433680702	29186	Economy	11000.00
0005433680632	29186	Economy	11000.00
0005433680705	29186	Economy	11000.00
0005432967176	29186	Economy	11000.00
0005432967180	29186	Economy	11000.00
0005432967177	29186	Economy	11000.00
0005433680564	29186	Economy	11000.00
0005433680820	29186	Economy	11000.00
0005433680498	29186	Economy	11000.00
0005433680642	29186	Economy	11000.00
0005433680750	29186	Economy	11000.00
0005432967185	29186	Economy	11000.00
0005432967162	29186	Economy	11000.00
0005433680660	29186	Economy	11000.00
0005433680604	29186	Economy	11000.00
0005433680619	29186	Economy	11000.00
0005432967179	29186	Economy	11000.00
0005433680636	29186	Economy	11000.00
0005433680504	29186	Economy	11000.00
0005433680667	29186	Economy	11000.00
0005433680749	29186	Economy	11000.00
0005432967168	29186	Economy	11000.00
0005433680538	29186	Economy	11000.00
0005432967171	29186	Economy	11000.00
0005432967173	29186	Economy	11000.00
0005433680689	29186	Economy	11000.00
0005432967158	29186	Economy	11000.00
0005432967181	29186	Economy	11000.00
0005433680363	29186	Economy	11000.00
0005432005240	29186	Economy	11000.00
0005433680614	29186	Economy	11000.00
0005433680490	29186	Economy	11000.00
0005432967172	29186	Economy	11000.00
0005433680435	29186	Economy	11000.00
0005433680668	29186	Economy	11000.00
0005433680503	29186	Economy	11000.00
0005433680626	29186	Economy	11000.00
0005433680673	29186	Economy	11000.00
0005433680635	29186	Economy	11000.00
0005433680747	29186	Economy	11000.00
0005432967165	29186	Economy	11000.00
0005432967174	29186	Economy	11000.00
0005433680491	29186	Economy	11000.00
0005432967170	29186	Economy	11000.00
0005433680752	29186	Economy	11000.00
0005433680424	29186	Economy	11000.00
0005433684421	29186	Economy	11000.00
0005432967184	29186	Economy	11000.00
0005433680644	29186	Economy	11000.00
0005433680640	29186	Economy	11000.00
0005432967182	29186	Economy	11000.00
0005433615298	9269	Business	132900.00
0005432755106	9269	Business	132900.00
0005433615264	9269	Business	132900.00
0005433615295	9269	Business	132900.00
0005433634093	9269	Business	132900.00
0005433615272	9269	Business	132900.00
0005433634087	9269	Business	132900.00
0005433634102	9269	Business	132900.00
0005433615267	9269	Business	132900.00
0005433577933	9269	Business	132900.00
0005433615269	9269	Business	132900.00
0005433634104	9269	Business	132900.00
0005433615309	9269	Business	132900.00
0005433615325	9269	Business	132900.00
0005433577927	9269	Business	132900.00
0005433615315	9269	Business	132900.00
0005433615323	9269	Business	132900.00
0005433634089	9269	Business	132900.00
0005434153534	9269	Business	132900.00
0005433634088	9269	Business	132900.00
0005433615300	9269	Business	132900.00
0005433615293	9269	Business	132900.00
0005433615279	9269	Business	132900.00
0005434163627	9269	Business	132900.00
0005433615263	9269	Business	132900.00
0005433615318	9269	Business	132900.00
0005433615306	9269	Economy	48700.00
0005433634098	9269	Economy	48700.00
0005433615266	9269	Economy	48700.00
0005433615317	9269	Economy	48700.00
0005433577925	9269	Economy	48700.00
0005433634103	9269	Economy	44300.00
0005433634092	9269	Economy	44300.00
0005433634108	9269	Economy	44300.00
0005433577935	9269	Economy	44300.00
0005433615324	9269	Economy	44300.00
0005433615327	9269	Economy	44300.00
0005433615326	9269	Economy	44300.00
0005433615311	9269	Economy	44300.00
0005433634096	9269	Economy	44300.00
0005433615276	9269	Economy	44300.00
0005433634099	9269	Economy	44300.00
0005432756877	9269	Economy	44300.00
0005433577926	9269	Economy	44300.00
0005434163615	9269	Economy	44300.00
0005433634113	9269	Economy	44300.00
0005433615304	9269	Economy	44300.00
0005432755105	9269	Economy	44300.00
0005434163619	9269	Economy	44300.00
0005433615328	9269	Economy	44300.00
0005433615312	9269	Economy	44300.00
0005433615268	9269	Economy	44300.00
0005433577931	9269	Economy	44300.00
0005433634116	9269	Economy	44300.00
0005433615275	9269	Economy	44300.00
0005433615294	9269	Economy	44300.00
0005433634086	9269	Economy	44300.00
0005433634111	9269	Economy	44300.00
0005433634119	9269	Economy	44300.00
0005433615282	9269	Economy	44300.00
0005433634106	9269	Economy	44300.00
0005434153533	9269	Economy	44300.00
0005433615277	9269	Economy	44300.00
0005433577932	9269	Economy	44300.00
0005433615260	9269	Economy	44300.00
0005433634110	9269	Economy	44300.00
0005434163626	9269	Economy	44300.00
0005433615296	9269	Economy	44300.00
0005433615305	9269	Economy	44300.00
0005433615273	9269	Economy	44300.00
0005434269096	9269	Economy	44300.00
0005433615274	9269	Economy	44300.00
0005433634091	9269	Economy	44300.00
0005434163554	9269	Economy	44300.00
0005433634107	9269	Economy	44300.00
0005433615331	9269	Economy	44300.00
0005433615286	9269	Economy	44300.00
0005434163628	9269	Economy	44300.00
0005433577934	9269	Economy	44300.00
0005433615322	9269	Economy	44300.00
0005433615321	9269	Economy	44300.00
0005433634117	9269	Economy	48700.00
0005433615281	9269	Economy	48700.00
0005433634097	9269	Economy	48700.00
0005433615332	9269	Economy	48700.00
0005433634090	9269	Economy	48700.00
0005433634118	9269	Economy	44300.00
0005433615303	9269	Economy	44300.00
0005433577924	9269	Economy	44300.00
0005433615316	9269	Economy	44300.00
0005433615314	9269	Economy	48700.00
0005433615285	9269	Economy	44300.00
0005433634105	9269	Economy	44300.00
0005433615307	9269	Economy	44300.00
0005434163613	9269	Economy	44300.00
0005433615310	9269	Economy	44300.00
0005434163614	9269	Economy	44300.00
0005433615271	9269	Economy	44300.00
0005432145127	9269	Economy	44300.00
0005433615330	9269	Economy	44300.00
0005434163629	9269	Economy	44300.00
0005433615313	9269	Economy	44300.00
0005433634115	9269	Economy	44300.00
0005433615265	9269	Economy	44300.00
0005433615278	9269	Economy	44300.00
0005433577936	9269	Economy	44300.00
0005433634112	9269	Economy	44300.00
0005432756878	9269	Economy	44300.00
0005433577923	9269	Economy	44300.00
0005433615292	9269	Economy	44300.00
0005433634101	9269	Economy	44300.00
0005433615297	9269	Economy	44300.00
0005433615299	9269	Economy	44300.00
0005433615289	9269	Economy	44300.00
0005433634094	9269	Economy	44300.00
0005433615329	9269	Economy	44300.00
0005432756879	9269	Economy	44300.00
0005432145128	9269	Economy	44300.00
0005433615288	9269	Economy	44300.00
0005433634109	9269	Economy	44300.00
0005432145129	9269	Economy	44300.00
0005433615290	9269	Economy	44300.00
0005433615319	9269	Economy	44300.00
0005433615287	9269	Economy	44300.00
0005434163630	9269	Economy	44300.00
0005433634100	9269	Economy	44300.00
0005433615291	9269	Economy	44300.00
0005433577930	9269	Economy	44300.00
0005433577929	9269	Economy	44300.00
0005433615283	9269	Economy	44300.00
0005433615262	9269	Economy	44300.00
0005433634114	9269	Economy	44300.00
0005433634095	9269	Economy	44300.00
0005433615270	9269	Economy	44300.00
0005433615301	9269	Economy	44300.00
0005433577928	9269	Economy	44300.00
0005433615280	9269	Economy	44300.00
0005433615261	9269	Economy	44300.00
0005433615308	9269	Economy	44300.00
0005434163592	9269	Economy	44300.00
0005433615284	9269	Economy	44300.00
0005433615302	9269	Economy	44300.00
0005434163555	9269	Economy	44300.00
0005433615320	9269	Economy	44300.00
0005433614599	25226	Business	132900.00
0005433614517	25226	Business	132900.00
0005433614563	25226	Business	132900.00
0005434163695	25226	Business	132900.00
0005433614620	25226	Business	132900.00
0005433577833	25226	Business	132900.00
0005433577795	25226	Business	132900.00
0005433614624	25226	Business	132900.00
0005433633900	25226	Business	132900.00
0005434163693	25226	Business	132900.00
0005433614586	25226	Business	132900.00
0005433614556	25226	Business	132900.00
0005433633748	25226	Business	132900.00
0005433614816	25226	Business	132900.00
0005433633920	25226	Business	132900.00
0005435854063	25226	Business	132900.00
0005433614774	25226	Business	132900.00
0005433614579	25226	Business	132900.00
0005433633869	25226	Business	132900.00
0005433633693	25226	Economy	48700.00
0005433614486	25226	Business	132900.00
0005433614492	25226	Economy	48700.00
0005433614738	25226	Economy	48700.00
0005433633873	25226	Economy	48700.00
0005433614504	25226	Economy	48700.00
0005433614339	25226	Economy	48700.00
0005433614708	25226	Economy	44300.00
0005433614790	25226	Economy	44300.00
0005433577824	25226	Economy	44300.00
0005433614428	25226	Economy	44300.00
0005433614734	25226	Economy	44300.00
0005433614557	25226	Economy	44300.00
0005434273092	25226	Economy	44300.00
0005433577808	25226	Economy	44300.00
0005433633786	25226	Economy	44300.00
0005434272205	25226	Economy	44300.00
0005433614968	25226	Economy	44300.00
0005433633674	25226	Economy	44300.00
0005433577848	25226	Economy	44300.00
0005433614658	25226	Economy	44300.00
0005434163699	25226	Economy	44300.00
0005433633711	25226	Economy	44300.00
0005434163696	25226	Economy	44300.00
0005433633834	25226	Economy	44300.00
0005433614516	25226	Economy	44300.00
0005433614796	25226	Economy	44300.00
0005433614460	25226	Economy	44300.00
0005433633692	25226	Economy	44300.00
0005433614771	25226	Economy	44300.00
0005433614491	25226	Economy	44300.00
0005433577856	25226	Economy	44300.00
0005433614372	25226	Economy	44300.00
0005433614621	25226	Economy	44300.00
0005433633840	25226	Economy	44300.00
0005434273091	25226	Economy	44300.00
0005434163697	25226	Economy	44300.00
0005433614795	25226	Economy	44300.00
0005433614879	25226	Economy	44300.00
0005433633729	25226	Economy	44300.00
0005433614855	25226	Economy	44300.00
0005433614587	25226	Economy	44300.00
0005433614436	25226	Economy	44300.00
0005434163703	25226	Economy	44300.00
0005434163701	25226	Economy	44300.00
0005433614493	25226	Economy	44300.00
0005433633897	25226	Economy	44300.00
0005433614606	25226	Economy	44300.00
0005433614596	25226	Economy	44300.00
0005433633874	25226	Economy	44300.00
0005433614770	25226	Economy	44300.00
0005433577807	25226	Economy	44300.00
0005433614623	25226	Economy	44300.00
0005433577889	25226	Economy	44300.00
0005433614583	25226	Economy	48700.00
0005433614392	25226	Economy	48700.00
0005433577850	25226	Economy	48700.00
0005433614876	25226	Economy	48700.00
0005433614553	25226	Economy	44300.00
0005433614490	25226	Economy	44300.00
0005434272207	25226	Economy	48700.00
0005433633770	25226	Economy	44300.00
0005433577855	25226	Economy	44300.00
0005433614485	25226	Economy	44300.00
0005433633737	25226	Economy	44300.00
0005433633835	25226	Economy	44300.00
0005433614791	25226	Economy	44300.00
0005433577849	25226	Economy	44300.00
0005433614678	25226	Economy	44300.00
0005433614605	25226	Economy	44300.00
0005433577851	25226	Economy	44300.00
0005433614834	25226	Economy	44300.00
0005433633863	25226	Economy	44300.00
0005433614699	25226	Economy	44300.00
0005433614861	25226	Economy	44300.00
0005433577799	25226	Economy	44300.00
0005433633573	25226	Economy	44300.00
0005433614564	25226	Economy	44300.00
0005434163702	25226	Economy	44300.00
0005433614687	25226	Economy	44300.00
0005433614695	25226	Economy	44300.00
0005433614614	25226	Economy	44300.00
0005433614615	25226	Economy	44300.00
0005433614747	25226	Economy	44300.00
0005433614533	25226	Economy	44300.00
0005433614580	25226	Economy	44300.00
0005433633881	25226	Economy	44300.00
0005433577847	25226	Economy	44300.00
0005433614836	25226	Economy	44300.00
0005433614817	25226	Economy	44300.00
0005433633830	25226	Economy	44300.00
0005433614366	25226	Economy	44300.00
0005433633795	25226	Economy	44300.00
0005433633785	25226	Economy	44300.00
0005433614854	25226	Economy	44300.00
0005433633885	25226	Economy	44300.00
0005433577794	25226	Economy	44300.00
0005433577834	25226	Economy	44300.00
0005433633728	25226	Economy	44300.00
0005433633814	25226	Economy	44300.00
0005434163698	25226	Economy	44300.00
0005433614525	25226	Economy	44300.00
0005433633877	25226	Economy	44300.00
0005433614792	25226	Economy	44300.00
0005434163694	25226	Economy	44300.00
0005434272206	25226	Economy	44300.00
0005433614688	25226	Economy	44300.00
0005433577828	25226	Economy	44300.00
0005433633862	25226	Economy	44300.00
0005433633710	25226	Economy	44300.00
0005433614627	25226	Economy	44300.00
0005433633572	25226	Economy	44300.00
0005433633870	25226	Economy	44300.00
0005434163700	25226	Economy	44300.00
0005435947256	4212	Business	193100.00
0005435947247	4212	Business	193100.00
0005432571311	4212	Business	193100.00
0005435947272	4212	Business	193100.00
0005435986827	4212	Business	193100.00
0005435787349	4212	Business	193100.00
0005435986824	4212	Business	193100.00
0005435856203	4212	Business	193100.00
0005435947283	4212	Business	193100.00
0005435856202	4212	Economy	70800.00
0005435986826	4212	Economy	64400.00
0005432571328	4212	Economy	64400.00
0005432184979	4212	Economy	64400.00
0005435947301	4212	Economy	64400.00
0005435947295	4212	Economy	64400.00
0005435856208	4212	Economy	64400.00
0005435947282	4212	Economy	64400.00
0005435856209	4212	Economy	64400.00
0005435947287	4212	Economy	64400.00
0005435986823	4212	Economy	64400.00
0005432184978	4212	Economy	64400.00
0005435947191	4212	Economy	70800.00
0005435787359	4212	Economy	70800.00
0005435947266	4212	Economy	70800.00
0005435787345	4212	Economy	64400.00
0005435787358	4212	Economy	64400.00
0005435947270	4212	Economy	64400.00
0005432571331	4212	Economy	64400.00
0005435986825	4212	Economy	64400.00
0005432184976	4212	Economy	64400.00
0005435947267	4212	Economy	64400.00
0005435947296	4212	Economy	64400.00
0005435947246	4212	Economy	64400.00
0005435947258	4212	Economy	64400.00
0005432184977	4212	Economy	64400.00
0005435947245	4212	Economy	64400.00
0005434271317	4212	Economy	64400.00
0005435947271	4212	Economy	64400.00
0005432571332	4212	Economy	64400.00
0005435947255	4212	Economy	64400.00
0005432571310	4212	Economy	64400.00
0005435947265	4212	Economy	64400.00
0005434271310	4212	Economy	64400.00
0005435787357	4212	Economy	64400.00
0005435787344	4212	Economy	64400.00
0005435986760	26559	Business	193100.00
0005432571361	26559	Business	193100.00
0005435856245	26559	Business	193100.00
0005432571359	26559	Business	193100.00
0005435947393	26559	Business	193100.00
0005435947395	26559	Business	193100.00
0005435947394	26559	Economy	70800.00
0005435947387	26559	Economy	64400.00
0005435856242	26559	Economy	64400.00
0005435856244	26559	Economy	64400.00
0005435947392	26559	Economy	64400.00
0005435856243	26559	Economy	64400.00
0005435986735	26559	Economy	64400.00
0005435986793	26559	Economy	64400.00
0005432571360	26559	Economy	64400.00
0005435986727	26559	Economy	64400.00
0005435986778	26559	Economy	64400.00
0005435947390	26559	Economy	64400.00
0005435986750	26559	Economy	64400.00
0005435787375	26559	Economy	64400.00
0005435947389	26559	Economy	64400.00
0005435947388	26559	Economy	64400.00
0005435986780	26559	Economy	64400.00
0005435947398	26559	Economy	64400.00
0005435986736	26559	Economy	64400.00
0005435947385	26559	Economy	64400.00
0005435947391	26559	Economy	64400.00
0005435986761	26559	Economy	64400.00
0005435947397	26559	Economy	64400.00
0005435787376	26559	Economy	64400.00
0005435947396	26559	Economy	64400.00
0005435986749	26559	Economy	64400.00
0005435986728	26559	Economy	64400.00
0005435947386	26559	Economy	64400.00
0005432571358	26559	Economy	64400.00
0005433569611	364	Business	21500.00
0005433569603	364	Business	21500.00
0005433569640	364	Business	21500.00
0005433569632	364	Business	21500.00
0005433569616	364	Business	21500.00
0005433569645	364	Business	21500.00
0005433074698	364	Business	21500.00
0005433569596	364	Business	21500.00
0005433134133	364	Business	21500.00
0005432948317	364	Business	21500.00
0005433129271	364	Business	21500.00
0005432948584	364	Business	21500.00
0005433569639	364	Business	21500.00
0005433569598	364	Business	21500.00
0005433569644	364	Business	21500.00
0005433569628	364	Business	21500.00
0005432238991	364	Business	21500.00
0005432238993	364	Business	21500.00
0005432948340	364	Business	21500.00
0005432948593	364	Business	21500.00
0005433569629	364	Economy	7900.00
0005433134138	364	Economy	7900.00
0005432948626	364	Economy	7200.00
0005433074549	364	Economy	7200.00
0005433569635	364	Economy	7200.00
0005433569591	364	Economy	7200.00
0005433074689	364	Economy	7200.00
0005433569631	364	Economy	7200.00
0005433134158	364	Economy	7200.00
0005432238992	364	Economy	7200.00
0005433569584	364	Economy	7200.00
0005432948463	364	Economy	7200.00
0005432948594	364	Economy	7200.00
0005432948595	364	Economy	7200.00
0005432238995	364	Economy	7200.00
0005433074747	364	Economy	7200.00
0005432948552	364	Economy	7200.00
0005433569609	364	Economy	7200.00
0005433569624	364	Economy	7200.00
0005433569599	364	Economy	7200.00
0005433569588	364	Economy	7200.00
0005433569608	364	Economy	7200.00
0005433134154	364	Economy	7200.00
0005433569634	364	Economy	7200.00
0005433569613	364	Economy	7200.00
0005433569587	364	Economy	7200.00
0005433569594	364	Economy	7200.00
0005433569592	364	Economy	7200.00
0005432948478	364	Economy	7200.00
0005433569607	364	Economy	7200.00
0005432948583	364	Economy	7200.00
0005433129272	364	Economy	7200.00
0005433129249	364	Economy	7200.00
0005433074748	364	Economy	7200.00
0005433569606	364	Economy	7200.00
0005433134139	364	Economy	7200.00
0005432948442	364	Economy	7200.00
0005433569620	364	Economy	7200.00
0005432948572	364	Economy	7200.00
0005432948504	364	Economy	7200.00
0005432948464	364	Economy	7200.00
0005433929857	364	Economy	7200.00
0005432948528	364	Economy	7200.00
0005432948476	364	Economy	7200.00
0005433569647	364	Economy	7200.00
0005432948341	364	Economy	7200.00
0005433569621	364	Economy	7200.00
0005432948288	364	Economy	7200.00
0005433569597	364	Economy	7200.00
0005432948550	364	Economy	7900.00
0005433569637	364	Economy	7900.00
0005433074722	364	Economy	7900.00
0005433569612	364	Economy	7200.00
0005433569585	364	Economy	7900.00
0005433569615	364	Economy	7200.00
0005432948339	364	Economy	7200.00
0005433134142	364	Economy	7200.00
0005433569595	364	Economy	7900.00
0005433569605	364	Economy	7200.00
0005433074744	364	Economy	7200.00
0005432948531	364	Economy	7200.00
0005433569627	364	Economy	7200.00
0005433569646	364	Economy	7200.00
0005432948546	364	Economy	7200.00
0005433569593	364	Economy	7200.00
0005433569642	364	Economy	7200.00
0005433129251	364	Economy	7200.00
0005433074613	364	Economy	7200.00
0005433569625	364	Economy	7200.00
0005432948627	364	Economy	7200.00
0005433134141	364	Economy	7200.00
0005433569623	364	Economy	7200.00
0005433569589	364	Economy	7200.00
0005433129274	364	Economy	7200.00
0005433569638	364	Economy	7200.00
0005432948392	364	Economy	7200.00
0005433569636	364	Economy	7200.00
0005433569618	364	Economy	7200.00
0005433074655	364	Economy	7200.00
0005433569633	364	Economy	7200.00
0005433074649	364	Economy	7200.00
0005433074786	364	Economy	7200.00
0005433134134	364	Economy	7200.00
0005432238996	364	Economy	7200.00
0005433569643	364	Economy	7200.00
0005433569590	364	Economy	7200.00
0005432948502	364	Economy	7200.00
0005432948477	364	Economy	7200.00
0005433129250	364	Economy	7200.00
0005432948551	364	Economy	7200.00
0005433074730	364	Economy	7200.00
0005433569610	364	Economy	7200.00
0005433569601	364	Economy	7200.00
0005433074785	364	Economy	7200.00
0005433569622	364	Economy	7200.00
0005433074775	364	Economy	7200.00
0005432948530	364	Economy	7200.00
0005433569602	364	Economy	7200.00
0005433569600	364	Economy	7200.00
0005432238994	364	Economy	7200.00
0005433569586	364	Economy	7200.00
0005432948529	364	Economy	7200.00
0005433569641	364	Economy	7200.00
0005433569630	364	Economy	7200.00
0005433569648	364	Economy	7200.00
0005432948557	364	Economy	7200.00
0005433569626	364	Economy	7200.00
0005432948503	364	Economy	7200.00
0005433569617	364	Economy	7200.00
0005433569614	364	Economy	7200.00
0005433569604	364	Economy	7200.00
0005432948556	364	Economy	7200.00
0005433569619	364	Economy	7200.00
0005433074983	11610	Business	21500.00
0005433074957	11610	Business	21500.00
0005432948839	11610	Business	21500.00
0005432948825	11610	Business	21500.00
0005433074969	11610	Business	21500.00
0005432948813	11610	Business	21500.00
0005433568917	11610	Business	21500.00
0005433074979	11610	Business	21500.00
0005433074971	11610	Business	21500.00
0005432948834	11610	Business	21500.00
0005433568796	11610	Business	21500.00
0005433568697	11610	Business	21500.00
0005432948836	11610	Business	21500.00
0005433074974	11610	Business	21500.00
0005433074978	11610	Business	21500.00
0005432192347	11610	Business	21500.00
0005433569002	11610	Business	21500.00
0005433134180	11610	Business	21500.00
0005433569153	11610	Business	21500.00
0005432948843	11610	Business	21500.00
0005432948818	11610	Business	21500.00
0005433568855	11610	Business	21500.00
0005433568918	11610	Business	21500.00
0005432192349	11610	Business	21500.00
0005433569172	11610	Economy	7900.00
0005433074968	11610	Economy	7900.00
0005433074977	11610	Economy	7900.00
0005432948808	11610	Economy	7900.00
0005433568787	11610	Economy	7900.00
0005432948809	11610	Economy	7900.00
0005432948821	11610	Economy	7200.00
0005432948832	11610	Economy	7200.00
0005433569117	11610	Economy	7200.00
0005433568646	11610	Economy	7200.00
0005432948814	11610	Economy	7200.00
0005433568745	11610	Economy	7200.00
0005432948816	11610	Economy	7200.00
0005433569036	11610	Economy	7200.00
0005433568926	11610	Economy	7200.00
0005433074955	11610	Economy	7200.00
0005432948806	11610	Economy	7200.00
0005433131750	11610	Economy	7200.00
0005433569104	11610	Economy	7200.00
0005432948845	11610	Economy	7200.00
0005433074981	11610	Economy	7200.00
0005432948829	11610	Economy	7200.00
0005433569033	11610	Economy	7200.00
0005433569068	11610	Economy	7200.00
0005433568971	11610	Economy	7200.00
0005432948840	11610	Economy	7200.00
0005433568982	11610	Economy	7200.00
0005432948820	11610	Economy	7200.00
0005433074967	11610	Economy	7200.00
0005433074982	11610	Economy	7200.00
0005433569111	11610	Economy	7200.00
0005433568897	11610	Economy	7200.00
0005433569097	11610	Economy	7200.00
0005433134178	11610	Economy	7200.00
0005433074976	11610	Economy	7200.00
0005433134181	11610	Economy	7200.00
0005433134182	11610	Economy	7200.00
0005432948828	11610	Economy	7200.00
0005433074961	11610	Economy	7200.00
0005433568886	11610	Economy	7200.00
0005433569030	11610	Economy	7200.00
0005433074975	11610	Economy	7200.00
0005433569015	11610	Economy	7200.00
0005433568965	11610	Economy	7200.00
0005432948822	11610	Economy	7200.00
0005433131751	11610	Economy	7200.00
0005432948817	11610	Economy	7200.00
0005432948838	11610	Economy	7200.00
0005432192350	11610	Economy	7200.00
0005433568811	11610	Economy	7200.00
0005433569037	11610	Economy	7200.00
0005432948846	11610	Economy	7200.00
0005433568991	11610	Economy	7200.00
0005433074980	11610	Economy	7200.00
0005433131749	11610	Economy	7200.00
0005432948826	11610	Economy	7200.00
0005433074954	11610	Economy	7900.00
0005433568992	11610	Economy	7200.00
0005433074964	11610	Economy	7900.00
0005432948811	11610	Economy	7900.00
0005432948819	11610	Economy	7900.00
0005432948830	11610	Economy	7900.00
0005433074963	11610	Economy	7200.00
0005432948815	11610	Economy	7200.00
0005433568999	11610	Economy	7200.00
0005433134179	11610	Economy	7200.00
0005433074960	11610	Economy	7900.00
0005432192348	11610	Economy	7200.00
0005433568629	11610	Economy	7200.00
0005433074966	11610	Economy	7200.00
0005433569019	11610	Economy	7200.00
0005433568848	11610	Economy	7200.00
0005433569118	11610	Economy	7200.00
0005433569180	11610	Economy	7200.00
0005433568952	11610	Economy	7200.00
0005432948827	11610	Economy	7200.00
0005432948844	11610	Economy	7200.00
0005433074970	11610	Economy	7200.00
0005433074965	11610	Economy	7200.00
0005433568968	11610	Economy	7200.00
0005433074956	11610	Economy	7200.00
0005432948810	11610	Economy	7200.00
0005432948833	11610	Economy	7200.00
0005433568915	11610	Economy	7200.00
0005432948847	11610	Economy	7200.00
0005433074962	11610	Economy	7200.00
0005433569119	11610	Economy	7200.00
0005433568732	11610	Economy	7200.00
0005433074972	11610	Economy	7200.00
0005433569014	11610	Economy	7200.00
0005432948831	11610	Economy	7200.00
0005433568964	11610	Economy	7200.00
0005433074973	11610	Economy	7200.00
0005432948835	11610	Economy	7200.00
0005433074958	11610	Economy	7200.00
0005433131752	11610	Economy	7200.00
0005432948837	11610	Economy	7200.00
0005433569079	11610	Economy	7200.00
0005433568993	11610	Economy	7200.00
0005432948812	11610	Economy	7200.00
0005433568951	11610	Economy	7200.00
0005433569051	11610	Economy	7200.00
0005432948841	11610	Economy	7200.00
0005433568630	11610	Economy	7200.00
0005433568628	11610	Economy	7200.00
0005433074959	11610	Economy	7200.00
0005433568953	11610	Economy	7200.00
0005433568636	11610	Economy	7200.00
0005433569166	11610	Economy	7200.00
0005433134183	11610	Economy	7200.00
0005433569043	11610	Economy	7200.00
0005433568788	11610	Economy	7200.00
0005433568808	11610	Economy	7200.00
0005433568959	11610	Economy	7200.00
0005432948823	11610	Economy	7200.00
0005432948807	11610	Economy	7200.00
0005432948842	11610	Economy	7200.00
0005432948824	11610	Economy	7200.00
0005433817504	9981	Economy	6300.00
0005433817507	9981	Economy	6300.00
0005433817505	9981	Economy	6300.00
0005434732984	9981	Economy	6300.00
0005434732985	9981	Economy	6300.00
0005433817506	9981	Economy	6300.00
0005433817483	13977	Economy	6300.00
0005433817484	13977	Economy	6300.00
0005434733015	13977	Economy	6300.00
0005433817485	13977	Economy	6300.00
0005434733014	13977	Economy	6300.00
0005434733012	13977	Economy	6300.00
0005434733013	13977	Economy	6300.00
0005432226117	2343	Business	184500.00
0005433754728	2343	Business	184500.00
0005433754725	2343	Business	184500.00
0005433754746	2343	Business	184500.00
0005433754758	2343	Business	184500.00
0005432655644	2343	Business	184500.00
0005432985028	2343	Business	184500.00
0005432869536	2343	Business	184500.00
0005433434628	2343	Business	184500.00
0005433754739	2343	Business	184500.00
0005432985077	2343	Business	184500.00
0005435982747	2343	Business	184500.00
0005433434706	2343	Business	184500.00
0005432869498	2343	Business	184500.00
0005432869552	2343	Business	184500.00
0005432226114	2343	Business	184500.00
0005432985089	2343	Business	184500.00
0005432655650	2343	Business	184500.00
0005435982763	2343	Business	184500.00
0005433754764	2343	Business	184500.00
0005435982728	2343	Business	184500.00
0005435982727	2343	Business	184500.00
0005433754762	2343	Business	184500.00
0005435982751	2343	Business	184500.00
0005433754720	2343	Business	184500.00
0005433754723	2343	Business	184500.00
0005433434646	2343	Business	184500.00
0005432869543	2343	Business	184500.00
0005432226115	2343	Economy	67700.00
0005433434720	2343	Business	184500.00
0005433754768	2343	Economy	67700.00
0005432226113	2343	Economy	67700.00
0005435982757	2343	Economy	67700.00
0005433754770	2343	Economy	61500.00
0005433754769	2343	Economy	61500.00
0005433754763	2343	Economy	61500.00
0005435982746	2343	Economy	61500.00
0005433434774	2343	Economy	61500.00
0005433754718	2343	Economy	61500.00
0005432300317	2343	Economy	61500.00
0005435982750	2343	Economy	61500.00
0005433754756	2343	Economy	61500.00
0005433754719	2343	Economy	61500.00
0005435982749	2343	Economy	61500.00
0005432655653	2343	Economy	61500.00
0005433754742	2343	Economy	61500.00
0005432300320	2343	Economy	61500.00
0005432869526	2343	Economy	61500.00
0005433754754	2343	Economy	61500.00
0005433434548	2343	Economy	61500.00
0005433754744	2343	Economy	61500.00
0005435982721	2343	Economy	61500.00
0005435982760	2343	Economy	61500.00
0005435982759	2343	Economy	61500.00
0005432985063	2343	Economy	61500.00
0005432985150	2343	Economy	61500.00
0005433754741	2343	Economy	61500.00
0005435982726	2343	Economy	61500.00
0005432985109	2343	Economy	61500.00
0005433754761	2343	Economy	61500.00
0005432985031	2343	Economy	61500.00
0005432226112	2343	Economy	61500.00
0005432985088	2343	Economy	61500.00
0005433434725	2343	Economy	61500.00
0005432985108	2343	Economy	61500.00
0005432985064	2343	Economy	61500.00
0005432984995	2343	Economy	61500.00
0005433434598	2343	Economy	61500.00
0005433754734	2343	Economy	61500.00
0005434731165	2343	Economy	61500.00
0005432869527	2343	Economy	61500.00
0005435982739	2343	Economy	61500.00
0005435982764	2343	Economy	61500.00
0005433434769	2343	Economy	61500.00
0005433754732	2343	Economy	61500.00
0005432655646	2343	Economy	61500.00
0005432985002	2343	Economy	61500.00
0005433434664	2343	Economy	61500.00
0005432985095	2343	Economy	61500.00
0005434731163	2343	Economy	61500.00
0005435982753	2343	Economy	61500.00
0005435982720	2343	Economy	61500.00
0005435982756	2343	Economy	61500.00
0005433754727	2343	Economy	61500.00
0005435982755	2343	Economy	61500.00
0005432300318	2343	Economy	61500.00
0005433766676	2343	Economy	61500.00
0005435982761	2343	Economy	61500.00
0005435982732	2343	Economy	61500.00
0005433754767	2343	Economy	61500.00
0005433754772	2343	Economy	61500.00
0005435982745	2343	Economy	61500.00
0005433754736	2343	Economy	61500.00
0005433764700	2343	Economy	61500.00
0005433754749	2343	Economy	61500.00
0005435982734	2343	Economy	61500.00
0005432655647	2343	Economy	61500.00
0005433754743	2343	Economy	61500.00
0005432985110	2343	Economy	61500.00
0005435982740	2343	Economy	61500.00
0005433754765	2343	Economy	61500.00
0005433434726	2343	Economy	61500.00
0005432226118	2343	Economy	61500.00
0005435982722	2343	Economy	61500.00
0005433754747	2343	Economy	61500.00
0005435982754	2343	Economy	61500.00
0005432985041	2343	Economy	61500.00
0005433766677	2343	Economy	61500.00
0005435982752	2343	Economy	61500.00
0005432226116	2343	Economy	61500.00
0005432300319	2343	Economy	61500.00
0005433754757	2343	Economy	61500.00
0005433754755	2343	Economy	61500.00
0005435982737	2343	Economy	61500.00
0005435982730	2343	Economy	61500.00
0005435982743	2343	Economy	61500.00
0005433434785	2343	Economy	61500.00
0005435982758	2343	Economy	61500.00
0005432655651	2343	Economy	61500.00
0005435982744	2343	Economy	61500.00
0005433754733	2343	Economy	61500.00
0005433754774	2343	Economy	61500.00
0005433754740	2343	Economy	61500.00
0005435982729	2343	Economy	61500.00
0005433754729	2343	Economy	67700.00
0005434731178	2343	Economy	61500.00
0005433764699	2343	Economy	67700.00
0005432655655	2343	Economy	61500.00
0005432869548	2343	Economy	67700.00
0005433434627	2343	Economy	61500.00
0005435982731	2343	Economy	61500.00
0005434731164	2343	Economy	61500.00
0005433754735	2343	Economy	61500.00
0005433754750	2343	Economy	61500.00
0005432869537	2343	Economy	61500.00
0005432869544	2343	Economy	61500.00
0005435982738	2343	Economy	61500.00
0005433434712	2343	Economy	61500.00
0005432985065	2343	Economy	61500.00
0005435982725	2343	Economy	61500.00
0005432655645	2343	Economy	61500.00
0005433754759	2343	Economy	61500.00
0005433754726	2343	Economy	61500.00
0005432985105	2343	Economy	61500.00
0005433754751	2343	Economy	61500.00
0005435982748	2343	Economy	61500.00
0005433754752	2343	Economy	61500.00
0005432655649	2343	Economy	61500.00
0005435982766	2343	Economy	61500.00
0005433434676	2343	Economy	61500.00
0005433754771	2343	Economy	61500.00
0005435982742	2343	Economy	61500.00
0005432985140	2343	Economy	61500.00
0005434731185	2343	Economy	61500.00
0005432869525	2343	Economy	61500.00
0005435982765	2343	Economy	61500.00
0005432655648	2343	Economy	61500.00
0005433754722	2343	Economy	61500.00
0005435982762	2343	Economy	61500.00
0005432985090	2343	Economy	61500.00
0005432985152	2343	Economy	61500.00
0005433754748	2343	Economy	61500.00
0005433754721	2343	Economy	61500.00
0005432985149	2343	Economy	61500.00
0005435982719	2343	Economy	61500.00
0005433434801	2343	Economy	61500.00
0005434731177	2343	Economy	61500.00
0005432985030	2343	Economy	61500.00
0005433754773	2343	Economy	61500.00
0005435982741	2343	Economy	61500.00
0005432985091	2343	Economy	61500.00
0005432985029	2343	Economy	61500.00
0005433754731	2343	Economy	61500.00
0005433754766	2343	Economy	61500.00
0005433754730	2343	Economy	61500.00
0005433754760	2343	Economy	61500.00
0005432655654	2343	Economy	61500.00
0005433434780	2343	Economy	61500.00
0005432869538	2343	Economy	61500.00
0005435982736	2343	Economy	61500.00
0005432985139	2343	Economy	61500.00
0005433754738	2343	Economy	61500.00
0005435982733	2343	Economy	61500.00
0005435982723	2343	Economy	61500.00
0005435982718	2343	Economy	61500.00
0005432869549	2343	Economy	61500.00
0005435982717	2343	Economy	61500.00
0005435982724	2343	Economy	61500.00
0005433434696	2343	Economy	61500.00
0005435982735	2343	Economy	61500.00
0005432300316	2343	Economy	61500.00
0005432869532	2343	Economy	61500.00
0005433754737	2343	Economy	61500.00
0005433434689	2343	Economy	61500.00
0005433754724	2343	Economy	61500.00
0005432655652	2343	Economy	61500.00
0005433766675	2343	Economy	61500.00
0005433766674	2343	Economy	61500.00
0005433754745	2343	Economy	61500.00
0005433754753	2343	Economy	61500.00
0005433434661	2343	Economy	61500.00
0005433754143	26202	Business	184500.00
0005435982386	26202	Business	184500.00
0005433754415	26202	Business	184500.00
0005435982210	26202	Business	184500.00
0005435982438	26202	Business	184500.00
0005433764673	26202	Business	184500.00
0005435982436	26202	Business	184500.00
0005433764677	26202	Business	184500.00
0005435982119	26202	Business	184500.00
0005433754424	26202	Business	184500.00
0005435982160	26202	Business	184500.00
0005433754377	26202	Business	184500.00
0005435982304	26202	Business	184500.00
0005435982202	26202	Business	184500.00
0005433754329	26202	Business	184500.00
0005432869586	26202	Business	184500.00
0005432985364	26202	Business	184500.00
0005432985392	26202	Business	184500.00
0005433434932	26202	Business	184500.00
0005432985374	26202	Business	184500.00
0005433754280	26202	Business	184500.00
0005433764671	26202	Business	184500.00
0005435982385	26202	Business	184500.00
0005435982244	26202	Business	184500.00
0005433434954	26202	Business	184500.00
0005433754467	26202	Business	184500.00
0005432985367	26202	Economy	67700.00
0005433754262	26202	Economy	67700.00
0005432869585	26202	Economy	67700.00
0005435982263	26202	Economy	67700.00
0005432869584	26202	Economy	61500.00
0005433434952	26202	Economy	61500.00
0005433434940	26202	Economy	61500.00
0005433754277	26202	Economy	61500.00
0005432051158	26202	Economy	61500.00
0005433766625	26202	Economy	61500.00
0005433754372	26202	Economy	61500.00
0005432985378	26202	Economy	61500.00
0005433753750	26202	Economy	61500.00
0005433434941	26202	Economy	61500.00
0005433754320	26202	Economy	61500.00
0005433754314	26202	Economy	61500.00
0005435982060	26202	Economy	61500.00
0005432985383	26202	Economy	61500.00
0005433754166	26202	Economy	61500.00
0005432985395	26202	Economy	61500.00
0005432655465	26202	Economy	61500.00
0005433434953	26202	Economy	61500.00
0005432985380	26202	Economy	61500.00
0005435982224	26202	Economy	61500.00
0005432985365	26202	Economy	61500.00
0005433754214	26202	Economy	61500.00
0005432049497	26202	Economy	61500.00
0005435982203	26202	Economy	61500.00
0005432985382	26202	Economy	61500.00
0005435982200	26202	Economy	61500.00
0005432985376	26202	Economy	61500.00
0005435982220	26202	Economy	61500.00
0005434731209	26202	Economy	61500.00
0005432655547	26202	Economy	61500.00
0005433754193	26202	Economy	61500.00
0005435982341	26202	Economy	61500.00
0005435982444	26202	Economy	61500.00
0005433434943	26202	Economy	61500.00
0005435982347	26202	Economy	61500.00
0005433754404	26202	Economy	61500.00
0005435982374	26202	Economy	61500.00
0005433754414	26202	Economy	61500.00
0005433434945	26202	Economy	61500.00
0005435982180	26202	Economy	61500.00
0005435982298	26202	Economy	61500.00
0005435982348	26202	Economy	61500.00
0005432985391	26202	Economy	61500.00
0005433764682	26202	Economy	61500.00
0005433434939	26202	Economy	61500.00
0005435982249	26202	Economy	61500.00
0005432985381	26202	Economy	61500.00
0005433434934	26202	Economy	61500.00
0005433434948	26202	Economy	61500.00
0005435982317	26202	Economy	61500.00
0005435982434	26202	Economy	61500.00
0005435982250	26202	Economy	61500.00
0005433754167	26202	Economy	61500.00
0005433754319	26202	Economy	61500.00
0005432985384	26202	Economy	61500.00
0005434731212	26202	Economy	61500.00
0005432985379	26202	Economy	61500.00
0005433766650	26202	Economy	61500.00
0005433434949	26202	Economy	61500.00
0005433434944	26202	Economy	61500.00
0005432985389	26202	Economy	61500.00
0005433434931	26202	Economy	61500.00
0005433434950	26202	Economy	61500.00
0005432985388	26202	Economy	61500.00
0005435982143	26202	Economy	61500.00
0005435982219	26202	Economy	61500.00
0005433754417	26202	Economy	61500.00
0005433434957	26202	Economy	61500.00
0005435982318	26202	Economy	61500.00
0005432869582	26202	Economy	61500.00
0005432985390	26202	Economy	61500.00
0005432985368	26202	Economy	61500.00
0005432655565	26202	Economy	61500.00
0005433754297	26202	Economy	61500.00
0005433753952	26202	Economy	61500.00
0005435982299	26202	Economy	61500.00
0005432985371	26202	Economy	61500.00
0005435982277	26202	Economy	61500.00
0005433754587	26202	Economy	61500.00
0005435982292	26202	Economy	61500.00
0005432869587	26202	Economy	61500.00
0005435982319	26202	Economy	61500.00
0005432985386	26202	Economy	61500.00
0005433754413	26202	Economy	61500.00
0005432985385	26202	Economy	61500.00
0005435982201	26202	Economy	61500.00
0005433754249	26202	Economy	61500.00
0005435982209	26202	Economy	61500.00
0005433754039	26202	Economy	61500.00
0005432869588	26202	Economy	61500.00
0005432655466	26202	Economy	67700.00
0005432985369	26202	Economy	61500.00
0005433754410	26202	Economy	61500.00
0005432655471	26202	Economy	61500.00
0005432985372	26202	Economy	67700.00
0005433434951	26202	Economy	67700.00
0005432869581	26202	Economy	61500.00
0005435982139	26202	Economy	61500.00
0005433764672	26202	Economy	61500.00
0005435982150	26202	Economy	61500.00
0005435982199	26202	Economy	61500.00
0005433764681	26202	Economy	61500.00
0005435982419	26202	Economy	61500.00
0005433754208	26202	Economy	61500.00
0005433753886	26202	Economy	61500.00
0005433754243	26202	Economy	61500.00
0005435982375	26202	Economy	61500.00
0005432985370	26202	Economy	61500.00
0005433754307	26202	Economy	61500.00
0005433754115	26202	Economy	61500.00
0005432985363	26202	Economy	61500.00
0005433754533	26202	Economy	61500.00
0005434731208	26202	Economy	61500.00
0005433754318	26202	Economy	61500.00
0005433434930	26202	Economy	61500.00
0005433754175	26202	Economy	61500.00
0005435982106	26202	Economy	61500.00
0005433753953	26202	Economy	61500.00
0005432051156	26202	Economy	61500.00
0005433754165	26202	Economy	61500.00
0005432051157	26202	Economy	61500.00
0005433434936	26202	Economy	61500.00
0005433434947	26202	Economy	61500.00
0005433434937	26202	Economy	61500.00
0005433754161	26202	Economy	61500.00
0005435982437	26202	Economy	61500.00
0005433764683	26202	Economy	61500.00
0005435982290	26202	Economy	61500.00
0005432869583	26202	Economy	61500.00
0005432655494	26202	Economy	61500.00
0005435982303	26202	Economy	61500.00
0005432985377	26202	Economy	61500.00
0005433434938	26202	Economy	61500.00
0005433434933	26202	Economy	61500.00
0005435982445	26202	Economy	61500.00
0005433434956	26202	Economy	61500.00
0005433754174	26202	Economy	61500.00
0005433754142	26202	Economy	61500.00
0005433754225	26202	Economy	61500.00
0005432869580	26202	Economy	61500.00
0005433766652	26202	Economy	61500.00
0005433754468	26202	Economy	61500.00
0005433434929	26202	Economy	61500.00
0005433434955	26202	Economy	61500.00
0005432985387	26202	Economy	61500.00
0005433754296	26202	Economy	61500.00
0005435982216	26202	Economy	61500.00
0005433434946	26202	Economy	61500.00
0005432985375	26202	Economy	61500.00
0005434731211	26202	Economy	61500.00
0005433766651	26202	Economy	61500.00
0005433434935	26202	Economy	61500.00
0005432985393	26202	Economy	61500.00
0005432985394	26202	Economy	61500.00
0005432985373	26202	Economy	61500.00
0005433434942	26202	Economy	61500.00
0005433754308	26202	Economy	61500.00
0005435982142	26202	Economy	61500.00
0005432985366	26202	Economy	61500.00
0005434731210	26202	Economy	61500.00
0005433764684	26202	Economy	61500.00
0005435982316	26202	Economy	61500.00
0005432655451	26202	Economy	61500.00
0005435982354	26202	Economy	61500.00
0005435982355	26202	Economy	61500.00
0005432049498	26202	Economy	61500.00
0005435982141	26202	Economy	61500.00
0005433754229	26202	Economy	61500.00
0005434375066	1512	Business	38900.00
0005434375069	1512	Business	38900.00
0005433151370	1512	Business	38900.00
0005433931470	1512	Business	38900.00
0005434375081	1512	Business	38900.00
0005434375072	1512	Business	38900.00
0005434375080	1512	Business	38900.00
0005433151600	1512	Business	38900.00
0005433151449	1512	Business	38900.00
0005434375084	1512	Business	38900.00
0005434375095	1512	Economy	13000.00
0005433151491	1512	Economy	13000.00
0005434375101	1512	Economy	13000.00
0005434375071	1512	Economy	13000.00
0005432267956	1512	Economy	13000.00
0005434375100	1512	Economy	13000.00
0005434375089	1512	Economy	13000.00
0005433460455	1512	Economy	13000.00
0005433151497	1512	Economy	13000.00
0005434375091	1512	Economy	13000.00
0005433461607	1512	Economy	13000.00
0005433931463	1512	Economy	13000.00
0005434375078	1512	Economy	13000.00
0005433151454	1512	Economy	13000.00
0005434375104	1512	Economy	13000.00
0005433151584	1512	Economy	13000.00
0005433460457	1512	Economy	13000.00
0005434375090	1512	Economy	13000.00
0005433460456	1512	Economy	13000.00
0005434375073	1512	Economy	13000.00
0005433151313	1512	Economy	13000.00
0005433151443	1512	Economy	13000.00
0005434375087	1512	Economy	13000.00
0005433151368	1512	Economy	13000.00
0005433151498	1512	Economy	13000.00
0005434375068	1512	Economy	13000.00
0005434375103	1512	Economy	14300.00
0005434375067	1512	Economy	14300.00
0005433151426	1512	Economy	14300.00
0005434375063	1512	Economy	14300.00
0005433151356	1512	Economy	14300.00
0005434375096	1512	Economy	14300.00
0005432267959	1512	Economy	13000.00
0005433460458	1512	Economy	13000.00
0005433151466	1512	Economy	13000.00
0005433151444	1512	Economy	13000.00
0005434375107	1512	Economy	13000.00
0005433151453	1512	Economy	13000.00
0005434375102	1512	Economy	13000.00
0005432267955	1512	Economy	13000.00
0005434375097	1512	Economy	13000.00
0005433931471	1512	Economy	13000.00
0005433151355	1512	Economy	13000.00
0005433151427	1512	Economy	13000.00
0005433151599	1512	Economy	13000.00
0005434375070	1512	Economy	13000.00
0005434375112	1512	Economy	13000.00
0005434375106	1512	Economy	13000.00
0005434375093	1512	Economy	13000.00
0005433151591	1512	Economy	13000.00
0005434375094	1512	Economy	13000.00
0005434375085	1512	Economy	13000.00
0005434375113	1512	Economy	13000.00
0005432267958	1512	Economy	13000.00
0005433151408	1512	Economy	13000.00
0005433151406	1512	Economy	13000.00
0005434375088	1512	Economy	13000.00
0005433151402	1512	Economy	13000.00
0005433461608	1512	Economy	13000.00
0005434375105	1512	Economy	13000.00
0005434375110	1512	Economy	13000.00
0005434375086	1512	Economy	13000.00
0005433151509	1512	Economy	13000.00
0005433461609	1512	Economy	13000.00
0005432267960	1512	Economy	13000.00
0005433151487	1512	Economy	13000.00
0005433151524	1512	Economy	13000.00
0005434375074	1512	Economy	13000.00
0005434375109	1512	Economy	13000.00
0005433931466	1512	Economy	13000.00
0005433151523	1512	Economy	13000.00
0005433151371	1512	Economy	13000.00
0005434375108	1512	Economy	13000.00
0005433151515	1512	Economy	13000.00
0005434375098	1512	Economy	13000.00
0005433151352	1512	Economy	13000.00
0005432267957	1512	Economy	13000.00
0005433931465	1512	Economy	13000.00
0005433151601	1512	Economy	13000.00
0005434375077	1512	Economy	13000.00
0005434375076	1512	Economy	13000.00
0005434375082	1512	Economy	13000.00
0005434375083	1512	Economy	13000.00
0005434375075	1512	Economy	13000.00
0005434375092	1512	Economy	13000.00
0005433151383	1512	Economy	13000.00
0005434375065	1512	Economy	13000.00
0005433151181	1512	Economy	13000.00
0005433151369	1512	Economy	13000.00
0005434375111	1512	Economy	13000.00
0005434375099	1512	Economy	13000.00
0005434375064	1512	Economy	13000.00
0005434375079	1512	Economy	13000.00
0005433151496	1512	Economy	13000.00
0005433151713	20148	Business	38900.00
0005433151734	20148	Business	38900.00
0005434374630	20148	Business	38900.00
0005433461579	20148	Business	38900.00
0005432056334	20148	Business	38900.00
0005434374596	20148	Business	38900.00
0005433931494	20148	Business	38900.00
0005432056332	20148	Business	38900.00
0005433151712	20148	Business	38900.00
0005433463886	20148	Business	38900.00
0005433463879	20148	Business	38900.00
0005433151727	20148	Economy	13000.00
0005434374572	20148	Economy	13000.00
0005433151741	20148	Economy	13000.00
0005433151720	20148	Economy	13000.00
0005433151710	20148	Economy	13000.00
0005433463867	20148	Economy	13000.00
0005433151738	20148	Economy	13000.00
0005433461578	20148	Economy	13000.00
0005434374632	20148	Economy	13000.00
0005434374460	20148	Economy	13000.00
0005434374520	20148	Economy	13000.00
0005433463882	20148	Economy	13000.00
0005433151714	20148	Economy	13000.00
0005433151740	20148	Economy	13000.00
0005433461555	20148	Economy	13000.00
0005433151715	20148	Economy	13000.00
0005434029681	20148	Economy	13000.00
0005433764699	20148	Economy	13000.00
0005434374617	20148	Economy	13000.00
0005433931493	20148	Economy	13000.00
0005433151722	20148	Economy	13000.00
0005433151724	20148	Economy	13000.00
0005433151717	20148	Economy	13000.00
0005433463889	20148	Economy	13000.00
0005433151735	20148	Economy	13000.00
0005434374461	20148	Economy	13000.00
0005433151737	20148	Economy	13000.00
0005433463872	20148	Economy	13000.00
0005432056336	20148	Economy	13000.00
0005433151733	20148	Economy	13000.00
0005434374398	20148	Economy	13000.00
0005433461574	20148	Economy	14300.00
0005433151730	20148	Economy	14300.00
0005434374397	20148	Economy	14300.00
0005434374603	20148	Economy	14300.00
0005434374635	20148	Economy	14300.00
0005434374597	20148	Economy	13000.00
0005433151743	20148	Economy	13000.00
0005433151726	20148	Economy	13000.00
0005433461565	20148	Economy	13000.00
0005434374559	20148	Economy	13000.00
0005433463892	20148	Economy	13000.00
0005433463890	20148	Economy	13000.00
0005433461577	20148	Economy	13000.00
0005433463887	20148	Economy	13000.00
0005433151716	20148	Economy	13000.00
0005433463880	20148	Economy	13000.00
0005433151708	20148	Economy	13000.00
0005433463893	20148	Economy	13000.00
0005433461591	20148	Economy	13000.00
0005433151742	20148	Economy	13000.00
0005433461575	20148	Economy	13000.00
0005434374634	20148	Economy	13000.00
0005433461570	20148	Economy	13000.00
0005433151736	20148	Economy	13000.00
0005433463883	20148	Economy	13000.00
0005433463881	20148	Economy	13000.00
0005433151721	20148	Economy	13000.00
0005433151719	20148	Economy	13000.00
0005433151739	20148	Economy	13000.00
0005433463888	20148	Economy	13000.00
0005434029680	20148	Economy	13000.00
0005433151732	20148	Economy	13000.00
0005434374462	20148	Economy	13000.00
0005433461573	20148	Economy	13000.00
0005432056335	20148	Economy	13000.00
0005433463884	20148	Economy	13000.00
0005434374631	20148	Economy	13000.00
0005434029679	20148	Economy	13000.00
0005433151709	20148	Economy	13000.00
0005433151731	20148	Economy	13000.00
0005434374600	20148	Economy	13000.00
0005433461576	20148	Economy	13000.00
0005433151718	20148	Economy	13000.00
0005433151729	20148	Economy	13000.00
0005433463894	20148	Economy	13000.00
0005433461566	20148	Economy	13000.00
0005433461569	20148	Economy	13000.00
0005433151711	20148	Economy	13000.00
0005432056333	20148	Economy	13000.00
0005433764700	20148	Economy	13000.00
0005433463885	20148	Economy	13000.00
0005434374521	20148	Economy	13000.00
0005433461572	20148	Economy	13000.00
0005433461583	20148	Economy	13000.00
0005433461567	20148	Economy	13000.00
0005433461584	20148	Economy	13000.00
0005433151723	20148	Economy	13000.00
0005433151725	20148	Economy	13000.00
0005433461571	20148	Economy	13000.00
0005433461568	20148	Economy	13000.00
0005433931495	20148	Economy	13000.00
0005433461592	20148	Economy	13000.00
0005433151728	20148	Economy	13000.00
0005433463891	20148	Economy	13000.00
0005432424871	570	Business	27500.00
0005432282930	570	Business	27500.00
0005432424875	570	Business	27500.00
0005432424893	570	Business	27500.00
0005432424903	570	Business	27500.00
0005432424870	570	Business	27500.00
0005432424881	570	Business	27500.00
0005432424880	570	Business	27500.00
0005432424879	570	Business	27500.00
0005432282933	570	Economy	10100.00
0005432424897	570	Economy	10100.00
0005432424890	570	Economy	10100.00
0005432424884	570	Economy	10100.00
0005432424906	570	Economy	9200.00
0005432424914	570	Economy	9200.00
0005432424902	570	Economy	9200.00
0005432424867	570	Economy	9200.00
0005432282928	570	Economy	9200.00
0005432424889	570	Economy	9200.00
0005432424900	570	Economy	9200.00
0005432424901	570	Economy	9200.00
0005432282926	570	Economy	9200.00
0005432424907	570	Economy	9200.00
0005432424886	570	Economy	9200.00
0005432424883	570	Economy	9200.00
0005432424908	570	Economy	9200.00
0005432424872	570	Economy	9200.00
0005432424888	570	Economy	9200.00
0005432424913	570	Economy	9200.00
0005432424898	570	Economy	9200.00
0005432282932	570	Economy	9200.00
0005432424910	570	Economy	9200.00
0005432424866	570	Economy	9200.00
0005432424891	570	Economy	9200.00
0005432424899	570	Economy	9200.00
0005432424869	570	Economy	9200.00
0005432282929	570	Economy	9200.00
0005432424873	570	Economy	10100.00
0005432424864	570	Economy	10100.00
0005432424876	570	Economy	9200.00
0005432424874	570	Economy	9200.00
0005432424877	570	Economy	9200.00
0005432424894	570	Economy	9200.00
0005432424865	570	Economy	9200.00
0005432424895	570	Economy	9200.00
0005432424912	570	Economy	9200.00
0005432424911	570	Economy	9200.00
0005432424878	570	Economy	9200.00
0005432424887	570	Economy	9200.00
0005432424892	570	Economy	9200.00
0005432424904	570	Economy	9200.00
0005432424868	570	Economy	9200.00
0005432424885	570	Economy	9200.00
0005432424909	570	Economy	9200.00
0005432424882	570	Economy	9200.00
0005432282927	570	Economy	9200.00
0005432424905	570	Economy	9200.00
0005432424896	570	Economy	9200.00
0005432282931	570	Economy	9200.00
0005432302366	12863	Economy	9200.00
0005432302367	12863	Economy	9200.00
0005432424428	12844	Business	27500.00
0005432424417	12844	Business	27500.00
0005432424438	12844	Business	27500.00
0005432424420	12844	Business	27500.00
0005432424232	12844	Business	27500.00
0005432424397	12844	Business	27500.00
0005432424332	12844	Business	27500.00
0005432424432	12844	Economy	10100.00
0005432424460	12844	Economy	10100.00
0005432424455	12844	Economy	9200.00
0005432424398	12844	Economy	9200.00
0005432424431	12844	Economy	9200.00
0005432424454	12844	Economy	9200.00
0005432424144	12844	Economy	9200.00
0005432424419	12844	Economy	9200.00
0005432424277	12844	Economy	9200.00
0005432424440	12844	Economy	9200.00
0005432424315	12844	Economy	9200.00
0005432424390	12844	Economy	9200.00
0005432424331	12844	Economy	9200.00
0005432424391	12844	Economy	9200.00
0005432424366	12844	Economy	9200.00
0005432424392	12844	Economy	9200.00
0005432424416	12844	Economy	9200.00
0005432424308	12844	Economy	9200.00
0005432424412	12844	Economy	9200.00
0005432424418	12844	Economy	9200.00
0005432424451	12844	Economy	9200.00
0005432424320	12844	Economy	9200.00
0005432424145	12844	Economy	9200.00
0005432424396	12844	Economy	9200.00
0005432424387	12844	Economy	9200.00
0005432424401	12844	Economy	9200.00
0005432424380	12844	Economy	9200.00
0005432424402	12844	Economy	9200.00
0005432424421	12844	Economy	9200.00
0005432424335	12844	Economy	9200.00
0005432424318	12844	Economy	9200.00
0005434024307	458	Business	24500.00
0005432235708	458	Business	24500.00
0005434024371	458	Business	24500.00
0005433058014	458	Business	24500.00
0005434024338	458	Business	24500.00
0005434024316	458	Business	24500.00
0005434024342	458	Business	24500.00
0005434024329	458	Business	24500.00
0005434024360	458	Business	24500.00
0005433057853	458	Business	24500.00
0005434024349	458	Business	24500.00
0005434024322	458	Business	24500.00
0005434024312	458	Business	24500.00
0005434024373	458	Business	24500.00
0005434024343	458	Business	24500.00
0005434024305	458	Business	24500.00
0005432235704	458	Business	24500.00
0005434024321	458	Business	24500.00
0005434024347	458	Business	24500.00
0005433057854	458	Business	24500.00
0005434024336	458	Business	24500.00
0005434024351	458	Business	24500.00
0005434024334	458	Business	24500.00
0005434024314	458	Economy	9000.00
0005433057833	458	Economy	9000.00
0005434024319	458	Economy	8200.00
0005434024348	458	Economy	8200.00
0005433058046	458	Economy	8200.00
0005434024326	458	Economy	8200.00
0005434024323	458	Economy	8200.00
0005433058089	458	Economy	8200.00
0005434029676	458	Economy	8200.00
0005434024327	458	Economy	8200.00
0005434024358	458	Economy	8200.00
0005432235709	458	Economy	8200.00
0005434376223	458	Economy	8200.00
0005433057746	458	Economy	8200.00
0005433684415	458	Economy	8200.00
0005433057915	458	Economy	8200.00
0005433057998	458	Economy	8200.00
0005434024369	458	Economy	8200.00
0005434024353	458	Economy	8200.00
0005434024335	458	Economy	8200.00
0005433057914	458	Economy	8200.00
0005434024317	458	Economy	8200.00
0005433057970	458	Economy	8200.00
0005434024365	458	Economy	8200.00
0005433058099	458	Economy	8200.00
0005434024332	458	Economy	8200.00
0005433929627	458	Economy	8200.00
0005434024363	458	Economy	8200.00
0005434028320	458	Economy	8200.00
0005433929601	458	Economy	8200.00
0005433057916	458	Economy	8200.00
0005433058021	458	Economy	8200.00
0005434032062	458	Economy	8200.00
0005434024339	458	Economy	8200.00
0005433058015	458	Economy	8200.00
0005434024311	458	Economy	8200.00
0005433058067	458	Economy	8200.00
0005434735670	458	Economy	8200.00
0005434024340	458	Economy	8200.00
0005433057745	458	Economy	8200.00
0005433057873	458	Economy	8200.00
0005434735669	458	Economy	8200.00
0005433058017	458	Economy	8200.00
0005433057834	458	Economy	8200.00
0005434024333	458	Economy	8200.00
0005433057887	458	Economy	8200.00
0005433057934	458	Economy	8200.00
0005434024366	458	Economy	8200.00
0005433057943	458	Economy	8200.00
0005433057999	458	Economy	8200.00
0005433057874	458	Economy	8200.00
0005433929628	458	Economy	8200.00
0005434024341	458	Economy	8200.00
0005433057855	458	Economy	8200.00
0005433684419	458	Economy	8200.00
0005434024328	458	Economy	8200.00
0005434024304	458	Economy	8200.00
0005432235706	458	Economy	8200.00
0005433684423	458	Economy	8200.00
0005434024364	458	Economy	8200.00
0005434024325	458	Economy	8200.00
0005434028319	458	Economy	8200.00
0005434028321	458	Economy	8200.00
0005433058095	458	Economy	8200.00
0005432235705	458	Economy	9000.00
0005433058018	458	Economy	9000.00
0005434024306	458	Economy	8200.00
0005434024310	458	Economy	8200.00
0005434024318	458	Economy	9000.00
0005434032064	458	Economy	8200.00
0005434024372	458	Economy	8200.00
0005434024313	458	Economy	8200.00
0005434735680	458	Economy	8200.00
0005432235711	458	Economy	8200.00
0005434029678	458	Economy	8200.00
0005434024368	458	Economy	8200.00
0005432235710	458	Economy	8200.00
0005433057917	458	Economy	8200.00
0005433057942	458	Economy	8200.00
0005433057953	458	Economy	8200.00
0005434024359	458	Economy	8200.00
0005434032065	458	Economy	8200.00
0005434024344	458	Economy	8200.00
0005434735662	458	Economy	8200.00
0005432045630	458	Economy	8200.00
0005434024324	458	Economy	8200.00
0005432235707	458	Economy	8200.00
0005434024331	458	Economy	8200.00
0005433057761	458	Economy	8200.00
0005434024352	458	Economy	8200.00
0005434032063	458	Economy	8200.00
0005434029677	458	Economy	8200.00
0005433058047	458	Economy	8200.00
0005434024357	458	Economy	8200.00
0005434024354	458	Economy	8200.00
0005434024361	458	Economy	8200.00
0005434024346	458	Economy	8200.00
0005433058121	458	Economy	8200.00
0005434024345	458	Economy	8200.00
0005434024355	458	Economy	8200.00
0005433057886	458	Economy	8200.00
0005434032061	458	Economy	8200.00
0005434028318	458	Economy	8200.00
0005433058114	458	Economy	8200.00
0005433057809	458	Economy	8200.00
0005434735661	458	Economy	8200.00
0005433929626	458	Economy	8200.00
0005434024370	458	Economy	8200.00
0005434024350	458	Economy	8200.00
0005434024367	458	Economy	8200.00
0005434024362	458	Economy	8200.00
0005433058066	458	Economy	8200.00
0005433058045	458	Economy	8200.00
0005434024309	458	Economy	8200.00
0005434024315	458	Economy	8200.00
0005433684431	458	Economy	8200.00
0005433058074	458	Economy	8200.00
0005434024337	458	Economy	8200.00
0005433058115	458	Economy	8200.00
0005434024320	458	Economy	8200.00
0005434376224	458	Economy	8200.00
0005433684420	458	Economy	8200.00
0005434024308	458	Economy	8200.00
0005434024356	458	Economy	8200.00
0005434024330	458	Economy	8200.00
0005433058246	12676	Business	24500.00
0005433058244	12676	Business	24500.00
0005434023596	12676	Business	24500.00
0005434023883	12676	Business	24500.00
0005433929653	12676	Business	24500.00
0005433058269	12676	Business	24500.00
0005434023847	12676	Business	24500.00
0005434024062	12676	Business	24500.00
0005432156407	12676	Business	24500.00
0005433058261	12676	Business	24500.00
0005434023871	12676	Business	24500.00
0005434023843	12676	Business	24500.00
0005434023725	12676	Business	24500.00
0005434023685	12676	Business	24500.00
0005434023793	12676	Business	24500.00
0005433058250	12676	Business	24500.00
0005434023788	12676	Business	24500.00
0005434023650	12676	Business	24500.00
0005433929649	12676	Business	24500.00
0005434735741	12676	Business	24500.00
0005432156405	12676	Economy	9000.00
0005433058256	12676	Economy	9000.00
0005434735740	12676	Economy	8200.00
0005433058236	12676	Economy	8200.00
0005434023700	12676	Economy	8200.00
0005433058273	12676	Economy	8200.00
0005434023777	12676	Economy	8200.00
0005433058247	12676	Economy	8200.00
0005434032034	12676	Economy	8200.00
0005433058259	12676	Economy	8200.00
0005434023419	12676	Economy	8200.00
0005434023965	12676	Economy	8200.00
0005433058248	12676	Economy	8200.00
0005434023689	12676	Economy	8200.00
0005434023726	12676	Economy	8200.00
0005433058254	12676	Economy	8200.00
0005432157510	12676	Economy	8200.00
0005434023741	12676	Economy	8200.00
0005434023874	12676	Economy	8200.00
0005434032035	12676	Economy	8200.00
0005434023624	12676	Economy	8200.00
0005433929652	12676	Economy	8200.00
0005434024021	12676	Economy	8200.00
0005433929651	12676	Economy	8200.00
0005432156409	12676	Economy	8200.00
0005434023936	12676	Economy	8200.00
0005434023542	12676	Economy	8200.00
0005433058242	12676	Economy	8200.00
0005433058243	12676	Economy	8200.00
0005434023628	12676	Economy	8200.00
0005434023957	12676	Economy	8200.00
0005434023679	12676	Economy	8200.00
0005433058260	12676	Economy	8200.00
0005434028288	12676	Economy	8200.00
0005434023824	12676	Economy	8200.00
0005434023718	12676	Economy	8200.00
0005433058252	12676	Economy	8200.00
0005433058264	12676	Economy	8200.00
0005434023880	12676	Economy	8200.00
0005434023928	12676	Economy	8200.00
0005434023937	12676	Economy	8200.00
0005434023724	12676	Economy	8200.00
0005434024063	12676	Economy	8200.00
0005434023512	12676	Economy	8200.00
0005434023714	12676	Economy	8200.00
0005433058267	12676	Economy	8200.00
0005433058265	12676	Economy	8200.00
0005433684440	12676	Economy	8200.00
0005434032039	12676	Economy	8200.00
0005434023956	12676	Economy	8200.00
0005433058270	12676	Economy	8200.00
0005433058258	12676	Economy	8200.00
0005433058276	12676	Economy	8200.00
0005433058253	12676	Economy	8200.00
0005433058275	12676	Economy	8200.00
0005434023713	12676	Economy	8200.00
0005433058249	12676	Economy	8200.00
0005434024083	12676	Economy	8200.00
0005433058251	12676	Economy	8200.00
0005434023828	12676	Economy	8200.00
0005434032020	12676	Economy	8200.00
0005434023723	12676	Economy	8200.00
0005434023831	12676	Economy	8200.00
0005434032038	12676	Economy	8200.00
0005434023552	12676	Economy	8200.00
0005434023833	12676	Economy	8200.00
0005433058240	12676	Economy	8200.00
0005434023821	12676	Economy	8200.00
0005434023918	12676	Economy	8200.00
0005434023387	12676	Economy	8200.00
0005433058255	12676	Economy	8200.00
0005434023794	12676	Economy	8200.00
0005434023553	12676	Economy	8200.00
0005433058262	12676	Economy	8200.00
0005433929650	12676	Economy	8200.00
0005434023677	12676	Economy	8200.00
0005434024020	12676	Economy	8200.00
0005433058241	12676	Economy	8200.00
0005432157509	12676	Economy	8200.00
0005434023678	12676	Economy	9000.00
0005434023844	12676	Economy	8200.00
0005433684439	12676	Economy	8200.00
0005433058271	12676	Economy	8200.00
0005433058263	12676	Economy	8200.00
0005434023921	12676	Economy	8200.00
0005434024071	12676	Economy	8200.00
0005433058266	12676	Economy	8200.00
0005433684441	12676	Economy	8200.00
0005434032021	12676	Economy	8200.00
0005434023917	12676	Economy	8200.00
0005433058238	12676	Economy	8200.00
0005434023688	12676	Economy	8200.00
0005433058257	12676	Economy	8200.00
0005434023887	12676	Economy	8200.00
0005434023929	12676	Economy	8200.00
0005434023731	12676	Economy	8200.00
0005432156408	12676	Economy	8200.00
0005434024089	12676	Economy	8200.00
0005434023717	12676	Economy	8200.00
0005434023800	12676	Economy	8200.00
0005434023927	12676	Economy	8200.00
0005434023701	12676	Economy	8200.00
0005433058274	12676	Economy	8200.00
0005434023647	12676	Economy	8200.00
0005433058237	12676	Economy	8200.00
0005434023942	12676	Economy	8200.00
0005434024022	12676	Economy	8200.00
0005434023690	12676	Economy	8200.00
0005434023848	12676	Economy	8200.00
0005434023849	12676	Economy	8200.00
0005434024044	12676	Economy	8200.00
0005434032028	12676	Economy	8200.00
0005434735737	12676	Economy	8200.00
0005434023819	12676	Economy	8200.00
0005434023648	12676	Economy	8200.00
0005434028297	12676	Economy	8200.00
0005434023902	12676	Economy	8200.00
0005434023966	12676	Economy	8200.00
0005434032019	12676	Economy	8200.00
0005432156406	12676	Economy	8200.00
0005434023783	12676	Economy	8200.00
0005434023955	12676	Economy	8200.00
0005434024061	12676	Economy	8200.00
0005433058239	12676	Economy	8200.00
0005434735738	12676	Economy	8200.00
0005434023730	12676	Economy	8200.00
0005434023825	12676	Economy	8200.00
0005434023581	12676	Economy	8200.00
0005434023943	12676	Economy	8200.00
0005434023935	12676	Economy	8200.00
0005434735736	12676	Economy	8200.00
0005434735739	12676	Economy	8200.00
0005434023422	12676	Economy	8200.00
0005434023799	12676	Economy	8200.00
0005434023810	12676	Economy	8200.00
0005433058268	12676	Economy	8200.00
0005434024070	12676	Economy	8200.00
0005433058272	12676	Economy	8200.00
0005434023827	12676	Economy	8200.00
0005433058245	12676	Economy	8200.00
0005433036233	2124	Business	34700.00
0005433036418	2124	Business	34700.00
0005433924185	2124	Business	34700.00
0005433929653	2124	Business	34700.00
0005433924144	2124	Business	34700.00
0005433924188	2124	Business	34700.00
0005433929650	2124	Business	34700.00
0005433924226	2124	Business	34700.00
0005433924174	2124	Business	34700.00
0005433924165	2124	Business	34700.00
0005433036214	2124	Business	34700.00
0005433924171	2124	Business	34700.00
0005433924146	2124	Business	34700.00
0005433924152	2124	Business	34700.00
0005433924193	2124	Business	34700.00
0005433036256	2124	Business	34700.00
0005433924147	2124	Business	34700.00
0005433036401	2124	Business	34700.00
0005433036235	2124	Business	34700.00
0005433924169	2124	Business	34700.00
0005433924218	2124	Economy	12700.00
0005432749781	2124	Economy	12700.00
0005433924160	2124	Economy	12700.00
0005433036435	2124	Economy	11600.00
0005433036225	2124	Economy	11600.00
0005433036408	2124	Economy	11600.00
0005432231664	2124	Economy	11600.00
0005433036251	2124	Economy	11600.00
0005433036227	2124	Economy	11600.00
0005433036517	2124	Economy	11600.00
0005433036198	2124	Economy	11600.00
0005433924234	2124	Economy	11600.00
0005433924198	2124	Economy	11600.00
0005433924145	2124	Economy	11600.00
0005433924183	2124	Economy	11600.00
0005433036011	2124	Economy	11600.00
0005433924217	2124	Economy	11600.00
0005433924192	2124	Economy	11600.00
0005433924194	2124	Economy	11600.00
0005433036582	2124	Economy	11600.00
0005433924227	2124	Economy	11600.00
0005433036462	2124	Economy	11600.00
0005433036386	2124	Economy	11600.00
0005433924233	2124	Economy	11600.00
0005433924204	2124	Economy	11600.00
0005433035956	2124	Economy	11600.00
0005433924161	2124	Economy	11600.00
0005434028297	2124	Economy	11600.00
0005433931494	2124	Economy	11600.00
0005433924213	2124	Economy	11600.00
0005433924210	2124	Economy	11600.00
0005433924207	2124	Economy	11600.00
0005433924200	2124	Economy	11600.00
0005433036400	2124	Economy	11600.00
0005433924182	2124	Economy	11600.00
0005433036536	2124	Economy	11600.00
0005433924221	2124	Economy	11600.00
0005433924167	2124	Economy	11600.00
0005432749775	2124	Economy	11600.00
0005433924187	2124	Economy	11600.00
0005433924143	2124	Economy	11600.00
0005432231658	2124	Economy	11600.00
0005433924219	2124	Economy	11600.00
0005433924199	2124	Economy	11600.00
0005433924179	2124	Economy	11600.00
0005433924229	2124	Economy	11600.00
0005433924238	2124	Economy	11600.00
0005433924225	2124	Economy	11600.00
0005433929651	2124	Economy	11600.00
0005433036258	2124	Economy	11600.00
0005433036285	2124	Economy	11600.00
0005432231661	2124	Economy	11600.00
0005433924191	2124	Economy	11600.00
0005433924151	2124	Economy	11600.00
0005433924186	2124	Economy	11600.00
0005433924157	2124	Economy	11600.00
0005433924236	2124	Economy	11600.00
0005433036319	2124	Economy	11600.00
0005433924195	2124	Economy	11600.00
0005433035955	2124	Economy	11600.00
0005432231663	2124	Economy	11600.00
0005433924173	2124	Economy	11600.00
0005433924168	2124	Economy	11600.00
0005433924237	2124	Economy	11600.00
0005432231659	2124	Economy	11600.00
0005433036399	2124	Economy	11600.00
0005433036425	2124	Economy	11600.00
0005433036365	2124	Economy	11600.00
0005433924202	2124	Economy	11600.00
0005434028288	2124	Economy	11600.00
0005433924164	2124	Economy	11600.00
0005433924224	2124	Economy	11600.00
0005433924163	2124	Economy	11600.00
0005433036272	2124	Economy	11600.00
0005433924196	2124	Economy	11600.00
0005432231662	2124	Economy	11600.00
0005433036118	2124	Economy	11600.00
0005433924228	2124	Economy	11600.00
0005433924141	2124	Economy	11600.00
0005433924178	2124	Economy	11600.00
0005433924154	2124	Economy	11600.00
0005433924206	2124	Economy	11600.00
0005432749776	2124	Economy	11600.00
0005433924212	2124	Economy	11600.00
0005433924176	2124	Economy	11600.00
0005433924230	2124	Economy	11600.00
0005433924142	2124	Economy	11600.00
0005433036437	2124	Economy	11600.00
0005432749771	2124	Economy	11600.00
0005432749784	2124	Economy	12700.00
0005433036463	2124	Economy	11600.00
0005433924159	2124	Economy	11600.00
0005433924184	2124	Economy	11600.00
0005433035975	2124	Economy	12700.00
0005433924205	2124	Economy	12700.00
0005432231665	2124	Economy	11600.00
0005433036439	2124	Economy	11600.00
0005433924214	2124	Economy	11600.00
0005433924181	2124	Economy	11600.00
0005433924175	2124	Economy	11600.00
0005433929649	2124	Economy	11600.00
0005433924180	2124	Economy	11600.00
0005433924162	2124	Economy	11600.00
0005433924197	2124	Economy	11600.00
0005433924153	2124	Economy	11600.00
0005433036518	2124	Economy	11600.00
0005433924209	2124	Economy	11600.00
0005433924189	2124	Economy	11600.00
0005433931493	2124	Economy	11600.00
0005433924158	2124	Economy	11600.00
0005433924231	2124	Economy	11600.00
0005433924232	2124	Economy	11600.00
0005433924155	2124	Economy	11600.00
0005433036613	2124	Economy	11600.00
0005433924203	2124	Economy	11600.00
0005433924211	2124	Economy	11600.00
0005433924220	2124	Economy	11600.00
0005433036356	2124	Economy	11600.00
0005433036284	2124	Economy	11600.00
0005432044550	2124	Economy	11600.00
0005433924148	2124	Economy	11600.00
0005432231668	2124	Economy	11600.00
0005433931495	2124	Economy	11600.00
0005433036436	2124	Economy	11600.00
0005433036234	2124	Economy	11600.00
0005433924208	2124	Economy	11600.00
0005433924156	2124	Economy	11600.00
0005433036299	2124	Economy	11600.00
0005433036364	2124	Economy	11600.00
0005433036387	2124	Economy	11600.00
0005433924150	2124	Economy	11600.00
0005433036320	2124	Economy	11600.00
0005433924235	2124	Economy	11600.00
0005433924177	2124	Economy	11600.00
0005433929652	2124	Economy	11600.00
0005433924172	2124	Economy	11600.00
0005432231666	2124	Economy	11600.00
0005433924223	2124	Economy	11600.00
0005432749788	2124	Economy	11600.00
0005433036431	2124	Economy	11600.00
0005433035976	2124	Economy	11600.00
0005433036257	2124	Economy	11600.00
0005433924215	2124	Economy	11600.00
0005433036250	2124	Economy	11600.00
0005433924201	2124	Economy	11600.00
0005433924222	2124	Economy	11600.00
0005433924170	2124	Economy	11600.00
0005432044551	2124	Economy	11600.00
0005432749777	2124	Economy	11600.00
0005433036197	2124	Economy	11600.00
0005432231657	2124	Economy	11600.00
0005433924216	2124	Economy	11600.00
0005433924166	2124	Economy	11600.00
0005432231660	2124	Economy	11600.00
0005433924190	2124	Economy	11600.00
0005433036273	2124	Economy	11600.00
0005432231667	2124	Economy	11600.00
0005433036381	2124	Economy	11600.00
0005433924149	2124	Economy	11600.00
0005433923774	24100	Business	34700.00
0005433923301	24100	Business	34700.00
0005433923619	24100	Business	34700.00
0005433923074	24100	Business	34700.00
0005433036766	24100	Business	34700.00
0005433036794	24100	Business	34700.00
0005433036803	24100	Business	34700.00
0005432749805	24100	Business	34700.00
0005433036775	24100	Business	34700.00
0005433036812	24100	Business	34700.00
0005433923381	24100	Business	34700.00
0005433922887	24100	Business	34700.00
0005433923393	24100	Business	34700.00
0005433923584	24100	Business	34700.00
0005433923370	24100	Business	34700.00
0005433923531	24100	Economy	12700.00
0005433923591	24100	Economy	12700.00
0005433923281	24100	Economy	12700.00
0005433931464	24100	Economy	12700.00
0005433923585	24100	Economy	11600.00
0005433923683	24100	Economy	11600.00
0005433923385	24100	Economy	11600.00
0005432206252	24100	Economy	11600.00
0005433923040	24100	Economy	11600.00
0005433036793	24100	Economy	11600.00
0005432206249	24100	Economy	11600.00
0005433036807	24100	Economy	11600.00
0005433036799	24100	Economy	11600.00
0005433923473	24100	Economy	11600.00
0005433923635	24100	Economy	11600.00
0005433923444	24100	Economy	11600.00
0005433036784	24100	Economy	11600.00
0005433931462	24100	Economy	11600.00
0005433923474	24100	Economy	11600.00
0005433922847	24100	Economy	11600.00
0005433923544	24100	Economy	11600.00
0005433929616	24100	Economy	11600.00
0005433923294	24100	Economy	11600.00
0005433036798	24100	Economy	11600.00
0005433923382	24100	Economy	11600.00
0005433923668	24100	Economy	11600.00
0005433036785	24100	Economy	11600.00
0005433923322	24100	Economy	11600.00
0005433923178	24100	Economy	11600.00
0005432206248	24100	Economy	11600.00
0005433036797	24100	Economy	11600.00
0005433923070	24100	Economy	11600.00
0005433923634	24100	Economy	11600.00
0005433036809	24100	Economy	11600.00
0005434028323	24100	Economy	11600.00
0005433036781	24100	Economy	11600.00
0005433923255	24100	Economy	11600.00
0005433923454	24100	Economy	11600.00
0005433036795	24100	Economy	11600.00
0005433036801	24100	Economy	11600.00
0005433923303	24100	Economy	11600.00
0005433036804	24100	Economy	11600.00
0005433923453	24100	Economy	11600.00
0005433923364	24100	Economy	11600.00
0005433923744	24100	Economy	11600.00
0005433036800	24100	Economy	11600.00
0005433923525	24100	Economy	11600.00
0005433923616	24100	Economy	11600.00
0005433036790	24100	Economy	11600.00
0005433036764	24100	Economy	11600.00
0005433923617	24100	Economy	11600.00
0005433923065	24100	Economy	11600.00
0005433923066	24100	Economy	11600.00
0005433923313	24100	Economy	11600.00
0005433036777	24100	Economy	11600.00
0005433923157	24100	Economy	11600.00
0005433929617	24100	Economy	11600.00
0005433923443	24100	Economy	11600.00
0005433923336	24100	Economy	11600.00
0005433036761	24100	Economy	11600.00
0005433036786	24100	Economy	11600.00
0005433036805	24100	Economy	11600.00
0005433923195	24100	Economy	11600.00
0005432206250	24100	Economy	11600.00
0005433036767	24100	Economy	11600.00
0005433923062	24100	Economy	11600.00
0005433923192	24100	Economy	11600.00
0005433875386	24100	Economy	11600.00
0005433923094	24100	Economy	11600.00
0005433923249	24100	Economy	11600.00
0005433929603	24100	Economy	11600.00
0005433923455	24100	Economy	11600.00
0005433931467	24100	Economy	11600.00
0005433923184	24100	Economy	11600.00
0005433036768	24100	Economy	11600.00
0005433036778	24100	Economy	11600.00
0005433922848	24100	Economy	11600.00
0005433923406	24100	Economy	11600.00
0005432749806	24100	Economy	11600.00
0005433923460	24100	Economy	12700.00
0005433923237	24100	Economy	11600.00
0005433923177	24100	Economy	12700.00
0005433923618	24100	Economy	11600.00
0005433923386	24100	Economy	11600.00
0005433036765	24100	Economy	11600.00
0005433929619	24100	Economy	11600.00
0005433923283	24100	Economy	11600.00
0005433923507	24100	Economy	11600.00
0005432206247	24100	Economy	11600.00
0005434028322	24100	Economy	11600.00
0005433036772	24100	Economy	11600.00
0005433875371	24100	Economy	11600.00
0005433036762	24100	Economy	11600.00
0005433036773	24100	Economy	11600.00
0005433923667	24100	Economy	11600.00
0005433923549	24100	Economy	11600.00
0005433922975	24100	Economy	11600.00
0005433923179	24100	Economy	11600.00
0005433923114	24100	Economy	11600.00
0005433923363	24100	Economy	11600.00
0005433923548	24100	Economy	11600.00
0005433036770	24100	Economy	11600.00
0005433923093	24100	Economy	11600.00
0005433036791	24100	Economy	11600.00
0005433923506	24100	Economy	11600.00
0005433923324	24100	Economy	11600.00
0005433923064	24100	Economy	11600.00
0005433923597	24100	Economy	11600.00
0005433923063	24100	Economy	11600.00
0005433036769	24100	Economy	11600.00
0005433036806	24100	Economy	11600.00
0005433923191	24100	Economy	11600.00
0005433036796	24100	Economy	11600.00
0005433923578	24100	Economy	11600.00
0005433036802	24100	Economy	11600.00
0005433923615	24100	Economy	11600.00
0005433923569	24100	Economy	11600.00
0005433036788	24100	Economy	11600.00
0005433923193	24100	Economy	11600.00
0005433036783	24100	Economy	11600.00
0005433922888	24100	Economy	11600.00
0005433036779	24100	Economy	11600.00
0005433036780	24100	Economy	11600.00
0005433875385	24100	Economy	11600.00
0005433036789	24100	Economy	11600.00
0005433036810	24100	Economy	11600.00
0005433923579	24100	Economy	11600.00
0005433036763	24100	Economy	11600.00
0005433931461	24100	Economy	11600.00
0005433923236	24100	Economy	11600.00
0005433036808	24100	Economy	11600.00
0005433036813	24100	Economy	11600.00
0005433923614	24100	Economy	11600.00
0005433036811	24100	Economy	11600.00
0005433923291	24100	Economy	11600.00
0005433036787	24100	Economy	11600.00
0005433923348	24100	Economy	11600.00
0005433036771	24100	Economy	11600.00
0005433036774	24100	Economy	11600.00
0005433923240	24100	Economy	11600.00
0005432206251	24100	Economy	11600.00
0005433036776	24100	Economy	11600.00
0005432207686	24100	Economy	11600.00
0005433036782	24100	Economy	11600.00
0005433923570	24100	Economy	11600.00
0005433036792	24100	Economy	11600.00
0005433234355	292	Business	83700.00
0005432277933	292	Business	83700.00
0005434726553	292	Business	83700.00
0005435142709	292	Business	83700.00
0005433234089	292	Business	83700.00
0005434726541	292	Business	83700.00
0005434726576	292	Business	83700.00
0005433289842	292	Business	83700.00
0005433234103	292	Business	83700.00
0005433289869	292	Business	83700.00
0005434551738	292	Business	83700.00
0005434726657	292	Business	83700.00
0005434302499	292	Business	83700.00
0005432277935	292	Business	83700.00
0005433234138	292	Business	83700.00
0005433234253	292	Business	83700.00
0005434726556	292	Business	83700.00
0005434726651	292	Business	83700.00
0005434735735	292	Business	83700.00
0005433111508	292	Business	83700.00
0005433234346	292	Business	83700.00
0005434551731	292	Business	83700.00
0005434551723	292	Business	83700.00
0005434551743	292	Business	83700.00
0005434726637	292	Business	83700.00
0005434726609	292	Business	83700.00
0005433234304	292	Business	83700.00
0005434731207	292	Business	83700.00
0005435142702	292	Comfort	47400.00
0005433234124	292	Business	83700.00
0005434551716	292	Comfort	47400.00
0005434551741	292	Comfort	47400.00
0005434726581	292	Comfort	47400.00
0005434551760	292	Comfort	47400.00
0005433234060	292	Comfort	47400.00
0005433181097	292	Comfort	47400.00
0005434551753	292	Comfort	47400.00
0005433289855	292	Comfort	47400.00
0005433181105	292	Comfort	47400.00
0005435142706	292	Comfort	47400.00
0005433234534	292	Comfort	47400.00
0005434726534	292	Comfort	47400.00
0005433181112	292	Comfort	47400.00
0005434551736	292	Comfort	47400.00
0005434551759	292	Comfort	47400.00
0005433766628	292	Comfort	47400.00
0005434726644	292	Comfort	47400.00
0005434726624	292	Comfort	47400.00
0005434726638	292	Comfort	47400.00
0005434726639	292	Comfort	47400.00
0005433234354	292	Comfort	47400.00
0005434551732	292	Comfort	47400.00
0005433234296	292	Comfort	47400.00
0005435142707	292	Comfort	47400.00
0005433289858	292	Comfort	47400.00
0005434551728	292	Comfort	47400.00
0005434726544	292	Comfort	47400.00
0005433181136	292	Comfort	47400.00
0005434551721	292	Comfort	47400.00
0005434551763	292	Comfort	47400.00
0005434726573	292	Comfort	47400.00
0005434726636	292	Comfort	47400.00
0005433234208	292	Comfort	47400.00
0005433181130	292	Comfort	47400.00
0005433234380	292	Comfort	47400.00
0005433234229	292	Comfort	47400.00
0005434726569	292	Comfort	47400.00
0005434551750	292	Comfort	47400.00
0005434726579	292	Comfort	47400.00
0005433234472	292	Comfort	47400.00
0005434726646	292	Economy	27900.00
0005434551718	292	Economy	27900.00
0005433234243	292	Economy	27900.00
0005433234392	292	Economy	27900.00
0005433181178	292	Economy	27900.00
0005434726633	292	Economy	27900.00
0005433181149	292	Economy	27900.00
0005434726630	292	Economy	27900.00
0005433234297	292	Economy	27900.00
0005434726561	292	Economy	27900.00
0005434551755	292	Economy	27900.00
0005433289843	292	Economy	27900.00
0005433234063	292	Economy	27900.00
0005435142698	292	Economy	27900.00
0005433234303	292	Economy	27900.00
0005433766630	292	Economy	27900.00
0005434551757	292	Economy	27900.00
0005434726606	292	Economy	27900.00
0005434726614	292	Economy	27900.00
0005433289845	292	Economy	27900.00
0005434726626	292	Economy	27900.00
0005434735733	292	Economy	27900.00
0005433234254	292	Economy	27900.00
0005432277928	292	Economy	27900.00
0005434726605	292	Economy	27900.00
0005434551767	292	Economy	27900.00
0005434551766	292	Economy	27900.00
0005433181070	292	Economy	27900.00
0005434726572	292	Economy	27900.00
0005434551730	292	Economy	27900.00
0005432277931	292	Economy	27900.00
0005434731206	292	Economy	27900.00
0005434551734	292	Economy	27900.00
0005434551752	292	Economy	27900.00
0005433234657	292	Economy	27900.00
0005434551733	292	Economy	27900.00
0005434726618	292	Economy	27900.00
0005433131714	292	Economy	27900.00
0005434726571	292	Economy	27900.00
0005432277930	292	Economy	27900.00
0005434726652	292	Economy	27900.00
0005434726623	292	Economy	27900.00
0005434726610	292	Economy	27900.00
0005434551749	292	Economy	27900.00
0005433233987	292	Economy	27900.00
0005434731204	292	Economy	27900.00
0005433234470	292	Economy	27900.00
0005433289859	292	Economy	27900.00
0005434726617	292	Economy	27900.00
0005434726567	292	Economy	27900.00
0005435142699	292	Economy	27900.00
0005433234460	292	Economy	27900.00
0005434726608	292	Economy	27900.00
0005433234295	292	Economy	27900.00
0005434551737	292	Economy	27900.00
0005433766646	292	Economy	27900.00
0005434551715	292	Economy	27900.00
0005433181104	292	Economy	27900.00
0005433181069	292	Economy	27900.00
0005434302501	292	Economy	30700.00
0005434726535	292	Economy	27900.00
0005433234351	292	Economy	30700.00
0005434551719	292	Economy	30700.00
0005433234206	292	Economy	27900.00
0005433234533	292	Economy	27900.00
0005432277938	292	Economy	27900.00
0005434726619	292	Economy	30700.00
0005434726604	292	Economy	30700.00
0005433234345	292	Economy	27900.00
0005434726631	292	Economy	27900.00
0005433234459	292	Economy	27900.00
0005433234202	292	Economy	27900.00
0005434726546	292	Economy	27900.00
0005433181146	292	Economy	27900.00
0005434551751	292	Economy	27900.00
0005433234113	292	Economy	27900.00
0005434726625	292	Economy	27900.00
0005434302873	292	Economy	27900.00
0005433181042	292	Economy	27900.00
0005434726548	292	Economy	27900.00
0005434726593	292	Economy	27900.00
0005434726642	292	Economy	27900.00
0005434726595	292	Economy	27900.00
0005433234503	292	Economy	27900.00
0005432277932	292	Economy	27900.00
0005435142708	292	Economy	27900.00
0005434551744	292	Economy	27900.00
0005434302500	292	Economy	27900.00
0005434726559	292	Economy	27900.00
0005433234502	292	Economy	27900.00
0005433234366	292	Economy	27900.00
0005433289852	292	Economy	27900.00
0005434726620	292	Economy	27900.00
0005434726612	292	Economy	27900.00
0005434726562	292	Economy	27900.00
0005433289835	292	Economy	27900.00
0005434726586	292	Economy	27900.00
0005432277929	292	Economy	27900.00
0005434551729	292	Economy	27900.00
0005434551720	292	Economy	27900.00
0005432277939	292	Economy	27900.00
0005434726538	292	Economy	27900.00
0005434726591	292	Economy	27900.00
0005433234158	292	Economy	27900.00
0005434551758	292	Economy	27900.00
0005434726594	292	Economy	27900.00
0005434726550	292	Economy	27900.00
0005434726558	292	Economy	27900.00
0005433181164	292	Economy	27900.00
0005434551724	292	Economy	27900.00
0005434726598	292	Economy	27900.00
0005434032027	292	Economy	27900.00
0005434726629	292	Economy	27900.00
0005433234199	292	Economy	27900.00
0005433234205	292	Economy	27900.00
0005433181131	292	Economy	27900.00
0005434726656	292	Economy	27900.00
0005434726611	292	Economy	27900.00
0005433181076	292	Economy	27900.00
0005434726585	292	Economy	27900.00
0005434726539	292	Economy	27900.00
0005434726583	292	Economy	27900.00
0005434726650	292	Economy	27900.00
0005433234282	292	Economy	27900.00
0005433181191	292	Economy	27900.00
0005434302874	292	Economy	27900.00
0005433289847	292	Economy	27900.00
0005435142697	292	Economy	27900.00
0005433234382	292	Economy	27900.00
0005433234231	292	Economy	27900.00
0005434726554	292	Economy	27900.00
0005434726578	292	Economy	27900.00
0005434726601	292	Economy	27900.00
0005434551735	292	Economy	27900.00
0005433234458	292	Economy	27900.00
0005434551762	292	Economy	27900.00
0005433289856	292	Economy	27900.00
0005434726536	292	Economy	27900.00
0005434551717	292	Economy	27900.00
0005433181084	292	Economy	27900.00
0005433131708	292	Economy	27900.00
0005434726596	292	Economy	27900.00
0005434726588	292	Economy	27900.00
0005434726584	292	Economy	27900.00
0005434726654	292	Economy	27900.00
0005434551722	292	Economy	27900.00
0005433234088	292	Economy	27900.00
0005434551740	292	Economy	27900.00
0005434726564	292	Economy	27900.00
0005433234214	292	Economy	27900.00
0005435142705	292	Economy	27900.00
0005433181187	292	Economy	27900.00
0005433131703	292	Economy	27900.00
0005433234285	292	Economy	27900.00
0005434726565	292	Economy	27900.00
0005434551747	292	Economy	27900.00
0005434551745	292	Economy	27900.00
0005433181132	292	Economy	27900.00
0005434726634	292	Economy	27900.00
0005433181208	292	Economy	27900.00
0005433181096	292	Economy	27900.00
0005433234159	292	Economy	27900.00
0005434551713	292	Economy	27900.00
0005434726648	292	Economy	27900.00
0005434551761	292	Economy	27900.00
0005434726628	292	Economy	27900.00
0005433234117	292	Economy	30700.00
0005433234200	292	Economy	30700.00
0005434726533	292	Economy	30700.00
0005434551756	292	Economy	30700.00
0005434726590	292	Economy	27900.00
0005434726603	292	Economy	30700.00
0005434726574	292	Economy	27900.00
0005434551726	292	Economy	27900.00
0005435142704	292	Economy	27900.00
0005433234381	292	Economy	27900.00
0005434726635	292	Economy	27900.00
0005434551725	292	Economy	27900.00
0005435142701	292	Economy	27900.00
0005433181087	292	Economy	27900.00
0005434551754	292	Economy	27900.00
0005434726600	292	Economy	27900.00
0005434551765	292	Economy	27900.00
0005434726542	292	Economy	27900.00
0005434726597	292	Economy	27900.00
0005435142700	292	Economy	27900.00
0005433181023	292	Economy	27900.00
0005434731205	292	Economy	27900.00
0005434726615	292	Economy	27900.00
0005434726547	292	Economy	27900.00
0005434726560	292	Economy	27900.00
0005434735732	292	Economy	27900.00
0005434726607	292	Economy	27900.00
0005433234469	292	Economy	27900.00
0005433181089	292	Economy	27900.00
0005434726632	292	Economy	27900.00
0005434551764	292	Economy	27900.00
0005434726649	292	Economy	27900.00
0005434726563	292	Economy	27900.00
0005434726653	292	Economy	27900.00
0005432277936	292	Economy	27900.00
0005434551748	292	Economy	27900.00
0005434726643	292	Economy	27900.00
0005434726552	292	Economy	27900.00
0005434726640	292	Economy	27900.00
0005434726545	292	Economy	27900.00
0005434726555	292	Economy	27900.00
0005434032025	292	Economy	27900.00
0005434735731	292	Economy	27900.00
0005434726551	292	Economy	27900.00
0005434735734	292	Economy	27900.00
0005434726592	292	Economy	27900.00
0005432277937	292	Economy	27900.00
0005433766645	292	Economy	27900.00
0005433289844	292	Economy	27900.00
0005434032026	292	Economy	27900.00
0005434726582	292	Economy	27900.00
0005433289857	292	Economy	27900.00
0005434726566	292	Economy	27900.00
0005434726599	292	Economy	27900.00
0005434726616	292	Economy	27900.00
0005434551746	292	Economy	27900.00
0005433111509	292	Economy	27900.00
0005434726655	292	Economy	27900.00
0005434726587	292	Economy	27900.00
0005434726540	292	Economy	27900.00
0005433234157	292	Economy	27900.00
0005434551739	292	Economy	27900.00
0005434726645	292	Economy	27900.00
0005433113543	292	Economy	27900.00
0005434551742	292	Economy	27900.00
0005435142703	292	Economy	27900.00
0005433289836	292	Economy	27900.00
0005434726568	292	Economy	27900.00
0005433234352	292	Economy	27900.00
0005433181106	292	Economy	27900.00
0005433234302	292	Economy	27900.00
0005434551714	292	Economy	27900.00
0005434726613	292	Economy	27900.00
0005433234123	292	Economy	27900.00
0005433131716	292	Economy	27900.00
0005434726622	292	Economy	27900.00
0005432277927	292	Economy	27900.00
0005434726647	292	Economy	27900.00
0005433234116	292	Economy	27900.00
0005434726575	292	Economy	27900.00
0005434726602	292	Economy	27900.00
0005433181077	292	Economy	27900.00
0005434726570	292	Economy	27900.00
0005434551727	292	Economy	27900.00
0005432277934	292	Economy	27900.00
0005434726577	292	Economy	27900.00
0005433234517	292	Economy	27900.00
0005434726549	292	Economy	27900.00
0005433234147	292	Economy	27900.00
0005433233873	292	Economy	27900.00
0005433289851	292	Economy	27900.00
0005433289837	292	Economy	27900.00
0005434726589	292	Economy	27900.00
0005434726627	292	Economy	27900.00
0005433181115	292	Economy	27900.00
0005435142696	292	Economy	27900.00
0005432277926	292	Economy	27900.00
0005433234215	292	Economy	27900.00
0005434726580	292	Economy	27900.00
0005433181116	292	Economy	27900.00
0005433234268	292	Economy	27900.00
0005434726621	292	Economy	27900.00
0005434726537	292	Economy	27900.00
0005433234084	292	Economy	27900.00
0005434726557	292	Economy	27900.00
0005433289854	292	Economy	27900.00
0005434726641	292	Economy	27900.00
0005434726543	292	Economy	27900.00
0005435142592	9837	Business	83700.00
0005433234782	9837	Business	83700.00
0005433181335	9837	Business	83700.00
0005434725777	9837	Business	83700.00
0005434725328	9837	Business	83700.00
0005433234757	9837	Business	83700.00
0005434725419	9837	Business	83700.00
0005433234783	9837	Business	83700.00
0005434725950	9837	Business	83700.00
0005433234770	9837	Business	83700.00
0005433181332	9837	Business	83700.00
0005433234803	9837	Business	83700.00
0005434725412	9837	Business	83700.00
0005433234786	9837	Business	83700.00
0005434551236	9837	Business	83700.00
0005433234758	9837	Business	83700.00
0005434551128	9837	Business	83700.00
0005434725874	9837	Business	83700.00
0005433234771	9837	Business	83700.00
0005433234762	9837	Business	83700.00
0005433289915	9837	Business	83700.00
0005434731163	9837	Business	83700.00
0005434725609	9837	Business	83700.00
0005434551171	9837	Business	83700.00
0005434726115	9837	Business	83700.00
0005434725787	9837	Business	83700.00
0005434725493	9837	Comfort	47400.00
0005434725219	9837	Comfort	47400.00
0005434551103	9837	Comfort	47400.00
0005433289916	9837	Comfort	47400.00
0005433113556	9837	Comfort	47400.00
0005434551014	9837	Comfort	47400.00
0005434725914	9837	Comfort	47400.00
0005434725222	9837	Comfort	47400.00
0005433234764	9837	Comfort	47400.00
0005434725191	9837	Comfort	47400.00
0005433289911	9837	Comfort	47400.00
0005434725576	9837	Comfort	47400.00
0005434725402	9837	Comfort	47400.00
0005434551247	9837	Comfort	47400.00
0005434725249	9837	Comfort	47400.00
0005434551286	9837	Comfort	47400.00
0005434725678	9837	Comfort	47400.00
0005434551210	9837	Comfort	47400.00
0005434725115	9837	Comfort	47400.00
0005434725759	9837	Comfort	47400.00
0005434032068	9837	Comfort	47400.00
0005434551204	9837	Comfort	47400.00
0005434725486	9837	Comfort	47400.00
0005434726026	9837	Comfort	47400.00
0005433234789	9837	Comfort	47400.00
0005434725522	9837	Comfort	47400.00
0005433234792	9837	Comfort	47400.00
0005435142604	9837	Comfort	47400.00
0005434725196	9837	Comfort	47400.00
0005435142609	9837	Comfort	47400.00
0005434725925	9837	Comfort	47400.00
0005434731178	9837	Comfort	47400.00
0005433234796	9837	Comfort	47400.00
0005433234778	9837	Comfort	47400.00
0005433181331	9837	Comfort	47400.00
0005433234815	9837	Comfort	47400.00
0005434731185	9837	Comfort	47400.00
0005433234807	9837	Comfort	47400.00
0005434551431	9837	Comfort	47400.00
0005433181329	9837	Economy	27900.00
0005434725625	9837	Economy	27900.00
0005433129320	9837	Economy	27900.00
0005434726007	9837	Economy	27900.00
0005434725368	9837	Economy	27900.00
0005434725468	9837	Economy	27900.00
0005435142554	9837	Economy	27900.00
0005435142579	9837	Economy	27900.00
0005434725529	9837	Economy	27900.00
0005433181337	9837	Economy	27900.00
0005435142514	9837	Economy	27900.00
0005433181345	9837	Economy	27900.00
0005434551170	9837	Economy	27900.00
0005434725041	9837	Economy	27900.00
0005434725512	9837	Economy	27900.00
0005434725365	9837	Economy	27900.00
0005434725464	9837	Economy	27900.00
0005433181344	9837	Economy	27900.00
0005433234817	9837	Economy	27900.00
0005434032066	9837	Economy	27900.00
0005433234756	9837	Economy	27900.00
0005434551296	9837	Economy	27900.00
0005434725285	9837	Economy	27900.00
0005433181325	9837	Economy	27900.00
0005434551297	9837	Economy	27900.00
0005433766675	9837	Economy	27900.00
0005434725538	9837	Economy	27900.00
0005434725277	9837	Economy	27900.00
0005434725085	9837	Economy	27900.00
0005434725808	9837	Economy	27900.00
0005434725677	9837	Economy	27900.00
0005433126887	9837	Economy	27900.00
0005434551027	9837	Economy	27900.00
0005434735667	9837	Economy	27900.00
0005433234798	9837	Economy	27900.00
0005433234790	9837	Economy	27900.00
0005434725355	9837	Economy	27900.00
0005434725698	9837	Economy	27900.00
0005434726128	9837	Economy	27900.00
0005433234808	9837	Economy	27900.00
0005434725560	9837	Economy	27900.00
0005434032069	9837	Economy	27900.00
0005434551323	9837	Economy	27900.00
0005434551257	9837	Economy	27900.00
0005434725799	9837	Economy	27900.00
0005434725757	9837	Economy	27900.00
0005434731165	9837	Economy	27900.00
0005434725809	9837	Economy	27900.00
0005434725084	9837	Economy	27900.00
0005434725516	9837	Economy	27900.00
0005434725265	9837	Economy	27900.00
0005434725532	9837	Economy	27900.00
0005433234813	9837	Economy	27900.00
0005434725531	9837	Economy	27900.00
0005434551342	9837	Economy	27900.00
0005433234811	9837	Economy	27900.00
0005434725567	9837	Economy	27900.00
0005433181324	9837	Economy	27900.00
0005435142605	9837	Economy	27900.00
0005434551235	9837	Economy	27900.00
0005433234776	9837	Economy	30700.00
0005434724936	9837	Economy	30700.00
0005433234755	9837	Economy	30700.00
0005434725873	9837	Economy	27900.00
0005433234774	9837	Economy	27900.00
0005434735702	9837	Economy	27900.00
0005434725774	9837	Economy	27900.00
0005434551221	9837	Economy	30700.00
0005435142546	9837	Economy	30700.00
0005433234781	9837	Economy	27900.00
0005433234802	9837	Economy	30700.00
0005434725617	9837	Economy	27900.00
0005433234763	9837	Economy	27900.00
0005433181333	9837	Economy	27900.00
0005434725367	9837	Economy	27900.00
0005433234809	9837	Economy	27900.00
0005433234775	9837	Economy	27900.00
0005433234800	9837	Economy	27900.00
0005434725601	9837	Economy	27900.00
0005433234814	9837	Economy	27900.00
0005434725352	9837	Economy	27900.00
0005434726035	9837	Economy	27900.00
0005434725924	9837	Economy	27900.00
0005435142510	9837	Economy	27900.00
0005434551129	9837	Economy	27900.00
0005433234788	9837	Economy	27900.00
0005434302435	9837	Economy	27900.00
0005434551354	9837	Economy	27900.00
0005434725369	9837	Economy	27900.00
0005433181326	9837	Economy	27900.00
0005434302436	9837	Economy	27900.00
0005434725276	9837	Economy	27900.00
0005433126888	9837	Economy	27900.00
0005434724885	9837	Economy	27900.00
0005433234787	9837	Economy	27900.00
0005433234768	9837	Economy	27900.00
0005434725779	9837	Economy	27900.00
0005434302462	9837	Economy	27900.00
0005434725561	9837	Economy	27900.00
0005432199313	9837	Economy	27900.00
0005434725349	9837	Economy	27900.00
0005434735668	9837	Economy	27900.00
0005434551255	9837	Economy	27900.00
0005434731177	9837	Economy	27900.00
0005434725477	9837	Economy	27900.00
0005434725885	9837	Economy	27900.00
0005434725279	9837	Economy	27900.00
0005434725901	9837	Economy	27900.00
0005434725589	9837	Economy	27900.00
0005434551287	9837	Economy	27900.00
0005434551172	9837	Economy	27900.00
0005433234761	9837	Economy	27900.00
0005434735687	9837	Economy	27900.00
0005434725463	9837	Economy	27900.00
0005435142591	9837	Economy	27900.00
0005433129318	9837	Economy	27900.00
0005433289913	9837	Economy	27900.00
0005434551348	9837	Economy	27900.00
0005434551222	9837	Economy	27900.00
0005435142593	9837	Economy	27900.00
0005433129319	9837	Economy	27900.00
0005434725517	9837	Economy	27900.00
0005434551003	9837	Economy	27900.00
0005434725709	9837	Economy	27900.00
0005435142509	9837	Economy	27900.00
0005433234766	9837	Economy	27900.00
0005433234795	9837	Economy	27900.00
0005433234769	9837	Economy	27900.00
0005433234793	9837	Economy	27900.00
0005433234806	9837	Economy	27900.00
0005433181341	9837	Economy	27900.00
0005433766674	9837	Economy	27900.00
0005434551355	9837	Economy	27900.00
0005435142581	9837	Economy	27900.00
0005435142612	9837	Economy	27900.00
0005433766677	9837	Economy	27900.00
0005433289914	9837	Economy	27900.00
0005434725752	9837	Economy	27900.00
0005433234804	9837	Economy	27900.00
0005434725582	9837	Economy	27900.00
0005434725205	9837	Economy	27900.00
0005433766676	9837	Economy	27900.00
0005433129316	9837	Economy	27900.00
0005434725988	9837	Economy	27900.00
0005434725221	9837	Economy	27900.00
0005434550881	9837	Economy	27900.00
0005434725716	9837	Economy	27900.00
0005433129317	9837	Economy	27900.00
0005434725760	9837	Economy	27900.00
0005434725465	9837	Economy	27900.00
0005434726008	9837	Economy	27900.00
0005434724978	9837	Economy	27900.00
0005433181340	9837	Economy	27900.00
0005434551223	9837	Economy	27900.00
0005433234784	9837	Economy	27900.00
0005434725630	9837	Economy	27900.00
0005433181339	9837	Economy	27900.00
0005432199315	9837	Economy	27900.00
0005434551213	9837	Economy	27900.00
0005434302449	9837	Economy	27900.00
0005433234819	9837	Economy	27900.00
0005434725679	9837	Economy	27900.00
0005433181342	9837	Economy	27900.00
0005434725354	9837	Economy	27900.00
0005434551125	9837	Economy	27900.00
0005434551372	9837	Economy	27900.00
0005432199314	9837	Economy	27900.00
0005433181338	9837	Economy	27900.00
0005433181334	9837	Economy	30700.00
0005434725353	9837	Economy	30700.00
0005433234760	9837	Economy	30700.00
0005433234777	9837	Economy	30700.00
0005433234772	9837	Economy	27900.00
0005433234759	9837	Economy	27900.00
0005433181320	9837	Economy	27900.00
0005434551134	9837	Economy	27900.00
0005433181343	9837	Economy	27900.00
0005434725467	9837	Economy	27900.00
0005434725804	9837	Economy	27900.00
0005434725697	9837	Economy	27900.00
0005433234797	9837	Economy	27900.00
0005432199311	9837	Economy	27900.00
0005434032067	9837	Economy	27900.00
0005434551133	9837	Economy	27900.00
0005434551256	9837	Economy	27900.00
0005434725715	9837	Economy	27900.00
0005434725600	9837	Economy	27900.00
0005433234773	9837	Economy	27900.00
0005434302437	9837	Economy	27900.00
0005434725632	9837	Economy	27900.00
0005434725488	9837	Economy	27900.00
0005434551209	9837	Economy	27900.00
0005432199312	9837	Economy	27900.00
0005434725608	9837	Economy	27900.00
0005434725028	9837	Economy	27900.00
0005434551234	9837	Economy	27900.00
0005433234794	9837	Economy	27900.00
0005433234765	9837	Economy	27900.00
0005434724979	9837	Economy	27900.00
0005434725629	9837	Economy	27900.00
0005434725923	9837	Economy	27900.00
0005433289912	9837	Economy	27900.00
0005433126886	9837	Economy	27900.00
0005434725327	9837	Economy	27900.00
0005434551124	9837	Economy	27900.00
0005434731164	9837	Economy	27900.00
0005433234791	9837	Economy	27900.00
0005434725356	9837	Economy	27900.00
0005434725286	9837	Economy	27900.00
0005434725425	9837	Economy	27900.00
0005433181321	9837	Economy	27900.00
0005434551130	9837	Economy	27900.00
0005434725333	9837	Economy	27900.00
0005433181327	9837	Economy	27900.00
0005434725810	9837	Economy	27900.00
0005433181336	9837	Economy	27900.00
0005434725347	9837	Economy	27900.00
0005433234818	9837	Economy	27900.00
0005434725413	9837	Economy	27900.00
0005435142545	9837	Economy	27900.00
0005434726127	9837	Economy	27900.00
0005434725348	9837	Economy	27900.00
0005433234779	9837	Economy	27900.00
0005433234767	9837	Economy	27900.00
0005433234816	9837	Economy	27900.00
0005433234785	9837	Economy	27900.00
0005433234810	9837	Economy	27900.00
0005434725364	9837	Economy	27900.00
0005434725978	9837	Economy	27900.00
0005432199309	9837	Economy	27900.00
0005433181322	9837	Economy	27900.00
0005433181328	9837	Economy	27900.00
0005434725624	9837	Economy	27900.00
0005433113555	9837	Economy	27900.00
0005433181330	9837	Economy	27900.00
0005434302450	9837	Economy	27900.00
0005434725332	9837	Economy	27900.00
0005434551294	9837	Economy	27900.00
0005434551165	9837	Economy	27900.00
0005433181323	9837	Economy	27900.00
0005434725528	9837	Economy	27900.00
0005433126885	9837	Economy	27900.00
0005434551232	9837	Economy	27900.00
0005434551258	9837	Economy	27900.00
0005434725590	9837	Economy	27900.00
0005434551373	9837	Economy	27900.00
0005433234812	9837	Economy	27900.00
0005434725424	9837	Economy	27900.00
0005432199310	9837	Economy	27900.00
0005434725376	9837	Economy	27900.00
0005434551310	9837	Economy	27900.00
0005433234799	9837	Economy	27900.00
0005433234805	9837	Economy	27900.00
0005434725029	9837	Economy	27900.00
0005434725778	9837	Economy	27900.00
0005434735690	9837	Economy	27900.00
0005434725633	9837	Economy	27900.00
0005433234801	9837	Economy	27900.00
0005434725492	9837	Economy	27900.00
0005434725951	9837	Economy	27900.00
0005433234780	9837	Economy	27900.00
0005434068237	7738	Business	42100.00
0005432529168	7738	Business	42100.00
0005435213623	7738	Business	42100.00
0005435213553	7738	Business	42100.00
0005432529250	7738	Business	42100.00
0005432069787	7738	Business	42100.00
0005435213554	7738	Business	42100.00
0005435213659	7738	Business	42100.00
0005435213566	7738	Business	42100.00
0005435213661	7738	Business	42100.00
0005435725611	7738	Business	42100.00
0005432529163	7738	Business	42100.00
0005432529126	7738	Business	42100.00
0005432529218	7738	Business	42100.00
0005432529227	7738	Business	42100.00
0005434068243	7738	Business	42100.00
0005434068204	7738	Business	42100.00
0005432535877	7738	Business	42100.00
0005435213512	7738	Business	42100.00
0005432529217	7738	Business	42100.00
0005435213555	7738	Business	42100.00
0005432150267	7738	Business	42100.00
0005432529252	7738	Business	42100.00
0005435213556	7738	Business	42100.00
0005435213354	7738	Comfort	23900.00
0005432529210	7738	Business	42100.00
0005435630976	7738	Comfort	23900.00
0005435213976	7738	Comfort	23900.00
0005434068240	7738	Comfort	23900.00
0005434068233	7738	Comfort	23900.00
0005432529231	7738	Comfort	23900.00
0005432529138	7738	Comfort	23900.00
0005435213778	7738	Comfort	23900.00
0005435213627	7738	Comfort	23900.00
0005434068247	7738	Comfort	23900.00
0005435213385	7738	Comfort	23900.00
0005434068211	7738	Comfort	23900.00
0005435213605	7738	Comfort	23900.00
0005435213565	7738	Comfort	23900.00
0005434068239	7738	Comfort	23900.00
0005434068195	7738	Comfort	23900.00
0005435213744	7738	Comfort	23900.00
0005432529166	7738	Comfort	23900.00
0005435213357	7738	Comfort	23900.00
0005432529247	7738	Comfort	23900.00
0005434068221	7738	Comfort	23900.00
0005432529242	7738	Comfort	23900.00
0005434068223	7738	Comfort	23900.00
0005432529147	7738	Comfort	23900.00
0005435213528	7738	Comfort	23900.00
0005435213702	7738	Comfort	23900.00
0005435213658	7738	Comfort	23900.00
0005435630971	7738	Comfort	23900.00
0005432529131	7738	Comfort	23900.00
0005435725592	7738	Comfort	23900.00
0005432529149	7738	Comfort	23900.00
0005432529122	7738	Comfort	23900.00
0005432529249	7738	Comfort	23900.00
0005435213526	7738	Comfort	23900.00
0005432529170	7738	Comfort	23900.00
0005432529158	7738	Comfort	23900.00
0005432533318	7738	Comfort	23900.00
0005432529174	7738	Comfort	23900.00
0005435213503	7738	Comfort	23900.00
0005432529182	7738	Comfort	23900.00
0005435213458	7738	Comfort	23900.00
0005432529251	7738	Comfort	23900.00
0005434068224	7738	Comfort	23900.00
0005432529144	7738	Comfort	23900.00
0005432529228	7738	Economy	14000.00
0005435213414	7738	Economy	14000.00
0005432529151	7738	Economy	14000.00
0005432529155	7738	Economy	14000.00
0005432529146	7738	Economy	14000.00
0005435213271	7738	Economy	14000.00
0005435213592	7738	Economy	14000.00
0005435213299	7738	Economy	14000.00
0005435213681	7738	Economy	14000.00
0005435213579	7738	Economy	14000.00
0005432529129	7738	Economy	14000.00
0005434068248	7738	Economy	14000.00
0005435213401	7738	Economy	14000.00
0005435213423	7738	Economy	14000.00
0005435213807	7738	Economy	14000.00
0005435213549	7738	Economy	14000.00
0005434068202	7738	Economy	14000.00
0005432529238	7738	Economy	14000.00
0005432529201	7738	Economy	14000.00
0005435213799	7738	Economy	14000.00
0005435213806	7738	Economy	14000.00
0005432529215	7738	Economy	14000.00
0005434068188	7738	Economy	14000.00
0005434068187	7738	Economy	14000.00
0005432529136	7738	Economy	14000.00
0005434068216	7738	Economy	14000.00
0005432537077	7738	Economy	14000.00
0005432428959	7738	Economy	14000.00
0005434068227	7738	Economy	14000.00
0005435213593	7738	Economy	14000.00
0005432529191	7738	Economy	14000.00
0005432529229	7738	Economy	14000.00
0005432529214	7738	Economy	14000.00
0005432529162	7738	Economy	14000.00
0005435213453	7738	Economy	14000.00
0005434068225	7738	Economy	14000.00
0005434068196	7738	Economy	14000.00
0005432535880	7738	Economy	14000.00
0005432069791	7738	Economy	14000.00
0005432428961	7738	Economy	14000.00
0005435213514	7738	Economy	14000.00
0005434068206	7738	Economy	14000.00
0005432069783	7738	Economy	14000.00
0005432529137	7738	Economy	14000.00
0005435213692	7738	Economy	14000.00
0005432069790	7738	Economy	14000.00
0005432150268	7738	Economy	14000.00
0005434068234	7738	Economy	14000.00
0005432529150	7738	Economy	14000.00
0005434068226	7738	Economy	14000.00
0005432529175	7738	Economy	14000.00
0005435630981	7738	Economy	14000.00
0005435213550	7738	Economy	14000.00
0005435630957	7738	Economy	14000.00
0005432150266	7738	Economy	14000.00
0005432529224	7738	Economy	14000.00
0005432529181	7738	Economy	14000.00
0005432529211	7738	Economy	15400.00
0005434068203	7738	Economy	14000.00
0005432529245	7738	Economy	15400.00
0005435213516	7738	Economy	14000.00
0005432529220	7738	Economy	15400.00
0005434068201	7738	Economy	14000.00
0005434068238	7738	Economy	14000.00
0005432529123	7738	Economy	14000.00
0005432529213	7738	Economy	15400.00
0005435213424	7738	Economy	15400.00
0005432529125	7738	Economy	14000.00
0005432529209	7738	Economy	14000.00
0005432529153	7738	Economy	14000.00
0005432529128	7738	Economy	14000.00
0005432529230	7738	Economy	14000.00
0005434068193	7738	Economy	14000.00
0005434068207	7738	Economy	14000.00
0005434068228	7738	Economy	14000.00
0005434068229	7738	Economy	14000.00
0005432529134	7738	Economy	14000.00
0005432529169	7738	Economy	14000.00
0005435213767	7738	Economy	14000.00
0005432537076	7738	Economy	14000.00
0005432529159	7738	Economy	14000.00
0005432529178	7738	Economy	14000.00
0005434068218	7738	Economy	14000.00
0005432529177	7738	Economy	14000.00
0005435213629	7738	Economy	14000.00
0005434068252	7738	Economy	14000.00
0005432529171	7738	Economy	14000.00
0005435213504	7738	Economy	14000.00
0005435213452	7738	Economy	14000.00
0005435213433	7738	Economy	14000.00
0005435213356	7738	Economy	14000.00
0005432529157	7738	Economy	14000.00
0005432529141	7738	Economy	14000.00
0005435213455	7738	Economy	14000.00
0005432529244	7738	Economy	14000.00
0005432529234	7738	Economy	14000.00
0005432529237	7738	Economy	14000.00
0005435725610	7738	Economy	14000.00
0005432529232	7738	Economy	14000.00
0005432529167	7738	Economy	14000.00
0005434068231	7738	Economy	14000.00
0005432537078	7738	Economy	14000.00
0005435213628	7738	Economy	14000.00
0005432529233	7738	Economy	14000.00
0005435213614	7738	Economy	14000.00
0005434068199	7738	Economy	14000.00
0005434068186	7738	Economy	14000.00
0005435630958	7738	Economy	14000.00
0005434068250	7738	Economy	14000.00
0005434068191	7738	Economy	14000.00
0005434068212	7738	Economy	14000.00
0005434068220	7738	Economy	14000.00
0005434068210	7738	Economy	14000.00
0005432069786	7738	Economy	14000.00
0005432529240	7738	Economy	14000.00
0005435213527	7738	Economy	14000.00
0005432529208	7738	Economy	14000.00
0005435213800	7738	Economy	14000.00
0005432529200	7738	Economy	14000.00
0005434068249	7738	Economy	14000.00
0005432529219	7738	Economy	14000.00
0005435213394	7738	Economy	14000.00
0005432529236	7738	Economy	14000.00
0005435213587	7738	Economy	14000.00
0005434068213	7738	Economy	14000.00
0005432529206	7738	Economy	14000.00
0005432069784	7738	Economy	14000.00
0005432529154	7738	Economy	14000.00
0005435213691	7738	Economy	14000.00
0005432529160	7738	Economy	14000.00
0005432535876	7738	Economy	14000.00
0005432535881	7738	Economy	14000.00
0005434068230	7738	Economy	14000.00
0005432529135	7738	Economy	14000.00
0005432529203	7738	Economy	14000.00
0005434068245	7738	Economy	14000.00
0005432529207	7738	Economy	14000.00
0005432529197	7738	Economy	14000.00
0005432529173	7738	Economy	14000.00
0005432069792	7738	Economy	14000.00
0005434068222	7738	Economy	14000.00
0005432529199	7738	Economy	14000.00
0005435213660	7738	Economy	14000.00
0005432529195	7738	Economy	14000.00
0005434068241	7738	Economy	14000.00
0005435213312	7738	Economy	14000.00
0005434068215	7738	Economy	14000.00
0005432529239	7738	Economy	14000.00
0005432529145	7738	Economy	14000.00
0005432529143	7738	Economy	14000.00
0005432069785	7738	Economy	14000.00
0005434068189	7738	Economy	14000.00
0005435213680	7738	Economy	14000.00
0005432529185	7738	Economy	14000.00
0005435213625	7738	Economy	14000.00
0005435213777	7738	Economy	14000.00
0005435213485	7738	Economy	14000.00
0005432529198	7738	Economy	14000.00
0005432529152	7738	Economy	14000.00
0005432069795	7738	Economy	14000.00
0005432529142	7738	Economy	14000.00
0005432529186	7738	Economy	14000.00
0005435213564	7738	Economy	14000.00
0005435213355	7738	Economy	14000.00
0005432529248	7738	Economy	14000.00
0005434068184	7738	Economy	14000.00
0005432529190	7738	Economy	14000.00
0005432529254	7738	Economy	14000.00
0005432529222	7738	Economy	14000.00
0005435213413	7738	Economy	15400.00
0005435213353	7738	Economy	15400.00
0005434068214	7738	Economy	15400.00
0005434068183	7738	Economy	15400.00
0005434068219	7738	Economy	14000.00
0005435213457	7738	Economy	15400.00
0005434068200	7738	Economy	14000.00
0005432529202	7738	Economy	14000.00
0005432529221	7738	Economy	14000.00
0005435213441	7738	Economy	14000.00
0005432529188	7738	Economy	14000.00
0005435213346	7738	Economy	14000.00
0005435213820	7738	Economy	14000.00
0005432150270	7738	Economy	14000.00
0005435213345	7738	Economy	14000.00
0005435630970	7738	Economy	14000.00
0005432150269	7738	Economy	14000.00
0005432150265	7738	Economy	14000.00
0005432529132	7738	Economy	14000.00
0005432529235	7738	Economy	14000.00
0005435725604	7738	Economy	14000.00
0005432529223	7738	Economy	14000.00
0005432529124	7738	Economy	14000.00
0005434068253	7738	Economy	14000.00
0005434068205	7738	Economy	14000.00
0005432529139	7738	Economy	14000.00
0005434068254	7738	Economy	14000.00
0005432529212	7738	Economy	14000.00
0005432529216	7738	Economy	14000.00
0005434068232	7738	Economy	14000.00
0005434068194	7738	Economy	14000.00
0005432150264	7738	Economy	14000.00
0005434068209	7738	Economy	14000.00
0005432529196	7738	Economy	14000.00
0005432529133	7738	Economy	14000.00
0005435725614	7738	Economy	14000.00
0005435213769	7738	Economy	14000.00
0005432529140	7738	Economy	14000.00
0005435213599	7738	Economy	14000.00
0005434068197	7738	Economy	14000.00
0005432529241	7738	Economy	14000.00
0005432529130	7738	Economy	14000.00
0005434068190	7738	Economy	14000.00
0005435213515	7738	Economy	14000.00
0005434068236	7738	Economy	14000.00
0005434068217	7738	Economy	14000.00
0005435213402	7738	Economy	14000.00
0005432529246	7738	Economy	14000.00
0005435725591	7738	Economy	14000.00
0005435213763	7738	Economy	14000.00
0005432069794	7738	Economy	14000.00
0005432069789	7738	Economy	14000.00
0005432529161	7738	Economy	14000.00
0005434068235	7738	Economy	14000.00
0005432533319	7738	Economy	14000.00
0005432533317	7738	Economy	14000.00
0005432529194	7738	Economy	14000.00
0005432069793	7738	Economy	14000.00
0005432529165	7738	Economy	14000.00
0005432529189	7738	Economy	14000.00
0005435213459	7738	Economy	14000.00
0005432529192	7738	Economy	14000.00
0005434068185	7738	Economy	14000.00
0005435213569	7738	Economy	14000.00
0005434068251	7738	Economy	14000.00
0005432529183	7738	Economy	14000.00
0005432529243	7738	Economy	14000.00
0005432529156	7738	Economy	14000.00
0005434068192	7738	Economy	14000.00
0005432529253	7738	Economy	14000.00
0005432529127	7738	Economy	14000.00
0005435213600	7738	Economy	14000.00
0005432529187	7738	Economy	14000.00
0005432529176	7738	Economy	14000.00
0005432529193	7738	Economy	14000.00
0005435213701	7738	Economy	14000.00
0005432529148	7738	Economy	14000.00
0005434068246	7738	Economy	14000.00
0005432529180	7738	Economy	14000.00
0005435213607	7738	Economy	14000.00
0005435213662	7738	Economy	14000.00
0005434068242	7738	Economy	14000.00
0005435213601	7738	Economy	14000.00
0005432529225	7738	Economy	14000.00
0005435213626	7738	Economy	14000.00
0005434068244	7738	Economy	14000.00
0005432529164	7738	Economy	14000.00
0005432529205	7738	Economy	14000.00
0005434068208	7738	Economy	14000.00
0005432529184	7738	Economy	14000.00
0005435213604	7738	Economy	14000.00
0005435725606	7738	Economy	14000.00
0005432529226	7738	Economy	14000.00
0005432529172	7738	Economy	14000.00
0005432535879	7738	Economy	14000.00
0005435213779	7738	Economy	14000.00
0005435213272	7738	Economy	14000.00
0005432529204	7738	Economy	14000.00
0005432428960	7738	Economy	14000.00
0005435213273	7738	Economy	14000.00
0005434068255	7738	Economy	14000.00
0005432529179	7738	Economy	14000.00
0005432069788	7738	Economy	14000.00
0005432529255	7738	Economy	14000.00
0005434068198	7738	Economy	14000.00
0005435213624	7738	Economy	14000.00
0005432535878	7738	Economy	14000.00
0005435630969	7738	Economy	14000.00
0005435614744	5351	Business	43100.00
0005432133348	5351	Business	43100.00
0005435614710	5351	Business	43100.00
0005435424703	5351	Business	43100.00
0005435097294	5351	Business	43100.00
0005435305018	5351	Business	43100.00
0005435614725	5351	Business	43100.00
0005432133352	5351	Business	43100.00
0005434344561	5351	Business	43100.00
0005435614668	5351	Business	43100.00
0005435614731	5351	Business	43100.00
0005435614651	5351	Business	43100.00
0005435614625	5351	Business	43100.00
0005435614720	5351	Business	43100.00
0005435614690	5351	Business	43100.00
0005435614713	5351	Business	43100.00
0005434245109	5351	Business	43100.00
0005435424710	5351	Business	43100.00
0005434344562	5351	Business	43100.00
0005435614672	5351	Business	43100.00
0005435614685	5351	Business	43100.00
0005435424898	5351	Business	43100.00
0005435424858	5351	Business	43100.00
0005435424863	5351	Business	43100.00
0005434245018	5351	Business	43100.00
0005435319601	5351	Business	43100.00
0005434244907	5351	Business	43100.00
0005434573479	5351	Comfort	24400.00
0005434245024	5351	Comfort	24400.00
0005434245027	5351	Comfort	24400.00
0005435305012	5351	Comfort	24400.00
0005435614654	5351	Comfort	24400.00
0005434573488	5351	Comfort	24400.00
0005435380310	5351	Comfort	24400.00
0005435425084	5351	Comfort	24400.00
0005435614630	5351	Comfort	24400.00
0005435614648	5351	Comfort	24400.00
0005434245110	5351	Comfort	24400.00
0005435424896	5351	Comfort	24400.00
0005435614716	5351	Comfort	24400.00
0005432133349	5351	Comfort	24400.00
0005435614659	5351	Comfort	24400.00
0005435614691	5351	Comfort	24400.00
0005434573490	5351	Comfort	24400.00
0005435614700	5351	Comfort	24400.00
0005435614626	5351	Comfort	24400.00
0005435380299	5351	Comfort	24400.00
0005435491458	5351	Comfort	24400.00
0005435614628	5351	Comfort	24400.00
0005435424972	5351	Comfort	24400.00
0005435614677	5351	Comfort	24400.00
0005435614736	5351	Comfort	24400.00
0005435614675	5351	Comfort	24400.00
0005432841013	5351	Comfort	24400.00
0005432047586	5351	Comfort	24400.00
0005432363413	5351	Comfort	24400.00
0005435614662	5351	Comfort	24400.00
0005435614702	5351	Comfort	24400.00
0005435424776	5351	Comfort	24400.00
0005434245082	5351	Comfort	24400.00
0005435614707	5351	Comfort	24400.00
0005435614730	5351	Comfort	24400.00
0005435614683	5351	Comfort	24400.00
0005435614645	5351	Comfort	24400.00
0005432133353	5351	Comfort	24400.00
0005435614709	5351	Economy	14400.00
0005435614689	5351	Economy	14400.00
0005433719128	5351	Economy	14400.00
0005435424871	5351	Economy	14400.00
0005434245033	5351	Economy	14400.00
0005435614657	5351	Economy	14400.00
0005434244949	5351	Economy	14400.00
0005435425191	5351	Economy	14400.00
0005435319612	5351	Economy	14400.00
0005435319599	5351	Economy	14400.00
0005435614714	5351	Economy	14400.00
0005435614688	5351	Economy	14400.00
0005435424839	5351	Economy	14400.00
0005434573487	5351	Economy	14400.00
0005435424897	5351	Economy	14400.00
0005434344550	5351	Economy	14400.00
0005435614644	5351	Economy	14400.00
0005435424930	5351	Economy	14400.00
0005435424865	5351	Economy	14400.00
0005434344548	5351	Economy	14400.00
0005435614676	5351	Economy	14400.00
0005435425024	5351	Economy	14400.00
0005432133346	5351	Economy	14400.00
0005435490260	5351	Economy	14400.00
0005435490262	5351	Economy	14400.00
0005434656552	5351	Economy	14400.00
0005435424920	5351	Economy	14400.00
0005435614693	5351	Economy	14400.00
0005435614655	5351	Economy	14400.00
0005434344559	5351	Economy	14400.00
0005434344557	5351	Economy	14400.00
0005435614729	5351	Economy	14400.00
0005435614636	5351	Economy	14400.00
0005434344560	5351	Economy	14400.00
0005435614742	5351	Economy	14400.00
0005435319591	5351	Economy	14400.00
0005435424724	5351	Economy	14400.00
0005435614694	5351	Economy	14400.00
0005435424886	5351	Economy	14400.00
0005435614718	5351	Economy	14400.00
0005435614746	5351	Economy	14400.00
0005435424691	5351	Economy	14400.00
0005435319611	5351	Economy	14400.00
0005435097299	5351	Economy	14400.00
0005434573486	5351	Economy	14400.00
0005435425086	5351	Economy	14400.00
0005435424723	5351	Economy	14400.00
0005434344545	5351	Economy	14400.00
0005435614681	5351	Economy	14400.00
0005435424980	5351	Economy	14400.00
0005435424975	5351	Economy	14400.00
0005434244917	5351	Economy	14400.00
0005435380293	5351	Economy	14400.00
0005435614637	5351	Economy	14400.00
0005435424778	5351	Economy	14400.00
0005433719144	5351	Economy	14400.00
0005435614719	5351	Economy	14400.00
0005434245040	5351	Economy	14400.00
0005434573483	5351	Economy	14400.00
0005433719118	5351	Economy	14400.00
0005435424945	5351	Economy	15800.00
0005435614667	5351	Economy	14400.00
0005434344539	5351	Economy	15800.00
0005435614643	5351	Economy	14400.00
0005435424982	5351	Economy	15800.00
0005432133355	5351	Economy	14400.00
0005434245097	5351	Economy	15800.00
0005435614632	5351	Economy	14400.00
0005434344553	5351	Economy	15800.00
0005434244936	5351	Economy	14400.00
0005435097295	5351	Economy	14400.00
0005435614678	5351	Economy	14400.00
0005435490263	5351	Economy	14400.00
0005435614653	5351	Economy	14400.00
0005435097291	5351	Economy	14400.00
0005435425225	5351	Economy	14400.00
0005434344538	5351	Economy	14400.00
0005435614661	5351	Economy	14400.00
0005435380300	5351	Economy	14400.00
0005435614724	5351	Economy	14400.00
0005435614674	5351	Economy	14400.00
0005434344542	5351	Economy	14400.00
0005434344565	5351	Economy	14400.00
0005435614723	5351	Economy	14400.00
0005434344547	5351	Economy	14400.00
0005434244989	5351	Economy	14400.00
0005435614646	5351	Economy	14400.00
0005435614705	5351	Economy	14400.00
0005435614670	5351	Economy	14400.00
0005434245025	5351	Economy	14400.00
0005434244909	5351	Economy	14400.00
0005435614722	5351	Economy	14400.00
0005435424864	5351	Economy	14400.00
0005435319572	5351	Economy	14400.00
0005434244937	5351	Economy	14400.00
0005434244908	5351	Economy	14400.00
0005432133347	5351	Economy	14400.00
0005435614715	5351	Economy	14400.00
0005434344563	5351	Economy	14400.00
0005434573478	5351	Economy	14400.00
0005432133358	5351	Economy	14400.00
0005435614638	5351	Economy	14400.00
0005435614673	5351	Economy	14400.00
0005435614696	5351	Economy	14400.00
0005435424974	5351	Economy	14400.00
0005435319600	5351	Economy	14400.00
0005434656553	5351	Economy	14400.00
0005434344551	5351	Economy	14400.00
0005434244950	5351	Economy	14400.00
0005435425173	5351	Economy	14400.00
0005434244967	5351	Economy	14400.00
0005435425125	5351	Economy	14400.00
0005435614639	5351	Economy	14400.00
0005435424955	5351	Economy	14400.00
0005434344566	5351	Economy	14400.00
0005434656554	5351	Economy	14400.00
0005435614679	5351	Economy	14400.00
0005435614665	5351	Economy	14400.00
0005432133357	5351	Economy	14400.00
0005434344558	5351	Economy	14400.00
0005434344536	5351	Economy	14400.00
0005435424718	5351	Economy	14400.00
0005435097293	5351	Economy	14400.00
0005435555388	5351	Economy	14400.00
0005435424834	5351	Economy	14400.00
0005434344564	5351	Economy	14400.00
0005435614708	5351	Economy	14400.00
0005434344549	5351	Economy	14400.00
0005435424978	5351	Economy	14400.00
0005435424722	5351	Economy	14400.00
0005432047584	5351	Economy	14400.00
0005435097290	5351	Economy	14400.00
0005435614642	5351	Economy	14400.00
0005435614652	5351	Economy	14400.00
0005435424857	5351	Economy	14400.00
0005435097292	5351	Economy	14400.00
0005435424762	5351	Economy	14400.00
0005435614728	5351	Economy	14400.00
0005435614732	5351	Economy	14400.00
0005435614739	5351	Economy	14400.00
0005435614686	5351	Economy	14400.00
0005435614627	5351	Economy	14400.00
0005432133354	5351	Economy	14400.00
0005435614640	5351	Economy	14400.00
0005435491457	5351	Economy	14400.00
0005434656557	5351	Economy	14400.00
0005435424804	5351	Economy	14400.00
0005432363414	5351	Economy	14400.00
0005435425008	5351	Economy	14400.00
0005435425009	5351	Economy	14400.00
0005434573484	5351	Economy	14400.00
0005435614745	5351	Economy	14400.00
0005434344552	5351	Economy	14400.00
0005434344555	5351	Economy	14400.00
0005435614717	5351	Economy	14400.00
0005435614658	5351	Economy	14400.00
0005434656555	5351	Economy	14400.00
0005432133343	5351	Economy	14400.00
0005435424991	5351	Economy	14400.00
0005435491456	5351	Economy	14400.00
0005435614669	5351	Economy	14400.00
0005435614647	5351	Economy	14400.00
0005432133350	5351	Economy	14400.00
0005435097296	5351	Economy	14400.00
0005435614650	5351	Economy	14400.00
0005434344554	5351	Economy	14400.00
0005435614711	5351	Economy	14400.00
0005435614684	5351	Economy	14400.00
0005435424709	5351	Economy	14400.00
0005435614629	5351	Economy	14400.00
0005435614706	5351	Economy	14400.00
0005434573485	5351	Economy	15800.00
0005435424659	5351	Economy	15800.00
0005434344534	5351	Economy	15800.00
0005434244993	5351	Economy	14400.00
0005435614701	5351	Economy	14400.00
0005434573482	5351	Economy	14400.00
0005435614741	5351	Economy	14400.00
0005435424943	5351	Economy	14400.00
0005435614660	5351	Economy	14400.00
0005435424791	5351	Economy	14400.00
0005432133345	5351	Economy	14400.00
0005434244996	5351	Economy	14400.00
0005435614634	5351	Economy	14400.00
0005434244994	5351	Economy	14400.00
0005435097298	5351	Economy	14400.00
0005435614712	5351	Economy	14400.00
0005435614726	5351	Economy	14400.00
0005434344556	5351	Economy	14400.00
0005434245122	5351	Economy	14400.00
0005434245043	5351	Economy	14400.00
0005435424732	5351	Economy	14400.00
0005435614649	5351	Economy	14400.00
0005434573491	5351	Economy	14400.00
0005435425025	5351	Economy	14400.00
0005434245019	5351	Economy	14400.00
0005435042853	5351	Economy	14400.00
0005434344544	5351	Economy	14400.00
0005435425085	5351	Economy	14400.00
0005432133356	5351	Economy	14400.00
0005435614743	5351	Economy	14400.00
0005434344533	5351	Economy	14400.00
0005434344540	5351	Economy	14400.00
0005434573489	5351	Economy	14400.00
0005435614734	5351	Economy	14400.00
0005435042852	5351	Economy	14400.00
0005435424708	5351	Economy	14400.00
0005435424803	5351	Economy	14400.00
0005435491455	5351	Economy	14400.00
0005435614682	5351	Economy	14400.00
0005435614735	5351	Economy	14400.00
0005434344543	5351	Economy	14400.00
0005434244986	5351	Economy	14400.00
0005435614664	5351	Economy	14400.00
0005432047585	5351	Economy	14400.00
0005435614698	5351	Economy	14400.00
0005435614671	5351	Economy	14400.00
0005435614727	5351	Economy	14400.00
0005434573480	5351	Economy	14400.00
0005435614680	5351	Economy	14400.00
0005435425189	5351	Economy	14400.00
0005434244919	5351	Economy	14400.00
0005435424882	5351	Economy	14400.00
0005435614738	5351	Economy	14400.00
0005435614663	5351	Economy	14400.00
0005434344535	5351	Economy	14400.00
0005435614737	5351	Economy	14400.00
0005435614733	5351	Economy	14400.00
0005434244990	5351	Economy	14400.00
0005434245046	5351	Economy	14400.00
0005434244890	5351	Economy	14400.00
0005435614687	5351	Economy	14400.00
0005435614704	5351	Economy	14400.00
0005434245047	5351	Economy	14400.00
0005435617173	5351	Economy	14400.00
0005435424907	5351	Economy	14400.00
0005435425329	5351	Economy	14400.00
0005434573477	5351	Economy	14400.00
0005435614695	5351	Economy	14400.00
0005434344537	5351	Economy	14400.00
0005435490261	5351	Economy	14400.00
0005435424942	5351	Economy	14400.00
0005432133344	5351	Economy	14400.00
0005434245014	5351	Economy	14400.00
0005434573481	5351	Economy	14400.00
0005434244881	5351	Economy	14400.00
0005435614656	5351	Economy	14400.00
0005435424997	5351	Economy	14400.00
0005435614697	5351	Economy	14400.00
0005434344541	5351	Economy	14400.00
0005435424944	5351	Economy	14400.00
0005434344546	5351	Economy	14400.00
0005434245035	5351	Economy	14400.00
0005432133351	5351	Economy	14400.00
0005435614666	5351	Economy	14400.00
0005435614692	5351	Economy	14400.00
0005435097297	5351	Economy	14400.00
0005435614635	5351	Economy	14400.00
0005434245053	5351	Economy	14400.00
0005435614703	5351	Economy	14400.00
0005435614633	5351	Economy	14400.00
0005435614740	5351	Economy	14400.00
0005435614631	5351	Economy	14400.00
0005435614699	5351	Economy	14400.00
0005435614641	5351	Economy	14400.00
0005435614721	5351	Economy	14400.00
0005435424725	5351	Economy	14400.00
0005435613572	10932	Business	43100.00
0005434344032	10932	Business	43100.00
0005435319653	10932	Business	43100.00
0005435097182	10932	Business	43100.00
0005435425452	10932	Business	43100.00
0005435613609	10932	Business	43100.00
0005435613119	10932	Business	43100.00
0005435425432	10932	Business	43100.00
0005435305030	10932	Business	43100.00
0005432165107	10932	Business	43100.00
0005435614085	10932	Business	43100.00
0005435613929	10932	Business	43100.00
0005435613649	10932	Business	43100.00
0005435042875	10932	Business	43100.00
0005434344204	10932	Business	43100.00
0005435613734	10932	Business	43100.00
0005435614167	10932	Business	43100.00
0005434344195	10932	Business	43100.00
0005435613459	10932	Business	43100.00
0005432165111	10932	Business	43100.00
0005435425464	10932	Business	43100.00
0005435613559	10932	Business	43100.00
0005434656575	10932	Business	43100.00
0005435614159	10932	Business	43100.00
0005434245249	10932	Business	43100.00
0005434245250	10932	Business	43100.00
0005434344230	10932	Comfort	24400.00
0005435491436	10932	Business	43100.00
0005432166931	10932	Comfort	24400.00
0005434573330	10932	Comfort	24400.00
0005435425460	10932	Comfort	24400.00
0005435097254	10932	Comfort	24400.00
0005435613482	10932	Comfort	24400.00
0005435613655	10932	Comfort	24400.00
0005434344201	10932	Comfort	24400.00
0005435425447	10932	Comfort	24400.00
0005435425448	10932	Comfort	24400.00
0005435613302	10932	Comfort	24400.00
0005435613623	10932	Comfort	24400.00
0005435425422	10932	Comfort	24400.00
0005432165110	10932	Comfort	24400.00
0005435380333	10932	Comfort	24400.00
0005435425410	10932	Comfort	24400.00
0005435097192	10932	Comfort	24400.00
0005435097206	10932	Comfort	24400.00
0005434245241	10932	Comfort	24400.00
0005435425449	10932	Comfort	24400.00
0005432166930	10932	Comfort	24400.00
0005435304195	10932	Comfort	24400.00
0005435425429	10932	Comfort	24400.00
0005435425473	10932	Comfort	24400.00
0005432166932	10932	Comfort	24400.00
0005435425416	10932	Comfort	24400.00
0005434245251	10932	Comfort	24400.00
0005435097193	10932	Comfort	24400.00
0005435097167	10932	Comfort	24400.00
0005435425427	10932	Comfort	24400.00
0005434573389	10932	Comfort	24400.00
0005435613583	10932	Comfort	24400.00
0005434344145	10932	Comfort	24400.00
0005435425471	10932	Comfort	24400.00
0005434343998	10932	Comfort	24400.00
0005435613987	10932	Comfort	24400.00
0005435097207	10932	Comfort	24400.00
0005435425408	10932	Comfort	24400.00
0005435613903	10932	Economy	14400.00
0005435613120	10932	Economy	14400.00
0005435613376	10932	Economy	14400.00
0005435613928	10932	Economy	14400.00
0005435425454	10932	Economy	14400.00
0005435613683	10932	Economy	14400.00
0005434245242	10932	Economy	14400.00
0005435613744	10932	Economy	14400.00
0005435613674	10932	Economy	14400.00
0005435613686	10932	Economy	14400.00
0005435425462	10932	Economy	14400.00
0005435614132	10932	Economy	14400.00
0005435613811	10932	Economy	14400.00
0005435613866	10932	Economy	14400.00
0005435319654	10932	Economy	14400.00
0005435614048	10932	Economy	14400.00
0005434344232	10932	Economy	14400.00
0005432165108	10932	Economy	14400.00
0005435613801	10932	Economy	14400.00
0005435425478	10932	Economy	14400.00
0005435304193	10932	Economy	14400.00
0005434344289	10932	Economy	14400.00
0005435555372	10932	Economy	14400.00
0005435613657	10932	Economy	14400.00
0005434245245	10932	Economy	14400.00
0005435425440	10932	Economy	14400.00
0005435097238	10932	Economy	14400.00
0005435425467	10932	Economy	14400.00
0005435425468	10932	Economy	14400.00
0005435097169	10932	Economy	14400.00
0005435613762	10932	Economy	14400.00
0005435425474	10932	Economy	14400.00
0005435097222	10932	Economy	14400.00
0005435613939	10932	Economy	14400.00
0005435425450	10932	Economy	14400.00
0005435425417	10932	Economy	14400.00
0005435613675	10932	Economy	14400.00
0005435614138	10932	Economy	14400.00
0005435425443	10932	Economy	14400.00
0005435613304	10932	Economy	14400.00
0005435425421	10932	Economy	14400.00
0005435613999	10932	Economy	14400.00
0005434344229	10932	Economy	14400.00
0005435613656	10932	Economy	14400.00
0005434344171	10932	Economy	14400.00
0005434344139	10932	Economy	14400.00
0005434245239	10932	Economy	14400.00
0005435319651	10932	Economy	14400.00
0005435097178	10932	Economy	14400.00
0005435613769	10932	Economy	14400.00
0005435613633	10932	Economy	14400.00
0005435613697	10932	Economy	14400.00
0005435613584	10932	Economy	14400.00
0005434344192	10932	Economy	14400.00
0005435613712	10932	Economy	14400.00
0005434344206	10932	Economy	14400.00
0005434344149	10932	Economy	14400.00
0005435319656	10932	Economy	14400.00
0005434573342	10932	Economy	14400.00
0005435425409	10932	Economy	15800.00
0005434245258	10932	Economy	15800.00
0005435613461	10932	Economy	14400.00
0005435425434	10932	Economy	15800.00
0005435425457	10932	Economy	14400.00
0005434245244	10932	Economy	14400.00
0005434245238	10932	Economy	15800.00
0005435614051	10932	Economy	14400.00
0005434344200	10932	Economy	15800.00
0005435614062	10932	Economy	15800.00
0005435425435	10932	Economy	14400.00
0005435425459	10932	Economy	14400.00
0005435613550	10932	Economy	14400.00
0005435425475	10932	Economy	14400.00
0005435613923	10932	Economy	14400.00
0005434344202	10932	Economy	14400.00
0005435425442	10932	Economy	14400.00
0005434344140	10932	Economy	14400.00
0005435613616	10932	Economy	14400.00
0005435613733	10932	Economy	14400.00
0005435613839	10932	Economy	14400.00
0005435613930	10932	Economy	14400.00
0005433719174	10932	Economy	14400.00
0005435305031	10932	Economy	14400.00
0005433719175	10932	Economy	14400.00
0005432841033	10932	Economy	14400.00
0005435319650	10932	Economy	14400.00
0005435425465	10932	Economy	14400.00
0005435613567	10932	Economy	14400.00
0005435613321	10932	Economy	14400.00
0005434344231	10932	Economy	14400.00
0005435425411	10932	Economy	14400.00
0005435380328	10932	Economy	14400.00
0005434344082	10932	Economy	14400.00
0005435425476	10932	Economy	14400.00
0005435425436	10932	Economy	14400.00
0005435613544	10932	Economy	14400.00
0005435613613	10932	Economy	14400.00
0005434245266	10932	Economy	14400.00
0005435613687	10932	Economy	14400.00
0005435425414	10932	Economy	14400.00
0005435425424	10932	Economy	14400.00
0005435425426	10932	Economy	14400.00
0005435380329	10932	Economy	14400.00
0005435425455	10932	Economy	14400.00
0005435612835	10932	Economy	14400.00
0005432165109	10932	Economy	14400.00
0005435613859	10932	Economy	14400.00
0005435613325	10932	Economy	14400.00
0005435613810	10932	Economy	14400.00
0005435613833	10932	Economy	14400.00
0005435613867	10932	Economy	14400.00
0005435097221	10932	Economy	14400.00
0005435613622	10932	Economy	14400.00
0005434344126	10932	Economy	14400.00
0005434245257	10932	Economy	14400.00
0005435614061	10932	Economy	14400.00
0005435425433	10932	Economy	14400.00
0005435425418	10932	Economy	14400.00
0005435612927	10932	Economy	14400.00
0005435425431	10932	Economy	14400.00
0005432363447	10932	Economy	14400.00
0005435425425	10932	Economy	14400.00
0005435614063	10932	Economy	14400.00
0005435613326	10932	Economy	14400.00
0005434245254	10932	Economy	14400.00
0005434344129	10932	Economy	14400.00
0005435614106	10932	Economy	14400.00
0005435613858	10932	Economy	14400.00
0005435425470	10932	Economy	14400.00
0005435613886	10932	Economy	14400.00
0005435425412	10932	Economy	14400.00
0005435425415	10932	Economy	14400.00
0005435613545	10932	Economy	14400.00
0005435304196	10932	Economy	14400.00
0005435613820	10932	Economy	14400.00
0005434245253	10932	Economy	14400.00
0005435097181	10932	Economy	14400.00
0005434344172	10932	Economy	14400.00
0005435614050	10932	Economy	14400.00
0005434344083	10932	Economy	14400.00
0005435613608	10932	Economy	14400.00
0005435614049	10932	Economy	14400.00
0005435613560	10932	Economy	14400.00
0005434245243	10932	Economy	14400.00
0005435319658	10932	Economy	14400.00
0005435612925	10932	Economy	14400.00
0005433719172	10932	Economy	14400.00
0005434344164	10932	Economy	14400.00
0005435613524	10932	Economy	14400.00
0005435425423	10932	Economy	14400.00
0005435613877	10932	Economy	14400.00
0005435042877	10932	Economy	14400.00
0005435380330	10932	Economy	14400.00
0005435613628	10932	Economy	14400.00
0005434245260	10932	Economy	14400.00
0005435425466	10932	Economy	14400.00
0005435425477	10932	Economy	14400.00
0005435319657	10932	Economy	14400.00
0005435613431	10932	Economy	14400.00
0005435425458	10932	Economy	14400.00
0005435380332	10932	Economy	14400.00
0005434343920	10932	Economy	14400.00
0005432363446	10932	Economy	14400.00
0005435614306	10932	Economy	14400.00
0005435097175	10932	Economy	14400.00
0005435614105	10932	Economy	14400.00
0005435613856	10932	Economy	14400.00
0005435613358	10932	Economy	14400.00
0005434245247	10932	Economy	15800.00
0005435425469	10932	Economy	14400.00
0005434245240	10932	Economy	15800.00
0005435425420	10932	Economy	15800.00
0005435614084	10932	Economy	15800.00
0005435304194	10932	Economy	14400.00
0005435614086	10932	Economy	14400.00
0005432363445	10932	Economy	14400.00
0005434344128	10932	Economy	14400.00
0005432841032	10932	Economy	14400.00
0005435425453	10932	Economy	14400.00
0005435042878	10932	Economy	14400.00
0005434245262	10932	Economy	14400.00
0005435613711	10932	Economy	14400.00
0005435613137	10932	Economy	14400.00
0005435425437	10932	Economy	14400.00
0005434344105	10932	Economy	14400.00
0005435425445	10932	Economy	14400.00
0005435613318	10932	Economy	14400.00
0005435097174	10932	Economy	14400.00
0005435425463	10932	Economy	14400.00
0005434344207	10932	Economy	14400.00
0005434245263	10932	Economy	14400.00
0005435613359	10932	Economy	14400.00
0005435613768	10932	Economy	14400.00
0005435613577	10932	Economy	14400.00
0005435613709	10932	Economy	14400.00
0005435613612	10932	Economy	14400.00
0005435613857	10932	Economy	14400.00
0005435613808	10932	Economy	14400.00
0005434344191	10932	Economy	14400.00
0005434245261	10932	Economy	14400.00
0005435613910	10932	Economy	14400.00
0005434245265	10932	Economy	14400.00
0005434245256	10932	Economy	14400.00
0005435042876	10932	Economy	14400.00
0005435614046	10932	Economy	14400.00
0005435305029	10932	Economy	14400.00
0005435380331	10932	Economy	14400.00
0005434344033	10932	Economy	14400.00
0005435319655	10932	Economy	14400.00
0005434245255	10932	Economy	14400.00
0005435425451	10932	Economy	14400.00
0005435425441	10932	Economy	14400.00
0005435613806	10932	Economy	14400.00
0005435613121	10932	Economy	14400.00
0005435319659	10932	Economy	14400.00
0005432363448	10932	Economy	14400.00
0005435097168	10932	Economy	14400.00
0005435613707	10932	Economy	14400.00
0005435613408	10932	Economy	14400.00
0005435425419	10932	Economy	14400.00
0005435613494	10932	Economy	14400.00
0005435613389	10932	Economy	14400.00
0005434245248	10932	Economy	14400.00
0005435305028	10932	Economy	14400.00
0005435425444	10932	Economy	14400.00
0005435425439	10932	Economy	14400.00
0005434245252	10932	Economy	14400.00
0005435613301	10932	Economy	14400.00
0005434245259	10932	Economy	14400.00
0005435613411	10932	Economy	14400.00
0005433719173	10932	Economy	14400.00
0005435425438	10932	Economy	14400.00
0005434573331	10932	Economy	14400.00
0005434344308	10932	Economy	14400.00
0005435613390	10932	Economy	14400.00
0005435613971	10932	Economy	14400.00
0005434344177	10932	Economy	14400.00
0005435425461	10932	Economy	14400.00
0005434573348	10932	Economy	14400.00
0005435425456	10932	Economy	14400.00
0005434573210	10932	Economy	14400.00
0005435613409	10932	Economy	14400.00
0005435425428	10932	Economy	14400.00
0005435613708	10932	Economy	14400.00
0005435491447	10932	Economy	14400.00
0005434344106	10932	Economy	14400.00
0005435425413	10932	Economy	14400.00
0005434245264	10932	Economy	14400.00
0005435613807	10932	Economy	14400.00
0005435614004	10932	Economy	14400.00
0005435304197	10932	Economy	14400.00
0005435613610	10932	Economy	14400.00
0005435425430	10932	Economy	14400.00
0005434344266	10932	Economy	14400.00
0005434573366	10932	Economy	14400.00
0005435613800	10932	Economy	14400.00
0005435613343	10932	Economy	14400.00
0005435425446	10932	Economy	14400.00
0005435612834	10932	Economy	14400.00
0005434573365	10932	Economy	14400.00
0005435319652	10932	Economy	14400.00
0005434245246	10932	Economy	14400.00
0005435425472	10932	Economy	14400.00
0005432181923	3225	Business	18800.00
0005433507353	3225	Business	18800.00
0005433507347	3225	Business	18800.00
0005433805687	3225	Business	18800.00
0005433805688	3225	Business	18800.00
0005432181920	3225	Business	18800.00
0005433634122	3225	Business	18800.00
0005432459700	3225	Business	18800.00
0005433805692	3225	Business	18800.00
0005432460037	3225	Business	18800.00
0005433507349	3225	Business	18800.00
0005432459823	3225	Business	18800.00
0005432181929	3225	Business	18800.00
0005433507341	3225	Business	18800.00
0005432460010	3225	Business	18800.00
0005432459818	3225	Business	18800.00
0005432459817	3225	Business	18800.00
0005433634120	3225	Business	18800.00
0005432459796	3225	Business	18800.00
0005433634121	3225	Business	18800.00
0005432459846	3225	Business	18800.00
0005433805707	3225	Business	18800.00
0005432459879	3225	Business	18800.00
0005433634144	3225	Business	18800.00
0005432460164	3225	Business	18800.00
0005433634153	3225	Business	18800.00
0005432459682	3225	Business	18800.00
0005432459749	3225	Economy	6900.00
0005433634149	3225	Economy	6900.00
0005432460009	3225	Economy	6900.00
0005432459758	3225	Economy	6900.00
0005433634147	3225	Economy	6900.00
0005433507342	3225	Economy	6300.00
0005433507352	3225	Economy	6300.00
0005432181919	3225	Economy	6300.00
0005432459950	3225	Economy	6300.00
0005432460000	3225	Economy	6300.00
0005432459767	3225	Economy	6300.00
0005433634146	3225	Economy	6300.00
0005432459880	3225	Economy	6300.00
0005433634131	3225	Economy	6300.00
0005432181927	3225	Economy	6300.00
0005432459797	3225	Economy	6300.00
0005432459918	3225	Economy	6300.00
0005432459892	3225	Economy	6300.00
0005432459819	3225	Economy	6300.00
0005433634137	3225	Economy	6300.00
0005433805701	3225	Economy	6300.00
0005432459798	3225	Economy	6300.00
0005433805685	3225	Economy	6300.00
0005433634132	3225	Economy	6300.00
0005433805712	3225	Economy	6300.00
0005433805691	3225	Economy	6300.00
0005433634152	3225	Economy	6300.00
0005432181926	3225	Economy	6300.00
0005432459968	3225	Economy	6300.00
0005432459848	3225	Economy	6300.00
0005433805715	3225	Economy	6300.00
0005433805699	3225	Economy	6300.00
0005432459829	3225	Economy	6300.00
0005433805696	3225	Economy	6300.00
0005432459987	3225	Economy	6300.00
0005433805716	3225	Economy	6300.00
0005433507346	3225	Economy	6300.00
0005432459993	3225	Economy	6300.00
0005432181917	3225	Economy	6300.00
0005432459893	3225	Economy	6300.00
0005432459876	3225	Economy	6300.00
0005433507351	3225	Economy	6300.00
0005433634136	3225	Economy	6300.00
0005432459881	3225	Economy	6300.00
0005432181932	3225	Economy	6300.00
0005433805698	3225	Economy	6300.00
0005432181931	3225	Economy	6300.00
0005432181930	3225	Economy	6300.00
0005432459747	3225	Economy	6300.00
0005432459877	3225	Economy	6300.00
0005433634126	3225	Economy	6300.00
0005433805697	3225	Economy	6300.00
0005433634151	3225	Economy	6300.00
0005433634133	3225	Economy	6300.00
0005433634138	3225	Economy	6300.00
0005433634143	3225	Economy	6300.00
0005432460011	3225	Economy	6300.00
0005433805713	3225	Economy	6300.00
0005433507355	3225	Economy	6300.00
0005432460028	3225	Economy	6300.00
0005433634130	3225	Economy	6300.00
0005433634128	3225	Economy	6300.00
0005433634129	3225	Economy	6900.00
0005433634140	3225	Economy	6900.00
0005433507343	3225	Economy	6900.00
0005433634135	3225	Economy	6900.00
0005432459999	3225	Economy	6900.00
0005433507345	3225	Economy	6300.00
0005433805714	3225	Economy	6300.00
0005432181914	3225	Economy	6300.00
0005432181934	3225	Economy	6900.00
0005433805703	3225	Economy	6300.00
0005433634139	3225	Economy	6300.00
0005432459949	3225	Economy	6300.00
0005433507350	3225	Economy	6300.00
0005433507344	3225	Economy	6300.00
0005432459887	3225	Economy	6300.00
0005433634124	3225	Economy	6300.00
0005432459912	3225	Economy	6300.00
0005432459789	3225	Economy	6300.00
0005433507356	3225	Economy	6300.00
0005433805693	3225	Economy	6300.00
0005433805689	3225	Economy	6300.00
0005432459649	3225	Economy	6300.00
0005432181921	3225	Economy	6300.00
0005432181918	3225	Economy	6300.00
0005433634154	3225	Economy	6300.00
0005433805717	3225	Economy	6300.00
0005433805695	3225	Economy	6300.00
0005433634127	3225	Economy	6300.00
0005432459746	3225	Economy	6300.00
0005433805700	3225	Economy	6300.00
0005433634134	3225	Economy	6300.00
0005433507354	3225	Economy	6300.00
0005432460087	3225	Economy	6300.00
0005433805711	3225	Economy	6300.00
0005432459903	3225	Economy	6300.00
0005433634125	3225	Economy	6300.00
0005433634141	3225	Economy	6300.00
0005433634148	3225	Economy	6300.00
0005432459773	3225	Economy	6300.00
0005432181922	3225	Economy	6300.00
0005432181915	3225	Economy	6300.00
0005432459822	3225	Economy	6300.00
0005433634150	3225	Economy	6300.00
0005433805705	3225	Economy	6300.00
0005433805690	3225	Economy	6300.00
0005433634145	3225	Economy	6300.00
0005432459704	3225	Economy	6300.00
0005433805694	3225	Economy	6300.00
0005432459768	3225	Economy	6300.00
0005432181928	3225	Economy	6300.00
0005432460038	3225	Economy	6300.00
0005433805709	3225	Economy	6300.00
0005432459849	3225	Economy	6300.00
0005432459719	3225	Economy	6300.00
0005432459913	3225	Economy	6300.00
0005433634142	3225	Economy	6300.00
0005432459904	3225	Economy	6300.00
0005432181925	3225	Economy	6300.00
0005433805708	3225	Economy	6300.00
0005432181924	3225	Economy	6300.00
0005433805706	3225	Economy	6300.00
0005433634123	3225	Economy	6300.00
0005433507348	3225	Economy	6300.00
0005432181933	3225	Economy	6300.00
0005433805710	3225	Economy	6300.00
0005432181913	3225	Economy	6300.00
0005432459756	3225	Economy	6300.00
0005433805686	3225	Economy	6300.00
0005433805704	3225	Economy	6300.00
0005432459847	3225	Economy	6300.00
0005432181916	3225	Economy	6300.00
0005432459650	3225	Economy	6300.00
0005433805702	3225	Economy	6300.00
0005432459948	3225	Economy	6300.00
0005435885277	3224	Business	18800.00
0005435885138	3224	Business	18800.00
0005435885398	3224	Business	18800.00
0005435885479	3224	Business	18800.00
0005435885258	3224	Business	18800.00
0005435885105	3224	Business	18800.00
0005435885144	3224	Business	18800.00
0005435885526	3224	Economy	6900.00
0005435885344	3224	Economy	6300.00
0005435885356	3224	Economy	6300.00
0005435885520	3224	Economy	6300.00
0005435885331	3224	Economy	6300.00
0005435885309	3224	Economy	6300.00
0005435885439	3224	Economy	6300.00
0005435885418	3224	Economy	6300.00
0005435885136	3224	Economy	6300.00
0005435885417	3224	Economy	6300.00
0005435885323	3224	Economy	6300.00
0005435885440	3224	Economy	6300.00
0005435885512	3224	Economy	6300.00
0005435885432	3224	Economy	6300.00
0005435885273	3224	Economy	6300.00
0005435885355	3224	Economy	6300.00
0005435885552	3224	Economy	6300.00
0005435885308	3224	Economy	6300.00
0005435885226	3224	Economy	6300.00
0005435885298	3224	Economy	6300.00
0005435885369	3224	Economy	6300.00
0005435885345	3224	Economy	6900.00
0005435885237	3224	Economy	6900.00
0005435885225	3224	Economy	6300.00
0005435885431	3224	Economy	6300.00
0005435885239	3224	Economy	6300.00
0005435885143	3224	Economy	6300.00
0005435885433	3224	Economy	6300.00
0005435885330	3224	Economy	6300.00
0005435885416	3224	Economy	6300.00
0005435885524	3224	Economy	6300.00
0005435885441	3224	Economy	6300.00
0005435885368	3224	Economy	6300.00
0005435885400	3224	Economy	6300.00
0005435885415	3224	Economy	6300.00
0005435885461	3224	Economy	6300.00
0005435885480	3224	Economy	6300.00
0005435885223	3224	Economy	6300.00
0005435885227	3224	Economy	6300.00
0005435885137	3224	Economy	6300.00
0005435885367	3224	Economy	6300.00
0005435885420	3224	Economy	6300.00
0005435885257	3224	Economy	6300.00
0005435885215	3224	Economy	6300.00
0005435885274	3224	Economy	6300.00
0005432460376	8198	Business	18800.00
0005432460346	8198	Business	18800.00
0005432042850	8198	Business	18800.00
0005433507215	8198	Business	18800.00
0005434326276	8198	Business	18800.00
0005432460397	8198	Business	18800.00
0005435885689	8198	Business	18800.00
0005435885686	8198	Business	18800.00
0005432460380	8198	Business	18800.00
0005435885703	8198	Business	18800.00
0005432460371	8198	Business	18800.00
0005435885695	8198	Business	18800.00
0005432460393	8198	Business	18800.00
0005432042839	8198	Business	18800.00
0005435885716	8198	Business	18800.00
0005432460387	8198	Business	18800.00
0005433507186	8198	Business	18800.00
0005432460363	8198	Business	18800.00
0005432460364	8198	Business	18800.00
0005432042842	8198	Business	18800.00
0005432460356	8198	Business	18800.00
0005435885724	8198	Business	18800.00
0005435885701	8198	Business	18800.00
0005435885721	8198	Business	18800.00
0005435885713	8198	Business	18800.00
0005435885744	8198	Economy	6900.00
0005435885706	8198	Economy	6900.00
0005435885730	8198	Economy	6900.00
0005434312340	8198	Economy	6900.00
0005432460357	8198	Economy	6900.00
0005435885731	8198	Economy	6300.00
0005432460368	8198	Economy	6300.00
0005435885696	8198	Economy	6300.00
0005432460385	8198	Economy	6300.00
0005433507149	8198	Economy	6300.00
0005433507203	8198	Economy	6300.00
0005435885691	8198	Economy	6300.00
0005435885692	8198	Economy	6300.00
0005435885714	8198	Economy	6300.00
0005435885718	8198	Economy	6300.00
0005433507182	8198	Economy	6300.00
0005433507166	8198	Economy	6300.00
0005435885735	8198	Economy	6300.00
0005432460369	8198	Economy	6300.00
0005435885728	8198	Economy	6300.00
0005435885705	8198	Economy	6300.00
0005432460349	8198	Economy	6300.00
0005435885717	8198	Economy	6300.00
0005435885740	8198	Economy	6300.00
0005435885732	8198	Economy	6300.00
0005435885742	8198	Economy	6300.00
0005432460384	8198	Economy	6300.00
0005432460390	8198	Economy	6300.00
0005435885722	8198	Economy	6300.00
0005435885707	8198	Economy	6300.00
0005432042845	8198	Economy	6300.00
0005432460382	8198	Economy	6300.00
0005435885702	8198	Economy	6300.00
0005433507133	8198	Economy	6300.00
0005432460367	8198	Economy	6300.00
0005435885710	8198	Economy	6300.00
0005432460378	8198	Economy	6300.00
0005435885699	8198	Economy	6300.00
0005435885697	8198	Economy	6300.00
0005434326277	8198	Economy	6300.00
0005432460347	8198	Economy	6300.00
0005435885743	8198	Economy	6300.00
0005432460375	8198	Economy	6300.00
0005432042843	8198	Economy	6300.00
0005432042838	8198	Economy	6300.00
0005435885726	8198	Economy	6300.00
0005432460355	8198	Economy	6300.00
0005435885725	8198	Economy	6300.00
0005435885698	8198	Economy	6300.00
0005435885729	8198	Economy	6300.00
0005435885739	8198	Economy	6300.00
0005432460351	8198	Economy	6900.00
0005433507174	8198	Economy	6900.00
0005435885704	8198	Economy	6900.00
0005435885719	8198	Economy	6900.00
0005432460372	8198	Economy	6900.00
0005435885693	8198	Economy	6300.00
0005432042844	8198	Economy	6300.00
0005432460392	8198	Economy	6300.00
0005432460377	8198	Economy	6300.00
0005432460389	8198	Economy	6900.00
0005432042841	8198	Economy	6300.00
0005432460366	8198	Economy	6300.00
0005432460398	8198	Economy	6300.00
0005432042851	8198	Economy	6300.00
0005432460383	8198	Economy	6300.00
0005435885720	8198	Economy	6300.00
0005432042840	8198	Economy	6300.00
0005432460373	8198	Economy	6300.00
0005432460381	8198	Economy	6300.00
0005435885715	8198	Economy	6300.00
0005435885694	8198	Economy	6300.00
0005435885712	8198	Economy	6300.00
0005435885741	8198	Economy	6300.00
0005435885700	8198	Economy	6300.00
0005435885738	8198	Economy	6300.00
0005432460370	8198	Economy	6300.00
0005434326275	8198	Economy	6300.00
0005432042848	8198	Economy	6300.00
0005432460354	8198	Economy	6300.00
0005432460391	8198	Economy	6300.00
0005432460362	8198	Economy	6300.00
0005435885708	8198	Economy	6300.00
0005432042846	8198	Economy	6300.00
0005432460350	8198	Economy	6300.00
0005432460360	8198	Economy	6300.00
0005432460396	8198	Economy	6300.00
0005433507212	8198	Economy	6300.00
0005435885711	8198	Economy	6300.00
0005435885709	8198	Economy	6300.00
0005435885727	8198	Economy	6300.00
0005435885734	8198	Economy	6300.00
0005432460359	8198	Economy	6300.00
0005432460352	8198	Economy	6300.00
0005432460388	8198	Economy	6300.00
0005432460379	8198	Economy	6300.00
0005435885688	8198	Economy	6300.00
0005432460348	8198	Economy	6300.00
0005435885737	8198	Economy	6300.00
0005432460395	8198	Economy	6300.00
0005435885687	8198	Economy	6300.00
0005432460386	8198	Economy	6300.00
0005433507216	8198	Economy	6300.00
0005432460358	8198	Economy	6300.00
0005432460394	8198	Economy	6300.00
0005435885736	8198	Economy	6300.00
0005435885690	8198	Economy	6300.00
0005432042847	8198	Economy	6300.00
0005432042849	8198	Economy	6300.00
0005435885723	8198	Economy	6300.00
0005433507183	8198	Economy	6300.00
0005435885733	8198	Economy	6300.00
0005432460353	8198	Economy	6300.00
0005432460361	8198	Economy	6300.00
0005432460365	8198	Economy	6300.00
0005432460374	8198	Economy	6300.00
0005433805355	8199	Business	18800.00
0005433805408	8199	Business	18800.00
0005433805466	8199	Business	18800.00
0005434271312	8199	Business	18800.00
0005433633795	8199	Business	18800.00
0005433633693	8199	Business	18800.00
0005433805405	8199	Business	18800.00
0005433633885	8199	Business	18800.00
0005433805315	8199	Economy	6900.00
0005433805395	8199	Economy	6900.00
0005433805422	8199	Economy	6900.00
0005433805413	8199	Economy	6300.00
0005433633573	8199	Economy	6300.00
0005433633862	8199	Economy	6300.00
0005433805453	8199	Economy	6300.00
0005434271323	8199	Economy	6300.00
0005433633835	8199	Economy	6300.00
0005433633877	8199	Economy	6300.00
0005433633869	8199	Economy	6300.00
0005433633692	8199	Economy	6300.00
0005433805469	8199	Economy	6300.00
0005433633572	8199	Economy	6300.00
0005433633920	8199	Economy	6300.00
0005435854063	8199	Economy	6300.00
0005433805467	8199	Economy	6300.00
0005433805350	8199	Economy	6300.00
0005433805257	8199	Economy	6300.00
0005433805394	8199	Economy	6300.00
0005433633674	8199	Economy	6300.00
0005433805333	8199	Economy	6300.00
0005433633710	8199	Economy	6300.00
0005433805317	8199	Economy	6300.00
0005433633873	8199	Economy	6300.00
0005433633874	8199	Economy	6300.00
0005433633711	8199	Economy	6300.00
0005433633830	8199	Economy	6300.00
0005433633870	8199	Economy	6300.00
0005433633900	8199	Economy	6300.00
0005433805291	8199	Economy	6300.00
0005433633728	8199	Economy	6300.00
0005433805454	8199	Economy	6300.00
0005433805268	8199	Economy	6300.00
0005433805490	8199	Economy	6300.00
0005433633863	8199	Economy	6900.00
0005433805409	8199	Economy	6900.00
0005433633840	8199	Economy	6300.00
0005433633785	8199	Economy	6300.00
0005433805299	8199	Economy	6900.00
0005433633737	8199	Economy	6300.00
0005433805292	8199	Economy	6300.00
0005433633786	8199	Economy	6300.00
0005433633881	8199	Economy	6300.00
0005433633748	8199	Economy	6300.00
0005433805341	8199	Economy	6300.00
0005433805396	8199	Economy	6300.00
0005433805431	8199	Economy	6300.00
0005433633834	8199	Economy	6300.00
0005433805403	8199	Economy	6300.00
0005433805369	8199	Economy	6300.00
0005433633770	8199	Economy	6300.00
0005434271311	8199	Economy	6300.00
0005433633729	8199	Economy	6300.00
0005433805417	8199	Economy	6300.00
0005433805285	8199	Economy	6300.00
0005433805503	8199	Economy	6300.00
0005433805334	8199	Economy	6300.00
0005433633897	8199	Economy	6300.00
0005433633814	8199	Economy	6300.00
0005433805374	8199	Economy	6300.00
0005433805349	8199	Economy	6300.00
0005433805404	8199	Economy	6300.00
0005433454896	4557	Business	9900.00
0005432728059	4557	Business	9900.00
0005432383569	4557	Business	9900.00
0005433194884	4557	Business	9900.00
0005432383541	4557	Business	9900.00
0005433453777	4557	Business	9900.00
0005432383540	4557	Business	9900.00
0005433722282	4557	Business	9900.00
0005432383539	4557	Business	9900.00
0005433453778	4557	Economy	3300.00
0005433194883	4557	Economy	3300.00
0005432383563	4557	Economy	3300.00
0005432728061	4557	Economy	3300.00
0005432383556	4557	Economy	3300.00
0005433194881	4557	Economy	3300.00
0005432383538	4557	Economy	3300.00
0005433194886	4557	Economy	3300.00
0005432728051	4557	Economy	3600.00
0005432728056	4557	Economy	3600.00
0005433194882	4557	Economy	3600.00
0005432383543	4557	Economy	3600.00
0005433453779	4557	Economy	3300.00
0005432728054	4557	Economy	3300.00
0005432383568	4557	Economy	3300.00
0005433454897	4557	Economy	3300.00
0005432383547	4557	Economy	3300.00
0005432383537	4557	Economy	3300.00
0005433194887	4557	Economy	3300.00
0005432383535	4557	Economy	3300.00
0005432383570	4557	Economy	3300.00
0005432728053	4557	Economy	3300.00
0005432728057	4557	Economy	3300.00
0005432383533	4557	Economy	3300.00
0005432383557	4557	Economy	3300.00
0005432383551	4557	Economy	3300.00
0005432383536	4557	Economy	3300.00
0005432383562	4557	Economy	3300.00
0005432383555	4557	Economy	3300.00
0005432383564	4557	Economy	3300.00
0005432728052	4557	Economy	3300.00
0005432383565	4557	Economy	3300.00
0005433194879	4557	Economy	3300.00
0005433194885	4557	Economy	3300.00
0005432728060	4557	Economy	3300.00
0005432728049	4557	Economy	3300.00
0005432383544	4557	Economy	3300.00
0005433454895	4557	Economy	3300.00
0005432383550	4557	Economy	3300.00
0005432383542	4557	Economy	3300.00
0005432383559	4557	Economy	3300.00
0005432383546	4557	Economy	3300.00
0005433194880	4557	Economy	3300.00
0005433722283	4557	Economy	3300.00
0005432383545	4557	Economy	3300.00
0005432383548	4557	Economy	3300.00
0005432383566	4557	Economy	3300.00
0005432728058	4557	Economy	3300.00
0005433194877	4557	Economy	3300.00
0005432383558	4557	Economy	3300.00
0005432728050	4557	Economy	3300.00
0005433194878	4557	Economy	3300.00
0005432383561	4557	Economy	3300.00
0005432383553	4557	Economy	3300.00
0005432383534	4557	Economy	3300.00
0005432383554	4557	Economy	3300.00
0005432383549	4557	Economy	3300.00
0005432728055	4557	Economy	3300.00
0005432383552	4557	Economy	3300.00
0005432383560	4557	Economy	3300.00
0005432383567	4557	Economy	3300.00
0005432383061	30237	Business	9900.00
0005433722202	30237	Business	9900.00
0005432383125	30237	Business	9900.00
0005433722215	30237	Business	9900.00
0005432383185	30237	Business	9900.00
0005433722216	30237	Business	9900.00
0005433451618	30237	Economy	3300.00
0005432383127	30237	Economy	3300.00
0005433451621	30237	Economy	3300.00
0005432383222	30237	Economy	3300.00
0005433194852	30237	Economy	3300.00
0005432383128	30237	Economy	3300.00
0005432383105	30237	Economy	3600.00
0005432383050	30237	Economy	3600.00
0005432383077	30237	Economy	3600.00
0005432727975	30237	Economy	3600.00
0005432727929	30237	Economy	3300.00
0005432383059	30237	Economy	3300.00
0005432383110	30237	Economy	3300.00
0005433722211	30237	Economy	3300.00
0005432383012	30237	Economy	3300.00
0005432383223	30237	Economy	3300.00
0005432383058	30237	Economy	3300.00
0005432727961	30237	Economy	3300.00
0005432383130	30237	Economy	3300.00
0005432383213	30237	Economy	3300.00
0005432383057	30237	Economy	3300.00
0005432382944	30237	Economy	3300.00
0005433722212	30237	Economy	3300.00
0005432383069	30237	Economy	3300.00
0005432383180	30237	Economy	3300.00
0005433722201	30237	Economy	3300.00
0005433453756	30237	Economy	3300.00
0005432383186	30237	Economy	3300.00
0005432383245	30237	Economy	3300.00
0005432383089	30237	Economy	3300.00
0005433453761	30237	Economy	3300.00
0005433453757	30237	Economy	3300.00
0005432383111	30237	Economy	3300.00
0005432383034	30237	Economy	3300.00
0005432383070	30237	Economy	3300.00
0005432383224	30237	Economy	3300.00
0005432383062	30237	Economy	3300.00
0005432383071	30237	Economy	3300.00
0005432383102	30237	Economy	3300.00
0005432383194	30237	Economy	3300.00
0005432383103	30237	Economy	3300.00
0005432383126	30237	Economy	3300.00
0005432383159	30237	Economy	3300.00
0005432382928	30237	Economy	3300.00
0005432383104	30237	Economy	3300.00
0005432383003	30237	Economy	3300.00
0005432727960	30237	Economy	3300.00
0005432383199	30237	Economy	3300.00
0005433453755	30237	Economy	3300.00
0005432382979	30237	Economy	3300.00
0005433722194	30237	Economy	3300.00
0005432727928	30237	Economy	3300.00
0005435529457	1712	Business	57200.00
0005435541203	1712	Business	57200.00
0005435529463	1712	Business	57200.00
0005435529458	1712	Business	57200.00
0005435541212	1712	Business	57200.00
0005435541209	1712	Business	57200.00
0005435529466	1712	Business	57200.00
0005435541199	1712	Economy	19100.00
0005435529475	1712	Economy	19100.00
0005435541221	1712	Economy	19100.00
0005432294510	1712	Economy	19100.00
0005435541215	1712	Economy	19100.00
0005433516973	1712	Economy	21000.00
0005435529465	1712	Economy	21000.00
0005435529468	1712	Economy	21000.00
0005435541211	1712	Economy	19100.00
0005433516974	1712	Economy	19100.00
0005435529474	1712	Economy	19100.00
0005432294509	1712	Economy	19100.00
0005435541206	1712	Economy	19100.00
0005433516978	1712	Economy	19100.00
0005435541200	1712	Economy	19100.00
0005433516971	1712	Economy	19100.00
0005435541219	1712	Economy	19100.00
0005435529461	1712	Economy	19100.00
0005435541202	1712	Economy	19100.00
0005435541214	1712	Economy	19100.00
0005433516970	1712	Economy	19100.00
0005433516976	1712	Economy	19100.00
0005433516972	1712	Economy	19100.00
0005435529464	1712	Economy	19100.00
0005435541220	1712	Economy	19100.00
0005435529467	1712	Economy	19100.00
0005435529471	1712	Economy	19100.00
0005435529459	1712	Economy	19100.00
0005435529460	1712	Economy	19100.00
0005435541207	1712	Economy	19100.00
0005432925042	1712	Economy	19100.00
0005435541216	1712	Economy	19100.00
0005435529462	1712	Economy	19100.00
0005435529473	1712	Economy	19100.00
0005435541204	1712	Economy	19100.00
0005435541217	1712	Economy	19100.00
0005435529476	1712	Economy	19100.00
0005435529469	1712	Economy	19100.00
0005435529456	1712	Economy	19100.00
0005435541213	1712	Economy	19100.00
0005433516977	1712	Economy	19100.00
0005435529470	1712	Economy	19100.00
0005435541210	1712	Economy	19100.00
0005435529472	1712	Economy	19100.00
0005432925043	1712	Economy	19100.00
0005433516975	1712	Economy	19100.00
0005435541218	1712	Economy	19100.00
0005435541201	1712	Economy	19100.00
0005435541205	1712	Economy	19100.00
0005435541208	1712	Economy	19100.00
0005435541042	22028	Business	57200.00
0005435517888	22028	Business	57200.00
0005433516911	22028	Business	57200.00
0005435540912	22028	Business	57200.00
0005435517887	22028	Business	57200.00
0005435517886	22028	Business	57200.00
0005435541011	22028	Business	57200.00
0005435540927	22028	Business	57200.00
0005435517876	22028	Business	57200.00
0005435517927	22028	Economy	19100.00
0005433516868	22028	Economy	19100.00
0005435517885	22028	Economy	19100.00
0005435541022	22028	Economy	19100.00
0005433516855	22028	Economy	19100.00
0005435540867	22028	Economy	19100.00
0005435517855	22028	Economy	21000.00
0005435517958	22028	Economy	21000.00
0005435541036	22028	Economy	21000.00
0005435541072	22028	Economy	21000.00
0005435541020	22028	Economy	19100.00
0005432925081	22028	Economy	19100.00
0005435517905	22028	Economy	19100.00
0005435517950	22028	Economy	19100.00
0005435517790	22028	Economy	19100.00
0005433516872	22028	Economy	19100.00
0005433516906	22028	Economy	19100.00
0005435517872	22028	Economy	19100.00
0005433516910	22028	Economy	19100.00
0005435517902	22028	Economy	19100.00
0005435540925	22028	Economy	19100.00
0005435540979	22028	Economy	19100.00
0005435541102	22028	Economy	19100.00
0005435541021	22028	Economy	19100.00
0005435540911	22028	Economy	19100.00
0005435540994	22028	Economy	19100.00
0005435517942	22028	Economy	19100.00
0005435517949	22028	Economy	19100.00
0005432925083	22028	Economy	19100.00
0005435540924	22028	Economy	19100.00
0005435540913	22028	Economy	19100.00
0005435517937	22028	Economy	19100.00
0005435541005	22028	Economy	19100.00
0005435517884	22028	Economy	19100.00
0005435541135	22028	Economy	19100.00
0005435517948	22028	Economy	19100.00
0005435517926	22028	Economy	19100.00
0005435517791	22028	Economy	19100.00
0005435517883	22028	Economy	19100.00
0005435541035	22028	Economy	19100.00
0005432925080	22028	Economy	19100.00
0005435541003	22028	Economy	19100.00
0005432925082	22028	Economy	19100.00
0005435540995	22028	Economy	19100.00
0005435540926	22028	Economy	19100.00
0005433516907	22028	Economy	19100.00
0005435541077	22028	Economy	19100.00
0005435540968	22028	Economy	19100.00
0005435517868	22028	Economy	19100.00
0005432839329	7351	Business	18500.00
0005432839324	7351	Business	18500.00
0005432839320	7351	Business	18500.00
0005432839317	7351	Business	18500.00
0005432839308	7351	Business	18500.00
0005434459005	7351	Business	18500.00
0005434458992	7351	Business	18500.00
0005432839312	7351	Business	18500.00
0005435252702	7351	Business	18500.00
0005435252723	7351	Economy	6200.00
0005432839322	7351	Economy	6200.00
0005434458997	7351	Economy	6200.00
0005434459009	7351	Economy	6200.00
0005434459007	7351	Economy	6200.00
0005432839334	7351	Economy	6200.00
0005435252718	7351	Economy	6200.00
0005434459000	7351	Economy	6200.00
0005435491440	7351	Economy	6200.00
0005432839318	7351	Economy	6800.00
0005435252666	7351	Economy	6800.00
0005434459003	7351	Economy	6800.00
0005435252704	7351	Economy	6800.00
0005435252691	7351	Economy	6200.00
0005432839335	7351	Economy	6200.00
0005432839326	7351	Economy	6200.00
0005432839328	7351	Economy	6200.00
0005432839310	7351	Economy	6200.00
0005432839331	7351	Economy	6200.00
0005434459004	7351	Economy	6200.00
0005432073421	7351	Economy	6200.00
0005435252736	7351	Economy	6200.00
0005432839332	7351	Economy	6200.00
0005432839339	7351	Economy	6200.00
0005432839330	7351	Economy	6200.00
0005435252684	7351	Economy	6200.00
0005434664952	7351	Economy	6200.00
0005432841031	7351	Economy	6200.00
0005432839325	7351	Economy	6200.00
0005434458995	7351	Economy	6200.00
0005432839321	7351	Economy	6200.00
0005434458993	7351	Economy	6200.00
0005434458990	7351	Economy	6200.00
0005434458991	7351	Economy	6200.00
0005434458998	7351	Economy	6200.00
0005432839336	7351	Economy	6200.00
0005435252739	7351	Economy	6200.00
0005432839319	7351	Economy	6200.00
0005432839333	7351	Economy	6200.00
0005432823467	7351	Economy	6200.00
0005432839314	7351	Economy	6200.00
0005435252731	7351	Economy	6200.00
0005435252680	7351	Economy	6200.00
0005432073423	7351	Economy	6200.00
0005432839311	7351	Economy	6200.00
0005432839327	7351	Economy	6200.00
0005432073424	7351	Economy	6200.00
0005432073425	7351	Economy	6200.00
0005434458996	7351	Economy	6200.00
0005435252713	7351	Economy	6200.00
0005434459006	7351	Economy	6200.00
0005435491442	7351	Economy	6200.00
0005435252734	7351	Economy	6200.00
0005432073422	7351	Economy	6200.00
0005432839309	7351	Economy	6200.00
0005435252743	7351	Economy	6200.00
0005435252735	7351	Economy	6200.00
0005434459002	7351	Economy	6200.00
0005432839316	7351	Economy	6200.00
0005434459001	7351	Economy	6200.00
0005432839315	7351	Economy	6200.00
0005432839323	7351	Economy	6200.00
0005435252712	7351	Economy	6200.00
0005435252744	7351	Economy	6200.00
0005434458994	7351	Economy	6200.00
0005432839337	7351	Economy	6200.00
0005435491441	7351	Economy	6200.00
0005434459008	7351	Economy	6200.00
0005434458988	7351	Economy	6200.00
0005432839313	7351	Economy	6200.00
0005434458999	7351	Economy	6200.00
0005432839338	7351	Economy	6200.00
0005435252742	7351	Economy	6200.00
0005434458989	7351	Economy	6200.00
0005434458987	7351	Economy	6200.00
0005432839114	28893	Business	18500.00
0005432839021	28893	Business	18500.00
0005434458801	28893	Business	18500.00
0005434458825	28893	Business	18500.00
0005434458747	28893	Business	18500.00
0005435252871	28893	Business	18500.00
0005434458845	28893	Business	18500.00
0005435252857	28893	Business	18500.00
0005434458834	28893	Business	18500.00
0005435252856	28893	Business	18500.00
0005432823453	28893	Business	18500.00
0005432839018	28893	Economy	6200.00
0005435252873	28893	Economy	6200.00
0005432839083	28893	Economy	6200.00
0005432823455	28893	Economy	6200.00
0005432838941	28893	Economy	6200.00
0005432839192	28893	Economy	6200.00
0005435252861	28893	Economy	6200.00
0005434458751	28893	Economy	6200.00
0005432839261	28893	Economy	6200.00
0005434458787	28893	Economy	6200.00
0005432839065	28893	Economy	6800.00
0005432839066	28893	Economy	6800.00
0005432001042	28893	Economy	6800.00
0005432838942	28893	Economy	6800.00
0005434458859	28893	Economy	6200.00
0005432839023	28893	Economy	6200.00
0005434458748	28893	Economy	6200.00
0005434458799	28893	Economy	6200.00
0005434458750	28893	Economy	6200.00
0005435252864	28893	Economy	6200.00
0005432839024	28893	Economy	6200.00
0005432823454	28893	Economy	6200.00
0005435252870	28893	Economy	6200.00
0005434664982	28893	Economy	6200.00
0005432839171	28893	Economy	6200.00
0005432839089	28893	Economy	6200.00
0005434458860	28893	Economy	6200.00
0005435252872	28893	Economy	6200.00
0005432839172	28893	Economy	6200.00
0005435252869	28893	Economy	6200.00
0005435252865	28893	Economy	6200.00
0005434458835	28893	Economy	6200.00
0005432839044	28893	Economy	6200.00
0005432839028	28893	Economy	6200.00
0005434458746	28893	Economy	6200.00
0005432841011	28893	Economy	6200.00
0005432839025	28893	Economy	6200.00
0005434458800	28893	Economy	6200.00
0005432839170	28893	Economy	6200.00
0005432839111	28893	Economy	6200.00
0005435252860	28893	Economy	6200.00
0005435252863	28893	Economy	6200.00
0005432839075	28893	Economy	6200.00
0005432839050	28893	Economy	6200.00
0005434458822	28893	Economy	6200.00
0005432839043	28893	Economy	6200.00
0005434458803	28893	Economy	6200.00
0005432839207	28893	Economy	6200.00
0005435252858	28893	Economy	6200.00
0005434458821	28893	Economy	6200.00
0005435252867	28893	Economy	6200.00
0005432001041	28893	Economy	6200.00
0005432839062	28893	Economy	6200.00
0005434458963	28893	Economy	6200.00
0005434458826	28893	Economy	6200.00
0005432839037	28893	Economy	6200.00
0005432839262	28893	Economy	6200.00
0005432839063	28893	Economy	6200.00
0005432839090	28893	Economy	6200.00
0005434458962	28893	Economy	6200.00
0005435252866	28893	Economy	6200.00
0005435491459	28893	Economy	6200.00
0005435252859	28893	Economy	6200.00
0005435252862	28893	Economy	6200.00
0005434458768	28893	Economy	6200.00
0005432839016	28893	Economy	6200.00
0005432839020	28893	Economy	6200.00
0005432839032	28893	Economy	6200.00
0005434458817	28893	Economy	6200.00
0005432839015	28893	Economy	6200.00
0005435252868	28893	Economy	6200.00
0005434458872	28893	Economy	6200.00
0005435990686	8815	Business	145300.00
0005435990693	8815	Business	145300.00
0005435990687	8815	Business	145300.00
0005434276037	8815	Economy	48400.00
0005435990688	8815	Economy	48400.00
0005434276049	8815	Economy	48400.00
0005434276027	8815	Economy	48400.00
0005435990691	8815	Economy	48400.00
0005434276030	8815	Economy	48400.00
0005435990689	8815	Economy	48400.00
0005435990694	8815	Economy	48400.00
0005434276050	8815	Economy	48400.00
0005434276051	8815	Economy	48400.00
0005434276041	8815	Economy	48400.00
0005434276038	8815	Economy	48400.00
0005435990690	8815	Economy	48400.00
0005435990692	8815	Economy	48400.00
0005434276080	15756	Business	145300.00
0005435990612	15756	Business	145300.00
0005435990631	15756	Business	145300.00
0005434276078	15756	Economy	48400.00
0005434276083	15756	Economy	48400.00
0005435990630	15756	Economy	48400.00
0005434276079	15756	Economy	53300.00
0005435990629	15756	Economy	53300.00
0005435990650	15756	Economy	53300.00
0005435990651	15756	Economy	48400.00
0005435990661	15756	Economy	48400.00
0005434276082	15756	Economy	48400.00
0005435990647	15756	Economy	48400.00
0005435990641	15756	Economy	48400.00
0005435990625	15756	Economy	48400.00
0005435990611	15756	Economy	48400.00
0005434276081	15756	Economy	48400.00
0005435990638	15756	Economy	48400.00
0005435990640	15756	Economy	48400.00
0005435990646	15756	Economy	48400.00
0005435990639	15756	Economy	48400.00
0005432909278	2092	Economy	13300.00
0005433468417	2092	Economy	13300.00
0005432909290	2092	Economy	13300.00
0005433468400	2092	Economy	13300.00
0005433468415	2092	Economy	12100.00
0005432909279	2092	Economy	12100.00
0005433468403	2092	Economy	12100.00
0005433468416	2092	Economy	12100.00
0005432909287	2092	Economy	12100.00
0005432909263	2092	Economy	12100.00
0005432909293	2092	Economy	12100.00
0005433468407	2092	Economy	12100.00
0005432909257	2092	Economy	12100.00
0005432909270	2092	Economy	12100.00
0005433468422	2092	Economy	12100.00
0005433468411	2092	Economy	12100.00
0005433468409	2092	Economy	12100.00
0005433468420	2092	Economy	12100.00
0005433468404	2092	Economy	12100.00
0005433468424	2092	Economy	12100.00
0005433468421	2092	Economy	12100.00
0005433468406	2092	Economy	12100.00
0005433468413	2092	Economy	12100.00
0005433468399	2092	Economy	12100.00
0005433468402	2092	Economy	12100.00
0005433468410	2092	Economy	12100.00
0005433468414	2092	Economy	12100.00
0005432909294	2092	Economy	12100.00
0005432909288	2092	Economy	12100.00
0005433468401	2092	Economy	12100.00
0005433468425	2092	Economy	12100.00
0005433468423	2092	Economy	12100.00
0005432909289	2092	Economy	12100.00
0005433468418	2092	Economy	12100.00
0005433468412	2092	Economy	12100.00
0005433468408	2092	Economy	12100.00
0005432909271	2092	Economy	12100.00
0005432909281	2092	Economy	12100.00
0005433468405	2092	Economy	12100.00
0005432909280	2092	Economy	12100.00
0005433468419	2092	Economy	12100.00
0005432909266	2092	Economy	12100.00
0005432909269	2092	Economy	12100.00
0005432909258	2092	Economy	12100.00
0005434149681	6385	Business	36600.00
0005434149755	6385	Business	36600.00
0005432360806	6385	Business	36600.00
0005432336144	6385	Business	36600.00
0005432062279	6385	Business	36600.00
0005435177137	6385	Business	36600.00
0005432360820	6385	Business	36600.00
0005432360793	6385	Business	36600.00
0005432360810	6385	Business	36600.00
0005432363445	6385	Business	36600.00
0005432360814	6385	Economy	12200.00
0005432360822	6385	Economy	12200.00
0005435176969	6385	Economy	12200.00
0005434149704	6385	Economy	12200.00
0005432360811	6385	Economy	12200.00
0005432360819	6385	Economy	12200.00
0005435177095	6385	Economy	12200.00
0005434149793	6385	Economy	12200.00
0005432360788	6385	Economy	12200.00
0005432360828	6385	Economy	12200.00
0005432360816	6385	Economy	12200.00
0005435177046	6385	Economy	12200.00
0005432360801	6385	Economy	12200.00
0005435177096	6385	Economy	12200.00
0005432360833	6385	Economy	12200.00
0005432360798	6385	Economy	12200.00
0005432363448	6385	Economy	12200.00
0005432360823	6385	Economy	12200.00
0005432360803	6385	Economy	12200.00
0005432360791	6385	Economy	12200.00
0005432336141	6385	Economy	12200.00
0005432360794	6385	Economy	12200.00
0005435177226	6385	Economy	12200.00
0005432360802	6385	Economy	12200.00
0005432360824	6385	Economy	12200.00
0005432360832	6385	Economy	12200.00
0005435177043	6385	Economy	12200.00
0005435177045	6385	Economy	12200.00
0005432360795	6385	Economy	12200.00
0005434149744	6385	Economy	12200.00
0005432336139	6385	Economy	12200.00
0005432360813	6385	Economy	12200.00
0005432360790	6385	Economy	13400.00
0005432360799	6385	Economy	13400.00
0005432336145	6385	Economy	13400.00
0005435177068	6385	Economy	13400.00
0005432360815	6385	Economy	13400.00
0005432062278	6385	Economy	13400.00
0005435177173	6385	Economy	12200.00
0005432336147	6385	Economy	12200.00
0005435723042	6385	Economy	12200.00
0005432360800	6385	Economy	12200.00
0005432336148	6385	Economy	12200.00
0005432363446	6385	Economy	12200.00
0005432360797	6385	Economy	12200.00
0005434149757	6385	Economy	12200.00
0005432360831	6385	Economy	12200.00
0005432336149	6385	Economy	12200.00
0005432360830	6385	Economy	12200.00
0005435723041	6385	Economy	12200.00
0005434149756	6385	Economy	12200.00
0005432062277	6385	Economy	12200.00
0005432062280	6385	Economy	12200.00
0005432360821	6385	Economy	12200.00
0005432360827	6385	Economy	12200.00
0005432360808	6385	Economy	12200.00
0005432360818	6385	Economy	12200.00
0005432336151	6385	Economy	12200.00
0005432360825	6385	Economy	12200.00
0005432360817	6385	Economy	12200.00
0005435177075	6385	Economy	12200.00
0005435177112	6385	Economy	12200.00
0005435177125	6385	Economy	12200.00
0005434149766	6385	Economy	12200.00
0005432360789	6385	Economy	12200.00
0005432360807	6385	Economy	12200.00
0005432360785	6385	Economy	12200.00
0005435177211	6385	Economy	12200.00
0005432360796	6385	Economy	12200.00
0005434149758	6385	Economy	12200.00
0005435177113	6385	Economy	12200.00
0005432336142	6385	Economy	12200.00
0005434149730	6385	Economy	12200.00
0005432336143	6385	Economy	12200.00
0005432360805	6385	Economy	12200.00
0005432363447	6385	Economy	12200.00
0005435177061	6385	Economy	12200.00
0005434149731	6385	Economy	12200.00
0005432360804	6385	Economy	12200.00
0005435177227	6385	Economy	12200.00
0005432360787	6385	Economy	12200.00
0005434149751	6385	Economy	12200.00
0005434149724	6385	Economy	12200.00
0005435176970	6385	Economy	12200.00
0005435177172	6385	Economy	12200.00
0005432360809	6385	Economy	12200.00
0005432360829	6385	Economy	12200.00
0005432360792	6385	Economy	12200.00
0005432360826	6385	Economy	12200.00
0005432336150	6385	Economy	12200.00
0005432336140	6385	Economy	12200.00
0005432336146	6385	Economy	12200.00
0005432360786	6385	Economy	12200.00
0005432360812	6385	Economy	12200.00
0005432360464	20997	Business	36600.00
0005434149842	20997	Business	36600.00
0005435177325	20997	Business	36600.00
0005432336026	20997	Business	36600.00
0005432336094	20997	Business	36600.00
0005435177324	20997	Business	36600.00
0005434149834	20997	Business	36600.00
0005432360406	20997	Business	36600.00
0005432363425	20997	Business	36600.00
0005432360285	20997	Business	36600.00
0005432363416	20997	Business	36600.00
0005435177320	20997	Business	36600.00
0005432360435	20997	Economy	12200.00
0005434149837	20997	Economy	12200.00
0005432360436	20997	Economy	12200.00
0005432360387	20997	Economy	12200.00
0005435177344	20997	Economy	12200.00
0005435177331	20997	Economy	12200.00
0005432360568	20997	Economy	12200.00
0005435490265	20997	Economy	12200.00
0005432335967	20997	Economy	12200.00
0005435177334	20997	Economy	12200.00
0005432360364	20997	Economy	12200.00
0005432336025	20997	Economy	12200.00
0005432360449	20997	Economy	12200.00
0005434149844	20997	Economy	12200.00
0005432360569	20997	Economy	12200.00
0005432336029	20997	Economy	12200.00
0005435177319	20997	Economy	12200.00
0005432336020	20997	Economy	12200.00
0005432052774	20997	Economy	12200.00
0005432336034	20997	Economy	12200.00
0005435177341	20997	Economy	12200.00
0005435177322	20997	Economy	12200.00
0005432360427	20997	Economy	12200.00
0005432360410	20997	Economy	12200.00
0005432360452	20997	Economy	12200.00
0005432052775	20997	Economy	12200.00
0005432360426	20997	Economy	12200.00
0005432360486	20997	Economy	12200.00
0005432360382	20997	Economy	12200.00
0005432360450	20997	Economy	12200.00
0005432360520	20997	Economy	12200.00
0005434149835	20997	Economy	12200.00
0005435490266	20997	Economy	12200.00
0005432336056	20997	Economy	12200.00
0005432360474	20997	Economy	12200.00
0005432363424	20997	Economy	12200.00
0005435177338	20997	Economy	13400.00
0005432360521	20997	Economy	13400.00
0005432360388	20997	Economy	13400.00
0005432360354	20997	Economy	13400.00
0005432360362	20997	Economy	13400.00
0005432360310	20997	Economy	12200.00
0005432360487	20997	Economy	12200.00
0005432360359	20997	Economy	12200.00
0005434149843	20997	Economy	12200.00
0005432360380	20997	Economy	12200.00
0005432336093	20997	Economy	12200.00
0005435177345	20997	Economy	12200.00
0005434149839	20997	Economy	12200.00
0005434149833	20997	Economy	12200.00
0005432336057	20997	Economy	12200.00
0005434149841	20997	Economy	12200.00
0005435177339	20997	Economy	12200.00
0005432360528	20997	Economy	12200.00
0005432360402	20997	Economy	12200.00
0005435177326	20997	Economy	12200.00
0005432336055	20997	Economy	12200.00
0005432052773	20997	Economy	12200.00
0005432360529	20997	Economy	12200.00
0005432363423	20997	Economy	12200.00
0005435177335	20997	Economy	12200.00
0005432052776	20997	Economy	12200.00
0005435177332	20997	Economy	12200.00
0005435177340	20997	Economy	12200.00
0005432360383	20997	Economy	12200.00
0005432360328	20997	Economy	12200.00
0005432360223	20997	Economy	12200.00
0005435177333	20997	Economy	12200.00
0005435490267	20997	Economy	12200.00
0005432360403	20997	Economy	12200.00
0005435177329	20997	Economy	12200.00
0005432360192	20997	Economy	12200.00
0005435177330	20997	Economy	12200.00
0005432360530	20997	Economy	12200.00
0005432360405	20997	Economy	12200.00
0005435177336	20997	Economy	12200.00
0005432360301	20997	Economy	12200.00
0005432360467	20997	Economy	12200.00
0005432360428	20997	Economy	12200.00
0005435177327	20997	Economy	12200.00
0005435177321	20997	Economy	12200.00
0005434149840	20997	Economy	12200.00
0005435490264	20997	Economy	12200.00
0005432360434	20997	Economy	12200.00
0005432360311	20997	Economy	12200.00
0005432360522	20997	Economy	12200.00
0005432336060	20997	Economy	12200.00
0005435177323	20997	Economy	12200.00
0005435177343	20997	Economy	12200.00
0005435177328	20997	Economy	12200.00
0005432335984	20997	Economy	12200.00
0005432360330	20997	Economy	12200.00
0005432360386	20997	Economy	12200.00
0005432360217	20997	Economy	12200.00
0005432335968	20997	Economy	12200.00
0005432360507	20997	Economy	12200.00
0005435177337	20997	Economy	12200.00
0005435177342	20997	Economy	12200.00
0005432360329	20997	Economy	12200.00
0005432336039	20997	Economy	12200.00
0005434149838	20997	Economy	12200.00
0005432360472	20997	Economy	12200.00
0005432360336	20997	Economy	12200.00
0005434149836	20997	Economy	12200.00
0005432360300	20997	Economy	12200.00
0005434458811	17697	Economy	3400.00
0005434463939	17697	Economy	3400.00
0005434458824	17697	Economy	3100.00
0005434458865	17697	Economy	3100.00
0005434186226	17697	Economy	3100.00
0005434463934	17697	Economy	3100.00
0005434458776	17697	Economy	3100.00
0005434458941	17697	Economy	3100.00
0005434458905	17697	Economy	3100.00
0005434458775	17697	Economy	3100.00
0005434186225	17697	Economy	3100.00
0005434448317	17697	Economy	3100.00
0005434458904	17697	Economy	3100.00
0005434458810	17697	Economy	3100.00
0005434448313	17697	Economy	3100.00
0005434458887	17697	Economy	3100.00
0005434186228	17697	Economy	3100.00
0005434458942	17697	Economy	3100.00
0005434458876	17697	Economy	3100.00
0005434458857	17697	Economy	3100.00
0005434458866	17697	Economy	3100.00
0005434458851	17697	Economy	3100.00
0005434461653	17697	Economy	3100.00
0005434186227	17697	Economy	3100.00
0005434463935	17697	Economy	3100.00
0005434463925	17697	Economy	3100.00
0005434458993	29100	Economy	3400.00
0005434186204	29100	Economy	3100.00
0005434186187	29100	Economy	3100.00
0005434459007	29100	Economy	3100.00
0005434458988	29100	Economy	3100.00
0005434448343	29100	Economy	3100.00
0005434186186	29100	Economy	3100.00
0005434458999	29100	Economy	3100.00
0005434463947	29100	Economy	3100.00
0005434458994	29100	Economy	3100.00
0005434459005	29100	Economy	3100.00
0005434448344	29100	Economy	3100.00
0005434458990	29100	Economy	3100.00
0005434463948	29100	Economy	3100.00
0005434459004	29100	Economy	3100.00
0005434458998	29100	Economy	3100.00
0005434458992	29100	Economy	3100.00
0005434186205	29100	Economy	3100.00
0005434459006	29100	Economy	3100.00
0005434459003	29100	Economy	3100.00
0005434459002	29100	Economy	3100.00
0005434459000	29100	Economy	3100.00
0005434459001	29100	Economy	3100.00
0005434459009	29100	Economy	3100.00
0005434186188	29100	Economy	3100.00
0005434186192	29100	Economy	3100.00
0005434458989	29100	Economy	3100.00
0005434458996	29100	Economy	3100.00
0005434458991	29100	Economy	3100.00
0005434186185	29100	Economy	3100.00
0005434458995	29100	Economy	3100.00
0005434448345	29100	Economy	3100.00
0005434463946	29100	Economy	3100.00
0005434458987	29100	Economy	3100.00
0005434458997	29100	Economy	3100.00
0005434459008	29100	Economy	3100.00
0005432604690	21446	Economy	7300.00
0005432604673	21446	Economy	7300.00
0005432604685	21446	Economy	7300.00
0005432604678	21446	Economy	7300.00
0005435218113	21446	Economy	6600.00
0005432604674	21446	Economy	6600.00
0005432604682	21446	Economy	6600.00
0005432604683	21446	Economy	6600.00
0005432604660	21446	Economy	6600.00
0005432604656	21446	Economy	6600.00
0005432604663	21446	Economy	6600.00
0005432604695	21446	Economy	6600.00
0005432604684	21446	Economy	6600.00
0005432604691	21446	Economy	6600.00
0005432604662	21446	Economy	6600.00
0005432604675	21446	Economy	6600.00
0005435220489	21446	Economy	6600.00
0005432604680	21446	Economy	6600.00
0005432604687	21446	Economy	6600.00
0005432604693	21446	Economy	6600.00
0005432604671	21446	Economy	6600.00
0005432604692	21446	Economy	6600.00
0005432604672	21446	Economy	6600.00
0005432604657	21446	Economy	6600.00
0005432604670	21446	Economy	6600.00
0005432604666	21446	Economy	6600.00
0005432604679	21446	Economy	6600.00
0005432604681	21446	Economy	6600.00
0005432604667	21446	Economy	6600.00
0005432604665	21446	Economy	6600.00
0005432604694	21446	Economy	6600.00
0005432604688	21446	Economy	6600.00
0005432604668	21446	Economy	6600.00
0005432604658	21446	Economy	6600.00
0005432604686	21446	Economy	6600.00
0005432604689	21446	Economy	6600.00
0005432604676	21446	Economy	6600.00
0005432604677	21446	Economy	6600.00
0005432604659	21446	Economy	6600.00
0005432604661	21446	Economy	6600.00
0005432604664	21446	Economy	6600.00
0005432604669	21446	Economy	6600.00
0005435218115	21446	Economy	6600.00
0005432604415	31710	Economy	7300.00
0005432604098	31710	Economy	7300.00
0005432604359	31710	Economy	7300.00
0005432604259	31710	Economy	7300.00
0005432604472	31710	Economy	6600.00
0005432604300	31710	Economy	6600.00
0005432604131	31710	Economy	6600.00
0005432604518	31710	Economy	6600.00
0005432604260	31710	Economy	6600.00
0005432604337	31710	Economy	6600.00
0005432604097	31710	Economy	6600.00
0005432604333	31710	Economy	6600.00
0005432604315	31710	Economy	6600.00
0005432604334	31710	Economy	6600.00
0005432604258	31710	Economy	6600.00
0005432604511	31710	Economy	6600.00
0005432604212	31710	Economy	6600.00
0005432604304	31710	Economy	6600.00
0005432604374	31710	Economy	6600.00
0005432604373	31710	Economy	6600.00
0005432604348	31710	Economy	6600.00
0005432604223	31710	Economy	6600.00
0005432604358	31710	Economy	6600.00
0005432604240	31710	Economy	6600.00
0005432604332	31710	Economy	6600.00
0005432604318	31710	Economy	6600.00
0005432604421	31710	Economy	6600.00
0005432604335	31710	Economy	6600.00
0005432604270	31710	Economy	6600.00
0005432604133	31710	Economy	6600.00
0005432604345	31710	Economy	6600.00
0005432604360	31710	Economy	6600.00
0005432604028	31710	Economy	6600.00
0005432604302	31710	Economy	6600.00
0005432604082	31710	Economy	6600.00
0005432604134	31710	Economy	6600.00
0005432604239	31710	Economy	6600.00
0005432604316	31710	Economy	6600.00
0005432604130	31710	Economy	6600.00
0005432604303	31710	Economy	6600.00
0005432604510	31710	Economy	6600.00
0005432604409	31710	Economy	6600.00
0005432604224	31710	Economy	6600.00
0005432604405	31710	Economy	6600.00
0005432604455	31710	Economy	6600.00
0005432604338	31710	Economy	6600.00
0005432604404	31710	Economy	6600.00
0005432604470	31710	Economy	6600.00
0005432604220	31710	Economy	6600.00
0005434606820	18913	Economy	6600.00
0005434606835	18913	Economy	6600.00
0005434606832	18913	Economy	6600.00
0005434606819	18913	Economy	6600.00
0005434606828	18913	Economy	6600.00
0005434604925	22399	Economy	6600.00
0005434606859	22399	Economy	6600.00
0005434606860	22399	Economy	6600.00
0005434604926	22399	Economy	6600.00
0005434604927	22399	Economy	6600.00
0005434606858	22399	Economy	6600.00
0005434606862	22399	Economy	6600.00
0005434606861	22399	Economy	6600.00
0005432747899	374	Business	44500.00
0005432747919	374	Business	44500.00
0005432891010	374	Business	44500.00
0005432749802	374	Business	44500.00
0005432890935	374	Business	44500.00
0005432220042	374	Business	44500.00
0005432747917	374	Business	44500.00
0005432890950	374	Business	44500.00
0005432890983	374	Business	44500.00
0005432891049	374	Business	44500.00
0005432747915	374	Business	44500.00
0005433293248	374	Economy	14800.00
0005435154610	374	Economy	14800.00
0005432747893	374	Economy	14800.00
0005432747902	374	Economy	14800.00
0005432890953	374	Economy	14800.00
0005432747906	374	Economy	14800.00
0005432747896	374	Economy	14800.00
0005432747895	374	Economy	16300.00
0005432747912	374	Economy	16300.00
0005432890970	374	Economy	16300.00
0005432747897	374	Economy	16300.00
0005432747923	374	Economy	16300.00
0005432747892	374	Economy	14800.00
0005432753328	374	Economy	14800.00
0005432749804	374	Economy	14800.00
0005432751555	374	Economy	14800.00
0005432747909	374	Economy	14800.00
0005432891055	374	Economy	14800.00
0005432747926	374	Economy	14800.00
0005433875377	374	Economy	14800.00
0005432747903	374	Economy	14800.00
0005432891075	374	Economy	14800.00
0005432753329	374	Economy	14800.00
0005432890951	374	Economy	14800.00
0005432747910	374	Economy	14800.00
0005432747891	374	Economy	14800.00
0005433293253	374	Economy	14800.00
0005432753331	374	Economy	14800.00
0005432747914	374	Economy	14800.00
0005432751553	374	Economy	14800.00
0005432747913	374	Economy	14800.00
0005432747925	374	Economy	14800.00
0005432747922	374	Economy	14800.00
0005432753327	374	Economy	14800.00
0005432890969	374	Economy	14800.00
0005432747907	374	Economy	14800.00
0005432747920	374	Economy	14800.00
0005432747918	374	Economy	14800.00
0005433293252	374	Economy	14800.00
0005432749803	374	Economy	14800.00
0005432891078	374	Economy	14800.00
0005433875372	374	Economy	14800.00
0005432747921	374	Economy	14800.00
0005432747905	374	Economy	14800.00
0005432747894	374	Economy	14800.00
0005432747924	374	Economy	14800.00
0005432220041	374	Economy	14800.00
0005432747927	374	Economy	14800.00
0005432891082	374	Economy	14800.00
0005432747928	374	Economy	14800.00
0005432747890	374	Economy	14800.00
0005432890975	374	Economy	14800.00
0005432747911	374	Economy	14800.00
0005432890881	374	Economy	14800.00
0005432747900	374	Economy	14800.00
0005432220043	374	Economy	14800.00
0005432747916	374	Economy	14800.00
0005432747908	374	Economy	14800.00
0005432891067	374	Economy	14800.00
0005432747904	374	Economy	14800.00
0005432747898	374	Economy	14800.00
0005432747901	374	Economy	14800.00
0005433875373	374	Economy	14800.00
0005432891061	374	Economy	14800.00
0005432753330	374	Economy	14800.00
0005432751554	374	Economy	14800.00
0005432747592	12088	Business	44500.00
0005432747593	12088	Business	44500.00
0005432747693	12088	Business	44500.00
0005432891194	12088	Business	44500.00
0005432747545	12088	Business	44500.00
0005435154595	12088	Business	44500.00
0005432747710	12088	Business	44500.00
0005435154591	12088	Business	44500.00
0005432891199	12088	Business	44500.00
0005432891192	12088	Business	44500.00
0005432891206	12088	Business	44500.00
0005432891196	12088	Business	44500.00
0005432891198	12088	Economy	14800.00
0005433293306	12088	Economy	14800.00
0005432747731	12088	Economy	14800.00
0005432747695	12088	Economy	14800.00
0005432891200	12088	Economy	14800.00
0005432747692	12088	Economy	14800.00
0005433293308	12088	Economy	14800.00
0005432891208	12088	Economy	14800.00
0005434153546	12088	Economy	16300.00
0005435154592	12088	Economy	16300.00
0005432749782	12088	Economy	16300.00
0005432747527	12088	Economy	16300.00
0005433293310	12088	Economy	16300.00
0005432747520	12088	Economy	14800.00
0005433293301	12088	Economy	14800.00
0005432891201	12088	Economy	14800.00
0005432891205	12088	Economy	14800.00
0005432747546	12088	Economy	14800.00
0005432747547	12088	Economy	14800.00
0005432747740	12088	Economy	14800.00
0005432747748	12088	Economy	14800.00
0005432747580	12088	Economy	14800.00
0005432891204	12088	Economy	14800.00
0005434153545	12088	Economy	14800.00
0005432891202	12088	Economy	14800.00
0005433293313	12088	Economy	14800.00
0005433293311	12088	Economy	14800.00
0005433293304	12088	Economy	14800.00
0005432756837	12088	Economy	14800.00
0005433293309	12088	Economy	14800.00
0005432749792	12088	Economy	14800.00
0005432756836	12088	Economy	14800.00
0005433293305	12088	Economy	14800.00
0005432747777	12088	Economy	14800.00
0005434153544	12088	Economy	14800.00
0005432747845	12088	Economy	14800.00
0005432756828	12088	Economy	14800.00
0005433293302	12088	Economy	14800.00
0005432214825	12088	Economy	14800.00
0005432747844	12088	Economy	14800.00
0005433293312	12088	Economy	14800.00
0005432747465	12088	Economy	14800.00
0005432753315	12088	Economy	14800.00
0005435154593	12088	Economy	14800.00
0005432747466	12088	Economy	14800.00
0005432747591	12088	Economy	14800.00
0005432891209	12088	Economy	14800.00
0005432891190	12088	Economy	14800.00
0005432891207	12088	Economy	14800.00
0005432891193	12088	Economy	14800.00
0005432891203	12088	Economy	14800.00
0005432747739	12088	Economy	14800.00
0005432747778	12088	Economy	14800.00
0005432747691	12088	Economy	14800.00
0005435154594	12088	Economy	14800.00
0005432747590	12088	Economy	14800.00
0005432747385	12088	Economy	14800.00
0005432747561	12088	Economy	14800.00
0005432747597	12088	Economy	14800.00
0005433293307	12088	Economy	14800.00
0005432747589	12088	Economy	14800.00
0005432747776	12088	Economy	14800.00
0005432756844	12088	Economy	14800.00
0005432214823	12088	Economy	14800.00
0005433293303	12088	Economy	14800.00
0005432747753	12088	Economy	14800.00
0005432747711	12088	Economy	14800.00
0005432749783	12088	Economy	14800.00
0005432747843	12088	Economy	14800.00
0005432891191	12088	Economy	14800.00
0005433875393	12088	Economy	14800.00
0005432747510	12088	Economy	14800.00
0005432891195	12088	Economy	14800.00
0005432214824	12088	Economy	14800.00
0005432747634	12088	Economy	14800.00
0005432747588	12088	Economy	14800.00
0005432891197	12088	Economy	14800.00
0005433525129	18941	Economy	28200.00
0005433525126	18941	Economy	28200.00
0005432927965	18941	Economy	25700.00
0005433525134	18941	Economy	25700.00
0005433525135	18941	Economy	25700.00
0005433531325	18941	Economy	25700.00
0005433533340	18941	Economy	25700.00
0005432927964	18941	Economy	25700.00
0005433525130	18941	Economy	25700.00
0005433525128	18941	Economy	25700.00
0005433531324	18941	Economy	25700.00
0005433525133	18941	Economy	25700.00
0005432927968	18941	Economy	25700.00
0005433533339	18941	Economy	25700.00
0005433533338	18941	Economy	25700.00
0005432927983	18941	Economy	25700.00
0005433525131	18941	Economy	25700.00
0005433525132	18941	Economy	25700.00
0005432927978	18941	Economy	25700.00
0005433525127	18941	Economy	25700.00
0005432928038	32498	Economy	28200.00
0005433531295	32498	Economy	28200.00
0005433525044	32498	Economy	28200.00
0005433531290	32498	Economy	25700.00
0005433525060	32498	Economy	25700.00
0005432928039	32498	Economy	25700.00
0005433525074	32498	Economy	25700.00
0005433531301	32498	Economy	25700.00
0005432928034	32498	Economy	25700.00
0005432928036	32498	Economy	25700.00
0005433525040	32498	Economy	25700.00
0005433525042	32498	Economy	25700.00
0005433525068	32498	Economy	25700.00
0005433525069	32498	Economy	25700.00
0005433527256	32498	Economy	25700.00
0005432928037	32498	Economy	25700.00
0005433525052	32498	Economy	25700.00
0005432928035	32498	Economy	25700.00
0005434824801	5262	Business	84000.00
0005435150159	5262	Business	84000.00
0005432121457	5262	Business	84000.00
0005435373391	5262	Business	84000.00
0005435373436	5262	Business	84000.00
0005434824710	5262	Business	84000.00
0005432396281	5262	Business	84000.00
0005435304165	5262	Business	84000.00
0005435373616	5262	Business	84000.00
0005434824808	5262	Business	84000.00
0005432121460	5262	Business	84000.00
0005434824785	5262	Business	84000.00
0005434824715	5262	Business	84000.00
0005435373490	5262	Business	84000.00
0005434824788	5262	Business	84000.00
0005435373516	5262	Business	84000.00
0005434824698	5262	Business	84000.00
0005432121469	5262	Business	84000.00
0005434824693	5262	Business	84000.00
0005434824765	5262	Business	84000.00
0005435373465	5262	Business	84000.00
0005435373514	5262	Business	84000.00
0005435373194	5262	Business	84000.00
0005435373716	5262	Business	84000.00
0005435373111	5262	Comfort	47600.00
0005434824752	5262	Comfort	47600.00
0005434824735	5262	Comfort	47600.00
0005435372940	5262	Comfort	47600.00
0005435373105	5262	Comfort	47600.00
0005434558349	5262	Comfort	47600.00
0005435373580	5262	Comfort	47600.00
0005434824716	5262	Comfort	47600.00
0005434824687	5262	Comfort	47600.00
0005434824746	5262	Comfort	47600.00
0005434824725	5262	Comfort	47600.00
0005434824773	5262	Comfort	47600.00
0005435373228	5262	Comfort	47600.00
0005434824740	5262	Comfort	47600.00
0005434824719	5262	Comfort	47600.00
0005435373375	5262	Comfort	47600.00
0005434824692	5262	Comfort	47600.00
0005435373139	5262	Comfort	47600.00
0005432121462	5262	Comfort	47600.00
0005432394142	5262	Comfort	47600.00
0005435373461	5262	Comfort	47600.00
0005435150158	5262	Comfort	47600.00
0005434824794	5262	Comfort	47600.00
0005432396279	5262	Comfort	47600.00
0005434824734	5262	Comfort	47600.00
0005432394141	5262	Comfort	47600.00
0005434824771	5262	Comfort	47600.00
0005435373185	5262	Comfort	47600.00
0005434824775	5262	Comfort	47600.00
0005432121464	5262	Comfort	47600.00
0005434824781	5262	Comfort	47600.00
0005434824731	5262	Comfort	47600.00
0005435373335	5262	Comfort	47600.00
0005435373460	5262	Comfort	47600.00
0005434824795	5262	Comfort	47600.00
0005435373447	5262	Comfort	47600.00
0005434824744	5262	Comfort	47600.00
0005435373253	5262	Economy	28000.00
0005435304178	5262	Comfort	47600.00
0005434824807	5262	Economy	28000.00
0005434824763	5262	Economy	28000.00
0005435373171	5262	Economy	28000.00
0005434824758	5262	Economy	28000.00
0005435373252	5262	Economy	28000.00
0005435150161	5262	Economy	28000.00
0005432121459	5262	Economy	28000.00
0005435373106	5262	Economy	28000.00
0005435304170	5262	Economy	28000.00
0005434824721	5262	Economy	28000.00
0005434824789	5262	Economy	28000.00
0005434824742	5262	Economy	28000.00
0005434824694	5262	Economy	28000.00
0005434824816	5262	Economy	28000.00
0005434824747	5262	Economy	28000.00
0005434824690	5262	Economy	28000.00
0005435373444	5262	Economy	28000.00
0005434558350	5262	Economy	28000.00
0005434824779	5262	Economy	28000.00
0005435372913	5262	Economy	28000.00
0005435299767	5262	Economy	28000.00
0005435150150	5262	Economy	28000.00
0005435150154	5262	Economy	28000.00
0005434824713	5262	Economy	28000.00
0005434824751	5262	Economy	28000.00
0005435373389	5262	Economy	28000.00
0005434824770	5262	Economy	28000.00
0005435373200	5262	Economy	28000.00
0005435373143	5262	Economy	28000.00
0005434824700	5262	Economy	28000.00
0005435299803	5262	Economy	28000.00
0005435373550	5262	Economy	28000.00
0005435372879	5262	Economy	28000.00
0005434824728	5262	Economy	28000.00
0005435372926	5262	Economy	28000.00
0005434828721	5262	Economy	28000.00
0005435373305	5262	Economy	28000.00
0005434824714	5262	Economy	28000.00
0005434824800	5262	Economy	28000.00
0005434824815	5262	Economy	28000.00
0005434824743	5262	Economy	28000.00
0005434664981	5262	Economy	28000.00
0005434824745	5262	Economy	28000.00
0005434824764	5262	Economy	28000.00
0005434824708	5262	Economy	28000.00
0005434831191	5262	Economy	28000.00
0005435373547	5262	Economy	28000.00
0005435373488	5262	Economy	28000.00
0005434824761	5262	Economy	28000.00
0005432823449	5262	Economy	28000.00
0005434824796	5262	Economy	28000.00
0005434558351	5262	Economy	30800.00
0005435373181	5262	Economy	30800.00
0005435373462	5262	Economy	28000.00
0005434558352	5262	Economy	28000.00
0005434824720	5262	Economy	30800.00
0005435373275	5262	Economy	30800.00
0005435373227	5262	Economy	30800.00
0005435373226	5262	Economy	28000.00
0005432823444	5262	Economy	28000.00
0005434824726	5262	Economy	28000.00
0005435373284	5262	Economy	28000.00
0005435373169	5262	Economy	28000.00
0005434831192	5262	Economy	28000.00
0005435661918	5262	Economy	28000.00
0005434824793	5262	Economy	28000.00
0005435150156	5262	Economy	28000.00
0005434824756	5262	Economy	28000.00
0005434664980	5262	Economy	28000.00
0005435373201	5262	Economy	28000.00
0005434824695	5262	Economy	28000.00
0005435373336	5262	Economy	28000.00
0005435373376	5262	Economy	28000.00
0005435150160	5262	Economy	28000.00
0005434558348	5262	Economy	28000.00
0005435373438	5262	Economy	28000.00
0005435373481	5262	Economy	28000.00
0005434824777	5262	Economy	28000.00
0005435373377	5262	Economy	28000.00
0005432823452	5262	Economy	28000.00
0005434824768	5262	Economy	28000.00
0005435373474	5262	Economy	28000.00
0005434824809	5262	Economy	28000.00
0005435373440	5262	Economy	28000.00
0005435373519	5262	Economy	28000.00
0005435304171	5262	Economy	28000.00
0005434824798	5262	Economy	28000.00
0005435373527	5262	Economy	28000.00
0005435373435	5262	Economy	28000.00
0005434824804	5262	Economy	28000.00
0005432121470	5262	Economy	28000.00
0005434824705	5262	Economy	28000.00
0005432121468	5262	Economy	28000.00
0005434824736	5262	Economy	28000.00
0005435373552	5262	Economy	28000.00
0005435373141	5262	Economy	28000.00
0005434824724	5262	Economy	28000.00
0005435373175	5262	Economy	28000.00
0005434824814	5262	Economy	28000.00
0005434824703	5262	Economy	28000.00
0005435661925	5262	Economy	28000.00
0005435373140	5262	Economy	28000.00
0005434824767	5262	Economy	28000.00
0005434831190	5262	Economy	28000.00
0005435373345	5262	Economy	28000.00
0005435179699	5262	Economy	28000.00
0005435373333	5262	Economy	28000.00
0005435373204	5262	Economy	28000.00
0005434824737	5262	Economy	28000.00
0005435150155	5262	Economy	28000.00
0005434824730	5262	Economy	28000.00
0005434824759	5262	Economy	28000.00
0005435373352	5262	Economy	28000.00
0005434824733	5262	Economy	28000.00
0005434824727	5262	Economy	28000.00
0005434824810	5262	Economy	28000.00
0005432396278	5262	Economy	28000.00
0005435373170	5262	Economy	28000.00
0005434824797	5262	Economy	28000.00
0005435373625	5262	Economy	28000.00
0005432121458	5262	Economy	28000.00
0005435373079	5262	Economy	28000.00
0005435150163	5262	Economy	28000.00
0005434824762	5262	Economy	28000.00
0005435373338	5262	Economy	28000.00
0005434824689	5262	Economy	28000.00
0005434558347	5262	Economy	28000.00
0005434824806	5262	Economy	28000.00
0005435373154	5262	Economy	28000.00
0005435373529	5262	Economy	28000.00
0005435373473	5262	Economy	28000.00
0005435304177	5262	Economy	28000.00
0005432121467	5262	Economy	28000.00
0005435373403	5262	Economy	28000.00
0005434824776	5262	Economy	28000.00
0005435661935	5262	Economy	28000.00
0005435304159	5262	Economy	28000.00
0005435150162	5262	Economy	28000.00
0005434824772	5262	Economy	28000.00
0005434824688	5262	Economy	28000.00
0005435373500	5262	Economy	28000.00
0005435299766	5262	Economy	28000.00
0005434824729	5262	Economy	28000.00
0005432394143	5262	Economy	28000.00
0005434824791	5262	Economy	28000.00
0005434824691	5262	Economy	28000.00
0005435373078	5262	Economy	28000.00
0005434824738	5262	Economy	28000.00
0005435150149	5262	Economy	28000.00
0005435150164	5262	Economy	28000.00
0005434824748	5262	Economy	28000.00
0005434824813	5262	Economy	28000.00
0005435299791	5262	Economy	28000.00
0005434824782	5262	Economy	28000.00
0005434824755	5262	Economy	28000.00
0005432121463	5262	Economy	28000.00
0005435373229	5262	Economy	30800.00
0005435373070	5262	Economy	30800.00
0005435150153	5262	Economy	30800.00
0005435373247	5262	Economy	30800.00
0005434824749	5262	Economy	28000.00
0005432394140	5262	Economy	28000.00
0005435373246	5262	Economy	28000.00
0005434824706	5262	Economy	28000.00
0005434824723	5262	Economy	28000.00
0005435373480	5262	Economy	28000.00
0005434824711	5262	Economy	28000.00
0005435304166	5262	Economy	28000.00
0005435373239	5262	Economy	28000.00
0005434824780	5262	Economy	28000.00
0005435372953	5262	Economy	28000.00
0005435373033	5262	Economy	28000.00
0005435299783	5262	Economy	28000.00
0005434824697	5262	Economy	28000.00
0005432823443	5262	Economy	28000.00
0005432121461	5262	Economy	28000.00
0005434824704	5262	Economy	28000.00
0005435373346	5262	Economy	28000.00
0005435373482	5262	Economy	28000.00
0005435373142	5262	Economy	28000.00
0005434824754	5262	Economy	28000.00
0005435373304	5262	Economy	28000.00
0005435373197	5262	Economy	28000.00
0005432121471	5262	Economy	28000.00
0005434824722	5262	Economy	28000.00
0005434824802	5262	Economy	28000.00
0005432823442	5262	Economy	28000.00
0005435373517	5262	Economy	28000.00
0005434824753	5262	Economy	28000.00
0005435373424	5262	Economy	28000.00
0005434824786	5262	Economy	28000.00
0005435373188	5262	Economy	28000.00
0005435373173	5262	Economy	28000.00
0005432121465	5262	Economy	28000.00
0005434824790	5262	Economy	28000.00
0005434824766	5262	Economy	28000.00
0005432396280	5262	Economy	28000.00
0005432396282	5262	Economy	28000.00
0005434558353	5262	Economy	28000.00
0005434831189	5262	Economy	28000.00
0005434824811	5262	Economy	28000.00
0005435661928	5262	Economy	28000.00
0005434831188	5262	Economy	28000.00
0005434824778	5262	Economy	28000.00
0005434824783	5262	Economy	28000.00
0005434824702	5262	Economy	28000.00
0005434824696	5262	Economy	28000.00
0005435373286	5262	Economy	28000.00
0005435373353	5262	Economy	28000.00
0005435373230	5262	Economy	28000.00
0005435373245	5262	Economy	28000.00
0005434824707	5262	Economy	28000.00
0005434824717	5262	Economy	28000.00
0005434824739	5262	Economy	28000.00
0005434824709	5262	Economy	28000.00
0005435373285	5262	Economy	28000.00
0005435373299	5262	Economy	28000.00
0005434824732	5262	Economy	28000.00
0005434824799	5262	Economy	28000.00
0005432394139	5262	Economy	28000.00
0005434824774	5262	Economy	28000.00
0005435373193	5262	Economy	28000.00
0005434824757	5262	Economy	28000.00
0005435299735	5262	Economy	28000.00
0005435373287	5262	Economy	28000.00
0005434824805	5262	Economy	28000.00
0005434824760	5262	Economy	28000.00
0005435150152	5262	Economy	28000.00
0005434824787	5262	Economy	28000.00
0005434824750	5262	Economy	28000.00
0005435150157	5262	Economy	28000.00
0005435373513	5262	Economy	28000.00
0005434824769	5262	Economy	28000.00
0005432823451	5262	Economy	28000.00
0005435373174	5262	Economy	28000.00
0005434824803	5262	Economy	28000.00
0005434824701	5262	Economy	28000.00
0005435373390	5262	Economy	28000.00
0005435373518	5262	Economy	28000.00
0005435373425	5262	Economy	28000.00
0005434824784	5262	Economy	28000.00
0005434824699	5262	Economy	28000.00
0005435150151	5262	Economy	28000.00
0005434558346	5262	Economy	28000.00
0005434824718	5262	Economy	28000.00
0005434664979	5262	Economy	28000.00
0005435304161	5262	Economy	28000.00
0005434824741	5262	Economy	28000.00
0005434824792	5262	Economy	28000.00
0005435373294	5262	Economy	28000.00
0005435373332	5262	Economy	28000.00
0005435372878	5262	Economy	28000.00
0005432121466	5262	Economy	28000.00
0005434824812	5262	Economy	28000.00
0005435373340	5262	Economy	28000.00
0005434824712	5262	Economy	28000.00
0005435373115	5262	Economy	28000.00
0005434823518	9901	Business	84000.00
0005434823803	9901	Business	84000.00
0005434824178	9901	Business	84000.00
0005435373881	9901	Business	84000.00
0005435373852	9901	Business	84000.00
0005435373841	9901	Business	84000.00
0005435373884	9901	Business	84000.00
0005435373848	9901	Business	84000.00
0005434824173	9901	Business	84000.00
0005434823756	9901	Business	84000.00
0005434823568	9901	Business	84000.00
0005434824075	9901	Business	84000.00
0005435150059	9901	Business	84000.00
0005434823735	9901	Business	84000.00
0005435373842	9901	Business	84000.00
0005435661959	9901	Business	84000.00
0005432400123	9901	Business	84000.00
0005435373860	9901	Business	84000.00
0005435373863	9901	Business	84000.00
0005434558251	9901	Comfort	47600.00
0005435150036	9901	Comfort	47600.00
0005435299821	9901	Comfort	47600.00
0005432203132	9901	Comfort	47600.00
0005434823897	9901	Comfort	47600.00
0005434823335	9901	Comfort	47600.00
0005434823386	9901	Comfort	47600.00
0005434823864	9901	Comfort	47600.00
0005434823494	9901	Comfort	47600.00
0005434558269	9901	Comfort	47600.00
0005432400132	9901	Comfort	47600.00
0005434558262	9901	Comfort	47600.00
0005435373866	9901	Comfort	47600.00
0005434823743	9901	Comfort	47600.00
0005435373883	9901	Comfort	47600.00
0005434823633	9901	Comfort	47600.00
0005435373886	9901	Comfort	47600.00
0005435373871	9901	Comfort	47600.00
0005435373877	9901	Comfort	47600.00
0005435386630	9901	Comfort	47600.00
0005434824074	9901	Comfort	47600.00
0005434823724	9901	Comfort	47600.00
0005435373888	9901	Comfort	47600.00
0005435373858	9901	Comfort	47600.00
0005434823744	9901	Comfort	47600.00
0005434823556	9901	Comfort	47600.00
0005434823330	9901	Comfort	47600.00
0005435302241	9901	Comfort	47600.00
0005434823892	9901	Comfort	47600.00
0005435373836	9901	Comfort	47600.00
0005435373870	9901	Comfort	47600.00
0005435150035	9901	Comfort	47600.00
0005434823784	9901	Comfort	47600.00
0005434823375	9901	Comfort	47600.00
0005434823709	9901	Comfort	47600.00
0005435373862	9901	Comfort	47600.00
0005434823645	9901	Comfort	47600.00
0005435386632	9901	Comfort	47600.00
0005435373844	9901	Comfort	47600.00
0005435373839	9901	Economy	28000.00
0005435373847	9901	Economy	28000.00
0005435373880	9901	Economy	28000.00
0005434824411	9901	Economy	28000.00
0005435373837	9901	Economy	28000.00
0005432203130	9901	Economy	28000.00
0005435735180	9901	Economy	28000.00
0005434824020	9901	Economy	28000.00
0005434823676	9901	Economy	28000.00
0005434823619	9901	Economy	28000.00
0005434823695	9901	Economy	28000.00
0005434823618	9901	Economy	28000.00
0005434823687	9901	Economy	28000.00
0005434823592	9901	Economy	28000.00
0005434823699	9901	Economy	28000.00
0005435373850	9901	Economy	28000.00
0005434823421	9901	Economy	28000.00
0005435661960	9901	Economy	28000.00
0005434823698	9901	Economy	28000.00
0005435373845	9901	Economy	28000.00
0005434823531	9901	Economy	28000.00
0005435373864	9901	Economy	28000.00
0005434823570	9901	Economy	28000.00
0005435386631	9901	Economy	28000.00
0005434823307	9901	Economy	28000.00
0005435373853	9901	Economy	28000.00
0005434823535	9901	Economy	28000.00
0005435299819	9901	Economy	28000.00
0005434823798	9901	Economy	28000.00
0005434824116	9901	Economy	28000.00
0005434823169	9901	Economy	28000.00
0005434823862	9901	Economy	28000.00
0005434823934	9901	Economy	28000.00
0005434823545	9901	Economy	28000.00
0005434823548	9901	Economy	28000.00
0005434558252	9901	Economy	28000.00
0005434558273	9901	Economy	28000.00
0005434823742	9901	Economy	28000.00
0005434823918	9901	Economy	28000.00
0005434823613	9901	Economy	28000.00
0005434824366	9901	Economy	28000.00
0005434823646	9901	Economy	28000.00
0005434823923	9901	Economy	28000.00
0005435150022	9901	Economy	28000.00
0005434558248	9901	Economy	28000.00
0005435735181	9901	Economy	28000.00
0005434823495	9901	Economy	30800.00
0005434824365	9901	Economy	28000.00
0005435373876	9901	Economy	30800.00
0005435373869	9901	Economy	28000.00
0005434823654	9901	Economy	28000.00
0005435373874	9901	Economy	28000.00
0005435373885	9901	Economy	30800.00
0005434823249	9901	Economy	30800.00
0005434823350	9901	Economy	28000.00
0005435373838	9901	Economy	30800.00
0005432823468	9901	Economy	28000.00
0005435302243	9901	Economy	28000.00
0005434823422	9901	Economy	28000.00
0005434823881	9901	Economy	28000.00
0005434823547	9901	Economy	28000.00
0005432823469	9901	Economy	28000.00
0005432203131	9901	Economy	28000.00
0005434823634	9901	Economy	28000.00
0005434823308	9901	Economy	28000.00
0005434823231	9901	Economy	28000.00
0005434823501	9901	Economy	28000.00
0005434831137	9901	Economy	28000.00
0005432396218	9901	Economy	28000.00
0005435150034	9901	Economy	28000.00
0005434824274	9901	Economy	28000.00
0005434823427	9901	Economy	28000.00
0005434824043	9901	Economy	28000.00
0005435373859	9901	Economy	28000.00
0005434823522	9901	Economy	28000.00
0005435373895	9901	Economy	28000.00
0005435149947	9901	Economy	28000.00
0005435302239	9901	Economy	28000.00
0005434824044	9901	Economy	28000.00
0005435150057	9901	Economy	28000.00
0005434823667	9901	Economy	28000.00
0005434823511	9901	Economy	28000.00
0005434824131	9901	Economy	28000.00
0005434823534	9901	Economy	28000.00
0005434823333	9901	Economy	28000.00
0005434823588	9901	Economy	28000.00
0005434558272	9901	Economy	28000.00
0005434823694	9901	Economy	28000.00
0005435302240	9901	Economy	28000.00
0005434823404	9901	Economy	28000.00
0005434824021	9901	Economy	28000.00
0005434831161	9901	Economy	28000.00
0005434823334	9901	Economy	28000.00
0005434823572	9901	Economy	28000.00
0005435373857	9901	Economy	28000.00
0005434823817	9901	Economy	28000.00
0005434558270	9901	Economy	28000.00
0005435373861	9901	Economy	28000.00
0005434823533	9901	Economy	28000.00
0005434823512	9901	Economy	28000.00
0005434823513	9901	Economy	28000.00
0005435373835	9901	Economy	28000.00
0005435299820	9901	Economy	28000.00
0005434823816	9901	Economy	28000.00
0005435373846	9901	Economy	28000.00
0005434824175	9901	Economy	28000.00
0005432396250	9901	Economy	28000.00
0005434823417	9901	Economy	28000.00
0005434823137	9901	Economy	28000.00
0005434823491	9901	Economy	28000.00
0005434823993	9901	Economy	28000.00
0005434824132	9901	Economy	28000.00
0005434823558	9901	Economy	28000.00
0005432396245	9901	Economy	28000.00
0005434823924	9901	Economy	28000.00
0005435373878	9901	Economy	28000.00
0005434823313	9901	Economy	28000.00
0005435373882	9901	Economy	28000.00
0005435149946	9901	Economy	28000.00
0005434823823	9901	Economy	28000.00
0005434824233	9901	Economy	28000.00
0005434823971	9901	Economy	28000.00
0005434558261	9901	Economy	28000.00
0005434823569	9901	Economy	28000.00
0005432203133	9901	Economy	28000.00
0005435373890	9901	Economy	28000.00
0005435373889	9901	Economy	28000.00
0005435735182	9901	Economy	28000.00
0005435373873	9901	Economy	28000.00
0005432396241	9901	Economy	28000.00
0005435373879	9901	Economy	28000.00
0005434823677	9901	Economy	28000.00
0005435373854	9901	Economy	28000.00
0005434823824	9901	Economy	28000.00
0005435373892	9901	Economy	28000.00
0005434823523	9901	Economy	28000.00
0005434558271	9901	Economy	28000.00
0005432400131	9901	Economy	30800.00
0005435373893	9901	Economy	30800.00
0005432396240	9901	Economy	30800.00
0005435386635	9901	Economy	30800.00
0005434823672	9901	Economy	28000.00
0005435386634	9901	Economy	28000.00
0005435373865	9901	Economy	28000.00
0005432203128	9901	Economy	28000.00
0005434824166	9901	Economy	28000.00
0005434823788	9901	Economy	28000.00
0005432400122	9901	Economy	28000.00
0005435373875	9901	Economy	28000.00
0005435373840	9901	Economy	28000.00
0005434823734	9901	Economy	28000.00
0005434823502	9901	Economy	28000.00
0005434823445	9901	Economy	28000.00
0005434823911	9901	Economy	28000.00
0005435373851	9901	Economy	28000.00
0005434823532	9901	Economy	28000.00
0005435735179	9901	Economy	28000.00
0005435373867	9901	Economy	28000.00
0005435373868	9901	Economy	28000.00
0005434823972	9901	Economy	28000.00
0005435373830	9901	Economy	28000.00
0005434831138	9901	Economy	28000.00
0005435150011	9901	Economy	28000.00
0005434823232	9901	Economy	28000.00
0005435373832	9901	Economy	28000.00
0005434823415	9901	Economy	28000.00
0005435150058	9901	Economy	28000.00
0005434823673	9901	Economy	28000.00
0005435373887	9901	Economy	28000.00
0005434824117	9901	Economy	28000.00
0005434823585	9901	Economy	28000.00
0005434823446	9901	Economy	28000.00
0005434823723	9901	Economy	28000.00
0005435299818	9901	Economy	28000.00
0005435302242	9901	Economy	28000.00
0005434823896	9901	Economy	28000.00
0005435373872	9901	Economy	28000.00
0005432203127	9901	Economy	28000.00
0005434824165	9901	Economy	28000.00
0005434823876	9901	Economy	28000.00
0005435373834	9901	Economy	28000.00
0005435302244	9901	Economy	28000.00
0005434823865	9901	Economy	28000.00
0005434823878	9901	Economy	28000.00
0005434823815	9901	Economy	28000.00
0005435373855	9901	Economy	28000.00
0005434824022	9901	Economy	28000.00
0005435299817	9901	Economy	28000.00
0005435386633	9901	Economy	28000.00
0005435179402	9901	Economy	28000.00
0005434831162	9901	Economy	28000.00
0005435373849	9901	Economy	28000.00
0005432396217	9901	Economy	28000.00
0005434823710	9901	Economy	28000.00
0005434824279	9901	Economy	28000.00
0005435373894	9901	Economy	28000.00
0005435373843	9901	Economy	28000.00
0005434823521	9901	Economy	28000.00
0005435373833	9901	Economy	28000.00
0005434823248	9901	Economy	28000.00
0005432396251	9901	Economy	28000.00
0005434823519	9901	Economy	28000.00
0005434823288	9901	Economy	28000.00
0005434823274	9901	Economy	28000.00
0005434824115	9901	Economy	28000.00
0005432203129	9901	Economy	28000.00
0005435373891	9901	Economy	28000.00
0005434823331	9901	Economy	28000.00
0005434823230	9901	Economy	28000.00
0005434823429	9901	Economy	28000.00
0005434558268	9901	Economy	28000.00
0005434823861	9901	Economy	28000.00
0005435373831	9901	Economy	28000.00
0005435373856	9901	Economy	28000.00
0005434823387	9901	Economy	28000.00
0005434823376	9901	Economy	28000.00
0005434823312	9901	Economy	28000.00
0005434823783	9901	Economy	28000.00
0005434823377	9901	Economy	28000.00
0005434823138	9901	Economy	28000.00
0005434823822	9901	Economy	28000.00
0005434824174	9901	Economy	28000.00
0005434558253	9901	Economy	28000.00
0005435082861	7026	Economy	8200.00
0005435790333	7026	Economy	7400.00
0005435790332	7026	Economy	7400.00
0005435790334	7026	Economy	7400.00
0005435082863	7026	Economy	7400.00
0005435082862	7026	Economy	7400.00
0005435082858	7026	Economy	7400.00
0005435082857	7026	Economy	7400.00
0005435082859	7026	Economy	7400.00
0005435082860	7026	Economy	7400.00
0005435082823	26004	Economy	8200.00
0005435082775	26004	Economy	8200.00
0005435082824	26004	Economy	7400.00
0005435082792	26004	Economy	7400.00
0005435082797	26004	Economy	7400.00
0005435082790	26004	Economy	7400.00
0005435082798	26004	Economy	7400.00
0005435082791	26004	Economy	7400.00
0005435082768	26004	Economy	7400.00
0005435790302	26004	Economy	7400.00
0005435790318	26004	Economy	7400.00
0005435790307	26004	Economy	7400.00
0005435082774	26004	Economy	7400.00
0005434214424	9547	Business	32800.00
0005434756789	9547	Business	32800.00
0005434756810	9547	Business	32800.00
0005434756788	9547	Business	32800.00
0005434214637	9547	Business	32800.00
0005434214492	9547	Business	32800.00
0005434756808	9547	Business	32800.00
0005434214494	9547	Business	32800.00
0005434756823	9547	Business	32800.00
0005434214431	9547	Business	32800.00
0005434214591	9547	Economy	10900.00
0005434214566	9547	Economy	10900.00
0005434214453	9547	Economy	10900.00
0005434756836	9547	Economy	10900.00
0005434756825	9547	Economy	10900.00
0005434756811	9547	Economy	10900.00
0005434756802	9547	Economy	10900.00
0005434214465	9547	Economy	10900.00
0005434756791	9547	Economy	10900.00
0005434214368	9547	Economy	10900.00
0005434214318	9547	Economy	12000.00
0005434756815	9547	Economy	12000.00
0005434756821	9547	Economy	12000.00
0005434214726	9547	Economy	12000.00
0005434756809	9547	Economy	12000.00
0005434756804	9547	Economy	10900.00
0005434214454	9547	Economy	10900.00
0005434214317	9547	Economy	10900.00
0005434756817	9547	Economy	10900.00
0005434214491	9547	Economy	10900.00
0005434214546	9547	Economy	10900.00
0005434214651	9547	Economy	10900.00
0005434756790	9547	Economy	10900.00
0005434214589	9547	Economy	10900.00
0005434214544	9547	Economy	10900.00
0005434756814	9547	Economy	10900.00
0005434214541	9547	Economy	10900.00
0005434756807	9547	Economy	10900.00
0005434756803	9547	Economy	10900.00
0005434756834	9547	Economy	10900.00
0005434756806	9547	Economy	10900.00
0005434756829	9547	Economy	10900.00
0005434756830	9547	Economy	10900.00
0005434756824	9547	Economy	10900.00
0005434214543	9547	Economy	10900.00
0005434756800	9547	Economy	10900.00
0005434214369	9547	Economy	10900.00
0005434756826	9547	Economy	10900.00
0005434214529	9547	Economy	10900.00
0005434214367	9547	Economy	10900.00
0005434756813	9547	Economy	10900.00
0005434214532	9547	Economy	10900.00
0005434214565	9547	Economy	10900.00
0005434756787	9547	Economy	10900.00
0005434756797	9547	Economy	10900.00
0005434214523	9547	Economy	10900.00
0005434214667	9547	Economy	10900.00
0005434756793	9547	Economy	10900.00
0005434214518	9547	Economy	10900.00
0005434214505	9547	Economy	10900.00
0005434214467	9547	Economy	10900.00
0005434214573	9547	Economy	10900.00
0005434756837	9547	Economy	10900.00
0005434756816	9547	Economy	10900.00
0005434756838	9547	Economy	10900.00
0005434756822	9547	Economy	10900.00
0005434214387	9547	Economy	10900.00
0005434756833	9547	Economy	10900.00
0005434214557	9547	Economy	10900.00
0005434756818	9547	Economy	10900.00
0005434756792	9547	Economy	10900.00
0005434756796	9547	Economy	10900.00
0005434214540	9547	Economy	10900.00
0005434756798	9547	Economy	10900.00
0005434756839	9547	Economy	10900.00
0005434756820	9547	Economy	10900.00
0005434214488	9547	Economy	10900.00
0005434756794	9547	Economy	10900.00
0005434756805	9547	Economy	10900.00
0005434214499	9547	Economy	10900.00
0005434214766	9547	Economy	10900.00
0005434756827	9547	Economy	10900.00
0005434214606	9547	Economy	10900.00
0005434756819	9547	Economy	10900.00
0005434756799	9547	Economy	10900.00
0005434756832	9547	Economy	10900.00
0005434756828	9547	Economy	10900.00
0005434756795	9547	Economy	10900.00
0005434756801	9547	Economy	10900.00
0005434756831	9547	Economy	10900.00
0005434214388	9547	Economy	10900.00
0005434756835	9547	Economy	10900.00
0005434214430	9547	Economy	10900.00
0005434756812	9547	Economy	10900.00
0005434756317	28647	Business	32800.00
0005434756318	28647	Business	32800.00
0005434214906	28647	Business	32800.00
0005434756401	28647	Business	32800.00
0005434214905	28647	Business	32800.00
0005434756402	28647	Business	32800.00
0005434756140	28647	Business	32800.00
0005434756312	28647	Business	32800.00
0005434756375	28647	Business	32800.00
0005434214892	28647	Business	32800.00
0005434214931	28647	Business	32800.00
0005434214918	28647	Business	32800.00
0005434756392	28647	Economy	10900.00
0005434756378	28647	Economy	10900.00
0005434214913	28647	Economy	10900.00
0005434756379	28647	Economy	10900.00
0005434756407	28647	Economy	10900.00
0005434756338	28647	Economy	10900.00
0005434214934	28647	Economy	10900.00
0005434214920	28647	Economy	10900.00
0005434756340	28647	Economy	10900.00
0005434214894	28647	Economy	12000.00
0005434214911	28647	Economy	12000.00
0005434214935	28647	Economy	12000.00
0005434756254	28647	Economy	12000.00
0005434756300	28647	Economy	12000.00
0005434756382	28647	Economy	10900.00
0005434756261	28647	Economy	10900.00
0005434214937	28647	Economy	10900.00
0005434214924	28647	Economy	10900.00
0005434214925	28647	Economy	10900.00
0005434756356	28647	Economy	10900.00
0005434756363	28647	Economy	10900.00
0005434214900	28647	Economy	10900.00
0005434214904	28647	Economy	10900.00
0005434214936	28647	Economy	10900.00
0005434756358	28647	Economy	10900.00
0005434756139	28647	Economy	10900.00
0005434756308	28647	Economy	10900.00
0005434214895	28647	Economy	10900.00
0005434756286	28647	Economy	10900.00
0005434214893	28647	Economy	10900.00
0005434214889	28647	Economy	10900.00
0005434214908	28647	Economy	10900.00
0005434214930	28647	Economy	10900.00
0005434214896	28647	Economy	10900.00
0005434756385	28647	Economy	10900.00
0005434214890	28647	Economy	10900.00
0005434756339	28647	Economy	10900.00
0005434756434	28647	Economy	10900.00
0005434214919	28647	Economy	10900.00
0005434214902	28647	Economy	10900.00
0005434756360	28647	Economy	10900.00
0005434214928	28647	Economy	10900.00
0005434214933	28647	Economy	10900.00
0005434756355	28647	Economy	10900.00
0005434756383	28647	Economy	10900.00
0005434214903	28647	Economy	10900.00
0005434756381	28647	Economy	10900.00
0005434756374	28647	Economy	10900.00
0005434756301	28647	Economy	10900.00
0005434214927	28647	Economy	10900.00
0005434756232	28647	Economy	10900.00
0005434214909	28647	Economy	10900.00
0005434214899	28647	Economy	10900.00
0005434214910	28647	Economy	10900.00
0005434756420	28647	Economy	10900.00
0005434214932	28647	Economy	10900.00
0005434214923	28647	Economy	10900.00
0005434214917	28647	Economy	10900.00
0005434214907	28647	Economy	10900.00
0005434214898	28647	Economy	10900.00
0005434214915	28647	Economy	10900.00
0005434756423	28647	Economy	10900.00
0005434756307	28647	Economy	10900.00
0005434214922	28647	Economy	10900.00
0005434756233	28647	Economy	10900.00
0005434214897	28647	Economy	10900.00
0005434756141	28647	Economy	10900.00
0005434214891	28647	Economy	10900.00
0005434756386	28647	Economy	10900.00
0005434214914	28647	Economy	10900.00
0005434214916	28647	Economy	10900.00
0005434214912	28647	Economy	10900.00
0005434214921	28647	Economy	10900.00
0005434756357	28647	Economy	10900.00
0005434756316	28647	Economy	10900.00
0005434756255	28647	Economy	10900.00
0005434214888	28647	Economy	10900.00
0005434756330	28647	Economy	10900.00
0005434756421	28647	Economy	10900.00
0005434214929	28647	Economy	10900.00
0005434214901	28647	Economy	10900.00
0005434214926	28647	Economy	10900.00
0005434756387	28647	Economy	10900.00
0005434756311	28647	Economy	10900.00
0005435100151	10844	Economy	9800.00
0005434760202	10844	Economy	8900.00
0005435100150	10844	Economy	8900.00
0005434760203	10844	Economy	8900.00
0005435100149	10844	Economy	8900.00
0005434760220	31832	Economy	8900.00
0005435100120	31832	Economy	8900.00
0005435100131	31832	Economy	8900.00
0005435100130	31832	Economy	8900.00
0005435100134	31832	Economy	8900.00
0005434760219	31832	Economy	8900.00
0005434639554	1969	Economy	20900.00
0005433202360	1969	Economy	20900.00
0005434639564	1969	Economy	20900.00
0005433202358	1969	Economy	20900.00
0005432290661	1969	Economy	19000.00
0005433202356	1969	Economy	19000.00
0005434639565	1969	Economy	19000.00
0005432290663	1969	Economy	19000.00
0005434639561	1969	Economy	19000.00
0005433202298	1969	Economy	19000.00
0005433202309	1969	Economy	19000.00
0005433202398	1969	Economy	19000.00
0005434639571	1969	Economy	19000.00
0005433202361	1969	Economy	19000.00
0005433202355	1969	Economy	19000.00
0005434639562	1969	Economy	19000.00
0005433202303	1969	Economy	19000.00
0005433202384	1969	Economy	19000.00
0005434639572	1969	Economy	19000.00
0005434639560	1969	Economy	19000.00
0005434639551	1969	Economy	19000.00
0005434639559	1969	Economy	19000.00
0005434639566	1969	Economy	19000.00
0005433202385	1969	Economy	19000.00
0005434639568	1969	Economy	19000.00
0005433202351	1969	Economy	19000.00
0005433202417	1969	Economy	19000.00
0005434639550	1969	Economy	19000.00
0005433202359	1969	Economy	19000.00
0005434639555	1969	Economy	19000.00
0005432290662	1969	Economy	19000.00
0005434639567	1969	Economy	19000.00
0005434639552	1969	Economy	19000.00
0005433202369	1969	Economy	19000.00
0005433202295	1969	Economy	19000.00
0005434639549	1969	Economy	19000.00
0005434639553	1969	Economy	19000.00
0005434639557	1969	Economy	19000.00
0005433202366	1969	Economy	19000.00
0005434639569	1969	Economy	19000.00
0005433202428	1969	Economy	19000.00
0005434639556	1969	Economy	19000.00
0005433202350	1969	Economy	19000.00
0005434639563	1969	Economy	19000.00
0005434639570	1969	Economy	19000.00
0005434639558	1969	Economy	19000.00
0005433202368	1969	Economy	19000.00
0005433202418	1969	Economy	19000.00
0005433202370	1969	Economy	19000.00
0005434639324	23247	Economy	20900.00
0005433202491	23247	Economy	20900.00
0005434639338	23247	Economy	20900.00
0005434639380	23247	Economy	20900.00
0005434639381	23247	Economy	19000.00
0005433202483	23247	Economy	19000.00
0005434639417	23247	Economy	19000.00
0005434639255	23247	Economy	19000.00
0005433202486	23247	Economy	19000.00
0005434639390	23247	Economy	19000.00
0005434639291	23247	Economy	19000.00
0005433202485	23247	Economy	19000.00
0005433202480	23247	Economy	19000.00
0005433202481	23247	Economy	19000.00
0005434639387	23247	Economy	19000.00
0005434639379	23247	Economy	19000.00
0005433202489	23247	Economy	19000.00
0005434639314	23247	Economy	19000.00
0005434639219	23247	Economy	19000.00
0005434639389	23247	Economy	19000.00
0005433202479	23247	Economy	19000.00
0005434639394	23247	Economy	19000.00
0005433202487	23247	Economy	19000.00
0005434639238	23247	Economy	19000.00
0005434639342	23247	Economy	19000.00
0005434639337	23247	Economy	19000.00
0005434639290	23247	Economy	19000.00
0005434639319	23247	Economy	19000.00
0005434639386	23247	Economy	19000.00
0005433202482	23247	Economy	19000.00
0005433202488	23247	Economy	19000.00
0005434639300	23247	Economy	19000.00
0005434639391	23247	Economy	19000.00
0005433202493	23247	Economy	19000.00
0005433202492	23247	Economy	19000.00
0005434639336	23247	Economy	19000.00
0005434639299	23247	Economy	19000.00
0005433202490	23247	Economy	19000.00
0005433202484	23247	Economy	19000.00
0005434601068	6086	Business	69700.00
0005434601054	6086	Business	69700.00
0005433531328	6086	Business	69700.00
0005434601059	6086	Business	69700.00
0005432111307	6086	Business	69700.00
0005434601066	6086	Business	69700.00
0005435326716	6086	Business	69700.00
0005433533344	6086	Economy	23200.00
0005434601061	6086	Economy	23200.00
0005434601056	6086	Economy	23200.00
0005434601063	6086	Economy	23200.00
0005435326713	6086	Economy	25600.00
0005434601065	6086	Economy	25600.00
0005434601069	6086	Economy	25600.00
0005433533345	6086	Economy	23200.00
0005434601062	6086	Economy	23200.00
0005434601044	6086	Economy	23200.00
0005433531329	6086	Economy	23200.00
0005433533342	6086	Economy	23200.00
0005434601060	6086	Economy	23200.00
0005434601058	6086	Economy	23200.00
0005435326820	6086	Economy	23200.00
0005432111308	6086	Economy	23200.00
0005435326725	6086	Economy	23200.00
0005434601047	6086	Economy	23200.00
0005435326791	6086	Economy	23200.00
0005434601046	6086	Economy	23200.00
0005433531327	6086	Economy	23200.00
0005435326707	6086	Economy	23200.00
0005434601051	6086	Economy	23200.00
0005435326724	6086	Economy	23200.00
0005435326709	6086	Economy	23200.00
0005435326710	6086	Economy	23200.00
0005434601055	6086	Economy	23200.00
0005433531330	6086	Economy	23200.00
0005435326752	6086	Economy	23200.00
0005435326743	6086	Economy	23200.00
0005434601067	6086	Economy	23200.00
0005434601050	6086	Economy	23200.00
0005435326714	6086	Economy	23200.00
0005435326790	6086	Economy	23200.00
0005432111306	6086	Economy	23200.00
0005435326715	6086	Economy	23200.00
0005435326729	6086	Economy	23200.00
0005434601052	6086	Economy	23200.00
0005434601064	6086	Economy	23200.00
0005433531326	6086	Economy	23200.00
0005433533343	6086	Economy	23200.00
0005433533341	6086	Economy	23200.00
0005434601049	6086	Economy	23200.00
0005434601045	6086	Economy	23200.00
0005434601053	6086	Economy	23200.00
0005434601057	6086	Economy	23200.00
0005434601048	6086	Economy	23200.00
0005434601070	6086	Economy	23200.00
0005435326726	6086	Economy	23200.00
0005435326871	18603	Business	69700.00
0005434600830	18603	Business	69700.00
0005434600803	18603	Business	69700.00
0005435326867	18603	Business	69700.00
0005434600804	18603	Business	69700.00
0005434600896	18603	Business	69700.00
0005434600895	18603	Business	69700.00
0005434600743	18603	Business	69700.00
0005434600843	18603	Economy	23200.00
0005434600840	18603	Economy	23200.00
0005434600773	18603	Economy	23200.00
0005435326872	18603	Economy	23200.00
0005434600730	18603	Economy	25600.00
0005434600766	18603	Economy	23200.00
0005434600836	18603	Economy	23200.00
0005434600782	18603	Economy	23200.00
0005435326874	18603	Economy	23200.00
0005434600957	18603	Economy	23200.00
0005434600841	18603	Economy	23200.00
0005433527241	18603	Economy	23200.00
0005434600763	18603	Economy	23200.00
0005435326876	18603	Economy	23200.00
0005435326869	18603	Economy	23200.00
0005434600783	18603	Economy	23200.00
0005434600779	18603	Economy	23200.00
0005435326879	18603	Economy	23200.00
0005434600835	18603	Economy	23200.00
0005434600847	18603	Economy	23200.00
0005435326870	18603	Economy	23200.00
0005434600884	18603	Economy	23200.00
0005434600697	18603	Economy	23200.00
0005435326877	18603	Economy	23200.00
0005434600780	18603	Economy	23200.00
0005434600767	18603	Economy	23200.00
0005434600698	18603	Economy	23200.00
0005434600735	18603	Economy	23200.00
0005434600846	18603	Economy	23200.00
0005433531314	18603	Economy	23200.00
0005434600786	18603	Economy	23200.00
0005434600839	18603	Economy	23200.00
0005434600910	18603	Economy	23200.00
0005435326873	18603	Economy	23200.00
0005434600924	18603	Economy	23200.00
0005435326878	18603	Economy	23200.00
0005435326875	18603	Economy	23200.00
0005434600806	18603	Economy	23200.00
0005435326866	18603	Economy	23200.00
0005435326868	18603	Economy	23200.00
0005434551711	10615	Business	9100.00
0005434551658	10615	Business	9100.00
0005434551671	10615	Business	9100.00
0005434551666	10615	Business	9100.00
0005434551672	10615	Business	9100.00
0005434551696	10615	Business	9100.00
0005434558337	10615	Business	9100.00
0005434558343	10615	Business	9100.00
0005434551678	10615	Business	9100.00
0005434551698	10615	Business	9100.00
0005434554080	10615	Business	9100.00
0005434551661	10615	Business	9100.00
0005434551668	10615	Economy	3000.00
0005434551660	10615	Economy	3000.00
0005433181010	10615	Economy	3000.00
0005434551699	10615	Economy	3000.00
0005433181189	10615	Economy	3000.00
0005434551695	10615	Economy	3000.00
0005434551689	10615	Economy	3000.00
0005434551664	10615	Economy	3000.00
0005434551712	10615	Economy	3000.00
0005434551710	10615	Economy	3300.00
0005433181103	10615	Economy	3300.00
0005434551686	10615	Economy	3300.00
0005433181180	10615	Economy	3300.00
0005434551685	10615	Economy	3300.00
0005434558341	10615	Economy	3000.00
0005434551673	10615	Economy	3000.00
0005434551709	10615	Economy	3000.00
0005434551659	10615	Economy	3000.00
0005434551679	10615	Economy	3000.00
0005434551683	10615	Economy	3000.00
0005434551681	10615	Economy	3000.00
0005434551693	10615	Economy	3000.00
0005434558335	10615	Economy	3000.00
0005434551702	10615	Economy	3000.00
0005433181056	10615	Economy	3000.00
0005433181163	10615	Economy	3000.00
0005434551662	10615	Economy	3000.00
0005434551687	10615	Economy	3000.00
0005434551705	10615	Economy	3000.00
0005434551665	10615	Economy	3000.00
0005433181152	10615	Economy	3000.00
0005434558345	10615	Economy	3000.00
0005433181083	10615	Economy	3000.00
0005434551694	10615	Economy	3000.00
0005434551688	10615	Economy	3000.00
0005434551701	10615	Economy	3000.00
0005434551706	10615	Economy	3000.00
0005434551708	10615	Economy	3000.00
0005434551676	10615	Economy	3000.00
0005434558334	10615	Economy	3000.00
0005433181009	10615	Economy	3000.00
0005433181054	10615	Economy	3000.00
0005434554081	10615	Economy	3000.00
0005433181032	10615	Economy	3000.00
0005433181091	10615	Economy	3000.00
0005434558342	10615	Economy	3000.00
0005434551674	10615	Economy	3000.00
0005434551682	10615	Economy	3000.00
0005433181141	10615	Economy	3000.00
0005433181162	10615	Economy	3000.00
0005434558344	10615	Economy	3000.00
0005434551680	10615	Economy	3000.00
0005434551690	10615	Economy	3000.00
0005434551691	10615	Economy	3000.00
0005433181102	10615	Economy	3000.00
0005434558339	10615	Economy	3000.00
0005434551667	10615	Economy	3000.00
0005434558340	10615	Economy	3000.00
0005434551692	10615	Economy	3000.00
0005434551697	10615	Economy	3000.00
0005433180992	10615	Economy	3000.00
0005434551703	10615	Economy	3000.00
0005434551670	10615	Economy	3000.00
0005434551675	10615	Economy	3000.00
0005433180993	10615	Economy	3000.00
0005434551700	10615	Economy	3000.00
0005433181113	10615	Economy	3000.00
0005434551704	10615	Economy	3000.00
0005433181179	10615	Economy	3000.00
0005433181008	10615	Economy	3000.00
0005434558336	10615	Economy	3000.00
0005434551677	10615	Economy	3000.00
0005433181181	10615	Economy	3000.00
0005434551707	10615	Economy	3000.00
0005434551669	10615	Economy	3000.00
0005433181090	10615	Economy	3000.00
0005434558338	10615	Economy	3000.00
0005434551663	10615	Economy	3000.00
0005434551684	10615	Economy	3000.00
0005433181140	10615	Economy	3000.00
0005433181327	27687	Business	9100.00
0005433181332	27687	Business	9100.00
0005433181322	27687	Economy	3000.00
0005433181342	27687	Economy	3000.00
0005433181336	27687	Economy	3000.00
0005433181333	27687	Economy	3000.00
0005433181330	27687	Economy	3000.00
0005433181337	27687	Economy	3000.00
0005433181345	27687	Economy	3000.00
0005433181331	27687	Economy	3000.00
0005433181320	27687	Economy	3000.00
0005433181335	27687	Economy	3000.00
0005433181341	27687	Economy	3000.00
0005433181344	27687	Economy	3000.00
0005433181334	27687	Economy	3000.00
0005433181340	27687	Economy	3000.00
0005433181339	27687	Economy	3000.00
0005433181329	27687	Economy	3000.00
0005433181323	27687	Economy	3000.00
0005433181324	27687	Economy	3000.00
0005433181326	27687	Economy	3000.00
0005433181321	27687	Economy	3000.00
0005433181338	27687	Economy	3000.00
0005433181325	27687	Economy	3000.00
0005433181328	27687	Economy	3000.00
0005433181343	27687	Economy	3000.00
0005434551259	27688	Business	9100.00
0005434558234	27688	Business	9100.00
0005434551078	27688	Business	9100.00
0005434551461	27688	Business	9100.00
0005434551149	27688	Business	9100.00
0005434554066	27688	Business	9100.00
0005434551436	27688	Business	9100.00
0005434551470	27688	Business	9100.00
0005434551260	27688	Business	9100.00
0005434551043	27688	Business	9100.00
0005434551039	27688	Business	9100.00
0005434551158	27688	Economy	3000.00
0005434551364	27688	Economy	3000.00
0005434551150	27688	Economy	3000.00
0005434551244	27688	Economy	3000.00
0005434551044	27688	Economy	3000.00
0005434551331	27688	Economy	3000.00
0005434551285	27688	Economy	3000.00
0005434551509	27688	Economy	3300.00
0005434551371	27688	Economy	3300.00
0005434551166	27688	Economy	3300.00
0005434551042	27688	Economy	3300.00
0005434551549	27688	Economy	3000.00
0005434551252	27688	Economy	3000.00
0005434551283	27688	Economy	3000.00
0005434551536	27688	Economy	3000.00
0005434551132	27688	Economy	3000.00
0005434551303	27688	Economy	3000.00
0005434551229	27688	Economy	3000.00
0005434551284	27688	Economy	3000.00
0005434551251	27688	Economy	3000.00
0005434551088	27688	Economy	3000.00
0005434551139	27688	Economy	3000.00
0005434551278	27688	Economy	3000.00
0005434551366	27688	Economy	3000.00
0005434551365	27688	Economy	3000.00
0005434558264	27688	Economy	3000.00
0005434551154	27688	Economy	3000.00
0005434551475	27688	Economy	3000.00
0005434551270	27688	Economy	3000.00
0005434551073	27688	Economy	3000.00
0005434551318	27688	Economy	3000.00
0005434551218	27688	Economy	3000.00
0005434551277	27688	Economy	3000.00
0005434551413	27688	Economy	3000.00
0005434551343	27688	Economy	3000.00
0005434551548	27688	Economy	3000.00
0005434551384	27688	Economy	3000.00
0005434551153	27688	Economy	3000.00
0005434551250	27688	Economy	3000.00
0005434558278	27688	Economy	3000.00
0005434551217	27688	Economy	3000.00
0005434551282	27688	Economy	3000.00
0005434551263	27688	Economy	3000.00
0005434551320	27688	Economy	3000.00
0005434551254	27688	Economy	3000.00
0005434551304	27688	Economy	3000.00
0005434558235	27688	Economy	3000.00
0005434551469	27688	Economy	3000.00
0005434551249	27688	Economy	3000.00
0005434551305	27688	Economy	3000.00
0005434551319	27688	Economy	3000.00
0005434551060	27688	Economy	3000.00
0005434551089	27688	Economy	3000.00
0005434551404	27688	Economy	3000.00
0005434551074	27688	Economy	3000.00
0005434551248	27688	Economy	3000.00
0005434551090	27688	Economy	3000.00
0005434551157	27688	Economy	3000.00
0005434551437	27688	Economy	3000.00
0005434558277	27688	Economy	3000.00
0005434551267	27688	Economy	3000.00
0005434551094	27688	Economy	3000.00
0005433459258	6134	Economy	11700.00
0005433459259	6134	Economy	11700.00
0005433459257	6134	Economy	11700.00
0005435254478	6134	Economy	11700.00
0005433459260	6134	Economy	11700.00
0005433459261	6134	Economy	11700.00
0005433459262	6134	Economy	11700.00
0005435254475	6134	Economy	11700.00
0005433459220	19303	Economy	11700.00
0005433459219	19303	Economy	11700.00
0005433459221	19303	Economy	11700.00
0005435254498	19303	Economy	11700.00
0005433459231	19303	Economy	11700.00
0005433459230	19303	Economy	11700.00
0005435254497	19303	Economy	11700.00
0005435682512	6713	Business	51100.00
0005432136218	6713	Business	51100.00
0005435437900	6713	Business	51100.00
0005435438031	6713	Business	51100.00
0005435630991	6713	Business	51100.00
0005435438050	6713	Business	51100.00
0005435682520	6713	Business	51100.00
0005435438003	6713	Business	51100.00
0005435682516	6713	Business	51100.00
0005435682517	6713	Economy	17000.00
0005435437952	6713	Economy	17000.00
0005435221514	6713	Economy	17000.00
0005435217713	6713	Economy	17000.00
0005435438004	6713	Economy	17000.00
0005435437975	6713	Economy	17000.00
0005435661958	6713	Economy	17000.00
0005435217723	6713	Economy	17000.00
0005435682518	6713	Economy	17000.00
0005435682510	6713	Economy	17000.00
0005435438032	6713	Economy	18700.00
0005435682505	6713	Economy	18700.00
0005435220320	6713	Economy	18700.00
0005435682498	6713	Economy	18700.00
0005435682494	6713	Economy	18700.00
0005435438073	6713	Economy	17000.00
0005435682485	6713	Economy	17000.00
0005435661955	6713	Economy	17000.00
0005435682491	6713	Economy	17000.00
0005435437947	6713	Economy	17000.00
0005435437966	6713	Economy	17000.00
0005435438049	6713	Economy	17000.00
0005435682488	6713	Economy	17000.00
0005435437970	6713	Economy	17000.00
0005435438022	6713	Economy	17000.00
0005435437899	6713	Economy	17000.00
0005435437923	6713	Economy	17000.00
0005435682499	6713	Economy	17000.00
0005435682511	6713	Economy	17000.00
0005435682514	6713	Economy	17000.00
0005435438029	6713	Economy	17000.00
0005435682506	6713	Economy	17000.00
0005435682507	6713	Economy	17000.00
0005435437974	6713	Economy	17000.00
0005432136217	6713	Economy	17000.00
0005435630992	6713	Economy	17000.00
0005435437922	6713	Economy	17000.00
0005435630993	6713	Economy	17000.00
0005435682519	6713	Economy	17000.00
0005435438015	6713	Economy	17000.00
0005435437953	6713	Economy	17000.00
0005435661956	6713	Economy	17000.00
0005435438030	6713	Economy	17000.00
0005432136215	6713	Economy	17000.00
0005435221515	6713	Economy	17000.00
0005435682501	6713	Economy	17000.00
0005435682504	6713	Economy	17000.00
0005435438008	6713	Economy	17000.00
0005434828696	6713	Economy	17000.00
0005435438048	6713	Economy	17000.00
0005435661957	6713	Economy	17000.00
0005435682489	6713	Economy	17000.00
0005435438002	6713	Economy	17000.00
0005435682490	6713	Economy	17000.00
0005432136216	6713	Economy	17000.00
0005435682496	6713	Economy	17000.00
0005435682500	6713	Economy	17000.00
0005435682486	6713	Economy	17000.00
0005435437969	6713	Economy	17000.00
0005432136213	6713	Economy	17000.00
0005435682497	6713	Economy	17000.00
0005434828700	6713	Economy	17000.00
0005435437946	6713	Economy	17000.00
0005435438009	6713	Economy	17000.00
0005435682495	6713	Economy	17000.00
0005435682487	6713	Economy	17000.00
0005435682508	6713	Economy	17000.00
0005435682492	6713	Economy	17000.00
0005435438072	6713	Economy	17000.00
0005432136214	6713	Economy	17000.00
0005435217722	6713	Economy	17000.00
0005435682502	6713	Economy	17000.00
0005435437910	6713	Economy	17000.00
0005435682515	6713	Economy	17000.00
0005435682493	6713	Economy	17000.00
0005435661954	6713	Economy	17000.00
0005435682513	6713	Economy	17000.00
0005435682509	6713	Economy	17000.00
0005435437911	6713	Economy	17000.00
0005435682503	6713	Economy	17000.00
0005435220321	6713	Economy	17000.00
0005435438012	6713	Economy	17000.00
0005435682043	24575	Business	51100.00
0005435682111	24575	Business	51100.00
0005435661938	24575	Business	51100.00
0005435219216	24575	Business	51100.00
0005435438147	24575	Business	51100.00
0005435630976	24575	Business	51100.00
0005435438160	24575	Business	51100.00
0005435630958	24575	Business	51100.00
0005435682313	24575	Business	51100.00
0005435630981	24575	Business	51100.00
0005435682110	24575	Business	51100.00
0005435682143	24575	Business	51100.00
0005435682147	24575	Economy	17000.00
0005435438152	24575	Economy	17000.00
0005435682239	24575	Economy	17000.00
0005435682000	24575	Economy	17000.00
0005435682045	24575	Economy	17000.00
0005435438157	24575	Economy	17000.00
0005435438143	24575	Economy	17000.00
0005435438158	24575	Economy	17000.00
0005435438159	24575	Economy	18700.00
0005435682316	24575	Economy	18700.00
0005435438164	24575	Economy	18700.00
0005435630957	24575	Economy	18700.00
0005435682029	24575	Economy	17000.00
0005434828724	24575	Economy	17000.00
0005432533317	24575	Economy	17000.00
0005435438163	24575	Economy	17000.00
0005435219217	24575	Economy	17000.00
0005435438145	24575	Economy	17000.00
0005435630971	24575	Economy	17000.00
0005432533319	24575	Economy	17000.00
0005435220338	24575	Economy	17000.00
0005435438144	24575	Economy	17000.00
0005435682312	24575	Economy	17000.00
0005434828722	24575	Economy	17000.00
0005435438161	24575	Economy	17000.00
0005435220337	24575	Economy	17000.00
0005435682262	24575	Economy	17000.00
0005435219219	24575	Economy	17000.00
0005435682044	24575	Economy	17000.00
0005435438165	24575	Economy	17000.00
0005435438148	24575	Economy	17000.00
0005435630969	24575	Economy	17000.00
0005435219218	24575	Economy	17000.00
0005435682123	24575	Economy	17000.00
0005435630970	24575	Economy	17000.00
0005435682062	24575	Economy	17000.00
0005435682247	24575	Economy	17000.00
0005435438151	24575	Economy	17000.00
0005432305771	24575	Economy	17000.00
0005435438146	24575	Economy	17000.00
0005435682216	24575	Economy	17000.00
0005435438153	24575	Economy	17000.00
0005435682168	24575	Economy	17000.00
0005435682092	24575	Economy	17000.00
0005435438155	24575	Economy	17000.00
0005435682125	24575	Economy	17000.00
0005435682014	24575	Economy	17000.00
0005435682061	24575	Economy	17000.00
0005435682195	24575	Economy	17000.00
0005435682127	24575	Economy	17000.00
0005432305773	24575	Economy	17000.00
0005435682093	24575	Economy	17000.00
0005432305772	24575	Economy	17000.00
0005435438162	24575	Economy	17000.00
0005435682018	24575	Economy	17000.00
0005432533318	24575	Economy	17000.00
0005435438150	24575	Economy	17000.00
0005435682146	24575	Economy	17000.00
0005435682263	24575	Economy	17000.00
0005435682368	24575	Economy	17000.00
0005435682096	24575	Economy	17000.00
0005435220335	24575	Economy	17000.00
0005435438156	24575	Economy	17000.00
0005432305770	24575	Economy	17000.00
0005435682217	24575	Economy	17000.00
0005435438149	24575	Economy	17000.00
0005434828723	24575	Economy	17000.00
0005435682194	24575	Economy	17000.00
0005435682215	24575	Economy	17000.00
0005435682310	24575	Economy	17000.00
0005435438154	24575	Economy	17000.00
0005435219220	24575	Economy	17000.00
0005435220339	24575	Economy	17000.00
0005435220336	24575	Economy	17000.00
0005435682153	24575	Economy	17000.00
0005435682219	24575	Economy	17000.00
0005435106008	11559	Business	26400.00
0005435106010	11559	Business	26400.00
0005435126702	11559	Business	26400.00
0005435126694	11559	Business	26400.00
0005435126706	11559	Business	26400.00
0005435126722	11559	Business	26400.00
0005435106009	11559	Business	26400.00
0005435126697	11559	Economy	8800.00
0005435126716	11559	Economy	8800.00
0005435126700	11559	Economy	8800.00
0005435126709	11559	Economy	8800.00
0005435126714	11559	Economy	9700.00
0005435126731	11559	Economy	9700.00
0005435126690	11559	Economy	9700.00
0005435126730	11559	Economy	9700.00
0005435126703	11559	Economy	8800.00
0005435126701	11559	Economy	8800.00
0005435126717	11559	Economy	8800.00
0005435126718	11559	Economy	8800.00
0005435106007	11559	Economy	8800.00
0005435126696	11559	Economy	8800.00
0005435126726	11559	Economy	8800.00
0005435126715	11559	Economy	8800.00
0005435126719	11559	Economy	8800.00
0005435126711	11559	Economy	8800.00
0005435126708	11559	Economy	8800.00
0005435126721	11559	Economy	8800.00
0005435126724	11559	Economy	8800.00
0005435126691	11559	Economy	8800.00
0005435126727	11559	Economy	8800.00
0005435126712	11559	Economy	8800.00
0005435126698	11559	Economy	8800.00
0005435126704	11559	Economy	8800.00
0005435126699	11559	Economy	8800.00
0005435126689	11559	Economy	8800.00
0005435126705	11559	Economy	8800.00
0005435126692	11559	Economy	8800.00
0005435126695	11559	Economy	8800.00
0005435126693	11559	Economy	8800.00
0005435126725	11559	Economy	8800.00
0005435126707	11559	Economy	8800.00
0005435126723	11559	Economy	8800.00
0005435126688	11559	Economy	8800.00
0005435126713	11559	Economy	8800.00
0005435126710	11559	Economy	8800.00
0005435126729	11559	Economy	8800.00
0005435126728	11559	Economy	8800.00
0005435126720	11559	Economy	8800.00
0005435126481	31863	Business	26400.00
0005435126470	31863	Business	26400.00
0005435126409	31863	Business	26400.00
0005435126515	31863	Business	26400.00
0005435126529	31863	Business	26400.00
0005435126446	31863	Business	26400.00
0005435126449	31863	Business	26400.00
0005435126445	31863	Business	26400.00
0005435126441	31863	Business	26400.00
0005435105993	31863	Economy	8800.00
0005435558111	31863	Economy	8800.00
0005435126478	31863	Economy	8800.00
0005435105988	31863	Economy	8800.00
0005435126389	31863	Economy	9700.00
0005435126303	31863	Economy	9700.00
0005435126489	31863	Economy	9700.00
0005435126380	31863	Economy	8800.00
0005435126408	31863	Economy	8800.00
0005435126528	31863	Economy	8800.00
0005435126410	31863	Economy	8800.00
0005435126427	31863	Economy	8800.00
0005435126358	31863	Economy	8800.00
0005435126432	31863	Economy	8800.00
0005435126354	31863	Economy	8800.00
0005435126433	31863	Economy	8800.00
0005435126337	31863	Economy	8800.00
0005435126336	31863	Economy	8800.00
0005435098544	31863	Economy	8800.00
0005435126331	31863	Economy	8800.00
0005435126547	31863	Economy	8800.00
0005435126450	31863	Economy	8800.00
0005435126527	31863	Economy	8800.00
0005435126295	31863	Economy	8800.00
0005435126471	31863	Economy	8800.00
0005435105992	31863	Economy	8800.00
0005435126472	31863	Economy	8800.00
0005435126428	31863	Economy	8800.00
0005435126488	31863	Economy	8800.00
0005435126388	31863	Economy	8800.00
0005435126270	31863	Economy	8800.00
0005435126332	31863	Economy	8800.00
0005435126364	31863	Economy	8800.00
0005435126451	31863	Economy	8800.00
0005435126363	31863	Economy	8800.00
0005435126392	31863	Economy	8800.00
0005435126448	31863	Economy	8800.00
0005435126271	31863	Economy	8800.00
0005435105994	31863	Economy	8800.00
0005435126359	31863	Economy	8800.00
0005435732284	13522	Business	36600.00
0005433398502	13522	Business	36600.00
0005435732300	13522	Business	36600.00
0005433398511	13522	Business	36600.00
0005433398487	13522	Business	36600.00
0005433398517	13522	Business	36600.00
0005433398503	13522	Business	36600.00
0005433398500	13522	Economy	12200.00
0005433398496	13522	Economy	12200.00
0005433398493	13522	Economy	12200.00
0005433398478	13522	Economy	12200.00
0005433398480	13522	Economy	12200.00
0005435732306	13522	Economy	12200.00
0005435732357	13522	Economy	12200.00
0005435732283	13522	Economy	12200.00
0005433398485	13522	Economy	13400.00
0005433398521	13522	Economy	13400.00
0005433398518	13522	Economy	13400.00
0005433398498	13522	Economy	12200.00
0005433398473	13522	Economy	12200.00
0005433398491	13522	Economy	12200.00
0005433398516	13522	Economy	12200.00
0005435732298	13522	Economy	12200.00
0005433398488	13522	Economy	12200.00
0005435732346	13522	Economy	12200.00
0005433398482	13522	Economy	12200.00
0005433398522	13522	Economy	12200.00
0005433398513	13522	Economy	12200.00
0005435732320	13522	Economy	12200.00
0005433398508	13522	Economy	12200.00
0005433398477	13522	Economy	12200.00
0005433398474	13522	Economy	12200.00
0005433398507	13522	Economy	12200.00
0005433398520	13522	Economy	12200.00
0005435732332	13522	Economy	12200.00
0005435732336	13522	Economy	12200.00
0005433398481	13522	Economy	12200.00
0005435732369	13522	Economy	12200.00
0005433398486	13522	Economy	12200.00
0005433398519	13522	Economy	12200.00
0005433398515	13522	Economy	12200.00
0005435732329	13522	Economy	12200.00
0005433398497	13522	Economy	12200.00
0005433398476	13522	Economy	12200.00
0005433398514	13522	Economy	12200.00
0005433398484	13522	Economy	12200.00
0005433398499	13522	Economy	12200.00
0005433398509	13522	Economy	12200.00
0005433398512	13522	Economy	12200.00
0005433398490	13522	Economy	12200.00
0005433398510	13522	Economy	12200.00
0005433398506	13522	Economy	12200.00
0005433398479	13522	Economy	12200.00
0005433398504	13522	Economy	12200.00
0005433398475	13522	Economy	12200.00
0005433398494	13522	Economy	12200.00
0005433398489	13522	Economy	12200.00
0005433398471	13522	Economy	12200.00
0005435732305	13522	Economy	12200.00
0005435732360	13522	Economy	12200.00
0005433398472	13522	Economy	12200.00
0005433398483	13522	Economy	12200.00
0005433398501	13522	Economy	12200.00
0005433398505	13522	Economy	12200.00
0005433398495	13522	Economy	12200.00
0005435732342	13522	Economy	12200.00
0005433398492	13522	Economy	12200.00
0005435732453	19388	Business	36600.00
0005435732459	19388	Business	36600.00
0005432297301	19388	Business	36600.00
0005433398057	19388	Business	36600.00
0005433398256	19388	Business	36600.00
0005433397984	19388	Business	36600.00
0005433398167	19388	Business	36600.00
0005433397931	19388	Economy	12200.00
0005433397972	19388	Economy	12200.00
0005433397988	19388	Economy	12200.00
0005433397971	19388	Economy	12200.00
0005435732455	19388	Economy	12200.00
0005433398079	19388	Economy	13400.00
0005433397999	19388	Economy	13400.00
0005433398087	19388	Economy	13400.00
0005433398119	19388	Economy	12200.00
0005433398198	19388	Economy	12200.00
0005435732447	19388	Economy	12200.00
0005433398030	19388	Economy	12200.00
0005435732449	19388	Economy	12200.00
0005435732452	19388	Economy	12200.00
0005435732443	19388	Economy	12200.00
0005433397985	19388	Economy	12200.00
0005435732442	19388	Economy	12200.00
0005433398084	19388	Economy	12200.00
0005435732456	19388	Economy	12200.00
0005435732454	19388	Economy	12200.00
0005433398268	19388	Economy	12200.00
0005432297300	19388	Economy	12200.00
0005433398059	19388	Economy	12200.00
0005433398215	19388	Economy	12200.00
0005435732450	19388	Economy	12200.00
0005433397998	19388	Economy	12200.00
0005433397976	19388	Economy	12200.00
0005433398174	19388	Economy	12200.00
0005432297302	19388	Economy	12200.00
0005433398156	19388	Economy	12200.00
0005433398048	19388	Economy	12200.00
0005433397863	19388	Economy	12200.00
0005435732448	19388	Economy	12200.00
0005433398180	19388	Economy	12200.00
0005433397932	19388	Economy	12200.00
0005435732446	19388	Economy	12200.00
0005433397960	19388	Economy	12200.00
0005433398207	19388	Economy	12200.00
0005435732451	19388	Economy	12200.00
0005433397864	19388	Economy	12200.00
0005433398060	19388	Economy	12200.00
0005435732445	19388	Economy	12200.00
0005435732458	19388	Economy	12200.00
0005435732457	19388	Economy	12200.00
0005433398104	19388	Economy	12200.00
0005435732460	19388	Economy	12200.00
0005435732444	19388	Economy	12200.00
0005433397970	19388	Economy	12200.00
0005433398085	19388	Economy	12200.00
0005433397907	19388	Economy	12200.00
0005433398214	19388	Economy	12200.00
0005433398095	19388	Economy	12200.00
0005435732441	19388	Economy	12200.00
0005435925423	13188	Business	11300.00
0005435069214	13188	Business	11300.00
0005435068879	13188	Business	11300.00
0005435069067	13188	Business	11300.00
0005435069004	13188	Business	11300.00
0005435069072	13188	Business	11300.00
0005435069002	13188	Business	11300.00
0005435925422	13188	Business	11300.00
0005435069098	13188	Business	11300.00
0005435069013	13188	Business	11300.00
0005435069043	13188	Economy	3800.00
0005435069230	13188	Economy	3800.00
0005435069163	13188	Economy	3800.00
0005435069061	13188	Economy	3800.00
0005435068931	13188	Economy	3800.00
0005435925412	13188	Economy	3800.00
0005435069077	13188	Economy	3800.00
0005435069093	13188	Economy	3800.00
0005435069076	13188	Economy	3800.00
0005435068964	13188	Economy	4100.00
0005435069119	13188	Economy	4100.00
0005435069147	13188	Economy	4100.00
0005435069220	13188	Economy	4100.00
0005435069236	13188	Economy	4100.00
0005435069039	13188	Economy	3800.00
0005435069229	13188	Economy	3800.00
0005435069162	13188	Economy	3800.00
0005435068763	13188	Economy	3800.00
0005435069023	13188	Economy	3800.00
0005435068947	13188	Economy	3800.00
0005435069033	13188	Economy	3800.00
0005435069088	13188	Economy	3800.00
0005435068759	13188	Economy	3800.00
0005435925418	13188	Economy	3800.00
0005435069224	13188	Economy	3800.00
0005435069040	13188	Economy	3800.00
0005435068975	13188	Economy	3800.00
0005435069066	13188	Economy	3800.00
0005435068957	13188	Economy	3800.00
0005435068901	13188	Economy	3800.00
0005435069047	13188	Economy	3800.00
0005435069083	13188	Economy	3800.00
0005435069099	13188	Economy	3800.00
0005435068915	13188	Economy	3800.00
0005435925413	13188	Economy	3800.00
0005435068952	13188	Economy	3800.00
0005435925417	13188	Economy	3800.00
0005435069127	13188	Economy	3800.00
0005435925419	13188	Economy	3800.00
0005435069189	13188	Economy	3800.00
0005435069048	13188	Economy	3800.00
0005435069286	13188	Economy	3800.00
0005435069183	13188	Economy	3800.00
0005435925416	13188	Economy	3800.00
0005435069022	13188	Economy	3800.00
0005435068762	13188	Economy	3800.00
0005435069058	13188	Economy	3800.00
0005435068951	13188	Economy	3800.00
0005435068716	13188	Economy	3800.00
0005435925421	13188	Economy	3800.00
0005435068867	13188	Economy	3800.00
0005435069068	13188	Economy	3800.00
0005435925415	13188	Economy	3800.00
0005435069021	13188	Economy	3800.00
0005435068896	13188	Economy	3800.00
0005435068958	13188	Economy	3800.00
0005435069215	13188	Economy	3800.00
0005435068715	13188	Economy	3800.00
0005435925420	13188	Economy	3800.00
0005435069223	13188	Economy	3800.00
0005435068930	13188	Economy	3800.00
0005435069221	13188	Economy	3800.00
0005435925414	13188	Economy	3800.00
0005435068948	13188	Economy	3800.00
0005435068963	13188	Economy	3800.00
0005435068914	13188	Economy	3800.00
0005435069521	15472	Business	11300.00
0005435925332	15472	Business	11300.00
0005435069493	15472	Business	11300.00
0005435069533	15472	Business	11300.00
0005435925309	15472	Business	11300.00
0005435925266	15472	Economy	3800.00
0005435069522	15472	Economy	3800.00
0005435069485	15472	Economy	3800.00
0005435069519	15472	Economy	3800.00
0005435069515	15472	Economy	3800.00
0005435069510	15472	Economy	3800.00
0005435069500	15472	Economy	3800.00
0005435069501	15472	Economy	4100.00
0005435069507	15472	Economy	4100.00
0005435925267	15472	Economy	4100.00
0005435069527	15472	Economy	4100.00
0005435069494	15472	Economy	3800.00
0005435069509	15472	Economy	3800.00
0005435069490	15472	Economy	3800.00
0005435069525	15472	Economy	3800.00
0005435069505	15472	Economy	3800.00
0005435069526	15472	Economy	3800.00
0005435925291	15472	Economy	3800.00
0005435069516	15472	Economy	3800.00
0005435069529	15472	Economy	3800.00
0005435069514	15472	Economy	3800.00
0005435069535	15472	Economy	3800.00
0005435069517	15472	Economy	3800.00
0005435069487	15472	Economy	3800.00
0005435069496	15472	Economy	3800.00
0005435069531	15472	Economy	3800.00
0005435069484	15472	Economy	3800.00
0005435069488	15472	Economy	3800.00
0005435925276	15472	Economy	3800.00
0005435069532	15472	Economy	3800.00
0005435925308	15472	Economy	3800.00
0005435069489	15472	Economy	3800.00
0005435925226	15472	Economy	3800.00
0005435069520	15472	Economy	3800.00
0005435069504	15472	Economy	3800.00
0005435069528	15472	Economy	3800.00
0005435925333	15472	Economy	3800.00
0005435925303	15472	Economy	3800.00
0005435069495	15472	Economy	3800.00
0005435069518	15472	Economy	3800.00
0005435925292	15472	Economy	3800.00
0005435069530	15472	Economy	3800.00
0005435069513	15472	Economy	3800.00
0005435069534	15472	Economy	3800.00
0005435069506	15472	Economy	3800.00
0005435069486	15472	Economy	3800.00
0005435069512	15472	Economy	3800.00
0005435069502	15472	Economy	3800.00
0005435069503	15472	Economy	3800.00
0005435069498	15472	Economy	3800.00
0005435069497	15472	Economy	3800.00
0005435925275	15472	Economy	3800.00
0005435069499	15472	Economy	3800.00
0005435069492	15472	Economy	3800.00
0005435069491	15472	Economy	3800.00
0005435069483	15472	Economy	3800.00
0005435069524	15472	Economy	3800.00
0005435069511	15472	Economy	3800.00
0005435069523	15472	Economy	3800.00
0005435069508	15472	Economy	3800.00
0005435925257	15472	Economy	3800.00
0005435925274	15472	Economy	3800.00
0005434756425	10734	Business	61300.00
0005434756419	10734	Business	61300.00
0005434756369	10734	Business	61300.00
0005434756297	10734	Business	61300.00
0005434756361	10734	Business	61300.00
0005434214941	10734	Business	61300.00
0005434214940	10734	Business	61300.00
0005434214977	10734	Business	61300.00
0005434756427	10734	Business	61300.00
0005434756323	10734	Business	61300.00
0005434756368	10734	Economy	20400.00
0005434756329	10734	Economy	20400.00
0005434756435	10734	Economy	20400.00
0005434214961	10734	Economy	20400.00
0005434214978	10734	Economy	20400.00
0005434214959	10734	Economy	20400.00
0005434214945	10734	Economy	20400.00
0005434756398	10734	Economy	20400.00
0005434756298	10734	Economy	22500.00
0005434214976	10734	Economy	22500.00
0005434214943	10734	Economy	22500.00
0005434756488	10734	Economy	22500.00
0005434214956	10734	Economy	22500.00
0005434214939	10734	Economy	20400.00
0005434756263	10734	Economy	20400.00
0005434214969	10734	Economy	20400.00
0005434214974	10734	Economy	20400.00
0005434214952	10734	Economy	20400.00
0005434214975	10734	Economy	20400.00
0005434214946	10734	Economy	20400.00
0005434214967	10734	Economy	20400.00
0005434756446	10734	Economy	20400.00
0005434756376	10734	Economy	20400.00
0005434214972	10734	Economy	20400.00
0005434214964	10734	Economy	20400.00
0005434756337	10734	Economy	20400.00
0005434756436	10734	Economy	20400.00
0005434756372	10734	Economy	20400.00
0005434214942	10734	Economy	20400.00
0005434214947	10734	Economy	20400.00
0005434214966	10734	Economy	20400.00
0005434214944	10734	Economy	20400.00
0005434214973	10734	Economy	20400.00
0005434214958	10734	Economy	20400.00
0005434756371	10734	Economy	20400.00
0005434756442	10734	Economy	20400.00
0005434756414	10734	Economy	20400.00
0005434756377	10734	Economy	20400.00
0005434214954	10734	Economy	20400.00
0005434756460	10734	Economy	20400.00
0005434756417	10734	Economy	20400.00
0005434756438	10734	Economy	20400.00
0005434214951	10734	Economy	20400.00
0005434214957	10734	Economy	20400.00
0005434214980	10734	Economy	20400.00
0005434214955	10734	Economy	20400.00
0005434756399	10734	Economy	20400.00
0005434214963	10734	Economy	20400.00
0005434756405	10734	Economy	20400.00
0005434214960	10734	Economy	20400.00
0005434756359	10734	Economy	20400.00
0005434214982	10734	Economy	20400.00
0005434756418	10734	Economy	20400.00
0005434214948	10734	Economy	20400.00
0005434756393	10734	Economy	20400.00
0005434214953	10734	Economy	20400.00
0005434214950	10734	Economy	20400.00
0005434214981	10734	Economy	20400.00
0005434756437	10734	Economy	20400.00
0005434214970	10734	Economy	20400.00
0005434214968	10734	Economy	20400.00
0005434214979	10734	Economy	20400.00
0005434756426	10734	Economy	20400.00
0005434756367	10734	Economy	20400.00
0005434214949	10734	Economy	20400.00
0005434214962	10734	Economy	20400.00
0005434214971	10734	Economy	20400.00
0005434756275	10734	Economy	20400.00
0005434756274	10734	Economy	20400.00
0005434214938	10734	Economy	20400.00
0005434214965	10734	Economy	20400.00
0005434756406	10734	Economy	20400.00
0005434756354	10734	Economy	20400.00
0005434214227	28696	Business	61300.00
0005434756766	28696	Business	61300.00
0005434214561	28696	Business	61300.00
0005434756783	28696	Business	61300.00
0005434756769	28696	Business	61300.00
0005434214377	28696	Business	61300.00
0005434214515	28696	Business	61300.00
0005434214421	28696	Business	61300.00
0005434756761	28696	Business	61300.00
0005434214366	28696	Business	61300.00
0005434756750	28696	Business	61300.00
0005434756784	28696	Business	61300.00
0005434214443	28696	Economy	20400.00
0005434214607	28696	Economy	20400.00
0005434756753	28696	Economy	20400.00
0005434214470	28696	Economy	20400.00
0005434214479	28696	Economy	20400.00
0005434756778	28696	Economy	20400.00
0005434214555	28696	Economy	20400.00
0005434756781	28696	Economy	20400.00
0005434214320	28696	Economy	20400.00
0005434756780	28696	Economy	22500.00
0005434756763	28696	Economy	22500.00
0005434214298	28696	Economy	22500.00
0005434756777	28696	Economy	22500.00
0005434214423	28696	Economy	22500.00
0005434214333	28696	Economy	20400.00
0005434214327	28696	Economy	20400.00
0005434214326	28696	Economy	20400.00
0005434214539	28696	Economy	20400.00
0005434756758	28696	Economy	20400.00
0005434214512	28696	Economy	20400.00
0005434214379	28696	Economy	20400.00
0005434756754	28696	Economy	20400.00
0005434214355	28696	Economy	20400.00
0005434756752	28696	Economy	20400.00
0005434756749	28696	Economy	20400.00
0005434756779	28696	Economy	20400.00
0005434756770	28696	Economy	20400.00
0005434214612	28696	Economy	20400.00
0005434214376	28696	Economy	20400.00
0005434756768	28696	Economy	20400.00
0005434214517	28696	Economy	20400.00
0005434756751	28696	Economy	20400.00
0005434214680	28696	Economy	20400.00
0005434214627	28696	Economy	20400.00
0005434214332	28696	Economy	20400.00
0005434214556	28696	Economy	20400.00
0005434214354	28696	Economy	20400.00
0005434214594	28696	Economy	20400.00
0005434214426	28696	Economy	20400.00
0005434214442	28696	Economy	20400.00
0005434756762	28696	Economy	20400.00
0005434214558	28696	Economy	20400.00
0005434214474	28696	Economy	20400.00
0005434756773	28696	Economy	20400.00
0005434214536	28696	Economy	20400.00
0005434214634	28696	Economy	20400.00
0005434214480	28696	Economy	20400.00
0005434214420	28696	Economy	20400.00
0005434756759	28696	Economy	20400.00
0005434756760	28696	Economy	20400.00
0005434214598	28696	Economy	20400.00
0005434756774	28696	Economy	20400.00
0005434756756	28696	Economy	20400.00
0005434214478	28696	Economy	20400.00
0005434756764	28696	Economy	20400.00
0005434756755	28696	Economy	20400.00
0005434756775	28696	Economy	20400.00
0005434756785	28696	Economy	20400.00
0005434756786	28696	Economy	20400.00
0005434214476	28696	Economy	20400.00
0005434214489	28696	Economy	20400.00
0005434214214	28696	Economy	20400.00
0005434756776	28696	Economy	20400.00
0005434756765	28696	Economy	20400.00
0005434214473	28696	Economy	20400.00
0005434756782	28696	Economy	20400.00
0005434214633	28696	Economy	20400.00
0005434214398	28696	Economy	20400.00
0005434214433	28696	Economy	20400.00
0005434214352	28696	Economy	20400.00
0005434756772	28696	Economy	20400.00
0005434214445	28696	Economy	20400.00
0005434756767	28696	Economy	20400.00
0005434214397	28696	Economy	20400.00
0005434756747	28696	Economy	20400.00
0005434756748	28696	Economy	20400.00
0005434214533	28696	Economy	20400.00
0005434756771	28696	Economy	20400.00
0005434214537	28696	Economy	20400.00
0005434214353	28696	Economy	20400.00
0005434214599	28696	Economy	20400.00
0005434214554	28696	Economy	20400.00
0005434756757	28696	Economy	20400.00
0005435007251	5448	Business	29500.00
0005435007231	5448	Business	29500.00
0005434229474	5448	Business	29500.00
0005435040338	5448	Business	29500.00
0005435040373	5448	Business	29500.00
0005435040327	5448	Business	29500.00
0005435040347	5448	Business	29500.00
0005435040377	5448	Business	29500.00
0005435040356	5448	Business	29500.00
0005435040361	5448	Business	29500.00
0005435040352	5448	Business	29500.00
0005435007244	5448	Business	29500.00
0005435040332	5448	Economy	9800.00
0005435007245	5448	Economy	9800.00
0005435040379	5448	Economy	9800.00
0005435040381	5448	Economy	9800.00
0005435007241	5448	Economy	9800.00
0005435007235	5448	Economy	9800.00
0005435007242	5448	Economy	9800.00
0005435040355	5448	Economy	9800.00
0005434229390	5448	Economy	9800.00
0005435040363	5448	Economy	9800.00
0005435040342	5448	Economy	9800.00
0005435040358	5448	Economy	9800.00
0005435040350	5448	Economy	9800.00
0005435007249	5448	Economy	9800.00
0005435040346	5448	Economy	9800.00
0005435007229	5448	Economy	9800.00
0005432125523	5448	Economy	9800.00
0005434229242	5448	Economy	9800.00
0005435040320	5448	Economy	9800.00
0005435007247	5448	Economy	9800.00
0005435040382	5448	Economy	9800.00
0005435040344	5448	Economy	9800.00
0005434229420	5448	Economy	9800.00
0005435007232	5448	Economy	9800.00
0005434229370	5448	Economy	9800.00
0005434229241	5448	Economy	9800.00
0005434229308	5448	Economy	9800.00
0005434229320	5448	Economy	9800.00
0005435040362	5448	Economy	9800.00
0005435040370	5448	Economy	9800.00
0005435040348	5448	Economy	9800.00
0005435040371	5448	Economy	9800.00
0005435040323	5448	Economy	9800.00
0005435043292	5448	Economy	9800.00
0005435040324	5448	Economy	9800.00
0005435040372	5448	Economy	9800.00
0005435040353	5448	Economy	9800.00
0005434229264	5448	Economy	9800.00
0005435040374	5448	Economy	9800.00
0005435040340	5448	Economy	10800.00
0005434229409	5448	Economy	10800.00
0005435040354	5448	Economy	10800.00
0005435040345	5448	Economy	10800.00
0005435040321	5448	Economy	9800.00
0005435007252	5448	Economy	10800.00
0005435040369	5448	Economy	9800.00
0005434229294	5448	Economy	9800.00
0005435040349	5448	Economy	9800.00
0005435040378	5448	Economy	9800.00
0005435040318	5448	Economy	9800.00
0005435040328	5448	Economy	9800.00
0005434229382	5448	Economy	9800.00
0005434229381	5448	Economy	9800.00
0005435040322	5448	Economy	9800.00
0005435007239	5448	Economy	9800.00
0005435040360	5448	Economy	9800.00
0005435040375	5448	Economy	9800.00
0005432125517	5448	Economy	9800.00
0005435007248	5448	Economy	9800.00
0005435007237	5448	Economy	9800.00
0005435042877	5448	Economy	9800.00
0005435040339	5448	Economy	9800.00
0005432125520	5448	Economy	9800.00
0005435040365	5448	Economy	9800.00
0005435007238	5448	Economy	9800.00
0005435040343	5448	Economy	9800.00
0005434229223	5448	Economy	9800.00
0005435040331	5448	Economy	9800.00
0005435040319	5448	Economy	9800.00
0005435040357	5448	Economy	9800.00
0005434229450	5448	Economy	9800.00
0005435007250	5448	Economy	9800.00
0005435040334	5448	Economy	9800.00
0005435040326	5448	Economy	9800.00
0005435040376	5448	Economy	9800.00
0005435040329	5448	Economy	9800.00
0005435040337	5448	Economy	9800.00
0005435007234	5448	Economy	9800.00
0005432125516	5448	Economy	9800.00
0005435040380	5448	Economy	9800.00
0005435040333	5448	Economy	9800.00
0005435040325	5448	Economy	9800.00
0005435007243	5448	Economy	9800.00
0005435040366	5448	Economy	9800.00
0005435042878	5448	Economy	9800.00
0005434229303	5448	Economy	9800.00
0005435007227	5448	Economy	9800.00
0005435007246	5448	Economy	9800.00
0005435007240	5448	Economy	9800.00
0005432125519	5448	Economy	9800.00
0005435007236	5448	Economy	9800.00
0005435007228	5448	Economy	9800.00
0005435040359	5448	Economy	9800.00
0005432125522	5448	Economy	9800.00
0005435040341	5448	Economy	9800.00
0005435040367	5448	Economy	9800.00
0005435040368	5448	Economy	9800.00
0005435007233	5448	Economy	9800.00
0005435040335	5448	Economy	9800.00
0005434229319	5448	Economy	9800.00
0005435040364	5448	Economy	9800.00
0005432125518	5448	Economy	9800.00
0005435040330	5448	Economy	9800.00
0005432125521	5448	Economy	9800.00
0005435042876	5448	Economy	9800.00
0005435042875	5448	Economy	9800.00
0005434229499	5448	Economy	9800.00
0005434229371	5448	Economy	9800.00
0005432125515	5448	Economy	9800.00
0005435040336	5448	Economy	9800.00
0005435007230	5448	Economy	9800.00
0005434229293	5448	Economy	9800.00
0005434229224	5448	Economy	9800.00
0005435040351	5448	Economy	9800.00
0005434229581	12954	Business	29500.00
0005434229576	12954	Business	29500.00
0005435007069	12954	Business	29500.00
0005435039938	12954	Business	29500.00
0005434229577	12954	Business	29500.00
0005435039862	12954	Business	29500.00
0005435007038	12954	Business	29500.00
0005435039764	12954	Business	29500.00
0005435039709	12954	Business	29500.00
0005435007071	12954	Business	29500.00
0005435039949	12954	Business	29500.00
0005435007068	12954	Business	29500.00
0005434229588	12954	Economy	9800.00
0005432304434	12954	Economy	9800.00
0005435039933	12954	Economy	9800.00
0005434229582	12954	Economy	9800.00
0005435039675	12954	Economy	9800.00
0005435039674	12954	Economy	9800.00
0005435039634	12954	Economy	9800.00
0005435039684	12954	Economy	9800.00
0005435039894	12954	Economy	9800.00
0005435039677	12954	Economy	9800.00
0005435039729	12954	Economy	9800.00
0005435039944	12954	Economy	9800.00
0005435006983	12954	Economy	9800.00
0005435039515	12954	Economy	9800.00
0005435006981	12954	Economy	9800.00
0005435007125	12954	Economy	9800.00
0005435040064	12954	Economy	9800.00
0005435007028	12954	Economy	9800.00
0005434229589	12954	Economy	9800.00
0005434229578	12954	Economy	9800.00
0005435007029	12954	Economy	9800.00
0005432304436	12954	Economy	9800.00
0005435039474	12954	Economy	9800.00
0005435039611	12954	Economy	9800.00
0005435039873	12954	Economy	9800.00
0005435007039	12954	Economy	9800.00
0005434229568	12954	Economy	9800.00
0005435039893	12954	Economy	9800.00
0005435039992	12954	Economy	9800.00
0005435039623	12954	Economy	9800.00
0005435039682	12954	Economy	9800.00
0005434229587	12954	Economy	9800.00
0005434229584	12954	Economy	9800.00
0005435006970	12954	Economy	9800.00
0005434229580	12954	Economy	9800.00
0005435039782	12954	Economy	9800.00
0005435039806	12954	Economy	9800.00
0005435039932	12954	Economy	9800.00
0005435040022	12954	Economy	9800.00
0005435040070	12954	Economy	9800.00
0005435040063	12954	Economy	10800.00
0005434229571	12954	Economy	10800.00
0005435039807	12954	Economy	10800.00
0005434229570	12954	Economy	10800.00
0005435039553	12954	Economy	10800.00
0005435039681	12954	Economy	9800.00
0005435039845	12954	Economy	9800.00
0005435039763	12954	Economy	9800.00
0005435039904	12954	Economy	9800.00
0005435007072	12954	Economy	9800.00
0005435039615	12954	Economy	9800.00
0005435040080	12954	Economy	9800.00
0005435039762	12954	Economy	9800.00
0005434229572	12954	Economy	9800.00
0005435039728	12954	Economy	9800.00
0005435039937	12954	Economy	9800.00
0005434229569	12954	Economy	9800.00
0005435007037	12954	Economy	9800.00
0005435007030	12954	Economy	9800.00
0005435040069	12954	Economy	9800.00
0005435007014	12954	Economy	9800.00
0005435039750	12954	Economy	9800.00
0005435039554	12954	Economy	9800.00
0005435039895	12954	Economy	9800.00
0005435039614	12954	Economy	9800.00
0005432304433	12954	Economy	9800.00
0005435039836	12954	Economy	9800.00
0005435006982	12954	Economy	9800.00
0005432304432	12954	Economy	9800.00
0005432304435	12954	Economy	9800.00
0005434229567	12954	Economy	9800.00
0005435039759	12954	Economy	9800.00
0005434229574	12954	Economy	9800.00
0005435007136	12954	Economy	9800.00
0005435039905	12954	Economy	9800.00
0005435040024	12954	Economy	9800.00
0005435007079	12954	Economy	9800.00
0005435039475	12954	Economy	9800.00
0005435040023	12954	Economy	9800.00
0005435007049	12954	Economy	9800.00
0005435039843	12954	Economy	9800.00
0005434229573	12954	Economy	9800.00
0005435039900	12954	Economy	9800.00
0005435039758	12954	Economy	9800.00
0005435007048	12954	Economy	9800.00
0005435007080	12954	Economy	9800.00
0005434229590	12954	Economy	9800.00
0005434229585	12954	Economy	9800.00
0005435007091	12954	Economy	9800.00
0005435007027	12954	Economy	9800.00
0005435007070	12954	Economy	9800.00
0005435039278	12954	Economy	9800.00
0005435039965	12954	Economy	9800.00
0005434229586	12954	Economy	9800.00
0005435039984	12954	Economy	9800.00
0005435007015	12954	Economy	9800.00
0005434229575	12954	Economy	9800.00
0005435039746	12954	Economy	9800.00
0005435039844	12954	Economy	9800.00
0005434229579	12954	Economy	9800.00
0005435007135	12954	Economy	9800.00
0005435006987	12954	Economy	9800.00
0005435039891	12954	Economy	9800.00
0005434229583	12954	Economy	9800.00
0005435007050	12954	Economy	9800.00
0005435007032	12954	Economy	9800.00
0005435007047	12954	Economy	9800.00
0005435039827	12954	Economy	9800.00
0005435039504	12954	Economy	9800.00
0005435007111	12954	Economy	9800.00
0005435039736	12954	Economy	9800.00
0005435039899	12954	Economy	9800.00
0005435039964	12954	Economy	9800.00
0005435039781	12954	Economy	9800.00
0005435039745	12954	Economy	9800.00
0005434411815	14853	Business	52900.00
0005435902659	14853	Business	52900.00
0005434426855	14853	Business	52900.00
0005434426839	14853	Business	52900.00
0005435902714	14853	Business	52900.00
0005434426853	14853	Business	52900.00
0005432188635	14853	Business	52900.00
0005434426862	14853	Business	52900.00
0005434426844	14853	Business	52900.00
0005434426858	14853	Business	52900.00
0005434426843	14853	Economy	17600.00
0005435554197	14853	Economy	17600.00
0005434426851	14853	Economy	17600.00
0005434426856	14853	Economy	17600.00
0005435902715	14853	Economy	17600.00
0005432188634	14853	Economy	19400.00
0005434426847	14853	Economy	19400.00
0005435902647	14853	Economy	19400.00
0005432188636	14853	Economy	19400.00
0005434426849	14853	Economy	17600.00
0005435902781	14853	Economy	17600.00
0005434426865	14853	Economy	17600.00
0005435902593	14853	Economy	17600.00
0005434426867	14853	Economy	17600.00
0005434426842	14853	Economy	17600.00
0005435902730	14853	Economy	17600.00
0005434426864	14853	Economy	17600.00
0005435902690	14853	Economy	17600.00
0005434411814	14853	Economy	17600.00
0005434426845	14853	Economy	17600.00
0005435554189	14853	Economy	17600.00
0005435902738	14853	Economy	17600.00
0005434426848	14853	Economy	17600.00
0005434426868	14853	Economy	17600.00
0005434426854	14853	Economy	17600.00
0005434426857	14853	Economy	17600.00
0005434426846	14853	Economy	17600.00
0005434426850	14853	Economy	17600.00
0005435902716	14853	Economy	17600.00
0005434426852	14853	Economy	17600.00
0005435902707	14853	Economy	17600.00
0005434426841	14853	Economy	17600.00
0005432188633	14853	Economy	17600.00
0005434426838	14853	Economy	17600.00
0005434426861	14853	Economy	17600.00
0005434426863	14853	Economy	17600.00
0005435554196	14853	Economy	17600.00
0005434426866	14853	Economy	17600.00
0005434426869	14853	Economy	17600.00
0005435902733	14853	Economy	17600.00
0005434426860	14853	Economy	17600.00
0005435554198	14853	Economy	17600.00
0005434411817	14853	Economy	17600.00
0005434426840	14853	Economy	17600.00
0005434411816	14853	Economy	17600.00
0005435902592	14853	Economy	17600.00
0005434411813	14853	Economy	17600.00
0005435902731	14853	Economy	17600.00
0005434426859	14853	Economy	17600.00
0005435902696	14853	Economy	17600.00
0005435902688	14853	Economy	17600.00
0005434411812	14853	Economy	17600.00
0005434426543	20206	Business	52900.00
0005434426648	20206	Business	52900.00
0005434426561	20206	Business	52900.00
0005435902867	20206	Business	52900.00
0005435902869	20206	Business	52900.00
0005434426692	20206	Business	52900.00
0005435902868	20206	Business	52900.00
0005435554234	20206	Economy	17600.00
0005435554235	20206	Economy	17600.00
0005434426496	20206	Economy	17600.00
0005432059522	20206	Economy	17600.00
0005434411775	20206	Economy	17600.00
0005434426434	20206	Economy	17600.00
0005434426627	20206	Economy	19400.00
0005435902864	20206	Economy	19400.00
0005435902859	20206	Economy	19400.00
0005434426527	20206	Economy	17600.00
0005434426497	20206	Economy	17600.00
0005435902872	20206	Economy	17600.00
0005434411771	20206	Economy	17600.00
0005434426660	20206	Economy	17600.00
0005435554232	20206	Economy	17600.00
0005434426584	20206	Economy	17600.00
0005434426691	20206	Economy	17600.00
0005434426647	20206	Economy	17600.00
0005435902863	20206	Economy	17600.00
0005434426671	20206	Economy	17600.00
0005434426694	20206	Economy	17600.00
0005434426661	20206	Economy	17600.00
0005434426664	20206	Economy	17600.00
0005434426659	20206	Economy	17600.00
0005435902866	20206	Economy	17600.00
0005434426560	20206	Economy	17600.00
0005435902861	20206	Economy	17600.00
0005434426544	20206	Economy	17600.00
0005434426658	20206	Economy	17600.00
0005434411802	20206	Economy	17600.00
0005434426540	20206	Economy	17600.00
0005435902874	20206	Economy	17600.00
0005434426665	20206	Economy	17600.00
0005435902865	20206	Economy	17600.00
0005435902871	20206	Economy	17600.00
0005435902873	20206	Economy	17600.00
0005434426714	20206	Economy	17600.00
0005434426599	20206	Economy	17600.00
0005434426624	20206	Economy	17600.00
0005435902870	20206	Economy	17600.00
0005434426605	20206	Economy	17600.00
0005434426607	20206	Economy	17600.00
0005434426662	20206	Economy	17600.00
0005435554231	20206	Economy	17600.00
0005435902875	20206	Economy	17600.00
0005435902876	20206	Economy	17600.00
0005435902860	20206	Economy	17600.00
0005434426578	20206	Economy	17600.00
0005435902858	20206	Economy	17600.00
0005434426723	20206	Economy	17600.00
0005435554233	20206	Economy	17600.00
0005434426539	20206	Economy	17600.00
0005432059523	20206	Economy	17600.00
0005434411803	20206	Economy	17600.00
0005434426693	20206	Economy	17600.00
0005435902862	20206	Economy	17600.00
0005433434679	26503	Business	18500.00
0005435982700	26503	Business	18500.00
0005435982681	26503	Business	18500.00
0005435982677	26503	Business	18500.00
0005434273076	26503	Business	18500.00
0005435982674	26503	Business	18500.00
0005434273077	26503	Business	18500.00
0005435982698	26503	Business	18500.00
0005434270207	26503	Business	18500.00
0005435982710	26503	Business	18500.00
0005432300310	26503	Business	18500.00
0005435982699	26503	Economy	6200.00
0005435982695	26503	Economy	6200.00
0005432300312	26503	Economy	6200.00
0005434270206	26503	Economy	6200.00
0005433434705	26503	Economy	6200.00
0005433434695	26503	Economy	6200.00
0005435982693	26503	Economy	6200.00
0005435982692	26503	Economy	6200.00
0005433434584	26503	Economy	6800.00
0005433434670	26503	Economy	6800.00
0005433434708	26503	Economy	6800.00
0005435982709	26503	Economy	6800.00
0005435982691	26503	Economy	6800.00
0005435982689	26503	Economy	6200.00
0005433434704	26503	Economy	6200.00
0005435982702	26503	Economy	6200.00
0005435982685	26503	Economy	6200.00
0005435982694	26503	Economy	6200.00
0005433434701	26503	Economy	6200.00
0005435982697	26503	Economy	6200.00
0005434273080	26503	Economy	6200.00
0005433434693	26503	Economy	6200.00
0005435982679	26503	Economy	6200.00
0005433434678	26503	Economy	6200.00
0005433434604	26503	Economy	6200.00
0005435982706	26503	Economy	6200.00
0005433434613	26503	Economy	6200.00
0005435982711	26503	Economy	6200.00
0005435982707	26503	Economy	6200.00
0005433434710	26503	Economy	6200.00
0005435982696	26503	Economy	6200.00
0005432300313	26503	Economy	6200.00
0005435982665	26503	Economy	6200.00
0005435982714	26503	Economy	6200.00
0005435982683	26503	Economy	6200.00
0005433434711	26503	Economy	6200.00
0005435982680	26503	Economy	6200.00
0005435982673	26503	Economy	6200.00
0005435982715	26503	Economy	6200.00
0005433434748	26503	Economy	6200.00
0005433434605	26503	Economy	6200.00
0005433434668	26503	Economy	6200.00
0005435982666	26503	Economy	6200.00
0005435982704	26503	Economy	6200.00
0005435982668	26503	Economy	6200.00
0005435982703	26503	Economy	6200.00
0005435982713	26503	Economy	6200.00
0005435982687	26503	Economy	6200.00
0005433434687	26503	Economy	6200.00
0005435982686	26503	Economy	6200.00
0005433434692	26503	Economy	6200.00
0005435982708	26503	Economy	6200.00
0005435982705	26503	Economy	6200.00
0005434273075	26503	Economy	6200.00
0005432300314	26503	Economy	6200.00
0005433434694	26503	Economy	6200.00
0005433434543	26503	Economy	6200.00
0005435982712	26503	Economy	6200.00
0005433434612	26503	Economy	6200.00
0005435982672	26503	Economy	6200.00
0005435982682	26503	Economy	6200.00
0005435982716	26503	Economy	6200.00
0005435982676	26503	Economy	6200.00
0005435982684	26503	Economy	6200.00
0005433434770	26503	Economy	6200.00
0005435982688	26503	Economy	6200.00
0005435982671	26503	Economy	6200.00
0005435982690	26503	Economy	6200.00
0005433434724	26503	Economy	6200.00
0005432300315	26503	Economy	6200.00
0005435982701	26503	Economy	6200.00
0005433434761	26503	Economy	6200.00
0005435982669	26503	Economy	6200.00
0005435982675	26503	Economy	6200.00
0005435982670	26503	Economy	6200.00
0005433434675	26503	Economy	6200.00
0005433434707	26503	Economy	6200.00
0005435982667	26503	Economy	6200.00
0005432300311	26503	Economy	6200.00
0005435982678	26503	Economy	6200.00
0005432300309	26503	Economy	6200.00
0005435982106	26687	Business	18500.00
0005433434953	26687	Business	18500.00
0005435982436	26687	Business	18500.00
0005435982445	26687	Business	18500.00
0005435982375	26687	Business	18500.00
0005435982201	26687	Business	18500.00
0005435982143	26687	Business	18500.00
0005435982219	26687	Business	18500.00
0005432051157	26687	Business	18500.00
0005434269124	26687	Business	18500.00
0005435982202	26687	Economy	6200.00
0005434270225	26687	Economy	6200.00
0005432051158	26687	Economy	6200.00
0005435982298	26687	Economy	6200.00
0005435982139	26687	Economy	6200.00
0005435982444	26687	Economy	6200.00
0005434271331	26687	Economy	6200.00
0005435982250	26687	Economy	6200.00
0005433434929	26687	Economy	6200.00
0005435982200	26687	Economy	6200.00
0005435982209	26687	Economy	6800.00
0005435982249	26687	Economy	6800.00
0005433434956	26687	Economy	6800.00
0005433434930	26687	Economy	6800.00
0005433434937	26687	Economy	6800.00
0005435982224	26687	Economy	6200.00
0005435982348	26687	Economy	6200.00
0005434269123	26687	Economy	6200.00
0005433434945	26687	Economy	6200.00
0005433434950	26687	Economy	6200.00
0005435982150	26687	Economy	6200.00
0005433434939	26687	Economy	6200.00
0005435982199	26687	Economy	6200.00
0005435982244	26687	Economy	6200.00
0005435982355	26687	Economy	6200.00
0005435982318	26687	Economy	6200.00
0005435982160	26687	Economy	6200.00
0005435982374	26687	Economy	6200.00
0005433434933	26687	Economy	6200.00
0005433434940	26687	Economy	6200.00
0005435982319	26687	Economy	6200.00
0005435982263	26687	Economy	6200.00
0005433434941	26687	Economy	6200.00
0005435982303	26687	Economy	6200.00
0005434269122	26687	Economy	6200.00
0005435982434	26687	Economy	6200.00
0005433434936	26687	Economy	6200.00
0005435982060	26687	Economy	6200.00
0005435982210	26687	Economy	6200.00
0005435982354	26687	Economy	6200.00
0005435982220	26687	Economy	6200.00
0005433434955	26687	Economy	6200.00
0005433434943	26687	Economy	6200.00
0005433434947	26687	Economy	6200.00
0005435982385	26687	Economy	6200.00
0005433434932	26687	Economy	6200.00
0005432051156	26687	Economy	6200.00
0005433434946	26687	Economy	6200.00
0005435982419	26687	Economy	6200.00
0005435982277	26687	Economy	6200.00
0005433434942	26687	Economy	6200.00
0005435982299	26687	Economy	6200.00
0005434271332	26687	Economy	6200.00
0005433434954	26687	Economy	6200.00
0005433434944	26687	Economy	6200.00
0005435982203	26687	Economy	6200.00
0005435982141	26687	Economy	6200.00
0005433434935	26687	Economy	6200.00
0005435982180	26687	Economy	6200.00
0005433434934	26687	Economy	6200.00
0005433434949	26687	Economy	6200.00
0005434270226	26687	Economy	6200.00
0005433434951	26687	Economy	6200.00
0005433434952	26687	Economy	6200.00
0005435982317	26687	Economy	6200.00
0005435982341	26687	Economy	6200.00
0005435982347	26687	Economy	6200.00
0005435982386	26687	Economy	6200.00
0005435982438	26687	Economy	6200.00
0005435982316	26687	Economy	6200.00
0005433434931	26687	Economy	6200.00
0005433434957	26687	Economy	6200.00
0005435982292	26687	Economy	6200.00
0005435982119	26687	Economy	6200.00
0005435982437	26687	Economy	6200.00
0005435982216	26687	Economy	6200.00
0005435982142	26687	Economy	6200.00
0005435982290	26687	Economy	6200.00
0005433434948	26687	Economy	6200.00
0005433434938	26687	Economy	6200.00
0005435982304	26687	Economy	6200.00
0005432584275	3130	Economy	11100.00
0005432584266	3130	Economy	11100.00
0005432858033	3130	Economy	11100.00
0005432858072	3130	Economy	11100.00
0005432584273	3130	Economy	10100.00
0005432858112	3130	Economy	10100.00
0005432858060	3130	Economy	10100.00
0005432584268	3130	Economy	10100.00
0005432584261	3130	Economy	10100.00
0005432584270	3130	Economy	10100.00
0005432584259	3130	Economy	10100.00
0005432584267	3130	Economy	10100.00
0005432584262	3130	Economy	10100.00
0005432584260	3130	Economy	10100.00
0005432216298	3130	Economy	10100.00
0005432858107	3130	Economy	10100.00
0005432584264	3130	Economy	10100.00
0005432858068	3130	Economy	10100.00
0005432216297	3130	Economy	10100.00
0005432858083	3130	Economy	10100.00
0005432858100	3130	Economy	10100.00
0005432858095	3130	Economy	10100.00
0005432584265	3130	Economy	10100.00
0005432584276	3130	Economy	10100.00
0005432584272	3130	Economy	10100.00
0005432858049	3130	Economy	10100.00
0005432858071	3130	Economy	10100.00
0005432584263	3130	Economy	10100.00
0005432858108	3130	Economy	10100.00
0005432584254	3130	Economy	10100.00
0005432858094	3130	Economy	10100.00
0005432584278	3130	Economy	10100.00
0005432584256	3130	Economy	10100.00
0005432858048	3130	Economy	10100.00
0005432858098	3130	Economy	10100.00
0005432584277	3130	Economy	10100.00
0005432858084	3130	Economy	10100.00
0005432584255	3130	Economy	10100.00
0005432584274	3130	Economy	10100.00
0005432584253	3130	Economy	10100.00
0005432584258	3130	Economy	10100.00
0005432584257	3130	Economy	10100.00
0005432584271	3130	Economy	10100.00
0005432858099	3130	Economy	10100.00
0005432584269	3130	Economy	10100.00
0005432858182	31486	Economy	11100.00
0005432858177	31486	Economy	11100.00
0005432583993	31486	Economy	11100.00
0005432858178	31486	Economy	10100.00
0005432858176	31486	Economy	10100.00
0005432858181	31486	Economy	10100.00
0005432584076	31486	Economy	10100.00
0005432858183	31486	Economy	10100.00
0005432858174	31486	Economy	10100.00
0005432583987	31486	Economy	10100.00
0005432584014	31486	Economy	10100.00
0005432583980	31486	Economy	10100.00
0005432584043	31486	Economy	10100.00
0005432584093	31486	Economy	10100.00
0005432584028	31486	Economy	10100.00
0005432584075	31486	Economy	10100.00
0005432583991	31486	Economy	10100.00
0005432858179	31486	Economy	10100.00
0005432583986	31486	Economy	10100.00
0005432584141	31486	Economy	10100.00
0005432584062	31486	Economy	10100.00
0005432584046	31486	Economy	10100.00
0005432584162	31486	Economy	10100.00
0005432858180	31486	Economy	10100.00
0005432583992	31486	Economy	10100.00
0005432584110	31486	Economy	10100.00
0005432583997	31486	Economy	10100.00
0005432583952	31486	Economy	10100.00
0005432858175	31486	Economy	10100.00
0005432858173	31486	Economy	10100.00
0005432584106	31486	Economy	10100.00
0005432858184	31486	Economy	10100.00
0005432584055	31486	Economy	10100.00
0005432584107	31486	Economy	10100.00
0005432584109	31486	Economy	10100.00
0005432584143	31486	Economy	10100.00
0005432583985	31486	Economy	10100.00
0005432584077	31486	Economy	10100.00
0005432584054	31486	Economy	10100.00
0005432584074	31486	Economy	10100.00
0005432584087	31486	Economy	10100.00
0005434943440	865	Economy	7500.00
0005434943437	865	Economy	7500.00
0005433255120	865	Economy	7500.00
0005434943432	865	Economy	7500.00
0005434943434	865	Economy	7500.00
0005434943435	865	Economy	7500.00
0005434943436	865	Economy	7500.00
0005434943433	865	Economy	7500.00
0005434943439	865	Economy	7500.00
0005434943431	865	Economy	7500.00
0005433255130	865	Economy	7500.00
0005433255107	865	Economy	7500.00
0005433255121	865	Economy	7500.00
0005433255105	865	Economy	7500.00
0005433255131	865	Economy	7500.00
0005434943438	865	Economy	7500.00
0005434943397	16241	Economy	8300.00
0005434943381	16241	Economy	7500.00
0005434943356	16241	Economy	7500.00
0005434943387	16241	Economy	7500.00
0005433255171	16241	Economy	7500.00
0005434943398	16241	Economy	7500.00
0005433255170	16241	Economy	7500.00
0005434943388	16241	Economy	7500.00
0005433255168	16241	Economy	7500.00
0005434943380	16241	Economy	7500.00
0005434943333	16241	Economy	7500.00
0005433255167	16241	Economy	7500.00
0005434943400	16241	Economy	7500.00
0005434943366	16241	Economy	7500.00
0005433255169	16241	Economy	7500.00
0005434943386	16241	Economy	7500.00
0005433255166	16241	Economy	7500.00
0005434943401	16241	Economy	7500.00
0005434943332	16241	Economy	7500.00
0005434943399	16241	Economy	7500.00
0005433811640	14429	Economy	4400.00
0005435653447	21765	Business	9800.00
0005435653420	21765	Business	9800.00
0005435653446	21765	Business	9800.00
0005435653422	21765	Business	9800.00
0005435653426	21765	Business	9800.00
0005435653441	21765	Business	9800.00
0005433367878	21765	Business	9800.00
0005435653438	21765	Business	9800.00
0005433367740	21765	Business	9800.00
0005435653415	21765	Economy	3300.00
0005435653452	21765	Economy	3300.00
0005433367708	21765	Economy	3300.00
0005435653433	21765	Economy	3300.00
0005433367885	21765	Economy	3300.00
0005435653418	21765	Economy	3300.00
0005435653413	21765	Economy	3300.00
0005435653436	21765	Economy	3300.00
0005435653439	21765	Economy	3300.00
0005435653435	21765	Economy	3300.00
0005435653443	21765	Economy	3600.00
0005435653442	21765	Economy	3600.00
0005433367876	21765	Economy	3600.00
0005435653444	21765	Economy	3600.00
0005435653405	21765	Economy	3300.00
0005433367815	21765	Economy	3300.00
0005433367714	21765	Economy	3300.00
0005433367664	21765	Economy	3300.00
0005435653445	21765	Economy	3300.00
0005435653417	21765	Economy	3300.00
0005435653424	21765	Economy	3300.00
0005433367560	21765	Economy	3300.00
0005435653423	21765	Economy	3300.00
0005433368015	21765	Economy	3300.00
0005433367786	21765	Economy	3300.00
0005433367955	21765	Economy	3300.00
0005435653440	21765	Economy	3300.00
0005433367933	21765	Economy	3300.00
0005435653408	21765	Economy	3300.00
0005435653412	21765	Economy	3300.00
0005435653411	21765	Economy	3300.00
0005435653451	21765	Economy	3300.00
0005433367879	21765	Economy	3300.00
0005435653410	21765	Economy	3300.00
0005433367863	21765	Economy	3300.00
0005433367816	21765	Economy	3300.00
0005435653421	21765	Economy	3300.00
0005435653409	21765	Economy	3300.00
0005433367839	21765	Economy	3300.00
0005433367946	21765	Economy	3300.00
0005435653449	21765	Economy	3300.00
0005433367710	21765	Economy	3300.00
0005435653416	21765	Economy	3300.00
0005435653455	21765	Economy	3300.00
0005435653453	21765	Economy	3300.00
0005435653428	21765	Economy	3300.00
0005435653407	21765	Economy	3300.00
0005433367739	21765	Economy	3300.00
0005433367820	21765	Economy	3300.00
0005435653406	21765	Economy	3300.00
0005433367954	21765	Economy	3300.00
0005433367824	21765	Economy	3300.00
0005433367844	21765	Economy	3300.00
0005435653434	21765	Economy	3300.00
0005433368022	21765	Economy	3300.00
0005435653414	21765	Economy	3300.00
0005435653456	21765	Economy	3300.00
0005435653454	21765	Economy	3300.00
0005433367941	21765	Economy	3300.00
0005433367903	21765	Economy	3300.00
0005435653432	21765	Economy	3300.00
0005435653437	21765	Economy	3300.00
0005433367797	21765	Economy	3300.00
0005435653448	21765	Economy	3300.00
0005433367814	21765	Economy	3300.00
0005433367799	21765	Economy	3300.00
0005435653429	21765	Economy	3300.00
0005433367918	21765	Economy	3300.00
0005435653427	21765	Economy	3300.00
0005433367801	21765	Economy	3300.00
0005435653431	21765	Economy	3300.00
0005433367932	21765	Economy	3300.00
0005435653430	21765	Economy	3300.00
0005433367834	21765	Economy	3300.00
0005435653419	21765	Economy	3300.00
0005433367864	21765	Economy	3300.00
0005435653425	21765	Economy	3300.00
0005435653450	21765	Economy	3300.00
0005433367835	21765	Economy	3300.00
0005433785295	9348	Business	186200.00
0005433763332	9348	Business	186200.00
0005433805693	9348	Business	186200.00
0005434171001	9348	Business	186200.00
0005433785284	9348	Business	186200.00
0005432666409	9348	Business	186200.00
0005433785297	9348	Business	186200.00
0005434171031	9348	Business	186200.00
0005434171104	9348	Business	186200.00
0005433785271	9348	Business	186200.00
0005433785294	9348	Business	186200.00
0005433763341	9348	Business	186200.00
0005433785268	9348	Business	186200.00
0005433763339	9348	Business	186200.00
0005433763340	9348	Business	186200.00
0005434151713	9348	Business	186200.00
0005433805716	9348	Business	186200.00
0005433785283	9348	Business	186200.00
0005433805698	9348	Business	186200.00
0005433805710	9348	Economy	68300.00
0005434171023	9348	Economy	68300.00
0005433785273	9348	Economy	68300.00
0005432666408	9348	Economy	62100.00
0005433785287	9348	Economy	62100.00
0005433805692	9348	Economy	62100.00
0005433785278	9348	Economy	62100.00
0005433805713	9348	Economy	62100.00
0005433763333	9348	Economy	62100.00
0005433805707	9348	Economy	62100.00
0005433785260	9348	Economy	62100.00
0005433805701	9348	Economy	62100.00
0005433805703	9348	Economy	62100.00
0005433785292	9348	Economy	62100.00
0005433805717	9348	Economy	62100.00
0005433785270	9348	Economy	62100.00
0005432667473	9348	Economy	62100.00
0005433805687	9348	Economy	62100.00
0005434151718	9348	Economy	62100.00
0005433785277	9348	Economy	62100.00
0005433805700	9348	Economy	62100.00
0005433763343	9348	Economy	62100.00
0005434171107	9348	Economy	62100.00
0005433785282	9348	Economy	62100.00
0005433785263	9348	Economy	62100.00
0005433763347	9348	Economy	62100.00
0005433805688	9348	Economy	62100.00
0005434171043	9348	Economy	62100.00
0005433763334	9348	Economy	62100.00
0005433805706	9348	Economy	62100.00
0005433785274	9348	Economy	62100.00
0005433763342	9348	Economy	62100.00
0005434171030	9348	Economy	62100.00
0005433785285	9348	Economy	62100.00
0005433785276	9348	Economy	62100.00
0005433805694	9348	Economy	62100.00
0005434171029	9348	Economy	62100.00
0005433805697	9348	Economy	62100.00
0005433785290	9348	Economy	62100.00
0005432657478	9348	Economy	62100.00
0005433805685	9348	Economy	62100.00
0005434171051	9348	Economy	62100.00
0005433805695	9348	Economy	62100.00
0005433763344	9348	Economy	62100.00
0005433805696	9348	Economy	62100.00
0005433785262	9348	Economy	62100.00
0005434151698	9348	Economy	62100.00
0005432657477	9348	Economy	68300.00
0005433805704	9348	Economy	62100.00
0005433805714	9348	Economy	68300.00
0005433785296	9348	Economy	68300.00
0005434151712	9348	Economy	62100.00
0005433763346	9348	Economy	62100.00
0005433785286	9348	Economy	62100.00
0005433805708	9348	Economy	62100.00
0005433785267	9348	Economy	62100.00
0005433785289	9348	Economy	62100.00
0005433805711	9348	Economy	62100.00
0005433785265	9348	Economy	62100.00
0005433805691	9348	Economy	62100.00
0005433785288	9348	Economy	62100.00
0005433805686	9348	Economy	62100.00
0005433785272	9348	Economy	62100.00
0005432657476	9348	Economy	62100.00
0005433785281	9348	Economy	62100.00
0005433805705	9348	Economy	62100.00
0005433763345	9348	Economy	62100.00
0005434171056	9348	Economy	62100.00
0005433805690	9348	Economy	62100.00
0005433785269	9348	Economy	62100.00
0005432665294	9348	Economy	62100.00
0005433763335	9348	Economy	62100.00
0005433785293	9348	Economy	62100.00
0005434171091	9348	Economy	62100.00
0005433763337	9348	Economy	62100.00
0005433805715	9348	Economy	62100.00
0005433785291	9348	Economy	62100.00
0005433805689	9348	Economy	62100.00
0005433805712	9348	Economy	62100.00
0005433763336	9348	Economy	62100.00
0005434171078	9348	Economy	62100.00
0005433785275	9348	Economy	62100.00
0005434171152	9348	Economy	62100.00
0005433785280	9348	Economy	62100.00
0005433805709	9348	Economy	62100.00
0005434151711	9348	Economy	62100.00
0005433785264	9348	Economy	62100.00
0005432665293	9348	Economy	62100.00
0005433785261	9348	Economy	62100.00
0005433763338	9348	Economy	62100.00
0005433785279	9348	Economy	62100.00
0005433785266	9348	Economy	62100.00
0005433805699	9348	Economy	62100.00
0005433805702	9348	Economy	62100.00
0005433784923	26265	Business	186200.00
0005433805333	26265	Business	186200.00
0005433784996	26265	Business	186200.00
0005433763247	26265	Business	186200.00
0005433784951	26265	Business	186200.00
0005433785072	26265	Business	186200.00
0005434171184	26265	Business	186200.00
0005435269807	26265	Business	186200.00
0005433805417	26265	Business	186200.00
0005433805395	26265	Business	186200.00
0005433784867	26265	Business	186200.00
0005433784857	26265	Business	186200.00
0005434269121	26265	Business	186200.00
0005433763207	26265	Business	186200.00
0005433763263	26265	Business	186200.00
0005433805403	26265	Business	186200.00
0005433805268	26265	Business	186200.00
0005434171190	26265	Business	186200.00
0005433763208	26265	Business	186200.00
0005433785172	26265	Business	186200.00
0005433784908	26265	Business	186200.00
0005433784824	26265	Business	186200.00
0005433763182	26265	Business	186200.00
0005433805299	26265	Business	186200.00
0005433784974	26265	Economy	68300.00
0005433805257	26265	Economy	62100.00
0005434171188	26265	Economy	62100.00
0005433784881	26265	Economy	62100.00
0005433784912	26265	Economy	62100.00
0005433785025	26265	Economy	62100.00
0005433784901	26265	Economy	62100.00
0005433784855	26265	Economy	62100.00
0005433763187	26265	Economy	62100.00
0005433805334	26265	Economy	62100.00
0005433785073	26265	Economy	62100.00
0005433784869	26265	Economy	62100.00
0005432659702	26265	Economy	62100.00
0005433784883	26265	Economy	62100.00
0005433784990	26265	Economy	62100.00
0005433805341	26265	Economy	62100.00
0005433805453	26265	Economy	62100.00
0005433805285	26265	Economy	62100.00
0005433784860	26265	Economy	62100.00
0005432657435	26265	Economy	62100.00
0005433763210	26265	Economy	62100.00
0005433805404	26265	Economy	62100.00
0005433805374	26265	Economy	62100.00
0005434171192	26265	Economy	62100.00
0005433805350	26265	Economy	62100.00
0005433805431	26265	Economy	62100.00
0005433805409	26265	Economy	62100.00
0005433784886	26265	Economy	62100.00
0005434271330	26265	Economy	62100.00
0005432657447	26265	Economy	62100.00
0005433784805	26265	Economy	62100.00
0005433763228	26265	Economy	62100.00
0005433805291	26265	Economy	62100.00
0005433805349	26265	Economy	62100.00
0005433785052	26265	Economy	62100.00
0005433784847	26265	Economy	62100.00
0005433805394	26265	Economy	62100.00
0005433785030	26265	Economy	62100.00
0005433763206	26265	Economy	62100.00
0005433784856	26265	Economy	62100.00
0005435269803	26265	Economy	62100.00
0005432666383	26265	Economy	62100.00
0005433805467	26265	Economy	62100.00
0005434171181	26265	Economy	62100.00
0005433763267	26265	Economy	62100.00
0005435269810	26265	Economy	62100.00
0005434171187	26265	Economy	62100.00
0005432663034	26265	Economy	62100.00
0005433805454	26265	Economy	62100.00
0005434171185	26265	Economy	62100.00
0005433805490	26265	Economy	62100.00
0005432666386	26265	Economy	62100.00
0005433785059	26265	Economy	62100.00
0005433785163	26265	Economy	62100.00
0005433805469	26265	Economy	62100.00
0005435269806	26265	Economy	62100.00
0005434171179	26265	Economy	62100.00
0005435269802	26265	Economy	62100.00
0005435269808	26265	Economy	62100.00
0005435269809	26265	Economy	62100.00
0005434171182	26265	Economy	62100.00
0005432659699	26265	Economy	62100.00
0005434151731	26265	Economy	62100.00
0005433763155	26265	Economy	62100.00
0005435269805	26265	Economy	62100.00
0005433805396	26265	Economy	62100.00
0005434270223	26265	Economy	62100.00
0005433805369	26265	Economy	62100.00
0005433805315	26265	Economy	62100.00
0005433784981	26265	Economy	62100.00
0005433785071	26265	Economy	68300.00
0005434171186	26265	Economy	68300.00
0005434171189	26265	Economy	62100.00
0005433763227	26265	Economy	62100.00
0005434151730	26265	Economy	62100.00
0005433784868	26265	Economy	62100.00
0005433784825	26265	Economy	62100.00
0005435269811	26265	Economy	62100.00
0005433805413	26265	Economy	62100.00
0005432666384	26265	Economy	62100.00
0005433805405	26265	Economy	62100.00
0005434271329	26265	Economy	62100.00
0005435269812	26265	Economy	62100.00
0005434270224	26265	Economy	62100.00
0005435269804	26265	Economy	62100.00
0005433784850	26265	Economy	62100.00
0005433805422	26265	Economy	62100.00
0005434171191	26265	Economy	62100.00
0005433784882	26265	Economy	62100.00
0005433763242	26265	Economy	62100.00
0005433784861	26265	Economy	62100.00
0005434171183	26265	Economy	62100.00
0005433784849	26265	Economy	62100.00
0005433805466	26265	Economy	62100.00
0005432663039	26265	Economy	62100.00
0005433785090	26265	Economy	62100.00
0005433763264	26265	Economy	62100.00
0005433784848	26265	Economy	62100.00
0005433805503	26265	Economy	62100.00
0005433784985	26265	Economy	62100.00
0005433785029	26265	Economy	62100.00
0005433784892	26265	Economy	62100.00
0005433805355	26265	Economy	62100.00
0005433784954	26265	Economy	62100.00
0005433763163	26265	Economy	62100.00
0005433763241	26265	Economy	62100.00
0005433763217	26265	Economy	62100.00
0005433763192	26265	Economy	62100.00
0005433805317	26265	Economy	62100.00
0005433763178	26265	Economy	62100.00
0005433805408	26265	Economy	62100.00
0005433763209	26265	Economy	62100.00
0005433805292	26265	Economy	62100.00
0005433784804	26265	Economy	62100.00
0005433784896	26265	Economy	62100.00
0005434171180	26265	Economy	62100.00
0005433784893	26265	Economy	62100.00
0005435929642	4880	Economy	5300.00
0005435135713	4880	Economy	5300.00
0005435135712	4880	Economy	5300.00
0005435929639	4880	Economy	5300.00
0005435929643	4880	Economy	5300.00
0005435135715	4880	Economy	5300.00
0005435135716	4880	Economy	5300.00
0005435135714	4880	Economy	5300.00
0005435135686	33016	Economy	5900.00
0005435929667	33016	Economy	5300.00
0005435135687	33016	Economy	5300.00
0005435135667	33016	Economy	5300.00
0005435929669	33016	Economy	5300.00
0005435929668	33016	Economy	5300.00
0005435135685	33016	Economy	5300.00
0005435135692	33016	Economy	5300.00
0005434983333	9459	Economy	19700.00
0005434217975	9459	Economy	17900.00
0005434217964	9459	Economy	17900.00
0005434217974	9459	Economy	17900.00
0005434217976	9459	Economy	17900.00
0005434983334	9459	Economy	17900.00
0005434217965	9459	Economy	17900.00
0005434217963	9459	Economy	17900.00
0005434983335	9459	Economy	17900.00
0005434217968	9459	Economy	17900.00
0005434217962	9459	Economy	17900.00
0005434217977	9459	Economy	17900.00
0005434983336	9459	Economy	17900.00
0005434217967	9459	Economy	17900.00
0005434217973	9459	Economy	17900.00
0005434218006	27362	Economy	19700.00
0005434983289	27362	Economy	19700.00
0005434218004	27362	Economy	17900.00
0005434983301	27362	Economy	17900.00
0005434218007	27362	Economy	17900.00
0005434983281	27362	Economy	17900.00
0005434218005	27362	Economy	17900.00
0005434983302	27362	Economy	17900.00
0005434983295	27362	Economy	17900.00
0005434983314	27362	Economy	17900.00
0005433985890	24278	Business	36400.00
0005433985892	24278	Business	36400.00
0005433960775	24278	Business	36400.00
0005433960757	24278	Business	36400.00
0005433960531	24278	Business	36400.00
0005433960770	24278	Business	36400.00
0005433985984	24278	Business	36400.00
0005433985971	24278	Business	36400.00
0005433960772	24278	Business	36400.00
0005433960530	24278	Business	36400.00
0005433960631	24278	Business	36400.00
0005433985816	24278	Business	36400.00
0005433960806	24278	Business	36400.00
0005433985894	24278	Business	36400.00
0005433985920	24278	Business	36400.00
0005433960799	24278	Business	36400.00
0005433985972	24278	Economy	12100.00
0005433960802	24278	Economy	12100.00
0005433985835	24278	Economy	12100.00
0005433960721	24278	Economy	12100.00
0005433985957	24278	Economy	12100.00
0005433960842	24278	Economy	12100.00
0005433960800	24278	Economy	12100.00
0005433960710	24278	Economy	12100.00
0005433960671	24278	Economy	12100.00
0005433960843	24278	Economy	12100.00
0005433985794	24278	Economy	12100.00
0005433985931	24278	Economy	12100.00
0005433985933	24278	Economy	12100.00
0005433960752	24278	Economy	12100.00
0005433960848	24278	Economy	12100.00
0005433985958	24278	Economy	12100.00
0005433985932	24278	Economy	12100.00
0005433985986	24278	Economy	12100.00
0005433985817	24278	Economy	12100.00
0005433960807	24278	Economy	12100.00
0005433960682	24278	Economy	12100.00
0005433960768	24278	Economy	12100.00
0005433960824	24278	Economy	12100.00
0005433985788	24278	Economy	12100.00
0005433985965	24278	Economy	12100.00
0005433960835	24278	Economy	12100.00
0005433985848	24278	Economy	12100.00
0005433960746	24278	Economy	12100.00
0005433960742	24278	Economy	12100.00
0005433960670	24278	Economy	12100.00
0005433960740	24278	Economy	12100.00
0005433960846	24278	Economy	12100.00
0005433960759	24278	Economy	12100.00
0005433960792	24278	Economy	12100.00
0005433985898	24278	Economy	12100.00
0005433960778	24278	Economy	12100.00
0005433960396	24278	Economy	12100.00
0005433985985	24278	Economy	12100.00
0005433960755	24278	Economy	12100.00
0005433960794	24278	Economy	12100.00
0005433960776	24278	Economy	12100.00
0005433960737	24278	Economy	12100.00
0005433960809	24278	Economy	12100.00
0005433985823	24278	Economy	12100.00
0005433960719	24278	Economy	12100.00
0005433960741	24278	Economy	13400.00
0005433985754	24278	Economy	13400.00
0005433985756	24278	Economy	12100.00
0005433960724	24278	Economy	12100.00
0005433960777	24278	Economy	13400.00
0005433985763	24278	Economy	12100.00
0005433985893	24278	Economy	12100.00
0005433960810	24278	Economy	12100.00
0005433985820	24278	Economy	12100.00
0005433985795	24278	Economy	12100.00
0005433960821	24278	Economy	12100.00
0005433960739	24278	Economy	12100.00
0005433985866	24278	Economy	12100.00
0005433960783	24278	Economy	12100.00
0005433960771	24278	Economy	12100.00
0005433985882	24278	Economy	12100.00
0005433960767	24278	Economy	12100.00
0005433960632	24278	Economy	12100.00
0005433960811	24278	Economy	12100.00
0005433960756	24278	Economy	12100.00
0005433985785	24278	Economy	12100.00
0005433960733	24278	Economy	12100.00
0005433960734	24278	Economy	12100.00
0005433985881	24278	Economy	12100.00
0005433985921	24278	Economy	12100.00
0005433960804	24278	Economy	12100.00
0005433985764	24278	Economy	12100.00
0005433985849	24278	Economy	12100.00
0005433985880	24278	Economy	12100.00
0005433985969	24278	Economy	12100.00
0005433960732	24278	Economy	12100.00
0005433960720	24278	Economy	12100.00
0005433960749	24278	Economy	12100.00
0005433985899	24278	Economy	12100.00
0005433960833	24278	Economy	12100.00
0005433960803	24278	Economy	12100.00
0005433961376	25952	Business	36400.00
0005433986337	25952	Business	36400.00
0005433986344	25952	Business	36400.00
0005433961370	25952	Business	36400.00
0005433986351	25952	Business	36400.00
0005433986321	25952	Business	36400.00
0005433961346	25952	Business	36400.00
0005433961333	25952	Business	36400.00
0005433986324	25952	Business	36400.00
0005433961384	25952	Business	36400.00
0005433986328	25952	Business	36400.00
0005433961367	25952	Business	36400.00
0005433961344	25952	Economy	13400.00
0005433986310	25952	Economy	13400.00
0005433961379	25952	Economy	12100.00
0005433986314	25952	Economy	12100.00
0005433986343	25952	Economy	12100.00
0005433986318	25952	Economy	12100.00
0005433961337	25952	Economy	12100.00
0005433986311	25952	Economy	12100.00
0005433986316	25952	Economy	12100.00
0005433986352	25952	Economy	12100.00
0005433961371	25952	Economy	12100.00
0005433986309	25952	Economy	12100.00
0005433961347	25952	Economy	12100.00
0005433961381	25952	Economy	12100.00
0005433986331	25952	Economy	12100.00
0005433961375	25952	Economy	12100.00
0005433961331	25952	Economy	12100.00
0005433961362	25952	Economy	12100.00
0005433961359	25952	Economy	12100.00
0005433986340	25952	Economy	12100.00
0005433986333	25952	Economy	12100.00
0005433986320	25952	Economy	12100.00
0005433986345	25952	Economy	12100.00
0005433961360	25952	Economy	12100.00
0005433961372	25952	Economy	12100.00
0005433961380	25952	Economy	12100.00
0005433961352	25952	Economy	12100.00
0005433986350	25952	Economy	12100.00
0005433986308	25952	Economy	12100.00
0005433961349	25952	Economy	12100.00
0005433961361	25952	Economy	12100.00
0005433961350	25952	Economy	12100.00
0005433961338	25952	Economy	12100.00
0005433986336	25952	Economy	12100.00
0005433961374	25952	Economy	12100.00
0005433986325	25952	Economy	12100.00
0005433986330	25952	Economy	12100.00
0005433961369	25952	Economy	12100.00
0005433986347	25952	Economy	12100.00
0005433986315	25952	Economy	12100.00
0005433961335	25952	Economy	12100.00
0005433961363	25952	Economy	12100.00
0005433961355	25952	Economy	12100.00
0005433986341	25952	Economy	12100.00
0005433986326	25952	Economy	12100.00
0005433961343	25952	Economy	12100.00
0005433961368	25952	Economy	12100.00
0005433986342	25952	Economy	12100.00
0005433961378	25952	Economy	12100.00
0005433961353	25952	Economy	12100.00
0005433961339	25952	Economy	12100.00
0005433986346	25952	Economy	12100.00
0005433961365	25952	Economy	13400.00
0005433986334	25952	Economy	12100.00
0005433986327	25952	Economy	13400.00
0005433961334	25952	Economy	12100.00
0005433961373	25952	Economy	12100.00
0005433961356	25952	Economy	12100.00
0005433986339	25952	Economy	12100.00
0005433961330	25952	Economy	12100.00
0005433986329	25952	Economy	12100.00
0005433986348	25952	Economy	12100.00
0005433961382	25952	Economy	12100.00
0005433986319	25952	Economy	12100.00
0005433986353	25952	Economy	12100.00
0005433986322	25952	Economy	12100.00
0005433961383	25952	Economy	12100.00
0005433961364	25952	Economy	12100.00
0005433961357	25952	Economy	12100.00
0005433961366	25952	Economy	12100.00
0005433961351	25952	Economy	12100.00
0005433986323	25952	Economy	12100.00
0005433986307	25952	Economy	12100.00
0005433986313	25952	Economy	12100.00
0005433961342	25952	Economy	12100.00
0005433986306	25952	Economy	12100.00
0005433961377	25952	Economy	12100.00
0005433961340	25952	Economy	12100.00
0005433961358	25952	Economy	12100.00
0005433986349	25952	Economy	12100.00
0005433986335	25952	Economy	12100.00
0005433961348	25952	Economy	12100.00
0005433986355	25952	Economy	12100.00
0005433986338	25952	Economy	12100.00
0005433986332	25952	Economy	12100.00
0005433961336	25952	Economy	12100.00
0005433986317	25952	Economy	12100.00
0005433986312	25952	Economy	12100.00
0005433961329	25952	Economy	12100.00
0005433961341	25952	Economy	12100.00
0005433986354	25952	Economy	12100.00
0005433961345	25952	Economy	12100.00
0005433961354	25952	Economy	12100.00
0005433961332	25952	Economy	12100.00
0005433165863	942	Economy	25400.00
0005434480565	942	Economy	25400.00
0005433165864	942	Economy	25400.00
0005434480551	942	Economy	23100.00
0005434480573	942	Economy	23100.00
0005434480569	942	Economy	23100.00
0005434480562	942	Economy	23100.00
0005434480558	942	Economy	23100.00
0005433165946	942	Economy	23100.00
0005433165885	942	Economy	23100.00
0005433165877	942	Economy	23100.00
0005432269521	942	Economy	23100.00
0005434480572	942	Economy	23100.00
0005433165890	942	Economy	23100.00
0005434480563	942	Economy	23100.00
0005432269522	942	Economy	23100.00
0005434480560	942	Economy	23100.00
0005433165903	942	Economy	23100.00
0005433165924	942	Economy	23100.00
0005434480566	942	Economy	23100.00
0005433165984	942	Economy	23100.00
0005434480561	942	Economy	23100.00
0005434480553	942	Economy	23100.00
0005433165896	942	Economy	23100.00
0005434480556	942	Economy	23100.00
0005433165941	942	Economy	23100.00
0005434480548	942	Economy	23100.00
0005434480559	942	Economy	23100.00
0005433165931	942	Economy	23100.00
0005433165947	942	Economy	23100.00
0005434480567	942	Economy	23100.00
0005434480550	942	Economy	23100.00
0005434480570	942	Economy	23100.00
0005432269520	942	Economy	23100.00
0005434480549	942	Economy	23100.00
0005434480555	942	Economy	23100.00
0005433165935	942	Economy	23100.00
0005434480557	942	Economy	23100.00
0005434480564	942	Economy	23100.00
0005434480554	942	Economy	23100.00
0005434480571	942	Economy	23100.00
0005433165943	942	Economy	23100.00
0005433165889	942	Economy	23100.00
0005434480568	942	Economy	23100.00
0005434480552	942	Economy	23100.00
0005434480348	16601	Economy	25400.00
0005434480344	16601	Economy	23100.00
0005434480395	16601	Economy	23100.00
0005434480263	16601	Economy	23100.00
0005434480222	16601	Economy	23100.00
0005434480290	16601	Economy	23100.00
0005433166029	16601	Economy	23100.00
0005434480378	16601	Economy	23100.00
0005434480318	16601	Economy	23100.00
0005434480394	16601	Economy	23100.00
0005434480436	16601	Economy	23100.00
0005434480458	16601	Economy	23100.00
0005433166023	16601	Economy	23100.00
0005434480275	16601	Economy	23100.00
0005433166021	16601	Economy	23100.00
0005434480362	16601	Economy	23100.00
0005433166019	16601	Economy	23100.00
0005433166025	16601	Economy	23100.00
0005434480347	16601	Economy	23100.00
0005433166020	16601	Economy	23100.00
0005433166031	16601	Economy	23100.00
0005433166026	16601	Economy	23100.00
0005433166024	16601	Economy	23100.00
0005434480297	16601	Economy	23100.00
0005434480457	16601	Economy	23100.00
0005433166030	16601	Economy	23100.00
0005433166022	16601	Economy	23100.00
0005434480274	16601	Economy	23100.00
0005434480437	16601	Economy	23100.00
0005433166027	16601	Economy	23100.00
0005434480309	16601	Economy	23100.00
0005433166028	16601	Economy	23100.00
0005434480281	16601	Economy	23100.00
0005433166018	16601	Economy	23100.00
0005434480440	16601	Economy	23100.00
0005434480381	16601	Economy	23100.00
0005435142693	10353	Economy	17000.00
0005435150139	10353	Economy	17000.00
0005435150144	10353	Economy	15400.00
0005435150140	10353	Economy	15400.00
0005435142682	10353	Economy	15400.00
0005435150138	10353	Economy	15400.00
0005435142687	10353	Economy	15400.00
0005435150141	10353	Economy	15400.00
0005435150145	10353	Economy	15400.00
0005435150137	10353	Economy	15400.00
0005435386572	10353	Economy	15400.00
0005435386571	10353	Economy	15400.00
0005435150146	10353	Economy	15400.00
0005435142684	10353	Economy	15400.00
0005435150135	10353	Economy	15400.00
0005435142686	10353	Economy	15400.00
0005435386570	10353	Economy	15400.00
0005435386577	10353	Economy	15400.00
0005435150147	10353	Economy	15400.00
0005435386560	10353	Economy	15400.00
0005435150148	10353	Economy	15400.00
0005435150143	10353	Economy	15400.00
0005435142690	10353	Economy	15400.00
0005435142685	10353	Economy	15400.00
0005435142688	10353	Economy	15400.00
0005435142695	10353	Economy	15400.00
0005433289841	10353	Economy	15400.00
0005435142689	10353	Economy	15400.00
0005435150142	10353	Economy	15400.00
0005435142683	10353	Economy	15400.00
0005435386583	10353	Economy	15400.00
0005433289838	10353	Economy	15400.00
0005435142691	10353	Economy	15400.00
0005435386576	10353	Economy	15400.00
0005435150136	10353	Economy	15400.00
0005435142692	10353	Economy	15400.00
0005435142694	10353	Economy	15400.00
0005435142556	21935	Economy	17000.00
0005435149947	21935	Economy	17000.00
0005433289917	21935	Economy	17000.00
0005435142560	21935	Economy	17000.00
0005435142537	21935	Economy	15400.00
0005435149946	21935	Economy	15400.00
0005433289921	21935	Economy	15400.00
0005435142538	21935	Economy	15400.00
0005433289920	21935	Economy	15400.00
0005435142603	21935	Economy	15400.00
0005435150022	21935	Economy	15400.00
0005435142577	21935	Economy	15400.00
0005435142613	21935	Economy	15400.00
0005433289923	21935	Economy	15400.00
0005435150011	21935	Economy	15400.00
0005435386630	21935	Economy	15400.00
0005435386635	21935	Economy	15400.00
0005435142559	21935	Economy	15400.00
0005435150036	21935	Economy	15400.00
0005433289924	21935	Economy	15400.00
0005435142555	21935	Economy	15400.00
0005435386633	21935	Economy	15400.00
0005435150057	21935	Economy	15400.00
0005435142602	21935	Economy	15400.00
0005435142550	21935	Economy	15400.00
0005435150059	21935	Economy	15400.00
0005435142539	21935	Economy	15400.00
0005433289922	21935	Economy	15400.00
0005435142587	21935	Economy	15400.00
0005435150034	21935	Economy	15400.00
0005435142624	21935	Economy	15400.00
0005435142563	21935	Economy	15400.00
0005435386632	21935	Economy	15400.00
0005433289919	21935	Economy	15400.00
0005435386634	21935	Economy	15400.00
0005435386631	21935	Economy	15400.00
0005433289918	21935	Economy	15400.00
0005435142578	21935	Economy	15400.00
0005435142586	21935	Economy	15400.00
0005435150058	21935	Economy	15400.00
0005435142564	21935	Economy	15400.00
0005435150035	21935	Economy	15400.00
0005435142568	21935	Economy	15400.00
0005435142580	21935	Economy	15400.00
0005435502305	11198	Business	57200.00
0005434573467	11198	Business	57200.00
0005435545734	11198	Business	57200.00
0005435502386	11198	Business	57200.00
0005435529316	11198	Business	57200.00
0005435502326	11198	Business	57200.00
0005435502403	11198	Economy	19100.00
0005435502331	11198	Economy	19100.00
0005435529286	11198	Economy	19100.00
0005434573466	11198	Economy	19100.00
0005434573468	11198	Economy	19100.00
0005435502276	11198	Economy	19100.00
0005435319556	11198	Economy	19100.00
0005435502358	11198	Economy	19100.00
0005435502275	11198	Economy	21000.00
0005435319569	11198	Economy	21000.00
0005435502302	11198	Economy	21000.00
0005435529323	11198	Economy	21000.00
0005435529259	11198	Economy	19100.00
0005435319587	11198	Economy	19100.00
0005435529211	11198	Economy	19100.00
0005435529224	11198	Economy	19100.00
0005435529324	11198	Economy	19100.00
0005435529271	11198	Economy	19100.00
0005435529325	11198	Economy	19100.00
0005434573471	11198	Economy	19100.00
0005435529213	11198	Economy	19100.00
0005435545729	11198	Economy	19100.00
0005435529156	11198	Economy	19100.00
0005435502309	11198	Economy	19100.00
0005435529258	11198	Economy	19100.00
0005434573472	11198	Economy	19100.00
0005435529281	11198	Economy	19100.00
0005435502329	11198	Economy	19100.00
0005435545736	11198	Economy	19100.00
0005435502357	11198	Economy	19100.00
0005434573470	11198	Economy	19100.00
0005435502389	11198	Economy	19100.00
0005435502330	11198	Economy	19100.00
0005435529163	11198	Economy	19100.00
0005435319616	11198	Economy	19100.00
0005434573474	11198	Economy	19100.00
0005435529162	11198	Economy	19100.00
0005435502390	11198	Economy	19100.00
0005435502278	11198	Economy	19100.00
0005435319617	11198	Economy	19100.00
0005434573465	11198	Economy	19100.00
0005435319619	11198	Economy	19100.00
0005435502310	11198	Economy	19100.00
0005435529223	11198	Economy	19100.00
0005435319563	11198	Economy	19100.00
0005435319620	11198	Economy	19100.00
0005435545728	11198	Economy	19100.00
0005435319570	11198	Economy	19100.00
0005435502359	11198	Economy	19100.00
0005435319588	11198	Economy	19100.00
0005435529247	11198	Economy	19100.00
0005435529222	11198	Economy	19100.00
0005435319584	11198	Economy	19100.00
0005435529214	11198	Economy	19100.00
0005434573475	11198	Economy	19100.00
0005435502363	11198	Economy	19100.00
0005434573469	11198	Economy	19100.00
0005435502404	11198	Economy	19100.00
0005435545737	11198	Economy	19100.00
0005435502332	11198	Economy	19100.00
0005434573476	11198	Economy	19100.00
0005435502301	11198	Economy	19100.00
0005434573463	11198	Economy	19100.00
0005435529155	11198	Economy	19100.00
0005435319575	11198	Economy	19100.00
0005435319583	11198	Economy	19100.00
0005435529315	11198	Economy	19100.00
0005435545730	11198	Economy	19100.00
0005434573464	11198	Economy	19100.00
0005434573473	11198	Economy	19100.00
0005434573462	11198	Economy	19100.00
0005435502269	11198	Economy	19100.00
0005435518063	20917	Business	57200.00
0005435518054	20917	Business	57200.00
0005435518069	20917	Business	57200.00
0005435518058	20917	Business	57200.00
0005435508459	20917	Business	57200.00
0005435518072	20917	Business	57200.00
0005435502487	20917	Business	57200.00
0005435502492	20917	Business	57200.00
0005435502496	20917	Business	57200.00
0005435518065	20917	Business	57200.00
0005435508456	20917	Business	57200.00
0005435508457	20917	Economy	19100.00
0005435319666	20917	Economy	19100.00
0005435518067	20917	Economy	19100.00
0005435508451	20917	Economy	19100.00
0005435518064	20917	Economy	19100.00
0005435502485	20917	Economy	19100.00
0005435518055	20917	Economy	19100.00
0005435508461	20917	Economy	19100.00
0005435518061	20917	Economy	19100.00
0005435508450	20917	Economy	19100.00
0005432291950	20917	Economy	21000.00
0005435518049	20917	Economy	21000.00
0005435518066	20917	Economy	21000.00
0005435319664	20917	Economy	21000.00
0005435502499	20917	Economy	21000.00
0005435518062	20917	Economy	19100.00
0005435518068	20917	Economy	19100.00
0005434573354	20917	Economy	19100.00
0005434573350	20917	Economy	19100.00
0005435508453	20917	Economy	19100.00
0005434573358	20917	Economy	19100.00
0005434573284	20917	Economy	19100.00
0005435502495	20917	Economy	19100.00
0005434573349	20917	Economy	19100.00
0005435508448	20917	Economy	19100.00
0005435502486	20917	Economy	19100.00
0005435518050	20917	Economy	19100.00
0005435502488	20917	Economy	19100.00
0005435518056	20917	Economy	19100.00
0005435518052	20917	Economy	19100.00
0005435518051	20917	Economy	19100.00
0005435319662	20917	Economy	19100.00
0005435319663	20917	Economy	19100.00
0005435508460	20917	Economy	19100.00
0005434573314	20917	Economy	19100.00
0005435502500	20917	Economy	19100.00
0005435319665	20917	Economy	19100.00
0005435518057	20917	Economy	19100.00
0005435502493	20917	Economy	19100.00
0005435502491	20917	Economy	19100.00
0005435518059	20917	Economy	19100.00
0005434573323	20917	Economy	19100.00
0005434573332	20917	Economy	19100.00
0005435508452	20917	Economy	19100.00
0005432291951	20917	Economy	19100.00
0005435508454	20917	Economy	19100.00
0005434573343	20917	Economy	19100.00
0005435319661	20917	Economy	19100.00
0005435502490	20917	Economy	19100.00
0005435518060	20917	Economy	19100.00
0005434573315	20917	Economy	19100.00
0005435518053	20917	Economy	19100.00
0005435502501	20917	Economy	19100.00
0005435502503	20917	Economy	19100.00
0005434573353	20917	Economy	19100.00
0005435502489	20917	Economy	19100.00
0005435502506	20917	Economy	19100.00
0005435319660	20917	Economy	19100.00
0005435502505	20917	Economy	19100.00
0005434573384	20917	Economy	19100.00
0005435508447	20917	Economy	19100.00
0005435502504	20917	Economy	19100.00
0005435508458	20917	Economy	19100.00
0005434573276	20917	Economy	19100.00
0005435502497	20917	Economy	19100.00
0005435502498	20917	Economy	19100.00
0005435502494	20917	Economy	19100.00
0005434573310	20917	Economy	19100.00
0005435502507	20917	Economy	19100.00
0005435518070	20917	Economy	19100.00
0005435508455	20917	Economy	19100.00
0005435518071	20917	Economy	19100.00
0005435319667	20917	Economy	19100.00
0005434573385	20917	Economy	19100.00
0005435508462	20917	Economy	19100.00
0005434573333	20917	Economy	19100.00
0005435508449	20917	Economy	19100.00
0005435502502	20917	Economy	19100.00
0005432693048	2959	Business	10300.00
0005432692911	2959	Business	10300.00
0005432692912	2959	Business	10300.00
0005432693095	2959	Business	10300.00
0005432693121	2959	Economy	3400.00
0005432692995	2959	Economy	3400.00
0005432693103	2959	Economy	3400.00
0005432693150	2959	Economy	3400.00
0005432693158	2959	Economy	3400.00
0005432693168	2959	Economy	3400.00
0005432693012	2959	Economy	3400.00
0005432693151	2959	Economy	3400.00
0005432693070	2959	Economy	3400.00
0005432693020	2959	Economy	3400.00
0005432692973	2959	Economy	3400.00
0005432693157	2959	Economy	3400.00
0005432693029	2959	Economy	3400.00
0005432692891	2959	Economy	3400.00
0005432693028	2959	Economy	3400.00
0005432693079	2959	Economy	3400.00
0005432693106	2959	Economy	3400.00
0005432693105	2959	Economy	3400.00
0005432692892	2959	Economy	3400.00
0005432693045	2959	Economy	3400.00
0005432693101	2959	Economy	3400.00
0005432693094	2959	Economy	3400.00
0005432693011	2959	Economy	3400.00
0005432693104	2959	Economy	3400.00
0005432693100	2959	Economy	3400.00
0005432693122	2959	Economy	3400.00
0005432692974	2959	Economy	3400.00
0005432693043	2959	Economy	3400.00
0005432693044	2959	Economy	3400.00
0005432693156	2959	Economy	3400.00
0005432707013	2960	Business	10300.00
0005432707001	2960	Business	10300.00
0005432217801	2960	Business	10300.00
0005432706996	2960	Business	10300.00
0005433123808	2960	Business	10300.00
0005433123876	2960	Business	10300.00
0005433123930	2960	Business	10300.00
0005432707014	2960	Economy	3400.00
0005433123853	2960	Economy	3400.00
0005432706993	2960	Economy	3400.00
0005432707007	2960	Economy	3800.00
0005433124015	2960	Economy	3800.00
0005432880827	2960	Economy	3800.00
0005432707009	2960	Economy	3800.00
0005433123897	2960	Economy	3800.00
0005433123956	2960	Economy	3400.00
0005432706997	2960	Economy	3400.00
0005432880804	2960	Economy	3400.00
0005432880869	2960	Economy	3400.00
0005432880825	2960	Economy	3400.00
0005432217802	2960	Economy	3400.00
0005433124016	2960	Economy	3400.00
0005432706999	2960	Economy	3400.00
0005432880824	2960	Economy	3400.00
0005432707008	2960	Economy	3400.00
0005432706992	2960	Economy	3400.00
0005433123899	2960	Economy	3400.00
0005432880792	2960	Economy	3400.00
0005433123997	2960	Economy	3400.00
0005433123926	2960	Economy	3400.00
0005432707004	2960	Economy	3400.00
0005432707002	2960	Economy	3400.00
0005432707003	2960	Economy	3400.00
0005432880819	2960	Economy	3400.00
0005432707011	2960	Economy	3400.00
0005432880786	2960	Economy	3400.00
0005432880839	2960	Economy	3400.00
0005432706991	2960	Economy	3400.00
0005432706990	2960	Economy	3400.00
0005432217800	2960	Economy	3400.00
0005432707010	2960	Economy	3400.00
0005432880818	2960	Economy	3400.00
0005433123962	2960	Economy	3400.00
0005433194856	2960	Economy	3400.00
0005432706995	2960	Economy	3400.00
0005432880771	2960	Economy	3400.00
0005432706989	2960	Economy	3400.00
0005433123957	2960	Economy	3400.00
0005432706998	2960	Economy	3400.00
0005432706994	2960	Economy	3400.00
0005432217803	2960	Economy	3400.00
0005432707012	2960	Economy	3400.00
0005432880826	2960	Economy	3400.00
0005433123963	2960	Economy	3400.00
0005432880788	2960	Economy	3400.00
0005433123895	2960	Economy	3400.00
0005433123925	2960	Economy	3400.00
0005433123807	2960	Economy	3400.00
0005432707000	2960	Economy	3400.00
0005432707005	2960	Economy	3400.00
0005432707006	2960	Economy	3400.00
0005433194887	30037	Business	10300.00
0005432693371	30037	Business	10300.00
0005432693361	30037	Business	10300.00
0005432706705	30037	Business	10300.00
0005432693370	30037	Business	10300.00
0005432693365	30037	Business	10300.00
0005432693367	30037	Business	10300.00
0005432693349	30037	Business	10300.00
0005432706772	30037	Business	10300.00
0005432706817	30037	Business	10300.00
0005433194879	30037	Business	10300.00
0005432706848	30037	Business	10300.00
0005432693350	30037	Economy	3400.00
0005432706769	30037	Economy	3400.00
0005432880947	30037	Economy	3400.00
0005433124111	30037	Economy	3400.00
0005432693368	30037	Economy	3400.00
0005432693362	30037	Economy	3400.00
0005432693356	30037	Economy	3400.00
0005432693348	30037	Economy	3400.00
0005432693375	30037	Economy	3400.00
0005433124107	30037	Economy	3400.00
0005433194886	30037	Economy	3800.00
0005433124112	30037	Economy	3800.00
0005433124098	30037	Economy	3800.00
0005432706792	30037	Economy	3800.00
0005433124101	30037	Economy	3800.00
0005432706818	30037	Economy	3400.00
0005432693369	30037	Economy	3400.00
0005432880953	30037	Economy	3400.00
0005433124106	30037	Economy	3400.00
0005432706782	30037	Economy	3400.00
0005432706820	30037	Economy	3400.00
0005432880952	30037	Economy	3400.00
0005433124114	30037	Economy	3400.00
0005432693377	30037	Economy	3400.00
0005432880943	30037	Economy	3400.00
0005433124119	30037	Economy	3400.00
0005433194884	30037	Economy	3400.00
0005432693360	30037	Economy	3400.00
0005433124097	30037	Economy	3400.00
0005433124115	30037	Economy	3400.00
0005432693363	30037	Economy	3400.00
0005433194878	30037	Economy	3400.00
0005432693378	30037	Economy	3400.00
0005433124105	30037	Economy	3400.00
0005432706850	30037	Economy	3400.00
0005433124109	30037	Economy	3400.00
0005432693358	30037	Economy	3400.00
0005432880944	30037	Economy	3400.00
0005432880942	30037	Economy	3400.00
0005433194877	30037	Economy	3400.00
0005432693373	30037	Economy	3400.00
0005432693353	30037	Economy	3400.00
0005433194880	30037	Economy	3400.00
0005432880951	30037	Economy	3400.00
0005432693372	30037	Economy	3400.00
0005432693366	30037	Economy	3400.00
0005433124099	30037	Economy	3400.00
0005433124113	30037	Economy	3400.00
0005432706924	30037	Economy	3400.00
0005433124104	30037	Economy	3400.00
0005433194882	30037	Economy	3400.00
0005433124110	30037	Economy	3400.00
0005432880950	30037	Economy	3400.00
0005432880946	30037	Economy	3400.00
0005433124116	30037	Economy	3400.00
0005432693374	30037	Economy	3400.00
0005433194881	30037	Economy	3400.00
0005432880949	30037	Economy	3400.00
0005432880955	30037	Economy	3400.00
0005433124100	30037	Economy	3400.00
0005432706823	30037	Economy	3400.00
0005433124118	30037	Economy	3400.00
0005432706800	30037	Economy	3400.00
0005432693352	30037	Economy	3400.00
0005433124117	30037	Economy	3400.00
0005432706786	30037	Economy	3400.00
0005432693354	30037	Economy	3400.00
0005432706785	30037	Economy	3400.00
0005433124108	30037	Economy	3400.00
0005432880954	30037	Economy	3400.00
0005432693364	30037	Economy	3400.00
0005433124102	30037	Economy	3400.00
0005432880945	30037	Economy	3400.00
0005433124103	30037	Economy	3400.00
0005433194883	30037	Economy	3400.00
0005432706773	30037	Economy	3400.00
0005432880948	30037	Economy	3400.00
0005432693357	30037	Economy	3400.00
0005433194885	30037	Economy	3400.00
0005432693359	30037	Economy	3400.00
0005432706897	30037	Economy	3400.00
0005432693351	30037	Economy	3400.00
0005432693355	30037	Economy	3400.00
0005432693376	30037	Economy	3400.00
0005434980051	23705	Economy	4000.00
0005434980046	23705	Economy	4000.00
0005434988824	23705	Economy	4000.00
0005434988828	23705	Economy	4000.00
0005434980030	23705	Economy	3600.00
0005434980044	23705	Economy	3600.00
0005434980048	23705	Economy	3600.00
0005434988829	23705	Economy	3600.00
0005434980036	23705	Economy	3600.00
0005434988822	23705	Economy	3600.00
0005434988830	23705	Economy	3600.00
0005434980031	23705	Economy	3600.00
0005434980035	23705	Economy	3600.00
0005434980032	23705	Economy	3600.00
0005434980040	23705	Economy	3600.00
0005434980041	23705	Economy	3600.00
0005434980027	23705	Economy	3600.00
0005434980045	23705	Economy	3600.00
0005434988826	23705	Economy	3600.00
0005434980028	23705	Economy	3600.00
0005434980034	23705	Economy	3600.00
0005434980038	23705	Economy	3600.00
0005434988831	23705	Economy	3600.00
0005434980049	23705	Economy	3600.00
0005434980025	23705	Economy	3600.00
0005434980047	23705	Economy	3600.00
0005434980033	23705	Economy	3600.00
0005434980039	23705	Economy	3600.00
0005434988825	23705	Economy	3600.00
0005434980026	23705	Economy	3600.00
0005434980021	23705	Economy	3600.00
0005434980042	23705	Economy	3600.00
0005434988827	23705	Economy	3600.00
0005434980029	23705	Economy	3600.00
0005434980037	23705	Economy	3600.00
0005434988823	23705	Economy	3600.00
0005434980050	23705	Economy	3600.00
0005434980023	23705	Economy	3600.00
0005434988821	23705	Economy	3600.00
0005434980024	23705	Economy	3600.00
0005434980043	23705	Economy	3600.00
0005434980022	23705	Economy	3600.00
0005434979768	27549	Economy	4000.00
0005434988716	27549	Economy	4000.00
0005434979779	27549	Economy	4000.00
0005434979820	27549	Economy	3600.00
0005434979886	27549	Economy	3600.00
0005434988733	27549	Economy	3600.00
0005434979846	27549	Economy	3600.00
0005434979767	27549	Economy	3600.00
0005434988715	27549	Economy	3600.00
0005434979750	27549	Economy	3600.00
0005434979736	27549	Economy	3600.00
0005434988751	27549	Economy	3600.00
0005434988720	27549	Economy	3600.00
0005434979885	27549	Economy	3600.00
0005434979712	27549	Economy	3600.00
0005434979742	27549	Economy	3600.00
0005434979882	27549	Economy	3600.00
0005434979766	27549	Economy	3600.00
0005434979861	27549	Economy	3600.00
0005434988724	27549	Economy	3600.00
0005434988731	27549	Economy	3600.00
0005434988745	27549	Economy	3600.00
0005434988730	27549	Economy	3600.00
0005434988743	27549	Economy	3600.00
0005434979743	27549	Economy	3600.00
0005434979786	27549	Economy	3600.00
0005434988726	27549	Economy	3600.00
0005434988732	27549	Economy	3600.00
0005434988719	27549	Economy	3600.00
0005434988741	27549	Economy	3600.00
0005434979753	27549	Economy	3600.00
0005434979787	27549	Economy	3600.00
0005434979855	27549	Economy	3600.00
0005434988717	27549	Economy	3600.00
0005434979713	27549	Economy	3600.00
0005434979817	27549	Economy	3600.00
0005434988727	27549	Economy	3600.00
0005433113530	10286	Economy	21600.00
0005434302498	10286	Economy	19700.00
0005434302497	10286	Economy	19700.00
0005434302493	10286	Economy	19700.00
0005434302494	10286	Economy	19700.00
0005434302495	10286	Economy	19700.00
0005434302496	10286	Economy	19700.00
0005433111489	10286	Economy	19700.00
0005433113534	10286	Economy	19700.00
0005433113529	10286	Economy	19700.00
0005433113555	19633	Economy	21600.00
0005434302462	19633	Economy	19700.00
0005434302450	19633	Economy	19700.00
0005433113556	19633	Economy	19700.00
0005434302435	19633	Economy	19700.00
0005434302437	19633	Economy	19700.00
0005434302449	19633	Economy	19700.00
0005434302436	19633	Economy	19700.00
0005435069569	3578	Business	26900.00
0005435069583	3578	Business	26900.00
0005435069550	3578	Business	26900.00
0005435069538	3578	Business	26900.00
0005435069564	3578	Business	26900.00
0005435069566	3578	Business	26900.00
0005435069568	3578	Business	26900.00
0005435925336	3578	Business	26900.00
0005435069571	3578	Economy	9000.00
0005435069552	3578	Economy	9000.00
0005435069580	3578	Economy	9000.00
0005435925337	3578	Economy	9000.00
0005435069585	3578	Economy	9000.00
0005435925278	3578	Economy	9000.00
0005435069539	3578	Economy	9000.00
0005435925300	3578	Economy	9000.00
0005435069586	3578	Economy	9000.00
0005435069556	3578	Economy	9900.00
0005435925279	3578	Economy	9900.00
0005435069581	3578	Economy	9900.00
0005435069537	3578	Economy	9000.00
0005435925283	3578	Economy	9000.00
0005435069584	3578	Economy	9000.00
0005435069587	3578	Economy	9000.00
0005435069559	3578	Economy	9000.00
0005435069570	3578	Economy	9000.00
0005435925328	3578	Economy	9000.00
0005435925302	3578	Economy	9000.00
0005435069540	3578	Economy	9000.00
0005435069547	3578	Economy	9000.00
0005435069542	3578	Economy	9000.00
0005435069557	3578	Economy	9000.00
0005435925282	3578	Economy	9000.00
0005435069575	3578	Economy	9000.00
0005435069545	3578	Economy	9000.00
0005435069548	3578	Economy	9000.00
0005435069574	3578	Economy	9000.00
0005435718995	3578	Economy	9000.00
0005435069565	3578	Economy	9000.00
0005435069543	3578	Economy	9000.00
0005435069560	3578	Economy	9000.00
0005435069549	3578	Economy	9000.00
0005435069588	3578	Economy	9000.00
0005435069558	3578	Economy	9000.00
0005435925284	3578	Economy	9000.00
0005435925301	3578	Economy	9000.00
0005435069573	3578	Economy	9000.00
0005435069572	3578	Economy	9000.00
0005435069541	3578	Economy	9000.00
0005435069551	3578	Economy	9000.00
0005435069578	3578	Economy	9000.00
0005435069582	3578	Economy	9000.00
0005435069553	3578	Economy	9000.00
0005435069567	3578	Economy	9000.00
0005435069555	3578	Economy	9000.00
0005435069563	3578	Economy	9000.00
0005435069561	3578	Economy	9000.00
0005435069554	3578	Economy	9000.00
0005435925272	3578	Economy	9000.00
0005435069577	3578	Economy	9000.00
0005435069562	3578	Economy	9000.00
0005435069579	3578	Economy	9000.00
0005435069546	3578	Economy	9000.00
0005435069544	3578	Economy	9000.00
0005435069536	3578	Economy	9000.00
0005435069576	3578	Economy	9000.00
0005435925421	15315	Business	26900.00
0005435925419	15315	Business	26900.00
0005435068867	15315	Business	26900.00
0005435069147	15315	Business	26900.00
0005435069061	15315	Business	26900.00
0005435069077	15315	Business	26900.00
0005435069004	15315	Business	26900.00
0005435069068	15315	Business	26900.00
0005435068901	15315	Economy	9000.00
0005435069093	15315	Economy	9000.00
0005435068958	15315	Economy	9000.00
0005435069002	15315	Economy	9000.00
0005435068896	15315	Economy	9000.00
0005435068763	15315	Economy	9000.00
0005435069119	15315	Economy	9000.00
0005435069021	15315	Economy	9000.00
0005435068759	15315	Economy	9000.00
0005435069162	15315	Economy	9900.00
0005435925412	15315	Economy	9900.00
0005435925418	15315	Economy	9900.00
0005435069230	15315	Economy	9900.00
0005435925414	15315	Economy	9000.00
0005435069221	15315	Economy	9000.00
0005435069072	15315	Economy	9000.00
0005435068948	15315	Economy	9000.00
0005435925420	15315	Economy	9000.00
0005435069013	15315	Economy	9000.00
0005435069023	15315	Economy	9000.00
0005435068963	15315	Economy	9000.00
0005435069043	15315	Economy	9000.00
0005435069098	15315	Economy	9000.00
0005435069215	15315	Economy	9000.00
0005435069047	15315	Economy	9000.00
0005435068947	15315	Economy	9000.00
0005435069183	15315	Economy	9000.00
0005435925423	15315	Economy	9000.00
0005435068952	15315	Economy	9000.00
0005435069058	15315	Economy	9000.00
0005435069223	15315	Economy	9000.00
0005435069163	15315	Economy	9000.00
0005435068914	15315	Economy	9000.00
0005435069088	15315	Economy	9000.00
0005435069229	15315	Economy	9000.00
0005435069236	15315	Economy	9000.00
0005435068964	15315	Economy	9000.00
0005435069286	15315	Economy	9000.00
0005435069022	15315	Economy	9000.00
0005435068715	15315	Economy	9000.00
0005435069099	15315	Economy	9000.00
0005435939895	15315	Economy	9000.00
0005435068975	15315	Economy	9000.00
0005435068931	15315	Economy	9000.00
0005435069048	15315	Economy	9000.00
0005435925413	15315	Economy	9000.00
0005435068762	15315	Economy	9000.00
0005435069220	15315	Economy	9000.00
0005435069067	15315	Economy	9000.00
0005435068879	15315	Economy	9000.00
0005435925417	15315	Economy	9000.00
0005435069214	15315	Economy	9000.00
0005435925416	15315	Economy	9000.00
0005435068915	15315	Economy	9000.00
0005435069039	15315	Economy	9000.00
0005435068951	15315	Economy	9000.00
0005435069040	15315	Economy	9000.00
0005435068930	15315	Economy	9000.00
0005435068716	15315	Economy	9000.00
0005435069127	15315	Economy	9000.00
0005435925422	15315	Economy	9000.00
0005435069224	15315	Economy	9000.00
0005435069076	15315	Economy	9000.00
0005435925415	15315	Economy	9000.00
0005435069189	15315	Economy	9000.00
0005435068957	15315	Economy	9000.00
0005435069066	15315	Economy	9000.00
0005435069083	15315	Economy	9000.00
0005435069033	15315	Economy	9000.00
0005432658610	18154	Economy	5900.00
0005432660838	18154	Economy	5900.00
0005432658611	18154	Economy	5900.00
0005432660837	18154	Economy	5900.00
0005432658609	18154	Economy	5900.00
0005432659725	18154	Economy	5900.00
0005432660821	26441	Economy	5900.00
0005432660811	26441	Economy	5900.00
0005432664134	26441	Economy	5900.00
0005432664133	26441	Economy	5900.00
0005432664132	26441	Economy	5900.00
0005432664138	26441	Economy	5900.00
0005432660822	26441	Economy	5900.00
0005433102183	108	Business	20000.00
0005432901586	108	Business	20000.00
0005433102170	108	Business	20000.00
0005433102159	108	Business	20000.00
0005432677576	108	Business	20000.00
0005433102168	108	Business	20000.00
0005433102239	108	Business	20000.00
0005433101898	108	Business	20000.00
0005432901656	108	Business	20000.00
0005432901659	108	Business	20000.00
0005433102161	108	Business	20000.00
0005432901680	108	Business	20000.00
0005433102145	108	Business	20000.00
0005432901644	108	Business	20000.00
0005433102166	108	Business	20000.00
0005433102107	108	Economy	7300.00
0005433102182	108	Economy	7300.00
0005433102207	108	Economy	7300.00
0005433102053	108	Economy	6700.00
0005432677568	108	Economy	6700.00
0005433102098	108	Economy	6700.00
0005432157510	108	Economy	6700.00
0005432919792	108	Economy	6700.00
0005433102150	108	Economy	6700.00
0005433102180	108	Economy	6700.00
0005433102160	108	Economy	6700.00
0005432919921	108	Economy	6700.00
0005433102144	108	Economy	6700.00
0005433102061	108	Economy	6700.00
0005432901621	108	Economy	6700.00
0005432919896	108	Economy	6700.00
0005433102153	108	Economy	6700.00
0005433102062	108	Economy	6700.00
0005433102167	108	Economy	6700.00
0005433101873	108	Economy	6700.00
0005433101899	108	Economy	6700.00
0005433102237	108	Economy	6700.00
0005432901650	108	Economy	6700.00
0005433102026	108	Economy	6700.00
0005432901648	108	Economy	6700.00
0005433102073	108	Economy	6700.00
0005433102067	108	Economy	6700.00
0005433102129	108	Economy	6700.00
0005433102210	108	Economy	6700.00
0005433102099	108	Economy	6700.00
0005433102169	108	Economy	6700.00
0005432901601	108	Economy	6700.00
0005433102092	108	Economy	6700.00
0005432919790	108	Economy	6700.00
0005432919913	108	Economy	6700.00
0005433101982	108	Economy	6700.00
0005432677567	108	Economy	7300.00
0005432677579	108	Economy	7300.00
0005433102211	108	Economy	7300.00
0005432919912	108	Economy	6700.00
0005433102175	108	Economy	6700.00
0005432901660	108	Economy	6700.00
0005433102070	108	Economy	6700.00
0005433102163	108	Economy	6700.00
0005433102102	108	Economy	6700.00
0005432901622	108	Economy	6700.00
0005433101900	108	Economy	6700.00
0005433102054	108	Economy	6700.00
0005433102128	108	Economy	6700.00
0005432919917	108	Economy	6700.00
0005432919919	108	Economy	6700.00
0005432901651	108	Economy	6700.00
0005432919920	108	Economy	6700.00
0005433102074	108	Economy	6700.00
0005433102162	108	Economy	6700.00
0005432919824	108	Economy	6700.00
0005432919886	108	Economy	6700.00
0005433102130	108	Economy	6700.00
0005432919897	108	Economy	6700.00
0005433102215	108	Economy	6700.00
0005432901574	108	Economy	6700.00
0005433102140	108	Economy	6700.00
0005432919924	108	Economy	6700.00
0005433102152	108	Economy	6700.00
0005433102178	108	Economy	6700.00
0005433102108	108	Economy	6700.00
0005432157509	108	Economy	6700.00
0005433102190	108	Economy	6700.00
0005432919875	108	Economy	6700.00
0005433102101	108	Economy	6700.00
0005433102082	108	Economy	6700.00
0005432919911	108	Economy	6700.00
0005433102076	108	Economy	6700.00
0005432901646	108	Economy	6700.00
0005432919791	108	Economy	6700.00
0005432919902	108	Economy	6700.00
0005433102143	108	Economy	6700.00
0005432901647	108	Economy	6700.00
0005433102171	108	Economy	6700.00
0005432919887	108	Economy	6700.00
0005433102189	108	Economy	6700.00
0005432919895	108	Economy	6700.00
0005432677575	108	Economy	6700.00
0005432901705	108	Economy	6700.00
0005432817737	109	Business	20000.00
0005432262333	109	Business	20000.00
0005432262320	109	Business	20000.00
0005432817742	109	Business	20000.00
0005432817732	109	Business	20000.00
0005432817741	109	Business	20000.00
0005432817756	109	Business	20000.00
0005432262328	109	Business	20000.00
0005432756850	109	Business	20000.00
0005432817738	109	Business	20000.00
0005432262332	109	Business	20000.00
0005432756849	109	Business	20000.00
0005432262346	109	Business	20000.00
0005432817750	109	Business	20000.00
0005432262317	109	Business	20000.00
0005432817746	109	Economy	7300.00
0005432262310	109	Economy	7300.00
0005432262326	109	Economy	7300.00
0005432262319	109	Economy	6700.00
0005432262336	109	Economy	6700.00
0005432817744	109	Economy	6700.00
0005432817755	109	Economy	6700.00
0005432262327	109	Economy	6700.00
0005432262335	109	Economy	6700.00
0005432262322	109	Economy	6700.00
0005432753305	109	Economy	6700.00
0005432262316	109	Economy	6700.00
0005432817754	109	Economy	6700.00
0005432262324	109	Economy	6700.00
0005432289016	109	Economy	6700.00
0005432817757	109	Economy	6700.00
0005432817735	109	Economy	6700.00
0005432262345	109	Economy	6700.00
0005432817743	109	Economy	6700.00
0005432262308	109	Economy	6700.00
0005432262314	109	Economy	6700.00
0005432262309	109	Economy	6700.00
0005432262331	109	Economy	6700.00
0005432262303	109	Economy	6700.00
0005432289017	109	Economy	6700.00
0005432262334	109	Economy	6700.00
0005432262347	109	Economy	6700.00
0005432817736	109	Economy	6700.00
0005432817730	109	Economy	6700.00
0005432262349	109	Economy	6700.00
0005434153542	109	Economy	6700.00
0005432262337	109	Economy	6700.00
0005432817739	109	Economy	6700.00
0005432817751	109	Economy	6700.00
0005432262312	109	Economy	6700.00
0005432262344	109	Economy	6700.00
0005432289015	109	Economy	7300.00
0005432262305	109	Economy	7300.00
0005432817734	109	Economy	7300.00
0005432817729	109	Economy	7300.00
0005432756830	109	Economy	6700.00
0005432262348	109	Economy	6700.00
0005432262341	109	Economy	6700.00
0005432262343	109	Economy	6700.00
0005432817728	109	Economy	6700.00
0005432817745	109	Economy	6700.00
0005432262340	109	Economy	6700.00
0005432262311	109	Economy	6700.00
0005432817740	109	Economy	6700.00
0005432262330	109	Economy	6700.00
0005432207685	109	Economy	6700.00
0005432262325	109	Economy	6700.00
0005432817733	109	Economy	6700.00
0005432262315	109	Economy	6700.00
0005432817731	109	Economy	6700.00
0005432817747	109	Economy	6700.00
0005434153543	109	Economy	6700.00
0005432817748	109	Economy	6700.00
0005432262339	109	Economy	6700.00
0005432262304	109	Economy	6700.00
0005432262321	109	Economy	6700.00
0005432756840	109	Economy	6700.00
0005432262342	109	Economy	6700.00
0005432207684	109	Economy	6700.00
0005432262318	109	Economy	6700.00
0005432262307	109	Economy	6700.00
0005432262313	109	Economy	6700.00
0005432817753	109	Economy	6700.00
0005432262323	109	Economy	6700.00
0005432262338	109	Economy	6700.00
0005432262306	109	Economy	6700.00
0005432817752	109	Economy	6700.00
0005432817749	109	Economy	6700.00
0005432262329	109	Economy	6700.00
0005433102635	7996	Business	20000.00
0005433102666	7996	Business	20000.00
0005432753332	7996	Business	20000.00
0005432020508	7996	Business	20000.00
0005433102634	7996	Business	20000.00
0005432020499	7996	Business	20000.00
0005433102616	7996	Business	20000.00
0005433102663	7996	Business	20000.00
0005433102637	7996	Business	20000.00
0005432920052	7996	Business	20000.00
0005432020513	7996	Business	20000.00
0005433102657	7996	Business	20000.00
0005432020493	7996	Business	20000.00
0005432020498	7996	Business	20000.00
0005433102628	7996	Business	20000.00
0005433102630	7996	Business	20000.00
0005433102648	7996	Business	20000.00
0005433102609	7996	Business	20000.00
0005433102604	7996	Business	20000.00
0005433102596	7996	Business	20000.00
0005432020506	7996	Business	20000.00
0005432920049	7996	Business	20000.00
0005432020507	7996	Business	20000.00
0005432020502	7996	Business	20000.00
0005433102670	7996	Business	20000.00
0005433102610	7996	Economy	7300.00
0005433102629	7996	Economy	7300.00
0005432392027	7996	Economy	7300.00
0005433102623	7996	Economy	7300.00
0005432920051	7996	Economy	6700.00
0005433102601	7996	Economy	6700.00
0005433102602	7996	Economy	6700.00
0005432020509	7996	Economy	6700.00
0005432920057	7996	Economy	6700.00
0005433102614	7996	Economy	6700.00
0005432020497	7996	Economy	6700.00
0005433102618	7996	Economy	6700.00
0005433102620	7996	Economy	6700.00
0005433102632	7996	Economy	6700.00
0005433102615	7996	Economy	6700.00
0005433102668	7996	Economy	6700.00
0005432020516	7996	Economy	6700.00
0005432751559	7996	Economy	6700.00
0005433102640	7996	Economy	6700.00
0005432920040	7996	Economy	6700.00
0005433102655	7996	Economy	6700.00
0005432020517	7996	Economy	6700.00
0005432920056	7996	Economy	6700.00
0005432020495	7996	Economy	6700.00
0005433102638	7996	Economy	6700.00
0005433102605	7996	Economy	6700.00
0005432677612	7996	Economy	6700.00
0005433102653	7996	Economy	6700.00
0005433102664	7996	Economy	6700.00
0005433102603	7996	Economy	6700.00
0005432020520	7996	Economy	6700.00
0005433102643	7996	Economy	6700.00
0005433102656	7996	Economy	6700.00
0005433102642	7996	Economy	6700.00
0005433102636	7996	Economy	6700.00
0005433102661	7996	Economy	6700.00
0005433102611	7996	Economy	6700.00
0005432020494	7996	Economy	6700.00
0005433102647	7996	Economy	6700.00
0005432920044	7996	Economy	6700.00
0005433102599	7996	Economy	6700.00
0005432020505	7996	Economy	6700.00
0005432020512	7996	Economy	6700.00
0005433102593	7996	Economy	6700.00
0005433102617	7996	Economy	6700.00
0005433102607	7996	Economy	6700.00
0005432020503	7996	Economy	6700.00
0005433102613	7996	Economy	6700.00
0005433102612	7996	Economy	6700.00
0005433102662	7996	Economy	6700.00
0005433102624	7996	Economy	6700.00
0005433102660	7996	Economy	6700.00
0005432020519	7996	Economy	6700.00
0005432751557	7996	Economy	6700.00
0005433102608	7996	Economy	6700.00
0005432677610	7996	Economy	7300.00
0005432020518	7996	Economy	7300.00
0005433102594	7996	Economy	7300.00
0005432920055	7996	Economy	7300.00
0005432920050	7996	Economy	6700.00
0005432920043	7996	Economy	6700.00
0005433102665	7996	Economy	6700.00
0005433102619	7996	Economy	6700.00
0005433102654	7996	Economy	7300.00
0005432392026	7996	Economy	6700.00
0005432920058	7996	Economy	6700.00
0005433102650	7996	Economy	6700.00
0005433102652	7996	Economy	6700.00
0005432020496	7996	Economy	6700.00
0005433102606	7996	Economy	6700.00
0005433102625	7996	Economy	6700.00
0005433102659	7996	Economy	6700.00
0005432920046	7996	Economy	6700.00
0005432020514	7996	Economy	6700.00
0005432920039	7996	Economy	6700.00
0005432045631	7996	Economy	6700.00
0005432920053	7996	Economy	6700.00
0005432045632	7996	Economy	6700.00
0005432751556	7996	Economy	6700.00
0005432920048	7996	Economy	6700.00
0005433102644	7996	Economy	6700.00
0005433102639	7996	Economy	6700.00
0005433102622	7996	Economy	6700.00
0005432020504	7996	Economy	6700.00
0005433102669	7996	Economy	6700.00
0005432920042	7996	Economy	6700.00
0005432753333	7996	Economy	6700.00
0005432020501	7996	Economy	6700.00
0005433102621	7996	Economy	6700.00
0005432677611	7996	Economy	6700.00
0005433102641	7996	Economy	6700.00
0005432920041	7996	Economy	6700.00
0005433102595	7996	Economy	6700.00
0005433102626	7996	Economy	6700.00
0005432020511	7996	Economy	6700.00
0005432044550	7996	Economy	6700.00
0005432920054	7996	Economy	6700.00
0005432020515	7996	Economy	6700.00
0005432020500	7996	Economy	6700.00
0005433102667	7996	Economy	6700.00
0005432677609	7996	Economy	6700.00
0005432920047	7996	Economy	6700.00
0005433102658	7996	Economy	6700.00
0005432392028	7996	Economy	6700.00
0005433102645	7996	Economy	6700.00
0005433102600	7996	Economy	6700.00
0005433102633	7996	Economy	6700.00
0005432044551	7996	Economy	6700.00
0005433102646	7996	Economy	6700.00
0005433102649	7996	Economy	6700.00
0005433102627	7996	Economy	6700.00
0005432920038	7996	Economy	6700.00
0005433102631	7996	Economy	6700.00
0005433102597	7996	Economy	6700.00
0005432920045	7996	Economy	6700.00
0005432020510	7996	Economy	6700.00
0005433102598	7996	Economy	6700.00
0005433102651	7996	Economy	6700.00
0005432751558	7996	Economy	6700.00
0005432901776	7997	Business	20000.00
0005432901770	7997	Business	20000.00
0005432901766	7997	Business	20000.00
0005432817551	7997	Business	20000.00
0005432901778	7997	Economy	7300.00
0005432817515	7997	Economy	6700.00
0005432901775	7997	Economy	6700.00
0005432901767	7997	Economy	6700.00
0005432817434	7997	Economy	6700.00
0005432817506	7997	Economy	6700.00
0005432817540	7997	Economy	6700.00
0005432817585	7997	Economy	6700.00
0005432817550	7997	Economy	6700.00
0005432901765	7997	Economy	6700.00
0005432817601	7997	Economy	6700.00
0005432901764	7997	Economy	6700.00
0005432901762	7997	Economy	6700.00
0005432901773	7997	Economy	6700.00
0005432901772	7997	Economy	6700.00
0005432002094	7997	Economy	6700.00
0005432002095	7997	Economy	6700.00
0005432901763	7997	Economy	7300.00
0005432817553	7997	Economy	7300.00
0005432901771	7997	Economy	6700.00
0005432901769	7997	Economy	6700.00
0005432817541	7997	Economy	7300.00
0005432817514	7997	Economy	6700.00
0005432901761	7997	Economy	6700.00
0005432817568	7997	Economy	6700.00
0005432901768	7997	Economy	6700.00
0005432901777	7997	Economy	6700.00
0005432817500	7997	Economy	6700.00
0005432817558	7997	Economy	6700.00
0005432817557	7997	Economy	6700.00
0005432817483	7997	Economy	6700.00
0005432901774	7997	Economy	6700.00
0005434175757	9662	Economy	6900.00
0005434175746	9662	Economy	6900.00
0005433870751	9662	Economy	6900.00
0005434175752	9662	Economy	6900.00
0005434175756	9662	Economy	6900.00
0005434175745	9662	Economy	6900.00
0005434175764	9662	Economy	6900.00
0005434175747	9662	Economy	6900.00
0005433870750	9662	Economy	6900.00
0005434175744	9662	Economy	6900.00
0005434175792	32378	Economy	6900.00
0005433870739	32378	Economy	6900.00
0005434175790	32378	Economy	6900.00
0005434175791	32378	Economy	6900.00
0005434175793	32378	Economy	6900.00
0005435902710	3487	Business	35000.00
0005434879132	3487	Business	35000.00
0005434426886	3487	Business	35000.00
0005435841820	3487	Business	35000.00
0005435841821	3487	Business	35000.00
0005435126766	3487	Business	35000.00
0005434938329	3487	Business	35000.00
0005435126767	3487	Business	35000.00
0005435913930	3487	Business	35000.00
0005434938316	3487	Business	35000.00
0005435626366	3487	Business	35000.00
0005434879069	3487	Business	35000.00
0005434879059	3487	Business	35000.00
0005434879092	3487	Business	35000.00
0005432799724	3487	Business	35000.00
0005432613900	3487	Business	35000.00
0005432611750	3487	Business	35000.00
0005434879134	3487	Business	35000.00
0005432188638	3487	Business	35000.00
0005434879098	3487	Business	35000.00
0005435126768	3487	Business	35000.00
0005434938327	3487	Business	35000.00
0005435902712	3487	Comfort	19900.00
0005432799726	3487	Business	35000.00
0005434426888	3487	Comfort	19900.00
0005435126747	3487	Comfort	19900.00
0005434879148	3487	Comfort	19900.00
0005432613899	3487	Comfort	19900.00
0005434879115	3487	Comfort	19900.00
0005432188637	3487	Comfort	19900.00
0005434426877	3487	Comfort	19900.00
0005434879066	3487	Comfort	19900.00
0005434879130	3487	Comfort	19900.00
0005434879104	3487	Comfort	19900.00
0005434938332	3487	Comfort	19900.00
0005435626353	3487	Comfort	19900.00
0005432799733	3487	Comfort	19900.00
0005435626363	3487	Comfort	19900.00
0005434938317	3487	Comfort	19900.00
0005435902694	3487	Comfort	19900.00
0005434938326	3487	Comfort	19900.00
0005434879062	3487	Comfort	19900.00
0005434879072	3487	Comfort	19900.00
0005435902783	3487	Comfort	19900.00
0005435902732	3487	Comfort	19900.00
0005432799714	3487	Comfort	19900.00
0005434879137	3487	Comfort	19900.00
0005434879111	3487	Comfort	19900.00
0005434879076	3487	Comfort	19900.00
0005434879067	3487	Comfort	19900.00
0005434879074	3487	Comfort	19900.00
0005435902759	3487	Comfort	19900.00
0005434426892	3487	Comfort	19900.00
0005434879121	3487	Economy	11700.00
0005434426879	3487	Economy	11700.00
0005434879089	3487	Economy	11700.00
0005434879109	3487	Economy	11700.00
0005435914695	3487	Economy	11700.00
0005435626365	3487	Economy	11700.00
0005432799730	3487	Economy	11700.00
0005434938314	3487	Economy	11700.00
0005435913928	3487	Economy	11700.00
0005434426872	3487	Economy	11700.00
0005434879133	3487	Economy	11700.00
0005432799711	3487	Economy	11700.00
0005434426885	3487	Economy	11700.00
0005434426876	3487	Economy	11700.00
0005434879141	3487	Economy	11700.00
0005434426887	3487	Economy	11700.00
0005434426889	3487	Economy	11700.00
0005434879091	3487	Economy	11700.00
0005434879126	3487	Economy	11700.00
0005435902758	3487	Economy	11700.00
0005435626359	3487	Economy	11700.00
0005434879097	3487	Economy	11700.00
0005434879123	3487	Economy	11700.00
0005435914699	3487	Economy	11700.00
0005434938330	3487	Economy	11700.00
0005435126762	3487	Economy	11700.00
0005434879110	3487	Economy	11700.00
0005435902775	3487	Economy	11700.00
0005434879101	3487	Economy	11700.00
0005434879107	3487	Economy	11700.00
0005434879149	3487	Economy	11700.00
0005434879102	3487	Economy	11700.00
0005434879124	3487	Economy	11700.00
0005435126746	3487	Economy	11700.00
0005434426897	3487	Economy	11700.00
0005435626369	3487	Economy	11700.00
0005434879055	3487	Economy	11700.00
0005434879119	3487	Economy	11700.00
0005435626351	3487	Economy	11700.00
0005434879060	3487	Economy	11700.00
0005435126770	3487	Economy	11700.00
0005434879063	3487	Economy	11700.00
0005432799712	3487	Economy	11700.00
0005434879144	3487	Economy	11700.00
0005435126757	3487	Economy	11700.00
0005434879081	3487	Economy	11700.00
0005434879065	3487	Economy	11700.00
0005435626360	3487	Economy	11700.00
0005435126736	3487	Economy	11700.00
0005435126738	3487	Economy	11700.00
0005435626344	3487	Economy	11700.00
0005434879150	3487	Economy	12800.00
0005434879152	3487	Economy	12800.00
0005435902743	3487	Economy	11700.00
0005434426878	3487	Economy	12800.00
0005432183486	3487	Economy	11700.00
0005432799732	3487	Economy	11700.00
0005434426894	3487	Economy	11700.00
0005432799718	3487	Economy	12800.00
0005435626362	3487	Economy	12800.00
0005434879103	3487	Economy	12800.00
0005435126751	3487	Economy	11700.00
0005434879140	3487	Economy	11700.00
0005434879100	3487	Economy	11700.00
0005432799723	3487	Economy	11700.00
0005435626354	3487	Economy	11700.00
0005435126741	3487	Economy	11700.00
0005434879057	3487	Economy	11700.00
0005434426875	3487	Economy	11700.00
0005434426873	3487	Economy	11700.00
0005435626343	3487	Economy	11700.00
0005435126754	3487	Economy	11700.00
0005434879117	3487	Economy	11700.00
0005432799717	3487	Economy	11700.00
0005434879096	3487	Economy	11700.00
0005434426899	3487	Economy	11700.00
0005434879129	3487	Economy	11700.00
0005435841093	3487	Economy	11700.00
0005434879127	3487	Economy	11700.00
0005435126750	3487	Economy	11700.00
0005434879138	3487	Economy	11700.00
0005434938321	3487	Economy	11700.00
0005435126756	3487	Economy	11700.00
0005435126743	3487	Economy	11700.00
0005432799713	3487	Economy	11700.00
0005434879105	3487	Economy	11700.00
0005432613902	3487	Economy	11700.00
0005435126742	3487	Economy	11700.00
0005434938318	3487	Economy	11700.00
0005435126769	3487	Economy	11700.00
0005432799719	3487	Economy	11700.00
0005434879064	3487	Economy	11700.00
0005434426882	3487	Economy	11700.00
0005435626349	3487	Economy	11700.00
0005434938324	3487	Economy	11700.00
0005434879142	3487	Economy	11700.00
0005434879147	3487	Economy	11700.00
0005432613901	3487	Economy	11700.00
0005434879095	3487	Economy	11700.00
0005434426870	3487	Economy	11700.00
0005434879079	3487	Economy	11700.00
0005434938323	3487	Economy	11700.00
0005435902742	3487	Economy	11700.00
0005434426896	3487	Economy	11700.00
0005435126752	3487	Economy	11700.00
0005435626358	3487	Economy	11700.00
0005435126765	3487	Economy	11700.00
0005434426893	3487	Economy	11700.00
0005435626348	3487	Economy	11700.00
0005435126760	3487	Economy	11700.00
0005435902711	3487	Economy	11700.00
0005434938322	3487	Economy	11700.00
0005432799731	3487	Economy	11700.00
0005434879082	3487	Economy	11700.00
0005435126759	3487	Economy	11700.00
0005434879056	3487	Economy	11700.00
0005434879139	3487	Economy	11700.00
0005434879088	3487	Economy	11700.00
0005432799727	3487	Economy	11700.00
0005432183487	3487	Economy	11700.00
0005434879058	3487	Economy	11700.00
0005434879070	3487	Economy	11700.00
0005434879068	3487	Economy	11700.00
0005434426884	3487	Economy	11700.00
0005435902776	3487	Economy	11700.00
0005432799720	3487	Economy	11700.00
0005434426891	3487	Economy	11700.00
0005434879078	3487	Economy	11700.00
0005435126745	3487	Economy	11700.00
0005434879146	3487	Economy	11700.00
0005434879099	3487	Economy	11700.00
0005432799710	3487	Economy	11700.00
0005434426898	3487	Economy	11700.00
0005435626361	3487	Economy	11700.00
0005435126753	3487	Economy	11700.00
0005434426871	3487	Economy	11700.00
0005432799725	3487	Economy	11700.00
0005432799707	3487	Economy	11700.00
0005435126740	3487	Economy	11700.00
0005435914694	3487	Economy	11700.00
0005435914697	3487	Economy	11700.00
0005432799729	3487	Economy	11700.00
0005435126755	3487	Economy	11700.00
0005434938315	3487	Economy	11700.00
0005435126739	3487	Economy	11700.00
0005432611749	3487	Economy	11700.00
0005434426881	3487	Economy	11700.00
0005434426890	3487	Economy	11700.00
0005434879118	3487	Economy	11700.00
0005435626347	3487	Economy	11700.00
0005434879083	3487	Economy	11700.00
0005435626340	3487	Economy	12800.00
0005434938325	3487	Economy	12800.00
0005435126749	3487	Economy	12800.00
0005434938320	3487	Economy	12800.00
0005432799722	3487	Economy	12800.00
0005432799709	3487	Economy	12800.00
0005435626352	3487	Economy	11700.00
0005434879080	3487	Economy	11700.00
0005435914696	3487	Economy	11700.00
0005435626367	3487	Economy	11700.00
0005432613898	3487	Economy	11700.00
0005435126761	3487	Economy	11700.00
0005434879086	3487	Economy	11700.00
0005434879108	3487	Economy	11700.00
0005434879116	3487	Economy	11700.00
0005432799715	3487	Economy	11700.00
0005434426895	3487	Economy	11700.00
0005434426880	3487	Economy	11700.00
0005434879061	3487	Economy	11700.00
0005435126732	3487	Economy	11700.00
0005435626345	3487	Economy	11700.00
0005434879125	3487	Economy	11700.00
0005434879112	3487	Economy	11700.00
0005434879075	3487	Economy	11700.00
0005434938328	3487	Economy	11700.00
0005432799716	3487	Economy	11700.00
0005435126733	3487	Economy	11700.00
0005435626368	3487	Economy	11700.00
0005434879113	3487	Economy	11700.00
0005435126744	3487	Economy	11700.00
0005434426883	3487	Economy	11700.00
0005434879071	3487	Economy	11700.00
0005435914698	3487	Economy	11700.00
0005435626346	3487	Economy	11700.00
0005435126737	3487	Economy	11700.00
0005435126763	3487	Economy	11700.00
0005435626370	3487	Economy	11700.00
0005434879131	3487	Economy	11700.00
0005432799708	3487	Economy	11700.00
0005434879106	3487	Economy	11700.00
0005435126734	3487	Economy	11700.00
0005435626356	3487	Economy	11700.00
0005435126748	3487	Economy	11700.00
0005434879084	3487	Economy	11700.00
0005435126758	3487	Economy	11700.00
0005434879114	3487	Economy	11700.00
0005435626350	3487	Economy	11700.00
0005434879077	3487	Economy	11700.00
0005434879128	3487	Economy	11700.00
0005432799728	3487	Economy	11700.00
0005432799721	3487	Economy	11700.00
0005434879143	3487	Economy	11700.00
0005435626357	3487	Economy	11700.00
0005434879087	3487	Economy	11700.00
0005435626364	3487	Economy	11700.00
0005434879085	3487	Economy	11700.00
0005434879136	3487	Economy	11700.00
0005434938331	3487	Economy	11700.00
0005432188639	3487	Economy	11700.00
0005435126764	3487	Economy	11700.00
0005435626342	3487	Economy	11700.00
0005434938319	3487	Economy	11700.00
0005435626341	3487	Economy	11700.00
0005434879151	3487	Economy	11700.00
0005434879135	3487	Economy	11700.00
0005434879090	3487	Economy	11700.00
0005434879094	3487	Economy	11700.00
0005435626355	3487	Economy	11700.00
0005434879120	3487	Economy	11700.00
0005434879093	3487	Economy	11700.00
0005434879122	3487	Economy	11700.00
0005434426874	3487	Economy	11700.00
0005435902741	3487	Economy	11700.00
0005435902682	3487	Economy	11700.00
0005435126735	3487	Economy	11700.00
0005434879145	3487	Economy	11700.00
0005434879073	3487	Economy	11700.00
0005434426497	14566	Business	35000.00
0005435126385	14566	Business	35000.00
0005434878076	14566	Business	35000.00
0005434877890	14566	Business	35000.00
0005434938185	14566	Business	35000.00
0005434878510	14566	Business	35000.00
0005434426543	14566	Business	35000.00
0005434878330	14566	Business	35000.00
0005434878259	14566	Business	35000.00
0005432799570	14566	Business	35000.00
0005432799540	14566	Business	35000.00
0005435902875	14566	Business	35000.00
0005434938165	14566	Business	35000.00
0005435902872	14566	Business	35000.00
0005434878340	14566	Business	35000.00
0005435842333	14566	Business	35000.00
0005435126274	14566	Business	35000.00
0005434938164	14566	Business	35000.00
0005434938147	14566	Business	35000.00
0005434878255	14566	Comfort	19900.00
0005435126452	14566	Comfort	19900.00
0005434426527	14566	Comfort	19900.00
0005434938211	14566	Comfort	19900.00
0005434878329	14566	Comfort	19900.00
0005432799494	14566	Comfort	19900.00
0005434426664	14566	Comfort	19900.00
0005434426659	14566	Comfort	19900.00
0005432059523	14566	Comfort	19900.00
0005434877894	14566	Comfort	19900.00
0005434878388	14566	Comfort	19900.00
0005434878325	14566	Comfort	19900.00
0005435626160	14566	Comfort	19900.00
0005435626162	14566	Comfort	19900.00
0005432799447	14566	Comfort	19900.00
0005435626110	14566	Comfort	19900.00
0005435902873	14566	Comfort	19900.00
0005434878430	14566	Comfort	19900.00
0005434878181	14566	Comfort	19900.00
0005434938272	14566	Comfort	19900.00
0005434426496	14566	Comfort	19900.00
0005434878084	14566	Comfort	19900.00
0005434878125	14566	Comfort	19900.00
0005434878480	14566	Comfort	19900.00
0005435126391	14566	Comfort	19900.00
0005434878441	14566	Comfort	19900.00
0005435126453	14566	Comfort	19900.00
0005434877895	14566	Comfort	19900.00
0005435902864	14566	Comfort	19900.00
0005435902870	14566	Comfort	19900.00
0005434938191	14566	Comfort	19900.00
0005434877873	14566	Economy	11700.00
0005434878235	14566	Economy	11700.00
0005432799542	14566	Comfort	19900.00
0005434878294	14566	Economy	11700.00
0005434878366	14566	Economy	11700.00
0005434878518	14566	Economy	11700.00
0005434426599	14566	Economy	11700.00
0005434878243	14566	Economy	11700.00
0005435902862	14566	Economy	11700.00
0005434878570	14566	Economy	11700.00
0005435126075	14566	Economy	11700.00
0005435126562	14566	Economy	11700.00
0005434878248	14566	Economy	11700.00
0005434878139	14566	Economy	11700.00
0005434878230	14566	Economy	11700.00
0005434426692	14566	Economy	11700.00
0005434878273	14566	Economy	11700.00
0005434938220	14566	Economy	11700.00
0005435126321	14566	Economy	11700.00
0005432799579	14566	Economy	11700.00
0005435126372	14566	Economy	11700.00
0005435126396	14566	Economy	11700.00
0005432799488	14566	Economy	11700.00
0005434878140	14566	Economy	11700.00
0005435902858	14566	Economy	11700.00
0005434426660	14566	Economy	11700.00
0005432611730	14566	Economy	11700.00
0005434878244	14566	Economy	11700.00
0005435126407	14566	Economy	11700.00
0005434878533	14566	Economy	11700.00
0005434878536	14566	Economy	11700.00
0005434426434	14566	Economy	11700.00
0005434878362	14566	Economy	11700.00
0005434426714	14566	Economy	11700.00
0005435126531	14566	Economy	11700.00
0005434878309	14566	Economy	11700.00
0005434938148	14566	Economy	11700.00
0005435126532	14566	Economy	11700.00
0005435126419	14566	Economy	11700.00
0005434426605	14566	Economy	11700.00
0005434426627	14566	Economy	11700.00
0005434878311	14566	Economy	11700.00
0005434878072	14566	Economy	11700.00
0005434878078	14566	Economy	11700.00
0005432799431	14566	Economy	11700.00
0005434938176	14566	Economy	11700.00
0005434878448	14566	Economy	11700.00
0005434878381	14566	Economy	11700.00
0005432799458	14566	Economy	11700.00
0005434878203	14566	Economy	11700.00
0005434938134	14566	Economy	11700.00
0005434878571	14566	Economy	11700.00
0005435902860	14566	Economy	12800.00
0005434426544	14566	Economy	12800.00
0005432799571	14566	Economy	11700.00
0005432799541	14566	Economy	12800.00
0005432799487	14566	Economy	11700.00
0005434878427	14566	Economy	12800.00
0005435126334	14566	Economy	12800.00
0005434878377	14566	Economy	11700.00
0005434878461	14566	Economy	11700.00
0005435126306	14566	Economy	11700.00
0005432799389	14566	Economy	11700.00
0005434878189	14566	Economy	11700.00
0005434426624	14566	Economy	11700.00
0005434877859	14566	Economy	11700.00
0005435126561	14566	Economy	11700.00
0005434878124	14566	Economy	11700.00
0005435842332	14566	Economy	11700.00
0005434426693	14566	Economy	11700.00
0005435126361	14566	Economy	11700.00
0005434426662	14566	Economy	11700.00
0005435126468	14566	Economy	11700.00
0005435626124	14566	Economy	11700.00
0005434938085	14566	Economy	11700.00
0005434877964	14566	Economy	11700.00
0005434878401	14566	Economy	11700.00
0005434426648	14566	Economy	11700.00
0005435126346	14566	Economy	11700.00
0005432799543	14566	Economy	11700.00
0005435126333	14566	Economy	11700.00
0005434878458	14566	Economy	11700.00
0005434878439	14566	Economy	11700.00
0005434426691	14566	Economy	11700.00
0005434878169	14566	Economy	11700.00
0005434878208	14566	Economy	11700.00
0005434878347	14566	Economy	11700.00
0005434878272	14566	Economy	11700.00
0005434878545	14566	Economy	11700.00
0005432611729	14566	Economy	11700.00
0005435902868	14566	Economy	11700.00
0005434878457	14566	Economy	11700.00
0005432799370	14566	Economy	11700.00
0005434877918	14566	Economy	11700.00
0005435126275	14566	Economy	11700.00
0005435126492	14566	Economy	11700.00
0005434426723	14566	Economy	11700.00
0005435126519	14566	Economy	11700.00
0005435126555	14566	Economy	11700.00
0005434878424	14566	Economy	11700.00
0005434426607	14566	Economy	11700.00
0005434878558	14566	Economy	11700.00
0005434878400	14566	Economy	11700.00
0005434877967	14566	Economy	11700.00
0005432799489	14566	Economy	11700.00
0005432799360	14566	Economy	11700.00
0005434877854	14566	Economy	11700.00
0005435126395	14566	Economy	11700.00
0005435126365	14566	Economy	11700.00
0005434938203	14566	Economy	11700.00
0005434426540	14566	Economy	11700.00
0005434878481	14566	Economy	11700.00
0005432799455	14566	Economy	11700.00
0005435126326	14566	Economy	11700.00
0005434878082	14566	Economy	11700.00
0005434878206	14566	Economy	11700.00
0005434878268	14566	Economy	11700.00
0005434878378	14566	Economy	11700.00
0005434877879	14566	Economy	11700.00
0005434878077	14566	Economy	11700.00
0005434878512	14566	Economy	11700.00
0005435902861	14566	Economy	11700.00
0005434878265	14566	Economy	11700.00
0005435126371	14566	Economy	11700.00
0005434878126	14566	Economy	11700.00
0005435902876	14566	Economy	11700.00
0005432799430	14566	Economy	11700.00
0005435126210	14566	Economy	11700.00
0005435126353	14566	Economy	11700.00
0005434878392	14566	Economy	11700.00
0005435902859	14566	Economy	11700.00
0005435902863	14566	Economy	11700.00
0005434878257	14566	Economy	11700.00
0005434938210	14566	Economy	11700.00
0005432799286	14566	Economy	11700.00
0005434878348	14566	Economy	11700.00
0005434938182	14566	Economy	11700.00
0005434938169	14566	Economy	11700.00
0005435902871	14566	Economy	11700.00
0005434878431	14566	Economy	11700.00
0005435626128	14566	Economy	11700.00
0005435126251	14566	Economy	11700.00
0005434878158	14566	Economy	11700.00
0005434877965	14566	Economy	11700.00
0005434878482	14566	Economy	11700.00
0005434426661	14566	Economy	11700.00
0005435126325	14566	Economy	12800.00
0005435626104	14566	Economy	12800.00
0005434878227	14566	Economy	12800.00
0005434878361	14566	Economy	12800.00
0005432799528	14566	Economy	11700.00
0005432799486	14566	Economy	11700.00
0005435126421	14566	Economy	11700.00
0005434878070	14566	Economy	11700.00
0005434938181	14566	Economy	11700.00
0005434877853	14566	Economy	11700.00
0005432799507	14566	Economy	11700.00
0005434878444	14566	Economy	11700.00
0005435126416	14566	Economy	11700.00
0005434878215	14566	Economy	11700.00
0005435126554	14566	Economy	11700.00
0005435842334	14566	Economy	11700.00
0005434877980	14566	Economy	11700.00
0005435126384	14566	Economy	11700.00
0005435126366	14566	Economy	11700.00
0005434877839	14566	Economy	11700.00
0005435902865	14566	Economy	11700.00
0005434878511	14566	Economy	11700.00
0005434426665	14566	Economy	11700.00
0005434426561	14566	Economy	11700.00
0005432799514	14566	Economy	11700.00
0005435126259	14566	Economy	11700.00
0005434877917	14566	Economy	11700.00
0005434878549	14566	Economy	11700.00
0005434878574	14566	Economy	11700.00
0005432799434	14566	Economy	11700.00
0005435126324	14566	Economy	11700.00
0005434878575	14566	Economy	11700.00
0005435126347	14566	Economy	11700.00
0005434878440	14566	Economy	11700.00
0005434878328	14566	Economy	11700.00
0005432059522	14566	Economy	11700.00
0005435626118	14566	Economy	11700.00
0005435126256	14566	Economy	11700.00
0005434878154	14566	Economy	11700.00
0005435902869	14566	Economy	11700.00
0005434878375	14566	Economy	11700.00
0005434426584	14566	Economy	11700.00
0005434878519	14566	Economy	11700.00
0005435626112	14566	Economy	11700.00
0005434878266	14566	Economy	11700.00
0005434426658	14566	Economy	11700.00
0005435126286	14566	Economy	11700.00
0005434878324	14566	Economy	11700.00
0005435126397	14566	Economy	11700.00
0005434426647	14566	Economy	11700.00
0005434426694	14566	Economy	11700.00
0005435126438	14566	Economy	11700.00
0005434878489	14566	Economy	11700.00
0005434426671	14566	Economy	11700.00
0005435626103	14566	Economy	11700.00
0005434426539	14566	Economy	11700.00
0005434878287	14566	Economy	11700.00
0005435902866	14566	Economy	11700.00
0005435126467	14566	Economy	11700.00
0005434938221	14566	Economy	11700.00
0005434878083	14566	Economy	11700.00
0005434878349	14566	Economy	11700.00
0005434426560	14566	Economy	11700.00
0005432799476	14566	Economy	11700.00
0005434878236	14566	Economy	11700.00
0005434878258	14566	Economy	11700.00
0005432799511	14566	Economy	11700.00
0005434878159	14566	Economy	11700.00
0005435626163	14566	Economy	11700.00
0005434877874	14566	Economy	11700.00
0005435126422	14566	Economy	11700.00
0005435126520	14566	Economy	11700.00
0005434878326	14566	Economy	11700.00
0005435126258	14566	Economy	11700.00
0005432607573	14566	Economy	11700.00
0005434878544	14566	Economy	11700.00
0005434878327	14566	Economy	11700.00
0005435126276	14566	Economy	11700.00
0005432799513	14566	Economy	11700.00
0005434878550	14566	Economy	11700.00
0005435626102	14566	Economy	11700.00
0005434938204	14566	Economy	11700.00
0005434426578	14566	Economy	11700.00
0005435126340	14566	Economy	11700.00
0005434878425	14566	Economy	11700.00
0005435626113	14566	Economy	11700.00
0005434877872	14566	Economy	11700.00
0005435902874	14566	Economy	11700.00
0005435902867	14566	Economy	11700.00
0005434325762	3598	Economy	16300.00
0005434312338	3598	Economy	16300.00
0005434325754	3598	Economy	14800.00
0005434325753	3598	Economy	14800.00
0005434325759	3598	Economy	14800.00
0005434325761	3598	Economy	14800.00
0005434325757	3598	Economy	14800.00
0005435889908	3598	Economy	14800.00
0005434325758	3598	Economy	14800.00
0005435889906	3598	Economy	14800.00
0005434325755	3598	Economy	14800.00
0005434312339	3598	Economy	14800.00
0005435889900	3598	Economy	14800.00
0005434325760	3598	Economy	14800.00
0005434325756	3598	Economy	14800.00
0005435889907	3598	Economy	14800.00
0005435889952	15646	Economy	16300.00
0005435889950	15646	Economy	16300.00
0005434325690	15646	Economy	16300.00
0005434325676	15646	Economy	14800.00
0005435889953	15646	Economy	14800.00
0005435889955	15646	Economy	14800.00
0005435889951	15646	Economy	14800.00
0005434325634	15646	Economy	14800.00
0005434325689	15646	Economy	14800.00
0005434325688	15646	Economy	14800.00
0005434325709	15646	Economy	14800.00
0005434325681	15646	Economy	14800.00
0005434325713	15646	Economy	14800.00
0005434325675	15646	Economy	14800.00
0005435889954	15646	Economy	14800.00
0005434325678	15646	Economy	14800.00
0005434325648	15646	Economy	14800.00
0005434325653	15646	Economy	14800.00
0005435957838	662	Economy	4500.00
0005435957841	662	Economy	4500.00
0005435957844	662	Economy	4500.00
0005433420399	662	Economy	4100.00
0005435957836	662	Economy	4100.00
0005435957846	662	Economy	4100.00
0005433420400	662	Economy	4100.00
0005435957837	662	Economy	4100.00
0005435957835	662	Economy	4100.00
0005433420413	662	Economy	4100.00
0005435957840	662	Economy	4100.00
0005435957845	662	Economy	4100.00
0005435957834	662	Economy	4100.00
0005433420384	662	Economy	4100.00
0005435957847	662	Economy	4100.00
0005433420397	662	Economy	4100.00
0005435957842	662	Economy	4100.00
0005435957832	662	Economy	4100.00
0005433420371	662	Economy	4100.00
0005435957833	662	Economy	4100.00
0005433420398	662	Economy	4100.00
0005435957843	662	Economy	4100.00
0005435957839	662	Economy	4100.00
0005435957748	15200	Economy	4500.00
0005433420480	15200	Economy	4500.00
0005435957665	15200	Economy	4500.00
0005433420478	15200	Economy	4100.00
0005433420482	15200	Economy	4100.00
0005433420481	15200	Economy	4100.00
0005435957734	15200	Economy	4100.00
0005435957691	15200	Economy	4100.00
0005435957738	15200	Economy	4100.00
0005435957726	15200	Economy	4100.00
0005435957725	15200	Economy	4100.00
0005433420484	15200	Economy	4100.00
0005433420479	15200	Economy	4100.00
0005433420483	15200	Economy	4100.00
0005435957724	15200	Economy	4100.00
0005435957731	15200	Economy	4100.00
0005435957715	15200	Economy	4100.00
0005435629417	8860	Economy	10400.00
0005435629415	8860	Economy	10400.00
0005434247140	8860	Economy	10400.00
0005435629416	8860	Economy	10400.00
0005434247172	16003	Economy	10400.00
0005435629404	16003	Economy	10400.00
0005435629408	16003	Economy	10400.00
0005435629407	16003	Economy	10400.00
0005435163226	29521	Economy	13400.00
0005435163209	29521	Economy	13400.00
0005435163207	29521	Economy	13400.00
0005435933488	29521	Economy	13400.00
0005435163215	29521	Economy	12200.00
0005435933485	29521	Economy	12200.00
0005435163225	29521	Economy	12200.00
0005435163223	29521	Economy	12200.00
0005435163232	29521	Economy	12200.00
0005435933487	29521	Economy	12200.00
0005435163213	29521	Economy	12200.00
0005435163212	29521	Economy	12200.00
0005435163240	29521	Economy	12200.00
0005435933486	29521	Economy	12200.00
0005435163231	29521	Economy	12200.00
0005435163208	29521	Economy	12200.00
0005435163210	29521	Economy	12200.00
0005435933483	29521	Economy	12200.00
0005435933479	29521	Economy	12200.00
0005435933481	29521	Economy	12200.00
0005435933478	29521	Economy	12200.00
0005435163239	29521	Economy	12200.00
0005435163238	29521	Economy	12200.00
0005435933484	29521	Economy	12200.00
0005435163237	29521	Economy	12200.00
0005435933480	29521	Economy	12200.00
0005435163216	29521	Economy	12200.00
0005435163196	29521	Economy	12200.00
0005435933482	29521	Economy	12200.00
0005435163228	29521	Economy	12200.00
0005435163219	29521	Economy	12200.00
0005435163227	29521	Economy	12200.00
0005435797598	2845	Business	12600.00
0005433404835	2845	Business	12600.00
0005433404798	2845	Business	12600.00
0005435797606	2845	Business	12600.00
0005435797610	2845	Business	12600.00
0005435797599	2845	Economy	4200.00
0005435797602	2845	Economy	4200.00
0005435797609	2845	Economy	4200.00
0005435797611	2845	Economy	4200.00
0005435797604	2845	Economy	4200.00
0005435797607	2845	Economy	4200.00
0005433404792	2845	Economy	4200.00
0005435797601	2845	Economy	4200.00
0005435797600	2845	Economy	4200.00
0005435797605	2845	Economy	4200.00
0005435797603	2845	Economy	4200.00
0005435797612	2845	Economy	4200.00
0005433404827	2845	Economy	4200.00
0005435797608	2845	Economy	4200.00
0005433404879	29302	Business	12600.00
0005435797514	29302	Business	12600.00
0005435797518	29302	Economy	4200.00
0005435797524	29302	Economy	4200.00
0005433404881	29302	Economy	4600.00
0005435797506	29302	Economy	4200.00
0005433404880	29302	Economy	4200.00
0005433404882	29302	Economy	4200.00
0005435797523	29302	Economy	4200.00
0005433404875	29302	Economy	4200.00
0005435797479	29302	Economy	4200.00
0005435797522	29302	Economy	4200.00
0005433404876	29302	Economy	4200.00
0005433404877	29302	Economy	4200.00
0005435797567	29302	Economy	4200.00
0005435797487	29302	Economy	4200.00
0005433404878	29302	Economy	4200.00
0005435797507	29302	Economy	4200.00
0005435797486	29302	Economy	4200.00
0005435376359	5834	Economy	6800.00
0005435376360	5834	Economy	6800.00
0005434948098	5826	Economy	6800.00
0005434948101	5826	Economy	6800.00
0005434948097	5826	Economy	6800.00
0005434948095	5826	Economy	6800.00
0005434948094	5826	Economy	6800.00
0005434948096	5826	Economy	6800.00
0005434948099	5826	Economy	6800.00
0005434948100	5826	Economy	6800.00
0005434948004	16320	Economy	6800.00
0005434948013	16320	Economy	6800.00
0005434947994	16320	Economy	6800.00
0005434948017	16320	Economy	6800.00
0005434948042	16320	Economy	6800.00
0005434948001	16320	Economy	6800.00
0005434948023	16320	Economy	6800.00
0005434948028	16320	Economy	6800.00
0005434948018	16320	Economy	6800.00
0005434947993	16320	Economy	6800.00
0005434948041	16320	Economy	6800.00
0005434948027	16320	Economy	6800.00
0005433961426	6871	Business	21400.00
0005433961405	6871	Business	21400.00
0005433961407	6871	Business	21400.00
0005433961403	6871	Business	21400.00
0005433961420	6871	Business	21400.00
0005433961423	6871	Economy	7100.00
0005433961408	6871	Economy	7100.00
0005433961410	6871	Economy	7100.00
0005433961406	6871	Economy	7800.00
0005433961386	6871	Economy	7800.00
0005433961427	6871	Economy	7100.00
0005433961402	6871	Economy	7100.00
0005433961401	6871	Economy	7100.00
0005433961388	6871	Economy	7100.00
0005433961404	6871	Economy	7100.00
0005433961385	6871	Economy	7100.00
0005433961394	6871	Economy	7100.00
0005433961387	6871	Economy	7100.00
0005433961419	6871	Economy	7100.00
0005433961398	6871	Economy	7100.00
0005433961428	6871	Economy	7100.00
0005433961392	6871	Economy	7100.00
0005433961416	6871	Economy	7100.00
0005433961425	6871	Economy	7100.00
0005433961396	6871	Economy	7100.00
0005433961413	6871	Economy	7100.00
0005433961414	6871	Economy	7100.00
0005433961411	6871	Economy	7100.00
0005433961391	6871	Economy	7100.00
0005433961389	6871	Economy	7100.00
0005433961390	6871	Economy	7100.00
0005433961412	6871	Economy	7100.00
0005433961417	6871	Economy	7100.00
0005433961415	6871	Economy	7100.00
0005433961424	6871	Economy	7100.00
0005433961393	6871	Economy	7100.00
0005433961397	6871	Economy	7100.00
0005433961395	6871	Economy	7100.00
0005433961421	6871	Economy	7100.00
0005433961422	6871	Economy	7100.00
0005433961418	6871	Economy	7100.00
0005433961399	6871	Economy	7100.00
0005433961409	6871	Economy	7100.00
0005433961400	6871	Economy	7100.00
0005433960666	25712	Business	21400.00
0005433960711	25712	Business	21400.00
0005433960487	25712	Business	21400.00
0005433960745	25712	Business	21400.00
0005433960845	25712	Business	21400.00
0005433960610	25712	Business	21400.00
0005433960581	25712	Economy	7100.00
0005433960593	25712	Economy	7100.00
0005433960673	25712	Economy	7100.00
0005433960813	25712	Economy	7800.00
0005433960784	25712	Economy	7800.00
0005433960504	25712	Economy	7100.00
0005433960702	25712	Economy	7100.00
0005433960664	25712	Economy	7100.00
0005433960503	25712	Economy	7100.00
0005433960516	25712	Economy	7100.00
0005433960798	25712	Economy	7100.00
0005433960667	25712	Economy	7100.00
0005433960594	25712	Economy	7100.00
0005433960764	25712	Economy	7100.00
0005433960839	25712	Economy	7100.00
0005433960782	25712	Economy	7100.00
0005433960763	25712	Economy	7100.00
0005433960841	25712	Economy	7100.00
0005433960844	25712	Economy	7100.00
0005433960753	25712	Economy	7100.00
0005433960665	25712	Economy	7100.00
0005433960703	25712	Economy	7100.00
0005433960612	25712	Economy	7100.00
0005433960747	25712	Economy	7100.00
0005433960651	25712	Economy	7100.00
0005433960797	25712	Economy	7100.00
0005433960766	25712	Economy	7100.00
0005433960829	25712	Economy	7100.00
0005433960850	25712	Economy	7100.00
0005433960686	25712	Economy	7100.00
0005433960754	25712	Economy	7100.00
0005433960828	25712	Economy	7100.00
0005433960409	25712	Economy	7100.00
0005433960765	25712	Economy	7100.00
0005433960685	25712	Economy	7100.00
0005433960684	25712	Economy	7100.00
0005433960834	25712	Economy	7100.00
0005433960650	25712	Economy	7100.00
0005433960611	25712	Economy	7100.00
0005433960808	25712	Economy	7100.00
0005435082774	24550	Economy	3900.00
0005435082768	24550	Economy	3900.00
0005435082790	24550	Economy	3900.00
0005435082823	24550	Economy	3900.00
0005435082798	24550	Economy	3900.00
0005435082791	24550	Economy	3900.00
0005435082775	24550	Economy	3900.00
0005435082824	24550	Economy	3900.00
0005435082792	24550	Economy	3900.00
0005435082797	24550	Economy	3900.00
0005435082855	26147	Economy	3900.00
0005435082853	26147	Economy	3900.00
0005435082852	26147	Economy	3900.00
0005435082856	26147	Economy	3900.00
0005435082851	26147	Economy	3900.00
0005435082854	26147	Economy	3900.00
0005434245240	5224	Business	18000.00
0005434245256	5224	Business	18000.00
0005434245239	5224	Business	18000.00
0005432166931	5224	Business	18000.00
0005434245257	5224	Business	18000.00
0005434245262	5224	Business	18000.00
0005434245261	5224	Economy	6600.00
0005434245247	5224	Economy	6000.00
0005434245253	5224	Economy	6000.00
0005434245251	5224	Economy	6000.00
0005434245244	5224	Economy	6000.00
0005434245243	5224	Economy	6000.00
0005434245265	5224	Economy	6000.00
0005432166932	5224	Economy	6000.00
0005434245248	5224	Economy	6000.00
0005434245266	5224	Economy	6000.00
0005434245264	5224	Economy	6000.00
0005434245254	5224	Economy	6000.00
0005434245249	5224	Economy	6600.00
0005434245263	5224	Economy	6000.00
0005434245242	5224	Economy	6600.00
0005435286640	5224	Economy	6600.00
0005434245246	5224	Economy	6000.00
0005434245259	5224	Economy	6000.00
0005434245241	5224	Economy	6000.00
0005434245260	5224	Economy	6000.00
0005435286638	5224	Economy	6000.00
0005435286642	5224	Economy	6000.00
0005434245245	5224	Economy	6000.00
0005434245238	5224	Economy	6000.00
0005433534496	5224	Economy	6000.00
0005432166930	5224	Economy	6000.00
0005434245255	5224	Economy	6000.00
0005434245250	5224	Economy	6000.00
0005434245252	5224	Economy	6000.00
0005433534495	5224	Economy	6000.00
0005434245258	5224	Economy	6000.00
0005433615343	5225	Business	18000.00
0005433785295	5225	Business	18000.00
0005433615385	5225	Business	18000.00
0005432105999	5225	Business	18000.00
0005433615366	5225	Business	18000.00
0005433615372	5225	Business	18000.00
0005433615377	5225	Business	18000.00
0005433615345	5225	Business	18000.00
0005433615348	5225	Business	18000.00
0005432106004	5225	Business	18000.00
0005432106033	5225	Business	18000.00
0005432105988	5225	Business	18000.00
0005433615405	5225	Business	18000.00
0005432145133	5225	Business	18000.00
0005433615353	5225	Business	18000.00
0005432106013	5225	Business	18000.00
0005433785275	5225	Business	18000.00
0005433615382	5225	Business	18000.00
0005432106032	5225	Business	18000.00
0005433615363	5225	Business	18000.00
0005433615398	5225	Business	18000.00
0005433615351	5225	Business	18000.00
0005433615406	5225	Business	18000.00
0005432106012	5225	Business	18000.00
0005432106016	5225	Business	18000.00
0005433615386	5225	Business	18000.00
0005433615354	5225	Business	18000.00
0005432106022	5225	Business	18000.00
0005433785286	5225	Economy	6600.00
0005432106002	5225	Economy	6600.00
0005433785291	5225	Economy	6600.00
0005433615338	5225	Economy	6600.00
0005433785272	5225	Economy	6600.00
0005433785271	5225	Economy	6600.00
0005433785289	5225	Economy	6000.00
0005433615402	5225	Economy	6000.00
0005433615337	5225	Economy	6000.00
0005433615357	5225	Economy	6000.00
0005432106005	5225	Economy	6000.00
0005433615356	5225	Economy	6000.00
0005433615339	5225	Economy	6000.00
0005432105995	5225	Economy	6000.00
0005433615369	5225	Economy	6000.00
0005432106026	5225	Economy	6000.00
0005433785277	5225	Economy	6000.00
0005433615381	5225	Economy	6000.00
0005433785261	5225	Economy	6000.00
0005432145131	5225	Economy	6000.00
0005433615352	5225	Economy	6000.00
0005432665293	5225	Economy	6000.00
0005433615376	5225	Economy	6000.00
0005432106010	5225	Economy	6000.00
0005432105994	5225	Economy	6000.00
0005433785288	5225	Economy	6000.00
0005432106000	5225	Economy	6000.00
0005433615400	5225	Economy	6000.00
0005432106017	5225	Economy	6000.00
0005433615383	5225	Economy	6000.00
0005433785263	5225	Economy	6000.00
0005433785269	5225	Economy	6000.00
0005433785264	5225	Economy	6000.00
0005433615370	5225	Economy	6000.00
0005433615364	5225	Economy	6000.00
0005432145130	5225	Economy	6000.00
0005432106003	5225	Economy	6000.00
0005433785260	5225	Economy	6000.00
0005433615342	5225	Economy	6000.00
0005433615368	5225	Economy	6000.00
0005432145132	5225	Economy	6000.00
0005432105998	5225	Economy	6000.00
0005432106019	5225	Economy	6000.00
0005433785294	5225	Economy	6000.00
0005433615365	5225	Economy	6000.00
0005433615380	5225	Economy	6000.00
0005433615334	5225	Economy	6000.00
0005433615392	5225	Economy	6000.00
0005433615344	5225	Economy	6000.00
0005432106021	5225	Economy	6000.00
0005432105992	5225	Economy	6000.00
0005432106014	5225	Economy	6000.00
0005433785273	5225	Economy	6000.00
0005432105990	5225	Economy	6000.00
0005432106011	5225	Economy	6000.00
0005432106015	5225	Economy	6000.00
0005432106028	5225	Economy	6000.00
0005432106009	5225	Economy	6000.00
0005433615397	5225	Economy	6000.00
0005432105986	5225	Economy	6000.00
0005433785297	5225	Economy	6000.00
0005432105991	5225	Economy	6000.00
0005433615361	5225	Economy	6000.00
0005432106018	5225	Economy	6000.00
0005432105993	5225	Economy	6000.00
0005432106027	5225	Economy	6000.00
0005432105996	5225	Economy	6600.00
0005433615390	5225	Economy	6600.00
0005432105987	5225	Economy	6600.00
0005433615359	5225	Economy	6600.00
0005433785285	5225	Economy	6600.00
0005433785268	5225	Economy	6000.00
0005432106001	5225	Economy	6000.00
0005433615367	5225	Economy	6000.00
0005433615335	5225	Economy	6000.00
0005433785280	5225	Economy	6600.00
0005433785281	5225	Economy	6000.00
0005433785290	5225	Economy	6000.00
0005432665294	5225	Economy	6000.00
0005433785292	5225	Economy	6000.00
0005433785283	5225	Economy	6000.00
0005433615333	5225	Economy	6000.00
0005433785296	5225	Economy	6000.00
0005433615393	5225	Economy	6000.00
0005433615375	5225	Economy	6000.00
0005433615341	5225	Economy	6000.00
0005433615399	5225	Economy	6000.00
0005432106030	5225	Economy	6000.00
0005433615389	5225	Economy	6000.00
0005432105989	5225	Economy	6000.00
0005432106024	5225	Economy	6000.00
0005432666409	5225	Economy	6000.00
0005433785293	5225	Economy	6000.00
0005433615394	5225	Economy	6000.00
0005433615379	5225	Economy	6000.00
0005432106006	5225	Economy	6000.00
0005433615384	5225	Economy	6000.00
0005433615362	5225	Economy	6000.00
0005433615346	5225	Economy	6000.00
0005432106023	5225	Economy	6000.00
0005432105997	5225	Economy	6000.00
0005433785270	5225	Economy	6000.00
0005433785276	5225	Economy	6000.00
0005433615388	5225	Economy	6000.00
0005433615396	5225	Economy	6000.00
0005433615371	5225	Economy	6000.00
0005433785282	5225	Economy	6000.00
0005432666408	5225	Economy	6000.00
0005433615378	5225	Economy	6000.00
0005432106008	5225	Economy	6000.00
0005433785262	5225	Economy	6000.00
0005433615401	5225	Economy	6000.00
0005433785279	5225	Economy	6000.00
0005433785274	5225	Economy	6000.00
0005433615358	5225	Economy	6000.00
0005433615350	5225	Economy	6000.00
0005433615391	5225	Economy	6000.00
0005433785284	5225	Economy	6000.00
0005433615360	5225	Economy	6000.00
0005433615340	5225	Economy	6000.00
0005432667473	5225	Economy	6000.00
0005433785266	5225	Economy	6000.00
0005433615395	5225	Economy	6000.00
0005433615355	5225	Economy	6000.00
0005432106007	5225	Economy	6000.00
0005432106029	5225	Economy	6000.00
0005433785265	5225	Economy	6000.00
0005433615404	5225	Economy	6000.00
0005433615336	5225	Economy	6000.00
0005433785267	5225	Economy	6000.00
0005432106020	5225	Economy	6000.00
0005433615387	5225	Economy	6000.00
0005432106031	5225	Economy	6000.00
0005433615373	5225	Economy	6000.00
0005433615374	5225	Economy	6000.00
0005432106025	5225	Economy	6000.00
0005433785287	5225	Economy	6000.00
0005433615349	5225	Economy	6000.00
0005433615347	5225	Economy	6000.00
0005433615403	5225	Economy	6000.00
0005433785278	5225	Economy	6000.00
0005432105985	5225	Economy	6000.00
0005434265371	5229	Business	18000.00
0005432335968	5229	Business	18000.00
0005435006982	5229	Business	18000.00
0005433688801	5229	Business	18000.00
0005434229589	5229	Business	18000.00
0005434229586	5229	Business	18000.00
0005435007111	5229	Business	18000.00
0005433688812	5229	Business	18000.00
0005434149842	5229	Business	18000.00
0005434265378	5229	Business	18000.00
0005434265369	5229	Business	18000.00
0005435007091	5229	Business	18000.00
0005435007029	5229	Business	18000.00
0005434311222	5229	Business	18000.00
0005435007049	5229	Business	18000.00
0005434229584	5229	Business	18000.00
0005434229581	5229	Business	18000.00
0005434265388	5229	Business	18000.00
0005432336039	5229	Business	18000.00
0005435007030	5229	Business	18000.00
0005434173555	5229	Business	18000.00
0005433688800	5229	Business	18000.00
0005432336020	5229	Economy	6600.00
0005434149837	5229	Economy	6600.00
0005435007136	5229	Economy	6600.00
0005432336060	5229	Economy	6000.00
0005434265386	5229	Economy	6000.00
0005435006987	5229	Economy	6000.00
0005435007125	5229	Economy	6000.00
0005434265377	5229	Economy	6000.00
0005435007032	5229	Economy	6000.00
0005434149841	5229	Economy	6000.00
0005433815394	5229	Economy	6000.00
0005434265382	5229	Economy	6000.00
0005434265368	5229	Economy	6000.00
0005434229588	5229	Economy	6000.00
0005434229572	5229	Economy	6000.00
0005434149833	5229	Economy	6000.00
0005432336094	5229	Economy	6000.00
0005434265383	5229	Economy	6000.00
0005434149838	5229	Economy	6000.00
0005433815393	5229	Economy	6000.00
0005434229567	5229	Economy	6000.00
0005434149839	5229	Economy	6000.00
0005434229568	5229	Economy	6000.00
0005434173557	5229	Economy	6000.00
0005434229577	5229	Economy	6000.00
0005435006983	5229	Economy	6000.00
0005434265372	5229	Economy	6000.00
0005435007015	5229	Economy	6000.00
0005434229576	5229	Economy	6000.00
0005434265384	5229	Economy	6000.00
0005434229580	5229	Economy	6000.00
0005434229590	5229	Economy	6000.00
0005432336056	5229	Economy	6000.00
0005435007027	5229	Economy	6000.00
0005434265370	5229	Economy	6000.00
0005434265387	5229	Economy	6000.00
0005434173556	5229	Economy	6000.00
0005433815395	5229	Economy	6000.00
0005433815387	5229	Economy	6000.00
0005434311217	5229	Economy	6000.00
0005432336025	5229	Economy	6000.00
0005432336034	5229	Economy	6000.00
0005435007079	5229	Economy	6000.00
0005434229585	5229	Economy	6000.00
0005434265374	5229	Economy	6000.00
0005434149834	5229	Economy	6000.00
0005432336093	5229	Economy	6000.00
0005434149835	5229	Economy	6000.00
0005434229578	5229	Economy	6000.00
0005434265373	5229	Economy	6000.00
0005433815384	5229	Economy	6000.00
0005433815385	5229	Economy	6000.00
0005435007070	5229	Economy	6600.00
0005435006981	5229	Economy	6600.00
0005434265381	5229	Economy	6600.00
0005435007072	5229	Economy	6000.00
0005434265379	5229	Economy	6000.00
0005434229575	5229	Economy	6000.00
0005434312314	5229	Economy	6600.00
0005434173558	5229	Economy	6000.00
0005434265367	5229	Economy	6000.00
0005434229574	5229	Economy	6000.00
0005432335967	5229	Economy	6000.00
0005434229583	5229	Economy	6000.00
0005434229573	5229	Economy	6000.00
0005434229582	5229	Economy	6000.00
0005434265364	5229	Economy	6000.00
0005433815365	5229	Economy	6000.00
0005434265365	5229	Economy	6000.00
0005433815392	5229	Economy	6000.00
0005435007038	5229	Economy	6000.00
0005435007047	5229	Economy	6000.00
0005434229570	5229	Economy	6000.00
0005435007068	5229	Economy	6000.00
0005435007135	5229	Economy	6000.00
0005434265376	5229	Economy	6000.00
0005434265375	5229	Economy	6000.00
0005435007037	5229	Economy	6000.00
0005434312318	5229	Economy	6000.00
0005432336026	5229	Economy	6000.00
0005434149844	5229	Economy	6000.00
0005434265366	5229	Economy	6000.00
0005434173559	5229	Economy	6000.00
0005434229569	5229	Economy	6000.00
0005435006970	5229	Economy	6000.00
0005435007069	5229	Economy	6000.00
0005435007014	5229	Economy	6000.00
0005432336055	5229	Economy	6000.00
0005432336029	5229	Economy	6000.00
0005433688799	5229	Economy	6000.00
0005433688811	5229	Economy	6000.00
0005433815380	5229	Economy	6000.00
0005435007048	5229	Economy	6000.00
0005434265380	5229	Economy	6000.00
0005434149843	5229	Economy	6000.00
0005434229587	5229	Economy	6000.00
0005432336057	5229	Economy	6000.00
0005434229571	5229	Economy	6000.00
0005435007028	5229	Economy	6000.00
0005435007080	5229	Economy	6000.00
0005434149840	5229	Economy	6000.00
0005433685508	5229	Economy	6000.00
0005433685507	5229	Economy	6000.00
0005435007050	5229	Economy	6000.00
0005435007039	5229	Economy	6000.00
0005434149836	5229	Economy	6000.00
0005432335984	5229	Economy	6000.00
0005434265385	5229	Economy	6000.00
0005434229579	5229	Economy	6000.00
0005433815388	5229	Economy	6000.00
0005435007071	5229	Economy	6000.00
0005433784849	8625	Business	18000.00
0005434245206	8625	Business	18000.00
0005435269812	8625	Business	18000.00
0005433784912	8625	Business	18000.00
0005434244978	8625	Business	18000.00
0005433784824	8625	Business	18000.00
0005434245186	8625	Business	18000.00
0005433784825	8625	Business	18000.00
0005433784855	8625	Business	18000.00
0005433784985	8625	Business	18000.00
0005432663034	8625	Business	18000.00
0005433784883	8625	Business	18000.00
0005433784882	8625	Business	18000.00
0005433784848	8625	Economy	6600.00
0005433784867	8625	Business	18000.00
0005433784805	8625	Economy	6600.00
0005433784881	8625	Economy	6000.00
0005435269811	8625	Economy	6000.00
0005434245207	8625	Economy	6000.00
0005433784847	8625	Economy	6000.00
0005433785073	8625	Economy	6000.00
0005435269804	8625	Economy	6000.00
0005433784856	8625	Economy	6000.00
0005435269803	8625	Economy	6000.00
0005433784861	8625	Economy	6000.00
0005433784804	8625	Economy	6000.00
0005435269808	8625	Economy	6000.00
0005434245022	8625	Economy	6000.00
0005433784868	8625	Economy	6000.00
0005434244915	8625	Economy	6000.00
0005434245080	8625	Economy	6000.00
0005433784981	8625	Economy	6000.00
0005432666383	8625	Economy	6000.00
0005434244988	8625	Economy	6000.00
0005435269809	8625	Economy	6000.00
0005433784850	8625	Economy	6000.00
0005433784886	8625	Economy	6000.00
0005433784901	8625	Economy	6000.00
0005433785029	8625	Economy	6000.00
0005434245079	8625	Economy	6000.00
0005433784896	8625	Economy	6000.00
0005434244944	8625	Economy	6000.00
0005433785025	8625	Economy	6000.00
0005433785163	8625	Economy	6000.00
0005432659702	8625	Economy	6000.00
0005434245065	8625	Economy	6000.00
0005434245070	8625	Economy	6000.00
0005434244979	8625	Economy	6600.00
0005432659699	8625	Economy	6600.00
0005433784892	8625	Economy	6000.00
0005434244987	8625	Economy	6000.00
0005434244977	8625	Economy	6000.00
0005434245187	8625	Economy	6600.00
0005433785030	8625	Economy	6000.00
0005434245205	8625	Economy	6000.00
0005433785090	8625	Economy	6000.00
0005435269805	8625	Economy	6000.00
0005433784893	8625	Economy	6000.00
0005433785072	8625	Economy	6000.00
0005433784954	8625	Economy	6000.00
0005432666386	8625	Economy	6000.00
0005434245071	8625	Economy	6000.00
0005433785172	8625	Economy	6000.00
0005433784860	8625	Economy	6000.00
0005434245041	8625	Economy	6000.00
0005433785052	8625	Economy	6000.00
0005433784869	8625	Economy	6000.00
0005433784990	8625	Economy	6000.00
0005434245066	8625	Economy	6000.00
0005433785071	8625	Economy	6000.00
0005433784923	8625	Economy	6000.00
0005434245064	8625	Economy	6000.00
0005433784951	8625	Economy	6000.00
0005432663039	8625	Economy	6000.00
0005433784857	8625	Economy	6000.00
0005435269806	8625	Economy	6000.00
0005435269807	8625	Economy	6000.00
0005433785059	8625	Economy	6000.00
0005432666384	8625	Economy	6000.00
0005433784974	8625	Economy	6000.00
0005435269802	8625	Economy	6000.00
0005433784996	8625	Economy	6000.00
0005435269810	8625	Economy	6000.00
0005433784908	8625	Economy	6000.00
0005433614876	8626	Business	18000.00
0005433614836	8626	Business	18000.00
0005433614834	8626	Business	18000.00
0005433614556	8626	Business	18000.00
0005433614774	8626	Business	18000.00
0005433614816	8626	Business	18000.00
0005433614517	8626	Business	18000.00
0005433614428	8626	Business	18000.00
0005433614792	8626	Business	18000.00
0005433614516	8626	Business	18000.00
0005433614861	8626	Economy	6600.00
0005433614525	8626	Economy	6000.00
0005433614855	8626	Economy	6000.00
0005433614372	8626	Economy	6000.00
0005433614627	8626	Economy	6000.00
0005433614553	8626	Economy	6000.00
0005433614557	8626	Economy	6000.00
0005433614460	8626	Economy	6000.00
0005433614436	8626	Economy	6000.00
0005433614688	8626	Economy	6000.00
0005433614708	8626	Economy	6000.00
0005433614599	8626	Economy	6000.00
0005433614687	8626	Economy	6000.00
0005433614658	8626	Economy	6000.00
0005433614620	8626	Economy	6000.00
0005433614586	8626	Economy	6000.00
0005433614968	8626	Economy	6000.00
0005433614621	8626	Economy	6000.00
0005433614504	8626	Economy	6000.00
0005433614579	8626	Economy	6000.00
0005433614879	8626	Economy	6000.00
0005433614580	8626	Economy	6000.00
0005433614491	8626	Economy	6000.00
0005433614695	8626	Economy	6000.00
0005433614747	8626	Economy	6000.00
0005433614492	8626	Economy	6000.00
0005433614392	8626	Economy	6000.00
0005433614339	8626	Economy	6000.00
0005433614564	8626	Economy	6000.00
0005433614583	8626	Economy	6600.00
0005433614734	8626	Economy	6000.00
0005433614606	8626	Economy	6600.00
0005433614615	8626	Economy	6000.00
0005433614486	8626	Economy	6000.00
0005433614770	8626	Economy	6000.00
0005433614587	8626	Economy	6000.00
0005433614614	8626	Economy	6000.00
0005433614490	8626	Economy	6000.00
0005433614605	8626	Economy	6000.00
0005433614817	8626	Economy	6000.00
0005433614624	8626	Economy	6000.00
0005433614366	8626	Economy	6000.00
0005433614738	8626	Economy	6000.00
0005433614795	8626	Economy	6000.00
0005433614596	8626	Economy	6000.00
0005433614485	8626	Economy	6000.00
0005433614791	8626	Economy	6000.00
0005433614796	8626	Economy	6000.00
0005433614533	8626	Economy	6000.00
0005433614493	8626	Economy	6000.00
0005433614854	8626	Economy	6000.00
0005433614771	8626	Economy	6000.00
0005433614563	8626	Economy	6000.00
0005433614678	8626	Economy	6000.00
0005433614623	8626	Economy	6000.00
0005433614699	8626	Economy	6000.00
0005433614790	8626	Economy	6000.00
0005432035196	8627	Business	18000.00
0005434265196	8627	Business	18000.00
0005435007242	8627	Business	18000.00
0005433534518	8627	Business	18000.00
0005434265219	8627	Business	18000.00
0005435007244	8627	Business	18000.00
0005432336148	8627	Business	18000.00
0005432035217	8627	Business	18000.00
0005434229450	8627	Business	18000.00
0005434229474	8627	Business	18000.00
0005435007230	8627	Business	18000.00
0005432336147	8627	Business	18000.00
0005434265159	8627	Business	18000.00
0005432336149	8627	Business	18000.00
0005434229381	8627	Business	18000.00
0005433815429	8627	Business	18000.00
0005432336146	8627	Business	18000.00
0005434149704	8627	Business	18000.00
0005432047585	8627	Business	18000.00
0005432035206	8627	Business	18000.00
0005432035203	8627	Business	18000.00
0005432336139	8627	Business	18000.00
0005435007243	8627	Business	18000.00
0005433815433	8627	Business	18000.00
0005435286668	8627	Business	18000.00
0005433815432	8627	Business	18000.00
0005434265226	8627	Economy	6600.00
0005432035213	8627	Economy	6600.00
0005434229390	8627	Economy	6600.00
0005433689930	8627	Economy	6600.00
0005434265038	8627	Economy	6000.00
0005433690944	8627	Economy	6600.00
0005432035194	8627	Economy	6000.00
0005434265123	8627	Economy	6000.00
0005432035208	8627	Economy	6000.00
0005434229308	8627	Economy	6000.00
0005432336143	8627	Economy	6000.00
0005434265115	8627	Economy	6000.00
0005434229241	8627	Economy	6000.00
0005434265187	8627	Economy	6000.00
0005432035210	8627	Economy	6000.00
0005434265222	8627	Economy	6000.00
0005432035200	8627	Economy	6000.00
0005435007238	8627	Economy	6000.00
0005432035198	8627	Economy	6000.00
0005434265225	8627	Economy	6000.00
0005434265201	8627	Economy	6000.00
0005433688828	8627	Economy	6000.00
0005434311239	8627	Economy	6000.00
0005435007228	8627	Economy	6000.00
0005434229224	8627	Economy	6000.00
0005433689932	8627	Economy	6000.00
0005434173509	8627	Economy	6000.00
0005435007247	8627	Economy	6000.00
0005435007252	8627	Economy	6000.00
0005432336150	8627	Economy	6000.00
0005434149681	8627	Economy	6000.00
0005432035201	8627	Economy	6000.00
0005433815430	8627	Economy	6000.00
0005434149756	8627	Economy	6000.00
0005434149744	8627	Economy	6000.00
0005433690943	8627	Economy	6000.00
0005435007235	8627	Economy	6000.00
0005434229409	8627	Economy	6000.00
0005434265188	8627	Economy	6000.00
0005432035202	8627	Economy	6000.00
0005434173519	8627	Economy	6000.00
0005434265184	8627	Economy	6000.00
0005435007249	8627	Economy	6000.00
0005432035212	8627	Economy	6000.00
0005434149793	8627	Economy	6000.00
0005432336141	8627	Economy	6000.00
0005434265221	8627	Economy	6000.00
0005432035193	8627	Economy	6000.00
0005432035195	8627	Economy	6000.00
0005434229382	8627	Economy	6000.00
0005434265185	8627	Economy	6000.00
0005432336142	8627	Economy	6000.00
0005432336145	8627	Economy	6000.00
0005435007246	8627	Economy	6000.00
0005434149757	8627	Economy	6000.00
0005433688829	8627	Economy	6000.00
0005435007245	8627	Economy	6000.00
0005434265198	8627	Economy	6000.00
0005435007240	8627	Economy	6000.00
0005434229420	8627	Economy	6000.00
0005434149758	8627	Economy	6000.00
0005432035204	8627	Economy	6000.00
0005432035192	8627	Economy	6600.00
0005432035216	8627	Economy	6600.00
0005432336144	8627	Economy	6600.00
0005435007234	8627	Economy	6600.00
0005435007237	8627	Economy	6600.00
0005432035218	8627	Economy	6000.00
0005435007241	8627	Economy	6000.00
0005435007229	8627	Economy	6000.00
0005435007227	8627	Economy	6000.00
0005432035205	8627	Economy	6000.00
0005433689933	8627	Economy	6000.00
0005434149755	8627	Economy	6000.00
0005435286669	8627	Economy	6000.00
0005434311238	8627	Economy	6000.00
0005432035214	8627	Economy	6000.00
0005434149731	8627	Economy	6000.00
0005432047586	8627	Economy	6000.00
0005435007231	8627	Economy	6000.00
0005434229223	8627	Economy	6000.00
0005434229242	8627	Economy	6000.00
0005435007248	8627	Economy	6000.00
0005432035211	8627	Economy	6000.00
0005432035197	8627	Economy	6000.00
0005434265180	8627	Economy	6000.00
0005434229264	8627	Economy	6000.00
0005434173510	8627	Economy	6000.00
0005434229370	8627	Economy	6000.00
0005435007239	8627	Economy	6000.00
0005433815431	8627	Economy	6000.00
0005432035207	8627	Economy	6000.00
0005432336140	8627	Economy	6000.00
0005434173520	8627	Economy	6000.00
0005434265171	8627	Economy	6000.00
0005433689931	8627	Economy	6000.00
0005434149724	8627	Economy	6000.00
0005435007250	8627	Economy	6000.00
0005434229294	8627	Economy	6000.00
0005432035199	8627	Economy	6000.00
0005434149751	8627	Economy	6000.00
0005434229293	8627	Economy	6000.00
0005434265217	8627	Economy	6000.00
0005434229303	8627	Economy	6000.00
0005432336151	8627	Economy	6000.00
0005434265150	8627	Economy	6000.00
0005434265149	8627	Economy	6000.00
0005434149766	8627	Economy	6000.00
0005434229320	8627	Economy	6000.00
0005434149730	8627	Economy	6000.00
0005434229319	8627	Economy	6000.00
0005434229371	8627	Economy	6000.00
0005432047584	8627	Economy	6000.00
0005432035190	8627	Economy	6000.00
0005435286667	8627	Economy	6000.00
0005435007236	8627	Economy	6000.00
0005432035215	8627	Economy	6000.00
0005434265200	8627	Economy	6000.00
0005432035191	8627	Economy	6000.00
0005434229499	8627	Economy	6000.00
0005434265029	8627	Economy	6000.00
0005434265124	8627	Economy	6000.00
0005435007251	8627	Economy	6000.00
0005432035209	8627	Economy	6000.00
0005434265179	8627	Economy	6000.00
0005433689929	8627	Economy	6000.00
0005435007232	8627	Economy	6000.00
0005434173511	8627	Economy	6000.00
0005435007233	8627	Economy	6000.00
0005434265223	8627	Economy	6000.00
0005433202507	12587	Economy	16200.00
0005433202500	12587	Economy	16200.00
0005433202499	12587	Economy	16200.00
0005434639329	12587	Economy	16200.00
0005433202501	12587	Economy	14800.00
0005434639335	12587	Economy	14800.00
0005434639412	12587	Economy	14800.00
0005434639229	12587	Economy	14800.00
0005434639193	12587	Economy	14800.00
0005434639349	12587	Economy	14800.00
0005434639350	12587	Economy	14800.00
0005434639356	12587	Economy	14800.00
0005433202503	12587	Economy	14800.00
0005434639413	12587	Economy	14800.00
0005433202502	12587	Economy	14800.00
0005433202497	12587	Economy	14800.00
0005434639372	12587	Economy	14800.00
0005434639262	12587	Economy	14800.00
0005433202508	12587	Economy	14800.00
0005434639369	12587	Economy	14800.00
0005433202494	12587	Economy	14800.00
0005434639269	12587	Economy	14800.00
0005434639326	12587	Economy	14800.00
0005434639302	12587	Economy	14800.00
0005434639485	12587	Economy	14800.00
0005434639194	12587	Economy	14800.00
0005434639333	12587	Economy	14800.00
0005433202504	12587	Economy	14800.00
0005434639270	12587	Economy	14800.00
0005434639464	12587	Economy	14800.00
0005433202506	12587	Economy	14800.00
0005434639355	12587	Economy	14800.00
0005434639340	12587	Economy	14800.00
0005433202498	12587	Economy	14800.00
0005434639325	12587	Economy	14800.00
0005433202496	12587	Economy	14800.00
0005434639330	12587	Economy	14800.00
0005433202505	12587	Economy	14800.00
0005433202495	12587	Economy	14800.00
0005434639484	12587	Economy	14800.00
0005433202318	23380	Economy	16200.00
0005434639541	23380	Economy	16200.00
0005434639538	23380	Economy	16200.00
0005434639545	23380	Economy	16200.00
0005434639524	23380	Economy	14800.00
0005434639543	23380	Economy	14800.00
0005434639539	23380	Economy	14800.00
0005433202435	23380	Economy	14800.00
0005434639526	23380	Economy	14800.00
0005434639537	23380	Economy	14800.00
0005434639547	23380	Economy	14800.00
0005433202343	23380	Economy	14800.00
0005432290658	23380	Economy	14800.00
0005434639525	23380	Economy	14800.00
0005434639523	23380	Economy	14800.00
0005433202322	23380	Economy	14800.00
0005434639527	23380	Economy	14800.00
0005434639529	23380	Economy	14800.00
0005433202334	23380	Economy	14800.00
0005433202329	23380	Economy	14800.00
0005434639544	23380	Economy	14800.00
0005432290660	23380	Economy	14800.00
0005434639540	23380	Economy	14800.00
0005434639531	23380	Economy	14800.00
0005434639534	23380	Economy	14800.00
0005432290659	23380	Economy	14800.00
0005434639532	23380	Economy	14800.00
0005434639533	23380	Economy	14800.00
0005433202331	23380	Economy	14800.00
0005434639530	23380	Economy	14800.00
0005434639535	23380	Economy	14800.00
0005434639528	23380	Economy	14800.00
0005434639536	23380	Economy	14800.00
0005433202330	23380	Economy	14800.00
0005434639522	23380	Economy	14800.00
0005433202346	23380	Economy	14800.00
0005433202436	23380	Economy	14800.00
0005433202319	23380	Economy	14800.00
0005434639542	23380	Economy	14800.00
0005434639546	23380	Economy	14800.00
0005433202338	23380	Economy	14800.00
0005433202383	23380	Economy	14800.00
0005434639548	23380	Economy	14800.00
0005432328783	21082	Business	18900.00
0005432054333	21082	Business	18900.00
0005432328655	21082	Business	18900.00
0005432383114	21082	Business	18900.00
0005432328782	21082	Business	18900.00
0005432328684	21082	Business	18900.00
0005432054331	21082	Business	18900.00
0005432382918	21082	Business	18900.00
0005432328608	21082	Business	18900.00
0005432383115	21082	Business	18900.00
0005432383064	21082	Economy	6300.00
0005432382971	21082	Economy	6300.00
0005432383192	21082	Economy	6300.00
0005432328632	21082	Economy	6300.00
0005432383218	21082	Economy	6300.00
0005432383226	21082	Economy	6300.00
0005432328730	21082	Economy	6300.00
0005432328566	21082	Economy	6300.00
0005432054332	21082	Economy	6300.00
0005432054330	21082	Economy	6900.00
0005432328919	21082	Economy	6900.00
0005432382988	21082	Economy	6900.00
0005432383197	21082	Economy	6900.00
0005432382919	21082	Economy	6300.00
0005432383217	21082	Economy	6300.00
0005432383254	21082	Economy	6300.00
0005432328767	21082	Economy	6300.00
0005432383332	21082	Economy	6300.00
0005432328741	21082	Economy	6300.00
0005432383240	21082	Economy	6300.00
0005432328870	21082	Economy	6300.00
0005432383200	21082	Economy	6300.00
0005432383158	21082	Economy	6300.00
0005432328761	21082	Economy	6300.00
0005432383161	21082	Economy	6300.00
0005432383270	21082	Economy	6300.00
0005432383227	21082	Economy	6300.00
0005432383041	21082	Economy	6300.00
0005432383072	21082	Economy	6300.00
0005432383036	21082	Economy	6300.00
0005432328609	21082	Economy	6300.00
0005432328714	21082	Economy	6300.00
0005432328762	21082	Economy	6300.00
0005432383201	21082	Economy	6300.00
0005432328731	21082	Economy	6300.00
0005432328536	21082	Economy	6300.00
0005432328746	21082	Economy	6300.00
0005432328763	21082	Economy	6300.00
0005432328769	21082	Economy	6300.00
0005432328490	21082	Economy	6300.00
0005432383155	21082	Economy	6300.00
0005432383113	21082	Economy	6300.00
0005432383321	21082	Economy	6300.00
0005432328814	21082	Economy	6300.00
0005432383157	21082	Economy	6300.00
0005432328745	21082	Economy	6300.00
0005432328491	21082	Economy	6300.00
0005432383119	21082	Economy	6300.00
0005432328772	21082	Economy	6300.00
0005432328791	21082	Economy	6300.00
0005432328775	21082	Economy	6300.00
0005432328383	21082	Economy	6300.00
0005432383136	21082	Economy	6300.00
0005432383035	21082	Economy	6300.00
0005432328657	21082	Economy	6300.00
0005432328559	21082	Economy	6300.00
0005432383331	21082	Economy	6300.00
0005432328786	21082	Economy	6300.00
0005432328411	21082	Economy	6300.00
0005432328739	21082	Economy	6300.00
0005432383129	21082	Economy	6300.00
0005432328831	21082	Economy	6300.00
0005432383156	21082	Economy	6300.00
0005432328568	21082	Economy	6300.00
0005432328755	21082	Economy	6300.00
0005432328658	21082	Economy	6300.00
0005432328611	21082	Economy	6300.00
0005432328633	21082	Economy	6300.00
0005432328656	21082	Economy	6300.00
0005432328771	21082	Economy	6300.00
0005432328751	21082	Economy	6300.00
0005432383160	21082	Economy	6300.00
0005432328631	21082	Economy	6300.00
0005432383163	21082	Economy	6300.00
0005432328639	21082	Economy	6300.00
0005432382972	21082	Economy	6300.00
0005432383320	21082	Economy	6300.00
0005432383118	21082	Economy	6300.00
0005432328615	21082	Economy	6300.00
0005432383309	21082	Economy	6300.00
0005432328781	21082	Economy	6300.00
0005432329100	31275	Business	18900.00
0005432329083	31275	Business	18900.00
0005432329111	31275	Business	18900.00
0005432329102	31275	Business	18900.00
0005432383532	31275	Business	18900.00
0005432383516	31275	Business	18900.00
0005432383509	31275	Business	18900.00
0005432329084	31275	Business	18900.00
0005432329074	31275	Business	18900.00
0005432329067	31275	Business	18900.00
0005432383528	31275	Business	18900.00
0005432329087	31275	Business	18900.00
0005432383517	31275	Economy	6300.00
0005432329098	31275	Economy	6300.00
0005432383525	31275	Economy	6300.00
0005432329095	31275	Economy	6300.00
0005432329104	31275	Economy	6300.00
0005432383496	31275	Economy	6300.00
0005432329103	31275	Economy	6300.00
0005432287234	31275	Economy	6300.00
0005432383507	31275	Economy	6300.00
0005432329077	31275	Economy	6900.00
0005432329085	31275	Economy	6900.00
0005432383488	31275	Economy	6900.00
0005432329088	31275	Economy	6900.00
0005432329071	31275	Economy	6900.00
0005432329093	31275	Economy	6300.00
0005432329068	31275	Economy	6300.00
0005432383513	31275	Economy	6300.00
0005432383512	31275	Economy	6300.00
0005432383524	31275	Economy	6300.00
0005432383518	31275	Economy	6300.00
0005432287230	31275	Economy	6300.00
0005432329072	31275	Economy	6300.00
0005432329073	31275	Economy	6300.00
0005432383495	31275	Economy	6300.00
0005432383521	31275	Economy	6300.00
0005432383490	31275	Economy	6300.00
0005432383493	31275	Economy	6300.00
0005432383505	31275	Economy	6300.00
0005432383508	31275	Economy	6300.00
0005432383498	31275	Economy	6300.00
0005432329089	31275	Economy	6300.00
0005432383502	31275	Economy	6300.00
0005432329082	31275	Economy	6300.00
0005432383531	31275	Economy	6300.00
0005432329097	31275	Economy	6300.00
0005432383522	31275	Economy	6300.00
0005432383491	31275	Economy	6300.00
0005432329108	31275	Economy	6300.00
0005432329079	31275	Economy	6300.00
0005432329094	31275	Economy	6300.00
0005432383492	31275	Economy	6300.00
0005432383523	31275	Economy	6300.00
0005432383519	31275	Economy	6300.00
0005432383504	31275	Economy	6300.00
0005432383510	31275	Economy	6300.00
0005432329092	31275	Economy	6300.00
0005432329081	31275	Economy	6300.00
0005432329070	31275	Economy	6300.00
0005432383494	31275	Economy	6300.00
0005432383530	31275	Economy	6300.00
0005432383497	31275	Economy	6300.00
0005432329105	31275	Economy	6300.00
0005432329107	31275	Economy	6300.00
0005432329106	31275	Economy	6300.00
0005432383506	31275	Economy	6300.00
0005432287231	31275	Economy	6300.00
0005432329066	31275	Economy	6300.00
0005432329110	31275	Economy	6300.00
0005432383489	31275	Economy	6300.00
0005432329078	31275	Economy	6300.00
0005432329075	31275	Economy	6300.00
0005432329076	31275	Economy	6300.00
0005432287233	31275	Economy	6300.00
0005432329091	31275	Economy	6300.00
0005432287232	31275	Economy	6300.00
0005432329109	31275	Economy	6300.00
0005432383511	31275	Economy	6300.00
0005432383529	31275	Economy	6300.00
0005432329099	31275	Economy	6300.00
0005432383526	31275	Economy	6300.00
0005432383499	31275	Economy	6300.00
0005432383520	31275	Economy	6300.00
0005432383514	31275	Economy	6300.00
0005432383503	31275	Economy	6300.00
0005432329080	31275	Economy	6300.00
0005432383515	31275	Economy	6300.00
0005432383500	31275	Economy	6300.00
0005432383527	31275	Economy	6300.00
0005432329090	31275	Economy	6300.00
0005432329101	31275	Economy	6300.00
0005432329086	31275	Economy	6300.00
0005432329069	31275	Economy	6300.00
0005432383501	31275	Economy	6300.00
0005432329096	31275	Economy	6300.00
0005432424833	13297	Business	12700.00
0005432424844	13297	Business	12700.00
0005432424823	13297	Business	12700.00
0005432424827	13297	Business	12700.00
0005432424835	13297	Business	12700.00
0005432424829	13297	Business	12700.00
0005432424840	13297	Business	12700.00
0005432424848	13297	Economy	4200.00
0005432424824	13297	Economy	4200.00
0005432424838	13297	Economy	4200.00
0005432424860	13297	Economy	4200.00
0005432424862	13297	Economy	4700.00
0005432424822	13297	Economy	4700.00
0005432424859	13297	Economy	4200.00
0005432424856	13297	Economy	4200.00
0005432424845	13297	Economy	4200.00
0005432424847	13297	Economy	4200.00
0005432424828	13297	Economy	4200.00
0005432424826	13297	Economy	4200.00
0005432424863	13297	Economy	4200.00
0005432424857	13297	Economy	4200.00
0005432424855	13297	Economy	4200.00
0005432424854	13297	Economy	4200.00
0005432424850	13297	Economy	4200.00
0005432424836	13297	Economy	4200.00
0005432424832	13297	Economy	4200.00
0005432424837	13297	Economy	4200.00
0005432424851	13297	Economy	4200.00
0005432424825	13297	Economy	4200.00
0005432424839	13297	Economy	4200.00
0005432424831	13297	Economy	4200.00
0005432424830	13297	Economy	4200.00
0005432424842	13297	Economy	4200.00
0005432424849	13297	Economy	4200.00
0005432424834	13297	Economy	4200.00
0005432424846	13297	Economy	4200.00
0005432424853	13297	Economy	4200.00
0005432424841	13297	Economy	4200.00
0005432424861	13297	Economy	4200.00
0005432424858	13297	Economy	4200.00
0005432424852	13297	Economy	4200.00
0005432424843	13297	Economy	4200.00
0005432424421	30722	Business	12700.00
0005432424419	30722	Business	12700.00
0005432424380	30722	Business	12700.00
0005432424402	30722	Economy	4200.00
0005432424428	30722	Economy	4200.00
0005432424335	30722	Economy	4200.00
0005432424277	30722	Economy	4700.00
0005432424432	30722	Economy	4700.00
0005432424418	30722	Economy	4700.00
0005432424460	30722	Economy	4200.00
0005432424145	30722	Economy	4200.00
0005432424144	30722	Economy	4200.00
0005432424320	30722	Economy	4200.00
0005432424366	30722	Economy	4200.00
0005432424392	30722	Economy	4200.00
0005432424308	30722	Economy	4200.00
0005432424420	30722	Economy	4200.00
0005432424398	30722	Economy	4200.00
0005432424454	30722	Economy	4200.00
0005432424440	30722	Economy	4200.00
0005432424387	30722	Economy	4200.00
0005432424390	30722	Economy	4200.00
0005432424451	30722	Economy	4200.00
0005432424391	30722	Economy	4200.00
0005432424431	30722	Economy	4200.00
0005432424331	30722	Economy	4200.00
0005432424315	30722	Economy	4200.00
0005432424438	30722	Economy	4200.00
0005432424318	30722	Economy	4200.00
0005432424396	30722	Economy	4200.00
0005432424397	30722	Economy	4200.00
0005432424412	30722	Economy	4200.00
0005432424232	30722	Economy	4200.00
0005432424455	30722	Economy	4200.00
0005432424401	30722	Economy	4200.00
0005432424332	30722	Economy	4200.00
0005432424416	30722	Economy	4200.00
0005432424417	30722	Economy	4200.00
0005434157485	9604	Business	32600.00
0005432817745	9604	Business	32600.00
0005434157486	9604	Business	32600.00
0005432901658	9604	Business	32600.00
0005432901707	9604	Business	32600.00
0005432822271	9604	Business	32600.00
0005434157530	9604	Business	32600.00
0005432901634	9604	Business	32600.00
0005432901557	9604	Business	32600.00
0005432817738	9604	Economy	10900.00
0005432817740	9604	Economy	10900.00
0005432822277	9604	Economy	10900.00
0005432817754	9604	Economy	10900.00
0005432817750	9604	Economy	10900.00
0005432901604	9604	Economy	10900.00
0005434448347	9604	Economy	10900.00
0005432817737	9604	Economy	11900.00
0005432822270	9604	Economy	11900.00
0005432822276	9604	Economy	11900.00
0005432901491	9604	Economy	10900.00
0005432817744	9604	Economy	10900.00
0005432817749	9604	Economy	10900.00
0005432822274	9604	Economy	10900.00
0005432817734	9604	Economy	10900.00
0005432901691	9604	Economy	10900.00
0005434448346	9604	Economy	10900.00
0005432901633	9604	Economy	10900.00
0005432817735	9604	Economy	10900.00
0005432817743	9604	Economy	10900.00
0005432822273	9604	Economy	10900.00
0005432817752	9604	Economy	10900.00
0005432901661	9604	Economy	10900.00
0005432901556	9604	Economy	10900.00
0005432817746	9604	Economy	10900.00
0005432817736	9604	Economy	10900.00
0005432822275	9604	Economy	10900.00
0005432817756	9604	Economy	10900.00
0005432901662	9604	Economy	10900.00
0005434448348	9604	Economy	10900.00
0005432901617	9604	Economy	10900.00
0005434157493	9604	Economy	10900.00
0005432817742	9604	Economy	10900.00
0005432289017	9604	Economy	10900.00
0005434186202	9604	Economy	10900.00
0005432817755	9604	Economy	10900.00
0005434157520	9604	Economy	10900.00
0005432901692	9604	Economy	10900.00
0005432817728	9604	Economy	10900.00
0005434157491	9604	Economy	10900.00
0005432289015	9604	Economy	10900.00
0005432817741	9604	Economy	10900.00
0005434448349	9604	Economy	10900.00
0005432817731	9604	Economy	10900.00
0005432817732	9604	Economy	10900.00
0005432817757	9604	Economy	10900.00
0005432817753	9604	Economy	10900.00
0005432901618	9604	Economy	10900.00
0005432901475	9604	Economy	10900.00
0005432817739	9604	Economy	10900.00
0005434157531	9604	Economy	10900.00
0005432817733	9604	Economy	10900.00
0005432901685	9604	Economy	10900.00
0005432289016	9604	Economy	10900.00
0005432817748	9604	Economy	10900.00
0005432817751	9604	Economy	10900.00
0005432817747	9604	Economy	10900.00
0005432901476	9604	Economy	10900.00
0005432817730	9604	Economy	10900.00
0005432901490	9604	Economy	10900.00
0005434186198	9604	Economy	10900.00
0005432901607	9604	Economy	10900.00
0005432817729	9604	Economy	10900.00
0005434157477	9604	Economy	10900.00
0005432822272	9604	Economy	10900.00
0005434157492	9604	Economy	10900.00
0005432817585	28953	Business	32600.00
0005432817434	28953	Business	32600.00
0005432901764	28953	Business	32600.00
0005432822192	28953	Business	32600.00
0005432817568	28953	Business	32600.00
0005432817550	28953	Economy	10900.00
0005432817553	28953	Economy	10900.00
0005432901765	28953	Economy	10900.00
0005434157550	28953	Economy	10900.00
0005432822211	28953	Economy	10900.00
0005432901775	28953	Economy	11900.00
0005432901767	28953	Economy	11900.00
0005434448320	28953	Economy	11900.00
0005432817506	28953	Economy	11900.00
0005434157553	28953	Economy	10900.00
0005432817551	28953	Economy	10900.00
0005432901766	28953	Economy	10900.00
0005432901777	28953	Economy	10900.00
0005432817514	28953	Economy	10900.00
0005434157552	28953	Economy	10900.00
0005434157551	28953	Economy	10900.00
0005432817540	28953	Economy	10900.00
0005432901762	28953	Economy	10900.00
0005432901761	28953	Economy	10900.00
0005432822233	28953	Economy	10900.00
0005434157549	28953	Economy	10900.00
0005432901774	28953	Economy	10900.00
0005432901778	28953	Economy	10900.00
0005432817515	28953	Economy	10900.00
0005432901769	28953	Economy	10900.00
0005434157555	28953	Economy	10900.00
0005434157554	28953	Economy	10900.00
0005432901776	28953	Economy	10900.00
0005432817500	28953	Economy	10900.00
0005432901768	28953	Economy	10900.00
0005432822234	28953	Economy	10900.00
0005434186224	28953	Economy	10900.00
0005432901770	28953	Economy	10900.00
0005432822232	28953	Economy	10900.00
0005432817541	28953	Economy	10900.00
0005432901773	28953	Economy	10900.00
0005432002094	28953	Economy	10900.00
0005432817483	28953	Economy	10900.00
0005432901763	28953	Economy	10900.00
0005432002095	28953	Economy	10900.00
0005432817558	28953	Economy	10900.00
0005434157548	28953	Economy	10900.00
0005432817557	28953	Economy	10900.00
0005434186223	28953	Economy	10900.00
0005434186222	28953	Economy	10900.00
0005432901771	28953	Economy	10900.00
0005432817601	28953	Economy	10900.00
0005432901772	28953	Economy	10900.00
0005432613899	15120	Economy	11000.00
0005432611750	15120	Economy	11000.00
0005435841093	15120	Economy	11000.00
0005432613902	15120	Economy	11000.00
0005432613900	15120	Economy	11000.00
0005432613901	15120	Economy	11000.00
0005432611749	15120	Economy	11000.00
0005435841820	15120	Economy	11000.00
0005435841821	15120	Economy	11000.00
0005432613898	15120	Economy	11000.00
0005435842334	31640	Economy	11000.00
0005432611730	31640	Economy	11000.00
0005435842332	31640	Economy	11000.00
0005432611729	31640	Economy	11000.00
0005435842333	31640	Economy	11000.00
0005432607573	31640	Economy	11000.00
0005432948455	11888	Business	105900.00
0005433569575	11888	Business	105900.00
0005433569556	11888	Business	105900.00
0005432948368	11888	Business	105900.00
0005433569561	11888	Business	105900.00
0005432948374	11888	Business	105900.00
0005433569550	11888	Business	105900.00
0005432948515	11888	Business	105900.00
0005432948652	11888	Business	105900.00
0005433569577	11888	Business	105900.00
0005433569545	11888	Business	105900.00
0005433569546	11888	Business	105900.00
0005432948293	11888	Business	105900.00
0005433569579	11888	Business	105900.00
0005432948434	11888	Business	105900.00
0005432948429	11888	Business	105900.00
0005433569565	11888	Business	105900.00
0005433569578	11888	Business	105900.00
0005432948311	11888	Business	105900.00
0005433569553	11888	Economy	35300.00
0005433569572	11888	Economy	35300.00
0005432948284	11888	Economy	35300.00
0005432948337	11888	Economy	35300.00
0005433569544	11888	Economy	35300.00
0005433569552	11888	Economy	35300.00
0005433569574	11888	Economy	35300.00
0005433569568	11888	Economy	35300.00
0005432948197	11888	Economy	35300.00
0005433569557	11888	Economy	35300.00
0005432948472	11888	Economy	35300.00
0005433569580	11888	Economy	38800.00
0005432948154	11888	Economy	38800.00
0005433569549	11888	Economy	38800.00
0005432948283	11888	Economy	35300.00
0005432948427	11888	Economy	35300.00
0005432948411	11888	Economy	35300.00
0005432948401	11888	Economy	35300.00
0005433569547	11888	Economy	35300.00
0005433569582	11888	Economy	35300.00
0005433569560	11888	Economy	35300.00
0005433569539	11888	Economy	35300.00
0005432948448	11888	Economy	35300.00
0005432948294	11888	Economy	35300.00
0005432948548	11888	Economy	35300.00
0005432948379	11888	Economy	35300.00
0005432948414	11888	Economy	35300.00
0005432948259	11888	Economy	35300.00
0005433569540	11888	Economy	35300.00
0005433569562	11888	Economy	35300.00
0005432948338	11888	Economy	35300.00
0005432948359	11888	Economy	35300.00
0005433569569	11888	Economy	35300.00
0005432948495	11888	Economy	35300.00
0005432948155	11888	Economy	35300.00
0005433569564	11888	Economy	35300.00
0005432948209	11888	Economy	35300.00
0005432948412	11888	Economy	35300.00
0005432948260	11888	Economy	35300.00
0005432948657	11888	Economy	35300.00
0005432948498	11888	Economy	35300.00
0005433569583	11888	Economy	35300.00
0005433569576	11888	Economy	35300.00
0005432948402	11888	Economy	35300.00
0005433569554	11888	Economy	35300.00
0005433569541	11888	Economy	35300.00
0005433569563	11888	Economy	35300.00
0005433569555	11888	Economy	35300.00
0005432948527	11888	Economy	35300.00
0005433569551	11888	Economy	35300.00
0005433569566	11888	Economy	35300.00
0005432948208	11888	Economy	35300.00
0005433569548	11888	Economy	35300.00
0005432948417	11888	Economy	35300.00
0005432948310	11888	Economy	35300.00
0005432948375	11888	Economy	35300.00
0005433569542	11888	Economy	35300.00
0005432948547	11888	Economy	35300.00
0005432948533	11888	Economy	35300.00
0005432948358	11888	Economy	35300.00
0005432948367	11888	Economy	35300.00
0005433569570	11888	Economy	35300.00
0005432948456	11888	Economy	35300.00
0005432948459	11888	Economy	35300.00
0005433569538	11888	Economy	35300.00
0005433569571	11888	Economy	35300.00
0005433569573	11888	Economy	35300.00
0005433569558	11888	Economy	35300.00
0005433569543	11888	Economy	35300.00
0005433569581	11888	Economy	35300.00
0005432948441	11888	Economy	35300.00
0005433569567	11888	Economy	35300.00
0005432948534	11888	Economy	35300.00
0005433569559	11888	Economy	35300.00
0005432948499	11888	Economy	35300.00
0005432948428	11888	Economy	35300.00
0005433569122	25298	Business	105900.00
0005433568927	25298	Business	105900.00
0005432948865	25298	Business	105900.00
0005433568988	25298	Business	105900.00
0005433569121	25298	Business	105900.00
0005432948877	25298	Business	105900.00
0005432948857	25298	Business	105900.00
0005433568997	25298	Business	105900.00
0005432948879	25298	Business	105900.00
0005432948884	25298	Business	105900.00
0005433569108	25298	Business	105900.00
0005432948868	25298	Business	105900.00
0005433568616	25298	Business	105900.00
0005433568996	25298	Business	105900.00
0005433569109	25298	Business	105900.00
0005432948858	25298	Business	105900.00
0005433568702	25298	Business	105900.00
0005433569028	25298	Business	105900.00
0005433568881	25298	Business	105900.00
0005432948866	25298	Business	105900.00
0005433569047	25298	Economy	35300.00
0005433568793	25298	Economy	35300.00
0005433569131	25298	Economy	35300.00
0005432948863	25298	Economy	35300.00
0005432948850	25298	Economy	35300.00
0005433569006	25298	Economy	35300.00
0005433569107	25298	Economy	35300.00
0005433568943	25298	Economy	35300.00
0005433568869	25298	Economy	35300.00
0005433568929	25298	Economy	35300.00
0005433568928	25298	Economy	35300.00
0005433569083	25298	Economy	38800.00
0005432948887	25298	Economy	38800.00
0005432948849	25298	Economy	35300.00
0005432948873	25298	Economy	35300.00
0005433569013	25298	Economy	35300.00
0005432948882	25298	Economy	35300.00
0005432948878	25298	Economy	35300.00
0005432948859	25298	Economy	35300.00
0005433568862	25298	Economy	35300.00
0005433568875	25298	Economy	35300.00
0005432948885	25298	Economy	35300.00
0005432948851	25298	Economy	35300.00
0005433569031	25298	Economy	35300.00
0005432948871	25298	Economy	35300.00
0005433568984	25298	Economy	35300.00
0005432948872	25298	Economy	35300.00
0005433568942	25298	Economy	35300.00
0005433569110	25298	Economy	35300.00
0005432948862	25298	Economy	35300.00
0005433569125	25298	Economy	35300.00
0005432948855	25298	Economy	35300.00
0005433569145	25298	Economy	35300.00
0005433568989	25298	Economy	35300.00
0005432948876	25298	Economy	35300.00
0005433569005	25298	Economy	35300.00
0005432948880	25298	Economy	35300.00
0005433569146	25298	Economy	35300.00
0005433568954	25298	Economy	35300.00
0005433568983	25298	Economy	35300.00
0005432948853	25298	Economy	35300.00
0005433569044	25298	Economy	35300.00
0005433569120	25298	Economy	35300.00
0005432948870	25298	Economy	35300.00
0005433569062	25298	Economy	35300.00
0005433569070	25298	Economy	35300.00
0005433569123	25298	Economy	35300.00
0005433568938	25298	Economy	35300.00
0005432948848	25298	Economy	35300.00
0005432948890	25298	Economy	35300.00
0005432948867	25298	Economy	35300.00
0005432948860	25298	Economy	35300.00
0005432948883	25298	Economy	35300.00
0005432948889	25298	Economy	35300.00
0005433568960	25298	Economy	35300.00
0005432948869	25298	Economy	35300.00
0005432948881	25298	Economy	35300.00
0005432948852	25298	Economy	35300.00
0005433569038	25298	Economy	35300.00
0005433568794	25298	Economy	35300.00
0005433569060	25298	Economy	35300.00
0005433569130	25298	Economy	35300.00
0005432948864	25298	Economy	35300.00
0005433568836	25298	Economy	35300.00
0005432948886	25298	Economy	35300.00
0005433569144	25298	Economy	35300.00
0005433568944	25298	Economy	35300.00
0005433569148	25298	Economy	35300.00
0005433568981	25298	Economy	35300.00
0005433569048	25298	Economy	35300.00
0005433568874	25298	Economy	35300.00
0005432948875	25298	Economy	35300.00
0005432948856	25298	Economy	35300.00
0005433568990	25298	Economy	35300.00
0005432948854	25298	Economy	35300.00
0005433569101	25298	Economy	35300.00
0005433569026	25298	Economy	35300.00
0005433569045	25298	Economy	35300.00
0005433569129	25298	Economy	35300.00
0005433569027	25298	Economy	35300.00
0005433569098	25298	Economy	35300.00
0005433568861	25298	Economy	35300.00
0005432948888	25298	Economy	35300.00
0005433568826	25298	Economy	35300.00
0005432948874	25298	Economy	35300.00
0005432948861	25298	Economy	35300.00
0005433569126	25298	Economy	35300.00
0005434654965	5382	Business	67200.00
0005435340299	5382	Business	67200.00
0005434654953	5382	Business	67200.00
0005434654958	5382	Business	67200.00
0005434654967	5382	Business	67200.00
0005435340261	5382	Business	67200.00
0005434654942	5382	Business	67200.00
0005434654939	5382	Economy	22400.00
0005435340295	5382	Economy	22400.00
0005432114234	5382	Economy	22400.00
0005434654955	5382	Economy	22400.00
0005435340277	5382	Economy	22400.00
0005434654956	5382	Economy	24600.00
0005435340247	5382	Economy	24600.00
0005434654951	5382	Economy	24600.00
0005434656575	5382	Economy	24600.00
0005435340273	5382	Economy	24600.00
0005434654941	5382	Economy	22400.00
0005434654957	5382	Economy	22400.00
0005434654944	5382	Economy	22400.00
0005434654950	5382	Economy	22400.00
0005434654949	5382	Economy	22400.00
0005434654945	5382	Economy	22400.00
0005434654948	5382	Economy	22400.00
0005435340184	5382	Economy	22400.00
0005434654963	5382	Economy	22400.00
0005434654954	5382	Economy	22400.00
0005434654938	5382	Economy	22400.00
0005435340274	5382	Economy	22400.00
0005434654946	5382	Economy	22400.00
0005434654952	5382	Economy	22400.00
0005435555372	5382	Economy	22400.00
0005435340242	5382	Economy	22400.00
0005435340254	5382	Economy	22400.00
0005435340183	5382	Economy	22400.00
0005434654959	5382	Economy	22400.00
0005435340314	5382	Economy	22400.00
0005434654966	5382	Economy	22400.00
0005434654947	5382	Economy	22400.00
0005432114232	5382	Economy	22400.00
0005434654937	5382	Economy	22400.00
0005432114231	5382	Economy	22400.00
0005434654940	5382	Economy	22400.00
0005434654964	5382	Economy	22400.00
0005435340315	5382	Economy	22400.00
0005432114235	5382	Economy	22400.00
0005434654943	5382	Economy	22400.00
0005432114233	5382	Economy	22400.00
0005435340243	5382	Economy	22400.00
0005434654961	5382	Economy	22400.00
0005434654962	5382	Economy	22400.00
0005434654968	5382	Economy	22400.00
0005434654960	5382	Economy	22400.00
0005435340294	5382	Economy	22400.00
0005435340265	5382	Economy	22400.00
0005435340396	12560	Business	67200.00
0005435340398	12560	Business	67200.00
0005434654862	12560	Business	67200.00
0005434654642	12560	Economy	22400.00
0005434654704	12560	Economy	22400.00
0005435555389	12560	Economy	22400.00
0005434654655	12560	Economy	22400.00
0005435340404	12560	Economy	24600.00
0005434654815	12560	Economy	22400.00
0005434654706	12560	Economy	22400.00
0005434654656	12560	Economy	22400.00
0005435340401	12560	Economy	22400.00
0005434654674	12560	Economy	22400.00
0005435340403	12560	Economy	22400.00
0005435340399	12560	Economy	22400.00
0005435340395	12560	Economy	22400.00
0005434654654	12560	Economy	22400.00
0005434654813	12560	Economy	22400.00
0005435340408	12560	Economy	22400.00
0005435340405	12560	Economy	22400.00
0005435340406	12560	Economy	22400.00
0005434654601	12560	Economy	22400.00
0005435340402	12560	Economy	22400.00
0005434654703	12560	Economy	22400.00
0005434654610	12560	Economy	22400.00
0005434654647	12560	Economy	22400.00
0005435555390	12560	Economy	22400.00
0005435340400	12560	Economy	22400.00
0005435340407	12560	Economy	22400.00
0005434654602	12560	Economy	22400.00
0005434654682	12560	Economy	22400.00
0005435340409	12560	Economy	22400.00
0005434654814	12560	Economy	22400.00
0005434654729	12560	Economy	22400.00
0005435340397	12560	Economy	22400.00
0005434656561	12560	Economy	22400.00
0005434654670	12560	Economy	22400.00
0005433716405	7419	Business	32000.00
0005433716419	7419	Business	32000.00
0005433716411	7419	Business	32000.00
0005433716416	7419	Business	32000.00
0005433716425	7419	Business	32000.00
0005435266152	7419	Business	32000.00
0005433716434	7419	Business	32000.00
0005433722279	7419	Business	32000.00
0005433716415	7419	Business	32000.00
0005433716447	7419	Economy	10700.00
0005433716444	7419	Economy	10700.00
0005433716400	7419	Economy	10700.00
0005433656700	7419	Economy	10700.00
0005433716410	7419	Economy	10700.00
0005433716421	7419	Economy	10700.00
0005433716412	7419	Economy	10700.00
0005433716404	7419	Economy	10700.00
0005433716426	7419	Economy	10700.00
0005433656699	7419	Economy	10700.00
0005433722277	7419	Economy	10700.00
0005433716436	7419	Economy	10700.00
0005433716399	7419	Economy	10700.00
0005433716413	7419	Economy	10700.00
0005433716433	7419	Economy	10700.00
0005433716441	7419	Economy	10700.00
0005433716403	7419	Economy	10700.00
0005433716438	7419	Economy	10700.00
0005432078162	7419	Economy	10700.00
0005433716446	7419	Economy	10700.00
0005432078161	7419	Economy	10700.00
0005433716437	7419	Economy	10700.00
0005433722280	7419	Economy	10700.00
0005433716443	7419	Economy	11700.00
0005433719170	7419	Economy	11700.00
0005433690941	7419	Economy	11700.00
0005433722278	7419	Economy	11700.00
0005433716440	7419	Economy	10700.00
0005433716417	7419	Economy	10700.00
0005432078159	7419	Economy	10700.00
0005433716431	7419	Economy	10700.00
0005433716423	7419	Economy	10700.00
0005433716435	7419	Economy	10700.00
0005433719171	7419	Economy	10700.00
0005433716398	7419	Economy	10700.00
0005432428930	7419	Economy	10700.00
0005433716414	7419	Economy	10700.00
0005433716430	7419	Economy	10700.00
0005433719169	7419	Economy	10700.00
0005433716418	7419	Economy	10700.00
0005433716397	7419	Economy	10700.00
0005435266151	7419	Economy	10700.00
0005433716442	7419	Economy	10700.00
0005433716409	7419	Economy	10700.00
0005433719168	7419	Economy	10700.00
0005433716408	7419	Economy	10700.00
0005432078158	7419	Economy	10700.00
0005433716432	7419	Economy	10700.00
0005433716420	7419	Economy	10700.00
0005433689928	7419	Economy	10700.00
0005433656697	7419	Economy	10700.00
0005433716439	7419	Economy	10700.00
0005433716406	7419	Economy	10700.00
0005433656698	7419	Economy	10700.00
0005433716445	7419	Economy	10700.00
0005432078157	7419	Economy	10700.00
0005433688827	7419	Economy	10700.00
0005433716401	7419	Economy	10700.00
0005433716402	7419	Economy	10700.00
0005433716428	7419	Economy	10700.00
0005433716427	7419	Economy	10700.00
0005433716422	7419	Economy	10700.00
0005432078160	7419	Economy	10700.00
0005433716429	7419	Economy	10700.00
0005433716424	7419	Economy	10700.00
0005433690942	7419	Economy	10700.00
0005433722281	7419	Economy	10700.00
0005433716407	7419	Economy	10700.00
0005433716008	29236	Business	32000.00
0005433715943	29236	Business	32000.00
0005433716030	29236	Business	32000.00
0005433715933	29236	Business	32000.00
0005433715908	29236	Business	32000.00
0005433716055	29236	Business	32000.00
0005433716011	29236	Business	32000.00
0005433715963	29236	Economy	10700.00
0005433716047	29236	Economy	10700.00
0005433688811	29236	Economy	10700.00
0005433716052	29236	Economy	10700.00
0005433716174	29236	Economy	10700.00
0005435266190	29236	Economy	10700.00
0005435266187	29236	Economy	10700.00
0005433685507	29236	Economy	10700.00
0005433715990	29236	Economy	10700.00
0005432428961	29236	Economy	10700.00
0005433715898	29236	Economy	10700.00
0005433716034	29236	Economy	10700.00
0005435266191	29236	Economy	10700.00
0005433716116	29236	Economy	10700.00
0005433715829	29236	Economy	10700.00
0005432006786	29236	Economy	10700.00
0005433715999	29236	Economy	10700.00
0005433715874	29236	Economy	10700.00
0005433715927	29236	Economy	10700.00
0005435266186	29236	Economy	10700.00
0005433715909	29236	Economy	10700.00
0005433715901	29236	Economy	10700.00
0005432428959	29236	Economy	10700.00
0005433716103	29236	Economy	11700.00
0005433688800	29236	Economy	10700.00
0005435266188	29236	Economy	10700.00
0005433715810	29236	Economy	10700.00
0005433715988	29236	Economy	10700.00
0005433688812	29236	Economy	10700.00
0005433719156	29236	Economy	10700.00
0005433688801	29236	Economy	10700.00
0005433715858	29236	Economy	10700.00
0005435266189	29236	Economy	10700.00
0005433716029	29236	Economy	10700.00
0005433715900	29236	Economy	10700.00
0005433716033	29236	Economy	10700.00
0005432006788	29236	Economy	10700.00
0005433716048	29236	Economy	10700.00
0005433716007	29236	Economy	10700.00
0005433715830	29236	Economy	10700.00
0005433715991	29236	Economy	10700.00
0005433716224	29236	Economy	10700.00
0005433715934	29236	Economy	10700.00
0005433716005	29236	Economy	10700.00
0005432006787	29236	Economy	10700.00
0005433715899	29236	Economy	10700.00
0005433715985	29236	Economy	10700.00
0005433716053	29236	Economy	10700.00
0005433716175	29236	Economy	10700.00
0005432428960	29236	Economy	10700.00
0005433715986	29236	Economy	10700.00
0005433715890	29236	Economy	10700.00
0005433685508	29236	Economy	10700.00
0005433715961	29236	Economy	10700.00
0005435266185	29236	Economy	10700.00
0005433719155	29236	Economy	10700.00
0005433715857	29236	Economy	10700.00
0005433715766	29236	Economy	10700.00
0005433716139	29236	Economy	10700.00
0005433688799	29236	Economy	10700.00
0005433715926	29236	Economy	10700.00
0005433716138	29236	Economy	10700.00
0005433716049	29236	Economy	10700.00
0005433716046	29236	Economy	10700.00
0005433716000	29236	Economy	10700.00
0005433715989	29236	Economy	10700.00
0005434095401	8693	Business	36500.00
0005434095399	8693	Business	36500.00
0005434095412	8693	Business	36500.00
0005434095406	8693	Economy	12200.00
0005434182197	8693	Economy	13400.00
0005434095408	8693	Economy	12200.00
0005434182191	8693	Economy	12200.00
0005434095409	8693	Economy	12200.00
0005434182222	8693	Economy	12200.00
0005434184666	8693	Economy	12200.00
0005434095411	8693	Economy	12200.00
0005434184665	8693	Economy	12200.00
0005434095403	8693	Economy	12200.00
0005434182192	8693	Economy	12200.00
0005434182132	8693	Economy	12200.00
0005434095400	8693	Economy	12200.00
0005434182198	8693	Economy	12200.00
0005434182225	8693	Economy	12200.00
0005434095405	8693	Economy	12200.00
0005434095413	8693	Economy	12200.00
0005434184663	8693	Economy	12200.00
0005434095402	8693	Economy	12200.00
0005434182125	8693	Economy	12200.00
0005434095407	8693	Economy	12200.00
0005434095410	8693	Economy	12200.00
0005434095404	8693	Economy	12200.00
0005434182295	11636	Business	36500.00
0005434182303	11636	Business	36500.00
0005434182304	11636	Business	36500.00
0005434184682	11636	Economy	12200.00
0005434182302	11636	Economy	12200.00
0005434095289	11636	Economy	12200.00
0005434095284	11636	Economy	13400.00
0005434182294	11636	Economy	12200.00
0005434182300	11636	Economy	12200.00
0005434182296	11636	Economy	12200.00
0005434182301	11636	Economy	12200.00
0005434182293	11636	Economy	12200.00
0005434095265	11636	Economy	12200.00
0005434095296	11636	Economy	12200.00
0005434095285	11636	Economy	12200.00
0005434182299	11636	Economy	12200.00
0005434182297	11636	Economy	12200.00
0005434182298	11636	Economy	12200.00
0005434183596	11636	Economy	12200.00
0005434182292	11636	Economy	12200.00
0005434095290	11636	Economy	12200.00
0005434183597	11636	Economy	12200.00
0005435732454	1467	Business	33000.00
0005432906547	1467	Business	33000.00
0005432906541	1467	Business	33000.00
0005432906532	1467	Business	33000.00
0005435732442	1467	Business	33000.00
0005433397984	1467	Business	33000.00
0005435732460	1467	Business	33000.00
0005433398057	1467	Business	33000.00
0005435732443	1467	Business	33000.00
0005433398167	1467	Business	33000.00
0005433457004	1467	Economy	11000.00
0005433397863	1467	Economy	11000.00
0005435732450	1467	Economy	11000.00
0005433397931	1467	Economy	11000.00
0005433457006	1467	Economy	11000.00
0005433398215	1467	Economy	11000.00
0005433398048	1467	Economy	11000.00
0005432297300	1467	Economy	11000.00
0005435732446	1467	Economy	12100.00
0005433398079	1467	Economy	12100.00
0005435732447	1467	Economy	12100.00
0005433398095	1467	Economy	11000.00
0005433397985	1467	Economy	11000.00
0005433397988	1467	Economy	11000.00
0005433398268	1467	Economy	11000.00
0005433398087	1467	Economy	11000.00
0005433398174	1467	Economy	11000.00
0005433397998	1467	Economy	11000.00
0005433398198	1467	Economy	11000.00
0005433397864	1467	Economy	11000.00
0005433398180	1467	Economy	11000.00
0005435732451	1467	Economy	11000.00
0005432906536	1467	Economy	11000.00
0005433398030	1467	Economy	11000.00
0005433398214	1467	Economy	11000.00
0005432297302	1467	Economy	11000.00
0005433398084	1467	Economy	11000.00
0005433398060	1467	Economy	11000.00
0005435732457	1467	Economy	11000.00
0005433397960	1467	Economy	11000.00
0005435732459	1467	Economy	11000.00
0005433397932	1467	Economy	11000.00
0005435732453	1467	Economy	11000.00
0005432906533	1467	Economy	11000.00
0005433397972	1467	Economy	11000.00
0005433457005	1467	Economy	11000.00
0005435732458	1467	Economy	11000.00
0005433398059	1467	Economy	11000.00
0005433398156	1467	Economy	11000.00
0005432906546	1467	Economy	11000.00
0005435732455	1467	Economy	11000.00
0005433457008	1467	Economy	11000.00
0005433397970	1467	Economy	11000.00
0005433397999	1467	Economy	11000.00
0005435732441	1467	Economy	11000.00
0005435732444	1467	Economy	11000.00
0005433398085	1467	Economy	11000.00
0005435732448	1467	Economy	11000.00
0005433398207	1467	Economy	11000.00
0005435732452	1467	Economy	11000.00
0005433398256	1467	Economy	11000.00
0005435732445	1467	Economy	11000.00
0005433398119	1467	Economy	11000.00
0005433397971	1467	Economy	11000.00
0005433457007	1467	Economy	11000.00
0005433397907	1467	Economy	11000.00
0005433397976	1467	Economy	11000.00
0005432297301	1467	Economy	11000.00
0005435732449	1467	Economy	11000.00
0005433398104	1467	Economy	11000.00
0005432906548	1467	Economy	11000.00
0005435732456	1467	Economy	11000.00
0005433456982	19285	Business	33000.00
0005435732332	19285	Business	33000.00
0005433398479	19285	Business	33000.00
0005435732329	19285	Business	33000.00
0005433398485	19285	Business	33000.00
0005433456954	19285	Business	33000.00
0005433398512	19285	Business	33000.00
0005433398484	19285	Business	33000.00
0005433398503	19285	Economy	11000.00
0005432906559	19285	Economy	11000.00
0005433398487	19285	Economy	11000.00
0005435732306	19285	Economy	11000.00
0005435732305	19285	Economy	11000.00
0005433398489	19285	Economy	11000.00
0005433398506	19285	Economy	11000.00
0005433398513	19285	Economy	11000.00
0005433398486	19285	Economy	11000.00
0005433398491	19285	Economy	12100.00
0005433398514	19285	Economy	11000.00
0005433398490	19285	Economy	11000.00
0005433398488	19285	Economy	11000.00
0005435732342	19285	Economy	11000.00
0005433456986	19285	Economy	11000.00
0005433456978	19285	Economy	11000.00
0005433398473	19285	Economy	11000.00
0005433398507	19285	Economy	11000.00
0005435732360	19285	Economy	11000.00
0005433398472	19285	Economy	11000.00
0005435732284	19285	Economy	11000.00
0005433398515	19285	Economy	11000.00
0005433398501	19285	Economy	11000.00
0005435732320	19285	Economy	11000.00
0005433398493	19285	Economy	11000.00
0005435732283	19285	Economy	11000.00
0005433398481	19285	Economy	11000.00
0005433398478	19285	Economy	11000.00
0005433398495	19285	Economy	11000.00
0005433398499	19285	Economy	11000.00
0005433398521	19285	Economy	11000.00
0005433398474	19285	Economy	11000.00
0005433398498	19285	Economy	11000.00
0005433398511	19285	Economy	11000.00
0005433398518	19285	Economy	11000.00
0005435732300	19285	Economy	11000.00
0005433398492	19285	Economy	11000.00
0005433398502	19285	Economy	11000.00
0005433398471	19285	Economy	11000.00
0005433456955	19285	Economy	11000.00
0005433398510	19285	Economy	11000.00
0005433398477	19285	Economy	11000.00
0005433398480	19285	Economy	11000.00
0005433398496	19285	Economy	11000.00
0005433398505	19285	Economy	11000.00
0005433398520	19285	Economy	11000.00
0005433398519	19285	Economy	11000.00
0005433398504	19285	Economy	11000.00
0005433398522	19285	Economy	11000.00
0005433398475	19285	Economy	11000.00
0005433398482	19285	Economy	11000.00
0005435732336	19285	Economy	11000.00
0005435732298	19285	Economy	11000.00
0005435732369	19285	Economy	11000.00
0005433398517	19285	Economy	11000.00
0005433398494	19285	Economy	11000.00
0005433398516	19285	Economy	11000.00
0005433456983	19285	Economy	11000.00
0005433398509	19285	Economy	11000.00
0005432906558	19285	Economy	11000.00
0005433398483	19285	Economy	11000.00
0005433398500	19285	Economy	11000.00
0005432906557	19285	Economy	11000.00
0005433456985	19285	Economy	11000.00
0005433398497	19285	Economy	11000.00
0005433398476	19285	Economy	11000.00
0005435732357	19285	Economy	11000.00
0005435732346	19285	Economy	11000.00
0005433398508	19285	Economy	11000.00
0005434443694	17362	Economy	15600.00
0005434443683	17362	Economy	15600.00
0005434443754	17362	Economy	14100.00
0005434443753	17362	Economy	14100.00
0005434443783	17362	Economy	14100.00
0005434443727	17362	Economy	14100.00
0005434443692	17362	Economy	14100.00
0005434443693	17362	Economy	14100.00
0005434443768	17362	Economy	14100.00
0005434443782	17362	Economy	14100.00
0005434443710	17362	Economy	14100.00
0005434443699	17362	Economy	14100.00
0005434443794	17362	Economy	14100.00
0005434443730	17362	Economy	14100.00
0005434443671	17362	Economy	14100.00
0005434443709	17362	Economy	14100.00
0005434443711	17362	Economy	14100.00
0005434443720	17362	Economy	14100.00
0005434443852	20588	Economy	14100.00
0005434443839	20588	Economy	14100.00
0005434443845	20588	Economy	14100.00
0005434443847	20588	Economy	14100.00
0005434443841	20588	Economy	14100.00
0005434443842	20588	Economy	14100.00
0005434443848	20588	Economy	14100.00
0005434443849	20588	Economy	14100.00
0005434443843	20588	Economy	14100.00
0005434443837	20588	Economy	14100.00
0005434443850	20588	Economy	14100.00
0005434443844	20588	Economy	14100.00
0005434443853	20588	Economy	14100.00
0005434443846	20588	Economy	14100.00
0005434443851	20588	Economy	14100.00
0005434443840	20588	Economy	14100.00
0005434443838	20588	Economy	14100.00
0005434954645	7237	Economy	5800.00
0005435377588	7237	Economy	5800.00
0005434954646	7237	Economy	5800.00
0005434954644	7237	Economy	5800.00
0005435377580	7237	Economy	5800.00
0005435377602	28338	Economy	5800.00
0005434954625	28338	Economy	5800.00
0005434954626	28338	Economy	5800.00
0005434954607	28338	Economy	5800.00
0005434954624	28338	Economy	5800.00
0005435377601	28338	Economy	5800.00
0005435893643	4450	Economy	15400.00
0005435893647	4450	Economy	15400.00
0005434351806	4450	Economy	14000.00
0005434183586	4450	Economy	14000.00
0005434183577	4450	Economy	14000.00
0005435893607	4450	Economy	14000.00
0005434351817	4450	Economy	14000.00
0005435893613	4450	Economy	14000.00
0005434351812	4450	Economy	14000.00
0005435893644	4450	Economy	14000.00
0005434351815	4450	Economy	14000.00
0005435893666	4450	Economy	14000.00
0005434351810	4450	Economy	14000.00
0005434183571	4450	Economy	14000.00
0005435893651	4450	Economy	14000.00
0005434351807	4450	Economy	14000.00
0005434351814	4450	Economy	14000.00
0005435893636	4450	Economy	14000.00
0005434326277	4450	Economy	14000.00
0005435893606	4450	Economy	14000.00
0005434351808	4450	Economy	14000.00
0005434351816	4450	Economy	14000.00
0005434326275	4450	Economy	14000.00
0005434351805	4450	Economy	14000.00
0005434351811	4450	Economy	14000.00
0005434326276	4450	Economy	14000.00
0005434351809	4450	Economy	14000.00
0005434351813	4450	Economy	14000.00
0005435893629	4450	Economy	14000.00
0005435893694	29652	Economy	14000.00
0005434351696	29652	Economy	14000.00
0005434351679	29652	Economy	14000.00
0005435893695	29652	Economy	14000.00
0005434351678	29652	Economy	14000.00
0005434351677	29652	Economy	14000.00
0005435893698	29652	Economy	14000.00
0005435893696	29652	Economy	14000.00
0005434351698	29652	Economy	14000.00
0005434351736	29652	Economy	14000.00
0005435893693	29652	Economy	14000.00
0005435893692	29652	Economy	14000.00
0005434351706	29652	Economy	14000.00
0005434351686	29652	Economy	14000.00
0005435893697	29652	Economy	14000.00
0005435893699	29652	Economy	14000.00
0005433342698	1078	Business	30600.00
0005433342665	1078	Business	30600.00
0005433343553	1078	Business	30600.00
0005433463920	1078	Business	30600.00
0005435545805	1078	Business	30600.00
0005433343388	1078	Business	30600.00
0005433342901	1078	Business	30600.00
0005432293231	1078	Business	30600.00
0005433342826	1078	Business	30600.00
0005433342722	1078	Business	30600.00
0005435545799	1078	Business	30600.00
0005433342703	1078	Business	30600.00
0005435545804	1078	Business	30600.00
0005435545806	1078	Business	30600.00
0005433342999	1078	Business	30600.00
0005433342825	1078	Business	30600.00
0005435092163	1078	Business	30600.00
0005433343034	1078	Business	30600.00
0005433159324	1078	Business	30600.00
0005435092164	1078	Business	30600.00
0005434445264	1078	Business	30600.00
0005435545803	1078	Business	30600.00
0005433343053	1078	Economy	11200.00
0005433342933	1078	Economy	11200.00
0005433343176	1078	Economy	11200.00
0005434446537	1078	Economy	11200.00
0005433343009	1078	Economy	10200.00
0005433342666	1078	Economy	10200.00
0005433343041	1078	Economy	10200.00
0005433343409	1078	Economy	10200.00
0005433343328	1078	Economy	10200.00
0005433342747	1078	Economy	10200.00
0005433343357	1078	Economy	10200.00
0005435545801	1078	Economy	10200.00
0005433158123	1078	Economy	10200.00
0005433343050	1078	Economy	10200.00
0005433342917	1078	Economy	10200.00
0005433343129	1078	Economy	10200.00
0005433343077	1078	Economy	10200.00
0005433343571	1078	Economy	10200.00
0005433342915	1078	Economy	10200.00
0005435545797	1078	Economy	10200.00
0005433342656	1078	Economy	10200.00
0005433342887	1078	Economy	10200.00
0005435092167	1078	Economy	10200.00
0005433343401	1078	Economy	10200.00
0005433343346	1078	Economy	10200.00
0005433158135	1078	Economy	10200.00
0005433342961	1078	Economy	10200.00
0005433342849	1078	Economy	10200.00
0005433269727	1078	Economy	10200.00
0005435092162	1078	Economy	10200.00
0005433343184	1078	Economy	10200.00
0005433343169	1078	Economy	10200.00
0005433343047	1078	Economy	10200.00
0005433342619	1078	Economy	10200.00
0005432293230	1078	Economy	10200.00
0005433342779	1078	Economy	10200.00
0005433342549	1078	Economy	10200.00
0005433343201	1078	Economy	10200.00
0005433343223	1078	Economy	10200.00
0005433343397	1078	Economy	10200.00
0005433343040	1078	Economy	10200.00
0005433343046	1078	Economy	10200.00
0005433343196	1078	Economy	10200.00
0005433342902	1078	Economy	10200.00
0005433343105	1078	Economy	10200.00
0005433343273	1078	Economy	10200.00
0005435092166	1078	Economy	10200.00
0005435092161	1078	Economy	10200.00
0005433343121	1078	Economy	10200.00
0005435545800	1078	Economy	10200.00
0005435545810	1078	Economy	10200.00
0005433343164	1078	Economy	10200.00
0005433343006	1078	Economy	10200.00
0005433342601	1078	Economy	10200.00
0005433342672	1078	Economy	10200.00
0005433342952	1078	Economy	10200.00
0005433343104	1078	Economy	10200.00
0005433343255	1078	Economy	10200.00
0005433159305	1078	Economy	10200.00
0005433343374	1078	Economy	10200.00
0005433342760	1078	Economy	10200.00
0005433462765	1078	Economy	10200.00
0005433343049	1078	Economy	10200.00
0005433159326	1078	Economy	11200.00
0005433342704	1078	Economy	10200.00
0005434445262	1078	Economy	10200.00
0005433342976	1078	Economy	11200.00
0005433343520	1078	Economy	11200.00
0005433342951	1078	Economy	10200.00
0005433343433	1078	Economy	10200.00
0005435545798	1078	Economy	10200.00
0005433343084	1078	Economy	10200.00
0005435545807	1078	Economy	10200.00
0005433159327	1078	Economy	10200.00
0005435545809	1078	Economy	10200.00
0005433342699	1078	Economy	10200.00
0005433342866	1078	Economy	10200.00
0005433462766	1078	Economy	10200.00
0005433343076	1078	Economy	10200.00
0005433343519	1078	Economy	10200.00
0005435092165	1078	Economy	10200.00
0005433342848	1078	Economy	10200.00
0005433343387	1078	Economy	10200.00
0005433342638	1078	Economy	10200.00
0005433343245	1078	Economy	10200.00
0005433343146	1078	Economy	10200.00
0005433342989	1078	Economy	10200.00
0005433342618	1078	Economy	10200.00
0005434445263	1078	Economy	10200.00
0005435545808	1078	Economy	10200.00
0005433462767	1078	Economy	10200.00
0005433269734	1078	Economy	10200.00
0005433343052	1078	Economy	10200.00
0005433342705	1078	Economy	10200.00
0005433343267	1078	Economy	10200.00
0005433342149	1078	Economy	10200.00
0005433343195	1078	Economy	10200.00
0005433342900	1078	Economy	10200.00
0005433342824	1078	Economy	10200.00
0005433343254	1078	Economy	10200.00
0005435545811	1078	Economy	10200.00
0005435092160	1078	Economy	10200.00
0005433269735	1078	Economy	10200.00
0005433343026	1078	Economy	10200.00
0005433343187	1078	Economy	10200.00
0005433343385	1078	Economy	10200.00
0005433343386	1078	Economy	10200.00
0005433343375	1078	Economy	10200.00
0005433342855	1078	Economy	10200.00
0005433463919	1078	Economy	10200.00
0005433343188	1078	Economy	10200.00
0005433343106	1078	Economy	10200.00
0005433343227	1078	Economy	10200.00
0005434445265	1078	Economy	10200.00
0005433342657	1078	Economy	10200.00
0005435092168	1078	Economy	10200.00
0005435545802	1078	Economy	10200.00
0005433343243	1078	Economy	10200.00
0005433342548	1078	Economy	10200.00
0005433342934	1078	Economy	10200.00
0005433269715	1078	Economy	10200.00
0005433342916	1078	Economy	10200.00
0005435092106	17070	Business	30600.00
0005433344013	17070	Business	30600.00
0005433269766	17070	Business	30600.00
0005433343923	17070	Business	30600.00
0005433343983	17070	Business	30600.00
0005433344018	17070	Business	30600.00
0005433344005	17070	Business	30600.00
0005433343987	17070	Business	30600.00
0005433343958	17070	Business	30600.00
0005433343947	17070	Business	30600.00
0005433344006	17070	Business	30600.00
0005433344023	17070	Business	30600.00
0005435092086	17070	Business	30600.00
0005433344011	17070	Business	30600.00
0005435508318	17070	Business	30600.00
0005435092054	17070	Economy	11200.00
0005433343999	17070	Economy	11200.00
0005433343990	17070	Economy	11200.00
0005433343964	17070	Economy	10200.00
0005433343972	17070	Economy	10200.00
0005433343929	17070	Economy	10200.00
0005433343970	17070	Economy	10200.00
0005433343985	17070	Economy	10200.00
0005433343922	17070	Economy	10200.00
0005433343935	17070	Economy	10200.00
0005433343962	17070	Economy	10200.00
0005433343926	17070	Economy	10200.00
0005433343934	17070	Economy	10200.00
0005433343937	17070	Economy	10200.00
0005433343980	17070	Economy	10200.00
0005433343965	17070	Economy	10200.00
0005433343979	17070	Economy	10200.00
0005433343986	17070	Economy	10200.00
0005433343967	17070	Economy	10200.00
0005433343968	17070	Economy	10200.00
0005433269767	17070	Economy	10200.00
0005433344016	17070	Economy	10200.00
0005433343951	17070	Economy	10200.00
0005433343982	17070	Economy	10200.00
0005435092053	17070	Economy	10200.00
0005433344008	17070	Economy	10200.00
0005433343984	17070	Economy	10200.00
0005435092090	17070	Economy	10200.00
0005433343995	17070	Economy	10200.00
0005433344012	17070	Economy	10200.00
0005433343974	17070	Economy	10200.00
0005433343956	17070	Economy	10200.00
0005435508304	17070	Economy	10200.00
0005433343993	17070	Economy	10200.00
0005433343978	17070	Economy	10200.00
0005433344015	17070	Economy	10200.00
0005435092103	17070	Economy	10200.00
0005433343954	17070	Economy	10200.00
0005435092089	17070	Economy	10200.00
0005433343931	17070	Economy	10200.00
0005433269769	17070	Economy	10200.00
0005433344010	17070	Economy	10200.00
0005433343992	17070	Economy	10200.00
0005435092049	17070	Economy	10200.00
0005433343977	17070	Economy	10200.00
0005433343955	17070	Economy	10200.00
0005435092085	17070	Economy	10200.00
0005435092105	17070	Economy	10200.00
0005433343994	17070	Economy	10200.00
0005434445243	17070	Economy	10200.00
0005433344002	17070	Economy	10200.00
0005433343924	17070	Economy	10200.00
0005433343971	17070	Economy	10200.00
0005433343991	17070	Economy	10200.00
0005433343952	17070	Economy	10200.00
0005435092047	17070	Economy	10200.00
0005435508306	17070	Economy	10200.00
0005433344014	17070	Economy	10200.00
0005435092108	17070	Economy	10200.00
0005433344022	17070	Economy	10200.00
0005433343988	17070	Economy	10200.00
0005433344000	17070	Economy	10200.00
0005435092055	17070	Economy	10200.00
0005433344009	17070	Economy	10200.00
0005433343959	17070	Economy	10200.00
0005433343966	17070	Economy	11200.00
0005433343928	17070	Economy	11200.00
0005433344007	17070	Economy	10200.00
0005433344003	17070	Economy	10200.00
0005433343960	17070	Economy	11200.00
0005433343949	17070	Economy	10200.00
0005433343948	17070	Economy	10200.00
0005435092114	17070	Economy	10200.00
0005433343940	17070	Economy	10200.00
0005434445228	17070	Economy	10200.00
0005433343938	17070	Economy	10200.00
0005433343973	17070	Economy	10200.00
0005433343946	17070	Economy	10200.00
0005433343975	17070	Economy	10200.00
0005433343930	17070	Economy	10200.00
0005433343941	17070	Economy	10200.00
0005433343976	17070	Economy	10200.00
0005433343997	17070	Economy	10200.00
0005433343927	17070	Economy	10200.00
0005433343998	17070	Economy	10200.00
0005433343942	17070	Economy	10200.00
0005433343945	17070	Economy	10200.00
0005433344004	17070	Economy	10200.00
0005435092060	17070	Economy	10200.00
0005435092048	17070	Economy	10200.00
0005433343943	17070	Economy	10200.00
0005433343936	17070	Economy	10200.00
0005435092102	17070	Economy	10200.00
0005433343981	17070	Economy	10200.00
0005433269768	17070	Economy	10200.00
0005433344019	17070	Economy	10200.00
0005433343957	17070	Economy	10200.00
0005433344020	17070	Economy	10200.00
0005433343950	17070	Economy	10200.00
0005433343989	17070	Economy	10200.00
0005433343961	17070	Economy	10200.00
0005435092076	17070	Economy	10200.00
0005433343939	17070	Economy	10200.00
0005433343932	17070	Economy	10200.00
0005433343969	17070	Economy	10200.00
0005433343933	17070	Economy	10200.00
0005435508303	17070	Economy	10200.00
0005433343953	17070	Economy	10200.00
0005433344021	17070	Economy	10200.00
0005433344017	17070	Economy	10200.00
0005435508302	17070	Economy	10200.00
0005433343925	17070	Economy	10200.00
0005435092109	17070	Economy	10200.00
0005433343944	17070	Economy	10200.00
0005433343996	17070	Economy	10200.00
0005433343963	17070	Economy	10200.00
0005433344001	17070	Economy	10200.00
0005435092113	17070	Economy	10200.00
0005434067696	12821	Business	40300.00
0005434067468	12821	Business	40300.00
0005434067387	12821	Business	40300.00
0005432433728	12821	Business	40300.00
0005434067648	12821	Business	40300.00
0005434067647	12821	Business	40300.00
0005434067704	12821	Business	40300.00
0005434081817	12821	Business	40300.00
0005432433727	12821	Business	40300.00
0005434067584	12821	Business	40300.00
0005434081874	12821	Business	40300.00
0005434081832	12821	Business	40300.00
0005434081908	12821	Economy	13400.00
0005434067238	12821	Economy	13400.00
0005434081909	12821	Economy	13400.00
0005434067794	12821	Economy	13400.00
0005434081769	12821	Economy	13400.00
0005434067573	12821	Economy	13400.00
0005434067574	12821	Economy	13400.00
0005434067442	12821	Economy	13400.00
0005434081955	12821	Economy	13400.00
0005434081838	12821	Economy	13400.00
0005433812921	12821	Economy	13400.00
0005433989762	12821	Economy	13400.00
0005432433730	12821	Economy	13400.00
0005434081833	12821	Economy	13400.00
0005432159897	12821	Economy	13400.00
0005434067323	12821	Economy	13400.00
0005434067603	12821	Economy	13400.00
0005432161172	12821	Economy	13400.00
0005434067362	12821	Economy	13400.00
0005434067691	12821	Economy	13400.00
0005434067275	12821	Economy	13400.00
0005434067640	12821	Economy	13400.00
0005434081826	12821	Economy	13400.00
0005434067548	12821	Economy	13400.00
0005434067768	12821	Economy	13400.00
0005434067378	12821	Economy	13400.00
0005434081923	12821	Economy	13400.00
0005434081856	12821	Economy	13400.00
0005434067372	12821	Economy	13400.00
0005434067512	12821	Economy	13400.00
0005434067439	12821	Economy	14800.00
0005432159901	12821	Economy	14800.00
0005434081836	12821	Economy	14800.00
0005434081875	12821	Economy	14800.00
0005434067641	12821	Economy	13400.00
0005434067689	12821	Economy	14800.00
0005434081794	12821	Economy	13400.00
0005434067302	12821	Economy	13400.00
0005434067529	12821	Economy	13400.00
0005434067673	12821	Economy	13400.00
0005434081937	12821	Economy	13400.00
0005434067405	12821	Economy	13400.00
0005434081816	12821	Economy	13400.00
0005434067061	12821	Economy	13400.00
0005434081869	12821	Economy	13400.00
0005434067721	12821	Economy	13400.00
0005434067324	12821	Economy	13400.00
0005434067705	12821	Economy	13400.00
0005434067453	12821	Economy	13400.00
0005434067511	12821	Economy	13400.00
0005432159899	12821	Economy	13400.00
0005434081903	12821	Economy	13400.00
0005434081950	12821	Economy	13400.00
0005434067513	12821	Economy	13400.00
0005434081951	12821	Economy	13400.00
0005434081882	12821	Economy	13400.00
0005434067301	12821	Economy	13400.00
0005433989766	12821	Economy	13400.00
0005434081862	12821	Economy	13400.00
0005434081855	12821	Economy	13400.00
0005434067406	12821	Economy	13400.00
0005432433726	12821	Economy	13400.00
0005434067386	12821	Economy	13400.00
0005434081897	12821	Economy	13400.00
0005434067590	12821	Economy	13400.00
0005434067438	12821	Economy	13400.00
0005434067690	12821	Economy	13400.00
0005434082031	12821	Economy	13400.00
0005434067184	12821	Economy	13400.00
0005434067560	12821	Economy	13400.00
0005434081796	12821	Economy	13400.00
0005433812922	12821	Economy	13400.00
0005434067593	12821	Economy	13400.00
0005434067658	12821	Economy	13400.00
0005434067435	12821	Economy	13400.00
0005434067062	12821	Economy	13400.00
0005434081954	12821	Economy	13400.00
0005432433729	12821	Economy	13400.00
0005434081997	12821	Economy	13400.00
0005434067657	12821	Economy	13400.00
0005434067379	12821	Economy	13400.00
0005434067281	12821	Economy	13400.00
0005434082030	12821	Economy	13400.00
0005432159900	12821	Economy	13400.00
0005434067487	12821	Economy	13400.00
0005434067496	12821	Economy	13400.00
0005434067437	12821	Economy	13400.00
0005432161173	12821	Economy	13400.00
0005432159898	12821	Economy	13400.00
0005434067549	12821	Economy	13400.00
0005434067815	12821	Economy	13400.00
0005434082105	30639	Business	40300.00
0005434068158	30639	Business	40300.00
0005434068123	30639	Business	40300.00
0005434068110	30639	Business	40300.00
0005432150258	30639	Business	40300.00
0005432150256	30639	Business	40300.00
0005434068141	30639	Business	40300.00
0005434068150	30639	Business	40300.00
0005434068131	30639	Business	40300.00
0005434068118	30639	Business	40300.00
0005433812882	30639	Business	40300.00
0005434068173	30639	Business	40300.00
0005434068149	30639	Economy	13400.00
0005432150255	30639	Economy	13400.00
0005434068176	30639	Economy	13400.00
0005433989808	30639	Economy	13400.00
0005434082092	30639	Economy	13400.00
0005432150259	30639	Economy	13400.00
0005434082097	30639	Economy	13400.00
0005433812879	30639	Economy	13400.00
0005434068155	30639	Economy	13400.00
0005432150260	30639	Economy	13400.00
0005434082102	30639	Economy	13400.00
0005434082096	30639	Economy	13400.00
0005434068130	30639	Economy	13400.00
0005434026722	30639	Economy	13400.00
0005434068181	30639	Economy	13400.00
0005434082108	30639	Economy	13400.00
0005434082101	30639	Economy	13400.00
0005432150261	30639	Economy	13400.00
0005434082104	30639	Economy	13400.00
0005434068160	30639	Economy	13400.00
0005434068113	30639	Economy	13400.00
0005434068156	30639	Economy	13400.00
0005434068122	30639	Economy	13400.00
0005432150262	30639	Economy	13400.00
0005434068166	30639	Economy	13400.00
0005434068167	30639	Economy	13400.00
0005434068136	30639	Economy	13400.00
0005434082098	30639	Economy	13400.00
0005434068146	30639	Economy	13400.00
0005434068180	30639	Economy	13400.00
0005434068127	30639	Economy	13400.00
0005434068171	30639	Economy	13400.00
0005433812886	30639	Economy	13400.00
0005434082094	30639	Economy	13400.00
0005434068138	30639	Economy	13400.00
0005434082103	30639	Economy	13400.00
0005433812883	30639	Economy	13400.00
0005434068143	30639	Economy	13400.00
0005434068182	30639	Economy	13400.00
0005432150263	30639	Economy	13400.00
0005434068151	30639	Economy	14800.00
0005434026720	30639	Economy	14800.00
0005434068148	30639	Economy	14800.00
0005434082093	30639	Economy	14800.00
0005434068161	30639	Economy	14800.00
0005434068121	30639	Economy	14800.00
0005434068169	30639	Economy	13400.00
0005434026717	30639	Economy	13400.00
0005434068152	30639	Economy	13400.00
0005434026721	30639	Economy	13400.00
0005434068178	30639	Economy	13400.00
0005434026715	30639	Economy	13400.00
0005434026723	30639	Economy	13400.00
0005434068168	30639	Economy	13400.00
0005434068135	30639	Economy	13400.00
0005433989812	30639	Economy	13400.00
0005434068179	30639	Economy	13400.00
0005434068154	30639	Economy	13400.00
0005434082106	30639	Economy	13400.00
0005434068153	30639	Economy	13400.00
0005432186901	30639	Economy	13400.00
0005434068128	30639	Economy	13400.00
0005434068162	30639	Economy	13400.00
0005434068129	30639	Economy	13400.00
0005434068159	30639	Economy	13400.00
0005434082090	30639	Economy	13400.00
0005434068163	30639	Economy	13400.00
0005434068114	30639	Economy	13400.00
0005434068137	30639	Economy	13400.00
0005434026719	30639	Economy	13400.00
0005434068164	30639	Economy	13400.00
0005434068139	30639	Economy	13400.00
0005432186899	30639	Economy	13400.00
0005434068147	30639	Economy	13400.00
0005434068115	30639	Economy	13400.00
0005434068133	30639	Economy	13400.00
0005434082095	30639	Economy	13400.00
0005434068126	30639	Economy	13400.00
0005434082091	30639	Economy	13400.00
0005434068134	30639	Economy	13400.00
0005434068174	30639	Economy	13400.00
0005433812880	30639	Economy	13400.00
0005434068165	30639	Economy	13400.00
0005433812878	30639	Economy	13400.00
0005432186898	30639	Economy	13400.00
0005434068175	30639	Economy	13400.00
0005434068145	30639	Economy	13400.00
0005433812887	30639	Economy	13400.00
0005433989811	30639	Economy	13400.00
0005434082099	30639	Economy	13400.00
0005432186900	30639	Economy	13400.00
0005433812881	30639	Economy	13400.00
0005434068144	30639	Economy	13400.00
0005434082100	30639	Economy	13400.00
0005432150257	30639	Economy	13400.00
0005434026716	30639	Economy	13400.00
0005434068112	30639	Economy	13400.00
0005434068142	30639	Economy	13400.00
0005434068111	30639	Economy	13400.00
0005433989809	30639	Economy	13400.00
0005434068177	30639	Economy	13400.00
0005434068116	30639	Economy	13400.00
0005432433696	30639	Economy	13400.00
0005434068119	30639	Economy	13400.00
0005432186897	30639	Economy	13400.00
0005434068140	30639	Economy	13400.00
0005434068172	30639	Economy	13400.00
0005433989810	30639	Economy	13400.00
0005434026718	30639	Economy	13400.00
0005434082107	30639	Economy	13400.00
0005433812893	30639	Economy	13400.00
0005434068117	30639	Economy	13400.00
0005434068124	30639	Economy	13400.00
0005434068125	30639	Economy	13400.00
0005434068157	30639	Economy	13400.00
0005434068170	30639	Economy	13400.00
0005434068132	30639	Economy	13400.00
0005434068120	30639	Economy	13400.00
0005433529313	5516	Business	35300.00
0005435766775	5516	Business	35300.00
0005435766800	5516	Business	35300.00
0005435766809	5516	Business	35300.00
0005433527303	5516	Business	35300.00
0005434264988	5516	Business	35300.00
0005433527304	5516	Business	35300.00
0005435766769	5516	Business	35300.00
0005435766779	5516	Business	35300.00
0005432140525	5516	Business	35300.00
0005435462340	5516	Business	35300.00
0005435766790	5516	Business	35300.00
0005435735176	5516	Business	35300.00
0005435766760	5516	Business	35300.00
0005435766756	5516	Business	35300.00
0005434265151	5516	Business	35300.00
0005435766783	5516	Business	35300.00
0005435462432	5516	Business	35300.00
0005435766771	5516	Business	35300.00
0005434831151	5516	Business	35300.00
0005435462464	5516	Business	35300.00
0005435462536	5516	Business	35300.00
0005434265031	5516	Business	35300.00
0005435735177	5516	Economy	12900.00
0005435725640	5516	Economy	12900.00
0005435766788	5516	Economy	12900.00
0005435462428	5516	Economy	12900.00
0005434831145	5516	Economy	11800.00
0005435723064	5516	Economy	11800.00
0005435720833	5516	Economy	11800.00
0005435766757	5516	Economy	11800.00
0005432140518	5516	Economy	11800.00
0005435462442	5516	Economy	11800.00
0005435766794	5516	Economy	11800.00
0005433527302	5516	Economy	11800.00
0005435766808	5516	Economy	11800.00
0005435766812	5516	Economy	11800.00
0005435462446	5516	Economy	11800.00
0005435766805	5516	Economy	11800.00
0005434265191	5516	Economy	11800.00
0005435766780	5516	Economy	11800.00
0005435766758	5516	Economy	11800.00
0005435725639	5516	Economy	11800.00
0005434264987	5516	Economy	11800.00
0005434265195	5516	Economy	11800.00
0005435766802	5516	Economy	11800.00
0005435766764	5516	Economy	11800.00
0005435766793	5516	Economy	11800.00
0005435766810	5516	Economy	11800.00
0005435725641	5516	Economy	11800.00
0005435766759	5516	Economy	11800.00
0005434265255	5516	Economy	11800.00
0005435462447	5516	Economy	11800.00
0005435766781	5516	Economy	11800.00
0005434265177	5516	Economy	11800.00
0005435462572	5516	Economy	11800.00
0005435462401	5516	Economy	11800.00
0005435766806	5516	Economy	11800.00
0005432140520	5516	Economy	11800.00
0005434831155	5516	Economy	11800.00
0005435766796	5516	Economy	11800.00
0005435462344	5516	Economy	11800.00
0005432535830	5516	Economy	11800.00
0005435462409	5516	Economy	11800.00
0005435723065	5516	Economy	11800.00
0005435766765	5516	Economy	11800.00
0005434265106	5516	Economy	11800.00
0005435766791	5516	Economy	11800.00
0005435766789	5516	Economy	11800.00
0005435766773	5516	Economy	11800.00
0005433527301	5516	Economy	11800.00
0005435462485	5516	Economy	11800.00
0005432140523	5516	Economy	11800.00
0005435766814	5516	Economy	11800.00
0005434265202	5516	Economy	11800.00
0005435722077	5516	Economy	11800.00
0005435462383	5516	Economy	11800.00
0005434831146	5516	Economy	11800.00
0005435462571	5516	Economy	11800.00
0005435462463	5516	Economy	11800.00
0005433529312	5516	Economy	11800.00
0005435766799	5516	Economy	11800.00
0005434831147	5516	Economy	11800.00
0005435725642	5516	Economy	11800.00
0005435766763	5516	Economy	11800.00
0005434265178	5516	Economy	11800.00
0005435766786	5516	Economy	11800.00
0005435723062	5516	Economy	11800.00
0005434265267	5516	Economy	11800.00
0005435766753	5516	Economy	11800.00
0005435735174	5516	Economy	11800.00
0005435462548	5516	Economy	11800.00
0005435462339	5516	Economy	11800.00
0005434265121	5516	Economy	11800.00
0005435766778	5516	Economy	11800.00
0005434265122	5516	Economy	11800.00
0005435766795	5516	Economy	11800.00
0005435723063	5516	Economy	11800.00
0005435462441	5516	Economy	11800.00
0005432140519	5516	Economy	11800.00
0005435462541	5516	Economy	11800.00
0005435766811	5516	Economy	11800.00
0005435462268	5516	Economy	11800.00
0005432140522	5516	Economy	11800.00
0005435766776	5516	Economy	11800.00
0005435766807	5516	Economy	12900.00
0005433527300	5516	Economy	11800.00
0005435766813	5516	Economy	12900.00
0005435462294	5516	Economy	11800.00
0005435735175	5516	Economy	11800.00
0005434265085	5516	Economy	11800.00
0005435766768	5516	Economy	11800.00
0005435462293	5516	Economy	11800.00
0005435735178	5516	Economy	11800.00
0005435766797	5516	Economy	11800.00
0005435766777	5516	Economy	11800.00
0005435766782	5516	Economy	11800.00
0005435462570	5516	Economy	11800.00
0005435725643	5516	Economy	11800.00
0005435462470	5516	Economy	11800.00
0005435462400	5516	Economy	11800.00
0005434265199	5516	Economy	11800.00
0005435766815	5516	Economy	11800.00
0005434265045	5516	Economy	11800.00
0005435766762	5516	Economy	11800.00
0005435462328	5516	Economy	11800.00
0005435462267	5516	Economy	11800.00
0005435462402	5516	Economy	11800.00
0005435462456	5516	Economy	11800.00
0005432535836	5516	Economy	11800.00
0005435766801	5516	Economy	11800.00
0005432535829	5516	Economy	11800.00
0005433529314	5516	Economy	11800.00
0005435462448	5516	Economy	11800.00
0005432535850	5516	Economy	11800.00
0005435766792	5516	Economy	11800.00
0005434265210	5516	Economy	11800.00
0005435735173	5516	Economy	11800.00
0005435462608	5516	Economy	11800.00
0005435766804	5516	Economy	11800.00
0005432140521	5516	Economy	11800.00
0005434265074	5516	Economy	11800.00
0005434265132	5516	Economy	11800.00
0005435766754	5516	Economy	11800.00
0005434265055	5516	Economy	11800.00
0005435462487	5516	Economy	11800.00
0005435043284	5516	Economy	11800.00
0005435462454	5516	Economy	11800.00
0005435766785	5516	Economy	11800.00
0005435766787	5516	Economy	11800.00
0005434265206	5516	Economy	11800.00
0005435462329	5516	Economy	11800.00
0005432535837	5516	Economy	11800.00
0005434265138	5516	Economy	11800.00
0005435462427	5516	Economy	11800.00
0005435462451	5516	Economy	11800.00
0005435462371	5516	Economy	11800.00
0005432140524	5516	Economy	11800.00
0005435766803	5516	Economy	11800.00
0005435766774	5516	Economy	11800.00
0005435766798	5516	Economy	11800.00
0005435766761	5516	Economy	11800.00
0005435766770	5516	Economy	11800.00
0005435462367	5516	Economy	11800.00
0005435720832	5516	Economy	11800.00
0005432535792	5516	Economy	11800.00
0005435462341	5516	Economy	11800.00
0005435722076	5516	Economy	11800.00
0005435766767	5516	Economy	11800.00
0005435766784	5516	Economy	11800.00
0005435766766	5516	Economy	11800.00
0005435766772	5516	Economy	11800.00
0005435766755	5516	Economy	11800.00
0005434831193	13492	Business	35300.00
0005435462762	13492	Business	35300.00
0005435766184	13492	Business	35300.00
0005435462789	13492	Business	35300.00
0005435766158	13492	Business	35300.00
0005435462763	13492	Business	35300.00
0005435766496	13492	Business	35300.00
0005432194551	13492	Business	35300.00
0005435766147	13492	Business	35300.00
0005435725591	13492	Business	35300.00
0005435766286	13492	Business	35300.00
0005435766497	13492	Business	35300.00
0005434831197	13492	Business	35300.00
0005434831194	13492	Business	35300.00
0005435462765	13492	Business	35300.00
0005435766298	13492	Business	35300.00
0005434265372	13492	Business	35300.00
0005435766233	13492	Business	35300.00
0005435462782	13492	Business	35300.00
0005435462769	13492	Business	35300.00
0005435462764	13492	Business	35300.00
0005435725614	13492	Business	35300.00
0005434265365	13492	Business	35300.00
0005435462766	13492	Business	35300.00
0005435766382	13492	Economy	12900.00
0005435462787	13492	Economy	12900.00
0005434265382	13492	Economy	11800.00
0005432535881	13492	Economy	11800.00
0005434265367	13492	Economy	11800.00
0005435725606	13492	Economy	11800.00
0005435766448	13492	Economy	11800.00
0005435766209	13492	Economy	11800.00
0005435766469	13492	Economy	11800.00
0005435725604	13492	Economy	11800.00
0005434265386	13492	Economy	11800.00
0005435462773	13492	Economy	11800.00
0005435766112	13492	Economy	11800.00
0005435765997	13492	Economy	11800.00
0005435766299	13492	Economy	11800.00
0005435766078	13492	Economy	11800.00
0005435462777	13492	Economy	11800.00
0005435766100	13492	Economy	11800.00
0005435766214	13492	Economy	11800.00
0005435766399	13492	Economy	11800.00
0005435043292	13492	Economy	11800.00
0005435766031	13492	Economy	11800.00
0005432194550	13492	Economy	11800.00
0005435462791	13492	Economy	11800.00
0005435462771	13492	Economy	11800.00
0005432194548	13492	Economy	11800.00
0005435766232	13492	Economy	11800.00
0005435766305	13492	Economy	11800.00
0005432535876	13492	Economy	11800.00
0005435766375	13492	Economy	11800.00
0005435462794	13492	Economy	11800.00
0005435462793	13492	Economy	11800.00
0005434265377	13492	Economy	11800.00
0005435462785	13492	Economy	11800.00
0005435766171	13492	Economy	11800.00
0005435766381	13492	Economy	11800.00
0005435462779	13492	Economy	11800.00
0005435765959	13492	Economy	11800.00
0005435462780	13492	Economy	11800.00
0005435766378	13492	Economy	11800.00
0005435766438	13492	Economy	11800.00
0005435462767	13492	Economy	11800.00
0005435462796	13492	Economy	11800.00
0005435720130	13492	Economy	11800.00
0005434265371	13492	Economy	11800.00
0005435766110	13492	Economy	11800.00
0005435725611	13492	Economy	11800.00
0005432194549	13492	Economy	11800.00
0005434831196	13492	Economy	11800.00
0005434265387	13492	Economy	11800.00
0005435766330	13492	Economy	11800.00
0005434265384	13492	Economy	11800.00
0005435766101	13492	Economy	11800.00
0005435766446	13492	Economy	11800.00
0005435462790	13492	Economy	11800.00
0005435766111	13492	Economy	11800.00
0005435766287	13492	Economy	11800.00
0005435766481	13492	Economy	11800.00
0005435462775	13492	Economy	11800.00
0005435766304	13492	Economy	11800.00
0005435766119	13492	Economy	11800.00
0005435462781	13492	Economy	11800.00
0005435766253	13492	Economy	11800.00
0005435766051	13492	Economy	11800.00
0005435725592	13492	Economy	11800.00
0005435462774	13492	Economy	11800.00
0005435766452	13492	Economy	11800.00
0005434265378	13492	Economy	11800.00
0005435462768	13492	Economy	11800.00
0005434265388	13492	Economy	11800.00
0005435766395	13492	Economy	11800.00
0005435766200	13492	Economy	11800.00
0005435723042	13492	Economy	11800.00
0005435462788	13492	Economy	11800.00
0005435766173	13492	Economy	11800.00
0005435723041	13492	Economy	12900.00
0005432535877	13492	Economy	12900.00
0005432535878	13492	Economy	11800.00
0005435766231	13492	Economy	12900.00
0005435766288	13492	Economy	12900.00
0005432194547	13492	Economy	11800.00
0005434265366	13492	Economy	11800.00
0005434265385	13492	Economy	11800.00
0005435766180	13492	Economy	11800.00
0005434265364	13492	Economy	11800.00
0005435766197	13492	Economy	11800.00
0005435462799	13492	Economy	11800.00
0005435765826	13492	Economy	11800.00
0005434265375	13492	Economy	11800.00
0005435462797	13492	Economy	11800.00
0005435766398	13492	Economy	11800.00
0005435462795	13492	Economy	11800.00
0005435766391	13492	Economy	11800.00
0005434265379	13492	Economy	11800.00
0005435462772	13492	Economy	11800.00
0005435462798	13492	Economy	11800.00
0005435462770	13492	Economy	11800.00
0005435766148	13492	Economy	11800.00
0005435766377	13492	Economy	11800.00
0005435766139	13492	Economy	11800.00
0005434265380	13492	Economy	11800.00
0005435766396	13492	Economy	11800.00
0005435766109	13492	Economy	11800.00
0005432535879	13492	Economy	11800.00
0005434265376	13492	Economy	11800.00
0005435462776	13492	Economy	11800.00
0005435766235	13492	Economy	11800.00
0005434265373	13492	Economy	11800.00
0005435735128	13492	Economy	11800.00
0005434265381	13492	Economy	11800.00
0005434265383	13492	Economy	11800.00
0005435766172	13492	Economy	11800.00
0005435462786	13492	Economy	11800.00
0005435766097	13492	Economy	11800.00
0005434265368	13492	Economy	11800.00
0005435462783	13492	Economy	11800.00
0005435462778	13492	Economy	11800.00
0005434265370	13492	Economy	11800.00
0005435725610	13492	Economy	11800.00
0005434265374	13492	Economy	11800.00
0005435766143	13492	Economy	11800.00
0005435766384	13492	Economy	11800.00
0005435766453	13492	Economy	11800.00
0005434265369	13492	Economy	11800.00
0005435462792	13492	Economy	11800.00
0005435766283	13492	Economy	11800.00
0005435735136	13492	Economy	11800.00
0005435462784	13492	Economy	11800.00
0005434831195	13492	Economy	11800.00
0005435766365	13492	Economy	11800.00
0005435766306	13492	Economy	11800.00
0005432535880	13492	Economy	11800.00
0005435766252	13492	Economy	11800.00
0005434602902	18635	Economy	3300.00
0005434602895	18635	Economy	3300.00
0005434602901	18635	Economy	3300.00
0005434602903	18635	Economy	3300.00
0005434602906	18635	Economy	3300.00
0005434602905	18635	Economy	3300.00
0005434602904	18635	Economy	3300.00
0005434604888	18722	Economy	3300.00
0005434514989	18722	Economy	3300.00
0005434513602	18722	Economy	3300.00
0005435904709	18722	Economy	3300.00
0005434513601	18722	Economy	3300.00
0005434514988	18722	Economy	3300.00
0005435904710	18722	Economy	3300.00
0005434604905	18722	Economy	3300.00
0005434514990	18722	Economy	3300.00
0005434602918	19203	Economy	3300.00
0005434602922	19203	Economy	3300.00
0005434514973	19203	Economy	3300.00
0005434602920	19203	Economy	3300.00
0005434514972	19203	Economy	3300.00
0005434514954	19203	Economy	3300.00
0005434602919	19203	Economy	3300.00
0005434602921	19203	Economy	3300.00
0005434602917	19203	Economy	3300.00
0005432632712	25090	Business	88300.00
0005435844348	25090	Business	88300.00
0005432649391	25090	Business	88300.00
0005435846285	25090	Business	88300.00
0005435846278	25090	Business	88300.00
0005435844349	25090	Business	88300.00
0005432632725	25090	Business	88300.00
0005432649396	25090	Business	88300.00
0005435846280	25090	Business	88300.00
0005432649427	25090	Business	88300.00
0005435846287	25090	Economy	29400.00
0005432632706	25090	Economy	29400.00
0005432649390	25090	Economy	29400.00
0005435844347	25090	Economy	29400.00
0005432649420	25090	Economy	29400.00
0005432632704	25090	Economy	29400.00
0005432632703	25090	Economy	29400.00
0005435846286	25090	Economy	29400.00
0005432632700	25090	Economy	29400.00
0005432632708	25090	Economy	32400.00
0005432632734	25090	Economy	32400.00
0005432649407	25090	Economy	32400.00
0005432649403	25090	Economy	32400.00
0005435846277	25090	Economy	29400.00
0005432632691	25090	Economy	29400.00
0005432632679	25090	Economy	29400.00
0005432632690	25090	Economy	29400.00
0005435844345	25090	Economy	29400.00
0005432649392	25090	Economy	29400.00
0005435846282	25090	Economy	29400.00
0005432649385	25090	Economy	29400.00
0005435844342	25090	Economy	29400.00
0005432632664	25090	Economy	29400.00
0005432632718	25090	Economy	29400.00
0005435844338	25090	Economy	29400.00
0005432632688	25090	Economy	29400.00
0005432632678	25090	Economy	29400.00
0005435844340	25090	Economy	29400.00
0005432632689	25090	Economy	29400.00
0005432632701	25090	Economy	29400.00
0005432632693	25090	Economy	29400.00
0005432632728	25090	Economy	29400.00
0005432632730	25090	Economy	29400.00
0005432632722	25090	Economy	29400.00
0005435846283	25090	Economy	29400.00
0005432632657	25090	Economy	29400.00
0005432632697	25090	Economy	29400.00
0005432632719	25090	Economy	29400.00
0005432632709	25090	Economy	29400.00
0005432632711	25090	Economy	29400.00
0005432632705	25090	Economy	29400.00
0005432649421	25090	Economy	29400.00
0005432632723	25090	Economy	29400.00
0005432632707	25090	Economy	29400.00
0005435844341	25090	Economy	29400.00
0005435846279	25090	Economy	29400.00
0005435846281	25090	Economy	29400.00
0005435844343	25090	Economy	29400.00
0005435844339	25090	Economy	29400.00
0005432632692	25090	Economy	29400.00
0005435846284	25090	Economy	29400.00
0005432649428	25090	Economy	29400.00
0005432649406	25090	Economy	29400.00
0005432632677	25090	Economy	29400.00
0005432632732	25090	Economy	29400.00
0005432632684	25090	Economy	29400.00
0005435844344	25090	Economy	29400.00
0005432632687	25090	Economy	29400.00
0005432632702	25090	Economy	29400.00
0005432649410	25090	Economy	29400.00
0005432632710	25090	Economy	29400.00
0005432632729	25090	Economy	29400.00
0005435844346	25090	Economy	29400.00
0005433285477	1870	Business	48700.00
0005433008543	1870	Business	48700.00
0005433008599	1870	Business	48700.00
0005433008688	1870	Business	48700.00
0005433008618	1870	Business	48700.00
0005433008601	1870	Business	48700.00
0005433285413	1870	Business	48700.00
0005433285374	1870	Business	48700.00
0005433008681	1870	Business	48700.00
0005433810581	1870	Business	48700.00
0005433008680	1870	Business	48700.00
0005433285405	1870	Economy	16200.00
0005433008619	1870	Economy	16200.00
0005433810582	1870	Economy	16200.00
0005433008591	1870	Economy	16200.00
0005433008662	1870	Economy	16200.00
0005433008625	1870	Economy	16200.00
0005433008600	1870	Economy	16200.00
0005433285344	1870	Economy	16200.00
0005433810580	1870	Economy	16200.00
0005433008562	1870	Economy	17900.00
0005433008585	1870	Economy	17900.00
0005433008584	1870	Economy	17900.00
0005433285310	1870	Economy	17900.00
0005433008561	1870	Economy	17900.00
0005433008719	1870	Economy	16200.00
0005433285301	1870	Economy	16200.00
0005433008669	1870	Economy	16200.00
0005433008664	1870	Economy	16200.00
0005433285318	1870	Economy	16200.00
0005433008686	1870	Economy	16200.00
0005433285311	1870	Economy	16200.00
0005433008822	1870	Economy	16200.00
0005433285457	1870	Economy	16200.00
0005433285514	1870	Economy	16200.00
0005433008705	1870	Economy	16200.00
0005433285300	1870	Economy	16200.00
0005433008810	1870	Economy	16200.00
0005433008592	1870	Economy	16200.00
0005433285456	1870	Economy	16200.00
0005433008624	1870	Economy	16200.00
0005433008839	1870	Economy	16200.00
0005433008679	1870	Economy	16200.00
0005433285459	1870	Economy	16200.00
0005433008665	1870	Economy	16200.00
0005433285244	1870	Economy	16200.00
0005433008663	1870	Economy	16200.00
0005433008783	1870	Economy	16200.00
0005433285375	1870	Economy	16200.00
0005433008687	1870	Economy	16200.00
0005433008753	1870	Economy	16200.00
0005433008586	1870	Economy	16200.00
0005433008700	1870	Economy	16200.00
0005433008678	1870	Economy	16200.00
0005433008603	1870	Economy	16200.00
0005433285337	1870	Economy	16200.00
0005433285373	1870	Economy	16200.00
0005433008564	1870	Economy	16200.00
0005432295905	1870	Economy	16200.00
0005433285223	1870	Economy	16200.00
0005433008542	1870	Economy	16200.00
0005433008577	1870	Economy	16200.00
0005433008563	1870	Economy	16200.00
0005433285336	1870	Economy	16200.00
0005433008647	1870	Economy	16200.00
0005433008604	1870	Economy	16200.00
0005432295904	1870	Economy	16200.00
0005433008633	1870	Economy	16200.00
0005433008798	1870	Economy	16200.00
0005433285309	1870	Economy	16200.00
0005433008590	1870	Economy	16200.00
0005433008614	1870	Economy	16200.00
0005433285236	1870	Economy	16200.00
0005433008644	1870	Economy	16200.00
0005433008741	1870	Economy	16200.00
0005433285189	1870	Economy	16200.00
0005433008752	1870	Economy	16200.00
0005433008740	1870	Economy	16200.00
0005433008751	1870	Economy	16200.00
0005433008606	1870	Economy	16200.00
0005432295903	1870	Economy	16200.00
0005433008782	1870	Economy	16200.00
0005433285342	1870	Economy	16200.00
0005433008794	1870	Economy	16200.00
0005433008811	1870	Economy	16200.00
0005433008648	1870	Economy	16200.00
0005433285386	1870	Economy	16200.00
0005433009009	22561	Business	48700.00
0005433285581	22561	Business	48700.00
0005433285568	22561	Business	48700.00
0005433008997	22561	Business	48700.00
0005433008983	22561	Business	48700.00
0005433009000	22561	Business	48700.00
0005433285573	22561	Business	48700.00
0005433008996	22561	Business	48700.00
0005433009007	22561	Business	48700.00
0005433008990	22561	Economy	16200.00
0005433285564	22561	Economy	16200.00
0005433285562	22561	Economy	16200.00
0005433008994	22561	Economy	16200.00
0005433009019	22561	Economy	16200.00
0005433009010	22561	Economy	16200.00
0005433285551	22561	Economy	16200.00
0005433009025	22561	Economy	16200.00
0005433008993	22561	Economy	17900.00
0005433008999	22561	Economy	17900.00
0005433009013	22561	Economy	17900.00
0005433008986	22561	Economy	17900.00
0005433009002	22561	Economy	17900.00
0005433285561	22561	Economy	16200.00
0005433285574	22561	Economy	16200.00
0005433009004	22561	Economy	16200.00
0005433285580	22561	Economy	16200.00
0005433285576	22561	Economy	16200.00
0005433009027	22561	Economy	16200.00
0005433009001	22561	Economy	16200.00
0005433810525	22561	Economy	16200.00
0005433285563	22561	Economy	16200.00
0005433009003	22561	Economy	16200.00
0005433009023	22561	Economy	16200.00
0005433285579	22561	Economy	16200.00
0005433009012	22561	Economy	16200.00
0005433009016	22561	Economy	16200.00
0005433285560	22561	Economy	16200.00
0005433285565	22561	Economy	16200.00
0005433285553	22561	Economy	16200.00
0005433285570	22561	Economy	16200.00
0005433810516	22561	Economy	16200.00
0005433008989	22561	Economy	16200.00
0005433285558	22561	Economy	16200.00
0005433009015	22561	Economy	16200.00
0005433285557	22561	Economy	16200.00
0005433009017	22561	Economy	16200.00
0005433285566	22561	Economy	16200.00
0005433009014	22561	Economy	16200.00
0005433009022	22561	Economy	16200.00
0005433009026	22561	Economy	16200.00
0005433009021	22561	Economy	16200.00
0005433009020	22561	Economy	16200.00
0005433285556	22561	Economy	16200.00
0005433009011	22561	Economy	16200.00
0005433285567	22561	Economy	16200.00
0005433008988	22561	Economy	16200.00
0005433008998	22561	Economy	16200.00
0005433285554	22561	Economy	16200.00
0005433285569	22561	Economy	16200.00
0005433285571	22561	Economy	16200.00
0005433009006	22561	Economy	16200.00
0005433810524	22561	Economy	16200.00
0005433285559	22561	Economy	16200.00
0005433285577	22561	Economy	16200.00
0005433285552	22561	Economy	16200.00
0005433008985	22561	Economy	16200.00
0005433285572	22561	Economy	16200.00
0005433008982	22561	Economy	16200.00
0005433285578	22561	Economy	16200.00
0005433009008	22561	Economy	16200.00
0005433009018	22561	Economy	16200.00
0005433009005	22561	Economy	16200.00
0005433008995	22561	Economy	16200.00
0005433008992	22561	Economy	16200.00
0005433285575	22561	Economy	16200.00
0005433009024	22561	Economy	16200.00
0005433008987	22561	Economy	16200.00
0005433285555	22561	Economy	16200.00
0005433008991	22561	Economy	16200.00
0005433810515	22561	Economy	16200.00
0005433008984	22561	Economy	16200.00
0005433847264	5597	Business	99800.00
0005433847230	5597	Business	99800.00
0005433847272	5597	Business	99800.00
0005433847274	5597	Business	99800.00
0005433847276	5597	Business	99800.00
0005433847247	5597	Business	99800.00
0005433847251	5597	Business	99800.00
0005433847254	5597	Business	99800.00
0005435282515	5597	Business	99800.00
0005433847267	5597	Business	99800.00
0005433847221	5597	Business	99800.00
0005434173521	5597	Business	99800.00
0005433847224	5597	Business	99800.00
0005433847242	5597	Business	99800.00
0005435282601	5597	Business	99800.00
0005433847238	5597	Business	99800.00
0005435282403	5597	Business	99800.00
0005435282609	5597	Economy	33300.00
0005435282543	5597	Economy	33300.00
0005433847218	5597	Economy	33300.00
0005433847245	5597	Economy	33300.00
0005435282514	5597	Economy	33300.00
0005434173516	5597	Economy	33300.00
0005435282494	5597	Economy	33300.00
0005433847259	5597	Economy	33300.00
0005433847261	5597	Economy	33300.00
0005433847265	5597	Economy	33300.00
0005433847270	5597	Economy	36600.00
0005433847233	5597	Economy	36600.00
0005433847237	5597	Economy	36600.00
0005433847220	5597	Economy	33300.00
0005433847241	5597	Economy	36600.00
0005433847223	5597	Economy	33300.00
0005433847253	5597	Economy	33300.00
0005433847240	5597	Economy	33300.00
0005433847255	5597	Economy	33300.00
0005433847243	5597	Economy	33300.00
0005432081569	5597	Economy	33300.00
0005433847269	5597	Economy	33300.00
0005433847250	5597	Economy	33300.00
0005433815427	5597	Economy	33300.00
0005432081568	5597	Economy	33300.00
0005433847222	5597	Economy	33300.00
0005433847246	5597	Economy	33300.00
0005432081571	5597	Economy	33300.00
0005433847258	5597	Economy	33300.00
0005435282608	5597	Economy	33300.00
0005435282363	5597	Economy	33300.00
0005433847225	5597	Economy	33300.00
0005433847266	5597	Economy	33300.00
0005433847268	5597	Economy	33300.00
0005433847219	5597	Economy	33300.00
0005433847227	5597	Economy	33300.00
0005433847231	5597	Economy	33300.00
0005435282469	5597	Economy	33300.00
0005435282437	5597	Economy	33300.00
0005433847252	5597	Economy	33300.00
0005433847248	5597	Economy	33300.00
0005433847226	5597	Economy	33300.00
0005433847271	5597	Economy	33300.00
0005433847262	5597	Economy	33300.00
0005435282490	5597	Economy	33300.00
0005433847260	5597	Economy	33300.00
0005433847263	5597	Economy	33300.00
0005435282552	5597	Economy	33300.00
0005433847275	5597	Economy	33300.00
0005432081570	5597	Economy	33300.00
0005433847234	5597	Economy	33300.00
0005433847256	5597	Economy	33300.00
0005435282495	5597	Economy	33300.00
0005433847235	5597	Economy	33300.00
0005433847273	5597	Economy	33300.00
0005435282465	5597	Economy	33300.00
0005433847249	5597	Economy	33300.00
0005435282649	5597	Economy	33300.00
0005435282610	5597	Economy	33300.00
0005433847239	5597	Economy	33300.00
0005433847232	5597	Economy	33300.00
0005435282650	5597	Economy	33300.00
0005435282464	5597	Economy	33300.00
0005433815428	5597	Economy	33300.00
0005433847228	5597	Economy	33300.00
0005435282641	5597	Economy	33300.00
0005433815426	5597	Economy	33300.00
0005435282517	5597	Economy	33300.00
0005433815425	5597	Economy	33300.00
0005435282538	5597	Economy	33300.00
0005433847244	5597	Economy	33300.00
0005433847236	5597	Economy	33300.00
0005434173526	5597	Economy	33300.00
0005433847257	5597	Economy	33300.00
0005433847229	5597	Economy	33300.00
0005435282553	5597	Economy	33300.00
0005432081567	5597	Economy	33300.00
0005434173515	5597	Economy	33300.00
0005433846763	13843	Business	99800.00
0005433846597	13843	Business	99800.00
0005433846753	13843	Business	99800.00
0005433815380	13843	Business	99800.00
0005433846728	13843	Business	99800.00
0005433846500	13843	Business	99800.00
0005433847139	13843	Business	99800.00
0005435282750	13843	Business	99800.00
0005435282733	13843	Business	99800.00
0005433846715	13843	Business	99800.00
0005433846663	13843	Business	99800.00
0005433846965	13843	Business	99800.00
0005433846599	13843	Business	99800.00
0005435282742	13843	Business	99800.00
0005433846880	13843	Business	99800.00
0005435282735	13843	Business	99800.00
0005433846679	13843	Business	99800.00
0005433815387	13843	Business	99800.00
0005433846598	13843	Economy	33300.00
0005433815393	13843	Economy	33300.00
0005435282748	13843	Economy	33300.00
0005433846662	13843	Economy	33300.00
0005435282739	13843	Economy	33300.00
0005435282738	13843	Economy	33300.00
0005433846661	13843	Economy	33300.00
0005433846698	13843	Economy	33300.00
0005433846757	13843	Economy	36600.00
0005433846621	13843	Economy	36600.00
0005435282751	13843	Economy	36600.00
0005435282734	13843	Economy	36600.00
0005433846864	13843	Economy	33300.00
0005435282743	13843	Economy	33300.00
0005433846913	13843	Economy	33300.00
0005433846685	13843	Economy	33300.00
0005433847018	13843	Economy	33300.00
0005434173557	13843	Economy	33300.00
0005433846431	13843	Economy	33300.00
0005433846754	13843	Economy	33300.00
0005433815392	13843	Economy	33300.00
0005433846643	13843	Economy	33300.00
0005435282745	13843	Economy	33300.00
0005433846771	13843	Economy	33300.00
0005433815395	13843	Economy	33300.00
0005435282732	13843	Economy	33300.00
0005433846805	13843	Economy	33300.00
0005433846717	13843	Economy	33300.00
0005433815385	13843	Economy	33300.00
0005435282747	13843	Economy	33300.00
0005433846644	13843	Economy	33300.00
0005435282746	13843	Economy	33300.00
0005435282741	13843	Economy	33300.00
0005432003730	13843	Economy	33300.00
0005433846912	13843	Economy	33300.00
0005433846633	13843	Economy	33300.00
0005433846322	13843	Economy	33300.00
0005433846769	13843	Economy	33300.00
0005433846954	13843	Economy	33300.00
0005433846686	13843	Economy	33300.00
0005433846791	13843	Economy	33300.00
0005433815388	13843	Economy	33300.00
0005433846803	13843	Economy	33300.00
0005434173555	13843	Economy	33300.00
0005433846961	13843	Economy	33300.00
0005434173559	13843	Economy	33300.00
0005433846835	13843	Economy	33300.00
0005435282740	13843	Economy	33300.00
0005435282736	13843	Economy	33300.00
0005433846772	13843	Economy	33300.00
0005433846742	13843	Economy	33300.00
0005433846687	13843	Economy	33300.00
0005433846417	13843	Economy	33300.00
0005433846737	13843	Economy	33300.00
0005433847032	13843	Economy	33300.00
0005433846714	13843	Economy	33300.00
0005433846950	13843	Economy	33300.00
0005432003728	13843	Economy	33300.00
0005433815394	13843	Economy	33300.00
0005433846736	13843	Economy	33300.00
0005433847019	13843	Economy	33300.00
0005433815384	13843	Economy	33300.00
0005433815365	13843	Economy	33300.00
0005433846955	13843	Economy	33300.00
0005435282737	13843	Economy	33300.00
0005435282744	13843	Economy	33300.00
0005433846989	13843	Economy	33300.00
0005433846758	13843	Economy	33300.00
0005432003729	13843	Economy	33300.00
0005433846654	13843	Economy	33300.00
0005434173556	13843	Economy	33300.00
0005433846651	13843	Economy	33300.00
0005435282749	13843	Economy	33300.00
0005434173558	13843	Economy	33300.00
0005433846953	13843	Economy	33300.00
0005433846678	13843	Economy	33300.00
0005433846482	13843	Economy	33300.00
0005434620771	7841	Economy	16600.00
0005435332387	7841	Economy	15100.00
0005434620778	7841	Economy	15100.00
0005432112535	7841	Economy	15100.00
0005434620770	7841	Economy	15100.00
0005434620776	7841	Economy	15100.00
0005434620781	7841	Economy	15100.00
0005434620774	7841	Economy	15100.00
0005435332308	7841	Economy	15100.00
0005435332307	7841	Economy	15100.00
0005434620786	7841	Economy	15100.00
0005434620790	7841	Economy	15100.00
0005434620780	7841	Economy	15100.00
0005434620772	7841	Economy	15100.00
0005432112536	7841	Economy	15100.00
0005434620779	7841	Economy	15100.00
0005435332368	7841	Economy	15100.00
0005434620782	7841	Economy	15100.00
0005432112537	7841	Economy	15100.00
0005434620784	7841	Economy	15100.00
0005435332369	7841	Economy	15100.00
0005434620773	7841	Economy	15100.00
0005434620789	7841	Economy	15100.00
0005434620775	7841	Economy	15100.00
0005434620787	7841	Economy	15100.00
0005434620785	7841	Economy	15100.00
0005434620788	7841	Economy	15100.00
0005435332366	7841	Economy	15100.00
0005434620777	7841	Economy	15100.00
0005434620769	7841	Economy	15100.00
0005434620783	7841	Economy	15100.00
0005434620543	32995	Economy	16600.00
0005434620576	32995	Economy	16600.00
0005435332430	32995	Economy	15100.00
0005435332431	32995	Economy	15100.00
0005434620560	32995	Economy	15100.00
0005434620727	32995	Economy	15100.00
0005434620511	32995	Economy	15100.00
0005435332427	32995	Economy	15100.00
0005434620680	32995	Economy	15100.00
0005435332428	32995	Economy	15100.00
0005435332433	32995	Economy	15100.00
0005434620575	32995	Economy	15100.00
0005435332426	32995	Economy	15100.00
0005434620569	32995	Economy	15100.00
0005435332425	32995	Economy	15100.00
0005434620592	32995	Economy	15100.00
0005434620559	32995	Economy	15100.00
0005434620540	32995	Economy	15100.00
0005434620618	32995	Economy	15100.00
0005435332432	32995	Economy	15100.00
0005435332424	32995	Economy	15100.00
0005434620544	32995	Economy	15100.00
0005435332429	32995	Economy	15100.00
0005435332434	32995	Economy	15100.00
0005434620561	32995	Economy	15100.00
0005434620538	32995	Economy	15100.00
0005435785676	4265	Business	38000.00
0005435785660	4265	Business	38000.00
0005435918669	4265	Business	38000.00
0005435785677	4265	Business	38000.00
0005435785683	4265	Business	38000.00
0005435937382	4265	Business	38000.00
0005432190664	4265	Business	38000.00
0005435785654	4265	Business	38000.00
0005435937384	4265	Business	38000.00
0005435785649	4265	Business	38000.00
0005435937381	4265	Economy	12700.00
0005435937374	4265	Economy	12700.00
0005434994109	4265	Economy	12700.00
0005435918668	4265	Economy	12700.00
0005432190666	4265	Economy	12700.00
0005435785678	4265	Economy	12700.00
0005435787372	4265	Economy	12700.00
0005435785656	4265	Economy	12700.00
0005435785679	4265	Economy	13900.00
0005435918643	4265	Economy	13900.00
0005435785657	4265	Economy	13900.00
0005435785684	4265	Economy	13900.00
0005435787373	4265	Economy	12700.00
0005435787374	4265	Economy	12700.00
0005434994110	4265	Economy	12700.00
0005434994114	4265	Economy	12700.00
0005435918652	4265	Economy	12700.00
0005432190665	4265	Economy	12700.00
0005435785665	4265	Economy	12700.00
0005435785661	4265	Economy	12700.00
0005435785666	4265	Economy	12700.00
0005435785674	4265	Economy	12700.00
0005435785681	4265	Economy	12700.00
0005435785671	4265	Economy	12700.00
0005432190662	4265	Economy	12700.00
0005435785675	4265	Economy	12700.00
0005435785658	4265	Economy	12700.00
0005435785682	4265	Economy	12700.00
0005435785663	4265	Economy	12700.00
0005434994106	4265	Economy	12700.00
0005435785669	4265	Economy	12700.00
0005435918651	4265	Economy	12700.00
0005435785655	4265	Economy	12700.00
0005435785668	4265	Economy	12700.00
0005435785670	4265	Economy	12700.00
0005434994112	4265	Economy	12700.00
0005435785672	4265	Economy	12700.00
0005434994105	4265	Economy	12700.00
0005435785680	4265	Economy	12700.00
0005434994113	4265	Economy	12700.00
0005434994111	4265	Economy	12700.00
0005434994108	4265	Economy	12700.00
0005434994107	4265	Economy	12700.00
0005435785651	4265	Economy	12700.00
0005435785659	4265	Economy	12700.00
0005435785650	4265	Economy	12700.00
0005432190663	4265	Economy	12700.00
0005435918648	4265	Economy	12700.00
0005435785667	4265	Economy	12700.00
0005435937383	4265	Economy	12700.00
0005435785664	4265	Economy	12700.00
0005435785673	4265	Economy	12700.00
0005435785652	4265	Economy	12700.00
0005435785662	4265	Economy	12700.00
0005435918662	4265	Economy	12700.00
0005435785653	4265	Economy	12700.00
0005435787358	27273	Business	38000.00
0005435785359	27273	Business	38000.00
0005435937417	27273	Business	38000.00
0005435785340	27273	Business	38000.00
0005435785330	27273	Business	38000.00
0005435785166	27273	Business	38000.00
0005435785462	27273	Economy	12700.00
0005435787357	27273	Economy	12700.00
0005435787344	27273	Economy	12700.00
0005435785223	27273	Economy	12700.00
0005432195710	27273	Economy	12700.00
0005435785285	27273	Economy	12700.00
0005434994010	27273	Economy	12700.00
0005435785483	27273	Economy	13900.00
0005435918699	27273	Economy	13900.00
0005435785339	27273	Economy	13900.00
0005434994021	27273	Economy	13900.00
0005434994058	27273	Economy	12700.00
0005435785227	27273	Economy	12700.00
0005435918696	27273	Economy	12700.00
0005435785374	27273	Economy	12700.00
0005435785264	27273	Economy	12700.00
0005435785218	27273	Economy	12700.00
0005435785228	27273	Economy	12700.00
0005434994030	27273	Economy	12700.00
0005435785187	27273	Economy	12700.00
0005435918701	27273	Economy	12700.00
0005435785243	27273	Economy	12700.00
0005435785208	27273	Economy	12700.00
0005435785384	27273	Economy	12700.00
0005435785179	27273	Economy	12700.00
0005435785240	27273	Economy	12700.00
0005435785329	27273	Economy	12700.00
0005435937416	27273	Economy	12700.00
0005435785118	27273	Economy	12700.00
0005434994059	27273	Economy	12700.00
0005435918698	27273	Economy	12700.00
0005435785383	27273	Economy	12700.00
0005434994052	27273	Economy	12700.00
0005435785225	27273	Economy	12700.00
0005434994033	27273	Economy	12700.00
0005434994025	27273	Economy	12700.00
0005435787345	27273	Economy	12700.00
0005435785085	27273	Economy	12700.00
0005434994020	27273	Economy	12700.00
0005434994022	27273	Economy	12700.00
0005435785196	27273	Economy	12700.00
0005435918700	27273	Economy	12700.00
0005432195711	27273	Economy	12700.00
0005435787359	27273	Economy	12700.00
0005435918697	27273	Economy	12700.00
0005435785161	27273	Economy	12700.00
0005435785177	27273	Economy	12700.00
0005435785119	27273	Economy	12700.00
0005435785219	27273	Economy	12700.00
0005434994024	27273	Economy	12700.00
0005435785276	27273	Economy	12700.00
0005435785183	27273	Economy	12700.00
0005435785328	27273	Economy	12700.00
0005435787349	27273	Economy	12700.00
0005435785331	27273	Economy	12700.00
0005435785412	27273	Economy	12700.00
0005435785297	27273	Economy	12700.00
0005434994060	27273	Economy	12700.00
0005435785226	27273	Economy	12700.00
0005435785267	27273	Economy	12700.00
0005432146217	19871	Economy	12800.00
0005432146216	19871	Economy	12800.00
0005432146215	19871	Economy	12800.00
0005434082113	4730	Business	40900.00
0005433452759	4730	Business	40900.00
0005432186904	4730	Business	40900.00
0005432460334	4730	Business	40900.00
0005432460294	4730	Business	40900.00
0005432568181	4730	Business	40900.00
0005432568196	4730	Business	40900.00
0005432460332	4730	Business	40900.00
0005432571356	4730	Business	40900.00
0005432460308	4730	Business	40900.00
0005432568154	4730	Business	40900.00
0005434082110	4730	Business	40900.00
0005432460327	4730	Business	40900.00
0005432460298	4730	Business	40900.00
0005432568207	4730	Business	40900.00
0005434082117	4730	Business	40900.00
0005432568193	4730	Business	40900.00
0005432460336	4730	Business	40900.00
0005432460323	4730	Business	40900.00
0005432460300	4730	Business	40900.00
0005432568191	4730	Economy	15000.00
0005434082124	4730	Business	40900.00
0005432460295	4730	Economy	15000.00
0005432460328	4730	Economy	15000.00
0005432568162	4730	Economy	13600.00
0005432460325	4730	Economy	13600.00
0005432460339	4730	Economy	13600.00
0005432568163	4730	Economy	13600.00
0005432568206	4730	Economy	13600.00
0005432568169	4730	Economy	13600.00
0005432568152	4730	Economy	13600.00
0005432568200	4730	Economy	13600.00
0005432568155	4730	Economy	13600.00
0005432170449	4730	Economy	13600.00
0005432460340	4730	Economy	13600.00
0005432568177	4730	Economy	13600.00
0005434082119	4730	Economy	13600.00
0005432568202	4730	Economy	13600.00
0005432460314	4730	Economy	13600.00
0005432170447	4730	Economy	13600.00
0005434082132	4730	Economy	13600.00
0005432568198	4730	Economy	13600.00
0005432568199	4730	Economy	13600.00
0005432571354	4730	Economy	13600.00
0005432568183	4730	Economy	13600.00
0005432460313	4730	Economy	13600.00
0005434082131	4730	Economy	13600.00
0005432460331	4730	Economy	13600.00
0005432460326	4730	Economy	13600.00
0005434082125	4730	Economy	13600.00
0005432568168	4730	Economy	13600.00
0005432568188	4730	Economy	13600.00
0005433452758	4730	Economy	13600.00
0005432170452	4730	Economy	13600.00
0005432170450	4730	Economy	13600.00
0005432460305	4730	Economy	13600.00
0005432568211	4730	Economy	13600.00
0005434082134	4730	Economy	13600.00
0005432568178	4730	Economy	13600.00
0005432460319	4730	Economy	13600.00
0005432568170	4730	Economy	13600.00
0005432186903	4730	Economy	13600.00
0005432460341	4730	Economy	13600.00
0005432568201	4730	Economy	13600.00
0005432568156	4730	Economy	13600.00
0005434082127	4730	Economy	13600.00
0005432460311	4730	Economy	13600.00
0005434082123	4730	Economy	13600.00
0005432568187	4730	Economy	13600.00
0005432460297	4730	Economy	13600.00
0005432568153	4730	Economy	13600.00
0005432460309	4730	Economy	13600.00
0005432460296	4730	Economy	13600.00
0005432568159	4730	Economy	13600.00
0005432460333	4730	Economy	13600.00
0005432571355	4730	Economy	13600.00
0005432460320	4730	Economy	13600.00
0005432568171	4730	Economy	13600.00
0005432460322	4730	Economy	13600.00
0005432568194	4730	Economy	13600.00
0005432460316	4730	Economy	13600.00
0005432460335	4730	Economy	13600.00
0005432571357	4730	Economy	13600.00
0005434082115	4730	Economy	13600.00
0005432460293	4730	Economy	13600.00
0005434082118	4730	Economy	13600.00
0005432568205	4730	Economy	13600.00
0005432568179	4730	Economy	13600.00
0005432568189	4730	Economy	13600.00
0005433726125	4730	Economy	13600.00
0005432568180	4730	Economy	13600.00
0005432460345	4730	Economy	13600.00
0005434082120	4730	Economy	13600.00
0005432460306	4730	Economy	13600.00
0005432460310	4730	Economy	13600.00
0005432568203	4730	Economy	13600.00
0005434082130	4730	Economy	13600.00
0005432460338	4730	Economy	13600.00
0005432460337	4730	Economy	13600.00
0005432568157	4730	Economy	15000.00
0005434082126	4730	Economy	13600.00
0005432568165	4730	Economy	13600.00
0005432460303	4730	Economy	13600.00
0005432568212	4730	Economy	15000.00
0005432568204	4730	Economy	13600.00
0005432460292	4730	Economy	13600.00
0005432568176	4730	Economy	13600.00
0005434082135	4730	Economy	13600.00
0005434082116	4730	Economy	13600.00
0005432568208	4730	Economy	13600.00
0005434082129	4730	Economy	13600.00
0005432460317	4730	Economy	13600.00
0005432460330	4730	Economy	13600.00
0005434082111	4730	Economy	13600.00
0005432568164	4730	Economy	13600.00
0005432460344	4730	Economy	13600.00
0005432186902	4730	Economy	13600.00
0005432460324	4730	Economy	13600.00
0005432568175	4730	Economy	13600.00
0005432568167	4730	Economy	13600.00
0005432568209	4730	Economy	13600.00
0005432170446	4730	Economy	13600.00
0005432568174	4730	Economy	13600.00
0005434082121	4730	Economy	13600.00
0005432568184	4730	Economy	13600.00
0005432460315	4730	Economy	13600.00
0005432460299	4730	Economy	13600.00
0005432460301	4730	Economy	13600.00
0005432460321	4730	Economy	13600.00
0005433451637	4730	Economy	13600.00
0005432568197	4730	Economy	13600.00
0005432568161	4730	Economy	13600.00
0005432170451	4730	Economy	13600.00
0005432568190	4730	Economy	13600.00
0005432460343	4730	Economy	13600.00
0005432460302	4730	Economy	13600.00
0005432568173	4730	Economy	13600.00
0005432460307	4730	Economy	13600.00
0005432568182	4730	Economy	13600.00
0005432568192	4730	Economy	13600.00
0005432568166	4730	Economy	13600.00
0005432568160	4730	Economy	13600.00
0005434082136	4730	Economy	13600.00
0005432568185	4730	Economy	13600.00
0005432568158	4730	Economy	13600.00
0005432460342	4730	Economy	13600.00
0005432460312	4730	Economy	13600.00
0005432568186	4730	Economy	13600.00
0005434082109	4730	Economy	13600.00
0005432460318	4730	Economy	13600.00
0005434082112	4730	Economy	13600.00
0005432460304	4730	Economy	13600.00
0005434082128	4730	Economy	13600.00
0005432568172	4730	Economy	13600.00
0005432568195	4730	Economy	13600.00
0005434082133	4730	Economy	13600.00
0005434082114	4730	Economy	13600.00
0005432568213	4730	Economy	13600.00
0005434082122	4730	Economy	13600.00
0005432568210	4730	Economy	13600.00
0005432460329	4730	Economy	13600.00
0005432170448	4730	Economy	13600.00
0005432567647	30526	Business	40900.00
0005432567864	30526	Business	40900.00
0005432459868	30526	Business	40900.00
0005432567769	30526	Business	40900.00
0005432460046	30526	Business	40900.00
0005432567885	30526	Business	40900.00
0005432567533	30526	Business	40900.00
0005432567472	30526	Business	40900.00
0005432459865	30526	Business	40900.00
0005432459884	30526	Business	40900.00
0005432567722	30526	Business	40900.00
0005432459908	30526	Business	40900.00
0005434081862	30526	Business	40900.00
0005432567776	30526	Business	40900.00
0005432459929	30526	Business	40900.00
0005432213643	30526	Business	40900.00
0005432567800	30526	Business	40900.00
0005432567784	30526	Business	40900.00
0005432459871	30526	Business	40900.00
0005432567834	30526	Economy	15000.00
0005434081950	30526	Economy	15000.00
0005434081826	30526	Economy	15000.00
0005432567828	30526	Economy	13600.00
0005433452744	30526	Economy	13600.00
0005432459861	30526	Economy	13600.00
0005434081997	30526	Economy	13600.00
0005432459992	30526	Economy	13600.00
0005432567768	30526	Economy	13600.00
0005432567785	30526	Economy	13600.00
0005432213641	30526	Economy	13600.00
0005432567709	30526	Economy	13600.00
0005434082031	30526	Economy	13600.00
0005434081836	30526	Economy	13600.00
0005432460019	30526	Economy	13600.00
0005432568017	30526	Economy	13600.00
0005432459983	30526	Economy	13600.00
0005432459957	30526	Economy	13600.00
0005432567753	30526	Economy	13600.00
0005432567833	30526	Economy	13600.00
0005432567835	30526	Economy	13600.00
0005432459930	30526	Economy	13600.00
0005434081794	30526	Economy	13600.00
0005432459809	30526	Economy	13600.00
0005432213640	30526	Economy	13600.00
0005432567881	30526	Economy	13600.00
0005432459869	30526	Economy	13600.00
0005432567687	30526	Economy	13600.00
0005434081909	30526	Economy	13600.00
0005434081817	30526	Economy	13600.00
0005432567667	30526	Economy	13600.00
0005434081796	30526	Economy	13600.00
0005432459702	30526	Economy	13600.00
0005432567611	30526	Economy	13600.00
0005434081856	30526	Economy	13600.00
0005432459907	30526	Economy	13600.00
0005432567958	30526	Economy	13600.00
0005434081923	30526	Economy	13600.00
0005432459914	30526	Economy	13600.00
0005432459637	30526	Economy	13600.00
0005432567911	30526	Economy	13600.00
0005432459997	30526	Economy	13600.00
0005432459793	30526	Economy	13600.00
0005432459899	30526	Economy	13600.00
0005432459978	30526	Economy	13600.00
0005432571335	30526	Economy	13600.00
0005432567796	30526	Economy	13600.00
0005434081937	30526	Economy	13600.00
0005432459931	30526	Economy	13600.00
0005432459970	30526	Economy	13600.00
0005434081951	30526	Economy	13600.00
0005432567607	30526	Economy	13600.00
0005432459864	30526	Economy	13600.00
0005434082030	30526	Economy	13600.00
0005432567516	30526	Economy	13600.00
0005432567581	30526	Economy	13600.00
0005432567411	30526	Economy	13600.00
0005432571334	30526	Economy	13600.00
0005432567786	30526	Economy	13600.00
0005432459858	30526	Economy	13600.00
0005434081838	30526	Economy	13600.00
0005432213642	30526	Economy	13600.00
0005432459937	30526	Economy	13600.00
0005432567646	30526	Economy	13600.00
0005432567773	30526	Economy	13600.00
0005434081769	30526	Economy	13600.00
0005434081855	30526	Economy	13600.00
0005432567865	30526	Economy	13600.00
0005432567534	30526	Economy	13600.00
0005432459925	30526	Economy	13600.00
0005432567580	30526	Economy	13600.00
0005432567817	30526	Economy	13600.00
0005432459860	30526	Economy	13600.00
0005434081903	30526	Economy	13600.00
0005432567537	30526	Economy	13600.00
0005432459638	30526	Economy	13600.00
0005432571333	30526	Economy	13600.00
0005432567540	30526	Economy	13600.00
0005432213639	30526	Economy	13600.00
0005432567827	30526	Economy	15000.00
0005432567535	30526	Economy	15000.00
0005432459794	30526	Economy	13600.00
0005432567811	30526	Economy	13600.00
0005432567612	30526	Economy	15000.00
0005432459787	30526	Economy	13600.00
0005432459958	30526	Economy	13600.00
0005432459882	30526	Economy	13600.00
0005433452743	30526	Economy	13600.00
0005432460012	30526	Economy	13600.00
0005432459820	30526	Economy	13600.00
0005432459923	30526	Economy	13600.00
0005432459959	30526	Economy	13600.00
0005432459701	30526	Economy	13600.00
0005434081875	30526	Economy	13600.00
0005432459866	30526	Economy	13600.00
0005432459883	30526	Economy	13600.00
0005434081908	30526	Economy	13600.00
0005432567664	30526	Economy	13600.00
0005432567536	30526	Economy	13600.00
0005434081816	30526	Economy	13600.00
0005433452740	30526	Economy	13600.00
0005432459916	30526	Economy	13600.00
0005434081954	30526	Economy	13600.00
0005432567464	30526	Economy	13600.00
0005434081882	30526	Economy	13600.00
0005432567859	30526	Economy	13600.00
0005432213638	30526	Economy	13600.00
0005432567832	30526	Economy	13600.00
0005432161172	30526	Economy	13600.00
0005432567532	30526	Economy	13600.00
0005432567606	30526	Economy	13600.00
0005434081833	30526	Economy	13600.00
0005432567561	30526	Economy	13600.00
0005434081832	30526	Economy	13600.00
0005432567853	30526	Economy	13600.00
0005433454873	30526	Economy	13600.00
0005434081955	30526	Economy	13600.00
0005432567755	30526	Economy	13600.00
0005432459898	30526	Economy	13600.00
0005434081897	30526	Economy	13600.00
0005432567688	30526	Economy	13600.00
0005432459792	30526	Economy	13600.00
0005432161173	30526	Economy	13600.00
0005432568016	30526	Economy	13600.00
0005432567757	30526	Economy	13600.00
0005432567758	30526	Economy	13600.00
0005432459872	30526	Economy	13600.00
0005432567823	30526	Economy	13600.00
0005432567634	30526	Economy	13600.00
0005432567826	30526	Economy	13600.00
0005433454881	30526	Economy	13600.00
0005432567544	30526	Economy	13600.00
0005432567678	30526	Economy	13600.00
0005432567560	30526	Economy	13600.00
0005432459799	30526	Economy	13600.00
0005432460128	30526	Economy	13600.00
0005432567444	30526	Economy	13600.00
0005432460127	30526	Economy	13600.00
0005432459703	30526	Economy	13600.00
0005434081869	30526	Economy	13600.00
0005432460002	30526	Economy	13600.00
0005432459740	30526	Economy	13600.00
0005432567378	30526	Economy	13600.00
0005432459743	30526	Economy	13600.00
0005432459971	30526	Economy	13600.00
0005434081874	30526	Economy	13600.00
0005432459960	30526	Economy	13600.00
0005432459845	30526	Economy	13600.00
0005432567839	30526	Economy	13600.00
0005435720832	13583	Economy	9900.00
0005435720833	13583	Economy	9900.00
0005435722077	13583	Economy	9900.00
0005435722076	13583	Economy	9900.00
0005435720134	21112	Economy	9900.00
0005435720132	21112	Economy	9900.00
0005435720133	21112	Economy	9900.00
0005432295903	22770	Economy	8800.00
0005432295905	22770	Economy	8800.00
0005432295904	22770	Economy	8800.00
0005435380305	11084	Business	23600.00
0005433344048	11084	Business	23600.00
0005433344089	11084	Business	23600.00
0005433344106	11084	Business	23600.00
0005435097280	11084	Business	23600.00
0005433344042	11084	Business	23600.00
0005433344125	11084	Business	23600.00
0005433344041	11084	Business	23600.00
0005433344115	11084	Business	23600.00
0005435508388	11084	Business	23600.00
0005435097286	11084	Business	23600.00
0005433344120	11084	Business	23600.00
0005435508346	11084	Economy	7900.00
0005433344060	11084	Economy	7900.00
0005433344097	11084	Economy	7900.00
0005433344088	11084	Economy	7900.00
0005435097284	11084	Economy	7900.00
0005435097285	11084	Economy	7900.00
0005433344065	11084	Economy	7900.00
0005433344057	11084	Economy	7900.00
0005433344075	11084	Economy	7900.00
0005433344114	11084	Economy	7900.00
0005433344033	11084	Economy	7900.00
0005433344109	11084	Economy	7900.00
0005433344054	11084	Economy	7900.00
0005433344085	11084	Economy	7900.00
0005433344069	11084	Economy	7900.00
0005433344124	11084	Economy	7900.00
0005433344078	11084	Economy	7900.00
0005433344066	11084	Economy	7900.00
0005433344079	11084	Economy	7900.00
0005433344056	11084	Economy	7900.00
0005433344025	11084	Economy	7900.00
0005433344059	11084	Economy	7900.00
0005433344072	11084	Economy	7900.00
0005433344091	11084	Economy	7900.00
0005433344077	11084	Economy	7900.00
0005435508379	11084	Economy	7900.00
0005433344035	11084	Economy	7900.00
0005433344082	11084	Economy	7900.00
0005433344090	11084	Economy	7900.00
0005435508363	11084	Economy	7900.00
0005433344084	11084	Economy	7900.00
0005433344102	11084	Economy	7900.00
0005435380284	11084	Economy	7900.00
0005433344105	11084	Economy	7900.00
0005433344103	11084	Economy	7900.00
0005433344095	11084	Economy	7900.00
0005433344068	11084	Economy	7900.00
0005433344104	11084	Economy	7900.00
0005433344062	11084	Economy	8600.00
0005433344096	11084	Economy	7900.00
0005433344044	11084	Economy	8600.00
0005433344100	11084	Economy	8600.00
0005435508329	11084	Economy	8600.00
0005433344036	11084	Economy	8600.00
0005433344024	11084	Economy	8600.00
0005435508342	11084	Economy	7900.00
0005433344045	11084	Economy	7900.00
0005433344031	11084	Economy	7900.00
0005433344087	11084	Economy	7900.00
0005435508343	11084	Economy	7900.00
0005433344027	11084	Economy	7900.00
0005433344119	11084	Economy	7900.00
0005433344076	11084	Economy	7900.00
0005433344067	11084	Economy	7900.00
0005435380283	11084	Economy	7900.00
0005435508330	11084	Economy	7900.00
0005433344080	11084	Economy	7900.00
0005433344055	11084	Economy	7900.00
0005433344051	11084	Economy	7900.00
0005433344026	11084	Economy	7900.00
0005433344049	11084	Economy	7900.00
0005433344064	11084	Economy	7900.00
0005433344123	11084	Economy	7900.00
0005433344058	11084	Economy	7900.00
0005433344046	11084	Economy	7900.00
0005433344092	11084	Economy	7900.00
0005433344117	11084	Economy	7900.00
0005433344043	11084	Economy	7900.00
0005433344116	11084	Economy	7900.00
0005433344032	11084	Economy	7900.00
0005435380306	11084	Economy	7900.00
0005433344039	11084	Economy	7900.00
0005433344063	11084	Economy	7900.00
0005433344029	11084	Economy	7900.00
0005435097288	11084	Economy	7900.00
0005433344110	11084	Economy	7900.00
0005433344030	11084	Economy	7900.00
0005433344111	11084	Economy	7900.00
0005433344061	11084	Economy	7900.00
0005433344112	11084	Economy	7900.00
0005435508326	11084	Economy	7900.00
0005433344107	11084	Economy	7900.00
0005435097281	11084	Economy	7900.00
0005433344038	11084	Economy	7900.00
0005433344070	11084	Economy	7900.00
0005435380298	11084	Economy	7900.00
0005435508331	11084	Economy	7900.00
0005435097287	11084	Economy	7900.00
0005433344073	11084	Economy	7900.00
0005433344053	11084	Economy	7900.00
0005433344052	11084	Economy	7900.00
0005435508358	11084	Economy	7900.00
0005433344094	11084	Economy	7900.00
0005435097282	11084	Economy	7900.00
0005435097283	11084	Economy	7900.00
0005433344122	11084	Economy	7900.00
0005433344118	11084	Economy	7900.00
0005433344086	11084	Economy	7900.00
0005433344037	11084	Economy	7900.00
0005433344101	11084	Economy	7900.00
0005433344093	11084	Economy	7900.00
0005433344074	11084	Economy	7900.00
0005433344081	11084	Economy	7900.00
0005433344050	11084	Economy	7900.00
0005435097289	11084	Economy	7900.00
0005433344034	11084	Economy	7900.00
0005433344099	11084	Economy	7900.00
0005433344083	11084	Economy	7900.00
0005433344028	11084	Economy	7900.00
0005433344098	11084	Economy	7900.00
0005433344047	11084	Economy	7900.00
0005433344108	11084	Economy	7900.00
0005433344121	11084	Economy	7900.00
0005433344113	11084	Economy	7900.00
0005433344040	11084	Economy	7900.00
0005433344071	11084	Economy	7900.00
0005433343374	17108	Business	23600.00
0005433342722	17108	Business	23600.00
0005433342961	17108	Business	23600.00
0005433343357	17108	Business	23600.00
0005433342855	17108	Business	23600.00
0005433342656	17108	Business	23600.00
0005433343409	17108	Business	23600.00
0005433342760	17108	Business	23600.00
0005433343188	17108	Business	23600.00
0005433343006	17108	Business	23600.00
0005433342848	17108	Business	23600.00
0005435545810	17108	Business	23600.00
0005433342672	17108	Economy	7900.00
0005435545805	17108	Economy	7900.00
0005435545806	17108	Economy	7900.00
0005433343433	17108	Economy	7900.00
0005435380337	17108	Economy	7900.00
0005435545804	17108	Economy	7900.00
0005435545800	17108	Economy	7900.00
0005433343053	17108	Economy	7900.00
0005433342934	17108	Economy	7900.00
0005433343106	17108	Economy	7900.00
0005433343267	17108	Economy	7900.00
0005433343401	17108	Economy	7900.00
0005433343187	17108	Economy	7900.00
0005433342548	17108	Economy	7900.00
0005433342999	17108	Economy	7900.00
0005433343146	17108	Economy	7900.00
0005433342698	17108	Economy	7900.00
0005432293231	17108	Economy	7900.00
0005433342902	17108	Economy	7900.00
0005433343223	17108	Economy	7900.00
0005433343387	17108	Economy	7900.00
0005433343195	17108	Economy	7900.00
0005433343046	17108	Economy	7900.00
0005433343164	17108	Economy	7900.00
0005433342747	17108	Economy	7900.00
0005435097195	17108	Economy	7900.00
0005433342952	17108	Economy	7900.00
0005435545799	17108	Economy	7900.00
0005433343176	17108	Economy	7900.00
0005433343026	17108	Economy	7900.00
0005435097203	17108	Economy	7900.00
0005433343245	17108	Economy	7900.00
0005435545811	17108	Economy	7900.00
0005433343184	17108	Economy	7900.00
0005435545808	17108	Economy	7900.00
0005433343243	17108	Economy	7900.00
0005433343084	17108	Economy	7900.00
0005433343121	17108	Economy	7900.00
0005433343519	17108	Economy	7900.00
0005435545797	17108	Economy	7900.00
0005435380336	17108	Economy	8600.00
0005433342989	17108	Economy	8600.00
0005433342951	17108	Economy	8600.00
0005433342915	17108	Economy	8600.00
0005433342619	17108	Economy	8600.00
0005433342826	17108	Economy	8600.00
0005433343040	17108	Economy	7900.00
0005433343227	17108	Economy	7900.00
0005435545801	17108	Economy	7900.00
0005433343105	17108	Economy	7900.00
0005433343385	17108	Economy	7900.00
0005433343397	17108	Economy	7900.00
0005433343009	17108	Economy	7900.00
0005433342699	17108	Economy	7900.00
0005435545802	17108	Economy	7900.00
0005433343328	17108	Economy	7900.00
0005435097197	17108	Economy	7900.00
0005433343034	17108	Economy	7900.00
0005433342917	17108	Economy	7900.00
0005435097211	17108	Economy	7900.00
0005433342666	17108	Economy	7900.00
0005432293230	17108	Economy	7900.00
0005433343052	17108	Economy	7900.00
0005433342705	17108	Economy	7900.00
0005433343050	17108	Economy	7900.00
0005433343273	17108	Economy	7900.00
0005433343041	17108	Economy	7900.00
0005433343553	17108	Economy	7900.00
0005433342638	17108	Economy	7900.00
0005433343375	17108	Economy	7900.00
0005435097196	17108	Economy	7900.00
0005433342601	17108	Economy	7900.00
0005435097210	17108	Economy	7900.00
0005433342933	17108	Economy	7900.00
0005433342976	17108	Economy	7900.00
0005433343104	17108	Economy	7900.00
0005433342901	17108	Economy	7900.00
0005433342866	17108	Economy	7900.00
0005435545798	17108	Economy	7900.00
0005435380334	17108	Economy	7900.00
0005433343169	17108	Economy	7900.00
0005435097204	17108	Economy	7900.00
0005433342824	17108	Economy	7900.00
0005433343571	17108	Economy	7900.00
0005433342657	17108	Economy	7900.00
0005433342704	17108	Economy	7900.00
0005433342703	17108	Economy	7900.00
0005433342887	17108	Economy	7900.00
0005435380335	17108	Economy	7900.00
0005435097198	17108	Economy	7900.00
0005433343049	17108	Economy	7900.00
0005433342849	17108	Economy	7900.00
0005435097202	17108	Economy	7900.00
0005433343520	17108	Economy	7900.00
0005435545803	17108	Economy	7900.00
0005433342618	17108	Economy	7900.00
0005435545807	17108	Economy	7900.00
0005433343388	17108	Economy	7900.00
0005433343076	17108	Economy	7900.00
0005433343077	17108	Economy	7900.00
0005433343196	17108	Economy	7900.00
0005433342149	17108	Economy	7900.00
0005433343386	17108	Economy	7900.00
0005433342900	17108	Economy	7900.00
0005433343201	17108	Economy	7900.00
0005433343129	17108	Economy	7900.00
0005433343255	17108	Economy	7900.00
0005433342549	17108	Economy	7900.00
0005435545809	17108	Economy	7900.00
0005433342916	17108	Economy	7900.00
0005433342825	17108	Economy	7900.00
0005435380338	17108	Economy	7900.00
0005433343346	17108	Economy	7900.00
0005433343254	17108	Economy	7900.00
0005433342665	17108	Economy	7900.00
0005433343047	17108	Economy	7900.00
0005433342779	17108	Economy	7900.00
0005433481240	9117	Business	26600.00
0005432919752	9117	Business	26600.00
0005433507344	9117	Business	26600.00
0005432919830	9117	Business	26600.00
0005433507345	9117	Business	26600.00
0005432919867	9117	Business	26600.00
0005433481239	9117	Business	26600.00
0005433507346	9117	Business	26600.00
0005432919843	9117	Economy	8900.00
0005433507354	9117	Economy	8900.00
0005434158971	9117	Economy	8900.00
0005432919849	9117	Economy	8900.00
0005433481237	9117	Economy	8900.00
0005432919892	9117	Economy	8900.00
0005433481238	9117	Economy	8900.00
0005433507350	9117	Economy	9800.00
0005432919848	9117	Economy	9800.00
0005432919834	9117	Economy	9800.00
0005433507355	9117	Economy	8900.00
0005432919766	9117	Economy	8900.00
0005433481236	9117	Economy	8900.00
0005433507349	9117	Economy	8900.00
0005432919822	9117	Economy	8900.00
0005432919865	9117	Economy	8900.00
0005433507356	9117	Economy	8900.00
0005434158972	9117	Economy	8900.00
0005433481241	9117	Economy	8900.00
0005432919882	9117	Economy	8900.00
0005433481234	9117	Economy	8900.00
0005432919881	9117	Economy	8900.00
0005432919931	9117	Economy	8900.00
0005433507352	9117	Economy	8900.00
0005432919753	9117	Economy	8900.00
0005433507343	9117	Economy	8900.00
0005432919847	9117	Economy	8900.00
0005433507347	9117	Economy	8900.00
0005433507342	9117	Economy	8900.00
0005433481235	9117	Economy	8900.00
0005432919927	9117	Economy	8900.00
0005432919850	9117	Economy	8900.00
0005432919914	9117	Economy	8900.00
0005432919866	9117	Economy	8900.00
0005432919891	9117	Economy	8900.00
0005433507348	9117	Economy	8900.00
0005432919853	9117	Economy	8900.00
0005433507341	9117	Economy	8900.00
0005433507353	9117	Economy	8900.00
0005433507351	9117	Economy	8900.00
0005432919928	9117	Economy	8900.00
0005432919802	9117	Economy	8900.00
0005434158999	20437	Business	26600.00
0005432920070	20437	Business	26600.00
0005432920072	20437	Business	26600.00
0005433507172	20437	Business	26600.00
0005432920076	20437	Business	26600.00
0005432920069	20437	Economy	8900.00
0005432920062	20437	Economy	8900.00
0005432920064	20437	Economy	8900.00
0005433507245	20437	Economy	8900.00
0005433481170	20437	Economy	8900.00
0005432920080	20437	Economy	8900.00
0005432920074	20437	Economy	9800.00
0005433507177	20437	Economy	9800.00
0005433507187	20437	Economy	9800.00
0005433481168	20437	Economy	9800.00
0005432920078	20437	Economy	8900.00
0005434159003	20437	Economy	8900.00
0005434159002	20437	Economy	8900.00
0005432920067	20437	Economy	8900.00
0005433507236	20437	Economy	8900.00
0005432920068	20437	Economy	8900.00
0005432920077	20437	Economy	8900.00
0005432920081	20437	Economy	8900.00
0005433481167	20437	Economy	8900.00
0005432920071	20437	Economy	8900.00
0005432920059	20437	Economy	8900.00
0005432920082	20437	Economy	8900.00
0005433481172	20437	Economy	8900.00
0005433507206	20437	Economy	8900.00
0005432920061	20437	Economy	8900.00
0005433507217	20437	Economy	8900.00
0005432920065	20437	Economy	8900.00
0005433481192	20437	Economy	8900.00
0005432920066	20437	Economy	8900.00
0005433507237	20437	Economy	8900.00
0005433481201	20437	Economy	8900.00
0005432920079	20437	Economy	8900.00
0005432920075	20437	Economy	8900.00
0005434158998	20437	Economy	8900.00
0005433507201	20437	Economy	8900.00
0005432920060	20437	Economy	8900.00
0005433481202	20437	Economy	8900.00
0005434159000	20437	Economy	8900.00
0005434159001	20437	Economy	8900.00
0005432920073	20437	Economy	8900.00
0005433507193	20437	Economy	8900.00
0005432920063	20437	Economy	8900.00
0005432394138	10180	Economy	5800.00
0005435178995	10180	Economy	5800.00
0005432396277	10180	Economy	5800.00
0005435179693	10180	Economy	5800.00
0005432396275	10180	Economy	5800.00
0005432394137	10180	Economy	5800.00
0005435178994	10180	Economy	5800.00
0005435179692	10180	Economy	5800.00
0005432396276	10180	Economy	5800.00
0005432396240	18365	Economy	5800.00
0005432396241	18365	Economy	5800.00
0005432400123	18365	Economy	5800.00
0005432396251	18365	Economy	5800.00
0005432396217	18365	Economy	5800.00
0005432400122	18365	Economy	5800.00
0005435179402	18365	Economy	5800.00
0005432396250	18365	Economy	5800.00
0005432396245	18365	Economy	5800.00
0005432396218	18365	Economy	5800.00
0005432400131	18365	Economy	5800.00
0005432400132	18365	Economy	5800.00
0005435626162	11038	Business	9500.00
0005435126372	11038	Business	9500.00
0005435626102	11038	Business	9500.00
0005435626103	11038	Business	9500.00
0005435554194	11038	Business	9500.00
0005435554191	11038	Business	9500.00
0005435554193	11038	Business	9500.00
0005435126421	11038	Business	9500.00
0005435126365	11038	Business	9500.00
0005435126259	11038	Business	9500.00
0005435626113	11038	Business	9500.00
0005435126306	11038	Economy	3200.00
0005435126251	11038	Economy	3200.00
0005435126384	11038	Economy	3200.00
0005434928325	11038	Economy	3200.00
0005435126353	11038	Economy	3200.00
0005434411820	11038	Economy	3200.00
0005435126210	11038	Economy	3200.00
0005435126324	11038	Economy	3500.00
0005435626118	11038	Economy	3500.00
0005435556703	11038	Economy	3500.00
0005435126519	11038	Economy	3500.00
0005435126453	11038	Economy	3500.00
0005435126562	11038	Economy	3200.00
0005435626128	11038	Economy	3200.00
0005435126366	11038	Economy	3200.00
0005435126520	11038	Economy	3200.00
0005435554187	11038	Economy	3200.00
0005435126321	11038	Economy	3200.00
0005435126276	11038	Economy	3200.00
0005435626110	11038	Economy	3200.00
0005435554186	11038	Economy	3200.00
0005435126407	11038	Economy	3200.00
0005435126554	11038	Economy	3200.00
0005435626160	11038	Economy	3200.00
0005434411819	11038	Economy	3200.00
0005435126419	11038	Economy	3200.00
0005435126531	11038	Economy	3200.00
0005435554195	11038	Economy	3200.00
0005435126286	11038	Economy	3200.00
0005435626124	11038	Economy	3200.00
0005435626104	11038	Economy	3200.00
0005435556702	11038	Economy	3200.00
0005435554190	11038	Economy	3200.00
0005435126334	11038	Economy	3200.00
0005435126347	11038	Economy	3200.00
0005435126256	11038	Economy	3200.00
0005435126325	11038	Economy	3200.00
0005435554192	11038	Economy	3200.00
0005435126326	11038	Economy	3200.00
0005435126340	11038	Economy	3200.00
0005435126391	11038	Economy	3200.00
0005435556694	11038	Economy	3200.00
0005435626163	11038	Economy	3200.00
0005435126438	11038	Economy	3200.00
0005435126532	11038	Economy	3200.00
0005435126395	11038	Economy	3200.00
0005435126361	11038	Economy	3200.00
0005434928327	11038	Economy	3200.00
0005435126555	11038	Economy	3200.00
0005435126468	11038	Economy	3200.00
0005435126422	11038	Economy	3200.00
0005435126371	11038	Economy	3200.00
0005435126396	11038	Economy	3200.00
0005435126492	11038	Economy	3200.00
0005435126258	11038	Economy	3200.00
0005435126275	11038	Economy	3200.00
0005434928326	11038	Economy	3200.00
0005435126385	11038	Economy	3200.00
0005435126416	11038	Economy	3200.00
0005435126274	11038	Economy	3200.00
0005435626112	11038	Economy	3200.00
0005435554174	11038	Economy	3200.00
0005435126452	11038	Economy	3200.00
0005435126346	11038	Economy	3200.00
0005434411818	11038	Economy	3200.00
0005435126397	11038	Economy	3200.00
0005435126075	11038	Economy	3200.00
0005435556697	11038	Economy	3200.00
0005435126467	11038	Economy	3200.00
0005435126333	11038	Economy	3200.00
0005435126561	11038	Economy	3200.00
0005435554181	11038	Economy	3200.00
0005435556704	11038	Economy	3200.00
0005435126754	14663	Business	9500.00
0005435626341	14663	Business	9500.00
0005435626361	14663	Business	9500.00
0005435126755	14663	Business	9500.00
0005435126735	14663	Business	9500.00
0005435126762	14663	Business	9500.00
0005435626340	14663	Business	9500.00
0005435626365	14663	Business	9500.00
0005435126734	14663	Economy	3200.00
0005435126745	14663	Economy	3200.00
0005435126763	14663	Economy	3200.00
0005435126742	14663	Economy	3200.00
0005435626358	14663	Economy	3200.00
0005435126736	14663	Economy	3200.00
0005435626367	14663	Economy	3200.00
0005435126761	14663	Economy	3200.00
0005435126732	14663	Economy	3200.00
0005435126739	14663	Economy	3200.00
0005435626351	14663	Economy	3500.00
0005435126764	14663	Economy	3500.00
0005435626359	14663	Economy	3500.00
0005435126770	14663	Economy	3500.00
0005435626356	14663	Economy	3200.00
0005435126744	14663	Economy	3200.00
0005435126759	14663	Economy	3200.00
0005435626369	14663	Economy	3200.00
0005435626349	14663	Economy	3200.00
0005435126766	14663	Economy	3200.00
0005435626348	14663	Economy	3200.00
0005435626353	14663	Economy	3200.00
0005435126768	14663	Economy	3200.00
0005435126749	14663	Economy	3200.00
0005435626342	14663	Economy	3200.00
0005435126753	14663	Economy	3200.00
0005435126750	14663	Economy	3200.00
0005435556715	14663	Economy	3200.00
0005434411784	14663	Economy	3200.00
0005435126740	14663	Economy	3200.00
0005435126757	14663	Economy	3200.00
0005435626354	14663	Economy	3200.00
0005435626360	14663	Economy	3200.00
0005435626364	14663	Economy	3200.00
0005434411788	14663	Economy	3200.00
0005435126751	14663	Economy	3200.00
0005435126746	14663	Economy	3200.00
0005435126752	14663	Economy	3200.00
0005435626345	14663	Economy	3200.00
0005435626343	14663	Economy	3200.00
0005435554228	14663	Economy	3200.00
0005435126737	14663	Economy	3200.00
0005435626355	14663	Economy	3200.00
0005435126741	14663	Economy	3200.00
0005435626344	14663	Economy	3200.00
0005435626370	14663	Economy	3200.00
0005435126767	14663	Economy	3200.00
0005435626362	14663	Economy	3200.00
0005435626366	14663	Economy	3200.00
0005435554230	14663	Economy	3200.00
0005435626347	14663	Economy	3200.00
0005435626368	14663	Economy	3200.00
0005435126760	14663	Economy	3200.00
0005435126765	14663	Economy	3200.00
0005435626350	14663	Economy	3200.00
0005435626363	14663	Economy	3200.00
0005435126733	14663	Economy	3200.00
0005435126738	14663	Economy	3200.00
0005435626357	14663	Economy	3200.00
0005435126769	14663	Economy	3200.00
0005435126758	14663	Economy	3200.00
0005434411777	14663	Economy	3200.00
0005435126747	14663	Economy	3200.00
0005435626346	14663	Economy	3200.00
0005435126748	14663	Economy	3200.00
0005435554227	14663	Economy	3200.00
0005435126756	14663	Economy	3200.00
0005435626352	14663	Economy	3200.00
0005435556716	14663	Economy	3200.00
0005435126743	14663	Economy	3200.00
0005435554229	14663	Economy	3200.00
0005432398234	7122	Business	86900.00
0005435443335	7122	Business	86900.00
0005435715633	7122	Business	86900.00
0005435715635	7122	Business	86900.00
0005432400162	7122	Economy	29000.00
0005432400159	7122	Economy	29000.00
0005435216589	7122	Economy	29000.00
0005435443326	7122	Economy	29000.00
0005432400161	7122	Economy	29000.00
0005432400160	7122	Economy	29000.00
0005435443322	7122	Economy	29000.00
0005435715618	7122	Economy	29000.00
0005435715621	7122	Economy	31900.00
0005435216588	7122	Economy	31900.00
0005432398231	7122	Economy	31900.00
0005435715624	7122	Economy	29000.00
0005435715623	7122	Economy	29000.00
0005435715632	7122	Economy	29000.00
0005432400164	7122	Economy	29000.00
0005435715628	7122	Economy	29000.00
0005435443316	7122	Economy	29000.00
0005435443339	7122	Economy	29000.00
0005435221057	7122	Economy	29000.00
0005435443331	7122	Economy	29000.00
0005435715622	7122	Economy	29000.00
0005435715625	7122	Economy	29000.00
0005435219199	7122	Economy	29000.00
0005435443298	7122	Economy	29000.00
0005435715617	7122	Economy	29000.00
0005432398233	7122	Economy	29000.00
0005435216591	7122	Economy	29000.00
0005432398232	7122	Economy	29000.00
0005435216582	7122	Economy	29000.00
0005435443299	7122	Economy	29000.00
0005435216580	7122	Economy	29000.00
0005435443340	7122	Economy	29000.00
0005435443332	7122	Economy	29000.00
0005435216590	7122	Economy	29000.00
0005435715631	7122	Economy	29000.00
0005435715626	7122	Economy	29000.00
0005435715629	7122	Economy	29000.00
0005435715619	7122	Economy	29000.00
0005435715620	7122	Economy	29000.00
0005435216581	7122	Economy	29000.00
0005435219198	7122	Economy	29000.00
0005435715634	7122	Economy	29000.00
0005435443327	7122	Economy	29000.00
0005435715630	7122	Economy	29000.00
0005435219200	7122	Economy	29000.00
0005435443300	7122	Economy	29000.00
0005435443333	7122	Economy	29000.00
0005435443334	7122	Economy	29000.00
0005435715627	7122	Economy	29000.00
0005432400163	7122	Economy	29000.00
0005432398235	7122	Economy	29000.00
0005435219197	7122	Economy	29000.00
0005435216583	7122	Economy	29000.00
0005435715476	27095	Business	86900.00
0005435715391	27095	Business	86900.00
0005435715467	27095	Business	86900.00
0005435715436	27095	Business	86900.00
0005432394099	27095	Business	86900.00
0005435715448	27095	Business	86900.00
0005435715478	27095	Business	86900.00
0005435715447	27095	Business	86900.00
0005435715442	27095	Economy	29000.00
0005435443398	27095	Economy	29000.00
0005435715531	27095	Economy	29000.00
0005435715444	27095	Economy	29000.00
0005435715529	27095	Economy	29000.00
0005435715504	27095	Economy	31900.00
0005432398198	27095	Economy	29000.00
0005435443402	27095	Economy	29000.00
0005435715450	27095	Economy	29000.00
0005432394098	27095	Economy	29000.00
0005435715446	27095	Economy	29000.00
0005432398197	27095	Economy	29000.00
0005432394105	27095	Economy	29000.00
0005435715441	27095	Economy	29000.00
0005435715481	27095	Economy	29000.00
0005435443399	27095	Economy	29000.00
0005435715443	27095	Economy	29000.00
0005435715475	27095	Economy	29000.00
0005432398191	27095	Economy	29000.00
0005435443403	27095	Economy	29000.00
0005432398196	27095	Economy	29000.00
0005435443401	27095	Economy	29000.00
0005435443400	27095	Economy	29000.00
0005435715482	27095	Economy	29000.00
0005435715527	27095	Economy	29000.00
0005435715437	27095	Economy	29000.00
0005435715466	27095	Economy	29000.00
0005432394109	27095	Economy	29000.00
0005435715451	27095	Economy	29000.00
0005435715470	27095	Economy	29000.00
0005435715456	27095	Economy	29000.00
0005435715509	27095	Economy	29000.00
0005432394113	27095	Economy	29000.00
0005435715406	27095	Economy	29000.00
0005435443404	27095	Economy	29000.00
0005435715510	27095	Economy	29000.00
0005435715390	27095	Economy	29000.00
0005435443405	27095	Economy	29000.00
0005435443397	27095	Economy	29000.00
0005435715505	27095	Economy	29000.00
0005435443396	27095	Economy	29000.00
0005432394097	27095	Economy	29000.00
0005432394106	27095	Economy	29000.00
0005435715528	27095	Economy	29000.00
0005434084975	2732	Economy	7700.00
0005434084974	2732	Economy	7700.00
0005434084973	2732	Economy	7700.00
0005434084976	2732	Economy	7700.00
0005433060403	2732	Economy	7700.00
0005434084972	2732	Economy	7700.00
0005434084971	2732	Economy	7700.00
0005434084938	28506	Economy	7700.00
0005434084939	28506	Economy	7700.00
0005434084927	28506	Economy	7700.00
0005434084926	28506	Economy	7700.00
0005434084928	28506	Economy	7700.00
0005433060437	28506	Economy	7700.00
0005434084923	28506	Economy	7700.00
0005433060439	28506	Economy	7700.00
0005434084945	28506	Economy	7700.00
0005434084922	28506	Economy	7700.00
0005433060438	28506	Economy	7700.00
0005435541073	11412	Business	20200.00
0005435540946	11412	Business	20200.00
0005435517903	11412	Economy	6700.00
0005435517935	11412	Economy	6700.00
0005435517938	11412	Economy	6700.00
0005435517915	11412	Economy	7400.00
0005435517960	11412	Economy	7400.00
0005435541017	11412	Economy	7400.00
0005435541002	11412	Economy	6700.00
0005435541027	11412	Economy	6700.00
0005435541018	11412	Economy	6700.00
0005435541007	11412	Economy	6700.00
0005435541029	11412	Economy	6700.00
0005435541028	11412	Economy	6700.00
0005435540965	11412	Economy	6700.00
0005435517936	11412	Economy	6700.00
0005435541071	11412	Economy	6700.00
0005435517914	11412	Economy	6700.00
0005435541016	11412	Economy	6700.00
0005435541046	11412	Economy	6700.00
0005435540887	11412	Economy	6700.00
0005435540947	11412	Economy	6700.00
0005435540997	11412	Economy	6700.00
0005435541039	11412	Economy	6700.00
0005435541070	11412	Economy	6700.00
0005435541030	11412	Economy	6700.00
0005435541047	11412	Economy	6700.00
0005435517900	11412	Economy	6700.00
0005435517899	11412	Economy	6700.00
0005435541008	11412	Economy	6700.00
0005435529433	22268	Business	20200.00
0005435529452	22268	Business	20200.00
0005435529446	22268	Business	20200.00
0005435529448	22268	Business	20200.00
0005435541188	22268	Economy	6700.00
0005435541185	22268	Economy	6700.00
0005435541177	22268	Economy	6700.00
0005435529453	22268	Economy	6700.00
0005435541176	22268	Economy	6700.00
0005435541182	22268	Economy	6700.00
0005435541191	22268	Economy	6700.00
0005435529438	22268	Economy	6700.00
0005435541194	22268	Economy	7400.00
0005435541180	22268	Economy	7400.00
0005435529432	22268	Economy	6700.00
0005435529441	22268	Economy	6700.00
0005435541187	22268	Economy	6700.00
0005435529443	22268	Economy	6700.00
0005435541186	22268	Economy	6700.00
0005435541189	22268	Economy	6700.00
0005435541190	22268	Economy	6700.00
0005432294507	22268	Economy	6700.00
0005432294508	22268	Economy	6700.00
0005435541198	22268	Economy	6700.00
0005435541195	22268	Economy	6700.00
0005435529440	22268	Economy	6700.00
0005435529439	22268	Economy	6700.00
0005435529455	22268	Economy	6700.00
0005435529445	22268	Economy	6700.00
0005435529449	22268	Economy	6700.00
0005435529444	22268	Economy	6700.00
0005435541183	22268	Economy	6700.00
0005435529454	22268	Economy	6700.00
0005435541184	22268	Economy	6700.00
0005435541193	22268	Economy	6700.00
0005435529450	22268	Economy	6700.00
0005435529451	22268	Economy	6700.00
0005435529442	22268	Economy	6700.00
0005435529436	22268	Economy	6700.00
0005435529437	22268	Economy	6700.00
0005435541181	22268	Economy	6700.00
0005435541196	22268	Economy	6700.00
0005435529435	22268	Economy	6700.00
0005435541178	22268	Economy	6700.00
0005435541197	22268	Economy	6700.00
0005435541179	22268	Economy	6700.00
0005435541192	22268	Economy	6700.00
0005435529447	22268	Economy	6700.00
0005435529434	22268	Economy	6700.00
0005434907795	2275	Business	20200.00
0005434907782	2275	Business	20200.00
0005434907778	2275	Business	20200.00
0005434907751	2275	Business	20200.00
0005433251477	2275	Business	20200.00
0005434907783	2275	Business	20200.00
0005434907749	2275	Business	20200.00
0005434907758	2275	Economy	6700.00
0005434907766	2275	Economy	6700.00
0005433251626	2275	Economy	6700.00
0005434907780	2275	Economy	6700.00
0005433251449	2275	Economy	6700.00
0005433251595	2275	Economy	6700.00
0005433251484	2275	Economy	6700.00
0005434907785	2275	Economy	6700.00
0005434907773	2275	Economy	6700.00
0005434907756	2275	Economy	7400.00
0005434907746	2275	Economy	7400.00
0005433400990	2275	Economy	7400.00
0005434907789	2275	Economy	7400.00
0005433251500	2275	Economy	6700.00
0005434907791	2275	Economy	6700.00
0005433251427	2275	Economy	6700.00
0005433251419	2275	Economy	6700.00
0005434907747	2275	Economy	6700.00
0005434907769	2275	Economy	6700.00
0005434907774	2275	Economy	6700.00
0005434907799	2275	Economy	6700.00
0005433251590	2275	Economy	6700.00
0005433251436	2275	Economy	6700.00
0005434907796	2275	Economy	6700.00
0005433400978	2275	Economy	6700.00
0005434907792	2275	Economy	6700.00
0005434907761	2275	Economy	6700.00
0005434907793	2275	Economy	6700.00
0005433251584	2275	Economy	6700.00
0005434907763	2275	Economy	6700.00
0005434907754	2275	Economy	6700.00
0005434907770	2275	Economy	6700.00
0005434907798	2275	Economy	6700.00
0005434907750	2275	Economy	6700.00
0005434907753	2275	Economy	6700.00
0005434907779	2275	Economy	6700.00
0005434907777	2275	Economy	6700.00
0005434907775	2275	Economy	6700.00
0005434907786	2275	Economy	6700.00
0005433400983	2275	Economy	6700.00
0005434907768	2275	Economy	6700.00
0005434907787	2275	Economy	6700.00
0005434907771	2275	Economy	6700.00
0005434907765	2275	Economy	6700.00
0005434907800	2275	Economy	6700.00
0005434907762	2275	Economy	6700.00
0005434907759	2275	Economy	6700.00
0005434907752	2275	Economy	6700.00
0005434907794	2275	Economy	6700.00
0005434907790	2275	Economy	6700.00
0005433251565	2275	Economy	6700.00
0005433251476	2275	Economy	6700.00
0005434907797	2275	Economy	6700.00
0005434907760	2275	Economy	6700.00
0005434907764	2275	Economy	6700.00
0005434907767	2275	Economy	6700.00
0005434907784	2275	Economy	6700.00
0005434907772	2275	Economy	6700.00
0005433251404	2275	Economy	6700.00
0005434907757	2275	Economy	6700.00
0005434907755	2275	Economy	6700.00
0005434907748	2275	Economy	6700.00
0005434907781	2275	Economy	6700.00
0005433251627	2275	Economy	6700.00
0005434907788	2275	Economy	6700.00
0005433251403	2275	Economy	6700.00
0005433251439	2275	Economy	6700.00
0005433251585	2275	Economy	6700.00
0005434907776	2275	Economy	6700.00
0005434907319	25573	Business	20200.00
0005433251750	25573	Business	20200.00
0005434907264	25573	Business	20200.00
0005433251772	25573	Business	20200.00
0005434907320	25573	Business	20200.00
0005434907192	25573	Business	20200.00
0005434907209	25573	Business	20200.00
0005433251761	25573	Business	20200.00
0005433251759	25573	Business	20200.00
0005434907258	25573	Business	20200.00
0005434907311	25573	Business	20200.00
0005433251774	25573	Economy	6700.00
0005433401010	25573	Economy	6700.00
0005434907276	25573	Economy	6700.00
0005434907307	25573	Economy	6700.00
0005434907259	25573	Economy	6700.00
0005434907341	25573	Economy	6700.00
0005434907160	25573	Economy	6700.00
0005434907153	25573	Economy	6700.00
0005433251749	25573	Economy	6700.00
0005433251755	25573	Economy	6700.00
0005434907152	25573	Economy	7400.00
0005433251757	25573	Economy	7400.00
0005434907205	25573	Economy	7400.00
0005434907275	25573	Economy	7400.00
0005434907177	25573	Economy	6700.00
0005433251775	25573	Economy	6700.00
0005434907159	25573	Economy	6700.00
0005434907346	25573	Economy	6700.00
0005433251778	25573	Economy	6700.00
0005434907210	25573	Economy	6700.00
0005433251773	25573	Economy	6700.00
0005433401011	25573	Economy	6700.00
0005433251770	25573	Economy	6700.00
0005433251769	25573	Economy	6700.00
0005433251754	25573	Economy	6700.00
0005433251768	25573	Economy	6700.00
0005434907165	25573	Economy	6700.00
0005433251752	25573	Economy	6700.00
0005433401012	25573	Economy	6700.00
0005433251779	25573	Economy	6700.00
0005434907290	25573	Economy	6700.00
0005433251758	25573	Economy	6700.00
0005434907312	25573	Economy	6700.00
0005434907306	25573	Economy	6700.00
0005434907300	25573	Economy	6700.00
0005433251776	25573	Economy	6700.00
0005434907304	25573	Economy	6700.00
0005434907048	25573	Economy	6700.00
0005433251764	25573	Economy	6700.00
0005434907105	25573	Economy	6700.00
0005434907134	25573	Economy	6700.00
0005433251765	25573	Economy	6700.00
0005433251767	25573	Economy	6700.00
0005433251753	25573	Economy	6700.00
0005434907339	25573	Economy	6700.00
0005434907235	25573	Economy	6700.00
0005433251763	25573	Economy	6700.00
0005434907321	25573	Economy	6700.00
0005433251762	25573	Economy	6700.00
0005433251766	25573	Economy	6700.00
0005434907211	25573	Economy	6700.00
0005434907017	25573	Economy	6700.00
0005434907280	25573	Economy	6700.00
0005433251780	25573	Economy	6700.00
0005433251771	25573	Economy	6700.00
0005434907267	25573	Economy	6700.00
0005434907347	25573	Economy	6700.00
0005434907178	25573	Economy	6700.00
0005434907201	25573	Economy	6700.00
0005434907340	25573	Economy	6700.00
0005433251751	25573	Economy	6700.00
0005434907104	25573	Economy	6700.00
0005434907250	25573	Economy	6700.00
0005434907191	25573	Economy	6700.00
0005433251756	25573	Economy	6700.00
0005434907272	25573	Economy	6700.00
0005434907230	25573	Economy	6700.00
0005434907052	25573	Economy	6700.00
0005434906871	25573	Economy	6700.00
0005434907313	25573	Economy	6700.00
0005434907169	25573	Economy	6700.00
0005434907170	25573	Economy	6700.00
0005433251781	25573	Economy	6700.00
0005434907202	25573	Economy	6700.00
0005433251777	25573	Economy	6700.00
0005434907279	25573	Economy	6700.00
0005433251760	25573	Economy	6700.00
0005434907130	25573	Economy	6700.00
0005434907016	25573	Economy	6700.00
0005434907263	25573	Economy	6700.00
0005432621173	2541	Economy	13600.00
0005432621164	2541	Economy	13600.00
0005432621168	2541	Economy	12400.00
0005432621170	2541	Economy	12400.00
0005432621176	2541	Economy	12400.00
0005432621171	2541	Economy	12400.00
0005432621174	2541	Economy	12400.00
0005432621166	2541	Economy	12400.00
0005432862235	2541	Economy	12400.00
0005432621172	2541	Economy	12400.00
0005432621175	2541	Economy	12400.00
0005432862298	2541	Economy	12400.00
0005432621165	2541	Economy	12400.00
0005432862234	2541	Economy	12400.00
0005432621163	2541	Economy	12400.00
0005432862313	2541	Economy	12400.00
0005432621162	2541	Economy	12400.00
0005432621169	2541	Economy	12400.00
0005432621167	2541	Economy	12400.00
0005432621132	28070	Economy	13600.00
0005432621079	28070	Economy	13600.00
0005432621055	28070	Economy	13600.00
0005432862376	28070	Economy	12400.00
0005432621012	28070	Economy	12400.00
0005432621030	28070	Economy	12400.00
0005432621034	28070	Economy	12400.00
0005432862374	28070	Economy	12400.00
0005432862377	28070	Economy	12400.00
0005432621053	28070	Economy	12400.00
0005432621073	28070	Economy	12400.00
0005432621101	28070	Economy	12400.00
0005432621100	28070	Economy	12400.00
0005432621040	28070	Economy	12400.00
0005432621031	28070	Economy	12400.00
0005432621080	28070	Economy	12400.00
0005432862375	28070	Economy	12400.00
0005432621067	28070	Economy	12400.00
0005432621029	28070	Economy	12400.00
0005432862372	28070	Economy	12400.00
0005432621011	28070	Economy	12400.00
0005432862370	28070	Economy	12400.00
0005432862371	28070	Economy	12400.00
0005432862373	28070	Economy	12400.00
0005434097481	11798	Economy	11300.00
0005434097479	11798	Economy	11300.00
0005434097480	11798	Economy	11300.00
0005434097488	13019	Economy	11300.00
0005434097490	13019	Economy	11300.00
0005434097489	13019	Economy	11300.00
0005433452758	30993	Economy	8400.00
0005433452759	30993	Economy	8400.00
0005433451637	30993	Economy	8400.00
0005433452744	31393	Economy	8400.00
0005433454881	31393	Economy	8400.00
0005433454873	31393	Economy	8400.00
0005433452740	31393	Economy	8400.00
0005433452743	31393	Economy	8400.00
0005434142625	12026	Economy	7200.00
0005434142615	12026	Economy	7200.00
0005433134138	12026	Economy	6600.00
0005433134133	12026	Economy	6600.00
0005433134141	12026	Economy	6600.00
0005433134154	12026	Economy	6600.00
0005433129274	12026	Economy	6600.00
0005434142619	12026	Economy	6600.00
0005433134158	12026	Economy	6600.00
0005433129272	12026	Economy	6600.00
0005434142618	12026	Economy	6600.00
0005433129271	12026	Economy	6600.00
0005434184669	12026	Economy	6600.00
0005434184670	12026	Economy	6600.00
0005433134139	12026	Economy	6600.00
0005433129250	12026	Economy	6600.00
0005433134134	12026	Economy	6600.00
0005434142611	12026	Economy	6600.00
0005433134142	12026	Economy	6600.00
0005433129251	12026	Economy	6600.00
0005433129249	12026	Economy	6600.00
0005433134183	29821	Economy	7200.00
0005433131751	29821	Economy	7200.00
0005433134179	29821	Economy	6600.00
0005433131750	29821	Economy	6600.00
0005434142644	29821	Economy	6600.00
0005433134181	29821	Economy	6600.00
0005433134182	29821	Economy	6600.00
0005433134178	29821	Economy	6600.00
0005434184684	29821	Economy	6600.00
0005434142645	29821	Economy	6600.00
0005434183599	29821	Economy	6600.00
0005433131749	29821	Economy	6600.00
0005434183598	29821	Economy	6600.00
0005434142643	29821	Economy	6600.00
0005433131752	29821	Economy	6600.00
0005434184683	29821	Economy	6600.00
0005433134180	29821	Economy	6600.00
0005435935041	16500	Economy	19900.00
0005435697565	16500	Economy	19900.00
0005435935038	16500	Economy	19900.00
0005435697584	16500	Economy	18100.00
0005435697582	16500	Economy	18100.00
0005435697562	16500	Economy	18100.00
0005435697573	16500	Economy	18100.00
0005435935051	16500	Economy	18100.00
0005435697583	16500	Economy	18100.00
0005435697568	16500	Economy	18100.00
0005435697581	16500	Economy	18100.00
0005435697574	16500	Economy	18100.00
0005435697580	16500	Economy	18100.00
0005435697564	16500	Economy	18100.00
0005435697588	16500	Economy	18100.00
0005435697578	16500	Economy	18100.00
0005435697566	16500	Economy	18100.00
0005435697587	16500	Economy	18100.00
0005435697576	16500	Economy	18100.00
0005435697579	16500	Economy	18100.00
0005435697575	16500	Economy	18100.00
0005435697561	16500	Economy	18100.00
0005435935050	16500	Economy	18100.00
0005435697571	16500	Economy	18100.00
0005435935039	16500	Economy	18100.00
0005435697563	16500	Economy	18100.00
0005435697586	16500	Economy	18100.00
0005435697572	16500	Economy	18100.00
0005435697577	16500	Economy	18100.00
0005435697569	16500	Economy	18100.00
0005435697570	16500	Economy	18100.00
0005435935040	16500	Economy	18100.00
0005435697585	16500	Economy	18100.00
0005435697567	16500	Economy	18100.00
0005435697346	24718	Economy	19900.00
0005435697374	24718	Economy	19900.00
0005435697353	24718	Economy	18100.00
0005435935073	24718	Economy	18100.00
0005435697348	24718	Economy	18100.00
0005435697370	24718	Economy	18100.00
0005435697343	24718	Economy	18100.00
0005435697345	24718	Economy	18100.00
0005435697428	24718	Economy	18100.00
0005435697420	24718	Economy	18100.00
0005435697371	24718	Economy	18100.00
0005435697373	24718	Economy	18100.00
0005435935075	24718	Economy	18100.00
0005435697344	24718	Economy	18100.00
0005435697391	24718	Economy	18100.00
0005435697421	24718	Economy	18100.00
0005435935076	24718	Economy	18100.00
0005435697255	24718	Economy	18100.00
0005435697397	24718	Economy	18100.00
0005435697403	24718	Economy	18100.00
0005435697389	24718	Economy	18100.00
0005435697422	24718	Economy	18100.00
0005435697376	24718	Economy	18100.00
0005435935074	24718	Economy	18100.00
0005435697388	24718	Economy	18100.00
0005435697493	24718	Economy	18100.00
0005435697429	24718	Economy	18100.00
0005433724844	18778	Economy	4400.00
0005433724842	18778	Economy	4400.00
0005433724843	18778	Economy	4400.00
0005432968844	18778	Economy	4400.00
0005432968842	18778	Economy	4400.00
0005432968833	18778	Economy	4400.00
0005433724845	18778	Economy	4400.00
0005432968832	18778	Economy	4400.00
0005433724823	21618	Economy	4400.00
0005433724821	21618	Economy	4400.00
0005432968864	21618	Economy	4400.00
0005433724812	21618	Economy	4400.00
0005434138938	7294	Business	23100.00
0005434138956	7294	Business	23100.00
0005434138899	7294	Business	23100.00
0005434138945	7294	Business	23100.00
0005434087557	7294	Business	23100.00
0005434138968	7294	Business	23100.00
0005434138942	7294	Business	23100.00
0005434138926	7294	Business	23100.00
0005434138917	7294	Business	23100.00
0005434138944	7294	Business	23100.00
0005434138965	7294	Business	23100.00
0005434138915	7294	Business	23100.00
0005434138913	7294	Economy	7700.00
0005434138935	7294	Economy	7700.00
0005434087562	7294	Economy	7700.00
0005434138916	7294	Economy	7700.00
0005434138964	7294	Economy	7700.00
0005434138969	7294	Economy	7700.00
0005434138947	7294	Economy	7700.00
0005434138907	7294	Economy	7700.00
0005434138904	7294	Economy	7700.00
0005434138970	7294	Economy	7700.00
0005434138914	7294	Economy	8500.00
0005434138905	7294	Economy	8500.00
0005434138928	7294	Economy	8500.00
0005434138909	7294	Economy	8500.00
0005434138952	7294	Economy	8500.00
0005434138924	7294	Economy	7700.00
0005434138951	7294	Economy	7700.00
0005434138931	7294	Economy	7700.00
0005434138975	7294	Economy	7700.00
0005434138978	7294	Economy	7700.00
0005434138903	7294	Economy	7700.00
0005434138906	7294	Economy	7700.00
0005434138943	7294	Economy	7700.00
0005434138950	7294	Economy	7700.00
0005434138919	7294	Economy	7700.00
0005434138920	7294	Economy	7700.00
0005434087558	7294	Economy	7700.00
0005434138966	7294	Economy	7700.00
0005434138910	7294	Economy	7700.00
0005434138977	7294	Economy	7700.00
0005434138896	7294	Economy	7700.00
0005434138963	7294	Economy	7700.00
0005434087561	7294	Economy	7700.00
0005434138936	7294	Economy	7700.00
0005434138918	7294	Economy	7700.00
0005434138923	7294	Economy	7700.00
0005434138898	7294	Economy	7700.00
0005434138921	7294	Economy	7700.00
0005434138960	7294	Economy	7700.00
0005434138961	7294	Economy	7700.00
0005434138902	7294	Economy	7700.00
0005434087560	7294	Economy	7700.00
0005434138971	7294	Economy	7700.00
0005434138967	7294	Economy	7700.00
0005434138895	7294	Economy	7700.00
0005434138955	7294	Economy	7700.00
0005434138973	7294	Economy	7700.00
0005434138933	7294	Economy	7700.00
0005434138948	7294	Economy	7700.00
0005434138912	7294	Economy	7700.00
0005434138957	7294	Economy	7700.00
0005434138959	7294	Economy	7700.00
0005434138974	7294	Economy	7700.00
0005434138922	7294	Economy	7700.00
0005434087559	7294	Economy	7700.00
0005434138894	7294	Economy	7700.00
0005434138946	7294	Economy	7700.00
0005434138897	7294	Economy	7700.00
0005434138901	7294	Economy	7700.00
0005434138939	7294	Economy	7700.00
0005434138930	7294	Economy	7700.00
0005434138927	7294	Economy	7700.00
0005434138962	7294	Economy	7700.00
0005434138932	7294	Economy	7700.00
0005434138929	7294	Economy	7700.00
0005434138925	7294	Economy	7700.00
0005434138976	7294	Economy	7700.00
0005434138937	7294	Economy	7700.00
0005434138911	7294	Economy	7700.00
0005434138949	7294	Economy	7700.00
0005434138972	7294	Economy	7700.00
0005434138908	7294	Economy	7700.00
0005434138900	7294	Economy	7700.00
0005434138934	7294	Economy	7700.00
0005434138958	7294	Economy	7700.00
0005434138954	7294	Economy	7700.00
0005434138941	7294	Economy	7700.00
0005434138953	7294	Economy	7700.00
0005434138940	7294	Economy	7700.00
0005434137916	28561	Business	23100.00
0005434138108	28561	Business	23100.00
0005434138075	28561	Business	23100.00
0005434087530	28561	Business	23100.00
0005434137924	28561	Business	23100.00
0005434138017	28561	Business	23100.00
0005434137803	28561	Business	23100.00
0005434138116	28561	Business	23100.00
0005434138180	28561	Business	23100.00
0005434137782	28561	Business	23100.00
0005434087529	28561	Business	23100.00
0005434138073	28561	Economy	7700.00
0005434138007	28561	Economy	7700.00
0005434087512	28561	Economy	7700.00
0005434137851	28561	Economy	7700.00
0005434138184	28561	Economy	7700.00
0005434138230	28561	Economy	7700.00
0005434138078	28561	Economy	7700.00
0005434137919	28561	Economy	7700.00
0005434138079	28561	Economy	7700.00
0005434138133	28561	Economy	7700.00
0005434137834	28561	Economy	8500.00
0005434138231	28561	Economy	8500.00
0005434138087	28561	Economy	8500.00
0005434137804	28561	Economy	8500.00
0005434137783	28561	Economy	8500.00
0005434138002	28561	Economy	7700.00
0005434087515	28561	Economy	7700.00
0005434137947	28561	Economy	7700.00
0005434138023	28561	Economy	7700.00
0005434138039	28561	Economy	7700.00
0005434138063	28561	Economy	7700.00
0005434138032	28561	Economy	7700.00
0005434138060	28561	Economy	7700.00
0005434137892	28561	Economy	7700.00
0005434137930	28561	Economy	7700.00
0005434137835	28561	Economy	7700.00
0005434138000	28561	Economy	7700.00
0005434138018	28561	Economy	7700.00
0005434138151	28561	Economy	7700.00
0005434087533	28561	Economy	7700.00
0005434137805	28561	Economy	7700.00
0005434138088	28561	Economy	7700.00
0005434138232	28561	Economy	7700.00
0005434138118	28561	Economy	7700.00
0005434137781	28561	Economy	7700.00
0005434137923	28561	Economy	7700.00
0005434138234	28561	Economy	7700.00
0005434138238	28561	Economy	7700.00
0005434138251	28561	Economy	7700.00
0005434138261	28561	Economy	7700.00
0005434138150	28561	Economy	7700.00
0005434138202	28561	Economy	7700.00
0005434138062	28561	Economy	7700.00
0005434138141	28561	Economy	7700.00
0005434087516	28561	Economy	7700.00
0005434138185	28561	Economy	7700.00
0005434137999	28561	Economy	7700.00
0005434138110	28561	Economy	7700.00
0005434138233	28561	Economy	7700.00
0005434137921	28561	Economy	7700.00
0005434087518	28561	Economy	7700.00
0005434138239	28561	Economy	7700.00
0005434137922	28561	Economy	7700.00
0005434137925	28561	Economy	7700.00
0005434138016	28561	Economy	7700.00
0005434138098	28561	Economy	7700.00
0005434138181	28561	Economy	7700.00
0005434137918	28561	Economy	7700.00
0005434138152	28561	Economy	7700.00
0005434138264	28561	Economy	7700.00
0005434138249	28561	Economy	7700.00
0005434138099	28561	Economy	7700.00
0005434137972	28561	Economy	7700.00
0005434138201	28561	Economy	7700.00
0005434137992	28561	Economy	7700.00
0005434137891	28561	Economy	7700.00
0005434138109	28561	Economy	7700.00
0005434137896	28561	Economy	7700.00
0005434137795	28561	Economy	7700.00
0005434137869	28561	Economy	7700.00
0005434137910	28561	Economy	7700.00
0005434137920	28561	Economy	7700.00
0005434138142	28561	Economy	7700.00
0005434138169	28561	Economy	7700.00
0005434138193	28561	Economy	7700.00
0005434087534	28561	Economy	7700.00
0005434137948	28561	Economy	7700.00
0005434137915	28561	Economy	7700.00
0005434138140	28561	Economy	7700.00
0005434137964	28561	Economy	7700.00
0005434087517	28561	Economy	7700.00
0005434138076	28561	Economy	7700.00
0005433407568	1913	Economy	23900.00
0005435808334	1913	Economy	21700.00
0005435808335	1913	Economy	21700.00
0005435808333	1913	Economy	21700.00
0005434610262	1913	Economy	21700.00
0005435808332	1913	Economy	21700.00
0005433407560	1913	Economy	21700.00
0005434610263	1913	Economy	21700.00
0005435808328	1913	Economy	21700.00
0005433407559	1913	Economy	21700.00
0005433407567	1913	Economy	21700.00
0005435808330	1913	Economy	21700.00
0005434610264	1913	Economy	21700.00
0005434610265	1913	Economy	21700.00
0005435808336	1913	Economy	21700.00
0005435808331	1913	Economy	21700.00
0005435808329	1913	Economy	21700.00
0005433407606	23077	Economy	23900.00
0005435808165	23077	Economy	23900.00
0005433407603	23077	Economy	23900.00
0005433407609	23077	Economy	21700.00
0005435808190	23077	Economy	21700.00
0005435808182	23077	Economy	21700.00
0005435808214	23077	Economy	21700.00
0005434610222	23077	Economy	21700.00
0005433407608	23077	Economy	21700.00
0005435808218	23077	Economy	21700.00
0005433407601	23077	Economy	21700.00
0005435808173	23077	Economy	21700.00
0005435808199	23077	Economy	21700.00
0005435808225	23077	Economy	21700.00
0005435808188	23077	Economy	21700.00
0005435808159	23077	Economy	21700.00
0005435808201	23077	Economy	21700.00
0005433407604	23077	Economy	21700.00
0005435808197	23077	Economy	21700.00
0005434610231	23077	Economy	21700.00
0005435808222	23077	Economy	21700.00
0005433407605	23077	Economy	21700.00
0005435808223	23077	Economy	21700.00
0005435808178	23077	Economy	21700.00
0005434610223	23077	Economy	21700.00
0005435808224	23077	Economy	21700.00
0005435808198	23077	Economy	21700.00
0005433407611	23077	Economy	21700.00
0005435808212	23077	Economy	21700.00
0005435808189	23077	Economy	21700.00
0005435808195	23077	Economy	21700.00
0005435808213	23077	Economy	21700.00
0005435808196	23077	Economy	21700.00
0005435808194	23077	Economy	21700.00
0005435808234	23077	Economy	21700.00
0005435808193	23077	Economy	21700.00
0005435808221	23077	Economy	21700.00
0005433407610	23077	Economy	21700.00
0005433407602	23077	Economy	21700.00
0005435808233	23077	Economy	21700.00
0005433407607	23077	Economy	21700.00
0005434504014	16697	Economy	7600.00
0005434504104	16697	Economy	7600.00
0005434504170	16697	Economy	7600.00
0005434504153	16697	Economy	7600.00
0005434504161	16697	Economy	6900.00
0005434504075	16697	Economy	6900.00
0005434504190	16697	Economy	6900.00
0005434504173	16697	Economy	6900.00
0005434504116	16697	Economy	6900.00
0005434504064	16697	Economy	6900.00
0005434503994	16697	Economy	6900.00
0005434504144	16697	Economy	6900.00
0005434504123	16697	Economy	6900.00
0005434504183	16697	Economy	6900.00
0005434504171	16697	Economy	6900.00
0005434504124	16697	Economy	6900.00
0005434504106	16697	Economy	6900.00
0005434503993	16697	Economy	6900.00
0005434504145	16697	Economy	6900.00
0005434504015	16697	Economy	6900.00
0005434504208	16697	Economy	6900.00
0005434504162	16697	Economy	6900.00
0005434504069	16697	Economy	6900.00
0005434504180	16697	Economy	6900.00
0005434504083	16697	Economy	6900.00
0005434504047	16697	Economy	6900.00
0005434504045	16697	Economy	6900.00
0005434504179	16697	Economy	6900.00
0005434503989	16697	Economy	6900.00
0005434504063	16697	Economy	6900.00
0005434504087	16697	Economy	6900.00
0005434504105	16697	Economy	6900.00
0005434504218	16697	Economy	6900.00
0005434504086	16697	Economy	6900.00
0005434504207	16697	Economy	6900.00
0005434504178	16697	Economy	6900.00
0005434504082	16697	Economy	6900.00
0005434504216	16697	Economy	6900.00
0005434504023	16697	Economy	6900.00
0005434504048	16697	Economy	6900.00
0005434504160	16697	Economy	6900.00
0005434504220	16697	Economy	6900.00
0005434504154	16697	Economy	6900.00
0005434504223	16697	Economy	6900.00
0005434504125	16697	Economy	6900.00
0005434504152	16697	Economy	6900.00
0005434504150	16697	Economy	6900.00
0005434504184	16697	Economy	6900.00
0005434504115	16697	Economy	6900.00
0005434504151	16697	Economy	6900.00
0005434504469	22935	Economy	7600.00
0005434504479	22935	Economy	7600.00
0005434504486	22935	Economy	7600.00
0005434504477	22935	Economy	7600.00
0005434504494	22935	Economy	6900.00
0005434504474	22935	Economy	6900.00
0005434504493	22935	Economy	6900.00
0005434504475	22935	Economy	6900.00
0005434504471	22935	Economy	6900.00
0005434504481	22935	Economy	6900.00
0005434504502	22935	Economy	6900.00
0005434504497	22935	Economy	6900.00
0005434504491	22935	Economy	6900.00
0005434504478	22935	Economy	6900.00
0005434504476	22935	Economy	6900.00
0005434504500	22935	Economy	6900.00
0005434504473	22935	Economy	6900.00
0005434504490	22935	Economy	6900.00
0005434504485	22935	Economy	6900.00
0005434504498	22935	Economy	6900.00
0005434504467	22935	Economy	6900.00
0005434504495	22935	Economy	6900.00
0005434504464	22935	Economy	6900.00
0005434504499	22935	Economy	6900.00
0005434504466	22935	Economy	6900.00
0005434504470	22935	Economy	6900.00
0005434504487	22935	Economy	6900.00
0005434504504	22935	Economy	6900.00
0005434504480	22935	Economy	6900.00
0005434504465	22935	Economy	6900.00
0005434504488	22935	Economy	6900.00
0005434504489	22935	Economy	6900.00
0005434504472	22935	Economy	6900.00
0005434504483	22935	Economy	6900.00
0005434504503	22935	Economy	6900.00
0005434504468	22935	Economy	6900.00
0005434504482	22935	Economy	6900.00
0005434504484	22935	Economy	6900.00
0005434504492	22935	Economy	6900.00
0005434504496	22935	Economy	6900.00
0005434504501	22935	Economy	6900.00
0005435078486	2229	Economy	7700.00
0005433266757	2229	Economy	7700.00
0005435078492	2229	Economy	7700.00
0005435078480	2229	Economy	7000.00
0005433266758	2229	Economy	7000.00
0005435078488	2229	Economy	7000.00
0005435078485	2229	Economy	7000.00
0005435078490	2229	Economy	7000.00
0005435078489	2229	Economy	7000.00
0005433266730	2229	Economy	7000.00
0005435078484	2229	Economy	7000.00
0005433266709	2229	Economy	7000.00
0005435078493	2229	Economy	7000.00
0005435078482	2229	Economy	7000.00
0005435078491	2229	Economy	7000.00
0005435078487	2229	Economy	7000.00
0005435078481	2229	Economy	7000.00
0005435078483	2229	Economy	7000.00
0005433266759	2229	Economy	7000.00
0005433266761	2229	Economy	7000.00
0005435078408	24346	Economy	7000.00
0005433266814	24346	Economy	7000.00
0005433266807	24346	Economy	7000.00
0005433266812	24346	Economy	7000.00
0005433266810	24346	Economy	7000.00
0005433266808	24346	Economy	7000.00
0005433266805	24346	Economy	7000.00
0005433266811	24346	Economy	7000.00
0005433266813	24346	Economy	7000.00
0005433266809	24346	Economy	7000.00
0005433266806	24346	Economy	7000.00
0005434988836	6663	Economy	10800.00
0005434988844	6663	Economy	9800.00
0005434988842	6663	Economy	9800.00
0005434988834	6663	Economy	9800.00
0005434988832	6663	Economy	9800.00
0005434988837	6663	Economy	9800.00
0005434988843	6663	Economy	9800.00
0005434988845	6663	Economy	9800.00
0005434988838	6663	Economy	9800.00
0005435464509	6663	Economy	9800.00
0005434988840	6663	Economy	9800.00
0005434988835	6663	Economy	9800.00
0005434988841	6663	Economy	9800.00
0005434988833	6663	Economy	9800.00
0005434988839	6663	Economy	9800.00
0005434988683	23615	Economy	10800.00
0005434988694	23615	Economy	9800.00
0005435464526	23615	Economy	9800.00
0005434988702	23615	Economy	9800.00
0005434988693	23615	Economy	9800.00
0005435803269	23615	Economy	9800.00
0005435803261	23615	Economy	9800.00
0005435464529	23615	Economy	9800.00
0005435803273	23615	Economy	9800.00
0005434988685	23615	Economy	9800.00
0005434988684	23615	Economy	9800.00
0005435464528	23615	Economy	9800.00
0005435803272	23615	Economy	9800.00
0005434988707	23615	Economy	9800.00
0005434988695	23615	Economy	9800.00
0005434988692	23615	Economy	9800.00
0005435464527	23615	Economy	9800.00
0005432383543	30505	Business	9900.00
0005432383537	30505	Business	9900.00
0005433450163	30505	Business	9900.00
0005432383550	30505	Business	9900.00
0005433450170	30505	Business	9900.00
0005433454896	30505	Business	9900.00
0005432383542	30505	Business	9900.00
0005433450165	30505	Business	9900.00
0005432383553	30505	Business	9900.00
0005432383560	30505	Business	9900.00
0005432383539	30505	Economy	3300.00
0005432383555	30505	Economy	3300.00
0005432383559	30505	Economy	3300.00
0005432383561	30505	Economy	3300.00
0005433450172	30505	Economy	3300.00
0005433450177	30505	Economy	3300.00
0005432383567	30505	Economy	3600.00
0005432383570	30505	Economy	3600.00
0005432383538	30505	Economy	3600.00
0005432383552	30505	Economy	3300.00
0005433450181	30505	Economy	3300.00
0005432383558	30505	Economy	3300.00
0005433450169	30505	Economy	3300.00
0005433450175	30505	Economy	3300.00
0005432383536	30505	Economy	3300.00
0005432383569	30505	Economy	3300.00
0005432383562	30505	Economy	3300.00
0005432383548	30505	Economy	3300.00
0005433450176	30505	Economy	3300.00
0005433453779	30505	Economy	3300.00
0005432383565	30505	Economy	3300.00
0005433454895	30505	Economy	3300.00
0005433450183	30505	Economy	3300.00
0005433450173	30505	Economy	3300.00
0005432383557	30505	Economy	3300.00
0005433450180	30505	Economy	3300.00
0005432383535	30505	Economy	3300.00
0005432383540	30505	Economy	3300.00
0005433450182	30505	Economy	3300.00
0005433450178	30505	Economy	3300.00
0005433454897	30505	Economy	3300.00
0005432383564	30505	Economy	3300.00
0005433450174	30505	Economy	3300.00
0005433450184	30505	Economy	3300.00
0005433450166	30505	Economy	3300.00
0005432383549	30505	Economy	3300.00
0005433450179	30505	Economy	3300.00
0005432383544	30505	Economy	3300.00
0005433453777	30505	Economy	3300.00
0005432383541	30505	Economy	3300.00
0005432383545	30505	Economy	3300.00
0005432383533	30505	Economy	3300.00
0005432383568	30505	Economy	3300.00
0005433450168	30505	Economy	3300.00
0005432383551	30505	Economy	3300.00
0005432383554	30505	Economy	3300.00
0005432383563	30505	Economy	3300.00
0005433450164	30505	Economy	3300.00
0005432383556	30505	Economy	3300.00
0005433453778	30505	Economy	3300.00
0005432383547	30505	Economy	3300.00
0005432383546	30505	Economy	3300.00
0005432383534	30505	Economy	3300.00
0005433450167	30505	Economy	3300.00
0005433450171	30505	Economy	3300.00
0005432383566	30505	Economy	3300.00
0005432383017	31332	Business	9900.00
0005433450063	31332	Business	9900.00
0005433449966	31332	Business	9900.00
0005432383112	31332	Business	9900.00
0005433450118	31332	Business	9900.00
0005432383067	31332	Business	9900.00
0005433449945	31332	Business	9900.00
0005432383173	31332	Business	9900.00
0005432382998	31332	Business	9900.00
0005432383005	31332	Business	9900.00
0005432383137	31332	Economy	3300.00
0005433449946	31332	Economy	3300.00
0005433449943	31332	Economy	3300.00
0005432383142	31332	Economy	3300.00
0005432383138	31332	Economy	3300.00
0005433450062	31332	Economy	3300.00
0005433450023	31332	Economy	3300.00
0005432383167	31332	Economy	3600.00
0005433449953	31332	Economy	3600.00
0005432383169	31332	Economy	3600.00
0005433450040	31332	Economy	3600.00
0005433449947	31332	Economy	3300.00
0005432383141	31332	Economy	3300.00
0005432383094	31332	Economy	3300.00
0005433450065	31332	Economy	3300.00
0005433449911	31332	Economy	3300.00
0005432383179	31332	Economy	3300.00
0005432383093	31332	Economy	3300.00
0005432382987	31332	Economy	3300.00
0005433449912	31332	Economy	3300.00
0005432382993	31332	Economy	3300.00
0005432383068	31332	Economy	3300.00
0005433449948	31332	Economy	3300.00
0005432383014	31332	Economy	3300.00
0005433449995	31332	Economy	3300.00
0005433450052	31332	Economy	3300.00
0005433449923	31332	Economy	3300.00
0005432383135	31332	Economy	3300.00
0005433449967	31332	Economy	3300.00
0005433449988	31332	Economy	3300.00
0005433449999	31332	Economy	3300.00
0005432383162	31332	Economy	3300.00
0005432383188	31332	Economy	3300.00
0005433449994	31332	Economy	3300.00
0005432383022	31332	Economy	3300.00
0005433449959	31332	Economy	3300.00
0005432383098	31332	Economy	3300.00
0005432383013	31332	Economy	3300.00
0005432383097	31332	Economy	3300.00
0005432383015	31332	Economy	3300.00
0005433450043	31332	Economy	3300.00
0005433449924	31332	Economy	3300.00
0005432382994	31332	Economy	3300.00
0005432383174	31332	Economy	3300.00
0005432383143	31332	Economy	3300.00
0005432382970	31332	Economy	3300.00
0005432382986	31332	Economy	3300.00
0005433449977	31332	Economy	3300.00
0005433449944	31332	Economy	3300.00
0005432383049	31332	Economy	3300.00
0005433450061	31332	Economy	3300.00
0005433450117	31332	Economy	3300.00
0005432383131	31332	Economy	3300.00
0005432383146	31332	Economy	3300.00
0005432383092	31332	Economy	3300.00
0005432383187	31332	Economy	3300.00
0005433449978	31332	Economy	3300.00
0005432383004	31332	Economy	3300.00
0005432383101	31332	Economy	3300.00
0005435299792	10778	Economy	15600.00
0005433126821	10778	Economy	15600.00
0005433126834	10778	Economy	15600.00
0005433126815	10778	Economy	15600.00
0005435304149	10778	Economy	15600.00
0005435304152	10778	Economy	15600.00
0005435304167	10778	Economy	15600.00
0005433126814	10778	Economy	15600.00
0005433126832	10778	Economy	15600.00
0005435304153	10778	Economy	15600.00
0005435304154	10778	Economy	15600.00
0005433126820	10778	Economy	15600.00
0005433131713	10778	Economy	15600.00
0005433131712	10778	Economy	15600.00
0005433126833	10778	Economy	15600.00
0005435299823	29732	Economy	17100.00
0005435299825	29732	Economy	17100.00
0005433126889	29732	Economy	15600.00
0005433129324	29732	Economy	15600.00
0005435299824	29732	Economy	15600.00
0005435302246	29732	Economy	15600.00
0005435299826	29732	Economy	15600.00
0005433126893	29732	Economy	15600.00
0005433126895	29732	Economy	15600.00
0005433126891	29732	Economy	15600.00
0005435302247	29732	Economy	15600.00
0005433129322	29732	Economy	15600.00
0005433129323	29732	Economy	15600.00
0005433126892	29732	Economy	15600.00
0005435302248	29732	Economy	15600.00
0005433126890	29732	Economy	15600.00
0005433129321	29732	Economy	15600.00
0005435299822	29732	Economy	15600.00
0005433126894	29732	Economy	15600.00
0005435302245	29732	Economy	15600.00
0005434287507	2407	Economy	17200.00
0005434287496	2407	Economy	17200.00
0005434287495	2407	Economy	17200.00
0005434287490	2407	Economy	15700.00
0005432264499	2407	Economy	15700.00
0005434287484	2407	Economy	15700.00
0005434287487	2407	Economy	15700.00
0005434287500	2407	Economy	15700.00
0005434287492	2407	Economy	15700.00
0005433110037	2407	Economy	15700.00
0005433110011	2407	Economy	15700.00
0005433110099	2407	Economy	15700.00
0005433110063	2407	Economy	15700.00
0005434287506	2407	Economy	15700.00
0005434287491	2407	Economy	15700.00
0005434287489	2407	Economy	15700.00
0005434287499	2407	Economy	15700.00
0005434287486	2407	Economy	15700.00
0005434287488	2407	Economy	15700.00
0005434287503	2407	Economy	15700.00
0005434287502	2407	Economy	15700.00
0005434287505	2407	Economy	15700.00
0005432264497	2407	Economy	15700.00
0005434287504	2407	Economy	15700.00
0005433110083	2407	Economy	15700.00
0005433110087	2407	Economy	15700.00
0005433110104	2407	Economy	15700.00
0005433110076	2407	Economy	15700.00
0005434287497	2407	Economy	15700.00
0005434287498	2407	Economy	15700.00
0005433110060	2407	Economy	15700.00
0005433110058	2407	Economy	15700.00
0005433110075	2407	Economy	15700.00
0005434287501	2407	Economy	15700.00
0005434287485	2407	Economy	15700.00
0005433110082	2407	Economy	15700.00
0005434287494	2407	Economy	15700.00
0005434287493	2407	Economy	15700.00
0005433110059	2407	Economy	15700.00
0005432264498	2407	Economy	15700.00
0005434287355	26842	Economy	17200.00
0005434287369	26842	Economy	17200.00
0005434287320	26842	Economy	17200.00
0005434287219	26842	Economy	15700.00
0005434287270	26842	Economy	15700.00
0005434287286	26842	Economy	15700.00
0005434287316	26842	Economy	15700.00
0005434287375	26842	Economy	15700.00
0005434287223	26842	Economy	15700.00
0005434287214	26842	Economy	15700.00
0005434287308	26842	Economy	15700.00
0005434287370	26842	Economy	15700.00
0005434287287	26842	Economy	15700.00
0005434287336	26842	Economy	15700.00
0005433110160	26842	Economy	15700.00
0005433110166	26842	Economy	15700.00
0005434287296	26842	Economy	15700.00
0005433110170	26842	Economy	15700.00
0005434287249	26842	Economy	15700.00
0005433110171	26842	Economy	15700.00
0005433110165	26842	Economy	15700.00
0005433110173	26842	Economy	15700.00
0005433110168	26842	Economy	15700.00
0005433110161	26842	Economy	15700.00
0005434287350	26842	Economy	15700.00
0005433110167	26842	Economy	15700.00
0005434287220	26842	Economy	15700.00
0005434287304	26842	Economy	15700.00
0005433110163	26842	Economy	15700.00
0005433110159	26842	Economy	15700.00
0005433110172	26842	Economy	15700.00
0005434287278	26842	Economy	15700.00
0005434287213	26842	Economy	15700.00
0005434287277	26842	Economy	15700.00
0005433110164	26842	Economy	15700.00
0005434287337	26842	Economy	15700.00
0005434287279	26842	Economy	15700.00
0005434287309	26842	Economy	15700.00
0005433110169	26842	Economy	15700.00
0005433110162	26842	Economy	15700.00
0005434287374	26842	Economy	15700.00
0005434272191	25474	Economy	22800.00
0005435856243	25474	Economy	22800.00
0005435856245	25474	Economy	22800.00
0005434269094	25474	Economy	22800.00
0005435856242	25474	Economy	22800.00
0005435856244	25474	Economy	22800.00
0005434272190	25474	Economy	22800.00
0005434269095	25474	Economy	22800.00
0005434272189	25474	Economy	22800.00
0005434269100	25474	Economy	22800.00
0005434273093	26621	Economy	22800.00
0005434273094	26621	Economy	22800.00
0005435854059	26621	Economy	22800.00
0005435856187	26621	Economy	22800.00
0005434272208	26621	Economy	22800.00
0005434272209	26621	Economy	22800.00
0005435856198	26621	Economy	22800.00
0005435856181	26621	Economy	22800.00
0005433650754	7162	Business	89800.00
0005433650757	7162	Business	89800.00
0005433650769	7162	Business	89800.00
0005435263639	7162	Business	89800.00
0005433650773	7162	Business	89800.00
0005433650792	7162	Business	89800.00
0005435263647	7162	Business	89800.00
0005435263601	7162	Business	89800.00
0005435263620	7162	Business	89800.00
0005433650766	7162	Business	89800.00
0005433650775	7162	Business	89800.00
0005433650763	7162	Economy	29900.00
0005435263641	7162	Economy	29900.00
0005433650782	7162	Economy	29900.00
0005433650779	7162	Economy	29900.00
0005433650797	7162	Economy	29900.00
0005435263630	7162	Economy	29900.00
0005435263612	7162	Economy	29900.00
0005433650781	7162	Economy	29900.00
0005433650788	7162	Economy	32900.00
0005433650795	7162	Economy	32900.00
0005433650767	7162	Economy	32900.00
0005433650796	7162	Economy	32900.00
0005433650752	7162	Economy	29900.00
0005433650768	7162	Economy	29900.00
0005435263570	7162	Economy	29900.00
0005435263609	7162	Economy	29900.00
0005435263573	7162	Economy	29900.00
0005433650793	7162	Economy	29900.00
0005435263613	7162	Economy	29900.00
0005435263615	7162	Economy	29900.00
0005433650789	7162	Economy	29900.00
0005433650765	7162	Economy	29900.00
0005433650791	7162	Economy	29900.00
0005433650755	7162	Economy	29900.00
0005435263629	7162	Economy	29900.00
0005435263633	7162	Economy	29900.00
0005433650790	7162	Economy	29900.00
0005433650778	7162	Economy	29900.00
0005435263602	7162	Economy	29900.00
0005433650786	7162	Economy	29900.00
0005433650777	7162	Economy	29900.00
0005433650758	7162	Economy	29900.00
0005435263627	7162	Economy	29900.00
0005433650761	7162	Economy	29900.00
0005435263632	7162	Economy	29900.00
0005433650762	7162	Economy	29900.00
0005435263628	7162	Economy	29900.00
0005435263571	7162	Economy	29900.00
0005433650771	7162	Economy	29900.00
0005433650759	7162	Economy	29900.00
0005433650760	7162	Economy	29900.00
0005435263640	7162	Economy	29900.00
0005435263621	7162	Economy	29900.00
0005435263642	7162	Economy	29900.00
0005435263635	7162	Economy	29900.00
0005433650774	7162	Economy	29900.00
0005433650783	7162	Economy	29900.00
0005435263565	7162	Economy	29900.00
0005433650776	7162	Economy	29900.00
0005433650780	7162	Economy	29900.00
0005433650772	7162	Economy	29900.00
0005433650785	7162	Economy	29900.00
0005433650770	7162	Economy	29900.00
0005433650794	7162	Economy	29900.00
0005433650799	7162	Economy	29900.00
0005433650753	7162	Economy	29900.00
0005433650798	7162	Economy	29900.00
0005433650764	7162	Economy	29900.00
0005433650784	7162	Economy	29900.00
0005435263572	7162	Economy	29900.00
0005435263614	7162	Economy	29900.00
0005433650756	7162	Economy	29900.00
0005433650787	7162	Economy	29900.00
0005433868801	4798	Economy	19400.00
0005433868800	4798	Economy	19400.00
0005433868815	4798	Economy	19400.00
0005433868823	4798	Economy	17600.00
0005433868825	4798	Economy	17600.00
0005433868799	4798	Economy	17600.00
0005433868802	4798	Economy	17600.00
0005433868811	4798	Economy	17600.00
0005433868821	4798	Economy	17600.00
0005433868807	4798	Economy	17600.00
0005433868828	4798	Economy	17600.00
0005433868833	4798	Economy	17600.00
0005433868803	4798	Economy	17600.00
0005433868806	4798	Economy	17600.00
0005433868826	4798	Economy	17600.00
0005433868816	4798	Economy	17600.00
0005433868832	4798	Economy	17600.00
0005433868831	4798	Economy	17600.00
0005433868809	4798	Economy	17600.00
0005433868819	4798	Economy	17600.00
0005433868797	4798	Economy	17600.00
0005433868814	4798	Economy	17600.00
0005433868813	4798	Economy	17600.00
0005433868812	4798	Economy	17600.00
0005433868827	4798	Economy	17600.00
0005433868835	4798	Economy	17600.00
0005433868808	4798	Economy	17600.00
0005433868830	4798	Economy	17600.00
0005433868822	4798	Economy	17600.00
0005433868818	4798	Economy	17600.00
0005433868805	4798	Economy	17600.00
0005433868836	4798	Economy	17600.00
0005433868798	4798	Economy	17600.00
0005433868829	4798	Economy	17600.00
0005433868804	4798	Economy	17600.00
0005433868820	4798	Economy	17600.00
0005433868810	4798	Economy	17600.00
0005433868817	4798	Economy	17600.00
0005433868834	4798	Economy	17600.00
0005433868824	4798	Economy	17600.00
0005433868395	32573	Economy	19400.00
0005433868371	32573	Economy	19400.00
0005433868357	32573	Economy	19400.00
0005433868233	32573	Economy	19400.00
0005433868439	32573	Economy	17600.00
0005433868346	32573	Economy	17600.00
0005433868539	32573	Economy	17600.00
0005433868561	32573	Economy	17600.00
0005433868437	32573	Economy	17600.00
0005433868440	32573	Economy	17600.00
0005433868234	32573	Economy	17600.00
0005433868513	32573	Economy	17600.00
0005433868505	32573	Economy	17600.00
0005433868376	32573	Economy	17600.00
0005433868614	32573	Economy	17600.00
0005433868379	32573	Economy	17600.00
0005433868401	32573	Economy	17600.00
0005433868350	32573	Economy	17600.00
0005433868343	32573	Economy	17600.00
0005433868396	32573	Economy	17600.00
0005433868421	32573	Economy	17600.00
0005433868407	32573	Economy	17600.00
0005433868400	32573	Economy	17600.00
0005433868562	32573	Economy	17600.00
0005433868120	32573	Economy	17600.00
0005433868341	32573	Economy	17600.00
0005433868463	32573	Economy	17600.00
0005433868419	32573	Economy	17600.00
0005433868351	32573	Economy	17600.00
0005433868422	32573	Economy	17600.00
0005433868342	32573	Economy	17600.00
0005433868347	32573	Economy	17600.00
0005433868514	32573	Economy	17600.00
0005433868480	32573	Economy	17600.00
0005433868232	32573	Economy	17600.00
0005433868533	32573	Economy	17600.00
0005433868231	32573	Economy	17600.00
0005433868616	32573	Economy	17600.00
0005433868468	32573	Economy	17600.00
0005433868617	32573	Economy	17600.00
0005433868540	32573	Economy	17600.00
0005434663533	3405	Economy	24800.00
0005434663535	3405	Economy	24800.00
0005434461667	3405	Economy	24800.00
0005434663541	3405	Economy	24800.00
0005434663529	3405	Economy	22600.00
0005435911494	3405	Economy	22600.00
0005435911475	3405	Economy	22600.00
0005434663534	3405	Economy	22600.00
0005434663528	3405	Economy	22600.00
0005435911450	3405	Economy	22600.00
0005434663530	3405	Economy	22600.00
0005434663531	3405	Economy	22600.00
0005434663540	3405	Economy	22600.00
0005434461666	3405	Economy	22600.00
0005434663532	3405	Economy	22600.00
0005435911449	3405	Economy	22600.00
0005434663536	3405	Economy	22600.00
0005434460525	3405	Economy	22600.00
0005435911437	3405	Economy	22600.00
0005434663539	3405	Economy	22600.00
0005435911458	3405	Economy	22600.00
0005434663542	3405	Economy	22600.00
0005435911476	3405	Economy	22600.00
0005435911448	3405	Economy	22600.00
0005434663537	3405	Economy	22600.00
0005434663538	3405	Economy	22600.00
0005435911459	3405	Economy	22600.00
0005435911445	3405	Economy	22600.00
0005435911466	3405	Economy	22600.00
0005434460526	3405	Economy	22600.00
0005435911525	12470	Economy	24800.00
0005435911523	12470	Economy	24800.00
0005434663449	12470	Economy	22600.00
0005434663442	12470	Economy	22600.00
0005435911524	12470	Economy	22600.00
0005434663443	12470	Economy	22600.00
0005435911521	12470	Economy	22600.00
0005434663432	12470	Economy	22600.00
0005434663458	12470	Economy	22600.00
0005434663445	12470	Economy	22600.00
0005434663407	12470	Economy	22600.00
0005434663450	12470	Economy	22600.00
0005434663405	12470	Economy	22600.00
0005435911520	12470	Economy	22600.00
0005434663457	12470	Economy	22600.00
0005435911522	12470	Economy	22600.00
0005434663480	12470	Economy	22600.00
0005435911526	12470	Economy	22600.00
0005433868347	14522	Economy	18500.00
0005433868233	14522	Economy	18500.00
0005433868513	14522	Economy	18500.00
0005433868514	14522	Economy	16800.00
0005433868562	14522	Economy	16800.00
0005433868422	14522	Economy	16800.00
0005433868480	14522	Economy	16800.00
0005433868505	14522	Economy	16800.00
0005433868379	14522	Economy	16800.00
0005433868376	14522	Economy	16800.00
0005433868341	14522	Economy	16800.00
0005433868533	14522	Economy	16800.00
0005433868419	14522	Economy	16800.00
0005433868440	14522	Economy	16800.00
0005433868231	14522	Economy	16800.00
0005433868617	14522	Economy	16800.00
0005433868234	14522	Economy	16800.00
0005433868561	14522	Economy	16800.00
0005433868614	14522	Economy	16800.00
0005433868407	14522	Economy	16800.00
0005433868351	14522	Economy	16800.00
0005433868401	14522	Economy	16800.00
0005433868463	14522	Economy	16800.00
0005433868421	14522	Economy	16800.00
0005433868232	14522	Economy	16800.00
0005433868400	14522	Economy	16800.00
0005433868346	14522	Economy	16800.00
0005433868540	14522	Economy	16800.00
0005433868396	14522	Economy	16800.00
0005433868395	14522	Economy	16800.00
0005433868539	14522	Economy	16800.00
0005433868468	14522	Economy	16800.00
0005433868371	14522	Economy	16800.00
0005433868342	14522	Economy	16800.00
0005433868343	14522	Economy	16800.00
0005433868439	14522	Economy	16800.00
0005433868350	14522	Economy	16800.00
0005433868437	14522	Economy	16800.00
0005433868616	14522	Economy	16800.00
0005433868357	14522	Economy	16800.00
0005433868120	14522	Economy	16800.00
0005433868780	32685	Economy	18500.00
0005433868779	32685	Economy	18500.00
0005433868762	32685	Economy	18500.00
0005433868781	32685	Economy	18500.00
0005433868763	32685	Economy	16800.00
0005435860488	32685	Economy	16800.00
0005433868770	32685	Economy	16800.00
0005433868795	32685	Economy	16800.00
0005433868764	32685	Economy	16800.00
0005435860489	32685	Economy	16800.00
0005433868761	32685	Economy	16800.00
0005433868772	32685	Economy	16800.00
0005433868782	32685	Economy	16800.00
0005433868753	32685	Economy	16800.00
0005433868786	32685	Economy	16800.00
0005433868783	32685	Economy	16800.00
0005433868784	32685	Economy	16800.00
0005433868768	32685	Economy	16800.00
0005433868760	32685	Economy	16800.00
0005433868773	32685	Economy	16800.00
0005433868789	32685	Economy	16800.00
0005433868787	32685	Economy	16800.00
0005433868771	32685	Economy	16800.00
0005433868790	32685	Economy	16800.00
0005433868767	32685	Economy	16800.00
0005433868769	32685	Economy	16800.00
0005433868796	32685	Economy	16800.00
0005433868755	32685	Economy	16800.00
0005433868759	32685	Economy	16800.00
0005433868776	32685	Economy	16800.00
0005435860481	32685	Economy	16800.00
0005433868774	32685	Economy	16800.00
0005433868794	32685	Economy	16800.00
0005433868778	32685	Economy	16800.00
0005435860470	32685	Economy	16800.00
0005433868788	32685	Economy	16800.00
0005433868754	32685	Economy	16800.00
0005433868791	32685	Economy	16800.00
0005433868756	32685	Economy	16800.00
0005433868792	32685	Economy	16800.00
0005433868758	32685	Economy	16800.00
0005433868766	32685	Economy	16800.00
0005433868775	32685	Economy	16800.00
0005433868765	32685	Economy	16800.00
0005433868785	32685	Economy	16800.00
0005433868793	32685	Economy	16800.00
0005433868777	32685	Economy	16800.00
0005433868757	32685	Economy	16800.00
0005432799511	12135	Economy	4900.00
0005432799476	12135	Economy	4900.00
0005432799458	12135	Economy	4400.00
0005432799542	12135	Economy	4400.00
0005432799528	12135	Economy	4400.00
0005432799455	12135	Economy	4400.00
0005432799431	12135	Economy	4400.00
0005432799430	12135	Economy	4400.00
0005432799488	12135	Economy	4400.00
0005432799540	12135	Economy	4400.00
0005432799570	12135	Economy	4400.00
0005432799286	12135	Economy	4400.00
0005432799434	12135	Economy	4400.00
0005432799360	12135	Economy	4400.00
0005432799541	12135	Economy	4400.00
0005432799579	12135	Economy	4400.00
0005432799489	12135	Economy	4400.00
0005432799507	12135	Economy	4400.00
0005432799513	12135	Economy	4400.00
0005432799486	12135	Economy	4400.00
0005432799447	12135	Economy	4400.00
0005432799494	12135	Economy	4400.00
0005432799514	12135	Economy	4400.00
0005432799370	12135	Economy	4400.00
0005432799389	12135	Economy	4400.00
0005432799487	12135	Economy	4400.00
0005432799571	12135	Economy	4400.00
0005432799543	12135	Economy	4400.00
0005432799679	14828	Economy	4900.00
0005432799682	14828	Economy	4900.00
0005432799700	14828	Economy	4400.00
0005432799695	14828	Economy	4400.00
0005432799694	14828	Economy	4400.00
0005432799680	14828	Economy	4400.00
0005432799698	14828	Economy	4400.00
0005432799691	14828	Economy	4400.00
0005432799692	14828	Economy	4400.00
0005432799696	14828	Economy	4400.00
0005432799678	14828	Economy	4400.00
0005432799702	14828	Economy	4400.00
0005432799676	14828	Economy	4400.00
0005432799686	14828	Economy	4400.00
0005432799699	14828	Economy	4400.00
0005432799706	14828	Economy	4400.00
0005432799681	14828	Economy	4400.00
0005432799688	14828	Economy	4400.00
0005432799687	14828	Economy	4400.00
0005432799693	14828	Economy	4400.00
0005432799689	14828	Economy	4400.00
0005432799690	14828	Economy	4400.00
0005432799684	14828	Economy	4400.00
0005432799685	14828	Economy	4400.00
0005432799683	14828	Economy	4400.00
0005432799697	14828	Economy	4400.00
0005432799705	14828	Economy	4400.00
0005432799703	14828	Economy	4400.00
0005432799704	14828	Economy	4400.00
0005432799701	14828	Economy	4400.00
0005432799677	14828	Economy	4400.00
0005434408375	7076	Business	49100.00
0005434408364	7076	Business	49100.00
0005434408354	7076	Business	49100.00
0005434408348	7076	Business	49100.00
0005432154001	7076	Business	49100.00
0005434299781	7076	Business	49100.00
0005432108275	7076	Business	49100.00
0005435311060	7076	Business	49100.00
0005435293281	7076	Business	49100.00
0005434299776	7076	Business	49100.00
0005434408359	7076	Business	49100.00
0005435293237	7076	Economy	16400.00
0005434299779	7076	Economy	16400.00
0005435293251	7076	Economy	16400.00
0005434408340	7076	Economy	16400.00
0005434408345	7076	Economy	16400.00
0005434299772	7076	Economy	16400.00
0005432108274	7076	Economy	16400.00
0005434408367	7076	Economy	16400.00
0005432154003	7076	Economy	16400.00
0005434408320	7076	Economy	16400.00
0005434299770	7076	Economy	16400.00
0005434408341	7076	Economy	16400.00
0005434408347	7076	Economy	16400.00
0005434408318	7076	Economy	16400.00
0005434408372	7076	Economy	16400.00
0005434408363	7076	Economy	16400.00
0005434408358	7076	Economy	16400.00
0005434408333	7076	Economy	16400.00
0005435293269	7076	Economy	16400.00
0005434408350	7076	Economy	16400.00
0005434408366	7076	Economy	16400.00
0005434299786	7076	Economy	16400.00
0005435293236	7076	Economy	16400.00
0005435311037	7076	Economy	16400.00
0005434408378	7076	Economy	16400.00
0005434299777	7076	Economy	16400.00
0005434299769	7076	Economy	16400.00
0005434408357	7076	Economy	16400.00
0005434408376	7076	Economy	16400.00
0005435311080	7076	Economy	16400.00
0005434408329	7076	Economy	16400.00
0005435293264	7076	Economy	16400.00
0005435293299	7076	Economy	16400.00
0005435311078	7076	Economy	16400.00
0005434408353	7076	Economy	16400.00
0005435293249	7076	Economy	16400.00
0005434299773	7076	Economy	16400.00
0005434408326	7076	Economy	16400.00
0005434408346	7076	Economy	18000.00
0005434299775	7076	Economy	18000.00
0005434408334	7076	Economy	18000.00
0005434408327	7076	Economy	18000.00
0005434408323	7076	Economy	18000.00
0005434408369	7076	Economy	16400.00
0005432154006	7076	Economy	16400.00
0005434408343	7076	Economy	16400.00
0005434408360	7076	Economy	16400.00
0005435293298	7076	Economy	16400.00
0005434408339	7076	Economy	16400.00
0005432154007	7076	Economy	16400.00
0005434408344	7076	Economy	16400.00
0005434408355	7076	Economy	16400.00
0005434408379	7076	Economy	16400.00
0005434408365	7076	Economy	16400.00
0005435293307	7076	Economy	16400.00
0005434299771	7076	Economy	16400.00
0005434408374	7076	Economy	16400.00
0005434408349	7076	Economy	16400.00
0005434408331	7076	Economy	16400.00
0005434408338	7076	Economy	16400.00
0005434299768	7076	Economy	16400.00
0005434408337	7076	Economy	16400.00
0005434408368	7076	Economy	16400.00
0005434408321	7076	Economy	16400.00
0005434408352	7076	Economy	16400.00
0005434408373	7076	Economy	16400.00
0005435311038	7076	Economy	16400.00
0005435293232	7076	Economy	16400.00
0005432154004	7076	Economy	16400.00
0005435293282	7076	Economy	16400.00
0005432154002	7076	Economy	16400.00
0005435311030	7076	Economy	16400.00
0005434408328	7076	Economy	16400.00
0005435293242	7076	Economy	16400.00
0005434408332	7076	Economy	16400.00
0005434299767	7076	Economy	16400.00
0005434408335	7076	Economy	16400.00
0005434408319	7076	Economy	16400.00
0005434299774	7076	Economy	16400.00
0005435311079	7076	Economy	16400.00
0005434299788	7076	Economy	16400.00
0005434299785	7076	Economy	16400.00
0005432154005	7076	Economy	16400.00
0005434408380	7076	Economy	16400.00
0005434408381	7076	Economy	16400.00
0005434299787	7076	Economy	16400.00
0005434408325	7076	Economy	16400.00
0005434299789	7076	Economy	16400.00
0005434299766	7076	Economy	16400.00
0005434408322	7076	Economy	16400.00
0005434408377	7076	Economy	16400.00
0005434299782	7076	Economy	16400.00
0005434408324	7076	Economy	16400.00
0005435311054	7076	Economy	16400.00
0005434299784	7076	Economy	16400.00
0005434408361	7076	Economy	16400.00
0005432154000	7076	Economy	16400.00
0005434408342	7076	Economy	16400.00
0005434299780	7076	Economy	16400.00
0005434408336	7076	Economy	16400.00
0005434408330	7076	Economy	16400.00
0005434408356	7076	Economy	16400.00
0005434408370	7076	Economy	16400.00
0005434299783	7076	Economy	16400.00
0005434408371	7076	Economy	16400.00
0005434408362	7076	Economy	16400.00
0005435311031	7076	Economy	16400.00
0005435293223	7076	Economy	16400.00
0005432154008	7076	Economy	16400.00
0005434299778	7076	Economy	16400.00
0005435311083	7076	Economy	16400.00
0005434408351	7076	Economy	16400.00
0005434299652	26924	Business	49100.00
0005434407630	26924	Business	49100.00
0005434299577	26924	Business	49100.00
0005435311161	26924	Business	49100.00
0005434299642	26924	Business	49100.00
0005432058415	26924	Business	49100.00
0005434408025	26924	Business	49100.00
0005434407878	26924	Business	49100.00
0005434407748	26924	Business	49100.00
0005434299708	26924	Business	49100.00
0005434407791	26924	Business	49100.00
0005434299640	26924	Business	49100.00
0005434299567	26924	Economy	16400.00
0005434407426	26924	Economy	16400.00
0005434407584	26924	Economy	16400.00
0005434407859	26924	Economy	16400.00
0005434407631	26924	Economy	16400.00
0005434299569	26924	Economy	16400.00
0005434299657	26924	Economy	16400.00
0005435311158	26924	Economy	16400.00
0005435293370	26924	Economy	16400.00
0005435293371	26924	Economy	16400.00
0005434407771	26924	Economy	16400.00
0005434299568	26924	Economy	16400.00
0005434299589	26924	Economy	16400.00
0005434407758	26924	Economy	16400.00
0005434407939	26924	Economy	16400.00
0005434407927	26924	Economy	16400.00
0005434407898	26924	Economy	16400.00
0005435293373	26924	Economy	16400.00
0005434407772	26924	Economy	16400.00
0005432058413	26924	Economy	16400.00
0005432058416	26924	Economy	16400.00
0005434299588	26924	Economy	16400.00
0005434407896	26924	Economy	16400.00
0005434407838	26924	Economy	16400.00
0005434407495	26924	Economy	16400.00
0005435293369	26924	Economy	16400.00
0005435293363	26924	Economy	16400.00
0005434407773	26924	Economy	16400.00
0005434407583	26924	Economy	16400.00
0005434407741	26924	Economy	16400.00
0005434299644	26924	Economy	16400.00
0005434299507	26924	Economy	16400.00
0005434299651	26924	Economy	16400.00
0005434407753	26924	Economy	16400.00
0005434407679	26924	Economy	16400.00
0005434407486	26924	Economy	18000.00
0005432058417	26924	Economy	18000.00
0005434299624	26924	Economy	18000.00
0005434299582	26924	Economy	18000.00
0005435311162	26924	Economy	18000.00
0005434407678	26924	Economy	16400.00
0005434407957	26924	Economy	16400.00
0005434407738	26924	Economy	16400.00
0005434299578	26924	Economy	16400.00
0005435293367	26924	Economy	16400.00
0005434407874	26924	Economy	16400.00
0005434407494	26924	Economy	16400.00
0005434407549	26924	Economy	16400.00
0005435311160	26924	Economy	16400.00
0005434299586	26924	Economy	16400.00
0005434408024	26924	Economy	16400.00
0005434407969	26924	Economy	16400.00
0005432058414	26924	Economy	16400.00
0005434407928	26924	Economy	16400.00
0005435293368	26924	Economy	16400.00
0005434407714	26924	Economy	16400.00
0005434407951	26924	Economy	16400.00
0005435311159	26924	Economy	16400.00
0005435311157	26924	Economy	16400.00
0005434299643	26924	Economy	16400.00
0005434299641	26924	Economy	16400.00
0005435293374	26924	Economy	16400.00
0005434407792	26924	Economy	16400.00
0005434407644	26924	Economy	16400.00
0005434407858	26924	Economy	16400.00
0005435293366	26924	Economy	16400.00
0005434407540	26924	Economy	16400.00
0005434299655	26924	Economy	16400.00
0005434299627	26924	Economy	16400.00
0005434299625	26924	Economy	16400.00
0005434407601	26924	Economy	16400.00
0005434407873	26924	Economy	16400.00
0005434299650	26924	Economy	16400.00
0005434407561	26924	Economy	16400.00
0005434407539	26924	Economy	16400.00
0005434407856	26924	Economy	16400.00
0005435293364	26924	Economy	16400.00
0005434299600	26924	Economy	16400.00
0005434407762	26924	Economy	16400.00
0005434407715	26924	Economy	16400.00
0005434407879	26924	Economy	16400.00
0005434407855	26924	Economy	16400.00
0005434407564	26924	Economy	16400.00
0005434407754	26924	Economy	16400.00
0005434407857	26924	Economy	16400.00
0005434408023	26924	Economy	16400.00
0005434407780	26924	Economy	16400.00
0005434299715	26924	Economy	16400.00
0005434407577	26924	Economy	16400.00
0005434407815	26924	Economy	16400.00
0005434299599	26924	Economy	16400.00
0005434299707	26924	Economy	16400.00
0005434299570	26924	Economy	16400.00
0005434407675	26924	Economy	16400.00
0005434299462	26924	Economy	16400.00
0005434299635	26924	Economy	16400.00
0005434407740	26924	Economy	16400.00
0005434407781	26924	Economy	16400.00
0005435293365	26924	Economy	16400.00
0005434299716	26924	Economy	16400.00
0005435293372	26924	Economy	16400.00
0005434299656	26924	Economy	16400.00
0005434299602	26924	Economy	16400.00
0005434407557	26924	Economy	16400.00
0005435293362	26924	Economy	16400.00
0005432604736	6443	Economy	16500.00
0005432604697	6443	Economy	16500.00
0005432604731	6443	Economy	16500.00
0005432604707	6443	Economy	15000.00
0005432604722	6443	Economy	15000.00
0005432604714	6443	Economy	15000.00
0005434512154	6443	Economy	15000.00
0005432604703	6443	Economy	15000.00
0005434512152	6443	Economy	15000.00
0005432604733	6443	Economy	15000.00
0005432604728	6443	Economy	15000.00
0005432604701	6443	Economy	15000.00
0005434512155	6443	Economy	15000.00
0005432604717	6443	Economy	15000.00
0005432604696	6443	Economy	15000.00
0005432604729	6443	Economy	15000.00
0005432604699	6443	Economy	15000.00
0005432604704	6443	Economy	15000.00
0005432604715	6443	Economy	15000.00
0005434512151	6443	Economy	15000.00
0005432604719	6443	Economy	15000.00
0005432604702	6443	Economy	15000.00
0005432604726	6443	Economy	15000.00
0005434512153	6443	Economy	15000.00
0005432604727	6443	Economy	15000.00
0005432604706	6443	Economy	15000.00
0005432604710	6443	Economy	15000.00
0005432604698	6443	Economy	15000.00
0005432604732	6443	Economy	15000.00
0005432604709	6443	Economy	15000.00
0005432604713	6443	Economy	15000.00
0005432604718	6443	Economy	15000.00
0005432604711	6443	Economy	15000.00
0005432604708	6443	Economy	15000.00
0005432604721	6443	Economy	15000.00
0005432604720	6443	Economy	15000.00
0005432604716	6443	Economy	15000.00
0005432604725	6443	Economy	15000.00
0005432604712	6443	Economy	15000.00
0005432604734	6443	Economy	15000.00
0005432604705	6443	Economy	15000.00
0005432604730	6443	Economy	15000.00
0005432604723	6443	Economy	15000.00
0005432604735	6443	Economy	15000.00
0005432604724	6443	Economy	15000.00
0005432604700	6443	Economy	15000.00
0005432604258	21396	Economy	16500.00
0005432604374	21396	Economy	16500.00
0005432604421	21396	Economy	16500.00
0005432604337	21396	Economy	16500.00
0005432604302	21396	Economy	15000.00
0005432604212	21396	Economy	15000.00
0005432604316	21396	Economy	15000.00
0005432604510	21396	Economy	15000.00
0005432604332	21396	Economy	15000.00
0005432604409	21396	Economy	15000.00
0005432604082	21396	Economy	15000.00
0005432604303	21396	Economy	15000.00
0005432604373	21396	Economy	15000.00
0005432604240	21396	Economy	15000.00
0005432604360	21396	Economy	15000.00
0005432604134	21396	Economy	15000.00
0005432604359	21396	Economy	15000.00
0005432604133	21396	Economy	15000.00
0005432604358	21396	Economy	15000.00
0005432604259	21396	Economy	15000.00
0005432604131	21396	Economy	15000.00
0005432604333	21396	Economy	15000.00
0005432604415	21396	Economy	15000.00
0005432604223	21396	Economy	15000.00
0005432604130	21396	Economy	15000.00
0005432604098	21396	Economy	15000.00
0005432604220	21396	Economy	15000.00
0005432604472	21396	Economy	15000.00
0005432604338	21396	Economy	15000.00
0005432604455	21396	Economy	15000.00
0005432604345	21396	Economy	15000.00
0005432604404	21396	Economy	15000.00
0005432604304	21396	Economy	15000.00
0005432604315	21396	Economy	15000.00
0005432604028	21396	Economy	15000.00
0005432604270	21396	Economy	15000.00
0005432604260	21396	Economy	15000.00
0005432604239	21396	Economy	15000.00
0005432604335	21396	Economy	15000.00
0005432604405	21396	Economy	15000.00
0005432604348	21396	Economy	15000.00
0005432604518	21396	Economy	15000.00
0005432604097	21396	Economy	15000.00
0005432604224	21396	Economy	15000.00
0005432604470	21396	Economy	15000.00
0005432604334	21396	Economy	15000.00
0005432604300	21396	Economy	15000.00
0005432604511	21396	Economy	15000.00
0005432604318	21396	Economy	15000.00
0005434907290	14985	Business	18900.00
0005434907153	14985	Business	18900.00
0005433251773	14985	Business	18900.00
0005433251767	14985	Business	18900.00
0005434907205	14985	Business	18900.00
0005434907339	14985	Business	18900.00
0005434907312	14985	Business	18900.00
0005434907191	14985	Business	18900.00
0005434907319	14985	Business	18900.00
0005433251749	14985	Business	18900.00
0005434906871	14985	Economy	6300.00
0005433251765	14985	Economy	6300.00
0005433251760	14985	Economy	6300.00
0005433251771	14985	Economy	6300.00
0005433251764	14985	Economy	6300.00
0005433251779	14985	Economy	6300.00
0005434907280	14985	Economy	6300.00
0005434907304	14985	Economy	6300.00
0005434907209	14985	Economy	6300.00
0005434907267	14985	Economy	6300.00
0005434907017	14985	Economy	6900.00
0005434907052	14985	Economy	6900.00
0005434907340	14985	Economy	6900.00
0005434907165	14985	Economy	6900.00
0005433251763	14985	Economy	6900.00
0005433251757	14985	Economy	6300.00
0005434907346	14985	Economy	6300.00
0005434907259	14985	Economy	6300.00
0005433251761	14985	Economy	6300.00
0005434907258	14985	Economy	6300.00
0005434907250	14985	Economy	6300.00
0005433251755	14985	Economy	6300.00
0005434907178	14985	Economy	6300.00
0005434907276	14985	Economy	6300.00
0005434907160	14985	Economy	6300.00
0005434907311	14985	Economy	6300.00
0005433251770	14985	Economy	6300.00
0005433251766	14985	Economy	6300.00
0005434907202	14985	Economy	6300.00
0005434907300	14985	Economy	6300.00
0005434907048	14985	Economy	6300.00
0005434907235	14985	Economy	6300.00
0005433251754	14985	Economy	6300.00
0005434907169	14985	Economy	6300.00
0005433251752	14985	Economy	6300.00
0005434907130	14985	Economy	6300.00
0005433251758	14985	Economy	6300.00
0005434907201	14985	Economy	6300.00
0005433251759	14985	Economy	6300.00
0005433251778	14985	Economy	6300.00
0005433251780	14985	Economy	6300.00
0005434907264	14985	Economy	6300.00
0005433251776	14985	Economy	6300.00
0005434907307	14985	Economy	6300.00
0005434907104	14985	Economy	6300.00
0005434907279	14985	Economy	6300.00
0005434907152	14985	Economy	6300.00
0005434907170	14985	Economy	6300.00
0005433251769	14985	Economy	6300.00
0005433251750	14985	Economy	6300.00
0005434907016	14985	Economy	6300.00
0005434907211	14985	Economy	6300.00
0005434907320	14985	Economy	6300.00
0005434907347	14985	Economy	6300.00
0005434907263	14985	Economy	6300.00
0005434907306	14985	Economy	6300.00
0005434907313	14985	Economy	6300.00
0005434907341	14985	Economy	6300.00
0005433251774	14985	Economy	6300.00
0005433251762	14985	Economy	6300.00
0005433251756	14985	Economy	6300.00
0005433251777	14985	Economy	6300.00
0005434907321	14985	Economy	6300.00
0005434907105	14985	Economy	6300.00
0005433251751	14985	Economy	6300.00
0005434907134	14985	Economy	6300.00
0005433251753	14985	Economy	6300.00
0005434907272	14985	Economy	6300.00
0005434907177	14985	Economy	6300.00
0005434907230	14985	Economy	6300.00
0005433251775	14985	Economy	6300.00
0005433251781	14985	Economy	6300.00
0005434907275	14985	Economy	6300.00
0005433251772	14985	Economy	6300.00
0005434907192	14985	Economy	6300.00
0005434907159	14985	Economy	6300.00
0005434907210	14985	Economy	6300.00
0005433251768	14985	Economy	6300.00
0005433251534	25846	Business	18900.00
0005433251420	25846	Business	18900.00
0005433251593	25846	Business	18900.00
0005434907729	25846	Business	18900.00
0005434907742	25846	Business	18900.00
0005433251455	25846	Business	18900.00
0005433251562	25846	Business	18900.00
0005433251512	25846	Business	18900.00
0005434907710	25846	Business	18900.00
0005433251447	25846	Business	18900.00
0005434907741	25846	Economy	6300.00
0005434907714	25846	Economy	6300.00
0005434907713	25846	Economy	6300.00
0005434907740	25846	Economy	6300.00
0005434907727	25846	Economy	6300.00
0005434907733	25846	Economy	6300.00
0005433251594	25846	Economy	6300.00
0005433251599	25846	Economy	6300.00
0005434907734	25846	Economy	6900.00
0005434907715	25846	Economy	6900.00
0005433251454	25846	Economy	6900.00
0005434907719	25846	Economy	6900.00
0005434907712	25846	Economy	6900.00
0005434907745	25846	Economy	6300.00
0005434907736	25846	Economy	6300.00
0005434907716	25846	Economy	6300.00
0005433251600	25846	Economy	6300.00
0005433251491	25846	Economy	6300.00
0005434907735	25846	Economy	6300.00
0005433251544	25846	Economy	6300.00
0005434907722	25846	Economy	6300.00
0005434907730	25846	Economy	6300.00
0005433251414	25846	Economy	6300.00
0005433251390	25846	Economy	6300.00
0005434907709	25846	Economy	6300.00
0005434907732	25846	Economy	6300.00
0005433251498	25846	Economy	6300.00
0005433251428	25846	Economy	6300.00
0005433251347	25846	Economy	6300.00
0005433251496	25846	Economy	6300.00
0005433251453	25846	Economy	6300.00
0005433251514	25846	Economy	6300.00
0005433251456	25846	Economy	6300.00
0005433251434	25846	Economy	6300.00
0005434907721	25846	Economy	6300.00
0005433251435	25846	Economy	6300.00
0005433251466	25846	Economy	6300.00
0005433251561	25846	Economy	6300.00
0005433251367	25846	Economy	6300.00
0005433251611	25846	Economy	6300.00
0005434907717	25846	Economy	6300.00
0005434907728	25846	Economy	6300.00
0005434907737	25846	Economy	6300.00
0005434907708	25846	Economy	6300.00
0005434907743	25846	Economy	6300.00
0005433251505	25846	Economy	6300.00
0005433251548	25846	Economy	6300.00
0005434907718	25846	Economy	6300.00
0005434907711	25846	Economy	6300.00
0005433251392	25846	Economy	6300.00
0005434907738	25846	Economy	6300.00
0005433251510	25846	Economy	6300.00
0005433251592	25846	Economy	6300.00
0005434907725	25846	Economy	6300.00
0005433251480	25846	Economy	6300.00
0005433251346	25846	Economy	6300.00
0005434907744	25846	Economy	6300.00
0005433251433	25846	Economy	6300.00
0005434907739	25846	Economy	6300.00
0005434907724	25846	Economy	6300.00
0005434907723	25846	Economy	6300.00
0005433251481	25846	Economy	6300.00
0005434907720	25846	Economy	6300.00
0005433251338	25846	Economy	6300.00
0005433251511	25846	Economy	6300.00
0005434907707	25846	Economy	6300.00
0005433251488	25846	Economy	6300.00
0005434907731	25846	Economy	6300.00
0005433251553	25846	Economy	6300.00
0005434907726	25846	Economy	6300.00
0005433251418	25846	Economy	6300.00
0005433251389	25846	Economy	6300.00
0005433251489	25846	Economy	6300.00
0005433009042	14192	Business	52300.00
0005433009063	14192	Business	52300.00
0005433009050	14192	Business	52300.00
0005433009045	14192	Business	52300.00
0005433009028	14192	Business	52300.00
0005433810526	14192	Business	52300.00
0005433009051	14192	Economy	17400.00
0005433009044	14192	Economy	17400.00
0005433810533	14192	Economy	17400.00
0005433009059	14192	Economy	19200.00
0005433009033	14192	Economy	19200.00
0005433009071	14192	Economy	19200.00
0005433009073	14192	Economy	17400.00
0005433009066	14192	Economy	17400.00
0005433009068	14192	Economy	17400.00
0005433009037	14192	Economy	17400.00
0005433009058	14192	Economy	17400.00
0005433009065	14192	Economy	17400.00
0005433009034	14192	Economy	17400.00
0005433009043	14192	Economy	17400.00
0005433810521	14192	Economy	17400.00
0005433009054	14192	Economy	17400.00
0005433009053	14192	Economy	17400.00
0005433009035	14192	Economy	17400.00
0005433009048	14192	Economy	17400.00
0005433009055	14192	Economy	17400.00
0005433009069	14192	Economy	17400.00
0005433009046	14192	Economy	17400.00
0005433009041	14192	Economy	17400.00
0005433009031	14192	Economy	17400.00
0005433009056	14192	Economy	17400.00
0005433009040	14192	Economy	17400.00
0005433009032	14192	Economy	17400.00
0005433009072	14192	Economy	17400.00
0005433009064	14192	Economy	17400.00
0005433009049	14192	Economy	17400.00
0005433009061	14192	Economy	17400.00
0005433009047	14192	Economy	17400.00
0005433009039	14192	Economy	17400.00
0005433009030	14192	Economy	17400.00
0005433810534	14192	Economy	17400.00
0005433810529	14192	Economy	17400.00
0005433009036	14192	Economy	17400.00
0005433009057	14192	Economy	17400.00
0005433009067	14192	Economy	17400.00
0005433009052	14192	Economy	17400.00
0005433009029	14192	Economy	17400.00
0005433009070	14192	Economy	17400.00
0005433009062	14192	Economy	17400.00
0005433009060	14192	Economy	17400.00
0005433009038	14192	Economy	17400.00
0005433008589	22866	Business	52300.00
0005433008481	22866	Business	52300.00
0005433008666	22866	Business	52300.00
0005433008734	22866	Business	52300.00
0005433008775	22866	Business	52300.00
0005433008883	22866	Business	52300.00
0005433008538	22866	Business	52300.00
0005433008658	22866	Economy	17400.00
0005433008616	22866	Economy	17400.00
0005433008559	22866	Economy	17400.00
0005433008774	22866	Economy	19200.00
0005433008750	22866	Economy	19200.00
0005433008502	22866	Economy	19200.00
0005433008495	22866	Economy	17400.00
0005433008530	22866	Economy	17400.00
0005433008580	22866	Economy	17400.00
0005433008656	22866	Economy	17400.00
0005433008615	22866	Economy	17400.00
0005433008657	22866	Economy	17400.00
0005433008745	22866	Economy	17400.00
0005433008713	22866	Economy	17400.00
0005433008560	22866	Economy	17400.00
0005433008544	22866	Economy	17400.00
0005433008442	22866	Economy	17400.00
0005433008727	22866	Economy	17400.00
0005433008595	22866	Economy	17400.00
0005433008683	22866	Economy	17400.00
0005433008501	22866	Economy	17400.00
0005433008555	22866	Economy	17400.00
0005433008496	22866	Economy	17400.00
0005433008379	22866	Economy	17400.00
0005433008655	22866	Economy	17400.00
0005433008882	22866	Economy	17400.00
0005433008474	22866	Economy	17400.00
0005433008545	22866	Economy	17400.00
0005433008541	22866	Economy	17400.00
0005433008536	22866	Economy	17400.00
0005433008623	22866	Economy	17400.00
0005433008746	22866	Economy	17400.00
0005433008508	22866	Economy	17400.00
0005433008575	22866	Economy	17400.00
0005433008316	22866	Economy	17400.00
0005433008776	22866	Economy	17400.00
0005433008676	22866	Economy	17400.00
0005433008482	22866	Economy	17400.00
0005433008735	22866	Economy	17400.00
0005433008396	22866	Economy	17400.00
0005433008682	22866	Economy	17400.00
0005433008626	22866	Economy	17400.00
0005433008685	22866	Economy	17400.00
0005433008550	22866	Economy	17400.00
0005434925776	14925	Business	22900.00
0005434925762	14925	Business	22900.00
0005434925755	14925	Business	22900.00
0005434925809	14925	Economy	7600.00
0005434925768	14925	Economy	7600.00
0005434925769	14925	Economy	7600.00
0005434925791	14925	Economy	8400.00
0005434925824	14925	Economy	7600.00
0005434925798	14925	Economy	7600.00
0005434925782	14925	Economy	7600.00
0005434925799	14925	Economy	7600.00
0005434925825	14925	Economy	7600.00
0005434925784	14925	Economy	7600.00
0005434925821	14925	Economy	7600.00
0005434925822	14925	Economy	7600.00
0005434925754	14925	Economy	7600.00
0005434925765	14925	Economy	7600.00
0005434925752	14925	Economy	7600.00
0005434925810	14925	Economy	7600.00
0005434925759	14925	Economy	7600.00
0005434925764	14925	Economy	7600.00
0005434925763	14925	Economy	7600.00
0005434925823	14925	Economy	7600.00
0005434925790	14925	Economy	7600.00
0005434925783	14925	Economy	7600.00
0005434925753	14925	Economy	7600.00
0005434925751	14925	Economy	7600.00
0005434925760	14925	Economy	7600.00
0005434926078	20543	Business	22900.00
0005434926095	20543	Business	22900.00
0005434926066	20543	Business	22900.00
0005434926077	20543	Business	22900.00
0005434926064	20543	Economy	7600.00
0005434926060	20543	Economy	7600.00
0005434926065	20543	Economy	8400.00
0005434926076	20543	Economy	8400.00
0005434926097	20543	Economy	7600.00
0005434926083	20543	Economy	7600.00
0005434926073	20543	Economy	7600.00
0005434926074	20543	Economy	7600.00
0005434926070	20543	Economy	7600.00
0005434926075	20543	Economy	7600.00
0005434926061	20543	Economy	7600.00
0005434926088	20543	Economy	7600.00
0005434926069	20543	Economy	7600.00
0005434926090	20543	Economy	7600.00
0005434926062	20543	Economy	7600.00
0005434926063	20543	Economy	7600.00
0005434926081	20543	Economy	7600.00
0005434926084	20543	Economy	7600.00
0005434926079	20543	Economy	7600.00
0005434926068	20543	Economy	7600.00
0005434926087	20543	Economy	7600.00
0005434926072	20543	Economy	7600.00
0005434926086	20543	Economy	7600.00
0005434926091	20543	Economy	7600.00
0005434926089	20543	Economy	7600.00
0005434926082	20543	Economy	7600.00
0005434926092	20543	Economy	7600.00
0005434926094	20543	Economy	7600.00
0005434926080	20543	Economy	7600.00
0005434926067	20543	Economy	7600.00
0005434926093	20543	Economy	7600.00
0005434926071	20543	Economy	7600.00
0005434926096	20543	Economy	7600.00
0005434926085	20543	Economy	7600.00
0005435488039	15813	Economy	8900.00
0005435488049	15813	Economy	8900.00
0005435488032	15813	Economy	8900.00
0005435488043	15813	Economy	8100.00
0005435488033	15813	Economy	8100.00
0005435999193	15813	Economy	8100.00
0005435999217	15813	Economy	8100.00
0005435999258	15813	Economy	8100.00
0005435488045	15813	Economy	8100.00
0005435488044	15813	Economy	8100.00
0005435488050	15813	Economy	8100.00
0005435488038	15813	Economy	8100.00
0005435999213	15813	Economy	8100.00
0005435488047	15813	Economy	8100.00
0005435488036	15813	Economy	8100.00
0005435999226	15813	Economy	8100.00
0005435999261	15813	Economy	8100.00
0005435999235	15813	Economy	8100.00
0005435488037	15813	Economy	8100.00
0005435488051	15813	Economy	8100.00
0005435488046	15813	Economy	8100.00
0005435488041	15813	Economy	8100.00
0005435999240	15813	Economy	8100.00
0005435488040	15813	Economy	8100.00
0005435999246	15813	Economy	8100.00
0005435488042	15813	Economy	8100.00
0005435999241	15813	Economy	8100.00
0005435999215	15813	Economy	8100.00
0005435488034	15813	Economy	8100.00
0005435999257	15813	Economy	8100.00
0005435999260	15813	Economy	8100.00
0005435999214	15813	Economy	8100.00
0005435999259	15813	Economy	8100.00
0005435999253	15813	Economy	8100.00
0005435488035	15813	Economy	8100.00
0005435999176	15813	Economy	8100.00
0005435488048	15813	Economy	8100.00
0005435999216	15813	Economy	8100.00
0005435999197	15813	Economy	8100.00
0005435999397	19676	Economy	8900.00
0005435487706	19676	Economy	8900.00
0005435999385	19676	Economy	8900.00
0005435999398	19676	Economy	8100.00
0005435487873	19676	Economy	8100.00
0005435999389	19676	Economy	8100.00
0005435487764	19676	Economy	8100.00
0005435487847	19676	Economy	8100.00
0005435999403	19676	Economy	8100.00
0005435487786	19676	Economy	8100.00
0005435487893	19676	Economy	8100.00
0005435999399	19676	Economy	8100.00
0005435487783	19676	Economy	8100.00
0005435999391	19676	Economy	8100.00
0005435487850	19676	Economy	8100.00
0005435999402	19676	Economy	8100.00
0005435487888	19676	Economy	8100.00
0005435999393	19676	Economy	8100.00
0005435999388	19676	Economy	8100.00
0005435487852	19676	Economy	8100.00
0005435487766	19676	Economy	8100.00
0005435487782	19676	Economy	8100.00
0005435487781	19676	Economy	8100.00
0005435487789	19676	Economy	8100.00
0005435999396	19676	Economy	8100.00
0005435999390	19676	Economy	8100.00
0005435999394	19676	Economy	8100.00
0005435999401	19676	Economy	8100.00
0005435487750	19676	Economy	8100.00
0005435487849	19676	Economy	8100.00
0005435487892	19676	Economy	8100.00
0005435999404	19676	Economy	8100.00
0005435487748	19676	Economy	8100.00
0005435487864	19676	Economy	8100.00
0005435999386	19676	Economy	8100.00
0005435999400	19676	Economy	8100.00
0005435999395	19676	Economy	8100.00
0005435487825	19676	Economy	8100.00
0005435487765	19676	Economy	8100.00
0005435487790	19676	Economy	8100.00
0005435487826	19676	Economy	8100.00
0005435487851	19676	Economy	8100.00
0005435999392	19676	Economy	8100.00
0005435487824	19676	Economy	8100.00
0005435999387	19676	Economy	8100.00
0005432537061	6011	Business	199300.00
0005435839713	6011	Business	199300.00
0005435472854	6011	Business	199300.00
0005435472748	6011	Business	199300.00
0005435472781	6011	Business	199300.00
0005432142280	6011	Business	199300.00
0005435472756	6011	Business	199300.00
0005435839729	6011	Business	199300.00
0005432142282	6011	Economy	66400.00
0005435839720	6011	Economy	66400.00
0005435472811	6011	Economy	66400.00
0005435839711	6011	Economy	66400.00
0005435839708	6011	Economy	66400.00
0005435839731	6011	Economy	66400.00
0005435839723	6011	Economy	66400.00
0005435839722	6011	Economy	73100.00
0005435839732	6011	Economy	66400.00
0005435839715	6011	Economy	66400.00
0005432659727	6011	Economy	66400.00
0005435472871	6011	Economy	66400.00
0005435472875	6011	Economy	66400.00
0005435839717	6011	Economy	66400.00
0005435839730	6011	Economy	66400.00
0005435839724	6011	Economy	66400.00
0005432660839	6011	Economy	66400.00
0005435839714	6011	Economy	66400.00
0005432658612	6011	Economy	66400.00
0005435839712	6011	Economy	66400.00
0005435472757	6011	Economy	66400.00
0005435839728	6011	Economy	66400.00
0005435839718	6011	Economy	66400.00
0005435839734	6011	Economy	66400.00
0005435472877	6011	Economy	66400.00
0005435839707	6011	Economy	66400.00
0005435472760	6011	Economy	66400.00
0005435472806	6011	Economy	66400.00
0005432142281	6011	Economy	66400.00
0005435839721	6011	Economy	66400.00
0005435839733	6011	Economy	66400.00
0005435839727	6011	Economy	66400.00
0005435839725	6011	Economy	66400.00
0005435472831	6011	Economy	66400.00
0005435472876	6011	Economy	66400.00
0005435839719	6011	Economy	66400.00
0005435472812	6011	Economy	66400.00
0005432658613	6011	Economy	66400.00
0005435472758	6011	Economy	66400.00
0005435839709	6011	Economy	66400.00
0005435839726	6011	Economy	66400.00
0005435472761	6011	Economy	66400.00
0005435839706	6011	Economy	66400.00
0005432659726	6011	Economy	66400.00
0005435472724	6011	Economy	66400.00
0005435839716	6011	Economy	66400.00
0005435472833	6011	Economy	66400.00
0005435472725	6011	Economy	66400.00
0005435839710	6011	Economy	66400.00
0005435472958	18084	Business	199300.00
0005435472962	18084	Business	199300.00
0005432537079	18084	Business	199300.00
0005432664136	18084	Business	199300.00
0005435839421	18084	Business	199300.00
0005435839284	18084	Economy	66400.00
0005435839392	18084	Economy	66400.00
0005435472957	18084	Economy	66400.00
0005435472953	18084	Economy	66400.00
0005435472955	18084	Economy	66400.00
0005435839474	18084	Economy	66400.00
0005435839496	18084	Economy	73100.00
0005435839369	18084	Economy	73100.00
0005435839420	18084	Economy	73100.00
0005435839324	18084	Economy	66400.00
0005432537080	18084	Economy	66400.00
0005432664141	18084	Economy	66400.00
0005435839504	18084	Economy	66400.00
0005435472961	18084	Economy	66400.00
0005435472952	18084	Economy	66400.00
0005435472964	18084	Economy	66400.00
0005435472963	18084	Economy	66400.00
0005435472966	18084	Economy	66400.00
0005435839495	18084	Economy	66400.00
0005435839325	18084	Economy	66400.00
0005435839452	18084	Economy	66400.00
0005435839581	18084	Economy	66400.00
0005435472967	18084	Economy	66400.00
0005432660820	18084	Economy	66400.00
0005435839579	18084	Economy	66400.00
0005435839408	18084	Economy	66400.00
0005435472956	18084	Economy	66400.00
0005435839285	18084	Economy	66400.00
0005432664142	18084	Economy	66400.00
0005432664114	18084	Economy	66400.00
0005435839453	18084	Economy	66400.00
0005435472959	18084	Economy	66400.00
0005435839530	18084	Economy	66400.00
0005435839538	18084	Economy	66400.00
0005432664137	18084	Economy	66400.00
0005435472954	18084	Economy	66400.00
0005435472965	18084	Economy	66400.00
0005435472960	18084	Economy	66400.00
0005432667456	18084	Economy	66400.00
0005433285244	23034	Business	15700.00
0005433285374	23034	Business	15700.00
0005433285310	23034	Business	15700.00
0005433285386	23034	Economy	5200.00
0005433285344	23034	Economy	5200.00
0005433285459	23034	Economy	5200.00
0005435103987	23034	Economy	5200.00
0005435103990	23034	Economy	5200.00
0005433285375	23034	Economy	5200.00
0005435103992	23034	Economy	5200.00
0005433285189	23034	Economy	5200.00
0005433285223	23034	Economy	5200.00
0005433285413	23034	Economy	5200.00
0005433285318	23034	Economy	5200.00
0005435103988	23034	Economy	5200.00
0005433285457	23034	Economy	5200.00
0005433285309	23034	Economy	5200.00
0005433285373	23034	Economy	5700.00
0005433285311	23034	Economy	5200.00
0005435103991	23034	Economy	5200.00
0005433285301	23034	Economy	5200.00
0005433285456	23034	Economy	5200.00
0005433285342	23034	Economy	5200.00
0005433285477	23034	Economy	5200.00
0005433285336	23034	Economy	5200.00
0005433285514	23034	Economy	5200.00
0005433285236	23034	Economy	5200.00
0005435103993	23034	Economy	5200.00
0005435103989	23034	Economy	5200.00
0005433285300	23034	Economy	5200.00
0005433285337	23034	Economy	5200.00
0005433285405	23034	Economy	5200.00
0005433285603	32068	Business	15700.00
0005433285611	32068	Business	15700.00
0005433285590	32068	Business	15700.00
0005433285596	32068	Economy	5200.00
0005433285599	32068	Economy	5200.00
0005435103923	32068	Economy	5200.00
0005433285587	32068	Economy	5200.00
0005433285586	32068	Economy	5200.00
0005433285605	32068	Economy	5200.00
0005433285591	32068	Economy	5200.00
0005433285588	32068	Economy	5200.00
0005435103925	32068	Economy	5200.00
0005433285609	32068	Economy	5200.00
0005433285606	32068	Economy	5200.00
0005433285613	32068	Economy	5700.00
0005433285601	32068	Economy	5700.00
0005433285584	32068	Economy	5200.00
0005433285592	32068	Economy	5200.00
0005435103928	32068	Economy	5200.00
0005435103914	32068	Economy	5200.00
0005433285595	32068	Economy	5200.00
0005433285607	32068	Economy	5200.00
0005433285612	32068	Economy	5200.00
0005433285597	32068	Economy	5200.00
0005433285594	32068	Economy	5200.00
0005433285608	32068	Economy	5200.00
0005433285602	32068	Economy	5200.00
0005435103908	32068	Economy	5200.00
0005433285585	32068	Economy	5200.00
0005433285600	32068	Economy	5200.00
0005435103919	32068	Economy	5200.00
0005433285610	32068	Economy	5200.00
0005433285598	32068	Economy	5200.00
0005433285582	32068	Economy	5200.00
0005433285604	32068	Economy	5200.00
0005433285589	32068	Economy	5200.00
0005433285583	32068	Economy	5200.00
0005433285593	32068	Economy	5200.00
0005435103913	32068	Economy	5200.00
0005435103909	32068	Economy	5200.00
0005433475712	23874	Economy	12300.00
0005433475707	23874	Economy	12300.00
0005435852603	23874	Economy	12300.00
0005433475706	23874	Economy	12300.00
0005433475688	23874	Economy	12300.00
0005433475717	23874	Economy	12300.00
0005433475720	23874	Economy	12300.00
0005433475687	23874	Economy	12300.00
0005435852602	23874	Economy	12300.00
0005433475705	23874	Economy	12300.00
0005435852601	23874	Economy	12300.00
0005433475718	23874	Economy	12300.00
0005435852600	23874	Economy	12300.00
0005432528200	30576	Business	42100.00
0005432527978	30576	Business	42100.00
0005435214233	30576	Business	42100.00
0005434067612	30576	Business	42100.00
0005435725651	30576	Business	42100.00
0005434067523	30576	Business	42100.00
0005434067645	30576	Business	42100.00
0005434067388	30576	Business	42100.00
0005435214218	30576	Business	42100.00
0005432528355	30576	Business	42100.00
0005432535843	30576	Business	42100.00
0005435214239	30576	Business	42100.00
0005432527958	30576	Business	42100.00
0005432533293	30576	Business	42100.00
0005432535844	30576	Business	42100.00
0005432528194	30576	Business	42100.00
0005435214205	30576	Business	42100.00
0005432428926	30576	Business	42100.00
0005435214203	30576	Comfort	23900.00
0005432535839	30576	Comfort	23900.00
0005435630997	30576	Comfort	23900.00
0005435214243	30576	Comfort	23900.00
0005435214226	30576	Comfort	23900.00
0005432533298	30576	Comfort	23900.00
0005432528225	30576	Comfort	23900.00
0005432528179	30576	Comfort	23900.00
0005432528284	30576	Comfort	23900.00
0005432528183	30576	Comfort	23900.00
0005432535840	30576	Comfort	23900.00
0005434067266	30576	Comfort	23900.00
0005432528203	30576	Comfort	23900.00
0005435214269	30576	Comfort	23900.00
0005432528520	30576	Comfort	23900.00
0005432528087	30576	Comfort	23900.00
0005432528625	30576	Comfort	23900.00
0005435214249	30576	Comfort	23900.00
0005432527720	30576	Comfort	23900.00
0005432527370	30576	Comfort	23900.00
0005432527972	30576	Comfort	23900.00
0005432533296	30576	Comfort	23900.00
0005434067679	30576	Comfort	23900.00
0005435214227	30576	Comfort	23900.00
0005434067629	30576	Comfort	23900.00
0005433656705	30576	Comfort	23900.00
0005432211575	30576	Comfort	23900.00
0005432527857	30576	Comfort	23900.00
0005432211580	30576	Comfort	23900.00
0005432528036	30576	Comfort	23900.00
0005434067553	30576	Comfort	23900.00
0005434067540	30576	Comfort	23900.00
0005432211576	30576	Comfort	23900.00
0005434067602	30576	Comfort	23900.00
0005434067592	30576	Comfort	23900.00
0005432159905	30576	Comfort	23900.00
0005432527868	30576	Comfort	23900.00
0005432527823	30576	Comfort	23900.00
0005434067591	30576	Economy	14000.00
0005435214240	30576	Economy	14000.00
0005432527988	30576	Economy	14000.00
0005432527751	30576	Economy	14000.00
0005432527991	30576	Economy	14000.00
0005434067428	30576	Economy	14000.00
0005432528121	30576	Economy	14000.00
0005434067750	30576	Economy	14000.00
0005434067693	30576	Economy	14000.00
0005432528025	30576	Economy	14000.00
0005435214210	30576	Economy	14000.00
0005434067692	30576	Economy	14000.00
0005435214236	30576	Economy	14000.00
0005432528192	30576	Economy	14000.00
0005432528246	30576	Economy	14000.00
0005435214228	30576	Economy	14000.00
0005435214260	30576	Economy	14000.00
0005432528384	30576	Economy	14000.00
0005432528324	30576	Economy	14000.00
0005433656704	30576	Economy	14000.00
0005432527911	30576	Economy	14000.00
0005435214225	30576	Economy	14000.00
0005432528949	30576	Economy	14000.00
0005432527967	30576	Economy	14000.00
0005434067670	30576	Economy	14000.00
0005432528348	30576	Economy	14000.00
0005435214258	30576	Economy	14000.00
0005435214206	30576	Economy	14000.00
0005432527858	30576	Economy	14000.00
0005434067764	30576	Economy	14000.00
0005432528120	30576	Economy	14000.00
0005432527979	30576	Economy	14000.00
0005432528030	30576	Economy	14000.00
0005432211578	30576	Economy	14000.00
0005432528162	30576	Economy	14000.00
0005435214235	30576	Economy	14000.00
0005432528522	30576	Economy	14000.00
0005435214250	30576	Economy	14000.00
0005434067401	30576	Economy	14000.00
0005435214223	30576	Economy	14000.00
0005435214256	30576	Economy	14000.00
0005432528578	30576	Economy	14000.00
0005434067980	30576	Economy	14000.00
0005432535856	30576	Economy	14000.00
0005433656706	30576	Economy	14000.00
0005434067694	30576	Economy	14000.00
0005434067851	30576	Economy	14000.00
0005435214216	30576	Economy	14000.00
0005432528201	30576	Economy	14000.00
0005434067531	30576	Economy	14000.00
0005434067475	30576	Economy	14000.00
0005435214204	30576	Economy	14000.00
0005434067289	30576	Economy	15400.00
0005434067616	30576	Economy	14000.00
0005435214241	30576	Economy	15400.00
0005435214211	30576	Economy	15400.00
0005434067601	30576	Economy	14000.00
0005432527730	30576	Economy	14000.00
0005432528122	30576	Economy	14000.00
0005432528311	30576	Economy	15400.00
0005432528825	30576	Economy	15400.00
0005432159904	30576	Economy	14000.00
0005432527905	30576	Economy	15400.00
0005434067522	30576	Economy	14000.00
0005432528289	30576	Economy	14000.00
0005432528237	30576	Economy	14000.00
0005435214207	30576	Economy	14000.00
0005432528182	30576	Economy	14000.00
0005432528577	30576	Economy	14000.00
0005434067762	30576	Economy	14000.00
0005432535857	30576	Economy	14000.00
0005432528521	30576	Economy	14000.00
0005435214245	30576	Economy	14000.00
0005435214263	30576	Economy	14000.00
0005432528055	30576	Economy	14000.00
0005435214237	30576	Economy	14000.00
0005434067753	30576	Economy	14000.00
0005435214230	30576	Economy	14000.00
0005435214231	30576	Economy	14000.00
0005434067742	30576	Economy	14000.00
0005435725654	30576	Economy	14000.00
0005435214220	30576	Economy	14000.00
0005435214222	30576	Economy	14000.00
0005432528024	30576	Economy	14000.00
0005432528184	30576	Economy	14000.00
0005434067723	30576	Economy	14000.00
0005435214255	30576	Economy	14000.00
0005435214247	30576	Economy	14000.00
0005435725652	30576	Economy	14000.00
0005432528325	30576	Economy	14000.00
0005434067353	30576	Economy	14000.00
0005434067644	30576	Economy	14000.00
0005435214201	30576	Economy	14000.00
0005432527912	30576	Economy	14000.00
0005432528252	30576	Economy	14000.00
0005432159906	30576	Economy	14000.00
0005435214264	30576	Economy	14000.00
0005432159903	30576	Economy	14000.00
0005432211574	30576	Economy	14000.00
0005432211579	30576	Economy	14000.00
0005435214254	30576	Economy	14000.00
0005432527936	30576	Economy	14000.00
0005434067741	30576	Economy	14000.00
0005432528180	30576	Economy	14000.00
0005434067751	30576	Economy	14000.00
0005432528218	30576	Economy	14000.00
0005432527975	30576	Economy	14000.00
0005435214248	30576	Economy	14000.00
0005432527870	30576	Economy	14000.00
0005434067169	30576	Economy	14000.00
0005434067699	30576	Economy	14000.00
0005434067343	30576	Economy	14000.00
0005432528066	30576	Economy	14000.00
0005435214217	30576	Economy	14000.00
0005432527992	30576	Economy	14000.00
0005432528199	30576	Economy	14000.00
0005434067720	30576	Economy	14000.00
0005432528547	30576	Economy	14000.00
0005434067763	30576	Economy	14000.00
0005434067409	30576	Economy	14000.00
0005432528341	30576	Economy	14000.00
0005435214267	30576	Economy	14000.00
0005435214257	30576	Economy	14000.00
0005434067752	30576	Economy	14000.00
0005432528207	30576	Economy	14000.00
0005432528032	30576	Economy	14000.00
0005432528376	30576	Economy	14000.00
0005432159902	30576	Economy	14000.00
0005434067520	30576	Economy	14000.00
0005435630998	30576	Economy	14000.00
0005435214244	30576	Economy	14000.00
0005434067389	30576	Economy	14000.00
0005434067785	30576	Economy	14000.00
0005432527966	30576	Economy	14000.00
0005434067518	30576	Economy	14000.00
0005432528375	30576	Economy	14000.00
0005432528394	30576	Economy	14000.00
0005432528386	30576	Economy	14000.00
0005432528014	30576	Economy	14000.00
0005435214246	30576	Economy	14000.00
0005434067736	30576	Economy	14000.00
0005434067656	30576	Economy	14000.00
0005432528063	30576	Economy	14000.00
0005435214262	30576	Economy	14000.00
0005432528528	30576	Economy	14000.00
0005432528219	30576	Economy	14000.00
0005435214209	30576	Economy	14000.00
0005434067856	30576	Economy	14000.00
0005432528240	30576	Economy	14000.00
0005432527729	30576	Economy	14000.00
0005434067425	30576	Economy	15400.00
0005435214266	30576	Economy	15400.00
0005432527879	30576	Economy	15400.00
0005435214214	30576	Economy	14000.00
0005435214232	30576	Economy	14000.00
0005432528362	30576	Economy	14000.00
0005434067481	30576	Economy	14000.00
0005435214208	30576	Economy	14000.00
0005434067458	30576	Economy	14000.00
0005432533291	30576	Economy	14000.00
0005435214265	30576	Economy	14000.00
0005432528067	30576	Economy	14000.00
0005432527968	30576	Economy	14000.00
0005434067615	30576	Economy	14000.00
0005432528070	30576	Economy	14000.00
0005435725653	30576	Economy	14000.00
0005435214234	30576	Economy	14000.00
0005432528285	30576	Economy	14000.00
0005434067519	30576	Economy	14000.00
0005435630999	30576	Economy	14000.00
0005434067688	30576	Economy	14000.00
0005435214253	30576	Economy	14000.00
0005435214261	30576	Economy	14000.00
0005435214259	30576	Economy	14000.00
0005432528361	30576	Economy	14000.00
0005434067567	30576	Economy	14000.00
0005432527728	30576	Economy	14000.00
0005435214202	30576	Economy	14000.00
0005435214213	30576	Economy	14000.00
0005435214219	30576	Economy	14000.00
0005432528385	30576	Economy	14000.00
0005432535855	30576	Economy	14000.00
0005432527957	30576	Economy	14000.00
0005432528414	30576	Economy	14000.00
0005434067446	30576	Economy	14000.00
0005432528208	30576	Economy	14000.00
0005432528146	30576	Economy	14000.00
0005432533292	30576	Economy	14000.00
0005432528354	30576	Economy	14000.00
0005432528291	30576	Economy	14000.00
0005434067857	30576	Economy	14000.00
0005435214238	30576	Economy	14000.00
0005434067671	30576	Economy	14000.00
0005432533295	30576	Economy	14000.00
0005432528417	30576	Economy	14000.00
0005432527880	30576	Economy	14000.00
0005432527886	30576	Economy	14000.00
0005432527885	30576	Economy	14000.00
0005432528163	30576	Economy	14000.00
0005434067400	30576	Economy	14000.00
0005432528185	30576	Economy	14000.00
0005432533294	30576	Economy	14000.00
0005432535845	30576	Economy	14000.00
0005432527887	30576	Economy	14000.00
0005435214212	30576	Economy	14000.00
0005435214242	30576	Economy	14000.00
0005435214224	30576	Economy	14000.00
0005434067482	30576	Economy	14000.00
0005435214215	30576	Economy	14000.00
0005432211577	30576	Economy	14000.00
0005432528193	30576	Economy	14000.00
0005432528554	30576	Economy	14000.00
0005432528395	30576	Economy	14000.00
0005435214268	30576	Economy	14000.00
0005432528065	30576	Economy	14000.00
0005435214252	30576	Economy	14000.00
0005434067410	30576	Economy	14000.00
0005435214229	30576	Economy	14000.00
0005435214221	30576	Economy	14000.00
0005432527956	30576	Economy	14000.00
0005432528290	30576	Economy	14000.00
0005434067617	30576	Economy	14000.00
0005435725650	30576	Economy	14000.00
0005432528239	30576	Economy	14000.00
0005434067426	30576	Economy	14000.00
0005432528031	30576	Economy	14000.00
0005435214251	30576	Economy	14000.00
0005434067429	30576	Economy	14000.00
0005432527696	30576	Economy	14000.00
0005434067457	30576	Economy	14000.00
0005432528443	30576	Economy	14000.00
0005435652888	24823	Business	9800.00
0005435653076	24823	Business	9800.00
0005433368292	24823	Business	9800.00
0005433368267	24823	Business	9800.00
0005433368293	24823	Business	9800.00
0005433368289	24823	Business	9800.00
0005435653118	24823	Business	9800.00
0005435652997	24823	Business	9800.00
0005433368274	24823	Business	9800.00
0005433368279	24823	Business	9800.00
0005433368280	24823	Economy	3300.00
0005435652936	24823	Economy	3300.00
0005435652935	24823	Economy	3300.00
0005435652956	24823	Economy	3300.00
0005435653063	24823	Economy	3300.00
0005435652886	24823	Economy	3300.00
0005435653164	24823	Economy	3300.00
0005433368270	24823	Economy	3300.00
0005435653021	24823	Economy	3600.00
0005435653077	24823	Economy	3600.00
0005435653097	24823	Economy	3600.00
0005435653156	24823	Economy	3600.00
0005435653019	24823	Economy	3600.00
0005435653000	24823	Economy	3300.00
0005433368286	24823	Economy	3300.00
0005435653109	24823	Economy	3300.00
0005433368290	24823	Economy	3300.00
0005433368282	24823	Economy	3300.00
0005433368287	24823	Economy	3300.00
0005433368261	24823	Economy	3300.00
0005435653075	24823	Economy	3300.00
0005435652998	24823	Economy	3300.00
0005433368258	24823	Economy	3300.00
0005435653099	24823	Economy	3300.00
0005433368262	24823	Economy	3300.00
0005435652947	24823	Economy	3300.00
0005435652996	24823	Economy	3300.00
0005435653117	24823	Economy	3300.00
0005433368276	24823	Economy	3300.00
0005435653090	24823	Economy	3300.00
0005435653110	24823	Economy	3300.00
0005433368256	24823	Economy	3300.00
0005433368284	24823	Economy	3300.00
0005435653071	24823	Economy	3300.00
0005433368275	24823	Economy	3300.00
0005433368277	24823	Economy	3300.00
0005435653073	24823	Economy	3300.00
0005435653085	24823	Economy	3300.00
0005435653020	24823	Economy	3300.00
0005435653105	24823	Economy	3300.00
0005435653101	24823	Economy	3300.00
0005433368278	24823	Economy	3300.00
0005435653018	24823	Economy	3300.00
0005435652994	24823	Economy	3300.00
0005433368255	24823	Economy	3300.00
0005435653141	24823	Economy	3300.00
0005435653044	24823	Economy	3300.00
0005433368272	24823	Economy	3300.00
0005435653072	24823	Economy	3300.00
0005435653104	24823	Economy	3300.00
0005435653064	24823	Economy	3300.00
0005433368263	24823	Economy	3300.00
0005433368283	24823	Economy	3300.00
0005433368266	24823	Economy	3300.00
0005435652999	24823	Economy	3300.00
0005433368257	24823	Economy	3300.00
0005435653080	24823	Economy	3300.00
0005435653010	24823	Economy	3300.00
0005433368285	24823	Economy	3300.00
0005433368281	24823	Economy	3300.00
0005435653089	24823	Economy	3300.00
0005433368264	24823	Economy	3300.00
0005433368273	24823	Economy	3300.00
0005435652965	24823	Economy	3300.00
0005435653098	24823	Economy	3300.00
0005435653162	24823	Economy	3300.00
0005433368265	24823	Economy	3300.00
0005433368291	24823	Economy	3300.00
0005435653011	24823	Economy	3300.00
0005433368271	24823	Economy	3300.00
0005435652887	24823	Economy	3300.00
0005435652957	24823	Economy	3300.00
0005433368260	24823	Economy	3300.00
0005433368288	24823	Economy	3300.00
0005433368259	24823	Economy	3300.00
0005435653008	24823	Economy	3300.00
0005433368268	24823	Economy	3300.00
0005433368269	24823	Economy	3300.00
0005435949807	6593	Economy	18700.00
0005435949809	6593	Economy	18700.00
0005435949812	6593	Economy	18700.00
0005435949808	6593	Economy	18700.00
0005435949806	6593	Economy	18700.00
0005435949810	6593	Economy	18700.00
0005435949805	6593	Economy	18700.00
0005435949811	6593	Economy	18700.00
0005434980093	2020	Economy	10500.00
0005434980089	2020	Economy	10500.00
0005434980110	2020	Economy	9500.00
0005434980094	2020	Economy	9500.00
0005434980099	2020	Economy	9500.00
0005434980086	2020	Economy	9500.00
0005434980112	2020	Economy	9500.00
0005434980083	2020	Economy	9500.00
0005434980109	2020	Economy	9500.00
0005434980108	2020	Economy	9500.00
0005434980095	2020	Economy	9500.00
0005434980102	2020	Economy	9500.00
0005434980085	2020	Economy	9500.00
0005434980113	2020	Economy	9500.00
0005434980101	2020	Economy	9500.00
0005434980098	2020	Economy	9500.00
0005434980100	2020	Economy	9500.00
0005434980106	2020	Economy	9500.00
0005434980097	2020	Economy	9500.00
0005434980084	2020	Economy	9500.00
0005434980091	2020	Economy	9500.00
0005435801728	2020	Economy	9500.00
0005435801727	2020	Economy	9500.00
0005434980088	2020	Economy	9500.00
0005434980105	2020	Economy	9500.00
0005434980103	2020	Economy	9500.00
0005434980087	2020	Economy	9500.00
0005434980096	2020	Economy	9500.00
0005434980090	2020	Economy	9500.00
0005434980104	2020	Economy	9500.00
0005434980111	2020	Economy	9500.00
0005434980107	2020	Economy	9500.00
0005434980092	2020	Economy	9500.00
0005434979713	23559	Economy	10500.00
0005435801705	23559	Economy	10500.00
0005435801704	23559	Economy	9500.00
0005434979779	23559	Economy	9500.00
0005434979750	23559	Economy	9500.00
0005435801691	23559	Economy	9500.00
0005434979817	23559	Economy	9500.00
0005434979882	23559	Economy	9500.00
0005434979753	23559	Economy	9500.00
0005434979768	23559	Economy	9500.00
0005434979787	23559	Economy	9500.00
0005434979742	23559	Economy	9500.00
0005434979885	23559	Economy	9500.00
0005434979786	23559	Economy	9500.00
0005434979736	23559	Economy	9500.00
0005434979861	23559	Economy	9500.00
0005434979886	23559	Economy	9500.00
0005434979767	23559	Economy	9500.00
0005434979855	23559	Economy	9500.00
0005434979766	23559	Economy	9500.00
0005434979743	23559	Economy	9500.00
0005435801703	23559	Economy	9500.00
0005434979820	23559	Economy	9500.00
0005434979712	23559	Economy	9500.00
0005434979846	23559	Economy	9500.00
0005434952570	2585	Economy	5300.00
0005434952571	2585	Economy	5300.00
0005434952568	2585	Economy	5300.00
0005434952572	2585	Economy	5300.00
0005434952569	2585	Economy	5300.00
0005433256427	2562	Economy	5300.00
0005433256444	28201	Economy	5300.00
0005433256446	28201	Economy	5300.00
0005433256447	28201	Economy	5300.00
0005433256445	28201	Economy	5300.00
0005434302859	19799	Economy	8700.00
0005433111529	19799	Economy	8700.00
0005434302860	19799	Economy	8700.00
0005434302861	19799	Economy	8700.00
0005433111528	19799	Economy	8700.00
0005434138267	11926	Business	9700.00
0005434138266	11926	Business	9700.00
0005434138186	11926	Business	9700.00
0005434138148	11926	Business	9700.00
0005434138444	11926	Business	9700.00
0005434138416	11926	Business	9700.00
0005434138308	11926	Business	9700.00
0005434138540	11926	Business	9700.00
0005434138268	11926	Business	9700.00
0005434138588	11926	Business	9700.00
0005434138414	11926	Business	9700.00
0005434138711	11926	Economy	3200.00
0005434138488	11926	Economy	3200.00
0005434138277	11926	Economy	3200.00
0005434138468	11926	Economy	3200.00
0005434138159	11926	Economy	3200.00
0005434138102	11926	Economy	3200.00
0005434138253	11926	Economy	3200.00
0005434138469	11926	Economy	3500.00
0005434138699	11926	Economy	3500.00
0005434138198	11926	Economy	3500.00
0005434138317	11926	Economy	3500.00
0005434138074	11926	Economy	3200.00
0005434138304	11926	Economy	3200.00
0005434138638	11926	Economy	3200.00
0005434138455	11926	Economy	3200.00
0005434138278	11926	Economy	3200.00
0005434137872	11926	Economy	3200.00
0005434138442	11926	Economy	3200.00
0005434138693	11926	Economy	3200.00
0005434138394	11926	Economy	3200.00
0005434138445	11926	Economy	3200.00
0005434138431	11926	Economy	3200.00
0005434137970	11926	Economy	3200.00
0005434138149	11926	Economy	3200.00
0005434138351	11926	Economy	3200.00
0005434138316	11926	Economy	3200.00
0005434138114	11926	Economy	3200.00
0005434138281	11926	Economy	3200.00
0005434138227	11926	Economy	3200.00
0005434138119	11926	Economy	3200.00
0005434137895	11926	Economy	3200.00
0005434138429	11926	Economy	3200.00
0005434138509	11926	Economy	3200.00
0005434137966	11926	Economy	3200.00
0005434138352	11926	Economy	3200.00
0005434138318	11926	Economy	3200.00
0005434138710	11926	Economy	3200.00
0005434138167	11926	Economy	3200.00
0005434138371	11926	Economy	3200.00
0005434138273	11926	Economy	3200.00
0005434138080	11926	Economy	3200.00
0005434138494	11926	Economy	3200.00
0005434138557	11926	Economy	3200.00
0005434138694	11926	Economy	3200.00
0005434138284	11926	Economy	3200.00
0005434138252	11926	Economy	3200.00
0005434137926	11926	Economy	3200.00
0005434138428	11926	Economy	3200.00
0005434138435	11926	Economy	3200.00
0005434138160	11926	Economy	3200.00
0005434138541	11926	Economy	3200.00
0005434138392	11926	Economy	3200.00
0005434138589	11926	Economy	3200.00
0005434138342	11926	Economy	3200.00
0005434138430	11926	Economy	3200.00
0005434138168	11926	Economy	3200.00
0005434138282	11926	Economy	3200.00
0005434138269	11926	Economy	3200.00
0005434137978	11926	Economy	3200.00
0005434138283	11926	Economy	3200.00
0005434138539	11926	Economy	3200.00
0005434138558	11926	Economy	3200.00
0005434137898	11926	Economy	3200.00
0005434138458	11926	Economy	3200.00
0005434138383	11926	Economy	3200.00
0005434138350	11926	Economy	3200.00
0005434138272	11926	Economy	3200.00
0005434138542	11926	Economy	3200.00
0005434138064	11926	Economy	3200.00
0005434138370	11926	Economy	3200.00
0005434138493	11926	Economy	3200.00
0005434138933	28752	Business	9700.00
0005434138897	28752	Business	9700.00
0005434138941	28752	Business	9700.00
0005434138929	28752	Business	9700.00
0005434138922	28752	Business	9700.00
0005434138918	28752	Business	9700.00
0005434138943	28752	Business	9700.00
0005434138912	28752	Business	9700.00
0005434138968	28752	Business	9700.00
0005434138976	28752	Business	9700.00
0005434138936	28752	Business	9700.00
0005434138906	28752	Economy	3200.00
0005434138942	28752	Economy	3200.00
0005434138928	28752	Economy	3200.00
0005434138907	28752	Economy	3200.00
0005434138954	28752	Economy	3200.00
0005434138909	28752	Economy	3200.00
0005434138972	28752	Economy	3200.00
0005434138938	28752	Economy	3200.00
0005434138913	28752	Economy	3200.00
0005434138904	28752	Economy	3200.00
0005434138903	28752	Economy	3500.00
0005434138962	28752	Economy	3500.00
0005434138930	28752	Economy	3500.00
0005434138900	28752	Economy	3500.00
0005434138896	28752	Economy	3200.00
0005434138969	28752	Economy	3200.00
0005434138963	28752	Economy	3200.00
0005434138894	28752	Economy	3200.00
0005434138950	28752	Economy	3200.00
0005434138923	28752	Economy	3200.00
0005434138966	28752	Economy	3200.00
0005434138898	28752	Economy	3200.00
0005434138965	28752	Economy	3200.00
0005434138915	28752	Economy	3200.00
0005434138924	28752	Economy	3200.00
0005434138940	28752	Economy	3200.00
0005434138925	28752	Economy	3200.00
0005434138926	28752	Economy	3200.00
0005434138908	28752	Economy	3200.00
0005434138973	28752	Economy	3200.00
0005434138974	28752	Economy	3200.00
0005434138899	28752	Economy	3200.00
0005434138953	28752	Economy	3200.00
0005434138952	28752	Economy	3200.00
0005434138975	28752	Economy	3200.00
0005434138945	28752	Economy	3200.00
0005434138905	28752	Economy	3200.00
0005434138917	28752	Economy	3200.00
0005434138911	28752	Economy	3200.00
0005434138958	28752	Economy	3200.00
0005434138960	28752	Economy	3200.00
0005434138939	28752	Economy	3200.00
0005434138959	28752	Economy	3200.00
0005434138949	28752	Economy	3200.00
0005434138978	28752	Economy	3200.00
0005434138931	28752	Economy	3200.00
0005434138927	28752	Economy	3200.00
0005434138957	28752	Economy	3200.00
0005434138944	28752	Economy	3200.00
0005434138947	28752	Economy	3200.00
0005434138919	28752	Economy	3200.00
0005434138935	28752	Economy	3200.00
0005434138971	28752	Economy	3200.00
0005434138955	28752	Economy	3200.00
0005434138956	28752	Economy	3200.00
0005434138920	28752	Economy	3200.00
0005434138934	28752	Economy	3200.00
0005434138902	28752	Economy	3200.00
0005434138977	28752	Economy	3200.00
0005434138937	28752	Economy	3200.00
0005434138910	28752	Economy	3200.00
0005434138964	28752	Economy	3200.00
0005434138967	28752	Economy	3200.00
0005434138895	28752	Economy	3200.00
0005434138901	28752	Economy	3200.00
0005434138951	28752	Economy	3200.00
0005434138946	28752	Economy	3200.00
0005434138961	28752	Economy	3200.00
0005434138916	28752	Economy	3200.00
0005434138948	28752	Economy	3200.00
0005434138921	28752	Economy	3200.00
0005434138914	28752	Economy	3200.00
0005434138970	28752	Economy	3200.00
0005434138932	28752	Economy	3200.00
0005434466512	6568	Economy	23000.00
0005435312812	6568	Economy	20900.00
0005434466513	6568	Economy	20900.00
0005434466514	6568	Economy	20900.00
0005434466507	6568	Economy	20900.00
0005435312813	6568	Economy	20900.00
0005434466506	6568	Economy	20900.00
0005434466505	6568	Economy	20900.00
0005434466510	6568	Economy	20900.00
0005434466509	6568	Economy	20900.00
0005434466511	6568	Economy	20900.00
0005435312799	6568	Economy	20900.00
0005434466508	6568	Economy	20900.00
0005433534521	6816	Economy	10900.00
0005433538956	6816	Economy	9900.00
0005433538955	6816	Economy	9900.00
0005433538957	6816	Economy	9900.00
0005433538960	6816	Economy	9900.00
0005433534520	6816	Economy	9900.00
0005433538958	6816	Economy	9900.00
0005433534519	6816	Economy	9900.00
0005433538962	6816	Economy	9900.00
0005435259742	6816	Economy	9900.00
0005435259767	6816	Economy	9900.00
0005433538959	6816	Economy	9900.00
0005433538961	6816	Economy	9900.00
0005433538882	24998	Economy	9900.00
0005433538876	24998	Economy	9900.00
0005433538875	24998	Economy	9900.00
0005433538909	24998	Economy	9900.00
0005433538915	24998	Economy	9900.00
0005433538867	24998	Economy	9900.00
0005433538883	24998	Economy	9900.00
0005433538927	24998	Economy	9900.00
0005433538868	24998	Economy	9900.00
0005433538865	24998	Economy	9900.00
0005435259802	24998	Economy	9900.00
0005433538881	24998	Economy	9900.00
0005433534503	24998	Economy	9900.00
0005433538864	24998	Economy	9900.00
0005433538890	24998	Economy	9900.00
0005435259800	24998	Economy	9900.00
0005433534501	24998	Economy	9900.00
0005433538914	24998	Economy	9900.00
0005435259801	24998	Economy	9900.00
0005435259803	24998	Economy	9900.00
0005433538908	24998	Economy	9900.00
0005433512035	850	Economy	16100.00
0005433512041	850	Economy	16100.00
0005433512037	850	Economy	14600.00
0005433512039	850	Economy	14600.00
0005433512034	850	Economy	14600.00
0005433512042	850	Economy	14600.00
0005432922543	850	Economy	14600.00
0005433512036	850	Economy	14600.00
0005432922539	850	Economy	14600.00
0005432922515	850	Economy	14600.00
0005433512038	850	Economy	14600.00
0005432922534	850	Economy	14600.00
0005433512040	850	Economy	14600.00
0005432922568	16144	Economy	16100.00
0005433511971	16144	Economy	14600.00
0005433512003	16144	Economy	14600.00
0005432922565	16144	Economy	14600.00
0005432922566	16144	Economy	14600.00
0005433511966	16144	Economy	14600.00
0005433511989	16144	Economy	14600.00
0005433511944	16144	Economy	14600.00
0005433511990	16144	Economy	14600.00
0005433511965	16144	Economy	14600.00
0005433511964	16144	Economy	14600.00
0005432922567	16144	Economy	14600.00
0005433511975	16144	Economy	14600.00
0005434950574	3690	Economy	7900.00
0005434950577	3690	Economy	7900.00
0005435697619	3690	Economy	7900.00
0005435697623	3690	Economy	7900.00
0005435935061	3690	Economy	7200.00
0005434950576	3690	Economy	7200.00
0005435697639	3690	Economy	7200.00
0005435697638	3690	Economy	7200.00
0005435697620	3690	Economy	7200.00
0005435697628	3690	Economy	7200.00
0005435697626	3690	Economy	7200.00
0005435697632	3690	Economy	7200.00
0005435697633	3690	Economy	7200.00
0005435697618	3690	Economy	7200.00
0005435697625	3690	Economy	7200.00
0005434950575	3690	Economy	7200.00
0005435697629	3690	Economy	7200.00
0005435697622	3690	Economy	7200.00
0005435697627	3690	Economy	7200.00
0005435916174	3690	Economy	7200.00
0005435697631	3690	Economy	7200.00
0005435697640	3690	Economy	7200.00
0005435916173	3690	Economy	7200.00
0005435935058	3690	Economy	7200.00
0005435697645	3690	Economy	7200.00
0005435697634	3690	Economy	7200.00
0005435697637	3690	Economy	7200.00
0005435697630	3690	Economy	7200.00
0005435697635	3690	Economy	7200.00
0005435697644	3690	Economy	7200.00
0005435697621	3690	Economy	7200.00
0005435697641	3690	Economy	7200.00
0005435697624	3690	Economy	7200.00
0005435697646	3690	Economy	7200.00
0005435697643	3690	Economy	7200.00
0005435697636	3690	Economy	7200.00
0005435697642	3690	Economy	7200.00
0005435697255	16302	Economy	7900.00
0005435697389	16302	Economy	7900.00
0005435935076	16302	Economy	7900.00
0005435697493	16302	Economy	7200.00
0005435697343	16302	Economy	7200.00
0005435697348	16302	Economy	7200.00
0005435697371	16302	Economy	7200.00
0005435697374	16302	Economy	7200.00
0005434950559	16302	Economy	7200.00
0005435916196	16302	Economy	7200.00
0005435697422	16302	Economy	7200.00
0005435697403	16302	Economy	7200.00
0005435697373	16302	Economy	7200.00
0005435697388	16302	Economy	7200.00
0005435697421	16302	Economy	7200.00
0005435935073	16302	Economy	7200.00
0005435697397	16302	Economy	7200.00
0005435697429	16302	Economy	7200.00
0005435697428	16302	Economy	7200.00
0005435697376	16302	Economy	7200.00
0005435935075	16302	Economy	7200.00
0005435697345	16302	Economy	7200.00
0005435697344	16302	Economy	7200.00
0005435697391	16302	Economy	7200.00
0005435697370	16302	Economy	7200.00
0005434950549	16302	Economy	7200.00
0005434950537	16302	Economy	7200.00
0005435935074	16302	Economy	7200.00
0005435697346	16302	Economy	7200.00
0005435697353	16302	Economy	7200.00
0005435697420	16302	Economy	7200.00
0005433519507	3984	Economy	21300.00
0005432609772	3984	Economy	19300.00
0005433519505	3984	Economy	19300.00
0005434604934	3984	Economy	19300.00
0005434604932	3984	Economy	19300.00
0005432607610	3984	Economy	19300.00
0005432609775	3984	Economy	19300.00
0005432607609	3984	Economy	19300.00
0005434606866	3984	Economy	19300.00
0005433519504	3984	Economy	19300.00
0005432609773	3984	Economy	19300.00
0005433519506	3984	Economy	19300.00
0005433519503	3984	Economy	19300.00
0005434604931	3984	Economy	19300.00
0005433519508	3984	Economy	19300.00
0005432609774	3984	Economy	19300.00
0005435842328	3984	Economy	19300.00
0005434604933	3984	Economy	19300.00
0005434604930	3984	Economy	19300.00
0005435904895	3984	Economy	19300.00
0005432607611	3984	Economy	19300.00
0005432607608	3984	Economy	19300.00
0005435853630	22057	Economy	19300.00
0005434606820	22057	Economy	19300.00
0005434606828	22057	Economy	19300.00
0005434606832	22057	Economy	19300.00
0005434606819	22057	Economy	19300.00
0005435853631	22057	Economy	19300.00
0005435853629	22057	Economy	19300.00
0005433519447	22057	Economy	19300.00
0005433519448	22057	Economy	19300.00
0005434606835	22057	Economy	19300.00
0005433348988	702	Economy	3700.00
0005435628759	702	Economy	3700.00
0005435628761	702	Economy	3700.00
0005433349020	702	Economy	3700.00
0005433348987	702	Economy	3700.00
0005433349019	702	Economy	3700.00
0005435628760	702	Economy	3700.00
0005433349049	15932	Economy	3700.00
0005433349051	15932	Economy	3700.00
0005435628724	15932	Economy	3700.00
0005433349047	15932	Economy	3700.00
0005433349050	15932	Economy	3700.00
0005433349052	15932	Economy	3700.00
0005433349048	15932	Economy	3700.00
0005435628747	15932	Economy	3700.00
0005434445264	17145	Economy	7100.00
0005433159305	17145	Economy	7100.00
0005433159324	17145	Economy	7100.00
0005434445265	17145	Economy	7100.00
0005433158123	17145	Economy	7100.00
0005434445263	17145	Economy	7100.00
0005433159327	17145	Economy	7100.00
0005433159326	17145	Economy	7100.00
0005434445262	17145	Economy	7100.00
0005433158135	17145	Economy	7100.00
0005434446537	17145	Economy	7100.00
0005434445240	17666	Economy	7100.00
0005434445258	17666	Economy	7100.00
0005434445251	17666	Economy	7100.00
0005433159337	17666	Economy	7100.00
0005435132996	7879	Economy	5400.00
0005435383153	7879	Economy	5400.00
0005435132988	7879	Economy	5400.00
0005435132995	7879	Economy	5400.00
0005435132990	7879	Economy	5400.00
0005435383147	7879	Economy	5400.00
0005435132992	7879	Economy	5400.00
0005435383146	7879	Economy	5400.00
0005435132997	7879	Economy	5400.00
0005435383159	7879	Economy	5400.00
0005435132991	7879	Economy	5400.00
0005435132989	7879	Economy	5400.00
0005435132994	7879	Economy	5400.00
0005435132993	7879	Economy	5400.00
0005435132987	7879	Economy	5400.00
0005435132883	33095	Economy	5900.00
0005435132907	33095	Economy	5900.00
0005435383204	33095	Economy	5400.00
0005435383208	33095	Economy	5400.00
0005435383205	33095	Economy	5400.00
0005435132884	33095	Economy	5400.00
0005435132919	33095	Economy	5400.00
0005435383206	33095	Economy	5400.00
0005435383207	33095	Economy	5400.00
0005435132880	33095	Economy	5400.00
0005435132917	33095	Economy	5400.00
0005435132918	33095	Economy	5400.00
0005435811128	4400	Business	133200.00
0005435938896	4400	Economy	44400.00
0005435938895	4400	Economy	44400.00
0005435811125	4400	Economy	44400.00
0005435811121	4400	Economy	44400.00
0005435811130	4400	Economy	44400.00
0005435811126	4400	Economy	44400.00
0005435811127	4400	Economy	44400.00
0005435938889	4400	Economy	44400.00
0005435811123	4400	Economy	44400.00
0005435811122	4400	Economy	44400.00
0005435938887	4400	Economy	44400.00
0005435811129	4400	Economy	44400.00
0005435938865	4400	Economy	44400.00
0005435938888	4400	Economy	44400.00
0005435938866	4400	Economy	44400.00
0005435811124	4400	Economy	44400.00
0005435811104	29443	Business	133200.00
0005435811067	29443	Business	133200.00
0005435938912	29443	Business	133200.00
0005435811073	29443	Business	133200.00
0005435938911	29443	Economy	44400.00
0005435811065	29443	Economy	48800.00
0005435811076	29443	Economy	44400.00
0005435811072	29443	Economy	44400.00
0005435938913	29443	Economy	44400.00
0005435938915	29443	Economy	44400.00
0005435811090	29443	Economy	44400.00
0005435938914	29443	Economy	44400.00
0005435811105	29443	Economy	44400.00
0005435811064	29443	Economy	44400.00
0005435811075	29443	Economy	44400.00
0005435811054	29443	Economy	44400.00
0005435390266	7525	Economy	12500.00
0005435160414	7525	Economy	12500.00
0005435390249	7525	Economy	12500.00
0005435390267	7525	Economy	12500.00
0005435390265	7525	Economy	12500.00
0005435390253	7525	Economy	12500.00
0005435160416	7525	Economy	12500.00
0005435160419	7525	Economy	12500.00
0005435160420	7525	Economy	12500.00
0005435160418	7525	Economy	12500.00
0005435390254	7525	Economy	12500.00
0005435390248	7525	Economy	12500.00
0005435160417	7525	Economy	12500.00
0005435160422	7525	Economy	12500.00
0005435160421	7525	Economy	12500.00
0005435160415	7525	Economy	12500.00
0005435390264	7525	Economy	12500.00
0005435160413	7525	Economy	12500.00
0005435160423	7525	Economy	12500.00
0005435390314	29530	Economy	13800.00
0005435390315	29530	Economy	12500.00
0005435160341	29530	Economy	12500.00
0005435390311	29530	Economy	12500.00
0005435390313	29530	Economy	12500.00
0005435160375	29530	Economy	12500.00
0005435160317	29530	Economy	12500.00
0005435160360	29530	Economy	12500.00
0005435160372	29530	Economy	12500.00
0005435160340	29530	Economy	12500.00
0005435390310	29530	Economy	12500.00
0005435390312	29530	Economy	12500.00
0005435160320	29530	Economy	12500.00
0005435160371	29530	Economy	12500.00
0005435160342	29530	Economy	12500.00
0005435178513	18469	Economy	4900.00
0005435178510	18469	Economy	4900.00
0005432398210	18469	Economy	4900.00
0005435178511	18469	Economy	4900.00
0005432398199	18469	Economy	4900.00
0005432398205	18469	Economy	4900.00
0005432394093	18469	Economy	4900.00
0005432398204	18469	Economy	4900.00
0005435178512	18469	Economy	4900.00
0005432394122	18469	Economy	4900.00
0005432394123	18469	Economy	4900.00
0005432394092	18469	Economy	4900.00
0005432398234	27145	Economy	4900.00
0005432398235	27145	Economy	4900.00
0005432400159	27145	Economy	4900.00
0005432398233	27145	Economy	4900.00
0005432400160	27145	Economy	4900.00
0005432400161	27145	Economy	4900.00
0005432400162	27145	Economy	4900.00
0005432398231	27145	Economy	4900.00
0005432400163	27145	Economy	4900.00
0005432400164	27145	Economy	4900.00
0005432398232	27145	Economy	4900.00
0005432639251	2252	Business	87300.00
0005432639256	2252	Business	87300.00
0005432639250	2252	Business	87300.00
0005432866027	2252	Business	87300.00
0005432639253	2252	Business	87300.00
0005432639271	2252	Business	87300.00
0005432866030	2252	Business	87300.00
0005432639269	2252	Business	87300.00
0005432866036	2252	Business	87300.00
0005432866033	2252	Economy	29100.00
0005432866022	2252	Economy	29100.00
0005432865994	2252	Economy	29100.00
0005432639265	2252	Economy	29100.00
0005432639254	2252	Economy	29100.00
0005432639262	2252	Economy	32000.00
0005432639261	2252	Economy	29100.00
0005432866016	2252	Economy	29100.00
0005432639257	2252	Economy	29100.00
0005432866015	2252	Economy	29100.00
0005432639259	2252	Economy	29100.00
0005432639245	2252	Economy	29100.00
0005432865996	2252	Economy	29100.00
0005432639249	2252	Economy	29100.00
0005432639260	2252	Economy	29100.00
0005432639258	2252	Economy	29100.00
0005432866040	2252	Economy	29100.00
0005432866010	2252	Economy	29100.00
0005432866031	2252	Economy	29100.00
0005432639267	2252	Economy	29100.00
0005432639263	2252	Economy	29100.00
0005432866041	2252	Economy	29100.00
0005432639264	2252	Economy	29100.00
0005432866011	2252	Economy	29100.00
0005432865995	2252	Economy	29100.00
0005432639248	2252	Economy	29100.00
0005432866053	2252	Economy	29100.00
0005432639268	2252	Economy	29100.00
0005432866017	2252	Economy	29100.00
0005432639246	2252	Economy	29100.00
0005432639252	2252	Economy	29100.00
0005432639255	2252	Economy	29100.00
0005432639266	2252	Economy	29100.00
0005432639270	2252	Economy	29100.00
0005432866018	2252	Economy	29100.00
0005432639247	2252	Economy	29100.00
0005432866032	2252	Economy	29100.00
0005433811647	24297	Economy	35100.00
0005433811645	24297	Economy	35100.00
0005433811656	24297	Economy	35100.00
0005433811655	24297	Economy	35100.00
0005433811649	24297	Economy	38600.00
0005433811646	24297	Economy	35100.00
0005433811652	24297	Economy	35100.00
0005433811654	24297	Economy	35100.00
0005433811648	24297	Economy	35100.00
0005433811653	24297	Economy	35100.00
0005433811651	24297	Economy	35100.00
0005433811650	24297	Economy	35100.00
0005434191276	9741	Economy	4400.00
0005434191286	32767	Economy	4400.00
0005434191289	32767	Economy	4400.00
0005434191287	32767	Economy	4400.00
0005434191295	32767	Economy	4400.00
0005434191294	32767	Economy	4400.00
0005434191296	32767	Economy	4400.00
0005434191293	32767	Economy	4400.00
0005434191285	32767	Economy	4400.00
0005434191291	32767	Economy	4400.00
0005434191288	32767	Economy	4400.00
0005434191290	32767	Economy	4400.00
0005434191292	32767	Economy	4400.00
0005432658579	26494	Business	92200.00
0005432665278	26494	Business	92200.00
0005432658589	26494	Business	92200.00
0005432658584	26494	Business	92200.00
0005432658601	26494	Business	92200.00
0005432665272	26494	Economy	30700.00
0005432658587	26494	Economy	30700.00
0005432665264	26494	Economy	30700.00
0005432658572	26494	Economy	33800.00
0005432661900	26494	Economy	30700.00
0005432661922	26494	Economy	30700.00
0005432658578	26494	Economy	30700.00
0005432665270	26494	Economy	30700.00
0005432665263	26494	Economy	30700.00
0005432665262	26494	Economy	30700.00
0005432661911	26494	Economy	30700.00
0005432661914	26494	Economy	30700.00
0005432665274	26494	Economy	30700.00
0005432658583	26494	Economy	30700.00
0005432658585	26494	Economy	30700.00
0005432658582	26494	Economy	30700.00
0005432665261	26494	Economy	30700.00
0005432658591	26494	Economy	30700.00
0005432665275	26494	Economy	30700.00
0005432661923	26494	Economy	30700.00
0005432665279	26494	Economy	30700.00
0005432665271	26494	Economy	30700.00
0005432661919	26494	Economy	30700.00
0005432661924	26494	Economy	30700.00
0005432658590	26494	Economy	30700.00
0005432661918	26494	Economy	30700.00
0005432658592	26494	Economy	30700.00
0005432658586	26494	Economy	30700.00
0005432665269	26494	Economy	30700.00
0005432661915	26494	Economy	30700.00
0005432658600	26494	Economy	30700.00
0005432658588	26494	Economy	30700.00
0005432665273	26494	Economy	30700.00
0005434504575	6508	Business	48400.00
0005434504556	6508	Business	48400.00
0005434504581	6508	Business	48400.00
0005434504572	6508	Economy	16100.00
0005434504573	6508	Economy	16100.00
0005434504548	6508	Economy	17800.00
0005434504562	6508	Economy	17800.00
0005435104013	6508	Economy	16100.00
0005434504563	6508	Economy	16100.00
0005434504568	6508	Economy	16100.00
0005435104011	6508	Economy	16100.00
0005434504549	6508	Economy	16100.00
0005434504569	6508	Economy	16100.00
0005434504560	6508	Economy	16100.00
0005435104012	6508	Economy	16100.00
0005434504578	6508	Economy	16100.00
0005434504567	6508	Economy	16100.00
0005434504553	6508	Economy	16100.00
0005434504555	6508	Economy	16100.00
0005435104010	6508	Economy	16100.00
0005434504576	6508	Economy	16100.00
0005434504554	6508	Economy	16100.00
0005434504558	6508	Economy	16100.00
0005434504574	6508	Economy	16100.00
0005434504550	6508	Economy	16100.00
0005434504579	6508	Economy	16100.00
0005434504566	6508	Economy	16100.00
0005434504565	6508	Economy	16100.00
0005434504552	6508	Economy	16100.00
0005434504580	6508	Economy	16100.00
0005434504557	6508	Economy	16100.00
0005434504547	6508	Economy	16100.00
0005434504577	6508	Economy	16100.00
0005434504546	6508	Economy	16100.00
0005434504551	6508	Economy	16100.00
0005434504561	6508	Economy	16100.00
0005434504559	6508	Economy	16100.00
0005434504571	6508	Economy	16100.00
0005434504564	6508	Economy	16100.00
0005434504570	6508	Economy	16100.00
0005434504144	22664	Business	48400.00
0005434503989	22664	Business	48400.00
0005434504184	22664	Business	48400.00
0005434504045	22664	Business	48400.00
0005434504154	22664	Business	48400.00
0005434504125	22664	Business	48400.00
0005434504170	22664	Business	48400.00
0005434504015	22664	Business	48400.00
0005434504160	22664	Economy	16100.00
0005435103908	22664	Economy	16100.00
0005435103919	22664	Economy	16100.00
0005434504180	22664	Economy	16100.00
0005434503993	22664	Economy	16100.00
0005434504218	22664	Economy	17800.00
0005435103928	22664	Economy	17800.00
0005434504171	22664	Economy	16100.00
0005434504075	22664	Economy	16100.00
0005434504106	22664	Economy	16100.00
0005434504150	22664	Economy	16100.00
0005435103925	22664	Economy	16100.00
0005434504179	22664	Economy	16100.00
0005434504162	22664	Economy	16100.00
0005434504069	22664	Economy	16100.00
0005434504063	22664	Economy	16100.00
0005434504220	22664	Economy	16100.00
0005434504087	22664	Economy	16100.00
0005434504151	22664	Economy	16100.00
0005434504023	22664	Economy	16100.00
0005434504173	22664	Economy	16100.00
0005434504105	22664	Economy	16100.00
0005434504104	22664	Economy	16100.00
0005434504123	22664	Economy	16100.00
0005434504183	22664	Economy	16100.00
0005434504153	22664	Economy	16100.00
0005435103923	22664	Economy	16100.00
0005435103909	22664	Economy	16100.00
0005434504190	22664	Economy	16100.00
0005434504145	22664	Economy	16100.00
0005434504083	22664	Economy	16100.00
0005434504178	22664	Economy	16100.00
0005434504161	22664	Economy	16100.00
0005434503994	22664	Economy	16100.00
0005434504208	22664	Economy	16100.00
0005434504115	22664	Economy	16100.00
0005435103913	22664	Economy	16100.00
0005434504047	22664	Economy	16100.00
0005434504223	22664	Economy	16100.00
0005434504064	22664	Economy	16100.00
0005434504082	22664	Economy	16100.00
0005434504207	22664	Economy	16100.00
0005434504116	22664	Economy	16100.00
0005434504124	22664	Economy	16100.00
0005434504152	22664	Economy	16100.00
0005435103914	22664	Economy	16100.00
0005434504048	22664	Economy	16100.00
0005434504014	22664	Economy	16100.00
0005434504216	22664	Economy	16100.00
0005434504086	22664	Economy	16100.00
0005435653500	1678	Business	50000.00
0005435653515	1678	Business	50000.00
0005435653539	1678	Business	50000.00
0005435653554	1678	Business	50000.00
0005433367940	1678	Business	50000.00
0005433367913	1678	Business	50000.00
0005433368095	1678	Business	50000.00
0005435653545	1678	Business	50000.00
0005433367949	1678	Business	50000.00
0005435653520	1678	Business	50000.00
0005435653524	1678	Business	50000.00
0005433367938	1678	Business	50000.00
0005433367833	1678	Economy	16700.00
0005435653546	1678	Economy	16700.00
0005433367947	1678	Economy	16700.00
0005435653529	1678	Economy	16700.00
0005433367836	1678	Economy	16700.00
0005433367951	1678	Economy	16700.00
0005435653542	1678	Economy	16700.00
0005435653533	1678	Economy	16700.00
0005435653502	1678	Economy	16700.00
0005435653519	1678	Economy	16700.00
0005433368010	1678	Economy	18300.00
0005435653525	1678	Economy	18300.00
0005433367950	1678	Economy	18300.00
0005435653498	1678	Economy	18300.00
0005433368157	1678	Economy	18300.00
0005433367764	1678	Economy	16700.00
0005435653507	1678	Economy	16700.00
0005433368011	1678	Economy	16700.00
0005435653527	1678	Economy	16700.00
0005433367920	1678	Economy	16700.00
0005435653509	1678	Economy	16700.00
0005433367985	1678	Economy	16700.00
0005433367984	1678	Economy	16700.00
0005435653532	1678	Economy	16700.00
0005435653511	1678	Economy	16700.00
0005435653513	1678	Economy	16700.00
0005433368216	1678	Economy	16700.00
0005435653544	1678	Economy	16700.00
0005433367725	1678	Economy	16700.00
0005435653517	1678	Economy	16700.00
0005435653503	1678	Economy	16700.00
0005435653505	1678	Economy	16700.00
0005435653548	1678	Economy	16700.00
0005435653508	1678	Economy	16700.00
0005435653516	1678	Economy	16700.00
0005433368007	1678	Economy	16700.00
0005435653501	1678	Economy	16700.00
0005435653535	1678	Economy	16700.00
0005435653526	1678	Economy	16700.00
0005435653528	1678	Economy	16700.00
0005435653530	1678	Economy	16700.00
0005435653536	1678	Economy	16700.00
0005435653506	1678	Economy	16700.00
0005435653499	1678	Economy	16700.00
0005435653550	1678	Economy	16700.00
0005435653547	1678	Economy	16700.00
0005435653521	1678	Economy	16700.00
0005435653543	1678	Economy	16700.00
0005435653510	1678	Economy	16700.00
0005435653504	1678	Economy	16700.00
0005435653556	1678	Economy	16700.00
0005433368036	1678	Economy	16700.00
0005435653551	1678	Economy	16700.00
0005433367840	1678	Economy	16700.00
0005433368068	1678	Economy	16700.00
0005433368081	1678	Economy	16700.00
0005433367945	1678	Economy	16700.00
0005435653553	1678	Economy	16700.00
0005435653518	1678	Economy	16700.00
0005433367986	1678	Economy	16700.00
0005433368077	1678	Economy	16700.00
0005433368094	1678	Economy	16700.00
0005435653531	1678	Economy	16700.00
0005435653523	1678	Economy	16700.00
0005433368128	1678	Economy	16700.00
0005435653540	1678	Economy	16700.00
0005435653541	1678	Economy	16700.00
0005433368057	1678	Economy	16700.00
0005435653514	1678	Economy	16700.00
0005435653555	1678	Economy	16700.00
0005433368115	1678	Economy	16700.00
0005433368012	1678	Economy	16700.00
0005435653538	1678	Economy	16700.00
0005435653552	1678	Economy	16700.00
0005435653549	1678	Economy	16700.00
0005435653512	1678	Economy	16700.00
0005433367921	1678	Economy	16700.00
0005435653537	1678	Economy	16700.00
0005433367894	1678	Economy	16700.00
0005435653534	1678	Economy	16700.00
0005433368158	1678	Economy	16700.00
0005435653522	1678	Economy	16700.00
0005435653497	1678	Economy	16700.00
0005433368275	21715	Business	50000.00
0005435653044	21715	Business	50000.00
0005435653090	21715	Business	50000.00
0005433368283	21715	Business	50000.00
0005435652999	21715	Business	50000.00
0005435653156	21715	Business	50000.00
0005433368292	21715	Business	50000.00
0005435653011	21715	Business	50000.00
0005433368265	21715	Business	50000.00
0005435652996	21715	Economy	16700.00
0005435652947	21715	Economy	16700.00
0005433368285	21715	Economy	16700.00
0005433368273	21715	Economy	16700.00
0005433368269	21715	Economy	16700.00
0005435652997	21715	Economy	16700.00
0005433368264	21715	Economy	16700.00
0005433368266	21715	Economy	16700.00
0005433368290	21715	Economy	16700.00
0005435652956	21715	Economy	16700.00
0005435652994	21715	Economy	18300.00
0005433368282	21715	Economy	18300.00
0005433368287	21715	Economy	18300.00
0005435653008	21715	Economy	18300.00
0005435652936	21715	Economy	18300.00
0005435653019	21715	Economy	16700.00
0005433368270	21715	Economy	16700.00
0005435652887	21715	Economy	16700.00
0005433368291	21715	Economy	16700.00
0005435652935	21715	Economy	16700.00
0005433368267	21715	Economy	16700.00
0005433368284	21715	Economy	16700.00
0005433368257	21715	Economy	16700.00
0005435652965	21715	Economy	16700.00
0005433368259	21715	Economy	16700.00
0005435653071	21715	Economy	16700.00
0005435653104	21715	Economy	16700.00
0005433368293	21715	Economy	16700.00
0005435653085	21715	Economy	16700.00
0005435653117	21715	Economy	16700.00
0005433368281	21715	Economy	16700.00
0005435653109	21715	Economy	16700.00
0005433368263	21715	Economy	16700.00
0005435652886	21715	Economy	16700.00
0005433368258	21715	Economy	16700.00
0005435653105	21715	Economy	16700.00
0005433368268	21715	Economy	16700.00
0005435653072	21715	Economy	16700.00
0005435652998	21715	Economy	16700.00
0005435653141	21715	Economy	16700.00
0005435653076	21715	Economy	16700.00
0005435653080	21715	Economy	16700.00
0005435653064	21715	Economy	16700.00
0005435653077	21715	Economy	16700.00
0005435653098	21715	Economy	16700.00
0005435653118	21715	Economy	16700.00
0005435653110	21715	Economy	16700.00
0005433368278	21715	Economy	16700.00
0005435653099	21715	Economy	16700.00
0005433368271	21715	Economy	16700.00
0005435653010	21715	Economy	16700.00
0005433368272	21715	Economy	16700.00
0005435653101	21715	Economy	16700.00
0005435652957	21715	Economy	16700.00
0005433368277	21715	Economy	16700.00
0005435653164	21715	Economy	16700.00
0005435653063	21715	Economy	16700.00
0005433368274	21715	Economy	16700.00
0005435653073	21715	Economy	16700.00
0005435653018	21715	Economy	16700.00
0005433368262	21715	Economy	16700.00
0005435653020	21715	Economy	16700.00
0005435653162	21715	Economy	16700.00
0005435652888	21715	Economy	16700.00
0005433368288	21715	Economy	16700.00
0005433368286	21715	Economy	16700.00
0005433368255	21715	Economy	16700.00
0005433368276	21715	Economy	16700.00
0005435653089	21715	Economy	16700.00
0005433368261	21715	Economy	16700.00
0005433368280	21715	Economy	16700.00
0005433368289	21715	Economy	16700.00
0005435653097	21715	Economy	16700.00
0005433368256	21715	Economy	16700.00
0005435653021	21715	Economy	16700.00
0005433368260	21715	Economy	16700.00
0005435653000	21715	Economy	16700.00
0005435653075	21715	Economy	16700.00
0005433368279	21715	Economy	16700.00
0005434466458	23237	Economy	20900.00
0005434466476	23237	Economy	20900.00
0005435312831	23237	Economy	20900.00
0005434466466	23237	Economy	20900.00
0005435312828	23237	Economy	20900.00
0005435312833	23237	Economy	20900.00
0005435312832	23237	Economy	20900.00
0005434466459	23237	Economy	20900.00
0005434466467	23237	Economy	20900.00
0005434466460	23237	Economy	20900.00
0005435312829	23237	Economy	20900.00
0005434466484	23237	Economy	20900.00
0005434466437	23237	Economy	20900.00
0005434466468	23237	Economy	20900.00
0005434466498	23237	Economy	20900.00
0005434466469	23237	Economy	20900.00
0005435312830	23237	Economy	20900.00
0005433986454	4151	Business	21500.00
0005433986435	4151	Business	21500.00
0005433986408	4151	Business	21500.00
0005433986434	4151	Business	21500.00
0005433986452	4151	Business	21500.00
0005433986436	4151	Business	21500.00
0005433986410	4151	Economy	7200.00
0005433986457	4151	Economy	7200.00
0005433986430	4151	Economy	7200.00
0005433986423	4151	Economy	7200.00
0005433986427	4151	Economy	7200.00
0005433986422	4151	Economy	7200.00
0005433986419	4151	Economy	7200.00
0005433986429	4151	Economy	7200.00
0005433986453	4151	Economy	7900.00
0005433986409	4151	Economy	7900.00
0005433986446	4151	Economy	7900.00
0005433986448	4151	Economy	7200.00
0005433986416	4151	Economy	7200.00
0005433986431	4151	Economy	7200.00
0005433986441	4151	Economy	7200.00
0005433986440	4151	Economy	7200.00
0005433986420	4151	Economy	7200.00
0005433986451	4151	Economy	7200.00
0005433986450	4151	Economy	7200.00
0005433986449	4151	Economy	7200.00
0005433986413	4151	Economy	7200.00
0005433986445	4151	Economy	7200.00
0005433986414	4151	Economy	7200.00
0005433986433	4151	Economy	7200.00
0005433986439	4151	Economy	7200.00
0005433986412	4151	Economy	7200.00
0005433986421	4151	Economy	7200.00
0005433986415	4151	Economy	7200.00
0005433986411	4151	Economy	7200.00
0005433986425	4151	Economy	7200.00
0005433986407	4151	Economy	7200.00
0005435788798	4151	Economy	7200.00
0005433986426	4151	Economy	7200.00
0005433986417	4151	Economy	7200.00
0005433986432	4151	Economy	7200.00
0005433986438	4151	Economy	7200.00
0005433986406	4151	Economy	7200.00
0005433986442	4151	Economy	7200.00
0005433986428	4151	Economy	7200.00
0005433986458	4151	Economy	7200.00
0005435788797	4151	Economy	7200.00
0005433986456	4151	Economy	7200.00
0005433986418	4151	Economy	7200.00
0005433986424	4151	Economy	7200.00
0005433986444	4151	Economy	7200.00
0005433986437	4151	Economy	7200.00
0005433986443	4151	Economy	7200.00
0005433986447	4151	Economy	7200.00
0005433986455	4151	Economy	7200.00
0005435788771	25670	Business	21500.00
0005433985995	25670	Business	21500.00
0005433985988	25670	Business	21500.00
0005433985946	25670	Business	21500.00
0005433986060	25670	Business	21500.00
0005435788773	25670	Business	21500.00
0005433985774	25670	Business	21500.00
0005433985918	25670	Economy	7200.00
0005433985831	25670	Economy	7200.00
0005433986047	25670	Economy	7200.00
0005433986004	25670	Economy	7200.00
0005433985891	25670	Economy	7200.00
0005433986059	25670	Economy	7200.00
0005433986092	25670	Economy	7200.00
0005433985968	25670	Economy	7900.00
0005433986033	25670	Economy	7900.00
0005433985954	25670	Economy	7200.00
0005433986052	25670	Economy	7200.00
0005433986048	25670	Economy	7200.00
0005433986024	25670	Economy	7200.00
0005433986078	25670	Economy	7200.00
0005433985901	25670	Economy	7200.00
0005433985993	25670	Economy	7200.00
0005433986076	25670	Economy	7200.00
0005433985775	25670	Economy	7200.00
0005433986063	25670	Economy	7200.00
0005433985843	25670	Economy	7200.00
0005433986079	25670	Economy	7200.00
0005433985962	25670	Economy	7200.00
0005433986119	25670	Economy	7200.00
0005433985766	25670	Economy	7200.00
0005433986023	25670	Economy	7200.00
0005433986014	25670	Economy	7200.00
0005433986044	25670	Economy	7200.00
0005433985749	25670	Economy	7200.00
0005433985868	25670	Economy	7200.00
0005433985976	25670	Economy	7200.00
0005435788774	25670	Economy	7200.00
0005433985902	25670	Economy	7200.00
0005433985887	25670	Economy	7200.00
0005433986031	25670	Economy	7200.00
0005433985859	25670	Economy	7200.00
0005433985847	25670	Economy	7200.00
0005433986037	25670	Economy	7200.00
0005433985951	25670	Economy	7200.00
0005433985977	25670	Economy	7200.00
0005433985950	25670	Economy	7200.00
0005433986007	25670	Economy	7200.00
0005435788770	25670	Economy	7200.00
0005433985869	25670	Economy	7200.00
0005433985945	25670	Economy	7200.00
0005433986067	25670	Economy	7200.00
0005433986012	25670	Economy	7200.00
0005433985973	25670	Economy	7200.00
0005435788772	25670	Economy	7200.00
0005433986006	25670	Economy	7200.00
0005433986009	25670	Economy	7200.00
0005433986118	25670	Economy	7200.00
0005433986013	25670	Economy	7200.00
0005433985758	25670	Economy	7200.00
0005433985992	25670	Economy	7200.00
0005433986008	25670	Economy	7200.00
0005433986005	25670	Economy	7200.00
0005434509229	1613	Economy	17000.00
0005433168363	1613	Economy	17000.00
0005434509233	1613	Economy	17000.00
0005434509222	1613	Economy	15500.00
0005433168374	1613	Economy	15500.00
0005434509225	1613	Economy	15500.00
0005433168373	1613	Economy	15500.00
0005434509221	1613	Economy	15500.00
0005433168367	1613	Economy	15500.00
0005433168356	1613	Economy	15500.00
0005433168375	1613	Economy	15500.00
0005434509219	1613	Economy	15500.00
0005434509224	1613	Economy	15500.00
0005433168376	1613	Economy	15500.00
0005434509226	1613	Economy	15500.00
0005433168378	1613	Economy	15500.00
0005434509220	1613	Economy	15500.00
0005434509231	1613	Economy	15500.00
0005433168360	1613	Economy	15500.00
0005434509228	1613	Economy	15500.00
0005433168377	1613	Economy	15500.00
0005433168357	1613	Economy	15500.00
0005433168364	1613	Economy	15500.00
0005434509218	1613	Economy	15500.00
0005433168361	1613	Economy	15500.00
0005434509230	1613	Economy	15500.00
0005433168358	1613	Economy	15500.00
0005434509232	1613	Economy	15500.00
0005434509234	1613	Economy	15500.00
0005434509223	1613	Economy	15500.00
0005433168362	1613	Economy	15500.00
0005433168372	1613	Economy	15500.00
0005433168369	1613	Economy	15500.00
0005433168368	1613	Economy	15500.00
0005434509227	1613	Economy	15500.00
0005434190400	9027	Economy	26000.00
0005434516100	9027	Economy	23600.00
0005434190401	9027	Economy	23600.00
0005434516097	9027	Economy	23600.00
0005434190403	9027	Economy	23600.00
0005434190402	9027	Economy	23600.00
0005434516098	9027	Economy	23600.00
0005434516099	9027	Economy	23600.00
0005434516101	9027	Economy	23600.00
0005434516102	9027	Economy	23600.00
0005434190405	9027	Economy	23600.00
0005432661917	17833	Business	18000.00
0005432658606	17833	Business	18000.00
0005432869600	17833	Business	18000.00
0005432655559	17833	Business	18000.00
0005432655556	17833	Economy	6000.00
0005432655537	17833	Economy	6000.00
0005432658607	17833	Economy	6000.00
0005432655535	17833	Economy	6000.00
0005432666395	17833	Economy	6000.00
0005434151736	17833	Economy	6000.00
0005432655570	17833	Economy	6000.00
0005432659709	17833	Economy	6600.00
0005432665276	17833	Economy	6000.00
0005432658608	17833	Economy	6000.00
0005432663038	17833	Economy	6000.00
0005432657460	17833	Economy	6000.00
0005432655558	17833	Economy	6000.00
0005432659710	17833	Economy	6000.00
0005432655536	17833	Economy	6000.00
0005432657461	17833	Economy	6000.00
0005432655526	17833	Economy	6000.00
0005432655523	17833	Economy	6000.00
0005432655534	17833	Economy	6000.00
0005432869597	17833	Economy	6000.00
0005432655557	17833	Economy	6000.00
0005432661916	17833	Economy	6000.00
0005432660819	17833	Economy	6000.00
0005434151735	17833	Economy	6000.00
0005432869598	17833	Economy	6000.00
0005432661913	17833	Economy	6000.00
0005432663037	17833	Economy	6000.00
0005432869599	17833	Economy	6000.00
0005432869594	17833	Economy	6000.00
0005432665268	17833	Economy	6000.00
0005432655538	17833	Economy	6000.00
0005432869596	17833	Economy	6000.00
0005432869595	17833	Economy	6000.00
0005432659715	17833	Economy	6000.00
0005434151737	17833	Economy	6000.00
0005432657456	17833	Economy	6000.00
0005432655546	17833	Economy	6000.00
0005432655569	17833	Economy	6000.00
0005432667458	17833	Economy	6000.00
0005432655643	26302	Business	18000.00
0005432655633	26302	Business	18000.00
0005432666409	26302	Business	18000.00
0005432655639	26302	Business	18000.00
0005432667473	26302	Business	18000.00
0005432869501	26302	Business	18000.00
0005432869524	26302	Economy	6000.00
0005432655636	26302	Economy	6000.00
0005432655640	26302	Economy	6000.00
0005432869487	26302	Economy	6000.00
0005434151718	26302	Economy	6000.00
0005432655637	26302	Economy	6000.00
0005432869523	26302	Economy	6600.00
0005432659725	26302	Economy	6600.00
0005432655635	26302	Economy	6000.00
0005432869502	26302	Economy	6000.00
0005432869494	26302	Economy	6000.00
0005432657478	26302	Economy	6000.00
0005432655632	26302	Economy	6000.00
0005432655638	26302	Economy	6000.00
0005432658609	26302	Economy	6000.00
0005432657477	26302	Economy	6000.00
0005432660838	26302	Economy	6000.00
0005432665294	26302	Economy	6000.00
0005434151712	26302	Economy	6000.00
0005432658611	26302	Economy	6000.00
0005432658610	26302	Economy	6000.00
0005432655634	26302	Economy	6000.00
0005434151713	26302	Economy	6000.00
0005432657476	26302	Economy	6000.00
0005434151698	26302	Economy	6000.00
0005434151711	26302	Economy	6000.00
0005432666408	26302	Economy	6000.00
0005432665293	26302	Economy	6000.00
0005432869530	26302	Economy	6000.00
0005432660837	26302	Economy	6000.00
0005432869514	26302	Economy	6000.00
0005432655641	26302	Economy	6000.00
0005432655642	26302	Economy	6000.00
0005432869515	26302	Economy	6000.00
0005432639138	25074	Business	87300.00
0005432639176	25074	Business	87300.00
0005432639079	25074	Business	87300.00
0005432639167	25074	Business	87300.00
0005432866091	25074	Economy	29100.00
0005432639161	25074	Economy	29100.00
0005432639102	25074	Economy	29100.00
0005432639118	25074	Economy	29100.00
0005432866082	25074	Economy	32000.00
0005432639146	25074	Economy	32000.00
0005432639136	25074	Economy	32000.00
0005432866083	25074	Economy	32000.00
0005432639097	25074	Economy	29100.00
0005432866089	25074	Economy	29100.00
0005432639164	25074	Economy	29100.00
0005432639139	25074	Economy	29100.00
0005432866087	25074	Economy	29100.00
0005432639124	25074	Economy	29100.00
0005432639166	25074	Economy	29100.00
0005432866090	25074	Economy	29100.00
0005432639135	25074	Economy	29100.00
0005432639137	25074	Economy	29100.00
0005432866081	25074	Economy	29100.00
0005432639080	25074	Economy	29100.00
0005432639134	25074	Economy	29100.00
0005432639203	25074	Economy	29100.00
0005432639122	25074	Economy	29100.00
0005432866088	25074	Economy	29100.00
0005432639119	25074	Economy	29100.00
0005432639163	25074	Economy	29100.00
0005432639121	25074	Economy	29100.00
0005432866092	25074	Economy	29100.00
0005432866093	25074	Economy	29100.00
0005432639133	25074	Economy	29100.00
0005432639120	25074	Economy	29100.00
0005432639175	25074	Economy	29100.00
0005432866084	25074	Economy	29100.00
0005432866085	25074	Economy	29100.00
0005432639165	25074	Economy	29100.00
0005432866086	25074	Economy	29100.00
0005432329179	3121	Business	16100.00
0005432329187	3121	Business	16100.00
0005432329184	3121	Business	16100.00
0005432329189	3121	Business	16100.00
0005432287240	3121	Business	16100.00
0005432287243	3121	Business	16100.00
0005432329168	3121	Business	16100.00
0005432329170	3121	Business	16100.00
0005432329178	3121	Economy	5400.00
0005432329190	3121	Economy	5400.00
0005432329164	3121	Economy	5400.00
0005432287242	3121	Economy	5400.00
0005432905176	3121	Economy	5400.00
0005432329166	3121	Economy	5400.00
0005432329181	3121	Economy	5900.00
0005432329171	3121	Economy	5900.00
0005432287244	3121	Economy	5900.00
0005432329180	3121	Economy	5900.00
0005433438955	3121	Economy	5400.00
0005433438958	3121	Economy	5400.00
0005432287241	3121	Economy	5400.00
0005432329200	3121	Economy	5400.00
0005433438961	3121	Economy	5400.00
0005432329194	3121	Economy	5400.00
0005432329192	3121	Economy	5400.00
0005432329174	3121	Economy	5400.00
0005432329191	3121	Economy	5400.00
0005432905145	3121	Economy	5400.00
0005432905144	3121	Economy	5400.00
0005433438957	3121	Economy	5400.00
0005432329159	3121	Economy	5400.00
0005432905151	3121	Economy	5400.00
0005432329173	3121	Economy	5400.00
0005432329172	3121	Economy	5400.00
0005432329186	3121	Economy	5400.00
0005432329177	3121	Economy	5400.00
0005432329167	3121	Economy	5400.00
0005432329161	3121	Economy	5400.00
0005432329193	3121	Economy	5400.00
0005432329204	3121	Economy	5400.00
0005432329203	3121	Economy	5400.00
0005433438959	3121	Economy	5400.00
0005432905143	3121	Economy	5400.00
0005432329198	3121	Economy	5400.00
0005432329205	3121	Economy	5400.00
0005432329162	3121	Economy	5400.00
0005432329197	3121	Economy	5400.00
0005432329195	3121	Economy	5400.00
0005432329176	3121	Economy	5400.00
0005432329160	3121	Economy	5400.00
0005432329169	3121	Economy	5400.00
0005432329196	3121	Economy	5400.00
0005432329175	3121	Economy	5400.00
0005432329183	3121	Economy	5400.00
0005432329201	3121	Economy	5400.00
0005432329199	3121	Economy	5400.00
0005433438960	3121	Economy	5400.00
0005432329165	3121	Economy	5400.00
0005432329185	3121	Economy	5400.00
0005433438956	3121	Economy	5400.00
0005432329188	3121	Economy	5400.00
0005432329182	3121	Economy	5400.00
0005432329163	3121	Economy	5400.00
0005432329202	3121	Economy	5400.00
0005432905186	31119	Business	16100.00
0005432328952	31119	Business	16100.00
0005432054334	31119	Business	16100.00
0005432328845	31119	Business	16100.00
0005432328830	31119	Business	16100.00
0005432054335	31119	Business	16100.00
0005433438883	31119	Business	16100.00
0005432328699	31119	Business	16100.00
0005432328819	31119	Business	16100.00
0005432905187	31119	Economy	5400.00
0005432905188	31119	Economy	5400.00
0005433438857	31119	Economy	5400.00
0005432905184	31119	Economy	5400.00
0005432328794	31119	Economy	5400.00
0005432328917	31119	Economy	5400.00
0005432328906	31119	Economy	5400.00
0005432328604	31119	Economy	5900.00
0005432328698	31119	Economy	5900.00
0005433438882	31119	Economy	5900.00
0005432328838	31119	Economy	5900.00
0005432328722	31119	Economy	5400.00
0005432328554	31119	Economy	5400.00
0005432328817	31119	Economy	5400.00
0005432328777	31119	Economy	5400.00
0005432328805	31119	Economy	5400.00
0005433438881	31119	Economy	5400.00
0005433438878	31119	Economy	5400.00
0005432328804	31119	Economy	5400.00
0005432328965	31119	Economy	5400.00
0005432905185	31119	Economy	5400.00
0005432328968	31119	Economy	5400.00
0005432328966	31119	Economy	5400.00
0005432328829	31119	Economy	5400.00
0005432905189	31119	Economy	5400.00
0005432328798	31119	Economy	5400.00
0005433438890	31119	Economy	5400.00
0005432328818	31119	Economy	5400.00
0005432328843	31119	Economy	5400.00
0005432905190	31119	Economy	5400.00
0005433438885	31119	Economy	5400.00
0005432328607	31119	Economy	5400.00
0005432328757	31119	Economy	5400.00
0005432328744	31119	Economy	5400.00
0005432328750	31119	Economy	5400.00
0005432328776	31119	Economy	5400.00
0005432328662	31119	Economy	5400.00
0005432328874	31119	Economy	5400.00
0005432328706	31119	Economy	5400.00
0005432328696	31119	Economy	5400.00
0005432328768	31119	Economy	5400.00
0005432328712	31119	Economy	5400.00
0005433438853	31119	Economy	5400.00
0005433438884	31119	Economy	5400.00
0005433438889	31119	Economy	5400.00
0005432328553	31119	Economy	5400.00
0005432328967	31119	Economy	5400.00
0005432328709	31119	Economy	5400.00
0005432328841	31119	Economy	5400.00
0005432328689	31119	Economy	5400.00
0005432328640	31119	Economy	5400.00
0005433438856	31119	Economy	5400.00
0005432328610	31119	Economy	5400.00
0005432328734	31119	Economy	5400.00
0005432328721	31119	Economy	5400.00
0005432328756	31119	Economy	5400.00
0005432328842	31119	Economy	5400.00
0005432328606	31119	Economy	5400.00
0005433438852	31119	Economy	5400.00
0005432328697	31119	Economy	5400.00
0005433438850	31119	Economy	5400.00
0005433438876	31119	Economy	5400.00
0005434309881	6207	Business	124600.00
0005434309883	6207	Business	124600.00
0005435487910	6207	Business	124600.00
0005435487865	6207	Business	124600.00
0005435487862	6207	Business	124600.00
0005434309880	6207	Business	124600.00
0005435487832	6207	Business	124600.00
0005435487924	6207	Business	124600.00
0005435487869	6207	Economy	41500.00
0005435487828	6207	Economy	41500.00
0005435487813	6207	Economy	41500.00
0005435487830	6207	Economy	41500.00
0005434309879	6207	Economy	41500.00
0005432146220	6207	Economy	41500.00
0005435487889	6207	Economy	41500.00
0005434309887	6207	Economy	41500.00
0005435487785	6207	Economy	41500.00
0005435297056	6207	Economy	41500.00
0005435487814	6207	Economy	41500.00
0005435999426	6207	Economy	41500.00
0005435487791	6207	Economy	41500.00
0005435999432	6207	Economy	41500.00
0005434309882	6207	Economy	41500.00
0005435487731	6207	Economy	41500.00
0005434309889	6207	Economy	41500.00
0005435999429	6207	Economy	45700.00
0005434309886	6207	Economy	41500.00
0005435487861	6207	Economy	41500.00
0005435999431	6207	Economy	41500.00
0005435487860	6207	Economy	41500.00
0005435487863	6207	Economy	41500.00
0005434309890	6207	Economy	41500.00
0005435487870	6207	Economy	41500.00
0005432146219	6207	Economy	41500.00
0005435999424	6207	Economy	41500.00
0005435999433	6207	Economy	41500.00
0005435487911	6207	Economy	41500.00
0005435999425	6207	Economy	41500.00
0005435487834	6207	Economy	41500.00
0005435297072	6207	Economy	41500.00
0005435297090	6207	Economy	41500.00
0005435487798	6207	Economy	41500.00
0005435999430	6207	Economy	41500.00
0005435487784	6207	Economy	41500.00
0005435999427	6207	Economy	41500.00
0005434309888	6207	Economy	41500.00
0005435297060	6207	Economy	41500.00
0005435999428	6207	Economy	41500.00
0005435487845	6207	Economy	41500.00
0005434309884	6207	Economy	41500.00
0005434309885	6207	Economy	41500.00
0005435487823	6207	Economy	41500.00
0005435487923	6207	Economy	41500.00
0005435487904	6207	Economy	41500.00
0005435999434	6207	Economy	41500.00
0005434309878	6207	Economy	41500.00
0005435999435	6207	Economy	41500.00
0005434309891	6207	Economy	41500.00
0005435487831	6207	Economy	41500.00
0005435487797	6207	Economy	41500.00
0005435297132	19537	Business	124600.00
0005434309766	19537	Business	124600.00
0005435999241	19537	Business	124600.00
0005435297133	19537	Business	124600.00
0005435999217	19537	Business	124600.00
0005435488034	19537	Business	124600.00
0005435999193	19537	Business	124600.00
0005434309745	19537	Business	124600.00
0005435999216	19537	Business	124600.00
0005435999259	19537	Economy	41500.00
0005434309818	19537	Economy	41500.00
0005434309739	19537	Economy	41500.00
0005435999213	19537	Economy	41500.00
0005435999226	19537	Economy	41500.00
0005434309744	19537	Economy	41500.00
0005434309746	19537	Economy	41500.00
0005434309738	19537	Economy	41500.00
0005435488042	19537	Economy	41500.00
0005435999260	19537	Economy	41500.00
0005435488051	19537	Economy	41500.00
0005434309772	19537	Economy	41500.00
0005435999253	19537	Economy	41500.00
0005434309771	19537	Economy	41500.00
0005434309778	19537	Economy	41500.00
0005435488050	19537	Economy	45700.00
0005435999257	19537	Economy	45700.00
0005435297134	19537	Economy	45700.00
0005435999197	19537	Economy	41500.00
0005434309764	19537	Economy	41500.00
0005435488043	19537	Economy	41500.00
0005435488033	19537	Economy	41500.00
0005434309752	19537	Economy	41500.00
0005435297129	19537	Economy	41500.00
0005434309793	19537	Economy	41500.00
0005435488049	19537	Economy	41500.00
0005434309777	19537	Economy	41500.00
0005435999246	19537	Economy	41500.00
0005435488048	19537	Economy	41500.00
0005435999240	19537	Economy	41500.00
0005435488038	19537	Economy	41500.00
0005434309716	19537	Economy	41500.00
0005434309715	19537	Economy	41500.00
0005435488040	19537	Economy	41500.00
0005435488035	19537	Economy	41500.00
0005435488039	19537	Economy	41500.00
0005435999261	19537	Economy	41500.00
0005434309857	19537	Economy	41500.00
0005435488041	19537	Economy	41500.00
0005435488044	19537	Economy	41500.00
0005434309720	19537	Economy	41500.00
0005435297131	19537	Economy	41500.00
0005435297127	19537	Economy	41500.00
0005435488045	19537	Economy	41500.00
0005435488047	19537	Economy	41500.00
0005435488037	19537	Economy	41500.00
0005435488036	19537	Economy	41500.00
0005434309736	19537	Economy	41500.00
0005435297128	19537	Economy	41500.00
0005435999214	19537	Economy	41500.00
0005435999235	19537	Economy	41500.00
0005434309734	19537	Economy	41500.00
0005434309721	19537	Economy	41500.00
0005434309783	19537	Economy	41500.00
0005435999176	19537	Economy	41500.00
0005435999215	19537	Economy	41500.00
0005435999258	19537	Economy	41500.00
0005435297130	19537	Economy	41500.00
0005435488046	19537	Economy	41500.00
0005435488032	19537	Economy	41500.00
0005433186148	1596	Business	86000.00
0005435518112	1596	Business	86000.00
0005434566060	1596	Business	86000.00
0005435502530	1596	Business	86000.00
0005435502547	1596	Business	86000.00
0005435518111	1596	Business	86000.00
0005435508480	1596	Business	86000.00
0005435518114	1596	Business	86000.00
0005435518097	1596	Economy	28700.00
0005432291956	1596	Economy	28700.00
0005434566054	1596	Economy	28700.00
0005434566062	1596	Economy	28700.00
0005433186125	1596	Economy	28700.00
0005432291954	1596	Economy	28700.00
0005435518104	1596	Economy	28700.00
0005435518107	1596	Economy	28700.00
0005435508475	1596	Economy	28700.00
0005435508478	1596	Economy	31500.00
0005435502531	1596	Economy	31500.00
0005434566056	1596	Economy	31500.00
0005435502534	1596	Economy	28700.00
0005435502535	1596	Economy	28700.00
0005435508477	1596	Economy	28700.00
0005435502541	1596	Economy	28700.00
0005433186132	1596	Economy	28700.00
0005435518106	1596	Economy	28700.00
0005435508474	1596	Economy	28700.00
0005435518098	1596	Economy	28700.00
0005435508479	1596	Economy	28700.00
0005433186103	1596	Economy	28700.00
0005435502544	1596	Economy	28700.00
0005435502552	1596	Economy	28700.00
0005435502532	1596	Economy	28700.00
0005435502539	1596	Economy	28700.00
0005433186135	1596	Economy	28700.00
0005435518101	1596	Economy	28700.00
0005435508482	1596	Economy	28700.00
0005435502550	1596	Economy	28700.00
0005435508473	1596	Economy	28700.00
0005435508483	1596	Economy	28700.00
0005432291955	1596	Economy	28700.00
0005433186157	1596	Economy	28700.00
0005435518102	1596	Economy	28700.00
0005433186131	1596	Economy	28700.00
0005434566055	1596	Economy	28700.00
0005435502533	1596	Economy	28700.00
0005435518096	1596	Economy	28700.00
0005433186122	1596	Economy	28700.00
0005435518099	1596	Economy	28700.00
0005433186123	1596	Economy	28700.00
0005435508476	1596	Economy	28700.00
0005435502548	1596	Economy	28700.00
0005435518110	1596	Economy	28700.00
0005435502543	1596	Economy	28700.00
0005435518103	1596	Economy	28700.00
0005434566059	1596	Economy	28700.00
0005433186133	1596	Economy	28700.00
0005435502542	1596	Economy	28700.00
0005435518094	1596	Economy	28700.00
0005435508481	1596	Economy	28700.00
0005435502540	1596	Economy	28700.00
0005433186134	1596	Economy	28700.00
0005435518108	1596	Economy	28700.00
0005435502546	1596	Economy	28700.00
0005435502545	1596	Economy	28700.00
0005435518105	1596	Economy	28700.00
0005435518109	1596	Economy	28700.00
0005434566061	1596	Economy	28700.00
0005434566050	1596	Economy	28700.00
0005435518100	1596	Economy	28700.00
0005435502551	1596	Economy	28700.00
0005435502536	1596	Economy	28700.00
0005435502537	1596	Economy	28700.00
0005434566052	1596	Economy	28700.00
0005435502549	1596	Economy	28700.00
0005435502538	1596	Economy	28700.00
0005435518113	1596	Economy	28700.00
0005434566057	1596	Economy	28700.00
0005435518095	1596	Economy	28700.00
0005434566051	1596	Economy	28700.00
0005434566058	1596	Economy	28700.00
0005434566053	1596	Economy	28700.00
0005435545736	20869	Business	86000.00
0005433186205	20869	Business	86000.00
0005435529214	20869	Business	86000.00
0005434565922	20869	Business	86000.00
0005435502331	20869	Business	86000.00
0005433186208	20869	Business	86000.00
0005433186207	20869	Business	86000.00
0005434565902	20869	Business	86000.00
0005435502278	20869	Business	86000.00
0005434565920	20869	Business	86000.00
0005435529155	20869	Business	86000.00
0005435502404	20869	Economy	28700.00
0005434565935	20869	Economy	28700.00
0005435529325	20869	Economy	28700.00
0005434565886	20869	Economy	28700.00
0005434565941	20869	Economy	28700.00
0005435502386	20869	Economy	28700.00
0005435545728	20869	Economy	28700.00
0005435502302	20869	Economy	31500.00
0005434565919	20869	Economy	31500.00
0005435502275	20869	Economy	31500.00
0005435529162	20869	Economy	31500.00
0005435529247	20869	Economy	31500.00
0005434565934	20869	Economy	28700.00
0005435529163	20869	Economy	28700.00
0005434565982	20869	Economy	28700.00
0005434565940	20869	Economy	28700.00
0005435502358	20869	Economy	28700.00
0005434565980	20869	Economy	28700.00
0005435502326	20869	Economy	28700.00
0005435529316	20869	Economy	28700.00
0005433186210	20869	Economy	28700.00
0005433186206	20869	Economy	28700.00
0005435529324	20869	Economy	28700.00
0005434565981	20869	Economy	28700.00
0005435502305	20869	Economy	28700.00
0005435529323	20869	Economy	28700.00
0005435502332	20869	Economy	28700.00
0005433186204	20869	Economy	28700.00
0005433186212	20869	Economy	28700.00
0005434565953	20869	Economy	28700.00
0005435529258	20869	Economy	28700.00
0005433186209	20869	Economy	28700.00
0005435502329	20869	Economy	28700.00
0005435502403	20869	Economy	28700.00
0005435502301	20869	Economy	28700.00
0005435529315	20869	Economy	28700.00
0005434565885	20869	Economy	28700.00
0005435502357	20869	Economy	28700.00
0005435545729	20869	Economy	28700.00
0005435529156	20869	Economy	28700.00
0005435529224	20869	Economy	28700.00
0005435529259	20869	Economy	28700.00
0005435545730	20869	Economy	28700.00
0005434565954	20869	Economy	28700.00
0005434565939	20869	Economy	28700.00
0005435529271	20869	Economy	28700.00
0005435502310	20869	Economy	28700.00
0005434565906	20869	Economy	28700.00
0005435529286	20869	Economy	28700.00
0005435545734	20869	Economy	28700.00
0005435502363	20869	Economy	28700.00
0005435529213	20869	Economy	28700.00
0005434565888	20869	Economy	28700.00
0005435545737	20869	Economy	28700.00
0005435529211	20869	Economy	28700.00
0005435529222	20869	Economy	28700.00
0005435502276	20869	Economy	28700.00
0005435502359	20869	Economy	28700.00
0005435529223	20869	Economy	28700.00
0005434565997	20869	Economy	28700.00
0005435502309	20869	Economy	28700.00
0005434565901	20869	Economy	28700.00
0005433186211	20869	Economy	28700.00
0005435502390	20869	Economy	28700.00
0005434565937	20869	Economy	28700.00
0005435502389	20869	Economy	28700.00
0005435529281	20869	Economy	28700.00
0005435502330	20869	Economy	28700.00
0005435502269	20869	Economy	28700.00
0005434565890	20869	Economy	28700.00
0005435931623	3910	Economy	21600.00
0005435153813	3910	Economy	19700.00
0005435153810	3910	Economy	19700.00
0005435931594	3910	Economy	19700.00
0005435153812	3910	Economy	19700.00
0005435153809	3910	Economy	19700.00
0005435931593	3910	Economy	19700.00
0005435153815	3910	Economy	19700.00
0005435153811	3910	Economy	19700.00
0005435931609	3910	Economy	19700.00
0005435153808	3910	Economy	19700.00
0005435153814	3910	Economy	19700.00
0005435931622	3910	Economy	19700.00
0005435931640	21875	Economy	21600.00
0005435153764	21875	Economy	19700.00
0005435153751	21875	Economy	19700.00
0005435153766	21875	Economy	19700.00
0005435153750	21875	Economy	19700.00
0005435931639	21875	Economy	19700.00
0005435153780	21875	Economy	19700.00
0005435153779	21875	Economy	19700.00
0005435931642	21875	Economy	19700.00
0005435931641	21875	Economy	19700.00
0005435931643	21875	Economy	19700.00
0005432629004	7173	Economy	14300.00
0005435225598	7173	Economy	14300.00
0005432629003	7173	Economy	14300.00
0005435225566	7173	Economy	13000.00
0005432628994	7173	Economy	13000.00
0005435225576	7173	Economy	13000.00
0005432628996	7173	Economy	13000.00
0005432629007	7173	Economy	13000.00
0005435225578	7173	Economy	13000.00
0005435225597	7173	Economy	13000.00
0005432629006	7173	Economy	13000.00
0005432629008	7173	Economy	13000.00
0005432629005	7173	Economy	13000.00
0005435225565	7173	Economy	13000.00
0005435225564	7173	Economy	13000.00
0005432629001	7173	Economy	13000.00
0005432629009	7173	Economy	13000.00
0005435225609	7173	Economy	13000.00
0005432629000	7173	Economy	13000.00
0005435225618	7173	Economy	13000.00
0005432628995	7173	Economy	13000.00
0005435225617	7173	Economy	13000.00
0005435225585	7173	Economy	13000.00
0005432628998	7173	Economy	13000.00
0005432628999	7173	Economy	13000.00
0005432628997	7173	Economy	13000.00
0005432629002	7173	Economy	13000.00
0005432628855	28142	Economy	14300.00
0005435225671	28142	Economy	14300.00
0005435225666	28142	Economy	14300.00
0005432628925	28142	Economy	13000.00
0005432628867	28142	Economy	13000.00
0005435225667	28142	Economy	13000.00
0005432628905	28142	Economy	13000.00
0005432628947	28142	Economy	13000.00
0005435225670	28142	Economy	13000.00
0005432628872	28142	Economy	13000.00
0005435225665	28142	Economy	13000.00
0005432628888	28142	Economy	13000.00
0005432628871	28142	Economy	13000.00
0005432628913	28142	Economy	13000.00
0005432628824	28142	Economy	13000.00
0005435225669	28142	Economy	13000.00
0005432628868	28142	Economy	13000.00
0005432628946	28142	Economy	13000.00
0005435225668	28142	Economy	13000.00
0005432628922	28142	Economy	13000.00
0005432628963	28142	Economy	13000.00
0005435225673	28142	Economy	13000.00
0005435225672	28142	Economy	13000.00
0005432628854	28142	Economy	13000.00
0005432628860	28142	Economy	13000.00
0005435960089	8770	Economy	10500.00
0005435960092	8770	Economy	10500.00
0005435960091	8770	Economy	10500.00
0005434267966	8770	Economy	10500.00
0005435960090	8770	Economy	10500.00
0005435960065	15260	Economy	10500.00
0005434267989	15260	Economy	10500.00
0005434267988	15260	Economy	10500.00
0005434267990	15260	Economy	10500.00
0005432675295	1213	Business	115000.00
0005432693378	1213	Business	115000.00
0005432693350	1213	Business	115000.00
0005432675296	1213	Business	115000.00
0005432693372	1213	Business	115000.00
0005432693359	1213	Business	115000.00
0005432873309	1213	Business	115000.00
0005432677612	1213	Business	115000.00
0005432693365	1213	Economy	38300.00
0005432675298	1213	Economy	38300.00
0005432693363	1213	Economy	38300.00
0005432675286	1213	Economy	38300.00
0005432693361	1213	Economy	38300.00
0005432693377	1213	Economy	42200.00
0005432675292	1213	Economy	42200.00
0005432693362	1213	Economy	38300.00
0005432873322	1213	Economy	38300.00
0005432675291	1213	Economy	38300.00
0005432693360	1213	Economy	38300.00
0005432693375	1213	Economy	38300.00
0005432675289	1213	Economy	38300.00
0005432693358	1213	Economy	38300.00
0005432675293	1213	Economy	38300.00
0005432693371	1213	Economy	38300.00
0005432675297	1213	Economy	38300.00
0005432693349	1213	Economy	38300.00
0005432677611	1213	Economy	38300.00
0005432693354	1213	Economy	38300.00
0005432873319	1213	Economy	38300.00
0005432693366	1213	Economy	38300.00
0005432873320	1213	Economy	38300.00
0005432693356	1213	Economy	38300.00
0005432693355	1213	Economy	38300.00
0005432693374	1213	Economy	38300.00
0005432675284	1213	Economy	38300.00
0005432693348	1213	Economy	38300.00
0005432677610	1213	Economy	38300.00
0005432693351	1213	Economy	38300.00
0005432675288	1213	Economy	38300.00
0005432693373	1213	Economy	38300.00
0005432693357	1213	Economy	38300.00
0005432693368	1213	Economy	38300.00
0005432675283	1213	Economy	38300.00
0005432675285	1213	Economy	38300.00
0005432693369	1213	Economy	38300.00
0005432675287	1213	Economy	38300.00
0005432693370	1213	Economy	38300.00
0005432693353	1213	Economy	38300.00
0005432675290	1213	Economy	38300.00
0005432693367	1213	Economy	38300.00
0005432677609	1213	Economy	38300.00
0005432675294	1213	Economy	38300.00
0005432693352	1213	Economy	38300.00
0005432693364	1213	Economy	38300.00
0005432693376	1213	Economy	38300.00
0005432693077	17490	Business	115000.00
0005432693062	17490	Business	115000.00
0005432693097	17490	Business	115000.00
0005432675208	17490	Business	115000.00
0005432675131	17490	Business	115000.00
0005432692936	17490	Business	115000.00
0005432693086	17490	Business	115000.00
0005432693022	17490	Business	115000.00
0005432677572	17490	Business	115000.00
0005432675133	17490	Business	115000.00
0005432693160	17490	Economy	38300.00
0005432693090	17490	Economy	38300.00
0005432693149	17490	Economy	38300.00
0005432873364	17490	Economy	38300.00
0005432675197	17490	Economy	38300.00
0005432675159	17490	Economy	42200.00
0005432675136	17490	Economy	42200.00
0005432693091	17490	Economy	42200.00
0005432675156	17490	Economy	38300.00
0005432675209	17490	Economy	38300.00
0005432693099	17490	Economy	38300.00
0005432693159	17490	Economy	38300.00
0005432677569	17490	Economy	38300.00
0005432675168	17490	Economy	38300.00
0005432693078	17490	Economy	38300.00
0005432693148	17490	Economy	38300.00
0005432873366	17490	Economy	38300.00
0005432693092	17490	Economy	38300.00
0005432675181	17490	Economy	38300.00
0005432675196	17490	Economy	38300.00
0005432692985	17490	Economy	38300.00
0005432693080	17490	Economy	38300.00
0005432693163	17490	Economy	38300.00
0005432675122	17490	Economy	38300.00
0005432693081	17490	Economy	38300.00
0005432873369	17490	Economy	38300.00
0005432693066	17490	Economy	38300.00
0005432675067	17490	Economy	38300.00
0005432693098	17490	Economy	38300.00
0005432675188	17490	Economy	38300.00
0005432873368	17490	Economy	38300.00
0005432873363	17490	Economy	38300.00
0005432873367	17490	Economy	38300.00
0005432675154	17490	Economy	38300.00
0005432693085	17490	Economy	38300.00
0005432675179	17490	Economy	38300.00
0005432693072	17490	Economy	38300.00
0005432675132	17490	Economy	38300.00
0005432873365	17490	Economy	38300.00
0005434435342	1122	Economy	15200.00
0005434435338	1122	Economy	15200.00
0005433156769	1122	Economy	15200.00
0005433156759	1122	Economy	15200.00
0005434435350	1122	Economy	13900.00
0005433156786	1122	Economy	13900.00
0005434435344	1122	Economy	13900.00
0005434435347	1122	Economy	13900.00
0005434435343	1122	Economy	13900.00
0005433156785	1122	Economy	13900.00
0005434435336	1122	Economy	13900.00
0005433156768	1122	Economy	13900.00
0005434435348	1122	Economy	13900.00
0005434435337	1122	Economy	13900.00
0005433156774	1122	Economy	13900.00
0005434435339	1122	Economy	13900.00
0005434435346	1122	Economy	13900.00
0005434435349	1122	Economy	13900.00
0005434435341	1122	Economy	13900.00
0005433156801	1122	Economy	13900.00
0005434435335	1122	Economy	13900.00
0005434435345	1122	Economy	13900.00
0005433156758	1122	Economy	13900.00
0005433156776	1122	Economy	13900.00
0005434435340	1122	Economy	13900.00
0005433156842	17328	Economy	15200.00
0005434435167	17328	Economy	15200.00
0005434435157	17328	Economy	13900.00
0005434435156	17328	Economy	13900.00
0005434435197	17328	Economy	13900.00
0005434435236	17328	Economy	13900.00
0005434435237	17328	Economy	13900.00
0005434435235	17328	Economy	13900.00
0005434435215	17328	Economy	13900.00
0005433156843	17328	Economy	13900.00
0005433156839	17328	Economy	13900.00
0005434435241	17328	Economy	13900.00
0005433156841	17328	Economy	13900.00
0005434435144	17328	Economy	13900.00
0005434435240	17328	Economy	13900.00
0005434435151	17328	Economy	13900.00
0005434435210	17328	Economy	13900.00
0005434435266	17328	Economy	13900.00
0005434435230	17328	Economy	13900.00
0005433156840	17328	Economy	13900.00
0005434435298	17328	Economy	13900.00
0005434435143	17328	Economy	13900.00
0005433156837	17328	Economy	13900.00
0005433156838	17328	Economy	13900.00
0005435086919	4089	Economy	8200.00
0005435086910	4089	Economy	7500.00
0005435086917	4089	Economy	7500.00
0005435086916	4089	Economy	7500.00
0005435086918	4089	Economy	7500.00
0005435086913	4089	Economy	7500.00
0005435928153	4089	Economy	7500.00
0005435086912	4089	Economy	7500.00
0005435086915	4089	Economy	7500.00
0005435086911	4089	Economy	7500.00
0005435086914	4089	Economy	7500.00
0005435928154	4089	Economy	7500.00
0005435086830	24396	Economy	7500.00
0005435928193	24396	Economy	7500.00
0005435928192	24396	Economy	7500.00
0005435086834	24396	Economy	7500.00
0005435086833	24396	Economy	7500.00
0005435928191	24396	Economy	7500.00
0005435086832	24396	Economy	7500.00
0005435086854	24396	Economy	7500.00
0005435928194	24396	Economy	7500.00
0005435928195	24396	Economy	7500.00
0005435551592	11060	Business	144300.00
0005435551561	11060	Business	144300.00
0005435551599	11060	Business	144300.00
0005435551600	11060	Business	144300.00
0005435551597	11060	Business	144300.00
0005435551565	11060	Business	144300.00
0005435551606	11060	Economy	48100.00
0005435551578	11060	Economy	48100.00
0005435098544	11060	Economy	48100.00
0005435551611	11060	Economy	48100.00
0005435551581	11060	Economy	48100.00
0005435551596	11060	Economy	48100.00
0005435551587	11060	Economy	48100.00
0005435551593	11060	Economy	48100.00
0005435098552	11060	Economy	48100.00
0005435098555	11060	Economy	48100.00
0005435551560	11060	Economy	48100.00
0005435098560	11060	Economy	48100.00
0005435551607	11060	Economy	48100.00
0005435098559	11060	Economy	48100.00
0005435551582	11060	Economy	48100.00
0005435551602	11060	Economy	48100.00
0005435098551	11060	Economy	48100.00
0005435098538	11060	Economy	48100.00
0005435551612	11060	Economy	48100.00
0005435551620	11060	Economy	48100.00
0005435551591	11060	Economy	48100.00
0005435551610	11060	Economy	48100.00
0005435551595	11060	Economy	48100.00
0005435098553	11060	Economy	48100.00
0005435098558	11060	Economy	48100.00
0005435551601	11060	Economy	48100.00
0005435551583	11060	Economy	48100.00
0005435098554	11060	Economy	48100.00
0005435098539	11060	Economy	48100.00
0005433373523	2456	Business	86800.00
0005433373535	2456	Business	86800.00
0005433373565	2456	Business	86800.00
0005433373564	2456	Business	86800.00
0005435706546	2456	Business	86800.00
0005435706560	2456	Business	86800.00
0005433373519	2456	Business	86800.00
0005435706542	2456	Economy	28900.00
0005435706549	2456	Economy	28900.00
0005435706540	2456	Economy	28900.00
0005433373541	2456	Economy	28900.00
0005435706563	2456	Economy	28900.00
0005435706557	2456	Economy	28900.00
0005435706534	2456	Economy	28900.00
0005435706559	2456	Economy	31800.00
0005435706553	2456	Economy	31800.00
0005435706561	2456	Economy	31800.00
0005433373547	2456	Economy	28900.00
0005435706538	2456	Economy	28900.00
0005435706551	2456	Economy	28900.00
0005435706565	2456	Economy	28900.00
0005435706539	2456	Economy	28900.00
0005435706545	2456	Economy	28900.00
0005435706558	2456	Economy	28900.00
0005435706555	2456	Economy	28900.00
0005435706564	2456	Economy	28900.00
0005435706556	2456	Economy	28900.00
0005435706544	2456	Economy	28900.00
0005435706548	2456	Economy	28900.00
0005435706567	2456	Economy	28900.00
0005435706533	2456	Economy	28900.00
0005435706554	2456	Economy	28900.00
0005435706541	2456	Economy	28900.00
0005435706566	2456	Economy	28900.00
0005435706535	2456	Economy	28900.00
0005435706547	2456	Economy	28900.00
0005433373509	2456	Economy	28900.00
0005433373554	2456	Economy	28900.00
0005435706536	2456	Economy	28900.00
0005435706537	2456	Economy	28900.00
0005435706543	2456	Economy	28900.00
0005433373530	2456	Economy	28900.00
0005433373548	2456	Economy	28900.00
0005435706562	2456	Economy	28900.00
0005435706552	2456	Economy	28900.00
0005433373511	2456	Economy	28900.00
0005435706550	2456	Economy	28900.00
0005435706493	27021	Business	86800.00
0005435706415	27021	Business	86800.00
0005435706400	27021	Economy	28900.00
0005433373630	27021	Economy	28900.00
0005435706431	27021	Economy	28900.00
0005435706432	27021	Economy	28900.00
0005433373635	27021	Economy	31800.00
0005433373622	27021	Economy	31800.00
0005435706407	27021	Economy	31800.00
0005435706336	27021	Economy	28900.00
0005433373621	27021	Economy	28900.00
0005435706382	27021	Economy	28900.00
0005433373633	27021	Economy	28900.00
0005435706401	27021	Economy	28900.00
0005435706414	27021	Economy	28900.00
0005435706342	27021	Economy	28900.00
0005433373624	27021	Economy	28900.00
0005435706462	27021	Economy	28900.00
0005435706383	27021	Economy	28900.00
0005433373627	27021	Economy	28900.00
0005435706406	27021	Economy	28900.00
0005433373629	27021	Economy	28900.00
0005433373626	27021	Economy	28900.00
0005433373625	27021	Economy	28900.00
0005433373619	27021	Economy	28900.00
0005435706367	27021	Economy	28900.00
0005433373628	27021	Economy	28900.00
0005433373620	27021	Economy	28900.00
0005435706399	27021	Economy	28900.00
0005435706409	27021	Economy	28900.00
0005435706335	27021	Economy	28900.00
0005433373636	27021	Economy	28900.00
0005435706354	27021	Economy	28900.00
0005435706402	27021	Economy	28900.00
0005435706397	27021	Economy	28900.00
0005435706381	27021	Economy	28900.00
0005435706437	27021	Economy	28900.00
0005435706341	27021	Economy	28900.00
0005433373631	27021	Economy	28900.00
0005435706343	27021	Economy	28900.00
0005435706425	27021	Economy	28900.00
0005435706396	27021	Economy	28900.00
0005433373618	27021	Economy	28900.00
0005435706302	27021	Economy	28900.00
0005433373623	27021	Economy	28900.00
0005435706366	27021	Economy	28900.00
0005435706368	27021	Economy	28900.00
0005433373632	27021	Economy	28900.00
0005435706403	27021	Economy	28900.00
0005433373634	27021	Economy	28900.00
0005435706352	27021	Economy	28900.00
0005433261609	1321	Business	203300.00
0005434964431	1321	Business	203300.00
0005434964417	1321	Business	203300.00
0005434964437	1321	Business	203300.00
0005433261603	1321	Business	203300.00
0005433261560	1321	Business	203300.00
0005434964430	1321	Business	203300.00
0005434964436	1321	Economy	67800.00
0005433261593	1321	Economy	67800.00
0005433261599	1321	Economy	67800.00
0005434964406	1321	Economy	67800.00
0005434964403	1321	Economy	67800.00
0005434964407	1321	Economy	67800.00
0005432279294	1321	Economy	67800.00
0005434964424	1321	Economy	67800.00
0005434964421	1321	Economy	67800.00
0005432279293	1321	Economy	67800.00
0005432279291	1321	Economy	67800.00
0005433261588	1321	Economy	67800.00
0005434964438	1321	Economy	67800.00
0005433261579	1321	Economy	67800.00
0005434964433	1321	Economy	67800.00
0005434964409	1321	Economy	67800.00
0005434964425	1321	Economy	67800.00
0005434964441	1321	Economy	67800.00
0005434964440	1321	Economy	67800.00
0005434964408	1321	Economy	67800.00
0005434964404	1321	Economy	67800.00
0005433261559	1321	Economy	67800.00
0005433261526	1321	Economy	67800.00
0005433261600	1321	Economy	67800.00
0005434964434	1321	Economy	67800.00
0005433261595	1321	Economy	67800.00
0005434964420	1321	Economy	67800.00
0005434964418	1321	Economy	67800.00
0005434964410	1321	Economy	67800.00
0005433261565	1321	Economy	67800.00
0005433261624	1321	Economy	67800.00
0005433261556	1321	Economy	67800.00
0005434964414	1321	Economy	74500.00
0005434964429	1321	Economy	74500.00
0005434964422	1321	Economy	67800.00
0005433261508	1321	Economy	67800.00
0005434964405	1321	Economy	67800.00
0005434964426	1321	Economy	67800.00
0005434964435	1321	Economy	67800.00
0005434964432	1321	Economy	67800.00
0005434964416	1321	Economy	67800.00
0005433261589	1321	Economy	67800.00
0005432279292	1321	Economy	67800.00
0005434964402	1321	Economy	67800.00
0005433261580	1321	Economy	67800.00
0005434964428	1321	Economy	67800.00
0005434964419	1321	Economy	67800.00
0005434964411	1321	Economy	67800.00
0005434964423	1321	Economy	67800.00
0005434964412	1321	Economy	67800.00
0005433261566	1321	Economy	67800.00
0005434964427	1321	Economy	67800.00
0005434964439	1321	Economy	67800.00
0005433261557	1321	Economy	67800.00
0005434964413	1321	Economy	67800.00
0005434964415	1321	Economy	67800.00
0005434964293	18254	Business	203300.00
0005434964270	18254	Business	203300.00
0005434964220	18254	Business	203300.00
0005433261664	18254	Business	203300.00
0005433261658	18254	Business	203300.00
0005433261650	18254	Business	203300.00
0005433261655	18254	Business	203300.00
0005433261672	18254	Business	203300.00
0005433261679	18254	Business	203300.00
0005433261668	18254	Business	203300.00
0005433261653	18254	Business	203300.00
0005434964174	18254	Business	203300.00
0005434964257	18254	Business	203300.00
0005433261649	18254	Business	203300.00
0005434964255	18254	Business	203300.00
0005434964222	18254	Economy	74500.00
0005434964196	18254	Economy	74500.00
0005434964197	18254	Economy	67800.00
0005433261652	18254	Economy	67800.00
0005433261648	18254	Economy	67800.00
0005433261651	18254	Economy	67800.00
0005434964221	18254	Economy	67800.00
0005434964241	18254	Economy	67800.00
0005434964224	18254	Economy	67800.00
0005433261667	18254	Economy	67800.00
0005434964269	18254	Economy	67800.00
0005434964164	18254	Economy	67800.00
0005434964126	18254	Economy	67800.00
0005434964250	18254	Economy	67800.00
0005433261678	18254	Economy	67800.00
0005434964263	18254	Economy	67800.00
0005433261670	18254	Economy	67800.00
0005434964252	18254	Economy	67800.00
0005434964230	18254	Economy	67800.00
0005433261676	18254	Economy	67800.00
0005434964256	18254	Economy	67800.00
0005434964198	18254	Economy	67800.00
0005434964163	18254	Economy	67800.00
0005433261663	18254	Economy	67800.00
0005434964208	18254	Economy	67800.00
0005434964292	18254	Economy	67800.00
0005433261669	18254	Economy	67800.00
0005434964175	18254	Economy	67800.00
0005434964229	18254	Economy	67800.00
0005434964294	18254	Economy	67800.00
0005433261660	18254	Economy	67800.00
0005433261661	18254	Economy	67800.00
0005434964243	18254	Economy	67800.00
0005434964260	18254	Economy	67800.00
0005434964227	18254	Economy	67800.00
0005434964251	18254	Economy	67800.00
0005433261675	18254	Economy	67800.00
0005433261654	18254	Economy	67800.00
0005434964261	18254	Economy	67800.00
0005433261673	18254	Economy	67800.00
0005434964205	18254	Economy	67800.00
0005434964242	18254	Economy	67800.00
0005433261680	18254	Economy	67800.00
0005433261674	18254	Economy	67800.00
0005434964215	18254	Economy	67800.00
0005434964244	18254	Economy	67800.00
0005434964228	18254	Economy	67800.00
0005433261666	18254	Economy	67800.00
0005433261665	18254	Economy	67800.00
0005434964211	18254	Economy	67800.00
0005433261656	18254	Economy	67800.00
0005433261657	18254	Economy	67800.00
0005434964212	18254	Economy	67800.00
0005433261662	18254	Economy	67800.00
0005434964199	18254	Economy	67800.00
0005433261677	18254	Economy	67800.00
0005434964262	18254	Economy	67800.00
0005433261659	18254	Economy	67800.00
0005433261671	18254	Economy	67800.00
0005434964143	18254	Economy	67800.00
0005434626057	4827	Business	44200.00
0005433194856	4827	Business	44200.00
0005434626064	4827	Economy	14700.00
0005434626058	4827	Economy	14700.00
0005434626061	4827	Economy	14700.00
0005434626062	4827	Economy	14700.00
0005434626060	4827	Economy	14700.00
0005434626056	4827	Economy	14700.00
0005434626063	4827	Economy	14700.00
0005434626059	4827	Economy	14700.00
0005435907556	32925	Economy	14700.00
0005434625997	32925	Economy	14700.00
0005435907555	32925	Economy	14700.00
0005434625998	32925	Economy	14700.00
0005434626002	32925	Economy	14700.00
0005435907557	32925	Economy	14700.00
0005434625967	32925	Economy	14700.00
0005434625999	32925	Economy	14700.00
0005434625966	32925	Economy	14700.00
0005435907554	32925	Economy	14700.00
0005434625973	32925	Economy	14700.00
0005434626003	32925	Economy	14700.00
0005435785182	13788	Economy	3400.00
0005435785371	13788	Economy	3400.00
0005435785447	13788	Economy	3400.00
0005435785420	13788	Economy	3100.00
0005435785437	13788	Economy	3100.00
0005435937429	13788	Economy	3100.00
0005435785334	13788	Economy	3100.00
0005435785391	13788	Economy	3100.00
0005435785325	13788	Economy	3100.00
0005432195714	13788	Economy	3100.00
0005435785419	13788	Economy	3100.00
0005435785349	13788	Economy	3100.00
0005435785310	13788	Economy	3100.00
0005435785373	13788	Economy	3100.00
0005432195715	13788	Economy	3100.00
0005435785404	13788	Economy	3100.00
0005435785254	13788	Economy	3100.00
0005435937430	13788	Economy	3100.00
0005435785422	13788	Economy	3100.00
0005435785421	13788	Economy	3100.00
0005435785438	13788	Economy	3100.00
0005435785332	13788	Economy	3100.00
0005435937432	13788	Economy	3100.00
0005435785390	13788	Economy	3100.00
0005435785327	13788	Economy	3100.00
0005435937431	13788	Economy	3100.00
0005435785370	13788	Economy	3100.00
0005435785389	13788	Economy	3100.00
0005435785392	13788	Economy	3100.00
0005435785426	13788	Economy	3100.00
0005435785439	13788	Economy	3100.00
0005435785460	13788	Economy	3100.00
0005435785275	13788	Economy	3100.00
0005435785252	13788	Economy	3100.00
0005435785434	13788	Economy	3100.00
0005435785423	13788	Economy	3100.00
0005435785281	13788	Economy	3100.00
0005435785308	13788	Economy	3100.00
0005435785444	13788	Economy	3100.00
0005435785684	27405	Economy	3400.00
0005435787372	27405	Economy	3400.00
0005435785662	27405	Economy	3400.00
0005432190665	27405	Economy	3400.00
0005435785675	27405	Economy	3100.00
0005435785653	27405	Economy	3100.00
0005435785651	27405	Economy	3100.00
0005435785673	27405	Economy	3100.00
0005435785661	27405	Economy	3100.00
0005435785659	27405	Economy	3100.00
0005435785665	27405	Economy	3100.00
0005435785682	27405	Economy	3100.00
0005435785657	27405	Economy	3100.00
0005435787374	27405	Economy	3100.00
0005435785654	27405	Economy	3100.00
0005432190663	27405	Economy	3100.00
0005435785652	27405	Economy	3100.00
0005435937382	27405	Economy	3100.00
0005435785663	27405	Economy	3100.00
0005435785649	27405	Economy	3100.00
0005435785664	27405	Economy	3100.00
0005435785655	27405	Economy	3100.00
0005435785650	27405	Economy	3100.00
0005435785679	27405	Economy	3100.00
0005435785672	27405	Economy	3100.00
0005435785660	27405	Economy	3100.00
0005435785680	27405	Economy	3100.00
0005435785678	27405	Economy	3100.00
0005435785666	27405	Economy	3100.00
0005435785658	27405	Economy	3100.00
0005435785676	27405	Economy	3100.00
0005435785656	27405	Economy	3100.00
0005432190664	27405	Economy	3100.00
0005435937383	27405	Economy	3100.00
0005435785683	27405	Economy	3100.00
0005435787373	27405	Economy	3100.00
0005435785669	27405	Economy	3100.00
0005435785674	27405	Economy	3100.00
0005435785667	27405	Economy	3100.00
0005435785668	27405	Economy	3100.00
0005435937374	27405	Economy	3100.00
0005432190666	27405	Economy	3100.00
0005435785681	27405	Economy	3100.00
0005435937381	27405	Economy	3100.00
0005435785677	27405	Economy	3100.00
0005435937384	27405	Economy	3100.00
0005435785671	27405	Economy	3100.00
0005435785670	27405	Economy	3100.00
0005432190662	27405	Economy	3100.00
0005435311183	20309	Business	12000.00
0005434408088	20309	Business	12000.00
0005434407680	20309	Business	12000.00
0005434407820	20309	Business	12000.00
0005434407693	20309	Business	12000.00
0005434408038	20309	Business	12000.00
0005434407727	20309	Business	12000.00
0005434407852	20309	Business	12000.00
0005434407743	20309	Business	12000.00
0005434407965	20309	Business	12000.00
0005434407964	20309	Business	12000.00
0005435311191	20309	Economy	4000.00
0005434408091	20309	Economy	4000.00
0005434407749	20309	Economy	4000.00
0005434407481	20309	Economy	4000.00
0005434407987	20309	Economy	4000.00
0005434407977	20309	Economy	4000.00
0005434407897	20309	Economy	4000.00
0005435311192	20309	Economy	4000.00
0005432058425	20309	Economy	4000.00
0005432058422	20309	Economy	4400.00
0005432058424	20309	Economy	4400.00
0005434407990	20309	Economy	4400.00
0005434407833	20309	Economy	4400.00
0005435311189	20309	Economy	4000.00
0005435311190	20309	Economy	4000.00
0005434408108	20309	Economy	4000.00
0005434408145	20309	Economy	4000.00
0005434407824	20309	Economy	4000.00
0005434408054	20309	Economy	4000.00
0005434407925	20309	Economy	4000.00
0005434407970	20309	Economy	4000.00
0005434407744	20309	Economy	4000.00
0005434408083	20309	Economy	4000.00
0005435311195	20309	Economy	4000.00
0005434408107	20309	Economy	4000.00
0005434408119	20309	Economy	4000.00
0005435311182	20309	Economy	4000.00
0005434407991	20309	Economy	4000.00
0005434407851	20309	Economy	4000.00
0005435311197	20309	Economy	4000.00
0005434407853	20309	Economy	4000.00
0005435311200	20309	Economy	4000.00
0005435311194	20309	Economy	4000.00
0005434407767	20309	Economy	4000.00
0005435311196	20309	Economy	4000.00
0005435311184	20309	Economy	4000.00
0005434407798	20309	Economy	4000.00
0005434407875	20309	Economy	4000.00
0005434407826	20309	Economy	4000.00
0005434407742	20309	Economy	4000.00
0005435311201	20309	Economy	4000.00
0005434407976	20309	Economy	4000.00
0005434407986	20309	Economy	4000.00
0005435311199	20309	Economy	4000.00
0005435311188	20309	Economy	4000.00
0005435311193	20309	Economy	4000.00
0005434407868	20309	Economy	4000.00
0005435311186	20309	Economy	4000.00
0005434408115	20309	Economy	4000.00
0005435311202	20309	Economy	4000.00
0005434407751	20309	Economy	4000.00
0005432058423	20309	Economy	4000.00
0005435311178	20309	Economy	4000.00
0005434407917	20309	Economy	4000.00
0005434407876	20309	Economy	4000.00
0005435311181	20309	Economy	4000.00
0005434407839	20309	Economy	4000.00
0005435311185	20309	Economy	4000.00
0005435311187	20309	Economy	4000.00
0005434407910	20309	Economy	4000.00
0005434407840	20309	Economy	4000.00
0005435311179	20309	Economy	4000.00
0005434407681	20309	Economy	4000.00
0005435311180	20309	Economy	4000.00
0005434407950	20309	Economy	4000.00
0005434407909	20309	Economy	4000.00
0005434407989	20309	Economy	4000.00
0005434407814	20309	Economy	4000.00
0005434408037	20309	Economy	4000.00
0005434407722	20309	Economy	4000.00
0005434407832	20309	Economy	4000.00
0005434407940	20309	Economy	4000.00
0005435311198	20309	Economy	4000.00
0005434408052	20309	Economy	4000.00
0005434407797	20309	Economy	4000.00
0005434408084	20309	Economy	4000.00
0005432058421	20309	Economy	4000.00
0005434407676	20309	Economy	4000.00
0005434408422	26995	Business	12000.00
0005434408441	26995	Business	12000.00
0005434408389	26995	Business	12000.00
0005434408440	26995	Business	12000.00
0005435311057	26995	Business	12000.00
0005434408382	26995	Business	12000.00
0005434408400	26995	Business	12000.00
0005434408383	26995	Business	12000.00
0005434408430	26995	Business	12000.00
0005434408408	26995	Economy	4000.00
0005434408401	26995	Economy	4000.00
0005434408391	26995	Economy	4000.00
0005434408425	26995	Economy	4000.00
0005434408402	26995	Economy	4000.00
0005432154009	26995	Economy	4000.00
0005434408436	26995	Economy	4000.00
0005432154011	26995	Economy	4000.00
0005432154013	26995	Economy	4400.00
0005434408410	26995	Economy	4400.00
0005434408386	26995	Economy	4400.00
0005434408424	26995	Economy	4400.00
0005434408431	26995	Economy	4400.00
0005434408414	26995	Economy	4000.00
0005434408415	26995	Economy	4000.00
0005432154010	26995	Economy	4000.00
0005435311056	26995	Economy	4000.00
0005434408385	26995	Economy	4000.00
0005434408427	26995	Economy	4000.00
0005434408421	26995	Economy	4000.00
0005434408409	26995	Economy	4000.00
0005434408390	26995	Economy	4000.00
0005434408426	26995	Economy	4000.00
0005434408403	26995	Economy	4000.00
0005434408435	26995	Economy	4000.00
0005434408395	26995	Economy	4000.00
0005434408434	26995	Economy	4000.00
0005434408384	26995	Economy	4000.00
0005434408404	26995	Economy	4000.00
0005434408417	26995	Economy	4000.00
0005434408437	26995	Economy	4000.00
0005434408412	26995	Economy	4000.00
0005434408407	26995	Economy	4000.00
0005434408446	26995	Economy	4000.00
0005435311085	26995	Economy	4000.00
0005434408396	26995	Economy	4000.00
0005434408420	26995	Economy	4000.00
0005434408406	26995	Economy	4000.00
0005435311052	26995	Economy	4000.00
0005434408432	26995	Economy	4000.00
0005434408429	26995	Economy	4000.00
0005434408399	26995	Economy	4000.00
0005434408405	26995	Economy	4000.00
0005434408423	26995	Economy	4000.00
0005434408418	26995	Economy	4000.00
0005434408444	26995	Economy	4000.00
0005434408419	26995	Economy	4000.00
0005434408394	26995	Economy	4000.00
0005435311053	26995	Economy	4000.00
0005434408413	26995	Economy	4000.00
0005434408397	26995	Economy	4000.00
0005434408439	26995	Economy	4000.00
0005434408443	26995	Economy	4000.00
0005434408387	26995	Economy	4000.00
0005434408398	26995	Economy	4000.00
0005434408393	26995	Economy	4000.00
0005434408442	26995	Economy	4000.00
0005434408388	26995	Economy	4000.00
0005434408445	26995	Economy	4000.00
0005434408433	26995	Economy	4000.00
0005435311048	26995	Economy	4000.00
0005432154012	26995	Economy	4000.00
0005434408392	26995	Economy	4000.00
0005434408428	26995	Economy	4000.00
0005434408438	26995	Economy	4000.00
0005435311042	26995	Economy	4000.00
0005435311041	26995	Economy	4000.00
0005434408411	26995	Economy	4000.00
0005434408416	26995	Economy	4000.00
0005434319544	5727	Business	43300.00
0005434319549	5727	Business	43300.00
0005433123986	5727	Business	43300.00
0005434319555	5727	Business	43300.00
0005433123827	5727	Business	43300.00
0005432109731	5727	Business	43300.00
0005434319554	5727	Business	43300.00
0005434319556	5727	Economy	14400.00
0005434319558	5727	Economy	15900.00
0005432109733	5727	Economy	15900.00
0005433123980	5727	Economy	14400.00
0005434319551	5727	Economy	14400.00
0005434319546	5727	Economy	14400.00
0005433123878	5727	Economy	14400.00
0005434319547	5727	Economy	14400.00
0005433124000	5727	Economy	14400.00
0005434319557	5727	Economy	14400.00
0005434319553	5727	Economy	14400.00
0005433123865	5727	Economy	14400.00
0005433123985	5727	Economy	14400.00
0005434319543	5727	Economy	14400.00
0005434319550	5727	Economy	14400.00
0005434319542	5727	Economy	14400.00
0005433123906	5727	Economy	14400.00
0005432109732	5727	Economy	14400.00
0005433123881	5727	Economy	14400.00
0005434319552	5727	Economy	14400.00
0005433123979	5727	Economy	14400.00
0005434311240	5727	Economy	14400.00
0005434319545	5727	Economy	14400.00
0005434319548	5727	Economy	14400.00
0005433123973	5727	Economy	14400.00
0005433123936	5727	Economy	14400.00
0005434311241	5727	Economy	14400.00
0005434319409	15658	Business	43300.00
0005433124144	15658	Business	43300.00
0005433124151	15658	Business	43300.00
0005434319463	15658	Business	43300.00
0005434319468	15658	Business	43300.00
0005433124163	15658	Economy	14400.00
0005434319368	15658	Economy	14400.00
0005433124154	15658	Economy	14400.00
0005434311220	15658	Economy	14400.00
0005434312332	15658	Economy	14400.00
0005433124152	15658	Economy	15900.00
0005433124153	15658	Economy	14400.00
0005434319466	15658	Economy	14400.00
0005434319427	15658	Economy	14400.00
0005433124162	15658	Economy	14400.00
0005434319412	15658	Economy	14400.00
0005434319347	15658	Economy	14400.00
0005434319474	15658	Economy	14400.00
0005434319426	15658	Economy	14400.00
0005434311219	15658	Economy	14400.00
0005434319411	15658	Economy	14400.00
0005433124161	15658	Economy	14400.00
0005433124160	15658	Economy	14400.00
0005433124159	15658	Economy	14400.00
0005434319337	15658	Economy	14400.00
0005433124149	15658	Economy	14400.00
0005433124148	15658	Economy	14400.00
0005433124146	15658	Economy	14400.00
0005433124150	15658	Economy	14400.00
0005434319390	15658	Economy	14400.00
0005434319424	15658	Economy	14400.00
0005434312311	15658	Economy	14400.00
0005433124155	15658	Economy	14400.00
0005434319351	15658	Economy	14400.00
0005434319336	15658	Economy	14400.00
0005433124158	15658	Economy	14400.00
0005433124145	15658	Economy	14400.00
0005433124157	15658	Economy	14400.00
0005434319372	15658	Economy	14400.00
0005433124147	15658	Economy	14400.00
0005434319369	15658	Economy	14400.00
0005434319397	15658	Economy	14400.00
0005433124156	15658	Economy	14400.00
0005434312331	15658	Economy	14400.00
0005433124164	15658	Economy	14400.00
0005435220316	24976	Economy	17100.00
0005435217708	24976	Economy	17100.00
0005435220307	24976	Economy	15500.00
0005435220320	24976	Economy	15500.00
0005435221514	24976	Economy	15500.00
0005435217700	24976	Economy	15500.00
0005435217713	24976	Economy	15500.00
0005435217723	24976	Economy	15500.00
0005435217706	24976	Economy	15500.00
0005435217710	24976	Economy	15500.00
0005435221516	24976	Economy	15500.00
0005435217722	24976	Economy	15500.00
0005435221511	24976	Economy	15500.00
0005435217704	24976	Economy	15500.00
0005435217707	24976	Economy	15500.00
0005435217711	24976	Economy	15500.00
0005435220317	24976	Economy	15500.00
0005435221515	24976	Economy	15500.00
0005435217709	24976	Economy	15500.00
0005435220321	24976	Economy	15500.00
0005434189178	8995	Economy	27400.00
0005434484415	8995	Economy	27400.00
0005434189202	8995	Economy	24900.00
0005434484419	8995	Economy	24900.00
0005434189191	8995	Economy	24900.00
0005434484416	8995	Economy	24900.00
0005434484413	8995	Economy	24900.00
0005434484418	8995	Economy	24900.00
0005434484417	8995	Economy	24900.00
0005434189201	8995	Economy	24900.00
0005434484414	8995	Economy	24900.00
0005434484356	16637	Economy	27400.00
0005434189236	16637	Economy	24900.00
0005434484328	16637	Economy	24900.00
0005434484353	16637	Economy	24900.00
0005434484365	16637	Economy	24900.00
0005434484380	16637	Economy	24900.00
0005434484354	16637	Economy	24900.00
0005434189238	16637	Economy	24900.00
0005434189241	16637	Economy	24900.00
0005434189240	16637	Economy	24900.00
0005434189239	16637	Economy	24900.00
0005434484364	16637	Economy	24900.00
0005434189237	16637	Economy	24900.00
0005433722206	7602	Business	11100.00
0005433124152	7602	Business	11100.00
0005433124155	7602	Business	11100.00
0005433124159	7602	Economy	4100.00
0005433124160	7602	Economy	4100.00
0005433124164	7602	Economy	4100.00
0005433722200	7602	Economy	4100.00
0005433124148	7602	Economy	3700.00
0005433722204	7602	Economy	3700.00
0005433124146	7602	Economy	3700.00
0005433124163	7602	Economy	3700.00
0005433124156	7602	Economy	3700.00
0005433124147	7602	Economy	3700.00
0005433124161	7602	Economy	3700.00
0005433124157	7602	Economy	3700.00
0005433124149	7602	Economy	3700.00
0005433124162	7602	Economy	3700.00
0005433124151	7602	Economy	3700.00
0005433124154	7602	Economy	3700.00
0005433124150	7602	Economy	3700.00
0005433124144	7602	Economy	3700.00
0005433124158	7602	Economy	3700.00
0005433722205	7602	Economy	3700.00
0005433124145	7602	Economy	3700.00
0005433124153	7602	Economy	3700.00
0005433450186	7601	Business	11100.00
0005432721194	7601	Business	11100.00
0005432693397	7601	Business	11100.00
0005433450197	7601	Business	11100.00
0005432721191	7601	Business	11100.00
0005432693379	7601	Business	11100.00
0005432693384	7601	Business	11100.00
0005433450187	7601	Business	11100.00
0005432693386	7601	Business	11100.00
0005432721190	7601	Business	11100.00
0005433450191	7601	Business	11100.00
0005432721170	7601	Economy	3700.00
0005432693404	7601	Economy	3700.00
0005432721174	7601	Economy	3700.00
0005432693385	7601	Economy	3700.00
0005432721182	7601	Economy	3700.00
0005433450189	7601	Economy	3700.00
0005433450195	7601	Economy	3700.00
0005433450203	7601	Economy	4100.00
0005432693405	7601	Economy	4100.00
0005432721192	7601	Economy	4100.00
0005433450193	7601	Economy	4100.00
0005432721196	7601	Economy	4100.00
0005432693402	7601	Economy	3700.00
0005432693410	7601	Economy	3700.00
0005433450199	7601	Economy	3700.00
0005432693392	7601	Economy	3700.00
0005432693396	7601	Economy	3700.00
0005432721189	7601	Economy	3700.00
0005433450194	7601	Economy	3700.00
0005432693389	7601	Economy	3700.00
0005433450205	7601	Economy	3700.00
0005432071605	7601	Economy	3700.00
0005433450202	7601	Economy	3700.00
0005432721195	7601	Economy	3700.00
0005432693381	7601	Economy	3700.00
0005432721187	7601	Economy	3700.00
0005432693390	7601	Economy	3700.00
0005433450196	7601	Economy	3700.00
0005433450198	7601	Economy	3700.00
0005433450206	7601	Economy	3700.00
0005432721186	7601	Economy	3700.00
0005432693388	7601	Economy	3700.00
0005432693380	7601	Economy	3700.00
0005432721177	7601	Economy	3700.00
0005432693399	7601	Economy	3700.00
0005432721180	7601	Economy	3700.00
0005432721179	7601	Economy	3700.00
0005432721171	7601	Economy	3700.00
0005433450192	7601	Economy	3700.00
0005432693383	7601	Economy	3700.00
0005432693409	7601	Economy	3700.00
0005432693393	7601	Economy	3700.00
0005432693401	7601	Economy	3700.00
0005433450188	7601	Economy	3700.00
0005432693387	7601	Economy	3700.00
0005432693403	7601	Economy	3700.00
0005432721197	7601	Economy	3700.00
0005432721183	7601	Economy	3700.00
0005433450185	7601	Economy	3700.00
0005432721173	7601	Economy	3700.00
0005432693408	7601	Economy	3700.00
0005432693395	7601	Economy	3700.00
0005432693394	7601	Economy	3700.00
0005433450204	7601	Economy	3700.00
0005432721172	7601	Economy	3700.00
0005433450200	7601	Economy	3700.00
0005432693382	7601	Economy	3700.00
0005432721184	7601	Economy	3700.00
0005432693406	7601	Economy	3700.00
0005432071604	7601	Economy	3700.00
0005433450190	7601	Economy	3700.00
0005432693400	7601	Economy	3700.00
0005432721181	7601	Economy	3700.00
0005432693391	7601	Economy	3700.00
0005432721175	7601	Economy	3700.00
0005432721193	7601	Economy	3700.00
0005432721185	7601	Economy	3700.00
0005432693398	7601	Economy	3700.00
0005433450201	7601	Economy	3700.00
0005432693407	7601	Economy	3700.00
0005432721188	7601	Economy	3700.00
0005432721176	7601	Economy	3700.00
0005432721178	7601	Economy	3700.00
0005433449941	30329	Business	11100.00
0005432693159	30329	Business	11100.00
0005433450107	30329	Business	11100.00
0005433450015	30329	Business	11100.00
0005433449934	30329	Business	11100.00
0005432693086	30329	Business	11100.00
0005432693092	30329	Economy	3700.00
0005433449989	30329	Economy	3700.00
0005433449982	30329	Economy	3700.00
0005433450084	30329	Economy	3700.00
0005433449935	30329	Economy	3700.00
0005433450011	30329	Economy	3700.00
0005433450089	30329	Economy	3700.00
0005433450013	30329	Economy	4100.00
0005432693098	30329	Economy	4100.00
0005432693149	30329	Economy	4100.00
0005432693077	30329	Economy	3700.00
0005433450010	30329	Economy	3700.00
0005432693099	30329	Economy	3700.00
0005433449984	30329	Economy	3700.00
0005432693090	30329	Economy	3700.00
0005433450108	30329	Economy	3700.00
0005432693022	30329	Economy	3700.00
0005432693085	30329	Economy	3700.00
0005432693148	30329	Economy	3700.00
0005433449955	30329	Economy	3700.00
0005433450076	30329	Economy	3700.00
0005433450048	30329	Economy	3700.00
0005433450047	30329	Economy	3700.00
0005433449983	30329	Economy	3700.00
0005433449877	30329	Economy	3700.00
0005433450083	30329	Economy	3700.00
0005433450090	30329	Economy	3700.00
0005433449991	30329	Economy	3700.00
0005432693078	30329	Economy	3700.00
0005432693081	30329	Economy	3700.00
0005432693062	30329	Economy	3700.00
0005432692985	30329	Economy	3700.00
0005433450030	30329	Economy	3700.00
0005432693097	30329	Economy	3700.00
0005432693091	30329	Economy	3700.00
0005433449985	30329	Economy	3700.00
0005432693072	30329	Economy	3700.00
0005433450031	30329	Economy	3700.00
0005432692936	30329	Economy	3700.00
0005433450088	30329	Economy	3700.00
0005432693066	30329	Economy	3700.00
0005432693080	30329	Economy	3700.00
0005433450087	30329	Economy	3700.00
0005433450021	30329	Economy	3700.00
0005433449986	30329	Economy	3700.00
0005432693163	30329	Economy	3700.00
0005432693160	30329	Economy	3700.00
0005433450038	30329	Economy	3700.00
0005433449878	30329	Economy	3700.00
0005432721073	30330	Business	11100.00
0005432721117	30330	Business	11100.00
0005433123980	30330	Business	11100.00
0005433722290	30330	Economy	3700.00
0005432720995	30330	Economy	3700.00
0005432720994	30330	Economy	3700.00
0005433123985	30330	Economy	3700.00
0005433123865	30330	Economy	3700.00
0005433722289	30330	Economy	3700.00
0005433722288	30330	Economy	4100.00
0005433123973	30330	Economy	3700.00
0005432720970	30330	Economy	3700.00
0005432721005	30330	Economy	3700.00
0005433123979	30330	Economy	3700.00
0005432720999	30330	Economy	3700.00
0005433722285	30330	Economy	3700.00
0005433722284	30330	Economy	3700.00
0005432721019	30330	Economy	3700.00
0005432720934	30330	Economy	3700.00
0005433123986	30330	Economy	3700.00
0005433722293	30330	Economy	3700.00
0005432721016	30330	Economy	3700.00
0005433722286	30330	Economy	3700.00
0005432720935	30330	Economy	3700.00
0005433123878	30330	Economy	3700.00
0005433123906	30330	Economy	3700.00
0005432720988	30330	Economy	3700.00
0005433722291	30330	Economy	3700.00
0005432721015	30330	Economy	3700.00
0005432720913	30330	Economy	3700.00
0005432721116	30330	Economy	3700.00
0005432721018	30330	Economy	3700.00
0005433123936	30330	Economy	3700.00
0005433123827	30330	Economy	3700.00
0005433123881	30330	Economy	3700.00
0005432720969	30330	Economy	3700.00
0005433124000	30330	Economy	3700.00
0005432721017	30330	Economy	3700.00
0005432721004	30330	Economy	3700.00
0005433722292	30330	Economy	3700.00
0005433722287	30330	Economy	3700.00
0005434586872	1352	Business	70400.00
0005434586887	1352	Business	70400.00
0005433724851	1352	Business	70400.00
0005433193080	1352	Business	70400.00
0005433193078	1352	Business	70400.00
0005433525152	1352	Business	70400.00
0005433193098	1352	Business	70400.00
0005434586883	1352	Business	70400.00
0005432928002	1352	Business	70400.00
0005432271035	1352	Business	70400.00
0005433525154	1352	Economy	23500.00
0005433525153	1352	Economy	23500.00
0005432927990	1352	Economy	23500.00
0005433525156	1352	Economy	23500.00
0005432927988	1352	Economy	23500.00
0005434586890	1352	Economy	23500.00
0005433193092	1352	Economy	23500.00
0005433193134	1352	Economy	23500.00
0005434586889	1352	Economy	23500.00
0005434586893	1352	Economy	23500.00
0005434586873	1352	Economy	25800.00
0005433525150	1352	Economy	25800.00
0005433193097	1352	Economy	25800.00
0005432271034	1352	Economy	25800.00
0005434513608	1352	Economy	23500.00
0005432927994	1352	Economy	23500.00
0005433525155	1352	Economy	23500.00
0005434586885	1352	Economy	23500.00
0005433525147	1352	Economy	23500.00
0005434586877	1352	Economy	23500.00
0005434586888	1352	Economy	23500.00
0005433193083	1352	Economy	23500.00
0005433193096	1352	Economy	23500.00
0005433193075	1352	Economy	23500.00
0005432271036	1352	Economy	23500.00
0005433193093	1352	Economy	23500.00
0005432271033	1352	Economy	23500.00
0005434586871	1352	Economy	23500.00
0005433193086	1352	Economy	23500.00
0005434586870	1352	Economy	23500.00
0005434586869	1352	Economy	23500.00
0005434586881	1352	Economy	23500.00
0005434586880	1352	Economy	23500.00
0005434586875	1352	Economy	23500.00
0005433193079	1352	Economy	23500.00
0005434586874	1352	Economy	23500.00
0005434586891	1352	Economy	23500.00
0005433193032	1352	Economy	23500.00
0005433193145	1352	Economy	23500.00
0005434586867	1352	Economy	23500.00
0005434586892	1352	Economy	23500.00
0005434513606	1352	Economy	23500.00
0005434586876	1352	Economy	23500.00
0005433193081	1352	Economy	23500.00
0005433724854	1352	Economy	23500.00
0005434513607	1352	Economy	23500.00
0005434514995	1352	Economy	23500.00
0005434586884	1352	Economy	23500.00
0005432927993	1352	Economy	23500.00
0005432928010	1352	Economy	23500.00
0005434586868	1352	Economy	23500.00
0005433525149	1352	Economy	23500.00
0005433193091	1352	Economy	23500.00
0005433193147	1352	Economy	23500.00
0005432927986	1352	Economy	23500.00
0005434586878	1352	Economy	23500.00
0005434514994	1352	Economy	23500.00
0005433525151	1352	Economy	23500.00
0005432927987	1352	Economy	23500.00
0005434586882	1352	Economy	23500.00
0005433724852	1352	Economy	23500.00
0005433193084	1352	Economy	23500.00
0005433193144	1352	Economy	23500.00
0005433193045	1352	Economy	23500.00
0005434586886	1352	Economy	23500.00
0005433724855	1352	Economy	23500.00
0005434586879	1352	Economy	23500.00
0005433525148	1352	Economy	23500.00
0005433525157	1352	Economy	23500.00
0005433192968	1352	Economy	23500.00
0005433724853	1352	Economy	23500.00
0005434514973	18538	Business	70400.00
0005432928036	18538	Business	70400.00
0005433193190	18538	Business	70400.00
0005433525069	18538	Economy	23500.00
0005432928038	18538	Economy	23500.00
0005433193187	18538	Economy	23500.00
0005433525040	18538	Economy	23500.00
0005434514972	18538	Economy	23500.00
0005434586656	18538	Economy	23500.00
0005433193191	18538	Economy	23500.00
0005433193179	18538	Economy	23500.00
0005433525052	18538	Economy	23500.00
0005434586732	18538	Economy	23500.00
0005433724823	18538	Economy	23500.00
0005433525074	18538	Economy	23500.00
0005432968864	18538	Economy	23500.00
0005434586769	18538	Economy	23500.00
0005432928035	18538	Economy	23500.00
0005433193182	18538	Economy	23500.00
0005434586730	18538	Economy	23500.00
0005433525044	18538	Economy	23500.00
0005434586681	18538	Economy	23500.00
0005433525068	18538	Economy	23500.00
0005434586691	18538	Economy	23500.00
0005434586675	18538	Economy	23500.00
0005433193183	18538	Economy	23500.00
0005433525060	18538	Economy	23500.00
0005432928037	18538	Economy	23500.00
0005433193180	18538	Economy	23500.00
0005433193189	18538	Economy	23500.00
0005433193186	18538	Economy	23500.00
0005432928034	18538	Economy	23500.00
0005432928039	18538	Economy	23500.00
0005433193185	18538	Economy	23500.00
0005433193188	18538	Economy	23500.00
0005433525042	18538	Economy	23500.00
0005433724821	18538	Economy	23500.00
0005433724812	18538	Economy	23500.00
0005434586676	18538	Economy	23500.00
0005434586700	18538	Economy	23500.00
0005434586642	18538	Economy	23500.00
0005434514954	18538	Economy	23500.00
0005433193184	18538	Economy	23500.00
0005433193181	18538	Economy	23500.00
0005434344565	11426	Economy	4300.00
0005434142652	11426	Economy	4300.00
0005434344557	11426	Economy	4300.00
0005434344534	11426	Economy	4000.00
0005434142653	11426	Economy	4000.00
0005434344536	11426	Economy	4000.00
0005434344543	11426	Economy	4000.00
0005434344550	11426	Economy	4000.00
0005434344560	11426	Economy	4000.00
0005435305018	11426	Economy	4000.00
0005434344562	11426	Economy	4000.00
0005434344555	11426	Economy	4000.00
0005434344564	11426	Economy	4000.00
0005434344553	11426	Economy	4000.00
0005434344540	11426	Economy	4000.00
0005434142651	11426	Economy	4000.00
0005434344539	11426	Economy	4000.00
0005434344548	11426	Economy	4000.00
0005434344559	11426	Economy	4000.00
0005434344533	11426	Economy	4000.00
0005434344554	11426	Economy	4000.00
0005434344566	11426	Economy	4000.00
0005434344544	11426	Economy	4000.00
0005434344545	11426	Economy	4000.00
0005434344558	11426	Economy	4000.00
0005434344541	11426	Economy	4000.00
0005434344538	11426	Economy	4000.00
0005434344563	11426	Economy	4000.00
0005434344537	11426	Economy	4000.00
0005434344546	11426	Economy	4000.00
0005434344549	11426	Economy	4000.00
0005434344535	11426	Economy	4000.00
0005434344561	11426	Economy	4000.00
0005434344551	11426	Economy	4000.00
0005434142650	11426	Economy	4000.00
0005434344547	11426	Economy	4000.00
0005434344542	11426	Economy	4000.00
0005435305012	11426	Economy	4000.00
0005434344552	11426	Economy	4000.00
0005434344556	11426	Economy	4000.00
0005434344281	29785	Economy	4300.00
0005435304207	29785	Economy	4300.00
0005434344249	29785	Economy	4300.00
0005434344178	29785	Economy	4000.00
0005435304208	29785	Economy	4000.00
0005434344270	29785	Economy	4000.00
0005434344142	29785	Economy	4000.00
0005434142615	29785	Economy	4000.00
0005434344276	29785	Economy	4000.00
0005434344235	29785	Economy	4000.00
0005434344301	29785	Economy	4000.00
0005434344205	29785	Economy	4000.00
0005435304205	29785	Economy	4000.00
0005434142619	29785	Economy	4000.00
0005434344362	29785	Economy	4000.00
0005434344187	29785	Economy	4000.00
0005434344267	29785	Economy	4000.00
0005434344275	29785	Economy	4000.00
0005434344274	29785	Economy	4000.00
0005434344278	29785	Economy	4000.00
0005434344363	29785	Economy	4000.00
0005434142611	29785	Economy	4000.00
0005434344179	29785	Economy	4000.00
0005434344258	29785	Economy	4000.00
0005434344340	29785	Economy	4000.00
0005434142618	29785	Economy	4000.00
0005434142625	29785	Economy	4000.00
0005434344250	29785	Economy	4000.00
0005434344254	29785	Economy	4000.00
0005434344096	29785	Economy	4000.00
0005434344302	29785	Economy	4000.00
0005434344262	29785	Economy	4000.00
0005434344277	29785	Economy	4000.00
0005435304203	29785	Economy	4000.00
0005434344341	29785	Economy	4000.00
0005435304204	29785	Economy	4000.00
0005434344193	29785	Economy	4000.00
0005435305035	29785	Economy	4000.00
0005435304206	29785	Economy	4000.00
0005434344400	29785	Economy	4000.00
0005434344392	29785	Economy	4000.00
0005435824899	1305	Business	199800.00
0005433415758	1305	Business	199800.00
0005435824916	1305	Business	199800.00
0005435824894	1305	Business	199800.00
0005433415662	1305	Business	199800.00
0005433415761	1305	Business	199800.00
0005435824901	1305	Business	199800.00
0005435824903	1305	Economy	66600.00
0005432284589	1305	Economy	66600.00
0005432284591	1305	Economy	66600.00
0005435824907	1305	Economy	66600.00
0005435824920	1305	Economy	66600.00
0005433415702	1305	Economy	66600.00
0005433415701	1305	Economy	66600.00
0005435824915	1305	Economy	66600.00
0005435824893	1305	Economy	66600.00
0005435824917	1305	Economy	66600.00
0005435824904	1305	Economy	66600.00
0005432284588	1305	Economy	66600.00
0005435824900	1305	Economy	66600.00
0005435824902	1305	Economy	66600.00
0005435824913	1305	Economy	66600.00
0005435824919	1305	Economy	66600.00
0005435824911	1305	Economy	66600.00
0005435824909	1305	Economy	66600.00
0005435824914	1305	Economy	66600.00
0005432284590	1305	Economy	66600.00
0005435824908	1305	Economy	66600.00
0005435824896	1305	Economy	66600.00
0005435824918	1305	Economy	66600.00
0005435824905	1305	Economy	66600.00
0005435824898	1305	Economy	66600.00
0005433415648	1305	Economy	66600.00
0005435824897	1305	Economy	66600.00
0005435824912	1305	Economy	66600.00
0005433415749	1305	Economy	66600.00
0005435824910	1305	Economy	66600.00
0005435824895	1305	Economy	66600.00
0005435824906	1305	Economy	66600.00
0005435824644	17996	Business	199800.00
0005435824757	17996	Business	199800.00
0005433415827	17996	Business	199800.00
0005433415819	17996	Business	199800.00
0005435824645	17996	Business	199800.00
0005433415825	17996	Business	199800.00
0005435824599	17996	Business	199800.00
0005433415834	17996	Business	199800.00
0005435824631	17996	Economy	66600.00
0005435824745	17996	Economy	66600.00
0005435824797	17996	Economy	66600.00
0005435824597	17996	Economy	66600.00
0005433415823	17996	Economy	66600.00
0005433415824	17996	Economy	66600.00
0005435824705	17996	Economy	73200.00
0005435824638	17996	Economy	66600.00
0005433415826	17996	Economy	66600.00
0005433415832	17996	Economy	66600.00
0005435824676	17996	Economy	66600.00
0005435824659	17996	Economy	66600.00
0005435824654	17996	Economy	66600.00
0005433415820	17996	Economy	66600.00
0005433415821	17996	Economy	66600.00
0005433415833	17996	Economy	66600.00
0005435824758	17996	Economy	66600.00
0005435824707	17996	Economy	66600.00
0005435824708	17996	Economy	66600.00
0005433415818	17996	Economy	66600.00
0005435824657	17996	Economy	66600.00
0005435824643	17996	Economy	66600.00
0005435824585	17996	Economy	66600.00
0005435824697	17996	Economy	66600.00
0005433415831	17996	Economy	66600.00
0005433415828	17996	Economy	66600.00
0005435824608	17996	Economy	66600.00
0005433415829	17996	Economy	66600.00
0005433415822	17996	Economy	66600.00
0005435824573	17996	Economy	66600.00
0005435824598	17996	Economy	66600.00
0005435824756	17996	Economy	66600.00
0005433415830	17996	Economy	66600.00
0005435824627	17996	Economy	66600.00
0005435824851	17996	Economy	66600.00
0005435824634	17996	Economy	66600.00
0005434460503	17527	Economy	14800.00
0005434462788	17527	Economy	13500.00
0005434462794	17527	Economy	13500.00
0005434460495	17527	Economy	13500.00
0005434460496	17527	Economy	13500.00
0005434460502	17527	Economy	13500.00
0005434462792	17527	Economy	13500.00
0005434462790	17527	Economy	13500.00
0005434462784	17527	Economy	13500.00
0005434462791	17527	Economy	13500.00
0005434462793	17527	Economy	13500.00
0005434462787	17527	Economy	13500.00
0005435242883	5627	Business	27800.00
0005432784337	5627	Business	27800.00
0005435242927	5627	Business	27800.00
0005432784336	5627	Business	27800.00
0005432784368	5627	Business	27800.00
0005432784349	5627	Business	27800.00
0005435242918	5627	Business	27800.00
0005432784356	5627	Business	27800.00
0005432784351	5627	Business	27800.00
0005432784380	5627	Business	27800.00
0005432784377	5627	Business	27800.00
0005435242917	5627	Business	27800.00
0005435242885	5627	Economy	9300.00
0005432784333	5627	Economy	9300.00
0005432784369	5627	Economy	9300.00
0005432784362	5627	Economy	9300.00
0005435242953	5627	Economy	9300.00
0005435242882	5627	Economy	9300.00
0005432784348	5627	Economy	9300.00
0005435242808	5627	Economy	9300.00
0005435242938	5627	Economy	9300.00
0005435242884	5627	Economy	9300.00
0005432784355	5627	Economy	10200.00
0005435476749	5627	Economy	10200.00
0005432784376	5627	Economy	10200.00
0005432784354	5627	Economy	10200.00
0005435242856	5627	Economy	10200.00
0005432784345	5627	Economy	9300.00
0005435242945	5627	Economy	9300.00
0005432784381	5627	Economy	9300.00
0005432784331	5627	Economy	9300.00
0005435242911	5627	Economy	9300.00
0005435242890	5627	Economy	9300.00
0005432144020	5627	Economy	9300.00
0005432784343	5627	Economy	9300.00
0005432784328	5627	Economy	9300.00
0005432784361	5627	Economy	9300.00
0005432784357	5627	Economy	9300.00
0005435476763	5627	Economy	9300.00
0005432784372	5627	Economy	9300.00
0005432784364	5627	Economy	9300.00
0005432784374	5627	Economy	9300.00
0005435476757	5627	Economy	9300.00
0005435242849	5627	Economy	9300.00
0005432784341	5627	Economy	9300.00
0005435242861	5627	Economy	9300.00
0005435242915	5627	Economy	9300.00
0005435242941	5627	Economy	9300.00
0005432144021	5627	Economy	9300.00
0005435242857	5627	Economy	9300.00
0005432784378	5627	Economy	9300.00
0005432784359	5627	Economy	9300.00
0005432784340	5627	Economy	9300.00
0005432784330	5627	Economy	9300.00
0005432784358	5627	Economy	9300.00
0005432784365	5627	Economy	9300.00
0005435242854	5627	Economy	9300.00
0005432784375	5627	Economy	9300.00
0005435242720	5627	Economy	9300.00
0005435242937	5627	Economy	9300.00
0005432784342	5627	Economy	9300.00
0005432144022	5627	Economy	9300.00
0005435242870	5627	Economy	9300.00
0005432784363	5627	Economy	9300.00
0005432784371	5627	Economy	9300.00
0005432784373	5627	Economy	9300.00
0005435476756	5627	Economy	9300.00
0005432784353	5627	Economy	9300.00
0005432784360	5627	Economy	9300.00
0005435242940	5627	Economy	9300.00
0005432784379	5627	Economy	9300.00
0005432784329	5627	Economy	9300.00
0005432784339	5627	Economy	9300.00
0005432784332	5627	Economy	9300.00
0005432784352	5627	Economy	9300.00
0005432784326	5627	Economy	9300.00
0005435242999	5627	Economy	9300.00
0005432784347	5627	Economy	9300.00
0005432784327	5627	Economy	9300.00
0005432784338	5627	Economy	9300.00
0005435242721	5627	Economy	9300.00
0005435242923	5627	Economy	9300.00
0005435242855	5627	Economy	9300.00
0005435242905	5627	Economy	9300.00
0005432784335	5627	Economy	9300.00
0005432784350	5627	Economy	9300.00
0005432784367	5627	Economy	9300.00
0005435242891	5627	Economy	9300.00
0005435242922	5627	Economy	9300.00
0005432784346	5627	Economy	9300.00
0005435242873	5627	Economy	9300.00
0005435242962	5627	Economy	9300.00
0005432784344	5627	Economy	9300.00
0005432784370	5627	Economy	9300.00
0005435242989	5627	Economy	9300.00
0005432784334	5627	Economy	9300.00
0005432784366	5627	Economy	9300.00
0005435243128	15336	Business	27800.00
0005435243121	15336	Business	27800.00
0005432783849	15336	Business	27800.00
0005435476830	15336	Business	27800.00
0005432783713	15336	Business	27800.00
0005435243126	15336	Business	27800.00
0005435243107	15336	Business	27800.00
0005432783778	15336	Business	27800.00
0005435243115	15336	Business	27800.00
0005435243103	15336	Business	27800.00
0005435243109	15336	Business	27800.00
0005435243127	15336	Economy	9300.00
0005435476832	15336	Economy	9300.00
0005435243114	15336	Economy	9300.00
0005432784049	15336	Economy	9300.00
0005432783888	15336	Economy	9300.00
0005432783897	15336	Economy	9300.00
0005432783948	15336	Economy	9300.00
0005435476827	15336	Economy	9300.00
0005432783668	15336	Economy	9300.00
0005435476828	15336	Economy	9300.00
0005432783887	15336	Economy	10200.00
0005435476837	15336	Economy	10200.00
0005435243118	15336	Economy	10200.00
0005432783702	15336	Economy	9300.00
0005432783780	15336	Economy	9300.00
0005435476831	15336	Economy	9300.00
0005432783848	15336	Economy	9300.00
0005435476834	15336	Economy	9300.00
0005435243116	15336	Economy	9300.00
0005432783553	15336	Economy	9300.00
0005432783855	15336	Economy	9300.00
0005435243113	15336	Economy	9300.00
0005432783735	15336	Economy	9300.00
0005435243105	15336	Economy	9300.00
0005432783928	15336	Economy	9300.00
0005435243123	15336	Economy	9300.00
0005435243117	15336	Economy	9300.00
0005432783941	15336	Economy	9300.00
0005432783906	15336	Economy	9300.00
0005432783994	15336	Economy	9300.00
0005432783714	15336	Economy	9300.00
0005435243122	15336	Economy	9300.00
0005432783926	15336	Economy	9300.00
0005435243111	15336	Economy	9300.00
0005435243125	15336	Economy	9300.00
0005432783995	15336	Economy	9300.00
0005435476833	15336	Economy	9300.00
0005432783779	15336	Economy	9300.00
0005432783929	15336	Economy	9300.00
0005432784003	15336	Economy	9300.00
0005435243104	15336	Economy	9300.00
0005435476829	15336	Economy	9300.00
0005435243112	15336	Economy	9300.00
0005435243124	15336	Economy	9300.00
0005432783988	15336	Economy	9300.00
0005435243119	15336	Economy	9300.00
0005435476838	15336	Economy	9300.00
0005432783667	15336	Economy	9300.00
0005435243106	15336	Economy	9300.00
0005435476835	15336	Economy	9300.00
0005432783678	15336	Economy	9300.00
0005435243108	15336	Economy	9300.00
0005432783583	15336	Economy	9300.00
0005435243110	15336	Economy	9300.00
0005432783949	15336	Economy	9300.00
0005435243120	15336	Economy	9300.00
0005435476836	15336	Economy	9300.00
0005432783952	15336	Economy	9300.00
0005432783927	15336	Economy	9300.00
0005432783942	15336	Economy	9300.00
0005432783898	15336	Economy	9300.00
0005435850930	4389	Economy	7000.00
0005435850952	4389	Economy	7000.00
0005432848460	4389	Economy	7000.00
0005434462812	4389	Economy	6300.00
0005432848463	4389	Economy	6300.00
0005435850893	4389	Economy	6300.00
0005432848470	4389	Economy	6300.00
0005432848459	4389	Economy	6300.00
0005434463953	4389	Economy	6300.00
0005434462813	4389	Economy	6300.00
0005435850928	4389	Economy	6300.00
0005432848468	4389	Economy	6300.00
0005435850894	4389	Economy	6300.00
0005432848458	4389	Economy	6300.00
0005432848464	4389	Economy	6300.00
0005434463952	4389	Economy	6300.00
0005434462814	4389	Economy	6300.00
0005432848462	4389	Economy	6300.00
0005435850951	4389	Economy	6300.00
0005435850937	4389	Economy	6300.00
0005432848461	4389	Economy	6300.00
0005432848467	4389	Economy	6300.00
0005432848457	4389	Economy	6300.00
0005432848469	4389	Economy	6300.00
0005435850916	4389	Economy	6300.00
0005435850935	4389	Economy	6300.00
0005435850943	4389	Economy	6300.00
0005435850927	4389	Economy	6300.00
0005432848465	4389	Economy	6300.00
0005432848466	4389	Economy	6300.00
0005435850915	4389	Economy	6300.00
0005435850917	4389	Economy	6300.00
0005435850936	4389	Economy	6300.00
0005432848328	28878	Economy	6300.00
0005434463939	28878	Economy	6300.00
0005434461653	28878	Economy	6300.00
0005432848339	28878	Economy	6300.00
0005432848292	28878	Economy	6300.00
0005435851006	28878	Economy	6300.00
0005432848341	28878	Economy	6300.00
0005434463925	28878	Economy	6300.00
0005435851005	28878	Economy	6300.00
0005435851001	28878	Economy	6300.00
0005435851002	28878	Economy	6300.00
0005435851010	28878	Economy	6300.00
0005432848338	28878	Economy	6300.00
0005434463935	28878	Economy	6300.00
0005432848282	28878	Economy	6300.00
0005435851008	28878	Economy	6300.00
0005432848320	28878	Economy	6300.00
0005432848343	28878	Economy	6300.00
0005432848340	28878	Economy	6300.00
0005435851009	28878	Economy	6300.00
0005432848326	28878	Economy	6300.00
0005435851003	28878	Economy	6300.00
0005434463934	28878	Economy	6300.00
0005435851004	28878	Economy	6300.00
0005435851007	28878	Economy	6300.00
0005432848327	28878	Economy	6300.00
0005434926159	6269	Business	11900.00
0005433497294	6269	Business	11900.00
0005433497284	6269	Business	11900.00
0005434926154	6269	Business	11900.00
0005432075266	6269	Business	11900.00
0005434926164	6269	Business	11900.00
0005434926143	6269	Business	11900.00
0005433497293	6269	Business	11900.00
0005434443880	6269	Business	11900.00
0005434443877	6269	Economy	4000.00
0005433497311	6269	Economy	4000.00
0005434443879	6269	Economy	4000.00
0005434443882	6269	Economy	4000.00
0005434926153	6269	Economy	4000.00
0005433497313	6269	Economy	4000.00
0005434926137	6269	Economy	4000.00
0005433497301	6269	Economy	4000.00
0005433497302	6269	Economy	4000.00
0005434443886	6269	Economy	4400.00
0005434443873	6269	Economy	4400.00
0005434926139	6269	Economy	4400.00
0005434926141	6269	Economy	4400.00
0005434443881	6269	Economy	4400.00
0005434926163	6269	Economy	4000.00
0005433497285	6269	Economy	4000.00
0005433497307	6269	Economy	4000.00
0005434926161	6269	Economy	4000.00
0005433497288	6269	Economy	4000.00
0005433497287	6269	Economy	4000.00
0005434926149	6269	Economy	4000.00
0005434443885	6269	Economy	4000.00
0005433497291	6269	Economy	4000.00
0005434926136	6269	Economy	4000.00
0005434443871	6269	Economy	4000.00
0005434926144	6269	Economy	4000.00
0005433497283	6269	Economy	4000.00
0005434926138	6269	Economy	4000.00
0005433497282	6269	Economy	4000.00
0005434926147	6269	Economy	4000.00
0005434443884	6269	Economy	4000.00
0005434926162	6269	Economy	4000.00
0005434443872	6269	Economy	4000.00
0005434926155	6269	Economy	4000.00
0005433497292	6269	Economy	4000.00
0005434443874	6269	Economy	4000.00
0005433497305	6269	Economy	4000.00
0005433497297	6269	Economy	4000.00
0005433497299	6269	Economy	4000.00
0005433497289	6269	Economy	4000.00
0005434926156	6269	Economy	4000.00
0005434926146	6269	Economy	4000.00
0005434926152	6269	Economy	4000.00
0005434926140	6269	Economy	4000.00
0005434926151	6269	Economy	4000.00
0005433497303	6269	Economy	4000.00
0005434443878	6269	Economy	4000.00
0005434926145	6269	Economy	4000.00
0005434926165	6269	Economy	4000.00
0005434926142	6269	Economy	4000.00
0005434926158	6269	Economy	4000.00
0005434443875	6269	Economy	4000.00
0005433497298	6269	Economy	4000.00
0005433497312	6269	Economy	4000.00
0005434443870	6269	Economy	4000.00
0005434443876	6269	Economy	4000.00
0005434926148	6269	Economy	4000.00
0005433497300	6269	Economy	4000.00
0005433497306	6269	Economy	4000.00
0005434926160	6269	Economy	4000.00
0005432075265	6269	Economy	4000.00
0005433497296	6269	Economy	4000.00
0005432075268	6269	Economy	4000.00
0005433497286	6269	Economy	4000.00
0005433497304	6269	Economy	4000.00
0005433497308	6269	Economy	4000.00
0005433497295	6269	Economy	4000.00
0005434443883	6269	Economy	4000.00
0005433497290	6269	Economy	4000.00
0005432075267	6269	Economy	4000.00
0005434926150	6269	Economy	4000.00
0005433497309	6269	Economy	4000.00
0005434926157	6269	Economy	4000.00
0005433497310	6269	Economy	4000.00
0005433496996	20339	Business	11900.00
0005433497112	20339	Business	11900.00
0005434925849	20339	Business	11900.00
0005434925818	20339	Business	11900.00
0005434925856	20339	Business	11900.00
0005434925797	20339	Business	11900.00
0005433497064	20339	Business	11900.00
0005433496985	20339	Business	11900.00
0005434443732	20339	Business	11900.00
0005434925808	20339	Business	11900.00
0005434443728	20339	Economy	4000.00
0005434925819	20339	Economy	4000.00
0005433497105	20339	Economy	4000.00
0005434925807	20339	Economy	4000.00
0005433496967	20339	Economy	4000.00
0005433496998	20339	Economy	4000.00
0005433497197	20339	Economy	4000.00
0005434925786	20339	Economy	4000.00
0005434925855	20339	Economy	4400.00
0005434443747	20339	Economy	4400.00
0005433496917	20339	Economy	4400.00
0005433497075	20339	Economy	4000.00
0005434925853	20339	Economy	4000.00
0005434925780	20339	Economy	4000.00
0005434443678	20339	Economy	4000.00
0005433497046	20339	Economy	4000.00
0005433497058	20339	Economy	4000.00
0005433497011	20339	Economy	4000.00
0005433496968	20339	Economy	4000.00
0005434443776	20339	Economy	4000.00
0005433497074	20339	Economy	4000.00
0005434925816	20339	Economy	4000.00
0005434925806	20339	Economy	4000.00
0005433497082	20339	Economy	4000.00
0005433497041	20339	Economy	4000.00
0005434925837	20339	Economy	4000.00
0005434925851	20339	Economy	4000.00
0005434443721	20339	Economy	4000.00
0005434925820	20339	Economy	4000.00
0005434443677	20339	Economy	4000.00
0005434443775	20339	Economy	4000.00
0005434443726	20339	Economy	4000.00
0005434925717	20339	Economy	4000.00
0005434443725	20339	Economy	4000.00
0005434925718	20339	Economy	4000.00
0005433497053	20339	Economy	4000.00
0005434443676	20339	Economy	4000.00
0005434443733	20339	Economy	4000.00
0005433496930	20339	Economy	4000.00
0005433496997	20339	Economy	4000.00
0005434925785	20339	Economy	4000.00
0005434443786	20339	Economy	4000.00
0005434925817	20339	Economy	4000.00
0005434925839	20339	Economy	4000.00
0005433497042	20339	Economy	4000.00
0005434925832	20339	Economy	4000.00
0005433496916	20339	Economy	4000.00
0005434925852	20339	Economy	4000.00
0005434925779	20339	Economy	4000.00
0005433497010	20339	Economy	4000.00
0005434925758	20339	Economy	4000.00
0005434443766	20339	Economy	4000.00
0005434443748	20339	Economy	4000.00
0005433497061	20339	Economy	4000.00
0005434925836	20339	Economy	4000.00
0005434925781	20339	Economy	4000.00
0005434925778	20339	Economy	4000.00
0005434925777	20339	Economy	4000.00
0005433496949	20339	Economy	4000.00
0005434443785	20339	Economy	4000.00
0005433497062	20339	Economy	4000.00
0005433497009	20339	Economy	4000.00
0005434925811	20339	Economy	4000.00
0005433496979	20339	Economy	4000.00
0005432783865	12169	Business	41200.00
0005432783873	12169	Business	41200.00
0005435243137	12169	Business	41200.00
0005432783623	12169	Business	41200.00
0005435243140	12169	Business	41200.00
0005432783758	12169	Business	41200.00
0005432783825	12169	Business	41200.00
0005432783624	12169	Business	41200.00
0005432784110	12169	Business	41200.00
0005432784060	12169	Business	41200.00
0005432783757	12169	Business	41200.00
0005432783749	12169	Business	41200.00
0005432783834	12169	Economy	13700.00
0005432784195	12169	Economy	13700.00
0005432783959	12169	Economy	13700.00
0005435243145	12169	Economy	13700.00
0005435243130	12169	Economy	13700.00
0005432783787	12169	Economy	13700.00
0005435243156	12169	Economy	13700.00
0005432784061	12169	Economy	13700.00
0005432783595	12169	Economy	13700.00
0005435243154	12169	Economy	13700.00
0005435243151	12169	Economy	15100.00
0005432784001	12169	Economy	15100.00
0005432783920	12169	Economy	15100.00
0005435243148	12169	Economy	15100.00
0005432784128	12169	Economy	15100.00
0005432783884	12169	Economy	13700.00
0005432784072	12169	Economy	13700.00
0005432783748	12169	Economy	13700.00
0005432783809	12169	Economy	13700.00
0005432783979	12169	Economy	13700.00
0005435243136	12169	Economy	13700.00
0005432783795	12169	Economy	13700.00
0005432784151	12169	Economy	13700.00
0005432783934	12169	Economy	13700.00
0005432784026	12169	Economy	13700.00
0005432783944	12169	Economy	13700.00
0005435243157	12169	Economy	13700.00
0005432783776	12169	Economy	13700.00
0005435243153	12169	Economy	13700.00
0005432783803	12169	Economy	13700.00
0005432783793	12169	Economy	13700.00
0005432783618	12169	Economy	13700.00
0005435243138	12169	Economy	13700.00
0005432783754	12169	Economy	13700.00
0005435243152	12169	Economy	13700.00
0005432783919	12169	Economy	13700.00
0005432783823	12169	Economy	13700.00
0005432783946	12169	Economy	13700.00
0005435243132	12169	Economy	13700.00
0005432783786	12169	Economy	13700.00
0005432784008	12169	Economy	13700.00
0005432783782	12169	Economy	13700.00
0005432783980	12169	Economy	13700.00
0005432783947	12169	Economy	13700.00
0005435243144	12169	Economy	13700.00
0005435243142	12169	Economy	13700.00
0005435243150	12169	Economy	13700.00
0005432783596	12169	Economy	13700.00
0005435243155	12169	Economy	13700.00
0005432783753	12169	Economy	13700.00
0005435243147	12169	Economy	13700.00
0005435243135	12169	Economy	13700.00
0005435243139	12169	Economy	13700.00
0005432784025	12169	Economy	13700.00
0005435243129	12169	Economy	13700.00
0005432783864	12169	Economy	13700.00
0005432784002	12169	Economy	13700.00
0005432783933	12169	Economy	13700.00
0005432783958	12169	Economy	13700.00
0005432783954	12169	Economy	13700.00
0005432783978	12169	Economy	13700.00
0005435243134	12169	Economy	13700.00
0005435243141	12169	Economy	13700.00
0005432784146	12169	Economy	13700.00
0005432783932	12169	Economy	13700.00
0005432783956	12169	Economy	13700.00
0005432783810	12169	Economy	13700.00
0005432783914	12169	Economy	13700.00
0005432783960	12169	Economy	13700.00
0005432783955	12169	Economy	13700.00
0005435243143	12169	Economy	13700.00
0005432783836	12169	Economy	13700.00
0005435243149	12169	Economy	13700.00
0005432784057	12169	Economy	13700.00
0005435243131	12169	Economy	13700.00
0005435243146	12169	Economy	13700.00
0005432783869	12169	Economy	13700.00
0005432783706	12169	Economy	13700.00
0005432783874	12169	Economy	13700.00
0005435243133	12169	Economy	13700.00
0005432783860	12169	Economy	13700.00
0005432784317	15438	Business	41200.00
0005432784323	15438	Business	41200.00
0005435242869	15438	Business	41200.00
0005432784305	15438	Business	41200.00
0005435242865	15438	Business	41200.00
0005432784324	15438	Business	41200.00
0005432784294	15438	Business	41200.00
0005432784277	15438	Business	41200.00
0005432784299	15438	Economy	13700.00
0005432784286	15438	Economy	13700.00
0005432784308	15438	Economy	13700.00
0005432784315	15438	Economy	13700.00
0005432784319	15438	Economy	13700.00
0005432784274	15438	Economy	13700.00
0005432784321	15438	Economy	13700.00
0005435242956	15438	Economy	13700.00
0005432784318	15438	Economy	13700.00
0005432784275	15438	Economy	13700.00
0005432784288	15438	Economy	15100.00
0005435242904	15438	Economy	15100.00
0005432784320	15438	Economy	15100.00
0005432784276	15438	Economy	15100.00
0005432784295	15438	Economy	13700.00
0005432784278	15438	Economy	13700.00
0005435242864	15438	Economy	13700.00
0005432784271	15438	Economy	13700.00
0005432784273	15438	Economy	13700.00
0005435242921	15438	Economy	13700.00
0005432784322	15438	Economy	13700.00
0005432784280	15438	Economy	13700.00
0005432784306	15438	Economy	13700.00
0005432784290	15438	Economy	13700.00
0005432784307	15438	Economy	13700.00
0005432784309	15438	Economy	13700.00
0005432784289	15438	Economy	13700.00
0005432784293	15438	Economy	13700.00
0005435242946	15438	Economy	13700.00
0005435242859	15438	Economy	13700.00
0005432784285	15438	Economy	13700.00
0005432784283	15438	Economy	13700.00
0005432784300	15438	Economy	13700.00
0005432784311	15438	Economy	13700.00
0005435242847	15438	Economy	13700.00
0005432784284	15438	Economy	13700.00
0005432784310	15438	Economy	13700.00
0005435242920	15438	Economy	13700.00
0005435242858	15438	Economy	13700.00
0005432784279	15438	Economy	13700.00
0005432784303	15438	Economy	13700.00
0005432784301	15438	Economy	13700.00
0005432784325	15438	Economy	13700.00
0005435242914	15438	Economy	13700.00
0005435242934	15438	Economy	13700.00
0005432784282	15438	Economy	13700.00
0005432784272	15438	Economy	13700.00
0005435242935	15438	Economy	13700.00
0005435242879	15438	Economy	13700.00
0005432784314	15438	Economy	13700.00
0005432784302	15438	Economy	13700.00
0005432784296	15438	Economy	13700.00
0005435242850	15438	Economy	13700.00
0005435242752	15438	Economy	13700.00
0005432784287	15438	Economy	13700.00
0005432784313	15438	Economy	13700.00
0005432784291	15438	Economy	13700.00
0005432784312	15438	Economy	13700.00
0005432784297	15438	Economy	13700.00
0005435242878	15438	Economy	13700.00
0005432784292	15438	Economy	13700.00
0005432784316	15438	Economy	13700.00
0005435242939	15438	Economy	13700.00
0005432784298	15438	Economy	13700.00
0005435242860	15438	Economy	13700.00
0005432784281	15438	Economy	13700.00
0005432784304	15438	Economy	13700.00
0005435242868	15438	Economy	13700.00
0005435242800	15438	Economy	13700.00
0005434878861	10081	Business	49700.00
0005434878470	10081	Business	49700.00
0005434878462	10081	Business	49700.00
0005434878229	10081	Business	49700.00
0005434758905	10081	Business	49700.00
0005434878506	10081	Business	49700.00
0005434878668	10081	Business	49700.00
0005434758900	10081	Business	49700.00
0005434878631	10081	Business	49700.00
0005434878505	10081	Business	49700.00
0005434878859	10081	Business	49700.00
0005434878732	10081	Business	49700.00
0005434878113	10081	Business	49700.00
0005434878488	10081	Business	49700.00
0005434878557	10081	Business	49700.00
0005434878355	10081	Business	49700.00
0005434878597	10081	Business	49700.00
0005434877829	10081	Business	49700.00
0005434878559	10081	Economy	16600.00
0005434878690	10081	Economy	16600.00
0005434878237	10081	Economy	16600.00
0005434878153	10081	Economy	16600.00
0005434878596	10081	Economy	16600.00
0005434878419	10081	Economy	16600.00
0005434878446	10081	Economy	16600.00
0005434878298	10081	Economy	16600.00
0005434878649	10081	Economy	16600.00
0005434878184	10081	Economy	16600.00
0005434878648	10081	Economy	16600.00
0005434878121	10081	Economy	16600.00
0005434878028	10081	Economy	18200.00
0005434878411	10081	Economy	18200.00
0005434878119	10081	Economy	16600.00
0005434877914	10081	Economy	18200.00
0005434878447	10081	Economy	16600.00
0005434878695	10081	Economy	16600.00
0005434878572	10081	Economy	16600.00
0005434878405	10081	Economy	16600.00
0005434878385	10081	Economy	16600.00
0005434878573	10081	Economy	16600.00
0005434878386	10081	Economy	16600.00
0005434878474	10081	Economy	16600.00
0005434878195	10081	Economy	16600.00
0005434878686	10081	Economy	16600.00
0005434878460	10081	Economy	16600.00
0005434878640	10081	Economy	16600.00
0005434877913	10081	Economy	16600.00
0005434878104	10081	Economy	16600.00
0005434878063	10081	Economy	16600.00
0005434878569	10081	Economy	16600.00
0005435913963	10081	Economy	16600.00
0005434878667	10081	Economy	16600.00
0005434878367	10081	Economy	16600.00
0005434877828	10081	Economy	16600.00
0005435913962	10081	Economy	16600.00
0005434878542	10081	Economy	16600.00
0005434878561	10081	Economy	16600.00
0005434878451	10081	Economy	16600.00
0005434878097	10081	Economy	16600.00
0005434878247	10081	Economy	16600.00
0005434878454	10081	Economy	16600.00
0005434878356	10081	Economy	16600.00
0005434878185	10081	Economy	16600.00
0005434878030	10081	Economy	16600.00
0005434878345	10081	Economy	16600.00
0005435913964	10081	Economy	16600.00
0005434878588	10081	Economy	16600.00
0005434878466	10081	Economy	16600.00
0005434878372	10081	Economy	16600.00
0005434878313	10081	Economy	16600.00
0005434878503	10081	Economy	16600.00
0005434758901	10081	Economy	16600.00
0005434878409	10081	Economy	16600.00
0005434878292	10081	Economy	16600.00
0005434878344	10081	Economy	16600.00
0005434878498	10081	Economy	16600.00
0005434878502	10081	Economy	16600.00
0005434878120	10081	Economy	16600.00
0005434878560	10081	Economy	16600.00
0005434878529	10081	Economy	16600.00
0005434878105	10081	Economy	16600.00
0005434878555	10081	Economy	16600.00
0005434878810	10081	Economy	16600.00
0005434878412	10081	Economy	16600.00
0005434878029	10081	Economy	16600.00
0005434878423	10081	Economy	16600.00
0005434878860	10081	Economy	16600.00
0005434878360	10081	Economy	16600.00
0005434878246	10081	Economy	16600.00
0005434878504	10081	Economy	16600.00
0005434878501	10081	Economy	16600.00
0005434878422	10081	Economy	16600.00
0005434878554	10081	Economy	16600.00
0005434878463	10081	Economy	16600.00
0005434878811	10081	Economy	16600.00
0005434878625	10081	Economy	16600.00
0005434910136	10081	Economy	16600.00
0005434878062	10081	Economy	16600.00
0005434878289	10081	Economy	16600.00
0005434878476	10081	Economy	16600.00
0005434878359	10081	Economy	16600.00
0005434878312	10081	Economy	16600.00
0005434877943	10081	Economy	16600.00
0005434879192	14603	Business	49700.00
0005434879174	14603	Business	49700.00
0005434879198	14603	Business	49700.00
0005434879222	14603	Business	49700.00
0005434879232	14603	Business	49700.00
0005434879218	14603	Business	49700.00
0005434879206	14603	Business	49700.00
0005434879167	14603	Business	49700.00
0005434758918	14603	Business	49700.00
0005434879207	14603	Business	49700.00
0005434879189	14603	Business	49700.00
0005434879178	14603	Business	49700.00
0005434879239	14603	Business	49700.00
0005434879226	14603	Business	49700.00
0005434879186	14603	Business	49700.00
0005434879210	14603	Business	49700.00
0005434879211	14603	Business	49700.00
0005434879200	14603	Economy	16600.00
0005434879185	14603	Economy	16600.00
0005434879182	14603	Economy	16600.00
0005434879181	14603	Economy	16600.00
0005434879188	14603	Economy	16600.00
0005434879157	14603	Economy	16600.00
0005434910105	14603	Economy	16600.00
0005434879158	14603	Economy	16600.00
0005434879240	14603	Economy	16600.00
0005434758917	14603	Economy	16600.00
0005434879215	14603	Economy	18200.00
0005434879208	14603	Economy	16600.00
0005434879191	14603	Economy	18200.00
0005434879237	14603	Economy	16600.00
0005434879221	14603	Economy	18200.00
0005434879225	14603	Economy	16600.00
0005434879220	14603	Economy	16600.00
0005434879162	14603	Economy	16600.00
0005434879209	14603	Economy	16600.00
0005434879155	14603	Economy	16600.00
0005434879219	14603	Economy	16600.00
0005434879172	14603	Economy	16600.00
0005434879204	14603	Economy	16600.00
0005434879199	14603	Economy	16600.00
0005434879180	14603	Economy	16600.00
0005434879171	14603	Economy	16600.00
0005434879248	14603	Economy	16600.00
0005434879176	14603	Economy	16600.00
0005434879159	14603	Economy	16600.00
0005434879156	14603	Economy	16600.00
0005435913933	14603	Economy	16600.00
0005434879154	14603	Economy	16600.00
0005434879201	14603	Economy	16600.00
0005434879242	14603	Economy	16600.00
0005434879195	14603	Economy	16600.00
0005434879179	14603	Economy	16600.00
0005434879193	14603	Economy	16600.00
0005434879216	14603	Economy	16600.00
0005434879153	14603	Economy	16600.00
0005434879169	14603	Economy	16600.00
0005434879238	14603	Economy	16600.00
0005434879161	14603	Economy	16600.00
0005434879196	14603	Economy	16600.00
0005434879175	14603	Economy	16600.00
0005434879235	14603	Economy	16600.00
0005434879183	14603	Economy	16600.00
0005434879203	14603	Economy	16600.00
0005434879187	14603	Economy	16600.00
0005434879213	14603	Economy	16600.00
0005434879243	14603	Economy	16600.00
0005434879246	14603	Economy	16600.00
0005434879173	14603	Economy	16600.00
0005434879229	14603	Economy	16600.00
0005434879194	14603	Economy	16600.00
0005434879233	14603	Economy	16600.00
0005434879224	14603	Economy	16600.00
0005434879165	14603	Economy	16600.00
0005434879228	14603	Economy	16600.00
0005435913932	14603	Economy	16600.00
0005434879230	14603	Economy	16600.00
0005434879231	14603	Economy	16600.00
0005434879227	14603	Economy	16600.00
0005434879197	14603	Economy	16600.00
0005434879190	14603	Economy	16600.00
0005434879164	14603	Economy	16600.00
0005434879160	14603	Economy	16600.00
0005434879247	14603	Economy	16600.00
0005434879244	14603	Economy	16600.00
0005434879217	14603	Economy	16600.00
0005434879184	14603	Economy	16600.00
0005434879234	14603	Economy	16600.00
0005434879223	14603	Economy	16600.00
0005434879245	14603	Economy	16600.00
0005434879241	14603	Economy	16600.00
0005434879205	14603	Economy	16600.00
0005434879236	14603	Economy	16600.00
0005434879214	14603	Economy	16600.00
0005434879163	14603	Economy	16600.00
0005434910106	14603	Economy	16600.00
0005434879177	14603	Economy	16600.00
0005434879168	14603	Economy	16600.00
0005434879166	14603	Economy	16600.00
0005434879212	14603	Economy	16600.00
0005435913937	14603	Economy	16600.00
0005434879202	14603	Economy	16600.00
0005435913931	14603	Economy	16600.00
0005434879170	14603	Economy	16600.00
0005435660251	9261	Economy	22400.00
0005435660250	9261	Economy	22400.00
0005434252022	9261	Economy	22400.00
0005435660257	9261	Economy	22400.00
0005435660256	9261	Economy	20300.00
0005435660253	9261	Economy	20300.00
0005434252000	9261	Economy	20300.00
0005434251991	9261	Economy	20300.00
0005434252023	9261	Economy	20300.00
0005434251999	9261	Economy	20300.00
0005435660259	9261	Economy	20300.00
0005435660252	9261	Economy	20300.00
0005435660249	9261	Economy	20300.00
0005434251992	9261	Economy	20300.00
0005435660255	9261	Economy	20300.00
0005435660248	9261	Economy	20300.00
0005435660258	9261	Economy	20300.00
0005435660254	9261	Economy	20300.00
0005435660178	24662	Economy	22400.00
0005435660133	24662	Economy	22400.00
0005435660152	24662	Economy	20300.00
0005434252059	24662	Economy	20300.00
0005434252060	24662	Economy	20300.00
0005435660128	24662	Economy	20300.00
0005435660127	24662	Economy	20300.00
0005435660153	24662	Economy	20300.00
0005435660183	24662	Economy	20300.00
0005434252064	24662	Economy	20300.00
0005435660182	24662	Economy	20300.00
0005434252062	24662	Economy	20300.00
0005434252063	24662	Economy	20300.00
0005434252061	24662	Economy	20300.00
0005435660192	24662	Economy	20300.00
0005434252067	24662	Economy	20300.00
0005434252065	24662	Economy	20300.00
0005434252066	24662	Economy	20300.00
0005435660101	24662	Economy	20300.00
0005433681071	2817	Business	33000.00
0005432966898	2817	Business	33000.00
0005432966909	2817	Business	33000.00
0005433681057	2817	Business	33000.00
0005432967064	2817	Business	33000.00
0005432966926	2817	Business	33000.00
0005432966956	2817	Business	33000.00
0005433681056	2817	Business	33000.00
0005433681042	2817	Business	33000.00
0005432222838	2817	Business	33000.00
0005432967043	2817	Economy	11000.00
0005432966990	2817	Economy	11000.00
0005433681072	2817	Economy	11000.00
0005433681054	2817	Economy	11000.00
0005433681029	2817	Economy	11000.00
0005432966892	2817	Economy	11000.00
0005433681076	2817	Economy	11000.00
0005433681067	2817	Economy	11000.00
0005432966959	2817	Economy	11000.00
0005432966897	2817	Economy	11000.00
0005432966975	2817	Economy	12100.00
0005433681053	2817	Economy	12100.00
0005433681045	2817	Economy	12100.00
0005433681037	2817	Economy	12100.00
0005432967042	2817	Economy	12100.00
0005432966925	2817	Economy	11000.00
0005433681039	2817	Economy	11000.00
0005433681074	2817	Economy	11000.00
0005433681070	2817	Economy	11000.00
0005432967044	2817	Economy	11000.00
0005433681040	2817	Economy	11000.00
0005432222837	2817	Economy	11000.00
0005433681036	2817	Economy	11000.00
0005433681035	2817	Economy	11000.00
0005433681069	2817	Economy	11000.00
0005432966923	2817	Economy	11000.00
0005433681032	2817	Economy	11000.00
0005433684439	2817	Economy	11000.00
0005433681059	2817	Economy	11000.00
0005433681062	2817	Economy	11000.00
0005433681038	2817	Economy	11000.00
0005433681049	2817	Economy	11000.00
0005432966976	2817	Economy	11000.00
0005433681048	2817	Economy	11000.00
0005432966910	2817	Economy	11000.00
0005433681031	2817	Economy	11000.00
0005433681047	2817	Economy	11000.00
0005433681055	2817	Economy	11000.00
0005432222834	2817	Economy	11000.00
0005432966960	2817	Economy	11000.00
0005433684441	2817	Economy	11000.00
0005433681033	2817	Economy	11000.00
0005433681052	2817	Economy	11000.00
0005433681078	2817	Economy	11000.00
0005433681064	2817	Economy	11000.00
0005432222836	2817	Economy	11000.00
0005433681058	2817	Economy	11000.00
0005433681068	2817	Economy	11000.00
0005433681044	2817	Economy	11000.00
0005432966933	2817	Economy	11000.00
0005432966924	2817	Economy	11000.00
0005433681077	2817	Economy	11000.00
0005432966939	2817	Economy	11000.00
0005432222835	2817	Economy	11000.00
0005433681075	2817	Economy	11000.00
0005432966945	2817	Economy	11000.00
0005432967045	2817	Economy	11000.00
0005433681030	2817	Economy	11000.00
0005433681063	2817	Economy	11000.00
0005433681065	2817	Economy	11000.00
0005433681043	2817	Economy	11000.00
0005433681034	2817	Economy	11000.00
0005433681041	2817	Economy	11000.00
0005432966880	2817	Economy	11000.00
0005432967008	2817	Economy	11000.00
0005432967007	2817	Economy	11000.00
0005433681066	2817	Economy	11000.00
0005433684440	2817	Economy	11000.00
0005433681060	2817	Economy	11000.00
0005433681046	2817	Economy	11000.00
0005432966891	2817	Economy	11000.00
0005433681050	2817	Economy	11000.00
0005432966974	2817	Economy	11000.00
0005432967046	2817	Economy	11000.00
0005433681061	2817	Economy	11000.00
0005433681073	2817	Economy	11000.00
0005433681051	2817	Economy	11000.00
0005432967063	2817	Economy	11000.00
0005432966918	2817	Economy	11000.00
0005433680718	29141	Business	33000.00
0005433680655	29141	Business	33000.00
0005433680906	29141	Business	33000.00
0005432967196	29141	Business	33000.00
0005433684430	29141	Business	33000.00
0005432967208	29141	Business	33000.00
0005432967189	29141	Business	33000.00
0005433680851	29141	Business	33000.00
0005433680684	29141	Business	33000.00
0005433680901	29141	Business	33000.00
0005432967190	29141	Business	33000.00
0005433680838	29141	Business	33000.00
0005433680907	29141	Economy	11000.00
0005433680685	29141	Economy	11000.00
0005432967204	29141	Economy	11000.00
0005433680877	29141	Economy	11000.00
0005432967191	29141	Economy	11000.00
0005433680722	29141	Economy	11000.00
0005433680704	29141	Economy	11000.00
0005432967192	29141	Economy	11000.00
0005433680943	29141	Economy	11000.00
0005433680755	29141	Economy	11000.00
0005433690928	29141	Economy	12100.00
0005433680683	29141	Economy	12100.00
0005433680873	29141	Economy	12100.00
0005432967198	29141	Economy	12100.00
0005433680713	29141	Economy	12100.00
0005433684429	29141	Economy	11000.00
0005432967201	29141	Economy	11000.00
0005433680648	29141	Economy	11000.00
0005433680616	29141	Economy	11000.00
0005432967206	29141	Economy	11000.00
0005433680908	29141	Economy	11000.00
0005433680799	29141	Economy	11000.00
0005433680638	29141	Economy	11000.00
0005433680430	29141	Economy	11000.00
0005432005243	29141	Economy	11000.00
0005433680593	29141	Economy	11000.00
0005433680629	29141	Economy	11000.00
0005433690937	29141	Economy	11000.00
0005433680545	29141	Economy	11000.00
0005433680876	29141	Economy	11000.00
0005433680547	29141	Economy	11000.00
0005433690934	29141	Economy	11000.00
0005432967209	29141	Economy	11000.00
0005432967205	29141	Economy	11000.00
0005432967199	29141	Economy	11000.00
0005433680663	29141	Economy	11000.00
0005433680681	29141	Economy	11000.00
0005433690925	29141	Economy	11000.00
0005433680428	29141	Economy	11000.00
0005433680800	29141	Economy	11000.00
0005433690926	29141	Economy	11000.00
0005433680623	29141	Economy	11000.00
0005433680900	29141	Economy	11000.00
0005433680892	29141	Economy	11000.00
0005433690927	29141	Economy	11000.00
0005432967187	29141	Economy	11000.00
0005432967210	29141	Economy	11000.00
0005433690938	29141	Economy	11000.00
0005432967197	29141	Economy	11000.00
0005433680751	29141	Economy	11000.00
0005432967188	29141	Economy	11000.00
0005432967200	29141	Economy	11000.00
0005433680726	29141	Economy	11000.00
0005433680624	29141	Economy	11000.00
0005432967193	29141	Economy	11000.00
0005433687714	29141	Economy	11000.00
0005433680546	29141	Economy	11000.00
0005433690933	29141	Economy	11000.00
0005432967207	29141	Economy	11000.00
0005433687701	29141	Economy	11000.00
0005432005241	29141	Economy	11000.00
0005433680808	29141	Economy	11000.00
0005433680721	29141	Economy	11000.00
0005433680852	29141	Economy	11000.00
0005433680542	29141	Economy	11000.00
0005433680429	29141	Economy	11000.00
0005433680687	29141	Economy	11000.00
0005433680839	29141	Economy	11000.00
0005433687702	29141	Economy	11000.00
0005433680628	29141	Economy	11000.00
0005433680627	29141	Economy	11000.00
0005433680966	29141	Economy	11000.00
0005433687713	29141	Economy	11000.00
0005433680717	29141	Economy	11000.00
0005433680543	29141	Economy	11000.00
0005432967194	29141	Economy	11000.00
0005433680965	29141	Economy	11000.00
0005432005242	29141	Economy	11000.00
0005432967202	29141	Economy	11000.00
0005432967203	29141	Economy	11000.00
0005433680843	29141	Economy	11000.00
0005433684433	29141	Economy	11000.00
0005432967195	29141	Economy	11000.00
0005432967186	29141	Economy	11000.00
0005433634132	9285	Business	132900.00
0005433577937	9285	Business	132900.00
0005433615366	9285	Business	132900.00
0005434163647	9285	Business	132900.00
0005433634144	9285	Business	132900.00
0005432145133	9285	Business	132900.00
0005434272196	9285	Business	132900.00
0005434163663	9285	Business	132900.00
0005433615358	9285	Business	132900.00
0005433615350	9285	Business	132900.00
0005433615370	9285	Business	132900.00
0005433634142	9285	Business	132900.00
0005433615360	9285	Business	132900.00
0005433577941	9285	Business	132900.00
0005433615354	9285	Business	132900.00
0005433634141	9285	Business	132900.00
0005433634127	9285	Business	132900.00
0005434163625	9285	Business	132900.00
0005434269110	9285	Business	132900.00
0005433615361	9285	Business	132900.00
0005432755107	9285	Business	132900.00
0005433634124	9285	Business	132900.00
0005433615374	9285	Business	132900.00
0005433634122	9285	Business	132900.00
0005433615401	9285	Economy	48700.00
0005433615339	9285	Economy	48700.00
0005433577942	9285	Economy	48700.00
0005433634133	9285	Economy	48700.00
0005433615385	9285	Economy	48700.00
0005433615383	9285	Economy	48700.00
0005433615373	9285	Economy	44300.00
0005433615334	9285	Economy	44300.00
0005433634151	9285	Economy	44300.00
0005433615392	9285	Economy	44300.00
0005433615341	9285	Economy	44300.00
0005432145130	9285	Economy	44300.00
0005433615406	9285	Economy	44300.00
0005433615343	9285	Economy	44300.00
0005433634135	9285	Economy	44300.00
0005434153538	9285	Economy	44300.00
0005433615345	9285	Economy	44300.00
0005433634129	9285	Economy	44300.00
0005433634149	9285	Economy	44300.00
0005433615376	9285	Economy	44300.00
0005434153531	9285	Economy	44300.00
0005433615405	9285	Economy	44300.00
0005433577945	9285	Economy	44300.00
0005434163622	9285	Economy	44300.00
0005433615384	9285	Economy	44300.00
0005433615387	9285	Economy	44300.00
0005432755110	9285	Economy	44300.00
0005433615364	9285	Economy	44300.00
0005433615396	9285	Economy	44300.00
0005433615390	9285	Economy	44300.00
0005432145131	9285	Economy	44300.00
0005433577947	9285	Economy	44300.00
0005433577950	9285	Economy	44300.00
0005433634126	9285	Economy	44300.00
0005433577949	9285	Economy	44300.00
0005433615333	9285	Economy	44300.00
0005433615357	9285	Economy	44300.00
0005433615368	9285	Economy	44300.00
0005433615344	9285	Economy	44300.00
0005434163623	9285	Economy	44300.00
0005433634150	9285	Economy	44300.00
0005433634123	9285	Economy	44300.00
0005433615379	9285	Economy	44300.00
0005433634121	9285	Economy	44300.00
0005434153537	9285	Economy	44300.00
0005433615338	9285	Economy	44300.00
0005433615397	9285	Economy	44300.00
0005433615340	9285	Economy	44300.00
0005432756880	9285	Economy	44300.00
0005432145132	9285	Economy	44300.00
0005434272197	9285	Economy	44300.00
0005433615386	9285	Economy	44300.00
0005433615404	9285	Economy	44300.00
0005434163610	9285	Economy	44300.00
0005434152789	9285	Economy	44300.00
0005434153532	9285	Economy	44300.00
0005433615342	9285	Economy	44300.00
0005433577946	9285	Economy	44300.00
0005433615352	9285	Economy	44300.00
0005432755109	9285	Economy	44300.00
0005433634131	9285	Economy	44300.00
0005433615369	9285	Economy	44300.00
0005432755111	9285	Economy	48700.00
0005433615380	9285	Economy	48700.00
0005433615389	9285	Economy	48700.00
0005433634138	9285	Economy	48700.00
0005433615375	9285	Economy	48700.00
0005433634148	9285	Economy	44300.00
0005433634136	9285	Economy	44300.00
0005433615351	9285	Economy	44300.00
0005433615371	9285	Economy	44300.00
0005433615355	9285	Economy	48700.00
0005433615402	9285	Economy	44300.00
0005433577944	9285	Economy	44300.00
0005433615353	9285	Economy	44300.00
0005433615398	9285	Economy	44300.00
0005434163649	9285	Economy	44300.00
0005434163655	9285	Economy	44300.00
0005432756881	9285	Economy	44300.00
0005433634152	9285	Economy	44300.00
0005433577939	9285	Economy	44300.00
0005433615349	9285	Economy	44300.00
0005433615400	9285	Economy	44300.00
0005433634153	9285	Economy	44300.00
0005433634143	9285	Economy	44300.00
0005433615381	9285	Economy	44300.00
0005433577938	9285	Economy	44300.00
0005433634137	9285	Economy	44300.00
0005434269106	9285	Economy	44300.00
0005433615335	9285	Economy	44300.00
0005433615346	9285	Economy	44300.00
0005433615337	9285	Economy	44300.00
0005432756882	9285	Economy	44300.00
0005433615388	9285	Economy	44300.00
0005433615356	9285	Economy	44300.00
0005433615378	9285	Economy	44300.00
0005434163666	9285	Economy	44300.00
0005433615348	9285	Economy	44300.00
0005433615365	9285	Economy	44300.00
0005433615363	9285	Economy	44300.00
0005433634140	9285	Economy	44300.00
0005432755108	9285	Economy	44300.00
0005434163638	9285	Economy	44300.00
0005433615391	9285	Economy	44300.00
0005433634134	9285	Economy	44300.00
0005433634154	9285	Economy	44300.00
0005433634128	9285	Economy	44300.00
0005433577948	9285	Economy	44300.00
0005433615367	9285	Economy	44300.00
0005433615362	9285	Economy	44300.00
0005433615403	9285	Economy	44300.00
0005433634145	9285	Economy	44300.00
0005434272195	9285	Economy	44300.00
0005433634125	9285	Economy	44300.00
0005433615395	9285	Economy	44300.00
0005433577940	9285	Economy	44300.00
0005433634147	9285	Economy	44300.00
0005433634139	9285	Economy	44300.00
0005433615399	9285	Economy	44300.00
0005434163648	9285	Economy	44300.00
0005433577943	9285	Economy	44300.00
0005433615359	9285	Economy	44300.00
0005434163665	9285	Economy	44300.00
0005433615377	9285	Economy	44300.00
0005433615394	9285	Economy	44300.00
0005433634130	9285	Economy	44300.00
0005434152788	9285	Economy	44300.00
0005433615347	9285	Economy	44300.00
0005433615393	9285	Economy	44300.00
0005433634146	9285	Economy	44300.00
0005433615372	9285	Economy	44300.00
0005433634120	9285	Economy	44300.00
0005433615336	9285	Economy	44300.00
0005434152787	9285	Economy	44300.00
0005433615382	9285	Economy	44300.00
0005433614675	25222	Business	132900.00
0005433614704	25222	Business	132900.00
0005433614702	25222	Business	132900.00
0005433614640	25222	Business	132900.00
0005434272208	25222	Business	132900.00
0005433633777	25222	Business	132900.00
0005433614869	25222	Business	132900.00
0005433614718	25222	Business	132900.00
0005433614901	25222	Business	132900.00
0005433577846	25222	Business	132900.00
0005433614902	25222	Business	132900.00
0005433614561	25222	Business	132900.00
0005433633790	25222	Business	132900.00
0005433633699	25222	Business	132900.00
0005433614725	25222	Business	132900.00
0005433615014	25222	Business	132900.00
0005433614555	25222	Business	132900.00
0005433633781	25222	Business	132900.00
0005433614519	25222	Business	132900.00
0005433577806	25222	Business	132900.00
0005433614464	25222	Business	132900.00
0005433633946	25222	Business	132900.00
0005433633780	25222	Business	132900.00
0005433614967	25222	Economy	48700.00
0005433614707	25222	Economy	48700.00
0005433614545	25222	Economy	48700.00
0005434163713	25222	Economy	48700.00
0005433633813	25222	Economy	48700.00
0005433614798	25222	Economy	44300.00
0005433615024	25222	Economy	44300.00
0005433614797	25222	Economy	44300.00
0005433633924	25222	Economy	44300.00
0005433614756	25222	Economy	44300.00
0005433577803	25222	Economy	44300.00
0005433614661	25222	Economy	44300.00
0005433577764	25222	Economy	44300.00
0005433614657	25222	Economy	44300.00
0005434273093	25222	Economy	44300.00
0005433633636	25222	Economy	44300.00
0005433614536	25222	Economy	44300.00
0005433615012	25222	Economy	44300.00
0005433614789	25222	Economy	44300.00
0005433614554	25222	Economy	44300.00
0005433614550	25222	Economy	44300.00
0005433633730	25222	Economy	44300.00
0005433577814	25222	Economy	44300.00
0005433634004	25222	Economy	44300.00
0005433615111	25222	Economy	44300.00
0005433614527	25222	Economy	44300.00
0005433614757	25222	Economy	44300.00
0005433633805	25222	Economy	44300.00
0005433614684	25222	Economy	44300.00
0005433614622	25222	Economy	44300.00
0005433614924	25222	Economy	44300.00
0005433614951	25222	Economy	44300.00
0005433614698	25222	Economy	44300.00
0005433614670	25222	Economy	44300.00
0005433614373	25222	Economy	44300.00
0005434163708	25222	Economy	44300.00
0005433577788	25222	Economy	44300.00
0005433615030	25222	Economy	44300.00
0005433633791	25222	Economy	44300.00
0005433633799	25222	Economy	44300.00
0005433614986	25222	Economy	44300.00
0005433615013	25222	Economy	44300.00
0005433614514	25222	Economy	44300.00
0005433633925	25222	Economy	44300.00
0005434163711	25222	Economy	44300.00
0005433577829	25222	Economy	44300.00
0005433614685	25222	Economy	44300.00
0005433614703	25222	Economy	44300.00
0005433614865	25222	Economy	44300.00
0005433614809	25222	Economy	44300.00
0005433615029	25222	Economy	44300.00
0005434163704	25222	Economy	44300.00
0005433614672	25222	Economy	44300.00
0005433633755	25222	Economy	44300.00
0005433633792	25222	Economy	48700.00
0005433633889	25222	Economy	44300.00
0005433614893	25222	Economy	48700.00
0005434163712	25222	Economy	48700.00
0005433614671	25222	Economy	48700.00
0005433614926	25222	Economy	48700.00
0005433633766	25222	Economy	44300.00
0005433614660	25222	Economy	44300.00
0005433633804	25222	Economy	48700.00
0005433614971	25222	Economy	44300.00
0005433614846	25222	Economy	44300.00
0005433633851	25222	Economy	44300.00
0005433614845	25222	Economy	44300.00
0005433614959	25222	Economy	44300.00
0005433633841	25222	Economy	44300.00
0005433633888	25222	Economy	44300.00
0005433614799	25222	Economy	44300.00
0005433614925	25222	Economy	44300.00
0005433634003	25222	Economy	44300.00
0005433614864	25222	Economy	44300.00
0005433614803	25222	Economy	44300.00
0005433577784	25222	Economy	44300.00
0005434163709	25222	Economy	44300.00
0005433633724	25222	Economy	44300.00
0005434272209	25222	Economy	44300.00
0005433614966	25222	Economy	44300.00
0005433614534	25222	Economy	44300.00
0005433577790	25222	Economy	44300.00
0005433615101	25222	Economy	44300.00
0005433615031	25222	Economy	44300.00
0005433614535	25222	Economy	44300.00
0005433614513	25222	Economy	44300.00
0005434163707	25222	Economy	44300.00
0005433614461	25222	Economy	44300.00
0005433577820	25222	Economy	44300.00
0005433633806	25222	Economy	44300.00
0005433577839	25222	Economy	44300.00
0005433614940	25222	Economy	44300.00
0005434163705	25222	Economy	44300.00
0005433633637	25222	Economy	44300.00
0005433577802	25222	Economy	44300.00
0005433614943	25222	Economy	44300.00
0005433633789	25222	Economy	44300.00
0005433633923	25222	Economy	44300.00
0005433614945	25222	Economy	44300.00
0005433615059	25222	Economy	44300.00
0005433633638	25222	Economy	44300.00
0005434163706	25222	Economy	44300.00
0005434273094	25222	Economy	44300.00
0005433614996	25222	Economy	44300.00
0005433614872	25222	Economy	44300.00
0005433614701	25222	Economy	44300.00
0005433614706	25222	Economy	44300.00
0005433614518	25222	Economy	44300.00
0005433614788	25222	Economy	44300.00
0005433614674	25222	Economy	44300.00
0005433614866	25222	Economy	44300.00
0005433614717	25222	Economy	44300.00
0005434163714	25222	Economy	44300.00
0005433633842	25222	Economy	44300.00
0005433615107	25222	Economy	44300.00
0005434163710	25222	Economy	44300.00
0005435856205	4211	Business	193100.00
0005435947205	4211	Business	193100.00
0005435986832	4211	Business	193100.00
0005435947274	4211	Business	193100.00
0005432571334	4211	Business	193100.00
0005435947347	4211	Business	193100.00
0005435856222	4211	Business	193100.00
0005435947276	4211	Business	193100.00
0005435947253	4211	Business	193100.00
0005435947275	4211	Economy	64400.00
0005432571333	4211	Economy	64400.00
0005435856223	4211	Economy	64400.00
0005434271323	4211	Economy	64400.00
0005434271311	4211	Economy	64400.00
0005435947231	4211	Economy	64400.00
0005435947291	4211	Economy	64400.00
0005435947277	4211	Economy	64400.00
0005435986830	4211	Economy	64400.00
0005435947289	4211	Economy	64400.00
0005435856217	4211	Economy	64400.00
0005435856204	4211	Economy	64400.00
0005435947320	4211	Economy	64400.00
0005435947206	4211	Economy	64400.00
0005435947321	4211	Economy	64400.00
0005435947207	4211	Economy	64400.00
0005432184980	4211	Economy	64400.00
0005435986829	4211	Economy	64400.00
0005435986831	4211	Economy	70800.00
0005435947346	4211	Economy	64400.00
0005435856225	4211	Economy	64400.00
0005434271312	4211	Economy	64400.00
0005435986833	4211	Economy	64400.00
0005435854062	4211	Economy	64400.00
0005435947230	4211	Economy	64400.00
0005435947288	4211	Economy	64400.00
0005435947260	4211	Economy	64400.00
0005435947264	4211	Economy	64400.00
0005435986828	4211	Economy	64400.00
0005435947298	4211	Economy	64400.00
0005432184981	4211	Economy	64400.00
0005435947229	4211	Economy	64400.00
0005432571335	4211	Economy	64400.00
0005435947290	4211	Economy	64400.00
0005435787356	4211	Economy	64400.00
0005435947273	4211	Economy	64400.00
0005435947280	4211	Economy	64400.00
0005435986834	4211	Economy	64400.00
0005435947400	26592	Business	193100.00
0005435787378	26592	Business	193100.00
0005435947402	26592	Business	193100.00
0005435856248	26592	Business	193100.00
0005435947407	26592	Business	193100.00
0005435947401	26592	Business	193100.00
0005432571364	26592	Business	193100.00
0005435986790	26592	Economy	64400.00
0005435787379	26592	Economy	64400.00
0005435856246	26592	Economy	64400.00
0005435856247	26592	Economy	64400.00
0005435947413	26592	Economy	64400.00
0005435947411	26592	Economy	64400.00
0005435947404	26592	Economy	64400.00
0005432571363	26592	Economy	64400.00
0005435986759	26592	Economy	64400.00
0005435986753	26592	Economy	64400.00
0005435856249	26592	Economy	64400.00
0005432571362	26592	Economy	64400.00
0005435986757	26592	Economy	64400.00
0005435986788	26592	Economy	64400.00
0005435986789	26592	Economy	64400.00
0005435947403	26592	Economy	64400.00
0005435986754	26592	Economy	64400.00
0005435986774	26592	Economy	64400.00
0005435947406	26592	Economy	64400.00
0005435947409	26592	Economy	64400.00
0005435986765	26592	Economy	64400.00
0005435947408	26592	Economy	64400.00
0005432571365	26592	Economy	64400.00
0005435986773	26592	Economy	64400.00
0005435947405	26592	Economy	64400.00
0005435986766	26592	Economy	64400.00
0005435986775	26592	Economy	64400.00
0005435986755	26592	Economy	64400.00
0005435787377	26592	Economy	64400.00
0005435947410	26592	Economy	64400.00
0005435947399	26592	Economy	64400.00
0005435947412	26592	Economy	64400.00
0005433074766	306	Business	21500.00
0005433569663	306	Business	21500.00
0005433569676	306	Business	21500.00
0005433074752	306	Business	21500.00
0005433134119	306	Business	21500.00
0005432948396	306	Business	21500.00
0005432948571	306	Business	21500.00
0005432948496	306	Business	21500.00
0005433569662	306	Business	21500.00
0005432948490	306	Business	21500.00
0005433569675	306	Business	21500.00
0005433129269	306	Business	21500.00
0005433569686	306	Business	21500.00
0005432948597	306	Business	21500.00
0005432948591	306	Business	21500.00
0005433569681	306	Business	21500.00
0005432948462	306	Business	21500.00
0005433569685	306	Business	21500.00
0005432948637	306	Business	21500.00
0005433569654	306	Business	21500.00
0005433569688	306	Business	21500.00
0005433569702	306	Business	21500.00
0005433569704	306	Business	21500.00
0005432948435	306	Business	21500.00
0005433129285	306	Business	21500.00
0005433074617	306	Economy	7900.00
0005432948457	306	Economy	7900.00
0005433569653	306	Economy	7900.00
0005433074676	306	Economy	7900.00
0005432948516	306	Economy	7900.00
0005433569683	306	Economy	7900.00
0005432948525	306	Economy	7200.00
0005433569666	306	Economy	7200.00
0005433569677	306	Economy	7200.00
0005433569670	306	Economy	7200.00
0005432948505	306	Economy	7200.00
0005433569695	306	Economy	7200.00
0005433134153	306	Economy	7200.00
0005433569680	306	Economy	7200.00
0005433569656	306	Economy	7200.00
0005432948376	306	Economy	7200.00
0005433129287	306	Economy	7200.00
0005432948506	306	Economy	7200.00
0005433569651	306	Economy	7200.00
0005433569669	306	Economy	7200.00
0005433569684	306	Economy	7200.00
0005432239000	306	Economy	7200.00
0005433569706	306	Economy	7200.00
0005432948608	306	Economy	7200.00
0005433569655	306	Economy	7200.00
0005432948522	306	Economy	7200.00
0005432948494	306	Economy	7200.00
0005433569678	306	Economy	7200.00
0005433074710	306	Economy	7200.00
0005433569682	306	Economy	7200.00
0005433134161	306	Economy	7200.00
0005433129260	306	Economy	7200.00
0005433569673	306	Economy	7200.00
0005433074701	306	Economy	7200.00
0005433569703	306	Economy	7200.00
0005432948521	306	Economy	7200.00
0005433134152	306	Economy	7200.00
0005433129270	306	Economy	7200.00
0005433569698	306	Economy	7200.00
0005432948554	306	Economy	7200.00
0005433129289	306	Economy	7200.00
0005433569690	306	Economy	7200.00
0005433569652	306	Economy	7200.00
0005432238998	306	Economy	7200.00
0005432238999	306	Economy	7200.00
0005433074753	306	Economy	7200.00
0005433129286	306	Economy	7200.00
0005432948561	306	Economy	7200.00
0005433569705	306	Economy	7200.00
0005433569660	306	Economy	7200.00
0005432948537	306	Economy	7200.00
0005432238997	306	Economy	7200.00
0005433569687	306	Economy	7200.00
0005433569667	306	Economy	7200.00
0005432948470	306	Economy	7200.00
0005433074777	306	Economy	7200.00
0005433569679	306	Economy	7200.00
0005432239002	306	Economy	7200.00
0005433129275	306	Economy	7900.00
0005432948590	306	Economy	7900.00
0005433569701	306	Economy	7900.00
0005432948526	306	Economy	7900.00
0005433569665	306	Economy	7900.00
0005432948553	306	Economy	7200.00
0005433074864	306	Economy	7200.00
0005432948605	306	Economy	7200.00
0005433134129	306	Economy	7900.00
0005433569658	306	Economy	7200.00
0005433569689	306	Economy	7200.00
0005432948630	306	Economy	7200.00
0005433569691	306	Economy	7200.00
0005433074702	306	Economy	7200.00
0005432948639	306	Economy	7200.00
0005432948465	306	Economy	7200.00
0005433134120	306	Economy	7200.00
0005433134155	306	Economy	7200.00
0005433569649	306	Economy	7200.00
0005432948555	306	Economy	7200.00
0005432948416	306	Economy	7200.00
0005433134130	306	Economy	7200.00
0005432948497	306	Economy	7200.00
0005432948562	306	Economy	7200.00
0005432948267	306	Economy	7200.00
0005433129281	306	Economy	7200.00
0005433569696	306	Economy	7200.00
0005432948366	306	Economy	7200.00
0005433074845	306	Economy	7200.00
0005432948266	306	Economy	7200.00
0005433129276	306	Economy	7200.00
0005432239001	306	Economy	7200.00
0005433074774	306	Economy	7200.00
0005433074703	306	Economy	7200.00
0005433569699	306	Economy	7200.00
0005433129279	306	Economy	7200.00
0005433569650	306	Economy	7200.00
0005432948538	306	Economy	7200.00
0005433569657	306	Economy	7200.00
0005433569692	306	Economy	7200.00
0005433569672	306	Economy	7200.00
0005433569697	306	Economy	7200.00
0005433569659	306	Economy	7200.00
0005432948638	306	Economy	7200.00
0005433074667	306	Economy	7200.00
0005432948405	306	Economy	7200.00
0005433569668	306	Economy	7200.00
0005432948489	306	Economy	7200.00
0005433569694	306	Economy	7200.00
0005433129278	306	Economy	7200.00
0005433569674	306	Economy	7200.00
0005433569700	306	Economy	7200.00
0005433074618	306	Economy	7200.00
0005433569693	306	Economy	7200.00
0005432948612	306	Economy	7200.00
0005433569661	306	Economy	7200.00
0005432948466	306	Economy	7200.00
0005432948535	306	Economy	7200.00
0005432948549	306	Economy	7200.00
0005433129288	306	Economy	7200.00
0005433569664	306	Economy	7200.00
0005433569671	306	Economy	7200.00
0005433074634	306	Economy	7200.00
0005433569121	11565	Business	21500.00
0005433074985	11565	Business	21500.00
0005433134185	11565	Business	21500.00
0005433131753	11565	Business	21500.00
0005432948850	11565	Business	21500.00
0005433569109	11565	Business	21500.00
0005433074986	11565	Business	21500.00
0005433568927	11565	Business	21500.00
0005432948872	11565	Business	21500.00
0005432948864	11565	Business	21500.00
0005433568794	11565	Business	21500.00
0005433075011	11565	Business	21500.00
0005433568997	11565	Business	21500.00
0005432948884	11565	Business	21500.00
0005433569126	11565	Business	21500.00
0005433569070	11565	Business	21500.00
0005433075008	11565	Business	21500.00
0005433569044	11565	Business	21500.00
0005432948880	11565	Business	21500.00
0005433569028	11565	Business	21500.00
0005432948877	11565	Business	21500.00
0005433131757	11565	Business	21500.00
0005433569122	11565	Business	21500.00
0005433075004	11565	Business	21500.00
0005433569145	11565	Economy	7900.00
0005433568616	11565	Economy	7900.00
0005432948883	11565	Economy	7900.00
0005433075012	11565	Economy	7900.00
0005432948881	11565	Economy	7900.00
0005433568960	11565	Economy	7900.00
0005433569146	11565	Economy	7200.00
0005433569083	11565	Economy	7200.00
0005433131756	11565	Economy	7200.00
0005433075002	11565	Economy	7200.00
0005432948871	11565	Economy	7200.00
0005433568702	11565	Economy	7200.00
0005433568942	11565	Economy	7200.00
0005432948854	11565	Economy	7200.00
0005433569006	11565	Economy	7200.00
0005433568988	11565	Economy	7200.00
0005433568938	11565	Economy	7200.00
0005432948857	11565	Economy	7200.00
0005432948887	11565	Economy	7200.00
0005433568944	11565	Economy	7200.00
0005433074988	11565	Economy	7200.00
0005432948886	11565	Economy	7200.00
0005433074991	11565	Economy	7200.00
0005432948879	11565	Economy	7200.00
0005433568793	11565	Economy	7200.00
0005433134186	11565	Economy	7200.00
0005433568996	11565	Economy	7200.00
0005433568826	11565	Economy	7200.00
0005433569148	11565	Economy	7200.00
0005432948852	11565	Economy	7200.00
0005433569062	11565	Economy	7200.00
0005432948849	11565	Economy	7200.00
0005433568869	11565	Economy	7200.00
0005433568874	11565	Economy	7200.00
0005432948855	11565	Economy	7200.00
0005433075001	11565	Economy	7200.00
0005433074993	11565	Economy	7200.00
0005433568984	11565	Economy	7200.00
0005433074995	11565	Economy	7200.00
0005433569026	11565	Economy	7200.00
0005433569110	11565	Economy	7200.00
0005433568981	11565	Economy	7200.00
0005432948889	11565	Economy	7200.00
0005433075003	11565	Economy	7200.00
0005432948868	11565	Economy	7200.00
0005432948888	11565	Economy	7200.00
0005433569060	11565	Economy	7200.00
0005433569131	11565	Economy	7200.00
0005433074987	11565	Economy	7200.00
0005432192354	11565	Economy	7200.00
0005432948874	11565	Economy	7200.00
0005433075006	11565	Economy	7200.00
0005433074984	11565	Economy	7200.00
0005433074999	11565	Economy	7200.00
0005433569108	11565	Economy	7200.00
0005432948856	11565	Economy	7200.00
0005432192352	11565	Economy	7200.00
0005433569101	11565	Economy	7200.00
0005433131754	11565	Economy	7200.00
0005433568881	11565	Economy	7900.00
0005433569048	11565	Economy	7900.00
0005433569125	11565	Economy	7900.00
0005433568943	11565	Economy	7200.00
0005433074996	11565	Economy	7200.00
0005432948853	11565	Economy	7200.00
0005433568954	11565	Economy	7900.00
0005433569129	11565	Economy	7200.00
0005433074998	11565	Economy	7200.00
0005432948870	11565	Economy	7200.00
0005432948867	11565	Economy	7200.00
0005432948860	11565	Economy	7200.00
0005433568861	11565	Economy	7200.00
0005432948885	11565	Economy	7200.00
0005433568983	11565	Economy	7200.00
0005433568836	11565	Economy	7200.00
0005433568989	11565	Economy	7200.00
0005433075007	11565	Economy	7200.00
0005433131755	11565	Economy	7200.00
0005433569130	11565	Economy	7200.00
0005433075000	11565	Economy	7200.00
0005432948873	11565	Economy	7200.00
0005432948848	11565	Economy	7200.00
0005433569144	11565	Economy	7200.00
0005432948875	11565	Economy	7200.00
0005433569098	11565	Economy	7200.00
0005432948882	11565	Economy	7200.00
0005433134187	11565	Economy	7200.00
0005433569027	11565	Economy	7200.00
0005432948876	11565	Economy	7200.00
0005433569005	11565	Economy	7200.00
0005432948865	11565	Economy	7200.00
0005433569013	11565	Economy	7200.00
0005433075010	11565	Economy	7200.00
0005433569107	11565	Economy	7200.00
0005432948859	11565	Economy	7200.00
0005433568862	11565	Economy	7200.00
0005432948851	11565	Economy	7200.00
0005433568928	11565	Economy	7200.00
0005433075005	11565	Economy	7200.00
0005433074989	11565	Economy	7200.00
0005432948866	11565	Economy	7200.00
0005433134184	11565	Economy	7200.00
0005432948863	11565	Economy	7200.00
0005433569038	11565	Economy	7200.00
0005432192351	11565	Economy	7200.00
0005433074990	11565	Economy	7200.00
0005432192353	11565	Economy	7200.00
0005433074992	11565	Economy	7200.00
0005432948858	11565	Economy	7200.00
0005433568875	11565	Economy	7200.00
0005432948862	11565	Economy	7200.00
0005433569047	11565	Economy	7200.00
0005432948861	11565	Economy	7200.00
0005433074994	11565	Economy	7200.00
0005432948878	11565	Economy	7200.00
0005433568990	11565	Economy	7200.00
0005433074997	11565	Economy	7200.00
0005433569045	11565	Economy	7200.00
0005433075009	11565	Economy	7200.00
0005432948869	11565	Economy	7200.00
0005433569120	11565	Economy	7200.00
0005432948890	11565	Economy	7200.00
0005433569123	11565	Economy	7200.00
0005433569031	11565	Economy	7200.00
0005433568929	11565	Economy	7200.00
0005433817508	9977	Economy	6300.00
0005433817512	9977	Economy	6300.00
0005434732980	9977	Economy	6300.00
0005433817509	9977	Economy	6300.00
0005433817511	9977	Economy	6300.00
0005434732982	9977	Economy	6300.00
0005433817510	9977	Economy	6300.00
0005434732987	9977	Economy	6300.00
0005433817459	13987	Economy	6300.00
0005433817468	13987	Economy	6300.00
0005433817473	13987	Economy	6300.00
0005434733017	13987	Economy	6300.00
0005433817469	13987	Economy	6300.00
0005433817460	13987	Economy	6300.00
0005434733016	13987	Economy	6300.00
0005433817474	13987	Economy	6300.00
0005433817486	13987	Economy	6300.00
0005434733018	13987	Economy	6300.00
0005433754775	2348	Business	184500.00
0005433434640	2348	Business	184500.00
0005433434808	2348	Business	184500.00
0005433754799	2348	Business	184500.00
0005435982809	2348	Business	184500.00
0005433754802	2348	Business	184500.00
0005435982771	2348	Business	184500.00
0005433434764	2348	Business	184500.00
0005432869574	2348	Business	184500.00
0005433434803	2348	Business	184500.00
0005435982785	2348	Business	184500.00
0005432985211	2348	Business	184500.00
0005433434660	2348	Business	184500.00
0005434731176	2348	Business	184500.00
0005435982804	2348	Business	184500.00
0005432226120	2348	Business	184500.00
0005432985260	2348	Business	184500.00
0005433434758	2348	Business	184500.00
0005433754792	2348	Business	184500.00
0005433434644	2348	Business	184500.00
0005433434747	2348	Business	184500.00
0005432985009	2348	Business	184500.00
0005435982776	2348	Business	184500.00
0005433766679	2348	Business	184500.00
0005435982799	2348	Business	184500.00
0005432985179	2348	Business	184500.00
0005435982795	2348	Business	184500.00
0005433754791	2348	Economy	67700.00
0005432226119	2348	Economy	67700.00
0005434731173	2348	Economy	67700.00
0005432655662	2348	Economy	67700.00
0005433754830	2348	Economy	61500.00
0005434731174	2348	Economy	61500.00
0005432985154	2348	Economy	61500.00
0005433434641	2348	Economy	61500.00
0005433754797	2348	Economy	61500.00
0005435982801	2348	Economy	61500.00
0005432984973	2348	Economy	61500.00
0005435982779	2348	Economy	61500.00
0005432655660	2348	Economy	61500.00
0005435982792	2348	Economy	61500.00
0005432985066	2348	Economy	61500.00
0005435982784	2348	Economy	61500.00
0005433754813	2348	Economy	61500.00
0005433434793	2348	Economy	61500.00
0005432655657	2348	Economy	61500.00
0005433754826	2348	Economy	61500.00
0005433754786	2348	Economy	61500.00
0005432985141	2348	Economy	61500.00
0005433434655	2348	Economy	61500.00
0005433754821	2348	Economy	61500.00
0005433434757	2348	Economy	61500.00
0005433434784	2348	Economy	61500.00
0005435982772	2348	Economy	61500.00
0005432985159	2348	Economy	61500.00
0005435982798	2348	Economy	61500.00
0005433434714	2348	Economy	61500.00
0005433754803	2348	Economy	61500.00
0005433766680	2348	Economy	61500.00
0005433754781	2348	Economy	61500.00
0005432985099	2348	Economy	61500.00
0005432655667	2348	Economy	61500.00
0005433754794	2348	Economy	61500.00
0005433754776	2348	Economy	61500.00
0005433434739	2348	Economy	61500.00
0005432985164	2348	Economy	61500.00
0005433434802	2348	Economy	61500.00
0005432300322	2348	Economy	61500.00
0005433754807	2348	Economy	61500.00
0005433754804	2348	Economy	61500.00
0005432226123	2348	Economy	61500.00
0005432300325	2348	Economy	61500.00
0005433754823	2348	Economy	61500.00
0005433754822	2348	Economy	61500.00
0005433754784	2348	Economy	61500.00
0005435982811	2348	Economy	61500.00
0005432985143	2348	Economy	61500.00
0005433434807	2348	Economy	61500.00
0005432655663	2348	Economy	61500.00
0005432985098	2348	Economy	61500.00
0005435982770	2348	Economy	61500.00
0005435982780	2348	Economy	61500.00
0005435982808	2348	Economy	61500.00
0005435982782	2348	Economy	61500.00
0005433754824	2348	Economy	61500.00
0005433754779	2348	Economy	61500.00
0005435982774	2348	Economy	61500.00
0005433754816	2348	Economy	61500.00
0005435982807	2348	Economy	61500.00
0005433754778	2348	Economy	61500.00
0005433434685	2348	Economy	61500.00
0005433764702	2348	Economy	61500.00
0005433434614	2348	Economy	61500.00
0005433764701	2348	Economy	61500.00
0005432226121	2348	Economy	61500.00
0005435982805	2348	Economy	61500.00
0005432985169	2348	Economy	61500.00
0005435982778	2348	Economy	61500.00
0005435982790	2348	Economy	61500.00
0005433754789	2348	Economy	61500.00
0005433754809	2348	Economy	61500.00
0005432655666	2348	Economy	61500.00
0005433754819	2348	Economy	61500.00
0005432655664	2348	Economy	61500.00
0005435982768	2348	Economy	61500.00
0005433434691	2348	Economy	61500.00
0005432655656	2348	Economy	61500.00
0005432985206	2348	Economy	61500.00
0005433754793	2348	Economy	61500.00
0005433754827	2348	Economy	61500.00
0005432985104	2348	Economy	61500.00
0005433754810	2348	Economy	61500.00
0005435982789	2348	Economy	61500.00
0005434731154	2348	Economy	61500.00
0005434731175	2348	Economy	61500.00
0005432985055	2348	Economy	61500.00
0005433434659	2348	Economy	61500.00
0005435982769	2348	Economy	61500.00
0005433754782	2348	Economy	61500.00
0005435982803	2348	Economy	61500.00
0005434731155	2348	Economy	61500.00
0005435982793	2348	Economy	61500.00
0005435982802	2348	Economy	61500.00
0005433754828	2348	Economy	61500.00
0005432984972	2348	Economy	61500.00
0005432869518	2348	Economy	61500.00
0005432869517	2348	Economy	61500.00
0005433434656	2348	Economy	67700.00
0005433754811	2348	Economy	67700.00
0005433754815	2348	Economy	61500.00
0005432985008	2348	Economy	61500.00
0005435982777	2348	Economy	61500.00
0005433754785	2348	Economy	67700.00
0005433754783	2348	Economy	61500.00
0005432985155	2348	Economy	61500.00
0005432985213	2348	Economy	61500.00
0005433754829	2348	Economy	61500.00
0005435982797	2348	Economy	61500.00
0005432300321	2348	Economy	61500.00
0005433754833	2348	Economy	61500.00
0005432300323	2348	Economy	61500.00
0005433754832	2348	Economy	61500.00
0005435982783	2348	Economy	61500.00
0005433434734	2348	Economy	61500.00
0005435982775	2348	Economy	61500.00
0005433434804	2348	Economy	61500.00
0005435982794	2348	Economy	61500.00
0005432226124	2348	Economy	61500.00
0005433754780	2348	Economy	61500.00
0005435982788	2348	Economy	61500.00
0005435982773	2348	Economy	61500.00
0005432985133	2348	Economy	61500.00
0005432985165	2348	Economy	61500.00
0005432300326	2348	Economy	61500.00
0005432985163	2348	Economy	61500.00
0005433766678	2348	Economy	61500.00
0005433434754	2348	Economy	61500.00
0005435982781	2348	Economy	61500.00
0005435982767	2348	Economy	61500.00
0005433754817	2348	Economy	61500.00
0005433754795	2348	Economy	61500.00
0005433754825	2348	Economy	61500.00
0005433434755	2348	Economy	61500.00
0005432985160	2348	Economy	61500.00
0005435982800	2348	Economy	61500.00
0005435982796	2348	Economy	61500.00
0005433754812	2348	Economy	61500.00
0005435982787	2348	Economy	61500.00
0005435982791	2348	Economy	61500.00
0005432300324	2348	Economy	61500.00
0005432226122	2348	Economy	61500.00
0005432985144	2348	Economy	61500.00
0005434731189	2348	Economy	61500.00
0005432985132	2348	Economy	61500.00
0005433754790	2348	Economy	61500.00
0005432869542	2348	Economy	61500.00
0005433754796	2348	Economy	61500.00
0005433754801	2348	Economy	61500.00
0005432985074	2348	Economy	61500.00
0005432985035	2348	Economy	61500.00
0005433754800	2348	Economy	61500.00
0005433754814	2348	Economy	61500.00
0005433754831	2348	Economy	61500.00
0005435982806	2348	Economy	61500.00
0005433754787	2348	Economy	61500.00
0005432655658	2348	Economy	61500.00
0005432655661	2348	Economy	61500.00
0005433754806	2348	Economy	61500.00
0005433754805	2348	Economy	61500.00
0005435982810	2348	Economy	61500.00
0005433434683	2348	Economy	61500.00
0005432985050	2348	Economy	61500.00
0005432985184	2348	Economy	61500.00
0005432869573	2348	Economy	61500.00
0005433434684	2348	Economy	61500.00
0005433754820	2348	Economy	61500.00
0005432985142	2348	Economy	61500.00
0005433754818	2348	Economy	61500.00
0005433754788	2348	Economy	61500.00
0005433754777	2348	Economy	61500.00
0005432655665	2348	Economy	61500.00
0005433754798	2348	Economy	61500.00
0005433434733	2348	Economy	61500.00
0005433754808	2348	Economy	61500.00
0005432655659	2348	Economy	61500.00
0005433434738	2348	Economy	61500.00
0005432985049	2348	Economy	61500.00
0005435982786	2348	Economy	61500.00
0005435982396	26216	Business	184500.00
0005432655540	26216	Business	184500.00
0005435982226	26216	Business	184500.00
0005433754449	26216	Business	184500.00
0005433754423	26216	Business	184500.00
0005433754310	26216	Business	184500.00
0005433754440	26216	Business	184500.00
0005433754180	26216	Business	184500.00
0005435982322	26216	Business	184500.00
0005434731215	26216	Business	184500.00
0005435982198	26216	Business	184500.00
0005435982562	26216	Business	184500.00
0005435982338	26216	Business	184500.00
0005435982336	26216	Business	184500.00
0005433754309	26216	Business	184500.00
0005433434982	26216	Business	184500.00
0005433434983	26216	Business	184500.00
0005433754149	26216	Business	184500.00
0005433766640	26216	Business	184500.00
0005433754541	26216	Business	184500.00
0005435982395	26216	Business	184500.00
0005433754575	26216	Business	184500.00
0005432869589	26216	Business	184500.00
0005433434966	26216	Business	184500.00
0005435982337	26216	Business	184500.00
0005432985401	26216	Business	184500.00
0005432655522	26216	Business	184500.00
0005432655495	26216	Business	184500.00
0005433754140	26216	Business	184500.00
0005435982239	26216	Economy	67700.00
0005432655555	26216	Economy	67700.00
0005432655586	26216	Economy	67700.00
0005433754463	26216	Economy	61500.00
0005433754054	26216	Economy	61500.00
0005435982364	26216	Economy	61500.00
0005435982605	26216	Economy	61500.00
0005433754450	26216	Economy	61500.00
0005435982388	26216	Economy	61500.00
0005433754418	26216	Economy	61500.00
0005433754451	26216	Economy	61500.00
0005435982458	26216	Economy	61500.00
0005432049502	26216	Economy	61500.00
0005433766647	26216	Economy	61500.00
0005433754148	26216	Economy	61500.00
0005433434981	26216	Economy	61500.00
0005433434977	26216	Economy	61500.00
0005432985399	26216	Economy	61500.00
0005433766636	26216	Economy	61500.00
0005433754452	26216	Economy	61500.00
0005432985406	26216	Economy	61500.00
0005432869593	26216	Economy	61500.00
0005432985404	26216	Economy	61500.00
0005433754053	26216	Economy	61500.00
0005433754226	26216	Economy	61500.00
0005433434971	26216	Economy	61500.00
0005433434965	26216	Economy	61500.00
0005432655521	26216	Economy	61500.00
0005432985425	26216	Economy	61500.00
0005432051160	26216	Economy	61500.00
0005435982334	26216	Economy	61500.00
0005433754287	26216	Economy	61500.00
0005432985418	26216	Economy	61500.00
0005433754227	26216	Economy	61500.00
0005435982479	26216	Economy	61500.00
0005433754098	26216	Economy	61500.00
0005432049501	26216	Economy	61500.00
0005435982063	26216	Economy	61500.00
0005432869591	26216	Economy	61500.00
0005433434963	26216	Economy	61500.00
0005433754150	26216	Economy	61500.00
0005434731216	26216	Economy	61500.00
0005433766639	26216	Economy	61500.00
0005433754245	26216	Economy	61500.00
0005432985397	26216	Economy	61500.00
0005433434967	26216	Economy	61500.00
0005432985426	26216	Economy	61500.00
0005432049504	26216	Economy	61500.00
0005433754384	26216	Economy	61500.00
0005433434972	26216	Economy	61500.00
0005433754252	26216	Economy	61500.00
0005433754192	26216	Economy	61500.00
0005433754466	26216	Economy	61500.00
0005432985414	26216	Economy	61500.00
0005433764689	26216	Economy	61500.00
0005433754258	26216	Economy	61500.00
0005433754542	26216	Economy	61500.00
0005433434962	26216	Economy	61500.00
0005433754284	26216	Economy	61500.00
0005435982475	26216	Economy	61500.00
0005433434985	26216	Economy	61500.00
0005432655513	26216	Economy	61500.00
0005432655548	26216	Economy	61500.00
0005435982371	26216	Economy	61500.00
0005433754448	26216	Economy	61500.00
0005432985408	26216	Economy	61500.00
0005435982287	26216	Economy	61500.00
0005435982232	26216	Economy	61500.00
0005435982560	26216	Economy	61500.00
0005433754247	26216	Economy	61500.00
0005433754338	26216	Economy	61500.00
0005433754218	26216	Economy	61500.00
0005435982474	26216	Economy	61500.00
0005433434959	26216	Economy	61500.00
0005432049499	26216	Economy	61500.00
0005432985423	26216	Economy	61500.00
0005432049503	26216	Economy	61500.00
0005435982274	26216	Economy	61500.00
0005433766653	26216	Economy	61500.00
0005433434960	26216	Economy	61500.00
0005432985407	26216	Economy	61500.00
0005433434969	26216	Economy	61500.00
0005432985427	26216	Economy	61500.00
0005435982155	26216	Economy	61500.00
0005432655512	26216	Economy	61500.00
0005432985415	26216	Economy	61500.00
0005433754125	26216	Economy	61500.00
0005435982061	26216	Economy	61500.00
0005433434978	26216	Economy	61500.00
0005435982233	26216	Economy	61500.00
0005433434968	26216	Economy	61500.00
0005432985411	26216	Economy	61500.00
0005433754409	26216	Economy	61500.00
0005432985398	26216	Economy	61500.00
0005435982404	26216	Economy	61500.00
0005432985424	26216	Economy	61500.00
0005435982313	26216	Economy	61500.00
0005433434958	26216	Economy	67700.00
0005434731214	26216	Economy	61500.00
0005435982459	26216	Economy	67700.00
0005433434964	26216	Economy	61500.00
0005432985428	26216	Economy	61500.00
0005432985413	26216	Economy	61500.00
0005432049500	26216	Economy	67700.00
0005432051159	26216	Economy	67700.00
0005432985403	26216	Economy	61500.00
0005433754462	26216	Economy	61500.00
0005433434961	26216	Economy	61500.00
0005433754392	26216	Economy	61500.00
0005433754055	26216	Economy	61500.00
0005435982241	26216	Economy	61500.00
0005432655582	26216	Economy	61500.00
0005433754419	26216	Economy	61500.00
0005435982423	26216	Economy	61500.00
0005433434979	26216	Economy	61500.00
0005432985400	26216	Economy	61500.00
0005433754522	26216	Economy	61500.00
0005432985402	26216	Economy	61500.00
0005433754286	26216	Economy	61500.00
0005433754217	26216	Economy	61500.00
0005435982227	26216	Economy	61500.00
0005433766637	26216	Economy	61500.00
0005433434970	26216	Economy	61500.00
0005432985420	26216	Economy	61500.00
0005435982460	26216	Economy	61500.00
0005434731213	26216	Economy	61500.00
0005435982517	26216	Economy	61500.00
0005433434975	26216	Economy	61500.00
0005432869592	26216	Economy	61500.00
0005435982463	26216	Economy	61500.00
0005432985422	26216	Economy	61500.00
0005433754188	26216	Economy	61500.00
0005435982399	26216	Economy	61500.00
0005432869590	26216	Economy	61500.00
0005433754179	26216	Economy	61500.00
0005433434974	26216	Economy	61500.00
0005433754246	26216	Economy	61500.00
0005433754570	26216	Economy	61500.00
0005433434984	26216	Economy	61500.00
0005432985417	26216	Economy	61500.00
0005432985421	26216	Economy	61500.00
0005432655541	26216	Economy	61500.00
0005432051161	26216	Economy	61500.00
0005432985419	26216	Economy	61500.00
0005435982320	26216	Economy	61500.00
0005434731217	26216	Economy	61500.00
0005433754178	26216	Economy	61500.00
0005433434976	26216	Economy	61500.00
0005433434973	26216	Economy	61500.00
0005435982151	26216	Economy	61500.00
0005433754076	26216	Economy	61500.00
0005435982062	26216	Economy	61500.00
0005435982340	26216	Economy	61500.00
0005432985396	26216	Economy	61500.00
0005435982561	26216	Economy	61500.00
0005432655551	26216	Economy	61500.00
0005432985412	26216	Economy	61500.00
0005435982440	26216	Economy	61500.00
0005433434980	26216	Economy	61500.00
0005433754204	26216	Economy	61500.00
0005433754141	26216	Economy	61500.00
0005433754065	26216	Economy	61500.00
0005432655524	26216	Economy	61500.00
0005433754169	26216	Economy	61500.00
0005433754401	26216	Economy	61500.00
0005433754576	26216	Economy	61500.00
0005435982323	26216	Economy	61500.00
0005433754391	26216	Economy	61500.00
0005435982387	26216	Economy	61500.00
0005433754399	26216	Economy	61500.00
0005433754244	26216	Economy	61500.00
0005432985405	26216	Economy	61500.00
0005433754274	26216	Economy	61500.00
0005432985409	26216	Economy	61500.00
0005432655549	26216	Economy	61500.00
0005432655539	26216	Economy	61500.00
0005432985410	26216	Economy	61500.00
0005432985416	26216	Economy	61500.00
0005433151570	1484	Business	38900.00
0005433151500	1484	Business	38900.00
0005434375126	1484	Business	38900.00
0005433151505	1484	Business	38900.00
0005433151550	1484	Business	38900.00
0005433151575	1484	Business	38900.00
0005433151581	1484	Business	38900.00
0005433764672	1484	Business	38900.00
0005434375127	1484	Business	38900.00
0005433151637	1484	Business	38900.00
0005433151392	1484	Business	38900.00
0005433151540	1484	Economy	13000.00
0005434375138	1484	Economy	13000.00
0005434375125	1484	Economy	13000.00
0005433151636	1484	Economy	13000.00
0005433151337	1484	Economy	13000.00
0005433151336	1484	Economy	13000.00
0005433151549	1484	Economy	13000.00
0005434375142	1484	Economy	13000.00
0005433151615	1484	Economy	13000.00
0005433151598	1484	Economy	13000.00
0005433151521	1484	Economy	13000.00
0005433764673	1484	Economy	13000.00
0005432267966	1484	Economy	13000.00
0005433764681	1484	Economy	13000.00
0005434375136	1484	Economy	13000.00
0005433151380	1484	Economy	13000.00
0005434375148	1484	Economy	13000.00
0005433151574	1484	Economy	13000.00
0005433151571	1484	Economy	13000.00
0005434375143	1484	Economy	13000.00
0005434375129	1484	Economy	13000.00
0005433764671	1484	Economy	13000.00
0005433461611	1484	Economy	13000.00
0005433931467	1484	Economy	13000.00
0005434029655	1484	Economy	13000.00
0005434375135	1484	Economy	13000.00
0005433151470	1484	Economy	13000.00
0005434375144	1484	Economy	14300.00
0005432267965	1484	Economy	14300.00
0005433151378	1484	Economy	13000.00
0005434375134	1484	Economy	13000.00
0005433151391	1484	Economy	13000.00
0005434375123	1484	Economy	13000.00
0005434375137	1484	Economy	13000.00
0005434375121	1484	Economy	13000.00
0005432267964	1484	Economy	13000.00
0005433151565	1484	Economy	13000.00
0005434375149	1484	Economy	13000.00
0005434375114	1484	Economy	13000.00
0005434375131	1484	Economy	13000.00
0005434375140	1484	Economy	13000.00
0005433151471	1484	Economy	13000.00
0005434375120	1484	Economy	13000.00
0005433151520	1484	Economy	13000.00
0005433931462	1484	Economy	13000.00
0005434375128	1484	Economy	13000.00
0005434375130	1484	Economy	13000.00
0005433931461	1484	Economy	13000.00
0005433151465	1484	Economy	13000.00
0005434375145	1484	Economy	13000.00
0005433151580	1484	Economy	13000.00
0005434375146	1484	Economy	13000.00
0005433151386	1484	Economy	13000.00
0005433151613	1484	Economy	13000.00
0005432267967	1484	Economy	13000.00
0005433764684	1484	Economy	13000.00
0005434375116	1484	Economy	13000.00
0005432267961	1484	Economy	13000.00
0005434375141	1484	Economy	13000.00
0005433764677	1484	Economy	13000.00
0005433151457	1484	Economy	13000.00
0005434375115	1484	Economy	13000.00
0005434375133	1484	Economy	13000.00
0005433460459	1484	Economy	13000.00
0005434375139	1484	Economy	13000.00
0005434375147	1484	Economy	13000.00
0005433764683	1484	Economy	13000.00
0005432267962	1484	Economy	13000.00
0005433764682	1484	Economy	13000.00
0005434375117	1484	Economy	13000.00
0005433461610	1484	Economy	13000.00
0005434375119	1484	Economy	13000.00
0005434375122	1484	Economy	13000.00
0005434375132	1484	Economy	13000.00
0005432267963	1484	Economy	13000.00
0005433151472	1484	Economy	13000.00
0005434375124	1484	Economy	13000.00
0005433151614	1484	Economy	13000.00
0005434375118	1484	Economy	13000.00
0005434029656	1484	Economy	13000.00
0005433931464	1484	Economy	13000.00
0005434374817	20143	Business	38900.00
0005434374862	20143	Business	38900.00
0005433764702	20143	Business	38900.00
0005434374919	20143	Business	38900.00
0005433151745	20143	Business	38900.00
0005434374861	20143	Business	38900.00
0005433151748	20143	Business	38900.00
0005433151756	20143	Business	38900.00
0005434374813	20143	Economy	13000.00
0005434374734	20143	Economy	13000.00
0005434374701	20143	Economy	13000.00
0005434374747	20143	Economy	13000.00
0005434374551	20143	Economy	13000.00
0005433151773	20143	Economy	13000.00
0005434374728	20143	Economy	13000.00
0005433931499	20143	Economy	13000.00
0005433151761	20143	Economy	13000.00
0005433151764	20143	Economy	13000.00
0005433151765	20143	Economy	13000.00
0005434374777	20143	Economy	13000.00
0005434374837	20143	Economy	13000.00
0005433151762	20143	Economy	13000.00
0005434374650	20143	Economy	13000.00
0005434374755	20143	Economy	13000.00
0005433151753	20143	Economy	13000.00
0005433151777	20143	Economy	13000.00
0005433151754	20143	Economy	13000.00
0005434374825	20143	Economy	13000.00
0005433151768	20143	Economy	13000.00
0005434374797	20143	Economy	13000.00
0005433151769	20143	Economy	13000.00
0005433151759	20143	Economy	13000.00
0005434374721	20143	Economy	13000.00
0005432056339	20143	Economy	13000.00
0005434374803	20143	Economy	13000.00
0005433151746	20143	Economy	13000.00
0005434374804	20143	Economy	13000.00
0005434374678	20143	Economy	13000.00
0005433151770	20143	Economy	13000.00
0005434374649	20143	Economy	13000.00
0005433151757	20143	Economy	13000.00
0005432056337	20143	Economy	14300.00
0005433151752	20143	Economy	14300.00
0005433931496	20143	Economy	14300.00
0005433931497	20143	Economy	14300.00
0005433151767	20143	Economy	13000.00
0005433151774	20143	Economy	13000.00
0005433151755	20143	Economy	13000.00
0005434374842	20143	Economy	13000.00
0005434374718	20143	Economy	13000.00
0005434374659	20143	Economy	13000.00
0005434374698	20143	Economy	13000.00
0005434374855	20143	Economy	13000.00
0005433151776	20143	Economy	13000.00
0005434374722	20143	Economy	13000.00
0005434374717	20143	Economy	13000.00
0005434374757	20143	Economy	13000.00
0005433151766	20143	Economy	13000.00
0005433151749	20143	Economy	13000.00
0005433151751	20143	Economy	13000.00
0005434029682	20143	Economy	13000.00
0005434374756	20143	Economy	13000.00
0005433151758	20143	Economy	13000.00
0005433151771	20143	Economy	13000.00
0005433151750	20143	Economy	13000.00
0005434374802	20143	Economy	13000.00
0005433151775	20143	Economy	13000.00
0005434374697	20143	Economy	13000.00
0005433151760	20143	Economy	13000.00
0005434374836	20143	Economy	13000.00
0005433151763	20143	Economy	13000.00
0005434374720	20143	Economy	13000.00
0005434374709	20143	Economy	13000.00
0005434374657	20143	Economy	13000.00
0005433151744	20143	Economy	13000.00
0005434029683	20143	Economy	13000.00
0005434374737	20143	Economy	13000.00
0005434029684	20143	Economy	13000.00
0005434374696	20143	Economy	13000.00
0005433151772	20143	Economy	13000.00
0005433931498	20143	Economy	13000.00
0005434374843	20143	Economy	13000.00
0005434374735	20143	Economy	13000.00
0005434374727	20143	Economy	13000.00
0005432056338	20143	Economy	13000.00
0005434374824	20143	Economy	13000.00
0005433151747	20143	Economy	13000.00
0005434374844	20143	Economy	13000.00
0005433764701	20143	Economy	13000.00
0005434374745	20143	Economy	13000.00
0005434374798	20143	Economy	13000.00
0005434374723	20143	Economy	13000.00
0005434374700	20143	Economy	13000.00
0005434374677	20143	Economy	13000.00
0005432424945	531	Business	27500.00
0005432424948	531	Business	27500.00
0005432282934	531	Business	27500.00
0005432424954	531	Business	27500.00
0005432424951	531	Business	27500.00
0005432424950	531	Business	27500.00
0005432424937	531	Business	27500.00
0005432424961	531	Business	27500.00
0005432424934	531	Economy	10100.00
0005432424933	531	Economy	10100.00
0005432424919	531	Economy	10100.00
0005432424935	531	Economy	10100.00
0005432424927	531	Economy	10100.00
0005432424944	531	Economy	9200.00
0005432424949	531	Economy	9200.00
0005432424930	531	Economy	9200.00
0005432424952	531	Economy	9200.00
0005432282939	531	Economy	9200.00
0005432424942	531	Economy	9200.00
0005432424932	531	Economy	9200.00
0005432424953	531	Economy	9200.00
0005432424959	531	Economy	9200.00
0005432424924	531	Economy	9200.00
0005432424955	531	Economy	9200.00
0005432282940	531	Economy	9200.00
0005432282938	531	Economy	9200.00
0005432424928	531	Economy	9200.00
0005432424938	531	Economy	9200.00
0005432282936	531	Economy	9200.00
0005432424915	531	Economy	9200.00
0005432424936	531	Economy	9200.00
0005432424931	531	Economy	9200.00
0005432282937	531	Economy	9200.00
0005432424916	531	Economy	9200.00
0005432424921	531	Economy	9200.00
0005432424918	531	Economy	9200.00
0005432424941	531	Economy	9200.00
0005432424929	531	Economy	9200.00
0005432424940	531	Economy	10100.00
0005432424920	531	Economy	9200.00
0005432424957	531	Economy	9200.00
0005432424922	531	Economy	9200.00
0005432424939	531	Economy	9200.00
0005432424925	531	Economy	9200.00
0005432424923	531	Economy	9200.00
0005432424956	531	Economy	9200.00
0005432424946	531	Economy	9200.00
0005432282935	531	Economy	9200.00
0005432424917	531	Economy	9200.00
0005432424947	531	Economy	9200.00
0005432424943	531	Economy	9200.00
0005432424960	531	Economy	9200.00
0005432424958	531	Economy	9200.00
0005432424926	531	Economy	9200.00
0005432302368	12946	Business	27500.00
0005432302373	12946	Economy	9200.00
0005432302369	12946	Economy	9200.00
0005432302371	12946	Economy	9200.00
0005432302370	12946	Economy	9200.00
0005432302372	12946	Economy	9200.00
0005432424407	12828	Business	27500.00
0005432424359	12828	Business	27500.00
0005432424429	12828	Business	27500.00
0005432424294	12828	Business	27500.00
0005432424483	12828	Business	27500.00
0005432424506	12828	Business	27500.00
0005432424433	12828	Business	27500.00
0005432424309	12828	Business	27500.00
0005432424377	12828	Business	27500.00
0005432424405	12828	Economy	10100.00
0005432424445	12828	Economy	10100.00
0005432424490	12828	Economy	10100.00
0005432424261	12828	Economy	9200.00
0005432424273	12828	Economy	9200.00
0005432424293	12828	Economy	9200.00
0005432424328	12828	Economy	9200.00
0005432424406	12828	Economy	9200.00
0005432424446	12828	Economy	9200.00
0005432424456	12828	Economy	9200.00
0005432424505	12828	Economy	9200.00
0005432424313	12828	Economy	9200.00
0005432424478	12828	Economy	9200.00
0005432424511	12828	Economy	9200.00
0005432424507	12828	Economy	9200.00
0005432424484	12828	Economy	9200.00
0005432424500	12828	Economy	9200.00
0005432424453	12828	Economy	9200.00
0005432424349	12828	Economy	9200.00
0005432424477	12828	Economy	9200.00
0005432424501	12828	Economy	9200.00
0005432424274	12828	Economy	9200.00
0005432424344	12828	Economy	9200.00
0005432424497	12828	Economy	9200.00
0005432424513	12828	Economy	9200.00
0005432424516	12828	Economy	9200.00
0005432424461	12828	Economy	9200.00
0005432424479	12828	Economy	9200.00
0005432424426	12828	Economy	9200.00
0005432424400	12828	Economy	9200.00
0005432424231	12828	Economy	9200.00
0005432424376	12828	Economy	9200.00
0005432424275	12828	Economy	9200.00
0005432424452	12828	Economy	9200.00
0005432424415	12828	Economy	9200.00
0005432424414	12828	Economy	9200.00
0005432424312	12828	Economy	9200.00
0005432424481	12828	Economy	9200.00
0005434024398	455	Business	24500.00
0005434024397	455	Business	24500.00
0005434024439	455	Business	24500.00
0005433057863	455	Business	24500.00
0005434024374	455	Business	24500.00
0005433058188	455	Business	24500.00
0005434024407	455	Business	24500.00
0005433057775	455	Business	24500.00
0005434735702	455	Business	24500.00
0005434024403	455	Business	24500.00
0005433929619	455	Business	24500.00
0005433057972	455	Business	24500.00
0005433684421	455	Business	24500.00
0005434024396	455	Business	24500.00
0005432235715	455	Business	24500.00
0005434024377	455	Economy	9000.00
0005434024418	455	Economy	9000.00
0005434024406	455	Economy	9000.00
0005434028323	455	Economy	8200.00
0005434024412	455	Economy	8200.00
0005433057976	455	Economy	8200.00
0005434024423	455	Economy	8200.00
0005434024424	455	Economy	8200.00
0005432235719	455	Economy	8200.00
0005434024413	455	Economy	8200.00
0005434024431	455	Economy	8200.00
0005433929616	455	Economy	8200.00
0005433058082	455	Economy	8200.00
0005433058060	455	Economy	8200.00
0005432235714	455	Economy	8200.00
0005434024387	455	Economy	8200.00
0005434024404	455	Economy	8200.00
0005434024441	455	Economy	8200.00
0005434024379	455	Economy	8200.00
0005434024414	455	Economy	8200.00
0005433057926	455	Economy	8200.00
0005433057925	455	Economy	8200.00
0005434024410	455	Economy	8200.00
0005434032068	455	Economy	8200.00
0005434024394	455	Economy	8200.00
0005434024389	455	Economy	8200.00
0005434024434	455	Economy	8200.00
0005434024436	455	Economy	8200.00
0005434024425	455	Economy	8200.00
0005433057839	455	Economy	8200.00
0005434024393	455	Economy	8200.00
0005434032067	455	Economy	8200.00
0005434024405	455	Economy	8200.00
0005434024380	455	Economy	8200.00
0005434024376	455	Economy	8200.00
0005434029679	455	Economy	8200.00
0005433058043	455	Economy	8200.00
0005434024420	455	Economy	8200.00
0005434024433	455	Economy	8200.00
0005434024409	455	Economy	8200.00
0005434024388	455	Economy	8200.00
0005433057864	455	Economy	8200.00
0005434024430	455	Economy	8200.00
0005434024422	455	Economy	8200.00
0005434024417	455	Economy	8200.00
0005434032069	455	Economy	8200.00
0005432235717	455	Economy	8200.00
0005434024408	455	Economy	8200.00
0005433057960	455	Economy	8200.00
0005432235713	455	Economy	8200.00
0005434024415	455	Economy	8200.00
0005434024382	455	Economy	8200.00
0005434735668	455	Economy	9000.00
0005433929603	455	Economy	8200.00
0005432235712	455	Economy	8200.00
0005434024419	455	Economy	9000.00
0005434024391	455	Economy	9000.00
0005434024440	455	Economy	8200.00
0005434024432	455	Economy	8200.00
0005434024421	455	Economy	8200.00
0005434032066	455	Economy	8200.00
0005433057975	455	Economy	8200.00
0005434024378	455	Economy	8200.00
0005434024392	455	Economy	8200.00
0005432045631	455	Economy	8200.00
0005434024383	455	Economy	8200.00
0005434024402	455	Economy	8200.00
0005434024381	455	Economy	8200.00
0005434735690	455	Economy	8200.00
0005433058189	455	Economy	8200.00
0005433929617	455	Economy	8200.00
0005432235718	455	Economy	8200.00
0005434024401	455	Economy	8200.00
0005433058004	455	Economy	8200.00
0005432235716	455	Economy	8200.00
0005434024386	455	Economy	8200.00
0005434024411	455	Economy	8200.00
0005433057927	455	Economy	8200.00
0005434024429	455	Economy	8200.00
0005434735667	455	Economy	8200.00
0005433058027	455	Economy	8200.00
0005433057837	455	Economy	8200.00
0005433058116	455	Economy	8200.00
0005434024400	455	Economy	8200.00
0005433058028	455	Economy	8200.00
0005434029680	455	Economy	8200.00
0005432045632	455	Economy	8200.00
0005434029681	455	Economy	8200.00
0005434024435	455	Economy	8200.00
0005434024438	455	Economy	8200.00
0005434024375	455	Economy	8200.00
0005433058019	455	Economy	8200.00
0005434024416	455	Economy	8200.00
0005434735687	455	Economy	8200.00
0005433057971	455	Economy	8200.00
0005434024390	455	Economy	8200.00
0005434028322	455	Economy	8200.00
0005434024395	455	Economy	8200.00
0005433057946	455	Economy	8200.00
0005434024428	455	Economy	8200.00
0005434024399	455	Economy	8200.00
0005434024437	455	Economy	8200.00
0005434024384	455	Economy	8200.00
0005434024427	455	Economy	8200.00
0005434024385	455	Economy	8200.00
0005434024426	455	Economy	8200.00
0005433058020	455	Economy	8200.00
0005434023710	12659	Business	24500.00
0005434023563	12659	Business	24500.00
0005433058316	12659	Business	24500.00
0005434735744	12659	Business	24500.00
0005433058283	12659	Business	24500.00
0005434023768	12659	Business	24500.00
0005434032032	12659	Business	24500.00
0005433058282	12659	Business	24500.00
0005434024068	12659	Business	24500.00
0005433058289	12659	Business	24500.00
0005434023733	12659	Business	24500.00
0005434023855	12659	Business	24500.00
0005434735743	12659	Business	24500.00
0005434023817	12659	Business	24500.00
0005434023859	12659	Business	24500.00
0005433058292	12659	Business	24500.00
0005433058308	12659	Business	24500.00
0005434023699	12659	Business	24500.00
0005434023776	12659	Business	24500.00
0005433058286	12659	Business	24500.00
0005434023923	12659	Economy	9000.00
0005434023321	12659	Economy	9000.00
0005434023792	12659	Economy	9000.00
0005434735746	12659	Economy	8200.00
0005434023734	12659	Economy	8200.00
0005434024014	12659	Economy	8200.00
0005434023486	12659	Economy	8200.00
0005434023775	12659	Economy	8200.00
0005433058293	12659	Economy	8200.00
0005432157511	12659	Economy	8200.00
0005434024006	12659	Economy	8200.00
0005434029655	12659	Economy	8200.00
0005433058285	12659	Economy	8200.00
0005433058300	12659	Economy	8200.00
0005434032048	12659	Economy	8200.00
0005434023780	12659	Economy	8200.00
0005434023939	12659	Economy	8200.00
0005434023854	12659	Economy	8200.00
0005434023750	12659	Economy	8200.00
0005433929655	12659	Economy	8200.00
0005434024163	12659	Economy	8200.00
0005433058284	12659	Economy	8200.00
0005434023875	12659	Economy	8200.00
0005433058278	12659	Economy	8200.00
0005434023696	12659	Economy	8200.00
0005434023933	12659	Economy	8200.00
0005434023473	12659	Economy	8200.00
0005434023695	12659	Economy	8200.00
0005433058298	12659	Economy	8200.00
0005434023870	12659	Economy	8200.00
0005434023707	12659	Economy	8200.00
0005434023697	12659	Economy	8200.00
0005433058297	12659	Economy	8200.00
0005433058294	12659	Economy	8200.00
0005434023706	12659	Economy	8200.00
0005433058295	12659	Economy	8200.00
0005433058302	12659	Economy	8200.00
0005434023454	12659	Economy	8200.00
0005434023812	12659	Economy	8200.00
0005433684443	12659	Economy	8200.00
0005433058281	12659	Economy	8200.00
0005434023655	12659	Economy	8200.00
0005434023907	12659	Economy	8200.00
0005434024069	12659	Economy	8200.00
0005433058277	12659	Economy	8200.00
0005434029656	12659	Economy	8200.00
0005433058318	12659	Economy	8200.00
0005433058290	12659	Economy	8200.00
0005434023864	12659	Economy	8200.00
0005433058280	12659	Economy	8200.00
0005434735742	12659	Economy	8200.00
0005433058312	12659	Economy	8200.00
0005433058313	12659	Economy	8200.00
0005432157512	12659	Economy	8200.00
0005434023704	12659	Economy	8200.00
0005434023861	12659	Economy	8200.00
0005434023801	12659	Economy	8200.00
0005434023813	12659	Economy	8200.00
0005434023672	12659	Economy	8200.00
0005434032049	12659	Economy	8200.00
0005433058303	12659	Economy	8200.00
0005434023472	12659	Economy	8200.00
0005434023745	12659	Economy	8200.00
0005434024019	12659	Economy	9000.00
0005434023863	12659	Economy	9000.00
0005433058296	12659	Economy	8200.00
0005434023654	12659	Economy	8200.00
0005433058315	12659	Economy	9000.00
0005433058314	12659	Economy	9000.00
0005433058299	12659	Economy	8200.00
0005433058291	12659	Economy	8200.00
0005434023860	12659	Economy	8200.00
0005433929657	12659	Economy	8200.00
0005433058287	12659	Economy	8200.00
0005433058310	12659	Economy	8200.00
0005434024005	12659	Economy	8200.00
0005434735747	12659	Economy	8200.00
0005433058301	12659	Economy	8200.00
0005433058288	12659	Economy	8200.00
0005433929656	12659	Economy	8200.00
0005434028300	12659	Economy	8200.00
0005434024004	12659	Economy	8200.00
0005434023619	12659	Economy	8200.00
0005432156411	12659	Economy	8200.00
0005434023791	12659	Economy	8200.00
0005434023541	12659	Economy	8200.00
0005433058309	12659	Economy	8200.00
0005434023705	12659	Economy	8200.00
0005434023751	12659	Economy	8200.00
0005434028301	12659	Economy	8200.00
0005432156413	12659	Economy	8200.00
0005432156412	12659	Economy	8200.00
0005433929654	12659	Economy	8200.00
0005433058306	12659	Economy	8200.00
0005434023767	12659	Economy	8200.00
0005434024216	12659	Economy	8200.00
0005434023779	12659	Economy	8200.00
0005433058311	12659	Economy	8200.00
0005432156414	12659	Economy	8200.00
0005434023567	12659	Economy	8200.00
0005432156410	12659	Economy	8200.00
0005434023811	12659	Economy	8200.00
0005434023862	12659	Economy	8200.00
0005434024067	12659	Economy	8200.00
0005434023938	12659	Economy	8200.00
0005434023922	12659	Economy	8200.00
0005433684442	12659	Economy	8200.00
0005433058279	12659	Economy	8200.00
0005434735745	12659	Economy	8200.00
0005434023669	12659	Economy	8200.00
0005433058307	12659	Economy	8200.00
0005433058305	12659	Economy	8200.00
0005432156415	12659	Economy	8200.00
0005433058304	12659	Economy	8200.00
0005433058317	12659	Economy	8200.00
0005433924316	2148	Business	34700.00
0005433036329	2148	Business	34700.00
0005433924280	2148	Business	34700.00
0005433036477	2148	Business	34700.00
0005433036349	2148	Business	34700.00
0005433931497	2148	Business	34700.00
0005433036429	2148	Business	34700.00
0005433924263	2148	Business	34700.00
0005433924288	2148	Business	34700.00
0005433924304	2148	Business	34700.00
0005433036472	2148	Business	34700.00
0005433924275	2148	Business	34700.00
0005433036510	2148	Business	34700.00
0005433924277	2148	Business	34700.00
0005434028301	2148	Business	34700.00
0005433036524	2148	Business	34700.00
0005433924290	2148	Business	34700.00
0005433924327	2148	Business	34700.00
0005433924311	2148	Business	34700.00
0005433924320	2148	Business	34700.00
0005433924317	2148	Business	34700.00
0005433924286	2148	Business	34700.00
0005433924261	2148	Business	34700.00
0005433924243	2148	Business	34700.00
0005433036336	2148	Economy	12700.00
0005433924297	2148	Economy	12700.00
0005433924239	2148	Economy	12700.00
0005433924260	2148	Economy	11600.00
0005433036301	2148	Economy	11600.00
0005433036443	2148	Economy	11600.00
0005433924334	2148	Economy	11600.00
0005433924244	2148	Economy	11600.00
0005433036333	2148	Economy	11600.00
0005433036393	2148	Economy	11600.00
0005433924309	2148	Economy	11600.00
0005433036326	2148	Economy	11600.00
0005433924266	2148	Economy	11600.00
0005433924255	2148	Economy	11600.00
0005433924265	2148	Economy	11600.00
0005433924256	2148	Economy	11600.00
0005433924259	2148	Economy	11600.00
0005432749783	2148	Economy	11600.00
0005433924273	2148	Economy	11600.00
0005433924318	2148	Economy	11600.00
0005433036509	2148	Economy	11600.00
0005432231677	2148	Economy	11600.00
0005433036230	2148	Economy	11600.00
0005433924310	2148	Economy	11600.00
0005433924332	2148	Economy	11600.00
0005433036175	2148	Economy	11600.00
0005432231669	2148	Economy	11600.00
0005433924258	2148	Economy	11600.00
0005433924270	2148	Economy	11600.00
0005433924298	2148	Economy	11600.00
0005433924329	2148	Economy	11600.00
0005433924330	2148	Economy	11600.00
0005433036255	2148	Economy	11600.00
0005433924335	2148	Economy	11600.00
0005433924247	2148	Economy	11600.00
0005433924246	2148	Economy	11600.00
0005433924306	2148	Economy	11600.00
0005433924299	2148	Economy	11600.00
0005433036426	2148	Economy	11600.00
0005433924242	2148	Economy	11600.00
0005433924325	2148	Economy	11600.00
0005434028300	2148	Economy	11600.00
0005433036323	2148	Economy	11600.00
0005433036278	2148	Economy	11600.00
0005432231672	2148	Economy	11600.00
0005433924319	2148	Economy	11600.00
0005433036410	2148	Economy	11600.00
0005433924303	2148	Economy	11600.00
0005433036442	2148	Economy	11600.00
0005432231670	2148	Economy	11600.00
0005433036413	2148	Economy	11600.00
0005433924251	2148	Economy	11600.00
0005433036478	2148	Economy	11600.00
0005433036473	2148	Economy	11600.00
0005433924284	2148	Economy	11600.00
0005433924323	2148	Economy	11600.00
0005433036229	2148	Economy	11600.00
0005433929654	2148	Economy	11600.00
0005433036268	2148	Economy	11600.00
0005433036414	2148	Economy	11600.00
0005433924269	2148	Economy	11600.00
0005433036471	2148	Economy	11600.00
0005433036448	2148	Economy	11600.00
0005433924248	2148	Economy	11600.00
0005433924292	2148	Economy	11600.00
0005433924315	2148	Economy	11600.00
0005432749782	2148	Economy	11600.00
0005433924301	2148	Economy	11600.00
0005433924291	2148	Economy	11600.00
0005433924262	2148	Economy	11600.00
0005432231675	2148	Economy	11600.00
0005433924279	2148	Economy	11600.00
0005433924249	2148	Economy	11600.00
0005433924278	2148	Economy	11600.00
0005433924321	2148	Economy	11600.00
0005433924281	2148	Economy	11600.00
0005433924296	2148	Economy	11600.00
0005433924264	2148	Economy	11600.00
0005433924276	2148	Economy	11600.00
0005432231671	2148	Economy	11600.00
0005433929656	2148	Economy	11600.00
0005433036427	2148	Economy	11600.00
0005433924302	2148	Economy	11600.00
0005433924289	2148	Economy	11600.00
0005433924252	2148	Economy	11600.00
0005433036627	2148	Economy	11600.00
0005433924254	2148	Economy	11600.00
0005433924312	2148	Economy	12700.00
0005433924295	2148	Economy	12700.00
0005432231673	2148	Economy	11600.00
0005433924257	2148	Economy	11600.00
0005433036226	2148	Economy	11600.00
0005433036529	2148	Economy	11600.00
0005433924314	2148	Economy	11600.00
0005433924328	2148	Economy	11600.00
0005433929657	2148	Economy	11600.00
0005433924267	2148	Economy	11600.00
0005433924274	2148	Economy	11600.00
0005433036523	2148	Economy	11600.00
0005433924294	2148	Economy	11600.00
0005432044554	2148	Economy	11600.00
0005433036554	2148	Economy	11600.00
0005433924307	2148	Economy	11600.00
0005433036476	2148	Economy	11600.00
0005432231674	2148	Economy	11600.00
0005433924285	2148	Economy	11600.00
0005433924283	2148	Economy	11600.00
0005433924300	2148	Economy	11600.00
0005433924322	2148	Economy	11600.00
0005433036277	2148	Economy	11600.00
0005433036328	2148	Economy	11600.00
0005433036244	2148	Economy	11600.00
0005433036628	2148	Economy	11600.00
0005433931499	2148	Economy	11600.00
0005433924241	2148	Economy	11600.00
0005433924293	2148	Economy	11600.00
0005433931496	2148	Economy	11600.00
0005433036245	2148	Economy	11600.00
0005433924250	2148	Economy	11600.00
0005433036441	2148	Economy	11600.00
0005433036122	2148	Economy	11600.00
0005433036327	2148	Economy	11600.00
0005433924272	2148	Economy	11600.00
0005433931498	2148	Economy	11600.00
0005433924333	2148	Economy	11600.00
0005433036512	2148	Economy	11600.00
0005432749792	2148	Economy	11600.00
0005433924331	2148	Economy	11600.00
0005433924253	2148	Economy	11600.00
0005433036377	2148	Economy	11600.00
0005433924271	2148	Economy	11600.00
0005433924287	2148	Economy	11600.00
0005433924268	2148	Economy	11600.00
0005433036392	2148	Economy	11600.00
0005432044553	2148	Economy	11600.00
0005433875393	2148	Economy	11600.00
0005433036481	2148	Economy	11600.00
0005433924240	2148	Economy	11600.00
0005433924308	2148	Economy	11600.00
0005433924313	2148	Economy	11600.00
0005433924245	2148	Economy	11600.00
0005433036325	2148	Economy	11600.00
0005433924326	2148	Economy	11600.00
0005433036419	2148	Economy	11600.00
0005433036447	2148	Economy	11600.00
0005432044552	2148	Economy	11600.00
0005433924282	2148	Economy	11600.00
0005433036513	2148	Economy	11600.00
0005432231678	2148	Economy	11600.00
0005433924305	2148	Economy	11600.00
0005433924324	2148	Economy	11600.00
0005433036446	2148	Economy	11600.00
0005432231676	2148	Economy	11600.00
0005433929655	2148	Economy	11600.00
0005433036409	2148	Economy	11600.00
0005433923329	24098	Business	34700.00
0005433923440	24098	Business	34700.00
0005433923268	24098	Business	34700.00
0005433923327	24098	Business	34700.00
0005433036855	24098	Business	34700.00
0005432207688	24098	Business	34700.00
0005433036818	24098	Business	34700.00
0005433036827	24098	Business	34700.00
0005433923409	24098	Business	34700.00
0005433923658	24098	Business	34700.00
0005433923596	24098	Business	34700.00
0005433923604	24098	Business	34700.00
0005433923752	24098	Business	34700.00
0005433923568	24098	Business	34700.00
0005433923441	24098	Business	34700.00
0005433923574	24098	Business	34700.00
0005433923115	24098	Business	34700.00
0005433923211	24098	Business	34700.00
0005433036819	24098	Business	34700.00
0005433923605	24098	Business	34700.00
0005433923380	24098	Business	34700.00
0005433923675	24098	Business	34700.00
0005433923304	24098	Economy	12700.00
0005433036851	24098	Economy	12700.00
0005433922910	24098	Economy	12700.00
0005433036848	24098	Economy	12700.00
0005433036867	24098	Economy	11600.00
0005433036856	24098	Economy	11600.00
0005433036847	24098	Economy	11600.00
0005432206254	24098	Economy	11600.00
0005433036837	24098	Economy	11600.00
0005433923310	24098	Economy	11600.00
0005433924004	24098	Economy	11600.00
0005433923228	24098	Economy	11600.00
0005433036849	24098	Economy	11600.00
0005433923573	24098	Economy	11600.00
0005433036834	24098	Economy	11600.00
0005433929622	24098	Economy	11600.00
0005433923245	24098	Economy	11600.00
0005433923761	24098	Economy	11600.00
0005433923512	24098	Economy	11600.00
0005433036821	24098	Economy	11600.00
0005433922943	24098	Economy	11600.00
0005433036835	24098	Economy	11600.00
0005433923371	24098	Economy	11600.00
0005433036820	24098	Economy	11600.00
0005433036841	24098	Economy	11600.00
0005433923503	24098	Economy	11600.00
0005432749809	24098	Economy	11600.00
0005433923326	24098	Economy	11600.00
0005433923483	24098	Economy	11600.00
0005433036828	24098	Economy	11600.00
0005433931474	24098	Economy	11600.00
0005433923270	24098	Economy	11600.00
0005433036824	24098	Economy	11600.00
0005433036860	24098	Economy	11600.00
0005433036844	24098	Economy	11600.00
0005433923266	24098	Economy	11600.00
0005433923008	24098	Economy	11600.00
0005433924020	24098	Economy	11600.00
0005433036842	24098	Economy	11600.00
0005433036865	24098	Economy	11600.00
0005432206253	24098	Economy	11600.00
0005433923876	24098	Economy	11600.00
0005433923717	24098	Economy	11600.00
0005433923271	24098	Economy	11600.00
0005433923697	24098	Economy	11600.00
0005433036832	24098	Economy	11600.00
0005433036858	24098	Economy	11600.00
0005433923298	24098	Economy	11600.00
0005433923183	24098	Economy	11600.00
0005433036852	24098	Economy	11600.00
0005433931473	24098	Economy	11600.00
0005433036853	24098	Economy	11600.00
0005433036864	24098	Economy	11600.00
0005433923530	24098	Economy	11600.00
0005433923933	24098	Economy	11600.00
0005433923631	24098	Economy	11600.00
0005433923903	24098	Economy	11600.00
0005433923623	24098	Economy	11600.00
0005433923311	24098	Economy	11600.00
0005433923484	24098	Economy	11600.00
0005433923269	24098	Economy	11600.00
0005433923904	24098	Economy	11600.00
0005432207687	24098	Economy	11600.00
0005433923499	24098	Economy	11600.00
0005433931472	24098	Economy	11600.00
0005433036857	24098	Economy	11600.00
0005433036862	24098	Economy	11600.00
0005433036823	24098	Economy	11600.00
0005433923575	24098	Economy	11600.00
0005433922909	24098	Economy	11600.00
0005433929614	24098	Economy	11600.00
0005434028326	24098	Economy	11600.00
0005433923720	24098	Economy	11600.00
0005433929620	24098	Economy	11600.00
0005433923521	24098	Economy	11600.00
0005433923233	24098	Economy	11600.00
0005433036833	24098	Economy	11600.00
0005433923328	24098	Economy	11600.00
0005433036866	24098	Economy	11600.00
0005432206256	24098	Economy	11600.00
0005433036861	24098	Economy	11600.00
0005432749808	24098	Economy	11600.00
0005433923751	24098	Economy	11600.00
0005433923159	24098	Economy	11600.00
0005433923007	24098	Economy	12700.00
0005433923606	24098	Economy	11600.00
0005432206258	24098	Economy	11600.00
0005432749807	24098	Economy	11600.00
0005433923740	24098	Economy	12700.00
0005433923727	24098	Economy	12700.00
0005433922972	24098	Economy	11600.00
0005433929623	24098	Economy	11600.00
0005433923232	24098	Economy	11600.00
0005433923828	24098	Economy	11600.00
0005433923212	24098	Economy	11600.00
0005433923831	24098	Economy	11600.00
0005433923433	24098	Economy	11600.00
0005433036854	24098	Economy	11600.00
0005433036817	24098	Economy	11600.00
0005433923624	24098	Economy	11600.00
0005433923567	24098	Economy	11600.00
0005433923712	24098	Economy	11600.00
0005433923489	24098	Economy	11600.00
0005433036814	24098	Economy	11600.00
0005433923603	24098	Economy	11600.00
0005433036830	24098	Economy	11600.00
0005433923500	24098	Economy	11600.00
0005434028327	24098	Economy	11600.00
0005433036836	24098	Economy	11600.00
0005433923760	24098	Economy	11600.00
0005433923309	24098	Economy	11600.00
0005433036840	24098	Economy	11600.00
0005433923674	24098	Economy	11600.00
0005432206257	24098	Economy	11600.00
0005433923365	24098	Economy	11600.00
0005433923869	24098	Economy	11600.00
0005433923576	24098	Economy	11600.00
0005434028325	24098	Economy	11600.00
0005433036825	24098	Economy	11600.00
0005432206255	24098	Economy	11600.00
0005433036831	24098	Economy	11600.00
0005433036845	24098	Economy	11600.00
0005433923875	24098	Economy	11600.00
0005433923515	24098	Economy	11600.00
0005433923419	24098	Economy	11600.00
0005433036815	24098	Economy	11600.00
0005433923934	24098	Economy	11600.00
0005433923325	24098	Economy	11600.00
0005433923726	24098	Economy	11600.00
0005434028324	24098	Economy	11600.00
0005433036829	24098	Economy	11600.00
0005433036816	24098	Economy	11600.00
0005433036826	24098	Economy	11600.00
0005433923739	24098	Economy	11600.00
0005433923528	24098	Economy	11600.00
0005433923562	24098	Economy	11600.00
0005433036843	24098	Economy	11600.00
0005433036863	24098	Economy	11600.00
0005433929615	24098	Economy	11600.00
0005433923759	24098	Economy	11600.00
0005433923379	24098	Economy	11600.00
0005432207689	24098	Economy	11600.00
0005433923116	24098	Economy	11600.00
0005433036859	24098	Economy	11600.00
0005433036846	24098	Economy	11600.00
0005433036839	24098	Economy	11600.00
0005433036838	24098	Economy	11600.00
0005433929621	24098	Economy	11600.00
0005433036822	24098	Economy	11600.00
0005433036850	24098	Economy	11600.00
0005433923267	24098	Economy	11600.00
0005434726756	289	Business	83700.00
0005434032038	289	Business	83700.00
0005434726666	289	Business	83700.00
0005434302503	289	Business	83700.00
0005433234555	289	Business	83700.00
0005434551783	289	Business	83700.00
0005434726739	289	Business	83700.00
0005434726751	289	Business	83700.00
0005433181215	289	Business	83700.00
0005434726743	289	Business	83700.00
0005434551775	289	Business	83700.00
0005434726780	289	Business	83700.00
0005433131701	289	Business	83700.00
0005434726706	289	Business	83700.00
0005433181065	289	Business	83700.00
0005434726771	289	Business	83700.00
0005434731211	289	Business	83700.00
0005434726729	289	Business	83700.00
0005434551785	289	Business	83700.00
0005434726763	289	Business	83700.00
0005434551774	289	Business	83700.00
0005433766650	289	Comfort	47400.00
0005434726766	289	Comfort	47400.00
0005434726727	289	Comfort	47400.00
0005434726717	289	Comfort	47400.00
0005433234056	289	Comfort	47400.00
0005434726758	289	Comfort	47400.00
0005434726769	289	Comfort	47400.00
0005435142716	289	Comfort	47400.00
0005434726725	289	Comfort	47400.00
0005434551789	289	Comfort	47400.00
0005435142720	289	Comfort	47400.00
0005434551822	289	Comfort	47400.00
0005433766652	289	Comfort	47400.00
0005433289822	289	Comfort	47400.00
0005433181072	289	Comfort	47400.00
0005434726730	289	Comfort	47400.00
0005434551805	289	Comfort	47400.00
0005434726670	289	Comfort	47400.00
0005433131705	289	Comfort	47400.00
0005433234201	289	Comfort	47400.00
0005434726721	289	Comfort	47400.00
0005433181234	289	Comfort	47400.00
0005433234255	289	Comfort	47400.00
0005433234275	289	Comfort	47400.00
0005433181182	289	Comfort	47400.00
0005433113535	289	Comfort	47400.00
0005434726678	289	Comfort	47400.00
0005434726736	289	Comfort	47400.00
0005434726731	289	Comfort	47400.00
0005433126852	289	Comfort	47400.00
0005432277940	289	Comfort	47400.00
0005433181167	289	Comfort	47400.00
0005432277950	289	Comfort	47400.00
0005434726682	289	Comfort	47400.00
0005435142719	289	Comfort	47400.00
0005433234554	289	Comfort	47400.00
0005434726757	289	Comfort	47400.00
0005434731210	289	Comfort	47400.00
0005434726712	289	Comfort	47400.00
0005434032028	289	Economy	27900.00
0005434551768	289	Economy	27900.00
0005434726722	289	Economy	27900.00
0005434551788	289	Economy	27900.00
0005434726667	289	Economy	27900.00
0005434726693	289	Economy	27900.00
0005434551807	289	Economy	27900.00
0005435142715	289	Economy	27900.00
0005434726719	289	Economy	27900.00
0005433181142	289	Economy	27900.00
0005434032039	289	Economy	27900.00
0005434726704	289	Economy	27900.00
0005434726710	289	Economy	27900.00
0005433234406	289	Economy	27900.00
0005433234194	289	Economy	27900.00
0005435142711	289	Economy	27900.00
0005434726752	289	Economy	27900.00
0005434551815	289	Economy	27900.00
0005433234256	289	Economy	27900.00
0005434726709	289	Economy	27900.00
0005433234195	289	Economy	27900.00
0005432277951	289	Economy	27900.00
0005434726770	289	Economy	27900.00
0005434032020	289	Economy	27900.00
0005434302502	289	Economy	27900.00
0005433234358	289	Economy	27900.00
0005434551804	289	Economy	27900.00
0005434726691	289	Economy	27900.00
0005433234350	289	Economy	27900.00
0005434731208	289	Economy	27900.00
0005433181160	289	Economy	27900.00
0005433234189	289	Economy	27900.00
0005434302505	289	Economy	27900.00
0005434726777	289	Economy	27900.00
0005434726700	289	Economy	27900.00
0005433181050	289	Economy	27900.00
0005433234137	289	Economy	27900.00
0005433234114	289	Economy	27900.00
0005433234301	289	Economy	27900.00
0005434551796	289	Economy	27900.00
0005433234490	289	Economy	27900.00
0005432277945	289	Economy	27900.00
0005434726755	289	Economy	27900.00
0005434726695	289	Economy	27900.00
0005433234156	289	Economy	27900.00
0005432277949	289	Economy	27900.00
0005434726768	289	Economy	27900.00
0005434551817	289	Economy	27900.00
0005433289848	289	Economy	27900.00
0005434551818	289	Economy	27900.00
0005433234277	289	Economy	27900.00
0005434726745	289	Economy	27900.00
0005432277942	289	Economy	27900.00
0005433126854	289	Economy	27900.00
0005432277944	289	Economy	27900.00
0005433234340	289	Economy	27900.00
0005433234216	289	Economy	30700.00
0005434735739	289	Economy	30700.00
0005434726734	289	Economy	27900.00
0005434726669	289	Economy	27900.00
0005434726778	289	Economy	27900.00
0005433234274	289	Economy	27900.00
0005433234403	289	Economy	30700.00
0005434551813	289	Economy	30700.00
0005432277946	289	Economy	27900.00
0005433181133	289	Economy	27900.00
0005434726697	289	Economy	27900.00
0005433766651	289	Economy	27900.00
0005434726748	289	Economy	27900.00
0005433234118	289	Economy	27900.00
0005434726672	289	Economy	27900.00
0005434726708	289	Economy	27900.00
0005434726659	289	Economy	27900.00
0005434726688	289	Economy	27900.00
0005433289866	289	Economy	27900.00
0005434726685	289	Economy	27900.00
0005434726713	289	Economy	27900.00
0005434032034	289	Economy	27900.00
0005433181168	289	Economy	27900.00
0005434551806	289	Economy	27900.00
0005433234556	289	Economy	27900.00
0005435142714	289	Economy	27900.00
0005435142721	289	Economy	27900.00
0005434302875	289	Economy	27900.00
0005434551800	289	Economy	27900.00
0005433181080	289	Economy	27900.00
0005434726703	289	Economy	27900.00
0005434726663	289	Economy	27900.00
0005433181071	289	Economy	27900.00
0005434726698	289	Economy	27900.00
0005433181139	289	Economy	27900.00
0005434726750	289	Economy	27900.00
0005433131696	289	Economy	27900.00
0005433126853	289	Economy	27900.00
0005434302504	289	Economy	27900.00
0005434726728	289	Economy	27900.00
0005434726726	289	Economy	27900.00
0005433234388	289	Economy	27900.00
0005433234399	289	Economy	27900.00
0005434726720	289	Economy	27900.00
0005433234300	289	Economy	27900.00
0005434726776	289	Economy	27900.00
0005433181206	289	Economy	27900.00
0005434726738	289	Economy	27900.00
0005433234119	289	Economy	27900.00
0005434731209	289	Economy	27900.00
0005433234160	289	Economy	27900.00
0005433234168	289	Economy	27900.00
0005433234319	289	Economy	27900.00
0005434551799	289	Economy	27900.00
0005435142710	289	Economy	27900.00
0005434551816	289	Economy	27900.00
0005434551781	289	Economy	27900.00
0005434726683	289	Economy	27900.00
0005432277953	289	Economy	27900.00
0005434726723	289	Economy	27900.00
0005434551776	289	Economy	27900.00
0005433234068	289	Economy	27900.00
0005433766625	289	Economy	27900.00
0005434726772	289	Economy	27900.00
0005434735741	289	Economy	27900.00
0005434551802	289	Economy	27900.00
0005434735740	289	Economy	27900.00
0005434726664	289	Economy	27900.00
0005434726680	289	Economy	27900.00
0005434726747	289	Economy	27900.00
0005434726674	289	Economy	27900.00
0005434726702	289	Economy	27900.00
0005435142722	289	Economy	27900.00
0005434726716	289	Economy	27900.00
0005434551787	289	Economy	27900.00
0005434551790	289	Economy	27900.00
0005434726759	289	Economy	27900.00
0005434726668	289	Economy	27900.00
0005434726735	289	Economy	27900.00
0005432277941	289	Economy	27900.00
0005434551823	289	Economy	27900.00
0005433234036	289	Economy	27900.00
0005433289867	289	Economy	27900.00
0005434726724	289	Economy	27900.00
0005433234232	289	Economy	27900.00
0005434735737	289	Economy	27900.00
0005434726718	289	Economy	27900.00
0005434551797	289	Economy	27900.00
0005434735736	289	Economy	27900.00
0005434551801	289	Economy	27900.00
0005434551819	289	Economy	27900.00
0005433234511	289	Economy	27900.00
0005433181158	289	Economy	27900.00
0005434551812	289	Economy	27900.00
0005434726694	289	Economy	27900.00
0005434032021	289	Economy	27900.00
0005434726775	289	Economy	27900.00
0005434726765	289	Economy	27900.00
0005434551778	289	Economy	27900.00
0005433181207	289	Economy	27900.00
0005434551793	289	Economy	27900.00
0005434551820	289	Economy	27900.00
0005434551810	289	Economy	27900.00
0005433289868	289	Economy	27900.00
0005433234228	289	Economy	27900.00
0005433234281	289	Economy	27900.00
0005433181183	289	Economy	30700.00
0005434726737	289	Economy	30700.00
0005434726673	289	Economy	30700.00
0005434726658	289	Economy	30700.00
0005434726705	289	Economy	30700.00
0005432277947	289	Economy	27900.00
0005433233854	289	Economy	27900.00
0005434735738	289	Economy	27900.00
0005433181049	289	Economy	27900.00
0005434726767	289	Economy	27900.00
0005434726671	289	Economy	27900.00
0005434551769	289	Economy	27900.00
0005434551811	289	Economy	27900.00
0005434551777	289	Economy	27900.00
0005434726689	289	Economy	27900.00
0005434726707	289	Economy	27900.00
0005433126829	289	Economy	27900.00
0005434726764	289	Economy	27900.00
0005434551791	289	Economy	27900.00
0005434726665	289	Economy	27900.00
0005434726676	289	Economy	27900.00
0005434726741	289	Economy	27900.00
0005434551794	289	Economy	27900.00
0005433181169	289	Economy	27900.00
0005434551808	289	Economy	27900.00
0005433181151	289	Economy	27900.00
0005433234120	289	Economy	27900.00
0005434726696	289	Economy	27900.00
0005433181147	289	Economy	27900.00
0005434032019	289	Economy	27900.00
0005435142713	289	Economy	27900.00
0005435142723	289	Economy	27900.00
0005434726761	289	Economy	27900.00
0005433234136	289	Economy	27900.00
0005434551786	289	Economy	27900.00
0005435142712	289	Economy	27900.00
0005433234422	289	Economy	27900.00
0005435142717	289	Economy	27900.00
0005434726733	289	Economy	27900.00
0005434032035	289	Economy	27900.00
0005434551773	289	Economy	27900.00
0005434551779	289	Economy	27900.00
0005433234191	289	Economy	27900.00
0005434726660	289	Economy	27900.00
0005432277952	289	Economy	27900.00
0005432277948	289	Economy	27900.00
0005434726690	289	Economy	27900.00
0005434726662	289	Economy	27900.00
0005433181225	289	Economy	27900.00
0005434551770	289	Economy	27900.00
0005434551782	289	Economy	27900.00
0005434726773	289	Economy	27900.00
0005433234086	289	Economy	27900.00
0005434551821	289	Economy	27900.00
0005434551798	289	Economy	27900.00
0005434726740	289	Economy	27900.00
0005434726661	289	Economy	27900.00
0005434726711	289	Economy	27900.00
0005434726714	289	Economy	27900.00
0005433234190	289	Economy	27900.00
0005434551814	289	Economy	27900.00
0005433131702	289	Economy	27900.00
0005433181214	289	Economy	27900.00
0005433234104	289	Economy	27900.00
0005434726701	289	Economy	27900.00
0005434726753	289	Economy	27900.00
0005434726675	289	Economy	27900.00
0005434726699	289	Economy	27900.00
0005434726760	289	Economy	27900.00
0005434726692	289	Economy	27900.00
0005433111506	289	Economy	27900.00
0005433233855	289	Economy	27900.00
0005434726746	289	Economy	27900.00
0005434726732	289	Economy	27900.00
0005434726715	289	Economy	27900.00
0005434551771	289	Economy	27900.00
0005434726774	289	Economy	27900.00
0005433234394	289	Economy	27900.00
0005434726749	289	Economy	27900.00
0005434726742	289	Economy	27900.00
0005433234393	289	Economy	27900.00
0005435142718	289	Economy	27900.00
0005434551772	289	Economy	27900.00
0005434726684	289	Economy	27900.00
0005434551792	289	Economy	27900.00
0005434731212	289	Economy	27900.00
0005434726681	289	Economy	27900.00
0005433234280	289	Economy	27900.00
0005434302876	289	Economy	27900.00
0005434551803	289	Economy	27900.00
0005434726754	289	Economy	27900.00
0005433234127	289	Economy	27900.00
0005434726686	289	Economy	27900.00
0005433181226	289	Economy	27900.00
0005434726687	289	Economy	27900.00
0005434726744	289	Economy	27900.00
0005433289874	289	Economy	27900.00
0005433289850	289	Economy	27900.00
0005434551784	289	Economy	27900.00
0005432277943	289	Economy	27900.00
0005434551809	289	Economy	27900.00
0005434726677	289	Economy	27900.00
0005434726779	289	Economy	27900.00
0005434551780	289	Economy	27900.00
0005434726762	289	Economy	27900.00
0005434726679	289	Economy	27900.00
0005434551795	289	Economy	27900.00
0005434725494	9819	Business	83700.00
0005434725495	9819	Business	83700.00
0005434725707	9819	Business	83700.00
0005434725421	9819	Business	83700.00
0005434731175	9819	Business	83700.00
0005434725189	9819	Business	83700.00
0005433126893	9819	Business	83700.00
0005433234847	9819	Business	83700.00
0005434551153	9819	Business	83700.00
0005434551043	9819	Business	83700.00
0005433234821	9819	Business	83700.00
0005433234837	9819	Business	83700.00
0005433234884	9819	Business	83700.00
0005434725496	9819	Business	83700.00
0005434725865	9819	Business	83700.00
0005433234870	9819	Business	83700.00
0005435142624	9819	Business	83700.00
0005434725211	9819	Business	83700.00
0005434551536	9819	Business	83700.00
0005434726091	9819	Business	83700.00
0005434302465	9819	Business	83700.00
0005433181366	9819	Business	83700.00
0005434725823	9819	Business	83700.00
0005433234827	9819	Business	83700.00
0005434725849	9819	Business	83700.00
0005434551436	9819	Business	83700.00
0005434725971	9819	Business	83700.00
0005433113559	9819	Comfort	47400.00
0005434725351	9819	Business	83700.00
0005434725980	9819	Comfort	47400.00
0005433234872	9819	Comfort	47400.00
0005434551469	9819	Comfort	47400.00
0005433181349	9819	Comfort	47400.00
0005434726052	9819	Comfort	47400.00
0005435142560	9819	Comfort	47400.00
0005434725188	9819	Comfort	47400.00
0005433181347	9819	Comfort	47400.00
0005434725750	9819	Comfort	47400.00
0005434725806	9819	Comfort	47400.00
0005433234869	9819	Comfort	47400.00
0005433234871	9819	Comfort	47400.00
0005434725420	9819	Comfort	47400.00
0005434551249	9819	Comfort	47400.00
0005434725882	9819	Comfort	47400.00
0005434551252	9819	Comfort	47400.00
0005434725864	9819	Comfort	47400.00
0005434731189	9819	Comfort	47400.00
0005434551404	9819	Comfort	47400.00
0005434725761	9819	Comfort	47400.00
0005434726149	9819	Comfort	47400.00
0005433234832	9819	Comfort	47400.00
0005434725210	9819	Comfort	47400.00
0005434725999	9819	Comfort	47400.00
0005433126894	9819	Comfort	47400.00
0005434725170	9819	Comfort	47400.00
0005433234880	9819	Comfort	47400.00
0005434551364	9819	Comfort	47400.00
0005432199319	9819	Comfort	47400.00
0005434302471	9819	Comfort	47400.00
0005434725505	9819	Comfort	47400.00
0005434725569	9819	Comfort	47400.00
0005434725615	9819	Comfort	47400.00
0005433234820	9819	Comfort	47400.00
0005434551320	9819	Comfort	47400.00
0005433181353	9819	Comfort	47400.00
0005434726388	9819	Comfort	47400.00
0005433181358	9819	Comfort	47400.00
0005434725998	9819	Comfort	47400.00
0005434725744	9819	Comfort	47400.00
0005434726053	9819	Comfort	47400.00
0005434725718	9819	Comfort	47400.00
0005434726386	9819	Comfort	47400.00
0005432199322	9819	Comfort	47400.00
0005434302451	9819	Economy	27900.00
0005433234828	9819	Comfort	47400.00
0005435142537	9819	Economy	27900.00
0005433234838	9819	Economy	27900.00
0005433181365	9819	Economy	27900.00
0005434725591	9819	Economy	27900.00
0005434731176	9819	Economy	27900.00
0005433234834	9819	Economy	27900.00
0005433181350	9819	Economy	27900.00
0005433234850	9819	Economy	27900.00
0005434725683	9819	Economy	27900.00
0005434551366	9819	Economy	27900.00
0005433181367	9819	Economy	27900.00
0005433234835	9819	Economy	27900.00
0005434725972	9819	Economy	27900.00
0005434725913	9819	Economy	27900.00
0005433181362	9819	Economy	27900.00
0005434551303	9819	Economy	27900.00
0005434726034	9819	Economy	27900.00
0005434735700	9819	Economy	27900.00
0005434725876	9819	Economy	27900.00
0005434725422	9819	Economy	27900.00
0005433234877	9819	Economy	27900.00
0005434725932	9819	Economy	27900.00
0005434551475	9819	Economy	27900.00
0005434302466	9819	Economy	27900.00
0005435142613	9819	Economy	27900.00
0005433181348	9819	Economy	27900.00
0005434551278	9819	Economy	27900.00
0005433234849	9819	Economy	27900.00
0005434725665	9819	Economy	27900.00
0005434551319	9819	Economy	27900.00
0005433234852	9819	Economy	27900.00
0005433234840	9819	Economy	27900.00
0005434731154	9819	Economy	27900.00
0005433234846	9819	Economy	27900.00
0005434725884	9819	Economy	27900.00
0005434725439	9819	Economy	27900.00
0005434725746	9819	Economy	27900.00
0005434032071	9819	Economy	27900.00
0005433181364	9819	Economy	27900.00
0005433181357	9819	Economy	27900.00
0005434551090	9819	Economy	27900.00
0005434725557	9819	Economy	27900.00
0005434725455	9819	Economy	27900.00
0005434725762	9819	Economy	27900.00
0005434725703	9819	Economy	27900.00
0005433129321	9819	Economy	27900.00
0005434735697	9819	Economy	27900.00
0005434725825	9819	Economy	27900.00
0005434551470	9819	Economy	27900.00
0005434725293	9819	Economy	27900.00
0005433181352	9819	Economy	27900.00
0005433234859	9819	Economy	27900.00
0005434551229	9819	Economy	27900.00
0005434725539	9819	Economy	27900.00
0005434725792	9819	Economy	27900.00
0005434725721	9819	Economy	27900.00
0005434551282	9819	Economy	27900.00
0005434725024	9819	Economy	27900.00
0005434725646	9819	Economy	27900.00
0005432199317	9819	Economy	27900.00
0005434302464	9819	Economy	27900.00
0005434726298	9819	Economy	27900.00
0005433234825	9819	Economy	27900.00
0005433126895	9819	Economy	27900.00
0005433234866	9819	Economy	27900.00
0005434725666	9819	Economy	27900.00
0005433289922	9819	Economy	27900.00
0005432199318	9819	Economy	30700.00
0005434725543	9819	Economy	30700.00
0005434725657	9819	Economy	30700.00
0005433234881	9819	Economy	27900.00
0005434735677	9819	Economy	27900.00
0005434725783	9819	Economy	27900.00
0005434551139	9819	Economy	30700.00
0005433181354	9819	Economy	30700.00
0005434725786	9819	Economy	30700.00
0005434725482	9819	Economy	27900.00
0005434725173	9819	Economy	27900.00
0005435142539	9819	Economy	27900.00
0005434735689	9819	Economy	27900.00
0005433181370	9819	Economy	27900.00
0005433234879	9819	Economy	27900.00
0005434551218	9819	Economy	27900.00
0005434725995	9819	Economy	27900.00
0005434725549	9819	Economy	27900.00
0005433234875	9819	Economy	27900.00
0005433234826	9819	Economy	27900.00
0005433181346	9819	Economy	27900.00
0005434551158	9819	Economy	27900.00
0005433181369	9819	Economy	27900.00
0005434725720	9819	Economy	27900.00
0005435142563	9819	Economy	27900.00
0005434725570	9819	Economy	27900.00
0005435142556	9819	Economy	27900.00
0005433234822	9819	Economy	27900.00
0005432199316	9819	Economy	27900.00
0005433766678	9819	Economy	27900.00
0005434725650	9819	Economy	27900.00
0005434726109	9819	Economy	27900.00
0005434551305	9819	Economy	27900.00
0005433766680	9819	Economy	27900.00
0005434726110	9819	Economy	27900.00
0005434731173	9819	Economy	27900.00
0005434551157	9819	Economy	27900.00
0005434551371	9819	Economy	27900.00
0005433129322	9819	Economy	27900.00
0005434551154	9819	Economy	27900.00
0005434725597	9819	Economy	27900.00
0005434551343	9819	Economy	27900.00
0005434725875	9819	Economy	27900.00
0005434551548	9819	Economy	27900.00
0005434725667	9819	Economy	27900.00
0005434551149	9819	Economy	27900.00
0005433181361	9819	Economy	27900.00
0005433234868	9819	Economy	27900.00
0005434725889	9819	Economy	27900.00
0005434551039	9819	Economy	27900.00
0005435142602	9819	Economy	27900.00
0005434551437	9819	Economy	27900.00
0005435142538	9819	Economy	27900.00
0005434725304	9819	Economy	27900.00
0005434735699	9819	Economy	27900.00
0005434551284	9819	Economy	27900.00
0005434551259	9819	Economy	27900.00
0005434725474	9819	Economy	27900.00
0005434731174	9819	Economy	27900.00
0005433289918	9819	Economy	27900.00
0005434032074	9819	Economy	27900.00
0005433234860	9819	Economy	27900.00
0005434725546	9819	Economy	27900.00
0005433234823	9819	Economy	27900.00
0005435142559	9819	Economy	27900.00
0005434302469	9819	Economy	27900.00
0005433234839	9819	Economy	27900.00
0005433129323	9819	Economy	27900.00
0005434726131	9819	Economy	27900.00
0005434551267	9819	Economy	27900.00
0005433234876	9819	Economy	27900.00
0005434551260	9819	Economy	27900.00
0005433181351	9819	Economy	27900.00
0005434725169	9819	Economy	27900.00
0005434725651	9819	Economy	27900.00
0005433234882	9819	Economy	27900.00
0005434551073	9819	Economy	27900.00
0005433126891	9819	Economy	27900.00
0005434302452	9819	Economy	27900.00
0005434725107	9819	Economy	27900.00
0005434551270	9819	Economy	27900.00
0005434551250	9819	Economy	27900.00
0005434725644	9819	Economy	27900.00
0005433234857	9819	Economy	27900.00
0005435142568	9819	Economy	27900.00
0005434731155	9819	Economy	27900.00
0005434551089	9819	Economy	27900.00
0005433234848	9819	Economy	27900.00
0005434551331	9819	Economy	27900.00
0005434551044	9819	Economy	27900.00
0005433113557	9819	Economy	27900.00
0005434725802	9819	Economy	27900.00
0005434725645	9819	Economy	27900.00
0005434725023	9819	Economy	27900.00
0005434725827	9819	Economy	27900.00
0005434726387	9819	Economy	27900.00
0005434725544	9819	Economy	27900.00
0005433181355	9819	Economy	27900.00
0005434551078	9819	Economy	27900.00
0005434032073	9819	Economy	27900.00
0005434551365	9819	Economy	27900.00
0005433234855	9819	Economy	27900.00
0005433181360	9819	Economy	27900.00
0005435142578	9819	Economy	27900.00
0005433234873	9819	Economy	27900.00
0005433289923	9819	Economy	27900.00
0005434726150	9819	Economy	27900.00
0005433234854	9819	Economy	27900.00
0005434725668	9819	Economy	27900.00
0005433113558	9819	Economy	27900.00
0005434725826	9819	Economy	27900.00
0005433234874	9819	Economy	27900.00
0005435142587	9819	Economy	27900.00
0005433234864	9819	Economy	27900.00
0005433234831	9819	Economy	27900.00
0005433234833	9819	Economy	27900.00
0005434551060	9819	Economy	27900.00
0005435142603	9819	Economy	27900.00
0005434725784	9819	Economy	27900.00
0005434725620	9819	Economy	30700.00
0005434551217	9819	Economy	30700.00
0005434725340	9819	Economy	30700.00
0005434725822	9819	Economy	30700.00
0005434302470	9819	Economy	30700.00
0005434725933	9819	Economy	30700.00
0005433234865	9819	Economy	27900.00
0005433234844	9819	Economy	27900.00
0005433234878	9819	Economy	27900.00
0005434551285	9819	Economy	27900.00
0005433181363	9819	Economy	27900.00
0005432199320	9819	Economy	27900.00
0005433289924	9819	Economy	27900.00
0005434551549	9819	Economy	27900.00
0005434725606	9819	Economy	27900.00
0005433234843	9819	Economy	27900.00
0005434725445	9819	Economy	27900.00
0005433234824	9819	Economy	27900.00
0005434726235	9819	Economy	27900.00
0005434724875	9819	Economy	27900.00
0005433234856	9819	Economy	27900.00
0005434551509	9819	Economy	27900.00
0005434032072	9819	Economy	27900.00
0005434551088	9819	Economy	27900.00
0005434725106	9819	Economy	27900.00
0005434032070	9819	Economy	27900.00
0005434551248	9819	Economy	27900.00
0005434551384	9819	Economy	27900.00
0005433234863	9819	Economy	27900.00
0005434551251	9819	Economy	27900.00
0005435142586	9819	Economy	27900.00
0005433181356	9819	Economy	27900.00
0005434551244	9819	Economy	27900.00
0005433126889	9819	Economy	27900.00
0005435142564	9819	Economy	27900.00
0005433234861	9819	Economy	27900.00
0005433234842	9819	Economy	27900.00
0005434726141	9819	Economy	27900.00
0005433234845	9819	Economy	27900.00
0005434725711	9819	Economy	27900.00
0005434725574	9819	Economy	27900.00
0005434725781	9819	Economy	27900.00
0005434725824	9819	Economy	27900.00
0005434551254	9819	Economy	27900.00
0005434725775	9819	Economy	27900.00
0005434551150	9819	Economy	27900.00
0005434725890	9819	Economy	27900.00
0005434725895	9819	Economy	27900.00
0005434725583	9819	Economy	27900.00
0005433289917	9819	Economy	27900.00
0005434725631	9819	Economy	27900.00
0005433234867	9819	Economy	27900.00
0005432199321	9819	Economy	27900.00
0005433181359	9819	Economy	27900.00
0005434725616	9819	Economy	27900.00
0005435142580	9819	Economy	27900.00
0005434726151	9819	Economy	27900.00
0005434725745	9819	Economy	27900.00
0005433289919	9819	Economy	27900.00
0005434735679	9819	Economy	27900.00
0005433234858	9819	Economy	27900.00
0005433234841	9819	Economy	27900.00
0005434735688	9819	Economy	27900.00
0005434725550	9819	Economy	27900.00
0005434725661	9819	Economy	27900.00
0005434551283	9819	Economy	27900.00
0005434551166	9819	Economy	27900.00
0005433129324	9819	Economy	27900.00
0005433181371	9819	Economy	27900.00
0005434551094	9819	Economy	27900.00
0005433289920	9819	Economy	27900.00
0005434725973	9819	Economy	27900.00
0005434551277	9819	Economy	27900.00
0005434725298	9819	Economy	27900.00
0005434725782	9819	Economy	27900.00
0005434725481	9819	Economy	27900.00
0005433234836	9819	Economy	27900.00
0005433234830	9819	Economy	27900.00
0005434551318	9819	Economy	27900.00
0005435142555	9819	Economy	27900.00
0005434726021	9819	Economy	27900.00
0005434726186	9819	Economy	27900.00
0005434551132	9819	Economy	27900.00
0005434735676	9819	Economy	27900.00
0005434551042	9819	Economy	27900.00
0005434725497	9819	Economy	27900.00
0005434725970	9819	Economy	27900.00
0005435142550	9819	Economy	27900.00
0005433289921	9819	Economy	27900.00
0005434726132	9819	Economy	27900.00
0005433181368	9819	Economy	27900.00
0005433234862	9819	Economy	27900.00
0005433234829	9819	Economy	27900.00
0005433234853	9819	Economy	27900.00
0005434551074	9819	Economy	27900.00
0005434551461	9819	Economy	27900.00
0005434735701	9819	Economy	27900.00
0005434725473	9819	Economy	27900.00
0005434725927	9819	Economy	27900.00
0005434725853	9819	Economy	27900.00
0005433126890	9819	Economy	27900.00
0005434725953	9819	Economy	27900.00
0005434735683	9819	Economy	27900.00
0005434725993	9819	Economy	27900.00
0005433234851	9819	Economy	27900.00
0005433234883	9819	Economy	27900.00
0005434551263	9819	Economy	27900.00
0005434551413	9819	Economy	27900.00
0005435142577	9819	Economy	27900.00
0005433113560	9819	Economy	27900.00
0005433126892	9819	Economy	27900.00
0005434551304	9819	Economy	27900.00
0005433766679	9819	Economy	27900.00
0005432150277	7762	Business	42100.00
0005432529353	7762	Business	42100.00
0005432529366	7762	Business	42100.00
0005432529256	7762	Business	42100.00
0005432529330	7762	Business	42100.00
0005435213711	7762	Business	42100.00
0005432533322	7762	Business	42100.00
0005432529284	7762	Business	42100.00
0005432529355	7762	Business	42100.00
0005435213743	7762	Business	42100.00
0005432069800	7762	Business	42100.00
0005432529320	7762	Business	42100.00
0005434068268	7762	Business	42100.00
0005432069801	7762	Business	42100.00
0005432529360	7762	Business	42100.00
0005432529268	7762	Business	42100.00
0005435213709	7762	Business	42100.00
0005432529322	7762	Business	42100.00
0005432529291	7762	Business	42100.00
0005435213574	7762	Business	42100.00
0005432529370	7762	Business	42100.00
0005434068289	7762	Comfort	23900.00
0005435213813	7762	Comfort	23900.00
0005435213664	7762	Comfort	23900.00
0005435630968	7762	Comfort	23900.00
0005435213479	7762	Comfort	23900.00
0005432529290	7762	Comfort	23900.00
0005432529379	7762	Comfort	23900.00
0005432069802	7762	Comfort	23900.00
0005432150276	7762	Comfort	23900.00
0005434068274	7762	Comfort	23900.00
0005432535886	7762	Comfort	23900.00
0005432069810	7762	Comfort	23900.00
0005435213679	7762	Comfort	23900.00
0005435213368	7762	Comfort	23900.00
0005432529335	7762	Comfort	23900.00
0005432529259	7762	Comfort	23900.00
0005435213591	7762	Comfort	23900.00
0005434068299	7762	Comfort	23900.00
0005432529340	7762	Comfort	23900.00
0005432537080	7762	Comfort	23900.00
0005432529348	7762	Comfort	23900.00
0005434068316	7762	Comfort	23900.00
0005432529352	7762	Comfort	23900.00
0005435213765	7762	Comfort	23900.00
0005432529314	7762	Comfort	23900.00
0005432529351	7762	Comfort	23900.00
0005434068263	7762	Comfort	23900.00
0005434068310	7762	Comfort	23900.00
0005435213616	7762	Comfort	23900.00
0005432529333	7762	Comfort	23900.00
0005432150272	7762	Comfort	23900.00
0005432529339	7762	Comfort	23900.00
0005432529338	7762	Comfort	23900.00
0005434068319	7762	Comfort	23900.00
0005432529305	7762	Economy	14000.00
0005432529382	7762	Economy	14000.00
0005432529297	7762	Economy	14000.00
0005434068275	7762	Economy	14000.00
0005432428963	7762	Economy	14000.00
0005434068277	7762	Economy	14000.00
0005432529277	7762	Economy	14000.00
0005432069811	7762	Economy	14000.00
0005432529337	7762	Economy	14000.00
0005432069797	7762	Economy	14000.00
0005432150274	7762	Economy	14000.00
0005434068261	7762	Economy	14000.00
0005432529311	7762	Economy	14000.00
0005432529367	7762	Economy	14000.00
0005434068321	7762	Economy	14000.00
0005432529384	7762	Economy	14000.00
0005432529332	7762	Economy	14000.00
0005434068267	7762	Economy	14000.00
0005432529383	7762	Economy	14000.00
0005434068269	7762	Economy	14000.00
0005432529341	7762	Economy	14000.00
0005435213568	7762	Economy	14000.00
0005432537079	7762	Economy	14000.00
0005432529357	7762	Economy	14000.00
0005434068311	7762	Economy	14000.00
0005432529287	7762	Economy	14000.00
0005433656664	7762	Economy	14000.00
0005432529296	7762	Economy	14000.00
0005432533320	7762	Economy	14000.00
0005434068297	7762	Economy	14000.00
0005432529281	7762	Economy	14000.00
0005435630953	7762	Economy	14000.00
0005432529343	7762	Economy	14000.00
0005432529303	7762	Economy	14000.00
0005432529350	7762	Economy	14000.00
0005434068280	7762	Economy	14000.00
0005435213611	7762	Economy	14000.00
0005432529258	7762	Economy	14000.00
0005435213748	7762	Economy	14000.00
0005435213613	7762	Economy	14000.00
0005432529369	7762	Economy	14000.00
0005432529318	7762	Economy	14000.00
0005432529288	7762	Economy	14000.00
0005432529327	7762	Economy	14000.00
0005435213758	7762	Economy	14000.00
0005434068259	7762	Economy	14000.00
0005432529359	7762	Economy	14000.00
0005432529374	7762	Economy	14000.00
0005432529334	7762	Economy	14000.00
0005432529389	7762	Economy	14000.00
0005435213714	7762	Economy	14000.00
0005432529260	7762	Economy	14000.00
0005432529274	7762	Economy	14000.00
0005432529346	7762	Economy	15400.00
0005434068306	7762	Economy	14000.00
0005432529307	7762	Economy	15400.00
0005435213537	7762	Economy	14000.00
0005434068315	7762	Economy	15400.00
0005432069796	7762	Economy	15400.00
0005432529371	7762	Economy	14000.00
0005435213747	7762	Economy	15400.00
0005432529381	7762	Economy	14000.00
0005435213951	7762	Economy	14000.00
0005432529364	7762	Economy	14000.00
0005435213920	7762	Economy	14000.00
0005434068273	7762	Economy	14000.00
0005435213774	7762	Economy	14000.00
0005432529294	7762	Economy	14000.00
0005434068256	7762	Economy	14000.00
0005432529289	7762	Economy	14000.00
0005432529331	7762	Economy	14000.00
0005432529316	7762	Economy	14000.00
0005432529295	7762	Economy	14000.00
0005432529315	7762	Economy	14000.00
0005435213811	7762	Economy	14000.00
0005432529292	7762	Economy	14000.00
0005434068264	7762	Economy	14000.00
0005432150279	7762	Economy	14000.00
0005432529276	7762	Economy	14000.00
0005434068308	7762	Economy	14000.00
0005435213642	7762	Economy	14000.00
0005432529309	7762	Economy	14000.00
0005432529285	7762	Economy	14000.00
0005432529328	7762	Economy	14000.00
0005432529362	7762	Economy	14000.00
0005434068323	7762	Economy	14000.00
0005432428965	7762	Economy	14000.00
0005432529298	7762	Economy	14000.00
0005432150278	7762	Economy	14000.00
0005434068314	7762	Economy	14000.00
0005435213350	7762	Economy	14000.00
0005435725602	7762	Economy	14000.00
0005432529265	7762	Economy	14000.00
0005432529263	7762	Economy	14000.00
0005434068303	7762	Economy	14000.00
0005434068307	7762	Economy	14000.00
0005432535885	7762	Economy	14000.00
0005434068266	7762	Economy	14000.00
0005435213369	7762	Economy	14000.00
0005434068312	7762	Economy	14000.00
0005432529280	7762	Economy	14000.00
0005432529358	7762	Economy	14000.00
0005434068270	7762	Economy	14000.00
0005434068265	7762	Economy	14000.00
0005432529354	7762	Economy	14000.00
0005432529257	7762	Economy	14000.00
0005432529286	7762	Economy	14000.00
0005434068279	7762	Economy	14000.00
0005432150271	7762	Economy	14000.00
0005432529301	7762	Economy	14000.00
0005434068285	7762	Economy	14000.00
0005434068327	7762	Economy	14000.00
0005432529306	7762	Economy	14000.00
0005432069809	7762	Economy	14000.00
0005432529347	7762	Economy	14000.00
0005435213663	7762	Economy	14000.00
0005432529308	7762	Economy	14000.00
0005432529264	7762	Economy	14000.00
0005434068320	7762	Economy	14000.00
0005434068283	7762	Economy	14000.00
0005434068281	7762	Economy	14000.00
0005432529321	7762	Economy	14000.00
0005435213521	7762	Economy	14000.00
0005434068276	7762	Economy	14000.00
0005432529324	7762	Economy	14000.00
0005432529375	7762	Economy	14000.00
0005434068309	7762	Economy	14000.00
0005432529378	7762	Economy	14000.00
0005432529363	7762	Economy	14000.00
0005434068258	7762	Economy	14000.00
0005435213718	7762	Economy	14000.00
0005435213536	7762	Economy	14000.00
0005432069803	7762	Economy	14000.00
0005435213637	7762	Economy	14000.00
0005432529365	7762	Economy	14000.00
0005435213416	7762	Economy	14000.00
0005435213801	7762	Economy	14000.00
0005435213897	7762	Economy	14000.00
0005433656686	7762	Economy	14000.00
0005432529273	7762	Economy	14000.00
0005434068262	7762	Economy	14000.00
0005434068290	7762	Economy	14000.00
0005435213567	7762	Economy	14000.00
0005432529342	7762	Economy	14000.00
0005432529336	7762	Economy	14000.00
0005434068301	7762	Economy	14000.00
0005432529299	7762	Economy	14000.00
0005434068304	7762	Economy	14000.00
0005432529376	7762	Economy	14000.00
0005432529386	7762	Economy	14000.00
0005433656668	7762	Economy	14000.00
0005432529326	7762	Economy	14000.00
0005435213819	7762	Economy	14000.00
0005432529361	7762	Economy	14000.00
0005434068326	7762	Economy	14000.00
0005432529356	7762	Economy	14000.00
0005434068318	7762	Economy	14000.00
0005432529372	7762	Economy	14000.00
0005434068284	7762	Economy	15400.00
0005435213529	7762	Economy	15400.00
0005434068294	7762	Economy	15400.00
0005434068305	7762	Economy	15400.00
0005432529266	7762	Economy	15400.00
0005435213483	7762	Economy	14000.00
0005432428962	7762	Economy	14000.00
0005432529387	7762	Economy	14000.00
0005432069808	7762	Economy	14000.00
0005434068286	7762	Economy	14000.00
0005432529319	7762	Economy	14000.00
0005432533321	7762	Economy	14000.00
0005435213787	7762	Economy	14000.00
0005434068296	7762	Economy	14000.00
0005435725603	7762	Economy	14000.00
0005435213666	7762	Economy	14000.00
0005432529345	7762	Economy	14000.00
0005432069805	7762	Economy	14000.00
0005434068293	7762	Economy	14000.00
0005432529368	7762	Economy	14000.00
0005432529302	7762	Economy	14000.00
0005434068257	7762	Economy	14000.00
0005435213598	7762	Economy	14000.00
0005434068325	7762	Economy	14000.00
0005432529329	7762	Economy	14000.00
0005435213450	7762	Economy	14000.00
0005435213716	7762	Economy	14000.00
0005432069807	7762	Economy	14000.00
0005432529388	7762	Economy	14000.00
0005432535884	7762	Economy	14000.00
0005432529304	7762	Economy	14000.00
0005434068300	7762	Economy	14000.00
0005434068260	7762	Economy	14000.00
0005432529279	7762	Economy	14000.00
0005432529349	7762	Economy	14000.00
0005432529300	7762	Economy	14000.00
0005432529261	7762	Economy	14000.00
0005434068302	7762	Economy	14000.00
0005435213901	7762	Economy	14000.00
0005432529272	7762	Economy	14000.00
0005435213678	7762	Economy	14000.00
0005435213522	7762	Economy	14000.00
0005432529282	7762	Economy	14000.00
0005434068288	7762	Economy	14000.00
0005435213509	7762	Economy	14000.00
0005435213377	7762	Economy	14000.00
0005432529317	7762	Economy	14000.00
0005432529385	7762	Economy	14000.00
0005434068292	7762	Economy	14000.00
0005434068317	7762	Economy	14000.00
0005432529278	7762	Economy	14000.00
0005432529373	7762	Economy	14000.00
0005433656666	7762	Economy	14000.00
0005434068278	7762	Economy	14000.00
0005432150273	7762	Economy	14000.00
0005434068322	7762	Economy	14000.00
0005432069799	7762	Economy	14000.00
0005434068298	7762	Economy	14000.00
0005435213707	7762	Economy	14000.00
0005432529270	7762	Economy	14000.00
0005432529271	7762	Economy	14000.00
0005435630954	7762	Economy	14000.00
0005432529283	7762	Economy	14000.00
0005432529380	7762	Economy	14000.00
0005432529377	7762	Economy	14000.00
0005432529312	7762	Economy	14000.00
0005434068287	7762	Economy	14000.00
0005432069804	7762	Economy	14000.00
0005432428964	7762	Economy	14000.00
0005432150275	7762	Economy	14000.00
0005435213790	7762	Economy	14000.00
0005435213523	7762	Economy	14000.00
0005432535882	7762	Economy	14000.00
0005435213665	7762	Economy	14000.00
0005432529293	7762	Economy	14000.00
0005432529313	7762	Economy	14000.00
0005435213802	7762	Economy	14000.00
0005435213812	7762	Economy	14000.00
0005434068295	7762	Economy	14000.00
0005432529310	7762	Economy	14000.00
0005432069806	7762	Economy	14000.00
0005433656665	7762	Economy	14000.00
0005432529323	7762	Economy	14000.00
0005434068291	7762	Economy	14000.00
0005434068271	7762	Economy	14000.00
0005434068272	7762	Economy	14000.00
0005432529275	7762	Economy	14000.00
0005432535883	7762	Economy	14000.00
0005432529262	7762	Economy	14000.00
0005434068313	7762	Economy	14000.00
0005432069798	7762	Economy	14000.00
0005432529325	7762	Economy	14000.00
0005432529267	7762	Economy	14000.00
0005432529269	7762	Economy	14000.00
0005435725601	7762	Economy	14000.00
0005435213757	7762	Economy	14000.00
0005432533323	7762	Economy	14000.00
0005434068282	7762	Economy	14000.00
0005432529344	7762	Economy	14000.00
0005434068324	7762	Economy	14000.00
0005432133371	5303	Business	43100.00
0005435614851	5303	Business	43100.00
0005434344569	5303	Business	43100.00
0005435490266	5303	Business	43100.00
0005434573500	5303	Business	43100.00
0005434344580	5303	Business	43100.00
0005435425117	5303	Business	43100.00
0005435425061	5303	Business	43100.00
0005434244979	5303	Business	43100.00
0005434344585	5303	Business	43100.00
0005434344570	5303	Business	43100.00
0005435424970	5303	Business	43100.00
0005435614831	5303	Business	43100.00
0005435614846	5303	Business	43100.00
0005435319625	5303	Business	43100.00
0005432133367	5303	Business	43100.00
0005435425118	5303	Business	43100.00
0005432047588	5303	Business	43100.00
0005434344582	5303	Business	43100.00
0005435425164	5303	Business	43100.00
0005435614773	5303	Business	43100.00
0005434344579	5303	Business	43100.00
0005434245206	5303	Business	43100.00
0005435425186	5303	Business	43100.00
0005435097302	5303	Business	43100.00
0005435425073	5303	Comfort	24400.00
0005435614858	5303	Business	43100.00
0005435614777	5303	Comfort	24400.00
0005434573502	5303	Comfort	24400.00
0005435614755	5303	Comfort	24400.00
0005432363416	5303	Comfort	24400.00
0005435614789	5303	Comfort	24400.00
0005435424979	5303	Comfort	24400.00
0005435614783	5303	Comfort	24400.00
0005435424790	5303	Comfort	24400.00
0005435614762	5303	Comfort	24400.00
0005435424998	5303	Comfort	24400.00
0005435424985	5303	Comfort	24400.00
0005435425122	5303	Comfort	24400.00
0005435424884	5303	Comfort	24400.00
0005435614775	5303	Comfort	24400.00
0005433719155	5303	Comfort	24400.00
0005435097307	5303	Comfort	24400.00
0005435614818	5303	Comfort	24400.00
0005435614824	5303	Comfort	24400.00
0005434245205	5303	Comfort	24400.00
0005435614781	5303	Comfort	24400.00
0005435424986	5303	Comfort	24400.00
0005435424814	5303	Comfort	24400.00
0005435614763	5303	Comfort	24400.00
0005435614797	5303	Comfort	24400.00
0005435614760	5303	Comfort	24400.00
0005435425108	5303	Comfort	24400.00
0005435614800	5303	Comfort	24400.00
0005435491459	5303	Comfort	24400.00
0005432363425	5303	Comfort	24400.00
0005434344589	5303	Comfort	24400.00
0005435614804	5303	Comfort	24400.00
0005434344576	5303	Comfort	24400.00
0005434344588	5303	Comfort	24400.00
0005435614871	5303	Comfort	24400.00
0005435614759	5303	Comfort	24400.00
0005434245070	5303	Comfort	24400.00
0005435614837	5303	Comfort	24400.00
0005434573499	5303	Comfort	24400.00
0005435614788	5303	Comfort	24400.00
0005435614838	5303	Comfort	24400.00
0005435614857	5303	Comfort	24400.00
0005435424817	5303	Comfort	24400.00
0005434573496	5303	Comfort	24400.00
0005432047590	5303	Comfort	24400.00
0005435097305	5303	Economy	14400.00
0005432841011	5303	Economy	14400.00
0005435097310	5303	Economy	14400.00
0005435614752	5303	Economy	14400.00
0005435319608	5303	Economy	14400.00
0005435302211	5303	Economy	14400.00
0005435425033	5303	Economy	14400.00
0005435319609	5303	Economy	14400.00
0005432133360	5303	Economy	14400.00
0005434344597	5303	Economy	14400.00
0005435614747	5303	Economy	14400.00
0005434573492	5303	Economy	14400.00
0005434344599	5303	Economy	14400.00
0005435424973	5303	Economy	14400.00
0005435097304	5303	Economy	14400.00
0005432133365	5303	Economy	14400.00
0005435614751	5303	Economy	14400.00
0005435424987	5303	Economy	14400.00
0005435614841	5303	Economy	14400.00
0005435614819	5303	Economy	14400.00
0005435424885	5303	Economy	14400.00
0005432133361	5303	Economy	14400.00
0005434344587	5303	Economy	14400.00
0005435614842	5303	Economy	14400.00
0005435614799	5303	Economy	14400.00
0005435425068	5303	Economy	14400.00
0005435614870	5303	Economy	14400.00
0005435614865	5303	Economy	14400.00
0005435614852	5303	Economy	14400.00
0005434245080	5303	Economy	14400.00
0005435614835	5303	Economy	14400.00
0005435614814	5303	Economy	14400.00
0005435424727	5303	Economy	14400.00
0005435614873	5303	Economy	14400.00
0005435425074	5303	Economy	14400.00
0005435614805	5303	Economy	14400.00
0005435614866	5303	Economy	14400.00
0005435614856	5303	Economy	14400.00
0005435490267	5303	Economy	14400.00
0005432133370	5303	Economy	14400.00
0005435614793	5303	Economy	14400.00
0005432047587	5303	Economy	14400.00
0005434344584	5303	Economy	14400.00
0005435424760	5303	Economy	14400.00
0005435424919	5303	Economy	14400.00
0005435097301	5303	Economy	14400.00
0005435614832	5303	Economy	14400.00
0005432133368	5303	Economy	14400.00
0005435425205	5303	Economy	14400.00
0005435614791	5303	Economy	14400.00
0005435424759	5303	Economy	14400.00
0005434244915	5303	Economy	14400.00
0005435614811	5303	Economy	14400.00
0005435614828	5303	Economy	14400.00
0005435425109	5303	Economy	14400.00
0005432133363	5303	Economy	14400.00
0005435425185	5303	Economy	14400.00
0005435425126	5303	Economy	14400.00
0005435614863	5303	Economy	14400.00
0005435614815	5303	Economy	15800.00
0005435302197	5303	Economy	15800.00
0005434245066	5303	Economy	14400.00
0005435614834	5303	Economy	14400.00
0005435614839	5303	Economy	14400.00
0005435302208	5303	Economy	14400.00
0005435319589	5303	Economy	15800.00
0005435614796	5303	Economy	15800.00
0005435424938	5303	Economy	15800.00
0005435424868	5303	Economy	14400.00
0005434245071	5303	Economy	14400.00
0005435614847	5303	Economy	14400.00
0005435614867	5303	Economy	14400.00
0005433719156	5303	Economy	14400.00
0005432133372	5303	Economy	14400.00
0005434344577	5303	Economy	14400.00
0005435614833	5303	Economy	14400.00
0005435425161	5303	Economy	14400.00
0005435614820	5303	Economy	14400.00
0005435424870	5303	Economy	14400.00
0005435425028	5303	Economy	14400.00
0005435424995	5303	Economy	14400.00
0005435614750	5303	Economy	14400.00
0005434344567	5303	Economy	14400.00
0005435319562	5303	Economy	14400.00
0005432133362	5303	Economy	14400.00
0005434344595	5303	Economy	14400.00
0005434344574	5303	Economy	14400.00
0005434245064	5303	Economy	14400.00
0005435425067	5303	Economy	14400.00
0005435319576	5303	Economy	14400.00
0005435614790	5303	Economy	14400.00
0005435424950	5303	Economy	14400.00
0005435614864	5303	Economy	14400.00
0005434245065	5303	Economy	14400.00
0005435614803	5303	Economy	14400.00
0005435424770	5303	Economy	14400.00
0005434344592	5303	Economy	14400.00
0005435614753	5303	Economy	14400.00
0005435614771	5303	Economy	14400.00
0005435614868	5303	Economy	14400.00
0005435424996	5303	Economy	14400.00
0005435614787	5303	Economy	14400.00
0005435614756	5303	Economy	14400.00
0005434244988	5303	Economy	14400.00
0005435424849	5303	Economy	14400.00
0005435555389	5303	Economy	14400.00
0005435425001	5303	Economy	14400.00
0005434344583	5303	Economy	14400.00
0005432047591	5303	Economy	14400.00
0005435425020	5303	Economy	14400.00
0005435614816	5303	Economy	14400.00
0005434573504	5303	Economy	14400.00
0005435614817	5303	Economy	14400.00
0005432133369	5303	Economy	14400.00
0005435424953	5303	Economy	14400.00
0005435097300	5303	Economy	14400.00
0005435302204	5303	Economy	14400.00
0005435614754	5303	Economy	14400.00
0005432133373	5303	Economy	14400.00
0005435614861	5303	Economy	14400.00
0005435614758	5303	Economy	14400.00
0005435614779	5303	Economy	14400.00
0005434573493	5303	Economy	14400.00
0005435614749	5303	Economy	14400.00
0005434344581	5303	Economy	14400.00
0005435302216	5303	Economy	14400.00
0005435614786	5303	Economy	14400.00
0005435424937	5303	Economy	14400.00
0005435425072	5303	Economy	14400.00
0005435614748	5303	Economy	14400.00
0005435614798	5303	Economy	14400.00
0005435614823	5303	Economy	14400.00
0005435380282	5303	Economy	14400.00
0005435614850	5303	Economy	14400.00
0005434244944	5303	Economy	14400.00
0005435424968	5303	Economy	14400.00
0005435614774	5303	Economy	14400.00
0005435614859	5303	Economy	14400.00
0005435424717	5303	Economy	14400.00
0005434573495	5303	Economy	14400.00
0005435614782	5303	Economy	14400.00
0005434573497	5303	Economy	14400.00
0005434344572	5303	Economy	14400.00
0005434344596	5303	Economy	14400.00
0005435614810	5303	Economy	14400.00
0005435614801	5303	Economy	14400.00
0005435614836	5303	Economy	14400.00
0005435614768	5303	Economy	14400.00
0005434573503	5303	Economy	14400.00
0005434245041	5303	Economy	14400.00
0005435614829	5303	Economy	14400.00
0005435097309	5303	Economy	14400.00
0005435424682	5303	Economy	14400.00
0005435424949	5303	Economy	14400.00
0005432047589	5303	Economy	14400.00
0005435614822	5303	Economy	14400.00
0005435380281	5303	Economy	14400.00
0005435425062	5303	Economy	14400.00
0005435425123	5303	Economy	14400.00
0005435424850	5303	Economy	14400.00
0005434245186	5303	Economy	14400.00
0005434244977	5303	Economy	14400.00
0005435614854	5303	Economy	14400.00
0005435425037	5303	Economy	14400.00
0005435614764	5303	Economy	14400.00
0005435614802	5303	Economy	14400.00
0005435614826	5303	Economy	15800.00
0005434245079	5303	Economy	15800.00
0005435425039	5303	Economy	15800.00
0005435097311	5303	Economy	15800.00
0005435424988	5303	Economy	15800.00
0005435614794	5303	Economy	14400.00
0005435614813	5303	Economy	14400.00
0005435097303	5303	Economy	14400.00
0005435614872	5303	Economy	14400.00
0005435614843	5303	Economy	14400.00
0005435424971	5303	Economy	14400.00
0005435614844	5303	Economy	14400.00
0005435614784	5303	Economy	14400.00
0005432133366	5303	Economy	14400.00
0005435425230	5303	Economy	14400.00
0005432363424	5303	Economy	14400.00
0005435424993	5303	Economy	14400.00
0005435424799	5303	Economy	14400.00
0005434573501	5303	Economy	14400.00
0005435614806	5303	Economy	14400.00
0005435614869	5303	Economy	14400.00
0005435614809	5303	Economy	14400.00
0005434344591	5303	Economy	14400.00
0005435319615	5303	Economy	14400.00
0005434656561	5303	Economy	14400.00
0005435614825	5303	Economy	14400.00
0005435614808	5303	Economy	14400.00
0005435614840	5303	Economy	14400.00
0005435614827	5303	Economy	14400.00
0005435614792	5303	Economy	14400.00
0005434244978	5303	Economy	14400.00
0005435614795	5303	Economy	14400.00
0005435614821	5303	Economy	14400.00
0005435425165	5303	Economy	14400.00
0005435614778	5303	Economy	14400.00
0005434344575	5303	Economy	14400.00
0005435614776	5303	Economy	14400.00
0005434245207	5303	Economy	14400.00
0005435319605	5303	Economy	14400.00
0005435319604	5303	Economy	14400.00
0005434245187	5303	Economy	14400.00
0005435302198	5303	Economy	14400.00
0005435097306	5303	Economy	14400.00
0005434244987	5303	Economy	14400.00
0005432133364	5303	Economy	14400.00
0005435424862	5303	Economy	14400.00
0005434573494	5303	Economy	14400.00
0005434344590	5303	Economy	14400.00
0005435614830	5303	Economy	14400.00
0005435614785	5303	Economy	14400.00
0005435614860	5303	Economy	14400.00
0005435425206	5303	Economy	14400.00
0005434344568	5303	Economy	14400.00
0005435614845	5303	Economy	14400.00
0005435424869	5303	Economy	14400.00
0005435614807	5303	Economy	14400.00
0005435614849	5303	Economy	14400.00
0005435424883	5303	Economy	14400.00
0005435424895	5303	Economy	14400.00
0005435614769	5303	Economy	14400.00
0005435425234	5303	Economy	14400.00
0005435319561	5303	Economy	14400.00
0005435424969	5303	Economy	14400.00
0005435097308	5303	Economy	14400.00
0005435614767	5303	Economy	14400.00
0005434344593	5303	Economy	14400.00
0005434344573	5303	Economy	14400.00
0005435614772	5303	Economy	14400.00
0005435614780	5303	Economy	14400.00
0005435614761	5303	Economy	14400.00
0005435614770	5303	Economy	14400.00
0005435424796	5303	Economy	14400.00
0005435614766	5303	Economy	14400.00
0005434344578	5303	Economy	14400.00
0005434344571	5303	Economy	14400.00
0005435424702	5303	Economy	14400.00
0005435302219	5303	Economy	14400.00
0005435319621	5303	Economy	14400.00
0005435614862	5303	Economy	14400.00
0005432133359	5303	Economy	14400.00
0005435424800	5303	Economy	14400.00
0005432363423	5303	Economy	14400.00
0005435380288	5303	Economy	14400.00
0005435555390	5303	Economy	14400.00
0005435614853	5303	Economy	14400.00
0005434344586	5303	Economy	14400.00
0005435380309	5303	Economy	14400.00
0005435614855	5303	Economy	14400.00
0005435425110	5303	Economy	14400.00
0005434573498	5303	Economy	14400.00
0005435425040	5303	Economy	14400.00
0005435614757	5303	Economy	14400.00
0005434344594	5303	Economy	14400.00
0005434344598	5303	Economy	14400.00
0005435490265	5303	Economy	14400.00
0005435490264	5303	Economy	14400.00
0005434245022	5303	Economy	14400.00
0005435614765	5303	Economy	14400.00
0005435424992	5303	Economy	14400.00
0005435614848	5303	Economy	14400.00
0005435614812	5303	Economy	14400.00
0005435319660	10905	Business	43100.00
0005435555376	10905	Business	43100.00
0005435380336	10905	Business	43100.00
0005435425517	10905	Business	43100.00
0005435097198	10905	Business	43100.00
0005435613888	10905	Business	43100.00
0005435425507	10905	Business	43100.00
0005434344244	10905	Business	43100.00
0005435614235	10905	Business	43100.00
0005434245272	10905	Business	43100.00
0005435425491	10905	Business	43100.00
0005435613352	10905	Business	43100.00
0005432363450	10905	Business	43100.00
0005435613925	10905	Business	43100.00
0005435425511	10905	Business	43100.00
0005435304201	10905	Business	43100.00
0005435425499	10905	Business	43100.00
0005435614059	10905	Business	43100.00
0005434245268	10905	Business	43100.00
0005435613640	10905	Business	43100.00
0005435617235	10905	Business	43100.00
0005435425498	10905	Business	43100.00
0005435425481	10905	Business	43100.00
0005435613392	10905	Comfort	24400.00
0005435425535	10905	Comfort	24400.00
0005435613393	10905	Comfort	24400.00
0005435613729	10905	Comfort	24400.00
0005435613826	10905	Comfort	24400.00
0005435613844	10905	Comfort	24400.00
0005435617169	10905	Comfort	24400.00
0005435614247	10905	Comfort	24400.00
0005435097195	10905	Comfort	24400.00
0005434245284	10905	Comfort	24400.00
0005435614234	10905	Comfort	24400.00
0005434245292	10905	Comfort	24400.00
0005434573350	10905	Comfort	24400.00
0005435613602	10905	Comfort	24400.00
0005435613837	10905	Comfort	24400.00
0005435613394	10905	Comfort	24400.00
0005434573333	10905	Comfort	24400.00
0005435613724	10905	Comfort	24400.00
0005435613275	10905	Comfort	24400.00
0005434344405	10905	Comfort	24400.00
0005435613639	10905	Comfort	24400.00
0005435613588	10905	Comfort	24400.00
0005434344469	10905	Comfort	24400.00
0005435613292	10905	Comfort	24400.00
0005433719176	10905	Comfort	24400.00
0005435613890	10905	Comfort	24400.00
0005435042879	10905	Comfort	24400.00
0005435304199	10905	Comfort	24400.00
0005435613519	10905	Comfort	24400.00
0005435613353	10905	Comfort	24400.00
0005434344312	10905	Comfort	24400.00
0005435617170	10905	Comfort	24400.00
0005434245271	10905	Comfort	24400.00
0005434245293	10905	Comfort	24400.00
0005435613880	10905	Comfort	24400.00
0005435305033	10905	Comfort	24400.00
0005435425533	10905	Comfort	24400.00
0005435613960	10905	Comfort	24400.00
0005435425519	10905	Comfort	24400.00
0005435425482	10905	Comfort	24400.00
0005435614160	10905	Comfort	24400.00
0005435613924	10905	Comfort	24400.00
0005432166937	10905	Economy	14400.00
0005435613710	10905	Economy	14400.00
0005435613667	10905	Economy	14400.00
0005435425545	10905	Economy	14400.00
0005435613836	10905	Economy	14400.00
0005434344183	10905	Economy	14400.00
0005435614171	10905	Economy	14400.00
0005435613797	10905	Economy	14400.00
0005435614196	10905	Economy	14400.00
0005434573358	10905	Economy	14400.00
0005435613706	10905	Economy	14400.00
0005435613772	10905	Economy	14400.00
0005435613668	10905	Economy	14400.00
0005435613895	10905	Economy	14400.00
0005435425506	10905	Economy	14400.00
0005435319666	10905	Economy	14400.00
0005435613874	10905	Economy	14400.00
0005435319664	10905	Economy	14400.00
0005435425544	10905	Economy	14400.00
0005434245291	10905	Economy	14400.00
0005435490220	10905	Economy	14400.00
0005434573276	10905	Economy	14400.00
0005435613765	10905	Economy	14400.00
0005435613730	10905	Economy	14400.00
0005434245283	10905	Economy	14400.00
0005435425528	10905	Economy	14400.00
0005435042881	10905	Economy	14400.00
0005434344154	10905	Economy	14400.00
0005434573353	10905	Economy	14400.00
0005435614060	10905	Economy	14400.00
0005432363451	10905	Economy	14400.00
0005435614174	10905	Economy	14400.00
0005435425487	10905	Economy	14400.00
0005435614055	10905	Economy	14400.00
0005435097203	10905	Economy	14400.00
0005435425548	10905	Economy	14400.00
0005435613834	10905	Economy	14400.00
0005435613517	10905	Economy	14400.00
0005435097202	10905	Economy	14400.00
0005434573385	10905	Economy	14400.00
0005435380338	10905	Economy	14400.00
0005435613676	10905	Economy	14400.00
0005435614161	10905	Economy	14400.00
0005432166934	10905	Economy	14400.00
0005435319663	10905	Economy	14400.00
0005434573310	10905	Economy	14400.00
0005435380337	10905	Economy	14400.00
0005435613970	10905	Economy	14400.00
0005434573284	10905	Economy	14400.00
0005434344222	10905	Economy	14400.00
0005435319662	10905	Economy	14400.00
0005435425492	10905	Economy	14400.00
0005432841034	10905	Economy	14400.00
0005435613255	10905	Economy	14400.00
0005435614191	10905	Economy	14400.00
0005435613835	10905	Economy	14400.00
0005435613959	10905	Economy	14400.00
0005435613980	10905	Economy	14400.00
0005432165113	10905	Economy	14400.00
0005435425514	10905	Economy	15800.00
0005435613618	10905	Economy	15800.00
0005435613589	10905	Economy	15800.00
0005435613879	10905	Economy	14400.00
0005434245287	10905	Economy	14400.00
0005435319661	10905	Economy	15800.00
0005434245275	10905	Economy	14400.00
0005435614021	10905	Economy	15800.00
0005435613515	10905	Economy	14400.00
0005434245282	10905	Economy	14400.00
0005434656577	10905	Economy	14400.00
0005435425515	10905	Economy	14400.00
0005435613961	10905	Economy	14400.00
0005434656576	10905	Economy	14400.00
0005435613388	10905	Economy	14400.00
0005435613966	10905	Economy	14400.00
0005435425524	10905	Economy	14400.00
0005435613406	10905	Economy	14400.00
0005434344199	10905	Economy	14400.00
0005435613721	10905	Economy	14400.00
0005434573323	10905	Economy	14400.00
0005435425496	10905	Economy	14400.00
0005435425534	10905	Economy	14400.00
0005435613735	10905	Economy	14400.00
0005435304202	10905	Economy	14400.00
0005435425516	10905	Economy	14400.00
0005435613902	10905	Economy	14400.00
0005434344225	10905	Economy	14400.00
0005434245278	10905	Economy	14400.00
0005435097204	10905	Economy	14400.00
0005432165115	10905	Economy	14400.00
0005435613876	10905	Economy	14400.00
0005434245288	10905	Economy	14400.00
0005434245274	10905	Economy	14400.00
0005434245296	10905	Economy	14400.00
0005435319665	10905	Economy	14400.00
0005435425493	10905	Economy	14400.00
0005435614153	10905	Economy	14400.00
0005435425546	10905	Economy	14400.00
0005434344285	10905	Economy	14400.00
0005435425529	10905	Economy	14400.00
0005435613732	10905	Economy	14400.00
0005435614027	10905	Economy	14400.00
0005435425501	10905	Economy	14400.00
0005434245276	10905	Economy	14400.00
0005434245290	10905	Economy	14400.00
0005434573349	10905	Economy	14400.00
0005435614002	10905	Economy	14400.00
0005434245289	10905	Economy	14400.00
0005434573332	10905	Economy	14400.00
0005434344221	10905	Economy	14400.00
0005434573314	10905	Economy	14400.00
0005435425538	10905	Economy	14400.00
0005435613896	10905	Economy	14400.00
0005435425513	10905	Economy	14400.00
0005435425503	10905	Economy	14400.00
0005435613827	10905	Economy	14400.00
0005435614134	10905	Economy	14400.00
0005435425531	10905	Economy	14400.00
0005435613617	10905	Economy	14400.00
0005434245277	10905	Economy	14400.00
0005435425510	10905	Economy	14400.00
0005435425497	10905	Economy	14400.00
0005435614031	10905	Economy	14400.00
0005435613716	10905	Economy	14400.00
0005435042882	10905	Economy	14400.00
0005435613720	10905	Economy	14400.00
0005435490244	10905	Economy	14400.00
0005435613915	10905	Economy	14400.00
0005435425525	10905	Economy	14400.00
0005434344280	10905	Economy	14400.00
0005435613793	10905	Economy	14400.00
0005435319667	10905	Economy	14400.00
0005435613291	10905	Economy	14400.00
0005435613493	10905	Economy	14400.00
0005435097211	10905	Economy	14400.00
0005435613696	10905	Economy	14400.00
0005435425486	10905	Economy	14400.00
0005435425532	10905	Economy	14400.00
0005435097210	10905	Economy	14400.00
0005435425480	10905	Economy	14400.00
0005435425483	10905	Economy	14400.00
0005432166933	10905	Economy	14400.00
0005435613028	10905	Economy	14400.00
0005435613329	10905	Economy	14400.00
0005435425550	10905	Economy	14400.00
0005435425500	10905	Economy	14400.00
0005434344153	10905	Economy	14400.00
0005435425495	10905	Economy	14400.00
0005432165120	10905	Economy	14400.00
0005435613719	10905	Economy	14400.00
0005434573384	10905	Economy	14400.00
0005435613274	10905	Economy	14400.00
0005435614228	10905	Economy	14400.00
0005435613354	10905	Economy	14400.00
0005434245285	10905	Economy	14400.00
0005434344236	10905	Economy	14400.00
0005435425489	10905	Economy	14400.00
0005435425540	10905	Economy	14400.00
0005435425505	10905	Economy	14400.00
0005435613791	10905	Economy	14400.00
0005432841035	10905	Economy	14400.00
0005432165114	10905	Economy	14400.00
0005435613516	10905	Economy	14400.00
0005435613889	10905	Economy	14400.00
0005434245286	10905	Economy	14400.00
0005435425536	10905	Economy	14400.00
0005434573315	10905	Economy	14400.00
0005435614233	10905	Economy	14400.00
0005435613875	10905	Economy	14400.00
0005435613773	10905	Economy	14400.00
0005435490245	10905	Economy	14400.00
0005433719178	10905	Economy	14400.00
0005435425537	10905	Economy	14400.00
0005435425518	10905	Economy	14400.00
0005435614395	10905	Economy	15800.00
0005434344138	10905	Economy	15800.00
0005435305034	10905	Economy	15800.00
0005435613514	10905	Economy	15800.00
0005435425522	10905	Economy	15800.00
0005432166935	10905	Economy	15800.00
0005435425547	10905	Economy	14400.00
0005434245294	10905	Economy	14400.00
0005432165117	10905	Economy	14400.00
0005435380334	10905	Economy	14400.00
0005434344182	10905	Economy	14400.00
0005435425490	10905	Economy	14400.00
0005435425508	10905	Economy	14400.00
0005434344030	10905	Economy	14400.00
0005435613805	10905	Economy	14400.00
0005435613520	10905	Economy	14400.00
0005435613327	10905	Economy	14400.00
0005435425502	10905	Economy	14400.00
0005435425520	10905	Economy	14400.00
0005434573343	10905	Economy	14400.00
0005434245269	10905	Economy	14400.00
0005435097197	10905	Economy	14400.00
0005434344372	10905	Economy	14400.00
0005435425527	10905	Economy	14400.00
0005435425530	10905	Economy	14400.00
0005434344217	10905	Economy	14400.00
0005435613870	10905	Economy	14400.00
0005434344190	10905	Economy	14400.00
0005435613843	10905	Economy	14400.00
0005435613641	10905	Economy	14400.00
0005435425526	10905	Economy	14400.00
0005435425485	10905	Economy	14400.00
0005435304200	10905	Economy	14400.00
0005434245273	10905	Economy	14400.00
0005435305032	10905	Economy	14400.00
0005435097196	10905	Economy	14400.00
0005435614170	10905	Economy	14400.00
0005435425479	10905	Economy	14400.00
0005435425543	10905	Economy	14400.00
0005435614394	10905	Economy	14400.00
0005434344311	10905	Economy	14400.00
0005432165116	10905	Economy	14400.00
0005435425541	10905	Economy	14400.00
0005434245270	10905	Economy	14400.00
0005432363449	10905	Economy	14400.00
0005435425488	10905	Economy	14400.00
0005435613995	10905	Economy	14400.00
0005435613328	10905	Economy	14400.00
0005435425504	10905	Economy	14400.00
0005433719177	10905	Economy	14400.00
0005432165112	10905	Economy	14400.00
0005432165119	10905	Economy	14400.00
0005435425494	10905	Economy	14400.00
0005435613705	10905	Economy	14400.00
0005435042880	10905	Economy	14400.00
0005435425512	10905	Economy	14400.00
0005435613979	10905	Economy	14400.00
0005434245295	10905	Economy	14400.00
0005434344243	10905	Economy	14400.00
0005435491445	10905	Economy	14400.00
0005435555375	10905	Economy	14400.00
0005434344265	10905	Economy	14400.00
0005435614248	10905	Economy	14400.00
0005435425549	10905	Economy	14400.00
0005435425484	10905	Economy	14400.00
0005435613984	10905	Economy	14400.00
0005435613897	10905	Economy	14400.00
0005435425539	10905	Economy	14400.00
0005434344198	10905	Economy	14400.00
0005435425523	10905	Economy	14400.00
0005435425521	10905	Economy	14400.00
0005435613878	10905	Economy	14400.00
0005434245280	10905	Economy	14400.00
0005434344162	10905	Economy	14400.00
0005435425509	10905	Economy	14400.00
0005435613271	10905	Economy	14400.00
0005435613587	10905	Economy	14400.00
0005435490223	10905	Economy	14400.00
0005435042883	10905	Economy	14400.00
0005435380335	10905	Economy	14400.00
0005434344261	10905	Economy	14400.00
0005434573354	10905	Economy	14400.00
0005434344152	10905	Economy	14400.00
0005435614056	10905	Economy	14400.00
0005432166936	10905	Economy	14400.00
0005435425542	10905	Economy	14400.00
0005434344373	10905	Economy	14400.00
0005435613723	10905	Economy	14400.00
0005434344273	10905	Economy	14400.00
0005434245281	10905	Economy	14400.00
0005435613731	10905	Economy	14400.00
0005435613594	10905	Economy	14400.00
0005434344242	10905	Economy	14400.00
0005434245267	10905	Economy	14400.00
0005434245279	10905	Economy	14400.00
0005435613998	10905	Economy	14400.00
0005435304198	10905	Economy	14400.00
0005435613654	10905	Economy	14400.00
0005432165118	10905	Economy	14400.00
0005435613850	10905	Economy	14400.00
0005435614022	10905	Economy	14400.00
0005432459743	3232	Business	18800.00
0005432181949	3232	Business	18800.00
0005432181937	3232	Business	18800.00
0005432459978	3232	Business	18800.00
0005432181938	3232	Business	18800.00
0005433805731	3232	Business	18800.00
0005432181956	3232	Business	18800.00
0005433634176	3232	Business	18800.00
0005433634158	3232	Business	18800.00
0005433805737	3232	Business	18800.00
0005432459884	3232	Business	18800.00
0005432459787	3232	Business	18800.00
0005433634166	3232	Business	18800.00
0005432459883	3232	Business	18800.00
0005432181946	3232	Business	18800.00
0005433507366	3232	Business	18800.00
0005432181955	3232	Business	18800.00
0005433634169	3232	Business	18800.00
0005432181953	3232	Business	18800.00
0005432181957	3232	Business	18800.00
0005433805729	3232	Business	18800.00
0005432459799	3232	Business	18800.00
0005433634170	3232	Business	18800.00
0005433805722	3232	Business	18800.00
0005433805732	3232	Business	18800.00
0005432459792	3232	Business	18800.00
0005432459845	3232	Business	18800.00
0005433805741	3232	Economy	6900.00
0005433507361	3232	Economy	6900.00
0005432181948	3232	Economy	6900.00
0005433805748	3232	Economy	6900.00
0005433634188	3232	Economy	6900.00
0005432459959	3232	Economy	6900.00
0005433634171	3232	Economy	6300.00
0005433507373	3232	Economy	6300.00
0005432459866	3232	Economy	6300.00
0005433634172	3232	Economy	6300.00
0005433507367	3232	Economy	6300.00
0005432459871	3232	Economy	6300.00
0005433634159	3232	Economy	6300.00
0005432460012	3232	Economy	6300.00
0005432181939	3232	Economy	6300.00
0005432459931	3232	Economy	6300.00
0005432459983	3232	Economy	6300.00
0005432460127	3232	Economy	6300.00
0005432459820	3232	Economy	6300.00
0005432181951	3232	Economy	6300.00
0005433507372	3232	Economy	6300.00
0005433805724	3232	Economy	6300.00
0005432459637	3232	Economy	6300.00
0005432459868	3232	Economy	6300.00
0005432459702	3232	Economy	6300.00
0005433805719	3232	Economy	6300.00
0005432181940	3232	Economy	6300.00
0005432460046	3232	Economy	6300.00
0005432459914	3232	Economy	6300.00
0005432459937	3232	Economy	6300.00
0005432181943	3232	Economy	6300.00
0005432459916	3232	Economy	6300.00
0005433805735	3232	Economy	6300.00
0005432459992	3232	Economy	6300.00
0005433634186	3232	Economy	6300.00
0005432181945	3232	Economy	6300.00
0005433634157	3232	Economy	6300.00
0005432181944	3232	Economy	6300.00
0005432459925	3232	Economy	6300.00
0005433507363	3232	Economy	6300.00
0005432181947	3232	Economy	6300.00
0005433507374	3232	Economy	6300.00
0005433805723	3232	Economy	6300.00
0005432459638	3232	Economy	6300.00
0005433507358	3232	Economy	6300.00
0005433507368	3232	Economy	6300.00
0005432459899	3232	Economy	6300.00
0005432459929	3232	Economy	6300.00
0005433805745	3232	Economy	6300.00
0005432459794	3232	Economy	6300.00
0005432459882	3232	Economy	6300.00
0005433805736	3232	Economy	6300.00
0005432459869	3232	Economy	6300.00
0005432459861	3232	Economy	6300.00
0005433634177	3232	Economy	6300.00
0005432181935	3232	Economy	6300.00
0005433634168	3232	Economy	6300.00
0005433634155	3232	Economy	6300.00
0005433805746	3232	Economy	6300.00
0005433805751	3232	Economy	6300.00
0005433805747	3232	Economy	6300.00
0005433634173	3232	Economy	6300.00
0005432459865	3232	Economy	6300.00
0005433805726	3232	Economy	6300.00
0005432459970	3232	Economy	6300.00
0005433634156	3232	Economy	6900.00
0005432459793	3232	Economy	6900.00
0005433805743	3232	Economy	6900.00
0005432460019	3232	Economy	6900.00
0005432459703	3232	Economy	6900.00
0005433634183	3232	Economy	6300.00
0005433805738	3232	Economy	6300.00
0005433507360	3232	Economy	6300.00
0005433805742	3232	Economy	6300.00
0005433634179	3232	Economy	6300.00
0005432460002	3232	Economy	6900.00
0005432459864	3232	Economy	6300.00
0005433634182	3232	Economy	6300.00
0005432459960	3232	Economy	6300.00
0005433507359	3232	Economy	6300.00
0005432459958	3232	Economy	6300.00
0005432459809	3232	Economy	6300.00
0005432459701	3232	Economy	6300.00
0005432459740	3232	Economy	6300.00
0005433805733	3232	Economy	6300.00
0005432181950	3232	Economy	6300.00
0005432459907	3232	Economy	6300.00
0005433507376	3232	Economy	6300.00
0005433507365	3232	Economy	6300.00
0005432459898	3232	Economy	6300.00
0005433805727	3232	Economy	6300.00
0005433634174	3232	Economy	6300.00
0005432181952	3232	Economy	6300.00
0005433507362	3232	Economy	6300.00
0005432181954	3232	Economy	6300.00
0005433634184	3232	Economy	6300.00
0005433507375	3232	Economy	6300.00
0005433634181	3232	Economy	6300.00
0005432181941	3232	Economy	6300.00
0005432181936	3232	Economy	6300.00
0005433507357	3232	Economy	6300.00
0005432459860	3232	Economy	6300.00
0005432459997	3232	Economy	6300.00
0005432459908	3232	Economy	6300.00
0005433634163	3232	Economy	6300.00
0005433634178	3232	Economy	6300.00
0005433805749	3232	Economy	6300.00
0005433507371	3232	Economy	6300.00
0005433634161	3232	Economy	6300.00
0005433507370	3232	Economy	6300.00
0005433805725	3232	Economy	6300.00
0005432459923	3232	Economy	6300.00
0005433805718	3232	Economy	6300.00
0005433805721	3232	Economy	6300.00
0005432459872	3232	Economy	6300.00
0005433634165	3232	Economy	6300.00
0005433634160	3232	Economy	6300.00
0005433805744	3232	Economy	6300.00
0005433805728	3232	Economy	6300.00
0005433805720	3232	Economy	6300.00
0005433805750	3232	Economy	6300.00
0005433634164	3232	Economy	6300.00
0005433634175	3232	Economy	6300.00
0005433507364	3232	Economy	6300.00
0005432460128	3232	Economy	6300.00
0005433805740	3232	Economy	6300.00
0005433634189	3232	Economy	6300.00
0005433634180	3232	Economy	6300.00
0005433805734	3232	Economy	6300.00
0005432459971	3232	Economy	6300.00
0005433805739	3232	Economy	6300.00
0005433634185	3232	Economy	6300.00
0005433507369	3232	Economy	6300.00
0005432181942	3232	Economy	6300.00
0005432459930	3232	Economy	6300.00
0005432459957	3232	Economy	6300.00
0005433634187	3232	Economy	6300.00
0005432459858	3232	Economy	6300.00
0005433634167	3232	Economy	6300.00
0005433805730	3232	Economy	6300.00
0005433634162	3232	Economy	6300.00
0005435885458	3233	Business	18800.00
0005435885523	3233	Business	18800.00
0005435885289	3233	Business	18800.00
0005435885335	3233	Business	18800.00
0005435885382	3233	Economy	6900.00
0005435885360	3233	Economy	6300.00
0005435885288	3233	Economy	6300.00
0005435885457	3233	Economy	6300.00
0005435885179	3233	Economy	6300.00
0005435885235	3233	Economy	6300.00
0005435885317	3233	Economy	6300.00
0005435885342	3233	Economy	6300.00
0005435885343	3233	Economy	6300.00
0005435885106	3233	Economy	6300.00
0005435885374	3233	Economy	6300.00
0005435885278	3233	Economy	6300.00
0005435885462	3233	Economy	6300.00
0005435885279	3233	Economy	6300.00
0005435885482	3233	Economy	6300.00
0005435885139	3233	Economy	6300.00
0005435885287	3233	Economy	6300.00
0005435885379	3233	Economy	6300.00
0005435885286	3233	Economy	6300.00
0005435885359	3233	Economy	6300.00
0005435885271	3233	Economy	6300.00
0005435885481	3233	Economy	6300.00
0005435885373	3233	Economy	6300.00
0005435885270	3233	Economy	6300.00
0005435885465	3233	Economy	6300.00
0005435885338	3233	Economy	6300.00
0005435885364	3233	Economy	6300.00
0005435885363	3233	Economy	6300.00
0005435885362	3233	Economy	6300.00
0005435885096	3233	Economy	6300.00
0005435885579	3233	Economy	6300.00
0005435885569	3233	Economy	6300.00
0005435885483	3233	Economy	6300.00
0005435885253	3233	Economy	6300.00
0005435885307	3233	Economy	6300.00
0005432460412	8179	Business	18800.00
0005435885750	8179	Business	18800.00
0005432042856	8179	Business	18800.00
0005435885748	8179	Business	18800.00
0005432460444	8179	Business	18800.00
0005435885754	8179	Business	18800.00
0005435885760	8179	Business	18800.00
0005432460419	8179	Business	18800.00
0005433507237	8179	Business	18800.00
0005432460450	8179	Business	18800.00
0005432460400	8179	Business	18800.00
0005432460402	8179	Business	18800.00
0005432460417	8179	Business	18800.00
0005435885797	8179	Business	18800.00
0005432460403	8179	Business	18800.00
0005435885774	8179	Business	18800.00
0005432460414	8179	Business	18800.00
0005434312342	8179	Business	18800.00
0005432042865	8179	Business	18800.00
0005432460427	8179	Business	18800.00
0005435885789	8179	Business	18800.00
0005433507177	8179	Business	18800.00
0005432460422	8179	Economy	6900.00
0005432042863	8179	Economy	6900.00
0005432460407	8179	Economy	6900.00
0005435885776	8179	Economy	6900.00
0005433507206	8179	Economy	6900.00
0005435885767	8179	Economy	6900.00
0005435885756	8179	Economy	6300.00
0005432042861	8179	Economy	6300.00
0005435885795	8179	Economy	6300.00
0005435885779	8179	Economy	6300.00
0005432460445	8179	Economy	6300.00
0005432460406	8179	Economy	6300.00
0005433507187	8179	Economy	6300.00
0005435885763	8179	Economy	6300.00
0005432460404	8179	Economy	6300.00
0005432460399	8179	Economy	6300.00
0005432460447	8179	Economy	6300.00
0005432460435	8179	Economy	6300.00
0005432042854	8179	Economy	6300.00
0005432460437	8179	Economy	6300.00
0005435885761	8179	Economy	6300.00
0005432460409	8179	Economy	6300.00
0005432460448	8179	Economy	6300.00
0005435885751	8179	Economy	6300.00
0005432460432	8179	Economy	6300.00
0005432460421	8179	Economy	6300.00
0005435885759	8179	Economy	6300.00
0005435885772	8179	Economy	6300.00
0005432460428	8179	Economy	6300.00
0005432460443	8179	Economy	6300.00
0005432460451	8179	Economy	6300.00
0005432460439	8179	Economy	6300.00
0005432460423	8179	Economy	6300.00
0005432460436	8179	Economy	6300.00
0005432460420	8179	Economy	6300.00
0005432460442	8179	Economy	6300.00
0005432042859	8179	Economy	6300.00
0005432042864	8179	Economy	6300.00
0005435885773	8179	Economy	6300.00
0005435885766	8179	Economy	6300.00
0005434312343	8179	Economy	6300.00
0005435885778	8179	Economy	6300.00
0005434312341	8179	Economy	6300.00
0005435885762	8179	Economy	6300.00
0005435885768	8179	Economy	6300.00
0005435885745	8179	Economy	6300.00
0005432460429	8179	Economy	6300.00
0005432042852	8179	Economy	6300.00
0005435885765	8179	Economy	6300.00
0005435885752	8179	Economy	6300.00
0005435885791	8179	Economy	6300.00
0005432042855	8179	Economy	6300.00
0005435885790	8179	Economy	6300.00
0005432460410	8179	Economy	6900.00
0005432460426	8179	Economy	6900.00
0005435885794	8179	Economy	6900.00
0005435885780	8179	Economy	6900.00
0005432460416	8179	Economy	6300.00
0005435885793	8179	Economy	6900.00
0005435885746	8179	Economy	6300.00
0005432460408	8179	Economy	6300.00
0005435885749	8179	Economy	6900.00
0005435885792	8179	Economy	6300.00
0005435885784	8179	Economy	6300.00
0005435885771	8179	Economy	6300.00
0005433507172	8179	Economy	6300.00
0005435885786	8179	Economy	6300.00
0005432460449	8179	Economy	6300.00
0005432460401	8179	Economy	6300.00
0005435885775	8179	Economy	6300.00
0005435885758	8179	Economy	6300.00
0005433507193	8179	Economy	6300.00
0005435885787	8179	Economy	6300.00
0005435885753	8179	Economy	6300.00
0005432460441	8179	Economy	6300.00
0005432460433	8179	Economy	6300.00
0005432460434	8179	Economy	6300.00
0005435885755	8179	Economy	6300.00
0005432042862	8179	Economy	6300.00
0005432460415	8179	Economy	6300.00
0005432460431	8179	Economy	6300.00
0005432042857	8179	Economy	6300.00
0005432460413	8179	Economy	6300.00
0005435885783	8179	Economy	6300.00
0005432460411	8179	Economy	6300.00
0005435885796	8179	Economy	6300.00
0005432460440	8179	Economy	6300.00
0005432460438	8179	Economy	6300.00
0005435885788	8179	Economy	6300.00
0005432042858	8179	Economy	6300.00
0005432460430	8179	Economy	6300.00
0005432460446	8179	Economy	6300.00
0005435885770	8179	Economy	6300.00
0005435885781	8179	Economy	6300.00
0005432042853	8179	Economy	6300.00
0005432460452	8179	Economy	6300.00
0005435885798	8179	Economy	6300.00
0005435885777	8179	Economy	6300.00
0005435885785	8179	Economy	6300.00
0005435885757	8179	Economy	6300.00
0005432460405	8179	Economy	6300.00
0005432460418	8179	Economy	6300.00
0005432460424	8179	Economy	6300.00
0005435885769	8179	Economy	6300.00
0005435885747	8179	Economy	6300.00
0005433507236	8179	Economy	6300.00
0005432460425	8179	Economy	6300.00
0005432042860	8179	Economy	6300.00
0005435885782	8179	Economy	6300.00
0005433507201	8179	Economy	6300.00
0005433507245	8179	Economy	6300.00
0005433507217	8179	Economy	6300.00
0005435885764	8179	Economy	6300.00
0005433805498	8181	Business	18800.00
0005433633946	8181	Business	18800.00
0005433633792	8181	Business	18800.00
0005433805626	8181	Business	18800.00
0005433805354	8181	Business	18800.00
0005433633730	8181	Business	18800.00
0005434143727	8181	Business	18800.00
0005433633841	8181	Business	18800.00
0005433805521	8181	Business	18800.00
0005433805505	8181	Business	18800.00
0005433633791	8181	Business	18800.00
0005433805483	8181	Business	18800.00
0005433633636	8181	Business	18800.00
0005433805387	8181	Business	18800.00
0005434271316	8181	Business	18800.00
0005433805468	8181	Economy	6900.00
0005433805271	8181	Economy	6900.00
0005433805446	8181	Economy	6900.00
0005433805389	8181	Economy	6300.00
0005433805353	8181	Economy	6300.00
0005433805430	8181	Economy	6300.00
0005434271318	8181	Economy	6300.00
0005433805507	8181	Economy	6300.00
0005433805438	8181	Economy	6300.00
0005434143729	8181	Economy	6300.00
0005433633804	8181	Economy	6300.00
0005433633780	8181	Economy	6300.00
0005433633699	8181	Economy	6300.00
0005433805420	8181	Economy	6300.00
0005433805442	8181	Economy	6300.00
0005434271309	8181	Economy	6300.00
0005433633789	8181	Economy	6300.00
0005433633790	8181	Economy	6300.00
0005433805491	8181	Economy	6300.00
0005433633925	8181	Economy	6300.00
0005433633924	8181	Economy	6300.00
0005433633842	8181	Economy	6300.00
0005433633755	8181	Economy	6300.00
0005433633805	8181	Economy	6300.00
0005433805340	8181	Economy	6300.00
0005433805284	8181	Economy	6300.00
0005433805416	8181	Economy	6300.00
0005433805339	8181	Economy	6300.00
0005433633724	8181	Economy	6300.00
0005433805415	8181	Economy	6300.00
0005433633638	8181	Economy	6300.00
0005433805440	8181	Economy	6300.00
0005433805565	8181	Economy	6300.00
0005433805388	8181	Economy	6300.00
0005433805517	8181	Economy	6300.00
0005433805471	8181	Economy	6300.00
0005433633806	8181	Economy	6900.00
0005433805365	8181	Economy	6300.00
0005433633851	8181	Economy	6300.00
0005433633889	8181	Economy	6300.00
0005433805506	8181	Economy	6300.00
0005433805364	8181	Economy	6300.00
0005433805448	8181	Economy	6300.00
0005433805504	8181	Economy	6300.00
0005433805522	8181	Economy	6300.00
0005433633637	8181	Economy	6300.00
0005433805484	8181	Economy	6300.00
0005433805441	8181	Economy	6300.00
0005433805366	8181	Economy	6300.00
0005433634003	8181	Economy	6300.00
0005433633813	8181	Economy	6300.00
0005433633799	8181	Economy	6300.00
0005433633923	8181	Economy	6300.00
0005433805418	8181	Economy	6300.00
0005433633777	8181	Economy	6300.00
0005433805419	8181	Economy	6300.00
0005433805443	8181	Economy	6300.00
0005433805439	8181	Economy	6300.00
0005433633888	8181	Economy	6300.00
0005433805412	8181	Economy	6300.00
0005433633781	8181	Economy	6300.00
0005433634004	8181	Economy	6300.00
0005433633766	8181	Economy	6300.00
0005434183587	8182	Economy	6300.00
0005433722293	4536	Business	9900.00
0005432383607	4536	Business	9900.00
0005432728073	4536	Business	9900.00
0005432728072	4536	Business	9900.00
0005433722285	4536	Business	9900.00
0005432383578	4536	Business	9900.00
0005433722284	4536	Business	9900.00
0005432383602	4536	Business	9900.00
0005432383600	4536	Economy	3300.00
0005432728064	4536	Economy	3300.00
0005433722286	4536	Economy	3300.00
0005433722289	4536	Economy	3300.00
0005433194888	4536	Economy	3300.00
0005433453780	4536	Economy	3300.00
0005433194890	4536	Economy	3600.00
0005432383597	4536	Economy	3600.00
0005432383584	4536	Economy	3600.00
0005432728063	4536	Economy	3600.00
0005432383587	4536	Economy	3600.00
0005432383586	4536	Economy	3300.00
0005433194889	4536	Economy	3300.00
0005432728070	4536	Economy	3300.00
0005432383608	4536	Economy	3300.00
0005433454898	4536	Economy	3300.00
0005432383605	4536	Economy	3300.00
0005433722291	4536	Economy	3300.00
0005432383606	4536	Economy	3300.00
0005432383598	4536	Economy	3300.00
0005432728071	4536	Economy	3300.00
0005432383591	4536	Economy	3300.00
0005432383604	4536	Economy	3300.00
0005433453781	4536	Economy	3300.00
0005432383590	4536	Economy	3300.00
0005432383583	4536	Economy	3300.00
0005432383574	4536	Economy	3300.00
0005432728069	4536	Economy	3300.00
0005432383572	4536	Economy	3300.00
0005432383581	4536	Economy	3300.00
0005432383603	4536	Economy	3300.00
0005432383582	4536	Economy	3300.00
0005433722292	4536	Economy	3300.00
0005432383601	4536	Economy	3300.00
0005432728062	4536	Economy	3300.00
0005432383585	4536	Economy	3300.00
0005432728067	4536	Economy	3300.00
0005432383579	4536	Economy	3300.00
0005432383571	4536	Economy	3300.00
0005432728065	4536	Economy	3300.00
0005433722288	4536	Economy	3300.00
0005432383573	4536	Economy	3300.00
0005432383588	4536	Economy	3300.00
0005432383576	4536	Economy	3300.00
0005433194891	4536	Economy	3300.00
0005432383577	4536	Economy	3300.00
0005432383589	4536	Economy	3300.00
0005432728068	4536	Economy	3300.00
0005432383594	4536	Economy	3300.00
0005433722287	4536	Economy	3300.00
0005432383592	4536	Economy	3300.00
0005432383596	4536	Economy	3300.00
0005432728066	4536	Economy	3300.00
0005432383575	4536	Economy	3300.00
0005432383580	4536	Economy	3300.00
0005432383599	4536	Economy	3300.00
0005432383595	4536	Economy	3300.00
0005433722290	4536	Economy	3300.00
0005432383593	4536	Economy	3300.00
0005432382998	30154	Business	9900.00
0005432727918	30154	Business	9900.00
0005432727955	30154	Business	9900.00
0005432727954	30154	Business	9900.00
0005432727951	30154	Business	9900.00
0005432383093	30154	Business	9900.00
0005432383049	30154	Business	9900.00
0005432727917	30154	Business	9900.00
0005432728009	30154	Business	9900.00
0005432727970	30154	Economy	3300.00
0005433194856	30154	Economy	3300.00
0005432383167	30154	Economy	3300.00
0005432382987	30154	Economy	3300.00
0005432382994	30154	Economy	3300.00
0005432383137	30154	Economy	3600.00
0005432727969	30154	Economy	3600.00
0005432383142	30154	Economy	3600.00
0005432383179	30154	Economy	3600.00
0005432727986	30154	Economy	3300.00
0005432383169	30154	Economy	3300.00
0005432727982	30154	Economy	3300.00
0005432383098	30154	Economy	3300.00
0005432383017	30154	Economy	3300.00
0005432383014	30154	Economy	3300.00
0005432383141	30154	Economy	3300.00
0005432383162	30154	Economy	3300.00
0005432727963	30154	Economy	3300.00
0005432382993	30154	Economy	3300.00
0005432382986	30154	Economy	3300.00
0005432727978	30154	Economy	3300.00
0005432383112	30154	Economy	3300.00
0005432727988	30154	Economy	3300.00
0005432727962	30154	Economy	3300.00
0005432383173	30154	Economy	3300.00
0005432727946	30154	Economy	3300.00
0005432727952	30154	Economy	3300.00
0005432383068	30154	Economy	3300.00
0005432382970	30154	Economy	3300.00
0005432383101	30154	Economy	3300.00
0005432383013	30154	Economy	3300.00
0005432383022	30154	Economy	3300.00
0005432383174	30154	Economy	3300.00
0005432383097	30154	Economy	3300.00
0005432727977	30154	Economy	3300.00
0005432383188	30154	Economy	3300.00
0005432727943	30154	Economy	3300.00
0005432383005	30154	Economy	3300.00
0005432383138	30154	Economy	3300.00
0005432383004	30154	Economy	3300.00
0005432383131	30154	Economy	3300.00
0005432383092	30154	Economy	3300.00
0005432727976	30154	Economy	3300.00
0005432383187	30154	Economy	3300.00
0005432383094	30154	Economy	3300.00
0005432383135	30154	Economy	3300.00
0005432383146	30154	Economy	3300.00
0005432728010	30154	Economy	3300.00
0005432727953	30154	Economy	3300.00
0005432383143	30154	Economy	3300.00
0005432727997	30154	Economy	3300.00
0005432383067	30154	Economy	3300.00
0005432383015	30154	Economy	3300.00
0005435541225	1717	Business	57200.00
0005432294513	1717	Business	57200.00
0005433516981	1717	Business	57200.00
0005435529480	1717	Business	57200.00
0005432925061	1717	Business	57200.00
0005435541242	1717	Business	57200.00
0005433516987	1717	Business	57200.00
0005435529496	1717	Business	57200.00
0005435529488	1717	Economy	19100.00
0005435529479	1717	Economy	19100.00
0005435529498	1717	Economy	19100.00
0005435541232	1717	Economy	19100.00
0005432925052	1717	Economy	19100.00
0005435529481	1717	Economy	21000.00
0005435541231	1717	Economy	21000.00
0005435541238	1717	Economy	21000.00
0005435541223	1717	Economy	21000.00
0005432925053	1717	Economy	21000.00
0005435529484	1717	Economy	19100.00
0005435529494	1717	Economy	19100.00
0005435541236	1717	Economy	19100.00
0005433516985	1717	Economy	19100.00
0005435541235	1717	Economy	19100.00
0005435541240	1717	Economy	19100.00
0005433516984	1717	Economy	19100.00
0005433516988	1717	Economy	19100.00
0005435529482	1717	Economy	19100.00
0005433516980	1717	Economy	19100.00
0005435529491	1717	Economy	19100.00
0005435541222	1717	Economy	19100.00
0005435529489	1717	Economy	19100.00
0005435529493	1717	Economy	19100.00
0005433516979	1717	Economy	19100.00
0005435541226	1717	Economy	19100.00
0005435529478	1717	Economy	19100.00
0005435541241	1717	Economy	19100.00
0005432925029	1717	Economy	19100.00
0005432294511	1717	Economy	19100.00
0005435541227	1717	Economy	19100.00
0005435529486	1717	Economy	19100.00
0005435541239	1717	Economy	19100.00
0005435541229	1717	Economy	19100.00
0005432294512	1717	Economy	19100.00
0005435529495	1717	Economy	19100.00
0005433516982	1717	Economy	19100.00
0005435529485	1717	Economy	19100.00
0005435541237	1717	Economy	19100.00
0005435529477	1717	Economy	19100.00
0005435529483	1717	Economy	19100.00
0005435541234	1717	Economy	19100.00
0005435541228	1717	Economy	19100.00
0005435541233	1717	Economy	19100.00
0005433516983	1717	Economy	19100.00
0005433516986	1717	Economy	19100.00
0005432925047	1717	Economy	19100.00
0005435529490	1717	Economy	19100.00
0005435529487	1717	Economy	19100.00
0005435529492	1717	Economy	19100.00
0005435529497	1717	Economy	19100.00
0005435541224	1717	Economy	19100.00
0005435541230	1717	Economy	19100.00
0005435540965	21981	Business	57200.00
0005433516919	21981	Business	57200.00
0005433516909	21981	Business	57200.00
0005433516905	21981	Business	57200.00
0005435541002	21981	Economy	19100.00
0005435541073	21981	Economy	19100.00
0005435540947	21981	Economy	19100.00
0005435517903	21981	Economy	19100.00
0005435541047	21981	Economy	21000.00
0005435541007	21981	Economy	21000.00
0005433516886	21981	Economy	21000.00
0005435541071	21981	Economy	21000.00
0005435517899	21981	Economy	19100.00
0005435541029	21981	Economy	19100.00
0005433516936	21981	Economy	19100.00
0005433516883	21981	Economy	19100.00
0005433516929	21981	Economy	19100.00
0005435541039	21981	Economy	19100.00
0005433516920	21981	Economy	19100.00
0005433516897	21981	Economy	19100.00
0005435540946	21981	Economy	19100.00
0005435541046	21981	Economy	19100.00
0005435517936	21981	Economy	19100.00
0005435541016	21981	Economy	19100.00
0005435541030	21981	Economy	19100.00
0005432925086	21981	Economy	19100.00
0005435517914	21981	Economy	19100.00
0005435517915	21981	Economy	19100.00
0005433516898	21981	Economy	19100.00
0005435540887	21981	Economy	19100.00
0005435541027	21981	Economy	19100.00
0005435541008	21981	Economy	19100.00
0005432925084	21981	Economy	19100.00
0005433516901	21981	Economy	19100.00
0005432925089	21981	Economy	19100.00
0005433516882	21981	Economy	19100.00
0005432925085	21981	Economy	19100.00
0005435541028	21981	Economy	19100.00
0005432925087	21981	Economy	19100.00
0005435541070	21981	Economy	19100.00
0005435517960	21981	Economy	19100.00
0005435517935	21981	Economy	19100.00
0005435541017	21981	Economy	19100.00
0005433516900	21981	Economy	19100.00
0005435517938	21981	Economy	19100.00
0005435517900	21981	Economy	19100.00
0005432925088	21981	Economy	19100.00
0005435540997	21981	Economy	19100.00
0005433516871	21981	Economy	19100.00
0005433516857	21981	Economy	19100.00
0005435541018	21981	Economy	19100.00
0005432073427	7368	Business	18500.00
0005435252799	7368	Business	18500.00
0005434459029	7368	Business	18500.00
0005432839348	7368	Business	18500.00
0005434459025	7368	Business	18500.00
0005434459027	7368	Business	18500.00
0005435252773	7368	Business	18500.00
0005432839365	7368	Business	18500.00
0005434459014	7368	Business	18500.00
0005432839350	7368	Business	18500.00
0005432839342	7368	Business	18500.00
0005434459019	7368	Economy	6200.00
0005434459010	7368	Economy	6200.00
0005432073426	7368	Economy	6200.00
0005435252709	7368	Economy	6200.00
0005432823469	7368	Economy	6200.00
0005435252690	7368	Economy	6200.00
0005435252756	7368	Economy	6200.00
0005434459012	7368	Economy	6200.00
0005434459013	7368	Economy	6200.00
0005432839367	7368	Economy	6800.00
0005434459018	7368	Economy	6800.00
0005434459024	7368	Economy	6800.00
0005435252789	7368	Economy	6800.00
0005432839341	7368	Economy	6200.00
0005432839345	7368	Economy	6200.00
0005432839346	7368	Economy	6200.00
0005432839369	7368	Economy	6200.00
0005434459016	7368	Economy	6200.00
0005432839364	7368	Economy	6200.00
0005434459030	7368	Economy	6200.00
0005434459026	7368	Economy	6200.00
0005432839361	7368	Economy	6200.00
0005432839353	7368	Economy	6200.00
0005435252782	7368	Economy	6200.00
0005432839354	7368	Economy	6200.00
0005432839340	7368	Economy	6200.00
0005432841032	7368	Economy	6200.00
0005435252764	7368	Economy	6200.00
0005435252757	7368	Economy	6200.00
0005435252675	7368	Economy	6200.00
0005432839357	7368	Economy	6200.00
0005435252701	7368	Economy	6200.00
0005432839351	7368	Economy	6200.00
0005432839360	7368	Economy	6200.00
0005435491436	7368	Economy	6200.00
0005434459020	7368	Economy	6200.00
0005432839347	7368	Economy	6200.00
0005432839362	7368	Economy	6200.00
0005434459022	7368	Economy	6200.00
0005435252800	7368	Economy	6200.00
0005432839344	7368	Economy	6200.00
0005432839363	7368	Economy	6200.00
0005432839372	7368	Economy	6200.00
0005435252700	7368	Economy	6200.00
0005435252699	7368	Economy	6200.00
0005434459015	7368	Economy	6200.00
0005432839352	7368	Economy	6200.00
0005432839366	7368	Economy	6200.00
0005435252689	7368	Economy	6200.00
0005435252788	7368	Economy	6200.00
0005435252783	7368	Economy	6200.00
0005434459028	7368	Economy	6200.00
0005435491447	7368	Economy	6200.00
0005434459011	7368	Economy	6200.00
0005435252706	7368	Economy	6200.00
0005435252714	7368	Economy	6200.00
0005434459017	7368	Economy	6200.00
0005432823468	7368	Economy	6200.00
0005432839368	7368	Economy	6200.00
0005432839371	7368	Economy	6200.00
0005435252715	7368	Economy	6200.00
0005432839358	7368	Economy	6200.00
0005432839349	7368	Economy	6200.00
0005435252705	7368	Economy	6200.00
0005432841033	7368	Economy	6200.00
0005432839355	7368	Economy	6200.00
0005432839356	7368	Economy	6200.00
0005435252708	7368	Economy	6200.00
0005434459021	7368	Economy	6200.00
0005434459023	7368	Economy	6200.00
0005432839343	7368	Economy	6200.00
0005432839359	7368	Economy	6200.00
0005435252727	7368	Economy	6200.00
0005432839370	7368	Economy	6200.00
0005432839113	28907	Business	18500.00
0005434458824	28907	Business	18500.00
0005432839245	28907	Business	18500.00
0005432001043	28907	Business	18500.00
0005435252885	28907	Business	18500.00
0005432839169	28907	Business	18500.00
0005432839136	28907	Business	18500.00
0005434664984	28907	Business	18500.00
0005432839125	28907	Business	18500.00
0005434458857	28907	Business	18500.00
0005435252886	28907	Economy	6200.00
0005435252891	28907	Economy	6200.00
0005432839198	28907	Economy	6200.00
0005432839144	28907	Economy	6200.00
0005434458851	28907	Economy	6200.00
0005434458810	28907	Economy	6800.00
0005432839007	28907	Economy	6800.00
0005435252892	28907	Economy	6800.00
0005435252887	28907	Economy	6800.00
0005432839008	28907	Economy	6800.00
0005432839105	28907	Economy	6200.00
0005432839186	28907	Economy	6200.00
0005432839030	28907	Economy	6200.00
0005434458865	28907	Economy	6200.00
0005435252879	28907	Economy	6200.00
0005434458941	28907	Economy	6200.00
0005432839167	28907	Economy	6200.00
0005435491460	28907	Economy	6200.00
0005435252884	28907	Economy	6200.00
0005435252875	28907	Economy	6200.00
0005434458887	28907	Economy	6200.00
0005435252880	28907	Economy	6200.00
0005434458904	28907	Economy	6200.00
0005432001044	28907	Economy	6200.00
0005432839123	28907	Economy	6200.00
0005435491462	28907	Economy	6200.00
0005432839185	28907	Economy	6200.00
0005432839197	28907	Economy	6200.00
0005434458866	28907	Economy	6200.00
0005435252889	28907	Economy	6200.00
0005435252874	28907	Economy	6200.00
0005435252878	28907	Economy	6200.00
0005435491461	28907	Economy	6200.00
0005432839031	28907	Economy	6200.00
0005435252882	28907	Economy	6200.00
0005434664983	28907	Economy	6200.00
0005434458776	28907	Economy	6200.00
0005432839127	28907	Economy	6200.00
0005432839046	28907	Economy	6200.00
0005434664985	28907	Economy	6200.00
0005435252888	28907	Economy	6200.00
0005435252876	28907	Economy	6200.00
0005432839112	28907	Economy	6200.00
0005434458942	28907	Economy	6200.00
0005432839168	28907	Economy	6200.00
0005435252890	28907	Economy	6200.00
0005432839126	28907	Economy	6200.00
0005432838991	28907	Economy	6200.00
0005434458876	28907	Economy	6200.00
0005434458811	28907	Economy	6200.00
0005434458905	28907	Economy	6200.00
0005432839242	28907	Economy	6200.00
0005432838990	28907	Economy	6200.00
0005432001045	28907	Economy	6200.00
0005435252881	28907	Economy	6200.00
0005432839101	28907	Economy	6200.00
0005435252883	28907	Economy	6200.00
0005432839143	28907	Economy	6200.00
0005432839241	28907	Economy	6200.00
0005432839091	28907	Economy	6200.00
0005435252877	28907	Economy	6200.00
0005434458775	28907	Economy	6200.00
0005434664986	28907	Economy	6200.00
0005435990697	8788	Business	145300.00
0005434276063	8788	Economy	48400.00
0005434276058	8788	Economy	48400.00
0005434276040	8788	Economy	53300.00
0005435990696	8788	Economy	48400.00
0005434276059	8788	Economy	48400.00
0005434276018	8788	Economy	48400.00
0005435990700	8788	Economy	48400.00
0005434276053	8788	Economy	48400.00
0005435990698	8788	Economy	48400.00
0005435990695	8788	Economy	48400.00
0005435990699	8788	Economy	48400.00
0005434276084	15732	Business	145300.00
0005434276088	15732	Business	145300.00
0005435990663	15732	Economy	48400.00
0005435990653	15732	Economy	48400.00
0005435990606	15732	Economy	48400.00
0005434276087	15732	Economy	48400.00
0005434276085	15732	Economy	48400.00
0005435990607	15732	Economy	48400.00
0005434276086	15732	Economy	48400.00
0005435990652	15732	Economy	48400.00
0005432427159	20615	Economy	14500.00
0005433476893	20615	Economy	14500.00
0005432427161	20615	Economy	14500.00
0005432427163	20615	Economy	14500.00
0005433476898	20615	Economy	14500.00
0005432427164	20615	Economy	14500.00
0005432427162	20615	Economy	14500.00
0005433476899	20615	Economy	14500.00
0005433476891	20615	Economy	14500.00
0005433476903	20615	Economy	14500.00
0005433476900	20615	Economy	14500.00
0005433476892	20615	Economy	14500.00
0005433476897	20615	Economy	14500.00
0005432427160	20615	Economy	14500.00
0005432427165	20615	Economy	14500.00
0005432427166	20615	Economy	14500.00
0005432427146	30859	Economy	15900.00
0005432427139	30859	Economy	14500.00
0005432427150	30859	Economy	14500.00
0005432427142	30859	Economy	14500.00
0005433476915	30859	Economy	14500.00
0005432427138	30859	Economy	14500.00
0005433476913	30859	Economy	14500.00
0005433476914	30859	Economy	14500.00
0005432427144	30859	Economy	14500.00
0005432427132	30859	Economy	14500.00
0005433476916	30859	Economy	14500.00
0005432427143	30859	Economy	14500.00
0005432909337	23839	Economy	13300.00
0005433468362	23839	Economy	12100.00
0005433468311	23839	Economy	12100.00
0005432909341	23839	Economy	12100.00
0005433468315	23839	Economy	12100.00
0005432909335	23839	Economy	12100.00
0005432909332	23839	Economy	12100.00
0005432909339	23839	Economy	12100.00
0005433468344	23839	Economy	12100.00
0005432909334	23839	Economy	12100.00
0005433468364	23839	Economy	12100.00
0005432909342	23839	Economy	12100.00
0005432909340	23839	Economy	12100.00
0005432909333	23839	Economy	12100.00
0005433468378	23839	Economy	12100.00
0005432909336	23839	Economy	12100.00
0005433468350	23839	Economy	12100.00
0005433468348	23839	Economy	12100.00
0005432909338	23839	Economy	12100.00
0005433468365	23839	Economy	12100.00
0005433468349	23839	Economy	12100.00
0005433468331	23839	Economy	12100.00
0005433468340	23839	Economy	12100.00
0005433468377	23839	Economy	12100.00
0005433468300	23839	Economy	12100.00
0005432336160	6406	Business	36600.00
0005435490220	6406	Business	36600.00
0005434149759	6406	Business	36600.00
0005434149740	6406	Business	36600.00
0005432336159	6406	Business	36600.00
0005435177191	6406	Business	36600.00
0005434149714	6406	Business	36600.00
0005434149735	6406	Business	36600.00
0005435723048	6406	Business	36600.00
0005432360860	6406	Economy	12200.00
0005432336156	6406	Economy	12200.00
0005432360854	6406	Economy	12200.00
0005435177105	6406	Economy	12200.00
0005432360859	6406	Economy	12200.00
0005432360847	6406	Economy	12200.00
0005435177092	6406	Economy	12200.00
0005432360875	6406	Economy	12200.00
0005432360872	6406	Economy	12200.00
0005432363449	6406	Economy	12200.00
0005432360881	6406	Economy	12200.00
0005432360836	6406	Economy	12200.00
0005432360870	6406	Economy	12200.00
0005432360850	6406	Economy	12200.00
0005434149801	6406	Economy	12200.00
0005434149799	6406	Economy	12200.00
0005435177242	6406	Economy	12200.00
0005432360855	6406	Economy	12200.00
0005432062284	6406	Economy	12200.00
0005432336154	6406	Economy	12200.00
0005432360840	6406	Economy	12200.00
0005432360864	6406	Economy	12200.00
0005432360839	6406	Economy	12200.00
0005435177009	6406	Economy	12200.00
0005432360876	6406	Economy	12200.00
0005432360852	6406	Economy	12200.00
0005432360874	6406	Economy	12200.00
0005432336155	6406	Economy	12200.00
0005432360846	6406	Economy	12200.00
0005432360863	6406	Economy	12200.00
0005432062283	6406	Economy	12200.00
0005432360879	6406	Economy	12200.00
0005435490245	6406	Economy	13400.00
0005432360845	6406	Economy	13400.00
0005434149752	6406	Economy	13400.00
0005432336153	6406	Economy	13400.00
0005432360867	6406	Economy	13400.00
0005435177093	6406	Economy	13400.00
0005432360880	6406	Economy	12200.00
0005432360848	6406	Economy	12200.00
0005432360835	6406	Economy	12200.00
0005435723043	6406	Economy	12200.00
0005432360843	6406	Economy	12200.00
0005435177156	6406	Economy	12200.00
0005432360861	6406	Economy	12200.00
0005432360871	6406	Economy	12200.00
0005432360856	6406	Economy	12200.00
0005435177157	6406	Economy	12200.00
0005435177194	6406	Economy	12200.00
0005434149713	6406	Economy	12200.00
0005432360841	6406	Economy	12200.00
0005432360869	6406	Economy	12200.00
0005432360857	6406	Economy	12200.00
0005432360834	6406	Economy	12200.00
0005434149736	6406	Economy	12200.00
0005432360873	6406	Economy	12200.00
0005432360853	6406	Economy	12200.00
0005432360838	6406	Economy	12200.00
0005432360862	6406	Economy	12200.00
0005435723044	6406	Economy	12200.00
0005435177201	6406	Economy	12200.00
0005432336158	6406	Economy	12200.00
0005432360849	6406	Economy	12200.00
0005432360878	6406	Economy	12200.00
0005432360868	6406	Economy	12200.00
0005435177091	6406	Economy	12200.00
0005435177106	6406	Economy	12200.00
0005435490223	6406	Economy	12200.00
0005432062282	6406	Economy	12200.00
0005435490244	6406	Economy	12200.00
0005432360866	6406	Economy	12200.00
0005434149726	6406	Economy	12200.00
0005432363450	6406	Economy	12200.00
0005432360882	6406	Economy	12200.00
0005432360877	6406	Economy	12200.00
0005432360858	6406	Economy	12200.00
0005434149720	6406	Economy	12200.00
0005434149721	6406	Economy	12200.00
0005432360842	6406	Economy	12200.00
0005434149749	6406	Economy	12200.00
0005432363451	6406	Economy	12200.00
0005435177108	6406	Economy	12200.00
0005434149768	6406	Economy	12200.00
0005432360851	6406	Economy	12200.00
0005432336162	6406	Economy	12200.00
0005434149800	6406	Economy	12200.00
0005432336157	6406	Economy	12200.00
0005435723047	6406	Economy	12200.00
0005432062281	6406	Economy	12200.00
0005432360837	6406	Economy	12200.00
0005432336161	6406	Economy	12200.00
0005432336152	6406	Economy	12200.00
0005432062285	6406	Economy	12200.00
0005432360865	6406	Economy	12200.00
0005432360844	6406	Economy	12200.00
0005432360883	6406	Economy	12200.00
0005434149754	6406	Economy	12200.00
0005435177117	6406	Economy	12200.00
0005432062286	6406	Economy	12200.00
0005434149847	21033	Business	36600.00
0005435177365	21033	Business	36600.00
0005432336075	21033	Business	36600.00
0005432360400	21033	Business	36600.00
0005435177369	21033	Business	36600.00
0005432360335	21033	Business	36600.00
0005434149853	21033	Business	36600.00
0005432360563	21033	Business	36600.00
0005435490268	21033	Business	36600.00
0005432360483	21033	Business	36600.00
0005432360343	21033	Business	36600.00
0005435177355	21033	Business	36600.00
0005435177370	21033	Economy	12200.00
0005432360384	21033	Economy	12200.00
0005432336041	21033	Economy	12200.00
0005435177349	21033	Economy	12200.00
0005432360303	21033	Economy	12200.00
0005432335957	21033	Economy	12200.00
0005435177354	21033	Economy	12200.00
0005432360447	21033	Economy	12200.00
0005434149850	21033	Economy	12200.00
0005435177360	21033	Economy	12200.00
0005432335975	21033	Economy	12200.00
0005432360281	21033	Economy	12200.00
0005432336078	21033	Economy	12200.00
0005432360502	21033	Economy	12200.00
0005432360304	21033	Economy	12200.00
0005432336069	21033	Economy	12200.00
0005435177366	21033	Economy	12200.00
0005432360443	21033	Economy	12200.00
0005432360516	21033	Economy	12200.00
0005434149849	21033	Economy	12200.00
0005435723068	21033	Economy	12200.00
0005432052780	21033	Economy	12200.00
0005432360461	21033	Economy	12200.00
0005432360239	21033	Economy	12200.00
0005435177358	21033	Economy	12200.00
0005435490270	21033	Economy	12200.00
0005432360404	21033	Economy	12200.00
0005435177361	21033	Economy	12200.00
0005435177367	21033	Economy	12200.00
0005435177363	21033	Economy	12200.00
0005435723066	21033	Economy	12200.00
0005432360351	21033	Economy	12200.00
0005432360198	21033	Economy	12200.00
0005435177368	21033	Economy	12200.00
0005432360722	21033	Economy	12200.00
0005435177352	21033	Economy	13400.00
0005432360589	21033	Economy	12200.00
0005432360488	21033	Economy	13400.00
0005432336085	21033	Economy	13400.00
0005432360448	21033	Economy	13400.00
0005432360280	21033	Economy	13400.00
0005435177356	21033	Economy	12200.00
0005432360681	21033	Economy	12200.00
0005432360451	21033	Economy	12200.00
0005432360585	21033	Economy	12200.00
0005432336061	21033	Economy	12200.00
0005434149848	21033	Economy	12200.00
0005432360276	21033	Economy	12200.00
0005432052777	21033	Economy	12200.00
0005435723069	21033	Economy	12200.00
0005435177357	21033	Economy	12200.00
0005432360240	21033	Economy	12200.00
0005432360322	21033	Economy	12200.00
0005434149855	21033	Economy	12200.00
0005432360323	21033	Economy	12200.00
0005432360282	21033	Economy	12200.00
0005432360683	21033	Economy	12200.00
0005432360199	21033	Economy	12200.00
0005434149846	21033	Economy	12200.00
0005432360682	21033	Economy	12200.00
0005432336079	21033	Economy	12200.00
0005435177353	21033	Economy	12200.00
0005432052779	21033	Economy	12200.00
0005432360491	21033	Economy	12200.00
0005432360551	21033	Economy	12200.00
0005432336042	21033	Economy	12200.00
0005434149851	21033	Economy	12200.00
0005435177371	21033	Economy	12200.00
0005435177373	21033	Economy	12200.00
0005432360399	21033	Economy	12200.00
0005432360125	21033	Economy	12200.00
0005435177350	21033	Economy	12200.00
0005432360723	21033	Economy	12200.00
0005432335974	21033	Economy	12200.00
0005434149845	21033	Economy	12200.00
0005435490269	21033	Economy	12200.00
0005435490271	21033	Economy	12200.00
0005432360442	21033	Economy	12200.00
0005435177362	21033	Economy	12200.00
0005435177359	21033	Economy	12200.00
0005432360446	21033	Economy	12200.00
0005434149852	21033	Economy	12200.00
0005432336019	21033	Economy	12200.00
0005435177351	21033	Economy	12200.00
0005432360370	21033	Economy	12200.00
0005432360629	21033	Economy	12200.00
0005432360283	21033	Economy	12200.00
0005435177347	21033	Economy	12200.00
0005432336059	21033	Economy	12200.00
0005434149854	21033	Economy	12200.00
0005432335973	21033	Economy	12200.00
0005432360429	21033	Economy	12200.00
0005435723067	21033	Economy	12200.00
0005435177348	21033	Economy	12200.00
0005435177346	21033	Economy	12200.00
0005432360273	21033	Economy	12200.00
0005434149856	21033	Economy	12200.00
0005432360440	21033	Economy	12200.00
0005432360352	21033	Economy	12200.00
0005432360302	21033	Economy	12200.00
0005432052778	21033	Economy	12200.00
0005435177364	21033	Economy	12200.00
0005435177372	21033	Economy	12200.00
0005432360630	21033	Economy	12200.00
0005434458841	17734	Economy	3400.00
0005434463930	17734	Economy	3400.00
0005434458880	17734	Economy	3400.00
0005434458910	17734	Economy	3100.00
0005434186230	17734	Economy	3100.00
0005434458874	17734	Economy	3100.00
0005434463933	17734	Economy	3100.00
0005434186229	17734	Economy	3100.00
0005434458823	17734	Economy	3100.00
0005434458844	17734	Economy	3100.00
0005434458881	17734	Economy	3100.00
0005434458843	17734	Economy	3100.00
0005434458964	17734	Economy	3100.00
0005434458838	17734	Economy	3100.00
0005434463931	17734	Economy	3100.00
0005434458871	17734	Economy	3100.00
0005434458842	17734	Economy	3100.00
0005434458864	17734	Economy	3100.00
0005434458870	17734	Economy	3100.00
0005434458875	17734	Economy	3100.00
0005434463932	17734	Economy	3100.00
0005434458903	17734	Economy	3100.00
0005434463951	29096	Economy	3400.00
0005434459028	29096	Economy	3400.00
0005434186202	29096	Economy	3400.00
0005434459027	29096	Economy	3400.00
0005434462811	29096	Economy	3100.00
0005434459022	29096	Economy	3100.00
0005434462810	29096	Economy	3100.00
0005434459011	29096	Economy	3100.00
0005434459023	29096	Economy	3100.00
0005434459016	29096	Economy	3100.00
0005434459025	29096	Economy	3100.00
0005434459015	29096	Economy	3100.00
0005434448348	29096	Economy	3100.00
0005434448346	29096	Economy	3100.00
0005434459024	29096	Economy	3100.00
0005434459021	29096	Economy	3100.00
0005434459014	29096	Economy	3100.00
0005434463949	29096	Economy	3100.00
0005434448349	29096	Economy	3100.00
0005434448347	29096	Economy	3100.00
0005434459026	29096	Economy	3100.00
0005434459013	29096	Economy	3100.00
0005434459019	29096	Economy	3100.00
0005434459020	29096	Economy	3100.00
0005434186198	29096	Economy	3100.00
0005434459029	29096	Economy	3100.00
0005434463950	29096	Economy	3100.00
0005434459018	29096	Economy	3100.00
0005434459017	29096	Economy	3100.00
0005434462809	29096	Economy	3100.00
0005434459012	29096	Economy	3100.00
0005434459010	29096	Economy	3100.00
0005434459030	29096	Economy	3100.00
0005432664167	6493	Business	185300.00
0005432663060	6493	Business	185300.00
0005432661951	6493	Business	185300.00
0005432663061	6493	Business	185300.00
0005432664161	6493	Business	185300.00
0005432661949	6493	Business	185300.00
0005432664159	6493	Business	185300.00
0005432661952	6493	Business	185300.00
0005432664171	6493	Business	185300.00
0005432664162	6493	Business	185300.00
0005432663069	6493	Business	185300.00
0005432661948	6493	Economy	61800.00
0005432661954	6493	Economy	61800.00
0005432663056	6493	Economy	61800.00
0005432664164	6493	Economy	61800.00
0005432661958	6493	Economy	61800.00
0005432661944	6493	Economy	61800.00
0005432664168	6493	Economy	67900.00
0005432661957	6493	Economy	61800.00
0005432664172	6493	Economy	61800.00
0005432663058	6493	Economy	61800.00
0005432661947	6493	Economy	61800.00
0005432663064	6493	Economy	61800.00
0005432664169	6493	Economy	61800.00
0005432663065	6493	Economy	61800.00
0005432664165	6493	Economy	61800.00
0005432664158	6493	Economy	61800.00
0005432663063	6493	Economy	61800.00
0005432663057	6493	Economy	61800.00
0005432661950	6493	Economy	61800.00
0005432663067	6493	Economy	61800.00
0005432661953	6493	Economy	61800.00
0005432663059	6493	Economy	61800.00
0005432663070	6493	Economy	61800.00
0005432661959	6493	Economy	61800.00
0005432661946	6493	Economy	61800.00
0005432663062	6493	Economy	61800.00
0005432661945	6493	Economy	61800.00
0005432664163	6493	Economy	61800.00
0005432663068	6493	Economy	61800.00
0005432664170	6493	Economy	61800.00
0005432664160	6493	Economy	61800.00
0005432661956	6493	Economy	61800.00
0005432663066	6493	Economy	61800.00
0005432664166	6493	Economy	61800.00
0005432661955	6493	Economy	61800.00
0005432604718	21462	Economy	7300.00
0005432604730	21462	Economy	7300.00
0005432604701	21462	Economy	7300.00
0005432604715	21462	Economy	7300.00
0005432604728	21462	Economy	6600.00
0005432604707	21462	Economy	6600.00
0005432604698	21462	Economy	6600.00
0005432604697	21462	Economy	6600.00
0005432604727	21462	Economy	6600.00
0005432604725	21462	Economy	6600.00
0005432604704	21462	Economy	6600.00
0005432604723	21462	Economy	6600.00
0005432604733	21462	Economy	6600.00
0005432604724	21462	Economy	6600.00
0005432604736	21462	Economy	6600.00
0005432604717	21462	Economy	6600.00
0005432604721	21462	Economy	6600.00
0005432604729	21462	Economy	6600.00
0005432604734	21462	Economy	6600.00
0005432604716	21462	Economy	6600.00
0005432604726	21462	Economy	6600.00
0005432604714	21462	Economy	6600.00
0005432604699	21462	Economy	6600.00
0005432604735	21462	Economy	6600.00
0005432604703	21462	Economy	6600.00
0005432604713	21462	Economy	6600.00
0005432604705	21462	Economy	6600.00
0005432604731	21462	Economy	6600.00
0005432604711	21462	Economy	6600.00
0005432604732	21462	Economy	6600.00
0005432604709	21462	Economy	6600.00
0005432604722	21462	Economy	6600.00
0005432604719	21462	Economy	6600.00
0005432604720	21462	Economy	6600.00
0005432604700	21462	Economy	6600.00
0005432604712	21462	Economy	6600.00
0005432604706	21462	Economy	6600.00
0005432604708	21462	Economy	6600.00
0005432604696	21462	Economy	6600.00
0005432604702	21462	Economy	6600.00
0005432604710	21462	Economy	6600.00
0005432604267	31663	Economy	7300.00
0005432604452	31663	Economy	7300.00
0005432604181	31663	Economy	7300.00
0005432604347	31663	Economy	7300.00
0005432604210	31663	Economy	6600.00
0005432604180	31663	Economy	6600.00
0005432604322	31663	Economy	6600.00
0005432604313	31663	Economy	6600.00
0005432604441	31663	Economy	6600.00
0005432604219	31663	Economy	6600.00
0005432604244	31663	Economy	6600.00
0005432604311	31663	Economy	6600.00
0005432604442	31663	Economy	6600.00
0005432604371	31663	Economy	6600.00
0005432604114	31663	Economy	6600.00
0005432604500	31663	Economy	6600.00
0005432604320	31663	Economy	6600.00
0005432604367	31663	Economy	6600.00
0005432604342	31663	Economy	6600.00
0005432604509	31663	Economy	6600.00
0005432604392	31663	Economy	6600.00
0005432604402	31663	Economy	6600.00
0005432604422	31663	Economy	6600.00
0005432604501	31663	Economy	6600.00
0005432604283	31663	Economy	6600.00
0005432604113	31663	Economy	6600.00
0005432604372	31663	Economy	6600.00
0005432604186	31663	Economy	6600.00
0005432604458	31663	Economy	6600.00
0005432604478	31663	Economy	6600.00
0005432604343	31663	Economy	6600.00
0005432604383	31663	Economy	6600.00
0005432604382	31663	Economy	6600.00
0005432604439	31663	Economy	6600.00
0005432604569	31663	Economy	6600.00
0005432604418	31663	Economy	6600.00
0005432604237	31663	Economy	6600.00
0005432604417	31663	Economy	6600.00
0005432604344	31663	Economy	6600.00
0005432604341	31663	Economy	6600.00
0005432604336	31663	Economy	6600.00
0005432604497	31663	Economy	6600.00
0005432604438	31663	Economy	6600.00
0005432604486	31663	Economy	6600.00
0005432604282	31663	Economy	6600.00
0005432604268	31663	Economy	6600.00
0005432604319	31663	Economy	6600.00
0005432604487	31663	Economy	6600.00
0005433293258	12298	Economy	19500.00
0005435154603	12298	Economy	19500.00
0005433293231	12298	Economy	17800.00
0005433293248	12298	Economy	17800.00
0005433293212	12298	Economy	17800.00
0005435154604	12298	Economy	17800.00
0005435154610	12298	Economy	17800.00
0005433293253	12298	Economy	17800.00
0005435154605	12298	Economy	17800.00
0005433293252	12298	Economy	17800.00
0005435154602	12298	Economy	17800.00
0005433293263	12298	Economy	17800.00
0005433293277	12298	Economy	17800.00
0005435154607	12298	Economy	17800.00
0005433293251	12298	Economy	17800.00
0005433293224	12298	Economy	17800.00
0005435154609	12298	Economy	17800.00
0005433293276	12298	Economy	17800.00
0005433293225	12298	Economy	17800.00
0005435154608	12298	Economy	17800.00
0005433293262	12298	Economy	17800.00
0005435154606	12298	Economy	17800.00
0005433473269	23905	Economy	14000.00
0005433473273	23905	Economy	12700.00
0005435257292	23905	Economy	12700.00
0005433473300	23905	Economy	12700.00
0005433473264	23905	Economy	12700.00
0005433473243	23905	Economy	12700.00
0005435257288	23905	Economy	12700.00
0005433473272	23905	Economy	12700.00
0005435257290	23905	Economy	12700.00
0005435257286	23905	Economy	12700.00
0005435257291	23905	Economy	12700.00
0005433473276	23905	Economy	12700.00
0005433473245	23905	Economy	12700.00
0005433473233	23905	Economy	12700.00
0005435257289	23905	Economy	12700.00
0005433473291	23905	Economy	12700.00
0005433473235	23905	Economy	12700.00
0005433473270	23905	Economy	12700.00
0005435257293	23905	Economy	12700.00
0005433473240	23905	Economy	12700.00
0005433473244	23905	Economy	12700.00
0005435257294	23905	Economy	12700.00
0005433473222	23905	Economy	12700.00
0005433473223	23905	Economy	12700.00
0005433473334	23905	Economy	12700.00
0005435257296	23905	Economy	12700.00
0005433473239	23905	Economy	12700.00
0005433473224	23905	Economy	12700.00
0005433473290	23905	Economy	12700.00
0005435257295	23905	Economy	12700.00
0005433473231	23905	Economy	12700.00
0005435257287	23905	Economy	12700.00
0005433473234	23905	Economy	12700.00
0005433473268	23905	Economy	12700.00
0005434606833	18884	Economy	6600.00
0005435904901	18884	Economy	6600.00
0005435904902	18884	Economy	6600.00
0005435904903	18884	Economy	6600.00
0005435904900	18884	Economy	6600.00
0005434606824	18884	Economy	6600.00
0005434606865	22290	Economy	6600.00
0005434606864	22290	Economy	6600.00
0005434604928	22290	Economy	6600.00
0005434604929	22290	Economy	6600.00
0005434606863	22290	Economy	6600.00
0005435904414	3845	Economy	24900.00
0005435904412	3845	Economy	24900.00
0005434522487	3845	Economy	22600.00
0005434522486	3845	Economy	22600.00
0005434522483	3845	Economy	22600.00
0005434522484	3845	Economy	22600.00
0005434522480	3845	Economy	22600.00
0005435904413	3845	Economy	22600.00
0005434522485	3845	Economy	22600.00
0005435904404	3845	Economy	22600.00
0005434522481	3845	Economy	22600.00
0005434602923	3845	Economy	22600.00
0005434522479	3845	Economy	22600.00
0005434602926	3845	Economy	22600.00
0005434522482	3845	Economy	22600.00
0005434602925	3845	Economy	22600.00
0005434522488	3845	Economy	22600.00
0005434602928	3845	Economy	22600.00
0005434602927	3845	Economy	22600.00
0005435904408	3845	Economy	22600.00
0005435904410	3845	Economy	22600.00
0005434602924	3845	Economy	22600.00
0005435904432	19062	Economy	24900.00
0005434604914	19062	Economy	24900.00
0005434602889	19062	Economy	22600.00
0005434604881	19062	Economy	22600.00
0005434602905	19062	Economy	22600.00
0005434522458	19062	Economy	22600.00
0005434522465	19062	Economy	22600.00
0005435904710	19062	Economy	22600.00
0005434604893	19062	Economy	22600.00
0005434602902	19062	Economy	22600.00
0005434604913	19062	Economy	22600.00
0005434602901	19062	Economy	22600.00
0005434604905	19062	Economy	22600.00
0005435904428	19062	Economy	22600.00
0005434604888	19062	Economy	22600.00
0005435904431	19062	Economy	22600.00
0005435904429	19062	Economy	22600.00
0005434602903	19062	Economy	22600.00
0005434522456	19062	Economy	22600.00
0005434602906	19062	Economy	22600.00
0005435904430	19062	Economy	22600.00
0005434522459	19062	Economy	22600.00
0005434604882	19062	Economy	22600.00
0005434602904	19062	Economy	22600.00
0005434602895	19062	Economy	22600.00
0005435904709	19062	Economy	22600.00
0005433875386	371	Business	44500.00
0005433293250	371	Business	44500.00
0005432891060	371	Business	44500.00
0005432747958	371	Business	44500.00
0005433293271	371	Business	44500.00
0005433293281	371	Business	44500.00
0005432747930	371	Business	44500.00
0005432747946	371	Business	44500.00
0005432747955	371	Business	44500.00
0005432891042	371	Business	44500.00
0005432749806	371	Business	44500.00
0005433875371	371	Business	44500.00
0005432891014	371	Economy	14800.00
0005432891031	371	Economy	14800.00
0005432747962	371	Economy	14800.00
0005432747956	371	Economy	14800.00
0005433875385	371	Economy	14800.00
0005432220046	371	Economy	14800.00
0005432747936	371	Economy	14800.00
0005432747931	371	Economy	14800.00
0005432747948	371	Economy	14800.00
0005433293272	371	Economy	16300.00
0005432747954	371	Economy	16300.00
0005432891064	371	Economy	16300.00
0005432891022	371	Economy	16300.00
0005432220047	371	Economy	16300.00
0005432747968	371	Economy	14800.00
0005432220045	371	Economy	14800.00
0005432751559	371	Economy	14800.00
0005435154611	371	Economy	14800.00
0005432747945	371	Economy	14800.00
0005432891128	371	Economy	14800.00
0005432747960	371	Economy	14800.00
0005432891130	371	Economy	14800.00
0005432749805	371	Economy	14800.00
0005432747935	371	Economy	14800.00
0005433293249	371	Economy	14800.00
0005433293259	371	Economy	14800.00
0005432747965	371	Economy	14800.00
0005432747942	371	Economy	14800.00
0005433293260	371	Economy	14800.00
0005432891129	371	Economy	14800.00
0005432747952	371	Economy	14800.00
0005432891051	371	Economy	14800.00
0005432747957	371	Economy	14800.00
0005432747970	371	Economy	14800.00
0005432747949	371	Economy	14800.00
0005432747932	371	Economy	14800.00
0005432747929	371	Economy	14800.00
0005432747967	371	Economy	14800.00
0005432891074	371	Economy	14800.00
0005432747933	371	Economy	14800.00
0005432891021	371	Economy	14800.00
0005433293236	371	Economy	14800.00
0005432753333	371	Economy	14800.00
0005432747944	371	Economy	14800.00
0005432891041	371	Economy	14800.00
0005432891085	371	Economy	14800.00
0005432747950	371	Economy	14800.00
0005432751556	371	Economy	14800.00
0005432747937	371	Economy	14800.00
0005432891038	371	Economy	14800.00
0005432747951	371	Economy	14800.00
0005432747966	371	Economy	14800.00
0005432747963	371	Economy	14800.00
0005432891104	371	Economy	14800.00
0005432747969	371	Economy	14800.00
0005432747934	371	Economy	14800.00
0005432220044	371	Economy	14800.00
0005432747961	371	Economy	14800.00
0005432891108	371	Economy	14800.00
0005433293242	371	Economy	14800.00
0005432891052	371	Economy	14800.00
0005432747938	371	Economy	14800.00
0005432747964	371	Economy	14800.00
0005432751557	371	Economy	14800.00
0005432747947	371	Economy	14800.00
0005432891032	371	Economy	14800.00
0005432747953	371	Economy	14800.00
0005432747941	371	Economy	14800.00
0005432891012	371	Economy	14800.00
0005432753332	371	Economy	14800.00
0005432747940	371	Economy	14800.00
0005433293261	371	Economy	14800.00
0005432747939	371	Economy	14800.00
0005432891039	371	Economy	14800.00
0005432747943	371	Economy	14800.00
0005432747959	371	Economy	14800.00
0005432891084	371	Economy	14800.00
0005432751558	371	Economy	14800.00
0005432891210	12084	Business	44500.00
0005432747701	12084	Business	44500.00
0005432891212	12084	Business	44500.00
0005432747594	12084	Business	44500.00
0005432891228	12084	Business	44500.00
0005432214827	12084	Business	44500.00
0005432891222	12084	Business	44500.00
0005432891219	12084	Business	44500.00
0005432747703	12084	Business	44500.00
0005432747585	12084	Economy	14800.00
0005432747609	12084	Economy	14800.00
0005432747621	12084	Economy	14800.00
0005432747635	12084	Economy	14800.00
0005432891221	12084	Economy	14800.00
0005432753300	12084	Economy	14800.00
0005432891215	12084	Economy	14800.00
0005432756846	12084	Economy	14800.00
0005432891225	12084	Economy	14800.00
0005432891211	12084	Economy	16300.00
0005432747729	12084	Economy	16300.00
0005432747636	12084	Economy	16300.00
0005432891231	12084	Economy	16300.00
0005432747574	12084	Economy	16300.00
0005432747751	12084	Economy	14800.00
0005432747712	12084	Economy	14800.00
0005433875396	12084	Economy	14800.00
0005432747595	12084	Economy	14800.00
0005432747727	12084	Economy	14800.00
0005432747713	12084	Economy	14800.00
0005432747749	12084	Economy	14800.00
0005432747544	12084	Economy	14800.00
0005432747611	12084	Economy	14800.00
0005432891223	12084	Economy	14800.00
0005432747760	12084	Economy	14800.00
0005432747423	12084	Economy	14800.00
0005432756847	12084	Economy	14800.00
0005432747728	12084	Economy	14800.00
0005432747659	12084	Economy	14800.00
0005432747750	12084	Economy	14800.00
0005432891213	12084	Economy	14800.00
0005432747622	12084	Economy	14800.00
0005432753299	12084	Economy	14800.00
0005432891220	12084	Economy	14800.00
0005432891218	12084	Economy	14800.00
0005432214826	12084	Economy	14800.00
0005432891216	12084	Economy	14800.00
0005432747469	12084	Economy	14800.00
0005432891230	12084	Economy	14800.00
0005432891224	12084	Economy	14800.00
0005432753314	12084	Economy	14800.00
0005432753294	12084	Economy	14800.00
0005432747573	12084	Economy	14800.00
0005432749787	12084	Economy	14800.00
0005432747586	12084	Economy	14800.00
0005433875395	12084	Economy	14800.00
0005432891217	12084	Economy	14800.00
0005432753313	12084	Economy	14800.00
0005432747608	12084	Economy	14800.00
0005432747752	12084	Economy	14800.00
0005432747759	12084	Economy	14800.00
0005432891227	12084	Economy	14800.00
0005432891229	12084	Economy	14800.00
0005432747762	12084	Economy	14800.00
0005433875394	12084	Economy	14800.00
0005432891214	12084	Economy	14800.00
0005432747865	12084	Economy	14800.00
0005432747704	12084	Economy	14800.00
0005432747761	12084	Economy	14800.00
0005432747705	12084	Economy	14800.00
0005432749793	12084	Economy	14800.00
0005432891226	12084	Economy	14800.00
0005433531328	18946	Economy	28200.00
0005433525141	18946	Economy	28200.00
0005433525137	18946	Economy	25700.00
0005433525145	18946	Economy	25700.00
0005433533344	18946	Economy	25700.00
0005432927996	18946	Economy	25700.00
0005433531327	18946	Economy	25700.00
0005433533345	18946	Economy	25700.00
0005433531326	18946	Economy	25700.00
0005432927995	18946	Economy	25700.00
0005433525136	18946	Economy	25700.00
0005432928004	18946	Economy	25700.00
0005433533342	18946	Economy	25700.00
0005433533341	18946	Economy	25700.00
0005433533343	18946	Economy	25700.00
0005433525142	18946	Economy	25700.00
0005433525143	18946	Economy	25700.00
0005433525140	18946	Economy	25700.00
0005433525144	18946	Economy	25700.00
0005433525146	18946	Economy	25700.00
0005433531329	18946	Economy	25700.00
0005433525139	18946	Economy	25700.00
0005433525138	18946	Economy	25700.00
0005433531330	18946	Economy	25700.00
0005433527271	32459	Economy	28200.00
0005433525091	32459	Economy	28200.00
0005433524987	32459	Economy	28200.00
0005433525083	32459	Economy	25700.00
0005433531287	32459	Economy	25700.00
0005433525090	32459	Economy	25700.00
0005432928044	32459	Economy	25700.00
0005433527264	32459	Economy	25700.00
0005432928045	32459	Economy	25700.00
0005433527258	32459	Economy	25700.00
0005433525051	32459	Economy	25700.00
0005433524994	32459	Economy	25700.00
0005433525092	32459	Economy	25700.00
0005433524986	32459	Economy	25700.00
0005432928042	32459	Economy	25700.00
0005433527257	32459	Economy	25700.00
0005433527254	32459	Economy	25700.00
0005433531296	32459	Economy	25700.00
0005433527255	32459	Economy	25700.00
0005433527260	32459	Economy	25700.00
0005433527263	32459	Economy	25700.00
0005433531288	32459	Economy	25700.00
0005432928040	32459	Economy	25700.00
0005432928043	32459	Economy	25700.00
0005433525050	32459	Economy	25700.00
0005433531305	32459	Economy	25700.00
0005433527272	32459	Economy	25700.00
0005433527277	32459	Economy	25700.00
0005433531293	32459	Economy	25700.00
0005433527259	32459	Economy	25700.00
0005433531297	32459	Economy	25700.00
0005432928041	32459	Economy	25700.00
0005433525084	32459	Economy	25700.00
0005435299771	5267	Business	84000.00
0005434824926	5267	Business	84000.00
0005435373544	5267	Business	84000.00
0005434824943	5267	Business	84000.00
0005435373109	5267	Business	84000.00
0005434824946	5267	Business	84000.00
0005434824881	5267	Business	84000.00
0005434824864	5267	Business	84000.00
0005434824928	5267	Business	84000.00
0005434828723	5267	Business	84000.00
0005434824924	5267	Business	84000.00
0005432394148	5267	Business	84000.00
0005434824835	5267	Business	84000.00
0005434824944	5267	Business	84000.00
0005435373568	5267	Business	84000.00
0005434824945	5267	Business	84000.00
0005435373441	5267	Business	84000.00
0005435386587	5267	Business	84000.00
0005435178993	5267	Business	84000.00
0005435735136	5267	Business	84000.00
0005435373567	5267	Comfort	47600.00
0005435373543	5267	Comfort	47600.00
0005434824850	5267	Comfort	47600.00
0005434824845	5267	Comfort	47600.00
0005435373325	5267	Comfort	47600.00
0005434824907	5267	Comfort	47600.00
0005434824840	5267	Comfort	47600.00
0005435373369	5267	Comfort	47600.00
0005434558360	5267	Comfort	47600.00
0005434824898	5267	Comfort	47600.00
0005435373420	5267	Comfort	47600.00
0005434824892	5267	Comfort	47600.00
0005434824860	5267	Comfort	47600.00
0005434824822	5267	Comfort	47600.00
0005434828722	5267	Comfort	47600.00
0005435373276	5267	Comfort	47600.00
0005434824908	5267	Comfort	47600.00
0005434824844	5267	Comfort	47600.00
0005434824931	5267	Comfort	47600.00
0005435150177	5267	Comfort	47600.00
0005434831197	5267	Comfort	47600.00
0005434824826	5267	Comfort	47600.00
0005434824912	5267	Comfort	47600.00
0005435373326	5267	Comfort	47600.00
0005435386566	5267	Comfort	47600.00
0005435386573	5267	Comfort	47600.00
0005435304155	5267	Comfort	47600.00
0005435373385	5267	Comfort	47600.00
0005435150170	5267	Comfort	47600.00
0005435373621	5267	Comfort	47600.00
0005435373263	5267	Comfort	47600.00
0005432121483	5267	Comfort	47600.00
0005434824876	5267	Comfort	47600.00
0005435373182	5267	Comfort	47600.00
0005434824879	5267	Comfort	47600.00
0005434824910	5267	Comfort	47600.00
0005434824940	5267	Comfort	47600.00
0005435373492	5267	Economy	28000.00
0005435373469	5267	Economy	28000.00
0005435299785	5267	Economy	28000.00
0005434824935	5267	Economy	28000.00
0005435373534	5267	Economy	28000.00
0005435373248	5267	Economy	28000.00
0005435373297	5267	Economy	28000.00
0005434824843	5267	Economy	28000.00
0005434824923	5267	Economy	28000.00
0005434824875	5267	Economy	28000.00
0005435373066	5267	Economy	28000.00
0005434824937	5267	Economy	28000.00
0005434831195	5267	Economy	28000.00
0005434824941	5267	Economy	28000.00
0005434824837	5267	Economy	28000.00
0005432121472	5267	Economy	28000.00
0005434831196	5267	Economy	28000.00
0005435373456	5267	Economy	28000.00
0005434824857	5267	Economy	28000.00
0005432121485	5267	Economy	28000.00
0005435373454	5267	Economy	28000.00
0005434824916	5267	Economy	28000.00
0005435373540	5267	Economy	28000.00
0005434824906	5267	Economy	28000.00
0005435373301	5267	Economy	28000.00
0005435304183	5267	Economy	28000.00
0005434824851	5267	Economy	28000.00
0005434558362	5267	Economy	28000.00
0005435373158	5267	Economy	28000.00
0005434824831	5267	Economy	28000.00
0005435373478	5267	Economy	28000.00
0005432394145	5267	Economy	28000.00
0005434824846	5267	Economy	28000.00
0005434828724	5267	Economy	28000.00
0005435373341	5267	Economy	28000.00
0005434824919	5267	Economy	28000.00
0005432121476	5267	Economy	28000.00
0005434824832	5267	Economy	28000.00
0005435373428	5267	Economy	28000.00
0005432121477	5267	Economy	28000.00
0005434824878	5267	Economy	28000.00
0005434824861	5267	Economy	28000.00
0005434824877	5267	Economy	28000.00
0005435150176	5267	Economy	28000.00
0005435373368	5267	Economy	28000.00
0005434824918	5267	Economy	28000.00
0005432823454	5267	Economy	28000.00
0005434824936	5267	Economy	28000.00
0005434824927	5267	Economy	28000.00
0005432396283	5267	Economy	28000.00
0005435373156	5267	Economy	28000.00
0005432394144	5267	Economy	28000.00
0005435150168	5267	Economy	28000.00
0005434824899	5267	Economy	28000.00
0005435299770	5267	Economy	28000.00
0005434824865	5267	Economy	30800.00
0005434831194	5267	Economy	28000.00
0005434558359	5267	Economy	28000.00
0005435373280	5267	Economy	28000.00
0005434824932	5267	Economy	30800.00
0005434824911	5267	Economy	28000.00
0005435373555	5267	Economy	30800.00
0005434824909	5267	Economy	28000.00
0005435373450	5267	Economy	28000.00
0005435373556	5267	Economy	28000.00
0005435373585	5267	Economy	28000.00
0005434558355	5267	Economy	28000.00
0005432396286	5267	Economy	28000.00
0005434824915	5267	Economy	28000.00
0005435299784	5267	Economy	28000.00
0005434824829	5267	Economy	28000.00
0005435373350	5267	Economy	28000.00
0005434824866	5267	Economy	28000.00
0005434824825	5267	Economy	28000.00
0005434824901	5267	Economy	28000.00
0005435373491	5267	Economy	28000.00
0005435150173	5267	Economy	28000.00
0005432121481	5267	Economy	28000.00
0005434824882	5267	Economy	28000.00
0005435386578	5267	Economy	28000.00
0005434824939	5267	Economy	28000.00
0005434824890	5267	Economy	28000.00
0005434824853	5267	Economy	28000.00
0005434824888	5267	Economy	28000.00
0005435373429	5267	Economy	28000.00
0005435150172	5267	Economy	28000.00
0005435373593	5267	Economy	28000.00
0005435299781	5267	Economy	28000.00
0005434824934	5267	Economy	28000.00
0005434824903	5267	Economy	28000.00
0005434824925	5267	Economy	28000.00
0005434558356	5267	Economy	28000.00
0005434824904	5267	Economy	28000.00
0005435373157	5267	Economy	28000.00
0005432121478	5267	Economy	28000.00
0005434824821	5267	Economy	28000.00
0005434558354	5267	Economy	28000.00
0005435150174	5267	Economy	28000.00
0005435373693	5267	Economy	28000.00
0005435373110	5267	Economy	28000.00
0005434824894	5267	Economy	28000.00
0005432121474	5267	Economy	28000.00
0005434558364	5267	Economy	28000.00
0005434824917	5267	Economy	28000.00
0005434824818	5267	Economy	28000.00
0005435373472	5267	Economy	28000.00
0005435304156	5267	Economy	28000.00
0005434824870	5267	Economy	28000.00
0005432396285	5267	Economy	28000.00
0005434824854	5267	Economy	28000.00
0005432394147	5267	Economy	28000.00
0005434824838	5267	Economy	28000.00
0005434824905	5267	Economy	28000.00
0005435150171	5267	Economy	28000.00
0005434824883	5267	Economy	28000.00
0005434824874	5267	Economy	28000.00
0005434824869	5267	Economy	28000.00
0005434558361	5267	Economy	28000.00
0005434824887	5267	Economy	28000.00
0005434824873	5267	Economy	28000.00
0005432121482	5267	Economy	28000.00
0005434824933	5267	Economy	28000.00
0005435373618	5267	Economy	28000.00
0005435373617	5267	Economy	28000.00
0005434824920	5267	Economy	28000.00
0005435150167	5267	Economy	28000.00
0005435373533	5267	Economy	28000.00
0005432823455	5267	Economy	28000.00
0005435373573	5267	Economy	28000.00
0005434824891	5267	Economy	28000.00
0005434558357	5267	Economy	28000.00
0005435150165	5267	Economy	28000.00
0005434824897	5267	Economy	28000.00
0005434824871	5267	Economy	28000.00
0005434831193	5267	Economy	28000.00
0005435373344	5267	Economy	28000.00
0005434824836	5267	Economy	28000.00
0005434824872	5267	Economy	28000.00
0005432121480	5267	Economy	28000.00
0005434824884	5267	Economy	28000.00
0005434824858	5267	Economy	28000.00
0005434824856	5267	Economy	28000.00
0005434824867	5267	Economy	28000.00
0005434824830	5267	Economy	28000.00
0005432394146	5267	Economy	28000.00
0005435373393	5267	Economy	28000.00
0005434824863	5267	Economy	28000.00
0005435373259	5267	Economy	28000.00
0005432121479	5267	Economy	30800.00
0005434558363	5267	Economy	30800.00
0005434824862	5267	Economy	28000.00
0005432396284	5267	Economy	28000.00
0005434824819	5267	Economy	28000.00
0005435373538	5267	Economy	28000.00
0005434824913	5267	Economy	28000.00
0005435386598	5267	Economy	28000.00
0005434824896	5267	Economy	28000.00
0005434824848	5267	Economy	28000.00
0005432121475	5267	Economy	28000.00
0005434824823	5267	Economy	28000.00
0005434824902	5267	Economy	28000.00
0005434824886	5267	Economy	28000.00
0005434824921	5267	Economy	28000.00
0005434824847	5267	Economy	28000.00
0005434824839	5267	Economy	28000.00
0005435150169	5267	Economy	28000.00
0005434824868	5267	Economy	28000.00
0005434824820	5267	Economy	28000.00
0005435373267	5267	Economy	28000.00
0005434824827	5267	Economy	28000.00
0005434824842	5267	Economy	28000.00
0005432121473	5267	Economy	28000.00
0005434824852	5267	Economy	28000.00
0005434824833	5267	Economy	28000.00
0005435735128	5267	Economy	28000.00
0005435373155	5267	Economy	28000.00
0005434824817	5267	Economy	28000.00
0005434824859	5267	Economy	28000.00
0005435178991	5267	Economy	28000.00
0005435373470	5267	Economy	28000.00
0005435373108	5267	Economy	28000.00
0005435373327	5267	Economy	28000.00
0005432121484	5267	Economy	28000.00
0005435304164	5267	Economy	28000.00
0005434824900	5267	Economy	28000.00
0005435373349	5267	Economy	28000.00
0005434824885	5267	Economy	28000.00
0005435386588	5267	Economy	28000.00
0005434824942	5267	Economy	28000.00
0005432823453	5267	Economy	28000.00
0005435373159	5267	Economy	28000.00
0005434824828	5267	Economy	28000.00
0005435661938	5267	Economy	28000.00
0005434824855	5267	Economy	28000.00
0005434824895	5267	Economy	28000.00
0005435150175	5267	Economy	28000.00
0005434824849	5267	Economy	28000.00
0005434824889	5267	Economy	28000.00
0005434824922	5267	Economy	28000.00
0005435304182	5267	Economy	28000.00
0005434824930	5267	Economy	28000.00
0005435373504	5267	Economy	28000.00
0005434824824	5267	Economy	28000.00
0005434824938	5267	Economy	28000.00
0005434824929	5267	Economy	28000.00
0005435373211	5267	Economy	28000.00
0005434824893	5267	Economy	28000.00
0005434824880	5267	Economy	28000.00
0005435373620	5267	Economy	28000.00
0005434824834	5267	Economy	28000.00
0005434824914	5267	Economy	28000.00
0005435150166	5267	Economy	28000.00
0005434824841	5267	Economy	28000.00
0005435386593	5267	Economy	28000.00
0005434558358	5267	Economy	28000.00
0005434664982	5267	Economy	28000.00
0005434824054	9903	Business	84000.00
0005434824055	9903	Business	84000.00
0005434823277	9903	Business	84000.00
0005435373957	9903	Business	84000.00
0005435373901	9903	Business	84000.00
0005435373914	9903	Business	84000.00
0005434664964	9903	Business	84000.00
0005434831163	9903	Business	84000.00
0005435299825	9903	Business	84000.00
0005434823902	9903	Business	84000.00
0005434831144	9903	Business	84000.00
0005434824253	9903	Business	84000.00
0005434831142	9903	Business	84000.00
0005435373959	9903	Business	84000.00
0005434823869	9903	Business	84000.00
0005435373947	9903	Business	84000.00
0005434824027	9903	Business	84000.00
0005434823713	9903	Business	84000.00
0005434823718	9903	Business	84000.00
0005434824114	9903	Business	84000.00
0005434823540	9903	Comfort	47600.00
0005432396238	9903	Comfort	47600.00
0005435386639	9903	Comfort	47600.00
0005434823373	9903	Comfort	47600.00
0005434558235	9903	Comfort	47600.00
0005434823852	9903	Comfort	47600.00
0005435373905	9903	Comfort	47600.00
0005435373912	9903	Comfort	47600.00
0005435179403	9903	Comfort	47600.00
0005432203135	9903	Comfort	47600.00
0005434823834	9903	Comfort	47600.00
0005432203134	9903	Comfort	47600.00
0005434823436	9903	Comfort	47600.00
0005435661963	9903	Comfort	47600.00
0005434831157	9903	Comfort	47600.00
0005434823819	9903	Comfort	47600.00
0005434824146	9903	Comfort	47600.00
0005432203137	9903	Comfort	47600.00
0005434823802	9903	Comfort	47600.00
0005435150006	9903	Comfort	47600.00
0005435373944	9903	Comfort	47600.00
0005434823946	9903	Comfort	47600.00
0005435373949	9903	Comfort	47600.00
0005435373940	9903	Comfort	47600.00
0005435373919	9903	Comfort	47600.00
0005434823498	9903	Comfort	47600.00
0005435302247	9903	Comfort	47600.00
0005435373918	9903	Comfort	47600.00
0005434823736	9903	Comfort	47600.00
0005434824285	9903	Comfort	47600.00
0005435299822	9903	Comfort	47600.00
0005435373921	9903	Economy	28000.00
0005435373922	9903	Economy	28000.00
0005435373903	9903	Economy	28000.00
0005435150039	9903	Economy	28000.00
0005434824088	9903	Economy	28000.00
0005434823829	9903	Economy	28000.00
0005435373932	9903	Economy	28000.00
0005434558278	9903	Economy	28000.00
0005434823948	9903	Economy	28000.00
0005435373960	9903	Economy	28000.00
0005434823928	9903	Economy	28000.00
0005434823474	9903	Economy	28000.00
0005434823468	9903	Economy	28000.00
0005435386640	9903	Economy	28000.00
0005434823485	9903	Economy	28000.00
0005434823786	9903	Economy	28000.00
0005434824287	9903	Economy	28000.00
0005432203136	9903	Economy	28000.00
0005434823621	9903	Economy	28000.00
0005434831177	9903	Economy	28000.00
0005435299824	9903	Economy	28000.00
0005435302246	9903	Economy	28000.00
0005434823410	9903	Economy	28000.00
0005435373939	9903	Economy	28000.00
0005435373920	9903	Economy	28000.00
0005434823565	9903	Economy	28000.00
0005435386643	9903	Economy	28000.00
0005434558234	9903	Economy	28000.00
0005435299826	9903	Economy	28000.00
0005435373915	9903	Economy	28000.00
0005434823608	9903	Economy	28000.00
0005434823279	9903	Economy	28000.00
0005434823539	9903	Economy	28000.00
0005434824006	9903	Economy	28000.00
0005434558264	9903	Economy	28000.00
0005434823831	9903	Economy	28000.00
0005435373927	9903	Economy	28000.00
0005434823969	9903	Economy	28000.00
0005434823717	9903	Economy	28000.00
0005435373952	9903	Economy	28000.00
0005434823949	9903	Economy	28000.00
0005432823472	9903	Economy	28000.00
0005435373925	9903	Economy	28000.00
0005435373948	9903	Economy	28000.00
0005434823541	9903	Economy	28000.00
0005435373950	9903	Economy	28000.00
0005435373953	9903	Economy	28000.00
0005435386638	9903	Economy	28000.00
0005435373943	9903	Economy	28000.00
0005434824248	9903	Economy	30800.00
0005434831166	9903	Economy	30800.00
0005434823839	9903	Economy	28000.00
0005434823754	9903	Economy	30800.00
0005434823914	9903	Economy	28000.00
0005435373913	9903	Economy	28000.00
0005434823332	9903	Economy	30800.00
0005434664963	9903	Economy	30800.00
0005434824210	9903	Economy	28000.00
0005434824513	9903	Economy	28000.00
0005434823701	9903	Economy	28000.00
0005435150038	9903	Economy	28000.00
0005435373904	9903	Economy	28000.00
0005432823470	9903	Economy	28000.00
0005434823632	9903	Economy	28000.00
0005434824064	9903	Economy	28000.00
0005434824110	9903	Economy	28000.00
0005434828702	9903	Economy	28000.00
0005432396237	9903	Economy	28000.00
0005432203141	9903	Economy	28000.00
0005434828706	9903	Economy	28000.00
0005434824007	9903	Economy	28000.00
0005435373898	9903	Economy	28000.00
0005434824062	9903	Economy	28000.00
0005435373926	9903	Economy	28000.00
0005434823325	9903	Economy	28000.00
0005435373923	9903	Economy	28000.00
0005434824327	9903	Economy	28000.00
0005435373937	9903	Economy	28000.00
0005432396259	9903	Economy	28000.00
0005435373929	9903	Economy	28000.00
0005434823626	9903	Economy	28000.00
0005434823305	9903	Economy	28000.00
0005434823747	9903	Economy	28000.00
0005435373956	9903	Economy	28000.00
0005435373909	9903	Economy	28000.00
0005434823663	9903	Economy	28000.00
0005434823469	9903	Economy	28000.00
0005434831156	9903	Economy	28000.00
0005435373911	9903	Economy	28000.00
0005435373945	9903	Economy	28000.00
0005435302245	9903	Economy	28000.00
0005432396242	9903	Economy	28000.00
0005435735183	9903	Economy	28000.00
0005434823721	9903	Economy	28000.00
0005435373916	9903	Economy	28000.00
0005435373900	9903	Economy	28000.00
0005435373899	9903	Economy	28000.00
0005435373946	9903	Economy	28000.00
0005435373924	9903	Economy	28000.00
0005434823702	9903	Economy	28000.00
0005435735188	9903	Economy	28000.00
0005434823716	9903	Economy	28000.00
0005434831135	9903	Economy	28000.00
0005434823664	9903	Economy	28000.00
0005435373908	9903	Economy	28000.00
0005434824394	9903	Economy	28000.00
0005435373902	9903	Economy	28000.00
0005434823753	9903	Economy	28000.00
0005434823715	9903	Economy	28000.00
0005435373954	9903	Economy	28000.00
0005434828703	9903	Economy	28000.00
0005435373942	9903	Economy	28000.00
0005434831171	9903	Economy	28000.00
0005432823471	9903	Economy	28000.00
0005434831140	9903	Economy	28000.00
0005435373907	9903	Economy	28000.00
0005435373928	9903	Economy	28000.00
0005435386642	9903	Economy	28000.00
0005434824070	9903	Economy	28000.00
0005434824296	9903	Economy	28000.00
0005434824089	9903	Economy	28000.00
0005434824113	9903	Economy	28000.00
0005435373930	9903	Economy	28000.00
0005435150005	9903	Economy	28000.00
0005434823566	9903	Economy	28000.00
0005435149966	9903	Economy	28000.00
0005434823324	9903	Economy	28000.00
0005434823657	9903	Economy	28000.00
0005434824298	9903	Economy	28000.00
0005434828705	9903	Economy	28000.00
0005434831134	9903	Economy	30800.00
0005434823851	9903	Economy	30800.00
0005434823935	9903	Economy	30800.00
0005434824035	9903	Economy	30800.00
0005434823818	9903	Economy	30800.00
0005435386637	9903	Economy	28000.00
0005435373936	9903	Economy	28000.00
0005434823901	9903	Economy	28000.00
0005435373917	9903	Economy	28000.00
0005435735184	9903	Economy	28000.00
0005432203139	9903	Economy	28000.00
0005434823622	9903	Economy	28000.00
0005435373934	9903	Economy	28000.00
0005435302248	9903	Economy	28000.00
0005434823722	9903	Economy	28000.00
0005434823782	9903	Economy	28000.00
0005434823714	9903	Economy	28000.00
0005435735186	9903	Economy	28000.00
0005434831139	9903	Economy	28000.00
0005434823868	9903	Economy	28000.00
0005434824036	9903	Economy	28000.00
0005432203138	9903	Economy	28000.00
0005435373931	9903	Economy	28000.00
0005434823309	9903	Economy	28000.00
0005435373910	9903	Economy	28000.00
0005434823600	9903	Economy	28000.00
0005434823435	9903	Economy	28000.00
0005435386641	9903	Economy	28000.00
0005435386636	9903	Economy	28000.00
0005434824003	9903	Economy	28000.00
0005434823835	9903	Economy	28000.00
0005434823772	9903	Economy	28000.00
0005434823467	9903	Economy	28000.00
0005432203140	9903	Economy	28000.00
0005435373935	9903	Economy	28000.00
0005434823885	9903	Economy	28000.00
0005434823863	9903	Economy	28000.00
0005434823703	9903	Economy	28000.00
0005434823895	9903	Economy	28000.00
0005434824063	9903	Economy	28000.00
0005434824008	9903	Economy	28000.00
0005434824393	9903	Economy	28000.00
0005434823550	9903	Economy	28000.00
0005435373933	9903	Economy	28000.00
0005435735185	9903	Economy	28000.00
0005435373906	9903	Economy	28000.00
0005434823607	9903	Economy	28000.00
0005434828707	9903	Economy	28000.00
0005435373896	9903	Economy	28000.00
0005435150023	9903	Economy	28000.00
0005434824512	9903	Economy	28000.00
0005435373958	9903	Economy	28000.00
0005434823407	9903	Economy	28000.00
0005435735187	9903	Economy	28000.00
0005434558277	9903	Economy	28000.00
0005434823915	9903	Economy	28000.00
0005435661962	9903	Economy	28000.00
0005435150037	9903	Economy	28000.00
0005435373961	9903	Economy	28000.00
0005434824148	9903	Economy	28000.00
0005434823684	9903	Economy	28000.00
0005434823755	9903	Economy	28000.00
0005435373955	9903	Economy	28000.00
0005434824297	9903	Economy	28000.00
0005432396255	9903	Economy	28000.00
0005434824286	9903	Economy	28000.00
0005434824328	9903	Economy	28000.00
0005435373941	9903	Economy	28000.00
0005434823460	9903	Economy	28000.00
0005434823394	9903	Economy	28000.00
0005434664966	9903	Economy	28000.00
0005434831143	9903	Economy	28000.00
0005434823712	9903	Economy	28000.00
0005434823866	9903	Economy	28000.00
0005435373951	9903	Economy	28000.00
0005435299823	9903	Economy	28000.00
0005435373897	9903	Economy	28000.00
0005434824153	9903	Economy	28000.00
0005434823872	9903	Economy	28000.00
0005435373938	9903	Economy	28000.00
0005434823306	9903	Economy	28000.00
0005435661961	9903	Economy	28000.00
0005435082865	6995	Economy	8200.00
0005435790336	6995	Economy	8200.00
0005435790338	6995	Economy	7400.00
0005435790335	6995	Economy	7400.00
0005435082864	6995	Economy	7400.00
0005435082872	6995	Economy	7400.00
0005435082868	6995	Economy	7400.00
0005435790337	6995	Economy	7400.00
0005435082867	6995	Economy	7400.00
0005435082869	6995	Economy	7400.00
0005435082871	6995	Economy	7400.00
0005435082866	6995	Economy	7400.00
0005435082870	6995	Economy	7400.00
0005435790306	25968	Economy	8200.00
0005435082800	25968	Economy	7400.00
0005435082786	25968	Economy	7400.00
0005435082793	25968	Economy	7400.00
0005435082778	25968	Economy	7400.00
0005435082784	25968	Economy	7400.00
0005435082799	25968	Economy	7400.00
0005435082801	25968	Economy	7400.00
0005435082788	25968	Economy	7400.00
0005435082811	25968	Economy	7400.00
0005435082779	25968	Economy	7400.00
0005435790316	25968	Economy	7400.00
0005435082781	25968	Economy	7400.00
0005435790317	25968	Economy	7400.00
0005435082812	25968	Economy	7400.00
0005434214577	9521	Business	32800.00
0005434214564	9521	Business	32800.00
0005434214783	9521	Business	32800.00
0005434756840	9521	Business	32800.00
0005434214636	9521	Business	32800.00
0005434214759	9521	Business	32800.00
0005434214447	9521	Business	32800.00
0005434214464	9521	Business	32800.00
0005434756846	9521	Business	32800.00
0005434756857	9521	Business	32800.00
0005434214439	9521	Business	32800.00
0005434214649	9521	Business	32800.00
0005434214542	9521	Economy	10900.00
0005434756861	9521	Economy	10900.00
0005434756842	9521	Economy	10900.00
0005434756880	9521	Economy	10900.00
0005434214583	9521	Economy	10900.00
0005434756863	9521	Economy	10900.00
0005434756853	9521	Economy	10900.00
0005434756869	9521	Economy	10900.00
0005434214538	9521	Economy	10900.00
0005434214438	9521	Economy	10900.00
0005434756855	9521	Economy	12000.00
0005434756847	9521	Economy	12000.00
0005434214635	9521	Economy	12000.00
0005434214755	9521	Economy	12000.00
0005434214575	9521	Economy	12000.00
0005434214363	9521	Economy	10900.00
0005434214526	9521	Economy	10900.00
0005434756877	9521	Economy	10900.00
0005434756850	9521	Economy	10900.00
0005434756858	9521	Economy	10900.00
0005434214756	9521	Economy	10900.00
0005434756859	9521	Economy	10900.00
0005434214711	9521	Economy	10900.00
0005434214614	9521	Economy	10900.00
0005434214567	9521	Economy	10900.00
0005434756871	9521	Economy	10900.00
0005434756865	9521	Economy	10900.00
0005434756872	9521	Economy	10900.00
0005434214525	9521	Economy	10900.00
0005434214760	9521	Economy	10900.00
0005434214619	9521	Economy	10900.00
0005434756844	9521	Economy	10900.00
0005434756875	9521	Economy	10900.00
0005434756873	9521	Economy	10900.00
0005434214782	9521	Economy	10900.00
0005434756867	9521	Economy	10900.00
0005434214338	9521	Economy	10900.00
0005434756864	9521	Economy	10900.00
0005434756868	9521	Economy	10900.00
0005434214490	9521	Economy	10900.00
0005434756854	9521	Economy	10900.00
0005434214411	9521	Economy	10900.00
0005434214516	9521	Economy	10900.00
0005434756848	9521	Economy	10900.00
0005434214574	9521	Economy	10900.00
0005434214576	9521	Economy	10900.00
0005434214611	9521	Economy	10900.00
0005434756849	9521	Economy	10900.00
0005434756876	9521	Economy	10900.00
0005434214468	9521	Economy	10900.00
0005434756841	9521	Economy	10900.00
0005434214498	9521	Economy	10900.00
0005434214685	9521	Economy	10900.00
0005434214527	9521	Economy	10900.00
0005434214440	9521	Economy	10900.00
0005434756852	9521	Economy	10900.00
0005434214616	9521	Economy	10900.00
0005434756851	9521	Economy	10900.00
0005434214508	9521	Economy	10900.00
0005434214509	9521	Economy	10900.00
0005434756866	9521	Economy	10900.00
0005434214412	9521	Economy	10900.00
0005434214618	9521	Economy	10900.00
0005434756874	9521	Economy	10900.00
0005434214615	9521	Economy	10900.00
0005434214463	9521	Economy	10900.00
0005434756860	9521	Economy	10900.00
0005434214524	9521	Economy	10900.00
0005434214638	9521	Economy	10900.00
0005434756879	9521	Economy	10900.00
0005434214466	9521	Economy	10900.00
0005434756856	9521	Economy	10900.00
0005434214758	9521	Economy	10900.00
0005434756843	9521	Economy	10900.00
0005434756845	9521	Economy	10900.00
0005434214346	9521	Economy	10900.00
0005434214781	9521	Economy	10900.00
0005434214623	9521	Economy	10900.00
0005434214569	9521	Economy	10900.00
0005434214568	9521	Economy	10900.00
0005434756878	9521	Economy	10900.00
0005434756862	9521	Economy	10900.00
0005434214757	9521	Economy	10900.00
0005434214446	9521	Economy	10900.00
0005434756870	9521	Economy	10900.00
0005434756488	28622	Business	32800.00
0005434214944	28622	Business	32800.00
0005434756435	28622	Business	32800.00
0005434214943	28622	Business	32800.00
0005434756436	28622	Business	32800.00
0005434756297	28622	Business	32800.00
0005434214975	28622	Business	32800.00
0005434756367	28622	Business	32800.00
0005434756323	28622	Business	32800.00
0005434756427	28622	Business	32800.00
0005434214971	28622	Business	32800.00
0005434756398	28622	Economy	10900.00
0005434756414	28622	Economy	10900.00
0005434214948	28622	Economy	10900.00
0005434214960	28622	Economy	10900.00
0005434214977	28622	Economy	10900.00
0005434214951	28622	Economy	10900.00
0005434756377	28622	Economy	10900.00
0005434756406	28622	Economy	10900.00
0005434214974	28622	Economy	10900.00
0005434214982	28622	Economy	12000.00
0005434214976	28622	Economy	12000.00
0005434214945	28622	Economy	12000.00
0005434756372	28622	Economy	10900.00
0005434756263	28622	Economy	10900.00
0005434214964	28622	Economy	10900.00
0005434756419	28622	Economy	10900.00
0005434756359	28622	Economy	10900.00
0005434214967	28622	Economy	10900.00
0005434214973	28622	Economy	10900.00
0005434756354	28622	Economy	10900.00
0005434756361	28622	Economy	10900.00
0005434756417	28622	Economy	10900.00
0005434756460	28622	Economy	10900.00
0005434214952	28622	Economy	10900.00
0005434756369	28622	Economy	10900.00
0005434214941	28622	Economy	10900.00
0005434214939	28622	Economy	10900.00
0005434756376	28622	Economy	10900.00
0005434214954	28622	Economy	10900.00
0005434214980	28622	Economy	10900.00
0005434756368	28622	Economy	10900.00
0005434214956	28622	Economy	10900.00
0005434214955	28622	Economy	10900.00
0005434756393	28622	Economy	10900.00
0005434214961	28622	Economy	10900.00
0005434214958	28622	Economy	10900.00
0005434214978	28622	Economy	10900.00
0005434756438	28622	Economy	10900.00
0005434214940	28622	Economy	10900.00
0005434214957	28622	Economy	10900.00
0005434214972	28622	Economy	10900.00
0005434756298	28622	Economy	10900.00
0005434756425	28622	Economy	10900.00
0005434756275	28622	Economy	10900.00
0005434214938	28622	Economy	10900.00
0005434756442	28622	Economy	10900.00
0005434214981	28622	Economy	10900.00
0005434214949	28622	Economy	10900.00
0005434756337	28622	Economy	10900.00
0005434756446	28622	Economy	10900.00
0005434214962	28622	Economy	10900.00
0005434756371	28622	Economy	10900.00
0005434214950	28622	Economy	10900.00
0005434214946	28622	Economy	10900.00
0005434214965	28622	Economy	10900.00
0005434756399	28622	Economy	10900.00
0005434756418	28622	Economy	10900.00
0005434756274	28622	Economy	10900.00
0005434214963	28622	Economy	10900.00
0005434214942	28622	Economy	10900.00
0005434214959	28622	Economy	10900.00
0005434214970	28622	Economy	10900.00
0005434214953	28622	Economy	10900.00
0005434214966	28622	Economy	10900.00
0005434756426	28622	Economy	10900.00
0005434756329	28622	Economy	10900.00
0005434756405	28622	Economy	10900.00
0005434214968	28622	Economy	10900.00
0005434756437	28622	Economy	10900.00
0005434214969	28622	Economy	10900.00
0005434214979	28622	Economy	10900.00
0005434214947	28622	Economy	10900.00
0005435100153	10861	Economy	8900.00
0005435100154	10861	Economy	8900.00
0005435100152	10861	Economy	8900.00
0005435100143	31835	Economy	8900.00
0005435100141	31835	Economy	8900.00
0005434760222	31835	Economy	8900.00
0005435100144	31835	Economy	8900.00
0005435100142	31835	Economy	8900.00
0005435100140	31835	Economy	8900.00
0005434760223	31835	Economy	8900.00
0005435100128	31835	Economy	8900.00
0005434760221	31835	Economy	8900.00
0005434639582	2012	Economy	20900.00
0005434639573	2012	Economy	20900.00
0005434639584	2012	Economy	20900.00
0005433202357	2012	Economy	20900.00
0005434639575	2012	Economy	19000.00
0005434639578	2012	Economy	19000.00
0005432290664	2012	Economy	19000.00
0005433202349	2012	Economy	19000.00
0005434639593	2012	Economy	19000.00
0005434639577	2012	Economy	19000.00
0005433202419	2012	Economy	19000.00
0005434639587	2012	Economy	19000.00
0005433202342	2012	Economy	19000.00
0005434639592	2012	Economy	19000.00
0005432290665	2012	Economy	19000.00
0005433202332	2012	Economy	19000.00
0005434639589	2012	Economy	19000.00
0005434639595	2012	Economy	19000.00
0005434639594	2012	Economy	19000.00
0005434639583	2012	Economy	19000.00
0005433202323	2012	Economy	19000.00
0005434639585	2012	Economy	19000.00
0005434639597	2012	Economy	19000.00
0005432290666	2012	Economy	19000.00
0005434639596	2012	Economy	19000.00
0005433202407	2012	Economy	19000.00
0005434639580	2012	Economy	19000.00
0005433202317	2012	Economy	19000.00
0005434639598	2012	Economy	19000.00
0005433202386	2012	Economy	19000.00
0005434639588	2012	Economy	19000.00
0005433202316	2012	Economy	19000.00
0005434639586	2012	Economy	19000.00
0005434639576	2012	Economy	19000.00
0005434639574	2012	Economy	19000.00
0005434639591	2012	Economy	19000.00
0005434639581	2012	Economy	19000.00
0005434639590	2012	Economy	19000.00
0005434639579	2012	Economy	19000.00
0005433202408	2012	Economy	19000.00
0005433202499	23301	Economy	20900.00
0005434639340	23301	Economy	20900.00
0005434639350	23301	Economy	19000.00
0005433202508	23301	Economy	19000.00
0005434639484	23301	Economy	19000.00
0005433202494	23301	Economy	19000.00
0005433202495	23301	Economy	19000.00
0005434639335	23301	Economy	19000.00
0005434639229	23301	Economy	19000.00
0005433202501	23301	Economy	19000.00
0005434639369	23301	Economy	19000.00
0005434639193	23301	Economy	19000.00
0005434639325	23301	Economy	19000.00
0005433202497	23301	Economy	19000.00
0005433202505	23301	Economy	19000.00
0005435948327	23301	Economy	19000.00
0005434639302	23301	Economy	19000.00
0005434639262	23301	Economy	19000.00
0005434639413	23301	Economy	19000.00
0005434639270	23301	Economy	19000.00
0005433202496	23301	Economy	19000.00
0005433202502	23301	Economy	19000.00
0005433202506	23301	Economy	19000.00
0005434639194	23301	Economy	19000.00
0005434639329	23301	Economy	19000.00
0005434639269	23301	Economy	19000.00
0005434639355	23301	Economy	19000.00
0005434639485	23301	Economy	19000.00
0005435948328	23301	Economy	19000.00
0005433202503	23301	Economy	19000.00
0005434639349	23301	Economy	19000.00
0005434639333	23301	Economy	19000.00
0005433202504	23301	Economy	19000.00
0005434639372	23301	Economy	19000.00
0005433202498	23301	Economy	19000.00
0005434639330	23301	Economy	19000.00
0005434639464	23301	Economy	19000.00
0005434639412	23301	Economy	19000.00
0005434639326	23301	Economy	19000.00
0005434639356	23301	Economy	19000.00
0005433202500	23301	Economy	19000.00
0005433202507	23301	Economy	19000.00
0005435326821	6056	Business	69700.00
0005434601091	6056	Business	69700.00
0005435326804	6056	Business	69700.00
0005434601093	6056	Business	69700.00
0005434601085	6056	Business	69700.00
0005432111310	6056	Business	69700.00
0005434601074	6056	Economy	23200.00
0005434601080	6056	Economy	23200.00
0005435326795	6056	Economy	23200.00
0005434601098	6056	Economy	23200.00
0005434601094	6056	Economy	23200.00
0005434601078	6056	Economy	23200.00
0005433533347	6056	Economy	23200.00
0005434601083	6056	Economy	25600.00
0005434601079	6056	Economy	25600.00
0005434601086	6056	Economy	23200.00
0005435326764	6056	Economy	23200.00
0005433531332	6056	Economy	23200.00
0005434601084	6056	Economy	23200.00
0005434601088	6056	Economy	23200.00
0005433531334	6056	Economy	23200.00
0005434601081	6056	Economy	23200.00
0005433533346	6056	Economy	23200.00
0005433531331	6056	Economy	23200.00
0005435326800	6056	Economy	23200.00
0005434601095	6056	Economy	23200.00
0005433531333	6056	Economy	23200.00
0005434601096	6056	Economy	23200.00
0005435326765	6056	Economy	23200.00
0005434601082	6056	Economy	23200.00
0005433533348	6056	Economy	23200.00
0005435326803	6056	Economy	23200.00
0005434601089	6056	Economy	23200.00
0005434601097	6056	Economy	23200.00
0005434601077	6056	Economy	23200.00
0005434601071	6056	Economy	23200.00
0005434601092	6056	Economy	23200.00
0005434601072	6056	Economy	23200.00
0005432111309	6056	Economy	23200.00
0005434601090	6056	Economy	23200.00
0005434601087	6056	Economy	23200.00
0005433531335	6056	Economy	23200.00
0005435326744	6056	Economy	23200.00
0005434601075	6056	Economy	23200.00
0005435326769	6056	Economy	23200.00
0005435326822	6056	Economy	23200.00
0005432111311	6056	Economy	23200.00
0005434601073	6056	Economy	23200.00
0005434601099	6056	Economy	23200.00
0005434601076	6056	Economy	23200.00
0005434600898	18598	Business	69700.00
0005435326882	18598	Business	69700.00
0005434600874	18598	Business	69700.00
0005433531295	18598	Business	69700.00
0005435326886	18598	Business	69700.00
0005434600869	18598	Economy	23200.00
0005433527256	18598	Economy	23200.00
0005434600829	18598	Economy	23200.00
0005435326880	18598	Economy	23200.00
0005434600802	18598	Economy	23200.00
0005434600906	18598	Economy	23200.00
0005434600742	18598	Economy	23200.00
0005435326885	18598	Economy	23200.00
0005434600842	18598	Economy	25600.00
0005435326891	18598	Economy	25600.00
0005433531290	18598	Economy	23200.00
0005434600892	18598	Economy	23200.00
0005435326889	18598	Economy	23200.00
0005434600943	18598	Economy	23200.00
0005434600827	18598	Economy	23200.00
0005434600942	18598	Economy	23200.00
0005434600858	18598	Economy	23200.00
0005435326892	18598	Economy	23200.00
0005434600897	18598	Economy	23200.00
0005434600928	18598	Economy	23200.00
0005434600905	18598	Economy	23200.00
0005435326887	18598	Economy	23200.00
0005435326881	18598	Economy	23200.00
0005434600859	18598	Economy	23200.00
0005434600754	18598	Economy	23200.00
0005434600873	18598	Economy	23200.00
0005434600738	18598	Economy	23200.00
0005434600900	18598	Economy	23200.00
0005435326888	18598	Economy	23200.00
0005434600904	18598	Economy	23200.00
0005434600875	18598	Economy	23200.00
0005434600746	18598	Economy	23200.00
0005435326884	18598	Economy	23200.00
0005435326893	18598	Economy	23200.00
0005434600812	18598	Economy	23200.00
0005434600765	18598	Economy	23200.00
0005435326890	18598	Economy	23200.00
0005433531301	18598	Economy	23200.00
0005435326883	18598	Economy	23200.00
0005434600828	18598	Economy	23200.00
0005434600995	18598	Economy	23200.00
0005434551758	10676	Business	9100.00
0005434551727	10676	Business	9100.00
0005433181084	10676	Business	9100.00
0005434554084	10676	Business	9100.00
0005434551741	10676	Business	9100.00
0005434558349	10676	Business	9100.00
0005434551757	10676	Business	9100.00
0005434551726	10676	Business	9100.00
0005434551740	10676	Business	9100.00
0005434551734	10676	Business	9100.00
0005433181191	10676	Business	9100.00
0005434551754	10676	Economy	3000.00
0005434551714	10676	Economy	3000.00
0005433181070	10676	Economy	3000.00
0005434558346	10676	Economy	3000.00
0005434551729	10676	Economy	3000.00
0005433181149	10676	Economy	3000.00
0005434554083	10676	Economy	3000.00
0005434551751	10676	Economy	3000.00
0005433181112	10676	Economy	3000.00
0005434551745	10676	Economy	3000.00
0005434551753	10676	Economy	3300.00
0005434551716	10676	Economy	3300.00
0005433181131	10676	Economy	3300.00
0005434551748	10676	Economy	3300.00
0005434551749	10676	Economy	3300.00
0005434551756	10676	Economy	3000.00
0005433181104	10676	Economy	3000.00
0005434551738	10676	Economy	3000.00
0005433181042	10676	Economy	3000.00
0005434558351	10676	Economy	3000.00
0005433181136	10676	Economy	3000.00
0005433181115	10676	Economy	3000.00
0005434551721	10676	Economy	3000.00
0005434558347	10676	Economy	3000.00
0005434551730	10676	Economy	3000.00
0005434558348	10676	Economy	3000.00
0005433181076	10676	Economy	3000.00
0005434551733	10676	Economy	3000.00
0005434551735	10676	Economy	3000.00
0005434551764	10676	Economy	3000.00
0005434551766	10676	Economy	3000.00
0005434551742	10676	Economy	3000.00
0005434551767	10676	Economy	3000.00
0005434551717	10676	Economy	3000.00
0005434551755	10676	Economy	3000.00
0005434551750	10676	Economy	3000.00
0005434551722	10676	Economy	3000.00
0005434554082	10676	Economy	3000.00
0005434551739	10676	Economy	3000.00
0005434551728	10676	Economy	3000.00
0005434558352	10676	Economy	3000.00
0005433181087	10676	Economy	3000.00
0005434551744	10676	Economy	3000.00
0005434551731	10676	Economy	3000.00
0005433181106	10676	Economy	3000.00
0005433181105	10676	Economy	3000.00
0005434558350	10676	Economy	3000.00
0005434551759	10676	Economy	3000.00
0005433181069	10676	Economy	3000.00
0005434551720	10676	Economy	3000.00
0005434551713	10676	Economy	3000.00
0005434551725	10676	Economy	3000.00
0005433181023	10676	Economy	3000.00
0005434551718	10676	Economy	3000.00
0005434551752	10676	Economy	3000.00
0005434551732	10676	Economy	3000.00
0005433181096	10676	Economy	3000.00
0005434551736	10676	Economy	3000.00
0005434551737	10676	Economy	3000.00
0005434551724	10676	Economy	3000.00
0005433181178	10676	Economy	3000.00
0005433181130	10676	Economy	3000.00
0005434551765	10676	Economy	3000.00
0005434551763	10676	Economy	3000.00
0005434551746	10676	Economy	3000.00
0005433181164	10676	Economy	3000.00
0005433181146	10676	Economy	3000.00
0005434558353	10676	Economy	3000.00
0005434551723	10676	Economy	3000.00
0005433181208	10676	Economy	3000.00
0005433181077	10676	Economy	3000.00
0005434551747	10676	Economy	3000.00
0005433181089	10676	Economy	3000.00
0005433181097	10676	Economy	3000.00
0005433181132	10676	Economy	3000.00
0005433181187	10676	Economy	3000.00
0005433181116	10676	Economy	3000.00
0005434551743	10676	Economy	3000.00
0005434551760	10676	Economy	3000.00
0005434551761	10676	Economy	3000.00
0005434551715	10676	Economy	3000.00
0005434551719	10676	Economy	3000.00
0005434551762	10676	Economy	3000.00
0005433181347	27743	Business	9100.00
0005433181361	27743	Business	9100.00
0005433181364	27743	Business	9100.00
0005433181363	27743	Business	9100.00
0005433181353	27743	Business	9100.00
0005433181362	27743	Business	9100.00
0005433181368	27743	Economy	3000.00
0005433181369	27743	Economy	3300.00
0005433181355	27743	Economy	3000.00
0005433181370	27743	Economy	3000.00
0005433181357	27743	Economy	3000.00
0005433181366	27743	Economy	3000.00
0005433181358	27743	Economy	3000.00
0005433181351	27743	Economy	3000.00
0005433181356	27743	Economy	3000.00
0005433181349	27743	Economy	3000.00
0005433181360	27743	Economy	3000.00
0005433181352	27743	Economy	3000.00
0005433181371	27743	Economy	3000.00
0005433181365	27743	Economy	3000.00
0005433181367	27743	Economy	3000.00
0005433181354	27743	Economy	3000.00
0005433181346	27743	Economy	3000.00
0005433181348	27743	Economy	3000.00
0005433181350	27743	Economy	3000.00
0005433181359	27743	Economy	3000.00
0005434551273	27746	Business	9100.00
0005434558274	27746	Business	9100.00
0005434551099	27746	Business	9100.00
0005434551312	27746	Business	9100.00
0005434551447	27746	Business	9100.00
0005434551200	27746	Business	9100.00
0005434558295	27746	Business	9100.00
0005434558256	27746	Business	9100.00
0005434551526	27746	Business	9100.00
0005434558294	27746	Business	9100.00
0005434558291	27746	Business	9100.00
0005434551322	27746	Business	9100.00
0005434558293	27746	Economy	3000.00
0005434551321	27746	Economy	3000.00
0005434551051	27746	Economy	3000.00
0005434551239	27746	Economy	3000.00
0005434551147	27746	Economy	3000.00
0005434551479	27746	Economy	3000.00
0005434558257	27746	Economy	3300.00
0005434551194	27746	Economy	3300.00
0005434551155	27746	Economy	3300.00
0005434558259	27746	Economy	3000.00
0005434551480	27746	Economy	3000.00
0005434551274	27746	Economy	3000.00
0005434551543	27746	Economy	3000.00
0005434551408	27746	Economy	3000.00
0005434551507	27746	Economy	3000.00
0005434551002	27746	Economy	3000.00
0005434551389	27746	Economy	3000.00
0005434558258	27746	Economy	3000.00
0005434551040	27746	Economy	3000.00
0005434551107	27746	Economy	3000.00
0005434551359	27746	Economy	3000.00
0005434551560	27746	Economy	3000.00
0005434551466	27746	Economy	3000.00
0005434551508	27746	Economy	3000.00
0005434551313	27746	Economy	3000.00
0005434551390	27746	Economy	3000.00
0005434551525	27746	Economy	3000.00
0005434551410	27746	Economy	3000.00
0005434551339	27746	Economy	3000.00
0005434551272	27746	Economy	3000.00
0005434551411	27746	Economy	3000.00
0005434551415	27746	Economy	3000.00
0005434558276	27746	Economy	3000.00
0005434551391	27746	Economy	3000.00
0005434551358	27746	Economy	3000.00
0005434551523	27746	Economy	3000.00
0005434551175	27746	Economy	3000.00
0005434558245	27746	Economy	3000.00
0005434551197	27746	Economy	3000.00
0005434551276	27746	Economy	3000.00
0005434551511	27746	Economy	3000.00
0005434551559	27746	Economy	3000.00
0005434551514	27746	Economy	3000.00
0005434551240	27746	Economy	3000.00
0005434551515	27746	Economy	3000.00
0005434551414	27746	Economy	3000.00
0005434551497	27746	Economy	3000.00
0005434551193	27746	Economy	3000.00
0005434551435	27746	Economy	3000.00
0005434551227	27746	Economy	3000.00
0005434551498	27746	Economy	3000.00
0005434551512	27746	Economy	3000.00
0005434558292	27746	Economy	3000.00
0005434551148	27746	Economy	3000.00
0005434551412	27746	Economy	3000.00
0005434558275	27746	Economy	3000.00
0005434551275	27746	Economy	3000.00
0005434558282	27746	Economy	3000.00
0005435254473	6146	Economy	11700.00
0005435254474	6146	Economy	11700.00
0005433459263	6146	Economy	11700.00
0005435254485	6146	Economy	11700.00
0005435254483	6146	Economy	11700.00
0005433459264	6146	Economy	11700.00
0005435254499	19344	Economy	11700.00
0005435682541	6725	Business	51100.00
0005435437992	6725	Business	51100.00
0005435682530	6725	Business	51100.00
0005435437998	6725	Business	51100.00
0005435682532	6725	Business	51100.00
0005435438005	6725	Business	51100.00
0005435438047	6725	Business	51100.00
0005435438011	6725	Business	51100.00
0005435682525	6725	Business	51100.00
0005432533297	6725	Business	51100.00
0005435438035	6725	Business	51100.00
0005435682539	6725	Economy	17000.00
0005435682537	6725	Economy	17000.00
0005435438044	6725	Economy	17000.00
0005435220312	6725	Economy	17000.00
0005435438045	6725	Economy	17000.00
0005435719571	6725	Economy	17000.00
0005435661960	6725	Economy	17000.00
0005435682550	6725	Economy	18700.00
0005435682524	6725	Economy	18700.00
0005432136219	6725	Economy	18700.00
0005435682521	6725	Economy	18700.00
0005435437984	6725	Economy	17000.00
0005435682548	6725	Economy	17000.00
0005435661959	6725	Economy	17000.00
0005435682554	6725	Economy	17000.00
0005435630996	6725	Economy	17000.00
0005435720142	6725	Economy	17000.00
0005435437987	6725	Economy	17000.00
0005435438069	6725	Economy	17000.00
0005435221517	6725	Economy	17000.00
0005435682535	6725	Economy	17000.00
0005432136220	6725	Economy	17000.00
0005435630994	6725	Economy	17000.00
0005435682553	6725	Economy	17000.00
0005435437997	6725	Economy	17000.00
0005435682558	6725	Economy	17000.00
0005435682526	6725	Economy	17000.00
0005435682559	6725	Economy	17000.00
0005435682531	6725	Economy	17000.00
0005435682533	6725	Economy	17000.00
0005435437939	6725	Economy	17000.00
0005435438078	6725	Economy	17000.00
0005435719570	6725	Economy	17000.00
0005435682529	6725	Economy	17000.00
0005435437951	6725	Economy	17000.00
0005435438068	6725	Economy	17000.00
0005435682544	6725	Economy	17000.00
0005432136221	6725	Economy	17000.00
0005435437941	6725	Economy	17000.00
0005435682560	6725	Economy	17000.00
0005435720143	6725	Economy	17000.00
0005435437995	6725	Economy	17000.00
0005435682556	6725	Economy	17000.00
0005435682540	6725	Economy	17000.00
0005435630995	6725	Economy	17000.00
0005435682545	6725	Economy	17000.00
0005435682534	6725	Economy	17000.00
0005435720141	6725	Economy	17000.00
0005435438088	6725	Economy	17000.00
0005435438010	6725	Economy	17000.00
0005435682552	6725	Economy	17000.00
0005435221518	6725	Economy	17000.00
0005435682546	6725	Economy	17000.00
0005435682523	6725	Economy	17000.00
0005435682543	6725	Economy	17000.00
0005435682538	6725	Economy	17000.00
0005435682551	6725	Economy	17000.00
0005435682555	6725	Economy	17000.00
0005435682547	6725	Economy	17000.00
0005435682536	6725	Economy	17000.00
0005435682542	6725	Economy	17000.00
0005435682528	6725	Economy	17000.00
0005435682527	6725	Economy	17000.00
0005435682557	6725	Economy	17000.00
0005435682549	6725	Economy	17000.00
0005435437973	6725	Economy	17000.00
0005435682522	6725	Economy	17000.00
0005435437965	6725	Economy	17000.00
0005435438065	6725	Economy	17000.00
0005435682154	24599	Business	51100.00
0005435720823	24599	Business	51100.00
0005435682249	24599	Business	51100.00
0005435438185	24599	Business	51100.00
0005435682185	24599	Business	51100.00
0005435661929	24599	Business	51100.00
0005435682094	24599	Business	51100.00
0005435438174	24599	Business	51100.00
0005435682290	24599	Business	51100.00
0005435682063	24599	Business	51100.00
0005435438172	24599	Business	51100.00
0005435682054	24599	Business	51100.00
0005435630953	24599	Economy	17000.00
0005435682273	24599	Economy	17000.00
0005435682047	24599	Economy	17000.00
0005435682393	24599	Economy	17000.00
0005435682032	24599	Economy	17000.00
0005435682162	24599	Economy	17000.00
0005435682075	24599	Economy	17000.00
0005435438184	24599	Economy	17000.00
0005432533320	24599	Economy	17000.00
0005435682256	24599	Economy	18700.00
0005434828726	24599	Economy	18700.00
0005434828725	24599	Economy	18700.00
0005435438175	24599	Economy	18700.00
0005435438187	24599	Economy	17000.00
0005435682320	24599	Economy	17000.00
0005435682289	24599	Economy	17000.00
0005435630968	24599	Economy	17000.00
0005435682181	24599	Economy	17000.00
0005435682361	24599	Economy	17000.00
0005435682174	24599	Economy	17000.00
0005435438179	24599	Economy	17000.00
0005435661915	24599	Economy	17000.00
0005432305775	24599	Economy	17000.00
0005435682071	24599	Economy	17000.00
0005435661930	24599	Economy	17000.00
0005435682053	24599	Economy	17000.00
0005435682281	24599	Economy	17000.00
0005435682175	24599	Economy	17000.00
0005435438181	24599	Economy	17000.00
0005435682101	24599	Economy	17000.00
0005435438178	24599	Economy	17000.00
0005435682445	24599	Economy	17000.00
0005435438171	24599	Economy	17000.00
0005435682298	24599	Economy	17000.00
0005435438168	24599	Economy	17000.00
0005435682207	24599	Economy	17000.00
0005435682186	24599	Economy	17000.00
0005435682206	24599	Economy	17000.00
0005432533321	24599	Economy	17000.00
0005435661916	24599	Economy	17000.00
0005432533322	24599	Economy	17000.00
0005435682107	24599	Economy	17000.00
0005435682172	24599	Economy	17000.00
0005435682200	24599	Economy	17000.00
0005432305774	24599	Economy	17000.00
0005435720822	24599	Economy	17000.00
0005435720824	24599	Economy	17000.00
0005435682250	24599	Economy	17000.00
0005435682285	24599	Economy	17000.00
0005432533323	24599	Economy	17000.00
0005435438183	24599	Economy	17000.00
0005435438186	24599	Economy	17000.00
0005434828727	24599	Economy	17000.00
0005435630954	24599	Economy	17000.00
0005435438170	24599	Economy	17000.00
0005435438180	24599	Economy	17000.00
0005435438166	24599	Economy	17000.00
0005435438176	24599	Economy	17000.00
0005435438177	24599	Economy	17000.00
0005435682180	24599	Economy	17000.00
0005435438169	24599	Economy	17000.00
0005435682295	24599	Economy	17000.00
0005435682192	24599	Economy	17000.00
0005435682072	24599	Economy	17000.00
0005435438173	24599	Economy	17000.00
0005435682171	24599	Economy	17000.00
0005435682163	24599	Economy	17000.00
0005435438167	24599	Economy	17000.00
0005435682319	24599	Economy	17000.00
0005435438182	24599	Economy	17000.00
0005435682272	24599	Economy	17000.00
0005435682064	24599	Economy	17000.00
0005435682208	24599	Economy	17000.00
0005435682230	24599	Economy	17000.00
0005435682112	24599	Economy	17000.00
0005435682394	24599	Economy	17000.00
0005435682156	24599	Economy	17000.00
0005435682297	24599	Economy	17000.00
0005435106011	11539	Business	26400.00
0005435126755	11539	Business	26400.00
0005435126768	11539	Business	26400.00
0005435126763	11539	Business	26400.00
0005435126759	11539	Business	26400.00
0005435126734	11539	Business	26400.00
0005435106013	11539	Economy	8800.00
0005435126758	11539	Economy	8800.00
0005435126739	11539	Economy	8800.00
0005435126740	11539	Economy	8800.00
0005435126732	11539	Economy	8800.00
0005435126770	11539	Economy	8800.00
0005435126746	11539	Economy	8800.00
0005435126769	11539	Economy	8800.00
0005435126748	11539	Economy	9700.00
0005435126737	11539	Economy	9700.00
0005435106012	11539	Economy	9700.00
0005435126751	11539	Economy	8800.00
0005435126733	11539	Economy	8800.00
0005435126742	11539	Economy	8800.00
0005435126765	11539	Economy	8800.00
0005435126745	11539	Economy	8800.00
0005435126756	11539	Economy	8800.00
0005435558096	11539	Economy	8800.00
0005435126750	11539	Economy	8800.00
0005435126754	11539	Economy	8800.00
0005435126738	11539	Economy	8800.00
0005435126747	11539	Economy	8800.00
0005435126736	11539	Economy	8800.00
0005435558091	11539	Economy	8800.00
0005435126767	11539	Economy	8800.00
0005435126743	11539	Economy	8800.00
0005435126757	11539	Economy	8800.00
0005435558093	11539	Economy	8800.00
0005435126753	11539	Economy	8800.00
0005435126735	11539	Economy	8800.00
0005435126761	11539	Economy	8800.00
0005435126752	11539	Economy	8800.00
0005435126760	11539	Economy	8800.00
0005435558092	11539	Economy	8800.00
0005435126762	11539	Economy	8800.00
0005435126744	11539	Economy	8800.00
0005435126764	11539	Economy	8800.00
0005435126749	11539	Economy	8800.00
0005435126766	11539	Economy	8800.00
0005435126741	11539	Economy	8800.00
0005435558095	11539	Economy	8800.00
0005435558090	11539	Economy	8800.00
0005435106007	31892	Business	26400.00
0005435126457	31892	Business	26400.00
0005435105981	31892	Business	26400.00
0005435126473	31892	Business	26400.00
0005435098557	31892	Business	26400.00
0005435126546	31892	Economy	8800.00
0005435558113	31892	Economy	8800.00
0005435126456	31892	Economy	9700.00
0005435098546	31892	Economy	8800.00
0005435126482	31892	Economy	8800.00
0005435126280	31892	Economy	8800.00
0005435126497	31892	Economy	8800.00
0005435126454	31892	Economy	8800.00
0005435558112	31892	Economy	8800.00
0005435105979	31892	Economy	8800.00
0005435126496	31892	Economy	8800.00
0005435126381	31892	Economy	8800.00
0005435098545	31892	Economy	8800.00
0005435126349	31892	Economy	8800.00
0005435105985	31892	Economy	8800.00
0005435558114	31892	Economy	8800.00
0005435126495	31892	Economy	8800.00
0005435126486	31892	Economy	8800.00
0005435126352	31892	Economy	8800.00
0005435126065	31892	Economy	8800.00
0005435126348	31892	Economy	8800.00
0005435126501	31892	Economy	8800.00
0005435126455	31892	Economy	8800.00
0005435126351	31892	Economy	8800.00
0005435126507	31892	Economy	8800.00
0005435126406	31892	Economy	8800.00
0005435126447	31892	Economy	8800.00
0005435126281	31892	Economy	8800.00
0005435126302	31892	Economy	8800.00
0005435126511	31892	Economy	8800.00
0005435126460	31892	Economy	8800.00
0005435105980	31892	Economy	8800.00
0005435126367	31892	Economy	8800.00
0005435126459	31892	Economy	8800.00
0005435126458	31892	Economy	8800.00
0005435126542	31892	Economy	8800.00
0005435126510	31892	Economy	8800.00
0005435126368	31892	Economy	8800.00
0005435126499	31892	Economy	8800.00
0005435732334	13545	Business	36600.00
0005433398559	13545	Business	36600.00
0005433398540	13545	Business	36600.00
0005433398526	13545	Business	36600.00
0005433398527	13545	Business	36600.00
0005433398541	13545	Business	36600.00
0005433398529	13545	Business	36600.00
0005433398542	13545	Business	36600.00
0005435732376	13545	Economy	12200.00
0005433398564	13545	Economy	12200.00
0005433398566	13545	Economy	12200.00
0005435732364	13545	Economy	13400.00
0005433398567	13545	Economy	13400.00
0005435732340	13545	Economy	13400.00
0005435732333	13545	Economy	13400.00
0005433398523	13545	Economy	12200.00
0005433398530	13545	Economy	12200.00
0005433398551	13545	Economy	12200.00
0005435732299	13545	Economy	12200.00
0005433398553	13545	Economy	12200.00
0005433398539	13545	Economy	12200.00
0005433398549	13545	Economy	12200.00
0005433398537	13545	Economy	12200.00
0005433398543	13545	Economy	12200.00
0005433398525	13545	Economy	12200.00
0005433398535	13545	Economy	12200.00
0005433398554	13545	Economy	12200.00
0005433398555	13545	Economy	12200.00
0005435732302	13545	Economy	12200.00
0005433398563	13545	Economy	12200.00
0005433398560	13545	Economy	12200.00
0005435732335	13545	Economy	12200.00
0005433398558	13545	Economy	12200.00
0005433398538	13545	Economy	12200.00
0005433398547	13545	Economy	12200.00
0005433398562	13545	Economy	12200.00
0005433398531	13545	Economy	12200.00
0005433398569	13545	Economy	12200.00
0005435732331	13545	Economy	12200.00
0005433398556	13545	Economy	12200.00
0005433398570	13545	Economy	12200.00
0005435732375	13545	Economy	12200.00
0005433398550	13545	Economy	12200.00
0005435732356	13545	Economy	12200.00
0005433398565	13545	Economy	12200.00
0005433398532	13545	Economy	12200.00
0005435732373	13545	Economy	12200.00
0005433398524	13545	Economy	12200.00
0005433398536	13545	Economy	12200.00
0005435732339	13545	Economy	12200.00
0005433398548	13545	Economy	12200.00
0005435732330	13545	Economy	12200.00
0005433398533	13545	Economy	12200.00
0005433398544	13545	Economy	12200.00
0005433398534	13545	Economy	12200.00
0005435732301	13545	Economy	12200.00
0005433398545	13545	Economy	12200.00
0005433398557	13545	Economy	12200.00
0005435732282	13545	Economy	12200.00
0005433398546	13545	Economy	12200.00
0005435732374	13545	Economy	12200.00
0005433398528	13545	Economy	12200.00
0005433398561	13545	Economy	12200.00
0005433398568	13545	Economy	12200.00
0005433398552	13545	Economy	12200.00
0005435732464	19411	Business	36600.00
0005435732467	19411	Business	36600.00
0005433398083	19411	Business	36600.00
0005433398124	19411	Business	36600.00
0005433398329	19411	Business	36600.00
0005433398114	19411	Business	36600.00
0005433398010	19411	Business	36600.00
0005435732479	19411	Business	36600.00
0005435732472	19411	Business	36600.00
0005433398151	19411	Business	36600.00
0005433397881	19411	Business	36600.00
0005435732461	19411	Economy	12200.00
0005433398135	19411	Economy	12200.00
0005433398195	19411	Economy	12200.00
0005435732469	19411	Economy	12200.00
0005435732462	19411	Economy	12200.00
0005433398121	19411	Economy	12200.00
0005433398243	19411	Economy	13400.00
0005433397835	19411	Economy	13400.00
0005435732466	19411	Economy	13400.00
0005435732481	19411	Economy	12200.00
0005433398110	19411	Economy	12200.00
0005433398184	19411	Economy	12200.00
0005432297304	19411	Economy	12200.00
0005433398190	19411	Economy	12200.00
0005433398169	19411	Economy	12200.00
0005433398211	19411	Economy	12200.00
0005435732465	19411	Economy	12200.00
0005433398134	19411	Economy	12200.00
0005433398183	19411	Economy	12200.00
0005433398120	19411	Economy	12200.00
0005433398126	19411	Economy	12200.00
0005433398136	19411	Economy	12200.00
0005435732475	19411	Economy	12200.00
0005435732476	19411	Economy	12200.00
0005435732471	19411	Economy	12200.00
0005433398038	19411	Economy	12200.00
0005433397994	19411	Economy	12200.00
0005433398026	19411	Economy	12200.00
0005433398244	19411	Economy	12200.00
0005433397991	19411	Economy	12200.00
0005433398082	19411	Economy	12200.00
0005435732478	19411	Economy	12200.00
0005433398210	19411	Economy	12200.00
0005433398175	19411	Economy	12200.00
0005432297305	19411	Economy	12200.00
0005433398196	19411	Economy	12200.00
0005433398109	19411	Economy	12200.00
0005433397986	19411	Economy	12200.00
0005435732480	19411	Economy	12200.00
0005433398260	19411	Economy	12200.00
0005433397905	19411	Economy	12200.00
0005435732477	19411	Economy	12200.00
0005433397830	19411	Economy	12200.00
0005433398219	19411	Economy	12200.00
0005435732473	19411	Economy	12200.00
0005433398125	19411	Economy	12200.00
0005433398005	19411	Economy	12200.00
0005435732463	19411	Economy	12200.00
0005432297303	19411	Economy	12200.00
0005433398127	19411	Economy	12200.00
0005435732474	19411	Economy	12200.00
0005435732468	19411	Economy	12200.00
0005433397992	19411	Economy	12200.00
0005433398188	19411	Economy	12200.00
0005433398157	19411	Economy	12200.00
0005435732470	19411	Economy	12200.00
0005435069075	13142	Business	11300.00
0005435925428	13142	Business	11300.00
0005435068865	13142	Business	11300.00
0005435069050	13142	Business	11300.00
0005435925427	13142	Business	11300.00
0005435069300	13142	Business	11300.00
0005435069279	13142	Business	11300.00
0005435069145	13142	Economy	3800.00
0005435069031	13142	Economy	3800.00
0005435068939	13142	Economy	3800.00
0005435069404	13142	Economy	3800.00
0005435069248	13142	Economy	3800.00
0005435925425	13142	Economy	4100.00
0005435069030	13142	Economy	3800.00
0005435069125	13142	Economy	3800.00
0005435068969	13142	Economy	3800.00
0005435069207	13142	Economy	3800.00
0005435925424	13142	Economy	3800.00
0005435069136	13142	Economy	3800.00
0005435069164	13142	Economy	3800.00
0005435069032	13142	Economy	3800.00
0005435069326	13142	Economy	3800.00
0005435069122	13142	Economy	3800.00
0005435069154	13142	Economy	3800.00
0005435069102	13142	Economy	3800.00
0005435069000	13142	Economy	3800.00
0005435069151	13142	Economy	3800.00
0005435069141	13142	Economy	3800.00
0005435069135	13142	Economy	3800.00
0005435925429	13142	Economy	3800.00
0005435925436	13142	Economy	3800.00
0005435069165	13142	Economy	3800.00
0005435069126	13142	Economy	3800.00
0005435925437	13142	Economy	3800.00
0005435925430	13142	Economy	3800.00
0005435069319	13142	Economy	3800.00
0005435068999	13142	Economy	3800.00
0005435069069	13142	Economy	3800.00
0005435069249	13142	Economy	3800.00
0005435069166	13142	Economy	3800.00
0005435069176	13142	Economy	3800.00
0005435069114	13142	Economy	3800.00
0005435069318	13142	Economy	3800.00
0005435069140	13142	Economy	3800.00
0005435925434	13142	Economy	3800.00
0005435925431	13142	Economy	3800.00
0005435069259	13142	Economy	3800.00
0005435925435	13142	Economy	3800.00
0005435069403	13142	Economy	3800.00
0005435925426	13142	Economy	3800.00
0005435069123	13142	Economy	3800.00
0005435925432	13142	Economy	3800.00
0005435068968	13142	Economy	3800.00
0005435069078	13142	Economy	3800.00
0005435925433	13142	Economy	3800.00
0005435925336	15513	Business	11300.00
0005435069577	15513	Business	11300.00
0005435069537	15513	Business	11300.00
0005435069569	15513	Business	11300.00
0005435069578	15513	Business	11300.00
0005435069542	15513	Business	11300.00
0005435069576	15513	Business	11300.00
0005435925337	15513	Business	11300.00
0005435069570	15513	Economy	3800.00
0005435925328	15513	Economy	3800.00
0005435069547	15513	Economy	3800.00
0005435069566	15513	Economy	3800.00
0005435069585	15513	Economy	3800.00
0005435069543	15513	Economy	3800.00
0005435069538	15513	Economy	3800.00
0005435069581	15513	Economy	4100.00
0005435069555	15513	Economy	4100.00
0005435925300	15513	Economy	4100.00
0005435069550	15513	Economy	4100.00
0005435925302	15513	Economy	3800.00
0005435069556	15513	Economy	3800.00
0005435069586	15513	Economy	3800.00
0005435069572	15513	Economy	3800.00
0005435069539	15513	Economy	3800.00
0005435069546	15513	Economy	3800.00
0005435069563	15513	Economy	3800.00
0005435925283	15513	Economy	3800.00
0005435925272	15513	Economy	3800.00
0005435069575	15513	Economy	3800.00
0005435069583	15513	Economy	3800.00
0005435069558	15513	Economy	3800.00
0005435069551	15513	Economy	3800.00
0005435069553	15513	Economy	3800.00
0005435069559	15513	Economy	3800.00
0005435069561	15513	Economy	3800.00
0005435069548	15513	Economy	3800.00
0005435069541	15513	Economy	3800.00
0005435069557	15513	Economy	3800.00
0005435069567	15513	Economy	3800.00
0005435069564	15513	Economy	3800.00
0005435069545	15513	Economy	3800.00
0005435069587	15513	Economy	3800.00
0005435069574	15513	Economy	3800.00
0005435069580	15513	Economy	3800.00
0005435925279	15513	Economy	3800.00
0005435069540	15513	Economy	3800.00
0005435069568	15513	Economy	3800.00
0005435925282	15513	Economy	3800.00
0005435925278	15513	Economy	3800.00
0005435069579	15513	Economy	3800.00
0005435069552	15513	Economy	3800.00
0005435069584	15513	Economy	3800.00
0005435925301	15513	Economy	3800.00
0005435069565	15513	Economy	3800.00
0005435925284	15513	Economy	3800.00
0005435069582	15513	Economy	3800.00
0005435069554	15513	Economy	3800.00
0005435069573	15513	Economy	3800.00
0005435069571	15513	Economy	3800.00
0005435069544	15513	Economy	3800.00
0005435069588	15513	Economy	3800.00
0005435069560	15513	Economy	3800.00
0005435069562	15513	Economy	3800.00
0005435069549	15513	Economy	3800.00
0005435069536	15513	Economy	3800.00
0005435808323	23180	Economy	27100.00
0005435808310	23180	Economy	27100.00
0005435808320	23180	Economy	27100.00
0005435808334	23180	Economy	27100.00
0005435808330	23180	Economy	24700.00
0005435808308	23180	Economy	24700.00
0005435808315	23180	Economy	24700.00
0005433407551	23180	Economy	24700.00
0005435808316	23180	Economy	24700.00
0005435808311	23180	Economy	24700.00
0005435808325	23180	Economy	24700.00
0005433407567	23180	Economy	24700.00
0005433407536	23180	Economy	24700.00
0005433407546	23180	Economy	24700.00
0005433407559	23180	Economy	24700.00
0005435808332	23180	Economy	24700.00
0005433407568	23180	Economy	24700.00
0005435808331	23180	Economy	24700.00
0005433407540	23180	Economy	24700.00
0005435808324	23180	Economy	24700.00
0005435808306	23180	Economy	24700.00
0005435808314	23180	Economy	24700.00
0005435808326	23180	Economy	24700.00
0005435808319	23180	Economy	24700.00
0005435808312	23180	Economy	24700.00
0005435808313	23180	Economy	24700.00
0005435808307	23180	Economy	24700.00
0005433407539	23180	Economy	24700.00
0005433407554	23180	Economy	24700.00
0005435808333	23180	Economy	24700.00
0005433407552	23180	Economy	24700.00
0005435808328	23180	Economy	24700.00
0005435808335	23180	Economy	24700.00
0005435808321	23180	Economy	24700.00
0005435808327	23180	Economy	24700.00
0005435808317	23180	Economy	24700.00
0005435808336	23180	Economy	24700.00
0005435808322	23180	Economy	24700.00
0005433407545	23180	Economy	24700.00
0005435808305	23180	Economy	24700.00
0005435808329	23180	Economy	24700.00
0005435808318	23180	Economy	24700.00
0005433407560	23180	Economy	24700.00
0005435808309	23180	Economy	24700.00
0005433407535	23180	Economy	24700.00
0005434756447	10730	Business	61300.00
0005434756380	10730	Business	61300.00
0005434756457	10730	Business	61300.00
0005434756276	10730	Business	61300.00
0005434215028	10730	Business	61300.00
0005434756352	10730	Business	61300.00
0005434214995	10730	Business	61300.00
0005434756469	10730	Business	61300.00
0005434756346	10730	Business	61300.00
0005434756535	10730	Business	61300.00
0005434756540	10730	Business	61300.00
0005434215014	10730	Economy	20400.00
0005434215008	10730	Economy	20400.00
0005434756475	10730	Economy	20400.00
0005434756400	10730	Economy	20400.00
0005434215029	10730	Economy	20400.00
0005434756430	10730	Economy	20400.00
0005434215020	10730	Economy	20400.00
0005434215024	10730	Economy	20400.00
0005434215001	10730	Economy	20400.00
0005434756541	10730	Economy	22500.00
0005434756593	10730	Economy	22500.00
0005434215025	10730	Economy	22500.00
0005434215005	10730	Economy	22500.00
0005434215017	10730	Economy	22500.00
0005434215018	10730	Economy	20400.00
0005434215011	10730	Economy	20400.00
0005434215006	10730	Economy	20400.00
0005434756455	10730	Economy	20400.00
0005434756505	10730	Economy	20400.00
0005434756533	10730	Economy	20400.00
0005434756511	10730	Economy	20400.00
0005434214994	10730	Economy	20400.00
0005434756571	10730	Economy	20400.00
0005434756343	10730	Economy	20400.00
0005434756362	10730	Economy	20400.00
0005434756456	10730	Economy	20400.00
0005434756496	10730	Economy	20400.00
0005434215023	10730	Economy	20400.00
0005434215010	10730	Economy	20400.00
0005434756512	10730	Economy	20400.00
0005434214983	10730	Economy	20400.00
0005434214991	10730	Economy	20400.00
0005434214999	10730	Economy	20400.00
0005434215021	10730	Economy	20400.00
0005434756527	10730	Economy	20400.00
0005434215022	10730	Economy	20400.00
0005434214988	10730	Economy	20400.00
0005434756472	10730	Economy	20400.00
0005434215026	10730	Economy	20400.00
0005434756409	10730	Economy	20400.00
0005434214998	10730	Economy	20400.00
0005434214990	10730	Economy	20400.00
0005434756410	10730	Economy	20400.00
0005434756458	10730	Economy	20400.00
0005434215000	10730	Economy	20400.00
0005434214989	10730	Economy	20400.00
0005434756353	10730	Economy	20400.00
0005434214985	10730	Economy	20400.00
0005434756205	10730	Economy	20400.00
0005434215007	10730	Economy	20400.00
0005434214993	10730	Economy	20400.00
0005434756473	10730	Economy	20400.00
0005434215015	10730	Economy	20400.00
0005434756534	10730	Economy	20400.00
0005434756470	10730	Economy	20400.00
0005434214987	10730	Economy	20400.00
0005434215016	10730	Economy	20400.00
0005434215002	10730	Economy	20400.00
0005434756464	10730	Economy	20400.00
0005434756424	10730	Economy	20400.00
0005434214986	10730	Economy	20400.00
0005434215013	10730	Economy	20400.00
0005434215012	10730	Economy	20400.00
0005434214997	10730	Economy	20400.00
0005434215027	10730	Economy	20400.00
0005434756408	10730	Economy	20400.00
0005434214984	10730	Economy	20400.00
0005434215004	10730	Economy	20400.00
0005434756506	10730	Economy	20400.00
0005434215009	10730	Economy	20400.00
0005434756344	10730	Economy	20400.00
0005434215003	10730	Economy	20400.00
0005434214996	10730	Economy	20400.00
0005434756439	10730	Economy	20400.00
0005434756370	10730	Economy	20400.00
0005434756497	10730	Economy	20400.00
0005434215019	10730	Economy	20400.00
0005434214992	10730	Economy	20400.00
0005434756809	28675	Business	61300.00
0005434756808	28675	Business	61300.00
0005434756812	28675	Business	61300.00
0005434214317	28675	Business	61300.00
0005434214606	28675	Business	61300.00
0005434756810	28675	Business	61300.00
0005434756819	28675	Business	61300.00
0005434756829	28675	Business	61300.00
0005434214541	28675	Business	61300.00
0005434214318	28675	Business	61300.00
0005434214488	28675	Business	61300.00
0005434756788	28675	Business	61300.00
0005434214573	28675	Economy	20400.00
0005434756803	28675	Economy	20400.00
0005434214467	28675	Economy	20400.00
0005434214424	28675	Economy	20400.00
0005434756822	28675	Economy	20400.00
0005434756799	28675	Economy	20400.00
0005434214667	28675	Economy	20400.00
0005434214546	28675	Economy	20400.00
0005434756805	28675	Economy	20400.00
0005434214454	28675	Economy	20400.00
0005434756818	28675	Economy	22500.00
0005434214540	28675	Economy	22500.00
0005434214431	28675	Economy	22500.00
0005434214492	28675	Economy	22500.00
0005434756836	28675	Economy	22500.00
0005434214518	28675	Economy	20400.00
0005434756796	28675	Economy	20400.00
0005434756792	28675	Economy	20400.00
0005434756816	28675	Economy	20400.00
0005434756828	28675	Economy	20400.00
0005434756831	28675	Economy	20400.00
0005434214543	28675	Economy	20400.00
0005434214523	28675	Economy	20400.00
0005434756813	28675	Economy	20400.00
0005434756832	28675	Economy	20400.00
0005434214566	28675	Economy	20400.00
0005434756838	28675	Economy	20400.00
0005434756817	28675	Economy	20400.00
0005434214529	28675	Economy	20400.00
0005434214505	28675	Economy	20400.00
0005434756804	28675	Economy	20400.00
0005434756814	28675	Economy	20400.00
0005434214387	28675	Economy	20400.00
0005434214532	28675	Economy	20400.00
0005434214565	28675	Economy	20400.00
0005434214368	28675	Economy	20400.00
0005434214637	28675	Economy	20400.00
0005434214367	28675	Economy	20400.00
0005434214591	28675	Economy	20400.00
0005434756834	28675	Economy	20400.00
0005434214726	28675	Economy	20400.00
0005434756807	28675	Economy	20400.00
0005434214499	28675	Economy	20400.00
0005434756795	28675	Economy	20400.00
0005434756824	28675	Economy	20400.00
0005434214557	28675	Economy	20400.00
0005434756830	28675	Economy	20400.00
0005434756837	28675	Economy	20400.00
0005434214651	28675	Economy	20400.00
0005434756790	28675	Economy	20400.00
0005434214453	28675	Economy	20400.00
0005434756825	28675	Economy	20400.00
0005434214544	28675	Economy	20400.00
0005434214369	28675	Economy	20400.00
0005434756835	28675	Economy	20400.00
0005434756811	28675	Economy	20400.00
0005434756815	28675	Economy	20400.00
0005434756827	28675	Economy	20400.00
0005434214430	28675	Economy	20400.00
0005434756820	28675	Economy	20400.00
0005434756787	28675	Economy	20400.00
0005434756793	28675	Economy	20400.00
0005434756821	28675	Economy	20400.00
0005434756794	28675	Economy	20400.00
0005434756797	28675	Economy	20400.00
0005434214388	28675	Economy	20400.00
0005434214494	28675	Economy	20400.00
0005434756789	28675	Economy	20400.00
0005434756839	28675	Economy	20400.00
0005434756826	28675	Economy	20400.00
0005434214589	28675	Economy	20400.00
0005434756823	28675	Economy	20400.00
0005434756798	28675	Economy	20400.00
0005434214465	28675	Economy	20400.00
0005434214766	28675	Economy	20400.00
0005434756833	28675	Economy	20400.00
0005434756801	28675	Economy	20400.00
0005434756791	28675	Economy	20400.00
0005434756806	28675	Economy	20400.00
0005434756800	28675	Economy	20400.00
0005434756802	28675	Economy	20400.00
0005434214491	28675	Economy	20400.00
0005434229473	5472	Business	29500.00
0005435040447	5472	Business	29500.00
0005435040400	5472	Business	29500.00
0005435040386	5472	Business	29500.00
0005435040391	5472	Business	29500.00
0005434229386	5472	Business	29500.00
0005434229385	5472	Business	29500.00
0005435040427	5472	Business	29500.00
0005435007268	5472	Business	29500.00
0005435042879	5472	Business	29500.00
0005435040395	5472	Business	29500.00
0005435040394	5472	Business	29500.00
0005435040420	5472	Economy	9800.00
0005434229436	5472	Economy	9800.00
0005434229388	5472	Economy	9800.00
0005434229389	5472	Economy	9800.00
0005435040435	5472	Economy	9800.00
0005435040443	5472	Economy	9800.00
0005434229412	5472	Economy	9800.00
0005435040411	5472	Economy	9800.00
0005432125526	5472	Economy	9800.00
0005435007253	5472	Economy	9800.00
0005432125530	5472	Economy	9800.00
0005434229395	5472	Economy	9800.00
0005435040434	5472	Economy	9800.00
0005435040407	5472	Economy	9800.00
0005435040442	5472	Economy	9800.00
0005435040402	5472	Economy	9800.00
0005435040414	5472	Economy	9800.00
0005434229444	5472	Economy	9800.00
0005434229356	5472	Economy	9800.00
0005435007261	5472	Economy	9800.00
0005435007264	5472	Economy	9800.00
0005435040441	5472	Economy	9800.00
0005435007265	5472	Economy	9800.00
0005435040437	5472	Economy	9800.00
0005435040440	5472	Economy	9800.00
0005435007254	5472	Economy	9800.00
0005435040397	5472	Economy	9800.00
0005435040389	5472	Economy	9800.00
0005435040449	5472	Economy	9800.00
0005435042881	5472	Economy	9800.00
0005432125528	5472	Economy	9800.00
0005435042882	5472	Economy	9800.00
0005435040384	5472	Economy	9800.00
0005435040390	5472	Economy	9800.00
0005435007275	5472	Economy	9800.00
0005435007269	5472	Economy	9800.00
0005435040404	5472	Economy	9800.00
0005435040439	5472	Economy	9800.00
0005435040393	5472	Economy	9800.00
0005435007273	5472	Economy	9800.00
0005434229403	5472	Economy	10800.00
0005435007266	5472	Economy	10800.00
0005435040406	5472	Economy	10800.00
0005435007257	5472	Economy	10800.00
0005435042880	5472	Economy	10800.00
0005435007255	5472	Economy	10800.00
0005435007272	5472	Economy	9800.00
0005435007263	5472	Economy	9800.00
0005435040410	5472	Economy	9800.00
0005435007262	5472	Economy	9800.00
0005432125525	5472	Economy	9800.00
0005435040403	5472	Economy	9800.00
0005435040436	5472	Economy	9800.00
0005435040409	5472	Economy	9800.00
0005435040412	5472	Economy	9800.00
0005434229434	5472	Economy	9800.00
0005435007260	5472	Economy	9800.00
0005435040428	5472	Economy	9800.00
0005434229383	5472	Economy	9800.00
0005435040385	5472	Economy	9800.00
0005434229410	5472	Economy	9800.00
0005435040387	5472	Economy	9800.00
0005435040429	5472	Economy	9800.00
0005434229425	5472	Economy	9800.00
0005434229445	5472	Economy	9800.00
0005435007259	5472	Economy	9800.00
0005435040383	5472	Economy	9800.00
0005435040444	5472	Economy	9800.00
0005434229426	5472	Economy	9800.00
0005435042883	5472	Economy	9800.00
0005435007271	5472	Economy	9800.00
0005435040405	5472	Economy	9800.00
0005432125527	5472	Economy	9800.00
0005435040421	5472	Economy	9800.00
0005435040417	5472	Economy	9800.00
0005435007276	5472	Economy	9800.00
0005435007256	5472	Economy	9800.00
0005435007258	5472	Economy	9800.00
0005435040422	5472	Economy	9800.00
0005435040450	5472	Economy	9800.00
0005435040408	5472	Economy	9800.00
0005435040431	5472	Economy	9800.00
0005435040433	5472	Economy	9800.00
0005435040398	5472	Economy	9800.00
0005435040401	5472	Economy	9800.00
0005434229384	5472	Economy	9800.00
0005435040419	5472	Economy	9800.00
0005435040425	5472	Economy	9800.00
0005435040415	5472	Economy	9800.00
0005435040424	5472	Economy	9800.00
0005435040430	5472	Economy	9800.00
0005435007277	5472	Economy	9800.00
0005435040388	5472	Economy	9800.00
0005434229435	5472	Economy	9800.00
0005434229376	5472	Economy	9800.00
0005435040413	5472	Economy	9800.00
0005435040399	5472	Economy	9800.00
0005435040423	5472	Economy	9800.00
0005435040418	5472	Economy	9800.00
0005432125524	5472	Economy	9800.00
0005435040392	5472	Economy	9800.00
0005435040426	5472	Economy	9800.00
0005435040446	5472	Economy	9800.00
0005434229396	5472	Economy	9800.00
0005435040448	5472	Economy	9800.00
0005435007267	5472	Economy	9800.00
0005432125529	5472	Economy	9800.00
0005434229446	5472	Economy	9800.00
0005435040416	5472	Economy	9800.00
0005434229413	5472	Economy	9800.00
0005435007274	5472	Economy	9800.00
0005435007270	5472	Economy	9800.00
0005435040438	5472	Economy	9800.00
0005435040445	5472	Economy	9800.00
0005435040396	5472	Economy	9800.00
0005435040432	5472	Economy	9800.00
0005435039876	12990	Business	29500.00
0005435007083	12990	Business	29500.00
0005435006996	12990	Business	29500.00
0005435039784	12990	Business	29500.00
0005435039373	12990	Business	29500.00
0005435007001	12990	Business	29500.00
0005435007057	12990	Business	29500.00
0005435007092	12990	Business	29500.00
0005435006998	12990	Business	29500.00
0005435039672	12990	Business	29500.00
0005435039925	12990	Business	29500.00
0005435039849	12990	Economy	9800.00
0005435039918	12990	Economy	9800.00
0005434229602	12990	Economy	9800.00
0005434229606	12990	Economy	9800.00
0005435039997	12990	Economy	9800.00
0005435039923	12990	Economy	9800.00
0005435039789	12990	Economy	9800.00
0005435039696	12990	Economy	9800.00
0005435039788	12990	Economy	9800.00
0005435039808	12990	Economy	9800.00
0005435039877	12990	Economy	9800.00
0005434229611	12990	Economy	9800.00
0005435039727	12990	Economy	9800.00
0005435039998	12990	Economy	9800.00
0005434229592	12990	Economy	9800.00
0005435007082	12990	Economy	9800.00
0005434229595	12990	Economy	9800.00
0005435007058	12990	Economy	9800.00
0005434229597	12990	Economy	9800.00
0005434229601	12990	Economy	9800.00
0005435039913	12990	Economy	9800.00
0005435007128	12990	Economy	9800.00
0005434229593	12990	Economy	9800.00
0005435007000	12990	Economy	9800.00
0005435039926	12990	Economy	9800.00
0005435039802	12990	Economy	9800.00
0005434229603	12990	Economy	9800.00
0005435007129	12990	Economy	9800.00
0005435039872	12990	Economy	9800.00
0005435040105	12990	Economy	9800.00
0005435039644	12990	Economy	9800.00
0005435039590	12990	Economy	9800.00
0005434229608	12990	Economy	9800.00
0005435039896	12990	Economy	9800.00
0005435039875	12990	Economy	9800.00
0005435039589	12990	Economy	9800.00
0005435006999	12990	Economy	9800.00
0005435039846	12990	Economy	9800.00
0005432304437	12990	Economy	9800.00
0005435039848	12990	Economy	10800.00
0005435039908	12990	Economy	10800.00
0005435040037	12990	Economy	10800.00
0005435040087	12990	Economy	10800.00
0005435039922	12990	Economy	10800.00
0005435042854	12990	Economy	10800.00
0005435007024	12990	Economy	9800.00
0005435040034	12990	Economy	9800.00
0005435039973	12990	Economy	9800.00
0005435039950	12990	Economy	9800.00
0005435040038	12990	Economy	9800.00
0005435007115	12990	Economy	9800.00
0005434229607	12990	Economy	9800.00
0005435039879	12990	Economy	9800.00
0005435039874	12990	Economy	9800.00
0005435007053	12990	Economy	9800.00
0005434229605	12990	Economy	9800.00
0005435039871	12990	Economy	9800.00
0005434229598	12990	Economy	9800.00
0005434229612	12990	Economy	9800.00
0005435039819	12990	Economy	9800.00
0005435007007	12990	Economy	9800.00
0005435007150	12990	Economy	9800.00
0005434229596	12990	Economy	9800.00
0005435039974	12990	Economy	9800.00
0005435039912	12990	Economy	9800.00
0005435039757	12990	Economy	9800.00
0005432304439	12990	Economy	9800.00
0005435039979	12990	Economy	9800.00
0005435039878	12990	Economy	9800.00
0005435042855	12990	Economy	9800.00
0005435039637	12990	Economy	9800.00
0005435040012	12990	Economy	9800.00
0005435039638	12990	Economy	9800.00
0005435007056	12990	Economy	9800.00
0005435039780	12990	Economy	9800.00
0005435040055	12990	Economy	9800.00
0005435039810	12990	Economy	9800.00
0005434229591	12990	Economy	9800.00
0005435039673	12990	Economy	9800.00
0005435007023	12990	Economy	9800.00
0005435039936	12990	Economy	9800.00
0005435006997	12990	Economy	9800.00
0005435039928	12990	Economy	9800.00
0005435007054	12990	Economy	9800.00
0005435007006	12990	Economy	9800.00
0005432304438	12990	Economy	9800.00
0005435007063	12990	Economy	9800.00
0005434229599	12990	Economy	9800.00
0005435007081	12990	Economy	9800.00
0005435007093	12990	Economy	9800.00
0005435039971	12990	Economy	9800.00
0005435039670	12990	Economy	9800.00
0005434229594	12990	Economy	9800.00
0005435039664	12990	Economy	9800.00
0005435007148	12990	Economy	9800.00
0005435007149	12990	Economy	9800.00
0005435039671	12990	Economy	9800.00
0005435039847	12990	Economy	9800.00
0005435039940	12990	Economy	9800.00
0005435040086	12990	Economy	9800.00
0005435039978	12990	Economy	9800.00
0005435039695	12990	Economy	9800.00
0005435039939	12990	Economy	9800.00
0005435007064	12990	Economy	9800.00
0005435007044	12990	Economy	9800.00
0005435039897	12990	Economy	9800.00
0005435039747	12990	Economy	9800.00
0005435040011	12990	Economy	9800.00
0005434229609	12990	Economy	9800.00
0005434229600	12990	Economy	9800.00
0005435039956	12990	Economy	9800.00
0005435039927	12990	Economy	9800.00
0005434229604	12990	Economy	9800.00
0005435007112	12990	Economy	9800.00
0005435039911	12990	Economy	9800.00
0005435039783	12990	Economy	9800.00
0005434229610	12990	Economy	9800.00
0005435902682	14873	Business	52900.00
0005434426878	14873	Business	52900.00
0005434426898	14873	Business	52900.00
0005434426877	14873	Business	52900.00
0005435554194	14873	Business	52900.00
0005434426894	14873	Business	52900.00
0005434426876	14873	Economy	17600.00
0005432188638	14873	Economy	17600.00
0005434426871	14873	Economy	17600.00
0005434426892	14873	Economy	17600.00
0005435902775	14873	Economy	17600.00
0005435902694	14873	Economy	17600.00
0005435902776	14873	Economy	19400.00
0005434426882	14873	Economy	19400.00
0005434426886	14873	Economy	17600.00
0005435554192	14873	Economy	17600.00
0005435902712	14873	Economy	17600.00
0005434426884	14873	Economy	17600.00
0005434426881	14873	Economy	17600.00
0005435902742	14873	Economy	17600.00
0005435902732	14873	Economy	17600.00
0005434426879	14873	Economy	17600.00
0005435554186	14873	Economy	17600.00
0005434426872	14873	Economy	17600.00
0005435554191	14873	Economy	17600.00
0005434426875	14873	Economy	17600.00
0005434426880	14873	Economy	17600.00
0005432188639	14873	Economy	17600.00
0005434426889	14873	Economy	17600.00
0005435902759	14873	Economy	17600.00
0005435902711	14873	Economy	17600.00
0005435554195	14873	Economy	17600.00
0005435902758	14873	Economy	17600.00
0005434426883	14873	Economy	17600.00
0005435902743	14873	Economy	17600.00
0005434426896	14873	Economy	17600.00
0005434426897	14873	Economy	17600.00
0005434426890	14873	Economy	17600.00
0005434426874	14873	Economy	17600.00
0005432188637	14873	Economy	17600.00
0005435554190	14873	Economy	17600.00
0005434426891	14873	Economy	17600.00
0005434426873	14873	Economy	17600.00
0005434426870	14873	Economy	17600.00
0005435902783	14873	Economy	17600.00
0005434426899	14873	Economy	17600.00
0005434426887	14873	Economy	17600.00
0005435902710	14873	Economy	17600.00
0005435554181	14873	Economy	17600.00
0005434411819	14873	Economy	17600.00
0005434426893	14873	Economy	17600.00
0005434426895	14873	Economy	17600.00
0005435554174	14873	Economy	17600.00
0005434426885	14873	Economy	17600.00
0005435554193	14873	Economy	17600.00
0005434426888	14873	Economy	17600.00
0005435902741	14873	Economy	17600.00
0005435554187	14873	Economy	17600.00
0005434411818	14873	Economy	17600.00
0005434411820	14873	Economy	17600.00
0005435902886	20229	Business	52900.00
0005434426629	20229	Business	52900.00
0005435902883	20229	Business	52900.00
0005435902893	20229	Business	52900.00
0005435902888	20229	Business	52900.00
0005434426597	20229	Economy	17600.00
0005434426728	20229	Economy	17600.00
0005434426574	20229	Economy	17600.00
0005435902881	20229	Economy	17600.00
0005434426757	20229	Economy	19400.00
0005434426756	20229	Economy	19400.00
0005435554238	20229	Economy	19400.00
0005434411779	20229	Economy	17600.00
0005434426718	20229	Economy	17600.00
0005434426680	20229	Economy	17600.00
0005435902891	20229	Economy	17600.00
0005434426670	20229	Economy	17600.00
0005435554236	20229	Economy	17600.00
0005434426667	20229	Economy	17600.00
0005434426641	20229	Economy	17600.00
0005435902894	20229	Economy	17600.00
0005434426628	20229	Economy	17600.00
0005434426596	20229	Economy	17600.00
0005435902878	20229	Economy	17600.00
0005435902892	20229	Economy	17600.00
0005434426673	20229	Economy	17600.00
0005434426717	20229	Economy	17600.00
0005435902877	20229	Economy	17600.00
0005434426657	20229	Economy	17600.00
0005434426726	20229	Economy	17600.00
0005435902889	20229	Economy	17600.00
0005435902885	20229	Economy	17600.00
0005432059524	20229	Economy	17600.00
0005435554239	20229	Economy	17600.00
0005435554240	20229	Economy	17600.00
0005435902882	20229	Economy	17600.00
0005435902884	20229	Economy	17600.00
0005434426669	20229	Economy	17600.00
0005434426763	20229	Economy	17600.00
0005435902887	20229	Economy	17600.00
0005434411780	20229	Economy	17600.00
0005435554237	20229	Economy	17600.00
0005435902890	20229	Economy	17600.00
0005434426668	20229	Economy	17600.00
0005432059525	20229	Economy	17600.00
0005434426549	20229	Economy	17600.00
0005435902879	20229	Economy	17600.00
0005434426637	20229	Economy	17600.00
0005434426640	20229	Economy	17600.00
0005434426681	20229	Economy	17600.00
0005435902880	20229	Economy	17600.00
0005434411774	20229	Economy	17600.00
0005434523769	28017	Business	106800.00
0005434559094	28017	Business	106800.00
0005432462532	28017	Business	106800.00
0005434559090	28017	Economy	35600.00
0005434559095	28017	Economy	35600.00
0005434523771	28017	Economy	35600.00
0005432462534	28017	Economy	35600.00
0005434523767	28017	Economy	35600.00
0005432462531	28017	Economy	35600.00
0005432462533	28017	Economy	35600.00
0005432462530	28017	Economy	39200.00
0005434559089	28017	Economy	35600.00
0005434559092	28017	Economy	35600.00
0005432462529	28017	Economy	35600.00
0005434523780	28017	Economy	35600.00
0005434523760	28017	Economy	35600.00
0005432462537	28017	Economy	35600.00
0005434523776	28017	Economy	35600.00
0005432462535	28017	Economy	35600.00
0005434523774	28017	Economy	35600.00
0005434523770	28017	Economy	35600.00
0005434523777	28017	Economy	35600.00
0005434559091	28017	Economy	35600.00
0005434523775	28017	Economy	35600.00
0005434523751	28017	Economy	35600.00
0005432462536	28017	Economy	35600.00
0005434559093	28017	Economy	35600.00
0005434523781	28017	Economy	35600.00
0005434559088	28017	Economy	35600.00
0005434523799	30896	Business	106800.00
0005434523795	30896	Business	106800.00
0005434559100	30896	Economy	35600.00
0005434523798	30896	Economy	35600.00
0005432462516	30896	Economy	35600.00
0005432462507	30896	Economy	35600.00
0005434559101	30896	Economy	35600.00
0005434559103	30896	Economy	35600.00
0005434523797	30896	Economy	39200.00
0005432462510	30896	Economy	35600.00
0005434523793	30896	Economy	35600.00
0005432462519	30896	Economy	35600.00
0005434523796	30896	Economy	35600.00
0005432462520	30896	Economy	35600.00
0005432462512	30896	Economy	35600.00
0005434559102	30896	Economy	35600.00
0005434523794	30896	Economy	35600.00
0005434523800	30896	Economy	35600.00
0005434559104	30896	Economy	35600.00
0005433726124	30868	Business	91700.00
0005433726121	30868	Business	91700.00
0005433726114	30868	Economy	30600.00
0005433726113	30868	Economy	30600.00
0005433726120	30868	Economy	30600.00
0005433726125	30868	Economy	30600.00
0005433726119	30868	Economy	30600.00
0005433726122	30868	Economy	30600.00
0005433726111	30868	Economy	30600.00
0005433726112	30868	Economy	30600.00
0005433726123	30868	Economy	30600.00
0005433726118	30868	Economy	30600.00
0005433726115	30868	Economy	30600.00
0005433726116	30868	Economy	30600.00
0005433726117	30868	Economy	30600.00
0005433434664	26547	Business	18500.00
0005433434661	26547	Business	18500.00
0005433434598	26547	Business	18500.00
0005435982765	26547	Business	18500.00
0005435982733	26547	Business	18500.00
0005435982738	26547	Business	18500.00
0005435982756	26547	Economy	6200.00
0005433434725	26547	Economy	6200.00
0005435982735	26547	Economy	6200.00
0005435982762	26547	Economy	6200.00
0005435982731	26547	Economy	6200.00
0005433434774	26547	Economy	6200.00
0005435982740	26547	Economy	6200.00
0005433434801	26547	Economy	6200.00
0005435982766	26547	Economy	6800.00
0005435982734	26547	Economy	6800.00
0005435982725	26547	Economy	6800.00
0005433434689	26547	Economy	6200.00
0005433434706	26547	Economy	6200.00
0005435982751	26547	Economy	6200.00
0005435982742	26547	Economy	6200.00
0005435982749	26547	Economy	6200.00
0005435982732	26547	Economy	6200.00
0005435982737	26547	Economy	6200.00
0005435982761	26547	Economy	6200.00
0005432300318	26547	Economy	6200.00
0005435982750	26547	Economy	6200.00
0005435982736	26547	Economy	6200.00
0005433434696	26547	Economy	6200.00
0005435982724	26547	Economy	6200.00
0005432300317	26547	Economy	6200.00
0005435982729	26547	Economy	6200.00
0005432300316	26547	Economy	6200.00
0005435982741	26547	Economy	6200.00
0005435982723	26547	Economy	6200.00
0005435982747	26547	Economy	6200.00
0005435982727	26547	Economy	6200.00
0005433434628	26547	Economy	6200.00
0005433434780	26547	Economy	6200.00
0005435982743	26547	Economy	6200.00
0005433434627	26547	Economy	6200.00
0005435982760	26547	Economy	6200.00
0005433434676	26547	Economy	6200.00
0005432300319	26547	Economy	6200.00
0005433434548	26547	Economy	6200.00
0005433434726	26547	Economy	6200.00
0005435982721	26547	Economy	6200.00
0005435982730	26547	Economy	6200.00
0005435982746	26547	Economy	6200.00
0005435982757	26547	Economy	6200.00
0005435982745	26547	Economy	6200.00
0005435982726	26547	Economy	6200.00
0005433434769	26547	Economy	6200.00
0005432300320	26547	Economy	6200.00
0005435982753	26547	Economy	6200.00
0005435982755	26547	Economy	6200.00
0005435982752	26547	Economy	6200.00
0005435982719	26547	Economy	6200.00
0005433434646	26547	Economy	6200.00
0005435982764	26547	Economy	6200.00
0005435982744	26547	Economy	6200.00
0005435982722	26547	Economy	6200.00
0005435982717	26547	Economy	6200.00
0005435982720	26547	Economy	6200.00
0005435982758	26547	Economy	6200.00
0005435982728	26547	Economy	6200.00
0005435982718	26547	Economy	6200.00
0005435982748	26547	Economy	6200.00
0005433434712	26547	Economy	6200.00
0005433434785	26547	Economy	6200.00
0005435982739	26547	Economy	6200.00
0005435982759	26547	Economy	6200.00
0005433434720	26547	Economy	6200.00
0005435982763	26547	Economy	6200.00
0005435982754	26547	Economy	6200.00
0005433434964	26731	Business	18500.00
0005433434966	26731	Business	18500.00
0005432051160	26731	Business	18500.00
0005433434958	26731	Business	18500.00
0005433434967	26731	Business	18500.00
0005435982463	26731	Business	18500.00
0005433434962	26731	Business	18500.00
0005435982423	26731	Business	18500.00
0005435982336	26731	Business	18500.00
0005433434961	26731	Business	18500.00
0005434271333	26731	Economy	6200.00
0005433434970	26731	Economy	6200.00
0005435982062	26731	Economy	6200.00
0005435982399	26731	Economy	6200.00
0005433434969	26731	Economy	6200.00
0005435982338	26731	Economy	6200.00
0005433434984	26731	Economy	6200.00
0005433434968	26731	Economy	6200.00
0005435982475	26731	Economy	6200.00
0005435982440	26731	Economy	6800.00
0005435982313	26731	Economy	6800.00
0005435982396	26731	Economy	6800.00
0005433434979	26731	Economy	6200.00
0005435982334	26731	Economy	6200.00
0005435982198	26731	Economy	6200.00
0005433434973	26731	Economy	6200.00
0005433434971	26731	Economy	6200.00
0005435982364	26731	Economy	6200.00
0005435982337	26731	Economy	6200.00
0005433434975	26731	Economy	6200.00
0005435982387	26731	Economy	6200.00
0005435982605	26731	Economy	6200.00
0005435982151	26731	Economy	6200.00
0005435982274	26731	Economy	6200.00
0005435982241	26731	Economy	6200.00
0005435982561	26731	Economy	6200.00
0005432051159	26731	Economy	6200.00
0005434270228	26731	Economy	6200.00
0005435982388	26731	Economy	6200.00
0005435982479	26731	Economy	6200.00
0005435982233	26731	Economy	6200.00
0005433434985	26731	Economy	6200.00
0005435982232	26731	Economy	6200.00
0005435982322	26731	Economy	6200.00
0005433434980	26731	Economy	6200.00
0005433434983	26731	Economy	6200.00
0005435982459	26731	Economy	6200.00
0005435982460	26731	Economy	6200.00
0005435982404	26731	Economy	6200.00
0005433434978	26731	Economy	6200.00
0005432051161	26731	Economy	6200.00
0005434270227	26731	Economy	6200.00
0005433434982	26731	Economy	6200.00
0005434271334	26731	Economy	6200.00
0005435982239	26731	Economy	6200.00
0005433434965	26731	Economy	6200.00
0005433434959	26731	Economy	6200.00
0005435982155	26731	Economy	6200.00
0005435982320	26731	Economy	6200.00
0005435982323	26731	Economy	6200.00
0005435982458	26731	Economy	6200.00
0005433434963	26731	Economy	6200.00
0005435982517	26731	Economy	6200.00
0005433434960	26731	Economy	6200.00
0005434269125	26731	Economy	6200.00
0005433434972	26731	Economy	6200.00
0005435982560	26731	Economy	6200.00
0005435982287	26731	Economy	6200.00
0005435982562	26731	Economy	6200.00
0005435982395	26731	Economy	6200.00
0005435982227	26731	Economy	6200.00
0005435982061	26731	Economy	6200.00
0005433434981	26731	Economy	6200.00
0005435982226	26731	Economy	6200.00
0005435982340	26731	Economy	6200.00
0005435982063	26731	Economy	6200.00
0005435982474	26731	Economy	6200.00
0005433434974	26731	Economy	6200.00
0005433434977	26731	Economy	6200.00
0005433434976	26731	Economy	6200.00
0005435982371	26731	Economy	6200.00
0005433686623	29273	Economy	21000.00
0005433686640	29273	Economy	19100.00
0005433689916	29273	Economy	19100.00
0005433689911	29273	Economy	19100.00
0005433686642	29273	Economy	19100.00
0005433689908	29273	Economy	19100.00
0005433689917	29273	Economy	19100.00
0005433686641	29273	Economy	19100.00
0005433686639	29273	Economy	19100.00
0005433689918	29273	Economy	19100.00
0005433689924	29273	Economy	19100.00
0005433686620	29273	Economy	19100.00
0005433689913	29273	Economy	19100.00
0005433689915	29273	Economy	19100.00
0005433686624	29273	Economy	19100.00
0005433686631	29273	Economy	19100.00
0005433689901	29273	Economy	19100.00
0005433689907	29273	Economy	19100.00
0005433689912	29273	Economy	19100.00
0005433686632	29273	Economy	19100.00
0005433689906	29273	Economy	19100.00
0005433689914	29273	Economy	19100.00
0005433686619	29273	Economy	19100.00
0005432858122	3174	Economy	11100.00
0005432584282	3174	Economy	11100.00
0005432584301	3174	Economy	11100.00
0005432584299	3174	Economy	10100.00
0005432858027	3174	Economy	10100.00
0005432584287	3174	Economy	10100.00
0005432858065	3174	Economy	10100.00
0005432858029	3174	Economy	10100.00
0005432584283	3174	Economy	10100.00
0005432858026	3174	Economy	10100.00
0005432858137	3174	Economy	10100.00
0005432216300	3174	Economy	10100.00
0005432584279	3174	Economy	10100.00
0005432584286	3174	Economy	10100.00
0005432584292	3174	Economy	10100.00
0005432858057	3174	Economy	10100.00
0005432584291	3174	Economy	10100.00
0005432584288	3174	Economy	10100.00
0005432584281	3174	Economy	10100.00
0005432584300	3174	Economy	10100.00
0005432584298	3174	Economy	10100.00
0005432858047	3174	Economy	10100.00
0005432858128	3174	Economy	10100.00
0005432584290	3174	Economy	10100.00
0005432584305	3174	Economy	10100.00
0005432584304	3174	Economy	10100.00
0005432858136	3174	Economy	10100.00
0005432584285	3174	Economy	10100.00
0005432858040	3174	Economy	10100.00
0005432584289	3174	Economy	10100.00
0005432584280	3174	Economy	10100.00
0005432584296	3174	Economy	10100.00
0005432584284	3174	Economy	10100.00
0005432584303	3174	Economy	10100.00
0005432584297	3174	Economy	10100.00
0005432584293	3174	Economy	10100.00
0005432584295	3174	Economy	10100.00
0005432858079	3174	Economy	10100.00
0005432216301	3174	Economy	10100.00
0005432584302	3174	Economy	10100.00
0005432858058	3174	Economy	10100.00
0005432216299	3174	Economy	10100.00
0005432858028	3174	Economy	10100.00
0005432584294	3174	Economy	10100.00
0005432858189	31478	Economy	11100.00
0005432858186	31478	Economy	11100.00
0005432584104	31478	Economy	10100.00
0005432584135	31478	Economy	10100.00
0005432584154	31478	Economy	10100.00
0005432583977	31478	Economy	10100.00
0005432858193	31478	Economy	10100.00
0005432858190	31478	Economy	10100.00
0005432584086	31478	Economy	10100.00
0005432858196	31478	Economy	10100.00
0005432583978	31478	Economy	10100.00
0005432584134	31478	Economy	10100.00
0005432584172	31478	Economy	10100.00
0005432583969	31478	Economy	10100.00
0005432584224	31478	Economy	10100.00
0005432858185	31478	Economy	10100.00
0005432584144	31478	Economy	10100.00
0005432584210	31478	Economy	10100.00
0005432858194	31478	Economy	10100.00
0005432858187	31478	Economy	10100.00
0005432858188	31478	Economy	10100.00
0005432584119	31478	Economy	10100.00
0005432858192	31478	Economy	10100.00
0005432584202	31478	Economy	10100.00
0005432584123	31478	Economy	10100.00
0005432584105	31478	Economy	10100.00
0005432858195	31478	Economy	10100.00
0005432858191	31478	Economy	10100.00
0005432584155	31478	Economy	10100.00
0005434943443	889	Economy	8300.00
0005434943445	889	Economy	8300.00
0005433255126	889	Economy	7500.00
0005434943444	889	Economy	7500.00
0005433255116	889	Economy	7500.00
0005433255118	889	Economy	7500.00
0005434943442	889	Economy	7500.00
0005434943446	889	Economy	7500.00
0005433255119	889	Economy	7500.00
0005433255132	889	Economy	7500.00
0005433255117	889	Economy	7500.00
0005434943441	889	Economy	7500.00
0005434943447	889	Economy	7500.00
0005433255136	889	Economy	7500.00
0005434943449	889	Economy	7500.00
0005434943448	889	Economy	7500.00
0005433255122	889	Economy	7500.00
0005433255137	889	Economy	7500.00
0005434943358	16235	Economy	8300.00
0005433255174	16235	Economy	8300.00
0005433255176	16235	Economy	7500.00
0005433255175	16235	Economy	7500.00
0005433255172	16235	Economy	7500.00
0005434943357	16235	Economy	7500.00
0005434943367	16235	Economy	7500.00
0005434943362	16235	Economy	7500.00
0005433255173	16235	Economy	7500.00
0005435858597	27604	Business	90500.00
0005435858598	27604	Business	90500.00
0005433654775	27604	Business	90500.00
0005435858595	27604	Business	90500.00
0005435858602	27604	Business	90500.00
0005435858599	27604	Business	90500.00
0005433654787	27604	Business	90500.00
0005433654800	27604	Economy	30200.00
0005433654763	27604	Economy	30200.00
0005435858606	27604	Economy	30200.00
0005433654786	27604	Economy	30200.00
0005433654772	27604	Economy	30200.00
0005433654778	27604	Economy	30200.00
0005435858605	27604	Economy	30200.00
0005435858600	27604	Economy	30200.00
0005435858601	27604	Economy	30200.00
0005433654781	27604	Economy	30200.00
0005433654774	27604	Economy	30200.00
0005435858603	27604	Economy	30200.00
0005433654777	27604	Economy	30200.00
0005433654789	27604	Economy	30200.00
0005435858604	27604	Economy	30200.00
0005435858596	27604	Economy	30200.00
0005433654755	27604	Economy	30200.00
0005433654788	27604	Economy	30200.00
0005433654764	27604	Economy	30200.00
0005433654809	27604	Economy	30200.00
0005435858607	27604	Economy	30200.00
0005433654736	27604	Economy	30200.00
0005435653477	21776	Business	9800.00
0005433367877	21776	Business	9800.00
0005433368005	21776	Business	9800.00
0005433367795	21776	Business	9800.00
0005435653463	21776	Business	9800.00
0005433367782	21776	Business	9800.00
0005433367785	21776	Business	9800.00
0005433367890	21776	Business	9800.00
0005433367891	21776	Business	9800.00
0005435653466	21776	Business	9800.00
0005433367888	21776	Business	9800.00
0005433367895	21776	Business	9800.00
0005435653479	21776	Economy	3300.00
0005433367868	21776	Economy	3300.00
0005435653461	21776	Economy	3300.00
0005435653487	21776	Economy	3300.00
0005433367830	21776	Economy	3300.00
0005433368003	21776	Economy	3300.00
0005435653468	21776	Economy	3300.00
0005435653493	21776	Economy	3300.00
0005435653480	21776	Economy	3300.00
0005433367862	21776	Economy	3600.00
0005433368006	21776	Economy	3600.00
0005433368063	21776	Economy	3600.00
0005435653494	21776	Economy	3600.00
0005433367841	21776	Economy	3300.00
0005435653465	21776	Economy	3300.00
0005435653492	21776	Economy	3300.00
0005435653490	21776	Economy	3300.00
0005433367873	21776	Economy	3300.00
0005433367865	21776	Economy	3300.00
0005435653458	21776	Economy	3300.00
0005435653496	21776	Economy	3300.00
0005435653484	21776	Economy	3300.00
0005433367935	21776	Economy	3300.00
0005433367859	21776	Economy	3300.00
0005435653470	21776	Economy	3300.00
0005433367923	21776	Economy	3300.00
0005433367831	21776	Economy	3300.00
0005433368002	21776	Economy	3300.00
0005435653459	21776	Economy	3300.00
0005433367980	21776	Economy	3300.00
0005433367889	21776	Economy	3300.00
0005433367803	21776	Economy	3300.00
0005433367869	21776	Economy	3300.00
0005435653457	21776	Economy	3300.00
0005435653462	21776	Economy	3300.00
0005435653464	21776	Economy	3300.00
0005435653469	21776	Economy	3300.00
0005433367784	21776	Economy	3300.00
0005433367961	21776	Economy	3300.00
0005435653475	21776	Economy	3300.00
0005435653495	21776	Economy	3300.00
0005433367897	21776	Economy	3300.00
0005435653476	21776	Economy	3300.00
0005433367892	21776	Economy	3300.00
0005433367800	21776	Economy	3300.00
0005435653489	21776	Economy	3300.00
0005433367896	21776	Economy	3300.00
0005435653481	21776	Economy	3300.00
0005435653483	21776	Economy	3300.00
0005433367981	21776	Economy	3300.00
0005433367999	21776	Economy	3300.00
0005433367837	21776	Economy	3300.00
0005433368056	21776	Economy	3300.00
0005433367783	21776	Economy	3300.00
0005435653473	21776	Economy	3300.00
0005433367983	21776	Economy	3300.00
0005433367842	21776	Economy	3300.00
0005433367990	21776	Economy	3300.00
0005435653485	21776	Economy	3300.00
0005433367874	21776	Economy	3300.00
0005435653482	21776	Economy	3300.00
0005433368061	21776	Economy	3300.00
0005435653471	21776	Economy	3300.00
0005433367893	21776	Economy	3300.00
0005435653474	21776	Economy	3300.00
0005435653486	21776	Economy	3300.00
0005435653488	21776	Economy	3300.00
0005435653467	21776	Economy	3300.00
0005435653478	21776	Economy	3300.00
0005435653472	21776	Economy	3300.00
0005435653460	21776	Economy	3300.00
0005435653491	21776	Economy	3300.00
0005433367848	21776	Economy	3300.00
0005433367989	21776	Economy	3300.00
0005433785331	9390	Business	186200.00
0005433805750	9390	Business	186200.00
0005433805725	9390	Business	186200.00
0005433805746	9390	Business	186200.00
0005434171113	9390	Business	186200.00
0005433805732	9390	Business	186200.00
0005433785319	9390	Business	186200.00
0005433805749	9390	Business	186200.00
0005433785307	9390	Business	186200.00
0005433805739	9390	Business	186200.00
0005433785318	9390	Business	186200.00
0005433785314	9390	Business	186200.00
0005433805729	9390	Economy	68300.00
0005433785305	9390	Economy	68300.00
0005433785320	9390	Economy	68300.00
0005434270210	9390	Economy	62100.00
0005433805726	9390	Economy	62100.00
0005433785310	9390	Economy	62100.00
0005433785313	9390	Economy	62100.00
0005433805719	9390	Economy	62100.00
0005433805747	9390	Economy	62100.00
0005433805738	9390	Economy	62100.00
0005434171063	9390	Economy	62100.00
0005433763358	9390	Economy	62100.00
0005434171123	9390	Economy	62100.00
0005433805744	9390	Economy	62100.00
0005434171096	9390	Economy	62100.00
0005434171117	9390	Economy	62100.00
0005434171118	9390	Economy	62100.00
0005433805731	9390	Economy	62100.00
0005433785325	9390	Economy	62100.00
0005433785317	9390	Economy	62100.00
0005433785300	9390	Economy	62100.00
0005434171074	9390	Economy	62100.00
0005433785312	9390	Economy	62100.00
0005433785322	9390	Economy	62100.00
0005434151720	9390	Economy	62100.00
0005433785303	9390	Economy	62100.00
0005432667474	9390	Economy	62100.00
0005432657480	9390	Economy	62100.00
0005433785309	9390	Economy	62100.00
0005433785335	9390	Economy	62100.00
0005433763353	9390	Economy	62100.00
0005433805741	9390	Economy	62100.00
0005433763357	9390	Economy	62100.00
0005433785315	9390	Economy	62100.00
0005433805724	9390	Economy	62100.00
0005434270211	9390	Economy	62100.00
0005432657481	9390	Economy	62100.00
0005433763360	9390	Economy	62100.00
0005433763350	9390	Economy	62100.00
0005434171065	9390	Economy	62100.00
0005433785324	9390	Economy	62100.00
0005433805748	9390	Economy	62100.00
0005433763351	9390	Economy	62100.00
0005433763361	9390	Economy	62100.00
0005433805734	9390	Economy	62100.00
0005434171064	9390	Economy	62100.00
0005433805742	9390	Economy	62100.00
0005432666410	9390	Economy	62100.00
0005434273079	9390	Economy	62100.00
0005434171126	9390	Economy	62100.00
0005433785302	9390	Economy	68300.00
0005433805727	9390	Economy	62100.00
0005432667475	9390	Economy	62100.00
0005434171106	9390	Economy	62100.00
0005433785333	9390	Economy	68300.00
0005433785304	9390	Economy	68300.00
0005433805728	9390	Economy	62100.00
0005433763348	9390	Economy	62100.00
0005433805733	9390	Economy	62100.00
0005433805743	9390	Economy	62100.00
0005433805721	9390	Economy	62100.00
0005433805751	9390	Economy	62100.00
0005432657479	9390	Economy	62100.00
0005433785328	9390	Economy	62100.00
0005433805737	9390	Economy	62100.00
0005433785321	9390	Economy	62100.00
0005433785330	9390	Economy	62100.00
0005433785323	9390	Economy	62100.00
0005432665295	9390	Economy	62100.00
0005434171066	9390	Economy	62100.00
0005433805740	9390	Economy	62100.00
0005433805730	9390	Economy	62100.00
0005433805720	9390	Economy	62100.00
0005434151719	9390	Economy	62100.00
0005433785316	9390	Economy	62100.00
0005433785326	9390	Economy	62100.00
0005433805735	9390	Economy	62100.00
0005432665296	9390	Economy	62100.00
0005433785299	9390	Economy	62100.00
0005434273078	9390	Economy	62100.00
0005432665297	9390	Economy	62100.00
0005433763355	9390	Economy	62100.00
0005433785306	9390	Economy	62100.00
0005433763352	9390	Economy	62100.00
0005433785301	9390	Economy	62100.00
0005433805718	9390	Economy	62100.00
0005434171112	9390	Economy	62100.00
0005434171052	9390	Economy	62100.00
0005433785298	9390	Economy	62100.00
0005433785308	9390	Economy	62100.00
0005433763356	9390	Economy	62100.00
0005433805723	9390	Economy	62100.00
0005433805745	9390	Economy	62100.00
0005433763349	9390	Economy	62100.00
0005433805722	9390	Economy	62100.00
0005433785332	9390	Economy	62100.00
0005433785311	9390	Economy	62100.00
0005433785334	9390	Economy	62100.00
0005433785329	9390	Economy	62100.00
0005433785327	9390	Economy	62100.00
0005433763359	9390	Economy	62100.00
0005433805736	9390	Economy	62100.00
0005433763354	9390	Economy	62100.00
0005434171200	26252	Business	186200.00
0005432657458	26252	Business	186200.00
0005433805443	26252	Business	186200.00
0005433785105	26252	Business	186200.00
0005434171193	26252	Business	186200.00
0005434171199	26252	Business	186200.00
0005434171204	26252	Business	186200.00
0005435269822	26252	Business	186200.00
0005433805483	26252	Business	186200.00
0005433784962	26252	Business	186200.00
0005435269813	26252	Business	186200.00
0005433805354	26252	Business	186200.00
0005433763188	26252	Business	186200.00
0005433784972	26252	Business	186200.00
0005433763266	26252	Business	186200.00
0005432666394	26252	Business	186200.00
0005434270225	26252	Business	186200.00
0005432659701	26252	Business	186200.00
0005433763191	26252	Business	186200.00
0005433784838	26252	Business	186200.00
0005433805504	26252	Business	186200.00
0005432657459	26252	Economy	68300.00
0005434171203	26252	Economy	68300.00
0005433763197	26252	Economy	68300.00
0005433805506	26252	Economy	62100.00
0005433805284	26252	Economy	62100.00
0005433785085	26252	Economy	62100.00
0005434270226	26252	Economy	62100.00
0005433805353	26252	Economy	62100.00
0005433785140	26252	Economy	62100.00
0005434171194	26252	Economy	62100.00
0005433763235	26252	Economy	62100.00
0005434171207	26252	Economy	62100.00
0005435269823	26252	Economy	62100.00
0005433785024	26252	Economy	62100.00
0005433805416	26252	Economy	62100.00
0005433805565	26252	Economy	62100.00
0005434151734	26252	Economy	62100.00
0005433784964	26252	Economy	62100.00
0005434269124	26252	Economy	62100.00
0005433763152	26252	Economy	62100.00
0005434171201	26252	Economy	62100.00
0005433805387	26252	Economy	62100.00
0005434171195	26252	Economy	62100.00
0005433805419	26252	Economy	62100.00
0005433805438	26252	Economy	62100.00
0005433785075	26252	Economy	62100.00
0005433805468	26252	Economy	62100.00
0005433805440	26252	Economy	62100.00
0005433784979	26252	Economy	62100.00
0005433805498	26252	Economy	62100.00
0005434171205	26252	Economy	62100.00
0005433763288	26252	Economy	62100.00
0005433805364	26252	Economy	62100.00
0005433805626	26252	Economy	62100.00
0005434271332	26252	Economy	62100.00
0005433805491	26252	Economy	62100.00
0005433763162	26252	Economy	62100.00
0005433785064	26252	Economy	62100.00
0005433805484	26252	Economy	62100.00
0005433805441	26252	Economy	62100.00
0005433784950	26252	Economy	62100.00
0005432657445	26252	Economy	62100.00
0005433785123	26252	Economy	62100.00
0005433805412	26252	Economy	62100.00
0005433763236	26252	Economy	62100.00
0005435269814	26252	Economy	62100.00
0005433805420	26252	Economy	62100.00
0005432663028	26252	Economy	62100.00
0005433784837	26252	Economy	62100.00
0005433805339	26252	Economy	62100.00
0005434171202	26252	Economy	62100.00
0005433805388	26252	Economy	62100.00
0005433805522	26252	Economy	62100.00
0005433805415	26252	Economy	62100.00
0005433784942	26252	Economy	62100.00
0005433785028	26252	Economy	62100.00
0005434171196	26252	Economy	62100.00
0005435269820	26252	Economy	62100.00
0005433784874	26252	Economy	62100.00
0005434269123	26252	Economy	62100.00
0005435269818	26252	Economy	62100.00
0005435269815	26252	Economy	62100.00
0005433763289	26252	Economy	68300.00
0005434171197	26252	Economy	62100.00
0005435269816	26252	Economy	62100.00
0005433805389	26252	Economy	68300.00
0005433763223	26252	Economy	68300.00
0005433785056	26252	Economy	62100.00
0005432666381	26252	Economy	62100.00
0005433763222	26252	Economy	62100.00
0005434171208	26252	Economy	62100.00
0005433785150	26252	Economy	62100.00
0005432659707	26252	Economy	62100.00
0005433763271	26252	Economy	62100.00
0005433805505	26252	Economy	62100.00
0005433784995	26252	Economy	62100.00
0005433805471	26252	Economy	62100.00
0005433785108	26252	Economy	62100.00
0005433784989	26252	Economy	62100.00
0005434269122	26252	Economy	62100.00
0005432663027	26252	Economy	62100.00
0005433763224	26252	Economy	62100.00
0005433805507	26252	Economy	62100.00
0005433784831	26252	Economy	62100.00
0005433763198	26252	Economy	62100.00
0005433784872	26252	Economy	62100.00
0005433805521	26252	Economy	62100.00
0005433805365	26252	Economy	62100.00
0005434151733	26252	Economy	62100.00
0005433805430	26252	Economy	62100.00
0005433805271	26252	Economy	62100.00
0005433763204	26252	Economy	62100.00
0005433785008	26252	Economy	62100.00
0005433805340	26252	Economy	62100.00
0005433784997	26252	Economy	62100.00
0005433805418	26252	Economy	62100.00
0005432659708	26252	Economy	62100.00
0005433805439	26252	Economy	62100.00
0005433784941	26252	Economy	62100.00
0005433763196	26252	Economy	62100.00
0005433805446	26252	Economy	62100.00
0005435269817	26252	Economy	62100.00
0005434171198	26252	Economy	62100.00
0005433784988	26252	Economy	62100.00
0005434171206	26252	Economy	62100.00
0005433785106	26252	Economy	62100.00
0005434151732	26252	Economy	62100.00
0005433805442	26252	Economy	62100.00
0005433784980	26252	Economy	62100.00
0005435269819	26252	Economy	62100.00
0005433805448	26252	Economy	62100.00
0005433763203	26252	Economy	62100.00
0005435269821	26252	Economy	62100.00
0005432663029	26252	Economy	62100.00
0005433763190	26252	Economy	62100.00
0005433805366	26252	Economy	62100.00
0005433763185	26252	Economy	62100.00
0005434271331	26252	Economy	62100.00
0005433805517	26252	Economy	62100.00
0005433784963	26252	Economy	62100.00
0005433784873	26252	Economy	62100.00
0005435929647	4877	Economy	5900.00
0005435929648	4877	Economy	5900.00
0005435929652	4877	Economy	5300.00
0005435135719	4877	Economy	5300.00
0005435135721	4877	Economy	5300.00
0005435929650	4877	Economy	5300.00
0005435135717	4877	Economy	5300.00
0005435135718	4877	Economy	5300.00
0005435135720	4877	Economy	5300.00
0005435929672	33008	Economy	5300.00
0005435135672	33008	Economy	5300.00
0005435929671	33008	Economy	5300.00
0005435929670	33008	Economy	5300.00
0005435135671	33008	Economy	5300.00
0005435135681	33008	Economy	5300.00
0005434217971	9483	Economy	17900.00
0005434983339	9483	Economy	17900.00
0005434983340	9483	Economy	17900.00
0005434217979	9483	Economy	17900.00
0005434983342	9483	Economy	17900.00
0005434983338	9483	Economy	17900.00
0005434983341	9483	Economy	17900.00
0005434217969	9483	Economy	17900.00
0005434983337	9483	Economy	17900.00
0005434217970	9483	Economy	17900.00
0005434218010	27376	Economy	17900.00
0005434983299	27376	Economy	17900.00
0005434983279	27376	Economy	17900.00
0005434218011	27376	Economy	17900.00
0005434983298	27376	Economy	17900.00
0005434218008	27376	Economy	17900.00
0005434218009	27376	Economy	17900.00
0005434983280	27376	Economy	17900.00
0005434983259	27376	Economy	17900.00
0005433960712	24246	Business	36400.00
0005433960857	24246	Business	36400.00
0005433985968	24246	Business	36400.00
0005433985831	24246	Business	36400.00
0005433960812	24246	Business	36400.00
0005433960716	24246	Business	36400.00
0005433960874	24246	Business	36400.00
0005433960930	24246	Business	36400.00
0005433960934	24246	Business	36400.00
0005433986047	24246	Business	36400.00
0005433986031	24246	Business	36400.00
0005433960699	24246	Business	36400.00
0005433960866	24246	Business	36400.00
0005433960694	24246	Business	36400.00
0005433985868	24246	Business	36400.00
0005433986059	24246	Business	36400.00
0005433960538	24246	Economy	13400.00
0005433985954	24246	Economy	13400.00
0005433986067	24246	Economy	12100.00
0005433960801	24246	Economy	12100.00
0005433986076	24246	Economy	12100.00
0005433960923	24246	Economy	12100.00
0005433960717	24246	Economy	12100.00
0005433985869	24246	Economy	12100.00
0005433985887	24246	Economy	12100.00
0005433960693	24246	Economy	12100.00
0005433985973	24246	Economy	12100.00
0005433960736	24246	Economy	12100.00
0005433960787	24246	Economy	12100.00
0005433960931	24246	Economy	12100.00
0005433960933	24246	Economy	12100.00
0005433960903	24246	Economy	12100.00
0005433960575	24246	Economy	12100.00
0005433960955	24246	Economy	12100.00
0005433986012	24246	Economy	12100.00
0005433960876	24246	Economy	12100.00
0005433985992	24246	Economy	12100.00
0005433960688	24246	Economy	12100.00
0005433960600	24246	Economy	12100.00
0005433960925	24246	Economy	12100.00
0005433985843	24246	Economy	12100.00
0005433986014	24246	Economy	12100.00
0005433960826	24246	Economy	12100.00
0005433960791	24246	Economy	12100.00
0005433985749	24246	Economy	12100.00
0005433986009	24246	Economy	12100.00
0005433960867	24246	Economy	12100.00
0005433985976	24246	Economy	12100.00
0005433985977	24246	Economy	12100.00
0005433960858	24246	Economy	12100.00
0005433960820	24246	Economy	12100.00
0005433986092	24246	Economy	12100.00
0005433985859	24246	Economy	12100.00
0005433985988	24246	Economy	12100.00
0005433960900	24246	Economy	12100.00
0005433960864	24246	Economy	12100.00
0005433960956	24246	Economy	12100.00
0005433960926	24246	Economy	12100.00
0005433960860	24246	Economy	12100.00
0005433985775	24246	Economy	12100.00
0005433960889	24246	Economy	12100.00
0005433985951	24246	Economy	12100.00
0005433960932	24246	Economy	12100.00
0005433960875	24246	Economy	12100.00
0005433960859	24246	Economy	12100.00
0005433986024	24246	Economy	12100.00
0005433985774	24246	Economy	12100.00
0005433986052	24246	Economy	12100.00
0005433986063	24246	Economy	12100.00
0005433986119	24246	Economy	12100.00
0005433986008	24246	Economy	12100.00
0005433960735	24246	Economy	12100.00
0005433960698	24246	Economy	12100.00
0005433986078	24246	Economy	13400.00
0005433960885	24246	Economy	13400.00
0005433986037	24246	Economy	12100.00
0005433960796	24246	Economy	12100.00
0005433985891	24246	Economy	12100.00
0005433960935	24246	Economy	12100.00
0005433960840	24246	Economy	12100.00
0005433986079	24246	Economy	12100.00
0005433985945	24246	Economy	12100.00
0005433985946	24246	Economy	12100.00
0005433960952	24246	Economy	12100.00
0005433985993	24246	Economy	12100.00
0005433960788	24246	Economy	12100.00
0005433960863	24246	Economy	12100.00
0005433960922	24246	Economy	12100.00
0005433986005	24246	Economy	12100.00
0005433986023	24246	Economy	12100.00
0005433985918	24246	Economy	12100.00
0005433986048	24246	Economy	12100.00
0005433985847	24246	Economy	12100.00
0005433960718	24246	Economy	12100.00
0005433985766	24246	Economy	12100.00
0005433960849	24246	Economy	12100.00
0005433985901	24246	Economy	12100.00
0005433986004	24246	Economy	12100.00
0005433986006	24246	Economy	12100.00
0005433985995	24246	Economy	12100.00
0005433960847	24246	Economy	12100.00
0005433960948	24246	Economy	12100.00
0005433986060	24246	Economy	12100.00
0005433960901	24246	Economy	12100.00
0005433985950	24246	Economy	12100.00
0005433985902	24246	Economy	12100.00
0005433986033	24246	Economy	12100.00
0005433986013	24246	Economy	12100.00
0005433986007	24246	Economy	12100.00
0005433986044	24246	Economy	12100.00
0005433960899	24246	Economy	12100.00
0005433960705	24246	Economy	12100.00
0005433986118	24246	Economy	12100.00
0005433960909	24246	Economy	12100.00
0005433985962	24246	Economy	12100.00
0005433985758	24246	Economy	12100.00
0005433960886	24246	Economy	12100.00
0005433986377	25949	Business	36400.00
0005433961394	25949	Business	36400.00
0005433961418	25949	Business	36400.00
0005433961391	25949	Business	36400.00
0005433961416	25949	Business	36400.00
0005433961402	25949	Business	36400.00
0005433986369	25949	Business	36400.00
0005433986365	25949	Business	36400.00
0005433961386	25949	Business	36400.00
0005433986383	25949	Business	36400.00
0005433986403	25949	Business	36400.00
0005433986392	25949	Business	36400.00
0005433961423	25949	Business	36400.00
0005433986361	25949	Economy	12100.00
0005433961406	25949	Economy	12100.00
0005433986373	25949	Economy	12100.00
0005433961427	25949	Economy	12100.00
0005433986390	25949	Economy	12100.00
0005433986375	25949	Economy	12100.00
0005433961412	25949	Economy	12100.00
0005433961413	25949	Economy	12100.00
0005433986397	25949	Economy	12100.00
0005433961395	25949	Economy	12100.00
0005433986400	25949	Economy	12100.00
0005433986389	25949	Economy	12100.00
0005433961409	25949	Economy	12100.00
0005433961399	25949	Economy	12100.00
0005433986370	25949	Economy	12100.00
0005433986394	25949	Economy	12100.00
0005433986358	25949	Economy	12100.00
0005433961411	25949	Economy	12100.00
0005433986393	25949	Economy	12100.00
0005433961420	25949	Economy	12100.00
0005433986364	25949	Economy	12100.00
0005433961397	25949	Economy	12100.00
0005433986356	25949	Economy	12100.00
0005433961387	25949	Economy	12100.00
0005433986362	25949	Economy	12100.00
0005433961419	25949	Economy	12100.00
0005433986372	25949	Economy	12100.00
0005433986401	25949	Economy	12100.00
0005433961398	25949	Economy	12100.00
0005433986363	25949	Economy	12100.00
0005433986387	25949	Economy	12100.00
0005433961400	25949	Economy	12100.00
0005433961426	25949	Economy	12100.00
0005433986374	25949	Economy	12100.00
0005433986379	25949	Economy	12100.00
0005433986386	25949	Economy	12100.00
0005433961404	25949	Economy	12100.00
0005433986395	25949	Economy	12100.00
0005433986367	25949	Economy	12100.00
0005433986368	25949	Economy	12100.00
0005433986357	25949	Economy	13400.00
0005433961428	25949	Economy	12100.00
0005433986391	25949	Economy	12100.00
0005433961392	25949	Economy	13400.00
0005433986405	25949	Economy	13400.00
0005433961415	25949	Economy	12100.00
0005433986384	25949	Economy	12100.00
0005433986360	25949	Economy	12100.00
0005433961385	25949	Economy	12100.00
0005433961388	25949	Economy	12100.00
0005433961403	25949	Economy	12100.00
0005433986402	25949	Economy	12100.00
0005433961390	25949	Economy	12100.00
0005433986399	25949	Economy	12100.00
0005433986381	25949	Economy	12100.00
0005433986382	25949	Economy	12100.00
0005433961410	25949	Economy	12100.00
0005433986359	25949	Economy	12100.00
0005433961407	25949	Economy	12100.00
0005433961417	25949	Economy	12100.00
0005433986396	25949	Economy	12100.00
0005433961396	25949	Economy	12100.00
0005433961408	25949	Economy	12100.00
0005433986380	25949	Economy	12100.00
0005433986371	25949	Economy	12100.00
0005433961393	25949	Economy	12100.00
0005433961414	25949	Economy	12100.00
0005433961389	25949	Economy	12100.00
0005433961424	25949	Economy	12100.00
0005433961425	25949	Economy	12100.00
0005433961421	25949	Economy	12100.00
0005433961422	25949	Economy	12100.00
0005433986398	25949	Economy	12100.00
0005433986404	25949	Economy	12100.00
0005433986366	25949	Economy	12100.00
0005433986388	25949	Economy	12100.00
0005433986385	25949	Economy	12100.00
0005433961401	25949	Economy	12100.00
0005433986378	25949	Economy	12100.00
0005433986376	25949	Economy	12100.00
0005433961405	25949	Economy	12100.00
0005434480579	944	Economy	25400.00
0005434480597	944	Economy	25400.00
0005433165967	944	Economy	23100.00
0005434480577	944	Economy	23100.00
0005434480589	944	Economy	23100.00
0005432269525	944	Economy	23100.00
0005432269524	944	Economy	23100.00
0005433165998	944	Economy	23100.00
0005434480584	944	Economy	23100.00
0005434480581	944	Economy	23100.00
0005434480574	944	Economy	23100.00
0005433165975	944	Economy	23100.00
0005432269523	944	Economy	23100.00
0005434480585	944	Economy	23100.00
0005433165934	944	Economy	23100.00
0005433165966	944	Economy	23100.00
0005434480592	944	Economy	23100.00
0005433165976	944	Economy	23100.00
0005434480598	944	Economy	23100.00
0005433165933	944	Economy	23100.00
0005434480593	944	Economy	23100.00
0005434480576	944	Economy	23100.00
0005434480590	944	Economy	23100.00
0005434480583	944	Economy	23100.00
0005434480575	944	Economy	23100.00
0005434480594	944	Economy	23100.00
0005434480599	944	Economy	23100.00
0005434480580	944	Economy	23100.00
0005434480596	944	Economy	23100.00
0005433165965	944	Economy	23100.00
0005434480582	944	Economy	23100.00
0005434480586	944	Economy	23100.00
0005433165944	944	Economy	23100.00
0005434480591	944	Economy	23100.00
0005434480595	944	Economy	23100.00
0005434480588	944	Economy	23100.00
0005433165970	944	Economy	23100.00
0005434480578	944	Economy	23100.00
0005433165945	944	Economy	23100.00
0005433165963	944	Economy	23100.00
0005434480587	944	Economy	23100.00
0005434480389	16599	Economy	25400.00
0005434480375	16599	Economy	25400.00
0005433166034	16599	Economy	25400.00
0005433166037	16599	Economy	23100.00
0005434480382	16599	Economy	23100.00
0005434480339	16599	Economy	23100.00
0005434480415	16599	Economy	23100.00
0005433166036	16599	Economy	23100.00
0005433166041	16599	Economy	23100.00
0005434480396	16599	Economy	23100.00
0005434480338	16599	Economy	23100.00
0005434480326	16599	Economy	23100.00
0005433166042	16599	Economy	23100.00
0005434480392	16599	Economy	23100.00
0005434480307	16599	Economy	23100.00
0005434480321	16599	Economy	23100.00
0005434480376	16599	Economy	23100.00
0005433166038	16599	Economy	23100.00
0005434480414	16599	Economy	23100.00
0005434480308	16599	Economy	23100.00
0005434480273	16599	Economy	23100.00
0005433166032	16599	Economy	23100.00
0005434480284	16599	Economy	23100.00
0005434480446	16599	Economy	23100.00
0005434480343	16599	Economy	23100.00
0005434480327	16599	Economy	23100.00
0005433166033	16599	Economy	23100.00
0005433166035	16599	Economy	23100.00
0005433166040	16599	Economy	23100.00
0005434480296	16599	Economy	23100.00
0005433166039	16599	Economy	23100.00
0005434480342	16599	Economy	23100.00
0005434480346	16599	Economy	23100.00
0005435150153	10326	Economy	17000.00
0005433289836	10326	Economy	17000.00
0005433289854	10326	Economy	17000.00
0005433289869	10326	Economy	17000.00
0005435150164	10326	Economy	15400.00
0005435142705	10326	Economy	15400.00
0005433289843	10326	Economy	15400.00
0005435142702	10326	Economy	15400.00
0005435142709	10326	Economy	15400.00
0005433289858	10326	Economy	15400.00
0005435150160	10326	Economy	15400.00
0005435150157	10326	Economy	15400.00
0005433289852	10326	Economy	15400.00
0005435142698	10326	Economy	15400.00
0005435150155	10326	Economy	15400.00
0005435150158	10326	Economy	15400.00
0005435150152	10326	Economy	15400.00
0005435150156	10326	Economy	15400.00
0005435142697	10326	Economy	15400.00
0005435150149	10326	Economy	15400.00
0005433289856	10326	Economy	15400.00
0005435142703	10326	Economy	15400.00
0005435142706	10326	Economy	15400.00
0005435142701	10326	Economy	15400.00
0005435142696	10326	Economy	15400.00
0005433289859	10326	Economy	15400.00
0005435142699	10326	Economy	15400.00
0005435142704	10326	Economy	15400.00
0005433289835	10326	Economy	15400.00
0005435142700	10326	Economy	15400.00
0005433289857	10326	Economy	15400.00
0005435142707	10326	Economy	15400.00
0005433289855	10326	Economy	15400.00
0005435142708	10326	Economy	15400.00
0005435150162	10326	Economy	15400.00
0005433289844	10326	Economy	15400.00
0005435150154	10326	Economy	15400.00
0005435150163	10326	Economy	15400.00
0005435150151	10326	Economy	15400.00
0005433289847	10326	Economy	15400.00
0005433289845	10326	Economy	15400.00
0005435150150	10326	Economy	15400.00
0005435150159	10326	Economy	15400.00
0005433289837	10326	Economy	15400.00
0005435150161	10326	Economy	15400.00
0005433289842	10326	Economy	15400.00
0005433289851	10326	Economy	15400.00
0005435142590	21916	Economy	17000.00
0005435142526	21916	Economy	17000.00
0005435386637	21916	Economy	17000.00
0005435386643	21916	Economy	15400.00
0005435142527	21916	Economy	15400.00
0005435142615	21916	Economy	15400.00
0005435142531	21916	Economy	15400.00
0005435149966	21916	Economy	15400.00
0005435142601	21916	Economy	15400.00
0005433289931	21916	Economy	15400.00
0005435386640	21916	Economy	15400.00
0005433289929	21916	Economy	15400.00
0005433289927	21916	Economy	15400.00
0005433289928	21916	Economy	15400.00
0005435142614	21916	Economy	15400.00
0005435386642	21916	Economy	15400.00
0005435150005	21916	Economy	15400.00
0005433289926	21916	Economy	15400.00
0005435386639	21916	Economy	15400.00
0005435386641	21916	Economy	15400.00
0005435150023	21916	Economy	15400.00
0005435386638	21916	Economy	15400.00
0005435150038	21916	Economy	15400.00
0005435142542	21916	Economy	15400.00
0005435150039	21916	Economy	15400.00
0005435142525	21916	Economy	15400.00
0005435150006	21916	Economy	15400.00
0005435142524	21916	Economy	15400.00
0005433289925	21916	Economy	15400.00
0005433289930	21916	Economy	15400.00
0005435142530	21916	Economy	15400.00
0005435386636	21916	Economy	15400.00
0005435142588	21916	Economy	15400.00
0005435142543	21916	Economy	15400.00
0005435150037	21916	Economy	15400.00
0005435142544	21916	Economy	15400.00
0005435529298	11190	Business	57200.00
0005435545742	11190	Business	57200.00
0005434573482	11190	Business	57200.00
0005435319611	11190	Business	57200.00
0005434573488	11190	Business	57200.00
0005435529269	11190	Business	57200.00
0005434573485	11190	Business	57200.00
0005435529267	11190	Business	57200.00
0005435502303	11190	Business	57200.00
0005435529285	11190	Business	57200.00
0005435529343	11190	Economy	19100.00
0005434573490	11190	Economy	19100.00
0005435502385	11190	Economy	19100.00
0005435545739	11190	Economy	19100.00
0005435545762	11190	Economy	19100.00
0005435545738	11190	Economy	19100.00
0005435502382	11190	Economy	19100.00
0005435529241	11190	Economy	19100.00
0005435529240	11190	Economy	19100.00
0005435529268	11190	Economy	21000.00
0005435529293	11190	Economy	21000.00
0005435529332	11190	Economy	21000.00
0005435529292	11190	Economy	21000.00
0005435529207	11190	Economy	19100.00
0005434573486	11190	Economy	19100.00
0005434573480	11190	Economy	19100.00
0005434573487	11190	Economy	19100.00
0005434573489	11190	Economy	19100.00
0005435529188	11190	Economy	19100.00
0005435502348	11190	Economy	19100.00
0005435529341	11190	Economy	19100.00
0005434573477	11190	Economy	19100.00
0005435529295	11190	Economy	19100.00
0005434573479	11190	Economy	19100.00
0005435502418	11190	Economy	19100.00
0005435545741	11190	Economy	19100.00
0005435529261	11190	Economy	19100.00
0005435529294	11190	Economy	19100.00
0005434573478	11190	Economy	19100.00
0005434573491	11190	Economy	19100.00
0005435319601	11190	Economy	19100.00
0005435529346	11190	Economy	19100.00
0005435545763	11190	Economy	19100.00
0005435529321	11190	Economy	19100.00
0005435319599	11190	Economy	19100.00
0005435529302	11190	Economy	19100.00
0005435319600	11190	Economy	19100.00
0005435502375	11190	Economy	19100.00
0005435502304	11190	Economy	19100.00
0005435529260	11190	Economy	19100.00
0005435545764	11190	Economy	19100.00
0005435529348	11190	Economy	19100.00
0005435502361	11190	Economy	19100.00
0005435502398	11190	Economy	19100.00
0005435529275	11190	Economy	19100.00
0005435529355	11190	Economy	19100.00
0005435529299	11190	Economy	19100.00
0005435529394	11190	Economy	19100.00
0005435502347	11190	Economy	19100.00
0005435529333	11190	Economy	19100.00
0005435529208	11190	Economy	19100.00
0005434573484	11190	Economy	19100.00
0005435529276	11190	Economy	19100.00
0005435502279	11190	Economy	19100.00
0005435502381	11190	Economy	19100.00
0005435502376	11190	Economy	19100.00
0005435502399	11190	Economy	19100.00
0005435529253	11190	Economy	19100.00
0005435529242	11190	Economy	19100.00
0005435319612	11190	Economy	19100.00
0005434573481	11190	Economy	19100.00
0005435502321	11190	Economy	19100.00
0005435529245	11190	Economy	19100.00
0005435502280	11190	Economy	19100.00
0005435529238	11190	Economy	19100.00
0005434573483	11190	Economy	19100.00
0005435319591	11190	Economy	19100.00
0005435502323	11190	Economy	19100.00
0005435529345	11190	Economy	19100.00
0005435529284	11190	Economy	19100.00
0005435529342	11190	Economy	19100.00
0005435502419	11190	Economy	19100.00
0005435529278	11190	Economy	19100.00
0005435319572	11190	Economy	19100.00
0005435319668	20909	Business	57200.00
0005435502513	20909	Business	57200.00
0005435518076	20909	Business	57200.00
0005435502510	20909	Business	57200.00
0005435319671	20909	Business	57200.00
0005435518082	20909	Business	57200.00
0005435508467	20909	Business	57200.00
0005435508463	20909	Business	57200.00
0005435502521	20909	Business	57200.00
0005434573379	20909	Economy	19100.00
0005435502527	20909	Economy	19100.00
0005435518087	20909	Economy	19100.00
0005435518074	20909	Economy	19100.00
0005435518084	20909	Economy	19100.00
0005435502514	20909	Economy	19100.00
0005434573351	20909	Economy	21000.00
0005435508464	20909	Economy	21000.00
0005435518088	20909	Economy	21000.00
0005434573296	20909	Economy	21000.00
0005435502509	20909	Economy	19100.00
0005435502523	20909	Economy	19100.00
0005435518080	20909	Economy	19100.00
0005435502517	20909	Economy	19100.00
0005435518075	20909	Economy	19100.00
0005435518086	20909	Economy	19100.00
0005435502525	20909	Economy	19100.00
0005435502528	20909	Economy	19100.00
0005435502512	20909	Economy	19100.00
0005435518085	20909	Economy	19100.00
0005435518083	20909	Economy	19100.00
0005435508469	20909	Economy	19100.00
0005435319676	20909	Economy	19100.00
0005435319670	20909	Economy	19100.00
0005435502516	20909	Economy	19100.00
0005435518093	20909	Economy	19100.00
0005435518081	20909	Economy	19100.00
0005435508468	20909	Economy	19100.00
0005435518073	20909	Economy	19100.00
0005435502522	20909	Economy	19100.00
0005435518092	20909	Economy	19100.00
0005435319669	20909	Economy	19100.00
0005434573371	20909	Economy	19100.00
0005435502524	20909	Economy	19100.00
0005435502511	20909	Economy	19100.00
0005435508466	20909	Economy	19100.00
0005435518089	20909	Economy	19100.00
0005435508472	20909	Economy	19100.00
0005435518090	20909	Economy	19100.00
0005434573370	20909	Economy	19100.00
0005432291953	20909	Economy	19100.00
0005435502529	20909	Economy	19100.00
0005435502515	20909	Economy	19100.00
0005435518079	20909	Economy	19100.00
0005434573375	20909	Economy	19100.00
0005435518077	20909	Economy	19100.00
0005434573387	20909	Economy	19100.00
0005435508471	20909	Economy	19100.00
0005435502508	20909	Economy	19100.00
0005435502518	20909	Economy	19100.00
0005435518078	20909	Economy	19100.00
0005435319673	20909	Economy	19100.00
0005435508465	20909	Economy	19100.00
0005434573386	20909	Economy	19100.00
0005435508470	20909	Economy	19100.00
0005435518091	20909	Economy	19100.00
0005435319675	20909	Economy	19100.00
0005435502520	20909	Economy	19100.00
0005432291952	20909	Economy	19100.00
0005434573324	20909	Economy	19100.00
0005435319674	20909	Economy	19100.00
0005435502519	20909	Economy	19100.00
0005435502526	20909	Economy	19100.00
0005435319672	20909	Economy	19100.00
0005432693098	3039	Business	10300.00
0005432693062	3039	Business	10300.00
0005432693078	3039	Economy	3400.00
0005432693159	3039	Economy	3400.00
0005432693085	3039	Economy	3400.00
0005432693080	3039	Economy	3400.00
0005432693160	3039	Economy	3800.00
0005432693097	3039	Economy	3400.00
0005432693090	3039	Economy	3400.00
0005432693092	3039	Economy	3400.00
0005432692936	3039	Economy	3400.00
0005432693086	3039	Economy	3400.00
0005432693072	3039	Economy	3400.00
0005432693091	3039	Economy	3400.00
0005432693077	3039	Economy	3400.00
0005432693081	3039	Economy	3400.00
0005432692985	3039	Economy	3400.00
0005432693099	3039	Economy	3400.00
0005432693022	3039	Economy	3400.00
0005432693066	3039	Economy	3400.00
0005432693163	3039	Economy	3400.00
0005432693148	3039	Economy	3400.00
0005432693149	3039	Economy	3400.00
0005432707023	2995	Business	10300.00
0005432707021	2995	Business	10300.00
0005432880886	2995	Business	10300.00
0005432707033	2995	Business	10300.00
0005432707027	2995	Business	10300.00
0005433123973	2995	Business	10300.00
0005433123980	2995	Economy	3400.00
0005432707015	2995	Economy	3400.00
0005433123865	2995	Economy	3400.00
0005432880813	2995	Economy	3400.00
0005432707031	2995	Economy	3400.00
0005432217804	2995	Economy	3400.00
0005432880845	2995	Economy	3400.00
0005433124000	2995	Economy	3800.00
0005432880857	2995	Economy	3400.00
0005432707025	2995	Economy	3400.00
0005432707026	2995	Economy	3400.00
0005432880860	2995	Economy	3400.00
0005432707037	2995	Economy	3400.00
0005433194870	2995	Economy	3400.00
0005432707024	2995	Economy	3400.00
0005432707038	2995	Economy	3400.00
0005432880828	2995	Economy	3400.00
0005433123936	2995	Economy	3400.00
0005432707032	2995	Economy	3400.00
0005432707016	2995	Economy	3400.00
0005432707017	2995	Economy	3400.00
0005433123906	2995	Economy	3400.00
0005432707019	2995	Economy	3400.00
0005432707034	2995	Economy	3400.00
0005433123985	2995	Economy	3400.00
0005432707035	2995	Economy	3400.00
0005432707022	2995	Economy	3400.00
0005432707028	2995	Economy	3400.00
0005432707036	2995	Economy	3400.00
0005432880798	2995	Economy	3400.00
0005432707039	2995	Economy	3400.00
0005433123986	2995	Economy	3400.00
0005432707029	2995	Economy	3400.00
0005433123827	2995	Economy	3400.00
0005432707020	2995	Economy	3400.00
0005432707030	2995	Economy	3400.00
0005432217805	2995	Economy	3400.00
0005432707040	2995	Economy	3400.00
0005433123878	2995	Economy	3400.00
0005432707018	2995	Economy	3400.00
0005433123979	2995	Economy	3400.00
0005433123881	2995	Economy	3400.00
0005432880797	2995	Economy	3400.00
0005432706734	29916	Business	10300.00
0005433124130	29916	Business	10300.00
0005433124123	29916	Business	10300.00
0005432706884	29916	Business	10300.00
0005433124140	29916	Business	10300.00
0005432693393	29916	Business	10300.00
0005432693396	29916	Business	10300.00
0005432693408	29916	Business	10300.00
0005432706764	29916	Business	10300.00
0005432880959	29916	Business	10300.00
0005433124139	29916	Business	10300.00
0005432693380	29916	Economy	3400.00
0005432706779	29916	Economy	3400.00
0005433124124	29916	Economy	3400.00
0005432693387	29916	Economy	3400.00
0005432693381	29916	Economy	3400.00
0005432693405	29916	Economy	3400.00
0005432693402	29916	Economy	3400.00
0005433124137	29916	Economy	3400.00
0005432693391	29916	Economy	3400.00
0005432706885	29916	Economy	3400.00
0005433124134	29916	Economy	3800.00
0005432693406	29916	Economy	3800.00
0005432693400	29916	Economy	3800.00
0005432693404	29916	Economy	3800.00
0005432880965	29916	Economy	3800.00
0005432693410	29916	Economy	3400.00
0005432880956	29916	Economy	3400.00
0005433124127	29916	Economy	3400.00
0005432693398	29916	Economy	3400.00
0005433194888	29916	Economy	3400.00
0005432693388	29916	Economy	3400.00
0005432693397	29916	Economy	3400.00
0005432693379	29916	Economy	3400.00
0005433124141	29916	Economy	3400.00
0005433124132	29916	Economy	3400.00
0005432706738	29916	Economy	3400.00
0005432880961	29916	Economy	3400.00
0005432880958	29916	Economy	3400.00
0005432693394	29916	Economy	3400.00
0005432693392	29916	Economy	3400.00
0005432880969	29916	Economy	3400.00
0005432880964	29916	Economy	3400.00
0005433124143	29916	Economy	3400.00
0005433194891	29916	Economy	3400.00
0005432880971	29916	Economy	3400.00
0005432706832	29916	Economy	3400.00
0005433124142	29916	Economy	3400.00
0005433124133	29916	Economy	3400.00
0005432693401	29916	Economy	3400.00
0005432880970	29916	Economy	3400.00
0005433124131	29916	Economy	3400.00
0005432706780	29916	Economy	3400.00
0005432706865	29916	Economy	3400.00
0005432880963	29916	Economy	3400.00
0005432880957	29916	Economy	3400.00
0005432706878	29916	Economy	3400.00
0005433124126	29916	Economy	3400.00
0005432693389	29916	Economy	3400.00
0005433124136	29916	Economy	3400.00
0005432706801	29916	Economy	3400.00
0005432706862	29916	Economy	3400.00
0005432693390	29916	Economy	3400.00
0005432693399	29916	Economy	3400.00
0005432880967	29916	Economy	3400.00
0005433124128	29916	Economy	3400.00
0005433124120	29916	Economy	3400.00
0005433194890	29916	Economy	3400.00
0005433124122	29916	Economy	3400.00
0005432706879	29916	Economy	3400.00
0005432880962	29916	Economy	3400.00
0005433124129	29916	Economy	3400.00
0005432706824	29916	Economy	3400.00
0005432706753	29916	Economy	3400.00
0005432706844	29916	Economy	3400.00
0005432693395	29916	Economy	3400.00
0005432706737	29916	Economy	3400.00
0005432706861	29916	Economy	3400.00
0005432693383	29916	Economy	3400.00
0005432693409	29916	Economy	3400.00
0005433194889	29916	Economy	3400.00
0005433124138	29916	Economy	3400.00
0005432693407	29916	Economy	3400.00
0005432693403	29916	Economy	3400.00
0005433124125	29916	Economy	3400.00
0005433124135	29916	Economy	3400.00
0005432706761	29916	Economy	3400.00
0005432880966	29916	Economy	3400.00
0005432693384	29916	Economy	3400.00
0005432880968	29916	Economy	3400.00
0005432693385	29916	Economy	3400.00
0005432706869	29916	Economy	3400.00
0005432880960	29916	Economy	3400.00
0005433124121	29916	Economy	3400.00
0005432693382	29916	Economy	3400.00
0005432693386	29916	Economy	3400.00
0005434988836	23657	Economy	4000.00
0005434980074	23657	Economy	4000.00
0005434980079	23657	Economy	4000.00
0005434980078	23657	Economy	4000.00
0005434980081	23657	Economy	3600.00
0005434980066	23657	Economy	3600.00
0005434980080	23657	Economy	3600.00
0005434980082	23657	Economy	3600.00
0005434988837	23657	Economy	3600.00
0005434980071	23657	Economy	3600.00
0005434988832	23657	Economy	3600.00
0005434980073	23657	Economy	3600.00
0005434980054	23657	Economy	3600.00
0005434980059	23657	Economy	3600.00
0005434988840	23657	Economy	3600.00
0005434980065	23657	Economy	3600.00
0005434980060	23657	Economy	3600.00
0005434980076	23657	Economy	3600.00
0005434988841	23657	Economy	3600.00
0005434988833	23657	Economy	3600.00
0005434988845	23657	Economy	3600.00
0005434988839	23657	Economy	3600.00
0005434980067	23657	Economy	3600.00
0005434980068	23657	Economy	3600.00
0005434980053	23657	Economy	3600.00
0005434980063	23657	Economy	3600.00
0005434980052	23657	Economy	3600.00
0005434980056	23657	Economy	3600.00
0005434988844	23657	Economy	3600.00
0005434980057	23657	Economy	3600.00
0005434980064	23657	Economy	3600.00
0005434988834	23657	Economy	3600.00
0005434980055	23657	Economy	3600.00
0005434980058	23657	Economy	3600.00
0005434988835	23657	Economy	3600.00
0005434980070	23657	Economy	3600.00
0005434980062	23657	Economy	3600.00
0005434980069	23657	Economy	3600.00
0005434988843	23657	Economy	3600.00
0005434988842	23657	Economy	3600.00
0005434988838	23657	Economy	3600.00
0005434980077	23657	Economy	3600.00
0005434980072	23657	Economy	3600.00
0005434980075	23657	Economy	3600.00
0005434980061	23657	Economy	3600.00
0005434988739	27540	Economy	4000.00
0005434979862	27540	Economy	4000.00
0005434979699	27540	Economy	4000.00
0005434979756	27540	Economy	3600.00
0005434988738	27540	Economy	3600.00
0005434979956	27540	Economy	3600.00
0005434979833	27540	Economy	3600.00
0005434979700	27540	Economy	3600.00
0005434988734	27540	Economy	3600.00
0005434979804	27540	Economy	3600.00
0005434988711	27540	Economy	3600.00
0005434988705	27540	Economy	3600.00
0005434979832	27540	Economy	3600.00
0005434988718	27540	Economy	3600.00
0005434979788	27540	Economy	3600.00
0005434979844	27540	Economy	3600.00
0005434979911	27540	Economy	3600.00
0005434988756	27540	Economy	3600.00
0005434979937	27540	Economy	3600.00
0005434988721	27540	Economy	3600.00
0005434979936	27540	Economy	3600.00
0005434979923	27540	Economy	3600.00
0005434979749	27540	Economy	3600.00
0005434979893	27540	Economy	3600.00
0005434988728	27540	Economy	3600.00
0005434979938	27540	Economy	3600.00
0005434979894	27540	Economy	3600.00
0005434979760	27540	Economy	3600.00
0005434979895	27540	Economy	3600.00
0005434979863	27540	Economy	3600.00
0005434988744	27540	Economy	3600.00
0005434988750	27540	Economy	3600.00
0005434979945	27540	Economy	3600.00
0005434979783	27540	Economy	3600.00
0005434979889	27540	Economy	3600.00
0005434988712	27540	Economy	3600.00
0005434979845	27540	Economy	3600.00
0005434979757	27540	Economy	3600.00
0005434988710	27540	Economy	3600.00
0005434979759	27540	Economy	3600.00
0005434979922	27540	Economy	3600.00
0005434988740	27540	Economy	3600.00
0005434979775	27540	Economy	3600.00
0005434979917	27540	Economy	3600.00
0005434988706	27540	Economy	3600.00
0005433113543	10267	Economy	19700.00
0005434302499	10267	Economy	19700.00
0005433111508	10267	Economy	19700.00
0005434302501	10267	Economy	19700.00
0005433111509	10267	Economy	19700.00
0005434302873	10267	Economy	19700.00
0005434302500	10267	Economy	19700.00
0005434302874	10267	Economy	19700.00
0005433113560	19602	Economy	21600.00
0005433113557	19602	Economy	21600.00
0005433113559	19602	Economy	19700.00
0005434302464	19602	Economy	19700.00
0005433113558	19602	Economy	19700.00
0005434302451	19602	Economy	19700.00
0005434302470	19602	Economy	19700.00
0005434302471	19602	Economy	19700.00
0005434302465	19602	Economy	19700.00
0005434302452	19602	Economy	19700.00
0005434302469	19602	Economy	19700.00
0005434302466	19602	Economy	19700.00
0005435069627	3544	Business	26900.00
0005435069596	3544	Business	26900.00
0005435069616	3544	Business	26900.00
0005435925298	3544	Business	26900.00
0005435069614	3544	Business	26900.00
0005435069591	3544	Business	26900.00
0005435069603	3544	Business	26900.00
0005435069631	3544	Business	26900.00
0005435069617	3544	Economy	9000.00
0005435925295	3544	Economy	9000.00
0005435069589	3544	Economy	9000.00
0005435069600	3544	Economy	9000.00
0005435925277	3544	Economy	9000.00
0005435069640	3544	Economy	9000.00
0005435069625	3544	Economy	9000.00
0005435925311	3544	Economy	9000.00
0005435069618	3544	Economy	9900.00
0005435925312	3544	Economy	9900.00
0005435069634	3544	Economy	9900.00
0005435069642	3544	Economy	9900.00
0005435069632	3544	Economy	9000.00
0005435069590	3544	Economy	9000.00
0005435069638	3544	Economy	9000.00
0005435718996	3544	Economy	9000.00
0005435925306	3544	Economy	9000.00
0005435069604	3544	Economy	9000.00
0005435069606	3544	Economy	9000.00
0005435069619	3544	Economy	9000.00
0005435069635	3544	Economy	9000.00
0005435069611	3544	Economy	9000.00
0005435069633	3544	Economy	9000.00
0005435069639	3544	Economy	9000.00
0005435069628	3544	Economy	9000.00
0005435069626	3544	Economy	9000.00
0005435718999	3544	Economy	9000.00
0005435925313	3544	Economy	9000.00
0005435069601	3544	Economy	9000.00
0005435069623	3544	Economy	9000.00
0005435069607	3544	Economy	9000.00
0005435925297	3544	Economy	9000.00
0005435069624	3544	Economy	9000.00
0005435925296	3544	Economy	9000.00
0005435069613	3544	Economy	9000.00
0005435069602	3544	Economy	9000.00
0005435069598	3544	Economy	9000.00
0005435069599	3544	Economy	9000.00
0005435718997	3544	Economy	9000.00
0005435069593	3544	Economy	9000.00
0005435069595	3544	Economy	9000.00
0005435069636	3544	Economy	9000.00
0005435069621	3544	Economy	9000.00
0005435069609	3544	Economy	9000.00
0005435069612	3544	Economy	9000.00
0005435069641	3544	Economy	9000.00
0005435069637	3544	Economy	9000.00
0005435069620	3544	Economy	9000.00
0005435925307	3544	Economy	9000.00
0005435925288	3544	Economy	9000.00
0005435069615	3544	Economy	9000.00
0005435069622	3544	Economy	9000.00
0005435718998	3544	Economy	9000.00
0005435069592	3544	Economy	9000.00
0005435069629	3544	Economy	9000.00
0005435069610	3544	Economy	9000.00
0005435069605	3544	Economy	9000.00
0005435069594	3544	Economy	9000.00
0005435069608	3544	Economy	9000.00
0005435069630	3544	Economy	9000.00
0005435069597	3544	Economy	9000.00
0005435069114	15294	Business	26900.00
0005435939898	15294	Business	26900.00
0005435069075	15294	Business	26900.00
0005435068969	15294	Business	26900.00
0005435069032	15294	Business	26900.00
0005435925433	15294	Business	26900.00
0005435069000	15294	Business	26900.00
0005435069145	15294	Business	26900.00
0005435069140	15294	Business	26900.00
0005435069176	15294	Business	26900.00
0005435925425	15294	Economy	9000.00
0005435069326	15294	Economy	9000.00
0005435069318	15294	Economy	9000.00
0005435069122	15294	Economy	9000.00
0005435069141	15294	Economy	9900.00
0005435925435	15294	Economy	9900.00
0005435069126	15294	Economy	9900.00
0005435069031	15294	Economy	9000.00
0005435069151	15294	Economy	9000.00
0005435925432	15294	Economy	9000.00
0005435069136	15294	Economy	9000.00
0005435069030	15294	Economy	9000.00
0005435069135	15294	Economy	9000.00
0005435069154	15294	Economy	9000.00
0005435069300	15294	Economy	9000.00
0005435069248	15294	Economy	9000.00
0005435068968	15294	Economy	9000.00
0005435925436	15294	Economy	9000.00
0005435069164	15294	Economy	9000.00
0005435939897	15294	Economy	9000.00
0005435069125	15294	Economy	9000.00
0005435925426	15294	Economy	9000.00
0005435925429	15294	Economy	9000.00
0005435069249	15294	Economy	9000.00
0005435069207	15294	Economy	9000.00
0005435069403	15294	Economy	9000.00
0005435069069	15294	Economy	9000.00
0005435925431	15294	Economy	9000.00
0005435069102	15294	Economy	9000.00
0005435068865	15294	Economy	9000.00
0005435069050	15294	Economy	9000.00
0005435069166	15294	Economy	9000.00
0005435069259	15294	Economy	9000.00
0005435068939	15294	Economy	9000.00
0005435069279	15294	Economy	9000.00
0005435069123	15294	Economy	9000.00
0005435068999	15294	Economy	9000.00
0005435069165	15294	Economy	9000.00
0005435925428	15294	Economy	9000.00
0005435925427	15294	Economy	9000.00
0005435069319	15294	Economy	9000.00
0005435069078	15294	Economy	9000.00
0005435925424	15294	Economy	9000.00
0005435925430	15294	Economy	9000.00
0005435939896	15294	Economy	9000.00
0005435069404	15294	Economy	9000.00
0005435925434	15294	Economy	9000.00
0005435925437	15294	Economy	9000.00
0005432659726	18129	Economy	5900.00
0005432658613	18129	Economy	5900.00
0005432659727	18129	Economy	5900.00
0005432658612	18129	Economy	5900.00
0005432660839	18129	Economy	5900.00
0005432660812	26382	Economy	5900.00
0005432660815	26382	Economy	5900.00
0005432664131	26382	Economy	5900.00
0005432660816	26382	Economy	5900.00
0005432660808	26382	Economy	5900.00
0005432901703	27	Business	20000.00
0005432919915	27	Business	20000.00
0005432919937	27	Business	20000.00
0005432919962	27	Business	20000.00
0005432901569	27	Business	20000.00
0005433102044	27	Business	20000.00
0005432919885	27	Business	20000.00
0005433102223	27	Business	20000.00
0005433102149	27	Business	20000.00
0005432157512	27	Business	20000.00
0005432919932	27	Business	20000.00
0005432901663	27	Business	20000.00
0005433102284	27	Business	20000.00
0005433102156	27	Business	20000.00
0005432919963	27	Economy	7300.00
0005432919899	27	Economy	7300.00
0005433102290	27	Economy	7300.00
0005433102255	27	Economy	7300.00
0005433102110	27	Economy	7300.00
0005433102289	27	Economy	6700.00
0005433102272	27	Economy	6700.00
0005433102279	27	Economy	6700.00
0005433102174	27	Economy	6700.00
0005432901624	27	Economy	6700.00
0005432901682	27	Economy	6700.00
0005433102268	27	Economy	6700.00
0005433102133	27	Economy	6700.00
0005433102200	27	Economy	6700.00
0005432901577	27	Economy	6700.00
0005432677569	27	Economy	6700.00
0005432901637	27	Economy	6700.00
0005432901628	27	Economy	6700.00
0005433102254	27	Economy	6700.00
0005433102234	27	Economy	6700.00
0005433102256	27	Economy	6700.00
0005433102281	27	Economy	6700.00
0005433102198	27	Economy	6700.00
0005433102186	27	Economy	6700.00
0005433102045	27	Economy	6700.00
0005433102253	27	Economy	6700.00
0005432919877	27	Economy	6700.00
0005432901645	27	Economy	6700.00
0005433102114	27	Economy	6700.00
0005433102283	27	Economy	6700.00
0005432901664	27	Economy	6700.00
0005433102181	27	Economy	6700.00
0005432919900	27	Economy	6700.00
0005432919901	27	Economy	6700.00
0005432919938	27	Economy	6700.00
0005433102230	27	Economy	7300.00
0005433102235	27	Economy	7300.00
0005433102214	27	Economy	6700.00
0005433102157	27	Economy	6700.00
0005433102199	27	Economy	6700.00
0005432919991	27	Economy	6700.00
0005433102148	27	Economy	6700.00
0005432901615	27	Economy	6700.00
0005432919876	27	Economy	6700.00
0005432677572	27	Economy	6700.00
0005433102173	27	Economy	6700.00
0005432901681	27	Economy	6700.00
0005432919936	27	Economy	6700.00
0005432919861	27	Economy	6700.00
0005433102247	27	Economy	6700.00
0005432901652	27	Economy	6700.00
0005432919894	27	Economy	6700.00
0005432901602	27	Economy	6700.00
0005432901578	27	Economy	6700.00
0005433102142	27	Economy	6700.00
0005432901635	27	Economy	6700.00
0005432901683	27	Economy	6700.00
0005432919910	27	Economy	6700.00
0005433102197	27	Economy	6700.00
0005433102113	27	Economy	6700.00
0005433102222	27	Economy	6700.00
0005433102285	27	Economy	6700.00
0005433102172	27	Economy	6700.00
0005433102213	27	Economy	6700.00
0005433102280	27	Economy	6700.00
0005433102273	27	Economy	6700.00
0005432919898	27	Economy	6700.00
0005433102117	27	Economy	6700.00
0005432901603	27	Economy	6700.00
0005432919908	27	Economy	6700.00
0005432901666	27	Economy	6700.00
0005432919916	27	Economy	6700.00
0005433102252	27	Economy	6700.00
0005432901670	27	Economy	6700.00
0005432901636	27	Economy	6700.00
0005432919871	27	Economy	6700.00
0005433102261	27	Economy	6700.00
0005432157511	27	Economy	6700.00
0005432817775	26	Business	20000.00
0005432262386	26	Business	20000.00
0005432262367	26	Business	20000.00
0005432262387	26	Business	20000.00
0005432262373	26	Business	20000.00
0005432817773	26	Business	20000.00
0005432262359	26	Business	20000.00
0005432289019	26	Business	20000.00
0005432289018	26	Business	20000.00
0005432262383	26	Business	20000.00
0005432817786	26	Business	20000.00
0005432262391	26	Business	20000.00
0005432262352	26	Business	20000.00
0005432262385	26	Business	20000.00
0005432262362	26	Economy	7300.00
0005432262376	26	Economy	7300.00
0005432262357	26	Economy	7300.00
0005432262377	26	Economy	6700.00
0005432756837	26	Economy	6700.00
0005432289021	26	Economy	6700.00
0005432817787	26	Economy	6700.00
0005432262395	26	Economy	6700.00
0005432262372	26	Economy	6700.00
0005432262384	26	Economy	6700.00
0005432817779	26	Economy	6700.00
0005432817768	26	Economy	6700.00
0005434153545	26	Economy	6700.00
0005432756828	26	Economy	6700.00
0005432262382	26	Economy	6700.00
0005432262366	26	Economy	6700.00
0005432817778	26	Economy	6700.00
0005432262355	26	Economy	6700.00
0005432262370	26	Economy	6700.00
0005432262392	26	Economy	6700.00
0005432262350	26	Economy	6700.00
0005432817780	26	Economy	6700.00
0005432262351	26	Economy	6700.00
0005432817763	26	Economy	6700.00
0005432262363	26	Economy	6700.00
0005432262379	26	Economy	6700.00
0005432262375	26	Economy	6700.00
0005432817781	26	Economy	6700.00
0005432262388	26	Economy	6700.00
0005432262356	26	Economy	6700.00
0005432262371	26	Economy	6700.00
0005432262390	26	Economy	6700.00
0005432756844	26	Economy	6700.00
0005432262364	26	Economy	6700.00
0005432289020	26	Economy	6700.00
0005434153546	26	Economy	6700.00
0005432262358	26	Economy	6700.00
0005432817761	26	Economy	6700.00
0005432817782	26	Economy	6700.00
0005432262361	26	Economy	6700.00
0005432817785	26	Economy	7300.00
0005432262394	26	Economy	7300.00
0005432753315	26	Economy	6700.00
0005432262369	26	Economy	6700.00
0005432262389	26	Economy	6700.00
0005432817769	26	Economy	6700.00
0005432817764	26	Economy	6700.00
0005434153544	26	Economy	6700.00
0005432817767	26	Economy	6700.00
0005432817765	26	Economy	6700.00
0005432262365	26	Economy	6700.00
0005432262354	26	Economy	6700.00
0005432817770	26	Economy	6700.00
0005432817776	26	Economy	6700.00
0005432817771	26	Economy	6700.00
0005432262360	26	Economy	6700.00
0005432262374	26	Economy	6700.00
0005432817759	26	Economy	6700.00
0005432756836	26	Economy	6700.00
0005432817772	26	Economy	6700.00
0005432262381	26	Economy	6700.00
0005432817766	26	Economy	6700.00
0005432817758	26	Economy	6700.00
0005432262380	26	Economy	6700.00
0005432817760	26	Economy	6700.00
0005433687692	26	Economy	6700.00
0005432817777	26	Economy	6700.00
0005432817774	26	Economy	6700.00
0005432262378	26	Economy	6700.00
0005432207686	26	Economy	6700.00
0005432262353	26	Economy	6700.00
0005432817783	26	Economy	6700.00
0005432817762	26	Economy	6700.00
0005432262368	26	Economy	6700.00
0005432262393	26	Economy	6700.00
0005432817784	26	Economy	6700.00
0005433102699	8089	Business	20000.00
0005432920079	8089	Business	20000.00
0005433102712	8089	Business	20000.00
0005432753336	8089	Business	20000.00
0005432920081	8089	Business	20000.00
0005432020533	8089	Business	20000.00
0005432751561	8089	Business	20000.00
0005433102688	8089	Business	20000.00
0005432020541	8089	Business	20000.00
0005433102675	8089	Business	20000.00
0005432753334	8089	Business	20000.00
0005432920069	8089	Business	20000.00
0005433102672	8089	Business	20000.00
0005433102692	8089	Business	20000.00
0005432753337	8089	Business	20000.00
0005432920082	8089	Business	20000.00
0005432045633	8089	Business	20000.00
0005433102683	8089	Business	20000.00
0005433102704	8089	Business	20000.00
0005433102719	8089	Business	20000.00
0005433102693	8089	Economy	7300.00
0005432020525	8089	Economy	7300.00
0005433102679	8089	Economy	7300.00
0005433102674	8089	Economy	6700.00
0005432920064	8089	Economy	6700.00
0005433102697	8089	Economy	6700.00
0005433102716	8089	Economy	6700.00
0005432753335	8089	Economy	6700.00
0005433102677	8089	Economy	6700.00
0005432751562	8089	Economy	6700.00
0005432044554	8089	Economy	6700.00
0005432020546	8089	Economy	6700.00
0005433102701	8089	Economy	6700.00
0005433102695	8089	Economy	6700.00
0005432920060	8089	Economy	6700.00
0005433102706	8089	Economy	6700.00
0005433102696	8089	Economy	6700.00
0005432020524	8089	Economy	6700.00
0005432044552	8089	Economy	6700.00
0005432920071	8089	Economy	6700.00
0005433102682	8089	Economy	6700.00
0005432920078	8089	Economy	6700.00
0005432020526	8089	Economy	6700.00
0005432920074	8089	Economy	6700.00
0005432920062	8089	Economy	6700.00
0005432920065	8089	Economy	6700.00
0005433102700	8089	Economy	6700.00
0005432392030	8089	Economy	6700.00
0005432020531	8089	Economy	6700.00
0005432920077	8089	Economy	6700.00
0005433102703	8089	Economy	6700.00
0005433102708	8089	Economy	6700.00
0005432020521	8089	Economy	6700.00
0005432020523	8089	Economy	6700.00
0005432020527	8089	Economy	6700.00
0005433102689	8089	Economy	6700.00
0005433102686	8089	Economy	6700.00
0005432751560	8089	Economy	6700.00
0005433102710	8089	Economy	6700.00
0005432020545	8089	Economy	6700.00
0005432920061	8089	Economy	6700.00
0005433102714	8089	Economy	6700.00
0005432920075	8089	Economy	7300.00
0005432020535	8089	Economy	7300.00
0005432920067	8089	Economy	7300.00
0005432020529	8089	Economy	7300.00
0005433102673	8089	Economy	6700.00
0005432020538	8089	Economy	6700.00
0005433102705	8089	Economy	6700.00
0005432020544	8089	Economy	6700.00
0005432920066	8089	Economy	7300.00
0005433102691	8089	Economy	6700.00
0005433102694	8089	Economy	6700.00
0005432920070	8089	Economy	6700.00
0005432392031	8089	Economy	6700.00
0005432677615	8089	Economy	6700.00
0005432920080	8089	Economy	6700.00
0005433102709	8089	Economy	6700.00
0005432920068	8089	Economy	6700.00
0005432677614	8089	Economy	6700.00
0005432020542	8089	Economy	6700.00
0005433102685	8089	Economy	6700.00
0005432020540	8089	Economy	6700.00
0005432045634	8089	Economy	6700.00
0005433102680	8089	Economy	6700.00
0005433102718	8089	Economy	6700.00
0005432020528	8089	Economy	6700.00
0005433102684	8089	Economy	6700.00
0005432677613	8089	Economy	6700.00
0005432020537	8089	Economy	6700.00
0005433102687	8089	Economy	6700.00
0005432020547	8089	Economy	6700.00
0005433102707	8089	Economy	6700.00
0005433102717	8089	Economy	6700.00
0005432920063	8089	Economy	6700.00
0005432020539	8089	Economy	6700.00
0005432020522	8089	Economy	6700.00
0005432020543	8089	Economy	6700.00
0005432920072	8089	Economy	6700.00
0005433102690	8089	Economy	6700.00
0005433102698	8089	Economy	6700.00
0005432020530	8089	Economy	6700.00
0005433102713	8089	Economy	6700.00
0005432392029	8089	Economy	6700.00
0005433102702	8089	Economy	6700.00
0005433102671	8089	Economy	6700.00
0005432044553	8089	Economy	6700.00
0005433102681	8089	Economy	6700.00
0005432920059	8089	Economy	6700.00
0005432020534	8089	Economy	6700.00
0005432020536	8089	Economy	6700.00
0005433102715	8089	Economy	6700.00
0005432920076	8089	Economy	6700.00
0005433102676	8089	Economy	6700.00
0005433102711	8089	Economy	6700.00
0005432677616	8089	Economy	6700.00
0005432020532	8089	Economy	6700.00
0005432920073	8089	Economy	6700.00
0005433102678	8089	Economy	6700.00
0005432817516	8090	Business	20000.00
0005432901779	8090	Business	20000.00
0005432817517	8090	Business	20000.00
0005432901792	8090	Business	20000.00
0005432817531	8090	Business	20000.00
0005432817402	8090	Business	20000.00
0005432901788	8090	Economy	7300.00
0005432817467	8090	Economy	7300.00
0005432817403	8090	Economy	6700.00
0005432817622	8090	Economy	6700.00
0005432901796	8090	Economy	6700.00
0005432901793	8090	Economy	6700.00
0005432901787	8090	Economy	6700.00
0005432817432	8090	Economy	6700.00
0005432901785	8090	Economy	6700.00
0005432817491	8090	Economy	6700.00
0005432817439	8090	Economy	6700.00
0005432817588	8090	Economy	6700.00
0005432002098	8090	Economy	6700.00
0005432901791	8090	Economy	6700.00
0005432901789	8090	Economy	6700.00
0005432901783	8090	Economy	6700.00
0005432817635	8090	Economy	6700.00
0005432901780	8090	Economy	6700.00
0005432901784	8090	Economy	6700.00
0005432817532	8090	Economy	6700.00
0005432817533	8090	Economy	7300.00
0005432817530	8090	Economy	7300.00
0005432817616	8090	Economy	6700.00
0005432817542	8090	Economy	6700.00
0005432901781	8090	Economy	6700.00
0005432817518	8090	Economy	6700.00
0005432817615	8090	Economy	6700.00
0005432901790	8090	Economy	6700.00
0005432901794	8090	Economy	6700.00
0005432817444	8090	Economy	6700.00
0005432817539	8090	Economy	6700.00
0005432817554	8090	Economy	6700.00
0005432817489	8090	Economy	6700.00
0005432002099	8090	Economy	6700.00
0005432901782	8090	Economy	6700.00
0005432817473	8090	Economy	6700.00
0005432817438	8090	Economy	6700.00
0005432901786	8090	Economy	6700.00
0005432901795	8090	Economy	6700.00
0005432002097	8090	Economy	6700.00
0005432817433	8090	Economy	6700.00
0005432901797	8090	Economy	6700.00
0005432002096	8090	Economy	6700.00
0005432817472	8090	Economy	6700.00
0005432817445	8090	Economy	6700.00
0005432817462	8090	Economy	6700.00
0005432817536	8090	Economy	6700.00
0005432817529	8090	Economy	6700.00
0005432817535	8090	Economy	6700.00
0005434175762	9683	Economy	6900.00
0005434175748	9683	Economy	6900.00
0005434175765	9683	Economy	6900.00
0005434175754	9683	Economy	6900.00
0005434175755	9683	Economy	6900.00
0005434175749	9683	Economy	6900.00
0005433870754	9683	Economy	6900.00
0005433870752	9683	Economy	6900.00
0005434175761	9683	Economy	6900.00
0005433870753	9683	Economy	6900.00
0005434175797	32367	Economy	6900.00
0005434175795	32367	Economy	6900.00
0005433870731	32367	Economy	6900.00
0005434175796	32367	Economy	6900.00
0005434175794	32367	Economy	6900.00
0005435902687	3492	Business	35000.00
0005434426915	3492	Business	35000.00
0005435626372	3492	Business	35000.00
0005434879243	3492	Business	35000.00
0005434879225	3492	Business	35000.00
0005434879176	3492	Business	35000.00
0005434879232	3492	Business	35000.00
0005434426911	3492	Business	35000.00
0005435902773	3492	Business	35000.00
0005434879155	3492	Business	35000.00
0005434879191	3492	Business	35000.00
0005434879203	3492	Business	35000.00
0005434879186	3492	Business	35000.00
0005435902678	3492	Business	35000.00
0005435126800	3492	Business	35000.00
0005434879196	3492	Business	35000.00
0005434879185	3492	Business	35000.00
0005434938352	3492	Business	35000.00
0005435626373	3492	Business	35000.00
0005434879194	3492	Comfort	19900.00
0005435126777	3492	Comfort	19900.00
0005434879198	3492	Comfort	19900.00
0005434426912	3492	Comfort	19900.00
0005434879189	3492	Comfort	19900.00
0005434879179	3492	Comfort	19900.00
0005435902697	3492	Comfort	19900.00
0005434938345	3492	Comfort	19900.00
0005434426927	3492	Comfort	19900.00
0005434426918	3492	Comfort	19900.00
0005432188642	3492	Comfort	19900.00
0005434426900	3492	Comfort	19900.00
0005435902750	3492	Comfort	19900.00
0005434426903	3492	Comfort	19900.00
0005435902764	3492	Comfort	19900.00
0005434426919	3492	Comfort	19900.00
0005434938344	3492	Comfort	19900.00
0005434879234	3492	Comfort	19900.00
0005435126802	3492	Comfort	19900.00
0005435841094	3492	Comfort	19900.00
0005432799739	3492	Comfort	19900.00
0005434879215	3492	Comfort	19900.00
0005435126775	3492	Comfort	19900.00
0005434879224	3492	Comfort	19900.00
0005434938349	3492	Comfort	19900.00
0005434879226	3492	Comfort	19900.00
0005432799748	3492	Comfort	19900.00
0005432799736	3492	Comfort	19900.00
0005434938341	3492	Comfort	19900.00
0005434879181	3492	Comfort	19900.00
0005434879207	3492	Comfort	19900.00
0005434426926	3492	Comfort	19900.00
0005434879246	3492	Comfort	19900.00
0005434879240	3492	Comfort	19900.00
0005434938342	3492	Economy	11700.00
0005434426920	3492	Economy	11700.00
0005435626383	3492	Economy	11700.00
0005434879228	3492	Economy	11700.00
0005435626376	3492	Economy	11700.00
0005434879167	3492	Economy	11700.00
0005435841824	3492	Economy	11700.00
0005434426910	3492	Economy	11700.00
0005435126788	3492	Economy	11700.00
0005434938336	3492	Economy	11700.00
0005434879164	3492	Economy	11700.00
0005434879213	3492	Economy	11700.00
0005435626384	3492	Economy	11700.00
0005434879223	3492	Economy	11700.00
0005434426906	3492	Economy	11700.00
0005432183489	3492	Economy	11700.00
0005435913933	3492	Economy	11700.00
0005435126803	3492	Economy	11700.00
0005434879204	3492	Economy	11700.00
0005435913932	3492	Economy	11700.00
0005434879217	3492	Economy	11700.00
0005432188641	3492	Economy	11700.00
0005435126809	3492	Economy	11700.00
0005434426922	3492	Economy	11700.00
0005434879163	3492	Economy	11700.00
0005435126793	3492	Economy	11700.00
0005434879192	3492	Economy	11700.00
0005435126807	3492	Economy	11700.00
0005434426928	3492	Economy	11700.00
0005434426909	3492	Economy	11700.00
0005435126781	3492	Economy	11700.00
0005435126771	3492	Economy	11700.00
0005434879247	3492	Economy	11700.00
0005435626377	3492	Economy	11700.00
0005434879160	3492	Economy	11700.00
0005434879212	3492	Economy	11700.00
0005432799751	3492	Economy	11700.00
0005435126785	3492	Economy	11700.00
0005435126790	3492	Economy	11700.00
0005434879237	3492	Economy	11700.00
0005435126799	3492	Economy	11700.00
0005435126797	3492	Economy	11700.00
0005435126794	3492	Economy	11700.00
0005434938334	3492	Economy	11700.00
0005432799747	3492	Economy	11700.00
0005435626371	3492	Economy	11700.00
0005434879236	3492	Economy	11700.00
0005432799741	3492	Economy	11700.00
0005434879244	3492	Economy	11700.00
0005432799744	3492	Economy	12800.00
0005434938351	3492	Economy	11700.00
0005435126783	3492	Economy	12800.00
0005434879211	3492	Economy	11700.00
0005434879242	3492	Economy	12800.00
0005432799761	3492	Economy	11700.00
0005434426923	3492	Economy	11700.00
0005434879209	3492	Economy	12800.00
0005432183490	3492	Economy	12800.00
0005434879208	3492	Economy	11700.00
0005432799758	3492	Economy	11700.00
0005435126805	3492	Economy	11700.00
0005434879187	3492	Economy	11700.00
0005434879233	3492	Economy	11700.00
0005434426908	3492	Economy	11700.00
0005434879177	3492	Economy	11700.00
0005432613905	3492	Economy	11700.00
0005435126786	3492	Economy	11700.00
0005435126801	3492	Economy	11700.00
0005435902701	3492	Economy	11700.00
0005435626382	3492	Economy	11700.00
0005434879168	3492	Economy	11700.00
0005434879210	3492	Economy	11700.00
0005434879222	3492	Economy	11700.00
0005435902686	3492	Economy	11700.00
0005435902652	3492	Economy	11700.00
0005435126789	3492	Economy	11700.00
0005434879159	3492	Economy	11700.00
0005434938348	3492	Economy	11700.00
0005434938346	3492	Economy	11700.00
0005434879174	3492	Economy	11700.00
0005434938340	3492	Economy	11700.00
0005434879172	3492	Economy	11700.00
0005434879175	3492	Economy	11700.00
0005434879173	3492	Economy	11700.00
0005434879190	3492	Economy	11700.00
0005432799762	3492	Economy	11700.00
0005434879154	3492	Economy	11700.00
0005434879200	3492	Economy	11700.00
0005435126811	3492	Economy	11700.00
0005434879206	3492	Economy	11700.00
0005434426924	3492	Economy	11700.00
0005434879161	3492	Economy	11700.00
0005434879219	3492	Economy	11700.00
0005435902748	3492	Economy	11700.00
0005432799755	3492	Economy	11700.00
0005434879221	3492	Economy	11700.00
0005434426904	3492	Economy	11700.00
0005435126808	3492	Economy	11700.00
0005434879245	3492	Economy	11700.00
0005434938335	3492	Economy	11700.00
0005435841823	3492	Economy	11700.00
0005435626380	3492	Economy	11700.00
0005432799734	3492	Economy	11700.00
0005434879230	3492	Economy	11700.00
0005434426902	3492	Economy	11700.00
0005432799743	3492	Economy	11700.00
0005432613903	3492	Economy	11700.00
0005432799745	3492	Economy	11700.00
0005435913931	3492	Economy	11700.00
0005434879238	3492	Economy	11700.00
0005432799757	3492	Economy	11700.00
0005434879241	3492	Economy	11700.00
0005432799749	3492	Economy	11700.00
0005432799752	3492	Economy	11700.00
0005434426907	3492	Economy	11700.00
0005432799760	3492	Economy	11700.00
0005434879171	3492	Economy	11700.00
0005435626381	3492	Economy	11700.00
0005432799754	3492	Economy	11700.00
0005434879227	3492	Economy	11700.00
0005432799738	3492	Economy	11700.00
0005432799735	3492	Economy	11700.00
0005435126791	3492	Economy	11700.00
0005434879216	3492	Economy	11700.00
0005434426916	3492	Economy	11700.00
0005432188643	3492	Economy	11700.00
0005432799746	3492	Economy	11700.00
0005434879197	3492	Economy	11700.00
0005434426925	3492	Economy	11700.00
0005434879239	3492	Economy	11700.00
0005434879170	3492	Economy	11700.00
0005432799737	3492	Economy	11700.00
0005435626379	3492	Economy	11700.00
0005435126806	3492	Economy	11700.00
0005435913937	3492	Economy	11700.00
0005435126782	3492	Economy	11700.00
0005435126795	3492	Economy	11700.00
0005435626375	3492	Economy	11700.00
0005434426914	3492	Economy	12800.00
0005434879182	3492	Economy	12800.00
0005432799750	3492	Economy	12800.00
0005432799742	3492	Economy	12800.00
0005434938337	3492	Economy	11700.00
0005435126774	3492	Economy	11700.00
0005434879229	3492	Economy	11700.00
0005434879165	3492	Economy	11700.00
0005435126779	3492	Economy	11700.00
0005434938339	3492	Economy	11700.00
0005435126773	3492	Economy	11700.00
0005432799753	3492	Economy	11700.00
0005435126776	3492	Economy	11700.00
0005432188640	3492	Economy	11700.00
0005434879220	3492	Economy	11700.00
0005432799759	3492	Economy	11700.00
0005435902779	3492	Economy	11700.00
0005434426901	3492	Economy	11700.00
0005434879248	3492	Economy	11700.00
0005434879193	3492	Economy	11700.00
0005435126792	3492	Economy	11700.00
0005435126804	3492	Economy	11700.00
0005434426913	3492	Economy	11700.00
0005432611751	3492	Economy	11700.00
0005434938347	3492	Economy	11700.00
0005435126772	3492	Economy	11700.00
0005432799756	3492	Economy	11700.00
0005434879162	3492	Economy	11700.00
0005435626374	3492	Economy	11700.00
0005434879183	3492	Economy	11700.00
0005434879156	3492	Economy	11700.00
0005434879202	3492	Economy	11700.00
0005435126778	3492	Economy	11700.00
0005434879188	3492	Economy	11700.00
0005434879157	3492	Economy	11700.00
0005434879178	3492	Economy	11700.00
0005435126780	3492	Economy	11700.00
0005432799740	3492	Economy	11700.00
0005435126812	3492	Economy	11700.00
0005434879180	3492	Economy	11700.00
0005434879205	3492	Economy	11700.00
0005434938350	3492	Economy	11700.00
0005434426905	3492	Economy	11700.00
0005432183488	3492	Economy	11700.00
0005435902798	3492	Economy	11700.00
0005434879184	3492	Economy	11700.00
0005434879158	3492	Economy	11700.00
0005434879199	3492	Economy	11700.00
0005434879235	3492	Economy	11700.00
0005434879214	3492	Economy	11700.00
0005435126784	3492	Economy	11700.00
0005435841825	3492	Economy	11700.00
0005434879169	3492	Economy	11700.00
0005434879231	3492	Economy	11700.00
0005434426921	3492	Economy	11700.00
0005432613904	3492	Economy	11700.00
0005434879153	3492	Economy	11700.00
0005434879201	3492	Economy	11700.00
0005434879166	3492	Economy	11700.00
0005434938343	3492	Economy	11700.00
0005435902680	3492	Economy	11700.00
0005435902679	3492	Economy	11700.00
0005434426917	3492	Economy	11700.00
0005434938333	3492	Economy	11700.00
0005435126798	3492	Economy	11700.00
0005435126796	3492	Economy	11700.00
0005434938338	3492	Economy	11700.00
0005434879218	3492	Economy	11700.00
0005435902726	3492	Economy	11700.00
0005435902653	3492	Economy	11700.00
0005434879195	3492	Economy	11700.00
0005435126787	3492	Economy	11700.00
0005435626378	3492	Economy	11700.00
0005435126810	3492	Economy	11700.00
0005435902797	3492	Economy	11700.00
0005434426757	14535	Business	35000.00
0005434938276	14535	Business	35000.00
0005434878385	14535	Business	35000.00
0005435902887	14535	Business	35000.00
0005434878686	14535	Business	35000.00
0005432799448	14535	Business	35000.00
0005434878649	14535	Business	35000.00
0005432799515	14535	Business	35000.00
0005434878573	14535	Business	35000.00
0005435126527	14535	Business	35000.00
0005434878312	14535	Business	35000.00
0005434878386	14535	Business	35000.00
0005435126270	14535	Business	35000.00
0005434878195	14535	Business	35000.00
0005434426574	14535	Business	35000.00
0005434938249	14535	Business	35000.00
0005434878372	14535	Business	35000.00
0005434878554	14535	Comfort	19900.00
0005432059525	14535	Business	35000.00
0005435626187	14535	Comfort	19900.00
0005435626147	14535	Comfort	19900.00
0005434877913	14535	Comfort	19900.00
0005434878121	14535	Comfort	19900.00
0005435913962	14535	Comfort	19900.00
0005434878460	14535	Comfort	19900.00
0005434878690	14535	Comfort	19900.00
0005432799493	14535	Comfort	19900.00
0005432799451	14535	Comfort	19900.00
0005435126332	14535	Comfort	19900.00
0005434878476	14535	Comfort	19900.00
0005435126336	14535	Comfort	19900.00
0005435626214	14535	Comfort	19900.00
0005435626155	14535	Comfort	19900.00
0005435626144	14535	Comfort	19900.00
0005435902884	14535	Comfort	19900.00
0005435626126	14535	Comfort	19900.00
0005435126489	14535	Comfort	19900.00
0005434426596	14535	Comfort	19900.00
0005434878345	14535	Comfort	19900.00
0005434877828	14535	Comfort	19900.00
0005435126364	14535	Comfort	19900.00
0005435126441	14535	Comfort	19900.00
0005434878029	14535	Comfort	19900.00
0005435913963	14535	Comfort	19900.00
0005435902894	14535	Comfort	19900.00
0005434426668	14535	Comfort	19900.00
0005434878811	14535	Comfort	19900.00
0005434938264	14535	Comfort	19900.00
0005435126472	14535	Comfort	19900.00
0005435902878	14535	Comfort	19900.00
0005432799417	14535	Comfort	19900.00
0005434878405	14535	Comfort	19900.00
0005432799450	14535	Economy	11700.00
0005434426629	14535	Economy	11700.00
0005434426667	14535	Economy	11700.00
0005435626181	14535	Economy	11700.00
0005434878237	14535	Economy	11700.00
0005434878298	14535	Economy	11700.00
0005434878860	14535	Economy	11700.00
0005434878501	14535	Economy	11700.00
0005434878859	14535	Economy	11700.00
0005434426628	14535	Economy	11700.00
0005434878596	14535	Economy	11700.00
0005435126451	14535	Economy	11700.00
0005434878153	14535	Economy	11700.00
0005435126529	14535	Economy	11700.00
0005434878474	14535	Economy	11700.00
0005435902893	14535	Economy	11700.00
0005435902888	14535	Economy	11700.00
0005434878360	14535	Economy	11700.00
0005434878597	14535	Economy	11700.00
0005435626150	14535	Economy	11700.00
0005434938197	14535	Economy	11700.00
0005434878184	14535	Economy	11700.00
0005434938214	14535	Economy	11700.00
0005434878422	14535	Economy	11700.00
0005434426673	14535	Economy	11700.00
0005432607577	14535	Economy	11700.00
0005435626196	14535	Economy	11700.00
0005434938205	14535	Economy	11700.00
0005435126448	14535	Economy	11700.00
0005434878247	14535	Economy	11700.00
0005434878367	14535	Economy	11700.00
0005434878542	14535	Economy	11700.00
0005435626086	14535	Economy	11700.00
0005435126449	14535	Economy	11700.00
0005434426726	14535	Economy	11700.00
0005434878423	14535	Economy	11700.00
0005434938116	14535	Economy	11700.00
0005432799484	14535	Economy	11700.00
0005434878502	14535	Economy	11700.00
0005434426718	14535	Economy	11700.00
0005435126471	14535	Economy	11700.00
0005434878289	14535	Economy	11700.00
0005435126432	14535	Economy	11700.00
0005434878561	14535	Economy	11700.00
0005434878097	14535	Economy	11700.00
0005434878668	14535	Economy	11700.00
0005434877943	14535	Economy	12800.00
0005434878313	14535	Economy	11700.00
0005434878695	14535	Economy	11700.00
0005435902883	14535	Economy	11700.00
0005434878419	14535	Economy	12800.00
0005434938189	14535	Economy	11700.00
0005435126528	14535	Economy	12800.00
0005434878355	14535	Economy	12800.00
0005432059524	14535	Economy	11700.00
0005435902892	14535	Economy	11700.00
0005434426763	14535	Economy	11700.00
0005435126359	14535	Economy	11700.00
0005434878344	14535	Economy	11700.00
0005432799509	14535	Economy	11700.00
0005434877829	14535	Economy	11700.00
0005434878640	14535	Economy	11700.00
0005434878555	14535	Economy	11700.00
0005435126358	14535	Economy	11700.00
0005432799585	14535	Economy	11700.00
0005435126433	14535	Economy	11700.00
0005435126331	14535	Economy	11700.00
0005434878732	14535	Economy	11700.00
0005434426728	14535	Economy	11700.00
0005434878861	14535	Economy	11700.00
0005435626156	14535	Economy	11700.00
0005435126470	14535	Economy	11700.00
0005434878246	14535	Economy	11700.00
0005435626159	14535	Economy	11700.00
0005434426641	14535	Economy	11700.00
0005434426680	14535	Economy	11700.00
0005435126428	14535	Economy	11700.00
0005432799547	14535	Economy	11700.00
0005432799586	14535	Economy	11700.00
0005435842336	14535	Economy	11700.00
0005434878625	14535	Economy	11700.00
0005435902880	14535	Economy	11700.00
0005434878504	14535	Economy	11700.00
0005432799483	14535	Economy	11700.00
0005434878104	14535	Economy	11700.00
0005435626208	14535	Economy	11700.00
0005432799479	14535	Economy	11700.00
0005434878667	14535	Economy	11700.00
0005435126363	14535	Economy	11700.00
0005434878113	14535	Economy	11700.00
0005434426549	14535	Economy	11700.00
0005432799416	14535	Economy	11700.00
0005435126354	14535	Economy	11700.00
0005434878063	14535	Economy	11700.00
0005435902877	14535	Economy	11700.00
0005434878028	14535	Economy	11700.00
0005434938237	14535	Economy	11700.00
0005434938156	14535	Economy	11700.00
0005434938048	14535	Economy	11700.00
0005434878506	14535	Economy	11700.00
0005434878560	14535	Economy	11700.00
0005435126478	14535	Economy	11700.00
0005434938175	14535	Economy	11700.00
0005435126380	14535	Economy	11700.00
0005434878359	14535	Economy	11700.00
0005434878030	14535	Economy	11700.00
0005435626213	14535	Economy	11700.00
0005434938251	14535	Economy	11700.00
0005435626084	14535	Economy	11700.00
0005434878572	14535	Economy	11700.00
0005434878411	14535	Economy	11700.00
0005435126337	14535	Economy	11700.00
0005434426657	14535	Economy	11700.00
0005435126445	14535	Economy	11700.00
0005434878529	14535	Economy	11700.00
0005434426717	14535	Economy	11700.00
0005434878446	14535	Economy	11700.00
0005434878447	14535	Economy	11700.00
0005434426669	14535	Economy	11700.00
0005434938099	14535	Economy	11700.00
0005432799474	14535	Economy	11700.00
0005435126408	14535	Economy	11700.00
0005435842335	14535	Economy	11700.00
0005434878119	14535	Economy	11700.00
0005435914702	14535	Economy	11700.00
0005435626161	14535	Economy	11700.00
0005435126410	14535	Economy	11700.00
0005435126446	14535	Economy	11700.00
0005434878292	14535	Economy	11700.00
0005435841829	14535	Economy	11700.00
0005435902889	14535	Economy	11700.00
0005434878470	14535	Economy	11700.00
0005434878503	14535	Economy	11700.00
0005434878462	14535	Economy	11700.00
0005435626178	14535	Economy	11700.00
0005434938206	14535	Economy	12800.00
0005434878505	14535	Economy	12800.00
0005434426681	14535	Economy	12800.00
0005435902890	14535	Economy	11700.00
0005435126515	14535	Economy	11700.00
0005435626199	14535	Economy	11700.00
0005432799485	14535	Economy	11700.00
0005435126392	14535	Economy	11700.00
0005432799587	14535	Economy	11700.00
0005432799482	14535	Economy	11700.00
0005434938155	14535	Economy	11700.00
0005434878463	14535	Economy	11700.00
0005435626186	14535	Economy	11700.00
0005432799422	14535	Economy	11700.00
0005434938049	14535	Economy	11700.00
0005434938157	14535	Economy	11700.00
0005435902882	14535	Economy	11700.00
0005434878466	14535	Economy	11700.00
0005434878648	14535	Economy	11700.00
0005435126295	14535	Economy	11700.00
0005434878810	14535	Economy	11700.00
0005434426637	14535	Economy	11700.00
0005434878062	14535	Economy	11700.00
0005432607574	14535	Economy	11700.00
0005435126388	14535	Economy	11700.00
0005435126389	14535	Economy	11700.00
0005434938202	14535	Economy	11700.00
0005435913964	14535	Economy	11700.00
0005434426756	14535	Economy	11700.00
0005434878498	14535	Economy	11700.00
0005435626127	14535	Economy	11700.00
0005432799573	14535	Economy	11700.00
0005434878559	14535	Economy	11700.00
0005434878105	14535	Economy	11700.00
0005434878356	14535	Economy	11700.00
0005435126547	14535	Economy	11700.00
0005432799546	14535	Economy	11700.00
0005435126427	14535	Economy	11700.00
0005435126450	14535	Economy	11700.00
0005432611716	14535	Economy	11700.00
0005434878185	14535	Economy	11700.00
0005432799508	14535	Economy	11700.00
0005434426670	14535	Economy	11700.00
0005434426640	14535	Economy	11700.00
0005434878588	14535	Economy	11700.00
0005435626197	14535	Economy	11700.00
0005435902885	14535	Economy	11700.00
0005434878557	14535	Economy	11700.00
0005432799444	14535	Economy	11700.00
0005434878412	14535	Economy	11700.00
0005434878569	14535	Economy	11700.00
0005434938098	14535	Economy	11700.00
0005435902891	14535	Economy	11700.00
0005434878451	14535	Economy	11700.00
0005435126488	14535	Economy	11700.00
0005434878120	14535	Economy	11700.00
0005435126303	14535	Economy	11700.00
0005435914703	14535	Economy	11700.00
0005435126409	14535	Economy	11700.00
0005432799580	14535	Economy	11700.00
0005435902881	14535	Economy	11700.00
0005435126481	14535	Economy	11700.00
0005434878454	14535	Economy	11700.00
0005434938190	14535	Economy	11700.00
0005432799534	14535	Economy	11700.00
0005434878229	14535	Economy	11700.00
0005435902886	14535	Economy	11700.00
0005434878488	14535	Economy	11700.00
0005432799535	14535	Economy	11700.00
0005434878409	14535	Economy	11700.00
0005434938236	14535	Economy	11700.00
0005434426597	14535	Economy	11700.00
0005434877914	14535	Economy	11700.00
0005435626180	14535	Economy	11700.00
0005435902879	14535	Economy	11700.00
0005434938196	14535	Economy	11700.00
0005434878631	14535	Economy	11700.00
0005432799581	14535	Economy	11700.00
0005432799480	14535	Economy	11700.00
0005435126271	14535	Economy	11700.00
0005434325769	3609	Economy	16300.00
0005435889881	3609	Economy	16300.00
0005434325766	3609	Economy	16300.00
0005434325770	3609	Economy	14800.00
0005435889912	3609	Economy	14800.00
0005435889875	3609	Economy	14800.00
0005434325768	3609	Economy	14800.00
0005435889911	3609	Economy	14800.00
0005435889902	3609	Economy	14800.00
0005435889901	3609	Economy	14800.00
0005434325767	3609	Economy	14800.00
0005434325772	3609	Economy	14800.00
0005435889899	3609	Economy	14800.00
0005434312340	3609	Economy	14800.00
0005435889895	3609	Economy	14800.00
0005435889874	3609	Economy	14800.00
0005434325765	3609	Economy	14800.00
0005434325773	3609	Economy	14800.00
0005434325771	3609	Economy	14800.00
0005434325764	3609	Economy	14800.00
0005434325763	3609	Economy	14800.00
0005434325686	15618	Economy	16300.00
0005434325683	15618	Economy	14800.00
0005434325668	15618	Economy	14800.00
0005435889960	15618	Economy	14800.00
0005434325682	15618	Economy	14800.00
0005434325612	15618	Economy	14800.00
0005435889961	15618	Economy	14800.00
0005435889958	15618	Economy	14800.00
0005435889956	15618	Economy	14800.00
0005435889957	15618	Economy	14800.00
0005434325710	15618	Economy	14800.00
0005435889959	15618	Economy	14800.00
0005434325674	15618	Economy	14800.00
0005435889962	15618	Economy	14800.00
0005434325685	15618	Economy	14800.00
0005433420434	622	Economy	4500.00
0005433420411	622	Economy	4500.00
0005435957855	622	Economy	4100.00
0005435957854	622	Economy	4100.00
0005435957857	622	Economy	4100.00
0005435957858	622	Economy	4100.00
0005433420409	622	Economy	4100.00
0005433420410	622	Economy	4100.00
0005433420433	622	Economy	4100.00
0005433420407	622	Economy	4100.00
0005435957849	622	Economy	4100.00
0005433420412	622	Economy	4100.00
0005433420432	622	Economy	4100.00
0005435957856	622	Economy	4100.00
0005435957848	622	Economy	4100.00
0005433420408	622	Economy	4100.00
0005435957852	622	Economy	4100.00
0005435957859	622	Economy	4100.00
0005435957853	622	Economy	4100.00
0005435957850	622	Economy	4100.00
0005435957851	622	Economy	4100.00
0005433420414	622	Economy	4100.00
0005435957860	622	Economy	4100.00
0005435957749	15163	Economy	4500.00
0005433420486	15163	Economy	4500.00
0005435957769	15163	Economy	4500.00
0005435957756	15163	Economy	4100.00
0005435957683	15163	Economy	4100.00
0005435957686	15163	Economy	4100.00
0005433420490	15163	Economy	4100.00
0005435957727	15163	Economy	4100.00
0005435957774	15163	Economy	4100.00
0005435957697	15163	Economy	4100.00
0005435957721	15163	Economy	4100.00
0005435957689	15163	Economy	4100.00
0005435957729	15163	Economy	4100.00
0005435957730	15163	Economy	4100.00
0005435957690	15163	Economy	4100.00
0005433420488	15163	Economy	4100.00
0005435957770	15163	Economy	4100.00
0005433420487	15163	Economy	4100.00
0005433420485	15163	Economy	4100.00
0005435957650	15163	Economy	4100.00
0005435957785	15163	Economy	4100.00
0005433420493	15163	Economy	4100.00
0005433420491	15163	Economy	4100.00
0005433420492	15163	Economy	4100.00
0005435957687	15163	Economy	4100.00
0005435957755	15163	Economy	4100.00
0005435957768	15163	Economy	4100.00
0005435957657	15163	Economy	4100.00
0005435957685	15163	Economy	4100.00
0005435957728	15163	Economy	4100.00
0005433420489	15163	Economy	4100.00
0005434247145	8846	Economy	10400.00
0005434247157	8846	Economy	10400.00
0005434247151	8846	Economy	10400.00
0005434247158	8846	Economy	10400.00
0005434247147	8846	Economy	10400.00
0005434247174	16061	Economy	10400.00
0005434247175	16061	Economy	10400.00
0005434247173	16061	Economy	10400.00
0005434096745	11826	Economy	13400.00
0005434096739	11826	Economy	13400.00
0005434096746	11826	Economy	13400.00
0005434096736	11826	Economy	13400.00
0005434096729	11826	Economy	13400.00
0005434096742	11826	Economy	13400.00
0005434096738	11826	Economy	13400.00
0005434096762	20172	Economy	14700.00
0005434096758	20172	Economy	13400.00
0005434096759	20172	Economy	13400.00
0005434096763	20172	Economy	13400.00
0005434096760	20172	Economy	13400.00
0005434096761	20172	Economy	13400.00
0005434096764	20172	Economy	13400.00
0005432645945	25116	Business	87700.00
0005435229499	25116	Business	87700.00
0005432645970	25116	Business	87700.00
0005432645977	25116	Business	87700.00
0005432646030	25116	Business	87700.00
0005432645965	25116	Economy	29200.00
0005432645966	25116	Economy	29200.00
0005432645981	25116	Economy	29200.00
0005435229492	25116	Economy	29200.00
0005435229498	25116	Economy	29200.00
0005432645972	25116	Economy	29200.00
0005432646001	25116	Economy	29200.00
0005435229489	25116	Economy	32200.00
0005432646015	25116	Economy	32200.00
0005432646031	25116	Economy	32200.00
0005432645969	25116	Economy	32200.00
0005435229487	25116	Economy	29200.00
0005435229503	25116	Economy	29200.00
0005435229491	25116	Economy	29200.00
0005435229501	25116	Economy	29200.00
0005435229494	25116	Economy	29200.00
0005432645951	25116	Economy	29200.00
0005435229505	25116	Economy	29200.00
0005432645976	25116	Economy	29200.00
0005435229500	25116	Economy	29200.00
0005435229507	25116	Economy	29200.00
0005435229496	25116	Economy	29200.00
0005435229495	25116	Economy	29200.00
0005435229488	25116	Economy	29200.00
0005432645975	25116	Economy	29200.00
0005432645974	25116	Economy	29200.00
0005432645992	25116	Economy	29200.00
0005432645980	25116	Economy	29200.00
0005435229502	25116	Economy	29200.00
0005435229506	25116	Economy	29200.00
0005432645946	25116	Economy	29200.00
0005432645971	25116	Economy	29200.00
0005432645993	25116	Economy	29200.00
0005432645912	25116	Economy	29200.00
0005432646016	25116	Economy	29200.00
0005432645963	25116	Economy	29200.00
0005432645962	25116	Economy	29200.00
0005432645986	25116	Economy	29200.00
0005432646017	25116	Economy	29200.00
0005435229508	25116	Economy	29200.00
0005435229504	25116	Economy	29200.00
0005432645952	25116	Economy	29200.00
0005435229490	25116	Economy	29200.00
0005435229497	25116	Economy	29200.00
0005432645973	25116	Economy	29200.00
0005435229493	25116	Economy	29200.00
0005432645978	25116	Economy	29200.00
0005435797619	2856	Business	12600.00
0005435797617	2856	Business	12600.00
0005433404810	2856	Business	12600.00
0005433404833	2856	Business	12600.00
0005433404815	2856	Business	12600.00
0005435797621	2856	Business	12600.00
0005433404808	2856	Economy	4200.00
0005433404811	2856	Economy	4200.00
0005435797624	2856	Economy	4200.00
0005433404794	2856	Economy	4600.00
0005435797626	2856	Economy	4600.00
0005435797616	2856	Economy	4600.00
0005433404797	2856	Economy	4200.00
0005433404809	2856	Economy	4200.00
0005435797622	2856	Economy	4200.00
0005435797623	2856	Economy	4200.00
0005435797614	2856	Economy	4200.00
0005435797620	2856	Economy	4200.00
0005433404842	2856	Economy	4200.00
0005435797618	2856	Economy	4200.00
0005433404793	2856	Economy	4200.00
0005435797613	2856	Economy	4200.00
0005433404812	2856	Economy	4200.00
0005435797625	2856	Economy	4200.00
0005433404834	2856	Economy	4200.00
0005435797615	2856	Economy	4200.00
0005433404889	29351	Business	12600.00
0005435797472	29351	Business	12600.00
0005435797516	29351	Business	12600.00
0005435797456	29351	Business	12600.00
0005433404884	29351	Economy	4600.00
0005435797530	29351	Economy	4200.00
0005435797490	29351	Economy	4200.00
0005435797473	29351	Economy	4200.00
0005433404887	29351	Economy	4200.00
0005435797491	29351	Economy	4200.00
0005433404885	29351	Economy	4200.00
0005435797547	29351	Economy	4200.00
0005435797455	29351	Economy	4200.00
0005433404886	29351	Economy	4200.00
0005435797546	29351	Economy	4200.00
0005433404883	29351	Economy	4200.00
0005433404888	29351	Economy	4200.00
0005435797568	29351	Economy	4200.00
0005435797492	29351	Economy	4200.00
0005435376363	5784	Economy	6800.00
0005435376365	5784	Economy	6800.00
0005434948103	5783	Economy	6800.00
0005434948105	5783	Economy	6800.00
0005434948107	5783	Economy	6800.00
0005434948108	5783	Economy	6800.00
0005434948106	5783	Economy	6800.00
0005434948102	5783	Economy	6800.00
0005434948104	5783	Economy	6800.00
0005434948109	5783	Economy	6800.00
0005435376372	16318	Economy	6800.00
0005434948050	16318	Economy	6800.00
0005435376374	16318	Economy	6800.00
0005434948053	16318	Economy	6800.00
0005434948029	16318	Economy	6800.00
0005435376373	16318	Economy	6800.00
0005435376371	16318	Economy	6800.00
0005434948048	16318	Economy	6800.00
0005434948098	16318	Economy	6800.00
0005435376369	16318	Economy	6800.00
0005434948040	16318	Economy	6800.00
0005435376370	16318	Economy	6800.00
0005433961462	6858	Business	21400.00
0005433961441	6858	Business	21400.00
0005433961450	6858	Business	21400.00
0005433961429	6858	Business	21400.00
0005433961467	6858	Business	21400.00
0005433961446	6858	Business	21400.00
0005433961456	6858	Economy	7100.00
0005433961469	6858	Economy	7100.00
0005433961466	6858	Economy	7100.00
0005433961430	6858	Economy	7100.00
0005433961463	6858	Economy	7100.00
0005433961447	6858	Economy	7100.00
0005433961474	6858	Economy	7100.00
0005433961481	6858	Economy	7100.00
0005433961477	6858	Economy	7800.00
0005433961475	6858	Economy	7800.00
0005433961448	6858	Economy	7800.00
0005433961432	6858	Economy	7800.00
0005433961431	6858	Economy	7100.00
0005433961480	6858	Economy	7100.00
0005433961473	6858	Economy	7100.00
0005433961459	6858	Economy	7100.00
0005433961442	6858	Economy	7100.00
0005433961437	6858	Economy	7100.00
0005433961453	6858	Economy	7100.00
0005433961444	6858	Economy	7100.00
0005433961479	6858	Economy	7100.00
0005433961460	6858	Economy	7100.00
0005433961478	6858	Economy	7100.00
0005433961468	6858	Economy	7100.00
0005433961445	6858	Economy	7100.00
0005433961486	6858	Economy	7100.00
0005433961455	6858	Economy	7100.00
0005433961434	6858	Economy	7100.00
0005433961471	6858	Economy	7100.00
0005433961443	6858	Economy	7100.00
0005433961483	6858	Economy	7100.00
0005433961454	6858	Economy	7100.00
0005433961465	6858	Economy	7100.00
0005433961440	6858	Economy	7100.00
0005433961482	6858	Economy	7100.00
0005433961451	6858	Economy	7100.00
0005433961433	6858	Economy	7100.00
0005433961452	6858	Economy	7100.00
0005433961461	6858	Economy	7100.00
0005433961439	6858	Economy	7100.00
0005433961436	6858	Economy	7100.00
0005433961470	6858	Economy	7100.00
0005433961438	6858	Economy	7100.00
0005433961457	6858	Economy	7100.00
0005433961472	6858	Economy	7100.00
0005433961484	6858	Economy	7100.00
0005433961458	6858	Economy	7100.00
0005433961435	6858	Economy	7100.00
0005433961485	6858	Economy	7100.00
0005433961464	6858	Economy	7100.00
0005433961449	6858	Economy	7100.00
0005433961476	6858	Economy	7100.00
0005433960807	25698	Business	21400.00
0005433960771	25698	Business	21400.00
0005433960756	25698	Business	21400.00
0005433960682	25698	Business	21400.00
0005433960835	25698	Business	21400.00
0005433960810	25698	Business	21400.00
0005433960809	25698	Business	21400.00
0005433960803	25698	Economy	7100.00
0005433960757	25698	Economy	7100.00
0005433960721	25698	Economy	7100.00
0005433960772	25698	Economy	7100.00
0005433960746	25698	Economy	7100.00
0005433960530	25698	Economy	7100.00
0005433960783	25698	Economy	7800.00
0005433960792	25698	Economy	7800.00
0005433960720	25698	Economy	7800.00
0005433960777	25698	Economy	7800.00
0005433960739	25698	Economy	7100.00
0005433960824	25698	Economy	7100.00
0005433960794	25698	Economy	7100.00
0005433960759	25698	Economy	7100.00
0005433960671	25698	Economy	7100.00
0005433960776	25698	Economy	7100.00
0005433960710	25698	Economy	7100.00
0005433960800	25698	Economy	7100.00
0005433960775	25698	Economy	7100.00
0005433960804	25698	Economy	7100.00
0005433960821	25698	Economy	7100.00
0005433960799	25698	Economy	7100.00
0005433960631	25698	Economy	7100.00
0005433960842	25698	Economy	7100.00
0005433960749	25698	Economy	7100.00
0005433960802	25698	Economy	7100.00
0005433960670	25698	Economy	7100.00
0005433960632	25698	Economy	7100.00
0005433960741	25698	Economy	7100.00
0005433960833	25698	Economy	7100.00
0005433960846	25698	Economy	7100.00
0005433960724	25698	Economy	7100.00
0005433960396	25698	Economy	7100.00
0005433960740	25698	Economy	7100.00
0005433960811	25698	Economy	7100.00
0005433960770	25698	Economy	7100.00
0005433960843	25698	Economy	7100.00
0005433960732	25698	Economy	7100.00
0005433960734	25698	Economy	7100.00
0005433960737	25698	Economy	7100.00
0005433960806	25698	Economy	7100.00
0005433960531	25698	Economy	7100.00
0005433960778	25698	Economy	7100.00
0005433960755	25698	Economy	7100.00
0005433960848	25698	Economy	7100.00
0005433960767	25698	Economy	7100.00
0005433960768	25698	Economy	7100.00
0005433960719	25698	Economy	7100.00
0005433960733	25698	Economy	7100.00
0005433960752	25698	Economy	7100.00
0005433960742	25698	Economy	7100.00
0005435082784	24556	Economy	3900.00
0005435082779	24556	Economy	3900.00
0005435082786	24556	Economy	3900.00
0005435082788	24556	Economy	3900.00
0005435082812	24556	Economy	3900.00
0005435082799	24556	Economy	3900.00
0005435082781	24556	Economy	3900.00
0005435082778	24556	Economy	3900.00
0005435082801	24556	Economy	3900.00
0005435082793	24556	Economy	3900.00
0005435082811	24556	Economy	3900.00
0005435082800	24556	Economy	3900.00
0005435082857	26094	Economy	3900.00
0005435082858	26094	Economy	3900.00
0005435082860	26094	Economy	3900.00
0005435082859	26094	Economy	3900.00
0005435082862	26094	Economy	3900.00
0005435082863	26094	Economy	3900.00
0005435082861	26094	Economy	3900.00
0005434245277	5020	Business	18000.00
0005435286634	5020	Business	18000.00
0005434245287	5020	Business	18000.00
0005432166933	5020	Business	18000.00
0005434245285	5020	Business	18000.00
0005434245275	5020	Economy	6600.00
0005434245294	5020	Economy	6000.00
0005434245269	5020	Economy	6000.00
0005434245270	5020	Economy	6000.00
0005434245279	5020	Economy	6000.00
0005435286629	5020	Economy	6000.00
0005434245280	5020	Economy	6000.00
0005434245273	5020	Economy	6000.00
0005434245292	5020	Economy	6000.00
0005434245276	5020	Economy	6000.00
0005434245282	5020	Economy	6000.00
0005435286630	5020	Economy	6000.00
0005434245295	5020	Economy	6600.00
0005434245271	5020	Economy	6000.00
0005435286628	5020	Economy	6000.00
0005432166937	5020	Economy	6000.00
0005434245268	5020	Economy	6000.00
0005434245286	5020	Economy	6000.00
0005434245296	5020	Economy	6000.00
0005434245293	5020	Economy	6000.00
0005432166936	5020	Economy	6000.00
0005434245278	5020	Economy	6000.00
0005434245272	5020	Economy	6000.00
0005432166935	5020	Economy	6000.00
0005433534501	5020	Economy	6000.00
0005432166934	5020	Economy	6000.00
0005434245284	5020	Economy	6000.00
0005433534503	5020	Economy	6000.00
0005434245290	5020	Economy	6000.00
0005434245267	5020	Economy	6000.00
0005434245281	5020	Economy	6000.00
0005434245288	5020	Economy	6000.00
0005434245274	5020	Economy	6000.00
0005434245291	5020	Economy	6000.00
0005434245283	5020	Economy	6000.00
0005434245289	5020	Economy	6000.00
0005432106046	5021	Business	18000.00
0005433785333	5021	Business	18000.00
0005433615446	5021	Business	18000.00
0005432106056	5021	Business	18000.00
0005432666410	5021	Business	18000.00
0005432106055	5021	Business	18000.00
0005433615425	5021	Business	18000.00
0005433615464	5021	Business	18000.00
0005433615420	5021	Business	18000.00
0005432106047	5021	Business	18000.00
0005433615481	5021	Business	18000.00
0005433615457	5021	Business	18000.00
0005433615463	5021	Business	18000.00
0005433615459	5021	Business	18000.00
0005432106048	5021	Business	18000.00
0005433615424	5021	Business	18000.00
0005433615442	5021	Business	18000.00
0005433785324	5021	Business	18000.00
0005433785309	5021	Business	18000.00
0005432106054	5021	Business	18000.00
0005433615407	5021	Business	18000.00
0005432106074	5021	Business	18000.00
0005433615436	5021	Business	18000.00
0005432106066	5021	Business	18000.00
0005432106035	5021	Business	18000.00
0005432106051	5021	Business	18000.00
0005433615429	5021	Economy	6600.00
0005432106052	5021	Business	18000.00
0005432106038	5021	Economy	6600.00
0005432106057	5021	Economy	6600.00
0005433615417	5021	Economy	6600.00
0005433785331	5021	Economy	6600.00
0005433615466	5021	Economy	6600.00
0005433615456	5021	Economy	6000.00
0005433615410	5021	Economy	6000.00
0005432665296	5021	Economy	6000.00
0005432106037	5021	Economy	6000.00
0005433615478	5021	Economy	6000.00
0005433615421	5021	Economy	6000.00
0005433785332	5021	Economy	6000.00
0005433615458	5021	Economy	6000.00
0005432106059	5021	Economy	6000.00
0005433615460	5021	Economy	6000.00
0005432106075	5021	Economy	6000.00
0005433615409	5021	Economy	6000.00
0005433615451	5021	Economy	6000.00
0005433615476	5021	Economy	6000.00
0005433785312	5021	Economy	6000.00
0005433615430	5021	Economy	6000.00
0005433615437	5021	Economy	6000.00
0005432106078	5021	Economy	6000.00
0005433615434	5021	Economy	6000.00
0005433785307	5021	Economy	6000.00
0005433785323	5021	Economy	6000.00
0005432106081	5021	Economy	6000.00
0005432106073	5021	Economy	6000.00
0005433615439	5021	Economy	6000.00
0005433615408	5021	Economy	6000.00
0005432106041	5021	Economy	6000.00
0005432667475	5021	Economy	6000.00
0005433615413	5021	Economy	6000.00
0005432106040	5021	Economy	6000.00
0005432106060	5021	Economy	6000.00
0005433785326	5021	Economy	6000.00
0005432665297	5021	Economy	6000.00
0005433615469	5021	Economy	6000.00
0005433615438	5021	Economy	6000.00
0005433615477	5021	Economy	6000.00
0005433615472	5021	Economy	6000.00
0005433615423	5021	Economy	6000.00
0005432106034	5021	Economy	6000.00
0005433615475	5021	Economy	6000.00
0005432106062	5021	Economy	6000.00
0005432665295	5021	Economy	6000.00
0005433615479	5021	Economy	6000.00
0005432106063	5021	Economy	6000.00
0005433785334	5021	Economy	6000.00
0005432106072	5021	Economy	6000.00
0005433615448	5021	Economy	6000.00
0005433785310	5021	Economy	6000.00
0005432106082	5021	Economy	6000.00
0005432106069	5021	Economy	6000.00
0005432106039	5021	Economy	6000.00
0005433615441	5021	Economy	6000.00
0005432106064	5021	Economy	6000.00
0005433785321	5021	Economy	6000.00
0005433785303	5021	Economy	6000.00
0005433615449	5021	Economy	6000.00
0005433615428	5021	Economy	6000.00
0005433615470	5021	Economy	6000.00
0005433615447	5021	Economy	6000.00
0005433615440	5021	Economy	6000.00
0005432106077	5021	Economy	6600.00
0005433615467	5021	Economy	6600.00
0005432106068	5021	Economy	6600.00
0005433615455	5021	Economy	6600.00
0005432106049	5021	Economy	6600.00
0005433615427	5021	Economy	6000.00
0005433615454	5021	Economy	6000.00
0005433785316	5021	Economy	6000.00
0005433785328	5021	Economy	6000.00
0005432106036	5021	Economy	6000.00
0005433785301	5021	Economy	6600.00
0005433785300	5021	Economy	6000.00
0005433615474	5021	Economy	6000.00
0005433785329	5021	Economy	6000.00
0005433615462	5021	Economy	6000.00
0005433615471	5021	Economy	6000.00
0005433785305	5021	Economy	6000.00
0005432106065	5021	Economy	6000.00
0005433615461	5021	Economy	6000.00
0005432106076	5021	Economy	6000.00
0005433615411	5021	Economy	6000.00
0005433785318	5021	Economy	6000.00
0005433615435	5021	Economy	6000.00
0005433785298	5021	Economy	6000.00
0005432106044	5021	Economy	6000.00
0005433785335	5021	Economy	6000.00
0005433615445	5021	Economy	6000.00
0005433615465	5021	Economy	6000.00
0005433615412	5021	Economy	6000.00
0005433615450	5021	Economy	6000.00
0005433615431	5021	Economy	6000.00
0005433615415	5021	Economy	6000.00
0005433785327	5021	Economy	6000.00
0005433785322	5021	Economy	6000.00
0005433785299	5021	Economy	6000.00
0005433785306	5021	Economy	6000.00
0005433785311	5021	Economy	6000.00
0005433615426	5021	Economy	6000.00
0005433785325	5021	Economy	6000.00
0005433615418	5021	Economy	6000.00
0005433785319	5021	Economy	6000.00
0005433785302	5021	Economy	6000.00
0005432106042	5021	Economy	6000.00
0005433615419	5021	Economy	6000.00
0005433615414	5021	Economy	6000.00
0005432106067	5021	Economy	6000.00
0005432667474	5021	Economy	6000.00
0005433615480	5021	Economy	6000.00
0005433785320	5021	Economy	6000.00
0005433615473	5021	Economy	6000.00
0005432106058	5021	Economy	6000.00
0005433615416	5021	Economy	6000.00
0005433615468	5021	Economy	6000.00
0005433615433	5021	Economy	6000.00
0005432106043	5021	Economy	6000.00
0005432106045	5021	Economy	6000.00
0005433785330	5021	Economy	6000.00
0005432106071	5021	Economy	6000.00
0005433785314	5021	Economy	6000.00
0005433615452	5021	Economy	6000.00
0005433785313	5021	Economy	6000.00
0005433615444	5021	Economy	6000.00
0005433615443	5021	Economy	6000.00
0005433615432	5021	Economy	6000.00
0005432106079	5021	Economy	6000.00
0005432106061	5021	Economy	6000.00
0005433785304	5021	Economy	6000.00
0005433785317	5021	Economy	6000.00
0005433615453	5021	Economy	6000.00
0005433785308	5021	Economy	6000.00
0005433785315	5021	Economy	6000.00
0005433615422	5021	Economy	6000.00
0005432106050	5021	Economy	6000.00
0005432106053	5021	Economy	6000.00
0005432106070	5021	Economy	6000.00
0005432106080	5021	Economy	6000.00
0005435007023	5031	Business	18000.00
0005435007053	5031	Business	18000.00
0005434265406	5031	Business	18000.00
0005434149849	5031	Business	18000.00
0005434265392	5031	Business	18000.00
0005434229611	5031	Business	18000.00
0005432335973	5031	Business	18000.00
0005434265413	5031	Business	18000.00
0005435007054	5031	Business	18000.00
0005433815376	5031	Business	18000.00
0005434265398	5031	Business	18000.00
0005434229597	5031	Business	18000.00
0005434173560	5031	Business	18000.00
0005434265397	5031	Business	18000.00
0005434265409	5031	Business	18000.00
0005434265399	5031	Business	18000.00
0005435006996	5031	Economy	6600.00
0005434229605	5031	Economy	6600.00
0005434149854	5031	Economy	6600.00
0005434173563	5031	Economy	6600.00
0005434265410	5031	Economy	6600.00
0005434229595	5031	Economy	6600.00
0005434265412	5031	Economy	6000.00
0005434229609	5031	Economy	6000.00
0005432336019	5031	Economy	6000.00
0005434265405	5031	Economy	6000.00
0005435007000	5031	Economy	6000.00
0005434265393	5031	Economy	6000.00
0005432336075	5031	Economy	6000.00
0005434229593	5031	Economy	6000.00
0005434149847	5031	Economy	6000.00
0005434265408	5031	Economy	6000.00
0005434265407	5031	Economy	6000.00
0005434311219	5031	Economy	6000.00
0005434149845	5031	Economy	6000.00
0005434311220	5031	Economy	6000.00
0005434149855	5031	Economy	6000.00
0005435007057	5031	Economy	6000.00
0005434265400	5031	Economy	6000.00
0005435007115	5031	Economy	6000.00
0005434229612	5031	Economy	6000.00
0005434229599	5031	Economy	6000.00
0005435007092	5031	Economy	6000.00
0005432336061	5031	Economy	6000.00
0005434149848	5031	Economy	6000.00
0005434265411	5031	Economy	6000.00
0005434149851	5031	Economy	6000.00
0005434229600	5031	Economy	6000.00
0005434265390	5031	Economy	6000.00
0005434312311	5031	Economy	6000.00
0005434229602	5031	Economy	6000.00
0005435006997	5031	Economy	6000.00
0005432336059	5031	Economy	6000.00
0005434229594	5031	Economy	6000.00
0005435007081	5031	Economy	6000.00
0005435007064	5031	Economy	6000.00
0005434265404	5031	Economy	6000.00
0005435007058	5031	Economy	6000.00
0005435007056	5031	Economy	6000.00
0005432336078	5031	Economy	6000.00
0005435007006	5031	Economy	6000.00
0005433815404	5031	Economy	6000.00
0005435006998	5031	Economy	6000.00
0005434173562	5031	Economy	6000.00
0005435007007	5031	Economy	6000.00
0005432336085	5031	Economy	6000.00
0005434265394	5031	Economy	6000.00
0005434229592	5031	Economy	6600.00
0005433688818	5031	Economy	6600.00
0005433688810	5031	Economy	6600.00
0005434265403	5031	Economy	6000.00
0005435007044	5031	Economy	6000.00
0005434149852	5031	Economy	6000.00
0005435007129	5031	Economy	6000.00
0005434229591	5031	Economy	6000.00
0005432336041	5031	Economy	6000.00
0005434312331	5031	Economy	6000.00
0005434229596	5031	Economy	6000.00
0005434229603	5031	Economy	6000.00
0005435007149	5031	Economy	6000.00
0005434149856	5031	Economy	6000.00
0005434265389	5031	Economy	6000.00
0005432335975	5031	Economy	6000.00
0005434265401	5031	Economy	6000.00
0005435007112	5031	Economy	6000.00
0005433815377	5031	Economy	6000.00
0005434229608	5031	Economy	6000.00
0005434229610	5031	Economy	6000.00
0005434265395	5031	Economy	6000.00
0005434173561	5031	Economy	6000.00
0005435007024	5031	Economy	6000.00
0005434265415	5031	Economy	6000.00
0005434312332	5031	Economy	6000.00
0005434265414	5031	Economy	6000.00
0005434229598	5031	Economy	6000.00
0005434265396	5031	Economy	6000.00
0005434229601	5031	Economy	6000.00
0005435007093	5031	Economy	6000.00
0005434265402	5031	Economy	6000.00
0005434229607	5031	Economy	6000.00
0005435006999	5031	Economy	6000.00
0005434229606	5031	Economy	6000.00
0005432336042	5031	Economy	6000.00
0005435007063	5031	Economy	6000.00
0005432336079	5031	Economy	6000.00
0005435007148	5031	Economy	6000.00
0005435007128	5031	Economy	6000.00
0005435007150	5031	Economy	6000.00
0005434149846	5031	Economy	6000.00
0005435007001	5031	Economy	6000.00
0005435007082	5031	Economy	6000.00
0005432335957	5031	Economy	6000.00
0005432336069	5031	Economy	6000.00
0005434149853	5031	Economy	6000.00
0005435007083	5031	Economy	6000.00
0005432335974	5031	Economy	6000.00
0005434229604	5031	Economy	6000.00
0005434149850	5031	Economy	6000.00
0005434265391	5031	Economy	6000.00
0005434245092	8635	Business	18000.00
0005434245049	8635	Business	18000.00
0005434245125	8635	Business	18000.00
0005433784989	8635	Business	18000.00
0005432659708	8635	Business	18000.00
0005433785085	8635	Business	18000.00
0005433785075	8635	Business	18000.00
0005434245048	8635	Business	18000.00
0005435269813	8635	Business	18000.00
0005433784980	8635	Business	18000.00
0005433784962	8635	Business	18000.00
0005434245011	8635	Business	18000.00
0005435269818	8635	Business	18000.00
0005434245127	8635	Business	18000.00
0005433784997	8635	Business	18000.00
0005434244965	8635	Business	18000.00
0005433784831	8635	Business	18000.00
0005434245012	8635	Economy	6600.00
0005433784950	8635	Economy	6600.00
0005435269822	8635	Economy	6600.00
0005434245095	8635	Economy	6600.00
0005433784837	8635	Economy	6000.00
0005432663028	8635	Economy	6000.00
0005433785108	8635	Economy	6000.00
0005435269814	8635	Economy	6000.00
0005434245123	8635	Economy	6000.00
0005434245104	8635	Economy	6000.00
0005435269816	8635	Economy	6000.00
0005434245128	8635	Economy	6000.00
0005433785008	8635	Economy	6000.00
0005435269817	8635	Economy	6000.00
0005433785024	8635	Economy	6000.00
0005433785105	8635	Economy	6000.00
0005434245113	8635	Economy	6000.00
0005432663027	8635	Economy	6000.00
0005433784941	8635	Economy	6000.00
0005433785028	8635	Economy	6000.00
0005434245081	8635	Economy	6000.00
0005432666381	8635	Economy	6000.00
0005433784988	8635	Economy	6000.00
0005432666394	8635	Economy	6000.00
0005433784838	8635	Economy	6000.00
0005435269821	8635	Economy	6000.00
0005434245037	8635	Economy	6000.00
0005433784995	8635	Economy	6600.00
0005435269820	8635	Economy	6600.00
0005433784872	8635	Economy	6000.00
0005434245036	8635	Economy	6000.00
0005432663029	8635	Economy	6000.00
0005434245000	8635	Economy	6000.00
0005433785140	8635	Economy	6000.00
0005433784963	8635	Economy	6000.00
0005433785056	8635	Economy	6000.00
0005433784942	8635	Economy	6000.00
0005434245112	8635	Economy	6000.00
0005433785123	8635	Economy	6000.00
0005433785150	8635	Economy	6000.00
0005434245129	8635	Economy	6000.00
0005432659701	8635	Economy	6000.00
0005434245111	8635	Economy	6000.00
0005434245020	8635	Economy	6000.00
0005433784964	8635	Economy	6000.00
0005434245044	8635	Economy	6000.00
0005433784874	8635	Economy	6000.00
0005434245124	8635	Economy	6000.00
0005433784873	8635	Economy	6000.00
0005434245001	8635	Economy	6000.00
0005433785106	8635	Economy	6000.00
0005432659707	8635	Economy	6000.00
0005435269815	8635	Economy	6000.00
0005434245085	8635	Economy	6000.00
0005433785064	8635	Economy	6000.00
0005435269823	8635	Economy	6000.00
0005435269819	8635	Economy	6000.00
0005433784972	8635	Economy	6000.00
0005434245052	8635	Economy	6000.00
0005434245091	8635	Economy	6000.00
0005433784979	8635	Economy	6000.00
0005433614675	8636	Business	18000.00
0005433614926	8636	Business	18000.00
0005433614519	8636	Business	18000.00
0005433614893	8636	Business	18000.00
0005433614703	8636	Business	18000.00
0005433614464	8636	Business	18000.00
0005433615030	8636	Business	18000.00
0005433614545	8636	Business	18000.00
0005433614707	8636	Business	18000.00
0005433614866	8636	Business	18000.00
0005433614672	8636	Business	18000.00
0005433615107	8636	Business	18000.00
0005433614657	8636	Economy	6600.00
0005433614684	8636	Economy	6600.00
0005433615012	8636	Economy	6000.00
0005433614671	8636	Economy	6000.00
0005433614536	8636	Economy	6000.00
0005433614797	8636	Economy	6000.00
0005433614660	8636	Economy	6000.00
0005433614966	8636	Economy	6000.00
0005433614718	8636	Economy	6000.00
0005433614554	8636	Economy	6000.00
0005433614725	8636	Economy	6000.00
0005433614799	8636	Economy	6000.00
0005433614622	8636	Economy	6000.00
0005433614967	8636	Economy	6000.00
0005433614698	8636	Economy	6000.00
0005433614971	8636	Economy	6000.00
0005433615014	8636	Economy	6000.00
0005433614959	8636	Economy	6000.00
0005433614555	8636	Economy	6000.00
0005433614670	8636	Economy	6000.00
0005433614809	8636	Economy	6000.00
0005433614702	8636	Economy	6000.00
0005433614864	8636	Economy	6000.00
0005433615101	8636	Economy	6000.00
0005433614788	8636	Economy	6000.00
0005433614945	8636	Economy	6000.00
0005433615013	8636	Economy	6000.00
0005433614561	8636	Economy	6000.00
0005433614803	8636	Economy	6000.00
0005433614986	8636	Economy	6000.00
0005433614902	8636	Economy	6000.00
0005433615031	8636	Economy	6600.00
0005433614925	8636	Economy	6600.00
0005433614717	8636	Economy	6600.00
0005433614872	8636	Economy	6000.00
0005433614514	8636	Economy	6000.00
0005433614951	8636	Economy	6000.00
0005433615024	8636	Economy	6000.00
0005433614924	8636	Economy	6000.00
0005433614756	8636	Economy	6000.00
0005433614550	8636	Economy	6000.00
0005433614996	8636	Economy	6000.00
0005433614461	8636	Economy	6000.00
0005433614704	8636	Economy	6000.00
0005433614798	8636	Economy	6000.00
0005433614535	8636	Economy	6000.00
0005433614640	8636	Economy	6000.00
0005433614518	8636	Economy	6000.00
0005433614846	8636	Economy	6000.00
0005433614674	8636	Economy	6000.00
0005433614513	8636	Economy	6000.00
0005433614373	8636	Economy	6000.00
0005433614845	8636	Economy	6000.00
0005433614534	8636	Economy	6000.00
0005433614757	8636	Economy	6000.00
0005433614789	8636	Economy	6000.00
0005433615059	8636	Economy	6000.00
0005433615029	8636	Economy	6000.00
0005433614943	8636	Economy	6000.00
0005433615111	8636	Economy	6000.00
0005433614865	8636	Economy	6000.00
0005433614706	8636	Economy	6000.00
0005433614940	8636	Economy	6000.00
0005433614701	8636	Economy	6000.00
0005433614901	8636	Economy	6000.00
0005433614685	8636	Economy	6000.00
0005433614527	8636	Economy	6000.00
0005433614661	8636	Economy	6000.00
0005433614869	8636	Economy	6000.00
0005432035245	8637	Business	18000.00
0005435007266	8637	Business	18000.00
0005433690946	8637	Business	18000.00
0005435007264	8637	Business	18000.00
0005432035224	8637	Business	18000.00
0005435007267	8637	Business	18000.00
0005434149736	8637	Business	18000.00
0005433688831	8637	Business	18000.00
0005435007257	8637	Business	18000.00
0005432336160	8637	Business	18000.00
0005434229413	8637	Business	18000.00
0005435007272	8637	Business	18000.00
0005434149754	8637	Business	18000.00
0005432035247	8637	Business	18000.00
0005433815437	8637	Business	18000.00
0005434265058	8637	Business	18000.00
0005435286672	8637	Business	18000.00
0005434265044	8637	Business	18000.00
0005434265260	8637	Business	18000.00
0005434149740	8637	Business	18000.00
0005435007263	8637	Business	18000.00
0005434229446	8637	Business	18000.00
0005435007269	8637	Business	18000.00
0005434229412	8637	Business	18000.00
0005435007253	8637	Economy	6600.00
0005433688830	8637	Economy	6600.00
0005432035227	8637	Economy	6600.00
0005434265164	8637	Economy	6600.00
0005434149714	8637	Economy	6600.00
0005435007274	8637	Economy	6600.00
0005434229444	8637	Economy	6000.00
0005434265129	8637	Economy	6000.00
0005435007261	8637	Economy	6000.00
0005434229388	8637	Economy	6000.00
0005435286670	8637	Economy	6000.00
0005432035237	8637	Economy	6000.00
0005432336162	8637	Economy	6000.00
0005432035225	8637	Economy	6000.00
0005434265193	8637	Economy	6000.00
0005434265144	8637	Economy	6000.00
0005432035220	8637	Economy	6000.00
0005434229425	8637	Economy	6000.00
0005434229445	8637	Economy	6000.00
0005433815438	8637	Economy	6000.00
0005434229410	8637	Economy	6000.00
0005434229473	8637	Economy	6000.00
0005432336159	8637	Economy	6000.00
0005435007268	8637	Economy	6000.00
0005434265069	8637	Economy	6000.00
0005432336155	8637	Economy	6000.00
0005435007259	8637	Economy	6000.00
0005434265170	8637	Economy	6000.00
0005434265192	8637	Economy	6000.00
0005434149721	8637	Economy	6000.00
0005432035231	8637	Economy	6000.00
0005433815435	8637	Economy	6000.00
0005434149800	8637	Economy	6000.00
0005434229386	8637	Economy	6000.00
0005434265136	8637	Economy	6000.00
0005435007258	8637	Economy	6000.00
0005435007270	8637	Economy	6000.00
0005432035232	8637	Economy	6000.00
0005432047587	8637	Economy	6000.00
0005435286673	8637	Economy	6000.00
0005432035233	8637	Economy	6000.00
0005435007275	8637	Economy	6000.00
0005433534519	8637	Economy	6000.00
0005432035230	8637	Economy	6000.00
0005432047590	8637	Economy	6000.00
0005432035246	8637	Economy	6000.00
0005433815439	8637	Economy	6000.00
0005434311240	8637	Economy	6000.00
0005432035242	8637	Economy	6000.00
0005435007256	8637	Economy	6000.00
0005434229396	8637	Economy	6000.00
0005434149799	8637	Economy	6000.00
0005432035243	8637	Economy	6000.00
0005432035219	8637	Economy	6000.00
0005433534520	8637	Economy	6000.00
0005432035229	8637	Economy	6000.00
0005434173536	8637	Economy	6000.00
0005434311241	8637	Economy	6000.00
0005435007262	8637	Economy	6000.00
0005434229383	8637	Economy	6000.00
0005432336156	8637	Economy	6000.00
0005434173540	8637	Economy	6600.00
0005434229426	8637	Economy	6600.00
0005435007265	8637	Economy	6600.00
0005432035236	8637	Economy	6600.00
0005435007273	8637	Economy	6600.00
0005434265135	8637	Economy	6000.00
0005434229403	8637	Economy	6000.00
0005435286671	8637	Economy	6000.00
0005432035234	8637	Economy	6000.00
0005433815434	8637	Economy	6000.00
0005432336158	8637	Economy	6600.00
0005434149726	8637	Economy	6000.00
0005434149759	8637	Economy	6000.00
0005434149713	8637	Economy	6000.00
0005434229385	8637	Economy	6000.00
0005432035223	8637	Economy	6000.00
0005435007260	8637	Economy	6000.00
0005432035235	8637	Economy	6000.00
0005432035226	8637	Economy	6000.00
0005434229434	8637	Economy	6000.00
0005434265181	8637	Economy	6000.00
0005432047591	8637	Economy	6000.00
0005435007254	8637	Economy	6000.00
0005432035238	8637	Economy	6000.00
0005434229435	8637	Economy	6000.00
0005432336157	8637	Economy	6000.00
0005435286675	8637	Economy	6000.00
0005432035221	8637	Economy	6000.00
0005434149801	8637	Economy	6000.00
0005432035228	8637	Economy	6000.00
0005434149749	8637	Economy	6000.00
0005434173537	8637	Economy	6000.00
0005434229356	8637	Economy	6000.00
0005433688833	8637	Economy	6000.00
0005432047588	8637	Economy	6000.00
0005432336153	8637	Economy	6000.00
0005432047589	8637	Economy	6000.00
0005435007276	8637	Economy	6000.00
0005432035222	8637	Economy	6000.00
0005434229389	8637	Economy	6000.00
0005434149720	8637	Economy	6000.00
0005434149735	8637	Economy	6000.00
0005435007277	8637	Economy	6000.00
0005434265043	8637	Economy	6000.00
0005434149752	8637	Economy	6000.00
0005434265213	8637	Economy	6000.00
0005432336152	8637	Economy	6000.00
0005433815436	8637	Economy	6000.00
0005434229395	8637	Economy	6000.00
0005433690945	8637	Economy	6000.00
0005434229376	8637	Economy	6000.00
0005432035241	8637	Economy	6000.00
0005434265259	8637	Economy	6000.00
0005434149768	8637	Economy	6000.00
0005435007255	8637	Economy	6000.00
0005435007271	8637	Economy	6000.00
0005435286674	8637	Economy	6000.00
0005434229436	8637	Economy	6000.00
0005432336154	8637	Economy	6000.00
0005434265165	8637	Economy	6000.00
0005432035248	8637	Economy	6000.00
0005432336161	8637	Economy	6000.00
0005432035244	8637	Economy	6000.00
0005433688832	8637	Economy	6000.00
0005434229384	8637	Economy	6000.00
0005432035239	8637	Economy	6000.00
0005432035240	8637	Economy	6000.00
0005433534521	8637	Economy	6000.00
0005434639420	12635	Economy	16200.00
0005433202513	12635	Economy	16200.00
0005434639426	12635	Economy	16200.00
0005433202523	12635	Economy	16200.00
0005433202522	12635	Economy	14800.00
0005433202516	12635	Economy	14800.00
0005434639399	12635	Economy	14800.00
0005434639419	12635	Economy	14800.00
0005434639313	12635	Economy	14800.00
0005434639301	12635	Economy	14800.00
0005434639327	12635	Economy	14800.00
0005434639322	12635	Economy	14800.00
0005433202510	12635	Economy	14800.00
0005434639287	12635	Economy	14800.00
0005434639383	12635	Economy	14800.00
0005433202511	12635	Economy	14800.00
0005434639368	12635	Economy	14800.00
0005434639423	12635	Economy	14800.00
0005434639276	12635	Economy	14800.00
0005434639396	12635	Economy	14800.00
0005434639359	12635	Economy	14800.00
0005434639334	12635	Economy	14800.00
0005433202520	12635	Economy	14800.00
0005434639414	12635	Economy	14800.00
0005434639323	12635	Economy	14800.00
0005434639406	12635	Economy	14800.00
0005434639395	12635	Economy	14800.00
0005434639405	12635	Economy	14800.00
0005433202512	12635	Economy	14800.00
0005434639366	12635	Economy	14800.00
0005434639286	12635	Economy	14800.00
0005434639398	12635	Economy	14800.00
0005434639367	12635	Economy	14800.00
0005434639425	12635	Economy	14800.00
0005434639312	12635	Economy	14800.00
0005433202514	12635	Economy	14800.00
0005434639384	12635	Economy	14800.00
0005433202521	12635	Economy	14800.00
0005434639277	12635	Economy	14800.00
0005433202519	12635	Economy	14800.00
0005433202517	12635	Economy	14800.00
0005433202509	12635	Economy	14800.00
0005433202518	12635	Economy	14800.00
0005434639447	12635	Economy	14800.00
0005434639365	12635	Economy	14800.00
0005434639446	12635	Economy	14800.00
0005434639328	12635	Economy	14800.00
0005433202515	12635	Economy	14800.00
0005434639407	12635	Economy	14800.00
0005434639558	23356	Economy	16200.00
0005433202350	23356	Economy	16200.00
0005433202384	23356	Economy	16200.00
0005434639557	23356	Economy	16200.00
0005433202360	23356	Economy	14800.00
0005433202398	23356	Economy	14800.00
0005433202359	23356	Economy	14800.00
0005434639571	23356	Economy	14800.00
0005434639564	23356	Economy	14800.00
0005434639565	23356	Economy	14800.00
0005433202303	23356	Economy	14800.00
0005434639549	23356	Economy	14800.00
0005434639552	23356	Economy	14800.00
0005432290661	23356	Economy	14800.00
0005434639572	23356	Economy	14800.00
0005432290663	23356	Economy	14800.00
0005434639570	23356	Economy	14800.00
0005433202351	23356	Economy	14800.00
0005433202358	23356	Economy	14800.00
0005433202355	23356	Economy	14800.00
0005433202417	23356	Economy	14800.00
0005434639551	23356	Economy	14800.00
0005434639559	23356	Economy	14800.00
0005433202418	23356	Economy	14800.00
0005434639567	23356	Economy	14800.00
0005434639553	23356	Economy	14800.00
0005434639563	23356	Economy	14800.00
0005433202309	23356	Economy	14800.00
0005434639554	23356	Economy	14800.00
0005433202298	23356	Economy	14800.00
0005433202295	23356	Economy	14800.00
0005433202356	23356	Economy	14800.00
0005433202366	23356	Economy	14800.00
0005434639562	23356	Economy	14800.00
0005434639550	23356	Economy	14800.00
0005434639569	23356	Economy	14800.00
0005432290662	23356	Economy	14800.00
0005434639555	23356	Economy	14800.00
0005433202368	23356	Economy	14800.00
0005434639560	23356	Economy	14800.00
0005433202385	23356	Economy	14800.00
0005434639556	23356	Economy	14800.00
0005433202361	23356	Economy	14800.00
0005433202428	23356	Economy	14800.00
0005434639568	23356	Economy	14800.00
0005433202369	23356	Economy	14800.00
0005433202370	23356	Economy	14800.00
0005434639561	23356	Economy	14800.00
0005434639566	23356	Economy	14800.00
0005432383147	21069	Business	18900.00
0005432328777	21069	Business	18900.00
0005432382995	21069	Business	18900.00
0005432383121	21069	Business	18900.00
0005432383278	21069	Business	18900.00
0005432328699	21069	Business	18900.00
0005432054335	21069	Business	18900.00
0005432328712	21069	Business	18900.00
0005432328697	21069	Business	18900.00
0005432328721	21069	Business	18900.00
0005432383117	21069	Business	18900.00
0005432328819	21069	Business	18900.00
0005432383084	21069	Economy	6300.00
0005432328689	21069	Economy	6300.00
0005432328842	21069	Economy	6300.00
0005432328776	21069	Economy	6300.00
0005432383116	21069	Economy	6300.00
0005432328829	21069	Economy	6300.00
0005432383312	21069	Economy	6300.00
0005432328874	21069	Economy	6300.00
0005432383150	21069	Economy	6300.00
0005432328640	21069	Economy	6300.00
0005432383016	21069	Economy	6900.00
0005432383154	21069	Economy	6900.00
0005432328604	21069	Economy	6900.00
0005432328845	21069	Economy	6900.00
0005432328843	21069	Economy	6300.00
0005432383202	21069	Economy	6300.00
0005432383306	21069	Economy	6300.00
0005432383260	21069	Economy	6300.00
0005432328554	21069	Economy	6300.00
0005432328967	21069	Economy	6300.00
0005432383171	21069	Economy	6300.00
0005432328798	21069	Economy	6300.00
0005432328696	21069	Economy	6300.00
0005432383311	21069	Economy	6300.00
0005432054334	21069	Economy	6300.00
0005432328757	21069	Economy	6300.00
0005432328794	21069	Economy	6300.00
0005432383269	21069	Economy	6300.00
0005432328966	21069	Economy	6300.00
0005432382996	21069	Economy	6300.00
0005432383043	21069	Economy	6300.00
0005432383095	21069	Economy	6300.00
0005432328610	21069	Economy	6300.00
0005432383242	21069	Economy	6300.00
0005432328709	21069	Economy	6300.00
0005432328818	21069	Economy	6300.00
0005432383153	21069	Economy	6300.00
0005432328965	21069	Economy	6300.00
0005432328805	21069	Economy	6300.00
0005432383096	21069	Economy	6300.00
0005432328804	21069	Economy	6300.00
0005432383183	21069	Economy	6300.00
0005432328607	21069	Economy	6300.00
0005432383149	21069	Economy	6300.00
0005432328917	21069	Economy	6300.00
0005432383148	21069	Economy	6300.00
0005432328706	21069	Economy	6300.00
0005432383042	21069	Economy	6300.00
0005432328768	21069	Economy	6300.00
0005432328838	21069	Economy	6300.00
0005432383264	21069	Economy	6300.00
0005432328722	21069	Economy	6300.00
0005432383268	21069	Economy	6300.00
0005432328734	21069	Economy	6300.00
0005432383152	21069	Economy	6300.00
0005432383191	21069	Economy	6300.00
0005432383241	21069	Economy	6300.00
0005432383237	21069	Economy	6300.00
0005432328841	21069	Economy	6300.00
0005432383232	21069	Economy	6300.00
0005432328744	21069	Economy	6300.00
0005432383276	21069	Economy	6300.00
0005432383170	21069	Economy	6300.00
0005432328606	21069	Economy	6300.00
0005432383277	21069	Economy	6300.00
0005432383243	21069	Economy	6300.00
0005432328756	21069	Economy	6300.00
0005432328553	21069	Economy	6300.00
0005432328662	21069	Economy	6300.00
0005432328698	21069	Economy	6300.00
0005432328750	21069	Economy	6300.00
0005432383203	21069	Economy	6300.00
0005432328952	21069	Economy	6300.00
0005432383198	21069	Economy	6300.00
0005432328968	21069	Economy	6300.00
0005432383238	21069	Economy	6300.00
0005432383100	21069	Economy	6300.00
0005432328817	21069	Economy	6300.00
0005432383132	21069	Economy	6300.00
0005432328906	21069	Economy	6300.00
0005432383239	21069	Economy	6300.00
0005432328830	21069	Economy	6300.00
0005432383164	21069	Economy	6300.00
0005432383099	21069	Economy	6300.00
0005432329151	31239	Business	18900.00
0005432383569	31239	Business	18900.00
0005432383554	31239	Business	18900.00
0005432383549	31239	Business	18900.00
0005432329123	31239	Business	18900.00
0005432383551	31239	Business	18900.00
0005432329118	31239	Business	18900.00
0005432329122	31239	Business	18900.00
0005432383534	31239	Business	18900.00
0005432329156	31239	Business	18900.00
0005432383538	31239	Economy	6300.00
0005432329146	31239	Economy	6300.00
0005432383570	31239	Economy	6300.00
0005432329133	31239	Economy	6300.00
0005432329141	31239	Economy	6300.00
0005432383552	31239	Economy	6300.00
0005432329136	31239	Economy	6300.00
0005432329127	31239	Economy	6300.00
0005432329112	31239	Economy	6300.00
0005432329157	31239	Economy	6900.00
0005432383563	31239	Economy	6900.00
0005432329119	31239	Economy	6900.00
0005432383547	31239	Economy	6900.00
0005432383535	31239	Economy	6900.00
0005432329137	31239	Economy	6300.00
0005432383548	31239	Economy	6300.00
0005432383553	31239	Economy	6300.00
0005432329115	31239	Economy	6300.00
0005432329121	31239	Economy	6300.00
0005432329139	31239	Economy	6300.00
0005432383537	31239	Economy	6300.00
0005432383561	31239	Economy	6300.00
0005432329130	31239	Economy	6300.00
0005432329145	31239	Economy	6300.00
0005432383543	31239	Economy	6300.00
0005432329116	31239	Economy	6300.00
0005432329134	31239	Economy	6300.00
0005432329132	31239	Economy	6300.00
0005432329158	31239	Economy	6300.00
0005432329120	31239	Economy	6300.00
0005432383565	31239	Economy	6300.00
0005432383533	31239	Economy	6300.00
0005432383542	31239	Economy	6300.00
0005432383562	31239	Economy	6300.00
0005432329150	31239	Economy	6300.00
0005432329143	31239	Economy	6300.00
0005432383550	31239	Economy	6300.00
0005432383558	31239	Economy	6300.00
0005432329148	31239	Economy	6300.00
0005432329144	31239	Economy	6300.00
0005432287235	31239	Economy	6300.00
0005432329142	31239	Economy	6300.00
0005432383559	31239	Economy	6300.00
0005432329131	31239	Economy	6300.00
0005432383555	31239	Economy	6300.00
0005432383557	31239	Economy	6300.00
0005432383568	31239	Economy	6300.00
0005432329152	31239	Economy	6300.00
0005432329149	31239	Economy	6300.00
0005432329135	31239	Economy	6300.00
0005432329126	31239	Economy	6300.00
0005432383556	31239	Economy	6300.00
0005432383560	31239	Economy	6300.00
0005432383544	31239	Economy	6300.00
0005432329128	31239	Economy	6300.00
0005432383536	31239	Economy	6300.00
0005432383545	31239	Economy	6300.00
0005432383567	31239	Economy	6300.00
0005432329155	31239	Economy	6300.00
0005432329153	31239	Economy	6300.00
0005432383541	31239	Economy	6300.00
0005432287238	31239	Economy	6300.00
0005432383539	31239	Economy	6300.00
0005432329113	31239	Economy	6300.00
0005432383540	31239	Economy	6300.00
0005432287239	31239	Economy	6300.00
0005432329117	31239	Economy	6300.00
0005432329125	31239	Economy	6300.00
0005432383566	31239	Economy	6300.00
0005432329147	31239	Economy	6300.00
0005432329154	31239	Economy	6300.00
0005432383564	31239	Economy	6300.00
0005432329114	31239	Economy	6300.00
0005432383546	31239	Economy	6300.00
0005432329124	31239	Economy	6300.00
0005432329140	31239	Economy	6300.00
0005432329129	31239	Economy	6300.00
0005432329138	31239	Economy	6300.00
0005432287236	31239	Economy	6300.00
0005432287237	31239	Economy	6300.00
0005433642258	27582	Business	89600.00
0005433642418	27582	Business	89600.00
0005433642271	27582	Business	89600.00
0005433642382	27582	Business	89600.00
0005433642320	27582	Business	89600.00
0005432954021	27582	Business	89600.00
0005432954014	27582	Economy	29900.00
0005432954017	27582	Economy	29900.00
0005433642376	27582	Economy	29900.00
0005433642314	27582	Economy	29900.00
0005433642406	27582	Economy	29900.00
0005433642307	27582	Economy	29900.00
0005432954020	27582	Economy	32800.00
0005432954012	27582	Economy	32800.00
0005432954023	27582	Economy	32800.00
0005433642407	27582	Economy	29900.00
0005433642380	27582	Economy	29900.00
0005432954022	27582	Economy	29900.00
0005432954028	27582	Economy	29900.00
0005433642342	27582	Economy	29900.00
0005433642411	27582	Economy	29900.00
0005432954019	27582	Economy	29900.00
0005433642351	27582	Economy	29900.00
0005432954013	27582	Economy	29900.00
0005432954015	27582	Economy	29900.00
0005433642362	27582	Economy	29900.00
0005433642383	27582	Economy	29900.00
0005432954026	27582	Economy	29900.00
0005432954024	27582	Economy	29900.00
0005433642328	27582	Economy	29900.00
0005433642329	27582	Economy	29900.00
0005433642410	27582	Economy	29900.00
0005433642324	27582	Economy	29900.00
0005433642372	27582	Economy	29900.00
0005433642389	27582	Economy	29900.00
0005433642313	27582	Economy	29900.00
0005432954027	27582	Economy	29900.00
0005432954016	27582	Economy	29900.00
0005432954018	27582	Economy	29900.00
0005433642308	27582	Economy	29900.00
0005433642343	27582	Economy	29900.00
0005433642371	27582	Economy	29900.00
0005433642388	27582	Economy	29900.00
0005433642419	27582	Economy	29900.00
0005433642330	27582	Economy	29900.00
0005433642327	27582	Economy	29900.00
0005432954025	27582	Economy	29900.00
0005433642341	27582	Economy	29900.00
0005432424891	13290	Business	12700.00
0005432424870	13290	Business	12700.00
0005432424898	13290	Business	12700.00
0005432424866	13290	Business	12700.00
0005432424872	13290	Business	12700.00
0005432424892	13290	Business	12700.00
0005432424906	13290	Business	12700.00
0005432424903	13290	Business	12700.00
0005432424910	13290	Economy	4200.00
0005432424868	13290	Economy	4200.00
0005432424907	13290	Economy	4200.00
0005432424885	13290	Economy	4200.00
0005432424900	13290	Economy	4200.00
0005432424890	13290	Economy	4200.00
0005432424878	13290	Economy	4200.00
0005432424880	13290	Economy	4200.00
0005432424887	13290	Economy	4200.00
0005432424893	13290	Economy	4200.00
0005432424901	13290	Economy	4200.00
0005432424911	13290	Economy	4200.00
0005432424914	13290	Economy	4200.00
0005432424894	13290	Economy	4200.00
0005432424874	13290	Economy	4200.00
0005432424875	13290	Economy	4200.00
0005432424909	13290	Economy	4200.00
0005432424895	13290	Economy	4200.00
0005432424902	13290	Economy	4200.00
0005432424873	13290	Economy	4200.00
0005432424867	13290	Economy	4200.00
0005432424905	13290	Economy	4200.00
0005432424886	13290	Economy	4200.00
0005432424879	13290	Economy	4200.00
0005432424882	13290	Economy	4200.00
0005432424896	13290	Economy	4200.00
0005432424908	13290	Economy	4200.00
0005432424883	13290	Economy	4200.00
0005432424897	13290	Economy	4200.00
0005432424864	13290	Economy	4200.00
0005432424881	13290	Economy	4200.00
0005432424865	13290	Economy	4200.00
0005432424913	13290	Economy	4200.00
0005432424869	13290	Economy	4200.00
0005432424871	13290	Economy	4200.00
0005432424899	13290	Economy	4200.00
0005432424912	13290	Economy	4200.00
0005432424888	13290	Economy	4200.00
0005432424876	13290	Economy	4200.00
0005432424884	13290	Economy	4200.00
0005432424877	13290	Economy	4200.00
0005432424889	13290	Economy	4200.00
0005432424904	13290	Economy	4200.00
0005432424516	30741	Business	12700.00
0005432424407	30741	Business	12700.00
0005432424507	30741	Business	12700.00
0005432424513	30741	Business	12700.00
0005432424429	30741	Business	12700.00
0005432424293	30741	Business	12700.00
0005432424483	30741	Business	12700.00
0005432424415	30741	Business	12700.00
0005432424426	30741	Economy	4200.00
0005432424313	30741	Economy	4200.00
0005432424490	30741	Economy	4200.00
0005432424477	30741	Economy	4200.00
0005432424344	30741	Economy	4700.00
0005432424484	30741	Economy	4700.00
0005432424231	30741	Economy	4700.00
0005432424274	30741	Economy	4700.00
0005432424377	30741	Economy	4200.00
0005432424400	30741	Economy	4200.00
0005432424456	30741	Economy	4200.00
0005432424497	30741	Economy	4200.00
0005432424481	30741	Economy	4200.00
0005432424445	30741	Economy	4200.00
0005432424406	30741	Economy	4200.00
0005432424501	30741	Economy	4200.00
0005432424312	30741	Economy	4200.00
0005432424433	30741	Economy	4200.00
0005432424294	30741	Economy	4200.00
0005432424309	30741	Economy	4200.00
0005432424446	30741	Economy	4200.00
0005432424478	30741	Economy	4200.00
0005432424414	30741	Economy	4200.00
0005432424349	30741	Economy	4200.00
0005432424405	30741	Economy	4200.00
0005432424261	30741	Economy	4200.00
0005432424453	30741	Economy	4200.00
0005432424275	30741	Economy	4200.00
0005432424506	30741	Economy	4200.00
0005432424273	30741	Economy	4200.00
0005432424505	30741	Economy	4200.00
0005432424461	30741	Economy	4200.00
0005432424328	30741	Economy	4200.00
0005432424452	30741	Economy	4200.00
0005432424511	30741	Economy	4200.00
0005432424359	30741	Economy	4200.00
0005432424376	30741	Economy	4200.00
0005432424479	30741	Economy	4200.00
0005432424500	30741	Economy	4200.00
0005432817787	9617	Business	32600.00
0005432822280	9617	Business	32600.00
0005432817778	9617	Business	32600.00
0005432817784	9617	Business	32600.00
0005434448351	9617	Business	32600.00
0005432817772	9617	Business	32600.00
0005432822282	9617	Business	32600.00
0005432817761	9617	Business	32600.00
0005432822283	9617	Business	32600.00
0005434186208	9617	Economy	10900.00
0005432289019	9617	Economy	10900.00
0005434157508	9617	Economy	10900.00
0005432817783	9617	Economy	10900.00
0005432817775	9617	Economy	10900.00
0005432901586	9617	Economy	10900.00
0005434157501	9617	Economy	10900.00
0005432817769	9617	Economy	11900.00
0005432817786	9617	Economy	11900.00
0005432817773	9617	Economy	11900.00
0005432289018	9617	Economy	11900.00
0005432817765	9617	Economy	10900.00
0005432901680	9617	Economy	10900.00
0005432901660	9617	Economy	10900.00
0005432901648	9617	Economy	10900.00
0005432817774	9617	Economy	10900.00
0005432817777	9617	Economy	10900.00
0005432817759	9617	Economy	10900.00
0005432817766	9617	Economy	10900.00
0005432901659	9617	Economy	10900.00
0005432822284	9617	Economy	10900.00
0005432817762	9617	Economy	10900.00
0005432817776	9617	Economy	10900.00
0005432817771	9617	Economy	10900.00
0005432817768	9617	Economy	10900.00
0005432901646	9617	Economy	10900.00
0005432817760	9617	Economy	10900.00
0005432901644	9617	Economy	10900.00
0005432817779	9617	Economy	10900.00
0005432817780	9617	Economy	10900.00
0005432817758	9617	Economy	10900.00
0005432901621	9617	Economy	10900.00
0005432817767	9617	Economy	10900.00
0005432901651	9617	Economy	10900.00
0005432822281	9617	Economy	10900.00
0005432822285	9617	Economy	10900.00
0005432822279	9617	Economy	10900.00
0005434448353	9617	Economy	10900.00
0005432817763	9617	Economy	10900.00
0005434157509	9617	Economy	10900.00
0005432901705	9617	Economy	10900.00
0005432901574	9617	Economy	10900.00
0005432822278	9617	Economy	10900.00
0005432817785	9617	Economy	10900.00
0005432901601	9617	Economy	10900.00
0005434448350	9617	Economy	10900.00
0005432289020	9617	Economy	10900.00
0005432817781	9617	Economy	10900.00
0005432817764	9617	Economy	10900.00
0005432901650	9617	Economy	10900.00
0005432289021	9617	Economy	10900.00
0005432817782	9617	Economy	10900.00
0005432901656	9617	Economy	10900.00
0005432817770	9617	Economy	10900.00
0005432901647	9617	Economy	10900.00
0005434448352	9617	Economy	10900.00
0005434157507	9617	Economy	10900.00
0005432901622	9617	Economy	10900.00
0005434157556	29000	Business	32600.00
0005432002098	29000	Business	32600.00
0005432817472	29000	Business	32600.00
0005434186227	29000	Business	32600.00
0005432817518	29000	Business	32600.00
0005432817489	29000	Business	32600.00
0005432817433	29000	Business	32600.00
0005432817516	29000	Business	32600.00
0005432817615	29000	Economy	10900.00
0005432817532	29000	Economy	10900.00
0005432901781	29000	Economy	10900.00
0005432901780	29000	Economy	10900.00
0005432002099	29000	Economy	10900.00
0005432901793	29000	Economy	10900.00
0005432901779	29000	Economy	10900.00
0005432901782	29000	Economy	11900.00
0005432817635	29000	Economy	11900.00
0005432817530	29000	Economy	11900.00
0005432817432	29000	Economy	11900.00
0005432817616	29000	Economy	11900.00
0005432901794	29000	Economy	10900.00
0005432822227	29000	Economy	10900.00
0005432817445	29000	Economy	10900.00
0005434157561	29000	Economy	10900.00
0005432901787	29000	Economy	10900.00
0005434448313	29000	Economy	10900.00
0005432817539	29000	Economy	10900.00
0005432901788	29000	Economy	10900.00
0005432817462	29000	Economy	10900.00
0005432817554	29000	Economy	10900.00
0005432817439	29000	Economy	10900.00
0005432822220	29000	Economy	10900.00
0005434186225	29000	Economy	10900.00
0005432817402	29000	Economy	10900.00
0005432822206	29000	Economy	10900.00
0005432817529	29000	Economy	10900.00
0005432817622	29000	Economy	10900.00
0005432817467	29000	Economy	10900.00
0005432817542	29000	Economy	10900.00
0005432817533	29000	Economy	10900.00
0005434157559	29000	Economy	10900.00
0005432817531	29000	Economy	10900.00
0005432822212	29000	Economy	10900.00
0005432822195	29000	Economy	10900.00
0005432901795	29000	Economy	10900.00
0005432822194	29000	Economy	10900.00
0005432817491	29000	Economy	10900.00
0005432817438	29000	Economy	10900.00
0005432002097	29000	Economy	10900.00
0005434157557	29000	Economy	10900.00
0005432002096	29000	Economy	10900.00
0005432901791	29000	Economy	10900.00
0005432817517	29000	Economy	10900.00
0005434157558	29000	Economy	10900.00
0005432817444	29000	Economy	10900.00
0005432817473	29000	Economy	10900.00
0005432901797	29000	Economy	10900.00
0005432901785	29000	Economy	10900.00
0005432901784	29000	Economy	10900.00
0005432901789	29000	Economy	10900.00
0005432901790	29000	Economy	10900.00
0005432817403	29000	Economy	10900.00
0005432901783	29000	Economy	10900.00
0005432817536	29000	Economy	10900.00
0005434448317	29000	Economy	10900.00
0005432822225	29000	Economy	10900.00
0005432817588	29000	Economy	10900.00
0005434157560	29000	Economy	10900.00
0005432901786	29000	Economy	10900.00
0005432901796	29000	Economy	10900.00
0005434157562	29000	Economy	10900.00
0005434186228	29000	Economy	10900.00
0005432817535	29000	Economy	10900.00
0005432822226	29000	Economy	10900.00
0005432901792	29000	Economy	10900.00
0005434186226	29000	Economy	10900.00
0005432822198	29000	Economy	10900.00
0005432611751	15070	Economy	11000.00
0005435841824	15070	Economy	11000.00
0005435841094	15070	Economy	11000.00
0005435841823	15070	Economy	11000.00
0005432613905	15070	Economy	11000.00
0005435841825	15070	Economy	11000.00
0005432613903	15070	Economy	11000.00
0005432613904	15070	Economy	11000.00
0005432607577	31607	Economy	11000.00
0005435841829	31607	Economy	11000.00
0005432611716	31607	Economy	11000.00
0005432607574	31607	Economy	11000.00
0005435842336	31607	Economy	11000.00
0005435842335	31607	Economy	11000.00
0005432948584	11853	Business	105900.00
0005433569605	11853	Business	105900.00
0005433569613	11853	Business	105900.00
0005432948583	11853	Business	105900.00
0005433569640	11853	Business	105900.00
0005432948557	11853	Business	105900.00
0005433569594	11853	Business	105900.00
0005432948339	11853	Business	105900.00
0005433569620	11853	Business	105900.00
0005433569648	11853	Business	105900.00
0005432948530	11853	Business	105900.00
0005433569638	11853	Business	105900.00
0005432948464	11853	Business	105900.00
0005433569646	11853	Business	105900.00
0005433569636	11853	Business	105900.00
0005433569625	11853	Economy	35300.00
0005432948478	11853	Economy	35300.00
0005432948392	11853	Economy	35300.00
0005433569603	11853	Economy	35300.00
0005432948556	11853	Economy	35300.00
0005432948531	11853	Economy	35300.00
0005433569609	11853	Economy	35300.00
0005432948552	11853	Economy	35300.00
0005433569591	11853	Economy	35300.00
0005433569596	11853	Economy	35300.00
0005433569587	11853	Economy	35300.00
0005433569585	11853	Economy	35300.00
0005432948477	11853	Economy	38800.00
0005433569612	11853	Economy	38800.00
0005432948529	11853	Economy	38800.00
0005433569617	11853	Economy	38800.00
0005432948463	11853	Economy	35300.00
0005433569622	11853	Economy	35300.00
0005432948550	11853	Economy	35300.00
0005433569599	11853	Economy	35300.00
0005433569595	11853	Economy	35300.00
0005433569623	11853	Economy	35300.00
0005433569639	11853	Economy	35300.00
0005433569598	11853	Economy	35300.00
0005433569641	11853	Economy	35300.00
0005433569630	11853	Economy	35300.00
0005433569632	11853	Economy	35300.00
0005433569607	11853	Economy	35300.00
0005432948593	11853	Economy	35300.00
0005433569588	11853	Economy	35300.00
0005433569602	11853	Economy	35300.00
0005432948317	11853	Economy	35300.00
0005432948288	11853	Economy	35300.00
0005433569600	11853	Economy	35300.00
0005433569615	11853	Economy	35300.00
0005433569647	11853	Economy	35300.00
0005433569601	11853	Economy	35300.00
0005433569624	11853	Economy	35300.00
0005432948340	11853	Economy	35300.00
0005433569608	11853	Economy	35300.00
0005432948442	11853	Economy	35300.00
0005433569628	11853	Economy	35300.00
0005432948551	11853	Economy	35300.00
0005432948503	11853	Economy	35300.00
0005433569643	11853	Economy	35300.00
0005432948476	11853	Economy	35300.00
0005432948502	11853	Economy	35300.00
0005433569611	11853	Economy	35300.00
0005433569629	11853	Economy	35300.00
0005433569592	11853	Economy	35300.00
0005433569627	11853	Economy	35300.00
0005432948528	11853	Economy	35300.00
0005432948341	11853	Economy	35300.00
0005433569633	11853	Economy	35300.00
0005433569621	11853	Economy	35300.00
0005432948627	11853	Economy	35300.00
0005433569610	11853	Economy	35300.00
0005433569597	11853	Economy	35300.00
0005433569637	11853	Economy	35300.00
0005433569645	11853	Economy	35300.00
0005433569589	11853	Economy	35300.00
0005433569584	11853	Economy	35300.00
0005432948626	11853	Economy	35300.00
0005433569614	11853	Economy	35300.00
0005433569634	11853	Economy	35300.00
0005433569590	11853	Economy	35300.00
0005433569635	11853	Economy	35300.00
0005432948594	11853	Economy	35300.00
0005432948595	11853	Economy	35300.00
0005433569644	11853	Economy	35300.00
0005433569619	11853	Economy	35300.00
0005433569593	11853	Economy	35300.00
0005433569626	11853	Economy	35300.00
0005432948572	11853	Economy	35300.00
0005433569642	11853	Economy	35300.00
0005433569606	11853	Economy	35300.00
0005433569618	11853	Economy	35300.00
0005433569631	11853	Economy	35300.00
0005433569604	11853	Economy	35300.00
0005432948546	11853	Economy	35300.00
0005433569586	11853	Economy	35300.00
0005433569616	11853	Economy	35300.00
0005432948504	11853	Economy	35300.00
0005433569241	25309	Business	105900.00
0005432948927	25309	Business	105900.00
0005433569065	25309	Business	105900.00
0005433569075	25309	Business	105900.00
0005433569057	25309	Business	105900.00
0005433568950	25309	Business	105900.00
0005433569298	25309	Business	105900.00
0005433569135	25309	Business	105900.00
0005433568961	25309	Business	105900.00
0005432948911	25309	Business	105900.00
0005432948909	25309	Business	105900.00
0005433569225	25309	Business	105900.00
0005433568963	25309	Business	105900.00
0005432948906	25309	Business	105900.00
0005432948929	25309	Business	105900.00
0005433569170	25309	Business	105900.00
0005432948894	25309	Business	105900.00
0005433569089	25309	Business	105900.00
0005433568775	25309	Business	105900.00
0005433569142	25309	Business	105900.00
0005433569115	25309	Economy	35300.00
0005432948915	25309	Economy	35300.00
0005433569012	25309	Economy	35300.00
0005433569096	25309	Economy	35300.00
0005433569116	25309	Economy	35300.00
0005433569143	25309	Economy	35300.00
0005432948914	25309	Economy	35300.00
0005432948896	25309	Economy	35300.00
0005433569011	25309	Economy	35300.00
0005433568962	25309	Economy	35300.00
0005433568776	25309	Economy	35300.00
0005433569158	25309	Economy	35300.00
0005433569008	25309	Economy	38800.00
0005432948920	25309	Economy	38800.00
0005433569223	25309	Economy	38800.00
0005433569205	25309	Economy	38800.00
0005433568931	25309	Economy	35300.00
0005433569152	25309	Economy	35300.00
0005432948898	25309	Economy	35300.00
0005432948908	25309	Economy	35300.00
0005432948930	25309	Economy	35300.00
0005433569039	25309	Economy	35300.00
0005433569238	25309	Economy	35300.00
0005433569198	25309	Economy	35300.00
0005432948904	25309	Economy	35300.00
0005432948899	25309	Economy	35300.00
0005433568978	25309	Economy	35300.00
0005432948903	25309	Economy	35300.00
0005433569175	25309	Economy	35300.00
0005433569147	25309	Economy	35300.00
0005432948917	25309	Economy	35300.00
0005433569201	25309	Economy	35300.00
0005433568932	25309	Economy	35300.00
0005432948892	25309	Economy	35300.00
0005433569277	25309	Economy	35300.00
0005432948913	25309	Economy	35300.00
0005433569206	25309	Economy	35300.00
0005433568857	25309	Economy	35300.00
0005432948900	25309	Economy	35300.00
0005432948922	25309	Economy	35300.00
0005433569066	25309	Economy	35300.00
0005433569061	25309	Economy	35300.00
0005433568872	25309	Economy	35300.00
0005432948912	25309	Economy	35300.00
0005432948891	25309	Economy	35300.00
0005432948926	25309	Economy	35300.00
0005433568916	25309	Economy	35300.00
0005433568976	25309	Economy	35300.00
0005432948919	25309	Economy	35300.00
0005433568856	25309	Economy	35300.00
0005433569063	25309	Economy	35300.00
0005433569007	25309	Economy	35300.00
0005432948901	25309	Economy	35300.00
0005433569149	25309	Economy	35300.00
0005433569207	25309	Economy	35300.00
0005433569208	25309	Economy	35300.00
0005433569276	25309	Economy	35300.00
0005432948924	25309	Economy	35300.00
0005432948905	25309	Economy	35300.00
0005432948907	25309	Economy	35300.00
0005432948928	25309	Economy	35300.00
0005433569023	25309	Economy	35300.00
0005433569090	25309	Economy	35300.00
0005433569174	25309	Economy	35300.00
0005432948918	25309	Economy	35300.00
0005432948916	25309	Economy	35300.00
0005433569167	25309	Economy	35300.00
0005432948925	25309	Economy	35300.00
0005433569157	25309	Economy	35300.00
0005433568977	25309	Economy	35300.00
0005432948923	25309	Economy	35300.00
0005432948893	25309	Economy	35300.00
0005432948895	25309	Economy	35300.00
0005433569224	25309	Economy	35300.00
0005432948910	25309	Economy	35300.00
0005433569156	25309	Economy	35300.00
0005433569307	25309	Economy	35300.00
0005433569076	25309	Economy	35300.00
0005432948921	25309	Economy	35300.00
0005432948902	25309	Economy	35300.00
0005433569134	25309	Economy	35300.00
0005432948897	25309	Economy	35300.00
0005434654981	5369	Business	67200.00
0005435340311	5369	Business	67200.00
0005434654997	5369	Business	67200.00
0005434654983	5369	Business	67200.00
0005435340236	5369	Business	67200.00
0005432114236	5369	Business	67200.00
0005434654988	5369	Business	67200.00
0005435340234	5369	Economy	22400.00
0005435340224	5369	Economy	22400.00
0005432114237	5369	Economy	22400.00
0005434654985	5369	Economy	22400.00
0005434654995	5369	Economy	22400.00
0005435340292	5369	Economy	22400.00
0005434654980	5369	Economy	22400.00
0005435340286	5369	Economy	22400.00
0005435340282	5369	Economy	24600.00
0005434654986	5369	Economy	24600.00
0005435340284	5369	Economy	24600.00
0005435340271	5369	Economy	24600.00
0005435340272	5369	Economy	22400.00
0005434654976	5369	Economy	22400.00
0005434654973	5369	Economy	22400.00
0005434654975	5369	Economy	22400.00
0005434654994	5369	Economy	22400.00
0005435340235	5369	Economy	22400.00
0005434654996	5369	Economy	22400.00
0005434654991	5369	Economy	22400.00
0005435340244	5369	Economy	22400.00
0005435340260	5369	Economy	22400.00
0005435340333	5369	Economy	22400.00
0005434656577	5369	Economy	22400.00
0005435340269	5369	Economy	22400.00
0005434654987	5369	Economy	22400.00
0005434654978	5369	Economy	22400.00
0005434654979	5369	Economy	22400.00
0005435555376	5369	Economy	22400.00
0005435555375	5369	Economy	22400.00
0005435340245	5369	Economy	22400.00
0005434654990	5369	Economy	22400.00
0005434654972	5369	Economy	22400.00
0005435340285	5369	Economy	22400.00
0005435340267	5369	Economy	22400.00
0005434654977	5369	Economy	22400.00
0005434654984	5369	Economy	22400.00
0005435340336	5369	Economy	22400.00
0005434654989	5369	Economy	22400.00
0005434654992	5369	Economy	22400.00
0005434654993	5369	Economy	22400.00
0005434654970	5369	Economy	22400.00
0005434654971	5369	Economy	22400.00
0005435340302	5369	Economy	22400.00
0005434654969	5369	Economy	22400.00
0005434654974	5369	Economy	22400.00
0005435340268	5369	Economy	22400.00
0005435340223	5369	Economy	22400.00
0005435340288	5369	Economy	22400.00
0005434654982	5369	Economy	22400.00
0005434656576	5369	Economy	22400.00
0005434654689	12553	Business	67200.00
0005434654749	12553	Business	67200.00
0005434656562	12553	Business	67200.00
0005434654784	12553	Business	67200.00
0005434654661	12553	Business	67200.00
0005435340419	12553	Business	67200.00
0005434654731	12553	Economy	22400.00
0005434654648	12553	Economy	22400.00
0005434654766	12553	Economy	22400.00
0005434654732	12553	Economy	22400.00
0005434656566	12553	Economy	22400.00
0005434654671	12553	Economy	22400.00
0005435340412	12553	Economy	22400.00
0005434654599	12553	Economy	24600.00
0005434654730	12553	Economy	24600.00
0005434654746	12553	Economy	24600.00
0005434656568	12553	Economy	22400.00
0005435340411	12553	Economy	22400.00
0005434654662	12553	Economy	22400.00
0005434654650	12553	Economy	22400.00
0005435340415	12553	Economy	22400.00
0005435340418	12553	Economy	22400.00
0005435340424	12553	Economy	22400.00
0005435340420	12553	Economy	22400.00
0005435555393	12553	Economy	22400.00
0005434654770	12553	Economy	22400.00
0005435340423	12553	Economy	22400.00
0005434654690	12553	Economy	22400.00
0005434654707	12553	Economy	22400.00
0005434654726	12553	Economy	22400.00
0005434654700	12553	Economy	22400.00
0005434654776	12553	Economy	22400.00
0005434654832	12553	Economy	22400.00
0005435340421	12553	Economy	22400.00
0005434654663	12553	Economy	22400.00
0005435340417	12553	Economy	22400.00
0005434654701	12553	Economy	22400.00
0005434654649	12553	Economy	22400.00
0005435340410	12553	Economy	22400.00
0005434654691	12553	Economy	22400.00
0005434654697	12553	Economy	22400.00
0005435555392	12553	Economy	22400.00
0005434654748	12553	Economy	22400.00
0005434654785	12553	Economy	22400.00
0005434654762	12553	Economy	22400.00
0005435555391	12553	Economy	22400.00
0005434654744	12553	Economy	22400.00
0005435340422	12553	Economy	22400.00
0005434654708	12553	Economy	22400.00
0005434654728	12553	Economy	22400.00
0005434654910	12553	Economy	22400.00
0005434654694	12553	Economy	22400.00
0005434654854	12553	Economy	22400.00
0005434654745	12553	Economy	22400.00
0005434656563	12553	Economy	22400.00
0005435340414	12553	Economy	22400.00
0005434654792	12553	Economy	22400.00
0005434654753	12553	Economy	22400.00
0005434654833	12553	Economy	22400.00
0005434654733	12553	Economy	22400.00
0005435340413	12553	Economy	22400.00
0005435340416	12553	Economy	22400.00
0005434654643	12553	Economy	22400.00
0005434654823	12553	Economy	22400.00
0005434656567	12553	Economy	22400.00
0005434654722	12553	Economy	22400.00
0005432078166	7445	Business	32000.00
0005433716465	7445	Business	32000.00
0005432428931	7445	Business	32000.00
0005433716480	7445	Business	32000.00
0005433716449	7445	Business	32000.00
0005433716466	7445	Business	32000.00
0005432428937	7445	Business	32000.00
0005433689930	7445	Business	32000.00
0005433716454	7445	Economy	10700.00
0005433716458	7445	Economy	10700.00
0005433716489	7445	Economy	10700.00
0005433716459	7445	Economy	10700.00
0005433716448	7445	Economy	10700.00
0005432078165	7445	Economy	10700.00
0005433716491	7445	Economy	10700.00
0005433716473	7445	Economy	10700.00
0005433656701	7445	Economy	10700.00
0005433716478	7445	Economy	10700.00
0005433716487	7445	Economy	10700.00
0005432078164	7445	Economy	10700.00
0005433716460	7445	Economy	10700.00
0005433716468	7445	Economy	10700.00
0005433716452	7445	Economy	10700.00
0005433719174	7445	Economy	10700.00
0005433716455	7445	Economy	10700.00
0005433716482	7445	Economy	10700.00
0005433716485	7445	Economy	10700.00
0005433716464	7445	Economy	10700.00
0005433688828	7445	Economy	10700.00
0005433716476	7445	Economy	10700.00
0005433689933	7445	Economy	10700.00
0005433716469	7445	Economy	10700.00
0005433716467	7445	Economy	10700.00
0005433716492	7445	Economy	10700.00
0005435266147	7445	Economy	10700.00
0005433716493	7445	Economy	11700.00
0005432078163	7445	Economy	10700.00
0005433716472	7445	Economy	10700.00
0005432428932	7445	Economy	10700.00
0005433719172	7445	Economy	10700.00
0005433716494	7445	Economy	10700.00
0005433716461	7445	Economy	10700.00
0005433722283	7445	Economy	10700.00
0005433716463	7445	Economy	10700.00
0005433716498	7445	Economy	10700.00
0005433656702	7445	Economy	10700.00
0005433719175	7445	Economy	10700.00
0005433690944	7445	Economy	10700.00
0005433716451	7445	Economy	10700.00
0005433716497	7445	Economy	10700.00
0005432428936	7445	Economy	10700.00
0005433716475	7445	Economy	10700.00
0005433716470	7445	Economy	10700.00
0005432428935	7445	Economy	10700.00
0005433716474	7445	Economy	10700.00
0005433716488	7445	Economy	10700.00
0005433719173	7445	Economy	10700.00
0005433716483	7445	Economy	10700.00
0005433716462	7445	Economy	10700.00
0005433716457	7445	Economy	10700.00
0005432428938	7445	Economy	10700.00
0005433722282	7445	Economy	10700.00
0005433689931	7445	Economy	10700.00
0005433716484	7445	Economy	10700.00
0005433716495	7445	Economy	10700.00
0005433716490	7445	Economy	10700.00
0005433716477	7445	Economy	10700.00
0005433716453	7445	Economy	10700.00
0005433716456	7445	Economy	10700.00
0005433716479	7445	Economy	10700.00
0005433656703	7445	Economy	10700.00
0005433716486	7445	Economy	10700.00
0005433716450	7445	Economy	10700.00
0005433688829	7445	Economy	10700.00
0005433689932	7445	Economy	10700.00
0005433716471	7445	Economy	10700.00
0005433689929	7445	Economy	10700.00
0005433716496	7445	Economy	10700.00
0005433690943	7445	Economy	10700.00
0005433716481	7445	Economy	10700.00
0005432428965	29228	Business	32000.00
0005433716179	29228	Business	32000.00
0005433722200	29228	Business	32000.00
0005433715740	29228	Business	32000.00
0005433716180	29228	Business	32000.00
0005433719153	29228	Business	32000.00
0005433715970	29228	Business	32000.00
0005433716044	29228	Economy	10700.00
0005435266194	29228	Economy	10700.00
0005432428964	29228	Economy	10700.00
0005432006789	29228	Economy	10700.00
0005433716113	29228	Economy	10700.00
0005433716016	29228	Economy	10700.00
0005433719159	29228	Economy	10700.00
0005433656664	29228	Economy	10700.00
0005433716100	29228	Economy	10700.00
0005433688818	29228	Economy	10700.00
0005433715893	29228	Economy	10700.00
0005433716133	29228	Economy	10700.00
0005433716121	29228	Economy	10700.00
0005433716032	29228	Economy	10700.00
0005433716153	29228	Economy	10700.00
0005435266195	29228	Economy	10700.00
0005433719151	29228	Economy	10700.00
0005433719142	29228	Economy	10700.00
0005433716137	29228	Economy	10700.00
0005432428962	29228	Economy	10700.00
0005433716287	29228	Economy	10700.00
0005433716162	29228	Economy	10700.00
0005432006790	29228	Economy	10700.00
0005433722206	29228	Economy	11700.00
0005433719137	29228	Economy	11700.00
0005433716288	29228	Economy	10700.00
0005433656665	29228	Economy	10700.00
0005433715939	29228	Economy	10700.00
0005433716099	29228	Economy	10700.00
0005433715977	29228	Economy	10700.00
0005435266192	29228	Economy	10700.00
0005433719140	29228	Economy	10700.00
0005433715978	29228	Economy	10700.00
0005433716130	29228	Economy	10700.00
0005432006792	29228	Economy	10700.00
0005433688810	29228	Economy	10700.00
0005433719141	29228	Economy	10700.00
0005433722204	29228	Economy	10700.00
0005433715947	29228	Economy	10700.00
0005433656668	29228	Economy	10700.00
0005435266193	29228	Economy	10700.00
0005433715946	29228	Economy	10700.00
0005433716097	29228	Economy	10700.00
0005433719160	29228	Economy	10700.00
0005433719136	29228	Economy	10700.00
0005433716368	29228	Economy	10700.00
0005433716010	29228	Economy	10700.00
0005432428963	29228	Economy	10700.00
0005433715962	29228	Economy	10700.00
0005433715976	29228	Economy	10700.00
0005433656686	29228	Economy	10700.00
0005433716006	29228	Economy	10700.00
0005433716098	29228	Economy	10700.00
0005433716079	29228	Economy	10700.00
0005433716124	29228	Economy	10700.00
0005433716045	29228	Economy	10700.00
0005433716136	29228	Economy	10700.00
0005433716253	29228	Economy	10700.00
0005433715957	29228	Economy	10700.00
0005433716009	29228	Economy	10700.00
0005433656666	29228	Economy	10700.00
0005433722205	29228	Economy	10700.00
0005433715852	29228	Economy	10700.00
0005433716017	29228	Economy	10700.00
0005432006791	29228	Economy	10700.00
0005434182227	8682	Business	36500.00
0005434182245	8682	Business	36500.00
0005434182186	8682	Business	36500.00
0005434182232	8682	Economy	12200.00
0005434182201	8682	Economy	12200.00
0005434182202	8682	Economy	12200.00
0005434182228	8682	Economy	12200.00
0005434095425	8682	Economy	12200.00
0005434095416	8682	Economy	12200.00
0005434182203	8682	Economy	12200.00
0005434182204	8682	Economy	12200.00
0005434182246	8682	Economy	12200.00
0005434182210	8682	Economy	12200.00
0005434182212	8682	Economy	12200.00
0005434182185	8682	Economy	12200.00
0005434095417	8682	Economy	12200.00
0005434095422	8682	Economy	12200.00
0005434182247	8682	Economy	12200.00
0005434095427	8682	Economy	12200.00
0005434095420	8682	Economy	12200.00
0005434095418	8682	Economy	12200.00
0005434095423	8682	Economy	12200.00
0005434182211	8682	Economy	12200.00
0005434095421	8682	Economy	12200.00
0005434095426	8682	Economy	12200.00
0005434095419	8682	Economy	12200.00
0005434095415	8682	Economy	12200.00
0005434095428	8682	Economy	12200.00
0005434095424	8682	Economy	12200.00
0005434095414	8682	Economy	12200.00
0005434095318	11662	Business	36500.00
0005434182309	11662	Business	36500.00
0005434182316	11662	Business	36500.00
0005434182312	11662	Business	36500.00
0005434182306	11662	Business	36500.00
0005434095306	11662	Economy	12200.00
0005434095278	11662	Economy	12200.00
0005434095232	11662	Economy	12200.00
0005434182313	11662	Economy	12200.00
0005434184683	11662	Economy	12200.00
0005434182314	11662	Economy	12200.00
0005434095322	11662	Economy	12200.00
0005434143729	11662	Economy	12200.00
0005434183598	11662	Economy	12200.00
0005434182311	11662	Economy	12200.00
0005434182315	11662	Economy	12200.00
0005434095266	11662	Economy	12200.00
0005434182307	11662	Economy	12200.00
0005434095333	11662	Economy	12200.00
0005434184684	11662	Economy	12200.00
0005434182317	11662	Economy	12200.00
0005434095258	11662	Economy	12200.00
0005434182308	11662	Economy	12200.00
0005434182310	11662	Economy	12200.00
0005434095279	11662	Economy	12200.00
0005434095259	11662	Economy	12200.00
0005434143727	11662	Economy	12200.00
0005434182305	11662	Economy	12200.00
0005434095334	11662	Economy	12200.00
0005434095303	11662	Economy	12200.00
0005434095267	11662	Economy	12200.00
0005434095323	11662	Economy	12200.00
0005434183599	11662	Economy	12200.00
0005434095307	11662	Economy	12200.00
0005434095310	11662	Economy	12200.00
0005433457010	1425	Business	33000.00
0005433397830	1425	Business	33000.00
0005433398244	1425	Business	33000.00
0005433398175	1425	Business	33000.00
0005433398136	1425	Business	33000.00
0005433398083	1425	Business	33000.00
0005435732476	1425	Business	33000.00
0005435732461	1425	Business	33000.00
0005432297305	1425	Business	33000.00
0005433397986	1425	Economy	11000.00
0005433398243	1425	Economy	11000.00
0005433398124	1425	Economy	11000.00
0005433457013	1425	Economy	11000.00
0005435732464	1425	Economy	11000.00
0005433398196	1425	Economy	11000.00
0005435732472	1425	Economy	11000.00
0005433397835	1425	Economy	11000.00
0005435732471	1425	Economy	12100.00
0005435732474	1425	Economy	12100.00
0005435732469	1425	Economy	12100.00
0005435732479	1425	Economy	12100.00
0005435732473	1425	Economy	11000.00
0005435732480	1425	Economy	11000.00
0005433398219	1425	Economy	11000.00
0005433398260	1425	Economy	11000.00
0005435732475	1425	Economy	11000.00
0005435732467	1425	Economy	11000.00
0005433398125	1425	Economy	11000.00
0005433398010	1425	Economy	11000.00
0005433397881	1425	Economy	11000.00
0005433457012	1425	Economy	11000.00
0005433398157	1425	Economy	11000.00
0005435732465	1425	Economy	11000.00
0005433398121	1425	Economy	11000.00
0005435732462	1425	Economy	11000.00
0005432297304	1425	Economy	11000.00
0005435732468	1425	Economy	11000.00
0005433397992	1425	Economy	11000.00
0005433457011	1425	Economy	11000.00
0005433398169	1425	Economy	11000.00
0005433398005	1425	Economy	11000.00
0005433398120	1425	Economy	11000.00
0005433398184	1425	Economy	11000.00
0005433398127	1425	Economy	11000.00
0005433398151	1425	Economy	11000.00
0005433398195	1425	Economy	11000.00
0005433398135	1425	Economy	11000.00
0005435732466	1425	Economy	11000.00
0005435732470	1425	Economy	11000.00
0005433398134	1425	Economy	11000.00
0005435732478	1425	Economy	11000.00
0005433397991	1425	Economy	11000.00
0005433398211	1425	Economy	11000.00
0005433398082	1425	Economy	11000.00
0005435732477	1425	Economy	11000.00
0005435732463	1425	Economy	11000.00
0005433398183	1425	Economy	11000.00
0005433397994	1425	Economy	11000.00
0005433398109	1425	Economy	11000.00
0005433398188	1425	Economy	11000.00
0005433398126	1425	Economy	11000.00
0005435732481	1425	Economy	11000.00
0005433398038	1425	Economy	11000.00
0005433398329	1425	Economy	11000.00
0005433398110	1425	Economy	11000.00
0005432297303	1425	Economy	11000.00
0005433397905	1425	Economy	11000.00
0005433398190	1425	Economy	11000.00
0005433398114	1425	Economy	11000.00
0005433398210	1425	Economy	11000.00
0005433398026	1425	Economy	11000.00
0005433457009	1425	Economy	11000.00
0005433398542	19269	Business	33000.00
0005433398567	19269	Business	33000.00
0005433398554	19269	Business	33000.00
0005433398538	19269	Business	33000.00
0005433398529	19269	Business	33000.00
0005433398556	19269	Business	33000.00
0005433398533	19269	Business	33000.00
0005433398548	19269	Business	33000.00
0005433398531	19269	Business	33000.00
0005433398549	19269	Business	33000.00
0005433398570	19269	Economy	11000.00
0005435732335	19269	Economy	11000.00
0005435732375	19269	Economy	11000.00
0005435732301	19269	Economy	11000.00
0005435732374	19269	Economy	11000.00
0005433398541	19269	Economy	11000.00
0005433398532	19269	Economy	11000.00
0005433398559	19269	Economy	11000.00
0005433398536	19269	Economy	12100.00
0005435732376	19269	Economy	12100.00
0005433398525	19269	Economy	12100.00
0005433398535	19269	Economy	12100.00
0005433456987	19269	Economy	12100.00
0005433398544	19269	Economy	11000.00
0005433398550	19269	Economy	11000.00
0005433398527	19269	Economy	11000.00
0005433398546	19269	Economy	11000.00
0005433456981	19269	Economy	11000.00
0005433398540	19269	Economy	11000.00
0005432906561	19269	Economy	11000.00
0005433398565	19269	Economy	11000.00
0005433398528	19269	Economy	11000.00
0005433398551	19269	Economy	11000.00
0005435732333	19269	Economy	11000.00
0005433398547	19269	Economy	11000.00
0005435732299	19269	Economy	11000.00
0005433398555	19269	Economy	11000.00
0005435732340	19269	Economy	11000.00
0005435732373	19269	Economy	11000.00
0005433398558	19269	Economy	11000.00
0005433398534	19269	Economy	11000.00
0005433398568	19269	Economy	11000.00
0005435732334	19269	Economy	11000.00
0005433398564	19269	Economy	11000.00
0005433398566	19269	Economy	11000.00
0005435732364	19269	Economy	11000.00
0005435732356	19269	Economy	11000.00
0005433398563	19269	Economy	11000.00
0005433398569	19269	Economy	11000.00
0005433398552	19269	Economy	11000.00
0005433398530	19269	Economy	11000.00
0005433398543	19269	Economy	11000.00
0005433398560	19269	Economy	11000.00
0005433398562	19269	Economy	11000.00
0005435732331	19269	Economy	11000.00
0005433398553	19269	Economy	11000.00
0005435732302	19269	Economy	11000.00
0005435732330	19269	Economy	11000.00
0005433398539	19269	Economy	11000.00
0005433398561	19269	Economy	11000.00
0005435732339	19269	Economy	11000.00
0005433398526	19269	Economy	11000.00
0005433398557	19269	Economy	11000.00
0005433398523	19269	Economy	11000.00
0005433398524	19269	Economy	11000.00
0005433398545	19269	Economy	11000.00
0005432906560	19269	Economy	11000.00
0005435732282	19269	Economy	11000.00
0005433398537	19269	Economy	11000.00
0005434443678	17335	Economy	15600.00
0005434443721	17335	Economy	14100.00
0005434443733	17335	Economy	14100.00
0005434443785	17335	Economy	14100.00
0005434443726	17335	Economy	14100.00
0005434443725	17335	Economy	14100.00
0005434443766	17335	Economy	14100.00
0005434443748	17335	Economy	14100.00
0005434443775	17335	Economy	14100.00
0005434443776	17335	Economy	14100.00
0005434443732	17335	Economy	14100.00
0005434443747	17335	Economy	14100.00
0005434443677	17335	Economy	14100.00
0005434443728	17335	Economy	14100.00
0005434443786	17335	Economy	14100.00
0005434443676	17335	Economy	14100.00
0005434443856	20585	Economy	14100.00
0005434443857	20585	Economy	14100.00
0005434443863	20585	Economy	14100.00
0005434443854	20585	Economy	14100.00
0005434443862	20585	Economy	14100.00
0005434443859	20585	Economy	14100.00
0005434443855	20585	Economy	14100.00
0005434443865	20585	Economy	14100.00
0005434443869	20585	Economy	14100.00
0005434443864	20585	Economy	14100.00
0005434443860	20585	Economy	14100.00
0005434443867	20585	Economy	14100.00
0005434443866	20585	Economy	14100.00
0005434443868	20585	Economy	14100.00
0005434443861	20585	Economy	14100.00
0005434443858	20585	Economy	14100.00
0005435377587	7288	Economy	5800.00
0005434954648	7288	Economy	5800.00
0005434954647	7288	Economy	5800.00
0005434954650	7288	Economy	5800.00
0005434954649	7288	Economy	5800.00
0005435377584	7288	Economy	5800.00
0005435377603	28303	Economy	5800.00
0005435377604	28303	Economy	5800.00
0005434954601	28303	Economy	5800.00
0005434351820	4464	Economy	15400.00
0005435893685	4464	Economy	14000.00
0005434351821	4464	Economy	14000.00
0005435893645	4464	Economy	14000.00
0005434351827	4464	Economy	14000.00
0005434351825	4464	Economy	14000.00
0005434351818	4464	Economy	14000.00
0005434351829	4464	Economy	14000.00
0005435893684	4464	Economy	14000.00
0005434351828	4464	Economy	14000.00
0005434351822	4464	Economy	14000.00
0005435893646	4464	Economy	14000.00
0005434351830	4464	Economy	14000.00
0005434351826	4464	Economy	14000.00
0005434351824	4464	Economy	14000.00
0005434351823	4464	Economy	14000.00
0005435893675	4464	Economy	14000.00
0005435893641	4464	Economy	14000.00
0005434351819	4464	Economy	14000.00
0005435893701	29682	Economy	14000.00
0005435893700	29682	Economy	14000.00
0005435893703	29682	Economy	14000.00
0005434351697	29682	Economy	14000.00
0005434351759	29682	Economy	14000.00
0005435893706	29682	Economy	14000.00
0005434351721	29682	Economy	14000.00
0005434351735	29682	Economy	14000.00
0005434351720	29682	Economy	14000.00
0005434351758	29682	Economy	14000.00
0005435893705	29682	Economy	14000.00
0005434351703	29682	Economy	14000.00
0005435893704	29682	Economy	14000.00
0005435893702	29682	Economy	14000.00
0005433343511	1071	Business	30600.00
0005433343012	1071	Business	30600.00
0005433343348	1071	Business	30600.00
0005432293232	1071	Business	30600.00
0005433343426	1071	Business	30600.00
0005433343203	1071	Business	30600.00
0005433462768	1071	Business	30600.00
0005433343390	1071	Business	30600.00
0005433343175	1071	Business	30600.00
0005433343265	1071	Business	30600.00
0005433342994	1071	Business	30600.00
0005433343538	1071	Business	30600.00
0005433343266	1071	Business	30600.00
0005433343291	1071	Business	30600.00
0005434445267	1071	Business	30600.00
0005433343349	1071	Business	30600.00
0005433343292	1071	Business	30600.00
0005433343497	1071	Business	30600.00
0005433343614	1071	Economy	11200.00
0005432293234	1071	Economy	11200.00
0005435545828	1071	Economy	11200.00
0005435545823	1071	Economy	10200.00
0005433343171	1071	Economy	10200.00
0005435092173	1071	Economy	10200.00
0005433343131	1071	Economy	10200.00
0005434446539	1071	Economy	10200.00
0005433343145	1071	Economy	10200.00
0005435545814	1071	Economy	10200.00
0005433343389	1071	Economy	10200.00
0005433343351	1071	Economy	10200.00
0005433343547	1071	Economy	10200.00
0005433343318	1071	Economy	10200.00
0005435545822	1071	Economy	10200.00
0005433343055	1071	Economy	10200.00
0005433342501	1071	Economy	10200.00
0005433343319	1071	Economy	10200.00
0005433343232	1071	Economy	10200.00
0005433343398	1071	Economy	10200.00
0005433343548	1071	Economy	10200.00
0005433158132	1071	Economy	10200.00
0005435545816	1071	Economy	10200.00
0005433463923	1071	Economy	10200.00
0005433343368	1071	Economy	10200.00
0005433343606	1071	Economy	10200.00
0005433463922	1071	Economy	10200.00
0005433343221	1071	Economy	10200.00
0005433343160	1071	Economy	10200.00
0005435545826	1071	Economy	10200.00
0005433343306	1071	Economy	10200.00
0005433343163	1071	Economy	10200.00
0005433343477	1071	Economy	10200.00
0005433343165	1071	Economy	10200.00
0005435092179	1071	Economy	10200.00
0005433343173	1071	Economy	10200.00
0005433463921	1071	Economy	10200.00
0005433343250	1071	Economy	10200.00
0005433343153	1071	Economy	10200.00
0005435092170	1071	Economy	10200.00
0005433342814	1071	Economy	10200.00
0005433343336	1071	Economy	10200.00
0005433343496	1071	Economy	10200.00
0005435092176	1071	Economy	10200.00
0005433343107	1071	Economy	10200.00
0005433343264	1071	Economy	10200.00
0005435092177	1071	Economy	10200.00
0005435545812	1071	Economy	10200.00
0005434446538	1071	Economy	10200.00
0005435092171	1071	Economy	10200.00
0005435545813	1071	Economy	10200.00
0005433343391	1071	Economy	10200.00
0005432293233	1071	Economy	10200.00
0005433269725	1071	Economy	10200.00
0005433462769	1071	Economy	10200.00
0005433343483	1071	Economy	10200.00
0005434445266	1071	Economy	10200.00
0005433343590	1071	Economy	10200.00
0005435545819	1071	Economy	10200.00
0005433343690	1071	Economy	10200.00
0005435545818	1071	Economy	10200.00
0005433343210	1071	Economy	10200.00
0005433343170	1071	Economy	10200.00
0005433269744	1071	Economy	10200.00
0005435545825	1071	Economy	10200.00
0005433269730	1071	Economy	11200.00
0005433158131	1071	Economy	11200.00
0005434445268	1071	Economy	10200.00
0005433343393	1071	Economy	10200.00
0005433342925	1071	Economy	10200.00
0005433343174	1071	Economy	10200.00
0005433342897	1071	Economy	10200.00
0005433343108	1071	Economy	10200.00
0005433343037	1071	Economy	10200.00
0005433343304	1071	Economy	10200.00
0005435092174	1071	Economy	10200.00
0005435545817	1071	Economy	10200.00
0005435545815	1071	Economy	10200.00
0005433343413	1071	Economy	10200.00
0005433342924	1071	Economy	10200.00
0005433269716	1071	Economy	10200.00
0005435092169	1071	Economy	10200.00
0005433342871	1071	Economy	10200.00
0005435545820	1071	Economy	10200.00
0005435545824	1071	Economy	10200.00
0005433343310	1071	Economy	10200.00
0005433343233	1071	Economy	10200.00
0005433343644	1071	Economy	10200.00
0005433343399	1071	Economy	10200.00
0005432293235	1071	Economy	10200.00
0005433343253	1071	Economy	10200.00
0005435545827	1071	Economy	10200.00
0005433343270	1071	Economy	10200.00
0005433343392	1071	Economy	10200.00
0005433343123	1071	Economy	10200.00
0005433343122	1071	Economy	10200.00
0005433342931	1071	Economy	10200.00
0005433342651	1071	Economy	10200.00
0005433342993	1071	Economy	10200.00
0005433343268	1071	Economy	10200.00
0005433343043	1071	Economy	10200.00
0005435092178	1071	Economy	10200.00
0005433343056	1071	Economy	10200.00
0005433462770	1071	Economy	10200.00
0005433343172	1071	Economy	10200.00
0005435092175	1071	Economy	10200.00
0005433343180	1071	Economy	10200.00
0005435545821	1071	Economy	10200.00
0005433343073	1071	Economy	10200.00
0005433158133	1071	Economy	10200.00
0005433343042	1071	Economy	10200.00
0005433158128	1071	Economy	10200.00
0005433343036	1071	Economy	10200.00
0005433343427	1071	Economy	10200.00
0005433158134	1071	Economy	10200.00
0005433343572	1071	Economy	10200.00
0005435092172	1071	Economy	10200.00
0005433343209	1071	Economy	10200.00
0005433344037	17056	Business	30600.00
0005435508346	17056	Business	30600.00
0005433344067	17056	Business	30600.00
0005433344065	17056	Business	30600.00
0005433344074	17056	Business	30600.00
0005433344072	17056	Business	30600.00
0005433344060	17056	Business	30600.00
0005433344056	17056	Business	30600.00
0005433344024	17056	Business	30600.00
0005433344115	17056	Business	30600.00
0005433344031	17056	Business	30600.00
0005433344063	17056	Business	30600.00
0005433344055	17056	Business	30600.00
0005435508388	17056	Business	30600.00
0005433344076	17056	Business	30600.00
0005433159334	17056	Business	30600.00
0005433344029	17056	Business	30600.00
0005435508358	17056	Economy	11200.00
0005433269774	17056	Economy	11200.00
0005435092112	17056	Economy	11200.00
0005433344093	17056	Economy	11200.00
0005435092126	17056	Economy	10200.00
0005435508329	17056	Economy	10200.00
0005433344062	17056	Economy	10200.00
0005433344114	17056	Economy	10200.00
0005433344041	17056	Economy	10200.00
0005433344106	17056	Economy	10200.00
0005433344116	17056	Economy	10200.00
0005433344033	17056	Economy	10200.00
0005433344094	17056	Economy	10200.00
0005433344100	17056	Economy	10200.00
0005433344095	17056	Economy	10200.00
0005435508343	17056	Economy	10200.00
0005433344105	17056	Economy	10200.00
0005433344117	17056	Economy	10200.00
0005433269772	17056	Economy	10200.00
0005433344086	17056	Economy	10200.00
0005433344027	17056	Economy	10200.00
0005433344113	17056	Economy	10200.00
0005433344104	17056	Economy	10200.00
0005435092095	17056	Economy	10200.00
0005435508342	17056	Economy	10200.00
0005435092110	17056	Economy	10200.00
0005433344025	17056	Economy	10200.00
0005433344085	17056	Economy	10200.00
0005433344118	17056	Economy	10200.00
0005435508363	17056	Economy	10200.00
0005433344030	17056	Economy	10200.00
0005433344071	17056	Economy	10200.00
0005433344043	17056	Economy	10200.00
0005433344077	17056	Economy	10200.00
0005433344069	17056	Economy	10200.00
0005435092063	17056	Economy	10200.00
0005433344054	17056	Economy	10200.00
0005435092111	17056	Economy	10200.00
0005433159335	17056	Economy	10200.00
0005433269775	17056	Economy	10200.00
0005433344046	17056	Economy	10200.00
0005433344122	17056	Economy	10200.00
0005433344078	17056	Economy	10200.00
0005433344110	17056	Economy	10200.00
0005433344061	17056	Economy	10200.00
0005433344066	17056	Economy	10200.00
0005433344123	17056	Economy	10200.00
0005433344079	17056	Economy	10200.00
0005433344026	17056	Economy	10200.00
0005433344124	17056	Economy	10200.00
0005435092093	17056	Economy	10200.00
0005435092065	17056	Economy	10200.00
0005433344039	17056	Economy	10200.00
0005435092125	17056	Economy	10200.00
0005433344097	17056	Economy	10200.00
0005433344090	17056	Economy	10200.00
0005433344052	17056	Economy	10200.00
0005433344068	17056	Economy	10200.00
0005433344125	17056	Economy	10200.00
0005433344082	17056	Economy	10200.00
0005433344053	17056	Economy	10200.00
0005433344096	17056	Economy	10200.00
0005433344028	17056	Economy	10200.00
0005433344049	17056	Economy	10200.00
0005434445244	17056	Economy	10200.00
0005433344087	17056	Economy	10200.00
0005433344109	17056	Economy	10200.00
0005433344083	17056	Economy	10200.00
0005433344107	17056	Economy	10200.00
0005435508330	17056	Economy	10200.00
0005435092071	17056	Economy	10200.00
0005435092124	17056	Economy	11200.00
0005435508379	17056	Economy	11200.00
0005433344044	17056	Economy	11200.00
0005433344035	17056	Economy	10200.00
0005433344038	17056	Economy	10200.00
0005433344073	17056	Economy	10200.00
0005433344098	17056	Economy	10200.00
0005433344064	17056	Economy	10200.00
0005433344101	17056	Economy	10200.00
0005433344070	17056	Economy	10200.00
0005433344111	17056	Economy	10200.00
0005433344084	17056	Economy	10200.00
0005435092097	17056	Economy	10200.00
0005433344045	17056	Economy	10200.00
0005435092064	17056	Economy	10200.00
0005433159333	17056	Economy	10200.00
0005433344057	17056	Economy	10200.00
0005433344036	17056	Economy	10200.00
0005433344119	17056	Economy	10200.00
0005433344099	17056	Economy	10200.00
0005435092096	17056	Economy	10200.00
0005433344032	17056	Economy	10200.00
0005435092099	17056	Economy	10200.00
0005435092092	17056	Economy	10200.00
0005433344040	17056	Economy	10200.00
0005433344059	17056	Economy	10200.00
0005433269771	17056	Economy	10200.00
0005433344091	17056	Economy	10200.00
0005433344047	17056	Economy	10200.00
0005433344080	17056	Economy	10200.00
0005433344081	17056	Economy	10200.00
0005433344092	17056	Economy	10200.00
0005433344112	17056	Economy	10200.00
0005433344120	17056	Economy	10200.00
0005433344103	17056	Economy	10200.00
0005433344088	17056	Economy	10200.00
0005435092072	17056	Economy	10200.00
0005433344034	17056	Economy	10200.00
0005433344075	17056	Economy	10200.00
0005433344058	17056	Economy	10200.00
0005435092101	17056	Economy	10200.00
0005433269770	17056	Economy	10200.00
0005433269773	17056	Economy	10200.00
0005433344050	17056	Economy	10200.00
0005433344051	17056	Economy	10200.00
0005433344048	17056	Economy	10200.00
0005433344102	17056	Economy	10200.00
0005435508331	17056	Economy	10200.00
0005435092100	17056	Economy	10200.00
0005433344089	17056	Economy	10200.00
0005433159336	17056	Economy	10200.00
0005433344121	17056	Economy	10200.00
0005433344042	17056	Economy	10200.00
0005433344108	17056	Economy	10200.00
0005435508326	17056	Economy	10200.00
0005432390238	1343	Business	101000.00
0005432851916	1343	Business	101000.00
0005432390244	1343	Business	101000.00
0005432390263	1343	Business	101000.00
0005432851886	1343	Business	101000.00
0005432390241	1343	Business	101000.00
0005432392028	1343	Business	101000.00
0005432392025	1343	Business	101000.00
0005432851933	1343	Business	101000.00
0005432851913	1343	Business	101000.00
0005432390226	1343	Business	101000.00
0005432390245	1343	Business	101000.00
0005432390224	1343	Economy	33700.00
0005432390265	1343	Economy	33700.00
0005432390227	1343	Economy	33700.00
0005432851941	1343	Economy	33700.00
0005432851932	1343	Economy	33700.00
0005432390221	1343	Economy	33700.00
0005432390234	1343	Economy	33700.00
0005432390247	1343	Economy	33700.00
0005432851901	1343	Economy	33700.00
0005432851910	1343	Economy	33700.00
0005432390258	1343	Economy	37000.00
0005432390253	1343	Economy	37000.00
0005432851903	1343	Economy	37000.00
0005432390240	1343	Economy	33700.00
0005432851893	1343	Economy	37000.00
0005432390219	1343	Economy	33700.00
0005432390222	1343	Economy	33700.00
0005432390260	1343	Economy	33700.00
0005432392023	1343	Economy	33700.00
0005432392024	1343	Economy	33700.00
0005432390262	1343	Economy	33700.00
0005432390259	1343	Economy	33700.00
0005432390220	1343	Economy	33700.00
0005432390243	1343	Economy	33700.00
0005432851894	1343	Economy	33700.00
0005432390229	1343	Economy	33700.00
0005432390218	1343	Economy	33700.00
0005432390261	1343	Economy	33700.00
0005432392018	1343	Economy	33700.00
0005432390254	1343	Economy	33700.00
0005432851895	1343	Economy	33700.00
0005432851887	1343	Economy	33700.00
0005432392022	1343	Economy	33700.00
0005432390231	1343	Economy	33700.00
0005432851904	1343	Economy	33700.00
0005432390249	1343	Economy	33700.00
0005432390242	1343	Economy	33700.00
0005432390252	1343	Economy	33700.00
0005432392020	1343	Economy	33700.00
0005432851968	1343	Economy	33700.00
0005432390237	1343	Economy	33700.00
0005432390223	1343	Economy	33700.00
0005432390232	1343	Economy	33700.00
0005432390239	1343	Economy	33700.00
0005432390257	1343	Economy	33700.00
0005432851912	1343	Economy	33700.00
0005432390250	1343	Economy	33700.00
0005432851945	1343	Economy	33700.00
0005432392021	1343	Economy	33700.00
0005432851918	1343	Economy	33700.00
0005432390233	1343	Economy	33700.00
0005432390235	1343	Economy	33700.00
0005432390230	1343	Economy	33700.00
0005432392027	1343	Economy	33700.00
0005432390246	1343	Economy	33700.00
0005432390255	1343	Economy	33700.00
0005432390256	1343	Economy	33700.00
0005432851925	1343	Economy	33700.00
0005432390228	1343	Economy	33700.00
0005432390248	1343	Economy	33700.00
0005432851892	1343	Economy	33700.00
0005432851900	1343	Economy	33700.00
0005432851942	1343	Economy	33700.00
0005432390236	1343	Economy	33700.00
0005432390251	1343	Economy	33700.00
0005432851902	1343	Economy	33700.00
0005432392019	1343	Economy	33700.00
0005432851911	1343	Economy	33700.00
0005432851915	1343	Economy	33700.00
0005432392026	1343	Economy	33700.00
0005432390225	1343	Economy	33700.00
0005432390264	1343	Economy	33700.00
0005432159902	12785	Business	40300.00
0005433989772	12785	Business	40300.00
0005434067742	12785	Business	40300.00
0005434067602	12785	Business	40300.00
0005434026703	12785	Business	40300.00
0005434067601	12785	Business	40300.00
0005434067425	12785	Business	40300.00
0005434081805	12785	Business	40300.00
0005434067762	12785	Business	40300.00
0005434067980	12785	Business	40300.00
0005434081910	12785	Economy	13400.00
0005434067692	12785	Economy	13400.00
0005434067612	12785	Economy	13400.00
0005434067617	12785	Economy	13400.00
0005434067446	12785	Economy	13400.00
0005434067751	12785	Economy	13400.00
0005432433732	12785	Economy	13400.00
0005433812925	12785	Economy	13400.00
0005434067694	12785	Economy	13400.00
0005432159903	12785	Economy	13400.00
0005434067645	12785	Economy	13400.00
0005434067388	12785	Economy	13400.00
0005434067567	12785	Economy	13400.00
0005434026708	12785	Economy	13400.00
0005434081900	12785	Economy	13400.00
0005434081800	12785	Economy	13400.00
0005434067457	12785	Economy	13400.00
0005434067540	12785	Economy	13400.00
0005434067785	12785	Economy	13400.00
0005434067523	12785	Economy	13400.00
0005434067592	12785	Economy	13400.00
0005434067519	12785	Economy	13400.00
0005432433731	12785	Economy	13400.00
0005433989773	12785	Economy	13400.00
0005434067688	12785	Economy	13400.00
0005432159906	12785	Economy	13400.00
0005434067400	12785	Economy	13400.00
0005433812924	12785	Economy	13400.00
0005434081977	12785	Economy	13400.00
0005434067401	12785	Economy	13400.00
0005434067389	12785	Economy	13400.00
0005434067693	12785	Economy	13400.00
0005434081961	12785	Economy	13400.00
0005434067591	12785	Economy	13400.00
0005434081899	12785	Economy	13400.00
0005434081933	12785	Economy	13400.00
0005434081830	12785	Economy	14800.00
0005434067481	12785	Economy	14800.00
0005434067289	12785	Economy	14800.00
0005434026707	12785	Economy	14800.00
0005434067720	12785	Economy	13400.00
0005432161176	12785	Economy	13400.00
0005432433735	12785	Economy	13400.00
0005434067750	12785	Economy	13400.00
0005434067343	12785	Economy	13400.00
0005434067169	12785	Economy	13400.00
0005434081891	12785	Economy	13400.00
0005434067482	12785	Economy	13400.00
0005434067644	12785	Economy	13400.00
0005434067458	12785	Economy	13400.00
0005434067723	12785	Economy	13400.00
0005434067409	12785	Economy	13400.00
0005432159905	12785	Economy	13400.00
0005434067671	12785	Economy	13400.00
0005434067553	12785	Economy	13400.00
0005434067428	12785	Economy	13400.00
0005434067429	12785	Economy	13400.00
0005433812923	12785	Economy	13400.00
0005434067736	12785	Economy	13400.00
0005434067522	12785	Economy	13400.00
0005434081823	12785	Economy	13400.00
0005434081829	12785	Economy	13400.00
0005434067629	12785	Economy	13400.00
0005432433736	12785	Economy	13400.00
0005434081865	12785	Economy	13400.00
0005434067616	12785	Economy	13400.00
0005434081972	12785	Economy	13400.00
0005434081866	12785	Economy	13400.00
0005434026714	12785	Economy	13400.00
0005432159904	12785	Economy	13400.00
0005434067764	12785	Economy	13400.00
0005434067741	12785	Economy	13400.00
0005434067851	12785	Economy	13400.00
0005434067753	12785	Economy	13400.00
0005434067752	12785	Economy	13400.00
0005434067857	12785	Economy	13400.00
0005434067475	12785	Economy	13400.00
0005434067531	12785	Economy	13400.00
0005434067699	12785	Economy	13400.00
0005432161174	12785	Economy	13400.00
0005434081801	12785	Economy	13400.00
0005434067410	12785	Economy	13400.00
0005432433733	12785	Economy	13400.00
0005434067670	12785	Economy	13400.00
0005434067353	12785	Economy	13400.00
0005434067656	12785	Economy	13400.00
0005434081935	12785	Economy	13400.00
0005434067763	12785	Economy	13400.00
0005432433734	12785	Economy	13400.00
0005434081828	12785	Economy	13400.00
0005433989774	12785	Economy	13400.00
0005434067426	12785	Economy	13400.00
0005434082049	12785	Economy	13400.00
0005434067615	12785	Economy	13400.00
0005434067518	12785	Economy	13400.00
0005432161175	12785	Economy	13400.00
0005434081804	12785	Economy	13400.00
0005434081911	12785	Economy	13400.00
0005434067520	12785	Economy	13400.00
0005434067856	12785	Economy	13400.00
0005434067679	12785	Economy	13400.00
0005433989768	12785	Economy	13400.00
0005434081841	12785	Economy	13400.00
0005434067266	12785	Economy	13400.00
0005434068236	30658	Business	40300.00
0005434068193	30658	Business	40300.00
0005434068198	30658	Business	40300.00
0005434068191	30658	Business	40300.00
0005434082126	30658	Business	40300.00
0005432186904	30658	Business	40300.00
0005434082116	30658	Business	40300.00
0005434068216	30658	Business	40300.00
0005434068190	30658	Business	40300.00
0005434068184	30658	Business	40300.00
0005434068215	30658	Business	40300.00
0005434068213	30658	Economy	13400.00
0005434068210	30658	Economy	13400.00
0005432150264	30658	Economy	13400.00
0005434068238	30658	Economy	13400.00
0005434068201	30658	Economy	13400.00
0005432186903	30658	Economy	13400.00
0005434068247	30658	Economy	13400.00
0005432433711	30658	Economy	13400.00
0005434068254	30658	Economy	13400.00
0005432150266	30658	Economy	13400.00
0005434068237	30658	Economy	13400.00
0005434068218	30658	Economy	13400.00
0005434082121	30658	Economy	13400.00
0005434082115	30658	Economy	13400.00
0005432433701	30658	Economy	13400.00
0005433989814	30658	Economy	13400.00
0005434068189	30658	Economy	13400.00
0005432150265	30658	Economy	13400.00
0005434068209	30658	Economy	13400.00
0005434068202	30658	Economy	13400.00
0005434082120	30658	Economy	13400.00
0005434068222	30658	Economy	13400.00
0005432433700	30658	Economy	13400.00
0005434082109	30658	Economy	13400.00
0005434082111	30658	Economy	13400.00
0005434068242	30658	Economy	13400.00
0005434068223	30658	Economy	13400.00
0005434068192	30658	Economy	13400.00
0005434082122	30658	Economy	13400.00
0005434068217	30658	Economy	13400.00
0005434082110	30658	Economy	13400.00
0005434068214	30658	Economy	13400.00
0005434068220	30658	Economy	13400.00
0005434068196	30658	Economy	13400.00
0005434068248	30658	Economy	13400.00
0005434082114	30658	Economy	13400.00
0005433989815	30658	Economy	13400.00
0005434068208	30658	Economy	14800.00
0005434068244	30658	Economy	14800.00
0005434068253	30658	Economy	14800.00
0005434068186	30658	Economy	14800.00
0005434068255	30658	Economy	14800.00
0005434068227	30658	Economy	13400.00
0005434082131	30658	Economy	13400.00
0005434068235	30658	Economy	13400.00
0005434068250	30658	Economy	13400.00
0005434068241	30658	Economy	13400.00
0005434068204	30658	Economy	13400.00
0005434068228	30658	Economy	13400.00
0005434068239	30658	Economy	13400.00
0005432150269	30658	Economy	13400.00
0005434068232	30658	Economy	13400.00
0005434068185	30658	Economy	13400.00
0005432433690	30658	Economy	13400.00
0005434068200	30658	Economy	13400.00
0005434068188	30658	Economy	13400.00
0005434082136	30658	Economy	13400.00
0005434068243	30658	Economy	13400.00
0005432186902	30658	Economy	13400.00
0005434082129	30658	Economy	13400.00
0005434068225	30658	Economy	13400.00
0005434068219	30658	Economy	13400.00
0005434068199	30658	Economy	13400.00
0005434082135	30658	Economy	13400.00
0005432150268	30658	Economy	13400.00
0005434082134	30658	Economy	13400.00
0005434068230	30658	Economy	13400.00
0005434068234	30658	Economy	13400.00
0005434082127	30658	Economy	13400.00
0005434068205	30658	Economy	13400.00
0005432433689	30658	Economy	13400.00
0005434068226	30658	Economy	13400.00
0005434082113	30658	Economy	13400.00
0005434068183	30658	Economy	13400.00
0005434068231	30658	Economy	13400.00
0005434082112	30658	Economy	13400.00
0005434068207	30658	Economy	13400.00
0005434068249	30658	Economy	13400.00
0005434068195	30658	Economy	13400.00
0005434082124	30658	Economy	13400.00
0005434082125	30658	Economy	13400.00
0005434068251	30658	Economy	13400.00
0005434068212	30658	Economy	13400.00
0005434082128	30658	Economy	13400.00
0005432150267	30658	Economy	13400.00
0005433989813	30658	Economy	13400.00
0005432433712	30658	Economy	13400.00
0005434068211	30658	Economy	13400.00
0005434082132	30658	Economy	13400.00
0005434068194	30658	Economy	13400.00
0005434082123	30658	Economy	13400.00
0005433989816	30658	Economy	13400.00
0005434068233	30658	Economy	13400.00
0005434082130	30658	Economy	13400.00
0005434082119	30658	Economy	13400.00
0005434068245	30658	Economy	13400.00
0005432150270	30658	Economy	13400.00
0005434082118	30658	Economy	13400.00
0005434068229	30658	Economy	13400.00
0005434082133	30658	Economy	13400.00
0005434068221	30658	Economy	13400.00
0005434068252	30658	Economy	13400.00
0005434068224	30658	Economy	13400.00
0005434068240	30658	Economy	13400.00
0005434068187	30658	Economy	13400.00
0005434082117	30658	Economy	13400.00
0005434068203	30658	Economy	13400.00
0005434068206	30658	Economy	13400.00
0005434068246	30658	Economy	13400.00
0005434068197	30658	Economy	13400.00
0005433685544	9039	Economy	19300.00
0005433685547	9039	Economy	19300.00
0005433687731	9039	Economy	17600.00
0005433685551	9039	Economy	17600.00
0005433685546	9039	Economy	17600.00
0005433685550	9039	Economy	17600.00
0005433687730	9039	Economy	17600.00
0005433687733	9039	Economy	17600.00
0005433686658	9039	Economy	17600.00
0005433687732	9039	Economy	17600.00
0005433686659	9039	Economy	17600.00
0005433685549	9039	Economy	17600.00
0005433685545	9039	Economy	17600.00
0005433686660	9039	Economy	17600.00
0005433687729	9039	Economy	17600.00
0005433687728	9039	Economy	17600.00
0005433686661	9039	Economy	17600.00
0005433686662	9039	Economy	17600.00
0005433685548	9039	Economy	17600.00
0005435766872	5494	Business	35300.00
0005435462575	5494	Business	35300.00
0005435766856	5494	Business	35300.00
0005435462460	5494	Business	35300.00
0005434265150	5494	Business	35300.00
0005434265198	5494	Business	35300.00
0005435462473	5494	Business	35300.00
0005435462683	5494	Business	35300.00
0005435462540	5494	Business	35300.00
0005435462669	5494	Business	35300.00
0005435462472	5494	Business	35300.00
0005435766870	5494	Business	35300.00
0005434265226	5494	Business	35300.00
0005432140528	5494	Business	35300.00
0005435462374	5494	Business	35300.00
0005435766834	5494	Business	35300.00
0005435462502	5494	Economy	12900.00
0005432140532	5494	Economy	12900.00
0005435722078	5494	Economy	12900.00
0005435766846	5494	Economy	11800.00
0005434265200	5494	Economy	11800.00
0005435766828	5494	Economy	11800.00
0005435766848	5494	Economy	11800.00
0005435462594	5494	Economy	11800.00
0005435735181	5494	Economy	11800.00
0005435766817	5494	Economy	11800.00
0005435766869	5494	Economy	11800.00
0005434265115	5494	Economy	11800.00
0005435766823	5494	Economy	11800.00
0005435766843	5494	Economy	11800.00
0005433527308	5494	Economy	11800.00
0005435462514	5494	Economy	11800.00
0005432140534	5494	Economy	11800.00
0005435462422	5494	Economy	11800.00
0005435462581	5494	Economy	11800.00
0005434265123	5494	Economy	11800.00
0005434831162	5494	Economy	11800.00
0005435725647	5494	Economy	11800.00
0005435462467	5494	Economy	11800.00
0005435462486	5494	Economy	11800.00
0005433527306	5494	Economy	11800.00
0005435766824	5494	Economy	11800.00
0005435462436	5494	Economy	11800.00
0005435462444	5494	Economy	11800.00
0005435462584	5494	Economy	11800.00
0005435720834	5494	Economy	11800.00
0005434265223	5494	Economy	11800.00
0005432535835	5494	Economy	11800.00
0005435462526	5494	Economy	11800.00
0005435766832	5494	Economy	11800.00
0005434265149	5494	Economy	11800.00
0005435766865	5494	Economy	11800.00
0005435766833	5494	Economy	11800.00
0005435766818	5494	Economy	11800.00
0005435766850	5494	Economy	11800.00
0005435462559	5494	Economy	11800.00
0005435766867	5494	Economy	11800.00
0005434265187	5494	Economy	11800.00
0005435462539	5494	Economy	11800.00
0005432535851	5494	Economy	11800.00
0005435766826	5494	Economy	11800.00
0005435766836	5494	Economy	11800.00
0005435766825	5494	Economy	11800.00
0005434265180	5494	Economy	11800.00
0005435462513	5494	Economy	11800.00
0005435766845	5494	Economy	11800.00
0005435462587	5494	Economy	11800.00
0005435766853	5494	Economy	11800.00
0005435462549	5494	Economy	11800.00
0005435722079	5494	Economy	11800.00
0005433527305	5494	Economy	11800.00
0005435462576	5494	Economy	11800.00
0005435725649	5494	Economy	11800.00
0005434265179	5494	Economy	11800.00
0005435766861	5494	Economy	11800.00
0005432140533	5494	Economy	11800.00
0005435462553	5494	Economy	11800.00
0005434265185	5494	Economy	11800.00
0005433529318	5494	Economy	11800.00
0005432535819	5494	Economy	11800.00
0005435766829	5494	Economy	11800.00
0005434265201	5494	Economy	11800.00
0005435766841	5494	Economy	11800.00
0005434831137	5494	Economy	11800.00
0005434265217	5494	Economy	11800.00
0005435462314	5494	Economy	11800.00
0005435462544	5494	Economy	11800.00
0005434265038	5494	Economy	11800.00
0005432140529	5494	Economy	11800.00
0005433529317	5494	Economy	11800.00
0005435462407	5494	Economy	11800.00
0005435735180	5494	Economy	11800.00
0005434265222	5494	Economy	11800.00
0005435725645	5494	Economy	11800.00
0005435725646	5494	Economy	11800.00
0005435766840	5494	Economy	11800.00
0005435766842	5494	Economy	11800.00
0005435462580	5494	Economy	11800.00
0005434265221	5494	Economy	11800.00
0005435725644	5494	Economy	11800.00
0005435766862	5494	Economy	11800.00
0005434265124	5494	Economy	11800.00
0005434265225	5494	Economy	11800.00
0005435766855	5494	Economy	11800.00
0005435766849	5494	Economy	12900.00
0005435766871	5494	Economy	11800.00
0005435766819	5494	Economy	11800.00
0005435766835	5494	Economy	12900.00
0005432535852	5494	Economy	12900.00
0005434265184	5494	Economy	11800.00
0005435462471	5494	Economy	11800.00
0005432140526	5494	Economy	11800.00
0005435766852	5494	Economy	11800.00
0005435462585	5494	Economy	11800.00
0005434265188	5494	Economy	11800.00
0005435725648	5494	Economy	11800.00
0005435462469	5494	Economy	11800.00
0005435462380	5494	Economy	11800.00
0005435766830	5494	Economy	11800.00
0005435766868	5494	Economy	11800.00
0005433529316	5494	Economy	11800.00
0005435766859	5494	Economy	11800.00
0005435462465	5494	Economy	11800.00
0005432535833	5494	Economy	11800.00
0005435766820	5494	Economy	11800.00
0005435462586	5494	Economy	11800.00
0005435766827	5494	Economy	11800.00
0005435462466	5494	Economy	11800.00
0005435462568	5494	Economy	11800.00
0005435766837	5494	Economy	11800.00
0005434831161	5494	Economy	11800.00
0005432140531	5494	Economy	11800.00
0005435462508	5494	Economy	11800.00
0005435766851	5494	Economy	11800.00
0005435766866	5494	Economy	11800.00
0005435462643	5494	Economy	11800.00
0005435766838	5494	Economy	11800.00
0005435462558	5494	Economy	11800.00
0005435766847	5494	Economy	11800.00
0005433529315	5494	Economy	11800.00
0005435766839	5494	Economy	11800.00
0005435766873	5494	Economy	11800.00
0005435766863	5494	Economy	11800.00
0005432535824	5494	Economy	11800.00
0005435766864	5494	Economy	11800.00
0005435735179	5494	Economy	11800.00
0005434831138	5494	Economy	11800.00
0005435462566	5494	Economy	11800.00
0005434265159	5494	Economy	11800.00
0005433527307	5494	Economy	11800.00
0005435462550	5494	Economy	11800.00
0005435462416	5494	Economy	11800.00
0005434265171	5494	Economy	11800.00
0005435766821	5494	Economy	11800.00
0005435766874	5494	Economy	11800.00
0005435462567	5494	Economy	11800.00
0005435766857	5494	Economy	11800.00
0005435766854	5494	Economy	11800.00
0005435766822	5494	Economy	11800.00
0005432140530	5494	Economy	11800.00
0005435766831	5494	Economy	11800.00
0005435766816	5494	Economy	11800.00
0005432140527	5494	Economy	11800.00
0005435462379	5494	Economy	11800.00
0005433527309	5494	Economy	11800.00
0005434265219	5494	Economy	11800.00
0005434265196	5494	Economy	11800.00
0005435766858	5494	Economy	11800.00
0005435766860	5494	Economy	11800.00
0005435462455	5494	Economy	11800.00
0005434265029	5494	Economy	11800.00
0005435462644	5494	Economy	11800.00
0005435735182	5494	Economy	11800.00
0005435766844	5494	Economy	11800.00
0005435462417	5494	Economy	11800.00
0005435766416	13443	Business	35300.00
0005434831199	13443	Business	35300.00
0005435766230	13443	Business	35300.00
0005435462829	13443	Business	35300.00
0005435766340	13443	Business	35300.00
0005435462817	13443	Business	35300.00
0005435720132	13443	Business	35300.00
0005435766470	13443	Business	35300.00
0005434265392	13443	Business	35300.00
0005435462828	13443	Business	35300.00
0005435725602	13443	Business	35300.00
0005435462806	13443	Business	35300.00
0005435766343	13443	Business	35300.00
0005435766059	13443	Business	35300.00
0005435766157	13443	Business	35300.00
0005435462831	13443	Business	35300.00
0005435725603	13443	Business	35300.00
0005435462832	13443	Business	35300.00
0005435766424	13443	Business	35300.00
0005435462812	13443	Economy	12900.00
0005434265400	13443	Economy	12900.00
0005435766255	13443	Economy	12900.00
0005435766366	13443	Economy	11800.00
0005435462814	13443	Economy	11800.00
0005432194554	13443	Economy	11800.00
0005435462821	13443	Economy	11800.00
0005435462815	13443	Economy	11800.00
0005435766324	13443	Economy	11800.00
0005435462808	13443	Economy	11800.00
0005435766477	13443	Economy	11800.00
0005434265394	13443	Economy	11800.00
0005435462827	13443	Economy	11800.00
0005435723048	13443	Economy	11800.00
0005434265406	13443	Economy	11800.00
0005435766144	13443	Economy	11800.00
0005434265390	13443	Economy	11800.00
0005435766050	13443	Economy	11800.00
0005435723044	13443	Economy	11800.00
0005432194552	13443	Economy	11800.00
0005435462818	13443	Economy	11800.00
0005435462810	13443	Economy	11800.00
0005435462824	13443	Economy	11800.00
0005434831202	13443	Economy	11800.00
0005434265409	13443	Economy	11800.00
0005435766145	13443	Economy	11800.00
0005435766341	13443	Economy	11800.00
0005435766460	13443	Economy	11800.00
0005435766154	13443	Economy	11800.00
0005435766413	13443	Economy	11800.00
0005435766429	13443	Economy	11800.00
0005434265396	13443	Economy	11800.00
0005435766297	13443	Economy	11800.00
0005435766302	13443	Economy	11800.00
0005435462807	13443	Economy	11800.00
0005435766187	13443	Economy	11800.00
0005435766354	13443	Economy	11800.00
0005435723047	13443	Economy	11800.00
0005434265391	13443	Economy	11800.00
0005434265408	13443	Economy	11800.00
0005434265414	13443	Economy	11800.00
0005434265389	13443	Economy	11800.00
0005435462822	13443	Economy	11800.00
0005435766136	13443	Economy	11800.00
0005434831200	13443	Economy	11800.00
0005435766220	13443	Economy	11800.00
0005435766493	13443	Economy	11800.00
0005435725601	13443	Economy	11800.00
0005435766108	13443	Economy	11800.00
0005434265405	13443	Economy	11800.00
0005435766186	13443	Economy	11800.00
0005434831198	13443	Economy	11800.00
0005435462802	13443	Economy	11800.00
0005435766222	13443	Economy	11800.00
0005434265397	13443	Economy	11800.00
0005435723043	13443	Economy	11800.00
0005435766135	13443	Economy	11800.00
0005434265404	13443	Economy	11800.00
0005435766303	13443	Economy	11800.00
0005434265411	13443	Economy	11800.00
0005435766166	13443	Economy	11800.00
0005435766131	13443	Economy	11800.00
0005435462835	13443	Economy	11800.00
0005435766151	13443	Economy	11800.00
0005435766155	13443	Economy	11800.00
0005435766352	13443	Economy	11800.00
0005435462820	13443	Economy	11800.00
0005434265393	13443	Economy	11800.00
0005435462801	13443	Economy	11800.00
0005435766271	13443	Economy	11800.00
0005434265403	13443	Economy	12900.00
0005435462803	13443	Economy	12900.00
0005432535886	13443	Economy	11800.00
0005435462837	13443	Economy	11800.00
0005435766156	13443	Economy	12900.00
0005435766459	13443	Economy	12900.00
0005434265398	13443	Economy	11800.00
0005435766415	13443	Economy	11800.00
0005435720134	13443	Economy	11800.00
0005432535882	13443	Economy	11800.00
0005432194553	13443	Economy	11800.00
0005435766364	13443	Economy	11800.00
0005435720133	13443	Economy	11800.00
0005434265413	13443	Economy	11800.00
0005435462805	13443	Economy	11800.00
0005435462825	13443	Economy	11800.00
0005432535885	13443	Economy	11800.00
0005435766058	13443	Economy	11800.00
0005435462819	13443	Economy	11800.00
0005435462826	13443	Economy	11800.00
0005435766474	13443	Economy	11800.00
0005435766335	13443	Economy	11800.00
0005435766420	13443	Economy	11800.00
0005435766152	13443	Economy	11800.00
0005434265399	13443	Economy	11800.00
0005435462800	13443	Economy	11800.00
0005435462816	13443	Economy	11800.00
0005435462804	13443	Economy	11800.00
0005434265395	13443	Economy	11800.00
0005435766419	13443	Economy	11800.00
0005435462830	13443	Economy	11800.00
0005435462834	13443	Economy	11800.00
0005435766393	13443	Economy	11800.00
0005434265401	13443	Economy	11800.00
0005435462813	13443	Economy	11800.00
0005435766325	13443	Economy	11800.00
0005435462811	13443	Economy	11800.00
0005435462836	13443	Economy	11800.00
0005432535883	13443	Economy	11800.00
0005432535884	13443	Economy	11800.00
0005434265412	13443	Economy	11800.00
0005434265410	13443	Economy	11800.00
0005435462823	13443	Economy	11800.00
0005435766203	13443	Economy	11800.00
0005435766356	13443	Economy	11800.00
0005435462833	13443	Economy	11800.00
0005434265415	13443	Economy	11800.00
0005435766476	13443	Economy	11800.00
0005434265402	13443	Economy	11800.00
0005435766355	13443	Economy	11800.00
0005435766117	13443	Economy	11800.00
0005435462809	13443	Economy	11800.00
0005435766256	13443	Economy	11800.00
0005435766296	13443	Economy	11800.00
0005435766609	13443	Economy	11800.00
0005434831201	13443	Economy	11800.00
0005434265407	13443	Economy	11800.00
0005435766204	13443	Economy	11800.00
0005434604913	18752	Economy	3300.00
0005434604882	18752	Economy	3300.00
0005434513603	18752	Economy	3300.00
0005434514991	18752	Economy	3300.00
0005434514992	18752	Economy	3300.00
0005434513605	18752	Economy	3300.00
0005434604881	18752	Economy	3300.00
0005434604914	18752	Economy	3300.00
0005434513604	18752	Economy	3300.00
0005434514993	18752	Economy	3300.00
0005434604893	18752	Economy	3300.00
0005434514980	19156	Economy	3300.00
0005434514977	19156	Economy	3300.00
0005434514976	19156	Economy	3300.00
0005435844290	4112	Business	88300.00
0005432649464	4112	Business	88300.00
0005432632806	4112	Business	88300.00
0005435844314	4112	Business	88300.00
0005435844319	4112	Business	88300.00
0005435844333	4112	Economy	29400.00
0005432649465	4112	Economy	29400.00
0005432632811	4112	Economy	29400.00
0005432632815	4112	Economy	29400.00
0005432649457	4112	Economy	32400.00
0005435846245	4112	Economy	32400.00
0005432649460	4112	Economy	32400.00
0005432632814	4112	Economy	29400.00
0005435846267	4112	Economy	29400.00
0005432649468	4112	Economy	29400.00
0005432632807	4112	Economy	29400.00
0005432632813	4112	Economy	29400.00
0005432649461	4112	Economy	29400.00
0005432649462	4112	Economy	29400.00
0005432649458	4112	Economy	29400.00
0005432632812	4112	Economy	29400.00
0005432632810	4112	Economy	29400.00
0005432632805	4112	Economy	29400.00
0005435846262	4112	Economy	29400.00
0005435844334	4112	Economy	29400.00
0005435844287	4112	Economy	29400.00
0005432649467	4112	Economy	29400.00
0005435844326	4112	Economy	29400.00
0005435846257	4112	Economy	29400.00
0005435844332	4112	Economy	29400.00
0005432649463	4112	Economy	29400.00
0005435844286	4112	Economy	29400.00
0005435846250	4112	Economy	29400.00
0005432632816	4112	Economy	29400.00
0005432632817	4112	Economy	29400.00
0005435844323	4112	Economy	29400.00
0005435844320	4112	Economy	29400.00
0005435844330	4112	Economy	29400.00
0005432632808	4112	Economy	29400.00
0005432649459	4112	Economy	29400.00
0005432632809	4112	Economy	29400.00
0005432649466	4112	Economy	29400.00
0005435844331	4112	Economy	29400.00
0005435844328	4112	Economy	29400.00
0005433285419	1839	Business	48700.00
0005433008632	1839	Business	48700.00
0005433008806	1839	Business	48700.00
0005433285432	1839	Business	48700.00
0005433008684	1839	Business	48700.00
0005433285227	1839	Business	48700.00
0005433285357	1839	Business	48700.00
0005433008637	1839	Business	48700.00
0005433008764	1839	Business	48700.00
0005433008631	1839	Business	48700.00
0005433285362	1839	Economy	16200.00
0005433285284	1839	Economy	16200.00
0005433285329	1839	Economy	16200.00
0005433285339	1839	Economy	16200.00
0005433008865	1839	Economy	17900.00
0005433008736	1839	Economy	17900.00
0005433008743	1839	Economy	17900.00
0005433810583	1839	Economy	17900.00
0005433285296	1839	Economy	16200.00
0005433008636	1839	Economy	16200.00
0005433285420	1839	Economy	16200.00
0005433008868	1839	Economy	16200.00
0005433285378	1839	Economy	16200.00
0005433008691	1839	Economy	16200.00
0005433008670	1839	Economy	16200.00
0005433008804	1839	Economy	16200.00
0005433008722	1839	Economy	16200.00
0005433008690	1839	Economy	16200.00
0005433285295	1839	Economy	16200.00
0005433008703	1839	Economy	16200.00
0005433008840	1839	Economy	16200.00
0005433285314	1839	Economy	16200.00
0005433285285	1839	Economy	16200.00
0005433285377	1839	Economy	16200.00
0005433285408	1839	Economy	16200.00
0005433285330	1839	Economy	16200.00
0005433008725	1839	Economy	16200.00
0005433810585	1839	Economy	16200.00
0005433285369	1839	Economy	16200.00
0005433285384	1839	Economy	16200.00
0005433008813	1839	Economy	16200.00
0005433008671	1839	Economy	16200.00
0005433285358	1839	Economy	16200.00
0005433008694	1839	Economy	16200.00
0005433008649	1839	Economy	16200.00
0005433008852	1839	Economy	16200.00
0005433285283	1839	Economy	16200.00
0005433008693	1839	Economy	16200.00
0005433285361	1839	Economy	16200.00
0005432295907	1839	Economy	16200.00
0005433285379	1839	Economy	16200.00
0005433008716	1839	Economy	16200.00
0005433008426	1839	Economy	16200.00
0005433285430	1839	Economy	16200.00
0005433008765	1839	Economy	16200.00
0005433008818	1839	Economy	16200.00
0005433008250	1839	Economy	16200.00
0005433008763	1839	Economy	16200.00
0005433008677	1839	Economy	16200.00
0005433008807	1839	Economy	16200.00
0005433008781	1839	Economy	16200.00
0005433810584	1839	Economy	16200.00
0005433008661	1839	Economy	16200.00
0005433285340	1839	Economy	16200.00
0005433008697	1839	Economy	16200.00
0005433008866	1839	Economy	16200.00
0005433285415	1839	Economy	16200.00
0005432295906	1839	Economy	16200.00
0005433008401	1839	Economy	16200.00
0005433008704	1839	Economy	16200.00
0005433008805	1839	Economy	16200.00
0005433008747	1839	Economy	16200.00
0005433285350	1839	Economy	16200.00
0005433008803	1839	Economy	16200.00
0005433008802	1839	Economy	16200.00
0005433285583	22571	Business	48700.00
0005433009043	22571	Business	48700.00
0005433285597	22571	Business	48700.00
0005433285612	22571	Business	48700.00
0005433009070	22571	Business	48700.00
0005433009045	22571	Business	48700.00
0005433285605	22571	Business	48700.00
0005433009047	22571	Business	48700.00
0005433285598	22571	Business	48700.00
0005433285599	22571	Business	48700.00
0005433285596	22571	Business	48700.00
0005433009038	22571	Economy	16200.00
0005433009029	22571	Economy	16200.00
0005433285585	22571	Economy	16200.00
0005433285606	22571	Economy	16200.00
0005433810521	22571	Economy	16200.00
0005433285610	22571	Economy	16200.00
0005433285604	22571	Economy	16200.00
0005433009034	22571	Economy	17900.00
0005433009058	22571	Economy	17900.00
0005433009035	22571	Economy	17900.00
0005433285588	22571	Economy	17900.00
0005433285584	22571	Economy	17900.00
0005433009044	22571	Economy	16200.00
0005433009055	22571	Economy	16200.00
0005433009031	22571	Economy	16200.00
0005433009068	22571	Economy	16200.00
0005433009054	22571	Economy	16200.00
0005433009046	22571	Economy	16200.00
0005433009041	22571	Economy	16200.00
0005433009032	22571	Economy	16200.00
0005433009056	22571	Economy	16200.00
0005433009057	22571	Economy	16200.00
0005433285589	22571	Economy	16200.00
0005433009061	22571	Economy	16200.00
0005433009039	22571	Economy	16200.00
0005433009030	22571	Economy	16200.00
0005433810529	22571	Economy	16200.00
0005433009059	22571	Economy	16200.00
0005433810526	22571	Economy	16200.00
0005433009051	22571	Economy	16200.00
0005433009065	22571	Economy	16200.00
0005433810534	22571	Economy	16200.00
0005433009071	22571	Economy	16200.00
0005433285611	22571	Economy	16200.00
0005433009072	22571	Economy	16200.00
0005433285591	22571	Economy	16200.00
0005433285594	22571	Economy	16200.00
0005433009073	22571	Economy	16200.00
0005433285613	22571	Economy	16200.00
0005433285587	22571	Economy	16200.00
0005433285590	22571	Economy	16200.00
0005433009048	22571	Economy	16200.00
0005433285600	22571	Economy	16200.00
0005433009069	22571	Economy	16200.00
0005433009053	22571	Economy	16200.00
0005433009064	22571	Economy	16200.00
0005433285608	22571	Economy	16200.00
0005433009066	22571	Economy	16200.00
0005433285592	22571	Economy	16200.00
0005433285601	22571	Economy	16200.00
0005433285582	22571	Economy	16200.00
0005433285607	22571	Economy	16200.00
0005433009042	22571	Economy	16200.00
0005433009037	22571	Economy	16200.00
0005433009063	22571	Economy	16200.00
0005433009052	22571	Economy	16200.00
0005433810533	22571	Economy	16200.00
0005433009060	22571	Economy	16200.00
0005433285602	22571	Economy	16200.00
0005433009040	22571	Economy	16200.00
0005433285603	22571	Economy	16200.00
0005433285586	22571	Economy	16200.00
0005433009033	22571	Economy	16200.00
0005433009062	22571	Economy	16200.00
0005433285593	22571	Economy	16200.00
0005433009036	22571	Economy	16200.00
0005433285609	22571	Economy	16200.00
0005433009067	22571	Economy	16200.00
0005433009050	22571	Economy	16200.00
0005433009028	22571	Economy	16200.00
0005433285595	22571	Economy	16200.00
0005433009049	22571	Economy	16200.00
0005432751527	12278	Business	83800.00
0005432751533	12278	Economy	27900.00
0005432751524	12278	Economy	27900.00
0005432755051	12278	Economy	30700.00
0005432751498	12278	Economy	30700.00
0005432751537	12278	Economy	30700.00
0005432751525	12278	Economy	27900.00
0005432755054	12278	Economy	27900.00
0005434152806	12278	Economy	27900.00
0005434152810	12278	Economy	27900.00
0005432755059	12278	Economy	27900.00
0005434152803	12278	Economy	27900.00
0005432755067	12278	Economy	27900.00
0005434152807	12278	Economy	27900.00
0005432751516	12278	Economy	27900.00
0005432755086	12278	Economy	27900.00
0005432755071	12278	Economy	27900.00
0005434152811	12278	Economy	27900.00
0005434152813	12278	Economy	27900.00
0005434152805	12278	Economy	27900.00
0005432751523	12278	Economy	27900.00
0005432755060	12278	Economy	27900.00
0005434152809	12278	Economy	27900.00
0005432755080	12278	Economy	27900.00
0005434152812	12278	Economy	27900.00
0005432751518	12278	Economy	27900.00
0005434152808	12278	Economy	27900.00
0005432755066	12278	Economy	27900.00
0005434152804	12278	Economy	27900.00
0005432751519	12278	Economy	27900.00
0005432755056	12278	Economy	27900.00
0005432755068	12278	Economy	27900.00
0005433847300	5584	Business	99800.00
0005435282516	5584	Business	99800.00
0005433847293	5584	Business	99800.00
0005433847329	5584	Business	99800.00
0005433847325	5584	Business	99800.00
0005433815430	5584	Business	99800.00
0005434173519	5584	Business	99800.00
0005435282431	5584	Business	99800.00
0005433847295	5584	Business	99800.00
0005434173509	5584	Business	99800.00
0005435282448	5584	Business	99800.00
0005432081577	5584	Business	99800.00
0005433847310	5584	Business	99800.00
0005433847314	5584	Business	99800.00
0005435282568	5584	Business	99800.00
0005433847298	5584	Business	99800.00
0005432081576	5584	Business	99800.00
0005432081574	5584	Business	99800.00
0005433847331	5584	Economy	33300.00
0005433847278	5584	Economy	33300.00
0005433847303	5584	Economy	33300.00
0005435282574	5584	Economy	33300.00
0005433847334	5584	Economy	33300.00
0005434173510	5584	Economy	33300.00
0005435282575	5584	Economy	33300.00
0005433847289	5584	Economy	33300.00
0005434173520	5584	Economy	33300.00
0005433847294	5584	Economy	33300.00
0005435282565	5584	Economy	33300.00
0005435282569	5584	Economy	33300.00
0005433847309	5584	Economy	36600.00
0005433847318	5584	Economy	36600.00
0005433847319	5584	Economy	36600.00
0005435282506	5584	Economy	36600.00
0005433847297	5584	Economy	33300.00
0005433847288	5584	Economy	33300.00
0005433847296	5584	Economy	33300.00
0005433847336	5584	Economy	33300.00
0005433847328	5584	Economy	33300.00
0005433847279	5584	Economy	33300.00
0005433847282	5584	Economy	33300.00
0005435282498	5584	Economy	33300.00
0005433847308	5584	Economy	33300.00
0005433847312	5584	Economy	33300.00
0005435282582	5584	Economy	33300.00
0005433847323	5584	Economy	33300.00
0005435282544	5584	Economy	33300.00
0005435282509	5584	Economy	33300.00
0005435282447	5584	Economy	33300.00
0005433847292	5584	Economy	33300.00
0005435282588	5584	Economy	33300.00
0005433847284	5584	Economy	33300.00
0005433847291	5584	Economy	33300.00
0005433847320	5584	Economy	33300.00
0005433847326	5584	Economy	33300.00
0005435282545	5584	Economy	33300.00
0005435282508	5584	Economy	33300.00
0005435282507	5584	Economy	33300.00
0005433847333	5584	Economy	33300.00
0005435282566	5584	Economy	33300.00
0005435282584	5584	Economy	33300.00
0005433847305	5584	Economy	33300.00
0005433847324	5584	Economy	33300.00
0005433847285	5584	Economy	33300.00
0005433815431	5584	Economy	33300.00
0005432081573	5584	Economy	33300.00
0005433847302	5584	Economy	33300.00
0005433847283	5584	Economy	33300.00
0005433847301	5584	Economy	33300.00
0005433847330	5584	Economy	33300.00
0005433847321	5584	Economy	33300.00
0005433847337	5584	Economy	33300.00
0005433847281	5584	Economy	33300.00
0005435282512	5584	Economy	33300.00
0005435282519	5584	Economy	33300.00
0005433847290	5584	Economy	33300.00
0005433847306	5584	Economy	33300.00
0005433815429	5584	Economy	33300.00
0005433815433	5584	Economy	33300.00
0005433847307	5584	Economy	33300.00
0005433847332	5584	Economy	33300.00
0005434173511	5584	Economy	33300.00
0005433847322	5584	Economy	33300.00
0005435282600	5584	Economy	33300.00
0005433847299	5584	Economy	33300.00
0005433847286	5584	Economy	33300.00
0005433847313	5584	Economy	33300.00
0005433847335	5584	Economy	33300.00
0005433847304	5584	Economy	33300.00
0005435282586	5584	Economy	33300.00
0005432081572	5584	Economy	33300.00
0005432081575	5584	Economy	33300.00
0005433847327	5584	Economy	33300.00
0005432081578	5584	Economy	33300.00
0005433847287	5584	Economy	33300.00
0005433847311	5584	Economy	33300.00
0005433847280	5584	Economy	33300.00
0005433847317	5584	Economy	33300.00
0005433847315	5584	Economy	33300.00
0005435282585	5584	Economy	33300.00
0005433815432	5584	Economy	33300.00
0005435282587	5584	Economy	33300.00
0005435282480	5584	Economy	33300.00
0005433847277	5584	Economy	33300.00
0005435282435	5584	Economy	33300.00
0005433847316	5584	Economy	33300.00
0005433846801	13871	Business	99800.00
0005433846690	13871	Business	99800.00
0005433846854	13871	Business	99800.00
0005435282753	13871	Business	99800.00
0005435282761	13871	Business	99800.00
0005433846768	13871	Business	99800.00
0005435282763	13871	Business	99800.00
0005433846723	13871	Business	99800.00
0005433846712	13871	Business	99800.00
0005433846785	13871	Business	99800.00
0005433847014	13871	Business	99800.00
0005435282759	13871	Business	99800.00
0005433847001	13871	Business	99800.00
0005434173563	13871	Business	99800.00
0005435282766	13871	Economy	33300.00
0005433846683	13871	Business	99800.00
0005432003732	13871	Economy	33300.00
0005433846514	13871	Economy	33300.00
0005435282769	13871	Economy	33300.00
0005433846665	13871	Economy	33300.00
0005433815377	13871	Economy	33300.00
0005433846666	13871	Economy	33300.00
0005433847047	13871	Economy	33300.00
0005433846933	13871	Economy	33300.00
0005434173561	13871	Economy	36600.00
0005433846944	13871	Economy	33300.00
0005435282755	13871	Economy	36600.00
0005433846733	13871	Economy	33300.00
0005435282760	13871	Economy	33300.00
0005433846832	13871	Economy	33300.00
0005432003733	13871	Economy	33300.00
0005434173560	13871	Economy	33300.00
0005434173562	13871	Economy	33300.00
0005433846765	13871	Economy	33300.00
0005433846713	13871	Economy	33300.00
0005435282768	13871	Economy	33300.00
0005435282770	13871	Economy	33300.00
0005433815404	13871	Economy	33300.00
0005435282765	13871	Economy	33300.00
0005433846938	13871	Economy	33300.00
0005433846873	13871	Economy	33300.00
0005433846830	13871	Economy	33300.00
0005433846831	13871	Economy	33300.00
0005435282762	13871	Economy	33300.00
0005433846796	13871	Economy	33300.00
0005433847000	13871	Economy	33300.00
0005433846755	13871	Economy	33300.00
0005433846729	13871	Economy	33300.00
0005435282758	13871	Economy	33300.00
0005433846937	13871	Economy	33300.00
0005433846795	13871	Economy	33300.00
0005435282756	13871	Economy	33300.00
0005433846888	13871	Economy	33300.00
0005433846924	13871	Economy	33300.00
0005433847079	13871	Economy	33300.00
0005433815376	13871	Economy	33300.00
0005433846689	13871	Economy	33300.00
0005432003731	13871	Economy	33300.00
0005435282754	13871	Economy	33300.00
0005433846900	13871	Economy	33300.00
0005435282757	13871	Economy	33300.00
0005435282752	13871	Economy	33300.00
0005433846703	13871	Economy	33300.00
0005433846646	13871	Economy	33300.00
0005433847037	13871	Economy	33300.00
0005433846928	13871	Economy	33300.00
0005432003734	13871	Economy	33300.00
0005433847095	13871	Economy	33300.00
0005433846767	13871	Economy	33300.00
0005433846653	13871	Economy	33300.00
0005433846923	13871	Economy	33300.00
0005435282764	13871	Economy	33300.00
0005433846973	13871	Economy	33300.00
0005433846784	13871	Economy	33300.00
0005433847066	13871	Economy	33300.00
0005433846939	13871	Economy	33300.00
0005433846645	13871	Economy	33300.00
0005433846841	13871	Economy	33300.00
0005433846475	13871	Economy	33300.00
0005433846684	13871	Economy	33300.00
0005435282767	13871	Economy	33300.00
0005433847078	13871	Economy	33300.00
0005435332339	7848	Economy	16600.00
0005434620800	7848	Economy	16600.00
0005434620809	7848	Economy	16600.00
0005434620792	7848	Economy	15100.00
0005434620791	7848	Economy	15100.00
0005434620795	7848	Economy	15100.00
0005434620803	7848	Economy	15100.00
0005435332370	7848	Economy	15100.00
0005434620794	7848	Economy	15100.00
0005434620805	7848	Economy	15100.00
0005435332349	7848	Economy	15100.00
0005434620810	7848	Economy	15100.00
0005432112539	7848	Economy	15100.00
0005434620798	7848	Economy	15100.00
0005432112538	7848	Economy	15100.00
0005434620808	7848	Economy	15100.00
0005434620796	7848	Economy	15100.00
0005434620799	7848	Economy	15100.00
0005434620793	7848	Economy	15100.00
0005434620802	7848	Economy	15100.00
0005435332350	7848	Economy	15100.00
0005434620806	7848	Economy	15100.00
0005434620801	7848	Economy	15100.00
0005434620807	7848	Economy	15100.00
0005434620797	7848	Economy	15100.00
0005434620804	7848	Economy	15100.00
0005434620633	32968	Economy	16600.00
0005434620675	32968	Economy	16600.00
0005435332443	32968	Economy	16600.00
0005435332444	32968	Economy	15100.00
0005434620625	32968	Economy	15100.00
0005435332437	32968	Economy	15100.00
0005435332435	32968	Economy	15100.00
0005434620638	32968	Economy	15100.00
0005434620624	32968	Economy	15100.00
0005435332440	32968	Economy	15100.00
0005434620613	32968	Economy	15100.00
0005434620590	32968	Economy	15100.00
0005435332441	32968	Economy	15100.00
0005434620701	32968	Economy	15100.00
0005434620639	32968	Economy	15100.00
0005434620626	32968	Economy	15100.00
0005434620674	32968	Economy	15100.00
0005434620678	32968	Economy	15100.00
0005435332436	32968	Economy	15100.00
0005435332438	32968	Economy	15100.00
0005435332442	32968	Economy	15100.00
0005434620566	32968	Economy	15100.00
0005434620571	32968	Economy	15100.00
0005435332439	32968	Economy	15100.00
0005434620634	32968	Economy	15100.00
0005434620589	32968	Economy	15100.00
0005434620700	32968	Economy	15100.00
0005435785703	4275	Business	38000.00
0005434994118	4275	Business	38000.00
0005435785711	4275	Business	38000.00
0005435785717	4275	Business	38000.00
0005434994119	4275	Business	38000.00
0005435785701	4275	Business	38000.00
0005435785716	4275	Business	38000.00
0005435785715	4275	Economy	12700.00
0005435785699	4275	Economy	12700.00
0005435918664	4275	Economy	12700.00
0005435785686	4275	Economy	12700.00
0005435785696	4275	Economy	12700.00
0005435785718	4275	Economy	13900.00
0005435785708	4275	Economy	13900.00
0005432190667	4275	Economy	12700.00
0005435785688	4275	Economy	12700.00
0005434994116	4275	Economy	12700.00
0005435785700	4275	Economy	12700.00
0005435785719	4275	Economy	12700.00
0005435785694	4275	Economy	12700.00
0005435918666	4275	Economy	12700.00
0005435785712	4275	Economy	12700.00
0005435918665	4275	Economy	12700.00
0005435785692	4275	Economy	12700.00
0005435785704	4275	Economy	12700.00
0005435937401	4275	Economy	12700.00
0005435785697	4275	Economy	12700.00
0005435785690	4275	Economy	12700.00
0005435785705	4275	Economy	12700.00
0005435785695	4275	Economy	12700.00
0005435785689	4275	Economy	12700.00
0005435937393	4275	Economy	12700.00
0005435785693	4275	Economy	12700.00
0005435787375	4275	Economy	12700.00
0005434994117	4275	Economy	12700.00
0005435918675	4275	Economy	12700.00
0005435937390	4275	Economy	12700.00
0005432190669	4275	Economy	12700.00
0005434994123	4275	Economy	12700.00
0005435785707	4275	Economy	12700.00
0005435785702	4275	Economy	12700.00
0005432190668	4275	Economy	12700.00
0005435937392	4275	Economy	12700.00
0005435785706	4275	Economy	12700.00
0005434994122	4275	Economy	12700.00
0005435785691	4275	Economy	12700.00
0005435785687	4275	Economy	12700.00
0005435787376	4275	Economy	12700.00
0005435785714	4275	Economy	12700.00
0005435785713	4275	Economy	12700.00
0005435785710	4275	Economy	12700.00
0005435918667	4275	Economy	12700.00
0005435785685	4275	Economy	12700.00
0005434994115	4275	Economy	12700.00
0005435918647	4275	Economy	12700.00
0005434994124	4275	Economy	12700.00
0005435785709	4275	Economy	12700.00
0005435785698	4275	Economy	12700.00
0005434994121	4275	Economy	12700.00
0005434994120	4275	Economy	12700.00
0005435785270	27275	Business	38000.00
0005435785269	27275	Business	38000.00
0005435785453	27275	Business	38000.00
0005435785435	27275	Business	38000.00
0005435785350	27275	Business	38000.00
0005435785366	27275	Business	38000.00
0005435785365	27275	Economy	12700.00
0005435785249	27275	Economy	12700.00
0005435785220	27275	Economy	12700.00
0005435918704	27275	Economy	12700.00
0005435785380	27275	Economy	12700.00
0005435785379	27275	Economy	12700.00
0005435785360	27275	Economy	12700.00
0005435785323	27275	Economy	13900.00
0005435785367	27275	Economy	13900.00
0005435937425	27275	Economy	13900.00
0005435937428	27275	Economy	12700.00
0005435785250	27275	Economy	12700.00
0005435785356	27275	Economy	12700.00
0005435785273	27275	Economy	12700.00
0005432195712	27275	Economy	12700.00
0005434994045	27275	Economy	12700.00
0005435937420	27275	Economy	12700.00
0005435937423	27275	Economy	12700.00
0005435937426	27275	Economy	12700.00
0005435785355	27275	Economy	12700.00
0005432195713	27275	Economy	12700.00
0005435785284	27275	Economy	12700.00
0005435937418	27275	Economy	12700.00
0005435785436	27275	Economy	12700.00
0005435785353	27275	Economy	12700.00
0005434994026	27275	Economy	12700.00
0005434994037	27275	Economy	12700.00
0005435937422	27275	Economy	12700.00
0005434994001	27275	Economy	12700.00
0005434994042	27275	Economy	12700.00
0005435785299	27275	Economy	12700.00
0005434994040	27275	Economy	12700.00
0005435937427	27275	Economy	12700.00
0005435937419	27275	Economy	12700.00
0005435785361	27275	Economy	12700.00
0005435918705	27275	Economy	12700.00
0005435937424	27275	Economy	12700.00
0005435785454	27275	Economy	12700.00
0005435787356	27275	Economy	12700.00
0005435785318	27275	Economy	12700.00
0005435918702	27275	Economy	12700.00
0005435937421	27275	Economy	12700.00
0005434994062	27275	Economy	12700.00
0005435785432	27275	Economy	12700.00
0005435785274	27275	Economy	12700.00
0005435785467	27275	Economy	12700.00
0005435785288	27275	Economy	12700.00
0005435785354	27275	Economy	12700.00
0005435918703	27275	Economy	12700.00
0005435785193	27275	Economy	12700.00
0005434994046	27275	Economy	12700.00
0005435785344	27275	Economy	12700.00
0005432146218	19854	Economy	12800.00
0005434082147	4749	Business	40900.00
0005432571358	4749	Business	40900.00
0005432460370	4749	Business	40900.00
0005432568228	4749	Business	40900.00
0005432568257	4749	Business	40900.00
0005432568263	4749	Business	40900.00
0005432568243	4749	Business	40900.00
0005432460373	4749	Business	40900.00
0005432460379	4749	Business	40900.00
0005432460356	4749	Business	40900.00
0005432460361	4749	Business	40900.00
0005434082154	4749	Business	40900.00
0005434082157	4749	Business	40900.00
0005432460365	4749	Business	40900.00
0005432460354	4749	Business	40900.00
0005432460398	4749	Business	40900.00
0005432460369	4749	Business	40900.00
0005432568274	4749	Business	40900.00
0005433726127	4749	Business	40900.00
0005432460359	4749	Business	40900.00
0005432568242	4749	Business	40900.00
0005432186906	4749	Business	40900.00
0005432460376	4749	Business	40900.00
0005432460392	4749	Business	40900.00
0005432568217	4749	Economy	15000.00
0005432568221	4749	Economy	15000.00
0005432460364	4749	Economy	15000.00
0005432460378	4749	Economy	13600.00
0005434082156	4749	Economy	13600.00
0005432568254	4749	Economy	13600.00
0005432186905	4749	Economy	13600.00
0005432460355	4749	Economy	13600.00
0005432568267	4749	Economy	13600.00
0005432568216	4749	Economy	13600.00
0005434082140	4749	Economy	13600.00
0005432568234	4749	Economy	13600.00
0005432460395	4749	Economy	13600.00
0005432568235	4749	Economy	13600.00
0005432568239	4749	Economy	13600.00
0005433726128	4749	Economy	13600.00
0005434082138	4749	Economy	13600.00
0005432568253	4749	Economy	13600.00
0005432568215	4749	Economy	13600.00
0005433452761	4749	Economy	13600.00
0005432460367	4749	Economy	13600.00
0005432568250	4749	Economy	13600.00
0005432460384	4749	Economy	13600.00
0005432568255	4749	Economy	13600.00
0005432568222	4749	Economy	13600.00
0005434082155	4749	Economy	13600.00
0005432568270	4749	Economy	13600.00
0005432460352	4749	Economy	13600.00
0005432568219	4749	Economy	13600.00
0005432568245	4749	Economy	13600.00
0005432568276	4749	Economy	13600.00
0005433726129	4749	Economy	13600.00
0005432460388	4749	Economy	13600.00
0005432568237	4749	Economy	13600.00
0005434082153	4749	Economy	13600.00
0005434082150	4749	Economy	13600.00
0005434082139	4749	Economy	13600.00
0005434082152	4749	Economy	13600.00
0005432568258	4749	Economy	13600.00
0005434082143	4749	Economy	13600.00
0005432460397	4749	Economy	13600.00
0005432568256	4749	Economy	13600.00
0005432568266	4749	Economy	13600.00
0005432460371	4749	Economy	13600.00
0005432568248	4749	Economy	13600.00
0005432568262	4749	Economy	13600.00
0005432568260	4749	Economy	13600.00
0005434082144	4749	Economy	13600.00
0005432460368	4749	Economy	13600.00
0005432568244	4749	Economy	13600.00
0005432568268	4749	Economy	13600.00
0005432460385	4749	Economy	13600.00
0005432568269	4749	Economy	13600.00
0005432460389	4749	Economy	13600.00
0005434082142	4749	Economy	13600.00
0005432460362	4749	Economy	13600.00
0005432170456	4749	Economy	13600.00
0005432170453	4749	Economy	13600.00
0005432568261	4749	Economy	13600.00
0005432571361	4749	Economy	13600.00
0005432568249	4749	Economy	13600.00
0005432568251	4749	Economy	13600.00
0005432170457	4749	Economy	13600.00
0005432568226	4749	Economy	13600.00
0005432568227	4749	Economy	13600.00
0005432460390	4749	Economy	13600.00
0005432460350	4749	Economy	13600.00
0005432186909	4749	Economy	13600.00
0005432460380	4749	Economy	13600.00
0005432460377	4749	Economy	13600.00
0005432568273	4749	Economy	13600.00
0005432170458	4749	Economy	13600.00
0005432460394	4749	Economy	13600.00
0005432460382	4749	Economy	15000.00
0005432460396	4749	Economy	13600.00
0005432568218	4749	Economy	15000.00
0005432170459	4749	Economy	13600.00
0005432460351	4749	Economy	13600.00
0005432568264	4749	Economy	13600.00
0005432460348	4749	Economy	15000.00
0005432568240	4749	Economy	13600.00
0005434082148	4749	Economy	13600.00
0005432568246	4749	Economy	13600.00
0005434082151	4749	Economy	13600.00
0005432460372	4749	Economy	13600.00
0005432568275	4749	Economy	13600.00
0005432460381	4749	Economy	13600.00
0005432568247	4749	Economy	13600.00
0005432568259	4749	Economy	13600.00
0005432460374	4749	Economy	13600.00
0005432568225	4749	Economy	13600.00
0005432460383	4749	Economy	13600.00
0005432568224	4749	Economy	13600.00
0005432460375	4749	Economy	13600.00
0005432460387	4749	Economy	13600.00
0005433451638	4749	Economy	13600.00
0005432568272	4749	Economy	13600.00
0005432568233	4749	Economy	13600.00
0005432186908	4749	Economy	13600.00
0005432460393	4749	Economy	13600.00
0005432568220	4749	Economy	13600.00
0005432460391	4749	Economy	13600.00
0005432568241	4749	Economy	13600.00
0005432568230	4749	Economy	13600.00
0005432568229	4749	Economy	13600.00
0005432460363	4749	Economy	13600.00
0005432460349	4749	Economy	13600.00
0005432568238	4749	Economy	13600.00
0005434082146	4749	Economy	13600.00
0005432568214	4749	Economy	13600.00
0005432460360	4749	Economy	13600.00
0005434082141	4749	Economy	13600.00
0005432170455	4749	Economy	13600.00
0005434082145	4749	Economy	13600.00
0005434082149	4749	Economy	13600.00
0005434082137	4749	Economy	13600.00
0005432568252	4749	Economy	13600.00
0005432460358	4749	Economy	13600.00
0005432460366	4749	Economy	13600.00
0005432460347	4749	Economy	13600.00
0005432568223	4749	Economy	13600.00
0005432568232	4749	Economy	13600.00
0005432568271	4749	Economy	13600.00
0005432460353	4749	Economy	13600.00
0005432186907	4749	Economy	13600.00
0005433451639	4749	Economy	13600.00
0005433726126	4749	Economy	13600.00
0005433452760	4749	Economy	13600.00
0005432460357	4749	Economy	13600.00
0005432460346	4749	Economy	13600.00
0005432571360	4749	Economy	13600.00
0005432568231	4749	Economy	13600.00
0005432571359	4749	Economy	13600.00
0005432568236	4749	Economy	13600.00
0005432568265	4749	Economy	13600.00
0005432170454	4749	Economy	13600.00
0005432460386	4749	Economy	13600.00
0005432567899	30567	Business	40900.00
0005433454886	30567	Business	40900.00
0005432567898	30567	Business	40900.00
0005432161174	30567	Business	40900.00
0005432567978	30567	Business	40900.00
0005432567584	30567	Business	40900.00
0005432567682	30567	Business	40900.00
0005432567494	30567	Business	40900.00
0005433452748	30567	Business	40900.00
0005434081977	30567	Business	40900.00
0005432460094	30567	Business	40900.00
0005432213644	30567	Business	40900.00
0005432459878	30567	Business	40900.00
0005432459966	30567	Business	40900.00
0005432567661	30567	Business	40900.00
0005432567512	30567	Business	40900.00
0005432567829	30567	Economy	15000.00
0005434081828	30567	Economy	15000.00
0005434081823	30567	Economy	13600.00
0005433452738	30567	Economy	13600.00
0005432459986	30567	Economy	13600.00
0005434081800	30567	Economy	13600.00
0005432459813	30567	Economy	13600.00
0005432459870	30567	Economy	13600.00
0005434081830	30567	Economy	13600.00
0005432460049	30567	Economy	13600.00
0005432567947	30567	Economy	13600.00
0005432460030	30567	Economy	13600.00
0005432567727	30567	Economy	13600.00
0005432567931	30567	Economy	13600.00
0005432459836	30567	Economy	13600.00
0005432567511	30567	Economy	13600.00
0005432459976	30567	Economy	13600.00
0005432567600	30567	Economy	13600.00
0005432459974	30567	Economy	13600.00
0005432460029	30567	Economy	13600.00
0005433452739	30567	Economy	13600.00
0005432460018	30567	Economy	13600.00
0005432568119	30567	Economy	13600.00
0005432567716	30567	Economy	13600.00
0005432567603	30567	Economy	13600.00
0005432460020	30567	Economy	13600.00
0005432459678	30567	Economy	13600.00
0005432567967	30567	Economy	13600.00
0005432459965	30567	Economy	13600.00
0005432567466	30567	Economy	13600.00
0005432567825	30567	Economy	13600.00
0005432460167	30567	Economy	13600.00
0005432567847	30567	Economy	13600.00
0005432567719	30567	Economy	13600.00
0005434081933	30567	Economy	13600.00
0005432213645	30567	Economy	13600.00
0005432459791	30567	Economy	13600.00
0005432459924	30567	Economy	13600.00
0005432459945	30567	Economy	13600.00
0005432459985	30567	Economy	13600.00
0005434081910	30567	Economy	13600.00
0005432459862	30567	Economy	13600.00
0005434081841	30567	Economy	13600.00
0005434081891	30567	Economy	13600.00
0005432567764	30567	Economy	13600.00
0005432567884	30567	Economy	13600.00
0005432459696	30567	Economy	13600.00
0005434081935	30567	Economy	13600.00
0005432567937	30567	Economy	13600.00
0005432567597	30567	Economy	13600.00
0005432567907	30567	Economy	13600.00
0005432460086	30567	Economy	13600.00
0005434081972	30567	Economy	13600.00
0005432460044	30567	Economy	13600.00
0005432460048	30567	Economy	13600.00
0005434559092	30567	Economy	13600.00
0005432459977	30567	Economy	13600.00
0005432567639	30567	Economy	13600.00
0005432567601	30567	Economy	13600.00
0005432567588	30567	Economy	13600.00
0005432459900	30567	Economy	13600.00
0005432567989	30567	Economy	13600.00
0005432459956	30567	Economy	13600.00
0005434081804	30567	Economy	13600.00
0005432567809	30567	Economy	13600.00
0005432567676	30567	Economy	13600.00
0005434081866	30567	Economy	13600.00
0005432567763	30567	Economy	13600.00
0005432567674	30567	Economy	13600.00
0005432567589	30567	Economy	13600.00
0005432459954	30567	Economy	13600.00
0005432567726	30567	Economy	13600.00
0005434559094	30567	Economy	13600.00
0005434081899	30567	Economy	13600.00
0005432567999	30567	Economy	13600.00
0005432459744	30567	Economy	13600.00
0005432567677	30567	Economy	13600.00
0005432460131	30567	Economy	13600.00
0005432567754	30567	Economy	13600.00
0005434082049	30567	Economy	13600.00
0005432460042	30567	Economy	13600.00
0005434559090	30567	Economy	15000.00
0005434081911	30567	Economy	13600.00
0005432460064	30567	Economy	15000.00
0005434081961	30567	Economy	13600.00
0005432571325	30567	Economy	13600.00
0005432459875	30567	Economy	13600.00
0005434081805	30567	Economy	13600.00
0005432161176	30567	Economy	13600.00
0005432567507	30567	Economy	13600.00
0005432567982	30567	Economy	13600.00
0005432568054	30567	Economy	13600.00
0005432459967	30567	Economy	13600.00
0005432567596	30567	Economy	13600.00
0005432459891	30567	Economy	13600.00
0005432460058	30567	Economy	13600.00
0005432567970	30567	Economy	13600.00
0005432568120	30567	Economy	13600.00
0005434559091	30567	Economy	13600.00
0005432567846	30567	Economy	13600.00
0005432460108	30567	Economy	13600.00
0005432567666	30567	Economy	13600.00
0005432459933	30567	Economy	13600.00
0005432567969	30567	Economy	13600.00
0005432567746	30567	Economy	13600.00
0005432567948	30567	Economy	13600.00
0005432459788	30567	Economy	13600.00
0005432459841	30567	Economy	13600.00
0005434559093	30567	Economy	13600.00
0005432459890	30567	Economy	13600.00
0005432567558	30567	Economy	13600.00
0005432567883	30567	Economy	13600.00
0005432459946	30567	Economy	13600.00
0005432567675	30567	Economy	13600.00
0005432567745	30567	Economy	13600.00
0005434559088	30567	Economy	13600.00
0005432571326	30567	Economy	13600.00
0005432161175	30567	Economy	13600.00
0005432460050	30567	Economy	13600.00
0005432567772	30567	Economy	13600.00
0005432568129	30567	Economy	13600.00
0005432571337	30567	Economy	13600.00
0005432459932	30567	Economy	13600.00
0005432460043	30567	Economy	13600.00
0005434081801	30567	Economy	13600.00
0005432459802	30567	Economy	13600.00
0005432567681	30567	Economy	13600.00
0005434081900	30567	Economy	13600.00
0005432567741	30567	Economy	13600.00
0005432459889	30567	Economy	13600.00
0005432567649	30567	Economy	13600.00
0005434559089	30567	Economy	13600.00
0005432567767	30567	Economy	13600.00
0005432567998	30567	Economy	13600.00
0005433454885	30567	Economy	13600.00
0005432567766	30567	Economy	13600.00
0005432460024	30567	Economy	13600.00
0005432460085	30567	Economy	13600.00
0005434081865	30567	Economy	13600.00
0005432459955	30567	Economy	13600.00
0005434081829	30567	Economy	13600.00
0005432460021	30567	Economy	13600.00
0005432567640	30567	Economy	13600.00
0005434559095	30567	Economy	13600.00
0005432567765	30567	Economy	13600.00
0005432567650	30567	Economy	13600.00
0005435722079	13585	Economy	9900.00
0005435720834	13585	Economy	9900.00
0005435722078	13585	Economy	9900.00
0005435722055	21129	Economy	9900.00
0005435722064	21129	Economy	9900.00
0005432295906	22756	Economy	8800.00
0005432295907	22756	Economy	8800.00
0005435097296	11105	Business	23600.00
0005433344159	11105	Business	23600.00
0005435508381	11105	Business	23600.00
0005435097290	11105	Business	23600.00
0005435380299	11105	Business	23600.00
0005433344158	11105	Business	23600.00
0005433344187	11105	Business	23600.00
0005433344213	11105	Business	23600.00
0005433344211	11105	Business	23600.00
0005433344154	11105	Business	23600.00
0005435097294	11105	Business	23600.00
0005433344184	11105	Business	23600.00
0005433344139	11105	Economy	7900.00
0005433344149	11105	Economy	7900.00
0005433344167	11105	Economy	7900.00
0005433344221	11105	Economy	7900.00
0005433344190	11105	Economy	7900.00
0005433344174	11105	Economy	7900.00
0005433344150	11105	Economy	7900.00
0005433344170	11105	Economy	7900.00
0005433344166	11105	Economy	7900.00
0005433344173	11105	Economy	7900.00
0005433344160	11105	Economy	7900.00
0005435380293	11105	Economy	7900.00
0005435508323	11105	Economy	7900.00
0005433344194	11105	Economy	7900.00
0005433344165	11105	Economy	7900.00
0005433344207	11105	Economy	7900.00
0005433344128	11105	Economy	7900.00
0005433344185	11105	Economy	7900.00
0005433344140	11105	Economy	7900.00
0005433344195	11105	Economy	7900.00
0005433344217	11105	Economy	7900.00
0005433344176	11105	Economy	7900.00
0005433344156	11105	Economy	7900.00
0005433344218	11105	Economy	7900.00
0005433344151	11105	Economy	7900.00
0005433344148	11105	Economy	7900.00
0005433344191	11105	Economy	7900.00
0005433344164	11105	Economy	7900.00
0005435097297	11105	Economy	7900.00
0005433344152	11105	Economy	7900.00
0005433344141	11105	Economy	7900.00
0005433344157	11105	Economy	7900.00
0005433344223	11105	Economy	7900.00
0005433344198	11105	Economy	7900.00
0005433344210	11105	Economy	7900.00
0005435380310	11105	Economy	7900.00
0005435508391	11105	Economy	7900.00
0005433344196	11105	Economy	7900.00
0005433344203	11105	Economy	8600.00
0005433344199	11105	Economy	7900.00
0005433344132	11105	Economy	8600.00
0005433344131	11105	Economy	8600.00
0005433344143	11105	Economy	8600.00
0005433344126	11105	Economy	8600.00
0005435508374	11105	Economy	8600.00
0005433344145	11105	Economy	7900.00
0005435508398	11105	Economy	7900.00
0005433344193	11105	Economy	7900.00
0005435508385	11105	Economy	7900.00
0005433344227	11105	Economy	7900.00
0005435097299	11105	Economy	7900.00
0005433344133	11105	Economy	7900.00
0005433344169	11105	Economy	7900.00
0005433344208	11105	Economy	7900.00
0005433344171	11105	Economy	7900.00
0005435097291	11105	Economy	7900.00
0005435508354	11105	Economy	7900.00
0005433344183	11105	Economy	7900.00
0005433344212	11105	Economy	7900.00
0005433344201	11105	Economy	7900.00
0005433344197	11105	Economy	7900.00
0005433344129	11105	Economy	7900.00
0005433344226	11105	Economy	7900.00
0005433344127	11105	Economy	7900.00
0005433344206	11105	Economy	7900.00
0005433344225	11105	Economy	7900.00
0005433344180	11105	Economy	7900.00
0005433344161	11105	Economy	7900.00
0005433344177	11105	Economy	7900.00
0005433344224	11105	Economy	7900.00
0005435508370	11105	Economy	7900.00
0005435380300	11105	Economy	7900.00
0005433344209	11105	Economy	7900.00
0005435508389	11105	Economy	7900.00
0005433344192	11105	Economy	7900.00
0005435097292	11105	Economy	7900.00
0005433344214	11105	Economy	7900.00
0005433344147	11105	Economy	7900.00
0005435508349	11105	Economy	7900.00
0005433344220	11105	Economy	7900.00
0005433344175	11105	Economy	7900.00
0005433344146	11105	Economy	7900.00
0005433344163	11105	Economy	7900.00
0005433344200	11105	Economy	7900.00
0005435508352	11105	Economy	7900.00
0005433344215	11105	Economy	7900.00
0005433344136	11105	Economy	7900.00
0005433344172	11105	Economy	7900.00
0005433344181	11105	Economy	7900.00
0005433344134	11105	Economy	7900.00
0005433344228	11105	Economy	7900.00
0005435097293	11105	Economy	7900.00
0005433344142	11105	Economy	7900.00
0005433344162	11105	Economy	7900.00
0005433344219	11105	Economy	7900.00
0005433344186	11105	Economy	7900.00
0005433344216	11105	Economy	7900.00
0005435097295	11105	Economy	7900.00
0005433344189	11105	Economy	7900.00
0005433344179	11105	Economy	7900.00
0005433344135	11105	Economy	7900.00
0005433344168	11105	Economy	7900.00
0005433344188	11105	Economy	7900.00
0005433344138	11105	Economy	7900.00
0005433344205	11105	Economy	7900.00
0005435097298	11105	Economy	7900.00
0005433344155	11105	Economy	7900.00
0005433344153	11105	Economy	7900.00
0005433344204	11105	Economy	7900.00
0005433344178	11105	Economy	7900.00
0005435508353	11105	Economy	7900.00
0005433344144	11105	Economy	7900.00
0005433344202	11105	Economy	7900.00
0005433344130	11105	Economy	7900.00
0005433344222	11105	Economy	7900.00
0005433344137	11105	Economy	7900.00
0005433344182	11105	Economy	7900.00
0005433343043	17120	Business	23600.00
0005435545821	17120	Business	23600.00
0005433342925	17120	Business	23600.00
0005433343107	17120	Business	23600.00
0005433343319	17120	Business	23600.00
0005433343511	17120	Business	23600.00
0005433343393	17120	Business	23600.00
0005432293232	17120	Business	23600.00
0005433343304	17120	Business	23600.00
0005433343391	17120	Business	23600.00
0005435545814	17120	Business	23600.00
0005433343055	17120	Economy	7900.00
0005433343160	17120	Economy	7900.00
0005433343145	17120	Economy	7900.00
0005433343174	17120	Economy	7900.00
0005435380339	17120	Economy	7900.00
0005435097224	17120	Economy	7900.00
0005433343310	17120	Economy	7900.00
0005433343426	17120	Economy	7900.00
0005433343548	17120	Economy	7900.00
0005435380343	17120	Economy	7900.00
0005433343291	17120	Economy	7900.00
0005433342897	17120	Economy	7900.00
0005433343390	17120	Economy	7900.00
0005433343690	17120	Economy	7900.00
0005433342871	17120	Economy	7900.00
0005435097212	17120	Economy	7900.00
0005433342994	17120	Economy	7900.00
0005435545812	17120	Economy	7900.00
0005435545813	17120	Economy	7900.00
0005435545826	17120	Economy	7900.00
0005433343042	17120	Economy	7900.00
0005433343036	17120	Economy	7900.00
0005435097190	17120	Economy	7900.00
0005432293234	17120	Economy	7900.00
0005433343012	17120	Economy	7900.00
0005433343172	17120	Economy	7900.00
0005433343368	17120	Economy	7900.00
0005433343037	17120	Economy	7900.00
0005435545822	17120	Economy	7900.00
0005435097239	17120	Economy	7900.00
0005435380342	17120	Economy	7900.00
0005433343349	17120	Economy	7900.00
0005433343266	17120	Economy	7900.00
0005433343221	17120	Economy	7900.00
0005433342814	17120	Economy	7900.00
0005433343056	17120	Economy	7900.00
0005433343180	17120	Economy	7900.00
0005433343483	17120	Economy	7900.00
0005433343348	17120	Economy	7900.00
0005435097205	17120	Economy	7900.00
0005435380340	17120	Economy	8600.00
0005433343122	17120	Economy	8600.00
0005435545827	17120	Economy	8600.00
0005433343123	17120	Economy	8600.00
0005435097229	17120	Economy	8600.00
0005433343336	17120	Economy	8600.00
0005435097231	17120	Economy	7900.00
0005433343496	17120	Economy	7900.00
0005433343170	17120	Economy	7900.00
0005435380341	17120	Economy	7900.00
0005435097213	17120	Economy	7900.00
0005435097228	17120	Economy	7900.00
0005435097226	17120	Economy	7900.00
0005435545820	17120	Economy	7900.00
0005432293233	17120	Economy	7900.00
0005432293235	17120	Economy	7900.00
0005435545825	17120	Economy	7900.00
0005433342651	17120	Economy	7900.00
0005433343171	17120	Economy	7900.00
0005433343233	17120	Economy	7900.00
0005433342924	17120	Economy	7900.00
0005433343292	17120	Economy	7900.00
0005433343163	17120	Economy	7900.00
0005435545823	17120	Economy	7900.00
0005435545815	17120	Economy	7900.00
0005433343497	17120	Economy	7900.00
0005433343614	17120	Economy	7900.00
0005433343173	17120	Economy	7900.00
0005433343209	17120	Economy	7900.00
0005433343210	17120	Economy	7900.00
0005433343253	17120	Economy	7900.00
0005433343398	17120	Economy	7900.00
0005433343318	17120	Economy	7900.00
0005435545819	17120	Economy	7900.00
0005433343547	17120	Economy	7900.00
0005433343232	17120	Economy	7900.00
0005435545817	17120	Economy	7900.00
0005433343175	17120	Economy	7900.00
0005433343203	17120	Economy	7900.00
0005433342501	17120	Economy	7900.00
0005433342931	17120	Economy	7900.00
0005433343399	17120	Economy	7900.00
0005433343606	17120	Economy	7900.00
0005435097220	17120	Economy	7900.00
0005433343389	17120	Economy	7900.00
0005435545818	17120	Economy	7900.00
0005433343264	17120	Economy	7900.00
0005433343270	17120	Economy	7900.00
0005433343477	17120	Economy	7900.00
0005435545824	17120	Economy	7900.00
0005433343538	17120	Economy	7900.00
0005433343108	17120	Economy	7900.00
0005433343306	17120	Economy	7900.00
0005433343644	17120	Economy	7900.00
0005433343268	17120	Economy	7900.00
0005433343427	17120	Economy	7900.00
0005435097225	17120	Economy	7900.00
0005435545828	17120	Economy	7900.00
0005433343351	17120	Economy	7900.00
0005433343131	17120	Economy	7900.00
0005435380344	17120	Economy	7900.00
0005433343413	17120	Economy	7900.00
0005433343265	17120	Economy	7900.00
0005435545816	17120	Economy	7900.00
0005433342993	17120	Economy	7900.00
0005433343153	17120	Economy	7900.00
0005433343165	17120	Economy	7900.00
0005433343590	17120	Economy	7900.00
0005433343073	17120	Economy	7900.00
0005433343250	17120	Economy	7900.00
0005433343392	17120	Economy	7900.00
0005433343572	17120	Economy	7900.00
0005433507374	9110	Business	26600.00
0005433481245	9110	Business	26600.00
0005433507360	9110	Business	26600.00
0005432919913	9110	Business	26600.00
0005434158979	9110	Business	26600.00
0005433507370	9110	Business	26600.00
0005433507373	9110	Business	26600.00
0005433481246	9110	Business	26600.00
0005433481249	9110	Economy	8900.00
0005433507362	9110	Economy	8900.00
0005433507366	9110	Economy	8900.00
0005432919921	9110	Economy	8900.00
0005432919791	9110	Economy	8900.00
0005433507357	9110	Economy	9800.00
0005432919897	9110	Economy	9800.00
0005433507359	9110	Economy	8900.00
0005432919790	9110	Economy	8900.00
0005432919895	9110	Economy	8900.00
0005433507376	9110	Economy	8900.00
0005433481242	9110	Economy	8900.00
0005432919792	9110	Economy	8900.00
0005434158980	9110	Economy	8900.00
0005433507375	9110	Economy	8900.00
0005432919902	9110	Economy	8900.00
0005432919896	9110	Economy	8900.00
0005432919875	9110	Economy	8900.00
0005433507358	9110	Economy	8900.00
0005432919824	9110	Economy	8900.00
0005433507364	9110	Economy	8900.00
0005433507371	9110	Economy	8900.00
0005433481247	9110	Economy	8900.00
0005432919924	9110	Economy	8900.00
0005433507361	9110	Economy	8900.00
0005433481244	9110	Economy	8900.00
0005432919919	9110	Economy	8900.00
0005432919917	9110	Economy	8900.00
0005434158969	9110	Economy	8900.00
0005433481248	9110	Economy	8900.00
0005432919886	9110	Economy	8900.00
0005433507365	9110	Economy	8900.00
0005433481243	9110	Economy	8900.00
0005432919911	9110	Economy	8900.00
0005432919887	9110	Economy	8900.00
0005433507369	9110	Economy	8900.00
0005433507372	9110	Economy	8900.00
0005433507367	9110	Economy	8900.00
0005432919912	9110	Economy	8900.00
0005433507368	9110	Economy	8900.00
0005432919920	9110	Economy	8900.00
0005433507363	9110	Economy	8900.00
0005432920097	20473	Business	26600.00
0005433507195	20473	Business	26600.00
0005432920083	20473	Business	26600.00
0005432920089	20473	Business	26600.00
0005433481214	20473	Economy	8900.00
0005433481216	20473	Economy	8900.00
0005433507130	20473	Economy	8900.00
0005433507226	20473	Economy	8900.00
0005432920099	20473	Economy	8900.00
0005433481215	20473	Economy	8900.00
0005433507190	20473	Economy	8900.00
0005433507189	20473	Economy	8900.00
0005432920096	20473	Economy	8900.00
0005433481169	20473	Economy	8900.00
0005433481163	20473	Economy	8900.00
0005432920085	20473	Economy	8900.00
0005432920088	20473	Economy	8900.00
0005432920090	20473	Economy	8900.00
0005432920084	20473	Economy	8900.00
0005433481162	20473	Economy	8900.00
0005432920092	20473	Economy	8900.00
0005433507120	20473	Economy	8900.00
0005433481190	20473	Economy	8900.00
0005432920094	20473	Economy	8900.00
0005433507210	20473	Economy	8900.00
0005433507232	20473	Economy	8900.00
0005432920086	20473	Economy	8900.00
0005432920091	20473	Economy	8900.00
0005432920087	20473	Economy	8900.00
0005433507192	20473	Economy	8900.00
0005433507102	20473	Economy	8900.00
0005432920103	20473	Economy	8900.00
0005433481166	20473	Economy	8900.00
0005433507199	20473	Economy	8900.00
0005433507197	20473	Economy	8900.00
0005433507196	20473	Economy	8900.00
0005432920102	20473	Economy	8900.00
0005433507200	20473	Economy	8900.00
0005433507194	20473	Economy	8900.00
0005433507103	20473	Economy	8900.00
0005433481191	20473	Economy	8900.00
0005432920101	20473	Economy	8900.00
0005433507211	20473	Economy	8900.00
0005433507233	20473	Economy	8900.00
0005432920100	20473	Economy	8900.00
0005432920098	20473	Economy	8900.00
0005432920095	20473	Economy	8900.00
0005432920093	20473	Economy	8900.00
0005432394142	10201	Economy	5800.00
0005432394143	10201	Economy	5800.00
0005432396282	10201	Economy	5800.00
0005432396279	10201	Economy	5800.00
0005432396280	10201	Economy	5800.00
0005432396278	10201	Economy	5800.00
0005432394141	10201	Economy	5800.00
0005432396281	10201	Economy	5800.00
0005432394140	10201	Economy	5800.00
0005432394139	10201	Economy	5800.00
0005435179699	10201	Economy	5800.00
0005432396242	18294	Economy	5800.00
0005432396255	18294	Economy	5800.00
0005432396237	18294	Economy	5800.00
0005432396238	18294	Economy	5800.00
0005435179403	18294	Economy	5800.00
0005432396259	18294	Economy	5800.00
0005435626180	11048	Business	9500.00
0005435126527	11048	Business	9500.00
0005434411821	11048	Business	9500.00
0005435126410	11048	Business	9500.00
0005435126445	11048	Business	9500.00
0005435126481	11048	Business	9500.00
0005435626178	11048	Business	9500.00
0005435626150	11048	Business	9500.00
0005435626086	11048	Business	9500.00
0005434928329	11048	Business	9500.00
0005435126331	11048	Business	9500.00
0005434411822	11048	Economy	3200.00
0005435126354	11048	Economy	3200.00
0005435556708	11048	Economy	3200.00
0005435626126	11048	Economy	3200.00
0005435626127	11048	Economy	3200.00
0005435626186	11048	Economy	3200.00
0005435626214	11048	Economy	3500.00
0005435126270	11048	Economy	3500.00
0005435626147	11048	Economy	3500.00
0005435626187	11048	Economy	3500.00
0005435626199	11048	Economy	3500.00
0005435126336	11048	Economy	3200.00
0005434928328	11048	Economy	3200.00
0005435554182	11048	Economy	3200.00
0005435626196	11048	Economy	3200.00
0005435126358	11048	Economy	3200.00
0005435126515	11048	Economy	3200.00
0005435626213	11048	Economy	3200.00
0005435626084	11048	Economy	3200.00
0005434928331	11048	Economy	3200.00
0005435556693	11048	Economy	3200.00
0005435126433	11048	Economy	3200.00
0005435126528	11048	Economy	3200.00
0005434411825	11048	Economy	3200.00
0005435126529	11048	Economy	3200.00
0005435126488	11048	Economy	3200.00
0005435126446	11048	Economy	3200.00
0005435126427	11048	Economy	3200.00
0005435626155	11048	Economy	3200.00
0005435126271	11048	Economy	3200.00
0005435126392	11048	Economy	3200.00
0005435556707	11048	Economy	3200.00
0005435626144	11048	Economy	3200.00
0005434411823	11048	Economy	3200.00
0005435626181	11048	Economy	3200.00
0005435126470	11048	Economy	3200.00
0005435126364	11048	Economy	3200.00
0005435554188	11048	Economy	3200.00
0005435126303	11048	Economy	3200.00
0005435626197	11048	Economy	3200.00
0005435126337	11048	Economy	3200.00
0005434411824	11048	Economy	3200.00
0005435626156	11048	Economy	3200.00
0005435126332	11048	Economy	3200.00
0005435126409	11048	Economy	3200.00
0005435556709	11048	Economy	3200.00
0005435126478	11048	Economy	3200.00
0005435126450	11048	Economy	3200.00
0005435126451	11048	Economy	3200.00
0005435126408	11048	Economy	3200.00
0005435626159	11048	Economy	3200.00
0005435126472	11048	Economy	3200.00
0005435126547	11048	Economy	3200.00
0005435126432	11048	Economy	3200.00
0005434928330	11048	Economy	3200.00
0005435126388	11048	Economy	3200.00
0005435126448	11048	Economy	3200.00
0005435126449	11048	Economy	3200.00
0005435126441	11048	Economy	3200.00
0005435126489	11048	Economy	3200.00
0005435126471	11048	Economy	3200.00
0005435126359	11048	Economy	3200.00
0005435126428	11048	Economy	3200.00
0005435126295	11048	Economy	3200.00
0005435126363	11048	Economy	3200.00
0005435126389	11048	Economy	3200.00
0005435626208	11048	Economy	3200.00
0005435626161	11048	Economy	3200.00
0005435126380	11048	Economy	3200.00
0005435626379	14736	Business	9500.00
0005435126778	14736	Business	9500.00
0005435126775	14736	Business	9500.00
0005435126802	14736	Business	9500.00
0005434411775	14736	Business	9500.00
0005435126805	14736	Business	9500.00
0005435126800	14736	Business	9500.00
0005435126790	14736	Business	9500.00
0005435126812	14736	Business	9500.00
0005435126804	14736	Business	9500.00
0005435126779	14736	Economy	3200.00
0005435126798	14736	Economy	3200.00
0005435626377	14736	Economy	3200.00
0005435626383	14736	Economy	3200.00
0005435126808	14736	Economy	3200.00
0005435126776	14736	Economy	3200.00
0005435126809	14736	Economy	3200.00
0005435126773	14736	Economy	3200.00
0005435626375	14736	Economy	3500.00
0005435626381	14736	Economy	3500.00
0005434928294	14736	Economy	3200.00
0005435626372	14736	Economy	3200.00
0005434928312	14736	Economy	3200.00
0005434928308	14736	Economy	3200.00
0005434928296	14736	Economy	3200.00
0005435126785	14736	Economy	3200.00
0005435126807	14736	Economy	3200.00
0005434411802	14736	Economy	3200.00
0005435626380	14736	Economy	3200.00
0005435626378	14736	Economy	3200.00
0005435126771	14736	Economy	3200.00
0005435554234	14736	Economy	3200.00
0005435126788	14736	Economy	3200.00
0005434928295	14736	Economy	3200.00
0005435126794	14736	Economy	3200.00
0005435126783	14736	Economy	3200.00
0005435556717	14736	Economy	3200.00
0005435626384	14736	Economy	3200.00
0005435126789	14736	Economy	3200.00
0005435126795	14736	Economy	3200.00
0005435126793	14736	Economy	3200.00
0005435126784	14736	Economy	3200.00
0005435554231	14736	Economy	3200.00
0005434411771	14736	Economy	3200.00
0005435126799	14736	Economy	3200.00
0005435626376	14736	Economy	3200.00
0005435126786	14736	Economy	3200.00
0005435554235	14736	Economy	3200.00
0005435126780	14736	Economy	3200.00
0005435126772	14736	Economy	3200.00
0005435626371	14736	Economy	3200.00
0005435126774	14736	Economy	3200.00
0005434928293	14736	Economy	3200.00
0005435554232	14736	Economy	3200.00
0005435126777	14736	Economy	3200.00
0005435626373	14736	Economy	3200.00
0005435556718	14736	Economy	3200.00
0005435126810	14736	Economy	3200.00
0005435126801	14736	Economy	3200.00
0005435126796	14736	Economy	3200.00
0005434411803	14736	Economy	3200.00
0005435126811	14736	Economy	3200.00
0005435126787	14736	Economy	3200.00
0005435126797	14736	Economy	3200.00
0005435126806	14736	Economy	3200.00
0005435554233	14736	Economy	3200.00
0005435626382	14736	Economy	3200.00
0005435126782	14736	Economy	3200.00
0005435126803	14736	Economy	3200.00
0005435126792	14736	Economy	3200.00
0005435126781	14736	Economy	3200.00
0005435126791	14736	Economy	3200.00
0005435626374	14736	Economy	3200.00
0005435443384	7132	Business	86900.00
0005435443361	7132	Business	86900.00
0005435443385	7132	Business	86900.00
0005435219206	7132	Business	86900.00
0005435221060	7132	Economy	29000.00
0005435715645	7132	Economy	29000.00
0005435443342	7132	Economy	29000.00
0005435715639	7132	Economy	29000.00
0005432400165	7132	Economy	29000.00
0005435715650	7132	Economy	31900.00
0005435443323	7132	Economy	31900.00
0005435178502	7132	Economy	31900.00
0005435443341	7132	Economy	29000.00
0005432398239	7132	Economy	29000.00
0005435443353	7132	Economy	29000.00
0005432398237	7132	Economy	29000.00
0005435715644	7132	Economy	29000.00
0005435178499	7132	Economy	29000.00
0005435715649	7132	Economy	29000.00
0005435178497	7132	Economy	29000.00
0005435219207	7132	Economy	29000.00
0005435715648	7132	Economy	29000.00
0005435715638	7132	Economy	29000.00
0005435715646	7132	Economy	29000.00
0005432400167	7132	Economy	29000.00
0005435443343	7132	Economy	29000.00
0005435443362	7132	Economy	29000.00
0005432400166	7132	Economy	29000.00
0005435715651	7132	Economy	29000.00
0005435715636	7132	Economy	29000.00
0005435715640	7132	Economy	29000.00
0005435219208	7132	Economy	29000.00
0005435443328	7132	Economy	29000.00
0005435178503	7132	Economy	29000.00
0005435443383	7132	Economy	29000.00
0005435715637	7132	Economy	29000.00
0005435715647	7132	Economy	29000.00
0005435715643	7132	Economy	29000.00
0005435443325	7132	Economy	29000.00
0005435178496	7132	Economy	29000.00
0005435443336	7132	Economy	29000.00
0005435715642	7132	Economy	29000.00
0005432398238	7132	Economy	29000.00
0005435443350	7132	Economy	29000.00
0005435715641	7132	Economy	29000.00
0005435443321	7132	Economy	29000.00
0005435443297	7132	Economy	29000.00
0005432398236	7132	Economy	29000.00
0005435443412	27093	Business	86900.00
0005435715501	27093	Business	86900.00
0005435715515	27093	Business	86900.00
0005432394112	27093	Business	86900.00
0005435443407	27093	Business	86900.00
0005432398207	27093	Economy	29000.00
0005435715477	27093	Economy	29000.00
0005432394103	27093	Economy	29000.00
0005435443406	27093	Economy	29000.00
0005432394102	27093	Economy	31900.00
0005435715574	27093	Economy	31900.00
0005432398209	27093	Economy	31900.00
0005435179001	27093	Economy	29000.00
0005435715519	27093	Economy	29000.00
0005435178508	27093	Economy	29000.00
0005435715493	27093	Economy	29000.00
0005435178509	27093	Economy	29000.00
0005435179000	27093	Economy	29000.00
0005435443408	27093	Economy	29000.00
0005432398218	27093	Economy	29000.00
0005435715520	27093	Economy	29000.00
0005432398208	27093	Economy	29000.00
0005435443409	27093	Economy	29000.00
0005435715536	27093	Economy	29000.00
0005435443413	27093	Economy	29000.00
0005435715492	27093	Economy	29000.00
0005435715535	27093	Economy	29000.00
0005435715521	27093	Economy	29000.00
0005435443410	27093	Economy	29000.00
0005435443411	27093	Economy	29000.00
0005435715513	27093	Economy	29000.00
0005435443414	27093	Economy	29000.00
0005434084980	2711	Economy	7700.00
0005434084978	2711	Economy	7700.00
0005434084979	2711	Economy	7700.00
0005434084977	2711	Economy	7700.00
0005433060405	2711	Economy	7700.00
0005433060406	2711	Economy	7700.00
0005434084933	28479	Economy	7700.00
0005433060442	28479	Economy	7700.00
0005434084957	28479	Economy	7700.00
0005433060440	28479	Economy	7700.00
0005434084949	28479	Economy	7700.00
0005433060441	28479	Economy	7700.00
0005434084956	28479	Economy	7700.00
0005434084925	28479	Economy	7700.00
0005435844310	25200	Economy	29000.00
0005432632796	25200	Economy	26400.00
0005432632790	25200	Economy	26400.00
0005432632799	25200	Economy	26400.00
0005432632800	25200	Economy	26400.00
0005432632784	25200	Economy	26400.00
0005435844316	25200	Economy	26400.00
0005435844318	25200	Economy	26400.00
0005432632804	25200	Economy	26400.00
0005432632803	25200	Economy	26400.00
0005432632794	25200	Economy	26400.00
0005435844294	25200	Economy	26400.00
0005432632798	25200	Economy	26400.00
0005435844305	25200	Economy	26400.00
0005432632788	25200	Economy	26400.00
0005435844292	25200	Economy	26400.00
0005435844317	25200	Economy	26400.00
0005432632791	25200	Economy	26400.00
0005432632795	25200	Economy	26400.00
0005432632787	25200	Economy	26400.00
0005432632793	25200	Economy	26400.00
0005432632786	25200	Economy	26400.00
0005432632797	25200	Economy	26400.00
0005432632802	25200	Economy	26400.00
0005432632785	25200	Economy	26400.00
0005432632792	25200	Economy	26400.00
0005432632801	25200	Economy	26400.00
0005435844293	25200	Economy	26400.00
0005432632783	25200	Economy	26400.00
0005432632789	25200	Economy	26400.00
0005432632750	28162	Economy	29000.00
0005435844351	28162	Economy	29000.00
0005435844357	28162	Economy	26400.00
0005435844350	28162	Economy	26400.00
0005435844354	28162	Economy	26400.00
0005435844362	28162	Economy	26400.00
0005432632751	28162	Economy	26400.00
0005432632737	28162	Economy	26400.00
0005432632745	28162	Economy	26400.00
0005435844360	28162	Economy	26400.00
0005432632749	28162	Economy	26400.00
0005435844361	28162	Economy	26400.00
0005435844355	28162	Economy	26400.00
0005432632753	28162	Economy	26400.00
0005432632735	28162	Economy	26400.00
0005432632738	28162	Economy	26400.00
0005432632714	28162	Economy	26400.00
0005432632752	28162	Economy	26400.00
0005432632686	28162	Economy	26400.00
0005435844359	28162	Economy	26400.00
0005432632685	28162	Economy	26400.00
0005432632717	28162	Economy	26400.00
0005435844352	28162	Economy	26400.00
0005432632743	28162	Economy	26400.00
0005432632754	28162	Economy	26400.00
0005432632713	28162	Economy	26400.00
0005432632727	28162	Economy	26400.00
0005435844353	28162	Economy	26400.00
0005432632726	28162	Economy	26400.00
0005435844358	28162	Economy	26400.00
0005432632721	28162	Economy	26400.00
0005435844356	28162	Economy	26400.00
0005432632724	28162	Economy	26400.00
0005432632736	28162	Economy	26400.00
0005432632720	28162	Economy	26400.00
0005435517907	11419	Business	20200.00
0005435517976	11419	Business	20200.00
0005435517906	11419	Business	20200.00
0005435541065	11419	Business	20200.00
0005435541050	11419	Business	20200.00
0005435517928	11419	Economy	7400.00
0005435517952	11419	Economy	6700.00
0005435517873	11419	Economy	6700.00
0005435540982	11419	Economy	6700.00
0005435517929	11419	Economy	6700.00
0005435540983	11419	Economy	6700.00
0005435540931	11419	Economy	6700.00
0005435541049	11419	Economy	6700.00
0005435517889	11419	Economy	6700.00
0005435517989	11419	Economy	6700.00
0005435541051	11419	Economy	6700.00
0005435518011	11419	Economy	6700.00
0005435541048	11419	Economy	6700.00
0005435541064	11419	Economy	6700.00
0005435540974	11419	Economy	6700.00
0005435517963	11419	Economy	6700.00
0005435541069	11419	Economy	6700.00
0005435541125	11419	Economy	6700.00
0005435517964	11419	Economy	6700.00
0005435541147	11419	Economy	6700.00
0005435517962	11419	Economy	6700.00
0005435541204	22251	Business	20200.00
0005435541200	22251	Business	20200.00
0005435541216	22251	Business	20200.00
0005435541218	22251	Business	20200.00
0005435541209	22251	Business	20200.00
0005435541213	22251	Business	20200.00
0005435541199	22251	Business	20200.00
0005435541201	22251	Business	20200.00
0005435541217	22251	Business	20200.00
0005435529475	22251	Business	20200.00
0005435541207	22251	Economy	6700.00
0005435541215	22251	Economy	6700.00
0005435529462	22251	Economy	6700.00
0005435529469	22251	Economy	6700.00
0005435529458	22251	Economy	7400.00
0005435529464	22251	Economy	7400.00
0005435541214	22251	Economy	6700.00
0005435541210	22251	Economy	6700.00
0005435541221	22251	Economy	6700.00
0005435529466	22251	Economy	6700.00
0005435529463	22251	Economy	6700.00
0005435541208	22251	Economy	6700.00
0005435541219	22251	Economy	6700.00
0005435529468	22251	Economy	6700.00
0005435541205	22251	Economy	6700.00
0005435541203	22251	Economy	6700.00
0005435529457	22251	Economy	6700.00
0005435529459	22251	Economy	6700.00
0005435529473	22251	Economy	6700.00
0005435529470	22251	Economy	6700.00
0005435529471	22251	Economy	6700.00
0005435529467	22251	Economy	6700.00
0005435529460	22251	Economy	6700.00
0005435529474	22251	Economy	6700.00
0005432294509	22251	Economy	6700.00
0005435541206	22251	Economy	6700.00
0005435529465	22251	Economy	6700.00
0005435529456	22251	Economy	6700.00
0005435541220	22251	Economy	6700.00
0005435541212	22251	Economy	6700.00
0005435541211	22251	Economy	6700.00
0005435529476	22251	Economy	6700.00
0005432294510	22251	Economy	6700.00
0005435529472	22251	Economy	6700.00
0005435529461	22251	Economy	6700.00
0005435541202	22251	Economy	6700.00
0005433251583	2297	Business	20200.00
0005434907825	2297	Business	20200.00
0005434907803	2297	Business	20200.00
0005434907833	2297	Business	20200.00
0005434907828	2297	Business	20200.00
0005434907819	2297	Business	20200.00
0005434907807	2297	Business	20200.00
0005434907815	2297	Business	20200.00
0005434907844	2297	Business	20200.00
0005433251546	2297	Business	20200.00
0005433251621	2297	Business	20200.00
0005434907817	2297	Business	20200.00
0005434907808	2297	Economy	6700.00
0005434907846	2297	Economy	6700.00
0005434907853	2297	Economy	6700.00
0005434907834	2297	Economy	6700.00
0005434907820	2297	Economy	6700.00
0005434907849	2297	Economy	6700.00
0005434907830	2297	Economy	6700.00
0005434907847	2297	Economy	6700.00
0005434907816	2297	Economy	6700.00
0005434907850	2297	Economy	7400.00
0005433251521	2297	Economy	7400.00
0005433251653	2297	Economy	7400.00
0005434907845	2297	Economy	7400.00
0005433251543	2297	Economy	7400.00
0005433251601	2297	Economy	6700.00
0005434907806	2297	Economy	6700.00
0005433251451	2297	Economy	6700.00
0005434907835	2297	Economy	6700.00
0005434907842	2297	Economy	6700.00
0005433400996	2297	Economy	6700.00
0005434907831	2297	Economy	6700.00
0005434907843	2297	Economy	6700.00
0005434907812	2297	Economy	6700.00
0005433251650	2297	Economy	6700.00
0005434907841	2297	Economy	6700.00
0005433251610	2297	Economy	6700.00
0005434907827	2297	Economy	6700.00
0005434907821	2297	Economy	6700.00
0005433251509	2297	Economy	6700.00
0005434907840	2297	Economy	6700.00
0005434907822	2297	Economy	6700.00
0005434907802	2297	Economy	6700.00
0005434907855	2297	Economy	6700.00
0005434907823	2297	Economy	6700.00
0005434907832	2297	Economy	6700.00
0005433251519	2297	Economy	6700.00
0005434907805	2297	Economy	6700.00
0005434907809	2297	Economy	6700.00
0005434907813	2297	Economy	6700.00
0005434907836	2297	Economy	6700.00
0005433251552	2297	Economy	6700.00
0005433251712	2297	Economy	6700.00
0005433251499	2297	Economy	6700.00
0005434907851	2297	Economy	6700.00
0005434907801	2297	Economy	6700.00
0005434907818	2297	Economy	6700.00
0005434907837	2297	Economy	6700.00
0005434907826	2297	Economy	6700.00
0005433251609	2297	Economy	6700.00
0005434907857	2297	Economy	6700.00
0005433251631	2297	Economy	6700.00
0005434907856	2297	Economy	6700.00
0005433400997	2297	Economy	6700.00
0005433251649	2297	Economy	6700.00
0005433251713	2297	Economy	6700.00
0005434907848	2297	Economy	6700.00
0005433251651	2297	Economy	6700.00
0005434907814	2297	Economy	6700.00
0005434907839	2297	Economy	6700.00
0005433251425	2297	Economy	6700.00
0005434907852	2297	Economy	6700.00
0005433251652	2297	Economy	6700.00
0005434907810	2297	Economy	6700.00
0005433251597	2297	Economy	6700.00
0005434907804	2297	Economy	6700.00
0005433251490	2297	Economy	6700.00
0005434907829	2297	Economy	6700.00
0005434907824	2297	Economy	6700.00
0005434907854	2297	Economy	6700.00
0005434907838	2297	Economy	6700.00
0005433251533	2297	Economy	6700.00
0005433251520	2297	Economy	6700.00
0005434907811	2297	Economy	6700.00
0005433251721	2297	Economy	6700.00
0005434907257	25630	Business	20200.00
0005433251793	25630	Business	20200.00
0005433401015	25630	Business	20200.00
0005434907120	25630	Business	20200.00
0005434907253	25630	Business	20200.00
0005434907286	25630	Business	20200.00
0005433251789	25630	Business	20200.00
0005433251801	25630	Business	20200.00
0005434907213	25630	Business	20200.00
0005434907260	25630	Business	20200.00
0005434907297	25630	Business	20200.00
0005434907093	25630	Economy	6700.00
0005433251807	25630	Economy	6700.00
0005434907447	25630	Economy	6700.00
0005434907428	25630	Economy	6700.00
0005434907296	25630	Economy	6700.00
0005434907367	25630	Economy	6700.00
0005434907281	25630	Economy	6700.00
0005434907355	25630	Economy	6700.00
0005434907446	25630	Economy	6700.00
0005433251785	25630	Economy	6700.00
0005433251809	25630	Economy	7400.00
0005434907514	25630	Economy	7400.00
0005434907368	25630	Economy	7400.00
0005433251811	25630	Economy	7400.00
0005433401014	25630	Economy	7400.00
0005433251797	25630	Economy	6700.00
0005434907448	25630	Economy	6700.00
0005434907392	25630	Economy	6700.00
0005434907338	25630	Economy	6700.00
0005434907515	25630	Economy	6700.00
0005434907317	25630	Economy	6700.00
0005433251808	25630	Economy	6700.00
0005434907409	25630	Economy	6700.00
0005434907426	25630	Economy	6700.00
0005433251795	25630	Economy	6700.00
0005434907269	25630	Economy	6700.00
0005433251800	25630	Economy	6700.00
0005434907291	25630	Economy	6700.00
0005434907441	25630	Economy	6700.00
0005433251796	25630	Economy	6700.00
0005433251786	25630	Economy	6700.00
0005434907216	25630	Economy	6700.00
0005434907234	25630	Economy	6700.00
0005433251799	25630	Economy	6700.00
0005434907310	25630	Economy	6700.00
0005433251810	25630	Economy	6700.00
0005434907287	25630	Economy	6700.00
0005433251804	25630	Economy	6700.00
0005434907199	25630	Economy	6700.00
0005434907394	25630	Economy	6700.00
0005434907255	25630	Economy	6700.00
0005434907333	25630	Economy	6700.00
0005433251782	25630	Economy	6700.00
0005434907329	25630	Economy	6700.00
0005433251791	25630	Economy	6700.00
0005433251784	25630	Economy	6700.00
0005433251806	25630	Economy	6700.00
0005433251802	25630	Economy	6700.00
0005434907331	25630	Economy	6700.00
0005434907309	25630	Economy	6700.00
0005434907519	25630	Economy	6700.00
0005434907416	25630	Economy	6700.00
0005433251792	25630	Economy	6700.00
0005434907271	25630	Economy	6700.00
0005434907496	25630	Economy	6700.00
0005433401013	25630	Economy	6700.00
0005433251783	25630	Economy	6700.00
0005434907518	25630	Economy	6700.00
0005434907337	25630	Economy	6700.00
0005433251798	25630	Economy	6700.00
0005434907332	25630	Economy	6700.00
0005434907256	25630	Economy	6700.00
0005434907252	25630	Economy	6700.00
0005433251788	25630	Economy	6700.00
0005434907498	25630	Economy	6700.00
0005434907360	25630	Economy	6700.00
0005434907308	25630	Economy	6700.00
0005434907222	25630	Economy	6700.00
0005434907108	25630	Economy	6700.00
0005434907427	25630	Economy	6700.00
0005433251787	25630	Economy	6700.00
0005433251805	25630	Economy	6700.00
0005434907330	25630	Economy	6700.00
0005433251794	25630	Economy	6700.00
0005434907270	25630	Economy	6700.00
0005434907251	25630	Economy	6700.00
0005433251803	25630	Economy	6700.00
0005434907292	25630	Economy	6700.00
0005433251790	25630	Economy	6700.00
0005432862309	2545	Economy	13600.00
0005432621184	2545	Economy	13600.00
0005432862310	2545	Economy	13600.00
0005432621190	2545	Economy	12400.00
0005432621186	2545	Economy	12400.00
0005432862351	2545	Economy	12400.00
0005432621189	2545	Economy	12400.00
0005432621182	2545	Economy	12400.00
0005432621181	2545	Economy	12400.00
0005432621187	2545	Economy	12400.00
0005432621188	2545	Economy	12400.00
0005432621183	2545	Economy	12400.00
0005432862350	2545	Economy	12400.00
0005432862319	2545	Economy	12400.00
0005432621185	2545	Economy	12400.00
0005432621179	2545	Economy	12400.00
0005432621178	2545	Economy	12400.00
0005432621180	2545	Economy	12400.00
0005432621177	2545	Economy	12400.00
0005432621056	28042	Economy	13600.00
0005432862382	28042	Economy	12400.00
0005432620981	28042	Economy	12400.00
0005432621061	28042	Economy	12400.00
0005432621093	28042	Economy	12400.00
0005432621039	28042	Economy	12400.00
0005432621033	28042	Economy	12400.00
0005432621032	28042	Economy	12400.00
0005432621038	28042	Economy	12400.00
0005432621006	28042	Economy	12400.00
0005432621091	28042	Economy	12400.00
0005432862380	28042	Economy	12400.00
0005432862381	28042	Economy	12400.00
0005432620982	28042	Economy	12400.00
0005432621099	28042	Economy	12400.00
0005432621005	28042	Economy	12400.00
0005432862378	28042	Economy	12400.00
0005432862385	28042	Economy	12400.00
0005432862384	28042	Economy	12400.00
0005432621014	28042	Economy	12400.00
0005432621060	28042	Economy	12400.00
0005432862379	28042	Economy	12400.00
0005432862383	28042	Economy	12400.00
0005432621092	28042	Economy	12400.00
0005434097477	11723	Economy	11300.00
0005434097473	11723	Economy	11300.00
0005434097472	11723	Economy	11300.00
0005434191289	28022	Business	89600.00
0005434191295	28022	Economy	29900.00
0005434191288	28022	Economy	29900.00
0005434191292	28022	Economy	29900.00
0005434191291	28022	Economy	29900.00
0005434191296	28022	Economy	29900.00
0005434191294	28022	Economy	29900.00
0005434191293	28022	Economy	29900.00
0005434191285	28022	Economy	29900.00
0005434191290	28022	Economy	29900.00
0005434191286	28022	Economy	29900.00
0005434191287	28022	Economy	29900.00
0005433452761	31078	Economy	8400.00
0005433452760	31078	Economy	8400.00
0005433451639	31078	Economy	8400.00
0005433451638	31078	Economy	8400.00
0005433454886	31422	Economy	8400.00
0005433454885	31422	Economy	8400.00
0005433452748	31422	Economy	8400.00
0005433452739	31422	Economy	8400.00
0005433452738	31422	Economy	8400.00
0005434184665	11992	Economy	7200.00
0005433134119	11992	Economy	7200.00
0005433134153	11992	Economy	7200.00
0005433129285	11992	Economy	6600.00
0005433134120	11992	Economy	6600.00
0005433129276	11992	Economy	6600.00
0005433129269	11992	Economy	6600.00
0005434142610	11992	Economy	6600.00
0005433129281	11992	Economy	6600.00
0005433129287	11992	Economy	6600.00
0005433129278	11992	Economy	6600.00
0005433129275	11992	Economy	6600.00
0005433129260	11992	Economy	6600.00
0005433129279	11992	Economy	6600.00
0005433129288	11992	Economy	6600.00
0005433134155	11992	Economy	6600.00
0005434184663	11992	Economy	6600.00
0005433129270	11992	Economy	6600.00
0005433134161	11992	Economy	6600.00
0005434184666	11992	Economy	6600.00
0005433129289	11992	Economy	6600.00
0005434142616	11992	Economy	6600.00
0005433134129	11992	Economy	6600.00
0005433134152	11992	Economy	6600.00
0005434142617	11992	Economy	6600.00
0005433134130	11992	Economy	6600.00
0005433129286	11992	Economy	6600.00
0005434184685	29854	Economy	7200.00
0005434184686	29854	Economy	6600.00
0005434184687	29854	Economy	6600.00
0005433134184	29854	Economy	6600.00
0005433131753	29854	Economy	6600.00
0005433131754	29854	Economy	6600.00
0005434142648	29854	Economy	6600.00
0005434142649	29854	Economy	6600.00
0005433134185	29854	Economy	6600.00
0005434183600	29854	Economy	6600.00
0005433134186	29854	Economy	6600.00
0005434142647	29854	Economy	6600.00
0005433131756	29854	Economy	6600.00
0005434142646	29854	Economy	6600.00
0005433131755	29854	Economy	6600.00
0005433134187	29854	Economy	6600.00
0005433131757	29854	Economy	6600.00
0005434183601	29854	Economy	6600.00
0005435697614	16458	Economy	19900.00
0005435697591	16458	Economy	19900.00
0005435697592	16458	Economy	19900.00
0005435697613	16458	Economy	18100.00
0005435935045	16458	Economy	18100.00
0005435697598	16458	Economy	18100.00
0005435697602	16458	Economy	18100.00
0005435697599	16458	Economy	18100.00
0005435697603	16458	Economy	18100.00
0005435697601	16458	Economy	18100.00
0005435697594	16458	Economy	18100.00
0005435697615	16458	Economy	18100.00
0005435697589	16458	Economy	18100.00
0005435935059	16458	Economy	18100.00
0005435697612	16458	Economy	18100.00
0005435935053	16458	Economy	18100.00
0005435697590	16458	Economy	18100.00
0005435935043	16458	Economy	18100.00
0005435697593	16458	Economy	18100.00
0005435697604	16458	Economy	18100.00
0005435697605	16458	Economy	18100.00
0005435697610	16458	Economy	18100.00
0005435697600	16458	Economy	18100.00
0005435697595	16458	Economy	18100.00
0005435697597	16458	Economy	18100.00
0005435697609	16458	Economy	18100.00
0005435935052	16458	Economy	18100.00
0005435697608	16458	Economy	18100.00
0005435697611	16458	Economy	18100.00
0005435697617	16458	Economy	18100.00
0005435697606	16458	Economy	18100.00
0005435697596	16458	Economy	18100.00
0005435697607	16458	Economy	18100.00
0005435697616	16458	Economy	18100.00
0005435935044	16458	Economy	18100.00
0005435697457	24738	Economy	19900.00
0005435697375	24738	Economy	19900.00
0005435697418	24738	Economy	18100.00
0005435697335	24738	Economy	18100.00
0005435697415	24738	Economy	18100.00
0005435697304	24738	Economy	18100.00
0005435697410	24738	Economy	18100.00
0005435697350	24738	Economy	18100.00
0005435697310	24738	Economy	18100.00
0005435697427	24738	Economy	18100.00
0005435697336	24738	Economy	18100.00
0005435697411	24738	Economy	18100.00
0005435935077	24738	Economy	18100.00
0005435697309	24738	Economy	18100.00
0005435697364	24738	Economy	18100.00
0005435697435	24738	Economy	18100.00
0005435697458	24738	Economy	18100.00
0005435935079	24738	Economy	18100.00
0005435697368	24738	Economy	18100.00
0005435697412	24738	Economy	18100.00
0005435697462	24738	Economy	18100.00
0005435697303	24738	Economy	18100.00
0005435697516	24738	Economy	18100.00
0005435697385	24738	Economy	18100.00
0005435697339	24738	Economy	18100.00
0005435697338	24738	Economy	18100.00
0005435697386	24738	Economy	18100.00
0005435697515	24738	Economy	18100.00
0005435697463	24738	Economy	18100.00
0005435935078	24738	Economy	18100.00
0005433724850	18774	Economy	4400.00
0005432968841	18774	Economy	4400.00
0005433724848	18774	Economy	4400.00
0005433724846	18774	Economy	4400.00
0005432968849	18774	Economy	4400.00
0005432968840	18774	Economy	4400.00
0005433724849	18774	Economy	4400.00
0005432968850	18774	Economy	4400.00
0005433724847	18774	Economy	4400.00
0005432968865	21650	Economy	4400.00
0005433724814	21650	Economy	4400.00
0005433724806	21650	Economy	4400.00
0005433724813	21650	Economy	4400.00
0005433724822	21650	Economy	4400.00
0005432968866	21650	Economy	4400.00
0005434138998	7332	Business	23100.00
0005434139004	7332	Business	23100.00
0005434139030	7332	Business	23100.00
0005434139044	7332	Business	23100.00
0005434138992	7332	Business	23100.00
0005434139045	7332	Business	23100.00
0005434138984	7332	Business	23100.00
0005434139034	7332	Business	23100.00
0005434087565	7332	Business	23100.00
0005434138986	7332	Economy	7700.00
0005434138981	7332	Economy	7700.00
0005434139024	7332	Economy	7700.00
0005434139000	7332	Economy	7700.00
0005434139031	7332	Economy	7700.00
0005434087563	7332	Economy	7700.00
0005434139013	7332	Economy	7700.00
0005434139027	7332	Economy	8500.00
0005434139001	7332	Economy	8500.00
0005434139022	7332	Economy	8500.00
0005434139010	7332	Economy	8500.00
0005434139017	7332	Economy	7700.00
0005434139035	7332	Economy	7700.00
0005434139047	7332	Economy	7700.00
0005434139032	7332	Economy	7700.00
0005434139046	7332	Economy	7700.00
0005434139008	7332	Economy	7700.00
0005434139029	7332	Economy	7700.00
0005434087566	7332	Economy	7700.00
0005434138999	7332	Economy	7700.00
0005434139043	7332	Economy	7700.00
0005434138979	7332	Economy	7700.00
0005434139033	7332	Economy	7700.00
0005434138987	7332	Economy	7700.00
0005434139003	7332	Economy	7700.00
0005434139028	7332	Economy	7700.00
0005434138996	7332	Economy	7700.00
0005434139021	7332	Economy	7700.00
0005434139037	7332	Economy	7700.00
0005434139014	7332	Economy	7700.00
0005434139016	7332	Economy	7700.00
0005434138991	7332	Economy	7700.00
0005434139007	7332	Economy	7700.00
0005434139041	7332	Economy	7700.00
0005434139040	7332	Economy	7700.00
0005434138989	7332	Economy	7700.00
0005434139020	7332	Economy	7700.00
0005434138997	7332	Economy	7700.00
0005434138982	7332	Economy	7700.00
0005434139006	7332	Economy	7700.00
0005434138995	7332	Economy	7700.00
0005434139026	7332	Economy	7700.00
0005434139009	7332	Economy	7700.00
0005434139015	7332	Economy	7700.00
0005434138983	7332	Economy	7700.00
0005434138993	7332	Economy	7700.00
0005434139025	7332	Economy	7700.00
0005434139005	7332	Economy	7700.00
0005434139023	7332	Economy	7700.00
0005434138980	7332	Economy	7700.00
0005434139012	7332	Economy	7700.00
0005434139002	7332	Economy	7700.00
0005434139039	7332	Economy	7700.00
0005434139038	7332	Economy	7700.00
0005434087564	7332	Economy	7700.00
0005434138988	7332	Economy	7700.00
0005434139036	7332	Economy	7700.00
0005434138994	7332	Economy	7700.00
0005434139019	7332	Economy	7700.00
0005434138990	7332	Economy	7700.00
0005434139011	7332	Economy	7700.00
0005434139018	7332	Economy	7700.00
0005434138985	7332	Economy	7700.00
0005434139042	7332	Economy	7700.00
0005434138103	28569	Business	23100.00
0005434087493	28569	Business	23100.00
0005434137939	28569	Business	23100.00
0005434138156	28569	Business	23100.00
0005434138054	28569	Business	23100.00
0005434138187	28569	Business	23100.00
0005434138091	28569	Business	23100.00
0005434138343	28569	Business	23100.00
0005434137906	28569	Business	23100.00
0005434138026	28569	Business	23100.00
0005434138164	28569	Business	23100.00
0005434138378	28569	Business	23100.00
0005434138341	28569	Economy	7700.00
0005434138089	28569	Economy	7700.00
0005434137953	28569	Economy	7700.00
0005434138207	28569	Economy	7700.00
0005434138084	28569	Economy	7700.00
0005434138206	28569	Economy	7700.00
0005434138259	28569	Economy	7700.00
0005434138326	28569	Economy	7700.00
0005434137960	28569	Economy	7700.00
0005434138306	28569	Economy	8500.00
0005434138196	28569	Economy	8500.00
0005434138286	28569	Economy	8500.00
0005434138154	28569	Economy	8500.00
0005434138387	28569	Economy	8500.00
0005434138037	28569	Economy	7700.00
0005434138285	28569	Economy	7700.00
0005434138377	28569	Economy	7700.00
0005434138379	28569	Economy	7700.00
0005434137841	28569	Economy	7700.00
0005434137994	28569	Economy	7700.00
0005434138083	28569	Economy	7700.00
0005434138036	28569	Economy	7700.00
0005434138144	28569	Economy	7700.00
0005434138226	28569	Economy	7700.00
0005434137993	28569	Economy	7700.00
0005434138372	28569	Economy	7700.00
0005434138254	28569	Economy	7700.00
0005434138388	28569	Economy	7700.00
0005434138172	28569	Economy	7700.00
0005434138307	28569	Economy	7700.00
0005434138270	28569	Economy	7700.00
0005434137940	28569	Economy	7700.00
0005434138043	28569	Economy	7700.00
0005434087523	28569	Economy	7700.00
0005434138128	28569	Economy	7700.00
0005434138029	28569	Economy	7700.00
0005434138044	28569	Economy	7700.00
0005434138059	28569	Economy	7700.00
0005434138162	28569	Economy	7700.00
0005434138295	28569	Economy	7700.00
0005434138061	28569	Economy	7700.00
0005434138138	28569	Economy	7700.00
0005434138155	28569	Economy	7700.00
0005434138173	28569	Economy	7700.00
0005434138315	28569	Economy	7700.00
0005434138182	28569	Economy	7700.00
0005434138117	28569	Economy	7700.00
0005434138319	28569	Economy	7700.00
0005434138055	28569	Economy	7700.00
0005434138194	28569	Economy	7700.00
0005434137905	28569	Economy	7700.00
0005434138153	28569	Economy	7700.00
0005434138280	28569	Economy	7700.00
0005434138143	28569	Economy	7700.00
0005434138104	28569	Economy	7700.00
0005434138335	28569	Economy	7700.00
0005434138031	28569	Economy	7700.00
0005434138374	28569	Economy	7700.00
0005434138276	28569	Economy	7700.00
0005434138165	28569	Economy	7700.00
0005434138176	28569	Economy	7700.00
0005434138290	28569	Economy	7700.00
0005434138363	28569	Economy	7700.00
0005434138373	28569	Economy	7700.00
0005434138166	28569	Economy	7700.00
0005434138320	28569	Economy	7700.00
0005434138056	28569	Economy	7700.00
0005434138334	28569	Economy	7700.00
0005434138361	28569	Economy	7700.00
0005434137842	28569	Economy	7700.00
0005434138025	28569	Economy	7700.00
0005434087524	28569	Economy	7700.00
0005434138090	28569	Economy	7700.00
0005434138314	28569	Economy	7700.00
0005434138163	28569	Economy	7700.00
0005434138042	28569	Economy	7700.00
0005434138183	28569	Economy	7700.00
0005434138225	28569	Economy	7700.00
0005435808343	1924	Economy	23900.00
0005435808345	1924	Economy	23900.00
0005435808341	1924	Economy	23900.00
0005435808337	1924	Economy	21700.00
0005434610266	1924	Economy	21700.00
0005435808340	1924	Economy	21700.00
0005435808347	1924	Economy	21700.00
0005434610268	1924	Economy	21700.00
0005433407586	1924	Economy	21700.00
0005435808342	1924	Economy	21700.00
0005433407555	1924	Economy	21700.00
0005433407579	1924	Economy	21700.00
0005434610267	1924	Economy	21700.00
0005433407537	1924	Economy	21700.00
0005435808339	1924	Economy	21700.00
0005433407577	1924	Economy	21700.00
0005433407574	1924	Economy	21700.00
0005433407578	1924	Economy	21700.00
0005435808346	1924	Economy	21700.00
0005435808344	1924	Economy	21700.00
0005435808338	1924	Economy	21700.00
0005433407573	1924	Economy	21700.00
0005434610228	23095	Economy	23900.00
0005434610248	23095	Economy	21700.00
0005434610224	23095	Economy	21700.00
0005434610225	23095	Economy	21700.00
0005434610247	23095	Economy	21700.00
0005434503944	16686	Economy	7600.00
0005434504245	16686	Economy	7600.00
0005434504226	16686	Economy	7600.00
0005434504186	16686	Economy	7600.00
0005434504238	16686	Economy	6900.00
0005434504174	16686	Economy	6900.00
0005434504166	16686	Economy	6900.00
0005434504297	16686	Economy	6900.00
0005434504250	16686	Economy	6900.00
0005434504244	16686	Economy	6900.00
0005434504189	16686	Economy	6900.00
0005434504202	16686	Economy	6900.00
0005434504165	16686	Economy	6900.00
0005434504175	16686	Economy	6900.00
0005434504205	16686	Economy	6900.00
0005434504305	16686	Economy	6900.00
0005434504232	16686	Economy	6900.00
0005434504247	16686	Economy	6900.00
0005434504167	16686	Economy	6900.00
0005434504172	16686	Economy	6900.00
0005434504236	16686	Economy	6900.00
0005434504078	16686	Economy	6900.00
0005434504237	16686	Economy	6900.00
0005434504201	16686	Economy	6900.00
0005434504211	16686	Economy	6900.00
0005434504310	16686	Economy	6900.00
0005434504114	16686	Economy	6900.00
0005434504210	16686	Economy	6900.00
0005434504231	16686	Economy	6900.00
0005434504251	16686	Economy	6900.00
0005434504129	16686	Economy	6900.00
0005434504177	16686	Economy	6900.00
0005434504176	16686	Economy	6900.00
0005434504248	16686	Economy	6900.00
0005434504271	16686	Economy	6900.00
0005434503943	16686	Economy	6900.00
0005434503945	16686	Economy	6900.00
0005434503992	16686	Economy	6900.00
0005434504217	16686	Economy	6900.00
0005434504227	16686	Economy	6900.00
0005434504146	16686	Economy	6900.00
0005434504131	16686	Economy	6900.00
0005434504203	16686	Economy	6900.00
0005434504185	16686	Economy	6900.00
0005434504113	16686	Economy	6900.00
0005434504531	22885	Economy	7600.00
0005434504522	22885	Economy	6900.00
0005434504510	22885	Economy	6900.00
0005434504512	22885	Economy	6900.00
0005434504525	22885	Economy	6900.00
0005434504534	22885	Economy	6900.00
0005434504544	22885	Economy	6900.00
0005434504537	22885	Economy	6900.00
0005434504518	22885	Economy	6900.00
0005434504517	22885	Economy	6900.00
0005434504532	22885	Economy	6900.00
0005434504516	22885	Economy	6900.00
0005434504507	22885	Economy	6900.00
0005434504513	22885	Economy	6900.00
0005434504528	22885	Economy	6900.00
0005434504515	22885	Economy	6900.00
0005434504545	22885	Economy	6900.00
0005434504538	22885	Economy	6900.00
0005434504509	22885	Economy	6900.00
0005434504529	22885	Economy	6900.00
0005434504511	22885	Economy	6900.00
0005434504535	22885	Economy	6900.00
0005434504526	22885	Economy	6900.00
0005434504539	22885	Economy	6900.00
0005434504514	22885	Economy	6900.00
0005434504524	22885	Economy	6900.00
0005434504542	22885	Economy	6900.00
0005434504533	22885	Economy	6900.00
0005434504508	22885	Economy	6900.00
0005434504506	22885	Economy	6900.00
0005434504505	22885	Economy	6900.00
0005434504530	22885	Economy	6900.00
0005434504541	22885	Economy	6900.00
0005434504520	22885	Economy	6900.00
0005434504519	22885	Economy	6900.00
0005434504521	22885	Economy	6900.00
0005434504543	22885	Economy	6900.00
0005434504527	22885	Economy	6900.00
0005434504540	22885	Economy	6900.00
0005434504536	22885	Economy	6900.00
0005434504523	22885	Economy	6900.00
0005433266766	2192	Economy	7700.00
0005435078503	2192	Economy	7700.00
0005435078509	2192	Economy	7700.00
0005435078497	2192	Economy	7000.00
0005433266750	2192	Economy	7000.00
0005433266677	2192	Economy	7000.00
0005433266692	2192	Economy	7000.00
0005433266763	2192	Economy	7000.00
0005435078501	2192	Economy	7000.00
0005433266732	2192	Economy	7000.00
0005433266738	2192	Economy	7000.00
0005433266724	2192	Economy	7000.00
0005435078507	2192	Economy	7000.00
0005435078496	2192	Economy	7000.00
0005433266767	2192	Economy	7000.00
0005433266749	2192	Economy	7000.00
0005435078510	2192	Economy	7000.00
0005435078500	2192	Economy	7000.00
0005435078502	2192	Economy	7000.00
0005435078498	2192	Economy	7000.00
0005435078495	2192	Economy	7000.00
0005433266747	2192	Economy	7000.00
0005433266733	2192	Economy	7000.00
0005433266752	2192	Economy	7000.00
0005433266768	2192	Economy	7000.00
0005435078506	2192	Economy	7000.00
0005435078499	2192	Economy	7000.00
0005435078505	2192	Economy	7000.00
0005435078504	2192	Economy	7000.00
0005433266737	2192	Economy	7000.00
0005435078494	2192	Economy	7000.00
0005435078508	2192	Economy	7000.00
0005433266769	2192	Economy	7000.00
0005433266745	2192	Economy	7000.00
0005433266815	24351	Economy	7000.00
0005435078326	24351	Economy	7000.00
0005433266820	24351	Economy	7000.00
0005433266821	24351	Economy	7000.00
0005435078327	24351	Economy	7000.00
0005435078405	24351	Economy	7000.00
0005433266818	24351	Economy	7000.00
0005435078367	24351	Economy	7000.00
0005435078369	24351	Economy	7000.00
0005435078353	24351	Economy	7000.00
0005435078360	24351	Economy	7000.00
0005433266817	24351	Economy	7000.00
0005433266819	24351	Economy	7000.00
0005433266822	24351	Economy	7000.00
0005435078366	24351	Economy	7000.00
0005435078359	24351	Economy	7000.00
0005435078370	24351	Economy	7000.00
0005435078411	24351	Economy	7000.00
0005433266816	24351	Economy	7000.00
0005435078406	24351	Economy	7000.00
0005433266823	24351	Economy	7000.00
0005435078407	24351	Economy	7000.00
0005435078371	24351	Economy	7000.00
0005435464515	6620	Economy	10800.00
0005434988848	6620	Economy	10800.00
0005434988857	6620	Economy	9800.00
0005435803288	6620	Economy	9800.00
0005435803290	6620	Economy	9800.00
0005434988856	6620	Economy	9800.00
0005435803291	6620	Economy	9800.00
0005434988855	6620	Economy	9800.00
0005435464505	6620	Economy	9800.00
0005434988852	6620	Economy	9800.00
0005434988850	6620	Economy	9800.00
0005434988853	6620	Economy	9800.00
0005435803289	6620	Economy	9800.00
0005435464513	6620	Economy	9800.00
0005434988858	6620	Economy	9800.00
0005434988846	6620	Economy	9800.00
0005434988849	6620	Economy	9800.00
0005434988854	6620	Economy	9800.00
0005434988851	6620	Economy	9800.00
0005435464514	6620	Economy	9800.00
0005434988847	6620	Economy	9800.00
0005434988716	23638	Economy	10800.00
0005434988730	23638	Economy	10800.00
0005434988727	23638	Economy	10800.00
0005434988731	23638	Economy	9800.00
0005434988751	23638	Economy	9800.00
0005434988719	23638	Economy	9800.00
0005434988726	23638	Economy	9800.00
0005434988741	23638	Economy	9800.00
0005434988720	23638	Economy	9800.00
0005434988717	23638	Economy	9800.00
0005434988732	23638	Economy	9800.00
0005434988733	23638	Economy	9800.00
0005434988715	23638	Economy	9800.00
0005434988724	23638	Economy	9800.00
0005434988745	23638	Economy	9800.00
0005434988743	23638	Economy	9800.00
0005433450196	30506	Business	9900.00
0005433450187	30506	Business	9900.00
0005432383593	30506	Business	9900.00
0005433450206	30506	Business	9900.00
0005432383599	30506	Business	9900.00
0005433453780	30506	Business	9900.00
0005433450192	30506	Business	9900.00
0005432383571	30506	Business	9900.00
0005432383607	30506	Economy	3300.00
0005432383581	30506	Economy	3300.00
0005432383586	30506	Economy	3300.00
0005432383592	30506	Economy	3300.00
0005433450188	30506	Economy	3300.00
0005433450198	30506	Economy	3300.00
0005432383583	30506	Economy	3600.00
0005432383601	30506	Economy	3600.00
0005433450186	30506	Economy	3600.00
0005432383576	30506	Economy	3300.00
0005432383577	30506	Economy	3300.00
0005433450194	30506	Economy	3300.00
0005432383574	30506	Economy	3300.00
0005433450193	30506	Economy	3300.00
0005433450201	30506	Economy	3300.00
0005432383589	30506	Economy	3300.00
0005432383575	30506	Economy	3300.00
0005433453781	30506	Economy	3300.00
0005433450197	30506	Economy	3300.00
0005432383578	30506	Economy	3300.00
0005432383594	30506	Economy	3300.00
0005433450191	30506	Economy	3300.00
0005432383598	30506	Economy	3300.00
0005432383584	30506	Economy	3300.00
0005432383602	30506	Economy	3300.00
0005432383573	30506	Economy	3300.00
0005432383588	30506	Economy	3300.00
0005433450200	30506	Economy	3300.00
0005432383587	30506	Economy	3300.00
0005432383585	30506	Economy	3300.00
0005432383582	30506	Economy	3300.00
0005432383580	30506	Economy	3300.00
0005432383604	30506	Economy	3300.00
0005432383596	30506	Economy	3300.00
0005433450189	30506	Economy	3300.00
0005432383606	30506	Economy	3300.00
0005433450203	30506	Economy	3300.00
0005432383600	30506	Economy	3300.00
0005433450205	30506	Economy	3300.00
0005433450195	30506	Economy	3300.00
0005433450204	30506	Economy	3300.00
0005432383591	30506	Economy	3300.00
0005432383605	30506	Economy	3300.00
0005432383608	30506	Economy	3300.00
0005432383590	30506	Economy	3300.00
0005432383597	30506	Economy	3300.00
0005433450199	30506	Economy	3300.00
0005432383603	30506	Economy	3300.00
0005432383572	30506	Economy	3300.00
0005433450185	30506	Economy	3300.00
0005433450202	30506	Economy	3300.00
0005433454898	30506	Economy	3300.00
0005432383579	30506	Economy	3300.00
0005433450190	30506	Economy	3300.00
0005432383595	30506	Economy	3300.00
0005432382918	31324	Business	9900.00
0005432383160	31324	Business	9900.00
0005432383041	31324	Business	9900.00
0005432383218	31324	Business	9900.00
0005432383163	31324	Business	9900.00
0005432383321	31324	Business	9900.00
0005433449955	31324	Business	9900.00
0005433449989	31324	Business	9900.00
0005432383072	31324	Economy	3300.00
0005432382971	31324	Economy	3300.00
0005432383035	31324	Economy	3300.00
0005433450010	31324	Economy	3300.00
0005433449935	31324	Economy	3300.00
0005433450030	31324	Economy	3300.00
0005433449983	31324	Economy	3600.00
0005433449991	31324	Economy	3600.00
0005432382972	31324	Economy	3600.00
0005433449877	31324	Economy	3600.00
0005432383129	31324	Economy	3300.00
0005432383309	31324	Economy	3300.00
0005432383157	31324	Economy	3300.00
0005432383136	31324	Economy	3300.00
0005432383119	31324	Economy	3300.00
0005432383201	31324	Economy	3300.00
0005433453767	31324	Economy	3300.00
0005433449941	31324	Economy	3300.00
0005432382919	31324	Economy	3300.00
0005433449878	31324	Economy	3300.00
0005432383118	31324	Economy	3300.00
0005432383227	31324	Economy	3300.00
0005433450048	31324	Economy	3300.00
0005432383158	31324	Economy	3300.00
0005433450013	31324	Economy	3300.00
0005433449984	31324	Economy	3300.00
0005433449985	31324	Economy	3300.00
0005432382988	31324	Economy	3300.00
0005432383320	31324	Economy	3300.00
0005432383226	31324	Economy	3300.00
0005432383161	31324	Economy	3300.00
0005432383200	31324	Economy	3300.00
0005432383114	31324	Economy	3300.00
0005433449982	31324	Economy	3300.00
0005433450087	31324	Economy	3300.00
0005432383332	31324	Economy	3300.00
0005432383197	31324	Economy	3300.00
0005433449986	31324	Economy	3300.00
0005432383240	31324	Economy	3300.00
0005433453765	31324	Economy	3300.00
0005432383331	31324	Economy	3300.00
0005433450011	31324	Economy	3300.00
0005433450047	31324	Economy	3300.00
0005432383036	31324	Economy	3300.00
0005432383217	31324	Economy	3300.00
0005433450084	31324	Economy	3300.00
0005432383064	31324	Economy	3300.00
0005433450021	31324	Economy	3300.00
0005433450088	31324	Economy	3300.00
0005433450038	31324	Economy	3300.00
0005433453766	31324	Economy	3300.00
0005433450107	31324	Economy	3300.00
0005433450076	31324	Economy	3300.00
0005433449934	31324	Economy	3300.00
0005433450090	31324	Economy	3300.00
0005432383156	31324	Economy	3300.00
0005432383254	31324	Economy	3300.00
0005432383270	31324	Economy	3300.00
0005432383192	31324	Economy	3300.00
0005433450015	31324	Economy	3300.00
0005432383113	31324	Economy	3300.00
0005433450031	31324	Economy	3300.00
0005433450083	31324	Economy	3300.00
0005433450089	31324	Economy	3300.00
0005433450108	31324	Economy	3300.00
0005432383155	31324	Economy	3300.00
0005432383115	31324	Economy	3300.00
0005433788204	26482	Economy	26200.00
0005433788197	26482	Economy	23800.00
0005435548542	26482	Economy	23800.00
0005433788194	26482	Economy	23800.00
0005435548539	26482	Economy	23800.00
0005433788199	26482	Economy	23800.00
0005435548544	26482	Economy	23800.00
0005433788195	26482	Economy	23800.00
0005435548541	26482	Economy	23800.00
0005435548545	26482	Economy	23800.00
0005433788181	26482	Economy	23800.00
0005433788182	26482	Economy	23800.00
0005435548546	26482	Economy	23800.00
0005435548538	26482	Economy	23800.00
0005433788205	26482	Economy	23800.00
0005433788198	26482	Economy	23800.00
0005435548543	26482	Economy	23800.00
0005435548540	26482	Economy	23800.00
0005433131708	10762	Economy	17100.00
0005433131716	10762	Economy	15600.00
0005435299735	10762	Economy	15600.00
0005435304166	10762	Economy	15600.00
0005435304171	10762	Economy	15600.00
0005435304161	10762	Economy	15600.00
0005435304178	10762	Economy	15600.00
0005435299803	10762	Economy	15600.00
0005435299791	10762	Economy	15600.00
0005433131703	10762	Economy	15600.00
0005435299783	10762	Economy	15600.00
0005435304177	10762	Economy	15600.00
0005433131714	10762	Economy	15600.00
0005435299766	10762	Economy	15600.00
0005435299767	10762	Economy	15600.00
0005435304170	10762	Economy	15600.00
0005435304165	10762	Economy	15600.00
0005435304159	10762	Economy	15600.00
0005435299827	29735	Economy	15600.00
0005433129327	29735	Economy	15600.00
0005435299829	29735	Economy	15600.00
0005433129325	29735	Economy	15600.00
0005433129328	29735	Economy	15600.00
0005433126896	29735	Economy	15600.00
0005435299828	29735	Economy	15600.00
0005435302252	29735	Economy	15600.00
0005433126898	29735	Economy	15600.00
0005435302253	29735	Economy	15600.00
0005433126897	29735	Economy	15600.00
0005435302250	29735	Economy	15600.00
0005433129329	29735	Economy	15600.00
0005433129326	29735	Economy	15600.00
0005435299831	29735	Economy	15600.00
0005435302249	29735	Economy	15600.00
0005435299830	29735	Economy	15600.00
0005435302251	29735	Economy	15600.00
0005433110045	2435	Economy	17200.00
0005434287518	2435	Economy	17200.00
0005432264501	2435	Economy	15700.00
0005434287512	2435	Economy	15700.00
0005433110077	2435	Economy	15700.00
0005433110096	2435	Economy	15700.00
0005434287520	2435	Economy	15700.00
0005434287516	2435	Economy	15700.00
0005434287519	2435	Economy	15700.00
0005434287517	2435	Economy	15700.00
0005434287510	2435	Economy	15700.00
0005433110044	2435	Economy	15700.00
0005434287528	2435	Economy	15700.00
0005432264500	2435	Economy	15700.00
0005434287525	2435	Economy	15700.00
0005433110046	2435	Economy	15700.00
0005434287508	2435	Economy	15700.00
0005434287513	2435	Economy	15700.00
0005434287509	2435	Economy	15700.00
0005434287521	2435	Economy	15700.00
0005433110042	2435	Economy	15700.00
0005434287522	2435	Economy	15700.00
0005433110110	2435	Economy	15700.00
0005434287524	2435	Economy	15700.00
0005433110111	2435	Economy	15700.00
0005433110078	2435	Economy	15700.00
0005434287526	2435	Economy	15700.00
0005434287511	2435	Economy	15700.00
0005434287523	2435	Economy	15700.00
0005434287527	2435	Economy	15700.00
0005434287515	2435	Economy	15700.00
0005434287514	2435	Economy	15700.00
0005434287314	26868	Economy	17200.00
0005434287417	26868	Economy	17200.00
0005434287371	26868	Economy	17200.00
0005433110174	26868	Economy	17200.00
0005434287349	26868	Economy	15700.00
0005434287354	26868	Economy	15700.00
0005434287364	26868	Economy	15700.00
0005433110181	26868	Economy	15700.00
0005434287305	26868	Economy	15700.00
0005434287313	26868	Economy	15700.00
0005433110178	26868	Economy	15700.00
0005434287326	26868	Economy	15700.00
0005434287319	26868	Economy	15700.00
0005433110183	26868	Economy	15700.00
0005433110180	26868	Economy	15700.00
0005434287162	26868	Economy	15700.00
0005434287391	26868	Economy	15700.00
0005434287303	26868	Economy	15700.00
0005433110179	26868	Economy	15700.00
0005433110182	26868	Economy	15700.00
0005434287318	26868	Economy	15700.00
0005434287342	26868	Economy	15700.00
0005434287392	26868	Economy	15700.00
0005434287353	26868	Economy	15700.00
0005434287362	26868	Economy	15700.00
0005433110175	26868	Economy	15700.00
0005433110177	26868	Economy	15700.00
0005433110176	26868	Economy	15700.00
0005434287348	26868	Economy	15700.00
0005434287372	26868	Economy	15700.00
0005434287317	26868	Economy	15700.00
0005435856246	25449	Economy	22800.00
0005434269096	25449	Economy	22800.00
0005435856249	25449	Economy	22800.00
0005435856247	25449	Economy	22800.00
0005435856248	25449	Economy	22800.00
0005435856206	26624	Economy	22800.00
0005435856221	26624	Economy	22800.00
0005435854060	26624	Economy	22800.00
0005435856185	26624	Economy	22800.00
0005435856207	26624	Economy	22800.00
0005435314832	6110	Economy	24600.00
0005435314823	6110	Economy	24600.00
0005434520345	6110	Economy	24600.00
0005434520360	6110	Economy	24600.00
0005434520351	6110	Economy	22300.00
0005434520334	6110	Economy	22300.00
0005434520339	6110	Economy	22300.00
0005435314824	6110	Economy	22300.00
0005434520356	6110	Economy	22300.00
0005434520355	6110	Economy	22300.00
0005434520335	6110	Economy	22300.00
0005434520347	6110	Economy	22300.00
0005434520361	6110	Economy	22300.00
0005435314829	6110	Economy	22300.00
0005434520338	6110	Economy	22300.00
0005434520353	6110	Economy	22300.00
0005434520342	6110	Economy	22300.00
0005435314831	6110	Economy	22300.00
0005434520352	6110	Economy	22300.00
0005435314825	6110	Economy	22300.00
0005434520348	6110	Economy	22300.00
0005434520343	6110	Economy	22300.00
0005435314822	6110	Economy	22300.00
0005434520340	6110	Economy	22300.00
0005435314841	6110	Economy	22300.00
0005434520362	6110	Economy	22300.00
0005434520357	6110	Economy	22300.00
0005434520344	6110	Economy	22300.00
0005434520354	6110	Economy	22300.00
0005434520333	6110	Economy	22300.00
0005434520346	6110	Economy	22300.00
0005434520349	6110	Economy	22300.00
0005434520350	6110	Economy	22300.00
0005434520337	6110	Economy	22300.00
0005434520332	6110	Economy	22300.00
0005434520341	6110	Economy	22300.00
0005435314827	6110	Economy	22300.00
0005435314842	6110	Economy	22300.00
0005435314840	6110	Economy	22300.00
0005434520358	6110	Economy	22300.00
0005435314815	6110	Economy	22300.00
0005434520359	6110	Economy	22300.00
0005434520331	6110	Economy	22300.00
0005434520336	6110	Economy	22300.00
0005435314826	6110	Economy	22300.00
0005433650611	27637	Business	89800.00
0005435263695	27637	Business	89800.00
0005433650589	27637	Business	89800.00
0005435263693	27637	Business	89800.00
0005433650582	27637	Business	89800.00
0005435263694	27637	Business	89800.00
0005433650602	27637	Business	89800.00
0005433650601	27637	Business	89800.00
0005433650658	27637	Business	89800.00
0005433650667	27637	Business	89800.00
0005433650627	27637	Business	89800.00
0005433650581	27637	Business	89800.00
0005433650661	27637	Economy	29900.00
0005435263688	27637	Economy	29900.00
0005435263687	27637	Economy	29900.00
0005433650624	27637	Economy	29900.00
0005435263696	27637	Economy	29900.00
0005433650663	27637	Economy	29900.00
0005433650625	27637	Economy	29900.00
0005435263690	27637	Economy	29900.00
0005433650619	27637	Economy	29900.00
0005433650642	27637	Economy	29900.00
0005433650552	27637	Economy	32900.00
0005433650628	27637	Economy	32900.00
0005433650688	27637	Economy	32900.00
0005433650576	27637	Economy	32900.00
0005433650614	27637	Economy	32900.00
0005433650610	27637	Economy	29900.00
0005433650664	27637	Economy	29900.00
0005433650557	27637	Economy	29900.00
0005435263691	27637	Economy	29900.00
0005433650615	27637	Economy	29900.00
0005433650726	27637	Economy	29900.00
0005433650598	27637	Economy	29900.00
0005433650528	27637	Economy	29900.00
0005433650674	27637	Economy	29900.00
0005433650671	27637	Economy	29900.00
0005433650593	27637	Economy	29900.00
0005433650652	27637	Economy	29900.00
0005435263697	27637	Economy	29900.00
0005433650604	27637	Economy	29900.00
0005435263685	27637	Economy	29900.00
0005433650587	27637	Economy	29900.00
0005433650590	27637	Economy	29900.00
0005435263684	27637	Economy	29900.00
0005433650551	27637	Economy	29900.00
0005433650536	27637	Economy	29900.00
0005433650577	27637	Economy	29900.00
0005433650584	27637	Economy	29900.00
0005435263686	27637	Economy	29900.00
0005435263683	27637	Economy	29900.00
0005433650606	27637	Economy	29900.00
0005433650603	27637	Economy	29900.00
0005433650668	27637	Economy	29900.00
0005433650655	27637	Economy	29900.00
0005433650670	27637	Economy	29900.00
0005435263689	27637	Economy	29900.00
0005433650588	27637	Economy	29900.00
0005433650594	27637	Economy	29900.00
0005433650676	27637	Economy	29900.00
0005435263680	27637	Economy	29900.00
0005433650649	27637	Economy	29900.00
0005433650583	27637	Economy	29900.00
0005435263679	27637	Economy	29900.00
0005433650630	27637	Economy	29900.00
0005433650608	27637	Economy	29900.00
0005433650678	27637	Economy	29900.00
0005433650629	27637	Economy	29900.00
0005433650597	27637	Economy	29900.00
0005433650727	27637	Economy	29900.00
0005433650616	27637	Economy	29900.00
0005435263681	27637	Economy	29900.00
0005433650596	27637	Economy	29900.00
0005433650684	27637	Economy	29900.00
0005435263682	27637	Economy	29900.00
0005433650687	27637	Economy	29900.00
0005433650724	27637	Economy	29900.00
0005433650689	27637	Economy	29900.00
0005433650626	27637	Economy	29900.00
0005433650609	27637	Economy	29900.00
0005433650617	27637	Economy	29900.00
0005433650641	27637	Economy	29900.00
0005433650683	27637	Economy	29900.00
0005433650675	27637	Economy	29900.00
0005433650679	27637	Economy	29900.00
0005433650637	27637	Economy	29900.00
0005433650643	27637	Economy	29900.00
0005435263692	27637	Economy	29900.00
0005433650636	27637	Economy	29900.00
0005433650607	27637	Economy	29900.00
0005433650650	27637	Economy	29900.00
0005433650682	27637	Economy	29900.00
0005433650725	27637	Economy	29900.00
0005433650638	27637	Economy	29900.00
0005433650586	27637	Economy	29900.00
0005433650651	27637	Economy	29900.00
0005433868863	4764	Economy	19400.00
0005433868848	4764	Economy	19400.00
0005433868871	4764	Economy	19400.00
0005433868866	4764	Economy	19400.00
0005433868872	4764	Economy	17600.00
0005433868845	4764	Economy	17600.00
0005435860483	4764	Economy	17600.00
0005433868854	4764	Economy	17600.00
0005435860485	4764	Economy	17600.00
0005433868867	4764	Economy	17600.00
0005433868837	4764	Economy	17600.00
0005435860493	4764	Economy	17600.00
0005433868855	4764	Economy	17600.00
0005433868870	4764	Economy	17600.00
0005433868852	4764	Economy	17600.00
0005433868874	4764	Economy	17600.00
0005435860490	4764	Economy	17600.00
0005435860492	4764	Economy	17600.00
0005433868851	4764	Economy	17600.00
0005433868846	4764	Economy	17600.00
0005433868850	4764	Economy	17600.00
0005433868873	4764	Economy	17600.00
0005433868859	4764	Economy	17600.00
0005433868858	4764	Economy	17600.00
0005433868869	4764	Economy	17600.00
0005433868840	4764	Economy	17600.00
0005433868862	4764	Economy	17600.00
0005433868842	4764	Economy	17600.00
0005433868843	4764	Economy	17600.00
0005433868841	4764	Economy	17600.00
0005433868853	4764	Economy	17600.00
0005433868868	4764	Economy	17600.00
0005433868864	4764	Economy	17600.00
0005435860484	4764	Economy	17600.00
0005433868856	4764	Economy	17600.00
0005433868839	4764	Economy	17600.00
0005433868861	4764	Economy	17600.00
0005433868847	4764	Economy	17600.00
0005433868860	4764	Economy	17600.00
0005435860491	4764	Economy	17600.00
0005433868857	4764	Economy	17600.00
0005433868876	4764	Economy	17600.00
0005433868838	4764	Economy	17600.00
0005433868875	4764	Economy	17600.00
0005435860482	4764	Economy	17600.00
0005433868844	4764	Economy	17600.00
0005433868849	4764	Economy	17600.00
0005433868877	4764	Economy	17600.00
0005433868865	4764	Economy	17600.00
0005433868544	32579	Economy	19400.00
0005433868355	32579	Economy	19400.00
0005433868328	32579	Economy	19400.00
0005433868497	32579	Economy	19400.00
0005433868389	32579	Economy	17600.00
0005433868434	32579	Economy	17600.00
0005433868579	32579	Economy	17600.00
0005433868460	32579	Economy	17600.00
0005433868581	32579	Economy	17600.00
0005433868382	32579	Economy	17600.00
0005433868570	32579	Economy	17600.00
0005433868354	32579	Economy	17600.00
0005433868474	32579	Economy	17600.00
0005433868397	32579	Economy	17600.00
0005433868388	32579	Economy	17600.00
0005433868326	32579	Economy	17600.00
0005433868369	32579	Economy	17600.00
0005433868490	32579	Economy	17600.00
0005433868461	32579	Economy	17600.00
0005433868572	32579	Economy	17600.00
0005433868580	32579	Economy	17600.00
0005433868398	32579	Economy	17600.00
0005433868367	32579	Economy	17600.00
0005433868489	32579	Economy	17600.00
0005433868473	32579	Economy	17600.00
0005433868306	32579	Economy	17600.00
0005433868380	32579	Economy	17600.00
0005433868603	32579	Economy	17600.00
0005433868548	32579	Economy	17600.00
0005433868469	32579	Economy	17600.00
0005433868443	32579	Economy	17600.00
0005433868431	32579	Economy	17600.00
0005433868430	32579	Economy	17600.00
0005433868442	32579	Economy	17600.00
0005433868403	32579	Economy	17600.00
0005433868547	32579	Economy	17600.00
0005433868372	32579	Economy	17600.00
0005433868329	32579	Economy	17600.00
0005433868327	32579	Economy	17600.00
0005433868585	32579	Economy	17600.00
0005433868454	32579	Economy	17600.00
0005433868602	32579	Economy	17600.00
0005433868404	32579	Economy	17600.00
0005433868520	32579	Economy	17600.00
0005433868368	32579	Economy	17600.00
0005433868462	32579	Economy	17600.00
0005433868405	32579	Economy	17600.00
0005433868390	32579	Economy	17600.00
0005433868429	32579	Economy	17600.00
0005433868331	32579	Economy	17600.00
0005435911456	3453	Economy	24800.00
0005435911467	3453	Economy	24800.00
0005435911463	3453	Economy	24800.00
0005434663553	3453	Economy	22600.00
0005435911497	3453	Economy	22600.00
0005434663549	3453	Economy	22600.00
0005434663554	3453	Economy	22600.00
0005435911461	3453	Economy	22600.00
0005435911462	3453	Economy	22600.00
0005435911468	3453	Economy	22600.00
0005435911464	3453	Economy	22600.00
0005434663545	3453	Economy	22600.00
0005434663546	3453	Economy	22600.00
0005434663551	3453	Economy	22600.00
0005435911457	3453	Economy	22600.00
0005434460527	3453	Economy	22600.00
0005434663548	3453	Economy	22600.00
0005434460528	3453	Economy	22600.00
0005435911496	3453	Economy	22600.00
0005434663543	3453	Economy	22600.00
0005434663544	3453	Economy	22600.00
0005434461668	3453	Economy	22600.00
0005434663550	3453	Economy	22600.00
0005434663547	3453	Economy	22600.00
0005434461669	3453	Economy	22600.00
0005434663555	3453	Economy	22600.00
0005435911447	3453	Economy	22600.00
0005434663552	3453	Economy	22600.00
0005434663511	12477	Economy	24800.00
0005434663379	12477	Economy	22600.00
0005434663409	12477	Economy	22600.00
0005434663402	12477	Economy	22600.00
0005434663404	12477	Economy	22600.00
0005434663420	12477	Economy	22600.00
0005435911529	12477	Economy	22600.00
0005434663368	12477	Economy	22600.00
0005435911531	12477	Economy	22600.00
0005434663434	12477	Economy	22600.00
0005435911532	12477	Economy	22600.00
0005434663413	12477	Economy	22600.00
0005434663380	12477	Economy	22600.00
0005434663416	12477	Economy	22600.00
0005435911527	12477	Economy	22600.00
0005435911530	12477	Economy	22600.00
0005434663433	12477	Economy	22600.00
0005434663415	12477	Economy	22600.00
0005435911528	12477	Economy	22600.00
0005434663381	12477	Economy	22600.00
0005435911533	12477	Economy	22600.00
0005433868429	14513	Economy	18500.00
0005433868490	14513	Economy	18500.00
0005433868520	14513	Economy	18500.00
0005433868404	14513	Economy	18500.00
0005433868497	14513	Economy	16800.00
0005433868547	14513	Economy	16800.00
0005433868489	14513	Economy	16800.00
0005433868460	14513	Economy	16800.00
0005433868388	14513	Economy	16800.00
0005433868405	14513	Economy	16800.00
0005433868389	14513	Economy	16800.00
0005433868570	14513	Economy	16800.00
0005433868327	14513	Economy	16800.00
0005433868331	14513	Economy	16800.00
0005433868329	14513	Economy	16800.00
0005433868367	14513	Economy	16800.00
0005433868579	14513	Economy	16800.00
0005433868326	14513	Economy	16800.00
0005433868398	14513	Economy	16800.00
0005433868403	14513	Economy	16800.00
0005433868461	14513	Economy	16800.00
0005433868328	14513	Economy	16800.00
0005433868469	14513	Economy	16800.00
0005433868431	14513	Economy	16800.00
0005433868442	14513	Economy	16800.00
0005433868306	14513	Economy	16800.00
0005433868474	14513	Economy	16800.00
0005433868354	14513	Economy	16800.00
0005433868397	14513	Economy	16800.00
0005433868372	14513	Economy	16800.00
0005433868368	14513	Economy	16800.00
0005433868585	14513	Economy	16800.00
0005433868355	14513	Economy	16800.00
0005433868382	14513	Economy	16800.00
0005433868443	14513	Economy	16800.00
0005433868454	14513	Economy	16800.00
0005433868602	14513	Economy	16800.00
0005433868544	14513	Economy	16800.00
0005433868572	14513	Economy	16800.00
0005433868462	14513	Economy	16800.00
0005433868434	14513	Economy	16800.00
0005433868603	14513	Economy	16800.00
0005433868390	14513	Economy	16800.00
0005433868548	14513	Economy	16800.00
0005433868581	14513	Economy	16800.00
0005433868430	14513	Economy	16800.00
0005433868473	14513	Economy	16800.00
0005433868380	14513	Economy	16800.00
0005433868369	14513	Economy	16800.00
0005433868580	14513	Economy	16800.00
0005433868809	32683	Economy	18500.00
0005433868818	32683	Economy	18500.00
0005433868825	32683	Economy	18500.00
0005433868806	32683	Economy	18500.00
0005433868800	32683	Economy	16800.00
0005433868830	32683	Economy	16800.00
0005433868814	32683	Economy	16800.00
0005433868815	32683	Economy	16800.00
0005433868798	32683	Economy	16800.00
0005433868812	32683	Economy	16800.00
0005433868811	32683	Economy	16800.00
0005433868801	32683	Economy	16800.00
0005433868833	32683	Economy	16800.00
0005433868835	32683	Economy	16800.00
0005433868823	32683	Economy	16800.00
0005433868834	32683	Economy	16800.00
0005433868797	32683	Economy	16800.00
0005433868802	32683	Economy	16800.00
0005433868808	32683	Economy	16800.00
0005433868810	32683	Economy	16800.00
0005433868832	32683	Economy	16800.00
0005433868817	32683	Economy	16800.00
0005433868820	32683	Economy	16800.00
0005433868828	32683	Economy	16800.00
0005433868803	32683	Economy	16800.00
0005433868804	32683	Economy	16800.00
0005433868836	32683	Economy	16800.00
0005433868821	32683	Economy	16800.00
0005433868822	32683	Economy	16800.00
0005433868826	32683	Economy	16800.00
0005433868831	32683	Economy	16800.00
0005433868799	32683	Economy	16800.00
0005433868824	32683	Economy	16800.00
0005433868805	32683	Economy	16800.00
0005433868827	32683	Economy	16800.00
0005433868807	32683	Economy	16800.00
0005433868819	32683	Economy	16800.00
0005433868813	32683	Economy	16800.00
0005433868829	32683	Economy	16800.00
0005433868816	32683	Economy	16800.00
0005432799573	12095	Economy	4900.00
0005432799448	12095	Economy	4900.00
0005432799482	12095	Economy	4900.00
0005432799479	12095	Economy	4400.00
0005432799417	12095	Economy	4400.00
0005432799587	12095	Economy	4400.00
0005432799508	12095	Economy	4400.00
0005432799586	12095	Economy	4400.00
0005432799483	12095	Economy	4400.00
0005432799484	12095	Economy	4400.00
0005432799534	12095	Economy	4400.00
0005432799547	12095	Economy	4400.00
0005432799485	12095	Economy	4400.00
0005432799581	12095	Economy	4400.00
0005432799515	12095	Economy	4400.00
0005432799493	12095	Economy	4400.00
0005432799546	12095	Economy	4400.00
0005432799509	12095	Economy	4400.00
0005432799580	12095	Economy	4400.00
0005432799444	12095	Economy	4400.00
0005432799450	12095	Economy	4400.00
0005432799585	12095	Economy	4400.00
0005432799416	12095	Economy	4400.00
0005432799535	12095	Economy	4400.00
0005432799474	12095	Economy	4400.00
0005432799422	12095	Economy	4400.00
0005432799451	12095	Economy	4400.00
0005432799480	12095	Economy	4400.00
0005432799726	14813	Economy	4900.00
0005432799717	14813	Economy	4900.00
0005432799730	14813	Economy	4400.00
0005432799714	14813	Economy	4400.00
0005432799733	14813	Economy	4400.00
0005432799722	14813	Economy	4400.00
0005432799709	14813	Economy	4400.00
0005432799721	14813	Economy	4400.00
0005432799707	14813	Economy	4400.00
0005432799713	14813	Economy	4400.00
0005432799727	14813	Economy	4400.00
0005432799720	14813	Economy	4400.00
0005432799725	14813	Economy	4400.00
0005432799731	14813	Economy	4400.00
0005432799716	14813	Economy	4400.00
0005432799729	14813	Economy	4400.00
0005432799715	14813	Economy	4400.00
0005432799724	14813	Economy	4400.00
0005432799718	14813	Economy	4400.00
0005432799723	14813	Economy	4400.00
0005432799711	14813	Economy	4400.00
0005432799708	14813	Economy	4400.00
0005432799719	14813	Economy	4400.00
0005432799728	14813	Economy	4400.00
0005432799710	14813	Economy	4400.00
0005432799732	14813	Economy	4400.00
0005432799712	14813	Economy	4400.00
0005435311057	7043	Business	49100.00
0005435293297	7043	Business	49100.00
0005434299814	7043	Business	49100.00
0005434408424	7043	Business	49100.00
0005434299798	7043	Business	49100.00
0005435293291	7043	Business	49100.00
0005435293234	7043	Business	49100.00
0005434299797	7043	Business	49100.00
0005434299803	7043	Economy	16400.00
0005435293296	7043	Economy	16400.00
0005434408396	7043	Economy	16400.00
0005435311056	7043	Economy	16400.00
0005434299806	7043	Economy	16400.00
0005434408419	7043	Economy	16400.00
0005434408407	7043	Economy	16400.00
0005434408445	7043	Economy	16400.00
0005434299801	7043	Economy	16400.00
0005434408431	7043	Economy	16400.00
0005434408386	7043	Economy	16400.00
0005434408404	7043	Economy	16400.00
0005434408443	7043	Economy	16400.00
0005434299812	7043	Economy	16400.00
0005434408444	7043	Economy	16400.00
0005434408408	7043	Economy	16400.00
0005434299796	7043	Economy	16400.00
0005434408438	7043	Economy	16400.00
0005432154010	7043	Economy	16400.00
0005434408433	7043	Economy	16400.00
0005434408384	7043	Economy	16400.00
0005434408390	7043	Economy	16400.00
0005434408388	7043	Economy	16400.00
0005434408410	7043	Economy	16400.00
0005434299805	7043	Economy	16400.00
0005434408382	7043	Economy	16400.00
0005434408441	7043	Economy	16400.00
0005434408436	7043	Economy	16400.00
0005434408428	7043	Economy	16400.00
0005434299808	7043	Economy	16400.00
0005434299793	7043	Economy	16400.00
0005434299810	7043	Economy	16400.00
0005434299792	7043	Economy	16400.00
0005435311041	7043	Economy	16400.00
0005435293277	7043	Economy	18000.00
0005434408417	7043	Economy	16400.00
0005434299790	7043	Economy	18000.00
0005434408399	7043	Economy	18000.00
0005435293233	7043	Economy	18000.00
0005432154013	7043	Economy	18000.00
0005435293276	7043	Economy	18000.00
0005435293257	7043	Economy	16400.00
0005434408414	7043	Economy	16400.00
0005434408383	7043	Economy	16400.00
0005435293265	7043	Economy	16400.00
0005432108276	7043	Economy	16400.00
0005432154011	7043	Economy	16400.00
0005434408401	7043	Economy	16400.00
0005435293210	7043	Economy	16400.00
0005434408440	7043	Economy	16400.00
0005434408389	7043	Economy	16400.00
0005434408418	7043	Economy	16400.00
0005432154012	7043	Economy	16400.00
0005434299791	7043	Economy	16400.00
0005435311085	7043	Economy	16400.00
0005434299809	7043	Economy	16400.00
0005435311052	7043	Economy	16400.00
0005434408435	7043	Economy	16400.00
0005434408406	7043	Economy	16400.00
0005434408387	7043	Economy	16400.00
0005434408413	7043	Economy	16400.00
0005435293206	7043	Economy	16400.00
0005434408403	7043	Economy	16400.00
0005434408394	7043	Economy	16400.00
0005432154009	7043	Economy	16400.00
0005434299795	7043	Economy	16400.00
0005434408434	7043	Economy	16400.00
0005434408432	7043	Economy	16400.00
0005434408425	7043	Economy	16400.00
0005435311053	7043	Economy	16400.00
0005434408385	7043	Economy	16400.00
0005434408415	7043	Economy	16400.00
0005434408446	7043	Economy	16400.00
0005434408416	7043	Economy	16400.00
0005434408423	7043	Economy	16400.00
0005434408405	7043	Economy	16400.00
0005434408391	7043	Economy	16400.00
0005434408437	7043	Economy	16400.00
0005434408422	7043	Economy	16400.00
0005434299794	7043	Economy	16400.00
0005434408397	7043	Economy	16400.00
0005434408426	7043	Economy	16400.00
0005434408442	7043	Economy	16400.00
0005434299802	7043	Economy	16400.00
0005432108277	7043	Economy	16400.00
0005434408393	7043	Economy	16400.00
0005435293211	7043	Economy	16400.00
0005434408421	7043	Economy	16400.00
0005434408412	7043	Economy	16400.00
0005434408400	7043	Economy	16400.00
0005435311042	7043	Economy	16400.00
0005434408430	7043	Economy	16400.00
0005434299811	7043	Economy	16400.00
0005434408411	7043	Economy	16400.00
0005434408392	7043	Economy	16400.00
0005434299804	7043	Economy	16400.00
0005434408409	7043	Economy	16400.00
0005435311048	7043	Economy	16400.00
0005434408439	7043	Economy	16400.00
0005434408427	7043	Economy	16400.00
0005434408420	7043	Economy	16400.00
0005434299799	7043	Economy	16400.00
0005434299807	7043	Economy	16400.00
0005434299813	7043	Economy	16400.00
0005434408429	7043	Economy	16400.00
0005434299800	7043	Economy	16400.00
0005434408395	7043	Economy	16400.00
0005434408398	7043	Economy	16400.00
0005435293207	7043	Economy	16400.00
0005434408402	7043	Economy	16400.00
0005434299615	26915	Business	49100.00
0005434407688	26915	Business	49100.00
0005434407885	26915	Business	49100.00
0005434299538	26915	Business	49100.00
0005434408062	26915	Business	49100.00
0005434407765	26915	Business	49100.00
0005434407774	26915	Business	49100.00
0005434407892	26915	Business	49100.00
0005434299665	26915	Business	49100.00
0005434407585	26915	Business	49100.00
0005434299669	26915	Business	49100.00
0005434407779	26915	Business	49100.00
0005434407745	26915	Economy	16400.00
0005435311174	26915	Economy	16400.00
0005435293377	26915	Economy	16400.00
0005435311170	26915	Economy	16400.00
0005435311172	26915	Economy	16400.00
0005434407915	26915	Economy	16400.00
0005434407963	26915	Economy	16400.00
0005435293384	26915	Economy	16400.00
0005434407658	26915	Economy	16400.00
0005434407700	26915	Economy	16400.00
0005435293380	26915	Economy	16400.00
0005435293376	26915	Economy	16400.00
0005434407825	26915	Economy	16400.00
0005434407709	26915	Economy	16400.00
0005434407707	26915	Economy	16400.00
0005434407926	26915	Economy	16400.00
0005435293382	26915	Economy	16400.00
0005434299608	26915	Economy	16400.00
0005434407635	26915	Economy	16400.00
0005434299617	26915	Economy	16400.00
0005432058420	26915	Economy	16400.00
0005434407661	26915	Economy	16400.00
0005434407806	26915	Economy	16400.00
0005434407835	26915	Economy	16400.00
0005435311167	26915	Economy	16400.00
0005434299702	26915	Economy	16400.00
0005435293383	26915	Economy	16400.00
0005434299667	26915	Economy	16400.00
0005434407801	26915	Economy	16400.00
0005435293385	26915	Economy	16400.00
0005435293386	26915	Economy	16400.00
0005434407818	26915	Economy	16400.00
0005434408087	26915	Economy	16400.00
0005434407884	26915	Economy	16400.00
0005434407805	26915	Economy	16400.00
0005434299676	26915	Economy	18000.00
0005435311165	26915	Economy	18000.00
0005435311163	26915	Economy	18000.00
0005434407593	26915	Economy	18000.00
0005434299616	26915	Economy	18000.00
0005434407800	26915	Economy	16400.00
0005434407525	26915	Economy	16400.00
0005434407634	26915	Economy	16400.00
0005434407942	26915	Economy	16400.00
0005434407687	26915	Economy	16400.00
0005435293379	26915	Economy	16400.00
0005435311176	26915	Economy	16400.00
0005434407913	26915	Economy	16400.00
0005434407804	26915	Economy	16400.00
0005434407646	26915	Economy	16400.00
0005434299646	26915	Economy	16400.00
0005435293375	26915	Economy	16400.00
0005434407817	26915	Economy	16400.00
0005434407813	26915	Economy	16400.00
0005434299674	26915	Economy	16400.00
0005434407799	26915	Economy	16400.00
0005434299639	26915	Economy	16400.00
0005434299638	26915	Economy	16400.00
0005434407861	26915	Economy	16400.00
0005434407943	26915	Economy	16400.00
0005434407881	26915	Economy	16400.00
0005434407816	26915	Economy	16400.00
0005434407880	26915	Economy	16400.00
0005435311171	26915	Economy	16400.00
0005434407626	26915	Economy	16400.00
0005434407819	26915	Economy	16400.00
0005434299558	26915	Economy	16400.00
0005434407914	26915	Economy	16400.00
0005435311177	26915	Economy	16400.00
0005435311169	26915	Economy	16400.00
0005432058418	26915	Economy	16400.00
0005434299594	26915	Economy	16400.00
0005434407766	26915	Economy	16400.00
0005434407929	26915	Economy	16400.00
0005435293378	26915	Economy	16400.00
0005434299614	26915	Economy	16400.00
0005435311164	26915	Economy	16400.00
0005435311168	26915	Economy	16400.00
0005434407708	26915	Economy	16400.00
0005434407775	26915	Economy	16400.00
0005434299673	26915	Economy	16400.00
0005434299626	26915	Economy	16400.00
0005435293387	26915	Economy	16400.00
0005434407647	26915	Economy	16400.00
0005434407841	26915	Economy	16400.00
0005434407787	26915	Economy	16400.00
0005435311166	26915	Economy	16400.00
0005435293381	26915	Economy	16400.00
0005434407850	26915	Economy	16400.00
0005434407736	26915	Economy	16400.00
0005434407588	26915	Economy	16400.00
0005432058419	26915	Economy	16400.00
0005434407657	26915	Economy	16400.00
0005435311173	26915	Economy	16400.00
0005434407587	26915	Economy	16400.00
0005435311175	26915	Economy	16400.00
0005434407656	26915	Economy	16400.00
0005434299668	26915	Economy	16400.00
0005434407782	26915	Economy	16400.00
0005434408035	26915	Economy	16400.00
0005432604740	6431	Economy	16500.00
0005432604762	6431	Economy	16500.00
0005432604756	6431	Economy	16500.00
0005435218120	6431	Economy	16500.00
0005432604752	6431	Economy	15000.00
0005432604765	6431	Economy	15000.00
0005432604743	6431	Economy	15000.00
0005432604742	6431	Economy	15000.00
0005434512157	6431	Economy	15000.00
0005432604777	6431	Economy	15000.00
0005432604773	6431	Economy	15000.00
0005432604768	6431	Economy	15000.00
0005432604753	6431	Economy	15000.00
0005432604759	6431	Economy	15000.00
0005434512156	6431	Economy	15000.00
0005432604767	6431	Economy	15000.00
0005432604771	6431	Economy	15000.00
0005432604764	6431	Economy	15000.00
0005432604745	6431	Economy	15000.00
0005432604763	6431	Economy	15000.00
0005432604774	6431	Economy	15000.00
0005432604758	6431	Economy	15000.00
0005432604751	6431	Economy	15000.00
0005432604746	6431	Economy	15000.00
0005432604755	6431	Economy	15000.00
0005432604757	6431	Economy	15000.00
0005432604761	6431	Economy	15000.00
0005432604749	6431	Economy	15000.00
0005432604775	6431	Economy	15000.00
0005432604772	6431	Economy	15000.00
0005432604760	6431	Economy	15000.00
0005432604769	6431	Economy	15000.00
0005432604741	6431	Economy	15000.00
0005432604770	6431	Economy	15000.00
0005432604750	6431	Economy	15000.00
0005432604747	6431	Economy	15000.00
0005432604739	6431	Economy	15000.00
0005432604754	6431	Economy	15000.00
0005432604744	6431	Economy	15000.00
0005432604766	6431	Economy	15000.00
0005432604778	6431	Economy	15000.00
0005432604776	6431	Economy	15000.00
0005432604737	6431	Economy	15000.00
0005432604738	6431	Economy	15000.00
0005432604748	6431	Economy	15000.00
0005432604402	21355	Economy	16500.00
0005432604569	21355	Economy	16500.00
0005432604442	21355	Economy	16500.00
0005432604336	21355	Economy	16500.00
0005432604439	21355	Economy	15000.00
0005432604486	21355	Economy	15000.00
0005432604114	21355	Economy	15000.00
0005432604501	21355	Economy	15000.00
0005432604487	21355	Economy	15000.00
0005432604268	21355	Economy	15000.00
0005432604458	21355	Economy	15000.00
0005432604319	21355	Economy	15000.00
0005434512126	21355	Economy	15000.00
0005432604347	21355	Economy	15000.00
0005432604500	21355	Economy	15000.00
0005432604113	21355	Economy	15000.00
0005432604219	21355	Economy	15000.00
0005432604283	21355	Economy	15000.00
0005432604322	21355	Economy	15000.00
0005432604497	21355	Economy	15000.00
0005434512125	21355	Economy	15000.00
0005432604341	21355	Economy	15000.00
0005432604313	21355	Economy	15000.00
0005432604343	21355	Economy	15000.00
0005432604181	21355	Economy	15000.00
0005432604282	21355	Economy	15000.00
0005432604478	21355	Economy	15000.00
0005432604210	21355	Economy	15000.00
0005432604186	21355	Economy	15000.00
0005432604267	21355	Economy	15000.00
0005432604371	21355	Economy	15000.00
0005432604311	21355	Economy	15000.00
0005432604244	21355	Economy	15000.00
0005432604367	21355	Economy	15000.00
0005432604382	21355	Economy	15000.00
0005432604452	21355	Economy	15000.00
0005432604438	21355	Economy	15000.00
0005432604392	21355	Economy	15000.00
0005432604237	21355	Economy	15000.00
0005432604422	21355	Economy	15000.00
0005432604372	21355	Economy	15000.00
0005432604383	21355	Economy	15000.00
0005432604320	21355	Economy	15000.00
0005432604180	21355	Economy	15000.00
0005432604342	21355	Economy	15000.00
0005432604344	21355	Economy	15000.00
0005432604417	21355	Economy	15000.00
0005432604441	21355	Economy	15000.00
0005432604418	21355	Economy	15000.00
0005432604509	21355	Economy	15000.00
0005434907426	15010	Business	18900.00
0005433251801	15010	Business	18900.00
0005433251799	15010	Business	18900.00
0005433251785	15010	Business	18900.00
0005434907253	15010	Business	18900.00
0005433251798	15010	Business	18900.00
0005434907428	15010	Business	18900.00
0005434907427	15010	Business	18900.00
0005434907368	15010	Business	18900.00
0005434907409	15010	Economy	6300.00
0005433251789	15010	Economy	6300.00
0005434907337	15010	Economy	6300.00
0005434907251	15010	Economy	6300.00
0005434907281	15010	Economy	6300.00
0005434907394	15010	Economy	6300.00
0005434907446	15010	Economy	6300.00
0005434907367	15010	Economy	6300.00
0005434907108	15010	Economy	6300.00
0005434907308	15010	Economy	6900.00
0005433251811	15010	Economy	6900.00
0005434907317	15010	Economy	6900.00
0005434907496	15010	Economy	6900.00
0005434907498	15010	Economy	6900.00
0005433251791	15010	Economy	6300.00
0005434907120	15010	Economy	6300.00
0005433251810	15010	Economy	6300.00
0005434907416	15010	Economy	6300.00
0005434907199	15010	Economy	6300.00
0005433251792	15010	Economy	6300.00
0005434907515	15010	Economy	6300.00
0005434907270	15010	Economy	6300.00
0005434907216	15010	Economy	6300.00
0005434907310	15010	Economy	6300.00
0005434907518	15010	Economy	6300.00
0005433251795	15010	Economy	6300.00
0005434907093	15010	Economy	6300.00
0005434907441	15010	Economy	6300.00
0005434907257	15010	Economy	6300.00
0005434907291	15010	Economy	6300.00
0005433251784	15010	Economy	6300.00
0005434907296	15010	Economy	6300.00
0005434907286	15010	Economy	6300.00
0005433251783	15010	Economy	6300.00
0005434907287	15010	Economy	6300.00
0005433251800	15010	Economy	6300.00
0005434907255	15010	Economy	6300.00
0005433251806	15010	Economy	6300.00
0005434907360	15010	Economy	6300.00
0005434907332	15010	Economy	6300.00
0005433251804	15010	Economy	6300.00
0005433251809	15010	Economy	6300.00
0005433251808	15010	Economy	6300.00
0005434907252	15010	Economy	6300.00
0005434907309	15010	Economy	6300.00
0005433251803	15010	Economy	6300.00
0005434907331	15010	Economy	6300.00
0005434907514	15010	Economy	6300.00
0005433251805	15010	Economy	6300.00
0005434907260	15010	Economy	6300.00
0005434907355	15010	Economy	6300.00
0005434907519	15010	Economy	6300.00
0005434907392	15010	Economy	6300.00
0005433251793	15010	Economy	6300.00
0005434907292	15010	Economy	6300.00
0005434907329	15010	Economy	6300.00
0005433251788	15010	Economy	6300.00
0005433251796	15010	Economy	6300.00
0005434907448	15010	Economy	6300.00
0005433251807	15010	Economy	6300.00
0005434907271	15010	Economy	6300.00
0005433251786	15010	Economy	6300.00
0005433251797	15010	Economy	6300.00
0005434907333	15010	Economy	6300.00
0005434907447	15010	Economy	6300.00
0005434907213	15010	Economy	6300.00
0005434907222	15010	Economy	6300.00
0005434907269	15010	Economy	6300.00
0005433251802	15010	Economy	6300.00
0005433251790	15010	Economy	6300.00
0005434907330	15010	Economy	6300.00
0005434907297	15010	Economy	6300.00
0005433251787	15010	Economy	6300.00
0005434907338	15010	Economy	6300.00
0005433251782	15010	Economy	6300.00
0005434907234	15010	Economy	6300.00
0005433251794	15010	Economy	6300.00
0005434907256	15010	Economy	6300.00
0005434907755	25845	Business	18900.00
0005434907765	25845	Business	18900.00
0005433251427	25845	Business	18900.00
0005434907753	25845	Business	18900.00
0005434907782	25845	Business	18900.00
0005433251627	25845	Business	18900.00
0005434907746	25845	Business	18900.00
0005434907783	25845	Business	18900.00
0005434907778	25845	Business	18900.00
0005433251404	25845	Business	18900.00
0005434907797	25845	Economy	6300.00
0005434907796	25845	Economy	6300.00
0005434907785	25845	Economy	6300.00
0005434907781	25845	Economy	6300.00
0005433251626	25845	Economy	6300.00
0005434907772	25845	Economy	6300.00
0005433251500	25845	Economy	6300.00
0005434907763	25845	Economy	6900.00
0005434907754	25845	Economy	6900.00
0005433251449	25845	Economy	6900.00
0005434907761	25845	Economy	6900.00
0005434907749	25845	Economy	6300.00
0005433251439	25845	Economy	6300.00
0005434907798	25845	Economy	6300.00
0005434907794	25845	Economy	6300.00
0005434907758	25845	Economy	6300.00
0005433251565	25845	Economy	6300.00
0005434907757	25845	Economy	6300.00
0005433251477	25845	Economy	6300.00
0005434907777	25845	Economy	6300.00
0005434907776	25845	Economy	6300.00
0005433251590	25845	Economy	6300.00
0005434907762	25845	Economy	6300.00
0005434907767	25845	Economy	6300.00
0005433251484	25845	Economy	6300.00
0005434907792	25845	Economy	6300.00
0005434907784	25845	Economy	6300.00
0005434907750	25845	Economy	6300.00
0005434907791	25845	Economy	6300.00
0005434907790	25845	Economy	6300.00
0005434907769	25845	Economy	6300.00
0005434907764	25845	Economy	6300.00
0005434907786	25845	Economy	6300.00
0005433251436	25845	Economy	6300.00
0005434907787	25845	Economy	6300.00
0005434907768	25845	Economy	6300.00
0005434907799	25845	Economy	6300.00
0005434907751	25845	Economy	6300.00
0005433251419	25845	Economy	6300.00
0005434907752	25845	Economy	6300.00
0005433251403	25845	Economy	6300.00
0005433251476	25845	Economy	6300.00
0005434907760	25845	Economy	6300.00
0005434907771	25845	Economy	6300.00
0005434907779	25845	Economy	6300.00
0005433251584	25845	Economy	6300.00
0005434907759	25845	Economy	6300.00
0005434907795	25845	Economy	6300.00
0005434907774	25845	Economy	6300.00
0005434907775	25845	Economy	6300.00
0005433251595	25845	Economy	6300.00
0005434907766	25845	Economy	6300.00
0005434907789	25845	Economy	6300.00
0005434907793	25845	Economy	6300.00
0005434907747	25845	Economy	6300.00
0005434907756	25845	Economy	6300.00
0005434907780	25845	Economy	6300.00
0005434907800	25845	Economy	6300.00
0005433251585	25845	Economy	6300.00
0005434907748	25845	Economy	6300.00
0005434907788	25845	Economy	6300.00
0005434907770	25845	Economy	6300.00
0005434907773	25845	Economy	6300.00
0005433009103	14170	Business	52300.00
0005433009118	14170	Business	52300.00
0005433009114	14170	Business	52300.00
0005433009081	14170	Business	52300.00
0005433009087	14170	Business	52300.00
0005433009090	14170	Business	52300.00
0005433009104	14170	Economy	17400.00
0005433009088	14170	Economy	17400.00
0005433009096	14170	Economy	17400.00
0005433009084	14170	Economy	17400.00
0005433009102	14170	Economy	17400.00
0005433810532	14170	Economy	17400.00
0005433009083	14170	Economy	19200.00
0005433009098	14170	Economy	19200.00
0005433009111	14170	Economy	17400.00
0005433009101	14170	Economy	17400.00
0005433009079	14170	Economy	17400.00
0005433009100	14170	Economy	17400.00
0005433009105	14170	Economy	17400.00
0005433009091	14170	Economy	17400.00
0005433009074	14170	Economy	17400.00
0005433009123	14170	Economy	17400.00
0005433009076	14170	Economy	17400.00
0005433009093	14170	Economy	17400.00
0005433009085	14170	Economy	17400.00
0005433009120	14170	Economy	17400.00
0005433009097	14170	Economy	17400.00
0005433009113	14170	Economy	17400.00
0005433009089	14170	Economy	17400.00
0005433009092	14170	Economy	17400.00
0005433009108	14170	Economy	17400.00
0005433009106	14170	Economy	17400.00
0005433009115	14170	Economy	17400.00
0005433009099	14170	Economy	17400.00
0005433009086	14170	Economy	17400.00
0005433009095	14170	Economy	17400.00
0005433009117	14170	Economy	17400.00
0005433009080	14170	Economy	17400.00
0005433009110	14170	Economy	17400.00
0005433009082	14170	Economy	17400.00
0005433009107	14170	Economy	17400.00
0005433009122	14170	Economy	17400.00
0005433009077	14170	Economy	17400.00
0005433009075	14170	Economy	17400.00
0005433009119	14170	Economy	17400.00
0005433009078	14170	Economy	17400.00
0005433009109	14170	Economy	17400.00
0005433009121	14170	Economy	17400.00
0005433009116	14170	Economy	17400.00
0005433009094	14170	Economy	17400.00
0005433009112	14170	Economy	17400.00
0005433810531	14170	Economy	17400.00
0005433008563	22860	Business	52300.00
0005433008585	22860	Business	52300.00
0005433008679	22860	Business	52300.00
0005433008577	22860	Business	52300.00
0005433008664	22860	Business	52300.00
0005433810581	22860	Business	52300.00
0005433008663	22860	Business	52300.00
0005433008625	22860	Business	52300.00
0005433008741	22860	Business	52300.00
0005433008794	22860	Economy	17400.00
0005433008681	22860	Economy	17400.00
0005433008822	22860	Economy	17400.00
0005433008584	22860	Economy	17400.00
0005433008678	22860	Economy	17400.00
0005433008810	22860	Economy	17400.00
0005433008782	22860	Economy	17400.00
0005433008624	22860	Economy	19200.00
0005433008603	22860	Economy	19200.00
0005433008753	22860	Economy	17400.00
0005433008686	22860	Economy	17400.00
0005433008599	22860	Economy	17400.00
0005433008740	22860	Economy	17400.00
0005433810582	22860	Economy	17400.00
0005433008614	22860	Economy	17400.00
0005433008542	22860	Economy	17400.00
0005433008751	22860	Economy	17400.00
0005433008601	22860	Economy	17400.00
0005433008600	22860	Economy	17400.00
0005433008564	22860	Economy	17400.00
0005433008811	22860	Economy	17400.00
0005433008705	22860	Economy	17400.00
0005433008562	22860	Economy	17400.00
0005433008633	22860	Economy	17400.00
0005433008619	22860	Economy	17400.00
0005433008647	22860	Economy	17400.00
0005433008688	22860	Economy	17400.00
0005433008543	22860	Economy	17400.00
0005433008604	22860	Economy	17400.00
0005433008662	22860	Economy	17400.00
0005433008592	22860	Economy	17400.00
0005433008665	22860	Economy	17400.00
0005433810580	22860	Economy	17400.00
0005433008687	22860	Economy	17400.00
0005433008644	22860	Economy	17400.00
0005433008618	22860	Economy	17400.00
0005433008700	22860	Economy	17400.00
0005433008606	22860	Economy	17400.00
0005433008586	22860	Economy	17400.00
0005433008590	22860	Economy	17400.00
0005433008752	22860	Economy	17400.00
0005433008561	22860	Economy	17400.00
0005433008591	22860	Economy	17400.00
0005433008719	22860	Economy	17400.00
0005433008783	22860	Economy	17400.00
0005433008839	22860	Economy	17400.00
0005433008680	22860	Economy	17400.00
0005433008648	22860	Economy	17400.00
0005433008669	22860	Economy	17400.00
0005433008798	22860	Economy	17400.00
0005434925780	14961	Economy	7600.00
0005434925777	14961	Economy	7600.00
0005434925817	14961	Economy	7600.00
0005434925811	14961	Economy	7600.00
0005434925853	14961	Economy	7600.00
0005434925718	14961	Economy	7600.00
0005434925779	14961	Economy	7600.00
0005434925820	14961	Economy	7600.00
0005434925806	14961	Economy	7600.00
0005434925832	14961	Economy	7600.00
0005434925807	14961	Economy	7600.00
0005434925786	14961	Economy	7600.00
0005434925855	14961	Economy	7600.00
0005434925778	14961	Economy	7600.00
0005434925839	14961	Economy	7600.00
0005434925852	14961	Economy	7600.00
0005434925816	14961	Economy	7600.00
0005434925818	14961	Economy	7600.00
0005434925785	14961	Economy	7600.00
0005434925781	14961	Economy	7600.00
0005434925797	14961	Economy	7600.00
0005434925856	14961	Economy	7600.00
0005434925717	14961	Economy	7600.00
0005434925808	14961	Economy	7600.00
0005434925819	14961	Economy	7600.00
0005434925851	14961	Economy	7600.00
0005434925836	14961	Economy	7600.00
0005434925849	14961	Economy	7600.00
0005434925758	14961	Economy	7600.00
0005434925837	14961	Economy	7600.00
0005434926122	20504	Business	22900.00
0005434926114	20504	Business	22900.00
0005434926131	20504	Business	22900.00
0005434926120	20504	Business	22900.00
0005434926098	20504	Business	22900.00
0005434926119	20504	Business	22900.00
0005434926113	20504	Economy	7600.00
0005434926123	20504	Economy	7600.00
0005434926109	20504	Economy	7600.00
0005434926105	20504	Economy	7600.00
0005434926132	20504	Economy	8400.00
0005434926126	20504	Economy	8400.00
0005434926111	20504	Economy	8400.00
0005434926116	20504	Economy	8400.00
0005434926106	20504	Economy	7600.00
0005434926128	20504	Economy	7600.00
0005434926118	20504	Economy	7600.00
0005434926135	20504	Economy	7600.00
0005434926108	20504	Economy	7600.00
0005434926127	20504	Economy	7600.00
0005434926101	20504	Economy	7600.00
0005434926103	20504	Economy	7600.00
0005434926134	20504	Economy	7600.00
0005434926100	20504	Economy	7600.00
0005434926129	20504	Economy	7600.00
0005434926124	20504	Economy	7600.00
0005434926133	20504	Economy	7600.00
0005434926099	20504	Economy	7600.00
0005434926125	20504	Economy	7600.00
0005434926130	20504	Economy	7600.00
0005434926121	20504	Economy	7600.00
0005434926104	20504	Economy	7600.00
0005434926112	20504	Economy	7600.00
0005434926115	20504	Economy	7600.00
0005434926107	20504	Economy	7600.00
0005434926102	20504	Economy	7600.00
0005434926110	20504	Economy	7600.00
0005434926117	20504	Economy	7600.00
0005435488062	15795	Economy	8900.00
0005435488058	15795	Economy	8900.00
0005435999273	15795	Economy	8100.00
0005435999282	15795	Economy	8100.00
0005435999283	15795	Economy	8100.00
0005435999255	15795	Economy	8100.00
0005435488052	15795	Economy	8100.00
0005435999266	15795	Economy	8100.00
0005435488061	15795	Economy	8100.00
0005435488069	15795	Economy	8100.00
0005435488057	15795	Economy	8100.00
0005435999285	15795	Economy	8100.00
0005435999267	15795	Economy	8100.00
0005435488064	15795	Economy	8100.00
0005435488063	15795	Economy	8100.00
0005435999274	15795	Economy	8100.00
0005435999275	15795	Economy	8100.00
0005435999231	15795	Economy	8100.00
0005435999254	15795	Economy	8100.00
0005435999212	15795	Economy	8100.00
0005435488056	15795	Economy	8100.00
0005435488054	15795	Economy	8100.00
0005435488053	15795	Economy	8100.00
0005435488065	15795	Economy	8100.00
0005435999264	15795	Economy	8100.00
0005435999286	15795	Economy	8100.00
0005435488073	15795	Economy	8100.00
0005435999186	15795	Economy	8100.00
0005435488059	15795	Economy	8100.00
0005435488068	15795	Economy	8100.00
0005435488071	15795	Economy	8100.00
0005435488067	15795	Economy	8100.00
0005435999298	15795	Economy	8100.00
0005435488072	15795	Economy	8100.00
0005435999287	15795	Economy	8100.00
0005435488055	15795	Economy	8100.00
0005435488070	15795	Economy	8100.00
0005435999262	15795	Economy	8100.00
0005435999249	15795	Economy	8100.00
0005435999211	15795	Economy	8100.00
0005435999263	15795	Economy	8100.00
0005435488066	15795	Economy	8100.00
0005435999297	15795	Economy	8100.00
0005435488060	15795	Economy	8100.00
0005435999407	19702	Economy	8900.00
0005435999408	19702	Economy	8900.00
0005435487816	19702	Economy	8900.00
0005435487822	19702	Economy	8100.00
0005435999416	19702	Economy	8100.00
0005435999411	19702	Economy	8100.00
0005435999422	19702	Economy	8100.00
0005435487880	19702	Economy	8100.00
0005435999406	19702	Economy	8100.00
0005435487867	19702	Economy	8100.00
0005435487872	19702	Economy	8100.00
0005435487853	19702	Economy	8100.00
0005435999423	19702	Economy	8100.00
0005435487769	19702	Economy	8100.00
0005435999413	19702	Economy	8100.00
0005435999420	19702	Economy	8100.00
0005435487883	19702	Economy	8100.00
0005435999410	19702	Economy	8100.00
0005435487854	19702	Economy	8100.00
0005435487817	19702	Economy	8100.00
0005435999412	19702	Economy	8100.00
0005435999419	19702	Economy	8100.00
0005435487836	19702	Economy	8100.00
0005435487882	19702	Economy	8100.00
0005435487877	19702	Economy	8100.00
0005435487914	19702	Economy	8100.00
0005435999421	19702	Economy	8100.00
0005435999409	19702	Economy	8100.00
0005435487895	19702	Economy	8100.00
0005435487835	19702	Economy	8100.00
0005435999405	19702	Economy	8100.00
0005435999415	19702	Economy	8100.00
0005435999417	19702	Economy	8100.00
0005435999418	19702	Economy	8100.00
0005435487881	19702	Economy	8100.00
0005435487894	19702	Economy	8100.00
0005435999414	19702	Economy	8100.00
0005435839744	5999	Business	199300.00
0005432537067	5999	Business	199300.00
0005435839749	5999	Business	199300.00
0005435472829	5999	Business	199300.00
0005435839763	5999	Business	199300.00
0005435839753	5999	Business	199300.00
0005435839756	5999	Business	199300.00
0005435839736	5999	Business	199300.00
0005432659728	5999	Economy	66400.00
0005432537066	5999	Economy	66400.00
0005435472883	5999	Economy	66400.00
0005432660841	5999	Economy	66400.00
0005432660840	5999	Economy	66400.00
0005435839751	5999	Economy	66400.00
0005435839743	5999	Economy	73100.00
0005435839764	5999	Economy	73100.00
0005432658615	5999	Economy	73100.00
0005435472861	5999	Economy	66400.00
0005432658614	5999	Economy	66400.00
0005432537060	5999	Economy	66400.00
0005435839761	5999	Economy	66400.00
0005435839745	5999	Economy	66400.00
0005435472862	5999	Economy	66400.00
0005435839750	5999	Economy	66400.00
0005432142285	5999	Economy	66400.00
0005435839760	5999	Economy	66400.00
0005435472863	5999	Economy	66400.00
0005435839758	5999	Economy	66400.00
0005435472815	5999	Economy	66400.00
0005435839752	5999	Economy	66400.00
0005435839757	5999	Economy	66400.00
0005432142283	5999	Economy	66400.00
0005435839738	5999	Economy	66400.00
0005435472858	5999	Economy	66400.00
0005435472855	5999	Economy	66400.00
0005435839755	5999	Economy	66400.00
0005435839735	5999	Economy	66400.00
0005432142284	5999	Economy	66400.00
0005435839759	5999	Economy	66400.00
0005435839754	5999	Economy	66400.00
0005435472913	5999	Economy	66400.00
0005435472884	5999	Economy	66400.00
0005435839747	5999	Economy	66400.00
0005435839737	5999	Economy	66400.00
0005432659730	5999	Economy	66400.00
0005432537059	5999	Economy	66400.00
0005435839762	5999	Economy	66400.00
0005435839739	5999	Economy	66400.00
0005435839740	5999	Economy	66400.00
0005435839742	5999	Economy	66400.00
0005432537062	5999	Economy	66400.00
0005435839748	5999	Economy	66400.00
0005435839746	5999	Economy	66400.00
0005432659729	5999	Economy	66400.00
0005435472819	5999	Economy	66400.00
0005435617235	5999	Economy	66400.00
0005435839741	5999	Economy	66400.00
0005435472970	18043	Business	199300.00
0005435472969	18043	Business	199300.00
0005435472982	18043	Business	199300.00
0005432660821	18043	Business	199300.00
0005435839520	18043	Business	199300.00
0005435472984	18043	Business	199300.00
0005435839550	18043	Business	199300.00
0005435472981	18043	Business	199300.00
0005432664138	18043	Business	199300.00
0005435839548	18043	Business	199300.00
0005432664133	18043	Business	199300.00
0005435839401	18043	Economy	66400.00
0005435839488	18043	Economy	66400.00
0005432537082	18043	Economy	66400.00
0005435839402	18043	Economy	66400.00
0005435839547	18043	Economy	73100.00
0005435472971	18043	Economy	66400.00
0005435839549	18043	Economy	66400.00
0005435839539	18043	Economy	66400.00
0005435472979	18043	Economy	66400.00
0005435472983	18043	Economy	66400.00
0005435839573	18043	Economy	66400.00
0005435839489	18043	Economy	66400.00
0005432660822	18043	Economy	66400.00
0005435472980	18043	Economy	66400.00
0005432664134	18043	Economy	66400.00
0005435472975	18043	Economy	66400.00
0005435839529	18043	Economy	66400.00
0005435839516	18043	Economy	66400.00
0005435472973	18043	Economy	66400.00
0005435839391	18043	Economy	66400.00
0005435472972	18043	Economy	66400.00
0005435839490	18043	Economy	66400.00
0005435472977	18043	Economy	66400.00
0005435839326	18043	Economy	66400.00
0005432537081	18043	Economy	66400.00
0005435839483	18043	Economy	66400.00
0005435839413	18043	Economy	66400.00
0005435839449	18043	Economy	66400.00
0005435839400	18043	Economy	66400.00
0005435472978	18043	Economy	66400.00
0005435839588	18043	Economy	66400.00
0005435839554	18043	Economy	66400.00
0005435472974	18043	Economy	66400.00
0005435839507	18043	Economy	66400.00
0005435839493	18043	Economy	66400.00
0005435839589	18043	Economy	66400.00
0005435472976	18043	Economy	66400.00
0005435839559	18043	Economy	66400.00
0005432660811	18043	Economy	66400.00
0005432664132	18043	Economy	66400.00
0005435839487	18043	Economy	66400.00
0005435839528	18043	Economy	66400.00
0005435472968	18043	Economy	66400.00
0005435839506	18043	Economy	66400.00
0005435839600	18043	Economy	66400.00
0005433285419	23050	Business	15700.00
0005433285420	23050	Business	15700.00
0005433285284	23050	Business	15700.00
0005435104001	23050	Economy	5200.00
0005435104003	23050	Economy	5200.00
0005433285358	23050	Economy	5200.00
0005433285285	23050	Economy	5200.00
0005433285329	23050	Economy	5200.00
0005433285357	23050	Economy	5200.00
0005433285227	23050	Economy	5200.00
0005433285384	23050	Economy	5200.00
0005433285296	23050	Economy	5200.00
0005435103994	23050	Economy	5200.00
0005433285340	23050	Economy	5200.00
0005435104009	23050	Economy	5200.00
0005435104002	23050	Economy	5700.00
0005435104007	23050	Economy	5200.00
0005433285350	23050	Economy	5200.00
0005433285377	23050	Economy	5200.00
0005433285379	23050	Economy	5200.00
0005435104000	23050	Economy	5200.00
0005433285362	23050	Economy	5200.00
0005435103996	23050	Economy	5200.00
0005433285432	23050	Economy	5200.00
0005433285339	23050	Economy	5200.00
0005433285330	23050	Economy	5200.00
0005433285369	23050	Economy	5200.00
0005433285378	23050	Economy	5200.00
0005435103998	23050	Economy	5200.00
0005435103997	23050	Economy	5200.00
0005433285430	23050	Economy	5200.00
0005433285408	23050	Economy	5200.00
0005433285283	23050	Economy	5200.00
0005435103999	23050	Economy	5200.00
0005433285361	23050	Economy	5200.00
0005435104008	23050	Economy	5200.00
0005435103995	23050	Economy	5200.00
0005435104004	23050	Economy	5200.00
0005435104005	23050	Economy	5200.00
0005433285415	23050	Economy	5200.00
0005433285295	23050	Economy	5200.00
0005435104006	23050	Economy	5200.00
0005433285314	23050	Economy	5200.00
0005433285627	32064	Business	15700.00
0005433285632	32064	Business	15700.00
0005433285630	32064	Economy	5200.00
0005433285620	32064	Economy	5200.00
0005433285634	32064	Economy	5200.00
0005433285628	32064	Economy	5200.00
0005433285626	32064	Economy	5200.00
0005433285631	32064	Economy	5200.00
0005433285645	32064	Economy	5200.00
0005433285642	32064	Economy	5200.00
0005433285621	32064	Economy	5200.00
0005433285615	32064	Economy	5200.00
0005433285643	32064	Economy	5200.00
0005433285624	32064	Economy	5700.00
0005433285636	32064	Economy	5700.00
0005435103916	32064	Economy	5700.00
0005433285617	32064	Economy	5200.00
0005433285623	32064	Economy	5200.00
0005435103926	32064	Economy	5200.00
0005433285638	32064	Economy	5200.00
0005433285622	32064	Economy	5200.00
0005433285629	32064	Economy	5200.00
0005433285618	32064	Economy	5200.00
0005435103920	32064	Economy	5200.00
0005435103910	32064	Economy	5200.00
0005433285641	32064	Economy	5200.00
0005433285633	32064	Economy	5200.00
0005433285625	32064	Economy	5200.00
0005435103935	32064	Economy	5200.00
0005433285616	32064	Economy	5200.00
0005433285644	32064	Economy	5200.00
0005435103934	32064	Economy	5200.00
0005433285640	32064	Economy	5200.00
0005433285637	32064	Economy	5200.00
0005433285619	32064	Economy	5200.00
0005435103927	32064	Economy	5200.00
0005433285635	32064	Economy	5200.00
0005433285614	32064	Economy	5200.00
0005433285639	32064	Economy	5200.00
0005435103917	32064	Economy	5200.00
0005432528190	30604	Business	42100.00
0005432527849	30604	Business	42100.00
0005434067739	30604	Business	42100.00
0005432528263	30604	Business	42100.00
0005434067464	30604	Business	42100.00
0005435214303	30604	Business	42100.00
0005435214284	30604	Business	42100.00
0005432211584	30604	Business	42100.00
0005432528451	30604	Business	42100.00
0005434067877	30604	Business	42100.00
0005435214338	30604	Business	42100.00
0005434067806	30604	Business	42100.00
0005435214297	30604	Business	42100.00
0005434067775	30604	Business	42100.00
0005432528565	30604	Business	42100.00
0005435214288	30604	Business	42100.00
0005435214321	30604	Business	42100.00
0005435214277	30604	Business	42100.00
0005435214308	30604	Business	42100.00
0005432535831	30604	Business	42100.00
0005435214273	30604	Business	42100.00
0005432528115	30604	Business	42100.00
0005435214309	30604	Business	42100.00
0005432528110	30604	Business	42100.00
0005434067726	30604	Comfort	23900.00
0005432211582	30604	Business	42100.00
0005432527682	30604	Comfort	23900.00
0005435214301	30604	Comfort	23900.00
0005434067795	30604	Comfort	23900.00
0005432528524	30604	Comfort	23900.00
0005432528739	30604	Comfort	23900.00
0005435214328	30604	Comfort	23900.00
0005432211588	30604	Comfort	23900.00
0005434067638	30604	Comfort	23900.00
0005432527917	30604	Comfort	23900.00
0005432528496	30604	Comfort	23900.00
0005432527948	30604	Comfort	23900.00
0005432528273	30604	Comfort	23900.00
0005435214287	30604	Comfort	23900.00
0005434067820	30604	Comfort	23900.00
0005432528971	30604	Comfort	23900.00
0005432528724	30604	Comfort	23900.00
0005435214333	30604	Comfort	23900.00
0005435214279	30604	Comfort	23900.00
0005432528343	30604	Comfort	23900.00
0005434067535	30604	Comfort	23900.00
0005432159907	30604	Comfort	23900.00
0005435214275	30604	Comfort	23900.00
0005435214316	30604	Comfort	23900.00
0005432528220	30604	Comfort	23900.00
0005434067293	30604	Comfort	23900.00
0005432527889	30604	Comfort	23900.00
0005432528768	30604	Comfort	23900.00
0005432528283	30604	Comfort	23900.00
0005432528189	30604	Comfort	23900.00
0005432528432	30604	Comfort	23900.00
0005432528585	30604	Comfort	23900.00
0005432528682	30604	Comfort	23900.00
0005435214339	30604	Comfort	23900.00
0005435214298	30604	Comfort	23900.00
0005432528651	30604	Comfort	23900.00
0005435214329	30604	Comfort	23900.00
0005435214290	30604	Comfort	23900.00
0005435725657	30604	Comfort	23900.00
0005432528487	30604	Comfort	23900.00
0005432159909	30604	Economy	14000.00
0005433656708	30604	Economy	14000.00
0005432528749	30604	Economy	14000.00
0005432528428	30604	Economy	14000.00
0005432528119	30604	Economy	14000.00
0005435214335	30604	Economy	14000.00
0005434067700	30604	Economy	14000.00
0005435214292	30604	Economy	14000.00
0005434067609	30604	Economy	14000.00
0005432528415	30604	Economy	14000.00
0005434067805	30604	Economy	14000.00
0005432528427	30604	Economy	14000.00
0005432528117	30604	Economy	14000.00
0005434067565	30604	Economy	14000.00
0005435214332	30604	Economy	14000.00
0005432528680	30604	Economy	14000.00
0005434067483	30604	Economy	14000.00
0005432211586	30604	Economy	14000.00
0005434067634	30604	Economy	14000.00
0005435214319	30604	Economy	14000.00
0005432528333	30604	Economy	14000.00
0005432527848	30604	Economy	14000.00
0005432528452	30604	Economy	14000.00
0005435214280	30604	Economy	14000.00
0005432527914	30604	Economy	14000.00
0005435214315	30604	Economy	14000.00
0005432528294	30604	Economy	14000.00
0005435214293	30604	Economy	14000.00
0005434067842	30604	Economy	14000.00
0005434067635	30604	Economy	14000.00
0005434067907	30604	Economy	14000.00
0005434067528	30604	Economy	14000.00
0005435214330	30604	Economy	14000.00
0005434067552	30604	Economy	14000.00
0005434067684	30604	Economy	14000.00
0005432537054	30604	Economy	14000.00
0005432527806	30604	Economy	14000.00
0005432528009	30604	Economy	14000.00
0005435214320	30604	Economy	14000.00
0005432528071	30604	Economy	14000.00
0005432528288	30604	Economy	14000.00
0005432528302	30604	Economy	14000.00
0005432528346	30604	Economy	14000.00
0005435725659	30604	Economy	14000.00
0005432528326	30604	Economy	14000.00
0005432527689	30604	Economy	14000.00
0005432528081	30604	Economy	14000.00
0005432528315	30604	Economy	14000.00
0005435214327	30604	Economy	14000.00
0005432528570	30604	Economy	14000.00
0005432528078	30604	Economy	15400.00
0005434067812	30604	Economy	14000.00
0005435214283	30604	Economy	15400.00
0005432528425	30604	Economy	14000.00
0005435214302	30604	Economy	14000.00
0005432528131	30604	Economy	15400.00
0005432533302	30604	Economy	14000.00
0005432528876	30604	Economy	15400.00
0005434067414	30604	Economy	15400.00
0005432528582	30604	Economy	14000.00
0005432528523	30604	Economy	14000.00
0005434067564	30604	Economy	14000.00
0005432528018	30604	Economy	14000.00
0005434067396	30604	Economy	14000.00
0005432527737	30604	Economy	14000.00
0005432428942	30604	Economy	14000.00
0005434067776	30604	Economy	14000.00
0005435214299	30604	Economy	14000.00
0005434068029	30604	Economy	14000.00
0005432527947	30604	Economy	14000.00
0005432528410	30604	Economy	14000.00
0005434067604	30604	Economy	14000.00
0005432528404	30604	Economy	14000.00
0005435214285	30604	Economy	14000.00
0005432527949	30604	Economy	14000.00
0005432528665	30604	Economy	14000.00
0005432528754	30604	Economy	14000.00
0005435214304	30604	Economy	14000.00
0005432528238	30604	Economy	14000.00
0005432528345	30604	Economy	14000.00
0005432528364	30604	Economy	14000.00
0005435214272	30604	Economy	14000.00
0005434067779	30604	Economy	14000.00
0005434067697	30604	Economy	14000.00
0005434067888	30604	Economy	14000.00
0005432528224	30604	Economy	14000.00
0005432528564	30604	Economy	14000.00
0005434067539	30604	Economy	14000.00
0005434067770	30604	Economy	14000.00
0005432528391	30604	Economy	14000.00
0005432528497	30604	Economy	14000.00
0005433656707	30604	Economy	14000.00
0005432528660	30604	Economy	14000.00
0005435214296	30604	Economy	14000.00
0005434067271	30604	Economy	14000.00
0005434067610	30604	Economy	14000.00
0005432528424	30604	Economy	14000.00
0005432528272	30604	Economy	14000.00
0005432528214	30604	Economy	14000.00
0005435214305	30604	Economy	14000.00
0005432528176	30604	Economy	14000.00
0005435214324	30604	Economy	14000.00
0005435214312	30604	Economy	14000.00
0005435214318	30604	Economy	14000.00
0005432528116	30604	Economy	14000.00
0005434067698	30604	Economy	14000.00
0005435214282	30604	Economy	14000.00
0005435214295	30604	Economy	14000.00
0005435214291	30604	Economy	14000.00
0005433656709	30604	Economy	14000.00
0005435725655	30604	Economy	14000.00
0005435214276	30604	Economy	14000.00
0005432528537	30604	Economy	14000.00
0005435214337	30604	Economy	14000.00
0005432528426	30604	Economy	14000.00
0005432533299	30604	Economy	14000.00
0005432528251	30604	Economy	14000.00
0005435214281	30604	Economy	14000.00
0005432528681	30604	Economy	14000.00
0005432528643	30604	Economy	14000.00
0005434067456	30604	Economy	14000.00
0005432528970	30604	Economy	14000.00
0005432527869	30604	Economy	14000.00
0005434067769	30604	Economy	14000.00
0005435214311	30604	Economy	14000.00
0005432528875	30604	Economy	14000.00
0005435214322	30604	Economy	14000.00
0005435725658	30604	Economy	14000.00
0005432428954	30604	Economy	14000.00
0005434067746	30604	Economy	14000.00
0005432528453	30604	Economy	14000.00
0005433656711	30604	Economy	14000.00
0005434067876	30604	Economy	14000.00
0005432528723	30604	Economy	14000.00
0005432528342	30604	Economy	14000.00
0005432528188	30604	Economy	14000.00
0005434067942	30604	Economy	14000.00
0005432528563	30604	Economy	14000.00
0005432535849	30604	Economy	14000.00
0005432528571	30604	Economy	14000.00
0005432528383	30604	Economy	14000.00
0005432211587	30604	Economy	14000.00
0005432528118	30604	Economy	14000.00
0005432528077	30604	Economy	14000.00
0005432159910	30604	Economy	14000.00
0005432527851	30604	Economy	14000.00
0005434067532	30604	Economy	14000.00
0005432528846	30604	Economy	14000.00
0005434067701	30604	Economy	14000.00
0005432159908	30604	Economy	14000.00
0005434067526	30604	Economy	14000.00
0005432535848	30604	Economy	14000.00
0005434067819	30604	Economy	14000.00
0005434067850	30604	Economy	14000.00
0005434067575	30604	Economy	15400.00
0005432528196	30604	Economy	15400.00
0005434067737	30604	Economy	15400.00
0005432528282	30604	Economy	14000.00
0005432528787	30604	Economy	15400.00
0005435214317	30604	Economy	15400.00
0005432528732	30604	Economy	14000.00
0005432527916	30604	Economy	14000.00
0005432211585	30604	Economy	14000.00
0005435214271	30604	Economy	14000.00
0005435631002	30604	Economy	14000.00
0005434067774	30604	Economy	14000.00
0005432211581	30604	Economy	14000.00
0005434067921	30604	Economy	14000.00
0005432528816	30604	Economy	14000.00
0005432528241	30604	Economy	14000.00
0005432528486	30604	Economy	14000.00
0005432211583	30604	Economy	14000.00
0005432528516	30604	Economy	14000.00
0005435214325	30604	Economy	14000.00
0005435214274	30604	Economy	14000.00
0005434067626	30604	Economy	14000.00
0005434067637	30604	Economy	14000.00
0005432533301	30604	Economy	14000.00
0005432528339	30604	Economy	14000.00
0005432528198	30604	Economy	14000.00
0005432528574	30604	Economy	14000.00
0005434067724	30604	Economy	14000.00
0005435214300	30604	Economy	14000.00
0005432528319	30604	Economy	14000.00
0005432528398	30604	Economy	14000.00
0005432428939	30604	Economy	14000.00
0005432533300	30604	Economy	14000.00
0005435214326	30604	Economy	14000.00
0005435214334	30604	Economy	14000.00
0005435214314	30604	Economy	14000.00
0005432528378	30604	Economy	14000.00
0005434067829	30604	Economy	14000.00
0005434067745	30604	Economy	14000.00
0005434067530	30604	Economy	14000.00
0005435631001	30604	Economy	14000.00
0005435725656	30604	Economy	14000.00
0005432528076	30604	Economy	14000.00
0005434067533	30604	Economy	14000.00
0005432528114	30604	Economy	14000.00
0005435214278	30604	Economy	14000.00
0005432528340	30604	Economy	14000.00
0005434067885	30604	Economy	14000.00
0005432528815	30604	Economy	14000.00
0005432528484	30604	Economy	14000.00
0005432533312	30604	Economy	14000.00
0005434067611	30604	Economy	14000.00
0005432528168	30604	Economy	14000.00
0005434067546	30604	Economy	14000.00
0005432528649	30604	Economy	14000.00
0005435631003	30604	Economy	14000.00
0005432528091	30604	Economy	14000.00
0005434067725	30604	Economy	14000.00
0005432528671	30604	Economy	14000.00
0005432527638	30604	Economy	14000.00
0005435214331	30604	Economy	14000.00
0005432527931	30604	Economy	14000.00
0005435214336	30604	Economy	14000.00
0005432528450	30604	Economy	14000.00
0005434067840	30604	Economy	14000.00
0005435214323	30604	Economy	14000.00
0005435214307	30604	Economy	14000.00
0005432527575	30604	Economy	14000.00
0005432428925	30604	Economy	14000.00
0005432159911	30604	Economy	14000.00
0005432528590	30604	Economy	14000.00
0005434067554	30604	Economy	14000.00
0005435631000	30604	Economy	14000.00
0005432528314	30604	Economy	14000.00
0005434067551	30604	Economy	14000.00
0005432528262	30604	Economy	14000.00
0005432528589	30604	Economy	14000.00
0005433656710	30604	Economy	14000.00
0005432528301	30604	Economy	14000.00
0005434067527	30604	Economy	14000.00
0005432535862	30604	Economy	14000.00
0005435214289	30604	Economy	14000.00
0005435214313	30604	Economy	14000.00
0005434067906	30604	Economy	14000.00
0005432527639	30604	Economy	14000.00
0005432528569	30604	Economy	14000.00
0005435214270	30604	Economy	14000.00
0005435214310	30604	Economy	14000.00
0005432528109	30604	Economy	14000.00
0005432528431	30604	Economy	14000.00
0005434067872	30604	Economy	14000.00
0005435214294	30604	Economy	14000.00
0005435214286	30604	Economy	14000.00
0005435214306	30604	Economy	14000.00
0005432527648	30604	Economy	14000.00
0005432527888	30604	Economy	14000.00
0005434067605	30604	Economy	14000.00
0005434067270	30604	Economy	14000.00
0005435653144	24852	Business	9800.00
0005433368322	24852	Business	9800.00
0005433368313	24852	Business	9800.00
0005435653035	24852	Business	9800.00
0005435653121	24852	Business	9800.00
0005435653198	24852	Business	9800.00
0005433368320	24852	Business	9800.00
0005433368319	24852	Business	9800.00
0005435653197	24852	Business	9800.00
0005433368298	24852	Business	9800.00
0005435652995	24852	Business	9800.00
0005435653108	24852	Business	9800.00
0005435653184	24852	Economy	3300.00
0005435653120	24852	Economy	3300.00
0005435653154	24852	Economy	3300.00
0005435653190	24852	Economy	3300.00
0005435652959	24852	Economy	3300.00
0005433368324	24852	Economy	3600.00
0005433368317	24852	Economy	3600.00
0005435652989	24852	Economy	3600.00
0005433368331	24852	Economy	3600.00
0005435652952	24852	Economy	3600.00
0005433368327	24852	Economy	3300.00
0005435652953	24852	Economy	3300.00
0005435653024	24852	Economy	3300.00
0005433368314	24852	Economy	3300.00
0005435653122	24852	Economy	3300.00
0005433368316	24852	Economy	3300.00
0005435653159	24852	Economy	3300.00
0005435653015	24852	Economy	3300.00
0005433368309	24852	Economy	3300.00
0005433368311	24852	Economy	3300.00
0005433368307	24852	Economy	3300.00
0005435653193	24852	Economy	3300.00
0005433368325	24852	Economy	3300.00
0005433368315	24852	Economy	3300.00
0005435653135	24852	Economy	3300.00
0005435652984	24852	Economy	3300.00
0005435653034	24852	Economy	3300.00
0005433368312	24852	Economy	3300.00
0005435653133	24852	Economy	3300.00
0005435653132	24852	Economy	3300.00
0005435653051	24852	Economy	3300.00
0005433368323	24852	Economy	3300.00
0005433368321	24852	Economy	3300.00
0005433368310	24852	Economy	3300.00
0005435653074	24852	Economy	3300.00
0005435653195	24852	Economy	3300.00
0005433368318	24852	Economy	3300.00
0005435653182	24852	Economy	3300.00
0005433368303	24852	Economy	3300.00
0005433368297	24852	Economy	3300.00
0005433368308	24852	Economy	3300.00
0005433368295	24852	Economy	3300.00
0005433368330	24852	Economy	3300.00
0005433368296	24852	Economy	3300.00
0005435653192	24852	Economy	3300.00
0005435653126	24852	Economy	3300.00
0005433368301	24852	Economy	3300.00
0005435653125	24852	Economy	3300.00
0005433368299	24852	Economy	3300.00
0005435653161	24852	Economy	3300.00
0005433368326	24852	Economy	3300.00
0005433368294	24852	Economy	3300.00
0005433368329	24852	Economy	3300.00
0005433368302	24852	Economy	3300.00
0005433368304	24852	Economy	3300.00
0005435653079	24852	Economy	3300.00
0005435653065	24852	Economy	3300.00
0005435653016	24852	Economy	3300.00
0005435652988	24852	Economy	3300.00
0005433368300	24852	Economy	3300.00
0005435652923	24852	Economy	3300.00
0005435652931	24852	Economy	3300.00
0005435653186	24852	Economy	3300.00
0005433368328	24852	Economy	3300.00
0005433368306	24852	Economy	3300.00
0005435653160	24852	Economy	3300.00
0005435653042	24852	Economy	3300.00
0005435653128	24852	Economy	3300.00
0005435653127	24852	Economy	3300.00
0005435653185	24852	Economy	3300.00
0005433368305	24852	Economy	3300.00
0005435653191	24852	Economy	3300.00
0005435949778	23313	Economy	20600.00
0005435949773	23313	Economy	20600.00
0005435949768	23313	Economy	18700.00
0005435949767	23313	Economy	18700.00
0005435949772	23313	Economy	18700.00
0005435949788	23313	Economy	18700.00
0005435949774	23313	Economy	18700.00
0005435949791	23313	Economy	18700.00
0005435949787	23313	Economy	18700.00
0005435949779	23313	Economy	18700.00
0005435949781	23313	Economy	18700.00
0005435949780	23313	Economy	18700.00
0005434980142	2045	Economy	10500.00
0005434980139	2045	Economy	10500.00
0005435801730	2045	Economy	9500.00
0005434980134	2045	Economy	9500.00
0005434980123	2045	Economy	9500.00
0005434980118	2045	Economy	9500.00
0005434980115	2045	Economy	9500.00
0005435801731	2045	Economy	9500.00
0005434980133	2045	Economy	9500.00
0005434980141	2045	Economy	9500.00
0005434980143	2045	Economy	9500.00
0005434980128	2045	Economy	9500.00
0005434980129	2045	Economy	9500.00
0005434980136	2045	Economy	9500.00
0005434980132	2045	Economy	9500.00
0005435801729	2045	Economy	9500.00
0005434980131	2045	Economy	9500.00
0005434980130	2045	Economy	9500.00
0005434980116	2045	Economy	9500.00
0005434980125	2045	Economy	9500.00
0005434980135	2045	Economy	9500.00
0005434980126	2045	Economy	9500.00
0005434980140	2045	Economy	9500.00
0005434980120	2045	Economy	9500.00
0005434980138	2045	Economy	9500.00
0005434980114	2045	Economy	9500.00
0005434980124	2045	Economy	9500.00
0005434980117	2045	Economy	9500.00
0005434980119	2045	Economy	9500.00
0005434980137	2045	Economy	9500.00
0005434980127	2045	Economy	9500.00
0005434980122	2045	Economy	9500.00
0005434980121	2045	Economy	9500.00
0005434979757	23541	Economy	10500.00
0005434979775	23541	Economy	10500.00
0005434979937	23541	Economy	9500.00
0005434979783	23541	Economy	9500.00
0005434979923	23541	Economy	9500.00
0005434979699	23541	Economy	9500.00
0005434979862	23541	Economy	9500.00
0005434979804	23541	Economy	9500.00
0005434979700	23541	Economy	9500.00
0005434979917	23541	Economy	9500.00
0005434979938	23541	Economy	9500.00
0005434979833	23541	Economy	9500.00
0005434979889	23541	Economy	9500.00
0005435801702	23541	Economy	9500.00
0005435801701	23541	Economy	9500.00
0005434979936	23541	Economy	9500.00
0005434979922	23541	Economy	9500.00
0005434979911	23541	Economy	9500.00
0005435801692	23541	Economy	9500.00
0005434979749	23541	Economy	9500.00
0005434979759	23541	Economy	9500.00
0005434979760	23541	Economy	9500.00
0005434979895	23541	Economy	9500.00
0005434979956	23541	Economy	9500.00
0005434979945	23541	Economy	9500.00
0005434979756	23541	Economy	9500.00
0005434979893	23541	Economy	9500.00
0005434979832	23541	Economy	9500.00
0005434979845	23541	Economy	9500.00
0005434979788	23541	Economy	9500.00
0005434979894	23541	Economy	9500.00
0005434979863	23541	Economy	9500.00
0005434979844	23541	Economy	9500.00
0005434952574	2633	Economy	5300.00
0005434952573	2633	Economy	5300.00
0005433256425	2630	Economy	5300.00
0005433256428	2630	Economy	5300.00
0005433256429	2630	Economy	5300.00
0005433256449	28186	Economy	5300.00
0005433256448	28186	Economy	5300.00
0005434952530	28186	Economy	5300.00
0005434952551	28186	Economy	5300.00
0005433112391	19836	Economy	8700.00
0005433112390	19836	Economy	8700.00
0005433111531	19836	Economy	8700.00
0005433111532	19836	Economy	8700.00
0005434302863	19836	Economy	8700.00
0005433111530	19836	Economy	8700.00
0005434302864	19836	Economy	8700.00
0005434138287	11925	Business	9700.00
0005434138299	11925	Business	9700.00
0005434138298	11925	Business	9700.00
0005434138347	11925	Business	9700.00
0005434138487	11925	Business	9700.00
0005434138105	11925	Business	9700.00
0005434138030	11925	Business	9700.00
0005434138049	11925	Business	9700.00
0005434138340	11925	Business	9700.00
0005434138224	11925	Business	9700.00
0005434138219	11925	Business	9700.00
0005434138275	11925	Economy	3200.00
0005434138456	11925	Economy	3200.00
0005434137758	11925	Economy	3200.00
0005434138204	11925	Economy	3200.00
0005434138346	11925	Economy	3200.00
0005434138236	11925	Economy	3200.00
0005434138213	11925	Economy	3200.00
0005434138463	11925	Economy	3200.00
0005434138048	11925	Economy	3200.00
0005434138274	11925	Economy	3200.00
0005434138524	11925	Economy	3500.00
0005434138522	11925	Economy	3500.00
0005434138525	11925	Economy	3500.00
0005434138106	11925	Economy	3500.00
0005434138521	11925	Economy	3200.00
0005434138516	11925	Economy	3200.00
0005434138418	11925	Economy	3200.00
0005434138218	11925	Economy	3200.00
0005434138297	11925	Economy	3200.00
0005434138520	11925	Economy	3200.00
0005434138294	11925	Economy	3200.00
0005434138041	11925	Economy	3200.00
0005434138161	11925	Economy	3200.00
0005434138214	11925	Economy	3200.00
0005434138077	11925	Economy	3200.00
0005434138197	11925	Economy	3200.00
0005434137998	11925	Economy	3200.00
0005434138403	11925	Economy	3200.00
0005434138130	11925	Economy	3200.00
0005434138360	11925	Economy	3200.00
0005434138336	11925	Economy	3200.00
0005434138132	11925	Economy	3200.00
0005434138338	11925	Economy	3200.00
0005434138223	11925	Economy	3200.00
0005434138220	11925	Economy	3200.00
0005434138339	11925	Economy	3200.00
0005434138301	11925	Economy	3200.00
0005434138384	11925	Economy	3200.00
0005434138368	11925	Economy	3200.00
0005434138483	11925	Economy	3200.00
0005434138050	11925	Economy	3200.00
0005434138543	11925	Economy	3200.00
0005434138415	11925	Economy	3200.00
0005434138544	11925	Economy	3200.00
0005434138296	11925	Economy	3200.00
0005434138288	11925	Economy	3200.00
0005434138474	11925	Economy	3200.00
0005434138453	11925	Economy	3200.00
0005434138047	11925	Economy	3200.00
0005434138289	11925	Economy	3200.00
0005434138279	11925	Economy	3200.00
0005434138131	11925	Economy	3200.00
0005434138237	11925	Economy	3200.00
0005434138448	11925	Economy	3200.00
0005434138462	11925	Economy	3200.00
0005434138300	11925	Economy	3200.00
0005434138337	11925	Economy	3200.00
0005434138330	11925	Economy	3200.00
0005434138529	11925	Economy	3200.00
0005434138523	11925	Economy	3200.00
0005434138389	11925	Economy	3200.00
0005434138528	11925	Economy	3200.00
0005434138240	11925	Economy	3200.00
0005434138345	11925	Economy	3200.00
0005434138425	11925	Economy	3200.00
0005434138381	11925	Economy	3200.00
0005434138380	11925	Economy	3200.00
0005434138423	11925	Economy	3200.00
0005434138439	11925	Economy	3200.00
0005434138512	11925	Economy	3200.00
0005434138313	11925	Economy	3200.00
0005434138402	11925	Economy	3200.00
0005434138069	11925	Economy	3200.00
0005434138438	11925	Economy	3200.00
0005434138545	11925	Economy	3200.00
0005434138382	11925	Economy	3200.00
0005434138496	11925	Economy	3200.00
0005434138359	11925	Economy	3200.00
0005434138293	11925	Economy	3200.00
0005434139030	28760	Business	9700.00
0005434138990	28760	Business	9700.00
0005434139004	28760	Business	9700.00
0005434139017	28760	Business	9700.00
0005434139013	28760	Business	9700.00
0005434139010	28760	Business	9700.00
0005434139018	28760	Economy	3200.00
0005434139029	28760	Economy	3200.00
0005434139042	28760	Economy	3200.00
0005434139025	28760	Economy	3200.00
0005434139012	28760	Economy	3200.00
0005434138993	28760	Economy	3200.00
0005434138987	28760	Economy	3200.00
0005434139006	28760	Economy	3200.00
0005434139023	28760	Economy	3500.00
0005434139037	28760	Economy	3500.00
0005434138986	28760	Economy	3500.00
0005434139014	28760	Economy	3500.00
0005434138981	28760	Economy	3500.00
0005434139035	28760	Economy	3200.00
0005434139026	28760	Economy	3200.00
0005434139005	28760	Economy	3200.00
0005434139022	28760	Economy	3200.00
0005434139028	28760	Economy	3200.00
0005434138984	28760	Economy	3200.00
0005434138999	28760	Economy	3200.00
0005434139003	28760	Economy	3200.00
0005434139038	28760	Economy	3200.00
0005434139041	28760	Economy	3200.00
0005434139036	28760	Economy	3200.00
0005434139032	28760	Economy	3200.00
0005434139009	28760	Economy	3200.00
0005434139044	28760	Economy	3200.00
0005434139000	28760	Economy	3200.00
0005434138989	28760	Economy	3200.00
0005434139001	28760	Economy	3200.00
0005434138996	28760	Economy	3200.00
0005434138979	28760	Economy	3200.00
0005434139047	28760	Economy	3200.00
0005434138985	28760	Economy	3200.00
0005434139016	28760	Economy	3200.00
0005434138998	28760	Economy	3200.00
0005434139034	28760	Economy	3200.00
0005434138991	28760	Economy	3200.00
0005434139027	28760	Economy	3200.00
0005434138994	28760	Economy	3200.00
0005434138995	28760	Economy	3200.00
0005434138988	28760	Economy	3200.00
0005434139040	28760	Economy	3200.00
0005434138992	28760	Economy	3200.00
0005434139019	28760	Economy	3200.00
0005434139007	28760	Economy	3200.00
0005434139021	28760	Economy	3200.00
0005434139046	28760	Economy	3200.00
0005434139020	28760	Economy	3200.00
0005434139039	28760	Economy	3200.00
0005434139024	28760	Economy	3200.00
0005434138997	28760	Economy	3200.00
0005434139011	28760	Economy	3200.00
0005434139043	28760	Economy	3200.00
0005434139002	28760	Economy	3200.00
0005434139045	28760	Economy	3200.00
0005434139008	28760	Economy	3200.00
0005434138982	28760	Economy	3200.00
0005434139033	28760	Economy	3200.00
0005434139031	28760	Economy	3200.00
0005434139015	28760	Economy	3200.00
0005434138980	28760	Economy	3200.00
0005434138983	28760	Economy	3200.00
0005434516087	19097	Economy	26000.00
0005434513584	19097	Economy	26000.00
0005434513586	19097	Economy	23600.00
0005434516082	19097	Economy	23600.00
0005434516075	19097	Economy	23600.00
0005434190428	19097	Economy	23600.00
0005434516086	19097	Economy	23600.00
0005434190427	19097	Economy	23600.00
0005434190424	19097	Economy	23600.00
0005434190425	19097	Economy	23600.00
0005434190429	19097	Economy	23600.00
0005434516081	19097	Economy	23600.00
0005434513579	19097	Economy	23600.00
0005434516079	19097	Economy	23600.00
0005434513588	19097	Economy	23600.00
0005434190426	19097	Economy	23600.00
0005434513585	19097	Economy	23600.00
0005434513574	19097	Economy	23600.00
0005434516093	19097	Economy	23600.00
0005434513587	19097	Economy	23600.00
0005433538966	6817	Economy	10900.00
0005433538965	6817	Economy	10900.00
0005435259757	6817	Economy	9900.00
0005433538969	6817	Economy	9900.00
0005435259758	6817	Economy	9900.00
0005433538963	6817	Economy	9900.00
0005433538968	6817	Economy	9900.00
0005433534522	6817	Economy	9900.00
0005433538971	6817	Economy	9900.00
0005435259781	6817	Economy	9900.00
0005435259771	6817	Economy	9900.00
0005433538964	6817	Economy	9900.00
0005435259769	6817	Economy	9900.00
0005435259768	6817	Economy	9900.00
0005433534523	6817	Economy	9900.00
0005433538970	6817	Economy	9900.00
0005433538967	6817	Economy	9900.00
0005433534509	25040	Economy	10900.00
0005433538921	25040	Economy	9900.00
0005433538888	25040	Economy	9900.00
0005433538857	25040	Economy	9900.00
0005433538887	25040	Economy	9900.00
0005433538922	25040	Economy	9900.00
0005435259809	25040	Economy	9900.00
0005435259805	25040	Economy	9900.00
0005435259807	25040	Economy	9900.00
0005433538906	25040	Economy	9900.00
0005433538866	25040	Economy	9900.00
0005435259806	25040	Economy	9900.00
0005435259804	25040	Economy	9900.00
0005435259810	25040	Economy	9900.00
0005435259808	25040	Economy	9900.00
0005433512045	849	Economy	16100.00
0005433512050	849	Economy	14600.00
0005433512047	849	Economy	14600.00
0005433512043	849	Economy	14600.00
0005432922530	849	Economy	14600.00
0005432922532	849	Economy	14600.00
0005433512049	849	Economy	14600.00
0005433512044	849	Economy	14600.00
0005433512048	849	Economy	14600.00
0005432922541	849	Economy	14600.00
0005433512046	849	Economy	14600.00
0005432922531	849	Economy	14600.00
0005432922547	849	Economy	14600.00
0005433512011	16146	Economy	16100.00
0005432922570	16146	Economy	14600.00
0005433511969	16146	Economy	14600.00
0005432922572	16146	Economy	14600.00
0005433511997	16146	Economy	14600.00
0005433511949	16146	Economy	14600.00
0005433511992	16146	Economy	14600.00
0005433511950	16146	Economy	14600.00
0005432922569	16146	Economy	14600.00
0005433512005	16146	Economy	14600.00
0005433511993	16146	Economy	14600.00
0005433511977	16146	Economy	14600.00
0005432922571	16146	Economy	14600.00
0005433512039	16146	Economy	14600.00
0005433511996	16146	Economy	14600.00
0005433475751	4041	Economy	13500.00
0005435852571	4041	Economy	12300.00
0005433475756	4041	Economy	12300.00
0005433475752	4041	Economy	12300.00
0005435852564	4041	Economy	12300.00
0005433475759	4041	Economy	12300.00
0005433475758	4041	Economy	12300.00
0005435852586	4041	Economy	12300.00
0005433475753	4041	Economy	12300.00
0005435852579	4041	Economy	12300.00
0005433475754	4041	Economy	12300.00
0005433475755	4041	Economy	12300.00
0005435852574	4041	Economy	12300.00
0005435852583	4041	Economy	12300.00
0005435852575	4041	Economy	12300.00
0005433475757	4041	Economy	12300.00
0005435852582	4041	Economy	12300.00
0005435697670	3683	Economy	7900.00
0005435697653	3683	Economy	7900.00
0005435697667	3683	Economy	7900.00
0005435935057	3683	Economy	7900.00
0005435697662	3683	Economy	7200.00
0005435697651	3683	Economy	7200.00
0005434950578	3683	Economy	7200.00
0005435697672	3683	Economy	7200.00
0005434950580	3683	Economy	7200.00
0005435697673	3683	Economy	7200.00
0005435697666	3683	Economy	7200.00
0005435697652	3683	Economy	7200.00
0005434950581	3683	Economy	7200.00
0005435697658	3683	Economy	7200.00
0005435697663	3683	Economy	7200.00
0005435697659	3683	Economy	7200.00
0005435697664	3683	Economy	7200.00
0005435697661	3683	Economy	7200.00
0005435697657	3683	Economy	7200.00
0005435935056	3683	Economy	7200.00
0005435916189	3683	Economy	7200.00
0005435697669	3683	Economy	7200.00
0005435916175	3683	Economy	7200.00
0005435697647	3683	Economy	7200.00
0005435697674	3683	Economy	7200.00
0005435935065	3683	Economy	7200.00
0005435697656	3683	Economy	7200.00
0005435697660	3683	Economy	7200.00
0005434950582	3683	Economy	7200.00
0005435697671	3683	Economy	7200.00
0005435697668	3683	Economy	7200.00
0005434950579	3683	Economy	7200.00
0005435697675	3683	Economy	7200.00
0005435697649	3683	Economy	7200.00
0005435697648	3683	Economy	7200.00
0005435697650	3683	Economy	7200.00
0005435697655	3683	Economy	7200.00
0005435935055	3683	Economy	7200.00
0005435697654	3683	Economy	7200.00
0005435697665	3683	Economy	7200.00
0005435935046	3683	Economy	7200.00
0005435916197	16293	Economy	7900.00
0005435697427	16293	Economy	7900.00
0005435697411	16293	Economy	7900.00
0005435697336	16293	Economy	7900.00
0005435697303	16293	Economy	7200.00
0005435697304	16293	Economy	7200.00
0005435697516	16293	Economy	7200.00
0005435697310	16293	Economy	7200.00
0005434950539	16293	Economy	7200.00
0005435697339	16293	Economy	7200.00
0005435916198	16293	Economy	7200.00
0005435935079	16293	Economy	7200.00
0005435697463	16293	Economy	7200.00
0005435697457	16293	Economy	7200.00
0005435935078	16293	Economy	7200.00
0005435916200	16293	Economy	7200.00
0005435697386	16293	Economy	7200.00
0005435697364	16293	Economy	7200.00
0005434950534	16293	Economy	7200.00
0005435697368	16293	Economy	7200.00
0005435697309	16293	Economy	7200.00
0005435697418	16293	Economy	7200.00
0005435697435	16293	Economy	7200.00
0005435697410	16293	Economy	7200.00
0005435697515	16293	Economy	7200.00
0005434950523	16293	Economy	7200.00
0005435916201	16293	Economy	7200.00
0005435697415	16293	Economy	7200.00
0005435697462	16293	Economy	7200.00
0005435697338	16293	Economy	7200.00
0005435697375	16293	Economy	7200.00
0005434950533	16293	Economy	7200.00
0005435697385	16293	Economy	7200.00
0005435697412	16293	Economy	7200.00
0005435935077	16293	Economy	7200.00
0005435697458	16293	Economy	7200.00
0005435697335	16293	Economy	7200.00
0005435916199	16293	Economy	7200.00
0005435697350	16293	Economy	7200.00
0005434950536	16293	Economy	7200.00
0005434606869	3960	Economy	21300.00
0005432607612	3960	Economy	21300.00
0005434606868	3960	Economy	19300.00
0005433519512	3960	Economy	19300.00
0005433519509	3960	Economy	19300.00
0005432607614	3960	Economy	19300.00
0005434606867	3960	Economy	19300.00
0005432609779	3960	Economy	19300.00
0005432607613	3960	Economy	19300.00
0005432609778	3960	Economy	19300.00
0005435853624	3960	Economy	19300.00
0005434604937	3960	Economy	19300.00
0005432609776	3960	Economy	19300.00
0005435841476	3960	Economy	19300.00
0005434604935	3960	Economy	19300.00
0005434604936	3960	Economy	19300.00
0005432609777	3960	Economy	19300.00
0005434606870	3960	Economy	19300.00
0005433519511	3960	Economy	19300.00
0005432609780	3960	Economy	19300.00
0005433519510	3960	Economy	19300.00
0005434604938	3960	Economy	19300.00
0005433519466	22066	Economy	21300.00
0005435904901	22066	Economy	21300.00
0005433519472	22066	Economy	19300.00
0005433519465	22066	Economy	19300.00
0005434606833	22066	Economy	19300.00
0005433519491	22066	Economy	19300.00
0005433519490	22066	Economy	19300.00
0005435853633	22066	Economy	19300.00
0005435904900	22066	Economy	19300.00
0005434606824	22066	Economy	19300.00
0005435853634	22066	Economy	19300.00
0005435853632	22066	Economy	19300.00
0005435904902	22066	Economy	19300.00
0005435904903	22066	Economy	19300.00
0005433519489	22066	Economy	19300.00
0005433519433	22066	Economy	19300.00
0005433349001	787	Economy	3700.00
0005433349003	787	Economy	3700.00
0005433349005	787	Economy	3700.00
0005433349018	787	Economy	3700.00
0005433348989	787	Economy	3700.00
0005433349000	787	Economy	3700.00
0005433349002	787	Economy	3700.00
0005433349022	787	Economy	3700.00
0005433349004	787	Economy	3700.00
0005435628723	15912	Economy	3700.00
0005435628719	15912	Economy	3700.00
0005433349057	15912	Economy	3700.00
0005433349059	15912	Economy	3700.00
0005433349058	15912	Economy	3700.00
0005435628720	15912	Economy	3700.00
0005435628722	15912	Economy	3700.00
0005433349055	15912	Economy	3700.00
0005433349054	15912	Economy	3700.00
0005433349056	15912	Economy	3700.00
0005433349053	15912	Economy	3700.00
0005434445267	17213	Economy	7100.00
0005433158132	17213	Economy	7100.00
0005434446539	17213	Economy	7100.00
0005433158133	17213	Economy	7100.00
0005433158134	17213	Economy	7100.00
0005434445268	17213	Economy	7100.00
0005433158131	17213	Economy	7100.00
0005433158128	17213	Economy	7100.00
0005434446538	17213	Economy	7100.00
0005434445266	17213	Economy	7100.00
0005434445249	17670	Economy	7100.00
0005434445245	17670	Economy	7100.00
0005434445248	17670	Economy	7100.00
0005434445247	17670	Economy	7100.00
0005433159339	17670	Economy	7100.00
0005434445246	17670	Economy	7100.00
0005433159338	17670	Economy	7100.00
0005435133000	7858	Economy	5900.00
0005435133007	7858	Economy	5900.00
0005435133008	7858	Economy	5400.00
0005435133002	7858	Economy	5400.00
0005435383164	7858	Economy	5400.00
0005435383163	7858	Economy	5400.00
0005435133006	7858	Economy	5400.00
0005435133003	7858	Economy	5400.00
0005435132998	7858	Economy	5400.00
0005435132999	7858	Economy	5400.00
0005435383162	7858	Economy	5400.00
0005435383157	7858	Economy	5400.00
0005435133001	7858	Economy	5400.00
0005435383187	7858	Economy	5400.00
0005435133005	7858	Economy	5400.00
0005435133004	7858	Economy	5400.00
0005435383155	7858	Economy	5400.00
0005435383156	7858	Economy	5400.00
0005435383209	33061	Economy	5900.00
0005435383214	33061	Economy	5900.00
0005435383211	33061	Economy	5400.00
0005435383212	33061	Economy	5400.00
0005435132915	33061	Economy	5400.00
0005435132979	33061	Economy	5400.00
0005435132963	33061	Economy	5400.00
0005435132980	33061	Economy	5400.00
0005435132929	33061	Economy	5400.00
0005435383213	33061	Economy	5400.00
0005435132910	33061	Economy	5400.00
0005435383210	33061	Economy	5400.00
0005435132889	33061	Economy	5400.00
0005435132962	33061	Economy	5400.00
0005435132947	33061	Economy	5400.00
0005435132890	33061	Economy	5400.00
0005435132881	33061	Economy	5400.00
0005435390228	7533	Economy	13800.00
0005435160425	7533	Economy	12500.00
0005435160433	7533	Economy	12500.00
0005435390250	7533	Economy	12500.00
0005435160428	7533	Economy	12500.00
0005435160424	7533	Economy	12500.00
0005435160434	7533	Economy	12500.00
0005435160426	7533	Economy	12500.00
0005435160427	7533	Economy	12500.00
0005435390251	7533	Economy	12500.00
0005435160435	7533	Economy	12500.00
0005435160431	7533	Economy	12500.00
0005435160432	7533	Economy	12500.00
0005435160430	7533	Economy	12500.00
0005435390279	7533	Economy	12500.00
0005435160429	7533	Economy	12500.00
0005435390319	29533	Economy	13800.00
0005435160315	29533	Economy	12500.00
0005435390320	29533	Economy	12500.00
0005435160316	29533	Economy	12500.00
0005435390317	29533	Economy	12500.00
0005435160335	29533	Economy	12500.00
0005435390318	29533	Economy	12500.00
0005435390322	29533	Economy	12500.00
0005435160336	29533	Economy	12500.00
0005435390321	29533	Economy	12500.00
0005435160355	29533	Economy	12500.00
0005435160337	29533	Economy	12500.00
0005435390316	29533	Economy	12500.00
0005435160344	29533	Economy	12500.00
0005432394118	18444	Economy	4900.00
0005432398194	18444	Economy	4900.00
0005432394120	18444	Economy	4900.00
0005432398200	18444	Economy	4900.00
0005432398201	18444	Economy	4900.00
0005432394104	18444	Economy	4900.00
0005432394119	18444	Economy	4900.00
0005435178514	18444	Economy	4900.00
0005432398202	18444	Economy	4900.00
0005432398213	18444	Economy	4900.00
0005432400165	27143	Economy	4900.00
0005435178499	27143	Economy	4900.00
0005435178496	27143	Economy	4900.00
0005432398239	27143	Economy	4900.00
0005432398236	27143	Economy	4900.00
0005432400166	27143	Economy	4900.00
0005435178503	27143	Economy	4900.00
0005435178502	27143	Economy	4900.00
0005432398238	27143	Economy	4900.00
0005432398237	27143	Economy	4900.00
0005435178497	27143	Economy	4900.00
0005432400167	27143	Economy	4900.00
0005434504606	6537	Business	48400.00
0005434504619	6537	Business	48400.00
0005434504598	6537	Business	48400.00
0005434504599	6537	Business	48400.00
0005434504596	6537	Business	48400.00
0005434504603	6537	Business	48400.00
0005434504618	6537	Business	48400.00
0005434504588	6537	Economy	16100.00
0005434504607	6537	Economy	16100.00
0005434504592	6537	Economy	16100.00
0005434504613	6537	Economy	17800.00
0005434504597	6537	Economy	17800.00
0005434504593	6537	Economy	16100.00
0005434504608	6537	Economy	16100.00
0005434504585	6537	Economy	16100.00
0005434504604	6537	Economy	16100.00
0005434504620	6537	Economy	16100.00
0005435104014	6537	Economy	16100.00
0005434504589	6537	Economy	16100.00
0005434504610	6537	Economy	16100.00
0005434504602	6537	Economy	16100.00
0005434504612	6537	Economy	16100.00
0005434504587	6537	Economy	16100.00
0005434504605	6537	Economy	16100.00
0005434504622	6537	Economy	16100.00
0005434504601	6537	Economy	16100.00
0005434504591	6537	Economy	16100.00
0005434504584	6537	Economy	16100.00
0005434504615	6537	Economy	16100.00
0005434504621	6537	Economy	16100.00
0005434504590	6537	Economy	16100.00
0005434504594	6537	Economy	16100.00
0005434504616	6537	Economy	16100.00
0005434504583	6537	Economy	16100.00
0005435104016	6537	Economy	16100.00
0005435104015	6537	Economy	16100.00
0005434504614	6537	Economy	16100.00
0005434504609	6537	Economy	16100.00
0005434504600	6537	Economy	16100.00
0005434504586	6537	Economy	16100.00
0005434504582	6537	Economy	16100.00
0005434504595	6537	Economy	16100.00
0005434504617	6537	Economy	16100.00
0005434504611	6537	Economy	16100.00
0005434504232	22658	Business	48400.00
0005434504217	22658	Business	48400.00
0005434504201	22658	Business	48400.00
0005434504172	22658	Business	48400.00
0005434504297	22658	Business	48400.00
0005434504203	22658	Business	48400.00
0005434504186	22658	Business	48400.00
0005434504236	22658	Business	48400.00
0005434504129	22658	Business	48400.00
0005434504174	22658	Business	48400.00
0005434504175	22658	Business	48400.00
0005434504244	22658	Economy	16100.00
0005434504165	22658	Economy	16100.00
0005434504248	22658	Economy	16100.00
0005434504237	22658	Economy	16100.00
0005434503944	22658	Economy	16100.00
0005434504271	22658	Economy	17800.00
0005434503992	22658	Economy	16100.00
0005435103934	22658	Economy	16100.00
0005434504305	22658	Economy	16100.00
0005435103917	22658	Economy	16100.00
0005434504131	22658	Economy	16100.00
0005435103916	22658	Economy	16100.00
0005434504202	22658	Economy	16100.00
0005434503943	22658	Economy	16100.00
0005434504189	22658	Economy	16100.00
0005434504250	22658	Economy	16100.00
0005434504211	22658	Economy	16100.00
0005434504167	22658	Economy	16100.00
0005434504177	22658	Economy	16100.00
0005434504114	22658	Economy	16100.00
0005434504245	22658	Economy	16100.00
0005434504227	22658	Economy	16100.00
0005434504205	22658	Economy	16100.00
0005434504166	22658	Economy	16100.00
0005434504231	22658	Economy	16100.00
0005434504251	22658	Economy	16100.00
0005434504247	22658	Economy	16100.00
0005435103920	22658	Economy	16100.00
0005435103926	22658	Economy	16100.00
0005434504226	22658	Economy	16100.00
0005434504078	22658	Economy	16100.00
0005434504210	22658	Economy	16100.00
0005434504310	22658	Economy	16100.00
0005435103935	22658	Economy	16100.00
0005434504146	22658	Economy	16100.00
0005434504185	22658	Economy	16100.00
0005435103927	22658	Economy	16100.00
0005434504113	22658	Economy	16100.00
0005435103910	22658	Economy	16100.00
0005434504238	22658	Economy	16100.00
0005434504176	22658	Economy	16100.00
0005434503945	22658	Economy	16100.00
0005433368048	1677	Business	50000.00
0005433367916	1677	Business	50000.00
0005433368091	1677	Business	50000.00
0005435653570	1677	Business	50000.00
0005435653574	1677	Business	50000.00
0005433368049	1677	Business	50000.00
0005433367922	1677	Business	50000.00
0005433367962	1677	Business	50000.00
0005433368000	1677	Economy	16700.00
0005435653569	1677	Economy	16700.00
0005435653586	1677	Economy	16700.00
0005435653557	1677	Economy	16700.00
0005433367974	1677	Economy	16700.00
0005435653565	1677	Economy	16700.00
0005433368040	1677	Economy	16700.00
0005435653584	1677	Economy	18300.00
0005433368001	1677	Economy	18300.00
0005435653568	1677	Economy	18300.00
0005433367919	1677	Economy	18300.00
0005435653579	1677	Economy	16700.00
0005435653591	1677	Economy	16700.00
0005435653585	1677	Economy	16700.00
0005433367964	1677	Economy	16700.00
0005435653582	1677	Economy	16700.00
0005435653562	1677	Economy	16700.00
0005433367944	1677	Economy	16700.00
0005433367901	1677	Economy	16700.00
0005435653566	1677	Economy	16700.00
0005435653573	1677	Economy	16700.00
0005435653558	1677	Economy	16700.00
0005433367905	1677	Economy	16700.00
0005433368093	1677	Economy	16700.00
0005433367899	1677	Economy	16700.00
0005435653583	1677	Economy	16700.00
0005435653560	1677	Economy	16700.00
0005433367969	1677	Economy	16700.00
0005433367883	1677	Economy	16700.00
0005433367917	1677	Economy	16700.00
0005433367988	1677	Economy	16700.00
0005435653580	1677	Economy	16700.00
0005435653575	1677	Economy	16700.00
0005435653590	1677	Economy	16700.00
0005435653588	1677	Economy	16700.00
0005433367968	1677	Economy	16700.00
0005433367875	1677	Economy	16700.00
0005433367927	1677	Economy	16700.00
0005433368087	1677	Economy	16700.00
0005435653592	1677	Economy	16700.00
0005433367898	1677	Economy	16700.00
0005435653561	1677	Economy	16700.00
0005433367948	1677	Economy	16700.00
0005435653577	1677	Economy	16700.00
0005433367806	1677	Economy	16700.00
0005435653563	1677	Economy	16700.00
0005435653567	1677	Economy	16700.00
0005433368014	1677	Economy	16700.00
0005433367900	1677	Economy	16700.00
0005433367963	1677	Economy	16700.00
0005435653578	1677	Economy	16700.00
0005435653571	1677	Economy	16700.00
0005435653581	1677	Economy	16700.00
0005433367908	1677	Economy	16700.00
0005435653576	1677	Economy	16700.00
0005433368004	1677	Economy	16700.00
0005435653589	1677	Economy	16700.00
0005433368088	1677	Economy	16700.00
0005435653572	1677	Economy	16700.00
0005433368028	1677	Economy	16700.00
0005435653564	1677	Economy	16700.00
0005433368092	1677	Economy	16700.00
0005435653587	1677	Economy	16700.00
0005435653559	1677	Economy	16700.00
0005435653108	21685	Business	50000.00
0005433368329	21685	Business	50000.00
0005435653160	21685	Business	50000.00
0005433368296	21685	Business	50000.00
0005435653125	21685	Business	50000.00
0005433368316	21685	Business	50000.00
0005435653034	21685	Business	50000.00
0005433368325	21685	Business	50000.00
0005435653195	21685	Business	50000.00
0005433368310	21685	Business	50000.00
0005433368317	21685	Economy	16700.00
0005433368312	21685	Economy	16700.00
0005433368328	21685	Economy	16700.00
0005433368313	21685	Economy	16700.00
0005433368322	21685	Economy	16700.00
0005435653185	21685	Economy	16700.00
0005435652952	21685	Economy	16700.00
0005435653191	21685	Economy	16700.00
0005433368302	21685	Economy	16700.00
0005435653159	21685	Economy	16700.00
0005435653128	21685	Economy	18300.00
0005433368327	21685	Economy	18300.00
0005433368303	21685	Economy	18300.00
0005435653024	21685	Economy	18300.00
0005433368320	21685	Economy	18300.00
0005435653133	21685	Economy	16700.00
0005433368326	21685	Economy	16700.00
0005435653186	21685	Economy	16700.00
0005435653192	21685	Economy	16700.00
0005433368297	21685	Economy	16700.00
0005435653126	21685	Economy	16700.00
0005433368330	21685	Economy	16700.00
0005433368304	21685	Economy	16700.00
0005433368305	21685	Economy	16700.00
0005435652988	21685	Economy	16700.00
0005435653016	21685	Economy	16700.00
0005435653198	21685	Economy	16700.00
0005435653161	21685	Economy	16700.00
0005435653042	21685	Economy	16700.00
0005435653154	21685	Economy	16700.00
0005435653127	21685	Economy	16700.00
0005435652953	21685	Economy	16700.00
0005435653144	21685	Economy	16700.00
0005435653135	21685	Economy	16700.00
0005435653051	21685	Economy	16700.00
0005433368295	21685	Economy	16700.00
0005433368321	21685	Economy	16700.00
0005435653035	21685	Economy	16700.00
0005435653197	21685	Economy	16700.00
0005433368331	21685	Economy	16700.00
0005435653065	21685	Economy	16700.00
0005435653184	21685	Economy	16700.00
0005435653121	21685	Economy	16700.00
0005435652984	21685	Economy	16700.00
0005435653190	21685	Economy	16700.00
0005435652959	21685	Economy	16700.00
0005435652931	21685	Economy	16700.00
0005433368294	21685	Economy	16700.00
0005433368299	21685	Economy	16700.00
0005435653015	21685	Economy	16700.00
0005433368315	21685	Economy	16700.00
0005433368308	21685	Economy	16700.00
0005435652923	21685	Economy	16700.00
0005433368309	21685	Economy	16700.00
0005435653074	21685	Economy	16700.00
0005433368319	21685	Economy	16700.00
0005435653182	21685	Economy	16700.00
0005435652995	21685	Economy	16700.00
0005435653193	21685	Economy	16700.00
0005433368324	21685	Economy	16700.00
0005435653120	21685	Economy	16700.00
0005435652989	21685	Economy	16700.00
0005433368318	21685	Economy	16700.00
0005435653132	21685	Economy	16700.00
0005433368306	21685	Economy	16700.00
0005433368301	21685	Economy	16700.00
0005433368300	21685	Economy	16700.00
0005433368311	21685	Economy	16700.00
0005435653122	21685	Economy	16700.00
0005433368314	21685	Economy	16700.00
0005433368307	21685	Economy	16700.00
0005433368298	21685	Economy	16700.00
0005433368323	21685	Economy	16700.00
0005435653079	21685	Economy	16700.00
0005433986466	4138	Business	21500.00
0005433986461	4138	Business	21500.00
0005433986484	4138	Business	21500.00
0005433986502	4138	Business	21500.00
0005433986495	4138	Business	21500.00
0005433986486	4138	Economy	7200.00
0005433986477	4138	Economy	7200.00
0005433986459	4138	Economy	7200.00
0005433986490	4138	Economy	7200.00
0005433986494	4138	Economy	7900.00
0005433986501	4138	Economy	7900.00
0005433986474	4138	Economy	7900.00
0005433986498	4138	Economy	7900.00
0005433986478	4138	Economy	7200.00
0005433986500	4138	Economy	7200.00
0005435788801	4138	Economy	7200.00
0005433986476	4138	Economy	7200.00
0005433986470	4138	Economy	7200.00
0005433986475	4138	Economy	7200.00
0005433986497	4138	Economy	7200.00
0005433986491	4138	Economy	7200.00
0005435788799	4138	Economy	7200.00
0005435788802	4138	Economy	7200.00
0005433986464	4138	Economy	7200.00
0005433986480	4138	Economy	7200.00
0005433986496	4138	Economy	7200.00
0005433986483	4138	Economy	7200.00
0005435788800	4138	Economy	7200.00
0005433986479	4138	Economy	7200.00
0005433986467	4138	Economy	7200.00
0005433986469	4138	Economy	7200.00
0005433986472	4138	Economy	7200.00
0005433986471	4138	Economy	7200.00
0005433986465	4138	Economy	7200.00
0005433986492	4138	Economy	7200.00
0005433986493	4138	Economy	7200.00
0005433986505	4138	Economy	7200.00
0005433986462	4138	Economy	7200.00
0005433986489	4138	Economy	7200.00
0005433986481	4138	Economy	7200.00
0005433986468	4138	Economy	7200.00
0005433986504	4138	Economy	7200.00
0005433986488	4138	Economy	7200.00
0005433986499	4138	Economy	7200.00
0005433986460	4138	Economy	7200.00
0005433986487	4138	Economy	7200.00
0005433986503	4138	Economy	7200.00
0005433986473	4138	Economy	7200.00
0005433986482	4138	Economy	7200.00
0005433986485	4138	Economy	7200.00
0005433986463	4138	Economy	7200.00
0005433985929	25641	Business	21500.00
0005433985844	25641	Business	21500.00
0005433986143	25641	Business	21500.00
0005433986022	25641	Business	21500.00
0005433986074	25641	Business	21500.00
0005433985767	25641	Business	21500.00
0005433985980	25641	Economy	7200.00
0005433985944	25641	Economy	7200.00
0005433985923	25641	Economy	7200.00
0005433985983	25641	Economy	7200.00
0005433985924	25641	Economy	7900.00
0005433985889	25641	Economy	7900.00
0005433985888	25641	Economy	7900.00
0005433985942	25641	Economy	7200.00
0005433986151	25641	Economy	7200.00
0005433985912	25641	Economy	7200.00
0005433985959	25641	Economy	7200.00
0005435788775	25641	Economy	7200.00
0005433985922	25641	Economy	7200.00
0005433985956	25641	Economy	7200.00
0005433986095	25641	Economy	7200.00
0005433986034	25641	Economy	7200.00
0005433986029	25641	Economy	7200.00
0005433985943	25641	Economy	7200.00
0005433986030	25641	Economy	7200.00
0005433986068	25641	Economy	7200.00
0005435788780	25641	Economy	7200.00
0005433985947	25641	Economy	7200.00
0005433985996	25641	Economy	7200.00
0005433985982	25641	Economy	7200.00
0005433985925	25641	Economy	7200.00
0005433986062	25641	Economy	7200.00
0005435788779	25641	Economy	7200.00
0005433986001	25641	Economy	7200.00
0005433986000	25641	Economy	7200.00
0005433985911	25641	Economy	7200.00
0005433985822	25641	Economy	7200.00
0005433985845	25641	Economy	7200.00
0005433986002	25641	Economy	7200.00
0005433986016	25641	Economy	7200.00
0005435788776	25641	Economy	7200.00
0005433986096	25641	Economy	7200.00
0005433985966	25641	Economy	7200.00
0005433986152	25641	Economy	7200.00
0005433986061	25641	Economy	7200.00
0005433985864	25641	Economy	7200.00
0005433985999	25641	Economy	7200.00
0005433985927	25641	Economy	7200.00
0005433986103	25641	Economy	7200.00
0005433461611	20246	Business	201300.00
0005433461597	20246	Business	201300.00
0005433461599	20246	Business	201300.00
0005433461601	20246	Business	201300.00
0005433460446	20246	Business	201300.00
0005433460459	20246	Economy	67100.00
0005433460458	20246	Economy	67100.00
0005433460448	20246	Economy	67100.00
0005433461600	20246	Economy	67100.00
0005433461607	20246	Economy	67100.00
0005433460451	20246	Economy	67100.00
0005433461606	20246	Economy	67100.00
0005433460450	20246	Economy	67100.00
0005433460457	20246	Economy	67100.00
0005433460445	20246	Economy	67100.00
0005433461609	20246	Economy	67100.00
0005433460456	20246	Economy	67100.00
0005433461598	20246	Economy	67100.00
0005433461605	20246	Economy	67100.00
0005433461608	20246	Economy	67100.00
0005433460454	20246	Economy	67100.00
0005433460455	20246	Economy	67100.00
0005433460452	20246	Economy	67100.00
0005433461610	20246	Economy	67100.00
0005433461604	20246	Economy	67100.00
0005433461603	20246	Economy	67100.00
0005433461602	20246	Economy	67100.00
0005433460449	20246	Economy	67100.00
0005433460447	20246	Economy	67100.00
0005433460453	20246	Economy	67100.00
0005435720143	24791	Economy	9400.00
0005435719570	24791	Economy	9400.00
0005435719571	24791	Economy	9400.00
0005435720141	24791	Economy	9400.00
0005435720142	24791	Economy	9400.00
0005433168419	21326	Economy	17000.00
0005433168417	21326	Economy	17000.00
0005434509173	21326	Economy	15500.00
0005434509163	21326	Economy	15500.00
0005434509176	21326	Economy	15500.00
0005434509150	21326	Economy	15500.00
0005434509152	21326	Economy	15500.00
0005434509190	21326	Economy	15500.00
0005434509175	21326	Economy	15500.00
0005434509189	21326	Economy	15500.00
0005434509170	21326	Economy	15500.00
0005434509165	21326	Economy	15500.00
0005433168415	21326	Economy	15500.00
0005433168418	21326	Economy	15500.00
0005434509160	21326	Economy	15500.00
0005433168423	21326	Economy	15500.00
0005433168416	21326	Economy	15500.00
0005434509182	21326	Economy	15500.00
0005433168422	21326	Economy	15500.00
0005434509192	21326	Economy	15500.00
0005433168420	21326	Economy	15500.00
0005434509149	21326	Economy	15500.00
0005433168421	21326	Economy	15500.00
0005434509213	21326	Economy	15500.00
0005434509191	21326	Economy	15500.00
0005432664135	17830	Business	18000.00
0005432869603	17830	Business	18000.00
0005432666400	17830	Business	18000.00
0005434151739	17830	Business	18000.00
0005432665280	17830	Economy	6000.00
0005432660824	17830	Economy	6000.00
0005432869601	17830	Economy	6000.00
0005432655568	17830	Economy	6600.00
0005432667459	17830	Economy	6600.00
0005432665290	17830	Economy	6000.00
0005432658596	17830	Economy	6000.00
0005432869606	17830	Economy	6000.00
0005434151740	17830	Economy	6000.00
0005432660828	17830	Economy	6000.00
0005432655595	17830	Economy	6000.00
0005432655572	17830	Economy	6000.00
0005432869605	17830	Economy	6000.00
0005432869604	17830	Economy	6000.00
0005432657457	17830	Economy	6000.00
0005432655543	17830	Economy	6000.00
0005432666391	17830	Economy	6000.00
0005432655606	17830	Economy	6000.00
0005434151738	17830	Economy	6000.00
0005432655594	17830	Economy	6000.00
0005432655573	17830	Economy	6000.00
0005432658598	17830	Economy	6000.00
0005432664140	17830	Economy	6000.00
0005432657463	17830	Economy	6000.00
0005432657455	17830	Economy	6000.00
0005432655571	17830	Economy	6000.00
0005432658597	17830	Economy	6000.00
0005432655566	17830	Economy	6000.00
0005432655567	17830	Economy	6000.00
0005432869602	17830	Economy	6000.00
0005432655576	17830	Economy	6000.00
0005432869536	26308	Business	18000.00
0005432869544	26308	Business	18000.00
0005432869532	26308	Business	18000.00
0005432655655	26308	Business	18000.00
0005432667475	26308	Business	18000.00
0005432869526	26308	Business	18000.00
0005432869549	26308	Economy	6000.00
0005432869498	26308	Economy	6000.00
0005432869525	26308	Economy	6000.00
0005432655646	26308	Economy	6000.00
0005432665296	26308	Economy	6000.00
0005432667474	26308	Economy	6000.00
0005432869527	26308	Economy	6000.00
0005432869538	26308	Economy	6000.00
0005432660839	26308	Economy	6000.00
0005434151720	26308	Economy	6000.00
0005432658612	26308	Economy	6000.00
0005432659726	26308	Economy	6000.00
0005432655647	26308	Economy	6000.00
0005432655644	26308	Economy	6000.00
0005432658613	26308	Economy	6000.00
0005432655653	26308	Economy	6000.00
0005432655649	26308	Economy	6000.00
0005432657481	26308	Economy	6000.00
0005432657479	26308	Economy	6000.00
0005432655648	26308	Economy	6000.00
0005432655654	26308	Economy	6000.00
0005432869548	26308	Economy	6000.00
0005432869543	26308	Economy	6000.00
0005432655651	26308	Economy	6000.00
0005432666410	26308	Economy	6000.00
0005432665295	26308	Economy	6000.00
0005432659727	26308	Economy	6000.00
0005432655652	26308	Economy	6000.00
0005432869537	26308	Economy	6000.00
0005432657480	26308	Economy	6000.00
0005432665297	26308	Economy	6000.00
0005432655645	26308	Economy	6000.00
0005434151719	26308	Economy	6000.00
0005432869552	26308	Economy	6000.00
0005432655650	26308	Economy	6000.00
0005432329243	3105	Business	16100.00
0005432905189	3105	Business	16100.00
0005432329227	3105	Business	16100.00
0005432329232	3105	Business	16100.00
0005433438962	3105	Business	16100.00
0005433438963	3105	Business	16100.00
0005432329228	3105	Business	16100.00
0005432329249	3105	Business	16100.00
0005432329215	3105	Business	16100.00
0005432329245	3105	Business	16100.00
0005432329220	3105	Business	16100.00
0005432329219	3105	Economy	5400.00
0005432329222	3105	Economy	5400.00
0005432329224	3105	Economy	5400.00
0005432329233	3105	Economy	5400.00
0005432329242	3105	Economy	5400.00
0005432905190	3105	Economy	5900.00
0005432329218	3105	Economy	5400.00
0005433438967	3105	Economy	5400.00
0005432287250	3105	Economy	5400.00
0005432329237	3105	Economy	5400.00
0005432287245	3105	Economy	5400.00
0005432329211	3105	Economy	5400.00
0005432329235	3105	Economy	5400.00
0005432287249	3105	Economy	5400.00
0005432287247	3105	Economy	5400.00
0005432329225	3105	Economy	5400.00
0005432329213	3105	Economy	5400.00
0005432329240	3105	Economy	5400.00
0005432329247	3105	Economy	5400.00
0005433438968	3105	Economy	5400.00
0005432329221	3105	Economy	5400.00
0005432329246	3105	Economy	5400.00
0005433438965	3105	Economy	5400.00
0005432329214	3105	Economy	5400.00
0005432329234	3105	Economy	5400.00
0005432329238	3105	Economy	5400.00
0005432329209	3105	Economy	5400.00
0005432329226	3105	Economy	5400.00
0005432329216	3105	Economy	5400.00
0005433438966	3105	Economy	5400.00
0005432329210	3105	Economy	5400.00
0005433438964	3105	Economy	5400.00
0005432329251	3105	Economy	5400.00
0005432287246	3105	Economy	5400.00
0005432329244	3105	Economy	5400.00
0005432329217	3105	Economy	5400.00
0005432287248	3105	Economy	5400.00
0005432329230	3105	Economy	5400.00
0005432329207	3105	Economy	5400.00
0005432329252	3105	Economy	5400.00
0005432329223	3105	Economy	5400.00
0005432329212	3105	Economy	5400.00
0005432329248	3105	Economy	5400.00
0005432329241	3105	Economy	5400.00
0005432329206	3105	Economy	5400.00
0005432329231	3105	Economy	5400.00
0005432329208	3105	Economy	5400.00
0005432329250	3105	Economy	5400.00
0005432329236	3105	Economy	5400.00
0005432329239	3105	Economy	5400.00
0005432329229	3105	Economy	5400.00
0005432328811	31107	Business	16100.00
0005432328787	31107	Business	16100.00
0005433438924	31107	Business	16100.00
0005432905192	31107	Business	16100.00
0005432328941	31107	Business	16100.00
0005432328701	31107	Business	16100.00
0005432328888	31107	Business	16100.00
0005432328853	31107	Business	16100.00
0005433438891	31107	Economy	5400.00
0005432328931	31107	Economy	5400.00
0005432328849	31107	Economy	5400.00
0005432328541	31107	Economy	5400.00
0005433438892	31107	Economy	5400.00
0005432328812	31107	Economy	5900.00
0005433438897	31107	Economy	5900.00
0005432328894	31107	Economy	5900.00
0005432905193	31107	Economy	5900.00
0005432328726	31107	Economy	5400.00
0005432328540	31107	Economy	5400.00
0005432328759	31107	Economy	5400.00
0005432328833	31107	Economy	5400.00
0005432905194	31107	Economy	5400.00
0005432905195	31107	Economy	5400.00
0005432328916	31107	Economy	5400.00
0005432328875	31107	Economy	5400.00
0005433438898	31107	Economy	5400.00
0005432054336	31107	Economy	5400.00
0005432328834	31107	Economy	5400.00
0005433438937	31107	Economy	5400.00
0005433438904	31107	Economy	5400.00
0005432328557	31107	Economy	5400.00
0005432328679	31107	Economy	5400.00
0005432328695	31107	Economy	5400.00
0005433438908	31107	Economy	5400.00
0005432328687	31107	Economy	5400.00
0005432328773	31107	Economy	5400.00
0005432328915	31107	Economy	5400.00
0005432328876	31107	Economy	5400.00
0005432328514	31107	Economy	5400.00
0005432054340	31107	Economy	5400.00
0005432328691	31107	Economy	5400.00
0005433438877	31107	Economy	5400.00
0005432328840	31107	Economy	5400.00
0005432328854	31107	Economy	5400.00
0005432054337	31107	Economy	5400.00
0005432328558	31107	Economy	5400.00
0005433438938	31107	Economy	5400.00
0005433438869	31107	Economy	5400.00
0005432905191	31107	Economy	5400.00
0005432328788	31107	Economy	5400.00
0005433438903	31107	Economy	5400.00
0005432328747	31107	Economy	5400.00
0005432328821	31107	Economy	5400.00
0005432328770	31107	Economy	5400.00
0005432328725	31107	Economy	5400.00
0005432328621	31107	Economy	5400.00
0005433438939	31107	Economy	5400.00
0005432054338	31107	Economy	5400.00
0005432328515	31107	Economy	5400.00
0005432054339	31107	Economy	5400.00
0005432328813	31107	Economy	5400.00
0005432328740	31107	Economy	5400.00
0005432328839	31107	Economy	5400.00
0005433438870	31107	Economy	5400.00
0005435487855	6192	Business	124600.00
0005435999445	6192	Business	124600.00
0005435487918	6192	Business	124600.00
0005435999456	6192	Business	124600.00
0005432146221	6192	Business	124600.00
0005434309903	6192	Economy	41500.00
0005432146222	6192	Economy	41500.00
0005435487891	6192	Economy	41500.00
0005435999438	6192	Economy	41500.00
0005435999446	6192	Economy	41500.00
0005434309904	6192	Economy	41500.00
0005435297039	6192	Economy	41500.00
0005435999443	6192	Economy	41500.00
0005434309899	6192	Economy	41500.00
0005435297038	6192	Economy	41500.00
0005435487964	6192	Economy	41500.00
0005434309893	6192	Economy	41500.00
0005435487935	6192	Economy	41500.00
0005435487815	6192	Economy	41500.00
0005434309905	6192	Economy	41500.00
0005435999439	6192	Economy	41500.00
0005435999440	6192	Economy	41500.00
0005435999451	6192	Economy	41500.00
0005435999450	6192	Economy	41500.00
0005435487974	6192	Economy	45700.00
0005435487878	6192	Economy	45700.00
0005435487942	6192	Economy	45700.00
0005435999453	6192	Economy	41500.00
0005435487941	6192	Economy	41500.00
0005435487879	6192	Economy	41500.00
0005434309901	6192	Economy	41500.00
0005435999442	6192	Economy	41500.00
0005435999455	6192	Economy	41500.00
0005434309902	6192	Economy	41500.00
0005435999444	6192	Economy	41500.00
0005435487900	6192	Economy	41500.00
0005435999437	6192	Economy	41500.00
0005434309898	6192	Economy	41500.00
0005435999441	6192	Economy	41500.00
0005434309895	6192	Economy	41500.00
0005435487989	6192	Economy	41500.00
0005435487903	6192	Economy	41500.00
0005435999454	6192	Economy	41500.00
0005435487925	6192	Economy	41500.00
0005435487899	6192	Economy	41500.00
0005435999452	6192	Economy	41500.00
0005434309896	6192	Economy	41500.00
0005435487966	6192	Economy	41500.00
0005435999449	6192	Economy	41500.00
0005435297077	6192	Economy	41500.00
0005435487965	6192	Economy	41500.00
0005435487856	6192	Economy	41500.00
0005435297049	6192	Economy	41500.00
0005435999447	6192	Economy	41500.00
0005435297066	6192	Economy	41500.00
0005435487973	6192	Economy	41500.00
0005434309897	6192	Economy	41500.00
0005434309900	6192	Economy	41500.00
0005435999448	6192	Economy	41500.00
0005434309894	6192	Economy	41500.00
0005434309892	6192	Economy	41500.00
0005435999436	6192	Economy	41500.00
0005435297107	6192	Economy	41500.00
0005434309757	19551	Business	124600.00
0005435999285	19551	Business	124600.00
0005435488069	19551	Business	124600.00
0005435999286	19551	Business	124600.00
0005435999282	19551	Business	124600.00
0005435488060	19551	Economy	41500.00
0005435999249	19551	Economy	41500.00
0005434309768	19551	Economy	41500.00
0005435488068	19551	Economy	41500.00
0005435488067	19551	Economy	41500.00
0005434309786	19551	Economy	41500.00
0005435488062	19551	Economy	41500.00
0005435297139	19551	Economy	41500.00
0005435488056	19551	Economy	41500.00
0005435999264	19551	Economy	41500.00
0005435297138	19551	Economy	41500.00
0005434309780	19551	Economy	41500.00
0005434309814	19551	Economy	41500.00
0005434309773	19551	Economy	41500.00
0005435488058	19551	Economy	41500.00
0005435999275	19551	Economy	41500.00
0005435999263	19551	Economy	41500.00
0005435999186	19551	Economy	41500.00
0005434309800	19551	Economy	41500.00
0005435999255	19551	Economy	41500.00
0005435999287	19551	Economy	41500.00
0005435488057	19551	Economy	41500.00
0005434309680	19551	Economy	41500.00
0005435999212	19551	Economy	41500.00
0005435488063	19551	Economy	45700.00
0005435999267	19551	Economy	45700.00
0005435488053	19551	Economy	45700.00
0005435999211	19551	Economy	41500.00
0005435999297	19551	Economy	41500.00
0005435488070	19551	Economy	41500.00
0005435999262	19551	Economy	41500.00
0005435999266	19551	Economy	41500.00
0005434309767	19551	Economy	41500.00
0005435488065	19551	Economy	41500.00
0005435488054	19551	Economy	41500.00
0005435297135	19551	Economy	41500.00
0005434309774	19551	Economy	41500.00
0005435488059	19551	Economy	41500.00
0005435488055	19551	Economy	41500.00
0005435297140	19551	Economy	41500.00
0005435488072	19551	Economy	41500.00
0005435297136	19551	Economy	41500.00
0005434309781	19551	Economy	41500.00
0005435488061	19551	Economy	41500.00
0005435999231	19551	Economy	41500.00
0005434309801	19551	Economy	41500.00
0005435999283	19551	Economy	41500.00
0005435999298	19551	Economy	41500.00
0005434309779	19551	Economy	41500.00
0005435488073	19551	Economy	41500.00
0005435999273	19551	Economy	41500.00
0005435999254	19551	Economy	41500.00
0005435999274	19551	Economy	41500.00
0005435297137	19551	Economy	41500.00
0005435488052	19551	Economy	41500.00
0005435488071	19551	Economy	41500.00
0005435488064	19551	Economy	41500.00
0005435488066	19551	Economy	41500.00
0005433158155	17536	Economy	13600.00
0005434446529	17536	Economy	12300.00
0005433158154	17536	Economy	12300.00
0005434446516	17536	Economy	12300.00
0005433158152	17536	Economy	12300.00
0005434446525	17536	Economy	12300.00
0005434446526	17536	Economy	12300.00
0005434446518	17536	Economy	12300.00
0005434446530	17536	Economy	12300.00
0005433158157	17536	Economy	12300.00
0005433158153	17536	Economy	12300.00
0005434446520	17536	Economy	12300.00
0005433158156	17536	Economy	12300.00
0005435508485	1574	Business	86000.00
0005434566071	1574	Business	86000.00
0005435518119	1574	Business	86000.00
0005434566069	1574	Business	86000.00
0005432291958	1574	Business	86000.00
0005434566067	1574	Business	86000.00
0005434566066	1574	Business	86000.00
0005432291957	1574	Business	86000.00
0005435518125	1574	Business	86000.00
0005435518129	1574	Economy	28700.00
0005433186120	1574	Economy	28700.00
0005435502554	1574	Economy	28700.00
0005435518126	1574	Economy	28700.00
0005435502555	1574	Economy	28700.00
0005435518116	1574	Economy	28700.00
0005435508484	1574	Economy	28700.00
0005434566073	1574	Economy	28700.00
0005435502564	1574	Economy	28700.00
0005435508486	1574	Economy	31500.00
0005435508491	1574	Economy	31500.00
0005435518120	1574	Economy	31500.00
0005435518134	1574	Economy	31500.00
0005435502560	1574	Economy	28700.00
0005435508488	1574	Economy	28700.00
0005434566072	1574	Economy	28700.00
0005435502566	1574	Economy	28700.00
0005434566075	1574	Economy	28700.00
0005435502561	1574	Economy	28700.00
0005435502558	1574	Economy	28700.00
0005432291959	1574	Economy	28700.00
0005435502570	1574	Economy	28700.00
0005433186128	1574	Economy	28700.00
0005435518127	1574	Economy	28700.00
0005435502567	1574	Economy	28700.00
0005433186119	1574	Economy	28700.00
0005434566065	1574	Economy	28700.00
0005435502572	1574	Economy	28700.00
0005435502565	1574	Economy	28700.00
0005433186158	1574	Economy	28700.00
0005434566076	1574	Economy	28700.00
0005435518122	1574	Economy	28700.00
0005435518128	1574	Economy	28700.00
0005435502563	1574	Economy	28700.00
0005434566064	1574	Economy	28700.00
0005435518123	1574	Economy	28700.00
0005435508487	1574	Economy	28700.00
0005435518133	1574	Economy	28700.00
0005435502557	1574	Economy	28700.00
0005433186139	1574	Economy	28700.00
0005435508489	1574	Economy	28700.00
0005435502562	1574	Economy	28700.00
0005435518115	1574	Economy	28700.00
0005434566070	1574	Economy	28700.00
0005435518124	1574	Economy	28700.00
0005435518131	1574	Economy	28700.00
0005435518130	1574	Economy	28700.00
0005435502553	1574	Economy	28700.00
0005435518135	1574	Economy	28700.00
0005435508490	1574	Economy	28700.00
0005434566074	1574	Economy	28700.00
0005434566063	1574	Economy	28700.00
0005433186127	1574	Economy	28700.00
0005435518132	1574	Economy	28700.00
0005435502569	1574	Economy	28700.00
0005435502571	1574	Economy	28700.00
0005435518118	1574	Economy	28700.00
0005435502568	1574	Economy	28700.00
0005435502559	1574	Economy	28700.00
0005435518121	1574	Economy	28700.00
0005435518117	1574	Economy	28700.00
0005435502573	1574	Economy	28700.00
0005435508492	1574	Economy	28700.00
0005434566068	1574	Economy	28700.00
0005435502556	1574	Economy	28700.00
0005435502304	20851	Business	86000.00
0005435529253	20851	Business	86000.00
0005434565930	20851	Business	86000.00
0005434565956	20851	Business	86000.00
0005435529342	20851	Business	86000.00
0005435529285	20851	Business	86000.00
0005435529242	20851	Business	86000.00
0005433186215	20851	Business	86000.00
0005433186221	20851	Business	86000.00
0005434565957	20851	Economy	28700.00
0005435529293	20851	Economy	28700.00
0005433186220	20851	Economy	28700.00
0005435529269	20851	Economy	28700.00
0005435529348	20851	Economy	28700.00
0005433186216	20851	Economy	28700.00
0005435502419	20851	Economy	28700.00
0005435529240	20851	Economy	28700.00
0005435545738	20851	Economy	28700.00
0005435529321	20851	Economy	31500.00
0005434565963	20851	Economy	31500.00
0005435502361	20851	Economy	31500.00
0005434565955	20851	Economy	31500.00
0005435529295	20851	Economy	31500.00
0005435529260	20851	Economy	28700.00
0005435502381	20851	Economy	28700.00
0005435529276	20851	Economy	28700.00
0005434565967	20851	Economy	28700.00
0005435529355	20851	Economy	28700.00
0005434565932	20851	Economy	28700.00
0005435502375	20851	Economy	28700.00
0005435529268	20851	Economy	28700.00
0005435502348	20851	Economy	28700.00
0005435529208	20851	Economy	28700.00
0005435502385	20851	Economy	28700.00
0005435529341	20851	Economy	28700.00
0005435529394	20851	Economy	28700.00
0005435502347	20851	Economy	28700.00
0005433186218	20851	Economy	28700.00
0005435545764	20851	Economy	28700.00
0005435529188	20851	Economy	28700.00
0005435529294	20851	Economy	28700.00
0005434565964	20851	Economy	28700.00
0005435529267	20851	Economy	28700.00
0005435529292	20851	Economy	28700.00
0005434565958	20851	Economy	28700.00
0005433186213	20851	Economy	28700.00
0005433186219	20851	Economy	28700.00
0005435529302	20851	Economy	28700.00
0005435529343	20851	Economy	28700.00
0005435502323	20851	Economy	28700.00
0005435529332	20851	Economy	28700.00
0005435529333	20851	Economy	28700.00
0005435545742	20851	Economy	28700.00
0005435529245	20851	Economy	28700.00
0005434565931	20851	Economy	28700.00
0005435529238	20851	Economy	28700.00
0005435545741	20851	Economy	28700.00
0005434565966	20851	Economy	28700.00
0005435529284	20851	Economy	28700.00
0005435502279	20851	Economy	28700.00
0005435529275	20851	Economy	28700.00
0005435545739	20851	Economy	28700.00
0005435502280	20851	Economy	28700.00
0005435529241	20851	Economy	28700.00
0005435529261	20851	Economy	28700.00
0005435529345	20851	Economy	28700.00
0005435529346	20851	Economy	28700.00
0005435502418	20851	Economy	28700.00
0005435529299	20851	Economy	28700.00
0005434565900	20851	Economy	28700.00
0005433186217	20851	Economy	28700.00
0005435545762	20851	Economy	28700.00
0005435502399	20851	Economy	28700.00
0005435529278	20851	Economy	28700.00
0005433186214	20851	Economy	28700.00
0005435502321	20851	Economy	28700.00
0005435529207	20851	Economy	28700.00
0005434565893	20851	Economy	28700.00
0005435545763	20851	Economy	28700.00
0005434565972	20851	Economy	28700.00
0005435529298	20851	Economy	28700.00
0005435502398	20851	Economy	28700.00
0005435502382	20851	Economy	28700.00
0005435502376	20851	Economy	28700.00
0005435502303	20851	Economy	28700.00
0005435153817	3921	Economy	21600.00
0005435931615	3921	Economy	21600.00
0005435153819	3921	Economy	19700.00
0005435153816	3921	Economy	19700.00
0005435931614	3921	Economy	19700.00
0005435931595	3921	Economy	19700.00
0005435153818	3921	Economy	19700.00
0005435153821	3921	Economy	19700.00
0005435153820	3921	Economy	19700.00
0005435931606	3921	Economy	19700.00
0005435153762	21876	Economy	19700.00
0005435931645	21876	Economy	19700.00
0005435153756	21876	Economy	19700.00
0005435153757	21876	Economy	19700.00
0005435931644	21876	Economy	19700.00
0005435153752	21876	Economy	19700.00
0005435931646	21876	Economy	19700.00
0005432629018	7218	Economy	14300.00
0005432629020	7218	Economy	14300.00
0005432629014	7218	Economy	13000.00
0005435225604	7218	Economy	13000.00
0005432629013	7218	Economy	13000.00
0005432629022	7218	Economy	13000.00
0005432629010	7218	Economy	13000.00
0005432629021	7218	Economy	13000.00
0005432629015	7218	Economy	13000.00
0005432629012	7218	Economy	13000.00
0005432629019	7218	Economy	13000.00
0005435225601	7218	Economy	13000.00
0005432629024	7218	Economy	13000.00
0005432629023	7218	Economy	13000.00
0005435225607	7218	Economy	13000.00
0005432629016	7218	Economy	13000.00
0005432629011	7218	Economy	13000.00
0005432629017	7218	Economy	13000.00
0005432628910	28114	Economy	14300.00
0005432628894	28114	Economy	13000.00
0005432628955	28114	Economy	13000.00
0005432628956	28114	Economy	13000.00
0005432628899	28114	Economy	13000.00
0005435225677	28114	Economy	13000.00
0005432628890	28114	Economy	13000.00
0005432628875	28114	Economy	13000.00
0005435225676	28114	Economy	13000.00
0005432628895	28114	Economy	13000.00
0005432628891	28114	Economy	13000.00
0005432628909	28114	Economy	13000.00
0005432628900	28114	Economy	13000.00
0005432628893	28114	Economy	13000.00
0005432628935	28114	Economy	13000.00
0005435225679	28114	Economy	13000.00
0005432629019	28114	Economy	13000.00
0005432628896	28114	Economy	13000.00
0005435225678	28114	Economy	13000.00
0005435225680	28114	Economy	13000.00
0005435225675	28114	Economy	13000.00
0005435225681	28114	Economy	13000.00
0005432628936	28114	Economy	13000.00
0005435225674	28114	Economy	13000.00
0005432628937	28114	Economy	13000.00
0005432628865	28114	Economy	13000.00
0005434267959	8714	Economy	11500.00
0005434267968	8714	Economy	11500.00
0005434267969	8714	Economy	10500.00
0005434267953	8714	Economy	10500.00
0005435960094	8714	Economy	10500.00
0005434267958	8714	Economy	10500.00
0005434267974	8714	Economy	10500.00
0005434267952	8714	Economy	10500.00
0005435960095	8714	Economy	10500.00
0005435960093	8714	Economy	10500.00
0005435960096	8714	Economy	10500.00
0005434267991	15228	Economy	11500.00
0005435960056	15228	Economy	11500.00
0005435960067	15228	Economy	10500.00
0005435960068	15228	Economy	10500.00
0005435960057	15228	Economy	10500.00
0005434267993	15228	Economy	10500.00
0005435960055	15228	Economy	10500.00
0005435960069	15228	Economy	10500.00
0005434267994	15228	Economy	10500.00
0005435960054	15228	Economy	10500.00
0005434267992	15228	Economy	10500.00
0005432693388	1217	Business	115000.00
0005432873326	1217	Business	115000.00
0005432693406	1217	Business	115000.00
0005432677614	1217	Business	115000.00
0005432693401	1217	Business	115000.00
0005432693397	1217	Business	115000.00
0005432675300	1217	Business	115000.00
0005432675312	1217	Business	115000.00
0005432675301	1217	Business	115000.00
0005432693407	1217	Business	115000.00
0005432693409	1217	Business	115000.00
0005432693393	1217	Business	115000.00
0005432677613	1217	Economy	38300.00
0005432873293	1217	Business	115000.00
0005432693380	1217	Economy	38300.00
0005432675314	1217	Economy	38300.00
0005432693392	1217	Economy	38300.00
0005432873327	1217	Economy	38300.00
0005432873307	1217	Economy	42200.00
0005432675313	1217	Economy	42200.00
0005432693402	1217	Economy	42200.00
0005432873298	1217	Economy	38300.00
0005432873294	1217	Economy	42200.00
0005432675306	1217	Economy	38300.00
0005432675307	1217	Economy	38300.00
0005432873299	1217	Economy	38300.00
0005432693379	1217	Economy	38300.00
0005432675311	1217	Economy	38300.00
0005432693405	1217	Economy	38300.00
0005432693381	1217	Economy	38300.00
0005432873292	1217	Economy	38300.00
0005432675304	1217	Economy	38300.00
0005432873328	1217	Economy	38300.00
0005432675303	1217	Economy	38300.00
0005432693394	1217	Economy	38300.00
0005432693391	1217	Economy	38300.00
0005432693396	1217	Economy	38300.00
0005432693399	1217	Economy	38300.00
0005432693400	1217	Economy	38300.00
0005432693404	1217	Economy	38300.00
0005432693387	1217	Economy	38300.00
0005432675299	1217	Economy	38300.00
0005432693398	1217	Economy	38300.00
0005432693385	1217	Economy	38300.00
0005432693386	1217	Economy	38300.00
0005432693403	1217	Economy	38300.00
0005432693384	1217	Economy	38300.00
0005432693390	1217	Economy	38300.00
0005432873291	1217	Economy	38300.00
0005432677615	1217	Economy	38300.00
0005432693410	1217	Economy	38300.00
0005432675305	1217	Economy	38300.00
0005432873325	1217	Economy	38300.00
0005432675308	1217	Economy	38300.00
0005432677616	1217	Economy	38300.00
0005432693382	1217	Economy	38300.00
0005432873352	1217	Economy	38300.00
0005432693408	1217	Economy	38300.00
0005432693389	1217	Economy	38300.00
0005432675302	1217	Economy	38300.00
0005432675309	1217	Economy	38300.00
0005432693395	1217	Economy	38300.00
0005432873306	1217	Economy	38300.00
0005432693383	1217	Economy	38300.00
0005432873308	1217	Economy	38300.00
0005432675310	1217	Economy	38300.00
0005432693109	17484	Business	115000.00
0005432693042	17484	Business	115000.00
0005432873371	17484	Business	115000.00
0005432675236	17484	Business	115000.00
0005432675237	17484	Business	115000.00
0005432873374	17484	Business	115000.00
0005432873376	17484	Business	115000.00
0005432693251	17484	Business	115000.00
0005432675178	17484	Business	115000.00
0005432693053	17484	Business	115000.00
0005432873375	17484	Business	115000.00
0005432693054	17484	Business	115000.00
0005432675220	17484	Business	115000.00
0005432693108	17484	Business	115000.00
0005432693047	17484	Economy	38300.00
0005432693110	17484	Economy	38300.00
0005432693107	17484	Economy	38300.00
0005432693176	17484	Economy	38300.00
0005432693205	17484	Economy	38300.00
0005432675140	17484	Economy	38300.00
0005432677595	17484	Economy	38300.00
0005432693037	17484	Economy	42200.00
0005432693073	17484	Economy	42200.00
0005432873372	17484	Economy	42200.00
0005432675221	17484	Economy	38300.00
0005432677593	17484	Economy	38300.00
0005432693142	17484	Economy	38300.00
0005432677596	17484	Economy	38300.00
0005432675148	17484	Economy	38300.00
0005432693177	17484	Economy	38300.00
0005432675186	17484	Economy	38300.00
0005432693036	17484	Economy	38300.00
0005432693252	17484	Economy	38300.00
0005432693052	17484	Economy	38300.00
0005432693115	17484	Economy	38300.00
0005432677574	17484	Economy	38300.00
0005432675176	17484	Economy	38300.00
0005432693138	17484	Economy	38300.00
0005432677592	17484	Economy	38300.00
0005432693131	17484	Economy	38300.00
0005432693139	17484	Economy	38300.00
0005432675203	17484	Economy	38300.00
0005432693051	17484	Economy	38300.00
0005432675177	17484	Economy	38300.00
0005432693102	17484	Economy	38300.00
0005432693096	17484	Economy	38300.00
0005432693116	17484	Economy	38300.00
0005432675143	17484	Economy	38300.00
0005432693074	17484	Economy	38300.00
0005432873370	17484	Economy	38300.00
0005432693130	17484	Economy	38300.00
0005432873373	17484	Economy	38300.00
0005432677589	17484	Economy	38300.00
0005432693132	17484	Economy	38300.00
0005432675139	17484	Economy	38300.00
0005432675121	17484	Economy	38300.00
0005432693038	17484	Economy	38300.00
0005432675147	17484	Economy	38300.00
0005432693111	17484	Economy	38300.00
0005432677594	17484	Economy	38300.00
0005432693181	17484	Economy	38300.00
0005432675187	17484	Economy	38300.00
0005432675144	17484	Economy	38300.00
0005432693035	17484	Economy	38300.00
0005432693114	17484	Economy	38300.00
0005432693112	17484	Economy	38300.00
0005434435357	1107	Economy	15200.00
0005434435361	1107	Economy	15200.00
0005433156782	1107	Economy	13900.00
0005433156724	1107	Economy	13900.00
0005433156781	1107	Economy	13900.00
0005434435362	1107	Economy	13900.00
0005433156780	1107	Economy	13900.00
0005434435366	1107	Economy	13900.00
0005434435365	1107	Economy	13900.00
0005433156723	1107	Economy	13900.00
0005434435356	1107	Economy	13900.00
0005434435360	1107	Economy	13900.00
0005433156789	1107	Economy	13900.00
0005433156824	1107	Economy	13900.00
0005434435351	1107	Economy	13900.00
0005433156803	1107	Economy	13900.00
0005434435364	1107	Economy	13900.00
0005434435355	1107	Economy	13900.00
0005434435363	1107	Economy	13900.00
0005434435359	1107	Economy	13900.00
0005434435353	1107	Economy	13900.00
0005434435358	1107	Economy	13900.00
0005434435352	1107	Economy	13900.00
0005434435354	1107	Economy	13900.00
0005433156763	1107	Economy	13900.00
0005433156788	1107	Economy	13900.00
0005433156793	1107	Economy	13900.00
0005434435250	17298	Economy	15200.00
0005433156848	17298	Economy	13900.00
0005434435218	17298	Economy	13900.00
0005433156844	17298	Economy	13900.00
0005433156851	17298	Economy	13900.00
0005433156850	17298	Economy	13900.00
0005434435220	17298	Economy	13900.00
0005434435228	17298	Economy	13900.00
0005433156846	17298	Economy	13900.00
0005433156849	17298	Economy	13900.00
0005434435219	17298	Economy	13900.00
0005433156847	17298	Economy	13900.00
0005434435192	17298	Economy	13900.00
0005433156852	17298	Economy	13900.00
0005434435242	17298	Economy	13900.00
0005434435274	17298	Economy	13900.00
0005434435170	17298	Economy	13900.00
0005434435224	17298	Economy	13900.00
0005434435284	17298	Economy	13900.00
0005434435229	17298	Economy	13900.00
0005434435223	17298	Economy	13900.00
0005433156845	17298	Economy	13900.00
0005435086922	4107	Economy	8200.00
0005435086920	4107	Economy	7500.00
0005435928144	4107	Economy	7500.00
0005435928161	4107	Economy	7500.00
0005435928146	4107	Economy	7500.00
0005435086924	4107	Economy	7500.00
0005435928145	4107	Economy	7500.00
0005435928162	4107	Economy	7500.00
0005435086923	4107	Economy	7500.00
0005435086921	4107	Economy	7500.00
0005435086843	24410	Economy	8200.00
0005435086857	24410	Economy	8200.00
0005435928198	24410	Economy	7500.00
0005435086858	24410	Economy	7500.00
0005435086879	24410	Economy	7500.00
0005435928200	24410	Economy	7500.00
0005435086848	24410	Economy	7500.00
0005435086861	24410	Economy	7500.00
0005435928196	24410	Economy	7500.00
0005435086873	24410	Economy	7500.00
0005435086878	24410	Economy	7500.00
0005435086872	24410	Economy	7500.00
0005435086842	24410	Economy	7500.00
0005435928197	24410	Economy	7500.00
0005435928199	24410	Economy	7500.00
0005435551650	17001	Business	144300.00
0005435551662	17001	Business	144300.00
0005435098581	17001	Business	144300.00
0005435098579	17001	Business	144300.00
0005435551648	17001	Business	144300.00
0005435551656	17001	Business	144300.00
0005435551663	17001	Business	144300.00
0005435551651	17001	Business	144300.00
0005435551647	17001	Economy	52900.00
0005435098576	17001	Economy	48100.00
0005435551645	17001	Economy	48100.00
0005435551664	17001	Economy	48100.00
0005435551660	17001	Economy	48100.00
0005435551642	17001	Economy	48100.00
0005435098580	17001	Economy	48100.00
0005435098577	17001	Economy	48100.00
0005435551652	17001	Economy	48100.00
0005435551643	17001	Economy	48100.00
0005435551661	17001	Economy	48100.00
0005435551659	17001	Economy	48100.00
0005435551646	17001	Economy	48100.00
0005435098578	17001	Economy	48100.00
0005435551655	17001	Economy	48100.00
0005435551649	17001	Economy	48100.00
0005435098582	17001	Economy	48100.00
0005435551657	17001	Economy	48100.00
0005435551658	17001	Economy	48100.00
0005435551654	17001	Economy	48100.00
0005435551653	17001	Economy	48100.00
0005435551644	17001	Economy	48100.00
0005435907553	4866	Business	44200.00
0005435907552	4866	Business	44200.00
0005435907518	4866	Business	44200.00
0005433194870	4866	Economy	14700.00
0005434626065	4866	Economy	16200.00
0005435907519	4866	Economy	16200.00
0005434626069	4866	Economy	14700.00
0005434626070	4866	Economy	14700.00
0005434626075	4866	Economy	14700.00
0005434626073	4866	Economy	14700.00
0005434626071	4866	Economy	14700.00
0005434626067	4866	Economy	14700.00
0005434626068	4866	Economy	14700.00
0005434626074	4866	Economy	14700.00
0005434626072	4866	Economy	14700.00
0005434626066	4866	Economy	14700.00
0005434625987	32906	Business	44200.00
0005434626043	32906	Business	44200.00
0005435907562	32906	Economy	14700.00
0005434625972	32906	Economy	14700.00
0005434625994	32906	Economy	14700.00
0005434625977	32906	Economy	14700.00
0005434626044	32906	Economy	14700.00
0005434626020	32906	Economy	14700.00
0005434626042	32906	Economy	14700.00
0005435907561	32906	Economy	14700.00
0005434626004	32906	Economy	14700.00
0005434626045	32906	Economy	14700.00
0005435907558	32906	Economy	14700.00
0005434625971	32906	Economy	14700.00
0005435907559	32906	Economy	14700.00
0005434625932	32906	Economy	14700.00
0005435907560	32906	Economy	14700.00
0005435937435	13806	Economy	3400.00
0005435785479	13806	Economy	3400.00
0005435785416	13806	Economy	3400.00
0005435785415	13806	Economy	3100.00
0005435785403	13806	Economy	3100.00
0005435785333	13806	Economy	3100.00
0005435785381	13806	Economy	3100.00
0005435785346	13806	Economy	3100.00
0005435785458	13806	Economy	3100.00
0005435785433	13806	Economy	3100.00
0005435785263	13806	Economy	3100.00
0005435785342	13806	Economy	3100.00
0005435787360	13806	Economy	3100.00
0005435785424	13806	Economy	3100.00
0005435785402	13806	Economy	3100.00
0005435785418	13806	Economy	3100.00
0005435785500	13806	Economy	3100.00
0005435785315	13806	Economy	3100.00
0005435785317	13806	Economy	3100.00
0005435785488	13806	Economy	3100.00
0005435785343	13806	Economy	3100.00
0005435785501	13806	Economy	3100.00
0005435785443	13806	Economy	3100.00
0005435785414	13806	Economy	3100.00
0005435785494	13806	Economy	3100.00
0005435937433	13806	Economy	3100.00
0005435785461	13806	Economy	3100.00
0005435785300	13806	Economy	3100.00
0005435785527	13806	Economy	3100.00
0005435785534	13806	Economy	3100.00
0005435937436	13806	Economy	3100.00
0005432195716	13806	Economy	3100.00
0005435785493	13806	Economy	3100.00
0005435785341	13806	Economy	3100.00
0005435785345	13806	Economy	3100.00
0005435785413	13806	Economy	3100.00
0005435785168	13806	Economy	3100.00
0005435937434	13806	Economy	3100.00
0005432195717	13806	Economy	3100.00
0005435785480	13806	Economy	3100.00
0005435785316	13806	Economy	3100.00
0005435785718	27434	Economy	3400.00
0005435785715	27434	Economy	3400.00
0005435785712	27434	Economy	3400.00
0005435785703	27434	Economy	3100.00
0005435785700	27434	Economy	3100.00
0005435785693	27434	Economy	3100.00
0005435785698	27434	Economy	3100.00
0005435785687	27434	Economy	3100.00
0005432190669	27434	Economy	3100.00
0005435785694	27434	Economy	3100.00
0005435785695	27434	Economy	3100.00
0005435785709	27434	Economy	3100.00
0005432190668	27434	Economy	3100.00
0005435785692	27434	Economy	3100.00
0005435785688	27434	Economy	3100.00
0005435785697	27434	Economy	3100.00
0005435785706	27434	Economy	3100.00
0005435785714	27434	Economy	3100.00
0005435785711	27434	Economy	3100.00
0005435785716	27434	Economy	3100.00
0005435785699	27434	Economy	3100.00
0005435785710	27434	Economy	3100.00
0005435785690	27434	Economy	3100.00
0005435937393	27434	Economy	3100.00
0005432190667	27434	Economy	3100.00
0005435785691	27434	Economy	3100.00
0005435785701	27434	Economy	3100.00
0005435785685	27434	Economy	3100.00
0005435937401	27434	Economy	3100.00
0005435785705	27434	Economy	3100.00
0005435937390	27434	Economy	3100.00
0005435785702	27434	Economy	3100.00
0005435785708	27434	Economy	3100.00
0005435785719	27434	Economy	3100.00
0005435787376	27434	Economy	3100.00
0005435785713	27434	Economy	3100.00
0005435785704	27434	Economy	3100.00
0005435785696	27434	Economy	3100.00
0005435785686	27434	Economy	3100.00
0005435785707	27434	Economy	3100.00
0005435785717	27434	Economy	3100.00
0005435937392	27434	Economy	3100.00
0005435787375	27434	Economy	3100.00
0005435785689	27434	Economy	3100.00
0005434408016	20281	Business	12000.00
0005435311212	20281	Business	12000.00
0005434408081	20281	Business	12000.00
0005434407920	20281	Business	12000.00
0005435311203	20281	Business	12000.00
0005434408097	20281	Business	12000.00
0005435311204	20281	Business	12000.00
0005434407821	20281	Business	12000.00
0005434407972	20281	Business	12000.00
0005434407597	20281	Business	12000.00
0005435311211	20281	Business	12000.00
0005434407907	20281	Economy	4000.00
0005434407899	20281	Economy	4000.00
0005435311210	20281	Economy	4000.00
0005432058427	20281	Economy	4000.00
0005434407955	20281	Economy	4000.00
0005434407900	20281	Economy	4000.00
0005434408017	20281	Economy	4000.00
0005435311207	20281	Economy	4000.00
0005434407802	20281	Economy	4000.00
0005434408301	20281	Economy	4400.00
0005434408048	20281	Economy	4400.00
0005434408009	20281	Economy	4400.00
0005434407761	20281	Economy	4400.00
0005434407971	20281	Economy	4400.00
0005434407961	20281	Economy	4000.00
0005435311206	20281	Economy	4000.00
0005432058429	20281	Economy	4000.00
0005434408162	20281	Economy	4000.00
0005434408176	20281	Economy	4000.00
0005434407958	20281	Economy	4000.00
0005434407777	20281	Economy	4000.00
0005434407908	20281	Economy	4000.00
0005434407968	20281	Economy	4000.00
0005434407935	20281	Economy	4000.00
0005434407893	20281	Economy	4000.00
0005434407860	20281	Economy	4000.00
0005434408096	20281	Economy	4000.00
0005434407993	20281	Economy	4000.00
0005434407962	20281	Economy	4000.00
0005434408098	20281	Economy	4000.00
0005434408007	20281	Economy	4000.00
0005434407960	20281	Economy	4000.00
0005434408177	20281	Economy	4000.00
0005434408078	20281	Economy	4000.00
0005435311213	20281	Economy	4000.00
0005435311219	20281	Economy	4000.00
0005434407982	20281	Economy	4000.00
0005434408008	20281	Economy	4000.00
0005434407627	20281	Economy	4000.00
0005434407778	20281	Economy	4000.00
0005434408031	20281	Economy	4000.00
0005435311218	20281	Economy	4000.00
0005434407894	20281	Economy	4000.00
0005434407967	20281	Economy	4000.00
0005434407889	20281	Economy	4000.00
0005434407905	20281	Economy	4000.00
0005434407981	20281	Economy	4000.00
0005434407747	20281	Economy	4000.00
0005434407984	20281	Economy	4000.00
0005434408163	20281	Economy	4000.00
0005434408120	20281	Economy	4000.00
0005434408164	20281	Economy	4000.00
0005434407596	20281	Economy	4000.00
0005435311217	20281	Economy	4000.00
0005434407869	20281	Economy	4000.00
0005434408026	20281	Economy	4000.00
0005434408080	20281	Economy	4000.00
0005435311215	20281	Economy	4000.00
0005434407890	20281	Economy	4000.00
0005432058426	20281	Economy	4000.00
0005432058428	20281	Economy	4000.00
0005434407906	20281	Economy	4000.00
0005435311208	20281	Economy	4000.00
0005434407979	20281	Economy	4000.00
0005435311205	20281	Economy	4000.00
0005435311209	20281	Economy	4000.00
0005434407992	20281	Economy	4000.00
0005434407954	20281	Economy	4000.00
0005434408300	20281	Economy	4000.00
0005434407934	20281	Economy	4000.00
0005434407980	20281	Economy	4000.00
0005434407959	20281	Economy	4000.00
0005434407953	20281	Economy	4000.00
0005434408077	20281	Economy	4000.00
0005435311216	20281	Economy	4000.00
0005435311214	20281	Economy	4000.00
0005434407684	20281	Economy	4000.00
0005434407848	20281	Economy	4000.00
0005434408470	26960	Business	12000.00
0005434408506	26960	Business	12000.00
0005434408481	26960	Business	12000.00
0005434408447	26960	Business	12000.00
0005434408486	26960	Business	12000.00
0005434408499	26960	Business	12000.00
0005434408449	26960	Business	12000.00
0005434408473	26960	Business	12000.00
0005434408505	26960	Business	12000.00
0005434408502	26960	Business	12000.00
0005435311063	26960	Economy	4000.00
0005434408454	26960	Economy	4000.00
0005434408461	26960	Economy	4000.00
0005434408487	26960	Economy	4000.00
0005434408466	26960	Economy	4000.00
0005434408453	26960	Economy	4000.00
0005434408477	26960	Economy	4400.00
0005434408510	26960	Economy	4400.00
0005434408495	26960	Economy	4400.00
0005434408480	26960	Economy	4400.00
0005434408493	26960	Economy	4000.00
0005434408490	26960	Economy	4000.00
0005434408460	26960	Economy	4000.00
0005434408471	26960	Economy	4000.00
0005434408474	26960	Economy	4000.00
0005434408482	26960	Economy	4000.00
0005435311076	26960	Economy	4000.00
0005434408496	26960	Economy	4000.00
0005434408455	26960	Economy	4000.00
0005434408469	26960	Economy	4000.00
0005434408491	26960	Economy	4000.00
0005434408468	26960	Economy	4000.00
0005434408488	26960	Economy	4000.00
0005434408457	26960	Economy	4000.00
0005432154019	26960	Economy	4000.00
0005434408503	26960	Economy	4000.00
0005434408472	26960	Economy	4000.00
0005434408508	26960	Economy	4000.00
0005435311062	26960	Economy	4000.00
0005432154018	26960	Economy	4000.00
0005434408476	26960	Economy	4000.00
0005434408511	26960	Economy	4000.00
0005432154017	26960	Economy	4000.00
0005434408497	26960	Economy	4000.00
0005434408507	26960	Economy	4000.00
0005434408483	26960	Economy	4000.00
0005434408492	26960	Economy	4000.00
0005434408462	26960	Economy	4000.00
0005435311075	26960	Economy	4000.00
0005434408489	26960	Economy	4000.00
0005435311065	26960	Economy	4000.00
0005434408463	26960	Economy	4000.00
0005434408452	26960	Economy	4000.00
0005434408464	26960	Economy	4000.00
0005434408451	26960	Economy	4000.00
0005434408475	26960	Economy	4000.00
0005434408450	26960	Economy	4000.00
0005434408484	26960	Economy	4000.00
0005434408509	26960	Economy	4000.00
0005434408500	26960	Economy	4000.00
0005434408478	26960	Economy	4000.00
0005434408448	26960	Economy	4000.00
0005434408479	26960	Economy	4000.00
0005434408485	26960	Economy	4000.00
0005435311086	26960	Economy	4000.00
0005434408459	26960	Economy	4000.00
0005434408456	26960	Economy	4000.00
0005434408494	26960	Economy	4000.00
0005432154014	26960	Economy	4000.00
0005434408504	26960	Economy	4000.00
0005434408465	26960	Economy	4000.00
0005434408501	26960	Economy	4000.00
0005432154020	26960	Economy	4000.00
0005432154016	26960	Economy	4000.00
0005434408458	26960	Economy	4000.00
0005432154015	26960	Economy	4000.00
0005434408498	26960	Economy	4000.00
0005434408467	26960	Economy	4000.00
0005434319573	5729	Business	43300.00
0005434319575	5729	Business	43300.00
0005433123952	5729	Business	43300.00
0005434319563	5729	Business	43300.00
0005433123953	5729	Business	43300.00
0005434319569	5729	Business	43300.00
0005432109734	5729	Economy	14400.00
0005433123971	5729	Economy	14400.00
0005434319566	5729	Economy	14400.00
0005432109735	5729	Economy	14400.00
0005434319561	5729	Economy	14400.00
0005433123972	5729	Economy	15900.00
0005434319581	5729	Economy	15900.00
0005433123934	5729	Economy	14400.00
0005433123978	5729	Economy	14400.00
0005433123950	5729	Economy	14400.00
0005434319559	5729	Economy	14400.00
0005434319565	5729	Economy	14400.00
0005434319568	5729	Economy	14400.00
0005434311242	5729	Economy	14400.00
0005434319562	5729	Economy	14400.00
0005434319576	5729	Economy	14400.00
0005433124045	5729	Economy	14400.00
0005434319571	5729	Economy	14400.00
0005433124020	5729	Economy	14400.00
0005433123935	5729	Economy	14400.00
0005434319582	5729	Economy	14400.00
0005434319578	5729	Economy	14400.00
0005434319579	5729	Economy	14400.00
0005433123933	5729	Economy	14400.00
0005434319574	5729	Economy	14400.00
0005433124026	5729	Economy	14400.00
0005434319567	5729	Economy	14400.00
0005434319572	5729	Economy	14400.00
0005433123949	5729	Economy	14400.00
0005433124073	5729	Economy	14400.00
0005434311243	5729	Economy	14400.00
0005433123922	5729	Economy	14400.00
0005434319564	5729	Economy	14400.00
0005433124034	5729	Economy	14400.00
0005433124047	5729	Economy	14400.00
0005433123970	5729	Economy	14400.00
0005434319570	5729	Economy	14400.00
0005434319580	5729	Economy	14400.00
0005434319577	5729	Economy	14400.00
0005434319560	5729	Economy	14400.00
0005433124168	15690	Business	43300.00
0005433124169	15690	Business	43300.00
0005433124171	15690	Business	43300.00
0005434319447	15690	Business	43300.00
0005433124174	15690	Economy	14400.00
0005434319479	15690	Economy	14400.00
0005434319433	15690	Economy	15900.00
0005434311218	15690	Economy	15900.00
0005433124176	15690	Economy	14400.00
0005433124177	15690	Economy	14400.00
0005434319384	15690	Economy	14400.00
0005434319422	15690	Economy	14400.00
0005434319405	15690	Economy	14400.00
0005434319450	15690	Economy	14400.00
0005433124170	15690	Economy	14400.00
0005434319430	15690	Economy	14400.00
0005433124175	15690	Economy	14400.00
0005434319458	15690	Economy	14400.00
0005433124167	15690	Economy	14400.00
0005434319444	15690	Economy	14400.00
0005434311223	15690	Economy	14400.00
0005434319415	15690	Economy	14400.00
0005434319441	15690	Economy	14400.00
0005434312322	15690	Economy	14400.00
0005434319400	15690	Economy	14400.00
0005434319429	15690	Economy	14400.00
0005433124165	15690	Economy	14400.00
0005433124172	15690	Economy	14400.00
0005434319428	15690	Economy	14400.00
0005434319418	15690	Economy	14400.00
0005434319414	15690	Economy	14400.00
0005434319451	15690	Economy	14400.00
0005434319421	15690	Economy	14400.00
0005433124173	15690	Economy	14400.00
0005433124166	15690	Economy	14400.00
0005435220342	31744	Economy	15500.00
0005435220344	31744	Economy	15500.00
0005435220343	31744	Economy	15500.00
0005435219221	31744	Economy	15500.00
0005435220340	31744	Economy	15500.00
0005435219224	31744	Economy	15500.00
0005435220345	31744	Economy	15500.00
0005435219223	31744	Economy	15500.00
0005435219226	31744	Economy	15500.00
0005435219222	31744	Economy	15500.00
0005435220341	31744	Economy	15500.00
0005435219225	31744	Economy	15500.00
0005434484424	8969	Economy	27400.00
0005434189190	8969	Economy	24900.00
0005434484426	8969	Economy	24900.00
0005434484421	8969	Economy	24900.00
0005434189209	8969	Economy	24900.00
0005434484425	8969	Economy	24900.00
0005434484427	8969	Economy	24900.00
0005434484420	8969	Economy	24900.00
0005434484422	8969	Economy	24900.00
0005434189194	8969	Economy	24900.00
0005434484423	8969	Economy	24900.00
0005434484362	16630	Economy	24900.00
0005434189243	16630	Economy	24900.00
0005434484358	16630	Economy	24900.00
0005434189244	16630	Economy	24900.00
0005434484357	16630	Economy	24900.00
0005434484390	16630	Economy	24900.00
0005434484361	16630	Economy	24900.00
0005434484360	16630	Economy	24900.00
0005434189245	16630	Economy	24900.00
0005434189246	16630	Economy	24900.00
0005434189242	16630	Economy	24900.00
0005433124168	7582	Business	11100.00
0005433124172	7582	Business	11100.00
0005433124167	7582	Business	11100.00
0005433722225	7582	Economy	3700.00
0005433124171	7582	Economy	4100.00
0005433722228	7582	Economy	4100.00
0005433124177	7582	Economy	3700.00
0005433124169	7582	Economy	3700.00
0005433124176	7582	Economy	3700.00
0005433722229	7582	Economy	3700.00
0005433124166	7582	Economy	3700.00
0005433722227	7582	Economy	3700.00
0005433124170	7582	Economy	3700.00
0005433124165	7582	Economy	3700.00
0005433124174	7582	Economy	3700.00
0005433722199	7582	Economy	3700.00
0005433124175	7582	Economy	3700.00
0005433124173	7582	Economy	3700.00
0005433450224	7580	Business	11100.00
0005432721224	7580	Business	11100.00
0005433450208	7580	Business	11100.00
0005432693430	7580	Business	11100.00
0005432721198	7580	Business	11100.00
0005432693435	7580	Business	11100.00
0005433450223	7580	Business	11100.00
0005432721203	7580	Business	11100.00
0005432693420	7580	Business	11100.00
0005432693423	7580	Business	11100.00
0005433450226	7580	Business	11100.00
0005432721211	7580	Economy	3700.00
0005432721214	7580	Economy	3700.00
0005432693416	7580	Economy	3700.00
0005432693426	7580	Economy	3700.00
0005432721219	7580	Economy	3700.00
0005433450219	7580	Economy	3700.00
0005432693425	7580	Economy	3700.00
0005432693418	7580	Economy	3700.00
0005432693424	7580	Economy	4100.00
0005432721217	7580	Economy	4100.00
0005432721200	7580	Economy	4100.00
0005432071607	7580	Economy	4100.00
0005432693433	7580	Economy	3700.00
0005432693411	7580	Economy	3700.00
0005432693429	7580	Economy	3700.00
0005432693438	7580	Economy	3700.00
0005433450217	7580	Economy	3700.00
0005432693437	7580	Economy	3700.00
0005432721202	7580	Economy	3700.00
0005432721204	7580	Economy	3700.00
0005432721216	7580	Economy	3700.00
0005433450228	7580	Economy	3700.00
0005432693428	7580	Economy	3700.00
0005433450216	7580	Economy	3700.00
0005433450222	7580	Economy	3700.00
0005432721212	7580	Economy	3700.00
0005432693422	7580	Economy	3700.00
0005433450210	7580	Economy	3700.00
0005433450207	7580	Economy	3700.00
0005433450211	7580	Economy	3700.00
0005432693436	7580	Economy	3700.00
0005432693427	7580	Economy	3700.00
0005433450209	7580	Economy	3700.00
0005432071606	7580	Economy	3700.00
0005432721210	7580	Economy	3700.00
0005432693415	7580	Economy	3700.00
0005432721223	7580	Economy	3700.00
0005433450227	7580	Economy	3700.00
0005432693434	7580	Economy	3700.00
0005432721222	7580	Economy	3700.00
0005432693412	7580	Economy	3700.00
0005432721225	7580	Economy	3700.00
0005432693439	7580	Economy	3700.00
0005432721199	7580	Economy	3700.00
0005432071608	7580	Economy	3700.00
0005433450225	7580	Economy	3700.00
0005432721206	7580	Economy	3700.00
0005432721218	7580	Economy	3700.00
0005432693441	7580	Economy	3700.00
0005432721208	7580	Economy	3700.00
0005433450214	7580	Economy	3700.00
0005432693413	7580	Economy	3700.00
0005433450212	7580	Economy	3700.00
0005433450218	7580	Economy	3700.00
0005432693417	7580	Economy	3700.00
0005432721213	7580	Economy	3700.00
0005432721221	7580	Economy	3700.00
0005432721220	7580	Economy	3700.00
0005433450215	7580	Economy	3700.00
0005432721215	7580	Economy	3700.00
0005432693440	7580	Economy	3700.00
0005433450213	7580	Economy	3700.00
0005432693414	7580	Economy	3700.00
0005432693419	7580	Economy	3700.00
0005432693432	7580	Economy	3700.00
0005433450221	7580	Economy	3700.00
0005432721201	7580	Economy	3700.00
0005433450220	7580	Economy	3700.00
0005432721205	7580	Economy	3700.00
0005432721209	7580	Economy	3700.00
0005432721207	7580	Economy	3700.00
0005432693421	7580	Economy	3700.00
0005432693431	7580	Economy	3700.00
0005432693108	30335	Business	11100.00
0005432693110	30335	Business	11100.00
0005433450154	30335	Business	11100.00
0005432693181	30335	Business	11100.00
0005432693042	30335	Business	11100.00
0005433450077	30335	Business	11100.00
0005433450094	30335	Business	11100.00
0005433450051	30335	Business	11100.00
0005433450064	30335	Economy	3700.00
0005433450050	30335	Economy	3700.00
0005432693115	30335	Economy	3700.00
0005433450058	30335	Economy	3700.00
0005432693138	30335	Economy	3700.00
0005432693132	30335	Economy	3700.00
0005433450014	30335	Economy	4100.00
0005433450157	30335	Economy	4100.00
0005432693036	30335	Economy	4100.00
0005433450009	30335	Economy	3700.00
0005433450095	30335	Economy	3700.00
0005433450020	30335	Economy	3700.00
0005433450072	30335	Economy	3700.00
0005432693109	30335	Economy	3700.00
0005432693038	30335	Economy	3700.00
0005433450135	30335	Economy	3700.00
0005432693051	30335	Economy	3700.00
0005433449895	30335	Economy	3700.00
0005432693073	30335	Economy	3700.00
0005433449979	30335	Economy	3700.00
0005432693037	30335	Economy	3700.00
0005432693035	30335	Economy	3700.00
0005432693054	30335	Economy	3700.00
0005433449957	30335	Economy	3700.00
0005433450017	30335	Economy	3700.00
0005433450028	30335	Economy	3700.00
0005433450000	30335	Economy	3700.00
0005432693107	30335	Economy	3700.00
0005433450049	30335	Economy	3700.00
0005432693205	30335	Economy	3700.00
0005432693116	30335	Economy	3700.00
0005432693112	30335	Economy	3700.00
0005432693131	30335	Economy	3700.00
0005433450018	30335	Economy	3700.00
0005432693142	30335	Economy	3700.00
0005432693130	30335	Economy	3700.00
0005432693096	30335	Economy	3700.00
0005432693251	30335	Economy	3700.00
0005433449960	30335	Economy	3700.00
0005432693139	30335	Economy	3700.00
0005433450008	30335	Economy	3700.00
0005433450019	30335	Economy	3700.00
0005432693177	30335	Economy	3700.00
0005432693074	30335	Economy	3700.00
0005432693047	30335	Economy	3700.00
0005433450042	30335	Economy	3700.00
0005432693052	30335	Economy	3700.00
0005433450104	30335	Economy	3700.00
0005433450039	30335	Economy	3700.00
0005432693252	30335	Economy	3700.00
0005432693114	30335	Economy	3700.00
0005432693102	30335	Economy	3700.00
0005433450073	30335	Economy	3700.00
0005433450059	30335	Economy	3700.00
0005432693176	30335	Economy	3700.00
0005433450158	30335	Economy	3700.00
0005432693111	30335	Economy	3700.00
0005433449896	30335	Economy	3700.00
0005432693053	30335	Economy	3700.00
0005433123934	30336	Business	11100.00
0005433123935	30336	Business	11100.00
0005432721046	30336	Business	11100.00
0005433124045	30336	Business	11100.00
0005433123972	30336	Business	11100.00
0005432720932	30336	Business	11100.00
0005433123952	30336	Business	11100.00
0005433123978	30336	Economy	3700.00
0005432721036	30336	Economy	3700.00
0005432720902	30336	Economy	3700.00
0005433722298	30336	Economy	3700.00
0005432721187	30336	Economy	3700.00
0005432720978	30336	Economy	3700.00
0005432720848	30336	Economy	3700.00
0005433123950	30336	Economy	4100.00
0005432721031	30336	Economy	4100.00
0005433722296	30336	Economy	4100.00
0005432721143	30336	Economy	4100.00
0005432721066	30336	Economy	3700.00
0005433124026	30336	Economy	3700.00
0005432720963	30336	Economy	3700.00
0005433123953	30336	Economy	3700.00
0005433722301	30336	Economy	3700.00
0005432721010	30336	Economy	3700.00
0005432721086	30336	Economy	3700.00
0005433722295	30336	Economy	3700.00
0005432721080	30336	Economy	3700.00
0005432720850	30336	Economy	3700.00
0005432721002	30336	Economy	3700.00
0005433722297	30336	Economy	3700.00
0005432720948	30336	Economy	3700.00
0005432721037	30336	Economy	3700.00
0005432721145	30336	Economy	3700.00
0005433722294	30336	Economy	3700.00
0005433124073	30336	Economy	3700.00
0005432721003	30336	Economy	3700.00
0005432721032	30336	Economy	3700.00
0005433722300	30336	Economy	3700.00
0005432721062	30336	Economy	3700.00
0005433123933	30336	Economy	3700.00
0005433124047	30336	Economy	3700.00
0005433124020	30336	Economy	3700.00
0005433123970	30336	Economy	3700.00
0005432720849	30336	Economy	3700.00
0005432720945	30336	Economy	3700.00
0005432721076	30336	Economy	3700.00
0005433124034	30336	Economy	3700.00
0005432721047	30336	Economy	3700.00
0005432721063	30336	Economy	3700.00
0005432721081	30336	Economy	3700.00
0005433722302	30336	Economy	3700.00
0005432720944	30336	Economy	3700.00
0005433123949	30336	Economy	3700.00
0005432721065	30336	Economy	3700.00
0005433722299	30336	Economy	3700.00
0005433123922	30336	Economy	3700.00
0005432720996	30336	Economy	3700.00
0005433123971	30336	Economy	3700.00
0005432721011	30336	Economy	3700.00
0005433525159	1403	Business	70400.00
0005434586907	1403	Business	70400.00
0005434513609	1403	Business	70400.00
0005433525162	1403	Business	70400.00
0005433525168	1403	Business	70400.00
0005434586896	1403	Business	70400.00
0005433193119	1403	Business	70400.00
0005433193101	1403	Business	70400.00
0005434513610	1403	Business	70400.00
0005434586897	1403	Business	70400.00
0005434586901	1403	Economy	23500.00
0005433193102	1403	Economy	23500.00
0005433525167	1403	Economy	23500.00
0005434586918	1403	Economy	23500.00
0005434586905	1403	Economy	23500.00
0005433724856	1403	Economy	23500.00
0005433193112	1403	Economy	25800.00
0005433525165	1403	Economy	25800.00
0005434586898	1403	Economy	25800.00
0005433525158	1403	Economy	23500.00
0005433193070	1403	Economy	23500.00
0005434586894	1403	Economy	23500.00
0005433525161	1403	Economy	23500.00
0005434586916	1403	Economy	23500.00
0005434586908	1403	Economy	23500.00
0005434586899	1403	Economy	23500.00
0005434586895	1403	Economy	23500.00
0005434514997	1403	Economy	23500.00
0005434586912	1403	Economy	23500.00
0005432968852	1403	Economy	23500.00
0005433193100	1403	Economy	23500.00
0005434586903	1403	Economy	23500.00
0005433193099	1403	Economy	23500.00
0005433193118	1403	Economy	23500.00
0005434586906	1403	Economy	23500.00
0005434586919	1403	Economy	23500.00
0005432271037	1403	Economy	23500.00
0005432928001	1403	Economy	23500.00
0005434514998	1403	Economy	23500.00
0005433724859	1403	Economy	23500.00
0005433724860	1403	Economy	23500.00
0005434586915	1403	Economy	23500.00
0005432928003	1403	Economy	23500.00
0005434514996	1403	Economy	23500.00
0005434514999	1403	Economy	23500.00
0005433193050	1403	Economy	23500.00
0005434586914	1403	Economy	23500.00
0005434586910	1403	Economy	23500.00
0005433724857	1403	Economy	23500.00
0005434586911	1403	Economy	23500.00
0005434586917	1403	Economy	23500.00
0005433193113	1403	Economy	23500.00
0005433525160	1403	Economy	23500.00
0005433525166	1403	Economy	23500.00
0005434586900	1403	Economy	23500.00
0005433724858	1403	Economy	23500.00
0005433193129	1403	Economy	23500.00
0005434586902	1403	Economy	23500.00
0005433525164	1403	Economy	23500.00
0005434586913	1403	Economy	23500.00
0005433525163	1403	Economy	23500.00
0005433193051	1403	Economy	23500.00
0005433193082	1403	Economy	23500.00
0005434586909	1403	Economy	23500.00
0005434586904	1403	Economy	23500.00
0005432968851	1403	Economy	23500.00
0005434586705	18494	Business	70400.00
0005433524986	18494	Business	70400.00
0005434586641	18494	Business	70400.00
0005433193193	18494	Business	70400.00
0005434586739	18494	Business	70400.00
0005433524994	18494	Business	70400.00
0005433193204	18494	Business	70400.00
0005433193202	18494	Business	70400.00
0005434514976	18494	Economy	23500.00
0005433193194	18494	Economy	23500.00
0005432928041	18494	Economy	23500.00
0005434586719	18494	Economy	23500.00
0005433525083	18494	Economy	23500.00
0005434586605	18494	Economy	23500.00
0005433525090	18494	Economy	25800.00
0005434586560	18494	Economy	25800.00
0005433193205	18494	Economy	25800.00
0005434586612	18494	Economy	23500.00
0005433193192	18494	Economy	23500.00
0005434586689	18494	Economy	23500.00
0005433193200	18494	Economy	23500.00
0005432928045	18494	Economy	23500.00
0005433524987	18494	Economy	23500.00
0005433724806	18494	Economy	23500.00
0005434586683	18494	Economy	23500.00
0005434586652	18494	Economy	23500.00
0005433193196	18494	Economy	23500.00
0005434586688	18494	Economy	23500.00
0005433525051	18494	Economy	23500.00
0005434514980	18494	Economy	23500.00
0005433724822	18494	Economy	23500.00
0005434586738	18494	Economy	23500.00
0005434586653	18494	Economy	23500.00
0005433724814	18494	Economy	23500.00
0005432928042	18494	Economy	23500.00
0005433193197	18494	Economy	23500.00
0005433193198	18494	Economy	23500.00
0005433724813	18494	Economy	23500.00
0005433193203	18494	Economy	23500.00
0005433525092	18494	Economy	23500.00
0005432928043	18494	Economy	23500.00
0005433525050	18494	Economy	23500.00
0005432928040	18494	Economy	23500.00
0005433193199	18494	Economy	23500.00
0005433525084	18494	Economy	23500.00
0005432968865	18494	Economy	23500.00
0005432968866	18494	Economy	23500.00
0005434514977	18494	Economy	23500.00
0005433193201	18494	Economy	23500.00
0005433193195	18494	Economy	23500.00
0005433525091	18494	Economy	23500.00
0005434586685	18494	Economy	23500.00
0005432928044	18494	Economy	23500.00
0005434344588	11447	Economy	4300.00
0005434344573	11447	Economy	4300.00
0005434344585	11447	Economy	4300.00
0005434344590	11447	Economy	4300.00
0005434344598	11447	Economy	4000.00
0005434344567	11447	Economy	4000.00
0005434344581	11447	Economy	4000.00
0005434344577	11447	Economy	4000.00
0005435302204	11447	Economy	4000.00
0005434344570	11447	Economy	4000.00
0005434344574	11447	Economy	4000.00
0005434344599	11447	Economy	4000.00
0005434344597	11447	Economy	4000.00
0005435302211	11447	Economy	4000.00
0005434142654	11447	Economy	4000.00
0005434344591	11447	Economy	4000.00
0005435302219	11447	Economy	4000.00
0005434344583	11447	Economy	4000.00
0005434344584	11447	Economy	4000.00
0005434344582	11447	Economy	4000.00
0005434344580	11447	Economy	4000.00
0005435302198	11447	Economy	4000.00
0005434344594	11447	Economy	4000.00
0005434344586	11447	Economy	4000.00
0005434344578	11447	Economy	4000.00
0005434344572	11447	Economy	4000.00
0005434344593	11447	Economy	4000.00
0005434344569	11447	Economy	4000.00
0005434142655	11447	Economy	4000.00
0005434344568	11447	Economy	4000.00
0005434344595	11447	Economy	4000.00
0005434344579	11447	Economy	4000.00
0005434344576	11447	Economy	4000.00
0005434142656	11447	Economy	4000.00
0005434344575	11447	Economy	4000.00
0005434344592	11447	Economy	4000.00
0005435302197	11447	Economy	4000.00
0005435302208	11447	Economy	4000.00
0005434344596	11447	Economy	4000.00
0005434344589	11447	Economy	4000.00
0005434142657	11447	Economy	4000.00
0005434344587	11447	Economy	4000.00
0005434344571	11447	Economy	4000.00
0005435302216	11447	Economy	4000.00
0005435304213	29763	Economy	4300.00
0005435305037	29763	Economy	4300.00
0005435305036	29763	Economy	4300.00
0005434344359	29763	Economy	4000.00
0005434344411	29763	Economy	4000.00
0005434344188	29763	Economy	4000.00
0005435304214	29763	Economy	4000.00
0005435304211	29763	Economy	4000.00
0005434344316	29763	Economy	4000.00
0005434344295	29763	Economy	4000.00
0005434142617	29763	Economy	4000.00
0005434344361	29763	Economy	4000.00
0005434344159	29763	Economy	4000.00
0005434344189	29763	Economy	4000.00
0005435304212	29763	Economy	4000.00
0005434344323	29763	Economy	4000.00
0005434344226	29763	Economy	4000.00
0005435304210	29763	Economy	4000.00
0005434344150	29763	Economy	4000.00
0005434344227	29763	Economy	4000.00
0005434344360	29763	Economy	4000.00
0005434344219	29763	Economy	4000.00
0005434344466	29763	Economy	4000.00
0005434344286	29763	Economy	4000.00
0005434344337	29763	Economy	4000.00
0005434344248	29763	Economy	4000.00
0005434344342	29763	Economy	4000.00
0005434344220	29763	Economy	4000.00
0005434344095	29763	Economy	4000.00
0005434142616	29763	Economy	4000.00
0005434344196	29763	Economy	4000.00
0005434344111	29763	Economy	4000.00
0005434344151	29763	Economy	4000.00
0005434344283	29763	Economy	4000.00
0005434344317	29763	Economy	4000.00
0005434344324	29763	Economy	4000.00
0005434344228	29763	Economy	4000.00
0005434344247	29763	Economy	4000.00
0005435304209	29763	Economy	4000.00
0005434142610	29763	Economy	4000.00
0005434344208	29763	Economy	4000.00
0005434344404	29763	Economy	4000.00
0005434344336	29763	Economy	4000.00
0005435824945	1269	Business	199800.00
0005433415707	1269	Business	199800.00
0005435824943	1269	Business	199800.00
0005433415700	1269	Business	199800.00
0005433415729	1269	Business	199800.00
0005433415766	1269	Business	199800.00
0005433415677	1269	Business	199800.00
0005435824934	1269	Business	199800.00
0005435824936	1269	Business	199800.00
0005435824923	1269	Economy	66600.00
0005435824941	1269	Economy	66600.00
0005435824926	1269	Economy	66600.00
0005435824921	1269	Economy	66600.00
0005433415645	1269	Economy	73200.00
0005435824939	1269	Economy	73200.00
0005435824946	1269	Economy	66600.00
0005433415737	1269	Economy	73200.00
0005433415748	1269	Economy	66600.00
0005435824925	1269	Economy	66600.00
0005435824935	1269	Economy	66600.00
0005435824937	1269	Economy	66600.00
0005435824932	1269	Economy	66600.00
0005435824942	1269	Economy	66600.00
0005433415675	1269	Economy	66600.00
0005435824933	1269	Economy	66600.00
0005435824938	1269	Economy	66600.00
0005433415747	1269	Economy	66600.00
0005435824931	1269	Economy	66600.00
0005433415708	1269	Economy	66600.00
0005435824947	1269	Economy	66600.00
0005435824944	1269	Economy	66600.00
0005432284593	1269	Economy	66600.00
0005435824929	1269	Economy	66600.00
0005435824930	1269	Economy	66600.00
0005432284594	1269	Economy	66600.00
0005435824922	1269	Economy	66600.00
0005433415704	1269	Economy	66600.00
0005433415705	1269	Economy	66600.00
0005433415736	1269	Economy	66600.00
0005432284592	1269	Economy	66600.00
0005435824924	1269	Economy	66600.00
0005435824927	1269	Economy	66600.00
0005435824940	1269	Economy	66600.00
0005433415706	1269	Economy	66600.00
0005435824928	1269	Economy	66600.00
0005433415842	17984	Business	199800.00
0005435824760	17984	Business	199800.00
0005435824800	17984	Business	199800.00
0005435824753	17984	Business	199800.00
0005435824692	17984	Business	199800.00
0005435824706	17984	Business	199800.00
0005433415840	17984	Business	199800.00
0005435824662	17984	Business	199800.00
0005435824652	17984	Economy	66600.00
0005433415836	17984	Economy	66600.00
0005435824759	17984	Economy	73200.00
0005435824691	17984	Economy	66600.00
0005435824650	17984	Economy	66600.00
0005435824807	17984	Economy	66600.00
0005435824664	17984	Economy	66600.00
0005435824702	17984	Economy	66600.00
0005433415839	17984	Economy	66600.00
0005433415838	17984	Economy	66600.00
0005435824607	17984	Economy	66600.00
0005433415850	17984	Economy	66600.00
0005435824731	17984	Economy	66600.00
0005433415837	17984	Economy	66600.00
0005435824685	17984	Economy	66600.00
0005435824663	17984	Economy	66600.00
0005433415845	17984	Economy	66600.00
0005435824635	17984	Economy	66600.00
0005433415846	17984	Economy	66600.00
0005435824689	17984	Economy	66600.00
0005435824620	17984	Economy	66600.00
0005433415844	17984	Economy	66600.00
0005433415848	17984	Economy	66600.00
0005433415851	17984	Economy	66600.00
0005433415843	17984	Economy	66600.00
0005433415847	17984	Economy	66600.00
0005435824754	17984	Economy	66600.00
0005433415849	17984	Economy	66600.00
0005435824688	17984	Economy	66600.00
0005433415835	17984	Economy	66600.00
0005433415841	17984	Economy	66600.00
0005432784427	5662	Business	27800.00
0005432784433	5662	Business	27800.00
0005435242972	5662	Business	27800.00
0005432784415	5662	Business	27800.00
0005432784393	5662	Business	27800.00
0005432784386	5662	Business	27800.00
0005432144024	5662	Business	27800.00
0005432784418	5662	Business	27800.00
0005432784432	5662	Business	27800.00
0005435242944	5662	Business	27800.00
0005432784420	5662	Business	27800.00
0005432784421	5662	Economy	9300.00
0005435476780	5662	Economy	9300.00
0005435476778	5662	Economy	9300.00
0005435242973	5662	Economy	9300.00
0005432784407	5662	Economy	9300.00
0005432784425	5662	Economy	9300.00
0005432784419	5662	Economy	9300.00
0005432784422	5662	Economy	9300.00
0005432784390	5662	Economy	9300.00
0005432784423	5662	Economy	10200.00
0005432784396	5662	Economy	10200.00
0005435242930	5662	Economy	10200.00
0005432784416	5662	Economy	10200.00
0005435476798	5662	Economy	9300.00
0005432784384	5662	Economy	9300.00
0005432784428	5662	Economy	9300.00
0005432784405	5662	Economy	9300.00
0005432144026	5662	Economy	9300.00
0005435242913	5662	Economy	9300.00
0005432784424	5662	Economy	9300.00
0005432144023	5662	Economy	9300.00
0005435242967	5662	Economy	9300.00
0005432784387	5662	Economy	9300.00
0005432784385	5662	Economy	9300.00
0005432784435	5662	Economy	9300.00
0005432784413	5662	Economy	9300.00
0005432784411	5662	Economy	9300.00
0005432784389	5662	Economy	9300.00
0005432784399	5662	Economy	9300.00
0005435476800	5662	Economy	9300.00
0005432784382	5662	Economy	9300.00
0005432144025	5662	Economy	9300.00
0005435242906	5662	Economy	9300.00
0005435242928	5662	Economy	9300.00
0005432784394	5662	Economy	9300.00
0005435242942	5662	Economy	9300.00
0005432784397	5662	Economy	9300.00
0005432784409	5662	Economy	9300.00
0005432784395	5662	Economy	9300.00
0005432784403	5662	Economy	9300.00
0005435476799	5662	Economy	9300.00
0005432784434	5662	Economy	9300.00
0005435242929	5662	Economy	9300.00
0005432784426	5662	Economy	9300.00
0005432784406	5662	Economy	9300.00
0005432784401	5662	Economy	9300.00
0005435476750	5662	Economy	9300.00
0005432784388	5662	Economy	9300.00
0005432784410	5662	Economy	9300.00
0005432784402	5662	Economy	9300.00
0005435476755	5662	Economy	9300.00
0005432784430	5662	Economy	9300.00
0005432784404	5662	Economy	9300.00
0005435242982	5662	Economy	9300.00
0005432784398	5662	Economy	9300.00
0005432784391	5662	Economy	9300.00
0005432784429	5662	Economy	9300.00
0005432784392	5662	Economy	9300.00
0005432784383	5662	Economy	9300.00
0005435242957	5662	Economy	9300.00
0005432784408	5662	Economy	9300.00
0005432784400	5662	Economy	9300.00
0005432784417	5662	Economy	9300.00
0005432784414	5662	Economy	9300.00
0005435476736	5662	Economy	9300.00
0005435476751	5662	Economy	9300.00
0005435242974	5662	Economy	9300.00
0005432784431	5662	Economy	9300.00
0005435242821	5662	Economy	9300.00
0005432784412	5662	Economy	9300.00
0005432783865	15366	Business	27800.00
0005435243143	15366	Business	27800.00
0005432783596	15366	Business	27800.00
0005432783955	15366	Business	27800.00
0005435243130	15366	Business	27800.00
0005435243147	15366	Business	27800.00
0005435243148	15366	Business	27800.00
0005432783753	15366	Business	27800.00
0005432783960	15366	Business	27800.00
0005435243149	15366	Business	27800.00
0005432783595	15366	Business	27800.00
0005435243132	15366	Business	27800.00
0005435243145	15366	Economy	9300.00
0005435243146	15366	Economy	9300.00
0005435243144	15366	Economy	9300.00
0005432783795	15366	Economy	9300.00
0005432783874	15366	Economy	9300.00
0005432784072	15366	Economy	9300.00
0005432784026	15366	Economy	9300.00
0005432783869	15366	Economy	9300.00
0005432783624	15366	Economy	9300.00
0005432784002	15366	Economy	9300.00
0005432783776	15366	Economy	10200.00
0005432783748	15366	Economy	10200.00
0005432783947	15366	Economy	10200.00
0005432783786	15366	Economy	10200.00
0005432783809	15366	Economy	10200.00
0005432784151	15366	Economy	9300.00
0005435243152	15366	Economy	9300.00
0005432784061	15366	Economy	9300.00
0005432784128	15366	Economy	9300.00
0005435243136	15366	Economy	9300.00
0005435243138	15366	Economy	9300.00
0005435243141	15366	Economy	9300.00
0005435243142	15366	Economy	9300.00
0005435476839	15366	Economy	9300.00
0005435243154	15366	Economy	9300.00
0005432784146	15366	Economy	9300.00
0005435243156	15366	Economy	9300.00
0005435243150	15366	Economy	9300.00
0005435476841	15366	Economy	9300.00
0005435243153	15366	Economy	9300.00
0005432783978	15366	Economy	9300.00
0005432783914	15366	Economy	9300.00
0005432783623	15366	Economy	9300.00
0005432783793	15366	Economy	9300.00
0005432783758	15366	Economy	9300.00
0005435243133	15366	Economy	9300.00
0005432783944	15366	Economy	9300.00
0005432783959	15366	Economy	9300.00
0005432783834	15366	Economy	9300.00
0005432784057	15366	Economy	9300.00
0005432783803	15366	Economy	9300.00
0005432783618	15366	Economy	9300.00
0005432783825	15366	Economy	9300.00
0005432783757	15366	Economy	9300.00
0005432783749	15366	Economy	9300.00
0005432783884	15366	Economy	9300.00
0005435243134	15366	Economy	9300.00
0005435476840	15366	Economy	9300.00
0005432783787	15366	Economy	9300.00
0005435243140	15366	Economy	9300.00
0005432783979	15366	Economy	9300.00
0005432783754	15366	Economy	9300.00
0005432783932	15366	Economy	9300.00
0005432783954	15366	Economy	9300.00
0005435243131	15366	Economy	9300.00
0005435243137	15366	Economy	9300.00
0005435243129	15366	Economy	9300.00
0005432784008	15366	Economy	9300.00
0005432784195	15366	Economy	9300.00
0005432783919	15366	Economy	9300.00
0005432783980	15366	Economy	9300.00
0005432784001	15366	Economy	9300.00
0005432784060	15366	Economy	9300.00
0005432783873	15366	Economy	9300.00
0005432783810	15366	Economy	9300.00
0005432783782	15366	Economy	9300.00
0005432783860	15366	Economy	9300.00
0005432784110	15366	Economy	9300.00
0005432783823	15366	Economy	9300.00
0005432783956	15366	Economy	9300.00
0005435243135	15366	Economy	9300.00
0005432783920	15366	Economy	9300.00
0005435243151	15366	Economy	9300.00
0005435243139	15366	Economy	9300.00
0005432783934	15366	Economy	9300.00
0005432783958	15366	Economy	9300.00
0005432783836	15366	Economy	9300.00
0005435243155	15366	Economy	9300.00
0005432783933	15366	Economy	9300.00
0005432783864	15366	Economy	9300.00
0005435243157	15366	Economy	9300.00
0005432783706	15366	Economy	9300.00
0005432783946	15366	Economy	9300.00
0005432784025	15366	Economy	9300.00
0005432848477	4382	Economy	7000.00
0005432848474	4382	Economy	7000.00
0005435850919	4382	Economy	7000.00
0005432848476	4382	Economy	6300.00
0005432848478	4382	Economy	6300.00
0005432848483	4382	Economy	6300.00
0005432848480	4382	Economy	6300.00
0005432848473	4382	Economy	6300.00
0005435850976	4382	Economy	6300.00
0005435850888	4382	Economy	6300.00
0005435850945	4382	Economy	6300.00
0005435850971	4382	Economy	6300.00
0005435850940	4382	Economy	6300.00
0005432848482	4382	Economy	6300.00
0005435850968	4382	Economy	6300.00
0005432848471	4382	Economy	6300.00
0005435850975	4382	Economy	6300.00
0005432848479	4382	Economy	6300.00
0005432848472	4382	Economy	6300.00
0005434462815	4382	Economy	6300.00
0005432848484	4382	Economy	6300.00
0005432848475	4382	Economy	6300.00
0005432848486	4382	Economy	6300.00
0005435850944	4382	Economy	6300.00
0005432848485	4382	Economy	6300.00
0005432848481	4382	Economy	6300.00
0005434463954	4382	Economy	6300.00
0005435851018	28885	Economy	7000.00
0005432848356	28885	Economy	7000.00
0005434463932	28885	Economy	6300.00
0005432848347	28885	Economy	6300.00
0005434463933	28885	Economy	6300.00
0005435851017	28885	Economy	6300.00
0005432848333	28885	Economy	6300.00
0005435851014	28885	Economy	6300.00
0005435851011	28885	Economy	6300.00
0005432848351	28885	Economy	6300.00
0005432848372	28885	Economy	6300.00
0005435851012	28885	Economy	6300.00
0005432848344	28885	Economy	6300.00
0005435851015	28885	Economy	6300.00
0005432848312	28885	Economy	6300.00
0005434463930	28885	Economy	6300.00
0005435851016	28885	Economy	6300.00
0005434463931	28885	Economy	6300.00
0005432848364	28885	Economy	6300.00
0005432848355	28885	Economy	6300.00
0005432848353	28885	Economy	6300.00
0005435851013	28885	Economy	6300.00
0005432848342	28885	Economy	6300.00
0005434443889	6266	Business	11900.00
0005433497317	6266	Business	11900.00
0005432075270	6266	Business	11900.00
0005434443892	6266	Business	11900.00
0005434443901	6266	Business	11900.00
0005434443893	6266	Business	11900.00
0005434926179	6266	Business	11900.00
0005434443888	6266	Business	11900.00
0005434926178	6266	Business	11900.00
0005433497338	6266	Economy	4000.00
0005434443891	6266	Economy	4000.00
0005434926181	6266	Economy	4000.00
0005433497321	6266	Economy	4000.00
0005434443890	6266	Economy	4000.00
0005434443895	6266	Economy	4000.00
0005434443899	6266	Economy	4400.00
0005433497339	6266	Economy	4400.00
0005434443896	6266	Economy	4400.00
0005433497319	6266	Economy	4000.00
0005434926177	6266	Economy	4000.00
0005433497340	6266	Economy	4000.00
0005433497328	6266	Economy	4000.00
0005434926175	6266	Economy	4000.00
0005433497343	6266	Economy	4000.00
0005433497325	6266	Economy	4000.00
0005433497329	6266	Economy	4000.00
0005433497327	6266	Economy	4000.00
0005434926187	6266	Economy	4000.00
0005433497336	6266	Economy	4000.00
0005434926185	6266	Economy	4000.00
0005434926176	6266	Economy	4000.00
0005433497341	6266	Economy	4000.00
0005434926169	6266	Economy	4000.00
0005434926180	6266	Economy	4000.00
0005434926173	6266	Economy	4000.00
0005433497318	6266	Economy	4000.00
0005434443898	6266	Economy	4000.00
0005434926184	6266	Economy	4000.00
0005434926171	6266	Economy	4000.00
0005434926182	6266	Economy	4000.00
0005433497344	6266	Economy	4000.00
0005434443887	6266	Economy	4000.00
0005433497332	6266	Economy	4000.00
0005434926168	6266	Economy	4000.00
0005434926174	6266	Economy	4000.00
0005433497323	6266	Economy	4000.00
0005432075269	6266	Economy	4000.00
0005433497345	6266	Economy	4000.00
0005433497334	6266	Economy	4000.00
0005433497322	6266	Economy	4000.00
0005433497331	6266	Economy	4000.00
0005433497324	6266	Economy	4000.00
0005433497333	6266	Economy	4000.00
0005433497326	6266	Economy	4000.00
0005434926170	6266	Economy	4000.00
0005434926186	6266	Economy	4000.00
0005433497330	6266	Economy	4000.00
0005434926172	6266	Economy	4000.00
0005433497315	6266	Economy	4000.00
0005434443900	6266	Economy	4000.00
0005434926167	6266	Economy	4000.00
0005433497342	6266	Economy	4000.00
0005432075271	6266	Economy	4000.00
0005433497337	6266	Economy	4000.00
0005434926166	6266	Economy	4000.00
0005433497346	6266	Economy	4000.00
0005434926183	6266	Economy	4000.00
0005433497316	6266	Economy	4000.00
0005434443902	6266	Economy	4000.00
0005433497320	6266	Economy	4000.00
0005433497335	6266	Economy	4000.00
0005434443897	6266	Economy	4000.00
0005433497314	6266	Economy	4000.00
0005434443894	6266	Economy	4000.00
0005434443645	20328	Business	11900.00
0005434443742	20328	Business	11900.00
0005434925750	20328	Business	11900.00
0005434443755	20328	Business	11900.00
0005433497161	20328	Business	11900.00
0005433497206	20328	Business	11900.00
0005433497092	20328	Business	11900.00
0005434925857	20328	Business	11900.00
0005434443731	20328	Business	11900.00
0005433497162	20328	Business	11900.00
0005433497155	20328	Business	11900.00
0005434443744	20328	Economy	4000.00
0005434925793	20328	Economy	4000.00
0005433496990	20328	Economy	4000.00
0005433497269	20328	Economy	4000.00
0005433497083	20328	Economy	4000.00
0005433497026	20328	Economy	4000.00
0005434925800	20328	Economy	4000.00
0005433497008	20328	Economy	4000.00
0005434443741	20328	Economy	4400.00
0005434925805	20328	Economy	4400.00
0005434925960	20328	Economy	4400.00
0005434443707	20328	Economy	4400.00
0005434443743	20328	Economy	4000.00
0005434925848	20328	Economy	4000.00
0005433497187	20328	Economy	4000.00
0005434925921	20328	Economy	4000.00
0005433497057	20328	Economy	4000.00
0005434925891	20328	Economy	4000.00
0005434925815	20328	Economy	4000.00
0005433497079	20328	Economy	4000.00
0005433497090	20328	Economy	4000.00
0005433497002	20328	Economy	4000.00
0005434925947	20328	Economy	4000.00
0005433497186	20328	Economy	4000.00
0005434443745	20328	Economy	4000.00
0005434925874	20328	Economy	4000.00
0005434925691	20328	Economy	4000.00
0005433496992	20328	Economy	4000.00
0005433497154	20328	Economy	4000.00
0005434925812	20328	Economy	4000.00
0005434925946	20328	Economy	4000.00
0005434925789	20328	Economy	4000.00
0005433497134	20328	Economy	4000.00
0005434443749	20328	Economy	4000.00
0005434925792	20328	Economy	4000.00
0005434925867	20328	Economy	4000.00
0005433497270	20328	Economy	4000.00
0005433497118	20328	Economy	4000.00
0005434925971	20328	Economy	4000.00
0005434925845	20328	Economy	4000.00
0005434925859	20328	Economy	4000.00
0005434925801	20328	Economy	4000.00
0005433497207	20328	Economy	4000.00
0005433497119	20328	Economy	4000.00
0005434925922	20328	Economy	4000.00
0005434443719	20328	Economy	4000.00
0005433497102	20328	Economy	4000.00
0005433497078	20328	Economy	4000.00
0005433496993	20328	Economy	4000.00
0005434443781	20328	Economy	4000.00
0005434443663	20328	Economy	4000.00
0005434925761	20328	Economy	4000.00
0005433497097	20328	Economy	4000.00
0005434925814	20328	Economy	4000.00
0005434925766	20328	Economy	4000.00
0005434925804	20328	Economy	4000.00
0005433497133	20328	Economy	4000.00
0005434925826	20328	Economy	4000.00
0005433497085	20328	Economy	4000.00
0005433497101	20328	Economy	4000.00
0005433497205	20328	Economy	4000.00
0005434925961	20328	Economy	4000.00
0005434925858	20328	Economy	4000.00
0005434925744	20328	Economy	4000.00
0005434925883	20328	Economy	4000.00
0005434925899	20328	Economy	4000.00
0005434925920	20328	Economy	4000.00
0005434443706	20328	Economy	4000.00
0005433497086	20328	Economy	4000.00
0005433497100	20328	Economy	4000.00
0005434925892	20328	Economy	4000.00
0005434925794	20328	Economy	4000.00
0005434925847	20328	Economy	4000.00
0005432784028	12192	Business	41200.00
0005435243167	12192	Business	41200.00
0005432783797	12192	Business	41200.00
0005432784069	12192	Business	41200.00
0005432783991	12192	Business	41200.00
0005432783871	12192	Business	41200.00
0005432783896	12192	Business	41200.00
0005432783964	12192	Business	41200.00
0005435243177	12192	Business	41200.00
0005432784070	12192	Business	41200.00
0005435243168	12192	Business	41200.00
0005432783837	12192	Economy	13700.00
0005432783840	12192	Economy	13700.00
0005432783900	12192	Economy	13700.00
0005435243183	12192	Economy	13700.00
0005432783804	12192	Economy	13700.00
0005435243178	12192	Economy	13700.00
0005435243184	12192	Economy	13700.00
0005432783818	12192	Economy	13700.00
0005432783893	12192	Economy	13700.00
0005432783657	12192	Economy	13700.00
0005435243174	12192	Economy	15100.00
0005432783731	12192	Economy	15100.00
0005432783984	12192	Economy	15100.00
0005432784139	12192	Economy	13700.00
0005432783915	12192	Economy	13700.00
0005432784137	12192	Economy	13700.00
0005435243172	12192	Economy	13700.00
0005432783902	12192	Economy	13700.00
0005432783889	12192	Economy	13700.00
0005432783817	12192	Economy	13700.00
0005432783791	12192	Economy	13700.00
0005435243171	12192	Economy	13700.00
0005435243160	12192	Economy	13700.00
0005432784071	12192	Economy	13700.00
0005432783983	12192	Economy	13700.00
0005432784020	12192	Economy	13700.00
0005432784135	12192	Economy	13700.00
0005432783901	12192	Economy	13700.00
0005432783953	12192	Economy	13700.00
0005432783986	12192	Economy	13700.00
0005435243159	12192	Economy	13700.00
0005435243162	12192	Economy	13700.00
0005432783890	12192	Economy	13700.00
0005435243170	12192	Economy	13700.00
0005432783808	12192	Economy	13700.00
0005432783841	12192	Economy	13700.00
0005435243182	12192	Economy	13700.00
0005432784150	12192	Economy	13700.00
0005432783899	12192	Economy	13700.00
0005435243161	12192	Economy	13700.00
0005435243166	12192	Economy	13700.00
0005432783894	12192	Economy	13700.00
0005432784019	12192	Economy	13700.00
0005432784010	12192	Economy	13700.00
0005432783805	12192	Economy	13700.00
0005432783730	12192	Economy	13700.00
0005432783658	12192	Economy	13700.00
0005432784056	12192	Economy	13700.00
0005435243173	12192	Economy	13700.00
0005435243179	12192	Economy	13700.00
0005432783792	12192	Economy	13700.00
0005435243163	12192	Economy	13700.00
0005435243165	12192	Economy	13700.00
0005432783992	12192	Economy	13700.00
0005435243180	12192	Economy	13700.00
0005435243169	12192	Economy	13700.00
0005435243181	12192	Economy	13700.00
0005435243175	12192	Economy	13700.00
0005432783951	12192	Economy	13700.00
0005432783985	12192	Economy	13700.00
0005432783870	12192	Economy	13700.00
0005435243176	12192	Economy	13700.00
0005435243158	12192	Economy	13700.00
0005435243164	12192	Economy	13700.00
0005432784109	12192	Economy	13700.00
0005432784138	12192	Economy	13700.00
0005432784095	12192	Economy	13700.00
0005432783732	12192	Economy	13700.00
0005432783963	12192	Economy	13700.00
0005432783895	12192	Economy	13700.00
0005435242856	15439	Business	41200.00
0005432784329	15439	Business	41200.00
0005435242918	15439	Business	41200.00
0005435242953	15439	Business	41200.00
0005432784343	15439	Business	41200.00
0005435242855	15439	Business	41200.00
0005432784369	15439	Business	41200.00
0005435242938	15439	Business	41200.00
0005435242873	15439	Business	41200.00
0005432784359	15439	Business	41200.00
0005435242854	15439	Business	41200.00
0005432784375	15439	Business	41200.00
0005432784379	15439	Economy	13700.00
0005432784328	15439	Economy	13700.00
0005432784337	15439	Economy	13700.00
0005435242870	15439	Economy	13700.00
0005432784333	15439	Economy	13700.00
0005432784350	15439	Economy	13700.00
0005435242861	15439	Economy	13700.00
0005435242945	15439	Economy	13700.00
0005435242989	15439	Economy	13700.00
0005432784363	15439	Economy	15100.00
0005432784360	15439	Economy	15100.00
0005432784365	15439	Economy	15100.00
0005435242720	15439	Economy	15100.00
0005432784362	15439	Economy	15100.00
0005432784347	15439	Economy	13700.00
0005435242885	15439	Economy	13700.00
0005435242884	15439	Economy	13700.00
0005432784330	15439	Economy	13700.00
0005432784361	15439	Economy	13700.00
0005432784338	15439	Economy	13700.00
0005432784357	15439	Economy	13700.00
0005432784355	15439	Economy	13700.00
0005432784373	15439	Economy	13700.00
0005432784348	15439	Economy	13700.00
0005432784372	15439	Economy	13700.00
0005435242923	15439	Economy	13700.00
0005435242849	15439	Economy	13700.00
0005432784342	15439	Economy	13700.00
0005435242883	15439	Economy	13700.00
0005432784340	15439	Economy	13700.00
0005432784358	15439	Economy	13700.00
0005432784353	15439	Economy	13700.00
0005432784368	15439	Economy	13700.00
0005432784376	15439	Economy	13700.00
0005435242962	15439	Economy	13700.00
0005435242927	15439	Economy	13700.00
0005432784367	15439	Economy	13700.00
0005435242941	15439	Economy	13700.00
0005432784334	15439	Economy	13700.00
0005435242937	15439	Economy	13700.00
0005432784352	15439	Economy	13700.00
0005435242940	15439	Economy	13700.00
0005435242999	15439	Economy	13700.00
0005432784351	15439	Economy	13700.00
0005432784354	15439	Economy	13700.00
0005432784370	15439	Economy	13700.00
0005432784381	15439	Economy	13700.00
0005432784371	15439	Economy	13700.00
0005432784331	15439	Economy	13700.00
0005432784378	15439	Economy	13700.00
0005432784366	15439	Economy	13700.00
0005432784336	15439	Economy	13700.00
0005432784356	15439	Economy	13700.00
0005435242922	15439	Economy	13700.00
0005435242721	15439	Economy	13700.00
0005432784346	15439	Economy	13700.00
0005432784326	15439	Economy	13700.00
0005435242882	15439	Economy	13700.00
0005435242808	15439	Economy	13700.00
0005432784374	15439	Economy	13700.00
0005432784335	15439	Economy	13700.00
0005432784344	15439	Economy	13700.00
0005432784332	15439	Economy	13700.00
0005432784327	15439	Economy	13700.00
0005432784341	15439	Economy	13700.00
0005435242890	15439	Economy	13700.00
0005432784339	15439	Economy	13700.00
0005435242857	15439	Economy	13700.00
0005435242891	15439	Economy	13700.00
0005435242911	15439	Economy	13700.00
0005432784349	15439	Economy	13700.00
0005432784364	15439	Economy	13700.00
0005432784345	15439	Economy	13700.00
0005435242917	15439	Economy	13700.00
0005435242905	15439	Economy	13700.00
0005432784380	15439	Economy	13700.00
0005432784377	15439	Economy	13700.00
0005435242915	15439	Economy	13700.00
0005434877931	10106	Business	49700.00
0005434878088	10106	Business	49700.00
0005434878757	10106	Business	49700.00
0005434758894	10106	Business	49700.00
0005434877778	10106	Business	49700.00
0005434878479	10106	Business	49700.00
0005434878791	10106	Business	49700.00
0005434878500	10106	Business	49700.00
0005434878708	10106	Business	49700.00
0005434878434	10106	Business	49700.00
0005434878406	10106	Business	49700.00
0005434878838	10106	Business	49700.00
0005434878387	10106	Business	49700.00
0005434878528	10106	Business	49700.00
0005434878376	10106	Business	49700.00
0005434878182	10106	Business	49700.00
0005434878556	10106	Business	49700.00
0005434878338	10106	Business	49700.00
0005434878337	10106	Economy	16600.00
0005434878138	10106	Economy	16600.00
0005434878437	10106	Economy	16600.00
0005434878334	10106	Economy	16600.00
0005434878238	10106	Economy	16600.00
0005434878336	10106	Economy	16600.00
0005434878318	10106	Economy	16600.00
0005434878468	10106	Economy	16600.00
0005434878756	10106	Economy	16600.00
0005434878438	10106	Economy	16600.00
0005434878297	10106	Economy	16600.00
0005434878303	10106	Economy	16600.00
0005434878750	10106	Economy	16600.00
0005434878744	10106	Economy	18200.00
0005434878790	10106	Economy	18200.00
0005434878743	10106	Economy	18200.00
0005434877932	10106	Economy	18200.00
0005434878523	10106	Economy	16600.00
0005434878584	10106	Economy	16600.00
0005434878722	10106	Economy	16600.00
0005434878760	10106	Economy	16600.00
0005434878727	10106	Economy	16600.00
0005434878281	10106	Economy	16600.00
0005434878844	10106	Economy	16600.00
0005434878040	10106	Economy	16600.00
0005434878632	10106	Economy	16600.00
0005435913965	10106	Economy	16600.00
0005434878156	10106	Economy	16600.00
0005434879051	10106	Economy	16600.00
0005434878335	10106	Economy	16600.00
0005434878585	10106	Economy	16600.00
0005434878547	10106	Economy	16600.00
0005434878763	10106	Economy	16600.00
0005434878196	10106	Economy	16600.00
0005434878039	10106	Economy	16600.00
0005434878524	10106	Economy	16600.00
0005434878310	10106	Economy	16600.00
0005434878499	10106	Economy	16600.00
0005434878724	10106	Economy	16600.00
0005434878768	10106	Economy	16600.00
0005434878526	10106	Economy	16600.00
0005434878604	10106	Economy	16600.00
0005434878155	10106	Economy	16600.00
0005434878280	10106	Economy	16600.00
0005434878728	10106	Economy	16600.00
0005434878271	10106	Economy	16600.00
0005434878659	10106	Economy	16600.00
0005434878435	10106	Economy	16600.00
0005434878239	10106	Economy	16600.00
0005434878477	10106	Economy	16600.00
0005434878467	10106	Economy	16600.00
0005434878302	10106	Economy	16600.00
0005434878688	10106	Economy	16600.00
0005434878706	10106	Economy	16600.00
0005434878428	10106	Economy	16600.00
0005434878758	10106	Economy	16600.00
0005434910138	10106	Economy	16600.00
0005434878745	10106	Economy	16600.00
0005434878527	10106	Economy	16600.00
0005434878687	10106	Economy	16600.00
0005434878525	10106	Economy	16600.00
0005434878622	10106	Economy	16600.00
0005434878364	10106	Economy	16600.00
0005434878755	10106	Economy	16600.00
0005434878497	10106	Economy	16600.00
0005434878754	10106	Economy	16600.00
0005434878513	10106	Economy	16600.00
0005434878546	10106	Economy	16600.00
0005434878753	10106	Economy	16600.00
0005434878429	10106	Economy	16600.00
0005434878509	10106	Economy	16600.00
0005434878522	10106	Economy	16600.00
0005434877908	10106	Economy	16600.00
0005434878746	10106	Economy	16600.00
0005434878339	10106	Economy	16600.00
0005434910139	10106	Economy	16600.00
0005434878583	10106	Economy	16600.00
0005434878603	10106	Economy	16600.00
0005434878042	10106	Economy	16600.00
0005434910137	10106	Economy	16600.00
0005434879050	10106	Economy	16600.00
0005434878660	10106	Economy	16600.00
0005434878478	10106	Economy	16600.00
0005434878520	10106	Economy	16600.00
0005434878594	10106	Economy	16600.00
0005434879340	14647	Business	49700.00
0005434879322	14647	Business	49700.00
0005434879253	14647	Business	49700.00
0005434879274	14647	Business	49700.00
0005434879259	14647	Business	49700.00
0005434879249	14647	Business	49700.00
0005434879312	14647	Business	49700.00
0005434879279	14647	Business	49700.00
0005434879285	14647	Business	49700.00
0005434879284	14647	Business	49700.00
0005434879271	14647	Business	49700.00
0005434879296	14647	Business	49700.00
0005434879332	14647	Business	49700.00
0005434879256	14647	Business	49700.00
0005434879313	14647	Business	49700.00
0005434910123	14647	Business	49700.00
0005434879344	14647	Business	49700.00
0005434879278	14647	Economy	16600.00
0005434758919	14647	Business	49700.00
0005434879283	14647	Economy	16600.00
0005434879263	14647	Economy	16600.00
0005434879314	14647	Economy	16600.00
0005434879324	14647	Economy	16600.00
0005434879335	14647	Economy	16600.00
0005435913934	14647	Economy	16600.00
0005434879330	14647	Economy	16600.00
0005434879306	14647	Economy	16600.00
0005434879339	14647	Economy	16600.00
0005434879321	14647	Economy	16600.00
0005434879258	14647	Economy	16600.00
0005434879290	14647	Economy	18200.00
0005434879295	14647	Economy	18200.00
0005434879291	14647	Economy	18200.00
0005434879300	14647	Economy	18200.00
0005434879268	14647	Economy	16600.00
0005435913936	14647	Economy	16600.00
0005434879275	14647	Economy	16600.00
0005434879318	14647	Economy	16600.00
0005434879337	14647	Economy	16600.00
0005434879260	14647	Economy	16600.00
0005434879326	14647	Economy	16600.00
0005434879331	14647	Economy	16600.00
0005434879325	14647	Economy	16600.00
0005434879320	14647	Economy	16600.00
0005434879252	14647	Economy	16600.00
0005434758920	14647	Economy	16600.00
0005434879267	14647	Economy	16600.00
0005434879345	14647	Economy	16600.00
0005434879304	14647	Economy	16600.00
0005434879277	14647	Economy	16600.00
0005434879338	14647	Economy	16600.00
0005434879255	14647	Economy	16600.00
0005434879311	14647	Economy	16600.00
0005435913935	14647	Economy	16600.00
0005434879288	14647	Economy	16600.00
0005434879323	14647	Economy	16600.00
0005434879308	14647	Economy	16600.00
0005434879265	14647	Economy	16600.00
0005434879298	14647	Economy	16600.00
0005434879327	14647	Economy	16600.00
0005434879334	14647	Economy	16600.00
0005434879282	14647	Economy	16600.00
0005434879269	14647	Economy	16600.00
0005434879333	14647	Economy	16600.00
0005434879299	14647	Economy	16600.00
0005434879343	14647	Economy	16600.00
0005434879276	14647	Economy	16600.00
0005434879262	14647	Economy	16600.00
0005434879302	14647	Economy	16600.00
0005434879250	14647	Economy	16600.00
0005434879261	14647	Economy	16600.00
0005434879310	14647	Economy	16600.00
0005434879289	14647	Economy	16600.00
0005434879317	14647	Economy	16600.00
0005434879341	14647	Economy	16600.00
0005434879254	14647	Economy	16600.00
0005434879286	14647	Economy	16600.00
0005434879272	14647	Economy	16600.00
0005434879329	14647	Economy	16600.00
0005434879273	14647	Economy	16600.00
0005434758921	14647	Economy	16600.00
0005434879270	14647	Economy	16600.00
0005434879297	14647	Economy	16600.00
0005434879264	14647	Economy	16600.00
0005434879293	14647	Economy	16600.00
0005434879328	14647	Economy	16600.00
0005434879281	14647	Economy	16600.00
0005434879303	14647	Economy	16600.00
0005434879316	14647	Economy	16600.00
0005434879336	14647	Economy	16600.00
0005434879266	14647	Economy	16600.00
0005434879315	14647	Economy	16600.00
0005434879307	14647	Economy	16600.00
0005434879319	14647	Economy	16600.00
0005434879309	14647	Economy	16600.00
0005434879292	14647	Economy	16600.00
0005434879305	14647	Economy	16600.00
0005434879287	14647	Economy	16600.00
0005434879251	14647	Economy	16600.00
0005434879280	14647	Economy	16600.00
0005434879301	14647	Economy	16600.00
0005434879342	14647	Economy	16600.00
0005434879257	14647	Economy	16600.00
0005434879294	14647	Economy	16600.00
0005435660264	9236	Economy	22400.00
0005435660268	9236	Economy	22400.00
0005435660263	9236	Economy	20300.00
0005435660269	9236	Economy	20300.00
0005434251937	9236	Economy	20300.00
0005434251996	9236	Economy	20300.00
0005434252027	9236	Economy	20300.00
0005435660270	9236	Economy	20300.00
0005435660266	9236	Economy	20300.00
0005434251977	9236	Economy	20300.00
0005434252003	9236	Economy	20300.00
0005435660262	9236	Economy	20300.00
0005435660260	9236	Economy	20300.00
0005434251990	9236	Economy	20300.00
0005435660261	9236	Economy	20300.00
0005435660267	9236	Economy	20300.00
0005434251960	9236	Economy	20300.00
0005434251938	9236	Economy	20300.00
0005434252019	9236	Economy	20300.00
0005435660265	9236	Economy	20300.00
0005434251963	9236	Economy	20300.00
0005434251997	9236	Economy	20300.00
0005434251964	9236	Economy	20300.00
0005434251989	9236	Economy	20300.00
0005434252068	24633	Economy	22400.00
0005434252072	24633	Economy	20300.00
0005434252074	24633	Economy	20300.00
0005435660100	24633	Economy	20300.00
0005434252075	24633	Economy	20300.00
0005434252069	24633	Economy	20300.00
0005435660155	24633	Economy	20300.00
0005435660210	24633	Economy	20300.00
0005434252073	24633	Economy	20300.00
0005434252070	24633	Economy	20300.00
0005434252071	24633	Economy	20300.00
0005435660126	24633	Economy	20300.00
0005435660224	24633	Economy	20300.00
0005434252076	24633	Economy	20300.00
0005435660165	24633	Economy	20300.00
0005435660189	24633	Economy	20300.00
0005435660154	24633	Economy	20300.00
0005435660158	24633	Economy	20300.00
0005433681119	2772	Business	33000.00
0005432967025	2772	Business	33000.00
0005432222845	2772	Business	33000.00
0005433681108	2772	Business	33000.00
0005433681091	2772	Business	33000.00
0005433681116	2772	Business	33000.00
0005433681090	2772	Business	33000.00
0005432966949	2772	Business	33000.00
0005432967057	2772	Business	33000.00
0005432222843	2772	Business	33000.00
0005432967113	2772	Business	33000.00
0005432966986	2772	Business	33000.00
0005433681081	2772	Economy	11000.00
0005432967101	2772	Economy	11000.00
0005433681103	2772	Economy	11000.00
0005432222844	2772	Economy	11000.00
0005432967099	2772	Economy	11000.00
0005433681092	2772	Economy	11000.00
0005433681080	2772	Economy	11000.00
0005432966958	2772	Economy	11000.00
0005433681122	2772	Economy	11000.00
0005432967076	2772	Economy	11000.00
0005433681110	2772	Economy	12100.00
0005433681104	2772	Economy	12100.00
0005432967006	2772	Economy	12100.00
0005433681085	2772	Economy	12100.00
0005432967049	2772	Economy	11000.00
0005432967017	2772	Economy	11000.00
0005433681089	2772	Economy	11000.00
0005433681095	2772	Economy	11000.00
0005433681086	2772	Economy	11000.00
0005433681079	2772	Economy	11000.00
0005433681097	2772	Economy	11000.00
0005432222839	2772	Economy	11000.00
0005432966967	2772	Economy	11000.00
0005432967147	2772	Economy	11000.00
0005433681113	2772	Economy	11000.00
0005432966987	2772	Economy	11000.00
0005433681125	2772	Economy	11000.00
0005433681088	2772	Economy	11000.00
0005432967026	2772	Economy	11000.00
0005433681082	2772	Economy	11000.00
0005432222842	2772	Economy	11000.00
0005433681098	2772	Economy	11000.00
0005433681121	2772	Economy	11000.00
0005432967100	2772	Economy	11000.00
0005432967098	2772	Economy	11000.00
0005432967050	2772	Economy	11000.00
0005432966970	2772	Economy	11000.00
0005433681114	2772	Economy	11000.00
0005433681124	2772	Economy	11000.00
0005432967089	2772	Economy	11000.00
0005433681087	2772	Economy	11000.00
0005432967102	2772	Economy	11000.00
0005433681107	2772	Economy	11000.00
0005432967112	2772	Economy	11000.00
0005432967036	2772	Economy	11000.00
0005433681096	2772	Economy	11000.00
0005432222840	2772	Economy	11000.00
0005432966906	2772	Economy	11000.00
0005432966969	2772	Economy	11000.00
0005433681099	2772	Economy	11000.00
0005432222841	2772	Economy	11000.00
0005433681123	2772	Economy	11000.00
0005432967048	2772	Economy	11000.00
0005432966994	2772	Economy	11000.00
0005433681083	2772	Economy	11000.00
0005433681115	2772	Economy	11000.00
0005433681118	2772	Economy	11000.00
0005433681084	2772	Economy	11000.00
0005433681094	2772	Economy	11000.00
0005433681093	2772	Economy	11000.00
0005433681102	2772	Economy	11000.00
0005433681105	2772	Economy	11000.00
0005433684443	2772	Economy	11000.00
0005433681112	2772	Economy	11000.00
0005433681109	2772	Economy	11000.00
0005433681117	2772	Economy	11000.00
0005432966907	2772	Economy	11000.00
0005432967053	2772	Economy	11000.00
0005432967097	2772	Economy	11000.00
0005433681106	2772	Economy	11000.00
0005433681100	2772	Economy	11000.00
0005433681120	2772	Economy	11000.00
0005433681101	2772	Economy	11000.00
0005433681111	2772	Economy	11000.00
0005432966951	2772	Economy	11000.00
0005433681126	2772	Economy	11000.00
0005432966950	2772	Economy	11000.00
0005433684442	2772	Economy	11000.00
0005433684422	29175	Business	33000.00
0005432005245	29175	Business	33000.00
0005432967231	29175	Business	33000.00
0005433680682	29175	Business	33000.00
0005433680552	29175	Business	33000.00
0005433680827	29175	Business	33000.00
0005432967227	29175	Business	33000.00
0005433680850	29175	Business	33000.00
0005433680766	29175	Business	33000.00
0005433680611	29175	Business	33000.00
0005433687717	29175	Economy	11000.00
0005432005244	29175	Economy	11000.00
0005432967230	29175	Economy	11000.00
0005433680578	29175	Economy	11000.00
0005432967215	29175	Economy	11000.00
0005432967216	29175	Economy	11000.00
0005433680977	29175	Economy	11000.00
0005432967212	29175	Economy	11000.00
0005433680610	29175	Economy	12100.00
0005433680922	29175	Economy	12100.00
0005433680554	29175	Economy	11000.00
0005432967220	29175	Economy	11000.00
0005433680909	29175	Economy	11000.00
0005432967224	29175	Economy	11000.00
0005432967235	29175	Economy	11000.00
0005432967236	29175	Economy	11000.00
0005433687704	29175	Economy	11000.00
0005433680669	29175	Economy	11000.00
0005433680915	29175	Economy	11000.00
0005432967233	29175	Economy	11000.00
0005433687703	29175	Economy	11000.00
0005433680658	29175	Economy	11000.00
0005433680923	29175	Economy	11000.00
0005432967229	29175	Economy	11000.00
0005432005246	29175	Economy	11000.00
0005433680803	29175	Economy	11000.00
0005433680768	29175	Economy	11000.00
0005432967228	29175	Economy	11000.00
0005432967234	29175	Economy	11000.00
0005433680609	29175	Economy	11000.00
0005432967214	29175	Economy	11000.00
0005433680769	29175	Economy	11000.00
0005433680763	29175	Economy	11000.00
0005433684436	29175	Economy	11000.00
0005433680764	29175	Economy	11000.00
0005433684438	29175	Economy	11000.00
0005432967226	29175	Economy	11000.00
0005433680716	29175	Economy	11000.00
0005433680767	29175	Economy	11000.00
0005432967222	29175	Economy	11000.00
0005433680976	29175	Economy	11000.00
0005433680659	29175	Economy	11000.00
0005432967217	29175	Economy	11000.00
0005432967219	29175	Economy	11000.00
0005433680679	29175	Economy	11000.00
0005432967221	29175	Economy	11000.00
0005433680882	29175	Economy	11000.00
0005433680916	29175	Economy	11000.00
0005433680553	29175	Economy	11000.00
0005433680957	29175	Economy	11000.00
0005433680579	29175	Economy	11000.00
0005433680727	29175	Economy	11000.00
0005433684437	29175	Economy	11000.00
0005432967218	29175	Economy	11000.00
0005432967232	29175	Economy	11000.00
0005432967225	29175	Economy	11000.00
0005433680956	29175	Economy	11000.00
0005433687718	29175	Economy	11000.00
0005433680720	29175	Economy	11000.00
0005432967213	29175	Economy	11000.00
0005433680584	29175	Economy	11000.00
0005432967211	29175	Economy	11000.00
0005432967223	29175	Economy	11000.00
0005433680519	29175	Economy	11000.00
0005433680810	29175	Economy	11000.00
0005434163657	9274	Business	132900.00
0005433615433	9274	Business	132900.00
0005433615418	9274	Business	132900.00
0005433615478	9274	Business	132900.00
0005433634167	9274	Business	132900.00
0005433577960	9274	Business	132900.00
0005433615480	9274	Business	132900.00
0005433615477	9274	Business	132900.00
0005433615427	9274	Business	132900.00
0005433615428	9274	Business	132900.00
0005434163617	9274	Business	132900.00
0005433615475	9274	Business	132900.00
0005433615456	9274	Business	132900.00
0005434163640	9274	Business	132900.00
0005433615457	9274	Business	132900.00
0005433634162	9274	Business	132900.00
0005433615462	9274	Business	132900.00
0005433577952	9274	Business	132900.00
0005433634188	9274	Business	132900.00
0005433634180	9274	Business	132900.00
0005433615407	9274	Business	132900.00
0005433615438	9274	Business	132900.00
0005433634158	9274	Business	132900.00
0005433615419	9274	Economy	48700.00
0005433577955	9274	Economy	48700.00
0005433634170	9274	Economy	48700.00
0005434152794	9274	Economy	48700.00
0005433634159	9274	Economy	48700.00
0005433615474	9274	Economy	44300.00
0005433634156	9274	Economy	44300.00
0005433634160	9274	Economy	44300.00
0005433615468	9274	Economy	44300.00
0005433615440	9274	Economy	44300.00
0005433634174	9274	Economy	44300.00
0005433615460	9274	Economy	44300.00
0005433615430	9274	Economy	44300.00
0005433615476	9274	Economy	44300.00
0005433634185	9274	Economy	44300.00
0005433577956	9274	Economy	44300.00
0005433577963	9274	Economy	44300.00
0005433615414	9274	Economy	44300.00
0005433634176	9274	Economy	44300.00
0005433615449	9274	Economy	44300.00
0005433615431	9274	Economy	44300.00
0005434163658	9274	Economy	44300.00
0005433577954	9274	Economy	44300.00
0005433634183	9274	Economy	44300.00
0005432756885	9274	Economy	44300.00
0005433615448	9274	Economy	44300.00
0005433634169	9274	Economy	44300.00
0005434152786	9274	Economy	44300.00
0005433615443	9274	Economy	44300.00
0005433634157	9274	Economy	44300.00
0005433615451	9274	Economy	44300.00
0005433615408	9274	Economy	44300.00
0005432755114	9274	Economy	44300.00
0005434163620	9274	Economy	44300.00
0005433615424	9274	Economy	44300.00
0005433577951	9274	Economy	44300.00
0005433577958	9274	Economy	44300.00
0005433615437	9274	Economy	44300.00
0005433615426	9274	Economy	44300.00
0005433615481	9274	Economy	44300.00
0005433634172	9274	Economy	44300.00
0005433615436	9274	Economy	44300.00
0005433615444	9274	Economy	44300.00
0005433634164	9274	Economy	44300.00
0005432755113	9274	Economy	44300.00
0005433634189	9274	Economy	44300.00
0005433615415	9274	Economy	44300.00
0005433615467	9274	Economy	44300.00
0005433634168	9274	Economy	44300.00
0005433615452	9274	Economy	44300.00
0005433577961	9274	Economy	44300.00
0005433615461	9274	Economy	44300.00
0005433634171	9274	Economy	44300.00
0005434163618	9274	Economy	44300.00
0005433615466	9274	Economy	44300.00
0005434152793	9274	Economy	44300.00
0005433615465	9274	Economy	44300.00
0005433634178	9274	Economy	44300.00
0005433634187	9274	Economy	48700.00
0005433615417	9274	Economy	48700.00
0005433634163	9274	Economy	48700.00
0005433615470	9274	Economy	48700.00
0005433615420	9274	Economy	48700.00
0005433615472	9274	Economy	44300.00
0005433634182	9274	Economy	44300.00
0005433634181	9274	Economy	44300.00
0005433615413	9274	Economy	44300.00
0005433577953	9274	Economy	48700.00
0005434163656	9274	Economy	44300.00
0005433634166	9274	Economy	44300.00
0005432756884	9274	Economy	44300.00
0005433615471	9274	Economy	44300.00
0005433615422	9274	Economy	44300.00
0005433634173	9274	Economy	44300.00
0005433615464	9274	Economy	44300.00
0005433615454	9274	Economy	44300.00
0005433615421	9274	Economy	44300.00
0005433634161	9274	Economy	44300.00
0005433615463	9274	Economy	44300.00
0005433577966	9274	Economy	44300.00
0005433615450	9274	Economy	44300.00
0005433577965	9274	Economy	44300.00
0005434163641	9274	Economy	44300.00
0005433615432	9274	Economy	44300.00
0005433634186	9274	Economy	44300.00
0005433615429	9274	Economy	44300.00
0005433615409	9274	Economy	44300.00
0005433615411	9274	Economy	44300.00
0005433615446	9274	Economy	44300.00
0005433615425	9274	Economy	44300.00
0005433615473	9274	Economy	44300.00
0005433577964	9274	Economy	44300.00
0005433615459	9274	Economy	44300.00
0005433615458	9274	Economy	44300.00
0005433634155	9274	Economy	44300.00
0005433615410	9274	Economy	44300.00
0005433577959	9274	Economy	44300.00
0005433615412	9274	Economy	44300.00
0005434269105	9274	Economy	44300.00
0005433615469	9274	Economy	44300.00
0005433615439	9274	Economy	44300.00
0005433634175	9274	Economy	44300.00
0005433615453	9274	Economy	44300.00
0005433634165	9274	Economy	44300.00
0005433615447	9274	Economy	44300.00
0005433615434	9274	Economy	44300.00
0005433615423	9274	Economy	44300.00
0005433615442	9274	Economy	44300.00
0005433615435	9274	Economy	44300.00
0005433577957	9274	Economy	44300.00
0005433615441	9274	Economy	44300.00
0005432756886	9274	Economy	44300.00
0005433634177	9274	Economy	44300.00
0005433577962	9274	Economy	44300.00
0005434152785	9274	Economy	44300.00
0005433615416	9274	Economy	44300.00
0005432756883	9274	Economy	44300.00
0005433634179	9274	Economy	44300.00
0005432755112	9274	Economy	44300.00
0005433615479	9274	Economy	44300.00
0005433634184	9274	Economy	44300.00
0005433615445	9274	Economy	44300.00
0005434163621	9274	Economy	44300.00
0005433615455	9274	Economy	44300.00
0005433634094	25241	Business	132900.00
0005434163717	25241	Business	132900.00
0005433614930	25241	Business	132900.00
0005433577857	25241	Business	132900.00
0005432751518	25241	Business	132900.00
0005432751519	25241	Business	132900.00
0005433633776	25241	Business	132900.00
0005433633913	25241	Business	132900.00
0005433633891	25241	Business	132900.00
0005433614769	25241	Business	132900.00
0005433614732	25241	Business	132900.00
0005433615011	25241	Business	132900.00
0005433614608	25241	Business	132900.00
0005433614768	25241	Business	132900.00
0005433614715	25241	Business	132900.00
0005433633958	25241	Business	132900.00
0005434152810	25241	Business	132900.00
0005433633906	25241	Business	132900.00
0005433615192	25241	Business	132900.00
0005433614988	25241	Business	132900.00
0005434152809	25241	Business	132900.00
0005432751525	25241	Business	132900.00
0005433577843	25241	Business	132900.00
0005433614731	25241	Business	132900.00
0005433614709	25241	Business	132900.00
0005433633833	25241	Business	132900.00
0005433577831	25241	Business	132900.00
0005433614710	25241	Business	132900.00
0005432755080	25241	Economy	48700.00
0005434163719	25241	Economy	48700.00
0005433633708	25241	Economy	48700.00
0005433577905	25241	Economy	48700.00
0005433633884	25241	Economy	44300.00
0005433614743	25241	Economy	44300.00
0005433615008	25241	Economy	44300.00
0005434163718	25241	Economy	44300.00
0005433614595	25241	Economy	44300.00
0005434163723	25241	Economy	44300.00
0005433614830	25241	Economy	44300.00
0005432755067	25241	Economy	44300.00
0005433614891	25241	Economy	44300.00
0005433633929	25241	Economy	44300.00
0005433614936	25241	Economy	44300.00
0005433614822	25241	Economy	44300.00
0005433577812	25241	Economy	44300.00
0005434163721	25241	Economy	44300.00
0005433633707	25241	Economy	44300.00
0005433577815	25241	Economy	44300.00
0005433614900	25241	Economy	44300.00
0005433577877	25241	Economy	44300.00
0005433633982	25241	Economy	44300.00
0005433614839	25241	Economy	44300.00
0005433614794	25241	Economy	44300.00
0005432751533	25241	Economy	44300.00
0005433614823	25241	Economy	44300.00
0005433614906	25241	Economy	44300.00
0005432755054	25241	Economy	44300.00
0005432755066	25241	Economy	44300.00
0005432755068	25241	Economy	44300.00
0005432751537	25241	Economy	44300.00
0005433615094	25241	Economy	44300.00
0005433634050	25241	Economy	44300.00
0005433614973	25241	Economy	44300.00
0005433633682	25241	Economy	44300.00
0005434152811	25241	Economy	44300.00
0005433614886	25241	Economy	44300.00
0005433614887	25241	Economy	44300.00
0005433614741	25241	Economy	44300.00
0005433614659	25241	Economy	44300.00
0005433614607	25241	Economy	44300.00
0005433614921	25241	Economy	44300.00
0005433633856	25241	Economy	44300.00
0005433614932	25241	Economy	44300.00
0005433633907	25241	Economy	44300.00
0005433577845	25241	Economy	44300.00
0005433633837	25241	Economy	44300.00
0005433614727	25241	Economy	44300.00
0005433614980	25241	Economy	44300.00
0005433614812	25241	Economy	44300.00
0005432755051	25241	Economy	44300.00
0005433614758	25241	Economy	44300.00
0005434152805	25241	Economy	44300.00
0005433614814	25241	Economy	44300.00
0005433614840	25241	Economy	44300.00
0005432755059	25241	Economy	44300.00
0005434152812	25241	Economy	48700.00
0005432751498	25241	Economy	44300.00
0005432751523	25241	Economy	48700.00
0005433614841	25241	Economy	48700.00
0005433577837	25241	Economy	48700.00
0005433633887	25241	Economy	48700.00
0005433614720	25241	Economy	44300.00
0005433614750	25241	Economy	44300.00
0005434152806	25241	Economy	44300.00
0005433614759	25241	Economy	48700.00
0005433633853	25241	Economy	44300.00
0005433614726	25241	Economy	44300.00
0005433633890	25241	Economy	44300.00
0005432751524	25241	Economy	44300.00
0005433615084	25241	Economy	44300.00
0005433614908	25241	Economy	44300.00
0005432755071	25241	Economy	44300.00
0005432755086	25241	Economy	44300.00
0005433633753	25241	Economy	44300.00
0005433614765	25241	Economy	44300.00
0005434163724	25241	Economy	44300.00
0005433614755	25241	Economy	44300.00
0005433633966	25241	Economy	44300.00
0005434163720	25241	Economy	44300.00
0005433614852	25241	Economy	44300.00
0005433634001	25241	Economy	44300.00
0005433614853	25241	Economy	44300.00
0005433614724	25241	Economy	44300.00
0005433577844	25241	Economy	44300.00
0005433577841	25241	Economy	44300.00
0005434152808	25241	Economy	44300.00
0005434163716	25241	Economy	44300.00
0005433614815	25241	Economy	44300.00
0005434152807	25241	Economy	44300.00
0005433633886	25241	Economy	44300.00
0005433614716	25241	Economy	44300.00
0005433633772	25241	Economy	44300.00
0005433633752	25241	Economy	44300.00
0005433614742	25241	Economy	44300.00
0005433614777	25241	Economy	44300.00
0005433614899	25241	Economy	44300.00
0005433577842	25241	Economy	44300.00
0005433577860	25241	Economy	44300.00
0005434152803	25241	Economy	44300.00
0005433577861	25241	Economy	44300.00
0005433634033	25241	Economy	44300.00
0005433614837	25241	Economy	44300.00
0005434163722	25241	Economy	44300.00
0005433577804	25241	Economy	44300.00
0005433614639	25241	Economy	44300.00
0005433633852	25241	Economy	44300.00
0005433614793	25241	Economy	44300.00
0005434152813	25241	Economy	44300.00
0005433577890	25241	Economy	44300.00
0005433577805	25241	Economy	44300.00
0005433577866	25241	Economy	44300.00
0005433615193	25241	Economy	44300.00
0005433614444	25241	Economy	44300.00
0005433633963	25241	Economy	44300.00
0005432755056	25241	Economy	44300.00
0005433614540	25241	Economy	44300.00
0005433614721	25241	Economy	44300.00
0005433577832	25241	Economy	44300.00
0005434152804	25241	Economy	44300.00
0005432751516	25241	Economy	44300.00
0005433577862	25241	Economy	44300.00
0005433614625	25241	Economy	44300.00
0005432751527	25241	Economy	44300.00
0005434163715	25241	Economy	44300.00
0005433614838	25241	Economy	44300.00
0005433614824	25241	Economy	44300.00
0005433615026	25241	Economy	44300.00
0005432755060	25241	Economy	44300.00
0005432571337	4200	Business	193100.00
0005435947309	4200	Business	193100.00
0005435947293	4200	Business	193100.00
0005434271318	4200	Business	193100.00
0005435947307	4200	Business	193100.00
0005432184983	4200	Business	193100.00
0005435947310	4200	Business	193100.00
0005435947314	4200	Economy	70800.00
0005435947285	4200	Economy	64400.00
0005435986838	4200	Economy	64400.00
0005435986841	4200	Economy	64400.00
0005435986844	4200	Economy	64400.00
0005435856212	4200	Economy	64400.00
0005435947306	4200	Economy	64400.00
0005434271309	4200	Economy	64400.00
0005435986835	4200	Economy	64400.00
0005435986837	4200	Economy	64400.00
0005435947242	4200	Economy	64400.00
0005432571325	4200	Economy	64400.00
0005435947261	4200	Economy	64400.00
0005435986836	4200	Economy	64400.00
0005434271316	4200	Economy	64400.00
0005435947316	4200	Economy	64400.00
0005435947337	4200	Economy	64400.00
0005435947317	4200	Economy	64400.00
0005432184984	4200	Economy	64400.00
0005435856210	4200	Economy	64400.00
0005435856197	4200	Economy	64400.00
0005435947311	4200	Economy	64400.00
0005432184982	4200	Economy	64400.00
0005435947294	4200	Economy	64400.00
0005435986839	4200	Economy	64400.00
0005435856213	4200	Economy	64400.00
0005435986842	4200	Economy	64400.00
0005435947328	4200	Economy	64400.00
0005435947313	4200	Economy	64400.00
0005435986843	4200	Economy	64400.00
0005435947243	4200	Economy	64400.00
0005435856211	4200	Economy	64400.00
0005435947327	4200	Economy	64400.00
0005435947241	4200	Economy	64400.00
0005432571326	4200	Economy	64400.00
0005435986840	4200	Economy	64400.00
0005435856253	26561	Business	193100.00
0005435986791	26561	Business	193100.00
0005435856254	26561	Business	193100.00
0005435947417	26561	Business	193100.00
0005435947426	26561	Business	193100.00
0005432571366	26561	Economy	64400.00
0005435947415	26561	Economy	64400.00
0005435986783	26561	Economy	64400.00
0005435856250	26561	Economy	64400.00
0005435947416	26561	Economy	64400.00
0005435947423	26561	Economy	64400.00
0005435947428	26561	Economy	64400.00
0005435986782	26561	Economy	64400.00
0005435947420	26561	Economy	64400.00
0005435856252	26561	Economy	64400.00
0005435947418	26561	Economy	64400.00
0005435986776	26561	Economy	64400.00
0005435947421	26561	Economy	64400.00
0005435986784	26561	Economy	64400.00
0005435986777	26561	Economy	64400.00
0005435947422	26561	Economy	64400.00
0005435947414	26561	Economy	64400.00
0005435947419	26561	Economy	64400.00
0005435947427	26561	Economy	64400.00
0005435947425	26561	Economy	64400.00
0005435787380	26561	Economy	64400.00
0005435986785	26561	Economy	64400.00
0005432571368	26561	Economy	64400.00
0005435787381	26561	Economy	64400.00
0005435947424	26561	Economy	64400.00
0005432571367	26561	Economy	64400.00
0005435856251	26561	Economy	64400.00
0005433134118	313	Business	21500.00
0005433569734	313	Business	21500.00
0005432948524	313	Business	21500.00
0005432948484	313	Business	21500.00
0005433074796	313	Business	21500.00
0005433134140	313	Business	21500.00
0005433074675	313	Business	21500.00
0005432948616	313	Business	21500.00
0005433134117	313	Business	21500.00
0005433074797	313	Business	21500.00
0005432948419	313	Business	21500.00
0005433569740	313	Business	21500.00
0005433074762	313	Business	21500.00
0005432239006	313	Business	21500.00
0005432948564	313	Business	21500.00
0005433569759	313	Business	21500.00
0005433074767	313	Business	21500.00
0005433569764	313	Business	21500.00
0005433569729	313	Business	21500.00
0005433569741	313	Business	21500.00
0005432239005	313	Business	21500.00
0005433569727	313	Business	21500.00
0005433569725	313	Business	21500.00
0005433569723	313	Business	21500.00
0005433569738	313	Business	21500.00
0005433129294	313	Business	21500.00
0005433569745	313	Economy	7900.00
0005432948536	313	Economy	7900.00
0005433074788	313	Economy	7900.00
0005433569730	313	Economy	7900.00
0005432948559	313	Economy	7900.00
0005432948400	313	Economy	7900.00
0005432948575	313	Economy	7200.00
0005433074772	313	Economy	7200.00
0005433074784	313	Economy	7200.00
0005433569722	313	Economy	7200.00
0005432948480	313	Economy	7200.00
0005433074790	313	Economy	7200.00
0005433569736	313	Economy	7200.00
0005433074662	313	Economy	7200.00
0005433074787	313	Economy	7200.00
0005432948618	313	Economy	7200.00
0005433569753	313	Economy	7200.00
0005432948649	313	Economy	7200.00
0005433569717	313	Economy	7200.00
0005432948418	313	Economy	7200.00
0005433569732	313	Economy	7200.00
0005433569755	313	Economy	7200.00
0005433569744	313	Economy	7200.00
0005433074830	313	Economy	7200.00
0005433074726	313	Economy	7200.00
0005432948322	313	Economy	7200.00
0005433569751	313	Economy	7200.00
0005433569713	313	Economy	7200.00
0005433074768	313	Economy	7200.00
0005433134145	313	Economy	7200.00
0005433134146	313	Economy	7200.00
0005432239008	313	Economy	7200.00
0005433074842	313	Economy	7200.00
0005433074763	313	Economy	7200.00
0005433074843	313	Economy	7200.00
0005433569746	313	Economy	7200.00
0005433074805	313	Economy	7200.00
0005433074827	313	Economy	7200.00
0005433074711	313	Economy	7200.00
0005432948655	313	Economy	7200.00
0005433569735	313	Economy	7200.00
0005433074859	313	Economy	7200.00
0005432239004	313	Economy	7200.00
0005432948664	313	Economy	7200.00
0005433569757	313	Economy	7200.00
0005433074789	313	Economy	7200.00
0005432239003	313	Economy	7200.00
0005433569742	313	Economy	7200.00
0005433129293	313	Economy	7200.00
0005433569720	313	Economy	7200.00
0005433074791	313	Economy	7200.00
0005433569752	313	Economy	7200.00
0005433569710	313	Economy	7200.00
0005433074880	313	Economy	7200.00
0005433569762	313	Economy	7200.00
0005432239007	313	Economy	7200.00
0005433569750	313	Economy	7200.00
0005432948264	313	Economy	7200.00
0005433569763	313	Economy	7200.00
0005432948574	313	Economy	7200.00
0005433074858	313	Economy	7200.00
0005433569712	313	Economy	7200.00
0005433074674	313	Economy	7200.00
0005433569733	313	Economy	7200.00
0005432948446	313	Economy	7200.00
0005432948408	313	Economy	7900.00
0005433569739	313	Economy	7900.00
0005433074773	313	Economy	7900.00
0005433569747	313	Economy	7900.00
0005433569716	313	Economy	7200.00
0005432948582	313	Economy	7200.00
0005433569711	313	Economy	7200.00
0005433569714	313	Economy	7900.00
0005433569715	313	Economy	7200.00
0005433129297	313	Economy	7200.00
0005432948483	313	Economy	7200.00
0005433074792	313	Economy	7200.00
0005433569728	313	Economy	7200.00
0005433569731	313	Economy	7200.00
0005433569718	313	Economy	7200.00
0005432948684	313	Economy	7200.00
0005433074688	313	Economy	7200.00
0005433569749	313	Economy	7200.00
0005433569748	313	Economy	7200.00
0005432948409	313	Economy	7200.00
0005432948648	313	Economy	7200.00
0005432948394	313	Economy	7200.00
0005433074783	313	Economy	7200.00
0005433129298	313	Economy	7200.00
0005433569724	313	Economy	7200.00
0005433569760	313	Economy	7200.00
0005432948312	313	Economy	7200.00
0005433569707	313	Economy	7200.00
0005432948321	313	Economy	7200.00
0005433074712	313	Economy	7200.00
0005433569737	313	Economy	7200.00
0005433569743	313	Economy	7200.00
0005433074782	313	Economy	7200.00
0005432948576	313	Economy	7200.00
0005432948449	313	Economy	7200.00
0005432948265	313	Economy	7200.00
0005433074854	313	Economy	7200.00
0005433569766	313	Economy	7200.00
0005433074725	313	Economy	7200.00
0005432948596	313	Economy	7200.00
0005433074844	313	Economy	7200.00
0005432948558	313	Economy	7200.00
0005432948565	313	Economy	7200.00
0005433074828	313	Economy	7200.00
0005433569761	313	Economy	7200.00
0005433569721	313	Economy	7200.00
0005433074850	313	Economy	7200.00
0005432948617	313	Economy	7200.00
0005433569758	313	Economy	7200.00
0005432948410	313	Economy	7200.00
0005432948563	313	Economy	7200.00
0005433074713	313	Economy	7200.00
0005433569719	313	Economy	7200.00
0005432948654	313	Economy	7200.00
0005432948451	313	Economy	7200.00
0005433569765	313	Economy	7200.00
0005433074663	313	Economy	7200.00
0005432948395	313	Economy	7200.00
0005433569709	313	Economy	7200.00
0005433569726	313	Economy	7200.00
0005433569708	313	Economy	7200.00
0005433569754	313	Economy	7200.00
0005433129292	313	Economy	7200.00
0005432948393	313	Economy	7200.00
0005433569756	313	Economy	7200.00
0005432948450	313	Economy	7200.00
0005432948581	313	Economy	7200.00
0005433074837	313	Economy	7200.00
0005433074798	313	Economy	7200.00
0005433075021	11575	Business	21500.00
0005432948929	11575	Business	21500.00
0005433569298	11575	Business	21500.00
0005433569008	11575	Business	21500.00
0005433569065	11575	Business	21500.00
0005433569096	11575	Business	21500.00
0005432948897	11575	Business	21500.00
0005433569198	11575	Business	21500.00
0005432948915	11575	Business	21500.00
0005433131760	11575	Business	21500.00
0005433075018	11575	Business	21500.00
0005432948908	11575	Business	21500.00
0005433075033	11575	Business	21500.00
0005432948921	11575	Business	21500.00
0005432948905	11575	Business	21500.00
0005433569201	11575	Business	21500.00
0005433569011	11575	Business	21500.00
0005432948913	11575	Business	21500.00
0005432948916	11575	Business	21500.00
0005432948912	11575	Business	21500.00
0005432948891	11575	Business	21500.00
0005433075020	11575	Business	21500.00
0005433568977	11575	Business	21500.00
0005433075016	11575	Economy	7900.00
0005433075042	11575	Economy	7900.00
0005432192357	11575	Economy	7900.00
0005432948900	11575	Economy	7900.00
0005433075024	11575	Economy	7900.00
0005432948926	11575	Economy	7200.00
0005433569241	11575	Economy	7200.00
0005433075028	11575	Economy	7200.00
0005433131761	11575	Economy	7200.00
0005433569007	11575	Economy	7200.00
0005433134188	11575	Economy	7200.00
0005433569152	11575	Economy	7200.00
0005433075023	11575	Economy	7200.00
0005433075017	11575	Economy	7200.00
0005433569023	11575	Economy	7200.00
0005433569277	11575	Economy	7200.00
0005433569012	11575	Economy	7200.00
0005433134190	11575	Economy	7200.00
0005433075043	11575	Economy	7200.00
0005433075041	11575	Economy	7200.00
0005433569175	11575	Economy	7200.00
0005432948918	11575	Economy	7200.00
0005433569076	11575	Economy	7200.00
0005432948919	11575	Economy	7200.00
0005433568916	11575	Economy	7200.00
0005433568776	11575	Economy	7200.00
0005433134191	11575	Economy	7200.00
0005432948895	11575	Economy	7200.00
0005432948914	11575	Economy	7200.00
0005433075031	11575	Economy	7200.00
0005433569276	11575	Economy	7200.00
0005433569115	11575	Economy	7200.00
0005433569157	11575	Economy	7200.00
0005433075029	11575	Economy	7200.00
0005432192356	11575	Economy	7200.00
0005433075022	11575	Economy	7200.00
0005433075015	11575	Economy	7200.00
0005432948909	11575	Economy	7200.00
0005433568976	11575	Economy	7200.00
0005433569206	11575	Economy	7200.00
0005432192355	11575	Economy	7200.00
0005433569207	11575	Economy	7200.00
0005433568872	11575	Economy	7200.00
0005432948923	11575	Economy	7200.00
0005433075030	11575	Economy	7200.00
0005432948910	11575	Economy	7200.00
0005433569134	11575	Economy	7200.00
0005433075037	11575	Economy	7200.00
0005433569147	11575	Economy	7200.00
0005433569135	11575	Economy	7200.00
0005433134189	11575	Economy	7200.00
0005432948902	11575	Economy	7200.00
0005433569149	11575	Economy	7200.00
0005433569061	11575	Economy	7200.00
0005433075025	11575	Economy	7200.00
0005433569116	11575	Economy	7200.00
0005433569224	11575	Economy	7900.00
0005432948892	11575	Economy	7900.00
0005433075014	11575	Economy	7900.00
0005432948917	11575	Economy	7900.00
0005433569174	11575	Economy	7900.00
0005432948924	11575	Economy	7200.00
0005433568950	11575	Economy	7200.00
0005433568857	11575	Economy	7200.00
0005433568961	11575	Economy	7200.00
0005432948920	11575	Economy	7900.00
0005432948930	11575	Economy	7200.00
0005432948911	11575	Economy	7200.00
0005432948928	11575	Economy	7200.00
0005433569143	11575	Economy	7200.00
0005433568856	11575	Economy	7200.00
0005433569205	11575	Economy	7200.00
0005433568963	11575	Economy	7200.00
0005433131758	11575	Economy	7200.00
0005433568775	11575	Economy	7200.00
0005433075040	11575	Economy	7200.00
0005433075026	11575	Economy	7200.00
0005433569089	11575	Economy	7200.00
0005432948903	11575	Economy	7200.00
0005433568962	11575	Economy	7200.00
0005433131759	11575	Economy	7200.00
0005433568931	11575	Economy	7200.00
0005433075032	11575	Economy	7200.00
0005433075034	11575	Economy	7200.00
0005433569066	11575	Economy	7200.00
0005433075039	11575	Economy	7200.00
0005433569156	11575	Economy	7200.00
0005432948898	11575	Economy	7200.00
0005433569075	11575	Economy	7200.00
0005433075035	11575	Economy	7200.00
0005433568978	11575	Economy	7200.00
0005432948904	11575	Economy	7200.00
0005433569057	11575	Economy	7200.00
0005432948907	11575	Economy	7200.00
0005433075019	11575	Economy	7200.00
0005432948901	11575	Economy	7200.00
0005433075027	11575	Economy	7200.00
0005432948906	11575	Economy	7200.00
0005433075036	11575	Economy	7200.00
0005433569039	11575	Economy	7200.00
0005433569225	11575	Economy	7200.00
0005433075013	11575	Economy	7200.00
0005433569167	11575	Economy	7200.00
0005433569158	11575	Economy	7200.00
0005433569208	11575	Economy	7200.00
0005432948894	11575	Economy	7200.00
0005432948896	11575	Economy	7200.00
0005433569238	11575	Economy	7200.00
0005432948925	11575	Economy	7200.00
0005432948927	11575	Economy	7200.00
0005433569142	11575	Economy	7200.00
0005432948922	11575	Economy	7200.00
0005433569063	11575	Economy	7200.00
0005432948899	11575	Economy	7200.00
0005433569223	11575	Economy	7200.00
0005433568932	11575	Economy	7200.00
0005433569307	11575	Economy	7200.00
0005432948893	11575	Economy	7200.00
0005433569090	11575	Economy	7200.00
0005433569170	11575	Economy	7200.00
0005433075038	11575	Economy	7200.00
0005433817513	10058	Economy	6300.00
0005433817514	10058	Economy	6300.00
0005434732990	10058	Economy	6300.00
0005434732977	10058	Economy	6300.00
0005433817476	13941	Economy	6300.00
0005434733021	13941	Economy	6300.00
0005434733020	13941	Economy	6300.00
0005433817479	13941	Economy	6300.00
0005434733022	13941	Economy	6300.00
0005433817477	13941	Economy	6300.00
0005433817491	13941	Economy	6300.00
0005433817480	13941	Economy	6300.00
0005434733019	13941	Economy	6300.00
0005433817490	13941	Economy	6300.00
0005433817481	13941	Economy	6300.00
0005433817475	13941	Economy	6300.00
0005432300328	2325	Business	184500.00
0005432985134	2325	Business	184500.00
0005433754839	2325	Business	184500.00
0005432985173	2325	Business	184500.00
0005432985289	2325	Business	184500.00
0005433434713	2325	Business	184500.00
0005435982825	2325	Business	184500.00
0005432985039	2325	Business	184500.00
0005433434783	2325	Business	184500.00
0005432985119	2325	Business	184500.00
0005434731179	2325	Business	184500.00
0005435982838	2325	Business	184500.00
0005432655675	2325	Business	184500.00
0005432985315	2325	Business	184500.00
0005432985231	2325	Business	184500.00
0005432985189	2325	Business	184500.00
0005432655672	2325	Business	184500.00
0005433754849	2325	Business	184500.00
0005433434672	2325	Business	184500.00
0005432226125	2325	Business	184500.00
0005432300332	2325	Business	184500.00
0005433434760	2325	Business	184500.00
0005433434759	2325	Business	184500.00
0005432985103	2325	Business	184500.00
0005433754848	2325	Business	184500.00
0005435982816	2325	Business	184500.00
0005433434767	2325	Business	184500.00
0005432869529	2325	Business	184500.00
0005433754870	2325	Business	184500.00
0005435982835	2325	Economy	67700.00
0005433434721	2325	Economy	67700.00
0005435982832	2325	Economy	67700.00
0005433754869	2325	Economy	67700.00
0005433434680	2325	Economy	61500.00
0005433434752	2325	Economy	61500.00
0005433766681	2325	Economy	61500.00
0005433754866	2325	Economy	61500.00
0005435982813	2325	Economy	61500.00
0005435982818	2325	Economy	61500.00
0005433754851	2325	Economy	61500.00
0005432985137	2325	Economy	61500.00
0005433754884	2325	Economy	61500.00
0005432985172	2325	Economy	61500.00
0005433434743	2325	Economy	61500.00
0005433754889	2325	Economy	61500.00
0005432985007	2325	Economy	61500.00
0005432985265	2325	Economy	61500.00
0005432869513	2325	Economy	61500.00
0005433754878	2325	Economy	61500.00
0005433434731	2325	Economy	61500.00
0005432226131	2325	Economy	61500.00
0005432985038	2325	Economy	61500.00
0005433754844	2325	Economy	61500.00
0005433434658	2325	Economy	61500.00
0005433754888	2325	Economy	61500.00
0005433754868	2325	Economy	61500.00
0005432655674	2325	Economy	61500.00
0005433754885	2325	Economy	61500.00
0005433754883	2325	Economy	61500.00
0005433434753	2325	Economy	61500.00
0005435982839	2325	Economy	61500.00
0005433754879	2325	Economy	61500.00
0005433754840	2325	Economy	61500.00
0005432655677	2325	Economy	61500.00
0005434731180	2325	Economy	61500.00
0005435982836	2325	Economy	61500.00
0005433754886	2325	Economy	61500.00
0005433754873	2325	Economy	61500.00
0005433434681	2325	Economy	61500.00
0005433754847	2325	Economy	61500.00
0005432985258	2325	Economy	61500.00
0005435982814	2325	Economy	61500.00
0005432300330	2325	Economy	61500.00
0005433766682	2325	Economy	61500.00
0005432985322	2325	Economy	61500.00
0005433754836	2325	Economy	61500.00
0005435982823	2325	Economy	61500.00
0005432985136	2325	Economy	61500.00
0005435982831	2325	Economy	61500.00
0005433754837	2325	Economy	61500.00
0005435982828	2325	Economy	61500.00
0005432985076	2325	Economy	61500.00
0005432226127	2325	Economy	61500.00
0005432985033	2325	Economy	61500.00
0005433754857	2325	Economy	61500.00
0005432985251	2325	Economy	61500.00
0005432655670	2325	Economy	61500.00
0005435982837	2325	Economy	61500.00
0005432985283	2325	Economy	61500.00
0005433754874	2325	Economy	61500.00
0005432985148	2325	Economy	61500.00
0005432985316	2325	Economy	61500.00
0005432226130	2325	Economy	61500.00
0005433434638	2325	Economy	61500.00
0005435982822	2325	Economy	61500.00
0005433434809	2325	Economy	61500.00
0005435982820	2325	Economy	61500.00
0005433754834	2325	Economy	61500.00
0005433754887	2325	Economy	61500.00
0005433754875	2325	Economy	61500.00
0005432300331	2325	Economy	61500.00
0005433754859	2325	Economy	61500.00
0005433754860	2325	Economy	61500.00
0005433754871	2325	Economy	61500.00
0005432985195	2325	Economy	61500.00
0005435982827	2325	Economy	61500.00
0005433434637	2325	Economy	61500.00
0005435982815	2325	Economy	61500.00
0005433754865	2325	Economy	61500.00
0005432655669	2325	Economy	61500.00
0005435982812	2325	Economy	61500.00
0005432655673	2325	Economy	61500.00
0005433754853	2325	Economy	61500.00
0005432985232	2325	Economy	61500.00
0005432985198	2325	Economy	61500.00
0005435982824	2325	Economy	61500.00
0005432985170	2325	Economy	61500.00
0005432226128	2325	Economy	61500.00
0005432985097	2325	Economy	61500.00
0005432655668	2325	Economy	61500.00
0005432655678	2325	Economy	61500.00
0005433434763	2325	Economy	61500.00
0005432985193	2325	Economy	61500.00
0005432985264	2325	Economy	61500.00
0005433434663	2325	Economy	61500.00
0005433754843	2325	Economy	61500.00
0005433766683	2325	Economy	61500.00
0005433754841	2325	Economy	61500.00
0005433754876	2325	Economy	61500.00
0005433754880	2325	Economy	67700.00
0005435982834	2325	Economy	67700.00
0005432655676	2325	Economy	61500.00
0005433434671	2325	Economy	61500.00
0005432869545	2325	Economy	61500.00
0005433434682	2325	Economy	67700.00
0005432985174	2325	Economy	67700.00
0005433434765	2325	Economy	61500.00
0005433434826	2325	Economy	61500.00
0005433754862	2325	Economy	61500.00
0005432985317	2325	Economy	61500.00
0005433434709	2325	Economy	61500.00
0005433434732	2325	Economy	61500.00
0005435982842	2325	Economy	61500.00
0005435982841	2325	Economy	61500.00
0005435982843	2325	Economy	61500.00
0005433754835	2325	Economy	61500.00
0005433766684	2325	Economy	61500.00
0005432869528	2325	Economy	61500.00
0005433754858	2325	Economy	61500.00
0005432985259	2325	Economy	61500.00
0005433754852	2325	Economy	61500.00
0005432985180	2325	Economy	61500.00
0005433754861	2325	Economy	61500.00
0005433754854	2325	Economy	61500.00
0005435982819	2325	Economy	61500.00
0005432655671	2325	Economy	61500.00
0005433754842	2325	Economy	61500.00
0005432300329	2325	Economy	61500.00
0005432985080	2325	Economy	61500.00
0005435982821	2325	Economy	61500.00
0005432985124	2325	Economy	61500.00
0005433434717	2325	Economy	61500.00
0005433434616	2325	Economy	61500.00
0005432655679	2325	Economy	61500.00
0005432985249	2325	Economy	61500.00
0005433754863	2325	Economy	61500.00
0005432985120	2325	Economy	61500.00
0005434731169	2325	Economy	61500.00
0005432226129	2325	Economy	61500.00
0005435982833	2325	Economy	61500.00
0005432985075	2325	Economy	61500.00
0005433754867	2325	Economy	61500.00
0005433754882	2325	Economy	61500.00
0005435982826	2325	Economy	61500.00
0005433754890	2325	Economy	61500.00
0005433434700	2325	Economy	61500.00
0005432869503	2325	Economy	61500.00
0005432985252	2325	Economy	61500.00
0005433434722	2325	Economy	61500.00
0005432985146	2325	Economy	61500.00
0005433754872	2325	Economy	61500.00
0005432985221	2325	Economy	61500.00
0005432985032	2325	Economy	61500.00
0005432985194	2325	Economy	61500.00
0005433754877	2325	Economy	61500.00
0005433766685	2325	Economy	61500.00
0005433434766	2325	Economy	61500.00
0005433754838	2325	Economy	61500.00
0005432985168	2325	Economy	61500.00
0005433754845	2325	Economy	61500.00
0005432985147	2325	Economy	61500.00
0005433754846	2325	Economy	61500.00
0005435982830	2325	Economy	61500.00
0005433434827	2325	Economy	61500.00
0005433754864	2325	Economy	61500.00
0005432985190	2325	Economy	61500.00
0005433754881	2325	Economy	61500.00
0005435982829	2325	Economy	61500.00
0005433754856	2325	Economy	61500.00
0005433434716	2325	Economy	61500.00
0005432226126	2325	Economy	61500.00
0005433434730	2325	Economy	61500.00
0005435982817	2325	Economy	61500.00
0005435982840	2325	Economy	61500.00
0005433754850	2325	Economy	61500.00
0005433764703	2325	Economy	61500.00
0005432869546	2325	Economy	61500.00
0005433434790	2325	Economy	61500.00
0005432985323	2325	Economy	61500.00
0005432300327	2325	Economy	61500.00
0005433754855	2325	Economy	61500.00
0005433434987	26194	Business	184500.00
0005433754357	26194	Business	184500.00
0005435982515	26194	Business	184500.00
0005435982223	26194	Business	184500.00
0005432869599	26194	Business	184500.00
0005433754282	26194	Business	184500.00
0005432985447	26194	Business	184500.00
0005435982358	26194	Business	184500.00
0005433754360	26194	Business	184500.00
0005434731218	26194	Business	184500.00
0005432985462	26194	Business	184500.00
0005433434988	26194	Business	184500.00
0005433754482	26194	Business	184500.00
0005433754455	26194	Business	184500.00
0005432985430	26194	Business	184500.00
0005435982346	26194	Business	184500.00
0005432985449	26194	Business	184500.00
0005435982407	26194	Business	184500.00
0005435982088	26194	Business	184500.00
0005432985437	26194	Business	184500.00
0005432655535	26194	Business	184500.00
0005435982426	26194	Business	184500.00
0005433754212	26194	Business	184500.00
0005435982393	26194	Business	184500.00
0005433434986	26194	Business	184500.00
0005433754464	26194	Business	184500.00
0005432985454	26194	Economy	67700.00
0005435982149	26194	Economy	67700.00
0005433754295	26194	Economy	61500.00
0005435982416	26194	Economy	61500.00
0005432985434	26194	Economy	61500.00
0005433754317	26194	Economy	61500.00
0005432051163	26194	Economy	61500.00
0005435982381	26194	Economy	61500.00
0005433434990	26194	Economy	61500.00
0005433435001	26194	Economy	61500.00
0005433435006	26194	Economy	61500.00
0005432655523	26194	Economy	61500.00
0005432051162	26194	Economy	61500.00
0005433753972	26194	Economy	61500.00
0005435982628	26194	Economy	61500.00
0005435982377	26194	Economy	61500.00
0005432869598	26194	Economy	61500.00
0005432985451	26194	Economy	61500.00
0005433754465	26194	Economy	61500.00
0005432869595	26194	Economy	61500.00
0005433754475	26194	Economy	61500.00
0005435982384	26194	Economy	61500.00
0005433434997	26194	Economy	61500.00
0005432985450	26194	Economy	61500.00
0005433754461	26194	Economy	61500.00
0005432985429	26194	Economy	61500.00
0005433434995	26194	Economy	61500.00
0005435982528	26194	Economy	61500.00
0005433754595	26194	Economy	61500.00
0005433435014	26194	Economy	61500.00
0005434731221	26194	Economy	61500.00
0005432985438	26194	Economy	61500.00
0005433435009	26194	Economy	61500.00
0005433753991	26194	Economy	61500.00
0005433754231	26194	Economy	61500.00
0005432051164	26194	Economy	61500.00
0005435982278	26194	Economy	61500.00
0005435982087	26194	Economy	61500.00
0005433754416	26194	Economy	61500.00
0005435982357	26194	Economy	61500.00
0005432655526	26194	Economy	61500.00
0005435982383	26194	Economy	61500.00
0005433435011	26194	Economy	61500.00
0005434731219	26194	Economy	61500.00
0005435982378	26194	Economy	61500.00
0005435982379	26194	Economy	61500.00
0005433754236	26194	Economy	61500.00
0005433754332	26194	Economy	61500.00
0005432655569	26194	Economy	61500.00
0005432985461	26194	Economy	61500.00
0005433754163	26194	Economy	61500.00
0005432985446	26194	Economy	61500.00
0005432985460	26194	Economy	61500.00
0005433754447	26194	Economy	61500.00
0005432985436	26194	Economy	61500.00
0005433754356	26194	Economy	61500.00
0005435982359	26194	Economy	61500.00
0005433754515	26194	Economy	61500.00
0005435982482	26194	Economy	61500.00
0005432985440	26194	Economy	61500.00
0005435982586	26194	Economy	61500.00
0005432869596	26194	Economy	61500.00
0005432655558	26194	Economy	61500.00
0005433754510	26194	Economy	61500.00
0005432655559	26194	Economy	61500.00
0005435982526	26194	Economy	61500.00
0005433754170	26194	Economy	61500.00
0005435982470	26194	Economy	61500.00
0005434731220	26194	Economy	61500.00
0005433754353	26194	Economy	61500.00
0005432655557	26194	Economy	61500.00
0005433754336	26194	Economy	61500.00
0005435982411	26194	Economy	61500.00
0005433754355	26194	Economy	61500.00
0005433754381	26194	Economy	61500.00
0005433754380	26194	Economy	61500.00
0005435982279	26194	Economy	61500.00
0005432985442	26194	Economy	61500.00
0005432985433	26194	Economy	61500.00
0005433435000	26194	Economy	61500.00
0005433434998	26194	Economy	61500.00
0005432985435	26194	Economy	61500.00
0005435982089	26194	Economy	61500.00
0005433764686	26194	Economy	61500.00
0005433754379	26194	Economy	61500.00
0005432985441	26194	Economy	61500.00
0005433434996	26194	Economy	61500.00
0005435982410	26194	Economy	61500.00
0005433435008	26194	Economy	61500.00
0005433754369	26194	Economy	61500.00
0005433754237	26194	Economy	61500.00
0005435982243	26194	Economy	61500.00
0005433754171	26194	Economy	61500.00
0005433434993	26194	Economy	61500.00
0005435982512	26194	Economy	61500.00
0005433766644	26194	Economy	61500.00
0005433754305	26194	Economy	61500.00
0005433754337	26194	Economy	61500.00
0005435982483	26194	Economy	67700.00
0005433754235	26194	Economy	61500.00
0005432049506	26194	Economy	61500.00
0005433754124	26194	Economy	61500.00
0005435982356	26194	Economy	67700.00
0005432869597	26194	Economy	61500.00
0005435982480	26194	Economy	61500.00
0005433435004	26194	Economy	61500.00
0005433434991	26194	Economy	61500.00
0005433435012	26194	Economy	61500.00
0005433434994	26194	Economy	61500.00
0005435982331	26194	Economy	61500.00
0005432985455	26194	Economy	61500.00
0005433754456	26194	Economy	61500.00
0005433435013	26194	Economy	61500.00
0005432985459	26194	Economy	61500.00
0005433766643	26194	Economy	61500.00
0005433754400	26194	Economy	61500.00
0005433754485	26194	Economy	61500.00
0005433754281	26194	Economy	61500.00
0005435982471	26194	Economy	61500.00
0005435982406	26194	Economy	61500.00
0005432985448	26194	Economy	61500.00
0005433435002	26194	Economy	61500.00
0005435982575	26194	Economy	61500.00
0005432985444	26194	Economy	61500.00
0005432869600	26194	Economy	61500.00
0005433434989	26194	Economy	61500.00
0005433754412	26194	Economy	61500.00
0005433435010	26194	Economy	61500.00
0005432985445	26194	Economy	61500.00
0005432985456	26194	Economy	61500.00
0005432869594	26194	Economy	61500.00
0005432985458	26194	Economy	61500.00
0005432985443	26194	Economy	61500.00
0005432655538	26194	Economy	61500.00
0005432049505	26194	Economy	61500.00
0005433754830	26194	Economy	61500.00
0005435982321	26194	Economy	61500.00
0005435982242	26194	Economy	61500.00
0005433754483	26194	Economy	61500.00
0005435982418	26194	Economy	61500.00
0005432985439	26194	Economy	61500.00
0005432655546	26194	Economy	61500.00
0005433435003	26194	Economy	61500.00
0005432655534	26194	Economy	61500.00
0005433754495	26194	Economy	61500.00
0005433754420	26194	Economy	61500.00
0005432655537	26194	Economy	61500.00
0005433754230	26194	Economy	61500.00
0005433434999	26194	Economy	61500.00
0005433435005	26194	Economy	61500.00
0005433754628	26194	Economy	61500.00
0005432655536	26194	Economy	61500.00
0005433754234	26194	Economy	61500.00
0005433754303	26194	Economy	61500.00
0005432985431	26194	Economy	61500.00
0005435982472	26194	Economy	61500.00
0005433754213	26194	Economy	61500.00
0005432985432	26194	Economy	61500.00
0005432985453	26194	Economy	61500.00
0005433434992	26194	Economy	61500.00
0005432985452	26194	Economy	61500.00
0005432655570	26194	Economy	61500.00
0005432655556	26194	Economy	61500.00
0005432985457	26194	Economy	61500.00
0005433435007	26194	Economy	61500.00
0005433754359	26194	Economy	61500.00
0005433754187	26194	Economy	61500.00
0005433754539	26194	Economy	61500.00
0005433753973	26194	Economy	61500.00
0005435982376	26194	Economy	61500.00
0005433754358	26194	Economy	61500.00
0005433764687	26194	Economy	61500.00
0005433151527	1531	Business	38900.00
0005433151359	1531	Business	38900.00
0005434375162	1531	Business	38900.00
0005434375181	1531	Business	38900.00
0005434375157	1531	Business	38900.00
0005433151407	1531	Business	38900.00
0005434375182	1531	Business	38900.00
0005434029660	1531	Business	38900.00
0005433931473	1531	Business	38900.00
0005432267970	1531	Business	38900.00
0005434375171	1531	Business	38900.00
0005434375167	1531	Economy	13000.00
0005434375177	1531	Economy	13000.00
0005433151473	1531	Economy	13000.00
0005433151404	1531	Economy	13000.00
0005434375158	1531	Economy	13000.00
0005433151602	1531	Economy	13000.00
0005434375175	1531	Economy	13000.00
0005433151499	1531	Economy	13000.00
0005433151621	1531	Economy	13000.00
0005434375185	1531	Economy	13000.00
0005434375184	1531	Economy	13000.00
0005433151388	1531	Economy	13000.00
0005433151424	1531	Economy	13000.00
0005434375174	1531	Economy	13000.00
0005433151428	1531	Economy	13000.00
0005433151450	1531	Economy	13000.00
0005433151493	1531	Economy	13000.00
0005434375159	1531	Economy	13000.00
0005433151422	1531	Economy	13000.00
0005433151425	1531	Economy	13000.00
0005434375150	1531	Economy	13000.00
0005433151659	1531	Economy	13000.00
0005434375160	1531	Economy	13000.00
0005434375151	1531	Economy	13000.00
0005433151375	1531	Economy	13000.00
0005432267973	1531	Economy	13000.00
0005434375154	1531	Economy	13000.00
0005433151461	1531	Economy	13000.00
0005434375152	1531	Economy	13000.00
0005433151462	1531	Economy	14300.00
0005433151661	1531	Economy	14300.00
0005433151622	1531	Economy	14300.00
0005433151563	1531	Economy	14300.00
0005434375188	1531	Economy	13000.00
0005433931472	1531	Economy	14300.00
0005434375168	1531	Economy	13000.00
0005433151532	1531	Economy	13000.00
0005433151483	1531	Economy	13000.00
0005433151534	1531	Economy	13000.00
0005434375170	1531	Economy	13000.00
0005433151508	1531	Economy	13000.00
0005433151561	1531	Economy	13000.00
0005434375187	1531	Economy	13000.00
0005434375183	1531	Economy	13000.00
0005433151511	1531	Economy	13000.00
0005434375164	1531	Economy	13000.00
0005433764689	1531	Economy	13000.00
0005433151658	1531	Economy	13000.00
0005432267968	1531	Economy	13000.00
0005433151474	1531	Economy	13000.00
0005434375161	1531	Economy	13000.00
0005433151479	1531	Economy	13000.00
0005433461612	1531	Economy	13000.00
0005433151579	1531	Economy	13000.00
0005432267972	1531	Economy	13000.00
0005433460460	1531	Economy	13000.00
0005433151423	1531	Economy	13000.00
0005433151547	1531	Economy	13000.00
0005433151506	1531	Economy	13000.00
0005433151526	1531	Economy	13000.00
0005434375163	1531	Economy	13000.00
0005434375153	1531	Economy	13000.00
0005433931474	1531	Economy	13000.00
0005433151668	1531	Economy	13000.00
0005434375156	1531	Economy	13000.00
0005433151484	1531	Economy	13000.00
0005432267974	1531	Economy	13000.00
0005434375186	1531	Economy	13000.00
0005434375176	1531	Economy	13000.00
0005434375173	1531	Economy	13000.00
0005434375178	1531	Economy	13000.00
0005433151387	1531	Economy	13000.00
0005433151562	1531	Economy	13000.00
0005434375165	1531	Economy	13000.00
0005433151564	1531	Economy	13000.00
0005433151451	1531	Economy	13000.00
0005433151475	1531	Economy	13000.00
0005433460461	1531	Economy	13000.00
0005433151774	1531	Economy	13000.00
0005433151476	1531	Economy	13000.00
0005433151595	1531	Economy	13000.00
0005433461613	1531	Economy	13000.00
0005433151463	1531	Economy	13000.00
0005433151405	1531	Economy	13000.00
0005433151433	1531	Economy	13000.00
0005432267971	1531	Economy	13000.00
0005434375166	1531	Economy	13000.00
0005433151740	1531	Economy	13000.00
0005434375172	1531	Economy	13000.00
0005433151452	1531	Economy	13000.00
0005434375180	1531	Economy	13000.00
0005433151469	1531	Economy	13000.00
0005434375169	1531	Economy	13000.00
0005432267969	1531	Economy	13000.00
0005433151741	1531	Economy	13000.00
0005434375155	1531	Economy	13000.00
0005434375179	1531	Economy	13000.00
0005433151793	20106	Business	38900.00
0005433151800	20106	Business	38900.00
0005433151804	20106	Business	38900.00
0005434374864	20106	Business	38900.00
0005434374738	20106	Business	38900.00
0005433151797	20106	Business	38900.00
0005433931501	20106	Business	38900.00
0005433151787	20106	Business	38900.00
0005434374582	20106	Business	38900.00
0005434374519	20106	Business	38900.00
0005433151786	20106	Economy	13000.00
0005434374821	20106	Economy	13000.00
0005433931503	20106	Economy	13000.00
0005433151783	20106	Economy	13000.00
0005434374689	20106	Economy	13000.00
0005434374472	20106	Economy	13000.00
0005434374800	20106	Economy	13000.00
0005433151779	20106	Economy	13000.00
0005433151791	20106	Economy	13000.00
0005433151809	20106	Economy	13000.00
0005434374590	20106	Economy	13000.00
0005434374870	20106	Economy	13000.00
0005433931502	20106	Economy	13000.00
0005433151789	20106	Economy	13000.00
0005433151782	20106	Economy	13000.00
0005434374663	20106	Economy	13000.00
0005434374764	20106	Economy	13000.00
0005433151808	20106	Economy	13000.00
0005434374865	20106	Economy	13000.00
0005434374668	20106	Economy	13000.00
0005434374561	20106	Economy	13000.00
0005433151812	20106	Economy	13000.00
0005434374711	20106	Economy	13000.00
0005433151788	20106	Economy	13000.00
0005434374684	20106	Economy	13000.00
0005434374665	20106	Economy	13000.00
0005434374688	20106	Economy	13000.00
0005434374863	20106	Economy	13000.00
0005433151795	20106	Economy	14300.00
0005433151799	20106	Economy	14300.00
0005434374794	20106	Economy	14300.00
0005434374749	20106	Economy	14300.00
0005434374810	20106	Economy	13000.00
0005432056341	20106	Economy	13000.00
0005432056340	20106	Economy	13000.00
0005433151781	20106	Economy	13000.00
0005433151778	20106	Economy	13000.00
0005434374733	20106	Economy	13000.00
0005433151796	20106	Economy	13000.00
0005433151802	20106	Economy	13000.00
0005434374829	20106	Economy	13000.00
0005434374852	20106	Economy	13000.00
0005434374823	20106	Economy	13000.00
0005433931504	20106	Economy	13000.00
0005433151784	20106	Economy	13000.00
0005434374853	20106	Economy	13000.00
0005434374601	20106	Economy	13000.00
0005433151780	20106	Economy	13000.00
0005433151785	20106	Economy	13000.00
0005434374866	20106	Economy	13000.00
0005434029686	20106	Economy	13000.00
0005433151807	20106	Economy	13000.00
0005433151803	20106	Economy	13000.00
0005433151811	20106	Economy	13000.00
0005433151801	20106	Economy	13000.00
0005433151790	20106	Economy	13000.00
0005434029685	20106	Economy	13000.00
0005433151805	20106	Economy	13000.00
0005434374793	20106	Economy	13000.00
0005434374871	20106	Economy	13000.00
0005434374741	20106	Economy	13000.00
0005434374868	20106	Economy	13000.00
0005433931500	20106	Economy	13000.00
0005434374851	20106	Economy	13000.00
0005434374669	20106	Economy	13000.00
0005434374693	20106	Economy	13000.00
0005434374615	20106	Economy	13000.00
0005434374518	20106	Economy	13000.00
0005434374681	20106	Economy	13000.00
0005433151792	20106	Economy	13000.00
0005434374874	20106	Economy	13000.00
0005434374710	20106	Economy	13000.00
0005433151810	20106	Economy	13000.00
0005434374880	20106	Economy	13000.00
0005434374716	20106	Economy	13000.00
0005434374740	20106	Economy	13000.00
0005434374517	20106	Economy	13000.00
0005433764703	20106	Economy	13000.00
0005434374686	20106	Economy	13000.00
0005433151798	20106	Economy	13000.00
0005433151806	20106	Economy	13000.00
0005434374859	20106	Economy	13000.00
0005434374732	20106	Economy	13000.00
0005434374739	20106	Economy	13000.00
0005433151794	20106	Economy	13000.00
0005434374867	20106	Economy	13000.00
0005434374666	20106	Economy	13000.00
0005434374827	20106	Economy	13000.00
0005434374674	20106	Economy	13000.00
0005434374715	20106	Economy	13000.00
0005432056343	20106	Economy	13000.00
0005432056342	20106	Economy	13000.00
0005432424982	545	Business	27500.00
0005432424984	545	Business	27500.00
0005432424970	545	Business	27500.00
0005432424972	545	Business	27500.00
0005432282946	545	Business	27500.00
0005432425002	545	Business	27500.00
0005432425005	545	Business	27500.00
0005432424965	545	Business	27500.00
0005432424988	545	Business	27500.00
0005432424967	545	Business	27500.00
0005432282943	545	Business	27500.00
0005432424981	545	Business	27500.00
0005432424986	545	Business	27500.00
0005432424968	545	Economy	10100.00
0005432424995	545	Economy	10100.00
0005432424991	545	Economy	9200.00
0005432424963	545	Economy	9200.00
0005432424989	545	Economy	9200.00
0005432425001	545	Economy	9200.00
0005432424974	545	Economy	9200.00
0005432282945	545	Economy	9200.00
0005432425008	545	Economy	9200.00
0005432425004	545	Economy	9200.00
0005432424990	545	Economy	9200.00
0005432424971	545	Economy	9200.00
0005432424994	545	Economy	9200.00
0005432424966	545	Economy	9200.00
0005432282941	545	Economy	9200.00
0005432282942	545	Economy	9200.00
0005432424964	545	Economy	10100.00
0005432424997	545	Economy	10100.00
0005432424962	545	Economy	9200.00
0005432424987	545	Economy	9200.00
0005432425007	545	Economy	9200.00
0005432424999	545	Economy	9200.00
0005432424976	545	Economy	9200.00
0005432424979	545	Economy	9200.00
0005432424998	545	Economy	9200.00
0005432424975	545	Economy	9200.00
0005432424973	545	Economy	9200.00
0005432424977	545	Economy	9200.00
0005432424980	545	Economy	9200.00
0005432424985	545	Economy	9200.00
0005432424992	545	Economy	9200.00
0005432425006	545	Economy	9200.00
0005432424969	545	Economy	9200.00
0005432424996	545	Economy	9200.00
0005432282947	545	Economy	9200.00
0005432424983	545	Economy	9200.00
0005432282944	545	Economy	9200.00
0005432425003	545	Economy	9200.00
0005432424993	545	Economy	9200.00
0005432425000	545	Economy	9200.00
0005432424978	545	Economy	9200.00
0005433158154	12832	Business	27500.00
0005433158157	12832	Business	27500.00
0005432302375	12832	Economy	9200.00
0005434446516	12832	Economy	9200.00
0005434446529	12832	Economy	9200.00
0005432302374	12832	Economy	9200.00
0005433158155	12832	Economy	9200.00
0005434446530	12832	Economy	10100.00
0005433158152	12832	Economy	9200.00
0005433158153	12832	Economy	9200.00
0005434446525	12832	Economy	9200.00
0005434446520	12832	Economy	9200.00
0005434446526	12832	Economy	9200.00
0005433158156	12832	Economy	9200.00
0005434446518	12832	Economy	9200.00
0005432424567	12888	Business	27500.00
0005432424536	12888	Business	27500.00
0005432424476	12888	Business	27500.00
0005432424498	12888	Business	27500.00
0005432424555	12888	Business	27500.00
0005432424457	12888	Business	27500.00
0005432424566	12888	Business	27500.00
0005432424528	12888	Business	27500.00
0005432424489	12888	Economy	10100.00
0005432424468	12888	Economy	10100.00
0005432424542	12888	Economy	9200.00
0005432424514	12888	Economy	9200.00
0005432424439	12888	Economy	9200.00
0005432424486	12888	Economy	9200.00
0005432424543	12888	Economy	9200.00
0005432424569	12888	Economy	9200.00
0005432424363	12888	Economy	9200.00
0005432424568	12888	Economy	9200.00
0005432424480	12888	Economy	9200.00
0005432424449	12888	Economy	9200.00
0005432424197	12888	Economy	9200.00
0005432424466	12888	Economy	9200.00
0005432424512	12888	Economy	9200.00
0005432424504	12888	Economy	9200.00
0005432424523	12888	Economy	9200.00
0005432424527	12888	Economy	9200.00
0005432424529	12888	Economy	9200.00
0005432424442	12888	Economy	9200.00
0005432424485	12888	Economy	9200.00
0005432424441	12888	Economy	9200.00
0005432424499	12888	Economy	9200.00
0005432424570	12888	Economy	10100.00
0005432424492	12888	Economy	9200.00
0005432424493	12888	Economy	9200.00
0005432424430	12888	Economy	9200.00
0005432424541	12888	Economy	9200.00
0005432424362	12888	Economy	9200.00
0005432424544	12888	Economy	9200.00
0005432424482	12888	Economy	9200.00
0005432424495	12888	Economy	9200.00
0005432424488	12888	Economy	9200.00
0005432424386	12888	Economy	9200.00
0005432424444	12888	Economy	9200.00
0005432424552	12888	Economy	9200.00
0005432424520	12888	Economy	9200.00
0005432424475	12888	Economy	9200.00
0005432424450	12888	Economy	9200.00
0005432424443	12888	Economy	9200.00
0005432424423	12888	Economy	9200.00
0005432424496	12888	Economy	9200.00
0005432424494	12888	Economy	9200.00
0005432424458	12888	Economy	9200.00
0005432424534	12888	Economy	9200.00
0005434024500	470	Business	24500.00
0005434735701	470	Business	24500.00
0005434024504	470	Business	24500.00
0005434024490	470	Business	24500.00
0005432235721	470	Business	24500.00
0005433058138	470	Business	24500.00
0005433929623	470	Business	24500.00
0005434024465	470	Business	24500.00
0005434024449	470	Business	24500.00
0005434024497	470	Business	24500.00
0005433058112	470	Business	24500.00
0005433057842	470	Business	24500.00
0005434024476	470	Business	24500.00
0005433057903	470	Business	24500.00
0005434028325	470	Business	24500.00
0005433058064	470	Business	24500.00
0005434024495	470	Business	24500.00
0005433057955	470	Economy	9000.00
0005433058022	470	Business	24500.00
0005433058111	470	Economy	9000.00
0005433058031	470	Economy	8200.00
0005434024445	470	Economy	8200.00
0005434735689	470	Economy	8200.00
0005433929614	470	Economy	8200.00
0005434024477	470	Economy	8200.00
0005434024469	470	Economy	8200.00
0005434024479	470	Economy	8200.00
0005433058256	470	Economy	8200.00
0005433058110	470	Economy	8200.00
0005434024505	470	Economy	8200.00
0005434024475	470	Economy	8200.00
0005434024484	470	Economy	8200.00
0005434024448	470	Economy	8200.00
0005432235720	470	Economy	8200.00
0005433058036	470	Economy	8200.00
0005434024488	470	Economy	8200.00
0005433057843	470	Economy	8200.00
0005434024462	470	Economy	8200.00
0005434024482	470	Economy	8200.00
0005433058151	470	Economy	8200.00
0005434024466	470	Economy	8200.00
0005434024491	470	Economy	8200.00
0005434024470	470	Economy	8200.00
0005433058038	470	Economy	8200.00
0005434024458	470	Economy	8200.00
0005433057956	470	Economy	8200.00
0005434024511	470	Economy	8200.00
0005434024464	470	Economy	8200.00
0005434024480	470	Economy	8200.00
0005434024472	470	Economy	8200.00
0005433057985	470	Economy	8200.00
0005434024442	470	Economy	8200.00
0005434024457	470	Economy	8200.00
0005434024471	470	Economy	8200.00
0005433057950	470	Economy	8200.00
0005433058126	470	Economy	8200.00
0005433057825	470	Economy	8200.00
0005434024487	470	Economy	8200.00
0005433684430	470	Economy	8200.00
0005434024508	470	Economy	8200.00
0005433057875	470	Economy	8200.00
0005434735683	470	Economy	8200.00
0005434024499	470	Economy	8200.00
0005434735697	470	Economy	8200.00
0005433058106	470	Economy	8200.00
0005434024501	470	Economy	8200.00
0005434024447	470	Economy	8200.00
0005434024473	470	Economy	8200.00
0005434024454	470	Economy	8200.00
0005434024494	470	Economy	8200.00
0005434024474	470	Economy	8200.00
0005434024460	470	Economy	8200.00
0005434032071	470	Economy	8200.00
0005432235723	470	Economy	8200.00
0005434735699	470	Economy	8200.00
0005434028324	470	Economy	8200.00
0005434024509	470	Economy	8200.00
0005432045634	470	Economy	8200.00
0005434024455	470	Economy	8200.00
0005433929615	470	Economy	8200.00
0005434024503	470	Economy	8200.00
0005434029684	470	Economy	8200.00
0005434024496	470	Economy	8200.00
0005433058029	470	Economy	8200.00
0005434024489	470	Economy	8200.00
0005434029683	470	Economy	8200.00
0005433058179	470	Economy	8200.00
0005433057826	470	Economy	8200.00
0005434024510	470	Economy	8200.00
0005432235726	470	Economy	9000.00
0005434024506	470	Economy	9000.00
0005433058191	470	Economy	8200.00
0005433058104	470	Economy	8200.00
0005434024461	470	Economy	9000.00
0005434024507	470	Economy	9000.00
0005434024478	470	Economy	8200.00
0005434024502	470	Economy	8200.00
0005434024493	470	Economy	8200.00
0005433684429	470	Economy	8200.00
0005434735688	470	Economy	8200.00
0005433057827	470	Economy	8200.00
0005434024456	470	Economy	8200.00
0005434024483	470	Economy	8200.00
0005433057841	470	Economy	8200.00
0005433684433	470	Economy	8200.00
0005434029682	470	Economy	8200.00
0005434024467	470	Economy	8200.00
0005434032073	470	Economy	8200.00
0005434028327	470	Economy	8200.00
0005433058128	470	Economy	8200.00
0005434735700	470	Economy	8200.00
0005433929622	470	Economy	8200.00
0005433057929	470	Economy	8200.00
0005434024453	470	Economy	8200.00
0005433058257	470	Economy	8200.00
0005434024452	470	Economy	8200.00
0005434024444	470	Economy	8200.00
0005433058105	470	Economy	8200.00
0005433058113	470	Economy	8200.00
0005433057937	470	Economy	8200.00
0005434024446	470	Economy	8200.00
0005433057936	470	Economy	8200.00
0005433058087	470	Economy	8200.00
0005434024486	470	Economy	8200.00
0005434024512	470	Economy	8200.00
0005434032070	470	Economy	8200.00
0005434735679	470	Economy	8200.00
0005432235724	470	Economy	8200.00
0005434024492	470	Economy	8200.00
0005434024459	470	Economy	8200.00
0005434032074	470	Economy	8200.00
0005434024468	470	Economy	8200.00
0005434028326	470	Economy	8200.00
0005433057894	470	Economy	8200.00
0005434024463	470	Economy	8200.00
0005434024485	470	Economy	8200.00
0005433929621	470	Economy	8200.00
0005434735676	470	Economy	8200.00
0005433058035	470	Economy	8200.00
0005434735677	470	Economy	8200.00
0005432235722	470	Economy	8200.00
0005434024451	470	Economy	8200.00
0005434024481	470	Economy	8200.00
0005432045633	470	Economy	8200.00
0005434024450	470	Economy	8200.00
0005434024443	470	Economy	8200.00
0005434032072	470	Economy	8200.00
0005432235725	470	Economy	8200.00
0005434024498	470	Economy	8200.00
0005433929620	470	Economy	8200.00
0005433058150	470	Economy	8200.00
0005433058127	470	Economy	8200.00
0005433058359	12697	Business	24500.00
0005434029660	12697	Business	24500.00
0005434023858	12697	Business	24500.00
0005434024131	12697	Business	24500.00
0005434024126	12697	Business	24500.00
0005433058342	12697	Business	24500.00
0005433058324	12697	Business	24500.00
0005434024130	12697	Business	24500.00
0005434024158	12697	Business	24500.00
0005433058345	12697	Business	24500.00
0005434023891	12697	Business	24500.00
0005433684445	12697	Business	24500.00
0005434024146	12697	Business	24500.00
0005434023548	12697	Business	24500.00
0005434023588	12697	Business	24500.00
0005433929660	12697	Business	24500.00
0005433929658	12697	Business	24500.00
0005433058358	12697	Business	24500.00
0005434023905	12697	Business	24500.00
0005433058340	12697	Economy	9000.00
0005434023969	12697	Economy	9000.00
0005433058323	12697	Economy	9000.00
0005434024103	12697	Economy	8200.00
0005434024053	12697	Economy	8200.00
0005434024161	12697	Economy	8200.00
0005434024077	12697	Economy	8200.00
0005434024205	12697	Economy	8200.00
0005434023970	12697	Economy	8200.00
0005434028299	12697	Economy	8200.00
0005434028307	12697	Economy	8200.00
0005433058320	12697	Economy	8200.00
0005434023711	12697	Economy	8200.00
0005434023761	12697	Economy	8200.00
0005433684444	12697	Economy	8200.00
0005433058331	12697	Economy	8200.00
0005433058339	12697	Economy	8200.00
0005434023826	12697	Economy	8200.00
0005433058355	12697	Economy	8200.00
0005433058321	12697	Economy	8200.00
0005433058328	12697	Economy	8200.00
0005434024011	12697	Economy	8200.00
0005434023978	12697	Economy	8200.00
0005434023971	12697	Economy	8200.00
0005433058346	12697	Economy	8200.00
0005434024127	12697	Economy	8200.00
0005434028298	12697	Economy	8200.00
0005434024159	12697	Economy	8200.00
0005434024030	12697	Economy	8200.00
0005434023838	12697	Economy	8200.00
0005433058334	12697	Economy	8200.00
0005434024052	12697	Economy	8200.00
0005433058326	12697	Economy	8200.00
0005434028314	12697	Economy	8200.00
0005433058343	12697	Economy	8200.00
0005434023797	12697	Economy	8200.00
0005434024111	12697	Economy	8200.00
0005434023896	12697	Economy	8200.00
0005433058332	12697	Economy	8200.00
0005433058337	12697	Economy	8200.00
0005434023737	12697	Economy	8200.00
0005434023925	12697	Economy	8200.00
0005432157514	12697	Economy	8200.00
0005434023620	12697	Economy	8200.00
0005434023736	12697	Economy	8200.00
0005434024110	12697	Economy	8200.00
0005434735749	12697	Economy	8200.00
0005434023839	12697	Economy	8200.00
0005434023879	12697	Economy	8200.00
0005433929661	12697	Economy	8200.00
0005434024010	12697	Economy	8200.00
0005434028283	12697	Economy	8200.00
0005434023958	12697	Economy	8200.00
0005432156416	12697	Economy	8200.00
0005434023829	12697	Economy	8200.00
0005434023878	12697	Economy	8200.00
0005433058351	12697	Economy	8200.00
0005433058344	12697	Economy	8200.00
0005434032015	12697	Economy	8200.00
0005433058349	12697	Economy	8200.00
0005433058330	12697	Economy	8200.00
0005434024081	12697	Economy	8200.00
0005433058357	12697	Economy	8200.00
0005433058354	12697	Economy	8200.00
0005433058353	12697	Economy	8200.00
0005433058319	12697	Economy	8200.00
0005434023589	12697	Economy	9000.00
0005434023856	12697	Economy	9000.00
0005433058350	12697	Economy	8200.00
0005433058356	12697	Economy	8200.00
0005434023968	12697	Economy	8200.00
0005433929659	12697	Economy	8200.00
0005434023892	12697	Economy	8200.00
0005432156417	12697	Economy	8200.00
0005434024109	12697	Economy	8200.00
0005434024033	12697	Economy	8200.00
0005434023816	12697	Economy	8200.00
0005434023806	12697	Economy	8200.00
0005433058338	12697	Economy	8200.00
0005433058336	12697	Economy	8200.00
0005434023926	12697	Economy	8200.00
0005434735748	12697	Economy	8200.00
0005434735750	12697	Economy	8200.00
0005434023972	12697	Economy	8200.00
0005434023959	12697	Economy	8200.00
0005433058325	12697	Economy	8200.00
0005433058348	12697	Economy	8200.00
0005434024106	12697	Economy	8200.00
0005434735751	12697	Economy	8200.00
0005434023836	12697	Economy	8200.00
0005434023913	12697	Economy	8200.00
0005433058335	12697	Economy	8200.00
0005433058347	12697	Economy	8200.00
0005434024107	12697	Economy	8200.00
0005433058360	12697	Economy	8200.00
0005434024162	12697	Economy	8200.00
0005434024029	12697	Economy	8200.00
0005434024075	12697	Economy	8200.00
0005433058333	12697	Economy	8200.00
0005433058341	12697	Economy	8200.00
0005434023721	12697	Economy	8200.00
0005433058329	12697	Economy	8200.00
0005434023683	12697	Economy	8200.00
0005434023837	12697	Economy	8200.00
0005434024105	12697	Economy	8200.00
0005434024206	12697	Economy	8200.00
0005434023549	12697	Economy	8200.00
0005434024160	12697	Economy	8200.00
0005433058352	12697	Economy	8200.00
0005433058322	12697	Economy	8200.00
0005433058327	12697	Economy	8200.00
0005434023995	12697	Economy	8200.00
0005434024214	12697	Economy	8200.00
0005434023967	12697	Economy	8200.00
0005432157513	12697	Economy	8200.00
0005433529310	13815	Business	111600.00
0005433527304	13815	Business	111600.00
0005433529316	13815	Business	111600.00
0005433529306	13815	Business	111600.00
0005433529311	13815	Economy	37200.00
0005433529304	13815	Economy	37200.00
0005433529317	13815	Economy	37200.00
0005433529313	13815	Economy	37200.00
0005433529314	13815	Economy	40900.00
0005433529318	13815	Economy	37200.00
0005433527308	13815	Economy	37200.00
0005433527299	13815	Economy	37200.00
0005433529308	13815	Economy	37200.00
0005433527302	13815	Economy	37200.00
0005433529305	13815	Economy	37200.00
0005433527297	13815	Economy	37200.00
0005433527298	13815	Economy	37200.00
0005433527301	13815	Economy	37200.00
0005433527300	13815	Economy	37200.00
0005433527293	13815	Economy	37200.00
0005433529315	13815	Economy	37200.00
0005433529309	13815	Economy	37200.00
0005433527309	13815	Economy	37200.00
0005433529307	13815	Economy	37200.00
0005433527307	13815	Economy	37200.00
0005433527294	13815	Economy	37200.00
0005433527306	13815	Economy	37200.00
0005433527296	13815	Economy	37200.00
0005433529312	13815	Economy	37200.00
0005433527295	13815	Economy	37200.00
0005433527305	13815	Economy	37200.00
0005433527303	13815	Economy	37200.00
0005433533318	32455	Business	111600.00
0005433533303	32455	Business	111600.00
0005433529281	32455	Business	111600.00
0005433533312	32455	Business	111600.00
0005433529250	32455	Business	111600.00
0005433533300	32455	Economy	37200.00
0005433533279	32455	Economy	37200.00
0005433529255	32455	Economy	37200.00
0005433533320	32455	Economy	37200.00
0005433529271	32455	Economy	37200.00
0005433533304	32455	Economy	37200.00
0005433529291	32455	Economy	40900.00
0005433533280	32455	Economy	37200.00
0005433529256	32455	Economy	37200.00
0005433533333	32455	Economy	37200.00
0005433529284	32455	Economy	37200.00
0005433529260	32455	Economy	37200.00
0005433529275	32455	Economy	37200.00
0005433533332	32455	Economy	37200.00
0005433533315	32455	Economy	37200.00
0005433529280	32455	Economy	37200.00
0005433533327	32455	Economy	37200.00
0005433533316	32455	Economy	37200.00
0005433529262	32455	Economy	37200.00
0005433529270	32455	Economy	37200.00
0005433533309	32455	Economy	37200.00
0005433533317	32455	Economy	37200.00
0005433533313	32455	Economy	37200.00
0005433529251	32455	Economy	37200.00
0005433529261	32455	Economy	37200.00
0005433529254	32455	Economy	37200.00
0005433529276	32455	Economy	37200.00
0005433924387	2146	Business	34700.00
0005433924354	2146	Business	34700.00
0005432231685	2146	Business	34700.00
0005433036372	2146	Business	34700.00
0005433931501	2146	Business	34700.00
0005433036221	2146	Business	34700.00
0005433036302	2146	Business	34700.00
0005433924408	2146	Business	34700.00
0005433924361	2146	Business	34700.00
0005433924346	2146	Business	34700.00
0005433036689	2146	Business	34700.00
0005433924431	2146	Business	34700.00
0005433924423	2146	Business	34700.00
0005433931504	2146	Business	34700.00
0005433924397	2146	Business	34700.00
0005433036618	2146	Business	34700.00
0005433875395	2146	Business	34700.00
0005433931502	2146	Business	34700.00
0005433924388	2146	Business	34700.00
0005433924424	2146	Business	34700.00
0005433924391	2146	Business	34700.00
0005433929659	2146	Business	34700.00
0005433036267	2146	Business	34700.00
0005433924405	2146	Economy	12700.00
0005433036508	2146	Economy	12700.00
0005433924339	2146	Economy	12700.00
0005433924373	2146	Economy	12700.00
0005433924385	2146	Economy	11600.00
0005432044556	2146	Economy	11600.00
0005433924410	2146	Economy	11600.00
0005433036619	2146	Economy	11600.00
0005433924392	2146	Economy	11600.00
0005433924342	2146	Economy	11600.00
0005433036366	2146	Economy	11600.00
0005433924377	2146	Economy	11600.00
0005433924341	2146	Economy	11600.00
0005432231687	2146	Economy	11600.00
0005433924368	2146	Economy	11600.00
0005433924362	2146	Economy	11600.00
0005433924353	2146	Economy	11600.00
0005433931503	2146	Economy	11600.00
0005433924411	2146	Economy	11600.00
0005433924336	2146	Economy	11600.00
0005433924429	2146	Economy	11600.00
0005432231689	2146	Economy	11600.00
0005432231688	2146	Economy	11600.00
0005433924402	2146	Economy	11600.00
0005433036334	2146	Economy	11600.00
0005433924426	2146	Economy	11600.00
0005432231684	2146	Economy	11600.00
0005433924371	2146	Economy	11600.00
0005433036654	2146	Economy	11600.00
0005433924400	2146	Economy	11600.00
0005434028307	2146	Economy	11600.00
0005433924401	2146	Economy	11600.00
0005433036496	2146	Economy	11600.00
0005433924370	2146	Economy	11600.00
0005434028299	2146	Economy	11600.00
0005433929658	2146	Economy	11600.00
0005433036590	2146	Economy	11600.00
0005433036479	2146	Economy	11600.00
0005434028298	2146	Economy	11600.00
0005433036249	2146	Economy	11600.00
0005433924404	2146	Economy	11600.00
0005433924383	2146	Economy	11600.00
0005433924398	2146	Economy	11600.00
0005433036605	2146	Economy	11600.00
0005433924416	2146	Economy	11600.00
0005433924403	2146	Economy	11600.00
0005433924343	2146	Economy	11600.00
0005433924428	2146	Economy	11600.00
0005433036591	2146	Economy	11600.00
0005433924386	2146	Economy	11600.00
0005433924374	2146	Economy	11600.00
0005433924363	2146	Economy	11600.00
0005433924432	2146	Economy	11600.00
0005433924338	2146	Economy	11600.00
0005433924433	2146	Economy	11600.00
0005433924382	2146	Economy	11600.00
0005433929661	2146	Economy	11600.00
0005433924412	2146	Economy	11600.00
0005433036332	2146	Economy	11600.00
0005433924422	2146	Economy	11600.00
0005433931500	2146	Economy	11600.00
0005433924372	2146	Economy	11600.00
0005433036492	2146	Economy	11600.00
0005434028283	2146	Economy	11600.00
0005433924395	2146	Economy	11600.00
0005433924344	2146	Economy	11600.00
0005433036467	2146	Economy	11600.00
0005433036452	2146	Economy	11600.00
0005433924357	2146	Economy	11600.00
0005433924355	2146	Economy	11600.00
0005433929660	2146	Economy	11600.00
0005433924337	2146	Economy	11600.00
0005433924394	2146	Economy	11600.00
0005433924414	2146	Economy	11600.00
0005433924413	2146	Economy	11600.00
0005433924350	2146	Economy	11600.00
0005433924366	2146	Economy	11600.00
0005433924418	2146	Economy	11600.00
0005433036385	2146	Economy	11600.00
0005432231679	2146	Economy	11600.00
0005433924359	2146	Economy	11600.00
0005433924425	2146	Economy	11600.00
0005432749793	2146	Economy	11600.00
0005433924347	2146	Economy	12700.00
0005433036487	2146	Economy	12700.00
0005433924376	2146	Economy	11600.00
0005433924427	2146	Economy	11600.00
0005433036636	2146	Economy	11600.00
0005433036369	2146	Economy	12700.00
0005433036491	2146	Economy	12700.00
0005433036362	2146	Economy	11600.00
0005433875396	2146	Economy	11600.00
0005433924407	2146	Economy	11600.00
0005433924420	2146	Economy	11600.00
0005433036606	2146	Economy	11600.00
0005433036468	2146	Economy	11600.00
0005433924409	2146	Economy	11600.00
0005433924380	2146	Economy	11600.00
0005433924364	2146	Economy	11600.00
0005433036521	2146	Economy	11600.00
0005432749787	2146	Economy	11600.00
0005433036688	2146	Economy	11600.00
0005433036276	2146	Economy	11600.00
0005433924419	2146	Economy	11600.00
0005433924384	2146	Economy	11600.00
0005433924379	2146	Economy	11600.00
0005433924349	2146	Economy	11600.00
0005433924352	2146	Economy	11600.00
0005433924415	2146	Economy	11600.00
0005432044555	2146	Economy	11600.00
0005433924358	2146	Economy	11600.00
0005433924356	2146	Economy	11600.00
0005433924348	2146	Economy	11600.00
0005433924351	2146	Economy	11600.00
0005433924393	2146	Economy	11600.00
0005433036620	2146	Economy	11600.00
0005433036374	2146	Economy	11600.00
0005433924396	2146	Economy	11600.00
0005433036236	2146	Economy	11600.00
0005433924381	2146	Economy	11600.00
0005433924365	2146	Economy	11600.00
0005432231680	2146	Economy	11600.00
0005433924360	2146	Economy	11600.00
0005433924390	2146	Economy	11600.00
0005433875394	2146	Economy	11600.00
0005433036594	2146	Economy	11600.00
0005433924421	2146	Economy	11600.00
0005432231683	2146	Economy	11600.00
0005433924417	2146	Economy	11600.00
0005433924430	2146	Economy	11600.00
0005433036495	2146	Economy	11600.00
0005433036303	2146	Economy	11600.00
0005433036371	2146	Economy	11600.00
0005433036522	2146	Economy	11600.00
0005433924369	2146	Economy	11600.00
0005433036607	2146	Economy	11600.00
0005433924406	2146	Economy	11600.00
0005432231686	2146	Economy	11600.00
0005433924399	2146	Economy	11600.00
0005433924389	2146	Economy	11600.00
0005434028314	2146	Economy	11600.00
0005433036453	2146	Economy	11600.00
0005433924340	2146	Economy	11600.00
0005432231682	2146	Economy	11600.00
0005433036350	2146	Economy	11600.00
0005433924375	2146	Economy	11600.00
0005433924345	2146	Economy	11600.00
0005432231681	2146	Economy	11600.00
0005433036484	2146	Economy	11600.00
0005433924378	2146	Economy	11600.00
0005433924367	2146	Economy	11600.00
0005433922945	24140	Business	34700.00
0005433036879	24140	Business	34700.00
0005433036901	24140	Business	34700.00
0005433923430	24140	Business	34700.00
0005433929631	24140	Business	34700.00
0005433923344	24140	Business	34700.00
0005433923888	24140	Business	34700.00
0005433036909	24140	Business	34700.00
0005434028330	24140	Business	34700.00
0005433923565	24140	Business	34700.00
0005433036914	24140	Business	34700.00
0005433929629	24140	Business	34700.00
0005432206261	24140	Business	34700.00
0005433036878	24140	Business	34700.00
0005432206260	24140	Business	34700.00
0005433036890	24140	Business	34700.00
0005433923401	24140	Business	34700.00
0005432206266	24140	Business	34700.00
0005433036894	24140	Business	34700.00
0005433036868	24140	Business	34700.00
0005433923435	24140	Business	34700.00
0005433036910	24140	Business	34700.00
0005433923778	24140	Business	34700.00
0005433036916	24140	Business	34700.00
0005433923456	24140	Business	34700.00
0005433922946	24140	Business	34700.00
0005433923276	24140	Economy	12700.00
0005433923650	24140	Economy	12700.00
0005433923816	24140	Economy	11600.00
0005433923714	24140	Economy	11600.00
0005433923626	24140	Economy	11600.00
0005433923314	24140	Economy	11600.00
0005433036917	24140	Economy	11600.00
0005433036900	24140	Economy	11600.00
0005433923305	24140	Economy	11600.00
0005433923628	24140	Economy	11600.00
0005433923786	24140	Economy	11600.00
0005433923983	24140	Economy	11600.00
0005433923546	24140	Economy	11600.00
0005433923494	24140	Economy	11600.00
0005433923535	24140	Economy	11600.00
0005433923200	24140	Economy	11600.00
0005432749810	24140	Economy	11600.00
0005433923638	24140	Economy	11600.00
0005433923461	24140	Economy	11600.00
0005433036899	24140	Economy	11600.00
0005432207692	24140	Economy	11600.00
0005433923420	24140	Economy	11600.00
0005433036898	24140	Economy	11600.00
0005432206265	24140	Economy	11600.00
0005433923273	24140	Economy	11600.00
0005433923819	24140	Economy	11600.00
0005433923732	24140	Economy	11600.00
0005433923804	24140	Economy	11600.00
0005434028328	24140	Economy	11600.00
0005433923555	24140	Economy	11600.00
0005433923534	24140	Economy	11600.00
0005433036911	24140	Economy	11600.00
0005433036875	24140	Economy	11600.00
0005433929611	24140	Economy	11600.00
0005433923625	24140	Economy	11600.00
0005433923923	24140	Economy	11600.00
0005433923692	24140	Economy	11600.00
0005433923620	24140	Economy	11600.00
0005433923469	24140	Economy	11600.00
0005433036883	24140	Economy	11600.00
0005433923754	24140	Economy	11600.00
0005433923803	24140	Economy	11600.00
0005433036881	24140	Economy	11600.00
0005433923333	24140	Economy	11600.00
0005433036886	24140	Economy	11600.00
0005433923795	24140	Economy	11600.00
0005433036885	24140	Economy	11600.00
0005433923958	24140	Economy	11600.00
0005433923425	24140	Economy	11600.00
0005433036915	24140	Economy	11600.00
0005433923777	24140	Economy	11600.00
0005433036892	24140	Economy	11600.00
0005433923357	24140	Economy	11600.00
0005433923418	24140	Economy	11600.00
0005433923657	24140	Economy	11600.00
0005433923334	24140	Economy	11600.00
0005433923421	24140	Economy	11600.00
0005433923609	24140	Economy	11600.00
0005433923554	24140	Economy	11600.00
0005433923414	24140	Economy	11600.00
0005433036921	24140	Economy	11600.00
0005433036907	24140	Economy	11600.00
0005433923662	24140	Economy	11600.00
0005433923661	24140	Economy	11600.00
0005433036919	24140	Economy	11600.00
0005433923659	24140	Economy	11600.00
0005433036893	24140	Economy	11600.00
0005433036869	24140	Economy	11600.00
0005433923815	24140	Economy	11600.00
0005434028331	24140	Economy	11600.00
0005433923335	24140	Economy	11600.00
0005433923356	24140	Economy	11600.00
0005433923502	24140	Economy	11600.00
0005433036876	24140	Economy	11600.00
0005433923640	24140	Economy	11600.00
0005433036884	24140	Economy	11600.00
0005432206263	24140	Economy	11600.00
0005433036889	24140	Economy	11600.00
0005433923006	24140	Economy	12700.00
0005433923354	24140	Economy	11600.00
0005433036872	24140	Economy	11600.00
0005433923818	24140	Economy	12700.00
0005433036913	24140	Economy	12700.00
0005433923293	24140	Economy	11600.00
0005433923693	24140	Economy	11600.00
0005433923649	24140	Economy	11600.00
0005433923730	24140	Economy	11600.00
0005433923691	24140	Economy	11600.00
0005433036902	24140	Economy	11600.00
0005433929608	24140	Economy	11600.00
0005433036896	24140	Economy	11600.00
0005433923627	24140	Economy	11600.00
0005433923274	24140	Economy	11600.00
0005433036903	24140	Economy	11600.00
0005433923542	24140	Economy	11600.00
0005433036871	24140	Economy	11600.00
0005433923501	24140	Economy	11600.00
0005433923594	24140	Economy	11600.00
0005433036891	24140	Economy	11600.00
0005433036906	24140	Economy	11600.00
0005433923602	24140	Economy	11600.00
0005433923306	24140	Economy	11600.00
0005433036895	24140	Economy	11600.00
0005433923792	24140	Economy	11600.00
0005433036874	24140	Economy	11600.00
0005434028332	24140	Economy	11600.00
0005433036873	24140	Economy	11600.00
0005433923220	24140	Economy	11600.00
0005433923402	24140	Economy	11600.00
0005433923470	24140	Economy	11600.00
0005433923595	24140	Economy	11600.00
0005433931481	24140	Economy	11600.00
0005433923887	24140	Economy	11600.00
0005433036920	24140	Economy	11600.00
0005434028329	24140	Economy	11600.00
0005433036870	24140	Economy	11600.00
0005432206259	24140	Economy	11600.00
0005433923257	24140	Economy	11600.00
0005433923219	24140	Economy	11600.00
0005433036905	24140	Economy	11600.00
0005433929618	24140	Economy	11600.00
0005432206264	24140	Economy	11600.00
0005433036882	24140	Economy	11600.00
0005433931475	24140	Economy	11600.00
0005433923753	24140	Economy	11600.00
0005432207691	24140	Economy	11600.00
0005433929609	24140	Economy	11600.00
0005433923566	24140	Economy	11600.00
0005433036912	24140	Economy	11600.00
0005433923814	24140	Economy	11600.00
0005433036918	24140	Economy	11600.00
0005433923598	24140	Economy	11600.00
0005433036908	24140	Economy	11600.00
0005433923820	24140	Economy	11600.00
0005433036877	24140	Economy	11600.00
0005433036897	24140	Economy	11600.00
0005433923553	24140	Economy	11600.00
0005433036887	24140	Economy	11600.00
0005433036888	24140	Economy	11600.00
0005433923514	24140	Economy	11600.00
0005432207690	24140	Economy	11600.00
0005433923982	24140	Economy	11600.00
0005433036880	24140	Economy	11600.00
0005433923387	24140	Economy	11600.00
0005432206262	24140	Economy	11600.00
0005433923601	24140	Economy	11600.00
0005433036904	24140	Economy	11600.00
0005434731217	249	Business	83700.00
0005434551864	249	Business	83700.00
0005433234313	249	Business	83700.00
0005433234333	249	Business	83700.00
0005434551874	249	Business	83700.00
0005434726898	249	Business	83700.00
0005433234145	249	Business	83700.00
0005433181099	249	Business	83700.00
0005433234288	249	Business	83700.00
0005433234146	249	Business	83700.00
0005433234416	249	Business	83700.00
0005434551837	249	Business	83700.00
0005434726849	249	Business	83700.00
0005434726888	249	Business	83700.00
0005433234450	249	Business	83700.00
0005433234240	249	Business	83700.00
0005434726801	249	Business	83700.00
0005433234174	249	Business	83700.00
0005433766653	249	Business	83700.00
0005434551877	249	Business	83700.00
0005435142729	249	Business	83700.00
0005434726902	249	Business	83700.00
0005433289878	249	Business	83700.00
0005433181170	249	Business	83700.00
0005434726783	249	Business	83700.00
0005433234284	249	Business	83700.00
0005434551830	249	Business	83700.00
0005433766639	249	Comfort	47400.00
0005433234413	249	Comfort	47400.00
0005433234415	249	Comfort	47400.00
0005433234588	249	Comfort	47400.00
0005434551865	249	Comfort	47400.00
0005434726806	249	Comfort	47400.00
0005433126849	249	Comfort	47400.00
0005434551825	249	Comfort	47400.00
0005433234283	249	Comfort	47400.00
0005435142737	249	Comfort	47400.00
0005434551872	249	Comfort	47400.00
0005432277966	249	Comfort	47400.00
0005434302506	249	Comfort	47400.00
0005434726864	249	Comfort	47400.00
0005434726843	249	Comfort	47400.00
0005434726789	249	Comfort	47400.00
0005434726874	249	Comfort	47400.00
0005434726824	249	Comfort	47400.00
0005434726886	249	Comfort	47400.00
0005434551850	249	Comfort	47400.00
0005433234148	249	Comfort	47400.00
0005434726862	249	Comfort	47400.00
0005434726825	249	Comfort	47400.00
0005433234153	249	Comfort	47400.00
0005434726840	249	Comfort	47400.00
0005433234209	249	Comfort	47400.00
0005433181184	249	Comfort	47400.00
0005433181144	249	Comfort	47400.00
0005434726833	249	Comfort	47400.00
0005434551875	249	Comfort	47400.00
0005433181195	249	Comfort	47400.00
0005434726781	249	Comfort	47400.00
0005433181093	249	Comfort	47400.00
0005433289899	249	Comfort	47400.00
0005434551829	249	Comfort	47400.00
0005433234455	249	Comfort	47400.00
0005434726883	249	Comfort	47400.00
0005434551834	249	Comfort	47400.00
0005434735743	249	Comfort	47400.00
0005433131721	249	Comfort	47400.00
0005434726839	249	Comfort	47400.00
0005434726831	249	Comfort	47400.00
0005434726848	249	Economy	27900.00
0005434735747	249	Comfort	47400.00
0005433234338	249	Economy	27900.00
0005433234546	249	Economy	27900.00
0005433234272	249	Economy	27900.00
0005433234467	249	Economy	27900.00
0005434551870	249	Economy	27900.00
0005434726836	249	Economy	27900.00
0005434551862	249	Economy	27900.00
0005435142734	249	Economy	27900.00
0005432277965	249	Economy	27900.00
0005434726876	249	Economy	27900.00
0005434726810	249	Economy	27900.00
0005434551847	249	Economy	27900.00
0005434551826	249	Economy	27900.00
0005432277960	249	Economy	27900.00
0005434726860	249	Economy	27900.00
0005433234269	249	Economy	27900.00
0005433766647	249	Economy	27900.00
0005434726809	249	Economy	27900.00
0005434551838	249	Economy	27900.00
0005435142725	249	Economy	27900.00
0005434726877	249	Economy	27900.00
0005433181213	249	Economy	27900.00
0005435142728	249	Economy	27900.00
0005433181237	249	Economy	27900.00
0005434726793	249	Economy	27900.00
0005434726785	249	Economy	27900.00
0005433289875	249	Economy	27900.00
0005433234276	249	Economy	27900.00
0005434726866	249	Economy	27900.00
0005433289877	249	Economy	27900.00
0005434726857	249	Economy	27900.00
0005434551853	249	Economy	27900.00
0005433234373	249	Economy	27900.00
0005434551831	249	Economy	27900.00
0005434551868	249	Economy	27900.00
0005433234437	249	Economy	27900.00
0005434726856	249	Economy	27900.00
0005433234105	249	Economy	27900.00
0005433234139	249	Economy	27900.00
0005434735744	249	Economy	27900.00
0005433181064	249	Economy	27900.00
0005434726834	249	Economy	27900.00
0005434726852	249	Economy	27900.00
0005433234456	249	Economy	27900.00
0005434726787	249	Economy	27900.00
0005434726788	249	Economy	27900.00
0005433234384	249	Economy	27900.00
0005434726844	249	Economy	27900.00
0005434726822	249	Economy	27900.00
0005434726800	249	Economy	27900.00
0005433234173	249	Economy	27900.00
0005434551832	249	Economy	27900.00
0005434726899	249	Economy	27900.00
0005434726853	249	Economy	27900.00
0005434551873	249	Economy	27900.00
0005434551867	249	Economy	27900.00
0005433234357	249	Economy	27900.00
0005433289898	249	Economy	27900.00
0005434302511	249	Economy	27900.00
0005433234448	249	Economy	27900.00
0005434726821	249	Economy	27900.00
0005433234529	249	Economy	27900.00
0005433289876	249	Economy	27900.00
0005434726889	249	Economy	27900.00
0005434726867	249	Economy	30700.00
0005434726855	249	Economy	27900.00
0005434726872	249	Economy	30700.00
0005434726865	249	Economy	30700.00
0005433111512	249	Economy	27900.00
0005433113540	249	Economy	27900.00
0005434731214	249	Economy	27900.00
0005434726794	249	Economy	30700.00
0005434551836	249	Economy	27900.00
0005433234444	249	Economy	30700.00
0005432277956	249	Economy	30700.00
0005434551879	249	Economy	27900.00
0005434726850	249	Economy	27900.00
0005434726792	249	Economy	27900.00
0005434726841	249	Economy	27900.00
0005434302508	249	Economy	27900.00
0005433234395	249	Economy	27900.00
0005432277954	249	Economy	27900.00
0005434551878	249	Economy	27900.00
0005434726892	249	Economy	27900.00
0005432277967	249	Economy	27900.00
0005433289900	249	Economy	27900.00
0005434726895	249	Economy	27900.00
0005434726791	249	Economy	27900.00
0005433113544	249	Economy	27900.00
0005434726784	249	Economy	27900.00
0005433181098	249	Economy	27900.00
0005434726897	249	Economy	27900.00
0005433234270	249	Economy	27900.00
0005434726896	249	Economy	27900.00
0005434726805	249	Economy	27900.00
0005433234198	249	Economy	27900.00
0005433234306	249	Economy	27900.00
0005432277957	249	Economy	27900.00
0005434032048	249	Economy	27900.00
0005433181244	249	Economy	27900.00
0005434726881	249	Economy	27900.00
0005433181092	249	Economy	27900.00
0005434551839	249	Economy	27900.00
0005433181127	249	Economy	27900.00
0005434726868	249	Economy	27900.00
0005433234567	249	Economy	27900.00
0005434726904	249	Economy	27900.00
0005433181245	249	Economy	27900.00
0005433234549	249	Economy	27900.00
0005433766640	249	Economy	27900.00
0005434726887	249	Economy	27900.00
0005433234347	249	Economy	27900.00
0005433234466	249	Economy	27900.00
0005434726808	249	Economy	27900.00
0005432277962	249	Economy	27900.00
0005433181161	249	Economy	27900.00
0005434726858	249	Economy	27900.00
0005432277959	249	Economy	27900.00
0005433181205	249	Economy	27900.00
0005433126844	249	Economy	27900.00
0005433234320	249	Economy	27900.00
0005433234454	249	Economy	27900.00
0005433234305	249	Economy	27900.00
0005435142733	249	Economy	27900.00
0005434551848	249	Economy	27900.00
0005434735742	249	Economy	27900.00
0005433234568	249	Economy	27900.00
0005434726813	249	Economy	27900.00
0005434726885	249	Economy	27900.00
0005433289840	249	Economy	27900.00
0005434551833	249	Economy	27900.00
0005435142727	249	Economy	27900.00
0005433234238	249	Economy	27900.00
0005433234449	249	Economy	27900.00
0005434726829	249	Economy	27900.00
0005434551824	249	Economy	27900.00
0005434726818	249	Economy	27900.00
0005434551845	249	Economy	27900.00
0005434726804	249	Economy	27900.00
0005434032049	249	Economy	27900.00
0005434726799	249	Economy	27900.00
0005434726827	249	Economy	27900.00
0005434551852	249	Economy	27900.00
0005434726826	249	Economy	27900.00
0005433126851	249	Economy	27900.00
0005434302509	249	Economy	27900.00
0005434726851	249	Economy	27900.00
0005434726832	249	Economy	27900.00
0005434726835	249	Economy	27900.00
0005433234106	249	Economy	27900.00
0005434726903	249	Economy	27900.00
0005434551851	249	Economy	27900.00
0005434551869	249	Economy	27900.00
0005434726798	249	Economy	27900.00
0005434726786	249	Economy	27900.00
0005433131711	249	Economy	27900.00
0005433126845	249	Economy	27900.00
0005434726884	249	Economy	27900.00
0005433234334	249	Economy	27900.00
0005433234463	249	Economy	27900.00
0005434726891	249	Economy	27900.00
0005434726845	249	Economy	27900.00
0005434726846	249	Economy	27900.00
0005433766637	249	Economy	27900.00
0005434551842	249	Economy	27900.00
0005434551849	249	Economy	27900.00
0005433234679	249	Economy	27900.00
0005434731213	249	Economy	27900.00
0005434551843	249	Economy	27900.00
0005434726815	249	Economy	27900.00
0005434726790	249	Economy	27900.00
0005435142730	249	Economy	27900.00
0005434726875	249	Economy	27900.00
0005434551828	249	Economy	27900.00
0005435142732	249	Economy	27900.00
0005434726828	249	Economy	27900.00
0005434726873	249	Economy	27900.00
0005432277964	249	Economy	27900.00
0005433234005	249	Economy	27900.00
0005434551827	249	Economy	27900.00
0005433234179	249	Economy	27900.00
0005434726863	249	Economy	27900.00
0005434726807	249	Economy	27900.00
0005433289879	249	Economy	27900.00
0005434726795	249	Economy	27900.00
0005434726871	249	Economy	30700.00
0005433234151	249	Economy	27900.00
0005434726817	249	Economy	30700.00
0005434551846	249	Economy	30700.00
0005432277961	249	Economy	30700.00
0005433234225	249	Economy	30700.00
0005434726906	249	Economy	30700.00
0005433234223	249	Economy	27900.00
0005433131724	249	Economy	27900.00
0005434726861	249	Economy	27900.00
0005434726814	249	Economy	27900.00
0005434551866	249	Economy	27900.00
0005434726847	249	Economy	27900.00
0005433289894	249	Economy	27900.00
0005434302510	249	Economy	27900.00
0005433234326	249	Economy	27900.00
0005433234241	249	Economy	27900.00
0005434551863	249	Economy	27900.00
0005434551871	249	Economy	27900.00
0005434726901	249	Economy	27900.00
0005434302507	249	Economy	27900.00
0005434726837	249	Economy	27900.00
0005433234436	249	Economy	27900.00
0005433289880	249	Economy	27900.00
0005433131720	249	Economy	27900.00
0005435142724	249	Economy	27900.00
0005433234237	249	Economy	27900.00
0005432277958	249	Economy	27900.00
0005434551859	249	Economy	27900.00
0005434726905	249	Economy	27900.00
0005434551844	249	Economy	27900.00
0005434726823	249	Economy	27900.00
0005434551858	249	Economy	27900.00
0005434726812	249	Economy	27900.00
0005433126848	249	Economy	27900.00
0005432277963	249	Economy	27900.00
0005433234453	249	Economy	27900.00
0005434726900	249	Economy	27900.00
0005433181194	249	Economy	27900.00
0005434735746	249	Economy	27900.00
0005434032032	249	Economy	27900.00
0005433181199	249	Economy	27900.00
0005434726882	249	Economy	27900.00
0005434726782	249	Economy	27900.00
0005434735745	249	Economy	27900.00
0005434551860	249	Economy	27900.00
0005434726811	249	Economy	27900.00
0005433234387	249	Economy	27900.00
0005434726869	249	Economy	27900.00
0005434726796	249	Economy	27900.00
0005433181143	249	Economy	27900.00
0005434731216	249	Economy	27900.00
0005433126850	249	Economy	27900.00
0005433234581	249	Economy	27900.00
0005433126858	249	Economy	27900.00
0005433181185	249	Economy	27900.00
0005434551841	249	Economy	27900.00
0005434726819	249	Economy	27900.00
0005435142736	249	Economy	27900.00
0005434726893	249	Economy	27900.00
0005435142726	249	Economy	27900.00
0005433234239	249	Economy	27900.00
0005434726854	249	Economy	27900.00
0005434726797	249	Economy	27900.00
0005434726870	249	Economy	27900.00
0005434551855	249	Economy	27900.00
0005434726879	249	Economy	27900.00
0005433289893	249	Economy	27900.00
0005434551835	249	Economy	27900.00
0005434726816	249	Economy	27900.00
0005434726878	249	Economy	27900.00
0005434551880	249	Economy	27900.00
0005434731215	249	Economy	27900.00
0005433131722	249	Economy	27900.00
0005433766636	249	Economy	27900.00
0005433181193	249	Economy	27900.00
0005433181078	249	Economy	27900.00
0005434551854	249	Economy	27900.00
0005433234337	249	Economy	27900.00
0005433131692	249	Economy	27900.00
0005433234271	249	Economy	27900.00
0005435142731	249	Economy	27900.00
0005432277955	249	Economy	27900.00
0005433234635	249	Economy	27900.00
0005434726803	249	Economy	27900.00
0005433181196	249	Economy	27900.00
0005434551861	249	Economy	27900.00
0005435142735	249	Economy	27900.00
0005433289839	249	Economy	27900.00
0005434551857	249	Economy	27900.00
0005433234242	249	Economy	27900.00
0005434551840	249	Economy	27900.00
0005434726838	249	Economy	27900.00
0005434726880	249	Economy	27900.00
0005434726842	249	Economy	27900.00
0005433234175	249	Economy	27900.00
0005434551856	249	Economy	27900.00
0005433234589	249	Economy	27900.00
0005434726859	249	Economy	27900.00
0005434726890	249	Economy	27900.00
0005433131723	249	Economy	27900.00
0005433234180	249	Economy	27900.00
0005434726820	249	Economy	27900.00
0005434726894	249	Economy	27900.00
0005433113541	249	Economy	27900.00
0005433234307	249	Economy	27900.00
0005434551876	249	Economy	27900.00
0005434726830	249	Economy	27900.00
0005434726802	249	Economy	27900.00
0005433181381	9844	Business	83700.00
0005433234938	9844	Business	83700.00
0005434032076	9844	Business	83700.00
0005434726047	9844	Business	83700.00
0005433181380	9844	Business	83700.00
0005433181390	9844	Business	83700.00
0005434726170	9844	Business	83700.00
0005433766684	9844	Business	83700.00
0005434726355	9844	Business	83700.00
0005433234896	9844	Business	83700.00
0005434551197	9844	Business	83700.00
0005433234915	9844	Business	83700.00
0005433234899	9844	Business	83700.00
0005433289930	9844	Business	83700.00
0005434725553	9844	Business	83700.00
0005434725621	9844	Business	83700.00
0005434551479	9844	Business	83700.00
0005434725437	9844	Business	83700.00
0005433289929	9844	Business	83700.00
0005434725747	9844	Business	83700.00
0005433234886	9844	Business	83700.00
0005434032079	9844	Business	83700.00
0005435142590	9844	Comfort	47400.00
0005434726111	9844	Comfort	47400.00
0005433234918	9844	Comfort	47400.00
0005434551435	9844	Comfort	47400.00
0005434725323	9844	Comfort	47400.00
0005434551273	9844	Comfort	47400.00
0005434551193	9844	Comfort	47400.00
0005435142525	9844	Comfort	47400.00
0005433289928	9844	Comfort	47400.00
0005433181372	9844	Comfort	47400.00
0005433234917	9844	Comfort	47400.00
0005434731180	9844	Comfort	47400.00
0005434551410	9844	Comfort	47400.00
0005433181396	9844	Comfort	47400.00
0005433181383	9844	Comfort	47400.00
0005433234931	9844	Comfort	47400.00
0005433234898	9844	Comfort	47400.00
0005435142615	9844	Comfort	47400.00
0005433181387	9844	Comfort	47400.00
0005434725934	9844	Comfort	47400.00
0005433181378	9844	Comfort	47400.00
0005433181379	9844	Comfort	47400.00
0005433234926	9844	Comfort	47400.00
0005434726032	9844	Comfort	47400.00
0005433234911	9844	Comfort	47400.00
0005434726228	9844	Comfort	47400.00
0005433234934	9844	Comfort	47400.00
0005433234908	9844	Comfort	47400.00
0005433234900	9844	Comfort	47400.00
0005434731179	9844	Comfort	47400.00
0005434726006	9844	Comfort	47400.00
0005434725886	9844	Comfort	47400.00
0005434551313	9844	Comfort	47400.00
0005433234919	9844	Comfort	47400.00
0005432199323	9844	Comfort	47400.00
0005434725643	9844	Comfort	47400.00
0005433234916	9844	Comfort	47400.00
0005433289927	9844	Comfort	47400.00
0005434725816	9844	Economy	27900.00
0005433234937	9844	Economy	27900.00
0005433234945	9844	Economy	27900.00
0005433181374	9844	Economy	27900.00
0005434725513	9844	Economy	27900.00
0005434551408	9844	Economy	27900.00
0005433181375	9844	Economy	27900.00
0005433234922	9844	Economy	27900.00
0005434725257	9844	Economy	27900.00
0005434726000	9844	Economy	27900.00
0005433234913	9844	Economy	27900.00
0005434726011	9844	Economy	27900.00
0005433234904	9844	Economy	27900.00
0005434725548	9844	Economy	27900.00
0005434551411	9844	Economy	27900.00
0005434551389	9844	Economy	27900.00
0005434725190	9844	Economy	27900.00
0005434551511	9844	Economy	27900.00
0005434551498	9844	Economy	27900.00
0005433181388	9844	Economy	27900.00
0005434726140	9844	Economy	27900.00
0005434726126	9844	Economy	27900.00
0005433289926	9844	Economy	27900.00
0005434551194	9844	Economy	27900.00
0005434725708	9844	Economy	27900.00
0005434725712	9844	Economy	27900.00
0005434551512	9844	Economy	27900.00
0005434725997	9844	Economy	27900.00
0005434726074	9844	Economy	27900.00
0005434725398	9844	Economy	27900.00
0005434725587	9844	Economy	27900.00
0005434725568	9844	Economy	27900.00
0005434725954	9844	Economy	27900.00
0005434551148	9844	Economy	27900.00
0005433181385	9844	Economy	27900.00
0005434725324	9844	Economy	27900.00
0005434725758	9844	Economy	27900.00
0005434725785	9844	Economy	27900.00
0005434726346	9844	Economy	27900.00
0005433234940	9844	Economy	27900.00
0005433234933	9844	Economy	27900.00
0005432199325	9844	Economy	27900.00
0005434726112	9844	Economy	27900.00
0005433766685	9844	Economy	27900.00
0005434726234	9844	Economy	27900.00
0005434725440	9844	Economy	27900.00
0005433129325	9844	Economy	27900.00
0005433234912	9844	Economy	27900.00
0005434726184	9844	Economy	27900.00
0005434725748	9844	Economy	27900.00
0005434726033	9844	Economy	27900.00
0005435142601	9844	Economy	27900.00
0005433129327	9844	Economy	27900.00
0005434551002	9844	Economy	27900.00
0005434725397	9844	Economy	27900.00
0005434302458	9844	Economy	27900.00
0005432199328	9844	Economy	27900.00
0005434725704	9844	Economy	30700.00
0005434551515	9844	Economy	27900.00
0005434725898	9844	Economy	27900.00
0005434725903	9844	Economy	27900.00
0005433234936	9844	Economy	27900.00
0005434551415	9844	Economy	30700.00
0005434726005	9844	Economy	30700.00
0005433234932	9844	Economy	27900.00
0005434726278	9844	Economy	27900.00
0005433234927	9844	Economy	27900.00
0005434726354	9844	Economy	27900.00
0005433289925	9844	Economy	27900.00
0005434725857	9844	Economy	27900.00
0005433234887	9844	Economy	27900.00
0005434551560	9844	Economy	27900.00
0005434551240	9844	Economy	27900.00
0005434725831	9844	Economy	27900.00
0005434725441	9844	Economy	27900.00
0005434032078	9844	Economy	27900.00
0005434725195	9844	Economy	27900.00
0005433234890	9844	Economy	27900.00
0005434731169	9844	Economy	27900.00
0005434726243	9844	Economy	27900.00
0005434551412	9844	Economy	27900.00
0005433126896	9844	Economy	27900.00
0005433234901	9844	Economy	27900.00
0005434726504	9844	Economy	27900.00
0005434551466	9844	Economy	27900.00
0005434032077	9844	Economy	27900.00
0005435142530	9844	Economy	27900.00
0005435142543	9844	Economy	27900.00
0005433181377	9844	Economy	27900.00
0005433181398	9844	Economy	27900.00
0005433234929	9844	Economy	27900.00
0005433234941	9844	Economy	27900.00
0005433234893	9844	Economy	27900.00
0005435142527	9844	Economy	27900.00
0005433234924	9844	Economy	27900.00
0005434726182	9844	Economy	27900.00
0005433289931	9844	Economy	27900.00
0005433181395	9844	Economy	27900.00
0005434725664	9844	Economy	27900.00
0005434726090	9844	Economy	27900.00
0005434725566	9844	Economy	27900.00
0005435142544	9844	Economy	27900.00
0005434725963	9844	Economy	27900.00
0005434551322	9844	Economy	27900.00
0005435142524	9844	Economy	27900.00
0005434551525	9844	Economy	27900.00
0005433234885	9844	Economy	27900.00
0005433181384	9844	Economy	27900.00
0005433234909	9844	Economy	27900.00
0005434551514	9844	Economy	27900.00
0005433181394	9844	Economy	27900.00
0005434551359	9844	Economy	27900.00
0005434725714	9844	Economy	27900.00
0005433181386	9844	Economy	27900.00
0005433234928	9844	Economy	27900.00
0005434551447	9844	Economy	27900.00
0005434551312	9844	Economy	27900.00
0005433113561	9844	Economy	27900.00
0005434725429	9844	Economy	27900.00
0005434551051	9844	Economy	27900.00
0005433766681	9844	Economy	27900.00
0005433234894	9844	Economy	27900.00
0005433234930	9844	Economy	27900.00
0005433234903	9844	Economy	27900.00
0005433234946	9844	Economy	27900.00
0005434551497	9844	Economy	27900.00
0005434725258	9844	Economy	27900.00
0005434725904	9844	Economy	27900.00
0005434726183	9844	Economy	27900.00
0005433234888	9844	Economy	27900.00
0005434725377	9844	Economy	27900.00
0005433181373	9844	Economy	27900.00
0005433181391	9844	Economy	27900.00
0005434726283	9844	Economy	27900.00
0005433181389	9844	Economy	27900.00
0005432199324	9844	Economy	27900.00
0005435142542	9844	Economy	27900.00
0005434725931	9844	Economy	27900.00
0005434551200	9844	Economy	27900.00
0005434551508	9844	Economy	27900.00
0005433129328	9844	Economy	27900.00
0005433234914	9844	Economy	27900.00
0005434725572	9844	Economy	27900.00
0005434551390	9844	Economy	27900.00
0005433129326	9844	Economy	27900.00
0005434725540	9844	Economy	27900.00
0005434551275	9844	Economy	27900.00
0005434726098	9844	Economy	27900.00
0005434551414	9844	Economy	27900.00
0005434725836	9844	Economy	27900.00
0005434551559	9844	Economy	27900.00
0005433234905	9844	Economy	30700.00
0005433234910	9844	Economy	27900.00
0005434551526	9844	Economy	30700.00
0005433766682	9844	Economy	30700.00
0005434551107	9844	Economy	27900.00
0005432199326	9844	Economy	30700.00
0005434725518	9844	Economy	27900.00
0005433181382	9844	Economy	27900.00
0005434726212	9844	Economy	27900.00
0005434551227	9844	Economy	27900.00
0005435142526	9844	Economy	27900.00
0005433129329	9844	Economy	27900.00
0005434551507	9844	Economy	27900.00
0005433126898	9844	Economy	27900.00
0005434726277	9844	Economy	27900.00
0005434551358	9844	Economy	27900.00
0005434725765	9844	Economy	27900.00
0005434725795	9844	Economy	27900.00
0005433113562	9844	Economy	27900.00
0005433181376	9844	Economy	27900.00
0005433234921	9844	Economy	27900.00
0005433234891	9844	Economy	27900.00
0005433766683	9844	Economy	27900.00
0005433234935	9844	Economy	27900.00
0005433234923	9844	Economy	27900.00
0005434551272	9844	Economy	27900.00
0005433234939	9844	Economy	27900.00
0005434551239	9844	Economy	27900.00
0005433234902	9844	Economy	27900.00
0005434726294	9844	Economy	27900.00
0005433234925	9844	Economy	27900.00
0005434725622	9844	Economy	27900.00
0005434551480	9844	Economy	27900.00
0005434726279	9844	Economy	27900.00
0005432199329	9844	Economy	27900.00
0005433126897	9844	Economy	27900.00
0005434725656	9844	Economy	27900.00
0005434726089	9844	Economy	27900.00
0005434725763	9844	Economy	27900.00
0005435142588	9844	Economy	27900.00
0005434551391	9844	Economy	27900.00
0005434551321	9844	Economy	27900.00
0005434725524	9844	Economy	27900.00
0005434725909	9844	Economy	27900.00
0005434725867	9844	Economy	27900.00
0005434725623	9844	Economy	27900.00
0005433181397	9844	Economy	27900.00
0005434551543	9844	Economy	27900.00
0005434725780	9844	Economy	27900.00
0005434726233	9844	Economy	27900.00
0005435142531	9844	Economy	27900.00
0005434551175	9844	Economy	27900.00
0005434726503	9844	Economy	27900.00
0005434551276	9844	Economy	27900.00
0005434725690	9844	Economy	27900.00
0005433181393	9844	Economy	27900.00
0005433234944	9844	Economy	27900.00
0005434725438	9844	Economy	27900.00
0005434551155	9844	Economy	27900.00
0005434726125	9844	Economy	27900.00
0005434726104	9844	Economy	27900.00
0005433234889	9844	Economy	27900.00
0005434725519	9844	Economy	27900.00
0005434726280	9844	Economy	27900.00
0005434725659	9844	Economy	27900.00
0005434726075	9844	Economy	27900.00
0005433234920	9844	Economy	27900.00
0005434725866	9844	Economy	27900.00
0005433234892	9844	Economy	27900.00
0005434725847	9844	Economy	27900.00
0005434551339	9844	Economy	27900.00
0005434726242	9844	Economy	27900.00
0005434725967	9844	Economy	27900.00
0005434551523	9844	Economy	27900.00
0005434726124	9844	Economy	27900.00
0005435142614	9844	Economy	27900.00
0005434725436	9844	Economy	27900.00
0005433234942	9844	Economy	27900.00
0005433234895	9844	Economy	27900.00
0005434302461	9844	Economy	27900.00
0005433234907	9844	Economy	27900.00
0005434032075	9844	Economy	27900.00
0005434551147	9844	Economy	27900.00
0005433234943	9844	Economy	27900.00
0005433181392	9844	Economy	27900.00
0005433234906	9844	Economy	27900.00
0005434551040	9844	Economy	27900.00
0005434735698	9844	Economy	27900.00
0005434726122	9844	Economy	27900.00
0005434725291	9844	Economy	27900.00
0005434725962	9844	Economy	27900.00
0005432199327	9844	Economy	27900.00
0005434725547	9844	Economy	27900.00
0005434726479	9844	Economy	27900.00
0005433234947	9844	Economy	27900.00
0005434551099	9844	Economy	27900.00
0005434725848	9844	Economy	27900.00
0005433234897	9844	Economy	27900.00
0005434551274	9844	Economy	27900.00
0005432537081	7753	Business	42100.00
0005434068353	7753	Business	42100.00
0005435213562	7753	Business	42100.00
0005432529500	7753	Business	42100.00
0005432529398	7753	Business	42100.00
0005432529447	7753	Business	42100.00
0005432150280	7753	Business	42100.00
0005432150282	7753	Business	42100.00
0005432529499	7753	Business	42100.00
0005432529433	7753	Business	42100.00
0005432529450	7753	Business	42100.00
0005434068337	7753	Business	42100.00
0005435213864	7753	Business	42100.00
0005435213913	7753	Business	42100.00
0005432529506	7753	Business	42100.00
0005434068352	7753	Business	42100.00
0005434068336	7753	Business	42100.00
0005432529431	7753	Business	42100.00
0005435213724	7753	Business	42100.00
0005435213589	7753	Business	42100.00
0005432529396	7753	Business	42100.00
0005432529391	7753	Business	42100.00
0005432529427	7753	Business	42100.00
0005434068334	7753	Business	42100.00
0005435725608	7753	Business	42100.00
0005434068342	7753	Business	42100.00
0005433656658	7753	Business	42100.00
0005432529392	7753	Comfort	23900.00
0005432529482	7753	Comfort	23900.00
0005432529481	7753	Comfort	23900.00
0005434068345	7753	Comfort	23900.00
0005435213694	7753	Comfort	23900.00
0005434068400	7753	Comfort	23900.00
0005434068378	7753	Comfort	23900.00
0005432529400	7753	Comfort	23900.00
0005435213577	7753	Comfort	23900.00
0005435213736	7753	Comfort	23900.00
0005432529454	7753	Comfort	23900.00
0005432529522	7753	Comfort	23900.00
0005432529518	7753	Comfort	23900.00
0005432529437	7753	Comfort	23900.00
0005432529393	7753	Comfort	23900.00
0005435213676	7753	Comfort	23900.00
0005434068371	7753	Comfort	23900.00
0005434068367	7753	Comfort	23900.00
0005434068358	7753	Comfort	23900.00
0005435213876	7753	Comfort	23900.00
0005434068380	7753	Comfort	23900.00
0005432529484	7753	Comfort	23900.00
0005432529483	7753	Comfort	23900.00
0005434068372	7753	Comfort	23900.00
0005434068350	7753	Comfort	23900.00
0005432529467	7753	Comfort	23900.00
0005434068376	7753	Comfort	23900.00
0005432529513	7753	Comfort	23900.00
0005434068392	7753	Comfort	23900.00
0005432069816	7753	Comfort	23900.00
0005434068357	7753	Comfort	23900.00
0005432529477	7753	Comfort	23900.00
0005432150285	7753	Comfort	23900.00
0005435213698	7753	Comfort	23900.00
0005434068340	7753	Comfort	23900.00
0005434068384	7753	Economy	14000.00
0005435213810	7753	Economy	14000.00
0005434068338	7753	Economy	14000.00
0005435214037	7753	Economy	14000.00
0005432529397	7753	Economy	14000.00
0005432529459	7753	Economy	14000.00
0005432529453	7753	Economy	14000.00
0005434068349	7753	Economy	14000.00
0005432150281	7753	Economy	14000.00
0005432529503	7753	Economy	14000.00
0005434068359	7753	Economy	14000.00
0005432529412	7753	Economy	14000.00
0005434068397	7753	Economy	14000.00
0005432529519	7753	Economy	14000.00
0005432529516	7753	Economy	14000.00
0005432069819	7753	Economy	14000.00
0005434068348	7753	Economy	14000.00
0005434068374	7753	Economy	14000.00
0005434068386	7753	Economy	14000.00
0005432529505	7753	Economy	14000.00
0005432529405	7753	Economy	14000.00
0005432529420	7753	Economy	14000.00
0005434068385	7753	Economy	14000.00
0005435213847	7753	Economy	14000.00
0005434068364	7753	Economy	14000.00
0005432529478	7753	Economy	14000.00
0005434068354	7753	Economy	14000.00
0005432069820	7753	Economy	14000.00
0005435213963	7753	Economy	14000.00
0005432529486	7753	Economy	14000.00
0005434068360	7753	Economy	14000.00
0005432529514	7753	Economy	14000.00
0005434068329	7753	Economy	14000.00
0005432428966	7753	Economy	14000.00
0005434068377	7753	Economy	14000.00
0005432069822	7753	Economy	14000.00
0005432529510	7753	Economy	14000.00
0005432529413	7753	Economy	14000.00
0005434068399	7753	Economy	14000.00
0005434068387	7753	Economy	14000.00
0005432529409	7753	Economy	14000.00
0005435630982	7753	Economy	14000.00
0005432529507	7753	Economy	14000.00
0005435213469	7753	Economy	14000.00
0005432529490	7753	Economy	14000.00
0005432529440	7753	Economy	14000.00
0005434068396	7753	Economy	14000.00
0005435213967	7753	Economy	14000.00
0005432069813	7753	Economy	14000.00
0005432529401	7753	Economy	14000.00
0005432529406	7753	Economy	14000.00
0005433656657	7753	Economy	14000.00
0005432529452	7753	Economy	14000.00
0005434068379	7753	Economy	14000.00
0005432150284	7753	Economy	14000.00
0005432529429	7753	Economy	14000.00
0005435213914	7753	Economy	14000.00
0005432529448	7753	Economy	15400.00
0005432529511	7753	Economy	15400.00
0005434068390	7753	Economy	14000.00
0005435213306	7753	Economy	15400.00
0005435213894	7753	Economy	14000.00
0005432529411	7753	Economy	14000.00
0005432529512	7753	Economy	15400.00
0005432069825	7753	Economy	14000.00
0005432533324	7753	Economy	15400.00
0005435213505	7753	Economy	15400.00
0005432529523	7753	Economy	14000.00
0005432069823	7753	Economy	14000.00
0005432529424	7753	Economy	14000.00
0005432529443	7753	Economy	14000.00
0005434068373	7753	Economy	14000.00
0005432529489	7753	Economy	14000.00
0005432529461	7753	Economy	14000.00
0005435725615	7753	Economy	14000.00
0005432529476	7753	Economy	14000.00
0005435213723	7753	Economy	14000.00
0005432529474	7753	Economy	14000.00
0005434068341	7753	Economy	14000.00
0005432535887	7753	Economy	14000.00
0005432529502	7753	Economy	14000.00
0005432529493	7753	Economy	14000.00
0005435213903	7753	Economy	14000.00
0005432529415	7753	Economy	14000.00
0005435213792	7753	Economy	14000.00
0005432529422	7753	Economy	14000.00
0005434068363	7753	Economy	14000.00
0005432529399	7753	Economy	14000.00
0005432529466	7753	Economy	14000.00
0005432529402	7753	Economy	14000.00
0005434068332	7753	Economy	14000.00
0005432150286	7753	Economy	14000.00
0005432529469	7753	Economy	14000.00
0005432150287	7753	Economy	14000.00
0005435213784	7753	Economy	14000.00
0005432533325	7753	Economy	14000.00
0005432529508	7753	Economy	14000.00
0005432529434	7753	Economy	14000.00
0005432529494	7753	Economy	14000.00
0005432529439	7753	Economy	14000.00
0005432529423	7753	Economy	14000.00
0005432428968	7753	Economy	14000.00
0005435213699	7753	Economy	14000.00
0005432529487	7753	Economy	14000.00
0005435213890	7753	Economy	14000.00
0005435213793	7753	Economy	14000.00
0005434068339	7753	Economy	14000.00
0005435213750	7753	Economy	14000.00
0005432529504	7753	Economy	14000.00
0005432529457	7753	Economy	14000.00
0005435213639	7753	Economy	14000.00
0005432069814	7753	Economy	14000.00
0005435213740	7753	Economy	14000.00
0005432069821	7753	Economy	14000.00
0005434068365	7753	Economy	14000.00
0005432529436	7753	Economy	14000.00
0005432529414	7753	Economy	14000.00
0005432529475	7753	Economy	14000.00
0005432535888	7753	Economy	14000.00
0005435213737	7753	Economy	14000.00
0005435213824	7753	Economy	14000.00
0005434068344	7753	Economy	14000.00
0005432529435	7753	Economy	14000.00
0005433656679	7753	Economy	14000.00
0005434068382	7753	Economy	14000.00
0005435213907	7753	Economy	14000.00
0005432529404	7753	Economy	14000.00
0005435213460	7753	Economy	14000.00
0005435725607	7753	Economy	14000.00
0005432529417	7753	Economy	14000.00
0005434068398	7753	Economy	14000.00
0005435213746	7753	Economy	14000.00
0005434068333	7753	Economy	14000.00
0005435213821	7753	Economy	14000.00
0005434068383	7753	Economy	14000.00
0005432529501	7753	Economy	14000.00
0005432529451	7753	Economy	14000.00
0005432529394	7753	Economy	14000.00
0005435213693	7753	Economy	14000.00
0005435213677	7753	Economy	14000.00
0005435213717	7753	Economy	14000.00
0005432529465	7753	Economy	14000.00
0005434068393	7753	Economy	14000.00
0005432529464	7753	Economy	14000.00
0005432529426	7753	Economy	14000.00
0005432529445	7753	Economy	14000.00
0005435213837	7753	Economy	14000.00
0005434068330	7753	Economy	14000.00
0005432529438	7753	Economy	14000.00
0005432529496	7753	Economy	14000.00
0005432529480	7753	Economy	14000.00
0005432150283	7753	Economy	14000.00
0005432069812	7753	Economy	14000.00
0005432537082	7753	Economy	14000.00
0005434068347	7753	Economy	14000.00
0005433656678	7753	Economy	14000.00
0005434068355	7753	Economy	14000.00
0005432529462	7753	Economy	14000.00
0005432529479	7753	Economy	14000.00
0005432529468	7753	Economy	14000.00
0005435213836	7753	Economy	14000.00
0005432529442	7753	Economy	14000.00
0005435213531	7753	Economy	15400.00
0005435214038	7753	Economy	15400.00
0005432069817	7753	Economy	15400.00
0005435213588	7753	Economy	15400.00
0005432529446	7753	Economy	14000.00
0005434068394	7753	Economy	14000.00
0005432529471	7753	Economy	14000.00
0005435213745	7753	Economy	14000.00
0005434068370	7753	Economy	14000.00
0005432069815	7753	Economy	14000.00
0005433656663	7753	Economy	14000.00
0005434068361	7753	Economy	14000.00
0005435213590	7753	Economy	14000.00
0005432529419	7753	Economy	14000.00
0005432529458	7753	Economy	14000.00
0005435213257	7753	Economy	14000.00
0005432529492	7753	Economy	14000.00
0005432529449	7753	Economy	14000.00
0005432529470	7753	Economy	14000.00
0005435213754	7753	Economy	14000.00
0005435213848	7753	Economy	14000.00
0005432529460	7753	Economy	14000.00
0005432529491	7753	Economy	14000.00
0005432529407	7753	Economy	14000.00
0005432529403	7753	Economy	14000.00
0005434068331	7753	Economy	14000.00
0005435213597	7753	Economy	14000.00
0005432529421	7753	Economy	14000.00
0005434068388	7753	Economy	14000.00
0005432529498	7753	Economy	14000.00
0005435213785	7753	Economy	14000.00
0005432529425	7753	Economy	14000.00
0005434068369	7753	Economy	14000.00
0005432428967	7753	Economy	14000.00
0005434068346	7753	Economy	14000.00
0005432529430	7753	Economy	14000.00
0005432535890	7753	Economy	14000.00
0005432529408	7753	Economy	14000.00
0005432535889	7753	Economy	14000.00
0005435213640	7753	Economy	14000.00
0005433656682	7753	Economy	14000.00
0005435213798	7753	Economy	14000.00
0005435213675	7753	Economy	14000.00
0005434068389	7753	Economy	14000.00
0005434068391	7753	Economy	14000.00
0005435213915	7753	Economy	14000.00
0005432529441	7753	Economy	14000.00
0005435213823	7753	Economy	14000.00
0005432069818	7753	Economy	14000.00
0005435213797	7753	Economy	14000.00
0005432529521	7753	Economy	14000.00
0005434068362	7753	Economy	14000.00
0005432529497	7753	Economy	14000.00
0005434068366	7753	Economy	14000.00
0005432529455	7753	Economy	14000.00
0005432529395	7753	Economy	14000.00
0005434068335	7753	Economy	14000.00
0005435213603	7753	Economy	14000.00
0005435213764	7753	Economy	14000.00
0005434068368	7753	Economy	14000.00
0005434068375	7753	Economy	14000.00
0005434068381	7753	Economy	14000.00
0005432529432	7753	Economy	14000.00
0005432529390	7753	Economy	14000.00
0005432529488	7753	Economy	14000.00
0005432529495	7753	Economy	14000.00
0005432529520	7753	Economy	14000.00
0005434068401	7753	Economy	14000.00
0005432529473	7753	Economy	14000.00
0005432529485	7753	Economy	14000.00
0005432529472	7753	Economy	14000.00
0005432529456	7753	Economy	14000.00
0005435213844	7753	Economy	14000.00
0005432529416	7753	Economy	14000.00
0005432529444	7753	Economy	14000.00
0005435213846	7753	Economy	14000.00
0005435213563	7753	Economy	14000.00
0005432529517	7753	Economy	14000.00
0005432069824	7753	Economy	14000.00
0005432529509	7753	Economy	14000.00
0005432529428	7753	Economy	14000.00
0005433656683	7753	Economy	14000.00
0005435213695	7753	Economy	14000.00
0005435213865	7753	Economy	14000.00
0005434068343	7753	Economy	14000.00
0005434068356	7753	Economy	14000.00
0005432529463	7753	Economy	14000.00
0005434068328	7753	Economy	14000.00
0005432529418	7753	Economy	14000.00
0005434068351	7753	Economy	14000.00
0005432529515	7753	Economy	14000.00
0005434068395	7753	Economy	14000.00
0005432529410	7753	Economy	14000.00
0005432533326	7753	Economy	14000.00
0005434245095	5348	Business	43100.00
0005435614947	5348	Business	43100.00
0005435614916	5348	Business	43100.00
0005435614969	5348	Business	43100.00
0005435614895	5348	Business	43100.00
0005434656567	5348	Business	43100.00
0005433719151	5348	Business	43100.00
0005434245129	5348	Business	43100.00
0005435380296	5348	Business	43100.00
0005435380313	5348	Business	43100.00
0005434245081	5348	Business	43100.00
0005435614993	5348	Business	43100.00
0005435614901	5348	Business	43100.00
0005435614960	5348	Business	43100.00
0005434344624	5348	Business	43100.00
0005435490269	5348	Business	43100.00
0005435425244	5348	Business	43100.00
0005435425027	5348	Business	43100.00
0005432133374	5348	Business	43100.00
0005435424854	5348	Business	43100.00
0005434573513	5348	Business	43100.00
0005434573507	5348	Business	43100.00
0005434344630	5348	Business	43100.00
0005434344625	5348	Business	43100.00
0005434344610	5348	Business	43100.00
0005432133376	5348	Business	43100.00
0005435614890	5348	Comfort	24400.00
0005434344627	5348	Comfort	24400.00
0005435614990	5348	Comfort	24400.00
0005434245128	5348	Comfort	24400.00
0005432133383	5348	Comfort	24400.00
0005432133390	5348	Comfort	24400.00
0005435425000	5348	Comfort	24400.00
0005435380320	5348	Comfort	24400.00
0005434573508	5348	Comfort	24400.00
0005434344628	5348	Comfort	24400.00
0005435614991	5348	Comfort	24400.00
0005435424935	5348	Comfort	24400.00
0005435614985	5348	Comfort	24400.00
0005434344608	5348	Comfort	24400.00
0005433719137	5348	Comfort	24400.00
0005434573505	5348	Comfort	24400.00
0005434344601	5348	Comfort	24400.00
0005434344631	5348	Comfort	24400.00
0005435614996	5348	Comfort	24400.00
0005435614972	5348	Comfort	24400.00
0005435302199	5348	Comfort	24400.00
0005435614933	5348	Comfort	24400.00
0005435614887	5348	Comfort	24400.00
0005435614918	5348	Comfort	24400.00
0005435614978	5348	Comfort	24400.00
0005435425300	5348	Comfort	24400.00
0005435614956	5348	Comfort	24400.00
0005435614906	5348	Comfort	24400.00
0005435425222	5348	Comfort	24400.00
0005434245092	5348	Comfort	24400.00
0005434344616	5348	Comfort	24400.00
0005435614948	5348	Comfort	24400.00
0005435614894	5348	Comfort	24400.00
0005434656568	5348	Comfort	24400.00
0005435425026	5348	Comfort	24400.00
0005435614942	5348	Comfort	24400.00
0005434344619	5348	Comfort	24400.00
0005435305020	5348	Comfort	24400.00
0005434573519	5348	Economy	14400.00
0005434344623	5348	Comfort	24400.00
0005435614987	5348	Economy	14400.00
0005434656563	5348	Economy	14400.00
0005434344634	5348	Economy	14400.00
0005434245125	5348	Economy	14400.00
0005435097314	5348	Economy	14400.00
0005435614950	5348	Economy	14400.00
0005435425100	5348	Economy	14400.00
0005435614973	5348	Economy	14400.00
0005432047594	5348	Economy	14400.00
0005435614939	5348	Economy	14400.00
0005435614943	5348	Economy	14400.00
0005435097313	5348	Economy	14400.00
0005433719160	5348	Economy	14400.00
0005435614905	5348	Economy	14400.00
0005435614900	5348	Economy	14400.00
0005434344604	5348	Economy	14400.00
0005435614953	5348	Economy	14400.00
0005435425255	5348	Economy	14400.00
0005435491462	5348	Economy	14400.00
0005434245020	5348	Economy	14400.00
0005435490270	5348	Economy	14400.00
0005435424856	5348	Economy	14400.00
0005435614899	5348	Economy	14400.00
0005435614965	5348	Economy	14400.00
0005432133384	5348	Economy	14400.00
0005435614975	5348	Economy	14400.00
0005434656566	5348	Economy	14400.00
0005435614932	5348	Economy	14400.00
0005435425093	5348	Economy	14400.00
0005433719136	5348	Economy	14400.00
0005433719140	5348	Economy	14400.00
0005435425245	5348	Economy	14400.00
0005435425116	5348	Economy	14400.00
0005434344618	5348	Economy	14400.00
0005432047593	5348	Economy	14400.00
0005434344609	5348	Economy	14400.00
0005432133388	5348	Economy	14400.00
0005432133382	5348	Economy	14400.00
0005435614876	5348	Economy	14400.00
0005435614875	5348	Economy	14400.00
0005435614929	5348	Economy	14400.00
0005435302209	5348	Economy	14400.00
0005434344633	5348	Economy	14400.00
0005435380302	5348	Economy	14400.00
0005435614986	5348	Economy	14400.00
0005435042855	5348	Economy	14400.00
0005435097319	5348	Economy	14400.00
0005435097315	5348	Economy	14400.00
0005435424780	5348	Economy	14400.00
0005434245127	5348	Economy	14400.00
0005434245052	5348	Economy	14400.00
0005435380295	5348	Economy	14400.00
0005435424747	5348	Economy	14400.00
0005434245104	5348	Economy	14400.00
0005434344636	5348	Economy	14400.00
0005434344629	5348	Economy	14400.00
0005435425102	5348	Economy	14400.00
0005435614877	5348	Economy	15800.00
0005435614911	5348	Economy	15800.00
0005435614925	5348	Economy	14400.00
0005435425287	5348	Economy	14400.00
0005435302201	5348	Economy	15800.00
0005435425223	5348	Economy	14400.00
0005435614966	5348	Economy	15800.00
0005434344612	5348	Economy	15800.00
0005435614989	5348	Economy	14400.00
0005432133387	5348	Economy	14400.00
0005434245000	5348	Economy	14400.00
0005435614994	5348	Economy	14400.00
0005435097316	5348	Economy	14400.00
0005434245011	5348	Economy	14400.00
0005435424948	5348	Economy	14400.00
0005434245124	5348	Economy	14400.00
0005435097321	5348	Economy	14400.00
0005435614927	5348	Economy	14400.00
0005435425221	5348	Economy	14400.00
0005435042854	5348	Economy	14400.00
0005434573518	5348	Economy	14400.00
0005435614882	5348	Economy	14400.00
0005434344635	5348	Economy	14400.00
0005435614937	5348	Economy	14400.00
0005434245001	5348	Economy	14400.00
0005434573506	5348	Economy	14400.00
0005435614938	5348	Economy	14400.00
0005435614923	5348	Economy	14400.00
0005432133377	5348	Economy	14400.00
0005435555393	5348	Economy	14400.00
0005435425107	5348	Economy	14400.00
0005434573517	5348	Economy	14400.00
0005435380301	5348	Economy	14400.00
0005435614888	5348	Economy	14400.00
0005435555391	5348	Economy	14400.00
0005435424746	5348	Economy	14400.00
0005433719142	5348	Economy	14400.00
0005432133378	5348	Economy	14400.00
0005434344600	5348	Economy	14400.00
0005435424927	5348	Economy	14400.00
0005435614976	5348	Economy	14400.00
0005435614970	5348	Economy	14400.00
0005434344617	5348	Economy	14400.00
0005435614971	5348	Economy	14400.00
0005435614913	5348	Economy	14400.00
0005435614908	5348	Economy	14400.00
0005435614897	5348	Economy	14400.00
0005435614914	5348	Economy	14400.00
0005434344614	5348	Economy	14400.00
0005435614922	5348	Economy	14400.00
0005435319594	5348	Economy	14400.00
0005435380312	5348	Economy	14400.00
0005433719141	5348	Economy	14400.00
0005434344603	5348	Economy	14400.00
0005435614967	5348	Economy	14400.00
0005434245112	5348	Economy	14400.00
0005434344626	5348	Economy	14400.00
0005435425181	5348	Economy	14400.00
0005435614893	5348	Economy	14400.00
0005435614874	5348	Economy	14400.00
0005435614957	5348	Economy	14400.00
0005435614964	5348	Economy	14400.00
0005432047592	5348	Economy	14400.00
0005435380297	5348	Economy	14400.00
0005435614980	5348	Economy	14400.00
0005435425082	5348	Economy	14400.00
0005435614921	5348	Economy	14400.00
0005435614935	5348	Economy	14400.00
0005435319590	5348	Economy	14400.00
0005433719159	5348	Economy	14400.00
0005435614968	5348	Economy	14400.00
0005434245012	5348	Economy	14400.00
0005435302200	5348	Economy	14400.00
0005435614886	5348	Economy	14400.00
0005434573509	5348	Economy	14400.00
0005435305025	5348	Economy	14400.00
0005435614879	5348	Economy	14400.00
0005435614974	5348	Economy	14400.00
0005434245111	5348	Economy	14400.00
0005434344632	5348	Economy	14400.00
0005435614896	5348	Economy	14400.00
0005434573515	5348	Economy	14400.00
0005435614951	5348	Economy	14400.00
0005435425047	5348	Economy	14400.00
0005434344605	5348	Economy	14400.00
0005435614944	5348	Economy	14400.00
0005435614892	5348	Economy	14400.00
0005435614992	5348	Economy	14400.00
0005435425178	5348	Economy	14400.00
0005435425115	5348	Economy	14400.00
0005435424977	5348	Economy	14400.00
0005435614988	5348	Economy	14400.00
0005432133381	5348	Economy	14400.00
0005435614997	5348	Economy	14400.00
0005435425038	5348	Economy	14400.00
0005434245049	5348	Economy	14400.00
0005435614881	5348	Economy	14400.00
0005435614958	5348	Economy	14400.00
0005435425177	5348	Economy	14400.00
0005434344611	5348	Economy	14400.00
0005435614963	5348	Economy	14400.00
0005435614910	5348	Economy	14400.00
0005434344620	5348	Economy	14400.00
0005434344613	5348	Economy	14400.00
0005434245113	5348	Economy	14400.00
0005435614955	5348	Economy	14400.00
0005435424952	5348	Economy	14400.00
0005435614941	5348	Economy	14400.00
0005435614940	5348	Economy	14400.00
0005435614961	5348	Economy	14400.00
0005435555392	5348	Economy	15800.00
0005435614884	5348	Economy	14400.00
0005435614907	5348	Economy	15800.00
0005434573516	5348	Economy	15800.00
0005432133380	5348	Economy	14400.00
0005435097320	5348	Economy	14400.00
0005435425220	5348	Economy	14400.00
0005434344602	5348	Economy	14400.00
0005434344607	5348	Economy	14400.00
0005434573510	5348	Economy	14400.00
0005435614945	5348	Economy	14400.00
0005435614891	5348	Economy	14400.00
0005435614946	5348	Economy	14400.00
0005434344615	5348	Economy	14400.00
0005434244965	5348	Economy	14400.00
0005435490268	5348	Economy	14400.00
0005435614902	5348	Economy	14400.00
0005435424961	5348	Economy	14400.00
0005435425066	5348	Economy	14400.00
0005435614919	5348	Economy	14400.00
0005434245044	5348	Economy	14400.00
0005434245085	5348	Economy	14400.00
0005434245037	5348	Economy	14400.00
0005434245048	5348	Economy	14400.00
0005435614954	5348	Economy	14400.00
0005432133385	5348	Economy	14400.00
0005434344622	5348	Economy	14400.00
0005435614977	5348	Economy	14400.00
0005435614920	5348	Economy	14400.00
0005435614915	5348	Economy	14400.00
0005435097317	5348	Economy	14400.00
0005435614982	5348	Economy	14400.00
0005435614981	5348	Economy	14400.00
0005435319622	5348	Economy	14400.00
0005435614984	5348	Economy	14400.00
0005435424999	5348	Economy	14400.00
0005435425114	5348	Economy	14400.00
0005434245036	5348	Economy	14400.00
0005435424951	5348	Economy	14400.00
0005435302224	5348	Economy	14400.00
0005435614912	5348	Economy	14400.00
0005435614878	5348	Economy	14400.00
0005435425065	5348	Economy	14400.00
0005435614917	5348	Economy	14400.00
0005435614983	5348	Economy	14400.00
0005435614995	5348	Economy	14400.00
0005434573511	5348	Economy	14400.00
0005435614930	5348	Economy	14400.00
0005435097318	5348	Economy	14400.00
0005435614934	5348	Economy	14400.00
0005435614936	5348	Economy	14400.00
0005435614931	5348	Economy	14400.00
0005435614880	5348	Economy	14400.00
0005435614883	5348	Economy	14400.00
0005435097312	5348	Economy	14400.00
0005435614949	5348	Economy	14400.00
0005435614889	5348	Economy	14400.00
0005435614924	5348	Economy	14400.00
0005435614952	5348	Economy	14400.00
0005432133375	5348	Economy	14400.00
0005435424936	5348	Economy	14400.00
0005435614903	5348	Economy	14400.00
0005434344621	5348	Economy	14400.00
0005435490271	5348	Economy	14400.00
0005435380316	5348	Economy	14400.00
0005435319579	5348	Economy	14400.00
0005435614959	5348	Economy	14400.00
0005432133389	5348	Economy	14400.00
0005435424983	5348	Economy	14400.00
0005435491461	5348	Economy	14400.00
0005435614885	5348	Economy	14400.00
0005435425103	5348	Economy	14400.00
0005435491460	5348	Economy	14400.00
0005435424666	5348	Economy	14400.00
0005434656562	5348	Economy	14400.00
0005435424965	5348	Economy	14400.00
0005435424904	5348	Economy	14400.00
0005434573514	5348	Economy	14400.00
0005435425098	5348	Economy	14400.00
0005435614904	5348	Economy	14400.00
0005435614898	5348	Economy	14400.00
0005435425124	5348	Economy	14400.00
0005434245123	5348	Economy	14400.00
0005434245091	5348	Economy	14400.00
0005435425140	5348	Economy	14400.00
0005435319592	5348	Economy	14400.00
0005435614979	5348	Economy	14400.00
0005435424855	5348	Economy	14400.00
0005435614928	5348	Economy	14400.00
0005435424833	5348	Economy	14400.00
0005435614926	5348	Economy	14400.00
0005435614909	5348	Economy	14400.00
0005433719153	5348	Economy	14400.00
0005432133386	5348	Economy	14400.00
0005434573512	5348	Economy	14400.00
0005434344606	5348	Economy	14400.00
0005432133379	5348	Economy	14400.00
0005435425007	5348	Economy	14400.00
0005435614962	5348	Economy	14400.00
0005435425606	10912	Business	43100.00
0005435425599	10912	Business	43100.00
0005435490240	10912	Business	43100.00
0005435490230	10912	Business	43100.00
0005435425566	10912	Business	43100.00
0005435617234	10912	Business	43100.00
0005435614580	10912	Business	43100.00
0005435425608	10912	Business	43100.00
0005435425586	10912	Business	43100.00
0005435319670	10912	Business	43100.00
0005435614126	10912	Business	43100.00
0005435613860	10912	Business	43100.00
0005434573324	10912	Business	43100.00
0005435425569	10912	Business	43100.00
0005435613619	10912	Business	43100.00
0005435319673	10912	Business	43100.00
0005434344193	10912	Business	43100.00
0005435319676	10912	Comfort	24400.00
0005435490238	10912	Business	43100.00
0005434344281	10912	Comfort	24400.00
0005434245318	10912	Comfort	24400.00
0005435613997	10912	Comfort	24400.00
0005435425572	10912	Comfort	24400.00
0005434344392	10912	Comfort	24400.00
0005435097225	10912	Comfort	24400.00
0005434344274	10912	Comfort	24400.00
0005435614007	10912	Comfort	24400.00
0005435425556	10912	Comfort	24400.00
0005434344341	10912	Comfort	24400.00
0005434245317	10912	Comfort	24400.00
0005435097229	10912	Comfort	24400.00
0005432165126	10912	Comfort	24400.00
0005435425554	10912	Comfort	24400.00
0005435305035	10912	Comfort	24400.00
0005432363454	10912	Comfort	24400.00
0005435614083	10912	Comfort	24400.00
0005435613996	10912	Comfort	24400.00
0005435490231	10912	Comfort	24400.00
0005434245313	10912	Comfort	24400.00
0005435490241	10912	Comfort	24400.00
0005434344362	10912	Comfort	24400.00
0005435425618	10912	Comfort	24400.00
0005434344254	10912	Comfort	24400.00
0005435425600	10912	Comfort	24400.00
0005435425559	10912	Comfort	24400.00
0005435613932	10912	Comfort	24400.00
0005435425578	10912	Comfort	24400.00
0005435097212	10912	Comfort	24400.00
0005435380344	10912	Comfort	24400.00
0005432841037	10912	Comfort	24400.00
0005435425611	10912	Comfort	24400.00
0005435425605	10912	Comfort	24400.00
0005435614009	10912	Comfort	24400.00
0005435319668	10912	Comfort	24400.00
0005435380342	10912	Economy	14400.00
0005432165121	10912	Economy	14400.00
0005435613809	10912	Economy	14400.00
0005435613504	10912	Economy	14400.00
0005435425612	10912	Economy	14400.00
0005435613533	10912	Economy	14400.00
0005432165127	10912	Economy	14400.00
0005435490227	10912	Economy	14400.00
0005435425577	10912	Economy	14400.00
0005435613569	10912	Economy	14400.00
0005435613770	10912	Economy	14400.00
0005434573386	10912	Economy	14400.00
0005435613771	10912	Economy	14400.00
0005434573375	10912	Economy	14400.00
0005435425610	10912	Economy	14400.00
0005435614129	10912	Economy	14400.00
0005435614082	10912	Economy	14400.00
0005435613822	10912	Economy	14400.00
0005435614519	10912	Economy	14400.00
0005435425619	10912	Economy	14400.00
0005434573296	10912	Economy	14400.00
0005435425613	10912	Economy	14400.00
0005435613841	10912	Economy	14400.00
0005434344179	10912	Economy	14400.00
0005435097224	10912	Economy	14400.00
0005435614111	10912	Economy	14400.00
0005434344270	10912	Economy	14400.00
0005434344258	10912	Economy	14400.00
0005435614181	10912	Economy	14400.00
0005435097190	10912	Economy	14400.00
0005435614276	10912	Economy	14400.00
0005435614016	10912	Economy	14400.00
0005435425561	10912	Economy	14400.00
0005435097213	10912	Economy	14400.00
0005435614146	10912	Economy	14400.00
0005434344301	10912	Economy	14400.00
0005435425609	10912	Economy	14400.00
0005435614389	10912	Economy	14400.00
0005435319674	10912	Economy	14400.00
0005435613373	10912	Economy	14400.00
0005435614125	10912	Economy	14400.00
0005435614548	10912	Economy	14400.00
0005435613498	10912	Economy	14400.00
0005435097220	10912	Economy	14400.00
0005435425598	10912	Economy	14400.00
0005435613842	10912	Economy	14400.00
0005435304205	10912	Economy	14400.00
0005435614283	10912	Economy	14400.00
0005435425603	10912	Economy	14400.00
0005435613887	10912	Economy	14400.00
0005435614404	10912	Economy	14400.00
0005435425616	10912	Economy	14400.00
0005434245308	10912	Economy	14400.00
0005435425570	10912	Economy	14400.00
0005435614390	10912	Economy	14400.00
0005434573370	10912	Economy	14400.00
0005435613632	10912	Economy	14400.00
0005435380341	10912	Economy	15800.00
0005435425551	10912	Economy	14400.00
0005432166938	10912	Economy	15800.00
0005435425558	10912	Economy	15800.00
0005435613561	10912	Economy	14400.00
0005435319675	10912	Economy	14400.00
0005432363452	10912	Economy	14400.00
0005435425573	10912	Economy	15800.00
0005434245302	10912	Economy	14400.00
0005435425557	10912	Economy	15800.00
0005434573387	10912	Economy	14400.00
0005435425591	10912	Economy	14400.00
0005435614074	10912	Economy	14400.00
0005435614356	10912	Economy	14400.00
0005435425560	10912	Economy	14400.00
0005435617172	10912	Economy	14400.00
0005435425574	10912	Economy	14400.00
0005435614254	10912	Economy	14400.00
0005435425575	10912	Economy	14400.00
0005435425595	10912	Economy	14400.00
0005435425601	10912	Economy	14400.00
0005435613783	10912	Economy	14400.00
0005435425576	10912	Economy	14400.00
0005435490239	10912	Economy	14400.00
0005435614520	10912	Economy	14400.00
0005435614224	10912	Economy	14400.00
0005435425580	10912	Economy	14400.00
0005432165123	10912	Economy	14400.00
0005435613788	10912	Economy	14400.00
0005435613908	10912	Economy	14400.00
0005435613653	10912	Economy	14400.00
0005434245321	10912	Economy	14400.00
0005435380340	10912	Economy	14400.00
0005434245304	10912	Economy	14400.00
0005432165125	10912	Economy	14400.00
0005434344178	10912	Economy	14400.00
0005435425614	10912	Economy	14400.00
0005435614097	10912	Economy	14400.00
0005435425565	10912	Economy	14400.00
0005434245316	10912	Economy	14400.00
0005435613840	10912	Economy	14400.00
0005435613838	10912	Economy	14400.00
0005434573351	10912	Economy	14400.00
0005434245303	10912	Economy	14400.00
0005434245301	10912	Economy	14400.00
0005435613831	10912	Economy	14400.00
0005433719179	10912	Economy	14400.00
0005435425583	10912	Economy	14400.00
0005434344142	10912	Economy	14400.00
0005434344205	10912	Economy	14400.00
0005435614284	10912	Economy	14400.00
0005435613659	10912	Economy	14400.00
0005435304207	10912	Economy	14400.00
0005435425593	10912	Economy	14400.00
0005435425585	10912	Economy	14400.00
0005435425617	10912	Economy	14400.00
0005432166939	10912	Economy	14400.00
0005434656579	10912	Economy	14400.00
0005435614089	10912	Economy	14400.00
0005434245297	10912	Economy	14400.00
0005435613652	10912	Economy	14400.00
0005435319669	10912	Economy	14400.00
0005435425604	10912	Economy	14400.00
0005434344262	10912	Economy	14400.00
0005435614436	10912	Economy	14400.00
0005435614547	10912	Economy	14400.00
0005435613786	10912	Economy	14400.00
0005434245299	10912	Economy	14400.00
0005435613473	10912	Economy	14400.00
0005434344302	10912	Economy	14400.00
0005435319671	10912	Economy	14400.00
0005432841036	10912	Economy	14400.00
0005435614392	10912	Economy	14400.00
0005435614100	10912	Economy	14400.00
0005434245312	10912	Economy	14400.00
0005434344250	10912	Economy	14400.00
0005435614249	10912	Economy	14400.00
0005435425555	10912	Economy	14400.00
0005435425564	10912	Economy	14400.00
0005435425596	10912	Economy	14400.00
0005434245319	10912	Economy	14400.00
0005435304208	10912	Economy	14400.00
0005435425587	10912	Economy	14400.00
0005435614189	10912	Economy	14400.00
0005435097226	10912	Economy	14400.00
0005432165122	10912	Economy	14400.00
0005435614040	10912	Economy	14400.00
0005435614110	10912	Economy	14400.00
0005435490228	10912	Economy	14400.00
0005432841038	10912	Economy	14400.00
0005432165128	10912	Economy	14400.00
0005435614190	10912	Economy	14400.00
0005434344277	10912	Economy	14400.00
0005433719180	10912	Economy	14400.00
0005434344278	10912	Economy	14400.00
0005435614521	10912	Economy	14400.00
0005434344276	10912	Economy	14400.00
0005435614434	10912	Economy	14400.00
0005435613444	10912	Economy	14400.00
0005435380343	10912	Economy	14400.00
0005435613534	10912	Economy	14400.00
0005434344235	10912	Economy	14400.00
0005435425571	10912	Economy	14400.00
0005435613722	10912	Economy	14400.00
0005435614099	10912	Economy	14400.00
0005435614522	10912	Economy	14400.00
0005435425588	10912	Economy	14400.00
0005435614101	10912	Economy	15800.00
0005435097239	10912	Economy	15800.00
0005434344187	10912	Economy	15800.00
0005435614157	10912	Economy	15800.00
0005434344340	10912	Economy	14400.00
0005435304203	10912	Economy	14400.00
0005435614258	10912	Economy	14400.00
0005435614546	10912	Economy	14400.00
0005432363453	10912	Economy	14400.00
0005434245309	10912	Economy	14400.00
0005435097228	10912	Economy	14400.00
0005434245307	10912	Economy	14400.00
0005435613620	10912	Economy	14400.00
0005435380339	10912	Economy	14400.00
0005435614508	10912	Economy	14400.00
0005434344363	10912	Economy	14400.00
0005434245314	10912	Economy	14400.00
0005435614064	10912	Economy	14400.00
0005434245311	10912	Economy	14400.00
0005435613821	10912	Economy	14400.00
0005435613782	10912	Economy	14400.00
0005435613931	10912	Economy	14400.00
0005435304206	10912	Economy	14400.00
0005435614545	10912	Economy	14400.00
0005435613592	10912	Economy	14400.00
0005435614435	10912	Economy	14400.00
0005435613753	10912	Economy	14400.00
0005435613883	10912	Economy	14400.00
0005435425567	10912	Economy	14400.00
0005435425581	10912	Economy	14400.00
0005435614271	10912	Economy	14400.00
0005434344275	10912	Economy	14400.00
0005435425563	10912	Economy	14400.00
0005435613503	10912	Economy	14400.00
0005434245298	10912	Economy	14400.00
0005435425615	10912	Economy	14400.00
0005434573371	10912	Economy	14400.00
0005434245315	10912	Economy	14400.00
0005434245305	10912	Economy	14400.00
0005435425589	10912	Economy	14400.00
0005435613402	10912	Economy	14400.00
0005432166940	10912	Economy	14400.00
0005434344249	10912	Economy	14400.00
0005432165124	10912	Economy	14400.00
0005435097205	10912	Economy	14400.00
0005434573379	10912	Economy	14400.00
0005435613690	10912	Economy	14400.00
0005435613861	10912	Economy	14400.00
0005435425607	10912	Economy	14400.00
0005435613660	10912	Economy	14400.00
0005435613794	10912	Economy	14400.00
0005434344267	10912	Economy	14400.00
0005435614008	10912	Economy	14400.00
0005435425584	10912	Economy	14400.00
0005435425552	10912	Economy	14400.00
0005435613562	10912	Economy	14400.00
0005435613737	10912	Economy	14400.00
0005435425590	10912	Economy	14400.00
0005435614250	10912	Economy	14400.00
0005435614139	10912	Economy	14400.00
0005435425562	10912	Economy	14400.00
0005435425620	10912	Economy	14400.00
0005435097231	10912	Economy	14400.00
0005435617171	10912	Economy	14400.00
0005434245322	10912	Economy	14400.00
0005435613621	10912	Economy	14400.00
0005435613967	10912	Economy	14400.00
0005434245306	10912	Economy	14400.00
0005434344096	10912	Economy	14400.00
0005434245324	10912	Economy	14400.00
0005435425594	10912	Economy	14400.00
0005435319672	10912	Economy	14400.00
0005434245300	10912	Economy	14400.00
0005435425602	10912	Economy	14400.00
0005435614263	10912	Economy	14400.00
0005435425582	10912	Economy	14400.00
0005434245325	10912	Economy	14400.00
0005435425592	10912	Economy	14400.00
0005434245326	10912	Economy	14400.00
0005435613909	10912	Economy	14400.00
0005435425553	10912	Economy	14400.00
0005434656578	10912	Economy	14400.00
0005434344400	10912	Economy	14400.00
0005435425597	10912	Economy	14400.00
0005433719181	10912	Economy	14400.00
0005434245320	10912	Economy	14400.00
0005435613862	10912	Economy	14400.00
0005435425579	10912	Economy	14400.00
0005435614514	10912	Economy	14400.00
0005435425568	10912	Economy	14400.00
0005434245323	10912	Economy	14400.00
0005435304204	10912	Economy	14400.00
0005435613738	10912	Economy	14400.00
0005434245310	10912	Economy	14400.00
0005433805770	3391	Business	18800.00
0005432459791	3391	Business	18800.00
0005433507377	3391	Business	18800.00
0005433805775	3391	Business	18800.00
0005433805780	3391	Business	18800.00
0005432459875	3391	Business	18800.00
0005432459889	3391	Business	18800.00
0005432459924	3391	Business	18800.00
0005433634210	3391	Business	18800.00
0005433634212	3391	Business	18800.00
0005432459945	3391	Business	18800.00
0005432459696	3391	Business	18800.00
0005433805763	3391	Business	18800.00
0005432181965	3391	Business	18800.00
0005432459891	3391	Business	18800.00
0005432460024	3391	Business	18800.00
0005432460018	3391	Business	18800.00
0005433634208	3391	Business	18800.00
0005433805772	3391	Business	18800.00
0005432460108	3391	Business	18800.00
0005433805758	3391	Business	18800.00
0005433634194	3391	Business	18800.00
0005433634197	3391	Business	18800.00
0005432459788	3391	Business	18800.00
0005433805769	3391	Business	18800.00
0005433805779	3391	Business	18800.00
0005432459955	3391	Economy	6900.00
0005433634217	3391	Economy	6900.00
0005432459870	3391	Economy	6900.00
0005432181976	3391	Economy	6900.00
0005432459933	3391	Economy	6900.00
0005432459900	3391	Economy	6900.00
0005433507386	3391	Economy	6300.00
0005432181960	3391	Economy	6300.00
0005433634198	3391	Economy	6300.00
0005433805782	3391	Economy	6300.00
0005433805759	3391	Economy	6300.00
0005433634195	3391	Economy	6300.00
0005432460021	3391	Economy	6300.00
0005433507383	3391	Economy	6300.00
0005433805771	3391	Economy	6300.00
0005432459966	3391	Economy	6300.00
0005433634220	3391	Economy	6300.00
0005433805786	3391	Economy	6300.00
0005432181974	3391	Economy	6300.00
0005432460030	3391	Economy	6300.00
0005432460042	3391	Economy	6300.00
0005433805764	3391	Economy	6300.00
0005433805785	3391	Economy	6300.00
0005433634219	3391	Economy	6300.00
0005432459976	3391	Economy	6300.00
0005433634222	3391	Economy	6300.00
0005433634216	3391	Economy	6300.00
0005433507380	3391	Economy	6300.00
0005433805778	3391	Economy	6300.00
0005433634203	3391	Economy	6300.00
0005433634193	3391	Economy	6300.00
0005433634209	3391	Economy	6300.00
0005433805768	3391	Economy	6300.00
0005432460131	3391	Economy	6300.00
0005432460049	3391	Economy	6300.00
0005433634196	3391	Economy	6300.00
0005432460085	3391	Economy	6300.00
0005432460043	3391	Economy	6300.00
0005432460064	3391	Economy	6300.00
0005433634204	3391	Economy	6300.00
0005433507391	3391	Economy	6300.00
0005433805788	3391	Economy	6300.00
0005432181967	3391	Economy	6300.00
0005433507378	3391	Economy	6300.00
0005433634223	3391	Economy	6300.00
0005432459985	3391	Economy	6300.00
0005432181975	3391	Economy	6300.00
0005432459841	3391	Economy	6300.00
0005432181979	3391	Economy	6300.00
0005432181964	3391	Economy	6300.00
0005432181959	3391	Economy	6300.00
0005433634213	3391	Economy	6300.00
0005433507381	3391	Economy	6300.00
0005432459967	3391	Economy	6300.00
0005433805773	3391	Economy	6300.00
0005433805757	3391	Economy	6300.00
0005432181966	3391	Economy	6300.00
0005432459836	3391	Economy	6300.00
0005432181958	3391	Economy	6300.00
0005433805761	3391	Economy	6300.00
0005432459932	3391	Economy	6300.00
0005433634202	3391	Economy	6300.00
0005432181963	3391	Economy	6300.00
0005433805765	3391	Economy	6900.00
0005433805774	3391	Economy	6900.00
0005433634206	3391	Economy	6900.00
0005432459744	3391	Economy	6900.00
0005433634190	3391	Economy	6900.00
0005432181971	3391	Economy	6300.00
0005433507388	3391	Economy	6300.00
0005433805753	3391	Economy	6300.00
0005432181973	3391	Economy	6300.00
0005432460044	3391	Economy	6900.00
0005433634224	3391	Economy	6300.00
0005432460167	3391	Economy	6300.00
0005433634200	3391	Economy	6300.00
0005433507384	3391	Economy	6300.00
0005433634205	3391	Economy	6300.00
0005433805784	3391	Economy	6300.00
0005432460086	3391	Economy	6300.00
0005433805755	3391	Economy	6300.00
0005432459862	3391	Economy	6300.00
0005432459678	3391	Economy	6300.00
0005432459974	3391	Economy	6300.00
0005433634191	3391	Economy	6300.00
0005433634214	3391	Economy	6300.00
0005432460050	3391	Economy	6300.00
0005432181972	3391	Economy	6300.00
0005432460029	3391	Economy	6300.00
0005432460020	3391	Economy	6300.00
0005433507387	3391	Economy	6300.00
0005433805752	3391	Economy	6300.00
0005433805776	3391	Economy	6300.00
0005433507389	3391	Economy	6300.00
0005432460048	3391	Economy	6300.00
0005433805783	3391	Economy	6300.00
0005433805754	3391	Economy	6300.00
0005432181978	3391	Economy	6300.00
0005432459954	3391	Economy	6300.00
0005433634199	3391	Economy	6300.00
0005432459878	3391	Economy	6300.00
0005432459813	3391	Economy	6300.00
0005433634207	3391	Economy	6300.00
0005433634218	3391	Economy	6300.00
0005433507379	3391	Economy	6300.00
0005432460058	3391	Economy	6300.00
0005432459986	3391	Economy	6300.00
0005432459802	3391	Economy	6300.00
0005432181970	3391	Economy	6300.00
0005432459946	3391	Economy	6300.00
0005433634211	3391	Economy	6300.00
0005432181969	3391	Economy	6300.00
0005433805762	3391	Economy	6300.00
0005433634215	3391	Economy	6300.00
0005433805760	3391	Economy	6300.00
0005433634201	3391	Economy	6300.00
0005433805781	3391	Economy	6300.00
0005432459965	3391	Economy	6300.00
0005432460094	3391	Economy	6300.00
0005433634192	3391	Economy	6300.00
0005432181968	3391	Economy	6300.00
0005432459956	3391	Economy	6300.00
0005433805766	3391	Economy	6300.00
0005433507382	3391	Economy	6300.00
0005432181962	3391	Economy	6300.00
0005433805767	3391	Economy	6300.00
0005433805777	3391	Economy	6300.00
0005433805756	3391	Economy	6300.00
0005433634221	3391	Economy	6300.00
0005432181977	3391	Economy	6300.00
0005432459890	3391	Economy	6300.00
0005433805787	3391	Economy	6300.00
0005433507385	3391	Economy	6300.00
0005432181961	3391	Economy	6300.00
0005433507390	3391	Economy	6300.00
0005432459977	3391	Economy	6300.00
0005433507392	3391	Economy	6300.00
0005435885376	3390	Business	18800.00
0005435885549	3390	Business	18800.00
0005435885340	3390	Business	18800.00
0005435885347	3390	Business	18800.00
0005435885339	3390	Business	18800.00
0005435885605	3390	Business	18800.00
0005435885326	3390	Business	18800.00
0005435885407	3390	Business	18800.00
0005435885272	3390	Economy	6900.00
0005435885348	3390	Economy	6300.00
0005435885606	3390	Economy	6300.00
0005435885454	3390	Economy	6300.00
0005435885423	3390	Economy	6300.00
0005435885545	3390	Economy	6300.00
0005435885463	3390	Economy	6300.00
0005435885548	3390	Economy	6300.00
0005435885414	3390	Economy	6300.00
0005435885386	3390	Economy	6300.00
0005435885351	3390	Economy	6300.00
0005435885390	3390	Economy	6300.00
0005435885546	3390	Economy	6300.00
0005435885460	3390	Economy	6300.00
0005435885333	3390	Economy	6300.00
0005435885559	3390	Economy	6300.00
0005435885550	3390	Economy	6300.00
0005435885484	3390	Economy	6300.00
0005435885691	3390	Economy	6900.00
0005435885391	3390	Economy	6900.00
0005435885312	3390	Economy	6300.00
0005435885551	3390	Economy	6300.00
0005435885406	3390	Economy	6300.00
0005435885476	3390	Economy	6300.00
0005435885313	3390	Economy	6300.00
0005435885499	3390	Economy	6300.00
0005435885269	3390	Economy	6300.00
0005435885319	3390	Economy	6300.00
0005435885572	3390	Economy	6300.00
0005435885594	3390	Economy	6300.00
0005435885389	3390	Economy	6300.00
0005435885282	3390	Economy	6300.00
0005435885401	3390	Economy	6300.00
0005435885381	3390	Economy	6300.00
0005435885358	3390	Economy	6300.00
0005435885485	3390	Economy	6300.00
0005435885547	3390	Economy	6300.00
0005435885602	3390	Economy	6300.00
0005435885577	3390	Economy	6300.00
0005435885352	3390	Economy	6300.00
0005435885405	3390	Economy	6300.00
0005435885320	3390	Economy	6300.00
0005435885573	3390	Economy	6300.00
0005435885560	3390	Economy	6300.00
0005435885314	3390	Economy	6300.00
0005435885395	3390	Economy	6300.00
0005435885422	3390	Economy	6300.00
0005435885824	8167	Business	18800.00
0005432460475	8167	Business	18800.00
0005435885804	8167	Business	18800.00
0005433507200	8167	Business	18800.00
0005432460501	8167	Business	18800.00
0005432042878	8167	Business	18800.00
0005432460505	8167	Business	18800.00
0005432460468	8167	Business	18800.00
0005433507190	8167	Business	18800.00
0005432460504	8167	Business	18800.00
0005432460464	8167	Business	18800.00
0005432460491	8167	Business	18800.00
0005432460479	8167	Business	18800.00
0005432460460	8167	Business	18800.00
0005435885813	8167	Business	18800.00
0005432460474	8167	Business	18800.00
0005435885829	8167	Business	18800.00
0005435885817	8167	Business	18800.00
0005435885833	8167	Business	18800.00
0005432460482	8167	Business	18800.00
0005433507197	8167	Business	18800.00
0005432042873	8167	Economy	6900.00
0005432460454	8167	Economy	6900.00
0005432460457	8167	Economy	6900.00
0005434312345	8167	Economy	6900.00
0005432460502	8167	Economy	6900.00
0005433507103	8167	Economy	6300.00
0005435885835	8167	Economy	6300.00
0005435885805	8167	Economy	6300.00
0005433507199	8167	Economy	6300.00
0005432460478	8167	Economy	6300.00
0005432460483	8167	Economy	6300.00
0005432460498	8167	Economy	6300.00
0005432460463	8167	Economy	6300.00
0005435885802	8167	Economy	6300.00
0005432460492	8167	Economy	6300.00
0005434312344	8167	Economy	6300.00
0005433507189	8167	Economy	6300.00
0005432460496	8167	Economy	6300.00
0005432460461	8167	Economy	6300.00
0005435885801	8167	Economy	6300.00
0005432460456	8167	Economy	6300.00
0005432460487	8167	Economy	6300.00
0005432460494	8167	Economy	6300.00
0005433507196	8167	Economy	6300.00
0005432042874	8167	Economy	6300.00
0005432460489	8167	Economy	6300.00
0005435885825	8167	Economy	6300.00
0005432460467	8167	Economy	6300.00
0005433507210	8167	Economy	6300.00
0005432460476	8167	Economy	6300.00
0005433507211	8167	Economy	6300.00
0005435885822	8167	Economy	6300.00
0005432460473	8167	Economy	6300.00
0005435885803	8167	Economy	6300.00
0005433507194	8167	Economy	6300.00
0005432042869	8167	Economy	6300.00
0005432460470	8167	Economy	6300.00
0005432042871	8167	Economy	6300.00
0005435885806	8167	Economy	6300.00
0005432042867	8167	Economy	6300.00
0005435885820	8167	Economy	6300.00
0005435885799	8167	Economy	6300.00
0005432042877	8167	Economy	6300.00
0005432460462	8167	Economy	6300.00
0005435885834	8167	Economy	6300.00
0005432042876	8167	Economy	6300.00
0005432460481	8167	Economy	6300.00
0005432042868	8167	Economy	6300.00
0005432460495	8167	Economy	6300.00
0005433507232	8167	Economy	6300.00
0005432042866	8167	Economy	6300.00
0005432460458	8167	Economy	6300.00
0005432460486	8167	Economy	6300.00
0005432460500	8167	Economy	6300.00
0005435885819	8167	Economy	6300.00
0005435885808	8167	Economy	6900.00
0005432460485	8167	Economy	6900.00
0005433507120	8167	Economy	6900.00
0005432460490	8167	Economy	6900.00
0005435885826	8167	Economy	6300.00
0005432460488	8167	Economy	6300.00
0005435885811	8167	Economy	6300.00
0005435885821	8167	Economy	6300.00
0005432460484	8167	Economy	6300.00
0005432042870	8167	Economy	6300.00
0005432460472	8167	Economy	6300.00
0005432460469	8167	Economy	6300.00
0005432460471	8167	Economy	6300.00
0005433507226	8167	Economy	6300.00
0005432460480	8167	Economy	6300.00
0005435885828	8167	Economy	6300.00
0005433507195	8167	Economy	6300.00
0005435885818	8167	Economy	6300.00
0005435885812	8167	Economy	6300.00
0005432460503	8167	Economy	6300.00
0005432460497	8167	Economy	6300.00
0005433507233	8167	Economy	6300.00
0005433507192	8167	Economy	6300.00
0005432460459	8167	Economy	6300.00
0005432460453	8167	Economy	6300.00
0005433507130	8167	Economy	6300.00
0005435885827	8167	Economy	6300.00
0005435885823	8167	Economy	6300.00
0005435885832	8167	Economy	6300.00
0005435885814	8167	Economy	6300.00
0005435885800	8167	Economy	6300.00
0005432042872	8167	Economy	6300.00
0005435885831	8167	Economy	6300.00
0005432042879	8167	Economy	6300.00
0005432460499	8167	Economy	6300.00
0005435885815	8167	Economy	6300.00
0005435885816	8167	Economy	6300.00
0005432460455	8167	Economy	6300.00
0005435885809	8167	Economy	6300.00
0005432042875	8167	Economy	6300.00
0005432460466	8167	Economy	6300.00
0005435885810	8167	Economy	6300.00
0005433507102	8167	Economy	6300.00
0005432460477	8167	Economy	6300.00
0005432460493	8167	Economy	6300.00
0005435885830	8167	Economy	6300.00
0005432460465	8167	Economy	6300.00
0005435885807	8167	Economy	6300.00
0005433805476	8325	Business	18800.00
0005433633776	8325	Business	18800.00
0005433633982	8325	Business	18800.00
0005433633837	8325	Business	18800.00
0005433805479	8325	Business	18800.00
0005433634050	8325	Business	18800.00
0005433634033	8325	Business	18800.00
0005433805660	8325	Business	18800.00
0005433805457	8325	Business	18800.00
0005433805279	8325	Business	18800.00
0005433633753	8325	Economy	6900.00
0005433633887	8325	Economy	6900.00
0005433805380	8325	Economy	6900.00
0005433633772	8325	Economy	6300.00
0005433805546	8325	Economy	6300.00
0005433633853	8325	Economy	6300.00
0005433634094	8325	Economy	6300.00
0005433805386	8325	Economy	6300.00
0005433634001	8325	Economy	6300.00
0005433633958	8325	Economy	6300.00
0005433633708	8325	Economy	6300.00
0005433805632	8325	Economy	6300.00
0005433805278	8325	Economy	6300.00
0005433633907	8325	Economy	6300.00
0005433633891	8325	Economy	6300.00
0005433633906	8325	Economy	6300.00
0005433633963	8325	Economy	6300.00
0005433805553	8325	Economy	6300.00
0005433633913	8325	Economy	6300.00
0005433805493	8325	Economy	6300.00
0005433805385	8325	Economy	6300.00
0005434271321	8325	Economy	6300.00
0005434271320	8325	Economy	6300.00
0005433805363	8325	Economy	6300.00
0005433633886	8325	Economy	6300.00
0005434271305	8325	Economy	6300.00
0005433805373	8325	Economy	6300.00
0005433805571	8325	Economy	6900.00
0005433805478	8325	Economy	6300.00
0005433633890	8325	Economy	6300.00
0005433633833	8325	Economy	6300.00
0005433805381	8325	Economy	6300.00
0005433805537	8325	Economy	6300.00
0005433805545	8325	Economy	6300.00
0005433805588	8325	Economy	6300.00
0005433805525	8325	Economy	6300.00
0005433633852	8325	Economy	6300.00
0005433633884	8325	Economy	6300.00
0005433805465	8325	Economy	6300.00
0005433805554	8325	Economy	6300.00
0005433805475	8325	Economy	6300.00
0005433633856	8325	Economy	6300.00
0005433805456	8325	Economy	6300.00
0005433805472	8325	Economy	6300.00
0005433633929	8325	Economy	6300.00
0005433633752	8325	Economy	6300.00
0005433633682	8325	Economy	6300.00
0005434271306	8325	Economy	6300.00
0005433633966	8325	Economy	6300.00
0005433633707	8325	Economy	6300.00
0005433722296	4621	Business	9900.00
0005432383618	4621	Business	9900.00
0005432383623	4621	Business	9900.00
0005432383632	4621	Business	9900.00
0005432383614	4621	Business	9900.00
0005432728082	4621	Business	9900.00
0005433454899	4621	Economy	3300.00
0005433722297	4621	Economy	3300.00
0005432383627	4621	Economy	3300.00
0005432383624	4621	Economy	3300.00
0005433454900	4621	Economy	3300.00
0005432728086	4621	Economy	3300.00
0005432383634	4621	Economy	3300.00
0005433722302	4621	Economy	3600.00
0005432728077	4621	Economy	3600.00
0005432728076	4621	Economy	3600.00
0005433453783	4621	Economy	3600.00
0005432383628	4621	Economy	3300.00
0005432728080	4621	Economy	3300.00
0005432383638	4621	Economy	3300.00
0005432383610	4621	Economy	3300.00
0005433722298	4621	Economy	3300.00
0005433722300	4621	Economy	3300.00
0005432383633	4621	Economy	3300.00
0005432728083	4621	Economy	3300.00
0005432383612	4621	Economy	3300.00
0005433722301	4621	Economy	3300.00
0005432383611	4621	Economy	3300.00
0005433453782	4621	Economy	3300.00
0005432383616	4621	Economy	3300.00
0005432383621	4621	Economy	3300.00
0005433722299	4621	Economy	3300.00
0005432383635	4621	Economy	3300.00
0005432383617	4621	Economy	3300.00
0005432383637	4621	Economy	3300.00
0005432728085	4621	Economy	3300.00
0005432383620	4621	Economy	3300.00
0005433453784	4621	Economy	3300.00
0005432728084	4621	Economy	3300.00
0005432728078	4621	Economy	3300.00
0005432728081	4621	Economy	3300.00
0005432383615	4621	Economy	3300.00
0005432383629	4621	Economy	3300.00
0005432383625	4621	Economy	3300.00
0005432383626	4621	Economy	3300.00
0005432383636	4621	Economy	3300.00
0005432383613	4621	Economy	3300.00
0005432383631	4621	Economy	3300.00
0005433722294	4621	Economy	3300.00
0005432383609	4621	Economy	3300.00
0005432728075	4621	Economy	3300.00
0005432383622	4621	Economy	3300.00
0005432728074	4621	Economy	3300.00
0005432383619	4621	Economy	3300.00
0005432383630	4621	Economy	3300.00
0005433722295	4621	Economy	3300.00
0005432728079	4621	Economy	3300.00
0005432383041	30252	Business	9900.00
0005432383226	30252	Business	9900.00
0005433453765	30252	Business	9900.00
0005433453766	30252	Business	9900.00
0005432383113	30252	Business	9900.00
0005432382971	30252	Business	9900.00
0005432383197	30252	Economy	3300.00
0005432383254	30252	Economy	3300.00
0005432383155	30252	Economy	3300.00
0005432382918	30252	Economy	3300.00
0005432383129	30252	Economy	3300.00
0005433194870	30252	Economy	3600.00
0005432727957	30252	Economy	3600.00
0005432383064	30252	Economy	3600.00
0005432727966	30252	Economy	3300.00
0005433722204	30252	Economy	3300.00
0005432383163	30252	Economy	3300.00
0005433722206	30252	Economy	3300.00
0005432383136	30252	Economy	3300.00
0005432382919	30252	Economy	3300.00
0005432727994	30252	Economy	3300.00
0005432727967	30252	Economy	3300.00
0005432383321	30252	Economy	3300.00
0005432727995	30252	Economy	3300.00
0005432727959	30252	Economy	3300.00
0005432383158	30252	Economy	3300.00
0005432383118	30252	Economy	3300.00
0005432383160	30252	Economy	3300.00
0005432727941	30252	Economy	3300.00
0005432383035	30252	Economy	3300.00
0005432383119	30252	Economy	3300.00
0005432383309	30252	Economy	3300.00
0005432727964	30252	Economy	3300.00
0005433722205	30252	Economy	3300.00
0005432727948	30252	Economy	3300.00
0005432383200	30252	Economy	3300.00
0005432383115	30252	Economy	3300.00
0005432383240	30252	Economy	3300.00
0005432727947	30252	Economy	3300.00
0005432383156	30252	Economy	3300.00
0005432727896	30252	Economy	3300.00
0005433453767	30252	Economy	3300.00
0005432383201	30252	Economy	3300.00
0005432727968	30252	Economy	3300.00
0005432383114	30252	Economy	3300.00
0005432383227	30252	Economy	3300.00
0005432727945	30252	Economy	3300.00
0005432383218	30252	Economy	3300.00
0005432383270	30252	Economy	3300.00
0005432383320	30252	Economy	3300.00
0005432383157	30252	Economy	3300.00
0005432727985	30252	Economy	3300.00
0005432383036	30252	Economy	3300.00
0005432382988	30252	Economy	3300.00
0005432383161	30252	Economy	3300.00
0005432727983	30252	Economy	3300.00
0005432383072	30252	Economy	3300.00
0005432383332	30252	Economy	3300.00
0005433722200	30252	Economy	3300.00
0005432727996	30252	Economy	3300.00
0005432383331	30252	Economy	3300.00
0005432383192	30252	Economy	3300.00
0005432383217	30252	Economy	3300.00
0005432382972	30252	Economy	3300.00
0005435529515	1753	Business	57200.00
0005435529501	1753	Business	57200.00
0005435529513	1753	Business	57200.00
0005433516989	1753	Business	57200.00
0005435529517	1753	Business	57200.00
0005435541251	1753	Business	57200.00
0005435529516	1753	Business	57200.00
0005435541263	1753	Business	57200.00
0005435541258	1753	Economy	19100.00
0005432294515	1753	Economy	19100.00
0005435541264	1753	Economy	19100.00
0005435541250	1753	Economy	19100.00
0005435541244	1753	Economy	19100.00
0005433516996	1753	Economy	19100.00
0005435541254	1753	Economy	19100.00
0005432925050	1753	Economy	21000.00
0005433516998	1753	Economy	21000.00
0005432294514	1753	Economy	21000.00
0005435529512	1753	Economy	21000.00
0005435541262	1753	Economy	19100.00
0005435529499	1753	Economy	19100.00
0005435541248	1753	Economy	19100.00
0005435541260	1753	Economy	19100.00
0005435541249	1753	Economy	19100.00
0005435529519	1753	Economy	19100.00
0005433516995	1753	Economy	19100.00
0005435541247	1753	Economy	19100.00
0005435529510	1753	Economy	19100.00
0005433516994	1753	Economy	19100.00
0005433516993	1753	Economy	19100.00
0005435541261	1753	Economy	19100.00
0005435541245	1753	Economy	19100.00
0005435529505	1753	Economy	19100.00
0005435529504	1753	Economy	19100.00
0005435541259	1753	Economy	19100.00
0005435529509	1753	Economy	19100.00
0005435529502	1753	Economy	19100.00
0005435529507	1753	Economy	19100.00
0005432925048	1753	Economy	19100.00
0005435541246	1753	Economy	19100.00
0005435541252	1753	Economy	19100.00
0005433516992	1753	Economy	19100.00
0005435541243	1753	Economy	19100.00
0005435529508	1753	Economy	19100.00
0005432925037	1753	Economy	19100.00
0005435541253	1753	Economy	19100.00
0005435529503	1753	Economy	19100.00
0005435529518	1753	Economy	19100.00
0005433516997	1753	Economy	19100.00
0005432925039	1753	Economy	19100.00
0005435541257	1753	Economy	19100.00
0005435529520	1753	Economy	19100.00
0005433516991	1753	Economy	19100.00
0005435529500	1753	Economy	19100.00
0005435541256	1753	Economy	19100.00
0005435541255	1753	Economy	19100.00
0005435529506	1753	Economy	19100.00
0005432925026	1753	Economy	19100.00
0005433516990	1753	Economy	19100.00
0005435529514	1753	Economy	19100.00
0005435529511	1753	Economy	19100.00
0005435517976	22023	Business	57200.00
0005433516887	22023	Business	57200.00
0005435541125	22023	Business	57200.00
0005435517928	22023	Business	57200.00
0005435518011	22023	Business	57200.00
0005432925090	22023	Economy	19100.00
0005435517952	22023	Economy	19100.00
0005435517989	22023	Economy	19100.00
0005435540931	22023	Economy	21000.00
0005432925092	22023	Economy	21000.00
0005435540983	22023	Economy	21000.00
0005433516893	22023	Economy	21000.00
0005435540982	22023	Economy	19100.00
0005433516913	22023	Economy	19100.00
0005435541069	22023	Economy	19100.00
0005435517964	22023	Economy	19100.00
0005435541065	22023	Economy	19100.00
0005435517907	22023	Economy	19100.00
0005435541147	22023	Economy	19100.00
0005433516960	22023	Economy	19100.00
0005433516902	22023	Economy	19100.00
0005433516924	22023	Economy	19100.00
0005435541064	22023	Economy	19100.00
0005435517962	22023	Economy	19100.00
0005432925093	22023	Economy	19100.00
0005433516890	22023	Economy	19100.00
0005433516938	22023	Economy	19100.00
0005435541051	22023	Economy	19100.00
0005435517963	22023	Economy	19100.00
0005435541050	22023	Economy	19100.00
0005435540974	22023	Economy	19100.00
0005435517873	22023	Economy	19100.00
0005435541048	22023	Economy	19100.00
0005435517906	22023	Economy	19100.00
0005433516925	22023	Economy	19100.00
0005435541049	22023	Economy	19100.00
0005433516937	22023	Economy	19100.00
0005432925091	22023	Economy	19100.00
0005435517889	22023	Economy	19100.00
0005435517929	22023	Economy	19100.00
0005432839380	7390	Business	18500.00
0005434459038	7390	Business	18500.00
0005432073430	7390	Business	18500.00
0005432073431	7390	Business	18500.00
0005432839391	7390	Business	18500.00
0005434459044	7390	Business	18500.00
0005432823470	7390	Business	18500.00
0005434459042	7390	Business	18500.00
0005432073429	7390	Business	18500.00
0005435252772	7390	Business	18500.00
0005432841034	7390	Business	18500.00
0005435491445	7390	Economy	6200.00
0005432839402	7390	Economy	6200.00
0005432823471	7390	Economy	6200.00
0005432839384	7390	Economy	6200.00
0005432839403	7390	Economy	6200.00
0005432839394	7390	Economy	6200.00
0005434664964	7390	Economy	6200.00
0005432839374	7390	Economy	6200.00
0005432839397	7390	Economy	6800.00
0005432839399	7390	Economy	6800.00
0005432839378	7390	Economy	6800.00
0005434459045	7390	Economy	6800.00
0005435252688	7390	Economy	6800.00
0005432839386	7390	Economy	6200.00
0005434459037	7390	Economy	6200.00
0005432839401	7390	Economy	6200.00
0005432839382	7390	Economy	6200.00
0005434459031	7390	Economy	6200.00
0005435252698	7390	Economy	6200.00
0005432839387	7390	Economy	6200.00
0005432839389	7390	Economy	6200.00
0005434459040	7390	Economy	6200.00
0005432839393	7390	Economy	6200.00
0005432839373	7390	Economy	6200.00
0005432839400	7390	Economy	6200.00
0005432839375	7390	Economy	6200.00
0005432073428	7390	Economy	6200.00
0005434459032	7390	Economy	6200.00
0005432839376	7390	Economy	6200.00
0005434459047	7390	Economy	6200.00
0005435252792	7390	Economy	6200.00
0005434459050	7390	Economy	6200.00
0005434459039	7390	Economy	6200.00
0005435252692	7390	Economy	6200.00
0005432839390	7390	Economy	6200.00
0005432839388	7390	Economy	6200.00
0005434459036	7390	Economy	6200.00
0005434459048	7390	Economy	6200.00
0005432839379	7390	Economy	6200.00
0005434459046	7390	Economy	6200.00
0005432839377	7390	Economy	6200.00
0005432839381	7390	Economy	6200.00
0005435252728	7390	Economy	6200.00
0005435252716	7390	Economy	6200.00
0005434459041	7390	Economy	6200.00
0005435252737	7390	Economy	6200.00
0005434459035	7390	Economy	6200.00
0005435252733	7390	Economy	6200.00
0005435252679	7390	Economy	6200.00
0005432839398	7390	Economy	6200.00
0005432839395	7390	Economy	6200.00
0005435252732	7390	Economy	6200.00
0005434664963	7390	Economy	6200.00
0005434459033	7390	Economy	6200.00
0005432839392	7390	Economy	6200.00
0005434459043	7390	Economy	6200.00
0005432839396	7390	Economy	6200.00
0005434459034	7390	Economy	6200.00
0005432841035	7390	Economy	6200.00
0005432839383	7390	Economy	6200.00
0005434664966	7390	Economy	6200.00
0005432823472	7390	Economy	6200.00
0005432839385	7390	Economy	6200.00
0005434459049	7390	Economy	6200.00
0005435252774	7390	Economy	6200.00
0005432838985	28938	Business	18500.00
0005432841024	28938	Business	18500.00
0005434664987	28938	Business	18500.00
0005435252912	28938	Business	18500.00
0005432839116	28938	Business	18500.00
0005432839052	28938	Business	18500.00
0005435252911	28938	Business	18500.00
0005435252897	28938	Business	18500.00
0005432839141	28938	Business	18500.00
0005432839078	28938	Economy	6200.00
0005432839054	28938	Economy	6200.00
0005432841017	28938	Economy	6200.00
0005432839203	28938	Economy	6200.00
0005432839053	28938	Economy	6200.00
0005432841018	28938	Economy	6200.00
0005435252909	28938	Economy	6200.00
0005435252908	28938	Economy	6200.00
0005435252896	28938	Economy	6800.00
0005432839086	28938	Economy	6800.00
0005432823459	28938	Economy	6800.00
0005432839088	28938	Economy	6800.00
0005434458838	28938	Economy	6200.00
0005432839087	28938	Economy	6200.00
0005435252907	28938	Economy	6200.00
0005435252895	28938	Economy	6200.00
0005432839285	28938	Economy	6200.00
0005434458964	28938	Economy	6200.00
0005432839223	28938	Economy	6200.00
0005432839161	28938	Economy	6200.00
0005434458903	28938	Economy	6200.00
0005432839252	28938	Economy	6200.00
0005432839199	28938	Economy	6200.00
0005432001047	28938	Economy	6200.00
0005432839202	28938	Economy	6200.00
0005435252901	28938	Economy	6200.00
0005434458871	28938	Economy	6200.00
0005432823460	28938	Economy	6200.00
0005435252893	28938	Economy	6200.00
0005432839135	28938	Economy	6200.00
0005432839051	28938	Economy	6200.00
0005432839210	28938	Economy	6200.00
0005432839200	28938	Economy	6200.00
0005432839222	28938	Economy	6200.00
0005432839221	28938	Economy	6200.00
0005432839079	28938	Economy	6200.00
0005435252902	28938	Economy	6200.00
0005432001046	28938	Economy	6200.00
0005435252898	28938	Economy	6200.00
0005432839128	28938	Economy	6200.00
0005434458844	28938	Economy	6200.00
0005432839085	28938	Economy	6200.00
0005432838984	28938	Economy	6200.00
0005435252894	28938	Economy	6200.00
0005432841012	28938	Economy	6200.00
0005434458864	28938	Economy	6200.00
0005435252904	28938	Economy	6200.00
0005434458842	28938	Economy	6200.00
0005435491464	28938	Economy	6200.00
0005435252900	28938	Economy	6200.00
0005434458880	28938	Economy	6200.00
0005432839115	28938	Economy	6200.00
0005432839120	28938	Economy	6200.00
0005435252899	28938	Economy	6200.00
0005435252906	28938	Economy	6200.00
0005434458870	28938	Economy	6200.00
0005434458875	28938	Economy	6200.00
0005434458843	28938	Economy	6200.00
0005435252910	28938	Economy	6200.00
0005432839235	28938	Economy	6200.00
0005435491463	28938	Economy	6200.00
0005434458841	28938	Economy	6200.00
0005432839153	28938	Economy	6200.00
0005432839129	28938	Economy	6200.00
0005432839165	28938	Economy	6200.00
0005432839251	28938	Economy	6200.00
0005435252905	28938	Economy	6200.00
0005434458874	28938	Economy	6200.00
0005435491465	28938	Economy	6200.00
0005434458910	28938	Economy	6200.00
0005434458823	28938	Economy	6200.00
0005435252903	28938	Economy	6200.00
0005434664988	28938	Economy	6200.00
0005432839160	28938	Economy	6200.00
0005434458881	28938	Economy	6200.00
0005432839140	28938	Economy	6200.00
0005434276067	8828	Business	145300.00
0005435990706	8828	Economy	48400.00
0005435990707	8828	Economy	48400.00
0005434276043	8828	Economy	48400.00
0005434276066	8828	Economy	48400.00
0005434276039	8828	Economy	48400.00
0005434276064	8828	Economy	48400.00
0005434276072	8828	Economy	48400.00
0005435990704	8828	Economy	48400.00
0005435990701	8828	Economy	48400.00
0005435990702	8828	Economy	48400.00
0005434276044	8828	Economy	48400.00
0005434276065	8828	Economy	48400.00
0005435990705	8828	Economy	48400.00
0005435990703	8828	Economy	48400.00
0005434276092	15762	Business	145300.00
0005434276089	15762	Economy	48400.00
0005435990616	15762	Economy	48400.00
0005434276093	15762	Economy	48400.00
0005434276094	15762	Economy	48400.00
0005435990649	15762	Economy	48400.00
0005434276091	15762	Economy	48400.00
0005434276095	15762	Economy	48400.00
0005435990648	15762	Economy	48400.00
0005435990657	15762	Economy	48400.00
0005435990617	15762	Economy	48400.00
0005434276090	15762	Economy	48400.00
0005435990656	15762	Economy	48400.00
0005433468430	2096	Economy	13300.00
0005433468434	2096	Economy	13300.00
0005433468431	2096	Economy	13300.00
0005433468428	2096	Economy	12100.00
0005433468435	2096	Economy	12100.00
0005432909327	2096	Economy	12100.00
0005433468426	2096	Economy	12100.00
0005433468442	2096	Economy	12100.00
0005433468432	2096	Economy	12100.00
0005433468427	2096	Economy	12100.00
0005433468440	2096	Economy	12100.00
0005432909274	2096	Economy	12100.00
0005432909297	2096	Economy	12100.00
0005432909276	2096	Economy	12100.00
0005433468441	2096	Economy	12100.00
0005433468429	2096	Economy	12100.00
0005433468439	2096	Economy	12100.00
0005432909295	2096	Economy	12100.00
0005433468443	2096	Economy	12100.00
0005433468437	2096	Economy	12100.00
0005432909275	2096	Economy	12100.00
0005432909328	2096	Economy	12100.00
0005432909311	2096	Economy	12100.00
0005432909298	2096	Economy	12100.00
0005433468436	2096	Economy	12100.00
0005432909296	2096	Economy	12100.00
0005432909286	2096	Economy	12100.00
0005432909285	2096	Economy	12100.00
0005432909282	2096	Economy	12100.00
0005433468438	2096	Economy	12100.00
0005433468433	2096	Economy	12100.00
0005435177133	6409	Business	36600.00
0005432360903	6409	Business	36600.00
0005432360894	6409	Business	36600.00
0005432360909	6409	Business	36600.00
0005435177228	6409	Business	36600.00
0005432360921	6409	Business	36600.00
0005432062291	6409	Business	36600.00
0005432363453	6409	Business	36600.00
0005432360905	6409	Economy	12200.00
0005432360884	6409	Economy	12200.00
0005432363454	6409	Economy	12200.00
0005432336169	6409	Economy	12200.00
0005432360912	6409	Economy	12200.00
0005432360932	6409	Economy	12200.00
0005432336163	6409	Economy	12200.00
0005432360916	6409	Economy	12200.00
0005432360907	6409	Economy	12200.00
0005434149787	6409	Economy	12200.00
0005432360891	6409	Economy	12200.00
0005432360886	6409	Economy	12200.00
0005432363452	6409	Economy	12200.00
0005432062289	6409	Economy	12200.00
0005435177131	6409	Economy	12200.00
0005435177103	6409	Economy	12200.00
0005435177223	6409	Economy	12200.00
0005432360899	6409	Economy	12200.00
0005435177063	6409	Economy	12200.00
0005434149762	6409	Economy	12200.00
0005435177132	6409	Economy	12200.00
0005435177246	6409	Economy	12200.00
0005435490231	6409	Economy	12200.00
0005432360927	6409	Economy	12200.00
0005432336173	6409	Economy	12200.00
0005432360926	6409	Economy	12200.00
0005432360931	6409	Economy	12200.00
0005432360911	6409	Economy	12200.00
0005432360908	6409	Economy	12200.00
0005432360922	6409	Economy	12200.00
0005434149786	6409	Economy	12200.00
0005435177123	6409	Economy	12200.00
0005432360901	6409	Economy	12200.00
0005432360918	6409	Economy	13400.00
0005435490228	6409	Economy	13400.00
0005432360904	6409	Economy	13400.00
0005432360910	6409	Economy	13400.00
0005435177012	6409	Economy	12200.00
0005432360893	6409	Economy	12200.00
0005432360929	6409	Economy	12200.00
0005435177272	6409	Economy	12200.00
0005432360930	6409	Economy	12200.00
0005432062290	6409	Economy	12200.00
0005432062287	6409	Economy	12200.00
0005432336170	6409	Economy	12200.00
0005435490239	6409	Economy	12200.00
0005435177234	6409	Economy	12200.00
0005435177217	6409	Economy	12200.00
0005432360915	6409	Economy	12200.00
0005432336175	6409	Economy	12200.00
0005432336174	6409	Economy	12200.00
0005435177233	6409	Economy	12200.00
0005435723053	6409	Economy	12200.00
0005432336171	6409	Economy	12200.00
0005434149781	6409	Economy	12200.00
0005435490238	6409	Economy	12200.00
0005432360897	6409	Economy	12200.00
0005435177064	6409	Economy	12200.00
0005435177271	6409	Economy	12200.00
0005435177178	6409	Economy	12200.00
0005432360888	6409	Economy	12200.00
0005432360902	6409	Economy	12200.00
0005432360924	6409	Economy	12200.00
0005432360895	6409	Economy	12200.00
0005432336168	6409	Economy	12200.00
0005432336166	6409	Economy	12200.00
0005435177136	6409	Economy	12200.00
0005432336172	6409	Economy	12200.00
0005432360920	6409	Economy	12200.00
0005435177258	6409	Economy	12200.00
0005432360890	6409	Economy	12200.00
0005432360906	6409	Economy	12200.00
0005434149743	6409	Economy	12200.00
0005432360892	6409	Economy	12200.00
0005432360914	6409	Economy	12200.00
0005432360896	6409	Economy	12200.00
0005435177110	6409	Economy	12200.00
0005435177148	6409	Economy	12200.00
0005432360919	6409	Economy	12200.00
0005432062288	6409	Economy	12200.00
0005432336167	6409	Economy	12200.00
0005435723038	6409	Economy	12200.00
0005432360898	6409	Economy	12200.00
0005432360925	6409	Economy	12200.00
0005432360923	6409	Economy	12200.00
0005432360887	6409	Economy	12200.00
0005432360913	6409	Economy	12200.00
0005432336164	6409	Economy	12200.00
0005435490227	6409	Economy	12200.00
0005432360917	6409	Economy	12200.00
0005435490230	6409	Economy	12200.00
0005432360900	6409	Economy	12200.00
0005435490241	6409	Economy	12200.00
0005432336165	6409	Economy	12200.00
0005432360928	6409	Economy	12200.00
0005432360885	6409	Economy	12200.00
0005435723037	6409	Economy	12200.00
0005435490240	6409	Economy	12200.00
0005432360889	6409	Economy	12200.00
0005435177391	20991	Business	36600.00
0005435177384	20991	Business	36600.00
0005434149857	20991	Business	36600.00
0005434149863	20991	Business	36600.00
0005432360249	20991	Business	36600.00
0005435490274	20991	Business	36600.00
0005432363426	20991	Business	36600.00
0005432360531	20991	Business	36600.00
0005435177396	20991	Business	36600.00
0005432360489	20991	Economy	12200.00
0005434149858	20991	Economy	12200.00
0005432360416	20991	Economy	12200.00
0005432360377	20991	Economy	12200.00
0005432360346	20991	Economy	12200.00
0005434149859	20991	Economy	12200.00
0005432360455	20991	Economy	12200.00
0005435723070	20991	Economy	12200.00
0005432336051	20991	Economy	12200.00
0005435177388	20991	Economy	12200.00
0005435177400	20991	Economy	12200.00
0005432336040	20991	Economy	12200.00
0005435177382	20991	Economy	12200.00
0005435177394	20991	Economy	12200.00
0005432360537	20991	Economy	12200.00
0005435177377	20991	Economy	12200.00
0005432360293	20991	Economy	12200.00
0005435177393	20991	Economy	12200.00
0005432360307	20991	Economy	12200.00
0005432360396	20991	Economy	12200.00
0005435177389	20991	Economy	12200.00
0005432360347	20991	Economy	12200.00
0005432360248	20991	Economy	12200.00
0005435177383	20991	Economy	12200.00
0005432360332	20991	Economy	12200.00
0005432360707	20991	Economy	12200.00
0005432360375	20991	Economy	12200.00
0005435177395	20991	Economy	12200.00
0005432336088	20991	Economy	12200.00
0005432360695	20991	Economy	12200.00
0005432360318	20991	Economy	12200.00
0005432360391	20991	Economy	12200.00
0005432360345	20991	Economy	13400.00
0005432360605	20991	Economy	12200.00
0005432360571	20991	Economy	13400.00
0005435177376	20991	Economy	13400.00
0005432360547	20991	Economy	13400.00
0005432360417	20991	Economy	13400.00
0005432052781	20991	Economy	13400.00
0005434149865	20991	Economy	12200.00
0005432360306	20991	Economy	12200.00
0005434149864	20991	Economy	12200.00
0005432360458	20991	Economy	12200.00
0005432360418	20991	Economy	12200.00
0005432360457	20991	Economy	12200.00
0005434149867	20991	Economy	12200.00
0005435177380	20991	Economy	12200.00
0005434149862	20991	Economy	12200.00
0005432360499	20991	Economy	12200.00
0005432360390	20991	Economy	12200.00
0005432336045	20991	Economy	12200.00
0005432360357	20991	Economy	12200.00
0005435177387	20991	Economy	12200.00
0005432360397	20991	Economy	12200.00
0005435177401	20991	Economy	12200.00
0005435177390	20991	Economy	12200.00
0005432360237	20991	Economy	12200.00
0005432360358	20991	Economy	12200.00
0005432360490	20991	Economy	12200.00
0005432360469	20991	Economy	12200.00
0005434149861	20991	Economy	12200.00
0005434149860	20991	Economy	12200.00
0005435177399	20991	Economy	12200.00
0005432360534	20991	Economy	12200.00
0005435177379	20991	Economy	12200.00
0005435177375	20991	Economy	12200.00
0005435177378	20991	Economy	12200.00
0005432360470	20991	Economy	12200.00
0005435177397	20991	Economy	12200.00
0005432360614	20991	Economy	12200.00
0005432336068	20991	Economy	12200.00
0005432360456	20991	Economy	12200.00
0005432360572	20991	Economy	12200.00
0005432360501	20991	Economy	12200.00
0005435490272	20991	Economy	12200.00
0005434149868	20991	Economy	12200.00
0005432360430	20991	Economy	12200.00
0005432336072	20991	Economy	12200.00
0005432336071	20991	Economy	12200.00
0005432336052	20991	Economy	12200.00
0005432360348	20991	Economy	12200.00
0005432360144	20991	Economy	12200.00
0005432336054	20991	Economy	12200.00
0005435177398	20991	Economy	12200.00
0005435177381	20991	Economy	12200.00
0005432360712	20991	Economy	12200.00
0005432360711	20991	Economy	12200.00
0005432360473	20991	Economy	12200.00
0005435490273	20991	Economy	12200.00
0005432360247	20991	Economy	12200.00
0005432360331	20991	Economy	12200.00
0005432360573	20991	Economy	12200.00
0005432360344	20991	Economy	12200.00
0005435177392	20991	Economy	12200.00
0005435177385	20991	Economy	12200.00
0005435177374	20991	Economy	12200.00
0005434149866	20991	Economy	12200.00
0005435177386	20991	Economy	12200.00
0005432360468	20991	Economy	12200.00
0005434458916	17731	Economy	3100.00
0005434458915	17731	Economy	3100.00
0005434448326	17731	Economy	3100.00
0005434458908	17731	Economy	3100.00
0005434186231	17731	Economy	3100.00
0005434458918	17731	Economy	3100.00
0005434458846	17731	Economy	3100.00
0005434458856	17731	Economy	3100.00
0005434458882	17731	Economy	3100.00
0005434458778	17731	Economy	3100.00
0005434461652	17731	Economy	3100.00
0005434186232	17731	Economy	3100.00
0005434458938	17731	Economy	3100.00
0005434458898	17731	Economy	3100.00
0005434461651	17731	Economy	3100.00
0005434461646	17731	Economy	3100.00
0005434448327	17731	Economy	3100.00
0005434458863	17731	Economy	3100.00
0005434458886	17731	Economy	3100.00
0005434458847	17731	Economy	3100.00
0005434458813	17731	Economy	3100.00
0005434461655	17731	Economy	3100.00
0005434458930	17731	Economy	3100.00
0005434448318	17731	Economy	3100.00
0005434448328	17731	Economy	3100.00
0005434458861	17731	Economy	3100.00
0005434463936	17731	Economy	3100.00
0005434461647	17731	Economy	3100.00
0005434448314	17731	Economy	3100.00
0005434458862	17731	Economy	3100.00
0005434186233	17731	Economy	3100.00
0005434458885	17731	Economy	3100.00
0005434462812	29105	Economy	3400.00
0005434463952	29105	Economy	3400.00
0005434459050	29105	Economy	3400.00
0005434459039	29105	Economy	3400.00
0005434459036	29105	Economy	3100.00
0005434448350	29105	Economy	3100.00
0005434459035	29105	Economy	3100.00
0005434462814	29105	Economy	3100.00
0005434459047	29105	Economy	3100.00
0005434459045	29105	Economy	3100.00
0005434459042	29105	Economy	3100.00
0005434448352	29105	Economy	3100.00
0005434459041	29105	Economy	3100.00
0005434448353	29105	Economy	3100.00
0005434459040	29105	Economy	3100.00
0005434186208	29105	Economy	3100.00
0005434448351	29105	Economy	3100.00
0005434459034	29105	Economy	3100.00
0005434459046	29105	Economy	3100.00
0005434459048	29105	Economy	3100.00
0005434459031	29105	Economy	3100.00
0005434459033	29105	Economy	3100.00
0005434459043	29105	Economy	3100.00
0005434459037	29105	Economy	3100.00
0005434459032	29105	Economy	3100.00
0005434459049	29105	Economy	3100.00
0005434459038	29105	Economy	3100.00
0005434463953	29105	Economy	3100.00
0005434462813	29105	Economy	3100.00
0005434459044	29105	Economy	3100.00
0005432604776	21427	Economy	7300.00
0005432604743	21427	Economy	7300.00
0005432604754	21427	Economy	7300.00
0005432604741	21427	Economy	6600.00
0005432604766	21427	Economy	6600.00
0005432604761	21427	Economy	6600.00
0005432604742	21427	Economy	6600.00
0005432604774	21427	Economy	6600.00
0005432604757	21427	Economy	6600.00
0005432604750	21427	Economy	6600.00
0005432604778	21427	Economy	6600.00
0005432604760	21427	Economy	6600.00
0005432604763	21427	Economy	6600.00
0005432604739	21427	Economy	6600.00
0005432604753	21427	Economy	6600.00
0005432604740	21427	Economy	6600.00
0005432604737	21427	Economy	6600.00
0005432604777	21427	Economy	6600.00
0005432604755	21427	Economy	6600.00
0005432604745	21427	Economy	6600.00
0005432604771	21427	Economy	6600.00
0005432604744	21427	Economy	6600.00
0005432604764	21427	Economy	6600.00
0005432604767	21427	Economy	6600.00
0005432604751	21427	Economy	6600.00
0005435218120	21427	Economy	6600.00
0005432604747	21427	Economy	6600.00
0005432604749	21427	Economy	6600.00
0005432604775	21427	Economy	6600.00
0005432604746	21427	Economy	6600.00
0005432604759	21427	Economy	6600.00
0005432604769	21427	Economy	6600.00
0005432604758	21427	Economy	6600.00
0005432604756	21427	Economy	6600.00
0005432604752	21427	Economy	6600.00
0005432604765	21427	Economy	6600.00
0005432604748	21427	Economy	6600.00
0005432604768	21427	Economy	6600.00
0005432604770	21427	Economy	6600.00
0005432604773	21427	Economy	6600.00
0005432604762	21427	Economy	6600.00
0005432604738	21427	Economy	6600.00
0005432604772	21427	Economy	6600.00
0005432604459	31704	Economy	7300.00
0005432604466	31704	Economy	7300.00
0005432604628	31704	Economy	6600.00
0005432604388	31704	Economy	6600.00
0005432604145	31704	Economy	6600.00
0005432604355	31704	Economy	6600.00
0005432604429	31704	Economy	6600.00
0005432604514	31704	Economy	6600.00
0005432604475	31704	Economy	6600.00
0005432604387	31704	Economy	6600.00
0005432604526	31704	Economy	6600.00
0005432604474	31704	Economy	6600.00
0005432604349	31704	Economy	6600.00
0005432604365	31704	Economy	6600.00
0005432604353	31704	Economy	6600.00
0005432604279	31704	Economy	6600.00
0005435221065	31704	Economy	6600.00
0005432604467	31704	Economy	6600.00
0005432604532	31704	Economy	6600.00
0005432604529	31704	Economy	6600.00
0005432604354	31704	Economy	6600.00
0005432604563	31704	Economy	6600.00
0005432604465	31704	Economy	6600.00
0005432604352	31704	Economy	6600.00
0005432604562	31704	Economy	6600.00
0005432604182	31704	Economy	6600.00
0005432604533	31704	Economy	6600.00
0005435221064	31704	Economy	6600.00
0005432604366	31704	Economy	6600.00
0005433293320	29609	Economy	19500.00
0005433293322	29609	Economy	17800.00
0005433293321	29609	Economy	17800.00
0005433293318	29609	Economy	17800.00
0005433293315	29609	Economy	17800.00
0005433293314	29609	Economy	17800.00
0005433293319	29609	Economy	17800.00
0005433293323	29609	Economy	17800.00
0005433293317	29609	Economy	17800.00
0005433293316	29609	Economy	17800.00
0005433473363	6680	Economy	14000.00
0005433473373	6680	Economy	14000.00
0005435257273	6680	Economy	14000.00
0005435257233	6680	Economy	14000.00
0005435257234	6680	Economy	12700.00
0005433473360	6680	Economy	12700.00
0005435257254	6680	Economy	12700.00
0005433473376	6680	Economy	12700.00
0005435257272	6680	Economy	12700.00
0005433473353	6680	Economy	12700.00
0005435257253	6680	Economy	12700.00
0005435257245	6680	Economy	12700.00
0005433473368	6680	Economy	12700.00
0005435257235	6680	Economy	12700.00
0005433473357	6680	Economy	12700.00
0005433473359	6680	Economy	12700.00
0005433473355	6680	Economy	12700.00
0005433473354	6680	Economy	12700.00
0005435257257	6680	Economy	12700.00
0005435257249	6680	Economy	12700.00
0005433473364	6680	Economy	12700.00
0005433473349	6680	Economy	12700.00
0005433473369	6680	Economy	12700.00
0005433473375	6680	Economy	12700.00
0005433473348	6680	Economy	12700.00
0005433473358	6680	Economy	12700.00
0005433473362	6680	Economy	12700.00
0005433473352	6680	Economy	12700.00
0005433473366	6680	Economy	12700.00
0005435257226	6680	Economy	12700.00
0005433473370	6680	Economy	12700.00
0005433473347	6680	Economy	12700.00
0005433473356	6680	Economy	12700.00
0005433473374	6680	Economy	12700.00
0005433473367	6680	Economy	12700.00
0005433473371	6680	Economy	12700.00
0005433473365	6680	Economy	12700.00
0005433473350	6680	Economy	12700.00
0005435257248	6680	Economy	12700.00
0005433473372	6680	Economy	12700.00
0005433473361	6680	Economy	12700.00
0005433473351	6680	Economy	12700.00
0005435257256	6680	Economy	12700.00
0005434606844	18874	Economy	6600.00
0005434606843	18874	Economy	6600.00
0005434606866	22398	Economy	6600.00
0005434604934	22398	Economy	6600.00
0005435904895	22398	Economy	6600.00
0005434604930	22398	Economy	6600.00
0005434604933	22398	Economy	6600.00
0005434604932	22398	Economy	6600.00
0005434604931	22398	Economy	6600.00
0005432891054	372	Business	44500.00
0005432891046	372	Business	44500.00
0005435154613	372	Business	44500.00
0005432747992	372	Business	44500.00
0005432220051	372	Business	44500.00
0005432753337	372	Business	44500.00
0005432747994	372	Business	44500.00
0005432220048	372	Business	44500.00
0005433293243	372	Business	44500.00
0005432748004	372	Business	44500.00
0005432891066	372	Business	44500.00
0005432748006	372	Business	44500.00
0005432747988	372	Economy	14800.00
0005433293270	372	Economy	14800.00
0005432748002	372	Economy	14800.00
0005432748003	372	Economy	14800.00
0005432891058	372	Economy	14800.00
0005432747989	372	Economy	14800.00
0005433293237	372	Economy	14800.00
0005432891095	372	Economy	14800.00
0005432891045	372	Economy	14800.00
0005432748007	372	Economy	14800.00
0005435154612	372	Economy	16300.00
0005432747978	372	Economy	16300.00
0005432747981	372	Economy	16300.00
0005432747976	372	Economy	16300.00
0005433293238	372	Economy	16300.00
0005432891122	372	Economy	14800.00
0005433293275	372	Economy	14800.00
0005432747974	372	Economy	14800.00
0005432747991	372	Economy	14800.00
0005432891106	372	Economy	14800.00
0005432748001	372	Economy	14800.00
0005432891053	372	Economy	14800.00
0005433293273	372	Economy	14800.00
0005432891037	372	Economy	14800.00
0005432751560	372	Economy	14800.00
0005432747975	372	Economy	14800.00
0005432751562	372	Economy	14800.00
0005432747979	372	Economy	14800.00
0005433293282	372	Economy	14800.00
0005432748000	372	Economy	14800.00
0005432220052	372	Economy	14800.00
0005432748008	372	Economy	14800.00
0005433293247	372	Economy	14800.00
0005432747990	372	Economy	14800.00
0005432747987	372	Economy	14800.00
0005432747993	372	Economy	14800.00
0005432747973	372	Economy	14800.00
0005435154615	372	Economy	14800.00
0005432753334	372	Economy	14800.00
0005432749807	372	Economy	14800.00
0005432891147	372	Economy	14800.00
0005432748005	372	Economy	14800.00
0005432220049	372	Economy	14800.00
0005432749808	372	Economy	14800.00
0005432747985	372	Economy	14800.00
0005432747984	372	Economy	14800.00
0005432891127	372	Economy	14800.00
0005432747980	372	Economy	14800.00
0005432891088	372	Economy	14800.00
0005433293274	372	Economy	14800.00
0005433293264	372	Economy	14800.00
0005432749809	372	Economy	14800.00
0005432753335	372	Economy	14800.00
0005432747982	372	Economy	14800.00
0005432747986	372	Economy	14800.00
0005432891081	372	Economy	14800.00
0005432891121	372	Economy	14800.00
0005432751561	372	Economy	14800.00
0005432891148	372	Economy	14800.00
0005432891087	372	Economy	14800.00
0005435154614	372	Economy	14800.00
0005432747996	372	Economy	14800.00
0005432747983	372	Economy	14800.00
0005432747997	372	Economy	14800.00
0005432747977	372	Economy	14800.00
0005432891023	372	Economy	14800.00
0005432220050	372	Economy	14800.00
0005432747971	372	Economy	14800.00
0005432753336	372	Economy	14800.00
0005432747972	372	Economy	14800.00
0005432747998	372	Economy	14800.00
0005432747995	372	Economy	14800.00
0005432747999	372	Economy	14800.00
0005432891094	372	Economy	14800.00
0005433293246	372	Economy	14800.00
0005432747625	12055	Business	44500.00
0005432747789	12055	Business	44500.00
0005432747837	12055	Business	44500.00
0005432891232	12055	Business	44500.00
0005432891249	12055	Business	44500.00
0005432747678	12055	Business	44500.00
0005432891237	12055	Business	44500.00
0005432756858	12055	Business	44500.00
0005432747526	12055	Business	44500.00
0005432891245	12055	Economy	14800.00
0005432753311	12055	Economy	14800.00
0005432747679	12055	Economy	14800.00
0005432747742	12055	Economy	14800.00
0005432753306	12055	Economy	14800.00
0005432753309	12055	Economy	14800.00
0005432891234	12055	Economy	14800.00
0005432747726	12055	Economy	14800.00
0005432747706	12055	Economy	14800.00
0005432747624	12055	Economy	16300.00
0005432891241	12055	Economy	16300.00
0005433875397	12055	Economy	16300.00
0005432747601	12055	Economy	16300.00
0005432891235	12055	Economy	14800.00
0005432214828	12055	Economy	14800.00
0005432749789	12055	Economy	14800.00
0005432756856	12055	Economy	14800.00
0005432756854	12055	Economy	14800.00
0005432747754	12055	Economy	14800.00
0005432747600	12055	Economy	14800.00
0005432747723	12055	Economy	14800.00
0005432891242	12055	Economy	14800.00
0005432747677	12055	Economy	14800.00
0005432747577	12055	Economy	14800.00
0005432756860	12055	Economy	14800.00
0005432891239	12055	Economy	14800.00
0005432747801	12055	Economy	14800.00
0005432747579	12055	Economy	14800.00
0005432891236	12055	Economy	14800.00
0005432756843	12055	Economy	14800.00
0005432747578	12055	Economy	14800.00
0005432756859	12055	Economy	14800.00
0005432747690	12055	Economy	14800.00
0005432891248	12055	Economy	14800.00
0005432891246	12055	Economy	14800.00
0005432756853	12055	Economy	14800.00
0005432747769	12055	Economy	14800.00
0005432747497	12055	Economy	14800.00
0005432747689	12055	Economy	14800.00
0005432747763	12055	Economy	14800.00
0005432747638	12055	Economy	14800.00
0005432747735	12055	Economy	14800.00
0005432747770	12055	Economy	14800.00
0005432747736	12055	Economy	14800.00
0005432747741	12055	Economy	14800.00
0005432747838	12055	Economy	14800.00
0005432747658	12055	Economy	14800.00
0005432747535	12055	Economy	14800.00
0005432747602	12055	Economy	14800.00
0005432756855	12055	Economy	14800.00
0005432756842	12055	Economy	14800.00
0005432756845	12055	Economy	14800.00
0005432891243	12055	Economy	14800.00
0005432747637	12055	Economy	14800.00
0005432747673	12055	Economy	14800.00
0005432753323	12055	Economy	14800.00
0005432747667	12055	Economy	14800.00
0005432747672	12055	Economy	14800.00
0005432753310	12055	Economy	14800.00
0005432747878	12055	Economy	14800.00
0005432891247	12055	Economy	14800.00
0005432747618	12055	Economy	14800.00
0005432747717	12055	Economy	14800.00
0005432891233	12055	Economy	14800.00
0005432756857	12055	Economy	14800.00
0005432891238	12055	Economy	14800.00
0005432747757	12055	Economy	14800.00
0005432891240	12055	Economy	14800.00
0005432891244	12055	Economy	14800.00
0005432747623	12055	Economy	14800.00
0005432747680	12055	Economy	14800.00
0005432747867	12055	Economy	14800.00
0005432927994	18961	Economy	28200.00
0005433525157	18961	Economy	28200.00
0005432928010	18961	Economy	25700.00
0005433525147	18961	Economy	25700.00
0005433531334	18961	Economy	25700.00
0005433531331	18961	Economy	25700.00
0005433531333	18961	Economy	25700.00
0005433525155	18961	Economy	25700.00
0005433525150	18961	Economy	25700.00
0005433531332	18961	Economy	25700.00
0005433525148	18961	Economy	25700.00
0005432927987	18961	Economy	25700.00
0005432927986	18961	Economy	25700.00
0005433525154	18961	Economy	25700.00
0005433525149	18961	Economy	25700.00
0005432927993	18961	Economy	25700.00
0005432927988	18961	Economy	25700.00
0005432928002	18961	Economy	25700.00
0005433533347	18961	Economy	25700.00
0005433533346	18961	Economy	25700.00
0005433531335	18961	Economy	25700.00
0005433533348	18961	Economy	25700.00
0005432927990	18961	Economy	25700.00
0005433525151	18961	Economy	25700.00
0005433525156	18961	Economy	25700.00
0005433525153	18961	Economy	25700.00
0005433525152	18961	Economy	25700.00
0005432928047	32508	Economy	28200.00
0005433531309	32508	Economy	28200.00
0005433531307	32508	Economy	28200.00
0005433525033	32508	Economy	25700.00
0005433531298	32508	Economy	25700.00
0005433525049	32508	Economy	25700.00
0005433527276	32508	Economy	25700.00
0005432928048	32508	Economy	25700.00
0005432928046	32508	Economy	25700.00
0005433525046	32508	Economy	25700.00
0005433525105	32508	Economy	25700.00
0005433527268	32508	Economy	25700.00
0005433531310	32508	Economy	25700.00
0005433525045	32508	Economy	25700.00
0005433527265	32508	Economy	25700.00
0005432928050	32508	Economy	25700.00
0005432928051	32508	Economy	25700.00
0005433525097	32508	Economy	25700.00
0005433527273	32508	Economy	25700.00
0005433525085	32508	Economy	25700.00
0005433531299	32508	Economy	25700.00
0005433525101	32508	Economy	25700.00
0005433531294	32508	Economy	25700.00
0005433527274	32508	Economy	25700.00
0005433525100	32508	Economy	25700.00
0005433525055	32508	Economy	25700.00
0005433525104	32508	Economy	25700.00
0005433527275	32508	Economy	25700.00
0005432928049	32508	Economy	25700.00
0005433531300	32508	Economy	25700.00
0005433525076	32508	Economy	25700.00
0005433525098	32508	Economy	25700.00
0005433525054	32508	Economy	25700.00
0005433525096	32508	Economy	25700.00
0005433525059	32508	Economy	25700.00
0005435386619	5273	Business	84000.00
0005434825074	5273	Business	84000.00
0005434831198	5273	Business	84000.00
0005434824956	5273	Business	84000.00
0005434825052	5273	Business	84000.00
0005435373250	5273	Business	84000.00
0005434824957	5273	Business	84000.00
0005435373373	5273	Business	84000.00
0005434824980	5273	Business	84000.00
0005434664985	5273	Business	84000.00
0005434825013	5273	Business	84000.00
0005434825071	5273	Business	84000.00
0005435304160	5273	Business	84000.00
0005434824962	5273	Business	84000.00
0005432396287	5273	Business	84000.00
0005434825005	5273	Business	84000.00
0005434825023	5273	Business	84000.00
0005434824951	5273	Business	84000.00
0005434664986	5273	Comfort	47600.00
0005434825026	5273	Business	84000.00
0005434825073	5273	Comfort	47600.00
0005435150181	5273	Comfort	47600.00
0005434824985	5273	Comfort	47600.00
0005432396291	5273	Comfort	47600.00
0005434825042	5273	Comfort	47600.00
0005434831201	5273	Comfort	47600.00
0005434825025	5273	Comfort	47600.00
0005434824973	5273	Comfort	47600.00
0005434824990	5273	Comfort	47600.00
0005434825056	5273	Comfort	47600.00
0005434824995	5273	Comfort	47600.00
0005435304173	5273	Comfort	47600.00
0005435373146	5273	Comfort	47600.00
0005435150185	5273	Comfort	47600.00
0005434825063	5273	Comfort	47600.00
0005432121495	5273	Comfort	47600.00
0005434824968	5273	Comfort	47600.00
0005435373419	5273	Comfort	47600.00
0005434558369	5273	Comfort	47600.00
0005435373562	5273	Comfort	47600.00
0005434824967	5273	Comfort	47600.00
0005435304147	5273	Comfort	47600.00
0005432121492	5273	Comfort	47600.00
0005434824994	5273	Comfort	47600.00
0005435304176	5273	Comfort	47600.00
0005434825011	5273	Comfort	47600.00
0005435150186	5273	Comfort	47600.00
0005435373310	5273	Comfort	47600.00
0005434825059	5273	Comfort	47600.00
0005434825019	5273	Comfort	47600.00
0005434824991	5273	Comfort	47600.00
0005434824966	5273	Comfort	47600.00
0005434824989	5273	Comfort	47600.00
0005434825008	5273	Comfort	47600.00
0005434831199	5273	Comfort	47600.00
0005435373266	5273	Economy	28000.00
0005435386579	5273	Economy	28000.00
0005435373486	5273	Economy	28000.00
0005434824955	5273	Economy	28000.00
0005434664983	5273	Economy	28000.00
0005434824948	5273	Economy	28000.00
0005434824960	5273	Economy	28000.00
0005434825050	5273	Economy	28000.00
0005435373378	5273	Economy	28000.00
0005435150184	5273	Economy	28000.00
0005432121497	5273	Economy	28000.00
0005435373530	5273	Economy	28000.00
0005434824970	5273	Economy	28000.00
0005434825038	5273	Economy	28000.00
0005434825039	5273	Economy	28000.00
0005434824983	5273	Economy	28000.00
0005434825054	5273	Economy	28000.00
0005434825049	5273	Economy	28000.00
0005434825037	5273	Economy	28000.00
0005435661929	5273	Economy	28000.00
0005432121496	5273	Economy	28000.00
0005434831202	5273	Economy	28000.00
0005434825035	5273	Economy	28000.00
0005435373221	5273	Economy	28000.00
0005434824984	5273	Economy	28000.00
0005434825058	5273	Economy	28000.00
0005434824974	5273	Economy	28000.00
0005434825041	5273	Economy	28000.00
0005434824949	5273	Economy	28000.00
0005434825065	5273	Economy	28000.00
0005434824992	5273	Economy	28000.00
0005432121494	5273	Economy	28000.00
0005435373282	5273	Economy	28000.00
0005434825017	5273	Economy	28000.00
0005435373354	5273	Economy	28000.00
0005434825066	5273	Economy	28000.00
0005435150182	5273	Economy	28000.00
0005435373611	5273	Economy	28000.00
0005435373631	5273	Economy	28000.00
0005434825006	5273	Economy	28000.00
0005432121488	5273	Economy	28000.00
0005432396290	5273	Economy	28000.00
0005432121491	5273	Economy	28000.00
0005435386605	5273	Economy	28000.00
0005435373394	5273	Economy	28000.00
0005434824958	5273	Economy	28000.00
0005434824965	5273	Economy	28000.00
0005434825043	5273	Economy	28000.00
0005432121499	5273	Economy	28000.00
0005434824999	5273	Economy	28000.00
0005434825024	5273	Economy	28000.00
0005435373386	5273	Economy	30800.00
0005434825064	5273	Economy	30800.00
0005434825029	5273	Economy	28000.00
0005435373560	5273	Economy	30800.00
0005434825028	5273	Economy	28000.00
0005434824993	5273	Economy	28000.00
0005434825036	5273	Economy	28000.00
0005435373281	5273	Economy	30800.00
0005435373432	5273	Economy	28000.00
0005434825016	5273	Economy	28000.00
0005435373068	5273	Economy	28000.00
0005432394149	5273	Economy	28000.00
0005435373566	5273	Economy	28000.00
0005432394151	5273	Economy	28000.00
0005435373417	5273	Economy	28000.00
0005434558368	5273	Economy	28000.00
0005434825032	5273	Economy	28000.00
0005434824964	5273	Economy	28000.00
0005434825044	5273	Economy	28000.00
0005434825046	5273	Economy	28000.00
0005434825033	5273	Economy	28000.00
0005434824996	5273	Economy	28000.00
0005432121501	5273	Economy	28000.00
0005435373485	5273	Economy	28000.00
0005434825051	5273	Economy	28000.00
0005435373561	5273	Economy	28000.00
0005434825003	5273	Economy	28000.00
0005434825021	5273	Economy	28000.00
0005435150189	5273	Economy	28000.00
0005434824988	5273	Economy	28000.00
0005434825067	5273	Economy	28000.00
0005435373664	5273	Economy	28000.00
0005435150188	5273	Economy	28000.00
0005435304163	5273	Economy	28000.00
0005434558366	5273	Economy	28000.00
0005435150179	5273	Economy	28000.00
0005432121487	5273	Economy	28000.00
0005434825010	5273	Economy	28000.00
0005434825060	5273	Economy	28000.00
0005435150191	5273	Economy	28000.00
0005435373418	5273	Economy	28000.00
0005434824954	5273	Economy	28000.00
0005435373595	5273	Economy	28000.00
0005434824982	5273	Economy	28000.00
0005432396292	5273	Economy	28000.00
0005435373241	5273	Economy	28000.00
0005435661930	5273	Economy	28000.00
0005434825057	5273	Economy	28000.00
0005435661916	5273	Economy	28000.00
0005435373374	5273	Economy	28000.00
0005434831200	5273	Economy	28000.00
0005434824975	5273	Economy	28000.00
0005435299789	5273	Economy	28000.00
0005434824959	5273	Economy	28000.00
0005434825045	5273	Economy	28000.00
0005434828726	5273	Economy	28000.00
0005434825070	5273	Economy	28000.00
0005434825053	5273	Economy	28000.00
0005434824979	5273	Economy	28000.00
0005435373708	5273	Economy	28000.00
0005435373596	5273	Economy	28000.00
0005435373312	5273	Economy	28000.00
0005434824961	5273	Economy	28000.00
0005435150187	5273	Economy	28000.00
0005435373466	5273	Economy	28000.00
0005434825034	5273	Economy	28000.00
0005434824976	5273	Economy	28000.00
0005432396289	5273	Economy	28000.00
0005435373254	5273	Economy	28000.00
0005435150180	5273	Economy	28000.00
0005434558374	5273	Economy	28000.00
0005434558367	5273	Economy	28000.00
0005434824998	5273	Economy	28000.00
0005434825007	5273	Economy	28000.00
0005432121493	5273	Economy	28000.00
0005435373512	5273	Economy	28000.00
0005432394152	5273	Economy	28000.00
0005435373548	5273	Economy	28000.00
0005434825076	5273	Economy	28000.00
0005434825012	5273	Economy	28000.00
0005435150192	5273	Economy	28000.00
0005434824952	5273	Economy	28000.00
0005435386599	5273	Economy	28000.00
0005435373685	5273	Economy	28000.00
0005435373796	5273	Economy	28000.00
0005434825040	5273	Economy	28000.00
0005434825022	5273	Economy	28000.00
0005435373433	5273	Economy	28000.00
0005434828725	5273	Economy	28000.00
0005434825068	5273	Economy	28000.00
0005434825061	5273	Economy	28000.00
0005432121498	5273	Economy	28000.00
0005432121500	5273	Economy	30800.00
0005434825015	5273	Economy	30800.00
0005434824997	5273	Economy	30800.00
0005432121486	5273	Economy	30800.00
0005434825014	5273	Economy	30800.00
0005434825020	5273	Economy	28000.00
0005435304172	5273	Economy	28000.00
0005432121490	5273	Economy	28000.00
0005435373430	5273	Economy	28000.00
0005434825002	5273	Economy	28000.00
0005435150178	5273	Economy	28000.00
0005435373365	5273	Economy	28000.00
0005434825004	5273	Economy	28000.00
0005435373251	5273	Economy	28000.00
0005435373283	5273	Economy	28000.00
0005434825001	5273	Economy	28000.00
0005434558370	5273	Economy	28000.00
0005435373160	5273	Economy	28000.00
0005434824950	5273	Economy	28000.00
0005434825072	5273	Economy	28000.00
0005434825030	5273	Economy	28000.00
0005434824986	5273	Economy	28000.00
0005435386620	5273	Economy	28000.00
0005434558375	5273	Economy	28000.00
0005435373067	5273	Economy	28000.00
0005434824972	5273	Economy	28000.00
0005434558373	5273	Economy	28000.00
0005435373089	5273	Economy	28000.00
0005435304146	5273	Economy	28000.00
0005434824953	5273	Economy	28000.00
0005435304162	5273	Economy	28000.00
0005434825027	5273	Economy	28000.00
0005435373161	5273	Economy	28000.00
0005435150190	5273	Economy	28000.00
0005434825062	5273	Economy	28000.00
0005434824971	5273	Economy	28000.00
0005434824963	5273	Economy	28000.00
0005435386600	5273	Economy	28000.00
0005435373714	5273	Economy	28000.00
0005435373088	5273	Economy	28000.00
0005434824981	5273	Economy	28000.00
0005434825009	5273	Economy	28000.00
0005435373549	5273	Economy	28000.00
0005434825069	5273	Economy	28000.00
0005434558372	5273	Economy	28000.00
0005434825055	5273	Economy	28000.00
0005435373451	5273	Economy	28000.00
0005434824969	5273	Economy	28000.00
0005434825075	5273	Economy	28000.00
0005434824947	5273	Economy	28000.00
0005434558365	5273	Economy	28000.00
0005435373236	5273	Economy	28000.00
0005435373351	5273	Economy	28000.00
0005432394150	5273	Economy	28000.00
0005434825031	5273	Economy	28000.00
0005435661915	5273	Economy	28000.00
0005434558371	5273	Economy	28000.00
0005435373262	5273	Economy	28000.00
0005435304158	5273	Economy	28000.00
0005434825047	5273	Economy	28000.00
0005435373539	5273	Economy	28000.00
0005434824978	5273	Economy	28000.00
0005434825000	5273	Economy	28000.00
0005435373372	5273	Economy	28000.00
0005435373487	5273	Economy	28000.00
0005434828727	5273	Economy	28000.00
0005434824987	5273	Economy	28000.00
0005435373392	5273	Economy	28000.00
0005432121489	5273	Economy	28000.00
0005435373467	5273	Economy	28000.00
0005434664984	5273	Economy	28000.00
0005435373524	5273	Economy	28000.00
0005434825048	5273	Economy	28000.00
0005434824977	5273	Economy	28000.00
0005435150183	5273	Economy	28000.00
0005434825018	5273	Economy	28000.00
0005435373300	5273	Economy	28000.00
0005435373355	5273	Economy	28000.00
0005432396288	5273	Economy	28000.00
0005434823792	9915	Business	84000.00
0005435373995	9915	Business	84000.00
0005434824123	9915	Business	84000.00
0005435373975	9915	Business	84000.00
0005434823192	9915	Business	84000.00
0005434823916	9915	Business	84000.00
0005434823950	9915	Business	84000.00
0005432203147	9915	Business	84000.00
0005435150027	9915	Business	84000.00
0005434558257	9915	Business	84000.00
0005434823655	9915	Business	84000.00
0005435150075	9915	Business	84000.00
0005435374003	9915	Business	84000.00
0005435386647	9915	Business	84000.00
0005435373963	9915	Comfort	47600.00
0005435386645	9915	Comfort	47600.00
0005435373976	9915	Comfort	47600.00
0005435373997	9915	Comfort	47600.00
0005435374025	9915	Comfort	47600.00
0005435373969	9915	Comfort	47600.00
0005434558245	9915	Comfort	47600.00
0005435374014	9915	Comfort	47600.00
0005434823941	9915	Comfort	47600.00
0005435374008	9915	Comfort	47600.00
0005435150014	9915	Comfort	47600.00
0005434823826	9915	Comfort	47600.00
0005434824009	9915	Comfort	47600.00
0005434824126	9915	Comfort	47600.00
0005435150086	9915	Comfort	47600.00
0005435373968	9915	Comfort	47600.00
0005434823441	9915	Comfort	47600.00
0005434823484	9915	Comfort	47600.00
0005432203145	9915	Comfort	47600.00
0005434824243	9915	Comfort	47600.00
0005434824331	9915	Comfort	47600.00
0005435374023	9915	Comfort	47600.00
0005434823882	9915	Comfort	47600.00
0005434823932	9915	Comfort	47600.00
0005432823473	9915	Economy	28000.00
0005434824091	9915	Economy	28000.00
0005435373994	9915	Economy	28000.00
0005435373978	9915	Economy	28000.00
0005434823883	9915	Economy	28000.00
0005434823805	9915	Economy	28000.00
0005435373970	9915	Economy	28000.00
0005434824348	9915	Economy	28000.00
0005434823967	9915	Economy	28000.00
0005434823807	9915	Economy	28000.00
0005434823827	9915	Economy	28000.00
0005434828699	9915	Economy	28000.00
0005434823483	9915	Economy	28000.00
0005435373962	9915	Economy	28000.00
0005434828709	9915	Economy	28000.00
0005435373981	9915	Economy	28000.00
0005435373973	9915	Economy	28000.00
0005435373982	9915	Economy	28000.00
0005434824269	9915	Economy	28000.00
0005435374017	9915	Economy	28000.00
0005434824290	9915	Economy	28000.00
0005435373983	9915	Economy	28000.00
0005434823636	9915	Economy	28000.00
0005434823833	9915	Economy	28000.00
0005435373965	9915	Economy	28000.00
0005434824547	9915	Economy	28000.00
0005434823295	9915	Economy	28000.00
0005432396254	9915	Economy	28000.00
0005435150056	9915	Economy	28000.00
0005434824417	9915	Economy	28000.00
0005434823578	9915	Economy	28000.00
0005434823933	9915	Economy	28000.00
0005434828711	9915	Economy	28000.00
0005434824010	9915	Economy	28000.00
0005434824163	9915	Economy	28000.00
0005432396247	9915	Economy	28000.00
0005435302253	9915	Economy	28000.00
0005435373977	9915	Economy	28000.00
0005435374022	9915	Economy	28000.00
0005434823961	9915	Economy	28000.00
0005434824405	9915	Economy	28000.00
0005434823458	9915	Economy	28000.00
0005435374019	9915	Economy	28000.00
0005434558282	9915	Economy	30800.00
0005435373972	9915	Economy	28000.00
0005435373971	9915	Economy	28000.00
0005435150044	9915	Economy	30800.00
0005434558259	9915	Economy	28000.00
0005435373964	9915	Economy	30800.00
0005435373986	9915	Economy	30800.00
0005435386649	9915	Economy	28000.00
0005434824164	9915	Economy	28000.00
0005435373980	9915	Economy	28000.00
0005434823942	9915	Economy	28000.00
0005434823988	9915	Economy	28000.00
0005435374020	9915	Economy	28000.00
0005434824012	9915	Economy	28000.00
0005435373967	9915	Economy	28000.00
0005434664955	9915	Economy	28000.00
0005434823594	9915	Economy	28000.00
0005435373990	9915	Economy	28000.00
0005434824315	9915	Economy	28000.00
0005434824244	9915	Economy	28000.00
0005434824416	9915	Economy	28000.00
0005434823806	9915	Economy	28000.00
0005434823936	9915	Economy	28000.00
0005434824121	9915	Economy	28000.00
0005435374016	9915	Economy	28000.00
0005435374006	9915	Economy	28000.00
0005435373979	9915	Economy	28000.00
0005435374026	9915	Economy	28000.00
0005434558275	9915	Economy	28000.00
0005432203148	9915	Economy	28000.00
0005434823593	9915	Economy	28000.00
0005435302249	9915	Economy	28000.00
0005434823481	9915	Economy	28000.00
0005434823962	9915	Economy	28000.00
0005435735192	9915	Economy	28000.00
0005435661964	9915	Economy	28000.00
0005435374027	9915	Economy	28000.00
0005435386648	9915	Economy	28000.00
0005434823193	9915	Economy	28000.00
0005434558295	9915	Economy	28000.00
0005435374015	9915	Economy	28000.00
0005434824360	9915	Economy	28000.00
0005435374007	9915	Economy	28000.00
0005434824318	9915	Economy	28000.00
0005435302250	9915	Economy	28000.00
0005434823191	9915	Economy	28000.00
0005434823794	9915	Economy	28000.00
0005434824442	9915	Economy	28000.00
0005435373998	9915	Economy	28000.00
0005434823842	9915	Economy	28000.00
0005434824037	9915	Economy	28000.00
0005434823828	9915	Economy	28000.00
0005435374002	9915	Economy	28000.00
0005434824002	9915	Economy	28000.00
0005434824092	9915	Economy	28000.00
0005434823970	9915	Economy	28000.00
0005434558293	9915	Economy	28000.00
0005435735189	9915	Economy	28000.00
0005435150087	9915	Economy	28000.00
0005432203143	9915	Economy	28000.00
0005434828698	9915	Economy	28000.00
0005434558291	9915	Economy	28000.00
0005434824127	9915	Economy	28000.00
0005434824398	9915	Economy	28000.00
0005434824289	9915	Economy	28000.00
0005435150088	9915	Economy	28000.00
0005434824145	9915	Economy	28000.00
0005434824538	9915	Economy	28000.00
0005435302252	9915	Economy	28000.00
0005435735191	9915	Economy	28000.00
0005434823990	9915	Economy	28000.00
0005434823984	9915	Economy	28000.00
0005434828712	9915	Economy	28000.00
0005435373992	9915	Economy	28000.00
0005435374010	9915	Economy	28000.00
0005434823774	9915	Economy	28000.00
0005434824156	9915	Economy	28000.00
0005435299828	9915	Economy	28000.00
0005435150013	9915	Economy	28000.00
0005434824291	9915	Economy	28000.00
0005434823877	9915	Economy	28000.00
0005434824390	9915	Economy	28000.00
0005434823552	9915	Economy	28000.00
0005432203144	9915	Economy	30800.00
0005435150028	9915	Economy	30800.00
0005434823846	9915	Economy	30800.00
0005434823981	9915	Economy	30800.00
0005434558258	9915	Economy	28000.00
0005434824057	9915	Economy	28000.00
0005432203146	9915	Economy	28000.00
0005435302251	9915	Economy	28000.00
0005435386644	9915	Economy	28000.00
0005434823986	9915	Economy	28000.00
0005434823773	9915	Economy	28000.00
0005434823528	9915	Economy	28000.00
0005435735190	9915	Economy	28000.00
0005432203142	9915	Economy	28000.00
0005435150026	9915	Economy	28000.00
0005435373989	9915	Economy	28000.00
0005435373988	9915	Economy	28000.00
0005434828710	9915	Economy	28000.00
0005435386650	9915	Economy	28000.00
0005434824177	9915	Economy	28000.00
0005434824330	9915	Economy	28000.00
0005435374028	9915	Economy	28000.00
0005434823985	9915	Economy	28000.00
0005435374012	9915	Economy	28000.00
0005434823963	9915	Economy	28000.00
0005434824011	9915	Economy	28000.00
0005435373993	9915	Economy	28000.00
0005434558256	9915	Economy	28000.00
0005435661965	9915	Economy	28000.00
0005434824176	9915	Economy	28000.00
0005435299827	9915	Economy	28000.00
0005434823457	9915	Economy	28000.00
0005435373974	9915	Economy	28000.00
0005435374021	9915	Economy	28000.00
0005435373999	9915	Economy	28000.00
0005435179404	9915	Economy	28000.00
0005434824270	9915	Economy	28000.00
0005434558274	9915	Economy	28000.00
0005434824001	9915	Economy	28000.00
0005434823579	9915	Economy	28000.00
0005432400126	9915	Economy	28000.00
0005434824288	9915	Economy	28000.00
0005435299830	9915	Economy	28000.00
0005435150098	9915	Economy	28000.00
0005432396257	9915	Economy	28000.00
0005434823560	9915	Economy	28000.00
0005434823832	9915	Economy	28000.00
0005434824232	9915	Economy	28000.00
0005435374011	9915	Economy	28000.00
0005435373987	9915	Economy	28000.00
0005434823957	9915	Economy	28000.00
0005435373985	9915	Economy	28000.00
0005435150060	9915	Economy	28000.00
0005435299829	9915	Economy	28000.00
0005435373996	9915	Economy	28000.00
0005434823606	9915	Economy	28000.00
0005434823757	9915	Economy	28000.00
0005434823966	9915	Economy	28000.00
0005434823808	9915	Economy	28000.00
0005434823845	9915	Economy	28000.00
0005434823987	9915	Economy	28000.00
0005435373966	9915	Economy	28000.00
0005435374005	9915	Economy	28000.00
0005434558276	9915	Economy	28000.00
0005435374004	9915	Economy	28000.00
0005434824058	9915	Economy	28000.00
0005434823789	9915	Economy	28000.00
0005434558294	9915	Economy	28000.00
0005432400107	9915	Economy	28000.00
0005435374013	9915	Economy	28000.00
0005435374009	9915	Economy	28000.00
0005435374001	9915	Economy	28000.00
0005435374024	9915	Economy	28000.00
0005435374000	9915	Economy	28000.00
0005434823976	9915	Economy	28000.00
0005435299831	9915	Economy	28000.00
0005435386646	9915	Economy	28000.00
0005434823964	9915	Economy	28000.00
0005435373991	9915	Economy	28000.00
0005434824391	9915	Economy	28000.00
0005435374018	9915	Economy	28000.00
0005434558292	9915	Economy	28000.00
0005435150076	9915	Economy	28000.00
0005434823844	9915	Economy	28000.00
0005434828708	9915	Economy	28000.00
0005434823793	9915	Economy	28000.00
0005435373984	9915	Economy	28000.00
0005434823524	9915	Economy	28000.00
0005435082874	6974	Economy	8200.00
0005435790339	6974	Economy	7400.00
0005435082877	6974	Economy	7400.00
0005435082879	6974	Economy	7400.00
0005435082873	6974	Economy	7400.00
0005435082880	6974	Economy	7400.00
0005435790340	6974	Economy	7400.00
0005435082876	6974	Economy	7400.00
0005435082878	6974	Economy	7400.00
0005435082875	6974	Economy	7400.00
0005435082881	6974	Economy	7400.00
0005435082803	26008	Economy	7400.00
0005435082802	26008	Economy	7400.00
0005435790305	26008	Economy	7400.00
0005435082806	26008	Economy	7400.00
0005435082771	26008	Economy	7400.00
0005435082789	26008	Economy	7400.00
0005434756914	9515	Business	32800.00
0005434756926	9515	Business	32800.00
0005434756927	9515	Business	32800.00
0005434756889	9515	Business	32800.00
0005434756895	9515	Business	32800.00
0005434214705	9515	Business	32800.00
0005434756923	9515	Business	32800.00
0005434756916	9515	Business	32800.00
0005434214601	9515	Business	32800.00
0005434756904	9515	Business	32800.00
0005434756909	9515	Business	32800.00
0005434214714	9515	Economy	10900.00
0005434214580	9515	Economy	10900.00
0005434214520	9515	Economy	10900.00
0005434214652	9515	Economy	10900.00
0005434756911	9515	Economy	10900.00
0005434214506	9515	Economy	10900.00
0005434756925	9515	Economy	10900.00
0005434214632	9515	Economy	10900.00
0005434214710	9515	Economy	10900.00
0005434756885	9515	Economy	10900.00
0005434756908	9515	Economy	12000.00
0005434214703	9515	Economy	12000.00
0005434756905	9515	Economy	12000.00
0005434214704	9515	Economy	12000.00
0005434214655	9515	Economy	12000.00
0005434756924	9515	Economy	10900.00
0005434756910	9515	Economy	10900.00
0005434214380	9515	Economy	10900.00
0005434214777	9515	Economy	10900.00
0005434214507	9515	Economy	10900.00
0005434214581	9515	Economy	10900.00
0005434756912	9515	Economy	10900.00
0005434214600	9515	Economy	10900.00
0005434214436	9515	Economy	10900.00
0005434756922	9515	Economy	10900.00
0005434756886	9515	Economy	10900.00
0005434214764	9515	Economy	10900.00
0005434756906	9515	Economy	10900.00
0005434756921	9515	Economy	10900.00
0005434756919	9515	Economy	10900.00
0005434756898	9515	Economy	10900.00
0005434756920	9515	Economy	10900.00
0005434214486	9515	Economy	10900.00
0005434756915	9515	Economy	10900.00
0005434756890	9515	Economy	10900.00
0005434214485	9515	Economy	10900.00
0005434756882	9515	Economy	10900.00
0005434756883	9515	Economy	10900.00
0005434214765	9515	Economy	10900.00
0005434756917	9515	Economy	10900.00
0005434214806	9515	Economy	10900.00
0005434214709	9515	Economy	10900.00
0005434756913	9515	Economy	10900.00
0005434756896	9515	Economy	10900.00
0005434214724	9515	Economy	10900.00
0005434214631	9515	Economy	10900.00
0005434214493	9515	Economy	10900.00
0005434214427	9515	Economy	10900.00
0005434756881	9515	Economy	10900.00
0005434214372	9515	Economy	10900.00
0005434214551	9515	Economy	10900.00
0005434756893	9515	Economy	10900.00
0005434214501	9515	Economy	10900.00
0005434756892	9515	Economy	10900.00
0005434214745	9515	Economy	10900.00
0005434756907	9515	Economy	10900.00
0005434756891	9515	Economy	10900.00
0005434214719	9515	Economy	10900.00
0005434756884	9515	Economy	10900.00
0005434214741	9515	Economy	10900.00
0005434756918	9515	Economy	10900.00
0005434756902	9515	Economy	10900.00
0005434756888	9515	Economy	10900.00
0005434214535	9515	Economy	10900.00
0005434756887	9515	Economy	10900.00
0005434214602	9515	Economy	10900.00
0005434214624	9515	Economy	10900.00
0005434214521	9515	Economy	10900.00
0005434756894	9515	Economy	10900.00
0005434756900	9515	Economy	10900.00
0005434756903	9515	Economy	10900.00
0005434214585	9515	Economy	10900.00
0005434756897	9515	Economy	10900.00
0005434214720	9515	Economy	10900.00
0005434214775	9515	Economy	10900.00
0005434214723	9515	Economy	10900.00
0005434214625	9515	Economy	10900.00
0005434756899	9515	Economy	10900.00
0005434214502	9515	Economy	10900.00
0005434214744	9515	Economy	10900.00
0005434756901	9515	Economy	10900.00
0005434214686	9515	Economy	10900.00
0005434214484	9515	Economy	10900.00
0005434214987	28635	Business	32800.00
0005434756346	28635	Business	32800.00
0005434215006	28635	Business	32800.00
0005434756475	28635	Business	32800.00
0005434756511	28635	Business	32800.00
0005434214984	28635	Business	32800.00
0005434215023	28635	Business	32800.00
0005434215011	28635	Business	32800.00
0005434214998	28635	Business	32800.00
0005434756424	28635	Business	32800.00
0005434215021	28635	Business	32800.00
0005434756496	28635	Economy	10900.00
0005434756352	28635	Economy	10900.00
0005434756534	28635	Economy	10900.00
0005434214991	28635	Economy	10900.00
0005434215016	28635	Economy	10900.00
0005434756408	28635	Economy	10900.00
0005434756370	28635	Economy	10900.00
0005434756400	28635	Economy	10900.00
0005434756343	28635	Economy	10900.00
0005434215019	28635	Economy	12000.00
0005434214983	28635	Economy	12000.00
0005434215007	28635	Economy	12000.00
0005434756470	28635	Economy	12000.00
0005434756473	28635	Economy	10900.00
0005434214988	28635	Economy	10900.00
0005434215003	28635	Economy	10900.00
0005434215029	28635	Economy	10900.00
0005434756512	28635	Economy	10900.00
0005434756205	28635	Economy	10900.00
0005434215014	28635	Economy	10900.00
0005434215017	28635	Economy	10900.00
0005434756409	28635	Economy	10900.00
0005434215027	28635	Economy	10900.00
0005434756457	28635	Economy	10900.00
0005434756430	28635	Economy	10900.00
0005434756464	28635	Economy	10900.00
0005434756276	28635	Economy	10900.00
0005434756455	28635	Economy	10900.00
0005434756456	28635	Economy	10900.00
0005434756344	28635	Economy	10900.00
0005434214993	28635	Economy	10900.00
0005434215008	28635	Economy	10900.00
0005434215015	28635	Economy	10900.00
0005434215002	28635	Economy	10900.00
0005434215005	28635	Economy	10900.00
0005434756380	28635	Economy	10900.00
0005434215022	28635	Economy	10900.00
0005434756593	28635	Economy	10900.00
0005434756362	28635	Economy	10900.00
0005434756505	28635	Economy	10900.00
0005434215012	28635	Economy	10900.00
0005434756540	28635	Economy	10900.00
0005434756527	28635	Economy	10900.00
0005434214989	28635	Economy	10900.00
0005434215004	28635	Economy	10900.00
0005434756410	28635	Economy	10900.00
0005434756497	28635	Economy	10900.00
0005434756571	28635	Economy	10900.00
0005434215000	28635	Economy	10900.00
0005434214996	28635	Economy	10900.00
0005434756458	28635	Economy	10900.00
0005434756439	28635	Economy	10900.00
0005434756353	28635	Economy	10900.00
0005434215026	28635	Economy	10900.00
0005434215013	28635	Economy	10900.00
0005434214994	28635	Economy	10900.00
0005434214992	28635	Economy	10900.00
0005434214997	28635	Economy	10900.00
0005434215009	28635	Economy	10900.00
0005434215028	28635	Economy	10900.00
0005434214986	28635	Economy	10900.00
0005434214990	28635	Economy	10900.00
0005434756447	28635	Economy	10900.00
0005434215024	28635	Economy	10900.00
0005434756541	28635	Economy	10900.00
0005434756506	28635	Economy	10900.00
0005434214995	28635	Economy	10900.00
0005434215010	28635	Economy	10900.00
0005434214999	28635	Economy	10900.00
0005434214985	28635	Economy	10900.00
0005434756535	28635	Economy	10900.00
0005434756533	28635	Economy	10900.00
0005434215025	28635	Economy	10900.00
0005434756469	28635	Economy	10900.00
0005434756472	28635	Economy	10900.00
0005434215018	28635	Economy	10900.00
0005434215020	28635	Economy	10900.00
0005434215001	28635	Economy	10900.00
0005435100156	10838	Economy	8900.00
0005434760195	10838	Economy	8900.00
0005435100157	10838	Economy	8900.00
0005434760196	10838	Economy	8900.00
0005435100155	10838	Economy	8900.00
0005435100117	31811	Economy	9800.00
0005434760224	31811	Economy	8900.00
0005434760225	31811	Economy	8900.00
0005435100132	31811	Economy	8900.00
0005434639599	1981	Economy	20900.00
0005433202374	1981	Economy	20900.00
0005434639608	1981	Economy	20900.00
0005433202372	1981	Economy	19000.00
0005434639620	1981	Economy	19000.00
0005434639619	1981	Economy	19000.00
0005433202378	1981	Economy	19000.00
0005432290667	1981	Economy	19000.00
0005434639603	1981	Economy	19000.00
0005434639611	1981	Economy	19000.00
0005433202406	1981	Economy	19000.00
0005434639626	1981	Economy	19000.00
0005434639606	1981	Economy	19000.00
0005432290669	1981	Economy	19000.00
0005434639610	1981	Economy	19000.00
0005434639612	1981	Economy	19000.00
0005434639600	1981	Economy	19000.00
0005434639613	1981	Economy	19000.00
0005433202442	1981	Economy	19000.00
0005433202413	1981	Economy	19000.00
0005432290668	1981	Economy	19000.00
0005433202373	1981	Economy	19000.00
0005433202405	1981	Economy	19000.00
0005433202371	1981	Economy	19000.00
0005435948337	1981	Economy	19000.00
0005434639614	1981	Economy	19000.00
0005434639617	1981	Economy	19000.00
0005434639625	1981	Economy	19000.00
0005433202376	1981	Economy	19000.00
0005434639615	1981	Economy	19000.00
0005434639601	1981	Economy	19000.00
0005434639621	1981	Economy	19000.00
0005434639616	1981	Economy	19000.00
0005434639623	1981	Economy	19000.00
0005434639618	1981	Economy	19000.00
0005434639609	1981	Economy	19000.00
0005434639624	1981	Economy	19000.00
0005433202393	1981	Economy	19000.00
0005434639607	1981	Economy	19000.00
0005433202395	1981	Economy	19000.00
0005434639605	1981	Economy	19000.00
0005434639622	1981	Economy	19000.00
0005434639604	1981	Economy	19000.00
0005434639602	1981	Economy	19000.00
0005434639276	23248	Economy	20900.00
0005434639313	23248	Economy	20900.00
0005433202511	23248	Economy	20900.00
0005433202520	23248	Economy	20900.00
0005434639287	23248	Economy	19000.00
0005433202516	23248	Economy	19000.00
0005434639420	23248	Economy	19000.00
0005434639419	23248	Economy	19000.00
0005434639426	23248	Economy	19000.00
0005434639327	23248	Economy	19000.00
0005434639323	23248	Economy	19000.00
0005434639398	23248	Economy	19000.00
0005434639367	23248	Economy	19000.00
0005434639406	23248	Economy	19000.00
0005434639286	23248	Economy	19000.00
0005434639425	23248	Economy	19000.00
0005433202519	23248	Economy	19000.00
0005433202522	23248	Economy	19000.00
0005433202510	23248	Economy	19000.00
0005433202514	23248	Economy	19000.00
0005434639383	23248	Economy	19000.00
0005433202509	23248	Economy	19000.00
0005434639368	23248	Economy	19000.00
0005434639366	23248	Economy	19000.00
0005434639405	23248	Economy	19000.00
0005434639399	23248	Economy	19000.00
0005434639277	23248	Economy	19000.00
0005434639301	23248	Economy	19000.00
0005434639322	23248	Economy	19000.00
0005434639447	23248	Economy	19000.00
0005433202515	23248	Economy	19000.00
0005434639396	23248	Economy	19000.00
0005433202523	23248	Economy	19000.00
0005434639407	23248	Economy	19000.00
0005433202521	23248	Economy	19000.00
0005434639384	23248	Economy	19000.00
0005434639334	23248	Economy	19000.00
0005433202512	23248	Economy	19000.00
0005433202513	23248	Economy	19000.00
0005434639359	23248	Economy	19000.00
0005434639446	23248	Economy	19000.00
0005434639312	23248	Economy	19000.00
0005433202517	23248	Economy	19000.00
0005434639328	23248	Economy	19000.00
0005433202518	23248	Economy	19000.00
0005434639365	23248	Economy	19000.00
0005434639395	23248	Economy	19000.00
0005434639423	23248	Economy	19000.00
0005434639414	23248	Economy	19000.00
0005434601112	6087	Business	69700.00
0005435326799	6087	Business	69700.00
0005434601115	6087	Business	69700.00
0005435326745	6087	Business	69700.00
0005433531336	6087	Business	69700.00
0005435326798	6087	Business	69700.00
0005435326793	6087	Business	69700.00
0005434601101	6087	Economy	23200.00
0005435326767	6087	Economy	23200.00
0005435326777	6087	Economy	23200.00
0005434601125	6087	Economy	23200.00
0005435326771	6087	Economy	23200.00
0005434601126	6087	Economy	23200.00
0005435326848	6087	Economy	25600.00
0005434601106	6087	Economy	25600.00
0005435326731	6087	Economy	23200.00
0005435326762	6087	Economy	23200.00
0005434601119	6087	Economy	23200.00
0005435326751	6087	Economy	23200.00
0005434601100	6087	Economy	23200.00
0005433533351	6087	Economy	23200.00
0005434601110	6087	Economy	23200.00
0005434601108	6087	Economy	23200.00
0005434601107	6087	Economy	23200.00
0005434601113	6087	Economy	23200.00
0005433533350	6087	Economy	23200.00
0005434601102	6087	Economy	23200.00
0005432111313	6087	Economy	23200.00
0005434601117	6087	Economy	23200.00
0005434601111	6087	Economy	23200.00
0005434601118	6087	Economy	23200.00
0005434601105	6087	Economy	23200.00
0005435326763	6087	Economy	23200.00
0005433531337	6087	Economy	23200.00
0005435326772	6087	Economy	23200.00
0005435326766	6087	Economy	23200.00
0005435326746	6087	Economy	23200.00
0005434601109	6087	Economy	23200.00
0005435326755	6087	Economy	23200.00
0005434601116	6087	Economy	23200.00
0005433533349	6087	Economy	23200.00
0005433533352	6087	Economy	23200.00
0005435326849	6087	Economy	23200.00
0005435326850	6087	Economy	23200.00
0005434601120	6087	Economy	23200.00
0005434601103	6087	Economy	23200.00
0005433533353	6087	Economy	23200.00
0005434601121	6087	Economy	23200.00
0005432111312	6087	Economy	23200.00
0005434601124	6087	Economy	23200.00
0005434601122	6087	Economy	23200.00
0005434601114	6087	Economy	23200.00
0005434601123	6087	Economy	23200.00
0005434601104	6087	Economy	23200.00
0005435326768	6087	Economy	23200.00
0005434600971	18555	Business	69700.00
0005434600748	18555	Business	69700.00
0005434600978	18555	Business	69700.00
0005434600878	18555	Business	69700.00
0005433531297	18555	Business	69700.00
0005434600800	18555	Business	69700.00
0005434600798	18555	Business	69700.00
0005434600935	18555	Economy	23200.00
0005434600966	18555	Economy	23200.00
0005434600863	18555	Economy	23200.00
0005433531296	18555	Economy	23200.00
0005435326904	18555	Economy	23200.00
0005433527255	18555	Economy	23200.00
0005435326897	18555	Economy	23200.00
0005435326907	18555	Economy	23200.00
0005433527257	18555	Economy	25600.00
0005435326905	18555	Economy	25600.00
0005434600930	18555	Economy	25600.00
0005434600938	18555	Economy	25600.00
0005434600903	18555	Economy	23200.00
0005434600891	18555	Economy	23200.00
0005434600918	18555	Economy	23200.00
0005434600865	18555	Economy	23200.00
0005434600816	18555	Economy	23200.00
0005435326903	18555	Economy	23200.00
0005433531288	18555	Economy	23200.00
0005433527271	18555	Economy	23200.00
0005434600775	18555	Economy	23200.00
0005435326898	18555	Economy	23200.00
0005433527277	18555	Economy	23200.00
0005433527259	18555	Economy	23200.00
0005435326900	18555	Economy	23200.00
0005435326906	18555	Economy	23200.00
0005434600815	18555	Economy	23200.00
0005434600936	18555	Economy	23200.00
0005433531293	18555	Economy	23200.00
0005433531287	18555	Economy	23200.00
0005434600953	18555	Economy	23200.00
0005434600959	18555	Economy	23200.00
0005434600805	18555	Economy	23200.00
0005434600799	18555	Economy	23200.00
0005433527254	18555	Economy	23200.00
0005434600902	18555	Economy	23200.00
0005434600862	18555	Economy	23200.00
0005434600861	18555	Economy	23200.00
0005433531305	18555	Economy	23200.00
0005434600879	18555	Economy	23200.00
0005434600967	18555	Economy	23200.00
0005433527272	18555	Economy	23200.00
0005434600790	18555	Economy	23200.00
0005434600982	18555	Economy	23200.00
0005434600901	18555	Economy	23200.00
0005434600980	18555	Economy	23200.00
0005434600831	18555	Economy	23200.00
0005434600952	18555	Economy	23200.00
0005433527258	18555	Economy	23200.00
0005433527263	18555	Economy	23200.00
0005435326902	18555	Economy	23200.00
0005435326899	18555	Economy	23200.00
0005434600998	18555	Economy	23200.00
0005434600939	18555	Economy	23200.00
0005435326894	18555	Economy	23200.00
0005434600826	18555	Economy	23200.00
0005434600981	18555	Economy	23200.00
0005434600919	18555	Economy	23200.00
0005435326895	18555	Economy	23200.00
0005433527260	18555	Economy	23200.00
0005435326901	18555	Economy	23200.00
0005434600860	18555	Economy	23200.00
0005435326896	18555	Economy	23200.00
0005433527264	18555	Economy	23200.00
0005434551799	10595	Business	9100.00
0005434551797	10595	Business	9100.00
0005433181225	10595	Business	9100.00
0005434554085	10595	Business	9100.00
0005434558360	10595	Business	9100.00
0005434558355	10595	Business	9100.00
0005434551804	10595	Business	9100.00
0005433181065	10595	Business	9100.00
0005434551823	10595	Business	9100.00
0005434551769	10595	Business	9100.00
0005434551810	10595	Business	9100.00
0005433181214	10595	Business	9100.00
0005433181139	10595	Economy	3000.00
0005434551816	10595	Economy	3000.00
0005433181215	10595	Economy	3000.00
0005434551813	10595	Economy	3000.00
0005434551814	10595	Economy	3000.00
0005434551772	10595	Economy	3000.00
0005433181206	10595	Economy	3000.00
0005433181049	10595	Economy	3000.00
0005434551788	10595	Economy	3000.00
0005434551809	10595	Economy	3000.00
0005434551800	10595	Economy	3300.00
0005434558356	10595	Economy	3300.00
0005433181226	10595	Economy	3300.00
0005434558357	10595	Economy	3300.00
0005434551775	10595	Economy	3300.00
0005433181072	10595	Economy	3000.00
0005433181133	10595	Economy	3000.00
0005434551818	10595	Economy	3000.00
0005433181168	10595	Economy	3000.00
0005434551793	10595	Economy	3000.00
0005434551782	10595	Economy	3000.00
0005433181169	10595	Economy	3000.00
0005434551807	10595	Economy	3000.00
0005433181147	10595	Economy	3000.00
0005434551801	10595	Economy	3000.00
0005434551805	10595	Economy	3000.00
0005433181071	10595	Economy	3000.00
0005433181151	10595	Economy	3000.00
0005433181167	10595	Economy	3000.00
0005434551786	10595	Economy	3000.00
0005434551815	10595	Economy	3000.00
0005434551790	10595	Economy	3000.00
0005433181080	10595	Economy	3000.00
0005434551796	10595	Economy	3000.00
0005434551803	10595	Economy	3000.00
0005433181207	10595	Economy	3000.00
0005434551777	10595	Economy	3000.00
0005434558358	10595	Economy	3000.00
0005434558362	10595	Economy	3000.00
0005434551783	10595	Economy	3000.00
0005434551808	10595	Economy	3000.00
0005434551812	10595	Economy	3000.00
0005433181158	10595	Economy	3000.00
0005434551785	10595	Economy	3000.00
0005433181183	10595	Economy	3000.00
0005434551776	10595	Economy	3000.00
0005433181182	10595	Economy	3000.00
0005434551784	10595	Economy	3000.00
0005434558364	10595	Economy	3000.00
0005434551774	10595	Economy	3000.00
0005434551792	10595	Economy	3000.00
0005434551819	10595	Economy	3000.00
0005434554086	10595	Economy	3000.00
0005434551791	10595	Economy	3000.00
0005434551768	10595	Economy	3000.00
0005434558363	10595	Economy	3000.00
0005434551820	10595	Economy	3000.00
0005434551773	10595	Economy	3000.00
0005434551795	10595	Economy	3000.00
0005434551787	10595	Economy	3000.00
0005433181160	10595	Economy	3000.00
0005434551770	10595	Economy	3000.00
0005434551821	10595	Economy	3000.00
0005434551794	10595	Economy	3000.00
0005433181142	10595	Economy	3000.00
0005434558359	10595	Economy	3000.00
0005434551778	10595	Economy	3000.00
0005433181234	10595	Economy	3000.00
0005434551779	10595	Economy	3000.00
0005434551817	10595	Economy	3000.00
0005434551780	10595	Economy	3000.00
0005434551822	10595	Economy	3000.00
0005434551771	10595	Economy	3000.00
0005434558354	10595	Economy	3000.00
0005434558361	10595	Economy	3000.00
0005434551789	10595	Economy	3000.00
0005434551781	10595	Economy	3000.00
0005434551802	10595	Economy	3000.00
0005434551806	10595	Economy	3000.00
0005434551798	10595	Economy	3000.00
0005434551811	10595	Economy	3000.00
0005433181050	10595	Economy	3000.00
0005433181392	27785	Business	9100.00
0005433181387	27785	Business	9100.00
0005433181380	27785	Business	9100.00
0005433181385	27785	Economy	3000.00
0005433181395	27785	Economy	3000.00
0005433181397	27785	Economy	3300.00
0005433181394	27785	Economy	3300.00
0005433181382	27785	Economy	3000.00
0005433181396	27785	Economy	3000.00
0005433181386	27785	Economy	3000.00
0005433181374	27785	Economy	3000.00
0005433181381	27785	Economy	3000.00
0005433181379	27785	Economy	3000.00
0005433181390	27785	Economy	3000.00
0005433181384	27785	Economy	3000.00
0005433181375	27785	Economy	3000.00
0005433181393	27785	Economy	3000.00
0005433181376	27785	Economy	3000.00
0005433181398	27785	Economy	3000.00
0005433181373	27785	Economy	3000.00
0005433181383	27785	Economy	3000.00
0005433181378	27785	Economy	3000.00
0005433181377	27785	Economy	3000.00
0005433181388	27785	Economy	3000.00
0005433181391	27785	Economy	3000.00
0005433181389	27785	Economy	3000.00
0005433181372	27785	Economy	3000.00
0005434551520	27669	Business	9100.00
0005434551224	27669	Business	9100.00
0005434551102	27669	Business	9100.00
0005434551487	27669	Business	9100.00
0005434551290	27669	Business	9100.00
0005434551538	27669	Business	9100.00
0005434551302	27669	Business	9100.00
0005434551329	27669	Business	9100.00
0005434551534	27669	Economy	3000.00
0005434551445	27669	Economy	3000.00
0005434551396	27669	Economy	3000.00
0005434551394	27669	Economy	3000.00
0005434551176	27669	Economy	3000.00
0005434558280	27669	Economy	3000.00
0005434551610	27669	Economy	3000.00
0005434551376	27669	Economy	3000.00
0005434551350	27669	Economy	3300.00
0005434551425	27669	Economy	3300.00
0005434551552	27669	Economy	3300.00
0005434551362	27669	Economy	3300.00
0005434551301	27669	Economy	3300.00
0005434551159	27669	Economy	3000.00
0005434551488	27669	Economy	3000.00
0005434551446	27669	Economy	3000.00
0005434551399	27669	Economy	3000.00
0005434558281	27669	Economy	3000.00
0005434551237	27669	Economy	3000.00
0005434551388	27669	Economy	3000.00
0005434551226	27669	Economy	3000.00
0005434558285	27669	Economy	3000.00
0005434551434	27669	Economy	3000.00
0005434551215	27669	Economy	3000.00
0005434551416	27669	Economy	3000.00
0005434551183	27669	Economy	3000.00
0005434551467	27669	Economy	3000.00
0005434551225	27669	Economy	3000.00
0005434551269	27669	Economy	3000.00
0005434551346	27669	Economy	3000.00
0005434551314	27669	Economy	3000.00
0005434551341	27669	Economy	3000.00
0005434558283	27669	Economy	3000.00
0005434551432	27669	Economy	3000.00
0005434551500	27669	Economy	3000.00
0005434551379	27669	Economy	3000.00
0005434551383	27669	Economy	3000.00
0005434551590	27669	Economy	3000.00
0005434551328	27669	Economy	3000.00
0005434551295	27669	Economy	3000.00
0005434551233	27669	Economy	3000.00
0005434551347	27669	Economy	3000.00
0005434551444	27669	Economy	3000.00
0005434551387	27669	Economy	3000.00
0005434551325	27669	Economy	3000.00
0005434551340	27669	Economy	3000.00
0005434558284	27669	Economy	3000.00
0005434551378	27669	Economy	3000.00
0005434551324	27669	Economy	3000.00
0005434551501	27669	Economy	3000.00
0005434551422	27669	Economy	3000.00
0005434551216	27669	Economy	3000.00
0005434551481	27669	Economy	3000.00
0005434551238	27669	Economy	3000.00
0005434551587	27669	Economy	3000.00
0005434551403	27669	Economy	3000.00
0005434551368	27669	Economy	3000.00
0005434551309	27669	Economy	3000.00
0005434551524	27669	Economy	3000.00
0005434551198	27669	Economy	3000.00
0005434558302	27669	Economy	3000.00
0005434551443	27669	Economy	3000.00
0005434551421	27669	Economy	3000.00
0005434551395	27669	Economy	3000.00
0005434551289	27669	Economy	3000.00
0005434551535	27669	Economy	3000.00
0005434558301	27669	Economy	3000.00
0005434551367	27669	Economy	3000.00
0005434551363	27669	Economy	3000.00
0005434551212	27669	Economy	3000.00
0005434551433	27669	Economy	3000.00
0005434558279	27669	Economy	3000.00
0005434551401	27669	Economy	3000.00
0005434551291	27669	Economy	3000.00
0005434551351	27669	Economy	3000.00
0005433459265	6122	Economy	11700.00
0005433459267	6122	Economy	11700.00
0005433459266	6122	Economy	11700.00
0005433459268	6122	Economy	11700.00
0005433459222	19340	Economy	11700.00
0005433459217	19340	Economy	11700.00
0005433459223	19340	Economy	11700.00
0005435254501	19340	Economy	11700.00
0005433459224	19340	Economy	11700.00
0005433459241	19340	Economy	11700.00
0005433459232	19340	Economy	11700.00
0005433459242	19340	Economy	11700.00
0005433459233	19340	Economy	11700.00
0005433459234	19340	Economy	11700.00
0005433459216	19340	Economy	11700.00
0005435254500	19340	Economy	11700.00
0005435682592	6730	Business	51100.00
0005435438126	6730	Business	51100.00
0005435437961	6730	Business	51100.00
0005435682586	6730	Business	51100.00
0005432136224	6730	Business	51100.00
0005432136222	6730	Business	51100.00
0005435682572	6730	Business	51100.00
0005435682588	6730	Business	51100.00
0005432533296	6730	Business	51100.00
0005435682578	6730	Business	51100.00
0005435682569	6730	Business	51100.00
0005435682605	6730	Business	51100.00
0005435630999	6730	Economy	17000.00
0005435682573	6730	Economy	17000.00
0005432136226	6730	Economy	17000.00
0005434828705	6730	Economy	17000.00
0005435682577	6730	Economy	17000.00
0005435217714	6730	Economy	17000.00
0005435682570	6730	Economy	17000.00
0005435682580	6730	Economy	17000.00
0005435661963	6730	Economy	17000.00
0005435661962	6730	Economy	17000.00
0005435438062	6730	Economy	18700.00
0005432136225	6730	Economy	18700.00
0005434828706	6730	Economy	18700.00
0005435682596	6730	Economy	18700.00
0005435682589	6730	Economy	17000.00
0005435682571	6730	Economy	17000.00
0005432533298	6730	Economy	17000.00
0005435438087	6730	Economy	17000.00
0005432533295	6730	Economy	17000.00
0005435682590	6730	Economy	17000.00
0005435438086	6730	Economy	17000.00
0005435682568	6730	Economy	17000.00
0005435682599	6730	Economy	17000.00
0005435437986	6730	Economy	17000.00
0005435438036	6730	Economy	17000.00
0005435437924	6730	Economy	17000.00
0005435682576	6730	Economy	17000.00
0005435630997	6730	Economy	17000.00
0005435630998	6730	Economy	17000.00
0005435438018	6730	Economy	17000.00
0005435220328	6730	Economy	17000.00
0005435438060	6730	Economy	17000.00
0005435661961	6730	Economy	17000.00
0005435438127	6730	Economy	17000.00
0005435438019	6730	Economy	17000.00
0005435682579	6730	Economy	17000.00
0005432533291	6730	Economy	17000.00
0005432533292	6730	Economy	17000.00
0005435682582	6730	Economy	17000.00
0005435682563	6730	Economy	17000.00
0005435682602	6730	Economy	17000.00
0005435682565	6730	Economy	17000.00
0005435682595	6730	Economy	17000.00
0005435682601	6730	Economy	17000.00
0005435682583	6730	Economy	17000.00
0005435682567	6730	Economy	17000.00
0005435682581	6730	Economy	17000.00
0005435682600	6730	Economy	17000.00
0005435682575	6730	Economy	17000.00
0005435682603	6730	Economy	17000.00
0005435437851	6730	Economy	17000.00
0005432533293	6730	Economy	17000.00
0005435682561	6730	Economy	17000.00
0005435438061	6730	Economy	17000.00
0005432136223	6730	Economy	17000.00
0005435682562	6730	Economy	17000.00
0005432533294	6730	Economy	17000.00
0005435682593	6730	Economy	17000.00
0005435682566	6730	Economy	17000.00
0005435682594	6730	Economy	17000.00
0005435682574	6730	Economy	17000.00
0005435682598	6730	Economy	17000.00
0005434828703	6730	Economy	17000.00
0005435437852	6730	Economy	17000.00
0005435438040	6730	Economy	17000.00
0005435719572	6730	Economy	17000.00
0005434828707	6730	Economy	17000.00
0005435682585	6730	Economy	17000.00
0005435682597	6730	Economy	17000.00
0005435682591	6730	Economy	17000.00
0005435220322	6730	Economy	17000.00
0005435682564	6730	Economy	17000.00
0005434828702	6730	Economy	17000.00
0005435437942	6730	Economy	17000.00
0005435682587	6730	Economy	17000.00
0005435682584	6730	Economy	17000.00
0005435682604	6730	Economy	17000.00
0005435217715	6730	Economy	17000.00
0005435438039	6730	Economy	17000.00
0005435682124	24580	Business	51100.00
0005435682024	24580	Business	51100.00
0005432305777	24580	Business	51100.00
0005435438196	24580	Business	51100.00
0005435682065	24580	Business	51100.00
0005435682279	24580	Business	51100.00
0005435438192	24580	Business	51100.00
0005435438207	24580	Business	51100.00
0005435682267	24580	Business	51100.00
0005435438201	24580	Business	51100.00
0005435681947	24580	Business	51100.00
0005435438209	24580	Economy	17000.00
0005435682211	24580	Economy	17000.00
0005435438199	24580	Economy	17000.00
0005435682458	24580	Economy	17000.00
0005435682336	24580	Economy	17000.00
0005435682104	24580	Economy	17000.00
0005435682240	24580	Economy	17000.00
0005435682150	24580	Economy	17000.00
0005435682236	24580	Economy	18700.00
0005435661936	24580	Economy	18700.00
0005435682155	24580	Economy	18700.00
0005435438194	24580	Economy	18700.00
0005435438189	24580	Economy	18700.00
0005435661939	24580	Economy	17000.00
0005435682046	24580	Economy	17000.00
0005435682188	24580	Economy	17000.00
0005432533326	24580	Economy	17000.00
0005435682165	24580	Economy	17000.00
0005435682158	24580	Economy	17000.00
0005432533324	24580	Economy	17000.00
0005435682253	24580	Economy	17000.00
0005435438193	24580	Economy	17000.00
0005435682232	24580	Economy	17000.00
0005435630982	24580	Economy	17000.00
0005435438203	24580	Economy	17000.00
0005435682268	24580	Economy	17000.00
0005435682321	24580	Economy	17000.00
0005435438191	24580	Economy	17000.00
0005435438208	24580	Economy	17000.00
0005435661937	24580	Economy	17000.00
0005435661934	24580	Economy	17000.00
0005435438197	24580	Economy	17000.00
0005435438204	24580	Economy	17000.00
0005435661933	24580	Economy	17000.00
0005435682397	24580	Economy	17000.00
0005435682350	24580	Economy	17000.00
0005434828730	24580	Economy	17000.00
0005434828728	24580	Economy	17000.00
0005435661931	24580	Economy	17000.00
0005435438188	24580	Economy	17000.00
0005435438206	24580	Economy	17000.00
0005435682191	24580	Economy	17000.00
0005435682254	24580	Economy	17000.00
0005435682139	24580	Economy	17000.00
0005435438200	24580	Economy	17000.00
0005435682406	24580	Economy	17000.00
0005435682456	24580	Economy	17000.00
0005435682357	24580	Economy	17000.00
0005435438190	24580	Economy	17000.00
0005435438210	24580	Economy	17000.00
0005435682337	24580	Economy	17000.00
0005434828729	24580	Economy	17000.00
0005435682225	24580	Economy	17000.00
0005435438198	24580	Economy	17000.00
0005435682066	24580	Economy	17000.00
0005435682109	24580	Economy	17000.00
0005435682277	24580	Economy	17000.00
0005435438202	24580	Economy	17000.00
0005435661940	24580	Economy	17000.00
0005435682315	24580	Economy	17000.00
0005435682152	24580	Economy	17000.00
0005432533325	24580	Economy	17000.00
0005435682199	24580	Economy	17000.00
0005435682269	24580	Economy	17000.00
0005435438205	24580	Economy	17000.00
0005435682398	24580	Economy	17000.00
0005435682173	24580	Economy	17000.00
0005435682457	24580	Economy	17000.00
0005435682338	24580	Economy	17000.00
0005432305776	24580	Economy	17000.00
0005435682149	24580	Economy	17000.00
0005435661932	24580	Economy	17000.00
0005435682271	24580	Economy	17000.00
0005435682278	24580	Economy	17000.00
0005435438195	24580	Economy	17000.00
0005435682023	24580	Economy	17000.00
0005435681950	24580	Economy	17000.00
0005435682243	24580	Economy	17000.00
0005435682114	24580	Economy	17000.00
0005435126805	11520	Business	26400.00
0005435126794	11520	Business	26400.00
0005435126774	11520	Business	26400.00
0005435126812	11520	Business	26400.00
0005435126800	11520	Business	26400.00
0005435126785	11520	Business	26400.00
0005435126788	11520	Business	26400.00
0005435106014	11520	Economy	8800.00
0005435126780	11520	Economy	8800.00
0005435126797	11520	Economy	9700.00
0005435126802	11520	Economy	9700.00
0005435106015	11520	Economy	8800.00
0005435126789	11520	Economy	8800.00
0005435126781	11520	Economy	8800.00
0005435126806	11520	Economy	8800.00
0005435126790	11520	Economy	8800.00
0005435126799	11520	Economy	8800.00
0005435106016	11520	Economy	8800.00
0005435126786	11520	Economy	8800.00
0005435126783	11520	Economy	8800.00
0005435126792	11520	Economy	8800.00
0005435126803	11520	Economy	8800.00
0005435126793	11520	Economy	8800.00
0005435126811	11520	Economy	8800.00
0005435126782	11520	Economy	8800.00
0005435126796	11520	Economy	8800.00
0005435126772	11520	Economy	8800.00
0005435126804	11520	Economy	8800.00
0005435126771	11520	Economy	8800.00
0005435126791	11520	Economy	8800.00
0005435126808	11520	Economy	8800.00
0005435126773	11520	Economy	8800.00
0005435126776	11520	Economy	8800.00
0005435126795	11520	Economy	8800.00
0005435126777	11520	Economy	8800.00
0005435126809	11520	Economy	8800.00
0005435126779	11520	Economy	8800.00
0005435126787	11520	Economy	8800.00
0005435126778	11520	Economy	8800.00
0005435126798	11520	Economy	8800.00
0005435126810	11520	Economy	8800.00
0005435126784	11520	Economy	8800.00
0005435126807	11520	Economy	8800.00
0005435126801	11520	Economy	8800.00
0005435126775	11520	Economy	8800.00
0005435126569	31893	Business	26400.00
0005435126568	31893	Business	26400.00
0005435126574	31893	Business	26400.00
0005435126362	31893	Economy	8800.00
0005435126545	31893	Economy	8800.00
0005435126505	31893	Economy	8800.00
0005435126375	31893	Economy	8800.00
0005435126463	31893	Economy	9700.00
0005435126474	31893	Economy	9700.00
0005435558115	31893	Economy	9700.00
0005435126672	31893	Economy	9700.00
0005435105990	31893	Economy	8800.00
0005435126485	31893	Economy	8800.00
0005435126310	31893	Economy	8800.00
0005435126466	31893	Economy	8800.00
0005435126521	31893	Economy	8800.00
0005435126573	31893	Economy	8800.00
0005435126636	31893	Economy	8800.00
0005435126508	31893	Economy	8800.00
0005435126335	31893	Economy	8800.00
0005435126436	31893	Economy	8800.00
0005435126475	31893	Economy	8800.00
0005435558117	31893	Economy	8800.00
0005435126320	31893	Economy	8800.00
0005435126493	31893	Economy	8800.00
0005435105987	31893	Economy	8800.00
0005435126635	31893	Economy	8800.00
0005435126342	31893	Economy	8800.00
0005435126435	31893	Economy	8800.00
0005435558116	31893	Economy	8800.00
0005435105989	31893	Economy	8800.00
0005435126311	31893	Economy	8800.00
0005435126590	31893	Economy	8800.00
0005435126589	31893	Economy	8800.00
0005435126538	31893	Economy	8800.00
0005435126566	31893	Economy	8800.00
0005435098566	31893	Economy	8800.00
0005435126506	31893	Economy	8800.00
0005435105986	31893	Economy	8800.00
0005435126673	31893	Economy	8800.00
0005433398594	13557	Business	36600.00
0005433398593	13557	Business	36600.00
0005433398596	13557	Business	36600.00
0005433398602	13557	Business	36600.00
0005433398601	13557	Business	36600.00
0005433398600	13557	Business	36600.00
0005433398581	13557	Business	36600.00
0005433398591	13557	Business	36600.00
0005433398608	13557	Economy	12200.00
0005433398598	13557	Economy	12200.00
0005435732371	13557	Economy	12200.00
0005433398609	13557	Economy	12200.00
0005433398587	13557	Economy	12200.00
0005433398619	13557	Economy	13400.00
0005433398616	13557	Economy	13400.00
0005433398584	13557	Economy	13400.00
0005433398582	13557	Economy	12200.00
0005433398590	13557	Economy	12200.00
0005433398577	13557	Economy	12200.00
0005433398604	13557	Economy	12200.00
0005433398592	13557	Economy	12200.00
0005433398603	13557	Economy	12200.00
0005433398586	13557	Economy	12200.00
0005433398595	13557	Economy	12200.00
0005433398578	13557	Economy	12200.00
0005433398571	13557	Economy	12200.00
0005433398614	13557	Economy	12200.00
0005433398599	13557	Economy	12200.00
0005433398597	13557	Economy	12200.00
0005433398579	13557	Economy	12200.00
0005433398617	13557	Economy	12200.00
0005433398575	13557	Economy	12200.00
0005435732403	13557	Economy	12200.00
0005433398615	13557	Economy	12200.00
0005433398572	13557	Economy	12200.00
0005433398613	13557	Economy	12200.00
0005433398605	13557	Economy	12200.00
0005433398583	13557	Economy	12200.00
0005433398589	13557	Economy	12200.00
0005433398580	13557	Economy	12200.00
0005435732344	13557	Economy	12200.00
0005433398618	13557	Economy	12200.00
0005433398620	13557	Economy	12200.00
0005435732372	13557	Economy	12200.00
0005435732419	13557	Economy	12200.00
0005435732385	13557	Economy	12200.00
0005433398607	13557	Economy	12200.00
0005435732317	13557	Economy	12200.00
0005433398573	13557	Economy	12200.00
0005433398606	13557	Economy	12200.00
0005433398585	13557	Economy	12200.00
0005435732337	13557	Economy	12200.00
0005435732439	13557	Economy	12200.00
0005433398621	13557	Economy	12200.00
0005433398576	13557	Economy	12200.00
0005433398574	13557	Economy	12200.00
0005433398610	13557	Economy	12200.00
0005435732338	13557	Economy	12200.00
0005433398612	13557	Economy	12200.00
0005433398611	13557	Economy	12200.00
0005433398588	13557	Economy	12200.00
0005435732485	19424	Business	36600.00
0005433398189	19424	Business	36600.00
0005433398221	19424	Business	36600.00
0005433398063	19424	Business	36600.00
0005433398161	19424	Business	36600.00
0005433398025	19424	Business	36600.00
0005433398153	19424	Business	36600.00
0005433398185	19424	Business	36600.00
0005435732490	19424	Business	36600.00
0005433398208	19424	Business	36600.00
0005433398320	19424	Economy	12200.00
0005433398186	19424	Economy	12200.00
0005435732482	19424	Economy	12200.00
0005433398171	19424	Economy	12200.00
0005433398047	19424	Economy	12200.00
0005433398240	19424	Economy	12200.00
0005433398018	19424	Economy	12200.00
0005433398261	19424	Economy	13400.00
0005433398113	19424	Economy	13400.00
0005433398152	19424	Economy	13400.00
0005433398154	19424	Economy	13400.00
0005433398200	19424	Economy	12200.00
0005433398108	19424	Economy	12200.00
0005433398105	19424	Economy	12200.00
0005433398292	19424	Economy	12200.00
0005433398228	19424	Economy	12200.00
0005435732483	19424	Economy	12200.00
0005433398250	19424	Economy	12200.00
0005433398088	19424	Economy	12200.00
0005435732486	19424	Economy	12200.00
0005433398220	19424	Economy	12200.00
0005433398081	19424	Economy	12200.00
0005433398181	19424	Economy	12200.00
0005435732492	19424	Economy	12200.00
0005433398132	19424	Economy	12200.00
0005433398036	19424	Economy	12200.00
0005435732484	19424	Economy	12200.00
0005433398162	19424	Economy	12200.00
0005435732489	19424	Economy	12200.00
0005433398321	19424	Economy	12200.00
0005433398098	19424	Economy	12200.00
0005433398011	19424	Economy	12200.00
0005433397793	19424	Economy	12200.00
0005433398133	19424	Economy	12200.00
0005433398342	19424	Economy	12200.00
0005433398046	19424	Economy	12200.00
0005433398231	19424	Economy	12200.00
0005435732488	19424	Economy	12200.00
0005433398064	19424	Economy	12200.00
0005433398160	19424	Economy	12200.00
0005433398117	19424	Economy	12200.00
0005433398306	19424	Economy	12200.00
0005433398176	19424	Economy	12200.00
0005433398257	19424	Economy	12200.00
0005433398232	19424	Economy	12200.00
0005432297307	19424	Economy	12200.00
0005435732487	19424	Economy	12200.00
0005433398229	19424	Economy	12200.00
0005433398262	19424	Economy	12200.00
0005433398170	19424	Economy	12200.00
0005433398258	19424	Economy	12200.00
0005435732491	19424	Economy	12200.00
0005432297306	19424	Economy	12200.00
0005433398013	19424	Economy	12200.00
0005433398296	19424	Economy	12200.00
0005433398019	19424	Economy	12200.00
0005433398045	19424	Economy	12200.00
0005433398319	19424	Economy	12200.00
0005435069197	13135	Business	11300.00
0005435925447	13135	Business	11300.00
0005435925460	13135	Business	11300.00
0005435069227	13135	Business	11300.00
0005435069179	13135	Business	11300.00
0005435925442	13135	Business	11300.00
0005435925453	13135	Business	11300.00
0005435069339	13135	Business	11300.00
0005435069115	13135	Business	11300.00
0005435925451	13135	Economy	3800.00
0005435925454	13135	Economy	3800.00
0005435069291	13135	Economy	3800.00
0005435069313	13135	Economy	3800.00
0005435069211	13135	Economy	3800.00
0005435925444	13135	Economy	3800.00
0005435069281	13135	Economy	3800.00
0005435068884	13135	Economy	3800.00
0005435069131	13135	Economy	4100.00
0005435069330	13135	Economy	4100.00
0005435069216	13135	Economy	4100.00
0005435069348	13135	Economy	3800.00
0005435069168	13135	Economy	3800.00
0005435069073	13135	Economy	3800.00
0005435069314	13135	Economy	3800.00
0005435068937	13135	Economy	3800.00
0005435069137	13135	Economy	3800.00
0005435925438	13135	Economy	3800.00
0005435925441	13135	Economy	3800.00
0005435925461	13135	Economy	3800.00
0005435925448	13135	Economy	3800.00
0005435925455	13135	Economy	3800.00
0005435069274	13135	Economy	3800.00
0005435069138	13135	Economy	3800.00
0005435925446	13135	Economy	3800.00
0005435925443	13135	Economy	3800.00
0005435068929	13135	Economy	3800.00
0005435069258	13135	Economy	3800.00
0005435069329	13135	Economy	3800.00
0005435068985	13135	Economy	3800.00
0005435069346	13135	Economy	3800.00
0005435925457	13135	Economy	3800.00
0005435069063	13135	Economy	3800.00
0005435068986	13135	Economy	3800.00
0005435069280	13135	Economy	3800.00
0005435069312	13135	Economy	3800.00
0005435925456	13135	Economy	3800.00
0005435925452	13135	Economy	3800.00
0005435069128	13135	Economy	3800.00
0005435069027	13135	Economy	3800.00
0005435925439	13135	Economy	3800.00
0005435925449	13135	Economy	3800.00
0005435069160	13135	Economy	3800.00
0005435069217	13135	Economy	3800.00
0005435069218	13135	Economy	3800.00
0005435069142	13135	Economy	3800.00
0005435069349	13135	Economy	3800.00
0005435069167	13135	Economy	3800.00
0005435069386	13135	Economy	3800.00
0005435925440	13135	Economy	3800.00
0005435069144	13135	Economy	3800.00
0005435925458	13135	Economy	3800.00
0005435069205	13135	Economy	3800.00
0005435069092	13135	Economy	3800.00
0005435925450	13135	Economy	3800.00
0005435069116	13135	Economy	3800.00
0005435069225	13135	Economy	3800.00
0005435069226	13135	Economy	3800.00
0005435069345	13135	Economy	3800.00
0005435069331	13135	Economy	3800.00
0005435069143	13135	Economy	3800.00
0005435925459	13135	Economy	3800.00
0005435925445	13135	Economy	3800.00
0005435069044	13135	Economy	3800.00
0005435068936	13135	Economy	3800.00
0005435069363	13135	Economy	3800.00
0005435069615	15491	Business	11300.00
0005435069631	15491	Business	11300.00
0005435069634	15491	Business	11300.00
0005435069632	15491	Business	11300.00
0005435925311	15491	Business	11300.00
0005435069590	15491	Business	11300.00
0005435069604	15491	Business	11300.00
0005435069642	15491	Business	11300.00
0005435069614	15491	Economy	3800.00
0005435069628	15491	Economy	3800.00
0005435069638	15491	Economy	3800.00
0005435069597	15491	Economy	3800.00
0005435069622	15491	Economy	3800.00
0005435069592	15491	Economy	3800.00
0005435069605	15491	Economy	3800.00
0005435069616	15491	Economy	3800.00
0005435069641	15491	Economy	3800.00
0005435069596	15491	Economy	4100.00
0005435069629	15491	Economy	4100.00
0005435069620	15491	Economy	4100.00
0005435069594	15491	Economy	4100.00
0005435069600	15491	Economy	3800.00
0005435925313	15491	Economy	3800.00
0005435069619	15491	Economy	3800.00
0005435925312	15491	Economy	3800.00
0005435069598	15491	Economy	3800.00
0005435069608	15491	Economy	3800.00
0005435069624	15491	Economy	3800.00
0005435925288	15491	Economy	3800.00
0005435069612	15491	Economy	3800.00
0005435925307	15491	Economy	3800.00
0005435069630	15491	Economy	3800.00
0005435069601	15491	Economy	3800.00
0005435069599	15491	Economy	3800.00
0005435069610	15491	Economy	3800.00
0005435069639	15491	Economy	3800.00
0005435069607	15491	Economy	3800.00
0005435069626	15491	Economy	3800.00
0005435925277	15491	Economy	3800.00
0005435069589	15491	Economy	3800.00
0005435069606	15491	Economy	3800.00
0005435069637	15491	Economy	3800.00
0005435069625	15491	Economy	3800.00
0005435069613	15491	Economy	3800.00
0005435069633	15491	Economy	3800.00
0005435069611	15491	Economy	3800.00
0005435069609	15491	Economy	3800.00
0005435925297	15491	Economy	3800.00
0005435069591	15491	Economy	3800.00
0005435925295	15491	Economy	3800.00
0005435069603	15491	Economy	3800.00
0005435069636	15491	Economy	3800.00
0005435925298	15491	Economy	3800.00
0005435069623	15491	Economy	3800.00
0005435069602	15491	Economy	3800.00
0005435069621	15491	Economy	3800.00
0005435069618	15491	Economy	3800.00
0005435069635	15491	Economy	3800.00
0005435069640	15491	Economy	3800.00
0005435069595	15491	Economy	3800.00
0005435069617	15491	Economy	3800.00
0005435925296	15491	Economy	3800.00
0005435069593	15491	Economy	3800.00
0005435925306	15491	Economy	3800.00
0005435069627	15491	Economy	3800.00
0005435808227	29487	Economy	27100.00
0005433407616	29487	Economy	27100.00
0005435808180	29487	Economy	27100.00
0005435808228	29487	Economy	24700.00
0005435808168	29487	Economy	24700.00
0005433407622	29487	Economy	24700.00
0005435808237	29487	Economy	24700.00
0005433407626	29487	Economy	24700.00
0005433407624	29487	Economy	24700.00
0005435808256	29487	Economy	24700.00
0005435808175	29487	Economy	24700.00
0005435808274	29487	Economy	24700.00
0005435808204	29487	Economy	24700.00
0005435808241	29487	Economy	24700.00
0005435808217	29487	Economy	24700.00
0005435808226	29487	Economy	24700.00
0005433407612	29487	Economy	24700.00
0005435808231	29487	Economy	24700.00
0005433407625	29487	Economy	24700.00
0005433407620	29487	Economy	24700.00
0005435808283	29487	Economy	24700.00
0005435808280	29487	Economy	24700.00
0005433407613	29487	Economy	24700.00
0005433407614	29487	Economy	24700.00
0005435808179	29487	Economy	24700.00
0005435808265	29487	Economy	24700.00
0005435808239	29487	Economy	24700.00
0005435808219	29487	Economy	24700.00
0005435808187	29487	Economy	24700.00
0005435808242	29487	Economy	24700.00
0005433407621	29487	Economy	24700.00
0005435808232	29487	Economy	24700.00
0005435808244	29487	Economy	24700.00
0005435808220	29487	Economy	24700.00
0005433407619	29487	Economy	24700.00
0005433407615	29487	Economy	24700.00
0005433407617	29487	Economy	24700.00
0005433407618	29487	Economy	24700.00
0005433407623	29487	Economy	24700.00
0005435808200	29487	Economy	24700.00
0005434756554	10691	Business	61300.00
0005434756504	10691	Business	61300.00
0005434215058	10691	Business	61300.00
0005434756483	10691	Business	61300.00
0005434215046	10691	Business	61300.00
0005434756521	10691	Business	61300.00
0005434756581	10691	Business	61300.00
0005434215067	10691	Business	61300.00
0005434756451	10691	Business	61300.00
0005434756484	10691	Business	61300.00
0005434215036	10691	Business	61300.00
0005434756384	10691	Business	61300.00
0005434756450	10691	Economy	20400.00
0005434756452	10691	Economy	20400.00
0005434756465	10691	Economy	20400.00
0005434756502	10691	Economy	20400.00
0005434756389	10691	Economy	20400.00
0005434756492	10691	Economy	20400.00
0005434215069	10691	Economy	20400.00
0005434756539	10691	Economy	20400.00
0005434215074	10691	Economy	20400.00
0005434215048	10691	Economy	22500.00
0005434756482	10691	Economy	22500.00
0005434215065	10691	Economy	22500.00
0005434756553	10691	Economy	22500.00
0005434215049	10691	Economy	22500.00
0005434756390	10691	Economy	20400.00
0005434756413	10691	Economy	20400.00
0005434215039	10691	Economy	20400.00
0005434215030	10691	Economy	20400.00
0005434756415	10691	Economy	20400.00
0005434215044	10691	Economy	20400.00
0005434215031	10691	Economy	20400.00
0005434756445	10691	Economy	20400.00
0005434756366	10691	Economy	20400.00
0005434215060	10691	Economy	20400.00
0005434215054	10691	Economy	20400.00
0005434215055	10691	Economy	20400.00
0005434756242	10691	Economy	20400.00
0005434756515	10691	Economy	20400.00
0005434215059	10691	Economy	20400.00
0005434756493	10691	Economy	20400.00
0005434215076	10691	Economy	20400.00
0005434215061	10691	Economy	20400.00
0005434756463	10691	Economy	20400.00
0005434756440	10691	Economy	20400.00
0005434756556	10691	Economy	20400.00
0005434215047	10691	Economy	20400.00
0005434215041	10691	Economy	20400.00
0005434215050	10691	Economy	20400.00
0005434756503	10691	Economy	20400.00
0005434756449	10691	Economy	20400.00
0005434215053	10691	Economy	20400.00
0005434215063	10691	Economy	20400.00
0005434215032	10691	Economy	20400.00
0005434756466	10691	Economy	20400.00
0005434756441	10691	Economy	20400.00
0005434756516	10691	Economy	20400.00
0005434215071	10691	Economy	20400.00
0005434215034	10691	Economy	20400.00
0005434756462	10691	Economy	20400.00
0005434215033	10691	Economy	20400.00
0005434215056	10691	Economy	20400.00
0005434215057	10691	Economy	20400.00
0005434215073	10691	Economy	20400.00
0005434756444	10691	Economy	20400.00
0005434215072	10691	Economy	20400.00
0005434756498	10691	Economy	20400.00
0005434215042	10691	Economy	20400.00
0005434756432	10691	Economy	20400.00
0005434215068	10691	Economy	20400.00
0005434215045	10691	Economy	20400.00
0005434215075	10691	Economy	20400.00
0005434215062	10691	Economy	20400.00
0005434756560	10691	Economy	20400.00
0005434756477	10691	Economy	20400.00
0005434215070	10691	Economy	20400.00
0005434756494	10691	Economy	20400.00
0005434756550	10691	Economy	20400.00
0005434756520	10691	Economy	20400.00
0005434215052	10691	Economy	20400.00
0005434756555	10691	Economy	20400.00
0005434215066	10691	Economy	20400.00
0005434756431	10691	Economy	20400.00
0005434215035	10691	Economy	20400.00
0005434215038	10691	Economy	20400.00
0005434756443	10691	Economy	20400.00
0005434215077	10691	Economy	20400.00
0005434215043	10691	Economy	20400.00
0005434215064	10691	Economy	20400.00
0005434215037	10691	Economy	20400.00
0005434756517	10691	Economy	20400.00
0005434756549	10691	Economy	20400.00
0005434215051	10691	Economy	20400.00
0005434215040	10691	Economy	20400.00
0005434756863	28691	Business	61300.00
0005434756867	28691	Business	61300.00
0005434214760	28691	Business	61300.00
0005434214346	28691	Business	61300.00
0005434214577	28691	Business	61300.00
0005434756845	28691	Business	61300.00
0005434756840	28691	Business	61300.00
0005434756880	28691	Business	61300.00
0005434756847	28691	Business	61300.00
0005434756879	28691	Business	61300.00
0005434214782	28691	Business	61300.00
0005434214615	28691	Business	61300.00
0005434214635	28691	Economy	20400.00
0005434214412	28691	Economy	20400.00
0005434214781	28691	Economy	20400.00
0005434214498	28691	Economy	20400.00
0005434214575	28691	Economy	20400.00
0005434756843	28691	Economy	20400.00
0005434214619	28691	Economy	20400.00
0005434756854	28691	Economy	20400.00
0005434756859	28691	Economy	20400.00
0005434756860	28691	Economy	20400.00
0005434214757	28691	Economy	22500.00
0005434214611	28691	Economy	22500.00
0005434214614	28691	Economy	22500.00
0005434756872	28691	Economy	22500.00
0005434214338	28691	Economy	22500.00
0005434214490	28691	Economy	20400.00
0005434756850	28691	Economy	20400.00
0005434214509	28691	Economy	20400.00
0005434214583	28691	Economy	20400.00
0005434756851	28691	Economy	20400.00
0005434214636	28691	Economy	20400.00
0005434756858	28691	Economy	20400.00
0005434756877	28691	Economy	20400.00
0005434214463	28691	Economy	20400.00
0005434214756	28691	Economy	20400.00
0005434214623	28691	Economy	20400.00
0005434214527	28691	Economy	20400.00
0005434214526	28691	Economy	20400.00
0005434756868	28691	Economy	20400.00
0005434214567	28691	Economy	20400.00
0005434214538	28691	Economy	20400.00
0005434214783	28691	Economy	20400.00
0005434756853	28691	Economy	20400.00
0005434756871	28691	Economy	20400.00
0005434756876	28691	Economy	20400.00
0005434214447	28691	Economy	20400.00
0005434756856	28691	Economy	20400.00
0005434756874	28691	Economy	20400.00
0005434214468	28691	Economy	20400.00
0005434214638	28691	Economy	20400.00
0005434214568	28691	Economy	20400.00
0005434214438	28691	Economy	20400.00
0005434214616	28691	Economy	20400.00
0005434214516	28691	Economy	20400.00
0005434214576	28691	Economy	20400.00
0005434214411	28691	Economy	20400.00
0005434756870	28691	Economy	20400.00
0005434756869	28691	Economy	20400.00
0005434214758	28691	Economy	20400.00
0005434756849	28691	Economy	20400.00
0005434214464	28691	Economy	20400.00
0005434214564	28691	Economy	20400.00
0005434756864	28691	Economy	20400.00
0005434214711	28691	Economy	20400.00
0005434756873	28691	Economy	20400.00
0005434214649	28691	Economy	20400.00
0005434214466	28691	Economy	20400.00
0005434756841	28691	Economy	20400.00
0005434214755	28691	Economy	20400.00
0005434756865	28691	Economy	20400.00
0005434214524	28691	Economy	20400.00
0005434756855	28691	Economy	20400.00
0005434756842	28691	Economy	20400.00
0005434756862	28691	Economy	20400.00
0005434214618	28691	Economy	20400.00
0005434214440	28691	Economy	20400.00
0005434756861	28691	Economy	20400.00
0005434756852	28691	Economy	20400.00
0005434214363	28691	Economy	20400.00
0005434214446	28691	Economy	20400.00
0005434756848	28691	Economy	20400.00
0005434756878	28691	Economy	20400.00
0005434756846	28691	Economy	20400.00
0005434214685	28691	Economy	20400.00
0005434214759	28691	Economy	20400.00
0005434214439	28691	Economy	20400.00
0005434214574	28691	Economy	20400.00
0005434214569	28691	Economy	20400.00
0005434214508	28691	Economy	20400.00
0005434756875	28691	Economy	20400.00
0005434756844	28691	Economy	20400.00
0005434214542	28691	Economy	20400.00
0005434756866	28691	Economy	20400.00
0005434756857	28691	Economy	20400.00
0005434214525	28691	Economy	20400.00
0005432125537	5434	Business	29500.00
0005435040502	5434	Business	29500.00
0005435040454	5434	Business	29500.00
0005435007288	5434	Business	29500.00
0005434229489	5434	Business	29500.00
0005435007302	5434	Business	29500.00
0005434229359	5434	Business	29500.00
0005435040487	5434	Business	29500.00
0005435007299	5434	Business	29500.00
0005435040478	5434	Business	29500.00
0005435040494	5434	Business	29500.00
0005435040467	5434	Business	29500.00
0005435040500	5434	Economy	9800.00
0005435007293	5434	Economy	9800.00
0005434229560	5434	Economy	9800.00
0005435040490	5434	Economy	9800.00
0005435040459	5434	Economy	9800.00
0005434229404	5434	Economy	9800.00
0005435040516	5434	Economy	9800.00
0005435007292	5434	Economy	9800.00
0005435040463	5434	Economy	9800.00
0005435040465	5434	Economy	9800.00
0005435007279	5434	Economy	9800.00
0005435040482	5434	Economy	9800.00
0005435040486	5434	Economy	9800.00
0005435040489	5434	Economy	9800.00
0005435007301	5434	Economy	9800.00
0005435040473	5434	Economy	9800.00
0005434229379	5434	Economy	9800.00
0005435007295	5434	Economy	9800.00
0005435007280	5434	Economy	9800.00
0005435007285	5434	Economy	9800.00
0005434229393	5434	Economy	9800.00
0005435040501	5434	Economy	9800.00
0005435040488	5434	Economy	9800.00
0005435040466	5434	Economy	9800.00
0005435040498	5434	Economy	9800.00
0005435040462	5434	Economy	9800.00
0005434229340	5434	Economy	9800.00
0005435040475	5434	Economy	9800.00
0005435040477	5434	Economy	9800.00
0005434229341	5434	Economy	9800.00
0005434229363	5434	Economy	9800.00
0005434229360	5434	Economy	9800.00
0005435007281	5434	Economy	9800.00
0005434229342	5434	Economy	9800.00
0005435007296	5434	Economy	9800.00
0005435040497	5434	Economy	9800.00
0005432125536	5434	Economy	9800.00
0005435007298	5434	Economy	9800.00
0005434229364	5434	Economy	9800.00
0005432125532	5434	Economy	9800.00
0005435040464	5434	Economy	10800.00
0005435007297	5434	Economy	10800.00
0005434229559	5434	Economy	10800.00
0005435040514	5434	Economy	10800.00
0005435040456	5434	Economy	10800.00
0005435040468	5434	Economy	10800.00
0005435040515	5434	Economy	9800.00
0005435040476	5434	Economy	9800.00
0005434229394	5434	Economy	9800.00
0005435040480	5434	Economy	9800.00
0005434229405	5434	Economy	9800.00
0005435040460	5434	Economy	9800.00
0005435040481	5434	Economy	9800.00
0005435007300	5434	Economy	9800.00
0005435007283	5434	Economy	9800.00
0005435040470	5434	Economy	9800.00
0005435040511	5434	Economy	9800.00
0005435007286	5434	Economy	9800.00
0005435040455	5434	Economy	9800.00
0005435040469	5434	Economy	9800.00
0005434229423	5434	Economy	9800.00
0005432125538	5434	Economy	9800.00
0005434229448	5434	Economy	9800.00
0005435040471	5434	Economy	9800.00
0005435007287	5434	Economy	9800.00
0005434229447	5434	Economy	9800.00
0005435040491	5434	Economy	9800.00
0005435007291	5434	Economy	9800.00
0005434229441	5434	Economy	9800.00
0005435007303	5434	Economy	9800.00
0005434229249	5434	Economy	9800.00
0005432125531	5434	Economy	9800.00
0005434229422	5434	Economy	9800.00
0005435040495	5434	Economy	9800.00
0005435040479	5434	Economy	9800.00
0005435040452	5434	Economy	9800.00
0005435040474	5434	Economy	9800.00
0005435040461	5434	Economy	9800.00
0005434229380	5434	Economy	9800.00
0005435040512	5434	Economy	9800.00
0005435007282	5434	Economy	9800.00
0005435040505	5434	Economy	9800.00
0005435040451	5434	Economy	9800.00
0005435007290	5434	Economy	9800.00
0005434229362	5434	Economy	9800.00
0005435040458	5434	Economy	9800.00
0005434229250	5434	Economy	9800.00
0005435040506	5434	Economy	9800.00
0005435007278	5434	Economy	9800.00
0005432125535	5434	Economy	9800.00
0005435040493	5434	Economy	9800.00
0005435040485	5434	Economy	9800.00
0005434229454	5434	Economy	9800.00
0005435007294	5434	Economy	9800.00
0005435040492	5434	Economy	9800.00
0005434229496	5434	Economy	9800.00
0005435040508	5434	Economy	9800.00
0005434229453	5434	Economy	9800.00
0005435040472	5434	Economy	9800.00
0005435040509	5434	Economy	9800.00
0005435040513	5434	Economy	9800.00
0005434229361	5434	Economy	9800.00
0005435040499	5434	Economy	9800.00
0005434229397	5434	Economy	9800.00
0005435040483	5434	Economy	9800.00
0005435040507	5434	Economy	9800.00
0005435040504	5434	Economy	9800.00
0005435040453	5434	Economy	9800.00
0005434229479	5434	Economy	9800.00
0005435040503	5434	Economy	9800.00
0005435040484	5434	Economy	9800.00
0005435040457	5434	Economy	9800.00
0005432125533	5434	Economy	9800.00
0005435040510	5434	Economy	9800.00
0005435007284	5434	Economy	9800.00
0005435007289	5434	Economy	9800.00
0005435040496	5434	Economy	9800.00
0005432125534	5434	Economy	9800.00
0005435040074	12984	Business	29500.00
0005435039942	12984	Business	29500.00
0005435042849	12984	Business	29500.00
0005435040110	12984	Business	29500.00
0005435040156	12984	Business	29500.00
0005435007031	12984	Business	29500.00
0005435042856	12984	Business	29500.00
0005435043289	12984	Business	29500.00
0005435039815	12984	Business	29500.00
0005435039822	12984	Business	29500.00
0005435042850	12984	Business	29500.00
0005435040052	12984	Business	29500.00
0005435039987	12984	Economy	9800.00
0005435039996	12984	Economy	9800.00
0005432304441	12984	Economy	9800.00
0005435039821	12984	Economy	9800.00
0005435042861	12984	Economy	9800.00
0005435039960	12984	Economy	9800.00
0005435007097	12984	Economy	9800.00
0005435042871	12984	Economy	9800.00
0005434229625	12984	Economy	9800.00
0005435042870	12984	Economy	9800.00
0005435039941	12984	Economy	9800.00
0005435040115	12984	Economy	9800.00
0005434229627	12984	Economy	9800.00
0005435042851	12984	Economy	9800.00
0005434229614	12984	Economy	9800.00
0005435039887	12984	Economy	9800.00
0005435039813	12984	Economy	9800.00
0005435042863	12984	Economy	9800.00
0005435007127	12984	Economy	9800.00
0005435040111	12984	Economy	9800.00
0005435040088	12984	Economy	9800.00
0005435039832	12984	Economy	9800.00
0005435040286	12984	Economy	9800.00
0005435039943	12984	Economy	9800.00
0005435040061	12984	Economy	9800.00
0005435040047	12984	Economy	9800.00
0005435039748	12984	Economy	9800.00
0005435007101	12984	Economy	9800.00
0005435039761	12984	Economy	9800.00
0005435039809	12984	Economy	9800.00
0005435007139	12984	Economy	9800.00
0005435040102	12984	Economy	9800.00
0005435007117	12984	Economy	9800.00
0005435040006	12984	Economy	9800.00
0005434229634	12984	Economy	9800.00
0005435007113	12984	Economy	9800.00
0005434229636	12984	Economy	10800.00
0005435039749	12984	Economy	9800.00
0005435040025	12984	Economy	10800.00
0005432304442	12984	Economy	10800.00
0005435039814	12984	Economy	10800.00
0005435039963	12984	Economy	10800.00
0005435040155	12984	Economy	9800.00
0005435042865	12984	Economy	9800.00
0005434229616	12984	Economy	9800.00
0005434229637	12984	Economy	9800.00
0005435007103	12984	Economy	9800.00
0005434229635	12984	Economy	9800.00
0005435007183	12984	Economy	9800.00
0005434229623	12984	Economy	9800.00
0005434229628	12984	Economy	9800.00
0005434229620	12984	Economy	9800.00
0005435039867	12984	Economy	9800.00
0005435007114	12984	Economy	9800.00
0005434229622	12984	Economy	9800.00
0005435039795	12984	Economy	9800.00
0005435040285	12984	Economy	9800.00
0005434229630	12984	Economy	9800.00
0005435039796	12984	Economy	9800.00
0005435039921	12984	Economy	9800.00
0005435039830	12984	Economy	9800.00
0005435039770	12984	Economy	9800.00
0005434229638	12984	Economy	9800.00
0005435039947	12984	Economy	9800.00
0005435042862	12984	Economy	9800.00
0005435042859	12984	Economy	9800.00
0005435039823	12984	Economy	9800.00
0005434229613	12984	Economy	9800.00
0005434229626	12984	Economy	9800.00
0005435039961	12984	Economy	9800.00
0005434229619	12984	Economy	9800.00
0005435039890	12984	Economy	9800.00
0005435040046	12984	Economy	9800.00
0005435040157	12984	Economy	9800.00
0005435039706	12984	Economy	9800.00
0005434229629	12984	Economy	9800.00
0005435039886	12984	Economy	9800.00
0005434229631	12984	Economy	9800.00
0005435039880	12984	Economy	9800.00
0005435042857	12984	Economy	9800.00
0005435007065	12984	Economy	9800.00
0005434229617	12984	Economy	9800.00
0005435039962	12984	Economy	9800.00
0005432304443	12984	Economy	9800.00
0005435007146	12984	Economy	9800.00
0005435007147	12984	Economy	9800.00
0005435040140	12984	Economy	9800.00
0005432304440	12984	Economy	9800.00
0005435040112	12984	Economy	9800.00
0005434229615	12984	Economy	9800.00
0005435040019	12984	Economy	9800.00
0005435039754	12984	Economy	9800.00
0005435007116	12984	Economy	9800.00
0005435042869	12984	Economy	9800.00
0005435040075	12984	Economy	9800.00
0005434229632	12984	Economy	9800.00
0005434229633	12984	Economy	9800.00
0005435039866	12984	Economy	9800.00
0005435040020	12984	Economy	9800.00
0005434229618	12984	Economy	9800.00
0005434229621	12984	Economy	9800.00
0005435007134	12984	Economy	9800.00
0005435039910	12984	Economy	9800.00
0005434229624	12984	Economy	9800.00
0005435039881	12984	Economy	9800.00
0005435040048	12984	Economy	9800.00
0005435902726	14876	Business	52900.00
0005435902797	14876	Business	52900.00
0005434426925	14876	Business	52900.00
0005434411822	14876	Business	52900.00
0005434426923	14876	Business	52900.00
0005434426908	14876	Business	52900.00
0005435902652	14876	Business	52900.00
0005434426924	14876	Business	52900.00
0005434426912	14876	Economy	17600.00
0005435902748	14876	Economy	17600.00
0005435902680	14876	Economy	17600.00
0005434426920	14876	Economy	17600.00
0005434426902	14876	Economy	17600.00
0005434426914	14876	Economy	17600.00
0005434426918	14876	Economy	17600.00
0005434426900	14876	Economy	17600.00
0005435902653	14876	Economy	19400.00
0005434426915	14876	Economy	17600.00
0005434426913	14876	Economy	17600.00
0005432188642	14876	Economy	17600.00
0005434426922	14876	Economy	17600.00
0005435902764	14876	Economy	17600.00
0005434426903	14876	Economy	17600.00
0005434426919	14876	Economy	17600.00
0005435902679	14876	Economy	17600.00
0005434411824	14876	Economy	17600.00
0005434426904	14876	Economy	17600.00
0005434411825	14876	Economy	17600.00
0005432188640	14876	Economy	17600.00
0005434426901	14876	Economy	17600.00
0005434426911	14876	Economy	17600.00
0005434411823	14876	Economy	17600.00
0005434426927	14876	Economy	17600.00
0005434426905	14876	Economy	17600.00
0005434426928	14876	Economy	17600.00
0005434426906	14876	Economy	17600.00
0005434426921	14876	Economy	17600.00
0005435902697	14876	Economy	17600.00
0005434426910	14876	Economy	17600.00
0005432188643	14876	Economy	17600.00
0005435554188	14876	Economy	17600.00
0005435902798	14876	Economy	17600.00
0005435902678	14876	Economy	17600.00
0005434411821	14876	Economy	17600.00
0005435902686	14876	Economy	17600.00
0005434426907	14876	Economy	17600.00
0005434426916	14876	Economy	17600.00
0005434426909	14876	Economy	17600.00
0005435554182	14876	Economy	17600.00
0005435902773	14876	Economy	17600.00
0005434426926	14876	Economy	17600.00
0005435902779	14876	Economy	17600.00
0005435902687	14876	Economy	17600.00
0005432188641	14876	Economy	17600.00
0005434426917	14876	Economy	17600.00
0005435902750	14876	Economy	17600.00
0005435902701	14876	Economy	17600.00
0005434411776	20192	Business	52900.00
0005434426686	20192	Business	52900.00
0005434426604	20192	Business	52900.00
0005435902909	20192	Business	52900.00
0005435902912	20192	Business	52900.00
0005435902899	20192	Business	52900.00
0005435902910	20192	Business	52900.00
0005435902903	20192	Economy	17600.00
0005434411782	20192	Economy	17600.00
0005434426679	20192	Economy	17600.00
0005435554246	20192	Economy	17600.00
0005434426619	20192	Economy	17600.00
0005435902906	20192	Economy	19400.00
0005434426715	20192	Economy	19400.00
0005432059526	20192	Economy	19400.00
0005434426685	20192	Economy	19400.00
0005434426585	20192	Economy	19400.00
0005434426761	20192	Economy	17600.00
0005435902913	20192	Economy	17600.00
0005435902895	20192	Economy	17600.00
0005435902896	20192	Economy	17600.00
0005434426632	20192	Economy	17600.00
0005434426606	20192	Economy	17600.00
0005434411768	20192	Economy	17600.00
0005435902898	20192	Economy	17600.00
0005434426737	20192	Economy	17600.00
0005434426807	20192	Economy	17600.00
0005434426620	20192	Economy	17600.00
0005435554242	20192	Economy	17600.00
0005432059527	20192	Economy	17600.00
0005434426621	20192	Economy	17600.00
0005434426733	20192	Economy	17600.00
0005434426706	20192	Economy	17600.00
0005435902897	20192	Economy	17600.00
0005434426615	20192	Economy	17600.00
0005435902911	20192	Economy	17600.00
0005434426528	20192	Economy	17600.00
0005435554244	20192	Economy	17600.00
0005435902904	20192	Economy	17600.00
0005434426633	20192	Economy	17600.00
0005435902905	20192	Economy	17600.00
0005434426738	20192	Economy	17600.00
0005435902902	20192	Economy	17600.00
0005434426663	20192	Economy	17600.00
0005435554245	20192	Economy	17600.00
0005434426586	20192	Economy	17600.00
0005434426710	20192	Economy	17600.00
0005434426793	20192	Economy	17600.00
0005435902908	20192	Economy	17600.00
0005434426734	20192	Economy	17600.00
0005434411796	20192	Economy	17600.00
0005435902900	20192	Economy	17600.00
0005434426808	20192	Economy	17600.00
0005435902907	20192	Economy	17600.00
0005435902901	20192	Economy	17600.00
0005434426595	20192	Economy	17600.00
0005434426649	20192	Economy	17600.00
0005434426739	20192	Economy	17600.00
0005435554241	20192	Economy	17600.00
0005434426631	20192	Economy	17600.00
0005435554243	20192	Economy	17600.00
0005434270210	26509	Business	18500.00
0005432300324	26509	Business	18500.00
0005433434685	26509	Business	18500.00
0005432300325	26509	Business	18500.00
0005433434804	26509	Business	18500.00
0005435982791	26509	Business	18500.00
0005435982784	26509	Business	18500.00
0005433434808	26509	Business	18500.00
0005432300323	26509	Business	18500.00
0005435982769	26509	Business	18500.00
0005433434734	26509	Business	18500.00
0005435982790	26509	Economy	6200.00
0005433434684	26509	Economy	6200.00
0005433434640	26509	Economy	6200.00
0005435982798	26509	Economy	6200.00
0005433434754	26509	Economy	6200.00
0005435982781	26509	Economy	6200.00
0005435982779	26509	Economy	6200.00
0005435982788	26509	Economy	6200.00
0005435982782	26509	Economy	6200.00
0005433434733	26509	Economy	6800.00
0005435982785	26509	Economy	6800.00
0005435982786	26509	Economy	6800.00
0005435982808	26509	Economy	6800.00
0005435982797	26509	Economy	6800.00
0005435982767	26509	Economy	6200.00
0005435982787	26509	Economy	6200.00
0005435982800	26509	Economy	6200.00
0005435982774	26509	Economy	6200.00
0005435982768	26509	Economy	6200.00
0005435982806	26509	Economy	6200.00
0005433434802	26509	Economy	6200.00
0005432300326	26509	Economy	6200.00
0005433434659	26509	Economy	6200.00
0005435982783	26509	Economy	6200.00
0005433434691	26509	Economy	6200.00
0005433434793	26509	Economy	6200.00
0005433434660	26509	Economy	6200.00
0005435982789	26509	Economy	6200.00
0005433434764	26509	Economy	6200.00
0005433434803	26509	Economy	6200.00
0005435982778	26509	Economy	6200.00
0005432300322	26509	Economy	6200.00
0005433434807	26509	Economy	6200.00
0005435982780	26509	Economy	6200.00
0005435982805	26509	Economy	6200.00
0005435982807	26509	Economy	6200.00
0005434270211	26509	Economy	6200.00
0005435982771	26509	Economy	6200.00
0005435982795	26509	Economy	6200.00
0005433434747	26509	Economy	6200.00
0005435982804	26509	Economy	6200.00
0005433434755	26509	Economy	6200.00
0005435982776	26509	Economy	6200.00
0005433434714	26509	Economy	6200.00
0005433434757	26509	Economy	6200.00
0005435982802	26509	Economy	6200.00
0005433434784	26509	Economy	6200.00
0005435982772	26509	Economy	6200.00
0005434273079	26509	Economy	6200.00
0005435982793	26509	Economy	6200.00
0005434273078	26509	Economy	6200.00
0005433434655	26509	Economy	6200.00
0005435982794	26509	Economy	6200.00
0005435982809	26509	Economy	6200.00
0005435982792	26509	Economy	6200.00
0005435982770	26509	Economy	6200.00
0005433434641	26509	Economy	6200.00
0005433434656	26509	Economy	6200.00
0005435982799	26509	Economy	6200.00
0005435982796	26509	Economy	6200.00
0005435982777	26509	Economy	6200.00
0005435982811	26509	Economy	6200.00
0005435982803	26509	Economy	6200.00
0005435982810	26509	Economy	6200.00
0005433434614	26509	Economy	6200.00
0005432300321	26509	Economy	6200.00
0005433434644	26509	Economy	6200.00
0005435982775	26509	Economy	6200.00
0005435982773	26509	Economy	6200.00
0005435982801	26509	Economy	6200.00
0005433434739	26509	Economy	6200.00
0005433434758	26509	Economy	6200.00
0005433434683	26509	Economy	6200.00
0005433434738	26509	Economy	6200.00
0005432051163	26730	Business	18500.00
0005435982378	26730	Business	18500.00
0005435982088	26730	Business	18500.00
0005433435012	26730	Business	18500.00
0005435982512	26730	Business	18500.00
0005435982482	26730	Business	18500.00
0005435982471	26730	Business	18500.00
0005435982407	26730	Business	18500.00
0005434269126	26730	Business	18500.00
0005435982381	26730	Business	18500.00
0005435982279	26730	Business	18500.00
0005435982393	26730	Economy	6200.00
0005435982358	26730	Economy	6200.00
0005433435008	26730	Economy	6200.00
0005433435005	26730	Economy	6200.00
0005433435011	26730	Economy	6200.00
0005433434998	26730	Economy	6200.00
0005432051162	26730	Economy	6200.00
0005435982242	26730	Economy	6200.00
0005433434990	26730	Economy	6200.00
0005435982278	26730	Economy	6800.00
0005432051164	26730	Economy	6800.00
0005435982526	26730	Economy	6800.00
0005435982515	26730	Economy	6800.00
0005433435004	26730	Economy	6800.00
0005435982331	26730	Economy	6200.00
0005433435014	26730	Economy	6200.00
0005433434999	26730	Economy	6200.00
0005435982628	26730	Economy	6200.00
0005435982472	26730	Economy	6200.00
0005435982356	26730	Economy	6200.00
0005433435003	26730	Economy	6200.00
0005435982321	26730	Economy	6200.00
0005435982410	26730	Economy	6200.00
0005435982359	26730	Economy	6200.00
0005433434991	26730	Economy	6200.00
0005433434996	26730	Economy	6200.00
0005435982411	26730	Economy	6200.00
0005434270230	26730	Economy	6200.00
0005433434997	26730	Economy	6200.00
0005433435000	26730	Economy	6200.00
0005434271336	26730	Economy	6200.00
0005433435013	26730	Economy	6200.00
0005435982383	26730	Economy	6200.00
0005435982089	26730	Economy	6200.00
0005433435009	26730	Economy	6200.00
0005433435007	26730	Economy	6200.00
0005435982346	26730	Economy	6200.00
0005435982384	26730	Economy	6200.00
0005435982149	26730	Economy	6200.00
0005435982416	26730	Economy	6200.00
0005435982377	26730	Economy	6200.00
0005435982379	26730	Economy	6200.00
0005435982418	26730	Economy	6200.00
0005433434993	26730	Economy	6200.00
0005433435006	26730	Economy	6200.00
0005435982483	26730	Economy	6200.00
0005433434988	26730	Economy	6200.00
0005433435010	26730	Economy	6200.00
0005433434992	26730	Economy	6200.00
0005435982575	26730	Economy	6200.00
0005433435002	26730	Economy	6200.00
0005433434987	26730	Economy	6200.00
0005433434989	26730	Economy	6200.00
0005435982376	26730	Economy	6200.00
0005435982586	26730	Economy	6200.00
0005433435001	26730	Economy	6200.00
0005434271335	26730	Economy	6200.00
0005435982243	26730	Economy	6200.00
0005434269127	26730	Economy	6200.00
0005435982426	26730	Economy	6200.00
0005435982480	26730	Economy	6200.00
0005433434994	26730	Economy	6200.00
0005435982223	26730	Economy	6200.00
0005433434986	26730	Economy	6200.00
0005435982470	26730	Economy	6200.00
0005435982528	26730	Economy	6200.00
0005433434995	26730	Economy	6200.00
0005434270229	26730	Economy	6200.00
0005435982406	26730	Economy	6200.00
0005435982357	26730	Economy	6200.00
0005434269128	26730	Economy	6200.00
0005435982087	26730	Economy	6200.00
0005433687729	19509	Economy	21000.00
0005433687722	19509	Economy	21000.00
0005433686655	19509	Economy	21000.00
0005433685539	19509	Economy	21000.00
0005433687731	19509	Economy	19100.00
0005433687730	19509	Economy	19100.00
0005433685550	19509	Economy	19100.00
0005433686658	19509	Economy	19100.00
0005433687726	19509	Economy	19100.00
0005433685551	19509	Economy	19100.00
0005433686648	19509	Economy	19100.00
0005433687728	19509	Economy	19100.00
0005433686662	19509	Economy	19100.00
0005433685538	19509	Economy	19100.00
0005433686651	19509	Economy	19100.00
0005433686660	19509	Economy	19100.00
0005433686656	19509	Economy	19100.00
0005433687725	19509	Economy	19100.00
0005433686657	19509	Economy	19100.00
0005433685542	19509	Economy	19100.00
0005433687721	19509	Economy	19100.00
0005433685545	19509	Economy	19100.00
0005433685548	19509	Economy	19100.00
0005433685546	19509	Economy	19100.00
0005433686661	19509	Economy	19100.00
0005433685543	19509	Economy	19100.00
0005433685549	19509	Economy	19100.00
0005433687719	19509	Economy	19100.00
0005433685537	19509	Economy	19100.00
0005433686654	19509	Economy	19100.00
0005433686647	19509	Economy	19100.00
0005433685540	19509	Economy	19100.00
0005433687724	19509	Economy	19100.00
0005433687727	19509	Economy	19100.00
0005433685541	19509	Economy	19100.00
0005433687733	19509	Economy	19100.00
0005433686653	19509	Economy	19100.00
0005433687723	19509	Economy	19100.00
0005433685544	19509	Economy	19100.00
0005433686659	19509	Economy	19100.00
0005433687732	19509	Economy	19100.00
0005433685536	19509	Economy	19100.00
0005433687720	19509	Economy	19100.00
0005433685547	19509	Economy	19100.00
0005433686650	19509	Economy	19100.00
0005433686652	19509	Economy	19100.00
0005433686649	19509	Economy	19100.00
0005432584314	3167	Economy	11100.00
0005432584329	3167	Economy	11100.00
0005432584325	3167	Economy	11100.00
0005432584324	3167	Economy	10100.00
0005432584321	3167	Economy	10100.00
0005432584313	3167	Economy	10100.00
0005432216303	3167	Economy	10100.00
0005432584320	3167	Economy	10100.00
0005432584309	3167	Economy	10100.00
0005432858067	3167	Economy	10100.00
0005432858138	3167	Economy	10100.00
0005432584326	3167	Economy	10100.00
0005432858121	3167	Economy	10100.00
0005432584307	3167	Economy	10100.00
0005432584308	3167	Economy	10100.00
0005432584306	3167	Economy	10100.00
0005432858103	3167	Economy	10100.00
0005432858086	3167	Economy	10100.00
0005432584316	3167	Economy	10100.00
0005432584327	3167	Economy	10100.00
0005432584315	3167	Economy	10100.00
0005432584330	3167	Economy	10100.00
0005432584319	3167	Economy	10100.00
0005432216304	3167	Economy	10100.00
0005432858120	3167	Economy	10100.00
0005432858116	3167	Economy	10100.00
0005432584317	3167	Economy	10100.00
0005432584322	3167	Economy	10100.00
0005432216302	3167	Economy	10100.00
0005432584310	3167	Economy	10100.00
0005432584312	3167	Economy	10100.00
0005432858075	3167	Economy	10100.00
0005432584328	3167	Economy	10100.00
0005432858066	3167	Economy	10100.00
0005432584311	3167	Economy	10100.00
0005432584323	3167	Economy	10100.00
0005432584318	3167	Economy	10100.00
0005432858205	31495	Economy	11100.00
0005432858202	31495	Economy	11100.00
0005432584160	31495	Economy	11100.00
0005432584175	31495	Economy	10100.00
0005432858200	31495	Economy	10100.00
0005432584118	31495	Economy	10100.00
0005432584128	31495	Economy	10100.00
0005432584007	31495	Economy	10100.00
0005432858206	31495	Economy	10100.00
0005432858208	31495	Economy	10100.00
0005432584040	31495	Economy	10100.00
0005432584188	31495	Economy	10100.00
0005432858201	31495	Economy	10100.00
0005432858199	31495	Economy	10100.00
0005432584174	31495	Economy	10100.00
0005432584173	31495	Economy	10100.00
0005432584131	31495	Economy	10100.00
0005432584006	31495	Economy	10100.00
0005432858209	31495	Economy	10100.00
0005432858207	31495	Economy	10100.00
0005432584161	31495	Economy	10100.00
0005432858197	31495	Economy	10100.00
0005432584058	31495	Economy	10100.00
0005432584057	31495	Economy	10100.00
0005432584129	31495	Economy	10100.00
0005432584072	31495	Economy	10100.00
0005432858204	31495	Economy	10100.00
0005432584140	31495	Economy	10100.00
0005432584139	31495	Economy	10100.00
0005432858203	31495	Economy	10100.00
0005432584049	31495	Economy	10100.00
0005432584176	31495	Economy	10100.00
0005432584073	31495	Economy	10100.00
0005432584169	31495	Economy	10100.00
0005432584117	31495	Economy	10100.00
0005432584114	31495	Economy	10100.00
0005432858198	31495	Economy	10100.00
0005432584088	31495	Economy	10100.00
0005434943455	888	Economy	8300.00
0005434943458	888	Economy	8300.00
0005434943450	888	Economy	8300.00
0005434943452	888	Economy	7500.00
0005434943453	888	Economy	7500.00
0005434943459	888	Economy	7500.00
0005433255149	888	Economy	7500.00
0005434943457	888	Economy	7500.00
0005434943454	888	Economy	7500.00
0005434943456	888	Economy	7500.00
0005433255148	888	Economy	7500.00
0005433255133	888	Economy	7500.00
0005433255153	888	Economy	7500.00
0005433255135	888	Economy	7500.00
0005434943451	888	Economy	7500.00
0005434943417	16216	Economy	7500.00
0005434943365	16216	Economy	7500.00
0005434943410	16216	Economy	7500.00
0005433255182	16216	Economy	7500.00
0005433255183	16216	Economy	7500.00
0005433255177	16216	Economy	7500.00
0005434943396	16216	Economy	7500.00
0005434943404	16216	Economy	7500.00
0005434943368	16216	Economy	7500.00
0005434943393	16216	Economy	7500.00
0005433255178	16216	Economy	7500.00
0005434943373	16216	Economy	7500.00
0005433255180	16216	Economy	7500.00
0005434943395	16216	Economy	7500.00
0005433255181	16216	Economy	7500.00
0005434943411	16216	Economy	7500.00
0005433255179	16216	Economy	7500.00
0005433654861	4326	Business	90500.00
0005433654858	4326	Business	90500.00
0005433654854	4326	Business	90500.00
0005435858554	4326	Business	90500.00
0005433654847	4326	Business	90500.00
0005433654864	4326	Business	90500.00
0005435858545	4326	Economy	30200.00
0005433654863	4326	Economy	30200.00
0005435858558	4326	Economy	30200.00
0005435858575	4326	Economy	30200.00
0005433654844	4326	Economy	30200.00
0005433654857	4326	Economy	30200.00
0005435858535	4326	Economy	33200.00
0005433654846	4326	Economy	33200.00
0005435858557	4326	Economy	30200.00
0005435858552	4326	Economy	30200.00
0005433654850	4326	Economy	30200.00
0005435858555	4326	Economy	30200.00
0005433654855	4326	Economy	30200.00
0005435858578	4326	Economy	30200.00
0005435858562	4326	Economy	30200.00
0005433654849	4326	Economy	30200.00
0005433654852	4326	Economy	30200.00
0005433654860	4326	Economy	30200.00
0005435858576	4326	Economy	30200.00
0005435858553	4326	Economy	30200.00
0005433654853	4326	Economy	30200.00
0005433654851	4326	Economy	30200.00
0005435858551	4326	Economy	30200.00
0005435858546	4326	Economy	30200.00
0005435858532	4326	Economy	30200.00
0005435858573	4326	Economy	30200.00
0005435858550	4326	Economy	30200.00
0005433654848	4326	Economy	30200.00
0005433654856	4326	Economy	30200.00
0005433654845	4326	Economy	30200.00
0005435858536	4326	Economy	30200.00
0005435858574	4326	Economy	30200.00
0005435858577	4326	Economy	30200.00
0005433654862	4326	Economy	30200.00
0005435858565	4326	Economy	30200.00
0005433654859	4326	Economy	30200.00
0005433811641	14407	Economy	4400.00
0005433811636	14407	Economy	4400.00
0005433811635	14407	Economy	4400.00
0005433811633	14407	Economy	4400.00
0005433811637	14407	Economy	4400.00
0005433811642	14407	Economy	4400.00
0005433811652	27852	Economy	4400.00
0005433811649	27852	Economy	4400.00
0005433811650	27852	Economy	4400.00
0005433811646	27852	Economy	4400.00
0005433811647	27852	Economy	4400.00
0005433811645	27852	Economy	4400.00
0005433811653	27852	Economy	4400.00
0005433811651	27852	Economy	4400.00
0005433811654	27852	Economy	4400.00
0005433811655	27852	Economy	4400.00
0005433811648	27852	Economy	4400.00
0005433811656	27852	Economy	4400.00
0005435653526	21745	Business	9800.00
0005435653522	21745	Business	9800.00
0005433368115	21745	Business	9800.00
0005435653501	21745	Business	9800.00
0005435653544	21745	Business	9800.00
0005433367836	21745	Business	9800.00
0005433367921	21745	Business	9800.00
0005435653527	21745	Business	9800.00
0005435653513	21745	Business	9800.00
0005433367833	21745	Business	9800.00
0005433368010	21745	Business	9800.00
0005435653497	21745	Business	9800.00
0005435653537	21745	Economy	3300.00
0005433367950	21745	Economy	3300.00
0005433368128	21745	Economy	3300.00
0005433367986	21745	Economy	3300.00
0005435653498	21745	Economy	3300.00
0005433368077	21745	Economy	3300.00
0005435653521	21745	Economy	3300.00
0005435653529	21745	Economy	3300.00
0005433367938	21745	Economy	3300.00
0005435653551	21745	Economy	3300.00
0005435653503	21745	Economy	3600.00
0005435653499	21745	Economy	3600.00
0005435653510	21745	Economy	3600.00
0005435653523	21745	Economy	3600.00
0005435653545	21745	Economy	3600.00
0005435653519	21745	Economy	3300.00
0005433367894	21745	Economy	3300.00
0005435653518	21745	Economy	3300.00
0005435653524	21745	Economy	3300.00
0005433367920	21745	Economy	3300.00
0005435653548	21745	Economy	3300.00
0005433367840	21745	Economy	3300.00
0005433368057	21745	Economy	3300.00
0005435653525	21745	Economy	3300.00
0005435653511	21745	Economy	3300.00
0005433367949	21745	Economy	3300.00
0005435653543	21745	Economy	3300.00
0005435653540	21745	Economy	3300.00
0005435653508	21745	Economy	3300.00
0005433367951	21745	Economy	3300.00
0005435653538	21745	Economy	3300.00
0005433368081	21745	Economy	3300.00
0005435653535	21745	Economy	3300.00
0005433367725	21745	Economy	3300.00
0005433368011	21745	Economy	3300.00
0005433367913	21745	Economy	3300.00
0005435653554	21745	Economy	3300.00
0005435653505	21745	Economy	3300.00
0005433367947	21745	Economy	3300.00
0005433367764	21745	Economy	3300.00
0005435653515	21745	Economy	3300.00
0005433367985	21745	Economy	3300.00
0005433368095	21745	Economy	3300.00
0005433367945	21745	Economy	3300.00
0005435653534	21745	Economy	3300.00
0005435653549	21745	Economy	3300.00
0005433368216	21745	Economy	3300.00
0005435653516	21745	Economy	3300.00
0005435653542	21745	Economy	3300.00
0005433368158	21745	Economy	3300.00
0005435653546	21745	Economy	3300.00
0005435653512	21745	Economy	3300.00
0005435653555	21745	Economy	3300.00
0005433368157	21745	Economy	3300.00
0005435653509	21745	Economy	3300.00
0005435653553	21745	Economy	3300.00
0005435653507	21745	Economy	3300.00
0005433368007	21745	Economy	3300.00
0005435653514	21745	Economy	3300.00
0005435653506	21745	Economy	3300.00
0005435653520	21745	Economy	3300.00
0005433367984	21745	Economy	3300.00
0005435653504	21745	Economy	3300.00
0005435653547	21745	Economy	3300.00
0005433367940	21745	Economy	3300.00
0005435653500	21745	Economy	3300.00
0005433368012	21745	Economy	3300.00
0005435653531	21745	Economy	3300.00
0005433368068	21745	Economy	3300.00
0005435653541	21745	Economy	3300.00
0005435653528	21745	Economy	3300.00
0005433368036	21745	Economy	3300.00
0005435653550	21745	Economy	3300.00
0005435653539	21745	Economy	3300.00
0005435653556	21745	Economy	3300.00
0005433368094	21745	Economy	3300.00
0005435653533	21745	Economy	3300.00
0005435653536	21745	Economy	3300.00
0005435653530	21745	Economy	3300.00
0005435653502	21745	Economy	3300.00
0005435653532	21745	Economy	3300.00
0005435653517	21745	Economy	3300.00
0005435653552	21745	Economy	3300.00
0005433805783	9361	Business	186200.00
0005434273085	9361	Business	186200.00
0005433805767	9361	Business	186200.00
0005433785350	9361	Business	186200.00
0005434273084	9361	Business	186200.00
0005433785336	9361	Business	186200.00
0005433785373	9361	Business	186200.00
0005433763372	9361	Business	186200.00
0005433805787	9361	Business	186200.00
0005433763363	9361	Business	186200.00
0005433785356	9361	Business	186200.00
0005433805784	9361	Business	186200.00
0005433763375	9361	Business	186200.00
0005433763367	9361	Business	186200.00
0005433763364	9361	Business	186200.00
0005433785347	9361	Economy	68300.00
0005434270213	9361	Economy	62100.00
0005433785357	9361	Economy	68300.00
0005434171068	9361	Economy	62100.00
0005434171058	9361	Economy	62100.00
0005433763373	9361	Economy	62100.00
0005434171130	9361	Economy	62100.00
0005433785364	9361	Economy	62100.00
0005433763362	9361	Economy	62100.00
0005434273082	9361	Economy	62100.00
0005433805773	9361	Economy	62100.00
0005433805759	9361	Economy	62100.00
0005433805761	9361	Economy	62100.00
0005432665298	9361	Economy	62100.00
0005434171131	9361	Economy	62100.00
0005433785340	9361	Economy	62100.00
0005434171069	9361	Economy	62100.00
0005434171129	9361	Economy	62100.00
0005433805772	9361	Economy	62100.00
0005433785362	9361	Economy	62100.00
0005433785345	9361	Economy	62100.00
0005433785348	9361	Economy	62100.00
0005433805777	9361	Economy	62100.00
0005433805760	9361	Economy	62100.00
0005433805785	9361	Economy	62100.00
0005434171095	9361	Economy	62100.00
0005433785374	9361	Economy	62100.00
0005433763368	9361	Economy	62100.00
0005433805758	9361	Economy	62100.00
0005433805769	9361	Economy	62100.00
0005432657482	9361	Economy	62100.00
0005434171109	9361	Economy	62100.00
0005433763369	9361	Economy	62100.00
0005433785349	9361	Economy	62100.00
0005433785366	9361	Economy	62100.00
0005434171111	9361	Economy	62100.00
0005432667477	9361	Economy	62100.00
0005433805788	9361	Economy	62100.00
0005433805779	9361	Economy	62100.00
0005433785372	9361	Economy	62100.00
0005433805768	9361	Economy	62100.00
0005433785338	9361	Economy	62100.00
0005433785370	9361	Economy	62100.00
0005433785341	9361	Economy	62100.00
0005433805765	9361	Economy	62100.00
0005433785358	9361	Economy	62100.00
0005434171162	9361	Economy	62100.00
0005433785346	9361	Economy	62100.00
0005433785351	9361	Economy	62100.00
0005433785344	9361	Economy	62100.00
0005433785359	9361	Economy	62100.00
0005433785363	9361	Economy	62100.00
0005433785369	9361	Economy	62100.00
0005432666411	9361	Economy	62100.00
0005433785368	9361	Economy	62100.00
0005433805764	9361	Economy	62100.00
0005433785360	9361	Economy	62100.00
0005433805752	9361	Economy	62100.00
0005432667476	9361	Economy	62100.00
0005434171070	9361	Economy	68300.00
0005433805778	9361	Economy	62100.00
0005433785365	9361	Economy	68300.00
0005433805754	9361	Economy	62100.00
0005434270214	9361	Economy	68300.00
0005433763370	9361	Economy	68300.00
0005433805781	9361	Economy	62100.00
0005433805766	9361	Economy	62100.00
0005432657483	9361	Economy	62100.00
0005433785339	9361	Economy	62100.00
0005433805757	9361	Economy	62100.00
0005433805774	9361	Economy	62100.00
0005433805755	9361	Economy	62100.00
0005432666412	9361	Economy	62100.00
0005433785343	9361	Economy	62100.00
0005433805780	9361	Economy	62100.00
0005433785361	9361	Economy	62100.00
0005433805762	9361	Economy	62100.00
0005433785355	9361	Economy	62100.00
0005433805771	9361	Economy	62100.00
0005433763371	9361	Economy	62100.00
0005434171067	9361	Economy	62100.00
0005433763365	9361	Economy	62100.00
0005433763374	9361	Economy	62100.00
0005433805770	9361	Economy	62100.00
0005432657484	9361	Economy	62100.00
0005433785354	9361	Economy	62100.00
0005433805753	9361	Economy	62100.00
0005433805776	9361	Economy	62100.00
0005433785342	9361	Economy	62100.00
0005433785337	9361	Economy	62100.00
0005433805756	9361	Economy	62100.00
0005433805763	9361	Economy	62100.00
0005433785371	9361	Economy	62100.00
0005434171125	9361	Economy	62100.00
0005433805782	9361	Economy	62100.00
0005433805775	9361	Economy	62100.00
0005433785352	9361	Economy	62100.00
0005433785353	9361	Economy	62100.00
0005433763376	9361	Economy	62100.00
0005433785367	9361	Economy	62100.00
0005433805786	9361	Economy	62100.00
0005433763366	9361	Economy	62100.00
0005433805380	26268	Business	186200.00
0005432657456	26268	Business	186200.00
0005433763239	26268	Business	186200.00
0005433784992	26268	Business	186200.00
0005433784932	26268	Business	186200.00
0005434151736	26268	Business	186200.00
0005435269828	26268	Business	186200.00
0005433785009	26268	Business	186200.00
0005433805588	26268	Business	186200.00
0005434171221	26268	Business	186200.00
0005433805278	26268	Business	186200.00
0005433785084	26268	Business	186200.00
0005433784978	26268	Business	186200.00
0005435269825	26268	Business	186200.00
0005433784891	26268	Business	186200.00
0005433763252	26268	Business	186200.00
0005433784947	26268	Economy	68300.00
0005434271334	26268	Economy	68300.00
0005434171213	26268	Economy	68300.00
0005433805385	26268	Economy	62100.00
0005433805363	26268	Economy	62100.00
0005432659710	26268	Economy	62100.00
0005433763259	26268	Economy	62100.00
0005435269835	26268	Economy	62100.00
0005433785096	26268	Economy	62100.00
0005434171212	26268	Economy	62100.00
0005433805545	26268	Economy	62100.00
0005433785152	26268	Economy	62100.00
0005435269836	26268	Economy	62100.00
0005433805554	26268	Economy	62100.00
0005433784798	26268	Economy	62100.00
0005434171220	26268	Economy	62100.00
0005435269832	26268	Economy	62100.00
0005433784983	26268	Economy	62100.00
0005433784924	26268	Economy	62100.00
0005433805373	26268	Economy	62100.00
0005435269830	26268	Economy	62100.00
0005433785091	26268	Economy	62100.00
0005433805478	26268	Economy	62100.00
0005433763250	26268	Economy	62100.00
0005435269838	26268	Economy	62100.00
0005434171219	26268	Economy	62100.00
0005435269824	26268	Economy	62100.00
0005434171210	26268	Economy	62100.00
0005433805465	26268	Economy	62100.00
0005433805525	26268	Economy	62100.00
0005433805479	26268	Economy	62100.00
0005434171216	26268	Economy	62100.00
0005433784903	26268	Economy	62100.00
0005434171215	26268	Economy	62100.00
0005433784993	26268	Economy	62100.00
0005435269831	26268	Economy	62100.00
0005434171218	26268	Economy	62100.00
0005433785176	26268	Economy	62100.00
0005435269837	26268	Economy	62100.00
0005433784959	26268	Economy	62100.00
0005432663038	26268	Economy	62100.00
0005434151737	26268	Economy	62100.00
0005433785177	26268	Economy	62100.00
0005433784984	26268	Economy	62100.00
0005433784799	26268	Economy	62100.00
0005434151735	26268	Economy	62100.00
0005434171211	26268	Economy	62100.00
0005433763283	26268	Economy	62100.00
0005433805553	26268	Economy	62100.00
0005434171217	26268	Economy	62100.00
0005434171209	26268	Economy	62100.00
0005433784890	26268	Economy	62100.00
0005433805476	26268	Economy	62100.00
0005435269826	26268	Economy	62100.00
0005433805475	26268	Economy	62100.00
0005432659709	26268	Economy	62100.00
0005432666395	26268	Economy	68300.00
0005434171222	26268	Economy	68300.00
0005433784926	26268	Economy	62100.00
0005433784994	26268	Economy	62100.00
0005433763240	26268	Economy	62100.00
0005433785058	26268	Economy	62100.00
0005433763278	26268	Economy	62100.00
0005432663037	26268	Economy	62100.00
0005433805456	26268	Economy	62100.00
0005433784975	26268	Economy	62100.00
0005433763275	26268	Economy	62100.00
0005433805632	26268	Economy	62100.00
0005433784976	26268	Economy	62100.00
0005433805472	26268	Economy	62100.00
0005433805457	26268	Economy	62100.00
0005435269839	26268	Economy	62100.00
0005433763274	26268	Economy	62100.00
0005433805660	26268	Economy	62100.00
0005432657460	26268	Economy	62100.00
0005434271333	26268	Economy	62100.00
0005433763201	26268	Economy	62100.00
0005433785118	26268	Economy	62100.00
0005434171214	26268	Economy	62100.00
0005435269829	26268	Economy	62100.00
0005434270228	26268	Economy	62100.00
0005433805386	26268	Economy	62100.00
0005433785023	26268	Economy	62100.00
0005433784925	26268	Economy	62100.00
0005433784958	26268	Economy	62100.00
0005433805546	26268	Economy	62100.00
0005435269834	26268	Economy	62100.00
0005432659715	26268	Economy	62100.00
0005433805381	26268	Economy	62100.00
0005433784904	26268	Economy	62100.00
0005433763200	26268	Economy	62100.00
0005433763251	26268	Economy	62100.00
0005434269125	26268	Economy	62100.00
0005433784929	26268	Economy	62100.00
0005433805279	26268	Economy	62100.00
0005433805537	26268	Economy	62100.00
0005435269833	26268	Economy	62100.00
0005434270227	26268	Economy	62100.00
0005433784931	26268	Economy	62100.00
0005433785119	26268	Economy	62100.00
0005433805493	26268	Economy	62100.00
0005433785054	26268	Economy	62100.00
0005433805571	26268	Economy	62100.00
0005433763199	26268	Economy	62100.00
0005432657461	26268	Economy	62100.00
0005435269827	26268	Economy	62100.00
0005433784991	26268	Economy	62100.00
0005433785053	26268	Economy	62100.00
0005435135723	4932	Economy	5900.00
0005435929651	4932	Economy	5300.00
0005435135724	4932	Economy	5300.00
0005435929645	4932	Economy	5300.00
0005435135727	4932	Economy	5300.00
0005435135726	4932	Economy	5300.00
0005435135725	4932	Economy	5300.00
0005435135722	4932	Economy	5300.00
0005435135728	4932	Economy	5300.00
0005435929675	33035	Economy	5900.00
0005435135688	33035	Economy	5300.00
0005435135689	33035	Economy	5300.00
0005435135676	33035	Economy	5300.00
0005435929673	33035	Economy	5300.00
0005435135680	33035	Economy	5300.00
0005435929674	33035	Economy	5300.00
0005435135696	33035	Economy	5300.00
0005435135695	33035	Economy	5300.00
0005435135691	33035	Economy	5300.00
0005434983345	9484	Economy	19700.00
0005434217990	9484	Economy	19700.00
0005434983344	9484	Economy	19700.00
0005434983343	9484	Economy	17900.00
0005434217983	9484	Economy	17900.00
0005434983346	9484	Economy	17900.00
0005434983347	9484	Economy	17900.00
0005434217953	9484	Economy	17900.00
0005434983303	27353	Economy	17900.00
0005434218015	27353	Economy	17900.00
0005434218014	27353	Economy	17900.00
0005434218016	27353	Economy	17900.00
0005434983315	27353	Economy	17900.00
0005434983316	27353	Economy	17900.00
0005434983304	27353	Economy	17900.00
0005434218012	27353	Economy	17900.00
0005434218013	27353	Economy	17900.00
0005433960985	24266	Business	36400.00
0005433986103	24266	Business	36400.00
0005433960687	24266	Business	36400.00
0005433986151	24266	Business	36400.00
0005433986001	24266	Business	36400.00
0005433960987	24266	Business	36400.00
0005433960950	24266	Business	36400.00
0005433960868	24266	Business	36400.00
0005433960915	24266	Business	36400.00
0005433960888	24266	Business	36400.00
0005433986062	24266	Business	36400.00
0005433986002	24266	Business	36400.00
0005433960805	24266	Business	36400.00
0005433960973	24266	Business	36400.00
0005433985844	24266	Business	36400.00
0005433985980	24266	Business	36400.00
0005433986068	24266	Economy	12100.00
0005433960853	24266	Economy	12100.00
0005433960947	24266	Economy	12100.00
0005433960939	24266	Economy	12100.00
0005433985944	24266	Economy	12100.00
0005433985927	24266	Economy	12100.00
0005433985947	24266	Economy	12100.00
0005433960993	24266	Economy	12100.00
0005433985943	24266	Economy	12100.00
0005433960819	24266	Economy	12100.00
0005433960882	24266	Economy	12100.00
0005433985982	24266	Economy	12100.00
0005433960769	24266	Economy	12100.00
0005433960940	24266	Economy	12100.00
0005433986000	24266	Economy	12100.00
0005433985822	24266	Economy	12100.00
0005433960827	24266	Economy	12100.00
0005433960878	24266	Economy	12100.00
0005433960818	24266	Economy	12100.00
0005433985922	24266	Economy	12100.00
0005433985923	24266	Economy	12100.00
0005433986152	24266	Economy	12100.00
0005433986034	24266	Economy	12100.00
0005433986096	24266	Economy	12100.00
0005433960852	24266	Economy	12100.00
0005433986095	24266	Economy	12100.00
0005433960880	24266	Economy	12100.00
0005433960822	24266	Economy	12100.00
0005433960984	24266	Economy	12100.00
0005433960963	24266	Economy	12100.00
0005433960914	24266	Economy	12100.00
0005433985956	24266	Economy	12100.00
0005433986016	24266	Economy	12100.00
0005433960817	24266	Economy	12100.00
0005433985996	24266	Economy	12100.00
0005433960877	24266	Economy	12100.00
0005433960962	24266	Economy	12100.00
0005433960968	24266	Economy	12100.00
0005433986022	24266	Economy	12100.00
0005433985767	24266	Economy	12100.00
0005433960913	24266	Economy	12100.00
0005433960902	24266	Economy	12100.00
0005433960873	24266	Economy	12100.00
0005433985999	24266	Economy	12100.00
0005433985845	24266	Economy	12100.00
0005433985983	24266	Economy	13400.00
0005433985966	24266	Economy	12100.00
0005433960674	24266	Economy	13400.00
0005433986030	24266	Economy	12100.00
0005433960748	24266	Economy	12100.00
0005433960907	24266	Economy	12100.00
0005433960854	24266	Economy	12100.00
0005433960976	24266	Economy	12100.00
0005433960837	24266	Economy	12100.00
0005433960871	24266	Economy	12100.00
0005433960815	24266	Economy	12100.00
0005433960883	24266	Economy	12100.00
0005433985942	24266	Economy	12100.00
0005433960851	24266	Economy	12100.00
0005433960588	24266	Economy	12100.00
0005433985912	24266	Economy	12100.00
0005433960823	24266	Economy	12100.00
0005433985864	24266	Economy	12100.00
0005433960814	24266	Economy	12100.00
0005433986143	24266	Economy	12100.00
0005433960904	24266	Economy	12100.00
0005433960836	24266	Economy	12100.00
0005433960761	24266	Economy	12100.00
0005433960865	24266	Economy	12100.00
0005433986061	24266	Economy	12100.00
0005433960760	24266	Economy	12100.00
0005433960795	24266	Economy	12100.00
0005433986029	24266	Economy	12100.00
0005433960977	24266	Economy	12100.00
0005433985889	24266	Economy	12100.00
0005433960884	24266	Economy	12100.00
0005433985924	24266	Economy	12100.00
0005433986074	24266	Economy	12100.00
0005433985959	24266	Economy	12100.00
0005433985888	24266	Economy	12100.00
0005433960816	24266	Economy	12100.00
0005433960975	24266	Economy	12100.00
0005433985929	24266	Economy	12100.00
0005433960986	24266	Economy	12100.00
0005433960879	24266	Economy	12100.00
0005433985911	24266	Economy	12100.00
0005433985925	24266	Economy	12100.00
0005433960642	24266	Economy	12100.00
0005433961437	25935	Business	36400.00
0005433961470	25935	Business	36400.00
0005433986442	25935	Business	36400.00
0005433986421	25935	Business	36400.00
0005433961481	25935	Business	36400.00
0005433961486	25935	Business	36400.00
0005433961434	25935	Business	36400.00
0005433986409	25935	Business	36400.00
0005433961449	25935	Business	36400.00
0005433986452	25935	Business	36400.00
0005433986406	25935	Business	36400.00
0005433986433	25935	Business	36400.00
0005433986417	25935	Business	36400.00
0005433961455	25935	Economy	13400.00
0005433986434	25935	Economy	12100.00
0005433961484	25935	Economy	12100.00
0005433986458	25935	Economy	12100.00
0005433986444	25935	Economy	12100.00
0005433986446	25935	Economy	12100.00
0005433986432	25935	Economy	12100.00
0005433961445	25935	Economy	12100.00
0005433986454	25935	Economy	12100.00
0005433986438	25935	Economy	12100.00
0005433986411	25935	Economy	12100.00
0005433986422	25935	Economy	12100.00
0005433986456	25935	Economy	12100.00
0005433961447	25935	Economy	12100.00
0005433986457	25935	Economy	12100.00
0005433961438	25935	Economy	12100.00
0005433961461	25935	Economy	12100.00
0005433986419	25935	Economy	12100.00
0005433961458	25935	Economy	12100.00
0005433986418	25935	Economy	12100.00
0005433961478	25935	Economy	12100.00
0005433961452	25935	Economy	12100.00
0005433961476	25935	Economy	12100.00
0005433961431	25935	Economy	12100.00
0005433961468	25935	Economy	12100.00
0005433961485	25935	Economy	12100.00
0005433986448	25935	Economy	12100.00
0005433986451	25935	Economy	12100.00
0005433986440	25935	Economy	12100.00
0005433986450	25935	Economy	12100.00
0005433961430	25935	Economy	12100.00
0005433986436	25935	Economy	12100.00
0005433986441	25935	Economy	12100.00
0005433986453	25935	Economy	12100.00
0005433961451	25935	Economy	12100.00
0005433986410	25935	Economy	12100.00
0005433961480	25935	Economy	12100.00
0005433961448	25935	Economy	12100.00
0005433961441	25935	Economy	12100.00
0005433961482	25935	Economy	12100.00
0005433986447	25935	Economy	12100.00
0005433961443	25935	Economy	12100.00
0005433961466	25935	Economy	12100.00
0005433986420	25935	Economy	12100.00
0005433961456	25935	Economy	12100.00
0005433961440	25935	Economy	12100.00
0005433961467	25935	Economy	12100.00
0005433986437	25935	Economy	12100.00
0005433961475	25935	Economy	12100.00
0005433961477	25935	Economy	12100.00
0005433986415	25935	Economy	12100.00
0005433986431	25935	Economy	12100.00
0005433986407	25935	Economy	12100.00
0005433961469	25935	Economy	13400.00
0005433986425	25935	Economy	13400.00
0005433986423	25935	Economy	13400.00
0005433961444	25935	Economy	12100.00
0005433986413	25935	Economy	12100.00
0005433986427	25935	Economy	12100.00
0005433986435	25935	Economy	12100.00
0005433961464	25935	Economy	12100.00
0005433961459	25935	Economy	12100.00
0005433986428	25935	Economy	12100.00
0005433961439	25935	Economy	12100.00
0005433986426	25935	Economy	12100.00
0005433961483	25935	Economy	12100.00
0005433961429	25935	Economy	12100.00
0005433986424	25935	Economy	12100.00
0005433961457	25935	Economy	12100.00
0005433961471	25935	Economy	12100.00
0005433986449	25935	Economy	12100.00
0005433986439	25935	Economy	12100.00
0005433986445	25935	Economy	12100.00
0005433986414	25935	Economy	12100.00
0005433961446	25935	Economy	12100.00
0005433961465	25935	Economy	12100.00
0005433961433	25935	Economy	12100.00
0005433986429	25935	Economy	12100.00
0005433961462	25935	Economy	12100.00
0005433961442	25935	Economy	12100.00
0005433986408	25935	Economy	12100.00
0005433961435	25935	Economy	12100.00
0005433961479	25935	Economy	12100.00
0005433986443	25935	Economy	12100.00
0005433961474	25935	Economy	12100.00
0005433986412	25935	Economy	12100.00
0005433961450	25935	Economy	12100.00
0005433961453	25935	Economy	12100.00
0005433986416	25935	Economy	12100.00
0005433961460	25935	Economy	12100.00
0005433961473	25935	Economy	12100.00
0005433986455	25935	Economy	12100.00
0005433986430	25935	Economy	12100.00
0005433961436	25935	Economy	12100.00
0005433961454	25935	Economy	12100.00
0005433961472	25935	Economy	12100.00
0005433961463	25935	Economy	12100.00
0005433961432	25935	Economy	12100.00
0005434480621	929	Economy	25400.00
0005434480624	929	Economy	25400.00
0005433165913	929	Economy	23100.00
0005434480609	929	Economy	23100.00
0005434480607	929	Economy	23100.00
0005434480620	929	Economy	23100.00
0005433165991	929	Economy	23100.00
0005434480604	929	Economy	23100.00
0005433165969	929	Economy	23100.00
0005434480617	929	Economy	23100.00
0005433165932	929	Economy	23100.00
0005434480600	929	Economy	23100.00
0005433165914	929	Economy	23100.00
0005434480613	929	Economy	23100.00
0005434480605	929	Economy	23100.00
0005434480603	929	Economy	23100.00
0005434480616	929	Economy	23100.00
0005434480622	929	Economy	23100.00
0005434480611	929	Economy	23100.00
0005434480618	929	Economy	23100.00
0005434480612	929	Economy	23100.00
0005434480602	929	Economy	23100.00
0005433165954	929	Economy	23100.00
0005434480626	929	Economy	23100.00
0005433165942	929	Economy	23100.00
0005434480601	929	Economy	23100.00
0005434480606	929	Economy	23100.00
0005434480610	929	Economy	23100.00
0005432269527	929	Economy	23100.00
0005433165971	929	Economy	23100.00
0005434480608	929	Economy	23100.00
0005432269526	929	Economy	23100.00
0005434480623	929	Economy	23100.00
0005433165920	929	Economy	23100.00
0005434480625	929	Economy	23100.00
0005434480619	929	Economy	23100.00
0005434480614	929	Economy	23100.00
0005434480615	929	Economy	23100.00
0005434480417	16602	Economy	25400.00
0005433166054	16602	Economy	25400.00
0005434480400	16602	Economy	25400.00
0005433166048	16602	Economy	25400.00
0005434480359	16602	Economy	23100.00
0005433166043	16602	Economy	23100.00
0005433166046	16602	Economy	23100.00
0005433166050	16602	Economy	23100.00
0005433166049	16602	Economy	23100.00
0005433166051	16602	Economy	23100.00
0005434480322	16602	Economy	23100.00
0005434480332	16602	Economy	23100.00
0005434480425	16602	Economy	23100.00
0005433166053	16602	Economy	23100.00
0005433166055	16602	Economy	23100.00
0005434480466	16602	Economy	23100.00
0005434480323	16602	Economy	23100.00
0005434480408	16602	Economy	23100.00
0005434480360	16602	Economy	23100.00
0005434480379	16602	Economy	23100.00
0005434480426	16602	Economy	23100.00
0005433166044	16602	Economy	23100.00
0005434480299	16602	Economy	23100.00
0005434480433	16602	Economy	23100.00
0005434480358	16602	Economy	23100.00
0005434480356	16602	Economy	23100.00
0005433166047	16602	Economy	23100.00
0005434480387	16602	Economy	23100.00
0005434480331	16602	Economy	23100.00
0005434480345	16602	Economy	23100.00
0005433166056	16602	Economy	23100.00
0005433166052	16602	Economy	23100.00
0005434480216	16602	Economy	23100.00
0005433166045	16602	Economy	23100.00
0005434480386	16602	Economy	23100.00
0005433872517	3196	Economy	17200.00
0005433872516	3196	Economy	17200.00
0005433872526	3196	Economy	17200.00
0005433872522	3196	Economy	17200.00
0005433872519	3196	Economy	17200.00
0005433872524	3196	Economy	17200.00
0005433872518	3196	Economy	17200.00
0005433872520	3196	Economy	17200.00
0005433872521	3196	Economy	17200.00
0005433872523	3196	Economy	17200.00
0005433872525	3196	Economy	17200.00
0005433872471	32540	Economy	19000.00
0005433872507	32540	Economy	19000.00
0005433872499	32540	Economy	19000.00
0005433872489	32540	Economy	17200.00
0005433872500	32540	Economy	17200.00
0005433872480	32540	Economy	17200.00
0005433872481	32540	Economy	17200.00
0005433872488	32540	Economy	17200.00
0005433872485	32540	Economy	17200.00
0005433872484	32540	Economy	17200.00
0005433872495	32540	Economy	17200.00
0005435386593	10335	Economy	17000.00
0005435386587	10335	Economy	17000.00
0005435142720	10335	Economy	17000.00
0005433289866	10335	Economy	17000.00
0005435142710	10335	Economy	15400.00
0005435142711	10335	Economy	15400.00
0005435142717	10335	Economy	15400.00
0005435142714	10335	Economy	15400.00
0005435150165	10335	Economy	15400.00
0005435386573	10335	Economy	15400.00
0005435142721	10335	Economy	15400.00
0005435142719	10335	Economy	15400.00
0005435142723	10335	Economy	15400.00
0005433289822	10335	Economy	15400.00
0005435142715	10335	Economy	15400.00
0005435386588	10335	Economy	15400.00
0005435150174	10335	Economy	15400.00
0005435150176	10335	Economy	15400.00
0005435150177	10335	Economy	15400.00
0005435142713	10335	Economy	15400.00
0005435142712	10335	Economy	15400.00
0005433289874	10335	Economy	15400.00
0005433289868	10335	Economy	15400.00
0005435142722	10335	Economy	15400.00
0005435386578	10335	Economy	15400.00
0005433289867	10335	Economy	15400.00
0005435150172	10335	Economy	15400.00
0005433289850	10335	Economy	15400.00
0005435150166	10335	Economy	15400.00
0005435142718	10335	Economy	15400.00
0005435150175	10335	Economy	15400.00
0005435150173	10335	Economy	15400.00
0005435386598	10335	Economy	15400.00
0005435150169	10335	Economy	15400.00
0005435386566	10335	Economy	15400.00
0005435150168	10335	Economy	15400.00
0005435150171	10335	Economy	15400.00
0005433289848	10335	Economy	15400.00
0005435142716	10335	Economy	15400.00
0005435150167	10335	Economy	15400.00
0005435150170	10335	Economy	15400.00
0005435142611	21953	Economy	17000.00
0005433289935	21953	Economy	17000.00
0005435142523	21953	Economy	17000.00
0005433289936	21953	Economy	15400.00
0005435150044	21953	Economy	15400.00
0005435150098	21953	Economy	15400.00
0005435150027	21953	Economy	15400.00
0005435150076	21953	Economy	15400.00
0005435150028	21953	Economy	15400.00
0005435150086	21953	Economy	15400.00
0005433289934	21953	Economy	15400.00
0005435150060	21953	Economy	15400.00
0005435386644	21953	Economy	15400.00
0005433289937	21953	Economy	15400.00
0005435150026	21953	Economy	15400.00
0005435386650	21953	Economy	15400.00
0005435150088	21953	Economy	15400.00
0005435142639	21953	Economy	15400.00
0005435386649	21953	Economy	15400.00
0005435142583	21953	Economy	15400.00
0005435142648	21953	Economy	15400.00
0005435386646	21953	Economy	15400.00
0005435150013	21953	Economy	15400.00
0005433289933	21953	Economy	15400.00
0005435150087	21953	Economy	15400.00
0005435150014	21953	Economy	15400.00
0005435150056	21953	Economy	15400.00
0005435150075	21953	Economy	15400.00
0005435386647	21953	Economy	15400.00
0005435386645	21953	Economy	15400.00
0005435142574	21953	Economy	15400.00
0005433289932	21953	Economy	15400.00
0005435142647	21953	Economy	15400.00
0005435386648	21953	Economy	15400.00
0005433289938	21953	Economy	15400.00
0005435319615	11220	Business	57200.00
0005435502430	11220	Business	57200.00
0005435502324	11220	Business	57200.00
0005435529266	11220	Business	57200.00
0005434573503	11220	Business	57200.00
0005435502433	11220	Business	57200.00
0005434573504	11220	Business	57200.00
0005435545756	11220	Business	57200.00
0005435529317	11220	Economy	19100.00
0005435545759	11220	Economy	19100.00
0005435529212	11220	Economy	19100.00
0005435545750	11220	Economy	19100.00
0005435529250	11220	Economy	19100.00
0005435529230	11220	Economy	19100.00
0005435319621	11220	Economy	19100.00
0005435529227	11220	Economy	19100.00
0005434573502	11220	Economy	19100.00
0005435529319	11220	Economy	19100.00
0005434573497	11220	Economy	21000.00
0005435502325	11220	Economy	21000.00
0005434573501	11220	Economy	21000.00
0005434573494	11220	Economy	21000.00
0005435319576	11220	Economy	19100.00
0005435502416	11220	Economy	19100.00
0005435502415	11220	Economy	19100.00
0005435529307	11220	Economy	19100.00
0005435319562	11220	Economy	19100.00
0005435319561	11220	Economy	19100.00
0005435545757	11220	Economy	19100.00
0005434573499	11220	Economy	19100.00
0005435529288	11220	Economy	19100.00
0005435545791	11220	Economy	19100.00
0005435529289	11220	Economy	19100.00
0005435502469	11220	Economy	19100.00
0005435502365	11220	Economy	19100.00
0005435319589	11220	Economy	19100.00
0005434573498	11220	Economy	19100.00
0005435502377	11220	Economy	19100.00
0005435319625	11220	Economy	19100.00
0005435529252	11220	Economy	19100.00
0005435529330	11220	Economy	19100.00
0005435502407	11220	Economy	19100.00
0005435529347	11220	Economy	19100.00
0005434573500	11220	Economy	19100.00
0005434573492	11220	Economy	19100.00
0005435529311	11220	Economy	19100.00
0005435502408	11220	Economy	19100.00
0005435319608	11220	Economy	19100.00
0005435529306	11220	Economy	19100.00
0005435529251	11220	Economy	19100.00
0005434573493	11220	Economy	19100.00
0005435502372	11220	Economy	19100.00
0005435502455	11220	Economy	19100.00
0005435502378	11220	Economy	19100.00
0005435502409	11220	Economy	19100.00
0005435545760	11220	Economy	19100.00
0005435529305	11220	Economy	19100.00
0005435502296	11220	Economy	19100.00
0005435529312	11220	Economy	19100.00
0005435502318	11220	Economy	19100.00
0005435319609	11220	Economy	19100.00
0005435529287	11220	Economy	19100.00
0005435502414	11220	Economy	19100.00
0005435502316	11220	Economy	19100.00
0005435319604	11220	Economy	19100.00
0005435529256	11220	Economy	19100.00
0005435529226	11220	Economy	19100.00
0005435502434	11220	Economy	19100.00
0005435502454	11220	Economy	19100.00
0005435502307	11220	Economy	19100.00
0005435529320	11220	Economy	19100.00
0005435502401	11220	Economy	19100.00
0005435545747	11220	Economy	19100.00
0005435502306	11220	Economy	19100.00
0005435319605	11220	Economy	19100.00
0005435502373	11220	Economy	19100.00
0005435545724	11220	Economy	19100.00
0005435529328	11220	Economy	19100.00
0005435545749	11220	Economy	19100.00
0005434573495	11220	Economy	19100.00
0005434573496	11220	Economy	19100.00
0005435502540	20918	Business	57200.00
0005435502542	20918	Business	57200.00
0005434573416	20918	Business	57200.00
0005435518111	20918	Business	57200.00
0005435502535	20918	Business	57200.00
0005435508478	20918	Business	57200.00
0005435502541	20918	Business	57200.00
0005435502544	20918	Business	57200.00
0005435518104	20918	Economy	19100.00
0005435518100	20918	Economy	19100.00
0005435319685	20918	Economy	19100.00
0005434573357	20918	Economy	19100.00
0005435502530	20918	Economy	19100.00
0005435518098	20918	Economy	19100.00
0005435319683	20918	Economy	19100.00
0005435502547	20918	Economy	19100.00
0005435502551	20918	Economy	21000.00
0005435508473	20918	Economy	21000.00
0005435502552	20918	Economy	21000.00
0005435502537	20918	Economy	21000.00
0005434573432	20918	Economy	19100.00
0005435508482	20918	Economy	19100.00
0005435518109	20918	Economy	19100.00
0005435518097	20918	Economy	19100.00
0005435502550	20918	Economy	19100.00
0005435502546	20918	Economy	19100.00
0005435502532	20918	Economy	19100.00
0005435502533	20918	Economy	19100.00
0005434573361	20918	Economy	19100.00
0005432291954	20918	Economy	19100.00
0005434573316	20918	Economy	19100.00
0005435319684	20918	Economy	19100.00
0005432291955	20918	Economy	19100.00
0005435518107	20918	Economy	19100.00
0005435319679	20918	Economy	19100.00
0005434573352	20918	Economy	19100.00
0005435508481	20918	Economy	19100.00
0005434573374	20918	Economy	19100.00
0005435319678	20918	Economy	19100.00
0005435502538	20918	Economy	19100.00
0005435502536	20918	Economy	19100.00
0005435518106	20918	Economy	19100.00
0005435518110	20918	Economy	19100.00
0005435508475	20918	Economy	19100.00
0005435518113	20918	Economy	19100.00
0005435502545	20918	Economy	19100.00
0005435319681	20918	Economy	19100.00
0005435508483	20918	Economy	19100.00
0005434573433	20918	Economy	19100.00
0005435518099	20918	Economy	19100.00
0005434573329	20918	Economy	19100.00
0005435502549	20918	Economy	19100.00
0005435518105	20918	Economy	19100.00
0005435518102	20918	Economy	19100.00
0005435518103	20918	Economy	19100.00
0005435319682	20918	Economy	19100.00
0005435508476	20918	Economy	19100.00
0005435518095	20918	Economy	19100.00
0005435508477	20918	Economy	19100.00
0005435518108	20918	Economy	19100.00
0005435319677	20918	Economy	19100.00
0005435518094	20918	Economy	19100.00
0005435502534	20918	Economy	19100.00
0005435508480	20918	Economy	19100.00
0005435518101	20918	Economy	19100.00
0005435502531	20918	Economy	19100.00
0005432291956	20918	Economy	19100.00
0005435518096	20918	Economy	19100.00
0005435502548	20918	Economy	19100.00
0005435508479	20918	Economy	19100.00
0005435502543	20918	Economy	19100.00
0005435319680	20918	Economy	19100.00
0005434573317	20918	Economy	19100.00
0005435518112	20918	Economy	19100.00
0005435502539	20918	Economy	19100.00
0005435508474	20918	Economy	19100.00
0005435518114	20918	Economy	19100.00
0005433927429	24318	Economy	18800.00
0005433927446	24318	Economy	18800.00
0005433927448	24318	Economy	18800.00
0005433683369	24318	Economy	17100.00
0005433683363	24318	Economy	17100.00
0005433683359	24318	Economy	17100.00
0005433927444	24318	Economy	17100.00
0005433683362	24318	Economy	17100.00
0005433683360	24318	Economy	17100.00
0005433683370	24318	Economy	17100.00
0005433927437	24318	Economy	17100.00
0005433683364	24318	Economy	17100.00
0005433683366	24318	Economy	17100.00
0005433927445	24318	Economy	17100.00
0005433683365	24318	Economy	17100.00
0005433683368	24318	Economy	17100.00
0005433683367	24318	Economy	17100.00
0005433683361	24318	Economy	17100.00
0005433927430	24318	Economy	17100.00
0005433683355	29279	Economy	18800.00
0005433683335	29279	Economy	17100.00
0005433927462	29279	Economy	17100.00
0005433927472	29279	Economy	17100.00
0005433927465	29279	Economy	17100.00
0005433683332	29279	Economy	17100.00
0005433927467	29279	Economy	17100.00
0005433927468	29279	Economy	17100.00
0005433927463	29279	Economy	17100.00
0005433927470	29279	Economy	17100.00
0005433927471	29279	Economy	17100.00
0005433927464	29279	Economy	17100.00
0005433683356	29279	Economy	17100.00
0005433683333	29279	Economy	17100.00
0005433927466	29279	Economy	17100.00
0005433927469	29279	Economy	17100.00
0005432693181	3013	Business	10300.00
0005432693252	3013	Business	10300.00
0005432693053	3013	Business	10300.00
0005432693042	3013	Business	10300.00
0005432693110	3013	Business	10300.00
0005432693107	3013	Economy	3400.00
0005432693132	3013	Economy	3400.00
0005432693115	3013	Economy	3400.00
0005432693052	3013	Economy	3800.00
0005432693142	3013	Economy	3400.00
0005432693205	3013	Economy	3400.00
0005432693116	3013	Economy	3400.00
0005432693138	3013	Economy	3400.00
0005432693054	3013	Economy	3400.00
0005432693096	3013	Economy	3400.00
0005432693074	3013	Economy	3400.00
0005432693131	3013	Economy	3400.00
0005432693177	3013	Economy	3400.00
0005432693111	3013	Economy	3400.00
0005432693073	3013	Economy	3400.00
0005432693114	3013	Economy	3400.00
0005432693112	3013	Economy	3400.00
0005432693037	3013	Economy	3400.00
0005432693108	3013	Economy	3400.00
0005432693176	3013	Economy	3400.00
0005432693130	3013	Economy	3400.00
0005432693051	3013	Economy	3400.00
0005432693102	3013	Economy	3400.00
0005432693139	3013	Economy	3400.00
0005432693038	3013	Economy	3400.00
0005432693047	3013	Economy	3400.00
0005432693251	3013	Economy	3400.00
0005432693035	3013	Economy	3400.00
0005432693036	3013	Economy	3400.00
0005432693109	3013	Economy	3400.00
0005432707067	2948	Business	10300.00
0005432707059	2948	Business	10300.00
0005432707060	2948	Business	10300.00
0005433123978	2948	Business	10300.00
0005432880844	2948	Business	10300.00
0005432707064	2948	Business	10300.00
0005433123971	2948	Business	10300.00
0005433123922	2948	Economy	3400.00
0005433124026	2948	Economy	3400.00
0005432707052	2948	Economy	3400.00
0005432217808	2948	Economy	3400.00
0005432707061	2948	Economy	3400.00
0005433123934	2948	Economy	3400.00
0005433124034	2948	Economy	3400.00
0005432880822	2948	Economy	3400.00
0005432707049	2948	Economy	3800.00
0005432707056	2948	Economy	3800.00
0005432880870	2948	Economy	3800.00
0005433124020	2948	Economy	3800.00
0005432707046	2948	Economy	3400.00
0005433123970	2948	Economy	3400.00
0005433124073	2948	Economy	3400.00
0005432880852	2948	Economy	3400.00
0005432707042	2948	Economy	3400.00
0005432880821	2948	Economy	3400.00
0005432707066	2948	Economy	3400.00
0005433124047	2948	Economy	3400.00
0005433194854	2948	Economy	3400.00
0005432707043	2948	Economy	3400.00
0005432880837	2948	Economy	3400.00
0005432880901	2948	Economy	3400.00
0005432707062	2948	Economy	3400.00
0005433124045	2948	Economy	3400.00
0005432707050	2948	Economy	3400.00
0005432880871	2948	Economy	3400.00
0005432707045	2948	Economy	3400.00
0005432707065	2948	Economy	3400.00
0005432707054	2948	Economy	3400.00
0005432707048	2948	Economy	3400.00
0005433123952	2948	Economy	3400.00
0005433123935	2948	Economy	3400.00
0005433123950	2948	Economy	3400.00
0005433194853	2948	Economy	3400.00
0005432707041	2948	Economy	3400.00
0005433123972	2948	Economy	3400.00
0005432707044	2948	Economy	3400.00
0005432707058	2948	Economy	3400.00
0005432707051	2948	Economy	3400.00
0005432880905	2948	Economy	3400.00
0005432880899	2948	Economy	3400.00
0005433123949	2948	Economy	3400.00
0005432707063	2948	Economy	3400.00
0005432880855	2948	Economy	3400.00
0005432707047	2948	Economy	3400.00
0005433123933	2948	Economy	3400.00
0005432880843	2948	Economy	3400.00
0005432217806	2948	Economy	3400.00
0005432707055	2948	Economy	3400.00
0005432707057	2948	Economy	3400.00
0005432707053	2948	Economy	3400.00
0005433123953	2948	Economy	3400.00
0005432217807	2948	Economy	3400.00
0005432880906	2948	Economy	3400.00
0005433194860	2948	Economy	3400.00
0005432880975	30047	Business	10300.00
0005433124146	30047	Business	10300.00
0005432693435	30047	Business	10300.00
0005433124152	30047	Business	10300.00
0005432693428	30047	Business	10300.00
0005432706787	30047	Business	10300.00
0005432693429	30047	Business	10300.00
0005433124150	30047	Business	10300.00
0005432706807	30047	Business	10300.00
0005432693425	30047	Business	10300.00
0005432693437	30047	Business	10300.00
0005432693417	30047	Economy	3400.00
0005432706814	30047	Economy	3400.00
0005432706903	30047	Economy	3400.00
0005432693432	30047	Economy	3400.00
0005433124161	30047	Economy	3400.00
0005433124164	30047	Economy	3400.00
0005433124159	30047	Economy	3400.00
0005432693436	30047	Economy	3400.00
0005432880984	30047	Economy	3400.00
0005433124144	30047	Economy	3400.00
0005432693415	30047	Economy	3800.00
0005432880978	30047	Economy	3800.00
0005432693420	30047	Economy	3800.00
0005432693411	30047	Economy	3800.00
0005433124145	30047	Economy	3800.00
0005433124163	30047	Economy	3400.00
0005432706810	30047	Economy	3400.00
0005432693426	30047	Economy	3400.00
0005433124162	30047	Economy	3400.00
0005432706847	30047	Economy	3400.00
0005432706904	30047	Economy	3400.00
0005432706809	30047	Economy	3400.00
0005432706845	30047	Economy	3400.00
0005433124148	30047	Economy	3400.00
0005432693419	30047	Economy	3400.00
0005432880979	30047	Economy	3400.00
0005432693438	30047	Economy	3400.00
0005432706855	30047	Economy	3400.00
0005432693427	30047	Economy	3400.00
0005432706856	30047	Economy	3400.00
0005433124149	30047	Economy	3400.00
0005432706956	30047	Economy	3400.00
0005432693421	30047	Economy	3400.00
0005432706776	30047	Economy	3400.00
0005432706811	30047	Economy	3400.00
0005432693440	30047	Economy	3400.00
0005432706808	30047	Economy	3400.00
0005432706822	30047	Economy	3400.00
0005432693431	30047	Economy	3400.00
0005433124153	30047	Economy	3400.00
0005433124155	30047	Economy	3400.00
0005432706837	30047	Economy	3400.00
0005433124158	30047	Economy	3400.00
0005432706700	30047	Economy	3400.00
0005432880976	30047	Economy	3400.00
0005432880980	30047	Economy	3400.00
0005432693418	30047	Economy	3400.00
0005432693433	30047	Economy	3400.00
0005432706942	30047	Economy	3400.00
0005432693412	30047	Economy	3400.00
0005432880985	30047	Economy	3400.00
0005432693441	30047	Economy	3400.00
0005432693414	30047	Economy	3400.00
0005432693439	30047	Economy	3400.00
0005433124154	30047	Economy	3400.00
0005432880981	30047	Economy	3400.00
0005432693424	30047	Economy	3400.00
0005432880982	30047	Economy	3400.00
0005432693423	30047	Economy	3400.00
0005432693422	30047	Economy	3400.00
0005432693416	30047	Economy	3400.00
0005432706757	30047	Economy	3400.00
0005432706701	30047	Economy	3400.00
0005432880983	30047	Economy	3400.00
0005432880972	30047	Economy	3400.00
0005433124151	30047	Economy	3400.00
0005432706854	30047	Economy	3400.00
0005432706849	30047	Economy	3400.00
0005432693434	30047	Economy	3400.00
0005433124156	30047	Economy	3400.00
0005432706880	30047	Economy	3400.00
0005433124147	30047	Economy	3400.00
0005433124160	30047	Economy	3400.00
0005432706836	30047	Economy	3400.00
0005432880974	30047	Economy	3400.00
0005432706906	30047	Economy	3400.00
0005432706858	30047	Economy	3400.00
0005432693413	30047	Economy	3400.00
0005432706846	30047	Economy	3400.00
0005432693430	30047	Economy	3400.00
0005433124157	30047	Economy	3400.00
0005432880977	30047	Economy	3400.00
0005432880973	30047	Economy	3400.00
0005432706900	30047	Economy	3400.00
0005432706857	30047	Economy	3400.00
0005434988853	23692	Economy	4000.00
0005434980107	23692	Economy	4000.00
0005434980086	23692	Economy	4000.00
0005434988849	23692	Economy	4000.00
0005434988854	23692	Economy	3600.00
0005434980089	23692	Economy	3600.00
0005434980113	23692	Economy	3600.00
0005434980091	23692	Economy	3600.00
0005434980093	23692	Economy	3600.00
0005434988850	23692	Economy	3600.00
0005434980099	23692	Economy	3600.00
0005434980098	23692	Economy	3600.00
0005434980096	23692	Economy	3600.00
0005434980084	23692	Economy	3600.00
0005434988851	23692	Economy	3600.00
0005434980106	23692	Economy	3600.00
0005434980103	23692	Economy	3600.00
0005434988848	23692	Economy	3600.00
0005434980087	23692	Economy	3600.00
0005434988858	23692	Economy	3600.00
0005434980090	23692	Economy	3600.00
0005434980101	23692	Economy	3600.00
0005434980092	23692	Economy	3600.00
0005434980111	23692	Economy	3600.00
0005434980095	23692	Economy	3600.00
0005434980085	23692	Economy	3600.00
0005434980102	23692	Economy	3600.00
0005434988846	23692	Economy	3600.00
0005434980083	23692	Economy	3600.00
0005434980097	23692	Economy	3600.00
0005434988847	23692	Economy	3600.00
0005434988855	23692	Economy	3600.00
0005434980109	23692	Economy	3600.00
0005434980104	23692	Economy	3600.00
0005434980110	23692	Economy	3600.00
0005434988857	23692	Economy	3600.00
0005434980100	23692	Economy	3600.00
0005434980105	23692	Economy	3600.00
0005434988856	23692	Economy	3600.00
0005434980108	23692	Economy	3600.00
0005434980094	23692	Economy	3600.00
0005434988852	23692	Economy	3600.00
0005434980112	23692	Economy	3600.00
0005434980088	23692	Economy	3600.00
0005434979816	27543	Economy	4000.00
0005434979754	27543	Economy	4000.00
0005434988725	27543	Economy	4000.00
0005434979721	27543	Economy	4000.00
0005434979828	27543	Economy	3600.00
0005434988752	27543	Economy	3600.00
0005434979920	27543	Economy	3600.00
0005434988775	27543	Economy	3600.00
0005434988769	27543	Economy	3600.00
0005434988772	27543	Economy	3600.00
0005434988776	27543	Economy	3600.00
0005434988771	27543	Economy	3600.00
0005434979827	27543	Economy	3600.00
0005434979822	27543	Economy	3600.00
0005434979818	27543	Economy	3600.00
0005434988770	27543	Economy	3600.00
0005434979875	27543	Economy	3600.00
0005434979819	27543	Economy	3600.00
0005434979830	27543	Economy	3600.00
0005434979748	27543	Economy	3600.00
0005434988765	27543	Economy	3600.00
0005434979918	27543	Economy	3600.00
0005434979739	27543	Economy	3600.00
0005434979823	27543	Economy	3600.00
0005434979797	27543	Economy	3600.00
0005434979755	27543	Economy	3600.00
0005434979829	27543	Economy	3600.00
0005434988753	27543	Economy	3600.00
0005434979740	27543	Economy	3600.00
0005434979831	27543	Economy	3600.00
0005434979798	27543	Economy	3600.00
0005434988754	27543	Economy	3600.00
0005434979919	27543	Economy	3600.00
0005434979731	27543	Economy	3600.00
0005434979815	27543	Economy	3600.00
0005434988774	27543	Economy	3600.00
0005434988766	27543	Economy	3600.00
0005434988755	27543	Economy	3600.00
0005434302503	10290	Economy	21600.00
0005433111506	10290	Economy	21600.00
0005434302505	10290	Economy	21600.00
0005434302502	10290	Economy	19700.00
0005434302504	10290	Economy	19700.00
0005434302876	10290	Economy	19700.00
0005434302875	10290	Economy	19700.00
0005433113535	10290	Economy	19700.00
0005434302458	19606	Economy	21600.00
0005434302461	19606	Economy	19700.00
0005433113561	19606	Economy	19700.00
0005433113562	19606	Economy	19700.00
0005435069685	3567	Business	26900.00
0005435069681	3567	Business	26900.00
0005435069656	3567	Business	26900.00
0005435069693	3567	Business	26900.00
0005435069645	3567	Business	26900.00
0005435069678	3567	Business	26900.00
0005435069671	3567	Business	26900.00
0005435939881	3567	Business	26900.00
0005435069683	3567	Business	26900.00
0005435069649	3567	Business	26900.00
0005435069658	3567	Business	26900.00
0005435069666	3567	Economy	9000.00
0005435939877	3567	Economy	9000.00
0005435939884	3567	Economy	9000.00
0005435069691	3567	Economy	9000.00
0005435069646	3567	Economy	9000.00
0005435069677	3567	Economy	9000.00
0005435069690	3567	Economy	9000.00
0005435069660	3567	Economy	9900.00
0005435069687	3567	Economy	9900.00
0005435069667	3567	Economy	9900.00
0005435925293	3567	Economy	9900.00
0005435069674	3567	Economy	9000.00
0005435069663	3567	Economy	9000.00
0005435069664	3567	Economy	9000.00
0005435069654	3567	Economy	9000.00
0005435069694	3567	Economy	9000.00
0005435069676	3567	Economy	9000.00
0005435925348	3567	Economy	9000.00
0005435939885	3567	Economy	9000.00
0005435069657	3567	Economy	9000.00
0005435069686	3567	Economy	9000.00
0005435069669	3567	Economy	9000.00
0005435719000	3567	Economy	9000.00
0005435069652	3567	Economy	9000.00
0005435069662	3567	Economy	9000.00
0005435069659	3567	Economy	9000.00
0005435069682	3567	Economy	9000.00
0005435069692	3567	Economy	9000.00
0005435925322	3567	Economy	9000.00
0005435069648	3567	Economy	9000.00
0005435939883	3567	Economy	9000.00
0005435069643	3567	Economy	9000.00
0005435069675	3567	Economy	9000.00
0005435069670	3567	Economy	9000.00
0005435069680	3567	Economy	9000.00
0005435069661	3567	Economy	9000.00
0005435069665	3567	Economy	9000.00
0005435069673	3567	Economy	9000.00
0005435069651	3567	Economy	9000.00
0005435069672	3567	Economy	9000.00
0005435069679	3567	Economy	9000.00
0005435719002	3567	Economy	9000.00
0005435069668	3567	Economy	9000.00
0005435069689	3567	Economy	9000.00
0005435925310	3567	Economy	9000.00
0005435925377	3567	Economy	9000.00
0005435925294	3567	Economy	9000.00
0005435069688	3567	Economy	9000.00
0005435069650	3567	Economy	9000.00
0005435069684	3567	Economy	9000.00
0005435069653	3567	Economy	9000.00
0005435939882	3567	Economy	9000.00
0005435069644	3567	Economy	9000.00
0005435719001	3567	Economy	9000.00
0005435939878	3567	Economy	9000.00
0005435069647	3567	Economy	9000.00
0005435069655	3567	Economy	9000.00
0005435069137	15333	Business	26900.00
0005435068884	15333	Business	26900.00
0005435069346	15333	Business	26900.00
0005435069179	15333	Business	26900.00
0005435069313	15333	Business	26900.00
0005435925455	15333	Business	26900.00
0005435069216	15333	Business	26900.00
0005435069142	15333	Business	26900.00
0005435069144	15333	Economy	9000.00
0005435069227	15333	Economy	9000.00
0005435925446	15333	Economy	9000.00
0005435069348	15333	Economy	9000.00
0005435939904	15333	Economy	9000.00
0005435069131	15333	Economy	9000.00
0005435939901	15333	Economy	9000.00
0005435925443	15333	Economy	9000.00
0005435939902	15333	Economy	9900.00
0005435925454	15333	Economy	9900.00
0005435939900	15333	Economy	9900.00
0005435925460	15333	Economy	9000.00
0005435069115	15333	Economy	9000.00
0005435069349	15333	Economy	9000.00
0005435068985	15333	Economy	9000.00
0005435925452	15333	Economy	9000.00
0005435069225	15333	Economy	9000.00
0005435069143	15333	Economy	9000.00
0005435069274	15333	Economy	9000.00
0005435069314	15333	Economy	9000.00
0005435925451	15333	Economy	9000.00
0005435069128	15333	Economy	9000.00
0005435068936	15333	Economy	9000.00
0005435069312	15333	Economy	9000.00
0005435069226	15333	Economy	9000.00
0005435925447	15333	Economy	9000.00
0005435925459	15333	Economy	9000.00
0005435069205	15333	Economy	9000.00
0005435069345	15333	Economy	9000.00
0005435939899	15333	Economy	9000.00
0005435925456	15333	Economy	9000.00
0005435068929	15333	Economy	9000.00
0005435925453	15333	Economy	9000.00
0005435069386	15333	Economy	9000.00
0005435069363	15333	Economy	9000.00
0005435925450	15333	Economy	9000.00
0005435069092	15333	Economy	9000.00
0005435068937	15333	Economy	9000.00
0005435069063	15333	Economy	9000.00
0005435925458	15333	Economy	9000.00
0005435069258	15333	Economy	9000.00
0005435925441	15333	Economy	9000.00
0005435950296	15333	Economy	9000.00
0005435069138	15333	Economy	9000.00
0005435069339	15333	Economy	9000.00
0005435068986	15333	Economy	9000.00
0005435925440	15333	Economy	9000.00
0005435925438	15333	Economy	9000.00
0005435069330	15333	Economy	9000.00
0005435069116	15333	Economy	9000.00
0005435925439	15333	Economy	9000.00
0005435069167	15333	Economy	9000.00
0005435925444	15333	Economy	9000.00
0005435069211	15333	Economy	9000.00
0005435069197	15333	Economy	9000.00
0005435069168	15333	Economy	9000.00
0005435069218	15333	Economy	9000.00
0005435069160	15333	Economy	9000.00
0005435069280	15333	Economy	9000.00
0005435069281	15333	Economy	9000.00
0005435925442	15333	Economy	9000.00
0005435069217	15333	Economy	9000.00
0005435069073	15333	Economy	9000.00
0005435069044	15333	Economy	9000.00
0005435069291	15333	Economy	9000.00
0005435069331	15333	Economy	9000.00
0005435925445	15333	Economy	9000.00
0005435925449	15333	Economy	9000.00
0005435925457	15333	Economy	9000.00
0005435069329	15333	Economy	9000.00
0005435925448	15333	Economy	9000.00
0005435069027	15333	Economy	9000.00
0005435925461	15333	Economy	9000.00
0005435939903	15333	Economy	9000.00
0005432659729	18127	Economy	5900.00
0005432659728	18127	Economy	5900.00
0005432660840	18127	Economy	5900.00
0005432660841	18127	Economy	5900.00
0005432658615	18127	Economy	5900.00
0005432658614	18127	Economy	5900.00
0005432659730	18127	Economy	5900.00
0005432660819	26448	Economy	5900.00
0005432667458	26448	Economy	5900.00
0005432919809	113	Business	20000.00
0005433102350	113	Business	20000.00
0005433102320	113	Business	20000.00
0005432677596	113	Business	20000.00
0005432901704	113	Business	20000.00
0005433102321	113	Business	20000.00
0005433102292	113	Business	20000.00
0005432391996	113	Business	20000.00
0005433102243	113	Business	20000.00
0005433102298	113	Business	20000.00
0005433102331	113	Business	20000.00
0005432919940	113	Business	20000.00
0005433102319	113	Business	20000.00
0005433102201	113	Business	20000.00
0005432901616	113	Business	20000.00
0005433102203	113	Business	20000.00
0005432677592	113	Business	20000.00
0005432901710	113	Business	20000.00
0005432919836	113	Economy	7300.00
0005433102240	113	Economy	7300.00
0005433102343	113	Economy	7300.00
0005432901736	113	Economy	7300.00
0005432157514	113	Economy	7300.00
0005433102302	113	Economy	6700.00
0005432919923	113	Economy	6700.00
0005433102111	113	Economy	6700.00
0005433102224	113	Economy	6700.00
0005432919840	113	Economy	6700.00
0005432901605	113	Economy	6700.00
0005433102185	113	Economy	6700.00
0005433102184	113	Economy	6700.00
0005433102227	113	Economy	6700.00
0005432677574	113	Economy	6700.00
0005433102264	113	Economy	6700.00
0005432901675	113	Economy	6700.00
0005432901640	113	Economy	6700.00
0005433102100	113	Economy	6700.00
0005432920001	113	Economy	6700.00
0005432901657	113	Economy	6700.00
0005433102269	113	Economy	6700.00
0005432391998	113	Economy	6700.00
0005432677594	113	Economy	6700.00
0005433102209	113	Economy	6700.00
0005433102139	113	Economy	6700.00
0005432901709	113	Economy	6700.00
0005432919952	113	Economy	6700.00
0005432919925	113	Economy	6700.00
0005433102126	113	Economy	6700.00
0005432901554	113	Economy	6700.00
0005433102306	113	Economy	6700.00
0005432157513	113	Economy	6700.00
0005432391995	113	Economy	6700.00
0005432677595	113	Economy	6700.00
0005433102138	113	Economy	6700.00
0005432901731	113	Economy	6700.00
0005433102305	113	Economy	6700.00
0005433102332	113	Economy	6700.00
0005433102248	113	Economy	6700.00
0005433102204	113	Economy	7300.00
0005433102151	113	Economy	7300.00
0005432920000	113	Economy	7300.00
0005432392000	113	Economy	7300.00
0005433102267	113	Economy	7300.00
0005432901642	113	Economy	6700.00
0005432901641	113	Economy	6700.00
0005433102131	113	Economy	6700.00
0005433102265	113	Economy	7300.00
0005433102188	113	Economy	6700.00
0005432901643	113	Economy	6700.00
0005433102312	113	Economy	6700.00
0005433102225	113	Economy	6700.00
0005433102226	113	Economy	6700.00
0005433102244	113	Economy	6700.00
0005432391999	113	Economy	6700.00
0005433102335	113	Economy	6700.00
0005432901606	113	Economy	6700.00
0005432901639	113	Economy	6700.00
0005432901679	113	Economy	6700.00
0005432901553	113	Economy	6700.00
0005433102249	113	Economy	6700.00
0005432901678	113	Economy	6700.00
0005432392011	113	Economy	6700.00
0005433102270	113	Economy	6700.00
0005433102334	113	Economy	6700.00
0005432919939	113	Economy	6700.00
0005433102192	113	Economy	6700.00
0005432677593	113	Economy	6700.00
0005433102212	113	Economy	6700.00
0005433102266	113	Economy	6700.00
0005433102123	113	Economy	6700.00
0005433102242	113	Economy	6700.00
0005433102187	113	Economy	6700.00
0005433102271	113	Economy	6700.00
0005432919926	113	Economy	6700.00
0005432391992	113	Economy	6700.00
0005433102208	113	Economy	6700.00
0005433102299	113	Economy	6700.00
0005432919964	113	Economy	6700.00
0005432901676	113	Economy	6700.00
0005432919835	113	Economy	6700.00
0005432677589	113	Economy	6700.00
0005433102330	113	Economy	6700.00
0005433102236	113	Economy	6700.00
0005432262397	114	Business	20000.00
0005432207689	114	Business	20000.00
0005432262431	114	Business	20000.00
0005432262403	114	Business	20000.00
0005433687701	114	Business	20000.00
0005433690925	114	Business	20000.00
0005432817791	114	Business	20000.00
0005433690933	114	Business	20000.00
0005433690934	114	Business	20000.00
0005432817816	114	Business	20000.00
0005432817794	114	Business	20000.00
0005432262429	114	Business	20000.00
0005432817798	114	Business	20000.00
0005432262400	114	Business	20000.00
0005432262437	114	Business	20000.00
0005432262432	114	Business	20000.00
0005432817814	114	Business	20000.00
0005432262409	114	Business	20000.00
0005432817793	114	Business	20000.00
0005432262422	114	Economy	7300.00
0005432817788	114	Economy	7300.00
0005433690926	114	Economy	7300.00
0005432262441	114	Economy	6700.00
0005432262442	114	Economy	6700.00
0005432817803	114	Economy	6700.00
0005432817813	114	Economy	6700.00
0005432817799	114	Economy	6700.00
0005432262404	114	Economy	6700.00
0005432817790	114	Economy	6700.00
0005432262425	114	Economy	6700.00
0005432817800	114	Economy	6700.00
0005432262408	114	Economy	6700.00
0005432756846	114	Economy	6700.00
0005432262399	114	Economy	6700.00
0005432262407	114	Economy	6700.00
0005432262424	114	Economy	6700.00
0005432262418	114	Economy	6700.00
0005432817801	114	Economy	6700.00
0005432817808	114	Economy	6700.00
0005432262401	114	Economy	6700.00
0005432262434	114	Economy	6700.00
0005433687713	114	Economy	6700.00
0005432262426	114	Economy	6700.00
0005433687714	114	Economy	6700.00
0005432262439	114	Economy	6700.00
0005432262412	114	Economy	6700.00
0005432817807	114	Economy	6700.00
0005432262415	114	Economy	6700.00
0005432753314	114	Economy	6700.00
0005432817806	114	Economy	6700.00
0005432262410	114	Economy	6700.00
0005432817789	114	Economy	6700.00
0005432207687	114	Economy	6700.00
0005432753313	114	Economy	6700.00
0005432817811	114	Economy	7300.00
0005432262443	114	Economy	7300.00
0005432817792	114	Economy	7300.00
0005432262396	114	Economy	7300.00
0005432262433	114	Economy	7300.00
0005432817810	114	Economy	6700.00
0005432289023	114	Economy	6700.00
0005432262417	114	Economy	6700.00
0005432817817	114	Economy	6700.00
0005432262414	114	Economy	6700.00
0005432817815	114	Economy	6700.00
0005432262428	114	Economy	6700.00
0005433687702	114	Economy	6700.00
0005432817805	114	Economy	6700.00
0005432262435	114	Economy	6700.00
0005432817796	114	Economy	6700.00
0005432262416	114	Economy	6700.00
0005432207688	114	Economy	6700.00
0005433690937	114	Economy	6700.00
0005432262419	114	Economy	6700.00
0005432262398	114	Economy	6700.00
0005432817802	114	Economy	6700.00
0005432262436	114	Economy	6700.00
0005432262430	114	Economy	6700.00
0005432262427	114	Economy	6700.00
0005432262438	114	Economy	6700.00
0005432262413	114	Economy	6700.00
0005432817809	114	Economy	6700.00
0005433690928	114	Economy	6700.00
0005432262406	114	Economy	6700.00
0005432817797	114	Economy	6700.00
0005432289024	114	Economy	6700.00
0005432262440	114	Economy	6700.00
0005432753299	114	Economy	6700.00
0005432817795	114	Economy	6700.00
0005432753300	114	Economy	6700.00
0005433690938	114	Economy	6700.00
0005432262411	114	Economy	6700.00
0005433690927	114	Economy	6700.00
0005432262423	114	Economy	6700.00
0005432756847	114	Economy	6700.00
0005432289022	114	Economy	6700.00
0005432262421	114	Economy	6700.00
0005432817818	114	Economy	6700.00
0005432262402	114	Economy	6700.00
0005432817804	114	Economy	6700.00
0005432753294	114	Economy	6700.00
0005432817812	114	Economy	6700.00
0005432262420	114	Economy	6700.00
0005432262405	114	Economy	6700.00
0005432020567	8073	Business	20000.00
0005432920102	8073	Business	20000.00
0005433102721	8073	Business	20000.00
0005432920091	8073	Business	20000.00
0005433102745	8073	Business	20000.00
0005432020571	8073	Business	20000.00
0005432753339	8073	Business	20000.00
0005432020572	8073	Business	20000.00
0005432020568	8073	Business	20000.00
0005432920101	8073	Business	20000.00
0005433102759	8073	Business	20000.00
0005432020549	8073	Business	20000.00
0005432677618	8073	Business	20000.00
0005432920085	8073	Business	20000.00
0005432044555	8073	Business	20000.00
0005432920092	8073	Business	20000.00
0005432392034	8073	Business	20000.00
0005432020563	8073	Business	20000.00
0005433102723	8073	Business	20000.00
0005433102740	8073	Economy	7300.00
0005432920100	8073	Economy	7300.00
0005433102761	8073	Economy	7300.00
0005433102724	8073	Economy	6700.00
0005433102726	8073	Economy	6700.00
0005433102747	8073	Economy	6700.00
0005432020548	8073	Economy	6700.00
0005432751565	8073	Economy	6700.00
0005432020561	8073	Economy	6700.00
0005432920084	8073	Economy	6700.00
0005433102762	8073	Economy	6700.00
0005432020551	8073	Economy	6700.00
0005433102750	8073	Economy	6700.00
0005433102729	8073	Economy	6700.00
0005432920093	8073	Economy	6700.00
0005432020573	8073	Economy	6700.00
0005433102742	8073	Economy	6700.00
0005433102728	8073	Economy	6700.00
0005432920083	8073	Economy	6700.00
0005432020564	8073	Economy	6700.00
0005433102720	8073	Economy	6700.00
0005432020562	8073	Economy	6700.00
0005433102730	8073	Economy	6700.00
0005432677619	8073	Economy	6700.00
0005432920099	8073	Economy	6700.00
0005432920098	8073	Economy	6700.00
0005432020569	8073	Economy	6700.00
0005433102753	8073	Economy	6700.00
0005432020560	8073	Economy	6700.00
0005433102754	8073	Economy	6700.00
0005433102722	8073	Economy	6700.00
0005432020565	8073	Economy	6700.00
0005433102751	8073	Economy	6700.00
0005432020556	8073	Economy	6700.00
0005432920097	8073	Economy	6700.00
0005432920089	8073	Economy	6700.00
0005432392033	8073	Economy	6700.00
0005432045636	8073	Economy	6700.00
0005433102748	8073	Economy	6700.00
0005432920103	8073	Economy	6700.00
0005433102746	8073	Economy	6700.00
0005433102734	8073	Economy	6700.00
0005433102755	8073	Economy	6700.00
0005433102727	8073	Economy	6700.00
0005432753340	8073	Economy	6700.00
0005432920090	8073	Economy	7300.00
0005432020570	8073	Economy	7300.00
0005433102749	8073	Economy	7300.00
0005433102757	8073	Economy	6700.00
0005432020553	8073	Economy	6700.00
0005433102733	8073	Economy	6700.00
0005433102735	8073	Economy	6700.00
0005433102737	8073	Economy	6700.00
0005432751563	8073	Economy	6700.00
0005432920086	8073	Economy	6700.00
0005432751564	8073	Economy	6700.00
0005433102760	8073	Economy	6700.00
0005432020555	8073	Economy	6700.00
0005432920094	8073	Economy	6700.00
0005432677617	8073	Economy	6700.00
0005433102738	8073	Economy	6700.00
0005432920087	8073	Economy	6700.00
0005432045637	8073	Economy	6700.00
0005432020550	8073	Economy	6700.00
0005432020554	8073	Economy	6700.00
0005433102731	8073	Economy	6700.00
0005433102736	8073	Economy	6700.00
0005433102732	8073	Economy	6700.00
0005433102764	8073	Economy	6700.00
0005432020558	8073	Economy	6700.00
0005433102756	8073	Economy	6700.00
0005432920095	8073	Economy	6700.00
0005432920088	8073	Economy	6700.00
0005432020574	8073	Economy	6700.00
0005432020557	8073	Economy	6700.00
0005433102741	8073	Economy	6700.00
0005432677620	8073	Economy	6700.00
0005433102725	8073	Economy	6700.00
0005432045635	8073	Economy	6700.00
0005432020559	8073	Economy	6700.00
0005433102763	8073	Economy	6700.00
0005433102752	8073	Economy	6700.00
0005432753338	8073	Economy	6700.00
0005433102765	8073	Economy	6700.00
0005433102758	8073	Economy	6700.00
0005432392032	8073	Economy	6700.00
0005433102739	8073	Economy	6700.00
0005432920096	8073	Economy	6700.00
0005432751566	8073	Economy	6700.00
0005432020552	8073	Economy	6700.00
0005432044556	8073	Economy	6700.00
0005433102743	8073	Economy	6700.00
0005433102744	8073	Economy	6700.00
0005432020566	8073	Economy	6700.00
0005434513585	8043	Business	20000.00
0005432817563	8043	Business	20000.00
0005432817547	8043	Business	20000.00
0005432901812	8043	Business	20000.00
0005432817559	8043	Business	20000.00
0005432817521	8043	Business	20000.00
0005432817446	8043	Economy	6700.00
0005432901807	8043	Economy	6700.00
0005432817574	8043	Economy	6700.00
0005432901801	8043	Economy	6700.00
0005432817493	8043	Economy	6700.00
0005432817593	8043	Economy	6700.00
0005432817594	8043	Economy	6700.00
0005432901799	8043	Economy	6700.00
0005434513586	8043	Economy	6700.00
0005432817576	8043	Economy	6700.00
0005432901809	8043	Economy	6700.00
0005432901804	8043	Economy	6700.00
0005432817749	8043	Economy	6700.00
0005432817546	8043	Economy	6700.00
0005432901813	8043	Economy	6700.00
0005432901814	8043	Economy	6700.00
0005432901800	8043	Economy	6700.00
0005434513588	8043	Economy	6700.00
0005432901806	8043	Economy	6700.00
0005432817668	8043	Economy	6700.00
0005434513579	8043	Economy	7300.00
0005432817543	8043	Economy	6700.00
0005434513574	8043	Economy	7300.00
0005432901810	8043	Economy	6700.00
0005432817447	8043	Economy	6700.00
0005432817560	8043	Economy	6700.00
0005432817627	8043	Economy	6700.00
0005432901798	8043	Economy	6700.00
0005434513584	8043	Economy	6700.00
0005432817552	8043	Economy	6700.00
0005432817575	8043	Economy	6700.00
0005432901808	8043	Economy	6700.00
0005432817667	8043	Economy	6700.00
0005432817520	8043	Economy	6700.00
0005432817666	8043	Economy	6700.00
0005432901811	8043	Economy	6700.00
0005432901802	8043	Economy	6700.00
0005432817750	8043	Economy	6700.00
0005432817573	8043	Economy	6700.00
0005432901805	8043	Economy	6700.00
0005432817603	8043	Economy	6700.00
0005432901815	8043	Economy	6700.00
0005432817494	8043	Economy	6700.00
0005432817519	8043	Economy	6700.00
0005434513587	8043	Economy	6700.00
0005432817490	8043	Economy	6700.00
0005432901803	8043	Economy	6700.00
0005434175779	9643	Economy	6900.00
0005433870755	9643	Economy	6900.00
0005434175772	9643	Economy	6900.00
0005433870756	9643	Economy	6900.00
0005434175780	9643	Economy	6900.00
0005434175771	9643	Economy	6900.00
0005434175802	32337	Economy	6900.00
0005434175800	32337	Economy	6900.00
0005434175799	32337	Economy	6900.00
0005433870736	32337	Economy	6900.00
0005434175798	32337	Economy	6900.00
0005433870737	32337	Economy	6900.00
0005434175801	32337	Economy	6900.00
0005434879306	3500	Business	35000.00
0005434879264	3500	Business	35000.00
0005435126820	3500	Business	35000.00
0005434879280	3500	Business	35000.00
0005434879267	3500	Business	35000.00
0005432188645	3500	Business	35000.00
0005435126825	3500	Business	35000.00
0005435626386	3500	Business	35000.00
0005434426951	3500	Business	35000.00
0005434426939	3500	Business	35000.00
0005435626390	3500	Business	35000.00
0005434879273	3500	Business	35000.00
0005434426952	3500	Business	35000.00
0005435126854	3500	Business	35000.00
0005435626392	3500	Business	35000.00
0005434879314	3500	Business	35000.00
0005434879261	3500	Business	35000.00
0005434879321	3500	Business	35000.00
0005435902708	3500	Business	35000.00
0005434426950	3500	Business	35000.00
0005434879293	3500	Comfort	19900.00
0005434879283	3500	Comfort	19900.00
0005435126826	3500	Comfort	19900.00
0005434879343	3500	Comfort	19900.00
0005435913935	3500	Comfort	19900.00
0005434938354	3500	Comfort	19900.00
0005434879270	3500	Comfort	19900.00
0005432799782	3500	Comfort	19900.00
0005435126853	3500	Comfort	19900.00
0005434938359	3500	Comfort	19900.00
0005435626391	3500	Comfort	19900.00
0005435626389	3500	Comfort	19900.00
0005434426941	3500	Comfort	19900.00
0005434879289	3500	Comfort	19900.00
0005432611754	3500	Comfort	19900.00
0005435126813	3500	Comfort	19900.00
0005434879281	3500	Comfort	19900.00
0005434426932	3500	Comfort	19900.00
0005434879278	3500	Comfort	19900.00
0005435126827	3500	Comfort	19900.00
0005435902823	3500	Comfort	19900.00
0005435126849	3500	Comfort	19900.00
0005434879276	3500	Comfort	19900.00
0005432799781	3500	Comfort	19900.00
0005435841097	3500	Comfort	19900.00
0005434879337	3500	Comfort	19900.00
0005434879303	3500	Comfort	19900.00
0005435902734	3500	Comfort	19900.00
0005434879318	3500	Comfort	19900.00
0005435126829	3500	Comfort	19900.00
0005435626385	3500	Comfort	19900.00
0005434426946	3500	Comfort	19900.00
0005434938360	3500	Comfort	19900.00
0005434879274	3500	Comfort	19900.00
0005434426935	3500	Comfort	19900.00
0005434426957	3500	Economy	11700.00
0005434879341	3500	Economy	11700.00
0005434879249	3500	Economy	11700.00
0005432188647	3500	Economy	11700.00
0005434938370	3500	Economy	11700.00
0005435126846	3500	Economy	11700.00
0005434426940	3500	Economy	11700.00
0005435126850	3500	Economy	11700.00
0005435626387	3500	Economy	11700.00
0005435626395	3500	Economy	11700.00
0005432799787	3500	Economy	11700.00
0005434879333	3500	Economy	11700.00
0005434879275	3500	Economy	11700.00
0005432611753	3500	Economy	11700.00
0005434938372	3500	Economy	11700.00
0005434426942	3500	Economy	11700.00
0005434426953	3500	Economy	11700.00
0005434879319	3500	Economy	11700.00
0005435902709	3500	Economy	11700.00
0005434879279	3500	Economy	11700.00
0005434879269	3500	Economy	11700.00
0005434879334	3500	Economy	11700.00
0005434879311	3500	Economy	11700.00
0005432799784	3500	Economy	11700.00
0005434879255	3500	Economy	11700.00
0005435126821	3500	Economy	11700.00
0005434879299	3500	Economy	11700.00
0005434879335	3500	Economy	11700.00
0005434879317	3500	Economy	11700.00
0005434426943	3500	Economy	11700.00
0005434938363	3500	Economy	11700.00
0005434938371	3500	Economy	11700.00
0005435902671	3500	Economy	11700.00
0005432799770	3500	Economy	11700.00
0005435626398	3500	Economy	11700.00
0005434879259	3500	Economy	11700.00
0005434426930	3500	Economy	11700.00
0005434879285	3500	Economy	11700.00
0005432799764	3500	Economy	11700.00
0005435126834	3500	Economy	11700.00
0005434938353	3500	Economy	11700.00
0005434938364	3500	Economy	11700.00
0005434938358	3500	Economy	11700.00
0005432799763	3500	Economy	11700.00
0005432799769	3500	Economy	11700.00
0005434879256	3500	Economy	11700.00
0005432799791	3500	Economy	11700.00
0005432611752	3500	Economy	11700.00
0005434879312	3500	Economy	12800.00
0005432799767	3500	Economy	12800.00
0005434879290	3500	Economy	11700.00
0005435126830	3500	Economy	12800.00
0005432799773	3500	Economy	12800.00
0005434879253	3500	Economy	11700.00
0005435913934	3500	Economy	11700.00
0005435126816	3500	Economy	11700.00
0005434426949	3500	Economy	11700.00
0005434938357	3500	Economy	11700.00
0005434938362	3500	Economy	11700.00
0005434426959	3500	Economy	11700.00
0005435126832	3500	Economy	11700.00
0005434879310	3500	Economy	11700.00
0005434879326	3500	Economy	11700.00
0005434879320	3500	Economy	11700.00
0005432799771	3500	Economy	11700.00
0005434426938	3500	Economy	11700.00
0005435126848	3500	Economy	11700.00
0005435126818	3500	Economy	11700.00
0005435126835	3500	Economy	11700.00
0005435902824	3500	Economy	11700.00
0005434426948	3500	Economy	11700.00
0005435126845	3500	Economy	11700.00
0005434879300	3500	Economy	11700.00
0005435902745	3500	Economy	11700.00
0005434879336	3500	Economy	11700.00
0005434426956	3500	Economy	11700.00
0005432613908	3500	Economy	11700.00
0005434938356	3500	Economy	11700.00
0005434879327	3500	Economy	11700.00
0005435902689	3500	Economy	11700.00
0005434879266	3500	Economy	11700.00
0005432799783	3500	Economy	11700.00
0005432799766	3500	Economy	11700.00
0005434879252	3500	Economy	11700.00
0005434879305	3500	Economy	11700.00
0005434879291	3500	Economy	11700.00
0005435902771	3500	Economy	11700.00
0005434426945	3500	Economy	11700.00
0005434879340	3500	Economy	11700.00
0005434879250	3500	Economy	11700.00
0005432613906	3500	Economy	11700.00
0005432799785	3500	Economy	11700.00
0005432188644	3500	Economy	11700.00
0005434426931	3500	Economy	11700.00
0005432613907	3500	Economy	11700.00
0005434879268	3500	Economy	11700.00
0005432799790	3500	Economy	11700.00
0005435902740	3500	Economy	11700.00
0005434426934	3500	Economy	11700.00
0005432799774	3500	Economy	11700.00
0005435126823	3500	Economy	11700.00
0005434879260	3500	Economy	11700.00
0005434879295	3500	Economy	11700.00
0005432188646	3500	Economy	11700.00
0005434879302	3500	Economy	11700.00
0005435626388	3500	Economy	11700.00
0005434879315	3500	Economy	11700.00
0005434879297	3500	Economy	11700.00
0005434879282	3500	Economy	11700.00
0005435126828	3500	Economy	11700.00
0005435126836	3500	Economy	11700.00
0005435126817	3500	Economy	11700.00
0005432799775	3500	Economy	11700.00
0005434879251	3500	Economy	11700.00
0005432799786	3500	Economy	11700.00
0005432613909	3500	Economy	11700.00
0005434879254	3500	Economy	11700.00
0005435626394	3500	Economy	11700.00
0005435126815	3500	Economy	11700.00
0005434879329	3500	Economy	11700.00
0005435902766	3500	Economy	11700.00
0005434879313	3500	Economy	11700.00
0005435902723	3500	Economy	11700.00
0005434879328	3500	Economy	11700.00
0005435126841	3500	Economy	11700.00
0005435913936	3500	Economy	11700.00
0005432799779	3500	Economy	11700.00
0005434938355	3500	Economy	11700.00
0005434426954	3500	Economy	12800.00
0005434938365	3500	Economy	12800.00
0005435126814	3500	Economy	12800.00
0005434426955	3500	Economy	12800.00
0005434879298	3500	Economy	12800.00
0005434426929	3500	Economy	11700.00
0005434879287	3500	Economy	11700.00
0005434879284	3500	Economy	11700.00
0005435126831	3500	Economy	11700.00
0005435902803	3500	Economy	11700.00
0005434879263	3500	Economy	11700.00
0005435126822	3500	Economy	11700.00
0005435126851	3500	Economy	11700.00
0005434938361	3500	Economy	11700.00
0005435126847	3500	Economy	11700.00
0005432799772	3500	Economy	11700.00
0005435126838	3500	Economy	11700.00
0005434879316	3500	Economy	11700.00
0005434879344	3500	Economy	11700.00
0005432183492	3500	Economy	11700.00
0005434879277	3500	Economy	11700.00
0005432611755	3500	Economy	11700.00
0005435126839	3500	Economy	11700.00
0005434879304	3500	Economy	11700.00
0005434879301	3500	Economy	11700.00
0005434879332	3500	Economy	11700.00
0005435126837	3500	Economy	11700.00
0005434426937	3500	Economy	11700.00
0005435626393	3500	Economy	11700.00
0005434879272	3500	Economy	11700.00
0005434879257	3500	Economy	11700.00
0005435626396	3500	Economy	11700.00
0005432799765	3500	Economy	11700.00
0005434879345	3500	Economy	11700.00
0005434426958	3500	Economy	11700.00
0005434879309	3500	Economy	11700.00
0005435126840	3500	Economy	11700.00
0005432799778	3500	Economy	11700.00
0005434426947	3500	Economy	11700.00
0005434938367	3500	Economy	11700.00
0005432799776	3500	Economy	11700.00
0005432799788	3500	Economy	11700.00
0005432183491	3500	Economy	11700.00
0005432799789	3500	Economy	11700.00
0005434879339	3500	Economy	11700.00
0005434879330	3500	Economy	11700.00
0005434879338	3500	Economy	11700.00
0005434938366	3500	Economy	11700.00
0005435126833	3500	Economy	11700.00
0005435126819	3500	Economy	11700.00
0005434879294	3500	Economy	11700.00
0005432799768	3500	Economy	11700.00
0005434879286	3500	Economy	11700.00
0005434879308	3500	Economy	11700.00
0005434426933	3500	Economy	11700.00
0005434879307	3500	Economy	11700.00
0005435902744	3500	Economy	11700.00
0005434938368	3500	Economy	11700.00
0005434879324	3500	Economy	11700.00
0005434879292	3500	Economy	11700.00
0005434879288	3500	Economy	11700.00
0005434879323	3500	Economy	11700.00
0005434426936	3500	Economy	11700.00
0005434879342	3500	Economy	11700.00
0005434879322	3500	Economy	11700.00
0005435126842	3500	Economy	11700.00
0005434879271	3500	Economy	11700.00
0005434426944	3500	Economy	11700.00
0005434879331	3500	Economy	11700.00
0005434879296	3500	Economy	11700.00
0005432799780	3500	Economy	11700.00
0005435626397	3500	Economy	11700.00
0005434879325	3500	Economy	11700.00
0005434879262	3500	Economy	11700.00
0005434938369	3500	Economy	11700.00
0005435126824	3500	Economy	11700.00
0005434879258	3500	Economy	11700.00
0005435126844	3500	Economy	11700.00
0005435902802	3500	Economy	11700.00
0005432799777	3500	Economy	11700.00
0005435126843	3500	Economy	11700.00
0005434879265	3500	Economy	11700.00
0005435126852	3500	Economy	11700.00
0005435902825	3500	Economy	11700.00
0005432799655	14541	Business	35000.00
0005434938166	14541	Business	35000.00
0005435902907	14541	Business	35000.00
0005434878364	14541	Business	35000.00
0005434426528	14541	Business	35000.00
0005432799525	14541	Business	35000.00
0005434878745	14541	Business	35000.00
0005434878303	14541	Business	35000.00
0005432611733	14541	Business	35000.00
0005435902913	14541	Business	35000.00
0005434426733	14541	Business	35000.00
0005434878584	14541	Business	35000.00
0005434938167	14541	Business	35000.00
0005434426585	14541	Business	35000.00
0005434878428	14541	Business	35000.00
0005434878156	14541	Business	35000.00
0005435126458	14541	Business	35000.00
0005435914704	14541	Comfort	19900.00
0005434878744	14541	Comfort	19900.00
0005434878547	14541	Comfort	19900.00
0005432611717	14541	Comfort	19900.00
0005435626200	14541	Comfort	19900.00
0005432799582	14541	Comfort	19900.00
0005434938152	14541	Comfort	19900.00
0005432799564	14541	Comfort	19900.00
0005434426649	14541	Comfort	19900.00
0005435626212	14541	Comfort	19900.00
0005435626146	14541	Comfort	19900.00
0005434878437	14541	Comfort	19900.00
0005434426679	14541	Comfort	19900.00
0005432059527	14541	Comfort	19900.00
0005432799454	14541	Comfort	19900.00
0005435126546	14541	Comfort	19900.00
0005432059526	14541	Comfort	19900.00
0005434878632	14541	Comfort	19900.00
0005434426715	14541	Comfort	19900.00
0005435126460	14541	Comfort	19900.00
0005434878155	14541	Comfort	19900.00
0005432799558	14541	Comfort	19900.00
0005432799588	14541	Comfort	19900.00
0005434878509	14541	Comfort	19900.00
0005434426615	14541	Comfort	19900.00
0005434878040	14541	Comfort	19900.00
0005434878687	14541	Comfort	19900.00
0005435902904	14541	Comfort	19900.00
0005435126510	14541	Comfort	19900.00
0005435126511	14541	Comfort	19900.00
0005435626188	14541	Comfort	19900.00
0005432799517	14541	Comfort	19900.00
0005434938215	14541	Comfort	19900.00
0005432799504	14541	Comfort	19900.00
0005434878556	14541	Economy	11700.00
0005434938296	14541	Economy	11700.00
0005434938146	14541	Economy	11700.00
0005434879051	14541	Economy	11700.00
0005435626183	14541	Economy	11700.00
0005434878088	14541	Economy	11700.00
0005432799429	14541	Economy	11700.00
0005434878583	14541	Economy	11700.00
0005434426586	14541	Economy	11700.00
0005434426738	14541	Economy	11700.00
0005434426706	14541	Economy	11700.00
0005434878339	14541	Economy	11700.00
0005432799388	14541	Economy	11700.00
0005434878280	14541	Economy	11700.00
0005434878335	14541	Economy	11700.00
0005435841830	14541	Economy	11700.00
0005434878318	14541	Economy	11700.00
0005435626148	14541	Economy	11700.00
0005435626171	14541	Economy	11700.00
0005434878182	14541	Economy	11700.00
0005432607567	14541	Economy	11700.00
0005434878434	14541	Economy	11700.00
0005432799553	14541	Economy	11700.00
0005434878239	14541	Economy	11700.00
0005434878523	14541	Economy	11700.00
0005435902909	14541	Economy	11700.00
0005434426633	14541	Economy	11700.00
0005434426663	14541	Economy	11700.00
0005434938192	14541	Economy	11700.00
0005434878478	14541	Economy	11700.00
0005434878743	14541	Economy	11700.00
0005434426793	14541	Economy	11700.00
0005435902902	14541	Economy	11700.00
0005435126281	14541	Economy	11700.00
0005432799518	14541	Economy	11700.00
0005432799467	14541	Economy	11700.00
0005434878238	14541	Economy	11700.00
0005434878763	14541	Economy	11700.00
0005435126351	14541	Economy	11700.00
0005432611731	14541	Economy	11700.00
0005434426595	14541	Economy	11700.00
0005435126507	14541	Economy	11700.00
0005434878522	14541	Economy	11700.00
0005434426808	14541	Economy	11700.00
0005434878660	14541	Economy	11700.00
0005435126482	14541	Economy	11700.00
0005435902895	14541	Economy	11700.00
0005435626167	14541	Economy	12800.00
0005435626153	14541	Economy	12800.00
0005432799499	14541	Economy	12800.00
0005435126367	14541	Economy	11700.00
0005434426619	14541	Economy	11700.00
0005434878406	14541	Economy	11700.00
0005434426620	14541	Economy	12800.00
0005434938253	14541	Economy	12800.00
0005434878138	14541	Economy	11700.00
0005435126454	14541	Economy	11700.00
0005432799462	14541	Economy	11700.00
0005435626189	14541	Economy	11700.00
0005434938329	14541	Economy	11700.00
0005434878526	14541	Economy	11700.00
0005435126349	14541	Economy	11700.00
0005435126542	14541	Economy	11700.00
0005434878753	14541	Economy	11700.00
0005432799512	14541	Economy	11700.00
0005434426686	14541	Economy	11700.00
0005434878727	14541	Economy	11700.00
0005432799600	14541	Economy	11700.00
0005435902906	14541	Economy	11700.00
0005435626210	14541	Economy	11700.00
0005434878758	14541	Economy	11700.00
0005435902910	14541	Economy	11700.00
0005434878659	14541	Economy	11700.00
0005434938254	14541	Economy	11700.00
0005435902911	14541	Economy	11700.00
0005432799505	14541	Economy	11700.00
0005434426761	14541	Economy	11700.00
0005435902908	14541	Economy	11700.00
0005432799562	14541	Economy	11700.00
0005435902896	14541	Economy	11700.00
0005435126496	14541	Economy	11700.00
0005434878310	14541	Economy	11700.00
0005434878746	14541	Economy	11700.00
0005434426632	14541	Economy	11700.00
0005434938307	14541	Economy	11700.00
0005434878790	14541	Economy	11700.00
0005435126457	14541	Economy	11700.00
0005432611718	14541	Economy	11700.00
0005434878302	14541	Economy	11700.00
0005435126368	14541	Economy	11700.00
0005435626174	14541	Economy	11700.00
0005434878708	14541	Economy	11700.00
0005435126447	14541	Economy	11700.00
0005434878467	14541	Economy	11700.00
0005432799651	14541	Economy	11700.00
0005434878688	14541	Economy	11700.00
0005434938230	14541	Economy	11700.00
0005434877932	14541	Economy	11700.00
0005434878603	14541	Economy	11700.00
0005435126499	14541	Economy	11700.00
0005435126065	14541	Economy	11700.00
0005434877908	14541	Economy	11700.00
0005434878337	14541	Economy	11700.00
0005434878791	14541	Economy	11700.00
0005434878594	14541	Economy	11700.00
0005435126486	14541	Economy	11700.00
0005434879050	14541	Economy	11700.00
0005432799549	14541	Economy	11700.00
0005435902905	14541	Economy	11700.00
0005435126497	14541	Economy	11700.00
0005434878622	14541	Economy	11700.00
0005432799498	14541	Economy	11700.00
0005435126348	14541	Economy	11700.00
0005434878768	14541	Economy	11700.00
0005434878760	14541	Economy	11700.00
0005434426739	14541	Economy	11700.00
0005435626209	14541	Economy	11700.00
0005434878499	14541	Economy	11700.00
0005434878724	14541	Economy	11700.00
0005435626176	14541	Economy	11700.00
0005432799524	14541	Economy	11700.00
0005435126302	14541	Economy	11700.00
0005435126456	14541	Economy	11700.00
0005435626207	14541	Economy	11700.00
0005434878604	14541	Economy	11700.00
0005432799506	14541	Economy	11700.00
0005435126473	14541	Economy	11700.00
0005435902897	14541	Economy	11700.00
0005435902898	14541	Economy	11700.00
0005434426685	14541	Economy	11700.00
0005435902903	14541	Economy	11700.00
0005435126495	14541	Economy	11700.00
0005435626177	14541	Economy	11700.00
0005434426606	14541	Economy	12800.00
0005435902901	14541	Economy	12800.00
0005435913965	14541	Economy	12800.00
0005434938297	14541	Economy	12800.00
0005432799597	14541	Economy	12800.00
0005434426604	14541	Economy	11700.00
0005434878722	14541	Economy	12800.00
0005434878513	14541	Economy	11700.00
0005434878435	14541	Economy	11700.00
0005432799466	14541	Economy	11700.00
0005434878757	14541	Economy	11700.00
0005435626149	14541	Economy	11700.00
0005434878756	14541	Economy	11700.00
0005435626166	14541	Economy	11700.00
0005434877778	14541	Economy	11700.00
0005434878844	14541	Economy	11700.00
0005432607572	14541	Economy	11700.00
0005435126459	14541	Economy	11700.00
0005434878297	14541	Economy	11700.00
0005432799602	14541	Economy	11700.00
0005434426737	14541	Economy	11700.00
0005434878477	14541	Economy	11700.00
0005432611721	14541	Economy	11700.00
0005434938142	14541	Economy	11700.00
0005434878585	14541	Economy	11700.00
0005435126381	14541	Economy	11700.00
0005435626172	14541	Economy	11700.00
0005434878706	14541	Economy	11700.00
0005434878527	14541	Economy	11700.00
0005435902912	14541	Economy	11700.00
0005434878546	14541	Economy	11700.00
0005434878838	14541	Economy	11700.00
0005434878728	14541	Economy	11700.00
0005434878525	14541	Economy	11700.00
0005434878387	14541	Economy	11700.00
0005435126280	14541	Economy	11700.00
0005432799550	14541	Economy	11700.00
0005432799563	14541	Economy	11700.00
0005434426710	14541	Economy	11700.00
0005434878338	14541	Economy	11700.00
0005434878438	14541	Economy	11700.00
0005434878429	14541	Economy	11700.00
0005435626211	14541	Economy	11700.00
0005435126501	14541	Economy	11700.00
0005432799423	14541	Economy	11700.00
0005434878750	14541	Economy	11700.00
0005435626203	14541	Economy	11700.00
0005435626152	14541	Economy	11700.00
0005435626125	14541	Economy	11700.00
0005434426807	14541	Economy	11700.00
0005434878497	14541	Economy	11700.00
0005434878336	14541	Economy	11700.00
0005435626173	14541	Economy	11700.00
0005434878754	14541	Economy	11700.00
0005435626058	14541	Economy	11700.00
0005432799565	14541	Economy	11700.00
0005434938193	14541	Economy	11700.00
0005434878376	14541	Economy	11700.00
0005434878755	14541	Economy	11700.00
0005434877931	14541	Economy	11700.00
0005434878479	14541	Economy	11700.00
0005434878500	14541	Economy	11700.00
0005435902899	14541	Economy	11700.00
0005434878042	14541	Economy	11700.00
0005434878524	14541	Economy	11700.00
0005434938292	14541	Economy	11700.00
0005435626151	14541	Economy	11700.00
0005434938231	14541	Economy	11700.00
0005434878468	14541	Economy	11700.00
0005435126455	14541	Economy	11700.00
0005435126352	14541	Economy	11700.00
0005435126406	14541	Economy	11700.00
0005434938291	14541	Economy	11700.00
0005435902900	14541	Economy	11700.00
0005435626206	14541	Economy	11700.00
0005435626179	14541	Economy	11700.00
0005434878334	14541	Economy	11700.00
0005434878039	14541	Economy	11700.00
0005434878271	14541	Economy	11700.00
0005434426734	14541	Economy	11700.00
0005434426621	14541	Economy	11700.00
0005434878196	14541	Economy	11700.00
0005435626154	14541	Economy	11700.00
0005434878520	14541	Economy	11700.00
0005434426631	14541	Economy	11700.00
0005432799593	14541	Economy	11700.00
0005434878528	14541	Economy	11700.00
0005434878281	14541	Economy	11700.00
0005434312341	3602	Economy	16300.00
0005434325784	3602	Economy	16300.00
0005434325774	3602	Economy	16300.00
0005435889924	3602	Economy	14800.00
0005434325776	3602	Economy	14800.00
0005435889913	3602	Economy	14800.00
0005434325779	3602	Economy	14800.00
0005434312342	3602	Economy	14800.00
0005434325778	3602	Economy	14800.00
0005435889923	3602	Economy	14800.00
0005435889914	3602	Economy	14800.00
0005434325780	3602	Economy	14800.00
0005434325782	3602	Economy	14800.00
0005434325775	3602	Economy	14800.00
0005434312343	3602	Economy	14800.00
0005435889932	3602	Economy	14800.00
0005435889927	3602	Economy	14800.00
0005434325785	3602	Economy	14800.00
0005435889910	3602	Economy	14800.00
0005434325781	3602	Economy	14800.00
0005434325777	3602	Economy	14800.00
0005435889928	3602	Economy	14800.00
0005435889909	3602	Economy	14800.00
0005434325783	3602	Economy	14800.00
0005434325649	15596	Economy	16300.00
0005434325723	15596	Economy	16300.00
0005435889964	15596	Economy	16300.00
0005434325697	15596	Economy	14800.00
0005434325733	15596	Economy	14800.00
0005434325716	15596	Economy	14800.00
0005434325700	15596	Economy	14800.00
0005435889966	15596	Economy	14800.00
0005434325734	15596	Economy	14800.00
0005434325715	15596	Economy	14800.00
0005434325699	15596	Economy	14800.00
0005434325714	15596	Economy	14800.00
0005434325722	15596	Economy	14800.00
0005434325696	15596	Economy	14800.00
0005435889963	15596	Economy	14800.00
0005435889967	15596	Economy	14800.00
0005435889965	15596	Economy	14800.00
0005435957866	646	Economy	4500.00
0005435957875	646	Economy	4500.00
0005435957862	646	Economy	4500.00
0005435957874	646	Economy	4100.00
0005435957864	646	Economy	4100.00
0005435957873	646	Economy	4100.00
0005435957870	646	Economy	4100.00
0005435957867	646	Economy	4100.00
0005433420441	646	Economy	4100.00
0005435957861	646	Economy	4100.00
0005435957865	646	Economy	4100.00
0005433420440	646	Economy	4100.00
0005435957868	646	Economy	4100.00
0005435957871	646	Economy	4100.00
0005435957872	646	Economy	4100.00
0005435957863	646	Economy	4100.00
0005433420426	646	Economy	4100.00
0005433420422	646	Economy	4100.00
0005433420427	646	Economy	4100.00
0005433420474	646	Economy	4100.00
0005435957869	646	Economy	4100.00
0005435957786	15164	Economy	4500.00
0005433420499	15164	Economy	4500.00
0005435957714	15164	Economy	4500.00
0005435957699	15164	Economy	4100.00
0005435957767	15164	Economy	4100.00
0005433420502	15164	Economy	4100.00
0005433420495	15164	Economy	4100.00
0005435957706	15164	Economy	4100.00
0005435957701	15164	Economy	4100.00
0005435957783	15164	Economy	4100.00
0005435957722	15164	Economy	4100.00
0005433420501	15164	Economy	4100.00
0005433420496	15164	Economy	4100.00
0005435957723	15164	Economy	4100.00
0005433420500	15164	Economy	4100.00
0005433420497	15164	Economy	4100.00
0005435957804	15164	Economy	4100.00
0005435957700	15164	Economy	4100.00
0005433420494	15164	Economy	4100.00
0005435957760	15164	Economy	4100.00
0005433420503	15164	Economy	4100.00
0005433420498	15164	Economy	4100.00
0005435957803	15164	Economy	4100.00
0005435216583	27263	Economy	28100.00
0005435219197	27263	Economy	25500.00
0005435219208	27263	Economy	25500.00
0005435221060	27263	Economy	25500.00
0005435221057	27263	Economy	25500.00
0005435216581	27263	Economy	25500.00
0005435216580	27263	Economy	25500.00
0005435216589	27263	Economy	25500.00
0005435216588	27263	Economy	25500.00
0005435219199	27263	Economy	25500.00
0005435216597	27263	Economy	25500.00
0005435219206	27263	Economy	25500.00
0005435216592	27263	Economy	25500.00
0005435216591	27263	Economy	25500.00
0005435219200	27263	Economy	25500.00
0005435219207	27263	Economy	25500.00
0005435219198	27263	Economy	25500.00
0005435216582	27263	Economy	25500.00
0005435216590	27263	Economy	25500.00
0005435217736	31777	Economy	28100.00
0005435216612	31777	Economy	25500.00
0005435216609	31777	Economy	25500.00
0005435217731	31777	Economy	25500.00
0005435217732	31777	Economy	25500.00
0005435216608	31777	Economy	25500.00
0005435217735	31777	Economy	25500.00
0005435216613	31777	Economy	25500.00
0005435217738	31777	Economy	25500.00
0005435217734	31777	Economy	25500.00
0005435217737	31777	Economy	25500.00
0005435216607	31777	Economy	25500.00
0005435216611	31777	Economy	25500.00
0005435216610	31777	Economy	25500.00
0005435216614	31777	Economy	25500.00
0005435217733	31777	Economy	25500.00
0005434247160	8928	Economy	10400.00
0005434247162	8928	Economy	10400.00
0005434247155	8928	Economy	10400.00
0005434247152	8928	Economy	10400.00
0005434247163	8928	Economy	10400.00
0005434247176	16098	Economy	10400.00
0005434247177	16098	Economy	10400.00
0005435629406	16098	Economy	10400.00
0005434467783	4006	Economy	21200.00
0005434467787	4006	Economy	21200.00
0005434467782	4006	Economy	21200.00
0005434467785	4006	Economy	21200.00
0005434467789	4006	Economy	21200.00
0005434467784	4006	Economy	21200.00
0005434467786	4006	Economy	21200.00
0005434467790	4006	Economy	21200.00
0005434467788	4006	Economy	21200.00
0005434467761	23205	Economy	21200.00
0005434467774	23205	Economy	21200.00
0005434467763	23205	Economy	21200.00
0005434467764	23205	Economy	21200.00
0005434467755	23205	Economy	21200.00
0005434467756	23205	Economy	21200.00
0005434467757	23205	Economy	21200.00
0005434467773	23205	Economy	21200.00
0005434467772	23205	Economy	21200.00
0005435163287	4441	Economy	13400.00
0005435163292	4441	Economy	12200.00
0005435933477	4441	Economy	12200.00
0005435933464	4441	Economy	12200.00
0005435163293	4441	Economy	12200.00
0005435163281	4441	Economy	12200.00
0005435163294	4441	Economy	12200.00
0005435933461	4441	Economy	12200.00
0005435163285	4441	Economy	12200.00
0005435933469	4441	Economy	12200.00
0005435163288	4441	Economy	12200.00
0005435163279	4441	Economy	12200.00
0005435163289	4441	Economy	12200.00
0005435933460	4441	Economy	12200.00
0005435163286	4441	Economy	12200.00
0005435163290	4441	Economy	12200.00
0005435163284	4441	Economy	12200.00
0005435163280	4441	Economy	12200.00
0005435163291	4441	Economy	12200.00
0005435163283	4441	Economy	12200.00
0005435163282	4441	Economy	12200.00
0005435933465	4441	Economy	12200.00
0005435163253	29519	Economy	13400.00
0005435163264	29519	Economy	13400.00
0005435163236	29519	Economy	12200.00
0005435933490	29519	Economy	12200.00
0005435933489	29519	Economy	12200.00
0005435933492	29519	Economy	12200.00
0005435163242	29519	Economy	12200.00
0005435163241	29519	Economy	12200.00
0005435163251	29519	Economy	12200.00
0005435163222	29519	Economy	12200.00
0005435933493	29519	Economy	12200.00
0005435933491	29519	Economy	12200.00
0005435933494	29519	Economy	12200.00
0005435933495	29519	Economy	12200.00
0005435229428	6833	Business	87700.00
0005432646095	6833	Business	87700.00
0005432646103	6833	Business	87700.00
0005432646124	6833	Business	87700.00
0005435229424	6833	Business	87700.00
0005432646100	6833	Business	87700.00
0005435229409	6833	Business	87700.00
0005432646142	6833	Business	87700.00
0005432646119	6833	Business	87700.00
0005435229480	6833	Economy	29200.00
0005432646112	6833	Economy	29200.00
0005432646131	6833	Economy	29200.00
0005432646108	6833	Economy	29200.00
0005435229416	6833	Economy	29200.00
0005432646139	6833	Economy	29200.00
0005432646143	6833	Economy	32200.00
0005435229445	6833	Economy	32200.00
0005435229425	6833	Economy	32200.00
0005432646106	6833	Economy	32200.00
0005435229446	6833	Economy	29200.00
0005435229418	6833	Economy	29200.00
0005435229451	6833	Economy	29200.00
0005432646141	6833	Economy	29200.00
0005432646107	6833	Economy	29200.00
0005432646120	6833	Economy	29200.00
0005432646121	6833	Economy	29200.00
0005435229449	6833	Economy	29200.00
0005435229419	6833	Economy	29200.00
0005435229448	6833	Economy	29200.00
0005435229407	6833	Economy	29200.00
0005432646129	6833	Economy	29200.00
0005432646114	6833	Economy	29200.00
0005432646104	6833	Economy	29200.00
0005432646096	6833	Economy	29200.00
0005432646098	6833	Economy	29200.00
0005432646092	6833	Economy	29200.00
0005432646133	6833	Economy	29200.00
0005435229417	6833	Economy	29200.00
0005432646111	6833	Economy	29200.00
0005435229415	6833	Economy	29200.00
0005432646116	6833	Economy	29200.00
0005432646145	6833	Economy	29200.00
0005435229408	6833	Economy	29200.00
0005432646132	6833	Economy	29200.00
0005432646105	6833	Economy	29200.00
0005432646144	6833	Economy	29200.00
0005432646128	6833	Economy	29200.00
0005432646138	6833	Economy	29200.00
0005435229420	6833	Economy	29200.00
0005435229389	6833	Economy	29200.00
0005432646136	6833	Economy	29200.00
0005435229426	6833	Economy	29200.00
0005432646123	6833	Economy	29200.00
0005432646109	6833	Economy	29200.00
0005435229427	6833	Economy	29200.00
0005432646115	6833	Economy	29200.00
0005432646140	6833	Economy	29200.00
0005432646093	6833	Economy	29200.00
0005432646097	6833	Economy	29200.00
0005435229388	6833	Economy	29200.00
0005432646137	6833	Economy	29200.00
0005432646113	6833	Economy	29200.00
0005432646118	6833	Economy	29200.00
0005432646117	6833	Economy	29200.00
0005432646135	6833	Economy	29200.00
0005432646130	6833	Economy	29200.00
0005432646126	6833	Economy	29200.00
0005432646127	6833	Economy	29200.00
0005435229456	6833	Economy	29200.00
0005435229433	6833	Economy	29200.00
0005432646094	6833	Economy	29200.00
0005432646125	6833	Economy	29200.00
0005432646110	6833	Economy	29200.00
0005432646099	6833	Economy	29200.00
0005432646102	6833	Economy	29200.00
0005435229434	6833	Economy	29200.00
0005432646101	6833	Economy	29200.00
0005435229436	6833	Economy	29200.00
0005432646122	6833	Economy	29200.00
0005432646134	6833	Economy	29200.00
0005435229455	6833	Economy	29200.00
0005435229444	6833	Economy	29200.00
0005435797641	2857	Business	12600.00
0005433404823	2857	Business	12600.00
0005435797630	2857	Business	12600.00
0005435797631	2857	Economy	4200.00
0005435797638	2857	Economy	4200.00
0005435797628	2857	Economy	4600.00
0005433404841	2857	Economy	4200.00
0005433404824	2857	Economy	4200.00
0005433404805	2857	Economy	4200.00
0005435797636	2857	Economy	4200.00
0005433404838	2857	Economy	4200.00
0005433404828	2857	Economy	4200.00
0005435797634	2857	Economy	4200.00
0005433404839	2857	Economy	4200.00
0005435797640	2857	Economy	4200.00
0005435797637	2857	Economy	4200.00
0005435797627	2857	Economy	4200.00
0005435797633	2857	Economy	4200.00
0005433404829	2857	Economy	4200.00
0005433404825	2857	Economy	4200.00
0005435797639	2857	Economy	4200.00
0005435797629	2857	Economy	4200.00
0005435797632	2857	Economy	4200.00
0005435797635	2857	Economy	4200.00
0005435797595	29320	Business	12600.00
0005435797596	29320	Business	12600.00
0005435797485	29320	Economy	4200.00
0005435797447	29320	Economy	4200.00
0005435797551	29320	Economy	4200.00
0005433404891	29320	Economy	4600.00
0005435797501	29320	Economy	4200.00
0005433404893	29320	Economy	4200.00
0005435797519	29320	Economy	4200.00
0005433404892	29320	Economy	4200.00
0005433404896	29320	Economy	4200.00
0005435797484	29320	Economy	4200.00
0005433404895	29320	Economy	4200.00
0005435797500	29320	Economy	4200.00
0005435797561	29320	Economy	4200.00
0005435797520	29320	Economy	4200.00
0005433404894	29320	Economy	4200.00
0005433404897	29320	Economy	4200.00
0005433404890	29320	Economy	4200.00
0005435376358	5777	Economy	6800.00
0005435376362	5777	Economy	6800.00
0005435376349	5777	Economy	6800.00
0005434948113	5731	Economy	6800.00
0005434948118	5731	Economy	6800.00
0005434948112	5731	Economy	6800.00
0005434948117	5731	Economy	6800.00
0005434948111	5731	Economy	6800.00
0005434948115	5731	Economy	6800.00
0005434948120	5731	Economy	6800.00
0005434948110	5731	Economy	6800.00
0005434948116	5731	Economy	6800.00
0005434948114	5731	Economy	6800.00
0005434948119	5731	Economy	6800.00
0005434948039	16313	Economy	6800.00
0005434948046	16313	Economy	6800.00
0005435376379	16313	Economy	6800.00
0005435376376	16313	Economy	6800.00
0005434948038	16313	Economy	6800.00
0005435376378	16313	Economy	6800.00
0005435376375	16313	Economy	6800.00
0005435376377	16313	Economy	6800.00
0005434948054	16313	Economy	6800.00
0005434948047	16313	Economy	6800.00
0005435376380	16313	Economy	6800.00
0005433961488	6853	Business	21400.00
0005433961530	6853	Business	21400.00
0005433961520	6853	Business	21400.00
0005433961489	6853	Economy	7100.00
0005433961500	6853	Economy	7100.00
0005433961512	6853	Economy	7100.00
0005433961522	6853	Economy	7100.00
0005433961509	6853	Economy	7100.00
0005433961521	6853	Economy	7800.00
0005433961487	6853	Economy	7800.00
0005433961492	6853	Economy	7100.00
0005433961491	6853	Economy	7100.00
0005433961496	6853	Economy	7100.00
0005433961499	6853	Economy	7100.00
0005433961493	6853	Economy	7100.00
0005433961529	6853	Economy	7100.00
0005433961526	6853	Economy	7100.00
0005433961503	6853	Economy	7100.00
0005433961505	6853	Economy	7100.00
0005433961511	6853	Economy	7100.00
0005433961524	6853	Economy	7100.00
0005433961498	6853	Economy	7100.00
0005433961516	6853	Economy	7100.00
0005433961490	6853	Economy	7100.00
0005433961510	6853	Economy	7100.00
0005433961504	6853	Economy	7100.00
0005433961525	6853	Economy	7100.00
0005433961531	6853	Economy	7100.00
0005433961518	6853	Economy	7100.00
0005433961513	6853	Economy	7100.00
0005433961507	6853	Economy	7100.00
0005433961515	6853	Economy	7100.00
0005433961508	6853	Economy	7100.00
0005433961506	6853	Economy	7100.00
0005433961495	6853	Economy	7100.00
0005433961501	6853	Economy	7100.00
0005433961517	6853	Economy	7100.00
0005433961502	6853	Economy	7100.00
0005433961494	6853	Economy	7100.00
0005433961497	6853	Economy	7100.00
0005433961514	6853	Economy	7100.00
0005433961519	6853	Economy	7100.00
0005433961528	6853	Economy	7100.00
0005433961523	6853	Economy	7100.00
0005433961527	6853	Economy	7100.00
0005433960956	25723	Business	21400.00
0005433960867	25723	Business	21400.00
0005433960840	25723	Business	21400.00
0005433960849	25723	Business	21400.00
0005433960901	25723	Business	21400.00
0005433960788	25723	Business	21400.00
0005433960885	25723	Business	21400.00
0005433960712	25723	Business	21400.00
0005433960718	25723	Economy	7100.00
0005433960866	25723	Economy	7100.00
0005433960716	25723	Economy	7100.00
0005433960933	25723	Economy	7100.00
0005433960900	25723	Economy	7100.00
0005433960801	25723	Economy	7100.00
0005433960736	25723	Economy	7100.00
0005433960948	25723	Economy	7100.00
0005433960735	25723	Economy	7800.00
0005433960935	25723	Economy	7800.00
0005433960717	25723	Economy	7100.00
0005433960705	25723	Economy	7100.00
0005433960930	25723	Economy	7100.00
0005433960693	25723	Economy	7100.00
0005433960922	25723	Economy	7100.00
0005433960600	25723	Economy	7100.00
0005433960575	25723	Economy	7100.00
0005433960931	25723	Economy	7100.00
0005433960847	25723	Economy	7100.00
0005433960858	25723	Economy	7100.00
0005433960952	25723	Economy	7100.00
0005433960860	25723	Economy	7100.00
0005433960791	25723	Economy	7100.00
0005433960812	25723	Economy	7100.00
0005433960926	25723	Economy	7100.00
0005433960787	25723	Economy	7100.00
0005433960826	25723	Economy	7100.00
0005433960932	25723	Economy	7100.00
0005433960694	25723	Economy	7100.00
0005433960909	25723	Economy	7100.00
0005433960925	25723	Economy	7100.00
0005433960903	25723	Economy	7100.00
0005433960863	25723	Economy	7100.00
0005433960820	25723	Economy	7100.00
0005433960875	25723	Economy	7100.00
0005433960889	25723	Economy	7100.00
0005433960688	25723	Economy	7100.00
0005433960857	25723	Economy	7100.00
0005433960699	25723	Economy	7100.00
0005433960796	25723	Economy	7100.00
0005433960864	25723	Economy	7100.00
0005433960538	25723	Economy	7100.00
0005433960874	25723	Economy	7100.00
0005433960876	25723	Economy	7100.00
0005433960698	25723	Economy	7100.00
0005433960859	25723	Economy	7100.00
0005433960923	25723	Economy	7100.00
0005433960899	25723	Economy	7100.00
0005433960934	25723	Economy	7100.00
0005433960955	25723	Economy	7100.00
0005433960886	25723	Economy	7100.00
0005435082802	24536	Economy	3900.00
0005435082806	24536	Economy	3900.00
0005435082803	24536	Economy	3900.00
0005435082789	24536	Economy	3900.00
0005435082771	24536	Economy	3900.00
0005435082867	26042	Economy	3900.00
0005435082868	26042	Economy	3900.00
0005435082866	26042	Economy	3900.00
0005435082869	26042	Economy	3900.00
0005435082865	26042	Economy	3900.00
0005435082870	26042	Economy	3900.00
0005435082864	26042	Economy	3900.00
0005435082871	26042	Economy	3900.00
0005435082872	26042	Economy	3900.00
0005434245313	5123	Business	18000.00
0005434245297	5123	Business	18000.00
0005434245298	5123	Business	18000.00
0005434245299	5123	Business	18000.00
0005434245323	5123	Business	18000.00
0005435286605	5123	Economy	6600.00
0005435286651	5123	Economy	6600.00
0005434245320	5123	Economy	6000.00
0005434245300	5123	Economy	6000.00
0005434245308	5123	Economy	6000.00
0005434245309	5123	Economy	6000.00
0005434245303	5123	Economy	6000.00
0005434245312	5123	Economy	6000.00
0005434245318	5123	Economy	6000.00
0005434245311	5123	Economy	6000.00
0005434245305	5123	Economy	6000.00
0005432166938	5123	Economy	6000.00
0005434245326	5123	Economy	6000.00
0005434245322	5123	Economy	6000.00
0005434245301	5123	Economy	6000.00
0005434245314	5123	Economy	6000.00
0005434245310	5123	Economy	6000.00
0005434245306	5123	Economy	6600.00
0005435286647	5123	Economy	6600.00
0005434245317	5123	Economy	6600.00
0005435286632	5123	Economy	6000.00
0005434245316	5123	Economy	6000.00
0005434245319	5123	Economy	6000.00
0005435286650	5123	Economy	6000.00
0005435286641	5123	Economy	6000.00
0005432166940	5123	Economy	6000.00
0005434245315	5123	Economy	6000.00
0005433534509	5123	Economy	6000.00
0005434245325	5123	Economy	6000.00
0005434245321	5123	Economy	6000.00
0005435286633	5123	Economy	6000.00
0005434245302	5123	Economy	6000.00
0005434245304	5123	Economy	6000.00
0005434245307	5123	Economy	6000.00
0005432166939	5123	Economy	6000.00
0005434245324	5123	Economy	6000.00
0005433785352	5126	Business	18000.00
0005433785338	5126	Business	18000.00
0005432106088	5126	Business	18000.00
0005432106095	5126	Business	18000.00
0005432106085	5126	Business	18000.00
0005432106123	5126	Business	18000.00
0005433785336	5126	Business	18000.00
0005433785368	5126	Business	18000.00
0005433615501	5126	Business	18000.00
0005432106109	5126	Business	18000.00
0005432106110	5126	Business	18000.00
0005433615522	5126	Business	18000.00
0005433615486	5126	Business	18000.00
0005433615531	5126	Business	18000.00
0005432106108	5126	Business	18000.00
0005433615489	5126	Business	18000.00
0005433615492	5126	Business	18000.00
0005432106124	5126	Business	18000.00
0005433615528	5126	Business	18000.00
0005433615526	5126	Business	18000.00
0005432106113	5126	Business	18000.00
0005432106127	5126	Business	18000.00
0005432106125	5126	Business	18000.00
0005433615552	5126	Business	18000.00
0005433615541	5126	Business	18000.00
0005433785372	5126	Business	18000.00
0005432106098	5126	Business	18000.00
0005433615535	5126	Economy	6600.00
0005433785364	5126	Business	18000.00
0005432106121	5126	Economy	6600.00
0005432106112	5126	Economy	6600.00
0005433785343	5126	Economy	6600.00
0005433615488	5126	Economy	6600.00
0005432106120	5126	Economy	6600.00
0005433615491	5126	Economy	6000.00
0005433785337	5126	Economy	6000.00
0005433615497	5126	Economy	6000.00
0005433785356	5126	Economy	6000.00
0005433785347	5126	Economy	6000.00
0005433615547	5126	Economy	6000.00
0005432106084	5126	Economy	6000.00
0005432145135	5126	Economy	6000.00
0005433615498	5126	Economy	6000.00
0005432106122	5126	Economy	6000.00
0005433785366	5126	Economy	6000.00
0005432667476	5126	Economy	6000.00
0005433785341	5126	Economy	6000.00
0005432106101	5126	Economy	6000.00
0005433615553	5126	Economy	6000.00
0005432106102	5126	Economy	6000.00
0005433615505	5126	Economy	6000.00
0005433615517	5126	Economy	6000.00
0005433785357	5126	Economy	6000.00
0005433785363	5126	Economy	6000.00
0005433615524	5126	Economy	6000.00
0005432106130	5126	Economy	6000.00
0005433615484	5126	Economy	6000.00
0005432106099	5126	Economy	6000.00
0005433615542	5126	Economy	6000.00
0005433615539	5126	Economy	6000.00
0005433615516	5126	Economy	6000.00
0005433615490	5126	Economy	6000.00
0005432106105	5126	Economy	6000.00
0005432106107	5126	Economy	6000.00
0005433615555	5126	Economy	6000.00
0005433615518	5126	Economy	6000.00
0005433785362	5126	Economy	6000.00
0005432106100	5126	Economy	6000.00
0005433615499	5126	Economy	6000.00
0005432106115	5126	Economy	6000.00
0005433785365	5126	Economy	6000.00
0005433615515	5126	Economy	6000.00
0005433615483	5126	Economy	6000.00
0005433615550	5126	Economy	6000.00
0005433615548	5126	Economy	6000.00
0005433615546	5126	Economy	6000.00
0005432106111	5126	Economy	6000.00
0005432106094	5126	Economy	6000.00
0005433785344	5126	Economy	6000.00
0005433615507	5126	Economy	6000.00
0005433615530	5126	Economy	6000.00
0005432106086	5126	Economy	6000.00
0005433785367	5126	Economy	6000.00
0005433615502	5126	Economy	6000.00
0005432666412	5126	Economy	6000.00
0005433615510	5126	Economy	6000.00
0005433615509	5126	Economy	6000.00
0005433785345	5126	Economy	6000.00
0005433615513	5126	Economy	6000.00
0005433615511	5126	Economy	6000.00
0005433785342	5126	Economy	6000.00
0005433615520	5126	Economy	6000.00
0005433615532	5126	Economy	6000.00
0005432145136	5126	Economy	6600.00
0005433615500	5126	Economy	6000.00
0005432106129	5126	Economy	6600.00
0005432106116	5126	Economy	6600.00
0005433785349	5126	Economy	6600.00
0005432106128	5126	Economy	6600.00
0005433615527	5126	Economy	6000.00
0005433785369	5126	Economy	6000.00
0005432106089	5126	Economy	6000.00
0005433785355	5126	Economy	6000.00
0005433615534	5126	Economy	6600.00
0005433785359	5126	Economy	6000.00
0005433785351	5126	Economy	6000.00
0005432106097	5126	Economy	6000.00
0005433615495	5126	Economy	6000.00
0005433615506	5126	Economy	6000.00
0005433615554	5126	Economy	6000.00
0005432106104	5126	Economy	6000.00
0005433785358	5126	Economy	6000.00
0005433785350	5126	Economy	6000.00
0005432106090	5126	Economy	6000.00
0005433785373	5126	Economy	6000.00
0005433615493	5126	Economy	6000.00
0005432106091	5126	Economy	6000.00
0005433615536	5126	Economy	6000.00
0005432667477	5126	Economy	6000.00
0005433785340	5126	Economy	6000.00
0005433615521	5126	Economy	6000.00
0005433615540	5126	Economy	6000.00
0005433615523	5126	Economy	6000.00
0005433785353	5126	Economy	6000.00
0005433615487	5126	Economy	6000.00
0005432145134	5126	Economy	6000.00
0005433615485	5126	Economy	6000.00
0005433615482	5126	Economy	6000.00
0005432106117	5126	Economy	6000.00
0005433615545	5126	Economy	6000.00
0005433615508	5126	Economy	6000.00
0005433615504	5126	Economy	6000.00
0005433615514	5126	Economy	6000.00
0005433615519	5126	Economy	6000.00
0005433615556	5126	Economy	6000.00
0005432665298	5126	Economy	6000.00
0005433615529	5126	Economy	6000.00
0005432106092	5126	Economy	6000.00
0005433615544	5126	Economy	6000.00
0005433785361	5126	Economy	6000.00
0005433785348	5126	Economy	6000.00
0005433615494	5126	Economy	6000.00
0005432106114	5126	Economy	6000.00
0005433785374	5126	Economy	6000.00
0005432106093	5126	Economy	6000.00
0005432106096	5126	Economy	6000.00
0005433615549	5126	Economy	6000.00
0005432106118	5126	Economy	6000.00
0005433615543	5126	Economy	6000.00
0005433785370	5126	Economy	6000.00
0005433785346	5126	Economy	6000.00
0005432106126	5126	Economy	6000.00
0005433615551	5126	Economy	6000.00
0005433615538	5126	Economy	6000.00
0005432106083	5126	Economy	6000.00
0005433615525	5126	Economy	6000.00
0005432666411	5126	Economy	6000.00
0005432106119	5126	Economy	6000.00
0005432106106	5126	Economy	6000.00
0005433785339	5126	Economy	6000.00
0005433615537	5126	Economy	6000.00
0005432106103	5126	Economy	6000.00
0005433615533	5126	Economy	6000.00
0005433615512	5126	Economy	6000.00
0005433615503	5126	Economy	6000.00
0005433615496	5126	Economy	6000.00
0005433785354	5126	Economy	6000.00
0005432106087	5126	Economy	6000.00
0005433785360	5126	Economy	6000.00
0005433785371	5126	Economy	6000.00
0005434265438	5193	Business	18000.00
0005432336088	5193	Business	18000.00
0005433688804	5193	Business	18000.00
0005435269749	5193	Business	18000.00
0005435007114	5193	Business	18000.00
0005433688809	5193	Business	18000.00
0005435007139	5193	Business	18000.00
0005433688815	5193	Business	18000.00
0005434229618	5193	Business	18000.00
0005434265436	5193	Business	18000.00
0005432336072	5193	Business	18000.00
0005434229616	5193	Business	18000.00
0005434229627	5193	Business	18000.00
0005434229636	5193	Business	18000.00
0005434149868	5193	Business	18000.00
0005434149865	5193	Business	18000.00
0005434265422	5193	Business	18000.00
0005434149864	5193	Business	18000.00
0005434229631	5193	Business	18000.00
0005435007031	5193	Business	18000.00
0005434229617	5193	Business	18000.00
0005434229624	5193	Economy	6600.00
0005433815398	5193	Business	18000.00
0005435007134	5193	Economy	6600.00
0005432336068	5193	Economy	6600.00
0005434265440	5193	Economy	6000.00
0005434149862	5193	Economy	6000.00
0005435007113	5193	Economy	6000.00
0005434149860	5193	Economy	6000.00
0005434229634	5193	Economy	6000.00
0005434265433	5193	Economy	6000.00
0005434229629	5193	Economy	6000.00
0005434265441	5193	Economy	6000.00
0005434173564	5193	Economy	6000.00
0005434229630	5193	Economy	6000.00
0005432336045	5193	Economy	6000.00
0005433688814	5193	Economy	6000.00
0005432336052	5193	Economy	6000.00
0005435269761	5193	Economy	6000.00
0005434265434	5193	Economy	6000.00
0005435007183	5193	Economy	6000.00
0005434229620	5193	Economy	6000.00
0005434265416	5193	Economy	6000.00
0005435007147	5193	Economy	6000.00
0005432336071	5193	Economy	6000.00
0005434149859	5193	Economy	6000.00
0005435269754	5193	Economy	6000.00
0005434312322	5193	Economy	6000.00
0005434229625	5193	Economy	6000.00
0005434149857	5193	Economy	6000.00
0005434265427	5193	Economy	6000.00
0005434265437	5193	Economy	6000.00
0005435007116	5193	Economy	6000.00
0005434173566	5193	Economy	6000.00
0005434229633	5193	Economy	6000.00
0005434229615	5193	Economy	6000.00
0005435007146	5193	Economy	6000.00
0005434229638	5193	Economy	6000.00
0005434149867	5193	Economy	6000.00
0005435007097	5193	Economy	6000.00
0005434229613	5193	Economy	6000.00
0005433815399	5193	Economy	6000.00
0005435007103	5193	Economy	6000.00
0005433815390	5193	Economy	6000.00
0005434265431	5193	Economy	6000.00
0005434265423	5193	Economy	6000.00
0005434229635	5193	Economy	6000.00
0005434229628	5193	Economy	6000.00
0005434229622	5193	Economy	6600.00
0005434229619	5193	Economy	6600.00
0005434149866	5193	Economy	6600.00
0005434149863	5193	Economy	6000.00
0005434265429	5193	Economy	6000.00
0005434265421	5193	Economy	6000.00
0005434173565	5193	Economy	6000.00
0005433688813	5193	Economy	6000.00
0005434265424	5193	Economy	6000.00
0005432336054	5193	Economy	6000.00
0005435269750	5193	Economy	6000.00
0005434265435	5193	Economy	6000.00
0005435269752	5193	Economy	6000.00
0005434229623	5193	Economy	6000.00
0005434265430	5193	Economy	6000.00
0005434229621	5193	Economy	6000.00
0005432336051	5193	Economy	6000.00
0005435269755	5193	Economy	6000.00
0005434265425	5193	Economy	6000.00
0005435269748	5193	Economy	6000.00
0005434229637	5193	Economy	6000.00
0005434265419	5193	Economy	6000.00
0005434229632	5193	Economy	6000.00
0005434229626	5193	Economy	6000.00
0005433688816	5193	Economy	6000.00
0005434311223	5193	Economy	6000.00
0005434149861	5193	Economy	6000.00
0005435007101	5193	Economy	6000.00
0005435007127	5193	Economy	6000.00
0005435269762	5193	Economy	6000.00
0005433688808	5193	Economy	6000.00
0005434265418	5193	Economy	6000.00
0005435007117	5193	Economy	6000.00
0005434265417	5193	Economy	6000.00
0005435269756	5193	Economy	6000.00
0005434265420	5193	Economy	6000.00
0005434229614	5193	Economy	6000.00
0005432336040	5193	Economy	6000.00
0005435007065	5193	Economy	6000.00
0005434311218	5193	Economy	6000.00
0005434265432	5193	Economy	6000.00
0005435269746	5193	Economy	6000.00
0005435269753	5193	Economy	6000.00
0005435269751	5193	Economy	6000.00
0005434265439	5193	Economy	6000.00
0005434149858	5193	Economy	6000.00
0005435269747	5193	Economy	6000.00
0005434265428	5193	Economy	6000.00
0005434265426	5193	Economy	6000.00
0005435269832	8647	Business	18000.00
0005433784994	8647	Business	18000.00
0005433784932	8647	Business	18000.00
0005433784984	8647	Business	18000.00
0005433784992	8647	Business	18000.00
0005434245021	8647	Business	18000.00
0005435269827	8647	Business	18000.00
0005435269838	8647	Business	18000.00
0005435269831	8647	Business	18000.00
0005433785023	8647	Business	18000.00
0005434245002	8647	Business	18000.00
0005435269830	8647	Business	18000.00
0005433784904	8647	Business	18000.00
0005434245086	8647	Business	18000.00
0005433785176	8647	Business	18000.00
0005433784903	8647	Economy	6600.00
0005433785058	8647	Economy	6600.00
0005434245106	8647	Economy	6600.00
0005432659709	8647	Economy	6000.00
0005434245059	8647	Economy	6000.00
0005434245147	8647	Economy	6000.00
0005432663037	8647	Economy	6000.00
0005434245140	8647	Economy	6000.00
0005433784959	8647	Economy	6000.00
0005434245149	8647	Economy	6000.00
0005433784993	8647	Economy	6000.00
0005435269837	8647	Economy	6000.00
0005433785096	8647	Economy	6000.00
0005434245107	8647	Economy	6000.00
0005435269824	8647	Economy	6000.00
0005434245030	8647	Economy	6000.00
0005433785119	8647	Economy	6000.00
0005434245061	8647	Economy	6000.00
0005434245077	8647	Economy	6000.00
0005434245144	8647	Economy	6000.00
0005433784924	8647	Economy	6000.00
0005433784958	8647	Economy	6000.00
0005435269825	8647	Economy	6000.00
0005433784925	8647	Economy	6000.00
0005434245148	8647	Economy	6000.00
0005434245094	8647	Economy	6000.00
0005434245136	8647	Economy	6000.00
0005434245087	8647	Economy	6000.00
0005435269839	8647	Economy	6000.00
0005432659710	8647	Economy	6000.00
0005434245056	8647	Economy	6000.00
0005435269835	8647	Economy	6000.00
0005434245084	8647	Economy	6000.00
0005434245116	8647	Economy	6000.00
0005433785118	8647	Economy	6000.00
0005434245185	8647	Economy	6000.00
0005434244976	8647	Economy	6000.00
0005434244964	8647	Economy	6000.00
0005435269833	8647	Economy	6000.00
0005434245138	8647	Economy	6600.00
0005434245143	8647	Economy	6000.00
0005433784799	8647	Economy	6000.00
0005433785009	8647	Economy	6600.00
0005433785177	8647	Economy	6000.00
0005434245062	8647	Economy	6000.00
0005433785054	8647	Economy	6000.00
0005433785091	8647	Economy	6000.00
0005434245203	8647	Economy	6000.00
0005435269836	8647	Economy	6000.00
0005433784983	8647	Economy	6000.00
0005433785152	8647	Economy	6000.00
0005435269834	8647	Economy	6000.00
0005434245156	8647	Economy	6000.00
0005434245029	8647	Economy	6000.00
0005433784926	8647	Economy	6000.00
0005433784947	8647	Economy	6000.00
0005433785053	8647	Economy	6000.00
0005434245135	8647	Economy	6000.00
0005432659715	8647	Economy	6000.00
0005433784978	8647	Economy	6000.00
0005435269829	8647	Economy	6000.00
0005434245139	8647	Economy	6000.00
0005434245031	8647	Economy	6000.00
0005434245117	8647	Economy	6000.00
0005435269828	8647	Economy	6000.00
0005433784975	8647	Economy	6000.00
0005435269826	8647	Economy	6000.00
0005433784929	8647	Economy	6000.00
0005433784798	8647	Economy	6000.00
0005432666395	8647	Economy	6000.00
0005434245055	8647	Economy	6000.00
0005433785084	8647	Economy	6000.00
0005434245063	8647	Economy	6000.00
0005433784890	8647	Economy	6000.00
0005433784931	8647	Economy	6000.00
0005434245060	8647	Economy	6000.00
0005432663038	8647	Economy	6000.00
0005433784991	8647	Economy	6000.00
0005433784976	8647	Economy	6000.00
0005434245067	8647	Economy	6000.00
0005433784891	8647	Economy	6000.00
0005433614812	8646	Business	18000.00
0005433614930	8646	Business	18000.00
0005433614768	8646	Business	18000.00
0005433614886	8646	Business	18000.00
0005433614777	8646	Business	18000.00
0005433615094	8646	Business	18000.00
0005433615084	8646	Business	18000.00
0005433614750	8646	Business	18000.00
0005433614721	8646	Economy	6600.00
0005433614444	8646	Economy	6000.00
0005433614727	8646	Economy	6000.00
0005433615008	8646	Economy	6000.00
0005433614822	8646	Economy	6000.00
0005433614908	8646	Economy	6000.00
0005433615011	8646	Economy	6000.00
0005433614838	8646	Economy	6000.00
0005433614936	8646	Economy	6000.00
0005433614716	8646	Economy	6000.00
0005433614659	8646	Economy	6000.00
0005433614839	8646	Economy	6000.00
0005433614639	8646	Economy	6000.00
0005433615192	8646	Economy	6000.00
0005433614607	8646	Economy	6000.00
0005433614932	8646	Economy	6000.00
0005433614742	8646	Economy	6000.00
0005433614765	8646	Economy	6000.00
0005433614899	8646	Economy	6000.00
0005433614900	8646	Economy	6000.00
0005433614724	8646	Economy	6000.00
0005433615193	8646	Economy	6000.00
0005433614726	8646	Economy	6000.00
0005433614891	8646	Economy	6000.00
0005433614720	8646	Economy	6000.00
0005433614853	8646	Economy	6000.00
0005433614814	8646	Economy	6000.00
0005433614731	8646	Economy	6000.00
0005433614980	8646	Economy	6600.00
0005433614710	8646	Economy	6600.00
0005433614852	8646	Economy	6000.00
0005433614758	8646	Economy	6000.00
0005433614732	8646	Economy	6000.00
0005433614715	8646	Economy	6000.00
0005433614769	8646	Economy	6000.00
0005433614837	8646	Economy	6000.00
0005433614830	8646	Economy	6000.00
0005433614608	8646	Economy	6000.00
0005433614595	8646	Economy	6000.00
0005433614906	8646	Economy	6000.00
0005433614759	8646	Economy	6000.00
0005433614921	8646	Economy	6000.00
0005433614625	8646	Economy	6000.00
0005433614841	8646	Economy	6000.00
0005433614973	8646	Economy	6000.00
0005433614988	8646	Economy	6000.00
0005433614741	8646	Economy	6000.00
0005433614840	8646	Economy	6000.00
0005433614743	8646	Economy	6000.00
0005433614823	8646	Economy	6000.00
0005433614824	8646	Economy	6000.00
0005433614887	8646	Economy	6000.00
0005433614540	8646	Economy	6000.00
0005433614815	8646	Economy	6000.00
0005433614794	8646	Economy	6000.00
0005433615026	8646	Economy	6000.00
0005433614755	8646	Economy	6000.00
0005433614709	8646	Economy	6000.00
0005433614793	8646	Economy	6000.00
0005432336167	8640	Business	18000.00
0005432035257	8640	Business	18000.00
0005434229397	8640	Business	18000.00
0005435007302	8640	Business	18000.00
0005432035261	8640	Business	18000.00
0005434265311	8640	Business	18000.00
0005434173532	8640	Business	18000.00
0005434265247	8640	Business	18000.00
0005432035249	8640	Business	18000.00
0005432035272	8640	Business	18000.00
0005434149781	8640	Business	18000.00
0005434265209	8640	Business	18000.00
0005435007303	8640	Business	18000.00
0005435007283	8640	Business	18000.00
0005435007284	8640	Business	18000.00
0005434265220	8640	Business	18000.00
0005435286676	8640	Business	18000.00
0005434149762	8640	Business	18000.00
0005434265182	8640	Business	18000.00
0005434265102	8640	Business	18000.00
0005432336172	8640	Business	18000.00
0005434229364	8640	Business	18000.00
0005432035269	8640	Business	18000.00
0005433815441	8640	Business	18000.00
0005432047592	8640	Business	18000.00
0005435007297	8640	Economy	6600.00
0005434229340	8640	Economy	6600.00
0005434229489	8640	Economy	6600.00
0005435007291	8640	Economy	6600.00
0005432336168	8640	Economy	6600.00
0005434265207	8640	Economy	6600.00
0005434229359	8640	Economy	6000.00
0005434173539	8640	Economy	6000.00
0005434265227	8640	Economy	6000.00
0005432035259	8640	Economy	6000.00
0005434173518	8640	Economy	6000.00
0005434229250	8640	Economy	6000.00
0005434229380	8640	Economy	6000.00
0005433815443	8640	Economy	6000.00
0005434229360	8640	Economy	6000.00
0005435007286	8640	Economy	6000.00
0005434265186	8640	Economy	6000.00
0005434229448	8640	Economy	6000.00
0005432035266	8640	Economy	6000.00
0005434265261	8640	Economy	6000.00
0005435007280	8640	Economy	6000.00
0005435007282	8640	Economy	6000.00
0005434265224	8640	Economy	6000.00
0005435007281	8640	Economy	6000.00
0005434229560	8640	Economy	6000.00
0005433815440	8640	Economy	6000.00
0005434311243	8640	Economy	6000.00
0005432336175	8640	Economy	6000.00
0005434265257	8640	Economy	6000.00
0005434265310	8640	Economy	6000.00
0005432035252	8640	Economy	6000.00
0005433689934	8640	Economy	6000.00
0005434229447	8640	Economy	6000.00
0005435286681	8640	Economy	6000.00
0005435007296	8640	Economy	6000.00
0005432047594	8640	Economy	6000.00
0005432035253	8640	Economy	6000.00
0005434229496	8640	Economy	6000.00
0005435007292	8640	Economy	6000.00
0005432336166	8640	Economy	6000.00
0005432336164	8640	Economy	6000.00
0005432035270	8640	Economy	6000.00
0005434265183	8640	Economy	6000.00
0005433689935	8640	Economy	6000.00
0005435007301	8640	Economy	6000.00
0005433690947	8640	Economy	6000.00
0005434229404	8640	Economy	6000.00
0005432336171	8640	Economy	6000.00
0005434265242	8640	Economy	6000.00
0005432035263	8640	Economy	6000.00
0005432035255	8640	Economy	6000.00
0005434229479	8640	Economy	6000.00
0005433689936	8640	Economy	6000.00
0005434311242	8640	Economy	6000.00
0005434149743	8640	Economy	6000.00
0005434229422	8640	Economy	6000.00
0005435007295	8640	Economy	6000.00
0005435007298	8640	Economy	6000.00
0005434229363	8640	Economy	6000.00
0005432336169	8640	Economy	6000.00
0005434229453	8640	Economy	6600.00
0005434229362	8640	Economy	6600.00
0005435007300	8640	Economy	6600.00
0005434265107	8640	Economy	6600.00
0005432047593	8640	Economy	6600.00
0005434229441	8640	Economy	6000.00
0005432336163	8640	Economy	6000.00
0005434229342	8640	Economy	6000.00
0005434265161	8640	Economy	6600.00
0005434265190	8640	Economy	6000.00
0005432035251	8640	Economy	6000.00
0005434265256	8640	Economy	6000.00
0005433534523	8640	Economy	6000.00
0005435007299	8640	Economy	6000.00
0005433689937	8640	Economy	6000.00
0005432035273	8640	Economy	6000.00
0005435286677	8640	Economy	6000.00
0005435286679	8640	Economy	6000.00
0005432035268	8640	Economy	6000.00
0005434173535	8640	Economy	6000.00
0005435007287	8640	Economy	6000.00
0005432336165	8640	Economy	6000.00
0005432336170	8640	Economy	6000.00
0005432336174	8640	Economy	6000.00
0005434229559	8640	Economy	6000.00
0005435007285	8640	Economy	6000.00
0005434265125	8640	Economy	6000.00
0005432035274	8640	Economy	6000.00
0005435007278	8640	Economy	6000.00
0005432035254	8640	Economy	6000.00
0005434265079	8640	Economy	6000.00
0005432336173	8640	Economy	6000.00
0005434229341	8640	Economy	6000.00
0005432035250	8640	Economy	6000.00
0005432035260	8640	Economy	6000.00
0005432035258	8640	Economy	6000.00
0005435007279	8640	Economy	6000.00
0005433534522	8640	Economy	6000.00
0005434229423	8640	Economy	6000.00
0005434265148	8640	Economy	6000.00
0005434265218	8640	Economy	6000.00
0005434149786	8640	Economy	6000.00
0005434265080	8640	Economy	6000.00
0005435286680	8640	Economy	6000.00
0005435286678	8640	Economy	6000.00
0005434229249	8640	Economy	6000.00
0005432035256	8640	Economy	6000.00
0005435007293	8640	Economy	6000.00
0005435007290	8640	Economy	6000.00
0005434265246	8640	Economy	6000.00
0005435007288	8640	Economy	6000.00
0005434229454	8640	Economy	6000.00
0005432035262	8640	Economy	6000.00
0005434229405	8640	Economy	6000.00
0005435007289	8640	Economy	6000.00
0005433690948	8640	Economy	6000.00
0005434149787	8640	Economy	6000.00
0005434229393	8640	Economy	6000.00
0005432035264	8640	Economy	6000.00
0005434229361	8640	Economy	6000.00
0005434265208	8640	Economy	6000.00
0005434229394	8640	Economy	6000.00
0005434173531	8640	Economy	6000.00
0005433815442	8640	Economy	6000.00
0005434265108	8640	Economy	6000.00
0005432035271	8640	Economy	6000.00
0005435007294	8640	Economy	6000.00
0005434265245	8640	Economy	6000.00
0005432035265	8640	Economy	6000.00
0005434229379	8640	Economy	6000.00
0005432035267	8640	Economy	6000.00
0005433202530	12583	Economy	16200.00
0005434639345	12583	Economy	16200.00
0005434639486	12583	Economy	16200.00
0005433202533	12583	Economy	16200.00
0005434639445	12583	Economy	14800.00
0005434639272	12583	Economy	14800.00
0005434639341	12583	Economy	14800.00
0005434639344	12583	Economy	14800.00
0005434639404	12583	Economy	14800.00
0005434639438	12583	Economy	14800.00
0005433202537	12583	Economy	14800.00
0005434639343	12583	Economy	14800.00
0005434639467	12583	Economy	14800.00
0005433202525	12583	Economy	14800.00
0005434639468	12583	Economy	14800.00
0005434639293	12583	Economy	14800.00
0005434639469	12583	Economy	14800.00
0005434639273	12583	Economy	14800.00
0005434639444	12583	Economy	14800.00
0005433202536	12583	Economy	14800.00
0005434639373	12583	Economy	14800.00
0005434639362	12583	Economy	14800.00
0005434639292	12583	Economy	14800.00
0005433202526	12583	Economy	14800.00
0005433202539	12583	Economy	14800.00
0005434639403	12583	Economy	14800.00
0005433202538	12583	Economy	14800.00
0005433202524	12583	Economy	14800.00
0005433202534	12583	Economy	14800.00
0005434639295	12583	Economy	14800.00
0005433202528	12583	Economy	14800.00
0005434639470	12583	Economy	14800.00
0005434639297	12583	Economy	14800.00
0005433202535	12583	Economy	14800.00
0005433202532	12583	Economy	14800.00
0005434639364	12583	Economy	14800.00
0005434639429	12583	Economy	14800.00
0005434639363	12583	Economy	14800.00
0005434639374	12583	Economy	14800.00
0005434639491	12583	Economy	14800.00
0005434639437	12583	Economy	14800.00
0005434639351	12583	Economy	14800.00
0005434639352	12583	Economy	14800.00
0005434639402	12583	Economy	14800.00
0005433202531	12583	Economy	14800.00
0005433202527	12583	Economy	14800.00
0005433202529	12583	Economy	14800.00
0005433202317	23354	Economy	16200.00
0005432290665	23354	Economy	16200.00
0005434639582	23354	Economy	16200.00
0005433202323	23354	Economy	14800.00
0005433202316	23354	Economy	14800.00
0005433202408	23354	Economy	14800.00
0005434639576	23354	Economy	14800.00
0005434639587	23354	Economy	14800.00
0005434639579	23354	Economy	14800.00
0005434639574	23354	Economy	14800.00
0005433202386	23354	Economy	14800.00
0005434639583	23354	Economy	14800.00
0005434639581	23354	Economy	14800.00
0005434639597	23354	Economy	14800.00
0005434639575	23354	Economy	14800.00
0005432290666	23354	Economy	14800.00
0005433202407	23354	Economy	14800.00
0005434639577	23354	Economy	14800.00
0005434639578	23354	Economy	14800.00
0005434639585	23354	Economy	14800.00
0005434639596	23354	Economy	14800.00
0005434639584	23354	Economy	14800.00
0005434639586	23354	Economy	14800.00
0005434639580	23354	Economy	14800.00
0005433202419	23354	Economy	14800.00
0005434639593	23354	Economy	14800.00
0005434639595	23354	Economy	14800.00
0005433202357	23354	Economy	14800.00
0005434639589	23354	Economy	14800.00
0005434639588	23354	Economy	14800.00
0005432290664	23354	Economy	14800.00
0005433202342	23354	Economy	14800.00
0005434639594	23354	Economy	14800.00
0005434639590	23354	Economy	14800.00
0005433202349	23354	Economy	14800.00
0005434639573	23354	Economy	14800.00
0005434639598	23354	Economy	14800.00
0005433202332	23354	Economy	14800.00
0005434639591	23354	Economy	14800.00
0005434639592	23354	Economy	14800.00
0005432383246	21085	Business	18900.00
0005432328833	21085	Business	18900.00
0005432328812	21085	Business	18900.00
0005432328853	21085	Business	18900.00
0005432328726	21085	Business	18900.00
0005432328941	21085	Business	18900.00
0005432328691	21085	Business	18900.00
0005432383215	21085	Business	18900.00
0005432383108	21085	Business	18900.00
0005432383204	21085	Business	18900.00
0005432328558	21085	Business	18900.00
0005432328839	21085	Business	18900.00
0005432328557	21085	Economy	6300.00
0005432054338	21085	Economy	6300.00
0005432383319	21085	Economy	6300.00
0005432328701	21085	Economy	6300.00
0005432383249	21085	Economy	6300.00
0005432328515	21085	Economy	6300.00
0005432383328	21085	Economy	6300.00
0005432383182	21085	Economy	6300.00
0005432383196	21085	Economy	6300.00
0005432054340	21085	Economy	6900.00
0005432328894	21085	Economy	6900.00
0005432328679	21085	Economy	6900.00
0005432383426	21085	Economy	6900.00
0005432383195	21085	Economy	6300.00
0005432328849	21085	Economy	6300.00
0005432328788	21085	Economy	6300.00
0005432054339	21085	Economy	6300.00
0005432383172	21085	Economy	6300.00
0005432328695	21085	Economy	6300.00
0005432328876	21085	Economy	6300.00
0005432383251	21085	Economy	6300.00
0005432383259	21085	Economy	6300.00
0005432383175	21085	Economy	6300.00
0005432328541	21085	Economy	6300.00
0005432328687	21085	Economy	6300.00
0005432328621	21085	Economy	6300.00
0005432328725	21085	Economy	6300.00
0005432054336	21085	Economy	6300.00
0005432383205	21085	Economy	6300.00
0005432383244	21085	Economy	6300.00
0005432383363	21085	Economy	6300.00
0005432383214	21085	Economy	6300.00
0005432383296	21085	Economy	6300.00
0005432328770	21085	Economy	6300.00
0005432383383	21085	Economy	6300.00
0005432383294	21085	Economy	6300.00
0005432383144	21085	Economy	6300.00
0005432383145	21085	Economy	6300.00
0005432383272	21085	Economy	6300.00
0005432328740	21085	Economy	6300.00
0005432328540	21085	Economy	6300.00
0005432328875	21085	Economy	6300.00
0005432328834	21085	Economy	6300.00
0005432328821	21085	Economy	6300.00
0005432328759	21085	Economy	6300.00
0005432328931	21085	Economy	6300.00
0005432383166	21085	Economy	6300.00
0005432383176	21085	Economy	6300.00
0005432328514	21085	Economy	6300.00
0005432383258	21085	Economy	6300.00
0005432383250	21085	Economy	6300.00
0005432383305	21085	Economy	6300.00
0005432328888	21085	Economy	6300.00
0005432054337	21085	Economy	6300.00
0005432328747	21085	Economy	6300.00
0005432383339	21085	Economy	6300.00
0005432383106	21085	Economy	6300.00
0005432328813	21085	Economy	6300.00
0005432328811	21085	Economy	6300.00
0005432383231	21085	Economy	6300.00
0005432383165	21085	Economy	6300.00
0005432383271	21085	Economy	6300.00
0005432383341	21085	Economy	6300.00
0005432383184	21085	Economy	6300.00
0005432328916	21085	Economy	6300.00
0005432328915	21085	Economy	6300.00
0005432383441	21085	Economy	6300.00
0005432383047	21085	Economy	6300.00
0005432328773	21085	Economy	6300.00
0005432383263	21085	Economy	6300.00
0005432383181	21085	Economy	6300.00
0005432328787	21085	Economy	6300.00
0005432383295	21085	Economy	6300.00
0005432383177	21085	Economy	6300.00
0005432328840	21085	Economy	6300.00
0005432328854	21085	Economy	6300.00
0005432383427	21085	Economy	6300.00
0005432287241	31279	Business	18900.00
0005432329199	31279	Business	18900.00
0005432329167	31279	Business	18900.00
0005432383583	31279	Business	18900.00
0005432383571	31279	Business	18900.00
0005432383603	31279	Business	18900.00
0005432383584	31279	Business	18900.00
0005432383591	31279	Business	18900.00
0005432329189	31279	Business	18900.00
0005432383594	31279	Business	18900.00
0005432383573	31279	Business	18900.00
0005432383592	31279	Business	18900.00
0005432329173	31279	Economy	6300.00
0005432329159	31279	Economy	6300.00
0005432329175	31279	Economy	6300.00
0005432383587	31279	Economy	6300.00
0005432287243	31279	Economy	6300.00
0005432383598	31279	Economy	6300.00
0005432329198	31279	Economy	6300.00
0005432329197	31279	Economy	6300.00
0005432383574	31279	Economy	6300.00
0005432383605	31279	Economy	6300.00
0005432287240	31279	Economy	6900.00
0005432329162	31279	Economy	6900.00
0005432329194	31279	Economy	6900.00
0005432383602	31279	Economy	6900.00
0005432287242	31279	Economy	6900.00
0005432329164	31279	Economy	6300.00
0005432329186	31279	Economy	6300.00
0005432383590	31279	Economy	6300.00
0005432383599	31279	Economy	6300.00
0005432329205	31279	Economy	6300.00
0005432329190	31279	Economy	6300.00
0005432329187	31279	Economy	6300.00
0005432383577	31279	Economy	6300.00
0005432329188	31279	Economy	6300.00
0005432329200	31279	Economy	6300.00
0005432329181	31279	Economy	6300.00
0005432383572	31279	Economy	6300.00
0005432383601	31279	Economy	6300.00
0005432383600	31279	Economy	6300.00
0005432329165	31279	Economy	6300.00
0005432383597	31279	Economy	6300.00
0005432383579	31279	Economy	6300.00
0005432383588	31279	Economy	6300.00
0005432329171	31279	Economy	6300.00
0005432329202	31279	Economy	6300.00
0005432383580	31279	Economy	6300.00
0005432383581	31279	Economy	6300.00
0005432329195	31279	Economy	6300.00
0005432383593	31279	Economy	6300.00
0005432329166	31279	Economy	6300.00
0005432383608	31279	Economy	6300.00
0005432329176	31279	Economy	6300.00
0005432383582	31279	Economy	6300.00
0005432383585	31279	Economy	6300.00
0005432329183	31279	Economy	6300.00
0005432329174	31279	Economy	6300.00
0005432329180	31279	Economy	6300.00
0005432329177	31279	Economy	6300.00
0005432287244	31279	Economy	6300.00
0005432383595	31279	Economy	6300.00
0005432329178	31279	Economy	6300.00
0005432329184	31279	Economy	6300.00
0005432383596	31279	Economy	6300.00
0005432329172	31279	Economy	6300.00
0005432329161	31279	Economy	6300.00
0005432329169	31279	Economy	6300.00
0005432383578	31279	Economy	6300.00
0005432329163	31279	Economy	6300.00
0005432383607	31279	Economy	6300.00
0005432383604	31279	Economy	6300.00
0005432329196	31279	Economy	6300.00
0005432383576	31279	Economy	6300.00
0005432329179	31279	Economy	6300.00
0005432329185	31279	Economy	6300.00
0005432329168	31279	Economy	6300.00
0005432329193	31279	Economy	6300.00
0005432383606	31279	Economy	6300.00
0005432329182	31279	Economy	6300.00
0005432383575	31279	Economy	6300.00
0005432329192	31279	Economy	6300.00
0005432383589	31279	Economy	6300.00
0005432329191	31279	Economy	6300.00
0005432329201	31279	Economy	6300.00
0005432329160	31279	Economy	6300.00
0005432329204	31279	Economy	6300.00
0005432329203	31279	Economy	6300.00
0005432383586	31279	Economy	6300.00
0005432329170	31279	Economy	6300.00
0005433642489	2472	Business	89600.00
0005433642519	2472	Business	89600.00
0005433642491	2472	Business	89600.00
0005433642511	2472	Business	89600.00
0005432953937	2472	Business	89600.00
0005432953878	2472	Business	89600.00
0005432953927	2472	Business	89600.00
0005432953941	2472	Business	89600.00
0005433642510	2472	Economy	29900.00
0005432953942	2472	Economy	29900.00
0005432953952	2472	Economy	29900.00
0005433642514	2472	Economy	29900.00
0005432953987	2472	Economy	29900.00
0005433642485	2472	Economy	29900.00
0005432953907	2472	Economy	29900.00
0005433642499	2472	Economy	29900.00
0005432953960	2472	Economy	32800.00
0005433642494	2472	Economy	32800.00
0005433642502	2472	Economy	32800.00
0005433642478	2472	Economy	29900.00
0005432953948	2472	Economy	29900.00
0005433642512	2472	Economy	29900.00
0005433642475	2472	Economy	29900.00
0005433642496	2472	Economy	29900.00
0005432953965	2472	Economy	29900.00
0005433642490	2472	Economy	29900.00
0005433642474	2472	Economy	29900.00
0005432953951	2472	Economy	29900.00
0005433642498	2472	Economy	29900.00
0005433642492	2472	Economy	29900.00
0005433642493	2472	Economy	29900.00
0005433642482	2472	Economy	29900.00
0005433642488	2472	Economy	29900.00
0005432953938	2472	Economy	29900.00
0005433642513	2472	Economy	29900.00
0005433642515	2472	Economy	29900.00
0005432953917	2472	Economy	29900.00
0005432953986	2472	Economy	29900.00
0005432953953	2472	Economy	29900.00
0005432953966	2472	Economy	29900.00
0005432953950	2472	Economy	29900.00
0005433642497	2472	Economy	29900.00
0005432953920	2472	Economy	29900.00
0005433642503	2472	Economy	29900.00
0005433642505	2472	Economy	29900.00
0005433642486	2472	Economy	29900.00
0005433642483	2472	Economy	29900.00
0005432953949	2472	Economy	29900.00
0005432953916	2472	Economy	29900.00
0005433642479	2472	Economy	29900.00
0005432953934	2472	Economy	29900.00
0005433642481	2472	Economy	29900.00
0005433642516	2472	Economy	29900.00
0005433642506	2472	Economy	29900.00
0005433642477	2472	Economy	29900.00
0005432953908	2472	Economy	29900.00
0005432953955	2472	Economy	29900.00
0005432953961	2472	Economy	29900.00
0005433642484	2472	Economy	29900.00
0005433642507	2472	Economy	29900.00
0005433642500	2472	Economy	29900.00
0005433642495	2472	Economy	29900.00
0005433642517	2472	Economy	29900.00
0005433642508	2472	Economy	29900.00
0005433642480	2472	Economy	29900.00
0005433642518	2472	Economy	29900.00
0005433642509	2472	Economy	29900.00
0005432953928	2472	Economy	29900.00
0005433642501	2472	Economy	29900.00
0005433642504	2472	Economy	29900.00
0005433642476	2472	Economy	29900.00
0005433642487	2472	Economy	29900.00
0005432424915	13312	Business	12700.00
0005432424922	13312	Business	12700.00
0005432424932	13312	Business	12700.00
0005432424946	13312	Business	12700.00
0005432424930	13312	Economy	4200.00
0005432424931	13312	Economy	4200.00
0005432424949	13312	Economy	4200.00
0005432424956	13312	Economy	4200.00
0005432424950	13312	Economy	4700.00
0005432424957	13312	Economy	4700.00
0005432424940	13312	Economy	4700.00
0005432424951	13312	Economy	4200.00
0005432424936	13312	Economy	4200.00
0005432424918	13312	Economy	4200.00
0005432424924	13312	Economy	4200.00
0005432424948	13312	Economy	4200.00
0005432424960	13312	Economy	4200.00
0005432424943	13312	Economy	4200.00
0005432424953	13312	Economy	4200.00
0005432424958	13312	Economy	4200.00
0005432424944	13312	Economy	4200.00
0005432424920	13312	Economy	4200.00
0005432424941	13312	Economy	4200.00
0005432424935	13312	Economy	4200.00
0005432424954	13312	Economy	4200.00
0005432424927	13312	Economy	4200.00
0005432424917	13312	Economy	4200.00
0005432424926	13312	Economy	4200.00
0005432424942	13312	Economy	4200.00
0005432424947	13312	Economy	4200.00
0005432424921	13312	Economy	4200.00
0005432424939	13312	Economy	4200.00
0005432424952	13312	Economy	4200.00
0005432424916	13312	Economy	4200.00
0005432424934	13312	Economy	4200.00
0005432424938	13312	Economy	4200.00
0005432424961	13312	Economy	4200.00
0005432424923	13312	Economy	4200.00
0005432424919	13312	Economy	4200.00
0005432424928	13312	Economy	4200.00
0005432424937	13312	Economy	4200.00
0005432424945	13312	Economy	4200.00
0005432424933	13312	Economy	4200.00
0005432424929	13312	Economy	4200.00
0005432424955	13312	Economy	4200.00
0005432424959	13312	Economy	4200.00
0005432424925	13312	Economy	4200.00
0005432424486	30702	Business	12700.00
0005432424495	30702	Business	12700.00
0005432424523	30702	Business	12700.00
0005432424493	30702	Business	12700.00
0005432424475	30702	Business	12700.00
0005432424536	30702	Business	12700.00
0005432424450	30702	Economy	4200.00
0005432424570	30702	Economy	4200.00
0005432424566	30702	Economy	4200.00
0005432424499	30702	Economy	4200.00
0005432424496	30702	Economy	4200.00
0005432424534	30702	Economy	4700.00
0005432424542	30702	Economy	4700.00
0005432424468	30702	Economy	4700.00
0005432424423	30702	Economy	4700.00
0005432424430	30702	Economy	4700.00
0005432424567	30702	Economy	4200.00
0005432424528	30702	Economy	4200.00
0005432424514	30702	Economy	4200.00
0005432424443	30702	Economy	4200.00
0005432424444	30702	Economy	4200.00
0005432424485	30702	Economy	4200.00
0005432424476	30702	Economy	4200.00
0005432424457	30702	Economy	4200.00
0005432424386	30702	Economy	4200.00
0005432424541	30702	Economy	4200.00
0005432424498	30702	Economy	4200.00
0005432424488	30702	Economy	4200.00
0005432424512	30702	Economy	4200.00
0005432424482	30702	Economy	4200.00
0005432424527	30702	Economy	4200.00
0005432424529	30702	Economy	4200.00
0005432424504	30702	Economy	4200.00
0005432424449	30702	Economy	4200.00
0005432424544	30702	Economy	4200.00
0005432424555	30702	Economy	4200.00
0005432424458	30702	Economy	4200.00
0005432424466	30702	Economy	4200.00
0005432424568	30702	Economy	4200.00
0005432424441	30702	Economy	4200.00
0005432424197	30702	Economy	4200.00
0005432424494	30702	Economy	4200.00
0005432424543	30702	Economy	4200.00
0005432424442	30702	Economy	4200.00
0005432424480	30702	Economy	4200.00
0005432424492	30702	Economy	4200.00
0005432424552	30702	Economy	4200.00
0005432424489	30702	Economy	4200.00
0005432424569	30702	Economy	4200.00
0005432424363	30702	Economy	4200.00
0005432424520	30702	Economy	4200.00
0005432424362	30702	Economy	4200.00
0005432424439	30702	Economy	4200.00
0005432817794	9594	Business	32600.00
0005432901637	9594	Business	32600.00
0005432822286	9594	Business	32600.00
0005432817791	9594	Business	32600.00
0005432822288	9594	Business	32600.00
0005432901624	9594	Business	32600.00
0005432901663	9594	Business	32600.00
0005432822289	9594	Business	32600.00
0005432817798	9594	Business	32600.00
0005432817817	9594	Business	32600.00
0005432901703	9594	Business	32600.00
0005432817796	9594	Economy	10900.00
0005432901615	9594	Economy	10900.00
0005432901652	9594	Economy	10900.00
0005434157490	9594	Economy	10900.00
0005434157506	9594	Economy	10900.00
0005432817815	9594	Economy	10900.00
0005434186193	9594	Economy	10900.00
0005434186215	9594	Economy	10900.00
0005432901636	9594	Economy	10900.00
0005432817804	9594	Economy	11900.00
0005432901682	9594	Economy	11900.00
0005432817788	9594	Economy	11900.00
0005434157505	9594	Economy	11900.00
0005434157489	9594	Economy	10900.00
0005434157500	9594	Economy	10900.00
0005432817799	9594	Economy	10900.00
0005432901664	9594	Economy	10900.00
0005432289024	9594	Economy	10900.00
0005434157518	9594	Economy	10900.00
0005432822290	9594	Economy	10900.00
0005432817795	9594	Economy	10900.00
0005432817811	9594	Economy	10900.00
0005432817818	9594	Economy	10900.00
0005432822287	9594	Economy	10900.00
0005432817803	9594	Economy	10900.00
0005432901577	9594	Economy	10900.00
0005432817802	9594	Economy	10900.00
0005432817807	9594	Economy	10900.00
0005432901681	9594	Economy	10900.00
0005432817816	9594	Economy	10900.00
0005432289022	9594	Economy	10900.00
0005432817805	9594	Economy	10900.00
0005432901578	9594	Economy	10900.00
0005432817790	9594	Economy	10900.00
0005432817793	9594	Economy	10900.00
0005432901603	9594	Economy	10900.00
0005434157479	9594	Economy	10900.00
0005432901635	9594	Economy	10900.00
0005432817813	9594	Economy	10900.00
0005432901670	9594	Economy	10900.00
0005432817789	9594	Economy	10900.00
0005434157519	9594	Economy	10900.00
0005432822292	9594	Economy	10900.00
0005432817797	9594	Economy	10900.00
0005434186220	9594	Economy	10900.00
0005432901666	9594	Economy	10900.00
0005432817792	9594	Economy	10900.00
0005432901569	9594	Economy	10900.00
0005432901628	9594	Economy	10900.00
0005432289023	9594	Economy	10900.00
0005432901602	9594	Economy	10900.00
0005434157473	9594	Economy	10900.00
0005432822291	9594	Economy	10900.00
0005432822293	9594	Economy	10900.00
0005432817806	9594	Economy	10900.00
0005434157499	9594	Economy	10900.00
0005432901683	9594	Economy	10900.00
0005432901645	9594	Economy	10900.00
0005432817809	9594	Economy	10900.00
0005432817808	9594	Economy	10900.00
0005432817800	9594	Economy	10900.00
0005434448354	9594	Economy	10900.00
0005432817814	9594	Economy	10900.00
0005432817810	9594	Economy	10900.00
0005432817801	9594	Economy	10900.00
0005434448355	9594	Economy	10900.00
0005432817812	9594	Economy	10900.00
0005432817603	28986	Business	32600.00
0005434157565	28986	Business	32600.00
0005432817446	28986	Business	32600.00
0005432817543	28986	Business	32600.00
0005432822215	28986	Business	32600.00
0005432817593	28986	Business	32600.00
0005434186229	28986	Business	32600.00
0005432822229	28986	Business	32600.00
0005432817576	28986	Business	32600.00
0005432817547	28986	Business	32600.00
0005432817575	28986	Business	32600.00
0005432817493	28986	Economy	10900.00
0005432901815	28986	Economy	10900.00
0005432901804	28986	Economy	10900.00
0005434157563	28986	Economy	10900.00
0005432817560	28986	Economy	10900.00
0005434157568	28986	Economy	10900.00
0005432817594	28986	Economy	11900.00
0005434157569	28986	Economy	11900.00
0005432817490	28986	Economy	11900.00
0005432817574	28986	Economy	10900.00
0005432901807	28986	Economy	10900.00
0005432901814	28986	Economy	10900.00
0005432901806	28986	Economy	10900.00
0005432901813	28986	Economy	10900.00
0005434157564	28986	Economy	10900.00
0005432822230	28986	Economy	10900.00
0005432901805	28986	Economy	10900.00
0005432901803	28986	Economy	10900.00
0005432817750	28986	Economy	10900.00
0005432901811	28986	Economy	10900.00
0005432817563	28986	Economy	10900.00
0005434157567	28986	Economy	10900.00
0005432817559	28986	Economy	10900.00
0005432822237	28986	Economy	10900.00
0005432901802	28986	Economy	10900.00
0005432901809	28986	Economy	10900.00
0005432817519	28986	Economy	10900.00
0005434157570	28986	Economy	10900.00
0005432817668	28986	Economy	10900.00
0005434157566	28986	Economy	10900.00
0005432822216	28986	Economy	10900.00
0005432817749	28986	Economy	10900.00
0005432901808	28986	Economy	10900.00
0005432817520	28986	Economy	10900.00
0005434157571	28986	Economy	10900.00
0005432817552	28986	Economy	10900.00
0005432901799	28986	Economy	10900.00
0005432817666	28986	Economy	10900.00
0005432901800	28986	Economy	10900.00
0005432901810	28986	Economy	10900.00
0005432822207	28986	Economy	10900.00
0005432817521	28986	Economy	10900.00
0005432901798	28986	Economy	10900.00
0005432901812	28986	Economy	10900.00
0005432817667	28986	Economy	10900.00
0005432817573	28986	Economy	10900.00
0005432817627	28986	Economy	10900.00
0005432901801	28986	Economy	10900.00
0005432817546	28986	Economy	10900.00
0005432817494	28986	Economy	10900.00
0005434186230	28986	Economy	10900.00
0005432817447	28986	Economy	10900.00
0005432613906	15092	Economy	11000.00
0005432611754	15092	Economy	11000.00
0005432611753	15092	Economy	11000.00
0005432613909	15092	Economy	11000.00
0005432613908	15092	Economy	11000.00
0005435841097	15092	Economy	11000.00
0005432613907	15092	Economy	11000.00
0005432611752	15092	Economy	11000.00
0005432611755	15092	Economy	11000.00
0005432611717	31569	Economy	11000.00
0005435841830	31569	Economy	11000.00
0005432611718	31569	Economy	11000.00
0005432611721	31569	Economy	11000.00
0005432611733	31569	Economy	11000.00
0005432607567	31569	Economy	11000.00
0005432607572	31569	Economy	11000.00
0005432611731	31569	Economy	11000.00
0005432948608	11854	Business	105900.00
0005433569662	11854	Business	105900.00
0005433569671	11854	Business	105900.00
0005432948490	11854	Business	105900.00
0005433569679	11854	Business	105900.00
0005433569664	11854	Business	105900.00
0005433569670	11854	Business	105900.00
0005433569655	11854	Business	105900.00
0005432948638	11854	Business	105900.00
0005433569680	11854	Business	105900.00
0005433569674	11854	Business	105900.00
0005433569653	11854	Business	105900.00
0005432948376	11854	Business	105900.00
0005433569704	11854	Business	105900.00
0005433569667	11854	Business	105900.00
0005432948605	11854	Business	105900.00
0005432948562	11854	Economy	35300.00
0005433569650	11854	Economy	35300.00
0005432948496	11854	Economy	35300.00
0005433569698	11854	Economy	35300.00
0005433569675	11854	Economy	35300.00
0005432948525	11854	Economy	35300.00
0005432948266	11854	Economy	35300.00
0005433569661	11854	Economy	35300.00
0005433569703	11854	Economy	35300.00
0005432948535	11854	Economy	35300.00
0005432948462	11854	Economy	35300.00
0005433569659	11854	Economy	35300.00
0005433569699	11854	Economy	38800.00
0005433569678	11854	Economy	38800.00
0005433569702	11854	Economy	38800.00
0005432948549	11854	Economy	38800.00
0005432948561	11854	Economy	35300.00
0005432948497	11854	Economy	35300.00
0005432948489	11854	Economy	35300.00
0005432948457	11854	Economy	35300.00
0005432948591	11854	Economy	35300.00
0005432948522	11854	Economy	35300.00
0005433569668	11854	Economy	35300.00
0005432948537	11854	Economy	35300.00
0005432948554	11854	Economy	35300.00
0005433569673	11854	Economy	35300.00
0005433569685	11854	Economy	35300.00
0005433569669	11854	Economy	35300.00
0005432948553	11854	Economy	35300.00
0005432948612	11854	Economy	35300.00
0005432948516	11854	Economy	35300.00
0005432948416	11854	Economy	35300.00
0005433569693	11854	Economy	35300.00
0005433569663	11854	Economy	35300.00
0005433569649	11854	Economy	35300.00
0005433569687	11854	Economy	35300.00
0005433569706	11854	Economy	35300.00
0005433569681	11854	Economy	35300.00
0005432948526	11854	Economy	35300.00
0005433569697	11854	Economy	35300.00
0005433569682	11854	Economy	35300.00
0005432948505	11854	Economy	35300.00
0005433569658	11854	Economy	35300.00
0005432948630	11854	Economy	35300.00
0005433569683	11854	Economy	35300.00
0005432948521	11854	Economy	35300.00
0005432948538	11854	Economy	35300.00
0005433569651	11854	Economy	35300.00
0005432948494	11854	Economy	35300.00
0005433569684	11854	Economy	35300.00
0005433569695	11854	Economy	35300.00
0005432948366	11854	Economy	35300.00
0005433569686	11854	Economy	35300.00
0005432948639	11854	Economy	35300.00
0005432948267	11854	Economy	35300.00
0005433569654	11854	Economy	35300.00
0005433569688	11854	Economy	35300.00
0005432948396	11854	Economy	35300.00
0005432948590	11854	Economy	35300.00
0005433569705	11854	Economy	35300.00
0005433569665	11854	Economy	35300.00
0005433569700	11854	Economy	35300.00
0005432948555	11854	Economy	35300.00
0005433569694	11854	Economy	35300.00
0005433569652	11854	Economy	35300.00
0005433569666	11854	Economy	35300.00
0005433569701	11854	Economy	35300.00
0005432948405	11854	Economy	35300.00
0005432948466	11854	Economy	35300.00
0005432948637	11854	Economy	35300.00
0005432948435	11854	Economy	35300.00
0005433569696	11854	Economy	35300.00
0005433569677	11854	Economy	35300.00
0005433569689	11854	Economy	35300.00
0005433569690	11854	Economy	35300.00
0005432948597	11854	Economy	35300.00
0005432948465	11854	Economy	35300.00
0005432948571	11854	Economy	35300.00
0005432948470	11854	Economy	35300.00
0005433569672	11854	Economy	35300.00
0005433569660	11854	Economy	35300.00
0005433569692	11854	Economy	35300.00
0005433569691	11854	Economy	35300.00
0005432948506	11854	Economy	35300.00
0005433569656	11854	Economy	35300.00
0005433569676	11854	Economy	35300.00
0005433569657	11854	Economy	35300.00
0005432948952	25319	Business	105900.00
0005432948954	25319	Business	105900.00
0005433569195	25319	Business	105900.00
0005433569176	25319	Business	105900.00
0005433568937	25319	Business	105900.00
0005432948934	25319	Business	105900.00
0005432948940	25319	Business	105900.00
0005433569256	25319	Business	105900.00
0005433569069	25319	Business	105900.00
0005433568998	25319	Business	105900.00
0005432948955	25319	Business	105900.00
0005432948962	25319	Business	105900.00
0005432948968	25319	Business	105900.00
0005433569288	25319	Business	105900.00
0005432948963	25319	Business	105900.00
0005433569236	25319	Business	105900.00
0005432948950	25319	Business	105900.00
0005433568995	25319	Business	105900.00
0005433569171	25319	Economy	35300.00
0005432948964	25319	Economy	35300.00
0005433569239	25319	Economy	35300.00
0005432948931	25319	Economy	35300.00
0005433569220	25319	Economy	35300.00
0005433569095	25319	Economy	35300.00
0005433568802	25319	Economy	35300.00
0005433569137	25319	Economy	35300.00
0005433569283	25319	Economy	35300.00
0005433569050	25319	Economy	35300.00
0005432948969	25319	Economy	35300.00
0005433569073	25319	Economy	35300.00
0005432948959	25319	Economy	38800.00
0005432948953	25319	Economy	38800.00
0005433568936	25319	Economy	38800.00
0005432948965	25319	Economy	38800.00
0005432948938	25319	Economy	35300.00
0005433569286	25319	Economy	35300.00
0005432948957	25319	Economy	35300.00
0005433569287	25319	Economy	35300.00
0005433569087	25319	Economy	35300.00
0005432948937	25319	Economy	35300.00
0005433569257	25319	Economy	35300.00
0005432948972	25319	Economy	35300.00
0005432948958	25319	Economy	35300.00
0005433569127	25319	Economy	35300.00
0005432948948	25319	Economy	35300.00
0005432948967	25319	Economy	35300.00
0005433569221	25319	Economy	35300.00
0005433569064	25319	Economy	35300.00
0005433569296	25319	Economy	35300.00
0005432948945	25319	Economy	35300.00
0005433569139	25319	Economy	35300.00
0005432948971	25319	Economy	35300.00
0005433569285	25319	Economy	35300.00
0005432948961	25319	Economy	35300.00
0005433569136	25319	Economy	35300.00
0005433569295	25319	Economy	35300.00
0005433569025	25319	Economy	35300.00
0005433569248	25319	Economy	35300.00
0005433568692	25319	Economy	35300.00
0005433569165	25319	Economy	35300.00
0005432948947	25319	Economy	35300.00
0005433569194	25319	Economy	35300.00
0005433569084	25319	Economy	35300.00
0005432948932	25319	Economy	35300.00
0005433569219	25319	Economy	35300.00
0005432948973	25319	Economy	35300.00
0005432948943	25319	Economy	35300.00
0005432948949	25319	Economy	35300.00
0005432948946	25319	Economy	35300.00
0005432948966	25319	Economy	35300.00
0005433569080	25319	Economy	35300.00
0005433569297	25319	Economy	35300.00
0005433569032	25319	Economy	35300.00
0005433568935	25319	Economy	35300.00
0005432948936	25319	Economy	35300.00
0005432948951	25319	Economy	35300.00
0005433569168	25319	Economy	35300.00
0005433569074	25319	Economy	35300.00
0005432948941	25319	Economy	35300.00
0005432948970	25319	Economy	35300.00
0005432948935	25319	Economy	35300.00
0005433569169	25319	Economy	35300.00
0005433569231	25319	Economy	35300.00
0005433569086	25319	Economy	35300.00
0005432948960	25319	Economy	35300.00
0005433569249	25319	Economy	35300.00
0005433569203	25319	Economy	35300.00
0005433569029	25319	Economy	35300.00
0005432948939	25319	Economy	35300.00
0005433568958	25319	Economy	35300.00
0005433569232	25319	Economy	35300.00
0005433569281	25319	Economy	35300.00
0005433569240	25319	Economy	35300.00
0005432948933	25319	Economy	35300.00
0005433568972	25319	Economy	35300.00
0005433569049	25319	Economy	35300.00
0005433569282	25319	Economy	35300.00
0005433568873	25319	Economy	35300.00
0005432948942	25319	Economy	35300.00
0005432948956	25319	Economy	35300.00
0005433569250	25319	Economy	35300.00
0005432948944	25319	Economy	35300.00
0005433569264	25319	Economy	35300.00
0005433569265	25319	Economy	35300.00
0005433569202	25319	Economy	35300.00
0005433812898	14464	Business	117400.00
0005433812905	14464	Business	117400.00
0005434026725	14464	Business	117400.00
0005433812908	14464	Business	117400.00
0005433808366	14464	Business	117400.00
0005433808382	14464	Business	117400.00
0005434026727	14464	Business	117400.00
0005433812915	14464	Business	117400.00
0005432430902	14464	Economy	39100.00
0005433808376	14464	Economy	39100.00
0005433808348	14464	Economy	39100.00
0005432430904	14464	Economy	43000.00
0005433808349	14464	Economy	43000.00
0005433808378	14464	Economy	39100.00
0005433812894	14464	Economy	39100.00
0005433808377	14464	Economy	39100.00
0005432430898	14464	Economy	39100.00
0005434026726	14464	Economy	39100.00
0005434026724	14464	Economy	39100.00
0005434026728	14464	Economy	39100.00
0005432430905	14464	Economy	39100.00
0005433812897	14464	Economy	39100.00
0005433812896	14464	Economy	39100.00
0005433808368	14464	Economy	39100.00
0005432430903	14464	Economy	39100.00
0005433812909	14464	Economy	39100.00
0005432430906	14464	Economy	39100.00
0005433812907	14464	Economy	39100.00
0005432430899	14464	Economy	39100.00
0005432430907	14464	Economy	39100.00
0005433808365	14464	Economy	39100.00
0005433808370	14464	Economy	39100.00
0005432430901	14464	Economy	39100.00
0005432430900	14464	Economy	39100.00
0005433812895	14464	Economy	39100.00
0005432430908	14464	Economy	39100.00
0005433808417	30819	Business	117400.00
0005433812924	30819	Business	117400.00
0005434026698	30819	Business	117400.00
0005433812917	30819	Business	117400.00
0005433808407	30819	Business	117400.00
0005432430872	30819	Business	117400.00
0005432430866	30819	Business	117400.00
0005433808414	30819	Business	117400.00
0005433812921	30819	Business	117400.00
0005433808406	30819	Economy	39100.00
0005432430874	30819	Economy	39100.00
0005432430855	30819	Economy	39100.00
0005433812919	30819	Economy	39100.00
0005433812920	30819	Economy	39100.00
0005434026699	30819	Economy	39100.00
0005433808418	30819	Economy	43000.00
0005432430862	30819	Economy	43000.00
0005433808416	30819	Economy	39100.00
0005432430867	30819	Economy	39100.00
0005433808419	30819	Economy	39100.00
0005432430871	30819	Economy	39100.00
0005432430854	30819	Economy	39100.00
0005433808421	30819	Economy	39100.00
0005433812925	30819	Economy	39100.00
0005434026687	30819	Economy	39100.00
0005433812922	30819	Economy	39100.00
0005432430861	30819	Economy	39100.00
0005433812916	30819	Economy	39100.00
0005432430878	30819	Economy	39100.00
0005433812918	30819	Economy	39100.00
0005434026708	30819	Economy	39100.00
0005433812923	30819	Economy	39100.00
0005432430869	30819	Economy	39100.00
0005434026707	30819	Economy	39100.00
0005432430863	30819	Economy	39100.00
0005432430846	30819	Economy	39100.00
0005433808408	30819	Economy	39100.00
0005433808405	30819	Economy	39100.00
0005432430849	30819	Economy	39100.00
0005433808410	30819	Economy	39100.00
0005432430858	30819	Economy	39100.00
0005434026688	30819	Economy	39100.00
0005433808411	30819	Economy	39100.00
0005433808413	30819	Economy	39100.00
0005433808415	30819	Economy	39100.00
0005434026714	30819	Economy	39100.00
0005432430868	30819	Economy	39100.00
0005432430864	30819	Economy	39100.00
0005432430860	30819	Economy	39100.00
0005433808412	30819	Economy	39100.00
0005432430859	30819	Economy	39100.00
0005433808409	30819	Economy	39100.00
0005433808420	30819	Economy	39100.00
0005434026689	30819	Economy	39100.00
0005434026703	30819	Economy	39100.00
0005432430865	30819	Economy	39100.00
0005434655007	5386	Business	67200.00
0005434655025	5386	Business	67200.00
0005434655022	5386	Economy	22400.00
0005434655001	5386	Economy	22400.00
0005435340259	5386	Economy	22400.00
0005434655023	5386	Economy	22400.00
0005434655012	5386	Economy	22400.00
0005434655020	5386	Economy	22400.00
0005434655018	5386	Economy	22400.00
0005434655013	5386	Economy	22400.00
0005434655024	5386	Economy	22400.00
0005435340281	5386	Economy	24600.00
0005434655000	5386	Economy	24600.00
0005435340324	5386	Economy	24600.00
0005434655008	5386	Economy	22400.00
0005434655004	5386	Economy	22400.00
0005434656578	5386	Economy	22400.00
0005434655014	5386	Economy	22400.00
0005434655011	5386	Economy	22400.00
0005435340304	5386	Economy	22400.00
0005435340283	5386	Economy	22400.00
0005434655019	5386	Economy	22400.00
0005432114240	5386	Economy	22400.00
0005434656579	5386	Economy	22400.00
0005434655026	5386	Economy	22400.00
0005435340303	5386	Economy	22400.00
0005435340276	5386	Economy	22400.00
0005432114241	5386	Economy	22400.00
0005435340287	5386	Economy	22400.00
0005435340237	5386	Economy	22400.00
0005434655009	5386	Economy	22400.00
0005432114238	5386	Economy	22400.00
0005434655010	5386	Economy	22400.00
0005435340370	5386	Economy	22400.00
0005435340317	5386	Economy	22400.00
0005435340280	5386	Economy	22400.00
0005435340301	5386	Economy	22400.00
0005434654999	5386	Economy	22400.00
0005434655015	5386	Economy	22400.00
0005435340300	5386	Economy	22400.00
0005434655006	5386	Economy	22400.00
0005434655017	5386	Economy	22400.00
0005434655016	5386	Economy	22400.00
0005432114239	5386	Economy	22400.00
0005435340293	5386	Economy	22400.00
0005434655003	5386	Economy	22400.00
0005434655005	5386	Economy	22400.00
0005434655002	5386	Economy	22400.00
0005435340296	5386	Economy	22400.00
0005434654998	5386	Economy	22400.00
0005434655021	5386	Economy	22400.00
0005434654756	12532	Business	67200.00
0005434654758	12532	Business	67200.00
0005435340441	12532	Business	67200.00
0005435340428	12532	Business	67200.00
0005435340438	12532	Economy	22400.00
0005434654680	12532	Economy	22400.00
0005434654810	12532	Economy	22400.00
0005434654693	12532	Economy	22400.00
0005434654774	12532	Economy	22400.00
0005435340432	12532	Economy	22400.00
0005435340434	12532	Economy	22400.00
0005434654775	12532	Economy	24600.00
0005434654727	12532	Economy	22400.00
0005435340440	12532	Economy	22400.00
0005435340430	12532	Economy	22400.00
0005434654840	12532	Economy	22400.00
0005434654747	12532	Economy	22400.00
0005434654715	12532	Economy	22400.00
0005434654764	12532	Economy	22400.00
0005435340426	12532	Economy	22400.00
0005434654609	12532	Economy	22400.00
0005435340439	12532	Economy	22400.00
0005434654755	12532	Economy	22400.00
0005434654763	12532	Economy	22400.00
0005434654839	12532	Economy	22400.00
0005435340425	12532	Economy	22400.00
0005435555394	12532	Economy	22400.00
0005434654802	12532	Economy	22400.00
0005435340429	12532	Economy	22400.00
0005434656558	12532	Economy	22400.00
0005434654718	12532	Economy	22400.00
0005434654669	12532	Economy	22400.00
0005434654719	12532	Economy	22400.00
0005434654679	12532	Economy	22400.00
0005434656564	12532	Economy	22400.00
0005435340437	12532	Economy	22400.00
0005435340427	12532	Economy	22400.00
0005434654922	12532	Economy	22400.00
0005435340431	12532	Economy	22400.00
0005435340435	12532	Economy	22400.00
0005434654740	12532	Economy	22400.00
0005435340436	12532	Economy	22400.00
0005434654705	12532	Economy	22400.00
0005434654692	12532	Economy	22400.00
0005434654750	12532	Economy	22400.00
0005435340433	12532	Economy	22400.00
0005434654761	12532	Economy	22400.00
0005434654818	12532	Economy	22400.00
0005434654757	12532	Economy	22400.00
0005432078172	7440	Business	32000.00
0005433716519	7440	Business	32000.00
0005433716523	7440	Business	32000.00
0005433716533	7440	Business	32000.00
0005433716551	7440	Business	32000.00
0005432078171	7440	Business	32000.00
0005433716502	7440	Business	32000.00
0005433716541	7440	Business	32000.00
0005433656704	7440	Economy	10700.00
0005433716499	7440	Economy	10700.00
0005432428926	7440	Economy	10700.00
0005433719178	7440	Economy	10700.00
0005433656705	7440	Economy	10700.00
0005433716515	7440	Economy	10700.00
0005433722289	7440	Economy	10700.00
0005432078170	7440	Economy	10700.00
0005433722284	7440	Economy	10700.00
0005435266142	7440	Economy	10700.00
0005433690946	7440	Economy	10700.00
0005433716535	7440	Economy	10700.00
0005433688831	7440	Economy	10700.00
0005433716507	7440	Economy	10700.00
0005433716536	7440	Economy	10700.00
0005433716544	7440	Economy	10700.00
0005433716503	7440	Economy	10700.00
0005433716540	7440	Economy	10700.00
0005433722292	7440	Economy	10700.00
0005433716511	7440	Economy	10700.00
0005433716534	7440	Economy	10700.00
0005433722293	7440	Economy	10700.00
0005433716539	7440	Economy	10700.00
0005433716520	7440	Economy	11700.00
0005433716521	7440	Economy	11700.00
0005432078168	7440	Economy	11700.00
0005433688833	7440	Economy	10700.00
0005433716501	7440	Economy	10700.00
0005433722288	7440	Economy	10700.00
0005433716550	7440	Economy	10700.00
0005433716552	7440	Economy	10700.00
0005433688830	7440	Economy	10700.00
0005433719176	7440	Economy	10700.00
0005433716529	7440	Economy	10700.00
0005433716514	7440	Economy	10700.00
0005433716548	7440	Economy	10700.00
0005433716513	7440	Economy	10700.00
0005433716509	7440	Economy	10700.00
0005433722290	7440	Economy	10700.00
0005433716526	7440	Economy	10700.00
0005433722291	7440	Economy	10700.00
0005433716530	7440	Economy	10700.00
0005432078167	7440	Economy	10700.00
0005433716522	7440	Economy	10700.00
0005433688832	7440	Economy	10700.00
0005433656706	7440	Economy	10700.00
0005432078169	7440	Economy	10700.00
0005433716543	7440	Economy	10700.00
0005433716516	7440	Economy	10700.00
0005433722286	7440	Economy	10700.00
0005433716508	7440	Economy	10700.00
0005433716517	7440	Economy	10700.00
0005433716524	7440	Economy	10700.00
0005433716504	7440	Economy	10700.00
0005433722287	7440	Economy	10700.00
0005433716538	7440	Economy	10700.00
0005433716532	7440	Economy	10700.00
0005433716506	7440	Economy	10700.00
0005433716505	7440	Economy	10700.00
0005433716518	7440	Economy	10700.00
0005433719177	7440	Economy	10700.00
0005433716531	7440	Economy	10700.00
0005433716510	7440	Economy	10700.00
0005433716537	7440	Economy	10700.00
0005433716500	7440	Economy	10700.00
0005433690945	7440	Economy	10700.00
0005433716525	7440	Economy	10700.00
0005433716546	7440	Economy	10700.00
0005433716547	7440	Economy	10700.00
0005433716512	7440	Economy	10700.00
0005433716549	7440	Economy	10700.00
0005433722285	7440	Economy	10700.00
0005433716528	7440	Economy	10700.00
0005433716527	7440	Economy	10700.00
0005433716545	7440	Economy	10700.00
0005433716542	7440	Economy	10700.00
0005435266197	29230	Business	32000.00
0005432428968	29230	Business	32000.00
0005433715949	29230	Business	32000.00
0005433716185	29230	Business	32000.00
0005433715940	29230	Business	32000.00
0005433722227	29230	Business	32000.00
0005433716192	29230	Economy	10700.00
0005433716080	29230	Economy	10700.00
0005433719152	29230	Economy	10700.00
0005433716062	29230	Economy	10700.00
0005433716131	29230	Economy	10700.00
0005433716127	29230	Economy	10700.00
0005433722228	29230	Economy	10700.00
0005433688815	29230	Economy	10700.00
0005433716171	29230	Economy	10700.00
0005433716126	29230	Economy	10700.00
0005432006793	29230	Economy	10700.00
0005433716194	29230	Economy	10700.00
0005433688804	29230	Economy	10700.00
0005433656658	29230	Economy	10700.00
0005433716039	29230	Economy	10700.00
0005433716193	29230	Economy	10700.00
0005435266196	29230	Economy	10700.00
0005433719147	29230	Economy	10700.00
0005432006794	29230	Economy	10700.00
0005433716172	29230	Economy	10700.00
0005433716256	29230	Economy	10700.00
0005433716040	29230	Economy	10700.00
0005433688814	29230	Economy	10700.00
0005433716132	29230	Economy	11700.00
0005432428966	29230	Economy	11700.00
0005433716023	29230	Economy	11700.00
0005433716163	29230	Economy	10700.00
0005435266199	29230	Economy	10700.00
0005433716074	29230	Economy	10700.00
0005435266198	29230	Economy	10700.00
0005433716158	29230	Economy	10700.00
0005433656657	29230	Economy	10700.00
0005433715997	29230	Economy	10700.00
0005433715936	29230	Economy	10700.00
0005433716057	29230	Economy	10700.00
0005433656663	29230	Economy	10700.00
0005433656679	29230	Economy	10700.00
0005433716302	29230	Economy	10700.00
0005433656682	29230	Economy	10700.00
0005435266200	29230	Economy	10700.00
0005433716122	29230	Economy	10700.00
0005433716183	29230	Economy	10700.00
0005433719148	29230	Economy	10700.00
0005432006797	29230	Economy	10700.00
0005433716058	29230	Economy	10700.00
0005433716152	29230	Economy	10700.00
0005433715998	29230	Economy	10700.00
0005433656678	29230	Economy	10700.00
0005432428967	29230	Economy	10700.00
0005433715941	29230	Economy	10700.00
0005432006796	29230	Economy	10700.00
0005433716237	29230	Economy	10700.00
0005433688813	29230	Economy	10700.00
0005433716022	29230	Economy	10700.00
0005433716149	29230	Economy	10700.00
0005433688816	29230	Economy	10700.00
0005433716221	29230	Economy	10700.00
0005432006795	29230	Economy	10700.00
0005433656683	29230	Economy	10700.00
0005433716301	29230	Economy	10700.00
0005433722229	29230	Economy	10700.00
0005433722225	29230	Economy	10700.00
0005433716125	29230	Economy	10700.00
0005433716073	29230	Economy	10700.00
0005433716068	29230	Economy	10700.00
0005433688808	29230	Economy	10700.00
0005433722199	29230	Economy	10700.00
0005433716199	29230	Economy	10700.00
0005433688809	29230	Economy	10700.00
0005434095435	8687	Business	36500.00
0005434095440	8687	Business	36500.00
0005434184664	8687	Business	36500.00
0005434182233	8687	Business	36500.00
0005434182257	8687	Business	36500.00
0005434182242	8687	Economy	12200.00
0005434095431	8687	Economy	12200.00
0005434095436	8687	Economy	12200.00
0005434182243	8687	Economy	12200.00
0005434095437	8687	Economy	12200.00
0005434095439	8687	Economy	12200.00
0005434182237	8687	Economy	12200.00
0005434182209	8687	Economy	12200.00
0005434182193	8687	Economy	12200.00
0005434184672	8687	Economy	12200.00
0005434095432	8687	Economy	12200.00
0005434182199	8687	Economy	12200.00
0005434095433	8687	Economy	12200.00
0005434182271	8687	Economy	12200.00
0005434182208	8687	Economy	12200.00
0005434182270	8687	Economy	12200.00
0005434182238	8687	Economy	12200.00
0005434095430	8687	Economy	12200.00
0005434095442	8687	Economy	12200.00
0005434095444	8687	Economy	12200.00
0005434182206	8687	Economy	12200.00
0005434182258	8687	Economy	12200.00
0005434182262	8687	Economy	12200.00
0005434095443	8687	Economy	12200.00
0005434182261	8687	Economy	12200.00
0005434182213	8687	Economy	12200.00
0005434184671	8687	Economy	12200.00
0005434182205	8687	Economy	12200.00
0005434095438	8687	Economy	12200.00
0005434182244	8687	Economy	12200.00
0005434182241	8687	Economy	12200.00
0005434095434	8687	Economy	12200.00
0005434095429	8687	Economy	12200.00
0005434095441	8687	Economy	12200.00
0005434184687	11672	Business	36500.00
0005434182318	11672	Business	36500.00
0005434095346	11672	Business	36500.00
0005434095343	11672	Business	36500.00
0005434182328	11672	Business	36500.00
0005434095317	11672	Economy	12200.00
0005434095276	11672	Economy	12200.00
0005434184685	11672	Economy	12200.00
0005434095347	11672	Economy	13400.00
0005434182321	11672	Economy	12200.00
0005434095316	11672	Economy	12200.00
0005434182326	11672	Economy	12200.00
0005434182323	11672	Economy	12200.00
0005434095362	11672	Economy	12200.00
0005434182329	11672	Economy	12200.00
0005434095342	11672	Economy	12200.00
0005434095312	11672	Economy	12200.00
0005434095353	11672	Economy	12200.00
0005434095300	11672	Economy	12200.00
0005434095313	11672	Economy	12200.00
0005434182327	11672	Economy	12200.00
0005434182325	11672	Economy	12200.00
0005434095277	11672	Economy	12200.00
0005434182322	11672	Economy	12200.00
0005434183601	11672	Economy	12200.00
0005434095352	11672	Economy	12200.00
0005434095304	11672	Economy	12200.00
0005434182320	11672	Economy	12200.00
0005434095361	11672	Economy	12200.00
0005434182330	11672	Economy	12200.00
0005434095311	11672	Economy	12200.00
0005434095314	11672	Economy	12200.00
0005434095272	11672	Economy	12200.00
0005434095305	11672	Economy	12200.00
0005434182319	11672	Economy	12200.00
0005434184686	11672	Economy	12200.00
0005434183600	11672	Economy	12200.00
0005434095351	11672	Economy	12200.00
0005434182324	11672	Economy	12200.00
0005433398232	1450	Business	33000.00
0005433398262	1450	Business	33000.00
0005433398257	1450	Business	33000.00
0005433398161	1450	Business	33000.00
0005432297306	1450	Business	33000.00
0005433398152	1450	Business	33000.00
0005433398019	1450	Business	33000.00
0005433398132	1450	Business	33000.00
0005433398220	1450	Economy	11000.00
0005433398081	1450	Economy	11000.00
0005433398013	1450	Economy	11000.00
0005433398064	1450	Economy	11000.00
0005433398250	1450	Economy	11000.00
0005435732483	1450	Economy	11000.00
0005435732489	1450	Economy	11000.00
0005435732490	1450	Economy	11000.00
0005433398117	1450	Economy	12100.00
0005433398113	1450	Economy	12100.00
0005433398186	1450	Economy	11000.00
0005433398170	1450	Economy	11000.00
0005433398063	1450	Economy	11000.00
0005433398160	1450	Economy	11000.00
0005435732488	1450	Economy	11000.00
0005433398221	1450	Economy	11000.00
0005435732492	1450	Economy	11000.00
0005433398258	1450	Economy	11000.00
0005433398321	1450	Economy	11000.00
0005433398306	1450	Economy	11000.00
0005433398018	1450	Economy	11000.00
0005432297307	1450	Economy	11000.00
0005433398025	1450	Economy	11000.00
0005433398208	1450	Economy	11000.00
0005433398200	1450	Economy	11000.00
0005433398154	1450	Economy	11000.00
0005433398036	1450	Economy	11000.00
0005433398342	1450	Economy	11000.00
0005433398045	1450	Economy	11000.00
0005433398105	1450	Economy	11000.00
0005433398296	1450	Economy	11000.00
0005433398181	1450	Economy	11000.00
0005433397793	1450	Economy	11000.00
0005433398231	1450	Economy	11000.00
0005433398261	1450	Economy	11000.00
0005433398189	1450	Economy	11000.00
0005433457014	1450	Economy	11000.00
0005433398176	1450	Economy	11000.00
0005435732485	1450	Economy	11000.00
0005435732487	1450	Economy	11000.00
0005433398292	1450	Economy	11000.00
0005433457016	1450	Economy	11000.00
0005433398047	1450	Economy	11000.00
0005433398133	1450	Economy	11000.00
0005433398098	1450	Economy	11000.00
0005433398011	1450	Economy	11000.00
0005433398229	1450	Economy	11000.00
0005433457017	1450	Economy	11000.00
0005433398108	1450	Economy	11000.00
0005433398088	1450	Economy	11000.00
0005435732491	1450	Economy	11000.00
0005435732482	1450	Economy	11000.00
0005435732486	1450	Economy	11000.00
0005433398185	1450	Economy	11000.00
0005435732484	1450	Economy	11000.00
0005433457015	1450	Economy	11000.00
0005433398319	1450	Economy	11000.00
0005433398240	1450	Economy	11000.00
0005433398046	1450	Economy	11000.00
0005433398228	1450	Economy	11000.00
0005433398171	1450	Economy	11000.00
0005433398320	1450	Economy	11000.00
0005433398153	1450	Economy	11000.00
0005433398162	1450	Economy	11000.00
0005433398593	19268	Business	33000.00
0005433398621	19268	Business	33000.00
0005433398600	19268	Business	33000.00
0005433398573	19268	Business	33000.00
0005433398575	19268	Business	33000.00
0005432906562	19268	Business	33000.00
0005433398571	19268	Business	33000.00
0005433456996	19268	Business	33000.00
0005433398588	19268	Business	33000.00
0005433398597	19268	Economy	11000.00
0005432906564	19268	Economy	11000.00
0005435732419	19268	Economy	11000.00
0005433398604	19268	Economy	11000.00
0005433398613	19268	Economy	11000.00
0005435732344	19268	Economy	11000.00
0005433398577	19268	Economy	12100.00
0005435732439	19268	Economy	12100.00
0005433398601	19268	Economy	12100.00
0005432906563	19268	Economy	12100.00
0005435732371	19268	Economy	11000.00
0005433398602	19268	Economy	11000.00
0005433398619	19268	Economy	11000.00
0005433456995	19268	Economy	11000.00
0005435732338	19268	Economy	11000.00
0005433398616	19268	Economy	11000.00
0005433398589	19268	Economy	11000.00
0005433398608	19268	Economy	11000.00
0005433398579	19268	Economy	11000.00
0005435732403	19268	Economy	11000.00
0005433398583	19268	Economy	11000.00
0005433398618	19268	Economy	11000.00
0005433398598	19268	Economy	11000.00
0005433398599	19268	Economy	11000.00
0005433398592	19268	Economy	11000.00
0005433398584	19268	Economy	11000.00
0005433398611	19268	Economy	11000.00
0005433456977	19268	Economy	11000.00
0005433398590	19268	Economy	11000.00
0005433398609	19268	Economy	11000.00
0005433398572	19268	Economy	11000.00
0005433398576	19268	Economy	11000.00
0005433398574	19268	Economy	11000.00
0005433398610	19268	Economy	11000.00
0005435732385	19268	Economy	11000.00
0005433398612	19268	Economy	11000.00
0005433398596	19268	Economy	11000.00
0005433398615	19268	Economy	11000.00
0005433398606	19268	Economy	11000.00
0005433456974	19268	Economy	11000.00
0005433398585	19268	Economy	11000.00
0005433398595	19268	Economy	11000.00
0005433398594	19268	Economy	11000.00
0005433398603	19268	Economy	11000.00
0005433398586	19268	Economy	11000.00
0005433398607	19268	Economy	11000.00
0005435732337	19268	Economy	11000.00
0005433398582	19268	Economy	11000.00
0005435732317	19268	Economy	11000.00
0005433456975	19268	Economy	11000.00
0005433398580	19268	Economy	11000.00
0005433398578	19268	Economy	11000.00
0005433398620	19268	Economy	11000.00
0005435732372	19268	Economy	11000.00
0005433398605	19268	Economy	11000.00
0005433398587	19268	Economy	11000.00
0005433398581	19268	Economy	11000.00
0005433398617	19268	Economy	11000.00
0005433398614	19268	Economy	11000.00
0005433456969	19268	Economy	11000.00
0005433398591	19268	Economy	11000.00
0005434443645	17368	Economy	14100.00
0005434443755	17368	Economy	14100.00
0005434443745	17368	Economy	14100.00
0005434443741	17368	Economy	14100.00
0005434443749	17368	Economy	14100.00
0005434443706	17368	Economy	14100.00
0005434443742	17368	Economy	14100.00
0005434443731	17368	Economy	14100.00
0005434443744	17368	Economy	14100.00
0005434443781	17368	Economy	14100.00
0005434443743	17368	Economy	14100.00
0005434443719	17368	Economy	14100.00
0005434443663	17368	Economy	14100.00
0005434443707	17368	Economy	14100.00
0005434443886	20561	Economy	15600.00
0005434443877	20561	Economy	15600.00
0005434443879	20561	Economy	14100.00
0005434443884	20561	Economy	14100.00
0005434443883	20561	Economy	14100.00
0005434443881	20561	Economy	14100.00
0005434443876	20561	Economy	14100.00
0005434443882	20561	Economy	14100.00
0005434443885	20561	Economy	14100.00
0005434443875	20561	Economy	14100.00
0005434443873	20561	Economy	14100.00
0005434443870	20561	Economy	14100.00
0005434443880	20561	Economy	14100.00
0005434443878	20561	Economy	14100.00
0005434443872	20561	Economy	14100.00
0005434443874	20561	Economy	14100.00
0005434443871	20561	Economy	14100.00
0005434954651	7260	Economy	5800.00
0005435377591	7260	Economy	5800.00
0005434954654	7260	Economy	5800.00
0005434954652	7260	Economy	5800.00
0005434954653	7260	Economy	5800.00
0005435377577	7260	Economy	5800.00
0005435377589	7260	Economy	5800.00
0005434954611	28356	Economy	5800.00
0005434954610	28356	Economy	5800.00
0005435377605	28356	Economy	5800.00
0005435377606	28356	Economy	5800.00
0005434954627	28356	Economy	5800.00
0005434954628	28356	Economy	5800.00
0005435377607	28356	Economy	5800.00
0005434351833	4459	Economy	15400.00
0005434351836	4459	Economy	15400.00
0005434351840	4459	Economy	15400.00
0005434351842	4459	Economy	14000.00
0005434351839	4459	Economy	14000.00
0005434351831	4459	Economy	14000.00
0005435893639	4459	Economy	14000.00
0005435893654	4459	Economy	14000.00
0005434351841	4459	Economy	14000.00
0005434351838	4459	Economy	14000.00
0005435893655	4459	Economy	14000.00
0005434351834	4459	Economy	14000.00
0005434351843	4459	Economy	14000.00
0005435893673	4459	Economy	14000.00
0005434351832	4459	Economy	14000.00
0005434351835	4459	Economy	14000.00
0005435893662	4459	Economy	14000.00
0005435893650	4459	Economy	14000.00
0005434351837	4459	Economy	14000.00
0005435893649	4459	Economy	14000.00
0005434183587	4459	Economy	14000.00
0005435893667	4459	Economy	14000.00
0005434351769	29638	Economy	15400.00
0005435893713	29638	Economy	14000.00
0005434351701	29638	Economy	14000.00
0005434351680	29638	Economy	14000.00
0005434351712	29638	Economy	14000.00
0005435893708	29638	Economy	14000.00
0005435893707	29638	Economy	14000.00
0005434351804	29638	Economy	14000.00
0005435893710	29638	Economy	14000.00
0005434351683	29638	Economy	14000.00
0005435893711	29638	Economy	14000.00
0005434351789	29638	Economy	14000.00
0005434351684	29638	Economy	14000.00
0005434351659	29638	Economy	14000.00
0005434351713	29638	Economy	14000.00
0005435893709	29638	Economy	14000.00
0005434351700	29638	Economy	14000.00
0005434351727	29638	Economy	14000.00
0005435893712	29638	Economy	14000.00
0005434351711	29638	Economy	14000.00
0005433269736	1040	Business	30600.00
0005435545829	1040	Business	30600.00
0005432293237	1040	Business	30600.00
0005433343465	1040	Business	30600.00
0005435545837	1040	Business	30600.00
0005433343241	1040	Business	30600.00
0005433343635	1040	Business	30600.00
0005433342726	1040	Business	30600.00
0005433343111	1040	Business	30600.00
0005433343583	1040	Business	30600.00
0005432293236	1040	Business	30600.00
0005433343240	1040	Business	30600.00
0005433343320	1040	Business	30600.00
0005433342940	1040	Business	30600.00
0005433343224	1040	Business	30600.00
0005433342710	1040	Business	30600.00
0005434446543	1040	Business	30600.00
0005434445270	1040	Economy	11200.00
0005435545833	1040	Economy	11200.00
0005434446541	1040	Economy	10200.00
0005435092185	1040	Economy	10200.00
0005433343463	1040	Economy	10200.00
0005433343262	1040	Economy	10200.00
0005433343225	1040	Economy	10200.00
0005433343417	1040	Economy	10200.00
0005433343361	1040	Economy	10200.00
0005433343603	1040	Economy	10200.00
0005435545841	1040	Economy	10200.00
0005435092180	1040	Economy	10200.00
0005433343430	1040	Economy	10200.00
0005434445269	1040	Economy	10200.00
0005433343065	1040	Economy	10200.00
0005433342911	1040	Economy	10200.00
0005433463925	1040	Economy	10200.00
0005433343322	1040	Economy	10200.00
0005433463924	1040	Economy	10200.00
0005435092183	1040	Economy	10200.00
0005433343197	1040	Economy	10200.00
0005433343114	1040	Economy	10200.00
0005433343500	1040	Economy	10200.00
0005433343215	1040	Economy	10200.00
0005433462771	1040	Economy	10200.00
0005434446540	1040	Economy	10200.00
0005433343464	1040	Economy	10200.00
0005433343182	1040	Economy	10200.00
0005433343133	1040	Economy	10200.00
0005433342958	1040	Economy	10200.00
0005434446542	1040	Economy	10200.00
0005433343504	1040	Economy	10200.00
0005433269714	1040	Economy	10200.00
0005435545830	1040	Economy	10200.00
0005433343248	1040	Economy	10200.00
0005433343222	1040	Economy	10200.00
0005433343289	1040	Economy	10200.00
0005433343068	1040	Economy	10200.00
0005433343508	1040	Economy	10200.00
0005435545839	1040	Economy	10200.00
0005435092182	1040	Economy	10200.00
0005433343418	1040	Economy	10200.00
0005433343144	1040	Economy	10200.00
0005433343648	1040	Economy	10200.00
0005433342640	1040	Economy	10200.00
0005435545831	1040	Economy	10200.00
0005433342926	1040	Economy	10200.00
0005433343683	1040	Economy	10200.00
0005435545832	1040	Economy	10200.00
0005433269713	1040	Economy	10200.00
0005433343281	1040	Economy	10200.00
0005433342639	1040	Economy	10200.00
0005433343244	1040	Economy	10200.00
0005433343637	1040	Economy	10200.00
0005433343290	1040	Economy	10200.00
0005433342709	1040	Economy	10200.00
0005433343260	1040	Economy	10200.00
0005433343220	1040	Economy	10200.00
0005433343383	1040	Economy	10200.00
0005433343280	1040	Economy	10200.00
0005433343609	1040	Economy	10200.00
0005433343505	1040	Economy	10200.00
0005433343407	1040	Economy	10200.00
0005433343156	1040	Economy	10200.00
0005433343377	1040	Economy	10200.00
0005433343177	1040	Economy	10200.00
0005433343408	1040	Economy	10200.00
0005433159317	1040	Economy	11200.00
0005433342725	1040	Economy	10200.00
0005433159318	1040	Economy	10200.00
0005433343204	1040	Economy	10200.00
0005433343579	1040	Economy	10200.00
0005433343135	1040	Economy	10200.00
0005433343314	1040	Economy	10200.00
0005435545842	1040	Economy	10200.00
0005433343315	1040	Economy	10200.00
0005435092181	1040	Economy	10200.00
0005433343271	1040	Economy	10200.00
0005435545840	1040	Economy	10200.00
0005433343416	1040	Economy	10200.00
0005435545835	1040	Economy	10200.00
0005433342939	1040	Economy	10200.00
0005435092189	1040	Economy	10200.00
0005433343596	1040	Economy	10200.00
0005435545834	1040	Economy	10200.00
0005433343636	1040	Economy	10200.00
0005433343362	1040	Economy	10200.00
0005433343811	1040	Economy	10200.00
0005433343217	1040	Economy	10200.00
0005433343249	1040	Economy	10200.00
0005433343219	1040	Economy	10200.00
0005435092184	1040	Economy	10200.00
0005433343585	1040	Economy	10200.00
0005435545836	1040	Economy	10200.00
0005435092188	1040	Economy	10200.00
0005433343411	1040	Economy	10200.00
0005435092187	1040	Economy	10200.00
0005435545838	1040	Economy	10200.00
0005435545843	1040	Economy	10200.00
0005433343376	1040	Economy	10200.00
0005433342943	1040	Economy	10200.00
0005433343506	1040	Economy	10200.00
0005433343412	1040	Economy	10200.00
0005433343569	1040	Economy	10200.00
0005433343302	1040	Economy	10200.00
0005433342711	1040	Economy	10200.00
0005433343700	1040	Economy	10200.00
0005433343410	1040	Economy	10200.00
0005433343321	1040	Economy	10200.00
0005433269745	1040	Economy	10200.00
0005433343561	1040	Economy	10200.00
0005433343582	1040	Economy	10200.00
0005433343363	1040	Economy	10200.00
0005435092186	1040	Economy	10200.00
0005433343134	1040	Economy	10200.00
0005433344153	17037	Business	30600.00
0005433344167	17037	Business	30600.00
0005433344189	17037	Business	30600.00
0005435508352	17037	Business	30600.00
0005433344225	17037	Business	30600.00
0005433344127	17037	Business	30600.00
0005433344172	17037	Business	30600.00
0005434445251	17037	Business	30600.00
0005433344183	17037	Business	30600.00
0005435092146	17037	Business	30600.00
0005433269780	17037	Business	30600.00
0005435508354	17037	Business	30600.00
0005433344149	17037	Business	30600.00
0005433344223	17037	Business	30600.00
0005433344168	17037	Business	30600.00
0005434445240	17037	Business	30600.00
0005435508374	17037	Business	30600.00
0005435092122	17037	Economy	11200.00
0005433344134	17037	Economy	11200.00
0005433344186	17037	Economy	10200.00
0005435092116	17037	Economy	10200.00
0005433344191	17037	Economy	10200.00
0005433344221	17037	Economy	10200.00
0005433344132	17037	Economy	10200.00
0005435092123	17037	Economy	10200.00
0005435092145	17037	Economy	10200.00
0005433344182	17037	Economy	10200.00
0005435508353	17037	Economy	10200.00
0005433344194	17037	Economy	10200.00
0005433344215	17037	Economy	10200.00
0005433344155	17037	Economy	10200.00
0005433344126	17037	Economy	10200.00
0005433344224	17037	Economy	10200.00
0005433344169	17037	Economy	10200.00
0005433344150	17037	Economy	10200.00
0005433344220	17037	Economy	10200.00
0005433344214	17037	Economy	10200.00
0005433344227	17037	Economy	10200.00
0005433344151	17037	Economy	10200.00
0005435508323	17037	Economy	10200.00
0005433344176	17037	Economy	10200.00
0005433344143	17037	Economy	10200.00
0005433344157	17037	Economy	10200.00
0005433344185	17037	Economy	10200.00
0005433344188	17037	Economy	10200.00
0005433344206	17037	Economy	10200.00
0005433344165	17037	Economy	10200.00
0005433344178	17037	Economy	10200.00
0005433344200	17037	Economy	10200.00
0005435092040	17037	Economy	10200.00
0005435092137	17037	Economy	10200.00
0005433344129	17037	Economy	10200.00
0005433344135	17037	Economy	10200.00
0005433344222	17037	Economy	10200.00
0005433344144	17037	Economy	10200.00
0005433344131	17037	Economy	10200.00
0005433344192	17037	Economy	10200.00
0005435508385	17037	Economy	10200.00
0005433344138	17037	Economy	10200.00
0005433344208	17037	Economy	10200.00
0005433344197	17037	Economy	10200.00
0005433344210	17037	Economy	10200.00
0005433344152	17037	Economy	10200.00
0005433344139	17037	Economy	10200.00
0005433344154	17037	Economy	10200.00
0005433344184	17037	Economy	10200.00
0005433344166	17037	Economy	10200.00
0005435092091	17037	Economy	10200.00
0005433344177	17037	Economy	10200.00
0005435092028	17037	Economy	10200.00
0005433344202	17037	Economy	10200.00
0005433344216	17037	Economy	10200.00
0005433344173	17037	Economy	10200.00
0005433344217	17037	Economy	10200.00
0005435508389	17037	Economy	10200.00
0005435092134	17037	Economy	10200.00
0005433344158	17037	Economy	10200.00
0005435092098	17037	Economy	10200.00
0005433269776	17037	Economy	10200.00
0005433344193	17037	Economy	10200.00
0005435508398	17037	Economy	10200.00
0005433344228	17037	Economy	10200.00
0005433344140	17037	Economy	10200.00
0005433344133	17037	Economy	10200.00
0005433344207	17037	Economy	10200.00
0005435092041	17037	Economy	10200.00
0005433344161	17037	Economy	11200.00
0005433344136	17037	Economy	10200.00
0005433344156	17037	Economy	10200.00
0005433344128	17037	Economy	10200.00
0005433344141	17037	Economy	10200.00
0005433269778	17037	Economy	11200.00
0005433344145	17037	Economy	11200.00
0005433344226	17037	Economy	10200.00
0005433344137	17037	Economy	10200.00
0005433344195	17037	Economy	10200.00
0005435508349	17037	Economy	10200.00
0005433344163	17037	Economy	10200.00
0005433344164	17037	Economy	10200.00
0005433344148	17037	Economy	10200.00
0005434445258	17037	Economy	10200.00
0005433344212	17037	Economy	10200.00
0005433344198	17037	Economy	10200.00
0005433344187	17037	Economy	10200.00
0005433344196	17037	Economy	10200.00
0005433344201	17037	Economy	10200.00
0005435508381	17037	Economy	10200.00
0005433344199	17037	Economy	10200.00
0005433344211	17037	Economy	10200.00
0005433344174	17037	Economy	10200.00
0005433344179	17037	Economy	10200.00
0005433344160	17037	Economy	10200.00
0005433344218	17037	Economy	10200.00
0005433344162	17037	Economy	10200.00
0005433269777	17037	Economy	10200.00
0005433344181	17037	Economy	10200.00
0005433344146	17037	Economy	10200.00
0005433344170	17037	Economy	10200.00
0005433344159	17037	Economy	10200.00
0005433344209	17037	Economy	10200.00
0005433344219	17037	Economy	10200.00
0005433344203	17037	Economy	10200.00
0005433344130	17037	Economy	10200.00
0005433159337	17037	Economy	10200.00
0005433344171	17037	Economy	10200.00
0005433344175	17037	Economy	10200.00
0005435508391	17037	Economy	10200.00
0005433344213	17037	Economy	10200.00
0005433344142	17037	Economy	10200.00
0005433269779	17037	Economy	10200.00
0005433344204	17037	Economy	10200.00
0005433344147	17037	Economy	10200.00
0005433344205	17037	Economy	10200.00
0005433344180	17037	Economy	10200.00
0005433344190	17037	Economy	10200.00
0005435508370	17037	Economy	10200.00
0005432851973	18262	Business	101000.00
0005432851983	18262	Business	101000.00
0005432391996	18262	Business	101000.00
0005432390107	18262	Business	101000.00
0005432851986	18262	Business	101000.00
0005432391992	18262	Business	101000.00
0005432390161	18262	Business	101000.00
0005432390140	18262	Business	101000.00
0005432851980	18262	Business	101000.00
0005432390187	18262	Business	101000.00
0005432851974	18262	Business	101000.00
0005432390083	18262	Economy	33700.00
0005432390206	18262	Economy	33700.00
0005432851991	18262	Economy	33700.00
0005432851981	18262	Economy	33700.00
0005432390182	18262	Economy	33700.00
0005432390142	18262	Economy	33700.00
0005432390124	18262	Economy	33700.00
0005432851975	18262	Economy	33700.00
0005432851985	18262	Economy	33700.00
0005432851977	18262	Economy	33700.00
0005432390103	18262	Economy	33700.00
0005432390116	18262	Economy	37000.00
0005432390141	18262	Economy	37000.00
0005432851989	18262	Economy	33700.00
0005432390181	18262	Economy	37000.00
0005432851972	18262	Economy	33700.00
0005432851988	18262	Economy	33700.00
0005432851979	18262	Economy	33700.00
0005432390065	18262	Economy	33700.00
0005432390127	18262	Economy	33700.00
0005432851984	18262	Economy	33700.00
0005432390126	18262	Economy	33700.00
0005432390157	18262	Economy	33700.00
0005432851971	18262	Economy	33700.00
0005432390168	18262	Economy	33700.00
0005432390162	18262	Economy	33700.00
0005432390151	18262	Economy	33700.00
0005432390149	18262	Economy	33700.00
0005432390179	18262	Economy	33700.00
0005432390152	18262	Economy	33700.00
0005432390146	18262	Economy	33700.00
0005432390102	18262	Economy	33700.00
0005432390123	18262	Economy	33700.00
0005432390174	18262	Economy	33700.00
0005432851976	18262	Economy	33700.00
0005432390125	18262	Economy	33700.00
0005432851992	18262	Economy	33700.00
0005432390148	18262	Economy	33700.00
0005432851990	18262	Economy	33700.00
0005432851982	18262	Economy	33700.00
0005432390169	18262	Economy	33700.00
0005432390135	18262	Economy	33700.00
0005432392000	18262	Economy	33700.00
0005432390164	18262	Economy	33700.00
0005432390147	18262	Economy	33700.00
0005432390101	18262	Economy	33700.00
0005432392011	18262	Economy	33700.00
0005432390159	18262	Economy	33700.00
0005432391999	18262	Economy	33700.00
0005432390104	18262	Economy	33700.00
0005432390156	18262	Economy	33700.00
0005432390160	18262	Economy	33700.00
0005432391998	18262	Economy	33700.00
0005432390153	18262	Economy	33700.00
0005432390115	18262	Economy	33700.00
0005432391995	18262	Economy	33700.00
0005432851987	18262	Economy	33700.00
0005432851978	18262	Economy	33700.00
0005432390184	18262	Economy	33700.00
0005432390167	18262	Economy	33700.00
0005432390158	18262	Economy	33700.00
0005432390108	18262	Economy	33700.00
0005432390178	18262	Economy	33700.00
0005432851970	18262	Economy	33700.00
0005432390145	18262	Economy	33700.00
0005432390129	18262	Economy	33700.00
0005432851969	18262	Economy	33700.00
0005434026711	12800	Business	40300.00
0005434067527	12800	Business	40300.00
0005434067769	12800	Business	40300.00
0005434067700	12800	Business	40300.00
0005434067906	12800	Business	40300.00
0005434067554	12800	Business	40300.00
0005434067637	12800	Business	40300.00
0005434081927	12800	Business	40300.00
0005434081960	12800	Business	40300.00
0005434067684	12800	Business	40300.00
0005434081941	12800	Business	40300.00
0005434067726	12800	Economy	13400.00
0005434067942	12800	Economy	13400.00
0005434068029	12800	Economy	13400.00
0005434026705	12800	Economy	13400.00
0005434081938	12800	Economy	13400.00
0005434067805	12800	Economy	13400.00
0005434067271	12800	Economy	13400.00
0005434067464	12800	Economy	13400.00
0005433812926	12800	Economy	13400.00
0005434081964	12800	Economy	13400.00
0005434026712	12800	Economy	13400.00
0005434067770	12800	Economy	13400.00
0005434067812	12800	Economy	13400.00
0005434067528	12800	Economy	13400.00
0005432161178	12800	Economy	13400.00
0005434067745	12800	Economy	13400.00
0005434067565	12800	Economy	13400.00
0005432433737	12800	Economy	13400.00
0005434067877	12800	Economy	13400.00
0005432159907	12800	Economy	13400.00
0005434067605	12800	Economy	13400.00
0005434081978	12800	Economy	13400.00
0005434081982	12800	Economy	13400.00
0005432433741	12800	Economy	13400.00
0005434026704	12800	Economy	13400.00
0005434082080	12800	Economy	13400.00
0005434081853	12800	Economy	13400.00
0005434067626	12800	Economy	13400.00
0005434067842	12800	Economy	13400.00
0005434081967	12800	Economy	13400.00
0005434067634	12800	Economy	13400.00
0005434067609	12800	Economy	13400.00
0005434082014	12800	Economy	13400.00
0005434067776	12800	Economy	13400.00
0005434067840	12800	Economy	13400.00
0005434067611	12800	Economy	13400.00
0005434067876	12800	Economy	13400.00
0005434067638	12800	Economy	13400.00
0005434082028	12800	Economy	14800.00
0005434082081	12800	Economy	14800.00
0005434067564	12800	Economy	14800.00
0005434081885	12800	Economy	14800.00
0005433812927	12800	Economy	14800.00
0005434067539	12800	Economy	14800.00
0005434067546	12800	Economy	13400.00
0005434067774	12800	Economy	13400.00
0005434026706	12800	Economy	13400.00
0005434081890	12800	Economy	13400.00
0005434067725	12800	Economy	13400.00
0005434067921	12800	Economy	13400.00
0005434067872	12800	Economy	13400.00
0005434067532	12800	Economy	13400.00
0005434067530	12800	Economy	13400.00
0005434081952	12800	Economy	13400.00
0005434081880	12800	Economy	13400.00
0005434067396	12800	Economy	13400.00
0005434082029	12800	Economy	13400.00
0005434067746	12800	Economy	13400.00
0005434067575	12800	Economy	13400.00
0005434067604	12800	Economy	13400.00
0005434067885	12800	Economy	13400.00
0005434067293	12800	Economy	13400.00
0005432433739	12800	Economy	13400.00
0005434067698	12800	Economy	13400.00
0005434067552	12800	Economy	13400.00
0005434067795	12800	Economy	13400.00
0005434067724	12800	Economy	13400.00
0005434067779	12800	Economy	13400.00
0005433989780	12800	Economy	13400.00
0005432433738	12800	Economy	13400.00
0005432433740	12800	Economy	13400.00
0005432159908	12800	Economy	13400.00
0005434067701	12800	Economy	13400.00
0005432159909	12800	Economy	13400.00
0005434067483	12800	Economy	13400.00
0005434067526	12800	Economy	13400.00
0005434067739	12800	Economy	13400.00
0005434067737	12800	Economy	13400.00
0005434067888	12800	Economy	13400.00
0005434067456	12800	Economy	13400.00
0005434067850	12800	Economy	13400.00
0005434067535	12800	Economy	13400.00
0005434067270	12800	Economy	13400.00
0005434081928	12800	Economy	13400.00
0005434081889	12800	Economy	13400.00
0005432161177	12800	Economy	13400.00
0005434067533	12800	Economy	13400.00
0005434081974	12800	Economy	13400.00
0005434081953	12800	Economy	13400.00
0005434067907	12800	Economy	13400.00
0005434081966	12800	Economy	13400.00
0005434067610	12800	Economy	13400.00
0005434081931	12800	Economy	13400.00
0005434082013	12800	Economy	13400.00
0005432159911	12800	Economy	13400.00
0005434067697	12800	Economy	13400.00
0005432159910	12800	Economy	13400.00
0005434067775	12800	Economy	13400.00
0005434067635	12800	Economy	13400.00
0005434081957	12800	Economy	13400.00
0005434081924	12800	Economy	13400.00
0005434081884	12800	Economy	13400.00
0005434081852	12800	Economy	13400.00
0005434081963	12800	Economy	13400.00
0005434067819	12800	Economy	13400.00
0005434067806	12800	Economy	13400.00
0005434067829	12800	Economy	13400.00
0005434067551	12800	Economy	13400.00
0005434067414	12800	Economy	13400.00
0005434067820	12800	Economy	13400.00
0005434068260	30678	Business	40300.00
0005434068291	30678	Business	40300.00
0005432150277	30678	Business	40300.00
0005434082143	30678	Business	40300.00
0005434068305	30678	Business	40300.00
0005432186905	30678	Business	40300.00
0005432150273	30678	Business	40300.00
0005434082153	30678	Business	40300.00
0005434068258	30678	Business	40300.00
0005434082146	30678	Economy	13400.00
0005434068315	30678	Economy	13400.00
0005434068276	30678	Economy	13400.00
0005432150279	30678	Economy	13400.00
0005432186909	30678	Economy	13400.00
0005432433695	30678	Economy	13400.00
0005434082156	30678	Economy	13400.00
0005432186907	30678	Economy	13400.00
0005433989817	30678	Economy	13400.00
0005433989818	30678	Economy	13400.00
0005434068279	30678	Economy	13400.00
0005434082144	30678	Economy	13400.00
0005434068285	30678	Economy	13400.00
0005434082157	30678	Economy	13400.00
0005434068295	30678	Economy	13400.00
0005434068308	30678	Economy	13400.00
0005434068316	30678	Economy	13400.00
0005434068306	30678	Economy	13400.00
0005434068326	30678	Economy	13400.00
0005434068303	30678	Economy	13400.00
0005434068275	30678	Economy	13400.00
0005434082148	30678	Economy	13400.00
0005434068262	30678	Economy	13400.00
0005434068290	30678	Economy	13400.00
0005434068287	30678	Economy	13400.00
0005434068307	30678	Economy	13400.00
0005434068288	30678	Economy	13400.00
0005434068264	30678	Economy	13400.00
0005434082141	30678	Economy	13400.00
0005433989821	30678	Economy	13400.00
0005434082138	30678	Economy	13400.00
0005434068297	30678	Economy	13400.00
0005434082151	30678	Economy	13400.00
0005434068268	30678	Economy	13400.00
0005432150271	30678	Economy	13400.00
0005434082147	30678	Economy	13400.00
0005432186908	30678	Economy	13400.00
0005434068263	30678	Economy	14800.00
0005434068266	30678	Economy	14800.00
0005433989819	30678	Economy	14800.00
0005434082150	30678	Economy	14800.00
0005432433698	30678	Economy	14800.00
0005434068322	30678	Economy	14800.00
0005434068283	30678	Economy	13400.00
0005434082140	30678	Economy	13400.00
0005434082142	30678	Economy	13400.00
0005434068289	30678	Economy	13400.00
0005432433718	30678	Economy	13400.00
0005434068259	30678	Economy	13400.00
0005434082137	30678	Economy	13400.00
0005434068309	30678	Economy	13400.00
0005432433688	30678	Economy	13400.00
0005433989822	30678	Economy	13400.00
0005434068312	30678	Economy	13400.00
0005434068269	30678	Economy	13400.00
0005434068320	30678	Economy	13400.00
0005434068293	30678	Economy	13400.00
0005434068292	30678	Economy	13400.00
0005434068310	30678	Economy	13400.00
0005434068256	30678	Economy	13400.00
0005434068284	30678	Economy	13400.00
0005434068257	30678	Economy	13400.00
0005434082155	30678	Economy	13400.00
0005434068299	30678	Economy	13400.00
0005434068265	30678	Economy	13400.00
0005434068281	30678	Economy	13400.00
0005434068298	30678	Economy	13400.00
0005434068273	30678	Economy	13400.00
0005434068324	30678	Economy	13400.00
0005432150276	30678	Economy	13400.00
0005434068286	30678	Economy	13400.00
0005432433717	30678	Economy	13400.00
0005434082139	30678	Economy	13400.00
0005434082149	30678	Economy	13400.00
0005432150274	30678	Economy	13400.00
0005434068261	30678	Economy	13400.00
0005434068282	30678	Economy	13400.00
0005432150275	30678	Economy	13400.00
0005434068271	30678	Economy	13400.00
0005434068317	30678	Economy	13400.00
0005434068313	30678	Economy	13400.00
0005434068311	30678	Economy	13400.00
0005434068327	30678	Economy	13400.00
0005434068302	30678	Economy	13400.00
0005432433681	30678	Economy	13400.00
0005434068314	30678	Economy	13400.00
0005434068301	30678	Economy	13400.00
0005432433713	30678	Economy	13400.00
0005434068267	30678	Economy	13400.00
0005432150278	30678	Economy	13400.00
0005434082152	30678	Economy	13400.00
0005434068296	30678	Economy	13400.00
0005434068300	30678	Economy	13400.00
0005434068325	30678	Economy	13400.00
0005434068321	30678	Economy	13400.00
0005434068270	30678	Economy	13400.00
0005434068274	30678	Economy	13400.00
0005434068323	30678	Economy	13400.00
0005434082145	30678	Economy	13400.00
0005434068277	30678	Economy	13400.00
0005432150272	30678	Economy	13400.00
0005433989820	30678	Economy	13400.00
0005434068318	30678	Economy	13400.00
0005432186906	30678	Economy	13400.00
0005434068278	30678	Economy	13400.00
0005434068272	30678	Economy	13400.00
0005434068304	30678	Economy	13400.00
0005434068294	30678	Economy	13400.00
0005434068280	30678	Economy	13400.00
0005434068319	30678	Economy	13400.00
0005434082154	30678	Economy	13400.00
0005432433699	30678	Economy	13400.00
0005433686642	19357	Economy	19300.00
0005433686640	19357	Economy	17600.00
0005433689907	19357	Economy	17600.00
0005433686620	19357	Economy	17600.00
0005433689917	19357	Economy	17600.00
0005433686639	19357	Economy	17600.00
0005433689901	19357	Economy	17600.00
0005433689912	19357	Economy	17600.00
0005433686641	19357	Economy	17600.00
0005433686631	19357	Economy	17600.00
0005433686623	19357	Economy	17600.00
0005433689915	19357	Economy	17600.00
0005433689918	19357	Economy	17600.00
0005433686624	19357	Economy	17600.00
0005433689911	19357	Economy	17600.00
0005433689906	19357	Economy	17600.00
0005433686619	19357	Economy	17600.00
0005433689908	19357	Economy	17600.00
0005433689916	19357	Economy	17600.00
0005433689913	19357	Economy	17600.00
0005433689924	19357	Economy	17600.00
0005433686632	19357	Economy	17600.00
0005433689914	19357	Economy	17600.00
0005435462603	5488	Business	35300.00
0005435462569	5488	Business	35300.00
0005435766928	5488	Business	35300.00
0005435766883	5488	Business	35300.00
0005435462476	5488	Business	35300.00
0005435766934	5488	Business	35300.00
0005435735187	5488	Business	35300.00
0005435723069	5488	Business	35300.00
0005435766915	5488	Business	35300.00
0005434831171	5488	Business	35300.00
0005434265164	5488	Business	35300.00
0005435462415	5488	Business	35300.00
0005434831140	5488	Business	35300.00
0005435766896	5488	Business	35300.00
0005435462530	5488	Business	35300.00
0005435766877	5488	Business	35300.00
0005435766911	5488	Business	35300.00
0005432140538	5488	Business	35300.00
0005435722080	5488	Business	35300.00
0005434831143	5488	Economy	12900.00
0005435462500	5488	Economy	12900.00
0005435766925	5488	Economy	12900.00
0005435735183	5488	Economy	11800.00
0005432140537	5488	Economy	12900.00
0005435462412	5488	Economy	11800.00
0005435462681	5488	Economy	11800.00
0005435766899	5488	Economy	11800.00
0005435766913	5488	Economy	11800.00
0005435462520	5488	Economy	11800.00
0005435462702	5488	Economy	11800.00
0005435462660	5488	Economy	11800.00
0005434265135	5488	Economy	11800.00
0005434265181	5488	Economy	11800.00
0005435766936	5488	Economy	11800.00
0005435462701	5488	Economy	11800.00
0005434831134	5488	Economy	11800.00
0005435766906	5488	Economy	11800.00
0005432535845	5488	Economy	11800.00
0005435735188	5488	Economy	11800.00
0005434265192	5488	Economy	11800.00
0005433529320	5488	Economy	11800.00
0005435766901	5488	Economy	11800.00
0005432535844	5488	Economy	11800.00
0005435766904	5488	Economy	11800.00
0005435766927	5488	Economy	11800.00
0005435766902	5488	Economy	11800.00
0005435766893	5488	Economy	11800.00
0005435766880	5488	Economy	11800.00
0005435766918	5488	Economy	11800.00
0005435462501	5488	Economy	11800.00
0005435766894	5488	Economy	11800.00
0005435766878	5488	Economy	11800.00
0005435462565	5488	Economy	11800.00
0005434265058	5488	Economy	11800.00
0005435462488	5488	Economy	11800.00
0005434265170	5488	Economy	11800.00
0005435766888	5488	Economy	11800.00
0005435766914	5488	Economy	11800.00
0005432535843	5488	Economy	11800.00
0005435766912	5488	Economy	11800.00
0005434831144	5488	Economy	11800.00
0005435723068	5488	Economy	11800.00
0005434831157	5488	Economy	11800.00
0005432140540	5488	Economy	11800.00
0005435766875	5488	Economy	11800.00
0005435766926	5488	Economy	11800.00
0005434831163	5488	Economy	11800.00
0005435462604	5488	Economy	11800.00
0005435617170	5488	Economy	11800.00
0005435766882	5488	Economy	11800.00
0005435766940	5488	Economy	11800.00
0005435735186	5488	Economy	11800.00
0005435766881	5488	Economy	11800.00
0005435462703	5488	Economy	11800.00
0005435766916	5488	Economy	11800.00
0005435462521	5488	Economy	11800.00
0005435766884	5488	Economy	11800.00
0005434265193	5488	Economy	11800.00
0005434265144	5488	Economy	11800.00
0005434831135	5488	Economy	11800.00
0005435462583	5488	Economy	11800.00
0005435722082	5488	Economy	11800.00
0005435766917	5488	Economy	11800.00
0005435766886	5488	Economy	11800.00
0005434265136	5488	Economy	11800.00
0005434265165	5488	Economy	11800.00
0005435766903	5488	Economy	11800.00
0005434265260	5488	Economy	11800.00
0005435766879	5488	Economy	11800.00
0005435462421	5488	Economy	11800.00
0005435723066	5488	Economy	11800.00
0005435462518	5488	Economy	11800.00
0005435766890	5488	Economy	11800.00
0005432535839	5488	Economy	11800.00
0005435766900	5488	Economy	11800.00
0005435766942	5488	Economy	11800.00
0005435725650	5488	Economy	11800.00
0005435766905	5488	Economy	11800.00
0005435766923	5488	Economy	11800.00
0005435462453	5488	Economy	11800.00
0005435766887	5488	Economy	11800.00
0005435462505	5488	Economy	11800.00
0005435462564	5488	Economy	11800.00
0005433529319	5488	Economy	11800.00
0005433527311	5488	Economy	11800.00
0005434831166	5488	Economy	11800.00
0005432140541	5488	Economy	11800.00
0005435766937	5488	Economy	11800.00
0005435725651	5488	Economy	12900.00
0005435462519	5488	Economy	11800.00
0005435766891	5488	Economy	11800.00
0005435462411	5488	Economy	11800.00
0005435462633	5488	Economy	12900.00
0005435766889	5488	Economy	11800.00
0005435462531	5488	Economy	11800.00
0005435725652	5488	Economy	11800.00
0005433529322	5488	Economy	11800.00
0005435766919	5488	Economy	11800.00
0005435766876	5488	Economy	11800.00
0005434831177	5488	Economy	11800.00
0005432140535	5488	Economy	11800.00
0005434265069	5488	Economy	11800.00
0005435766935	5488	Economy	11800.00
0005434831142	5488	Economy	11800.00
0005434265043	5488	Economy	11800.00
0005435462347	5488	Economy	11800.00
0005435766897	5488	Economy	11800.00
0005435766924	5488	Economy	11800.00
0005435766922	5488	Economy	11800.00
0005435735184	5488	Economy	11800.00
0005435462484	5488	Economy	11800.00
0005435462582	5488	Economy	11800.00
0005434265259	5488	Economy	11800.00
0005435766932	5488	Economy	11800.00
0005433527310	5488	Economy	11800.00
0005432140536	5488	Economy	11800.00
0005435766941	5488	Economy	11800.00
0005432535855	5488	Economy	11800.00
0005435720836	5488	Economy	11800.00
0005435766895	5488	Economy	11800.00
0005435725654	5488	Economy	11800.00
0005432140542	5488	Economy	11800.00
0005434265129	5488	Economy	11800.00
0005435766938	5488	Economy	11800.00
0005435735185	5488	Economy	11800.00
0005435617169	5488	Economy	11800.00
0005435766907	5488	Economy	11800.00
0005433529321	5488	Economy	11800.00
0005435462532	5488	Economy	11800.00
0005435766910	5488	Economy	11800.00
0005435766908	5488	Economy	11800.00
0005432140539	5488	Economy	11800.00
0005435766931	5488	Economy	11800.00
0005435462534	5488	Economy	11800.00
0005435766929	5488	Economy	11800.00
0005435462516	5488	Economy	11800.00
0005435766898	5488	Economy	11800.00
0005435720835	5488	Economy	11800.00
0005432535840	5488	Economy	11800.00
0005434265213	5488	Economy	11800.00
0005434265044	5488	Economy	11800.00
0005435766920	5488	Economy	11800.00
0005435462605	5488	Economy	11800.00
0005435462528	5488	Economy	11800.00
0005434831156	5488	Economy	11800.00
0005432535857	5488	Economy	11800.00
0005435766930	5488	Economy	11800.00
0005435723067	5488	Economy	11800.00
0005435722081	5488	Economy	11800.00
0005434831139	5488	Economy	11800.00
0005435766909	5488	Economy	11800.00
0005435766933	5488	Economy	11800.00
0005435766892	5488	Economy	11800.00
0005435766939	5488	Economy	11800.00
0005435462477	5488	Economy	11800.00
0005432535856	5488	Economy	11800.00
0005435766921	5488	Economy	11800.00
0005435766885	5488	Economy	11800.00
0005435725653	5488	Economy	11800.00
0005435462852	13444	Business	35300.00
0005435766269	13444	Business	35300.00
0005435462873	13444	Business	35300.00
0005435735150	13444	Business	35300.00
0005435766183	13444	Business	35300.00
0005435766468	13444	Business	35300.00
0005435766281	13444	Business	35300.00
0005435462866	13444	Business	35300.00
0005435766216	13444	Business	35300.00
0005435766423	13444	Business	35300.00
0005435462847	13444	Business	35300.00
0005435462856	13444	Business	35300.00
0005435766606	13444	Business	35300.00
0005435766425	13444	Business	35300.00
0005435462859	13444	Business	35300.00
0005435462871	13444	Business	35300.00
0005435766598	13444	Business	35300.00
0005435725608	13444	Business	35300.00
0005435722055	13444	Business	35300.00
0005435462857	13444	Business	35300.00
0005435766550	13444	Economy	12900.00
0005435766512	13444	Economy	12900.00
0005435766402	13444	Economy	12900.00
0005435766285	13444	Economy	12900.00
0005435462865	13444	Economy	11800.00
0005435766532	13444	Economy	11800.00
0005435735140	13444	Economy	11800.00
0005435735148	13444	Economy	11800.00
0005435766224	13444	Economy	11800.00
0005435723053	13444	Economy	11800.00
0005434265418	13444	Economy	11800.00
0005435462851	13444	Economy	11800.00
0005435766548	13444	Economy	11800.00
0005435722064	13444	Economy	11800.00
0005435766266	13444	Economy	11800.00
0005434831203	13444	Economy	11800.00
0005435766348	13444	Economy	11800.00
0005435766338	13444	Economy	11800.00
0005435766403	13444	Economy	11800.00
0005435766346	13444	Economy	11800.00
0005435462876	13444	Economy	11800.00
0005435725615	13444	Economy	11800.00
0005435766300	13444	Economy	11800.00
0005434265434	13444	Economy	11800.00
0005435766336	13444	Economy	11800.00
0005434265426	13444	Economy	11800.00
0005435766436	13444	Economy	11800.00
0005432535889	13444	Economy	11800.00
0005435766347	13444	Economy	11800.00
0005434265431	13444	Economy	11800.00
0005434265437	13444	Economy	11800.00
0005435462855	13444	Economy	11800.00
0005435766437	13444	Economy	11800.00
0005435766206	13444	Economy	11800.00
0005435462864	13444	Economy	11800.00
0005435462870	13444	Economy	11800.00
0005435766270	13444	Economy	11800.00
0005435766014	13444	Economy	11800.00
0005432194558	13444	Economy	11800.00
0005435766301	13444	Economy	11800.00
0005435462842	13444	Economy	11800.00
0005435735152	13444	Economy	11800.00
0005432194555	13444	Economy	11800.00
0005434265432	13444	Economy	11800.00
0005435723037	13444	Economy	11800.00
0005435766428	13444	Economy	11800.00
0005434265417	13444	Economy	11800.00
0005435462867	13444	Economy	11800.00
0005435766589	13444	Economy	11800.00
0005434265430	13444	Economy	11800.00
0005434265428	13444	Economy	11800.00
0005435462839	13444	Economy	11800.00
0005432535888	13444	Economy	11800.00
0005435766225	13444	Economy	11800.00
0005435735137	13444	Economy	11800.00
0005435766344	13444	Economy	11800.00
0005432194559	13444	Economy	11800.00
0005435766226	13444	Economy	11800.00
0005435462868	13444	Economy	11800.00
0005435462846	13444	Economy	11800.00
0005435766351	13444	Economy	11800.00
0005435462840	13444	Economy	11800.00
0005434265424	13444	Economy	11800.00
0005434265419	13444	Economy	11800.00
0005435735149	13444	Economy	11800.00
0005434265421	13444	Economy	11800.00
0005434831206	13444	Economy	11800.00
0005434265425	13444	Economy	11800.00
0005435766392	13444	Economy	11800.00
0005435766342	13444	Economy	11800.00
0005434831204	13444	Economy	11800.00
0005435462861	13444	Economy	11800.00
0005435766409	13444	Economy	11800.00
0005432194556	13444	Economy	11800.00
0005435766248	13444	Economy	11800.00
0005435766317	13444	Economy	11800.00
0005435462862	13444	Economy	11800.00
0005435462844	13444	Economy	11800.00
0005435766353	13444	Economy	11800.00
0005435462860	13444	Economy	12900.00
0005435766349	13444	Economy	12900.00
0005435462874	13444	Economy	11800.00
0005435462843	13444	Economy	11800.00
0005435462853	13444	Economy	11800.00
0005434265427	13444	Economy	12900.00
0005432194560	13444	Economy	11800.00
0005432535890	13444	Economy	11800.00
0005435735139	13444	Economy	11800.00
0005435462849	13444	Economy	11800.00
0005435766412	13444	Economy	11800.00
0005435766212	13444	Economy	11800.00
0005435766451	13444	Economy	11800.00
0005435723038	13444	Economy	11800.00
0005435766240	13444	Economy	11800.00
0005435462869	13444	Economy	11800.00
0005435766211	13444	Economy	11800.00
0005435766227	13444	Economy	11800.00
0005435766215	13444	Economy	11800.00
0005434265420	13444	Economy	11800.00
0005435462848	13444	Economy	11800.00
0005435766334	13444	Economy	11800.00
0005435462838	13444	Economy	11800.00
0005435766164	13444	Economy	11800.00
0005435766241	13444	Economy	11800.00
0005435766408	13444	Economy	11800.00
0005435766284	13444	Economy	11800.00
0005435766239	13444	Economy	11800.00
0005434265422	13444	Economy	11800.00
0005435766265	13444	Economy	11800.00
0005435462872	13444	Economy	11800.00
0005434265416	13444	Economy	11800.00
0005432194557	13444	Economy	11800.00
0005435766116	13444	Economy	11800.00
0005435766569	13444	Economy	11800.00
0005435765897	13444	Economy	11800.00
0005434265429	13444	Economy	11800.00
0005434265440	13444	Economy	11800.00
0005432535887	13444	Economy	11800.00
0005434265436	13444	Economy	11800.00
0005435766417	13444	Economy	11800.00
0005435462845	13444	Economy	11800.00
0005434265435	13444	Economy	11800.00
0005435766259	13444	Economy	11800.00
0005435766570	13444	Economy	11800.00
0005435462850	13444	Economy	11800.00
0005434265438	13444	Economy	11800.00
0005435766605	13444	Economy	11800.00
0005435766350	13444	Economy	11800.00
0005435766107	13444	Economy	11800.00
0005434831205	13444	Economy	11800.00
0005435462863	13444	Economy	11800.00
0005435725607	13444	Economy	11800.00
0005434265439	13444	Economy	11800.00
0005434265423	13444	Economy	11800.00
0005435462858	13444	Economy	11800.00
0005435766205	13444	Economy	11800.00
0005435766339	13444	Economy	11800.00
0005435766426	13444	Economy	11800.00
0005435766213	13444	Economy	11800.00
0005435766411	13444	Economy	11800.00
0005435462841	13444	Economy	11800.00
0005434265441	13444	Economy	11800.00
0005434265433	13444	Economy	11800.00
0005435766293	13444	Economy	11800.00
0005435462854	13444	Economy	11800.00
0005435462875	13444	Economy	11800.00
0005435766292	13444	Economy	11800.00
0005435766551	13444	Economy	11800.00
0005434602896	18708	Economy	3300.00
0005434602910	18708	Economy	3300.00
0005434514994	18716	Economy	3300.00
0005434513606	18716	Economy	3300.00
0005434604907	18716	Economy	3300.00
0005434604906	18716	Economy	3300.00
0005434514995	18716	Economy	3300.00
0005434513607	18716	Economy	3300.00
0005434604892	18716	Economy	3300.00
0005434604908	18716	Economy	3300.00
0005434513608	18716	Economy	3300.00
0005434602925	19141	Economy	3300.00
0005434602923	19141	Economy	3300.00
0005434602926	19141	Economy	3300.00
0005434602924	19141	Economy	3300.00
0005434602928	19141	Economy	3300.00
0005434602927	19141	Economy	3300.00
0005434514975	19141	Economy	3300.00
0005434514984	19141	Economy	3300.00
0005435846291	25094	Business	88300.00
0005435846292	25094	Business	88300.00
0005432632753	25094	Business	88300.00
0005432632717	25094	Business	88300.00
0005432632751	25094	Business	88300.00
0005432632736	25094	Business	88300.00
0005435846294	25094	Business	88300.00
0005435844351	25094	Business	88300.00
0005435844356	25094	Business	88300.00
0005435846293	25094	Economy	29400.00
0005432632749	25094	Economy	29400.00
0005432632720	25094	Economy	29400.00
0005432649416	25094	Economy	32400.00
0005435844359	25094	Economy	32400.00
0005435846288	25094	Economy	32400.00
0005432632713	25094	Economy	29400.00
0005432649411	25094	Economy	29400.00
0005435844355	25094	Economy	29400.00
0005432632737	25094	Economy	29400.00
0005432632752	25094	Economy	29400.00
0005432649397	25094	Economy	29400.00
0005432649398	25094	Economy	29400.00
0005432632726	25094	Economy	29400.00
0005432632738	25094	Economy	29400.00
0005432649433	25094	Economy	29400.00
0005432632727	25094	Economy	29400.00
0005432649399	25094	Economy	29400.00
0005435846295	25094	Economy	29400.00
0005435844354	25094	Economy	29400.00
0005432632724	25094	Economy	29400.00
0005432649404	25094	Economy	29400.00
0005432632714	25094	Economy	29400.00
0005435844353	25094	Economy	29400.00
0005435844352	25094	Economy	29400.00
0005435844362	25094	Economy	29400.00
0005432632743	25094	Economy	29400.00
0005435846290	25094	Economy	29400.00
0005432632686	25094	Economy	29400.00
0005435844357	25094	Economy	29400.00
0005432632721	25094	Economy	29400.00
0005435844360	25094	Economy	29400.00
0005435844361	25094	Economy	29400.00
0005432632685	25094	Economy	29400.00
0005432649414	25094	Economy	29400.00
0005435844358	25094	Economy	29400.00
0005432632745	25094	Economy	29400.00
0005435844350	25094	Economy	29400.00
0005432632735	25094	Economy	29400.00
0005432632754	25094	Economy	29400.00
0005435846289	25094	Economy	29400.00
0005432632750	25094	Economy	29400.00
0005433285423	1881	Business	48700.00
0005433285322	1881	Business	48700.00
0005433285414	1881	Business	48700.00
0005433008836	1881	Business	48700.00
0005433285213	1881	Business	48700.00
0005433008761	1881	Business	48700.00
0005433810587	1881	Business	48700.00
0005433285365	1881	Business	48700.00
0005433285332	1881	Business	48700.00
0005433285287	1881	Business	48700.00
0005432295909	1881	Business	48700.00
0005433008724	1881	Economy	16200.00
0005433810594	1881	Economy	16200.00
0005433008875	1881	Economy	16200.00
0005433008515	1881	Economy	16200.00
0005433008886	1881	Economy	16200.00
0005433285426	1881	Economy	16200.00
0005433008845	1881	Economy	16200.00
0005433008605	1881	Economy	16200.00
0005433285402	1881	Economy	16200.00
0005433008844	1881	Economy	17900.00
0005433285447	1881	Economy	17900.00
0005433008651	1881	Economy	17900.00
0005433285469	1881	Economy	17900.00
0005433810593	1881	Economy	16200.00
0005433008612	1881	Economy	16200.00
0005433009023	1881	Economy	16200.00
0005433008759	1881	Economy	16200.00
0005433008723	1881	Economy	16200.00
0005433008583	1881	Economy	16200.00
0005433008639	1881	Economy	16200.00
0005433285372	1881	Economy	16200.00
0005433008814	1881	Economy	16200.00
0005433008762	1881	Economy	16200.00
0005433810597	1881	Economy	16200.00
0005433810592	1881	Economy	16200.00
0005433285510	1881	Economy	16200.00
0005433285335	1881	Economy	16200.00
0005433008729	1881	Economy	16200.00
0005433285392	1881	Economy	16200.00
0005433285338	1881	Economy	16200.00
0005433285438	1881	Economy	16200.00
0005433285425	1881	Economy	16200.00
0005433285303	1881	Economy	16200.00
0005433008698	1881	Economy	16200.00
0005433810591	1881	Economy	16200.00
0005433285212	1881	Economy	16200.00
0005433810588	1881	Economy	16200.00
0005433810586	1881	Economy	16200.00
0005433285354	1881	Economy	16200.00
0005433285360	1881	Economy	16200.00
0005433285417	1881	Economy	16200.00
0005433810595	1881	Economy	16200.00
0005433810596	1881	Economy	16200.00
0005433810589	1881	Economy	16200.00
0005433008828	1881	Economy	16200.00
0005433285395	1881	Economy	16200.00
0005433008643	1881	Economy	16200.00
0005433285394	1881	Economy	16200.00
0005433285334	1881	Economy	16200.00
0005433285288	1881	Economy	16200.00
0005433285559	1881	Economy	16200.00
0005433008827	1881	Economy	16200.00
0005433008766	1881	Economy	16200.00
0005433008887	1881	Economy	16200.00
0005433285359	1881	Economy	16200.00
0005433008899	1881	Economy	16200.00
0005433285434	1881	Economy	16200.00
0005433285353	1881	Economy	16200.00
0005433285424	1881	Economy	16200.00
0005433008792	1881	Economy	16200.00
0005433285439	1881	Economy	16200.00
0005433285506	1881	Economy	16200.00
0005432295908	1881	Economy	16200.00
0005433008642	1881	Economy	16200.00
0005433285422	1881	Economy	16200.00
0005433285448	1881	Economy	16200.00
0005433008699	1881	Economy	16200.00
0005433810590	1881	Economy	16200.00
0005433008760	1881	Economy	16200.00
0005433008793	1881	Economy	16200.00
0005433008613	1881	Economy	16200.00
0005433285452	1881	Economy	16200.00
0005433008787	1881	Economy	16200.00
0005433008714	1881	Economy	16200.00
0005433285333	1881	Economy	16200.00
0005433008695	1881	Economy	16200.00
0005433285630	22581	Business	48700.00
0005433009109	22581	Business	48700.00
0005433009089	22581	Business	48700.00
0005433009120	22581	Business	48700.00
0005433285632	22581	Business	48700.00
0005433285633	22581	Business	48700.00
0005433285628	22581	Business	48700.00
0005433009080	22581	Business	48700.00
0005433009119	22581	Business	48700.00
0005433285635	22581	Business	48700.00
0005433285615	22581	Business	48700.00
0005433285640	22581	Business	48700.00
0005433285636	22581	Economy	16200.00
0005433009084	22581	Economy	16200.00
0005433285638	22581	Economy	16200.00
0005433009101	22581	Economy	16200.00
0005433009096	22581	Economy	16200.00
0005433285619	22581	Economy	16200.00
0005433009111	22581	Economy	16200.00
0005433009114	22581	Economy	17900.00
0005433285645	22581	Economy	17900.00
0005433285641	22581	Economy	17900.00
0005433009103	22581	Economy	17900.00
0005433009098	22581	Economy	17900.00
0005433009088	22581	Economy	16200.00
0005433285620	22581	Economy	16200.00
0005433285642	22581	Economy	16200.00
0005433285639	22581	Economy	16200.00
0005433009081	22581	Economy	16200.00
0005433285643	22581	Economy	16200.00
0005433285626	22581	Economy	16200.00
0005433009085	22581	Economy	16200.00
0005433285622	22581	Economy	16200.00
0005433009116	22581	Economy	16200.00
0005433009110	22581	Economy	16200.00
0005433009112	22581	Economy	16200.00
0005433285614	22581	Economy	16200.00
0005433009095	22581	Economy	16200.00
0005433009083	22581	Economy	16200.00
0005433009123	22581	Economy	16200.00
0005433285618	22581	Economy	16200.00
0005433285616	22581	Economy	16200.00
0005433810531	22581	Economy	16200.00
0005433285627	22581	Economy	16200.00
0005433285625	22581	Economy	16200.00
0005433009105	22581	Economy	16200.00
0005433009104	22581	Economy	16200.00
0005433009102	22581	Economy	16200.00
0005433009078	22581	Economy	16200.00
0005433009075	22581	Economy	16200.00
0005433009079	22581	Economy	16200.00
0005433009107	22581	Economy	16200.00
0005433009115	22581	Economy	16200.00
0005433009082	22581	Economy	16200.00
0005433009117	22581	Economy	16200.00
0005433285644	22581	Economy	16200.00
0005433285623	22581	Economy	16200.00
0005433009086	22581	Economy	16200.00
0005433009099	22581	Economy	16200.00
0005433285617	22581	Economy	16200.00
0005433009108	22581	Economy	16200.00
0005433009094	22581	Economy	16200.00
0005433285629	22581	Economy	16200.00
0005433009091	22581	Economy	16200.00
0005433009074	22581	Economy	16200.00
0005433810532	22581	Economy	16200.00
0005433009113	22581	Economy	16200.00
0005433009092	22581	Economy	16200.00
0005433009122	22581	Economy	16200.00
0005433285621	22581	Economy	16200.00
0005433009097	22581	Economy	16200.00
0005433285624	22581	Economy	16200.00
0005433285631	22581	Economy	16200.00
0005433009087	22581	Economy	16200.00
0005433009093	22581	Economy	16200.00
0005433009090	22581	Economy	16200.00
0005433009106	22581	Economy	16200.00
0005433009077	22581	Economy	16200.00
0005433285637	22581	Economy	16200.00
0005433009118	22581	Economy	16200.00
0005433009121	22581	Economy	16200.00
0005433009100	22581	Economy	16200.00
0005433285634	22581	Economy	16200.00
0005433009076	22581	Economy	16200.00
0005432755106	25337	Business	83800.00
0005434153538	25337	Business	83800.00
0005432756874	25337	Economy	27900.00
0005432756876	25337	Economy	27900.00
0005432755103	25337	Economy	27900.00
0005432755099	25337	Economy	27900.00
0005432755107	25337	Economy	27900.00
0005434153530	25337	Economy	27900.00
0005432755110	25337	Economy	30700.00
0005432756881	25337	Economy	30700.00
0005434153534	25337	Economy	27900.00
0005434153537	25337	Economy	27900.00
0005432756873	25337	Economy	27900.00
0005432755104	25337	Economy	27900.00
0005432755097	25337	Economy	27900.00
0005432755108	25337	Economy	27900.00
0005432756875	25337	Economy	27900.00
0005432755100	25337	Economy	27900.00
0005434152788	25337	Economy	27900.00
0005434152781	25337	Economy	27900.00
0005432755102	25337	Economy	27900.00
0005434153528	25337	Economy	27900.00
0005432756870	25337	Economy	27900.00
0005432755105	25337	Economy	27900.00
0005434152789	25337	Economy	27900.00
0005434152787	25337	Economy	27900.00
0005432755109	25337	Economy	27900.00
0005432756869	25337	Economy	27900.00
0005432756872	25337	Economy	27900.00
0005432756877	25337	Economy	27900.00
0005432756878	25337	Economy	27900.00
0005434153533	25337	Economy	27900.00
0005432756871	25337	Economy	27900.00
0005432756882	25337	Economy	27900.00
0005434153531	25337	Economy	27900.00
0005432755111	25337	Economy	27900.00
0005434153535	25337	Economy	27900.00
0005432755101	25337	Economy	27900.00
0005432756879	25337	Economy	27900.00
0005432756880	25337	Economy	27900.00
0005432755098	25337	Economy	27900.00
0005434153532	25337	Economy	27900.00
0005433847359	5592	Business	99800.00
0005432081583	5592	Business	99800.00
0005432081581	5592	Business	99800.00
0005433847339	5592	Business	99800.00
0005435282657	5592	Business	99800.00
0005433847348	5592	Business	99800.00
0005433847373	5592	Business	99800.00
0005433847358	5592	Business	99800.00
0005433847368	5592	Business	99800.00
0005435282561	5592	Business	99800.00
0005432081585	5592	Business	99800.00
0005433847392	5592	Business	99800.00
0005433847354	5592	Business	99800.00
0005435282589	5592	Business	99800.00
0005433815435	5592	Business	99800.00
0005435282663	5592	Business	99800.00
0005435282636	5592	Business	99800.00
0005435282615	5592	Business	99800.00
0005433815439	5592	Business	99800.00
0005433847349	5592	Economy	33300.00
0005433847342	5592	Business	99800.00
0005433847378	5592	Economy	33300.00
0005435282583	5592	Economy	33300.00
0005433847338	5592	Economy	33300.00
0005433847393	5592	Economy	33300.00
0005435282594	5592	Economy	33300.00
0005433847381	5592	Economy	33300.00
0005433847341	5592	Economy	33300.00
0005434173540	5592	Economy	33300.00
0005433847389	5592	Economy	33300.00
0005433815434	5592	Economy	36600.00
0005435282572	5592	Economy	36600.00
0005433815437	5592	Economy	36600.00
0005435282623	5592	Economy	33300.00
0005432081582	5592	Economy	33300.00
0005433815438	5592	Economy	33300.00
0005433847385	5592	Economy	33300.00
0005433847352	5592	Economy	33300.00
0005435282504	5592	Economy	33300.00
0005435282511	5592	Economy	33300.00
0005433847346	5592	Economy	33300.00
0005433847383	5592	Economy	33300.00
0005433847363	5592	Economy	33300.00
0005433847391	5592	Economy	33300.00
0005435282573	5592	Economy	33300.00
0005435282489	5592	Economy	33300.00
0005433847395	5592	Economy	33300.00
0005435282481	5592	Economy	33300.00
0005435282612	5592	Economy	33300.00
0005435282524	5592	Economy	33300.00
0005433847369	5592	Economy	33300.00
0005433847388	5592	Economy	33300.00
0005433847365	5592	Economy	33300.00
0005435282539	5592	Economy	33300.00
0005433847371	5592	Economy	33300.00
0005433847394	5592	Economy	33300.00
0005435282540	5592	Economy	33300.00
0005435282499	5592	Economy	33300.00
0005433847351	5592	Economy	33300.00
0005433847377	5592	Economy	33300.00
0005432081579	5592	Economy	33300.00
0005435282409	5592	Economy	33300.00
0005433847374	5592	Economy	33300.00
0005433815436	5592	Economy	33300.00
0005433847364	5592	Economy	33300.00
0005433847390	5592	Economy	33300.00
0005433847344	5592	Economy	33300.00
0005433847387	5592	Economy	33300.00
0005433847353	5592	Economy	33300.00
0005433847362	5592	Economy	33300.00
0005433847370	5592	Economy	33300.00
0005434173536	5592	Economy	33300.00
0005433847350	5592	Economy	33300.00
0005433847340	5592	Economy	33300.00
0005433847361	5592	Economy	33300.00
0005433847343	5592	Economy	33300.00
0005433847380	5592	Economy	33300.00
0005432081584	5592	Economy	33300.00
0005435282616	5592	Economy	33300.00
0005435282525	5592	Economy	33300.00
0005433847357	5592	Economy	33300.00
0005433847360	5592	Economy	33300.00
0005435282534	5592	Economy	33300.00
0005433847382	5592	Economy	33300.00
0005434173537	5592	Economy	33300.00
0005433847384	5592	Economy	33300.00
0005433847372	5592	Economy	33300.00
0005433847375	5592	Economy	33300.00
0005435282613	5592	Economy	33300.00
0005433847379	5592	Economy	33300.00
0005433847345	5592	Economy	33300.00
0005433847386	5592	Economy	33300.00
0005432081580	5592	Economy	33300.00
0005435282454	5592	Economy	33300.00
0005433847376	5592	Economy	33300.00
0005433847347	5592	Economy	33300.00
0005433847367	5592	Economy	33300.00
0005433847356	5592	Economy	33300.00
0005433847355	5592	Economy	33300.00
0005435282662	5592	Economy	33300.00
0005433847366	5592	Economy	33300.00
0005435282453	5592	Economy	33300.00
0005433846922	13832	Business	99800.00
0005433846710	13832	Business	99800.00
0005435282785	13832	Business	99800.00
0005433846893	13832	Business	99800.00
0005433846819	13832	Business	99800.00
0005433847035	13832	Business	99800.00
0005433846871	13832	Business	99800.00
0005433846966	13832	Business	99800.00
0005433846807	13832	Business	99800.00
0005433846709	13832	Business	99800.00
0005433847072	13832	Business	99800.00
0005433846907	13832	Business	99800.00
0005434173566	13832	Business	99800.00
0005433846914	13832	Business	99800.00
0005435282788	13832	Economy	33300.00
0005433846829	13832	Business	99800.00
0005433847067	13832	Economy	33300.00
0005433846731	13832	Economy	33300.00
0005432003736	13832	Economy	33300.00
0005433846935	13832	Economy	33300.00
0005433846824	13832	Economy	33300.00
0005435282772	13832	Economy	33300.00
0005435282780	13832	Economy	33300.00
0005435282787	13832	Economy	33300.00
0005433846896	13832	Economy	33300.00
0005433846814	13832	Economy	36600.00
0005433847008	13832	Economy	36600.00
0005433846901	13832	Economy	36600.00
0005433847020	13832	Economy	33300.00
0005433846870	13832	Economy	33300.00
0005433847021	13832	Economy	33300.00
0005433846921	13832	Economy	33300.00
0005433847261	13832	Economy	33300.00
0005432003737	13832	Economy	33300.00
0005435282773	13832	Economy	33300.00
0005432003738	13832	Economy	33300.00
0005433846906	13832	Economy	33300.00
0005435282790	13832	Economy	33300.00
0005433846694	13832	Economy	33300.00
0005433846915	13832	Economy	33300.00
0005435282776	13832	Economy	33300.00
0005433846804	13832	Economy	33300.00
0005433846670	13832	Economy	33300.00
0005433846869	13832	Economy	33300.00
0005433815390	13832	Economy	33300.00
0005433846889	13832	Economy	33300.00
0005435282774	13832	Economy	33300.00
0005433846904	13832	Economy	33300.00
0005433815399	13832	Economy	33300.00
0005433846934	13832	Economy	33300.00
0005433846897	13832	Economy	33300.00
0005435282789	13832	Economy	33300.00
0005433846752	13832	Economy	33300.00
0005433846695	13832	Economy	33300.00
0005433846910	13832	Economy	33300.00
0005435282777	13832	Economy	33300.00
0005433846837	13832	Economy	33300.00
0005435282778	13832	Economy	33300.00
0005435282771	13832	Economy	33300.00
0005433846917	13832	Economy	33300.00
0005433846903	13832	Economy	33300.00
0005433846902	13832	Economy	33300.00
0005433846866	13832	Economy	33300.00
0005433846815	13832	Economy	33300.00
0005433815398	13832	Economy	33300.00
0005434173564	13832	Economy	33300.00
0005435282786	13832	Economy	33300.00
0005433847071	13832	Economy	33300.00
0005435282779	13832	Economy	33300.00
0005433846708	13832	Economy	33300.00
0005433846797	13832	Economy	33300.00
0005433847073	13832	Economy	33300.00
0005433846908	13832	Economy	33300.00
0005435282781	13832	Economy	33300.00
0005434173565	13832	Economy	33300.00
0005435282775	13832	Economy	33300.00
0005435282782	13832	Economy	33300.00
0005433846656	13832	Economy	33300.00
0005433846770	13832	Economy	33300.00
0005432003735	13832	Economy	33300.00
0005433846911	13832	Economy	33300.00
0005433846751	13832	Economy	33300.00
0005435282783	13832	Economy	33300.00
0005435282784	13832	Economy	33300.00
0005433846872	13832	Economy	33300.00
0005433846693	13832	Economy	33300.00
0005433846823	13832	Economy	33300.00
0005434620815	7847	Economy	16600.00
0005434620814	7847	Economy	16600.00
0005434620812	7847	Economy	16600.00
0005434620820	7847	Economy	15100.00
0005434620817	7847	Economy	15100.00
0005435332391	7847	Economy	15100.00
0005435332373	7847	Economy	15100.00
0005435332411	7847	Economy	15100.00
0005434620816	7847	Economy	15100.00
0005434620832	7847	Economy	15100.00
0005434620827	7847	Economy	15100.00
0005435332410	7847	Economy	15100.00
0005434620811	7847	Economy	15100.00
0005434620829	7847	Economy	15100.00
0005434620824	7847	Economy	15100.00
0005435332346	7847	Economy	15100.00
0005434620813	7847	Economy	15100.00
0005434620825	7847	Economy	15100.00
0005435332356	7847	Economy	15100.00
0005434620819	7847	Economy	15100.00
0005434620826	7847	Economy	15100.00
0005434620823	7847	Economy	15100.00
0005434620821	7847	Economy	15100.00
0005434620830	7847	Economy	15100.00
0005432112541	7847	Economy	15100.00
0005435332357	7847	Economy	15100.00
0005434620818	7847	Economy	15100.00
0005435332365	7847	Economy	15100.00
0005435332372	7847	Economy	15100.00
0005434620828	7847	Economy	15100.00
0005434620831	7847	Economy	15100.00
0005434620822	7847	Economy	15100.00
0005435332371	7847	Economy	15100.00
0005432112540	7847	Economy	15100.00
0005435332451	32987	Economy	16600.00
0005434620586	32987	Economy	16600.00
0005434620630	32987	Economy	15100.00
0005434620712	32987	Economy	15100.00
0005435332453	32987	Economy	15100.00
0005435332450	32987	Economy	15100.00
0005434620715	32987	Economy	15100.00
0005434620636	32987	Economy	15100.00
0005434620642	32987	Economy	15100.00
0005435332452	32987	Economy	15100.00
0005434620628	32987	Economy	15100.00
0005434620631	32987	Economy	15100.00
0005435332449	32987	Economy	15100.00
0005435332445	32987	Economy	15100.00
0005435332446	32987	Economy	15100.00
0005435332448	32987	Economy	15100.00
0005434620698	32987	Economy	15100.00
0005434620706	32987	Economy	15100.00
0005435332454	32987	Economy	15100.00
0005434620707	32987	Economy	15100.00
0005434620697	32987	Economy	15100.00
0005435332447	32987	Economy	15100.00
0005434620635	32987	Economy	15100.00
0005434620620	32987	Economy	15100.00
0005434620699	32987	Economy	15100.00
0005434620542	32987	Economy	15100.00
0005434620629	32987	Economy	15100.00
0005432190673	4292	Business	38000.00
0005435785735	4292	Business	38000.00
0005435785745	4292	Business	38000.00
0005432190674	4292	Business	38000.00
0005432190670	4292	Business	38000.00
0005435785754	4292	Business	38000.00
0005435787379	4292	Business	38000.00
0005435785737	4292	Business	38000.00
0005435785724	4292	Economy	12700.00
0005434994128	4292	Economy	12700.00
0005435785749	4292	Economy	12700.00
0005434994129	4292	Economy	12700.00
0005435785726	4292	Economy	13900.00
0005435785721	4292	Economy	13900.00
0005435785720	4292	Economy	13900.00
0005435937389	4292	Economy	13900.00
0005434994126	4292	Economy	12700.00
0005435785747	4292	Economy	12700.00
0005435787378	4292	Economy	12700.00
0005435785731	4292	Economy	12700.00
0005435785743	4292	Economy	12700.00
0005435785755	4292	Economy	12700.00
0005435785725	4292	Economy	12700.00
0005435787377	4292	Economy	12700.00
0005435785752	4292	Economy	12700.00
0005434994131	4292	Economy	12700.00
0005435785733	4292	Economy	12700.00
0005435785734	4292	Economy	12700.00
0005434994127	4292	Economy	12700.00
0005435785723	4292	Economy	12700.00
0005435785728	4292	Economy	12700.00
0005435785729	4292	Economy	12700.00
0005434994134	4292	Economy	12700.00
0005435918677	4292	Economy	12700.00
0005435785753	4292	Economy	12700.00
0005435785739	4292	Economy	12700.00
0005435785722	4292	Economy	12700.00
0005435785748	4292	Economy	12700.00
0005435785742	4292	Economy	12700.00
0005434994133	4292	Economy	12700.00
0005435785736	4292	Economy	12700.00
0005432190671	4292	Economy	12700.00
0005434994125	4292	Economy	12700.00
0005434994130	4292	Economy	12700.00
0005435785740	4292	Economy	12700.00
0005435785727	4292	Economy	12700.00
0005435785738	4292	Economy	12700.00
0005435785746	4292	Economy	12700.00
0005434994132	4292	Economy	12700.00
0005435785750	4292	Economy	12700.00
0005435785744	4292	Economy	12700.00
0005435785741	4292	Economy	12700.00
0005435785732	4292	Economy	12700.00
0005435937380	4292	Economy	12700.00
0005432190672	4292	Economy	12700.00
0005435918676	4292	Economy	12700.00
0005435785730	4292	Economy	12700.00
0005435785751	4292	Economy	12700.00
0005432195715	27278	Business	38000.00
0005435918707	27278	Business	38000.00
0005435937431	27278	Business	38000.00
0005435785254	27278	Business	38000.00
0005435785391	27278	Business	38000.00
0005435785404	27278	Economy	12700.00
0005435785419	27278	Economy	12700.00
0005435918710	27278	Economy	12700.00
0005435785460	27278	Economy	12700.00
0005435785439	27278	Economy	12700.00
0005435785438	27278	Economy	12700.00
0005435785332	27278	Economy	13900.00
0005435785392	27278	Economy	13900.00
0005434994013	27278	Economy	12700.00
0005434994048	27278	Economy	12700.00
0005434994014	27278	Economy	12700.00
0005435918708	27278	Economy	12700.00
0005435785421	27278	Economy	12700.00
0005435918711	27278	Economy	12700.00
0005435785447	27278	Economy	12700.00
0005434994064	27278	Economy	12700.00
0005435785281	27278	Economy	12700.00
0005434994047	27278	Economy	12700.00
0005435785334	27278	Economy	12700.00
0005435785420	27278	Economy	12700.00
0005435918709	27278	Economy	12700.00
0005435785370	27278	Economy	12700.00
0005435785426	27278	Economy	12700.00
0005435785389	27278	Economy	12700.00
0005435937430	27278	Economy	12700.00
0005435785371	27278	Economy	12700.00
0005435785434	27278	Economy	12700.00
0005435785349	27278	Economy	12700.00
0005435785423	27278	Economy	12700.00
0005435785390	27278	Economy	12700.00
0005435785275	27278	Economy	12700.00
0005435785308	27278	Economy	12700.00
0005435937432	27278	Economy	12700.00
0005435785422	27278	Economy	12700.00
0005435785437	27278	Economy	12700.00
0005435785325	27278	Economy	12700.00
0005435785310	27278	Economy	12700.00
0005435918706	27278	Economy	12700.00
0005435785327	27278	Economy	12700.00
0005435785444	27278	Economy	12700.00
0005435937429	27278	Economy	12700.00
0005435785182	27278	Economy	12700.00
0005432195714	27278	Economy	12700.00
0005435785252	27278	Economy	12700.00
0005435785373	27278	Economy	12700.00
0005432146219	19888	Economy	12800.00
0005432146220	19888	Economy	12800.00
0005434082167	4732	Business	40900.00
0005432460450	4732	Business	40900.00
0005432460407	4732	Business	40900.00
0005432460442	4732	Business	40900.00
0005432170462	4732	Business	40900.00
0005432568336	4732	Business	40900.00
0005432568302	4732	Business	40900.00
0005432568338	4732	Business	40900.00
0005434082165	4732	Business	40900.00
0005432568308	4732	Business	40900.00
0005432460400	4732	Business	40900.00
0005432568314	4732	Business	40900.00
0005432460445	4732	Business	40900.00
0005432571363	4732	Business	40900.00
0005432460426	4732	Business	40900.00
0005432568300	4732	Business	40900.00
0005433726130	4732	Business	40900.00
0005432568291	4732	Business	40900.00
0005432568296	4732	Business	40900.00
0005432460424	4732	Business	40900.00
0005432568311	4732	Business	40900.00
0005432460417	4732	Business	40900.00
0005432571365	4732	Economy	15000.00
0005432568307	4732	Economy	15000.00
0005432170460	4732	Economy	13600.00
0005432568332	4732	Economy	13600.00
0005434082169	4732	Economy	13600.00
0005432460425	4732	Economy	13600.00
0005432568280	4732	Economy	13600.00
0005432460446	4732	Economy	13600.00
0005432568329	4732	Economy	13600.00
0005432568294	4732	Economy	13600.00
0005432568339	4732	Economy	13600.00
0005432568293	4732	Economy	13600.00
0005432568298	4732	Economy	13600.00
0005432186911	4732	Economy	13600.00
0005432460437	4732	Economy	13600.00
0005432568328	4732	Economy	13600.00
0005432571362	4732	Economy	13600.00
0005434082158	4732	Economy	13600.00
0005432568310	4732	Economy	13600.00
0005432568286	4732	Economy	13600.00
0005432460399	4732	Economy	13600.00
0005434082160	4732	Economy	13600.00
0005434082162	4732	Economy	13600.00
0005432460410	4732	Economy	13600.00
0005432460452	4732	Economy	13600.00
0005433452763	4732	Economy	13600.00
0005432568304	4732	Economy	13600.00
0005432568279	4732	Economy	13600.00
0005432460401	4732	Economy	13600.00
0005432568278	4732	Economy	13600.00
0005432460451	4732	Economy	13600.00
0005432460412	4732	Economy	13600.00
0005432568321	4732	Economy	13600.00
0005432568297	4732	Economy	13600.00
0005432568299	4732	Economy	13600.00
0005432460434	4732	Economy	13600.00
0005432568323	4732	Economy	13600.00
0005433451640	4732	Economy	13600.00
0005432460439	4732	Economy	13600.00
0005432186910	4732	Economy	13600.00
0005432460420	4732	Economy	13600.00
0005432568285	4732	Economy	13600.00
0005432568331	4732	Economy	13600.00
0005432568284	4732	Economy	13600.00
0005432568303	4732	Economy	13600.00
0005432568281	4732	Economy	13600.00
0005432460403	4732	Economy	13600.00
0005432568334	4732	Economy	13600.00
0005432460404	4732	Economy	13600.00
0005432568326	4732	Economy	13600.00
0005432460402	4732	Economy	13600.00
0005432460423	4732	Economy	13600.00
0005432568306	4732	Economy	13600.00
0005432568309	4732	Economy	13600.00
0005432460406	4732	Economy	13600.00
0005432568312	4732	Economy	13600.00
0005432460441	4732	Economy	13600.00
0005433452762	4732	Economy	13600.00
0005434082168	4732	Economy	13600.00
0005432568301	4732	Economy	13600.00
0005432170465	4732	Economy	13600.00
0005432568287	4732	Economy	13600.00
0005432568305	4732	Economy	13600.00
0005432568318	4732	Economy	13600.00
0005432170464	4732	Economy	13600.00
0005434082161	4732	Economy	13600.00
0005432460416	4732	Economy	13600.00
0005432460427	4732	Economy	13600.00
0005434082175	4732	Economy	13600.00
0005432460414	4732	Economy	13600.00
0005432568337	4732	Economy	13600.00
0005432568313	4732	Economy	13600.00
0005433451641	4732	Economy	13600.00
0005434082172	4732	Economy	13600.00
0005432460432	4732	Economy	13600.00
0005432460443	4732	Economy	15000.00
0005432568290	4732	Economy	15000.00
0005432568292	4732	Economy	13600.00
0005432568277	4732	Economy	13600.00
0005432568315	4732	Economy	15000.00
0005432460419	4732	Economy	15000.00
0005432568289	4732	Economy	13600.00
0005432568317	4732	Economy	13600.00
0005432460435	4732	Economy	13600.00
0005432186912	4732	Economy	13600.00
0005432460409	4732	Economy	13600.00
0005432568330	4732	Economy	13600.00
0005432568327	4732	Economy	13600.00
0005432460422	4732	Economy	13600.00
0005432568335	4732	Economy	13600.00
0005432460408	4732	Economy	13600.00
0005432460421	4732	Economy	13600.00
0005432460430	4732	Economy	13600.00
0005432568322	4732	Economy	13600.00
0005432568325	4732	Economy	13600.00
0005432460440	4732	Economy	13600.00
0005432571364	4732	Economy	13600.00
0005432460448	4732	Economy	13600.00
0005432568288	4732	Economy	13600.00
0005432460413	4732	Economy	13600.00
0005434082170	4732	Economy	13600.00
0005432460411	4732	Economy	13600.00
0005432568283	4732	Economy	13600.00
0005432460418	4732	Economy	13600.00
0005432460405	4732	Economy	13600.00
0005432568316	4732	Economy	13600.00
0005432568324	4732	Economy	13600.00
0005432460415	4732	Economy	13600.00
0005432568333	4732	Economy	13600.00
0005434082166	4732	Economy	13600.00
0005432568320	4732	Economy	13600.00
0005432460429	4732	Economy	13600.00
0005432460436	4732	Economy	13600.00
0005434082171	4732	Economy	13600.00
0005432460438	4732	Economy	13600.00
0005434082173	4732	Economy	13600.00
0005432460428	4732	Economy	13600.00
0005432568319	4732	Economy	13600.00
0005434082159	4732	Economy	13600.00
0005432170461	4732	Economy	13600.00
0005432460433	4732	Economy	13600.00
0005433451642	4732	Economy	13600.00
0005432460444	4732	Economy	13600.00
0005432568282	4732	Economy	13600.00
0005432460431	4732	Economy	13600.00
0005432568295	4732	Economy	13600.00
0005432460449	4732	Economy	13600.00
0005432460447	4732	Economy	13600.00
0005434082164	4732	Economy	13600.00
0005432170463	4732	Economy	13600.00
0005434082163	4732	Economy	13600.00
0005434082174	4732	Economy	13600.00
0005432460053	30560	Business	40900.00
0005432460178	30560	Business	40900.00
0005432568027	30560	Business	40900.00
0005432459988	30560	Business	40900.00
0005432568057	30560	Business	40900.00
0005434081889	30560	Business	40900.00
0005432459935	30560	Business	40900.00
0005432459921	30560	Business	40900.00
0005432460091	30560	Business	40900.00
0005432161177	30560	Business	40900.00
0005432567938	30560	Business	40900.00
0005434081852	30560	Business	40900.00
0005432459996	30560	Business	40900.00
0005434081938	30560	Business	40900.00
0005432571327	30560	Business	40900.00
0005432459825	30560	Business	40900.00
0005434081853	30560	Business	40900.00
0005432460056	30560	Business	40900.00
0005434082081	30560	Business	40900.00
0005432460039	30560	Business	40900.00
0005432460016	30560	Business	40900.00
0005432567762	30560	Business	40900.00
0005434081964	30560	Business	40900.00
0005434081885	30560	Business	40900.00
0005432460130	30560	Economy	15000.00
0005434081960	30560	Economy	13600.00
0005432459915	30560	Economy	13600.00
0005432567710	30560	Economy	13600.00
0005432568059	30560	Economy	13600.00
0005432459995	30560	Economy	13600.00
0005434082028	30560	Economy	13600.00
0005432567608	30560	Economy	13600.00
0005434081974	30560	Economy	13600.00
0005432459936	30560	Economy	13600.00
0005432568001	30560	Economy	13600.00
0005432567860	30560	Economy	13600.00
0005432460270	30560	Economy	13600.00
0005432567587	30560	Economy	13600.00
0005432567935	30560	Economy	13600.00
0005433452731	30560	Economy	13600.00
0005434081952	30560	Economy	13600.00
0005434082014	30560	Economy	13600.00
0005432459944	30560	Economy	13600.00
0005432567824	30560	Economy	13600.00
0005432567756	30560	Economy	13600.00
0005432459895	30560	Economy	13600.00
0005432460003	30560	Economy	13600.00
0005432567792	30560	Economy	13600.00
0005432460107	30560	Economy	13600.00
0005434081953	30560	Economy	13600.00
0005432459984	30560	Economy	13600.00
0005432568044	30560	Economy	13600.00
0005432459832	30560	Economy	13600.00
0005432567562	30560	Economy	13600.00
0005432567798	30560	Economy	13600.00
0005432568055	30560	Economy	13600.00
0005432567894	30560	Economy	13600.00
0005432460040	30560	Economy	13600.00
0005432567863	30560	Economy	13600.00
0005432567941	30560	Economy	13600.00
0005432567728	30560	Economy	13600.00
0005432567915	30560	Economy	13600.00
0005432460236	30560	Economy	13600.00
0005432459989	30560	Economy	13600.00
0005432460068	30560	Economy	13600.00
0005432460141	30560	Economy	13600.00
0005432213648	30560	Economy	13600.00
0005434081928	30560	Economy	13600.00
0005432459859	30560	Economy	13600.00
0005434081890	30560	Economy	13600.00
0005432567820	30560	Economy	13600.00
0005432459803	30560	Economy	13600.00
0005434081924	30560	Economy	13600.00
0005432460065	30560	Economy	13600.00
0005432567797	30560	Economy	13600.00
0005432568026	30560	Economy	13600.00
0005432567652	30560	Economy	13600.00
0005432460067	30560	Economy	13600.00
0005432567936	30560	Economy	13600.00
0005432567793	30560	Economy	13600.00
0005432460122	30560	Economy	13600.00
0005432567842	30560	Economy	13600.00
0005432567802	30560	Economy	13600.00
0005432567810	30560	Economy	13600.00
0005432459943	30560	Economy	13600.00
0005432567744	30560	Economy	13600.00
0005432213647	30560	Economy	13600.00
0005434081884	30560	Economy	13600.00
0005432459844	30560	Economy	13600.00
0005432460023	30560	Economy	15000.00
0005432567695	30560	Economy	15000.00
0005432460237	30560	Economy	13600.00
0005432567672	30560	Economy	13600.00
0005434082029	30560	Economy	15000.00
0005432460047	30560	Economy	15000.00
0005432567599	30560	Economy	13600.00
0005434081880	30560	Economy	13600.00
0005434081967	30560	Economy	13600.00
0005434081978	30560	Economy	13600.00
0005432460166	30560	Economy	13600.00
0005433452732	30560	Economy	13600.00
0005432567696	30560	Economy	13600.00
0005434081982	30560	Economy	13600.00
0005432459942	30560	Economy	13600.00
0005432460275	30560	Economy	13600.00
0005432213646	30560	Economy	13600.00
0005432567821	30560	Economy	13600.00
0005434081931	30560	Economy	13600.00
0005432567775	30560	Economy	13600.00
0005432567563	30560	Economy	13600.00
0005432567564	30560	Economy	13600.00
0005432567878	30560	Economy	13600.00
0005432567673	30560	Economy	13600.00
0005432460191	30560	Economy	13600.00
0005432460179	30560	Economy	13600.00
0005432567571	30560	Economy	13600.00
0005434081927	30560	Economy	13600.00
0005432460190	30560	Economy	13600.00
0005432567740	30560	Economy	13600.00
0005434081966	30560	Economy	13600.00
0005432567861	30560	Economy	13600.00
0005433454884	30560	Economy	13600.00
0005432460120	30560	Economy	13600.00
0005432567840	30560	Economy	13600.00
0005432161178	30560	Economy	13600.00
0005432567761	30560	Economy	13600.00
0005434082013	30560	Economy	13600.00
0005432460204	30560	Economy	13600.00
0005432568045	30560	Economy	13600.00
0005432213649	30560	Economy	13600.00
0005432567900	30560	Economy	13600.00
0005432460054	30560	Economy	13600.00
0005432460015	30560	Economy	13600.00
0005432460052	30560	Economy	13600.00
0005434082080	30560	Economy	13600.00
0005434081963	30560	Economy	13600.00
0005432567893	30560	Economy	13600.00
0005432568056	30560	Economy	13600.00
0005432567942	30560	Economy	13600.00
0005434081957	30560	Economy	13600.00
0005432460279	30560	Economy	13600.00
0005434081941	30560	Economy	13600.00
0005432571336	30560	Economy	13600.00
0005432567843	30560	Economy	13600.00
0005432459824	30560	Economy	13600.00
0005432459922	30560	Economy	13600.00
0005432460088	30560	Economy	13600.00
0005432460089	30560	Economy	13600.00
0005433454883	30560	Economy	13600.00
0005432460092	30560	Economy	13600.00
0005432460041	30560	Economy	13600.00
0005435720835	13595	Economy	9900.00
0005435722080	13595	Economy	9900.00
0005435722082	13595	Economy	9900.00
0005435720836	13595	Economy	9900.00
0005435722081	13595	Economy	9900.00
0005435722060	21200	Economy	9900.00
0005435722061	21200	Economy	9900.00
0005435722059	21200	Economy	9900.00
0005432295909	22778	Economy	8800.00
0005432295908	22778	Economy	8800.00
0005433344273	11110	Business	23600.00
0005433344311	11110	Business	23600.00
0005433344262	11110	Business	23600.00
0005433344327	11110	Business	23600.00
0005435097302	11110	Business	23600.00
0005433344319	11110	Business	23600.00
0005433344320	11110	Business	23600.00
0005433344289	11110	Business	23600.00
0005435508310	11110	Business	23600.00
0005433344270	11110	Business	23600.00
0005433344251	11110	Business	23600.00
0005433344318	11110	Business	23600.00
0005433344295	11110	Economy	7900.00
0005433344296	11110	Economy	7900.00
0005433344240	11110	Economy	7900.00
0005433344269	11110	Economy	7900.00
0005433344275	11110	Economy	7900.00
0005433344300	11110	Economy	7900.00
0005435097307	11110	Economy	7900.00
0005433344249	11110	Economy	7900.00
0005433344297	11110	Economy	7900.00
0005433344292	11110	Economy	7900.00
0005433344280	11110	Economy	7900.00
0005433344231	11110	Economy	7900.00
0005433344238	11110	Economy	7900.00
0005433344314	11110	Economy	7900.00
0005433344246	11110	Economy	7900.00
0005433344287	11110	Economy	7900.00
0005433344230	11110	Economy	7900.00
0005433344254	11110	Economy	7900.00
0005433344326	11110	Economy	7900.00
0005433344247	11110	Economy	7900.00
0005435508338	11110	Economy	7900.00
0005435097306	11110	Economy	7900.00
0005433344293	11110	Economy	7900.00
0005433344272	11110	Economy	7900.00
0005433344265	11110	Economy	7900.00
0005435097305	11110	Economy	7900.00
0005433344310	11110	Economy	7900.00
0005433344248	11110	Economy	7900.00
0005433344274	11110	Economy	7900.00
0005433344261	11110	Economy	7900.00
0005433344263	11110	Economy	7900.00
0005433344294	11110	Economy	7900.00
0005435097301	11110	Economy	7900.00
0005433344313	11110	Economy	7900.00
0005433344256	11110	Economy	7900.00
0005433344315	11110	Economy	7900.00
0005433344244	11110	Economy	7900.00
0005435508366	11110	Economy	7900.00
0005433344260	11110	Economy	7900.00
0005433344288	11110	Economy	8600.00
0005435508386	11110	Economy	8600.00
0005433344322	11110	Economy	8600.00
0005433344281	11110	Economy	8600.00
0005433344236	11110	Economy	8600.00
0005433344259	11110	Economy	8600.00
0005435508371	11110	Economy	7900.00
0005433344325	11110	Economy	7900.00
0005433344307	11110	Economy	7900.00
0005433344305	11110	Economy	7900.00
0005435508380	11110	Economy	7900.00
0005433344284	11110	Economy	7900.00
0005435097303	11110	Economy	7900.00
0005433344255	11110	Economy	7900.00
0005435097309	11110	Economy	7900.00
0005433344317	11110	Economy	7900.00
0005435380282	11110	Economy	7900.00
0005435097311	11110	Economy	7900.00
0005433344282	11110	Economy	7900.00
0005433344258	11110	Economy	7900.00
0005435508365	11110	Economy	7900.00
0005433344276	11110	Economy	7900.00
0005435097308	11110	Economy	7900.00
0005435097310	11110	Economy	7900.00
0005433344264	11110	Economy	7900.00
0005433344241	11110	Economy	7900.00
0005435508372	11110	Economy	7900.00
0005435380288	11110	Economy	7900.00
0005435380309	11110	Economy	7900.00
0005433344237	11110	Economy	7900.00
0005433344321	11110	Economy	7900.00
0005433344329	11110	Economy	7900.00
0005435508378	11110	Economy	7900.00
0005433344285	11110	Economy	7900.00
0005433344239	11110	Economy	7900.00
0005433344302	11110	Economy	7900.00
0005433344252	11110	Economy	7900.00
0005433344283	11110	Economy	7900.00
0005433344268	11110	Economy	7900.00
0005433344324	11110	Economy	7900.00
0005433344306	11110	Economy	7900.00
0005433344242	11110	Economy	7900.00
0005433344308	11110	Economy	7900.00
0005433344235	11110	Economy	7900.00
0005435380281	11110	Economy	7900.00
0005433344286	11110	Economy	7900.00
0005435097300	11110	Economy	7900.00
0005433344232	11110	Economy	7900.00
0005433344266	11110	Economy	7900.00
0005433344279	11110	Economy	7900.00
0005433344290	11110	Economy	7900.00
0005433344291	11110	Economy	7900.00
0005433344328	11110	Economy	7900.00
0005435508311	11110	Economy	7900.00
0005433344245	11110	Economy	7900.00
0005435097304	11110	Economy	7900.00
0005433344233	11110	Economy	7900.00
0005433344243	11110	Economy	7900.00
0005433344267	11110	Economy	7900.00
0005433344278	11110	Economy	7900.00
0005433344303	11110	Economy	7900.00
0005433344309	11110	Economy	7900.00
0005433344234	11110	Economy	7900.00
0005433344257	11110	Economy	7900.00
0005433344304	11110	Economy	7900.00
0005433344301	11110	Economy	7900.00
0005433344316	11110	Economy	7900.00
0005433344299	11110	Economy	7900.00
0005433344312	11110	Economy	7900.00
0005433344298	11110	Economy	7900.00
0005433344253	11110	Economy	7900.00
0005433344250	11110	Economy	7900.00
0005435508387	11110	Economy	7900.00
0005433344277	11110	Economy	7900.00
0005433344229	11110	Economy	7900.00
0005433344323	11110	Economy	7900.00
0005435508390	11110	Economy	7900.00
0005433344271	11110	Economy	7900.00
0005433343383	17100	Business	23600.00
0005433343464	17100	Business	23600.00
0005435545836	17100	Business	23600.00
0005435380348	17100	Business	23600.00
0005433343418	17100	Business	23600.00
0005433343156	17100	Business	23600.00
0005435545834	17100	Business	23600.00
0005433343362	17100	Business	23600.00
0005433342943	17100	Business	23600.00
0005433342726	17100	Business	23600.00
0005433343648	17100	Economy	7900.00
0005435380349	17100	Economy	7900.00
0005433343241	17100	Economy	7900.00
0005433343302	17100	Economy	7900.00
0005433343281	17100	Economy	7900.00
0005435545843	17100	Economy	7900.00
0005433343811	17100	Economy	7900.00
0005433343504	17100	Economy	7900.00
0005435545829	17100	Economy	7900.00
0005435545830	17100	Economy	7900.00
0005432293237	17100	Economy	7900.00
0005433343249	17100	Economy	7900.00
0005433343217	17100	Economy	7900.00
0005433343637	17100	Economy	7900.00
0005433343463	17100	Economy	7900.00
0005433343220	17100	Economy	7900.00
0005433342958	17100	Economy	7900.00
0005433343222	17100	Economy	7900.00
0005435545842	17100	Economy	7900.00
0005433343068	17100	Economy	7900.00
0005433343569	17100	Economy	7900.00
0005433343134	17100	Economy	7900.00
0005433343290	17100	Economy	7900.00
0005433343289	17100	Economy	7900.00
0005433343582	17100	Economy	7900.00
0005435380351	17100	Economy	7900.00
0005432293236	17100	Economy	7900.00
0005433342939	17100	Economy	7900.00
0005435097247	17100	Economy	7900.00
0005433343280	17100	Economy	7900.00
0005433343320	17100	Economy	7900.00
0005433343224	17100	Economy	7900.00
0005433343465	17100	Economy	7900.00
0005433343111	17100	Economy	7900.00
0005435380347	17100	Economy	7900.00
0005433343240	17100	Economy	8600.00
0005433343417	17100	Economy	8600.00
0005435545838	17100	Economy	8600.00
0005433343508	17100	Economy	8600.00
0005433343407	17100	Economy	8600.00
0005433343412	17100	Economy	7900.00
0005435097236	17100	Economy	7900.00
0005433343635	17100	Economy	7900.00
0005435545841	17100	Economy	7900.00
0005433343315	17100	Economy	7900.00
0005433343271	17100	Economy	7900.00
0005433343363	17100	Economy	7900.00
0005433343376	17100	Economy	7900.00
0005433342926	17100	Economy	7900.00
0005433342711	17100	Economy	7900.00
0005433343408	17100	Economy	7900.00
0005435545835	17100	Economy	7900.00
0005433343215	17100	Economy	7900.00
0005433343430	17100	Economy	7900.00
0005433343248	17100	Economy	7900.00
0005435380346	17100	Economy	7900.00
0005433343321	17100	Economy	7900.00
0005433343065	17100	Economy	7900.00
0005433343579	17100	Economy	7900.00
0005433343411	17100	Economy	7900.00
0005433343182	17100	Economy	7900.00
0005433343262	17100	Economy	7900.00
0005433342640	17100	Economy	7900.00
0005433343506	17100	Economy	7900.00
0005433343609	17100	Economy	7900.00
0005435380345	17100	Economy	7900.00
0005433343596	17100	Economy	7900.00
0005433343585	17100	Economy	7900.00
0005433343144	17100	Economy	7900.00
0005433343322	17100	Economy	7900.00
0005435545833	17100	Economy	7900.00
0005433343505	17100	Economy	7900.00
0005435545839	17100	Economy	7900.00
0005433342710	17100	Economy	7900.00
0005433343377	17100	Economy	7900.00
0005433343177	17100	Economy	7900.00
0005433343225	17100	Economy	7900.00
0005433343700	17100	Economy	7900.00
0005433343361	17100	Economy	7900.00
0005433342639	17100	Economy	7900.00
0005435097253	17100	Economy	7900.00
0005433342940	17100	Economy	7900.00
0005433343583	17100	Economy	7900.00
0005433343244	17100	Economy	7900.00
0005433343114	17100	Economy	7900.00
0005435545837	17100	Economy	7900.00
0005433343133	17100	Economy	7900.00
0005435545832	17100	Economy	7900.00
0005433343204	17100	Economy	7900.00
0005435545831	17100	Economy	7900.00
0005435380350	17100	Economy	7900.00
0005433343314	17100	Economy	7900.00
0005433343603	17100	Economy	7900.00
0005433343636	17100	Economy	7900.00
0005433342911	17100	Economy	7900.00
0005435545840	17100	Economy	7900.00
0005433343683	17100	Economy	7900.00
0005433343197	17100	Economy	7900.00
0005433343561	17100	Economy	7900.00
0005433342709	17100	Economy	7900.00
0005433342725	17100	Economy	7900.00
0005433343260	17100	Economy	7900.00
0005435097191	17100	Economy	7900.00
0005433343416	17100	Economy	7900.00
0005433343135	17100	Economy	7900.00
0005433343500	17100	Economy	7900.00
0005433343219	17100	Economy	7900.00
0005433343410	17100	Economy	7900.00
0005433481255	9118	Business	26600.00
0005433507387	9118	Business	26600.00
0005433507388	9118	Business	26600.00
0005432919936	9118	Business	26600.00
0005433507385	9118	Business	26600.00
0005433507391	9118	Business	26600.00
0005432919962	9118	Business	26600.00
0005433507381	9118	Business	26600.00
0005433507377	9118	Business	26600.00
0005433507392	9118	Economy	8900.00
0005432919938	9118	Economy	8900.00
0005432919963	9118	Economy	8900.00
0005432919885	9118	Economy	8900.00
0005432919901	9118	Economy	8900.00
0005432919877	9118	Economy	9800.00
0005432919932	9118	Economy	9800.00
0005433481254	9118	Economy	9800.00
0005432919898	9118	Economy	9800.00
0005433481257	9118	Economy	8900.00
0005432919991	9118	Economy	8900.00
0005432919908	9118	Economy	8900.00
0005432919900	9118	Economy	8900.00
0005433507379	9118	Economy	8900.00
0005433507390	9118	Economy	8900.00
0005432919894	9118	Economy	8900.00
0005432919937	9118	Economy	8900.00
0005433481253	9118	Economy	8900.00
0005433481250	9118	Economy	8900.00
0005433507383	9118	Economy	8900.00
0005432919915	9118	Economy	8900.00
0005432919899	9118	Economy	8900.00
0005433507378	9118	Economy	8900.00
0005433481251	9118	Economy	8900.00
0005432919910	9118	Economy	8900.00
0005434158975	9118	Economy	8900.00
0005433481256	9118	Economy	8900.00
0005433507389	9118	Economy	8900.00
0005432919871	9118	Economy	8900.00
0005432919861	9118	Economy	8900.00
0005433507384	9118	Economy	8900.00
0005433481252	9118	Economy	8900.00
0005433507386	9118	Economy	8900.00
0005433507380	9118	Economy	8900.00
0005432919916	9118	Economy	8900.00
0005432919876	9118	Economy	8900.00
0005434158974	9118	Economy	8900.00
0005433507382	9118	Economy	8900.00
0005433507271	20457	Business	26600.00
0005432920104	20457	Business	26600.00
0005432920109	20457	Business	26600.00
0005432920111	20457	Business	26600.00
0005433507287	20457	Business	26600.00
0005433507169	20457	Business	26600.00
0005432920123	20457	Economy	8900.00
0005433507222	20457	Economy	8900.00
0005432920108	20457	Economy	8900.00
0005433481186	20457	Economy	8900.00
0005433507171	20457	Economy	8900.00
0005434159004	20457	Economy	8900.00
0005432920114	20457	Economy	9800.00
0005433507244	20457	Economy	9800.00
0005432920115	20457	Economy	9800.00
0005432920105	20457	Economy	8900.00
0005433507230	20457	Economy	8900.00
0005433481204	20457	Economy	8900.00
0005433507292	20457	Economy	8900.00
0005433481188	20457	Economy	8900.00
0005433507317	20457	Economy	8900.00
0005433507270	20457	Economy	8900.00
0005433507268	20457	Economy	8900.00
0005432920121	20457	Economy	8900.00
0005433507247	20457	Economy	8900.00
0005433481171	20457	Economy	8900.00
0005432920117	20457	Economy	8900.00
0005432920120	20457	Economy	8900.00
0005432920106	20457	Economy	8900.00
0005434159009	20457	Economy	8900.00
0005433507269	20457	Economy	8900.00
0005432920107	20457	Economy	8900.00
0005433481205	20457	Economy	8900.00
0005433481217	20457	Economy	8900.00
0005433481194	20457	Economy	8900.00
0005432920112	20457	Economy	8900.00
0005433481187	20457	Economy	8900.00
0005433507106	20457	Economy	8900.00
0005433507221	20457	Economy	8900.00
0005434159006	20457	Economy	8900.00
0005433507209	20457	Economy	8900.00
0005432920116	20457	Economy	8900.00
0005433507219	20457	Economy	8900.00
0005432920110	20457	Economy	8900.00
0005434159008	20457	Economy	8900.00
0005433507170	20457	Economy	8900.00
0005433507173	20457	Economy	8900.00
0005434159005	20457	Economy	8900.00
0005433507214	20457	Economy	8900.00
0005433507330	20457	Economy	8900.00
0005433481193	20457	Economy	8900.00
0005432920113	20457	Economy	8900.00
0005433507208	20457	Economy	8900.00
0005432920119	20457	Economy	8900.00
0005432920118	20457	Economy	8900.00
0005432920122	20457	Economy	8900.00
0005434159007	20457	Economy	8900.00
0005432394148	10193	Economy	5800.00
0005432396284	10193	Economy	5800.00
0005432394146	10193	Economy	5800.00
0005432396285	10193	Economy	5800.00
0005435178993	10193	Economy	5800.00
0005435178991	10193	Economy	5800.00
0005432396286	10193	Economy	5800.00
0005432394145	10193	Economy	5800.00
0005432394144	10193	Economy	5800.00
0005432394147	10193	Economy	5800.00
0005432396283	10193	Economy	5800.00
0005432400126	18380	Economy	5800.00
0005432396247	18380	Economy	5800.00
0005435179404	18380	Economy	5800.00
0005432396254	18380	Economy	5800.00
0005432400107	18380	Economy	5800.00
0005432396257	18380	Economy	5800.00
0005435626173	11032	Business	9500.00
0005435626148	11032	Business	9500.00
0005435554231	11032	Business	9500.00
0005435126458	11032	Business	9500.00
0005435126482	11032	Business	9500.00
0005435626212	11032	Business	9500.00
0005435126459	11032	Business	9500.00
0005435626149	11032	Business	9500.00
0005435626210	11032	Business	9500.00
0005435554205	11032	Economy	3200.00
0005435126447	11032	Economy	3200.00
0005435626177	11032	Economy	3200.00
0005435126457	11032	Economy	3200.00
0005435554183	11032	Economy	3200.00
0005435554232	11032	Economy	3200.00
0005435626166	11032	Economy	3200.00
0005435626179	11032	Economy	3200.00
0005435626151	11032	Economy	3200.00
0005435556699	11032	Economy	3500.00
0005435126406	11032	Economy	3500.00
0005435126065	11032	Economy	3500.00
0005435626172	11032	Economy	3200.00
0005434411829	11032	Economy	3200.00
0005435554204	11032	Economy	3200.00
0005435126486	11032	Economy	3200.00
0005435126280	11032	Economy	3200.00
0005435126460	11032	Economy	3200.00
0005434928332	11032	Economy	3200.00
0005434411827	11032	Economy	3200.00
0005435626167	11032	Economy	3200.00
0005435556691	11032	Economy	3200.00
0005435126511	11032	Economy	3200.00
0005435126349	11032	Economy	3200.00
0005435126281	11032	Economy	3200.00
0005435626171	11032	Economy	3200.00
0005435126381	11032	Economy	3200.00
0005435126455	11032	Economy	3200.00
0005435126454	11032	Economy	3200.00
0005435626125	11032	Economy	3200.00
0005435626146	11032	Economy	3200.00
0005435626176	11032	Economy	3200.00
0005435126367	11032	Economy	3200.00
0005435126351	11032	Economy	3200.00
0005435126499	11032	Economy	3200.00
0005435126352	11032	Economy	3200.00
0005435626209	11032	Economy	3200.00
0005435626183	11032	Economy	3200.00
0005435126497	11032	Economy	3200.00
0005435126456	11032	Economy	3200.00
0005435626203	11032	Economy	3200.00
0005435126496	11032	Economy	3200.00
0005435126510	11032	Economy	3200.00
0005435126473	11032	Economy	3200.00
0005435626058	11032	Economy	3200.00
0005435126302	11032	Economy	3200.00
0005435626206	11032	Economy	3200.00
0005434411826	11032	Economy	3200.00
0005435126495	11032	Economy	3200.00
0005435554202	11032	Economy	3200.00
0005435626152	11032	Economy	3200.00
0005435626207	11032	Economy	3200.00
0005435126368	11032	Economy	3200.00
0005435126348	11032	Economy	3200.00
0005435126507	11032	Economy	3200.00
0005435626211	11032	Economy	3200.00
0005435626200	11032	Economy	3200.00
0005435126546	11032	Economy	3200.00
0005435556690	11032	Economy	3200.00
0005435626174	11032	Economy	3200.00
0005435626189	11032	Economy	3200.00
0005435126542	11032	Economy	3200.00
0005435626154	11032	Economy	3200.00
0005435626188	11032	Economy	3200.00
0005434411828	11032	Economy	3200.00
0005435126501	11032	Economy	3200.00
0005435626153	11032	Economy	3200.00
0005435126845	14719	Business	9500.00
0005435126816	14719	Business	9500.00
0005435626396	14719	Business	9500.00
0005435126842	14719	Business	9500.00
0005434411779	14719	Business	9500.00
0005435626395	14719	Business	9500.00
0005435126850	14719	Business	9500.00
0005435126849	14719	Business	9500.00
0005435126828	14719	Business	9500.00
0005435126844	14719	Business	9500.00
0005435126852	14719	Economy	3200.00
0005435126840	14719	Economy	3200.00
0005435626391	14719	Economy	3200.00
0005435626397	14719	Economy	3200.00
0005435126814	14719	Economy	3200.00
0005435126822	14719	Economy	3200.00
0005435556721	14719	Economy	3200.00
0005435626394	14719	Economy	3200.00
0005435556719	14719	Economy	3500.00
0005435126848	14719	Economy	3500.00
0005435126829	14719	Economy	3500.00
0005435556722	14719	Economy	3200.00
0005435126838	14719	Economy	3200.00
0005435126818	14719	Economy	3200.00
0005435126826	14719	Economy	3200.00
0005435126833	14719	Economy	3200.00
0005435126823	14719	Economy	3200.00
0005435626385	14719	Economy	3200.00
0005435626390	14719	Economy	3200.00
0005435126846	14719	Economy	3200.00
0005435126835	14719	Economy	3200.00
0005435554238	14719	Economy	3200.00
0005435554240	14719	Economy	3200.00
0005435126837	14719	Economy	3200.00
0005435626388	14719	Economy	3200.00
0005434928309	14719	Economy	3200.00
0005435126824	14719	Economy	3200.00
0005435626389	14719	Economy	3200.00
0005435126843	14719	Economy	3200.00
0005435126841	14719	Economy	3200.00
0005435126821	14719	Economy	3200.00
0005435554236	14719	Economy	3200.00
0005435554237	14719	Economy	3200.00
0005435626393	14719	Economy	3200.00
0005435126839	14719	Economy	3200.00
0005434411780	14719	Economy	3200.00
0005435126834	14719	Economy	3200.00
0005434411774	14719	Economy	3200.00
0005435626398	14719	Economy	3200.00
0005435126820	14719	Economy	3200.00
0005435126854	14719	Economy	3200.00
0005435126847	14719	Economy	3200.00
0005435126830	14719	Economy	3200.00
0005435126853	14719	Economy	3200.00
0005435126813	14719	Economy	3200.00
0005435126815	14719	Economy	3200.00
0005435626392	14719	Economy	3200.00
0005435556720	14719	Economy	3200.00
0005435126827	14719	Economy	3200.00
0005435554239	14719	Economy	3200.00
0005435626386	14719	Economy	3200.00
0005435126817	14719	Economy	3200.00
0005435126825	14719	Economy	3200.00
0005435126851	14719	Economy	3200.00
0005435126831	14719	Economy	3200.00
0005435626387	14719	Economy	3200.00
0005435126836	14719	Economy	3200.00
0005435126832	14719	Economy	3200.00
0005435126819	14719	Economy	3200.00
0005434928310	14719	Economy	3200.00
0005435715656	7112	Business	86900.00
0005432398242	7112	Business	86900.00
0005435443293	7112	Business	86900.00
0005432400169	7112	Business	86900.00
0005435715658	7112	Business	86900.00
0005435216597	7112	Business	86900.00
0005435715653	7112	Business	86900.00
0005435715659	7112	Economy	29000.00
0005435216592	7112	Economy	29000.00
0005435715660	7112	Economy	29000.00
0005435715652	7112	Economy	29000.00
0005435443309	7112	Economy	29000.00
0005435715662	7112	Economy	29000.00
0005435715655	7112	Economy	29000.00
0005435715664	7112	Economy	29000.00
0005432398240	7112	Economy	29000.00
0005435443292	7112	Economy	29000.00
0005435715668	7112	Economy	29000.00
0005432400170	7112	Economy	29000.00
0005435715665	7112	Economy	29000.00
0005435715661	7112	Economy	29000.00
0005435715657	7112	Economy	29000.00
0005435715654	7112	Economy	29000.00
0005435443320	7112	Economy	29000.00
0005432398241	7112	Economy	29000.00
0005435443319	7112	Economy	29000.00
0005435715667	7112	Economy	29000.00
0005435715669	7112	Economy	29000.00
0005432400168	7112	Economy	29000.00
0005435715663	7112	Economy	29000.00
0005435715666	7112	Economy	29000.00
0005435715502	27065	Business	86900.00
0005435715514	27065	Business	86900.00
0005435715594	27065	Business	86900.00
0005435715523	27065	Economy	29000.00
0005432398199	27065	Economy	29000.00
0005435715503	27065	Economy	29000.00
0005435443421	27065	Economy	29000.00
0005435178511	27065	Economy	29000.00
0005435443418	27065	Economy	31900.00
0005432398205	27065	Economy	29000.00
0005435715459	27065	Economy	29000.00
0005435715457	27065	Economy	29000.00
0005435443415	27065	Economy	29000.00
0005435443423	27065	Economy	29000.00
0005435715560	27065	Economy	29000.00
0005435715522	27065	Economy	29000.00
0005432398204	27065	Economy	29000.00
0005435715463	27065	Economy	29000.00
0005432394123	27065	Economy	29000.00
0005432398210	27065	Economy	29000.00
0005435178513	27065	Economy	29000.00
0005432394093	27065	Economy	29000.00
0005435178510	27065	Economy	29000.00
0005435715525	27065	Economy	29000.00
0005432394092	27065	Economy	29000.00
0005435715595	27065	Economy	29000.00
0005435178512	27065	Economy	29000.00
0005435443419	27065	Economy	29000.00
0005435443420	27065	Economy	29000.00
0005435715564	27065	Economy	29000.00
0005435715593	27065	Economy	29000.00
0005435443422	27065	Economy	29000.00
0005435715571	27065	Economy	29000.00
0005435443416	27065	Economy	29000.00
0005435715422	27065	Economy	29000.00
0005435443417	27065	Economy	29000.00
0005435715421	27065	Economy	29000.00
0005435715485	27065	Economy	29000.00
0005432394122	27065	Economy	29000.00
0005434084981	2760	Economy	7700.00
0005434084982	2760	Economy	7700.00
0005434084983	2760	Economy	7700.00
0005434084985	2760	Economy	7700.00
0005433060428	2760	Economy	7700.00
0005434084984	2760	Economy	7700.00
0005434084947	28520	Economy	7700.00
0005433060444	28520	Economy	7700.00
0005433060445	28520	Economy	7700.00
0005434084934	28520	Economy	7700.00
0005434084946	28520	Economy	7700.00
0005434084954	28520	Economy	7700.00
0005433060443	28520	Economy	7700.00
0005434084924	28520	Economy	7700.00
0005434084955	28520	Economy	7700.00
0005434084935	28520	Economy	7700.00
0005435541096	11416	Business	20200.00
0005435517934	11416	Business	20200.00
0005435518015	11416	Business	20200.00
0005435517947	11416	Business	20200.00
0005435517953	11416	Business	20200.00
0005435518001	11416	Business	20200.00
0005435541097	11416	Business	20200.00
0005435541115	11416	Business	20200.00
0005435541062	11416	Business	20200.00
0005435541099	11416	Economy	6700.00
0005435518022	11416	Economy	6700.00
0005435517939	11416	Economy	6700.00
0005435541032	11416	Economy	7400.00
0005435517862	11416	Economy	7400.00
0005435541138	11416	Economy	7400.00
0005435517878	11416	Economy	6700.00
0005435541116	11416	Economy	6700.00
0005435540999	11416	Economy	6700.00
0005435517933	11416	Economy	6700.00
0005435540998	11416	Economy	6700.00
0005435517861	11416	Economy	6700.00
0005435517993	11416	Economy	6700.00
0005435541100	11416	Economy	6700.00
0005435517954	11416	Economy	6700.00
0005435518035	11416	Economy	6700.00
0005435541052	11416	Economy	6700.00
0005435541079	11416	Economy	6700.00
0005435541089	11416	Economy	6700.00
0005435517924	11416	Economy	6700.00
0005435541019	11416	Economy	6700.00
0005435517923	11416	Economy	6700.00
0005435541000	11416	Economy	6700.00
0005435541134	11416	Economy	6700.00
0005435541137	11416	Economy	6700.00
0005435517967	11416	Economy	6700.00
0005435518037	11416	Economy	6700.00
0005435517946	11416	Economy	6700.00
0005435540966	11416	Economy	6700.00
0005435541033	11416	Economy	6700.00
0005435541112	11416	Economy	6700.00
0005435517951	11416	Economy	6700.00
0005435541040	11416	Economy	6700.00
0005435541131	11416	Economy	6700.00
0005435541095	11416	Economy	6700.00
0005435517877	11416	Economy	6700.00
0005435541231	22272	Business	20200.00
0005435541224	22272	Business	20200.00
0005435529493	22272	Business	20200.00
0005435529497	22272	Business	20200.00
0005435529496	22272	Business	20200.00
0005435529495	22272	Business	20200.00
0005435541234	22272	Economy	6700.00
0005435529478	22272	Economy	6700.00
0005432294513	22272	Economy	6700.00
0005432294511	22272	Economy	6700.00
0005435541242	22272	Economy	7400.00
0005435541235	22272	Economy	7400.00
0005435541238	22272	Economy	7400.00
0005435529498	22272	Economy	7400.00
0005435529484	22272	Economy	7400.00
0005435529490	22272	Economy	6700.00
0005435529482	22272	Economy	6700.00
0005435529483	22272	Economy	6700.00
0005435541222	22272	Economy	6700.00
0005435529487	22272	Economy	6700.00
0005435541226	22272	Economy	6700.00
0005435541229	22272	Economy	6700.00
0005435529481	22272	Economy	6700.00
0005435529488	22272	Economy	6700.00
0005435529486	22272	Economy	6700.00
0005435529491	22272	Economy	6700.00
0005435541241	22272	Economy	6700.00
0005435529480	22272	Economy	6700.00
0005435541232	22272	Economy	6700.00
0005435529477	22272	Economy	6700.00
0005435529479	22272	Economy	6700.00
0005435529494	22272	Economy	6700.00
0005435541236	22272	Economy	6700.00
0005432294512	22272	Economy	6700.00
0005435541225	22272	Economy	6700.00
0005435529485	22272	Economy	6700.00
0005435541240	22272	Economy	6700.00
0005435541237	22272	Economy	6700.00
0005435541223	22272	Economy	6700.00
0005435529489	22272	Economy	6700.00
0005435541227	22272	Economy	6700.00
0005435529492	22272	Economy	6700.00
0005435541228	22272	Economy	6700.00
0005435541233	22272	Economy	6700.00
0005435541230	22272	Economy	6700.00
0005435541239	22272	Economy	6700.00
0005434907894	2284	Business	20200.00
0005434907863	2284	Business	20200.00
0005433251628	2284	Business	20200.00
0005434907890	2284	Business	20200.00
0005433251523	2284	Business	20200.00
0005433251635	2284	Business	20200.00
0005434907887	2284	Business	20200.00
0005433251402	2284	Business	20200.00
0005434907891	2284	Business	20200.00
0005433251663	2284	Business	20200.00
0005434907879	2284	Business	20200.00
0005433251586	2284	Business	20200.00
0005433251617	2284	Economy	6700.00
0005434907870	2284	Economy	6700.00
0005434907860	2284	Economy	6700.00
0005433251588	2284	Economy	6700.00
0005433251401	2284	Economy	6700.00
0005434907895	2284	Economy	6700.00
0005434907880	2284	Economy	6700.00
0005433251697	2284	Economy	6700.00
0005434907901	2284	Economy	6700.00
0005434907881	2284	Economy	6700.00
0005433251618	2284	Economy	7400.00
0005433251646	2284	Economy	7400.00
0005434907866	2284	Economy	7400.00
0005433251596	2284	Economy	7400.00
0005434907864	2284	Economy	6700.00
0005434907861	2284	Economy	6700.00
0005434907871	2284	Economy	6700.00
0005433400995	2284	Economy	6700.00
0005433251647	2284	Economy	6700.00
0005433400994	2284	Economy	6700.00
0005433251607	2284	Economy	6700.00
0005433251719	2284	Economy	6700.00
0005434907897	2284	Economy	6700.00
0005434907877	2284	Economy	6700.00
0005434907878	2284	Economy	6700.00
0005434907882	2284	Economy	6700.00
0005433251554	2284	Economy	6700.00
0005433251629	2284	Economy	6700.00
0005433251528	2284	Economy	6700.00
0005433251791	2284	Economy	6700.00
0005433251587	2284	Economy	6700.00
0005434907885	2284	Economy	6700.00
0005434907903	2284	Economy	6700.00
0005434907893	2284	Economy	6700.00
0005433251539	2284	Economy	6700.00
0005433251636	2284	Economy	6700.00
0005434907889	2284	Economy	6700.00
0005434907896	2284	Economy	6700.00
0005434907869	2284	Economy	6700.00
0005434907865	2284	Economy	6700.00
0005433251560	2284	Economy	6700.00
0005434907900	2284	Economy	6700.00
0005433251566	2284	Economy	6700.00
0005433251473	2284	Economy	6700.00
0005433251604	2284	Economy	6700.00
0005433251790	2284	Economy	6700.00
0005434907862	2284	Economy	6700.00
0005433251684	2284	Economy	6700.00
0005434907892	2284	Economy	6700.00
0005433251529	2284	Economy	6700.00
0005434907874	2284	Economy	6700.00
0005434907898	2284	Economy	6700.00
0005433251608	2284	Economy	6700.00
0005433251720	2284	Economy	6700.00
0005434907867	2284	Economy	6700.00
0005434907875	2284	Economy	6700.00
0005434907859	2284	Economy	6700.00
0005433251613	2284	Economy	6700.00
0005434907899	2284	Economy	6700.00
0005433251475	2284	Economy	6700.00
0005433251545	2284	Economy	6700.00
0005434907886	2284	Economy	6700.00
0005434907873	2284	Economy	6700.00
0005434907858	2284	Economy	6700.00
0005434907902	2284	Economy	6700.00
0005434907876	2284	Economy	6700.00
0005434907884	2284	Economy	6700.00
0005434907883	2284	Economy	6700.00
0005434907888	2284	Economy	6700.00
0005434907872	2284	Economy	6700.00
0005433251507	2284	Economy	6700.00
0005433251648	2284	Economy	6700.00
0005434907868	2284	Economy	6700.00
0005433251555	2284	Economy	6700.00
0005433251474	2284	Economy	6700.00
0005433400989	2284	Economy	6700.00
0005434907408	25631	Business	20200.00
0005434907302	25631	Business	20200.00
0005434907334	25631	Business	20200.00
0005434907314	25631	Business	20200.00
0005433401016	25631	Business	20200.00
0005434907316	25631	Business	20200.00
0005433251832	25631	Business	20200.00
0005434907301	25631	Business	20200.00
0005434907345	25631	Business	20200.00
0005434907227	25631	Business	20200.00
0005434907244	25631	Business	20200.00
0005433251838	25631	Economy	6700.00
0005433251824	25631	Economy	6700.00
0005433251822	25631	Economy	6700.00
0005434907266	25631	Economy	6700.00
0005434907175	25631	Economy	6700.00
0005433251821	25631	Economy	6700.00
0005434907442	25631	Economy	6700.00
0005434907425	25631	Economy	6700.00
0005434907445	25631	Economy	6700.00
0005434907386	25631	Economy	6700.00
0005434907433	25631	Economy	7400.00
0005434907381	25631	Economy	7400.00
0005433251830	25631	Economy	7400.00
0005433251843	25631	Economy	7400.00
0005434907217	25631	Economy	7400.00
0005433251813	25631	Economy	6700.00
0005434907401	25631	Economy	6700.00
0005434907248	25631	Economy	6700.00
0005434907373	25631	Economy	6700.00
0005433251831	25631	Economy	6700.00
0005433251820	25631	Economy	6700.00
0005433251825	25631	Economy	6700.00
0005433251817	25631	Economy	6700.00
0005434907249	25631	Economy	6700.00
0005433251842	25631	Economy	6700.00
0005434907379	25631	Economy	6700.00
0005434907174	25631	Economy	6700.00
0005434907374	25631	Economy	6700.00
0005434907429	25631	Economy	6700.00
0005434907412	25631	Economy	6700.00
0005434907318	25631	Economy	6700.00
0005433251837	25631	Economy	6700.00
0005434907176	25631	Economy	6700.00
0005434907370	25631	Economy	6700.00
0005433251834	25631	Economy	6700.00
0005434907366	25631	Economy	6700.00
0005433251828	25631	Economy	6700.00
0005434907268	25631	Economy	6700.00
0005433251826	25631	Economy	6700.00
0005433251840	25631	Economy	6700.00
0005433251812	25631	Economy	6700.00
0005433251839	25631	Economy	6700.00
0005433251827	25631	Economy	6700.00
0005434907395	25631	Economy	6700.00
0005433251818	25631	Economy	6700.00
0005434907245	25631	Economy	6700.00
0005434907387	25631	Economy	6700.00
0005433251823	25631	Economy	6700.00
0005433251819	25631	Economy	6700.00
0005434907391	25631	Economy	6700.00
0005434907322	25631	Economy	6700.00
0005434907402	25631	Economy	6700.00
0005433401017	25631	Economy	6700.00
0005434907294	25631	Economy	6700.00
0005433251816	25631	Economy	6700.00
0005434907285	25631	Economy	6700.00
0005433401018	25631	Economy	6700.00
0005434907413	25631	Economy	6700.00
0005433251815	25631	Economy	6700.00
0005434907342	25631	Economy	6700.00
0005434907327	25631	Economy	6700.00
0005434907371	25631	Economy	6700.00
0005434907380	25631	Economy	6700.00
0005434907434	25631	Economy	6700.00
0005434907382	25631	Economy	6700.00
0005433251814	25631	Economy	6700.00
0005433251833	25631	Economy	6700.00
0005434907274	25631	Economy	6700.00
0005434907390	25631	Economy	6700.00
0005434907224	25631	Economy	6700.00
0005434907303	25631	Economy	6700.00
0005434907424	25631	Economy	6700.00
0005433251836	25631	Economy	6700.00
0005434907349	25631	Economy	6700.00
0005434907444	25631	Economy	6700.00
0005434907343	25631	Economy	6700.00
0005433251829	25631	Economy	6700.00
0005433251835	25631	Economy	6700.00
0005433251841	25631	Economy	6700.00
0005434907265	25631	Economy	6700.00
0005434907228	25631	Economy	6700.00
0005434907293	25631	Economy	6700.00
0005434907298	25631	Economy	6700.00
0005432621192	2538	Economy	13600.00
0005432862318	2538	Economy	12400.00
0005432621194	2538	Economy	12400.00
0005432621195	2538	Economy	12400.00
0005432862337	2538	Economy	12400.00
0005432862317	2538	Economy	12400.00
0005432862336	2538	Economy	12400.00
0005432621205	2538	Economy	12400.00
0005432621196	2538	Economy	12400.00
0005432621191	2538	Economy	12400.00
0005432621202	2538	Economy	12400.00
0005432621197	2538	Economy	12400.00
0005432621198	2538	Economy	12400.00
0005432621193	2538	Economy	12400.00
0005432621204	2538	Economy	12400.00
0005432862338	2538	Economy	12400.00
0005432621203	2538	Economy	12400.00
0005432621200	2538	Economy	12400.00
0005432621201	2538	Economy	12400.00
0005432621199	2538	Economy	12400.00
0005432862387	28090	Economy	12400.00
0005432862394	28090	Economy	12400.00
0005432862389	28090	Economy	12400.00
0005432621112	28090	Economy	12400.00
0005432862390	28090	Economy	12400.00
0005432862392	28090	Economy	12400.00
0005432621082	28090	Economy	12400.00
0005432621071	28090	Economy	12400.00
0005432621118	28090	Economy	12400.00
0005432621083	28090	Economy	12400.00
0005432862391	28090	Economy	12400.00
0005432621081	28090	Economy	12400.00
0005432621068	28090	Economy	12400.00
0005432862388	28090	Economy	12400.00
0005432862393	28090	Economy	12400.00
0005432862386	28090	Economy	12400.00
0005434097475	11746	Economy	11300.00
0005434097474	11746	Economy	11300.00
0005434097478	11746	Economy	11300.00
0005434097492	13103	Economy	11300.00
0005434097491	13103	Economy	11300.00
0005434191264	32870	Business	89600.00
0005434191282	32870	Economy	29900.00
0005434191265	32870	Economy	29900.00
0005434191279	32870	Economy	32800.00
0005434191274	32870	Economy	32800.00
0005434191283	32870	Economy	32800.00
0005434191268	32870	Economy	29900.00
0005434191278	32870	Economy	29900.00
0005434191277	32870	Economy	29900.00
0005434191271	32870	Economy	29900.00
0005434191273	32870	Economy	29900.00
0005434191284	32870	Economy	29900.00
0005434191276	32870	Economy	29900.00
0005434191263	32870	Economy	29900.00
0005434191275	32870	Economy	29900.00
0005433451640	31052	Economy	8400.00
0005433451641	31052	Economy	8400.00
0005433451642	31052	Economy	8400.00
0005433452763	31052	Economy	8400.00
0005433452762	31052	Economy	8400.00
0005433452732	31451	Economy	8400.00
0005433454883	31451	Economy	8400.00
0005433454884	31451	Economy	8400.00
0005433452731	31451	Economy	8400.00
0005433134146	12009	Economy	7200.00
0005433129292	12009	Economy	6600.00
0005433134117	12009	Economy	6600.00
0005433129294	12009	Economy	6600.00
0005433129293	12009	Economy	6600.00
0005434142609	12009	Economy	6600.00
0005433134118	12009	Economy	6600.00
0005433129298	12009	Economy	6600.00
0005433134145	12009	Economy	6600.00
0005433134140	12009	Economy	6600.00
0005433129297	12009	Economy	6600.00
0005434184688	29866	Economy	6600.00
0005434183603	29866	Economy	6600.00
0005433134189	29866	Economy	6600.00
0005434183602	29866	Economy	6600.00
0005433134188	29866	Economy	6600.00
0005433131760	29866	Economy	6600.00
0005434142650	29866	Economy	6600.00
0005434142653	29866	Economy	6600.00
0005433131759	29866	Economy	6600.00
0005433131758	29866	Economy	6600.00
0005434142651	29866	Economy	6600.00
0005434142652	29866	Economy	6600.00
0005433134191	29866	Economy	6600.00
0005433131761	29866	Economy	6600.00
0005433134190	29866	Economy	6600.00
0005435798968	1610	Economy	17200.00
0005435798965	1610	Economy	15700.00
0005435798973	1610	Economy	15700.00
0005435798971	1610	Economy	15700.00
0005435798961	1610	Economy	15700.00
0005435798970	1610	Economy	15700.00
0005435798962	1610	Economy	15700.00
0005435798964	1610	Economy	15700.00
0005435798972	1610	Economy	15700.00
0005435798976	1610	Economy	15700.00
0005435798963	1610	Economy	15700.00
0005435798967	1610	Economy	15700.00
0005435798974	1610	Economy	15700.00
0005435798966	1610	Economy	15700.00
0005435798969	1610	Economy	15700.00
0005435798977	1610	Economy	15700.00
0005435798975	1610	Economy	15700.00
0005435697619	16475	Economy	19900.00
0005435697640	16475	Economy	19900.00
0005435697633	16475	Economy	18100.00
0005435697634	16475	Economy	18100.00
0005435697631	16475	Economy	18100.00
0005435697637	16475	Economy	18100.00
0005435697632	16475	Economy	18100.00
0005435697641	16475	Economy	18100.00
0005435697635	16475	Economy	18100.00
0005435697645	16475	Economy	18100.00
0005435697636	16475	Economy	18100.00
0005435697628	16475	Economy	18100.00
0005435697627	16475	Economy	18100.00
0005435697622	16475	Economy	18100.00
0005435697643	16475	Economy	18100.00
0005435935058	16475	Economy	18100.00
0005435697629	16475	Economy	18100.00
0005435697646	16475	Economy	18100.00
0005435697639	16475	Economy	18100.00
0005435697630	16475	Economy	18100.00
0005435697642	16475	Economy	18100.00
0005435697623	16475	Economy	18100.00
0005435697638	16475	Economy	18100.00
0005435697618	16475	Economy	18100.00
0005435697644	16475	Economy	18100.00
0005435697624	16475	Economy	18100.00
0005435697625	16475	Economy	18100.00
0005435935061	16475	Economy	18100.00
0005435697620	16475	Economy	18100.00
0005435697626	16475	Economy	18100.00
0005435697621	16475	Economy	18100.00
0005435697503	24739	Economy	19900.00
0005435935082	24739	Economy	18100.00
0005435697419	24739	Economy	18100.00
0005435697430	24739	Economy	18100.00
0005435697484	24739	Economy	18100.00
0005435697276	24739	Economy	18100.00
0005435697473	24739	Economy	18100.00
0005435697402	24739	Economy	18100.00
0005435697438	24739	Economy	18100.00
0005435697483	24739	Economy	18100.00
0005435935081	24739	Economy	18100.00
0005435697426	24739	Economy	18100.00
0005435697464	24739	Economy	18100.00
0005435697502	24739	Economy	18100.00
0005435697425	24739	Economy	18100.00
0005435697439	24739	Economy	18100.00
0005435935080	24739	Economy	18100.00
0005435935083	24739	Economy	18100.00
0005433724854	18802	Economy	4400.00
0005433724851	18802	Economy	4400.00
0005433724852	18802	Economy	4400.00
0005433724853	18802	Economy	4400.00
0005433724855	18802	Economy	4400.00
0005433724820	21597	Economy	4400.00
0005433724819	21597	Economy	4400.00
0005432968869	21597	Economy	4400.00
0005432968868	21597	Economy	4400.00
0005433724818	21597	Economy	4400.00
0005433724838	21597	Economy	4400.00
0005433724826	21597	Economy	4400.00
0005432968867	21597	Economy	4400.00
0005434139127	7349	Business	23100.00
0005434139126	7349	Business	23100.00
0005434139102	7349	Business	23100.00
0005434139108	7349	Business	23100.00
0005434139049	7349	Business	23100.00
0005434087568	7349	Business	23100.00
0005434139090	7349	Business	23100.00
0005434139124	7349	Business	23100.00
0005434139092	7349	Business	23100.00
0005434139110	7349	Business	23100.00
0005434139117	7349	Business	23100.00
0005434139052	7349	Business	23100.00
0005434139048	7349	Economy	7700.00
0005434139113	7349	Economy	7700.00
0005434087570	7349	Economy	7700.00
0005434139125	7349	Economy	7700.00
0005434139129	7349	Economy	7700.00
0005434139101	7349	Economy	7700.00
0005434087567	7349	Economy	7700.00
0005434139112	7349	Economy	7700.00
0005434139089	7349	Economy	7700.00
0005434139068	7349	Economy	7700.00
0005434139075	7349	Economy	8500.00
0005434139059	7349	Economy	8500.00
0005434139081	7349	Economy	8500.00
0005434139087	7349	Economy	8500.00
0005434139107	7349	Economy	8500.00
0005434139053	7349	Economy	7700.00
0005434139056	7349	Economy	7700.00
0005434139095	7349	Economy	7700.00
0005434139100	7349	Economy	7700.00
0005434139069	7349	Economy	7700.00
0005434139064	7349	Economy	7700.00
0005434139050	7349	Economy	7700.00
0005434139128	7349	Economy	7700.00
0005434139106	7349	Economy	7700.00
0005434139079	7349	Economy	7700.00
0005434139078	7349	Economy	7700.00
0005434139062	7349	Economy	7700.00
0005434139077	7349	Economy	7700.00
0005434139088	7349	Economy	7700.00
0005434139074	7349	Economy	7700.00
0005434139097	7349	Economy	7700.00
0005434139065	7349	Economy	7700.00
0005434139105	7349	Economy	7700.00
0005434139058	7349	Economy	7700.00
0005434139055	7349	Economy	7700.00
0005434139070	7349	Economy	7700.00
0005434139123	7349	Economy	7700.00
0005434139083	7349	Economy	7700.00
0005434139118	7349	Economy	7700.00
0005434139085	7349	Economy	7700.00
0005434139054	7349	Economy	7700.00
0005434139073	7349	Economy	7700.00
0005434139091	7349	Economy	7700.00
0005434139115	7349	Economy	7700.00
0005434087569	7349	Economy	7700.00
0005434139084	7349	Economy	7700.00
0005434139072	7349	Economy	7700.00
0005434139066	7349	Economy	7700.00
0005434139061	7349	Economy	7700.00
0005434139057	7349	Economy	7700.00
0005434139104	7349	Economy	7700.00
0005434139063	7349	Economy	7700.00
0005434139120	7349	Economy	7700.00
0005434139086	7349	Economy	7700.00
0005434139060	7349	Economy	7700.00
0005434139080	7349	Economy	7700.00
0005434139122	7349	Economy	7700.00
0005434139093	7349	Economy	7700.00
0005434139116	7349	Economy	7700.00
0005434139076	7349	Economy	7700.00
0005434139103	7349	Economy	7700.00
0005434139094	7349	Economy	7700.00
0005434139099	7349	Economy	7700.00
0005434139067	7349	Economy	7700.00
0005434139111	7349	Economy	7700.00
0005434139121	7349	Economy	7700.00
0005434139096	7349	Economy	7700.00
0005434087571	7349	Economy	7700.00
0005434139098	7349	Economy	7700.00
0005434139051	7349	Economy	7700.00
0005434139071	7349	Economy	7700.00
0005434139109	7349	Economy	7700.00
0005434139082	7349	Economy	7700.00
0005434139114	7349	Economy	7700.00
0005434139119	7349	Economy	7700.00
0005434138148	28573	Business	23100.00
0005434138318	28573	Business	23100.00
0005434138392	28573	Business	23100.00
0005434138444	28573	Business	23100.00
0005434138277	28573	Business	23100.00
0005434138540	28573	Business	23100.00
0005434138588	28573	Business	23100.00
0005434138149	28573	Business	23100.00
0005434138557	28573	Business	23100.00
0005434138711	28573	Business	23100.00
0005434138269	28573	Business	23100.00
0005434138282	28573	Economy	7700.00
0005434138541	28573	Economy	7700.00
0005434138430	28573	Economy	7700.00
0005434137978	28573	Economy	7700.00
0005434138416	28573	Economy	7700.00
0005434138074	28573	Economy	7700.00
0005434138458	28573	Economy	7700.00
0005434138469	28573	Economy	7700.00
0005434138267	28573	Economy	7700.00
0005434138119	28573	Economy	8500.00
0005434138102	28573	Economy	8500.00
0005434138370	28573	Economy	8500.00
0005434138114	28573	Economy	8500.00
0005434138558	28573	Economy	7700.00
0005434138455	28573	Economy	7700.00
0005434138167	28573	Economy	7700.00
0005434138693	28573	Economy	7700.00
0005434138272	28573	Economy	7700.00
0005434138429	28573	Economy	7700.00
0005434138278	28573	Economy	7700.00
0005434138494	28573	Economy	7700.00
0005434138160	28573	Economy	7700.00
0005434087510	28573	Economy	7700.00
0005434137898	28573	Economy	7700.00
0005434138342	28573	Economy	7700.00
0005434138638	28573	Economy	7700.00
0005434137966	28573	Economy	7700.00
0005434138168	28573	Economy	7700.00
0005434138281	28573	Economy	7700.00
0005434138383	28573	Economy	7700.00
0005434138304	28573	Economy	7700.00
0005434138542	28573	Economy	7700.00
0005434137970	28573	Economy	7700.00
0005434138317	28573	Economy	7700.00
0005434138352	28573	Economy	7700.00
0005434138159	28573	Economy	7700.00
0005434138284	28573	Economy	7700.00
0005434138268	28573	Economy	7700.00
0005434138699	28573	Economy	7700.00
0005434087532	28573	Economy	7700.00
0005434138266	28573	Economy	7700.00
0005434087531	28573	Economy	7700.00
0005434138080	28573	Economy	7700.00
0005434138431	28573	Economy	7700.00
0005434138283	28573	Economy	7700.00
0005434138394	28573	Economy	7700.00
0005434138273	28573	Economy	7700.00
0005434138064	28573	Economy	7700.00
0005434138428	28573	Economy	7700.00
0005434138488	28573	Economy	7700.00
0005434138186	28573	Economy	7700.00
0005434138351	28573	Economy	7700.00
0005434137872	28573	Economy	7700.00
0005434138493	28573	Economy	7700.00
0005434138539	28573	Economy	7700.00
0005434137926	28573	Economy	7700.00
0005434138371	28573	Economy	7700.00
0005434137895	28573	Economy	7700.00
0005434138468	28573	Economy	7700.00
0005434138445	28573	Economy	7700.00
0005434138694	28573	Economy	7700.00
0005434138710	28573	Economy	7700.00
0005434138414	28573	Economy	7700.00
0005434087536	28573	Economy	7700.00
0005434138252	28573	Economy	7700.00
0005434087509	28573	Economy	7700.00
0005434138227	28573	Economy	7700.00
0005434138308	28573	Economy	7700.00
0005434138198	28573	Economy	7700.00
0005434138589	28573	Economy	7700.00
0005434138316	28573	Economy	7700.00
0005434138253	28573	Economy	7700.00
0005434138435	28573	Economy	7700.00
0005434138442	28573	Economy	7700.00
0005434138509	28573	Economy	7700.00
0005434138350	28573	Economy	7700.00
0005435808356	1916	Economy	23900.00
0005433407581	1916	Economy	23900.00
0005433407580	1916	Economy	21700.00
0005435808358	1916	Economy	21700.00
0005433407564	1916	Economy	21700.00
0005434610270	1916	Economy	21700.00
0005435808354	1916	Economy	21700.00
0005435808359	1916	Economy	21700.00
0005434610269	1916	Economy	21700.00
0005434610271	1916	Economy	21700.00
0005435808351	1916	Economy	21700.00
0005435808352	1916	Economy	21700.00
0005435808348	1916	Economy	21700.00
0005435808350	1916	Economy	21700.00
0005433407585	1916	Economy	21700.00
0005433407572	1916	Economy	21700.00
0005433407584	1916	Economy	21700.00
0005435808355	1916	Economy	21700.00
0005435808349	1916	Economy	21700.00
0005435808353	1916	Economy	21700.00
0005435808357	1916	Economy	21700.00
0005434610252	23106	Economy	21700.00
0005434610233	23106	Economy	21700.00
0005434610235	23106	Economy	21700.00
0005434610234	23106	Economy	21700.00
0005434504320	16705	Economy	7600.00
0005434504345	16705	Economy	7600.00
0005434504132	16705	Economy	6900.00
0005434504319	16705	Economy	6900.00
0005434504292	16705	Economy	6900.00
0005434504258	16705	Economy	6900.00
0005434504306	16705	Economy	6900.00
0005434504327	16705	Economy	6900.00
0005434504324	16705	Economy	6900.00
0005434504133	16705	Economy	6900.00
0005434504159	16705	Economy	6900.00
0005434504323	16705	Economy	6900.00
0005434504169	16705	Economy	6900.00
0005434504117	16705	Economy	6900.00
0005434504138	16705	Economy	6900.00
0005434504107	16705	Economy	6900.00
0005434504354	16705	Economy	6900.00
0005434504158	16705	Economy	6900.00
0005434504229	16705	Economy	6900.00
0005434504118	16705	Economy	6900.00
0005434503996	16705	Economy	6900.00
0005434504200	16705	Economy	6900.00
0005434504246	16705	Economy	6900.00
0005434504111	16705	Economy	6900.00
0005434504228	16705	Economy	6900.00
0005434504253	16705	Economy	6900.00
0005434504366	16705	Economy	6900.00
0005434503997	16705	Economy	6900.00
0005434504191	16705	Economy	6900.00
0005434504168	16705	Economy	6900.00
0005434504058	16705	Economy	6900.00
0005434504182	16705	Economy	6900.00
0005434504568	22880	Economy	7600.00
0005434504562	22880	Economy	7600.00
0005434504565	22880	Economy	7600.00
0005434504567	22880	Economy	6900.00
0005434504560	22880	Economy	6900.00
0005434504580	22880	Economy	6900.00
0005434504569	22880	Economy	6900.00
0005434504576	22880	Economy	6900.00
0005434504553	22880	Economy	6900.00
0005434504570	22880	Economy	6900.00
0005434504549	22880	Economy	6900.00
0005434504566	22880	Economy	6900.00
0005434504546	22880	Economy	6900.00
0005434504579	22880	Economy	6900.00
0005434504559	22880	Economy	6900.00
0005434504572	22880	Economy	6900.00
0005434504571	22880	Economy	6900.00
0005434504556	22880	Economy	6900.00
0005434504577	22880	Economy	6900.00
0005434504581	22880	Economy	6900.00
0005434504561	22880	Economy	6900.00
0005434504550	22880	Economy	6900.00
0005434504564	22880	Economy	6900.00
0005434504563	22880	Economy	6900.00
0005434504578	22880	Economy	6900.00
0005434504551	22880	Economy	6900.00
0005434504575	22880	Economy	6900.00
0005434504548	22880	Economy	6900.00
0005434504555	22880	Economy	6900.00
0005434504552	22880	Economy	6900.00
0005434504558	22880	Economy	6900.00
0005434504554	22880	Economy	6900.00
0005434504547	22880	Economy	6900.00
0005434504574	22880	Economy	6900.00
0005434504557	22880	Economy	6900.00
0005434504573	22880	Economy	6900.00
0005434608349	6500	Economy	19100.00
0005434608352	6500	Economy	17300.00
0005434608353	6500	Economy	17300.00
0005434608341	6500	Economy	17300.00
0005434608356	6500	Economy	17300.00
0005434608347	6500	Economy	17300.00
0005434608351	6500	Economy	17300.00
0005434608346	6500	Economy	17300.00
0005434608339	6500	Economy	17300.00
0005434608340	6500	Economy	17300.00
0005434608348	6500	Economy	17300.00
0005434608344	6500	Economy	17300.00
0005434608355	6500	Economy	17300.00
0005434608350	6500	Economy	17300.00
0005434608345	6500	Economy	17300.00
0005434608342	6500	Economy	17300.00
0005434608354	6500	Economy	17300.00
0005434608343	6500	Economy	17300.00
0005434608357	6500	Economy	17300.00
0005434608316	22499	Economy	19100.00
0005434608310	22499	Economy	19100.00
0005434608333	22499	Economy	17300.00
0005434608336	22499	Economy	17300.00
0005434608331	22499	Economy	17300.00
0005434608317	22499	Economy	17300.00
0005434608321	22499	Economy	17300.00
0005434608301	22499	Economy	17300.00
0005434608302	22499	Economy	17300.00
0005434608320	22499	Economy	17300.00
0005434608307	22499	Economy	17300.00
0005434608306	22499	Economy	17300.00
0005434608309	22499	Economy	17300.00
0005434608323	22499	Economy	17300.00
0005434608303	22499	Economy	17300.00
0005434608308	22499	Economy	17300.00
0005434608322	22499	Economy	17300.00
0005434608313	22499	Economy	17300.00
0005434608335	22499	Economy	17300.00
0005434608329	22499	Economy	17300.00
0005434608312	22499	Economy	17300.00
0005434608311	22499	Economy	17300.00
0005435078517	2225	Economy	7700.00
0005433266740	2225	Economy	7000.00
0005435078519	2225	Economy	7000.00
0005433266742	2225	Economy	7000.00
0005435078524	2225	Economy	7000.00
0005435078525	2225	Economy	7000.00
0005435078512	2225	Economy	7000.00
0005435078516	2225	Economy	7000.00
0005433266783	2225	Economy	7000.00
0005435078513	2225	Economy	7000.00
0005435078514	2225	Economy	7000.00
0005433266675	2225	Economy	7000.00
0005435078523	2225	Economy	7000.00
0005433266741	2225	Economy	7000.00
0005435078515	2225	Economy	7000.00
0005435078521	2225	Economy	7000.00
0005435078511	2225	Economy	7000.00
0005435078520	2225	Economy	7000.00
0005435078518	2225	Economy	7000.00
0005435078522	2225	Economy	7000.00
0005433266731	2225	Economy	7000.00
0005435078337	24344	Economy	7700.00
0005435078392	24344	Economy	7000.00
0005433266832	24344	Economy	7000.00
0005435078398	24344	Economy	7000.00
0005435078399	24344	Economy	7000.00
0005435078391	24344	Economy	7000.00
0005433266827	24344	Economy	7000.00
0005435078294	24344	Economy	7000.00
0005433266828	24344	Economy	7000.00
0005435078293	24344	Economy	7000.00
0005435078343	24344	Economy	7000.00
0005433266829	24344	Economy	7000.00
0005433266825	24344	Economy	7000.00
0005435078400	24344	Economy	7000.00
0005435078387	24344	Economy	7000.00
0005433266826	24344	Economy	7000.00
0005433266831	24344	Economy	7000.00
0005435078372	24344	Economy	7000.00
0005435078429	24344	Economy	7000.00
0005435078356	24344	Economy	7000.00
0005435078240	24344	Economy	7000.00
0005435078338	24344	Economy	7000.00
0005433266824	24344	Economy	7000.00
0005435078334	24344	Economy	7000.00
0005435078335	24344	Economy	7000.00
0005435078357	24344	Economy	7000.00
0005435078396	24344	Economy	7000.00
0005433266830	24344	Economy	7000.00
0005435078397	24344	Economy	7000.00
0005435464511	6656	Economy	10800.00
0005434988866	6656	Economy	10800.00
0005435464522	6656	Economy	10800.00
0005434988861	6656	Economy	9800.00
0005434988864	6656	Economy	9800.00
0005434988869	6656	Economy	9800.00
0005434988865	6656	Economy	9800.00
0005434988870	6656	Economy	9800.00
0005435464510	6656	Economy	9800.00
0005434988863	6656	Economy	9800.00
0005434988859	6656	Economy	9800.00
0005435803294	6656	Economy	9800.00
0005435803293	6656	Economy	9800.00
0005435464512	6656	Economy	9800.00
0005434988862	6656	Economy	9800.00
0005434988867	6656	Economy	9800.00
0005434988860	6656	Economy	9800.00
0005435803292	6656	Economy	9800.00
0005435464523	6656	Economy	9800.00
0005434988868	6656	Economy	9800.00
0005434988728	23631	Economy	10800.00
0005434988734	23631	Economy	10800.00
0005435803271	23631	Economy	9800.00
0005434988740	23631	Economy	9800.00
0005434988706	23631	Economy	9800.00
0005434988711	23631	Economy	9800.00
0005435464531	23631	Economy	9800.00
0005434988705	23631	Economy	9800.00
0005434988738	23631	Economy	9800.00
0005434988712	23631	Economy	9800.00
0005434988756	23631	Economy	9800.00
0005434988750	23631	Economy	9800.00
0005435464532	23631	Economy	9800.00
0005434988710	23631	Economy	9800.00
0005434988721	23631	Economy	9800.00
0005435464530	23631	Economy	9800.00
0005434988718	23631	Economy	9800.00
0005434988744	23631	Economy	9800.00
0005434988739	23631	Economy	9800.00
0005433450209	30465	Business	9900.00
0005432383627	30465	Business	9900.00
0005433450210	30465	Business	9900.00
0005433450222	30465	Business	9900.00
0005432383612	30465	Business	9900.00
0005432383610	30465	Business	9900.00
0005432383611	30465	Economy	3300.00
0005432383620	30465	Economy	3300.00
0005432383621	30465	Economy	3300.00
0005432383616	30465	Economy	3300.00
0005433450217	30465	Economy	3300.00
0005433450215	30465	Economy	3300.00
0005432383637	30465	Economy	3600.00
0005432383635	30465	Economy	3600.00
0005432383634	30465	Economy	3600.00
0005432383629	30465	Economy	3300.00
0005433450223	30465	Economy	3300.00
0005433453783	30465	Economy	3300.00
0005433450226	30465	Economy	3300.00
0005433450213	30465	Economy	3300.00
0005433450225	30465	Economy	3300.00
0005432383636	30465	Economy	3300.00
0005433450207	30465	Economy	3300.00
0005432383632	30465	Economy	3300.00
0005432383623	30465	Economy	3300.00
0005432383630	30465	Economy	3300.00
0005433450221	30465	Economy	3300.00
0005433453782	30465	Economy	3300.00
0005433450220	30465	Economy	3300.00
0005433450214	30465	Economy	3300.00
0005432383626	30465	Economy	3300.00
0005433454900	30465	Economy	3300.00
0005432383631	30465	Economy	3300.00
0005432383618	30465	Economy	3300.00
0005432383625	30465	Economy	3300.00
0005432383628	30465	Economy	3300.00
0005433453784	30465	Economy	3300.00
0005433454899	30465	Economy	3300.00
0005432383624	30465	Economy	3300.00
0005432383609	30465	Economy	3300.00
0005432383617	30465	Economy	3300.00
0005432383614	30465	Economy	3300.00
0005432383633	30465	Economy	3300.00
0005432383619	30465	Economy	3300.00
0005433450211	30465	Economy	3300.00
0005433450216	30465	Economy	3300.00
0005433450212	30465	Economy	3300.00
0005432383615	30465	Economy	3300.00
0005433450219	30465	Economy	3300.00
0005432383613	30465	Economy	3300.00
0005432383638	30465	Economy	3300.00
0005433450218	30465	Economy	3300.00
0005433450208	30465	Economy	3300.00
0005433450224	30465	Economy	3300.00
0005433450228	30465	Economy	3300.00
0005433450227	30465	Economy	3300.00
0005432383622	30465	Economy	3300.00
0005432383116	31297	Business	9900.00
0005433450095	31297	Business	9900.00
0005432383100	31297	Business	9900.00
0005432383239	31297	Business	9900.00
0005432383278	31297	Business	9900.00
0005433450051	31297	Business	9900.00
0005433450059	31297	Business	9900.00
0005432383311	31297	Business	9900.00
0005432383198	31297	Business	9900.00
0005432383170	31297	Business	9900.00
0005432382996	31297	Economy	3300.00
0005432383243	31297	Economy	3300.00
0005433449960	31297	Economy	3300.00
0005432383132	31297	Economy	3300.00
0005432383306	31297	Economy	3300.00
0005433450157	31297	Economy	3300.00
0005433450018	31297	Economy	3300.00
0005433450020	31297	Economy	3600.00
0005433449896	31297	Economy	3600.00
0005433450039	31297	Economy	3600.00
0005433450077	31297	Economy	3600.00
0005433450064	31297	Economy	3600.00
0005432383084	31297	Economy	3300.00
0005432383043	31297	Economy	3300.00
0005433450073	31297	Economy	3300.00
0005432383242	31297	Economy	3300.00
0005432383154	31297	Economy	3300.00
0005432383183	31297	Economy	3300.00
0005433453763	31297	Economy	3300.00
0005433450008	31297	Economy	3300.00
0005432383148	31297	Economy	3300.00
0005432383164	31297	Economy	3300.00
0005433450058	31297	Economy	3300.00
0005432383276	31297	Economy	3300.00
0005432383153	31297	Economy	3300.00
0005432383191	31297	Economy	3300.00
0005433450050	31297	Economy	3300.00
0005432383237	31297	Economy	3300.00
0005433450049	31297	Economy	3300.00
0005432383099	31297	Economy	3300.00
0005432383147	31297	Economy	3300.00
0005432383121	31297	Economy	3300.00
0005433451632	31297	Economy	3300.00
0005432383238	31297	Economy	3300.00
0005433449979	31297	Economy	3300.00
0005432383117	31297	Economy	3300.00
0005433450094	31297	Economy	3300.00
0005433451631	31297	Economy	3300.00
0005432383096	31297	Economy	3300.00
0005433450135	31297	Economy	3300.00
0005432383268	31297	Economy	3300.00
0005433450009	31297	Economy	3300.00
0005432383241	31297	Economy	3300.00
0005432383202	31297	Economy	3300.00
0005433450158	31297	Economy	3300.00
0005433450042	31297	Economy	3300.00
0005432383277	31297	Economy	3300.00
0005432383269	31297	Economy	3300.00
0005433450154	31297	Economy	3300.00
0005432383150	31297	Economy	3300.00
0005433450072	31297	Economy	3300.00
0005432383203	31297	Economy	3300.00
0005432383149	31297	Economy	3300.00
0005432383260	31297	Economy	3300.00
0005432383152	31297	Economy	3300.00
0005432383312	31297	Economy	3300.00
0005432383042	31297	Economy	3300.00
0005433450028	31297	Economy	3300.00
0005433450019	31297	Economy	3300.00
0005432383016	31297	Economy	3300.00
0005433449957	31297	Economy	3300.00
0005432383232	31297	Economy	3300.00
0005433453762	31297	Economy	3300.00
0005433450014	31297	Economy	3300.00
0005433449895	31297	Economy	3300.00
0005432383264	31297	Economy	3300.00
0005433450017	31297	Economy	3300.00
0005432383171	31297	Economy	3300.00
0005433450000	31297	Economy	3300.00
0005432383095	31297	Economy	3300.00
0005432382995	31297	Economy	3300.00
0005433450104	31297	Economy	3300.00
0005433788244	20824	Economy	26200.00
0005435548476	20824	Economy	23800.00
0005433788235	20824	Economy	23800.00
0005435548484	20824	Economy	23800.00
0005435548489	20824	Economy	23800.00
0005435548485	20824	Economy	23800.00
0005435548471	20824	Economy	23800.00
0005435548473	20824	Economy	23800.00
0005435548478	20824	Economy	23800.00
0005435548490	20824	Economy	23800.00
0005433788236	20824	Economy	23800.00
0005433788237	20824	Economy	23800.00
0005433788246	20824	Economy	23800.00
0005433788243	20824	Economy	23800.00
0005433788247	20824	Economy	23800.00
0005435548459	20824	Economy	23800.00
0005435548492	20824	Economy	23800.00
0005435548493	20824	Economy	23800.00
0005433788241	20824	Economy	23800.00
0005433788248	20824	Economy	23800.00
0005435548477	20824	Economy	23800.00
0005433788242	20824	Economy	23800.00
0005433788240	20824	Economy	23800.00
0005435548472	20824	Economy	23800.00
0005435548488	20824	Economy	23800.00
0005435548463	20824	Economy	23800.00
0005433788238	20824	Economy	23800.00
0005435548475	20824	Economy	23800.00
0005433788239	20824	Economy	23800.00
0005433788245	20824	Economy	23800.00
0005433126853	10757	Economy	17100.00
0005435299784	10757	Economy	15600.00
0005433126829	10757	Economy	15600.00
0005433131701	10757	Economy	15600.00
0005435299785	10757	Economy	15600.00
0005433131705	10757	Economy	15600.00
0005435304156	10757	Economy	15600.00
0005433126852	10757	Economy	15600.00
0005435304183	10757	Economy	15600.00
0005433126854	10757	Economy	15600.00
0005433131702	10757	Economy	15600.00
0005435304164	10757	Economy	15600.00
0005435299781	10757	Economy	15600.00
0005435304155	10757	Economy	15600.00
0005435299771	10757	Economy	15600.00
0005435304182	10757	Economy	15600.00
0005433131696	10757	Economy	15600.00
0005435299770	10757	Economy	15600.00
0005433129334	29723	Economy	17100.00
0005435302255	29723	Economy	17100.00
0005435299834	29723	Economy	17100.00
0005433126900	29723	Economy	17100.00
0005435299833	29723	Economy	15600.00
0005435299835	29723	Economy	15600.00
0005435302256	29723	Economy	15600.00
0005435299832	29723	Economy	15600.00
0005435299836	29723	Economy	15600.00
0005433126901	29723	Economy	15600.00
0005435302258	29723	Economy	15600.00
0005433126902	29723	Economy	15600.00
0005433126899	29723	Economy	15600.00
0005435302257	29723	Economy	15600.00
0005435302254	29723	Economy	15600.00
0005433129330	29723	Economy	15600.00
0005433129332	29723	Economy	15600.00
0005433129331	29723	Economy	15600.00
0005433129333	29723	Economy	15600.00
0005434287537	2410	Economy	17200.00
0005433110117	2410	Economy	17200.00
0005434287541	2410	Economy	17200.00
0005434287548	2410	Economy	15700.00
0005434287538	2410	Economy	15700.00
0005433110050	2410	Economy	15700.00
0005433110068	2410	Economy	15700.00
0005432264503	2410	Economy	15700.00
0005433110112	2410	Economy	15700.00
0005434287550	2410	Economy	15700.00
0005433110113	2410	Economy	15700.00
0005434287545	2410	Economy	15700.00
0005432264502	2410	Economy	15700.00
0005434287534	2410	Economy	15700.00
0005434287551	2410	Economy	15700.00
0005434287532	2410	Economy	15700.00
0005434287542	2410	Economy	15700.00
0005434287529	2410	Economy	15700.00
0005433110052	2410	Economy	15700.00
0005434287552	2410	Economy	15700.00
0005434287531	2410	Economy	15700.00
0005433110065	2410	Economy	15700.00
0005434287533	2410	Economy	15700.00
0005433110066	2410	Economy	15700.00
0005434287543	2410	Economy	15700.00
0005434287535	2410	Economy	15700.00
0005434287539	2410	Economy	15700.00
0005434287549	2410	Economy	15700.00
0005434287530	2410	Economy	15700.00
0005434287546	2410	Economy	15700.00
0005433110089	2410	Economy	15700.00
0005434287540	2410	Economy	15700.00
0005434287536	2410	Economy	15700.00
0005434287547	2410	Economy	15700.00
0005434287544	2410	Economy	15700.00
0005432264504	2410	Economy	15700.00
0005433110188	26822	Economy	17200.00
0005433110196	26822	Economy	17200.00
0005434287344	26822	Economy	17200.00
0005434287434	26822	Economy	17200.00
0005434287347	26822	Economy	15700.00
0005433110186	26822	Economy	15700.00
0005433110184	26822	Economy	15700.00
0005433110192	26822	Economy	15700.00
0005434287473	26822	Economy	15700.00
0005434287468	26822	Economy	15700.00
0005434287352	26822	Economy	15700.00
0005433110193	26822	Economy	15700.00
0005433110194	26822	Economy	15700.00
0005434287339	26822	Economy	15700.00
0005433110185	26822	Economy	15700.00
0005434287376	26822	Economy	15700.00
0005434287380	26822	Economy	15700.00
0005434287242	26822	Economy	15700.00
0005434287262	26822	Economy	15700.00
0005434287411	26822	Economy	15700.00
0005434287345	26822	Economy	15700.00
0005434287418	26822	Economy	15700.00
0005434287377	26822	Economy	15700.00
0005434287340	26822	Economy	15700.00
0005434287346	26822	Economy	15700.00
0005434287343	26822	Economy	15700.00
0005434287382	26822	Economy	15700.00
0005434287282	26822	Economy	15700.00
0005434287338	26822	Economy	15700.00
0005433110190	26822	Economy	15700.00
0005434287433	26822	Economy	15700.00
0005434287383	26822	Economy	15700.00
0005434287261	26822	Economy	15700.00
0005433110191	26822	Economy	15700.00
0005433110195	26822	Economy	15700.00
0005433110189	26822	Economy	15700.00
0005433110187	26822	Economy	15700.00
0005434287381	26822	Economy	15700.00
0005434272197	25471	Economy	22800.00
0005435856251	25471	Economy	22800.00
0005434269110	25471	Economy	22800.00
0005435856252	25471	Economy	22800.00
0005435856254	25471	Economy	22800.00
0005435856253	25471	Economy	22800.00
0005434272195	25471	Economy	22800.00
0005434269106	25471	Economy	22800.00
0005435856250	25471	Economy	22800.00
0005434272196	25471	Economy	22800.00
0005435856202	26633	Economy	25000.00
0005435856209	26633	Economy	25000.00
0005435856208	26633	Economy	22800.00
0005434273095	26633	Economy	22800.00
0005434272210	26633	Economy	22800.00
0005434273096	26633	Economy	22800.00
0005435856203	26633	Economy	22800.00
0005435314880	19085	Economy	24600.00
0005434520253	19085	Economy	24600.00
0005434520270	19085	Economy	22300.00
0005434520287	19085	Economy	22300.00
0005435314876	19085	Economy	22300.00
0005434520268	19085	Economy	22300.00
0005435314881	19085	Economy	22300.00
0005434520279	19085	Economy	22300.00
0005434520276	19085	Economy	22300.00
0005435314882	19085	Economy	22300.00
0005434520273	19085	Economy	22300.00
0005435314883	19085	Economy	22300.00
0005434520246	19085	Economy	22300.00
0005435314877	19085	Economy	22300.00
0005434520226	19085	Economy	22300.00
0005434520301	19085	Economy	22300.00
0005434520267	19085	Economy	22300.00
0005434520280	19085	Economy	22300.00
0005435314878	19085	Economy	22300.00
0005434520290	19085	Economy	22300.00
0005434520225	19085	Economy	22300.00
0005435314879	19085	Economy	22300.00
0005434520281	19085	Economy	22300.00
0005434520254	19085	Economy	22300.00
0005434520266	19085	Economy	22300.00
0005434520271	19085	Economy	22300.00
0005434520324	19085	Economy	22300.00
0005434520288	19085	Economy	22300.00
0005434520302	19085	Economy	22300.00
0005435314875	19085	Economy	22300.00
0005434520300	19085	Economy	22300.00
0005435314874	19085	Economy	22300.00
0005434520269	19085	Economy	22300.00
0005434520299	19085	Economy	22300.00
0005434520316	19085	Economy	22300.00
0005434520303	19085	Economy	22300.00
0005433874390	7783	Economy	19200.00
0005433874394	7783	Economy	17400.00
0005433874384	7783	Economy	17400.00
0005433874395	7783	Economy	17400.00
0005433874386	7783	Economy	17400.00
0005433874392	7783	Economy	17400.00
0005433874387	7783	Economy	17400.00
0005433874389	7783	Economy	17400.00
0005433874393	7783	Economy	17400.00
0005433874391	7783	Economy	17400.00
0005433874388	7783	Economy	17400.00
0005433874385	7783	Economy	17400.00
0005433874357	32634	Economy	17400.00
0005433874353	32634	Economy	17400.00
0005433874356	32634	Economy	17400.00
0005433874364	32634	Economy	17400.00
0005433874344	32634	Economy	17400.00
0005433874363	32634	Economy	17400.00
0005433874338	32634	Economy	17400.00
0005433874339	32634	Economy	17400.00
0005433874345	32634	Economy	17400.00
0005433874343	32634	Economy	17400.00
0005433874346	32634	Economy	17400.00
0005433874354	32634	Economy	17400.00
0005433868905	4793	Economy	19400.00
0005433868885	4793	Economy	19400.00
0005433868906	4793	Economy	19400.00
0005433868903	4793	Economy	19400.00
0005433868914	4793	Economy	17600.00
0005433868878	4793	Economy	17600.00
0005433868904	4793	Economy	17600.00
0005433868879	4793	Economy	17600.00
0005433868889	4793	Economy	17600.00
0005433868901	4793	Economy	17600.00
0005433868894	4793	Economy	17600.00
0005433868881	4793	Economy	17600.00
0005433868900	4793	Economy	17600.00
0005433868916	4793	Economy	17600.00
0005433868910	4793	Economy	17600.00
0005433868895	4793	Economy	17600.00
0005433868880	4793	Economy	17600.00
0005433868888	4793	Economy	17600.00
0005433868911	4793	Economy	17600.00
0005433868891	4793	Economy	17600.00
0005433868882	4793	Economy	17600.00
0005433868899	4793	Economy	17600.00
0005435860486	4793	Economy	17600.00
0005433868897	4793	Economy	17600.00
0005433868915	4793	Economy	17600.00
0005435860487	4793	Economy	17600.00
0005433868892	4793	Economy	17600.00
0005433868908	4793	Economy	17600.00
0005433868886	4793	Economy	17600.00
0005433868909	4793	Economy	17600.00
0005433868898	4793	Economy	17600.00
0005433868907	4793	Economy	17600.00
0005433868893	4793	Economy	17600.00
0005433868884	4793	Economy	17600.00
0005433868887	4793	Economy	17600.00
0005433868896	4793	Economy	17600.00
0005433868913	4793	Economy	17600.00
0005433868902	4793	Economy	17600.00
0005433868890	4793	Economy	17600.00
0005433868912	4793	Economy	17600.00
0005433868883	4793	Economy	17600.00
0005433868568	32611	Economy	19400.00
0005433868627	32611	Economy	17600.00
0005435860517	32611	Economy	17600.00
0005433868538	32611	Economy	17600.00
0005435860518	32611	Economy	17600.00
0005433868527	32611	Economy	17600.00
0005433868742	32611	Economy	17600.00
0005433868567	32611	Economy	17600.00
0005435860516	32611	Economy	17600.00
0005433868630	32611	Economy	17600.00
0005433868493	32611	Economy	17600.00
0005433868414	32611	Economy	17600.00
0005433868564	32611	Economy	17600.00
0005433868619	32611	Economy	17600.00
0005433868703	32611	Economy	17600.00
0005433868415	32611	Economy	17600.00
0005433868631	32611	Economy	17600.00
0005433868448	32611	Economy	17600.00
0005435860514	32611	Economy	17600.00
0005433868620	32611	Economy	17600.00
0005433868504	32611	Economy	17600.00
0005433868309	32611	Economy	17600.00
0005433868629	32611	Economy	17600.00
0005433868270	32611	Economy	17600.00
0005433868529	32611	Economy	17600.00
0005433868573	32611	Economy	17600.00
0005435860519	32611	Economy	17600.00
0005433868565	32611	Economy	17600.00
0005433868530	32611	Economy	17600.00
0005433868569	32611	Economy	17600.00
0005433868453	32611	Economy	17600.00
0005435860515	32611	Economy	17600.00
0005433868531	32611	Economy	17600.00
0005433868503	32611	Economy	17600.00
0005433868479	32611	Economy	17600.00
0005433868370	32611	Economy	17600.00
0005433868451	32611	Economy	17600.00
0005433868478	32611	Economy	17600.00
0005433868546	32611	Economy	17600.00
0005434663566	3406	Economy	24800.00
0005434663561	3406	Economy	24800.00
0005434461672	3406	Economy	24800.00
0005434663558	3406	Economy	22600.00
0005434663569	3406	Economy	22600.00
0005435911480	3406	Economy	22600.00
0005435911485	3406	Economy	22600.00
0005434663565	3406	Economy	22600.00
0005434663563	3406	Economy	22600.00
0005435911474	3406	Economy	22600.00
0005434663568	3406	Economy	22600.00
0005434663564	3406	Economy	22600.00
0005434460530	3406	Economy	22600.00
0005434663557	3406	Economy	22600.00
0005434461673	3406	Economy	22600.00
0005434461670	3406	Economy	22600.00
0005435911433	3406	Economy	22600.00
0005435911486	3406	Economy	22600.00
0005435911481	3406	Economy	22600.00
0005434663562	3406	Economy	22600.00
0005435911482	3406	Economy	22600.00
0005435911473	3406	Economy	22600.00
0005434461671	3406	Economy	22600.00
0005434663559	3406	Economy	22600.00
0005434663567	3406	Economy	22600.00
0005434663556	3406	Economy	22600.00
0005434460529	3406	Economy	22600.00
0005434663560	3406	Economy	22600.00
0005434663475	12475	Economy	24800.00
0005435911541	12475	Economy	24800.00
0005434462792	12475	Economy	24800.00
0005435911534	12475	Economy	24800.00
0005434462791	12475	Economy	22600.00
0005434663377	12475	Economy	22600.00
0005435911538	12475	Economy	22600.00
0005434462784	12475	Economy	22600.00
0005434462793	12475	Economy	22600.00
0005434462787	12475	Economy	22600.00
0005434663448	12475	Economy	22600.00
0005434663491	12475	Economy	22600.00
0005434460502	12475	Economy	22600.00
0005435911535	12475	Economy	22600.00
0005435911539	12475	Economy	22600.00
0005434462788	12475	Economy	22600.00
0005434663479	12475	Economy	22600.00
0005434663425	12475	Economy	22600.00
0005434663429	12475	Economy	22600.00
0005434663376	12475	Economy	22600.00
0005434663424	12475	Economy	22600.00
0005434460495	12475	Economy	22600.00
0005434462790	12475	Economy	22600.00
0005435911537	12475	Economy	22600.00
0005434663478	12475	Economy	22600.00
0005434460503	12475	Economy	22600.00
0005435911540	12475	Economy	22600.00
0005434663349	12475	Economy	22600.00
0005434462794	12475	Economy	22600.00
0005434663378	12475	Economy	22600.00
0005435911536	12475	Economy	22600.00
0005434663469	12475	Economy	22600.00
0005434663426	12475	Economy	22600.00
0005434460496	12475	Economy	22600.00
0005433868479	14473	Economy	18500.00
0005433868478	14473	Economy	18500.00
0005433868538	14473	Economy	18500.00
0005433868569	14473	Economy	16800.00
0005435860516	14473	Economy	16800.00
0005433868493	14473	Economy	16800.00
0005433868451	14473	Economy	16800.00
0005433868504	14473	Economy	16800.00
0005433868309	14473	Economy	16800.00
0005433868619	14473	Economy	16800.00
0005433868503	14473	Economy	16800.00
0005433868529	14473	Economy	16800.00
0005433868530	14473	Economy	16800.00
0005433868531	14473	Economy	16800.00
0005433868527	14473	Economy	16800.00
0005435860518	14473	Economy	16800.00
0005433868631	14473	Economy	16800.00
0005435860519	14473	Economy	16800.00
0005433868742	14473	Economy	16800.00
0005433868415	14473	Economy	16800.00
0005433868564	14473	Economy	16800.00
0005433868448	14473	Economy	16800.00
0005435860514	14473	Economy	16800.00
0005435860515	14473	Economy	16800.00
0005433868573	14473	Economy	16800.00
0005433868370	14473	Economy	16800.00
0005435860517	14473	Economy	16800.00
0005433868627	14473	Economy	16800.00
0005433868620	14473	Economy	16800.00
0005433868703	14473	Economy	16800.00
0005433868568	14473	Economy	16800.00
0005433868630	14473	Economy	16800.00
0005433868629	14473	Economy	16800.00
0005433868567	14473	Economy	16800.00
0005433868453	14473	Economy	16800.00
0005433868546	14473	Economy	16800.00
0005433868414	14473	Economy	16800.00
0005433868565	14473	Economy	16800.00
0005433868270	14473	Economy	16800.00
0005435860491	32693	Economy	18500.00
0005433868874	32693	Economy	18500.00
0005433868876	32693	Economy	18500.00
0005433868866	32693	Economy	18500.00
0005433868863	32693	Economy	16800.00
0005433868865	32693	Economy	16800.00
0005433868842	32693	Economy	16800.00
0005433868845	32693	Economy	16800.00
0005433868867	32693	Economy	16800.00
0005433868870	32693	Economy	16800.00
0005433868873	32693	Economy	16800.00
0005433868852	32693	Economy	16800.00
0005435860493	32693	Economy	16800.00
0005433868872	32693	Economy	16800.00
0005433868841	32693	Economy	16800.00
0005433868843	32693	Economy	16800.00
0005433868855	32693	Economy	16800.00
0005433868846	32693	Economy	16800.00
0005433868877	32693	Economy	16800.00
0005433868838	32693	Economy	16800.00
0005433868837	32693	Economy	16800.00
0005433868851	32693	Economy	16800.00
0005433868844	32693	Economy	16800.00
0005433868860	32693	Economy	16800.00
0005433868849	32693	Economy	16800.00
0005433868871	32693	Economy	16800.00
0005433868864	32693	Economy	16800.00
0005433868875	32693	Economy	16800.00
0005433868861	32693	Economy	16800.00
0005433868850	32693	Economy	16800.00
0005433868858	32693	Economy	16800.00
0005433868853	32693	Economy	16800.00
0005433868868	32693	Economy	16800.00
0005435860484	32693	Economy	16800.00
0005435860492	32693	Economy	16800.00
0005433868840	32693	Economy	16800.00
0005433868854	32693	Economy	16800.00
0005433868869	32693	Economy	16800.00
0005435860490	32693	Economy	16800.00
0005435860485	32693	Economy	16800.00
0005435860483	32693	Economy	16800.00
0005433868856	32693	Economy	16800.00
0005433868859	32693	Economy	16800.00
0005433868839	32693	Economy	16800.00
0005433868862	32693	Economy	16800.00
0005433868847	32693	Economy	16800.00
0005433868857	32693	Economy	16800.00
0005435860482	32693	Economy	16800.00
0005433868848	32693	Economy	16800.00
0005432799525	12133	Economy	4900.00
0005432799388	12133	Economy	4400.00
0005432799553	12133	Economy	4400.00
0005432799564	12133	Economy	4400.00
0005432799466	12133	Economy	4400.00
0005432799524	12133	Economy	4400.00
0005432799651	12133	Economy	4400.00
0005432799550	12133	Economy	4400.00
0005432799423	12133	Economy	4400.00
0005432799499	12133	Economy	4400.00
0005432799512	12133	Economy	4400.00
0005432799467	12133	Economy	4400.00
0005432799588	12133	Economy	4400.00
0005432799517	12133	Economy	4400.00
0005432799454	12133	Economy	4400.00
0005432799462	12133	Economy	4400.00
0005432799562	12133	Economy	4400.00
0005432799582	12133	Economy	4400.00
0005432799505	12133	Economy	4400.00
0005432799563	12133	Economy	4400.00
0005432799558	12133	Economy	4400.00
0005432799504	12133	Economy	4400.00
0005432799498	12133	Economy	4400.00
0005432799565	12133	Economy	4400.00
0005432799429	12133	Economy	4400.00
0005432799597	12133	Economy	4400.00
0005432799518	12133	Economy	4400.00
0005432799655	12133	Economy	4400.00
0005432799549	12133	Economy	4400.00
0005432799602	12133	Economy	4400.00
0005432799593	12133	Economy	4400.00
0005432799506	12133	Economy	4400.00
0005432799600	12133	Economy	4400.00
0005432799754	14805	Economy	4900.00
0005432799747	14805	Economy	4900.00
0005432799751	14805	Economy	4900.00
0005432799737	14805	Economy	4900.00
0005432799745	14805	Economy	4400.00
0005432799749	14805	Economy	4400.00
0005432799752	14805	Economy	4400.00
0005432799743	14805	Economy	4400.00
0005432799738	14805	Economy	4400.00
0005432799742	14805	Economy	4400.00
0005432799740	14805	Economy	4400.00
0005432799744	14805	Economy	4400.00
0005432799760	14805	Economy	4400.00
0005432799741	14805	Economy	4400.00
0005432799762	14805	Economy	4400.00
0005432799759	14805	Economy	4400.00
0005432799758	14805	Economy	4400.00
0005432799761	14805	Economy	4400.00
0005432799736	14805	Economy	4400.00
0005432799753	14805	Economy	4400.00
0005432799755	14805	Economy	4400.00
0005432799750	14805	Economy	4400.00
0005432799739	14805	Economy	4400.00
0005432799735	14805	Economy	4400.00
0005432799756	14805	Economy	4400.00
0005432799734	14805	Economy	4400.00
0005432799757	14805	Economy	4400.00
0005432799746	14805	Economy	4400.00
0005432799748	14805	Economy	4400.00
0005434408461	7079	Business	49100.00
0005434408448	7079	Business	49100.00
0005434408487	7079	Business	49100.00
0005434408451	7079	Business	49100.00
0005435293295	7079	Business	49100.00
0005434299820	7079	Business	49100.00
0005434408474	7079	Business	49100.00
0005435293220	7079	Business	49100.00
0005435293311	7079	Business	49100.00
0005434299817	7079	Business	49100.00
0005434299835	7079	Business	49100.00
0005435311086	7079	Business	49100.00
0005434408500	7079	Economy	16400.00
0005434408505	7079	Economy	16400.00
0005435293246	7079	Economy	16400.00
0005434299819	7079	Economy	16400.00
0005435293290	7079	Economy	16400.00
0005434408447	7079	Economy	16400.00
0005432154016	7079	Economy	16400.00
0005434299836	7079	Economy	16400.00
0005434299821	7079	Economy	16400.00
0005435311063	7079	Economy	16400.00
0005432154015	7079	Economy	16400.00
0005435293324	7079	Economy	16400.00
0005434408510	7079	Economy	16400.00
0005435293280	7079	Economy	16400.00
0005434408501	7079	Economy	16400.00
0005434408497	7079	Economy	16400.00
0005434299832	7079	Economy	16400.00
0005434408507	7079	Economy	16400.00
0005435311076	7079	Economy	16400.00
0005434299825	7079	Economy	16400.00
0005434299823	7079	Economy	16400.00
0005435293289	7079	Economy	16400.00
0005434408511	7079	Economy	16400.00
0005434408454	7079	Economy	16400.00
0005435293260	7079	Economy	16400.00
0005434299833	7079	Economy	16400.00
0005434408458	7079	Economy	16400.00
0005434299818	7079	Economy	16400.00
0005434408490	7079	Economy	16400.00
0005434408491	7079	Economy	16400.00
0005432154018	7079	Economy	16400.00
0005434408463	7079	Economy	16400.00
0005434299829	7079	Economy	16400.00
0005434408508	7079	Economy	16400.00
0005434408455	7079	Economy	16400.00
0005434408480	7079	Economy	16400.00
0005434408472	7079	Economy	16400.00
0005434299816	7079	Economy	16400.00
0005435293218	7079	Economy	16400.00
0005432154014	7079	Economy	16400.00
0005435311065	7079	Economy	18000.00
0005435293271	7079	Economy	18000.00
0005434299830	7079	Economy	18000.00
0005434299834	7079	Economy	18000.00
0005434408482	7079	Economy	18000.00
0005434408469	7079	Economy	18000.00
0005432108280	7079	Economy	16400.00
0005434408450	7079	Economy	16400.00
0005434408496	7079	Economy	16400.00
0005435293288	7079	Economy	16400.00
0005435293272	7079	Economy	16400.00
0005435293273	7079	Economy	16400.00
0005435293312	7079	Economy	16400.00
0005434408492	7079	Economy	16400.00
0005435311075	7079	Economy	16400.00
0005434408509	7079	Economy	16400.00
0005432154019	7079	Economy	16400.00
0005434408481	7079	Economy	16400.00
0005434408453	7079	Economy	16400.00
0005435311062	7079	Economy	16400.00
0005434408462	7079	Economy	16400.00
0005434408473	7079	Economy	16400.00
0005434408485	7079	Economy	16400.00
0005434299822	7079	Economy	16400.00
0005434408465	7079	Economy	16400.00
0005434408471	7079	Economy	16400.00
0005434408478	7079	Economy	16400.00
0005434408449	7079	Economy	16400.00
0005432154017	7079	Economy	16400.00
0005434408459	7079	Economy	16400.00
0005435293278	7079	Economy	16400.00
0005435293314	7079	Economy	16400.00
0005435293219	7079	Economy	16400.00
0005434408503	7079	Economy	16400.00
0005434408489	7079	Economy	16400.00
0005434299815	7079	Economy	16400.00
0005434299831	7079	Economy	16400.00
0005434299827	7079	Economy	16400.00
0005434408470	7079	Economy	16400.00
0005434408484	7079	Economy	16400.00
0005434408464	7079	Economy	16400.00
0005432108279	7079	Economy	16400.00
0005435293279	7079	Economy	16400.00
0005434408456	7079	Economy	16400.00
0005434408483	7079	Economy	16400.00
0005435293286	7079	Economy	16400.00
0005435293323	7079	Economy	16400.00
0005435293261	7079	Economy	16400.00
0005434408479	7079	Economy	16400.00
0005432108278	7079	Economy	16400.00
0005434408466	7079	Economy	16400.00
0005434408494	7079	Economy	16400.00
0005434408506	7079	Economy	16400.00
0005435293270	7079	Economy	16400.00
0005434408504	7079	Economy	16400.00
0005434408477	7079	Economy	16400.00
0005434299828	7079	Economy	16400.00
0005432154020	7079	Economy	16400.00
0005434408452	7079	Economy	16400.00
0005434408460	7079	Economy	16400.00
0005434299826	7079	Economy	16400.00
0005434408457	7079	Economy	16400.00
0005435293317	7079	Economy	16400.00
0005434408467	7079	Economy	16400.00
0005434408468	7079	Economy	16400.00
0005434408488	7079	Economy	16400.00
0005434408475	7079	Economy	16400.00
0005434408495	7079	Economy	16400.00
0005434299824	7079	Economy	16400.00
0005435293221	7079	Economy	16400.00
0005434408499	7079	Economy	16400.00
0005434408476	7079	Economy	16400.00
0005434408502	7079	Economy	16400.00
0005434408486	7079	Economy	16400.00
0005434299837	7079	Economy	16400.00
0005434408493	7079	Economy	16400.00
0005434408498	7079	Economy	16400.00
0005435293310	7079	Economy	16400.00
0005434299659	26901	Business	49100.00
0005434407814	26901	Business	49100.00
0005434407925	26901	Business	49100.00
0005434407989	26901	Business	49100.00
0005434407977	26901	Business	49100.00
0005434407798	26901	Business	49100.00
0005435311182	26901	Business	49100.00
0005435311193	26901	Business	49100.00
0005434407751	26901	Business	49100.00
0005434407743	26901	Business	49100.00
0005434407832	26901	Business	49100.00
0005434408037	26901	Business	49100.00
0005434407839	26901	Economy	16400.00
0005435311189	26901	Economy	16400.00
0005434407991	26901	Economy	16400.00
0005434407964	26901	Economy	16400.00
0005435311197	26901	Economy	16400.00
0005434408088	26901	Economy	16400.00
0005434299623	26901	Economy	16400.00
0005435293396	26901	Economy	16400.00
0005432058422	26901	Economy	16400.00
0005435311180	26901	Economy	16400.00
0005434407976	26901	Economy	16400.00
0005434408145	26901	Economy	16400.00
0005434299725	26901	Economy	16400.00
0005434299773	26901	Economy	16400.00
0005435311188	26901	Economy	16400.00
0005434299697	26901	Economy	16400.00
0005435311184	26901	Economy	16400.00
0005435311179	26901	Economy	16400.00
0005434408107	26901	Economy	16400.00
0005434408038	26901	Economy	16400.00
0005435293397	26901	Economy	16400.00
0005435311178	26901	Economy	16400.00
0005435293388	26901	Economy	16400.00
0005434407722	26901	Economy	16400.00
0005432058425	26901	Economy	16400.00
0005434408083	26901	Economy	16400.00
0005435311196	26901	Economy	16400.00
0005434299710	26901	Economy	16400.00
0005434407681	26901	Economy	16400.00
0005434299658	26901	Economy	16400.00
0005434407797	26901	Economy	16400.00
0005434407986	26901	Economy	16400.00
0005434299613	26901	Economy	16400.00
0005435293394	26901	Economy	16400.00
0005434407990	26901	Economy	16400.00
0005434408108	26901	Economy	16400.00
0005435311186	26901	Economy	16400.00
0005435311194	26901	Economy	18000.00
0005434408119	26901	Economy	18000.00
0005434299631	26901	Economy	18000.00
0005435293391	26901	Economy	18000.00
0005432058423	26901	Economy	18000.00
0005434407727	26901	Economy	18000.00
0005435293390	26901	Economy	16400.00
0005434408115	26901	Economy	16400.00
0005434408054	26901	Economy	16400.00
0005434407875	26901	Economy	16400.00
0005432058421	26901	Economy	16400.00
0005434407749	26901	Economy	16400.00
0005432058424	26901	Economy	16400.00
0005434407910	26901	Economy	16400.00
0005434407987	26901	Economy	16400.00
0005435293399	26901	Economy	16400.00
0005435311200	26901	Economy	16400.00
0005434299647	26901	Economy	16400.00
0005434407742	26901	Economy	16400.00
0005434407676	26901	Economy	16400.00
0005435311191	26901	Economy	16400.00
0005434299738	26901	Economy	16400.00
0005434407965	26901	Economy	16400.00
0005435311199	26901	Economy	16400.00
0005434407851	26901	Economy	16400.00
0005434408052	26901	Economy	16400.00
0005434299660	26901	Economy	16400.00
0005435311190	26901	Economy	16400.00
0005434407826	26901	Economy	16400.00
0005434407917	26901	Economy	16400.00
0005434407868	26901	Economy	16400.00
0005435293389	26901	Economy	16400.00
0005435293400	26901	Economy	16400.00
0005434407767	26901	Economy	16400.00
0005434407680	26901	Economy	16400.00
0005434299772	26901	Economy	16400.00
0005435293392	26901	Economy	16400.00
0005435311183	26901	Economy	16400.00
0005434299592	26901	Economy	16400.00
0005435293398	26901	Economy	16400.00
0005434299695	26901	Economy	16400.00
0005434299593	26901	Economy	16400.00
0005434299694	26901	Economy	16400.00
0005434299737	26901	Economy	16400.00
0005434407950	26901	Economy	16400.00
0005434407744	26901	Economy	16400.00
0005434407897	26901	Economy	16400.00
0005435311185	26901	Economy	16400.00
0005434299666	26901	Economy	16400.00
0005434407820	26901	Economy	16400.00
0005434299628	26901	Economy	16400.00
0005434407481	26901	Economy	16400.00
0005434407852	26901	Economy	16400.00
0005434407876	26901	Economy	16400.00
0005435293395	26901	Economy	16400.00
0005434408091	26901	Economy	16400.00
0005434407853	26901	Economy	16400.00
0005434299633	26901	Economy	16400.00
0005434407970	26901	Economy	16400.00
0005434407840	26901	Economy	16400.00
0005434407693	26901	Economy	16400.00
0005434407940	26901	Economy	16400.00
0005435293393	26901	Economy	16400.00
0005434407833	26901	Economy	16400.00
0005434407909	26901	Economy	16400.00
0005435311192	26901	Economy	16400.00
0005435311181	26901	Economy	16400.00
0005434299632	26901	Economy	16400.00
0005435311202	26901	Economy	16400.00
0005435311187	26901	Economy	16400.00
0005434407824	26901	Economy	16400.00
0005434408084	26901	Economy	16400.00
0005434299663	26901	Economy	16400.00
0005435311201	26901	Economy	16400.00
0005435311198	26901	Economy	16400.00
0005435311195	26901	Economy	16400.00
0005432604814	6440	Economy	16500.00
0005432604815	6440	Economy	16500.00
0005432604808	6440	Economy	16500.00
0005434512159	6440	Economy	16500.00
0005432604800	6440	Economy	15000.00
0005432604796	6440	Economy	15000.00
0005432604801	6440	Economy	15000.00
0005432604791	6440	Economy	15000.00
0005432604794	6440	Economy	15000.00
0005432604804	6440	Economy	15000.00
0005432604810	6440	Economy	15000.00
0005432604787	6440	Economy	15000.00
0005434512162	6440	Economy	15000.00
0005432604786	6440	Economy	15000.00
0005432604795	6440	Economy	15000.00
0005432604812	6440	Economy	15000.00
0005432604792	6440	Economy	15000.00
0005432604798	6440	Economy	15000.00
0005432604780	6440	Economy	15000.00
0005432604809	6440	Economy	15000.00
0005434512158	6440	Economy	15000.00
0005432604779	6440	Economy	15000.00
0005432604782	6440	Economy	15000.00
0005432604797	6440	Economy	15000.00
0005432604789	6440	Economy	15000.00
0005432604802	6440	Economy	15000.00
0005432604817	6440	Economy	15000.00
0005432604784	6440	Economy	15000.00
0005432604783	6440	Economy	15000.00
0005432604811	6440	Economy	15000.00
0005432604813	6440	Economy	15000.00
0005432604805	6440	Economy	15000.00
0005432604793	6440	Economy	15000.00
0005432604806	6440	Economy	15000.00
0005432604788	6440	Economy	15000.00
0005432604799	6440	Economy	15000.00
0005432604785	6440	Economy	15000.00
0005432604781	6440	Economy	15000.00
0005432604807	6440	Economy	15000.00
0005434512161	6440	Economy	15000.00
0005434512160	6440	Economy	15000.00
0005432604790	6440	Economy	15000.00
0005432604816	6440	Economy	15000.00
0005432604803	6440	Economy	15000.00
0005432604387	21344	Economy	16500.00
0005434512113	21344	Economy	16500.00
0005432604467	21344	Economy	16500.00
0005434512140	21344	Economy	15000.00
0005432604279	21344	Economy	15000.00
0005432604533	21344	Economy	15000.00
0005432604466	21344	Economy	15000.00
0005434512119	21344	Economy	15000.00
0005432604474	21344	Economy	15000.00
0005432604628	21344	Economy	15000.00
0005432604349	21344	Economy	15000.00
0005434512127	21344	Economy	15000.00
0005432604145	21344	Economy	15000.00
0005432604388	21344	Economy	15000.00
0005434512134	21344	Economy	15000.00
0005435221065	21344	Economy	15000.00
0005434512129	21344	Economy	15000.00
0005434512117	21344	Economy	15000.00
0005432604532	21344	Economy	15000.00
0005432604429	21344	Economy	15000.00
0005432604365	21344	Economy	15000.00
0005432604352	21344	Economy	15000.00
0005432604514	21344	Economy	15000.00
0005432604465	21344	Economy	15000.00
0005434512118	21344	Economy	15000.00
0005432604182	21344	Economy	15000.00
0005432604562	21344	Economy	15000.00
0005432604563	21344	Economy	15000.00
0005432604355	21344	Economy	15000.00
0005435221064	21344	Economy	15000.00
0005432604475	21344	Economy	15000.00
0005432604459	21344	Economy	15000.00
0005432604526	21344	Economy	15000.00
0005432604366	21344	Economy	15000.00
0005434512128	21344	Economy	15000.00
0005434512112	21344	Economy	15000.00
0005432604354	21344	Economy	15000.00
0005432604529	21344	Economy	15000.00
0005432604353	21344	Economy	15000.00
0005434907227	14991	Business	18900.00
0005434907316	14991	Business	18900.00
0005433251838	14991	Business	18900.00
0005433251824	14991	Business	18900.00
0005434907379	14991	Business	18900.00
0005433251841	14991	Business	18900.00
0005433251831	14991	Business	18900.00
0005433251835	14991	Business	18900.00
0005434907303	14991	Business	18900.00
0005434907294	14991	Business	18900.00
0005434907387	14991	Business	18900.00
0005434907298	14991	Economy	6300.00
0005434907175	14991	Economy	6300.00
0005434907401	14991	Economy	6300.00
0005433251843	14991	Economy	6300.00
0005434907371	14991	Economy	6300.00
0005434907442	14991	Economy	6300.00
0005433251826	14991	Economy	6300.00
0005433251817	14991	Economy	6300.00
0005434907386	14991	Economy	6300.00
0005433251825	14991	Economy	6900.00
0005433251829	14991	Economy	6900.00
0005434907334	14991	Economy	6900.00
0005433251816	14991	Economy	6900.00
0005434907402	14991	Economy	6900.00
0005433251818	14991	Economy	6300.00
0005434907412	14991	Economy	6300.00
0005434907266	14991	Economy	6300.00
0005433251813	14991	Economy	6300.00
0005434907248	14991	Economy	6300.00
0005434907444	14991	Economy	6300.00
0005434907318	14991	Economy	6300.00
0005434907174	14991	Economy	6300.00
0005433251823	14991	Economy	6300.00
0005434907391	14991	Economy	6300.00
0005434907373	14991	Economy	6300.00
0005434907244	14991	Economy	6300.00
0005434907342	14991	Economy	6300.00
0005434907434	14991	Economy	6300.00
0005434907395	14991	Economy	6300.00
0005434907322	14991	Economy	6300.00
0005434907274	14991	Economy	6300.00
0005433251836	14991	Economy	6300.00
0005433251812	14991	Economy	6300.00
0005434907425	14991	Economy	6300.00
0005434907374	14991	Economy	6300.00
0005433251833	14991	Economy	6300.00
0005434907249	14991	Economy	6300.00
0005433251827	14991	Economy	6300.00
0005434907176	14991	Economy	6300.00
0005433251830	14991	Economy	6300.00
0005434907370	14991	Economy	6300.00
0005433251832	14991	Economy	6300.00
0005433251837	14991	Economy	6300.00
0005434907382	14991	Economy	6300.00
0005434907228	14991	Economy	6300.00
0005433251819	14991	Economy	6300.00
0005433251814	14991	Economy	6300.00
0005434907268	14991	Economy	6300.00
0005433251834	14991	Economy	6300.00
0005433251828	14991	Economy	6300.00
0005434907381	14991	Economy	6300.00
0005434907265	14991	Economy	6300.00
0005434907433	14991	Economy	6300.00
0005434907349	14991	Economy	6300.00
0005434907366	14991	Economy	6300.00
0005434907429	14991	Economy	6300.00
0005434907224	14991	Economy	6300.00
0005434907390	14991	Economy	6300.00
0005433251820	14991	Economy	6300.00
0005433251822	14991	Economy	6300.00
0005434907245	14991	Economy	6300.00
0005434907285	14991	Economy	6300.00
0005434907424	14991	Economy	6300.00
0005434907408	14991	Economy	6300.00
0005433251839	14991	Economy	6300.00
0005434907380	14991	Economy	6300.00
0005434907345	14991	Economy	6300.00
0005434907314	14991	Economy	6300.00
0005433251821	14991	Economy	6300.00
0005434907413	14991	Economy	6300.00
0005434907301	14991	Economy	6300.00
0005434907445	14991	Economy	6300.00
0005434907302	14991	Economy	6300.00
0005434907293	14991	Economy	6300.00
0005433251842	14991	Economy	6300.00
0005434907343	14991	Economy	6300.00
0005433251815	14991	Economy	6300.00
0005433251840	14991	Economy	6300.00
0005434907217	14991	Economy	6300.00
0005434907327	14991	Economy	6300.00
0005434907854	25825	Business	18900.00
0005434907806	25825	Business	18900.00
0005434907825	25825	Business	18900.00
0005434907855	25825	Business	18900.00
0005434907836	25825	Business	18900.00
0005434907838	25825	Business	18900.00
0005433251583	25825	Business	18900.00
0005434907824	25825	Business	18900.00
0005434907814	25825	Business	18900.00
0005434907833	25825	Business	18900.00
0005433251653	25825	Business	18900.00
0005434907826	25825	Economy	6300.00
0005433251712	25825	Economy	6300.00
0005433251490	25825	Economy	6300.00
0005434907857	25825	Economy	6300.00
0005433251521	25825	Economy	6300.00
0005433251649	25825	Economy	6300.00
0005433251631	25825	Economy	6300.00
0005434907811	25825	Economy	6300.00
0005433251520	25825	Economy	6300.00
0005434907803	25825	Economy	6900.00
0005434907812	25825	Economy	6900.00
0005433251621	25825	Economy	6900.00
0005434907809	25825	Economy	6900.00
0005434907819	25825	Economy	6900.00
0005434907845	25825	Economy	6300.00
0005434907804	25825	Economy	6300.00
0005433251546	25825	Economy	6300.00
0005433251597	25825	Economy	6300.00
0005434907820	25825	Economy	6300.00
0005433251451	25825	Economy	6300.00
0005434907830	25825	Economy	6300.00
0005433251609	25825	Economy	6300.00
0005434907815	25825	Economy	6300.00
0005433251543	25825	Economy	6300.00
0005434907843	25825	Economy	6300.00
0005433251721	25825	Economy	6300.00
0005434907851	25825	Economy	6300.00
0005434907853	25825	Economy	6300.00
0005434907818	25825	Economy	6300.00
0005434907835	25825	Economy	6300.00
0005434907834	25825	Economy	6300.00
0005433251552	25825	Economy	6300.00
0005434907822	25825	Economy	6300.00
0005434907802	25825	Economy	6300.00
0005434907850	25825	Economy	6300.00
0005434907847	25825	Economy	6300.00
0005433251651	25825	Economy	6300.00
0005433251499	25825	Economy	6300.00
0005433251509	25825	Economy	6300.00
0005434907848	25825	Economy	6300.00
0005433251519	25825	Economy	6300.00
0005434907839	25825	Economy	6300.00
0005434907841	25825	Economy	6300.00
0005434907805	25825	Economy	6300.00
0005434907832	25825	Economy	6300.00
0005434907828	25825	Economy	6300.00
0005434907852	25825	Economy	6300.00
0005434907842	25825	Economy	6300.00
0005434907827	25825	Economy	6300.00
0005434907849	25825	Economy	6300.00
0005434907840	25825	Economy	6300.00
0005434907816	25825	Economy	6300.00
0005434907856	25825	Economy	6300.00
0005434907808	25825	Economy	6300.00
0005433251601	25825	Economy	6300.00
0005434907813	25825	Economy	6300.00
0005434907823	25825	Economy	6300.00
0005434907829	25825	Economy	6300.00
0005433251650	25825	Economy	6300.00
0005433251425	25825	Economy	6300.00
0005434907844	25825	Economy	6300.00
0005434907831	25825	Economy	6300.00
0005434907801	25825	Economy	6300.00
0005434907846	25825	Economy	6300.00
0005434907810	25825	Economy	6300.00
0005433251713	25825	Economy	6300.00
0005434907807	25825	Economy	6300.00
0005433251533	25825	Economy	6300.00
0005433251610	25825	Economy	6300.00
0005433251652	25825	Economy	6300.00
0005434907821	25825	Economy	6300.00
0005434907817	25825	Economy	6300.00
0005434907837	25825	Economy	6300.00
0005432607606	22470	Economy	16400.00
0005432607607	22470	Economy	16400.00
0005432609763	22470	Economy	16400.00
0005432607601	22470	Economy	16400.00
0005432609771	22470	Economy	14900.00
0005432609773	22470	Economy	14900.00
0005432609760	22470	Economy	14900.00
0005432607605	22470	Economy	14900.00
0005432609774	22470	Economy	14900.00
0005432609766	22470	Economy	14900.00
0005432607597	22470	Economy	14900.00
0005432607603	22470	Economy	14900.00
0005432609769	22470	Economy	14900.00
0005432607596	22470	Economy	14900.00
0005432607599	22470	Economy	14900.00
0005432609767	22470	Economy	14900.00
0005432607609	22470	Economy	14900.00
0005432607595	22470	Economy	14900.00
0005432609770	22470	Economy	14900.00
0005432609765	22470	Economy	14900.00
0005432609768	22470	Economy	14900.00
0005432607602	22470	Economy	14900.00
0005432609764	22470	Economy	14900.00
0005435842327	22470	Economy	14900.00
0005432609775	22470	Economy	14900.00
0005432607594	22470	Economy	14900.00
0005432607600	22470	Economy	14900.00
0005432607608	22470	Economy	14900.00
0005432607598	22470	Economy	14900.00
0005432607611	22470	Economy	14900.00
0005432607610	22470	Economy	14900.00
0005435842328	22470	Economy	14900.00
0005432607604	22470	Economy	14900.00
0005432609772	22470	Economy	14900.00
0005432609762	22470	Economy	14900.00
0005432609761	22470	Economy	14900.00
0005432609725	31724	Economy	16400.00
0005432613867	31724	Economy	16400.00
0005432613848	31724	Economy	16400.00
0005432613872	31724	Economy	16400.00
0005432609734	31724	Economy	14900.00
0005432613858	31724	Economy	14900.00
0005432609724	31724	Economy	14900.00
0005432609719	31724	Economy	14900.00
0005432613864	31724	Economy	14900.00
0005432613862	31724	Economy	14900.00
0005432613863	31724	Economy	14900.00
0005432613873	31724	Economy	14900.00
0005432613870	31724	Economy	14900.00
0005432609723	31724	Economy	14900.00
0005432613877	31724	Economy	14900.00
0005435841102	31724	Economy	14900.00
0005432613861	31724	Economy	14900.00
0005432609702	31724	Economy	14900.00
0005432613859	31724	Economy	14900.00
0005432609718	31724	Economy	14900.00
0005432613878	31724	Economy	14900.00
0005432613874	31724	Economy	14900.00
0005432613876	31724	Economy	14900.00
0005432609739	31724	Economy	14900.00
0005432613845	31724	Economy	14900.00
0005432613871	31724	Economy	14900.00
0005432609732	31724	Economy	14900.00
0005432613846	31724	Economy	14900.00
0005432613865	31724	Economy	14900.00
0005432613860	31724	Economy	14900.00
0005432609733	31724	Economy	14900.00
0005432613866	31724	Economy	14900.00
0005432609744	31724	Economy	14900.00
0005432609745	31724	Economy	14900.00
0005432609731	31724	Economy	14900.00
0005432609746	31724	Economy	14900.00
0005432613869	31724	Economy	14900.00
0005435841103	31724	Economy	14900.00
0005432609729	31724	Economy	14900.00
0005432609722	31724	Economy	14900.00
0005433009144	14175	Business	52300.00
0005433009143	14175	Business	52300.00
0005433810545	14175	Business	52300.00
0005433810541	14175	Business	52300.00
0005433009130	14175	Business	52300.00
0005433009165	14175	Business	52300.00
0005433009147	14175	Economy	17400.00
0005433009138	14175	Economy	17400.00
0005433009135	14175	Economy	17400.00
0005433009124	14175	Economy	17400.00
0005433810547	14175	Economy	17400.00
0005433009162	14175	Economy	17400.00
0005433009136	14175	Economy	17400.00
0005433009131	14175	Economy	19200.00
0005433009166	14175	Economy	19200.00
0005433009142	14175	Economy	19200.00
0005433009152	14175	Economy	17400.00
0005433009161	14175	Economy	17400.00
0005433810544	14175	Economy	17400.00
0005433009126	14175	Economy	17400.00
0005433009129	14175	Economy	17400.00
0005433009132	14175	Economy	17400.00
0005433009156	14175	Economy	17400.00
0005433009155	14175	Economy	17400.00
0005433009164	14175	Economy	17400.00
0005433009167	14175	Economy	17400.00
0005433009157	14175	Economy	17400.00
0005433009137	14175	Economy	17400.00
0005433009139	14175	Economy	17400.00
0005433009153	14175	Economy	17400.00
0005433009149	14175	Economy	17400.00
0005433009145	14175	Economy	17400.00
0005433009128	14175	Economy	17400.00
0005433009127	14175	Economy	17400.00
0005433009146	14175	Economy	17400.00
0005433009163	14175	Economy	17400.00
0005433009134	14175	Economy	17400.00
0005433009160	14175	Economy	17400.00
0005433009151	14175	Economy	17400.00
0005433009159	14175	Economy	17400.00
0005433009150	14175	Economy	17400.00
0005433009148	14175	Economy	17400.00
0005433009140	14175	Economy	17400.00
0005433009154	14175	Economy	17400.00
0005433009133	14175	Economy	17400.00
0005433009125	14175	Economy	17400.00
0005433009158	14175	Economy	17400.00
0005433810543	14175	Economy	17400.00
0005433009141	14175	Economy	17400.00
0005433008852	22869	Business	52300.00
0005433008804	22869	Business	52300.00
0005433810585	22869	Business	52300.00
0005433008765	22869	Business	52300.00
0005433008763	22869	Business	52300.00
0005433008694	22869	Business	52300.00
0005433008840	22869	Business	52300.00
0005433008637	22869	Economy	17400.00
0005433008716	22869	Economy	17400.00
0005433008250	22869	Economy	17400.00
0005433008805	22869	Economy	17400.00
0005433008631	22869	Economy	19200.00
0005433008693	22869	Economy	17400.00
0005433008781	22869	Economy	17400.00
0005433008743	22869	Economy	17400.00
0005433008866	22869	Economy	17400.00
0005433008671	22869	Economy	17400.00
0005433008677	22869	Economy	17400.00
0005433008697	22869	Economy	17400.00
0005433008661	22869	Economy	17400.00
0005433008725	22869	Economy	17400.00
0005433008684	22869	Economy	17400.00
0005433008632	22869	Economy	17400.00
0005433008764	22869	Economy	17400.00
0005433008802	22869	Economy	17400.00
0005433008806	22869	Economy	17400.00
0005433008703	22869	Economy	17400.00
0005433008865	22869	Economy	17400.00
0005433008868	22869	Economy	17400.00
0005433008736	22869	Economy	17400.00
0005433008691	22869	Economy	17400.00
0005433008670	22869	Economy	17400.00
0005433008813	22869	Economy	17400.00
0005433008722	22869	Economy	17400.00
0005433810584	22869	Economy	17400.00
0005433008690	22869	Economy	17400.00
0005433810583	22869	Economy	17400.00
0005433008807	22869	Economy	17400.00
0005433008401	22869	Economy	17400.00
0005433008747	22869	Economy	17400.00
0005433008818	22869	Economy	17400.00
0005433008649	22869	Economy	17400.00
0005433008426	22869	Economy	17400.00
0005433008704	22869	Economy	17400.00
0005433008803	22869	Economy	17400.00
0005433008636	22869	Economy	17400.00
0005434925922	14924	Business	22900.00
0005434925867	14924	Business	22900.00
0005434925874	14924	Business	22900.00
0005434925859	14924	Business	22900.00
0005434925848	14924	Business	22900.00
0005434925947	14924	Business	22900.00
0005434925891	14924	Economy	7600.00
0005434925691	14924	Economy	7600.00
0005434925789	14924	Economy	7600.00
0005434925804	14924	Economy	7600.00
0005434925815	14924	Economy	7600.00
0005434925960	14924	Economy	7600.00
0005434925857	14924	Economy	8400.00
0005434925794	14924	Economy	8400.00
0005434925801	14924	Economy	8400.00
0005434925761	14924	Economy	7600.00
0005434925814	14924	Economy	7600.00
0005434925793	14924	Economy	7600.00
0005434925961	14924	Economy	7600.00
0005434925971	14924	Economy	7600.00
0005434925812	14924	Economy	7600.00
0005434925899	14924	Economy	7600.00
0005434925792	14924	Economy	7600.00
0005434925805	14924	Economy	7600.00
0005434925858	14924	Economy	7600.00
0005434925845	14924	Economy	7600.00
0005434925800	14924	Economy	7600.00
0005434925744	14924	Economy	7600.00
0005434925766	14924	Economy	7600.00
0005434925921	14924	Economy	7600.00
0005434925946	14924	Economy	7600.00
0005434925826	14924	Economy	7600.00
0005434925750	14924	Economy	7600.00
0005434925892	14924	Economy	7600.00
0005434925920	14924	Economy	7600.00
0005434925847	14924	Economy	7600.00
0005434925883	14924	Economy	7600.00
0005434926152	20520	Business	22900.00
0005434926150	20520	Business	22900.00
0005434926151	20520	Business	22900.00
0005434926140	20520	Economy	7600.00
0005434926160	20520	Economy	7600.00
0005434926154	20520	Economy	7600.00
0005434926139	20520	Economy	8400.00
0005434926153	20520	Economy	7600.00
0005434926146	20520	Economy	7600.00
0005434926149	20520	Economy	7600.00
0005434926144	20520	Economy	7600.00
0005434926155	20520	Economy	7600.00
0005434926138	20520	Economy	7600.00
0005434926156	20520	Economy	7600.00
0005434926145	20520	Economy	7600.00
0005434926158	20520	Economy	7600.00
0005434926164	20520	Economy	7600.00
0005434926147	20520	Economy	7600.00
0005434926163	20520	Economy	7600.00
0005434926141	20520	Economy	7600.00
0005434926165	20520	Economy	7600.00
0005434926162	20520	Economy	7600.00
0005434926148	20520	Economy	7600.00
0005434926143	20520	Economy	7600.00
0005434926157	20520	Economy	7600.00
0005434926142	20520	Economy	7600.00
0005434926137	20520	Economy	7600.00
0005434926136	20520	Economy	7600.00
0005434926161	20520	Economy	7600.00
0005434926159	20520	Economy	7600.00
0005435488094	15809	Economy	8900.00
0005435488074	15809	Economy	8100.00
0005435999265	15809	Economy	8100.00
0005435488086	15809	Economy	8100.00
0005435488077	15809	Economy	8100.00
0005435999316	15809	Economy	8100.00
0005435488093	15809	Economy	8100.00
0005435999280	15809	Economy	8100.00
0005435488080	15809	Economy	8100.00
0005435488084	15809	Economy	8100.00
0005435488092	15809	Economy	8100.00
0005435488089	15809	Economy	8100.00
0005435488078	15809	Economy	8100.00
0005435488083	15809	Economy	8100.00
0005435999252	15809	Economy	8100.00
0005435488088	15809	Economy	8100.00
0005435488081	15809	Economy	8100.00
0005435999296	15809	Economy	8100.00
0005435488087	15809	Economy	8100.00
0005435488075	15809	Economy	8100.00
0005435999295	15809	Economy	8100.00
0005435488076	15809	Economy	8100.00
0005435999300	15809	Economy	8100.00
0005435999321	15809	Economy	8100.00
0005435488090	15809	Economy	8100.00
0005435999268	15809	Economy	8100.00
0005435999294	15809	Economy	8100.00
0005435488079	15809	Economy	8100.00
0005435488082	15809	Economy	8100.00
0005435999293	15809	Economy	8100.00
0005435488085	15809	Economy	8100.00
0005435488095	15809	Economy	8100.00
0005435999288	15809	Economy	8100.00
0005435488091	15809	Economy	8100.00
0005435999320	15809	Economy	8100.00
0005435487814	19668	Economy	8900.00
0005435999430	19668	Economy	8900.00
0005435999426	19668	Economy	8900.00
0005435487860	19668	Economy	8900.00
0005435487862	19668	Economy	8100.00
0005435487911	19668	Economy	8100.00
0005435999429	19668	Economy	8100.00
0005435999433	19668	Economy	8100.00
0005435487845	19668	Economy	8100.00
0005435487785	19668	Economy	8100.00
0005435999434	19668	Economy	8100.00
0005435487889	19668	Economy	8100.00
0005435487861	19668	Economy	8100.00
0005435487924	19668	Economy	8100.00
0005435487813	19668	Economy	8100.00
0005435999435	19668	Economy	8100.00
0005435999428	19668	Economy	8100.00
0005435487834	19668	Economy	8100.00
0005435487870	19668	Economy	8100.00
0005435487865	19668	Economy	8100.00
0005435999425	19668	Economy	8100.00
0005435487798	19668	Economy	8100.00
0005435999431	19668	Economy	8100.00
0005435487828	19668	Economy	8100.00
0005435487869	19668	Economy	8100.00
0005435487831	19668	Economy	8100.00
0005435487784	19668	Economy	8100.00
0005435487830	19668	Economy	8100.00
0005435487863	19668	Economy	8100.00
0005435487797	19668	Economy	8100.00
0005435487910	19668	Economy	8100.00
0005435999432	19668	Economy	8100.00
0005435487923	19668	Economy	8100.00
0005435487904	19668	Economy	8100.00
0005435487823	19668	Economy	8100.00
0005435487731	19668	Economy	8100.00
0005435487832	19668	Economy	8100.00
0005435487791	19668	Economy	8100.00
0005435999427	19668	Economy	8100.00
0005435999424	19668	Economy	8100.00
0005435472795	5983	Business	199300.00
0005435839770	5983	Business	199300.00
0005432660843	5983	Business	199300.00
0005432142290	5983	Business	199300.00
0005435839779	5983	Business	199300.00
0005435472844	5983	Business	199300.00
0005435472881	5983	Business	199300.00
0005435472845	5983	Business	199300.00
0005435472751	5983	Economy	66400.00
0005435472847	5983	Economy	66400.00
0005435472840	5983	Economy	66400.00
0005435472820	5983	Economy	66400.00
0005432660842	5983	Economy	66400.00
0005435839771	5983	Economy	66400.00
0005435617234	5983	Economy	66400.00
0005432659731	5983	Economy	73100.00
0005435839787	5983	Economy	66400.00
0005435839780	5983	Economy	66400.00
0005435839769	5983	Economy	66400.00
0005435472849	5983	Economy	66400.00
0005435839782	5983	Economy	66400.00
0005435839773	5983	Economy	66400.00
0005435839767	5983	Economy	66400.00
0005432142288	5983	Economy	66400.00
0005432658616	5983	Economy	66400.00
0005435472834	5983	Economy	66400.00
0005432142287	5983	Economy	66400.00
0005435839778	5983	Economy	66400.00
0005435839777	5983	Economy	66400.00
0005435839785	5983	Economy	66400.00
0005435839776	5983	Economy	66400.00
0005432142286	5983	Economy	66400.00
0005435472838	5983	Economy	66400.00
0005435472841	5983	Economy	66400.00
0005435839765	5983	Economy	66400.00
0005435839774	5983	Economy	66400.00
0005435839768	5983	Economy	66400.00
0005435839784	5983	Economy	66400.00
0005435472880	5983	Economy	66400.00
0005432658617	5983	Economy	66400.00
0005435472839	5983	Economy	66400.00
0005435839766	5983	Economy	66400.00
0005435839775	5983	Economy	66400.00
0005435472794	5983	Economy	66400.00
0005435839772	5983	Economy	66400.00
0005432142289	5983	Economy	66400.00
0005432659732	5983	Economy	66400.00
0005435839783	5983	Economy	66400.00
0005435839781	5983	Economy	66400.00
0005435839786	5983	Economy	66400.00
0005435839791	5983	Economy	66400.00
0005435839789	5983	Economy	66400.00
0005435839788	5983	Economy	66400.00
0005435839790	5983	Economy	66400.00
0005435472991	18052	Business	199300.00
0005435472998	18052	Business	199300.00
0005435472993	18052	Business	199300.00
0005435839442	18052	Business	199300.00
0005435839552	18052	Business	199300.00
0005435472994	18052	Business	199300.00
0005435839498	18052	Business	199300.00
0005435839422	18052	Business	199300.00
0005435839637	18052	Business	199300.00
0005435839612	18052	Economy	66400.00
0005435839509	18052	Economy	66400.00
0005435472990	18052	Economy	66400.00
0005432537083	18052	Economy	66400.00
0005435473000	18052	Economy	66400.00
0005435839595	18052	Economy	66400.00
0005435473001	18052	Economy	66400.00
0005435839574	18052	Economy	66400.00
0005432660816	18052	Economy	73100.00
0005435839455	18052	Economy	73100.00
0005435839609	18052	Economy	66400.00
0005435839510	18052	Economy	66400.00
0005435839508	18052	Economy	66400.00
0005435839479	18052	Economy	66400.00
0005432664131	18052	Economy	66400.00
0005435472987	18052	Economy	66400.00
0005435839448	18052	Economy	66400.00
0005435839477	18052	Economy	66400.00
0005435839388	18052	Economy	66400.00
0005435839478	18052	Economy	66400.00
0005435839395	18052	Economy	66400.00
0005435472986	18052	Economy	66400.00
0005435839505	18052	Economy	66400.00
0005432660815	18052	Economy	66400.00
0005435839502	18052	Economy	66400.00
0005435839501	18052	Economy	66400.00
0005435472995	18052	Economy	66400.00
0005435839497	18052	Economy	66400.00
0005435839393	18052	Economy	66400.00
0005435839394	18052	Economy	66400.00
0005435839556	18052	Economy	66400.00
0005432660808	18052	Economy	66400.00
0005435839644	18052	Economy	66400.00
0005435472992	18052	Economy	66400.00
0005432660812	18052	Economy	66400.00
0005435839564	18052	Economy	66400.00
0005435839459	18052	Economy	66400.00
0005435839565	18052	Economy	66400.00
0005435839476	18052	Economy	66400.00
0005432537084	18052	Economy	66400.00
0005435839643	18052	Economy	66400.00
0005435839557	18052	Economy	66400.00
0005435839575	18052	Economy	66400.00
0005435839443	18052	Economy	66400.00
0005435839636	18052	Economy	66400.00
0005435839464	18052	Economy	66400.00
0005435839555	18052	Economy	66400.00
0005435472988	18052	Economy	66400.00
0005435472989	18052	Economy	66400.00
0005435839389	18052	Economy	66400.00
0005435472985	18052	Economy	66400.00
0005435839551	18052	Economy	66400.00
0005435472997	18052	Economy	66400.00
0005435472996	18052	Economy	66400.00
0005435472999	18052	Economy	66400.00
0005433463924	17264	Business	146400.00
0005433463923	17264	Business	146400.00
0005433462761	17264	Business	146400.00
0005433462762	17264	Economy	48800.00
0005433462769	17264	Economy	48800.00
0005433462764	17264	Economy	48800.00
0005433463921	17264	Economy	48800.00
0005433463919	17264	Economy	48800.00
0005433462768	17264	Economy	48800.00
0005433462758	17264	Economy	48800.00
0005433463918	17264	Economy	48800.00
0005433463914	17264	Economy	48800.00
0005433463922	17264	Economy	48800.00
0005433463925	17264	Economy	48800.00
0005433462765	17264	Economy	48800.00
0005433463917	17264	Economy	48800.00
0005433462759	17264	Economy	48800.00
0005433462771	17264	Economy	48800.00
0005433463911	17264	Economy	48800.00
0005433463916	17264	Economy	48800.00
0005433462763	17264	Economy	53700.00
0005433462767	17264	Economy	48800.00
0005433462766	17264	Economy	48800.00
0005433463912	17264	Economy	48800.00
0005433462757	17264	Economy	48800.00
0005433462760	17264	Economy	48800.00
0005433463920	17264	Economy	48800.00
0005433463913	17264	Economy	48800.00
0005433462770	17264	Economy	48800.00
0005433463915	17264	Economy	48800.00
0005435104011	23059	Business	15700.00
0005433285395	23059	Business	15700.00
0005433285287	23059	Business	15700.00
0005433285414	23059	Economy	5200.00
0005433285559	23059	Economy	5200.00
0005433285212	23059	Economy	5200.00
0005433285424	23059	Economy	5200.00
0005433285360	23059	Economy	5200.00
0005433285359	23059	Economy	5200.00
0005433285434	23059	Economy	5200.00
0005433285333	23059	Economy	5200.00
0005433285402	23059	Economy	5200.00
0005433285422	23059	Economy	5700.00
0005433285372	23059	Economy	5700.00
0005433285425	23059	Economy	5200.00
0005433285303	23059	Economy	5200.00
0005433285448	23059	Economy	5200.00
0005433285365	23059	Economy	5200.00
0005435104013	23059	Economy	5200.00
0005433285392	23059	Economy	5200.00
0005433285469	23059	Economy	5200.00
0005433285426	23059	Economy	5200.00
0005433285288	23059	Economy	5200.00
0005433285213	23059	Economy	5200.00
0005433285439	23059	Economy	5200.00
0005433285332	23059	Economy	5200.00
0005433285354	23059	Economy	5200.00
0005433285334	23059	Economy	5200.00
0005433285438	23059	Economy	5200.00
0005433285506	23059	Economy	5200.00
0005433285335	23059	Economy	5200.00
0005433285447	23059	Economy	5200.00
0005433285353	23059	Economy	5200.00
0005433285417	23059	Economy	5200.00
0005433285338	23059	Economy	5200.00
0005433285322	23059	Economy	5200.00
0005435104010	23059	Economy	5200.00
0005433285452	23059	Economy	5200.00
0005435104012	23059	Economy	5200.00
0005433285394	23059	Economy	5200.00
0005433285510	23059	Economy	5200.00
0005433285423	23059	Economy	5200.00
0005433285672	32074	Business	15700.00
0005435103911	32074	Economy	5200.00
0005433285675	32074	Economy	5200.00
0005433285665	32074	Economy	5200.00
0005433285668	32074	Economy	5200.00
0005435103939	32074	Economy	5200.00
0005433285660	32074	Economy	5200.00
0005433285667	32074	Economy	5200.00
0005433285651	32074	Economy	5200.00
0005433285649	32074	Economy	5200.00
0005433285662	32074	Economy	5200.00
0005435103933	32074	Economy	5200.00
0005433285671	32074	Economy	5200.00
0005433285653	32074	Economy	5200.00
0005433285647	32074	Economy	5200.00
0005433285648	32074	Economy	5200.00
0005433285669	32074	Economy	5200.00
0005433285658	32074	Economy	5700.00
0005433285650	32074	Economy	5200.00
0005433285652	32074	Economy	5200.00
0005435103940	32074	Economy	5200.00
0005433285673	32074	Economy	5200.00
0005433285655	32074	Economy	5200.00
0005433285657	32074	Economy	5200.00
0005435103937	32074	Economy	5200.00
0005433285666	32074	Economy	5200.00
0005433285646	32074	Economy	5200.00
0005433285664	32074	Economy	5200.00
0005435103938	32074	Economy	5200.00
0005433285661	32074	Economy	5200.00
0005433285659	32074	Economy	5200.00
0005433285663	32074	Economy	5200.00
0005433285654	32074	Economy	5200.00
0005433285674	32074	Economy	5200.00
0005435103912	32074	Economy	5200.00
0005433285670	32074	Economy	5200.00
0005433285656	32074	Economy	5200.00
0005432528270	30624	Business	42100.00
0005435214351	30624	Business	42100.00
0005432528157	30624	Business	42100.00
0005434067398	30624	Business	42100.00
0005432528281	30624	Business	42100.00
0005432528735	30624	Business	42100.00
0005432528054	30624	Business	42100.00
0005432527798	30624	Business	42100.00
0005434067718	30624	Business	42100.00
0005432211590	30624	Business	42100.00
0005432533307	30624	Business	42100.00
0005432528434	30624	Business	42100.00
0005434067576	30624	Business	42100.00
0005432535859	30624	Business	42100.00
0005435214393	30624	Business	42100.00
0005432528549	30624	Business	42100.00
0005435214382	30624	Business	42100.00
0005435214366	30624	Business	42100.00
0005435214358	30624	Business	42100.00
0005435725660	30624	Business	42100.00
0005434067807	30624	Business	42100.00
0005432528708	30624	Business	42100.00
0005434067719	30624	Business	42100.00
0005432528533	30624	Comfort	23900.00
0005435725663	30624	Comfort	23900.00
0005432528906	30624	Comfort	23900.00
0005434067818	30624	Comfort	23900.00
0005434067822	30624	Comfort	23900.00
0005434067784	30624	Comfort	23900.00
0005434067943	30624	Comfort	23900.00
0005435214406	30624	Comfort	23900.00
0005434067712	30624	Comfort	23900.00
0005434068134	30624	Comfort	23900.00
0005435214362	30624	Comfort	23900.00
0005434068006	30624	Comfort	23900.00
0005432528834	30624	Comfort	23900.00
0005435214405	30624	Comfort	23900.00
0005434067802	30624	Comfort	23900.00
0005432528837	30624	Comfort	23900.00
0005432529161	30624	Comfort	23900.00
0005434067572	30624	Comfort	23900.00
0005434067711	30624	Comfort	23900.00
0005432528911	30624	Comfort	23900.00
0005432528210	30624	Comfort	23900.00
0005434067832	30624	Comfort	23900.00
0005432159912	30624	Comfort	23900.00
0005432528747	30624	Comfort	23900.00
0005432528172	30624	Comfort	23900.00
0005434067651	30624	Comfort	23900.00
0005435214355	30624	Comfort	23900.00
0005435214408	30624	Comfort	23900.00
0005434067340	30624	Comfort	23900.00
0005432528445	30624	Comfort	23900.00
0005435214364	30624	Comfort	23900.00
0005434067664	30624	Comfort	23900.00
0005435214403	30624	Comfort	23900.00
0005432528259	30624	Comfort	23900.00
0005435214391	30624	Economy	14000.00
0005432528280	30624	Economy	14000.00
0005432211592	30624	Economy	14000.00
0005432528963	30624	Economy	14000.00
0005434067402	30624	Economy	14000.00
0005434067760	30624	Economy	14000.00
0005435214359	30624	Economy	14000.00
0005432528148	30624	Economy	14000.00
0005432528687	30624	Economy	14000.00
0005435214371	30624	Economy	14000.00
0005432528534	30624	Economy	14000.00
0005434067801	30624	Economy	14000.00
0005434067578	30624	Economy	14000.00
0005432528575	30624	Economy	14000.00
0005432528332	30624	Economy	14000.00
0005432528321	30624	Economy	14000.00
0005435214344	30624	Economy	14000.00
0005432528592	30624	Economy	14000.00
0005432535869	30624	Economy	14000.00
0005435214390	30624	Economy	14000.00
0005435214363	30624	Economy	14000.00
0005435214348	30624	Economy	14000.00
0005432528309	30624	Economy	14000.00
0005435214378	30624	Economy	14000.00
0005432528690	30624	Economy	14000.00
0005432528104	30624	Economy	14000.00
0005435214376	30624	Economy	14000.00
0005434067642	30624	Economy	14000.00
0005434067773	30624	Economy	14000.00
0005434067904	30624	Economy	14000.00
0005432528204	30624	Economy	14000.00
0005434067854	30624	Economy	14000.00
0005432528206	30624	Economy	14000.00
0005432529050	30624	Economy	14000.00
0005432528144	30624	Economy	14000.00
0005432528370	30624	Economy	14000.00
0005432535841	30624	Economy	14000.00
0005435214407	30624	Economy	14000.00
0005432528047	30624	Economy	14000.00
0005432211594	30624	Economy	14000.00
0005432528127	30624	Economy	14000.00
0005432529061	30624	Economy	14000.00
0005432528509	30624	Economy	14000.00
0005434067831	30624	Economy	14000.00
0005435214372	30624	Economy	14000.00
0005434067835	30624	Economy	14000.00
0005434067761	30624	Economy	14000.00
0005432528344	30624	Economy	14000.00
0005432528369	30624	Economy	14000.00
0005432528734	30624	Economy	14000.00
0005435214345	30624	Economy	14000.00
0005432528143	30624	Economy	14000.00
0005435214341	30624	Economy	14000.00
0005435214392	30624	Economy	14000.00
0005434067780	30624	Economy	14000.00
0005435214377	30624	Economy	15400.00
0005435725664	30624	Economy	15400.00
0005432528079	30624	Economy	14000.00
0005432528809	30624	Economy	14000.00
0005432528308	30624	Economy	15400.00
0005432528320	30624	Economy	15400.00
0005432528962	30624	Economy	14000.00
0005432159913	30624	Economy	14000.00
0005435214384	30624	Economy	14000.00
0005432528686	30624	Economy	14000.00
0005435214389	30624	Economy	14000.00
0005432211591	30624	Economy	14000.00
0005432528145	30624	Economy	14000.00
0005432528435	30624	Economy	14000.00
0005434067821	30624	Economy	14000.00
0005433656712	30624	Economy	14000.00
0005434067772	30624	Economy	14000.00
0005432528448	30624	Economy	14000.00
0005432527721	30624	Economy	14000.00
0005435214369	30624	Economy	14000.00
0005435214360	30624	Economy	14000.00
0005432528105	30624	Economy	14000.00
0005434067662	30624	Economy	14000.00
0005435214373	30624	Economy	14000.00
0005435631005	30624	Economy	14000.00
0005432428951	30624	Economy	14000.00
0005435214342	30624	Economy	14000.00
0005434067861	30624	Economy	14000.00
0005432528907	30624	Economy	14000.00
0005432528422	30624	Economy	14000.00
0005432528393	30624	Economy	14000.00
0005434067882	30624	Economy	14000.00
0005432535847	30624	Economy	14000.00
0005432528249	30624	Economy	14000.00
0005432528806	30624	Economy	14000.00
0005434067771	30624	Economy	14000.00
0005435214398	30624	Economy	14000.00
0005432211596	30624	Economy	14000.00
0005432528848	30624	Economy	14000.00
0005434067862	30624	Economy	14000.00
0005435214380	30624	Economy	14000.00
0005435631006	30624	Economy	14000.00
0005434067803	30624	Economy	14000.00
0005432528519	30624	Economy	14000.00
0005434067667	30624	Economy	14000.00
0005432527953	30624	Economy	14000.00
0005432528000	30624	Economy	14000.00
0005433656713	30624	Economy	14000.00
0005434068005	30624	Economy	14000.00
0005432528808	30624	Economy	14000.00
0005434067702	30624	Economy	14000.00
0005435214387	30624	Economy	14000.00
0005435214402	30624	Economy	14000.00
0005434067630	30624	Economy	14000.00
0005434067683	30624	Economy	14000.00
0005432528607	30624	Economy	14000.00
0005432528586	30624	Economy	14000.00
0005435214396	30624	Economy	14000.00
0005435214365	30624	Economy	14000.00
0005432533306	30624	Economy	14000.00
0005434068007	30624	Economy	14000.00
0005435725662	30624	Economy	14000.00
0005435214404	30624	Economy	14000.00
0005432528518	30624	Economy	14000.00
0005435214395	30624	Economy	14000.00
0005432528392	30624	Economy	14000.00
0005435214349	30624	Economy	14000.00
0005432528215	30624	Economy	14000.00
0005434067826	30624	Economy	14000.00
0005432528685	30624	Economy	14000.00
0005434067894	30624	Economy	14000.00
0005432529045	30624	Economy	14000.00
0005434067777	30624	Economy	14000.00
0005432528085	30624	Economy	14000.00
0005435214374	30624	Economy	14000.00
0005432528492	30624	Economy	14000.00
0005434067786	30624	Economy	14000.00
0005432533304	30624	Economy	14000.00
0005435214388	30624	Economy	14000.00
0005435214385	30624	Economy	14000.00
0005435214352	30624	Economy	14000.00
0005432528707	30624	Economy	14000.00
0005435214343	30624	Economy	14000.00
0005432528593	30624	Economy	14000.00
0005432528481	30624	Economy	14000.00
0005435214340	30624	Economy	14000.00
0005432528743	30624	Economy	14000.00
0005432528174	30624	Economy	14000.00
0005435214399	30624	Economy	14000.00
0005432528368	30624	Economy	14000.00
0005435214350	30624	Economy	14000.00
0005432528205	30624	Economy	14000.00
0005434067631	30624	Economy	14000.00
0005435214370	30624	Economy	14000.00
0005432211589	30624	Economy	14000.00
0005434067666	30624	Economy	14000.00
0005435214353	30624	Economy	14000.00
0005435214375	30624	Economy	14000.00
0005434067830	30624	Economy	14000.00
0005432528419	30624	Economy	14000.00
0005432529086	30624	Economy	14000.00
0005432528678	30624	Economy	15400.00
0005432528170	30624	Economy	15400.00
0005432528817	30624	Economy	15400.00
0005435214361	30624	Economy	15400.00
0005432528594	30624	Economy	14000.00
0005432528267	30624	Economy	14000.00
0005432528740	30624	Economy	14000.00
0005435214356	30624	Economy	14000.00
0005432528379	30624	Economy	14000.00
0005434067847	30624	Economy	14000.00
0005434068010	30624	Economy	14000.00
0005432159914	30624	Economy	14000.00
0005432528835	30624	Economy	14000.00
0005435214368	30624	Economy	14000.00
0005432535860	30624	Economy	14000.00
0005432528307	30624	Economy	14000.00
0005432528216	30624	Economy	14000.00
0005432535842	30624	Economy	14000.00
0005435214367	30624	Economy	14000.00
0005435631004	30624	Economy	14000.00
0005432428949	30624	Economy	14000.00
0005432528169	30624	Economy	14000.00
0005432528279	30624	Economy	14000.00
0005434067984	30624	Economy	14000.00
0005434067827	30624	Economy	14000.00
0005434067646	30624	Economy	14000.00
0005435214357	30624	Economy	14000.00
0005435725661	30624	Economy	14000.00
0005432528961	30624	Economy	14000.00
0005434067710	30624	Economy	14000.00
0005432535838	30624	Economy	14000.00
0005435214397	30624	Economy	14000.00
0005432528700	30624	Economy	14000.00
0005432528468	30624	Economy	14000.00
0005432528832	30624	Economy	14000.00
0005432528470	30624	Economy	14000.00
0005432529062	30624	Economy	14000.00
0005434067606	30624	Economy	14000.00
0005432528902	30624	Economy	14000.00
0005435283411	30624	Economy	14000.00
0005432527831	30624	Economy	14000.00
0005434067652	30624	Economy	14000.00
0005435214379	30624	Economy	14000.00
0005432533305	30624	Economy	14000.00
0005432528629	30624	Economy	14000.00
0005432528483	30624	Economy	14000.00
0005432528469	30624	Economy	14000.00
0005434068011	30624	Economy	14000.00
0005434067747	30624	Economy	14000.00
0005432211595	30624	Economy	14000.00
0005432528610	30624	Economy	14000.00
0005435214401	30624	Economy	14000.00
0005432528548	30624	Economy	14000.00
0005435214394	30624	Economy	14000.00
0005432528480	30624	Economy	14000.00
0005432528413	30624	Economy	14000.00
0005435214346	30624	Economy	14000.00
0005432428950	30624	Economy	14000.00
0005434067623	30624	Economy	14000.00
0005434067607	30624	Economy	14000.00
0005432159915	30624	Economy	14000.00
0005432528910	30624	Economy	14000.00
0005432528173	30624	Economy	14000.00
0005435214400	30624	Economy	14000.00
0005432528532	30624	Economy	14000.00
0005434067722	30624	Economy	14000.00
0005432537068	30624	Economy	14000.00
0005432528209	30624	Economy	14000.00
0005432528084	30624	Economy	14000.00
0005432535861	30624	Economy	14000.00
0005435214386	30624	Economy	14000.00
0005435214347	30624	Economy	14000.00
0005435631007	30624	Economy	14000.00
0005435214354	30624	Economy	14000.00
0005435214381	30624	Economy	14000.00
0005434067778	30624	Economy	14000.00
0005432528382	30624	Economy	14000.00
0005432528679	30624	Economy	14000.00
0005434067800	30624	Economy	14000.00
0005432528271	30624	Economy	14000.00
0005432528097	30624	Economy	14000.00
0005432528761	30624	Economy	14000.00
0005432528472	30624	Economy	14000.00
0005432528807	30624	Economy	14000.00
0005432528137	30624	Economy	14000.00
0005434067781	30624	Economy	14000.00
0005432211593	30624	Economy	14000.00
0005432528449	30624	Economy	14000.00
0005432528849	30624	Economy	14000.00
0005432528572	30624	Economy	14000.00
0005435214383	30624	Economy	14000.00
0005432528494	30624	Economy	14000.00
0005435653234	24871	Business	9800.00
0005433368342	24871	Business	9800.00
0005435653114	24871	Business	9800.00
0005433368345	24871	Business	9800.00
0005435653228	24871	Business	9800.00
0005435653176	24871	Business	9800.00
0005435653148	24871	Business	9800.00
0005433368354	24871	Business	9800.00
0005433368346	24871	Business	9800.00
0005433368367	24871	Business	9800.00
0005435653205	24871	Business	9800.00
0005435653095	24871	Economy	3300.00
0005433368368	24871	Economy	3300.00
0005435653140	24871	Economy	3300.00
0005433368360	24871	Economy	3300.00
0005435653023	24871	Economy	3300.00
0005435653130	24871	Economy	3300.00
0005433368357	24871	Economy	3300.00
0005433368338	24871	Economy	3300.00
0005435653060	24871	Economy	3300.00
0005435653007	24871	Economy	3300.00
0005435653189	24871	Economy	3600.00
0005433368337	24871	Economy	3600.00
0005435653233	24871	Economy	3600.00
0005435653163	24871	Economy	3600.00
0005433368348	24871	Economy	3300.00
0005433368347	24871	Economy	3300.00
0005433368336	24871	Economy	3300.00
0005435653178	24871	Economy	3300.00
0005433368361	24871	Economy	3300.00
0005433368363	24871	Economy	3300.00
0005435653129	24871	Economy	3300.00
0005433368355	24871	Economy	3300.00
0005435653172	24871	Economy	3300.00
0005435653131	24871	Economy	3300.00
0005435653211	24871	Economy	3300.00
0005433368359	24871	Economy	3300.00
0005433368353	24871	Economy	3300.00
0005435653043	24871	Economy	3300.00
0005435653113	24871	Economy	3300.00
0005433368335	24871	Economy	3300.00
0005433368332	24871	Economy	3300.00
0005435653177	24871	Economy	3300.00
0005433368352	24871	Economy	3300.00
0005435653227	24871	Economy	3300.00
0005435653206	24871	Economy	3300.00
0005433368369	24871	Economy	3300.00
0005435653081	24871	Economy	3300.00
0005433368350	24871	Economy	3300.00
0005435653155	24871	Economy	3300.00
0005435653006	24871	Economy	3300.00
0005435653179	24871	Economy	3300.00
0005433368344	24871	Economy	3300.00
0005435653199	24871	Economy	3300.00
0005435653103	24871	Economy	3300.00
0005435652955	24871	Economy	3300.00
0005435653237	24871	Economy	3300.00
0005435653107	24871	Economy	3300.00
0005433368334	24871	Economy	3300.00
0005435653147	24871	Economy	3300.00
0005435652934	24871	Economy	3300.00
0005433368333	24871	Economy	3300.00
0005433368366	24871	Economy	3300.00
0005433368358	24871	Economy	3300.00
0005433368364	24871	Economy	3300.00
0005435653210	24871	Economy	3300.00
0005435653200	24871	Economy	3300.00
0005435653149	24871	Economy	3300.00
0005433368351	24871	Economy	3300.00
0005435653062	24871	Economy	3300.00
0005433368339	24871	Economy	3300.00
0005433368349	24871	Economy	3300.00
0005435653094	24871	Economy	3300.00
0005433368365	24871	Economy	3300.00
0005435653188	24871	Economy	3300.00
0005435653082	24871	Economy	3300.00
0005435653175	24871	Economy	3300.00
0005435653223	24871	Economy	3300.00
0005433368362	24871	Economy	3300.00
0005433368343	24871	Economy	3300.00
0005433368340	24871	Economy	3300.00
0005435653173	24871	Economy	3300.00
0005435653055	24871	Economy	3300.00
0005435653061	24871	Economy	3300.00
0005433368341	24871	Economy	3300.00
0005433368356	24871	Economy	3300.00
0005434980146	2017	Economy	10500.00
0005434980172	2017	Economy	10500.00
0005435801734	2017	Economy	9500.00
0005434980158	2017	Economy	9500.00
0005434980166	2017	Economy	9500.00
0005434980173	2017	Economy	9500.00
0005434980150	2017	Economy	9500.00
0005434980169	2017	Economy	9500.00
0005434980161	2017	Economy	9500.00
0005434980174	2017	Economy	9500.00
0005434980147	2017	Economy	9500.00
0005434980164	2017	Economy	9500.00
0005434980162	2017	Economy	9500.00
0005434980157	2017	Economy	9500.00
0005434980153	2017	Economy	9500.00
0005435801733	2017	Economy	9500.00
0005434980154	2017	Economy	9500.00
0005434980159	2017	Economy	9500.00
0005434980160	2017	Economy	9500.00
0005434980167	2017	Economy	9500.00
0005434980152	2017	Economy	9500.00
0005434980155	2017	Economy	9500.00
0005434980165	2017	Economy	9500.00
0005434980156	2017	Economy	9500.00
0005434980171	2017	Economy	9500.00
0005434980149	2017	Economy	9500.00
0005434980163	2017	Economy	9500.00
0005434980168	2017	Economy	9500.00
0005435801732	2017	Economy	9500.00
0005434980170	2017	Economy	9500.00
0005434980145	2017	Economy	9500.00
0005434980151	2017	Economy	9500.00
0005434980144	2017	Economy	9500.00
0005434980148	2017	Economy	9500.00
0005435801721	23563	Economy	10500.00
0005434979822	23563	Economy	9500.00
0005435801710	23563	Economy	9500.00
0005434979919	23563	Economy	9500.00
0005434979797	23563	Economy	9500.00
0005434979739	23563	Economy	9500.00
0005435801711	23563	Economy	9500.00
0005434979830	23563	Economy	9500.00
0005435801697	23563	Economy	9500.00
0005435801722	23563	Economy	9500.00
0005435801696	23563	Economy	9500.00
0005434979748	23563	Economy	9500.00
0005434979828	23563	Economy	9500.00
0005434979918	23563	Economy	9500.00
0005434979875	23563	Economy	9500.00
0005434979798	23563	Economy	9500.00
0005434979740	23563	Economy	9500.00
0005434979920	23563	Economy	9500.00
0005434979827	23563	Economy	9500.00
0005434979823	23563	Economy	9500.00
0005434979721	23563	Economy	9500.00
0005434979731	23563	Economy	9500.00
0005434979755	23563	Economy	9500.00
0005434979819	23563	Economy	9500.00
0005435801708	23563	Economy	9500.00
0005434979818	23563	Economy	9500.00
0005434979831	23563	Economy	9500.00
0005434979815	23563	Economy	9500.00
0005434979754	23563	Economy	9500.00
0005434979829	23563	Economy	9500.00
0005434979816	23563	Economy	9500.00
0005434952575	2593	Economy	5300.00
0005434952578	2593	Economy	5300.00
0005434952577	2593	Economy	5300.00
0005434952576	2593	Economy	5300.00
0005433256432	2612	Economy	5300.00
0005433256431	2612	Economy	5300.00
0005433256423	2612	Economy	5300.00
0005433256450	28261	Economy	5300.00
0005434952529	28261	Economy	5300.00
0005433111533	19804	Economy	8700.00
0005433111534	19804	Economy	8700.00
0005433112392	19804	Economy	8700.00
0005434138303	11931	Business	9700.00
0005434138606	11931	Business	9700.00
0005434138775	11931	Business	9700.00
0005434138145	11931	Business	9700.00
0005434138328	11931	Business	9700.00
0005434138507	11931	Business	9700.00
0005434138322	11931	Business	9700.00
0005434138922	11931	Business	9700.00
0005434138503	11931	Business	9700.00
0005434138457	11931	Economy	3200.00
0005434138449	11931	Economy	3200.00
0005434138844	11931	Economy	3200.00
0005434138486	11931	Economy	3200.00
0005434138654	11931	Economy	3200.00
0005434138309	11931	Economy	3200.00
0005434138310	11931	Economy	3200.00
0005434138510	11931	Economy	3500.00
0005434138574	11931	Economy	3500.00
0005434138195	11931	Economy	3500.00
0005434138499	11931	Economy	3200.00
0005434138617	11931	Economy	3200.00
0005434138471	11931	Economy	3200.00
0005434138125	11931	Economy	3200.00
0005434138585	11931	Economy	3200.00
0005434138506	11931	Economy	3200.00
0005434138399	11931	Economy	3200.00
0005434138222	11931	Economy	3200.00
0005434138390	11931	Economy	3200.00
0005434138461	11931	Economy	3200.00
0005434138395	11931	Economy	3200.00
0005434138385	11931	Economy	3200.00
0005434138605	11931	Economy	3200.00
0005434138413	11931	Economy	3200.00
0005434138407	11931	Economy	3200.00
0005434138386	11931	Economy	3200.00
0005434138653	11931	Economy	3200.00
0005434138982	11931	Economy	3200.00
0005434138242	11931	Economy	3200.00
0005434138683	11931	Economy	3200.00
0005434138845	11931	Economy	3200.00
0005434138479	11931	Economy	3200.00
0005434138504	11931	Economy	3200.00
0005434138664	11931	Economy	3200.00
0005434138312	11931	Economy	3200.00
0005434138354	11931	Economy	3200.00
0005434138353	11931	Economy	3200.00
0005434138481	11931	Economy	3200.00
0005434138502	11931	Economy	3200.00
0005435283567	11931	Economy	3200.00
0005434138601	11931	Economy	3200.00
0005434138437	11931	Economy	3200.00
0005434138006	11931	Economy	3200.00
0005434138495	11931	Economy	3200.00
0005434137689	11931	Economy	3200.00
0005434138619	11931	Economy	3200.00
0005434138622	11931	Economy	3200.00
0005434138682	11931	Economy	3200.00
0005434138575	11931	Economy	3200.00
0005434138465	11931	Economy	3200.00
0005434138655	11931	Economy	3200.00
0005434138391	11931	Economy	3200.00
0005434138263	11931	Economy	3200.00
0005434138761	11931	Economy	3200.00
0005434138464	11931	Economy	3200.00
0005434138531	11931	Economy	3200.00
0005434138321	11931	Economy	3200.00
0005434137688	11931	Economy	3200.00
0005434138393	11931	Economy	3200.00
0005434138333	11931	Economy	3200.00
0005434138466	11931	Economy	3200.00
0005434138573	11931	Economy	3200.00
0005434138417	11931	Economy	3200.00
0005434138511	11931	Economy	3200.00
0005434138419	11931	Economy	3200.00
0005434138480	11931	Economy	3200.00
0005434138243	11931	Economy	3200.00
0005434139093	28750	Business	9700.00
0005434139059	28750	Business	9700.00
0005434139103	28750	Business	9700.00
0005434139049	28750	Business	9700.00
0005434139057	28750	Business	9700.00
0005434139092	28750	Business	9700.00
0005434139069	28750	Business	9700.00
0005434139078	28750	Business	9700.00
0005434139067	28750	Economy	3200.00
0005434139052	28750	Economy	3200.00
0005434139125	28750	Economy	3200.00
0005434139085	28750	Economy	3200.00
0005434139100	28750	Economy	3200.00
0005434139115	28750	Economy	3200.00
0005434139128	28750	Economy	3200.00
0005434139088	28750	Economy	3200.00
0005434139076	28750	Economy	3200.00
0005434139097	28750	Economy	3500.00
0005434139095	28750	Economy	3500.00
0005434139098	28750	Economy	3500.00
0005434139126	28750	Economy	3500.00
0005434139120	28750	Economy	3500.00
0005434139068	28750	Economy	3200.00
0005434139075	28750	Economy	3200.00
0005434139058	28750	Economy	3200.00
0005434139064	28750	Economy	3200.00
0005434139108	28750	Economy	3200.00
0005434139111	28750	Economy	3200.00
0005434139062	28750	Economy	3200.00
0005434139101	28750	Economy	3200.00
0005434139079	28750	Economy	3200.00
0005434139081	28750	Economy	3200.00
0005434139117	28750	Economy	3200.00
0005434139116	28750	Economy	3200.00
0005434139074	28750	Economy	3200.00
0005434139106	28750	Economy	3200.00
0005434139096	28750	Economy	3200.00
0005434139063	28750	Economy	3200.00
0005434139118	28750	Economy	3200.00
0005434139072	28750	Economy	3200.00
0005434139077	28750	Economy	3200.00
0005434139051	28750	Economy	3200.00
0005434139082	28750	Economy	3200.00
0005434139086	28750	Economy	3200.00
0005434139091	28750	Economy	3200.00
0005434139112	28750	Economy	3200.00
0005434139060	28750	Economy	3200.00
0005434139073	28750	Economy	3200.00
0005434139054	28750	Economy	3200.00
0005434139109	28750	Economy	3200.00
0005434139089	28750	Economy	3200.00
0005434139065	28750	Economy	3200.00
0005434139055	28750	Economy	3200.00
0005434139053	28750	Economy	3200.00
0005434139105	28750	Economy	3200.00
0005434139050	28750	Economy	3200.00
0005434139099	28750	Economy	3200.00
0005434139122	28750	Economy	3200.00
0005434139080	28750	Economy	3200.00
0005434139066	28750	Economy	3200.00
0005434139119	28750	Economy	3200.00
0005434139102	28750	Economy	3200.00
0005434139124	28750	Economy	3200.00
0005434139110	28750	Economy	3200.00
0005434139129	28750	Economy	3200.00
0005434139061	28750	Economy	3200.00
0005434139083	28750	Economy	3200.00
0005434139127	28750	Economy	3200.00
0005434139113	28750	Economy	3200.00
0005434139090	28750	Economy	3200.00
0005434139056	28750	Economy	3200.00
0005434139048	28750	Economy	3200.00
0005434139107	28750	Economy	3200.00
0005434139121	28750	Economy	3200.00
0005434139070	28750	Economy	3200.00
0005434139104	28750	Economy	3200.00
0005434139084	28750	Economy	3200.00
0005434139114	28750	Economy	3200.00
0005434139087	28750	Economy	3200.00
0005434139123	28750	Economy	3200.00
0005434139071	28750	Economy	3200.00
0005434139094	28750	Economy	3200.00
0005433538981	6806	Economy	10900.00
0005433538975	6806	Economy	9900.00
0005433538977	6806	Economy	9900.00
0005433538980	6806	Economy	9900.00
0005433538974	6806	Economy	9900.00
0005433538978	6806	Economy	9900.00
0005433538973	6806	Economy	9900.00
0005433538976	6806	Economy	9900.00
0005435259764	6806	Economy	9900.00
0005433538979	6806	Economy	9900.00
0005435259765	6806	Economy	9900.00
0005433534524	6806	Economy	9900.00
0005433538972	6806	Economy	9900.00
0005433534525	6806	Economy	9900.00
0005433538932	25018	Economy	9900.00
0005433538900	25018	Economy	9900.00
0005433534504	25018	Economy	9900.00
0005433538919	25018	Economy	9900.00
0005433538878	25018	Economy	9900.00
0005435259812	25018	Economy	9900.00
0005433538880	25018	Economy	9900.00
0005435259811	25018	Economy	9900.00
0005433538879	25018	Economy	9900.00
0005433538918	25018	Economy	9900.00
0005433538923	25018	Economy	9900.00
0005433538933	25018	Economy	9900.00
0005433512059	851	Economy	16100.00
0005432922544	851	Economy	16100.00
0005433512053	851	Economy	14600.00
0005432922542	851	Economy	14600.00
0005433512058	851	Economy	14600.00
0005433512055	851	Economy	14600.00
0005432922526	851	Economy	14600.00
0005433512056	851	Economy	14600.00
0005433512057	851	Economy	14600.00
0005433512051	851	Economy	14600.00
0005433512054	851	Economy	14600.00
0005433512052	851	Economy	14600.00
0005432922575	16128	Economy	14600.00
0005432922577	16128	Economy	14600.00
0005433511979	16128	Economy	14600.00
0005433511973	16128	Economy	14600.00
0005432922574	16128	Economy	14600.00
0005432922576	16128	Economy	14600.00
0005433512033	16128	Economy	14600.00
0005433511988	16128	Economy	14600.00
0005433512032	16128	Economy	14600.00
0005433511984	16128	Economy	14600.00
0005433511974	16128	Economy	14600.00
0005433512010	16128	Economy	14600.00
0005432922573	16128	Economy	14600.00
0005435697678	3692	Economy	7900.00
0005435697687	3692	Economy	7900.00
0005435697683	3692	Economy	7900.00
0005435697696	3692	Economy	7200.00
0005434950584	3692	Economy	7200.00
0005435697679	3692	Economy	7200.00
0005435697685	3692	Economy	7200.00
0005435697698	3692	Economy	7200.00
0005435697701	3692	Economy	7200.00
0005434950586	3692	Economy	7200.00
0005435935064	3692	Economy	7200.00
0005435697694	3692	Economy	7200.00
0005435916176	3692	Economy	7200.00
0005435697690	3692	Economy	7200.00
0005435697697	3692	Economy	7200.00
0005434950583	3692	Economy	7200.00
0005435697688	3692	Economy	7200.00
0005435916169	3692	Economy	7200.00
0005435697681	3692	Economy	7200.00
0005435697704	3692	Economy	7200.00
0005435697682	3692	Economy	7200.00
0005435697693	3692	Economy	7200.00
0005435697702	3692	Economy	7200.00
0005435697703	3692	Economy	7200.00
0005435697680	3692	Economy	7200.00
0005435697695	3692	Economy	7200.00
0005435697700	3692	Economy	7200.00
0005435697684	3692	Economy	7200.00
0005434950585	3692	Economy	7200.00
0005434950587	3692	Economy	7200.00
0005435697676	3692	Economy	7200.00
0005435916178	3692	Economy	7200.00
0005435697677	3692	Economy	7200.00
0005435697686	3692	Economy	7200.00
0005435916177	3692	Economy	7200.00
0005435697699	3692	Economy	7200.00
0005435697692	3692	Economy	7200.00
0005435697691	3692	Economy	7200.00
0005435697689	3692	Economy	7200.00
0005435916166	3692	Economy	7200.00
0005434950552	16296	Economy	7900.00
0005435935080	16296	Economy	7900.00
0005435697425	16296	Economy	7200.00
0005435697503	16296	Economy	7200.00
0005434950561	16296	Economy	7200.00
0005435697438	16296	Economy	7200.00
0005435935081	16296	Economy	7200.00
0005435935083	16296	Economy	7200.00
0005435697484	16296	Economy	7200.00
0005435697483	16296	Economy	7200.00
0005434950562	16296	Economy	7200.00
0005434950553	16296	Economy	7200.00
0005435697426	16296	Economy	7200.00
0005434950558	16296	Economy	7200.00
0005435697473	16296	Economy	7200.00
0005435935082	16296	Economy	7200.00
0005435697276	16296	Economy	7200.00
0005435697464	16296	Economy	7200.00
0005435697502	16296	Economy	7200.00
0005435697419	16296	Economy	7200.00
0005435697439	16296	Economy	7200.00
0005435697430	16296	Economy	7200.00
0005435697402	16296	Economy	7200.00
0005434950551	16296	Economy	7200.00
0005435853622	3962	Economy	21300.00
0005432609782	3962	Economy	19300.00
0005435853621	3962	Economy	19300.00
0005434604940	3962	Economy	19300.00
0005434604942	3962	Economy	19300.00
0005432609783	3962	Economy	19300.00
0005432607615	3962	Economy	19300.00
0005434606872	3962	Economy	19300.00
0005435853623	3962	Economy	19300.00
0005432607618	3962	Economy	19300.00
0005433519515	3962	Economy	19300.00
0005434604943	3962	Economy	19300.00
0005434606871	3962	Economy	19300.00
0005434604939	3962	Economy	19300.00
0005433519514	3962	Economy	19300.00
0005433519516	3962	Economy	19300.00
0005435842329	3962	Economy	19300.00
0005435853627	3962	Economy	19300.00
0005433519513	3962	Economy	19300.00
0005432607616	3962	Economy	19300.00
0005432607617	3962	Economy	19300.00
0005435842330	3962	Economy	19300.00
0005434606873	3962	Economy	19300.00
0005432609781	3962	Economy	19300.00
0005434604941	3962	Economy	19300.00
0005434606844	22044	Economy	21300.00
0005432613859	22044	Economy	21300.00
0005432609723	22044	Economy	21300.00
0005432613870	22044	Economy	21300.00
0005432613846	22044	Economy	19300.00
0005433519474	22044	Economy	19300.00
0005432609702	22044	Economy	19300.00
0005432613867	22044	Economy	19300.00
0005432613863	22044	Economy	19300.00
0005433519475	22044	Economy	19300.00
0005432613869	22044	Economy	19300.00
0005432613872	22044	Economy	19300.00
0005435841102	22044	Economy	19300.00
0005432613877	22044	Economy	19300.00
0005432613864	22044	Economy	19300.00
0005432609722	22044	Economy	19300.00
0005432613876	22044	Economy	19300.00
0005432613845	22044	Economy	19300.00
0005432609731	22044	Economy	19300.00
0005432609739	22044	Economy	19300.00
0005432613865	22044	Economy	19300.00
0005433519486	22044	Economy	19300.00
0005432613848	22044	Economy	19300.00
0005432613873	22044	Economy	19300.00
0005432613861	22044	Economy	19300.00
0005432613874	22044	Economy	19300.00
0005433519488	22044	Economy	19300.00
0005432609746	22044	Economy	19300.00
0005432613860	22044	Economy	19300.00
0005432613858	22044	Economy	19300.00
0005432609744	22044	Economy	19300.00
0005432613878	22044	Economy	19300.00
0005432609733	22044	Economy	19300.00
0005432609745	22044	Economy	19300.00
0005432609724	22044	Economy	19300.00
0005432613871	22044	Economy	19300.00
0005432609719	22044	Economy	19300.00
0005432609729	22044	Economy	19300.00
0005432613862	22044	Economy	19300.00
0005435841103	22044	Economy	19300.00
0005432609734	22044	Economy	19300.00
0005434606843	22044	Economy	19300.00
0005432609732	22044	Economy	19300.00
0005432613866	22044	Economy	19300.00
0005432609718	22044	Economy	19300.00
0005432609725	22044	Economy	19300.00
0005435628763	709	Economy	3700.00
0005435628762	709	Economy	3700.00
0005433349008	709	Economy	3700.00
0005433349012	709	Economy	3700.00
0005435628766	709	Economy	3700.00
0005433349007	709	Economy	3700.00
0005435628764	709	Economy	3700.00
0005433349029	709	Economy	3700.00
0005435628765	709	Economy	3700.00
0005433349013	709	Economy	3700.00
0005435628767	709	Economy	3700.00
0005433349060	15876	Economy	3700.00
0005433349064	15876	Economy	3700.00
0005433349065	15876	Economy	3700.00
0005435628737	15876	Economy	3700.00
0005433349061	15876	Economy	3700.00
0005435628735	15876	Economy	3700.00
0005435628738	15876	Economy	3700.00
0005433349062	15876	Economy	3700.00
0005433349063	15876	Economy	3700.00
0005433159318	17149	Economy	7100.00
0005434446543	17149	Economy	7100.00
0005434446542	17149	Economy	7100.00
0005434446541	17149	Economy	7100.00
0005434445269	17149	Economy	7100.00
0005434445270	17149	Economy	7100.00
0005434446540	17149	Economy	7100.00
0005433159317	17149	Economy	7100.00
0005434445250	17575	Economy	7100.00
0005433159341	17575	Economy	7100.00
0005433159340	17575	Economy	7100.00
0005433159342	17575	Economy	7100.00
0005433159343	17575	Economy	7100.00
0005435383181	7876	Economy	5400.00
0005435133010	7876	Economy	5400.00
0005435133015	7876	Economy	5400.00
0005435133017	7876	Economy	5400.00
0005435383182	7876	Economy	5400.00
0005435133016	7876	Economy	5400.00
0005435133014	7876	Economy	5400.00
0005435133018	7876	Economy	5400.00
0005435133011	7876	Economy	5400.00
0005435133013	7876	Economy	5400.00
0005435383177	7876	Economy	5400.00
0005435133012	7876	Economy	5400.00
0005435133009	7876	Economy	5400.00
0005435383215	33075	Economy	5900.00
0005435132995	33075	Economy	5900.00
0005435383216	33075	Economy	5400.00
0005435132936	33075	Economy	5400.00
0005435132996	33075	Economy	5400.00
0005435132943	33075	Economy	5400.00
0005435132922	33075	Economy	5400.00
0005435132956	33075	Economy	5400.00
0005435132906	33075	Economy	5400.00
0005435383219	33075	Economy	5400.00
0005435132896	33075	Economy	5400.00
0005435383218	33075	Economy	5400.00
0005435132911	33075	Economy	5400.00
0005435383217	33075	Economy	5400.00
0005435132895	33075	Economy	5400.00
0005435132937	33075	Economy	5400.00
0005435132925	33075	Economy	5400.00
0005435132938	33075	Economy	5400.00
0005435132905	33075	Economy	5400.00
0005435132904	33075	Economy	5400.00
0005435132926	33075	Economy	5400.00
0005435132928	33075	Economy	5400.00
0005435938903	4398	Business	133200.00
0005435811137	4398	Economy	44400.00
0005435811136	4398	Economy	44400.00
0005435938891	4398	Economy	44400.00
0005435938886	4398	Economy	44400.00
0005435811141	4398	Economy	44400.00
0005435811140	4398	Economy	44400.00
0005435811138	4398	Economy	44400.00
0005435811139	4398	Economy	44400.00
0005435938885	4398	Economy	44400.00
0005435811134	4398	Economy	44400.00
0005435811132	4398	Economy	44400.00
0005435811135	4398	Economy	44400.00
0005435811133	4398	Economy	44400.00
0005435811131	4398	Economy	44400.00
0005435938902	4398	Economy	44400.00
0005435811074	29450	Business	133200.00
0005435811102	29450	Business	133200.00
0005435811085	29450	Economy	44400.00
0005435811071	29450	Economy	44400.00
0005435811095	29450	Economy	44400.00
0005435811070	29450	Economy	44400.00
0005435938920	29450	Economy	44400.00
0005435811117	29450	Economy	44400.00
0005435938916	29450	Economy	44400.00
0005435811077	29450	Economy	44400.00
0005435938917	29450	Economy	44400.00
0005435811093	29450	Economy	44400.00
0005435811083	29450	Economy	44400.00
0005435811082	29450	Economy	44400.00
0005435811096	29450	Economy	44400.00
0005435811084	29450	Economy	44400.00
0005435811103	29450	Economy	44400.00
0005435811097	29450	Economy	44400.00
0005435938919	29450	Economy	44400.00
0005435938918	29450	Economy	44400.00
0005435938921	29450	Economy	44400.00
0005435811094	29450	Economy	44400.00
0005435390230	7494	Economy	13800.00
0005435160441	7494	Economy	13800.00
0005435160443	7494	Economy	13800.00
0005435390263	7494	Economy	12500.00
0005435160445	7494	Economy	12500.00
0005435160442	7494	Economy	12500.00
0005435160438	7494	Economy	12500.00
0005435160439	7494	Economy	12500.00
0005435160446	7494	Economy	12500.00
0005435160444	7494	Economy	12500.00
0005435390246	7494	Economy	12500.00
0005435160437	7494	Economy	12500.00
0005435160440	7494	Economy	12500.00
0005435160447	7494	Economy	12500.00
0005435160436	7494	Economy	12500.00
0005435390262	7494	Economy	12500.00
0005435160392	29539	Economy	13800.00
0005435160404	29539	Economy	13800.00
0005435160374	29539	Economy	12500.00
0005435390327	29539	Economy	12500.00
0005435160301	29539	Economy	12500.00
0005435160359	29539	Economy	12500.00
0005435160350	29539	Economy	12500.00
0005435160300	29539	Economy	12500.00
0005435160386	29539	Economy	12500.00
0005435160357	29539	Economy	12500.00
0005435390328	29539	Economy	12500.00
0005435390326	29539	Economy	12500.00
0005435390329	29539	Economy	12500.00
0005435160377	29539	Economy	12500.00
0005435160322	29539	Economy	12500.00
0005435160354	29539	Economy	12500.00
0005435160384	29539	Economy	12500.00
0005435390324	29539	Economy	12500.00
0005435390325	29539	Economy	12500.00
0005435390323	29539	Economy	12500.00
0005435160376	29539	Economy	12500.00
0005435160323	29539	Economy	12500.00
0005435160385	29539	Economy	12500.00
0005435160373	29539	Economy	12500.00
0005432394115	18467	Economy	4900.00
0005432398203	18467	Economy	4900.00
0005432394111	18467	Economy	4900.00
0005432398214	18467	Economy	4900.00
0005432398223	18467	Economy	4900.00
0005432394133	18467	Economy	4900.00
0005432394110	18467	Economy	4900.00
0005432398215	18467	Economy	4900.00
0005432394114	18467	Economy	4900.00
0005432398224	18467	Economy	4900.00
0005432398240	27142	Economy	4900.00
0005432400168	27142	Economy	4900.00
0005432398242	27142	Economy	4900.00
0005432400169	27142	Economy	4900.00
0005432398241	27142	Economy	4900.00
0005432400170	27142	Economy	4900.00
0005435104023	6521	Business	48400.00
0005434504631	6521	Business	48400.00
0005434504646	6521	Business	48400.00
0005434504663	6521	Business	48400.00
0005434504659	6521	Business	48400.00
0005435104026	6521	Business	48400.00
0005434504632	6521	Business	48400.00
0005434504657	6521	Economy	16100.00
0005434504625	6521	Economy	16100.00
0005434504661	6521	Economy	16100.00
0005434504644	6521	Economy	16100.00
0005434504652	6521	Economy	16100.00
0005434504623	6521	Economy	16100.00
0005435104018	6521	Economy	16100.00
0005434504650	6521	Economy	17800.00
0005434504639	6521	Economy	17800.00
0005435104022	6521	Economy	16100.00
0005434504655	6521	Economy	16100.00
0005434504638	6521	Economy	16100.00
0005434504624	6521	Economy	16100.00
0005434504662	6521	Economy	16100.00
0005435104017	6521	Economy	16100.00
0005434504629	6521	Economy	16100.00
0005434504637	6521	Economy	16100.00
0005435104029	6521	Economy	16100.00
0005435104020	6521	Economy	16100.00
0005434504653	6521	Economy	16100.00
0005434504640	6521	Economy	16100.00
0005434504645	6521	Economy	16100.00
0005434504635	6521	Economy	16100.00
0005434504626	6521	Economy	16100.00
0005434504660	6521	Economy	16100.00
0005434504651	6521	Economy	16100.00
0005434504641	6521	Economy	16100.00
0005434504642	6521	Economy	16100.00
0005434504649	6521	Economy	16100.00
0005434504628	6521	Economy	16100.00
0005435104024	6521	Economy	16100.00
0005435104021	6521	Economy	16100.00
0005434504643	6521	Economy	16100.00
0005435104028	6521	Economy	16100.00
0005434504656	6521	Economy	16100.00
0005434504647	6521	Economy	16100.00
0005434504633	6521	Economy	16100.00
0005435104019	6521	Economy	16100.00
0005435104027	6521	Economy	16100.00
0005434504658	6521	Economy	16100.00
0005434504654	6521	Economy	16100.00
0005435104025	6521	Economy	16100.00
0005434504648	6521	Economy	16100.00
0005434504630	6521	Economy	16100.00
0005434504634	6521	Economy	16100.00
0005434504636	6521	Economy	16100.00
0005434504627	6521	Economy	16100.00
0005434503996	22645	Business	48400.00
0005434504345	22645	Business	48400.00
0005434504058	22645	Business	48400.00
0005434504306	22645	Business	48400.00
0005434504159	22645	Business	48400.00
0005434504354	22645	Business	48400.00
0005435103940	22645	Economy	16100.00
0005434504200	22645	Economy	16100.00
0005434504323	22645	Economy	16100.00
0005434504258	22645	Economy	16100.00
0005434504324	22645	Economy	16100.00
0005434504229	22645	Economy	16100.00
0005434504319	22645	Economy	16100.00
0005435103937	22645	Economy	16100.00
0005434503997	22645	Economy	16100.00
0005434504117	22645	Economy	16100.00
0005434504158	22645	Economy	16100.00
0005435103912	22645	Economy	16100.00
0005435103933	22645	Economy	16100.00
0005434504253	22645	Economy	16100.00
0005434504327	22645	Economy	16100.00
0005434504169	22645	Economy	16100.00
0005434504191	22645	Economy	16100.00
0005435103938	22645	Economy	16100.00
0005434504168	22645	Economy	16100.00
0005435103911	22645	Economy	16100.00
0005435103939	22645	Economy	16100.00
0005434504366	22645	Economy	16100.00
0005434504118	22645	Economy	16100.00
0005434504246	22645	Economy	16100.00
0005434504111	22645	Economy	16100.00
0005434504182	22645	Economy	16100.00
0005434504292	22645	Economy	16100.00
0005434504107	22645	Economy	16100.00
0005434504132	22645	Economy	16100.00
0005434504133	22645	Economy	16100.00
0005434504320	22645	Economy	16100.00
0005434504228	22645	Economy	16100.00
0005434504138	22645	Economy	16100.00
0005435800111	21309	Economy	16800.00
0005435800105	21309	Economy	15300.00
0005435800106	21309	Economy	15300.00
0005435800109	21309	Economy	15300.00
0005435800120	21309	Economy	15300.00
0005435800104	21309	Economy	15300.00
0005435800099	21309	Economy	15300.00
0005435800116	21309	Economy	15300.00
0005435800102	21309	Economy	15300.00
0005435800117	21309	Economy	15300.00
0005435800098	21309	Economy	15300.00
0005435800124	21309	Economy	15300.00
0005435800121	21309	Economy	15300.00
0005435800107	21309	Economy	15300.00
0005435800112	21309	Economy	15300.00
0005435800115	21309	Economy	15300.00
0005435800103	21309	Economy	15300.00
0005435800125	21309	Economy	15300.00
0005435800100	21309	Economy	15300.00
0005435800108	21309	Economy	15300.00
0005435800110	21309	Economy	15300.00
0005433368187	1643	Business	50000.00
0005433367952	1643	Business	50000.00
0005433367866	1643	Business	50000.00
0005433367937	1643	Business	50000.00
0005433368021	1643	Business	50000.00
0005433367978	1643	Business	50000.00
0005433368151	1643	Business	50000.00
0005433368050	1643	Business	50000.00
0005433367979	1643	Business	50000.00
0005435653602	1643	Business	50000.00
0005433367912	1643	Economy	16700.00
0005433368044	1643	Economy	16700.00
0005433367991	1643	Economy	16700.00
0005433367987	1643	Economy	16700.00
0005433368188	1643	Economy	16700.00
0005433368138	1643	Economy	16700.00
0005433368032	1643	Economy	16700.00
0005435653597	1643	Economy	16700.00
0005433367975	1643	Economy	16700.00
0005435653609	1643	Economy	18300.00
0005433368035	1643	Economy	18300.00
0005433367838	1643	Economy	18300.00
0005433367929	1643	Economy	18300.00
0005435653599	1643	Economy	16700.00
0005433368239	1643	Economy	16700.00
0005435653594	1643	Economy	16700.00
0005433368240	1643	Economy	16700.00
0005433367884	1643	Economy	16700.00
0005433368104	1643	Economy	16700.00
0005435653596	1643	Economy	16700.00
0005435653593	1643	Economy	16700.00
0005433368062	1643	Economy	16700.00
0005433367976	1643	Economy	16700.00
0005433368137	1643	Economy	16700.00
0005435653595	1643	Economy	16700.00
0005433367931	1643	Economy	16700.00
0005435653608	1643	Economy	16700.00
0005433367973	1643	Economy	16700.00
0005433367906	1643	Economy	16700.00
0005433368125	1643	Economy	16700.00
0005433367911	1643	Economy	16700.00
0005433368099	1643	Economy	16700.00
0005435653610	1643	Economy	16700.00
0005433368072	1643	Economy	16700.00
0005433368054	1643	Economy	16700.00
0005433368079	1643	Economy	16700.00
0005433368037	1643	Economy	16700.00
0005433367953	1643	Economy	16700.00
0005433367930	1643	Economy	16700.00
0005433368027	1643	Economy	16700.00
0005433368150	1643	Economy	16700.00
0005433368071	1643	Economy	16700.00
0005435653601	1643	Economy	16700.00
0005433368106	1643	Economy	16700.00
0005433368102	1643	Economy	16700.00
0005435653606	1643	Economy	16700.00
0005435653598	1643	Economy	16700.00
0005433368051	1643	Economy	16700.00
0005433367936	1643	Economy	16700.00
0005433368029	1643	Economy	16700.00
0005433368039	1643	Economy	16700.00
0005435653603	1643	Economy	16700.00
0005433368033	1643	Economy	16700.00
0005435653605	1643	Economy	16700.00
0005433368101	1643	Economy	16700.00
0005433368038	1643	Economy	16700.00
0005435653607	1643	Economy	16700.00
0005435653604	1643	Economy	16700.00
0005433368108	1643	Economy	16700.00
0005433368134	1643	Economy	16700.00
0005433368078	1643	Economy	16700.00
0005433368100	1643	Economy	16700.00
0005435653600	1643	Economy	16700.00
0005433368107	1643	Economy	16700.00
0005433368129	1643	Economy	16700.00
0005433368139	1643	Economy	16700.00
0005433368045	1643	Economy	16700.00
0005435653233	21696	Business	50000.00
0005433368346	21696	Business	50000.00
0005435653055	21696	Business	50000.00
0005435653140	21696	Business	50000.00
0005435652934	21696	Business	50000.00
0005435653176	21696	Business	50000.00
0005435653211	21696	Business	50000.00
0005435653205	21696	Business	50000.00
0005435653179	21696	Business	50000.00
0005433368357	21696	Business	50000.00
0005435653228	21696	Economy	16700.00
0005433368348	21696	Economy	16700.00
0005433368369	21696	Economy	16700.00
0005435653189	21696	Economy	16700.00
0005435653130	21696	Economy	16700.00
0005435653061	21696	Economy	16700.00
0005433368338	21696	Economy	16700.00
0005433368349	21696	Economy	18300.00
0005433368359	21696	Economy	18300.00
0005433368351	21696	Economy	18300.00
0005435653062	21696	Economy	18300.00
0005433368334	21696	Economy	16700.00
0005435653081	21696	Economy	16700.00
0005435653175	21696	Economy	16700.00
0005433368361	21696	Economy	16700.00
0005435653200	21696	Economy	16700.00
0005433368360	21696	Economy	16700.00
0005435653043	21696	Economy	16700.00
0005435653177	21696	Economy	16700.00
0005433368332	21696	Economy	16700.00
0005433368342	21696	Economy	16700.00
0005433368350	21696	Economy	16700.00
0005433368337	21696	Economy	16700.00
0005435652955	21696	Economy	16700.00
0005433368368	21696	Economy	16700.00
0005433368341	21696	Economy	16700.00
0005435653210	21696	Economy	16700.00
0005435653129	21696	Economy	16700.00
0005433368354	21696	Economy	16700.00
0005435653148	21696	Economy	16700.00
0005433368365	21696	Economy	16700.00
0005435653149	21696	Economy	16700.00
0005435653107	21696	Economy	16700.00
0005433368362	21696	Economy	16700.00
0005435653114	21696	Economy	16700.00
0005435653147	21696	Economy	16700.00
0005433368366	21696	Economy	16700.00
0005433368356	21696	Economy	16700.00
0005435653173	21696	Economy	16700.00
0005433368333	21696	Economy	16700.00
0005435653172	21696	Economy	16700.00
0005433368340	21696	Economy	16700.00
0005433368355	21696	Economy	16700.00
0005435653131	21696	Economy	16700.00
0005435653188	21696	Economy	16700.00
0005435653095	21696	Economy	16700.00
0005435653060	21696	Economy	16700.00
0005433368367	21696	Economy	16700.00
0005435653206	21696	Economy	16700.00
0005435653103	21696	Economy	16700.00
0005435653082	21696	Economy	16700.00
0005435653113	21696	Economy	16700.00
0005435653155	21696	Economy	16700.00
0005433368343	21696	Economy	16700.00
0005433368358	21696	Economy	16700.00
0005433368344	21696	Economy	16700.00
0005435653178	21696	Economy	16700.00
0005435653227	21696	Economy	16700.00
0005435653237	21696	Economy	16700.00
0005433368345	21696	Economy	16700.00
0005435653006	21696	Economy	16700.00
0005433368364	21696	Economy	16700.00
0005435653199	21696	Economy	16700.00
0005433368336	21696	Economy	16700.00
0005433368339	21696	Economy	16700.00
0005435653094	21696	Economy	16700.00
0005435653007	21696	Economy	16700.00
0005435653163	21696	Economy	16700.00
0005435653023	21696	Economy	16700.00
0005433368353	21696	Economy	16700.00
0005433368363	21696	Economy	16700.00
0005433368352	21696	Economy	16700.00
0005433368335	21696	Economy	16700.00
0005433368347	21696	Economy	16700.00
0005435653234	21696	Economy	16700.00
0005435653223	21696	Economy	16700.00
0005433986534	4147	Business	21500.00
0005433986543	4147	Business	21500.00
0005435788804	4147	Business	21500.00
0005433986536	4147	Business	21500.00
0005433986527	4147	Business	21500.00
0005433986540	4147	Economy	7200.00
0005433986530	4147	Economy	7200.00
0005433986542	4147	Economy	7200.00
0005433986535	4147	Economy	7900.00
0005433986507	4147	Economy	7900.00
0005433986514	4147	Economy	7900.00
0005433986545	4147	Economy	7900.00
0005433986520	4147	Economy	7200.00
0005433986506	4147	Economy	7200.00
0005433986517	4147	Economy	7200.00
0005433986533	4147	Economy	7200.00
0005433986518	4147	Economy	7200.00
0005433986532	4147	Economy	7200.00
0005433986544	4147	Economy	7200.00
0005433986519	4147	Economy	7200.00
0005433986529	4147	Economy	7200.00
0005433986521	4147	Economy	7200.00
0005433986541	4147	Economy	7200.00
0005433986528	4147	Economy	7200.00
0005435788803	4147	Economy	7200.00
0005433986512	4147	Economy	7200.00
0005433986513	4147	Economy	7200.00
0005433986515	4147	Economy	7200.00
0005433986531	4147	Economy	7200.00
0005433986510	4147	Economy	7200.00
0005433986525	4147	Economy	7200.00
0005433986516	4147	Economy	7200.00
0005433986524	4147	Economy	7200.00
0005433986523	4147	Economy	7200.00
0005433986522	4147	Economy	7200.00
0005433986546	4147	Economy	7200.00
0005433986508	4147	Economy	7200.00
0005433986511	4147	Economy	7200.00
0005433986509	4147	Economy	7200.00
0005433986537	4147	Economy	7200.00
0005433986538	4147	Economy	7200.00
0005433986539	4147	Economy	7200.00
0005433986547	4147	Economy	7200.00
0005433986526	4147	Economy	7200.00
0005435788777	25689	Business	21500.00
0005433986104	25689	Business	21500.00
0005435788778	25689	Business	21500.00
0005433986223	25689	Business	21500.00
0005433986139	25689	Business	21500.00
0005433986026	25689	Business	21500.00
0005433986194	25689	Business	21500.00
0005433986133	25689	Business	21500.00
0005433986192	25689	Economy	7200.00
0005433985975	25689	Economy	7200.00
0005433986160	25689	Economy	7200.00
0005433986090	25689	Economy	7200.00
0005433985991	25689	Economy	7200.00
0005433985955	25689	Economy	7200.00
0005433986064	25689	Economy	7200.00
0005433986102	25689	Economy	7900.00
0005433986056	25689	Economy	7900.00
0005433986124	25689	Economy	7900.00
0005433985939	25689	Economy	7200.00
0005433986222	25689	Economy	7200.00
0005433986117	25689	Economy	7200.00
0005433985974	25689	Economy	7200.00
0005433985960	25689	Economy	7200.00
0005433986158	25689	Economy	7200.00
0005433986106	25689	Economy	7200.00
0005433986054	25689	Economy	7200.00
0005433986057	25689	Economy	7200.00
0005433986049	25689	Economy	7200.00
0005433986071	25689	Economy	7200.00
0005433986073	25689	Economy	7200.00
0005433986070	25689	Economy	7200.00
0005433986162	25689	Economy	7200.00
0005433986165	25689	Economy	7200.00
0005433986075	25689	Economy	7200.00
0005433986028	25689	Economy	7200.00
0005433986055	25689	Economy	7200.00
0005433986157	25689	Economy	7200.00
0005433985840	25689	Economy	7200.00
0005433986097	25689	Economy	7200.00
0005433986116	25689	Economy	7200.00
0005433986125	25689	Economy	7200.00
0005433986105	25689	Economy	7200.00
0005433985861	25689	Economy	7200.00
0005433985949	25689	Economy	7200.00
0005433986141	25689	Economy	7200.00
0005433986098	25689	Economy	7200.00
0005433986065	25689	Economy	7200.00
0005433986140	25689	Economy	7200.00
0005433986159	25689	Economy	7200.00
0005433986050	25689	Economy	7200.00
0005433986025	25689	Economy	7200.00
0005433985948	25689	Economy	7200.00
0005433986027	25689	Economy	7200.00
0005433986072	25689	Economy	7200.00
0005433985997	25689	Economy	7200.00
0005433985860	25689	Economy	7200.00
0005433985961	25689	Economy	7200.00
0005433986132	25689	Economy	7200.00
0005433986163	25689	Economy	7200.00
0005433986003	25689	Economy	7200.00
0005433986126	25689	Economy	7200.00
0005433986164	25689	Economy	7200.00
0005433986142	25689	Economy	7200.00
0005435720826	21252	Economy	10400.00
0005435720825	21252	Economy	9400.00
0005435719572	24768	Economy	10400.00
0005433168389	1620	Economy	17000.00
0005434509243	1620	Economy	17000.00
0005434509241	1620	Economy	17000.00
0005434509248	1620	Economy	15500.00
0005434509238	1620	Economy	15500.00
0005433168391	1620	Economy	15500.00
0005433168387	1620	Economy	15500.00
0005434509245	1620	Economy	15500.00
0005433168379	1620	Economy	15500.00
0005433168388	1620	Economy	15500.00
0005433168380	1620	Economy	15500.00
0005434509250	1620	Economy	15500.00
0005434509247	1620	Economy	15500.00
0005433168401	1620	Economy	15500.00
0005434509244	1620	Economy	15500.00
0005434509249	1620	Economy	15500.00
0005434509240	1620	Economy	15500.00
0005434509242	1620	Economy	15500.00
0005433168390	1620	Economy	15500.00
0005434509235	1620	Economy	15500.00
0005434509246	1620	Economy	15500.00
0005434509237	1620	Economy	15500.00
0005434509239	1620	Economy	15500.00
0005434509236	1620	Economy	15500.00
0005432659720	17823	Business	18000.00
0005432659721	17823	Business	18000.00
0005432869608	17823	Business	18000.00
0005434151742	17823	Business	18000.00
0005432655562	17823	Business	18000.00
0005432661928	17823	Business	18000.00
0005432869611	17823	Business	18000.00
0005432660823	17823	Economy	6000.00
0005434151743	17823	Economy	6000.00
0005432666385	17823	Economy	6000.00
0005432657453	17823	Economy	6000.00
0005432655520	17823	Economy	6600.00
0005432655531	17823	Economy	6600.00
0005432869614	17823	Economy	6600.00
0005432869612	17823	Economy	6600.00
0005432658593	17823	Economy	6000.00
0005432666398	17823	Economy	6000.00
0005432655597	17823	Economy	6000.00
0005432663051	17823	Economy	6000.00
0005432657466	17823	Economy	6000.00
0005432659713	17823	Economy	6000.00
0005432655552	17823	Economy	6000.00
0005432666397	17823	Economy	6000.00
0005432665283	17823	Economy	6000.00
0005432661920	17823	Economy	6000.00
0005432655553	17823	Economy	6000.00
0005432655584	17823	Economy	6000.00
0005432658594	17823	Economy	6000.00
0005432869615	17823	Economy	6000.00
0005432667453	17823	Economy	6000.00
0005432869613	17823	Economy	6000.00
0005432655579	17823	Economy	6000.00
0005432661935	17823	Economy	6000.00
0005432664139	17823	Economy	6000.00
0005432661921	17823	Economy	6000.00
0005432655515	17823	Economy	6000.00
0005432869610	17823	Economy	6000.00
0005432869607	17823	Economy	6000.00
0005432655529	17823	Economy	6000.00
0005432869609	17823	Economy	6000.00
0005432657454	17823	Economy	6000.00
0005432655578	17823	Economy	6000.00
0005432655589	17823	Economy	6000.00
0005432665282	17823	Economy	6000.00
0005434151741	17823	Economy	6000.00
0005432655577	17823	Economy	6000.00
0005432666393	17823	Economy	6000.00
0005432666392	17823	Economy	6000.00
0005432655550	17823	Economy	6000.00
0005432659714	17823	Economy	6000.00
0005432660827	17823	Economy	6000.00
0005432655627	17823	Economy	6000.00
0005432655530	17823	Economy	6000.00
0005432655585	17823	Economy	6000.00
0005432666411	26333	Business	18000.00
0005432869518	26333	Business	18000.00
0005432660841	26333	Business	18000.00
0005432655656	26333	Business	18000.00
0005432657483	26333	Business	18000.00
0005432655658	26333	Business	18000.00
0005432665298	26333	Business	18000.00
0005432655657	26333	Economy	6000.00
0005432659730	26333	Economy	6600.00
0005432655665	26333	Economy	6600.00
0005432869517	26333	Economy	6000.00
0005432655659	26333	Economy	6000.00
0005432655667	26333	Economy	6000.00
0005432657484	26333	Economy	6000.00
0005432655663	26333	Economy	6000.00
0005432667476	26333	Economy	6000.00
0005432666412	26333	Economy	6000.00
0005432655661	26333	Economy	6000.00
0005432655660	26333	Economy	6000.00
0005432659729	26333	Economy	6000.00
0005432658615	26333	Economy	6000.00
0005432660840	26333	Economy	6000.00
0005432659728	26333	Economy	6000.00
0005432869542	26333	Economy	6000.00
0005432658614	26333	Economy	6000.00
0005432667477	26333	Economy	6000.00
0005432657482	26333	Economy	6000.00
0005432655664	26333	Economy	6000.00
0005432655662	26333	Economy	6000.00
0005432869574	26333	Economy	6000.00
0005432869573	26333	Economy	6000.00
0005432655666	26333	Economy	6000.00
0005432866098	25055	Business	87300.00
0005432866105	25055	Business	87300.00
0005432639159	25055	Business	87300.00
0005432866103	25055	Business	87300.00
0005432639132	25055	Business	87300.00
0005432866100	25055	Economy	29100.00
0005432866106	25055	Economy	29100.00
0005432639160	25055	Economy	29100.00
0005432639173	25055	Economy	32000.00
0005432866099	25055	Economy	32000.00
0005432866096	25055	Economy	29100.00
0005432639168	25055	Economy	29100.00
0005432639174	25055	Economy	29100.00
0005432639162	25055	Economy	29100.00
0005432639177	25055	Economy	29100.00
0005432639169	25055	Economy	29100.00
0005432639153	25055	Economy	29100.00
0005432639157	25055	Economy	29100.00
0005432639093	25055	Economy	29100.00
0005432639152	25055	Economy	29100.00
0005432639147	25055	Economy	29100.00
0005432866097	25055	Economy	29100.00
0005432866104	25055	Economy	29100.00
0005432639193	25055	Economy	29100.00
0005432639158	25055	Economy	29100.00
0005432866101	25055	Economy	29100.00
0005432866107	25055	Economy	29100.00
0005432866095	25055	Economy	29100.00
0005432866094	25055	Economy	29100.00
0005432866102	25055	Economy	29100.00
0005432866108	25055	Economy	29100.00
0005432329282	3098	Business	16100.00
0005432329294	3098	Business	16100.00
0005432329298	3098	Business	16100.00
0005432905139	3098	Business	16100.00
0005432329277	3098	Business	16100.00
0005432329292	3098	Business	16100.00
0005432329265	3098	Business	16100.00
0005432329293	3098	Business	16100.00
0005432905161	3098	Business	16100.00
0005432329287	3098	Economy	5400.00
0005432329281	3098	Economy	5400.00
0005432329260	3098	Economy	5400.00
0005432905141	3098	Economy	5400.00
0005432329255	3098	Economy	5400.00
0005432329279	3098	Economy	5400.00
0005432329254	3098	Economy	5400.00
0005432287255	3098	Economy	5400.00
0005432329264	3098	Economy	5900.00
0005432329274	3098	Economy	5900.00
0005432329257	3098	Economy	5400.00
0005433438969	3098	Economy	5400.00
0005432329296	3098	Economy	5400.00
0005432329266	3098	Economy	5400.00
0005432329289	3098	Economy	5400.00
0005432287251	3098	Economy	5400.00
0005432329263	3098	Economy	5400.00
0005432905154	3098	Economy	5400.00
0005432329290	3098	Economy	5400.00
0005432329291	3098	Economy	5400.00
0005432329278	3098	Economy	5400.00
0005432905163	3098	Economy	5400.00
0005432905164	3098	Economy	5400.00
0005432329253	3098	Economy	5400.00
0005432329262	3098	Economy	5400.00
0005432329261	3098	Economy	5400.00
0005432905162	3098	Economy	5400.00
0005432329276	3098	Economy	5400.00
0005432329283	3098	Economy	5400.00
0005432329273	3098	Economy	5400.00
0005432329275	3098	Economy	5400.00
0005432329286	3098	Economy	5400.00
0005432329272	3098	Economy	5400.00
0005433438970	3098	Economy	5400.00
0005432287253	3098	Economy	5400.00
0005432329270	3098	Economy	5400.00
0005432329256	3098	Economy	5400.00
0005432287252	3098	Economy	5400.00
0005432905160	3098	Economy	5400.00
0005432329280	3098	Economy	5400.00
0005432905159	3098	Economy	5400.00
0005432329271	3098	Economy	5400.00
0005432329297	3098	Economy	5400.00
0005432905142	3098	Economy	5400.00
0005432905138	3098	Economy	5400.00
0005432329285	3098	Economy	5400.00
0005432329267	3098	Economy	5400.00
0005432329284	3098	Economy	5400.00
0005432329295	3098	Economy	5400.00
0005432329288	3098	Economy	5400.00
0005432329269	3098	Economy	5400.00
0005432905140	3098	Economy	5400.00
0005432329259	3098	Economy	5400.00
0005432329268	3098	Economy	5400.00
0005432905153	3098	Economy	5400.00
0005432905132	3098	Economy	5400.00
0005432329258	3098	Economy	5400.00
0005432905131	3098	Economy	5400.00
0005432905155	3098	Economy	5400.00
0005432287254	3098	Economy	5400.00
0005433438919	31139	Business	16100.00
0005432328858	31139	Business	16100.00
0005432328903	31139	Business	16100.00
0005432328878	31139	Business	16100.00
0005433438887	31139	Business	16100.00
0005432328871	31139	Business	16100.00
0005432328663	31139	Economy	5400.00
0005432848842	31139	Economy	5400.00
0005432328991	31139	Economy	5400.00
0005433438893	31139	Economy	5400.00
0005432328887	31139	Economy	5400.00
0005432328749	31139	Economy	5400.00
0005432328907	31139	Economy	5400.00
0005432328847	31139	Economy	5400.00
0005432905201	31139	Economy	5900.00
0005432328857	31139	Economy	5900.00
0005433438899	31139	Economy	5900.00
0005432328792	31139	Economy	5900.00
0005432328886	31139	Economy	5400.00
0005432328998	31139	Economy	5400.00
0005432328995	31139	Economy	5400.00
0005432328809	31139	Economy	5400.00
0005432328796	31139	Economy	5400.00
0005432328702	31139	Economy	5400.00
0005432328895	31139	Economy	5400.00
0005432905196	31139	Economy	5400.00
0005432328808	31139	Economy	5400.00
0005432328867	31139	Economy	5400.00
0005432905197	31139	Economy	5400.00
0005432905200	31139	Economy	5400.00
0005432328900	31139	Economy	5400.00
0005432328651	31139	Economy	5400.00
0005432328810	31139	Economy	5400.00
0005433438888	31139	Economy	5400.00
0005432328748	31139	Economy	5400.00
0005433438907	31139	Economy	5400.00
0005432329048	31139	Economy	5400.00
0005432054341	31139	Economy	5400.00
0005432328904	31139	Economy	5400.00
0005432328760	31139	Economy	5400.00
0005432328664	31139	Economy	5400.00
0005433438906	31139	Economy	5400.00
0005433438925	31139	Economy	5400.00
0005432328652	31139	Economy	5400.00
0005432328795	31139	Economy	5400.00
0005432328999	31139	Economy	5400.00
0005432328837	31139	Economy	5400.00
0005432328846	31139	Economy	5400.00
0005433438886	31139	Economy	5400.00
0005432328935	31139	Economy	5400.00
0005432328936	31139	Economy	5400.00
0005432328703	31139	Economy	5400.00
0005432328793	31139	Economy	5400.00
0005432905203	31139	Economy	5400.00
0005433438918	31139	Economy	5400.00
0005432905202	31139	Economy	5400.00
0005432328692	31139	Economy	5400.00
0005432328934	31139	Economy	5400.00
0005432905199	31139	Economy	5400.00
0005432328908	31139	Economy	5400.00
0005432848841	31139	Economy	5400.00
0005432328780	31139	Economy	5400.00
0005432905198	31139	Economy	5400.00
0005432328779	31139	Economy	5400.00
0005435487927	6203	Business	124600.00
0005434309917	6203	Business	124600.00
0005434309909	6203	Business	124600.00
0005434309915	6203	Business	124600.00
0005435487905	6203	Business	124600.00
0005435487808	6203	Business	124600.00
0005435297095	6203	Business	124600.00
0005432146227	6203	Business	124600.00
0005435999467	6203	Economy	41500.00
0005435999470	6203	Economy	41500.00
0005435999471	6203	Economy	41500.00
0005435487840	6203	Economy	41500.00
0005435487841	6203	Economy	41500.00
0005434309919	6203	Economy	41500.00
0005435297074	6203	Economy	41500.00
0005435297041	6203	Economy	41500.00
0005435999473	6203	Economy	41500.00
0005435999462	6203	Economy	41500.00
0005435487928	6203	Economy	41500.00
0005435297100	6203	Economy	41500.00
0005432146226	6203	Economy	41500.00
0005435999466	6203	Economy	41500.00
0005435487902	6203	Economy	41500.00
0005435297099	6203	Economy	41500.00
0005432146225	6203	Economy	41500.00
0005435487848	6203	Economy	41500.00
0005435297084	6203	Economy	41500.00
0005435999468	6203	Economy	41500.00
0005435487948	6203	Economy	45700.00
0005435487929	6203	Economy	41500.00
0005435487884	6203	Economy	45700.00
0005435999457	6203	Economy	45700.00
0005434309906	6203	Economy	45700.00
0005435999458	6203	Economy	41500.00
0005435999463	6203	Economy	41500.00
0005435487810	6203	Economy	41500.00
0005435297094	6203	Economy	41500.00
0005434309910	6203	Economy	41500.00
0005435999459	6203	Economy	41500.00
0005432146224	6203	Economy	41500.00
0005435999475	6203	Economy	41500.00
0005435487801	6203	Economy	41500.00
0005435999461	6203	Economy	41500.00
0005435487947	6203	Economy	41500.00
0005435999474	6203	Economy	41500.00
0005435487809	6203	Economy	41500.00
0005434309912	6203	Economy	41500.00
0005434309916	6203	Economy	41500.00
0005434309913	6203	Economy	41500.00
0005435999460	6203	Economy	41500.00
0005434309911	6203	Economy	41500.00
0005435999465	6203	Economy	41500.00
0005435487866	6203	Economy	41500.00
0005435999472	6203	Economy	41500.00
0005434309914	6203	Economy	41500.00
0005435999469	6203	Economy	41500.00
0005435487901	6203	Economy	41500.00
0005435487846	6203	Economy	41500.00
0005435297086	6203	Economy	41500.00
0005435487871	6203	Economy	41500.00
0005435999464	6203	Economy	41500.00
0005435297085	6203	Economy	41500.00
0005435297096	6203	Economy	41500.00
0005435297098	6203	Economy	41500.00
0005435487931	6203	Economy	41500.00
0005435487932	6203	Economy	41500.00
0005434309908	6203	Economy	41500.00
0005435487982	6203	Economy	41500.00
0005434309907	6203	Economy	41500.00
0005435487938	6203	Economy	41500.00
0005434309918	6203	Economy	41500.00
0005432146223	6203	Economy	41500.00
0005435297073	6203	Economy	41500.00
0005435297083	6203	Economy	41500.00
0005435487912	6203	Economy	41500.00
0005435297042	6203	Economy	41500.00
0005435999316	19557	Business	124600.00
0005435488081	19557	Business	124600.00
0005435297147	19557	Business	124600.00
0005434309834	19557	Business	124600.00
0005434309833	19557	Business	124600.00
0005434309782	19557	Business	124600.00
0005435999300	19557	Business	124600.00
0005434309824	19557	Economy	41500.00
0005435488090	19557	Economy	41500.00
0005435488085	19557	Economy	41500.00
0005435488075	19557	Economy	41500.00
0005435488077	19557	Economy	41500.00
0005435999295	19557	Economy	41500.00
0005435999321	19557	Economy	41500.00
0005435488093	19557	Economy	41500.00
0005434309776	19557	Economy	41500.00
0005435488088	19557	Economy	41500.00
0005434309849	19557	Economy	41500.00
0005435999288	19557	Economy	41500.00
0005434309759	19557	Economy	41500.00
0005434309835	19557	Economy	41500.00
0005435999296	19557	Economy	41500.00
0005434309769	19557	Economy	41500.00
0005435488076	19557	Economy	41500.00
0005435999268	19557	Economy	41500.00
0005435488095	19557	Economy	41500.00
0005435488074	19557	Economy	41500.00
0005435999280	19557	Economy	41500.00
0005434309787	19557	Economy	41500.00
0005435488079	19557	Economy	45700.00
0005434309794	19557	Economy	45700.00
0005435488083	19557	Economy	45700.00
0005435999265	19557	Economy	41500.00
0005434309829	19557	Economy	41500.00
0005434309799	19557	Economy	41500.00
0005435488087	19557	Economy	41500.00
0005435297145	19557	Economy	41500.00
0005435488086	19557	Economy	41500.00
0005435297146	19557	Economy	41500.00
0005435999320	19557	Economy	41500.00
0005434309828	19557	Economy	41500.00
0005435999293	19557	Economy	41500.00
0005434309812	19557	Economy	41500.00
0005435297148	19557	Economy	41500.00
0005435488078	19557	Economy	41500.00
0005434309802	19557	Economy	41500.00
0005435488092	19557	Economy	41500.00
0005435488091	19557	Economy	41500.00
0005435999294	19557	Economy	41500.00
0005434309813	19557	Economy	41500.00
0005435297143	19557	Economy	41500.00
0005434309711	19557	Economy	41500.00
0005435488084	19557	Economy	41500.00
0005434309754	19557	Economy	41500.00
0005435297144	19557	Economy	41500.00
0005434309755	19557	Economy	41500.00
0005435297141	19557	Economy	41500.00
0005434309735	19557	Economy	41500.00
0005434309710	19557	Economy	41500.00
0005434309758	19557	Economy	41500.00
0005435488089	19557	Economy	41500.00
0005434309762	19557	Economy	41500.00
0005435488080	19557	Economy	41500.00
0005435488094	19557	Economy	41500.00
0005435999252	19557	Economy	41500.00
0005435297142	19557	Economy	41500.00
0005434309848	19557	Economy	41500.00
0005435488082	19557	Economy	41500.00
0005435502593	1586	Business	86000.00
0005435508501	1586	Business	86000.00
0005435502592	1586	Business	86000.00
0005434566077	1586	Business	86000.00
0005434566081	1586	Business	86000.00
0005434566086	1586	Business	86000.00
0005435518146	1586	Business	86000.00
0005434566079	1586	Business	86000.00
0005435508498	1586	Business	86000.00
0005434566085	1586	Business	86000.00
0005435502591	1586	Business	86000.00
0005435502585	1586	Business	86000.00
0005435508504	1586	Economy	28700.00
0005435502583	1586	Economy	28700.00
0005435508494	1586	Economy	28700.00
0005435518148	1586	Economy	28700.00
0005435518154	1586	Economy	28700.00
0005435502582	1586	Economy	28700.00
0005434566083	1586	Economy	28700.00
0005434566090	1586	Economy	28700.00
0005435502586	1586	Economy	28700.00
0005434566078	1586	Economy	31500.00
0005433186168	1586	Economy	31500.00
0005433186098	1586	Economy	31500.00
0005435502579	1586	Economy	31500.00
0005434566089	1586	Economy	31500.00
0005435502588	1586	Economy	28700.00
0005435518152	1586	Economy	28700.00
0005435518156	1586	Economy	28700.00
0005435518151	1586	Economy	28700.00
0005435518144	1586	Economy	28700.00
0005434566091	1586	Economy	28700.00
0005432291960	1586	Economy	28700.00
0005435518140	1586	Economy	28700.00
0005435518157	1586	Economy	28700.00
0005435518145	1586	Economy	28700.00
0005435502577	1586	Economy	28700.00
0005435508495	1586	Economy	28700.00
0005434566082	1586	Economy	28700.00
0005435518143	1586	Economy	28700.00
0005433186141	1586	Economy	28700.00
0005435518147	1586	Economy	28700.00
0005435508500	1586	Economy	28700.00
0005435502589	1586	Economy	28700.00
0005435508497	1586	Economy	28700.00
0005435518155	1586	Economy	28700.00
0005435508506	1586	Economy	28700.00
0005434566087	1586	Economy	28700.00
0005434566088	1586	Economy	28700.00
0005435502578	1586	Economy	28700.00
0005432291961	1586	Economy	28700.00
0005433186099	1586	Economy	28700.00
0005435502594	1586	Economy	28700.00
0005435508502	1586	Economy	28700.00
0005435518137	1586	Economy	28700.00
0005435502580	1586	Economy	28700.00
0005435518142	1586	Economy	28700.00
0005435518139	1586	Economy	28700.00
0005433186149	1586	Economy	28700.00
0005435508493	1586	Economy	28700.00
0005435518138	1586	Economy	28700.00
0005435518141	1586	Economy	28700.00
0005435508505	1586	Economy	28700.00
0005435502575	1586	Economy	28700.00
0005434566080	1586	Economy	28700.00
0005435518153	1586	Economy	28700.00
0005434566084	1586	Economy	28700.00
0005435518149	1586	Economy	28700.00
0005435502584	1586	Economy	28700.00
0005435502587	1586	Economy	28700.00
0005435508499	1586	Economy	28700.00
0005435508507	1586	Economy	28700.00
0005435502574	1586	Economy	28700.00
0005435502590	1586	Economy	28700.00
0005435518150	1586	Economy	28700.00
0005434566092	1586	Economy	28700.00
0005435508496	1586	Economy	28700.00
0005435502581	1586	Economy	28700.00
0005435508508	1586	Economy	28700.00
0005435508503	1586	Economy	28700.00
0005435518136	1586	Economy	28700.00
0005433186140	1586	Economy	28700.00
0005435502595	1586	Economy	28700.00
0005435502576	1586	Economy	28700.00
0005433186167	1586	Economy	28700.00
0005435502306	20902	Business	86000.00
0005435502430	20902	Business	86000.00
0005435502401	20902	Business	86000.00
0005435529317	20902	Business	86000.00
0005433186229	20902	Business	86000.00
0005435529230	20902	Business	86000.00
0005435502407	20902	Business	86000.00
0005435529212	20902	Business	86000.00
0005435529319	20902	Business	86000.00
0005435529307	20902	Business	86000.00
0005435502318	20902	Business	86000.00
0005435545757	20902	Economy	28700.00
0005435529250	20902	Economy	28700.00
0005434565987	20902	Economy	28700.00
0005435545791	20902	Economy	28700.00
0005433186224	20902	Economy	28700.00
0005435502409	20902	Economy	28700.00
0005433186222	20902	Economy	28700.00
0005434565989	20902	Economy	31500.00
0005435502365	20902	Economy	31500.00
0005435545756	20902	Economy	31500.00
0005435502416	20902	Economy	31500.00
0005435545724	20902	Economy	28700.00
0005435545759	20902	Economy	28700.00
0005435529312	20902	Economy	28700.00
0005435529347	20902	Economy	28700.00
0005435502307	20902	Economy	28700.00
0005435502454	20902	Economy	28700.00
0005435529252	20902	Economy	28700.00
0005434565962	20902	Economy	28700.00
0005435502296	20902	Economy	28700.00
0005433186228	20902	Economy	28700.00
0005435529320	20902	Economy	28700.00
0005435502455	20902	Economy	28700.00
0005435502415	20902	Economy	28700.00
0005433186225	20902	Economy	28700.00
0005435529226	20902	Economy	28700.00
0005435502378	20902	Economy	28700.00
0005435529288	20902	Economy	28700.00
0005435529330	20902	Economy	28700.00
0005435529305	20902	Economy	28700.00
0005435545750	20902	Economy	28700.00
0005433186223	20902	Economy	28700.00
0005434565928	20902	Economy	28700.00
0005435529306	20902	Economy	28700.00
0005434565979	20902	Economy	28700.00
0005435502377	20902	Economy	28700.00
0005435529227	20902	Economy	28700.00
0005435529287	20902	Economy	28700.00
0005434565978	20902	Economy	28700.00
0005435502408	20902	Economy	28700.00
0005435529289	20902	Economy	28700.00
0005435545760	20902	Economy	28700.00
0005435529328	20902	Economy	28700.00
0005435529266	20902	Economy	28700.00
0005435502433	20902	Economy	28700.00
0005434565965	20902	Economy	28700.00
0005435545747	20902	Economy	28700.00
0005435502434	20902	Economy	28700.00
0005435502325	20902	Economy	28700.00
0005433186230	20902	Economy	28700.00
0005435529256	20902	Economy	28700.00
0005435502372	20902	Economy	28700.00
0005434566007	20902	Economy	28700.00
0005435529251	20902	Economy	28700.00
0005435502414	20902	Economy	28700.00
0005435529311	20902	Economy	28700.00
0005433186227	20902	Economy	28700.00
0005434565988	20902	Economy	28700.00
0005433186226	20902	Economy	28700.00
0005435502324	20902	Economy	28700.00
0005435502316	20902	Economy	28700.00
0005435502373	20902	Economy	28700.00
0005435545749	20902	Economy	28700.00
0005435502469	20902	Economy	28700.00
0005435153822	3914	Economy	21600.00
0005435153823	3914	Economy	19700.00
0005435153825	3914	Economy	19700.00
0005435153826	3914	Economy	19700.00
0005435153824	3914	Economy	19700.00
0005435931617	3914	Economy	19700.00
0005435153827	3914	Economy	19700.00
0005435153828	3914	Economy	19700.00
0005435931626	3914	Economy	19700.00
0005435931635	3914	Economy	19700.00
0005435153759	21877	Economy	21600.00
0005435931647	21877	Economy	21600.00
0005435153768	21877	Economy	21600.00
0005435153770	21877	Economy	19700.00
0005435931648	21877	Economy	19700.00
0005435153760	21877	Economy	19700.00
0005435153767	21877	Economy	19700.00
0005435931649	21877	Economy	19700.00
0005435153753	21877	Economy	19700.00
0005435153769	21877	Economy	19700.00
0005432629040	7177	Economy	14300.00
0005435225629	7177	Economy	13000.00
0005432629032	7177	Economy	13000.00
0005432629029	7177	Economy	13000.00
0005432629036	7177	Economy	13000.00
0005432629039	7177	Economy	13000.00
0005435225613	7177	Economy	13000.00
0005435225645	7177	Economy	13000.00
0005435225584	7177	Economy	13000.00
0005432629037	7177	Economy	13000.00
0005432629031	7177	Economy	13000.00
0005432629030	7177	Economy	13000.00
0005435225567	7177	Economy	13000.00
0005435225622	7177	Economy	13000.00
0005432629038	7177	Economy	13000.00
0005432629026	7177	Economy	13000.00
0005432629027	7177	Economy	13000.00
0005435225634	7177	Economy	13000.00
0005432629028	7177	Economy	13000.00
0005435225643	7177	Economy	13000.00
0005432629033	7177	Economy	13000.00
0005435225644	7177	Economy	13000.00
0005435225614	7177	Economy	13000.00
0005432629034	7177	Economy	13000.00
0005432629025	7177	Economy	13000.00
0005432629035	7177	Economy	13000.00
0005435225583	7177	Economy	13000.00
0005432628908	28093	Economy	14300.00
0005435225688	28093	Economy	13000.00
0005435225687	28093	Economy	13000.00
0005432628889	28093	Economy	13000.00
0005435225686	28093	Economy	13000.00
0005432628924	28093	Economy	13000.00
0005432628934	28093	Economy	13000.00
0005432628926	28093	Economy	13000.00
0005432628933	28093	Economy	13000.00
0005432628863	28093	Economy	13000.00
0005435225685	28093	Economy	13000.00
0005435225684	28093	Economy	13000.00
0005435225682	28093	Economy	13000.00
0005432628948	28093	Economy	13000.00
0005435225689	28093	Economy	13000.00
0005432628927	28093	Economy	13000.00
0005432628923	28093	Economy	13000.00
0005432628873	28093	Economy	13000.00
0005432628906	28093	Economy	13000.00
0005435225683	28093	Economy	13000.00
0005432628907	28093	Economy	13000.00
0005434267961	8765	Economy	10500.00
0005435960098	8765	Economy	10500.00
0005434267950	8765	Economy	10500.00
0005435960097	8765	Economy	10500.00
0005434267962	8765	Economy	10500.00
0005435960099	8765	Economy	10500.00
0005434267976	8765	Economy	10500.00
0005434267949	8765	Economy	10500.00
0005434267998	15273	Economy	10500.00
0005435960062	15273	Economy	10500.00
0005435960060	15273	Economy	10500.00
0005434267997	15273	Economy	10500.00
0005435960059	15273	Economy	10500.00
0005434267999	15273	Economy	10500.00
0005435960076	15273	Economy	10500.00
0005435960075	15273	Economy	10500.00
0005434267996	15273	Economy	10500.00
0005434267995	15273	Economy	10500.00
0005432693436	1167	Business	115000.00
0005432675323	1167	Business	115000.00
0005432677619	1167	Business	115000.00
0005432693431	1167	Business	115000.00
0005432693428	1167	Business	115000.00
0005432693413	1167	Business	115000.00
0005432693433	1167	Business	115000.00
0005432693412	1167	Business	115000.00
0005432675320	1167	Business	115000.00
0005432693426	1167	Business	115000.00
0005432873303	1167	Business	115000.00
0005432675321	1167	Business	115000.00
0005432693422	1167	Business	115000.00
0005432693411	1167	Economy	38300.00
0005432675318	1167	Economy	38300.00
0005432873295	1167	Economy	38300.00
0005432693419	1167	Economy	38300.00
0005432693437	1167	Economy	38300.00
0005432693416	1167	Economy	38300.00
0005432693430	1167	Economy	42200.00
0005432675329	1167	Economy	42200.00
0005432873314	1167	Economy	42200.00
0005432677620	1167	Economy	38300.00
0005432675319	1167	Economy	38300.00
0005432873302	1167	Economy	38300.00
0005432675325	1167	Economy	38300.00
0005432693417	1167	Economy	38300.00
0005432677618	1167	Economy	38300.00
0005432873330	1167	Economy	38300.00
0005432693434	1167	Economy	38300.00
0005432675317	1167	Economy	38300.00
0005432693440	1167	Economy	38300.00
0005432693429	1167	Economy	38300.00
0005432693425	1167	Economy	38300.00
0005432693435	1167	Economy	38300.00
0005432693424	1167	Economy	38300.00
0005432873331	1167	Economy	38300.00
0005432675326	1167	Economy	38300.00
0005432675315	1167	Economy	38300.00
0005432693414	1167	Economy	38300.00
0005432675322	1167	Economy	38300.00
0005432675316	1167	Economy	38300.00
0005432693441	1167	Economy	38300.00
0005432693415	1167	Economy	38300.00
0005432873318	1167	Economy	38300.00
0005432693418	1167	Economy	38300.00
0005432693421	1167	Economy	38300.00
0005432693432	1167	Economy	38300.00
0005432675327	1167	Economy	38300.00
0005432675324	1167	Economy	38300.00
0005432693439	1167	Economy	38300.00
0005432677617	1167	Economy	38300.00
0005432693423	1167	Economy	38300.00
0005432693420	1167	Economy	38300.00
0005432675328	1167	Economy	38300.00
0005432693427	1167	Economy	38300.00
0005432693438	1167	Economy	38300.00
0005432693164	17455	Business	115000.00
0005432873382	17455	Business	115000.00
0005432675212	17455	Business	115000.00
0005432693226	17455	Business	115000.00
0005432873380	17455	Business	115000.00
0005432677585	17455	Business	115000.00
0005432693214	17455	Economy	38300.00
0005432693129	17455	Economy	38300.00
0005432675127	17455	Economy	38300.00
0005432693136	17455	Economy	38300.00
0005432693089	17455	Economy	38300.00
0005432693271	17455	Economy	38300.00
0005432675182	17455	Economy	42200.00
0005432693241	17455	Economy	42200.00
0005432693377	17455	Economy	42200.00
0005432693196	17455	Economy	38300.00
0005432675201	17455	Economy	42200.00
0005432693155	17455	Economy	38300.00
0005432675218	17455	Economy	38300.00
0005432675130	17455	Economy	38300.00
0005432693229	17455	Economy	38300.00
0005432693137	17455	Economy	38300.00
0005432693135	17455	Economy	38300.00
0005432693141	17455	Economy	38300.00
0005432873379	17455	Economy	38300.00
0005432675150	17455	Economy	38300.00
0005432873377	17455	Economy	38300.00
0005432873381	17455	Economy	38300.00
0005432675233	17455	Economy	38300.00
0005432675149	17455	Economy	38300.00
0005432693147	17455	Economy	38300.00
0005432693186	17455	Economy	38300.00
0005432693175	17455	Economy	38300.00
0005432675211	17455	Economy	38300.00
0005432693190	17455	Economy	38300.00
0005432693204	17455	Economy	38300.00
0005432873384	17455	Economy	38300.00
0005432693272	17455	Economy	38300.00
0005432675172	17455	Economy	38300.00
0005432693165	17455	Economy	38300.00
0005432693243	17455	Economy	38300.00
0005432693140	17455	Economy	38300.00
0005432693242	17455	Economy	38300.00
0005432693218	17455	Economy	38300.00
0005432693262	17455	Economy	38300.00
0005432873383	17455	Economy	38300.00
0005432693134	17455	Economy	38300.00
0005432675234	17455	Economy	38300.00
0005432675137	17455	Economy	38300.00
0005432675183	17455	Economy	38300.00
0005432873378	17455	Economy	38300.00
0005433156807	1112	Economy	15200.00
0005434435378	1112	Economy	15200.00
0005433156787	1112	Economy	15200.00
0005433156806	1112	Economy	15200.00
0005434435368	1112	Economy	13900.00
0005434435380	1112	Economy	13900.00
0005434435370	1112	Economy	13900.00
0005434435381	1112	Economy	13900.00
0005434435372	1112	Economy	13900.00
0005434435379	1112	Economy	13900.00
0005434435374	1112	Economy	13900.00
0005433156742	1112	Economy	13900.00
0005433156795	1112	Economy	13900.00
0005434435367	1112	Economy	13900.00
0005433156741	1112	Economy	13900.00
0005434435377	1112	Economy	13900.00
0005434435371	1112	Economy	13900.00
0005433156798	1112	Economy	13900.00
0005433156802	1112	Economy	13900.00
0005434435375	1112	Economy	13900.00
0005434435373	1112	Economy	13900.00
0005434435369	1112	Economy	13900.00
0005434435376	1112	Economy	13900.00
0005433156816	1112	Economy	13900.00
0005434435382	1112	Economy	13900.00
0005433156805	1112	Economy	13900.00
0005434435234	17304	Economy	15200.00
0005434435255	17304	Economy	15200.00
0005434435221	17304	Economy	15200.00
0005433156858	17304	Economy	13900.00
0005434435290	17304	Economy	13900.00
0005434435227	17304	Economy	13900.00
0005434435195	17304	Economy	13900.00
0005433156856	17304	Economy	13900.00
0005434435243	17304	Economy	13900.00
0005434435260	17304	Economy	13900.00
0005433156860	17304	Economy	13900.00
0005434435222	17304	Economy	13900.00
0005434435239	17304	Economy	13900.00
0005434435233	17304	Economy	13900.00
0005434435263	17304	Economy	13900.00
0005434435182	17304	Economy	13900.00
0005434435196	17304	Economy	13900.00
0005433156853	17304	Economy	13900.00
0005434435282	17304	Economy	13900.00
0005433156854	17304	Economy	13900.00
0005433156855	17304	Economy	13900.00
0005433156857	17304	Economy	13900.00
0005434435261	17304	Economy	13900.00
0005434435244	17304	Economy	13900.00
0005434435181	17304	Economy	13900.00
0005434435254	17304	Economy	13900.00
0005434435271	17304	Economy	13900.00
0005433156861	17304	Economy	13900.00
0005433156859	17304	Economy	13900.00
0005435086933	4052	Economy	7500.00
0005435086927	4052	Economy	7500.00
0005435086925	4052	Economy	7500.00
0005435086930	4052	Economy	7500.00
0005435086932	4052	Economy	7500.00
0005435928176	4052	Economy	7500.00
0005435086926	4052	Economy	7500.00
0005435086928	4052	Economy	7500.00
0005435086934	4052	Economy	7500.00
0005435086929	4052	Economy	7500.00
0005435928149	4052	Economy	7500.00
0005435928148	4052	Economy	7500.00
0005435086931	4052	Economy	7500.00
0005435086868	24381	Economy	7500.00
0005435086824	24381	Economy	7500.00
0005435928203	24381	Economy	7500.00
0005435928204	24381	Economy	7500.00
0005435086870	24381	Economy	7500.00
0005435086869	24381	Economy	7500.00
0005435928202	24381	Economy	7500.00
0005435928205	24381	Economy	7500.00
0005435928201	24381	Economy	7500.00
0005435086871	24381	Economy	7500.00
0005434964472	1311	Business	203300.00
0005434964478	1311	Business	203300.00
0005433261586	1311	Business	203300.00
0005433261531	1311	Business	203300.00
0005434964449	1311	Business	203300.00
0005433261610	1311	Business	203300.00
0005433261587	1311	Business	203300.00
0005433261620	1311	Business	203300.00
0005434964462	1311	Economy	74500.00
0005434964455	1311	Economy	74500.00
0005433261578	1311	Economy	67800.00
0005434964456	1311	Economy	67800.00
0005434964477	1311	Economy	67800.00
0005434964465	1311	Economy	67800.00
0005432279299	1311	Economy	67800.00
0005434964469	1311	Economy	67800.00
0005433261562	1311	Economy	67800.00
0005434964467	1311	Economy	67800.00
0005434964454	1311	Economy	67800.00
0005434964451	1311	Economy	67800.00
0005433261605	1311	Economy	67800.00
0005432279297	1311	Economy	67800.00
0005433261592	1311	Economy	67800.00
0005432279295	1311	Economy	67800.00
0005434964453	1311	Economy	67800.00
0005434964476	1311	Economy	67800.00
0005433261627	1311	Economy	67800.00
0005434964464	1311	Economy	67800.00
0005434964445	1311	Economy	67800.00
0005434964466	1311	Economy	67800.00
0005433261577	1311	Economy	67800.00
0005434964452	1311	Economy	67800.00
0005433261590	1311	Economy	67800.00
0005433261619	1311	Economy	67800.00
0005434964479	1311	Economy	67800.00
0005434964448	1311	Economy	67800.00
0005434964460	1311	Economy	67800.00
0005434964458	1311	Economy	67800.00
0005434964474	1311	Economy	74500.00
0005433261648	1311	Economy	74500.00
0005434964480	1311	Economy	67800.00
0005434964468	1311	Economy	67800.00
0005433261604	1311	Economy	67800.00
0005434964459	1311	Economy	67800.00
0005432279298	1311	Economy	67800.00
0005432279296	1311	Economy	67800.00
0005434964447	1311	Economy	67800.00
0005434964461	1311	Economy	67800.00
0005433261585	1311	Economy	67800.00
0005433261598	1311	Economy	67800.00
0005434964450	1311	Economy	67800.00
0005433261623	1311	Economy	67800.00
0005434964442	1311	Economy	67800.00
0005433261597	1311	Economy	67800.00
0005433261594	1311	Economy	67800.00
0005434964471	1311	Economy	67800.00
0005434964443	1311	Economy	67800.00
0005434964457	1311	Economy	67800.00
0005434964470	1311	Economy	67800.00
0005434964475	1311	Economy	67800.00
0005434964444	1311	Economy	67800.00
0005433261611	1311	Economy	67800.00
0005434964473	1311	Economy	67800.00
0005434964463	1311	Economy	67800.00
0005434964446	1311	Economy	67800.00
0005433261690	18252	Business	203300.00
0005434964271	18252	Business	203300.00
0005434964249	18252	Business	203300.00
0005433261699	18252	Business	203300.00
0005434964309	18252	Business	203300.00
0005433261697	18252	Business	203300.00
0005433261687	18252	Business	203300.00
0005434964300	18252	Business	203300.00
0005434964170	18252	Business	203300.00
0005434964246	18252	Economy	74500.00
0005434964247	18252	Business	203300.00
0005434964276	18252	Economy	67800.00
0005433261689	18252	Economy	67800.00
0005434964209	18252	Economy	67800.00
0005434964277	18252	Economy	67800.00
0005434964272	18252	Economy	67800.00
0005434964265	18252	Economy	67800.00
0005434964299	18252	Economy	67800.00
0005434964297	18252	Economy	67800.00
0005434964281	18252	Economy	67800.00
0005434964319	18252	Economy	67800.00
0005434964169	18252	Economy	67800.00
0005434964225	18252	Economy	67800.00
0005434964298	18252	Economy	67800.00
0005433261684	18252	Economy	67800.00
0005433261698	18252	Economy	67800.00
0005433261686	18252	Economy	67800.00
0005433261695	18252	Economy	67800.00
0005433261691	18252	Economy	67800.00
0005434964288	18252	Economy	67800.00
0005434964343	18252	Economy	67800.00
0005434964295	18252	Economy	74500.00
0005433261681	18252	Economy	74500.00
0005434964226	18252	Economy	67800.00
0005434964245	18252	Economy	67800.00
0005434964296	18252	Economy	67800.00
0005434964287	18252	Economy	67800.00
0005434964349	18252	Economy	67800.00
0005434964168	18252	Economy	67800.00
0005433261685	18252	Economy	67800.00
0005434964285	18252	Economy	67800.00
0005434964275	18252	Economy	67800.00
0005433261683	18252	Economy	67800.00
0005434964264	18252	Economy	67800.00
0005434964330	18252	Economy	67800.00
0005433261688	18252	Economy	67800.00
0005434964259	18252	Economy	67800.00
0005434964279	18252	Economy	67800.00
0005434964248	18252	Economy	67800.00
0005433261682	18252	Economy	67800.00
0005433261694	18252	Economy	67800.00
0005434964308	18252	Economy	67800.00
0005433261696	18252	Economy	67800.00
0005434964304	18252	Economy	67800.00
0005434964278	18252	Economy	67800.00
0005433261693	18252	Economy	67800.00
0005434964331	18252	Economy	67800.00
0005433261692	18252	Economy	67800.00
0005434626080	4856	Business	44200.00
0005433194860	4856	Economy	14700.00
0005434626084	4856	Economy	14700.00
0005435907534	4856	Economy	14700.00
0005434626082	4856	Economy	14700.00
0005434626079	4856	Economy	14700.00
0005435907539	4856	Economy	14700.00
0005434626083	4856	Economy	14700.00
0005434626076	4856	Economy	14700.00
0005434626078	4856	Economy	14700.00
0005434626081	4856	Economy	14700.00
0005435907533	4856	Economy	14700.00
0005433194853	4856	Economy	14700.00
0005433194854	4856	Economy	14700.00
0005434626077	4856	Economy	14700.00
0005433194893	32896	Business	44200.00
0005433194894	32896	Business	44200.00
0005435907563	32896	Economy	14700.00
0005434626012	32896	Economy	14700.00
0005435907568	32896	Economy	14700.00
0005434626013	32896	Economy	14700.00
0005434626001	32896	Economy	14700.00
0005433194892	32896	Economy	14700.00
0005435907565	32896	Economy	14700.00
0005435907567	32896	Economy	14700.00
0005435907564	32896	Economy	14700.00
0005435907566	32896	Economy	14700.00
0005434626007	32896	Economy	14700.00
0005434626015	32896	Economy	14700.00
0005433194895	32896	Economy	14700.00
0005434625986	32896	Economy	14700.00
0005434626016	32896	Economy	14700.00
0005433194897	32896	Economy	14700.00
0005433194896	32896	Economy	14700.00
0005434626005	32896	Economy	14700.00
0005435785495	13770	Economy	3400.00
0005435785377	13770	Economy	3400.00
0005435785452	13770	Economy	3400.00
0005435785520	13770	Economy	3400.00
0005435785496	13770	Economy	3100.00
0005435787363	13770	Economy	3100.00
0005435785484	13770	Economy	3100.00
0005435937439	13770	Economy	3100.00
0005435785540	13770	Economy	3100.00
0005435785394	13770	Economy	3100.00
0005435785409	13770	Economy	3100.00
0005435785319	13770	Economy	3100.00
0005435785396	13770	Economy	3100.00
0005435785363	13770	Economy	3100.00
0005432195719	13770	Economy	3100.00
0005435785431	13770	Economy	3100.00
0005435785466	13770	Economy	3100.00
0005435937438	13770	Economy	3100.00
0005435785387	13770	Economy	3100.00
0005435785398	13770	Economy	3100.00
0005435785441	13770	Economy	3100.00
0005435785485	13770	Economy	3100.00
0005435785372	13770	Economy	3100.00
0005435785400	13770	Economy	3100.00
0005435785567	13770	Economy	3100.00
0005435785401	13770	Economy	3100.00
0005435785320	13770	Economy	3100.00
0005435787365	13770	Economy	3100.00
0005435937437	13770	Economy	3100.00
0005435787355	13770	Economy	3100.00
0005435785348	13770	Economy	3100.00
0005435785558	13770	Economy	3100.00
0005435785468	13770	Economy	3100.00
0005435785499	13770	Economy	3100.00
0005435785397	13770	Economy	3100.00
0005435785259	13770	Economy	3100.00
0005435785455	13770	Economy	3100.00
0005435785471	13770	Economy	3100.00
0005432195718	13770	Economy	3100.00
0005435785347	13770	Economy	3100.00
0005435787364	13770	Economy	3100.00
0005435785393	13770	Economy	3100.00
0005435785503	13770	Economy	3100.00
0005435785364	13770	Economy	3100.00
0005435785430	13770	Economy	3100.00
0005435785417	13770	Economy	3100.00
0005435785399	13770	Economy	3100.00
0005435785376	13770	Economy	3100.00
0005432195720	13770	Economy	3100.00
0005435785752	27437	Economy	3400.00
0005435785739	27437	Economy	3400.00
0005435785723	27437	Economy	3400.00
0005435785729	27437	Economy	3100.00
0005435785742	27437	Economy	3100.00
0005435785753	27437	Economy	3100.00
0005435785735	27437	Economy	3100.00
0005435785749	27437	Economy	3100.00
0005435785732	27437	Economy	3100.00
0005435937389	27437	Economy	3100.00
0005435787379	27437	Economy	3100.00
0005435785751	27437	Economy	3100.00
0005435785720	27437	Economy	3100.00
0005435785740	27437	Economy	3100.00
0005435785745	27437	Economy	3100.00
0005435785736	27437	Economy	3100.00
0005435785747	27437	Economy	3100.00
0005432190672	27437	Economy	3100.00
0005435785728	27437	Economy	3100.00
0005432190671	27437	Economy	3100.00
0005435785725	27437	Economy	3100.00
0005435785721	27437	Economy	3100.00
0005432190673	27437	Economy	3100.00
0005435785733	27437	Economy	3100.00
0005435785727	27437	Economy	3100.00
0005435785731	27437	Economy	3100.00
0005435785746	27437	Economy	3100.00
0005435785744	27437	Economy	3100.00
0005435785737	27437	Economy	3100.00
0005435785741	27437	Economy	3100.00
0005435785724	27437	Economy	3100.00
0005435787377	27437	Economy	3100.00
0005435785730	27437	Economy	3100.00
0005435787378	27437	Economy	3100.00
0005435785743	27437	Economy	3100.00
0005435785722	27437	Economy	3100.00
0005435785734	27437	Economy	3100.00
0005435785726	27437	Economy	3100.00
0005435785750	27437	Economy	3100.00
0005435937380	27437	Economy	3100.00
0005435785755	27437	Economy	3100.00
0005432190670	27437	Economy	3100.00
0005435785754	27437	Economy	3100.00
0005432190674	27437	Economy	3100.00
0005435785738	27437	Economy	3100.00
0005435785748	27437	Economy	3100.00
0005434407543	20252	Business	12000.00
0005434408174	20252	Business	12000.00
0005434408029	20252	Business	12000.00
0005434407785	20252	Business	12000.00
0005434407810	20252	Business	12000.00
0005434408072	20252	Business	12000.00
0005434408061	20252	Business	12000.00
0005434407983	20252	Business	12000.00
0005434407671	20252	Business	12000.00
0005434408198	20252	Business	12000.00
0005434407904	20252	Business	12000.00
0005434407847	20252	Economy	4000.00
0005434408200	20252	Economy	4000.00
0005434408213	20252	Economy	4000.00
0005434407932	20252	Economy	4000.00
0005434407947	20252	Economy	4000.00
0005434407903	20252	Economy	4000.00
0005434407807	20252	Economy	4000.00
0005434407756	20252	Economy	4000.00
0005435311223	20252	Economy	4400.00
0005434407829	20252	Economy	4400.00
0005434407809	20252	Economy	4400.00
0005434408203	20252	Economy	4400.00
0005434408045	20252	Economy	4400.00
0005432058432	20252	Economy	4000.00
0005434407729	20252	Economy	4000.00
0005434407616	20252	Economy	4000.00
0005434407945	20252	Economy	4000.00
0005435311220	20252	Economy	4000.00
0005434408046	20252	Economy	4000.00
0005434407918	20252	Economy	4000.00
0005434407949	20252	Economy	4000.00
0005434408042	20252	Economy	4000.00
0005434408201	20252	Economy	4000.00
0005434408205	20252	Economy	4000.00
0005434408060	20252	Economy	4000.00
0005432058431	20252	Economy	4000.00
0005434407952	20252	Economy	4000.00
0005434408206	20252	Economy	4000.00
0005435311222	20252	Economy	4000.00
0005434407757	20252	Economy	4000.00
0005432058430	20252	Economy	4000.00
0005434407670	20252	Economy	4000.00
0005434408053	20252	Economy	4000.00
0005434408287	20252	Economy	4000.00
0005434408055	20252	Economy	4000.00
0005435311225	20252	Economy	4000.00
0005434408212	20252	Economy	4000.00
0005434408033	20252	Economy	4000.00
0005434407770	20252	Economy	4000.00
0005435311221	20252	Economy	4000.00
0005434407808	20252	Economy	4000.00
0005434408288	20252	Economy	4000.00
0005434408015	20252	Economy	4000.00
0005434407997	20252	Economy	4000.00
0005434407933	20252	Economy	4000.00
0005434408214	20252	Economy	4000.00
0005434407973	20252	Economy	4000.00
0005434407706	20252	Economy	4000.00
0005434408030	20252	Economy	4000.00
0005434408067	20252	Economy	4000.00
0005434408172	20252	Economy	4000.00
0005434408182	20252	Economy	4000.00
0005434408000	20252	Economy	4000.00
0005434408211	20252	Economy	4000.00
0005434407811	20252	Economy	4000.00
0005434408196	20252	Economy	4000.00
0005434408185	20252	Economy	4000.00
0005434408173	20252	Economy	4000.00
0005434408068	20252	Economy	4000.00
0005434407946	20252	Economy	4000.00
0005434408157	20252	Economy	4000.00
0005434408034	20252	Economy	4000.00
0005434407863	20252	Economy	4000.00
0005434407862	20252	Economy	4000.00
0005434407786	20252	Economy	4000.00
0005434407978	20252	Economy	4000.00
0005434408043	20252	Economy	4000.00
0005435311224	20252	Economy	4000.00
0005434408555	27008	Business	12000.00
0005434408544	27008	Business	12000.00
0005435311084	27008	Business	12000.00
0005434408524	27008	Business	12000.00
0005435311096	27008	Business	12000.00
0005435311043	27008	Business	12000.00
0005435311068	27008	Business	12000.00
0005434408576	27008	Business	12000.00
0005434408547	27008	Business	12000.00
0005434408573	27008	Business	12000.00
0005434408527	27008	Economy	4000.00
0005434408551	27008	Economy	4000.00
0005434408561	27008	Economy	4000.00
0005435311082	27008	Economy	4000.00
0005434408562	27008	Economy	4000.00
0005434408570	27008	Economy	4000.00
0005434408558	27008	Economy	4000.00
0005434408574	27008	Economy	4000.00
0005434408537	27008	Economy	4000.00
0005435311081	27008	Economy	4000.00
0005434408522	27008	Economy	4400.00
0005434408523	27008	Economy	4400.00
0005434408543	27008	Economy	4400.00
0005434408528	27008	Economy	4400.00
0005434408532	27008	Economy	4400.00
0005434408566	27008	Economy	4000.00
0005434408538	27008	Economy	4000.00
0005432154025	27008	Economy	4000.00
0005434408515	27008	Economy	4000.00
0005434408549	27008	Economy	4000.00
0005434408525	27008	Economy	4000.00
0005434408559	27008	Economy	4000.00
0005435311077	27008	Economy	4000.00
0005432154024	27008	Economy	4000.00
0005434408512	27008	Economy	4000.00
0005434408548	27008	Economy	4000.00
0005432154028	27008	Economy	4000.00
0005434408569	27008	Economy	4000.00
0005432154026	27008	Economy	4000.00
0005434408521	27008	Economy	4000.00
0005434408567	27008	Economy	4000.00
0005434408530	27008	Economy	4000.00
0005432154021	27008	Economy	4000.00
0005434408513	27008	Economy	4000.00
0005434408552	27008	Economy	4000.00
0005434408568	27008	Economy	4000.00
0005434408542	27008	Economy	4000.00
0005435311058	27008	Economy	4000.00
0005434408572	27008	Economy	4000.00
0005434408550	27008	Economy	4000.00
0005434408520	27008	Economy	4000.00
0005435311069	27008	Economy	4000.00
0005434408535	27008	Economy	4000.00
0005434408540	27008	Economy	4000.00
0005434408526	27008	Economy	4000.00
0005434408563	27008	Economy	4000.00
0005434408564	27008	Economy	4000.00
0005434408533	27008	Economy	4000.00
0005432154023	27008	Economy	4000.00
0005434408536	27008	Economy	4000.00
0005434408531	27008	Economy	4000.00
0005434408514	27008	Economy	4000.00
0005434408545	27008	Economy	4000.00
0005434408546	27008	Economy	4000.00
0005434408560	27008	Economy	4000.00
0005432154022	27008	Economy	4000.00
0005434408554	27008	Economy	4000.00
0005434408519	27008	Economy	4000.00
0005432154027	27008	Economy	4000.00
0005434408534	27008	Economy	4000.00
0005434408529	27008	Economy	4000.00
0005434408541	27008	Economy	4000.00
0005434408539	27008	Economy	4000.00
0005434408575	27008	Economy	4000.00
0005434408517	27008	Economy	4000.00
0005434408556	27008	Economy	4000.00
0005434408565	27008	Economy	4000.00
0005434408557	27008	Economy	4000.00
0005434408571	27008	Economy	4000.00
0005435311044	27008	Economy	4000.00
0005434408518	27008	Economy	4000.00
0005434408516	27008	Economy	4000.00
0005434408553	27008	Economy	4000.00
0005433123959	5725	Business	43300.00
0005433123994	5725	Business	43300.00
0005433123945	5725	Business	43300.00
0005433123974	5725	Business	43300.00
0005433124042	5725	Business	43300.00
0005433124046	5725	Business	43300.00
0005433123946	5725	Economy	14400.00
0005433123920	5725	Economy	15900.00
0005432109738	5725	Economy	15900.00
0005433123981	5725	Economy	15900.00
0005433124041	5725	Economy	14400.00
0005433123975	5725	Economy	14400.00
0005432109736	5725	Economy	14400.00
0005433124037	5725	Economy	14400.00
0005433123983	5725	Economy	14400.00
0005433124028	5725	Economy	14400.00
0005433123958	5725	Economy	14400.00
0005433124057	5725	Economy	14400.00
0005433124050	5725	Economy	14400.00
0005433123984	5725	Economy	14400.00
0005433124105	5725	Economy	14400.00
0005433124038	5725	Economy	14400.00
0005433123995	5725	Economy	14400.00
0005433123929	5725	Economy	14400.00
0005433123998	5725	Economy	14400.00
0005433124021	5725	Economy	14400.00
0005433124027	5725	Economy	14400.00
0005433123928	5725	Economy	14400.00
0005433124095	5725	Economy	14400.00
0005433124040	5725	Economy	14400.00
0005433123964	5725	Economy	14400.00
0005433124043	5725	Economy	14400.00
0005433123992	5725	Economy	14400.00
0005433124025	5725	Economy	14400.00
0005433124024	5725	Economy	14400.00
0005433124003	5725	Economy	14400.00
0005433123982	5725	Economy	14400.00
0005433123919	5725	Economy	14400.00
0005433124022	5725	Economy	14400.00
0005433123961	5725	Economy	14400.00
0005433123918	5725	Economy	14400.00
0005433123993	5725	Economy	14400.00
0005432109737	5725	Economy	14400.00
0005433123987	5725	Economy	14400.00
0005433124051	5725	Economy	14400.00
0005433123960	5725	Economy	14400.00
0005434319416	15657	Business	43300.00
0005433124188	15657	Business	43300.00
0005434319460	15657	Business	43300.00
0005434319453	15657	Business	43300.00
0005434319452	15657	Business	43300.00
0005434312323	15657	Business	43300.00
0005434319465	15657	Economy	14400.00
0005434319485	15657	Economy	14400.00
0005433124183	15657	Economy	14400.00
0005434319535	15657	Economy	14400.00
0005433124193	15657	Economy	15900.00
0005433124192	15657	Economy	15900.00
0005433124199	15657	Economy	14400.00
0005433124196	15657	Economy	14400.00
0005434319442	15657	Economy	14400.00
0005434312324	15657	Economy	14400.00
0005434319443	15657	Economy	14400.00
0005434319339	15657	Economy	14400.00
0005433124200	15657	Economy	14400.00
0005434319456	15657	Economy	14400.00
0005434319464	15657	Economy	14400.00
0005433124182	15657	Economy	14400.00
0005433124186	15657	Economy	14400.00
0005433124178	15657	Economy	14400.00
0005433124191	15657	Economy	14400.00
0005433124198	15657	Economy	14400.00
0005434319417	15657	Economy	14400.00
0005433124195	15657	Economy	14400.00
0005433124180	15657	Economy	14400.00
0005433124185	15657	Economy	14400.00
0005433124181	15657	Economy	14400.00
0005433124189	15657	Economy	14400.00
0005434319438	15657	Economy	14400.00
0005433124201	15657	Economy	14400.00
0005433124184	15657	Economy	14400.00
0005434319437	15657	Economy	14400.00
0005434319338	15657	Economy	14400.00
0005433124187	15657	Economy	14400.00
0005434319410	15657	Economy	14400.00
0005433124197	15657	Economy	14400.00
0005433124179	15657	Economy	14400.00
0005433124190	15657	Economy	14400.00
0005433124194	15657	Economy	14400.00
0005434319454	15657	Economy	14400.00
0005435221518	24972	Economy	15500.00
0005435220322	24972	Economy	15500.00
0005435220328	24972	Economy	15500.00
0005435220312	24972	Economy	15500.00
0005435217714	24972	Economy	15500.00
0005435217715	24972	Economy	15500.00
0005435221517	24972	Economy	15500.00
0005434189215	9006	Economy	24900.00
0005434484428	9006	Economy	24900.00
0005434484432	9006	Economy	24900.00
0005434484430	9006	Economy	24900.00
0005434189216	9006	Economy	24900.00
0005434189183	9006	Economy	24900.00
0005434484431	9006	Economy	24900.00
0005434189182	9006	Economy	24900.00
0005434189184	9006	Economy	24900.00
0005434484429	9006	Economy	24900.00
0005434189188	9006	Economy	24900.00
0005434189200	9006	Economy	24900.00
0005434189214	9006	Economy	24900.00
0005434189217	9006	Economy	24900.00
0005434484383	16656	Economy	27400.00
0005434189251	16656	Economy	27400.00
0005434189252	16656	Economy	24900.00
0005434189248	16656	Economy	24900.00
0005434484384	16656	Economy	24900.00
0005434484410	16656	Economy	24900.00
0005434189250	16656	Economy	24900.00
0005434484403	16656	Economy	24900.00
0005434189249	16656	Economy	24900.00
0005434484352	16656	Economy	24900.00
0005434189247	16656	Economy	24900.00
0005434484369	16656	Economy	24900.00
0005434484402	16656	Economy	24900.00
0005433124189	7637	Business	11100.00
0005433124197	7637	Business	11100.00
0005433124185	7637	Business	11100.00
0005433124192	7637	Economy	3700.00
0005433722209	7637	Economy	4100.00
0005433722226	7637	Economy	4100.00
0005433124201	7637	Economy	4100.00
0005433124183	7637	Economy	3700.00
0005433124200	7637	Economy	3700.00
0005433124190	7637	Economy	3700.00
0005433124191	7637	Economy	3700.00
0005433722223	7637	Economy	3700.00
0005433124188	7637	Economy	3700.00
0005433124194	7637	Economy	3700.00
0005433124187	7637	Economy	3700.00
0005433124178	7637	Economy	3700.00
0005433124180	7637	Economy	3700.00
0005433124196	7637	Economy	3700.00
0005433124195	7637	Economy	3700.00
0005433124198	7637	Economy	3700.00
0005433124184	7637	Economy	3700.00
0005433722222	7637	Economy	3700.00
0005433124181	7637	Economy	3700.00
0005433124186	7637	Economy	3700.00
0005433124199	7637	Economy	3700.00
0005433124193	7637	Economy	3700.00
0005433124182	7637	Economy	3700.00
0005433124179	7637	Economy	3700.00
0005432693442	7639	Business	11100.00
0005432721241	7639	Business	11100.00
0005432693443	7639	Business	11100.00
0005433450245	7639	Business	11100.00
0005432693455	7639	Business	11100.00
0005433450240	7639	Business	11100.00
0005432721250	7639	Business	11100.00
0005433450247	7639	Business	11100.00
0005432721226	7639	Business	11100.00
0005433450236	7639	Business	11100.00
0005432721239	7639	Business	11100.00
0005432721249	7639	Economy	3700.00
0005433450244	7639	Economy	3700.00
0005432071610	7639	Economy	3700.00
0005432721228	7639	Economy	3700.00
0005432693458	7639	Economy	3700.00
0005432071611	7639	Economy	3700.00
0005432721251	7639	Economy	3700.00
0005432721233	7639	Economy	3700.00
0005432721237	7639	Economy	3700.00
0005432693461	7639	Economy	3700.00
0005432693468	7639	Economy	4100.00
0005432693464	7639	Economy	4100.00
0005432721247	7639	Economy	4100.00
0005432693462	7639	Economy	4100.00
0005433450242	7639	Economy	3700.00
0005432693456	7639	Economy	3700.00
0005433450249	7639	Economy	3700.00
0005432721227	7639	Economy	3700.00
0005432693447	7639	Economy	3700.00
0005432693454	7639	Economy	3700.00
0005433450229	7639	Economy	3700.00
0005432721246	7639	Economy	3700.00
0005433450246	7639	Economy	3700.00
0005433450234	7639	Economy	3700.00
0005433450232	7639	Economy	3700.00
0005432721245	7639	Economy	3700.00
0005433450243	7639	Economy	3700.00
0005432721238	7639	Economy	3700.00
0005432721229	7639	Economy	3700.00
0005432071609	7639	Economy	3700.00
0005432693472	7639	Economy	3700.00
0005432693460	7639	Economy	3700.00
0005432721236	7639	Economy	3700.00
0005433450250	7639	Economy	3700.00
0005432693445	7639	Economy	3700.00
0005432693453	7639	Economy	3700.00
0005432721231	7639	Economy	3700.00
0005432721240	7639	Economy	3700.00
0005432693449	7639	Economy	3700.00
0005433450230	7639	Economy	3700.00
0005432721230	7639	Economy	3700.00
0005433450238	7639	Economy	3700.00
0005432721243	7639	Economy	3700.00
0005433450251	7639	Economy	3700.00
0005433450233	7639	Economy	3700.00
0005432721248	7639	Economy	3700.00
0005432721242	7639	Economy	3700.00
0005432721235	7639	Economy	3700.00
0005432693473	7639	Economy	3700.00
0005432693450	7639	Economy	3700.00
0005432693466	7639	Economy	3700.00
0005432693465	7639	Economy	3700.00
0005433450231	7639	Economy	3700.00
0005432693470	7639	Economy	3700.00
0005432071612	7639	Economy	3700.00
0005432693469	7639	Economy	3700.00
0005432721244	7639	Economy	3700.00
0005432693471	7639	Economy	3700.00
0005432693463	7639	Economy	3700.00
0005433450239	7639	Economy	3700.00
0005433450235	7639	Economy	3700.00
0005432693457	7639	Economy	3700.00
0005432693467	7639	Economy	3700.00
0005432693459	7639	Economy	3700.00
0005433450248	7639	Economy	3700.00
0005432721234	7639	Economy	3700.00
0005432693452	7639	Economy	3700.00
0005433450241	7639	Economy	3700.00
0005432693448	7639	Economy	3700.00
0005432693451	7639	Economy	3700.00
0005433450237	7639	Economy	3700.00
0005432693444	7639	Economy	3700.00
0005432693446	7639	Economy	3700.00
0005432721232	7639	Economy	3700.00
0005432693229	30346	Business	11100.00
0005432693155	30346	Business	11100.00
0005432693147	30346	Business	11100.00
0005433449950	30346	Business	11100.00
0005433449990	30346	Economy	3700.00
0005433449949	30346	Economy	3700.00
0005432693135	30346	Economy	3700.00
0005433450026	30346	Economy	3700.00
0005433450106	30346	Economy	3700.00
0005433450029	30346	Economy	3700.00
0005432693377	30346	Economy	3700.00
0005432693089	30346	Economy	4100.00
0005432693241	30346	Economy	4100.00
0005432693165	30346	Economy	4100.00
0005432693137	30346	Economy	3700.00
0005432693141	30346	Economy	3700.00
0005432693271	30346	Economy	3700.00
0005432693204	30346	Economy	3700.00
0005432693129	30346	Economy	3700.00
0005432693272	30346	Economy	3700.00
0005432693140	30346	Economy	3700.00
0005433450096	30346	Economy	3700.00
0005432693190	30346	Economy	3700.00
0005433450054	30346	Economy	3700.00
0005432693214	30346	Economy	3700.00
0005433450079	30346	Economy	3700.00
0005432693262	30346	Economy	3700.00
0005432693164	30346	Economy	3700.00
0005433449928	30346	Economy	3700.00
0005433450003	30346	Economy	3700.00
0005432693136	30346	Economy	3700.00
0005432693175	30346	Economy	3700.00
0005433450046	30346	Economy	3700.00
0005432693243	30346	Economy	3700.00
0005433449971	30346	Economy	3700.00
0005433450071	30346	Economy	3700.00
0005432693134	30346	Economy	3700.00
0005432693226	30346	Economy	3700.00
0005432693186	30346	Economy	3700.00
0005433450075	30346	Economy	3700.00
0005433450082	30346	Economy	3700.00
0005432693242	30346	Economy	3700.00
0005433450097	30346	Economy	3700.00
0005433450027	30346	Economy	3700.00
0005433450025	30346	Economy	3700.00
0005432693196	30346	Economy	3700.00
0005433450116	30346	Economy	3700.00
0005433450055	30346	Economy	3700.00
0005433450078	30346	Economy	3700.00
0005433450086	30346	Economy	3700.00
0005432693218	30346	Economy	3700.00
0005432720983	30347	Business	11100.00
0005433124095	30347	Business	11100.00
0005433124040	30347	Business	11100.00
0005433124037	30347	Business	11100.00
0005432720920	30347	Business	11100.00
0005432721089	30347	Business	11100.00
0005432720954	30347	Business	11100.00
0005432721030	30347	Business	11100.00
0005432721150	30347	Business	11100.00
0005432721099	30347	Business	11100.00
0005432721104	30347	Economy	3700.00
0005433123961	30347	Economy	3700.00
0005432721052	30347	Economy	3700.00
0005433123974	30347	Economy	3700.00
0005433123983	30347	Economy	3700.00
0005432721029	30347	Economy	3700.00
0005432720973	30347	Economy	3700.00
0005433124024	30347	Economy	3700.00
0005433722305	30347	Economy	3700.00
0005432721097	30347	Economy	3700.00
0005433124105	30347	Economy	4100.00
0005433124038	30347	Economy	4100.00
0005432720919	30347	Economy	4100.00
0005433124041	30347	Economy	4100.00
0005433124043	30347	Economy	4100.00
0005432721084	30347	Economy	3700.00
0005433123993	30347	Economy	3700.00
0005433123960	30347	Economy	3700.00
0005433722306	30347	Economy	3700.00
0005432720989	30347	Economy	3700.00
0005433123918	30347	Economy	3700.00
0005432721103	30347	Economy	3700.00
0005432720955	30347	Economy	3700.00
0005433123920	30347	Economy	3700.00
0005432720960	30347	Economy	3700.00
0005432721149	30347	Economy	3700.00
0005433124046	30347	Economy	3700.00
0005433124027	30347	Economy	3700.00
0005433123945	30347	Economy	3700.00
0005432721083	30347	Economy	3700.00
0005433123959	30347	Economy	3700.00
0005433123995	30347	Economy	3700.00
0005433123928	30347	Economy	3700.00
0005432720967	30347	Economy	3700.00
0005432720968	30347	Economy	3700.00
0005432720971	30347	Economy	3700.00
0005433123984	30347	Economy	3700.00
0005433124003	30347	Economy	3700.00
0005432721092	30347	Economy	3700.00
0005433124051	30347	Economy	3700.00
0005432721039	30347	Economy	3700.00
0005432720987	30347	Economy	3700.00
0005433123992	30347	Economy	3700.00
0005432720958	30347	Economy	3700.00
0005432720993	30347	Economy	3700.00
0005432720921	30347	Economy	3700.00
0005433124025	30347	Economy	3700.00
0005433722303	30347	Economy	3700.00
0005432720979	30347	Economy	3700.00
0005433124028	30347	Economy	3700.00
0005432721093	30347	Economy	3700.00
0005432720959	30347	Economy	3700.00
0005433123964	30347	Economy	3700.00
0005433722304	30347	Economy	3700.00
0005433124022	30347	Economy	3700.00
0005432720916	30347	Economy	3700.00
0005433124042	30347	Economy	3700.00
0005433123919	30347	Economy	3700.00
0005433123998	30347	Economy	3700.00
0005433722308	30347	Economy	3700.00
0005433123982	30347	Economy	3700.00
0005433123958	30347	Economy	3700.00
0005432720914	30347	Economy	3700.00
0005433123981	30347	Economy	3700.00
0005433123987	30347	Economy	3700.00
0005432720974	30347	Economy	3700.00
0005433123946	30347	Economy	3700.00
0005432720904	30347	Economy	3700.00
0005433124050	30347	Economy	3700.00
0005433722307	30347	Economy	3700.00
0005433123975	30347	Economy	3700.00
0005432721082	30347	Economy	3700.00
0005433124021	30347	Economy	3700.00
0005433123994	30347	Economy	3700.00
0005432721105	30347	Economy	3700.00
0005433124057	30347	Economy	3700.00
0005432721067	30347	Economy	3700.00
0005433123929	30347	Economy	3700.00
0005434586941	1377	Business	70400.00
0005433193127	1377	Business	70400.00
0005433525178	1377	Business	70400.00
0005433724862	1377	Business	70400.00
0005433525180	1377	Business	70400.00
0005434586921	1377	Business	70400.00
0005434586934	1377	Business	70400.00
0005434586937	1377	Economy	23500.00
0005433193123	1377	Economy	23500.00
0005433193140	1377	Economy	23500.00
0005432928007	1377	Economy	23500.00
0005433193150	1377	Economy	23500.00
0005434586925	1377	Economy	23500.00
0005432271040	1377	Economy	23500.00
0005434586930	1377	Economy	25800.00
0005434586928	1377	Economy	25800.00
0005434586926	1377	Economy	25800.00
0005433525171	1377	Economy	25800.00
0005433193110	1377	Economy	25800.00
0005434586920	1377	Economy	23500.00
0005432928008	1377	Economy	23500.00
0005434515001	1377	Economy	23500.00
0005434513612	1377	Economy	23500.00
0005433193167	1377	Economy	23500.00
0005432968857	1377	Economy	23500.00
0005434586935	1377	Economy	23500.00
0005434586942	1377	Economy	23500.00
0005434513613	1377	Economy	23500.00
0005434586943	1377	Economy	23500.00
0005432968847	1377	Economy	23500.00
0005434586922	1377	Economy	23500.00
0005433525174	1377	Economy	23500.00
0005432271039	1377	Economy	23500.00
0005433525172	1377	Economy	23500.00
0005433193122	1377	Economy	23500.00
0005432968846	1377	Economy	23500.00
0005433525176	1377	Economy	23500.00
0005432968856	1377	Economy	23500.00
0005433193136	1377	Economy	23500.00
0005434586927	1377	Economy	23500.00
0005432928022	1377	Economy	23500.00
0005433193042	1377	Economy	23500.00
0005433724861	1377	Economy	23500.00
0005434586940	1377	Economy	23500.00
0005433525177	1377	Economy	23500.00
0005434586933	1377	Economy	23500.00
0005434586945	1377	Economy	23500.00
0005432271038	1377	Economy	23500.00
0005433525170	1377	Economy	23500.00
0005433193135	1377	Economy	23500.00
0005432968843	1377	Economy	23500.00
0005434586936	1377	Economy	23500.00
0005433525169	1377	Economy	23500.00
0005434586924	1377	Economy	23500.00
0005434586939	1377	Economy	23500.00
0005434586932	1377	Economy	23500.00
0005433724864	1377	Economy	23500.00
0005433193111	1377	Economy	23500.00
0005434586929	1377	Economy	23500.00
0005434586938	1377	Economy	23500.00
0005434586923	1377	Economy	23500.00
0005433525173	1377	Economy	23500.00
0005434513611	1377	Economy	23500.00
0005433525175	1377	Economy	23500.00
0005432927984	1377	Economy	23500.00
0005434586931	1377	Economy	23500.00
0005434515000	1377	Economy	23500.00
0005433724863	1377	Economy	23500.00
0005433193141	1377	Economy	23500.00
0005433193137	1377	Economy	23500.00
0005433525181	1377	Economy	23500.00
0005433525179	1377	Economy	23500.00
0005434586944	1377	Economy	23500.00
0005433193103	1377	Economy	23500.00
0005433525055	18526	Business	70400.00
0005433724820	18526	Business	70400.00
0005433525054	18526	Business	70400.00
0005433525059	18526	Business	70400.00
0005433193206	18526	Business	70400.00
0005434586807	18526	Business	70400.00
0005433193209	18526	Business	70400.00
0005433724826	18526	Business	70400.00
0005434586624	18526	Business	70400.00
0005432928047	18526	Business	70400.00
0005433525085	18526	Economy	23500.00
0005433193216	18526	Economy	23500.00
0005433193217	18526	Economy	23500.00
0005433193210	18526	Economy	23500.00
0005434586617	18526	Economy	23500.00
0005434586587	18526	Economy	23500.00
0005434586770	18526	Economy	23500.00
0005434586736	18526	Economy	23500.00
0005434586806	18526	Economy	23500.00
0005433525100	18526	Economy	25800.00
0005434586799	18526	Economy	25800.00
0005434586663	18526	Economy	25800.00
0005433193214	18526	Economy	25800.00
0005434586800	18526	Economy	25800.00
0005433193207	18526	Economy	23500.00
0005434586664	18526	Economy	23500.00
0005433525105	18526	Economy	23500.00
0005433193208	18526	Economy	23500.00
0005432968869	18526	Economy	23500.00
0005433525104	18526	Economy	23500.00
0005433525046	18526	Economy	23500.00
0005434586795	18526	Economy	23500.00
0005433525097	18526	Economy	23500.00
0005434514984	18526	Economy	23500.00
0005434586714	18526	Economy	23500.00
0005434586666	18526	Economy	23500.00
0005434586721	18526	Economy	23500.00
0005434586609	18526	Economy	23500.00
0005433724818	18526	Economy	23500.00
0005434586639	18526	Economy	23500.00
0005433525101	18526	Economy	23500.00
0005434586796	18526	Economy	23500.00
0005434514975	18526	Economy	23500.00
0005434586716	18526	Economy	23500.00
0005434586588	18526	Economy	23500.00
0005432928048	18526	Economy	23500.00
0005433193213	18526	Economy	23500.00
0005433525049	18526	Economy	23500.00
0005432928051	18526	Economy	23500.00
0005434586737	18526	Economy	23500.00
0005434586710	18526	Economy	23500.00
0005433724819	18526	Economy	23500.00
0005434586611	18526	Economy	23500.00
0005434586771	18526	Economy	23500.00
0005433193211	18526	Economy	23500.00
0005434586662	18526	Economy	23500.00
0005432968868	18526	Economy	23500.00
0005433525098	18526	Economy	23500.00
0005434586779	18526	Economy	23500.00
0005433525045	18526	Economy	23500.00
0005433724838	18526	Economy	23500.00
0005434586715	18526	Economy	23500.00
0005433525076	18526	Economy	23500.00
0005434586851	18526	Economy	23500.00
0005434586852	18526	Economy	23500.00
0005434586810	18526	Economy	23500.00
0005432928049	18526	Economy	23500.00
0005434586661	18526	Economy	23500.00
0005433193215	18526	Economy	23500.00
0005432928050	18526	Economy	23500.00
0005434586695	18526	Economy	23500.00
0005432968867	18526	Economy	23500.00
0005434586711	18526	Economy	23500.00
0005433525096	18526	Economy	23500.00
0005434586702	18526	Economy	23500.00
0005434586657	18526	Economy	23500.00
0005433193212	18526	Economy	23500.00
0005432928046	18526	Economy	23500.00
0005434586724	18526	Economy	23500.00
0005434586720	18526	Economy	23500.00
0005434586658	18526	Economy	23500.00
0005434586709	18526	Economy	23500.00
0005433525033	18526	Economy	23500.00
0005433193218	18526	Economy	23500.00
0005434586610	18526	Economy	23500.00
0005434344636	11422	Economy	4300.00
0005435302201	11422	Economy	4300.00
0005434344615	11422	Economy	4300.00
0005434344616	11422	Economy	4300.00
0005434142659	11422	Economy	4000.00
0005434344623	11422	Economy	4000.00
0005435302224	11422	Economy	4000.00
0005434344631	11422	Economy	4000.00
0005434344635	11422	Economy	4000.00
0005434344611	11422	Economy	4000.00
0005434344627	11422	Economy	4000.00
0005435302199	11422	Economy	4000.00
0005434142660	11422	Economy	4000.00
0005434344606	11422	Economy	4000.00
0005434344617	11422	Economy	4000.00
0005435305020	11422	Economy	4000.00
0005434344619	11422	Economy	4000.00
0005434344625	11422	Economy	4000.00
0005434344614	11422	Economy	4000.00
0005435302200	11422	Economy	4000.00
0005434344624	11422	Economy	4000.00
0005434344613	11422	Economy	4000.00
0005434344626	11422	Economy	4000.00
0005435302209	11422	Economy	4000.00
0005434344607	11422	Economy	4000.00
0005434344634	11422	Economy	4000.00
0005434344629	11422	Economy	4000.00
0005434344609	11422	Economy	4000.00
0005434344610	11422	Economy	4000.00
0005434344602	11422	Economy	4000.00
0005434344603	11422	Economy	4000.00
0005435305025	11422	Economy	4000.00
0005434344604	11422	Economy	4000.00
0005434344605	11422	Economy	4000.00
0005434344628	11422	Economy	4000.00
0005434344612	11422	Economy	4000.00
0005434344600	11422	Economy	4000.00
0005434344608	11422	Economy	4000.00
0005434142658	11422	Economy	4000.00
0005434344601	11422	Economy	4000.00
0005434344633	11422	Economy	4000.00
0005434344620	11422	Economy	4000.00
0005434344630	11422	Economy	4000.00
0005434344632	11422	Economy	4000.00
0005434142661	11422	Economy	4000.00
0005434344618	11422	Economy	4000.00
0005434344621	11422	Economy	4000.00
0005434344622	11422	Economy	4000.00
0005434344329	29760	Economy	4300.00
0005435305040	29760	Economy	4300.00
0005435304217	29760	Economy	4300.00
0005434344284	29760	Economy	4300.00
0005434344412	29760	Economy	4000.00
0005434344264	29760	Economy	4000.00
0005435305039	29760	Economy	4000.00
0005434344343	29760	Economy	4000.00
0005434344318	29760	Economy	4000.00
0005434344322	29760	Economy	4000.00
0005434344253	29760	Economy	4000.00
0005434344306	29760	Economy	4000.00
0005434344338	29760	Economy	4000.00
0005434344333	29760	Economy	4000.00
0005434344391	29760	Economy	4000.00
0005434344165	29760	Economy	4000.00
0005434344456	29760	Economy	4000.00
0005434344345	29760	Economy	4000.00
0005434344279	29760	Economy	4000.00
0005434142609	29760	Economy	4000.00
0005434344507	29760	Economy	4000.00
0005434344305	29760	Economy	4000.00
0005434344238	29760	Economy	4000.00
0005434344263	29760	Economy	4000.00
0005434344303	29760	Economy	4000.00
0005434344315	29760	Economy	4000.00
0005435304215	29760	Economy	4000.00
0005434344309	29760	Economy	4000.00
0005434344388	29760	Economy	4000.00
0005434344304	29760	Economy	4000.00
0005434344310	29760	Economy	4000.00
0005434344297	29760	Economy	4000.00
0005434344380	29760	Economy	4000.00
0005434344166	29760	Economy	4000.00
0005434344257	29760	Economy	4000.00
0005434344155	29760	Economy	4000.00
0005434344459	29760	Economy	4000.00
0005434344344	29760	Economy	4000.00
0005434344339	29760	Economy	4000.00
0005434344218	29760	Economy	4000.00
0005435304216	29760	Economy	4000.00
0005435305038	29760	Economy	4000.00
0005434344237	29760	Economy	4000.00
0005434344346	29760	Economy	4000.00
0005434344447	29760	Economy	4000.00
0005435824969	1289	Business	199800.00
0005435824953	1289	Business	199800.00
0005435824956	1289	Business	199800.00
0005435824962	1289	Business	199800.00
0005435824961	1289	Business	199800.00
0005433415722	1289	Business	199800.00
0005435824966	1289	Business	199800.00
0005435824952	1289	Business	199800.00
0005435824973	1289	Business	199800.00
0005435824963	1289	Business	199800.00
0005435824974	1289	Business	199800.00
0005435824948	1289	Economy	66600.00
0005433415723	1289	Economy	66600.00
0005435824975	1289	Economy	66600.00
0005435824960	1289	Economy	66600.00
0005435824967	1289	Economy	66600.00
0005433415692	1289	Economy	73200.00
0005433415744	1289	Economy	66600.00
0005432284596	1289	Economy	66600.00
0005433415712	1289	Economy	66600.00
0005433415746	1289	Economy	66600.00
0005433415703	1289	Economy	66600.00
0005435824949	1289	Economy	66600.00
0005433415760	1289	Economy	66600.00
0005433415719	1289	Economy	66600.00
0005433415763	1289	Economy	66600.00
0005433415787	1289	Economy	66600.00
0005435824972	1289	Economy	66600.00
0005433415776	1289	Economy	66600.00
0005435824970	1289	Economy	66600.00
0005435824968	1289	Economy	66600.00
0005435824955	1289	Economy	66600.00
0005435824964	1289	Economy	66600.00
0005433415762	1289	Economy	66600.00
0005435824971	1289	Economy	66600.00
0005435824951	1289	Economy	66600.00
0005435824954	1289	Economy	66600.00
0005433415670	1289	Economy	66600.00
0005435824959	1289	Economy	66600.00
0005433415717	1289	Economy	66600.00
0005435824965	1289	Economy	66600.00
0005435824957	1289	Economy	66600.00
0005435824950	1289	Economy	66600.00
0005435824958	1289	Economy	66600.00
0005433415718	1289	Economy	66600.00
0005432284595	1289	Economy	66600.00
0005435824646	17981	Business	199800.00
0005435824748	17981	Business	199800.00
0005435824795	17981	Business	199800.00
0005435824825	17981	Business	199800.00
0005435824747	17981	Business	199800.00
0005433415862	17981	Business	199800.00
0005435824824	17981	Business	199800.00
0005435824632	17981	Business	199800.00
0005435824718	17981	Economy	66600.00
0005433415867	17981	Economy	66600.00
0005435824746	17981	Economy	66600.00
0005435824704	17981	Economy	66600.00
0005435824633	17981	Economy	66600.00
0005435824739	17981	Economy	66600.00
0005435824703	17981	Economy	66600.00
0005433415863	17981	Economy	66600.00
0005435824783	17981	Economy	66600.00
0005433415865	17981	Economy	66600.00
0005435824784	17981	Economy	66600.00
0005435824794	17981	Economy	66600.00
0005433415857	17981	Economy	66600.00
0005433415856	17981	Economy	66600.00
0005435824803	17981	Economy	66600.00
0005435824717	17981	Economy	66600.00
0005433415858	17981	Economy	66600.00
0005433415861	17981	Economy	66600.00
0005433415859	17981	Economy	66600.00
0005433415855	17981	Economy	66600.00
0005433415854	17981	Economy	66600.00
0005433415868	17981	Economy	66600.00
0005433415853	17981	Economy	66600.00
0005433415860	17981	Economy	66600.00
0005433415852	17981	Economy	66600.00
0005433415866	17981	Economy	66600.00
0005435824673	17981	Economy	66600.00
0005435824779	17981	Economy	66600.00
0005433415864	17981	Economy	66600.00
0005434461669	12572	Economy	14800.00
0005434461672	12572	Economy	13500.00
0005434460528	12572	Economy	13500.00
0005434461666	12572	Economy	13500.00
0005434461671	12572	Economy	13500.00
0005434461667	12572	Economy	13500.00
0005434460525	12572	Economy	13500.00
0005434460530	12572	Economy	13500.00
0005434461670	12572	Economy	13500.00
0005434460527	12572	Economy	13500.00
0005434460529	12572	Economy	13500.00
0005434461668	12572	Economy	13500.00
0005434461673	12572	Economy	13500.00
0005434460526	12572	Economy	13500.00
0005435242888	5657	Business	27800.00
0005432784452	5657	Business	27800.00
0005432784484	5657	Business	27800.00
0005435242827	5657	Business	27800.00
0005435242898	5657	Business	27800.00
0005432784483	5657	Business	27800.00
0005435476743	5657	Business	27800.00
0005432784471	5657	Business	27800.00
0005435242853	5657	Business	27800.00
0005435242867	5657	Business	27800.00
0005432784465	5657	Business	27800.00
0005435476783	5657	Business	27800.00
0005435476814	5657	Economy	9300.00
0005432784445	5657	Economy	9300.00
0005435242887	5657	Economy	9300.00
0005432784448	5657	Economy	9300.00
0005435242852	5657	Economy	9300.00
0005432784447	5657	Economy	9300.00
0005432784449	5657	Economy	9300.00
0005435242828	5657	Economy	9300.00
0005432784455	5657	Economy	9300.00
0005432784479	5657	Economy	10200.00
0005432784476	5657	Economy	10200.00
0005432784486	5657	Economy	10200.00
0005435476813	5657	Economy	10200.00
0005435243001	5657	Economy	10200.00
0005432784485	5657	Economy	9300.00
0005435242926	5657	Economy	9300.00
0005435476784	5657	Economy	9300.00
0005435476805	5657	Economy	9300.00
0005435476782	5657	Economy	9300.00
0005435476768	5657	Economy	9300.00
0005432784481	5657	Economy	9300.00
0005432784444	5657	Economy	9300.00
0005432144028	5657	Economy	9300.00
0005432784450	5657	Economy	9300.00
0005432784457	5657	Economy	9300.00
0005432784478	5657	Economy	9300.00
0005432784442	5657	Economy	9300.00
0005432784469	5657	Economy	9300.00
0005435243002	5657	Economy	9300.00
0005432784456	5657	Economy	9300.00
0005432784453	5657	Economy	9300.00
0005435242866	5657	Economy	9300.00
0005432784480	5657	Economy	9300.00
0005432784489	5657	Economy	9300.00
0005432784441	5657	Economy	9300.00
0005432784458	5657	Economy	9300.00
0005432784467	5657	Economy	9300.00
0005435242826	5657	Economy	9300.00
0005432784446	5657	Economy	9300.00
0005435242896	5657	Economy	9300.00
0005432784472	5657	Economy	9300.00
0005432784461	5657	Economy	9300.00
0005432784487	5657	Economy	9300.00
0005435242897	5657	Economy	9300.00
0005435243034	5657	Economy	9300.00
0005432784463	5657	Economy	9300.00
0005435243033	5657	Economy	9300.00
0005432784436	5657	Economy	9300.00
0005432784482	5657	Economy	9300.00
0005432784464	5657	Economy	9300.00
0005432784475	5657	Economy	9300.00
0005432784443	5657	Economy	9300.00
0005432784440	5657	Economy	9300.00
0005432784459	5657	Economy	9300.00
0005432784473	5657	Economy	9300.00
0005432784466	5657	Economy	9300.00
0005432784454	5657	Economy	9300.00
0005435476815	5657	Economy	9300.00
0005435242979	5657	Economy	9300.00
0005435476810	5657	Economy	9300.00
0005432784438	5657	Economy	9300.00
0005432784488	5657	Economy	9300.00
0005432784477	5657	Economy	9300.00
0005432784462	5657	Economy	9300.00
0005435243000	5657	Economy	9300.00
0005432784439	5657	Economy	9300.00
0005435242889	5657	Economy	9300.00
0005432144029	5657	Economy	9300.00
0005432784460	5657	Economy	9300.00
0005432784490	5657	Economy	9300.00
0005432144027	5657	Economy	9300.00
0005432784468	5657	Economy	9300.00
0005432784451	5657	Economy	9300.00
0005435242780	5657	Economy	9300.00
0005435242925	5657	Economy	9300.00
0005432784474	5657	Economy	9300.00
0005432784437	5657	Economy	9300.00
0005432784470	5657	Economy	9300.00
0005435476850	15343	Business	27800.00
0005435243174	15343	Business	27800.00
0005435243177	15343	Business	27800.00
0005435476846	15343	Business	27800.00
0005432783899	15343	Business	27800.00
0005435476842	15343	Business	27800.00
0005432783841	15343	Business	27800.00
0005432784150	15343	Business	27800.00
0005435243166	15343	Economy	9300.00
0005435243178	15343	Economy	9300.00
0005435243159	15343	Economy	9300.00
0005432783992	15343	Economy	9300.00
0005432783893	15343	Economy	9300.00
0005432783963	15343	Economy	9300.00
0005432783953	15343	Economy	9300.00
0005435476847	15343	Economy	9300.00
0005432784010	15343	Economy	9300.00
0005435243170	15343	Economy	9300.00
0005432783894	15343	Economy	10200.00
0005432783791	15343	Economy	10200.00
0005435243172	15343	Economy	10200.00
0005432783792	15343	Economy	10200.00
0005432784109	15343	Economy	9300.00
0005432783890	15343	Economy	9300.00
0005432783951	15343	Economy	9300.00
0005435243171	15343	Economy	9300.00
0005435476845	15343	Economy	9300.00
0005435243181	15343	Economy	9300.00
0005432783818	15343	Economy	9300.00
0005435476844	15343	Economy	9300.00
0005432784070	15343	Economy	9300.00
0005432784019	15343	Economy	9300.00
0005432783817	15343	Economy	9300.00
0005432784137	15343	Economy	9300.00
0005432784069	15343	Economy	9300.00
0005435243175	15343	Economy	9300.00
0005432783984	15343	Economy	9300.00
0005432783985	15343	Economy	9300.00
0005432784135	15343	Economy	9300.00
0005432784056	15343	Economy	9300.00
0005435476848	15343	Economy	9300.00
0005432783657	15343	Economy	9300.00
0005432784020	15343	Economy	9300.00
0005435243168	15343	Economy	9300.00
0005432783808	15343	Economy	9300.00
0005435243173	15343	Economy	9300.00
0005435243162	15343	Economy	9300.00
0005432783896	15343	Economy	9300.00
0005435243163	15343	Economy	9300.00
0005435476849	15343	Economy	9300.00
0005432783900	15343	Economy	9300.00
0005432784138	15343	Economy	9300.00
0005432783797	15343	Economy	9300.00
0005432783964	15343	Economy	9300.00
0005432784095	15343	Economy	9300.00
0005432783889	15343	Economy	9300.00
0005435243161	15343	Economy	9300.00
0005432783915	15343	Economy	9300.00
0005435243165	15343	Economy	9300.00
0005432783804	15343	Economy	9300.00
0005432784071	15343	Economy	9300.00
0005432783837	15343	Economy	9300.00
0005435243176	15343	Economy	9300.00
0005432783730	15343	Economy	9300.00
0005435243158	15343	Economy	9300.00
0005432783732	15343	Economy	9300.00
0005435243183	15343	Economy	9300.00
0005432783840	15343	Economy	9300.00
0005432783991	15343	Economy	9300.00
0005432784028	15343	Economy	9300.00
0005432783901	15343	Economy	9300.00
0005432784139	15343	Economy	9300.00
0005432783895	15343	Economy	9300.00
0005435243164	15343	Economy	9300.00
0005435243160	15343	Economy	9300.00
0005432783983	15343	Economy	9300.00
0005435243182	15343	Economy	9300.00
0005432783658	15343	Economy	9300.00
0005435243184	15343	Economy	9300.00
0005432783871	15343	Economy	9300.00
0005435243169	15343	Economy	9300.00
0005432783731	15343	Economy	9300.00
0005432783870	15343	Economy	9300.00
0005432783986	15343	Economy	9300.00
0005432783805	15343	Economy	9300.00
0005432783902	15343	Economy	9300.00
0005435243180	15343	Economy	9300.00
0005435476843	15343	Economy	9300.00
0005435243167	15343	Economy	9300.00
0005435243179	15343	Economy	9300.00
0005435850963	4350	Economy	7000.00
0005432848500	4350	Economy	7000.00
0005432848494	4350	Economy	7000.00
0005435850966	4350	Economy	6300.00
0005434462816	4350	Economy	6300.00
0005434463955	4350	Economy	6300.00
0005435850949	4350	Economy	6300.00
0005435850994	4350	Economy	6300.00
0005435850961	4350	Economy	6300.00
0005432848491	4350	Economy	6300.00
0005432848493	4350	Economy	6300.00
0005432848490	4350	Economy	6300.00
0005434462817	4350	Economy	6300.00
0005432848495	4350	Economy	6300.00
0005432848492	4350	Economy	6300.00
0005432848497	4350	Economy	6300.00
0005435850947	4350	Economy	6300.00
0005434463956	4350	Economy	6300.00
0005432848498	4350	Economy	6300.00
0005432848489	4350	Economy	6300.00
0005435850960	4350	Economy	6300.00
0005435850997	4350	Economy	6300.00
0005435850950	4350	Economy	6300.00
0005435850924	4350	Economy	6300.00
0005432848499	4350	Economy	6300.00
0005432848496	4350	Economy	6300.00
0005435850962	4350	Economy	6300.00
0005432848487	4350	Economy	6300.00
0005432848501	4350	Economy	6300.00
0005435850946	4350	Economy	6300.00
0005434462818	4350	Economy	6300.00
0005432848488	4350	Economy	6300.00
0005434461646	28837	Economy	7000.00
0005435851028	28837	Economy	6300.00
0005432848370	28837	Economy	6300.00
0005434463936	28837	Economy	6300.00
0005432848350	28837	Economy	6300.00
0005432848377	28837	Economy	6300.00
0005435851024	28837	Economy	6300.00
0005435851025	28837	Economy	6300.00
0005432848359	28837	Economy	6300.00
0005435851019	28837	Economy	6300.00
0005434461651	28837	Economy	6300.00
0005432848371	28837	Economy	6300.00
0005432848395	28837	Economy	6300.00
0005432848358	28837	Economy	6300.00
0005435851026	28837	Economy	6300.00
0005435851021	28837	Economy	6300.00
0005432848386	28837	Economy	6300.00
0005434461652	28837	Economy	6300.00
0005435851023	28837	Economy	6300.00
0005432848360	28837	Economy	6300.00
0005435851027	28837	Economy	6300.00
0005435851022	28837	Economy	6300.00
0005434461647	28837	Economy	6300.00
0005434461655	28837	Economy	6300.00
0005432848412	28837	Economy	6300.00
0005435851020	28837	Economy	6300.00
0005432848369	28837	Economy	6300.00
0005432848401	28837	Economy	6300.00
0005433497363	6303	Business	11900.00
0005434443905	6303	Business	11900.00
0005434926192	6303	Business	11900.00
0005434443910	6303	Business	11900.00
0005434926206	6303	Business	11900.00
0005433497368	6303	Business	11900.00
0005433497364	6303	Business	11900.00
0005434443913	6303	Business	11900.00
0005434926188	6303	Business	11900.00
0005433497366	6303	Economy	4000.00
0005434926216	6303	Economy	4000.00
0005433497350	6303	Economy	4000.00
0005433497354	6303	Economy	4000.00
0005433497352	6303	Economy	4000.00
0005434443919	6303	Economy	4000.00
0005433497371	6303	Economy	4000.00
0005433497348	6303	Economy	4000.00
0005433497369	6303	Economy	4000.00
0005433497372	6303	Economy	4000.00
0005434926202	6303	Economy	4400.00
0005434926218	6303	Economy	4400.00
0005434443918	6303	Economy	4400.00
0005434926200	6303	Economy	4400.00
0005433497353	6303	Economy	4400.00
0005434926189	6303	Economy	4000.00
0005434926196	6303	Economy	4000.00
0005433497362	6303	Economy	4000.00
0005434926205	6303	Economy	4000.00
0005434926217	6303	Economy	4000.00
0005434926208	6303	Economy	4000.00
0005434926195	6303	Economy	4000.00
0005434443917	6303	Economy	4000.00
0005434926194	6303	Economy	4000.00
0005434926215	6303	Economy	4000.00
0005434926193	6303	Economy	4000.00
0005433497355	6303	Economy	4000.00
0005434443916	6303	Economy	4000.00
0005434443911	6303	Economy	4000.00
0005433497365	6303	Economy	4000.00
0005432075273	6303	Economy	4000.00
0005433497376	6303	Economy	4000.00
0005433497349	6303	Economy	4000.00
0005434443906	6303	Economy	4000.00
0005434443907	6303	Economy	4000.00
0005434926203	6303	Economy	4000.00
0005434926190	6303	Economy	4000.00
0005432075275	6303	Economy	4000.00
0005433497351	6303	Economy	4000.00
0005434443912	6303	Economy	4000.00
0005434443904	6303	Economy	4000.00
0005434926220	6303	Economy	4000.00
0005434926221	6303	Economy	4000.00
0005433497357	6303	Economy	4000.00
0005434926204	6303	Economy	4000.00
0005434443908	6303	Economy	4000.00
0005433497367	6303	Economy	4000.00
0005433497373	6303	Economy	4000.00
0005432075274	6303	Economy	4000.00
0005433497360	6303	Economy	4000.00
0005433497361	6303	Economy	4000.00
0005434443915	6303	Economy	4000.00
0005434926191	6303	Economy	4000.00
0005433497374	6303	Economy	4000.00
0005433497359	6303	Economy	4000.00
0005434926197	6303	Economy	4000.00
0005434926210	6303	Economy	4000.00
0005432075272	6303	Economy	4000.00
0005433497377	6303	Economy	4000.00
0005433497370	6303	Economy	4000.00
0005434443909	6303	Economy	4000.00
0005434926211	6303	Economy	4000.00
0005434443903	6303	Economy	4000.00
0005434926207	6303	Economy	4000.00
0005433497347	6303	Economy	4000.00
0005434926199	6303	Economy	4000.00
0005434926219	6303	Economy	4000.00
0005433497358	6303	Economy	4000.00
0005434926209	6303	Economy	4000.00
0005434926212	6303	Economy	4000.00
0005434926201	6303	Economy	4000.00
0005433497356	6303	Economy	4000.00
0005434926198	6303	Economy	4000.00
0005433497375	6303	Economy	4000.00
0005434926213	6303	Economy	4000.00
0005434926214	6303	Economy	4000.00
0005434443914	6303	Economy	4000.00
0005434925770	20368	Business	11900.00
0005434925733	20368	Business	11900.00
0005434443802	20368	Business	11900.00
0005433497214	20368	Business	11900.00
0005433497143	20368	Business	11900.00
0005433497229	20368	Business	11900.00
0005434925895	20368	Business	11900.00
0005433497077	20368	Business	11900.00
0005434925833	20368	Business	11900.00
0005434925885	20368	Economy	4000.00
0005433497096	20368	Economy	4000.00
0005434443780	20368	Economy	4000.00
0005434925988	20368	Economy	4000.00
0005433497227	20368	Economy	4000.00
0005434925962	20368	Economy	4000.00
0005434925854	20368	Economy	4000.00
0005433497122	20368	Economy	4400.00
0005434925838	20368	Economy	4400.00
0005434925757	20368	Economy	4400.00
0005434443812	20368	Economy	4400.00
0005434925850	20368	Economy	4000.00
0005433497142	20368	Economy	4000.00
0005434925888	20368	Economy	4000.00
0005434443752	20368	Economy	4000.00
0005433497120	20368	Economy	4000.00
0005434925886	20368	Economy	4000.00
0005434925830	20368	Economy	4000.00
0005434925865	20368	Economy	4000.00
0005433497121	20368	Economy	4000.00
0005434925978	20368	Economy	4000.00
0005433497195	20368	Economy	4000.00
0005434925831	20368	Economy	4000.00
0005434443751	20368	Economy	4000.00
0005434925835	20368	Economy	4000.00
0005434925931	20368	Economy	4000.00
0005433497127	20368	Economy	4000.00
0005434443779	20368	Economy	4000.00
0005433497144	20368	Economy	4000.00
0005434925930	20368	Economy	4000.00
0005433497160	20368	Economy	4000.00
0005433497126	20368	Economy	4000.00
0005434443684	20368	Economy	4000.00
0005434925731	20368	Economy	4000.00
0005433497174	20368	Economy	4000.00
0005434925909	20368	Economy	4000.00
0005434925730	20368	Economy	4000.00
0005434925908	20368	Economy	4000.00
0005434925802	20368	Economy	4000.00
0005434925977	20368	Economy	4000.00
0005434925747	20368	Economy	4000.00
0005434925827	20368	Economy	4000.00
0005433497099	20368	Economy	4000.00
0005433497228	20368	Economy	4000.00
0005434925915	20368	Economy	4000.00
0005433497073	20368	Economy	4000.00
0005434925910	20368	Economy	4000.00
0005433497146	20368	Economy	4000.00
0005433497213	20368	Economy	4000.00
0005434925771	20368	Economy	4000.00
0005434925834	20368	Economy	4000.00
0005434925796	20368	Economy	4000.00
0005434443746	20368	Economy	4000.00
0005433497128	20368	Economy	4000.00
0005434925803	20368	Economy	4000.00
0005433497175	20368	Economy	4000.00
0005433497153	20368	Economy	4000.00
0005434443712	20368	Economy	4000.00
0005433497148	20368	Economy	4000.00
0005433497095	20368	Economy	4000.00
0005434443716	20368	Economy	4000.00
0005434925756	20368	Economy	4000.00
0005435243206	12156	Business	41200.00
0005432783931	12156	Business	41200.00
0005432783971	12156	Business	41200.00
0005432783831	12156	Business	41200.00
0005432784047	12156	Business	41200.00
0005432784112	12156	Business	41200.00
0005432783742	12156	Business	41200.00
0005432784079	12156	Business	41200.00
0005432784227	12156	Business	41200.00
0005435243197	12156	Business	41200.00
0005435243199	12156	Business	41200.00
0005435243205	12156	Business	41200.00
0005432783830	12156	Economy	13700.00
0005435243191	12156	Economy	13700.00
0005432784122	12156	Economy	13700.00
0005435243187	12156	Economy	13700.00
0005432783923	12156	Economy	13700.00
0005432783741	12156	Economy	13700.00
0005432783987	12156	Economy	13700.00
0005432784089	12156	Economy	13700.00
0005432784039	12156	Economy	13700.00
0005432784248	12156	Economy	13700.00
0005432783967	12156	Economy	15100.00
0005432783783	12156	Economy	15100.00
0005432783853	12156	Economy	15100.00
0005432784086	12156	Economy	15100.00
0005435243195	12156	Economy	15100.00
0005435243188	12156	Economy	13700.00
0005432784048	12156	Economy	13700.00
0005432784098	12156	Economy	13700.00
0005432784091	12156	Economy	13700.00
0005432783845	12156	Economy	13700.00
0005432784164	12156	Economy	13700.00
0005432783844	12156	Economy	13700.00
0005432784232	12156	Economy	13700.00
0005432784103	12156	Economy	13700.00
0005435243194	12156	Economy	13700.00
0005432783930	12156	Economy	13700.00
0005432783950	12156	Economy	13700.00
0005432784096	12156	Economy	13700.00
0005432783740	12156	Economy	13700.00
0005432784068	12156	Economy	13700.00
0005432784080	12156	Economy	13700.00
0005435243186	12156	Economy	13700.00
0005432784023	12156	Economy	13700.00
0005432784161	12156	Economy	13700.00
0005432783886	12156	Economy	13700.00
0005432784014	12156	Economy	13700.00
0005432783880	12156	Economy	13700.00
0005432784064	12156	Economy	13700.00
0005435243185	12156	Economy	13700.00
0005432784087	12156	Economy	13700.00
0005432783977	12156	Economy	13700.00
0005432783866	12156	Economy	13700.00
0005432784113	12156	Economy	13700.00
0005432783687	12156	Economy	13700.00
0005432784102	12156	Economy	13700.00
0005432783909	12156	Economy	13700.00
0005432784073	12156	Economy	13700.00
0005435243208	12156	Economy	13700.00
0005432783962	12156	Economy	13700.00
0005435243200	12156	Economy	13700.00
0005435243204	12156	Economy	13700.00
0005432783976	12156	Economy	13700.00
0005432784165	12156	Economy	13700.00
0005435243190	12156	Economy	13700.00
0005435243196	12156	Economy	13700.00
0005432784101	12156	Economy	13700.00
0005432783970	12156	Economy	13700.00
0005432784097	12156	Economy	13700.00
0005435243202	12156	Economy	13700.00
0005432784013	12156	Economy	13700.00
0005435243193	12156	Economy	13700.00
0005432784074	12156	Economy	13700.00
0005432783833	12156	Economy	13700.00
0005435243207	12156	Economy	13700.00
0005432784027	12156	Economy	13700.00
0005435243192	12156	Economy	13700.00
0005432783446	12156	Economy	13700.00
0005432783784	12156	Economy	13700.00
0005432784090	12156	Economy	13700.00
0005432783943	12156	Economy	13700.00
0005435243203	12156	Economy	13700.00
0005432784094	12156	Economy	13700.00
0005432784043	12156	Economy	13700.00
0005435243189	12156	Economy	13700.00
0005435243201	12156	Economy	13700.00
0005432784121	12156	Economy	13700.00
0005432783885	12156	Economy	13700.00
0005435243198	12156	Economy	13700.00
0005432784040	12156	Economy	13700.00
0005432784099	12156	Economy	13700.00
0005432784044	12156	Economy	13700.00
0005432783940	12156	Economy	13700.00
0005432784088	12156	Economy	13700.00
0005432784100	12156	Economy	13700.00
0005432784397	15441	Business	41200.00
0005432784408	15441	Business	41200.00
0005432784393	15441	Business	41200.00
0005432784390	15441	Business	41200.00
0005435242913	15441	Business	41200.00
0005435242928	15441	Business	41200.00
0005432784413	15441	Economy	13700.00
0005432784435	15441	Economy	13700.00
0005432784394	15441	Economy	13700.00
0005435242906	15441	Economy	13700.00
0005435242973	15441	Economy	13700.00
0005435242821	15441	Economy	13700.00
0005435242974	15441	Economy	13700.00
0005432784429	15441	Economy	13700.00
0005435242929	15441	Economy	15100.00
0005432784415	15441	Economy	15100.00
0005432784427	15441	Economy	15100.00
0005432784385	15441	Economy	15100.00
0005432784424	15441	Economy	13700.00
0005432784422	15441	Economy	13700.00
0005432784383	15441	Economy	13700.00
0005432784412	15441	Economy	13700.00
0005432784387	15441	Economy	13700.00
0005432784417	15441	Economy	13700.00
0005432784410	15441	Economy	13700.00
0005432784389	15441	Economy	13700.00
0005432784406	15441	Economy	13700.00
0005432784382	15441	Economy	13700.00
0005432784391	15441	Economy	13700.00
0005435242944	15441	Economy	13700.00
0005432784428	15441	Economy	13700.00
0005432784414	15441	Economy	13700.00
0005432784411	15441	Economy	13700.00
0005432784399	15441	Economy	13700.00
0005432784433	15441	Economy	13700.00
0005435242930	15441	Economy	13700.00
0005432784420	15441	Economy	13700.00
0005435242942	15441	Economy	13700.00
0005432784386	15441	Economy	13700.00
0005432784402	15441	Economy	13700.00
0005432784423	15441	Economy	13700.00
0005432784432	15441	Economy	13700.00
0005432784434	15441	Economy	13700.00
0005432784421	15441	Economy	13700.00
0005432784404	15441	Economy	13700.00
0005432784392	15441	Economy	13700.00
0005432784384	15441	Economy	13700.00
0005432784425	15441	Economy	13700.00
0005432784416	15441	Economy	13700.00
0005432784419	15441	Economy	13700.00
0005432784398	15441	Economy	13700.00
0005432784431	15441	Economy	13700.00
0005432784418	15441	Economy	13700.00
0005435242982	15441	Economy	13700.00
0005432784396	15441	Economy	13700.00
0005435242967	15441	Economy	13700.00
0005432784401	15441	Economy	13700.00
0005432784405	15441	Economy	13700.00
0005432784395	15441	Economy	13700.00
0005432784426	15441	Economy	13700.00
0005432784430	15441	Economy	13700.00
0005435242957	15441	Economy	13700.00
0005432784400	15441	Economy	13700.00
0005435242972	15441	Economy	13700.00
0005432784388	15441	Economy	13700.00
0005432784409	15441	Economy	13700.00
0005432784403	15441	Economy	13700.00
0005432784407	15441	Economy	13700.00
0005434878242	10073	Business	49700.00
0005434878801	10073	Business	49700.00
0005434878725	10073	Business	49700.00
0005434878933	10073	Business	49700.00
0005434878316	10073	Business	49700.00
0005434878928	10073	Business	49700.00
0005434878369	10073	Business	49700.00
0005434878234	10073	Business	49700.00
0005434878723	10073	Business	49700.00
0005434878623	10073	Business	49700.00
0005434878655	10073	Business	49700.00
0005434878784	10073	Business	49700.00
0005434878904	10073	Business	49700.00
0005434878192	10073	Business	49700.00
0005434878165	10073	Business	49700.00
0005434878341	10073	Business	49700.00
0005434878671	10073	Business	49700.00
0005434878190	10073	Business	49700.00
0005434878721	10073	Business	49700.00
0005434878373	10073	Business	49700.00
0005434878628	10073	Economy	16600.00
0005434878197	10073	Economy	16600.00
0005434878901	10073	Economy	16600.00
0005434878394	10073	Economy	16600.00
0005434878445	10073	Economy	16600.00
0005434878395	10073	Economy	16600.00
0005434878669	10073	Economy	16600.00
0005434878415	10073	Economy	16600.00
0005434878796	10073	Economy	16600.00
0005434878417	10073	Economy	16600.00
0005434878368	10073	Economy	16600.00
0005434910143	10073	Economy	16600.00
0005434878839	10073	Economy	18200.00
0005434878577	10073	Economy	18200.00
0005434878929	10073	Economy	18200.00
0005434878586	10073	Economy	16600.00
0005434878664	10073	Economy	18200.00
0005434878782	10073	Economy	16600.00
0005434878323	10073	Economy	16600.00
0005434878666	10073	Economy	16600.00
0005434878645	10073	Economy	16600.00
0005434878531	10073	Economy	16600.00
0005434878521	10073	Economy	16600.00
0005434878582	10073	Economy	16600.00
0005434878681	10073	Economy	16600.00
0005434878562	10073	Economy	16600.00
0005434878670	10073	Economy	16600.00
0005434878643	10073	Economy	16600.00
0005434878633	10073	Economy	16600.00
0005434878748	10073	Economy	16600.00
0005434878634	10073	Economy	16600.00
0005434878322	10073	Economy	16600.00
0005434910140	10073	Economy	16600.00
0005434878600	10073	Economy	16600.00
0005434878653	10073	Economy	16600.00
0005434878730	10073	Economy	16600.00
0005434878617	10073	Economy	16600.00
0005434878308	10073	Economy	16600.00
0005434878729	10073	Economy	16600.00
0005434878709	10073	Economy	16600.00
0005434878856	10073	Economy	16600.00
0005434878426	10073	Economy	16600.00
0005434878548	10073	Economy	16600.00
0005434878624	10073	Economy	16600.00
0005434878644	10073	Economy	16600.00
0005434878589	10073	Economy	16600.00
0005434878383	10073	Economy	16600.00
0005434878857	10073	Economy	16600.00
0005435913968	10073	Economy	16600.00
0005434878443	10073	Economy	16600.00
0005434878226	10073	Economy	16600.00
0005434878465	10073	Economy	16600.00
0005434878225	10073	Economy	16600.00
0005434878317	10073	Economy	16600.00
0005434878855	10073	Economy	16600.00
0005434878821	10073	Economy	16600.00
0005434878858	10073	Economy	16600.00
0005434878241	10073	Economy	16600.00
0005434878449	10073	Economy	16600.00
0005434878882	10073	Economy	16600.00
0005434878579	10073	Economy	16600.00
0005434910142	10073	Economy	16600.00
0005434878475	10073	Economy	16600.00
0005434878534	10073	Economy	16600.00
0005434878733	10073	Economy	16600.00
0005434878618	10073	Economy	16600.00
0005434878587	10073	Economy	16600.00
0005434878927	10073	Economy	16600.00
0005434878288	10073	Economy	16600.00
0005434878539	10073	Economy	16600.00
0005434878698	10073	Economy	16600.00
0005434878749	10073	Economy	16600.00
0005434878537	10073	Economy	16600.00
0005434878384	10073	Economy	16600.00
0005434878296	10073	Economy	16600.00
0005434878783	10073	Economy	16600.00
0005435913966	10073	Economy	16600.00
0005434878374	10073	Economy	16600.00
0005434878654	10073	Economy	16600.00
0005434878382	10073	Economy	16600.00
0005434878442	10073	Economy	16600.00
0005434878532	10073	Economy	16600.00
0005434878127	10073	Economy	16600.00
0005434878131	10073	Economy	16600.00
0005434878233	10073	Economy	16600.00
0005434878232	10073	Economy	16600.00
0005434910141	10073	Economy	16600.00
0005434758906	10073	Economy	16600.00
0005434878231	10073	Economy	16600.00
0005434878464	10073	Economy	16600.00
0005434878191	10073	Economy	16600.00
0005434878837	10073	Economy	16600.00
0005434878514	10073	Economy	16600.00
0005435913967	10073	Economy	16600.00
0005434878785	10073	Economy	16600.00
0005434879396	14601	Business	49700.00
0005434879364	14601	Business	49700.00
0005434879392	14601	Business	49700.00
0005434879362	14601	Business	49700.00
0005434879369	14601	Business	49700.00
0005434879420	14601	Business	49700.00
0005434879391	14601	Business	49700.00
0005434879399	14601	Business	49700.00
0005434879348	14601	Business	49700.00
0005434910114	14601	Business	49700.00
0005434879366	14601	Business	49700.00
0005434879440	14601	Business	49700.00
0005434879372	14601	Business	49700.00
0005434879425	14601	Business	49700.00
0005434879379	14601	Business	49700.00
0005434879377	14601	Business	49700.00
0005434879429	14601	Business	49700.00
0005434758922	14601	Business	49700.00
0005434879365	14601	Economy	16600.00
0005434879437	14601	Business	49700.00
0005434879430	14601	Economy	16600.00
0005434879436	14601	Economy	16600.00
0005434879427	14601	Economy	16600.00
0005434879431	14601	Economy	16600.00
0005434879438	14601	Economy	16600.00
0005434879406	14601	Economy	16600.00
0005434879418	14601	Economy	16600.00
0005434879350	14601	Economy	16600.00
0005434879388	14601	Economy	16600.00
0005434879361	14601	Economy	16600.00
0005434879390	14601	Economy	18200.00
0005434879356	14601	Economy	18200.00
0005434879407	14601	Economy	18200.00
0005434879373	14601	Economy	16600.00
0005434879410	14601	Economy	16600.00
0005434879357	14601	Economy	16600.00
0005434879393	14601	Economy	16600.00
0005434879428	14601	Economy	16600.00
0005434879386	14601	Economy	16600.00
0005434879412	14601	Economy	16600.00
0005434879375	14601	Economy	16600.00
0005434879401	14601	Economy	16600.00
0005434879389	14601	Economy	16600.00
0005434879367	14601	Economy	16600.00
0005434879354	14601	Economy	16600.00
0005434879368	14601	Economy	16600.00
0005434879413	14601	Economy	16600.00
0005434879352	14601	Economy	16600.00
0005434879414	14601	Economy	16600.00
0005434879374	14601	Economy	16600.00
0005434879346	14601	Economy	16600.00
0005434879441	14601	Economy	16600.00
0005434879384	14601	Economy	16600.00
0005434879405	14601	Economy	16600.00
0005434879395	14601	Economy	16600.00
0005434879433	14601	Economy	16600.00
0005434879408	14601	Economy	16600.00
0005434879360	14601	Economy	16600.00
0005434879376	14601	Economy	16600.00
0005434879347	14601	Economy	16600.00
0005434879421	14601	Economy	16600.00
0005434879370	14601	Economy	16600.00
0005434879404	14601	Economy	16600.00
0005434879400	14601	Economy	16600.00
0005434879397	14601	Economy	16600.00
0005434879417	14601	Economy	16600.00
0005434879349	14601	Economy	16600.00
0005434879355	14601	Economy	16600.00
0005434879403	14601	Economy	16600.00
0005434879378	14601	Economy	16600.00
0005434879394	14601	Economy	16600.00
0005434879419	14601	Economy	16600.00
0005434758923	14601	Economy	16600.00
0005434879381	14601	Economy	16600.00
0005434879439	14601	Economy	16600.00
0005434879423	14601	Economy	16600.00
0005434879434	14601	Economy	16600.00
0005434879383	14601	Economy	16600.00
0005434879398	14601	Economy	16600.00
0005434879359	14601	Economy	16600.00
0005434879432	14601	Economy	16600.00
0005434879382	14601	Economy	16600.00
0005434879424	14601	Economy	16600.00
0005434910119	14601	Economy	16600.00
0005434879387	14601	Economy	16600.00
0005434879416	14601	Economy	16600.00
0005434879411	14601	Economy	16600.00
0005434879363	14601	Economy	16600.00
0005434879351	14601	Economy	16600.00
0005434879371	14601	Economy	16600.00
0005434879402	14601	Economy	16600.00
0005434879426	14601	Economy	16600.00
0005434879358	14601	Economy	16600.00
0005434879409	14601	Economy	16600.00
0005434879385	14601	Economy	16600.00
0005434879422	14601	Economy	16600.00
0005434879415	14601	Economy	16600.00
0005434879353	14601	Economy	16600.00
0005434879380	14601	Economy	16600.00
0005434879435	14601	Economy	16600.00
0005435660278	9250	Economy	22400.00
0005435660280	9250	Economy	20300.00
0005435660273	9250	Economy	20300.00
0005434252001	9250	Economy	20300.00
0005434251987	9250	Economy	20300.00
0005435660271	9250	Economy	20300.00
0005434251980	9250	Economy	20300.00
0005435660277	9250	Economy	20300.00
0005435660274	9250	Economy	20300.00
0005435660272	9250	Economy	20300.00
0005435660275	9250	Economy	20300.00
0005435660279	9250	Economy	20300.00
0005434252012	9250	Economy	20300.00
0005434251995	9250	Economy	20300.00
0005435660276	9250	Economy	20300.00
0005435660281	9250	Economy	20300.00
0005434251981	9250	Economy	20300.00
0005435660175	24635	Economy	22400.00
0005435660149	24635	Economy	22400.00
0005435660179	24635	Economy	20300.00
0005435660136	24635	Economy	20300.00
0005435660180	24635	Economy	20300.00
0005435660176	24635	Economy	20300.00
0005434252081	24635	Economy	20300.00
0005435660174	24635	Economy	20300.00
0005434252086	24635	Economy	20300.00
0005435660173	24635	Economy	20300.00
0005435660181	24635	Economy	20300.00
0005435660199	24635	Economy	20300.00
0005434252079	24635	Economy	20300.00
0005434252085	24635	Economy	20300.00
0005435660150	24635	Economy	20300.00
0005434252080	24635	Economy	20300.00
0005434252078	24635	Economy	20300.00
0005435660184	24635	Economy	20300.00
0005434252082	24635	Economy	20300.00
0005434252077	24635	Economy	20300.00
0005434252083	24635	Economy	20300.00
0005434252084	24635	Economy	20300.00
0005433681164	2810	Business	33000.00
0005433681127	2810	Business	33000.00
0005432966995	2810	Business	33000.00
0005433681149	2810	Business	33000.00
0005433681130	2810	Business	33000.00
0005433681140	2810	Business	33000.00
0005433681169	2810	Business	33000.00
0005433681167	2810	Business	33000.00
0005432967005	2810	Business	33000.00
0005432966920	2810	Economy	11000.00
0005433684444	2810	Economy	11000.00
0005433681134	2810	Economy	11000.00
0005433681157	2810	Economy	11000.00
0005433681136	2810	Economy	11000.00
0005433681139	2810	Economy	11000.00
0005432966954	2810	Economy	12100.00
0005433681128	2810	Economy	12100.00
0005433681151	2810	Economy	12100.00
0005433681156	2810	Economy	12100.00
0005433681174	2810	Economy	12100.00
0005433681147	2810	Economy	11000.00
0005433681144	2810	Economy	11000.00
0005433681161	2810	Economy	11000.00
0005433681131	2810	Economy	11000.00
0005432967014	2810	Economy	11000.00
0005433681141	2810	Economy	11000.00
0005432967056	2810	Economy	11000.00
0005432967083	2810	Economy	11000.00
0005432222847	2810	Economy	11000.00
0005433681171	2810	Economy	11000.00
0005433681155	2810	Economy	11000.00
0005433681132	2810	Economy	11000.00
0005433681154	2810	Economy	11000.00
0005432967119	2810	Economy	11000.00
0005433681142	2810	Economy	11000.00
0005432967084	2810	Economy	11000.00
0005432967001	2810	Economy	11000.00
0005433681163	2810	Economy	11000.00
0005432966955	2810	Economy	11000.00
0005432222849	2810	Economy	11000.00
0005433681158	2810	Economy	11000.00
0005433681165	2810	Economy	11000.00
0005433684445	2810	Economy	11000.00
0005432966919	2810	Economy	11000.00
0005433681143	2810	Economy	11000.00
0005433681133	2810	Economy	11000.00
0005433681135	2810	Economy	11000.00
0005433681162	2810	Economy	11000.00
0005432967077	2810	Economy	11000.00
0005432222846	2810	Economy	11000.00
0005433681152	2810	Economy	11000.00
0005433681172	2810	Economy	11000.00
0005433681173	2810	Economy	11000.00
0005433681148	2810	Economy	11000.00
0005432967078	2810	Economy	11000.00
0005433681129	2810	Economy	11000.00
0005433681166	2810	Economy	11000.00
0005433681145	2810	Economy	11000.00
0005433681153	2810	Economy	11000.00
0005432966999	2810	Economy	11000.00
0005433681160	2810	Economy	11000.00
0005432967004	2810	Economy	11000.00
0005432967016	2810	Economy	11000.00
0005433681146	2810	Economy	11000.00
0005433681138	2810	Economy	11000.00
0005433681168	2810	Economy	11000.00
0005433681159	2810	Economy	11000.00
0005433681150	2810	Economy	11000.00
0005432967106	2810	Economy	11000.00
0005432966953	2810	Economy	11000.00
0005432222848	2810	Economy	11000.00
0005433681137	2810	Economy	11000.00
0005433681170	2810	Economy	11000.00
0005432967105	2810	Economy	11000.00
0005433680856	29176	Business	33000.00
0005432967257	29176	Business	33000.00
0005432967262	29176	Business	33000.00
0005433680837	29176	Business	33000.00
0005433680633	29176	Business	33000.00
0005432967242	29176	Business	33000.00
0005433690930	29176	Business	33000.00
0005433680646	29176	Business	33000.00
0005433680698	29176	Business	33000.00
0005433680661	29176	Business	33000.00
0005433680793	29176	Business	33000.00
0005432967240	29176	Economy	11000.00
0005432967248	29176	Economy	11000.00
0005433680807	29176	Economy	11000.00
0005432967256	29176	Economy	11000.00
0005433680778	29176	Economy	11000.00
0005433680728	29176	Economy	11000.00
0005432967246	29176	Economy	11000.00
0005433680854	29176	Economy	11000.00
0005432967261	29176	Economy	12100.00
0005432005248	29176	Economy	12100.00
0005433680971	29176	Economy	12100.00
0005433680472	29176	Economy	12100.00
0005433680634	29176	Economy	11000.00
0005433680860	29176	Economy	11000.00
0005433680818	29176	Economy	11000.00
0005432967258	29176	Economy	11000.00
0005432967251	29176	Economy	11000.00
0005433680870	29176	Economy	11000.00
0005432005247	29176	Economy	11000.00
0005433680806	29176	Economy	11000.00
0005433680825	29176	Economy	11000.00
0005433680805	29176	Economy	11000.00
0005433690932	29176	Economy	11000.00
0005433680701	29176	Economy	11000.00
0005433680497	29176	Economy	11000.00
0005433680826	29176	Economy	11000.00
0005432967241	29176	Economy	11000.00
0005433680731	29176	Economy	11000.00
0005433680780	29176	Economy	11000.00
0005433680835	29176	Economy	11000.00
0005432967249	29176	Economy	11000.00
0005433680859	29176	Economy	11000.00
0005433680779	29176	Economy	11000.00
0005432967244	29176	Economy	11000.00
0005433680729	29176	Economy	11000.00
0005432967250	29176	Economy	11000.00
0005432967239	29176	Economy	11000.00
0005433680871	29176	Economy	11000.00
0005433680653	29176	Economy	11000.00
0005433680792	29176	Economy	11000.00
0005433680765	29176	Economy	11000.00
0005433680869	29176	Economy	11000.00
0005433680618	29176	Economy	11000.00
0005433680879	29176	Economy	11000.00
0005432967245	29176	Economy	11000.00
0005433690929	29176	Economy	11000.00
0005432005249	29176	Economy	11000.00
0005433680817	29176	Economy	11000.00
0005432967252	29176	Economy	11000.00
0005433680853	29176	Economy	11000.00
0005433680662	29176	Economy	11000.00
0005432967247	29176	Economy	11000.00
0005432967253	29176	Economy	11000.00
0005432967243	29176	Economy	11000.00
0005433680967	29176	Economy	11000.00
0005432967260	29176	Economy	11000.00
0005432967238	29176	Economy	11000.00
0005433680647	29176	Economy	11000.00
0005433680730	29176	Economy	11000.00
0005432967255	29176	Economy	11000.00
0005433680617	29176	Economy	11000.00
0005433680762	29176	Economy	11000.00
0005432967254	29176	Economy	11000.00
0005433680756	29176	Economy	11000.00
0005433680482	29176	Economy	11000.00
0005432967237	29176	Economy	11000.00
0005433680723	29176	Economy	11000.00
0005433680878	29176	Economy	11000.00
0005433687707	29176	Economy	11000.00
0005432967259	29176	Economy	11000.00
0005433680645	29176	Economy	11000.00
0005433680481	29176	Economy	11000.00
0005433680968	29176	Economy	11000.00
0005433634220	9309	Business	132900.00
0005433615506	9309	Business	132900.00
0005433615524	9309	Business	132900.00
0005433615487	9309	Business	132900.00
0005434163670	9309	Business	132900.00
0005433634219	9309	Business	132900.00
0005432145134	9309	Business	132900.00
0005433615514	9309	Business	132900.00
0005434163654	9309	Business	132900.00
0005432756888	9309	Business	132900.00
0005433615504	9309	Business	132900.00
0005433634215	9309	Business	132900.00
0005433615517	9309	Business	132900.00
0005433615512	9309	Business	132900.00
0005433634213	9309	Business	132900.00
0005434163653	9309	Business	132900.00
0005433634193	9309	Business	132900.00
0005433615500	9309	Business	132900.00
0005433634196	9309	Business	132900.00
0005433577974	9309	Business	132900.00
0005433615537	9309	Business	132900.00
0005433634207	9309	Business	132900.00
0005433634203	9309	Economy	48700.00
0005432755118	9309	Economy	48700.00
0005433634216	9309	Economy	48700.00
0005434163639	9309	Economy	48700.00
0005433634190	9309	Economy	48700.00
0005433634198	9309	Economy	48700.00
0005433615549	9309	Economy	44300.00
0005432756887	9309	Economy	44300.00
0005433577967	9309	Economy	44300.00
0005432755117	9309	Economy	44300.00
0005433634210	9309	Economy	44300.00
0005434163646	9309	Economy	44300.00
0005433615530	9309	Economy	44300.00
0005433615552	9309	Economy	44300.00
0005433615501	9309	Economy	44300.00
0005433615516	9309	Economy	44300.00
0005433615553	9309	Economy	44300.00
0005433577972	9309	Economy	44300.00
0005433615499	9309	Economy	44300.00
0005433634221	9309	Economy	44300.00
0005433615488	9309	Economy	44300.00
0005433615538	9309	Economy	44300.00
0005433615541	9309	Economy	44300.00
0005433577975	9309	Economy	44300.00
0005433615542	9309	Economy	44300.00
0005433615523	9309	Economy	44300.00
0005433634195	9309	Economy	44300.00
0005433615495	9309	Economy	44300.00
0005433615502	9309	Economy	44300.00
0005433615545	9309	Economy	44300.00
0005433634223	9309	Economy	44300.00
0005433634199	9309	Economy	44300.00
0005432755115	9309	Economy	44300.00
0005433615489	9309	Economy	44300.00
0005433577968	9309	Economy	44300.00
0005433577977	9309	Economy	44300.00
0005434163642	9309	Economy	44300.00
0005434163675	9309	Economy	44300.00
0005433615519	9309	Economy	44300.00
0005433615548	9309	Economy	44300.00
0005432755116	9309	Economy	44300.00
0005433634212	9309	Economy	44300.00
0005433615539	9309	Economy	44300.00
0005433615490	9309	Economy	44300.00
0005433615482	9309	Economy	44300.00
0005432145136	9309	Economy	44300.00
0005434152796	9309	Economy	44300.00
0005433634200	9309	Economy	44300.00
0005433577973	9309	Economy	44300.00
0005433615554	9309	Economy	44300.00
0005433615533	9309	Economy	44300.00
0005433615555	9309	Economy	44300.00
0005433634205	9309	Economy	44300.00
0005433634194	9309	Economy	44300.00
0005433615511	9309	Economy	44300.00
0005433634224	9309	Economy	44300.00
0005433577978	9309	Economy	44300.00
0005433577976	9309	Economy	44300.00
0005433615556	9309	Economy	44300.00
0005433615547	9309	Economy	44300.00
0005433634222	9309	Economy	44300.00
0005433634197	9309	Economy	48700.00
0005433615494	9309	Economy	48700.00
0005433615485	9309	Economy	48700.00
0005433615483	9309	Economy	48700.00
0005433577969	9309	Economy	48700.00
0005433615508	9309	Economy	44300.00
0005433577971	9309	Economy	44300.00
0005433634201	9309	Economy	48700.00
0005433615509	9309	Economy	44300.00
0005433615546	9309	Economy	44300.00
0005433615551	9309	Economy	44300.00
0005433615496	9309	Economy	44300.00
0005433615505	9309	Economy	44300.00
0005433615507	9309	Economy	44300.00
0005434163644	9309	Economy	44300.00
0005433615510	9309	Economy	44300.00
0005433615529	9309	Economy	44300.00
0005433615492	9309	Economy	44300.00
0005433634202	9309	Economy	44300.00
0005432756889	9309	Economy	44300.00
0005433634206	9309	Economy	44300.00
0005433615522	9309	Economy	44300.00
0005434272193	9309	Economy	44300.00
0005433615534	9309	Economy	44300.00
0005434269102	9309	Economy	44300.00
0005434152795	9309	Economy	44300.00
0005433577970	9309	Economy	44300.00
0005433615520	9309	Economy	44300.00
0005434163671	9309	Economy	44300.00
0005433634218	9309	Economy	44300.00
0005433615493	9309	Economy	44300.00
0005433634191	9309	Economy	44300.00
0005434163645	9309	Economy	44300.00
0005433615497	9309	Economy	44300.00
0005433615535	9309	Economy	44300.00
0005433615543	9309	Economy	44300.00
0005433615526	9309	Economy	44300.00
0005433634192	9309	Economy	44300.00
0005433634211	9309	Economy	44300.00
0005433615525	9309	Economy	44300.00
0005433634217	9309	Economy	44300.00
0005433615515	9309	Economy	44300.00
0005433615503	9309	Economy	44300.00
0005433615521	9309	Economy	44300.00
0005433615498	9309	Economy	44300.00
0005433615540	9309	Economy	44300.00
0005433634204	9309	Economy	44300.00
0005433634208	9309	Economy	44300.00
0005433615518	9309	Economy	44300.00
0005433615532	9309	Economy	44300.00
0005433615531	9309	Economy	44300.00
0005433615528	9309	Economy	44300.00
0005433634214	9309	Economy	44300.00
0005434272194	9309	Economy	44300.00
0005433615513	9309	Economy	44300.00
0005433615544	9309	Economy	44300.00
0005433615527	9309	Economy	44300.00
0005433615491	9309	Economy	44300.00
0005433615484	9309	Economy	44300.00
0005433615486	9309	Economy	44300.00
0005433615536	9309	Economy	44300.00
0005434163643	9309	Economy	44300.00
0005433634209	9309	Economy	44300.00
0005432145135	9309	Economy	44300.00
0005433615550	9309	Economy	44300.00
0005433614946	25238	Business	132900.00
0005433614766	25238	Business	132900.00
0005433614784	25238	Business	132900.00
0005434163735	25238	Business	132900.00
0005433614773	25238	Business	132900.00
0005434163730	25238	Business	132900.00
0005433633951	25238	Business	132900.00
0005433614785	25238	Business	132900.00
0005433614760	25238	Business	132900.00
0005433614633	25238	Business	132900.00
0005434163731	25238	Business	132900.00
0005433614751	25238	Business	132900.00
0005433615044	25238	Business	132900.00
0005433614589	25238	Business	132900.00
0005434273095	25238	Business	132900.00
0005433614654	25238	Business	132900.00
0005433614894	25238	Business	132900.00
0005433614825	25238	Business	132900.00
0005433614962	25238	Business	132900.00
0005433614916	25238	Business	132900.00
0005433633942	25238	Economy	48700.00
0005433577863	25238	Business	132900.00
0005433614655	25238	Economy	48700.00
0005433614863	25238	Economy	48700.00
0005434163733	25238	Economy	48700.00
0005433614588	25238	Economy	48700.00
0005434163732	25238	Economy	48700.00
0005433615162	25238	Economy	44300.00
0005434163725	25238	Economy	44300.00
0005433614892	25238	Economy	44300.00
0005433633843	25238	Economy	44300.00
0005433614927	25238	Economy	44300.00
0005433633779	25238	Economy	44300.00
0005433614749	25238	Economy	44300.00
0005433615020	25238	Economy	44300.00
0005433615032	25238	Economy	44300.00
0005433615033	25238	Economy	44300.00
0005433614629	25238	Economy	44300.00
0005433577868	25238	Economy	44300.00
0005433614764	25238	Economy	44300.00
0005433615025	25238	Economy	44300.00
0005433577893	25238	Economy	44300.00
0005433614584	25238	Economy	44300.00
0005433633880	25238	Economy	44300.00
0005433614885	25238	Economy	44300.00
0005433577895	25238	Economy	44300.00
0005433633922	25238	Economy	44300.00
0005433633970	25238	Economy	44300.00
0005433633969	25238	Economy	44300.00
0005434163727	25238	Economy	44300.00
0005433615072	25238	Economy	44300.00
0005433577876	25238	Economy	44300.00
0005433615127	25238	Economy	44300.00
0005433577838	25238	Economy	44300.00
0005433577869	25238	Economy	44300.00
0005433615144	25238	Economy	44300.00
0005433633850	25238	Economy	44300.00
0005433614923	25238	Economy	44300.00
0005433614963	25238	Economy	44300.00
0005433633932	25238	Economy	44300.00
0005433577778	25238	Economy	44300.00
0005433614953	25238	Economy	44300.00
0005434272210	25238	Economy	44300.00
0005433614896	25238	Economy	44300.00
0005434273096	25238	Economy	44300.00
0005433615002	25238	Economy	44300.00
0005433633931	25238	Economy	44300.00
0005435854064	25238	Economy	44300.00
0005433577875	25238	Economy	44300.00
0005433614862	25238	Economy	44300.00
0005433614767	25238	Economy	44300.00
0005433614944	25238	Economy	44300.00
0005433614737	25238	Economy	44300.00
0005433614905	25238	Economy	48700.00
0005433614947	25238	Economy	48700.00
0005433614585	25238	Economy	44300.00
0005433633824	25238	Economy	44300.00
0005433614650	25238	Economy	44300.00
0005433614934	25238	Economy	44300.00
0005434163736	25238	Economy	44300.00
0005434163734	25238	Economy	44300.00
0005433615173	25238	Economy	44300.00
0005433633661	25238	Economy	44300.00
0005433633930	25238	Economy	44300.00
0005433615119	25238	Economy	44300.00
0005433633892	25238	Economy	44300.00
0005433577853	25238	Economy	44300.00
0005433614813	25238	Economy	44300.00
0005433615313	25238	Economy	44300.00
0005433633662	25238	Economy	44300.00
0005433614897	25238	Economy	44300.00
0005433615018	25238	Economy	44300.00
0005433614772	25238	Economy	44300.00
0005433614736	25238	Economy	44300.00
0005433614847	25238	Economy	44300.00
0005433633832	25238	Economy	44300.00
0005433577819	25238	Economy	44300.00
0005433577864	25238	Economy	44300.00
0005433614506	25238	Economy	44300.00
0005433614763	25238	Economy	44300.00
0005433633883	25238	Economy	44300.00
0005433614778	25238	Economy	44300.00
0005433614955	25238	Economy	44300.00
0005433614961	25238	Economy	44300.00
0005433615019	25238	Economy	44300.00
0005433614922	25238	Economy	44300.00
0005433633918	25238	Economy	44300.00
0005433614909	25238	Economy	44300.00
0005433615315	25238	Economy	44300.00
0005433614917	25238	Economy	44300.00
0005433633921	25238	Economy	44300.00
0005433614972	25238	Economy	44300.00
0005434163726	25238	Economy	44300.00
0005433614752	25238	Economy	44300.00
0005433633979	25238	Economy	44300.00
0005433633660	25238	Economy	44300.00
0005433577777	25238	Economy	44300.00
0005433614871	25238	Economy	44300.00
0005433577894	25238	Economy	44300.00
0005433614895	25238	Economy	44300.00
0005433633858	25238	Economy	44300.00
0005433633825	25238	Economy	44300.00
0005433577852	25238	Economy	44300.00
0005433633831	25238	Economy	44300.00
0005434163729	25238	Economy	44300.00
0005434163728	25238	Economy	44300.00
0005433615314	25238	Economy	44300.00
0005433614956	25238	Economy	44300.00
0005433614964	25238	Economy	44300.00
0005433614933	25238	Economy	44300.00
0005435854065	25238	Economy	44300.00
0005433577883	25238	Economy	44300.00
0005433633879	25238	Economy	44300.00
0005433615009	25238	Economy	44300.00
0005435947330	4226	Business	193100.00
0005435986850	4226	Business	193100.00
0005435856239	4226	Business	193100.00
0005435947304	4226	Business	193100.00
0005435947259	4226	Business	193100.00
0005435947292	4226	Business	193100.00
0005434271320	4226	Business	193100.00
0005435947257	4226	Business	193100.00
0005432184985	4226	Economy	70800.00
0005435856195	4226	Economy	64400.00
0005435986845	4226	Economy	64400.00
0005435947284	4226	Economy	64400.00
0005435986848	4226	Economy	64400.00
0005435986851	4226	Economy	64400.00
0005435856218	4226	Economy	64400.00
0005435856194	4226	Economy	64400.00
0005435947236	4226	Economy	64400.00
0005435986847	4226	Economy	64400.00
0005435787360	4226	Economy	64400.00
0005435947332	4226	Economy	64400.00
0005435854061	4226	Economy	64400.00
0005435947352	4226	Economy	64400.00
0005435947331	4226	Economy	64400.00
0005435856231	4226	Economy	64400.00
0005435856232	4226	Economy	64400.00
0005435947339	4226	Economy	64400.00
0005435947300	4226	Economy	64400.00
0005435947338	4226	Economy	64400.00
0005434271305	4226	Economy	64400.00
0005435856230	4226	Economy	64400.00
0005432571327	4226	Economy	64400.00
0005435947281	4226	Economy	64400.00
0005434271321	4226	Economy	64400.00
0005435947305	4226	Economy	64400.00
0005432571336	4226	Economy	64400.00
0005432184986	4226	Economy	64400.00
0005435986846	4226	Economy	64400.00
0005434271306	4226	Economy	64400.00
0005435986849	4226	Economy	64400.00
0005432184988	4226	Economy	64400.00
0005435947351	4226	Economy	64400.00
0005432184987	4226	Economy	64400.00
0005432571372	26612	Business	193100.00
0005435986792	26612	Business	193100.00
0005435986771	26612	Business	193100.00
0005435947439	26612	Business	193100.00
0005435787382	26612	Business	193100.00
0005435986797	26612	Business	193100.00
0005435947437	26612	Business	193100.00
0005435856259	26612	Economy	64400.00
0005435947440	26612	Economy	64400.00
0005435947436	26612	Economy	64400.00
0005435947438	26612	Economy	64400.00
0005435856257	26612	Economy	64400.00
0005435787383	26612	Economy	64400.00
0005435947430	26612	Economy	64400.00
0005432571370	26612	Economy	64400.00
0005435947441	26612	Economy	64400.00
0005435947435	26612	Economy	64400.00
0005435947443	26612	Economy	64400.00
0005432571371	26612	Economy	64400.00
0005435986747	26612	Economy	64400.00
0005435986764	26612	Economy	64400.00
0005435947434	26612	Economy	64400.00
0005435947442	26612	Economy	64400.00
0005435856255	26612	Economy	64400.00
0005435947432	26612	Economy	64400.00
0005435986772	26612	Economy	64400.00
0005435986748	26612	Economy	64400.00
0005435947431	26612	Economy	64400.00
0005435986796	26612	Economy	64400.00
0005435787384	26612	Economy	70800.00
0005435947433	26612	Economy	64400.00
0005435856256	26612	Economy	64400.00
0005435856258	26612	Economy	64400.00
0005435947429	26612	Economy	64400.00
0005432571369	26612	Economy	64400.00
0005433074914	365	Business	21500.00
0005433569793	365	Business	21500.00
0005433569767	365	Business	21500.00
0005433074866	365	Business	21500.00
0005433569806	365	Business	21500.00
0005433134163	365	Business	21500.00
0005433569836	365	Business	21500.00
0005433074714	365	Business	21500.00
0005432239012	365	Business	21500.00
0005433129302	365	Business	21500.00
0005433129303	365	Business	21500.00
0005433134144	365	Business	21500.00
0005432948801	365	Business	21500.00
0005433074813	365	Business	21500.00
0005433074794	365	Business	21500.00
0005433569775	365	Business	21500.00
0005433569827	365	Business	21500.00
0005432948492	365	Business	21500.00
0005433569798	365	Business	21500.00
0005432948727	365	Business	21500.00
0005433074812	365	Business	21500.00
0005432948673	365	Business	21500.00
0005433569807	365	Business	21500.00
0005433074879	365	Business	21500.00
0005433129291	365	Business	21500.00
0005433569778	365	Business	21500.00
0005432948474	365	Business	21500.00
0005432948663	365	Economy	7900.00
0005433074810	365	Economy	7900.00
0005433074793	365	Economy	7900.00
0005433569770	365	Economy	7900.00
0005433569803	365	Economy	7900.00
0005433074924	365	Economy	7200.00
0005433569773	365	Economy	7200.00
0005433074839	365	Economy	7200.00
0005433569805	365	Economy	7200.00
0005433569824	365	Economy	7200.00
0005433074696	365	Economy	7200.00
0005433569822	365	Economy	7200.00
0005433074822	365	Economy	7200.00
0005432948680	365	Economy	7200.00
0005433074874	365	Economy	7200.00
0005432948543	365	Economy	7200.00
0005433569821	365	Economy	7200.00
0005432239011	365	Economy	7200.00
0005432948681	365	Economy	7200.00
0005432948672	365	Economy	7200.00
0005433074823	365	Economy	7200.00
0005433074875	365	Economy	7200.00
0005432948632	365	Economy	7200.00
0005432948431	365	Economy	7200.00
0005433074816	365	Economy	7200.00
0005432948731	365	Economy	7200.00
0005432239013	365	Economy	7200.00
0005432948763	365	Economy	7200.00
0005433569786	365	Economy	7200.00
0005432239015	365	Economy	7200.00
0005433074811	365	Economy	7200.00
0005432948599	365	Economy	7200.00
0005432948447	365	Economy	7200.00
0005433129290	365	Economy	7200.00
0005433569795	365	Economy	7200.00
0005432239010	365	Economy	7200.00
0005433569783	365	Economy	7200.00
0005433074764	365	Economy	7200.00
0005432948454	365	Economy	7200.00
0005433569779	365	Economy	7200.00
0005433569812	365	Economy	7200.00
0005433569832	365	Economy	7200.00
0005432948586	365	Economy	7200.00
0005433569788	365	Economy	7200.00
0005432948666	365	Economy	7200.00
0005433074851	365	Economy	7200.00
0005433569781	365	Economy	7200.00
0005433569789	365	Economy	7200.00
0005433569797	365	Economy	7200.00
0005433569818	365	Economy	7200.00
0005433569835	365	Economy	7200.00
0005433569830	365	Economy	7200.00
0005433074821	365	Economy	7200.00
0005432948765	365	Economy	7200.00
0005433074809	365	Economy	7200.00
0005433569831	365	Economy	7200.00
0005433569799	365	Economy	7200.00
0005433074695	365	Economy	7200.00
0005432948683	365	Economy	7200.00
0005433569800	365	Economy	7200.00
0005433569820	365	Economy	7200.00
0005433074852	365	Economy	7200.00
0005433129296	365	Economy	7200.00
0005432948764	365	Economy	7200.00
0005432948430	365	Economy	7900.00
0005432948670	365	Economy	7900.00
0005432948598	365	Economy	7900.00
0005432948640	365	Economy	7900.00
0005433569796	365	Economy	7900.00
0005433569813	365	Economy	7200.00
0005432948475	365	Economy	7200.00
0005432948544	365	Economy	7200.00
0005433569817	365	Economy	7200.00
0005433134143	365	Economy	7900.00
0005433569826	365	Economy	7200.00
0005433569809	365	Economy	7200.00
0005432948458	365	Economy	7200.00
0005433569772	365	Economy	7200.00
0005433134150	365	Economy	7200.00
0005433569794	365	Economy	7200.00
0005432239014	365	Economy	7200.00
0005433074765	365	Economy	7200.00
0005432948790	365	Economy	7200.00
0005433569828	365	Economy	7200.00
0005432948619	365	Economy	7200.00
0005433569811	365	Economy	7200.00
0005432239009	365	Economy	7200.00
0005433569808	365	Economy	7200.00
0005433129301	365	Economy	7200.00
0005433569768	365	Economy	7200.00
0005433569787	365	Economy	7200.00
0005433074865	365	Economy	7200.00
0005433134149	365	Economy	7200.00
0005433074825	365	Economy	7200.00
0005433569804	365	Economy	7200.00
0005433569790	365	Economy	7200.00
0005433569771	365	Economy	7200.00
0005433074840	365	Economy	7200.00
0005433569829	365	Economy	7200.00
0005432948740	365	Economy	7200.00
0005433569777	365	Economy	7200.00
0005433569819	365	Economy	7200.00
0005433569780	365	Economy	7200.00
0005433569784	365	Economy	7200.00
0005433569816	365	Economy	7200.00
0005433074913	365	Economy	7200.00
0005433134151	365	Economy	7200.00
0005433569823	365	Economy	7200.00
0005433569825	365	Economy	7200.00
0005433074709	365	Economy	7200.00
0005433569782	365	Economy	7200.00
0005432948636	365	Economy	7200.00
0005433569833	365	Economy	7200.00
0005432948485	365	Economy	7200.00
0005433074757	365	Economy	7200.00
0005432948491	365	Economy	7200.00
0005433569814	365	Economy	7200.00
0005433569791	365	Economy	7200.00
0005433569810	365	Economy	7200.00
0005433074668	365	Economy	7200.00
0005432948674	365	Economy	7200.00
0005433569769	365	Economy	7200.00
0005432948631	365	Economy	7200.00
0005433074871	365	Economy	7200.00
0005432948570	365	Economy	7200.00
0005433569815	365	Economy	7200.00
0005433569774	365	Economy	7200.00
0005432948679	365	Economy	7200.00
0005433569785	365	Economy	7200.00
0005433569776	365	Economy	7200.00
0005432948641	365	Economy	7200.00
0005433134148	365	Economy	7200.00
0005433074817	365	Economy	7200.00
0005433074915	365	Economy	7200.00
0005433569834	365	Economy	7200.00
0005433074818	365	Economy	7200.00
0005433569801	365	Economy	7200.00
0005433569802	365	Economy	7200.00
0005433569792	365	Economy	7200.00
0005433569283	11562	Business	21500.00
0005432948950	11562	Business	21500.00
0005433131766	11562	Business	21500.00
0005433568936	11562	Business	21500.00
0005433569264	11562	Business	21500.00
0005432948935	11562	Business	21500.00
0005433569176	11562	Business	21500.00
0005433134195	11562	Business	21500.00
0005433569296	11562	Business	21500.00
0005433569281	11562	Business	21500.00
0005433075056	11562	Business	21500.00
0005433569095	11562	Business	21500.00
0005433075053	11562	Business	21500.00
0005432948932	11562	Business	21500.00
0005433569165	11562	Business	21500.00
0005433569050	11562	Business	21500.00
0005432948973	11562	Business	21500.00
0005433075045	11562	Business	21500.00
0005433569168	11562	Business	21500.00
0005433569064	11562	Business	21500.00
0005433075046	11562	Business	21500.00
0005432948941	11562	Business	21500.00
0005432948970	11562	Economy	7900.00
0005432948957	11562	Economy	7900.00
0005433569137	11562	Economy	7900.00
0005433131763	11562	Economy	7900.00
0005433569220	11562	Economy	7900.00
0005433075054	11562	Economy	7900.00
0005433569249	11562	Economy	7200.00
0005433075047	11562	Economy	7200.00
0005432948964	11562	Economy	7200.00
0005433569219	11562	Economy	7200.00
0005432192359	11562	Economy	7200.00
0005433131764	11562	Economy	7200.00
0005433075067	11562	Economy	7200.00
0005433569025	11562	Economy	7200.00
0005432948938	11562	Economy	7200.00
0005433569073	11562	Economy	7200.00
0005433075062	11562	Economy	7200.00
0005433569239	11562	Economy	7200.00
0005433569080	11562	Economy	7200.00
0005433568937	11562	Economy	7200.00
0005433131765	11562	Economy	7200.00
0005433131762	11562	Economy	7200.00
0005432948972	11562	Economy	7200.00
0005433569285	11562	Economy	7200.00
0005433134197	11562	Economy	7200.00
0005433075050	11562	Economy	7200.00
0005433569240	11562	Economy	7200.00
0005432948943	11562	Economy	7200.00
0005432948953	11562	Economy	7200.00
0005433569194	11562	Economy	7200.00
0005433569203	11562	Economy	7200.00
0005433134194	11562	Economy	7200.00
0005432948937	11562	Economy	7200.00
0005433075063	11562	Economy	7200.00
0005432948951	11562	Economy	7200.00
0005432948942	11562	Economy	7200.00
0005433569248	11562	Economy	7200.00
0005432948955	11562	Economy	7200.00
0005432948971	11562	Economy	7200.00
0005432948948	11562	Economy	7200.00
0005433075068	11562	Economy	7200.00
0005432192360	11562	Economy	7200.00
0005433568972	11562	Economy	7200.00
0005433569069	11562	Economy	7200.00
0005433569236	11562	Economy	7200.00
0005433568692	11562	Economy	7200.00
0005433075059	11562	Economy	7200.00
0005433569127	11562	Economy	7200.00
0005433134193	11562	Economy	7200.00
0005432948939	11562	Economy	7200.00
0005432948959	11562	Economy	7200.00
0005433568873	11562	Economy	7200.00
0005433075061	11562	Economy	7200.00
0005432948944	11562	Economy	7200.00
0005433569074	11562	Economy	7200.00
0005433569136	11562	Economy	7200.00
0005433075052	11562	Economy	7200.00
0005433134192	11562	Economy	7200.00
0005433569288	11562	Economy	7200.00
0005433075055	11562	Economy	7900.00
0005433075070	11562	Economy	7200.00
0005433569032	11562	Economy	7900.00
0005432948945	11562	Economy	7900.00
0005433075048	11562	Economy	7900.00
0005433569202	11562	Economy	7900.00
0005433075058	11562	Economy	7200.00
0005432948968	11562	Economy	7200.00
0005433075051	11562	Economy	7200.00
0005432948946	11562	Economy	7900.00
0005433569257	11562	Economy	7200.00
0005433569195	11562	Economy	7200.00
0005432948960	11562	Economy	7200.00
0005432948963	11562	Economy	7200.00
0005433569295	11562	Economy	7200.00
0005433568998	11562	Economy	7200.00
0005433569084	11562	Economy	7200.00
0005432948933	11562	Economy	7200.00
0005432948969	11562	Economy	7200.00
0005433568935	11562	Economy	7200.00
0005433569169	11562	Economy	7200.00
0005432948962	11562	Economy	7200.00
0005433569029	11562	Economy	7200.00
0005433568802	11562	Economy	7200.00
0005432948947	11562	Economy	7200.00
0005433131767	11562	Economy	7200.00
0005432948934	11562	Economy	7200.00
0005432948966	11562	Economy	7200.00
0005433075044	11562	Economy	7200.00
0005433569221	11562	Economy	7200.00
0005432948956	11562	Economy	7200.00
0005432948958	11562	Economy	7200.00
0005432948954	11562	Economy	7200.00
0005433569265	11562	Economy	7200.00
0005433075057	11562	Economy	7200.00
0005433075066	11562	Economy	7200.00
0005433075049	11562	Economy	7200.00
0005433569286	11562	Economy	7200.00
0005432948952	11562	Economy	7200.00
0005433075069	11562	Economy	7200.00
0005432192358	11562	Economy	7200.00
0005433075064	11562	Economy	7200.00
0005433568995	11562	Economy	7200.00
0005433569297	11562	Economy	7200.00
0005433569282	11562	Economy	7200.00
0005433569256	11562	Economy	7200.00
0005433134196	11562	Economy	7200.00
0005433569049	11562	Economy	7200.00
0005433569087	11562	Economy	7200.00
0005433569171	11562	Economy	7200.00
0005432948965	11562	Economy	7200.00
0005432948967	11562	Economy	7200.00
0005433569287	11562	Economy	7200.00
0005433569231	11562	Economy	7200.00
0005433075065	11562	Economy	7200.00
0005432948961	11562	Economy	7200.00
0005432948931	11562	Economy	7200.00
0005432948940	11562	Economy	7200.00
0005433568958	11562	Economy	7200.00
0005433569232	11562	Economy	7200.00
0005433569086	11562	Economy	7200.00
0005432948949	11562	Economy	7200.00
0005433569250	11562	Economy	7200.00
0005433569139	11562	Economy	7200.00
0005432948936	11562	Economy	7200.00
0005433075060	11562	Economy	7200.00
0005434733002	9959	Economy	6300.00
0005433817516	9959	Economy	6300.00
0005433817518	9959	Economy	6300.00
0005434732996	9959	Economy	6300.00
0005434732986	9959	Economy	6300.00
0005434732993	9959	Economy	6300.00
0005433817517	9959	Economy	6300.00
0005433817515	9959	Economy	6300.00
0005434733001	9959	Economy	6300.00
0005433817482	13990	Economy	6300.00
0005434733025	13990	Economy	6300.00
0005434733023	13990	Economy	6300.00
0005433817500	13990	Economy	6300.00
0005433817499	13990	Economy	6300.00
0005433817501	13990	Economy	6300.00
0005434733024	13990	Economy	6300.00
0005432655692	2351	Business	184500.00
0005432226138	2351	Business	184500.00
0005432985186	2351	Business	184500.00
0005432985135	2351	Business	184500.00
0005435982850	2351	Business	184500.00
0005433754936	2351	Business	184500.00
0005435982854	2351	Business	184500.00
0005435982852	2351	Business	184500.00
0005432869535	2351	Business	184500.00
0005432985199	2351	Business	184500.00
0005432655688	2351	Business	184500.00
0005435982851	2351	Business	184500.00
0005435982845	2351	Business	184500.00
0005432985175	2351	Business	184500.00
0005432985254	2351	Business	184500.00
0005433754893	2351	Business	184500.00
0005433434728	2351	Business	184500.00
0005433766686	2351	Business	184500.00
0005435982858	2351	Business	184500.00
0005435982844	2351	Business	184500.00
0005432985071	2351	Business	184500.00
0005433754924	2351	Business	184500.00
0005432655680	2351	Business	184500.00
0005432985188	2351	Business	184500.00
0005435982874	2351	Business	184500.00
0005433754945	2351	Business	184500.00
0005435982853	2351	Business	184500.00
0005435982861	2351	Business	184500.00
0005433434690	2351	Business	184500.00
0005432655683	2351	Economy	67700.00
0005432985187	2351	Economy	67700.00
0005435982891	2351	Economy	67700.00
0005433754907	2351	Economy	67700.00
0005432985200	2351	Economy	61500.00
0005433754902	2351	Economy	61500.00
0005433754905	2351	Economy	61500.00
0005432985246	2351	Economy	61500.00
0005432300337	2351	Economy	61500.00
0005432226137	2351	Economy	61500.00
0005433754923	2351	Economy	61500.00
0005432655690	2351	Economy	61500.00
0005433754933	2351	Economy	61500.00
0005433754935	2351	Economy	61500.00
0005433754944	2351	Economy	61500.00
0005433754928	2351	Economy	61500.00
0005432985256	2351	Economy	61500.00
0005432300336	2351	Economy	61500.00
0005433764704	2351	Economy	61500.00
0005435982889	2351	Economy	61500.00
0005433754948	2351	Economy	61500.00
0005433754894	2351	Economy	61500.00
0005435982870	2351	Economy	61500.00
0005435982848	2351	Economy	61500.00
0005432226133	2351	Economy	61500.00
0005433434821	2351	Economy	61500.00
0005432655689	2351	Economy	61500.00
0005433754942	2351	Economy	61500.00
0005432985299	2351	Economy	61500.00
0005435982877	2351	Economy	61500.00
0005433754911	2351	Economy	61500.00
0005433434834	2351	Economy	61500.00
0005432655687	2351	Economy	61500.00
0005435982884	2351	Economy	61500.00
0005433434781	2351	Economy	61500.00
0005434731166	2351	Economy	61500.00
0005433754909	2351	Economy	61500.00
0005432985245	2351	Economy	61500.00
0005433434749	2351	Economy	61500.00
0005432985101	2351	Economy	61500.00
0005435982872	2351	Economy	61500.00
0005432985216	2351	Economy	61500.00
0005433766687	2351	Economy	61500.00
0005433766689	2351	Economy	61500.00
0005432985138	2351	Economy	61500.00
0005433754938	2351	Economy	61500.00
0005433434920	2351	Economy	61500.00
0005435982863	2351	Economy	61500.00
0005433754932	2351	Economy	61500.00
0005435982886	2351	Economy	61500.00
0005433754934	2351	Economy	61500.00
0005432869533	2351	Economy	61500.00
0005433754900	2351	Economy	61500.00
0005434731188	2351	Economy	61500.00
0005432985300	2351	Economy	61500.00
0005432985237	2351	Economy	61500.00
0005433754930	2351	Economy	61500.00
0005433754919	2351	Economy	61500.00
0005435982888	2351	Economy	61500.00
0005433754937	2351	Economy	61500.00
0005433434777	2351	Economy	61500.00
0005433434773	2351	Economy	61500.00
0005435982879	2351	Economy	61500.00
0005432985253	2351	Economy	61500.00
0005433754925	2351	Economy	61500.00
0005433434624	2351	Economy	61500.00
0005432226135	2351	Economy	61500.00
0005433754892	2351	Economy	61500.00
0005435982893	2351	Economy	61500.00
0005433434751	2351	Economy	61500.00
0005433754897	2351	Economy	61500.00
0005433434756	2351	Economy	61500.00
0005433754927	2351	Economy	61500.00
0005432985171	2351	Economy	61500.00
0005432300334	2351	Economy	61500.00
0005435982847	2351	Economy	61500.00
0005435982860	2351	Economy	61500.00
0005433754910	2351	Economy	61500.00
0005433434779	2351	Economy	61500.00
0005432226134	2351	Economy	61500.00
0005433754901	2351	Economy	61500.00
0005432655693	2351	Economy	61500.00
0005433764706	2351	Economy	61500.00
0005435982885	2351	Economy	61500.00
0005433754913	2351	Economy	61500.00
0005433754917	2351	Economy	61500.00
0005432655682	2351	Economy	61500.00
0005432985217	2351	Economy	61500.00
0005435982869	2351	Economy	61500.00
0005433754899	2351	Economy	61500.00
0005433434750	2351	Economy	61500.00
0005433434823	2351	Economy	61500.00
0005433754929	2351	Economy	61500.00
0005433754947	2351	Economy	61500.00
0005433434883	2351	Economy	61500.00
0005432226136	2351	Economy	61500.00
0005433754891	2351	Economy	61500.00
0005435982868	2351	Economy	61500.00
0005433754906	2351	Economy	61500.00
0005432985185	2351	Economy	67700.00
0005433754931	2351	Economy	61500.00
0005432985182	2351	Economy	61500.00
0005433434782	2351	Economy	61500.00
0005433754898	2351	Economy	67700.00
0005432985236	2351	Economy	67700.00
0005433754912	2351	Economy	61500.00
0005433754896	2351	Economy	61500.00
0005435982849	2351	Economy	61500.00
0005433434792	2351	Economy	61500.00
0005432985230	2351	Economy	61500.00
0005432655684	2351	Economy	61500.00
0005435982865	2351	Economy	61500.00
0005435982876	2351	Economy	61500.00
0005433764705	2351	Economy	61500.00
0005435982857	2351	Economy	61500.00
0005433754895	2351	Economy	61500.00
0005434731206	2351	Economy	61500.00
0005433754921	2351	Economy	61500.00
0005435982867	2351	Economy	61500.00
0005435982864	2351	Economy	61500.00
0005435982883	2351	Economy	61500.00
0005433434921	2351	Economy	61500.00
0005434731186	2351	Economy	61500.00
0005432985261	2351	Economy	61500.00
0005433754939	2351	Economy	61500.00
0005432300335	2351	Economy	61500.00
0005435982866	2351	Economy	61500.00
0005435982892	2351	Economy	61500.00
0005432869534	2351	Economy	61500.00
0005435982887	2351	Economy	61500.00
0005432985096	2351	Economy	61500.00
0005435982859	2351	Economy	61500.00
0005433754943	2351	Economy	61500.00
0005433766688	2351	Economy	61500.00
0005433434791	2351	Economy	61500.00
0005432655685	2351	Economy	61500.00
0005433434771	2351	Economy	61500.00
0005435982856	2351	Economy	61500.00
0005434731184	2351	Economy	61500.00
0005433754920	2351	Economy	61500.00
0005433434772	2351	Economy	61500.00
0005434731187	2351	Economy	61500.00
0005433754946	2351	Economy	61500.00
0005432985220	2351	Economy	61500.00
0005433754941	2351	Economy	61500.00
0005433754916	2351	Economy	61500.00
0005435982882	2351	Economy	61500.00
0005435982875	2351	Economy	61500.00
0005433754915	2351	Economy	61500.00
0005435982855	2351	Economy	61500.00
0005435982862	2351	Economy	61500.00
0005435982846	2351	Economy	61500.00
0005433434775	2351	Economy	61500.00
0005433754918	2351	Economy	61500.00
0005435982881	2351	Economy	61500.00
0005433754922	2351	Economy	61500.00
0005432655681	2351	Economy	61500.00
0005435982880	2351	Economy	61500.00
0005433754914	2351	Economy	61500.00
0005433754940	2351	Economy	61500.00
0005432300338	2351	Economy	61500.00
0005432869512	2351	Economy	61500.00
0005433434884	2351	Economy	61500.00
0005433754903	2351	Economy	61500.00
0005433754904	2351	Economy	61500.00
0005433434778	2351	Economy	61500.00
0005432869541	2351	Economy	61500.00
0005433434729	2351	Economy	61500.00
0005432655691	2351	Economy	61500.00
0005435982873	2351	Economy	61500.00
0005432300333	2351	Economy	61500.00
0005435982890	2351	Economy	61500.00
0005435982878	2351	Economy	61500.00
0005433754926	2351	Economy	61500.00
0005433754908	2351	Economy	61500.00
0005432869547	2351	Economy	61500.00
0005435982871	2351	Economy	61500.00
0005432655686	2351	Economy	61500.00
0005432226132	2351	Economy	61500.00
0005433434702	2351	Economy	61500.00
0005432985483	26189	Business	184500.00
0005432985486	26189	Business	184500.00
0005433435029	26189	Business	184500.00
0005432049508	26189	Business	184500.00
0005433754037	26189	Business	184500.00
0005432655572	26189	Business	184500.00
0005433754383	26189	Business	184500.00
0005433754403	26189	Business	184500.00
0005433754405	26189	Business	184500.00
0005434731223	26189	Business	184500.00
0005433754579	26189	Business	184500.00
0005433754421	26189	Business	184500.00
0005435982420	26189	Business	184500.00
0005432869606	26189	Business	184500.00
0005433754527	26189	Business	184500.00
0005435982345	26189	Business	184500.00
0005435982489	26189	Business	184500.00
0005433754411	26189	Business	184500.00
0005433764685	26189	Business	184500.00
0005435982342	26189	Business	184500.00
0005433754233	26189	Business	184500.00
0005433435015	26189	Business	184500.00
0005432985471	26189	Business	184500.00
0005433435036	26189	Business	184500.00
0005433754630	26189	Business	184500.00
0005432985463	26189	Business	184500.00
0005435982601	26189	Business	184500.00
0005433435042	26189	Business	184500.00
0005433754350	26189	Economy	67700.00
0005432985485	26189	Economy	67700.00
0005432655595	26189	Economy	67700.00
0005432985473	26189	Economy	61500.00
0005433754556	26189	Economy	61500.00
0005433754342	26189	Economy	61500.00
0005435982461	26189	Economy	61500.00
0005433435019	26189	Economy	61500.00
0005435982308	26189	Economy	61500.00
0005435982382	26189	Economy	61500.00
0005433754215	26189	Economy	61500.00
0005432985489	26189	Economy	61500.00
0005433754544	26189	Economy	61500.00
0005435982637	26189	Economy	61500.00
0005432985477	26189	Economy	61500.00
0005435982367	26189	Economy	61500.00
0005432655594	26189	Economy	61500.00
0005432655566	26189	Economy	61500.00
0005433754160	26189	Economy	61500.00
0005433435041	26189	Economy	61500.00
0005432655606	26189	Economy	61500.00
0005435982452	26189	Economy	61500.00
0005432051168	26189	Economy	61500.00
0005433754386	26189	Economy	61500.00
0005435982506	26189	Economy	61500.00
0005432869603	26189	Economy	61500.00
0005433435020	26189	Economy	61500.00
0005432985468	26189	Economy	61500.00
0005433754772	26189	Economy	61500.00
0005433754278	26189	Economy	61500.00
0005433435025	26189	Economy	61500.00
0005433754580	26189	Economy	61500.00
0005433754545	26189	Economy	61500.00
0005433435032	26189	Economy	61500.00
0005433754325	26189	Economy	61500.00
0005435982443	26189	Economy	61500.00
0005432985478	26189	Economy	61500.00
0005433435026	26189	Economy	61500.00
0005433754406	26189	Economy	61500.00
0005432985482	26189	Economy	61500.00
0005435982311	26189	Economy	61500.00
0005435982462	26189	Economy	61500.00
0005432655543	26189	Economy	61500.00
0005433435040	26189	Economy	61500.00
0005433435037	26189	Economy	61500.00
0005433435033	26189	Economy	61500.00
0005435982312	26189	Economy	61500.00
0005432049507	26189	Economy	61500.00
0005435982421	26189	Economy	61500.00
0005432655571	26189	Economy	61500.00
0005433754428	26189	Economy	61500.00
0005432985464	26189	Economy	61500.00
0005433754583	26189	Economy	61500.00
0005432985474	26189	Economy	61500.00
0005433754476	26189	Economy	61500.00
0005432985465	26189	Economy	61500.00
0005433435024	26189	Economy	61500.00
0005433435038	26189	Economy	61500.00
0005432869604	26189	Economy	61500.00
0005432985466	26189	Economy	61500.00
0005433754201	26189	Economy	61500.00
0005434731225	26189	Economy	61500.00
0005435982353	26189	Economy	61500.00
0005432655567	26189	Economy	61500.00
0005433754185	26189	Economy	61500.00
0005435982291	26189	Economy	61500.00
0005433766656	26189	Economy	61500.00
0005432985491	26189	Economy	61500.00
0005433766649	26189	Economy	61500.00
0005432985476	26189	Economy	61500.00
0005433754385	26189	Economy	61500.00
0005435982296	26189	Economy	61500.00
0005432985479	26189	Economy	61500.00
0005433766648	26189	Economy	61500.00
0005435982417	26189	Economy	61500.00
0005435982539	26189	Economy	61500.00
0005435982330	26189	Economy	61500.00
0005433754288	26189	Economy	61500.00
0005433754348	26189	Economy	61500.00
0005432985494	26189	Economy	61500.00
0005432985467	26189	Economy	61500.00
0005435982566	26189	Economy	61500.00
0005435982405	26189	Economy	61500.00
0005433754408	26189	Economy	61500.00
0005432985493	26189	Economy	61500.00
0005434731224	26189	Economy	61500.00
0005433754324	26189	Economy	61500.00
0005432869605	26189	Economy	61500.00
0005435982453	26189	Economy	61500.00
0005432985490	26189	Economy	61500.00
0005435982636	26189	Economy	61500.00
0005432049509	26189	Economy	61500.00
0005434731222	26189	Economy	61500.00
0005435982451	26189	Economy	61500.00
0005433435027	26189	Economy	67700.00
0005433766661	26189	Economy	61500.00
0005435982248	26189	Economy	67700.00
0005433754496	26189	Economy	61500.00
0005433754283	26189	Economy	61500.00
0005433754604	26189	Economy	61500.00
0005432869601	26189	Economy	67700.00
0005435982350	26189	Economy	67700.00
0005432985487	26189	Economy	61500.00
0005432985492	26189	Economy	61500.00
0005433754525	26189	Economy	61500.00
0005433754279	26189	Economy	61500.00
0005435982447	26189	Economy	61500.00
0005435982488	26189	Economy	61500.00
0005433754443	26189	Economy	61500.00
0005432655568	26189	Economy	61500.00
0005433754458	26189	Economy	61500.00
0005433435034	26189	Economy	61500.00
0005433754339	26189	Economy	61500.00
0005433766641	26189	Economy	61500.00
0005435982614	26189	Economy	61500.00
0005433435018	26189	Economy	61500.00
0005433754600	26189	Economy	61500.00
0005433754327	26189	Economy	61500.00
0005435982538	26189	Economy	61500.00
0005433754326	26189	Economy	61500.00
0005433435031	26189	Economy	61500.00
0005433754407	26189	Economy	61500.00
0005433435039	26189	Economy	61500.00
0005433754260	26189	Economy	61500.00
0005433754346	26189	Economy	61500.00
0005433754438	26189	Economy	61500.00
0005433435017	26189	Economy	61500.00
0005435982422	26189	Economy	61500.00
0005432985472	26189	Economy	61500.00
0005433754300	26189	Economy	61500.00
0005433754289	26189	Economy	61500.00
0005435982484	26189	Economy	61500.00
0005432985484	26189	Economy	61500.00
0005433435023	26189	Economy	61500.00
0005432655576	26189	Economy	61500.00
0005433754526	26189	Economy	61500.00
0005433754578	26189	Economy	61500.00
0005433754232	26189	Economy	61500.00
0005432655573	26189	Economy	61500.00
0005433754349	26189	Economy	61500.00
0005435982511	26189	Economy	61500.00
0005435982247	26189	Economy	61500.00
0005433754436	26189	Economy	61500.00
0005435982647	26189	Economy	61500.00
0005435982349	26189	Economy	61500.00
0005433754435	26189	Economy	61500.00
0005433435035	26189	Economy	61500.00
0005435982505	26189	Economy	61500.00
0005432985488	26189	Economy	61500.00
0005435982481	26189	Economy	61500.00
0005435982366	26189	Economy	61500.00
0005432985475	26189	Economy	61500.00
0005433435016	26189	Economy	61500.00
0005432051166	26189	Economy	61500.00
0005432985469	26189	Economy	61500.00
0005432985481	26189	Economy	61500.00
0005435982344	26189	Economy	61500.00
0005433435030	26189	Economy	61500.00
0005433435028	26189	Economy	61500.00
0005435982648	26189	Economy	61500.00
0005433435021	26189	Economy	61500.00
0005432985470	26189	Economy	61500.00
0005433435022	26189	Economy	61500.00
0005432051167	26189	Economy	61500.00
0005435982343	26189	Economy	61500.00
0005435982446	26189	Economy	61500.00
0005432985480	26189	Economy	61500.00
0005432869602	26189	Economy	61500.00
0005433754601	26189	Economy	61500.00
0005435982352	26189	Economy	61500.00
0005432051165	26189	Economy	61500.00
0005435982548	26189	Economy	61500.00
0005433151551	1527	Business	38900.00
0005433151437	1527	Business	38900.00
0005433151438	1527	Business	38900.00
0005433151597	1527	Business	38900.00
0005433151623	1527	Business	38900.00
0005434375197	1527	Business	38900.00
0005434375212	1527	Business	38900.00
0005434375192	1527	Business	38900.00
0005434375201	1527	Business	38900.00
0005433151490	1527	Economy	13000.00
0005433461614	1527	Economy	13000.00
0005434375217	1527	Economy	13000.00
0005433931481	1527	Economy	13000.00
0005434375193	1527	Economy	13000.00
0005433151533	1527	Economy	13000.00
0005434029666	1527	Economy	13000.00
0005433461615	1527	Economy	13000.00
0005433151619	1527	Economy	13000.00
0005434375205	1527	Economy	13000.00
0005434375218	1527	Economy	13000.00
0005434375200	1527	Economy	13000.00
0005433151513	1527	Economy	13000.00
0005434375196	1527	Economy	13000.00
0005433764686	1527	Economy	13000.00
0005434375224	1527	Economy	13000.00
0005434375215	1527	Economy	13000.00
0005434375199	1527	Economy	13000.00
0005433151618	1527	Economy	13000.00
0005434029665	1527	Economy	13000.00
0005434375222	1527	Economy	13000.00
0005433151596	1527	Economy	13000.00
0005433151517	1527	Economy	13000.00
0005432267979	1527	Economy	13000.00
0005433151516	1527	Economy	13000.00
0005433151648	1527	Economy	13000.00
0005433151518	1527	Economy	13000.00
0005434375206	1527	Economy	13000.00
0005434375190	1527	Economy	13000.00
0005434375228	1527	Economy	13000.00
0005434375189	1527	Economy	13000.00
0005434375221	1527	Economy	13000.00
0005433151572	1527	Economy	14300.00
0005433151557	1527	Economy	14300.00
0005432267981	1527	Economy	14300.00
0005432267978	1527	Economy	14300.00
0005433151573	1527	Economy	14300.00
0005433151647	1527	Economy	13000.00
0005434029658	1527	Economy	13000.00
0005433151707	1527	Economy	13000.00
0005434375226	1527	Economy	13000.00
0005434029659	1527	Economy	13000.00
0005434375220	1527	Economy	13000.00
0005433151552	1527	Economy	13000.00
0005434375202	1527	Economy	13000.00
0005432267980	1527	Economy	13000.00
0005433151569	1527	Economy	13000.00
0005434375210	1527	Economy	13000.00
0005433151578	1527	Economy	13000.00
0005434375211	1527	Economy	13000.00
0005433460462	1527	Economy	13000.00
0005434375223	1527	Economy	13000.00
0005434375225	1527	Economy	13000.00
0005433151588	1527	Economy	13000.00
0005433151556	1527	Economy	13000.00
0005434375219	1527	Economy	13000.00
0005433460463	1527	Economy	13000.00
0005434375229	1527	Economy	13000.00
0005434029657	1527	Economy	13000.00
0005433151507	1527	Economy	13000.00
0005433151640	1527	Economy	13000.00
0005433151558	1527	Economy	13000.00
0005434375204	1527	Economy	13000.00
0005434029668	1527	Economy	13000.00
0005432267977	1527	Economy	13000.00
0005434029661	1527	Economy	13000.00
0005434375216	1527	Economy	13000.00
0005432267976	1527	Economy	13000.00
0005433151635	1527	Economy	13000.00
0005433151699	1527	Economy	13000.00
0005434375194	1527	Economy	13000.00
0005433151559	1527	Economy	13000.00
0005434375195	1527	Economy	13000.00
0005434375214	1527	Economy	13000.00
0005434375208	1527	Economy	13000.00
0005433151663	1527	Economy	13000.00
0005434375207	1527	Economy	13000.00
0005434375198	1527	Economy	13000.00
0005434375227	1527	Economy	13000.00
0005432267975	1527	Economy	13000.00
0005433151700	1527	Economy	13000.00
0005433461616	1527	Economy	13000.00
0005433151478	1527	Economy	13000.00
0005433151568	1527	Economy	13000.00
0005433151734	1527	Economy	13000.00
0005434375213	1527	Economy	13000.00
0005433151589	1527	Economy	13000.00
0005434375209	1527	Economy	13000.00
0005433151447	1527	Economy	13000.00
0005433151664	1527	Economy	13000.00
0005433764687	1527	Economy	13000.00
0005433151607	1527	Economy	13000.00
0005434375191	1527	Economy	13000.00
0005433151514	1527	Economy	13000.00
0005434375203	1527	Economy	13000.00
0005433931475	1527	Economy	13000.00
0005434029662	1527	Economy	13000.00
0005433151662	1527	Economy	13000.00
0005434374761	20145	Business	38900.00
0005434375040	20145	Business	38900.00
0005434374662	20145	Business	38900.00
0005433151844	20145	Business	38900.00
0005433151843	20145	Business	38900.00
0005433764706	20145	Business	38900.00
0005434029690	20145	Business	38900.00
0005434374885	20145	Business	38900.00
0005433151838	20145	Business	38900.00
0005434029687	20145	Business	38900.00
0005433151841	20145	Business	38900.00
0005434374750	20145	Economy	13000.00
0005434374703	20145	Economy	13000.00
0005434374877	20145	Economy	13000.00
0005433151839	20145	Economy	13000.00
0005434374644	20145	Economy	13000.00
0005434374660	20145	Economy	13000.00
0005433151837	20145	Economy	13000.00
0005432056347	20145	Economy	13000.00
0005434374699	20145	Economy	13000.00
0005434029688	20145	Economy	13000.00
0005434374826	20145	Economy	13000.00
0005433151817	20145	Economy	13000.00
0005434374760	20145	Economy	13000.00
0005433151831	20145	Economy	13000.00
0005434374888	20145	Economy	13000.00
0005434374833	20145	Economy	13000.00
0005433151823	20145	Economy	13000.00
0005434374690	20145	Economy	13000.00
0005433151845	20145	Economy	13000.00
0005434374995	20145	Economy	13000.00
0005434029689	20145	Economy	13000.00
0005434375003	20145	Economy	13000.00
0005433151820	20145	Economy	13000.00
0005433151814	20145	Economy	13000.00
0005434374648	20145	Economy	13000.00
0005434374643	20145	Economy	13000.00
0005433151826	20145	Economy	13000.00
0005433151818	20145	Economy	13000.00
0005433151833	20145	Economy	13000.00
0005434374702	20145	Economy	13000.00
0005433151836	20145	Economy	14300.00
0005434374694	20145	Economy	14300.00
0005433151822	20145	Economy	14300.00
0005433151835	20145	Economy	13000.00
0005434374840	20145	Economy	13000.00
0005433764705	20145	Economy	13000.00
0005433151842	20145	Economy	13000.00
0005434374882	20145	Economy	13000.00
0005432056344	20145	Economy	13000.00
0005433931505	20145	Economy	13000.00
0005433151824	20145	Economy	13000.00
0005434374695	20145	Economy	13000.00
0005433151816	20145	Economy	13000.00
0005434374724	20145	Economy	13000.00
0005434374932	20145	Economy	13000.00
0005433151821	20145	Economy	13000.00
0005434374954	20145	Economy	13000.00
0005433931506	20145	Economy	13000.00
0005433151846	20145	Economy	13000.00
0005433151828	20145	Economy	13000.00
0005434374955	20145	Economy	13000.00
0005433151830	20145	Economy	13000.00
0005434374726	20145	Economy	13000.00
0005434375039	20145	Economy	13000.00
0005433151827	20145	Economy	13000.00
0005432056345	20145	Economy	13000.00
0005433151847	20145	Economy	13000.00
0005434374661	20145	Economy	13000.00
0005433151829	20145	Economy	13000.00
0005433151813	20145	Economy	13000.00
0005434374876	20145	Economy	13000.00
0005434374751	20145	Economy	13000.00
0005434374655	20145	Economy	13000.00
0005433151834	20145	Economy	13000.00
0005434374729	20145	Economy	13000.00
0005434374683	20145	Economy	13000.00
0005433151840	20145	Economy	13000.00
0005432056346	20145	Economy	13000.00
0005434374746	20145	Economy	13000.00
0005434374832	20145	Economy	13000.00
0005434374917	20145	Economy	13000.00
0005434374769	20145	Economy	13000.00
0005433151825	20145	Economy	13000.00
0005434374682	20145	Economy	13000.00
0005434374767	20145	Economy	13000.00
0005434374725	20145	Economy	13000.00
0005434374956	20145	Economy	13000.00
0005433151819	20145	Economy	13000.00
0005434374886	20145	Economy	13000.00
0005433764704	20145	Economy	13000.00
0005434374766	20145	Economy	13000.00
0005434374770	20145	Economy	13000.00
0005433151815	20145	Economy	13000.00
0005433151832	20145	Economy	13000.00
0005432282948	555	Business	27500.00
0005432425018	555	Business	27500.00
0005432425040	555	Business	27500.00
0005432425033	555	Business	27500.00
0005432425046	555	Business	27500.00
0005432425009	555	Business	27500.00
0005432425021	555	Business	27500.00
0005432425043	555	Business	27500.00
0005432425034	555	Business	27500.00
0005432425017	555	Business	27500.00
0005432425041	555	Business	27500.00
0005432425013	555	Business	27500.00
0005432425054	555	Business	27500.00
0005432425063	555	Economy	10100.00
0005432425030	555	Business	27500.00
0005432425049	555	Economy	10100.00
0005432282950	555	Economy	10100.00
0005432282949	555	Economy	9200.00
0005432425050	555	Economy	9200.00
0005432425065	555	Economy	9200.00
0005432425053	555	Economy	9200.00
0005432425070	555	Economy	9200.00
0005432425042	555	Economy	9200.00
0005432425028	555	Economy	9200.00
0005432425029	555	Economy	9200.00
0005432425016	555	Economy	9200.00
0005432425015	555	Economy	9200.00
0005432425044	555	Economy	9200.00
0005432425073	555	Economy	9200.00
0005432425037	555	Economy	9200.00
0005432425051	555	Economy	9200.00
0005432425035	555	Economy	9200.00
0005432425072	555	Economy	9200.00
0005432425068	555	Economy	9200.00
0005432425062	555	Economy	9200.00
0005432425022	555	Economy	9200.00
0005432425060	555	Economy	9200.00
0005432282953	555	Economy	9200.00
0005432425020	555	Economy	9200.00
0005432425074	555	Economy	9200.00
0005432425012	555	Economy	9200.00
0005432425010	555	Economy	9200.00
0005432425056	555	Economy	10100.00
0005432425014	555	Economy	10100.00
0005432425071	555	Economy	10100.00
0005432425048	555	Economy	9200.00
0005432425045	555	Economy	9200.00
0005432425031	555	Economy	9200.00
0005432425024	555	Economy	10100.00
0005432425059	555	Economy	9200.00
0005432425023	555	Economy	9200.00
0005432425055	555	Economy	9200.00
0005432425066	555	Economy	9200.00
0005432425075	555	Economy	9200.00
0005432282951	555	Economy	9200.00
0005432425069	555	Economy	9200.00
0005432425047	555	Economy	9200.00
0005432425061	555	Economy	9200.00
0005432425019	555	Economy	9200.00
0005432282954	555	Economy	9200.00
0005432425039	555	Economy	9200.00
0005432425025	555	Economy	9200.00
0005432425036	555	Economy	9200.00
0005432425011	555	Economy	9200.00
0005432425064	555	Economy	9200.00
0005432425027	555	Economy	9200.00
0005432425058	555	Economy	9200.00
0005432282952	555	Economy	9200.00
0005432425067	555	Economy	9200.00
0005432425026	555	Economy	9200.00
0005432425032	555	Economy	9200.00
0005432425038	555	Economy	9200.00
0005432425052	555	Economy	9200.00
0005432425057	555	Economy	9200.00
0005432302376	12858	Economy	9200.00
0005432302378	12858	Economy	9200.00
0005432302379	12858	Economy	9200.00
0005432302377	12858	Economy	9200.00
0005432424547	12914	Business	27500.00
0005432424564	12914	Business	27500.00
0005432424519	12914	Business	27500.00
0005432424545	12914	Business	27500.00
0005432424563	12914	Business	27500.00
0005432424524	12914	Business	27500.00
0005432424436	12914	Business	27500.00
0005432424530	12914	Business	27500.00
0005432424467	12914	Business	27500.00
0005432424434	12914	Business	27500.00
0005432424361	12914	Business	27500.00
0005432424535	12914	Business	27500.00
0005432424596	12914	Business	27500.00
0005432424462	12914	Business	27500.00
0005432424427	12914	Economy	10100.00
0005432424598	12914	Economy	10100.00
0005432424522	12914	Economy	9200.00
0005432424573	12914	Economy	9200.00
0005432424502	12914	Economy	9200.00
0005432424576	12914	Economy	9200.00
0005432424435	12914	Economy	9200.00
0005432424551	12914	Economy	9200.00
0005432424517	12914	Economy	9200.00
0005432424597	12914	Economy	9200.00
0005432424565	12914	Economy	9200.00
0005432424605	12914	Economy	9200.00
0005432424579	12914	Economy	9200.00
0005432424424	12914	Economy	9200.00
0005432424472	12914	Economy	9200.00
0005432424599	12914	Economy	9200.00
0005432424509	12914	Economy	9200.00
0005432424559	12914	Economy	9200.00
0005432424608	12914	Economy	9200.00
0005432424558	12914	Economy	9200.00
0005432424581	12914	Economy	9200.00
0005432424591	12914	Economy	9200.00
0005432424503	12914	Economy	9200.00
0005432424508	12914	Economy	9200.00
0005432424425	12914	Economy	9200.00
0005432424589	12914	Economy	9200.00
0005432424580	12914	Economy	9200.00
0005432424463	12914	Economy	9200.00
0005432424560	12914	Economy	9200.00
0005432424575	12914	Economy	9200.00
0005432424546	12914	Economy	9200.00
0005432424518	12914	Economy	9200.00
0005432424521	12914	Economy	9200.00
0005432424437	12914	Economy	9200.00
0005432424413	12914	Economy	9200.00
0005432424459	12914	Economy	9200.00
0005433058226	469	Business	24500.00
0005434024543	469	Business	24500.00
0005434024537	469	Business	24500.00
0005433058164	469	Business	24500.00
0005434024570	469	Business	24500.00
0005434024557	469	Business	24500.00
0005432235730	469	Business	24500.00
0005432235732	469	Business	24500.00
0005434032075	469	Business	24500.00
0005434024539	469	Business	24500.00
0005433684437	469	Business	24500.00
0005434024531	469	Business	24500.00
0005434024565	469	Business	24500.00
0005434024574	469	Business	24500.00
0005434024573	469	Business	24500.00
0005433058030	469	Business	24500.00
0005434032076	469	Business	24500.00
0005434024546	469	Economy	9000.00
0005433058295	469	Economy	9000.00
0005433058049	469	Economy	9000.00
0005434024577	469	Economy	8200.00
0005434024550	469	Economy	8200.00
0005433057958	469	Economy	8200.00
0005433058044	469	Economy	8200.00
0005433057945	469	Economy	8200.00
0005434024523	469	Economy	8200.00
0005434028332	469	Economy	8200.00
0005432235734	469	Economy	8200.00
0005432235733	469	Economy	8200.00
0005432235728	469	Economy	8200.00
0005434024548	469	Economy	8200.00
0005434032078	469	Economy	8200.00
0005434024559	469	Economy	8200.00
0005434024549	469	Economy	8200.00
0005434024554	469	Economy	8200.00
0005433058269	469	Economy	8200.00
0005434024526	469	Economy	8200.00
0005434024517	469	Economy	8200.00
0005433058040	469	Economy	8200.00
0005432045636	469	Economy	8200.00
0005434024524	469	Economy	8200.00
0005434024547	469	Economy	8200.00
0005433684422	469	Economy	8200.00
0005434024575	469	Economy	8200.00
0005434024544	469	Economy	8200.00
0005433058165	469	Economy	8200.00
0005433057965	469	Economy	8200.00
0005434024572	469	Economy	8200.00
0005434024519	469	Economy	8200.00
0005434024536	469	Economy	8200.00
0005434024515	469	Economy	8200.00
0005434029686	469	Economy	8200.00
0005433058184	469	Economy	8200.00
0005433057933	469	Economy	8200.00
0005434024535	469	Economy	8200.00
0005433058183	469	Economy	8200.00
0005433929609	469	Economy	8200.00
0005434029685	469	Economy	8200.00
0005434032079	469	Economy	8200.00
0005433058086	469	Economy	8200.00
0005434024551	469	Economy	8200.00
0005433058109	469	Economy	8200.00
0005434024521	469	Economy	8200.00
0005434024534	469	Economy	8200.00
0005433929611	469	Economy	8200.00
0005434024566	469	Economy	8200.00
0005434024527	469	Economy	8200.00
0005434024561	469	Economy	8200.00
0005434024567	469	Economy	8200.00
0005434024555	469	Economy	8200.00
0005434024571	469	Economy	8200.00
0005433929608	469	Economy	8200.00
0005434028328	469	Economy	8200.00
0005434024542	469	Economy	8200.00
0005434024514	469	Economy	8200.00
0005434024579	469	Economy	8200.00
0005434024538	469	Economy	8200.00
0005433058268	469	Economy	8200.00
0005434024578	469	Economy	8200.00
0005433057944	469	Economy	8200.00
0005433058048	469	Economy	8200.00
0005434024545	469	Economy	8200.00
0005433684438	469	Economy	9000.00
0005434024525	469	Economy	8200.00
0005434024530	469	Economy	8200.00
0005433058039	469	Economy	9000.00
0005433058102	469	Economy	8200.00
0005434032077	469	Economy	8200.00
0005432235727	469	Economy	8200.00
0005434024556	469	Economy	8200.00
0005433058145	469	Economy	8200.00
0005433058034	469	Economy	8200.00
0005433929618	469	Economy	8200.00
0005434024529	469	Economy	8200.00
0005432045637	469	Economy	8200.00
0005434024522	469	Economy	8200.00
0005433929629	469	Economy	8200.00
0005434024560	469	Economy	8200.00
0005434028331	469	Economy	8200.00
0005433058154	469	Economy	8200.00
0005434024553	469	Economy	8200.00
0005433057987	469	Economy	8200.00
0005433057988	469	Economy	8200.00
0005433058230	469	Economy	8200.00
0005434024568	469	Economy	8200.00
0005434024532	469	Economy	8200.00
0005433929631	469	Economy	8200.00
0005433058117	469	Economy	8200.00
0005433058075	469	Economy	8200.00
0005434024562	469	Economy	8200.00
0005433057935	469	Economy	8200.00
0005432235731	469	Economy	8200.00
0005434024569	469	Economy	8200.00
0005433058076	469	Economy	8200.00
0005434024552	469	Economy	8200.00
0005434024563	469	Economy	8200.00
0005432235729	469	Economy	8200.00
0005433058071	469	Economy	8200.00
0005434024576	469	Economy	8200.00
0005432045635	469	Economy	8200.00
0005432235735	469	Economy	8200.00
0005434028329	469	Economy	8200.00
0005434024520	469	Economy	8200.00
0005434024558	469	Economy	8200.00
0005434024528	469	Economy	8200.00
0005433684436	469	Economy	8200.00
0005434024516	469	Economy	8200.00
0005434024541	469	Economy	8200.00
0005434024580	469	Economy	8200.00
0005434735698	469	Economy	8200.00
0005434024564	469	Economy	8200.00
0005434028330	469	Economy	8200.00
0005434024540	469	Economy	8200.00
0005434024533	469	Economy	8200.00
0005434024518	469	Economy	8200.00
0005434024513	469	Economy	8200.00
0005434735753	12644	Business	24500.00
0005434029662	12644	Business	24500.00
0005434023743	12644	Business	24500.00
0005433058401	12644	Business	24500.00
0005434024104	12644	Business	24500.00
0005434029665	12644	Business	24500.00
0005434023981	12644	Business	24500.00
0005434023964	12644	Business	24500.00
0005434023857	12644	Business	24500.00
0005433058370	12644	Business	24500.00
0005433058363	12644	Business	24500.00
0005433058382	12644	Business	24500.00
0005433058387	12644	Business	24500.00
0005433058377	12644	Business	24500.00
0005433058391	12644	Business	24500.00
0005434023910	12644	Business	24500.00
0005433058392	12644	Business	24500.00
0005433058384	12644	Business	24500.00
0005434023909	12644	Business	24500.00
0005434024125	12644	Business	24500.00
0005434024100	12644	Business	24500.00
0005434024047	12644	Business	24500.00
0005433058388	12644	Economy	9000.00
0005434024261	12644	Economy	9000.00
0005434023738	12644	Economy	8200.00
0005434023997	12644	Economy	8200.00
0005434024150	12644	Economy	8200.00
0005434029659	12644	Economy	8200.00
0005433058398	12644	Economy	8200.00
0005434029657	12644	Economy	8200.00
0005433684446	12644	Economy	8200.00
0005434023915	12644	Economy	8200.00
0005433058389	12644	Economy	8200.00
0005434023982	12644	Economy	8200.00
0005433058400	12644	Economy	8200.00
0005434024091	12644	Economy	8200.00
0005433058399	12644	Economy	8200.00
0005434023973	12644	Economy	8200.00
0005434024120	12644	Economy	8200.00
0005433684447	12644	Economy	8200.00
0005434735754	12644	Economy	8200.00
0005433058362	12644	Economy	8200.00
0005434024016	12644	Economy	8200.00
0005434735752	12644	Economy	8200.00
0005434023962	12644	Economy	8200.00
0005434024139	12644	Economy	8200.00
0005433058366	12644	Economy	8200.00
0005434023931	12644	Economy	8200.00
0005433058394	12644	Economy	8200.00
0005434023781	12644	Economy	8200.00
0005433058395	12644	Economy	8200.00
0005434024124	12644	Economy	8200.00
0005434735757	12644	Economy	8200.00
0005434024027	12644	Economy	8200.00
0005433929663	12644	Economy	8200.00
0005434023912	12644	Economy	8200.00
0005433058386	12644	Economy	8200.00
0005434023993	12644	Economy	8200.00
0005433058376	12644	Economy	8200.00
0005432156418	12644	Economy	8200.00
0005434023667	12644	Economy	8200.00
0005432156419	12644	Economy	8200.00
0005434029668	12644	Economy	8200.00
0005433058396	12644	Economy	8200.00
0005433058378	12644	Economy	8200.00
0005433058371	12644	Economy	8200.00
0005433058379	12644	Economy	8200.00
0005433929662	12644	Economy	8200.00
0005433058364	12644	Economy	8200.00
0005434023727	12644	Economy	8200.00
0005434024003	12644	Economy	8200.00
0005434023992	12644	Economy	8200.00
0005434735758	12644	Economy	8200.00
0005434029666	12644	Economy	8200.00
0005434023637	12644	Economy	8200.00
0005434735755	12644	Economy	8200.00
0005434029661	12644	Economy	8200.00
0005433058368	12644	Economy	8200.00
0005434024366	12644	Economy	8200.00
0005434032041	12644	Economy	8200.00
0005434024278	12644	Economy	8200.00
0005434023680	12644	Economy	8200.00
0005434024035	12644	Economy	8200.00
0005433058393	12644	Economy	8200.00
0005432156422	12644	Economy	8200.00
0005434023945	12644	Economy	8200.00
0005434023916	12644	Economy	8200.00
0005434024145	12644	Economy	8200.00
0005433929664	12644	Economy	8200.00
0005434023770	12644	Economy	8200.00
0005434024365	12644	Economy	8200.00
0005433058381	12644	Economy	8200.00
0005434023869	12644	Economy	8200.00
0005434024260	12644	Economy	9000.00
0005433058383	12644	Economy	9000.00
0005434032061	12644	Economy	8200.00
0005432157516	12644	Economy	8200.00
0005434023868	12644	Economy	8200.00
0005433058373	12644	Economy	9000.00
0005434735756	12644	Economy	9000.00
0005434023996	12644	Economy	8200.00
0005433058390	12644	Economy	8200.00
0005434023638	12644	Economy	8200.00
0005434032054	12644	Economy	8200.00
0005434023749	12644	Economy	8200.00
0005434024078	12644	Economy	8200.00
0005433058397	12644	Economy	8200.00
0005434023998	12644	Economy	8200.00
0005434023867	12644	Economy	8200.00
0005434023795	12644	Economy	8200.00
0005434023954	12644	Economy	8200.00
0005434023668	12644	Economy	8200.00
0005434023782	12644	Economy	8200.00
0005434024138	12644	Economy	8200.00
0005434024082	12644	Economy	8200.00
0005434024023	12644	Economy	8200.00
0005433058367	12644	Economy	8200.00
0005434023991	12644	Economy	8200.00
0005433058372	12644	Economy	8200.00
0005433058369	12644	Economy	8200.00
0005434023681	12644	Economy	8200.00
0005434024040	12644	Economy	8200.00
0005433058365	12644	Economy	8200.00
0005434023932	12644	Economy	8200.00
0005433929665	12644	Economy	8200.00
0005432156420	12644	Economy	8200.00
0005434023748	12644	Economy	8200.00
0005434023698	12644	Economy	8200.00
0005433058380	12644	Economy	8200.00
0005434023771	12644	Economy	8200.00
0005434024026	12644	Economy	8200.00
0005434024046	12644	Economy	8200.00
0005434023666	12644	Economy	8200.00
0005434023985	12644	Economy	8200.00
0005434023865	12644	Economy	8200.00
0005434024028	12644	Economy	8200.00
0005432157515	12644	Economy	8200.00
0005434023976	12644	Economy	8200.00
0005434023911	12644	Economy	8200.00
0005434023758	12644	Economy	8200.00
0005434024129	12644	Economy	8200.00
0005434024015	12644	Economy	8200.00
0005432156421	12644	Economy	8200.00
0005433058361	12644	Economy	8200.00
0005433058374	12644	Economy	8200.00
0005434024039	12644	Economy	8200.00
0005434023953	12644	Economy	8200.00
0005433058375	12644	Economy	8200.00
0005434032051	12644	Economy	8200.00
0005434029658	12644	Economy	8200.00
0005433058385	12644	Economy	8200.00
0005433924489	2114	Business	34700.00
0005433924512	2114	Business	34700.00
0005433924514	2114	Business	34700.00
0005433924458	2114	Business	34700.00
0005433036457	2114	Business	34700.00
0005433036530	2114	Business	34700.00
0005433924494	2114	Business	34700.00
0005433036583	2114	Business	34700.00
0005433924521	2114	Business	34700.00
0005433924486	2114	Business	34700.00
0005433036416	2114	Business	34700.00
0005433924518	2114	Business	34700.00
0005433924472	2114	Business	34700.00
0005433036493	2114	Business	34700.00
0005433036534	2114	Business	34700.00
0005432231690	2114	Business	34700.00
0005433924516	2114	Business	34700.00
0005433924481	2114	Business	34700.00
0005432044558	2114	Business	34700.00
0005433924517	2114	Business	34700.00
0005433924435	2114	Business	34700.00
0005433924487	2114	Business	34700.00
0005433036376	2114	Business	34700.00
0005433924498	2114	Business	34700.00
0005433036537	2114	Economy	12700.00
0005433924501	2114	Economy	12700.00
0005433924475	2114	Economy	11600.00
0005433924480	2114	Economy	11600.00
0005433924461	2114	Economy	11600.00
0005433931505	2114	Economy	11600.00
0005433924530	2114	Economy	11600.00
0005432231693	2114	Economy	11600.00
0005433924528	2114	Economy	11600.00
0005433924450	2114	Economy	11600.00
0005433036692	2114	Economy	11600.00
0005433924504	2114	Economy	11600.00
0005433036567	2114	Economy	11600.00
0005433924497	2114	Economy	11600.00
0005433036538	2114	Economy	11600.00
0005432044559	2114	Economy	11600.00
0005433875397	2114	Economy	11600.00
0005433924449	2114	Economy	11600.00
0005432231694	2114	Economy	11600.00
0005433924495	2114	Economy	11600.00
0005432044557	2114	Economy	11600.00
0005433924456	2114	Economy	11600.00
0005433924523	2114	Economy	11600.00
0005433924500	2114	Economy	11600.00
0005433924453	2114	Economy	11600.00
0005433924463	2114	Economy	11600.00
0005433036584	2114	Economy	11600.00
0005433924490	2114	Economy	11600.00
0005433924511	2114	Economy	11600.00
0005433036540	2114	Economy	11600.00
0005433036354	2114	Economy	11600.00
0005433036450	2114	Economy	11600.00
0005433036565	2114	Economy	11600.00
0005433924464	2114	Economy	11600.00
0005432231700	2114	Economy	11600.00
0005433036608	2114	Economy	11600.00
0005433924492	2114	Economy	11600.00
0005433924434	2114	Economy	11600.00
0005433036432	2114	Economy	11600.00
0005433036086	2114	Economy	11600.00
0005433929664	2114	Economy	11600.00
0005433036531	2114	Economy	11600.00
0005433924478	2114	Economy	11600.00
0005433036475	2114	Economy	11600.00
0005433924445	2114	Economy	11600.00
0005433924510	2114	Economy	11600.00
0005433036800	2114	Economy	11600.00
0005433036412	2114	Economy	11600.00
0005433924482	2114	Economy	11600.00
0005433036482	2114	Economy	11600.00
0005433036568	2114	Economy	11600.00
0005433924503	2114	Economy	11600.00
0005433924451	2114	Economy	11600.00
0005433924505	2114	Economy	11600.00
0005433924477	2114	Economy	11600.00
0005433036474	2114	Economy	11600.00
0005433924442	2114	Economy	11600.00
0005433929662	2114	Economy	11600.00
0005433036614	2114	Economy	11600.00
0005433036539	2114	Economy	11600.00
0005433924522	2114	Economy	11600.00
0005433924476	2114	Economy	11600.00
0005432231692	2114	Economy	11600.00
0005433924508	2114	Economy	11600.00
0005433924441	2114	Economy	11600.00
0005433931506	2114	Economy	11600.00
0005433036629	2114	Economy	11600.00
0005433924485	2114	Economy	11600.00
0005433036602	2114	Economy	11600.00
0005432231691	2114	Economy	11600.00
0005432231697	2114	Economy	11600.00
0005433924468	2114	Economy	11600.00
0005433924483	2114	Economy	11600.00
0005433924459	2114	Economy	11600.00
0005433036616	2114	Economy	11600.00
0005433924436	2114	Economy	11600.00
0005433924519	2114	Economy	11600.00
0005433924439	2114	Economy	11600.00
0005433924454	2114	Economy	12700.00
0005433924466	2114	Economy	12700.00
0005433924455	2114	Economy	11600.00
0005433924507	2114	Economy	11600.00
0005433924525	2114	Economy	12700.00
0005433036669	2114	Economy	12700.00
0005433036458	2114	Economy	11600.00
0005433924470	2114	Economy	11600.00
0005433924529	2114	Economy	11600.00
0005433924473	2114	Economy	11600.00
0005433924515	2114	Economy	11600.00
0005433924506	2114	Economy	11600.00
0005433929663	2114	Economy	11600.00
0005433036337	2114	Economy	11600.00
0005433924520	2114	Economy	11600.00
0005433924532	2114	Economy	11600.00
0005432231699	2114	Economy	11600.00
0005433924479	2114	Economy	11600.00
0005433924499	2114	Economy	11600.00
0005433924531	2114	Economy	11600.00
0005433036564	2114	Economy	11600.00
0005433924446	2114	Economy	11600.00
0005433924467	2114	Economy	11600.00
0005433036566	2114	Economy	11600.00
0005433924513	2114	Economy	11600.00
0005433924509	2114	Economy	11600.00
0005433924447	2114	Economy	11600.00
0005433036433	2114	Economy	11600.00
0005433036494	2114	Economy	11600.00
0005433924438	2114	Economy	11600.00
0005432231695	2114	Economy	11600.00
0005433036454	2114	Economy	11600.00
0005432749789	2114	Economy	11600.00
0005433036666	2114	Economy	11600.00
0005433924469	2114	Economy	11600.00
0005433036603	2114	Economy	11600.00
0005433924491	2114	Economy	11600.00
0005433929665	2114	Economy	11600.00
0005433036516	2114	Economy	11600.00
0005433924457	2114	Economy	11600.00
0005433924496	2114	Economy	11600.00
0005433036535	2114	Economy	11600.00
0005433924437	2114	Economy	11600.00
0005433924460	2114	Economy	11600.00
0005433924484	2114	Economy	11600.00
0005433924465	2114	Economy	11600.00
0005433924527	2114	Economy	11600.00
0005433924452	2114	Economy	11600.00
0005433924448	2114	Economy	11600.00
0005433924502	2114	Economy	11600.00
0005433924443	2114	Economy	11600.00
0005433924444	2114	Economy	11600.00
0005433924474	2114	Economy	11600.00
0005433924524	2114	Economy	11600.00
0005433924440	2114	Economy	11600.00
0005433924526	2114	Economy	11600.00
0005432231696	2114	Economy	11600.00
0005433924471	2114	Economy	11600.00
0005433924488	2114	Economy	11600.00
0005433036615	2114	Economy	11600.00
0005432231698	2114	Economy	11600.00
0005433924462	2114	Economy	11600.00
0005433036411	2114	Economy	11600.00
0005433036307	2114	Economy	11600.00
0005433036353	2114	Economy	11600.00
0005433924493	2114	Economy	11600.00
0005433036340	2114	Economy	11600.00
0005433923611	24095	Business	34700.00
0005433875384	24095	Business	34700.00
0005433923563	24095	Business	34700.00
0005433036950	24095	Business	34700.00
0005433036955	24095	Business	34700.00
0005434028336	24095	Business	34700.00
0005433923858	24095	Business	34700.00
0005433923785	24095	Business	34700.00
0005433036953	24095	Business	34700.00
0005433924227	24095	Business	34700.00
0005433923767	24095	Business	34700.00
0005433036925	24095	Business	34700.00
0005433036969	24095	Business	34700.00
0005433923745	24095	Business	34700.00
0005433923905	24095	Business	34700.00
0005432749812	24095	Business	34700.00
0005433923353	24095	Business	34700.00
0005433923972	24095	Business	34700.00
0005433923194	24095	Business	34700.00
0005433923912	24095	Business	34700.00
0005433036931	24095	Business	34700.00
0005433923538	24095	Business	34700.00
0005433923671	24095	Business	34700.00
0005433923656	24095	Business	34700.00
0005433923921	24095	Economy	12700.00
0005433923424	24095	Economy	12700.00
0005433923482	24095	Economy	12700.00
0005433923924	24095	Economy	12700.00
0005433036923	24095	Economy	11600.00
0005433036924	24095	Economy	11600.00
0005433923648	24095	Economy	11600.00
0005432206267	24095	Economy	11600.00
0005433036933	24095	Economy	11600.00
0005433923647	24095	Economy	11600.00
0005433923215	24095	Economy	11600.00
0005432206268	24095	Economy	11600.00
0005433036974	24095	Economy	11600.00
0005433923529	24095	Economy	11600.00
0005433923859	24095	Economy	11600.00
0005433036971	24095	Economy	11600.00
0005433923742	24095	Economy	11600.00
0005433036973	24095	Economy	11600.00
0005433923916	24095	Economy	11600.00
0005433923438	24095	Economy	11600.00
0005433875382	24095	Economy	11600.00
0005432207694	24095	Economy	11600.00
0005433923703	24095	Economy	11600.00
0005433923582	24095	Economy	11600.00
0005433036941	24095	Economy	11600.00
0005433923593	24095	Economy	11600.00
0005433036946	24095	Economy	11600.00
0005433923361	24095	Economy	11600.00
0005433036937	24095	Economy	11600.00
0005433036957	24095	Economy	11600.00
0005433923700	24095	Economy	11600.00
0005433923559	24095	Economy	11600.00
0005433923497	24095	Economy	11600.00
0005433036956	24095	Economy	11600.00
0005433924045	24095	Economy	11600.00
0005433036939	24095	Economy	11600.00
0005432749811	24095	Economy	11600.00
0005433036922	24095	Economy	11600.00
0005433924044	24095	Economy	11600.00
0005433923646	24095	Economy	11600.00
0005433036961	24095	Economy	11600.00
0005433923811	24095	Economy	11600.00
0005433923813	24095	Economy	11600.00
0005433875383	24095	Economy	11600.00
0005433875380	24095	Economy	11600.00
0005433923812	24095	Economy	11600.00
0005433036926	24095	Economy	11600.00
0005433036962	24095	Economy	11600.00
0005433036967	24095	Economy	11600.00
0005433923136	24095	Economy	11600.00
0005433923709	24095	Economy	11600.00
0005433923413	24095	Economy	11600.00
0005433036970	24095	Economy	11600.00
0005433036945	24095	Economy	11600.00
0005432206269	24095	Economy	11600.00
0005433923762	24095	Economy	11600.00
0005433923539	24095	Economy	11600.00
0005433036932	24095	Economy	11600.00
0005433036952	24095	Economy	11600.00
0005433923943	24095	Economy	11600.00
0005433036951	24095	Economy	11600.00
0005433923860	24095	Economy	11600.00
0005433923682	24095	Economy	11600.00
0005433923882	24095	Economy	11600.00
0005433036934	24095	Economy	11600.00
0005434028334	24095	Economy	11600.00
0005433036963	24095	Economy	11600.00
0005433036954	24095	Economy	11600.00
0005434028335	24095	Economy	11600.00
0005433923681	24095	Economy	11600.00
0005433923612	24095	Economy	11600.00
0005433923504	24095	Economy	11600.00
0005433924264	24095	Economy	11600.00
0005433923423	24095	Economy	11600.00
0005433036958	24095	Economy	11600.00
0005433036965	24095	Economy	11600.00
0005433923722	24095	Economy	11600.00
0005433923030	24095	Economy	11600.00
0005433875379	24095	Economy	11600.00
0005433923633	24095	Economy	11600.00
0005433036944	24095	Economy	11600.00
0005433923610	24095	Economy	11600.00
0005433923702	24095	Economy	11600.00
0005433923874	24095	Economy	11600.00
0005433923902	24095	Economy	11600.00
0005433923784	24095	Economy	11600.00
0005433036938	24095	Economy	11600.00
0005433036975	24095	Economy	11600.00
0005433923817	24095	Economy	11600.00
0005433036928	24095	Economy	11600.00
0005433923738	24095	Economy	12700.00
0005433923749	24095	Economy	12700.00
0005433036960	24095	Economy	11600.00
0005433036935	24095	Economy	11600.00
0005433036940	24095	Economy	11600.00
0005433923806	24095	Economy	12700.00
0005433923216	24095	Economy	12700.00
0005433036966	24095	Economy	11600.00
0005433036942	24095	Economy	11600.00
0005433923572	24095	Economy	11600.00
0005433923973	24095	Economy	11600.00
0005433923894	24095	Economy	11600.00
0005433923927	24095	Economy	11600.00
0005433923701	24095	Economy	11600.00
0005433924265	24095	Economy	11600.00
0005433923718	24095	Economy	11600.00
0005433923347	24095	Economy	11600.00
0005433923926	24095	Economy	11600.00
0005433923920	24095	Economy	11600.00
0005433036947	24095	Economy	11600.00
0005433036930	24095	Economy	11600.00
0005432207693	24095	Economy	11600.00
0005433923360	24095	Economy	11600.00
0005433929630	24095	Economy	11600.00
0005433923527	24095	Economy	11600.00
0005433923733	24095	Economy	11600.00
0005433923699	24095	Economy	11600.00
0005433923422	24095	Economy	11600.00
0005433875387	24095	Economy	11600.00
0005432749813	24095	Economy	11600.00
0005434028333	24095	Economy	11600.00
0005433923824	24095	Economy	11600.00
0005432206270	24095	Economy	11600.00
0005433036964	24095	Economy	11600.00
0005433875378	24095	Economy	11600.00
0005433923437	24095	Economy	11600.00
0005433923641	24095	Economy	11600.00
0005433036949	24095	Economy	11600.00
0005433036948	24095	Economy	11600.00
0005433036936	24095	Economy	11600.00
0005433923496	24095	Economy	11600.00
0005433036927	24095	Economy	11600.00
0005434028337	24095	Economy	11600.00
0005433923698	24095	Economy	11600.00
0005433923537	24095	Economy	11600.00
0005433923713	24095	Economy	11600.00
0005433923526	24095	Economy	11600.00
0005433923925	24095	Economy	11600.00
0005433923154	24095	Economy	11600.00
0005433923794	24095	Economy	11600.00
0005433923756	24095	Economy	11600.00
0005433923670	24095	Economy	11600.00
0005433923510	24095	Economy	11600.00
0005433923556	24095	Economy	11600.00
0005433924080	24095	Economy	11600.00
0005433036972	24095	Economy	11600.00
0005433923719	24095	Economy	11600.00
0005433923278	24095	Economy	11600.00
0005432749814	24095	Economy	11600.00
0005433036943	24095	Economy	11600.00
0005433036968	24095	Economy	11600.00
0005433923187	24095	Economy	11600.00
0005433923201	24095	Economy	11600.00
0005433923513	24095	Economy	11600.00
0005433923412	24095	Economy	11600.00
0005433923498	24095	Economy	11600.00
0005433923153	24095	Economy	11600.00
0005433923922	24095	Economy	11600.00
0005433923457	24095	Economy	11600.00
0005433924133	24095	Economy	11600.00
0005433036959	24095	Economy	11600.00
0005433923508	24095	Economy	11600.00
0005433923729	24095	Economy	11600.00
0005433923485	24095	Economy	11600.00
0005433923509	24095	Economy	11600.00
0005433036929	24095	Economy	11600.00
0005433923411	24095	Economy	11600.00
0005433875381	24095	Economy	11600.00
0005433923901	24095	Economy	11600.00
0005432277977	297	Business	83700.00
0005434726977	297	Business	83700.00
0005434726950	297	Business	83700.00
0005433181176	297	Business	83700.00
0005434726916	297	Business	83700.00
0005435142745	297	Business	83700.00
0005434727011	297	Business	83700.00
0005434726924	297	Business	83700.00
0005434551884	297	Business	83700.00
0005434551892	297	Business	83700.00
0005432277971	297	Business	83700.00
0005433181266	297	Business	83700.00
0005434726998	297	Business	83700.00
0005433181186	297	Business	83700.00
0005434551926	297	Business	83700.00
0005433126869	297	Business	83700.00
0005433181171	297	Business	83700.00
0005433234618	297	Business	83700.00
0005434726933	297	Business	83700.00
0005433234493	297	Business	83700.00
0005434726963	297	Business	83700.00
0005434735750	297	Business	83700.00
0005433234134	297	Business	83700.00
0005434726910	297	Comfort	47400.00
0005433289846	297	Business	83700.00
0005433234133	297	Comfort	47400.00
0005433766644	297	Comfort	47400.00
0005434551935	297	Comfort	47400.00
0005433234015	297	Comfort	47400.00
0005433234143	297	Comfort	47400.00
0005433234292	297	Comfort	47400.00
0005433181145	297	Comfort	47400.00
0005434726913	297	Comfort	47400.00
0005433234078	297	Comfort	47400.00
0005433131728	297	Comfort	47400.00
0005434551894	297	Comfort	47400.00
0005434726986	297	Comfort	47400.00
0005433234293	297	Comfort	47400.00
0005433234491	297	Comfort	47400.00
0005434551927	297	Comfort	47400.00
0005434726989	297	Comfort	47400.00
0005432277970	297	Comfort	47400.00
0005433766643	297	Comfort	47400.00
0005434727016	297	Comfort	47400.00
0005434551936	297	Comfort	47400.00
0005434726953	297	Comfort	47400.00
0005434551885	297	Comfort	47400.00
0005434551887	297	Comfort	47400.00
0005434551888	297	Comfort	47400.00
0005433126870	297	Comfort	47400.00
0005433234519	297	Comfort	47400.00
0005433234386	297	Comfort	47400.00
0005435142741	297	Comfort	47400.00
0005434726956	297	Comfort	47400.00
0005433234249	297	Comfort	47400.00
0005433234289	297	Comfort	47400.00
0005433234482	297	Comfort	47400.00
0005433234487	297	Comfort	47400.00
0005433234182	297	Comfort	47400.00
0005433289853	297	Comfort	47400.00
0005434551918	297	Comfort	47400.00
0005433234278	297	Comfort	47400.00
0005434726978	297	Comfort	47400.00
0005434727001	297	Economy	27900.00
0005434551922	297	Economy	27900.00
0005433234236	297	Economy	27900.00
0005434726948	297	Economy	27900.00
0005434726917	297	Economy	27900.00
0005434302512	297	Economy	27900.00
0005433181121	297	Economy	27900.00
0005434726961	297	Economy	27900.00
0005434551904	297	Economy	27900.00
0005434551900	297	Economy	27900.00
0005434727002	297	Economy	27900.00
0005434726994	297	Economy	27900.00
0005434731218	297	Economy	27900.00
0005434726926	297	Economy	27900.00
0005433234430	297	Economy	27900.00
0005434551881	297	Economy	27900.00
0005434551902	297	Economy	27900.00
0005434726968	297	Economy	27900.00
0005434727022	297	Economy	27900.00
0005434551893	297	Economy	27900.00
0005434726984	297	Economy	27900.00
0005434726960	297	Economy	27900.00
0005435142748	297	Economy	27900.00
0005434726982	297	Economy	27900.00
0005433181125	297	Economy	27900.00
0005433234593	297	Economy	27900.00
0005435142739	297	Economy	27900.00
0005434731220	297	Economy	27900.00
0005434726967	297	Economy	27900.00
0005434551915	297	Economy	27900.00
0005434551923	297	Economy	27900.00
0005434726936	297	Economy	27900.00
0005434551899	297	Economy	27900.00
0005435142742	297	Economy	27900.00
0005433234439	297	Economy	27900.00
0005434551930	297	Economy	27900.00
0005435142750	297	Economy	27900.00
0005434727006	297	Economy	27900.00
0005433289861	297	Economy	27900.00
0005434726932	297	Economy	27900.00
0005434727015	297	Economy	27900.00
0005433234325	297	Economy	27900.00
0005433181166	297	Economy	27900.00
0005434551882	297	Economy	27900.00
0005433181177	297	Economy	27900.00
0005434302513	297	Economy	27900.00
0005434726921	297	Economy	27900.00
0005434726944	297	Economy	27900.00
0005433131734	297	Economy	27900.00
0005433234526	297	Economy	27900.00
0005434032015	297	Economy	27900.00
0005432277978	297	Economy	27900.00
0005433181267	297	Economy	27900.00
0005433181107	297	Economy	27900.00
0005434731221	297	Economy	27900.00
0005433181243	297	Economy	27900.00
0005434726975	297	Economy	27900.00
0005434727003	297	Economy	27900.00
0005434551911	297	Economy	30700.00
0005433234512	297	Economy	27900.00
0005432277981	297	Economy	30700.00
0005433234290	297	Economy	30700.00
0005434726970	297	Economy	27900.00
0005434551916	297	Economy	27900.00
0005433131744	297	Economy	27900.00
0005434551934	297	Economy	27900.00
0005433181265	297	Economy	30700.00
0005434727021	297	Economy	30700.00
0005434551925	297	Economy	27900.00
0005435142744	297	Economy	27900.00
0005433234279	297	Economy	27900.00
0005434726991	297	Economy	27900.00
0005434551933	297	Economy	27900.00
0005435142747	297	Economy	27900.00
0005434551895	297	Economy	27900.00
0005432277974	297	Economy	27900.00
0005434551928	297	Economy	27900.00
0005434551929	297	Economy	27900.00
0005433234069	297	Economy	27900.00
0005432277976	297	Economy	27900.00
0005434551920	297	Economy	27900.00
0005434726995	297	Economy	27900.00
0005434726974	297	Economy	27900.00
0005433234398	297	Economy	27900.00
0005434551905	297	Economy	27900.00
0005434726954	297	Economy	27900.00
0005434727009	297	Economy	27900.00
0005434726923	297	Economy	27900.00
0005434302514	297	Economy	27900.00
0005434726925	297	Economy	27900.00
0005433181126	297	Economy	27900.00
0005434551906	297	Economy	27900.00
0005434727019	297	Economy	27900.00
0005433181239	297	Economy	27900.00
0005432277973	297	Economy	27900.00
0005433234397	297	Economy	27900.00
0005432277972	297	Economy	27900.00
0005434726911	297	Economy	27900.00
0005433234451	297	Economy	27900.00
0005432277980	297	Economy	27900.00
0005433234518	297	Economy	27900.00
0005434727017	297	Economy	27900.00
0005434551896	297	Economy	27900.00
0005434726929	297	Economy	27900.00
0005433234515	297	Economy	27900.00
0005433234468	297	Economy	27900.00
0005434302515	297	Economy	27900.00
0005434727004	297	Economy	27900.00
0005434727018	297	Economy	27900.00
0005434726941	297	Economy	27900.00
0005434726918	297	Economy	27900.00
0005434727025	297	Economy	27900.00
0005433234495	297	Economy	27900.00
0005433234531	297	Economy	27900.00
0005434726908	297	Economy	27900.00
0005434726945	297	Economy	27900.00
0005433234310	297	Economy	27900.00
0005434551908	297	Economy	27900.00
0005434551921	297	Economy	27900.00
0005433126860	297	Economy	27900.00
0005434551901	297	Economy	27900.00
0005434727000	297	Economy	27900.00
0005434726981	297	Economy	27900.00
0005433234452	297	Economy	27900.00
0005434726907	297	Economy	27900.00
0005434726955	297	Economy	27900.00
0005434551886	297	Economy	27900.00
0005434726942	297	Economy	27900.00
0005433181108	297	Economy	27900.00
0005433289892	297	Economy	27900.00
0005434726928	297	Economy	27900.00
0005434735751	297	Economy	27900.00
0005434551913	297	Economy	27900.00
0005433181232	297	Economy	27900.00
0005434551883	297	Economy	27900.00
0005434726920	297	Economy	27900.00
0005433181165	297	Economy	27900.00
0005434726996	297	Economy	27900.00
0005433234248	297	Economy	27900.00
0005434726988	297	Economy	27900.00
0005434551912	297	Economy	27900.00
0005433234181	297	Economy	27900.00
0005434551909	297	Economy	27900.00
0005434726909	297	Economy	27900.00
0005432277975	297	Economy	27900.00
0005433234514	297	Economy	27900.00
0005434726934	297	Economy	27900.00
0005434551897	297	Economy	27900.00
0005434551919	297	Economy	27900.00
0005434726971	297	Economy	27900.00
0005434726951	297	Economy	27900.00
0005434726965	297	Economy	27900.00
0005434726976	297	Economy	27900.00
0005433181088	297	Economy	27900.00
0005433234431	297	Economy	27900.00
0005434727026	297	Economy	27900.00
0005434551891	297	Economy	27900.00
0005433234447	297	Economy	27900.00
0005434726962	297	Economy	27900.00
0005434726993	297	Economy	27900.00
0005434726915	297	Economy	27900.00
0005433181211	297	Economy	27900.00
0005433181238	297	Economy	27900.00
0005433234480	297	Economy	27900.00
0005433234513	297	Economy	30700.00
0005434727024	297	Economy	30700.00
0005433289864	297	Economy	30700.00
0005434727013	297	Economy	30700.00
0005434731219	297	Economy	27900.00
0005433234332	297	Economy	27900.00
0005433234424	297	Economy	27900.00
0005434726949	297	Economy	27900.00
0005433234400	297	Economy	27900.00
0005434726979	297	Economy	27900.00
0005435142749	297	Economy	27900.00
0005433181231	297	Economy	27900.00
0005434551924	297	Economy	27900.00
0005433234652	297	Economy	27900.00
0005434726987	297	Economy	27900.00
0005433234016	297	Economy	27900.00
0005433181212	297	Economy	27900.00
0005434735748	297	Economy	27900.00
0005434726999	297	Economy	27900.00
0005434726992	297	Economy	27900.00
0005433234423	297	Economy	27900.00
0005434726930	297	Economy	27900.00
0005433131727	297	Economy	27900.00
0005432277968	297	Economy	27900.00
0005434726947	297	Economy	27900.00
0005434727010	297	Economy	27900.00
0005434551890	297	Economy	27900.00
0005434726943	297	Economy	27900.00
0005433234309	297	Economy	27900.00
0005434726940	297	Economy	27900.00
0005434726914	297	Economy	27900.00
0005433234314	297	Economy	27900.00
0005434726958	297	Economy	27900.00
0005434551931	297	Economy	27900.00
0005434726912	297	Economy	27900.00
0005433234481	297	Economy	27900.00
0005434726927	297	Economy	27900.00
0005434726959	297	Economy	27900.00
0005434726931	297	Economy	27900.00
0005434726957	297	Economy	27900.00
0005434727012	297	Economy	27900.00
0005434551932	297	Economy	27900.00
0005434551917	297	Economy	27900.00
0005434726964	297	Economy	27900.00
0005434726952	297	Economy	27900.00
0005434726969	297	Economy	27900.00
0005434726990	297	Economy	27900.00
0005433181175	297	Economy	27900.00
0005434551914	297	Economy	27900.00
0005433181235	297	Economy	27900.00
0005434551898	297	Economy	27900.00
0005433234222	297	Economy	27900.00
0005434726973	297	Economy	27900.00
0005433234132	297	Economy	27900.00
0005433234425	297	Economy	27900.00
0005434551903	297	Economy	27900.00
0005434551910	297	Economy	27900.00
0005434726966	297	Economy	27900.00
0005434727007	297	Economy	27900.00
0005433234186	297	Economy	27900.00
0005433111511	297	Economy	27900.00
0005434726983	297	Economy	27900.00
0005434727023	297	Economy	27900.00
0005433234418	297	Economy	27900.00
0005432277979	297	Economy	27900.00
0005434727014	297	Economy	27900.00
0005434735749	297	Economy	27900.00
0005435142738	297	Economy	27900.00
0005434727027	297	Economy	27900.00
0005434551889	297	Economy	27900.00
0005434726938	297	Economy	27900.00
0005432277969	297	Economy	27900.00
0005433234142	297	Economy	27900.00
0005435142746	297	Economy	27900.00
0005434726935	297	Economy	27900.00
0005434551907	297	Economy	27900.00
0005434727005	297	Economy	27900.00
0005433234286	297	Economy	27900.00
0005434726972	297	Economy	27900.00
0005433234383	297	Economy	27900.00
0005434726919	297	Economy	27900.00
0005433234376	297	Economy	27900.00
0005434727008	297	Economy	27900.00
0005433126855	297	Economy	27900.00
0005434726946	297	Economy	27900.00
0005434727028	297	Economy	27900.00
0005434726985	297	Economy	27900.00
0005434726939	297	Economy	27900.00
0005434726937	297	Economy	27900.00
0005433234291	297	Economy	27900.00
0005433234446	297	Economy	27900.00
0005433234328	297	Economy	27900.00
0005433234419	297	Economy	27900.00
0005433234221	297	Economy	27900.00
0005434727020	297	Economy	27900.00
0005434726980	297	Economy	27900.00
0005433181255	297	Economy	27900.00
0005435142743	297	Economy	27900.00
0005433289860	297	Economy	27900.00
0005433181242	297	Economy	27900.00
0005435142740	297	Economy	27900.00
0005433234339	297	Economy	27900.00
0005434726922	297	Economy	27900.00
0005433181258	297	Economy	27900.00
0005434726997	297	Economy	27900.00
0005433111505	297	Economy	27900.00
0005433234998	9835	Business	83700.00
0005433181421	9835	Business	83700.00
0005434726253	9835	Business	83700.00
0005434551590	9835	Business	83700.00
0005434725941	9835	Business	83700.00
0005433234951	9835	Business	83700.00
0005434726093	9835	Business	83700.00
0005433235003	9835	Business	83700.00
0005434725801	9835	Business	83700.00
0005434551314	9835	Business	83700.00
0005434032081	9835	Business	83700.00
0005434551501	9835	Business	83700.00
0005434551362	9835	Business	83700.00
0005434726410	9835	Business	83700.00
0005433235008	9835	Business	83700.00
0005434551176	9835	Business	83700.00
0005433181401	9835	Business	83700.00
0005433234973	9835	Business	83700.00
0005434725471	9835	Business	83700.00
0005434551225	9835	Business	83700.00
0005435142611	9835	Business	83700.00
0005433181407	9835	Business	83700.00
0005433181408	9835	Comfort	47400.00
0005433235000	9835	Comfort	47400.00
0005434725912	9835	Comfort	47400.00
0005432199332	9835	Comfort	47400.00
0005434725472	9835	Comfort	47400.00
0005434551444	9835	Comfort	47400.00
0005433234983	9835	Comfort	47400.00
0005433234999	9835	Comfort	47400.00
0005433235009	9835	Comfort	47400.00
0005433181419	9835	Comfort	47400.00
0005434726105	9835	Comfort	47400.00
0005434551610	9835	Comfort	47400.00
0005433289937	9835	Comfort	47400.00
0005433289934	9835	Comfort	47400.00
0005434551535	9835	Comfort	47400.00
0005433234977	9835	Comfort	47400.00
0005432199336	9835	Comfort	47400.00
0005433234962	9835	Comfort	47400.00
0005433289936	9835	Comfort	47400.00
0005434726038	9835	Comfort	47400.00
0005434725688	9835	Comfort	47400.00
0005433126900	9835	Comfort	47400.00
0005434551269	9835	Comfort	47400.00
0005434725662	9835	Comfort	47400.00
0005434725691	9835	Comfort	47400.00
0005433181415	9835	Comfort	47400.00
0005433181406	9835	Comfort	47400.00
0005434726333	9835	Comfort	47400.00
0005433129330	9835	Comfort	47400.00
0005435142647	9835	Comfort	47400.00
0005434726176	9835	Comfort	47400.00
0005433289935	9835	Comfort	47400.00
0005434726332	9835	Comfort	47400.00
0005434725803	9835	Comfort	47400.00
0005434302459	9835	Comfort	47400.00
0005434551291	9835	Comfort	47400.00
0005434726249	9835	Comfort	47400.00
0005434726605	9835	Comfort	47400.00
0005433234992	9835	Comfort	47400.00
0005433234991	9835	Economy	27900.00
0005434726148	9835	Economy	27900.00
0005433129331	9835	Economy	27900.00
0005434551587	9835	Economy	27900.00
0005434551534	9835	Economy	27900.00
0005434731184	9835	Economy	27900.00
0005434725556	9835	Economy	27900.00
0005434725670	9835	Economy	27900.00
0005433234949	9835	Economy	27900.00
0005434551425	9835	Economy	27900.00
0005433234954	9835	Economy	27900.00
0005434725929	9835	Economy	27900.00
0005433234997	9835	Economy	27900.00
0005433235010	9835	Economy	27900.00
0005433234978	9835	Economy	27900.00
0005434725686	9835	Economy	27900.00
0005433129334	9835	Economy	27900.00
0005434726336	9835	Economy	27900.00
0005433234969	9835	Economy	27900.00
0005434725964	9835	Economy	27900.00
0005434725545	9835	Economy	27900.00
0005434551295	9835	Economy	27900.00
0005434726185	9835	Economy	27900.00
0005434725987	9835	Economy	27900.00
0005432199334	9835	Economy	27900.00
0005434551302	9835	Economy	27900.00
0005434725966	9835	Economy	27900.00
0005434551379	9835	Economy	27900.00
0005434726067	9835	Economy	27900.00
0005434726339	9835	Economy	27900.00
0005434731166	9835	Economy	27900.00
0005434726014	9835	Economy	27900.00
0005434725883	9835	Economy	27900.00
0005434725949	9835	Economy	27900.00
0005434551487	9835	Economy	27900.00
0005434726418	9835	Economy	27900.00
0005434725983	9835	Economy	27900.00
0005433235012	9835	Economy	27900.00
0005434551520	9835	Economy	27900.00
0005433181399	9835	Economy	27900.00
0005435142648	9835	Economy	27900.00
0005434302463	9835	Economy	27900.00
0005434725907	9835	Economy	27900.00
0005433234956	9835	Economy	27900.00
0005434551363	9835	Economy	27900.00
0005433234952	9835	Economy	27900.00
0005434731187	9835	Economy	27900.00
0005434551396	9835	Economy	27900.00
0005434726196	9835	Economy	27900.00
0005434551183	9835	Economy	27900.00
0005434551403	9835	Economy	27900.00
0005434725814	9835	Economy	27900.00
0005434725675	9835	Economy	27900.00
0005433234960	9835	Economy	27900.00
0005434725321	9835	Economy	27900.00
0005434726334	9835	Economy	27900.00
0005434551552	9835	Economy	27900.00
0005434726087	9835	Economy	27900.00
0005434551237	9835	Economy	27900.00
0005434551350	9835	Economy	27900.00
0005434551422	9835	Economy	27900.00
0005433234982	9835	Economy	27900.00
0005433181416	9835	Economy	27900.00
0005433235011	9835	Economy	27900.00
0005433234985	9835	Economy	30700.00
0005433234984	9835	Economy	30700.00
0005434551399	9835	Economy	27900.00
0005433181403	9835	Economy	30700.00
0005434726147	9835	Economy	27900.00
0005434725940	9835	Economy	27900.00
0005433766688	9835	Economy	27900.00
0005433181422	9835	Economy	30700.00
0005433181417	9835	Economy	30700.00
0005434725996	9835	Economy	27900.00
0005434551102	9835	Economy	30700.00
0005432199338	9835	Economy	27900.00
0005434725948	9835	Economy	27900.00
0005434725939	9835	Economy	27900.00
0005434726335	9835	Economy	27900.00
0005434551500	9835	Economy	27900.00
0005433129332	9835	Economy	27900.00
0005433234968	9835	Economy	27900.00
0005434725749	9835	Economy	27900.00
0005434726338	9835	Economy	27900.00
0005433235002	9835	Economy	27900.00
0005434725985	9835	Economy	27900.00
0005434551301	9835	Economy	27900.00
0005433234976	9835	Economy	27900.00
0005434551212	9835	Economy	27900.00
0005434551445	9835	Economy	27900.00
0005434725635	9835	Economy	27900.00
0005434551224	9835	Economy	27900.00
0005434551538	9835	Economy	27900.00
0005435142523	9835	Economy	27900.00
0005433235005	9835	Economy	27900.00
0005433234955	9835	Economy	27900.00
0005433234966	9835	Economy	27900.00
0005434725756	9835	Economy	27900.00
0005434731188	9835	Economy	27900.00
0005434726036	9835	Economy	27900.00
0005434726094	9835	Economy	27900.00
0005433113563	9835	Economy	27900.00
0005434032080	9835	Economy	27900.00
0005433126899	9835	Economy	27900.00
0005433234958	9835	Economy	27900.00
0005433234995	9835	Economy	27900.00
0005433234963	9835	Economy	27900.00
0005433234950	9835	Economy	27900.00
0005434725908	9835	Economy	27900.00
0005434726068	9835	Economy	27900.00
0005433234994	9835	Economy	27900.00
0005433234980	9835	Economy	27900.00
0005433181414	9835	Economy	27900.00
0005434551421	9835	Economy	27900.00
0005434551159	9835	Economy	27900.00
0005434726417	9835	Economy	27900.00
0005434725676	9835	Economy	27900.00
0005433181410	9835	Economy	27900.00
0005434725877	9835	Economy	27900.00
0005433181424	9835	Economy	27900.00
0005433289932	9835	Economy	27900.00
0005434731206	9835	Economy	27900.00
0005434726411	9835	Economy	27900.00
0005434551481	9835	Economy	27900.00
0005434725475	9835	Economy	27900.00
0005434551383	9835	Economy	27900.00
0005433234986	9835	Economy	27900.00
0005433234979	9835	Economy	27900.00
0005434725928	9835	Economy	27900.00
0005432199331	9835	Economy	27900.00
0005434725977	9835	Economy	27900.00
0005434551347	9835	Economy	27900.00
0005433766689	9835	Economy	27900.00
0005434725322	9835	Economy	27900.00
0005434726306	9835	Economy	27900.00
0005434726210	9835	Economy	27900.00
0005434551215	9835	Economy	27900.00
0005433766686	9835	Economy	27900.00
0005433181404	9835	Economy	27900.00
0005434725984	9835	Economy	27900.00
0005434032083	9835	Economy	27900.00
0005434551434	9835	Economy	27900.00
0005434725899	9835	Economy	27900.00
0005434551416	9835	Economy	27900.00
0005434725592	9835	Economy	27900.00
0005433234959	9835	Economy	27900.00
0005433234970	9835	Economy	27900.00
0005434725769	9835	Economy	27900.00
0005434725800	9835	Economy	27900.00
0005433234990	9835	Economy	27900.00
0005434551387	9835	Economy	27900.00
0005434551289	9835	Economy	27900.00
0005433234948	9835	Economy	27900.00
0005434735717	9835	Economy	27900.00
0005434725320	9835	Economy	27900.00
0005434551378	9835	Economy	27900.00
0005434725729	9835	Economy	27900.00
0005434725713	9835	Economy	27900.00
0005434726174	9835	Economy	27900.00
0005434032082	9835	Economy	27900.00
0005434726353	9835	Economy	27900.00
0005434551446	9835	Economy	27900.00
0005434551309	9835	Economy	27900.00
0005433234975	9835	Economy	27900.00
0005434551329	9835	Economy	27900.00
0005434725815	9835	Economy	27900.00
0005434726049	9835	Economy	27900.00
0005434725416	9835	Economy	27900.00
0005433181418	9835	Economy	27900.00
0005434725599	9835	Economy	27900.00
0005434551198	9835	Economy	27900.00
0005434726066	9835	Economy	27900.00
0005434725900	9835	Economy	27900.00
0005434725776	9835	Economy	27900.00
0005433234965	9835	Economy	27900.00
0005433181412	9835	Economy	30700.00
0005434725994	9835	Economy	27900.00
0005434726069	9835	Economy	30700.00
0005433234953	9835	Economy	30700.00
0005434725687	9835	Economy	30700.00
0005434302460	9835	Economy	30700.00
0005434551376	9835	Economy	27900.00
0005434725389	9835	Economy	30700.00
0005433235004	9835	Economy	27900.00
0005434551394	9835	Economy	27900.00
0005434726154	9835	Economy	27900.00
0005434726043	9835	Economy	27900.00
0005433234964	9835	Economy	27900.00
0005434726268	9835	Economy	27900.00
0005434551488	9835	Economy	27900.00
0005434551351	9835	Economy	27900.00
0005435142574	9835	Economy	27900.00
0005433129333	9835	Economy	27900.00
0005434725607	9835	Economy	27900.00
0005434731186	9835	Economy	27900.00
0005434551524	9835	Economy	27900.00
0005434551340	9835	Economy	27900.00
0005434551290	9835	Economy	27900.00
0005433234967	9835	Economy	27900.00
0005434551346	9835	Economy	27900.00
0005434725669	9835	Economy	27900.00
0005433126901	9835	Economy	27900.00
0005434725852	9835	Economy	27900.00
0005433181409	9835	Economy	27900.00
0005434725565	9835	Economy	27900.00
0005433181405	9835	Economy	27900.00
0005434551233	9835	Economy	27900.00
0005434726130	9835	Economy	27900.00
0005433234972	9835	Economy	27900.00
0005434725753	9835	Economy	27900.00
0005434726164	9835	Economy	27900.00
0005433181402	9835	Economy	27900.00
0005434551432	9835	Economy	27900.00
0005433181413	9835	Economy	27900.00
0005434725634	9835	Economy	27900.00
0005433234971	9835	Economy	27900.00
0005433235001	9835	Economy	27900.00
0005434725525	9835	Economy	27900.00
0005434725702	9835	Economy	27900.00
0005434726165	9835	Economy	27900.00
0005434302474	9835	Economy	27900.00
0005433234974	9835	Economy	27900.00
0005434725850	9835	Economy	27900.00
0005434725911	9835	Economy	27900.00
0005433181400	9835	Economy	27900.00
0005433234989	9835	Economy	27900.00
0005433181423	9835	Economy	27900.00
0005433235013	9835	Economy	27900.00
0005433181420	9835	Economy	27900.00
0005433234987	9835	Economy	27900.00
0005433234988	9835	Economy	27900.00
0005433289938	9835	Economy	27900.00
0005434551238	9835	Economy	27900.00
0005432199330	9835	Economy	27900.00
0005434725689	9835	Economy	27900.00
0005434551216	9835	Economy	27900.00
0005433181411	9835	Economy	27900.00
0005433234993	9835	Economy	27900.00
0005434726219	9835	Economy	27900.00
0005434725730	9835	Economy	27900.00
0005434726039	9835	Economy	27900.00
0005434725526	9835	Economy	27900.00
0005434551325	9835	Economy	27900.00
0005434725851	9835	Economy	27900.00
0005433235007	9835	Economy	27900.00
0005434725764	9835	Economy	27900.00
0005434551443	9835	Economy	27900.00
0005434726167	9835	Economy	27900.00
0005434551341	9835	Economy	27900.00
0005434726037	9835	Economy	27900.00
0005433234957	9835	Economy	27900.00
0005434551433	9835	Economy	27900.00
0005434726050	9835	Economy	27900.00
0005434551367	9835	Economy	27900.00
0005434551395	9835	Economy	27900.00
0005434551388	9835	Economy	27900.00
0005434551401	9835	Economy	27900.00
0005433234961	9835	Economy	27900.00
0005434725728	9835	Economy	27900.00
0005433289933	9835	Economy	27900.00
0005432199335	9835	Economy	27900.00
0005434551324	9835	Economy	27900.00
0005434726155	9835	Economy	27900.00
0005435142583	9835	Economy	27900.00
0005433766687	9835	Economy	27900.00
0005434726145	9835	Economy	27900.00
0005434551226	9835	Economy	27900.00
0005433235006	9835	Economy	27900.00
0005433126902	9835	Economy	27900.00
0005434725628	9835	Economy	27900.00
0005434725663	9835	Economy	27900.00
0005434551467	9835	Economy	27900.00
0005434551368	9835	Economy	27900.00
0005432199337	9835	Economy	27900.00
0005435142639	9835	Economy	27900.00
0005434726606	9835	Economy	27900.00
0005433234981	9835	Economy	27900.00
0005433234996	9835	Economy	27900.00
0005434551328	9835	Economy	27900.00
0005434726187	9835	Economy	27900.00
0005434726209	9835	Economy	27900.00
0005434726175	9835	Economy	27900.00
0005432199333	9835	Economy	27900.00
0005432529582	7721	Business	42100.00
0005432529566	7721	Business	42100.00
0005433656674	7721	Business	42100.00
0005432428971	7721	Business	42100.00
0005432428970	7721	Business	42100.00
0005432529565	7721	Business	42100.00
0005434068428	7721	Business	42100.00
0005434068469	7721	Business	42100.00
0005432428972	7721	Business	42100.00
0005435213733	7721	Business	42100.00
0005432069835	7721	Business	42100.00
0005432529605	7721	Business	42100.00
0005432529555	7721	Business	42100.00
0005434068468	7721	Business	42100.00
0005432529626	7721	Business	42100.00
0005432529601	7721	Business	42100.00
0005432529558	7721	Business	42100.00
0005434068465	7721	Business	42100.00
0005432529628	7721	Business	42100.00
0005432529652	7721	Business	42100.00
0005434068439	7721	Business	42100.00
0005435213873	7721	Business	42100.00
0005432529578	7721	Business	42100.00
0005432529627	7721	Business	42100.00
0005435213906	7721	Business	42100.00
0005434068464	7721	Business	42100.00
0005434068404	7721	Comfort	23900.00
0005434068455	7721	Business	42100.00
0005432529552	7721	Comfort	23900.00
0005434068415	7721	Comfort	23900.00
0005435214058	7721	Comfort	23900.00
0005434068426	7721	Comfort	23900.00
0005432069829	7721	Comfort	23900.00
0005434068416	7721	Comfort	23900.00
0005434068472	7721	Comfort	23900.00
0005432150293	7721	Comfort	23900.00
0005434068471	7721	Comfort	23900.00
0005434068442	7721	Comfort	23900.00
0005432529617	7721	Comfort	23900.00
0005432069827	7721	Comfort	23900.00
0005432529567	7721	Comfort	23900.00
0005432529614	7721	Comfort	23900.00
0005432529594	7721	Comfort	23900.00
0005432069828	7721	Comfort	23900.00
0005435213839	7721	Comfort	23900.00
0005432150292	7721	Comfort	23900.00
0005432069830	7721	Comfort	23900.00
0005432529550	7721	Comfort	23900.00
0005432529624	7721	Comfort	23900.00
0005434068445	7721	Comfort	23900.00
0005434068424	7721	Comfort	23900.00
0005435213866	7721	Comfort	23900.00
0005434068441	7721	Comfort	23900.00
0005434068407	7721	Comfort	23900.00
0005432529562	7721	Comfort	23900.00
0005432529584	7721	Comfort	23900.00
0005434068431	7721	Comfort	23900.00
0005432069836	7721	Comfort	23900.00
0005432529597	7721	Comfort	23900.00
0005435725605	7721	Comfort	23900.00
0005432150289	7721	Comfort	23900.00
0005432529586	7721	Comfort	23900.00
0005432529543	7721	Comfort	23900.00
0005432529575	7721	Comfort	23900.00
0005435213749	7721	Comfort	23900.00
0005432533328	7721	Comfort	23900.00
0005432529658	7721	Comfort	23900.00
0005435213731	7721	Comfort	23900.00
0005432529603	7721	Comfort	23900.00
0005432529654	7721	Economy	14000.00
0005432529641	7721	Economy	14000.00
0005432069838	7721	Economy	14000.00
0005432529657	7721	Economy	14000.00
0005432150288	7721	Economy	14000.00
0005432529526	7721	Economy	14000.00
0005435213730	7721	Economy	14000.00
0005435213719	7721	Economy	14000.00
0005434068420	7721	Economy	14000.00
0005432529539	7721	Economy	14000.00
0005432529608	7721	Economy	14000.00
0005432529571	7721	Economy	14000.00
0005432529647	7721	Economy	14000.00
0005432529588	7721	Economy	14000.00
0005432529634	7721	Economy	14000.00
0005432529649	7721	Economy	14000.00
0005432529561	7721	Economy	14000.00
0005435214057	7721	Economy	14000.00
0005435213922	7721	Economy	14000.00
0005434068437	7721	Economy	14000.00
0005435213898	7721	Economy	14000.00
0005432529615	7721	Economy	14000.00
0005432529556	7721	Economy	14000.00
0005432069839	7721	Economy	14000.00
0005432529609	7721	Economy	14000.00
0005435213755	7721	Economy	14000.00
0005432535891	7721	Economy	14000.00
0005432529613	7721	Economy	14000.00
0005435630963	7721	Economy	14000.00
0005434068447	7721	Economy	14000.00
0005434068421	7721	Economy	14000.00
0005435213732	7721	Economy	14000.00
0005432529528	7721	Economy	14000.00
0005432529653	7721	Economy	14000.00
0005432529630	7721	Economy	14000.00
0005432529625	7721	Economy	14000.00
0005434068425	7721	Economy	14000.00
0005432529542	7721	Economy	14000.00
0005434068461	7721	Economy	14000.00
0005435213700	7721	Economy	14000.00
0005435213729	7721	Economy	14000.00
0005432529635	7721	Economy	14000.00
0005434068405	7721	Economy	14000.00
0005435213721	7721	Economy	14000.00
0005432529534	7721	Economy	14000.00
0005435213825	7721	Economy	14000.00
0005432529560	7721	Economy	14000.00
0005434068444	7721	Economy	14000.00
0005432529532	7721	Economy	14000.00
0005434068411	7721	Economy	14000.00
0005432529590	7721	Economy	14000.00
0005432428969	7721	Economy	14000.00
0005434068438	7721	Economy	14000.00
0005432529593	7721	Economy	14000.00
0005435213891	7721	Economy	14000.00
0005432529537	7721	Economy	14000.00
0005432529533	7721	Economy	14000.00
0005434068470	7721	Economy	14000.00
0005432529549	7721	Economy	15400.00
0005435213923	7721	Economy	15400.00
0005432529557	7721	Economy	14000.00
0005434068459	7721	Economy	14000.00
0005435213720	7721	Economy	14000.00
0005432533327	7721	Economy	15400.00
0005432529599	7721	Economy	15400.00
0005434068450	7721	Economy	14000.00
0005434068436	7721	Economy	15400.00
0005434068451	7721	Economy	14000.00
0005434068435	7721	Economy	14000.00
0005432529638	7721	Economy	14000.00
0005435213766	7721	Economy	14000.00
0005432529546	7721	Economy	14000.00
0005432529621	7721	Economy	14000.00
0005432069833	7721	Economy	14000.00
0005432529529	7721	Economy	14000.00
0005432529536	7721	Economy	14000.00
0005432069834	7721	Economy	14000.00
0005432529607	7721	Economy	14000.00
0005435213652	7721	Economy	14000.00
0005435213752	7721	Economy	14000.00
0005434068423	7721	Economy	14000.00
0005434068410	7721	Economy	14000.00
0005435213715	7721	Economy	14000.00
0005432529587	7721	Economy	14000.00
0005432529618	7721	Economy	14000.00
0005432529591	7721	Economy	14000.00
0005435213518	7721	Economy	14000.00
0005434068457	7721	Economy	14000.00
0005432150291	7721	Economy	14000.00
0005432529632	7721	Economy	14000.00
0005435213471	7721	Economy	14000.00
0005434068406	7721	Economy	14000.00
0005432529585	7721	Economy	14000.00
0005432529540	7721	Economy	14000.00
0005435213742	7721	Economy	14000.00
0005432529619	7721	Economy	14000.00
0005434068458	7721	Economy	14000.00
0005432529541	7721	Economy	14000.00
0005435214019	7721	Economy	14000.00
0005434068454	7721	Economy	14000.00
0005432529583	7721	Economy	14000.00
0005435214002	7721	Economy	14000.00
0005432529642	7721	Economy	14000.00
0005432529646	7721	Economy	14000.00
0005435213917	7721	Economy	14000.00
0005434068402	7721	Economy	14000.00
0005432529589	7721	Economy	14000.00
0005432529633	7721	Economy	14000.00
0005432529622	7721	Economy	14000.00
0005432069832	7721	Economy	14000.00
0005434068462	7721	Economy	14000.00
0005434068440	7721	Economy	14000.00
0005434068414	7721	Economy	14000.00
0005432529569	7721	Economy	14000.00
0005432529656	7721	Economy	14000.00
0005434068446	7721	Economy	14000.00
0005435213816	7721	Economy	14000.00
0005434068422	7721	Economy	14000.00
0005432069837	7721	Economy	14000.00
0005432529576	7721	Economy	14000.00
0005434068433	7721	Economy	14000.00
0005435213645	7721	Economy	14000.00
0005432529637	7721	Economy	14000.00
0005432529577	7721	Economy	14000.00
0005432529644	7721	Economy	14000.00
0005435213919	7721	Economy	14000.00
0005435213805	7721	Economy	14000.00
0005435213633	7721	Economy	14000.00
0005435213960	7721	Economy	14000.00
0005435630964	7721	Economy	14000.00
0005435213728	7721	Economy	14000.00
0005435213530	7721	Economy	14000.00
0005432529580	7721	Economy	14000.00
0005435214130	7721	Economy	14000.00
0005432529551	7721	Economy	14000.00
0005434068463	7721	Economy	14000.00
0005435213775	7721	Economy	14000.00
0005435213655	7721	Economy	14000.00
0005432529568	7721	Economy	14000.00
0005434068409	7721	Economy	14000.00
0005432529616	7721	Economy	14000.00
0005434068408	7721	Economy	14000.00
0005435213727	7721	Economy	14000.00
0005434068412	7721	Economy	14000.00
0005435213756	7721	Economy	14000.00
0005432529573	7721	Economy	14000.00
0005434068403	7721	Economy	14000.00
0005432529623	7721	Economy	14000.00
0005432529650	7721	Economy	14000.00
0005434068417	7721	Economy	14000.00
0005435213735	7721	Economy	14000.00
0005432529643	7721	Economy	14000.00
0005432529581	7721	Economy	14000.00
0005435213650	7721	Economy	14000.00
0005435213734	7721	Economy	14000.00
0005432529553	7721	Economy	14000.00
0005432529547	7721	Economy	14000.00
0005432529579	7721	Economy	14000.00
0005432529559	7721	Economy	15400.00
0005434068460	7721	Economy	14000.00
0005432529596	7721	Economy	15400.00
0005432150290	7721	Economy	15400.00
0005432529564	7721	Economy	15400.00
0005435213686	7721	Economy	15400.00
0005432529563	7721	Economy	14000.00
0005435213781	7721	Economy	14000.00
0005432529572	7721	Economy	14000.00
0005432150294	7721	Economy	14000.00
0005435214123	7721	Economy	14000.00
0005435213722	7721	Economy	14000.00
0005435213751	7721	Economy	14000.00
0005432535894	7721	Economy	14000.00
0005432537083	7721	Economy	14000.00
0005435213867	7721	Economy	14000.00
0005435213705	7721	Economy	14000.00
0005435213776	7721	Economy	14000.00
0005432529570	7721	Economy	14000.00
0005432537084	7721	Economy	14000.00
0005434068443	7721	Economy	14000.00
0005432069826	7721	Economy	14000.00
0005432529531	7721	Economy	14000.00
0005432535892	7721	Economy	14000.00
0005432529592	7721	Economy	14000.00
0005432529611	7721	Economy	14000.00
0005435213726	7721	Economy	14000.00
0005434068418	7721	Economy	14000.00
0005435214066	7721	Economy	14000.00
0005432529538	7721	Economy	14000.00
0005434068466	7721	Economy	14000.00
0005432529636	7721	Economy	14000.00
0005434068449	7721	Economy	14000.00
0005432529598	7721	Economy	14000.00
0005434068452	7721	Economy	14000.00
0005434068467	7721	Economy	14000.00
0005432529612	7721	Economy	14000.00
0005432529629	7721	Economy	14000.00
0005432529574	7721	Economy	14000.00
0005432529600	7721	Economy	14000.00
0005434068453	7721	Economy	14000.00
0005435213517	7721	Economy	14000.00
0005434068413	7721	Economy	14000.00
0005432529645	7721	Economy	14000.00
0005435213578	7721	Economy	14000.00
0005434068430	7721	Economy	14000.00
0005432529595	7721	Economy	14000.00
0005435213475	7721	Economy	14000.00
0005435213761	7721	Economy	14000.00
0005432529544	7721	Economy	14000.00
0005434068427	7721	Economy	14000.00
0005432529606	7721	Economy	14000.00
0005432529639	7721	Economy	14000.00
0005432529527	7721	Economy	14000.00
0005435213641	7721	Economy	14000.00
0005434068429	7721	Economy	14000.00
0005434068456	7721	Economy	14000.00
0005435213472	7721	Economy	14000.00
0005432529655	7721	Economy	14000.00
0005432529651	7721	Economy	14000.00
0005432535895	7721	Economy	14000.00
0005435213712	7721	Economy	14000.00
0005432529530	7721	Economy	14000.00
0005435213704	7721	Economy	14000.00
0005432529525	7721	Economy	14000.00
0005435213930	7721	Economy	14000.00
0005432529535	7721	Economy	14000.00
0005435213638	7721	Economy	14000.00
0005432150295	7721	Economy	14000.00
0005432069840	7721	Economy	14000.00
0005435213366	7721	Economy	14000.00
0005435213829	7721	Economy	14000.00
0005434068419	7721	Economy	14000.00
0005434068448	7721	Economy	14000.00
0005432529602	7721	Economy	14000.00
0005435214124	7721	Economy	14000.00
0005432529554	7721	Economy	14000.00
0005433656673	7721	Economy	14000.00
0005435213815	7721	Economy	14000.00
0005434068434	7721	Economy	14000.00
0005432529604	7721	Economy	14000.00
0005435213703	7721	Economy	14000.00
0005432529545	7721	Economy	14000.00
0005432529640	7721	Economy	14000.00
0005435213367	7721	Economy	14000.00
0005432529610	7721	Economy	14000.00
0005435213762	7721	Economy	14000.00
0005434068432	7721	Economy	14000.00
0005432529648	7721	Economy	14000.00
0005435213454	7721	Economy	14000.00
0005432069831	7721	Economy	14000.00
0005435213609	7721	Economy	14000.00
0005432529548	7721	Economy	14000.00
0005432529631	7721	Economy	14000.00
0005435213902	7721	Economy	14000.00
0005432529620	7721	Economy	14000.00
0005432529524	7721	Economy	14000.00
0005432535893	7721	Economy	14000.00
0005435380319	5353	Business	43100.00
0005434344668	5353	Business	43100.00
0005435615043	5353	Business	43100.00
0005435424984	5353	Business	43100.00
0005435425127	5353	Business	43100.00
0005435097325	5353	Business	43100.00
0005435615088	5353	Business	43100.00
0005435615003	5353	Business	43100.00
0005435425151	5353	Business	43100.00
0005435615038	5353	Business	43100.00
0005434573524	5353	Business	43100.00
0005434344644	5353	Business	43100.00
0005435425159	5353	Business	43100.00
0005435490273	5353	Business	43100.00
0005434245056	5353	Business	43100.00
0005435615017	5353	Business	43100.00
0005435615091	5353	Business	43100.00
0005435615027	5353	Business	43100.00
0005435425298	5353	Business	43100.00
0005435425266	5353	Business	43100.00
0005435615063	5353	Business	43100.00
0005434245148	5353	Business	43100.00
0005435425339	5353	Business	43100.00
0005435042851	5353	Business	43100.00
0005432047597	5353	Business	43100.00
0005435615036	5353	Business	43100.00
0005435424954	5353	Comfort	24400.00
0005435615075	5353	Comfort	24400.00
0005435615048	5353	Comfort	24400.00
0005435615074	5353	Comfort	24400.00
0005435615056	5353	Comfort	24400.00
0005432133400	5353	Comfort	24400.00
0005435425121	5353	Comfort	24400.00
0005435425270	5353	Comfort	24400.00
0005435425012	5353	Comfort	24400.00
0005435425018	5353	Comfort	24400.00
0005432841024	5353	Comfort	24400.00
0005434344657	5353	Comfort	24400.00
0005435615039	5353	Comfort	24400.00
0005435425078	5353	Comfort	24400.00
0005435425350	5353	Comfort	24400.00
0005435615049	5353	Comfort	24400.00
0005434344667	5353	Comfort	24400.00
0005435615024	5353	Comfort	24400.00
0005434245106	5353	Comfort	24400.00
0005434245203	5353	Comfort	24400.00
0005434344672	5353	Comfort	24400.00
0005435425112	5353	Comfort	24400.00
0005435042869	5353	Comfort	24400.00
0005434573533	5353	Comfort	24400.00
0005434245084	5353	Comfort	24400.00
0005435615059	5353	Comfort	24400.00
0005435425049	5353	Comfort	24400.00
0005434344640	5353	Comfort	24400.00
0005434245135	5353	Comfort	24400.00
0005435425261	5353	Comfort	24400.00
0005435615080	5353	Comfort	24400.00
0005435615041	5353	Comfort	24400.00
0005435425148	5353	Comfort	24400.00
0005435425050	5353	Comfort	24400.00
0005435302218	5353	Comfort	24400.00
0005435491465	5353	Economy	14400.00
0005435615096	5353	Economy	14400.00
0005435425453	5353	Economy	14400.00
0005434344643	5353	Economy	14400.00
0005434344645	5353	Economy	14400.00
0005435615077	5353	Economy	14400.00
0005435425059	5353	Economy	14400.00
0005435425032	5353	Economy	14400.00
0005435615020	5353	Economy	14400.00
0005435615028	5353	Economy	14400.00
0005434573520	5353	Economy	14400.00
0005434245055	5353	Economy	14400.00
0005435425509	5353	Economy	14400.00
0005435615037	5353	Economy	14400.00
0005434344669	5353	Economy	14400.00
0005434245062	5353	Economy	14400.00
0005435615067	5353	Economy	14400.00
0005434245087	5353	Economy	14400.00
0005435425029	5353	Economy	14400.00
0005435615090	5353	Economy	14400.00
0005434344665	5353	Economy	14400.00
0005435615058	5353	Economy	14400.00
0005435615005	5353	Economy	14400.00
0005435425147	5353	Economy	14400.00
0005434344661	5353	Economy	14400.00
0005432133391	5353	Economy	14400.00
0005435425516	5353	Economy	14400.00
0005435615007	5353	Economy	14400.00
0005434344655	5353	Economy	14400.00
0005435615083	5353	Economy	14400.00
0005434245147	5353	Economy	14400.00
0005435425183	5353	Economy	14400.00
0005435615018	5353	Economy	14400.00
0005435615060	5353	Economy	14400.00
0005434344664	5353	Economy	14400.00
0005432133399	5353	Economy	14400.00
0005435319648	5353	Economy	14400.00
0005435615013	5353	Economy	14400.00
0005434344646	5353	Economy	14400.00
0005434344660	5353	Economy	14400.00
0005434344637	5353	Economy	14400.00
0005435615026	5353	Economy	14400.00
0005435425359	5353	Economy	14400.00
0005435042861	5353	Economy	14400.00
0005435615001	5353	Economy	14400.00
0005434245029	5353	Economy	14400.00
0005432047595	5353	Economy	14400.00
0005435425455	5353	Economy	14400.00
0005435042870	5353	Economy	14400.00
0005435425031	5353	Economy	14400.00
0005434245031	5353	Economy	14400.00
0005435615095	5353	Economy	14400.00
0005432133395	5353	Economy	14400.00
0005435425111	5353	Economy	14400.00
0005435614999	5353	Economy	14400.00
0005435425030	5353	Economy	14400.00
0005434245086	5353	Economy	14400.00
0005435097323	5353	Economy	14400.00
0005435042849	5353	Economy	14400.00
0005434344666	5353	Economy	14400.00
0005435424859	5353	Economy	14400.00
0005435615002	5353	Economy	14400.00
0005433719152	5353	Economy	14400.00
0005435615071	5353	Economy	14400.00
0005435615044	5353	Economy	14400.00
0005435491463	5353	Economy	14400.00
0005434245143	5353	Economy	15800.00
0005435319647	5353	Economy	15800.00
0005434245077	5353	Economy	14400.00
0005435425041	5353	Economy	14400.00
0005435380326	5353	Economy	14400.00
0005432133397	5353	Economy	15800.00
0005435615064	5353	Economy	15800.00
0005435305015	5353	Economy	14400.00
0005435615069	5353	Economy	14400.00
0005434573526	5353	Economy	14400.00
0005435097324	5353	Economy	14400.00
0005435490272	5353	Economy	14400.00
0005435302205	5353	Economy	14400.00
0005434245116	5353	Economy	14400.00
0005435425180	5353	Economy	14400.00
0005432363426	5353	Economy	14400.00
0005434344650	5353	Economy	14400.00
0005434573530	5353	Economy	14400.00
0005435042850	5353	Economy	14400.00
0005435615076	5353	Economy	14400.00
0005432133393	5353	Economy	14400.00
0005435424903	5353	Economy	14400.00
0005435425397	5353	Economy	14400.00
0005434245060	5353	Economy	14400.00
0005435425454	5353	Economy	14400.00
0005435615047	5353	Economy	14400.00
0005435615015	5353	Economy	14400.00
0005434344670	5353	Economy	14400.00
0005434344662	5353	Economy	14400.00
0005435615078	5353	Economy	14400.00
0005432133401	5353	Economy	14400.00
0005432133404	5353	Economy	14400.00
0005432841012	5353	Economy	14400.00
0005435425048	5353	Economy	14400.00
0005434245185	5353	Economy	14400.00
0005435615072	5353	Economy	14400.00
0005435425518	5353	Economy	14400.00
0005434344663	5353	Economy	14400.00
0005434245021	5353	Economy	14400.00
0005435615057	5353	Economy	14400.00
0005435425311	5353	Economy	14400.00
0005435425099	5353	Economy	14400.00
0005435425133	5353	Economy	14400.00
0005435097326	5353	Economy	14400.00
0005435615068	5353	Economy	14400.00
0005435615086	5353	Economy	14400.00
0005434573529	5353	Economy	14400.00
0005435424946	5353	Economy	14400.00
0005434573534	5353	Economy	14400.00
0005432047596	5353	Economy	14400.00
0005434245140	5353	Economy	14400.00
0005432841018	5353	Economy	14400.00
0005435425179	5353	Economy	14400.00
0005435042865	5353	Economy	14400.00
0005435615016	5353	Economy	14400.00
0005435424902	5353	Economy	14400.00
0005435425190	5353	Economy	14400.00
0005435305014	5353	Economy	14400.00
0005434344659	5353	Economy	14400.00
0005435425313	5353	Economy	14400.00
0005435042862	5353	Economy	14400.00
0005435615062	5353	Economy	14400.00
0005435615094	5353	Economy	14400.00
0005435615073	5353	Economy	14400.00
0005434245063	5353	Economy	14400.00
0005435097329	5353	Economy	14400.00
0005435615070	5353	Economy	14400.00
0005435425283	5353	Economy	14400.00
0005434656564	5353	Economy	14400.00
0005435425312	5353	Economy	14400.00
0005434344647	5353	Economy	14400.00
0005435424947	5353	Economy	14400.00
0005435615046	5353	Economy	14400.00
0005435615010	5353	Economy	14400.00
0005435425232	5353	Economy	14400.00
0005435425243	5353	Economy	14400.00
0005435425004	5353	Economy	14400.00
0005433719148	5353	Economy	14400.00
0005435615031	5353	Economy	14400.00
0005435615054	5353	Economy	14400.00
0005435042857	5353	Economy	14400.00
0005434245117	5353	Economy	14400.00
0005435424976	5353	Economy	14400.00
0005434344658	5353	Economy	14400.00
0005432133398	5353	Economy	14400.00
0005435425228	5353	Economy	14400.00
0005434244964	5353	Economy	14400.00
0005434344654	5353	Economy	14400.00
0005435425088	5353	Economy	14400.00
0005435615065	5353	Economy	14400.00
0005435615061	5353	Economy	14400.00
0005435615000	5353	Economy	14400.00
0005435615084	5353	Economy	14400.00
0005435615051	5353	Economy	14400.00
0005434344649	5353	Economy	14400.00
0005435615004	5353	Economy	14400.00
0005435615022	5353	Economy	14400.00
0005435615045	5353	Economy	14400.00
0005434573525	5353	Economy	14400.00
0005435097327	5353	Economy	14400.00
0005435425340	5353	Economy	14400.00
0005435615052	5353	Economy	14400.00
0005435615085	5353	Economy	14400.00
0005435555394	5353	Economy	14400.00
0005435425396	5353	Economy	14400.00
0005432133402	5353	Economy	14400.00
0005435425517	5353	Economy	14400.00
0005434573521	5353	Economy	14400.00
0005434245030	5353	Economy	14400.00
0005434245136	5353	Economy	15800.00
0005435491464	5353	Economy	15800.00
0005434344638	5353	Economy	15800.00
0005435319610	5353	Economy	14400.00
0005432133396	5353	Economy	14400.00
0005434245094	5353	Economy	14400.00
0005435425055	5353	Economy	14400.00
0005435425005	5353	Economy	14400.00
0005435424924	5353	Economy	14400.00
0005435424726	5353	Economy	14400.00
0005435319614	5353	Economy	14400.00
0005435615011	5353	Economy	14400.00
0005435615030	5353	Economy	14400.00
0005434344653	5353	Economy	14400.00
0005434245107	5353	Economy	14400.00
0005434245067	5353	Economy	14400.00
0005434245144	5353	Economy	14400.00
0005434344652	5353	Economy	14400.00
0005435424940	5353	Economy	14400.00
0005435319602	5353	Economy	14400.00
0005435490274	5353	Economy	14400.00
0005434245139	5353	Economy	14400.00
0005434573528	5353	Economy	14400.00
0005434245061	5353	Economy	14400.00
0005434344673	5353	Economy	14400.00
0005435425152	5353	Economy	14400.00
0005434573523	5353	Economy	14400.00
0005434245149	5353	Economy	14400.00
0005435615066	5353	Economy	14400.00
0005435319613	5353	Economy	14400.00
0005435425160	5353	Economy	14400.00
0005435319568	5353	Economy	14400.00
0005435615029	5353	Economy	14400.00
0005435425201	5353	Economy	14400.00
0005434344639	5353	Economy	14400.00
0005435615093	5353	Economy	14400.00
0005435042859	5353	Economy	14400.00
0005435425089	5353	Economy	14400.00
0005435615021	5353	Economy	14400.00
0005435615087	5353	Economy	14400.00
0005435615089	5353	Economy	14400.00
0005435042871	5353	Economy	14400.00
0005434656558	5353	Economy	14400.00
0005434344656	5353	Economy	14400.00
0005435615034	5353	Economy	14400.00
0005432841017	5353	Economy	14400.00
0005435302202	5353	Economy	14400.00
0005432133394	5353	Economy	14400.00
0005435425325	5353	Economy	14400.00
0005435615023	5353	Economy	14400.00
0005435615042	5353	Economy	14400.00
0005435615032	5353	Economy	14400.00
0005434344648	5353	Economy	14400.00
0005434573527	5353	Economy	14400.00
0005435615033	5353	Economy	14400.00
0005434244976	5353	Economy	14400.00
0005434344641	5353	Economy	14400.00
0005435042863	5353	Economy	14400.00
0005435042856	5353	Economy	14400.00
0005432133403	5353	Economy	14400.00
0005435615008	5353	Economy	14400.00
0005435615025	5353	Economy	14400.00
0005435425141	5353	Economy	14400.00
0005434344671	5353	Economy	14400.00
0005432133392	5353	Economy	14400.00
0005435615009	5353	Economy	14400.00
0005435425139	5353	Economy	14400.00
0005434573532	5353	Economy	14400.00
0005433719147	5353	Economy	14400.00
0005435615040	5353	Economy	14400.00
0005435097331	5353	Economy	14400.00
0005435615019	5353	Economy	14400.00
0005435615055	5353	Economy	14400.00
0005435425231	5353	Economy	14400.00
0005435425113	5353	Economy	14400.00
0005435425006	5353	Economy	14400.00
0005435424941	5353	Economy	14400.00
0005435097330	5353	Economy	14400.00
0005434573522	5353	Economy	14400.00
0005435615079	5353	Economy	14400.00
0005435614998	5353	Economy	14400.00
0005435615050	5353	Economy	14400.00
0005434245138	5353	Economy	14400.00
0005435615006	5353	Economy	14400.00
0005435302212	5353	Economy	14400.00
0005434344651	5353	Economy	14400.00
0005435380271	5353	Economy	14400.00
0005435097322	5353	Economy	14400.00
0005435615035	5353	Economy	14400.00
0005434573531	5353	Economy	14400.00
0005435615082	5353	Economy	14400.00
0005434245156	5353	Economy	14400.00
0005435615012	5353	Economy	14400.00
0005435425134	5353	Economy	14400.00
0005435424631	5353	Economy	14400.00
0005435425150	5353	Economy	14400.00
0005435425335	5353	Economy	14400.00
0005434344642	5353	Economy	14400.00
0005434245002	5353	Economy	14400.00
0005435425071	5353	Economy	14400.00
0005434245059	5353	Economy	14400.00
0005435615092	5353	Economy	14400.00
0005435615081	5353	Economy	14400.00
0005435302203	5353	Economy	14400.00
0005435615053	5353	Economy	14400.00
0005435097328	5353	Economy	14400.00
0005435425508	5353	Economy	14400.00
0005435615014	5353	Economy	14400.00
0005435613740	10873	Business	43100.00
0005434573433	10873	Business	43100.00
0005435614120	10873	Business	43100.00
0005432165130	10873	Business	43100.00
0005435613940	10873	Business	43100.00
0005434245327	10873	Business	43100.00
0005435425639	10873	Business	43100.00
0005434245345	10873	Business	43100.00
0005435425641	10873	Business	43100.00
0005434344359	10873	Business	43100.00
0005435613790	10873	Business	43100.00
0005435097247	10873	Business	43100.00
0005435614420	10873	Business	43100.00
0005435613865	10873	Business	43100.00
0005435613604	10873	Business	43100.00
0005434344323	10873	Business	43100.00
0005435614217	10873	Business	43100.00
0005435614115	10873	Business	43100.00
0005435425638	10873	Business	43100.00
0005435614091	10873	Business	43100.00
0005435614230	10873	Business	43100.00
0005435425623	10873	Business	43100.00
0005435614124	10873	Business	43100.00
0005435613975	10873	Business	43100.00
0005435425625	10873	Business	43100.00
0005435380345	10873	Business	43100.00
0005435613882	10873	Business	43100.00
0005435305036	10873	Comfort	24400.00
0005434344361	10873	Comfort	24400.00
0005434245356	10873	Comfort	24400.00
0005435614338	10873	Comfort	24400.00
0005435614526	10873	Comfort	24400.00
0005435613920	10873	Comfort	24400.00
0005435614162	10873	Comfort	24400.00
0005435614337	10873	Comfort	24400.00
0005435425631	10873	Comfort	24400.00
0005434344248	10873	Comfort	24400.00
0005435614332	10873	Comfort	24400.00
0005435613947	10873	Comfort	24400.00
0005435614172	10873	Comfort	24400.00
0005435614221	10873	Comfort	24400.00
0005435614151	10873	Comfort	24400.00
0005435425676	10873	Comfort	24400.00
0005435613955	10873	Comfort	24400.00
0005432166941	10873	Comfort	24400.00
0005435304209	10873	Comfort	24400.00
0005434344360	10873	Comfort	24400.00
0005435304213	10873	Comfort	24400.00
0005435491453	10873	Comfort	24400.00
0005435614116	10873	Comfort	24400.00
0005435613845	10873	Comfort	24400.00
0005435097191	10873	Comfort	24400.00
0005435425677	10873	Comfort	24400.00
0005435380348	10873	Comfort	24400.00
0005435613663	10873	Comfort	24400.00
0005434245337	10873	Comfort	24400.00
0005435614141	10873	Comfort	24400.00
0005435425621	10873	Comfort	24400.00
0005434573374	10873	Comfort	24400.00
0005435613973	10873	Comfort	24400.00
0005435304214	10873	Comfort	24400.00
0005435425678	10873	Comfort	24400.00
0005434656581	10873	Comfort	24400.00
0005435614114	10873	Comfort	24400.00
0005434245343	10873	Comfort	24400.00
0005435614498	10873	Economy	14400.00
0005434344336	10873	Economy	14400.00
0005435425657	10873	Economy	14400.00
0005432165129	10873	Economy	14400.00
0005434344159	10873	Economy	14400.00
0005435425690	10873	Economy	14400.00
0005435380347	10873	Economy	14400.00
0005435425662	10873	Economy	14400.00
0005435319677	10873	Economy	14400.00
0005435305037	10873	Economy	14400.00
0005435425642	10873	Economy	14400.00
0005434245348	10873	Economy	14400.00
0005435425658	10873	Economy	14400.00
0005435490224	10873	Economy	14400.00
0005435614015	10873	Economy	14400.00
0005432165131	10873	Economy	14400.00
0005434573416	10873	Economy	14400.00
0005435425660	10873	Economy	14400.00
0005435491454	10873	Economy	14400.00
0005435425663	10873	Economy	14400.00
0005435613946	10873	Economy	14400.00
0005435614245	10873	Economy	14400.00
0005435614102	10873	Economy	14400.00
0005434245338	10873	Economy	14400.00
0005435614176	10873	Economy	14400.00
0005434344283	10873	Economy	14400.00
0005435614222	10873	Economy	14400.00
0005432165135	10873	Economy	14400.00
0005434573432	10873	Economy	14400.00
0005435613956	10873	Economy	14400.00
0005435614349	10873	Economy	14400.00
0005435425681	10873	Economy	14400.00
0005435613698	10873	Economy	14400.00
0005435613796	10873	Economy	14400.00
0005435425649	10873	Economy	14400.00
0005434245335	10873	Economy	14400.00
0005435613948	10873	Economy	14400.00
0005434245355	10873	Economy	14400.00
0005435613433	10873	Economy	14400.00
0005435613847	10873	Economy	14400.00
0005435613736	10873	Economy	14400.00
0005435614350	10873	Economy	14400.00
0005435614297	10873	Economy	14400.00
0005435319685	10873	Economy	14400.00
0005435614093	10873	Economy	14400.00
0005435614317	10873	Economy	14400.00
0005435614223	10873	Economy	14400.00
0005435425669	10873	Economy	14400.00
0005435425628	10873	Economy	14400.00
0005435613758	10873	Economy	14400.00
0005435425675	10873	Economy	14400.00
0005434344095	10873	Economy	14400.00
0005435614298	10873	Economy	14400.00
0005432165136	10873	Economy	14400.00
0005435613804	10873	Economy	14400.00
0005435613746	10873	Economy	14400.00
0005434245347	10873	Economy	14400.00
0005434344228	10873	Economy	14400.00
0005435614336	10873	Economy	14400.00
0005435613974	10873	Economy	14400.00
0005434573316	10873	Economy	14400.00
0005434245340	10873	Economy	15800.00
0005435613715	10873	Economy	15800.00
0005435425647	10873	Economy	15800.00
0005435380349	10873	Economy	14400.00
0005435425637	10873	Economy	14400.00
0005435042884	10873	Economy	14400.00
0005434245351	10873	Economy	15800.00
0005435425668	10873	Economy	14400.00
0005435614147	10873	Economy	15800.00
0005435425653	10873	Economy	14400.00
0005435613351	10873	Economy	15800.00
0005435425636	10873	Economy	14400.00
0005435613944	10873	Economy	14400.00
0005435613812	10873	Economy	14400.00
0005435614164	10873	Economy	14400.00
0005434245350	10873	Economy	14400.00
0005435613949	10873	Economy	14400.00
0005435614242	10873	Economy	14400.00
0005435425670	10873	Economy	14400.00
0005435613795	10873	Economy	14400.00
0005435425661	10873	Economy	14400.00
0005435425627	10873	Economy	14400.00
0005435614079	10873	Economy	14400.00
0005435614165	10873	Economy	14400.00
0005435319678	10873	Economy	14400.00
0005435380346	10873	Economy	14400.00
0005435613525	10873	Economy	14400.00
0005434344295	10873	Economy	14400.00
0005435614220	10873	Economy	14400.00
0005435425667	10873	Economy	14400.00
0005433719184	10873	Economy	14400.00
0005434573329	10873	Economy	14400.00
0005435319682	10873	Economy	14400.00
0005435614090	10873	Economy	14400.00
0005435425683	10873	Economy	14400.00
0005432165134	10873	Economy	14400.00
0005434344150	10873	Economy	14400.00
0005435425633	10873	Economy	14400.00
0005434573352	10873	Economy	14400.00
0005434344219	10873	Economy	14400.00
0005435613976	10873	Economy	14400.00
0005435425622	10873	Economy	14400.00
0005434344411	10873	Economy	14400.00
0005435613699	10873	Economy	14400.00
0005434344342	10873	Economy	14400.00
0005435425686	10873	Economy	14400.00
0005435319680	10873	Economy	14400.00
0005435613803	10873	Economy	14400.00
0005435614383	10873	Economy	14400.00
0005435614216	10873	Economy	14400.00
0005435614014	10873	Economy	14400.00
0005435425684	10873	Economy	14400.00
0005435613607	10873	Economy	14400.00
0005435425645	10873	Economy	14400.00
0005435425656	10873	Economy	14400.00
0005435425674	10873	Economy	14400.00
0005435614119	10873	Economy	14400.00
0005435614244	10873	Economy	14400.00
0005435425679	10873	Economy	14400.00
0005433719185	10873	Economy	14400.00
0005435425624	10873	Economy	14400.00
0005435425689	10873	Economy	14400.00
0005435614467	10873	Economy	14400.00
0005435614282	10873	Economy	14400.00
0005435425654	10873	Economy	14400.00
0005434573357	10873	Economy	14400.00
0005434245330	10873	Economy	14400.00
0005435614327	10873	Economy	14400.00
0005435425685	10873	Economy	14400.00
0005435425655	10873	Economy	14400.00
0005435614280	10873	Economy	14400.00
0005434245342	10873	Economy	14400.00
0005434245354	10873	Economy	14400.00
0005435613747	10873	Economy	14400.00
0005435614403	10873	Economy	14400.00
0005434344220	10873	Economy	14400.00
0005432363456	10873	Economy	14400.00
0005434344317	10873	Economy	14400.00
0005434245346	10873	Economy	14400.00
0005435380350	10873	Economy	14400.00
0005435614243	10873	Economy	14400.00
0005435613846	10873	Economy	14400.00
0005432841040	10873	Economy	14400.00
0005435425665	10873	Economy	14400.00
0005435614387	10873	Economy	14400.00
0005435614152	10873	Economy	14400.00
0005434245329	10873	Economy	14400.00
0005435425680	10873	Economy	14400.00
0005435425688	10873	Economy	14400.00
0005435613748	10873	Economy	14400.00
0005434573361	10873	Economy	14400.00
0005433719183	10873	Economy	14400.00
0005435613798	10873	Economy	14400.00
0005435613828	10873	Economy	14400.00
0005435425672	10873	Economy	14400.00
0005434245336	10873	Economy	14400.00
0005435614201	10873	Economy	14400.00
0005434344151	10873	Economy	14400.00
0005435614163	10873	Economy	14400.00
0005434245334	10873	Economy	14400.00
0005435614334	10873	Economy	15800.00
0005435425630	10873	Economy	14400.00
0005435425640	10873	Economy	15800.00
0005434344227	10873	Economy	15800.00
0005435613919	10873	Economy	15800.00
0005435097253	10873	Economy	14400.00
0005432363457	10873	Economy	14400.00
0005435614524	10873	Economy	14400.00
0005435425673	10873	Economy	14400.00
0005434245328	10873	Economy	14400.00
0005434344404	10873	Economy	14400.00
0005435614477	10873	Economy	14400.00
0005434344226	10873	Economy	14400.00
0005435304210	10873	Economy	14400.00
0005435425666	10873	Economy	14400.00
0005435614335	10873	Economy	14400.00
0005434573317	10873	Economy	14400.00
0005434344111	10873	Economy	14400.00
0005435613741	10873	Economy	14400.00
0005435613784	10873	Economy	14400.00
0005435304211	10873	Economy	14400.00
0005434245339	10873	Economy	14400.00
0005435614241	10873	Economy	14400.00
0005435613749	10873	Economy	14400.00
0005435613945	10873	Economy	14400.00
0005435613881	10873	Economy	14400.00
0005435614087	10873	Economy	14400.00
0005435425632	10873	Economy	14400.00
0005434245353	10873	Economy	14400.00
0005435614382	10873	Economy	14400.00
0005435614405	10873	Economy	14400.00
0005434344188	10873	Economy	14400.00
0005435613664	10873	Economy	14400.00
0005432841039	10873	Economy	14400.00
0005432165133	10873	Economy	14400.00
0005434344208	10873	Economy	14400.00
0005435425629	10873	Economy	14400.00
0005434344196	10873	Economy	14400.00
0005433719182	10873	Economy	14400.00
0005435425691	10873	Economy	14400.00
0005434245333	10873	Economy	14400.00
0005435614468	10873	Economy	14400.00
0005435613907	10873	Economy	14400.00
0005435425646	10873	Economy	14400.00
0005435614117	10873	Economy	14400.00
0005435425648	10873	Economy	14400.00
0005435425635	10873	Economy	14400.00
0005434245349	10873	Economy	14400.00
0005435319684	10873	Economy	14400.00
0005435613432	10873	Economy	14400.00
0005434245332	10873	Economy	14400.00
0005434344337	10873	Economy	14400.00
0005435425626	10873	Economy	14400.00
0005434344247	10873	Economy	14400.00
0005435319679	10873	Economy	14400.00
0005435425634	10873	Economy	14400.00
0005435613994	10873	Economy	14400.00
0005435614231	10873	Economy	14400.00
0005434344324	10873	Economy	14400.00
0005435425671	10873	Economy	14400.00
0005434656580	10873	Economy	14400.00
0005435425664	10873	Economy	14400.00
0005435380351	10873	Economy	14400.00
0005435613526	10873	Economy	14400.00
0005435613665	10873	Economy	14400.00
0005435613666	10873	Economy	14400.00
0005435614088	10873	Economy	14400.00
0005434245352	10873	Economy	14400.00
0005435614478	10873	Economy	14400.00
0005435425643	10873	Economy	14400.00
0005435425644	10873	Economy	14400.00
0005435490242	10873	Economy	14400.00
0005435613532	10873	Economy	14400.00
0005435614173	10873	Economy	14400.00
0005432363455	10873	Economy	14400.00
0005432165132	10873	Economy	14400.00
0005435425659	10873	Economy	14400.00
0005435425652	10873	Economy	14400.00
0005432166942	10873	Economy	14400.00
0005435613739	10873	Economy	14400.00
0005435319683	10873	Economy	14400.00
0005435614041	10873	Economy	14400.00
0005435319681	10873	Economy	14400.00
0005434245331	10873	Economy	14400.00
0005435425650	10873	Economy	14400.00
0005434344189	10873	Economy	14400.00
0005435614166	10873	Economy	14400.00
0005434245341	10873	Economy	14400.00
0005435614333	10873	Economy	14400.00
0005434344316	10873	Economy	14400.00
0005434656582	10873	Economy	14400.00
0005435425651	10873	Economy	14400.00
0005435614140	10873	Economy	14400.00
0005435097236	10873	Economy	14400.00
0005434344466	10873	Economy	14400.00
0005435425682	10873	Economy	14400.00
0005435304212	10873	Economy	14400.00
0005435614281	10873	Economy	14400.00
0005435614344	10873	Economy	14400.00
0005434344286	10873	Economy	14400.00
0005434245344	10873	Economy	14400.00
0005435425687	10873	Economy	14400.00
0005433634237	3226	Business	18800.00
0005433805793	3226	Business	18800.00
0005432460107	3226	Business	18800.00
0005432181986	3226	Business	18800.00
0005433805816	3226	Business	18800.00
0005433634244	3226	Business	18800.00
0005432181980	3226	Business	18800.00
0005433805796	3226	Business	18800.00
0005432459996	3226	Business	18800.00
0005433634242	3226	Business	18800.00
0005432181999	3226	Business	18800.00
0005432181996	3226	Business	18800.00
0005432460053	3226	Business	18800.00
0005432459824	3226	Business	18800.00
0005432460056	3226	Business	18800.00
0005432460047	3226	Business	18800.00
0005433634255	3226	Business	18800.00
0005433805818	3226	Business	18800.00
0005432181993	3226	Business	18800.00
0005432459944	3226	Business	18800.00
0005432460178	3226	Business	18800.00
0005432460065	3226	Business	18800.00
0005432181981	3226	Business	18800.00
0005432460054	3226	Business	18800.00
0005432460040	3226	Business	18800.00
0005433805819	3226	Business	18800.00
0005433634231	3226	Economy	6900.00
0005433805791	3226	Economy	6900.00
0005432459803	3226	Economy	6900.00
0005433805821	3226	Economy	6900.00
0005432182003	3226	Economy	6900.00
0005432181995	3226	Economy	6900.00
0005433507397	3226	Economy	6300.00
0005432459859	3226	Economy	6300.00
0005432460039	3226	Economy	6300.00
0005432460141	3226	Economy	6300.00
0005432181990	3226	Economy	6300.00
0005432181997	3226	Economy	6300.00
0005432460041	3226	Economy	6300.00
0005432460122	3226	Economy	6300.00
0005432181991	3226	Economy	6300.00
0005433805789	3226	Economy	6300.00
0005432459995	3226	Economy	6300.00
0005433805804	3226	Economy	6300.00
0005432459936	3226	Economy	6300.00
0005432460191	3226	Economy	6300.00
0005432460088	3226	Economy	6300.00
0005433507400	3226	Economy	6300.00
0005433634246	3226	Economy	6300.00
0005433634248	3226	Economy	6300.00
0005432181985	3226	Economy	6300.00
0005432460236	3226	Economy	6300.00
0005433805807	3226	Economy	6300.00
0005432181998	3226	Economy	6300.00
0005433634241	3226	Economy	6300.00
0005432460023	3226	Economy	6300.00
0005432460068	3226	Economy	6300.00
0005433805813	3226	Economy	6300.00
0005432459942	3226	Economy	6300.00
0005433805794	3226	Economy	6300.00
0005433634235	3226	Economy	6300.00
0005433805806	3226	Economy	6300.00
0005432459988	3226	Economy	6300.00
0005433507402	3226	Economy	6300.00
0005433634233	3226	Economy	6300.00
0005433507396	3226	Economy	6300.00
0005432459989	3226	Economy	6300.00
0005433634239	3226	Economy	6300.00
0005433507404	3226	Economy	6300.00
0005432459943	3226	Economy	6300.00
0005432460016	3226	Economy	6300.00
0005433507406	3226	Economy	6300.00
0005432460237	3226	Economy	6300.00
0005432460052	3226	Economy	6300.00
0005432460279	3226	Economy	6300.00
0005433805810	3226	Economy	6300.00
0005433634247	3226	Economy	6300.00
0005433507405	3226	Economy	6300.00
0005433507393	3226	Economy	6300.00
0005433634245	3226	Economy	6300.00
0005433634226	3226	Economy	6300.00
0005433507399	3226	Economy	6300.00
0005433805802	3226	Economy	6300.00
0005432459984	3226	Economy	6300.00
0005433634228	3226	Economy	6300.00
0005433634240	3226	Economy	6300.00
0005433805817	3226	Economy	6300.00
0005432181989	3226	Economy	6300.00
0005433805799	3226	Economy	6900.00
0005433634256	3226	Economy	6900.00
0005433805795	3226	Economy	6900.00
0005433805792	3226	Economy	6900.00
0005433805798	3226	Economy	6900.00
0005433634238	3226	Economy	6300.00
0005433634252	3226	Economy	6300.00
0005433805822	3226	Economy	6300.00
0005432460003	3226	Economy	6300.00
0005432181983	3226	Economy	6900.00
0005432460130	3226	Economy	6300.00
0005432459825	3226	Economy	6300.00
0005432459935	3226	Economy	6300.00
0005433634234	3226	Economy	6300.00
0005433634251	3226	Economy	6300.00
0005433507398	3226	Economy	6300.00
0005433507401	3226	Economy	6300.00
0005433805820	3226	Economy	6300.00
0005432460166	3226	Economy	6300.00
0005433634229	3226	Economy	6300.00
0005433507394	3226	Economy	6300.00
0005432182000	3226	Economy	6300.00
0005433805803	3226	Economy	6300.00
0005433634254	3226	Economy	6300.00
0005432459832	3226	Economy	6300.00
0005432181987	3226	Economy	6300.00
0005433805797	3226	Economy	6300.00
0005433634243	3226	Economy	6300.00
0005432181994	3226	Economy	6300.00
0005433507395	3226	Economy	6300.00
0005432460275	3226	Economy	6300.00
0005432181982	3226	Economy	6300.00
0005432460067	3226	Economy	6300.00
0005432460015	3226	Economy	6300.00
0005432460120	3226	Economy	6300.00
0005433634227	3226	Economy	6300.00
0005432460204	3226	Economy	6300.00
0005433805815	3226	Economy	6300.00
0005433805801	3226	Economy	6300.00
0005432459921	3226	Economy	6300.00
0005432182002	3226	Economy	6300.00
0005432181984	3226	Economy	6300.00
0005432181988	3226	Economy	6300.00
0005432460089	3226	Economy	6300.00
0005433634232	3226	Economy	6300.00
0005433805812	3226	Economy	6300.00
0005433805805	3226	Economy	6300.00
0005433634250	3226	Economy	6300.00
0005432459895	3226	Economy	6300.00
0005433805811	3226	Economy	6300.00
0005433805814	3226	Economy	6300.00
0005433634236	3226	Economy	6300.00
0005433634253	3226	Economy	6300.00
0005433634259	3226	Economy	6300.00
0005433634225	3226	Economy	6300.00
0005432181992	3226	Economy	6300.00
0005432182001	3226	Economy	6300.00
0005433507403	3226	Economy	6300.00
0005433634258	3226	Economy	6300.00
0005432459844	3226	Economy	6300.00
0005432460092	3226	Economy	6300.00
0005432459922	3226	Economy	6300.00
0005433634230	3226	Economy	6300.00
0005433634249	3226	Economy	6300.00
0005433634257	3226	Economy	6300.00
0005432459915	3226	Economy	6300.00
0005432460190	3226	Economy	6300.00
0005432460270	3226	Economy	6300.00
0005433805809	3226	Economy	6300.00
0005432460179	3226	Economy	6300.00
0005433805790	3226	Economy	6300.00
0005432460091	3226	Economy	6300.00
0005433805808	3226	Economy	6300.00
0005433805800	3226	Economy	6300.00
0005435885491	3227	Business	18800.00
0005435885685	3227	Business	18800.00
0005435885571	3227	Business	18800.00
0005435885659	3227	Business	18800.00
0005435885410	3227	Business	18800.00
0005435885498	3227	Business	18800.00
0005435885411	3227	Business	18800.00
0005435885445	3227	Business	18800.00
0005435885444	3227	Economy	6900.00
0005435885620	3227	Economy	6900.00
0005435885438	3227	Economy	6900.00
0005435885380	3227	Economy	6300.00
0005435885664	3227	Economy	6300.00
0005435885516	3227	Economy	6300.00
0005435885377	3227	Economy	6300.00
0005435885508	3227	Economy	6300.00
0005435885621	3227	Economy	6300.00
0005435885442	3227	Economy	6300.00
0005435885429	3227	Economy	6300.00
0005435885448	3227	Economy	6300.00
0005435885514	3227	Economy	6300.00
0005435885500	3227	Economy	6300.00
0005435885336	3227	Economy	6300.00
0005435885300	3227	Economy	6300.00
0005435885697	3227	Economy	6300.00
0005435885450	3227	Economy	6300.00
0005435885447	3227	Economy	6300.00
0005435885497	3227	Economy	6300.00
0005435885660	3227	Economy	6300.00
0005435885611	3227	Economy	6300.00
0005435885403	3227	Economy	6900.00
0005435885399	3227	Economy	6900.00
0005435885676	3227	Economy	6300.00
0005435885299	3227	Economy	6300.00
0005435885350	3227	Economy	6300.00
0005435885325	3227	Economy	6300.00
0005435885492	3227	Economy	6300.00
0005435885394	3227	Economy	6300.00
0005435885518	3227	Economy	6300.00
0005435885544	3227	Economy	6300.00
0005435885449	3227	Economy	6300.00
0005435885501	3227	Economy	6300.00
0005435885409	3227	Economy	6300.00
0005435885665	3227	Economy	6300.00
0005435885443	3227	Economy	6300.00
0005435885472	3227	Economy	6300.00
0005435885608	3227	Economy	6300.00
0005435885607	3227	Economy	6300.00
0005432460540	8172	Business	18800.00
0005435885861	8172	Business	18800.00
0005432460547	8172	Business	18800.00
0005435885847	8172	Business	18800.00
0005432460533	8172	Business	18800.00
0005432042889	8172	Business	18800.00
0005435885850	8172	Business	18800.00
0005435885873	8172	Business	18800.00
0005432460512	8172	Business	18800.00
0005435885881	8172	Business	18800.00
0005433507169	8172	Business	18800.00
0005435885858	8172	Business	18800.00
0005432460517	8172	Business	18800.00
0005435885874	8172	Business	18800.00
0005432460508	8172	Business	18800.00
0005432460509	8172	Business	18800.00
0005435885862	8172	Business	18800.00
0005435885836	8172	Business	18800.00
0005432460554	8172	Business	18800.00
0005432042880	8172	Business	18800.00
0005432460520	8172	Business	18800.00
0005432460543	8172	Economy	6900.00
0005435885841	8172	Economy	6900.00
0005435885851	8172	Economy	6900.00
0005432460521	8172	Economy	6900.00
0005432460518	8172	Economy	6900.00
0005435885870	8172	Economy	6900.00
0005432460523	8172	Economy	6300.00
0005432042892	8172	Economy	6300.00
0005432460535	8172	Economy	6300.00
0005435885837	8172	Economy	6300.00
0005433507330	8172	Economy	6300.00
0005435885843	8172	Economy	6300.00
0005435885844	8172	Economy	6300.00
0005435885840	8172	Economy	6300.00
0005432460506	8172	Economy	6300.00
0005435885868	8172	Economy	6300.00
0005432460544	8172	Economy	6300.00
0005434312347	8172	Economy	6300.00
0005432460530	8172	Economy	6300.00
0005433507219	8172	Economy	6300.00
0005435885877	8172	Economy	6300.00
0005432460546	8172	Economy	6300.00
0005435885852	8172	Economy	6300.00
0005432460522	8172	Economy	6300.00
0005435885872	8172	Economy	6300.00
0005432460549	8172	Economy	6300.00
0005432042882	8172	Economy	6300.00
0005432460516	8172	Economy	6300.00
0005432460542	8172	Economy	6300.00
0005432460552	8172	Economy	6300.00
0005435885876	8172	Economy	6300.00
0005432042887	8172	Economy	6300.00
0005432042888	8172	Economy	6300.00
0005435885867	8172	Economy	6300.00
0005435885875	8172	Economy	6300.00
0005433507208	8172	Economy	6300.00
0005432460550	8172	Economy	6300.00
0005432460556	8172	Economy	6300.00
0005432460511	8172	Economy	6300.00
0005435885856	8172	Economy	6300.00
0005432460548	8172	Economy	6300.00
0005433507244	8172	Economy	6300.00
0005435885839	8172	Economy	6300.00
0005433507106	8172	Economy	6300.00
0005435885849	8172	Economy	6300.00
0005435885860	8172	Economy	6300.00
0005433507221	8172	Economy	6300.00
0005435885869	8172	Economy	6300.00
0005433507209	8172	Economy	6300.00
0005432460524	8172	Economy	6300.00
0005432460558	8172	Economy	6300.00
0005432460538	8172	Economy	6300.00
0005432460545	8172	Economy	6300.00
0005433507247	8172	Economy	6300.00
0005432460519	8172	Economy	6300.00
0005435885853	8172	Economy	6900.00
0005433507230	8172	Economy	6900.00
0005433507317	8172	Economy	6900.00
0005435885846	8172	Economy	6900.00
0005432460532	8172	Economy	6900.00
0005432042894	8172	Economy	6300.00
0005432460539	8172	Economy	6300.00
0005432460551	8172	Economy	6300.00
0005435885878	8172	Economy	6300.00
0005435885863	8172	Economy	6900.00
0005433507222	8172	Economy	6300.00
0005432460527	8172	Economy	6300.00
0005433507270	8172	Economy	6300.00
0005435885865	8172	Economy	6300.00
0005432460555	8172	Economy	6300.00
0005432042886	8172	Economy	6300.00
0005432460531	8172	Economy	6300.00
0005432460536	8172	Economy	6300.00
0005435885859	8172	Economy	6300.00
0005435885880	8172	Economy	6300.00
0005432460525	8172	Economy	6300.00
0005432042890	8172	Economy	6300.00
0005432460514	8172	Economy	6300.00
0005433507292	8172	Economy	6300.00
0005433507173	8172	Economy	6300.00
0005432460553	8172	Economy	6300.00
0005433507268	8172	Economy	6300.00
0005432042883	8172	Economy	6300.00
0005432460534	8172	Economy	6300.00
0005432460541	8172	Economy	6300.00
0005433507170	8172	Economy	6300.00
0005432042891	8172	Economy	6300.00
0005432460528	8172	Economy	6300.00
0005432460513	8172	Economy	6300.00
0005435885864	8172	Economy	6300.00
0005433507269	8172	Economy	6300.00
0005432042881	8172	Economy	6300.00
0005432460526	8172	Economy	6300.00
0005435885879	8172	Economy	6300.00
0005435885845	8172	Economy	6300.00
0005433507214	8172	Economy	6300.00
0005432460529	8172	Economy	6300.00
0005435885882	8172	Economy	6300.00
0005432042884	8172	Economy	6300.00
0005435885871	8172	Economy	6300.00
0005432460515	8172	Economy	6300.00
0005432460537	8172	Economy	6300.00
0005435885857	8172	Economy	6300.00
0005435885838	8172	Economy	6300.00
0005432042895	8172	Economy	6300.00
0005432042893	8172	Economy	6300.00
0005435885855	8172	Economy	6300.00
0005435885854	8172	Economy	6300.00
0005432460507	8172	Economy	6300.00
0005433507171	8172	Economy	6300.00
0005432042885	8172	Economy	6300.00
0005435885848	8172	Economy	6300.00
0005435885866	8172	Economy	6300.00
0005435885842	8172	Economy	6300.00
0005432460510	8172	Economy	6300.00
0005433507287	8172	Economy	6300.00
0005433507271	8172	Economy	6300.00
0005432460557	8172	Economy	6300.00
0005434312346	8172	Economy	6300.00
0005433805580	8169	Business	18800.00
0005433805613	8169	Business	18800.00
0005433805592	8169	Business	18800.00
0005433805447	8169	Business	18800.00
0005435854064	8169	Business	18800.00
0005434271315	8169	Business	18800.00
0005433633824	8169	Business	18800.00
0005433633825	8169	Business	18800.00
0005433805486	8169	Business	18800.00
0005433805577	8169	Business	18800.00
0005433633970	8169	Business	18800.00
0005433633858	8169	Business	18800.00
0005433805494	8169	Business	18800.00
0005434143738	8169	Economy	6900.00
0005433805600	8169	Economy	6900.00
0005433633832	8169	Economy	6900.00
0005433805488	8169	Economy	6300.00
0005433805643	8169	Economy	6300.00
0005433633892	8169	Economy	6300.00
0005433805579	8169	Economy	6300.00
0005433633931	8169	Economy	6300.00
0005433805578	8169	Economy	6300.00
0005433633883	8169	Economy	6300.00
0005433633779	8169	Economy	6300.00
0005433633850	8169	Economy	6300.00
0005433805411	8169	Economy	6300.00
0005433633918	8169	Economy	6300.00
0005433805485	8169	Economy	6300.00
0005433805492	8169	Economy	6300.00
0005433805593	8169	Economy	6300.00
0005433805569	8169	Economy	6300.00
0005434143734	8169	Economy	6300.00
0005433633879	8169	Economy	6300.00
0005433805459	8169	Economy	6300.00
0005433633942	8169	Economy	6300.00
0005433805242	8169	Economy	6300.00
0005433805495	8169	Economy	6300.00
0005433633930	8169	Economy	6300.00
0005433633843	8169	Economy	6300.00
0005433633921	8169	Economy	6300.00
0005433633932	8169	Economy	6300.00
0005433805601	8169	Economy	6300.00
0005433633831	8169	Economy	6300.00
0005433805423	8169	Economy	6300.00
0005433633661	8169	Economy	6300.00
0005434271314	8169	Economy	6300.00
0005433805570	8169	Economy	6900.00
0005433805391	8169	Economy	6900.00
0005433805544	8169	Economy	6300.00
0005433805451	8169	Economy	6300.00
0005435854065	8169	Economy	6300.00
0005433805560	8169	Economy	6300.00
0005433633969	8169	Economy	6300.00
0005433805541	8169	Economy	6300.00
0005433805561	8169	Economy	6300.00
0005433805540	8169	Economy	6300.00
0005433633880	8169	Economy	6300.00
0005433805543	8169	Economy	6300.00
0005433633660	8169	Economy	6300.00
0005433805426	8169	Economy	6300.00
0005433805487	8169	Economy	6300.00
0005433805489	8169	Economy	6300.00
0005433805450	8169	Economy	6300.00
0005433805424	8169	Economy	6300.00
0005433633951	8169	Economy	6300.00
0005433805379	8169	Economy	6300.00
0005433805514	8169	Economy	6300.00
0005433633979	8169	Economy	6300.00
0005433805648	8169	Economy	6300.00
0005433633662	8169	Economy	6300.00
0005433805515	8169	Economy	6300.00
0005433633922	8169	Economy	6300.00
0005434183592	8168	Business	18800.00
0005434183589	8168	Business	18800.00
0005434183588	8168	Economy	6300.00
0005434183581	8168	Economy	6300.00
0005434183591	8168	Economy	6300.00
0005432728088	4561	Business	9900.00
0005432728094	4561	Business	9900.00
0005432383667	4561	Business	9900.00
0005432383664	4561	Business	9900.00
0005432383676	4561	Business	9900.00
0005433722304	4561	Business	9900.00
0005433722303	4561	Business	9900.00
0005432383672	4561	Business	9900.00
0005432383665	4561	Business	9900.00
0005432728090	4561	Business	9900.00
0005432383639	4561	Economy	3300.00
0005433722307	4561	Economy	3300.00
0005432383650	4561	Economy	3300.00
0005432728095	4561	Economy	3300.00
0005432383648	4561	Economy	3300.00
0005433453785	4561	Economy	3300.00
0005432383652	4561	Economy	3600.00
0005432728093	4561	Economy	3600.00
0005433722306	4561	Economy	3600.00
0005432728098	4561	Economy	3600.00
0005432383649	4561	Economy	3600.00
0005432383651	4561	Economy	3300.00
0005432383679	4561	Economy	3300.00
0005432383677	4561	Economy	3300.00
0005432383674	4561	Economy	3300.00
0005432383669	4561	Economy	3300.00
0005432728099	4561	Economy	3300.00
0005433453786	4561	Economy	3300.00
0005432728092	4561	Economy	3300.00
0005433454902	4561	Economy	3300.00
0005432728091	4561	Economy	3300.00
0005432383660	4561	Economy	3300.00
0005432383678	4561	Economy	3300.00
0005432383659	4561	Economy	3300.00
0005432383647	4561	Economy	3300.00
0005432383653	4561	Economy	3300.00
0005432383646	4561	Economy	3300.00
0005432383658	4561	Economy	3300.00
0005432383644	4561	Economy	3300.00
0005432728089	4561	Economy	3300.00
0005433454901	4561	Economy	3300.00
0005432728087	4561	Economy	3300.00
0005432383642	4561	Economy	3300.00
0005432383668	4561	Economy	3300.00
0005432383663	4561	Economy	3300.00
0005432383641	4561	Economy	3300.00
0005432383675	4561	Economy	3300.00
0005432383666	4561	Economy	3300.00
0005432383645	4561	Economy	3300.00
0005432383670	4561	Economy	3300.00
0005432383671	4561	Economy	3300.00
0005432383661	4561	Economy	3300.00
0005432383673	4561	Economy	3300.00
0005432383654	4561	Economy	3300.00
0005433722308	4561	Economy	3300.00
0005432383657	4561	Economy	3300.00
0005433722305	4561	Economy	3300.00
0005432383662	4561	Economy	3300.00
0005432383643	4561	Economy	3300.00
0005432728096	4561	Economy	3300.00
0005432728097	4561	Economy	3300.00
0005432383655	4561	Economy	3300.00
0005432383656	4561	Economy	3300.00
0005432383640	4561	Economy	3300.00
0005432383147	30219	Business	9900.00
0005432383116	30219	Business	9900.00
0005432383100	30219	Business	9900.00
0005432383241	30219	Business	9900.00
0005432383153	30219	Business	9900.00
0005433722225	30219	Business	9900.00
0005433453762	30219	Business	9900.00
0005432383121	30219	Economy	3300.00
0005432727950	30219	Economy	3300.00
0005433194854	30219	Economy	3300.00
0005432728022	30219	Economy	3300.00
0005432728020	30219	Economy	3300.00
0005432383243	30219	Economy	3300.00
0005432383311	30219	Economy	3300.00
0005432383149	30219	Economy	3300.00
0005432383277	30219	Economy	3600.00
0005432728023	30219	Economy	3600.00
0005433453763	30219	Economy	3600.00
0005432383232	30219	Economy	3600.00
0005432383042	30219	Economy	3300.00
0005433722199	30219	Economy	3300.00
0005432383016	30219	Economy	3300.00
0005432383191	30219	Economy	3300.00
0005432383306	30219	Economy	3300.00
0005432383183	30219	Economy	3300.00
0005432383264	30219	Economy	3300.00
0005433722228	30219	Economy	3300.00
0005432382995	30219	Economy	3300.00
0005433722227	30219	Economy	3300.00
0005432383148	30219	Economy	3300.00
0005432383084	30219	Economy	3300.00
0005433451632	30219	Economy	3300.00
0005432383202	30219	Economy	3300.00
0005432383154	30219	Economy	3300.00
0005432383278	30219	Economy	3300.00
0005432383312	30219	Economy	3300.00
0005432383150	30219	Economy	3300.00
0005432383096	30219	Economy	3300.00
0005432383239	30219	Economy	3300.00
0005432728021	30219	Economy	3300.00
0005432383268	30219	Economy	3300.00
0005432383132	30219	Economy	3300.00
0005432382996	30219	Economy	3300.00
0005432383117	30219	Economy	3300.00
0005432383203	30219	Economy	3300.00
0005432383043	30219	Economy	3300.00
0005432383276	30219	Economy	3300.00
0005432728003	30219	Economy	3300.00
0005432383170	30219	Economy	3300.00
0005432383095	30219	Economy	3300.00
0005432383198	30219	Economy	3300.00
0005432727949	30219	Economy	3300.00
0005432383269	30219	Economy	3300.00
0005432383237	30219	Economy	3300.00
0005432383238	30219	Economy	3300.00
0005433194853	30219	Economy	3300.00
0005433194860	30219	Economy	3300.00
0005432383242	30219	Economy	3300.00
0005432383099	30219	Economy	3300.00
0005432383260	30219	Economy	3300.00
0005432727993	30219	Economy	3300.00
0005432383164	30219	Economy	3300.00
0005433451631	30219	Economy	3300.00
0005433722229	30219	Economy	3300.00
0005432383171	30219	Economy	3300.00
0005432383152	30219	Economy	3300.00
0005435541280	1714	Business	57200.00
0005435541267	1714	Business	57200.00
0005435529524	1714	Business	57200.00
0005435529538	1714	Business	57200.00
0005433517004	1714	Business	57200.00
0005435541284	1714	Business	57200.00
0005433517008	1714	Business	57200.00
0005435529533	1714	Business	57200.00
0005432294517	1714	Business	57200.00
0005432925079	1714	Business	57200.00
0005432294518	1714	Economy	19100.00
0005435529536	1714	Economy	19100.00
0005435541269	1714	Economy	19100.00
0005435529528	1714	Economy	19100.00
0005435541278	1714	Economy	19100.00
0005432294516	1714	Economy	19100.00
0005435529540	1714	Economy	21000.00
0005435541281	1714	Economy	21000.00
0005435529527	1714	Economy	21000.00
0005432925078	1714	Economy	21000.00
0005435541275	1714	Economy	19100.00
0005435529539	1714	Economy	19100.00
0005433516999	1714	Economy	19100.00
0005435529523	1714	Economy	19100.00
0005435541273	1714	Economy	19100.00
0005435529541	1714	Economy	19100.00
0005433517006	1714	Economy	19100.00
0005435529532	1714	Economy	19100.00
0005433517003	1714	Economy	19100.00
0005435529530	1714	Economy	19100.00
0005435541283	1714	Economy	19100.00
0005433517000	1714	Economy	19100.00
0005435541265	1714	Economy	19100.00
0005435541277	1714	Economy	19100.00
0005435529534	1714	Economy	19100.00
0005432294519	1714	Economy	19100.00
0005435529522	1714	Economy	19100.00
0005433517001	1714	Economy	19100.00
0005435529535	1714	Economy	19100.00
0005432925032	1714	Economy	19100.00
0005435541270	1714	Economy	19100.00
0005435529537	1714	Economy	19100.00
0005435541271	1714	Economy	19100.00
0005435541285	1714	Economy	19100.00
0005432925031	1714	Economy	19100.00
0005433517002	1714	Economy	19100.00
0005435541272	1714	Economy	19100.00
0005433517007	1714	Economy	19100.00
0005435529529	1714	Economy	19100.00
0005435529521	1714	Economy	19100.00
0005435541266	1714	Economy	19100.00
0005435541276	1714	Economy	19100.00
0005435541268	1714	Economy	19100.00
0005435541286	1714	Economy	19100.00
0005435529526	1714	Economy	19100.00
0005433517005	1714	Economy	19100.00
0005435541279	1714	Economy	19100.00
0005435529525	1714	Economy	19100.00
0005435541274	1714	Economy	19100.00
0005435529542	1714	Economy	19100.00
0005435529531	1714	Economy	19100.00
0005435541282	1714	Economy	19100.00
0005435517939	21972	Business	57200.00
0005435517923	21972	Business	57200.00
0005433516922	21972	Business	57200.00
0005433516943	21972	Business	57200.00
0005435541079	21972	Business	57200.00
0005435518037	21972	Business	57200.00
0005435541040	21972	Business	57200.00
0005432925097	21972	Business	57200.00
0005435541032	21972	Business	57200.00
0005435517954	21972	Economy	19100.00
0005435541115	21972	Economy	19100.00
0005435517993	21972	Economy	19100.00
0005432925095	21972	Economy	19100.00
0005433516923	21972	Economy	19100.00
0005433516917	21972	Economy	19100.00
0005435517946	21972	Economy	21000.00
0005435540999	21972	Economy	21000.00
0005433516899	21972	Economy	21000.00
0005435541112	21972	Economy	19100.00
0005435518035	21972	Economy	19100.00
0005435540966	21972	Economy	19100.00
0005435517951	21972	Economy	19100.00
0005432925098	21972	Economy	19100.00
0005435541052	21972	Economy	19100.00
0005435541116	21972	Economy	19100.00
0005435541033	21972	Economy	19100.00
0005435541062	21972	Economy	19100.00
0005435517877	21972	Economy	19100.00
0005433516950	21972	Economy	19100.00
0005435541095	21972	Economy	19100.00
0005433516955	21972	Economy	19100.00
0005435517953	21972	Economy	19100.00
0005435541131	21972	Economy	19100.00
0005435541134	21972	Economy	19100.00
0005435518022	21972	Economy	19100.00
0005433516904	21972	Economy	19100.00
0005435541137	21972	Economy	19100.00
0005435517947	21972	Economy	19100.00
0005432925094	21972	Economy	19100.00
0005435541138	21972	Economy	19100.00
0005432925096	21972	Economy	19100.00
0005435517862	21972	Economy	19100.00
0005435517861	21972	Economy	19100.00
0005435541096	21972	Economy	19100.00
0005433516840	21972	Economy	19100.00
0005435541019	21972	Economy	19100.00
0005435517878	21972	Economy	19100.00
0005435541099	21972	Economy	19100.00
0005433516926	21972	Economy	19100.00
0005435517933	21972	Economy	19100.00
0005435541100	21972	Economy	19100.00
0005435517924	21972	Economy	19100.00
0005435541089	21972	Economy	19100.00
0005433516921	21972	Economy	19100.00
0005433516903	21972	Economy	19100.00
0005435517967	21972	Economy	19100.00
0005433516918	21972	Economy	19100.00
0005435541000	21972	Economy	19100.00
0005435541097	21972	Economy	19100.00
0005435518001	21972	Economy	19100.00
0005435518015	21972	Economy	19100.00
0005435540998	21972	Economy	19100.00
0005435517934	21972	Economy	19100.00
0005432839428	7358	Business	18500.00
0005435252860	7358	Business	18500.00
0005432839406	7358	Business	18500.00
0005434459072	7358	Business	18500.00
0005434459064	7358	Business	18500.00
0005434459070	7358	Business	18500.00
0005432839431	7358	Business	18500.00
0005435252762	7358	Business	18500.00
0005435252777	7358	Economy	6200.00
0005432839429	7358	Economy	6200.00
0005435252818	7358	Economy	6200.00
0005432839410	7358	Economy	6200.00
0005435252836	7358	Economy	6200.00
0005432839404	7358	Economy	6200.00
0005432839434	7358	Economy	6200.00
0005432839412	7358	Economy	6200.00
0005432839430	7358	Economy	6800.00
0005432839408	7358	Economy	6800.00
0005432839413	7358	Economy	6800.00
0005432839422	7358	Economy	6800.00
0005432823473	7358	Economy	6200.00
0005432839415	7358	Economy	6200.00
0005432839423	7358	Economy	6200.00
0005434459063	7358	Economy	6200.00
0005434459057	7358	Economy	6200.00
0005432839432	7358	Economy	6200.00
0005435252753	7358	Economy	6200.00
0005432839407	7358	Economy	6200.00
0005435252769	7358	Economy	6200.00
0005432839427	7358	Economy	6200.00
0005432839421	7358	Economy	6200.00
0005432839425	7358	Economy	6200.00
0005432073434	7358	Economy	6200.00
0005434459067	7358	Economy	6200.00
0005432839411	7358	Economy	6200.00
0005434459058	7358	Economy	6200.00
0005434459056	7358	Economy	6200.00
0005432839426	7358	Economy	6200.00
0005434459062	7358	Economy	6200.00
0005432073433	7358	Economy	6200.00
0005432839433	7358	Economy	6200.00
0005434459071	7358	Economy	6200.00
0005432839418	7358	Economy	6200.00
0005434664955	7358	Economy	6200.00
0005435252797	7358	Economy	6200.00
0005434459055	7358	Economy	6200.00
0005432839409	7358	Economy	6200.00
0005434459068	7358	Economy	6200.00
0005432839414	7358	Economy	6200.00
0005435252754	7358	Economy	6200.00
0005434459059	7358	Economy	6200.00
0005434459065	7358	Economy	6200.00
0005434459054	7358	Economy	6200.00
0005435252817	7358	Economy	6200.00
0005432841036	7358	Economy	6200.00
0005434459060	7358	Economy	6200.00
0005435252755	7358	Economy	6200.00
0005435252752	7358	Economy	6200.00
0005434459052	7358	Economy	6200.00
0005432839405	7358	Economy	6200.00
0005432839419	7358	Economy	6200.00
0005432841038	7358	Economy	6200.00
0005432839416	7358	Economy	6200.00
0005434459053	7358	Economy	6200.00
0005434459061	7358	Economy	6200.00
0005434459051	7358	Economy	6200.00
0005432841037	7358	Economy	6200.00
0005432839417	7358	Economy	6200.00
0005432073435	7358	Economy	6200.00
0005432839424	7358	Economy	6200.00
0005435252770	7358	Economy	6200.00
0005432073432	7358	Economy	6200.00
0005434459069	7358	Economy	6200.00
0005434459066	7358	Economy	6200.00
0005432839420	7358	Economy	6200.00
0005432839225	28917	Business	18500.00
0005432839117	28917	Business	18500.00
0005432839219	28917	Business	18500.00
0005432839271	28917	Business	18500.00
0005434458908	28917	Business	18500.00
0005434458915	28917	Business	18500.00
0005432841014	28917	Business	18500.00
0005435252913	28917	Economy	6200.00
0005432839220	28917	Economy	6200.00
0005435252926	28917	Economy	6200.00
0005434458898	28917	Economy	6200.00
0005435252920	28917	Economy	6200.00
0005435252916	28917	Economy	6800.00
0005432839293	28917	Economy	6200.00
0005432839266	28917	Economy	6200.00
0005434458862	28917	Economy	6200.00
0005432839178	28917	Economy	6200.00
0005432839209	28917	Economy	6200.00
0005435252927	28917	Economy	6200.00
0005435252925	28917	Economy	6200.00
0005435252924	28917	Economy	6200.00
0005432839270	28917	Economy	6200.00
0005435252929	28917	Economy	6200.00
0005435252914	28917	Economy	6200.00
0005434458856	28917	Economy	6200.00
0005432839254	28917	Economy	6200.00
0005432839152	28917	Economy	6200.00
0005432839176	28917	Economy	6200.00
0005435252922	28917	Economy	6200.00
0005432839124	28917	Economy	6200.00
0005434458916	28917	Economy	6200.00
0005434458918	28917	Economy	6200.00
0005434458778	28917	Economy	6200.00
0005434458846	28917	Economy	6200.00
0005434458861	28917	Economy	6200.00
0005432839208	28917	Economy	6200.00
0005435252917	28917	Economy	6200.00
0005435252921	28917	Economy	6200.00
0005432839216	28917	Economy	6200.00
0005435252923	28917	Economy	6200.00
0005435252928	28917	Economy	6200.00
0005434664989	28917	Economy	6200.00
0005432001048	28917	Economy	6200.00
0005435252915	28917	Economy	6200.00
0005435491467	28917	Economy	6200.00
0005434458863	28917	Economy	6200.00
0005434458885	28917	Economy	6200.00
0005434458930	28917	Economy	6200.00
0005434458847	28917	Economy	6200.00
0005434458886	28917	Economy	6200.00
0005435491466	28917	Economy	6200.00
0005432839177	28917	Economy	6200.00
0005434458938	28917	Economy	6200.00
0005435252919	28917	Economy	6200.00
0005435252918	28917	Economy	6200.00
0005432839106	28917	Economy	6200.00
0005434458813	28917	Economy	6200.00
0005434458882	28917	Economy	6200.00
0005435990710	8797	Business	145300.00
0005435990711	8797	Business	145300.00
0005435990713	8797	Economy	48400.00
0005434276078	8797	Economy	48400.00
0005435990712	8797	Economy	48400.00
0005435990714	8797	Economy	48400.00
0005435990708	8797	Economy	48400.00
0005434276052	8797	Economy	48400.00
0005435990709	8797	Economy	48400.00
0005434276098	15747	Business	145300.00
0005434276096	15747	Economy	48400.00
0005435990668	15747	Economy	48400.00
0005434276100	15747	Economy	48400.00
0005434276099	15747	Economy	48400.00
0005435990645	15747	Economy	48400.00
0005435990676	15747	Economy	48400.00
0005434276097	15747	Economy	48400.00
0005435990654	15747	Economy	48400.00
0005433476896	20630	Economy	15900.00
0005432427169	20630	Economy	14500.00
0005432427167	20630	Economy	14500.00
0005432427170	20630	Economy	14500.00
0005432427168	20630	Economy	14500.00
0005433476901	20630	Economy	14500.00
0005433476920	30846	Economy	14500.00
0005432427145	30846	Economy	14500.00
0005433476919	30846	Economy	14500.00
0005432427140	30846	Economy	14500.00
0005432427147	30846	Economy	14500.00
0005432427148	30846	Economy	14500.00
0005433476918	30846	Economy	14500.00
0005433476917	30846	Economy	14500.00
0005432427149	30846	Economy	14500.00
0005432360979	6368	Business	36600.00
0005435177188	6368	Business	36600.00
0005432360944	6368	Business	36600.00
0005432360959	6368	Business	36600.00
0005432360937	6368	Business	36600.00
0005435177244	6368	Business	36600.00
0005432363456	6368	Business	36600.00
0005432360955	6368	Business	36600.00
0005432336182	6368	Business	36600.00
0005434149769	6368	Business	36600.00
0005432360980	6368	Business	36600.00
0005435177154	6368	Economy	12200.00
0005432360935	6368	Economy	12200.00
0005432336177	6368	Economy	12200.00
0005435177142	6368	Economy	12200.00
0005435177225	6368	Economy	12200.00
0005432360966	6368	Economy	12200.00
0005435177174	6368	Economy	12200.00
0005435177218	6368	Economy	12200.00
0005432336181	6368	Economy	12200.00
0005432360946	6368	Economy	12200.00
0005434149761	6368	Economy	12200.00
0005432360948	6368	Economy	12200.00
0005432360950	6368	Economy	12200.00
0005432360941	6368	Economy	12200.00
0005432360968	6368	Economy	12200.00
0005432360945	6368	Economy	12200.00
0005432360972	6368	Economy	12200.00
0005434149723	6368	Economy	12200.00
0005432360970	6368	Economy	12200.00
0005435177198	6368	Economy	12200.00
0005435177182	6368	Economy	12200.00
0005432360977	6368	Economy	12200.00
0005432336179	6368	Economy	12200.00
0005435177266	6368	Economy	12200.00
0005434149722	6368	Economy	12200.00
0005435177181	6368	Economy	12200.00
0005434149770	6368	Economy	12200.00
0005435177165	6368	Economy	12200.00
0005432360949	6368	Economy	12200.00
0005435723060	6368	Economy	12200.00
0005435177135	6368	Economy	12200.00
0005432363457	6368	Economy	12200.00
0005432360951	6368	Economy	12200.00
0005435177200	6368	Economy	12200.00
0005432360981	6368	Economy	12200.00
0005432336176	6368	Economy	12200.00
0005434149764	6368	Economy	12200.00
0005435177160	6368	Economy	13400.00
0005432360933	6368	Economy	12200.00
0005435177127	6368	Economy	13400.00
0005435177220	6368	Economy	13400.00
0005432062292	6368	Economy	13400.00
0005435177243	6368	Economy	13400.00
0005435177268	6368	Economy	13400.00
0005435177280	6368	Economy	12200.00
0005434149760	6368	Economy	12200.00
0005434149767	6368	Economy	12200.00
0005432062294	6368	Economy	12200.00
0005432360975	6368	Economy	12200.00
0005432336180	6368	Economy	12200.00
0005432360969	6368	Economy	12200.00
0005434149783	6368	Economy	12200.00
0005432360967	6368	Economy	12200.00
0005432336178	6368	Economy	12200.00
0005432360936	6368	Economy	12200.00
0005435177187	6368	Economy	12200.00
0005435490224	6368	Economy	12200.00
0005432360934	6368	Economy	12200.00
0005434149784	6368	Economy	12200.00
0005435177204	6368	Economy	12200.00
0005432360963	6368	Economy	12200.00
0005435723045	6368	Economy	12200.00
0005432360965	6368	Economy	12200.00
0005432360953	6368	Economy	12200.00
0005432360939	6368	Economy	12200.00
0005432336183	6368	Economy	12200.00
0005432336186	6368	Economy	12200.00
0005435177263	6368	Economy	12200.00
0005432360947	6368	Economy	12200.00
0005432062296	6368	Economy	12200.00
0005435177179	6368	Economy	12200.00
0005432360978	6368	Economy	12200.00
0005432336185	6368	Economy	12200.00
0005435177279	6368	Economy	12200.00
0005432360962	6368	Economy	12200.00
0005434149738	6368	Economy	12200.00
0005435177277	6368	Economy	12200.00
0005432360957	6368	Economy	12200.00
0005432360956	6368	Economy	12200.00
0005435177199	6368	Economy	12200.00
0005432360943	6368	Economy	12200.00
0005435177128	6368	Economy	12200.00
0005435177267	6368	Economy	12200.00
0005432360964	6368	Economy	12200.00
0005432360976	6368	Economy	12200.00
0005435490242	6368	Economy	12200.00
0005435177221	6368	Economy	12200.00
0005432360973	6368	Economy	12200.00
0005432360938	6368	Economy	12200.00
0005434149765	6368	Economy	12200.00
0005435177262	6368	Economy	12200.00
0005435177183	6368	Economy	12200.00
0005434149837	6368	Economy	12200.00
0005432360971	6368	Economy	12200.00
0005435177224	6368	Economy	12200.00
0005434149737	6368	Economy	12200.00
0005432360960	6368	Economy	12200.00
0005434149771	6368	Economy	12200.00
0005432360940	6368	Economy	12200.00
0005432062295	6368	Economy	12200.00
0005432360961	6368	Economy	12200.00
0005432360958	6368	Economy	12200.00
0005435177276	6368	Economy	12200.00
0005434149792	6368	Economy	12200.00
0005432360974	6368	Economy	12200.00
0005432360954	6368	Economy	12200.00
0005435177281	6368	Economy	12200.00
0005432336184	6368	Economy	12200.00
0005432062293	6368	Economy	12200.00
0005432360942	6368	Economy	12200.00
0005432363455	6368	Economy	12200.00
0005434149763	6368	Economy	12200.00
0005432360952	6368	Economy	12200.00
0005434149871	21013	Business	36600.00
0005435177410	21013	Business	36600.00
0005435177412	21013	Business	36600.00
0005435177426	21013	Business	36600.00
0005435177417	21013	Business	36600.00
0005432336123	21013	Business	36600.00
0005432360381	21013	Business	36600.00
0005432336047	21013	Business	36600.00
0005432360619	21013	Business	36600.00
0005432360424	21013	Business	36600.00
0005432360554	21013	Business	36600.00
0005434149879	21013	Business	36600.00
0005435177427	21013	Economy	12200.00
0005435177406	21013	Economy	12200.00
0005432360565	21013	Economy	12200.00
0005432360667	21013	Economy	12200.00
0005432360441	21013	Economy	12200.00
0005435177404	21013	Economy	12200.00
0005432336098	21013	Economy	12200.00
0005432360444	21013	Economy	12200.00
0005434149878	21013	Economy	12200.00
0005435177413	21013	Economy	12200.00
0005432360445	21013	Economy	12200.00
0005432360401	21013	Economy	12200.00
0005435177403	21013	Economy	12200.00
0005432336077	21013	Economy	12200.00
0005432360538	21013	Economy	12200.00
0005432360611	21013	Economy	12200.00
0005435177408	21013	Economy	12200.00
0005432360533	21013	Economy	12200.00
0005432360532	21013	Economy	12200.00
0005432360315	21013	Economy	12200.00
0005432360536	21013	Economy	12200.00
0005432363438	21013	Economy	12200.00
0005434149880	21013	Economy	12200.00
0005432360677	21013	Economy	12200.00
0005432360598	21013	Economy	12200.00
0005434149876	21013	Economy	12200.00
0005435177405	21013	Economy	12200.00
0005432052784	21013	Economy	12200.00
0005432360437	21013	Economy	12200.00
0005435723071	21013	Economy	12200.00
0005435177423	21013	Economy	12200.00
0005435177402	21013	Economy	12200.00
0005435177416	21013	Economy	12200.00
0005432360438	21013	Economy	12200.00
0005432360641	21013	Economy	12200.00
0005432360407	21013	Economy	12200.00
0005435177414	21013	Economy	12200.00
0005432336095	21013	Economy	12200.00
0005432360373	21013	Economy	12200.00
0005435177422	21013	Economy	13400.00
0005432336116	21013	Economy	13400.00
0005434149874	21013	Economy	13400.00
0005432360567	21013	Economy	13400.00
0005432360482	21013	Economy	13400.00
0005435490276	21013	Economy	13400.00
0005435177425	21013	Economy	12200.00
0005432360492	21013	Economy	12200.00
0005432360566	21013	Economy	12200.00
0005432336097	21013	Economy	12200.00
0005432360363	21013	Economy	12200.00
0005432360580	21013	Economy	12200.00
0005434149875	21013	Economy	12200.00
0005435177411	21013	Economy	12200.00
0005435177418	21013	Economy	12200.00
0005432360494	21013	Economy	12200.00
0005432360425	21013	Economy	12200.00
0005434149869	21013	Economy	12200.00
0005432360632	21013	Economy	12200.00
0005432360633	21013	Economy	12200.00
0005435177424	21013	Economy	12200.00
0005432360476	21013	Economy	12200.00
0005435490275	21013	Economy	12200.00
0005432360626	21013	Economy	12200.00
0005432360705	21013	Economy	12200.00
0005435177407	21013	Economy	12200.00
0005432360523	21013	Economy	12200.00
0005432360691	21013	Economy	12200.00
0005432336076	21013	Economy	12200.00
0005432360655	21013	Economy	12200.00
0005432360582	21013	Economy	12200.00
0005434149872	21013	Economy	12200.00
0005435490278	21013	Economy	12200.00
0005435177421	21013	Economy	12200.00
0005432360555	21013	Economy	12200.00
0005432360408	21013	Economy	12200.00
0005432360371	21013	Economy	12200.00
0005432360453	21013	Economy	12200.00
0005432360504	21013	Economy	12200.00
0005432360584	21013	Economy	12200.00
0005432360627	21013	Economy	12200.00
0005434149873	21013	Economy	12200.00
0005432360411	21013	Economy	12200.00
0005432052783	21013	Economy	12200.00
0005432360654	21013	Economy	12200.00
0005432360678	21013	Economy	12200.00
0005432360505	21013	Economy	12200.00
0005434149870	21013	Economy	12200.00
0005432336101	21013	Economy	12200.00
0005432360647	21013	Economy	12200.00
0005434149877	21013	Economy	12200.00
0005432360578	21013	Economy	12200.00
0005435177420	21013	Economy	12200.00
0005435723072	21013	Economy	12200.00
0005432336096	21013	Economy	12200.00
0005434149881	21013	Economy	12200.00
0005435723073	21013	Economy	12200.00
0005432360372	21013	Economy	12200.00
0005432052782	21013	Economy	12200.00
0005432360620	21013	Economy	12200.00
0005432360561	21013	Economy	12200.00
0005432363439	21013	Economy	12200.00
0005432363428	21013	Economy	12200.00
0005432360524	21013	Economy	12200.00
0005435177419	21013	Economy	12200.00
0005432360493	21013	Economy	12200.00
0005435490277	21013	Economy	12200.00
0005432336046	21013	Economy	12200.00
0005435177415	21013	Economy	12200.00
0005432360648	21013	Economy	12200.00
0005432360539	21013	Economy	12200.00
0005432360475	21013	Economy	12200.00
0005435177428	21013	Economy	12200.00
0005435177409	21013	Economy	12200.00
0005435177429	21013	Economy	12200.00
0005432360495	21013	Economy	12200.00
0005432336082	21013	Economy	12200.00
0005432360481	21013	Economy	12200.00
0005434458899	17714	Economy	3400.00
0005434448333	17714	Economy	3400.00
0005434458934	17714	Economy	3100.00
0005434458973	17714	Economy	3100.00
0005434458986	17714	Economy	3100.00
0005434458890	17714	Economy	3100.00
0005434458888	17714	Economy	3100.00
0005434458840	17714	Economy	3100.00
0005434458985	17714	Economy	3100.00
0005434186237	17714	Economy	3100.00
0005434458900	17714	Economy	3100.00
0005434458980	17714	Economy	3100.00
0005434458901	17714	Economy	3100.00
0005434458920	17714	Economy	3100.00
0005434458894	17714	Economy	3100.00
0005434186234	17714	Economy	3100.00
0005434186236	17714	Economy	3100.00
0005434458896	17714	Economy	3100.00
0005434458891	17714	Economy	3100.00
0005434458919	17714	Economy	3100.00
0005434458984	17714	Economy	3100.00
0005434461645	17714	Economy	3100.00
0005434458974	17714	Economy	3100.00
0005434458950	17714	Economy	3100.00
0005434448335	17714	Economy	3100.00
0005434458895	17714	Economy	3100.00
0005434448332	17714	Economy	3100.00
0005434448334	17714	Economy	3100.00
0005434458897	17714	Economy	3100.00
0005434458889	17714	Economy	3100.00
0005434186235	17714	Economy	3100.00
0005434186220	29112	Economy	3400.00
0005434459069	29112	Economy	3400.00
0005434463954	29112	Economy	3400.00
0005434459068	29112	Economy	3100.00
0005434448355	29112	Economy	3100.00
0005434459054	29112	Economy	3100.00
0005434186215	29112	Economy	3100.00
0005434459061	29112	Economy	3100.00
0005434459057	29112	Economy	3100.00
0005434459055	29112	Economy	3100.00
0005434459052	29112	Economy	3100.00
0005434459058	29112	Economy	3100.00
0005434448354	29112	Economy	3100.00
0005434459066	29112	Economy	3100.00
0005434186193	29112	Economy	3100.00
0005434459067	29112	Economy	3100.00
0005434459060	29112	Economy	3100.00
0005434459071	29112	Economy	3100.00
0005434459070	29112	Economy	3100.00
0005434459063	29112	Economy	3100.00
0005434459051	29112	Economy	3100.00
0005434459053	29112	Economy	3100.00
0005434459072	29112	Economy	3100.00
0005434459059	29112	Economy	3100.00
0005434462815	29112	Economy	3100.00
0005434459062	29112	Economy	3100.00
0005434459065	29112	Economy	3100.00
0005434459056	29112	Economy	3100.00
0005434459064	29112	Economy	3100.00
0005432604805	21464	Economy	7300.00
0005432604793	21464	Economy	7300.00
0005432604791	21464	Economy	6600.00
0005432604797	21464	Economy	6600.00
0005432604802	21464	Economy	6600.00
0005432604783	21464	Economy	6600.00
0005432604781	21464	Economy	6600.00
0005432604803	21464	Economy	6600.00
0005432604792	21464	Economy	6600.00
0005432604780	21464	Economy	6600.00
0005432604809	21464	Economy	6600.00
0005432604813	21464	Economy	6600.00
0005432604810	21464	Economy	6600.00
0005432604794	21464	Economy	6600.00
0005432604782	21464	Economy	6600.00
0005432604807	21464	Economy	6600.00
0005432604796	21464	Economy	6600.00
0005432604784	21464	Economy	6600.00
0005432604789	21464	Economy	6600.00
0005432604800	21464	Economy	6600.00
0005432604812	21464	Economy	6600.00
0005432604816	21464	Economy	6600.00
0005432604808	21464	Economy	6600.00
0005432604799	21464	Economy	6600.00
0005432604804	21464	Economy	6600.00
0005432604788	21464	Economy	6600.00
0005432604798	21464	Economy	6600.00
0005432604779	21464	Economy	6600.00
0005432604811	21464	Economy	6600.00
0005432604786	21464	Economy	6600.00
0005432604801	21464	Economy	6600.00
0005432604814	21464	Economy	6600.00
0005432604817	21464	Economy	6600.00
0005432604790	21464	Economy	6600.00
0005432604806	21464	Economy	6600.00
0005432604815	21464	Economy	6600.00
0005432604787	21464	Economy	6600.00
0005432604785	21464	Economy	6600.00
0005432604795	21464	Economy	6600.00
0005432604598	31656	Economy	7300.00
0005432604308	31656	Economy	7300.00
0005432604588	31656	Economy	7300.00
0005432604419	31656	Economy	7300.00
0005432604256	31656	Economy	6600.00
0005432604340	31656	Economy	6600.00
0005432604426	31656	Economy	6600.00
0005432604449	31656	Economy	6600.00
0005432604431	31656	Economy	6600.00
0005432604489	31656	Economy	6600.00
0005432604370	31656	Economy	6600.00
0005432604379	31656	Economy	6600.00
0005432604457	31656	Economy	6600.00
0005432604482	31656	Economy	6600.00
0005432604485	31656	Economy	6600.00
0005432604558	31656	Economy	6600.00
0005432604643	31656	Economy	6600.00
0005432604432	31656	Economy	6600.00
0005432604502	31656	Economy	6600.00
0005432604435	31656	Economy	6600.00
0005432604399	31656	Economy	6600.00
0005432604395	31656	Economy	6600.00
0005432604433	31656	Economy	6600.00
0005432604245	31656	Economy	6600.00
0005432604380	31656	Economy	6600.00
0005432604589	31656	Economy	6600.00
0005432604597	31656	Economy	6600.00
0005432604437	31656	Economy	6600.00
0005432604301	31656	Economy	6600.00
0005432604434	31656	Economy	6600.00
0005432604634	31656	Economy	6600.00
0005432604246	31656	Economy	6600.00
0005432604430	31656	Economy	6600.00
0005432604423	31656	Economy	6600.00
0005432604390	31656	Economy	6600.00
0005432604456	31656	Economy	6600.00
0005432604463	31656	Economy	6600.00
0005432604420	31656	Economy	6600.00
0005432604381	31656	Economy	6600.00
0005432604633	31656	Economy	6600.00
0005432604325	31656	Economy	6600.00
0005432604398	31656	Economy	6600.00
0005432604306	31656	Economy	6600.00
0005432604469	31656	Economy	6600.00
0005432604307	31656	Economy	6600.00
0005432604369	31656	Economy	6600.00
0005432604468	31656	Economy	6600.00
0005432604326	31656	Economy	6600.00
0005433293260	12317	Economy	19500.00
0005433293264	12317	Economy	19500.00
0005433293261	12317	Economy	19500.00
0005435154615	12317	Economy	17800.00
0005433293247	12317	Economy	17800.00
0005433293274	12317	Economy	17800.00
0005433293237	12317	Economy	17800.00
0005433293282	12317	Economy	17800.00
0005435154611	12317	Economy	17800.00
0005433293246	12317	Economy	17800.00
0005433293273	12317	Economy	17800.00
0005433293270	12317	Economy	17800.00
0005433293242	12317	Economy	17800.00
0005435154613	12317	Economy	17800.00
0005433293275	12317	Economy	17800.00
0005435154612	12317	Economy	17800.00
0005433293236	12317	Economy	17800.00
0005433293249	12317	Economy	17800.00
0005433293259	12317	Economy	17800.00
0005433293272	12317	Economy	17800.00
0005433293243	12317	Economy	17800.00
0005433293271	12317	Economy	17800.00
0005433293238	12317	Economy	17800.00
0005433293250	12317	Economy	17800.00
0005435154614	12317	Economy	17800.00
0005433293281	12317	Economy	17800.00
0005434606823	18857	Economy	6600.00
0005434606827	18857	Economy	6600.00
0005434606826	18857	Economy	6600.00
0005434606825	18857	Economy	6600.00
0005434606846	18857	Economy	6600.00
0005434606842	18857	Economy	6600.00
0005434606847	18857	Economy	6600.00
0005434606831	18857	Economy	6600.00
0005434606845	18857	Economy	6600.00
0005434604938	22375	Economy	6600.00
0005434606869	22375	Economy	6600.00
0005434604937	22375	Economy	6600.00
0005434606867	22375	Economy	6600.00
0005434606868	22375	Economy	6600.00
0005434604935	22375	Economy	6600.00
0005434604936	22375	Economy	6600.00
0005434606870	22375	Economy	6600.00
0005432748010	375	Business	44500.00
0005432891116	375	Business	44500.00
0005432891097	375	Business	44500.00
0005432891105	375	Business	44500.00
0005432220053	375	Business	44500.00
0005432891070	375	Business	44500.00
0005432891071	375	Business	44500.00
0005432891098	375	Business	44500.00
0005432749810	375	Business	44500.00
0005432891036	375	Business	44500.00
0005432748018	375	Business	44500.00
0005432751566	375	Economy	14800.00
0005432891165	375	Economy	14800.00
0005435154618	375	Economy	14800.00
0005432753339	375	Economy	14800.00
0005432748019	375	Economy	14800.00
0005432891089	375	Economy	14800.00
0005432220055	375	Economy	14800.00
0005432748014	375	Economy	14800.00
0005432891069	375	Economy	16300.00
0005432891030	375	Economy	16300.00
0005432748015	375	Economy	16300.00
0005432891156	375	Economy	16300.00
0005432748009	375	Economy	14800.00
0005432748031	375	Economy	14800.00
0005432891044	375	Economy	14800.00
0005432748047	375	Economy	14800.00
0005432748035	375	Economy	14800.00
0005432748037	375	Economy	14800.00
0005432751564	375	Economy	14800.00
0005435154619	375	Economy	14800.00
0005433293257	375	Economy	14800.00
0005432891029	375	Economy	14800.00
0005432748030	375	Economy	14800.00
0005432748040	375	Economy	14800.00
0005432748032	375	Economy	14800.00
0005432748021	375	Economy	14800.00
0005432748045	375	Economy	14800.00
0005432748046	375	Economy	14800.00
0005432748022	375	Economy	14800.00
0005432748043	375	Economy	14800.00
0005432753338	375	Economy	14800.00
0005432748036	375	Economy	14800.00
0005435154616	375	Economy	14800.00
0005432891150	375	Economy	14800.00
0005432748038	375	Economy	14800.00
0005432748044	375	Economy	14800.00
0005432891035	375	Economy	14800.00
0005432751563	375	Economy	14800.00
0005432748011	375	Economy	14800.00
0005432220056	375	Economy	14800.00
0005432891083	375	Economy	14800.00
0005432748023	375	Economy	14800.00
0005432891043	375	Economy	14800.00
0005432748028	375	Economy	14800.00
0005432748042	375	Economy	14800.00
0005432891120	375	Economy	14800.00
0005432748025	375	Economy	14800.00
0005432748026	375	Economy	14800.00
0005432748033	375	Economy	14800.00
0005432748017	375	Economy	14800.00
0005432748012	375	Economy	14800.00
0005432220054	375	Economy	14800.00
0005432748016	375	Economy	14800.00
0005432748034	375	Economy	14800.00
0005435154620	375	Economy	14800.00
0005432220057	375	Economy	14800.00
0005432748013	375	Economy	14800.00
0005432748024	375	Economy	14800.00
0005432891059	375	Economy	14800.00
0005432748029	375	Economy	14800.00
0005432748020	375	Economy	14800.00
0005432753340	375	Economy	14800.00
0005432748041	375	Economy	14800.00
0005433293245	375	Economy	14800.00
0005432891113	375	Economy	14800.00
0005435154617	375	Economy	14800.00
0005432748039	375	Economy	14800.00
0005432751565	375	Economy	14800.00
0005432748027	375	Economy	14800.00
0005432891065	375	Economy	14800.00
0005432891250	12041	Business	44500.00
0005432747825	12041	Business	44500.00
0005432747665	12041	Business	44500.00
0005432753303	12041	Business	44500.00
0005432747683	12041	Business	44500.00
0005432753319	12041	Business	44500.00
0005432891266	12041	Business	44500.00
0005432747883	12041	Business	44500.00
0005432753302	12041	Business	44500.00
0005433293320	12041	Business	44500.00
0005433293321	12041	Business	44500.00
0005432747671	12041	Business	44500.00
0005432891269	12041	Economy	14800.00
0005432747656	12041	Economy	14800.00
0005432891251	12041	Economy	14800.00
0005433293315	12041	Economy	14800.00
0005432749791	12041	Economy	14800.00
0005432747652	12041	Economy	14800.00
0005432747682	12041	Economy	14800.00
0005432891255	12041	Economy	14800.00
0005432891264	12041	Economy	14800.00
0005432891256	12041	Economy	14800.00
0005432747810	12041	Economy	16300.00
0005432753304	12041	Economy	16300.00
0005432747568	12041	Economy	16300.00
0005432747782	12041	Economy	16300.00
0005432747725	12041	Economy	16300.00
0005432747820	12041	Economy	14800.00
0005433293317	12041	Economy	14800.00
0005433293319	12041	Economy	14800.00
0005432747724	12041	Economy	14800.00
0005432214830	12041	Economy	14800.00
0005432756851	12041	Economy	14800.00
0005432747700	12041	Economy	14800.00
0005432747819	12041	Economy	14800.00
0005432891261	12041	Economy	14800.00
0005432214829	12041	Economy	14800.00
0005432747773	12041	Economy	14800.00
0005432747648	12041	Economy	14800.00
0005432891262	12041	Economy	14800.00
0005432891257	12041	Economy	14800.00
0005432891253	12041	Economy	14800.00
0005432891252	12041	Economy	14800.00
0005432753307	12041	Economy	14800.00
0005432747707	12041	Economy	14800.00
0005432747758	12041	Economy	14800.00
0005432891260	12041	Economy	14800.00
0005432747666	12041	Economy	14800.00
0005432747660	12041	Economy	14800.00
0005432747755	12041	Economy	14800.00
0005432756865	12041	Economy	14800.00
0005432747722	12041	Economy	14800.00
0005432747835	12041	Economy	14800.00
0005432747548	12041	Economy	14800.00
0005433293323	12041	Economy	14800.00
0005432747534	12041	Economy	14800.00
0005432891265	12041	Economy	14800.00
0005432749790	12041	Economy	14800.00
0005432747721	12041	Economy	14800.00
0005432747662	12041	Economy	14800.00
0005432747809	12041	Economy	14800.00
0005432747772	12041	Economy	14800.00
0005432747781	12041	Economy	14800.00
0005432747708	12041	Economy	14800.00
0005433293314	12041	Economy	14800.00
0005432747614	12041	Economy	14800.00
0005432747842	12041	Economy	14800.00
0005432747702	12041	Economy	14800.00
0005432747821	12041	Economy	14800.00
0005432891268	12041	Economy	14800.00
0005433293316	12041	Economy	14800.00
0005432747743	12041	Economy	14800.00
0005432891254	12041	Economy	14800.00
0005432891258	12041	Economy	14800.00
0005433293318	12041	Economy	14800.00
0005432747859	12041	Economy	14800.00
0005432891263	12041	Economy	14800.00
0005432747684	12041	Economy	14800.00
0005432891259	12041	Economy	14800.00
0005432747800	12041	Economy	14800.00
0005432747639	12041	Economy	14800.00
0005432747802	12041	Economy	14800.00
0005432747657	12041	Economy	14800.00
0005432756852	12041	Economy	14800.00
0005432747669	12041	Economy	14800.00
0005432747653	12041	Economy	14800.00
0005432753318	12041	Economy	14800.00
0005432753301	12041	Economy	14800.00
0005432747661	12041	Economy	14800.00
0005432747764	12041	Economy	14800.00
0005432891267	12041	Economy	14800.00
0005433293322	12041	Economy	14800.00
0005432747815	12041	Economy	14800.00
0005432747604	12041	Economy	14800.00
0005432749801	12041	Economy	14800.00
0005432747603	12041	Economy	14800.00
0005432747668	12041	Economy	14800.00
0005433525163	18971	Economy	28200.00
0005433525160	18971	Economy	25700.00
0005433525162	18971	Economy	25700.00
0005433525158	18971	Economy	25700.00
0005432928003	18971	Economy	25700.00
0005433525161	18971	Economy	25700.00
0005433533350	18971	Economy	25700.00
0005433525159	18971	Economy	25700.00
0005433531337	18971	Economy	25700.00
0005433533351	18971	Economy	25700.00
0005433533352	18971	Economy	25700.00
0005433525167	18971	Economy	25700.00
0005432928001	18971	Economy	25700.00
0005433525168	18971	Economy	25700.00
0005433533349	18971	Economy	25700.00
0005433533353	18971	Economy	25700.00
0005433531336	18971	Economy	25700.00
0005433525166	18971	Economy	25700.00
0005433525164	18971	Economy	25700.00
0005433525165	18971	Economy	25700.00
0005433531292	32486	Economy	28200.00
0005433525067	32486	Economy	28200.00
0005433531308	32486	Economy	28200.00
0005433525078	32486	Economy	25700.00
0005432928052	32486	Economy	25700.00
0005433527261	32486	Economy	25700.00
0005433525080	32486	Economy	25700.00
0005432928055	32486	Economy	25700.00
0005433525057	32486	Economy	25700.00
0005433531306	32486	Economy	25700.00
0005432928056	32486	Economy	25700.00
0005433525108	32486	Economy	25700.00
0005433525130	32486	Economy	25700.00
0005433525077	32486	Economy	25700.00
0005433525079	32486	Economy	25700.00
0005433531304	32486	Economy	25700.00
0005432928054	32486	Economy	25700.00
0005433527262	32486	Economy	25700.00
0005432928053	32486	Economy	25700.00
0005433525081	32486	Economy	25700.00
0005433525071	32486	Economy	25700.00
0005433525109	32486	Economy	25700.00
0005433525062	32486	Economy	25700.00
0005433525063	32486	Economy	25700.00
0005433525087	32486	Economy	25700.00
0005433525066	32486	Economy	25700.00
0005434664987	5272	Business	84000.00
0005434825094	5272	Business	84000.00
0005432121509	5272	Business	84000.00
0005435304192	5272	Business	84000.00
0005435373684	5272	Business	84000.00
0005435373317	5272	Business	84000.00
0005435373274	5272	Business	84000.00
0005434825146	5272	Business	84000.00
0005435373330	5272	Business	84000.00
0005435373331	5272	Business	84000.00
0005435373605	5272	Business	84000.00
0005434825156	5272	Business	84000.00
0005434558377	5272	Business	84000.00
0005434825154	5272	Business	84000.00
0005435373571	5272	Business	84000.00
0005434825110	5272	Business	84000.00
0005435661933	5272	Business	84000.00
0005435150195	5272	Business	84000.00
0005434558379	5272	Business	84000.00
0005435150196	5272	Business	84000.00
0005434825129	5272	Business	84000.00
0005432121514	5272	Business	84000.00
0005432394154	5272	Business	84000.00
0005435373273	5272	Business	84000.00
0005434825091	5272	Business	84000.00
0005435373828	5272	Business	84000.00
0005434825140	5272	Comfort	47600.00
0005434825158	5272	Business	84000.00
0005434825134	5272	Comfort	47600.00
0005434825126	5272	Comfort	47600.00
0005434558382	5272	Comfort	47600.00
0005434825084	5272	Comfort	47600.00
0005435661939	5272	Comfort	47600.00
0005434825103	5272	Comfort	47600.00
0005434825090	5272	Comfort	47600.00
0005434825160	5272	Comfort	47600.00
0005434825171	5272	Comfort	47600.00
0005432394153	5272	Comfort	47600.00
0005434825163	5272	Comfort	47600.00
0005435373412	5272	Comfort	47600.00
0005434825118	5272	Comfort	47600.00
0005435373371	5272	Comfort	47600.00
0005434825120	5272	Comfort	47600.00
0005434831203	5272	Comfort	47600.00
0005434825170	5272	Comfort	47600.00
0005435373322	5272	Comfort	47600.00
0005435373343	5272	Comfort	47600.00
0005435373452	5272	Comfort	47600.00
0005434825099	5272	Comfort	47600.00
0005435373062	5272	Comfort	47600.00
0005435373570	5272	Comfort	47600.00
0005434825142	5272	Comfort	47600.00
0005435373443	5272	Comfort	47600.00
0005434825176	5272	Comfort	47600.00
0005435373496	5272	Comfort	47600.00
0005434825196	5272	Comfort	47600.00
0005435150206	5272	Comfort	47600.00
0005434825089	5272	Comfort	47600.00
0005432121513	5272	Comfort	47600.00
0005435178992	5272	Comfort	47600.00
0005435661936	5272	Comfort	47600.00
0005434825161	5272	Comfort	47600.00
0005434825165	5272	Comfort	47600.00
0005434825181	5272	Comfort	47600.00
0005435735149	5272	Comfort	47600.00
0005434825179	5272	Comfort	47600.00
0005435373776	5272	Economy	28000.00
0005434825204	5272	Comfort	47600.00
0005434825187	5272	Economy	28000.00
0005432121511	5272	Economy	28000.00
0005432121512	5272	Economy	28000.00
0005434825138	5272	Economy	28000.00
0005435373321	5272	Economy	28000.00
0005434828728	5272	Economy	28000.00
0005434825184	5272	Economy	28000.00
0005435373614	5272	Economy	28000.00
0005435373683	5272	Economy	28000.00
0005434825175	5272	Economy	28000.00
0005435373453	5272	Economy	28000.00
0005434825169	5272	Economy	28000.00
0005435373231	5272	Economy	28000.00
0005435373209	5272	Economy	28000.00
0005434825132	5272	Economy	28000.00
0005434825106	5272	Economy	28000.00
0005435373572	5272	Economy	28000.00
0005435735148	5272	Economy	28000.00
0005435373739	5272	Economy	28000.00
0005434825141	5272	Economy	28000.00
0005435373366	5272	Economy	28000.00
0005435386617	5272	Economy	28000.00
0005435373827	5272	Economy	28000.00
0005434825079	5272	Economy	28000.00
0005434825147	5272	Economy	28000.00
0005434825124	5272	Economy	28000.00
0005435373446	5272	Economy	28000.00
0005434558380	5272	Economy	28000.00
0005434825195	5272	Economy	28000.00
0005434825201	5272	Economy	28000.00
0005434825143	5272	Economy	28000.00
0005435373740	5272	Economy	28000.00
0005434825136	5272	Economy	28000.00
0005434825101	5272	Economy	28000.00
0005434825151	5272	Economy	28000.00
0005434558381	5272	Economy	28000.00
0005434828730	5272	Economy	28000.00
0005434825180	5272	Economy	28000.00
0005434825200	5272	Economy	28000.00
0005435373442	5272	Economy	28000.00
0005434825135	5272	Economy	28000.00
0005434825153	5272	Economy	28000.00
0005435150194	5272	Economy	28000.00
0005434831206	5272	Economy	28000.00
0005435735152	5272	Economy	28000.00
0005434825137	5272	Economy	28000.00
0005432121504	5272	Economy	30800.00
0005435150205	5272	Economy	28000.00
0005434825082	5272	Economy	30800.00
0005435373367	5272	Economy	28000.00
0005434825085	5272	Economy	30800.00
0005435373455	5272	Economy	28000.00
0005434825206	5272	Economy	28000.00
0005435373242	5272	Economy	28000.00
0005434825199	5272	Economy	30800.00
0005434825166	5272	Economy	30800.00
0005432396293	5272	Economy	30800.00
0005432823460	5272	Economy	28000.00
0005434825150	5272	Economy	28000.00
0005435373508	5272	Economy	28000.00
0005435373613	5272	Economy	28000.00
0005434825202	5272	Economy	28000.00
0005435150197	5272	Economy	28000.00
0005435373736	5272	Economy	28000.00
0005434825189	5272	Economy	28000.00
0005434825119	5272	Economy	28000.00
0005434825188	5272	Economy	28000.00
0005432121510	5272	Economy	28000.00
0005435304169	5272	Economy	28000.00
0005434825092	5272	Economy	28000.00
0005434825128	5272	Economy	28000.00
0005434825152	5272	Economy	28000.00
0005435386621	5272	Economy	28000.00
0005434825191	5272	Economy	28000.00
0005435373663	5272	Economy	28000.00
0005434825190	5272	Economy	28000.00
0005435735140	5272	Economy	28000.00
0005434825111	5272	Economy	28000.00
0005435150203	5272	Economy	28000.00
0005434825167	5272	Economy	28000.00
0005435661937	5272	Economy	28000.00
0005432394155	5272	Economy	28000.00
0005434828729	5272	Economy	28000.00
0005435373553	5272	Economy	28000.00
0005434825081	5272	Economy	28000.00
0005434825104	5272	Economy	28000.00
0005435150199	5272	Economy	28000.00
0005434825186	5272	Economy	28000.00
0005435373599	5272	Economy	28000.00
0005435373615	5272	Economy	28000.00
0005434825087	5272	Economy	28000.00
0005434825149	5272	Economy	28000.00
0005434825193	5272	Economy	28000.00
0005434825172	5272	Economy	28000.00
0005432121502	5272	Economy	28000.00
0005434825108	5272	Economy	28000.00
0005435373421	5272	Economy	28000.00
0005435373445	5272	Economy	28000.00
0005434825083	5272	Economy	28000.00
0005435179694	5272	Economy	28000.00
0005435304194	5272	Economy	28000.00
0005432823459	5272	Economy	28000.00
0005434825116	5272	Economy	28000.00
0005435661932	5272	Economy	28000.00
0005435150202	5272	Economy	28000.00
0005434825115	5272	Economy	28000.00
0005434825162	5272	Economy	28000.00
0005434831204	5272	Economy	28000.00
0005432121506	5272	Economy	28000.00
0005435735137	5272	Economy	28000.00
0005434825122	5272	Economy	28000.00
0005434825100	5272	Economy	28000.00
0005435304187	5272	Economy	28000.00
0005434825131	5272	Economy	28000.00
0005435373583	5272	Economy	28000.00
0005434825113	5272	Economy	28000.00
0005434831205	5272	Economy	28000.00
0005434825198	5272	Economy	28000.00
0005435373422	5272	Economy	28000.00
0005435373509	5272	Economy	28000.00
0005434825102	5272	Economy	28000.00
0005435373569	5272	Economy	28000.00
0005435304168	5272	Economy	28000.00
0005432121508	5272	Economy	28000.00
0005434825173	5272	Economy	28000.00
0005434825127	5272	Economy	28000.00
0005435150204	5272	Economy	28000.00
0005432121505	5272	Economy	28000.00
0005435304181	5272	Economy	28000.00
0005434558383	5272	Economy	28000.00
0005435373515	5272	Economy	28000.00
0005434825114	5272	Economy	28000.00
0005435373591	5272	Economy	28000.00
0005434825139	5272	Economy	28000.00
0005434825077	5272	Economy	28000.00
0005434825159	5272	Economy	30800.00
0005434825098	5272	Economy	30800.00
0005435373624	5272	Economy	30800.00
0005435386580	5272	Economy	30800.00
0005435661940	5272	Economy	30800.00
0005435150200	5272	Economy	28000.00
0005435373413	5272	Economy	28000.00
0005434558378	5272	Economy	28000.00
0005435373691	5272	Economy	28000.00
0005435661934	5272	Economy	28000.00
0005434825133	5272	Economy	28000.00
0005435373439	5272	Economy	28000.00
0005435150201	5272	Economy	28000.00
0005434825123	5272	Economy	28000.00
0005435373811	5272	Economy	28000.00
0005434825117	5272	Economy	28000.00
0005434558376	5272	Economy	28000.00
0005435179695	5272	Economy	28000.00
0005434825097	5272	Economy	28000.00
0005432396294	5272	Economy	28000.00
0005434825178	5272	Economy	28000.00
0005435373370	5272	Economy	28000.00
0005435386604	5272	Economy	28000.00
0005434825205	5272	Economy	28000.00
0005434825078	5272	Economy	28000.00
0005434825121	5272	Economy	28000.00
0005434825183	5272	Economy	28000.00
0005435304195	5272	Economy	28000.00
0005434664988	5272	Economy	28000.00
0005435386603	5272	Economy	28000.00
0005435373584	5272	Economy	28000.00
0005434825096	5272	Economy	28000.00
0005434825088	5272	Economy	28000.00
0005435735150	5272	Economy	28000.00
0005434825157	5272	Economy	28000.00
0005434825144	5272	Economy	28000.00
0005432121507	5272	Economy	28000.00
0005435373243	5272	Economy	28000.00
0005434825093	5272	Economy	28000.00
0005435299801	5272	Economy	28000.00
0005435150193	5272	Economy	28000.00
0005434825086	5272	Economy	28000.00
0005434825168	5272	Economy	28000.00
0005435150198	5272	Economy	28000.00
0005434825105	5272	Economy	28000.00
0005435373604	5272	Economy	28000.00
0005434825174	5272	Economy	28000.00
0005434825177	5272	Economy	28000.00
0005434825164	5272	Economy	28000.00
0005435373588	5272	Economy	28000.00
0005435373590	5272	Economy	28000.00
0005434825125	5272	Economy	28000.00
0005434825185	5272	Economy	28000.00
0005435373471	5272	Economy	28000.00
0005435661931	5272	Economy	28000.00
0005434825203	5272	Economy	28000.00
0005435373337	5272	Economy	28000.00
0005434825182	5272	Economy	28000.00
0005435299777	5272	Economy	28000.00
0005435735139	5272	Economy	28000.00
0005435373318	5272	Economy	28000.00
0005435373210	5272	Economy	28000.00
0005434825109	5272	Economy	28000.00
0005434825148	5272	Economy	28000.00
0005434825145	5272	Economy	28000.00
0005434825130	5272	Economy	28000.00
0005435373589	5272	Economy	28000.00
0005434825192	5272	Economy	28000.00
0005435178997	5272	Economy	28000.00
0005434825112	5272	Economy	28000.00
0005434825107	5272	Economy	28000.00
0005435373777	5272	Economy	28000.00
0005434825080	5272	Economy	28000.00
0005434825194	5272	Economy	28000.00
0005435373669	5272	Economy	28000.00
0005434825095	5272	Economy	28000.00
0005434825155	5272	Economy	28000.00
0005435386602	5272	Economy	28000.00
0005432121503	5272	Economy	28000.00
0005435373592	5272	Economy	28000.00
0005435373829	5272	Economy	28000.00
0005434825197	5272	Economy	28000.00
0005434823450	9933	Business	84000.00
0005434824266	9933	Business	84000.00
0005434824604	9933	Business	84000.00
0005434823999	9933	Business	84000.00
0005434823956	9933	Business	84000.00
0005434824048	9933	Business	84000.00
0005434823974	9933	Business	84000.00
0005434824603	9933	Business	84000.00
0005435374077	9933	Business	84000.00
0005434664967	9933	Business	84000.00
0005432203154	9933	Business	84000.00
0005435150070	9933	Business	84000.00
0005435374063	9933	Business	84000.00
0005434823944	9933	Business	84000.00
0005434823553	9933	Business	84000.00
0005435374064	9933	Business	84000.00
0005435661968	9933	Business	84000.00
0005434831160	9933	Business	84000.00
0005434824133	9933	Business	84000.00
0005432203151	9933	Business	84000.00
0005434831180	9933	Business	84000.00
0005435374067	9933	Comfort	47600.00
0005434831165	9933	Comfort	47600.00
0005435374031	9933	Comfort	47600.00
0005434558281	9933	Comfort	47600.00
0005434824458	9933	Comfort	47600.00
0005434823642	9933	Comfort	47600.00
0005434558284	9933	Comfort	47600.00
0005435150077	9933	Comfort	47600.00
0005432203156	9933	Comfort	47600.00
0005435374078	9933	Comfort	47600.00
0005434823994	9933	Comfort	47600.00
0005435150032	9933	Comfort	47600.00
0005434824150	9933	Comfort	47600.00
0005435150073	9933	Comfort	47600.00
0005434824140	9933	Comfort	47600.00
0005435179405	9933	Comfort	47600.00
0005435374057	9933	Comfort	47600.00
0005434824503	9933	Comfort	47600.00
0005434824281	9933	Comfort	47600.00
0005435374065	9933	Comfort	47600.00
0005434558280	9933	Comfort	47600.00
0005435374090	9933	Comfort	47600.00
0005434824477	9933	Comfort	47600.00
0005435374051	9933	Comfort	47600.00
0005434823939	9933	Comfort	47600.00
0005434823692	9933	Comfort	47600.00
0005435374085	9933	Comfort	47600.00
0005434824305	9933	Comfort	47600.00
0005434823954	9933	Comfort	47600.00
0005435374081	9933	Comfort	47600.00
0005435374050	9933	Comfort	47600.00
0005435374034	9933	Comfort	47600.00
0005434823413	9933	Comfort	47600.00
0005434824195	9933	Comfort	47600.00
0005435302258	9933	Comfort	47600.00
0005432396269	9933	Economy	28000.00
0005434824000	9933	Economy	28000.00
0005434823520	9933	Economy	28000.00
0005434823656	9933	Economy	28000.00
0005434823938	9933	Economy	28000.00
0005435374044	9933	Economy	28000.00
0005434823973	9933	Economy	28000.00
0005434823693	9933	Economy	28000.00
0005434824261	9933	Economy	28000.00
0005434824124	9933	Economy	28000.00
0005435150068	9933	Economy	28000.00
0005435374095	9933	Economy	28000.00
0005435374091	9933	Economy	28000.00
0005435374069	9933	Economy	28000.00
0005432203150	9933	Economy	28000.00
0005434824324	9933	Economy	28000.00
0005434824469	9933	Economy	28000.00
0005435150020	9933	Economy	28000.00
0005434824206	9933	Economy	28000.00
0005435150071	9933	Economy	28000.00
0005434824522	9933	Economy	28000.00
0005435374043	9933	Economy	28000.00
0005434824039	9933	Economy	28000.00
0005434824134	9933	Economy	28000.00
0005435374038	9933	Economy	28000.00
0005434824042	9933	Economy	28000.00
0005434824186	9933	Economy	28000.00
0005434558301	9933	Economy	28000.00
0005434664970	9933	Economy	28000.00
0005434824076	9933	Economy	28000.00
0005434823945	9933	Economy	28000.00
0005435374086	9933	Economy	28000.00
0005435374046	9933	Economy	28000.00
0005432203153	9933	Economy	28000.00
0005432400142	9933	Economy	28000.00
0005435374074	9933	Economy	28000.00
0005435374083	9933	Economy	28000.00
0005435374030	9933	Economy	28000.00
0005435374068	9933	Economy	28000.00
0005435735195	9933	Economy	28000.00
0005435374048	9933	Economy	28000.00
0005435374096	9933	Economy	28000.00
0005435150062	9933	Economy	28000.00
0005435299833	9933	Economy	28000.00
0005435150049	9933	Economy	28000.00
0005434824319	9933	Economy	28000.00
0005434824072	9933	Economy	30800.00
0005434824425	9933	Economy	30800.00
0005435374053	9933	Economy	28000.00
0005434823725	9933	Economy	28000.00
0005434824078	9933	Economy	28000.00
0005435374082	9933	Economy	28000.00
0005435299834	9933	Economy	28000.00
0005434831181	9933	Economy	28000.00
0005434823975	9933	Economy	28000.00
0005435150078	9933	Economy	28000.00
0005435299835	9933	Economy	28000.00
0005435374075	9933	Economy	28000.00
0005434823873	9933	Economy	28000.00
0005435150029	9933	Economy	28000.00
0005435150069	9933	Economy	28000.00
0005432396270	9933	Economy	28000.00
0005434824147	9933	Economy	28000.00
0005434558285	9933	Economy	28000.00
0005434558279	9933	Economy	28000.00
0005435374045	9933	Economy	28000.00
0005435374071	9933	Economy	28000.00
0005434824229	9933	Economy	28000.00
0005435302257	9933	Economy	28000.00
0005435150046	9933	Economy	28000.00
0005434823812	9933	Economy	28000.00
0005434823937	9933	Economy	28000.00
0005434824209	9933	Economy	28000.00
0005434824426	9933	Economy	28000.00
0005434664969	9933	Economy	28000.00
0005434824304	9933	Economy	28000.00
0005435302254	9933	Economy	28000.00
0005434824370	9933	Economy	28000.00
0005435374080	9933	Economy	28000.00
0005434824325	9933	Economy	28000.00
0005434824662	9933	Economy	28000.00
0005435374042	9933	Economy	28000.00
0005435374076	9933	Economy	28000.00
0005434824254	9933	Economy	28000.00
0005435735193	9933	Economy	28000.00
0005434823955	9933	Economy	28000.00
0005434823836	9933	Economy	28000.00
0005434824071	9933	Economy	28000.00
0005434823953	9933	Economy	28000.00
0005435374094	9933	Economy	28000.00
0005435374036	9933	Economy	28000.00
0005435299836	9933	Economy	28000.00
0005434664968	9933	Economy	28000.00
0005434831182	9933	Economy	28000.00
0005435735197	9933	Economy	28000.00
0005434824332	9933	Economy	28000.00
0005434823752	9933	Economy	28000.00
0005435661969	9933	Economy	28000.00
0005435374073	9933	Economy	28000.00
0005434823720	9933	Economy	28000.00
0005432203149	9933	Economy	28000.00
0005434824118	9933	Economy	28000.00
0005435374079	9933	Economy	28000.00
0005434823554	9933	Economy	28000.00
0005435150072	9933	Economy	28000.00
0005435302255	9933	Economy	28000.00
0005434824262	9933	Economy	28000.00
0005435150052	9933	Economy	28000.00
0005435150074	9933	Economy	28000.00
0005435150085	9933	Economy	28000.00
0005435374039	9933	Economy	28000.00
0005434823880	9933	Economy	28000.00
0005434823991	9933	Economy	28000.00
0005434823909	9933	Economy	28000.00
0005434823372	9933	Economy	28000.00
0005434824038	9933	Economy	28000.00
0005434824125	9933	Economy	28000.00
0005435374084	9933	Economy	28000.00
0005434824523	9933	Economy	28000.00
0005435150048	9933	Economy	28000.00
0005434824109	9933	Economy	28000.00
0005434824247	9933	Economy	28000.00
0005435374047	9933	Economy	28000.00
0005434823691	9933	Economy	28000.00
0005434823796	9933	Economy	28000.00
0005434824500	9933	Economy	30800.00
0005434828701	9933	Economy	30800.00
0005434824168	9933	Economy	30800.00
0005432203155	9933	Economy	30800.00
0005434558302	9933	Economy	30800.00
0005435661966	9933	Economy	28000.00
0005434823989	9933	Economy	28000.00
0005434823811	9933	Economy	28000.00
0005435735194	9933	Economy	28000.00
0005434824028	9933	Economy	28000.00
0005432823475	9933	Economy	28000.00
0005435374052	9933	Economy	28000.00
0005434824228	9933	Economy	28000.00
0005435374040	9933	Economy	28000.00
0005434823904	9933	Economy	28000.00
0005434824557	9933	Economy	28000.00
0005434824282	9933	Economy	28000.00
0005434824208	9933	Economy	28000.00
0005434823414	9933	Economy	28000.00
0005434831164	9933	Economy	28000.00
0005435735196	9933	Economy	28000.00
0005435150061	9933	Economy	28000.00
0005435374059	9933	Economy	28000.00
0005434824369	9933	Economy	28000.00
0005434824196	9933	Economy	28000.00
0005432823474	9933	Economy	28000.00
0005432203152	9933	Economy	28000.00
0005434824392	9933	Economy	28000.00
0005435374037	9933	Economy	28000.00
0005434824162	9933	Economy	28000.00
0005434823326	9933	Economy	28000.00
0005435374092	9933	Economy	28000.00
0005435374072	9933	Economy	28000.00
0005435374066	9933	Economy	28000.00
0005434823906	9933	Economy	28000.00
0005435374032	9933	Economy	28000.00
0005435374049	9933	Economy	28000.00
0005434824129	9933	Economy	28000.00
0005435374058	9933	Economy	28000.00
0005434824329	9933	Economy	28000.00
0005434823688	9933	Economy	28000.00
0005435374093	9933	Economy	28000.00
0005434823995	9933	Economy	28000.00
0005434823732	9933	Economy	28000.00
0005435374097	9933	Economy	28000.00
0005432396249	9933	Economy	28000.00
0005434824320	9933	Economy	28000.00
0005434823951	9933	Economy	28000.00
0005434558283	9933	Economy	28000.00
0005434824246	9933	Economy	28000.00
0005435374041	9933	Economy	28000.00
0005434824130	9933	Economy	28000.00
0005434824207	9933	Economy	28000.00
0005435374033	9933	Economy	28000.00
0005435374087	9933	Economy	28000.00
0005435150065	9933	Economy	28000.00
0005435374089	9933	Economy	28000.00
0005435150021	9933	Economy	28000.00
0005434823903	9933	Economy	28000.00
0005432396246	9933	Economy	28000.00
0005435302256	9933	Economy	28000.00
0005435374035	9933	Economy	28000.00
0005434824602	9933	Economy	28000.00
0005435299832	9933	Economy	28000.00
0005435150045	9933	Economy	28000.00
0005435661967	9933	Economy	28000.00
0005435374088	9933	Economy	28000.00
0005435374070	9933	Economy	28000.00
0005432400137	9933	Economy	28000.00
0005435374055	9933	Economy	28000.00
0005434824457	9933	Economy	28000.00
0005434824077	9933	Economy	28000.00
0005435374060	9933	Economy	28000.00
0005435374062	9933	Economy	28000.00
0005435150031	9933	Economy	28000.00
0005435374029	9933	Economy	28000.00
0005435374061	9933	Economy	28000.00
0005435374056	9933	Economy	28000.00
0005434823559	9933	Economy	28000.00
0005435374054	9933	Economy	28000.00
0005434823795	9933	Economy	28000.00
0005435082889	6981	Economy	8200.00
0005435082886	6981	Economy	8200.00
0005435082890	6981	Economy	7400.00
0005435790342	6981	Economy	7400.00
0005435082891	6981	Economy	7400.00
0005435082888	6981	Economy	7400.00
0005435082887	6981	Economy	7400.00
0005435082883	6981	Economy	7400.00
0005435082884	6981	Economy	7400.00
0005435082882	6981	Economy	7400.00
0005435082885	6981	Economy	7400.00
0005435790341	6981	Economy	7400.00
0005435790343	6981	Economy	7400.00
0005435082787	25994	Economy	8200.00
0005435082819	25994	Economy	7400.00
0005435082836	25994	Economy	7400.00
0005435082838	25994	Economy	7400.00
0005435082810	25994	Economy	7400.00
0005435082837	25994	Economy	7400.00
0005435082818	25994	Economy	7400.00
0005435082794	25994	Economy	7400.00
0005434214613	9555	Business	32800.00
0005434756958	9555	Business	32800.00
0005434756946	9555	Business	32800.00
0005434214629	9555	Business	32800.00
0005434214682	9555	Business	32800.00
0005434214671	9555	Business	32800.00
0005434756943	9555	Business	32800.00
0005434214559	9555	Business	32800.00
0005434214718	9555	Business	32800.00
0005434756951	9555	Business	32800.00
0005434214621	9555	Business	32800.00
0005434214698	9555	Economy	10900.00
0005434756953	9555	Economy	10900.00
0005434756948	9555	Economy	10900.00
0005434214622	9555	Economy	10900.00
0005434214721	9555	Economy	10900.00
0005434214449	9555	Economy	10900.00
0005434214448	9555	Economy	10900.00
0005434214722	9555	Economy	10900.00
0005434756960	9555	Economy	12000.00
0005434214560	9555	Economy	12000.00
0005434756954	9555	Economy	12000.00
0005434214810	9555	Economy	12000.00
0005434214661	9555	Economy	12000.00
0005434756939	9555	Economy	10900.00
0005434756964	9555	Economy	10900.00
0005434756930	9555	Economy	10900.00
0005434214737	9555	Economy	10900.00
0005434214553	9555	Economy	10900.00
0005434214414	9555	Economy	10900.00
0005434214838	9555	Economy	10900.00
0005434214596	9555	Economy	10900.00
0005434214534	9555	Economy	10900.00
0005434214668	9555	Economy	10900.00
0005434214597	9555	Economy	10900.00
0005434214646	9555	Economy	10900.00
0005434214793	9555	Economy	10900.00
0005434756932	9555	Economy	10900.00
0005434756940	9555	Economy	10900.00
0005434756931	9555	Economy	10900.00
0005434214809	9555	Economy	10900.00
0005434214669	9555	Economy	10900.00
0005434756962	9555	Economy	10900.00
0005434214586	9555	Economy	10900.00
0005434756942	9555	Economy	10900.00
0005434214650	9555	Economy	10900.00
0005434756952	9555	Economy	10900.00
0005434756936	9555	Economy	10900.00
0005434756955	9555	Economy	10900.00
0005434214706	9555	Economy	10900.00
0005434214610	9555	Economy	10900.00
0005434214513	9555	Economy	10900.00
0005434756941	9555	Economy	10900.00
0005434214588	9555	Economy	10900.00
0005434756933	9555	Economy	10900.00
0005434756956	9555	Economy	10900.00
0005434756944	9555	Economy	10900.00
0005434756947	9555	Economy	10900.00
0005434214519	9555	Economy	10900.00
0005434756937	9555	Economy	10900.00
0005434756959	9555	Economy	10900.00
0005434214609	9555	Economy	10900.00
0005434214628	9555	Economy	10900.00
0005434214886	9555	Economy	10900.00
0005434214887	9555	Economy	10900.00
0005434214699	9555	Economy	10900.00
0005434214552	9555	Economy	10900.00
0005434214587	9555	Economy	10900.00
0005434214413	9555	Economy	10900.00
0005434214811	9555	Economy	10900.00
0005434214592	9555	Economy	10900.00
0005434214419	9555	Economy	10900.00
0005434214487	9555	Economy	10900.00
0005434214740	9555	Economy	10900.00
0005434756938	9555	Economy	10900.00
0005434756945	9555	Economy	10900.00
0005434214528	9555	Economy	10900.00
0005434214504	9555	Economy	10900.00
0005434756950	9555	Economy	10900.00
0005434756963	9555	Economy	10900.00
0005434214681	9555	Economy	10900.00
0005434756935	9555	Economy	10900.00
0005434756934	9555	Economy	10900.00
0005434756961	9555	Economy	10900.00
0005434756928	9555	Economy	10900.00
0005434756957	9555	Economy	10900.00
0005434214593	9555	Economy	10900.00
0005434214514	9555	Economy	10900.00
0005434756949	9555	Economy	10900.00
0005434756929	9555	Economy	10900.00
0005434756550	28590	Business	32800.00
0005434215044	28590	Business	32800.00
0005434215035	28590	Business	32800.00
0005434756549	28590	Business	32800.00
0005434756449	28590	Business	32800.00
0005434756466	28590	Business	32800.00
0005434215057	28590	Business	32800.00
0005434756494	28590	Business	32800.00
0005434215040	28590	Business	32800.00
0005434756555	28590	Business	32800.00
0005434215048	28590	Business	32800.00
0005434756484	28590	Business	32800.00
0005434756504	28590	Economy	10900.00
0005434756451	28590	Economy	10900.00
0005434215069	28590	Economy	10900.00
0005434756432	28590	Economy	10900.00
0005434215062	28590	Economy	10900.00
0005434756520	28590	Economy	10900.00
0005434756482	28590	Economy	10900.00
0005434756389	28590	Economy	10900.00
0005434756431	28590	Economy	10900.00
0005434756441	28590	Economy	10900.00
0005434756413	28590	Economy	12000.00
0005434215053	28590	Economy	12000.00
0005434756452	28590	Economy	12000.00
0005434215068	28590	Economy	12000.00
0005434215066	28590	Economy	12000.00
0005434215036	28590	Economy	10900.00
0005434215061	28590	Economy	10900.00
0005434215075	28590	Economy	10900.00
0005434215065	28590	Economy	10900.00
0005434756444	28590	Economy	10900.00
0005434756477	28590	Economy	10900.00
0005434756498	28590	Economy	10900.00
0005434756390	28590	Economy	10900.00
0005434756445	28590	Economy	10900.00
0005434756462	28590	Economy	10900.00
0005434215045	28590	Economy	10900.00
0005434756516	28590	Economy	10900.00
0005434756242	28590	Economy	10900.00
0005434756483	28590	Economy	10900.00
0005434215041	28590	Economy	10900.00
0005434215077	28590	Economy	10900.00
0005434215042	28590	Economy	10900.00
0005434756492	28590	Economy	10900.00
0005434215047	28590	Economy	10900.00
0005434756463	28590	Economy	10900.00
0005434215059	28590	Economy	10900.00
0005434215043	28590	Economy	10900.00
0005434756450	28590	Economy	10900.00
0005434215038	28590	Economy	10900.00
0005434215056	28590	Economy	10900.00
0005434215031	28590	Economy	10900.00
0005434215049	28590	Economy	10900.00
0005434215064	28590	Economy	10900.00
0005434756415	28590	Economy	10900.00
0005434215039	28590	Economy	10900.00
0005434756553	28590	Economy	10900.00
0005434756465	28590	Economy	10900.00
0005434756554	28590	Economy	10900.00
0005434215073	28590	Economy	10900.00
0005434215058	28590	Economy	10900.00
0005434756502	28590	Economy	10900.00
0005434756503	28590	Economy	10900.00
0005434215067	28590	Economy	10900.00
0005434756366	28590	Economy	10900.00
0005434756443	28590	Economy	10900.00
0005434756581	28590	Economy	10900.00
0005434756556	28590	Economy	10900.00
0005434215063	28590	Economy	10900.00
0005434215037	28590	Economy	10900.00
0005434756384	28590	Economy	10900.00
0005434215052	28590	Economy	10900.00
0005434756515	28590	Economy	10900.00
0005434215074	28590	Economy	10900.00
0005434215054	28590	Economy	10900.00
0005434756440	28590	Economy	10900.00
0005434215076	28590	Economy	10900.00
0005434215055	28590	Economy	10900.00
0005434215046	28590	Economy	10900.00
0005434215033	28590	Economy	10900.00
0005434215032	28590	Economy	10900.00
0005434215071	28590	Economy	10900.00
0005434756493	28590	Economy	10900.00
0005434215051	28590	Economy	10900.00
0005434215050	28590	Economy	10900.00
0005434215072	28590	Economy	10900.00
0005434756560	28590	Economy	10900.00
0005434756539	28590	Economy	10900.00
0005434756517	28590	Economy	10900.00
0005434215060	28590	Economy	10900.00
0005434215030	28590	Economy	10900.00
0005434756521	28590	Economy	10900.00
0005434215034	28590	Economy	10900.00
0005434215070	28590	Economy	10900.00
0005435100160	10834	Economy	9800.00
0005435100161	10834	Economy	8900.00
0005435100159	10834	Economy	8900.00
0005435100158	10834	Economy	8900.00
0005434760200	10834	Economy	8900.00
0005434760201	10834	Economy	8900.00
0005435100129	31823	Economy	8900.00
0005434760226	31823	Economy	8900.00
0005435100136	31823	Economy	8900.00
0005434760228	31823	Economy	8900.00
0005434760227	31823	Economy	8900.00
0005435100137	31823	Economy	8900.00
0005434639639	1978	Economy	20900.00
0005434639641	1978	Economy	20900.00
0005432290673	1978	Economy	20900.00
0005434639643	1978	Economy	20900.00
0005433202430	1978	Economy	19000.00
0005434639635	1978	Economy	19000.00
0005434639648	1978	Economy	19000.00
0005434639653	1978	Economy	19000.00
0005434639644	1978	Economy	19000.00
0005434639629	1978	Economy	19000.00
0005433202404	1978	Economy	19000.00
0005432290671	1978	Economy	19000.00
0005433202459	1978	Economy	19000.00
0005434639630	1978	Economy	19000.00
0005434639651	1978	Economy	19000.00
0005433202403	1978	Economy	19000.00
0005434639628	1978	Economy	19000.00
0005433202429	1978	Economy	19000.00
0005433202410	1978	Economy	19000.00
0005434639627	1978	Economy	19000.00
0005433202415	1978	Economy	19000.00
0005433202354	1978	Economy	19000.00
0005433202412	1978	Economy	19000.00
0005434639631	1978	Economy	19000.00
0005433202414	1978	Economy	19000.00
0005433202399	1978	Economy	19000.00
0005434639640	1978	Economy	19000.00
0005434639652	1978	Economy	19000.00
0005432290670	1978	Economy	19000.00
0005434639634	1978	Economy	19000.00
0005434639636	1978	Economy	19000.00
0005434639632	1978	Economy	19000.00
0005433202411	1978	Economy	19000.00
0005434639637	1978	Economy	19000.00
0005434639647	1978	Economy	19000.00
0005432290672	1978	Economy	19000.00
0005434639646	1978	Economy	19000.00
0005434639633	1978	Economy	19000.00
0005433202458	1978	Economy	19000.00
0005434639650	1978	Economy	19000.00
0005434639642	1978	Economy	19000.00
0005434639649	1978	Economy	19000.00
0005434639645	1978	Economy	19000.00
0005434639638	1978	Economy	19000.00
0005434639654	1978	Economy	19000.00
0005433202400	1978	Economy	19000.00
0005434639469	23262	Economy	20900.00
0005433202526	23262	Economy	20900.00
0005433202530	23262	Economy	19000.00
0005434639292	23262	Economy	19000.00
0005434639363	23262	Economy	19000.00
0005434639362	23262	Economy	19000.00
0005433202532	23262	Economy	19000.00
0005434639273	23262	Economy	19000.00
0005433202527	23262	Economy	19000.00
0005433202536	23262	Economy	19000.00
0005434639444	23262	Economy	19000.00
0005434639374	23262	Economy	19000.00
0005434639467	23262	Economy	19000.00
0005435948329	23262	Economy	19000.00
0005434639343	23262	Economy	19000.00
0005433202528	23262	Economy	19000.00
0005434639468	23262	Economy	19000.00
0005433202525	23262	Economy	19000.00
0005434639297	23262	Economy	19000.00
0005434639445	23262	Economy	19000.00
0005434639402	23262	Economy	19000.00
0005434639429	23262	Economy	19000.00
0005434639293	23262	Economy	19000.00
0005434639351	23262	Economy	19000.00
0005434639486	23262	Economy	19000.00
0005434639373	23262	Economy	19000.00
0005434639437	23262	Economy	19000.00
0005434639438	23262	Economy	19000.00
0005434639470	23262	Economy	19000.00
0005433202524	23262	Economy	19000.00
0005434639341	23262	Economy	19000.00
0005434639491	23262	Economy	19000.00
0005433202535	23262	Economy	19000.00
0005434639403	23262	Economy	19000.00
0005434639404	23262	Economy	19000.00
0005433202533	23262	Economy	19000.00
0005433202538	23262	Economy	19000.00
0005434639272	23262	Economy	19000.00
0005434639352	23262	Economy	19000.00
0005433202531	23262	Economy	19000.00
0005433202539	23262	Economy	19000.00
0005433202534	23262	Economy	19000.00
0005434639364	23262	Economy	19000.00
0005434639295	23262	Economy	19000.00
0005434639345	23262	Economy	19000.00
0005434639344	23262	Economy	19000.00
0005433202529	23262	Economy	19000.00
0005433202537	23262	Economy	19000.00
0005435326807	6094	Business	69700.00
0005434601132	6094	Business	69700.00
0005434601136	6094	Business	69700.00
0005434601127	6094	Business	69700.00
0005435326842	6094	Business	69700.00
0005435326794	6094	Business	69700.00
0005433531341	6094	Business	69700.00
0005432111315	6094	Economy	23200.00
0005434601137	6094	Economy	23200.00
0005432111317	6094	Economy	23200.00
0005434601138	6094	Economy	23200.00
0005435326789	6094	Economy	23200.00
0005434601140	6094	Economy	23200.00
0005435326782	6094	Economy	25600.00
0005434601147	6094	Economy	25600.00
0005434601134	6094	Economy	25600.00
0005433531338	6094	Economy	23200.00
0005434601131	6094	Economy	23200.00
0005434601146	6094	Economy	23200.00
0005434601143	6094	Economy	23200.00
0005435326805	6094	Economy	23200.00
0005435326808	6094	Economy	23200.00
0005434601149	6094	Economy	23200.00
0005434601144	6094	Economy	23200.00
0005434601148	6094	Economy	23200.00
0005435326776	6094	Economy	23200.00
0005435326806	6094	Economy	23200.00
0005434601130	6094	Economy	23200.00
0005434601150	6094	Economy	23200.00
0005434601152	6094	Economy	23200.00
0005432111316	6094	Economy	23200.00
0005433533354	6094	Economy	23200.00
0005434601128	6094	Economy	23200.00
0005434601151	6094	Economy	23200.00
0005433533355	6094	Economy	23200.00
0005434601129	6094	Economy	23200.00
0005434601133	6094	Economy	23200.00
0005435326747	6094	Economy	23200.00
0005433531340	6094	Economy	23200.00
0005432111314	6094	Economy	23200.00
0005433531339	6094	Economy	23200.00
0005434601135	6094	Economy	23200.00
0005434601139	6094	Economy	23200.00
0005434601145	6094	Economy	23200.00
0005434601153	6094	Economy	23200.00
0005435326760	6094	Economy	23200.00
0005433533356	6094	Economy	23200.00
0005434601142	6094	Economy	23200.00
0005434601141	6094	Economy	23200.00
0005435326910	18595	Business	69700.00
0005434600947	18595	Business	69700.00
0005434600987	18595	Business	69700.00
0005433531310	18595	Business	69700.00
0005434600949	18595	Business	69700.00
0005433531307	18595	Economy	23200.00
0005433527265	18595	Economy	23200.00
0005434600962	18595	Economy	23200.00
0005433527274	18595	Economy	23200.00
0005434600880	18595	Economy	23200.00
0005435326919	18595	Economy	25600.00
0005434600950	18595	Economy	25600.00
0005433531294	18595	Economy	25600.00
0005434601009	18595	Economy	25600.00
0005434600899	18595	Economy	23200.00
0005434600871	18595	Economy	23200.00
0005434600960	18595	Economy	23200.00
0005433527276	18595	Economy	23200.00
0005433527273	18595	Economy	23200.00
0005435326914	18595	Economy	23200.00
0005435326918	18595	Economy	23200.00
0005433531300	18595	Economy	23200.00
0005434600911	18595	Economy	23200.00
0005433527268	18595	Economy	23200.00
0005434600923	18595	Economy	23200.00
0005435326912	18595	Economy	23200.00
0005434600856	18595	Economy	23200.00
0005433531299	18595	Economy	23200.00
0005435326908	18595	Economy	23200.00
0005433527275	18595	Economy	23200.00
0005435326916	18595	Economy	23200.00
0005435326911	18595	Economy	23200.00
0005435326921	18595	Economy	23200.00
0005434600877	18595	Economy	23200.00
0005434600955	18595	Economy	23200.00
0005434600853	18595	Economy	23200.00
0005435326917	18595	Economy	23200.00
0005434600824	18595	Economy	23200.00
0005433531298	18595	Economy	23200.00
0005435326909	18595	Economy	23200.00
0005435326920	18595	Economy	23200.00
0005435326913	18595	Economy	23200.00
0005434600946	18595	Economy	23200.00
0005434600823	18595	Economy	23200.00
0005433531309	18595	Economy	23200.00
0005435326915	18595	Economy	23200.00
0005434600890	18595	Economy	23200.00
0005434600921	18595	Economy	23200.00
0005434600954	18595	Economy	23200.00
0005434600983	18595	Economy	23200.00
0005434600961	18595	Economy	23200.00
0005433181170	10645	Business	9100.00
0005433181196	10645	Business	9100.00
0005434551824	10645	Business	9100.00
0005434558367	10645	Business	9100.00
0005434558374	10645	Business	9100.00
0005433181098	10645	Business	9100.00
0005434551874	10645	Business	9100.00
0005434551873	10645	Business	9100.00
0005434551833	10645	Business	9100.00
0005434551880	10645	Business	9100.00
0005433181143	10645	Business	9100.00
0005434551844	10645	Business	9100.00
0005434551856	10645	Economy	3000.00
0005434558365	10645	Economy	3000.00
0005433181099	10645	Economy	3000.00
0005434551834	10645	Economy	3000.00
0005434551857	10645	Economy	3000.00
0005433181144	10645	Economy	3000.00
0005434551835	10645	Economy	3000.00
0005434558372	10645	Economy	3000.00
0005433181092	10645	Economy	3000.00
0005434551863	10645	Economy	3300.00
0005434551827	10645	Economy	3300.00
0005434558370	10645	Economy	3300.00
0005434551826	10645	Economy	3300.00
0005433181199	10645	Economy	3300.00
0005434551869	10645	Economy	3000.00
0005434551853	10645	Economy	3000.00
0005434551838	10645	Economy	3000.00
0005434551852	10645	Economy	3000.00
0005434558375	10645	Economy	3000.00
0005434551850	10645	Economy	3000.00
0005433181185	10645	Economy	3000.00
0005434551855	10645	Economy	3000.00
0005433181184	10645	Economy	3000.00
0005434558373	10645	Economy	3000.00
0005434551860	10645	Economy	3000.00
0005434551845	10645	Economy	3000.00
0005434551859	10645	Economy	3000.00
0005434551832	10645	Economy	3000.00
0005434551829	10645	Economy	3000.00
0005434551849	10645	Economy	3000.00
0005433181093	10645	Economy	3000.00
0005434551878	10645	Economy	3000.00
0005434551839	10645	Economy	3000.00
0005434551851	10645	Economy	3000.00
0005434551842	10645	Economy	3000.00
0005433181195	10645	Economy	3000.00
0005434551879	10645	Economy	3000.00
0005434551837	10645	Economy	3000.00
0005433181194	10645	Economy	3000.00
0005434551871	10645	Economy	3000.00
0005434558371	10645	Economy	3000.00
0005433181205	10645	Economy	3000.00
0005433181245	10645	Economy	3000.00
0005434551841	10645	Economy	3000.00
0005434551830	10645	Economy	3000.00
0005434551836	10645	Economy	3000.00
0005434551872	10645	Economy	3000.00
0005434551868	10645	Economy	3000.00
0005434554087	10645	Economy	3000.00
0005433181078	10645	Economy	3000.00
0005433181213	10645	Economy	3000.00
0005434551862	10645	Economy	3000.00
0005434551864	10645	Economy	3000.00
0005434551858	10645	Economy	3000.00
0005433181064	10645	Economy	3000.00
0005433181237	10645	Economy	3000.00
0005433181161	10645	Economy	3000.00
0005434551843	10645	Economy	3000.00
0005434558369	10645	Economy	3000.00
0005433181127	10645	Economy	3000.00
0005434551840	10645	Economy	3000.00
0005434551870	10645	Economy	3000.00
0005434551865	10645	Economy	3000.00
0005434551867	10645	Economy	3000.00
0005433181193	10645	Economy	3000.00
0005434551866	10645	Economy	3000.00
0005434551847	10645	Economy	3000.00
0005434551854	10645	Economy	3000.00
0005434551828	10645	Economy	3000.00
0005434558366	10645	Economy	3000.00
0005434551825	10645	Economy	3000.00
0005434551877	10645	Economy	3000.00
0005434551876	10645	Economy	3000.00
0005434558368	10645	Economy	3000.00
0005434551861	10645	Economy	3000.00
0005434551848	10645	Economy	3000.00
0005434551846	10645	Economy	3000.00
0005434551875	10645	Economy	3000.00
0005433181244	10645	Economy	3000.00
0005434554088	10645	Economy	3000.00
0005434551831	10645	Economy	3000.00
0005433181401	27764	Business	9100.00
0005433181406	27764	Business	9100.00
0005433181414	27764	Economy	3000.00
0005433181422	27764	Economy	3000.00
0005433181416	27764	Economy	3000.00
0005433181409	27764	Economy	3300.00
0005433181399	27764	Economy	3000.00
0005433181411	27764	Economy	3000.00
0005433181400	27764	Economy	3000.00
0005433181403	27764	Economy	3000.00
0005433181407	27764	Economy	3000.00
0005433181404	27764	Economy	3000.00
0005433181423	27764	Economy	3000.00
0005433181420	27764	Economy	3000.00
0005433181405	27764	Economy	3000.00
0005433181424	27764	Economy	3000.00
0005433181419	27764	Economy	3000.00
0005433181415	27764	Economy	3000.00
0005433181413	27764	Economy	3000.00
0005433181417	27764	Economy	3000.00
0005433181418	27764	Economy	3000.00
0005433181421	27764	Economy	3000.00
0005433181410	27764	Economy	3000.00
0005433181412	27764	Economy	3000.00
0005433181408	27764	Economy	3000.00
0005433181402	27764	Economy	3000.00
0005434551370	27763	Business	9100.00
0005434551375	27763	Business	9100.00
0005434558296	27763	Business	9100.00
0005434551476	27763	Business	9100.00
0005434551580	27763	Business	9100.00
0005434551245	27763	Business	9100.00
0005434551349	27763	Business	9100.00
0005434551789	27763	Business	9100.00
0005434551361	27763	Business	9100.00
0005434558314	27763	Business	9100.00
0005434551558	27763	Business	9100.00
0005434551385	27763	Economy	3000.00
0005434551430	27763	Economy	3000.00
0005434551230	27763	Economy	3000.00
0005434551405	27763	Economy	3000.00
0005434551631	27763	Economy	3300.00
0005434551537	27763	Economy	3300.00
0005434551532	27763	Economy	3300.00
0005434551424	27763	Economy	3000.00
0005434551333	27763	Economy	3000.00
0005434554073	27763	Economy	3000.00
0005434551791	27763	Economy	3000.00
0005434551344	27763	Economy	3000.00
0005434551545	27763	Economy	3000.00
0005434551577	27763	Economy	3000.00
0005434551597	27763	Economy	3000.00
0005434551790	27763	Economy	3000.00
0005434551579	27763	Economy	3000.00
0005434551299	27763	Economy	3000.00
0005434551589	27763	Economy	3000.00
0005434551374	27763	Economy	3000.00
0005434554064	27763	Economy	3000.00
0005434551578	27763	Economy	3000.00
0005434551271	27763	Economy	3000.00
0005434551298	27763	Economy	3000.00
0005434551356	27763	Economy	3000.00
0005434551392	27763	Economy	3000.00
0005434551566	27763	Economy	3000.00
0005434551450	27763	Economy	3000.00
0005434554072	27763	Economy	3000.00
0005434551485	27763	Economy	3000.00
0005434551496	27763	Economy	3000.00
0005434551369	27763	Economy	3000.00
0005434551400	27763	Economy	3000.00
0005434551677	27763	Economy	3000.00
0005434551491	27763	Economy	3000.00
0005434551531	27763	Economy	3000.00
0005434551595	27763	Economy	3000.00
0005434551588	27763	Economy	3000.00
0005434551484	27763	Economy	3000.00
0005434551671	27763	Economy	3000.00
0005434551477	27763	Economy	3000.00
0005434554063	27763	Economy	3000.00
0005434551454	27763	Economy	3000.00
0005434551598	27763	Economy	3000.00
0005434554071	27763	Economy	3000.00
0005434551203	27763	Economy	3000.00
0005434551490	27763	Economy	3000.00
0005434551676	27763	Economy	3000.00
0005434551380	27763	Economy	3000.00
0005434551591	27763	Economy	3000.00
0005434551306	27763	Economy	3000.00
0005434551357	27763	Economy	3000.00
0005434551307	27763	Economy	3000.00
0005434551423	27763	Economy	3000.00
0005434551451	27763	Economy	3000.00
0005434551246	27763	Economy	3000.00
0005434551584	27763	Economy	3000.00
0005434551112	27763	Economy	3000.00
0005433459271	6132	Economy	11700.00
0005433459272	6132	Economy	11700.00
0005433459269	6132	Economy	11700.00
0005435254487	6132	Economy	11700.00
0005435254486	6132	Economy	11700.00
0005433459273	6132	Economy	11700.00
0005433459270	6132	Economy	11700.00
0005433459229	19341	Economy	11700.00
0005435254502	19341	Economy	11700.00
0005433459237	19341	Economy	11700.00
0005433459236	19341	Economy	11700.00
0005433459240	19341	Economy	11700.00
0005435254504	19341	Economy	11700.00
0005435254503	19341	Economy	11700.00
0005435682626	6729	Business	51100.00
0005432136231	6729	Business	51100.00
0005434828709	6729	Business	51100.00
0005435221519	6729	Business	51100.00
0005435682609	6729	Business	51100.00
0005434828710	6729	Business	51100.00
0005432136228	6729	Business	51100.00
0005435682624	6729	Business	51100.00
0005435631003	6729	Business	51100.00
0005435438108	6729	Business	51100.00
0005435682630	6729	Business	51100.00
0005435437978	6729	Economy	17000.00
0005435438034	6729	Economy	17000.00
0005435438074	6729	Economy	17000.00
0005435682618	6729	Economy	17000.00
0005432533300	6729	Economy	17000.00
0005435682620	6729	Economy	17000.00
0005432136230	6729	Economy	17000.00
0005435682621	6729	Economy	17000.00
0005435682629	6729	Economy	17000.00
0005435682638	6729	Economy	17000.00
0005435682636	6729	Economy	18700.00
0005435682633	6729	Economy	18700.00
0005434828711	6729	Economy	18700.00
0005435682616	6729	Economy	18700.00
0005434828699	6729	Economy	17000.00
0005435631002	6729	Economy	17000.00
0005434828708	6729	Economy	17000.00
0005435438148	6729	Economy	17000.00
0005435437976	6729	Economy	17000.00
0005435438098	6729	Economy	17000.00
0005435438001	6729	Economy	17000.00
0005432533302	6729	Economy	17000.00
0005435631001	6729	Economy	17000.00
0005435438106	6729	Economy	17000.00
0005435682606	6729	Economy	17000.00
0005435682637	6729	Economy	17000.00
0005435682625	6729	Economy	17000.00
0005435438097	6729	Economy	17000.00
0005435682635	6729	Economy	17000.00
0005435682628	6729	Economy	17000.00
0005435217721	6729	Economy	17000.00
0005434828698	6729	Economy	17000.00
0005432136229	6729	Economy	17000.00
0005435438095	6729	Economy	17000.00
0005435437972	6729	Economy	17000.00
0005435682608	6729	Economy	17000.00
0005435682614	6729	Economy	17000.00
0005435438056	6729	Economy	17000.00
0005435221521	6729	Economy	17000.00
0005435661965	6729	Economy	17000.00
0005434828712	6729	Economy	17000.00
0005435631000	6729	Economy	17000.00
0005435438054	6729	Economy	17000.00
0005435438096	6729	Economy	17000.00
0005435661964	6729	Economy	17000.00
0005435438094	6729	Economy	17000.00
0005435682607	6729	Economy	17000.00
0005435682631	6729	Economy	17000.00
0005435220323	6729	Economy	17000.00
0005435438059	6729	Economy	17000.00
0005435682617	6729	Economy	17000.00
0005435438051	6729	Economy	17000.00
0005432533312	6729	Economy	17000.00
0005432533299	6729	Economy	17000.00
0005435682627	6729	Economy	17000.00
0005435682615	6729	Economy	17000.00
0005435682610	6729	Economy	17000.00
0005435682632	6729	Economy	17000.00
0005435682622	6729	Economy	17000.00
0005435438067	6729	Economy	17000.00
0005432136227	6729	Economy	17000.00
0005435438052	6729	Economy	17000.00
0005435438066	6729	Economy	17000.00
0005435682613	6729	Economy	17000.00
0005435438107	6729	Economy	17000.00
0005435221520	6729	Economy	17000.00
0005435682634	6729	Economy	17000.00
0005435437991	6729	Economy	17000.00
0005435682612	6729	Economy	17000.00
0005435220330	6729	Economy	17000.00
0005435437977	6729	Economy	17000.00
0005435682619	6729	Economy	17000.00
0005435438000	6729	Economy	17000.00
0005432533301	6729	Economy	17000.00
0005435682623	6729	Economy	17000.00
0005435682611	6729	Economy	17000.00
0005435220319	6729	Economy	17000.00
0005435438222	24619	Business	51100.00
0005435682374	24619	Business	51100.00
0005435438225	24619	Business	51100.00
0005435682349	24619	Business	51100.00
0005435682184	24619	Business	51100.00
0005435219221	24619	Business	51100.00
0005435682246	24619	Business	51100.00
0005435682328	24619	Business	51100.00
0005435438232	24619	Business	51100.00
0005435438233	24619	Economy	17000.00
0005435438227	24619	Economy	17000.00
0005432533327	24619	Economy	17000.00
0005435438219	24619	Economy	17000.00
0005435438213	24619	Economy	17000.00
0005435682375	24619	Economy	17000.00
0005435682161	24619	Economy	17000.00
0005435682257	24619	Economy	17000.00
0005435438220	24619	Economy	17000.00
0005435682345	24619	Economy	18700.00
0005435682031	24619	Economy	18700.00
0005435682160	24619	Economy	18700.00
0005435438223	24619	Economy	18700.00
0005435630964	24619	Economy	18700.00
0005435682329	24619	Economy	17000.00
0005434828733	24619	Economy	17000.00
0005435682218	24619	Economy	17000.00
0005435682159	24619	Economy	17000.00
0005432305779	24619	Economy	17000.00
0005435219226	24619	Economy	17000.00
0005432533328	24619	Economy	17000.00
0005435682212	24619	Economy	17000.00
0005435682360	24619	Economy	17000.00
0005435220341	24619	Economy	17000.00
0005435219225	24619	Economy	17000.00
0005435682341	24619	Economy	17000.00
0005435438212	24619	Economy	17000.00
0005435682226	24619	Economy	17000.00
0005435220343	24619	Economy	17000.00
0005435438216	24619	Economy	17000.00
0005435682433	24619	Economy	17000.00
0005435682314	24619	Economy	17000.00
0005435219222	24619	Economy	17000.00
0005435220345	24619	Economy	17000.00
0005435682209	24619	Economy	17000.00
0005435438226	24619	Economy	17000.00
0005435682340	24619	Economy	17000.00
0005435438228	24619	Economy	17000.00
0005435682245	24619	Economy	17000.00
0005432305778	24619	Economy	17000.00
0005435682193	24619	Economy	17000.00
0005435438231	24619	Economy	17000.00
0005435438214	24619	Economy	17000.00
0005435682420	24619	Economy	17000.00
0005435682342	24619	Economy	17000.00
0005435682227	24619	Economy	17000.00
0005435438217	24619	Economy	17000.00
0005435682291	24619	Economy	17000.00
0005435219224	24619	Economy	17000.00
0005435682376	24619	Economy	17000.00
0005435438215	24619	Economy	17000.00
0005435438224	24619	Economy	17000.00
0005434828731	24619	Economy	17000.00
0005435682214	24619	Economy	17000.00
0005434828732	24619	Economy	17000.00
0005435682213	24619	Economy	17000.00
0005435220340	24619	Economy	17000.00
0005435438229	24619	Economy	17000.00
0005435682258	24619	Economy	17000.00
0005435438221	24619	Economy	17000.00
0005435682210	24619	Economy	17000.00
0005435682229	24619	Economy	17000.00
0005435682231	24619	Economy	17000.00
0005435220344	24619	Economy	17000.00
0005435682347	24619	Economy	17000.00
0005435438218	24619	Economy	17000.00
0005435219223	24619	Economy	17000.00
0005435438211	24619	Economy	17000.00
0005435682346	24619	Economy	17000.00
0005435220342	24619	Economy	17000.00
0005435438230	24619	Economy	17000.00
0005435682292	24619	Economy	17000.00
0005435630963	24619	Economy	17000.00
0005435126828	11528	Business	26400.00
0005435126848	11528	Business	26400.00
0005435126850	11528	Business	26400.00
0005435106019	11528	Business	26400.00
0005435126821	11528	Business	26400.00
0005435106021	11528	Economy	8800.00
0005435126833	11528	Economy	8800.00
0005435098582	11528	Economy	8800.00
0005435106020	11528	Economy	8800.00
0005435126849	11528	Economy	8800.00
0005435126813	11528	Economy	9700.00
0005435126822	11528	Economy	9700.00
0005435126820	11528	Economy	9700.00
0005435126851	11528	Economy	9700.00
0005435126814	11528	Economy	8800.00
0005435098576	11528	Economy	8800.00
0005435098579	11528	Economy	8800.00
0005435126831	11528	Economy	8800.00
0005435098578	11528	Economy	8800.00
0005435126846	11528	Economy	8800.00
0005435126824	11528	Economy	8800.00
0005435126834	11528	Economy	8800.00
0005435098577	11528	Economy	8800.00
0005435126847	11528	Economy	8800.00
0005435126827	11528	Economy	8800.00
0005435126854	11528	Economy	8800.00
0005435126816	11528	Economy	8800.00
0005435126830	11528	Economy	8800.00
0005435126841	11528	Economy	8800.00
0005435126826	11528	Economy	8800.00
0005435126843	11528	Economy	8800.00
0005435558099	11528	Economy	8800.00
0005435126815	11528	Economy	8800.00
0005435558100	11528	Economy	8800.00
0005435126818	11528	Economy	8800.00
0005435106017	11528	Economy	8800.00
0005435098581	11528	Economy	8800.00
0005435126839	11528	Economy	8800.00
0005435126835	11528	Economy	8800.00
0005435098580	11528	Economy	8800.00
0005435126838	11528	Economy	8800.00
0005435126817	11528	Economy	8800.00
0005435126825	11528	Economy	8800.00
0005435126842	11528	Economy	8800.00
0005435126853	11528	Economy	8800.00
0005435126829	11528	Economy	8800.00
0005435126840	11528	Economy	8800.00
0005435106018	11528	Economy	8800.00
0005435126836	11528	Economy	8800.00
0005435126852	11528	Economy	8800.00
0005435126819	11528	Economy	8800.00
0005435126823	11528	Economy	8800.00
0005435126832	11528	Economy	8800.00
0005435126844	11528	Economy	8800.00
0005435126837	11528	Economy	8800.00
0005435126845	11528	Economy	8800.00
0005435126398	31894	Business	26400.00
0005435126376	31894	Business	26400.00
0005435126544	31894	Business	26400.00
0005435558120	31894	Business	26400.00
0005435126723	31894	Business	26400.00
0005435126425	31894	Business	26400.00
0005435126557	31894	Business	26400.00
0005435126583	31894	Economy	8800.00
0005435126465	31894	Economy	8800.00
0005435105995	31894	Economy	8800.00
0005435126575	31894	Economy	9700.00
0005435126523	31894	Economy	9700.00
0005435126577	31894	Economy	9700.00
0005435126598	31894	Economy	9700.00
0005435126430	31894	Economy	9700.00
0005435126479	31894	Economy	8800.00
0005435126571	31894	Economy	8800.00
0005435558119	31894	Economy	8800.00
0005435126553	31894	Economy	8800.00
0005435126530	31894	Economy	8800.00
0005435126503	31894	Economy	8800.00
0005435126412	31894	Economy	8800.00
0005435126399	31894	Economy	8800.00
0005435558118	31894	Economy	8800.00
0005435126631	31894	Economy	8800.00
0005435126461	31894	Economy	8800.00
0005435126570	31894	Economy	8800.00
0005435126552	31894	Economy	8800.00
0005435126525	31894	Economy	8800.00
0005435126444	31894	Economy	8800.00
0005435126732	31894	Economy	8800.00
0005435126699	31894	Economy	8800.00
0005435126374	31894	Economy	8800.00
0005435126480	31894	Economy	8800.00
0005435126509	31894	Economy	8800.00
0005435126462	31894	Economy	8800.00
0005435126558	31894	Economy	8800.00
0005435126413	31894	Economy	8800.00
0005435126373	31894	Economy	8800.00
0005435126386	31894	Economy	8800.00
0005435126429	31894	Economy	8800.00
0005435126490	31894	Economy	8800.00
0005435126524	31894	Economy	8800.00
0005435105977	31894	Economy	8800.00
0005435126491	31894	Economy	8800.00
0005435126426	31894	Economy	8800.00
0005435126599	31894	Economy	8800.00
0005435126387	31894	Economy	8800.00
0005435126578	31894	Economy	8800.00
0005435126464	31894	Economy	8800.00
0005435732365	13538	Business	36600.00
0005433398636	13538	Business	36600.00
0005433398645	13538	Business	36600.00
0005433398628	13538	Business	36600.00
0005433398666	13538	Business	36600.00
0005433398634	13538	Business	36600.00
0005433398663	13538	Business	36600.00
0005433398659	13538	Business	36600.00
0005433398633	13538	Economy	12200.00
0005435732391	13538	Economy	12200.00
0005435732343	13538	Economy	12200.00
0005433398638	13538	Economy	12200.00
0005433398640	13538	Economy	12200.00
0005433398650	13538	Economy	12200.00
0005433398660	13538	Economy	12200.00
0005433398627	13538	Economy	13400.00
0005433398649	13538	Economy	12200.00
0005435732368	13538	Economy	12200.00
0005433398639	13538	Economy	12200.00
0005433398622	13538	Economy	12200.00
0005435732397	13538	Economy	12200.00
0005433398655	13538	Economy	12200.00
0005435732386	13538	Economy	12200.00
0005433398624	13538	Economy	12200.00
0005433398654	13538	Economy	12200.00
0005433398658	13538	Economy	12200.00
0005433398652	13538	Economy	12200.00
0005433398665	13538	Economy	12200.00
0005433398641	13538	Economy	12200.00
0005433398653	13538	Economy	12200.00
0005433398664	13538	Economy	12200.00
0005433398644	13538	Economy	12200.00
0005433398631	13538	Economy	12200.00
0005433398632	13538	Economy	12200.00
0005435732416	13538	Economy	12200.00
0005433398635	13538	Economy	12200.00
0005433398661	13538	Economy	12200.00
0005433398667	13538	Economy	12200.00
0005435732351	13538	Economy	12200.00
0005433398669	13538	Economy	12200.00
0005433398625	13538	Economy	12200.00
0005433398637	13538	Economy	12200.00
0005433398643	13538	Economy	12200.00
0005433398647	13538	Economy	12200.00
0005433398629	13538	Economy	12200.00
0005433398630	13538	Economy	12200.00
0005433398623	13538	Economy	12200.00
0005433398642	13538	Economy	12200.00
0005433398668	13538	Economy	12200.00
0005435732355	13538	Economy	12200.00
0005433398662	13538	Economy	12200.00
0005435732390	13538	Economy	12200.00
0005433398626	13538	Economy	12200.00
0005435732398	13538	Economy	12200.00
0005433398648	13538	Economy	12200.00
0005433398656	13538	Economy	12200.00
0005433398651	13538	Economy	12200.00
0005433398646	13538	Economy	12200.00
0005433398657	13538	Economy	12200.00
0005433398145	19386	Business	36600.00
0005433398218	19386	Business	36600.00
0005433398077	19386	Business	36600.00
0005433398380	19386	Business	36600.00
0005432297309	19386	Business	36600.00
0005433398287	19386	Business	36600.00
0005433398078	19386	Business	36600.00
0005433398061	19386	Business	36600.00
0005433398315	19386	Business	36600.00
0005433398375	19386	Business	36600.00
0005433398332	19386	Economy	12200.00
0005433398376	19386	Economy	12200.00
0005433398264	19386	Economy	12200.00
0005433398107	19386	Economy	12200.00
0005433398295	19386	Economy	12200.00
0005433398316	19386	Economy	12200.00
0005433398369	19386	Economy	12200.00
0005433398106	19386	Economy	12200.00
0005433398137	19386	Economy	13400.00
0005433398039	19386	Economy	13400.00
0005433398053	19386	Economy	13400.00
0005433398139	19386	Economy	12200.00
0005433398052	19386	Economy	12200.00
0005433398359	19386	Economy	12200.00
0005433398138	19386	Economy	12200.00
0005433398277	19386	Economy	12200.00
0005433398281	19386	Economy	12200.00
0005433398212	19386	Economy	12200.00
0005433398150	19386	Economy	12200.00
0005433398263	19386	Economy	12200.00
0005433398279	19386	Economy	12200.00
0005433398070	19386	Economy	12200.00
0005433398299	19386	Economy	12200.00
0005433398164	19386	Economy	12200.00
0005433398118	19386	Economy	12200.00
0005433398223	19386	Economy	12200.00
0005433398066	19386	Economy	12200.00
0005433398246	19386	Economy	12200.00
0005433398374	19386	Economy	12200.00
0005433398043	19386	Economy	12200.00
0005433398177	19386	Economy	12200.00
0005433398051	19386	Economy	12200.00
0005433398383	19386	Economy	12200.00
0005433398100	19386	Economy	12200.00
0005433398068	19386	Economy	12200.00
0005433398062	19386	Economy	12200.00
0005433398141	19386	Economy	12200.00
0005433398297	19386	Economy	12200.00
0005433398213	19386	Economy	12200.00
0005432297308	19386	Economy	12200.00
0005433398346	19386	Economy	12200.00
0005433398379	19386	Economy	12200.00
0005433398360	19386	Economy	12200.00
0005433398345	19386	Economy	12200.00
0005433398333	19386	Economy	12200.00
0005433398291	19386	Economy	12200.00
0005433398373	19386	Economy	12200.00
0005433398217	19386	Economy	12200.00
0005433398187	19386	Economy	12200.00
0005432297310	19386	Economy	12200.00
0005433398298	19386	Economy	12200.00
0005433398149	19386	Economy	12200.00
0005433398178	19386	Economy	12200.00
0005433398099	19386	Economy	12200.00
0005433398140	19386	Economy	12200.00
0005433398069	19386	Economy	12200.00
0005433398412	19386	Economy	12200.00
0005433398293	19386	Economy	12200.00
0005433398163	19386	Economy	12200.00
0005433398382	19386	Economy	12200.00
0005433398294	19386	Economy	12200.00
0005433398222	19386	Economy	12200.00
0005433398241	19386	Economy	12200.00
0005433398361	19386	Economy	12200.00
0005433398424	19386	Economy	12200.00
0005435069239	13161	Business	11300.00
0005435925466	13161	Business	11300.00
0005435069112	13161	Business	11300.00
0005435069171	13161	Business	11300.00
0005435925465	13161	Business	11300.00
0005435069206	13161	Business	11300.00
0005435069182	13161	Business	11300.00
0005435069086	13161	Business	11300.00
0005435069134	13161	Economy	3800.00
0005435069052	13161	Economy	3800.00
0005435069180	13161	Economy	3800.00
0005435069242	13161	Economy	3800.00
0005435069056	13161	Economy	3800.00
0005435069146	13161	Economy	3800.00
0005435069262	13161	Economy	3800.00
0005435069287	13161	Economy	4100.00
0005435069255	13161	Economy	4100.00
0005435925464	13161	Economy	4100.00
0005435925462	13161	Economy	4100.00
0005435068955	13161	Economy	3800.00
0005435069059	13161	Economy	3800.00
0005435069046	13161	Economy	3800.00
0005435069024	13161	Economy	3800.00
0005435069148	13161	Economy	3800.00
0005435069065	13161	Economy	3800.00
0005435069260	13161	Economy	3800.00
0005435069195	13161	Economy	3800.00
0005435069178	13161	Economy	3800.00
0005435069308	13161	Economy	3800.00
0005435069181	13161	Economy	3800.00
0005435925467	13161	Economy	3800.00
0005435069250	13161	Economy	3800.00
0005435069305	13161	Economy	3800.00
0005435069237	13161	Economy	3800.00
0005435069090	13161	Economy	3800.00
0005435069053	13161	Economy	3800.00
0005435069322	13161	Economy	3800.00
0005435068976	13161	Economy	3800.00
0005435069240	13161	Economy	3800.00
0005435069185	13161	Economy	3800.00
0005435069091	13161	Economy	3800.00
0005435069089	13161	Economy	3800.00
0005435069177	13161	Economy	3800.00
0005435069155	13161	Economy	3800.00
0005435069184	13161	Economy	3800.00
0005435069025	13161	Economy	3800.00
0005435069213	13161	Economy	3800.00
0005435069228	13161	Economy	3800.00
0005435069201	13161	Economy	3800.00
0005435069124	13161	Economy	3800.00
0005435069118	13161	Economy	3800.00
0005435069051	13161	Economy	3800.00
0005435069064	13161	Economy	3800.00
0005435069238	13161	Economy	3800.00
0005435069079	13161	Economy	3800.00
0005435069202	13161	Economy	3800.00
0005435069219	13161	Economy	3800.00
0005435069261	13161	Economy	3800.00
0005435069194	13161	Economy	3800.00
0005435925463	13161	Economy	3800.00
0005435069252	13161	Economy	3800.00
0005435069243	13161	Economy	3800.00
0005435069113	13161	Economy	3800.00
0005435069686	15496	Business	11300.00
0005435069661	15496	Business	11300.00
0005435925310	15496	Business	11300.00
0005435069675	15496	Business	11300.00
0005435069664	15496	Business	11300.00
0005435069670	15496	Business	11300.00
0005435069643	15496	Business	11300.00
0005435069682	15496	Business	11300.00
0005435069651	15496	Business	11300.00
0005435069656	15496	Economy	3800.00
0005435069648	15496	Economy	3800.00
0005435069662	15496	Economy	3800.00
0005435925348	15496	Economy	3800.00
0005435069685	15496	Economy	3800.00
0005435069690	15496	Economy	4100.00
0005435925322	15496	Economy	4100.00
0005435069669	15496	Economy	3800.00
0005435069657	15496	Economy	3800.00
0005435069671	15496	Economy	3800.00
0005435069687	15496	Economy	3800.00
0005435069693	15496	Economy	3800.00
0005435069645	15496	Economy	3800.00
0005435069659	15496	Economy	3800.00
0005435069650	15496	Economy	3800.00
0005435069679	15496	Economy	3800.00
0005435069680	15496	Economy	3800.00
0005435069668	15496	Economy	3800.00
0005435069652	15496	Economy	3800.00
0005435069660	15496	Economy	3800.00
0005435069654	15496	Economy	3800.00
0005435069674	15496	Economy	3800.00
0005435069655	15496	Economy	3800.00
0005435069666	15496	Economy	3800.00
0005435925294	15496	Economy	3800.00
0005435069649	15496	Economy	3800.00
0005435069665	15496	Economy	3800.00
0005435069667	15496	Economy	3800.00
0005435069653	15496	Economy	3800.00
0005435069673	15496	Economy	3800.00
0005435069694	15496	Economy	3800.00
0005435069658	15496	Economy	3800.00
0005435069681	15496	Economy	3800.00
0005435069691	15496	Economy	3800.00
0005435069663	15496	Economy	3800.00
0005435069677	15496	Economy	3800.00
0005435925377	15496	Economy	3800.00
0005435069689	15496	Economy	3800.00
0005435069672	15496	Economy	3800.00
0005435069688	15496	Economy	3800.00
0005435069683	15496	Economy	3800.00
0005435069647	15496	Economy	3800.00
0005435069676	15496	Economy	3800.00
0005435925293	15496	Economy	3800.00
0005435069646	15496	Economy	3800.00
0005435069684	15496	Economy	3800.00
0005435069644	15496	Economy	3800.00
0005435069692	15496	Economy	3800.00
0005435069678	15496	Economy	3800.00
0005435808350	23176	Economy	27100.00
0005435808340	23176	Economy	27100.00
0005435808343	23176	Economy	27100.00
0005435808345	23176	Economy	24700.00
0005433407580	23176	Economy	24700.00
0005435808348	23176	Economy	24700.00
0005435808351	23176	Economy	24700.00
0005433407564	23176	Economy	24700.00
0005433407578	23176	Economy	24700.00
0005433407555	23176	Economy	24700.00
0005435808346	23176	Economy	24700.00
0005433407586	23176	Economy	24700.00
0005435808341	23176	Economy	24700.00
0005433407573	23176	Economy	24700.00
0005433407585	23176	Economy	24700.00
0005435808359	23176	Economy	24700.00
0005433407574	23176	Economy	24700.00
0005433407581	23176	Economy	24700.00
0005435808358	23176	Economy	24700.00
0005435808347	23176	Economy	24700.00
0005435808349	23176	Economy	24700.00
0005433407577	23176	Economy	24700.00
0005435808342	23176	Economy	24700.00
0005433407584	23176	Economy	24700.00
0005435808339	23176	Economy	24700.00
0005435808355	23176	Economy	24700.00
0005433407537	23176	Economy	24700.00
0005435808352	23176	Economy	24700.00
0005435808357	23176	Economy	24700.00
0005435808354	23176	Economy	24700.00
0005433407572	23176	Economy	24700.00
0005435808356	23176	Economy	24700.00
0005433407579	23176	Economy	24700.00
0005435808337	23176	Economy	24700.00
0005435808353	23176	Economy	24700.00
0005435808344	23176	Economy	24700.00
0005435808338	23176	Economy	24700.00
0005434215089	10685	Business	61300.00
0005434756461	10685	Business	61300.00
0005434756510	10685	Business	61300.00
0005434756500	10685	Business	61300.00
0005434215080	10685	Business	61300.00
0005434215086	10685	Business	61300.00
0005434756664	10685	Business	61300.00
0005434215093	10685	Business	61300.00
0005434215099	10685	Business	61300.00
0005434215125	10685	Business	61300.00
0005434215106	10685	Business	61300.00
0005434215120	10685	Business	61300.00
0005434756448	10685	Economy	20400.00
0005434215091	10685	Economy	20400.00
0005434215083	10685	Economy	20400.00
0005434756565	10685	Economy	20400.00
0005434215107	10685	Economy	20400.00
0005434215114	10685	Economy	20400.00
0005434756428	10685	Economy	20400.00
0005434756772	10685	Economy	20400.00
0005434215094	10685	Economy	22500.00
0005434215098	10685	Economy	22500.00
0005434756507	10685	Economy	22500.00
0005434215102	10685	Economy	22500.00
0005434756580	10685	Economy	20400.00
0005434215116	10685	Economy	20400.00
0005434215112	10685	Economy	20400.00
0005434756501	10685	Economy	20400.00
0005434756606	10685	Economy	20400.00
0005434215103	10685	Economy	20400.00
0005434215117	10685	Economy	20400.00
0005434756491	10685	Economy	20400.00
0005434215113	10685	Economy	20400.00
0005434215079	10685	Economy	20400.00
0005434215101	10685	Economy	20400.00
0005434215084	10685	Economy	20400.00
0005434756495	10685	Economy	20400.00
0005434215118	10685	Economy	20400.00
0005434756479	10685	Economy	20400.00
0005434756508	10685	Economy	20400.00
0005434756608	10685	Economy	20400.00
0005434756429	10685	Economy	20400.00
0005434215111	10685	Economy	20400.00
0005434756588	10685	Economy	20400.00
0005434215119	10685	Economy	20400.00
0005434215121	10685	Economy	20400.00
0005434756620	10685	Economy	20400.00
0005434215078	10685	Economy	20400.00
0005434215108	10685	Economy	20400.00
0005434215110	10685	Economy	20400.00
0005434215092	10685	Economy	20400.00
0005434215096	10685	Economy	20400.00
0005434215082	10685	Economy	20400.00
0005434215105	10685	Economy	20400.00
0005434756547	10685	Economy	20400.00
0005434215123	10685	Economy	20400.00
0005434756559	10685	Economy	20400.00
0005434215097	10685	Economy	20400.00
0005434215122	10685	Economy	20400.00
0005434756592	10685	Economy	20400.00
0005434215087	10685	Economy	20400.00
0005434215104	10685	Economy	20400.00
0005434215115	10685	Economy	20400.00
0005434215095	10685	Economy	20400.00
0005434756490	10685	Economy	20400.00
0005434215100	10685	Economy	20400.00
0005434756480	10685	Economy	20400.00
0005434756601	10685	Economy	20400.00
0005434756489	10685	Economy	20400.00
0005434215109	10685	Economy	20400.00
0005434756388	10685	Economy	20400.00
0005434215085	10685	Economy	20400.00
0005434756771	10685	Economy	20400.00
0005434215090	10685	Economy	20400.00
0005434215088	10685	Economy	20400.00
0005434756396	10685	Economy	20400.00
0005434215124	10685	Economy	20400.00
0005434756587	10685	Economy	20400.00
0005434756558	10685	Economy	20400.00
0005434756566	10685	Economy	20400.00
0005434215081	10685	Economy	20400.00
0005434214486	28650	Business	61300.00
0005434214777	28650	Business	61300.00
0005434756893	28650	Business	61300.00
0005434756907	28650	Business	61300.00
0005434214764	28650	Business	61300.00
0005434756920	28650	Business	61300.00
0005434214625	28650	Business	61300.00
0005434756904	28650	Business	61300.00
0005434756913	28650	Business	61300.00
0005434214372	28650	Business	61300.00
0005434756919	28650	Business	61300.00
0005434756890	28650	Economy	20400.00
0005434214704	28650	Economy	20400.00
0005434214720	28650	Economy	20400.00
0005434214521	28650	Economy	20400.00
0005434214551	28650	Economy	20400.00
0005434214703	28650	Economy	20400.00
0005434214765	28650	Economy	20400.00
0005434756916	28650	Economy	20400.00
0005434756884	28650	Economy	20400.00
0005434214520	28650	Economy	20400.00
0005434756892	28650	Economy	22500.00
0005434214501	28650	Economy	22500.00
0005434756925	28650	Economy	22500.00
0005434214427	28650	Economy	22500.00
0005434756908	28650	Economy	22500.00
0005434756914	28650	Economy	20400.00
0005434214506	28650	Economy	20400.00
0005434756902	28650	Economy	20400.00
0005434214709	28650	Economy	20400.00
0005434214535	28650	Economy	20400.00
0005434214380	28650	Economy	20400.00
0005434756898	28650	Economy	20400.00
0005434756911	28650	Economy	20400.00
0005434214580	28650	Economy	20400.00
0005434214602	28650	Economy	20400.00
0005434756888	28650	Economy	20400.00
0005434214806	28650	Economy	20400.00
0005434756915	28650	Economy	20400.00
0005434214719	28650	Economy	20400.00
0005434214655	28650	Economy	20400.00
0005434214741	28650	Economy	20400.00
0005434214723	28650	Economy	20400.00
0005434756906	28650	Economy	20400.00
0005434214631	28650	Economy	20400.00
0005434756922	28650	Economy	20400.00
0005434756903	28650	Economy	20400.00
0005434756881	28650	Economy	20400.00
0005434756924	28650	Economy	20400.00
0005434214581	28650	Economy	20400.00
0005434214485	28650	Economy	20400.00
0005434214624	28650	Economy	20400.00
0005434214705	28650	Economy	20400.00
0005434214686	28650	Economy	20400.00
0005434214652	28650	Economy	20400.00
0005434756912	28650	Economy	20400.00
0005434756926	28650	Economy	20400.00
0005434756900	28650	Economy	20400.00
0005434756886	28650	Economy	20400.00
0005434214507	28650	Economy	20400.00
0005434756896	28650	Economy	20400.00
0005434214775	28650	Economy	20400.00
0005434214493	28650	Economy	20400.00
0005434756889	28650	Economy	20400.00
0005434214484	28650	Economy	20400.00
0005434756895	28650	Economy	20400.00
0005434214632	28650	Economy	20400.00
0005434214502	28650	Economy	20400.00
0005434756883	28650	Economy	20400.00
0005434214436	28650	Economy	20400.00
0005434756899	28650	Economy	20400.00
0005434756905	28650	Economy	20400.00
0005434756897	28650	Economy	20400.00
0005434756894	28650	Economy	20400.00
0005434756921	28650	Economy	20400.00
0005434756927	28650	Economy	20400.00
0005434214600	28650	Economy	20400.00
0005434214710	28650	Economy	20400.00
0005434756885	28650	Economy	20400.00
0005434214601	28650	Economy	20400.00
0005434756882	28650	Economy	20400.00
0005434756891	28650	Economy	20400.00
0005434756887	28650	Economy	20400.00
0005434214714	28650	Economy	20400.00
0005434214585	28650	Economy	20400.00
0005434214744	28650	Economy	20400.00
0005434756923	28650	Economy	20400.00
0005434756901	28650	Economy	20400.00
0005434756917	28650	Economy	20400.00
0005434756910	28650	Economy	20400.00
0005434756909	28650	Economy	20400.00
0005434214724	28650	Economy	20400.00
0005434214745	28650	Economy	20400.00
0005434756918	28650	Economy	20400.00
0005435007328	5468	Business	29500.00
0005434229339	5468	Business	29500.00
0005435040544	5468	Business	29500.00
0005435040556	5468	Business	29500.00
0005432125543	5468	Business	29500.00
0005435040575	5468	Business	29500.00
0005435007304	5468	Business	29500.00
0005435040531	5468	Business	29500.00
0005435007319	5468	Business	29500.00
0005435377904	5468	Business	29500.00
0005435040539	5468	Business	29500.00
0005435040526	5468	Economy	9800.00
0005435007320	5468	Economy	9800.00
0005435040552	5468	Economy	9800.00
0005435040567	5468	Economy	9800.00
0005435040568	5468	Economy	9800.00
0005434229419	5468	Economy	9800.00
0005434229491	5468	Economy	9800.00
0005435040557	5468	Economy	9800.00
0005435007305	5468	Economy	9800.00
0005435040555	5468	Economy	9800.00
0005435040566	5468	Economy	9800.00
0005435040583	5468	Economy	9800.00
0005435040574	5468	Economy	9800.00
0005435040521	5468	Economy	9800.00
0005434229584	5468	Economy	9800.00
0005434229451	5468	Economy	9800.00
0005432125539	5468	Economy	9800.00
0005435040543	5468	Economy	9800.00
0005435040530	5468	Economy	9800.00
0005434229466	5468	Economy	9800.00
0005435040541	5468	Economy	9800.00
0005435040564	5468	Economy	9800.00
0005435040565	5468	Economy	9800.00
0005432125540	5468	Economy	9800.00
0005435040540	5468	Economy	9800.00
0005435040582	5468	Economy	9800.00
0005435040576	5468	Economy	9800.00
0005435007318	5468	Economy	9800.00
0005435007327	5468	Economy	9800.00
0005435040525	5468	Economy	9800.00
0005435040553	5468	Economy	9800.00
0005435040581	5468	Economy	9800.00
0005435007316	5468	Economy	9800.00
0005435040561	5468	Economy	9800.00
0005435040548	5468	Economy	9800.00
0005435040559	5468	Economy	9800.00
0005435007326	5468	Economy	10800.00
0005435040533	5468	Economy	10800.00
0005435007312	5468	Economy	10800.00
0005435040580	5468	Economy	10800.00
0005435040570	5468	Economy	10800.00
0005435040536	5468	Economy	9800.00
0005435040546	5468	Economy	9800.00
0005434229477	5468	Economy	9800.00
0005435007317	5468	Economy	9800.00
0005434229406	5468	Economy	9800.00
0005435040578	5468	Economy	9800.00
0005435040579	5468	Economy	9800.00
0005435007314	5468	Economy	9800.00
0005435042884	5468	Economy	9800.00
0005435040563	5468	Economy	9800.00
0005435007306	5468	Economy	9800.00
0005435040537	5468	Economy	9800.00
0005435007315	5468	Economy	9800.00
0005435040584	5468	Economy	9800.00
0005435040551	5468	Economy	9800.00
0005435040545	5468	Economy	9800.00
0005435040535	5468	Economy	9800.00
0005435040527	5468	Economy	9800.00
0005435040532	5468	Economy	9800.00
0005435007325	5468	Economy	9800.00
0005435007309	5468	Economy	9800.00
0005435040517	5468	Economy	9800.00
0005435040524	5468	Economy	9800.00
0005434229476	5468	Economy	9800.00
0005432125542	5468	Economy	9800.00
0005435040549	5468	Economy	9800.00
0005434229465	5468	Economy	9800.00
0005435007322	5468	Economy	9800.00
0005435007313	5468	Economy	9800.00
0005435040522	5468	Economy	9800.00
0005434229486	5468	Economy	9800.00
0005434229449	5468	Economy	9800.00
0005432125541	5468	Economy	9800.00
0005435377905	5468	Economy	9800.00
0005435007308	5468	Economy	9800.00
0005435040573	5468	Economy	9800.00
0005432125544	5468	Economy	9800.00
0005435007323	5468	Economy	9800.00
0005435040571	5468	Economy	9800.00
0005435040519	5468	Economy	9800.00
0005435040554	5468	Economy	9800.00
0005435040569	5468	Economy	9800.00
0005435007321	5468	Economy	9800.00
0005435040558	5468	Economy	9800.00
0005435040562	5468	Economy	9800.00
0005435040560	5468	Economy	9800.00
0005434229433	5468	Economy	9800.00
0005435007324	5468	Economy	9800.00
0005435040547	5468	Economy	9800.00
0005435040550	5468	Economy	9800.00
0005435040529	5468	Economy	9800.00
0005435040528	5468	Economy	9800.00
0005435040542	5468	Economy	9800.00
0005435040518	5468	Economy	9800.00
0005435040520	5468	Economy	9800.00
0005435040577	5468	Economy	9800.00
0005435040534	5468	Economy	9800.00
0005435007310	5468	Economy	9800.00
0005435007311	5468	Economy	9800.00
0005435040538	5468	Economy	9800.00
0005435040572	5468	Economy	9800.00
0005435007307	5468	Economy	9800.00
0005435040523	5468	Economy	9800.00
0005435007159	12966	Business	29500.00
0005435040029	12966	Business	29500.00
0005434229654	12966	Business	29500.00
0005435040147	12966	Business	29500.00
0005435039916	12966	Business	29500.00
0005435040079	12966	Business	29500.00
0005435007186	12966	Business	29500.00
0005435040100	12966	Business	29500.00
0005435040007	12966	Business	29500.00
0005435007085	12966	Business	29500.00
0005435039755	12966	Business	29500.00
0005435007074	12966	Business	29500.00
0005435007126	12966	Economy	9800.00
0005435039791	12966	Economy	9800.00
0005435007151	12966	Economy	9800.00
0005435039934	12966	Economy	9800.00
0005435007051	12966	Economy	9800.00
0005435007086	12966	Economy	9800.00
0005435040009	12966	Economy	9800.00
0005432304446	12966	Economy	9800.00
0005435040096	12966	Economy	9800.00
0005435039892	12966	Economy	9800.00
0005434229648	12966	Economy	9800.00
0005435007046	12966	Economy	9800.00
0005434229639	12966	Economy	9800.00
0005435040035	12966	Economy	9800.00
0005435039989	12966	Economy	9800.00
0005435007187	12966	Economy	9800.00
0005434229641	12966	Economy	9800.00
0005435039659	12966	Economy	9800.00
0005435039955	12966	Economy	9800.00
0005435039924	12966	Economy	9800.00
0005435039909	12966	Economy	9800.00
0005435039991	12966	Economy	9800.00
0005435040010	12966	Economy	9800.00
0005435039855	12966	Economy	9800.00
0005434229644	12966	Economy	9800.00
0005435039869	12966	Economy	9800.00
0005435040076	12966	Economy	9800.00
0005435040018	12966	Economy	9800.00
0005435040153	12966	Economy	9800.00
0005435039870	12966	Economy	9800.00
0005435007098	12966	Economy	9800.00
0005435039856	12966	Economy	9800.00
0005435040008	12966	Economy	9800.00
0005435039693	12966	Economy	9800.00
0005435039968	12966	Economy	9800.00
0005435039790	12966	Economy	9800.00
0005434229657	12966	Economy	9800.00
0005434229656	12966	Economy	9800.00
0005435007188	12966	Economy	9800.00
0005435007145	12966	Economy	10800.00
0005435007104	12966	Economy	10800.00
0005435007045	12966	Economy	10800.00
0005435040130	12966	Economy	10800.00
0005435040021	12966	Economy	10800.00
0005434229640	12966	Economy	10800.00
0005435039999	12966	Economy	9800.00
0005435007052	12966	Economy	9800.00
0005435007176	12966	Economy	9800.00
0005435007167	12966	Economy	9800.00
0005435040154	12966	Economy	9800.00
0005435040028	12966	Economy	9800.00
0005435007099	12966	Economy	9800.00
0005435039756	12966	Economy	9800.00
0005434229655	12966	Economy	9800.00
0005435039868	12966	Economy	9800.00
0005435007106	12966	Economy	9800.00
0005434229646	12966	Economy	9800.00
0005435007026	12966	Economy	9800.00
0005435040113	12966	Economy	9800.00
0005435039902	12966	Economy	9800.00
0005435040059	12966	Economy	9800.00
0005435007177	12966	Economy	9800.00
0005435039929	12966	Economy	9800.00
0005435007107	12966	Economy	9800.00
0005435039811	12966	Economy	9800.00
0005435007073	12966	Economy	9800.00
0005435040005	12966	Economy	9800.00
0005435039951	12966	Economy	9800.00
0005434229650	12966	Economy	9800.00
0005435039730	12966	Economy	9800.00
0005435039990	12966	Economy	9800.00
0005435040116	12966	Economy	9800.00
0005435040101	12966	Economy	9800.00
0005432304447	12966	Economy	9800.00
0005435039954	12966	Economy	9800.00
0005434229649	12966	Economy	9800.00
0005432304444	12966	Economy	9800.00
0005435040050	12966	Economy	9800.00
0005435039812	12966	Economy	9800.00
0005434229645	12966	Economy	9800.00
0005435040058	12966	Economy	9800.00
0005435039903	12966	Economy	9800.00
0005435007163	12966	Economy	9800.00
0005435040148	12966	Economy	9800.00
0005435040032	12966	Economy	9800.00
0005435040000	12966	Economy	9800.00
0005435007175	12966	Economy	9800.00
0005434229659	12966	Economy	9800.00
0005435007161	12966	Economy	9800.00
0005434229647	12966	Economy	9800.00
0005435007216	12966	Economy	9800.00
0005435039952	12966	Economy	9800.00
0005435007108	12966	Economy	9800.00
0005435039976	12966	Economy	9800.00
0005435040117	12966	Economy	9800.00
0005434229653	12966	Economy	9800.00
0005435007152	12966	Economy	9800.00
0005435007105	12966	Economy	9800.00
0005435040045	12966	Economy	9800.00
0005435040033	12966	Economy	9800.00
0005434229651	12966	Economy	9800.00
0005435039930	12966	Economy	9800.00
0005435040095	12966	Economy	9800.00
0005435007160	12966	Economy	9800.00
0005434229642	12966	Economy	9800.00
0005434229643	12966	Economy	9800.00
0005434229652	12966	Economy	9800.00
0005432304445	12966	Economy	9800.00
0005435039931	12966	Economy	9800.00
0005435039977	12966	Economy	9800.00
0005435007124	12966	Economy	9800.00
0005435007153	12966	Economy	9800.00
0005435007144	12966	Economy	9800.00
0005435039982	12966	Economy	9800.00
0005435007087	12966	Economy	9800.00
0005435039864	12966	Economy	9800.00
0005434229658	12966	Economy	9800.00
0005435902671	14905	Business	52900.00
0005434426929	14905	Business	52900.00
0005434426948	14905	Business	52900.00
0005432188644	14905	Business	52900.00
0005434426941	14905	Business	52900.00
0005434426944	14905	Business	52900.00
0005432188645	14905	Business	52900.00
0005434426955	14905	Business	52900.00
0005434426954	14905	Business	52900.00
0005434426937	14905	Economy	17600.00
0005435902745	14905	Economy	17600.00
0005435902825	14905	Economy	17600.00
0005434411829	14905	Economy	17600.00
0005434426945	14905	Economy	17600.00
0005434426938	14905	Economy	17600.00
0005435902766	14905	Economy	17600.00
0005434426952	14905	Economy	19400.00
0005435902744	14905	Economy	19400.00
0005435554205	14905	Economy	19400.00
0005435902771	14905	Economy	19400.00
0005435554232	14905	Economy	17600.00
0005435902740	14905	Economy	17600.00
0005435554202	14905	Economy	17600.00
0005434426953	14905	Economy	17600.00
0005434426933	14905	Economy	17600.00
0005434426936	14905	Economy	17600.00
0005435902723	14905	Economy	17600.00
0005435902708	14905	Economy	17600.00
0005435902802	14905	Economy	17600.00
0005432188647	14905	Economy	17600.00
0005434426930	14905	Economy	17600.00
0005435902689	14905	Economy	17600.00
0005434426950	14905	Economy	17600.00
0005434426934	14905	Economy	17600.00
0005434426957	14905	Economy	17600.00
0005434426942	14905	Economy	17600.00
0005434426946	14905	Economy	17600.00
0005434426949	14905	Economy	17600.00
0005434426947	14905	Economy	17600.00
0005435902734	14905	Economy	17600.00
0005432188646	14905	Economy	17600.00
0005435554204	14905	Economy	17600.00
0005434426939	14905	Economy	17600.00
0005434426943	14905	Economy	17600.00
0005434426940	14905	Economy	17600.00
0005434426951	14905	Economy	17600.00
0005434411828	14905	Economy	17600.00
0005434426958	14905	Economy	17600.00
0005435902823	14905	Economy	17600.00
0005435902709	14905	Economy	17600.00
0005435902824	14905	Economy	17600.00
0005434426931	14905	Economy	17600.00
0005434411826	14905	Economy	17600.00
0005434411827	14905	Economy	17600.00
0005434426956	14905	Economy	17600.00
0005434426932	14905	Economy	17600.00
0005435554231	14905	Economy	17600.00
0005435554183	14905	Economy	17600.00
0005434426935	14905	Economy	17600.00
0005434426959	14905	Economy	17600.00
0005435902803	14905	Economy	17600.00
0005434426774	20226	Business	52900.00
0005432059529	20226	Business	52900.00
0005435554248	20226	Business	52900.00
0005434426777	20226	Business	52900.00
0005434426746	20226	Business	52900.00
0005434426865	20226	Business	52900.00
0005435554247	20226	Economy	17600.00
0005434426806	20226	Economy	17600.00
0005434426740	20226	Economy	17600.00
0005434426767	20226	Economy	17600.00
0005435902920	20226	Economy	17600.00
0005434426677	20226	Economy	17600.00
0005434426713	20226	Economy	17600.00
0005435902914	20226	Economy	19400.00
0005434426650	20226	Economy	19400.00
0005434426722	20226	Economy	17600.00
0005435902923	20226	Economy	17600.00
0005434426701	20226	Economy	17600.00
0005435902931	20226	Economy	17600.00
0005435902927	20226	Economy	17600.00
0005434426651	20226	Economy	17600.00
0005434426678	20226	Economy	17600.00
0005434426812	20226	Economy	17600.00
0005435902928	20226	Economy	17600.00
0005434411786	20226	Economy	17600.00
0005435554249	20226	Economy	17600.00
0005434426700	20226	Economy	17600.00
0005435902919	20226	Economy	17600.00
0005435902929	20226	Economy	17600.00
0005435902925	20226	Economy	17600.00
0005435902921	20226	Economy	17600.00
0005434426768	20226	Economy	17600.00
0005434426675	20226	Economy	17600.00
0005435902918	20226	Economy	17600.00
0005432059528	20226	Economy	17600.00
0005435902926	20226	Economy	17600.00
0005434426729	20226	Economy	17600.00
0005434426801	20226	Economy	17600.00
0005434426775	20226	Economy	17600.00
0005435902917	20226	Economy	17600.00
0005435902930	20226	Economy	17600.00
0005434411792	20226	Economy	17600.00
0005434411781	20226	Economy	17600.00
0005434426705	20226	Economy	17600.00
0005435902924	20226	Economy	17600.00
0005434411785	20226	Economy	17600.00
0005434426674	20226	Economy	17600.00
0005434426696	20226	Economy	17600.00
0005435554250	20226	Economy	17600.00
0005435902915	20226	Economy	17600.00
0005435902922	20226	Economy	17600.00
0005434426676	20226	Economy	17600.00
0005435902916	20226	Economy	17600.00
0005433726096	21653	Business	91700.00
0005433726101	21653	Economy	30600.00
0005433726104	21653	Economy	30600.00
0005433726079	21653	Economy	30600.00
0005433726105	21653	Economy	30600.00
0005433726093	21653	Economy	30600.00
0005433726103	21653	Economy	30600.00
0005433726086	21653	Economy	30600.00
0005433726095	21653	Economy	30600.00
0005433726110	21653	Economy	30600.00
0005433726109	21653	Economy	30600.00
0005433726076	21653	Economy	30600.00
0005433726097	21653	Economy	30600.00
0005433726106	21653	Economy	30600.00
0005433726108	21653	Economy	30600.00
0005433434731	26525	Business	18500.00
0005433434763	26525	Business	18500.00
0005435982812	26525	Business	18500.00
0005433434680	26525	Business	18500.00
0005433434717	26525	Business	18500.00
0005433434790	26525	Business	18500.00
0005433434826	26525	Business	18500.00
0005433434637	26525	Business	18500.00
0005435982825	26525	Business	18500.00
0005433434672	26525	Business	18500.00
0005435982826	26525	Economy	6200.00
0005435982829	26525	Economy	6200.00
0005433434783	26525	Economy	6200.00
0005435982815	26525	Economy	6200.00
0005435982820	26525	Economy	6200.00
0005433434709	26525	Economy	6200.00
0005433434616	26525	Economy	6200.00
0005433434827	26525	Economy	6800.00
0005435982822	26525	Economy	6800.00
0005435982837	26525	Economy	6800.00
0005435982830	26525	Economy	6200.00
0005433434658	26525	Economy	6200.00
0005432300332	26525	Economy	6200.00
0005434273085	26525	Economy	6200.00
0005433434743	26525	Economy	6200.00
0005435982840	26525	Economy	6200.00
0005433434671	26525	Economy	6200.00
0005435982814	26525	Economy	6200.00
0005435982833	26525	Economy	6200.00
0005433434700	26525	Economy	6200.00
0005433434713	26525	Economy	6200.00
0005433434752	26525	Economy	6200.00
0005433434765	26525	Economy	6200.00
0005435982839	26525	Economy	6200.00
0005433434766	26525	Economy	6200.00
0005433434721	26525	Economy	6200.00
0005433434730	26525	Economy	6200.00
0005435982842	26525	Economy	6200.00
0005435982836	26525	Economy	6200.00
0005433434663	26525	Economy	6200.00
0005435982841	26525	Economy	6200.00
0005435982834	26525	Economy	6200.00
0005434270214	26525	Economy	6200.00
0005435982831	26525	Economy	6200.00
0005433434760	26525	Economy	6200.00
0005432300331	26525	Economy	6200.00
0005434273084	26525	Economy	6200.00
0005433434753	26525	Economy	6200.00
0005433434732	26525	Economy	6200.00
0005435982813	26525	Economy	6200.00
0005432300330	26525	Economy	6200.00
0005433434809	26525	Economy	6200.00
0005435982832	26525	Economy	6200.00
0005433434682	26525	Economy	6200.00
0005435982824	26525	Economy	6200.00
0005435982835	26525	Economy	6200.00
0005435982828	26525	Economy	6200.00
0005435982817	26525	Economy	6200.00
0005433434759	26525	Economy	6200.00
0005434273082	26525	Economy	6200.00
0005432300328	26525	Economy	6200.00
0005432300327	26525	Economy	6200.00
0005435982816	26525	Economy	6200.00
0005435982819	26525	Economy	6200.00
0005435982843	26525	Economy	6200.00
0005433434716	26525	Economy	6200.00
0005435982838	26525	Economy	6200.00
0005433434638	26525	Economy	6200.00
0005432300329	26525	Economy	6200.00
0005434270213	26525	Economy	6200.00
0005433434722	26525	Economy	6200.00
0005435982827	26525	Economy	6200.00
0005433434681	26525	Economy	6200.00
0005435982818	26525	Economy	6200.00
0005433434767	26525	Economy	6200.00
0005435982823	26525	Economy	6200.00
0005435982821	26525	Economy	6200.00
0005435982349	26692	Business	18500.00
0005435982484	26692	Business	18500.00
0005433435016	26692	Business	18500.00
0005435982382	26692	Business	18500.00
0005435982421	26692	Business	18500.00
0005433435015	26692	Business	18500.00
0005433435017	26692	Business	18500.00
0005433435021	26692	Business	18500.00
0005435982447	26692	Business	18500.00
0005433435039	26692	Business	18500.00
0005435982548	26692	Economy	6200.00
0005433435042	26692	Economy	6200.00
0005435982344	26692	Economy	6200.00
0005433435018	26692	Economy	6200.00
0005435982291	26692	Economy	6200.00
0005433435038	26692	Economy	6200.00
0005433435035	26692	Economy	6200.00
0005435982443	26692	Economy	6200.00
0005435982539	26692	Economy	6200.00
0005435982353	26692	Economy	6800.00
0005433435027	26692	Economy	6800.00
0005435982648	26692	Economy	6800.00
0005435982247	26692	Economy	6800.00
0005435982601	26692	Economy	6800.00
0005434270234	26692	Economy	6200.00
0005435982352	26692	Economy	6200.00
0005432051165	26692	Economy	6200.00
0005435982405	26692	Economy	6200.00
0005435982461	26692	Economy	6200.00
0005435982417	26692	Economy	6200.00
0005432051167	26692	Economy	6200.00
0005433435036	26692	Economy	6200.00
0005435982636	26692	Economy	6200.00
0005435982538	26692	Economy	6200.00
0005435982422	26692	Economy	6200.00
0005432051168	26692	Economy	6200.00
0005435982451	26692	Economy	6200.00
0005433435026	26692	Economy	6200.00
0005434270233	26692	Economy	6200.00
0005433435040	26692	Economy	6200.00
0005435982452	26692	Economy	6200.00
0005435982343	26692	Economy	6200.00
0005435982505	26692	Economy	6200.00
0005435982481	26692	Economy	6200.00
0005434269129	26692	Economy	6200.00
0005433435034	26692	Economy	6200.00
0005435982637	26692	Economy	6200.00
0005433435037	26692	Economy	6200.00
0005435982311	26692	Economy	6200.00
0005435982614	26692	Economy	6200.00
0005435982342	26692	Economy	6200.00
0005433435019	26692	Economy	6200.00
0005433435041	26692	Economy	6200.00
0005435982248	26692	Economy	6200.00
0005433435032	26692	Economy	6200.00
0005434270231	26692	Economy	6200.00
0005434271337	26692	Economy	6200.00
0005435982566	26692	Economy	6200.00
0005435982350	26692	Economy	6200.00
0005435982308	26692	Economy	6200.00
0005435982296	26692	Economy	6200.00
0005433435030	26692	Economy	6200.00
0005435982506	26692	Economy	6200.00
0005433435022	26692	Economy	6200.00
0005433435023	26692	Economy	6200.00
0005435982462	26692	Economy	6200.00
0005433435020	26692	Economy	6200.00
0005434270232	26692	Economy	6200.00
0005434271338	26692	Economy	6200.00
0005435982453	26692	Economy	6200.00
0005433435024	26692	Economy	6200.00
0005435982446	26692	Economy	6200.00
0005435982488	26692	Economy	6200.00
0005435982330	26692	Economy	6200.00
0005433435033	26692	Economy	6200.00
0005435982367	26692	Economy	6200.00
0005435982647	26692	Economy	6200.00
0005435982489	26692	Economy	6200.00
0005432051166	26692	Economy	6200.00
0005435982312	26692	Economy	6200.00
0005435982511	26692	Economy	6200.00
0005435982345	26692	Economy	6200.00
0005433435028	26692	Economy	6200.00
0005433435031	26692	Economy	6200.00
0005435982366	26692	Economy	6200.00
0005433435029	26692	Economy	6200.00
0005433435025	26692	Economy	6200.00
0005435982420	26692	Economy	6200.00
0005432858154	3175	Economy	11100.00
0005432584354	3175	Economy	11100.00
0005432858146	3175	Economy	11100.00
0005432584349	3175	Economy	11100.00
0005432584346	3175	Economy	10100.00
0005432584356	3175	Economy	10100.00
0005432858142	3175	Economy	10100.00
0005432584350	3175	Economy	10100.00
0005432584352	3175	Economy	10100.00
0005432858149	3175	Economy	10100.00
0005432858088	3175	Economy	10100.00
0005432858126	3175	Economy	10100.00
0005432858101	3175	Economy	10100.00
0005432584333	3175	Economy	10100.00
0005432216306	3175	Economy	10100.00
0005432858144	3175	Economy	10100.00
0005432584341	3175	Economy	10100.00
0005432858082	3175	Economy	10100.00
0005432584355	3175	Economy	10100.00
0005432216307	3175	Economy	10100.00
0005432584347	3175	Economy	10100.00
0005432858087	3175	Economy	10100.00
0005432858111	3175	Economy	10100.00
0005432584348	3175	Economy	10100.00
0005432584353	3175	Economy	10100.00
0005432858063	3175	Economy	10100.00
0005432584335	3175	Economy	10100.00
0005432584339	3175	Economy	10100.00
0005432584345	3175	Economy	10100.00
0005432584340	3175	Economy	10100.00
0005432584336	3175	Economy	10100.00
0005432584342	3175	Economy	10100.00
0005432216305	3175	Economy	10100.00
0005432584344	3175	Economy	10100.00
0005432584343	3175	Economy	10100.00
0005432584334	3175	Economy	10100.00
0005432584338	3175	Economy	10100.00
0005432584337	3175	Economy	10100.00
0005432858145	3175	Economy	10100.00
0005432858069	3175	Economy	10100.00
0005432858127	3175	Economy	10100.00
0005432584331	3175	Economy	10100.00
0005432584351	3175	Economy	10100.00
0005432858102	3175	Economy	10100.00
0005432858110	3175	Economy	10100.00
0005432858089	3175	Economy	10100.00
0005432584332	3175	Economy	10100.00
0005432858219	31490	Economy	11100.00
0005432584223	31490	Economy	11100.00
0005432584234	31490	Economy	11100.00
0005432584120	31490	Economy	11100.00
0005432584099	31490	Economy	10100.00
0005432584097	31490	Economy	10100.00
0005432584133	31490	Economy	10100.00
0005432858212	31490	Economy	10100.00
0005432858216	31490	Economy	10100.00
0005432858220	31490	Economy	10100.00
0005432584089	31490	Economy	10100.00
0005432584153	31490	Economy	10100.00
0005432858211	31490	Economy	10100.00
0005432584066	31490	Economy	10100.00
0005432584152	31490	Economy	10100.00
0005432584082	31490	Economy	10100.00
0005432584096	31490	Economy	10100.00
0005432858210	31490	Economy	10100.00
0005432584227	31490	Economy	10100.00
0005432584027	31490	Economy	10100.00
0005432584225	31490	Economy	10100.00
0005432858215	31490	Economy	10100.00
0005432584180	31490	Economy	10100.00
0005432584156	31490	Economy	10100.00
0005432584102	31490	Economy	10100.00
0005432584148	31490	Economy	10100.00
0005432584067	31490	Economy	10100.00
0005432584121	31490	Economy	10100.00
0005432858221	31490	Economy	10100.00
0005432584145	31490	Economy	10100.00
0005432584181	31490	Economy	10100.00
0005432584235	31490	Economy	10100.00
0005432584098	31490	Economy	10100.00
0005432584151	31490	Economy	10100.00
0005432584090	31490	Economy	10100.00
0005432584111	31490	Economy	10100.00
0005432584226	31490	Economy	10100.00
0005432584146	31490	Economy	10100.00
0005432584158	31490	Economy	10100.00
0005432584112	31490	Economy	10100.00
0005432584177	31490	Economy	10100.00
0005432858213	31490	Economy	10100.00
0005432584272	31490	Economy	10100.00
0005432858217	31490	Economy	10100.00
0005432858218	31490	Economy	10100.00
0005432584190	31490	Economy	10100.00
0005432858214	31490	Economy	10100.00
0005433255123	860	Economy	7500.00
0005433255145	860	Economy	7500.00
0005434943460	860	Economy	7500.00
0005434943468	860	Economy	7500.00
0005434943467	860	Economy	7500.00
0005434943462	860	Economy	7500.00
0005434943465	860	Economy	7500.00
0005434943464	860	Economy	7500.00
0005433255142	860	Economy	7500.00
0005434943463	860	Economy	7500.00
0005434943466	860	Economy	7500.00
0005433255144	860	Economy	7500.00
0005434943461	860	Economy	7500.00
0005433255124	860	Economy	7500.00
0005433255143	860	Economy	7500.00
0005433255139	860	Economy	7500.00
0005434943389	16191	Economy	8300.00
0005434943375	16191	Economy	8300.00
0005434943406	16191	Economy	7500.00
0005434943384	16191	Economy	7500.00
0005434943409	16191	Economy	7500.00
0005433255185	16191	Economy	7500.00
0005434943379	16191	Economy	7500.00
0005434943435	16191	Economy	7500.00
0005434943369	16191	Economy	7500.00
0005434943391	16191	Economy	7500.00
0005434943338	16191	Economy	7500.00
0005434943339	16191	Economy	7500.00
0005434943376	16191	Economy	7500.00
0005434943408	16191	Economy	7500.00
0005433255184	16191	Economy	7500.00
0005433255186	16191	Economy	7500.00
0005434943383	16191	Economy	7500.00
0005433255188	16191	Economy	7500.00
0005433255187	16191	Economy	7500.00
0005433367898	21727	Business	9800.00
0005433367883	21727	Business	9800.00
0005435653566	21727	Business	9800.00
0005433367917	21727	Business	9800.00
0005433368001	21727	Business	9800.00
0005435653560	21727	Business	9800.00
0005435653574	21727	Business	9800.00
0005435653571	21727	Business	9800.00
0005433368040	21727	Economy	3300.00
0005433367968	21727	Economy	3300.00
0005433367916	21727	Economy	3300.00
0005435653584	21727	Economy	3300.00
0005433367901	21727	Economy	3300.00
0005435653579	21727	Economy	3300.00
0005435653559	21727	Economy	3300.00
0005435653583	21727	Economy	3600.00
0005433367974	21727	Economy	3600.00
0005435653572	21727	Economy	3600.00
0005435653586	21727	Economy	3600.00
0005435653587	21727	Economy	3300.00
0005435653570	21727	Economy	3300.00
0005435653558	21727	Economy	3300.00
0005435653580	21727	Economy	3300.00
0005433368004	21727	Economy	3300.00
0005435653582	21727	Economy	3300.00
0005435653563	21727	Economy	3300.00
0005433368093	21727	Economy	3300.00
0005435653573	21727	Economy	3300.00
0005435653575	21727	Economy	3300.00
0005433367963	21727	Economy	3300.00
0005435653588	21727	Economy	3300.00
0005435653576	21727	Economy	3300.00
0005435653590	21727	Economy	3300.00
0005433367988	21727	Economy	3300.00
0005435653565	21727	Economy	3300.00
0005433367806	21727	Economy	3300.00
0005433368028	21727	Economy	3300.00
0005433367964	21727	Economy	3300.00
0005435653577	21727	Economy	3300.00
0005433367927	21727	Economy	3300.00
0005433367900	21727	Economy	3300.00
0005433368048	21727	Economy	3300.00
0005435653557	21727	Economy	3300.00
0005433367969	21727	Economy	3300.00
0005433367922	21727	Economy	3300.00
0005433367905	21727	Economy	3300.00
0005433367962	21727	Economy	3300.00
0005435653585	21727	Economy	3300.00
0005435653562	21727	Economy	3300.00
0005435653581	21727	Economy	3300.00
0005435653569	21727	Economy	3300.00
0005435653564	21727	Economy	3300.00
0005433368014	21727	Economy	3300.00
0005433368091	21727	Economy	3300.00
0005435653561	21727	Economy	3300.00
0005433367944	21727	Economy	3300.00
0005433367899	21727	Economy	3300.00
0005433367875	21727	Economy	3300.00
0005435653589	21727	Economy	3300.00
0005435653591	21727	Economy	3300.00
0005435653568	21727	Economy	3300.00
0005433368088	21727	Economy	3300.00
0005435653578	21727	Economy	3300.00
0005435653567	21727	Economy	3300.00
0005433367948	21727	Economy	3300.00
0005433368000	21727	Economy	3300.00
0005433367908	21727	Economy	3300.00
0005433368092	21727	Economy	3300.00
0005433368049	21727	Economy	3300.00
0005435653592	21727	Economy	3300.00
0005433368087	21727	Economy	3300.00
0005433367919	21727	Economy	3300.00
0005433763385	9373	Business	186200.00
0005433805818	9373	Business	186200.00
0005432657488	9373	Business	186200.00
0005432667479	9373	Business	186200.00
0005433805817	9373	Business	186200.00
0005433805797	9373	Business	186200.00
0005433763390	9373	Business	186200.00
0005434171124	9373	Business	186200.00
0005433805815	9373	Business	186200.00
0005433805801	9373	Business	186200.00
0005432665300	9373	Business	186200.00
0005435269751	9373	Business	186200.00
0005433805804	9373	Business	186200.00
0005433805792	9373	Business	186200.00
0005434151714	9373	Business	186200.00
0005434171076	9373	Business	186200.00
0005433785406	9373	Business	186200.00
0005434151717	9373	Business	186200.00
0005433763391	9373	Economy	62100.00
0005433785382	9373	Economy	62100.00
0005433805806	9373	Economy	62100.00
0005432666414	9373	Economy	62100.00
0005433763377	9373	Economy	62100.00
0005433805796	9373	Economy	62100.00
0005433785407	9373	Economy	62100.00
0005433785399	9373	Economy	62100.00
0005435269755	9373	Economy	62100.00
0005433785388	9373	Economy	62100.00
0005434171161	9373	Economy	62100.00
0005433805812	9373	Economy	62100.00
0005433785395	9373	Economy	62100.00
0005434171084	9373	Economy	62100.00
0005433805807	9373	Economy	62100.00
0005433785398	9373	Economy	62100.00
0005435269761	9373	Economy	62100.00
0005435269754	9373	Economy	62100.00
0005435269756	9373	Economy	62100.00
0005434171121	9373	Economy	62100.00
0005433785377	9373	Economy	62100.00
0005433785410	9373	Economy	62100.00
0005433785409	9373	Economy	62100.00
0005433785404	9373	Economy	62100.00
0005435269747	9373	Economy	62100.00
0005433785376	9373	Economy	62100.00
0005433805809	9373	Economy	62100.00
0005434171083	9373	Economy	62100.00
0005434171105	9373	Economy	62100.00
0005432667478	9373	Economy	62100.00
0005434171173	9373	Economy	62100.00
0005435269749	9373	Economy	62100.00
0005434171174	9373	Economy	62100.00
0005432657487	9373	Economy	62100.00
0005433785401	9373	Economy	62100.00
0005433785380	9373	Economy	62100.00
0005433805794	9373	Economy	62100.00
0005434151716	9373	Economy	62100.00
0005432666413	9373	Economy	62100.00
0005434171119	9373	Economy	62100.00
0005433785389	9373	Economy	62100.00
0005433805799	9373	Economy	62100.00
0005434171082	9373	Economy	62100.00
0005434270222	9373	Economy	62100.00
0005433805805	9373	Economy	62100.00
0005434270221	9373	Economy	62100.00
0005433805810	9373	Economy	62100.00
0005433805802	9373	Economy	62100.00
0005433763388	9373	Economy	62100.00
0005433805791	9373	Economy	62100.00
0005434171086	9373	Economy	62100.00
0005435269748	9373	Economy	62100.00
0005434171077	9373	Economy	62100.00
0005433763382	9373	Economy	62100.00
0005433785392	9373	Economy	62100.00
0005433785391	9373	Economy	62100.00
0005433785387	9373	Economy	62100.00
0005433805793	9373	Economy	62100.00
0005433763387	9373	Economy	62100.00
0005433785405	9373	Economy	62100.00
0005433785378	9373	Economy	62100.00
0005435269750	9373	Economy	62100.00
0005433785400	9373	Economy	62100.00
0005433763378	9373	Economy	62100.00
0005433785403	9373	Economy	62100.00
0005433785383	9373	Economy	62100.00
0005435269762	9373	Economy	62100.00
0005433805795	9373	Economy	62100.00
0005432657485	9373	Economy	68300.00
0005433785385	9373	Economy	62100.00
0005433805816	9373	Economy	62100.00
0005433805800	9373	Economy	68300.00
0005432665301	9373	Economy	68300.00
0005434171122	9373	Economy	62100.00
0005434171108	9373	Economy	62100.00
0005433805813	9373	Economy	62100.00
0005434171085	9373	Economy	62100.00
0005433805820	9373	Economy	62100.00
0005433805819	9373	Economy	62100.00
0005434151709	9373	Economy	62100.00
0005433785390	9373	Economy	62100.00
0005433805814	9373	Economy	62100.00
0005433763383	9373	Economy	62100.00
0005433763381	9373	Economy	62100.00
0005433805808	9373	Economy	62100.00
0005433763384	9373	Economy	62100.00
0005433785397	9373	Economy	62100.00
0005433805790	9373	Economy	62100.00
0005433805811	9373	Economy	62100.00
0005433805803	9373	Economy	62100.00
0005433785375	9373	Economy	62100.00
0005434171120	9373	Economy	62100.00
0005433763386	9373	Economy	62100.00
0005433785394	9373	Economy	62100.00
0005433785402	9373	Economy	62100.00
0005432657489	9373	Economy	62100.00
0005434171081	9373	Economy	62100.00
0005433785408	9373	Economy	62100.00
0005433763389	9373	Economy	62100.00
0005433805822	9373	Economy	62100.00
0005432657486	9373	Economy	62100.00
0005432665299	9373	Economy	62100.00
0005435269746	9373	Economy	62100.00
0005435269752	9373	Economy	62100.00
0005433763380	9373	Economy	62100.00
0005433785393	9373	Economy	62100.00
0005433805798	9373	Economy	62100.00
0005433785384	9373	Economy	62100.00
0005434151715	9373	Economy	62100.00
0005433785386	9373	Economy	62100.00
0005433805821	9373	Economy	62100.00
0005433785396	9373	Economy	62100.00
0005433805789	9373	Economy	62100.00
0005433785381	9373	Economy	62100.00
0005434171101	9373	Economy	62100.00
0005433785379	9373	Economy	62100.00
0005433763379	9373	Economy	62100.00
0005435269753	9373	Economy	62100.00
0005433763260	26250	Business	186200.00
0005433785162	26250	Business	186200.00
0005433805577	26250	Business	186200.00
0005433785012	26250	Business	186200.00
0005432657463	26250	Business	186200.00
0005432657455	26250	Business	186200.00
0005432657457	26250	Business	186200.00
0005433763246	26250	Business	186200.00
0005435269849	26250	Business	186200.00
0005433805561	26250	Business	186200.00
0005435269842	26250	Business	186200.00
0005433785244	26250	Business	186200.00
0005434269127	26250	Business	186200.00
0005433805391	26250	Business	186200.00
0005433785000	26250	Business	186200.00
0005433763245	26250	Business	186200.00
0005435269841	26250	Business	186200.00
0005434171229	26250	Business	186200.00
0005433785113	26250	Economy	68300.00
0005433785155	26250	Economy	62100.00
0005433805451	26250	Economy	62100.00
0005433785051	26250	Economy	62100.00
0005435269846	26250	Economy	62100.00
0005434171227	26250	Economy	62100.00
0005433763253	26250	Economy	62100.00
0005433785110	26250	Economy	62100.00
0005433805486	26250	Economy	62100.00
0005433763261	26250	Economy	62100.00
0005434151739	26250	Economy	62100.00
0005433785125	26250	Economy	62100.00
0005433763254	26250	Economy	62100.00
0005433805579	26250	Economy	62100.00
0005433805569	26250	Economy	62100.00
0005433805494	26250	Economy	62100.00
0005434171232	26250	Economy	62100.00
0005433805540	26250	Economy	62100.00
0005433784953	26250	Economy	62100.00
0005435269854	26250	Economy	62100.00
0005433784876	26250	Economy	62100.00
0005433785111	26250	Economy	62100.00
0005433763268	26250	Economy	62100.00
0005433763285	26250	Economy	62100.00
0005433805242	26250	Economy	62100.00
0005433805426	26250	Economy	62100.00
0005433805643	26250	Economy	62100.00
0005433785124	26250	Economy	62100.00
0005434171230	26250	Economy	62100.00
0005433784952	26250	Economy	62100.00
0005434271336	26250	Economy	62100.00
0005434271335	26250	Economy	62100.00
0005435269840	26250	Economy	62100.00
0005433785004	26250	Economy	62100.00
0005434171224	26250	Economy	62100.00
0005433805541	26250	Economy	62100.00
0005433805544	26250	Economy	62100.00
0005435269845	26250	Economy	62100.00
0005433784998	26250	Economy	62100.00
0005434171233	26250	Economy	62100.00
0005435269853	26250	Economy	62100.00
0005432666400	26250	Economy	62100.00
0005434269128	26250	Economy	62100.00
0005433805379	26250	Economy	62100.00
0005433805424	26250	Economy	62100.00
0005433805514	26250	Economy	62100.00
0005433805492	26250	Economy	62100.00
0005432666391	26250	Economy	62100.00
0005433805593	26250	Economy	62100.00
0005434270229	26250	Economy	62100.00
0005434171235	26250	Economy	62100.00
0005433763286	26250	Economy	62100.00
0005433785038	26250	Economy	62100.00
0005433785086	26250	Economy	62100.00
0005434171228	26250	Economy	62100.00
0005435269847	26250	Economy	62100.00
0005433805570	26250	Economy	62100.00
0005433763256	26250	Economy	62100.00
0005433785097	26250	Economy	62100.00
0005433785112	26250	Economy	62100.00
0005435269852	26250	Economy	62100.00
0005433785133	26250	Economy	62100.00
0005433785044	26250	Economy	62100.00
0005434171234	26250	Economy	62100.00
0005435269844	26250	Economy	62100.00
0005433784986	26250	Economy	62100.00
0005433763279	26250	Economy	62100.00
0005433805485	26250	Economy	62100.00
0005433785141	26250	Economy	62100.00
0005433785134	26250	Economy	68300.00
0005433784999	26250	Economy	68300.00
0005433785050	26250	Economy	62100.00
0005433785079	26250	Economy	62100.00
0005433763244	26250	Economy	62100.00
0005433805459	26250	Economy	68300.00
0005435269850	26250	Economy	68300.00
0005433785121	26250	Economy	62100.00
0005433785116	26250	Economy	62100.00
0005433785164	26250	Economy	62100.00
0005433805600	26250	Economy	62100.00
0005433785115	26250	Economy	62100.00
0005433805495	26250	Economy	62100.00
0005433785144	26250	Economy	62100.00
0005433763216	26250	Economy	62100.00
0005433805411	26250	Economy	62100.00
0005433805450	26250	Economy	62100.00
0005433785136	26250	Economy	62100.00
0005434171236	26250	Economy	62100.00
0005433785120	26250	Economy	62100.00
0005434171223	26250	Economy	62100.00
0005433763255	26250	Economy	62100.00
0005433784987	26250	Economy	62100.00
0005433805580	26250	Economy	62100.00
0005433805613	26250	Economy	62100.00
0005433785043	26250	Economy	62100.00
0005433785011	26250	Economy	62100.00
0005433805560	26250	Economy	62100.00
0005434269126	26250	Economy	62100.00
0005433785005	26250	Economy	62100.00
0005433785151	26250	Economy	62100.00
0005433805648	26250	Economy	62100.00
0005434171226	26250	Economy	62100.00
0005433805489	26250	Economy	62100.00
0005433805487	26250	Economy	62100.00
0005434151738	26250	Economy	62100.00
0005434171225	26250	Economy	62100.00
0005435269843	26250	Economy	62100.00
0005433785216	26250	Economy	62100.00
0005433805592	26250	Economy	62100.00
0005434270230	26250	Economy	62100.00
0005433785006	26250	Economy	62100.00
0005433785098	26250	Economy	62100.00
0005433805423	26250	Economy	62100.00
0005433805601	26250	Economy	62100.00
0005433805488	26250	Economy	62100.00
0005434171231	26250	Economy	62100.00
0005435269848	26250	Economy	62100.00
0005433805515	26250	Economy	62100.00
0005433805447	26250	Economy	62100.00
0005433785117	26250	Economy	62100.00
0005433805578	26250	Economy	62100.00
0005433784949	26250	Economy	62100.00
0005433805543	26250	Economy	62100.00
0005435269851	26250	Economy	62100.00
0005434151740	26250	Economy	62100.00
0005433785049	26250	Economy	62100.00
0005435135731	4878	Economy	5300.00
0005435135729	4878	Economy	5300.00
0005435135732	4878	Economy	5300.00
0005435135730	4878	Economy	5300.00
0005435929662	4878	Economy	5300.00
0005435135694	33036	Economy	5900.00
0005435135700	33036	Economy	5300.00
0005435135699	33036	Economy	5300.00
0005435135693	33036	Economy	5300.00
0005435929676	33036	Economy	5300.00
0005435929677	33036	Economy	5300.00
0005435135705	33036	Economy	5300.00
0005435135697	33036	Economy	5300.00
0005435135698	33036	Economy	5300.00
0005434983351	9476	Economy	17900.00
0005434217989	9476	Economy	17900.00
0005434983352	9476	Economy	17900.00
0005434217997	9476	Economy	17900.00
0005434983350	9476	Economy	17900.00
0005434217988	9476	Economy	17900.00
0005434983348	9476	Economy	17900.00
0005434983349	9476	Economy	17900.00
0005434218019	27350	Economy	19700.00
0005434983319	27350	Economy	17900.00
0005434983327	27350	Economy	17900.00
0005434983311	27350	Economy	17900.00
0005434983317	27350	Economy	17900.00
0005434983318	27350	Economy	17900.00
0005434983326	27350	Economy	17900.00
0005434983323	27350	Economy	17900.00
0005434218017	27350	Economy	17900.00
0005434218018	27350	Economy	17900.00
0005434983324	27350	Economy	17900.00
0005434218020	27350	Economy	17900.00
0005434983340	27350	Economy	17900.00
0005433960869	24236	Business	36400.00
0005433986223	24236	Business	36400.00
0005433985948	24236	Business	36400.00
0005433986090	24236	Business	36400.00
0005433986133	24236	Business	36400.00
0005433961090	24236	Business	36400.00
0005433961106	24236	Business	36400.00
0005433961059	24236	Business	36400.00
0005433986139	24236	Business	36400.00
0005433986159	24236	Business	36400.00
0005433986132	24236	Business	36400.00
0005433960966	24236	Business	36400.00
0005433960944	24236	Business	36400.00
0005433986098	24236	Business	36400.00
0005433960911	24236	Business	36400.00
0005433985997	24236	Business	36400.00
0005433961025	24236	Economy	13400.00
0005433961013	24236	Economy	13400.00
0005433986126	24236	Economy	13400.00
0005433986142	24236	Economy	12100.00
0005433986071	24236	Economy	13400.00
0005433986049	24236	Economy	12100.00
0005433985840	24236	Economy	12100.00
0005433985975	24236	Economy	12100.00
0005433961027	24236	Economy	12100.00
0005433960831	24236	Economy	12100.00
0005433960891	24236	Economy	12100.00
0005433986057	24236	Economy	12100.00
0005433986064	24236	Economy	12100.00
0005433961011	24236	Economy	12100.00
0005433986028	24236	Economy	12100.00
0005433961081	24236	Economy	12100.00
0005433985961	24236	Economy	12100.00
0005433961050	24236	Economy	12100.00
0005433960991	24236	Economy	12100.00
0005433961075	24236	Economy	12100.00
0005433986050	24236	Economy	12100.00
0005433986072	24236	Economy	12100.00
0005433961088	24236	Economy	12100.00
0005433960949	24236	Economy	12100.00
0005433985960	24236	Economy	12100.00
0005433960978	24236	Economy	12100.00
0005433986160	24236	Economy	12100.00
0005433960995	24236	Economy	12100.00
0005433960958	24236	Economy	12100.00
0005433960890	24236	Economy	12100.00
0005433986106	24236	Economy	12100.00
0005433960855	24236	Economy	12100.00
0005433961058	24236	Economy	12100.00
0005433986194	24236	Economy	12100.00
0005433960898	24236	Economy	12100.00
0005433985991	24236	Economy	12100.00
0005433986027	24236	Economy	12100.00
0005433986192	24236	Economy	12100.00
0005433986026	24236	Economy	12100.00
0005433960905	24236	Economy	12100.00
0005433986104	24236	Economy	12100.00
0005433986054	24236	Economy	12100.00
0005433986102	24236	Economy	12100.00
0005433960897	24236	Economy	12100.00
0005433960881	24236	Economy	12100.00
0005433960830	24236	Economy	12100.00
0005433961030	24236	Economy	12100.00
0005433986124	24236	Economy	12100.00
0005433960969	24236	Economy	12100.00
0005433986164	24236	Economy	12100.00
0005433961012	24236	Economy	12100.00
0005433960992	24236	Economy	12100.00
0005433985861	24236	Economy	12100.00
0005433986165	24236	Economy	12100.00
0005433961005	24236	Economy	12100.00
0005433961009	24236	Economy	12100.00
0005433986140	24236	Economy	12100.00
0005433985949	24236	Economy	12100.00
0005433961089	24236	Economy	12100.00
0005433986065	24236	Economy	12100.00
0005433961003	24236	Economy	12100.00
0005433986056	24236	Economy	13400.00
0005433986163	24236	Economy	13400.00
0005433961024	24236	Economy	12100.00
0005433985939	24236	Economy	12100.00
0005433986097	24236	Economy	13400.00
0005433961091	24236	Economy	12100.00
0005433961060	24236	Economy	12100.00
0005433960997	24236	Economy	12100.00
0005433960965	24236	Economy	12100.00
0005433961055	24236	Economy	12100.00
0005433960896	24236	Economy	12100.00
0005433986141	24236	Economy	12100.00
0005433960892	24236	Economy	12100.00
0005433961026	24236	Economy	12100.00
0005433985955	24236	Economy	12100.00
0005433961092	24236	Economy	12100.00
0005433961004	24236	Economy	12100.00
0005433960951	24236	Economy	12100.00
0005433961049	24236	Economy	12100.00
0005433985860	24236	Economy	12100.00
0005433986116	24236	Economy	12100.00
0005433986158	24236	Economy	12100.00
0005433986070	24236	Economy	12100.00
0005433960910	24236	Economy	12100.00
0005433986075	24236	Economy	12100.00
0005433960750	24236	Economy	12100.00
0005433986162	24236	Economy	12100.00
0005433960908	24236	Economy	12100.00
0005433986003	24236	Economy	12100.00
0005433986055	24236	Economy	12100.00
0005433961008	24236	Economy	12100.00
0005433960793	24236	Economy	12100.00
0005433986125	24236	Economy	12100.00
0005433961031	24236	Economy	12100.00
0005433986073	24236	Economy	12100.00
0005433960996	24236	Economy	12100.00
0005433986025	24236	Economy	12100.00
0005433985974	24236	Economy	12100.00
0005433986105	24236	Economy	12100.00
0005433960979	24236	Economy	12100.00
0005433961017	24236	Economy	12100.00
0005433961028	24236	Economy	12100.00
0005433986157	24236	Economy	12100.00
0005433961086	24236	Economy	12100.00
0005433961023	24236	Economy	12100.00
0005433960994	24236	Economy	12100.00
0005433960945	24236	Economy	12100.00
0005433986222	24236	Economy	12100.00
0005433960751	24236	Economy	12100.00
0005433961082	24236	Economy	12100.00
0005433986117	24236	Economy	12100.00
0005433961528	25907	Business	36400.00
0005433986499	25907	Business	36400.00
0005433986478	25907	Business	36400.00
0005433986469	25907	Business	36400.00
0005433961501	25907	Business	36400.00
0005433986492	25907	Business	36400.00
0005433986486	25907	Business	36400.00
0005433961520	25907	Business	36400.00
0005433986491	25907	Business	36400.00
0005433986479	25907	Business	36400.00
0005433961495	25907	Business	36400.00
0005433961513	25907	Economy	13400.00
0005433986504	25907	Economy	12100.00
0005433961516	25907	Economy	12100.00
0005433961488	25907	Economy	12100.00
0005433986496	25907	Economy	12100.00
0005433961487	25907	Economy	12100.00
0005433961514	25907	Economy	12100.00
0005433961529	25907	Economy	12100.00
0005433961517	25907	Economy	12100.00
0005433986466	25907	Economy	12100.00
0005433961502	25907	Economy	12100.00
0005433961506	25907	Economy	12100.00
0005433986473	25907	Economy	12100.00
0005433986493	25907	Economy	12100.00
0005433961523	25907	Economy	12100.00
0005433986482	25907	Economy	12100.00
0005433986501	25907	Economy	12100.00
0005433961512	25907	Economy	12100.00
0005433986467	25907	Economy	12100.00
0005433986463	25907	Economy	12100.00
0005433986498	25907	Economy	12100.00
0005433961503	25907	Economy	12100.00
0005433986470	25907	Economy	12100.00
0005433986483	25907	Economy	12100.00
0005433961499	25907	Economy	12100.00
0005433961511	25907	Economy	12100.00
0005433986461	25907	Economy	12100.00
0005433986462	25907	Economy	12100.00
0005433961504	25907	Economy	12100.00
0005433986497	25907	Economy	12100.00
0005433986503	25907	Economy	12100.00
0005433961526	25907	Economy	12100.00
0005433986472	25907	Economy	12100.00
0005433961518	25907	Economy	12100.00
0005433986460	25907	Economy	12100.00
0005433961496	25907	Economy	12100.00
0005433986477	25907	Economy	12100.00
0005433961521	25907	Economy	12100.00
0005433961494	25907	Economy	12100.00
0005433961498	25907	Economy	12100.00
0005433961493	25907	Economy	12100.00
0005433961530	25907	Economy	12100.00
0005433986490	25907	Economy	12100.00
0005433961490	25907	Economy	12100.00
0005433961525	25907	Economy	13400.00
0005433986468	25907	Economy	12100.00
0005433986484	25907	Economy	13400.00
0005433961519	25907	Economy	13400.00
0005433986500	25907	Economy	12100.00
0005433986485	25907	Economy	12100.00
0005433986480	25907	Economy	12100.00
0005433961497	25907	Economy	12100.00
0005433986459	25907	Economy	12100.00
0005433961515	25907	Economy	12100.00
0005433986476	25907	Economy	12100.00
0005433986487	25907	Economy	12100.00
0005433986495	25907	Economy	12100.00
0005433961505	25907	Economy	12100.00
0005433961492	25907	Economy	12100.00
0005433986481	25907	Economy	12100.00
0005433986471	25907	Economy	12100.00
0005433961500	25907	Economy	12100.00
0005433961531	25907	Economy	12100.00
0005433986502	25907	Economy	12100.00
0005433986465	25907	Economy	12100.00
0005433961491	25907	Economy	12100.00
0005433961509	25907	Economy	12100.00
0005433986474	25907	Economy	12100.00
0005433986505	25907	Economy	12100.00
0005433986489	25907	Economy	12100.00
0005433961507	25907	Economy	12100.00
0005433961508	25907	Economy	12100.00
0005433986464	25907	Economy	12100.00
0005433986494	25907	Economy	12100.00
0005433961510	25907	Economy	12100.00
0005433961489	25907	Economy	12100.00
0005433986488	25907	Economy	12100.00
0005433961524	25907	Economy	12100.00
0005433961522	25907	Economy	12100.00
0005433961527	25907	Economy	12100.00
0005433986475	25907	Economy	12100.00
0005433165951	971	Economy	25400.00
0005433165993	971	Economy	25400.00
0005434480630	971	Economy	25400.00
0005433165892	971	Economy	25400.00
0005432269529	971	Economy	23100.00
0005434480651	971	Economy	23100.00
0005434480633	971	Economy	23100.00
0005434480635	971	Economy	23100.00
0005434480644	971	Economy	23100.00
0005433165911	971	Economy	23100.00
0005433165950	971	Economy	23100.00
0005434480648	971	Economy	23100.00
0005433165948	971	Economy	23100.00
0005434480649	971	Economy	23100.00
0005433165893	971	Economy	23100.00
0005434480650	971	Economy	23100.00
0005433165936	971	Economy	23100.00
0005434480631	971	Economy	23100.00
0005434480638	971	Economy	23100.00
0005434480632	971	Economy	23100.00
0005434480639	971	Economy	23100.00
0005433166009	971	Economy	23100.00
0005434480645	971	Economy	23100.00
0005434480628	971	Economy	23100.00
0005434480647	971	Economy	23100.00
0005434480642	971	Economy	23100.00
0005434480629	971	Economy	23100.00
0005433165982	971	Economy	23100.00
0005434480643	971	Economy	23100.00
0005434480627	971	Economy	23100.00
0005434480652	971	Economy	23100.00
0005433165981	971	Economy	23100.00
0005434480637	971	Economy	23100.00
0005434480641	971	Economy	23100.00
0005433165989	971	Economy	23100.00
0005433165912	971	Economy	23100.00
0005433165955	971	Economy	23100.00
0005433166010	971	Economy	23100.00
0005434480636	971	Economy	23100.00
0005432269530	971	Economy	23100.00
0005434480634	971	Economy	23100.00
0005433165949	971	Economy	23100.00
0005433165894	971	Economy	23100.00
0005434480640	971	Economy	23100.00
0005434480653	971	Economy	23100.00
0005433165952	971	Economy	23100.00
0005432269528	971	Economy	23100.00
0005433166000	971	Economy	23100.00
0005433165956	971	Economy	23100.00
0005434480646	971	Economy	23100.00
0005433166068	16564	Economy	25400.00
0005434480418	16564	Economy	25400.00
0005433166059	16564	Economy	25400.00
0005434480377	16564	Economy	23100.00
0005434480489	16564	Economy	23100.00
0005433166060	16564	Economy	23100.00
0005434480270	16564	Economy	23100.00
0005434480429	16564	Economy	23100.00
0005434480504	16564	Economy	23100.00
0005433166058	16564	Economy	23100.00
0005434480456	16564	Economy	23100.00
0005433166064	16564	Economy	23100.00
0005434480547	16564	Economy	23100.00
0005434480459	16564	Economy	23100.00
0005433166065	16564	Economy	23100.00
0005434480428	16564	Economy	23100.00
0005433166067	16564	Economy	23100.00
0005434480380	16564	Economy	23100.00
0005433166066	16564	Economy	23100.00
0005434480341	16564	Economy	23100.00
0005433166062	16564	Economy	23100.00
0005434480503	16564	Economy	23100.00
0005433166057	16564	Economy	23100.00
0005433166070	16564	Economy	23100.00
0005434480353	16564	Economy	23100.00
0005434480497	16564	Economy	23100.00
0005434480463	16564	Economy	23100.00
0005433166063	16564	Economy	23100.00
0005434480404	16564	Economy	23100.00
0005434480438	16564	Economy	23100.00
0005434480352	16564	Economy	23100.00
0005434480465	16564	Economy	23100.00
0005433166069	16564	Economy	23100.00
0005434480464	16564	Economy	23100.00
0005434480361	16564	Economy	23100.00
0005434480413	16564	Economy	23100.00
0005434480462	16564	Economy	23100.00
0005434480416	16564	Economy	23100.00
0005433166061	16564	Economy	23100.00
0005434480498	16564	Economy	23100.00
0005433289898	10358	Economy	17000.00
0005435142732	10358	Economy	17000.00
0005433289893	10358	Economy	17000.00
0005435150187	10358	Economy	17000.00
0005435150181	10358	Economy	15400.00
0005435142727	10358	Economy	15400.00
0005435142737	10358	Economy	15400.00
0005435150179	10358	Economy	15400.00
0005435386579	10358	Economy	15400.00
0005433289900	10358	Economy	15400.00
0005435142735	10358	Economy	15400.00
0005435142728	10358	Economy	15400.00
0005433289839	10358	Economy	15400.00
0005435386605	10358	Economy	15400.00
0005435386619	10358	Economy	15400.00
0005435150184	10358	Economy	15400.00
0005435150185	10358	Economy	15400.00
0005435150188	10358	Economy	15400.00
0005435150190	10358	Economy	15400.00
0005435150192	10358	Economy	15400.00
0005435150183	10358	Economy	15400.00
0005433289899	10358	Economy	15400.00
0005435150180	10358	Economy	15400.00
0005435150189	10358	Economy	15400.00
0005435142725	10358	Economy	15400.00
0005435386600	10358	Economy	15400.00
0005435142734	10358	Economy	15400.00
0005435386599	10358	Economy	15400.00
0005433289878	10358	Economy	15400.00
0005435142726	10358	Economy	15400.00
0005435150186	10358	Economy	15400.00
0005435142729	10358	Economy	15400.00
0005435142724	10358	Economy	15400.00
0005435150191	10358	Economy	15400.00
0005435142731	10358	Economy	15400.00
0005435386620	10358	Economy	15400.00
0005435150182	10358	Economy	15400.00
0005433289840	10358	Economy	15400.00
0005433289877	10358	Economy	15400.00
0005433289875	10358	Economy	15400.00
0005435142733	10358	Economy	15400.00
0005435142736	10358	Economy	15400.00
0005435142730	10358	Economy	15400.00
0005433289880	10358	Economy	15400.00
0005433289879	10358	Economy	15400.00
0005433289876	10358	Economy	15400.00
0005435150178	10358	Economy	15400.00
0005433289894	10358	Economy	15400.00
0005435150021	21966	Economy	17000.00
0005435142619	21966	Economy	17000.00
0005435150065	21966	Economy	17000.00
0005435142642	21966	Economy	17000.00
0005435142667	21966	Economy	15400.00
0005435150085	21966	Economy	15400.00
0005435150020	21966	Economy	15400.00
0005435150061	21966	Economy	15400.00
0005433289946	21966	Economy	15400.00
0005435142620	21966	Economy	15400.00
0005435142595	21966	Economy	15400.00
0005433289943	21966	Economy	15400.00
0005435150052	21966	Economy	15400.00
0005433289944	21966	Economy	15400.00
0005435150049	21966	Economy	15400.00
0005435150046	21966	Economy	15400.00
0005435142621	21966	Economy	15400.00
0005435150073	21966	Economy	15400.00
0005435142645	21966	Economy	15400.00
0005435142548	21966	Economy	15400.00
0005435142594	21966	Economy	15400.00
0005435142651	21966	Economy	15400.00
0005435142628	21966	Economy	15400.00
0005435142618	21966	Economy	15400.00
0005435150069	21966	Economy	15400.00
0005435150071	21966	Economy	15400.00
0005435150070	21966	Economy	15400.00
0005433289941	21966	Economy	15400.00
0005435150068	21966	Economy	15400.00
0005435150029	21966	Economy	15400.00
0005435142650	21966	Economy	15400.00
0005433289942	21966	Economy	15400.00
0005433289947	21966	Economy	15400.00
0005435150048	21966	Economy	15400.00
0005433289940	21966	Economy	15400.00
0005433289945	21966	Economy	15400.00
0005435150062	21966	Economy	15400.00
0005435150077	21966	Economy	15400.00
0005435150032	21966	Economy	15400.00
0005435150074	21966	Economy	15400.00
0005435150078	21966	Economy	15400.00
0005435142656	21966	Economy	15400.00
0005435150072	21966	Economy	15400.00
0005435142597	21966	Economy	15400.00
0005435150031	21966	Economy	15400.00
0005435150045	21966	Economy	15400.00
0005435142643	21966	Economy	15400.00
0005435142599	21966	Economy	15400.00
0005435142596	21966	Economy	15400.00
0005433289939	21966	Economy	15400.00
0005435545752	11235	Business	57200.00
0005435502420	11235	Business	57200.00
0005434573510	11235	Business	57200.00
0005435529326	11235	Business	57200.00
0005435502495	11235	Business	57200.00
0005435529365	11235	Business	57200.00
0005435502346	11235	Business	57200.00
0005435502345	11235	Business	57200.00
0005434573513	11235	Economy	19100.00
0005435545754	11235	Economy	19100.00
0005435529360	11235	Economy	19100.00
0005434573514	11235	Economy	19100.00
0005434573511	11235	Economy	19100.00
0005435319622	11235	Economy	19100.00
0005435502402	11235	Economy	21000.00
0005435502341	11235	Economy	21000.00
0005434573512	11235	Economy	21000.00
0005435529277	11235	Economy	21000.00
0005435502406	11235	Economy	21000.00
0005435529337	11235	Economy	19100.00
0005435529308	11235	Economy	19100.00
0005435529329	11235	Economy	19100.00
0005435529290	11235	Economy	19100.00
0005435502437	11235	Economy	19100.00
0005435502494	11235	Economy	19100.00
0005435319590	11235	Economy	19100.00
0005435529309	11235	Economy	19100.00
0005434573508	11235	Economy	19100.00
0005434573509	11235	Economy	19100.00
0005435319594	11235	Economy	19100.00
0005435319592	11235	Economy	19100.00
0005435529279	11235	Economy	19100.00
0005434573505	11235	Economy	19100.00
0005435529300	11235	Economy	19100.00
0005435502374	11235	Economy	19100.00
0005435502460	11235	Economy	19100.00
0005435502342	11235	Economy	19100.00
0005435529361	11235	Economy	19100.00
0005435545768	11235	Economy	19100.00
0005435502435	11235	Economy	19100.00
0005435502459	11235	Economy	19100.00
0005435529364	11235	Economy	19100.00
0005434573519	11235	Economy	19100.00
0005435319579	11235	Economy	19100.00
0005435529382	11235	Economy	19100.00
0005435529291	11235	Economy	19100.00
0005435545781	11235	Economy	19100.00
0005434573517	11235	Economy	19100.00
0005435502338	11235	Economy	19100.00
0005435502485	11235	Economy	19100.00
0005434573507	11235	Economy	19100.00
0005435545783	11235	Economy	19100.00
0005434573515	11235	Economy	19100.00
0005434573516	11235	Economy	19100.00
0005435545780	11235	Economy	19100.00
0005435529272	11235	Economy	19100.00
0005435545769	11235	Economy	19100.00
0005435502349	11235	Economy	19100.00
0005435502291	11235	Economy	19100.00
0005435529386	11235	Economy	19100.00
0005435545748	11235	Economy	19100.00
0005434573518	11235	Economy	19100.00
0005434573506	11235	Economy	19100.00
0005435545753	11235	Economy	19100.00
0005435529280	11235	Economy	19100.00
0005435529336	11235	Economy	19100.00
0005435508492	20952	Business	57200.00
0005435502572	20952	Business	57200.00
0005434573412	20952	Business	57200.00
0005434573413	20952	Business	57200.00
0005434573399	20952	Business	57200.00
0005435502567	20952	Business	57200.00
0005432291959	20952	Business	57200.00
0005435319694	20952	Business	57200.00
0005435508487	20952	Business	57200.00
0005435502568	20952	Business	57200.00
0005434573421	20952	Business	57200.00
0005435502558	20952	Business	57200.00
0005435518128	20952	Economy	19100.00
0005435502555	20952	Economy	19100.00
0005434573425	20952	Economy	19100.00
0005435518129	20952	Economy	19100.00
0005435518124	20952	Economy	19100.00
0005435502565	20952	Economy	19100.00
0005435502573	20952	Economy	19100.00
0005435502566	20952	Economy	21000.00
0005435518130	20952	Economy	21000.00
0005435518131	20952	Economy	21000.00
0005434573369	20952	Economy	21000.00
0005435518127	20952	Economy	19100.00
0005435502559	20952	Economy	19100.00
0005435319691	20952	Economy	19100.00
0005435502569	20952	Economy	19100.00
0005435518119	20952	Economy	19100.00
0005435502561	20952	Economy	19100.00
0005434573419	20952	Economy	19100.00
0005434573445	20952	Economy	19100.00
0005435502570	20952	Economy	19100.00
0005435508485	20952	Economy	19100.00
0005435502553	20952	Economy	19100.00
0005435319686	20952	Economy	19100.00
0005434573424	20952	Economy	19100.00
0005435508489	20952	Economy	19100.00
0005434573400	20952	Economy	19100.00
0005435502563	20952	Economy	19100.00
0005435518118	20952	Economy	19100.00
0005435518133	20952	Economy	19100.00
0005435502560	20952	Economy	19100.00
0005435508491	20952	Economy	19100.00
0005434573414	20952	Economy	19100.00
0005435319693	20952	Economy	19100.00
0005435518123	20952	Economy	19100.00
0005435502554	20952	Economy	19100.00
0005434573338	20952	Economy	19100.00
0005435319692	20952	Economy	19100.00
0005435518121	20952	Economy	19100.00
0005435508488	20952	Economy	19100.00
0005435319695	20952	Economy	19100.00
0005435518134	20952	Economy	19100.00
0005432291957	20952	Economy	19100.00
0005435518120	20952	Economy	19100.00
0005434573362	20952	Economy	19100.00
0005434573373	20952	Economy	19100.00
0005434573347	20952	Economy	19100.00
0005435502562	20952	Economy	19100.00
0005435508484	20952	Economy	19100.00
0005435319689	20952	Economy	19100.00
0005435518125	20952	Economy	19100.00
0005435518117	20952	Economy	19100.00
0005435518135	20952	Economy	19100.00
0005435518122	20952	Economy	19100.00
0005435319687	20952	Economy	19100.00
0005434573372	20952	Economy	19100.00
0005434573376	20952	Economy	19100.00
0005434573292	20952	Economy	19100.00
0005434573339	20952	Economy	19100.00
0005435518115	20952	Economy	19100.00
0005435319688	20952	Economy	19100.00
0005435502571	20952	Economy	19100.00
0005435518132	20952	Economy	19100.00
0005435508490	20952	Economy	19100.00
0005435319690	20952	Economy	19100.00
0005435502557	20952	Economy	19100.00
0005435508486	20952	Economy	19100.00
0005432291958	20952	Economy	19100.00
0005435502556	20952	Economy	19100.00
0005434573368	20952	Economy	19100.00
0005435518126	20952	Economy	19100.00
0005435502564	20952	Economy	19100.00
0005434573420	20952	Economy	19100.00
0005435518116	20952	Economy	19100.00
0005432693135	3060	Economy	3400.00
0005432693377	3060	Economy	3400.00
0005432693196	3060	Economy	3800.00
0005432693147	3060	Economy	3800.00
0005432693175	3060	Economy	3400.00
0005432693214	3060	Economy	3400.00
0005432693186	3060	Economy	3400.00
0005432693141	3060	Economy	3400.00
0005432693241	3060	Economy	3400.00
0005432693155	3060	Economy	3400.00
0005432693134	3060	Economy	3400.00
0005432693218	3060	Economy	3400.00
0005432693164	3060	Economy	3400.00
0005432693242	3060	Economy	3400.00
0005432693137	3060	Economy	3400.00
0005432693229	3060	Economy	3400.00
0005432693136	3060	Economy	3400.00
0005432693226	3060	Economy	3400.00
0005432693190	3060	Economy	3400.00
0005432693272	3060	Economy	3400.00
0005432693271	3060	Economy	3400.00
0005432693204	3060	Economy	3400.00
0005432693140	3060	Economy	3400.00
0005432693262	3060	Economy	3400.00
0005432693243	3060	Economy	3400.00
0005432693129	3060	Economy	3400.00
0005432693089	3060	Economy	3400.00
0005432693165	3060	Economy	3400.00
0005433123998	3062	Business	10300.00
0005432880893	3062	Business	10300.00
0005433124025	3062	Business	10300.00
0005433124022	3062	Business	10300.00
0005432707076	3062	Business	10300.00
0005433123975	3062	Business	10300.00
0005432880897	3062	Business	10300.00
0005432707082	3062	Business	10300.00
0005433123929	3062	Business	10300.00
0005432707080	3062	Business	10300.00
0005433123984	3062	Business	10300.00
0005433124024	3062	Business	10300.00
0005433123961	3062	Economy	3400.00
0005432880842	3062	Economy	3400.00
0005433123964	3062	Economy	3400.00
0005432707068	3062	Economy	3400.00
0005432880865	3062	Economy	3400.00
0005433123958	3062	Economy	3400.00
0005433123987	3062	Economy	3400.00
0005432707087	3062	Economy	3400.00
0005433124028	3062	Economy	3800.00
0005432707085	3062	Economy	3800.00
0005433123919	3062	Economy	3800.00
0005432707073	3062	Economy	3400.00
0005432880868	3062	Economy	3400.00
0005433124003	3062	Economy	3400.00
0005433123981	3062	Economy	3400.00
0005433124037	3062	Economy	3400.00
0005432880867	3062	Economy	3400.00
0005433123974	3062	Economy	3400.00
0005433123995	3062	Economy	3400.00
0005432707074	3062	Economy	3400.00
0005433124042	3062	Economy	3400.00
0005433123994	3062	Economy	3400.00
0005432707093	3062	Economy	3400.00
0005433123928	3062	Economy	3400.00
0005433123992	3062	Economy	3400.00
0005433124027	3062	Economy	3400.00
0005432707078	3062	Economy	3400.00
0005433123959	3062	Economy	3400.00
0005433123946	3062	Economy	3400.00
0005433124051	3062	Economy	3400.00
0005433123982	3062	Economy	3400.00
0005433124050	3062	Economy	3400.00
0005432880878	3062	Economy	3400.00
0005433124057	3062	Economy	3400.00
0005432707072	3062	Economy	3400.00
0005432707086	3062	Economy	3400.00
0005432217809	3062	Economy	3400.00
0005432707079	3062	Economy	3400.00
0005432707090	3062	Economy	3400.00
0005433124105	3062	Economy	3400.00
0005432707083	3062	Economy	3400.00
0005432707092	3062	Economy	3400.00
0005433124095	3062	Economy	3400.00
0005432217811	3062	Economy	3400.00
0005432880898	3062	Economy	3400.00
0005432707070	3062	Economy	3400.00
0005433123983	3062	Economy	3400.00
0005433124041	3062	Economy	3400.00
0005433123993	3062	Economy	3400.00
0005433123945	3062	Economy	3400.00
0005432880874	3062	Economy	3400.00
0005432707089	3062	Economy	3400.00
0005433124021	3062	Economy	3400.00
0005432880841	3062	Economy	3400.00
0005432707088	3062	Economy	3400.00
0005432880866	3062	Economy	3400.00
0005433124043	3062	Economy	3400.00
0005432880830	3062	Economy	3400.00
0005433123920	3062	Economy	3400.00
0005432707075	3062	Economy	3400.00
0005432880877	3062	Economy	3400.00
0005432707084	3062	Economy	3400.00
0005432707069	3062	Economy	3400.00
0005433123918	3062	Economy	3400.00
0005432880815	3062	Economy	3400.00
0005432707077	3062	Economy	3400.00
0005432880814	3062	Economy	3400.00
0005432707081	3062	Economy	3400.00
0005432880829	3062	Economy	3400.00
0005433124040	3062	Economy	3400.00
0005433123960	3062	Economy	3400.00
0005432707071	3062	Economy	3400.00
0005432217810	3062	Economy	3400.00
0005433124046	3062	Economy	3400.00
0005433124038	3062	Economy	3400.00
0005432880864	3062	Economy	3400.00
0005432707091	3062	Economy	3400.00
0005432693452	29913	Business	10300.00
0005432706930	29913	Business	10300.00
0005432693461	29913	Business	10300.00
0005432880988	29913	Business	10300.00
0005432693471	29913	Business	10300.00
0005432880997	29913	Business	10300.00
0005432706893	29913	Business	10300.00
0005432706864	29913	Business	10300.00
0005432706892	29913	Business	10300.00
0005432693447	29913	Business	10300.00
0005432706813	29913	Business	10300.00
0005432693473	29913	Business	10300.00
0005432706819	29913	Economy	3400.00
0005433124172	29913	Economy	3400.00
0005433124169	29913	Economy	3400.00
0005432693443	29913	Economy	3400.00
0005433124167	29913	Economy	3400.00
0005432880987	29913	Economy	3400.00
0005432693445	29913	Economy	3400.00
0005432693456	29913	Economy	3400.00
0005432706842	29913	Economy	3400.00
0005432706830	29913	Economy	3400.00
0005432706920	29913	Economy	3800.00
0005432706918	29913	Economy	3800.00
0005432706853	29913	Economy	3800.00
0005432706860	29913	Economy	3800.00
0005432881001	29913	Economy	3800.00
0005432706756	29913	Economy	3400.00
0005432693463	29913	Economy	3400.00
0005432706950	29913	Economy	3400.00
0005432880992	29913	Economy	3400.00
0005432706915	29913	Economy	3400.00
0005432706916	29913	Economy	3400.00
0005433124165	29913	Economy	3400.00
0005432693458	29913	Economy	3400.00
0005432693446	29913	Economy	3400.00
0005433124170	29913	Economy	3400.00
0005432693468	29913	Economy	3400.00
0005432706868	29913	Economy	3400.00
0005432693449	29913	Economy	3400.00
0005432706825	29913	Economy	3400.00
0005432693462	29913	Economy	3400.00
0005432881000	29913	Economy	3400.00
0005433124175	29913	Economy	3400.00
0005432880996	29913	Economy	3400.00
0005432880995	29913	Economy	3400.00
0005432706843	29913	Economy	3400.00
0005432693455	29913	Economy	3400.00
0005432693467	29913	Economy	3400.00
0005432706863	29913	Economy	3400.00
0005432706948	29913	Economy	3400.00
0005432706907	29913	Economy	3400.00
0005432693457	29913	Economy	3400.00
0005432706919	29913	Economy	3400.00
0005433124176	29913	Economy	3400.00
0005432693466	29913	Economy	3400.00
0005433124171	29913	Economy	3400.00
0005432706840	29913	Economy	3400.00
0005432880991	29913	Economy	3400.00
0005432693454	29913	Economy	3400.00
0005432706951	29913	Economy	3400.00
0005432706727	29913	Economy	3400.00
0005432706921	29913	Economy	3400.00
0005432693442	29913	Economy	3400.00
0005432706839	29913	Economy	3400.00
0005432693444	29913	Economy	3400.00
0005432693460	29913	Economy	3400.00
0005432706934	29913	Economy	3400.00
0005432693448	29913	Economy	3400.00
0005432693450	29913	Economy	3400.00
0005432693459	29913	Economy	3400.00
0005433124168	29913	Economy	3400.00
0005432880990	29913	Economy	3400.00
0005432880998	29913	Economy	3400.00
0005432706774	29913	Economy	3400.00
0005432693451	29913	Economy	3400.00
0005432706947	29913	Economy	3400.00
0005432693472	29913	Economy	3400.00
0005432693469	29913	Economy	3400.00
0005432880986	29913	Economy	3400.00
0005433124173	29913	Economy	3400.00
0005432706905	29913	Economy	3400.00
0005432693470	29913	Economy	3400.00
0005432706909	29913	Economy	3400.00
0005432706812	29913	Economy	3400.00
0005432693464	29913	Economy	3400.00
0005432880993	29913	Economy	3400.00
0005433124166	29913	Economy	3400.00
0005432706891	29913	Economy	3400.00
0005432693453	29913	Economy	3400.00
0005432880994	29913	Economy	3400.00
0005432880999	29913	Economy	3400.00
0005433124174	29913	Economy	3400.00
0005432880989	29913	Economy	3400.00
0005433124177	29913	Economy	3400.00
0005432693465	29913	Economy	3400.00
0005432706943	29913	Economy	3400.00
0005434980135	23677	Economy	4000.00
0005434980126	23677	Economy	4000.00
0005434988868	23677	Economy	4000.00
0005434980138	23677	Economy	4000.00
0005434980121	23677	Economy	3600.00
0005434980134	23677	Economy	3600.00
0005434980120	23677	Economy	3600.00
0005434980141	23677	Economy	3600.00
0005434988866	23677	Economy	3600.00
0005434980116	23677	Economy	3600.00
0005434980139	23677	Economy	3600.00
0005434980118	23677	Economy	3600.00
0005434980115	23677	Economy	3600.00
0005434988861	23677	Economy	3600.00
0005434980119	23677	Economy	3600.00
0005434980117	23677	Economy	3600.00
0005434980127	23677	Economy	3600.00
0005434988863	23677	Economy	3600.00
0005434980128	23677	Economy	3600.00
0005434988869	23677	Economy	3600.00
0005434988865	23677	Economy	3600.00
0005434980122	23677	Economy	3600.00
0005434980132	23677	Economy	3600.00
0005434980130	23677	Economy	3600.00
0005434980142	23677	Economy	3600.00
0005434980143	23677	Economy	3600.00
0005434980114	23677	Economy	3600.00
0005434980123	23677	Economy	3600.00
0005434980133	23677	Economy	3600.00
0005434988864	23677	Economy	3600.00
0005434988867	23677	Economy	3600.00
0005434980140	23677	Economy	3600.00
0005434988862	23677	Economy	3600.00
0005434980125	23677	Economy	3600.00
0005434980129	23677	Economy	3600.00
0005434980136	23677	Economy	3600.00
0005434988860	23677	Economy	3600.00
0005434980124	23677	Economy	3600.00
0005434988870	23677	Economy	3600.00
0005434988859	23677	Economy	3600.00
0005434980137	23677	Economy	3600.00
0005434980131	23677	Economy	3600.00
0005434979902	27559	Economy	4000.00
0005434979884	27559	Economy	4000.00
0005434979782	27559	Economy	4000.00
0005434988735	27559	Economy	4000.00
0005434979925	27559	Economy	3600.00
0005434979930	27559	Economy	3600.00
0005434979772	27559	Economy	3600.00
0005434979856	27559	Economy	3600.00
0005434979688	27559	Economy	3600.00
0005434979836	27559	Economy	3600.00
0005434979933	27559	Economy	3600.00
0005434979931	27559	Economy	3600.00
0005434979899	27559	Economy	3600.00
0005434988713	27559	Economy	3600.00
0005434979773	27559	Economy	3600.00
0005434979994	27559	Economy	3600.00
0005434979929	27559	Economy	3600.00
0005434979718	27559	Economy	3600.00
0005434979921	27559	Economy	3600.00
0005434979874	27559	Economy	3600.00
0005434979898	27559	Economy	3600.00
0005434979813	27559	Economy	3600.00
0005434979781	27559	Economy	3600.00
0005434979808	27559	Economy	3600.00
0005434979717	27559	Economy	3600.00
0005434979872	27559	Economy	3600.00
0005434979807	27559	Economy	3600.00
0005434979901	27559	Economy	3600.00
0005434979897	27559	Economy	3600.00
0005434979857	27559	Economy	3600.00
0005434988736	27559	Economy	3600.00
0005434979865	27559	Economy	3600.00
0005434979780	27559	Economy	3600.00
0005434979689	27559	Economy	3600.00
0005434988722	27559	Economy	3600.00
0005434988714	27559	Economy	3600.00
0005434979900	27559	Economy	3600.00
0005434979963	27559	Economy	3600.00
0005434979860	27559	Economy	3600.00
0005434979932	27559	Economy	3600.00
0005434979877	27559	Economy	3600.00
0005434988723	27559	Economy	3600.00
0005434979866	27559	Economy	3600.00
0005434988748	27559	Economy	3600.00
0005434979826	27559	Economy	3600.00
0005434979858	27559	Economy	3600.00
0005434979774	27559	Economy	3600.00
0005434979873	27559	Economy	3600.00
0005434988759	27559	Economy	3600.00
0005433111512	10263	Economy	19700.00
0005434302507	10263	Economy	19700.00
0005434302508	10263	Economy	19700.00
0005433113541	10263	Economy	19700.00
0005433113540	10263	Economy	19700.00
0005434302510	10263	Economy	19700.00
0005434302506	10263	Economy	19700.00
0005434302511	10263	Economy	19700.00
0005433113544	10263	Economy	19700.00
0005434302509	10263	Economy	19700.00
0005433113563	19621	Economy	19700.00
0005434302463	19621	Economy	19700.00
0005434302460	19621	Economy	19700.00
0005434302474	19621	Economy	19700.00
0005434302459	19621	Economy	19700.00
0005435069695	3542	Business	26900.00
0005435069733	3542	Business	26900.00
0005435069743	3542	Business	26900.00
0005435719009	3542	Business	26900.00
0005435069711	3542	Business	26900.00
0005435925338	3542	Business	26900.00
0005435069723	3542	Business	26900.00
0005435069742	3542	Business	26900.00
0005435925340	3542	Business	26900.00
0005435069745	3542	Economy	9000.00
0005435069737	3542	Economy	9000.00
0005435069704	3542	Economy	9000.00
0005435069709	3542	Economy	9000.00
0005435069697	3542	Economy	9000.00
0005435069712	3542	Economy	9000.00
0005435925317	3542	Economy	9000.00
0005435069714	3542	Economy	9900.00
0005435069741	3542	Economy	9900.00
0005435925321	3542	Economy	9000.00
0005435069740	3542	Economy	9000.00
0005435719005	3542	Economy	9000.00
0005435719004	3542	Economy	9000.00
0005435069716	3542	Economy	9000.00
0005435069735	3542	Economy	9000.00
0005435069747	3542	Economy	9000.00
0005435069717	3542	Economy	9000.00
0005435069729	3542	Economy	9000.00
0005435069701	3542	Economy	9000.00
0005435719003	3542	Economy	9000.00
0005435069696	3542	Economy	9000.00
0005435069730	3542	Economy	9000.00
0005435069700	3542	Economy	9000.00
0005435069708	3542	Economy	9000.00
0005435069732	3542	Economy	9000.00
0005435719008	3542	Economy	9000.00
0005435069715	3542	Economy	9000.00
0005435069727	3542	Economy	9000.00
0005435069744	3542	Economy	9000.00
0005435719006	3542	Economy	9000.00
0005435069720	3542	Economy	9000.00
0005435069731	3542	Economy	9000.00
0005435069710	3542	Economy	9000.00
0005435925339	3542	Economy	9000.00
0005435069705	3542	Economy	9000.00
0005435069746	3542	Economy	9000.00
0005435069698	3542	Economy	9000.00
0005435069738	3542	Economy	9000.00
0005435925318	3542	Economy	9000.00
0005435069728	3542	Economy	9000.00
0005435719010	3542	Economy	9000.00
0005435069706	3542	Economy	9000.00
0005435925330	3542	Economy	9000.00
0005435925335	3542	Economy	9000.00
0005435069724	3542	Economy	9000.00
0005435069713	3542	Economy	9000.00
0005435069722	3542	Economy	9000.00
0005435719007	3542	Economy	9000.00
0005435069748	3542	Economy	9000.00
0005435069721	3542	Economy	9000.00
0005435069734	3542	Economy	9000.00
0005435069702	3542	Economy	9000.00
0005435069739	3542	Economy	9000.00
0005435069736	3542	Economy	9000.00
0005435069699	3542	Economy	9000.00
0005435069726	3542	Economy	9000.00
0005435069718	3542	Economy	9000.00
0005435069719	3542	Economy	9000.00
0005435069703	3542	Economy	9000.00
0005435069725	3542	Economy	9000.00
0005435925331	3542	Economy	9000.00
0005435069707	3542	Economy	9000.00
0005435925334	3542	Economy	9000.00
0005435925325	3542	Economy	9000.00
0005435925319	3542	Economy	9000.00
0005435069322	15320	Business	26900.00
0005435069089	15320	Business	26900.00
0005435069182	15320	Business	26900.00
0005435925464	15320	Business	26900.00
0005435069134	15320	Business	26900.00
0005435069202	15320	Business	26900.00
0005435069305	15320	Economy	9000.00
0005435069260	15320	Economy	9000.00
0005435069155	15320	Economy	9000.00
0005435925466	15320	Economy	9000.00
0005435069255	15320	Economy	9000.00
0005435925463	15320	Economy	9000.00
0005435069025	15320	Economy	9000.00
0005435069250	15320	Economy	9000.00
0005435069178	15320	Economy	9000.00
0005435069059	15320	Economy	9900.00
0005435069261	15320	Economy	9900.00
0005435069046	15320	Economy	9900.00
0005435069052	15320	Economy	9000.00
0005435069185	15320	Economy	9000.00
0005435069064	15320	Economy	9000.00
0005435069206	15320	Economy	9000.00
0005435069113	15320	Economy	9000.00
0005435069287	15320	Economy	9000.00
0005435069213	15320	Economy	9000.00
0005435069148	15320	Economy	9000.00
0005435069252	15320	Economy	9000.00
0005435069124	15320	Economy	9000.00
0005435069243	15320	Economy	9000.00
0005435069180	15320	Economy	9000.00
0005435925465	15320	Economy	9000.00
0005435069056	15320	Economy	9000.00
0005435069024	15320	Economy	9000.00
0005435068976	15320	Economy	9000.00
0005435068955	15320	Economy	9000.00
0005435069194	15320	Economy	9000.00
0005435925462	15320	Economy	9000.00
0005435069146	15320	Economy	9000.00
0005435069090	15320	Economy	9000.00
0005435069091	15320	Economy	9000.00
0005435069228	15320	Economy	9000.00
0005435069181	15320	Economy	9000.00
0005435069171	15320	Economy	9000.00
0005435069238	15320	Economy	9000.00
0005435925467	15320	Economy	9000.00
0005435069051	15320	Economy	9000.00
0005435069177	15320	Economy	9000.00
0005435069240	15320	Economy	9000.00
0005435069053	15320	Economy	9000.00
0005435069079	15320	Economy	9000.00
0005435069308	15320	Economy	9000.00
0005435069118	15320	Economy	9000.00
0005435069201	15320	Economy	9000.00
0005435069195	15320	Economy	9000.00
0005435069086	15320	Economy	9000.00
0005435069262	15320	Economy	9000.00
0005435069112	15320	Economy	9000.00
0005435069065	15320	Economy	9000.00
0005435069242	15320	Economy	9000.00
0005435069239	15320	Economy	9000.00
0005435069237	15320	Economy	9000.00
0005435069219	15320	Economy	9000.00
0005435069184	15320	Economy	9000.00
0005432660843	18179	Economy	5900.00
0005432658617	18179	Economy	5900.00
0005432660842	18179	Economy	5900.00
0005432659732	18179	Economy	5900.00
0005432658616	18179	Economy	5900.00
0005432659731	18179	Economy	5900.00
0005432667459	26451	Economy	5900.00
0005432660824	26451	Economy	5900.00
0005432660828	26451	Economy	5900.00
0005432664135	26451	Economy	5900.00
0005432664140	26451	Economy	5900.00
0005433102177	92	Business	20000.00
0005433102414	92	Business	20000.00
0005432920080	92	Business	20000.00
0005432157516	92	Business	20000.00
0005433102301	92	Business	20000.00
0005433102291	92	Business	20000.00
0005432919993	92	Business	20000.00
0005433102310	92	Business	20000.00
0005433102245	92	Business	20000.00
0005433102258	92	Business	20000.00
0005433102344	92	Business	20000.00
0005432920024	92	Business	20000.00
0005433102241	92	Business	20000.00
0005433102027	92	Business	20000.00
0005433102296	92	Business	20000.00
0005432901717	92	Business	20000.00
0005432157515	92	Business	20000.00
0005432901667	92	Business	20000.00
0005433102286	92	Business	20000.00
0005433102300	92	Economy	7300.00
0005433102379	92	Economy	7300.00
0005433102378	92	Economy	6700.00
0005433102364	92	Economy	6700.00
0005432919796	92	Economy	6700.00
0005433102309	92	Economy	6700.00
0005432901688	92	Economy	6700.00
0005432901755	92	Economy	6700.00
0005432919992	92	Economy	6700.00
0005433102318	92	Economy	6700.00
0005433102359	92	Economy	6700.00
0005433102086	92	Economy	6700.00
0005433102363	92	Economy	6700.00
0005433102412	92	Economy	6700.00
0005432901695	92	Economy	6700.00
0005433102282	92	Economy	6700.00
0005433102342	92	Economy	6700.00
0005433102293	92	Economy	6700.00
0005433102328	92	Economy	6700.00
0005432901582	92	Economy	6700.00
0005432901696	92	Economy	6700.00
0005432901689	92	Economy	6700.00
0005432919961	92	Economy	6700.00
0005432677585	92	Economy	6700.00
0005433102311	92	Economy	6700.00
0005433102308	92	Economy	6700.00
0005432901654	92	Economy	6700.00
0005433102085	92	Economy	6700.00
0005433102340	92	Economy	6700.00
0005432901599	92	Economy	6700.00
0005433102317	92	Economy	6700.00
0005432919905	92	Economy	6700.00
0005433102406	92	Economy	6700.00
0005433102158	92	Economy	6700.00
0005433102246	92	Economy	6700.00
0005433102347	92	Economy	6700.00
0005433102205	92	Economy	6700.00
0005433102325	92	Economy	6700.00
0005433102345	92	Economy	6700.00
0005432920081	92	Economy	6700.00
0005432919934	92	Economy	6700.00
0005433102375	92	Economy	7300.00
0005433102295	92	Economy	6700.00
0005432919804	92	Economy	6700.00
0005432901686	92	Economy	7300.00
0005433102326	92	Economy	6700.00
0005432919999	92	Economy	6700.00
0005432919966	92	Economy	6700.00
0005433102307	92	Economy	6700.00
0005433102327	92	Economy	6700.00
0005432919954	92	Economy	6700.00
0005432919970	92	Economy	6700.00
0005433102294	92	Economy	6700.00
0005432901655	92	Economy	6700.00
0005432901718	92	Economy	6700.00
0005433102329	92	Economy	6700.00
0005432920082	92	Economy	6700.00
0005432901583	92	Economy	6700.00
0005433102251	92	Economy	6700.00
0005433102297	92	Economy	6700.00
0005432920071	92	Economy	6700.00
0005433102352	92	Economy	6700.00
0005432901638	92	Economy	6700.00
0005433102257	92	Economy	6700.00
0005433102365	92	Economy	6700.00
0005433102346	92	Economy	6700.00
0005433102316	92	Economy	6700.00
0005433102250	92	Economy	6700.00
0005432901716	92	Economy	6700.00
0005432901653	92	Economy	6700.00
0005432919960	92	Economy	6700.00
0005433102413	92	Economy	6700.00
0005433102415	92	Economy	6700.00
0005433102341	92	Economy	6700.00
0005432901690	92	Economy	6700.00
0005433102333	92	Economy	6700.00
0005432901668	92	Economy	6700.00
0005433102357	92	Economy	6700.00
0005432901769	92	Economy	6700.00
0005432901677	92	Economy	6700.00
0005433102380	92	Economy	6700.00
0005432901687	92	Economy	6700.00
0005432919893	92	Economy	6700.00
0005433102358	92	Economy	6700.00
0005432901742	92	Economy	6700.00
0005432901758	92	Economy	6700.00
0005432919950	92	Economy	6700.00
0005432919918	92	Economy	6700.00
0005432817821	91	Business	20000.00
0005432262471	91	Business	20000.00
0005432817839	91	Business	20000.00
0005432262451	91	Business	20000.00
0005432207690	91	Business	20000.00
0005432262452	91	Business	20000.00
0005432817833	91	Business	20000.00
0005432817823	91	Business	20000.00
0005432262447	91	Business	20000.00
0005432817842	91	Business	20000.00
0005432817838	91	Business	20000.00
0005432262464	91	Business	20000.00
0005432756856	91	Business	20000.00
0005432817848	91	Business	20000.00
0005432262486	91	Business	20000.00
0005432817834	91	Business	20000.00
0005432753306	91	Business	20000.00
0005432817841	91	Economy	7300.00
0005432817847	91	Business	20000.00
0005432817825	91	Economy	7300.00
0005432262463	91	Economy	7300.00
0005432262457	91	Economy	6700.00
0005432262446	91	Economy	6700.00
0005432756854	91	Economy	6700.00
0005432207691	91	Economy	6700.00
0005432262488	91	Economy	6700.00
0005432262478	91	Economy	6700.00
0005432756860	91	Economy	6700.00
0005432289027	91	Economy	6700.00
0005432817844	91	Economy	6700.00
0005432817846	91	Economy	6700.00
0005432262448	91	Economy	6700.00
0005432753311	91	Economy	6700.00
0005432817826	91	Economy	6700.00
0005432817843	91	Economy	6700.00
0005432262467	91	Economy	6700.00
0005433687717	91	Economy	6700.00
0005432817819	91	Economy	6700.00
0005432262453	91	Economy	6700.00
0005432817822	91	Economy	6700.00
0005432262456	91	Economy	6700.00
0005432262450	91	Economy	6700.00
0005432262460	91	Economy	6700.00
0005432817840	91	Economy	6700.00
0005432817824	91	Economy	6700.00
0005433687703	91	Economy	6700.00
0005432817845	91	Economy	6700.00
0005432756845	91	Economy	6700.00
0005432756857	91	Economy	6700.00
0005432262465	91	Economy	6700.00
0005432817827	91	Economy	6700.00
0005432753323	91	Economy	6700.00
0005432753310	91	Economy	6700.00
0005432262477	91	Economy	6700.00
0005432817837	91	Economy	6700.00
0005432817836	91	Economy	6700.00
0005432207692	91	Economy	6700.00
0005432262449	91	Economy	6700.00
0005432262470	91	Economy	7300.00
0005432817832	91	Economy	6700.00
0005432262455	91	Economy	7300.00
0005432262484	91	Economy	6700.00
0005432262468	91	Economy	6700.00
0005432817835	91	Economy	6700.00
0005432817830	91	Economy	6700.00
0005432262444	91	Economy	6700.00
0005432262445	91	Economy	6700.00
0005432262487	91	Economy	6700.00
0005432756855	91	Economy	6700.00
0005432262474	91	Economy	6700.00
0005432262466	91	Economy	6700.00
0005432289026	91	Economy	6700.00
0005432262476	91	Economy	6700.00
0005432817829	91	Economy	6700.00
0005432262458	91	Economy	6700.00
0005432262469	91	Economy	6700.00
0005432756858	91	Economy	6700.00
0005432262482	91	Economy	6700.00
0005432262454	91	Economy	6700.00
0005432262472	91	Economy	6700.00
0005432753309	91	Economy	6700.00
0005432262459	91	Economy	6700.00
0005432756842	91	Economy	6700.00
0005432262480	91	Economy	6700.00
0005432262481	91	Economy	6700.00
0005432756859	91	Economy	6700.00
0005432817849	91	Economy	6700.00
0005432817820	91	Economy	6700.00
0005432289025	91	Economy	6700.00
0005432756843	91	Economy	6700.00
0005432262490	91	Economy	6700.00
0005432262483	91	Economy	6700.00
0005432817828	91	Economy	6700.00
0005433687718	91	Economy	6700.00
0005432262475	91	Economy	6700.00
0005432262479	91	Economy	6700.00
0005432262462	91	Economy	6700.00
0005432262461	91	Economy	6700.00
0005432262489	91	Economy	6700.00
0005432262473	91	Economy	6700.00
0005432262485	91	Economy	6700.00
0005432817831	91	Economy	6700.00
0005432756853	91	Economy	6700.00
0005433687704	91	Economy	6700.00
0005432020589	7953	Business	20000.00
0005432920120	7953	Business	20000.00
0005433102787	7953	Business	20000.00
0005432920108	7953	Business	20000.00
0005432920104	7953	Business	20000.00
0005432020598	7953	Business	20000.00
0005433102777	7953	Business	20000.00
0005432020581	7953	Business	20000.00
0005432677623	7953	Business	20000.00
0005433102810	7953	Business	20000.00
0005433102773	7953	Business	20000.00
0005433102803	7953	Business	20000.00
0005432020590	7953	Business	20000.00
0005432020577	7953	Business	20000.00
0005432392036	7953	Business	20000.00
0005432020594	7953	Business	20000.00
0005433102814	7953	Business	20000.00
0005433102770	7953	Business	20000.00
0005432920117	7953	Business	20000.00
0005433102811	7953	Business	20000.00
0005432753344	7953	Economy	7300.00
0005432920112	7953	Economy	7300.00
0005433102798	7953	Economy	7300.00
0005432020585	7953	Economy	7300.00
0005432920119	7953	Economy	6700.00
0005433102816	7953	Economy	6700.00
0005432020592	7953	Economy	6700.00
0005433102768	7953	Economy	6700.00
0005432020575	7953	Economy	6700.00
0005433102819	7953	Economy	6700.00
0005433102790	7953	Economy	6700.00
0005433102769	7953	Economy	6700.00
0005433102818	7953	Economy	6700.00
0005432044558	7953	Economy	6700.00
0005433102808	7953	Economy	6700.00
0005433102791	7953	Economy	6700.00
0005432920105	7953	Economy	6700.00
0005432920107	7953	Economy	6700.00
0005432044559	7953	Economy	6700.00
0005432020593	7953	Economy	6700.00
0005432753342	7953	Economy	6700.00
0005433102805	7953	Economy	6700.00
0005433102809	7953	Economy	6700.00
0005433102820	7953	Economy	6700.00
0005432044557	7953	Economy	6700.00
0005433102807	7953	Economy	6700.00
0005432020579	7953	Economy	6700.00
0005433102815	7953	Economy	6700.00
0005432020591	7953	Economy	6700.00
0005432020580	7953	Economy	6700.00
0005432920114	7953	Economy	6700.00
0005432753345	7953	Economy	6700.00
0005432920116	7953	Economy	6700.00
0005433102804	7953	Economy	6700.00
0005433102792	7953	Economy	6700.00
0005432392037	7953	Economy	6700.00
0005432920111	7953	Economy	6700.00
0005433102794	7953	Economy	6700.00
0005432677622	7953	Economy	6700.00
0005433102780	7953	Economy	6700.00
0005432045639	7953	Economy	6700.00
0005432920109	7953	Economy	6700.00
0005432920123	7953	Economy	6700.00
0005432020595	7953	Economy	6700.00
0005433102786	7953	Economy	6700.00
0005432677624	7953	Economy	6700.00
0005432392035	7953	Economy	6700.00
0005433102788	7953	Economy	7300.00
0005432020601	7953	Economy	7300.00
0005432920113	7953	Economy	7300.00
0005432920106	7953	Economy	7300.00
0005432020599	7953	Economy	6700.00
0005432753341	7953	Economy	6700.00
0005433102778	7953	Economy	6700.00
0005432045638	7953	Economy	6700.00
0005433102806	7953	Economy	6700.00
0005433102800	7953	Economy	6700.00
0005433102771	7953	Economy	6700.00
0005432020586	7953	Economy	6700.00
0005433102783	7953	Economy	6700.00
0005432920115	7953	Economy	6700.00
0005432920118	7953	Economy	6700.00
0005433102795	7953	Economy	6700.00
0005432020578	7953	Economy	6700.00
0005433102781	7953	Economy	6700.00
0005432020583	7953	Economy	6700.00
0005433102813	7953	Economy	6700.00
0005432920122	7953	Economy	6700.00
0005432020582	7953	Economy	6700.00
0005432020597	7953	Economy	6700.00
0005433102799	7953	Economy	6700.00
0005433102796	7953	Economy	6700.00
0005433102774	7953	Economy	6700.00
0005433102775	7953	Economy	6700.00
0005432020588	7953	Economy	6700.00
0005433102772	7953	Economy	6700.00
0005433102801	7953	Economy	6700.00
0005432020596	7953	Economy	6700.00
0005433102789	7953	Economy	6700.00
0005432751569	7953	Economy	6700.00
0005433102785	7953	Economy	6700.00
0005433102797	7953	Economy	6700.00
0005433102782	7953	Economy	6700.00
0005433102802	7953	Economy	6700.00
0005433102767	7953	Economy	6700.00
0005433102793	7953	Economy	6700.00
0005433102766	7953	Economy	6700.00
0005433102817	7953	Economy	6700.00
0005432753343	7953	Economy	6700.00
0005432677621	7953	Economy	6700.00
0005432020576	7953	Economy	6700.00
0005432751568	7953	Economy	6700.00
0005433102776	7953	Economy	6700.00
0005432020584	7953	Economy	6700.00
0005432920110	7953	Economy	6700.00
0005432751567	7953	Economy	6700.00
0005432020602	7953	Economy	6700.00
0005433102812	7953	Economy	6700.00
0005433102784	7953	Economy	6700.00
0005432020600	7953	Economy	6700.00
0005433102779	7953	Economy	6700.00
0005432920121	7953	Economy	6700.00
0005432020587	7953	Economy	6700.00
0005432901819	7952	Business	20000.00
0005432817523	7952	Business	20000.00
0005432901830	7952	Business	20000.00
0005432817440	7952	Business	20000.00
0005432817664	7952	Business	20000.00
0005432817565	7952	Business	20000.00
0005432817528	7952	Business	20000.00
0005432817591	7952	Business	20000.00
0005432901821	7952	Business	20000.00
0005432817569	7952	Business	20000.00
0005432817681	7952	Business	20000.00
0005432817634	7952	Business	20000.00
0005432901827	7952	Economy	7300.00
0005432817567	7952	Economy	6700.00
0005432002104	7952	Economy	6700.00
0005432817680	7952	Economy	6700.00
0005432817580	7952	Economy	6700.00
0005432817417	7952	Economy	6700.00
0005432817566	7952	Economy	6700.00
0005432901833	7952	Economy	6700.00
0005432901823	7952	Economy	6700.00
0005432901820	7952	Economy	6700.00
0005432817522	7952	Economy	6700.00
0005432901832	7952	Economy	6700.00
0005432817492	7952	Economy	6700.00
0005432901826	7952	Economy	6700.00
0005432817623	7952	Economy	6700.00
0005432817475	7952	Economy	6700.00
0005432002101	7952	Economy	6700.00
0005432817589	7952	Economy	6700.00
0005432901831	7952	Economy	6700.00
0005432817555	7952	Economy	6700.00
0005432817527	7952	Economy	6700.00
0005432817715	7952	Economy	6700.00
0005432817579	7952	Economy	6700.00
0005432901834	7952	Economy	6700.00
0005432817587	7952	Economy	6700.00
0005432817686	7952	Economy	6700.00
0005432901824	7952	Economy	7300.00
0005432817614	7952	Economy	7300.00
0005432817624	7952	Economy	7300.00
0005432817657	7952	Economy	6700.00
0005432817525	7952	Economy	6700.00
0005432901818	7952	Economy	7300.00
0005432817592	7952	Economy	6700.00
0005432901825	7952	Economy	6700.00
0005432817695	7952	Economy	6700.00
0005432817474	7952	Economy	6700.00
0005432901816	7952	Economy	6700.00
0005432817602	7952	Economy	6700.00
0005432901828	7952	Economy	6700.00
0005432817556	7952	Economy	6700.00
0005432002103	7952	Economy	6700.00
0005432901822	7952	Economy	6700.00
0005432817586	7952	Economy	6700.00
0005432002100	7952	Economy	6700.00
0005432817702	7952	Economy	6700.00
0005432901817	7952	Economy	6700.00
0005432817590	7952	Economy	6700.00
0005432002102	7952	Economy	6700.00
0005432817679	7952	Economy	6700.00
0005432817598	7952	Economy	6700.00
0005432901829	7952	Economy	6700.00
0005432817656	7952	Economy	6700.00
0005433870757	9646	Economy	6900.00
0005433870758	9646	Economy	6900.00
0005434175758	9646	Economy	6900.00
0005434175770	9646	Economy	6900.00
0005434175769	9646	Economy	6900.00
0005434175803	32323	Economy	6900.00
0005433870733	32323	Economy	6900.00
0005434175806	32323	Economy	6900.00
0005433870745	32323	Economy	6900.00
0005434175805	32323	Economy	6900.00
0005434175804	32323	Economy	6900.00
0005433870735	32323	Economy	6900.00
0005433870732	32323	Economy	6900.00
0005433870734	32323	Economy	6900.00
0005434175807	32323	Economy	6900.00
0005432799811	3497	Business	35000.00
0005432799792	3497	Business	35000.00
0005434938380	3497	Business	35000.00
0005432799805	3497	Business	35000.00
0005432799801	3497	Business	35000.00
0005434879427	3497	Business	35000.00
0005434879408	3497	Business	35000.00
0005434879397	3497	Business	35000.00
0005434426963	3497	Business	35000.00
0005434879368	3497	Business	35000.00
0005434879434	3497	Business	35000.00
0005432183495	3497	Business	35000.00
0005432188648	3497	Business	35000.00
0005434938378	3497	Business	35000.00
0005435126858	3497	Business	35000.00
0005434879401	3497	Business	35000.00
0005435126893	3497	Business	35000.00
0005432799809	3497	Comfort	19900.00
0005435126867	3497	Comfort	19900.00
0005435626404	3497	Comfort	19900.00
0005434879349	3497	Comfort	19900.00
0005434879392	3497	Comfort	19900.00
0005434879390	3497	Comfort	19900.00
0005435126873	3497	Comfort	19900.00
0005434879360	3497	Comfort	19900.00
0005434426969	3497	Comfort	19900.00
0005434879437	3497	Comfort	19900.00
0005434879423	3497	Comfort	19900.00
0005434879439	3497	Comfort	19900.00
0005434879411	3497	Comfort	19900.00
0005432799819	3497	Comfort	19900.00
0005434938391	3497	Comfort	19900.00
0005434879435	3497	Comfort	19900.00
0005434426976	3497	Comfort	19900.00
0005435126882	3497	Comfort	19900.00
0005434879363	3497	Comfort	19900.00
0005434879358	3497	Comfort	19900.00
0005435126884	3497	Comfort	19900.00
0005435126870	3497	Comfort	19900.00
0005434938377	3497	Comfort	19900.00
0005435126894	3497	Comfort	19900.00
0005434879407	3497	Comfort	19900.00
0005434879432	3497	Comfort	19900.00
0005432799813	3497	Comfort	19900.00
0005435626400	3497	Economy	11700.00
0005434879385	3497	Economy	11700.00
0005434879393	3497	Economy	11700.00
0005434879430	3497	Economy	11700.00
0005434879379	3497	Economy	11700.00
0005434426966	3497	Economy	11700.00
0005435902719	3497	Economy	11700.00
0005434426988	3497	Economy	11700.00
0005434426970	3497	Economy	11700.00
0005435626413	3497	Economy	11700.00
0005432799817	3497	Economy	11700.00
0005435126895	3497	Economy	11700.00
0005432611756	3497	Economy	11700.00
0005434879424	3497	Economy	11700.00
0005434879380	3497	Economy	11700.00
0005432799806	3497	Economy	11700.00
0005435126857	3497	Economy	11700.00
0005434879364	3497	Economy	11700.00
0005434879369	3497	Economy	11700.00
0005434879412	3497	Economy	11700.00
0005435626399	3497	Economy	11700.00
0005434879414	3497	Economy	11700.00
0005435126888	3497	Economy	11700.00
0005435902787	3497	Economy	11700.00
0005435126871	3497	Economy	11700.00
0005434938383	3497	Economy	11700.00
0005435126855	3497	Economy	11700.00
0005435126872	3497	Economy	11700.00
0005435626402	3497	Economy	11700.00
0005434879371	3497	Economy	11700.00
0005435126878	3497	Economy	11700.00
0005435902703	3497	Economy	11700.00
0005434879417	3497	Economy	11700.00
0005434879398	3497	Economy	11700.00
0005435126864	3497	Economy	11700.00
0005435626401	3497	Economy	11700.00
0005434879376	3497	Economy	11700.00
0005435126887	3497	Economy	11700.00
0005435626406	3497	Economy	11700.00
0005434879382	3497	Economy	11700.00
0005432799797	3497	Economy	11700.00
0005435126889	3497	Economy	11700.00
0005432799804	3497	Economy	11700.00
0005432799815	3497	Economy	11700.00
0005434879403	3497	Economy	11700.00
0005432799799	3497	Economy	11700.00
0005435126862	3497	Economy	11700.00
0005435626410	3497	Economy	11700.00
0005434879352	3497	Economy	11700.00
0005434938392	3497	Economy	11700.00
0005434879396	3497	Economy	11700.00
0005432799807	3497	Economy	12800.00
0005435902830	3497	Economy	11700.00
0005435126885	3497	Economy	11700.00
0005434879410	3497	Economy	12800.00
0005434879422	3497	Economy	11700.00
0005434879420	3497	Economy	12800.00
0005434879367	3497	Economy	11700.00
0005432613910	3497	Economy	11700.00
0005435126866	3497	Economy	11700.00
0005434426968	3497	Economy	11700.00
0005434938382	3497	Economy	11700.00
0005434879431	3497	Economy	11700.00
0005435902836	3497	Economy	11700.00
0005435841095	3497	Economy	11700.00
0005435126869	3497	Economy	11700.00
0005435126861	3497	Economy	11700.00
0005432799812	3497	Economy	11700.00
0005434879356	3497	Economy	11700.00
0005435126868	3497	Economy	11700.00
0005434879378	3497	Economy	11700.00
0005435626408	3497	Economy	11700.00
0005434879374	3497	Economy	11700.00
0005434879388	3497	Economy	11700.00
0005434426974	3497	Economy	11700.00
0005434426980	3497	Economy	11700.00
0005434426987	3497	Economy	11700.00
0005435902778	3497	Economy	11700.00
0005432613912	3497	Economy	11700.00
0005435902727	3497	Economy	11700.00
0005434879355	3497	Economy	11700.00
0005434879409	3497	Economy	11700.00
0005434879359	3497	Economy	11700.00
0005432183493	3497	Economy	11700.00
0005432183494	3497	Economy	11700.00
0005434879365	3497	Economy	11700.00
0005435626403	3497	Economy	11700.00
0005432799808	3497	Economy	11700.00
0005434938384	3497	Economy	11700.00
0005435126865	3497	Economy	11700.00
0005434426984	3497	Economy	11700.00
0005435126856	3497	Economy	11700.00
0005434938379	3497	Economy	11700.00
0005435902717	3497	Economy	11700.00
0005435126863	3497	Economy	11700.00
0005434879406	3497	Economy	11700.00
0005434426962	3497	Economy	11700.00
0005434879381	3497	Economy	11700.00
0005434879366	3497	Economy	11700.00
0005435126890	3497	Economy	11700.00
0005434879348	3497	Economy	11700.00
0005435126879	3497	Economy	11700.00
0005434879426	3497	Economy	11700.00
0005434879350	3497	Economy	11700.00
0005434879433	3497	Economy	11700.00
0005432799803	3497	Economy	11700.00
0005435126874	3497	Economy	11700.00
0005434938387	3497	Economy	11700.00
0005434879373	3497	Economy	11700.00
0005434879413	3497	Economy	11700.00
0005435126877	3497	Economy	11700.00
0005434938373	3497	Economy	11700.00
0005432611758	3497	Economy	11700.00
0005432799821	3497	Economy	11700.00
0005435126883	3497	Economy	11700.00
0005434879384	3497	Economy	11700.00
0005434879404	3497	Economy	11700.00
0005435126892	3497	Economy	11700.00
0005432799816	3497	Economy	11700.00
0005434938386	3497	Economy	11700.00
0005432799820	3497	Economy	11700.00
0005434879389	3497	Economy	11700.00
0005434879387	3497	Economy	11700.00
0005434879362	3497	Economy	11700.00
0005434938375	3497	Economy	11700.00
0005434879441	3497	Economy	11700.00
0005435902702	3497	Economy	11700.00
0005435126859	3497	Economy	11700.00
0005434879375	3497	Economy	11700.00
0005432799800	3497	Economy	11700.00
0005435126860	3497	Economy	11700.00
0005435626405	3497	Economy	11700.00
0005434879370	3497	Economy	11700.00
0005434879415	3497	Economy	11700.00
0005434879346	3497	Economy	11700.00
0005434879361	3497	Economy	11700.00
0005434879391	3497	Economy	12800.00
0005434426979	3497	Economy	12800.00
0005434879394	3497	Economy	12800.00
0005434426985	3497	Economy	12800.00
0005434426983	3497	Economy	12800.00
0005435126876	3497	Economy	11700.00
0005432611757	3497	Economy	11700.00
0005432799795	3497	Economy	11700.00
0005435126891	3497	Economy	11700.00
0005432799810	3497	Economy	11700.00
0005435841096	3497	Economy	11700.00
0005434426972	3497	Economy	11700.00
0005434938389	3497	Economy	11700.00
0005434938381	3497	Economy	11700.00
0005435902718	3497	Economy	11700.00
0005435626411	3497	Economy	11700.00
0005432613913	3497	Economy	11700.00
0005432799793	3497	Economy	11700.00
0005435626412	3497	Economy	11700.00
0005434879347	3497	Economy	11700.00
0005435902704	3497	Economy	11700.00
0005434426982	3497	Economy	11700.00
0005432799802	3497	Economy	11700.00
0005434879402	3497	Economy	11700.00
0005434879399	3497	Economy	11700.00
0005434879418	3497	Economy	11700.00
0005434426977	3497	Economy	11700.00
0005435902792	3497	Economy	11700.00
0005434426961	3497	Economy	11700.00
0005435126896	3497	Economy	11700.00
0005434426967	3497	Economy	11700.00
0005434879429	3497	Economy	11700.00
0005435902837	3497	Economy	11700.00
0005434426964	3497	Economy	11700.00
0005434879354	3497	Economy	11700.00
0005434426978	3497	Economy	11700.00
0005434879377	3497	Economy	11700.00
0005435126886	3497	Economy	11700.00
0005434938376	3497	Economy	11700.00
0005435902793	3497	Economy	11700.00
0005434879416	3497	Economy	11700.00
0005435126881	3497	Economy	11700.00
0005434879395	3497	Economy	11700.00
0005434879419	3497	Economy	11700.00
0005435902751	3497	Economy	11700.00
0005435126875	3497	Economy	11700.00
0005434879405	3497	Economy	11700.00
0005432613911	3497	Economy	11700.00
0005434426973	3497	Economy	11700.00
0005432799794	3497	Economy	11700.00
0005434879353	3497	Economy	11700.00
0005434879372	3497	Economy	11700.00
0005434426960	3497	Economy	11700.00
0005434426975	3497	Economy	11700.00
0005435626407	3497	Economy	11700.00
0005434879351	3497	Economy	11700.00
0005434426971	3497	Economy	11700.00
0005432799796	3497	Economy	11700.00
0005435902767	3497	Economy	11700.00
0005434426986	3497	Economy	11700.00
0005434879440	3497	Economy	11700.00
0005434938385	3497	Economy	11700.00
0005435126880	3497	Economy	11700.00
0005434879425	3497	Economy	11700.00
0005432799814	3497	Economy	11700.00
0005432799818	3497	Economy	11700.00
0005434879438	3497	Economy	11700.00
0005434879421	3497	Economy	11700.00
0005432799798	3497	Economy	11700.00
0005434426965	3497	Economy	11700.00
0005434879386	3497	Economy	11700.00
0005435626409	3497	Economy	11700.00
0005434938390	3497	Economy	11700.00
0005434938374	3497	Economy	11700.00
0005434426981	3497	Economy	11700.00
0005434879383	3497	Economy	11700.00
0005434879428	3497	Economy	11700.00
0005434879400	3497	Economy	11700.00
0005432188649	3497	Economy	11700.00
0005432188650	3497	Economy	11700.00
0005434938388	3497	Economy	11700.00
0005434879436	3497	Economy	11700.00
0005434879357	3497	Economy	11700.00
0005434878783	14587	Business	35000.00
0005434878821	14587	Business	35000.00
0005434938238	14587	Business	35000.00
0005435914710	14587	Business	35000.00
0005432799477	14587	Business	35000.00
0005434878654	14587	Business	35000.00
0005434878449	14587	Business	35000.00
0005435902923	14587	Business	35000.00
0005434878664	14587	Business	35000.00
0005435626216	14587	Business	35000.00
0005434878633	14587	Business	35000.00
0005434878928	14587	Business	35000.00
0005435902916	14587	Business	35000.00
0005432607589	14587	Business	35000.00
0005434878655	14587	Business	35000.00
0005435126311	14587	Business	35000.00
0005434878709	14587	Business	35000.00
0005434878933	14587	Business	35000.00
0005434878231	14587	Business	35000.00
0005435126362	14587	Business	35000.00
0005434426676	14587	Business	35000.00
0005432799459	14587	Business	35000.00
0005435126505	14587	Comfort	19900.00
0005435914706	14587	Business	35000.00
0005435126568	14587	Comfort	19900.00
0005434938252	14587	Comfort	19900.00
0005434878373	14587	Comfort	19900.00
0005435626236	14587	Comfort	19900.00
0005435126673	14587	Comfort	19900.00
0005435626223	14587	Comfort	19900.00
0005435126475	14587	Comfort	19900.00
0005434878131	14587	Comfort	19900.00
0005434878317	14587	Comfort	19900.00
0005434878534	14587	Comfort	19900.00
0005434878382	14587	Comfort	19900.00
0005435626217	14587	Comfort	19900.00
0005435902930	14587	Comfort	19900.00
0005434878589	14587	Comfort	19900.00
0005434426777	14587	Comfort	19900.00
0005434878415	14587	Comfort	19900.00
0005432799527	14587	Comfort	19900.00
0005434426865	14587	Comfort	19900.00
0005435626257	14587	Comfort	19900.00
0005434878729	14587	Comfort	19900.00
0005434938187	14587	Comfort	19900.00
0005434878322	14587	Comfort	19900.00
0005435126566	14587	Comfort	19900.00
0005435126545	14587	Comfort	19900.00
0005435626251	14587	Comfort	19900.00
0005432799703	14587	Comfort	19900.00
0005435902919	14587	Comfort	19900.00
0005435913968	14587	Comfort	19900.00
0005435902915	14587	Economy	11700.00
0005434878127	14587	Economy	11700.00
0005434878426	14587	Economy	11700.00
0005432059528	14587	Economy	11700.00
0005434878644	14587	Economy	11700.00
0005435126485	14587	Economy	11700.00
0005435126463	14587	Economy	11700.00
0005435626169	14587	Economy	11700.00
0005434938195	14587	Economy	11700.00
0005434878234	14587	Economy	11700.00
0005434938281	14587	Economy	11700.00
0005434878197	14587	Economy	11700.00
0005435126635	14587	Economy	11700.00
0005434426775	14587	Economy	11700.00
0005434878368	14587	Economy	11700.00
0005432799526	14587	Economy	11700.00
0005434938266	14587	Economy	11700.00
0005434938288	14587	Economy	11700.00
0005435626226	14587	Economy	11700.00
0005434426767	14587	Economy	11700.00
0005434878577	14587	Economy	11700.00
0005434878927	14587	Economy	11700.00
0005434878539	14587	Economy	11700.00
0005434426675	14587	Economy	11700.00
0005435902920	14587	Economy	11700.00
0005432799424	14587	Economy	11700.00
0005434878666	14587	Economy	11700.00
0005434878837	14587	Economy	11700.00
0005432799478	14587	Economy	11700.00
0005434878628	14587	Economy	11700.00
0005435126573	14587	Economy	11700.00
0005435126636	14587	Economy	11700.00
0005434878839	14587	Economy	11700.00
0005434938273	14587	Economy	11700.00
0005434878521	14587	Economy	11700.00
0005434878394	14587	Economy	11700.00
0005434426651	14587	Economy	11700.00
0005434426768	14587	Economy	11700.00
0005432799555	14587	Economy	11700.00
0005434878514	14587	Economy	11700.00
0005435126375	14587	Economy	11700.00
0005434878537	14587	Economy	11700.00
0005434878232	14587	Economy	11700.00
0005435626184	14587	Economy	11700.00
0005435902928	14587	Economy	11700.00
0005435913966	14587	Economy	11700.00
0005434878316	14587	Economy	11700.00
0005434878233	14587	Economy	11700.00
0005434878582	14587	Economy	11700.00
0005434878725	14587	Economy	11700.00
0005434878901	14587	Economy	12800.00
0005434878445	14587	Economy	12800.00
0005435126310	14587	Economy	12800.00
0005434878670	14587	Economy	11700.00
0005432799575	14587	Economy	11700.00
0005432799568	14587	Economy	12800.00
0005434878671	14587	Economy	12800.00
0005432799567	14587	Economy	11700.00
0005432799701	14587	Economy	11700.00
0005434878801	14587	Economy	11700.00
0005435902929	14587	Economy	11700.00
0005434878384	14587	Economy	11700.00
0005432799531	14587	Economy	11700.00
0005435902917	14587	Economy	11700.00
0005435914708	14587	Economy	11700.00
0005434878587	14587	Economy	11700.00
0005435126436	14587	Economy	11700.00
0005434878464	14587	Economy	11700.00
0005434426729	14587	Economy	11700.00
0005432799628	14587	Economy	11700.00
0005435126506	14587	Economy	11700.00
0005435126342	14587	Economy	11700.00
0005434878532	14587	Economy	11700.00
0005435841832	14587	Economy	11700.00
0005434426722	14587	Economy	11700.00
0005434878475	14587	Economy	11700.00
0005434878579	14587	Economy	11700.00
0005434938228	14587	Economy	11700.00
0005432799539	14587	Economy	11700.00
0005435902925	14587	Economy	11700.00
0005434938186	14587	Economy	11700.00
0005435902914	14587	Economy	11700.00
0005432607588	14587	Economy	11700.00
0005434878586	14587	Economy	11700.00
0005432059529	14587	Economy	11700.00
0005435626193	14587	Economy	11700.00
0005432799599	14587	Economy	11700.00
0005432799481	14587	Economy	11700.00
0005432607592	14587	Economy	11700.00
0005435626168	14587	Economy	11700.00
0005434878624	14587	Economy	11700.00
0005435902926	14587	Economy	11700.00
0005435126574	14587	Economy	11700.00
0005434878882	14587	Economy	11700.00
0005435126466	14587	Economy	11700.00
0005434878165	14587	Economy	11700.00
0005434426650	14587	Economy	11700.00
0005435126672	14587	Economy	11700.00
0005432611714	14587	Economy	11700.00
0005432799572	14587	Economy	11700.00
0005434878443	14587	Economy	11700.00
0005434878784	14587	Economy	11700.00
0005435626218	14587	Economy	11700.00
0005434878417	14587	Economy	11700.00
0005435914707	14587	Economy	11700.00
0005435902924	14587	Economy	11700.00
0005435126538	14587	Economy	11700.00
0005435626258	14587	Economy	11700.00
0005435126320	14587	Economy	11700.00
0005434878191	14587	Economy	11700.00
0005434878904	14587	Economy	11700.00
0005432799631	14587	Economy	11700.00
0005435626229	14587	Economy	11700.00
0005434878733	14587	Economy	11700.00
0005435126569	14587	Economy	11700.00
0005434878296	14587	Economy	11700.00
0005435902918	14587	Economy	11700.00
0005434878192	14587	Economy	11700.00
0005435913967	14587	Economy	11700.00
0005434878855	14587	Economy	11700.00
0005435626170	14587	Economy	11700.00
0005434878653	14587	Economy	11700.00
0005432799569	14587	Economy	11700.00
0005432799425	14587	Economy	11700.00
0005435626164	14587	Economy	11700.00
0005432799648	14587	Economy	11700.00
0005435126493	14587	Economy	11700.00
0005435126335	14587	Economy	11700.00
0005434878634	14587	Economy	11700.00
0005434878225	14587	Economy	11700.00
0005434878748	14587	Economy	11700.00
0005434878308	14587	Economy	11700.00
0005434878721	14587	Economy	12800.00
0005435914709	14587	Economy	11700.00
0005434878395	14587	Economy	12800.00
0005434426701	14587	Economy	12800.00
0005435126590	14587	Economy	12800.00
0005434426700	14587	Economy	12800.00
0005434878531	14587	Economy	11700.00
0005434938194	14587	Economy	11700.00
0005434878442	14587	Economy	11700.00
0005435126589	14587	Economy	11700.00
0005434426740	14587	Economy	11700.00
0005434878730	14587	Economy	11700.00
0005434878562	14587	Economy	11700.00
0005434878856	14587	Economy	11700.00
0005434426705	14587	Economy	11700.00
0005435126508	14587	Economy	11700.00
0005434426678	14587	Economy	11700.00
0005435902922	14587	Economy	11700.00
0005435626239	14587	Economy	11700.00
0005434938201	14587	Economy	11700.00
0005434878374	14587	Economy	11700.00
0005432799574	14587	Economy	11700.00
0005434878645	14587	Economy	11700.00
0005435914705	14587	Economy	11700.00
0005434878341	14587	Economy	11700.00
0005434878226	14587	Economy	11700.00
0005435626143	14587	Economy	11700.00
0005435126435	14587	Economy	11700.00
0005434426746	14587	Economy	11700.00
0005434878190	14587	Economy	11700.00
0005434878617	14587	Economy	11700.00
0005434938284	14587	Economy	11700.00
0005434878242	14587	Economy	11700.00
0005434878782	14587	Economy	11700.00
0005434426696	14587	Economy	11700.00
0005435902931	14587	Economy	11700.00
0005434878241	14587	Economy	11700.00
0005434878669	14587	Economy	11700.00
0005434878383	14587	Economy	11700.00
0005435841831	14587	Economy	11700.00
0005435626256	14587	Economy	11700.00
0005434878723	14587	Economy	11700.00
0005432799532	14587	Economy	11700.00
0005434878785	14587	Economy	11700.00
0005434878749	14587	Economy	11700.00
0005434878681	14587	Economy	11700.00
0005434878643	14587	Economy	11700.00
0005434938282	14587	Economy	11700.00
0005435126521	14587	Economy	11700.00
0005434878465	14587	Economy	11700.00
0005434426806	14587	Economy	11700.00
0005434878698	14587	Economy	11700.00
0005434878929	14587	Economy	11700.00
0005435902927	14587	Economy	11700.00
0005435626185	14587	Economy	11700.00
0005434426677	14587	Economy	11700.00
0005435626227	14587	Economy	11700.00
0005432799551	14587	Economy	11700.00
0005434878288	14587	Economy	11700.00
0005435902921	14587	Economy	11700.00
0005434878858	14587	Economy	11700.00
0005434878623	14587	Economy	11700.00
0005435626238	14587	Economy	11700.00
0005434878323	14587	Economy	11700.00
0005434878857	14587	Economy	11700.00
0005434938102	14587	Economy	11700.00
0005434878618	14587	Economy	11700.00
0005434426713	14587	Economy	11700.00
0005434426801	14587	Economy	11700.00
0005434426674	14587	Economy	11700.00
0005435626228	14587	Economy	11700.00
0005434938101	14587	Economy	11700.00
0005434938226	14587	Economy	11700.00
0005434426774	14587	Economy	11700.00
0005435126474	14587	Economy	11700.00
0005434878548	14587	Economy	11700.00
0005434426812	14587	Economy	11700.00
0005434878600	14587	Economy	11700.00
0005432799576	14587	Economy	11700.00
0005434878796	14587	Economy	11700.00
0005432799590	14587	Economy	11700.00
0005434878369	14587	Economy	11700.00
0005434938227	14587	Economy	11700.00
0005432799702	14587	Economy	11700.00
0005435889893	3632	Economy	16300.00
0005435889915	3632	Economy	14800.00
0005434325790	3632	Economy	14800.00
0005434325794	3632	Economy	14800.00
0005435889916	3632	Economy	14800.00
0005434312344	3632	Economy	14800.00
0005435889943	3632	Economy	14800.00
0005435889930	3632	Economy	14800.00
0005435889945	3632	Economy	14800.00
0005434325797	3632	Economy	14800.00
0005434325792	3632	Economy	14800.00
0005435889889	3632	Economy	14800.00
0005434325789	3632	Economy	14800.00
0005435889922	3632	Economy	14800.00
0005435889929	3632	Economy	14800.00
0005434325795	3632	Economy	14800.00
0005434325793	3632	Economy	14800.00
0005434325791	3632	Economy	14800.00
0005435889918	3632	Economy	14800.00
0005435889903	3632	Economy	14800.00
0005434325786	3632	Economy	14800.00
0005434325788	3632	Economy	14800.00
0005435889888	3632	Economy	14800.00
0005434325796	3632	Economy	14800.00
0005435889917	3632	Economy	14800.00
0005434312345	3632	Economy	14800.00
0005434325787	3632	Economy	14800.00
0005434325702	15620	Economy	16300.00
0005434325726	15620	Economy	16300.00
0005434325711	15620	Economy	16300.00
0005435889971	15620	Economy	14800.00
0005435889968	15620	Economy	14800.00
0005434325750	15620	Economy	14800.00
0005434325684	15620	Economy	14800.00
0005434325752	15620	Economy	14800.00
0005434325672	15620	Economy	14800.00
0005435889973	15620	Economy	14800.00
0005434325751	15620	Economy	14800.00
0005434325692	15620	Economy	14800.00
0005435889969	15620	Economy	14800.00
0005434325691	15620	Economy	14800.00
0005434325717	15620	Economy	14800.00
0005434325679	15620	Economy	14800.00
0005435889972	15620	Economy	14800.00
0005434325698	15620	Economy	14800.00
0005434325693	15620	Economy	14800.00
0005434325673	15620	Economy	14800.00
0005434325712	15620	Economy	14800.00
0005435889970	15620	Economy	14800.00
0005435957877	645	Economy	4500.00
0005435957880	645	Economy	4100.00
0005435957891	645	Economy	4100.00
0005435957888	645	Economy	4100.00
0005435957881	645	Economy	4100.00
0005435957884	645	Economy	4100.00
0005435957882	645	Economy	4100.00
0005435957876	645	Economy	4100.00
0005433420429	645	Economy	4100.00
0005435957883	645	Economy	4100.00
0005435957890	645	Economy	4100.00
0005435957887	645	Economy	4100.00
0005435957879	645	Economy	4100.00
0005435957889	645	Economy	4100.00
0005433420438	645	Economy	4100.00
0005433420439	645	Economy	4100.00
0005433420430	645	Economy	4100.00
0005435957886	645	Economy	4100.00
0005435957878	645	Economy	4100.00
0005435957885	645	Economy	4100.00
0005433420508	15196	Economy	4100.00
0005433420506	15196	Economy	4100.00
0005435957789	15196	Economy	4100.00
0005435957757	15196	Economy	4100.00
0005433420511	15196	Economy	4100.00
0005435957717	15196	Economy	4100.00
0005435957792	15196	Economy	4100.00
0005435957776	15196	Economy	4100.00
0005435957752	15196	Economy	4100.00
0005435957712	15196	Economy	4100.00
0005435957758	15196	Economy	4100.00
0005435957736	15196	Economy	4100.00
0005433420512	15196	Economy	4100.00
0005435957793	15196	Economy	4100.00
0005435957740	15196	Economy	4100.00
0005433420507	15196	Economy	4100.00
0005435957716	15196	Economy	4100.00
0005433420505	15196	Economy	4100.00
0005435957711	15196	Economy	4100.00
0005435957753	15196	Economy	4100.00
0005433420504	15196	Economy	4100.00
0005435957720	15196	Economy	4100.00
0005435957741	15196	Economy	4100.00
0005433420509	15196	Economy	4100.00
0005435957742	15196	Economy	4100.00
0005433420510	15196	Economy	4100.00
0005434995305	23999	Business	94000.00
0005434995301	23999	Economy	31300.00
0005434995297	23999	Economy	31300.00
0005434995283	23999	Economy	31300.00
0005434995304	23999	Economy	31300.00
0005434995303	23999	Economy	31300.00
0005434995299	23999	Economy	31300.00
0005434995298	23999	Economy	31300.00
0005434995300	23999	Economy	31300.00
0005434995306	23999	Economy	31300.00
0005434995302	23999	Economy	31300.00
0005434995307	23999	Economy	31300.00
0005435629418	8873	Economy	10400.00
0005434247153	8873	Economy	10400.00
0005435629419	8873	Economy	10400.00
0005434247154	8873	Economy	10400.00
0005434247179	16058	Economy	10400.00
0005435629405	16058	Economy	10400.00
0005434247180	16058	Economy	10400.00
0005434247178	16058	Economy	10400.00
0005433404856	2870	Business	12600.00
0005435797645	2870	Business	12600.00
0005435797651	2870	Business	12600.00
0005435797648	2870	Business	12600.00
0005433404857	2870	Business	12600.00
0005435797657	2870	Economy	4200.00
0005435797658	2870	Economy	4200.00
0005435797656	2870	Economy	4200.00
0005435797646	2870	Economy	4200.00
0005435797654	2870	Economy	4200.00
0005435797653	2870	Economy	4200.00
0005435797644	2870	Economy	4200.00
0005435797642	2870	Economy	4200.00
0005435797649	2870	Economy	4200.00
0005435797655	2870	Economy	4200.00
0005435797650	2870	Economy	4200.00
0005435797647	2870	Economy	4200.00
0005433404858	2870	Economy	4200.00
0005435797652	2870	Economy	4200.00
0005435797643	2870	Economy	4200.00
0005433404904	29314	Business	12600.00
0005435797540	29314	Business	12600.00
0005435797556	29314	Business	12600.00
0005435797554	29314	Business	12600.00
0005435797539	29314	Business	12600.00
0005435797549	29314	Economy	4200.00
0005433404899	29314	Economy	4200.00
0005433404906	29314	Economy	4200.00
0005433404898	29314	Economy	4600.00
0005435797495	29314	Economy	4600.00
0005433404903	29314	Economy	4200.00
0005435797573	29314	Economy	4200.00
0005435797538	29314	Economy	4200.00
0005435797542	29314	Economy	4200.00
0005435797548	29314	Economy	4200.00
0005435797543	29314	Economy	4200.00
0005435797494	29314	Economy	4200.00
0005433404900	29314	Economy	4200.00
0005435797564	29314	Economy	4200.00
0005433404902	29314	Economy	4200.00
0005435797552	29314	Economy	4200.00
0005435797553	29314	Economy	4200.00
0005435797537	29314	Economy	4200.00
0005435797504	29314	Economy	4200.00
0005435797521	29314	Economy	4200.00
0005435797550	29314	Economy	4200.00
0005433404901	29314	Economy	4200.00
0005433404905	29314	Economy	4200.00
0005435797505	29314	Economy	4200.00
0005435376366	5825	Economy	6800.00
0005435376367	5825	Economy	6800.00
0005435376368	5825	Economy	6800.00
0005434948130	5829	Economy	6800.00
0005434948125	5829	Economy	6800.00
0005434948126	5829	Economy	6800.00
0005434948128	5829	Economy	6800.00
0005434948121	5829	Economy	6800.00
0005434948129	5829	Economy	6800.00
0005434948127	5829	Economy	6800.00
0005434948122	5829	Economy	6800.00
0005434948124	5829	Economy	6800.00
0005434948123	5829	Economy	6800.00
0005434948035	16325	Economy	6800.00
0005434948069	16325	Economy	6800.00
0005435376383	16325	Economy	6800.00
0005434948068	16325	Economy	6800.00
0005435376382	16325	Economy	6800.00
0005435376381	16325	Economy	6800.00
0005435376387	16325	Economy	6800.00
0005435376386	16325	Economy	6800.00
0005434948057	16325	Economy	6800.00
0005434948056	16325	Economy	6800.00
0005435376385	16325	Economy	6800.00
0005435376384	16325	Economy	6800.00
0005433961563	6888	Business	21400.00
0005433961557	6888	Business	21400.00
0005433961590	6888	Business	21400.00
0005433961565	6888	Business	21400.00
0005433961544	6888	Business	21400.00
0005433961561	6888	Business	21400.00
0005433961547	6888	Business	21400.00
0005433961581	6888	Business	21400.00
0005433961586	6888	Economy	7100.00
0005433961583	6888	Economy	7100.00
0005433961558	6888	Economy	7100.00
0005433961550	6888	Economy	7100.00
0005433961580	6888	Economy	7100.00
0005433961564	6888	Economy	7100.00
0005433961536	6888	Economy	7100.00
0005433961551	6888	Economy	7800.00
0005433961569	6888	Economy	7800.00
0005433961538	6888	Economy	7100.00
0005433961556	6888	Economy	7100.00
0005433961548	6888	Economy	7100.00
0005433961573	6888	Economy	7100.00
0005433961532	6888	Economy	7100.00
0005433961579	6888	Economy	7100.00
0005433961534	6888	Economy	7100.00
0005433961567	6888	Economy	7100.00
0005433961574	6888	Economy	7100.00
0005433961582	6888	Economy	7100.00
0005433961571	6888	Economy	7100.00
0005433961588	6888	Economy	7100.00
0005433961591	6888	Economy	7100.00
0005433961560	6888	Economy	7100.00
0005433961587	6888	Economy	7100.00
0005433961533	6888	Economy	7100.00
0005433961540	6888	Economy	7100.00
0005433961546	6888	Economy	7100.00
0005433961578	6888	Economy	7100.00
0005433961537	6888	Economy	7100.00
0005433961553	6888	Economy	7100.00
0005433961562	6888	Economy	7100.00
0005433961554	6888	Economy	7100.00
0005433961555	6888	Economy	7100.00
0005433961541	6888	Economy	7100.00
0005433961589	6888	Economy	7100.00
0005433961549	6888	Economy	7100.00
0005433961539	6888	Economy	7100.00
0005433961572	6888	Economy	7100.00
0005433961535	6888	Economy	7100.00
0005433961542	6888	Economy	7100.00
0005433961577	6888	Economy	7100.00
0005433961568	6888	Economy	7100.00
0005433961575	6888	Economy	7100.00
0005433961543	6888	Economy	7100.00
0005433961559	6888	Economy	7100.00
0005433961584	6888	Economy	7100.00
0005433961566	6888	Economy	7100.00
0005433961585	6888	Economy	7100.00
0005433961545	6888	Economy	7100.00
0005433961570	6888	Economy	7100.00
0005433961576	6888	Economy	7100.00
0005433961552	6888	Economy	7100.00
0005433960877	25750	Business	21400.00
0005433960939	25750	Business	21400.00
0005433960902	25750	Business	21400.00
0005433960871	25750	Business	21400.00
0005433960880	25750	Business	21400.00
0005433960975	25750	Business	21400.00
0005433960817	25750	Business	21400.00
0005433960940	25750	Economy	7100.00
0005433960827	25750	Economy	7100.00
0005433960748	25750	Economy	7100.00
0005433960687	25750	Economy	7100.00
0005433960853	25750	Economy	7100.00
0005433960818	25750	Economy	7100.00
0005433960993	25750	Economy	7800.00
0005433960986	25750	Economy	7800.00
0005433960882	25750	Economy	7800.00
0005433960837	25750	Economy	7100.00
0005433960947	25750	Economy	7100.00
0005433960907	25750	Economy	7100.00
0005433960973	25750	Economy	7100.00
0005433960913	25750	Economy	7100.00
0005433960977	25750	Economy	7100.00
0005433960760	25750	Economy	7100.00
0005433960884	25750	Economy	7100.00
0005433960852	25750	Economy	7100.00
0005433960854	25750	Economy	7100.00
0005433960868	25750	Economy	7100.00
0005433960888	25750	Economy	7100.00
0005433960865	25750	Economy	7100.00
0005433960819	25750	Economy	7100.00
0005433960950	25750	Economy	7100.00
0005433960815	25750	Economy	7100.00
0005433960976	25750	Economy	7100.00
0005433960795	25750	Economy	7100.00
0005433960851	25750	Economy	7100.00
0005433960968	25750	Economy	7100.00
0005433960985	25750	Economy	7100.00
0005433960761	25750	Economy	7100.00
0005433960873	25750	Economy	7100.00
0005433960769	25750	Economy	7100.00
0005433960642	25750	Economy	7100.00
0005433960987	25750	Economy	7100.00
0005433960836	25750	Economy	7100.00
0005433960879	25750	Economy	7100.00
0005433960883	25750	Economy	7100.00
0005433960962	25750	Economy	7100.00
0005433960805	25750	Economy	7100.00
0005433960915	25750	Economy	7100.00
0005433960878	25750	Economy	7100.00
0005433960914	25750	Economy	7100.00
0005433960588	25750	Economy	7100.00
0005433960814	25750	Economy	7100.00
0005433960904	25750	Economy	7100.00
0005433960816	25750	Economy	7100.00
0005433960963	25750	Economy	7100.00
0005433960984	25750	Economy	7100.00
0005433960823	25750	Economy	7100.00
0005433960674	25750	Economy	7100.00
0005433960822	25750	Economy	7100.00
0005435082819	24517	Economy	3900.00
0005435082794	24517	Economy	3900.00
0005435082818	24517	Economy	3900.00
0005435082836	24517	Economy	3900.00
0005435082810	24517	Economy	3900.00
0005435082838	24517	Economy	3900.00
0005435082837	24517	Economy	3900.00
0005435082787	24517	Economy	3900.00
0005435082878	26085	Economy	3900.00
0005435082881	26085	Economy	3900.00
0005435082873	26085	Economy	3900.00
0005435082875	26085	Economy	3900.00
0005435082877	26085	Economy	3900.00
0005435082879	26085	Economy	3900.00
0005435082880	26085	Economy	3900.00
0005435082874	26085	Economy	3900.00
0005435082876	26085	Economy	3900.00
0005433534504	5136	Business	18000.00
0005434245339	5136	Business	18000.00
0005434245354	5136	Business	18000.00
0005434245343	5136	Business	18000.00
0005435286649	5136	Business	18000.00
0005434245327	5136	Business	18000.00
0005435286635	5136	Business	18000.00
0005435286645	5136	Business	18000.00
0005434245329	5136	Business	18000.00
0005434245348	5136	Economy	6000.00
0005434245346	5136	Economy	6000.00
0005434245337	5136	Economy	6000.00
0005434245345	5136	Economy	6000.00
0005434245336	5136	Economy	6000.00
0005434245351	5136	Economy	6000.00
0005434245355	5136	Economy	6000.00
0005434245332	5136	Economy	6000.00
0005434245350	5136	Economy	6000.00
0005435286646	5136	Economy	6000.00
0005434245347	5136	Economy	6000.00
0005435286644	5136	Economy	6000.00
0005434245356	5136	Economy	6000.00
0005434245334	5136	Economy	6000.00
0005434245342	5136	Economy	6600.00
0005434245340	5136	Economy	6000.00
0005434245349	5136	Economy	6600.00
0005435286654	5136	Economy	6000.00
0005434245341	5136	Economy	6000.00
0005432166941	5136	Economy	6000.00
0005434245333	5136	Economy	6000.00
0005434245353	5136	Economy	6000.00
0005434245352	5136	Economy	6000.00
0005434245330	5136	Economy	6000.00
0005434245344	5136	Economy	6000.00
0005434245335	5136	Economy	6000.00
0005435286648	5136	Economy	6000.00
0005434245328	5136	Economy	6000.00
0005435286639	5136	Economy	6000.00
0005434245338	5136	Economy	6000.00
0005432166942	5136	Economy	6000.00
0005434245331	5136	Economy	6000.00
0005433785394	5135	Business	18000.00
0005432106166	5135	Business	18000.00
0005433615621	5135	Business	18000.00
0005433785389	5135	Business	18000.00
0005433615622	5135	Business	18000.00
0005433785384	5135	Business	18000.00
0005433785404	5135	Business	18000.00
0005432666413	5135	Business	18000.00
0005432106143	5135	Business	18000.00
0005433615584	5135	Business	18000.00
0005433785407	5135	Business	18000.00
0005433615620	5135	Business	18000.00
0005433615590	5135	Business	18000.00
0005433615601	5135	Business	18000.00
0005433615591	5135	Business	18000.00
0005433615628	5135	Business	18000.00
0005432106165	5135	Business	18000.00
0005433785390	5135	Business	18000.00
0005432106133	5135	Business	18000.00
0005433615561	5135	Business	18000.00
0005432106175	5135	Business	18000.00
0005433785376	5135	Business	18000.00
0005433785395	5135	Business	18000.00
0005433615573	5135	Business	18000.00
0005433785386	5135	Business	18000.00
0005433785397	5135	Business	18000.00
0005432106132	5135	Business	18000.00
0005433785398	5135	Business	18000.00
0005433615606	5135	Economy	6600.00
0005433785402	5135	Economy	6600.00
0005433615602	5135	Economy	6600.00
0005432106177	5135	Economy	6600.00
0005433785406	5135	Economy	6600.00
0005433615607	5135	Economy	6600.00
0005432106153	5135	Economy	6000.00
0005432106169	5135	Economy	6000.00
0005433615612	5135	Economy	6000.00
0005433615604	5135	Economy	6000.00
0005433615619	5135	Economy	6000.00
0005432106147	5135	Economy	6000.00
0005432106158	5135	Economy	6000.00
0005433785410	5135	Economy	6000.00
0005432145137	5135	Economy	6000.00
0005432106171	5135	Economy	6000.00
0005433615560	5135	Economy	6000.00
0005433615618	5135	Economy	6000.00
0005432665299	5135	Economy	6000.00
0005433615629	5135	Economy	6000.00
0005433615589	5135	Economy	6000.00
0005432106161	5135	Economy	6000.00
0005433615623	5135	Economy	6000.00
0005433615600	5135	Economy	6000.00
0005433785388	5135	Economy	6000.00
0005433785405	5135	Economy	6000.00
0005433785377	5135	Economy	6000.00
0005433615587	5135	Economy	6000.00
0005432667478	5135	Economy	6000.00
0005432106136	5135	Economy	6000.00
0005433615575	5135	Economy	6000.00
0005433615592	5135	Economy	6000.00
0005433785375	5135	Economy	6000.00
0005432106162	5135	Economy	6000.00
0005432106134	5135	Economy	6000.00
0005433615576	5135	Economy	6000.00
0005432106152	5135	Economy	6000.00
0005433615610	5135	Economy	6000.00
0005433615574	5135	Economy	6000.00
0005433615593	5135	Economy	6000.00
0005433615583	5135	Economy	6000.00
0005433615609	5135	Economy	6000.00
0005432106145	5135	Economy	6000.00
0005432106168	5135	Economy	6000.00
0005433615580	5135	Economy	6000.00
0005433615625	5135	Economy	6000.00
0005432106146	5135	Economy	6000.00
0005432106157	5135	Economy	6000.00
0005432106139	5135	Economy	6000.00
0005433785400	5135	Economy	6000.00
0005433615579	5135	Economy	6000.00
0005433615569	5135	Economy	6000.00
0005432665300	5135	Economy	6000.00
0005433785382	5135	Economy	6000.00
0005432106180	5135	Economy	6000.00
0005433785379	5135	Economy	6000.00
0005433615581	5135	Economy	6000.00
0005432106144	5135	Economy	6000.00
0005433615567	5135	Economy	6000.00
0005433615603	5135	Economy	6000.00
0005433615611	5135	Economy	6000.00
0005433615614	5135	Economy	6000.00
0005433615597	5135	Economy	6000.00
0005433785396	5135	Economy	6000.00
0005433615564	5135	Economy	6000.00
0005432106154	5135	Economy	6000.00
0005433785387	5135	Economy	6600.00
0005433615557	5135	Economy	6600.00
0005432106148	5135	Economy	6600.00
0005432106151	5135	Economy	6600.00
0005433615558	5135	Economy	6600.00
0005432106155	5135	Economy	6000.00
0005432106149	5135	Economy	6000.00
0005433785378	5135	Economy	6000.00
0005432106160	5135	Economy	6000.00
0005433615616	5135	Economy	6600.00
0005433785409	5135	Economy	6000.00
0005432106170	5135	Economy	6000.00
0005433615559	5135	Economy	6000.00
0005433615627	5135	Economy	6000.00
0005433615578	5135	Economy	6000.00
0005433615577	5135	Economy	6000.00
0005432106176	5135	Economy	6000.00
0005433785408	5135	Economy	6000.00
0005433785383	5135	Economy	6000.00
0005432106167	5135	Economy	6000.00
0005432106174	5135	Economy	6000.00
0005433785385	5135	Economy	6000.00
0005433615588	5135	Economy	6000.00
0005432106142	5135	Economy	6000.00
0005432667479	5135	Economy	6000.00
0005433785381	5135	Economy	6000.00
0005433615613	5135	Economy	6000.00
0005432106178	5135	Economy	6000.00
0005433785392	5135	Economy	6000.00
0005432106141	5135	Economy	6000.00
0005433785393	5135	Economy	6000.00
0005433615624	5135	Economy	6000.00
0005433785401	5135	Economy	6000.00
0005433615566	5135	Economy	6000.00
0005432106163	5135	Economy	6000.00
0005433615572	5135	Economy	6000.00
0005433615595	5135	Economy	6000.00
0005433615571	5135	Economy	6000.00
0005433615608	5135	Economy	6000.00
0005433615626	5135	Economy	6000.00
0005433615594	5135	Economy	6000.00
0005432106131	5135	Economy	6000.00
0005433615565	5135	Economy	6000.00
0005432106137	5135	Economy	6000.00
0005432665301	5135	Economy	6000.00
0005433615586	5135	Economy	6000.00
0005433615617	5135	Economy	6000.00
0005432106140	5135	Economy	6000.00
0005432106159	5135	Economy	6000.00
0005432106173	5135	Economy	6000.00
0005433615585	5135	Economy	6000.00
0005432106172	5135	Economy	6000.00
0005432106179	5135	Economy	6000.00
0005433615615	5135	Economy	6000.00
0005433615596	5135	Economy	6000.00
0005433615630	5135	Economy	6000.00
0005433615631	5135	Economy	6000.00
0005432666414	5135	Economy	6000.00
0005432106164	5135	Economy	6000.00
0005432106138	5135	Economy	6000.00
0005433615582	5135	Economy	6000.00
0005433785399	5135	Economy	6000.00
0005433785380	5135	Economy	6000.00
0005433785391	5135	Economy	6000.00
0005432145138	5135	Economy	6000.00
0005433615568	5135	Economy	6000.00
0005433785403	5135	Economy	6000.00
0005433615570	5135	Economy	6000.00
0005432106156	5135	Economy	6000.00
0005433615605	5135	Economy	6000.00
0005433615598	5135	Economy	6000.00
0005433615599	5135	Economy	6000.00
0005433615563	5135	Economy	6000.00
0005432106135	5135	Economy	6000.00
0005433615562	5135	Economy	6000.00
0005432106150	5135	Economy	6000.00
0005435007045	5133	Business	18000.00
0005434229653	5133	Business	18000.00
0005435007151	5133	Business	18000.00
0005434173567	5133	Business	18000.00
0005434229644	5133	Business	18000.00
0005435007144	5133	Business	18000.00
0005435007104	5133	Business	18000.00
0005434265454	5133	Business	18000.00
0005435007106	5133	Business	18000.00
0005434149872	5133	Business	18000.00
0005434265450	5133	Business	18000.00
0005435007126	5133	Business	18000.00
0005435007107	5133	Business	18000.00
0005434265458	5133	Business	18000.00
0005434229646	5133	Business	18000.00
0005434229654	5133	Business	18000.00
0005434265456	5133	Business	18000.00
0005434149877	5133	Business	18000.00
0005434149873	5133	Business	18000.00
0005434229657	5133	Economy	6600.00
0005434265465	5133	Economy	6600.00
0005435007153	5133	Economy	6600.00
0005435007163	5133	Economy	6600.00
0005434149878	5133	Economy	6600.00
0005434265463	5133	Economy	6000.00
0005434229649	5133	Economy	6000.00
0005435007175	5133	Economy	6000.00
0005434265444	5133	Economy	6000.00
0005434265446	5133	Economy	6000.00
0005434229639	5133	Economy	6000.00
0005435007087	5133	Economy	6000.00
0005434229651	5133	Economy	6000.00
0005434229655	5133	Economy	6000.00
0005435007046	5133	Economy	6000.00
0005432336101	5133	Economy	6000.00
0005434173570	5133	Economy	6000.00
0005435007074	5133	Economy	6000.00
0005434229658	5133	Economy	6000.00
0005435007085	5133	Economy	6000.00
0005434265443	5133	Economy	6000.00
0005434312324	5133	Economy	6000.00
0005435007108	5133	Economy	6000.00
0005432336076	5133	Economy	6000.00
0005432336096	5133	Economy	6000.00
0005433815405	5133	Economy	6000.00
0005434149881	5133	Economy	6000.00
0005433815391	5133	Economy	6000.00
0005435007188	5133	Economy	6000.00
0005432336116	5133	Economy	6000.00
0005434265464	5133	Economy	6000.00
0005435007177	5133	Economy	6000.00
0005434149879	5133	Economy	6000.00
0005434265460	5133	Economy	6000.00
0005432336082	5133	Economy	6000.00
0005432336077	5133	Economy	6000.00
0005435007051	5133	Economy	6000.00
0005434229645	5133	Economy	6000.00
0005434229641	5133	Economy	6000.00
0005434149880	5133	Economy	6000.00
0005432336097	5133	Economy	6000.00
0005435007159	5133	Economy	6000.00
0005434229647	5133	Economy	6000.00
0005434149869	5133	Economy	6000.00
0005433688824	5133	Economy	6000.00
0005435007216	5133	Economy	6000.00
0005434265467	5133	Economy	6000.00
0005434265452	5133	Economy	6000.00
0005434229656	5133	Economy	6600.00
0005434149875	5133	Economy	6600.00
0005435007098	5133	Economy	6000.00
0005435007086	5133	Economy	6000.00
0005434149870	5133	Economy	6600.00
0005434265447	5133	Economy	6000.00
0005435007145	5133	Economy	6000.00
0005434265457	5133	Economy	6000.00
0005434173568	5133	Economy	6000.00
0005434265466	5133	Economy	6000.00
0005434265468	5133	Economy	6000.00
0005434312323	5133	Economy	6000.00
0005435007160	5133	Economy	6000.00
0005434265453	5133	Economy	6000.00
0005434229640	5133	Economy	6000.00
0005434149876	5133	Economy	6000.00
0005434229648	5133	Economy	6000.00
0005432336047	5133	Economy	6000.00
0005432336123	5133	Economy	6000.00
0005434265462	5133	Economy	6000.00
0005434265448	5133	Economy	6000.00
0005434265459	5133	Economy	6000.00
0005434265451	5133	Economy	6000.00
0005434173569	5133	Economy	6000.00
0005435007124	5133	Economy	6000.00
0005434149871	5133	Economy	6000.00
0005432336098	5133	Economy	6000.00
0005434265445	5133	Economy	6000.00
0005435007176	5133	Economy	6000.00
0005433815407	5133	Economy	6000.00
0005434265461	5133	Economy	6000.00
0005435007052	5133	Economy	6000.00
0005435007187	5133	Economy	6000.00
0005434265455	5133	Economy	6000.00
0005435007167	5133	Economy	6000.00
0005434265449	5133	Economy	6000.00
0005435007073	5133	Economy	6000.00
0005434229650	5133	Economy	6000.00
0005435007105	5133	Economy	6000.00
0005433815386	5133	Economy	6000.00
0005434229659	5133	Economy	6000.00
0005434229642	5133	Economy	6000.00
0005435007186	5133	Economy	6000.00
0005434229652	5133	Economy	6000.00
0005432336046	5133	Economy	6000.00
0005435007152	5133	Economy	6000.00
0005435007099	5133	Economy	6000.00
0005435007161	5133	Economy	6000.00
0005432336095	5133	Economy	6000.00
0005433815408	5133	Economy	6000.00
0005434265442	5133	Economy	6000.00
0005434149874	5133	Economy	6000.00
0005434229643	5133	Economy	6000.00
0005435007026	5133	Economy	6000.00
0005433784987	8597	Business	18000.00
0005433785120	8597	Business	18000.00
0005434245255	8597	Business	18000.00
0005433785162	8597	Business	18000.00
0005433785051	8597	Business	18000.00
0005433784986	8597	Business	18000.00
0005433785113	8597	Business	18000.00
0005435269851	8597	Business	18000.00
0005435269842	8597	Business	18000.00
0005434244991	8597	Business	18000.00
0005433784876	8597	Business	18000.00
0005434245219	8597	Business	18000.00
0005433785012	8597	Business	18000.00
0005433785049	8597	Business	18000.00
0005434245045	8597	Economy	6600.00
0005433785004	8597	Business	18000.00
0005435269853	8597	Economy	6600.00
0005433785141	8597	Economy	6600.00
0005433785244	8597	Economy	6000.00
0005435269841	8597	Economy	6000.00
0005433785110	8597	Economy	6000.00
0005433784999	8597	Economy	6000.00
0005433785038	8597	Economy	6000.00
0005435269843	8597	Economy	6000.00
0005434245058	8597	Economy	6000.00
0005432666400	8597	Economy	6000.00
0005433785011	8597	Economy	6000.00
0005434245105	8597	Economy	6000.00
0005435269849	8597	Economy	6000.00
0005434245198	8597	Economy	6000.00
0005434245108	8597	Economy	6000.00
0005433785097	8597	Economy	6000.00
0005435269845	8597	Economy	6000.00
0005433785121	8597	Economy	6000.00
0005433785006	8597	Economy	6000.00
0005435269846	8597	Economy	6000.00
0005434245245	8597	Economy	6000.00
0005435269850	8597	Economy	6000.00
0005435269848	8597	Economy	6000.00
0005434244992	8597	Economy	6000.00
0005433785000	8597	Economy	6000.00
0005434245137	8597	Economy	6000.00
0005433785098	8597	Economy	6000.00
0005433785079	8597	Economy	6000.00
0005433785050	8597	Economy	6000.00
0005434245246	8597	Economy	6000.00
0005433785115	8597	Economy	6000.00
0005433784998	8597	Economy	6000.00
0005435269847	8597	Economy	6600.00
0005433785086	8597	Economy	6600.00
0005434245057	8597	Economy	6000.00
0005435269854	8597	Economy	6000.00
0005433785043	8597	Economy	6000.00
0005434244999	8597	Economy	6000.00
0005433785164	8597	Economy	6000.00
0005434245015	8597	Economy	6000.00
0005434245166	8597	Economy	6000.00
0005433785044	8597	Economy	6000.00
0005433785134	8597	Economy	6000.00
0005434245099	8597	Economy	6000.00
0005433784952	8597	Economy	6000.00
0005433785112	8597	Economy	6000.00
0005433785151	8597	Economy	6000.00
0005434245200	8597	Economy	6000.00
0005434245132	8597	Economy	6000.00
0005432666391	8597	Economy	6000.00
0005434245098	8597	Economy	6000.00
0005435269844	8597	Economy	6000.00
0005433785124	8597	Economy	6000.00
0005434245170	8597	Economy	6000.00
0005433785125	8597	Economy	6000.00
0005433784953	8597	Economy	6000.00
0005435269852	8597	Economy	6000.00
0005433785117	8597	Economy	6000.00
0005434245199	8597	Economy	6000.00
0005433785116	8597	Economy	6000.00
0005433784949	8597	Economy	6000.00
0005433785111	8597	Economy	6000.00
0005433785136	8597	Economy	6000.00
0005435269840	8597	Economy	6000.00
0005433785005	8597	Economy	6000.00
0005433785144	8597	Economy	6000.00
0005433785155	8597	Economy	6000.00
0005433785216	8597	Economy	6000.00
0005433785133	8597	Economy	6000.00
0005434245034	8597	Economy	6000.00
0005433614588	8596	Business	18000.00
0005433614766	8596	Business	18000.00
0005433614961	8596	Business	18000.00
0005433614923	8596	Business	18000.00
0005433614964	8596	Business	18000.00
0005433614760	8596	Business	18000.00
0005433614785	8596	Business	18000.00
0005433614916	8596	Business	18000.00
0005433615025	8596	Business	18000.00
0005433614813	8596	Business	18000.00
0005433614584	8596	Business	18000.00
0005433614778	8596	Economy	6600.00
0005433615315	8596	Economy	6600.00
0005433615019	8596	Economy	6000.00
0005433614654	8596	Economy	6000.00
0005433614946	8596	Economy	6000.00
0005433614944	8596	Economy	6000.00
0005433614962	8596	Economy	6000.00
0005433615314	8596	Economy	6000.00
0005433614767	8596	Economy	6000.00
0005433614629	8596	Economy	6000.00
0005433614862	8596	Economy	6000.00
0005433614885	8596	Economy	6000.00
0005433615313	8596	Economy	6000.00
0005433614909	8596	Economy	6000.00
0005433615072	8596	Economy	6000.00
0005433614963	8596	Economy	6000.00
0005433614894	8596	Economy	6000.00
0005433614751	8596	Economy	6000.00
0005433614752	8596	Economy	6000.00
0005433614650	8596	Economy	6000.00
0005433615018	8596	Economy	6000.00
0005433614655	8596	Economy	6000.00
0005433615044	8596	Economy	6000.00
0005433614927	8596	Economy	6000.00
0005433614895	8596	Economy	6000.00
0005433614953	8596	Economy	6000.00
0005433615119	8596	Economy	6000.00
0005433614922	8596	Economy	6000.00
0005433614506	8596	Economy	6000.00
0005433614847	8596	Economy	6000.00
0005433615009	8596	Economy	6000.00
0005433614956	8596	Economy	6000.00
0005433614896	8596	Economy	6600.00
0005433614585	8596	Economy	6600.00
0005433614772	8596	Economy	6000.00
0005433614897	8596	Economy	6600.00
0005433615032	8596	Economy	6000.00
0005433614947	8596	Economy	6000.00
0005433614736	8596	Economy	6000.00
0005433614972	8596	Economy	6000.00
0005433614825	8596	Economy	6000.00
0005433614863	8596	Economy	6000.00
0005433614633	8596	Economy	6000.00
0005433615020	8596	Economy	6000.00
0005433614917	8596	Economy	6000.00
0005433614589	8596	Economy	6000.00
0005433614933	8596	Economy	6000.00
0005433615162	8596	Economy	6000.00
0005433614764	8596	Economy	6000.00
0005433614892	8596	Economy	6000.00
0005433614749	8596	Economy	6000.00
0005433615144	8596	Economy	6000.00
0005433615033	8596	Economy	6000.00
0005433615127	8596	Economy	6000.00
0005433614763	8596	Economy	6000.00
0005433614955	8596	Economy	6000.00
0005433614905	8596	Economy	6000.00
0005433615173	8596	Economy	6000.00
0005433614773	8596	Economy	6000.00
0005433614871	8596	Economy	6000.00
0005433614737	8596	Economy	6000.00
0005433614784	8596	Economy	6000.00
0005433615002	8596	Economy	6000.00
0005433614934	8596	Economy	6000.00
0005434265175	8595	Business	18000.00
0005434229491	8595	Business	18000.00
0005432035282	8595	Business	18000.00
0005435007315	8595	Business	18000.00
0005433690949	8595	Business	18000.00
0005434265174	8595	Business	18000.00
0005432336180	8595	Business	18000.00
0005432035298	8595	Business	18000.00
0005435286689	8595	Business	18000.00
0005432336177	8595	Business	18000.00
0005434149738	8595	Business	18000.00
0005432035295	8595	Business	18000.00
0005434265105	8595	Business	18000.00
0005435286687	8595	Business	18000.00
0005434149792	8595	Business	18000.00
0005435007324	8595	Business	18000.00
0005433688837	8595	Business	18000.00
0005435007308	8595	Business	18000.00
0005434265160	8595	Business	18000.00
0005434265235	8595	Business	18000.00
0005432035275	8595	Business	18000.00
0005432035300	8595	Business	18000.00
0005432047597	8595	Business	18000.00
0005434149784	8595	Business	18000.00
0005432336184	8595	Business	18000.00
0005434229451	8595	Economy	6600.00
0005434229584	8595	Economy	6600.00
0005435007325	8595	Economy	6600.00
0005434265281	8595	Economy	6600.00
0005434265253	8595	Economy	6600.00
0005432047595	8595	Economy	6600.00
0005433688836	8595	Economy	6000.00
0005435286682	8595	Economy	6000.00
0005435007305	8595	Economy	6000.00
0005434149837	8595	Economy	6000.00
0005432336185	8595	Economy	6000.00
0005434149763	8595	Economy	6000.00
0005433689938	8595	Economy	6000.00
0005435007312	8595	Economy	6000.00
0005434229433	8595	Economy	6000.00
0005432035283	8595	Economy	6000.00
0005432035284	8595	Economy	6000.00
0005432035290	8595	Economy	6000.00
0005434173533	8595	Economy	6000.00
0005435007304	8595	Economy	6000.00
0005434265266	8595	Economy	6000.00
0005434149771	8595	Economy	6000.00
0005435007309	8595	Economy	6000.00
0005433815444	8595	Economy	6000.00
0005433688834	8595	Economy	6000.00
0005432035302	8595	Economy	6000.00
0005434229486	8595	Economy	6000.00
0005433688835	8595	Economy	6000.00
0005432336178	8595	Economy	6000.00
0005434149737	8595	Economy	6000.00
0005435007319	8595	Economy	6000.00
0005432035278	8595	Economy	6000.00
0005432336182	8595	Economy	6000.00
0005434149764	8595	Economy	6000.00
0005433534524	8595	Economy	6000.00
0005435007326	8595	Economy	6000.00
0005433815447	8595	Economy	6000.00
0005434265265	8595	Economy	6000.00
0005432035287	8595	Economy	6000.00
0005435286684	8595	Economy	6000.00
0005434265269	8595	Economy	6000.00
0005435007314	8595	Economy	6000.00
0005435007311	8595	Economy	6000.00
0005434229406	8595	Economy	6000.00
0005432035297	8595	Economy	6000.00
0005434173528	8595	Economy	6000.00
0005434229449	8595	Economy	6000.00
0005432035294	8595	Economy	6000.00
0005433815446	8595	Economy	6000.00
0005434265158	8595	Economy	6000.00
0005434265103	8595	Economy	6000.00
0005435286688	8595	Economy	6000.00
0005435007320	8595	Economy	6000.00
0005435286690	8595	Economy	6000.00
0005433690950	8595	Economy	6000.00
0005432047596	8595	Economy	6000.00
0005432035291	8595	Economy	6000.00
0005435007318	8595	Economy	6000.00
0005434149767	8595	Economy	6000.00
0005435286685	8595	Economy	6000.00
0005432035303	8595	Economy	6000.00
0005435286686	8595	Economy	6000.00
0005434149722	8595	Economy	6000.00
0005432035299	8595	Economy	6600.00
0005434265254	8595	Economy	6600.00
0005433815448	8595	Economy	6600.00
0005434265205	8595	Economy	6000.00
0005434265153	8595	Economy	6000.00
0005434149770	8595	Economy	6000.00
0005432336183	8595	Economy	6000.00
0005432035301	8595	Economy	6600.00
0005432035288	8595	Economy	6000.00
0005432336181	8595	Economy	6000.00
0005434149769	8595	Economy	6000.00
0005435007328	8595	Economy	6000.00
0005434229466	8595	Economy	6000.00
0005432035289	8595	Economy	6000.00
0005434265248	8595	Economy	6000.00
0005434229476	8595	Economy	6000.00
0005434265163	8595	Economy	6000.00
0005434229465	8595	Economy	6000.00
0005432035280	8595	Economy	6000.00
0005434265128	8595	Economy	6000.00
0005435007313	8595	Economy	6000.00
0005432035296	8595	Economy	6000.00
0005432035285	8595	Economy	6000.00
0005435286683	8595	Economy	6000.00
0005432035277	8595	Economy	6000.00
0005432035293	8595	Economy	6000.00
0005434265104	8595	Economy	6000.00
0005435007322	8595	Economy	6000.00
0005435007316	8595	Economy	6000.00
0005432035276	8595	Economy	6000.00
0005432336176	8595	Economy	6000.00
0005435007307	8595	Economy	6000.00
0005434229339	8595	Economy	6000.00
0005432035286	8595	Economy	6000.00
0005433815445	8595	Economy	6000.00
0005432035279	8595	Economy	6000.00
0005433534525	8595	Economy	6000.00
0005434149723	8595	Economy	6000.00
0005435007327	8595	Economy	6000.00
0005434265228	8595	Economy	6000.00
0005434229477	8595	Economy	6000.00
0005434149761	8595	Economy	6000.00
0005434149783	8595	Economy	6000.00
0005435007317	8595	Economy	6000.00
0005435007306	8595	Economy	6000.00
0005434265229	8595	Economy	6000.00
0005434265204	8595	Economy	6000.00
0005434265303	8595	Economy	6000.00
0005434265293	8595	Economy	6000.00
0005435007321	8595	Economy	6000.00
0005432035292	8595	Economy	6000.00
0005434149760	8595	Economy	6000.00
0005432035281	8595	Economy	6000.00
0005434173529	8595	Economy	6000.00
0005432336179	8595	Economy	6000.00
0005434229419	8595	Economy	6000.00
0005434173530	8595	Economy	6000.00
0005432336186	8595	Economy	6000.00
0005434149765	8595	Economy	6000.00
0005435007323	8595	Economy	6000.00
0005435007310	8595	Economy	6000.00
0005433202540	12610	Economy	16200.00
0005434639536	12610	Economy	16200.00
0005433202547	12610	Economy	16200.00
0005433202543	12610	Economy	14800.00
0005433202542	12610	Economy	14800.00
0005433202545	12610	Economy	14800.00
0005433202550	12610	Economy	14800.00
0005433202546	12610	Economy	14800.00
0005433202541	12610	Economy	14800.00
0005434639451	12610	Economy	14800.00
0005434639483	12610	Economy	14800.00
0005433202549	12610	Economy	14800.00
0005434639535	12610	Economy	14800.00
0005434639375	12610	Economy	14800.00
0005434639480	12610	Economy	14800.00
0005434639388	12610	Economy	14800.00
0005434639482	12610	Economy	14800.00
0005434639397	12610	Economy	14800.00
0005434639465	12610	Economy	14800.00
0005434639418	12610	Economy	14800.00
0005433202553	12610	Economy	14800.00
0005434639490	12610	Economy	14800.00
0005433202544	12610	Economy	14800.00
0005433202552	12610	Economy	14800.00
0005434639432	12610	Economy	14800.00
0005434639360	12610	Economy	14800.00
0005434639481	12610	Economy	14800.00
0005434639422	12610	Economy	14800.00
0005433202548	12610	Economy	14800.00
0005434639489	12610	Economy	14800.00
0005434639382	12610	Economy	14800.00
0005433202551	12610	Economy	14800.00
0005434639346	12610	Economy	14800.00
0005434639603	23346	Economy	16200.00
0005433202442	23346	Economy	16200.00
0005434639611	23346	Economy	16200.00
0005432290668	23346	Economy	16200.00
0005433202374	23346	Economy	14800.00
0005434639618	23346	Economy	14800.00
0005433202413	23346	Economy	14800.00
0005434639600	23346	Economy	14800.00
0005434639605	23346	Economy	14800.00
0005434639609	23346	Economy	14800.00
0005433202405	23346	Economy	14800.00
0005434639602	23346	Economy	14800.00
0005433202395	23346	Economy	14800.00
0005433202372	23346	Economy	14800.00
0005434639610	23346	Economy	14800.00
0005434639604	23346	Economy	14800.00
0005432290667	23346	Economy	14800.00
0005433202393	23346	Economy	14800.00
0005434639607	23346	Economy	14800.00
0005434639620	23346	Economy	14800.00
0005434639625	23346	Economy	14800.00
0005432290669	23346	Economy	14800.00
0005434639621	23346	Economy	14800.00
0005434639622	23346	Economy	14800.00
0005434639619	23346	Economy	14800.00
0005433202371	23346	Economy	14800.00
0005434639601	23346	Economy	14800.00
0005433202376	23346	Economy	14800.00
0005434639623	23346	Economy	14800.00
0005434639624	23346	Economy	14800.00
0005434639612	23346	Economy	14800.00
0005433202406	23346	Economy	14800.00
0005434639615	23346	Economy	14800.00
0005434639606	23346	Economy	14800.00
0005434639626	23346	Economy	14800.00
0005433202373	23346	Economy	14800.00
0005434639599	23346	Economy	14800.00
0005434639608	23346	Economy	14800.00
0005434639613	23346	Economy	14800.00
0005433202378	23346	Economy	14800.00
0005434639617	23346	Economy	14800.00
0005434639614	23346	Economy	14800.00
0005434639616	23346	Economy	14800.00
0005432328652	21075	Business	18900.00
0005432328904	21075	Business	18900.00
0005432383469	21075	Business	18900.00
0005432383228	21075	Business	18900.00
0005432328903	21075	Business	18900.00
0005432328809	21075	Business	18900.00
0005432848841	21075	Business	18900.00
0005432328792	21075	Business	18900.00
0005432383308	21075	Business	18900.00
0005432383336	21075	Economy	6300.00
0005432383207	21075	Economy	6300.00
0005432328793	21075	Economy	6300.00
0005432328837	21075	Economy	6300.00
0005432328664	21075	Economy	6300.00
0005432328858	21075	Economy	6300.00
0005432328846	21075	Economy	6300.00
0005432383225	21075	Economy	6300.00
0005432383282	21075	Economy	6300.00
0005432328760	21075	Economy	6300.00
0005432383313	21075	Economy	6900.00
0005432328936	21075	Economy	6900.00
0005432328886	21075	Economy	6900.00
0005432328702	21075	Economy	6300.00
0005432383193	21075	Economy	6300.00
0005432383288	21075	Economy	6300.00
0005432383470	21075	Economy	6300.00
0005432383221	21075	Economy	6300.00
0005432328808	21075	Economy	6300.00
0005432383151	21075	Economy	6300.00
0005432383252	21075	Economy	6300.00
0005432328995	21075	Economy	6300.00
0005432328780	21075	Economy	6300.00
0005432383327	21075	Economy	6300.00
0005432383257	21075	Economy	6300.00
0005432328991	21075	Economy	6300.00
0005432383342	21075	Economy	6300.00
0005432383090	21075	Economy	6300.00
0005432328871	21075	Economy	6300.00
0005432328895	21075	Economy	6300.00
0005432383253	21075	Economy	6300.00
0005432383287	21075	Economy	6300.00
0005432383178	21075	Economy	6300.00
0005432328900	21075	Economy	6300.00
0005432328857	21075	Economy	6300.00
0005432328749	21075	Economy	6300.00
0005432383262	21075	Economy	6300.00
0005432328999	21075	Economy	6300.00
0005432328934	21075	Economy	6300.00
0005432328748	21075	Economy	6300.00
0005432328887	21075	Economy	6300.00
0005432328878	21075	Economy	6300.00
0005432383189	21075	Economy	6300.00
0005432328908	21075	Economy	6300.00
0005432848842	21075	Economy	6300.00
0005432328703	21075	Economy	6300.00
0005432383345	21075	Economy	6300.00
0005432328935	21075	Economy	6300.00
0005432328907	21075	Economy	6300.00
0005432328663	21075	Economy	6300.00
0005432328779	21075	Economy	6300.00
0005432383428	21075	Economy	6300.00
0005432383211	21075	Economy	6300.00
0005432328847	21075	Economy	6300.00
0005432329048	21075	Economy	6300.00
0005432383283	21075	Economy	6300.00
0005432328796	21075	Economy	6300.00
0005432383310	21075	Economy	6300.00
0005432328867	21075	Economy	6300.00
0005432054341	21075	Economy	6300.00
0005432328810	21075	Economy	6300.00
0005432383344	21075	Economy	6300.00
0005432383468	21075	Economy	6300.00
0005432328998	21075	Economy	6300.00
0005432383343	21075	Economy	6300.00
0005432383216	21075	Economy	6300.00
0005432383109	21075	Economy	6300.00
0005432328692	21075	Economy	6300.00
0005432383208	21075	Economy	6300.00
0005432328795	21075	Economy	6300.00
0005432383220	21075	Economy	6300.00
0005432383255	21075	Economy	6300.00
0005432383219	21075	Economy	6300.00
0005432328651	21075	Economy	6300.00
0005432383256	21075	Economy	6300.00
0005432329232	31234	Business	18900.00
0005432329225	31234	Business	18900.00
0005432383638	31234	Business	18900.00
0005432383616	31234	Business	18900.00
0005432329220	31234	Business	18900.00
0005432383628	31234	Business	18900.00
0005432329222	31234	Business	18900.00
0005432383633	31234	Business	18900.00
0005432383613	31234	Business	18900.00
0005432383637	31234	Business	18900.00
0005432329251	31234	Business	18900.00
0005432383618	31234	Business	18900.00
0005432329211	31234	Economy	6300.00
0005432329227	31234	Economy	6300.00
0005432383617	31234	Economy	6300.00
0005432329228	31234	Economy	6300.00
0005432383623	31234	Economy	6300.00
0005432383627	31234	Economy	6300.00
0005432329219	31234	Economy	6300.00
0005432383609	31234	Economy	6900.00
0005432287249	31234	Economy	6900.00
0005432329240	31234	Economy	6900.00
0005432329226	31234	Economy	6900.00
0005432329244	31234	Economy	6900.00
0005432383632	31234	Economy	6300.00
0005432329214	31234	Economy	6300.00
0005432329208	31234	Economy	6300.00
0005432329230	31234	Economy	6300.00
0005432329250	31234	Economy	6300.00
0005432383621	31234	Economy	6300.00
0005432329213	31234	Economy	6300.00
0005432329241	31234	Economy	6300.00
0005432329209	31234	Economy	6300.00
0005432329210	31234	Economy	6300.00
0005432383610	31234	Economy	6300.00
0005432383612	31234	Economy	6300.00
0005432287247	31234	Economy	6300.00
0005432287250	31234	Economy	6300.00
0005432383619	31234	Economy	6300.00
0005432329243	31234	Economy	6300.00
0005432287248	31234	Economy	6300.00
0005432329247	31234	Economy	6300.00
0005432287246	31234	Economy	6300.00
0005432329239	31234	Economy	6300.00
0005432383629	31234	Economy	6300.00
0005432329249	31234	Economy	6300.00
0005432383635	31234	Economy	6300.00
0005432383624	31234	Economy	6300.00
0005432329233	31234	Economy	6300.00
0005432329245	31234	Economy	6300.00
0005432329212	31234	Economy	6300.00
0005432383630	31234	Economy	6300.00
0005432383611	31234	Economy	6300.00
0005432329221	31234	Economy	6300.00
0005432329216	31234	Economy	6300.00
0005432329242	31234	Economy	6300.00
0005432329246	31234	Economy	6300.00
0005432329223	31234	Economy	6300.00
0005432329207	31234	Economy	6300.00
0005432329231	31234	Economy	6300.00
0005432383614	31234	Economy	6300.00
0005432383615	31234	Economy	6300.00
0005432383625	31234	Economy	6300.00
0005432329252	31234	Economy	6300.00
0005432329217	31234	Economy	6300.00
0005432329248	31234	Economy	6300.00
0005432329236	31234	Economy	6300.00
0005432329224	31234	Economy	6300.00
0005432383620	31234	Economy	6300.00
0005432329218	31234	Economy	6300.00
0005432329229	31234	Economy	6300.00
0005432383622	31234	Economy	6300.00
0005432329206	31234	Economy	6300.00
0005432329234	31234	Economy	6300.00
0005432329237	31234	Economy	6300.00
0005432383634	31234	Economy	6300.00
0005432329235	31234	Economy	6300.00
0005432383636	31234	Economy	6300.00
0005432287245	31234	Economy	6300.00
0005432383631	31234	Economy	6300.00
0005432383626	31234	Economy	6300.00
0005432329238	31234	Economy	6300.00
0005432329215	31234	Economy	6300.00
0005432424999	13336	Business	12700.00
0005432424990	13336	Business	12700.00
0005432425006	13336	Business	12700.00
0005432424982	13336	Business	12700.00
0005432424973	13336	Business	12700.00
0005432424965	13336	Business	12700.00
0005432424968	13336	Business	12700.00
0005432424992	13336	Economy	4200.00
0005432424971	13336	Economy	4200.00
0005432424978	13336	Economy	4200.00
0005432424967	13336	Economy	4200.00
0005432425003	13336	Economy	4700.00
0005432424963	13336	Economy	4200.00
0005432424972	13336	Economy	4200.00
0005432424970	13336	Economy	4200.00
0005432424994	13336	Economy	4200.00
0005432425000	13336	Economy	4200.00
0005432425004	13336	Economy	4200.00
0005432424975	13336	Economy	4200.00
0005432424976	13336	Economy	4200.00
0005432424964	13336	Economy	4200.00
0005432425001	13336	Economy	4200.00
0005432424974	13336	Economy	4200.00
0005432424997	13336	Economy	4200.00
0005432424991	13336	Economy	4200.00
0005432425008	13336	Economy	4200.00
0005432424984	13336	Economy	4200.00
0005432424980	13336	Economy	4200.00
0005432424981	13336	Economy	4200.00
0005432424998	13336	Economy	4200.00
0005432424995	13336	Economy	4200.00
0005432424988	13336	Economy	4200.00
0005432425007	13336	Economy	4200.00
0005432425002	13336	Economy	4200.00
0005432424969	13336	Economy	4200.00
0005432424985	13336	Economy	4200.00
0005432424993	13336	Economy	4200.00
0005432424989	13336	Economy	4200.00
0005432424987	13336	Economy	4200.00
0005432425005	13336	Economy	4200.00
0005432424962	13336	Economy	4200.00
0005432424996	13336	Economy	4200.00
0005432424979	13336	Economy	4200.00
0005432424986	13336	Economy	4200.00
0005432424966	13336	Economy	4200.00
0005432424983	13336	Economy	4200.00
0005432424977	13336	Economy	4200.00
0005432424462	30753	Business	12700.00
0005432424509	30753	Business	12700.00
0005432424530	30753	Business	12700.00
0005432424472	30753	Business	12700.00
0005432424524	30753	Business	12700.00
0005432424599	30753	Business	12700.00
0005432424425	30753	Business	12700.00
0005432424436	30753	Business	12700.00
0005432424565	30753	Business	12700.00
0005432424434	30753	Economy	4200.00
0005432424413	30753	Economy	4200.00
0005432424521	30753	Economy	4200.00
0005432424522	30753	Economy	4200.00
0005432424503	30753	Economy	4700.00
0005432424459	30753	Economy	4700.00
0005432424546	30753	Economy	4200.00
0005432424519	30753	Economy	4200.00
0005432424545	30753	Economy	4200.00
0005432424573	30753	Economy	4200.00
0005432424589	30753	Economy	4200.00
0005432424502	30753	Economy	4200.00
0005432424558	30753	Economy	4200.00
0005432424579	30753	Economy	4200.00
0005432424361	30753	Economy	4200.00
0005432424424	30753	Economy	4200.00
0005432424463	30753	Economy	4200.00
0005432424596	30753	Economy	4200.00
0005432424508	30753	Economy	4200.00
0005432424597	30753	Economy	4200.00
0005432424559	30753	Economy	4200.00
0005432424598	30753	Economy	4200.00
0005432424575	30753	Economy	4200.00
0005432424435	30753	Economy	4200.00
0005432424437	30753	Economy	4200.00
0005432424563	30753	Economy	4200.00
0005432424427	30753	Economy	4200.00
0005432424608	30753	Economy	4200.00
0005432424517	30753	Economy	4200.00
0005432424467	30753	Economy	4200.00
0005432424591	30753	Economy	4200.00
0005432424580	30753	Economy	4200.00
0005432424581	30753	Economy	4200.00
0005432424551	30753	Economy	4200.00
0005432424560	30753	Economy	4200.00
0005432424535	30753	Economy	4200.00
0005432424547	30753	Economy	4200.00
0005432424605	30753	Economy	4200.00
0005432424518	30753	Economy	4200.00
0005432424564	30753	Economy	4200.00
0005432424576	30753	Economy	4200.00
0005432817845	9582	Business	32600.00
0005432817848	9582	Business	32600.00
0005434186206	9582	Business	32600.00
0005434157502	9582	Business	32600.00
0005432817829	9582	Business	32600.00
0005432822300	9582	Business	32600.00
0005432901605	9582	Business	32600.00
0005432289027	9582	Business	32600.00
0005432901731	9582	Business	32600.00
0005434157536	9582	Business	32600.00
0005434186207	9582	Economy	10900.00
0005432901736	9582	Economy	10900.00
0005432817843	9582	Economy	10900.00
0005432817820	9582	Economy	10900.00
0005432901641	9582	Economy	10900.00
0005432817831	9582	Economy	10900.00
0005432817846	9582	Economy	10900.00
0005434157503	9582	Economy	10900.00
0005432822297	9582	Economy	10900.00
0005432822295	9582	Economy	11900.00
0005432817828	9582	Economy	11900.00
0005432817838	9582	Economy	11900.00
0005432817822	9582	Economy	11900.00
0005432817823	9582	Economy	11900.00
0005434186209	9582	Economy	10900.00
0005432822299	9582	Economy	10900.00
0005434186197	9582	Economy	10900.00
0005434448358	9582	Economy	10900.00
0005432817837	9582	Economy	10900.00
0005432817847	9582	Economy	10900.00
0005432901709	9582	Economy	10900.00
0005432817842	9582	Economy	10900.00
0005432901616	9582	Economy	10900.00
0005432901675	9582	Economy	10900.00
0005432901554	9582	Economy	10900.00
0005432817849	9582	Economy	10900.00
0005434448356	9582	Economy	10900.00
0005434186214	9582	Economy	10900.00
0005432817833	9582	Economy	10900.00
0005432817832	9582	Economy	10900.00
0005434186210	9582	Economy	10900.00
0005432817836	9582	Economy	10900.00
0005432817835	9582	Economy	10900.00
0005432817824	9582	Economy	10900.00
0005432901640	9582	Economy	10900.00
0005434186196	9582	Economy	10900.00
0005432817825	9582	Economy	10900.00
0005432817826	9582	Economy	10900.00
0005432901679	9582	Economy	10900.00
0005432817839	9582	Economy	10900.00
0005432901639	9582	Economy	10900.00
0005432901678	9582	Economy	10900.00
0005432822296	9582	Economy	10900.00
0005432901643	9582	Economy	10900.00
0005432901676	9582	Economy	10900.00
0005432901606	9582	Economy	10900.00
0005432901710	9582	Economy	10900.00
0005432822301	9582	Economy	10900.00
0005432817844	9582	Economy	10900.00
0005432289025	9582	Economy	10900.00
0005434448359	9582	Economy	10900.00
0005434157523	9582	Economy	10900.00
0005432901657	9582	Economy	10900.00
0005432817840	9582	Economy	10900.00
0005432901553	9582	Economy	10900.00
0005432901704	9582	Economy	10900.00
0005432817819	9582	Economy	10900.00
0005432901642	9582	Economy	10900.00
0005432822294	9582	Economy	10900.00
0005432817834	9582	Economy	10900.00
0005432289026	9582	Economy	10900.00
0005434157504	9582	Economy	10900.00
0005432817841	9582	Economy	10900.00
0005432817821	9582	Economy	10900.00
0005432817830	9582	Economy	10900.00
0005434186201	9582	Economy	10900.00
0005434157524	9582	Economy	10900.00
0005434448357	9582	Economy	10900.00
0005432822298	9582	Economy	10900.00
0005432817827	9582	Economy	10900.00
0005432817567	28980	Business	32600.00
0005434186231	28980	Business	32600.00
0005434157573	28980	Business	32600.00
0005432817695	28980	Business	32600.00
0005432817680	28980	Business	32600.00
0005434157576	28980	Business	32600.00
0005432822223	28980	Business	32600.00
0005432817522	28980	Business	32600.00
0005434157574	28980	Business	32600.00
0005432901820	28980	Business	32600.00
0005432817681	28980	Business	32600.00
0005434186233	28980	Economy	10900.00
0005432817656	28980	Economy	10900.00
0005432817614	28980	Economy	10900.00
0005432901831	28980	Economy	10900.00
0005432817623	28980	Economy	10900.00
0005432817715	28980	Economy	10900.00
0005434157575	28980	Economy	10900.00
0005432817591	28980	Economy	10900.00
0005432817417	28980	Economy	11900.00
0005432817565	28980	Economy	11900.00
0005432901829	28980	Economy	11900.00
0005432901825	28980	Economy	11900.00
0005432901823	28980	Economy	10900.00
0005432901833	28980	Economy	10900.00
0005432822228	28980	Economy	10900.00
0005434448328	28980	Economy	10900.00
0005432817657	28980	Economy	10900.00
0005432817475	28980	Economy	10900.00
0005432817525	28980	Economy	10900.00
0005432901819	28980	Economy	10900.00
0005434157572	28980	Economy	10900.00
0005432901830	28980	Economy	10900.00
0005434157577	28980	Economy	10900.00
0005432002102	28980	Economy	10900.00
0005432901827	28980	Economy	10900.00
0005432817579	28980	Economy	10900.00
0005432817679	28980	Economy	10900.00
0005432822218	28980	Economy	10900.00
0005432817590	28980	Economy	10900.00
0005432822236	28980	Economy	10900.00
0005434448318	28980	Economy	10900.00
0005432901821	28980	Economy	10900.00
0005432901834	28980	Economy	10900.00
0005432817602	28980	Economy	10900.00
0005432817589	28980	Economy	10900.00
0005432817555	28980	Economy	10900.00
0005432817664	28980	Economy	10900.00
0005432817556	28980	Economy	10900.00
0005432901824	28980	Economy	10900.00
0005432901832	28980	Economy	10900.00
0005432901826	28980	Economy	10900.00
0005432817686	28980	Economy	10900.00
0005432817523	28980	Economy	10900.00
0005432817587	28980	Economy	10900.00
0005432817569	28980	Economy	10900.00
0005432817528	28980	Economy	10900.00
0005432822224	28980	Economy	10900.00
0005434186232	28980	Economy	10900.00
0005434448327	28980	Economy	10900.00
0005432817580	28980	Economy	10900.00
0005432817586	28980	Economy	10900.00
0005432817598	28980	Economy	10900.00
0005432817702	28980	Economy	10900.00
0005432901828	28980	Economy	10900.00
0005432901818	28980	Economy	10900.00
0005432817474	28980	Economy	10900.00
0005432817440	28980	Economy	10900.00
0005434157578	28980	Economy	10900.00
0005432901817	28980	Economy	10900.00
0005432901822	28980	Economy	10900.00
0005432002101	28980	Economy	10900.00
0005434448326	28980	Economy	10900.00
0005432002100	28980	Economy	10900.00
0005434448314	28980	Economy	10900.00
0005432817566	28980	Economy	10900.00
0005432817492	28980	Economy	10900.00
0005432002104	28980	Economy	10900.00
0005432901816	28980	Economy	10900.00
0005432817592	28980	Economy	10900.00
0005432002103	28980	Economy	10900.00
0005432817527	28980	Economy	10900.00
0005432817634	28980	Economy	10900.00
0005432817624	28980	Economy	10900.00
0005432613912	15045	Economy	11000.00
0005432613913	15045	Economy	11000.00
0005435841096	15045	Economy	11000.00
0005432611756	15045	Economy	11000.00
0005435841095	15045	Economy	11000.00
0005432611757	15045	Economy	11000.00
0005432611758	15045	Economy	11000.00
0005432613910	15045	Economy	11000.00
0005432613911	15045	Economy	11000.00
0005435841831	31529	Economy	11000.00
0005432607588	31529	Economy	11000.00
0005432611714	31529	Economy	11000.00
0005432607589	31529	Economy	11000.00
0005435841832	31529	Economy	11000.00
0005432607592	31529	Economy	11000.00
0005433569747	11844	Business	105900.00
0005432948649	11844	Business	105900.00
0005433569762	11844	Business	105900.00
0005432948264	11844	Business	105900.00
0005433569734	11844	Business	105900.00
0005433569736	11844	Business	105900.00
0005433569726	11844	Business	105900.00
0005433569763	11844	Business	105900.00
0005432948449	11844	Business	105900.00
0005432948654	11844	Business	105900.00
0005433569722	11844	Business	105900.00
0005432948419	11844	Business	105900.00
0005433569766	11844	Business	105900.00
0005433569714	11844	Business	105900.00
0005432948484	11844	Business	105900.00
0005433569725	11844	Business	105900.00
0005432948410	11844	Business	105900.00
0005433569710	11844	Economy	35300.00
0005433569707	11844	Economy	35300.00
0005433569718	11844	Economy	35300.00
0005432948451	11844	Economy	35300.00
0005432948575	11844	Economy	35300.00
0005433569754	11844	Economy	35300.00
0005432948524	11844	Economy	35300.00
0005433569740	11844	Economy	35300.00
0005433569730	11844	Economy	35300.00
0005432948409	11844	Economy	35300.00
0005432948480	11844	Economy	38800.00
0005433569746	11844	Economy	38800.00
0005432948450	11844	Economy	38800.00
0005432948574	11844	Economy	38800.00
0005432948400	11844	Economy	35300.00
0005433569727	11844	Economy	35300.00
0005433569735	11844	Economy	35300.00
0005433569713	11844	Economy	35300.00
0005432948408	11844	Economy	35300.00
0005433569709	11844	Economy	35300.00
0005433569733	11844	Economy	35300.00
0005432948684	11844	Economy	35300.00
0005432948564	11844	Economy	35300.00
0005433569752	11844	Economy	35300.00
0005433569731	11844	Economy	35300.00
0005433569765	11844	Economy	35300.00
0005432948321	11844	Economy	35300.00
0005433569708	11844	Economy	35300.00
0005432948395	11844	Economy	35300.00
0005433569711	11844	Economy	35300.00
0005433569744	11844	Economy	35300.00
0005432948618	11844	Economy	35300.00
0005432948559	11844	Economy	35300.00
0005432948616	11844	Economy	35300.00
0005433569723	11844	Economy	35300.00
0005432948394	11844	Economy	35300.00
0005433569751	11844	Economy	35300.00
0005432948483	11844	Economy	35300.00
0005433569755	11844	Economy	35300.00
0005432948581	11844	Economy	35300.00
0005433569721	11844	Economy	35300.00
0005433569719	11844	Economy	35300.00
0005432948322	11844	Economy	35300.00
0005432948617	11844	Economy	35300.00
0005432948582	11844	Economy	35300.00
0005433569764	11844	Economy	35300.00
0005433569715	11844	Economy	35300.00
0005432948265	11844	Economy	35300.00
0005433569738	11844	Economy	35300.00
0005433569716	11844	Economy	35300.00
0005433569748	11844	Economy	35300.00
0005433569757	11844	Economy	35300.00
0005433569745	11844	Economy	35300.00
0005433569741	11844	Economy	35300.00
0005433569749	11844	Economy	35300.00
0005433569759	11844	Economy	35300.00
0005432948393	11844	Economy	35300.00
0005433569760	11844	Economy	35300.00
0005432948664	11844	Economy	35300.00
0005432948565	11844	Economy	35300.00
0005433569761	11844	Economy	35300.00
0005433569743	11844	Economy	35300.00
0005433569724	11844	Economy	35300.00
0005433569728	11844	Economy	35300.00
0005432948576	11844	Economy	35300.00
0005433569753	11844	Economy	35300.00
0005433569720	11844	Economy	35300.00
0005433569737	11844	Economy	35300.00
0005433569732	11844	Economy	35300.00
0005432948655	11844	Economy	35300.00
0005432948563	11844	Economy	35300.00
0005433569758	11844	Economy	35300.00
0005432948536	11844	Economy	35300.00
0005433569750	11844	Economy	35300.00
0005432948312	11844	Economy	35300.00
0005433569756	11844	Economy	35300.00
0005432948596	11844	Economy	35300.00
0005433569729	11844	Economy	35300.00
0005432948446	11844	Economy	35300.00
0005433569742	11844	Economy	35300.00
0005432948558	11844	Economy	35300.00
0005432948648	11844	Economy	35300.00
0005433569739	11844	Economy	35300.00
0005433569712	11844	Economy	35300.00
0005433569717	11844	Economy	35300.00
0005432948418	11844	Economy	35300.00
0005433569466	25289	Business	105900.00
0005433569410	25289	Business	105900.00
0005433569253	25289	Business	105900.00
0005433569465	25289	Business	105900.00
0005433569267	25289	Business	105900.00
0005432948993	25289	Business	105900.00
0005433569244	25289	Business	105900.00
0005432948990	25289	Business	105900.00
0005433569234	25289	Business	105900.00
0005432948986	25289	Business	105900.00
0005433569531	25289	Business	105900.00
0005433569182	25289	Business	105900.00
0005433569411	25289	Business	105900.00
0005432948996	25289	Business	105900.00
0005433569311	25289	Business	105900.00
0005433569179	25289	Business	105900.00
0005433569046	25289	Business	105900.00
0005433569451	25289	Business	105900.00
0005432949007	25289	Economy	35300.00
0005432949012	25289	Economy	35300.00
0005433569348	25289	Economy	35300.00
0005433569545	25289	Economy	35300.00
0005432949009	25289	Economy	35300.00
0005433569396	25289	Economy	35300.00
0005433569163	25289	Economy	35300.00
0005432949011	25289	Economy	35300.00
0005433569196	25289	Economy	35300.00
0005433569245	25289	Economy	35300.00
0005433569269	25289	Economy	35300.00
0005433568974	25289	Economy	35300.00
0005432949006	25289	Economy	38800.00
0005433569463	25289	Economy	38800.00
0005433569040	25289	Economy	38800.00
0005433569351	25289	Economy	38800.00
0005433569018	25289	Economy	35300.00
0005433569530	25289	Economy	35300.00
0005432949001	25289	Economy	35300.00
0005432948983	25289	Economy	35300.00
0005432949013	25289	Economy	35300.00
0005432948976	25289	Economy	35300.00
0005433569100	25289	Economy	35300.00
0005433569280	25289	Economy	35300.00
0005432948995	25289	Economy	35300.00
0005433569085	25289	Economy	35300.00
0005433569467	25289	Economy	35300.00
0005433568880	25289	Economy	35300.00
0005433569197	25289	Economy	35300.00
0005433569054	25289	Economy	35300.00
0005433569291	25289	Economy	35300.00
0005432948997	25289	Economy	35300.00
0005433569228	25289	Economy	35300.00
0005433569464	25289	Economy	35300.00
0005432948989	25289	Economy	35300.00
0005432949000	25289	Economy	35300.00
0005432949003	25289	Economy	35300.00
0005432949008	25289	Economy	35300.00
0005433569160	25289	Economy	35300.00
0005433568994	25289	Economy	35300.00
0005432948987	25289	Economy	35300.00
0005433568839	25289	Economy	35300.00
0005432949005	25289	Economy	35300.00
0005433569151	25289	Economy	35300.00
0005432948988	25289	Economy	35300.00
0005432948978	25289	Economy	35300.00
0005433569072	25289	Economy	35300.00
0005433569159	25289	Economy	35300.00
0005432948979	25289	Economy	35300.00
0005433569183	25289	Economy	35300.00
0005432948981	25289	Economy	35300.00
0005433569091	25289	Economy	35300.00
0005432948982	25289	Economy	35300.00
0005432948992	25289	Economy	35300.00
0005432948974	25289	Economy	35300.00
0005432948975	25289	Economy	35300.00
0005432948998	25289	Economy	35300.00
0005433568840	25289	Economy	35300.00
0005433569290	25289	Economy	35300.00
0005432948977	25289	Economy	35300.00
0005432948991	25289	Economy	35300.00
0005432948980	25289	Economy	35300.00
0005433569352	25289	Economy	35300.00
0005432949004	25289	Economy	35300.00
0005433569133	25289	Economy	35300.00
0005432948999	25289	Economy	35300.00
0005432949002	25289	Economy	35300.00
0005432948994	25289	Economy	35300.00
0005433568975	25289	Economy	35300.00
0005433569448	25289	Economy	35300.00
0005432948985	25289	Economy	35300.00
0005433569377	25289	Economy	35300.00
0005433569193	25289	Economy	35300.00
0005432949014	25289	Economy	35300.00
0005433569071	25289	Economy	35300.00
0005432948984	25289	Economy	35300.00
0005433569132	25289	Economy	35300.00
0005433569162	25289	Economy	35300.00
0005432949010	25289	Economy	35300.00
0005433569255	25289	Economy	35300.00
0005433569161	25289	Economy	35300.00
0005433811641	27938	Business	105400.00
0005433811642	27938	Economy	35100.00
0005433811627	27938	Economy	35100.00
0005433811636	27938	Economy	35100.00
0005433811629	27938	Economy	35100.00
0005433811637	27938	Economy	35100.00
0005433811635	27938	Economy	35100.00
0005433811640	27938	Economy	35100.00
0005433811626	27938	Economy	35100.00
0005433811633	27938	Economy	35100.00
0005434655035	5368	Business	67200.00
0005434655038	5368	Business	67200.00
0005435340319	5368	Business	67200.00
0005435340325	5368	Business	67200.00
0005435340320	5368	Business	67200.00
0005434655051	5368	Business	67200.00
0005434655039	5368	Business	67200.00
0005434655049	5368	Economy	22400.00
0005434655041	5368	Economy	22400.00
0005434655052	5368	Economy	22400.00
0005434655048	5368	Economy	22400.00
0005434655032	5368	Economy	22400.00
0005435340350	5368	Economy	22400.00
0005432114242	5368	Economy	22400.00
0005434655028	5368	Economy	24600.00
0005434655030	5368	Economy	24600.00
0005435340326	5368	Economy	22400.00
0005435340308	5368	Economy	22400.00
0005434655034	5368	Economy	22400.00
0005434655029	5368	Economy	22400.00
0005435340270	5368	Economy	22400.00
0005434655033	5368	Economy	22400.00
0005435340402	5368	Economy	22400.00
0005434655031	5368	Economy	22400.00
0005434655045	5368	Economy	22400.00
0005434655050	5368	Economy	22400.00
0005434655047	5368	Economy	22400.00
0005435340366	5368	Economy	22400.00
0005434655036	5368	Economy	22400.00
0005434655037	5368	Economy	22400.00
0005434655055	5368	Economy	22400.00
0005435340246	5368	Economy	22400.00
0005435340305	5368	Economy	22400.00
0005435340310	5368	Economy	22400.00
0005434655044	5368	Economy	22400.00
0005434655053	5368	Economy	22400.00
0005434656582	5368	Economy	22400.00
0005434655043	5368	Economy	22400.00
0005435340403	5368	Economy	22400.00
0005434655054	5368	Economy	22400.00
0005435340341	5368	Economy	22400.00
0005434655040	5368	Economy	22400.00
0005435340367	5368	Economy	22400.00
0005435340318	5368	Economy	22400.00
0005434656581	5368	Economy	22400.00
0005434655042	5368	Economy	22400.00
0005435340309	5368	Economy	22400.00
0005434656580	5368	Economy	22400.00
0005434655046	5368	Economy	22400.00
0005434655027	5368	Economy	22400.00
0005432114243	5368	Economy	22400.00
0005435340449	12503	Business	67200.00
0005434654805	12503	Business	67200.00
0005434654685	12503	Business	67200.00
0005435340443	12503	Business	67200.00
0005435340452	12503	Business	67200.00
0005434654759	12503	Business	67200.00
0005434656565	12503	Business	67200.00
0005434654901	12503	Economy	22400.00
0005434654848	12503	Economy	22400.00
0005434654699	12503	Economy	22400.00
0005435340442	12503	Economy	22400.00
0005434654804	12503	Economy	22400.00
0005434654723	12503	Economy	24600.00
0005434654751	12503	Economy	24600.00
0005434654807	12503	Economy	24600.00
0005434656556	12503	Economy	24600.00
0005435340455	12503	Economy	22400.00
0005434654684	12503	Economy	22400.00
0005434654822	12503	Economy	22400.00
0005435340445	12503	Economy	22400.00
0005434654780	12503	Economy	22400.00
0005435340450	12503	Economy	22400.00
0005434654798	12503	Economy	22400.00
0005435340454	12503	Economy	22400.00
0005435340446	12503	Economy	22400.00
0005435555396	12503	Economy	22400.00
0005435340448	12503	Economy	22400.00
0005434654888	12503	Economy	22400.00
0005434654803	12503	Economy	22400.00
0005434654806	12503	Economy	22400.00
0005434654686	12503	Economy	22400.00
0005435340447	12503	Economy	22400.00
0005435555395	12503	Economy	22400.00
0005434654808	12503	Economy	22400.00
0005435340453	12503	Economy	22400.00
0005434654887	12503	Economy	22400.00
0005434654875	12503	Economy	22400.00
0005435340451	12503	Economy	22400.00
0005434654752	12503	Economy	22400.00
0005434654741	12503	Economy	22400.00
0005434654830	12503	Economy	22400.00
0005434654593	12503	Economy	22400.00
0005434654855	12503	Economy	22400.00
0005434654791	12503	Economy	22400.00
0005435340456	12503	Economy	22400.00
0005434654838	12503	Economy	22400.00
0005434654713	12503	Economy	22400.00
0005434654681	12503	Economy	22400.00
0005434654856	12503	Economy	22400.00
0005435340444	12503	Economy	22400.00
0005433716596	7437	Business	32000.00
0005433716569	7437	Business	32000.00
0005433716562	7437	Business	32000.00
0005433656708	7437	Business	32000.00
0005433656710	7437	Business	32000.00
0005433716566	7437	Business	32000.00
0005433716558	7437	Business	32000.00
0005433716580	7437	Economy	10700.00
0005433716593	7437	Economy	10700.00
0005433716584	7437	Economy	10700.00
0005433716583	7437	Economy	10700.00
0005433722295	7437	Economy	10700.00
0005433689935	7437	Economy	10700.00
0005433716563	7437	Economy	10700.00
0005433716600	7437	Economy	10700.00
0005433716564	7437	Economy	10700.00
0005433719181	7437	Economy	10700.00
0005433716595	7437	Economy	10700.00
0005433716575	7437	Economy	10700.00
0005435266143	7437	Economy	10700.00
0005433716582	7437	Economy	10700.00
0005433716571	7437	Economy	10700.00
0005432078177	7437	Economy	10700.00
0005433716570	7437	Economy	10700.00
0005433656711	7437	Economy	10700.00
0005433656709	7437	Economy	10700.00
0005433716560	7437	Economy	10700.00
0005433716559	7437	Economy	10700.00
0005433716586	7437	Economy	10700.00
0005433716592	7437	Economy	10700.00
0005433716573	7437	Economy	10700.00
0005433716599	7437	Economy	10700.00
0005433690947	7437	Economy	10700.00
0005433722301	7437	Economy	10700.00
0005433716589	7437	Economy	11700.00
0005433689937	7437	Economy	11700.00
0005432428942	7437	Economy	11700.00
0005433722298	7437	Economy	11700.00
0005432078174	7437	Economy	11700.00
0005433716601	7437	Economy	10700.00
0005433722302	7437	Economy	10700.00
0005432428954	7437	Economy	10700.00
0005433716556	7437	Economy	10700.00
0005433722296	7437	Economy	10700.00
0005433716557	7437	Economy	10700.00
0005433722300	7437	Economy	10700.00
0005433722294	7437	Economy	10700.00
0005433716598	7437	Economy	10700.00
0005433716591	7437	Economy	10700.00
0005433689934	7437	Economy	10700.00
0005433716578	7437	Economy	10700.00
0005433656707	7437	Economy	10700.00
0005433719179	7437	Economy	10700.00
0005433689936	7437	Economy	10700.00
0005433716590	7437	Economy	10700.00
0005435266148	7437	Economy	10700.00
0005433716568	7437	Economy	10700.00
0005433722299	7437	Economy	10700.00
0005433716577	7437	Economy	10700.00
0005432078176	7437	Economy	10700.00
0005433716572	7437	Economy	10700.00
0005435266149	7437	Economy	10700.00
0005432428925	7437	Economy	10700.00
0005432078178	7437	Economy	10700.00
0005433716554	7437	Economy	10700.00
0005432078173	7437	Economy	10700.00
0005432428939	7437	Economy	10700.00
0005433716579	7437	Economy	10700.00
0005433716553	7437	Economy	10700.00
0005433690948	7437	Economy	10700.00
0005433719180	7437	Economy	10700.00
0005433716576	7437	Economy	10700.00
0005433716594	7437	Economy	10700.00
0005433722297	7437	Economy	10700.00
0005433716587	7437	Economy	10700.00
0005432078175	7437	Economy	10700.00
0005433716597	7437	Economy	10700.00
0005433716561	7437	Economy	10700.00
0005433716565	7437	Economy	10700.00
0005433716567	7437	Economy	10700.00
0005433716585	7437	Economy	10700.00
0005433716574	7437	Economy	10700.00
0005433716555	7437	Economy	10700.00
0005433716588	7437	Economy	10700.00
0005433716581	7437	Economy	10700.00
0005433716110	29226	Business	32000.00
0005433716312	29226	Business	32000.00
0005433716222	29226	Business	32000.00
0005433716346	29226	Business	32000.00
0005433716167	29226	Business	32000.00
0005433716292	29226	Economy	10700.00
0005433716003	29226	Economy	10700.00
0005433716275	29226	Economy	10700.00
0005433716144	29226	Economy	10700.00
0005433716160	29226	Economy	10700.00
0005433656673	29226	Economy	10700.00
0005433722223	29226	Economy	10700.00
0005433716248	29226	Economy	10700.00
0005433716389	29226	Economy	10700.00
0005433716096	29226	Economy	10700.00
0005433715903	29226	Economy	10700.00
0005433715995	29226	Economy	10700.00
0005433716240	29226	Economy	10700.00
0005433716069	29226	Economy	10700.00
0005433716004	29226	Economy	10700.00
0005433688824	29226	Economy	10700.00
0005433716108	29226	Economy	10700.00
0005433716041	29226	Economy	10700.00
0005433719150	29226	Economy	10700.00
0005433722209	29226	Economy	10700.00
0005433716150	29226	Economy	10700.00
0005433656674	29226	Economy	10700.00
0005433715956	29226	Economy	10700.00
0005433716188	29226	Economy	10700.00
0005433716249	29226	Economy	10700.00
0005433716166	29226	Economy	11700.00
0005433716217	29226	Economy	11700.00
0005433716211	29226	Economy	11700.00
0005433716234	29226	Economy	10700.00
0005432006798	29226	Economy	10700.00
0005433716410	29226	Economy	10700.00
0005433716270	29226	Economy	10700.00
0005432428971	29226	Economy	10700.00
0005433715992	29226	Economy	10700.00
0005433716035	29226	Economy	10700.00
0005433719158	29226	Economy	10700.00
0005433716112	29226	Economy	10700.00
0005433716230	29226	Economy	10700.00
0005433715994	29226	Economy	10700.00
0005433716173	29226	Economy	10700.00
0005433716151	29226	Economy	10700.00
0005433722226	29226	Economy	10700.00
0005433716078	29226	Economy	10700.00
0005433715955	29226	Economy	10700.00
0005433716050	29226	Economy	10700.00
0005433716051	29226	Economy	10700.00
0005433716411	29226	Economy	10700.00
0005433716223	29226	Economy	10700.00
0005433716111	29226	Economy	10700.00
0005433722222	29226	Economy	10700.00
0005433716142	29226	Economy	10700.00
0005433716200	29226	Economy	10700.00
0005433715993	29226	Economy	10700.00
0005433719157	29226	Economy	10700.00
0005433716210	29226	Economy	10700.00
0005433716143	29226	Economy	10700.00
0005433716165	29226	Economy	10700.00
0005433716159	29226	Economy	10700.00
0005432428972	29226	Economy	10700.00
0005433716070	29226	Economy	10700.00
0005433716114	29226	Economy	10700.00
0005433716115	29226	Economy	10700.00
0005433716291	29226	Economy	10700.00
0005433716247	29226	Economy	10700.00
0005433716311	29226	Economy	10700.00
0005433715944	29226	Economy	10700.00
0005432428970	29226	Economy	10700.00
0005433716269	29226	Economy	10700.00
0005433716445	29226	Economy	10700.00
0005432428969	29226	Economy	10700.00
0005433716328	29226	Economy	10700.00
0005433716091	29226	Economy	10700.00
0005434182278	8695	Business	36500.00
0005434095454	8695	Business	36500.00
0005434095456	8695	Economy	12200.00
0005434095450	8695	Economy	13400.00
0005434095446	8695	Economy	13400.00
0005434184673	8695	Economy	12200.00
0005434095455	8695	Economy	12200.00
0005434095453	8695	Economy	12200.00
0005434095458	8695	Economy	12200.00
0005434182226	8695	Economy	12200.00
0005434095451	8695	Economy	12200.00
0005434095457	8695	Economy	12200.00
0005434182277	8695	Economy	12200.00
0005434095448	8695	Economy	12200.00
0005434095449	8695	Economy	12200.00
0005434095447	8695	Economy	12200.00
0005434095445	8695	Economy	12200.00
0005434095452	8695	Economy	12200.00
0005434182343	11630	Business	36500.00
0005434182336	11630	Business	36500.00
0005434182339	11630	Business	36500.00
0005434143734	11630	Business	36500.00
0005434182334	11630	Business	36500.00
0005434182337	11630	Economy	12200.00
0005434095321	11630	Economy	12200.00
0005434095378	11630	Economy	13400.00
0005434095332	11630	Economy	12200.00
0005434183602	11630	Economy	12200.00
0005434182335	11630	Economy	12200.00
0005434095294	11630	Economy	12200.00
0005434183603	11630	Economy	12200.00
0005434182344	11630	Economy	12200.00
0005434095331	11630	Economy	12200.00
0005434182332	11630	Economy	12200.00
0005434095325	11630	Economy	12200.00
0005434182342	11630	Economy	12200.00
0005434182340	11630	Economy	12200.00
0005434182338	11630	Economy	12200.00
0005434095293	11630	Economy	12200.00
0005434143738	11630	Economy	12200.00
0005434095281	11630	Economy	12200.00
0005434095261	11630	Economy	12200.00
0005434182341	11630	Economy	12200.00
0005434184688	11630	Economy	12200.00
0005434095413	11630	Economy	12200.00
0005434182331	11630	Economy	12200.00
0005434182333	11630	Economy	12200.00
0005432906543	1432	Business	33000.00
0005433398345	1432	Business	33000.00
0005433398187	1432	Business	33000.00
0005433398332	1432	Business	33000.00
0005433398277	1432	Business	33000.00
0005433398212	1432	Business	33000.00
0005433398297	1432	Business	33000.00
0005433457018	1432	Business	33000.00
0005433398382	1432	Business	33000.00
0005433398369	1432	Business	33000.00
0005433398149	1432	Business	33000.00
0005433398099	1432	Business	33000.00
0005433398316	1432	Economy	11000.00
0005433398139	1432	Economy	11000.00
0005433398223	1432	Economy	11000.00
0005433398376	1432	Economy	11000.00
0005433398039	1432	Economy	11000.00
0005433398118	1432	Economy	11000.00
0005433398424	1432	Economy	11000.00
0005433398069	1432	Economy	11000.00
0005433398078	1432	Economy	12100.00
0005433398379	1432	Economy	12100.00
0005433398077	1432	Economy	12100.00
0005433398380	1432	Economy	12100.00
0005433398137	1432	Economy	12100.00
0005433398217	1432	Economy	11000.00
0005432906545	1432	Economy	11000.00
0005433398361	1432	Economy	11000.00
0005433398051	1432	Economy	11000.00
0005433398062	1432	Economy	11000.00
0005433398264	1432	Economy	11000.00
0005432297309	1432	Economy	11000.00
0005433398070	1432	Economy	11000.00
0005433398241	1432	Economy	11000.00
0005432297310	1432	Economy	11000.00
0005433398145	1432	Economy	11000.00
0005432906544	1432	Economy	11000.00
0005433398106	1432	Economy	11000.00
0005433457019	1432	Economy	11000.00
0005433398163	1432	Economy	11000.00
0005433398281	1432	Economy	11000.00
0005433398359	1432	Economy	11000.00
0005433398178	1432	Economy	11000.00
0005433398346	1432	Economy	11000.00
0005433398279	1432	Economy	11000.00
0005433398100	1432	Economy	11000.00
0005433398246	1432	Economy	11000.00
0005433398043	1432	Economy	11000.00
0005433398373	1432	Economy	11000.00
0005433398294	1432	Economy	11000.00
0005433398263	1432	Economy	11000.00
0005433398061	1432	Economy	11000.00
0005433398333	1432	Economy	11000.00
0005433398140	1432	Economy	11000.00
0005433398412	1432	Economy	11000.00
0005433398164	1432	Economy	11000.00
0005433398218	1432	Economy	11000.00
0005433398295	1432	Economy	11000.00
0005433398052	1432	Economy	11000.00
0005433398299	1432	Economy	11000.00
0005433398375	1432	Economy	11000.00
0005433398068	1432	Economy	11000.00
0005433398053	1432	Economy	11000.00
0005433398213	1432	Economy	11000.00
0005433398287	1432	Economy	11000.00
0005433398138	1432	Economy	11000.00
0005433398177	1432	Economy	11000.00
0005433398222	1432	Economy	11000.00
0005433398383	1432	Economy	11000.00
0005433398293	1432	Economy	11000.00
0005433398374	1432	Economy	11000.00
0005433398315	1432	Economy	11000.00
0005433398291	1432	Economy	11000.00
0005433398360	1432	Economy	11000.00
0005433398141	1432	Economy	11000.00
0005433398298	1432	Economy	11000.00
0005432906542	1432	Economy	11000.00
0005433398066	1432	Economy	11000.00
0005433457020	1432	Economy	11000.00
0005432297308	1432	Economy	11000.00
0005433398107	1432	Economy	11000.00
0005433398150	1432	Economy	11000.00
0005433398655	19275	Business	33000.00
0005433398638	19275	Business	33000.00
0005433398663	19275	Business	33000.00
0005433398640	19275	Business	33000.00
0005435732391	19275	Business	33000.00
0005433398649	19275	Business	33000.00
0005433398652	19275	Business	33000.00
0005435732398	19275	Economy	11000.00
0005433398664	19275	Economy	11000.00
0005435732386	19275	Economy	11000.00
0005433398632	19275	Economy	11000.00
0005433398661	19275	Economy	11000.00
0005433398641	19275	Economy	11000.00
0005433398653	19275	Economy	12100.00
0005433398634	19275	Economy	12100.00
0005433398657	19275	Economy	12100.00
0005433398666	19275	Economy	11000.00
0005433398659	19275	Economy	11000.00
0005433398651	19275	Economy	11000.00
0005433398669	19275	Economy	11000.00
0005433398660	19275	Economy	11000.00
0005433398635	19275	Economy	11000.00
0005433398629	19275	Economy	11000.00
0005433398643	19275	Economy	11000.00
0005433398665	19275	Economy	11000.00
0005433398626	19275	Economy	11000.00
0005433398668	19275	Economy	11000.00
0005433398639	19275	Economy	11000.00
0005433398650	19275	Economy	11000.00
0005435732368	19275	Economy	11000.00
0005435732416	19275	Economy	11000.00
0005435732351	19275	Economy	11000.00
0005435732365	19275	Economy	11000.00
0005433398631	19275	Economy	11000.00
0005433398622	19275	Economy	11000.00
0005433398633	19275	Economy	11000.00
0005433398667	19275	Economy	11000.00
0005433398644	19275	Economy	11000.00
0005433398623	19275	Economy	11000.00
0005433456984	19275	Economy	11000.00
0005433398648	19275	Economy	11000.00
0005435732390	19275	Economy	11000.00
0005433398636	19275	Economy	11000.00
0005435732343	19275	Economy	11000.00
0005433398662	19275	Economy	11000.00
0005433398637	19275	Economy	11000.00
0005432906565	19275	Economy	11000.00
0005433398628	19275	Economy	11000.00
0005435732355	19275	Economy	11000.00
0005433398645	19275	Economy	11000.00
0005433398642	19275	Economy	11000.00
0005435732397	19275	Economy	11000.00
0005433456976	19275	Economy	11000.00
0005433398627	19275	Economy	11000.00
0005433398646	19275	Economy	11000.00
0005433398630	19275	Economy	11000.00
0005432906566	19275	Economy	11000.00
0005433398624	19275	Economy	11000.00
0005433398625	19275	Economy	11000.00
0005433398656	19275	Economy	11000.00
0005433398658	19275	Economy	11000.00
0005433398647	19275	Economy	11000.00
0005433398654	19275	Economy	11000.00
0005434443746	17346	Economy	14100.00
0005434443712	17346	Economy	14100.00
0005434443751	17346	Economy	14100.00
0005434443779	17346	Economy	14100.00
0005434443752	17346	Economy	14100.00
0005434443802	17346	Economy	14100.00
0005434443684	17346	Economy	14100.00
0005434443812	17346	Economy	14100.00
0005434443716	17346	Economy	14100.00
0005434443780	17346	Economy	14100.00
0005434443887	20572	Economy	15600.00
0005434443888	20572	Economy	14100.00
0005434443891	20572	Economy	14100.00
0005434443897	20572	Economy	14100.00
0005434443895	20572	Economy	14100.00
0005434443889	20572	Economy	14100.00
0005434443902	20572	Economy	14100.00
0005434443892	20572	Economy	14100.00
0005434443901	20572	Economy	14100.00
0005434443890	20572	Economy	14100.00
0005434443894	20572	Economy	14100.00
0005434443898	20572	Economy	14100.00
0005434443893	20572	Economy	14100.00
0005434443896	20572	Economy	14100.00
0005434443899	20572	Economy	14100.00
0005434443900	20572	Economy	14100.00
0005434954657	7230	Economy	5800.00
0005434954659	7230	Economy	5800.00
0005434954658	7230	Economy	5800.00
0005434954656	7230	Economy	5800.00
0005435377594	7230	Economy	5800.00
0005435377595	7230	Economy	5800.00
0005435377593	7230	Economy	5800.00
0005434954655	7230	Economy	5800.00
0005435377592	7230	Economy	5800.00
0005435377610	28309	Economy	5800.00
0005434954629	28309	Economy	5800.00
0005434954621	28309	Economy	5800.00
0005434954620	28309	Economy	5800.00
0005434954640	28309	Economy	5800.00
0005434954617	28309	Economy	5800.00
0005434954630	28309	Economy	5800.00
0005435377609	28309	Economy	5800.00
0005434954618	28309	Economy	5800.00
0005435377608	28309	Economy	5800.00
0005435893682	4495	Economy	15400.00
0005434351853	4495	Economy	14000.00
0005434351848	4495	Economy	14000.00
0005435893678	4495	Economy	14000.00
0005434351852	4495	Economy	14000.00
0005434351855	4495	Economy	14000.00
0005434351851	4495	Economy	14000.00
0005434351849	4495	Economy	14000.00
0005434351850	4495	Economy	14000.00
0005434351845	4495	Economy	14000.00
0005435893660	4495	Economy	14000.00
0005434351854	4495	Economy	14000.00
0005434351847	4495	Economy	14000.00
0005434351844	4495	Economy	14000.00
0005434351856	4495	Economy	14000.00
0005434351846	4495	Economy	14000.00
0005435893614	4495	Economy	14000.00
0005435893714	29627	Economy	15400.00
0005434351722	29627	Economy	14000.00
0005434351724	29627	Economy	14000.00
0005435893715	29627	Economy	14000.00
0005434351691	29627	Economy	14000.00
0005435893720	29627	Economy	14000.00
0005434351723	29627	Economy	14000.00
0005435893717	29627	Economy	14000.00
0005435893719	29627	Economy	14000.00
0005435893718	29627	Economy	14000.00
0005435893721	29627	Economy	14000.00
0005434351786	29627	Economy	14000.00
0005435893722	29627	Economy	14000.00
0005435893716	29627	Economy	14000.00
0005434351726	29627	Economy	14000.00
0005433343019	1094	Business	30600.00
0005433343167	1094	Business	30600.00
0005433343216	1094	Business	30600.00
0005433343110	1094	Business	30600.00
0005433343681	1094	Business	30600.00
0005433462773	1094	Business	30600.00
0005433343288	1094	Business	30600.00
0005433343166	1094	Business	30600.00
0005434446547	1094	Business	30600.00
0005433343013	1094	Business	30600.00
0005433343489	1094	Business	30600.00
0005433343360	1094	Business	30600.00
0005434445272	1094	Business	30600.00
0005433343337	1094	Economy	11200.00
0005433343132	1094	Economy	11200.00
0005435092192	1094	Economy	10200.00
0005433343794	1094	Economy	10200.00
0005433343313	1094	Economy	10200.00
0005433343793	1094	Economy	10200.00
0005433343685	1094	Economy	10200.00
0005433158140	1094	Economy	10200.00
0005433343421	1094	Economy	10200.00
0005434446546	1094	Economy	10200.00
0005433269740	1094	Economy	10200.00
0005433343763	1094	Economy	10200.00
0005433463929	1094	Economy	10200.00
0005433343795	1094	Economy	10200.00
0005435092197	1094	Economy	10200.00
0005433343125	1094	Economy	10200.00
0005433343696	1094	Economy	10200.00
0005433343396	1094	Economy	10200.00
0005433343435	1094	Economy	10200.00
0005435092195	1094	Economy	10200.00
0005433343189	1094	Economy	10200.00
0005433463927	1094	Economy	10200.00
0005433343491	1094	Economy	10200.00
0005433343503	1094	Economy	10200.00
0005433343551	1094	Economy	10200.00
0005433343597	1094	Economy	10200.00
0005433343495	1094	Economy	10200.00
0005433343381	1094	Economy	10200.00
0005433343126	1094	Economy	10200.00
0005434445271	1094	Economy	10200.00
0005433343512	1094	Economy	10200.00
0005433343382	1094	Economy	10200.00
0005433343305	1094	Economy	10200.00
0005433343604	1094	Economy	10200.00
0005433343531	1094	Economy	10200.00
0005433343544	1094	Economy	10200.00
0005433342894	1094	Economy	10200.00
0005433343119	1094	Economy	10200.00
0005433343487	1094	Economy	10200.00
0005433343323	1094	Economy	10200.00
0005433343014	1094	Economy	10200.00
0005433343358	1094	Economy	10200.00
0005434446545	1094	Economy	10200.00
0005433343773	1094	Economy	10200.00
0005433343307	1094	Economy	10200.00
0005433269753	1094	Economy	10200.00
0005433343372	1094	Economy	10200.00
0005433343494	1094	Economy	10200.00
0005433343436	1094	Economy	10200.00
0005433343296	1094	Economy	10200.00
0005433343384	1094	Economy	10200.00
0005433343239	1094	Economy	10200.00
0005435092191	1094	Economy	10200.00
0005433343326	1094	Economy	10200.00
0005433343485	1094	Economy	10200.00
0005433343574	1094	Economy	10200.00
0005435092199	1094	Economy	10200.00
0005433343641	1094	Economy	10200.00
0005433343532	1094	Economy	10200.00
0005433343439	1094	Economy	10200.00
0005433343555	1094	Economy	10200.00
0005433158138	1094	Economy	10200.00
0005433343238	1094	Economy	10200.00
0005433343976	1094	Economy	10200.00
0005435092198	1094	Economy	10200.00
0005432293239	1094	Economy	10200.00
0005433343476	1094	Economy	10200.00
0005433343663	1094	Economy	10200.00
0005433343566	1094	Economy	11200.00
0005435545844	1094	Economy	10200.00
0005433343554	1094	Economy	11200.00
0005433343434	1094	Economy	11200.00
0005433158139	1094	Economy	10200.00
0005435092193	1094	Economy	10200.00
0005433343664	1094	Economy	10200.00
0005433343862	1094	Economy	10200.00
0005433343474	1094	Economy	10200.00
0005433343605	1094	Economy	10200.00
0005433343470	1094	Economy	10200.00
0005433343469	1094	Economy	10200.00
0005433343787	1094	Economy	10200.00
0005433342893	1094	Economy	10200.00
0005432293238	1094	Economy	10200.00
0005433342990	1094	Economy	10200.00
0005433343342	1094	Economy	10200.00
0005433343373	1094	Economy	10200.00
0005433343334	1094	Economy	10200.00
0005433343137	1094	Economy	10200.00
0005433343668	1094	Economy	10200.00
0005433463928	1094	Economy	10200.00
0005433343335	1094	Economy	10200.00
0005433343686	1094	Economy	10200.00
0005435092194	1094	Economy	10200.00
0005433343020	1094	Economy	10200.00
0005433343682	1094	Economy	10200.00
0005433343109	1094	Economy	10200.00
0005433463926	1094	Economy	10200.00
0005433343543	1094	Economy	10200.00
0005433343725	1094	Economy	10200.00
0005433343282	1094	Economy	10200.00
0005433343060	1094	Economy	10200.00
0005433343486	1094	Economy	10200.00
0005433343516	1094	Economy	10200.00
0005433462772	1094	Economy	10200.00
0005433343120	1094	Economy	10200.00
0005433343283	1094	Economy	10200.00
0005433343475	1094	Economy	10200.00
0005433343237	1094	Economy	10200.00
0005433343726	1094	Economy	10200.00
0005433343788	1094	Economy	10200.00
0005433343016	1094	Economy	10200.00
0005433343630	1094	Economy	10200.00
0005435092196	1094	Economy	10200.00
0005434446544	1094	Economy	10200.00
0005433343018	1094	Economy	10200.00
0005435092190	1094	Economy	10200.00
0005433343705	1094	Economy	10200.00
0005433343242	1094	Economy	10200.00
0005433343608	1094	Economy	10200.00
0005433343727	1094	Economy	10200.00
0005433343490	1094	Economy	10200.00
0005433344310	17079	Business	30600.00
0005433159338	17079	Business	30600.00
0005433344273	17079	Business	30600.00
0005435092127	17079	Business	30600.00
0005433344315	17079	Business	30600.00
0005433344230	17079	Business	30600.00
0005433344264	17079	Business	30600.00
0005435508310	17079	Business	30600.00
0005435508380	17079	Business	30600.00
0005433344237	17079	Business	30600.00
0005435508311	17079	Business	30600.00
0005433344302	17079	Business	30600.00
0005433344268	17079	Business	30600.00
0005435092152	17079	Business	30600.00
0005433344309	17079	Business	30600.00
0005433344229	17079	Business	30600.00
0005433344313	17079	Business	30600.00
0005433269786	17079	Business	30600.00
0005433344316	17079	Economy	11200.00
0005433344258	17079	Economy	11200.00
0005433344272	17079	Economy	10200.00
0005433344277	17079	Economy	10200.00
0005435092104	17079	Economy	10200.00
0005433344243	17079	Economy	10200.00
0005435092150	17079	Economy	10200.00
0005433269785	17079	Economy	10200.00
0005433344320	17079	Economy	10200.00
0005433344318	17079	Economy	10200.00
0005434445248	17079	Economy	10200.00
0005433344278	17079	Economy	10200.00
0005433344251	17079	Economy	10200.00
0005435092107	17079	Economy	10200.00
0005433344321	17079	Economy	10200.00
0005433344311	17079	Economy	10200.00
0005433344319	17079	Economy	10200.00
0005433344297	17079	Economy	10200.00
0005433344280	17079	Economy	10200.00
0005433344275	17079	Economy	10200.00
0005433344238	17079	Economy	10200.00
0005433344314	17079	Economy	10200.00
0005433344252	17079	Economy	10200.00
0005433344322	17079	Economy	10200.00
0005435508338	17079	Economy	10200.00
0005433159339	17079	Economy	10200.00
0005435508378	17079	Economy	10200.00
0005433344293	17079	Economy	10200.00
0005433344285	17079	Economy	10200.00
0005433344257	17079	Economy	10200.00
0005433344289	17079	Economy	10200.00
0005433344328	17079	Economy	10200.00
0005433344255	17079	Economy	10200.00
0005433344294	17079	Economy	10200.00
0005435508365	17079	Economy	10200.00
0005433344291	17079	Economy	10200.00
0005433344317	17079	Economy	10200.00
0005433344288	17079	Economy	10200.00
0005433344259	17079	Economy	10200.00
0005433344233	17079	Economy	10200.00
0005435092118	17079	Economy	10200.00
0005433344296	17079	Economy	10200.00
0005433344256	17079	Economy	10200.00
0005433344292	17079	Economy	10200.00
0005433344266	17079	Economy	10200.00
0005433344303	17079	Economy	10200.00
0005433344249	17079	Economy	10200.00
0005433344246	17079	Economy	10200.00
0005433344306	17079	Economy	10200.00
0005433344261	17079	Economy	10200.00
0005433344284	17079	Economy	10200.00
0005433344260	17079	Economy	10200.00
0005433269784	17079	Economy	10200.00
0005433344300	17079	Economy	10200.00
0005433344281	17079	Economy	10200.00
0005433344245	17079	Economy	10200.00
0005433344263	17079	Economy	10200.00
0005433344279	17079	Economy	10200.00
0005433344235	17079	Economy	10200.00
0005433344231	17079	Economy	10200.00
0005433344287	17079	Economy	10200.00
0005433344269	17079	Economy	10200.00
0005433344327	17079	Economy	10200.00
0005435508372	17079	Economy	10200.00
0005433344236	17079	Economy	10200.00
0005433344262	17079	Economy	10200.00
0005433344242	17079	Economy	11200.00
0005434445247	17079	Economy	10200.00
0005433344248	17079	Economy	10200.00
0005433344286	17079	Economy	10200.00
0005433344329	17079	Economy	10200.00
0005433344244	17079	Economy	10200.00
0005433269781	17079	Economy	10200.00
0005433344325	17079	Economy	10200.00
0005434445249	17079	Economy	10200.00
0005435508366	17079	Economy	10200.00
0005433344283	17079	Economy	10200.00
0005433344271	17079	Economy	10200.00
0005433344324	17079	Economy	10200.00
0005433344274	17079	Economy	10200.00
0005433344267	17079	Economy	10200.00
0005435508387	17079	Economy	10200.00
0005433344240	17079	Economy	10200.00
0005434445245	17079	Economy	10200.00
0005433344276	17079	Economy	10200.00
0005433344304	17079	Economy	10200.00
0005433344239	17079	Economy	10200.00
0005433344295	17079	Economy	10200.00
0005433344307	17079	Economy	10200.00
0005433344326	17079	Economy	10200.00
0005433344253	17079	Economy	10200.00
0005433344312	17079	Economy	10200.00
0005433344232	17079	Economy	10200.00
0005433344290	17079	Economy	10200.00
0005433344308	17079	Economy	10200.00
0005433344234	17079	Economy	10200.00
0005433344250	17079	Economy	10200.00
0005433344298	17079	Economy	10200.00
0005433269782	17079	Economy	10200.00
0005433344305	17079	Economy	10200.00
0005435092151	17079	Economy	10200.00
0005433269787	17079	Economy	10200.00
0005433344241	17079	Economy	10200.00
0005433344301	17079	Economy	10200.00
0005433344323	17079	Economy	10200.00
0005433344247	17079	Economy	10200.00
0005435508386	17079	Economy	10200.00
0005433344270	17079	Economy	10200.00
0005434445246	17079	Economy	10200.00
0005435508390	17079	Economy	10200.00
0005433344265	17079	Economy	10200.00
0005433344299	17079	Economy	10200.00
0005433344254	17079	Economy	10200.00
0005435508371	17079	Economy	10200.00
0005433269783	17079	Economy	10200.00
0005433344282	17079	Economy	10200.00
0005435092135	17079	Economy	10200.00
0005432433743	12782	Business	40300.00
0005434067710	12782	Business	40300.00
0005434081917	12782	Business	40300.00
0005434026710	12782	Business	40300.00
0005434067778	12782	Business	40300.00
0005434067747	12782	Business	40300.00
0005434067718	12782	Business	40300.00
0005434067803	12782	Business	40300.00
0005434082023	12782	Business	40300.00
0005434067862	12782	Business	40300.00
0005434067761	12782	Business	40300.00
0005434067630	12782	Business	40300.00
0005434067606	12782	Economy	13400.00
0005434067340	12782	Economy	13400.00
0005434067667	12782	Economy	13400.00
0005434067646	12782	Economy	13400.00
0005434081971	12782	Economy	13400.00
0005434082000	12782	Economy	13400.00
0005434082084	12782	Economy	13400.00
0005434067827	12782	Economy	13400.00
0005434081995	12782	Economy	13400.00
0005434067821	12782	Economy	13400.00
0005434082004	12782	Economy	13400.00
0005434067847	12782	Economy	13400.00
0005434067607	12782	Economy	13400.00
0005434067642	12782	Economy	13400.00
0005434067832	12782	Economy	13400.00
0005434068006	12782	Economy	13400.00
0005432433742	12782	Economy	13400.00
0005434067398	12782	Economy	13400.00
0005434067830	12782	Economy	13400.00
0005434067773	12782	Economy	13400.00
0005434067854	12782	Economy	13400.00
0005434067651	12782	Economy	13400.00
0005432433744	12782	Economy	13400.00
0005434026713	12782	Economy	13400.00
0005434081883	12782	Economy	13400.00
0005434067822	12782	Economy	13400.00
0005433989777	12782	Economy	13400.00
0005434067904	12782	Economy	13400.00
0005434067722	12782	Economy	13400.00
0005434067802	12782	Economy	13400.00
0005434067772	12782	Economy	13400.00
0005434067771	12782	Economy	13400.00
0005433812929	12782	Economy	13400.00
0005434067835	12782	Economy	13400.00
0005434068005	12782	Economy	13400.00
0005434081934	12782	Economy	14800.00
0005434081979	12782	Economy	14800.00
0005434067861	12782	Economy	14800.00
0005434067882	12782	Economy	14800.00
0005434067683	12782	Economy	14800.00
0005432433747	12782	Economy	13400.00
0005434067402	12782	Economy	13400.00
0005432159915	12782	Economy	13400.00
0005434067801	12782	Economy	13400.00
0005434068134	12782	Economy	13400.00
0005433812931	12782	Economy	13400.00
0005432161180	12782	Economy	13400.00
0005434067664	12782	Economy	13400.00
0005433989782	12782	Economy	13400.00
0005434067777	12782	Economy	13400.00
0005434081944	12782	Economy	13400.00
0005433989779	12782	Economy	13400.00
0005434067780	12782	Economy	13400.00
0005434067652	12782	Economy	13400.00
0005434067666	12782	Economy	13400.00
0005434067623	12782	Economy	13400.00
0005432159912	12782	Economy	13400.00
0005434067807	12782	Economy	13400.00
0005432433746	12782	Economy	13400.00
0005434068007	12782	Economy	13400.00
0005432433745	12782	Economy	13400.00
0005434067719	12782	Economy	13400.00
0005434067760	12782	Economy	13400.00
0005434067943	12782	Economy	13400.00
0005434067894	12782	Economy	13400.00
0005434081962	12782	Economy	13400.00
0005432159913	12782	Economy	13400.00
0005434067800	12782	Economy	13400.00
0005434026709	12782	Economy	13400.00
0005434081872	12782	Economy	13400.00
0005434067818	12782	Economy	13400.00
0005434067781	12782	Economy	13400.00
0005434067572	12782	Economy	13400.00
0005434067711	12782	Economy	13400.00
0005434067826	12782	Economy	13400.00
0005434067576	12782	Economy	13400.00
0005434082001	12782	Economy	13400.00
0005434067712	12782	Economy	13400.00
0005434067831	12782	Economy	13400.00
0005433989781	12782	Economy	13400.00
0005432159914	12782	Economy	13400.00
0005434067784	12782	Economy	13400.00
0005434081980	12782	Economy	13400.00
0005434082022	12782	Economy	13400.00
0005434082010	12782	Economy	13400.00
0005434068011	12782	Economy	13400.00
0005433812930	12782	Economy	13400.00
0005434067786	12782	Economy	13400.00
0005434067702	12782	Economy	13400.00
0005434081863	12782	Economy	13400.00
0005434067662	12782	Economy	13400.00
0005434067631	12782	Economy	13400.00
0005434067984	12782	Economy	13400.00
0005432161179	12782	Economy	13400.00
0005434081984	12782	Economy	13400.00
0005434067578	12782	Economy	13400.00
0005434081965	12782	Economy	13400.00
0005433989767	12782	Economy	13400.00
0005434081994	12782	Economy	13400.00
0005435283411	12782	Economy	13400.00
0005434068010	12782	Economy	13400.00
0005433812928	12782	Economy	13400.00
0005434081873	12782	Economy	13400.00
0005434081947	12782	Economy	13400.00
0005434082160	30636	Business	40300.00
0005434068359	30636	Business	40300.00
0005434026724	30636	Business	40300.00
0005433989824	30636	Business	40300.00
0005434068341	30636	Business	40300.00
0005434082165	30636	Business	40300.00
0005434068383	30636	Business	40300.00
0005434068334	30636	Business	40300.00
0005434068397	30636	Business	40300.00
0005434068352	30636	Business	40300.00
0005434068329	30636	Business	40300.00
0005434068369	30636	Business	40300.00
0005433812897	30636	Economy	13400.00
0005434068366	30636	Economy	13400.00
0005434068380	30636	Economy	13400.00
0005434082158	30636	Economy	13400.00
0005434068367	30636	Economy	13400.00
0005432150283	30636	Economy	13400.00
0005432150286	30636	Economy	13400.00
0005433812896	30636	Economy	13400.00
0005434068381	30636	Economy	13400.00
0005434068336	30636	Economy	13400.00
0005434068391	30636	Economy	13400.00
0005434068331	30636	Economy	13400.00
0005434068351	30636	Economy	13400.00
0005434068378	30636	Economy	13400.00
0005433812908	30636	Economy	13400.00
0005434082170	30636	Economy	13400.00
0005433812909	30636	Economy	13400.00
0005434082166	30636	Economy	13400.00
0005434068393	30636	Economy	13400.00
0005433812898	30636	Economy	13400.00
0005434082163	30636	Economy	13400.00
0005434068338	30636	Economy	13400.00
0005432186912	30636	Economy	13400.00
0005434068328	30636	Economy	13400.00
0005433812894	30636	Economy	13400.00
0005434068382	30636	Economy	13400.00
0005433989826	30636	Economy	13400.00
0005434068362	30636	Economy	13400.00
0005434082164	30636	Economy	13400.00
0005434068370	30636	Economy	13400.00
0005434082167	30636	Economy	13400.00
0005434082159	30636	Economy	13400.00
0005434068350	30636	Economy	13400.00
0005434068335	30636	Economy	13400.00
0005434082171	30636	Economy	13400.00
0005434068343	30636	Economy	13400.00
0005434068375	30636	Economy	13400.00
0005434082168	30636	Economy	13400.00
0005434068349	30636	Economy	14800.00
0005432433706	30636	Economy	14800.00
0005434082169	30636	Economy	14800.00
0005434068376	30636	Economy	14800.00
0005434068379	30636	Economy	14800.00
0005432150281	30636	Economy	14800.00
0005432186911	30636	Economy	13400.00
0005434068347	30636	Economy	13400.00
0005432433693	30636	Economy	13400.00
0005434068374	30636	Economy	13400.00
0005432150280	30636	Economy	13400.00
0005434068387	30636	Economy	13400.00
0005434082162	30636	Economy	13400.00
0005434068390	30636	Economy	13400.00
0005434068337	30636	Economy	13400.00
0005434068346	30636	Economy	13400.00
0005432433684	30636	Economy	13400.00
0005434068340	30636	Economy	13400.00
0005434068368	30636	Economy	13400.00
0005434082161	30636	Economy	13400.00
0005434068373	30636	Economy	13400.00
0005434068377	30636	Economy	13400.00
0005434068389	30636	Economy	13400.00
0005434068400	30636	Economy	13400.00
0005434068365	30636	Economy	13400.00
0005434068361	30636	Economy	13400.00
0005434068399	30636	Economy	13400.00
0005434068333	30636	Economy	13400.00
0005434068360	30636	Economy	13400.00
0005434068339	30636	Economy	13400.00
0005434068364	30636	Economy	13400.00
0005434068356	30636	Economy	13400.00
0005434068357	30636	Economy	13400.00
0005434068330	30636	Economy	13400.00
0005434068384	30636	Economy	13400.00
0005432150282	30636	Economy	13400.00
0005434068332	30636	Economy	13400.00
0005434068394	30636	Economy	13400.00
0005434068344	30636	Economy	13400.00
0005434068401	30636	Economy	13400.00
0005434068392	30636	Economy	13400.00
0005434068353	30636	Economy	13400.00
0005434068388	30636	Economy	13400.00
0005433989825	30636	Economy	13400.00
0005434026727	30636	Economy	13400.00
0005432150284	30636	Economy	13400.00
0005432150287	30636	Economy	13400.00
0005433812905	30636	Economy	13400.00
0005434068385	30636	Economy	13400.00
0005434068354	30636	Economy	13400.00
0005434082174	30636	Economy	13400.00
0005434068396	30636	Economy	13400.00
0005434068398	30636	Economy	13400.00
0005434068371	30636	Economy	13400.00
0005434068348	30636	Economy	13400.00
0005434068372	30636	Economy	13400.00
0005434068345	30636	Economy	13400.00
0005433812907	30636	Economy	13400.00
0005434068355	30636	Economy	13400.00
0005434026726	30636	Economy	13400.00
0005434026725	30636	Economy	13400.00
0005433812915	30636	Economy	13400.00
0005432433716	30636	Economy	13400.00
0005434068342	30636	Economy	13400.00
0005434068358	30636	Economy	13400.00
0005432433702	30636	Economy	13400.00
0005433812895	30636	Economy	13400.00
0005433989823	30636	Economy	13400.00
0005434026728	30636	Economy	13400.00
0005432186910	30636	Economy	13400.00
0005434068395	30636	Economy	13400.00
0005434068363	30636	Economy	13400.00
0005434082175	30636	Economy	13400.00
0005434068386	30636	Economy	13400.00
0005432150285	30636	Economy	13400.00
0005434082173	30636	Economy	13400.00
0005434082172	30636	Economy	13400.00
0005435462561	5524	Business	35300.00
0005435462430	5524	Business	35300.00
0005434265182	5524	Business	35300.00
0005432140545	5524	Business	35300.00
0005435462542	5524	Business	35300.00
0005435462726	5524	Business	35300.00
0005435735191	5524	Business	35300.00
0005435722085	5524	Business	35300.00
0005435766945	5524	Business	35300.00
0005434265224	5524	Business	35300.00
0005435766952	5524	Business	35300.00
0005435722084	5524	Business	35300.00
0005435462437	5524	Business	35300.00
0005432535848	5524	Business	35300.00
0005435766961	5524	Business	35300.00
0005432140547	5524	Business	35300.00
0005432140551	5524	Business	35300.00
0005434265190	5524	Business	35300.00
0005435766963	5524	Business	35300.00
0005435462495	5524	Business	35300.00
0005435766954	5524	Business	35300.00
0005434265208	5524	Business	35300.00
0005435462538	5524	Business	35300.00
0005435766958	5524	Business	35300.00
0005435462599	5524	Economy	12900.00
0005435766970	5524	Business	35300.00
0005435462537	5524	Economy	12900.00
0005435462522	5524	Economy	12900.00
0005435462481	5524	Economy	12900.00
0005435766951	5524	Economy	11800.00
0005433529325	5524	Economy	11800.00
0005435766953	5524	Economy	11800.00
0005434265125	5524	Economy	11800.00
0005435766946	5524	Economy	11800.00
0005435462480	5524	Economy	11800.00
0005435043289	5524	Economy	11800.00
0005435766955	5524	Economy	11800.00
0005434265242	5524	Economy	11800.00
0005435766967	5524	Economy	11800.00
0005435462588	5524	Economy	11800.00
0005435766978	5524	Economy	11800.00
0005435766972	5524	Economy	11800.00
0005435725659	5524	Economy	11800.00
0005434265183	5524	Economy	11800.00
0005433529326	5524	Economy	11800.00
0005435766973	5524	Economy	11800.00
0005435462725	5524	Economy	11800.00
0005435462719	5524	Economy	11800.00
0005435462507	5524	Economy	11800.00
0005434265257	5524	Economy	11800.00
0005435766964	5524	Economy	11800.00
0005435462302	5524	Economy	11800.00
0005435462620	5524	Economy	11800.00
0005435462711	5524	Economy	11800.00
0005435462431	5524	Economy	11800.00
0005435462746	5524	Economy	11800.00
0005435725658	5524	Economy	11800.00
0005434265186	5524	Economy	11800.00
0005433529323	5524	Economy	11800.00
0005435766960	5524	Economy	11800.00
0005434265310	5524	Economy	11800.00
0005435462543	5524	Economy	11800.00
0005432140544	5524	Economy	11800.00
0005435462625	5524	Economy	11800.00
0005433527314	5524	Economy	11800.00
0005433529324	5524	Economy	11800.00
0005435766983	5524	Economy	11800.00
0005435462600	5524	Economy	11800.00
0005432140549	5524	Economy	11800.00
0005435766943	5524	Economy	11800.00
0005435735189	5524	Economy	11800.00
0005435766944	5524	Economy	11800.00
0005435766976	5524	Economy	11800.00
0005434265079	5524	Economy	11800.00
0005435766969	5524	Economy	11800.00
0005432535862	5524	Economy	11800.00
0005435462619	5524	Economy	11800.00
0005434265209	5524	Economy	11800.00
0005435766965	5524	Economy	11800.00
0005435766971	5524	Economy	11800.00
0005435462631	5524	Economy	11800.00
0005435766962	5524	Economy	11800.00
0005435735190	5524	Economy	11800.00
0005435462614	5524	Economy	11800.00
0005435462362	5524	Economy	11800.00
0005435462668	5524	Economy	11800.00
0005435462641	5524	Economy	11800.00
0005435720838	5524	Economy	11800.00
0005433527313	5524	Economy	11800.00
0005434265245	5524	Economy	11800.00
0005433527312	5524	Economy	11800.00
0005435722083	5524	Economy	11800.00
0005435462562	5524	Economy	11800.00
0005435462682	5524	Economy	11800.00
0005435766981	5524	Economy	11800.00
0005435766979	5524	Economy	11800.00
0005435766984	5524	Economy	11800.00
0005435462494	5524	Economy	11800.00
0005435462457	5524	Economy	11800.00
0005434265256	5524	Economy	11800.00
0005435766966	5524	Economy	11800.00
0005435462720	5524	Economy	11800.00
0005435462632	5524	Economy	12900.00
0005433527315	5524	Economy	12900.00
0005435462661	5524	Economy	11800.00
0005435766975	5524	Economy	12900.00
0005435766959	5524	Economy	12900.00
0005435725656	5524	Economy	11800.00
0005435725657	5524	Economy	11800.00
0005434265080	5524	Economy	11800.00
0005435725655	5524	Economy	11800.00
0005434265311	5524	Economy	11800.00
0005435462506	5524	Economy	11800.00
0005434265108	5524	Economy	11800.00
0005432140550	5524	Economy	11800.00
0005435462452	5524	Economy	11800.00
0005435462745	5524	Economy	11800.00
0005435617172	5524	Economy	11800.00
0005432140546	5524	Economy	11800.00
0005435766948	5524	Economy	11800.00
0005435766977	5524	Economy	11800.00
0005435766985	5524	Economy	11800.00
0005435766956	5524	Economy	11800.00
0005435766947	5524	Economy	11800.00
0005434265207	5524	Economy	11800.00
0005435462425	5524	Economy	11800.00
0005435766986	5524	Economy	11800.00
0005435462642	5524	Economy	11800.00
0005435462535	5524	Economy	11800.00
0005435462589	5524	Economy	11800.00
0005434265102	5524	Economy	11800.00
0005434265220	5524	Economy	11800.00
0005432535849	5524	Economy	11800.00
0005435766982	5524	Economy	11800.00
0005434265227	5524	Economy	11800.00
0005432535831	5524	Economy	11800.00
0005435617171	5524	Economy	11800.00
0005434265107	5524	Economy	11800.00
0005435462615	5524	Economy	11800.00
0005435462590	5524	Economy	11800.00
0005432140543	5524	Economy	11800.00
0005435462621	5524	Economy	11800.00
0005435462606	5524	Economy	11800.00
0005435766949	5524	Economy	11800.00
0005435723070	5524	Economy	11800.00
0005435462598	5524	Economy	11800.00
0005435735192	5524	Economy	11800.00
0005434265148	5524	Economy	11800.00
0005435766974	5524	Economy	11800.00
0005435766950	5524	Economy	11800.00
0005434265247	5524	Economy	11800.00
0005434265261	5524	Economy	11800.00
0005434265161	5524	Economy	11800.00
0005435766957	5524	Economy	11800.00
0005434265218	5524	Economy	11800.00
0005432140548	5524	Economy	11800.00
0005435766980	5524	Economy	11800.00
0005434265246	5524	Economy	11800.00
0005432140552	5524	Economy	11800.00
0005435766968	5524	Economy	11800.00
0005435720837	5524	Economy	11800.00
0005435766327	13476	Business	35300.00
0005434831209	13476	Business	35300.00
0005435462878	13476	Business	35300.00
0005434265452	13476	Business	35300.00
0005435766260	13476	Business	35300.00
0005435766326	13476	Business	35300.00
0005435766504	13476	Business	35300.00
0005435723045	13476	Business	35300.00
0005434265442	13476	Business	35300.00
0005435766234	13476	Business	35300.00
0005435462884	13476	Business	35300.00
0005435462914	13476	Business	35300.00
0005435766373	13476	Business	35300.00
0005433529280	13476	Business	35300.00
0005434265448	13476	Business	35300.00
0005435766320	13476	Business	35300.00
0005435766195	13476	Business	35300.00
0005435766463	13476	Business	35300.00
0005435462893	13476	Business	35300.00
0005434265465	13476	Business	35300.00
0005435462890	13476	Business	35300.00
0005433533315	13476	Business	35300.00
0005435766149	13476	Economy	12900.00
0005435462888	13476	Business	35300.00
0005435766421	13476	Economy	12900.00
0005433529270	13476	Economy	12900.00
0005435766456	13476	Economy	12900.00
0005435462917	13476	Economy	11800.00
0005432194561	13476	Economy	11800.00
0005435766441	13476	Economy	11800.00
0005435766475	13476	Economy	11800.00
0005434265445	13476	Economy	11800.00
0005433533312	13476	Economy	11800.00
0005435766541	13476	Economy	11800.00
0005433533320	13476	Economy	11800.00
0005434265461	13476	Economy	11800.00
0005434265459	13476	Economy	11800.00
0005434265451	13476	Economy	11800.00
0005435735162	13476	Economy	11800.00
0005434265444	13476	Economy	11800.00
0005435766345	13476	Economy	11800.00
0005435766506	13476	Economy	11800.00
0005434265467	13476	Economy	11800.00
0005435462907	13476	Economy	11800.00
0005435462902	13476	Economy	11800.00
0005435722059	13476	Economy	11800.00
0005435766360	13476	Economy	11800.00
0005434265462	13476	Economy	11800.00
0005435722061	13476	Economy	11800.00
0005435462898	13476	Economy	11800.00
0005433529291	13476	Economy	11800.00
0005435766536	13476	Economy	11800.00
0005435462881	13476	Economy	11800.00
0005435766372	13476	Economy	11800.00
0005433533317	13476	Economy	11800.00
0005432535891	13476	Economy	11800.00
0005434265468	13476	Economy	11800.00
0005433533309	13476	Economy	11800.00
0005434265449	13476	Economy	11800.00
0005434265460	13476	Economy	11800.00
0005433533300	13476	Economy	11800.00
0005435766525	13476	Economy	11800.00
0005435766514	13476	Economy	11800.00
0005435766540	13476	Economy	11800.00
0005435462880	13476	Economy	11800.00
0005432535892	13476	Economy	11800.00
0005435462889	13476	Economy	11800.00
0005433533303	13476	Economy	11800.00
0005433533327	13476	Economy	11800.00
0005435766362	13476	Economy	11800.00
0005434265456	13476	Economy	11800.00
0005433529284	13476	Economy	11800.00
0005435462913	13476	Economy	11800.00
0005435462877	13476	Economy	11800.00
0005435462882	13476	Economy	11800.00
0005433529275	13476	Economy	11800.00
0005433529276	13476	Economy	11800.00
0005435766521	13476	Economy	11800.00
0005432194564	13476	Economy	11800.00
0005435725605	13476	Economy	11800.00
0005435462906	13476	Economy	11800.00
0005435462903	13476	Economy	11800.00
0005435766505	13476	Economy	11800.00
0005435462895	13476	Economy	11800.00
0005435462909	13476	Economy	11800.00
0005433529254	13476	Economy	11800.00
0005434265464	13476	Economy	11800.00
0005435766168	13476	Economy	11800.00
0005433533333	13476	Economy	11800.00
0005435766515	13476	Economy	11800.00
0005435766462	13476	Economy	11800.00
0005433529271	13476	Economy	11800.00
0005434265457	13476	Economy	11800.00
0005435462912	13476	Economy	11800.00
0005433529262	13476	Economy	11800.00
0005435462879	13476	Economy	11800.00
0005435462908	13476	Economy	11800.00
0005434831211	13476	Economy	11800.00
0005435462904	13476	Economy	11800.00
0005435723060	13476	Economy	11800.00
0005433533280	13476	Economy	11800.00
0005435735142	13476	Economy	11800.00
0005435722060	13476	Economy	11800.00
0005434265454	13476	Economy	11800.00
0005432535894	13476	Economy	11800.00
0005433533313	13476	Economy	11800.00
0005435766150	13476	Economy	11800.00
0005434265453	13476	Economy	11800.00
0005435766262	13476	Economy	12900.00
0005435766322	13476	Economy	12900.00
0005435462883	13476	Economy	11800.00
0005435766261	13476	Economy	11800.00
0005434831208	13476	Economy	12900.00
0005435462892	13476	Economy	11800.00
0005435766522	13476	Economy	11800.00
0005435462887	13476	Economy	11800.00
0005434265463	13476	Economy	11800.00
0005432535893	13476	Economy	11800.00
0005435735143	13476	Economy	11800.00
0005434831207	13476	Economy	11800.00
0005435766167	13476	Economy	11800.00
0005435462900	13476	Economy	11800.00
0005435462911	13476	Economy	11800.00
0005435766127	13476	Economy	11800.00
0005435766332	13476	Economy	11800.00
0005432194563	13476	Economy	11800.00
0005433529261	13476	Economy	11800.00
0005435766359	13476	Economy	11800.00
0005432194562	13476	Economy	11800.00
0005433529256	13476	Economy	11800.00
0005435462905	13476	Economy	11800.00
0005435766363	13476	Economy	11800.00
0005432535895	13476	Economy	11800.00
0005435462910	13476	Economy	11800.00
0005435462897	13476	Economy	11800.00
0005434265466	13476	Economy	11800.00
0005433533304	13476	Economy	11800.00
0005433529260	13476	Economy	11800.00
0005435766440	13476	Economy	11800.00
0005434265458	13476	Economy	11800.00
0005435766524	13476	Economy	11800.00
0005435766406	13476	Economy	11800.00
0005433529250	13476	Economy	11800.00
0005434831210	13476	Economy	11800.00
0005435766361	13476	Economy	11800.00
0005434265446	13476	Economy	11800.00
0005434265450	13476	Economy	11800.00
0005435462885	13476	Economy	11800.00
0005435462896	13476	Economy	11800.00
0005435462901	13476	Economy	11800.00
0005435462886	13476	Economy	11800.00
0005434265455	13476	Economy	11800.00
0005433533316	13476	Economy	11800.00
0005433533318	13476	Economy	11800.00
0005435462915	13476	Economy	11800.00
0005435766321	13476	Economy	11800.00
0005435766439	13476	Economy	11800.00
0005435462899	13476	Economy	11800.00
0005435462894	13476	Economy	11800.00
0005435766357	13476	Economy	11800.00
0005433529251	13476	Economy	11800.00
0005435766264	13476	Economy	11800.00
0005435766371	13476	Economy	11800.00
0005434265443	13476	Economy	11800.00
0005435462916	13476	Economy	11800.00
0005435462891	13476	Economy	11800.00
0005433533332	13476	Economy	11800.00
0005433533279	13476	Economy	11800.00
0005433529281	13476	Economy	11800.00
0005435766454	13476	Economy	11800.00
0005435766526	13476	Economy	11800.00
0005433529255	13476	Economy	11800.00
0005434265447	13476	Economy	11800.00
0005434602909	18744	Economy	3300.00
0005434602908	18744	Economy	3300.00
0005434602907	18744	Economy	3300.00
0005434602900	18744	Economy	3300.00
0005434513609	18736	Economy	3300.00
0005434513610	18736	Economy	3300.00
0005434604897	18736	Economy	3300.00
0005434514997	18736	Economy	3300.00
0005434514999	18736	Economy	3300.00
0005434514998	18736	Economy	3300.00
0005434604901	18736	Economy	3300.00
0005434514996	18736	Economy	3300.00
0005434604902	18736	Economy	3300.00
0005434604899	18736	Economy	3300.00
0005434514971	19173	Economy	3300.00
0005434514985	19173	Economy	3300.00
0005432632818	4117	Business	88300.00
0005432649469	4117	Business	88300.00
0005432649475	4117	Business	88300.00
0005435844336	4117	Business	88300.00
0005432649474	4117	Business	88300.00
0005432649477	4117	Business	88300.00
0005435844337	4117	Business	88300.00
0005435846251	4117	Business	88300.00
0005435846275	4117	Economy	29400.00
0005435846270	4117	Economy	29400.00
0005432649470	4117	Economy	29400.00
0005432649480	4117	Economy	32400.00
0005432649483	4117	Economy	32400.00
0005432632823	4117	Economy	29400.00
0005432649482	4117	Economy	29400.00
0005435846252	4117	Economy	29400.00
0005435846253	4117	Economy	29400.00
0005435846236	4117	Economy	29400.00
0005435844322	4117	Economy	29400.00
0005432632820	4117	Economy	29400.00
0005432632826	4117	Economy	29400.00
0005435844335	4117	Economy	29400.00
0005432632821	4117	Economy	29400.00
0005432649481	4117	Economy	29400.00
0005432632825	4117	Economy	29400.00
0005432632828	4117	Economy	29400.00
0005435844324	4117	Economy	29400.00
0005432632829	4117	Economy	29400.00
0005432632822	4117	Economy	29400.00
0005432632831	4117	Economy	29400.00
0005432649478	4117	Economy	29400.00
0005435846254	4117	Economy	29400.00
0005432649471	4117	Economy	29400.00
0005435846271	4117	Economy	29400.00
0005432649479	4117	Economy	29400.00
0005432632819	4117	Economy	29400.00
0005432632830	4117	Economy	29400.00
0005432649472	4117	Economy	29400.00
0005435844321	4117	Economy	29400.00
0005432632824	4117	Economy	29400.00
0005432649476	4117	Economy	29400.00
0005435844325	4117	Economy	29400.00
0005432632827	4117	Economy	29400.00
0005432649473	4117	Economy	29400.00
0005433285507	1786	Business	48700.00
0005433008571	1786	Business	48700.00
0005433008945	1786	Business	48700.00
0005433285471	1786	Business	48700.00
0005433008744	1786	Business	48700.00
0005433285482	1786	Business	48700.00
0005433285589	1786	Business	48700.00
0005433285504	1786	Business	48700.00
0005433009025	1786	Business	48700.00
0005433285275	1786	Business	48700.00
0005433008902	1786	Business	48700.00
0005433285299	1786	Business	48700.00
0005433008958	1786	Economy	16200.00
0005432295912	1786	Economy	16200.00
0005433285399	1786	Economy	16200.00
0005433285502	1786	Economy	16200.00
0005433008784	1786	Economy	16200.00
0005433008966	1786	Economy	16200.00
0005433008712	1786	Economy	16200.00
0005433285489	1786	Economy	16200.00
0005433285588	1786	Economy	16200.00
0005433285450	1786	Economy	17900.00
0005433008913	1786	Economy	17900.00
0005433008851	1786	Economy	17900.00
0005433008754	1786	Economy	17900.00
0005433008581	1786	Economy	17900.00
0005433008755	1786	Economy	16200.00
0005433285446	1786	Economy	16200.00
0005433285400	1786	Economy	16200.00
0005433285398	1786	Economy	16200.00
0005433008850	1786	Economy	16200.00
0005433285429	1786	Economy	16200.00
0005433285427	1786	Economy	16200.00
0005433008959	1786	Economy	16200.00
0005433008778	1786	Economy	16200.00
0005433008568	1786	Economy	16200.00
0005433285370	1786	Economy	16200.00
0005433008930	1786	Economy	16200.00
0005433008874	1786	Economy	16200.00
0005433285433	1786	Economy	16200.00
0005433285385	1786	Economy	16200.00
0005433285389	1786	Economy	16200.00
0005433008872	1786	Economy	16200.00
0005433285605	1786	Economy	16200.00
0005433008928	1786	Economy	16200.00
0005433008821	1786	Economy	16200.00
0005433285421	1786	Economy	16200.00
0005433008533	1786	Economy	16200.00
0005433008709	1786	Economy	16200.00
0005433285428	1786	Economy	16200.00
0005433285449	1786	Economy	16200.00
0005433285503	1786	Economy	16200.00
0005433008731	1786	Economy	16200.00
0005433008706	1786	Economy	16200.00
0005433008726	1786	Economy	16200.00
0005433008689	1786	Economy	16200.00
0005432295910	1786	Economy	16200.00
0005433008711	1786	Economy	16200.00
0005433008779	1786	Economy	16200.00
0005433008730	1786	Economy	16200.00
0005433285470	1786	Economy	16200.00
0005433008756	1786	Economy	16200.00
0005433285435	1786	Economy	16200.00
0005433008569	1786	Economy	16200.00
0005433285238	1786	Economy	16200.00
0005433008668	1786	Economy	16200.00
0005432295911	1786	Economy	16200.00
0005433285368	1786	Economy	16200.00
0005433285325	1786	Economy	16200.00
0005433008820	1786	Economy	16200.00
0005433285403	1786	Economy	16200.00
0005433285480	1786	Economy	16200.00
0005433285508	1786	Economy	16200.00
0005433008715	1786	Economy	16200.00
0005433285436	1786	Economy	16200.00
0005433285404	1786	Economy	16200.00
0005433009043	1786	Economy	16200.00
0005433008667	1786	Economy	16200.00
0005433008696	1786	Economy	16200.00
0005433285481	1786	Economy	16200.00
0005433285277	1786	Economy	16200.00
0005433285383	1786	Economy	16200.00
0005433285388	1786	Economy	16200.00
0005433285387	1786	Economy	16200.00
0005433285501	1786	Economy	16200.00
0005433008777	1786	Economy	16200.00
0005433285401	1786	Economy	16200.00
0005433008771	1786	Economy	16200.00
0005433008904	1786	Economy	16200.00
0005433285606	1786	Economy	16200.00
0005433285667	22591	Business	48700.00
0005433009167	22591	Business	48700.00
0005433009134	22591	Business	48700.00
0005433285650	22591	Business	48700.00
0005433009158	22591	Business	48700.00
0005433810544	22591	Business	48700.00
0005433285673	22591	Business	48700.00
0005433009140	22591	Business	48700.00
0005433009154	22591	Business	48700.00
0005433285660	22591	Economy	16200.00
0005433285671	22591	Economy	16200.00
0005433009161	22591	Economy	16200.00
0005433285668	22591	Economy	16200.00
0005433285672	22591	Economy	16200.00
0005433009163	22591	Economy	16200.00
0005433009146	22591	Economy	16200.00
0005433009136	22591	Economy	16200.00
0005433009143	22591	Economy	17900.00
0005433009137	22591	Economy	17900.00
0005433009135	22591	Economy	17900.00
0005433285651	22591	Economy	17900.00
0005433009144	22591	Economy	17900.00
0005433009132	22591	Economy	16200.00
0005433009156	22591	Economy	16200.00
0005433285654	22591	Economy	16200.00
0005433009128	22591	Economy	16200.00
0005433285670	22591	Economy	16200.00
0005433009150	22591	Economy	16200.00
0005433009164	22591	Economy	16200.00
0005433285652	22591	Economy	16200.00
0005433810543	22591	Economy	16200.00
0005433009138	22591	Economy	16200.00
0005433810541	22591	Economy	16200.00
0005433009145	22591	Economy	16200.00
0005433009130	22591	Economy	16200.00
0005433285646	22591	Economy	16200.00
0005433009141	22591	Economy	16200.00
0005433009165	22591	Economy	16200.00
0005433285649	22591	Economy	16200.00
0005433009126	22591	Economy	16200.00
0005433285666	22591	Economy	16200.00
0005433009148	22591	Economy	16200.00
0005433009157	22591	Economy	16200.00
0005433009124	22591	Economy	16200.00
0005433009131	22591	Economy	16200.00
0005433285675	22591	Economy	16200.00
0005433009160	22591	Economy	16200.00
0005433009155	22591	Economy	16200.00
0005433285653	22591	Economy	16200.00
0005433285659	22591	Economy	16200.00
0005433810545	22591	Economy	16200.00
0005433009152	22591	Economy	16200.00
0005433009151	22591	Economy	16200.00
0005433285656	22591	Economy	16200.00
0005433009129	22591	Economy	16200.00
0005433285648	22591	Economy	16200.00
0005433285663	22591	Economy	16200.00
0005433009127	22591	Economy	16200.00
0005433009142	22591	Economy	16200.00
0005433009159	22591	Economy	16200.00
0005433285664	22591	Economy	16200.00
0005433009149	22591	Economy	16200.00
0005433285658	22591	Economy	16200.00
0005433285655	22591	Economy	16200.00
0005433285662	22591	Economy	16200.00
0005433009153	22591	Economy	16200.00
0005433009162	22591	Economy	16200.00
0005433009166	22591	Economy	16200.00
0005433009147	22591	Economy	16200.00
0005433285661	22591	Economy	16200.00
0005433285647	22591	Economy	16200.00
0005433285674	22591	Economy	16200.00
0005433009125	22591	Economy	16200.00
0005433285665	22591	Economy	16200.00
0005433810547	22591	Economy	16200.00
0005433285669	22591	Economy	16200.00
0005433009133	22591	Economy	16200.00
0005433009139	22591	Economy	16200.00
0005433285657	22591	Economy	16200.00
0005433847400	5599	Business	99800.00
0005435282522	5599	Business	99800.00
0005433847413	5599	Business	99800.00
0005435282571	5599	Business	99800.00
0005433847414	5599	Business	99800.00
0005433847456	5599	Business	99800.00
0005433847454	5599	Business	99800.00
0005433847453	5599	Business	99800.00
0005433847434	5599	Business	99800.00
0005435282597	5599	Business	99800.00
0005432081591	5599	Business	99800.00
0005433847407	5599	Business	99800.00
0005433847439	5599	Business	99800.00
0005433847405	5599	Business	99800.00
0005435282521	5599	Business	99800.00
0005435282592	5599	Business	99800.00
0005433847429	5599	Business	99800.00
0005433847433	5599	Economy	33300.00
0005433847441	5599	Business	99800.00
0005433847450	5599	Economy	33300.00
0005435282562	5599	Economy	33300.00
0005435282678	5599	Economy	33300.00
0005433847446	5599	Economy	33300.00
0005433815441	5599	Economy	33300.00
0005434173531	5599	Economy	33300.00
0005433847437	5599	Economy	33300.00
0005435282679	5599	Economy	33300.00
0005433847449	5599	Economy	33300.00
0005434173539	5599	Economy	33300.00
0005433847442	5599	Economy	33300.00
0005433847409	5599	Economy	33300.00
0005433847403	5599	Economy	36600.00
0005432081590	5599	Economy	36600.00
0005435282595	5599	Economy	36600.00
0005435282548	5599	Economy	33300.00
0005435282570	5599	Economy	33300.00
0005435282549	5599	Economy	33300.00
0005433847423	5599	Economy	33300.00
0005433847435	5599	Economy	33300.00
0005435282619	5599	Economy	33300.00
0005435282671	5599	Economy	33300.00
0005433847425	5599	Economy	33300.00
0005433847422	5599	Economy	33300.00
0005433847397	5599	Economy	33300.00
0005433847406	5599	Economy	33300.00
0005433847447	5599	Economy	33300.00
0005433847399	5599	Economy	33300.00
0005432081587	5599	Economy	33300.00
0005433847452	5599	Economy	33300.00
0005435282634	5599	Economy	33300.00
0005433847421	5599	Economy	33300.00
0005433847445	5599	Economy	33300.00
0005433847426	5599	Economy	33300.00
0005433847416	5599	Economy	33300.00
0005435282527	5599	Economy	33300.00
0005435282635	5599	Economy	33300.00
0005433847396	5599	Economy	33300.00
0005432081586	5599	Economy	33300.00
0005433847398	5599	Economy	33300.00
0005434173535	5599	Economy	33300.00
0005433847402	5599	Economy	33300.00
0005433847440	5599	Economy	33300.00
0005433847432	5599	Economy	33300.00
0005433847431	5599	Economy	33300.00
0005433815442	5599	Economy	33300.00
0005433847451	5599	Economy	33300.00
0005433847420	5599	Economy	33300.00
0005433847401	5599	Economy	33300.00
0005433847415	5599	Economy	33300.00
0005433847418	5599	Economy	33300.00
0005433815443	5599	Economy	33300.00
0005435282528	5599	Economy	33300.00
0005435282523	5599	Economy	33300.00
0005434173532	5599	Economy	33300.00
0005433847436	5599	Economy	33300.00
0005433847412	5599	Economy	33300.00
0005433847427	5599	Economy	33300.00
0005433847404	5599	Economy	33300.00
0005433815440	5599	Economy	33300.00
0005433847430	5599	Economy	33300.00
0005433847417	5599	Economy	33300.00
0005433847419	5599	Economy	33300.00
0005433847444	5599	Economy	33300.00
0005432081588	5599	Economy	33300.00
0005433847411	5599	Economy	33300.00
0005433847428	5599	Economy	33300.00
0005435282642	5599	Economy	33300.00
0005432081589	5599	Economy	33300.00
0005433847424	5599	Economy	33300.00
0005433847410	5599	Economy	33300.00
0005434173518	5599	Economy	33300.00
0005433847455	5599	Economy	33300.00
0005435282547	5599	Economy	33300.00
0005435282620	5599	Economy	33300.00
0005433847448	5599	Economy	33300.00
0005433847443	5599	Economy	33300.00
0005433847438	5599	Economy	33300.00
0005433847408	5599	Economy	33300.00
0005433846847	13856	Business	99800.00
0005433847103	13856	Business	99800.00
0005433846899	13856	Business	99800.00
0005435282802	13856	Business	99800.00
0005433846743	13856	Business	99800.00
0005435282810	13856	Business	99800.00
0005433846936	13856	Business	99800.00
0005433846817	13856	Business	99800.00
0005433846887	13856	Business	99800.00
0005433815391	13856	Business	99800.00
0005433846808	13856	Business	99800.00
0005433815386	13856	Business	99800.00
0005435282798	13856	Business	99800.00
0005435282795	13856	Business	99800.00
0005435282791	13856	Business	99800.00
0005433847106	13856	Business	99800.00
0005435282805	13856	Business	99800.00
0005435282806	13856	Economy	33300.00
0005433846844	13856	Business	99800.00
0005433815407	13856	Economy	33300.00
0005433847009	13856	Economy	33300.00
0005433846842	13856	Economy	33300.00
0005435282804	13856	Economy	33300.00
0005433846635	13856	Economy	33300.00
0005433846997	13856	Economy	33300.00
0005433846813	13856	Economy	33300.00
0005433847026	13856	Economy	33300.00
0005435282809	13856	Economy	33300.00
0005433846868	13856	Economy	36600.00
0005433847057	13856	Economy	36600.00
0005433846825	13856	Economy	36600.00
0005433847129	13856	Economy	36600.00
0005435282807	13856	Economy	33300.00
0005434173570	13856	Economy	33300.00
0005432003740	13856	Economy	33300.00
0005433847093	13856	Economy	33300.00
0005433846792	13856	Economy	33300.00
0005433846867	13856	Economy	33300.00
0005433846848	13856	Economy	33300.00
0005433846747	13856	Economy	33300.00
0005433846982	13856	Economy	33300.00
0005435282808	13856	Economy	33300.00
0005433847007	13856	Economy	33300.00
0005433846863	13856	Economy	33300.00
0005433846959	13856	Economy	33300.00
0005433846859	13856	Economy	33300.00
0005435282811	13856	Economy	33300.00
0005434173568	13856	Economy	33300.00
0005433846951	13856	Economy	33300.00
0005433847130	13856	Economy	33300.00
0005433846786	13856	Economy	33300.00
0005433847059	13856	Economy	33300.00
0005433846892	13856	Economy	33300.00
0005433847065	13856	Economy	33300.00
0005433846827	13856	Economy	33300.00
0005433847002	13856	Economy	33300.00
0005435282793	13856	Economy	33300.00
0005433846840	13856	Economy	33300.00
0005433846744	13856	Economy	33300.00
0005433847005	13856	Economy	33300.00
0005435282796	13856	Economy	33300.00
0005435282797	13856	Economy	33300.00
0005433846877	13856	Economy	33300.00
0005433846948	13856	Economy	33300.00
0005433846741	13856	Economy	33300.00
0005433846826	13856	Economy	33300.00
0005433847058	13856	Economy	33300.00
0005433846787	13856	Economy	33300.00
0005433846820	13856	Economy	33300.00
0005435282792	13856	Economy	33300.00
0005433846720	13856	Economy	33300.00
0005432003739	13856	Economy	33300.00
0005433846634	13856	Economy	33300.00
0005434173567	13856	Economy	33300.00
0005433846865	13856	Economy	33300.00
0005433846816	13856	Economy	33300.00
0005433846918	13856	Economy	33300.00
0005433847166	13856	Economy	33300.00
0005435282801	13856	Economy	33300.00
0005433846856	13856	Economy	33300.00
0005434173569	13856	Economy	33300.00
0005433846806	13856	Economy	33300.00
0005433846821	13856	Economy	33300.00
0005435282803	13856	Economy	33300.00
0005433846746	13856	Economy	33300.00
0005433846793	13856	Economy	33300.00
0005433847102	13856	Economy	33300.00
0005435282799	13856	Economy	33300.00
0005433846725	13856	Economy	33300.00
0005433846719	13856	Economy	33300.00
0005433815408	13856	Economy	33300.00
0005433846727	13856	Economy	33300.00
0005433846788	13856	Economy	33300.00
0005433846969	13856	Economy	33300.00
0005435282800	13856	Economy	33300.00
0005433846845	13856	Economy	33300.00
0005433846828	13856	Economy	33300.00
0005433846855	13856	Economy	33300.00
0005433847006	13856	Economy	33300.00
0005433815405	13856	Economy	33300.00
0005433846726	13856	Economy	33300.00
0005435282794	13856	Economy	33300.00
0005435332377	7826	Economy	16600.00
0005432112543	7826	Economy	16600.00
0005434620853	7826	Economy	15100.00
0005434620841	7826	Economy	15100.00
0005434620837	7826	Economy	15100.00
0005434620851	7826	Economy	15100.00
0005432112544	7826	Economy	15100.00
0005435332348	7826	Economy	15100.00
0005434620847	7826	Economy	15100.00
0005434620838	7826	Economy	15100.00
0005434620852	7826	Economy	15100.00
0005434620846	7826	Economy	15100.00
0005435332388	7826	Economy	15100.00
0005434620850	7826	Economy	15100.00
0005435332358	7826	Economy	15100.00
0005432112545	7826	Economy	15100.00
0005434620842	7826	Economy	15100.00
0005434620835	7826	Economy	15100.00
0005434620839	7826	Economy	15100.00
0005434620844	7826	Economy	15100.00
0005432112542	7826	Economy	15100.00
0005434620836	7826	Economy	15100.00
0005434620843	7826	Economy	15100.00
0005434620845	7826	Economy	15100.00
0005434620849	7826	Economy	15100.00
0005435332376	7826	Economy	15100.00
0005434620833	7826	Economy	15100.00
0005434620840	7826	Economy	15100.00
0005435332359	7826	Economy	15100.00
0005435332398	7826	Economy	15100.00
0005434620834	7826	Economy	15100.00
0005434620848	7826	Economy	15100.00
0005435332457	32955	Economy	16600.00
0005434620673	32955	Economy	16600.00
0005434620645	32955	Economy	16600.00
0005434620662	32955	Economy	16600.00
0005434620651	32955	Economy	15100.00
0005434620708	32955	Economy	15100.00
0005435332460	32955	Economy	15100.00
0005435332461	32955	Economy	15100.00
0005434620563	32955	Economy	15100.00
0005434620692	32955	Economy	15100.00
0005434620650	32955	Economy	15100.00
0005434620644	32955	Economy	15100.00
0005434620677	32955	Economy	15100.00
0005435332463	32955	Economy	15100.00
0005434620643	32955	Economy	15100.00
0005434620614	32955	Economy	15100.00
0005434620694	32955	Economy	15100.00
0005434620669	32955	Economy	15100.00
0005435332464	32955	Economy	15100.00
0005435332456	32955	Economy	15100.00
0005435332459	32955	Economy	15100.00
0005435332455	32955	Economy	15100.00
0005434620632	32955	Economy	15100.00
0005434620693	32955	Economy	15100.00
0005435332462	32955	Economy	15100.00
0005435332458	32955	Economy	15100.00
0005434620617	32955	Economy	15100.00
0005435332465	32955	Economy	15100.00
0005434620663	32955	Economy	15100.00
0005434620616	32955	Economy	15100.00
0005434620695	32955	Economy	15100.00
0005434620615	32955	Economy	15100.00
0005434620676	32955	Economy	15100.00
0005434620709	32955	Economy	15100.00
0005435785776	4271	Business	38000.00
0005435785766	4271	Business	38000.00
0005435785765	4271	Business	38000.00
0005435785757	4271	Business	38000.00
0005435785787	4271	Business	38000.00
0005435785775	4271	Business	38000.00
0005435785771	4271	Economy	12700.00
0005435785785	4271	Economy	12700.00
0005435785784	4271	Economy	12700.00
0005435785788	4271	Economy	12700.00
0005432190677	4271	Economy	12700.00
0005435785756	4271	Economy	12700.00
0005434994135	4271	Economy	12700.00
0005435785764	4271	Economy	13900.00
0005435937395	4271	Economy	13900.00
0005435918691	4271	Economy	12700.00
0005435918685	4271	Economy	12700.00
0005435785789	4271	Economy	12700.00
0005435785761	4271	Economy	12700.00
0005435785779	4271	Economy	12700.00
0005435785780	4271	Economy	12700.00
0005435787380	4271	Economy	12700.00
0005435785781	4271	Economy	12700.00
0005435785759	4271	Economy	12700.00
0005435785774	4271	Economy	12700.00
0005435785777	4271	Economy	12700.00
0005434994143	4271	Economy	12700.00
0005435785760	4271	Economy	12700.00
0005434994138	4271	Economy	12700.00
0005435785790	4271	Economy	12700.00
0005434994141	4271	Economy	12700.00
0005435918678	4271	Economy	12700.00
0005434994136	4271	Economy	12700.00
0005434994140	4271	Economy	12700.00
0005435785773	4271	Economy	12700.00
0005435785772	4271	Economy	12700.00
0005434994144	4271	Economy	12700.00
0005435787381	4271	Economy	12700.00
0005434994137	4271	Economy	12700.00
0005435785767	4271	Economy	12700.00
0005434994139	4271	Economy	12700.00
0005432190676	4271	Economy	12700.00
0005435785762	4271	Economy	12700.00
0005435785783	4271	Economy	12700.00
0005435785786	4271	Economy	12700.00
0005435785758	4271	Economy	12700.00
0005432190675	4271	Economy	12700.00
0005435785768	4271	Economy	12700.00
0005435785770	4271	Economy	12700.00
0005435785782	4271	Economy	12700.00
0005435785778	4271	Economy	12700.00
0005435785769	4271	Economy	12700.00
0005435785763	4271	Economy	12700.00
0005434994142	4271	Economy	12700.00
0005435785534	27289	Business	38000.00
0005432195717	27289	Business	38000.00
0005435937435	27289	Business	38000.00
0005435785315	27289	Business	38000.00
0005434994051	27289	Business	38000.00
0005435937436	27289	Business	38000.00
0005435785418	27289	Business	38000.00
0005435785263	27289	Economy	12700.00
0005435785527	27289	Economy	12700.00
0005435785316	27289	Economy	12700.00
0005435785424	27289	Economy	12700.00
0005435785494	27289	Economy	13900.00
0005432195716	27289	Economy	13900.00
0005435785493	27289	Economy	13900.00
0005435918714	27289	Economy	13900.00
0005435787360	27289	Economy	12700.00
0005435785168	27289	Economy	12700.00
0005435785333	27289	Economy	12700.00
0005435785381	27289	Economy	12700.00
0005435785443	27289	Economy	12700.00
0005435785300	27289	Economy	12700.00
0005435785480	27289	Economy	12700.00
0005435785415	27289	Economy	12700.00
0005435785501	27289	Economy	12700.00
0005435785317	27289	Economy	12700.00
0005435918713	27289	Economy	12700.00
0005435785345	27289	Economy	12700.00
0005435785403	27289	Economy	12700.00
0005435785414	27289	Economy	12700.00
0005435785413	27289	Economy	12700.00
0005434994017	27289	Economy	12700.00
0005435785461	27289	Economy	12700.00
0005435785488	27289	Economy	12700.00
0005435785416	27289	Economy	12700.00
0005434994016	27289	Economy	12700.00
0005435937433	27289	Economy	12700.00
0005435785500	27289	Economy	12700.00
0005435918712	27289	Economy	12700.00
0005434994018	27289	Economy	12700.00
0005435937434	27289	Economy	12700.00
0005435785343	27289	Economy	12700.00
0005435785433	27289	Economy	12700.00
0005435785402	27289	Economy	12700.00
0005435918715	27289	Economy	12700.00
0005435785341	27289	Economy	12700.00
0005435785346	27289	Economy	12700.00
0005435785458	27289	Economy	12700.00
0005435785342	27289	Economy	12700.00
0005435785479	27289	Economy	12700.00
0005432146222	19856	Economy	12800.00
0005432146221	19856	Economy	12800.00
0005432568353	4736	Business	40900.00
0005432460485	4736	Business	40900.00
0005432568351	4736	Business	40900.00
0005432568345	4736	Business	40900.00
0005432460473	4736	Business	40900.00
0005432568357	4736	Business	40900.00
0005432460476	4736	Business	40900.00
0005432568376	4736	Business	40900.00
0005432460486	4736	Business	40900.00
0005434082191	4736	Business	40900.00
0005432460494	4736	Business	40900.00
0005432460479	4736	Business	40900.00
0005432460471	4736	Business	40900.00
0005432460478	4736	Business	40900.00
0005432568370	4736	Business	40900.00
0005432568374	4736	Business	40900.00
0005432571367	4736	Business	40900.00
0005434082178	4736	Business	40900.00
0005432568360	4736	Economy	15000.00
0005432460498	4736	Business	40900.00
0005432568366	4736	Economy	15000.00
0005432568372	4736	Economy	15000.00
0005432460456	4736	Economy	13600.00
0005432460455	4736	Economy	13600.00
0005432568393	4736	Economy	13600.00
0005433726131	4736	Economy	13600.00
0005432568387	4736	Economy	13600.00
0005432568386	4736	Economy	13600.00
0005432568348	4736	Economy	13600.00
0005432170471	4736	Economy	13600.00
0005432568373	4736	Economy	13600.00
0005432460467	4736	Economy	13600.00
0005432571366	4736	Economy	13600.00
0005434082195	4736	Economy	13600.00
0005432460492	4736	Economy	13600.00
0005434082190	4736	Economy	13600.00
0005433452765	4736	Economy	13600.00
0005432568399	4736	Economy	13600.00
0005432460483	4736	Economy	13600.00
0005432568367	4736	Economy	13600.00
0005434082192	4736	Economy	13600.00
0005432568368	4736	Economy	13600.00
0005433451644	4736	Economy	13600.00
0005432568402	4736	Economy	13600.00
0005432568401	4736	Economy	13600.00
0005434082196	4736	Economy	13600.00
0005432568365	4736	Economy	13600.00
0005432460464	4736	Economy	13600.00
0005432460480	4736	Economy	13600.00
0005432186916	4736	Economy	13600.00
0005432568381	4736	Economy	13600.00
0005432460459	4736	Economy	13600.00
0005433451643	4736	Economy	13600.00
0005432568364	4736	Economy	13600.00
0005432568379	4736	Economy	13600.00
0005432460469	4736	Economy	13600.00
0005432460475	4736	Economy	13600.00
0005432460503	4736	Economy	13600.00
0005432460495	4736	Economy	13600.00
0005432568356	4736	Economy	13600.00
0005434082179	4736	Economy	13600.00
0005432568394	4736	Economy	13600.00
0005432568361	4736	Economy	13600.00
0005432571368	4736	Economy	13600.00
0005432460461	4736	Economy	13600.00
0005432460465	4736	Economy	13600.00
0005432568371	4736	Economy	13600.00
0005432568397	4736	Economy	13600.00
0005432460496	4736	Economy	13600.00
0005432568362	4736	Economy	13600.00
0005432568350	4736	Economy	13600.00
0005432568347	4736	Economy	13600.00
0005432568358	4736	Economy	13600.00
0005432568352	4736	Economy	13600.00
0005432568344	4736	Economy	13600.00
0005432460463	4736	Economy	13600.00
0005433726132	4736	Economy	13600.00
0005434082176	4736	Economy	13600.00
0005432568354	4736	Economy	13600.00
0005434082184	4736	Economy	13600.00
0005432568388	4736	Economy	13600.00
0005432460454	4736	Economy	13600.00
0005434082181	4736	Economy	13600.00
0005434082180	4736	Economy	13600.00
0005434082186	4736	Economy	13600.00
0005432460491	4736	Economy	13600.00
0005432460490	4736	Economy	13600.00
0005432170472	4736	Economy	13600.00
0005432460477	4736	Economy	13600.00
0005432568400	4736	Economy	13600.00
0005432568390	4736	Economy	13600.00
0005432186914	4736	Economy	13600.00
0005432460489	4736	Economy	15000.00
0005432568380	4736	Economy	15000.00
0005432170467	4736	Economy	13600.00
0005434082185	4736	Economy	15000.00
0005432568392	4736	Economy	15000.00
0005432460484	4736	Economy	13600.00
0005432460488	4736	Economy	13600.00
0005432460481	4736	Economy	13600.00
0005432460472	4736	Economy	13600.00
0005432460457	4736	Economy	13600.00
0005434082193	4736	Economy	13600.00
0005432568363	4736	Economy	13600.00
0005432460462	4736	Economy	13600.00
0005432460460	4736	Economy	13600.00
0005432460453	4736	Economy	13600.00
0005432186915	4736	Economy	13600.00
0005432568385	4736	Economy	13600.00
0005434082189	4736	Economy	13600.00
0005432568342	4736	Economy	13600.00
0005432568349	4736	Economy	13600.00
0005432460470	4736	Economy	13600.00
0005432460458	4736	Economy	13600.00
0005432170469	4736	Economy	13600.00
0005434082188	4736	Economy	13600.00
0005434082177	4736	Economy	13600.00
0005432460468	4736	Economy	13600.00
0005432460482	4736	Economy	13600.00
0005432460497	4736	Economy	13600.00
0005432460501	4736	Economy	13600.00
0005432568384	4736	Economy	13600.00
0005432460466	4736	Economy	13600.00
0005432568395	4736	Economy	13600.00
0005432568359	4736	Economy	13600.00
0005432568346	4736	Economy	13600.00
0005432460474	4736	Economy	13600.00
0005432170468	4736	Economy	13600.00
0005433452766	4736	Economy	13600.00
0005432568369	4736	Economy	13600.00
0005432186913	4736	Economy	13600.00
0005432568375	4736	Economy	13600.00
0005432568383	4736	Economy	13600.00
0005432460504	4736	Economy	13600.00
0005432460493	4736	Economy	13600.00
0005432568382	4736	Economy	13600.00
0005432460487	4736	Economy	13600.00
0005432460499	4736	Economy	13600.00
0005432568389	4736	Economy	13600.00
0005432170466	4736	Economy	13600.00
0005432460500	4736	Economy	13600.00
0005432460505	4736	Economy	13600.00
0005432460502	4736	Economy	13600.00
0005432568396	4736	Economy	13600.00
0005434082182	4736	Economy	13600.00
0005434082187	4736	Economy	13600.00
0005432568377	4736	Economy	13600.00
0005434082183	4736	Economy	13600.00
0005434082194	4736	Economy	13600.00
0005432568391	4736	Economy	13600.00
0005432568341	4736	Economy	13600.00
0005432568378	4736	Economy	13600.00
0005432568340	4736	Economy	13600.00
0005432568343	4736	Economy	13600.00
0005432568398	4736	Economy	13600.00
0005433452764	4736	Economy	13600.00
0005432170470	4736	Economy	13600.00
0005432568355	4736	Economy	13600.00
0005432460129	30525	Business	40900.00
0005434081984	30525	Business	40900.00
0005432460033	30525	Business	40900.00
0005432567781	30525	Business	40900.00
0005432213650	30525	Business	40900.00
0005432568200	30525	Business	40900.00
0005432460083	30525	Business	40900.00
0005432568084	30525	Business	40900.00
0005432460133	30525	Business	40900.00
0005432568029	30525	Business	40900.00
0005432459972	30525	Business	40900.00
0005434082001	30525	Business	40900.00
0005432213651	30525	Business	40900.00
0005432567747	30525	Business	40900.00
0005432460260	30525	Business	40900.00
0005432460102	30525	Business	40900.00
0005432567985	30525	Business	40900.00
0005432161179	30525	Business	40900.00
0005432460156	30525	Business	40900.00
0005432567721	30525	Business	40900.00
0005434081965	30525	Business	40900.00
0005432567830	30525	Economy	15000.00
0005432567934	30525	Economy	15000.00
0005432567848	30525	Economy	13600.00
0005432567959	30525	Economy	13600.00
0005432568015	30525	Economy	13600.00
0005432567653	30525	Economy	13600.00
0005432568031	30525	Economy	13600.00
0005432567971	30525	Economy	13600.00
0005432460228	30525	Economy	13600.00
0005432567849	30525	Economy	13600.00
0005432459938	30525	Economy	13600.00
0005432568082	30525	Economy	13600.00
0005432460162	30525	Economy	13600.00
0005433454893	30525	Economy	13600.00
0005432459927	30525	Economy	13600.00
0005432459939	30525	Economy	13600.00
0005432571349	30525	Economy	13600.00
0005434081944	30525	Economy	13600.00
0005432567808	30525	Economy	13600.00
0005432567912	30525	Economy	13600.00
0005432161180	30525	Economy	13600.00
0005433452746	30525	Economy	13600.00
0005432460374	30525	Economy	13600.00
0005432459831	30525	Economy	13600.00
0005432460158	30525	Economy	13600.00
0005432567804	30525	Economy	13600.00
0005432568013	30525	Economy	13600.00
0005432567579	30525	Economy	13600.00
0005432459973	30525	Economy	13600.00
0005432460103	30525	Economy	13600.00
0005432459926	30525	Economy	13600.00
0005432460184	30525	Economy	13600.00
0005432567855	30525	Economy	13600.00
0005433452752	30525	Economy	13600.00
0005432459940	30525	Economy	13600.00
0005432460153	30525	Economy	13600.00
0005432567795	30525	Economy	13600.00
0005432459969	30525	Economy	13600.00
0005432567794	30525	Economy	13600.00
0005432460157	30525	Economy	13600.00
0005432567594	30525	Economy	13600.00
0005432460159	30525	Economy	13600.00
0005434081962	30525	Economy	13600.00
0005432567862	30525	Economy	13600.00
0005432459706	30525	Economy	13600.00
0005432567965	30525	Economy	13600.00
0005434081994	30525	Economy	13600.00
0005432567805	30525	Economy	13600.00
0005432567950	30525	Economy	13600.00
0005432568003	30525	Economy	13600.00
0005432460229	30525	Economy	13600.00
0005434081934	30525	Economy	13600.00
0005432568159	30525	Economy	13600.00
0005432567738	30525	Economy	13600.00
0005434081995	30525	Economy	13600.00
0005434082023	30525	Economy	13600.00
0005432567783	30525	Economy	13600.00
0005434082000	30525	Economy	13600.00
0005432567735	30525	Economy	13600.00
0005432567648	30525	Economy	13600.00
0005432213653	30525	Economy	13600.00
0005434082084	30525	Economy	13600.00
0005432460163	30525	Economy	13600.00
0005432567961	30525	Economy	13600.00
0005432567919	30525	Economy	13600.00
0005432568158	30525	Economy	13600.00
0005432459707	30525	Economy	13600.00
0005432567715	30525	Economy	13600.00
0005432460135	30525	Economy	13600.00
0005432460155	30525	Economy	13600.00
0005432460263	30525	Economy	13600.00
0005432567714	30525	Economy	13600.00
0005434081971	30525	Economy	13600.00
0005432460070	30525	Economy	13600.00
0005432567739	30525	Economy	13600.00
0005432460165	30525	Economy	13600.00
0005432460118	30525	Economy	13600.00
0005432460409	30525	Economy	13600.00
0005432459964	30525	Economy	15000.00
0005434081917	30525	Economy	13600.00
0005432568028	30525	Economy	13600.00
0005432567803	30525	Economy	15000.00
0005432567868	30525	Economy	15000.00
0005432460207	30525	Economy	13600.00
0005432568083	30525	Economy	13600.00
0005432459902	30525	Economy	13600.00
0005432460093	30525	Economy	13600.00
0005434081979	30525	Economy	13600.00
0005432460104	30525	Economy	13600.00
0005432567981	30525	Economy	13600.00
0005432459998	30525	Economy	13600.00
0005432459830	30525	Economy	13600.00
0005432568136	30525	Economy	13600.00
0005432460105	30525	Economy	13600.00
0005432459896	30525	Economy	13600.00
0005433452750	30525	Economy	13600.00
0005432567844	30525	Economy	13600.00
0005432460218	30525	Economy	13600.00
0005432567972	30525	Economy	13600.00
0005432567956	30525	Economy	13600.00
0005432460022	30525	Economy	13600.00
0005434081883	30525	Economy	13600.00
0005432460045	30525	Economy	13600.00
0005432568107	30525	Economy	13600.00
0005434081947	30525	Economy	13600.00
0005432459975	30525	Economy	13600.00
0005432567957	30525	Economy	13600.00
0005432567831	30525	Economy	13600.00
0005432460375	30525	Economy	13600.00
0005432460171	30525	Economy	13600.00
0005432460136	30525	Economy	13600.00
0005434082010	30525	Economy	13600.00
0005434082022	30525	Economy	13600.00
0005432460032	30525	Economy	13600.00
0005432460051	30525	Economy	13600.00
0005433454892	30525	Economy	13600.00
0005433452745	30525	Economy	13600.00
0005434082004	30525	Economy	13600.00
0005432213652	30525	Economy	13600.00
0005432567822	30525	Economy	13600.00
0005432460078	30525	Economy	13600.00
0005432459838	30525	Economy	13600.00
0005432460119	30525	Economy	13600.00
0005432568155	30525	Economy	13600.00
0005432567986	30525	Economy	13600.00
0005432567806	30525	Economy	13600.00
0005432571351	30525	Economy	13600.00
0005432567968	30525	Economy	13600.00
0005432459901	30525	Economy	13600.00
0005432567960	30525	Economy	13600.00
0005432568032	30525	Economy	13600.00
0005432460140	30525	Economy	13600.00
0005432459994	30525	Economy	13600.00
0005432567780	30525	Economy	13600.00
0005432460154	30525	Economy	13600.00
0005432567593	30525	Economy	13600.00
0005434081873	30525	Economy	13600.00
0005432567984	30525	Economy	13600.00
0005432567660	30525	Economy	13600.00
0005434081980	30525	Economy	13600.00
0005432460084	30525	Economy	13600.00
0005432460231	30525	Economy	13600.00
0005432460410	30525	Economy	13600.00
0005432571350	30525	Economy	13600.00
0005434081863	30525	Economy	13600.00
0005434081872	30525	Economy	13600.00
0005435720837	13617	Economy	9900.00
0005435722084	13617	Economy	9900.00
0005435720838	13617	Economy	9900.00
0005435722083	13617	Economy	9900.00
0005435722085	13617	Economy	9900.00
0005435722063	21189	Economy	9900.00
0005435722065	21189	Economy	9900.00
0005435720135	21189	Economy	9900.00
0005435722066	21189	Economy	9900.00
0005432295912	22804	Economy	8800.00
0005432295910	22804	Economy	8800.00
0005432295911	22804	Economy	8800.00
0005433344403	11089	Business	23600.00
0005435380316	11089	Business	23600.00
0005433344344	11089	Business	23600.00
0005433344389	11089	Business	23600.00
0005433344384	11089	Business	23600.00
0005433344358	11089	Business	23600.00
0005433344425	11089	Business	23600.00
0005433344414	11089	Business	23600.00
0005433344390	11089	Business	23600.00
0005433344392	11089	Business	23600.00
0005433344356	11089	Business	23600.00
0005433344365	11089	Economy	7900.00
0005435380302	11089	Economy	7900.00
0005433344345	11089	Economy	7900.00
0005433344331	11089	Economy	7900.00
0005435097313	11089	Economy	7900.00
0005433344416	11089	Economy	7900.00
0005433344353	11089	Economy	7900.00
0005433344395	11089	Economy	7900.00
0005433344405	11089	Economy	7900.00
0005433344364	11089	Economy	7900.00
0005433344338	11089	Economy	7900.00
0005433344333	11089	Economy	7900.00
0005433344401	11089	Economy	7900.00
0005433344412	11089	Economy	7900.00
0005433344360	11089	Economy	7900.00
0005435097315	11089	Economy	7900.00
0005433344394	11089	Economy	7900.00
0005433344402	11089	Economy	7900.00
0005433344363	11089	Economy	7900.00
0005433344342	11089	Economy	7900.00
0005433344375	11089	Economy	7900.00
0005435097318	11089	Economy	7900.00
0005433344388	11089	Economy	7900.00
0005435097320	11089	Economy	7900.00
0005433344339	11089	Economy	7900.00
0005435508361	11089	Economy	7900.00
0005433344366	11089	Economy	7900.00
0005435097317	11089	Economy	7900.00
0005433344362	11089	Economy	7900.00
0005433344399	11089	Economy	7900.00
0005433344418	11089	Economy	7900.00
0005433344383	11089	Economy	7900.00
0005433344361	11089	Economy	7900.00
0005433344340	11089	Economy	7900.00
0005433344376	11089	Economy	7900.00
0005433344385	11089	Economy	7900.00
0005433344410	11089	Economy	7900.00
0005433344431	11089	Economy	7900.00
0005433344354	11089	Economy	7900.00
0005433344379	11089	Economy	8600.00
0005435380313	11089	Economy	8600.00
0005433344411	11089	Economy	8600.00
0005435380297	11089	Economy	8600.00
0005433344387	11089	Economy	8600.00
0005433344370	11089	Economy	8600.00
0005433344332	11089	Economy	7900.00
0005433344404	11089	Economy	7900.00
0005433344346	11089	Economy	7900.00
0005433344330	11089	Economy	7900.00
0005435097321	11089	Economy	7900.00
0005433344372	11089	Economy	7900.00
0005435097314	11089	Economy	7900.00
0005435508376	11089	Economy	7900.00
0005433344422	11089	Economy	7900.00
0005433344429	11089	Economy	7900.00
0005433344400	11089	Economy	7900.00
0005433344371	11089	Economy	7900.00
0005433344352	11089	Economy	7900.00
0005433344391	11089	Economy	7900.00
0005433344407	11089	Economy	7900.00
0005433344409	11089	Economy	7900.00
0005433344367	11089	Economy	7900.00
0005433344423	11089	Economy	7900.00
0005433344380	11089	Economy	7900.00
0005433344378	11089	Economy	7900.00
0005435508369	11089	Economy	7900.00
0005433344368	11089	Economy	7900.00
0005435380320	11089	Economy	7900.00
0005433344420	11089	Economy	7900.00
0005433344349	11089	Economy	7900.00
0005433344347	11089	Economy	7900.00
0005433344369	11089	Economy	7900.00
0005433344430	11089	Economy	7900.00
0005435380312	11089	Economy	7900.00
0005433344350	11089	Economy	7900.00
0005433344335	11089	Economy	7900.00
0005433344334	11089	Economy	7900.00
0005433344382	11089	Economy	7900.00
0005433344393	11089	Economy	7900.00
0005433344398	11089	Economy	7900.00
0005433344386	11089	Economy	7900.00
0005433344381	11089	Economy	7900.00
0005433344413	11089	Economy	7900.00
0005433344424	11089	Economy	7900.00
0005433344337	11089	Economy	7900.00
0005433344351	11089	Economy	7900.00
0005435097319	11089	Economy	7900.00
0005433344415	11089	Economy	7900.00
0005435380295	11089	Economy	7900.00
0005433344377	11089	Economy	7900.00
0005433344417	11089	Economy	7900.00
0005433344427	11089	Economy	7900.00
0005433344359	11089	Economy	7900.00
0005433344406	11089	Economy	7900.00
0005433344374	11089	Economy	7900.00
0005433344396	11089	Economy	7900.00
0005433344419	11089	Economy	7900.00
0005435097316	11089	Economy	7900.00
0005433344428	11089	Economy	7900.00
0005433344341	11089	Economy	7900.00
0005435508377	11089	Economy	7900.00
0005433344432	11089	Economy	7900.00
0005433344397	11089	Economy	7900.00
0005435380296	11089	Economy	7900.00
0005433344355	11089	Economy	7900.00
0005435380301	11089	Economy	7900.00
0005433344343	11089	Economy	7900.00
0005433344336	11089	Economy	7900.00
0005433344348	11089	Economy	7900.00
0005433344421	11089	Economy	7900.00
0005433344357	11089	Economy	7900.00
0005433344373	11089	Economy	7900.00
0005433344408	11089	Economy	7900.00
0005433344426	11089	Economy	7900.00
0005435097312	11089	Economy	7900.00
0005433343020	17133	Business	23600.00
0005433343494	17133	Business	23600.00
0005433343604	17133	Business	23600.00
0005433343014	17133	Business	23600.00
0005433343681	17133	Business	23600.00
0005433343726	17133	Business	23600.00
0005435380352	17133	Business	23600.00
0005433343132	17133	Business	23600.00
0005435097233	17133	Business	23600.00
0005433342893	17133	Business	23600.00
0005433343773	17133	Business	23600.00
0005433343555	17133	Business	23600.00
0005433343126	17133	Economy	7900.00
0005433343307	17133	Economy	7900.00
0005433343166	17133	Economy	7900.00
0005433343384	17133	Economy	7900.00
0005433343543	17133	Economy	7900.00
0005433343574	17133	Economy	7900.00
0005435380354	17133	Economy	7900.00
0005433343016	17133	Economy	7900.00
0005433343396	17133	Economy	7900.00
0005433343334	17133	Economy	7900.00
0005433343685	17133	Economy	7900.00
0005433343605	17133	Economy	7900.00
0005433343469	17133	Economy	7900.00
0005433343788	17133	Economy	7900.00
0005433343120	17133	Economy	7900.00
0005433343474	17133	Economy	7900.00
0005433343337	17133	Economy	7900.00
0005433343323	17133	Economy	7900.00
0005433343436	17133	Economy	7900.00
0005433343544	17133	Economy	7900.00
0005433343554	17133	Economy	7900.00
0005433343373	17133	Economy	7900.00
0005433343189	17133	Economy	7900.00
0005433343682	17133	Economy	7900.00
0005435097208	17133	Economy	7900.00
0005433343110	17133	Economy	7900.00
0005433343125	17133	Economy	7900.00
0005433343018	17133	Economy	7900.00
0005433343475	17133	Economy	7900.00
0005433343476	17133	Economy	7900.00
0005433343503	17133	Economy	7900.00
0005435097243	17133	Economy	7900.00
0005435545844	17133	Economy	7900.00
0005433343641	17133	Economy	7900.00
0005433343242	17133	Economy	7900.00
0005435097235	17133	Economy	7900.00
0005433343495	17133	Economy	7900.00
0005435380353	17133	Economy	7900.00
0005435097209	17133	Economy	8600.00
0005433343109	17133	Economy	8600.00
0005433343237	17133	Economy	8600.00
0005433343705	17133	Economy	8600.00
0005433343335	17133	Economy	8600.00
0005433343439	17133	Economy	7900.00
0005433343725	17133	Economy	7900.00
0005433343491	17133	Economy	7900.00
0005433343283	17133	Economy	7900.00
0005433342894	17133	Economy	7900.00
0005433343793	17133	Economy	7900.00
0005433343608	17133	Economy	7900.00
0005433343305	17133	Economy	7900.00
0005433343664	17133	Economy	7900.00
0005433343976	17133	Economy	7900.00
0005433343421	17133	Economy	7900.00
0005433343489	17133	Economy	7900.00
0005433343485	17133	Economy	7900.00
0005433343862	17133	Economy	7900.00
0005433343137	17133	Economy	7900.00
0005433343727	17133	Economy	7900.00
0005433343060	17133	Economy	7900.00
0005435097259	17133	Economy	7900.00
0005435380357	17133	Economy	7900.00
0005433343686	17133	Economy	7900.00
0005433343566	17133	Economy	7900.00
0005433343372	17133	Economy	7900.00
0005435097245	17133	Economy	7900.00
0005433343381	17133	Economy	7900.00
0005435380355	17133	Economy	7900.00
0005433342990	17133	Economy	7900.00
0005433343551	17133	Economy	7900.00
0005433343490	17133	Economy	7900.00
0005433343013	17133	Economy	7900.00
0005433343794	17133	Economy	7900.00
0005433343119	17133	Economy	7900.00
0005433343787	17133	Economy	7900.00
0005433343696	17133	Economy	7900.00
0005433343239	17133	Economy	7900.00
0005433343313	17133	Economy	7900.00
0005435097232	17133	Economy	7900.00
0005433343282	17133	Economy	7900.00
0005433343763	17133	Economy	7900.00
0005433343238	17133	Economy	7900.00
0005433343663	17133	Economy	7900.00
0005433343216	17133	Economy	7900.00
0005432293238	17133	Economy	7900.00
0005433343434	17133	Economy	7900.00
0005433343288	17133	Economy	7900.00
0005433343487	17133	Economy	7900.00
0005433343795	17133	Economy	7900.00
0005435097244	17133	Economy	7900.00
0005433343167	17133	Economy	7900.00
0005433343531	17133	Economy	7900.00
0005433343019	17133	Economy	7900.00
0005433343296	17133	Economy	7900.00
0005433343360	17133	Economy	7900.00
0005435380356	17133	Economy	7900.00
0005433343435	17133	Economy	7900.00
0005433343630	17133	Economy	7900.00
0005433343342	17133	Economy	7900.00
0005433343382	17133	Economy	7900.00
0005435097260	17133	Economy	7900.00
0005433343358	17133	Economy	7900.00
0005433343512	17133	Economy	7900.00
0005433343668	17133	Economy	7900.00
0005433343597	17133	Economy	7900.00
0005433343532	17133	Economy	7900.00
0005433343486	17133	Economy	7900.00
0005433343326	17133	Economy	7900.00
0005432293239	17133	Economy	7900.00
0005433343516	17133	Economy	7900.00
0005435097246	17133	Economy	7900.00
0005433343470	17133	Economy	7900.00
0005434158986	9099	Business	26600.00
0005433507396	9099	Business	26600.00
0005433481262	9099	Business	26600.00
0005433507401	9099	Business	26600.00
0005434158989	9099	Business	26600.00
0005432919923	9099	Business	26600.00
0005433507403	9099	Business	26600.00
0005433507402	9099	Business	26600.00
0005434158984	9099	Economy	8900.00
0005432919840	9099	Economy	8900.00
0005433481263	9099	Economy	8900.00
0005433481259	9099	Economy	8900.00
0005432919940	9099	Economy	8900.00
0005433481265	9099	Economy	8900.00
0005433507397	9099	Economy	9800.00
0005433507394	9099	Economy	8900.00
0005433507399	9099	Economy	8900.00
0005432919925	9099	Economy	8900.00
0005432919964	9099	Economy	8900.00
0005432919926	9099	Economy	8900.00
0005433481266	9099	Economy	8900.00
0005434158973	9099	Economy	8900.00
0005433507400	9099	Economy	8900.00
0005433481260	9099	Economy	8900.00
0005432919809	9099	Economy	8900.00
0005432919939	9099	Economy	8900.00
0005434158988	9099	Economy	8900.00
0005433481261	9099	Economy	8900.00
0005434158985	9099	Economy	8900.00
0005433507395	9099	Economy	8900.00
0005434158983	9099	Economy	8900.00
0005433507393	9099	Economy	8900.00
0005432920000	9099	Economy	8900.00
0005433507406	9099	Economy	8900.00
0005432920001	9099	Economy	8900.00
0005433507405	9099	Economy	8900.00
0005432919835	9099	Economy	8900.00
0005433481258	9099	Economy	8900.00
0005433481264	9099	Economy	8900.00
0005432919836	9099	Economy	8900.00
0005433507398	9099	Economy	8900.00
0005433507404	9099	Economy	8900.00
0005432919952	9099	Economy	8900.00
0005433507202	20479	Business	26600.00
0005432920126	20479	Business	26600.00
0005433507204	20479	Business	26600.00
0005433481211	20479	Business	26600.00
0005433507150	20479	Business	26600.00
0005433507250	20479	Business	26600.00
0005432920138	20479	Business	26600.00
0005433481197	20479	Business	26600.00
0005433507178	20479	Economy	8900.00
0005432920125	20479	Economy	8900.00
0005433507254	20479	Economy	8900.00
0005433507284	20479	Economy	8900.00
0005433507255	20479	Economy	8900.00
0005433507246	20479	Economy	9800.00
0005433507251	20479	Economy	9800.00
0005433481230	20479	Economy	9800.00
0005432920136	20479	Economy	9800.00
0005432920129	20479	Economy	8900.00
0005432920124	20479	Economy	8900.00
0005432920127	20479	Economy	8900.00
0005433507264	20479	Economy	8900.00
0005433507253	20479	Economy	8900.00
0005432920137	20479	Economy	8900.00
0005432920141	20479	Economy	8900.00
0005432920134	20479	Economy	8900.00
0005432920132	20479	Economy	8900.00
0005433481195	20479	Economy	8900.00
0005432920143	20479	Economy	8900.00
0005433507252	20479	Economy	8900.00
0005433507179	20479	Economy	8900.00
0005432920128	20479	Economy	8900.00
0005432920144	20479	Economy	8900.00
0005432920131	20479	Economy	8900.00
0005433507234	20479	Economy	8900.00
0005433507281	20479	Economy	8900.00
0005433507213	20479	Economy	8900.00
0005433507265	20479	Economy	8900.00
0005433507238	20479	Economy	8900.00
0005432920140	20479	Economy	8900.00
0005432920133	20479	Economy	8900.00
0005432920145	20479	Economy	8900.00
0005432920130	20479	Economy	8900.00
0005432920135	20479	Economy	8900.00
0005433481196	20479	Economy	8900.00
0005433507280	20479	Economy	8900.00
0005433507235	20479	Economy	8900.00
0005433507257	20479	Economy	8900.00
0005433507205	20479	Economy	8900.00
0005433507263	20479	Economy	8900.00
0005433507286	20479	Economy	8900.00
0005432920142	20479	Economy	8900.00
0005432920139	20479	Economy	8900.00
0005433507258	20479	Economy	8900.00
0005432396288	10157	Economy	5800.00
0005432396291	10157	Economy	5800.00
0005432396290	10157	Economy	5800.00
0005432394150	10157	Economy	5800.00
0005432396292	10157	Economy	5800.00
0005432396287	10157	Economy	5800.00
0005432394152	10157	Economy	5800.00
0005432396289	10157	Economy	5800.00
0005432394151	10157	Economy	5800.00
0005432394149	10157	Economy	5800.00
0005432396249	18325	Economy	5800.00
0005432400137	18325	Economy	5800.00
0005435179405	18325	Economy	5800.00
0005432396270	18325	Economy	5800.00
0005432396246	18325	Economy	5800.00
0005432400142	18325	Economy	5800.00
0005432396269	18325	Economy	5800.00
0005435126466	10988	Business	9500.00
0005435126375	10988	Business	9500.00
0005434928334	10988	Business	9500.00
0005435126320	10988	Business	9500.00
0005435126521	10988	Business	9500.00
0005435556701	10988	Business	9500.00
0005435126589	10988	Business	9500.00
0005435626226	10988	Business	9500.00
0005435126474	10988	Economy	3200.00
0005434411831	10988	Economy	3200.00
0005435626227	10988	Economy	3200.00
0005435126463	10988	Economy	3200.00
0005435626257	10988	Economy	3200.00
0005435556700	10988	Economy	3200.00
0005435626169	10988	Economy	3500.00
0005435626236	10988	Economy	3500.00
0005435126342	10988	Economy	3500.00
0005435126673	10988	Economy	3500.00
0005435126573	10988	Economy	3200.00
0005435626256	10988	Economy	3200.00
0005435126568	10988	Economy	3200.00
0005435626184	10988	Economy	3200.00
0005435626239	10988	Economy	3200.00
0005435626143	10988	Economy	3200.00
0005435126475	10988	Economy	3200.00
0005435126436	10988	Economy	3200.00
0005435126545	10988	Economy	3200.00
0005435626193	10988	Economy	3200.00
0005435626228	10988	Economy	3200.00
0005435126493	10988	Economy	3200.00
0005435626216	10988	Economy	3200.00
0005435626185	10988	Economy	3200.00
0005435126569	10988	Economy	3200.00
0005435626238	10988	Economy	3200.00
0005434411832	10988	Economy	3200.00
0005435126362	10988	Economy	3200.00
0005435126635	10988	Economy	3200.00
0005435126310	10988	Economy	3200.00
0005434411833	10988	Economy	3200.00
0005435626164	10988	Economy	3200.00
0005435626170	10988	Economy	3200.00
0005435126566	10988	Economy	3200.00
0005435626223	10988	Economy	3200.00
0005435126574	10988	Economy	3200.00
0005435126538	10988	Economy	3200.00
0005435126672	10988	Economy	3200.00
0005434928335	10988	Economy	3200.00
0005434411830	10988	Economy	3200.00
0005435626258	10988	Economy	3200.00
0005435126435	10988	Economy	3200.00
0005435554213	10988	Economy	3200.00
0005435126590	10988	Economy	3200.00
0005435626251	10988	Economy	3200.00
0005435126636	10988	Economy	3200.00
0005435626218	10988	Economy	3200.00
0005435126506	10988	Economy	3200.00
0005435126508	10988	Economy	3200.00
0005435626217	10988	Economy	3200.00
0005435126505	10988	Economy	3200.00
0005435554203	10988	Economy	3200.00
0005435626229	10988	Economy	3200.00
0005434928333	10988	Economy	3200.00
0005435126311	10988	Economy	3200.00
0005435126485	10988	Economy	3200.00
0005435626168	10988	Economy	3200.00
0005435126335	10988	Economy	3200.00
0005435126863	14694	Business	9500.00
0005435126855	14694	Business	9500.00
0005435126890	14694	Business	9500.00
0005435554243	14694	Business	9500.00
0005435126894	14694	Business	9500.00
0005435626399	14694	Economy	3200.00
0005435626410	14694	Economy	3200.00
0005434928302	14694	Economy	3200.00
0005435126872	14694	Economy	3200.00
0005435126859	14694	Economy	3200.00
0005435626412	14694	Economy	3200.00
0005435126879	14694	Economy	3200.00
0005435626407	14694	Economy	3200.00
0005435126864	14694	Economy	3200.00
0005435626408	14694	Economy	3500.00
0005435126874	14694	Economy	3500.00
0005435626400	14694	Economy	3500.00
0005435126889	14694	Economy	3500.00
0005434411768	14694	Economy	3200.00
0005435126862	14694	Economy	3200.00
0005435126869	14694	Economy	3200.00
0005435126888	14694	Economy	3200.00
0005435126860	14694	Economy	3200.00
0005435126856	14694	Economy	3200.00
0005435126895	14694	Economy	3200.00
0005435126861	14694	Economy	3200.00
0005435626406	14694	Economy	3200.00
0005435126892	14694	Economy	3200.00
0005435126878	14694	Economy	3200.00
0005435126882	14694	Economy	3200.00
0005434411796	14694	Economy	3200.00
0005435626401	14694	Economy	3200.00
0005435126877	14694	Economy	3200.00
0005435626411	14694	Economy	3200.00
0005435626404	14694	Economy	3200.00
0005435126873	14694	Economy	3200.00
0005435556723	14694	Economy	3200.00
0005435554242	14694	Economy	3200.00
0005434928303	14694	Economy	3200.00
0005435126858	14694	Economy	3200.00
0005435126885	14694	Economy	3200.00
0005435554246	14694	Economy	3200.00
0005434928317	14694	Economy	3200.00
0005435626403	14694	Economy	3200.00
0005435126887	14694	Economy	3200.00
0005435626402	14694	Economy	3200.00
0005435126896	14694	Economy	3200.00
0005435126886	14694	Economy	3200.00
0005435626409	14694	Economy	3200.00
0005434928318	14694	Economy	3200.00
0005435554245	14694	Economy	3200.00
0005435626405	14694	Economy	3200.00
0005435126880	14694	Economy	3200.00
0005435126884	14694	Economy	3200.00
0005435626413	14694	Economy	3200.00
0005435126881	14694	Economy	3200.00
0005435126866	14694	Economy	3200.00
0005435126883	14694	Economy	3200.00
0005434411782	14694	Economy	3200.00
0005435126865	14694	Economy	3200.00
0005435126870	14694	Economy	3200.00
0005435554241	14694	Economy	3200.00
0005435554244	14694	Economy	3200.00
0005435126867	14694	Economy	3200.00
0005435126871	14694	Economy	3200.00
0005435126868	14694	Economy	3200.00
0005434928311	14694	Economy	3200.00
0005435126876	14694	Economy	3200.00
0005434411776	14694	Economy	3200.00
0005435126893	14694	Economy	3200.00
0005434928304	14694	Economy	3200.00
0005435126857	14694	Economy	3200.00
0005435126891	14694	Economy	3200.00
0005435126875	14694	Economy	3200.00
0005435443338	7148	Business	86900.00
0005435715680	7148	Business	86900.00
0005435715671	7148	Business	86900.00
0005435715683	7148	Business	86900.00
0005435221059	7148	Business	86900.00
0005432398246	7148	Business	86900.00
0005435443346	7148	Economy	29000.00
0005435216594	7148	Economy	29000.00
0005435715673	7148	Economy	31900.00
0005435715685	7148	Economy	29000.00
0005435715682	7148	Economy	29000.00
0005435715687	7148	Economy	29000.00
0005432398244	7148	Economy	29000.00
0005435715686	7148	Economy	29000.00
0005435715670	7148	Economy	29000.00
0005435443337	7148	Economy	29000.00
0005435715672	7148	Economy	29000.00
0005435715677	7148	Economy	29000.00
0005432398247	7148	Economy	29000.00
0005435221058	7148	Economy	29000.00
0005435216593	7148	Economy	29000.00
0005435443348	7148	Economy	29000.00
0005435715674	7148	Economy	29000.00
0005435715678	7148	Economy	29000.00
0005435443347	7148	Economy	29000.00
0005435219215	7148	Economy	29000.00
0005435715684	7148	Economy	29000.00
0005435715675	7148	Economy	29000.00
0005435216585	7148	Economy	29000.00
0005435443368	7148	Economy	29000.00
0005432398245	7148	Economy	29000.00
0005435715679	7148	Economy	29000.00
0005432400172	7148	Economy	29000.00
0005432400171	7148	Economy	29000.00
0005435715681	7148	Economy	29000.00
0005435178500	7148	Economy	29000.00
0005432398243	7148	Economy	29000.00
0005435715676	7148	Economy	29000.00
0005435219214	7148	Economy	29000.00
0005435715508	27079	Business	86900.00
0005435715550	27079	Business	86900.00
0005435216614	27079	Business	86900.00
0005435715553	27079	Business	86900.00
0005435715499	27079	Business	86900.00
0005435443425	27079	Business	86900.00
0005435216613	27079	Business	86900.00
0005435715586	27079	Economy	29000.00
0005435443434	27079	Economy	29000.00
0005435217735	27079	Economy	29000.00
0005435715496	27079	Economy	29000.00
0005435715516	27079	Economy	29000.00
0005435443428	27079	Economy	29000.00
0005435217738	27079	Economy	29000.00
0005432398202	27079	Economy	29000.00
0005432398200	27079	Economy	31900.00
0005435715495	27079	Economy	31900.00
0005435715549	27079	Economy	31900.00
0005435715552	27079	Economy	31900.00
0005435715547	27079	Economy	29000.00
0005435443432	27079	Economy	29000.00
0005435217733	27079	Economy	29000.00
0005435715497	27079	Economy	29000.00
0005435216612	27079	Economy	29000.00
0005435216611	27079	Economy	29000.00
0005435217736	27079	Economy	29000.00
0005435715518	27079	Economy	29000.00
0005435216610	27079	Economy	29000.00
0005432394118	27079	Economy	29000.00
0005432398213	27079	Economy	29000.00
0005432394104	27079	Economy	29000.00
0005435443430	27079	Economy	29000.00
0005435715585	27079	Economy	29000.00
0005435443433	27079	Economy	29000.00
0005432398201	27079	Economy	29000.00
0005435715548	27079	Economy	29000.00
0005432394120	27079	Economy	29000.00
0005435443424	27079	Economy	29000.00
0005435443429	27079	Economy	29000.00
0005435715538	27079	Economy	29000.00
0005435443426	27079	Economy	29000.00
0005435217731	27079	Economy	29000.00
0005435216609	27079	Economy	29000.00
0005435178514	27079	Economy	29000.00
0005435217737	27079	Economy	29000.00
0005435443431	27079	Economy	29000.00
0005435443427	27079	Economy	29000.00
0005435715507	27079	Economy	29000.00
0005435715587	27079	Economy	29000.00
0005435715590	27079	Economy	29000.00
0005435216607	27079	Economy	29000.00
0005432398194	27079	Economy	29000.00
0005435715498	27079	Economy	29000.00
0005435217732	27079	Economy	29000.00
0005435715558	27079	Economy	29000.00
0005435216608	27079	Economy	29000.00
0005435715551	27079	Economy	29000.00
0005435715591	27079	Economy	29000.00
0005432394119	27079	Economy	29000.00
0005435715506	27079	Economy	29000.00
0005435217734	27079	Economy	29000.00
0005433060414	2704	Economy	7700.00
0005433060431	2704	Economy	7700.00
0005434084988	2704	Economy	7700.00
0005434084986	2704	Economy	7700.00
0005433060432	2704	Economy	7700.00
0005434084987	2704	Economy	7700.00
0005433060430	2704	Economy	7700.00
0005433060423	2704	Economy	7700.00
0005434084989	2704	Economy	7700.00
0005433060433	2704	Economy	7700.00
0005433060447	28468	Economy	7700.00
0005434084929	28468	Economy	7700.00
0005434084931	28468	Economy	7700.00
0005434084932	28468	Economy	7700.00
0005434084936	28468	Economy	7700.00
0005434084937	28468	Economy	7700.00
0005433060446	28468	Economy	7700.00
0005435548494	11168	Economy	27100.00
0005433788259	11168	Economy	27100.00
0005433788257	11168	Economy	24600.00
0005433788255	11168	Economy	24600.00
0005435548507	11168	Economy	24600.00
0005435548483	11168	Economy	24600.00
0005435548501	11168	Economy	24600.00
0005435548497	11168	Economy	24600.00
0005435548491	11168	Economy	24600.00
0005433788252	11168	Economy	24600.00
0005435548511	11168	Economy	24600.00
0005435548503	11168	Economy	24600.00
0005435548499	11168	Economy	24600.00
0005435548481	11168	Economy	24600.00
0005435548480	11168	Economy	24600.00
0005433788254	11168	Economy	24600.00
0005435548496	11168	Economy	24600.00
0005435548482	11168	Economy	24600.00
0005435548504	11168	Economy	24600.00
0005433788253	11168	Economy	24600.00
0005435548486	11168	Economy	24600.00
0005433788263	11168	Economy	24600.00
0005435548508	11168	Economy	24600.00
0005433788251	11168	Economy	24600.00
0005433788258	11168	Economy	24600.00
0005433788262	11168	Economy	24600.00
0005435548487	11168	Economy	24600.00
0005435548479	11168	Economy	24600.00
0005433788261	11168	Economy	24600.00
0005433788260	11168	Economy	24600.00
0005435548502	11168	Economy	24600.00
0005433788250	11168	Economy	24600.00
0005433788249	11168	Economy	24600.00
0005435548495	11168	Economy	24600.00
0005433788256	11168	Economy	24600.00
0005435548543	20681	Economy	27100.00
0005435548541	20681	Economy	27100.00
0005435548545	20681	Economy	27100.00
0005435548538	20681	Economy	24600.00
0005433788195	20681	Economy	24600.00
0005433788194	20681	Economy	24600.00
0005433788182	20681	Economy	24600.00
0005433788204	20681	Economy	24600.00
0005435548544	20681	Economy	24600.00
0005433788199	20681	Economy	24600.00
0005433788181	20681	Economy	24600.00
0005433788205	20681	Economy	24600.00
0005435548539	20681	Economy	24600.00
0005435548546	20681	Economy	24600.00
0005433788197	20681	Economy	24600.00
0005435548542	20681	Economy	24600.00
0005435548540	20681	Economy	24600.00
0005433788198	20681	Economy	24600.00
0005435541084	11404	Business	20200.00
0005435517984	11404	Business	20200.00
0005435517943	11404	Business	20200.00
0005435541113	11404	Business	20200.00
0005435541031	11404	Business	20200.00
0005435541078	11404	Business	20200.00
0005435517983	11404	Economy	6700.00
0005435541025	11404	Economy	6700.00
0005435541129	11404	Economy	6700.00
0005435517959	11404	Economy	6700.00
0005435517940	11404	Economy	6700.00
0005435541067	11404	Economy	6700.00
0005435541091	11404	Economy	6700.00
0005435541068	11404	Economy	7400.00
0005435517925	11404	Economy	7400.00
0005435541092	11404	Economy	6700.00
0005435541133	11404	Economy	6700.00
0005435517916	11404	Economy	6700.00
0005435541108	11404	Economy	6700.00
0005435541109	11404	Economy	6700.00
0005435541093	11404	Economy	6700.00
0005435517985	11404	Economy	6700.00
0005435541034	11404	Economy	6700.00
0005435517980	11404	Economy	6700.00
0005435541013	11404	Economy	6700.00
0005435518026	11404	Economy	6700.00
0005435541055	11404	Economy	6700.00
0005435541184	11404	Economy	6700.00
0005435541038	11404	Economy	6700.00
0005435517986	11404	Economy	6700.00
0005435541053	11404	Economy	6700.00
0005435541043	11404	Economy	6700.00
0005435541090	11404	Economy	6700.00
0005435541063	11404	Economy	6700.00
0005435517941	11404	Economy	6700.00
0005435518044	11404	Economy	6700.00
0005435517956	11404	Economy	6700.00
0005435541119	11404	Economy	6700.00
0005435541104	11404	Economy	6700.00
0005435518075	11404	Economy	6700.00
0005435518027	11404	Economy	6700.00
0005435541123	11404	Economy	6700.00
0005435541024	11404	Economy	6700.00
0005435541058	11404	Economy	6700.00
0005435541037	11404	Economy	6700.00
0005435541120	11404	Economy	6700.00
0005435541105	11404	Economy	6700.00
0005435517997	11404	Economy	6700.00
0005435541054	11404	Economy	6700.00
0005435517996	11404	Economy	6700.00
0005435517944	11404	Economy	6700.00
0005435541012	11404	Economy	6700.00
0005435517917	11404	Economy	6700.00
0005435518029	11404	Economy	6700.00
0005435541124	11404	Economy	6700.00
0005435529507	22214	Business	20200.00
0005435529520	22214	Business	20200.00
0005435529511	22214	Business	20200.00
0005435529510	22214	Business	20200.00
0005435541258	22214	Business	20200.00
0005435541263	22214	Business	20200.00
0005435541243	22214	Economy	6700.00
0005435529515	22214	Economy	6700.00
0005435529505	22214	Economy	6700.00
0005435529517	22214	Economy	6700.00
0005435529509	22214	Economy	6700.00
0005435541252	22214	Economy	7400.00
0005435529516	22214	Economy	7400.00
0005435541250	22214	Economy	7400.00
0005435541251	22214	Economy	6700.00
0005435541247	22214	Economy	6700.00
0005435529513	22214	Economy	6700.00
0005435529499	22214	Economy	6700.00
0005435541262	22214	Economy	6700.00
0005435541254	22214	Economy	6700.00
0005435529500	22214	Economy	6700.00
0005435541245	22214	Economy	6700.00
0005435541246	22214	Economy	6700.00
0005435541256	22214	Economy	6700.00
0005435541264	22214	Economy	6700.00
0005435541257	22214	Economy	6700.00
0005435529504	22214	Economy	6700.00
0005435541253	22214	Economy	6700.00
0005435529518	22214	Economy	6700.00
0005435529506	22214	Economy	6700.00
0005435529519	22214	Economy	6700.00
0005435541261	22214	Economy	6700.00
0005435529512	22214	Economy	6700.00
0005435529501	22214	Economy	6700.00
0005435541248	22214	Economy	6700.00
0005435529508	22214	Economy	6700.00
0005435529502	22214	Economy	6700.00
0005435541255	22214	Economy	6700.00
0005435541260	22214	Economy	6700.00
0005432294515	22214	Economy	6700.00
0005432294514	22214	Economy	6700.00
0005435541244	22214	Economy	6700.00
0005435541259	22214	Economy	6700.00
0005435541249	22214	Economy	6700.00
0005435529514	22214	Economy	6700.00
0005435529503	22214	Economy	6700.00
0005434907917	2305	Business	20200.00
0005433251559	2305	Business	20200.00
0005434907930	2305	Business	20200.00
0005434907923	2305	Business	20200.00
0005433251603	2305	Business	20200.00
0005433251641	2305	Business	20200.00
0005433251570	2305	Business	20200.00
0005434907909	2305	Business	20200.00
0005434907953	2305	Business	20200.00
0005434907924	2305	Business	20200.00
0005434907907	2305	Business	20200.00
0005433251517	2305	Business	20200.00
0005434907943	2305	Economy	6700.00
0005433251730	2305	Economy	6700.00
0005433251658	2305	Economy	6700.00
0005434907958	2305	Economy	6700.00
0005434907939	2305	Economy	6700.00
0005434907931	2305	Economy	6700.00
0005434907904	2305	Economy	6700.00
0005433251633	2305	Economy	6700.00
0005434907960	2305	Economy	6700.00
0005434907946	2305	Economy	6700.00
0005434907936	2305	Economy	7400.00
0005434907957	2305	Economy	7400.00
0005434907932	2305	Economy	7400.00
0005434907959	2305	Economy	7400.00
0005433251513	2305	Economy	7400.00
0005434907950	2305	Economy	6700.00
0005433251716	2305	Economy	6700.00
0005434907948	2305	Economy	6700.00
0005434907908	2305	Economy	6700.00
0005434907940	2305	Economy	6700.00
0005434907949	2305	Economy	6700.00
0005434907911	2305	Economy	6700.00
0005433251557	2305	Economy	6700.00
0005434907933	2305	Economy	6700.00
0005434907918	2305	Economy	6700.00
0005433251666	2305	Economy	6700.00
0005433251550	2305	Economy	6700.00
0005434907910	2305	Economy	6700.00
0005433251665	2305	Economy	6700.00
0005434907942	2305	Economy	6700.00
0005433251622	2305	Economy	6700.00
0005434907922	2305	Economy	6700.00
0005434907951	2305	Economy	6700.00
0005434907955	2305	Economy	6700.00
0005433251582	2305	Economy	6700.00
0005434907914	2305	Economy	6700.00
0005433251640	2305	Economy	6700.00
0005433251681	2305	Economy	6700.00
0005434907912	2305	Economy	6700.00
0005433251573	2305	Economy	6700.00
0005434907925	2305	Economy	6700.00
0005433251503	2305	Economy	6700.00
0005434907906	2305	Economy	6700.00
0005433251634	2305	Economy	6700.00
0005434907921	2305	Economy	6700.00
0005434907937	2305	Economy	6700.00
0005434907913	2305	Economy	6700.00
0005434907919	2305	Economy	6700.00
0005433251717	2305	Economy	6700.00
0005433251531	2305	Economy	6700.00
0005433251569	2305	Economy	6700.00
0005434907952	2305	Economy	6700.00
0005433251657	2305	Economy	6700.00
0005433251551	2305	Economy	6700.00
0005434907954	2305	Economy	6700.00
0005434907941	2305	Economy	6700.00
0005434907935	2305	Economy	6700.00
0005434907947	2305	Economy	6700.00
0005434907945	2305	Economy	6700.00
0005433251656	2305	Economy	6700.00
0005433251619	2305	Economy	6700.00
0005433251623	2305	Economy	6700.00
0005434907926	2305	Economy	6700.00
0005433251632	2305	Economy	6700.00
0005433251563	2305	Economy	6700.00
0005434907928	2305	Economy	6700.00
0005433401000	2305	Economy	6700.00
0005433251814	2305	Economy	6700.00
0005433251659	2305	Economy	6700.00
0005434907920	2305	Economy	6700.00
0005434907944	2305	Economy	6700.00
0005434907905	2305	Economy	6700.00
0005434907938	2305	Economy	6700.00
0005434907956	2305	Economy	6700.00
0005434907927	2305	Economy	6700.00
0005434907929	2305	Economy	6700.00
0005433251639	2305	Economy	6700.00
0005433251680	2305	Economy	6700.00
0005434907934	2305	Economy	6700.00
0005433251558	2305	Economy	6700.00
0005433251574	2305	Economy	6700.00
0005433401001	2305	Economy	6700.00
0005434907915	2305	Economy	6700.00
0005434907916	2305	Economy	6700.00
0005434907411	25605	Business	20200.00
0005433251846	25605	Business	20200.00
0005434907198	25605	Business	20200.00
0005433251849	25605	Business	20200.00
0005434907595	25605	Business	20200.00
0005434907524	25605	Business	20200.00
0005434907378	25605	Business	20200.00
0005433251853	25605	Business	20200.00
0005434907396	25605	Business	20200.00
0005433251874	25605	Business	20200.00
0005434907601	25605	Business	20200.00
0005433401022	25605	Economy	6700.00
0005434907576	25605	Economy	6700.00
0005434907575	25605	Economy	6700.00
0005434907363	25605	Economy	6700.00
0005434907525	25605	Economy	6700.00
0005434907625	25605	Economy	6700.00
0005433251871	25605	Economy	6700.00
0005433401019	25605	Economy	6700.00
0005434907362	25605	Economy	7400.00
0005434907600	25605	Economy	7400.00
0005434907389	25605	Economy	7400.00
0005433251857	25605	Economy	7400.00
0005434907709	25605	Economy	7400.00
0005434907277	25605	Economy	6700.00
0005434907351	25605	Economy	6700.00
0005434907357	25605	Economy	6700.00
0005434907372	25605	Economy	6700.00
0005433251859	25605	Economy	6700.00
0005433251868	25605	Economy	6700.00
0005434907483	25605	Economy	6700.00
0005434907388	25605	Economy	6700.00
0005433401021	25605	Economy	6700.00
0005434907508	25605	Economy	6700.00
0005433251867	25605	Economy	6700.00
0005434907482	25605	Economy	6700.00
0005434907225	25605	Economy	6700.00
0005434907418	25605	Economy	6700.00
0005433251856	25605	Economy	6700.00
0005433251864	25605	Economy	6700.00
0005434907526	25605	Economy	6700.00
0005434907529	25605	Economy	6700.00
0005434907488	25605	Economy	6700.00
0005433251847	25605	Economy	6700.00
0005433251870	25605	Economy	6700.00
0005434907359	25605	Economy	6700.00
0005433251844	25605	Economy	6700.00
0005434907407	25605	Economy	6700.00
0005433251865	25605	Economy	6700.00
0005434907470	25605	Economy	6700.00
0005433251852	25605	Economy	6700.00
0005434907180	25605	Economy	6700.00
0005434907481	25605	Economy	6700.00
0005433251848	25605	Economy	6700.00
0005434907624	25605	Economy	6700.00
0005433251860	25605	Economy	6700.00
0005434907361	25605	Economy	6700.00
0005434907737	25605	Economy	6700.00
0005433251854	25605	Economy	6700.00
0005434907335	25605	Economy	6700.00
0005433251866	25605	Economy	6700.00
0005433251869	25605	Economy	6700.00
0005434907608	25605	Economy	6700.00
0005433251850	25605	Economy	6700.00
0005434907697	25605	Economy	6700.00
0005434907336	25605	Economy	6700.00
0005434907703	25605	Economy	6700.00
0005433251863	25605	Economy	6700.00
0005433251872	25605	Economy	6700.00
0005434907181	25605	Economy	6700.00
0005434907647	25605	Economy	6700.00
0005433251862	25605	Economy	6700.00
0005434907440	25605	Economy	6700.00
0005433251845	25605	Economy	6700.00
0005434907369	25605	Economy	6700.00
0005434907226	25605	Economy	6700.00
0005433251855	25605	Economy	6700.00
0005433401020	25605	Economy	6700.00
0005433251861	25605	Economy	6700.00
0005434907261	25605	Economy	6700.00
0005433251875	25605	Economy	6700.00
0005433251873	25605	Economy	6700.00
0005433251858	25605	Economy	6700.00
0005433251851	25605	Economy	6700.00
0005432621207	2503	Economy	13600.00
0005432621210	2503	Economy	13600.00
0005432621209	2503	Economy	12400.00
0005432621215	2503	Economy	12400.00
0005432862327	2503	Economy	12400.00
0005432621218	2503	Economy	12400.00
0005432862326	2503	Economy	12400.00
0005432621212	2503	Economy	12400.00
0005432862345	2503	Economy	12400.00
0005432621206	2503	Economy	12400.00
0005432862328	2503	Economy	12400.00
0005432621214	2503	Economy	12400.00
0005432621208	2503	Economy	12400.00
0005432621220	2503	Economy	12400.00
0005432621216	2503	Economy	12400.00
0005432862344	2503	Economy	12400.00
0005432862330	2503	Economy	12400.00
0005432621217	2503	Economy	12400.00
0005432621211	2503	Economy	12400.00
0005432862354	2503	Economy	12400.00
0005432621219	2503	Economy	12400.00
0005432862352	2503	Economy	12400.00
0005432621213	2503	Economy	12400.00
0005432621087	28058	Economy	13600.00
0005432862395	28058	Economy	13600.00
0005432862397	28058	Economy	12400.00
0005432621115	28058	Economy	12400.00
0005432621069	28058	Economy	12400.00
0005432621052	28058	Economy	12400.00
0005432862401	28058	Economy	12400.00
0005432621084	28058	Economy	12400.00
0005432862396	28058	Economy	12400.00
0005432621097	28058	Economy	12400.00
0005432862399	28058	Economy	12400.00
0005432621088	28058	Economy	12400.00
0005432862398	28058	Economy	12400.00
0005432621137	28058	Economy	12400.00
0005432621070	28058	Economy	12400.00
0005432621103	28058	Economy	12400.00
0005432621051	28058	Economy	12400.00
0005432862400	28058	Economy	12400.00
0005434097494	13083	Economy	11300.00
0005434097493	13083	Economy	11300.00
0005433452766	31024	Economy	8400.00
0005433451644	31024	Economy	8400.00
0005433452765	31024	Economy	8400.00
0005433452764	31024	Economy	8400.00
0005433451643	31024	Economy	8400.00
0005433452752	31358	Economy	8400.00
0005433454893	31358	Economy	8400.00
0005433452750	31358	Economy	8400.00
0005433452746	31358	Economy	8400.00
0005433454892	31358	Economy	8400.00
0005433452745	31358	Economy	8400.00
0005433129301	12014	Economy	7200.00
0005433129290	12014	Economy	7200.00
0005433129291	12014	Economy	6600.00
0005434142628	12014	Economy	6600.00
0005433129296	12014	Economy	6600.00
0005434142614	12014	Economy	6600.00
0005433129303	12014	Economy	6600.00
0005433134150	12014	Economy	6600.00
0005434142613	12014	Economy	6600.00
0005434184671	12014	Economy	6600.00
0005433129302	12014	Economy	6600.00
0005433134151	12014	Economy	6600.00
0005433134148	12014	Economy	6600.00
0005434142626	12014	Economy	6600.00
0005434184672	12014	Economy	6600.00
0005433134144	12014	Economy	6600.00
0005433134149	12014	Economy	6600.00
0005434142627	12014	Economy	6600.00
0005433134163	12014	Economy	6600.00
0005434184664	12014	Economy	6600.00
0005433134143	12014	Economy	6600.00
0005433134193	29861	Economy	7200.00
0005433134197	29861	Economy	7200.00
0005433134196	29861	Economy	6600.00
0005433131767	29861	Economy	6600.00
0005434142655	29861	Economy	6600.00
0005433131764	29861	Economy	6600.00
0005433134194	29861	Economy	6600.00
0005434142657	29861	Economy	6600.00
0005434184689	29861	Economy	6600.00
0005433131765	29861	Economy	6600.00
0005433134192	29861	Economy	6600.00
0005434142654	29861	Economy	6600.00
0005433131766	29861	Economy	6600.00
0005434183604	29861	Economy	6600.00
0005433134195	29861	Economy	6600.00
0005434142656	29861	Economy	6600.00
0005434184690	29861	Economy	6600.00
0005433131763	29861	Economy	6600.00
0005433131762	29861	Economy	6600.00
0005434183605	29861	Economy	6600.00
0005435798951	21295	Economy	15700.00
0005435798945	21295	Economy	15700.00
0005435798944	21295	Economy	15700.00
0005435798934	21295	Economy	15700.00
0005435798938	21295	Economy	15700.00
0005435798952	21295	Economy	15700.00
0005435798935	21295	Economy	15700.00
0005435798937	21295	Economy	15700.00
0005435798936	21295	Economy	15700.00
0005435798943	21295	Economy	15700.00
0005435798933	21295	Economy	15700.00
0005435697661	16497	Economy	19900.00
0005435697662	16497	Economy	19900.00
0005435697648	16497	Economy	19900.00
0005435697655	16497	Economy	19900.00
0005435697657	16497	Economy	18100.00
0005435697656	16497	Economy	18100.00
0005435697649	16497	Economy	18100.00
0005435697672	16497	Economy	18100.00
0005435697663	16497	Economy	18100.00
0005435697671	16497	Economy	18100.00
0005435697670	16497	Economy	18100.00
0005435935057	16497	Economy	18100.00
0005435697675	16497	Economy	18100.00
0005435697653	16497	Economy	18100.00
0005435697660	16497	Economy	18100.00
0005435697650	16497	Economy	18100.00
0005435935046	16497	Economy	18100.00
0005435697666	16497	Economy	18100.00
0005435697664	16497	Economy	18100.00
0005435697674	16497	Economy	18100.00
0005435935056	16497	Economy	18100.00
0005435697669	16497	Economy	18100.00
0005435697654	16497	Economy	18100.00
0005435697673	16497	Economy	18100.00
0005435697667	16497	Economy	18100.00
0005435697665	16497	Economy	18100.00
0005435697659	16497	Economy	18100.00
0005435697647	16497	Economy	18100.00
0005435697652	16497	Economy	18100.00
0005435697658	16497	Economy	18100.00
0005435935065	16497	Economy	18100.00
0005435935055	16497	Economy	18100.00
0005435697651	16497	Economy	18100.00
0005435697668	16497	Economy	18100.00
0005435697527	24742	Economy	19900.00
0005435697440	24742	Economy	19900.00
0005435697387	24742	Economy	19900.00
0005435697497	24742	Economy	18100.00
0005435697451	24742	Economy	18100.00
0005435697452	24742	Economy	18100.00
0005435697431	24742	Economy	18100.00
0005435697545	24742	Economy	18100.00
0005435697367	24742	Economy	18100.00
0005435697522	24742	Economy	18100.00
0005435697546	24742	Economy	18100.00
0005435697432	24742	Economy	18100.00
0005435697423	24742	Economy	18100.00
0005435697445	24742	Economy	18100.00
0005435697434	24742	Economy	18100.00
0005435697467	24742	Economy	18100.00
0005435697495	24742	Economy	18100.00
0005435697377	24742	Economy	18100.00
0005435697424	24742	Economy	18100.00
0005435697541	24742	Economy	18100.00
0005435697542	24742	Economy	18100.00
0005435697441	24742	Economy	18100.00
0005435697436	24742	Economy	18100.00
0005435697471	24742	Economy	18100.00
0005435697472	24742	Economy	18100.00
0005435697526	24742	Economy	18100.00
0005435697414	24742	Economy	18100.00
0005435697444	24742	Economy	18100.00
0005435697486	24742	Economy	18100.00
0005435697504	24742	Economy	18100.00
0005435697366	24742	Economy	18100.00
0005435697433	24742	Economy	18100.00
0005435697446	24742	Economy	18100.00
0005435697365	24742	Economy	18100.00
0005435697525	24742	Economy	18100.00
0005435697530	24742	Economy	18100.00
0005435697521	24742	Economy	18100.00
0005435697413	24742	Economy	18100.00
0005432968852	18769	Economy	4400.00
0005433724858	18769	Economy	4400.00
0005433724856	18769	Economy	4400.00
0005433724857	18769	Economy	4400.00
0005433724860	18769	Economy	4400.00
0005432968851	18769	Economy	4400.00
0005433724859	18769	Economy	4400.00
0005432968871	21641	Economy	4400.00
0005433724840	21641	Economy	4400.00
0005432968870	21641	Economy	4400.00
0005433724815	21641	Economy	4400.00
0005433724841	21641	Economy	4400.00
0005433724839	21641	Economy	4400.00
0005434139212	7299	Business	23100.00
0005434139135	7299	Business	23100.00
0005434139202	7299	Business	23100.00
0005434139157	7299	Business	23100.00
0005434139194	7299	Business	23100.00
0005434139192	7299	Business	23100.00
0005434139137	7299	Business	23100.00
0005434087575	7299	Business	23100.00
0005434139179	7299	Business	23100.00
0005434139142	7299	Business	23100.00
0005434087572	7299	Business	23100.00
0005434139165	7299	Business	23100.00
0005434139207	7299	Economy	7700.00
0005434139191	7299	Economy	7700.00
0005434139158	7299	Economy	7700.00
0005434139130	7299	Economy	7700.00
0005434139149	7299	Economy	7700.00
0005434139213	7299	Economy	7700.00
0005434139159	7299	Economy	7700.00
0005434139134	7299	Economy	7700.00
0005434139166	7299	Economy	7700.00
0005434139193	7299	Economy	7700.00
0005434139146	7299	Economy	8500.00
0005434139164	7299	Economy	8500.00
0005434139185	7299	Economy	8500.00
0005434139145	7299	Economy	8500.00
0005434139175	7299	Economy	7700.00
0005434139211	7299	Economy	7700.00
0005434139210	7299	Economy	7700.00
0005434139181	7299	Economy	7700.00
0005434139147	7299	Economy	7700.00
0005434139167	7299	Economy	7700.00
0005434139154	7299	Economy	7700.00
0005434139180	7299	Economy	7700.00
0005434139148	7299	Economy	7700.00
0005434139152	7299	Economy	7700.00
0005434139156	7299	Economy	7700.00
0005434139139	7299	Economy	7700.00
0005434139177	7299	Economy	7700.00
0005434139204	7299	Economy	7700.00
0005434139173	7299	Economy	7700.00
0005434139182	7299	Economy	7700.00
0005434139160	7299	Economy	7700.00
0005434139200	7299	Economy	7700.00
0005434139190	7299	Economy	7700.00
0005434139150	7299	Economy	7700.00
0005434139172	7299	Economy	7700.00
0005434087576	7299	Economy	7700.00
0005434139205	7299	Economy	7700.00
0005434139198	7299	Economy	7700.00
0005434139195	7299	Economy	7700.00
0005434139161	7299	Economy	7700.00
0005434139132	7299	Economy	7700.00
0005434139203	7299	Economy	7700.00
0005434139174	7299	Economy	7700.00
0005434139162	7299	Economy	7700.00
0005434139209	7299	Economy	7700.00
0005434139151	7299	Economy	7700.00
0005434139168	7299	Economy	7700.00
0005434139199	7299	Economy	7700.00
0005434139133	7299	Economy	7700.00
0005434139155	7299	Economy	7700.00
0005434139214	7299	Economy	7700.00
0005434139144	7299	Economy	7700.00
0005434139183	7299	Economy	7700.00
0005434139140	7299	Economy	7700.00
0005434087574	7299	Economy	7700.00
0005434139206	7299	Economy	7700.00
0005434139143	7299	Economy	7700.00
0005434139196	7299	Economy	7700.00
0005434139170	7299	Economy	7700.00
0005434139187	7299	Economy	7700.00
0005434139131	7299	Economy	7700.00
0005434139188	7299	Economy	7700.00
0005434139171	7299	Economy	7700.00
0005434139208	7299	Economy	7700.00
0005434139178	7299	Economy	7700.00
0005434139163	7299	Economy	7700.00
0005434139189	7299	Economy	7700.00
0005434139153	7299	Economy	7700.00
0005434139136	7299	Economy	7700.00
0005434139201	7299	Economy	7700.00
0005434139197	7299	Economy	7700.00
0005434139184	7299	Economy	7700.00
0005434139138	7299	Economy	7700.00
0005434139186	7299	Economy	7700.00
0005434139176	7299	Economy	7700.00
0005434139141	7299	Economy	7700.00
0005434087573	7299	Economy	7700.00
0005434139169	7299	Economy	7700.00
0005434138402	28582	Business	23100.00
0005434138213	28582	Business	23100.00
0005434138524	28582	Business	23100.00
0005434138456	28582	Business	23100.00
0005434087526	28582	Business	23100.00
0005434138528	28582	Business	23100.00
0005434138223	28582	Business	23100.00
0005434138523	28582	Business	23100.00
0005434138077	28582	Business	23100.00
0005434138359	28582	Business	23100.00
0005434138439	28582	Business	23100.00
0005434138340	28582	Business	23100.00
0005434137998	28582	Economy	7700.00
0005434138105	28582	Economy	7700.00
0005434138520	28582	Economy	7700.00
0005434138204	28582	Economy	7700.00
0005434138294	28582	Economy	7700.00
0005434138522	28582	Economy	7700.00
0005434138300	28582	Economy	7700.00
0005434138240	28582	Economy	7700.00
0005434138197	28582	Economy	7700.00
0005434138106	28582	Economy	7700.00
0005434138130	28582	Economy	8500.00
0005434138448	28582	Economy	8500.00
0005434138483	28582	Economy	8500.00
0005434138132	28582	Economy	8500.00
0005434138403	28582	Economy	8500.00
0005434138543	28582	Economy	7700.00
0005434138050	28582	Economy	7700.00
0005434138287	28582	Economy	7700.00
0005434138275	28582	Economy	7700.00
0005434138293	28582	Economy	7700.00
0005434138288	28582	Economy	7700.00
0005434138131	28582	Economy	7700.00
0005434138296	28582	Economy	7700.00
0005434138298	28582	Economy	7700.00
0005434138496	28582	Economy	7700.00
0005434138425	28582	Economy	7700.00
0005434138297	28582	Economy	7700.00
0005434138030	28582	Economy	7700.00
0005434138279	28582	Economy	7700.00
0005434138330	28582	Economy	7700.00
0005434138529	28582	Economy	7700.00
0005434138289	28582	Economy	7700.00
0005434138438	28582	Economy	7700.00
0005434138512	28582	Economy	7700.00
0005434138339	28582	Economy	7700.00
0005434138384	28582	Economy	7700.00
0005434138299	28582	Economy	7700.00
0005434138301	28582	Economy	7700.00
0005434138360	28582	Economy	7700.00
0005434138545	28582	Economy	7700.00
0005434137758	28582	Economy	7700.00
0005434138415	28582	Economy	7700.00
0005434138380	28582	Economy	7700.00
0005434138525	28582	Economy	7700.00
0005434138368	28582	Economy	7700.00
0005434138521	28582	Economy	7700.00
0005434138487	28582	Economy	7700.00
0005434138048	28582	Economy	7700.00
0005434087525	28582	Economy	7700.00
0005434138346	28582	Economy	7700.00
0005434138069	28582	Economy	7700.00
0005434138516	28582	Economy	7700.00
0005434138214	28582	Economy	7700.00
0005434138423	28582	Economy	7700.00
0005434138219	28582	Economy	7700.00
0005434138381	28582	Economy	7700.00
0005434138274	28582	Economy	7700.00
0005434138336	28582	Economy	7700.00
0005434138237	28582	Economy	7700.00
0005434138463	28582	Economy	7700.00
0005434138345	28582	Economy	7700.00
0005434138220	28582	Economy	7700.00
0005434138453	28582	Economy	7700.00
0005434138041	28582	Economy	7700.00
0005434138474	28582	Economy	7700.00
0005434138049	28582	Economy	7700.00
0005434138462	28582	Economy	7700.00
0005434138236	28582	Economy	7700.00
0005434138544	28582	Economy	7700.00
0005434138338	28582	Economy	7700.00
0005434138347	28582	Economy	7700.00
0005434138389	28582	Economy	7700.00
0005434138382	28582	Economy	7700.00
0005434138313	28582	Economy	7700.00
0005434138161	28582	Economy	7700.00
0005434138337	28582	Economy	7700.00
0005434138418	28582	Economy	7700.00
0005434138218	28582	Economy	7700.00
0005434138047	28582	Economy	7700.00
0005434138224	28582	Economy	7700.00
0005435808363	1948	Economy	23900.00
0005434610273	1948	Economy	21700.00
0005435808369	1948	Economy	21700.00
0005434610274	1948	Economy	21700.00
0005435808360	1948	Economy	21700.00
0005433407556	1948	Economy	21700.00
0005433407570	1948	Economy	21700.00
0005433407558	1948	Economy	21700.00
0005435808367	1948	Economy	21700.00
0005435808366	1948	Economy	21700.00
0005434610272	1948	Economy	21700.00
0005435808365	1948	Economy	21700.00
0005434610275	1948	Economy	21700.00
0005435808362	1948	Economy	21700.00
0005435808364	1948	Economy	21700.00
0005433407557	1948	Economy	21700.00
0005435808368	1948	Economy	21700.00
0005435808361	1948	Economy	21700.00
0005433407626	23113	Economy	23900.00
0005435808239	23113	Economy	23900.00
0005435808175	23113	Economy	21700.00
0005434610242	23113	Economy	21700.00
0005433407620	23113	Economy	21700.00
0005435808179	23113	Economy	21700.00
0005433407615	23113	Economy	21700.00
0005435808231	23113	Economy	21700.00
0005435808265	23113	Economy	21700.00
0005435808226	23113	Economy	21700.00
0005433407614	23113	Economy	21700.00
0005435808217	23113	Economy	21700.00
0005435808241	23113	Economy	21700.00
0005434610243	23113	Economy	21700.00
0005433407623	23113	Economy	21700.00
0005433407616	23113	Economy	21700.00
0005435808274	23113	Economy	21700.00
0005435808227	23113	Economy	21700.00
0005435808232	23113	Economy	21700.00
0005433407622	23113	Economy	21700.00
0005435808244	23113	Economy	21700.00
0005435808219	23113	Economy	21700.00
0005435808228	23113	Economy	21700.00
0005435808242	23113	Economy	21700.00
0005435808237	23113	Economy	21700.00
0005433407625	23113	Economy	21700.00
0005433407612	23113	Economy	21700.00
0005434610257	23113	Economy	21700.00
0005435808168	23113	Economy	21700.00
0005433407619	23113	Economy	21700.00
0005435808220	23113	Economy	21700.00
0005435808280	23113	Economy	21700.00
0005435808200	23113	Economy	21700.00
0005435808283	23113	Economy	21700.00
0005433407618	23113	Economy	21700.00
0005433407617	23113	Economy	21700.00
0005435808187	23113	Economy	21700.00
0005433407624	23113	Economy	21700.00
0005435808204	23113	Economy	21700.00
0005433407613	23113	Economy	21700.00
0005435808180	23113	Economy	21700.00
0005435808256	23113	Economy	21700.00
0005433407621	23113	Economy	21700.00
0005434504371	16682	Economy	7600.00
0005434504225	16682	Economy	7600.00
0005434504337	16682	Economy	6900.00
0005434504224	16682	Economy	6900.00
0005434504418	16682	Economy	6900.00
0005434504219	16682	Economy	6900.00
0005434504409	16682	Economy	6900.00
0005434504212	16682	Economy	6900.00
0005434504286	16682	Economy	6900.00
0005434504307	16682	Economy	6900.00
0005434504338	16682	Economy	6900.00
0005434503972	16682	Economy	6900.00
0005434504130	16682	Economy	6900.00
0005434504355	16682	Economy	6900.00
0005434504285	16682	Economy	6900.00
0005434504091	16682	Economy	6900.00
0005434504243	16682	Economy	6900.00
0005434504204	16682	Economy	6900.00
0005434504273	16682	Economy	6900.00
0005434504339	16682	Economy	6900.00
0005434504214	16682	Economy	6900.00
0005434504255	16682	Economy	6900.00
0005434504213	16682	Economy	6900.00
0005434504193	16682	Economy	6900.00
0005434504269	16682	Economy	6900.00
0005434504612	22902	Economy	7600.00
0005434504599	22902	Economy	7600.00
0005434504615	22902	Economy	7600.00
0005434504619	22902	Economy	6900.00
0005434504621	22902	Economy	6900.00
0005434504606	22902	Economy	6900.00
0005434504613	22902	Economy	6900.00
0005434504607	22902	Economy	6900.00
0005434504600	22902	Economy	6900.00
0005434504622	22902	Economy	6900.00
0005434504594	22902	Economy	6900.00
0005434504583	22902	Economy	6900.00
0005434504591	22902	Economy	6900.00
0005434504617	22902	Economy	6900.00
0005434504609	22902	Economy	6900.00
0005434504586	22902	Economy	6900.00
0005434504589	22902	Economy	6900.00
0005434504592	22902	Economy	6900.00
0005434504587	22902	Economy	6900.00
0005434504602	22902	Economy	6900.00
0005434504582	22902	Economy	6900.00
0005434504604	22902	Economy	6900.00
0005434504620	22902	Economy	6900.00
0005434504598	22902	Economy	6900.00
0005434504597	22902	Economy	6900.00
0005434504590	22902	Economy	6900.00
0005434504616	22902	Economy	6900.00
0005434504611	22902	Economy	6900.00
0005434504584	22902	Economy	6900.00
0005434504596	22902	Economy	6900.00
0005434504610	22902	Economy	6900.00
0005434504605	22902	Economy	6900.00
0005434504593	22902	Economy	6900.00
0005434504595	22902	Economy	6900.00
0005434504614	22902	Economy	6900.00
0005434504608	22902	Economy	6900.00
0005434504601	22902	Economy	6900.00
0005434504588	22902	Economy	6900.00
0005434504603	22902	Economy	6900.00
0005434504585	22902	Economy	6900.00
0005434504618	22902	Economy	6900.00
0005433266743	2202	Economy	7700.00
0005435078530	2202	Economy	7700.00
0005435078528	2202	Economy	7000.00
0005435078527	2202	Economy	7000.00
0005433266718	2202	Economy	7000.00
0005433266764	2202	Economy	7000.00
0005435078531	2202	Economy	7000.00
0005435078541	2202	Economy	7000.00
0005435078532	2202	Economy	7000.00
0005433266760	2202	Economy	7000.00
0005435078542	2202	Economy	7000.00
0005435078526	2202	Economy	7000.00
0005435078539	2202	Economy	7000.00
0005435078529	2202	Economy	7000.00
0005433266715	2202	Economy	7000.00
0005433266719	2202	Economy	7000.00
0005433266744	2202	Economy	7000.00
0005433266765	2202	Economy	7000.00
0005435078538	2202	Economy	7000.00
0005435078534	2202	Economy	7000.00
0005435078533	2202	Economy	7000.00
0005435078540	2202	Economy	7000.00
0005435078537	2202	Economy	7000.00
0005435078536	2202	Economy	7000.00
0005435078535	2202	Economy	7000.00
0005435078440	24324	Economy	7700.00
0005433266834	24324	Economy	7000.00
0005433266841	24324	Economy	7000.00
0005435078382	24324	Economy	7000.00
0005433266833	24324	Economy	7000.00
0005433266836	24324	Economy	7000.00
0005435078441	24324	Economy	7000.00
0005435078431	24324	Economy	7000.00
0005433266840	24324	Economy	7000.00
0005433266838	24324	Economy	7000.00
0005435078345	24324	Economy	7000.00
0005433266837	24324	Economy	7000.00
0005435078386	24324	Economy	7000.00
0005433266839	24324	Economy	7000.00
0005435078379	24324	Economy	7000.00
0005435078385	24324	Economy	7000.00
0005433266842	24324	Economy	7000.00
0005435078344	24324	Economy	7000.00
0005435078373	24324	Economy	7000.00
0005435078409	24324	Economy	7000.00
0005435078432	24324	Economy	7000.00
0005435078389	24324	Economy	7000.00
0005435078347	24324	Economy	7000.00
0005435078390	24324	Economy	7000.00
0005435078346	24324	Economy	7000.00
0005435078358	24324	Economy	7000.00
0005435078363	24324	Economy	7000.00
0005435078443	24324	Economy	7000.00
0005433266835	24324	Economy	7000.00
0005434988881	6621	Economy	10800.00
0005435803296	6621	Economy	10800.00
0005434988872	6621	Economy	9800.00
0005434988882	6621	Economy	9800.00
0005434988876	6621	Economy	9800.00
0005434988884	6621	Economy	9800.00
0005434988880	6621	Economy	9800.00
0005435803295	6621	Economy	9800.00
0005434988875	6621	Economy	9800.00
0005435803297	6621	Economy	9800.00
0005434988883	6621	Economy	9800.00
0005434988879	6621	Economy	9800.00
0005434988885	6621	Economy	9800.00
0005434988878	6621	Economy	9800.00
0005434988874	6621	Economy	9800.00
0005434988877	6621	Economy	9800.00
0005434988873	6621	Economy	9800.00
0005434988871	6621	Economy	9800.00
0005435464533	23620	Economy	10800.00
0005434988754	23620	Economy	9800.00
0005434988771	23620	Economy	9800.00
0005434988770	23620	Economy	9800.00
0005434988766	23620	Economy	9800.00
0005434988774	23620	Economy	9800.00
0005435464534	23620	Economy	9800.00
0005434988775	23620	Economy	9800.00
0005434988755	23620	Economy	9800.00
0005434988772	23620	Economy	9800.00
0005434988725	23620	Economy	9800.00
0005434988776	23620	Economy	9800.00
0005434988753	23620	Economy	9800.00
0005434988765	23620	Economy	9800.00
0005434988752	23620	Economy	9800.00
0005434988769	23620	Economy	9800.00
0005433454901	30456	Business	9900.00
0005432383661	30456	Business	9900.00
0005432383657	30456	Business	9900.00
0005432383659	30456	Business	9900.00
0005432383660	30456	Business	9900.00
0005433450238	30456	Business	9900.00
0005432383679	30456	Business	9900.00
0005433450229	30456	Business	9900.00
0005432383643	30456	Business	9900.00
0005432383651	30456	Business	9900.00
0005433450232	30456	Economy	3300.00
0005433450231	30456	Economy	3300.00
0005432383639	30456	Economy	3300.00
0005432383675	30456	Economy	3300.00
0005432383656	30456	Economy	3300.00
0005432383667	30456	Economy	3300.00
0005432383663	30456	Economy	3300.00
0005432383668	30456	Economy	3300.00
0005433450251	30456	Economy	3300.00
0005432383670	30456	Economy	3600.00
0005432383655	30456	Economy	3600.00
0005432383652	30456	Economy	3600.00
0005432383654	30456	Economy	3300.00
0005433450242	30456	Economy	3300.00
0005432383644	30456	Economy	3300.00
0005433453785	30456	Economy	3300.00
0005432383662	30456	Economy	3300.00
0005433450246	30456	Economy	3300.00
0005432383645	30456	Economy	3300.00
0005432383678	30456	Economy	3300.00
0005433453786	30456	Economy	3300.00
0005433450236	30456	Economy	3300.00
0005433450244	30456	Economy	3300.00
0005432383646	30456	Economy	3300.00
0005432383666	30456	Economy	3300.00
0005432383642	30456	Economy	3300.00
0005433450239	30456	Economy	3300.00
0005432383671	30456	Economy	3300.00
0005432383650	30456	Economy	3300.00
0005432383658	30456	Economy	3300.00
0005433450235	30456	Economy	3300.00
0005432383641	30456	Economy	3300.00
0005433450243	30456	Economy	3300.00
0005433450233	30456	Economy	3300.00
0005433450248	30456	Economy	3300.00
0005433450250	30456	Economy	3300.00
0005433450249	30456	Economy	3300.00
0005432383649	30456	Economy	3300.00
0005432383640	30456	Economy	3300.00
0005433450241	30456	Economy	3300.00
0005432383672	30456	Economy	3300.00
0005432383676	30456	Economy	3300.00
0005433450247	30456	Economy	3300.00
0005433450234	30456	Economy	3300.00
0005433454902	30456	Economy	3300.00
0005432383674	30456	Economy	3300.00
0005433450240	30456	Economy	3300.00
0005432383653	30456	Economy	3300.00
0005432383673	30456	Economy	3300.00
0005432383647	30456	Economy	3300.00
0005433450230	30456	Economy	3300.00
0005432383648	30456	Economy	3300.00
0005433450245	30456	Economy	3300.00
0005432383664	30456	Economy	3300.00
0005432383677	30456	Economy	3300.00
0005432383665	30456	Economy	3300.00
0005433450237	30456	Economy	3300.00
0005432383669	30456	Economy	3300.00
0005433450097	31288	Business	9900.00
0005432383144	31288	Business	9900.00
0005432383341	31288	Business	9900.00
0005432383244	31288	Business	9900.00
0005433451625	31288	Business	9900.00
0005432383182	31288	Business	9900.00
0005432383328	31288	Business	9900.00
0005432383250	31288	Business	9900.00
0005433450025	31288	Business	9900.00
0005433453774	31288	Business	9900.00
0005433453773	31288	Economy	3300.00
0005432383427	31288	Economy	3300.00
0005433450046	31288	Economy	3300.00
0005433450055	31288	Economy	3300.00
0005432383426	31288	Economy	3300.00
0005433450029	31288	Economy	3300.00
0005433450003	31288	Economy	3300.00
0005433450026	31288	Economy	3300.00
0005432383166	31288	Economy	3300.00
0005433449928	31288	Economy	3600.00
0005433453771	31288	Economy	3600.00
0005433449990	31288	Economy	3600.00
0005432383319	31288	Economy	3600.00
0005432383363	31288	Economy	3300.00
0005432383383	31288	Economy	3300.00
0005433449950	31288	Economy	3300.00
0005433450054	31288	Economy	3300.00
0005432383296	31288	Economy	3300.00
0005432383271	31288	Economy	3300.00
0005432383176	31288	Economy	3300.00
0005432383205	31288	Economy	3300.00
0005433450078	31288	Economy	3300.00
0005432383108	31288	Economy	3300.00
0005432383172	31288	Economy	3300.00
0005432383249	31288	Economy	3300.00
0005432383106	31288	Economy	3300.00
0005433450082	31288	Economy	3300.00
0005432383047	31288	Economy	3300.00
0005432383145	31288	Economy	3300.00
0005432383165	31288	Economy	3300.00
0005433453768	31288	Economy	3300.00
0005433451622	31288	Economy	3300.00
0005432383295	31288	Economy	3300.00
0005432383195	31288	Economy	3300.00
0005432383251	31288	Economy	3300.00
0005433450079	31288	Economy	3300.00
0005433451624	31288	Economy	3300.00
0005433450106	31288	Economy	3300.00
0005433450096	31288	Economy	3300.00
0005432383184	31288	Economy	3300.00
0005432383246	31288	Economy	3300.00
0005432383339	31288	Economy	3300.00
0005433450116	31288	Economy	3300.00
0005432383294	31288	Economy	3300.00
0005432383441	31288	Economy	3300.00
0005432383175	31288	Economy	3300.00
0005433450086	31288	Economy	3300.00
0005433450075	31288	Economy	3300.00
0005432383196	31288	Economy	3300.00
0005432383263	31288	Economy	3300.00
0005432383259	31288	Economy	3300.00
0005432383214	31288	Economy	3300.00
0005433449949	31288	Economy	3300.00
0005433450071	31288	Economy	3300.00
0005432383258	31288	Economy	3300.00
0005432383181	31288	Economy	3300.00
0005432383177	31288	Economy	3300.00
0005432383215	31288	Economy	3300.00
0005433449971	31288	Economy	3300.00
0005432383204	31288	Economy	3300.00
0005433450027	31288	Economy	3300.00
0005432383231	31288	Economy	3300.00
0005433451623	31288	Economy	3300.00
0005432383272	31288	Economy	3300.00
0005432383305	31288	Economy	3300.00
0005433131711	10798	Economy	17100.00
0005435304172	10798	Economy	15600.00
0005435304176	10798	Economy	15600.00
0005435304162	10798	Economy	15600.00
0005435304160	10798	Economy	15600.00
0005435304147	10798	Economy	15600.00
0005433131692	10798	Economy	15600.00
0005433126845	10798	Economy	15600.00
0005433126858	10798	Economy	15600.00
0005435304158	10798	Economy	15600.00
0005433126850	10798	Economy	15600.00
0005433126848	10798	Economy	15600.00
0005433131721	10798	Economy	15600.00
0005433131722	10798	Economy	15600.00
0005433131724	10798	Economy	15600.00
0005433126849	10798	Economy	15600.00
0005435304163	10798	Economy	15600.00
0005433131723	10798	Economy	15600.00
0005435304146	10798	Economy	15600.00
0005435299789	10798	Economy	15600.00
0005433126851	10798	Economy	15600.00
0005433131720	10798	Economy	15600.00
0005433126844	10798	Economy	15600.00
0005435304173	10798	Economy	15600.00
0005433129337	29704	Economy	17100.00
0005433126903	29704	Economy	17100.00
0005435302259	29704	Economy	15600.00
0005435299840	29704	Economy	15600.00
0005433126907	29704	Economy	15600.00
0005435299842	29704	Economy	15600.00
0005435299837	29704	Economy	15600.00
0005435302263	29704	Economy	15600.00
0005435302262	29704	Economy	15600.00
0005433126904	29704	Economy	15600.00
0005435299838	29704	Economy	15600.00
0005435302260	29704	Economy	15600.00
0005435299839	29704	Economy	15600.00
0005435299841	29704	Economy	15600.00
0005433126905	29704	Economy	15600.00
0005433129336	29704	Economy	15600.00
0005433129335	29704	Economy	15600.00
0005435302261	29704	Economy	15600.00
0005433126906	29704	Economy	15600.00
0005433129338	29704	Economy	15600.00
0005435302264	29704	Economy	15600.00
0005434287571	2403	Economy	17200.00
0005434287564	2403	Economy	17200.00
0005434287570	2403	Economy	17200.00
0005433110131	2403	Economy	15700.00
0005433110094	2403	Economy	15700.00
0005433110070	2403	Economy	15700.00
0005433110135	2403	Economy	15700.00
0005432264506	2403	Economy	15700.00
0005434287555	2403	Economy	15700.00
0005434287561	2403	Economy	15700.00
0005433110105	2403	Economy	15700.00
0005434287574	2403	Economy	15700.00
0005433110109	2403	Economy	15700.00
0005434287566	2403	Economy	15700.00
0005434287559	2403	Economy	15700.00
0005433110116	2403	Economy	15700.00
0005434287567	2403	Economy	15700.00
0005434287557	2403	Economy	15700.00
0005434287563	2403	Economy	15700.00
0005433110136	2403	Economy	15700.00
0005433110142	2403	Economy	15700.00
0005433110090	2403	Economy	15700.00
0005432264507	2403	Economy	15700.00
0005433110139	2403	Economy	15700.00
0005433110047	2403	Economy	15700.00
0005434287560	2403	Economy	15700.00
0005434287554	2403	Economy	15700.00
0005434287562	2403	Economy	15700.00
0005434287573	2403	Economy	15700.00
0005434287568	2403	Economy	15700.00
0005432264505	2403	Economy	15700.00
0005433110145	2403	Economy	15700.00
0005433110143	2403	Economy	15700.00
0005434287553	2403	Economy	15700.00
0005434287575	2403	Economy	15700.00
0005434287569	2403	Economy	15700.00
0005434287565	2403	Economy	15700.00
0005434287572	2403	Economy	15700.00
0005434287556	2403	Economy	15700.00
0005433110069	2403	Economy	15700.00
0005434287558	2403	Economy	15700.00
0005433110204	26860	Economy	17200.00
0005434287373	26860	Economy	17200.00
0005433110202	26860	Economy	17200.00
0005433110208	26860	Economy	15700.00
0005434287428	26860	Economy	15700.00
0005434287315	26860	Economy	15700.00
0005434287306	26860	Economy	15700.00
0005434287269	26860	Economy	15700.00
0005434287410	26860	Economy	15700.00
0005433110198	26860	Economy	15700.00
0005433110199	26860	Economy	15700.00
0005433110197	26860	Economy	15700.00
0005433110201	26860	Economy	15700.00
0005434287322	26860	Economy	15700.00
0005434287390	26860	Economy	15700.00
0005434287310	26860	Economy	15700.00
0005434287307	26860	Economy	15700.00
0005433110207	26860	Economy	15700.00
0005434287351	26860	Economy	15700.00
0005434287291	26860	Economy	15700.00
0005434287292	26860	Economy	15700.00
0005433110200	26860	Economy	15700.00
0005434287409	26860	Economy	15700.00
0005434287408	26860	Economy	15700.00
0005434287366	26860	Economy	15700.00
0005434287363	26860	Economy	15700.00
0005434287368	26860	Economy	15700.00
0005434287271	26860	Economy	15700.00
0005434287321	26860	Economy	15700.00
0005433110205	26860	Economy	15700.00
0005433110206	26860	Economy	15700.00
0005433110203	26860	Economy	15700.00
0005434287421	26860	Economy	15700.00
0005434287240	26860	Economy	15700.00
0005434287385	26860	Economy	15700.00
0005435856259	25453	Economy	22800.00
0005435856258	25453	Economy	22800.00
0005435856256	25453	Economy	22800.00
0005435856255	25453	Economy	22800.00
0005434269105	25453	Economy	22800.00
0005435856257	25453	Economy	22800.00
0005435856205	26642	Economy	25000.00
0005435856217	26642	Economy	25000.00
0005435854062	26642	Economy	22800.00
0005434272211	26642	Economy	22800.00
0005435856223	26642	Economy	22800.00
0005434273098	26642	Economy	22800.00
0005434273099	26642	Economy	22800.00
0005435856225	26642	Economy	22800.00
0005435856204	26642	Economy	22800.00
0005434273097	26642	Economy	22800.00
0005434272212	26642	Economy	22800.00
0005435856222	26642	Economy	22800.00
0005433868947	4771	Economy	19400.00
0005433868928	4771	Economy	19400.00
0005433868925	4771	Economy	19400.00
0005433868955	4771	Economy	19400.00
0005433868930	4771	Economy	17600.00
0005433868942	4771	Economy	17600.00
0005433868936	4771	Economy	17600.00
0005433868953	4771	Economy	17600.00
0005433868954	4771	Economy	17600.00
0005433868919	4771	Economy	17600.00
0005433868952	4771	Economy	17600.00
0005433868934	4771	Economy	17600.00
0005435860497	4771	Economy	17600.00
0005433868927	4771	Economy	17600.00
0005433868948	4771	Economy	17600.00
0005433868945	4771	Economy	17600.00
0005433868921	4771	Economy	17600.00
0005433868949	4771	Economy	17600.00
0005433868938	4771	Economy	17600.00
0005433868937	4771	Economy	17600.00
0005433868917	4771	Economy	17600.00
0005433868944	4771	Economy	17600.00
0005433868946	4771	Economy	17600.00
0005433868941	4771	Economy	17600.00
0005433868924	4771	Economy	17600.00
0005433868940	4771	Economy	17600.00
0005433868950	4771	Economy	17600.00
0005433868918	4771	Economy	17600.00
0005433868931	4771	Economy	17600.00
0005433868923	4771	Economy	17600.00
0005433868932	4771	Economy	17600.00
0005433868933	4771	Economy	17600.00
0005433868920	4771	Economy	17600.00
0005433868939	4771	Economy	17600.00
0005433868929	4771	Economy	17600.00
0005433868951	4771	Economy	17600.00
0005433868922	4771	Economy	17600.00
0005433868943	4771	Economy	17600.00
0005433868935	4771	Economy	17600.00
0005433868926	4771	Economy	17600.00
0005433868488	32609	Economy	19400.00
0005433868476	32609	Economy	19400.00
0005433868608	32609	Economy	19400.00
0005433868618	32609	Economy	19400.00
0005433868450	32609	Economy	17600.00
0005433868485	32609	Economy	17600.00
0005433868526	32609	Economy	17600.00
0005433868512	32609	Economy	17600.00
0005433868732	32609	Economy	17600.00
0005433868545	32609	Economy	17600.00
0005433868598	32609	Economy	17600.00
0005433868436	32609	Economy	17600.00
0005433868335	32609	Economy	17600.00
0005433868591	32609	Economy	17600.00
0005433868411	32609	Economy	17600.00
0005433868481	32609	Economy	17600.00
0005433868466	32609	Economy	17600.00
0005433868464	32609	Economy	17600.00
0005433868668	32609	Economy	17600.00
0005433868607	32609	Economy	17600.00
0005433868518	32609	Economy	17600.00
0005433868584	32609	Economy	17600.00
0005433868465	32609	Economy	17600.00
0005433868535	32609	Economy	17600.00
0005433868517	32609	Economy	17600.00
0005433868483	32609	Economy	17600.00
0005433868416	32609	Economy	17600.00
0005433868475	32609	Economy	17600.00
0005433868510	32609	Economy	17600.00
0005433868467	32609	Economy	17600.00
0005433868484	32609	Economy	17600.00
0005433868491	32609	Economy	17600.00
0005433868446	32609	Economy	17600.00
0005433868606	32609	Economy	17600.00
0005433868552	32609	Economy	17600.00
0005433868417	32609	Economy	17600.00
0005433868519	32609	Economy	17600.00
0005433868553	32609	Economy	17600.00
0005433868447	32609	Economy	17600.00
0005433868669	32609	Economy	17600.00
0005433868509	32609	Economy	17600.00
0005433868486	32609	Economy	17600.00
0005433868487	32609	Economy	17600.00
0005433868492	32609	Economy	17600.00
0005433868626	32609	Economy	17600.00
0005433868560	32609	Economy	17600.00
0005434663582	3432	Economy	24800.00
0005434663573	3432	Economy	22600.00
0005435911489	3432	Economy	24800.00
0005434460531	3432	Economy	22600.00
0005435911500	3432	Economy	22600.00
0005434461674	3432	Economy	22600.00
0005435911499	3432	Economy	22600.00
0005434663580	3432	Economy	22600.00
0005434663574	3432	Economy	22600.00
0005435911472	3432	Economy	22600.00
0005434663570	3432	Economy	22600.00
0005435911501	3432	Economy	22600.00
0005435911471	3432	Economy	22600.00
0005434461675	3432	Economy	22600.00
0005435911492	3432	Economy	22600.00
0005434663578	3432	Economy	22600.00
0005434460532	3432	Economy	22600.00
0005434663581	3432	Economy	22600.00
0005435911483	3432	Economy	22600.00
0005434663571	3432	Economy	22600.00
0005434663576	3432	Economy	22600.00
0005434663579	3432	Economy	22600.00
0005434663575	3432	Economy	22600.00
0005434663577	3432	Economy	22600.00
0005434663572	3432	Economy	22600.00
0005435911549	12467	Economy	24800.00
0005434663490	12467	Economy	24800.00
0005434663482	12467	Economy	24800.00
0005434663466	12467	Economy	22600.00
0005434663439	12467	Economy	22600.00
0005434663460	12467	Economy	22600.00
0005435911544	12467	Economy	22600.00
0005434663452	12467	Economy	22600.00
0005435911543	12467	Economy	22600.00
0005434663438	12467	Economy	22600.00
0005434663431	12467	Economy	22600.00
0005434663473	12467	Economy	22600.00
0005434663483	12467	Economy	22600.00
0005434663451	12467	Economy	22600.00
0005435911547	12467	Economy	22600.00
0005434663486	12467	Economy	22600.00
0005435911545	12467	Economy	22600.00
0005434663493	12467	Economy	22600.00
0005434663437	12467	Economy	22600.00
0005435911546	12467	Economy	22600.00
0005434663487	12467	Economy	22600.00
0005435911542	12467	Economy	22600.00
0005434663481	12467	Economy	22600.00
0005434663488	12467	Economy	22600.00
0005435911548	12467	Economy	22600.00
0005435911550	12467	Economy	22600.00
0005434663465	12467	Economy	22600.00
0005433868526	14490	Economy	18500.00
0005433868626	14490	Economy	18500.00
0005433868464	14490	Economy	18500.00
0005433868606	14490	Economy	16800.00
0005433868618	14490	Economy	16800.00
0005433868416	14490	Economy	16800.00
0005433868485	14490	Economy	16800.00
0005433868450	14490	Economy	16800.00
0005433868545	14490	Economy	16800.00
0005433868487	14490	Economy	16800.00
0005433868492	14490	Economy	16800.00
0005433868732	14490	Economy	16800.00
0005433868560	14490	Economy	16800.00
0005433868488	14490	Economy	16800.00
0005433868484	14490	Economy	16800.00
0005433868486	14490	Economy	16800.00
0005433868552	14490	Economy	16800.00
0005433868481	14490	Economy	16800.00
0005433868591	14490	Economy	16800.00
0005433868475	14490	Economy	16800.00
0005433868669	14490	Economy	16800.00
0005433868465	14490	Economy	16800.00
0005433868584	14490	Economy	16800.00
0005433868411	14490	Economy	16800.00
0005433868519	14490	Economy	16800.00
0005433868608	14490	Economy	16800.00
0005433868512	14490	Economy	16800.00
0005433868467	14490	Economy	16800.00
0005433868668	14490	Economy	16800.00
0005433868518	14490	Economy	16800.00
0005433868466	14490	Economy	16800.00
0005433868607	14490	Economy	16800.00
0005433868510	14490	Economy	16800.00
0005433868491	14490	Economy	16800.00
0005433868553	14490	Economy	16800.00
0005433868476	14490	Economy	16800.00
0005433868509	14490	Economy	16800.00
0005433868535	14490	Economy	16800.00
0005433868417	14490	Economy	16800.00
0005433868483	14490	Economy	16800.00
0005433868447	14490	Economy	16800.00
0005433868446	14490	Economy	16800.00
0005433868517	14490	Economy	16800.00
0005433868436	14490	Economy	16800.00
0005433868335	14490	Economy	16800.00
0005433868598	14490	Economy	16800.00
0005433868901	32665	Economy	18500.00
0005433868911	32665	Economy	18500.00
0005433868889	32665	Economy	16800.00
0005433868894	32665	Economy	16800.00
0005433868884	32665	Economy	16800.00
0005433868899	32665	Economy	16800.00
0005433868895	32665	Economy	16800.00
0005433868883	32665	Economy	16800.00
0005433868913	32665	Economy	16800.00
0005433868892	32665	Economy	16800.00
0005433868903	32665	Economy	16800.00
0005433868896	32665	Economy	16800.00
0005433868916	32665	Economy	16800.00
0005435860487	32665	Economy	16800.00
0005433868907	32665	Economy	16800.00
0005433868878	32665	Economy	16800.00
0005433868891	32665	Economy	16800.00
0005433868886	32665	Economy	16800.00
0005433868897	32665	Economy	16800.00
0005433868905	32665	Economy	16800.00
0005433868885	32665	Economy	16800.00
0005433868893	32665	Economy	16800.00
0005433868887	32665	Economy	16800.00
0005433868902	32665	Economy	16800.00
0005435860486	32665	Economy	16800.00
0005433868906	32665	Economy	16800.00
0005433868882	32665	Economy	16800.00
0005433868910	32665	Economy	16800.00
0005433868888	32665	Economy	16800.00
0005433868909	32665	Economy	16800.00
0005433868898	32665	Economy	16800.00
0005433868881	32665	Economy	16800.00
0005433868908	32665	Economy	16800.00
0005433868900	32665	Economy	16800.00
0005433868914	32665	Economy	16800.00
0005433868890	32665	Economy	16800.00
0005433868904	32665	Economy	16800.00
0005433868879	32665	Economy	16800.00
0005433868912	32665	Economy	16800.00
0005433868880	32665	Economy	16800.00
0005433868915	32665	Economy	16800.00
0005432799575	12145	Economy	4900.00
0005432799569	12145	Economy	4900.00
0005432799702	12145	Economy	4400.00
0005432799590	12145	Economy	4400.00
0005432799648	12145	Economy	4400.00
0005432799526	12145	Economy	4400.00
0005432799572	12145	Economy	4400.00
0005432799599	12145	Economy	4400.00
0005432799568	12145	Economy	4400.00
0005432799532	12145	Economy	4400.00
0005432799628	12145	Economy	4400.00
0005432799631	12145	Economy	4400.00
0005432799703	12145	Economy	4400.00
0005432799425	12145	Economy	4400.00
0005432799701	12145	Economy	4400.00
0005432799459	12145	Economy	4400.00
0005432799551	12145	Economy	4400.00
0005432799567	12145	Economy	4400.00
0005432799424	12145	Economy	4400.00
0005432799527	12145	Economy	4400.00
0005432799576	12145	Economy	4400.00
0005432799555	12145	Economy	4400.00
0005432799539	12145	Economy	4400.00
0005432799531	12145	Economy	4400.00
0005432799477	12145	Economy	4400.00
0005432799478	12145	Economy	4400.00
0005432799481	12145	Economy	4400.00
0005432799574	12145	Economy	4400.00
0005432799774	14795	Economy	4900.00
0005432799783	14795	Economy	4900.00
0005432799789	14795	Economy	4400.00
0005432799772	14795	Economy	4400.00
0005432799778	14795	Economy	4400.00
0005432799786	14795	Economy	4400.00
0005432799787	14795	Economy	4400.00
0005432799790	14795	Economy	4400.00
0005432799780	14795	Economy	4400.00
0005432799781	14795	Economy	4400.00
0005432799784	14795	Economy	4400.00
0005432799779	14795	Economy	4400.00
0005432799771	14795	Economy	4400.00
0005432799764	14795	Economy	4400.00
0005432799791	14795	Economy	4400.00
0005432799763	14795	Economy	4400.00
0005432799767	14795	Economy	4400.00
0005432799785	14795	Economy	4400.00
0005432799775	14795	Economy	4400.00
0005432799765	14795	Economy	4400.00
0005432799788	14795	Economy	4400.00
0005432799773	14795	Economy	4400.00
0005432799769	14795	Economy	4400.00
0005432799777	14795	Economy	4400.00
0005432799768	14795	Economy	4400.00
0005432799782	14795	Economy	4400.00
0005432799776	14795	Economy	4400.00
0005432799770	14795	Economy	4400.00
0005432799766	14795	Economy	4400.00
0005434299846	7053	Business	49100.00
0005434299847	7053	Business	49100.00
0005434408560	7053	Business	49100.00
0005434408549	7053	Business	49100.00
0005434408534	7053	Business	49100.00
0005434408562	7053	Business	49100.00
0005434299859	7053	Business	49100.00
0005435293301	7053	Business	49100.00
0005434408529	7053	Business	49100.00
0005434408553	7053	Business	49100.00
0005434408516	7053	Business	49100.00
0005434408522	7053	Business	49100.00
0005434408558	7053	Economy	16400.00
0005434408525	7053	Economy	16400.00
0005434408519	7053	Economy	16400.00
0005434408530	7053	Economy	16400.00
0005435293328	7053	Economy	16400.00
0005435293329	7053	Economy	16400.00
0005434408551	7053	Economy	16400.00
0005434408572	7053	Economy	16400.00
0005434408545	7053	Economy	16400.00
0005434408521	7053	Economy	16400.00
0005434299850	7053	Economy	16400.00
0005434299842	7053	Economy	16400.00
0005432154025	7053	Economy	16400.00
0005432154022	7053	Economy	16400.00
0005435293293	7053	Economy	16400.00
0005434408514	7053	Economy	16400.00
0005434408526	7053	Economy	16400.00
0005434408515	7053	Economy	16400.00
0005435311096	7053	Economy	16400.00
0005434408564	7053	Economy	16400.00
0005434408552	7053	Economy	16400.00
0005434408543	7053	Economy	16400.00
0005435293292	7053	Economy	16400.00
0005435293306	7053	Economy	16400.00
0005434408565	7053	Economy	16400.00
0005434408520	7053	Economy	16400.00
0005434408536	7053	Economy	16400.00
0005435311077	7053	Economy	16400.00
0005434408533	7053	Economy	16400.00
0005434299854	7053	Economy	16400.00
0005434299851	7053	Economy	16400.00
0005434408566	7053	Economy	16400.00
0005434408539	7053	Economy	16400.00
0005434408527	7053	Economy	16400.00
0005435293331	7053	Economy	16400.00
0005435293274	7053	Economy	16400.00
0005432108282	7053	Economy	16400.00
0005434408544	7053	Economy	18000.00
0005432154021	7053	Economy	18000.00
0005435311069	7053	Economy	18000.00
0005434299860	7053	Economy	18000.00
0005434408531	7053	Economy	18000.00
0005435293300	7053	Economy	18000.00
0005434408532	7053	Economy	16400.00
0005435311084	7053	Economy	16400.00
0005434408556	7053	Economy	16400.00
0005434299857	7053	Economy	16400.00
0005434408554	7053	Economy	16400.00
0005434408573	7053	Economy	16400.00
0005434408559	7053	Economy	16400.00
0005434408513	7053	Economy	16400.00
0005432108281	7053	Economy	16400.00
0005434408523	7053	Economy	16400.00
0005434299838	7053	Economy	16400.00
0005434408548	7053	Economy	16400.00
0005434408547	7053	Economy	16400.00
0005434408563	7053	Economy	16400.00
0005435293340	7053	Economy	16400.00
0005432108283	7053	Economy	16400.00
0005434299843	7053	Economy	16400.00
0005432154026	7053	Economy	16400.00
0005434408528	7053	Economy	16400.00
0005435311068	7053	Economy	16400.00
0005434408555	7053	Economy	16400.00
0005434299849	7053	Economy	16400.00
0005434408557	7053	Economy	16400.00
0005434408568	7053	Economy	16400.00
0005434299855	7053	Economy	16400.00
0005434408567	7053	Economy	16400.00
0005435311082	7053	Economy	16400.00
0005434299839	7053	Economy	16400.00
0005434408561	7053	Economy	16400.00
0005432154023	7053	Economy	16400.00
0005435311043	7053	Economy	16400.00
0005434408541	7053	Economy	16400.00
0005432154028	7053	Economy	16400.00
0005434408512	7053	Economy	16400.00
0005434408546	7053	Economy	16400.00
0005434408517	7053	Economy	16400.00
0005435293275	7053	Economy	16400.00
0005434299845	7053	Economy	16400.00
0005434299840	7053	Economy	16400.00
0005432154024	7053	Economy	16400.00
0005435293330	7053	Economy	16400.00
0005434408518	7053	Economy	16400.00
0005435311044	7053	Economy	16400.00
0005434408538	7053	Economy	16400.00
0005434408576	7053	Economy	16400.00
0005434299848	7053	Economy	16400.00
0005434408542	7053	Economy	16400.00
0005434408575	7053	Economy	16400.00
0005434408570	7053	Economy	16400.00
0005434299844	7053	Economy	16400.00
0005434408540	7053	Economy	16400.00
0005435293305	7053	Economy	16400.00
0005434408569	7053	Economy	16400.00
0005434299853	7053	Economy	16400.00
0005434408574	7053	Economy	16400.00
0005434299841	7053	Economy	16400.00
0005434408571	7053	Economy	16400.00
0005434299856	7053	Economy	16400.00
0005434408524	7053	Economy	16400.00
0005435311058	7053	Economy	16400.00
0005434408550	7053	Economy	16400.00
0005434299852	7053	Economy	16400.00
0005434408535	7053	Economy	16400.00
0005434299858	7053	Economy	16400.00
0005435311081	7053	Economy	16400.00
0005434408537	7053	Economy	16400.00
0005432154027	7053	Economy	16400.00
0005434407982	26892	Business	49100.00
0005434408300	26892	Business	49100.00
0005434407962	26892	Business	49100.00
0005434408163	26892	Business	49100.00
0005434407934	26892	Business	49100.00
0005434407954	26892	Business	49100.00
0005434408016	26892	Business	49100.00
0005434408080	26892	Business	49100.00
0005434407980	26892	Business	49100.00
0005434408098	26892	Business	49100.00
0005434408162	26892	Business	49100.00
0005434407960	26892	Economy	16400.00
0005434407972	26892	Economy	16400.00
0005435293408	26892	Economy	16400.00
0005435293413	26892	Economy	16400.00
0005434407596	26892	Economy	16400.00
0005434408176	26892	Economy	16400.00
0005434299699	26892	Economy	16400.00
0005434408081	26892	Economy	16400.00
0005434299560	26892	Economy	16400.00
0005434299753	26892	Economy	16400.00
0005434407893	26892	Economy	16400.00
0005434408164	26892	Economy	16400.00
0005434407899	26892	Economy	16400.00
0005434408017	26892	Economy	16400.00
0005435293405	26892	Economy	16400.00
0005435311215	26892	Economy	16400.00
0005434299693	26892	Economy	16400.00
0005434407848	26892	Economy	16400.00
0005434407908	26892	Economy	16400.00
0005434299683	26892	Economy	16400.00
0005435311218	26892	Economy	16400.00
0005434407984	26892	Economy	16400.00
0005434407802	26892	Economy	16400.00
0005434408026	26892	Economy	16400.00
0005434407894	26892	Economy	16400.00
0005435293412	26892	Economy	16400.00
0005435293404	26892	Economy	16400.00
0005435311217	26892	Economy	16400.00
0005435311204	26892	Economy	16400.00
0005434407955	26892	Economy	16400.00
0005434407821	26892	Economy	16400.00
0005435293406	26892	Economy	16400.00
0005434299698	26892	Economy	16400.00
0005434407860	26892	Economy	16400.00
0005434408096	26892	Economy	16400.00
0005432058426	26892	Economy	16400.00
0005434299591	26892	Economy	16400.00
0005434299762	26892	Economy	16400.00
0005434299682	26892	Economy	18000.00
0005434408077	26892	Economy	18000.00
0005434407890	26892	Economy	18000.00
0005435293407	26892	Economy	16400.00
0005435311209	26892	Economy	18000.00
0005434299681	26892	Economy	16400.00
0005432058427	26892	Economy	16400.00
0005434407979	26892	Economy	16400.00
0005434408301	26892	Economy	16400.00
0005434407778	26892	Economy	16400.00
0005435311219	26892	Economy	16400.00
0005434407900	26892	Economy	16400.00
0005434299744	26892	Economy	16400.00
0005434299735	26892	Economy	16400.00
0005434408097	26892	Economy	16400.00
0005434407992	26892	Economy	16400.00
0005434408078	26892	Economy	16400.00
0005434407920	26892	Economy	16400.00
0005434407761	26892	Economy	16400.00
0005434407777	26892	Economy	16400.00
0005434407906	26892	Economy	16400.00
0005435311213	26892	Economy	16400.00
0005434299561	26892	Economy	16400.00
0005434408031	26892	Economy	16400.00
0005435311205	26892	Economy	16400.00
0005434407959	26892	Economy	16400.00
0005434407993	26892	Economy	16400.00
0005435293402	26892	Economy	16400.00
0005434299692	26892	Economy	16400.00
0005434408048	26892	Economy	16400.00
0005434407935	26892	Economy	16400.00
0005435311208	26892	Economy	16400.00
0005432058429	26892	Economy	16400.00
0005435293411	26892	Economy	16400.00
0005435311211	26892	Economy	16400.00
0005435293403	26892	Economy	16400.00
0005434407869	26892	Economy	16400.00
0005434407961	26892	Economy	16400.00
0005434408008	26892	Economy	16400.00
0005435311216	26892	Economy	16400.00
0005434407967	26892	Economy	16400.00
0005434299712	26892	Economy	16400.00
0005434407907	26892	Economy	16400.00
0005434407968	26892	Economy	16400.00
0005434408120	26892	Economy	16400.00
0005434408007	26892	Economy	16400.00
0005432058428	26892	Economy	16400.00
0005435311214	26892	Economy	16400.00
0005434407958	26892	Economy	16400.00
0005434408009	26892	Economy	16400.00
0005435311210	26892	Economy	16400.00
0005434407953	26892	Economy	16400.00
0005434299680	26892	Economy	16400.00
0005435311207	26892	Economy	16400.00
0005435293409	26892	Economy	16400.00
0005434407684	26892	Economy	16400.00
0005435311212	26892	Economy	16400.00
0005435293401	26892	Economy	16400.00
0005435293410	26892	Economy	16400.00
0005434407981	26892	Economy	16400.00
0005434408177	26892	Economy	16400.00
0005434407627	26892	Economy	16400.00
0005434407889	26892	Economy	16400.00
0005434407905	26892	Economy	16400.00
0005434407747	26892	Economy	16400.00
0005435311203	26892	Economy	16400.00
0005435311206	26892	Economy	16400.00
0005434407597	26892	Economy	16400.00
0005434407971	26892	Economy	16400.00
0005432604839	6466	Economy	16500.00
0005432604832	6466	Economy	16500.00
0005432604842	6466	Economy	16500.00
0005432604836	6466	Economy	16500.00
0005432604820	6466	Economy	15000.00
0005432604859	6466	Economy	15000.00
0005432604849	6466	Economy	15000.00
0005432604853	6466	Economy	15000.00
0005432604822	6466	Economy	15000.00
0005434512167	6466	Economy	15000.00
0005432604821	6466	Economy	15000.00
0005432604851	6466	Economy	15000.00
0005432604835	6466	Economy	15000.00
0005432604856	6466	Economy	15000.00
0005432604833	6466	Economy	15000.00
0005432604830	6466	Economy	15000.00
0005432604818	6466	Economy	15000.00
0005432604847	6466	Economy	15000.00
0005432604843	6466	Economy	15000.00
0005432604855	6466	Economy	15000.00
0005434512168	6466	Economy	15000.00
0005432604824	6466	Economy	15000.00
0005432604852	6466	Economy	15000.00
0005432604848	6466	Economy	15000.00
0005432604829	6466	Economy	15000.00
0005434512164	6466	Economy	15000.00
0005432604838	6466	Economy	15000.00
0005432604827	6466	Economy	15000.00
0005432604819	6466	Economy	15000.00
0005434512165	6466	Economy	15000.00
0005432604823	6466	Economy	15000.00
0005432604857	6466	Economy	15000.00
0005432604825	6466	Economy	15000.00
0005434512166	6466	Economy	15000.00
0005432604826	6466	Economy	15000.00
0005432604844	6466	Economy	15000.00
0005432604828	6466	Economy	15000.00
0005432604834	6466	Economy	15000.00
0005432604854	6466	Economy	15000.00
0005434512163	6466	Economy	15000.00
0005432604846	6466	Economy	15000.00
0005434512169	6466	Economy	15000.00
0005432604840	6466	Economy	15000.00
0005432604841	6466	Economy	15000.00
0005432604837	6466	Economy	15000.00
0005432604858	6466	Economy	15000.00
0005432604831	6466	Economy	15000.00
0005435218119	6466	Economy	15000.00
0005432604850	6466	Economy	15000.00
0005432604845	6466	Economy	15000.00
0005432604307	21385	Economy	16500.00
0005432604449	21385	Economy	16500.00
0005432604633	21385	Economy	16500.00
0005432604502	21385	Economy	16500.00
0005432604246	21385	Economy	15000.00
0005432604435	21385	Economy	15000.00
0005432604643	21385	Economy	15000.00
0005432604558	21385	Economy	15000.00
0005432604434	21385	Economy	15000.00
0005432604379	21385	Economy	15000.00
0005432604485	21385	Economy	15000.00
0005432604395	21385	Economy	15000.00
0005434512115	21385	Economy	15000.00
0005432604399	21385	Economy	15000.00
0005432604390	21385	Economy	15000.00
0005432604598	21385	Economy	15000.00
0005432604370	21385	Economy	15000.00
0005432604426	21385	Economy	15000.00
0005432604431	21385	Economy	15000.00
0005432604340	21385	Economy	15000.00
0005432604433	21385	Economy	15000.00
0005432604437	21385	Economy	15000.00
0005432604469	21385	Economy	15000.00
0005432604301	21385	Economy	15000.00
0005432604380	21385	Economy	15000.00
0005432604245	21385	Economy	15000.00
0005432604634	21385	Economy	15000.00
0005432604588	21385	Economy	15000.00
0005432604468	21385	Economy	15000.00
0005432604308	21385	Economy	15000.00
0005432604589	21385	Economy	15000.00
0005432604256	21385	Economy	15000.00
0005432604489	21385	Economy	15000.00
0005432604419	21385	Economy	15000.00
0005432604430	21385	Economy	15000.00
0005432604432	21385	Economy	15000.00
0005432604597	21385	Economy	15000.00
0005432604325	21385	Economy	15000.00
0005432604398	21385	Economy	15000.00
0005432604456	21385	Economy	15000.00
0005432604326	21385	Economy	15000.00
0005432604423	21385	Economy	15000.00
0005434512116	21385	Economy	15000.00
0005432604482	21385	Economy	15000.00
0005432604306	21385	Economy	15000.00
0005432604369	21385	Economy	15000.00
0005432604381	21385	Economy	15000.00
0005432604420	21385	Economy	15000.00
0005432604463	21385	Economy	15000.00
0005432604457	21385	Economy	15000.00
0005434907351	14993	Business	18900.00
0005434907378	14993	Business	18900.00
0005433251875	14993	Business	18900.00
0005433251860	14993	Business	18900.00
0005434907363	14993	Business	18900.00
0005434907482	14993	Business	18900.00
0005433251865	14993	Business	18900.00
0005434907226	14993	Business	18900.00
0005433251857	14993	Business	18900.00
0005434907576	14993	Economy	6300.00
0005433251853	14993	Economy	6300.00
0005434907372	14993	Economy	6300.00
0005434907697	14993	Economy	6300.00
0005433251847	14993	Economy	6300.00
0005433251852	14993	Economy	6300.00
0005434907277	14993	Economy	6300.00
0005434907624	14993	Economy	6300.00
0005433251854	14993	Economy	6900.00
0005434907575	14993	Economy	6900.00
0005434907389	14993	Economy	6900.00
0005434907407	14993	Economy	6900.00
0005433251869	14993	Economy	6300.00
0005434907396	14993	Economy	6300.00
0005433251863	14993	Economy	6300.00
0005434907369	14993	Economy	6300.00
0005433251867	14993	Economy	6300.00
0005434907336	14993	Economy	6300.00
0005434907357	14993	Economy	6300.00
0005433251874	14993	Economy	6300.00
0005434907362	14993	Economy	6300.00
0005434907181	14993	Economy	6300.00
0005434907481	14993	Economy	6300.00
0005433251861	14993	Economy	6300.00
0005434907525	14993	Economy	6300.00
0005434907601	14993	Economy	6300.00
0005434907703	14993	Economy	6300.00
0005433251846	14993	Economy	6300.00
0005433251850	14993	Economy	6300.00
0005433251862	14993	Economy	6300.00
0005433251871	14993	Economy	6300.00
0005433251870	14993	Economy	6300.00
0005433251851	14993	Economy	6300.00
0005433251848	14993	Economy	6300.00
0005434907411	14993	Economy	6300.00
0005433251855	14993	Economy	6300.00
0005434907361	14993	Economy	6300.00
0005434907388	14993	Economy	6300.00
0005434907483	14993	Economy	6300.00
0005434907647	14993	Economy	6300.00
0005433251868	14993	Economy	6300.00
0005433251873	14993	Economy	6300.00
0005433251859	14993	Economy	6300.00
0005434907529	14993	Economy	6300.00
0005433251864	14993	Economy	6300.00
0005433251845	14993	Economy	6300.00
0005434907488	14993	Economy	6300.00
0005434907737	14993	Economy	6300.00
0005433251844	14993	Economy	6300.00
0005433251858	14993	Economy	6300.00
0005434907470	14993	Economy	6300.00
0005434907709	14993	Economy	6300.00
0005433251856	14993	Economy	6300.00
0005434907261	14993	Economy	6300.00
0005434907524	14993	Economy	6300.00
0005434907225	14993	Economy	6300.00
0005434907526	14993	Economy	6300.00
0005434907440	14993	Economy	6300.00
0005434907359	14993	Economy	6300.00
0005434907508	14993	Economy	6300.00
0005434907198	14993	Economy	6300.00
0005434907625	14993	Economy	6300.00
0005434907600	14993	Economy	6300.00
0005434907418	14993	Economy	6300.00
0005433251866	14993	Economy	6300.00
0005434907180	14993	Economy	6300.00
0005434907608	14993	Economy	6300.00
0005433251872	14993	Economy	6300.00
0005434907335	14993	Economy	6300.00
0005433251849	14993	Economy	6300.00
0005434907595	14993	Economy	6300.00
0005434907872	25833	Business	18900.00
0005434907880	25833	Business	18900.00
0005434907884	25833	Business	18900.00
0005433251608	25833	Business	18900.00
0005434907891	25833	Business	18900.00
0005433251719	25833	Business	18900.00
0005434907876	25833	Business	18900.00
0005433251523	25833	Business	18900.00
0005434907871	25833	Business	18900.00
0005434907877	25833	Business	18900.00
0005433251560	25833	Business	18900.00
0005434907868	25833	Economy	6300.00
0005433251402	25833	Economy	6300.00
0005433251528	25833	Economy	6300.00
0005433251697	25833	Economy	6300.00
0005434907882	25833	Economy	6300.00
0005434907878	25833	Economy	6300.00
0005433251596	25833	Economy	6300.00
0005434907874	25833	Economy	6300.00
0005433251475	25833	Economy	6900.00
0005434907893	25833	Economy	6900.00
0005434907879	25833	Economy	6900.00
0005433251539	25833	Economy	6900.00
0005434907875	25833	Economy	6900.00
0005433251720	25833	Economy	6300.00
0005434907858	25833	Economy	6300.00
0005434907897	25833	Economy	6300.00
0005433251618	25833	Economy	6300.00
0005433251586	25833	Economy	6300.00
0005434907867	25833	Economy	6300.00
0005434907898	25833	Economy	6300.00
0005434907883	25833	Economy	6300.00
0005433251588	25833	Economy	6300.00
0005433251554	25833	Economy	6300.00
0005433251663	25833	Economy	6300.00
0005434907901	25833	Economy	6300.00
0005434907865	25833	Economy	6300.00
0005433251555	25833	Economy	6300.00
0005433251566	25833	Economy	6300.00
0005433251473	25833	Economy	6300.00
0005434907903	25833	Economy	6300.00
0005434907862	25833	Economy	6300.00
0005434907873	25833	Economy	6300.00
0005434907870	25833	Economy	6300.00
0005433251629	25833	Economy	6300.00
0005434907895	25833	Economy	6300.00
0005433251791	25833	Economy	6300.00
0005433251613	25833	Economy	6300.00
0005434907890	25833	Economy	6300.00
0005434907863	25833	Economy	6300.00
0005434907887	25833	Economy	6300.00
0005433251635	25833	Economy	6300.00
0005434907860	25833	Economy	6300.00
0005433251401	25833	Economy	6300.00
0005433251684	25833	Economy	6300.00
0005433251636	25833	Economy	6300.00
0005433251628	25833	Economy	6300.00
0005434907894	25833	Economy	6300.00
0005433251648	25833	Economy	6300.00
0005433251474	25833	Economy	6300.00
0005434907869	25833	Economy	6300.00
0005434907902	25833	Economy	6300.00
0005434907892	25833	Economy	6300.00
0005434907896	25833	Economy	6300.00
0005434907900	25833	Economy	6300.00
0005433251647	25833	Economy	6300.00
0005434907881	25833	Economy	6300.00
0005434907885	25833	Economy	6300.00
0005434907866	25833	Economy	6300.00
0005433251607	25833	Economy	6300.00
0005433251604	25833	Economy	6300.00
0005433251646	25833	Economy	6300.00
0005433251529	25833	Economy	6300.00
0005434907861	25833	Economy	6300.00
0005434907888	25833	Economy	6300.00
0005433251617	25833	Economy	6300.00
0005433251790	25833	Economy	6300.00
0005433251587	25833	Economy	6300.00
0005434907864	25833	Economy	6300.00
0005434907899	25833	Economy	6300.00
0005434907886	25833	Economy	6300.00
0005433251545	25833	Economy	6300.00
0005434907889	25833	Economy	6300.00
0005433251507	25833	Economy	6300.00
0005434907859	25833	Economy	6300.00
0005433810535	14199	Business	52300.00
0005433009202	14199	Business	52300.00
0005433009168	14199	Business	52300.00
0005433009170	14199	Business	52300.00
0005433810542	14199	Business	52300.00
0005433009208	14199	Business	52300.00
0005433009210	14199	Business	52300.00
0005433009206	14199	Economy	17400.00
0005433009191	14199	Economy	17400.00
0005433009209	14199	Economy	17400.00
0005433810530	14199	Economy	17400.00
0005433009201	14199	Economy	17400.00
0005433009207	14199	Economy	17400.00
0005433009212	14199	Economy	17400.00
0005433009181	14199	Economy	19200.00
0005433009174	14199	Economy	19200.00
0005433009188	14199	Economy	17400.00
0005433009200	14199	Economy	17400.00
0005433009179	14199	Economy	17400.00
0005433009184	14199	Economy	17400.00
0005433009195	14199	Economy	17400.00
0005433009173	14199	Economy	17400.00
0005433009194	14199	Economy	17400.00
0005433009183	14199	Economy	17400.00
0005433009203	14199	Economy	17400.00
0005433810536	14199	Economy	17400.00
0005433009187	14199	Economy	17400.00
0005433009197	14199	Economy	17400.00
0005433009186	14199	Economy	17400.00
0005433009169	14199	Economy	17400.00
0005433009178	14199	Economy	17400.00
0005433009213	14199	Economy	17400.00
0005433009205	14199	Economy	17400.00
0005433009175	14199	Economy	17400.00
0005433009172	14199	Economy	17400.00
0005433009182	14199	Economy	17400.00
0005433009190	14199	Economy	17400.00
0005433009211	14199	Economy	17400.00
0005433009176	14199	Economy	17400.00
0005433009171	14199	Economy	17400.00
0005433009196	14199	Economy	17400.00
0005433009198	14199	Economy	17400.00
0005433009214	14199	Economy	17400.00
0005433009185	14199	Economy	17400.00
0005433009192	14199	Economy	17400.00
0005433810554	14199	Economy	17400.00
0005433009180	14199	Economy	17400.00
0005433009189	14199	Economy	17400.00
0005433009204	14199	Economy	17400.00
0005433009199	14199	Economy	17400.00
0005433009177	14199	Economy	17400.00
0005433009193	14199	Economy	17400.00
0005433008714	22855	Business	52300.00
0005433008760	22855	Business	52300.00
0005433810594	22855	Business	52300.00
0005433008695	22855	Business	52300.00
0005433008643	22855	Business	52300.00
0005433810595	22855	Economy	17400.00
0005433008639	22855	Economy	17400.00
0005433810590	22855	Economy	17400.00
0005433008793	22855	Economy	17400.00
0005433008766	22855	Economy	19200.00
0005433008723	22855	Economy	19200.00
0005433008827	22855	Economy	19200.00
0005433008699	22855	Economy	17400.00
0005433008759	22855	Economy	17400.00
0005433008651	22855	Economy	17400.00
0005433810588	22855	Economy	17400.00
0005433008875	22855	Economy	17400.00
0005433008583	22855	Economy	17400.00
0005433008605	22855	Economy	17400.00
0005433008828	22855	Economy	17400.00
0005433008613	22855	Economy	17400.00
0005433008698	22855	Economy	17400.00
0005433008761	22855	Economy	17400.00
0005433008729	22855	Economy	17400.00
0005433008836	22855	Economy	17400.00
0005433810597	22855	Economy	17400.00
0005433810596	22855	Economy	17400.00
0005433008642	22855	Economy	17400.00
0005433008844	22855	Economy	17400.00
0005433008724	22855	Economy	17400.00
0005433008787	22855	Economy	17400.00
0005433008899	22855	Economy	17400.00
0005433008792	22855	Economy	17400.00
0005433810589	22855	Economy	17400.00
0005433810593	22855	Economy	17400.00
0005433008762	22855	Economy	17400.00
0005433008886	22855	Economy	17400.00
0005433810586	22855	Economy	17400.00
0005433810591	22855	Economy	17400.00
0005433008887	22855	Economy	17400.00
0005433008845	22855	Economy	17400.00
0005433008612	22855	Economy	17400.00
0005433008515	22855	Economy	17400.00
0005433810587	22855	Economy	17400.00
0005433810592	22855	Economy	17400.00
0005433008814	22855	Economy	17400.00
0005433009023	22855	Economy	17400.00
0005435718981	15524	Business	85200.00
0005435718995	15524	Business	85200.00
0005435718987	15524	Business	85200.00
0005435719002	15524	Business	85200.00
0005435718983	15524	Economy	31200.00
0005435718994	15524	Economy	28400.00
0005435718986	15524	Economy	28400.00
0005435718985	15524	Economy	28400.00
0005435718991	15524	Economy	28400.00
0005435718989	15524	Economy	28400.00
0005435718982	15524	Economy	28400.00
0005435718999	15524	Economy	28400.00
0005435718984	15524	Economy	28400.00
0005435718997	15524	Economy	28400.00
0005435718980	15524	Economy	28400.00
0005435718993	15524	Economy	28400.00
0005435718992	15524	Economy	28400.00
0005435718990	15524	Economy	28400.00
0005435719000	15524	Economy	28400.00
0005435718988	15524	Economy	28400.00
0005435718996	15524	Economy	28400.00
0005435719001	15524	Economy	28400.00
0005435718998	15524	Economy	28400.00
0005434925756	14941	Business	22900.00
0005434925802	14941	Business	22900.00
0005434925888	14941	Business	22900.00
0005434925730	14941	Economy	7600.00
0005434925733	14941	Economy	7600.00
0005434925796	14941	Economy	7600.00
0005434925909	14941	Economy	8400.00
0005434925830	14941	Economy	7600.00
0005434925915	14941	Economy	7600.00
0005434925831	14941	Economy	7600.00
0005434925962	14941	Economy	7600.00
0005434925838	14941	Economy	7600.00
0005434925757	14941	Economy	7600.00
0005434925865	14941	Economy	7600.00
0005434925770	14941	Economy	7600.00
0005434925827	14941	Economy	7600.00
0005434925803	14941	Economy	7600.00
0005434925885	14941	Economy	7600.00
0005434925731	14941	Economy	7600.00
0005434925771	14941	Economy	7600.00
0005434925908	14941	Economy	7600.00
0005434925835	14941	Economy	7600.00
0005434925988	14941	Economy	7600.00
0005434925886	14941	Economy	7600.00
0005434925910	14941	Economy	7600.00
0005434925834	14941	Economy	7600.00
0005434925978	14941	Economy	7600.00
0005434925931	14941	Economy	7600.00
0005434925930	14941	Economy	7600.00
0005434925850	14941	Economy	7600.00
0005434925895	14941	Economy	7600.00
0005434925747	14941	Economy	7600.00
0005434925977	14941	Economy	7600.00
0005434925833	14941	Economy	7600.00
0005434925854	14941	Economy	7600.00
0005434926168	20496	Business	22900.00
0005434926175	20496	Economy	7600.00
0005434926169	20496	Economy	7600.00
0005434926166	20496	Economy	7600.00
0005434926173	20496	Economy	8400.00
0005434926177	20496	Economy	7600.00
0005434926172	20496	Economy	7600.00
0005434926182	20496	Economy	7600.00
0005434926170	20496	Economy	7600.00
0005434926183	20496	Economy	7600.00
0005434926179	20496	Economy	7600.00
0005434926180	20496	Economy	7600.00
0005434926171	20496	Economy	7600.00
0005434926187	20496	Economy	7600.00
0005434926181	20496	Economy	7600.00
0005434926167	20496	Economy	7600.00
0005434926185	20496	Economy	7600.00
0005434926178	20496	Economy	7600.00
0005434926174	20496	Economy	7600.00
0005434926186	20496	Economy	7600.00
0005434926176	20496	Economy	7600.00
0005434926184	20496	Economy	7600.00
0005435999325	15848	Economy	8900.00
0005435999200	15848	Economy	8900.00
0005435999330	15848	Economy	8900.00
0005435488113	15848	Economy	8900.00
0005435999317	15848	Economy	8100.00
0005435488112	15848	Economy	8100.00
0005435488096	15848	Economy	8100.00
0005435488105	15848	Economy	8100.00
0005435999307	15848	Economy	8100.00
0005435488109	15848	Economy	8100.00
0005435488118	15848	Economy	8100.00
0005435488111	15848	Economy	8100.00
0005435999276	15848	Economy	8100.00
0005435488107	15848	Economy	8100.00
0005435488116	15848	Economy	8100.00
0005435488101	15848	Economy	8100.00
0005435488110	15848	Economy	8100.00
0005435999331	15848	Economy	8100.00
0005435488104	15848	Economy	8100.00
0005435488100	15848	Economy	8100.00
0005435999284	15848	Economy	8100.00
0005435488102	15848	Economy	8100.00
0005435999256	15848	Economy	8100.00
0005435488106	15848	Economy	8100.00
0005435999271	15848	Economy	8100.00
0005435999272	15848	Economy	8100.00
0005435488117	15848	Economy	8100.00
0005435999279	15848	Economy	8100.00
0005435488099	15848	Economy	8100.00
0005435999277	15848	Economy	8100.00
0005435488108	15848	Economy	8100.00
0005435488097	15848	Economy	8100.00
0005435488114	15848	Economy	8100.00
0005435999308	15848	Economy	8100.00
0005435999201	15848	Economy	8100.00
0005435488098	15848	Economy	8100.00
0005435999303	15848	Economy	8100.00
0005435488103	15848	Economy	8100.00
0005435999278	15848	Economy	8100.00
0005435488115	15848	Economy	8100.00
0005435999448	19692	Economy	8900.00
0005435999453	19692	Economy	8900.00
0005435999452	19692	Economy	8100.00
0005435487935	19692	Economy	8100.00
0005435487965	19692	Economy	8100.00
0005435487815	19692	Economy	8100.00
0005435487925	19692	Economy	8100.00
0005435999445	19692	Economy	8100.00
0005435487855	19692	Economy	8100.00
0005435999447	19692	Economy	8100.00
0005435999439	19692	Economy	8100.00
0005435487973	19692	Economy	8100.00
0005435487879	19692	Economy	8100.00
0005435487878	19692	Economy	8100.00
0005435487942	19692	Economy	8100.00
0005435999446	19692	Economy	8100.00
0005435487964	19692	Economy	8100.00
0005435999441	19692	Economy	8100.00
0005435999438	19692	Economy	8100.00
0005435999437	19692	Economy	8100.00
0005435999451	19692	Economy	8100.00
0005435487989	19692	Economy	8100.00
0005435487918	19692	Economy	8100.00
0005435999436	19692	Economy	8100.00
0005435487941	19692	Economy	8100.00
0005435999449	19692	Economy	8100.00
0005435999444	19692	Economy	8100.00
0005435487899	19692	Economy	8100.00
0005435487891	19692	Economy	8100.00
0005435487856	19692	Economy	8100.00
0005435487966	19692	Economy	8100.00
0005435999443	19692	Economy	8100.00
0005435487900	19692	Economy	8100.00
0005435999456	19692	Economy	8100.00
0005435999440	19692	Economy	8100.00
0005435487903	19692	Economy	8100.00
0005435999454	19692	Economy	8100.00
0005435487974	19692	Economy	8100.00
0005435999442	19692	Economy	8100.00
0005435999450	19692	Economy	8100.00
0005435999455	19692	Economy	8100.00
0005435472825	6023	Business	199300.00
0005435472774	6023	Business	199300.00
0005435839801	6023	Business	199300.00
0005435839819	6023	Business	199300.00
0005435472882	6023	Business	199300.00
0005435839797	6023	Business	199300.00
0005432658618	6023	Business	199300.00
0005435839812	6023	Business	199300.00
0005435472891	6023	Business	199300.00
0005435472866	6023	Business	199300.00
0005435472909	6023	Business	199300.00
0005435472856	6023	Business	199300.00
0005435839800	6023	Economy	66400.00
0005435839796	6023	Economy	66400.00
0005435472865	6023	Economy	66400.00
0005435839811	6023	Economy	66400.00
0005435839814	6023	Economy	66400.00
0005435839810	6023	Economy	73100.00
0005435839806	6023	Economy	66400.00
0005435839794	6023	Economy	66400.00
0005435839818	6023	Economy	66400.00
0005435839808	6023	Economy	66400.00
0005435472870	6023	Economy	66400.00
0005435839817	6023	Economy	66400.00
0005435472775	6023	Economy	66400.00
0005435839799	6023	Economy	66400.00
0005435839805	6023	Economy	66400.00
0005435839804	6023	Economy	66400.00
0005435839792	6023	Economy	66400.00
0005435839813	6023	Economy	66400.00
0005432660845	6023	Economy	66400.00
0005432658619	6023	Economy	66400.00
0005432659733	6023	Economy	66400.00
0005435839802	6023	Economy	66400.00
0005435839809	6023	Economy	66400.00
0005435839820	6023	Economy	66400.00
0005435839798	6023	Economy	66400.00
0005435472933	6023	Economy	66400.00
0005435839807	6023	Economy	66400.00
0005432659734	6023	Economy	66400.00
0005435839815	6023	Economy	66400.00
0005432142291	6023	Economy	66400.00
0005435839816	6023	Economy	66400.00
0005432537054	6023	Economy	66400.00
0005435472837	6023	Economy	66400.00
0005435472910	6023	Economy	66400.00
0005435472857	6023	Economy	66400.00
0005435839803	6023	Economy	66400.00
0005432660844	6023	Economy	66400.00
0005432142292	6023	Economy	66400.00
0005435472895	6023	Economy	66400.00
0005435839793	6023	Economy	66400.00
0005435472773	6023	Economy	66400.00
0005435472836	6023	Economy	66400.00
0005435472936	6023	Economy	66400.00
0005435839795	6023	Economy	66400.00
0005435472867	6023	Economy	66400.00
0005435472846	6023	Economy	66400.00
0005435473002	18056	Business	199300.00
0005435839596	18056	Business	199300.00
0005435473014	18056	Business	199300.00
0005435473011	18056	Business	199300.00
0005432537085	18056	Business	199300.00
0005435839532	18056	Economy	66400.00
0005435839668	18056	Economy	66400.00
0005435473008	18056	Economy	66400.00
0005435473005	18056	Economy	66400.00
0005435473003	18056	Economy	66400.00
0005435839597	18056	Economy	66400.00
0005432667458	18056	Economy	73100.00
0005432660819	18056	Economy	73100.00
0005435839543	18056	Economy	66400.00
0005435839525	18056	Economy	66400.00
0005435473015	18056	Economy	66400.00
0005435473010	18056	Economy	66400.00
0005435839680	18056	Economy	66400.00
0005432537086	18056	Economy	66400.00
0005435473006	18056	Economy	66400.00
0005435839582	18056	Economy	66400.00
0005435839544	18056	Economy	66400.00
0005435839641	18056	Economy	66400.00
0005435839542	18056	Economy	66400.00
0005435839615	18056	Economy	66400.00
0005435839649	18056	Economy	66400.00
0005435473016	18056	Economy	66400.00
0005435839491	18056	Economy	66400.00
0005435473017	18056	Economy	66400.00
0005435473009	18056	Economy	66400.00
0005435839518	18056	Economy	66400.00
0005435839526	18056	Economy	66400.00
0005435839524	18056	Economy	66400.00
0005435839625	18056	Economy	66400.00
0005435839531	18056	Economy	66400.00
0005435473013	18056	Economy	66400.00
0005435473004	18056	Economy	66400.00
0005435839624	18056	Economy	66400.00
0005435839523	18056	Economy	66400.00
0005435473007	18056	Economy	66400.00
0005435473012	18056	Economy	66400.00
0005435839533	18056	Economy	66400.00
0005435839613	18056	Economy	66400.00
0005433285400	23021	Business	15700.00
0005433285275	23021	Business	15700.00
0005433285588	23021	Business	15700.00
0005433285383	23021	Business	15700.00
0005433285481	23021	Business	15700.00
0005433285421	23021	Business	15700.00
0005433285482	23021	Business	15700.00
0005433285606	23021	Business	15700.00
0005433285403	23021	Economy	5200.00
0005433285385	23021	Economy	5200.00
0005433285238	23021	Economy	5200.00
0005433285446	23021	Economy	5200.00
0005433285470	23021	Economy	5200.00
0005433285436	23021	Economy	5200.00
0005433285404	23021	Economy	5200.00
0005433285508	23021	Economy	5200.00
0005433285449	23021	Economy	5200.00
0005435104016	23021	Economy	5200.00
0005433285387	23021	Economy	5200.00
0005435104015	23021	Economy	5200.00
0005433285299	23021	Economy	5200.00
0005433285605	23021	Economy	5200.00
0005433285428	23021	Economy	5200.00
0005433285502	23021	Economy	5200.00
0005433285401	23021	Economy	5200.00
0005433285370	23021	Economy	5700.00
0005433285325	23021	Economy	5200.00
0005433285429	23021	Economy	5200.00
0005433285471	23021	Economy	5200.00
0005433285435	23021	Economy	5200.00
0005433285398	23021	Economy	5200.00
0005433285503	23021	Economy	5200.00
0005433285389	23021	Economy	5200.00
0005433285504	23021	Economy	5200.00
0005435104014	23021	Economy	5200.00
0005433285433	23021	Economy	5200.00
0005433285480	23021	Economy	5200.00
0005433285277	23021	Economy	5200.00
0005433285507	23021	Economy	5200.00
0005433285427	23021	Economy	5200.00
0005433285489	23021	Economy	5200.00
0005433285450	23021	Economy	5200.00
0005433285368	23021	Economy	5200.00
0005433285589	23021	Economy	5200.00
0005433285501	23021	Economy	5200.00
0005433285388	23021	Economy	5200.00
0005433285399	23021	Economy	5200.00
0005435103924	32073	Business	15700.00
0005435103918	32073	Business	15700.00
0005433285689	32073	Business	15700.00
0005433285690	32073	Business	15700.00
0005433285702	32073	Economy	5200.00
0005433285700	32073	Economy	5200.00
0005435103931	32073	Economy	5200.00
0005433285692	32073	Economy	5200.00
0005433285684	32073	Economy	5200.00
0005433285691	32073	Economy	5200.00
0005433285680	32073	Economy	5200.00
0005433285698	32073	Economy	5200.00
0005433285705	32073	Economy	5200.00
0005433285677	32073	Economy	5200.00
0005433285676	32073	Economy	5200.00
0005433285687	32073	Economy	5200.00
0005433285706	32073	Economy	5200.00
0005435103922	32073	Economy	5200.00
0005433285695	32073	Economy	5200.00
0005433285679	32073	Economy	5700.00
0005433285685	32073	Economy	5700.00
0005433285697	32073	Economy	5700.00
0005435103921	32073	Economy	5700.00
0005433285696	32073	Economy	5200.00
0005435103930	32073	Economy	5200.00
0005433285704	32073	Economy	5200.00
0005433285688	32073	Economy	5200.00
0005433285693	32073	Economy	5200.00
0005435103929	32073	Economy	5200.00
0005433285707	32073	Economy	5200.00
0005433285678	32073	Economy	5200.00
0005433285683	32073	Economy	5200.00
0005433285694	32073	Economy	5200.00
0005433285701	32073	Economy	5200.00
0005433285703	32073	Economy	5200.00
0005433285699	32073	Economy	5200.00
0005433285681	32073	Economy	5200.00
0005433285682	32073	Economy	5200.00
0005435103887	32073	Economy	5200.00
0005433285686	32073	Economy	5200.00
0005432802549	1481	Business	150400.00
0005432892772	1481	Business	150400.00
0005432802561	1481	Business	150400.00
0005432892770	1481	Business	150400.00
0005433112369	1481	Business	150400.00
0005432892746	1481	Business	150400.00
0005432802546	1481	Business	150400.00
0005432802562	1481	Business	150400.00
0005432802535	1481	Business	150400.00
0005433112364	1481	Business	150400.00
0005432892745	1481	Economy	50100.00
0005433112362	1481	Business	150400.00
0005432802551	1481	Economy	50100.00
0005432802556	1481	Economy	50100.00
0005432802533	1481	Economy	50100.00
0005432892747	1481	Economy	50100.00
0005432802534	1481	Economy	50100.00
0005432802550	1481	Economy	55200.00
0005432802541	1481	Economy	55200.00
0005432802545	1481	Economy	50100.00
0005432892758	1481	Economy	55200.00
0005432892764	1481	Economy	50100.00
0005432892756	1481	Economy	50100.00
0005432802539	1481	Economy	50100.00
0005432892757	1481	Economy	50100.00
0005432802542	1481	Economy	50100.00
0005432802558	1481	Economy	50100.00
0005432802554	1481	Economy	50100.00
0005433112368	1481	Economy	50100.00
0005432802563	1481	Economy	50100.00
0005432892771	1481	Economy	50100.00
0005432802559	1481	Economy	50100.00
0005432802553	1481	Economy	50100.00
0005432802536	1481	Economy	50100.00
0005432802540	1481	Economy	50100.00
0005432892775	1481	Economy	50100.00
0005433112366	1481	Economy	50100.00
0005432802543	1481	Economy	50100.00
0005432802544	1481	Economy	50100.00
0005432802560	1481	Economy	50100.00
0005433112370	1481	Economy	50100.00
0005432892755	1481	Economy	50100.00
0005433112372	1481	Economy	50100.00
0005432802532	1481	Economy	50100.00
0005433112365	1481	Economy	50100.00
0005432892769	1481	Economy	50100.00
0005432802552	1481	Economy	50100.00
0005432892766	1481	Economy	50100.00
0005433112367	1481	Economy	50100.00
0005432892753	1481	Economy	50100.00
0005432802555	1481	Economy	50100.00
0005433112363	1481	Economy	50100.00
0005432802557	1481	Economy	50100.00
0005432802547	1481	Economy	50100.00
0005432802548	1481	Economy	50100.00
0005432802538	1481	Economy	50100.00
0005433112375	1481	Economy	50100.00
0005432802537	1481	Economy	50100.00
0005435852608	23860	Economy	13500.00
0005435852604	23860	Economy	13500.00
0005433475726	23860	Economy	12300.00
0005435852612	23860	Economy	12300.00
0005433475714	23860	Economy	12300.00
0005435852607	23860	Economy	12300.00
0005435852611	23860	Economy	12300.00
0005435852613	23860	Economy	12300.00
0005433475721	23860	Economy	12300.00
0005435852605	23860	Economy	12300.00
0005435852610	23860	Economy	12300.00
0005433475713	23860	Economy	12300.00
0005433475725	23860	Economy	12300.00
0005433475727	23860	Economy	12300.00
0005435852606	23860	Economy	12300.00
0005433475733	23860	Economy	12300.00
0005435852609	23860	Economy	12300.00
0005433475732	23860	Economy	12300.00
0005433475719	23860	Economy	12300.00
0005433475716	23860	Economy	12300.00
0005433475724	23860	Economy	12300.00
0005435725667	30614	Business	42100.00
0005432528212	30614	Business	42100.00
0005432528440	30614	Business	42100.00
0005434067783	30614	Business	42100.00
0005432528568	30614	Business	42100.00
0005434067908	30614	Business	42100.00
0005432528151	30614	Business	42100.00
0005434067569	30614	Business	42100.00
0005435725666	30614	Business	42100.00
0005432528831	30614	Business	42100.00
0005435214409	30614	Business	42100.00
0005432528366	30614	Business	42100.00
0005432211605	30614	Business	42100.00
0005435214417	30614	Business	42100.00
0005432159918	30614	Business	42100.00
0005432528622	30614	Business	42100.00
0005432528269	30614	Business	42100.00
0005434067934	30614	Business	42100.00
0005433656718	30614	Business	42100.00
0005432528811	30614	Business	42100.00
0005432528898	30614	Business	42100.00
0005432528406	30614	Business	42100.00
0005432527915	30614	Business	42100.00
0005432528633	30614	Business	42100.00
0005434067661	30614	Business	42100.00
0005432528936	30614	Business	42100.00
0005432528558	30614	Comfort	23900.00
0005435214414	30614	Comfort	23900.00
0005435725668	30614	Comfort	23900.00
0005434067957	30614	Comfort	23900.00
0005434068175	30614	Comfort	23900.00
0005434067935	30614	Comfort	23900.00
0005434067740	30614	Comfort	23900.00
0005432527908	30614	Comfort	23900.00
0005435214474	30614	Comfort	23900.00
0005432528069	30614	Comfort	23900.00
0005432528797	30614	Comfort	23900.00
0005435214423	30614	Comfort	23900.00
0005432159920	30614	Comfort	23900.00
0005435214477	30614	Comfort	23900.00
0005432528640	30614	Comfort	23900.00
0005434067796	30614	Comfort	23900.00
0005432529091	30614	Comfort	23900.00
0005435214451	30614	Comfort	23900.00
0005435214446	30614	Comfort	23900.00
0005432528796	30614	Comfort	23900.00
0005432528830	30614	Comfort	23900.00
0005434067901	30614	Comfort	23900.00
0005434067998	30614	Comfort	23900.00
0005432528926	30614	Comfort	23900.00
0005435214416	30614	Comfort	23900.00
0005433656715	30614	Comfort	23900.00
0005434067964	30614	Comfort	23900.00
0005432528889	30614	Comfort	23900.00
0005434067956	30614	Comfort	23900.00
0005435214418	30614	Comfort	23900.00
0005434067902	30614	Comfort	23900.00
0005432528647	30614	Comfort	23900.00
0005432528648	30614	Comfort	23900.00
0005434067836	30614	Comfort	23900.00
0005435214428	30614	Economy	14000.00
0005434067681	30614	Economy	14000.00
0005435214439	30614	Economy	14000.00
0005435214461	30614	Economy	14000.00
0005432527927	30614	Economy	14000.00
0005432211601	30614	Economy	14000.00
0005434067884	30614	Economy	14000.00
0005432528618	30614	Economy	14000.00
0005434067787	30614	Economy	14000.00
0005435214473	30614	Economy	14000.00
0005434067983	30614	Economy	14000.00
0005432528374	30614	Economy	14000.00
0005433656716	30614	Economy	14000.00
0005435214463	30614	Economy	14000.00
0005435214457	30614	Economy	14000.00
0005432528632	30614	Economy	14000.00
0005434067828	30614	Economy	14000.00
0005434067809	30614	Economy	14000.00
0005435214449	30614	Economy	14000.00
0005435214468	30614	Economy	14000.00
0005432528526	30614	Economy	14000.00
0005434067706	30614	Economy	14000.00
0005435214442	30614	Economy	14000.00
0005434067579	30614	Economy	14000.00
0005434067680	30614	Economy	14000.00
0005432528349	30614	Economy	14000.00
0005432211603	30614	Economy	14000.00
0005435214420	30614	Economy	14000.00
0005432529092	30614	Economy	14000.00
0005432528456	30614	Economy	14000.00
0005432528726	30614	Economy	14000.00
0005434067556	30614	Economy	14000.00
0005435631009	30614	Economy	14000.00
0005434067896	30614	Economy	14000.00
0005432528402	30614	Economy	14000.00
0005432528171	30614	Economy	14000.00
0005435214429	30614	Economy	14000.00
0005434068187	30614	Economy	14000.00
0005432528439	30614	Economy	14000.00
0005435214436	30614	Economy	14000.00
0005432528401	30614	Economy	14000.00
0005434068193	30614	Economy	14000.00
0005434067804	30614	Economy	14000.00
0005435214453	30614	Economy	14000.00
0005435214467	30614	Economy	14000.00
0005432528695	30614	Economy	14000.00
0005435214410	30614	Economy	14000.00
0005435214445	30614	Economy	14000.00
0005435214447	30614	Economy	14000.00
0005435214431	30614	Economy	14000.00
0005432528350	30614	Economy	15400.00
0005432528274	30614	Economy	15400.00
0005432528800	30614	Economy	14000.00
0005434067558	30614	Economy	14000.00
0005432528057	30614	Economy	15400.00
0005432535863	30614	Economy	15400.00
0005434067557	30614	Economy	14000.00
0005432528677	30614	Economy	14000.00
0005435214413	30614	Economy	14000.00
0005435725665	30614	Economy	14000.00
0005432528676	30614	Economy	14000.00
0005432527898	30614	Economy	14000.00
0005434067788	30614	Economy	14000.00
0005432528226	30614	Economy	14000.00
0005432528691	30614	Economy	14000.00
0005432528850	30614	Economy	14000.00
0005435214440	30614	Economy	14000.00
0005432529071	30614	Economy	14000.00
0005435214443	30614	Economy	14000.00
0005434067893	30614	Economy	14000.00
0005432428941	30614	Economy	14000.00
0005434067580	30614	Economy	14000.00
0005432528412	30614	Economy	14000.00
0005435214450	30614	Economy	14000.00
0005432159916	30614	Economy	14000.00
0005432528557	30614	Economy	14000.00
0005432211599	30614	Economy	14000.00
0005434067920	30614	Economy	14000.00
0005434067841	30614	Economy	14000.00
0005434068176	30614	Economy	14000.00
0005432528403	30614	Economy	14000.00
0005435631008	30614	Economy	14000.00
0005432528712	30614	Economy	14000.00
0005435214435	30614	Economy	14000.00
0005432528812	30614	Economy	14000.00
0005432528599	30614	Economy	14000.00
0005432159917	30614	Economy	14000.00
0005434067744	30614	Economy	14000.00
0005435214434	30614	Economy	14000.00
0005435214458	30614	Economy	14000.00
0005435214448	30614	Economy	14000.00
0005435214427	30614	Economy	14000.00
0005432428953	30614	Economy	14000.00
0005432528365	30614	Economy	14000.00
0005432528634	30614	Economy	14000.00
0005432528056	30614	Economy	14000.00
0005432529101	30614	Economy	14000.00
0005433656714	30614	Economy	14000.00
0005434067958	30614	Economy	14000.00
0005432528617	30614	Economy	14000.00
0005432528652	30614	Economy	14000.00
0005435214464	30614	Economy	14000.00
0005432528504	30614	Economy	14000.00
0005435214438	30614	Economy	14000.00
0005434067743	30614	Economy	14000.00
0005434067963	30614	Economy	14000.00
0005432528515	30614	Economy	14000.00
0005432159919	30614	Economy	14000.00
0005435214460	30614	Economy	14000.00
0005434068177	30614	Economy	14000.00
0005432527862	30614	Economy	14000.00
0005432528517	30614	Economy	14000.00
0005432528675	30614	Economy	14000.00
0005432528913	30614	Economy	14000.00
0005432528725	30614	Economy	14000.00
0005432528644	30614	Economy	14000.00
0005435214452	30614	Economy	14000.00
0005432528353	30614	Economy	14000.00
0005435214415	30614	Economy	14000.00
0005432528624	30614	Economy	14000.00
0005435214441	30614	Economy	14000.00
0005434067797	30614	Economy	14000.00
0005432528646	30614	Economy	14000.00
0005432528373	30614	Economy	14000.00
0005435214469	30614	Economy	14000.00
0005435725669	30614	Economy	14000.00
0005432528090	30614	Economy	14000.00
0005434068030	30614	Economy	14000.00
0005435214411	30614	Economy	14000.00
0005432211600	30614	Economy	14000.00
0005434067883	30614	Economy	14000.00
0005434068236	30614	Economy	14000.00
0005434067865	30614	Economy	14000.00
0005434067878	30614	Economy	14000.00
0005435214433	30614	Economy	14000.00
0005432528623	30614	Economy	14000.00
0005432528331	30614	Economy	14000.00
0005435214462	30614	Economy	14000.00
0005435214425	30614	Economy	14000.00
0005435214421	30614	Economy	14000.00
0005432529069	30614	Economy	14000.00
0005432527861	30614	Economy	14000.00
0005432528887	30614	Economy	14000.00
0005435214475	30614	Economy	15400.00
0005432528666	30614	Economy	15400.00
0005434067668	30614	Economy	15400.00
0005432528813	30614	Economy	15400.00
0005432211597	30614	Economy	14000.00
0005432528925	30614	Economy	14000.00
0005432527907	30614	Economy	14000.00
0005435214470	30614	Economy	14000.00
0005432428952	30614	Economy	14000.00
0005434067892	30614	Economy	14000.00
0005432528693	30614	Economy	14000.00
0005433656717	30614	Economy	14000.00
0005435214476	30614	Economy	14000.00
0005432528694	30614	Economy	14000.00
0005435214444	30614	Economy	14000.00
0005432528669	30614	Economy	14000.00
0005435214471	30614	Economy	14000.00
0005432528276	30614	Economy	14000.00
0005432528951	30614	Economy	14000.00
0005432528347	30614	Economy	14000.00
0005432428940	30614	Economy	14000.00
0005434067570	30614	Economy	14000.00
0005432528488	30614	Economy	14000.00
0005435214455	30614	Economy	14000.00
0005435214454	30614	Economy	14000.00
0005435214419	30614	Economy	14000.00
0005432528159	30614	Economy	14000.00
0005432528197	30614	Economy	14000.00
0005434067900	30614	Economy	14000.00
0005432528760	30614	Economy	14000.00
0005432428927	30614	Economy	14000.00
0005435214466	30614	Economy	14000.00
0005434068235	30614	Economy	14000.00
0005432528828	30614	Economy	14000.00
0005432528805	30614	Economy	14000.00
0005432528879	30614	Economy	14000.00
0005432528140	30614	Economy	14000.00
0005432528782	30614	Economy	14000.00
0005432529030	30614	Economy	14000.00
0005432528503	30614	Economy	14000.00
0005434068085	30614	Economy	14000.00
0005432535864	30614	Economy	14000.00
0005435214430	30614	Economy	14000.00
0005432528275	30614	Economy	14000.00
0005434067825	30614	Economy	14000.00
0005434068186	30614	Economy	14000.00
0005435214472	30614	Economy	14000.00
0005432528338	30614	Economy	14000.00
0005432428928	30614	Economy	14000.00
0005432528645	30614	Economy	14000.00
0005432528037	30614	Economy	14000.00
0005432528798	30614	Economy	14000.00
0005432535846	30614	Economy	14000.00
0005432211602	30614	Economy	14000.00
0005435214459	30614	Economy	14000.00
0005434067903	30614	Economy	14000.00
0005432528089	30614	Economy	14000.00
0005435214422	30614	Economy	14000.00
0005435214465	30614	Economy	14000.00
0005432528741	30614	Economy	14000.00
0005435214426	30614	Economy	14000.00
0005435214437	30614	Economy	14000.00
0005432528888	30614	Economy	14000.00
0005432528635	30614	Economy	14000.00
0005432528833	30614	Economy	14000.00
0005435214432	30614	Economy	14000.00
0005432528211	30614	Economy	14000.00
0005432211604	30614	Economy	14000.00
0005432211598	30614	Economy	14000.00
0005435214424	30614	Economy	14000.00
0005432528912	30614	Economy	14000.00
0005434067933	30614	Economy	14000.00
0005435214456	30614	Economy	14000.00
0005432528829	30614	Economy	14000.00
0005435214412	30614	Economy	14000.00
0005432528407	30614	Economy	14000.00
0005432528268	30614	Economy	14000.00
0005432528852	30614	Economy	14000.00
0005432528759	30614	Economy	14000.00
0005432528613	30614	Economy	14000.00
0005435653217	24840	Business	9800.00
0005433368400	24840	Business	9800.00
0005435653252	24840	Business	9800.00
0005433368396	24840	Business	9800.00
0005435653238	24840	Business	9800.00
0005433368397	24840	Business	9800.00
0005433368390	24840	Business	9800.00
0005435653169	24840	Business	9800.00
0005435653180	24840	Business	9800.00
0005433368380	24840	Economy	3300.00
0005435653253	24840	Economy	3300.00
0005433368407	24840	Economy	3300.00
0005435653229	24840	Economy	3300.00
0005433368385	24840	Economy	3300.00
0005433368381	24840	Economy	3300.00
0005433368405	24840	Economy	3300.00
0005435653014	24840	Economy	3300.00
0005435653245	24840	Economy	3300.00
0005435653248	24840	Economy	3600.00
0005435653246	24840	Economy	3600.00
0005433368401	24840	Economy	3600.00
0005433368389	24840	Economy	3300.00
0005435653048	24840	Economy	3300.00
0005435653215	24840	Economy	3300.00
0005433368408	24840	Economy	3300.00
0005433368387	24840	Economy	3300.00
0005435653221	24840	Economy	3300.00
0005433368386	24840	Economy	3300.00
0005435653166	24840	Economy	3300.00
0005433368379	24840	Economy	3300.00
0005433368378	24840	Economy	3300.00
0005433368393	24840	Economy	3300.00
0005433368392	24840	Economy	3300.00
0005433368391	24840	Economy	3300.00
0005435653157	24840	Economy	3300.00
0005435653165	24840	Economy	3300.00
0005435653239	24840	Economy	3300.00
0005433368403	24840	Economy	3300.00
0005433368371	24840	Economy	3300.00
0005435653056	24840	Economy	3300.00
0005433368398	24840	Economy	3300.00
0005435653194	24840	Economy	3300.00
0005435653218	24840	Economy	3300.00
0005433368399	24840	Economy	3300.00
0005433368404	24840	Economy	3300.00
0005435653222	24840	Economy	3300.00
0005433368388	24840	Economy	3300.00
0005435653243	24840	Economy	3300.00
0005433368376	24840	Economy	3300.00
0005435653224	24840	Economy	3300.00
0005433368373	24840	Economy	3300.00
0005435653247	24840	Economy	3300.00
0005435653201	24840	Economy	3300.00
0005435653181	24840	Economy	3300.00
0005435653050	24840	Economy	3300.00
0005435652976	24840	Economy	3300.00
0005435653049	24840	Economy	3300.00
0005433368395	24840	Economy	3300.00
0005433368402	24840	Economy	3300.00
0005433368383	24840	Economy	3300.00
0005433368394	24840	Economy	3300.00
0005435653220	24840	Economy	3300.00
0005433368406	24840	Economy	3300.00
0005433368384	24840	Economy	3300.00
0005435653057	24840	Economy	3300.00
0005435653244	24840	Economy	3300.00
0005433368370	24840	Economy	3300.00
0005435653100	24840	Economy	3300.00
0005433368377	24840	Economy	3300.00
0005435653115	24840	Economy	3300.00
0005435653216	24840	Economy	3300.00
0005435653214	24840	Economy	3300.00
0005433368375	24840	Economy	3300.00
0005433368374	24840	Economy	3300.00
0005433368372	24840	Economy	3300.00
0005435653167	24840	Economy	3300.00
0005435653212	24840	Economy	3300.00
0005435652918	24840	Economy	3300.00
0005433368382	24840	Economy	3300.00
0005434980203	2051	Economy	10500.00
0005434980191	2051	Economy	10500.00
0005434980202	2051	Economy	10500.00
0005435801735	2051	Economy	9500.00
0005434980196	2051	Economy	9500.00
0005435801736	2051	Economy	9500.00
0005435801737	2051	Economy	9500.00
0005434980181	2051	Economy	9500.00
0005434980197	2051	Economy	9500.00
0005434980186	2051	Economy	9500.00
0005434980205	2051	Economy	9500.00
0005434980195	2051	Economy	9500.00
0005434980175	2051	Economy	9500.00
0005434980180	2051	Economy	9500.00
0005434980184	2051	Economy	9500.00
0005434980176	2051	Economy	9500.00
0005434980183	2051	Economy	9500.00
0005434980204	2051	Economy	9500.00
0005434980187	2051	Economy	9500.00
0005434980198	2051	Economy	9500.00
0005434980194	2051	Economy	9500.00
0005434980185	2051	Economy	9500.00
0005434980200	2051	Economy	9500.00
0005435801738	2051	Economy	9500.00
0005434980182	2051	Economy	9500.00
0005434980192	2051	Economy	9500.00
0005434980177	2051	Economy	9500.00
0005434980178	2051	Economy	9500.00
0005434980189	2051	Economy	9500.00
0005434980190	2051	Economy	9500.00
0005434980193	2051	Economy	9500.00
0005434980201	2051	Economy	9500.00
0005434980188	2051	Economy	9500.00
0005434980199	2051	Economy	9500.00
0005434980179	2051	Economy	9500.00
0005434979860	23571	Economy	10500.00
0005434979929	23571	Economy	10500.00
0005434979933	23571	Economy	10500.00
0005434979688	23571	Economy	9500.00
0005434979925	23571	Economy	9500.00
0005434979689	23571	Economy	9500.00
0005435801707	23571	Economy	9500.00
0005434979718	23571	Economy	9500.00
0005434979897	23571	Economy	9500.00
0005434979900	23571	Economy	9500.00
0005434979932	23571	Economy	9500.00
0005434979866	23571	Economy	9500.00
0005434979884	23571	Economy	9500.00
0005434979857	23571	Economy	9500.00
0005434979826	23571	Economy	9500.00
0005434979963	23571	Economy	9500.00
0005434979813	23571	Economy	9500.00
0005434979930	23571	Economy	9500.00
0005434979858	23571	Economy	9500.00
0005434979994	23571	Economy	9500.00
0005434979872	23571	Economy	9500.00
0005434979901	23571	Economy	9500.00
0005434979808	23571	Economy	9500.00
0005434979899	23571	Economy	9500.00
0005434979782	23571	Economy	9500.00
0005434979856	23571	Economy	9500.00
0005434979874	23571	Economy	9500.00
0005434979773	23571	Economy	9500.00
0005434979902	23571	Economy	9500.00
0005434979873	23571	Economy	9500.00
0005434979717	23571	Economy	9500.00
0005434979807	23571	Economy	9500.00
0005434979931	23571	Economy	9500.00
0005434979836	23571	Economy	9500.00
0005434979774	23571	Economy	9500.00
0005434979921	23571	Economy	9500.00
0005434979865	23571	Economy	9500.00
0005434979772	23571	Economy	9500.00
0005434979781	23571	Economy	9500.00
0005434979898	23571	Economy	9500.00
0005434979877	23571	Economy	9500.00
0005434979780	23571	Economy	9500.00
0005435801715	23571	Economy	9500.00
0005434952581	2600	Economy	5300.00
0005434952583	2600	Economy	5300.00
0005434952582	2600	Economy	5300.00
0005434952580	2600	Economy	5300.00
0005434952579	2600	Economy	5300.00
0005433256439	2606	Economy	5300.00
0005433256438	2606	Economy	5300.00
0005434952554	28188	Economy	5300.00
0005434952543	28188	Economy	5300.00
0005434952552	28188	Economy	5300.00
0005434952556	28188	Economy	5300.00
0005433256451	28188	Economy	5300.00
0005434952553	28188	Economy	5300.00
0005433256452	28188	Economy	5300.00
0005434952545	28188	Economy	5300.00
0005434952542	28188	Economy	5300.00
0005434952544	28188	Economy	5300.00
0005434952537	28188	Economy	5300.00
0005433112395	19726	Economy	8700.00
0005433111536	19726	Economy	8700.00
0005433112394	19726	Economy	8700.00
0005433111535	19726	Economy	8700.00
0005433112393	19726	Economy	8700.00
0005433112368	19995	Economy	8700.00
0005433112372	19995	Economy	8700.00
0005433112365	19995	Economy	8700.00
0005433112363	19995	Economy	8700.00
0005433112364	19995	Economy	8700.00
0005433112370	19995	Economy	8700.00
0005433112375	19995	Economy	8700.00
0005433112366	19995	Economy	8700.00
0005433112369	19995	Economy	8700.00
0005433112367	19995	Economy	8700.00
0005433112362	19995	Economy	8700.00
0005434138752	11947	Business	9700.00
0005434138489	11947	Business	9700.00
0005434138459	11947	Business	9700.00
0005434138621	11947	Business	9700.00
0005434138676	11947	Business	9700.00
0005434138441	11947	Business	9700.00
0005434138358	11947	Business	9700.00
0005434138517	11947	Business	9700.00
0005434138674	11947	Business	9700.00
0005434138302	11947	Business	9700.00
0005434138514	11947	Economy	3200.00
0005434138505	11947	Economy	3200.00
0005434138675	11947	Economy	3200.00
0005434138477	11947	Economy	3200.00
0005434138362	11947	Economy	3200.00
0005434138203	11947	Economy	3200.00
0005434138436	11947	Economy	3200.00
0005434138792	11947	Economy	3200.00
0005434138808	11947	Economy	3500.00
0005434138795	11947	Economy	3500.00
0005434138490	11947	Economy	3500.00
0005434138823	11947	Economy	3500.00
0005434138836	11947	Economy	3500.00
0005434138518	11947	Economy	3200.00
0005434138136	11947	Economy	3200.00
0005434138782	11947	Economy	3200.00
0005434138515	11947	Economy	3200.00
0005434138595	11947	Economy	3200.00
0005434138137	11947	Economy	3200.00
0005434138255	11947	Economy	3200.00
0005434138460	11947	Economy	3200.00
0005434138793	11947	Economy	3200.00
0005434138581	11947	Economy	3200.00
0005434138292	11947	Economy	3200.00
0005434138697	11947	Economy	3200.00
0005434138566	11947	Economy	3200.00
0005434138467	11947	Economy	3200.00
0005434138657	11947	Economy	3200.00
0005434138659	11947	Economy	3200.00
0005434138396	11947	Economy	3200.00
0005434138190	11947	Economy	3200.00
0005434138580	11947	Economy	3200.00
0005434138446	11947	Economy	3200.00
0005434138365	11947	Economy	3200.00
0005434138367	11947	Economy	3200.00
0005434138563	11947	Economy	3200.00
0005434138257	11947	Economy	3200.00
0005434138357	11947	Economy	3200.00
0005434138229	11947	Economy	3200.00
0005434138835	11947	Economy	3200.00
0005434138256	11947	Economy	3200.00
0005434138807	11947	Economy	3200.00
0005434138501	11947	Economy	3200.00
0005434138127	11947	Economy	3200.00
0005434138671	11947	Economy	3200.00
0005434138404	11947	Economy	3200.00
0005434138561	11947	Economy	3200.00
0005434138364	11947	Economy	3200.00
0005434138366	11947	Economy	3200.00
0005434138188	11947	Economy	3200.00
0005434138582	11947	Economy	3200.00
0005434138534	11947	Economy	3200.00
0005434138751	11947	Economy	3200.00
0005434138825	11947	Economy	3200.00
0005434138344	11947	Economy	3200.00
0005434138478	11947	Economy	3200.00
0005434138816	11947	Economy	3200.00
0005434138401	11947	Economy	3200.00
0005434138794	11947	Economy	3200.00
0005434138535	11947	Economy	3200.00
0005434138579	11947	Economy	3200.00
0005434138803	11947	Economy	3200.00
0005434138189	11947	Economy	3200.00
0005434138768	11947	Economy	3200.00
0005434138485	11947	Economy	3200.00
0005434138834	11947	Economy	3200.00
0005434138708	11947	Economy	3200.00
0005434138452	11947	Economy	3200.00
0005434138658	11947	Economy	3200.00
0005434138228	11947	Economy	3200.00
0005434138482	11947	Economy	3200.00
0005434138562	11947	Economy	3200.00
0005434138719	11947	Economy	3200.00
0005434138772	11947	Economy	3200.00
0005434138766	11947	Economy	3200.00
0005434138567	11947	Economy	3200.00
0005434138291	11947	Economy	3200.00
0005434139199	28763	Business	9700.00
0005434139156	28763	Business	9700.00
0005434139134	28763	Business	9700.00
0005434139190	28763	Business	9700.00
0005434139194	28763	Business	9700.00
0005434139182	28763	Business	9700.00
0005434139148	28763	Business	9700.00
0005434139154	28763	Business	9700.00
0005434139180	28763	Business	9700.00
0005434139162	28763	Business	9700.00
0005434139160	28763	Economy	3200.00
0005434139195	28763	Economy	3200.00
0005434139204	28763	Economy	3200.00
0005434139184	28763	Economy	3200.00
0005434139208	28763	Economy	3200.00
0005434139164	28763	Economy	3200.00
0005434139211	28763	Economy	3200.00
0005434139201	28763	Economy	3200.00
0005434139147	28763	Economy	3500.00
0005434139189	28763	Economy	3500.00
0005434139212	28763	Economy	3500.00
0005434139168	28763	Economy	3500.00
0005434139133	28763	Economy	3500.00
0005434139137	28763	Economy	3200.00
0005434139131	28763	Economy	3200.00
0005434139214	28763	Economy	3200.00
0005434139151	28763	Economy	3200.00
0005434139206	28763	Economy	3200.00
0005434139136	28763	Economy	3200.00
0005434139172	28763	Economy	3200.00
0005434139142	28763	Economy	3200.00
0005434139183	28763	Economy	3200.00
0005434139135	28763	Economy	3200.00
0005434139132	28763	Economy	3200.00
0005434139177	28763	Economy	3200.00
0005434139145	28763	Economy	3200.00
0005434139169	28763	Economy	3200.00
0005434139157	28763	Economy	3200.00
0005434139173	28763	Economy	3200.00
0005434139207	28763	Economy	3200.00
0005434139163	28763	Economy	3200.00
0005434139203	28763	Economy	3200.00
0005434139196	28763	Economy	3200.00
0005434139210	28763	Economy	3200.00
0005434139166	28763	Economy	3200.00
0005434139193	28763	Economy	3200.00
0005434139138	28763	Economy	3200.00
0005434139152	28763	Economy	3200.00
0005434139197	28763	Economy	3200.00
0005434139186	28763	Economy	3200.00
0005434139178	28763	Economy	3200.00
0005434139167	28763	Economy	3200.00
0005434139140	28763	Economy	3200.00
0005434139179	28763	Economy	3200.00
0005434139141	28763	Economy	3200.00
0005434139200	28763	Economy	3200.00
0005434139191	28763	Economy	3200.00
0005434139161	28763	Economy	3200.00
0005434139174	28763	Economy	3200.00
0005434139192	28763	Economy	3200.00
0005434139158	28763	Economy	3200.00
0005434139176	28763	Economy	3200.00
0005434139202	28763	Economy	3200.00
0005434139187	28763	Economy	3200.00
0005434139165	28763	Economy	3200.00
0005434139153	28763	Economy	3200.00
0005434139209	28763	Economy	3200.00
0005434139146	28763	Economy	3200.00
0005434139130	28763	Economy	3200.00
0005434139139	28763	Economy	3200.00
0005434139143	28763	Economy	3200.00
0005434139213	28763	Economy	3200.00
0005434139171	28763	Economy	3200.00
0005434139149	28763	Economy	3200.00
0005434139144	28763	Economy	3200.00
0005434139159	28763	Economy	3200.00
0005434139155	28763	Economy	3200.00
0005434139181	28763	Economy	3200.00
0005434139205	28763	Economy	3200.00
0005434139188	28763	Economy	3200.00
0005434139170	28763	Economy	3200.00
0005434139198	28763	Economy	3200.00
0005434139175	28763	Economy	3200.00
0005434139185	28763	Economy	3200.00
0005434139150	28763	Economy	3200.00
0005434466518	6574	Economy	23000.00
0005435312814	6574	Economy	23000.00
0005435312815	6574	Economy	20900.00
0005435312816	6574	Economy	20900.00
0005434466523	6574	Economy	20900.00
0005434466520	6574	Economy	20900.00
0005434466524	6574	Economy	20900.00
0005435312823	6574	Economy	20900.00
0005434466517	6574	Economy	20900.00
0005434466516	6574	Economy	20900.00
0005434466519	6574	Economy	20900.00
0005434466515	6574	Economy	20900.00
0005434466521	6574	Economy	20900.00
0005434466527	6574	Economy	20900.00
0005434466525	6574	Economy	20900.00
0005434466526	6574	Economy	20900.00
0005434466522	6574	Economy	20900.00
0005434466528	6574	Economy	20900.00
0005433538987	6783	Economy	10900.00
0005435259760	6783	Economy	9900.00
0005433538983	6783	Economy	9900.00
0005435259770	6783	Economy	9900.00
0005433538989	6783	Economy	9900.00
0005433538985	6783	Economy	9900.00
0005433534527	6783	Economy	9900.00
0005433538988	6783	Economy	9900.00
0005433534526	6783	Economy	9900.00
0005433538990	6783	Economy	9900.00
0005435259788	6783	Economy	9900.00
0005433538986	6783	Economy	9900.00
0005433538984	6783	Economy	9900.00
0005433538982	6783	Economy	9900.00
0005435259759	6783	Economy	9900.00
0005433534507	25045	Economy	10900.00
0005435259815	25045	Economy	10900.00
0005433538893	25045	Economy	9900.00
0005435259813	25045	Economy	9900.00
0005435259816	25045	Economy	9900.00
0005433538930	25045	Economy	9900.00
0005433538895	25045	Economy	9900.00
0005433538929	25045	Economy	9900.00
0005433538924	25045	Economy	9900.00
0005433538905	25045	Economy	9900.00
0005433534506	25045	Economy	9900.00
0005435259817	25045	Economy	9900.00
0005435259814	25045	Economy	9900.00
0005433538896	25045	Economy	9900.00
0005433538889	25045	Economy	9900.00
0005432922546	796	Economy	16100.00
0005432922553	796	Economy	14600.00
0005433512063	796	Economy	14600.00
0005433512067	796	Economy	14600.00
0005433512064	796	Economy	14600.00
0005432922552	796	Economy	14600.00
0005433512065	796	Economy	14600.00
0005433512061	796	Economy	14600.00
0005433512066	796	Economy	14600.00
0005433512060	796	Economy	14600.00
0005433512062	796	Economy	14600.00
0005433512069	796	Economy	14600.00
0005433512068	796	Economy	14600.00
0005432922520	796	Economy	14600.00
0005432922580	16161	Economy	16100.00
0005433512006	16161	Economy	14600.00
0005433511976	16161	Economy	14600.00
0005432922581	16161	Economy	14600.00
0005433512009	16161	Economy	14600.00
0005433511991	16161	Economy	14600.00
0005433511994	16161	Economy	14600.00
0005433511982	16161	Economy	14600.00
0005433511983	16161	Economy	14600.00
0005433512016	16161	Economy	14600.00
0005432922578	16161	Economy	14600.00
0005433511981	16161	Economy	14600.00
0005432922579	16161	Economy	14600.00
0005433511995	16161	Economy	14600.00
0005433512021	16161	Economy	14600.00
0005433511955	16161	Economy	14600.00
0005435852591	4027	Economy	13500.00
0005435852589	4027	Economy	12300.00
0005433475766	4027	Economy	12300.00
0005435852594	4027	Economy	12300.00
0005433475761	4027	Economy	12300.00
0005433475763	4027	Economy	12300.00
0005433475764	4027	Economy	12300.00
0005433475762	4027	Economy	12300.00
0005433475760	4027	Economy	12300.00
0005433475767	4027	Economy	12300.00
0005433475765	4027	Economy	12300.00
0005435697714	3671	Economy	7900.00
0005435697727	3671	Economy	7900.00
0005434950590	3671	Economy	7200.00
0005435697733	3671	Economy	7200.00
0005435697734	3671	Economy	7200.00
0005435697709	3671	Economy	7200.00
0005435697707	3671	Economy	7200.00
0005435697730	3671	Economy	7200.00
0005435935072	3671	Economy	7200.00
0005435935060	3671	Economy	7200.00
0005434950588	3671	Economy	7200.00
0005435697723	3671	Economy	7200.00
0005435697731	3671	Economy	7200.00
0005434950589	3671	Economy	7200.00
0005435916185	3671	Economy	7200.00
0005435697705	3671	Economy	7200.00
0005435697720	3671	Economy	7200.00
0005435697726	3671	Economy	7200.00
0005435697706	3671	Economy	7200.00
0005435697721	3671	Economy	7200.00
0005435697708	3671	Economy	7200.00
0005435697716	3671	Economy	7200.00
0005435697712	3671	Economy	7200.00
0005435697717	3671	Economy	7200.00
0005435697725	3671	Economy	7200.00
0005435697713	3671	Economy	7200.00
0005435697728	3671	Economy	7200.00
0005435697719	3671	Economy	7200.00
0005434950591	3671	Economy	7200.00
0005435697724	3671	Economy	7200.00
0005435916181	3671	Economy	7200.00
0005435697729	3671	Economy	7200.00
0005435697711	3671	Economy	7200.00
0005435697715	3671	Economy	7200.00
0005435697722	3671	Economy	7200.00
0005435697732	3671	Economy	7200.00
0005435697710	3671	Economy	7200.00
0005435697718	3671	Economy	7200.00
0005435916182	3671	Economy	7200.00
0005435697471	16281	Economy	7900.00
0005435697541	16281	Economy	7900.00
0005435916202	16281	Economy	7900.00
0005435697433	16281	Economy	7900.00
0005435697365	16281	Economy	7200.00
0005435697441	16281	Economy	7200.00
0005435697525	16281	Economy	7200.00
0005435697495	16281	Economy	7200.00
0005435697431	16281	Economy	7200.00
0005434950530	16281	Economy	7200.00
0005435916204	16281	Economy	7200.00
0005435697546	16281	Economy	7200.00
0005434950555	16281	Economy	7200.00
0005435697452	16281	Economy	7200.00
0005435697423	16281	Economy	7200.00
0005435697451	16281	Economy	7200.00
0005435697526	16281	Economy	7200.00
0005435697432	16281	Economy	7200.00
0005434950563	16281	Economy	7200.00
0005435697413	16281	Economy	7200.00
0005434950568	16281	Economy	7200.00
0005435697527	16281	Economy	7200.00
0005435697436	16281	Economy	7200.00
0005434950564	16281	Economy	7200.00
0005435697522	16281	Economy	7200.00
0005435697545	16281	Economy	7200.00
0005435697440	16281	Economy	7200.00
0005435916205	16281	Economy	7200.00
0005435697467	16281	Economy	7200.00
0005435697387	16281	Economy	7200.00
0005435697434	16281	Economy	7200.00
0005435697530	16281	Economy	7200.00
0005435697414	16281	Economy	7200.00
0005435697472	16281	Economy	7200.00
0005434950557	16281	Economy	7200.00
0005435697446	16281	Economy	7200.00
0005435697367	16281	Economy	7200.00
0005435697424	16281	Economy	7200.00
0005435697521	16281	Economy	7200.00
0005434950531	16281	Economy	7200.00
0005435697542	16281	Economy	7200.00
0005435697444	16281	Economy	7200.00
0005435697486	16281	Economy	7200.00
0005435697497	16281	Economy	7200.00
0005435697445	16281	Economy	7200.00
0005435697504	16281	Economy	7200.00
0005435697366	16281	Economy	7200.00
0005435697377	16281	Economy	7200.00
0005435916203	16281	Economy	7200.00
0005434950569	16281	Economy	7200.00
0005432607620	3949	Economy	21300.00
0005433519518	3949	Economy	21300.00
0005434604946	3949	Economy	21300.00
0005435853617	3949	Economy	19300.00
0005434606876	3949	Economy	19300.00
0005434604944	3949	Economy	19300.00
0005434606874	3949	Economy	19300.00
0005435904897	3949	Economy	19300.00
0005432609786	3949	Economy	19300.00
0005433519522	3949	Economy	19300.00
0005432609788	3949	Economy	19300.00
0005432609785	3949	Economy	19300.00
0005435904706	3949	Economy	19300.00
0005434604945	3949	Economy	19300.00
0005434606875	3949	Economy	19300.00
0005433519521	3949	Economy	19300.00
0005432609784	3949	Economy	19300.00
0005432607623	3949	Economy	19300.00
0005433519517	3949	Economy	19300.00
0005433519519	3949	Economy	19300.00
0005432609787	3949	Economy	19300.00
0005435904896	3949	Economy	19300.00
0005432607621	3949	Economy	19300.00
0005433519520	3949	Economy	19300.00
0005432607622	3949	Economy	19300.00
0005432607619	3949	Economy	19300.00
0005434606877	3949	Economy	19300.00
0005434606826	22037	Economy	21300.00
0005434606825	22037	Economy	19300.00
0005433519484	22037	Economy	19300.00
0005434606845	22037	Economy	19300.00
0005434606823	22037	Economy	19300.00
0005434606847	22037	Economy	19300.00
0005433519483	22037	Economy	19300.00
0005434606827	22037	Economy	19300.00
0005434606846	22037	Economy	19300.00
0005435853635	22037	Economy	19300.00
0005434606831	22037	Economy	19300.00
0005434606842	22037	Economy	19300.00
0005435853636	22037	Economy	19300.00
0005433519471	22037	Economy	19300.00
0005433519487	22037	Economy	19300.00
0005433519485	22037	Economy	19300.00
0005435628768	713	Economy	3700.00
0005433349017	713	Economy	3700.00
0005433349031	713	Economy	3700.00
0005433349024	713	Economy	3700.00
0005433348995	713	Economy	3700.00
0005433349030	713	Economy	3700.00
0005433349025	713	Economy	3700.00
0005433349026	713	Economy	3700.00
0005433349015	713	Economy	3700.00
0005433349006	713	Economy	3700.00
0005433349034	713	Economy	3700.00
0005433349066	15905	Economy	3700.00
0005435628734	15905	Economy	3700.00
0005433349070	15905	Economy	3700.00
0005433349069	15905	Economy	3700.00
0005435628743	15905	Economy	3700.00
0005433349068	15905	Economy	3700.00
0005435628742	15905	Economy	3700.00
0005433349067	15905	Economy	3700.00
0005433158140	17186	Economy	7100.00
0005434445272	17186	Economy	7100.00
0005434446544	17186	Economy	7100.00
0005434446547	17186	Economy	7100.00
0005434445271	17186	Economy	7100.00
0005433158139	17186	Economy	7100.00
0005434446546	17186	Economy	7100.00
0005434446545	17186	Economy	7100.00
0005433158138	17186	Economy	7100.00
0005434445253	17676	Economy	7100.00
0005433159346	17676	Economy	7100.00
0005434445252	17676	Economy	7100.00
0005433159345	17676	Economy	7100.00
0005434445255	17676	Economy	7100.00
0005433159344	17676	Economy	7100.00
0005434445254	17676	Economy	7100.00
0005435133028	7869	Economy	5900.00
0005435383175	7869	Economy	5900.00
0005435383138	7869	Economy	5400.00
0005435133025	7869	Economy	5400.00
0005435133021	7869	Economy	5400.00
0005435383167	7869	Economy	5400.00
0005435383168	7869	Economy	5400.00
0005435133022	7869	Economy	5400.00
0005435133026	7869	Economy	5400.00
0005435133019	7869	Economy	5400.00
0005435383171	7869	Economy	5400.00
0005435133023	7869	Economy	5400.00
0005435133024	7869	Economy	5400.00
0005435383137	7869	Economy	5400.00
0005435383174	7869	Economy	5400.00
0005435383176	7869	Economy	5400.00
0005435133020	7869	Economy	5400.00
0005435133029	7869	Economy	5400.00
0005435133027	7869	Economy	5400.00
0005435383169	7869	Economy	5400.00
0005435132927	33116	Economy	5900.00
0005435383220	33116	Economy	5400.00
0005435132914	33116	Economy	5400.00
0005435132902	33116	Economy	5400.00
0005435132924	33116	Economy	5400.00
0005435383226	33116	Economy	5400.00
0005435132942	33116	Economy	5400.00
0005435132984	33116	Economy	5400.00
0005435383221	33116	Economy	5400.00
0005435132945	33116	Economy	5400.00
0005435383224	33116	Economy	5400.00
0005435132953	33116	Economy	5400.00
0005435383222	33116	Economy	5400.00
0005435383225	33116	Economy	5400.00
0005435132903	33116	Economy	5400.00
0005435383223	33116	Economy	5400.00
0005435132901	33116	Economy	5400.00
0005435160455	7516	Economy	13800.00
0005435390238	7516	Economy	13800.00
0005435160449	7516	Economy	12500.00
0005435390271	7516	Economy	12500.00
0005435160456	7516	Economy	12500.00
0005435160448	7516	Economy	12500.00
0005435160450	7516	Economy	12500.00
0005435160453	7516	Economy	12500.00
0005435160454	7516	Economy	12500.00
0005435390239	7516	Economy	12500.00
0005435390286	7516	Economy	12500.00
0005435160458	7516	Economy	12500.00
0005435390293	7516	Economy	12500.00
0005435390285	7516	Economy	12500.00
0005435160452	7516	Economy	12500.00
0005435160457	7516	Economy	12500.00
0005435160451	7516	Economy	12500.00
0005435160313	29537	Economy	13800.00
0005435160364	29537	Economy	13800.00
0005435390335	29537	Economy	12500.00
0005435390332	29537	Economy	12500.00
0005435160363	29537	Economy	12500.00
0005435390334	29537	Economy	12500.00
0005435390336	29537	Economy	12500.00
0005435160366	29537	Economy	12500.00
0005435160343	29537	Economy	12500.00
0005435160393	29537	Economy	12500.00
0005435160314	29537	Economy	12500.00
0005435390333	29537	Economy	12500.00
0005435160394	29537	Economy	12500.00
0005435390330	29537	Economy	12500.00
0005435390331	29537	Economy	12500.00
0005432398219	18481	Economy	4900.00
0005432398206	18481	Economy	4900.00
0005432394116	18481	Economy	4900.00
0005432398217	18481	Economy	4900.00
0005432394121	18481	Economy	4900.00
0005435178515	18481	Economy	4900.00
0005432394125	18481	Economy	4900.00
0005432394124	18481	Economy	4900.00
0005435179002	18481	Economy	4900.00
0005432398211	18481	Economy	4900.00
0005432398212	18481	Economy	4900.00
0005432398246	27140	Economy	4900.00
0005432400172	27140	Economy	4900.00
0005432400171	27140	Economy	4900.00
0005435178500	27140	Economy	4900.00
0005432398244	27140	Economy	4900.00
0005432398247	27140	Economy	4900.00
0005432398245	27140	Economy	4900.00
0005432398243	27140	Economy	4900.00
0005432866051	2242	Business	87300.00
0005432639275	2242	Business	87300.00
0005432866014	2242	Business	87300.00
0005432639278	2242	Business	87300.00
0005432639283	2242	Business	87300.00
0005432639304	2242	Business	87300.00
0005432866009	2242	Business	87300.00
0005432866038	2242	Business	87300.00
0005432639273	2242	Business	87300.00
0005432639294	2242	Economy	29100.00
0005432639302	2242	Economy	29100.00
0005432639295	2242	Economy	29100.00
0005432866023	2242	Economy	29100.00
0005432865999	2242	Economy	32000.00
0005432639297	2242	Economy	29100.00
0005432639291	2242	Economy	29100.00
0005432639303	2242	Economy	29100.00
0005432639300	2242	Economy	29100.00
0005432866043	2242	Economy	29100.00
0005432639287	2242	Economy	29100.00
0005432639308	2242	Economy	29100.00
0005432639306	2242	Economy	29100.00
0005432639289	2242	Economy	29100.00
0005432639293	2242	Economy	29100.00
0005432639285	2242	Economy	29100.00
0005432639286	2242	Economy	29100.00
0005432639277	2242	Economy	29100.00
0005432639305	2242	Economy	29100.00
0005432639281	2242	Economy	29100.00
0005432866037	2242	Economy	29100.00
0005432639307	2242	Economy	29100.00
0005432639282	2242	Economy	29100.00
0005432639272	2242	Economy	29100.00
0005432639301	2242	Economy	29100.00
0005432866034	2242	Economy	29100.00
0005432639292	2242	Economy	29100.00
0005432639274	2242	Economy	29100.00
0005432866042	2242	Economy	29100.00
0005432639290	2242	Economy	29100.00
0005432866039	2242	Economy	29100.00
0005432639279	2242	Economy	29100.00
0005432639284	2242	Economy	29100.00
0005432639276	2242	Economy	29100.00
0005432639299	2242	Economy	29100.00
0005432866012	2242	Economy	29100.00
0005432639288	2242	Economy	29100.00
0005432639296	2242	Economy	29100.00
0005432639298	2242	Economy	29100.00
0005432639280	2242	Economy	29100.00
0005434191280	9761	Economy	4400.00
0005434191281	9761	Economy	4400.00
0005434504680	6524	Business	48400.00
0005435104040	6524	Business	48400.00
0005434504671	6524	Business	48400.00
0005434504703	6524	Business	48400.00
0005434504687	6524	Business	48400.00
0005434504678	6524	Business	48400.00
0005434504685	6524	Economy	16100.00
0005434504698	6524	Economy	16100.00
0005435104035	6524	Economy	16100.00
0005434504664	6524	Economy	16100.00
0005434504679	6524	Economy	16100.00
0005435104039	6524	Economy	16100.00
0005434504674	6524	Economy	16100.00
0005434504681	6524	Economy	17800.00
0005435104047	6524	Economy	17800.00
0005434504667	6524	Economy	17800.00
0005435104036	6524	Economy	17800.00
0005434504695	6524	Economy	17800.00
0005434504677	6524	Economy	16100.00
0005434504668	6524	Economy	16100.00
0005435104032	6524	Economy	16100.00
0005434504699	6524	Economy	16100.00
0005435104042	6524	Economy	16100.00
0005434504691	6524	Economy	16100.00
0005434504696	6524	Economy	16100.00
0005434504697	6524	Economy	16100.00
0005435104046	6524	Economy	16100.00
0005434504676	6524	Economy	16100.00
0005434504694	6524	Economy	16100.00
0005434504684	6524	Economy	16100.00
0005435104045	6524	Economy	16100.00
0005435104043	6524	Economy	16100.00
0005435104034	6524	Economy	16100.00
0005434504670	6524	Economy	16100.00
0005434504665	6524	Economy	16100.00
0005435104041	6524	Economy	16100.00
0005435104031	6524	Economy	16100.00
0005434504693	6524	Economy	16100.00
0005434504692	6524	Economy	16100.00
0005434504690	6524	Economy	16100.00
0005434504669	6524	Economy	16100.00
0005434504689	6524	Economy	16100.00
0005434504673	6524	Economy	16100.00
0005434504672	6524	Economy	16100.00
0005434504666	6524	Economy	16100.00
0005435104038	6524	Economy	16100.00
0005435104033	6524	Economy	16100.00
0005434504683	6524	Economy	16100.00
0005434504675	6524	Economy	16100.00
0005435104037	6524	Economy	16100.00
0005434504686	6524	Economy	16100.00
0005434504688	6524	Economy	16100.00
0005434504700	6524	Economy	16100.00
0005435104030	6524	Economy	16100.00
0005434504682	6524	Economy	16100.00
0005435104044	6524	Economy	16100.00
0005434504701	6524	Economy	16100.00
0005434504702	6524	Economy	16100.00
0005434504214	22693	Business	48400.00
0005435103921	22693	Business	48400.00
0005434504193	22693	Business	48400.00
0005434504338	22693	Business	48400.00
0005434504255	22693	Economy	16100.00
0005434504213	22693	Economy	16100.00
0005435103929	22693	Economy	16100.00
0005435103887	22693	Economy	16100.00
0005435103922	22693	Economy	16100.00
0005434504224	22693	Economy	16100.00
0005434504212	22693	Economy	16100.00
0005434503972	22693	Economy	16100.00
0005435103918	22693	Economy	16100.00
0005434504285	22693	Economy	16100.00
0005434504371	22693	Economy	16100.00
0005434504219	22693	Economy	16100.00
0005434504355	22693	Economy	16100.00
0005434504243	22693	Economy	16100.00
0005434504130	22693	Economy	16100.00
0005434504286	22693	Economy	16100.00
0005434504418	22693	Economy	16100.00
0005434504409	22693	Economy	16100.00
0005434504337	22693	Economy	16100.00
0005434504307	22693	Economy	16100.00
0005435103931	22693	Economy	16100.00
0005434504339	22693	Economy	16100.00
0005435103930	22693	Economy	16100.00
0005434504091	22693	Economy	16100.00
0005435103924	22693	Economy	16100.00
0005434504269	22693	Economy	16100.00
0005434504225	22693	Economy	16100.00
0005434504273	22693	Economy	16100.00
0005434504204	22693	Economy	16100.00
0005435800137	6421	Economy	16800.00
0005435800140	6421	Economy	16800.00
0005435800142	6421	Economy	15300.00
0005435800130	6421	Economy	15300.00
0005435800131	6421	Economy	15300.00
0005435800139	6421	Economy	15300.00
0005435800136	6421	Economy	15300.00
0005435800143	6421	Economy	15300.00
0005435800129	6421	Economy	15300.00
0005435800135	6421	Economy	15300.00
0005435800144	6421	Economy	15300.00
0005435800138	6421	Economy	15300.00
0005435800132	6421	Economy	15300.00
0005435800141	6421	Economy	15300.00
0005435800133	6421	Economy	15300.00
0005435800134	6421	Economy	15300.00
0005435653614	1658	Business	50000.00
0005433367970	1658	Business	50000.00
0005433367995	1658	Business	50000.00
0005435653643	1658	Business	50000.00
0005433368211	1658	Business	50000.00
0005435653628	1658	Business	50000.00
0005435653640	1658	Business	50000.00
0005433368083	1658	Business	50000.00
0005435653630	1658	Business	50000.00
0005433367872	1658	Economy	16700.00
0005433368024	1658	Economy	16700.00
0005433367871	1658	Economy	16700.00
0005435653619	1658	Economy	16700.00
0005435653642	1658	Economy	16700.00
0005433368009	1658	Economy	16700.00
0005433367982	1658	Economy	16700.00
0005435653611	1658	Economy	16700.00
0005435653631	1658	Economy	16700.00
0005435653655	1658	Economy	18300.00
0005435653649	1658	Economy	18300.00
0005433368067	1658	Economy	18300.00
0005433368111	1658	Economy	16700.00
0005435653625	1658	Economy	16700.00
0005433367972	1658	Economy	16700.00
0005433368085	1658	Economy	16700.00
0005435653648	1658	Economy	16700.00
0005435653621	1658	Economy	16700.00
0005433367959	1658	Economy	16700.00
0005433368066	1658	Economy	16700.00
0005435653651	1658	Economy	16700.00
0005433368073	1658	Economy	16700.00
0005433368084	1658	Economy	16700.00
0005435653615	1658	Economy	16700.00
0005435653641	1658	Economy	16700.00
0005433367994	1658	Economy	16700.00
0005435653624	1658	Economy	16700.00
0005435653635	1658	Economy	16700.00
0005435653644	1658	Economy	16700.00
0005435653620	1658	Economy	16700.00
0005435653616	1658	Economy	16700.00
0005433367992	1658	Economy	16700.00
0005433367958	1658	Economy	16700.00
0005433367996	1658	Economy	16700.00
0005435653627	1658	Economy	16700.00
0005435653623	1658	Economy	16700.00
0005435653636	1658	Economy	16700.00
0005435653637	1658	Economy	16700.00
0005433368023	1658	Economy	16700.00
0005435653638	1658	Economy	16700.00
0005435653618	1658	Economy	16700.00
0005433367993	1658	Economy	16700.00
0005435653613	1658	Economy	16700.00
0005433368105	1658	Economy	16700.00
0005433368025	1658	Economy	16700.00
0005435653650	1658	Economy	16700.00
0005435653633	1658	Economy	16700.00
0005435653622	1658	Economy	16700.00
0005433368043	1658	Economy	16700.00
0005433368112	1658	Economy	16700.00
0005435653634	1658	Economy	16700.00
0005435653647	1658	Economy	16700.00
0005433368113	1658	Economy	16700.00
0005435653645	1658	Economy	16700.00
0005433368196	1658	Economy	16700.00
0005435653617	1658	Economy	16700.00
0005433367971	1658	Economy	16700.00
0005435653612	1658	Economy	16700.00
0005433368238	1658	Economy	16700.00
0005435653626	1658	Economy	16700.00
0005435653646	1658	Economy	16700.00
0005435653652	1658	Economy	16700.00
0005433368201	1658	Economy	16700.00
0005435653639	1658	Economy	16700.00
0005435653653	1658	Economy	16700.00
0005435653629	1658	Economy	16700.00
0005433368042	1658	Economy	16700.00
0005435653654	1658	Economy	16700.00
0005433368192	1658	Economy	16700.00
0005433368202	1658	Economy	16700.00
0005435653632	1658	Economy	16700.00
0005433368372	21711	Business	50000.00
0005433368378	21711	Business	50000.00
0005433368380	21711	Business	50000.00
0005435653181	21711	Business	50000.00
0005435653048	21711	Business	50000.00
0005435653216	21711	Business	50000.00
0005433368383	21711	Business	50000.00
0005435653244	21711	Business	50000.00
0005433368405	21711	Business	50000.00
0005433368403	21711	Economy	16700.00
0005435653214	21711	Economy	16700.00
0005433368402	21711	Economy	16700.00
0005435653247	21711	Economy	16700.00
0005435653180	21711	Economy	16700.00
0005435653167	21711	Economy	16700.00
0005433368379	21711	Economy	16700.00
0005433368377	21711	Economy	16700.00
0005433368397	21711	Economy	16700.00
0005435653056	21711	Economy	18300.00
0005435653245	21711	Economy	18300.00
0005433368393	21711	Economy	18300.00
0005435653248	21711	Economy	18300.00
0005433368376	21711	Economy	18300.00
0005435653057	21711	Economy	16700.00
0005433368401	21711	Economy	16700.00
0005433368399	21711	Economy	16700.00
0005435653212	21711	Economy	16700.00
0005433368388	21711	Economy	16700.00
0005433368371	21711	Economy	16700.00
0005433368407	21711	Economy	16700.00
0005435653165	21711	Economy	16700.00
0005435653049	21711	Economy	16700.00
0005435653050	21711	Economy	16700.00
0005435653218	21711	Economy	16700.00
0005433368392	21711	Economy	16700.00
0005433368384	21711	Economy	16700.00
0005435653252	21711	Economy	16700.00
0005435653246	21711	Economy	16700.00
0005435653100	21711	Economy	16700.00
0005435653166	21711	Economy	16700.00
0005435653243	21711	Economy	16700.00
0005433368370	21711	Economy	16700.00
0005435653169	21711	Economy	16700.00
0005433368389	21711	Economy	16700.00
0005435653222	21711	Economy	16700.00
0005435653221	21711	Economy	16700.00
0005433368382	21711	Economy	16700.00
0005433368375	21711	Economy	16700.00
0005435653115	21711	Economy	16700.00
0005433368400	21711	Economy	16700.00
0005433368398	21711	Economy	16700.00
0005435653224	21711	Economy	16700.00
0005435653239	21711	Economy	16700.00
0005435653201	21711	Economy	16700.00
0005435653014	21711	Economy	16700.00
0005435652976	21711	Economy	16700.00
0005433368391	21711	Economy	16700.00
0005433368406	21711	Economy	16700.00
0005435653229	21711	Economy	16700.00
0005433368395	21711	Economy	16700.00
0005435652918	21711	Economy	16700.00
0005433368404	21711	Economy	16700.00
0005435653220	21711	Economy	16700.00
0005433368387	21711	Economy	16700.00
0005435653157	21711	Economy	16700.00
0005433368381	21711	Economy	16700.00
0005435653194	21711	Economy	16700.00
0005433368396	21711	Economy	16700.00
0005435653215	21711	Economy	16700.00
0005433368390	21711	Economy	16700.00
0005433368373	21711	Economy	16700.00
0005435653253	21711	Economy	16700.00
0005433368408	21711	Economy	16700.00
0005433368374	21711	Economy	16700.00
0005433368385	21711	Economy	16700.00
0005433368386	21711	Economy	16700.00
0005435653217	21711	Economy	16700.00
0005433368394	21711	Economy	16700.00
0005435653238	21711	Economy	16700.00
0005435627119	23769	Economy	11200.00
0005435627120	23769	Economy	11200.00
0005434466452	23222	Economy	23000.00
0005435312836	23222	Economy	23000.00
0005435312841	23222	Economy	20900.00
0005434466465	23222	Economy	20900.00
0005434466472	23222	Economy	20900.00
0005434466491	23222	Economy	20900.00
0005435312839	23222	Economy	20900.00
0005434466471	23222	Economy	20900.00
0005435312834	23222	Economy	20900.00
0005434466477	23222	Economy	20900.00
0005434466473	23222	Economy	20900.00
0005434466463	23222	Economy	20900.00
0005435312835	23222	Economy	20900.00
0005434466464	23222	Economy	20900.00
0005434466493	23222	Economy	20900.00
0005435312838	23222	Economy	20900.00
0005434466475	23222	Economy	20900.00
0005434466451	23222	Economy	20900.00
0005434466462	23222	Economy	20900.00
0005434466490	23222	Economy	20900.00
0005434466470	23222	Economy	20900.00
0005434466446	23222	Economy	20900.00
0005434466487	23222	Economy	20900.00
0005435312837	23222	Economy	20900.00
0005435312840	23222	Economy	20900.00
0005433986575	4182	Business	21500.00
0005433986550	4182	Business	21500.00
0005433986590	4182	Business	21500.00
0005433986561	4182	Business	21500.00
0005433986591	4182	Business	21500.00
0005433986560	4182	Business	21500.00
0005433986566	4182	Economy	7200.00
0005433986582	4182	Economy	7200.00
0005433986551	4182	Economy	7200.00
0005433986568	4182	Economy	7200.00
0005433986565	4182	Economy	7900.00
0005433986558	4182	Economy	7900.00
0005433986571	4182	Economy	7900.00
0005433986567	4182	Economy	7900.00
0005435788806	4182	Economy	7900.00
0005433986579	4182	Economy	7200.00
0005433986595	4182	Economy	7200.00
0005433986585	4182	Economy	7200.00
0005433986596	4182	Economy	7200.00
0005435788805	4182	Economy	7200.00
0005433986599	4182	Economy	7200.00
0005433986600	4182	Economy	7200.00
0005433986598	4182	Economy	7200.00
0005433986555	4182	Economy	7200.00
0005433986593	4182	Economy	7200.00
0005433986564	4182	Economy	7200.00
0005433986586	4182	Economy	7200.00
0005433986576	4182	Economy	7200.00
0005433986553	4182	Economy	7200.00
0005433986587	4182	Economy	7200.00
0005433986584	4182	Economy	7200.00
0005433986601	4182	Economy	7200.00
0005433986562	4182	Economy	7200.00
0005433986563	4182	Economy	7200.00
0005433986548	4182	Economy	7200.00
0005433986597	4182	Economy	7200.00
0005433986592	4182	Economy	7200.00
0005433986594	4182	Economy	7200.00
0005433986577	4182	Economy	7200.00
0005433986583	4182	Economy	7200.00
0005433986559	4182	Economy	7200.00
0005433986588	4182	Economy	7200.00
0005433986578	4182	Economy	7200.00
0005433986569	4182	Economy	7200.00
0005433986581	4182	Economy	7200.00
0005433986556	4182	Economy	7200.00
0005433986589	4182	Economy	7200.00
0005433986574	4182	Economy	7200.00
0005433986557	4182	Economy	7200.00
0005433986573	4182	Economy	7200.00
0005433986570	4182	Economy	7200.00
0005433986554	4182	Economy	7200.00
0005433986572	4182	Economy	7200.00
0005433986552	4182	Economy	7200.00
0005433986580	4182	Economy	7200.00
0005433986549	4182	Economy	7200.00
0005433986100	25637	Business	21500.00
0005433986099	25637	Business	21500.00
0005433986032	25637	Business	21500.00
0005433986084	25637	Business	21500.00
0005433986211	25637	Business	21500.00
0005433986210	25637	Business	21500.00
0005435788782	25637	Business	21500.00
0005433986228	25637	Economy	7200.00
0005433986043	25637	Economy	7200.00
0005433986069	25637	Economy	7200.00
0005433986212	25637	Economy	7200.00
0005433986291	25637	Economy	7200.00
0005433986230	25637	Economy	7200.00
0005433985964	25637	Economy	7200.00
0005433986197	25637	Economy	7200.00
0005435788793	25637	Economy	7900.00
0005433986085	25637	Economy	7900.00
0005433986111	25637	Economy	7900.00
0005435788790	25637	Economy	7200.00
0005433986237	25637	Economy	7200.00
0005433986051	25637	Economy	7200.00
0005433986017	25637	Economy	7200.00
0005433986035	25637	Economy	7200.00
0005433986191	25637	Economy	7200.00
0005433986180	25637	Economy	7200.00
0005433986247	25637	Economy	7200.00
0005433986263	25637	Economy	7200.00
0005433986170	25637	Economy	7200.00
0005433985981	25637	Economy	7200.00
0005433986036	25637	Economy	7200.00
0005433985914	25637	Economy	7200.00
0005433986081	25637	Economy	7200.00
0005433986083	25637	Economy	7200.00
0005433985797	25637	Economy	7200.00
0005433986186	25637	Economy	7200.00
0005433986213	25637	Economy	7200.00
0005433985913	25637	Economy	7200.00
0005433986385	25637	Economy	7200.00
0005433986248	25637	Economy	7200.00
0005433986018	25637	Economy	7200.00
0005433986188	25637	Economy	7200.00
0005433986249	25637	Economy	7200.00
0005433985967	25637	Economy	7200.00
0005433986127	25637	Economy	7200.00
0005433986226	25637	Economy	7200.00
0005433985908	25637	Economy	7200.00
0005433985903	25637	Economy	7200.00
0005433985904	25637	Economy	7200.00
0005433986145	25637	Economy	7200.00
0005433986038	25637	Economy	7200.00
0005433986205	25637	Economy	7200.00
0005433986198	25637	Economy	7200.00
0005433985963	25637	Economy	7200.00
0005433986094	25637	Economy	7200.00
0005433985909	25637	Economy	7200.00
0005433986250	25637	Economy	7200.00
0005433986171	25637	Economy	7200.00
0005433986227	25637	Economy	7200.00
0005433986240	25637	Economy	7200.00
0005433986185	25637	Economy	7200.00
0005433986042	25637	Economy	7200.00
0005433986337	25637	Economy	7200.00
0005433986187	25637	Economy	7200.00
0005433986122	25637	Economy	7200.00
0005433986238	25637	Economy	7200.00
0005433168424	21323	Economy	17000.00
0005434509199	21323	Economy	17000.00
0005433168425	21323	Economy	15500.00
0005433168426	21323	Economy	15500.00
0005434509185	21323	Economy	15500.00
0005434509169	21323	Economy	15500.00
0005434509172	21323	Economy	15500.00
0005434509193	21323	Economy	15500.00
0005434509174	21323	Economy	15500.00
0005433168431	21323	Economy	15500.00
0005433168428	21323	Economy	15500.00
0005434509188	21323	Economy	15500.00
0005433168429	21323	Economy	15500.00
0005433168427	21323	Economy	15500.00
0005434509186	21323	Economy	15500.00
0005434509208	21323	Economy	15500.00
0005434509187	21323	Economy	15500.00
0005434509200	21323	Economy	15500.00
0005434509183	21323	Economy	15500.00
0005434509203	21323	Economy	15500.00
0005434509201	21323	Economy	15500.00
0005434509207	21323	Economy	15500.00
0005434509171	21323	Economy	15500.00
0005434509204	21323	Economy	15500.00
0005433168432	21323	Economy	15500.00
0005433168430	21323	Economy	15500.00
0005434509181	21323	Economy	15500.00
0005432666389	17818	Business	18000.00
0005432658599	17818	Business	18000.00
0005432661926	17818	Business	18000.00
0005432664157	17818	Business	18000.00
0005432666390	17818	Business	18000.00
0005432655591	17818	Business	18000.00
0005432661925	17818	Business	18000.00
0005432666388	17818	Economy	6000.00
0005432655623	17818	Economy	6000.00
0005432655637	17818	Economy	6000.00
0005432659716	17818	Economy	6000.00
0005432659717	17818	Economy	6600.00
0005432663049	17818	Economy	6600.00
0005432666404	17818	Economy	6600.00
0005432655563	17818	Economy	6000.00
0005432667460	17818	Economy	6000.00
0005432657464	17818	Economy	6000.00
0005432664149	17818	Economy	6000.00
0005432664146	17818	Economy	6000.00
0005432657462	17818	Economy	6000.00
0005432869618	17818	Economy	6000.00
0005432655622	17818	Economy	6000.00
0005432869619	17818	Economy	6000.00
0005432658595	17818	Economy	6000.00
0005434151745	17818	Economy	6000.00
0005432660834	17818	Economy	6000.00
0005432664156	17818	Economy	6000.00
0005432665289	17818	Economy	6000.00
0005432657451	17818	Economy	6000.00
0005434151747	17818	Economy	6000.00
0005432869616	17818	Economy	6000.00
0005432659718	17818	Economy	6000.00
0005432869617	17818	Economy	6000.00
0005432655636	17818	Economy	6000.00
0005432661927	17818	Economy	6000.00
0005432655590	17818	Economy	6000.00
0005432869620	17818	Economy	6000.00
0005434151744	17818	Economy	6000.00
0005432661934	17818	Economy	6000.00
0005432655609	17818	Economy	6000.00
0005432665285	17818	Economy	6000.00
0005432660833	17818	Economy	6000.00
0005434151746	17818	Economy	6000.00
0005432666399	17818	Economy	6000.00
0005432667461	17818	Economy	6000.00
0005432663050	17818	Economy	6000.00
0005432657487	26315	Business	18000.00
0005432658616	26315	Business	18000.00
0005434151716	26315	Business	18000.00
0005432655669	26315	Business	18000.00
0005434151709	26315	Business	18000.00
0005432665299	26315	Economy	6000.00
0005432655679	26315	Economy	6000.00
0005434151714	26315	Economy	6000.00
0005432657488	26315	Economy	6000.00
0005432660843	26315	Economy	6000.00
0005432667478	26315	Economy	6600.00
0005432869546	26315	Economy	6000.00
0005432869529	26315	Economy	6000.00
0005432869503	26315	Economy	6000.00
0005434151717	26315	Economy	6000.00
0005432659732	26315	Economy	6000.00
0005432655676	26315	Economy	6000.00
0005432665300	26315	Economy	6000.00
0005432869528	26315	Economy	6000.00
0005432655668	26315	Economy	6000.00
0005432655672	26315	Economy	6000.00
0005432657486	26315	Economy	6000.00
0005432655675	26315	Economy	6000.00
0005432655674	26315	Economy	6000.00
0005432667479	26315	Economy	6000.00
0005432658617	26315	Economy	6000.00
0005432655670	26315	Economy	6000.00
0005432655673	26315	Economy	6000.00
0005432657489	26315	Economy	6000.00
0005432869513	26315	Economy	6000.00
0005432665301	26315	Economy	6000.00
0005432657485	26315	Economy	6000.00
0005432659731	26315	Economy	6000.00
0005434151715	26315	Economy	6000.00
0005432869545	26315	Economy	6000.00
0005432666414	26315	Economy	6000.00
0005432655671	26315	Economy	6000.00
0005432655677	26315	Economy	6000.00
0005432660842	26315	Economy	6000.00
0005432666413	26315	Economy	6000.00
0005432655678	26315	Economy	6000.00
0005432287260	3122	Business	16100.00
0005432329337	3122	Business	16100.00
0005432329320	3122	Business	16100.00
0005432329313	3122	Business	16100.00
0005433438972	3122	Business	16100.00
0005432329315	3122	Business	16100.00
0005432905157	3122	Business	16100.00
0005432287259	3122	Business	16100.00
0005432329322	3122	Business	16100.00
0005432329300	3122	Economy	5400.00
0005432329327	3122	Economy	5400.00
0005432329328	3122	Economy	5400.00
0005432329303	3122	Economy	5400.00
0005432329309	3122	Economy	5400.00
0005432329305	3122	Economy	5900.00
0005432905168	3122	Economy	5900.00
0005432905167	3122	Economy	5900.00
0005432905152	3122	Economy	5900.00
0005432905165	3122	Economy	5400.00
0005432329329	3122	Economy	5400.00
0005432329321	3122	Economy	5400.00
0005432329319	3122	Economy	5400.00
0005432329339	3122	Economy	5400.00
0005432329324	3122	Economy	5400.00
0005432329306	3122	Economy	5400.00
0005432329307	3122	Economy	5400.00
0005432329336	3122	Economy	5400.00
0005432905135	3122	Economy	5400.00
0005432329335	3122	Economy	5400.00
0005432329310	3122	Economy	5400.00
0005432329332	3122	Economy	5400.00
0005432905166	3122	Economy	5400.00
0005433438971	3122	Economy	5400.00
0005432287256	3122	Economy	5400.00
0005432905158	3122	Economy	5400.00
0005432329342	3122	Economy	5400.00
0005432329311	3122	Economy	5400.00
0005432329345	3122	Economy	5400.00
0005432287257	3122	Economy	5400.00
0005432329340	3122	Economy	5400.00
0005432329301	3122	Economy	5400.00
0005432329325	3122	Economy	5400.00
0005432905136	3122	Economy	5400.00
0005432329343	3122	Economy	5400.00
0005432329344	3122	Economy	5400.00
0005432329326	3122	Economy	5400.00
0005432329333	3122	Economy	5400.00
0005432329331	3122	Economy	5400.00
0005432905172	3122	Economy	5400.00
0005432329341	3122	Economy	5400.00
0005432329330	3122	Economy	5400.00
0005432329316	3122	Economy	5400.00
0005432329299	3122	Economy	5400.00
0005432329317	3122	Economy	5400.00
0005432329323	3122	Economy	5400.00
0005432329308	3122	Economy	5400.00
0005432329304	3122	Economy	5400.00
0005432329302	3122	Economy	5400.00
0005432329338	3122	Economy	5400.00
0005432329346	3122	Economy	5400.00
0005432287258	3122	Economy	5400.00
0005432329334	3122	Economy	5400.00
0005432329314	3122	Economy	5400.00
0005432329318	3122	Economy	5400.00
0005432329312	3122	Economy	5400.00
0005432848845	31150	Business	16100.00
0005432328778	31150	Business	16100.00
0005432905204	31150	Business	16100.00
0005432054345	31150	Business	16100.00
0005432328860	31150	Business	16100.00
0005432328852	31150	Business	16100.00
0005432328815	31150	Business	16100.00
0005432054344	31150	Business	16100.00
0005433438944	31150	Economy	5400.00
0005432328822	31150	Economy	5400.00
0005432329061	31150	Economy	5400.00
0005432328823	31150	Economy	5400.00
0005432905206	31150	Economy	5400.00
0005432054342	31150	Economy	5400.00
0005432329008	31150	Economy	5400.00
0005432328732	31150	Economy	5900.00
0005432905207	31150	Economy	5900.00
0005432328724	31150	Economy	5900.00
0005432848846	31150	Economy	5900.00
0005432054343	31150	Economy	5400.00
0005432329036	31150	Economy	5400.00
0005432328630	31150	Economy	5400.00
0005432905209	31150	Economy	5400.00
0005432329081	31150	Economy	5400.00
0005432329016	31150	Economy	5400.00
0005432328670	31150	Economy	5400.00
0005432905205	31150	Economy	5400.00
0005432329035	31150	Economy	5400.00
0005432329086	31150	Economy	5400.00
0005432905208	31150	Economy	5400.00
0005432328954	31150	Economy	5400.00
0005432848843	31150	Economy	5400.00
0005432328868	31150	Economy	5400.00
0005432328902	31150	Economy	5400.00
0005432329087	31150	Economy	5400.00
0005433438943	31150	Economy	5400.00
0005432328464	31150	Economy	5400.00
0005432328856	31150	Economy	5400.00
0005432328956	31150	Economy	5400.00
0005432329034	31150	Economy	5400.00
0005432329009	31150	Economy	5400.00
0005432328671	31150	Economy	5400.00
0005433438945	31150	Economy	5400.00
0005432328848	31150	Economy	5400.00
0005432328942	31150	Economy	5400.00
0005432848844	31150	Economy	5400.00
0005432328869	31150	Economy	5400.00
0005432328835	31150	Economy	5400.00
0005432328571	31150	Economy	5400.00
0005432328943	31150	Economy	5400.00
0005432328909	31150	Economy	5400.00
0005432328955	31150	Economy	5400.00
0005432328927	31150	Economy	5400.00
0005433438894	31150	Economy	5400.00
0005432328881	31150	Economy	5400.00
0005432328715	31150	Economy	5400.00
0005433438942	31150	Economy	5400.00
0005432328913	31150	Economy	5400.00
0005434309930	6206	Business	124600.00
0005434309924	6206	Business	124600.00
0005435487977	6206	Business	124600.00
0005435488041	6206	Business	124600.00
0005435487842	6206	Business	124600.00
0005435487961	6206	Economy	41500.00
0005435487946	6206	Economy	41500.00
0005435999476	6206	Economy	41500.00
0005435999481	6206	Economy	41500.00
0005435297071	6206	Economy	41500.00
0005435487874	6206	Economy	41500.00
0005434309920	6206	Economy	41500.00
0005434309928	6206	Economy	41500.00
0005435487922	6206	Economy	41500.00
0005435297091	6206	Economy	41500.00
0005434309933	6206	Economy	41500.00
0005435999483	6206	Economy	41500.00
0005435999482	6206	Economy	41500.00
0005435487957	6206	Economy	41500.00
0005435488039	6206	Economy	41500.00
0005435487844	6206	Economy	41500.00
0005435487930	6206	Economy	41500.00
0005435297079	6206	Economy	41500.00
0005435488040	6206	Economy	41500.00
0005434309932	6206	Economy	41500.00
0005435999479	6206	Economy	45700.00
0005434309927	6206	Economy	45700.00
0005435487921	6206	Economy	41500.00
0005435487939	6206	Economy	41500.00
0005435297078	6206	Economy	41500.00
0005435297080	6206	Economy	41500.00
0005435487774	6206	Economy	41500.00
0005435487959	6206	Economy	41500.00
0005435999478	6206	Economy	41500.00
0005435487920	6206	Economy	41500.00
0005435487933	6206	Economy	41500.00
0005434309921	6206	Economy	41500.00
0005435487875	6206	Economy	41500.00
0005435297104	6206	Economy	41500.00
0005435297087	6206	Economy	41500.00
0005434309923	6206	Economy	41500.00
0005435487958	6206	Economy	41500.00
0005435487898	6206	Economy	41500.00
0005435487897	6206	Economy	41500.00
0005434309922	6206	Economy	41500.00
0005434309931	6206	Economy	41500.00
0005435999477	6206	Economy	41500.00
0005435487917	6206	Economy	41500.00
0005434309926	6206	Economy	41500.00
0005435487916	6206	Economy	41500.00
0005435487843	6206	Economy	41500.00
0005434309929	6206	Economy	41500.00
0005435999480	6206	Economy	41500.00
0005435487909	6206	Economy	41500.00
0005435297102	6206	Economy	41500.00
0005435297070	6206	Economy	41500.00
0005435297088	6206	Economy	41500.00
0005435999484	6206	Economy	41500.00
0005434309934	6206	Economy	41500.00
0005435487876	6206	Economy	41500.00
0005435297092	6206	Economy	41500.00
0005435487940	6206	Economy	41500.00
0005435487896	6206	Economy	41500.00
0005434309925	6206	Economy	41500.00
0005435999276	19575	Business	124600.00
0005435488115	19575	Business	124600.00
0005435488097	19575	Business	124600.00
0005435999331	19575	Business	124600.00
0005435488114	19575	Business	124600.00
0005435488103	19575	Economy	41500.00
0005435488108	19575	Economy	41500.00
0005434309792	19575	Economy	41500.00
0005435488111	19575	Economy	41500.00
0005435488112	19575	Economy	41500.00
0005435297152	19575	Economy	41500.00
0005434309880	19575	Economy	41500.00
0005435999308	19575	Economy	41500.00
0005435297154	19575	Economy	41500.00
0005435297149	19575	Economy	41500.00
0005434309881	19575	Economy	41500.00
0005435999330	19575	Economy	41500.00
0005435488098	19575	Economy	41500.00
0005435999325	19575	Economy	41500.00
0005434309795	19575	Economy	41500.00
0005435297153	19575	Economy	41500.00
0005435999279	19575	Economy	41500.00
0005434309830	19575	Economy	45700.00
0005435999284	19575	Economy	45700.00
0005434309852	19575	Economy	45700.00
0005435488106	19575	Economy	41500.00
0005435488110	19575	Economy	41500.00
0005435488096	19575	Economy	41500.00
0005435297150	19575	Economy	41500.00
0005435999303	19575	Economy	41500.00
0005434309854	19575	Economy	41500.00
0005434309853	19575	Economy	41500.00
0005434309836	19575	Economy	41500.00
0005435999272	19575	Economy	41500.00
0005434309791	19575	Economy	41500.00
0005435488116	19575	Economy	41500.00
0005435297151	19575	Economy	41500.00
0005435999317	19575	Economy	41500.00
0005435999307	19575	Economy	41500.00
0005435488105	19575	Economy	41500.00
0005435488102	19575	Economy	41500.00
0005435488104	19575	Economy	41500.00
0005435999201	19575	Economy	41500.00
0005435488101	19575	Economy	41500.00
0005434309821	19575	Economy	41500.00
0005435999200	19575	Economy	41500.00
0005435488113	19575	Economy	41500.00
0005435488100	19575	Economy	41500.00
0005435999271	19575	Economy	41500.00
0005435488118	19575	Economy	41500.00
0005435488117	19575	Economy	41500.00
0005435999256	19575	Economy	41500.00
0005435999277	19575	Economy	41500.00
0005435488107	19575	Economy	41500.00
0005434309785	19575	Economy	41500.00
0005435488109	19575	Economy	41500.00
0005435999278	19575	Economy	41500.00
0005435488099	19575	Economy	41500.00
0005433158161	17555	Economy	12300.00
0005433158159	17555	Economy	12300.00
0005434446519	17555	Economy	12300.00
0005433158160	17555	Economy	12300.00
0005433158158	17555	Economy	12300.00
0005433158162	17555	Economy	12300.00
0005433186173	1576	Business	86000.00
0005433186146	1576	Business	86000.00
0005435518169	1576	Business	86000.00
0005435508510	1576	Business	86000.00
0005433186147	1576	Business	86000.00
0005435518159	1576	Business	86000.00
0005435502605	1576	Business	86000.00
0005435502606	1576	Business	86000.00
0005435518170	1576	Business	86000.00
0005433186165	1576	Business	86000.00
0005434566099	1576	Economy	28700.00
0005435502600	1576	Economy	28700.00
0005435518172	1576	Economy	28700.00
0005435518161	1576	Economy	28700.00
0005433186145	1576	Economy	28700.00
0005434566098	1576	Economy	28700.00
0005433186150	1576	Economy	28700.00
0005432291962	1576	Economy	28700.00
0005433186161	1576	Economy	28700.00
0005435518174	1576	Economy	31500.00
0005433186129	1576	Economy	31500.00
0005435502609	1576	Economy	31500.00
0005433186166	1576	Economy	31500.00
0005434566094	1576	Economy	28700.00
0005435502596	1576	Economy	28700.00
0005435502599	1576	Economy	28700.00
0005435502613	1576	Economy	28700.00
0005434566095	1576	Economy	28700.00
0005435502607	1576	Economy	28700.00
0005435502616	1576	Economy	28700.00
0005435518168	1576	Economy	28700.00
0005435502604	1576	Economy	28700.00
0005435502597	1576	Economy	28700.00
0005435502602	1576	Economy	28700.00
0005435508509	1576	Economy	28700.00
0005433186175	1576	Economy	28700.00
0005435502614	1576	Economy	28700.00
0005435518175	1576	Economy	28700.00
0005435508513	1576	Economy	28700.00
0005435502598	1576	Economy	28700.00
0005435518166	1576	Economy	28700.00
0005435502615	1576	Economy	28700.00
0005435502611	1576	Economy	28700.00
0005433186174	1576	Economy	28700.00
0005434566105	1576	Economy	28700.00
0005435502603	1576	Economy	28700.00
0005433186151	1576	Economy	28700.00
0005434566102	1576	Economy	28700.00
0005435502601	1576	Economy	28700.00
0005435518158	1576	Economy	28700.00
0005434566101	1576	Economy	28700.00
0005435518163	1576	Economy	28700.00
0005435508512	1576	Economy	28700.00
0005434566103	1576	Economy	28700.00
0005435518164	1576	Economy	28700.00
0005435518165	1576	Economy	28700.00
0005435518173	1576	Economy	28700.00
0005434566100	1576	Economy	28700.00
0005435502617	1576	Economy	28700.00
0005434566096	1576	Economy	28700.00
0005434566093	1576	Economy	28700.00
0005435508511	1576	Economy	28700.00
0005435518167	1576	Economy	28700.00
0005435508514	1576	Economy	28700.00
0005433186130	1576	Economy	28700.00
0005435518162	1576	Economy	28700.00
0005435518160	1576	Economy	28700.00
0005434566097	1576	Economy	28700.00
0005435518171	1576	Economy	28700.00
0005435502612	1576	Economy	28700.00
0005434566104	1576	Economy	28700.00
0005432291963	1576	Economy	28700.00
0005435502610	1576	Economy	28700.00
0005435502608	1576	Economy	28700.00
0005435529291	20865	Business	86000.00
0005435502345	20865	Business	86000.00
0005435545754	20865	Business	86000.00
0005435529382	20865	Business	86000.00
0005435545752	20865	Business	86000.00
0005435502435	20865	Business	86000.00
0005433186236	20865	Business	86000.00
0005435545783	20865	Business	86000.00
0005435529272	20865	Economy	28700.00
0005434565948	20865	Economy	28700.00
0005433186232	20865	Economy	28700.00
0005434566035	20865	Economy	28700.00
0005435502495	20865	Economy	28700.00
0005434565996	20865	Economy	28700.00
0005433186234	20865	Economy	28700.00
0005435529329	20865	Economy	28700.00
0005435529361	20865	Economy	31500.00
0005435529277	20865	Economy	31500.00
0005433186238	20865	Economy	31500.00
0005435502437	20865	Economy	31500.00
0005434566015	20865	Economy	31500.00
0005435529364	20865	Economy	28700.00
0005434565973	20865	Economy	28700.00
0005435529365	20865	Economy	28700.00
0005435529280	20865	Economy	28700.00
0005435529290	20865	Economy	28700.00
0005435502374	20865	Economy	28700.00
0005435529308	20865	Economy	28700.00
0005433186231	20865	Economy	28700.00
0005433186237	20865	Economy	28700.00
0005433186235	20865	Economy	28700.00
0005435502459	20865	Economy	28700.00
0005434565986	20865	Economy	28700.00
0005435545768	20865	Economy	28700.00
0005434565927	20865	Economy	28700.00
0005433186233	20865	Economy	28700.00
0005435545780	20865	Economy	28700.00
0005435502349	20865	Economy	28700.00
0005434565974	20865	Economy	28700.00
0005435502338	20865	Economy	28700.00
0005435502342	20865	Economy	28700.00
0005435502460	20865	Economy	28700.00
0005435529300	20865	Economy	28700.00
0005435529309	20865	Economy	28700.00
0005434566001	20865	Economy	28700.00
0005435502346	20865	Economy	28700.00
0005435502406	20865	Economy	28700.00
0005434565946	20865	Economy	28700.00
0005434566036	20865	Economy	28700.00
0005434565926	20865	Economy	28700.00
0005435502494	20865	Economy	28700.00
0005433186239	20865	Economy	28700.00
0005435545748	20865	Economy	28700.00
0005435502485	20865	Economy	28700.00
0005435545769	20865	Economy	28700.00
0005435529279	20865	Economy	28700.00
0005435529336	20865	Economy	28700.00
0005434565959	20865	Economy	28700.00
0005435545753	20865	Economy	28700.00
0005435529337	20865	Economy	28700.00
0005435529386	20865	Economy	28700.00
0005434565895	20865	Economy	28700.00
0005434566000	20865	Economy	28700.00
0005435529326	20865	Economy	28700.00
0005435502402	20865	Economy	28700.00
0005435502341	20865	Economy	28700.00
0005435545781	20865	Economy	28700.00
0005434565947	20865	Economy	28700.00
0005435529360	20865	Economy	28700.00
0005434565960	20865	Economy	28700.00
0005435502420	20865	Economy	28700.00
0005435502291	20865	Economy	28700.00
0005434565896	20865	Economy	28700.00
0005435153829	3904	Economy	19700.00
0005435153833	3904	Economy	19700.00
0005435153834	3904	Economy	19700.00
0005435931616	3904	Economy	19700.00
0005435931618	3904	Economy	19700.00
0005435931604	3904	Economy	19700.00
0005435153832	3904	Economy	19700.00
0005435931611	3904	Economy	19700.00
0005435153835	3904	Economy	19700.00
0005435153831	3904	Economy	19700.00
0005435153830	3904	Economy	19700.00
0005435931631	3904	Economy	19700.00
0005435153754	21878	Economy	19700.00
0005435931652	21878	Economy	19700.00
0005435931650	21878	Economy	19700.00
0005435153755	21878	Economy	19700.00
0005435931651	21878	Economy	19700.00
0005435931653	21878	Economy	19700.00
0005435153798	21878	Economy	19700.00
0005435153805	21878	Economy	19700.00
0005435153763	21878	Economy	19700.00
0005435153799	21878	Economy	19700.00
0005435225611	7187	Economy	14300.00
0005435225612	7187	Economy	14300.00
0005432629052	7187	Economy	13000.00
0005432629055	7187	Economy	13000.00
0005432629047	7187	Economy	13000.00
0005432629048	7187	Economy	13000.00
0005432629046	7187	Economy	13000.00
0005432629054	7187	Economy	13000.00
0005432629042	7187	Economy	13000.00
0005435225616	7187	Economy	13000.00
0005432629044	7187	Economy	13000.00
0005432629050	7187	Economy	13000.00
0005432629051	7187	Economy	13000.00
0005432629043	7187	Economy	13000.00
0005435225650	7187	Economy	13000.00
0005432629053	7187	Economy	13000.00
0005435225610	7187	Economy	13000.00
0005432629041	7187	Economy	13000.00
0005435225608	7187	Economy	13000.00
0005432629049	7187	Economy	13000.00
0005432629045	7187	Economy	13000.00
0005432628969	28094	Economy	14300.00
0005432628918	28094	Economy	14300.00
0005432628950	28094	Economy	13000.00
0005432628911	28094	Economy	13000.00
0005432628930	28094	Economy	13000.00
0005435225692	28094	Economy	13000.00
0005432629010	28094	Economy	13000.00
0005435225695	28094	Economy	13000.00
0005432628968	28094	Economy	13000.00
0005435225696	28094	Economy	13000.00
0005432628917	28094	Economy	13000.00
0005435225691	28094	Economy	13000.00
0005432628960	28094	Economy	13000.00
0005432628985	28094	Economy	13000.00
0005432628945	28094	Economy	13000.00
0005435225690	28094	Economy	13000.00
0005432628931	28094	Economy	13000.00
0005432628944	28094	Economy	13000.00
0005435225697	28094	Economy	13000.00
0005432628959	28094	Economy	13000.00
0005432628949	28094	Economy	13000.00
0005432628929	28094	Economy	13000.00
0005432628978	28094	Economy	13000.00
0005432628928	28094	Economy	13000.00
0005435225693	28094	Economy	13000.00
0005435225694	28094	Economy	13000.00
0005432628904	28094	Economy	13000.00
0005432628984	28094	Economy	13000.00
0005435960102	8740	Economy	10500.00
0005434267963	8740	Economy	10500.00
0005435960103	8740	Economy	10500.00
0005434267951	8740	Economy	10500.00
0005434267954	8740	Economy	10500.00
0005435960104	8740	Economy	10500.00
0005434267965	8740	Economy	10500.00
0005435960100	8740	Economy	10500.00
0005435960101	8740	Economy	10500.00
0005434268002	15221	Economy	11500.00
0005435960079	15221	Economy	11500.00
0005434268001	15221	Economy	10500.00
0005435960078	15221	Economy	10500.00
0005435960074	15221	Economy	10500.00
0005434268004	15221	Economy	10500.00
0005435960070	15221	Economy	10500.00
0005435960077	15221	Economy	10500.00
0005434268000	15221	Economy	10500.00
0005435960071	15221	Economy	10500.00
0005435960082	15221	Economy	10500.00
0005434268003	15221	Economy	10500.00
0005432873324	1201	Business	115000.00
0005432693460	1201	Business	115000.00
0005432693462	1201	Business	115000.00
0005432675345	1201	Business	115000.00
0005432675335	1201	Business	115000.00
0005432693473	1201	Business	115000.00
0005432693466	1201	Business	115000.00
0005432675339	1201	Business	115000.00
0005432693467	1201	Business	115000.00
0005432693455	1201	Economy	38300.00
0005432693464	1201	Economy	38300.00
0005432693457	1201	Economy	38300.00
0005432693459	1201	Economy	38300.00
0005432675344	1201	Economy	38300.00
0005432873323	1201	Economy	38300.00
0005432675334	1201	Economy	42200.00
0005432677621	1201	Economy	42200.00
0005432693446	1201	Economy	42200.00
0005432693449	1201	Economy	38300.00
0005432693442	1201	Economy	38300.00
0005432675338	1201	Economy	38300.00
0005432693451	1201	Economy	38300.00
0005432675342	1201	Economy	38300.00
0005432675332	1201	Economy	38300.00
0005432693447	1201	Economy	38300.00
0005432675337	1201	Economy	38300.00
0005432675331	1201	Economy	38300.00
0005432693461	1201	Economy	38300.00
0005432693444	1201	Economy	38300.00
0005432693456	1201	Economy	38300.00
0005432873337	1201	Economy	38300.00
0005432675343	1201	Economy	38300.00
0005432677622	1201	Economy	38300.00
0005432693470	1201	Economy	38300.00
0005432693471	1201	Economy	38300.00
0005432693450	1201	Economy	38300.00
0005432693468	1201	Economy	38300.00
0005432675346	1201	Economy	38300.00
0005432693445	1201	Economy	38300.00
0005432675347	1201	Economy	38300.00
0005432693463	1201	Economy	38300.00
0005432677624	1201	Economy	38300.00
0005432675333	1201	Economy	38300.00
0005432675330	1201	Economy	38300.00
0005432675341	1201	Economy	38300.00
0005432693472	1201	Economy	38300.00
0005432675340	1201	Economy	38300.00
0005432677623	1201	Economy	38300.00
0005432693448	1201	Economy	38300.00
0005432693452	1201	Economy	38300.00
0005432693469	1201	Economy	38300.00
0005432693453	1201	Economy	38300.00
0005432675336	1201	Economy	38300.00
0005432693443	1201	Economy	38300.00
0005432693458	1201	Economy	38300.00
0005432873321	1201	Economy	38300.00
0005432693454	1201	Economy	38300.00
0005432693465	1201	Economy	38300.00
0005432677600	17493	Business	115000.00
0005432693197	17493	Business	115000.00
0005432675198	17493	Business	115000.00
0005432693071	17493	Business	115000.00
0005432873391	17493	Business	115000.00
0005432693064	17493	Business	115000.00
0005432693339	17493	Business	115000.00
0005432693337	17493	Business	115000.00
0005432693055	17493	Business	115000.00
0005432693056	17493	Business	115000.00
0005432693017	17493	Business	115000.00
0005432693174	17493	Business	115000.00
0005432693199	17493	Business	115000.00
0005432693282	17493	Economy	38300.00
0005432693201	17493	Economy	38300.00
0005432693336	17493	Economy	38300.00
0005432693228	17493	Economy	38300.00
0005432677573	17493	Economy	38300.00
0005432693254	17493	Economy	42200.00
0005432693184	17493	Economy	42200.00
0005432693119	17493	Economy	42200.00
0005432693126	17493	Economy	38300.00
0005432693239	17493	Economy	38300.00
0005432693125	17493	Economy	38300.00
0005432693124	17493	Economy	38300.00
0005432873388	17493	Economy	38300.00
0005432677603	17493	Economy	38300.00
0005432693255	17493	Economy	38300.00
0005432675193	17493	Economy	38300.00
0005432675199	17493	Economy	38300.00
0005432693146	17493	Economy	38300.00
0005432693283	17493	Economy	38300.00
0005432677601	17493	Economy	38300.00
0005432693200	17493	Economy	38300.00
0005432675200	17493	Economy	38300.00
0005432677598	17493	Economy	38300.00
0005432873390	17493	Economy	38300.00
0005432693227	17493	Economy	38300.00
0005432675241	17493	Economy	38300.00
0005432693059	17493	Economy	38300.00
0005432675216	17493	Economy	38300.00
0005432675224	17493	Economy	38300.00
0005432693162	17493	Economy	38300.00
0005432693198	17493	Economy	38300.00
0005432677590	17493	Economy	38300.00
0005432693193	17493	Economy	38300.00
0005432677599	17493	Economy	38300.00
0005432693016	17493	Economy	38300.00
0005432693290	17493	Economy	38300.00
0005432873387	17493	Economy	38300.00
0005432693145	17493	Economy	38300.00
0005432873386	17493	Economy	38300.00
0005432693075	17493	Economy	38300.00
0005432693120	17493	Economy	38300.00
0005432873385	17493	Economy	38300.00
0005432873389	17493	Economy	38300.00
0005432675202	17493	Economy	38300.00
0005432693240	17493	Economy	38300.00
0005432693325	17493	Economy	38300.00
0005434435396	1103	Economy	15200.00
0005434435394	1103	Economy	15200.00
0005434435397	1103	Economy	15200.00
0005433156791	1103	Economy	13900.00
0005434435388	1103	Economy	13900.00
0005434435390	1103	Economy	13900.00
0005433156825	1103	Economy	13900.00
0005434435391	1103	Economy	13900.00
0005434435392	1103	Economy	13900.00
0005433156829	1103	Economy	13900.00
0005434435386	1103	Economy	13900.00
0005433156792	1103	Economy	13900.00
0005434435385	1103	Economy	13900.00
0005433156808	1103	Economy	13900.00
0005434435389	1103	Economy	13900.00
0005434435387	1103	Economy	13900.00
0005434435398	1103	Economy	13900.00
0005434435393	1103	Economy	13900.00
0005433156797	1103	Economy	13900.00
0005433156827	1103	Economy	13900.00
0005433156775	1103	Economy	13900.00
0005433156796	1103	Economy	13900.00
0005434435384	1103	Economy	13900.00
0005434435395	1103	Economy	13900.00
0005434435399	1103	Economy	13900.00
0005433156790	1103	Economy	13900.00
0005434435383	1103	Economy	13900.00
0005433156864	17288	Economy	15200.00
0005433156870	17288	Economy	13900.00
0005434435280	17288	Economy	13900.00
0005433156869	17288	Economy	13900.00
0005434435248	17288	Economy	13900.00
0005434435226	17288	Economy	13900.00
0005433156868	17288	Economy	13900.00
0005434435212	17288	Economy	13900.00
0005434435231	17288	Economy	13900.00
0005433156866	17288	Economy	13900.00
0005433156867	17288	Economy	13900.00
0005434435191	17288	Economy	13900.00
0005434435253	17288	Economy	13900.00
0005434435281	17288	Economy	13900.00
0005433156862	17288	Economy	13900.00
0005434435270	17288	Economy	13900.00
0005433156865	17288	Economy	13900.00
0005434435252	17288	Economy	13900.00
0005433156863	17288	Economy	13900.00
0005434435211	17288	Economy	13900.00
0005435086938	4048	Economy	8200.00
0005435086936	4048	Economy	7500.00
0005435086937	4048	Economy	7500.00
0005435928158	4048	Economy	7500.00
0005435928156	4048	Economy	7500.00
0005435086935	4048	Economy	7500.00
0005435928165	4048	Economy	7500.00
0005435086939	4048	Economy	7500.00
0005435928157	4048	Economy	7500.00
0005435928164	4048	Economy	7500.00
0005435086940	4048	Economy	7500.00
0005435086880	24438	Economy	7500.00
0005435086851	24438	Economy	7500.00
0005435928212	24438	Economy	7500.00
0005435086852	24438	Economy	7500.00
0005435086894	24438	Economy	7500.00
0005435086855	24438	Economy	7500.00
0005435086881	24438	Economy	7500.00
0005435928207	24438	Economy	7500.00
0005435086882	24438	Economy	7500.00
0005435928209	24438	Economy	7500.00
0005435928208	24438	Economy	7500.00
0005435086867	24438	Economy	7500.00
0005435928211	24438	Economy	7500.00
0005435928206	24438	Economy	7500.00
0005435928210	24438	Economy	7500.00
0005435086856	24438	Economy	7500.00
0005435706601	2461	Business	86800.00
0005435706573	2461	Business	86800.00
0005435706570	2461	Business	86800.00
0005433373532	2461	Business	86800.00
0005433373598	2461	Business	86800.00
0005433373569	2461	Business	86800.00
0005433373534	2461	Business	86800.00
0005433373545	2461	Business	86800.00
0005435706568	2461	Business	86800.00
0005435706609	2461	Business	86800.00
0005433373571	2461	Business	86800.00
0005435706586	2461	Economy	28900.00
0005435706587	2461	Economy	28900.00
0005433373553	2461	Economy	28900.00
0005433373567	2461	Economy	28900.00
0005435706602	2461	Economy	28900.00
0005433373508	2461	Economy	28900.00
0005433373518	2461	Economy	28900.00
0005435706610	2461	Economy	28900.00
0005435706604	2461	Economy	28900.00
0005435706597	2461	Economy	31800.00
0005435706583	2461	Economy	31800.00
0005435706599	2461	Economy	28900.00
0005435706607	2461	Economy	28900.00
0005435706593	2461	Economy	28900.00
0005435706580	2461	Economy	28900.00
0005435706592	2461	Economy	28900.00
0005435706611	2461	Economy	28900.00
0005433373544	2461	Economy	28900.00
0005433373556	2461	Economy	28900.00
0005433373507	2461	Economy	28900.00
0005435706576	2461	Economy	28900.00
0005435706600	2461	Economy	28900.00
0005435706585	2461	Economy	28900.00
0005433373542	2461	Economy	28900.00
0005435706581	2461	Economy	28900.00
0005435706596	2461	Economy	28900.00
0005433373533	2461	Economy	28900.00
0005435706577	2461	Economy	28900.00
0005435706605	2461	Economy	28900.00
0005435706578	2461	Economy	28900.00
0005435706598	2461	Economy	28900.00
0005433373566	2461	Economy	28900.00
0005435706584	2461	Economy	28900.00
0005435706614	2461	Economy	28900.00
0005435706613	2461	Economy	28900.00
0005433373543	2461	Economy	28900.00
0005435706574	2461	Economy	28900.00
0005435706569	2461	Economy	28900.00
0005435706572	2461	Economy	28900.00
0005433373561	2461	Economy	28900.00
0005435706590	2461	Economy	28900.00
0005433373557	2461	Economy	28900.00
0005435706579	2461	Economy	28900.00
0005435706612	2461	Economy	28900.00
0005435706595	2461	Economy	28900.00
0005433373549	2461	Economy	28900.00
0005435706615	2461	Economy	28900.00
0005435706591	2461	Economy	28900.00
0005435706588	2461	Economy	28900.00
0005433373580	2461	Economy	28900.00
0005435706575	2461	Economy	28900.00
0005433373550	2461	Economy	28900.00
0005435706608	2461	Economy	28900.00
0005435706594	2461	Economy	28900.00
0005433373585	2461	Economy	28900.00
0005435706606	2461	Economy	28900.00
0005433373583	2461	Economy	28900.00
0005433373587	2461	Economy	28900.00
0005435706582	2461	Economy	28900.00
0005435706589	2461	Economy	28900.00
0005433373586	2461	Economy	28900.00
0005435706571	2461	Economy	28900.00
0005433373570	2461	Economy	28900.00
0005433373596	2461	Economy	28900.00
0005433373568	2461	Economy	28900.00
0005435706603	2461	Economy	28900.00
0005433373581	2461	Economy	28900.00
0005433373597	2461	Economy	28900.00
0005435706616	2461	Economy	28900.00
0005433373656	27028	Business	86800.00
0005435706420	27028	Business	86800.00
0005433373651	27028	Business	86800.00
0005433373640	27028	Business	86800.00
0005433373643	27028	Business	86800.00
0005433373649	27028	Business	86800.00
0005433373658	27028	Economy	28900.00
0005433373637	27028	Economy	28900.00
0005435706429	27028	Economy	28900.00
0005435706502	27028	Economy	28900.00
0005435706433	27028	Economy	28900.00
0005435706434	27028	Economy	28900.00
0005435706377	27028	Economy	28900.00
0005435706418	27028	Economy	31800.00
0005435706440	27028	Economy	31800.00
0005433373662	27028	Economy	31800.00
0005433373638	27028	Economy	28900.00
0005433373660	27028	Economy	28900.00
0005435706421	27028	Economy	28900.00
0005435706511	27028	Economy	28900.00
0005433373657	27028	Economy	28900.00
0005435706353	27028	Economy	28900.00
0005433373648	27028	Economy	28900.00
0005433373646	27028	Economy	28900.00
0005433373639	27028	Economy	28900.00
0005433373645	27028	Economy	28900.00
0005435706374	27028	Economy	28900.00
0005435706441	27028	Economy	28900.00
0005435706512	27028	Economy	28900.00
0005435706388	27028	Economy	28900.00
0005433373641	27028	Economy	28900.00
0005433373661	27028	Economy	28900.00
0005433373650	27028	Economy	28900.00
0005433373655	27028	Economy	28900.00
0005433373642	27028	Economy	28900.00
0005435706411	27028	Economy	28900.00
0005435706468	27028	Economy	28900.00
0005435706348	27028	Economy	28900.00
0005435706359	27028	Economy	28900.00
0005435706422	27028	Economy	28900.00
0005433373644	27028	Economy	28900.00
0005435706490	27028	Economy	28900.00
0005435706435	27028	Economy	28900.00
0005435706405	27028	Economy	28900.00
0005433373652	27028	Economy	28900.00
0005435706439	27028	Economy	28900.00
0005433373659	27028	Economy	28900.00
0005433373647	27028	Economy	28900.00
0005435706362	27028	Economy	28900.00
0005435706419	27028	Economy	28900.00
0005433373653	27028	Economy	28900.00
0005435706510	27028	Economy	28900.00
0005435706499	27028	Economy	28900.00
0005435706417	27028	Economy	28900.00
0005435706349	27028	Economy	28900.00
0005435706395	27028	Economy	28900.00
0005433373654	27028	Economy	28900.00
0005435706416	27028	Economy	28900.00
0005435706438	27028	Economy	28900.00
0005435706489	27028	Economy	28900.00
0005434626087	4875	Economy	16200.00
0005434626091	4875	Economy	14700.00
0005434626089	4875	Economy	14700.00
0005434626086	4875	Economy	14700.00
0005434626093	4875	Economy	14700.00
0005435907526	4875	Economy	14700.00
0005434626088	4875	Economy	14700.00
0005434626090	4875	Economy	14700.00
0005434626094	4875	Economy	14700.00
0005434626085	4875	Economy	14700.00
0005434626092	4875	Economy	14700.00
0005434626017	32937	Business	44200.00
0005435907570	32937	Economy	16200.00
0005435907573	32937	Economy	14700.00
0005435907571	32937	Economy	14700.00
0005435907569	32937	Economy	14700.00
0005435907572	32937	Economy	14700.00
0005435785411	13747	Economy	3400.00
0005435785512	13747	Economy	3400.00
0005435785538	13747	Economy	3400.00
0005435785497	13747	Economy	3400.00
0005435785407	13747	Economy	3100.00
0005435785322	13747	Economy	3100.00
0005435785489	13747	Economy	3100.00
0005435785511	13747	Economy	3100.00
0005435785428	13747	Economy	3100.00
0005435785533	13747	Economy	3100.00
0005435787361	13747	Economy	3100.00
0005435785386	13747	Economy	3100.00
0005435785532	13747	Economy	3100.00
0005435785535	13747	Economy	3100.00
0005435785427	13747	Economy	3100.00
0005435785579	13747	Economy	3100.00
0005435785498	13747	Economy	3100.00
0005435785518	13747	Economy	3100.00
0005435785617	13747	Economy	3100.00
0005435785314	13747	Economy	3100.00
0005432195721	13747	Economy	3100.00
0005435785440	13747	Economy	3100.00
0005435785326	13747	Economy	3100.00
0005432195722	13747	Economy	3100.00
0005432195724	13747	Economy	3100.00
0005432195723	13747	Economy	3100.00
0005435785448	13747	Economy	3100.00
0005435785513	13747	Economy	3100.00
0005435785362	13747	Economy	3100.00
0005435785406	13747	Economy	3100.00
0005435787354	13747	Economy	3100.00
0005435785450	13747	Economy	3100.00
0005435785584	13747	Economy	3100.00
0005435785519	13747	Economy	3100.00
0005435787362	13747	Economy	3100.00
0005435785514	13747	Economy	3100.00
0005435785515	13747	Economy	3100.00
0005435785385	13747	Economy	3100.00
0005435785378	13747	Economy	3100.00
0005435937440	13747	Economy	3100.00
0005435785335	13747	Economy	3100.00
0005435785536	13747	Economy	3100.00
0005435785336	13747	Economy	3100.00
0005435785506	13747	Economy	3100.00
0005435785321	13747	Economy	3100.00
0005435785338	13747	Economy	3100.00
0005435785505	13747	Economy	3100.00
0005435785572	13747	Economy	3100.00
0005435785502	13747	Economy	3100.00
0005435785788	27447	Economy	3400.00
0005435785785	27447	Economy	3400.00
0005435785783	27447	Economy	3400.00
0005435785770	27447	Economy	3100.00
0005435785790	27447	Economy	3100.00
0005435785773	27447	Economy	3100.00
0005435785784	27447	Economy	3100.00
0005435785771	27447	Economy	3100.00
0005435785789	27447	Economy	3100.00
0005435785777	27447	Economy	3100.00
0005435785756	27447	Economy	3100.00
0005435785764	27447	Economy	3100.00
0005435785769	27447	Economy	3100.00
0005435785758	27447	Economy	3100.00
0005435785786	27447	Economy	3100.00
0005435785761	27447	Economy	3100.00
0005435785766	27447	Economy	3100.00
0005435937395	27447	Economy	3100.00
0005435785765	27447	Economy	3100.00
0005435785781	27447	Economy	3100.00
0005435785760	27447	Economy	3100.00
0005435785776	27447	Economy	3100.00
0005435785768	27447	Economy	3100.00
0005435785763	27447	Economy	3100.00
0005435785767	27447	Economy	3100.00
0005435785774	27447	Economy	3100.00
0005435787380	27447	Economy	3100.00
0005435785757	27447	Economy	3100.00
0005435785780	27447	Economy	3100.00
0005432190676	27447	Economy	3100.00
0005435785778	27447	Economy	3100.00
0005435785782	27447	Economy	3100.00
0005435785759	27447	Economy	3100.00
0005435787381	27447	Economy	3100.00
0005432190677	27447	Economy	3100.00
0005435785787	27447	Economy	3100.00
0005435785762	27447	Economy	3100.00
0005435785775	27447	Economy	3100.00
0005435785772	27447	Economy	3100.00
0005432190675	27447	Economy	3100.00
0005435785779	27447	Economy	3100.00
0005434408279	20302	Business	12000.00
0005434408018	20302	Business	12000.00
0005434407924	20302	Business	12000.00
0005434407719	20302	Business	12000.00
0005434408226	20302	Business	12000.00
0005434408095	20302	Business	12000.00
0005434408160	20302	Business	12000.00
0005434408207	20302	Business	12000.00
0005434408217	20302	Business	12000.00
0005434408152	20302	Business	12000.00
0005434408006	20302	Business	12000.00
0005434408175	20302	Economy	4000.00
0005434408028	20302	Economy	4000.00
0005434408126	20302	Economy	4000.00
0005435311236	20302	Economy	4000.00
0005434408005	20302	Economy	4000.00
0005434407975	20302	Economy	4000.00
0005435311232	20302	Economy	4000.00
0005434408076	20302	Economy	4000.00
0005434408135	20302	Economy	4000.00
0005434407830	20302	Economy	4400.00
0005434408019	20302	Economy	4400.00
0005434407831	20302	Economy	4400.00
0005435311233	20302	Economy	4400.00
0005435311230	20302	Economy	4400.00
0005435311228	20302	Economy	4000.00
0005434408306	20302	Economy	4000.00
0005432058436	20302	Economy	4000.00
0005432058434	20302	Economy	4000.00
0005434407752	20302	Economy	4000.00
0005434407865	20302	Economy	4000.00
0005434408014	20302	Economy	4000.00
0005434408139	20302	Economy	4000.00
0005434408159	20302	Economy	4000.00
0005434407570	20302	Economy	4000.00
0005434408161	20302	Economy	4000.00
0005432058433	20302	Economy	4000.00
0005435311229	20302	Economy	4000.00
0005434408099	20302	Economy	4000.00
0005434408112	20302	Economy	4000.00
0005435311231	20302	Economy	4000.00
0005434408224	20302	Economy	4000.00
0005435311226	20302	Economy	4000.00
0005434408049	20302	Economy	4000.00
0005435311235	20302	Economy	4000.00
0005434408286	20302	Economy	4000.00
0005434407937	20302	Economy	4000.00
0005434408103	20302	Economy	4000.00
0005434408100	20302	Economy	4000.00
0005434407720	20302	Economy	4000.00
0005434408020	20302	Economy	4000.00
0005434407888	20302	Economy	4000.00
0005434407923	20302	Economy	4000.00
0005434407995	20302	Economy	4000.00
0005434408225	20302	Economy	4000.00
0005434407922	20302	Economy	4000.00
0005434408102	20302	Economy	4000.00
0005434408275	20302	Economy	4000.00
0005432058435	20302	Economy	4000.00
0005434407721	20302	Economy	4000.00
0005434408153	20302	Economy	4000.00
0005434407948	20302	Economy	4000.00
0005434407866	20302	Economy	4000.00
0005434407870	20302	Economy	4000.00
0005434408130	20302	Economy	4000.00
0005434408027	20302	Economy	4000.00
0005434407966	20302	Economy	4000.00
0005434408166	20302	Economy	4000.00
0005434408117	20302	Economy	4000.00
0005434408004	20302	Economy	4000.00
0005434407659	20302	Economy	4000.00
0005434407769	20302	Economy	4000.00
0005434407891	20302	Economy	4000.00
0005434407871	20302	Economy	4000.00
0005434408073	20302	Economy	4000.00
0005434408044	20302	Economy	4000.00
0005434407883	20302	Economy	4000.00
0005435311234	20302	Economy	4000.00
0005434408276	20302	Economy	4000.00
0005434407886	20302	Economy	4000.00
0005434408070	20302	Economy	4000.00
0005435311227	20302	Economy	4000.00
0005434407974	20302	Economy	4000.00
0005434407887	20302	Economy	4000.00
0005434407864	20302	Economy	4000.00
0005434407867	20302	Economy	4000.00
0005432154033	26993	Business	12000.00
0005434408586	26993	Business	12000.00
0005434408580	26993	Business	12000.00
0005434408594	26993	Business	12000.00
0005434408618	26993	Business	12000.00
0005434408640	26993	Business	12000.00
0005434408631	26993	Business	12000.00
0005434408613	26993	Business	12000.00
0005432154029	26993	Business	12000.00
0005432154030	26993	Business	12000.00
0005434408632	26993	Business	12000.00
0005434408616	26993	Economy	4000.00
0005434408588	26993	Economy	4000.00
0005434408589	26993	Economy	4000.00
0005434408583	26993	Economy	4000.00
0005434408597	26993	Economy	4000.00
0005434408625	26993	Economy	4000.00
0005435311067	26993	Economy	4000.00
0005434408607	26993	Economy	4000.00
0005434408627	26993	Economy	4000.00
0005435311072	26993	Economy	4000.00
0005435311111	26993	Economy	4400.00
0005434408620	26993	Economy	4400.00
0005434408614	26993	Economy	4400.00
0005435311028	26993	Economy	4400.00
0005434408628	26993	Economy	4000.00
0005435311089	26993	Economy	4000.00
0005434408605	26993	Economy	4000.00
0005434408612	26993	Economy	4000.00
0005434408596	26993	Economy	4000.00
0005434408636	26993	Economy	4000.00
0005435311073	26993	Economy	4000.00
0005434408637	26993	Economy	4000.00
0005434408608	26993	Economy	4000.00
0005434408590	26993	Economy	4000.00
0005434408577	26993	Economy	4000.00
0005434408599	26993	Economy	4000.00
0005432154031	26993	Economy	4000.00
0005435311103	26993	Economy	4000.00
0005434408639	26993	Economy	4000.00
0005434408598	26993	Economy	4000.00
0005434408634	26993	Economy	4000.00
0005434408579	26993	Economy	4000.00
0005434408604	26993	Economy	4000.00
0005435311104	26993	Economy	4000.00
0005434408630	26993	Economy	4000.00
0005434408593	26993	Economy	4000.00
0005434408610	26993	Economy	4000.00
0005434408626	26993	Economy	4000.00
0005434408592	26993	Economy	4000.00
0005434408633	26993	Economy	4000.00
0005434408578	26993	Economy	4000.00
0005434408619	26993	Economy	4000.00
0005435311093	26993	Economy	4000.00
0005434408617	26993	Economy	4000.00
0005434408600	26993	Economy	4000.00
0005435311090	26993	Economy	4000.00
0005434408622	26993	Economy	4000.00
0005434408606	26993	Economy	4000.00
0005434408635	26993	Economy	4000.00
0005434408638	26993	Economy	4000.00
0005434408582	26993	Economy	4000.00
0005434408629	26993	Economy	4000.00
0005434408623	26993	Economy	4000.00
0005434408615	26993	Economy	4000.00
0005435311027	26993	Economy	4000.00
0005435311071	26993	Economy	4000.00
0005434408595	26993	Economy	4000.00
0005434408609	26993	Economy	4000.00
0005434408587	26993	Economy	4000.00
0005432154032	26993	Economy	4000.00
0005435311110	26993	Economy	4000.00
0005435311066	26993	Economy	4000.00
0005435311099	26993	Economy	4000.00
0005434408591	26993	Economy	4000.00
0005432154034	26993	Economy	4000.00
0005434408602	26993	Economy	4000.00
0005434408624	26993	Economy	4000.00
0005434408611	26993	Economy	4000.00
0005434408584	26993	Economy	4000.00
0005432154035	26993	Economy	4000.00
0005434408621	26993	Economy	4000.00
0005434408581	26993	Economy	4000.00
0005434408601	26993	Economy	4000.00
0005434408585	26993	Economy	4000.00
0005434408603	26993	Economy	4000.00
0005432109741	5721	Business	43300.00
0005433124012	5721	Business	43300.00
0005434319583	5721	Business	43300.00
0005434319589	5721	Business	43300.00
0005434319586	5721	Business	43300.00
0005434319602	5721	Business	43300.00
0005434319596	5721	Business	43300.00
0005434319601	5721	Business	43300.00
0005433123940	5721	Economy	14400.00
0005434319590	5721	Economy	14400.00
0005434319594	5721	Economy	14400.00
0005433123871	5721	Economy	14400.00
0005434319592	5721	Economy	14400.00
0005433124063	5721	Economy	14400.00
0005433124001	5721	Economy	15900.00
0005433123991	5721	Economy	15900.00
0005434319585	5721	Economy	14400.00
0005433123996	5721	Economy	14400.00
0005432109740	5721	Economy	14400.00
0005433124064	5721	Economy	14400.00
0005434319591	5721	Economy	14400.00
0005434319599	5721	Economy	14400.00
0005434311245	5721	Economy	14400.00
0005434311244	5721	Economy	14400.00
0005434319600	5721	Economy	14400.00
0005433123941	5721	Economy	14400.00
0005434319588	5721	Economy	14400.00
0005434319595	5721	Economy	14400.00
0005434319593	5721	Economy	14400.00
0005434319587	5721	Economy	14400.00
0005434311246	5721	Economy	14400.00
0005433124013	5721	Economy	14400.00
0005433123924	5721	Economy	14400.00
0005432109739	5721	Economy	14400.00
0005434319584	5721	Economy	14400.00
0005432109742	5721	Economy	14400.00
0005433124002	5721	Economy	14400.00
0005433123954	5721	Economy	14400.00
0005434319597	5721	Economy	14400.00
0005434319598	5721	Economy	14400.00
0005433123990	5721	Economy	14400.00
0005433123955	5721	Economy	14400.00
0005433124202	15675	Business	43300.00
0005433124213	15675	Business	43300.00
0005433124216	15675	Business	43300.00
0005434319467	15675	Business	43300.00
0005433124205	15675	Business	43300.00
0005434319494	15675	Economy	14400.00
0005433124204	15675	Economy	14400.00
0005433124215	15675	Economy	14400.00
0005433124211	15675	Economy	14400.00
0005434319505	15675	Economy	14400.00
0005434311231	15675	Economy	15900.00
0005433124206	15675	Economy	14400.00
0005433124214	15675	Economy	14400.00
0005433124212	15675	Economy	14400.00
0005434311226	15675	Economy	14400.00
0005433124217	15675	Economy	14400.00
0005434319457	15675	Economy	14400.00
0005434319431	15675	Economy	14400.00
0005434319413	15675	Economy	14400.00
0005433124208	15675	Economy	14400.00
0005433124207	15675	Economy	14400.00
0005434311227	15675	Economy	14400.00
0005434311236	15675	Economy	14400.00
0005434319503	15675	Economy	14400.00
0005433124209	15675	Economy	14400.00
0005434319408	15675	Economy	14400.00
0005434319434	15675	Economy	14400.00
0005434311235	15675	Economy	14400.00
0005434319455	15675	Economy	14400.00
0005434319502	15675	Economy	14400.00
0005434311228	15675	Economy	14400.00
0005433124203	15675	Economy	14400.00
0005434319423	15675	Economy	14400.00
0005434319475	15675	Economy	14400.00
0005434319478	15675	Economy	14400.00
0005433124210	15675	Economy	14400.00
0005434312319	15675	Economy	14400.00
0005434319401	15675	Economy	14400.00
0005434319525	15675	Economy	14400.00
0005433124218	15675	Economy	14400.00
0005434311232	15675	Economy	14400.00
0005434319506	15675	Economy	14400.00
0005434319499	15675	Economy	14400.00
0005435219230	31752	Economy	15500.00
0005435220347	31752	Economy	15500.00
0005435220349	31752	Economy	15500.00
0005435219227	31752	Economy	15500.00
0005435220348	31752	Economy	15500.00
0005435219229	31752	Economy	15500.00
0005435220346	31752	Economy	15500.00
0005435219228	31752	Economy	15500.00
0005434484434	8960	Economy	27400.00
0005434189204	8960	Economy	24900.00
0005434484437	8960	Economy	24900.00
0005434484436	8960	Economy	24900.00
0005434189220	8960	Economy	24900.00
0005434484439	8960	Economy	24900.00
0005434189219	8960	Economy	24900.00
0005434189180	8960	Economy	24900.00
0005434484438	8960	Economy	24900.00
0005434189179	8960	Economy	24900.00
0005434484435	8960	Economy	24900.00
0005434189218	8960	Economy	24900.00
0005434484433	8960	Economy	24900.00
0005434484367	16622	Economy	27400.00
0005434189257	16622	Economy	27400.00
0005434484355	16622	Economy	24900.00
0005434484366	16622	Economy	24900.00
0005434484335	16622	Economy	24900.00
0005434484391	16622	Economy	24900.00
0005434484379	16622	Economy	24900.00
0005434484381	16622	Economy	24900.00
0005434189254	16622	Economy	24900.00
0005434484374	16622	Economy	24900.00
0005434189256	16622	Economy	24900.00
0005434189258	16622	Economy	24900.00
0005434189253	16622	Economy	24900.00
0005434189255	16622	Economy	24900.00
0005434484373	16622	Economy	24900.00
0005434484378	16622	Economy	24900.00
0005433124206	7680	Business	11100.00
0005433124209	7680	Business	11100.00
0005433722232	7680	Business	11100.00
0005433722246	7680	Business	11100.00
0005433124205	7680	Business	11100.00
0005433124203	7680	Business	11100.00
0005433722255	7680	Economy	3700.00
0005433722276	7680	Economy	3700.00
0005433722241	7680	Economy	4100.00
0005433722274	7680	Economy	4100.00
0005433124202	7680	Economy	4100.00
0005433124214	7680	Economy	3700.00
0005433722239	7680	Economy	3700.00
0005433722243	7680	Economy	3700.00
0005433722242	7680	Economy	3700.00
0005433124208	7680	Economy	3700.00
0005433722256	7680	Economy	3700.00
0005433124207	7680	Economy	3700.00
0005433124216	7680	Economy	3700.00
0005433124218	7680	Economy	3700.00
0005433124204	7680	Economy	3700.00
0005433722240	7680	Economy	3700.00
0005433124213	7680	Economy	3700.00
0005433722275	7680	Economy	3700.00
0005433124212	7680	Economy	3700.00
0005433722252	7680	Economy	3700.00
0005433124217	7680	Economy	3700.00
0005433722244	7680	Economy	3700.00
0005433722233	7680	Economy	3700.00
0005433124211	7680	Economy	3700.00
0005433124215	7680	Economy	3700.00
0005433722254	7680	Economy	3700.00
0005433722249	7680	Economy	3700.00
0005433124210	7680	Economy	3700.00
0005432693499	7679	Business	11100.00
0005433450257	7679	Business	11100.00
0005433450267	7679	Business	11100.00
0005432721276	7679	Business	11100.00
0005432693497	7679	Business	11100.00
0005432693492	7679	Business	11100.00
0005432721257	7679	Business	11100.00
0005432721261	7679	Business	11100.00
0005433450273	7679	Business	11100.00
0005432693484	7679	Business	11100.00
0005432721274	7679	Economy	3700.00
0005432693501	7679	Economy	3700.00
0005432721255	7679	Economy	3700.00
0005433450266	7679	Economy	3700.00
0005432721256	7679	Economy	3700.00
0005433450271	7679	Economy	3700.00
0005432693493	7679	Economy	3700.00
0005432693485	7679	Economy	3700.00
0005432721277	7679	Economy	3700.00
0005432721279	7679	Economy	4100.00
0005432693498	7679	Economy	4100.00
0005432693495	7679	Economy	4100.00
0005432721264	7679	Economy	4100.00
0005432693505	7679	Economy	3700.00
0005432693502	7679	Economy	3700.00
0005432721273	7679	Economy	3700.00
0005432693490	7679	Economy	3700.00
0005432721268	7679	Economy	3700.00
0005433450270	7679	Economy	3700.00
0005432721267	7679	Economy	3700.00
0005432721278	7679	Economy	3700.00
0005432693482	7679	Economy	3700.00
0005432693477	7679	Economy	3700.00
0005432721262	7679	Economy	3700.00
0005432721270	7679	Economy	3700.00
0005432721254	7679	Economy	3700.00
0005433450263	7679	Economy	3700.00
0005432693478	7679	Economy	3700.00
0005432693486	7679	Economy	3700.00
0005432693489	7679	Economy	3700.00
0005433450262	7679	Economy	3700.00
0005432721272	7679	Economy	3700.00
0005432693500	7679	Economy	3700.00
0005433450258	7679	Economy	3700.00
0005433450265	7679	Economy	3700.00
0005433450272	7679	Economy	3700.00
0005432721269	7679	Economy	3700.00
0005432693487	7679	Economy	3700.00
0005433450254	7679	Economy	3700.00
0005432721265	7679	Economy	3700.00
0005433450259	7679	Economy	3700.00
0005432693479	7679	Economy	3700.00
0005432693475	7679	Economy	3700.00
0005433450256	7679	Economy	3700.00
0005432721252	7679	Economy	3700.00
0005432721253	7679	Economy	3700.00
0005432721263	7679	Economy	3700.00
0005433450269	7679	Economy	3700.00
0005432693503	7679	Economy	3700.00
0005432721259	7679	Economy	3700.00
0005432693496	7679	Economy	3700.00
0005432721275	7679	Economy	3700.00
0005432721260	7679	Economy	3700.00
0005433450264	7679	Economy	3700.00
0005432693481	7679	Economy	3700.00
0005432071614	7679	Economy	3700.00
0005432721271	7679	Economy	3700.00
0005432721258	7679	Economy	3700.00
0005432693480	7679	Economy	3700.00
0005432721266	7679	Economy	3700.00
0005432693491	7679	Economy	3700.00
0005432693494	7679	Economy	3700.00
0005432693476	7679	Economy	3700.00
0005433450260	7679	Economy	3700.00
0005432071615	7679	Economy	3700.00
0005432693483	7679	Economy	3700.00
0005433450268	7679	Economy	3700.00
0005432693506	7679	Economy	3700.00
0005433450255	7679	Economy	3700.00
0005432693474	7679	Economy	3700.00
0005433450261	7679	Economy	3700.00
0005432693504	7679	Economy	3700.00
0005432071613	7679	Economy	3700.00
0005433450253	7679	Economy	3700.00
0005433450252	7679	Economy	3700.00
0005432693488	7679	Economy	3700.00
0005432693071	30355	Business	11100.00
0005432693125	30355	Business	11100.00
0005433450022	30355	Business	11100.00
0005432693200	30355	Business	11100.00
0005432693120	30355	Business	11100.00
0005432693337	30355	Business	11100.00
0005432693201	30355	Business	11100.00
0005432693227	30355	Economy	3700.00
0005432693255	30355	Economy	3700.00
0005432693145	30355	Economy	3700.00
0005432693239	30355	Economy	3700.00
0005432693016	30355	Economy	3700.00
0005433450074	30355	Economy	3700.00
0005432693254	30355	Economy	3700.00
0005433450093	30355	Economy	3700.00
0005433450100	30355	Economy	3700.00
0005432693119	30355	Economy	4100.00
0005433450127	30355	Economy	4100.00
0005432693075	30355	Economy	4100.00
0005433450091	30355	Economy	4100.00
0005433450056	30355	Economy	4100.00
0005432693283	30355	Economy	3700.00
0005433449997	30355	Economy	3700.00
0005433449987	30355	Economy	3700.00
0005432693059	30355	Economy	3700.00
0005433450092	30355	Economy	3700.00
0005432693055	30355	Economy	3700.00
0005433450053	30355	Economy	3700.00
0005432693336	30355	Economy	3700.00
0005432693124	30355	Economy	3700.00
0005432693325	30355	Economy	3700.00
0005432693199	30355	Economy	3700.00
0005433450132	30355	Economy	3700.00
0005432693197	30355	Economy	3700.00
0005433450057	30355	Economy	3700.00
0005432693282	30355	Economy	3700.00
0005432693339	30355	Economy	3700.00
0005433450136	30355	Economy	3700.00
0005433450070	30355	Economy	3700.00
0005433450081	30355	Economy	3700.00
0005432693184	30355	Economy	3700.00
0005432693017	30355	Economy	3700.00
0005433450035	30355	Economy	3700.00
0005432693198	30355	Economy	3700.00
0005432693126	30355	Economy	3700.00
0005432693056	30355	Economy	3700.00
0005432693146	30355	Economy	3700.00
0005432693064	30355	Economy	3700.00
0005432693162	30355	Economy	3700.00
0005433450115	30355	Economy	3700.00
0005433449996	30355	Economy	3700.00
0005432693193	30355	Economy	3700.00
0005433450034	30355	Economy	3700.00
0005432693228	30355	Economy	3700.00
0005433450036	30355	Economy	3700.00
0005432693174	30355	Economy	3700.00
0005432693290	30355	Economy	3700.00
0005433449964	30355	Economy	3700.00
0005433450111	30355	Economy	3700.00
0005433450126	30355	Economy	3700.00
0005433450069	30355	Economy	3700.00
0005432693240	30355	Economy	3700.00
0005433124063	30356	Business	11100.00
0005432721071	30356	Business	11100.00
0005433124012	30356	Business	11100.00
0005432721045	30356	Business	11100.00
0005432721147	30356	Business	11100.00
0005432721096	30356	Business	11100.00
0005433722311	30356	Business	11100.00
0005433722312	30356	Economy	3700.00
0005432720980	30356	Economy	3700.00
0005433123954	30356	Economy	3700.00
0005432721033	30356	Economy	3700.00
0005432721115	30356	Economy	3700.00
0005432721070	30356	Economy	4100.00
0005432720895	30356	Economy	4100.00
0005432720981	30356	Economy	4100.00
0005432720997	30356	Economy	3700.00
0005433123941	30356	Economy	3700.00
0005432721114	30356	Economy	3700.00
0005432721053	30356	Economy	3700.00
0005432721088	30356	Economy	3700.00
0005432720946	30356	Economy	3700.00
0005432721165	30356	Economy	3700.00
0005433123871	30356	Economy	3700.00
0005433123955	30356	Economy	3700.00
0005432720931	30356	Economy	3700.00
0005433124013	30356	Economy	3700.00
0005432721028	30356	Economy	3700.00
0005433722313	30356	Economy	3700.00
0005433123924	30356	Economy	3700.00
0005433722310	30356	Economy	3700.00
0005432721102	30356	Economy	3700.00
0005433722309	30356	Economy	3700.00
0005433124002	30356	Economy	3700.00
0005433123990	30356	Economy	3700.00
0005433123991	30356	Economy	3700.00
0005432720950	30356	Economy	3700.00
0005433124001	30356	Economy	3700.00
0005433123940	30356	Economy	3700.00
0005433123996	30356	Economy	3700.00
0005432721101	30356	Economy	3700.00
0005432721034	30356	Economy	3700.00
0005432721098	30356	Economy	3700.00
0005432721120	30356	Economy	3700.00
0005433124064	30356	Economy	3700.00
0005432721119	30356	Economy	3700.00
0005433724868	1390	Business	70400.00
0005434586947	1390	Business	70400.00
0005434586972	1390	Business	70400.00
0005433525191	1390	Business	70400.00
0005432928000	1390	Business	70400.00
0005434513614	1390	Business	70400.00
0005434586946	1390	Business	70400.00
0005432271044	1390	Business	70400.00
0005432271042	1390	Business	70400.00
0005432928016	1390	Business	70400.00
0005433525183	1390	Business	70400.00
0005434586971	1390	Economy	23500.00
0005433193163	1390	Economy	23500.00
0005432271041	1390	Economy	23500.00
0005434586960	1390	Economy	23500.00
0005433193157	1390	Economy	23500.00
0005432927999	1390	Economy	23500.00
0005434586949	1390	Economy	23500.00
0005432271043	1390	Economy	23500.00
0005434586958	1390	Economy	25800.00
0005434586970	1390	Economy	25800.00
0005433193117	1390	Economy	25800.00
0005432928015	1390	Economy	23500.00
0005433724867	1390	Economy	23500.00
0005433193178	1390	Economy	23500.00
0005433525186	1390	Economy	23500.00
0005434515003	1390	Economy	23500.00
0005432928017	1390	Economy	23500.00
0005434586969	1390	Economy	23500.00
0005432928037	1390	Economy	23500.00
0005432968861	1390	Economy	23500.00
0005434586959	1390	Economy	23500.00
0005433193175	1390	Economy	23500.00
0005433525182	1390	Economy	23500.00
0005434586961	1390	Economy	23500.00
0005434586956	1390	Economy	23500.00
0005433525190	1390	Economy	23500.00
0005433724865	1390	Economy	23500.00
0005433724869	1390	Economy	23500.00
0005434513616	1390	Economy	23500.00
0005434513615	1390	Economy	23500.00
0005434586955	1390	Economy	23500.00
0005434586952	1390	Economy	23500.00
0005433525189	1390	Economy	23500.00
0005432927991	1390	Economy	23500.00
0005433525184	1390	Economy	23500.00
0005434586967	1390	Economy	23500.00
0005433193177	1390	Economy	23500.00
0005433193176	1390	Economy	23500.00
0005434586963	1390	Economy	23500.00
0005434586957	1390	Economy	23500.00
0005434586954	1390	Economy	23500.00
0005433193116	1390	Economy	23500.00
0005433193133	1390	Economy	23500.00
0005434586968	1390	Economy	23500.00
0005433525187	1390	Economy	23500.00
0005434586962	1390	Economy	23500.00
0005434586964	1390	Economy	23500.00
0005434586965	1390	Economy	23500.00
0005432928018	1390	Economy	23500.00
0005434586966	1390	Economy	23500.00
0005432968855	1390	Economy	23500.00
0005434586950	1390	Economy	23500.00
0005434586953	1390	Economy	23500.00
0005433525188	1390	Economy	23500.00
0005433525185	1390	Economy	23500.00
0005434586973	1390	Economy	23500.00
0005433193115	1390	Economy	23500.00
0005433724866	1390	Economy	23500.00
0005434586948	1390	Economy	23500.00
0005433193162	1390	Economy	23500.00
0005434586951	1390	Economy	23500.00
0005434515002	1390	Economy	23500.00
0005432928055	18524	Business	70400.00
0005434586761	18524	Business	70400.00
0005433193221	18524	Business	70400.00
0005434586767	18524	Business	70400.00
0005432928056	18524	Business	70400.00
0005433193229	18524	Business	70400.00
0005433525062	18524	Business	70400.00
0005434586788	18524	Business	70400.00
0005434586786	18524	Business	70400.00
0005433193220	18524	Business	70400.00
0005434586798	18524	Business	70400.00
0005433193231	18524	Economy	23500.00
0005434586704	18524	Economy	23500.00
0005434586636	18524	Economy	23500.00
0005434586668	18524	Economy	23500.00
0005433525071	18524	Economy	23500.00
0005434586696	18524	Economy	23500.00
0005434586919	18524	Economy	23500.00
0005434586762	18524	Economy	23500.00
0005434586758	18524	Economy	23500.00
0005433193219	18524	Economy	25800.00
0005434586772	18524	Economy	25800.00
0005433193224	18524	Economy	25800.00
0005434586706	18524	Economy	25800.00
0005434586722	18524	Economy	25800.00
0005433525077	18524	Economy	23500.00
0005434586805	18524	Economy	23500.00
0005433193227	18524	Economy	23500.00
0005434586837	18524	Economy	23500.00
0005434586718	18524	Economy	23500.00
0005433525109	18524	Economy	23500.00
0005434586787	18524	Economy	23500.00
0005432968870	18524	Economy	23500.00
0005434586839	18524	Economy	23500.00
0005434586756	18524	Economy	23500.00
0005432928053	18524	Economy	23500.00
0005434586773	18524	Economy	23500.00
0005433525057	18524	Economy	23500.00
0005432928054	18524	Economy	23500.00
0005432968871	18524	Economy	23500.00
0005432928052	18524	Economy	23500.00
0005433724839	18524	Economy	23500.00
0005433525087	18524	Economy	23500.00
0005434586918	18524	Economy	23500.00
0005433525130	18524	Economy	23500.00
0005433193223	18524	Economy	23500.00
0005434586759	18524	Economy	23500.00
0005433193232	18524	Economy	23500.00
0005434586838	18524	Economy	23500.00
0005434586697	18524	Economy	23500.00
0005434586723	18524	Economy	23500.00
0005433525066	18524	Economy	23500.00
0005434586717	18524	Economy	23500.00
0005433724841	18524	Economy	23500.00
0005434586623	18524	Economy	23500.00
0005433525080	18524	Economy	23500.00
0005433193230	18524	Economy	23500.00
0005433525063	18524	Economy	23500.00
0005434586757	18524	Economy	23500.00
0005433193228	18524	Economy	23500.00
0005433525067	18524	Economy	23500.00
0005433193226	18524	Economy	23500.00
0005433525079	18524	Economy	23500.00
0005434586797	18524	Economy	23500.00
0005433525081	18524	Economy	23500.00
0005433525078	18524	Economy	23500.00
0005433193225	18524	Economy	23500.00
0005434586792	18524	Economy	23500.00
0005433724840	18524	Economy	23500.00
0005433193222	18524	Economy	23500.00
0005434586690	18524	Economy	23500.00
0005434586760	18524	Economy	23500.00
0005434514971	18524	Economy	23500.00
0005433525108	18524	Economy	23500.00
0005433724815	18524	Economy	23500.00
0005434514985	18524	Economy	23500.00
0005435302218	11472	Economy	4300.00
0005434142662	11472	Economy	4300.00
0005434344664	11472	Economy	4300.00
0005434344654	11472	Economy	4300.00
0005434344661	11472	Economy	4000.00
0005435302203	11472	Economy	4000.00
0005434344668	11472	Economy	4000.00
0005434344660	11472	Economy	4000.00
0005434344641	11472	Economy	4000.00
0005434344639	11472	Economy	4000.00
0005434344657	11472	Economy	4000.00
0005434344650	11472	Economy	4000.00
0005434344649	11472	Economy	4000.00
0005434344663	11472	Economy	4000.00
0005434344670	11472	Economy	4000.00
0005434344659	11472	Economy	4000.00
0005434344656	11472	Economy	4000.00
0005434344655	11472	Economy	4000.00
0005435305014	11472	Economy	4000.00
0005434344666	11472	Economy	4000.00
0005435302202	11472	Economy	4000.00
0005434142663	11472	Economy	4000.00
0005434344667	11472	Economy	4000.00
0005434344653	11472	Economy	4000.00
0005434142664	11472	Economy	4000.00
0005434344643	11472	Economy	4000.00
0005434344671	11472	Economy	4000.00
0005434344637	11472	Economy	4000.00
0005434344669	11472	Economy	4000.00
0005434344648	11472	Economy	4000.00
0005435305015	11472	Economy	4000.00
0005434344658	11472	Economy	4000.00
0005434344652	11472	Economy	4000.00
0005434344651	11472	Economy	4000.00
0005434344640	11472	Economy	4000.00
0005434344638	11472	Economy	4000.00
0005434344645	11472	Economy	4000.00
0005434344642	11472	Economy	4000.00
0005434344646	11472	Economy	4000.00
0005434344665	11472	Economy	4000.00
0005434344662	11472	Economy	4000.00
0005434142665	11472	Economy	4000.00
0005435302212	11472	Economy	4000.00
0005434344644	11472	Economy	4000.00
0005434344672	11472	Economy	4000.00
0005434344673	11472	Economy	4000.00
0005434344647	11472	Economy	4000.00
0005435302205	11472	Economy	4000.00
0005435305041	29784	Economy	4300.00
0005434344379	29784	Economy	4300.00
0005434142628	29784	Economy	4300.00
0005435305042	29784	Economy	4300.00
0005435304219	29784	Economy	4000.00
0005434344358	29784	Economy	4000.00
0005435304220	29784	Economy	4000.00
0005435304221	29784	Economy	4000.00
0005434344211	29784	Economy	4000.00
0005434344486	29784	Economy	4000.00
0005434344481	29784	Economy	4000.00
0005434344354	29784	Economy	4000.00
0005434344169	29784	Economy	4000.00
0005434344326	29784	Economy	4000.00
0005434142627	29784	Economy	4000.00
0005434344511	29784	Economy	4000.00
0005434344245	29784	Economy	4000.00
0005435304218	29784	Economy	4000.00
0005434142613	29784	Economy	4000.00
0005434344239	29784	Economy	4000.00
0005434344321	29784	Economy	4000.00
0005434344378	29784	Economy	4000.00
0005434344458	29784	Economy	4000.00
0005434344325	29784	Economy	4000.00
0005434344352	29784	Economy	4000.00
0005434344377	29784	Economy	4000.00
0005434344423	29784	Economy	4000.00
0005434344271	29784	Economy	4000.00
0005434142626	29784	Economy	4000.00
0005434344272	29784	Economy	4000.00
0005434344376	29784	Economy	4000.00
0005434142614	29784	Economy	4000.00
0005435304222	29784	Economy	4000.00
0005434344436	29784	Economy	4000.00
0005434344212	29784	Economy	4000.00
0005434344435	29784	Economy	4000.00
0005434344307	29784	Economy	4000.00
0005433415716	1304	Business	199800.00
0005433415801	1304	Business	199800.00
0005435824978	1304	Business	199800.00
0005433415769	1304	Business	199800.00
0005435824991	1304	Business	199800.00
0005435824997	1304	Business	199800.00
0005432284598	1304	Economy	66600.00
0005432284597	1304	Economy	66600.00
0005435825000	1304	Economy	66600.00
0005433415770	1304	Economy	66600.00
0005435824982	1304	Economy	66600.00
0005435824992	1304	Economy	66600.00
0005435824976	1304	Economy	73200.00
0005435824988	1304	Economy	66600.00
0005435824977	1304	Economy	66600.00
0005435824979	1304	Economy	66600.00
0005435824983	1304	Economy	66600.00
0005433415753	1304	Economy	66600.00
0005435825003	1304	Economy	66600.00
0005435824993	1304	Economy	66600.00
0005433415775	1304	Economy	66600.00
0005435824994	1304	Economy	66600.00
0005433415827	1304	Economy	66600.00
0005435824981	1304	Economy	66600.00
0005435824996	1304	Economy	66600.00
0005433415735	1304	Economy	66600.00
0005435825002	1304	Economy	66600.00
0005435824998	1304	Economy	66600.00
0005435825001	1304	Economy	66600.00
0005433415745	1304	Economy	66600.00
0005433415774	1304	Economy	66600.00
0005435824984	1304	Economy	66600.00
0005435824989	1304	Economy	66600.00
0005432284599	1304	Economy	66600.00
0005435824986	1304	Economy	66600.00
0005435824985	1304	Economy	66600.00
0005433415800	1304	Economy	66600.00
0005435824980	1304	Economy	66600.00
0005433415768	1304	Economy	66600.00
0005435824999	1304	Economy	66600.00
0005435824995	1304	Economy	66600.00
0005433415811	1304	Economy	66600.00
0005433415759	1304	Economy	66600.00
0005435824990	1304	Economy	66600.00
0005435824987	1304	Economy	66600.00
0005435824808	17974	Business	199800.00
0005435824711	17974	Business	199800.00
0005433415872	17974	Business	199800.00
0005435824695	17974	Business	199800.00
0005435824778	17974	Business	199800.00
0005435824675	17974	Business	199800.00
0005435824672	17974	Business	199800.00
0005435824693	17974	Business	199800.00
0005433415874	17974	Business	199800.00
0005435824694	17974	Business	199800.00
0005435824769	17974	Business	199800.00
0005433415879	17974	Business	199800.00
0005433415880	17974	Economy	66600.00
0005433415875	17974	Economy	66600.00
0005435824799	17974	Economy	66600.00
0005435824732	17974	Economy	66600.00
0005433415884	17974	Economy	66600.00
0005433415878	17974	Economy	73200.00
0005435824742	17974	Economy	73200.00
0005433415871	17974	Economy	73200.00
0005433415882	17974	Economy	66600.00
0005435824751	17974	Economy	66600.00
0005435824682	17974	Economy	66600.00
0005435824777	17974	Economy	66600.00
0005433415873	17974	Economy	66600.00
0005435824749	17974	Economy	66600.00
0005433415883	17974	Economy	66600.00
0005435824671	17974	Economy	66600.00
0005435824771	17974	Economy	66600.00
0005435824681	17974	Economy	66600.00
0005435824791	17974	Economy	66600.00
0005433415870	17974	Economy	66600.00
0005435824721	17974	Economy	66600.00
0005435824743	17974	Economy	66600.00
0005435824775	17974	Economy	66600.00
0005435824727	17974	Economy	66600.00
0005435824826	17974	Economy	66600.00
0005435824770	17974	Economy	66600.00
0005435824744	17974	Economy	66600.00
0005435824859	17974	Economy	66600.00
0005433415876	17974	Economy	66600.00
0005435824720	17974	Economy	66600.00
0005435824798	17974	Economy	66600.00
0005435824700	17974	Economy	66600.00
0005433415881	17974	Economy	66600.00
0005433415877	17974	Economy	66600.00
0005435824701	17974	Economy	66600.00
0005435824846	17974	Economy	66600.00
0005433415869	17974	Economy	66600.00
0005435824844	17974	Economy	66600.00
0005435824845	17974	Economy	66600.00
0005435824802	17974	Economy	66600.00
0005432784530	5666	Business	27800.00
0005432144030	5666	Business	27800.00
0005435242995	5666	Business	27800.00
0005435243153	5666	Business	27800.00
0005432784529	5666	Business	27800.00
0005435242903	5666	Business	27800.00
0005435476767	5666	Business	27800.00
0005432784512	5666	Business	27800.00
0005432784513	5666	Business	27800.00
0005435476774	5666	Business	27800.00
0005435476802	5666	Business	27800.00
0005432784526	5666	Business	27800.00
0005432784500	5666	Economy	9300.00
0005435476791	5666	Economy	9300.00
0005432784537	5666	Economy	9300.00
0005432784535	5666	Economy	9300.00
0005432784540	5666	Economy	9300.00
0005435242951	5666	Economy	9300.00
0005432784521	5666	Economy	9300.00
0005432784522	5666	Economy	9300.00
0005432784515	5666	Economy	9300.00
0005432784541	5666	Economy	9300.00
0005435242912	5666	Economy	10200.00
0005432784519	5666	Economy	10200.00
0005435242919	5666	Economy	10200.00
0005435476781	5666	Economy	10200.00
0005435242984	5666	Economy	10200.00
0005432784518	5666	Economy	9300.00
0005435242960	5666	Economy	9300.00
0005432144032	5666	Economy	9300.00
0005435476765	5666	Economy	9300.00
0005432784517	5666	Economy	9300.00
0005435242901	5666	Economy	9300.00
0005435242994	5666	Economy	9300.00
0005432784516	5666	Economy	9300.00
0005432784543	5666	Economy	9300.00
0005435242996	5666	Economy	9300.00
0005435242862	5666	Economy	9300.00
0005432784527	5666	Economy	9300.00
0005432784544	5666	Economy	9300.00
0005432784508	5666	Economy	9300.00
0005432784511	5666	Economy	9300.00
0005435242886	5666	Economy	9300.00
0005432784533	5666	Economy	9300.00
0005435476775	5666	Economy	9300.00
0005435476779	5666	Economy	9300.00
0005432784520	5666	Economy	9300.00
0005432784524	5666	Economy	9300.00
0005435476789	5666	Economy	9300.00
0005432784534	5666	Economy	9300.00
0005432784506	5666	Economy	9300.00
0005435476801	5666	Economy	9300.00
0005435242933	5666	Economy	9300.00
0005432784531	5666	Economy	9300.00
0005435243020	5666	Economy	9300.00
0005435476821	5666	Economy	9300.00
0005432144031	5666	Economy	9300.00
0005432784525	5666	Economy	9300.00
0005432784538	5666	Economy	9300.00
0005432784497	5666	Economy	9300.00
0005432784503	5666	Economy	9300.00
0005432784542	5666	Economy	9300.00
0005432784491	5666	Economy	9300.00
0005435242863	5666	Economy	9300.00
0005432784539	5666	Economy	9300.00
0005435242985	5666	Economy	9300.00
0005435242802	5666	Economy	9300.00
0005432784509	5666	Economy	9300.00
0005432784505	5666	Economy	9300.00
0005432784514	5666	Economy	9300.00
0005432784501	5666	Economy	9300.00
0005435476807	5666	Economy	9300.00
0005432784495	5666	Economy	9300.00
0005432784523	5666	Economy	9300.00
0005432784498	5666	Economy	9300.00
0005435242902	5666	Economy	9300.00
0005435242952	5666	Economy	9300.00
0005435476820	5666	Economy	9300.00
0005432784528	5666	Economy	9300.00
0005432784507	5666	Economy	9300.00
0005435476764	5666	Economy	9300.00
0005432784504	5666	Economy	9300.00
0005432784546	5666	Economy	9300.00
0005432784510	5666	Economy	9300.00
0005435476773	5666	Economy	9300.00
0005435242907	5666	Economy	9300.00
0005432784492	5666	Economy	9300.00
0005432784496	5666	Economy	9300.00
0005432784532	5666	Economy	9300.00
0005432784493	5666	Economy	9300.00
0005432784536	5666	Economy	9300.00
0005432784494	5666	Economy	9300.00
0005432784502	5666	Economy	9300.00
0005432784545	5666	Economy	9300.00
0005432784499	5666	Economy	9300.00
0005432784113	15338	Business	27800.00
0005432784101	15338	Business	27800.00
0005435243195	15338	Business	27800.00
0005432783446	15338	Business	27800.00
0005432784013	15338	Business	27800.00
0005432784098	15338	Business	27800.00
0005432784086	15338	Business	27800.00
0005435243196	15338	Business	27800.00
0005432784068	15338	Business	27800.00
0005432784165	15338	Business	27800.00
0005432783784	15338	Business	27800.00
0005435243191	15338	Business	27800.00
0005435243206	15338	Economy	9300.00
0005432784079	15338	Economy	9300.00
0005432784122	15338	Economy	9300.00
0005432784014	15338	Economy	9300.00
0005432784090	15338	Economy	9300.00
0005432783866	15338	Economy	9300.00
0005435243189	15338	Economy	9300.00
0005435243185	15338	Economy	9300.00
0005432784040	15338	Economy	9300.00
0005435243193	15338	Economy	9300.00
0005432784232	15338	Economy	10200.00
0005432783830	15338	Economy	10200.00
0005432783931	15338	Economy	10200.00
0005435243197	15338	Economy	10200.00
0005432783783	15338	Economy	10200.00
0005432784096	15338	Economy	9300.00
0005432783853	15338	Economy	9300.00
0005432784099	15338	Economy	9300.00
0005432784091	15338	Economy	9300.00
0005432783742	15338	Economy	9300.00
0005432783909	15338	Economy	9300.00
0005432783844	15338	Economy	9300.00
0005432783940	15338	Economy	9300.00
0005435243200	15338	Economy	9300.00
0005432784102	15338	Economy	9300.00
0005432784103	15338	Economy	9300.00
0005432784089	15338	Economy	9300.00
0005432784100	15338	Economy	9300.00
0005435243199	15338	Economy	9300.00
0005432784044	15338	Economy	9300.00
0005435243190	15338	Economy	9300.00
0005432784047	15338	Economy	9300.00
0005435243194	15338	Economy	9300.00
0005432784227	15338	Economy	9300.00
0005432784080	15338	Economy	9300.00
0005432784164	15338	Economy	9300.00
0005432784161	15338	Economy	9300.00
0005435243208	15338	Economy	9300.00
0005432783687	15338	Economy	9300.00
0005435243188	15338	Economy	9300.00
0005435243207	15338	Economy	9300.00
0005432783962	15338	Economy	9300.00
0005432783987	15338	Economy	9300.00
0005432784248	15338	Economy	9300.00
0005432784048	15338	Economy	9300.00
0005432783971	15338	Economy	9300.00
0005432783976	15338	Economy	9300.00
0005435243192	15338	Economy	9300.00
0005432784121	15338	Economy	9300.00
0005432784094	15338	Economy	9300.00
0005435243205	15338	Economy	9300.00
0005432783977	15338	Economy	9300.00
0005432784039	15338	Economy	9300.00
0005432783930	15338	Economy	9300.00
0005432783741	15338	Economy	9300.00
0005432783880	15338	Economy	9300.00
0005432783886	15338	Economy	9300.00
0005432783885	15338	Economy	9300.00
0005432783831	15338	Economy	9300.00
0005432784073	15338	Economy	9300.00
0005432783845	15338	Economy	9300.00
0005435243187	15338	Economy	9300.00
0005432783833	15338	Economy	9300.00
0005432783950	15338	Economy	9300.00
0005432783923	15338	Economy	9300.00
0005432783970	15338	Economy	9300.00
0005435243201	15338	Economy	9300.00
0005432784074	15338	Economy	9300.00
0005432784064	15338	Economy	9300.00
0005432783740	15338	Economy	9300.00
0005432784097	15338	Economy	9300.00
0005432784023	15338	Economy	9300.00
0005435243202	15338	Economy	9300.00
0005435243204	15338	Economy	9300.00
0005432784112	15338	Economy	9300.00
0005435243186	15338	Economy	9300.00
0005432784088	15338	Economy	9300.00
0005432783967	15338	Economy	9300.00
0005432784087	15338	Economy	9300.00
0005432783943	15338	Economy	9300.00
0005435243198	15338	Economy	9300.00
0005432784043	15338	Economy	9300.00
0005432784027	15338	Economy	9300.00
0005435243203	15338	Economy	9300.00
0005432848504	4376	Economy	6300.00
0005432848507	4376	Economy	6300.00
0005432848502	4376	Economy	6300.00
0005434463957	4376	Economy	6300.00
0005434463958	4376	Economy	6300.00
0005432848513	4376	Economy	6300.00
0005435850985	4376	Economy	6300.00
0005435850955	4376	Economy	6300.00
0005434463960	4376	Economy	6300.00
0005432848508	4376	Economy	6300.00
0005434462820	4376	Economy	6300.00
0005432848510	4376	Economy	6300.00
0005434463959	4376	Economy	6300.00
0005432848505	4376	Economy	6300.00
0005435850998	4376	Economy	6300.00
0005435850996	4376	Economy	6300.00
0005435850918	4376	Economy	6300.00
0005434462819	4376	Economy	6300.00
0005435850970	4376	Economy	6300.00
0005432848503	4376	Economy	6300.00
0005432848506	4376	Economy	6300.00
0005432848512	4376	Economy	6300.00
0005432848514	4376	Economy	6300.00
0005432848509	4376	Economy	6300.00
0005432848511	4376	Economy	6300.00
0005432848408	28877	Economy	7000.00
0005435851031	28877	Economy	6300.00
0005435851036	28877	Economy	6300.00
0005432848379	28877	Economy	6300.00
0005432848411	28877	Economy	6300.00
0005432848375	28877	Economy	6300.00
0005432848383	28877	Economy	6300.00
0005435851033	28877	Economy	6300.00
0005432848393	28877	Economy	6300.00
0005435851037	28877	Economy	6300.00
0005434461645	28877	Economy	6300.00
0005435851034	28877	Economy	6300.00
0005435851035	28877	Economy	6300.00
0005432848396	28877	Economy	6300.00
0005435851029	28877	Economy	6300.00
0005432848354	28877	Economy	6300.00
0005435851032	28877	Economy	6300.00
0005432848376	28877	Economy	6300.00
0005432848324	28877	Economy	6300.00
0005432848352	28877	Economy	6300.00
0005435851030	28877	Economy	6300.00
0005432848384	28877	Economy	6300.00
0005432848378	28877	Economy	6300.00
0005433497383	6312	Business	11900.00
0005434443925	6312	Business	11900.00
0005434443926	6312	Business	11900.00
0005434926243	6312	Business	11900.00
0005434926230	6312	Business	11900.00
0005434926235	6312	Business	11900.00
0005434926240	6312	Business	11900.00
0005434926244	6312	Business	11900.00
0005434926234	6312	Business	11900.00
0005434926238	6312	Economy	4000.00
0005434926228	6312	Economy	4000.00
0005434926231	6312	Economy	4000.00
0005434926246	6312	Economy	4000.00
0005433497399	6312	Economy	4000.00
0005433497379	6312	Economy	4000.00
0005433497408	6312	Economy	4000.00
0005433497398	6312	Economy	4000.00
0005434926241	6312	Economy	4000.00
0005434926252	6312	Economy	4400.00
0005434926224	6312	Economy	4400.00
0005434443932	6312	Economy	4400.00
0005433497381	6312	Economy	4400.00
0005434926232	6312	Economy	4000.00
0005432075278	6312	Economy	4000.00
0005432075276	6312	Economy	4000.00
0005434926226	6312	Economy	4000.00
0005433497394	6312	Economy	4000.00
0005433497392	6312	Economy	4000.00
0005434443921	6312	Economy	4000.00
0005434443935	6312	Economy	4000.00
0005434443929	6312	Economy	4000.00
0005433497401	6312	Economy	4000.00
0005433497386	6312	Economy	4000.00
0005434443934	6312	Economy	4000.00
0005434926229	6312	Economy	4000.00
0005433497407	6312	Economy	4000.00
0005433497400	6312	Economy	4000.00
0005434443920	6312	Economy	4000.00
0005433497387	6312	Economy	4000.00
0005434443927	6312	Economy	4000.00
0005433497393	6312	Economy	4000.00
0005433497406	6312	Economy	4000.00
0005433497395	6312	Economy	4000.00
0005434443933	6312	Economy	4000.00
0005433497403	6312	Economy	4000.00
0005434443924	6312	Economy	4000.00
0005433497405	6312	Economy	4000.00
0005434926222	6312	Economy	4000.00
0005433497397	6312	Economy	4000.00
0005433497388	6312	Economy	4000.00
0005434926247	6312	Economy	4000.00
0005434443930	6312	Economy	4000.00
0005434926236	6312	Economy	4000.00
0005433497385	6312	Economy	4000.00
0005434926245	6312	Economy	4000.00
0005434926249	6312	Economy	4000.00
0005433497404	6312	Economy	4000.00
0005433497389	6312	Economy	4000.00
0005434926248	6312	Economy	4000.00
0005434926237	6312	Economy	4000.00
0005433497382	6312	Economy	4000.00
0005434443923	6312	Economy	4000.00
0005434926242	6312	Economy	4000.00
0005434443931	6312	Economy	4000.00
0005434443928	6312	Economy	4000.00
0005434926225	6312	Economy	4000.00
0005433497396	6312	Economy	4000.00
0005433497409	6312	Economy	4000.00
0005434926223	6312	Economy	4000.00
0005433497384	6312	Economy	4000.00
0005433497390	6312	Economy	4000.00
0005432075277	6312	Economy	4000.00
0005434443922	6312	Economy	4000.00
0005434926250	6312	Economy	4000.00
0005433497378	6312	Economy	4000.00
0005434926239	6312	Economy	4000.00
0005434926227	6312	Economy	4000.00
0005433497380	6312	Economy	4000.00
0005434926251	6312	Economy	4000.00
0005433497402	6312	Economy	4000.00
0005433497391	6312	Economy	4000.00
0005434926233	6312	Economy	4000.00
0005434443829	20402	Business	11900.00
0005433497065	20402	Business	11900.00
0005434925842	20402	Business	11900.00
0005434925869	20402	Business	11900.00
0005433497093	20402	Business	11900.00
0005434443784	20402	Business	11900.00
0005434925917	20402	Business	11900.00
0005434925950	20402	Business	11900.00
0005433497172	20402	Business	11900.00
0005434443771	20402	Business	11900.00
0005434925953	20402	Business	11900.00
0005434925884	20402	Economy	4000.00
0005433497076	20402	Economy	4000.00
0005433497163	20402	Economy	4000.00
0005434925877	20402	Economy	4000.00
0005434443803	20402	Economy	4000.00
0005434925956	20402	Economy	4000.00
0005434925914	20402	Economy	4000.00
0005433497117	20402	Economy	4000.00
0005434925926	20402	Economy	4400.00
0005434925925	20402	Economy	4400.00
0005434443760	20402	Economy	4400.00
0005434925840	20402	Economy	4400.00
0005434443761	20402	Economy	4000.00
0005433497043	20402	Economy	4000.00
0005434925841	20402	Economy	4000.00
0005433497089	20402	Economy	4000.00
0005434443701	20402	Economy	4000.00
0005434925935	20402	Economy	4000.00
0005433497140	20402	Economy	4000.00
0005433497044	20402	Economy	4000.00
0005433497088	20402	Economy	4000.00
0005433497091	20402	Economy	4000.00
0005434925938	20402	Economy	4000.00
0005434925868	20402	Economy	4000.00
0005433497223	20402	Economy	4000.00
0005433497157	20402	Economy	4000.00
0005434443804	20402	Economy	4000.00
0005433497220	20402	Economy	4000.00
0005434443773	20402	Economy	4000.00
0005433497003	20402	Economy	4000.00
0005434925952	20402	Economy	4000.00
0005433497066	20402	Economy	4000.00
0005433497129	20402	Economy	4000.00
0005434925875	20402	Economy	4000.00
0005433497225	20402	Economy	4000.00
0005434443762	20402	Economy	4000.00
0005433497216	20402	Economy	4000.00
0005433497084	20402	Economy	4000.00
0005433497260	20402	Economy	4000.00
0005433497183	20402	Economy	4000.00
0005433497169	20402	Economy	4000.00
0005433497087	20402	Economy	4000.00
0005434443774	20402	Economy	4000.00
0005434925934	20402	Economy	4000.00
0005434925955	20402	Economy	4000.00
0005434925911	20402	Economy	4000.00
0005434925880	20402	Economy	4000.00
0005434443772	20402	Economy	4000.00
0005434925795	20402	Economy	4000.00
0005434925954	20402	Economy	4000.00
0005434925927	20402	Economy	4000.00
0005434925843	20402	Economy	4000.00
0005434925928	20402	Economy	4000.00
0005434925844	20402	Economy	4000.00
0005434925929	20402	Economy	4000.00
0005433497116	20402	Economy	4000.00
0005433497094	20402	Economy	4000.00
0005434443857	20402	Economy	4000.00
0005434443769	20402	Economy	4000.00
0005433497141	20402	Economy	4000.00
0005434443826	20402	Economy	4000.00
0005433497219	20402	Economy	4000.00
0005433497130	20402	Economy	4000.00
0005434925937	20402	Economy	4000.00
0005434925861	20402	Economy	4000.00
0005433497055	20402	Economy	4000.00
0005434925957	20402	Economy	4000.00
0005434443729	20402	Economy	4000.00
0005433497224	20402	Economy	4000.00
0005433497170	20402	Economy	4000.00
0005433497158	20402	Economy	4000.00
0005433497230	20402	Economy	4000.00
0005434925876	20402	Economy	4000.00
0005434925881	20402	Economy	4000.00
0005434925870	20402	Economy	4000.00
0005433497004	20402	Economy	4000.00
0005435243218	12185	Business	41200.00
0005432784076	12185	Business	41200.00
0005432783904	12185	Business	41200.00
0005435243227	12185	Business	41200.00
0005435243217	12185	Business	41200.00
0005432784216	12185	Business	41200.00
0005435243224	12185	Business	41200.00
0005435243232	12185	Business	41200.00
0005435243237	12185	Business	41200.00
0005432784093	12185	Business	41200.00
0005432784078	12185	Business	41200.00
0005435243212	12185	Economy	13700.00
0005432784059	12185	Economy	13700.00
0005435243233	12185	Economy	13700.00
0005432784153	12185	Economy	13700.00
0005432783903	12185	Economy	13700.00
0005435243215	12185	Economy	13700.00
0005432784030	12185	Economy	13700.00
0005432784035	12185	Economy	13700.00
0005435243213	12185	Economy	13700.00
0005435243230	12185	Economy	13700.00
0005432784009	12185	Economy	15100.00
0005432784279	12185	Economy	15100.00
0005432783990	12185	Economy	15100.00
0005432784235	12185	Economy	15100.00
0005432784018	12185	Economy	15100.00
0005432784300	12185	Economy	13700.00
0005432784155	12185	Economy	13700.00
0005432784058	12185	Economy	13700.00
0005435243236	12185	Economy	13700.00
0005432784081	12185	Economy	13700.00
0005432783989	12185	Economy	13700.00
0005432783913	12185	Economy	13700.00
0005432784154	12185	Economy	13700.00
0005432784236	12185	Economy	13700.00
0005432783862	12185	Economy	13700.00
0005432783821	12185	Economy	13700.00
0005432784152	12185	Economy	13700.00
0005435243214	12185	Economy	13700.00
0005432784130	12185	Economy	13700.00
0005435243226	12185	Economy	13700.00
0005435243221	12185	Economy	13700.00
0005432784214	12185	Economy	13700.00
0005432784142	12185	Economy	13700.00
0005432783838	12185	Economy	13700.00
0005432783912	12185	Economy	13700.00
0005432784085	12185	Economy	13700.00
0005432784114	12185	Economy	13700.00
0005435243225	12185	Economy	13700.00
0005432784115	12185	Economy	13700.00
0005435243219	12185	Economy	13700.00
0005432783911	12185	Economy	13700.00
0005435243209	12185	Economy	13700.00
0005435243216	12185	Economy	13700.00
0005432784052	12185	Economy	13700.00
0005432784037	12185	Economy	13700.00
0005435243235	12185	Economy	13700.00
0005432784034	12185	Economy	13700.00
0005432783839	12185	Economy	13700.00
0005432783961	12185	Economy	13700.00
0005432784053	12185	Economy	13700.00
0005432783999	12185	Economy	13700.00
0005432784036	12185	Economy	13700.00
0005432783822	12185	Economy	13700.00
0005432784242	12185	Economy	13700.00
0005432784241	12185	Economy	13700.00
0005432783965	12185	Economy	13700.00
0005432783905	12185	Economy	13700.00
0005432784239	12185	Economy	13700.00
0005432784029	12185	Economy	13700.00
0005432784215	12185	Economy	13700.00
0005432784133	12185	Economy	13700.00
0005435243229	12185	Economy	13700.00
0005432783863	12185	Economy	13700.00
0005435243222	12185	Economy	13700.00
0005435243211	12185	Economy	13700.00
0005432784240	12185	Economy	13700.00
0005432783910	12185	Economy	13700.00
0005432783966	12185	Economy	13700.00
0005432784000	12185	Economy	13700.00
0005432784045	12185	Economy	13700.00
0005435243231	12185	Economy	13700.00
0005435243234	12185	Economy	13700.00
0005432783937	12185	Economy	13700.00
0005435243228	12185	Economy	13700.00
0005435243210	12185	Economy	13700.00
0005432784143	12185	Economy	13700.00
0005435243220	12185	Economy	13700.00
0005432784038	12185	Economy	13700.00
0005432784140	12185	Economy	13700.00
0005432784129	12185	Economy	13700.00
0005435243223	12185	Economy	13700.00
0005432784471	15442	Business	41200.00
0005432784480	15442	Business	41200.00
0005435243001	15442	Business	41200.00
0005432784487	15442	Business	41200.00
0005435242897	15442	Business	41200.00
0005432784444	15442	Business	41200.00
0005432784475	15442	Business	41200.00
0005432784467	15442	Business	41200.00
0005432784440	15442	Business	41200.00
0005432784472	15442	Economy	13700.00
0005432784468	15442	Economy	13700.00
0005432784453	15442	Economy	13700.00
0005435242866	15442	Economy	13700.00
0005435242979	15442	Economy	13700.00
0005432784462	15442	Economy	13700.00
0005435243002	15442	Economy	13700.00
0005432784479	15442	Economy	13700.00
0005432784485	15442	Economy	13700.00
0005432784448	15442	Economy	15100.00
0005435243033	15442	Economy	15100.00
0005435242827	15442	Economy	15100.00
0005432784452	15442	Economy	15100.00
0005432784447	15442	Economy	15100.00
0005432784442	15442	Economy	13700.00
0005435242888	15442	Economy	13700.00
0005432784456	15442	Economy	13700.00
0005432784458	15442	Economy	13700.00
0005432784454	15442	Economy	13700.00
0005432784436	15442	Economy	13700.00
0005435242780	15442	Economy	13700.00
0005432784476	15442	Economy	13700.00
0005435242925	15442	Economy	13700.00
0005432784441	15442	Economy	13700.00
0005432784488	15442	Economy	13700.00
0005435242852	15442	Economy	13700.00
0005432784477	15442	Economy	13700.00
0005432784445	15442	Economy	13700.00
0005435243000	15442	Economy	13700.00
0005432784465	15442	Economy	13700.00
0005432784483	15442	Economy	13700.00
0005432784490	15442	Economy	13700.00
0005432784482	15442	Economy	13700.00
0005435242889	15442	Economy	13700.00
0005432784450	15442	Economy	13700.00
0005432784449	15442	Economy	13700.00
0005432784470	15442	Economy	13700.00
0005432784484	15442	Economy	13700.00
0005432784486	15442	Economy	13700.00
0005432784463	15442	Economy	13700.00
0005432784481	15442	Economy	13700.00
0005435242898	15442	Economy	13700.00
0005435243034	15442	Economy	13700.00
0005432784466	15442	Economy	13700.00
0005432784437	15442	Economy	13700.00
0005432784446	15442	Economy	13700.00
0005432784438	15442	Economy	13700.00
0005432784439	15442	Economy	13700.00
0005435242853	15442	Economy	13700.00
0005432784473	15442	Economy	13700.00
0005435242887	15442	Economy	13700.00
0005435242828	15442	Economy	13700.00
0005432784460	15442	Economy	13700.00
0005432784474	15442	Economy	13700.00
0005432784457	15442	Economy	13700.00
0005432784455	15442	Economy	13700.00
0005432784478	15442	Economy	13700.00
0005435242826	15442	Economy	13700.00
0005432784459	15442	Economy	13700.00
0005435242867	15442	Economy	13700.00
0005432784464	15442	Economy	13700.00
0005435242896	15442	Economy	13700.00
0005435242926	15442	Economy	13700.00
0005432784451	15442	Economy	13700.00
0005432784489	15442	Economy	13700.00
0005432784443	15442	Economy	13700.00
0005432784469	15442	Economy	13700.00
0005432784461	15442	Economy	13700.00
0005434878552	10110	Business	49700.00
0005434878566	10110	Business	49700.00
0005434878580	10110	Business	49700.00
0005434878802	10110	Business	49700.00
0005434878841	10110	Business	49700.00
0005434878692	10110	Business	49700.00
0005434878910	10110	Business	49700.00
0005435913973	10110	Business	49700.00
0005434878591	10110	Business	49700.00
0005434878602	10110	Business	49700.00
0005434878833	10110	Business	49700.00
0005434879053	10110	Business	49700.00
0005434878726	10110	Business	49700.00
0005434878609	10110	Business	49700.00
0005434878862	10110	Business	49700.00
0005434878719	10110	Business	49700.00
0005434878864	10110	Business	49700.00
0005435913969	10110	Business	49700.00
0005434878607	10110	Economy	16600.00
0005434878619	10110	Economy	16600.00
0005434878672	10110	Economy	16600.00
0005434758912	10110	Economy	16600.00
0005434878764	10110	Economy	16600.00
0005434878677	10110	Economy	16600.00
0005434878353	10110	Economy	16600.00
0005434758913	10110	Economy	16600.00
0005434879027	10110	Economy	16600.00
0005434878535	10110	Economy	16600.00
0005434878598	10110	Economy	16600.00
0005434878697	10110	Economy	16600.00
0005434878455	10110	Economy	18200.00
0005434878832	10110	Economy	18200.00
0005434878606	10110	Economy	18200.00
0005434879102	10110	Economy	16600.00
0005434878831	10110	Economy	18200.00
0005434878803	10110	Economy	16600.00
0005435913975	10110	Economy	16600.00
0005434878615	10110	Economy	16600.00
0005434878507	10110	Economy	16600.00
0005434877849	10110	Economy	16600.00
0005434878720	10110	Economy	16600.00
0005435913971	10110	Economy	16600.00
0005434878735	10110	Economy	16600.00
0005434878605	10110	Economy	16600.00
0005434878616	10110	Economy	16600.00
0005434878491	10110	Economy	16600.00
0005434878610	10110	Economy	16600.00
0005434878912	10110	Economy	16600.00
0005434878629	10110	Economy	16600.00
0005434878133	10110	Economy	16600.00
0005434878576	10110	Economy	16600.00
0005435913972	10110	Economy	16600.00
0005435913974	10110	Economy	16600.00
0005434878696	10110	Economy	16600.00
0005434878800	10110	Economy	16600.00
0005434878751	10110	Economy	16600.00
0005434878742	10110	Economy	16600.00
0005434878228	10110	Economy	16600.00
0005434878608	10110	Economy	16600.00
0005434878830	10110	Economy	16600.00
0005434878911	10110	Economy	16600.00
0005435913976	10110	Economy	16600.00
0005435913970	10110	Economy	16600.00
0005434878843	10110	Economy	16600.00
0005434878741	10110	Economy	16600.00
0005434878954	10110	Economy	16600.00
0005434879023	10110	Economy	16600.00
0005434878305	10110	Economy	16600.00
0005434878935	10110	Economy	16600.00
0005434878884	10110	Economy	16600.00
0005434878894	10110	Economy	16600.00
0005434878842	10110	Economy	16600.00
0005434878863	10110	Economy	16600.00
0005434878578	10110	Economy	16600.00
0005434910144	10110	Economy	16600.00
0005434878306	10110	Economy	16600.00
0005434879034	10110	Economy	16600.00
0005434878166	10110	Economy	16600.00
0005434878736	10110	Economy	16600.00
0005434878389	10110	Economy	16600.00
0005434878581	10110	Economy	16600.00
0005434879026	10110	Economy	16600.00
0005434879022	10110	Economy	16600.00
0005434878263	10110	Economy	16600.00
0005434878134	10110	Economy	16600.00
0005434878934	10110	Economy	16600.00
0005434878766	10110	Economy	16600.00
0005434878213	10110	Economy	16600.00
0005434878955	10110	Economy	16600.00
0005434878658	10110	Economy	16600.00
0005434878737	10110	Economy	16600.00
0005434878553	10110	Economy	16600.00
0005434878642	10110	Economy	16600.00
0005434878718	10110	Economy	16600.00
0005434878564	10110	Economy	16600.00
0005434878921	10110	Economy	16600.00
0005434878691	10110	Economy	16600.00
0005434878592	10110	Economy	16600.00
0005434878637	10110	Economy	16600.00
0005434878565	10110	Economy	16600.00
0005434879054	10110	Economy	16600.00
0005434878538	10110	Economy	16600.00
0005434878885	10110	Economy	16600.00
0005434879445	14646	Business	49700.00
0005434879525	14646	Business	49700.00
0005434879497	14646	Business	49700.00
0005434879504	14646	Business	49700.00
0005434879534	14646	Business	49700.00
0005434879507	14646	Business	49700.00
0005434879457	14646	Business	49700.00
0005434879459	14646	Business	49700.00
0005434879466	14646	Business	49700.00
0005434879486	14646	Business	49700.00
0005434879492	14646	Business	49700.00
0005434879471	14646	Business	49700.00
0005434879532	14646	Business	49700.00
0005434879447	14646	Business	49700.00
0005434879487	14646	Business	49700.00
0005434879470	14646	Business	49700.00
0005434879523	14646	Business	49700.00
0005434879531	14646	Business	49700.00
0005434879467	14646	Business	49700.00
0005434879448	14646	Economy	16600.00
0005434879484	14646	Business	49700.00
0005434879503	14646	Economy	16600.00
0005434879498	14646	Economy	16600.00
0005434879511	14646	Economy	16600.00
0005434879493	14646	Economy	16600.00
0005434879478	14646	Economy	16600.00
0005434879502	14646	Economy	16600.00
0005434879468	14646	Economy	16600.00
0005434879505	14646	Economy	16600.00
0005434879481	14646	Economy	16600.00
0005434879513	14646	Economy	16600.00
0005434879488	14646	Economy	18200.00
0005434879463	14646	Economy	18200.00
0005434879482	14646	Economy	18200.00
0005434879529	14646	Economy	16600.00
0005434879479	14646	Economy	18200.00
0005434879472	14646	Economy	16600.00
0005434879460	14646	Economy	16600.00
0005434879480	14646	Economy	16600.00
0005434879462	14646	Economy	16600.00
0005434879530	14646	Economy	16600.00
0005434879533	14646	Economy	16600.00
0005434879515	14646	Economy	16600.00
0005434879516	14646	Economy	16600.00
0005434879520	14646	Economy	16600.00
0005434879465	14646	Economy	16600.00
0005434879454	14646	Economy	16600.00
0005434879452	14646	Economy	16600.00
0005434879485	14646	Economy	16600.00
0005434879510	14646	Economy	16600.00
0005434879491	14646	Economy	16600.00
0005434879489	14646	Economy	16600.00
0005434879474	14646	Economy	16600.00
0005434879443	14646	Economy	16600.00
0005434879514	14646	Economy	16600.00
0005434879508	14646	Economy	16600.00
0005434879458	14646	Economy	16600.00
0005434879500	14646	Economy	16600.00
0005434879469	14646	Economy	16600.00
0005434879518	14646	Economy	16600.00
0005434879449	14646	Economy	16600.00
0005434879535	14646	Economy	16600.00
0005434910120	14646	Economy	16600.00
0005434879477	14646	Economy	16600.00
0005434879528	14646	Economy	16600.00
0005434879517	14646	Economy	16600.00
0005434879519	14646	Economy	16600.00
0005434879446	14646	Economy	16600.00
0005434879464	14646	Economy	16600.00
0005434879490	14646	Economy	16600.00
0005434879483	14646	Economy	16600.00
0005434879475	14646	Economy	16600.00
0005434879506	14646	Economy	16600.00
0005434879455	14646	Economy	16600.00
0005434879521	14646	Economy	16600.00
0005434879496	14646	Economy	16600.00
0005434879499	14646	Economy	16600.00
0005434879451	14646	Economy	16600.00
0005434758925	14646	Economy	16600.00
0005434879509	14646	Economy	16600.00
0005434879512	14646	Economy	16600.00
0005434879476	14646	Economy	16600.00
0005434879522	14646	Economy	16600.00
0005434879450	14646	Economy	16600.00
0005434879444	14646	Economy	16600.00
0005434879527	14646	Economy	16600.00
0005434879442	14646	Economy	16600.00
0005434879526	14646	Economy	16600.00
0005434879456	14646	Economy	16600.00
0005434879501	14646	Economy	16600.00
0005434879461	14646	Economy	16600.00
0005434879524	14646	Economy	16600.00
0005434879537	14646	Economy	16600.00
0005434879494	14646	Economy	16600.00
0005434879473	14646	Economy	16600.00
0005434879453	14646	Economy	16600.00
0005434879536	14646	Economy	16600.00
0005434758924	14646	Economy	16600.00
0005434879495	14646	Economy	16600.00
0005434251970	9252	Economy	22400.00
0005435660288	9252	Economy	22400.00
0005434252020	9252	Economy	20300.00
0005434252016	9252	Economy	20300.00
0005434252036	9252	Economy	20300.00
0005435660286	9252	Economy	20300.00
0005435660293	9252	Economy	20300.00
0005435660282	9252	Economy	20300.00
0005434251994	9252	Economy	20300.00
0005435660285	9252	Economy	20300.00
0005434252037	9252	Economy	20300.00
0005435660289	9252	Economy	20300.00
0005434252021	9252	Economy	20300.00
0005435660284	9252	Economy	20300.00
0005435660292	9252	Economy	20300.00
0005435660287	9252	Economy	20300.00
0005435660291	9252	Economy	20300.00
0005435660290	9252	Economy	20300.00
0005434252035	9252	Economy	20300.00
0005435660283	9252	Economy	20300.00
0005435660169	24627	Economy	22400.00
0005435660208	24627	Economy	22400.00
0005434252094	24627	Economy	22400.00
0005435660188	24627	Economy	20300.00
0005434252091	24627	Economy	20300.00
0005435660204	24627	Economy	20300.00
0005434252090	24627	Economy	20300.00
0005435660187	24627	Economy	20300.00
0005434252088	24627	Economy	20300.00
0005435660186	24627	Economy	20300.00
0005435660160	24627	Economy	20300.00
0005434252096	24627	Economy	20300.00
0005435660212	24627	Economy	20300.00
0005435660207	24627	Economy	20300.00
0005435660168	24627	Economy	20300.00
0005434252089	24627	Economy	20300.00
0005435660211	24627	Economy	20300.00
0005435660159	24627	Economy	20300.00
0005434252095	24627	Economy	20300.00
0005434252087	24627	Economy	20300.00
0005434252093	24627	Economy	20300.00
0005434252092	24627	Economy	20300.00
0005433681201	2774	Business	33000.00
0005433681205	2774	Business	33000.00
0005433681203	2774	Business	33000.00
0005433681175	2774	Business	33000.00
0005432222854	2774	Business	33000.00
0005432222851	2774	Business	33000.00
0005432967013	2774	Business	33000.00
0005432967136	2774	Business	33000.00
0005433681210	2774	Business	33000.00
0005433681176	2774	Economy	11000.00
0005432966979	2774	Economy	11000.00
0005432967030	2774	Economy	11000.00
0005432966991	2774	Economy	11000.00
0005433681182	2774	Economy	11000.00
0005433681209	2774	Economy	11000.00
0005433681211	2774	Economy	11000.00
0005433681206	2774	Economy	11000.00
0005432967060	2774	Economy	11000.00
0005433681208	2774	Economy	11000.00
0005433681198	2774	Economy	12100.00
0005432967066	2774	Economy	12100.00
0005433681217	2774	Economy	12100.00
0005433681220	2774	Economy	11000.00
0005433681180	2774	Economy	11000.00
0005432967054	2774	Economy	11000.00
0005433681179	2774	Economy	11000.00
0005432967088	2774	Economy	11000.00
0005433681219	2774	Economy	11000.00
0005432966978	2774	Economy	11000.00
0005433681184	2774	Economy	11000.00
0005433681218	2774	Economy	11000.00
0005433684446	2774	Economy	11000.00
0005433681223	2774	Economy	11000.00
0005433681221	2774	Economy	11000.00
0005433681191	2774	Economy	11000.00
0005433681185	2774	Economy	11000.00
0005432967029	2774	Economy	11000.00
0005432967035	2774	Economy	11000.00
0005433681222	2774	Economy	11000.00
0005432966980	2774	Economy	11000.00
0005433681195	2774	Economy	11000.00
0005432966977	2774	Economy	11000.00
0005432967019	2774	Economy	11000.00
0005433681178	2774	Economy	11000.00
0005433681181	2774	Economy	11000.00
0005432966930	2774	Economy	11000.00
0005432967075	2774	Economy	11000.00
0005433681194	2774	Economy	11000.00
0005432967037	2774	Economy	11000.00
0005432967020	2774	Economy	11000.00
0005433681183	2774	Economy	11000.00
0005433681193	2774	Economy	11000.00
0005433681197	2774	Economy	11000.00
0005432222850	2774	Economy	11000.00
0005432967166	2774	Economy	11000.00
0005433681213	2774	Economy	11000.00
0005433681186	2774	Economy	11000.00
0005433681199	2774	Economy	11000.00
0005433681188	2774	Economy	11000.00
0005432967031	2774	Economy	11000.00
0005432967065	2774	Economy	11000.00
0005432222853	2774	Economy	11000.00
0005433681192	2774	Economy	11000.00
0005433681214	2774	Economy	11000.00
0005432966972	2774	Economy	11000.00
0005432222852	2774	Economy	11000.00
0005433681212	2774	Economy	11000.00
0005433681189	2774	Economy	11000.00
0005433684447	2774	Economy	11000.00
0005433681204	2774	Economy	11000.00
0005433681190	2774	Economy	11000.00
0005433681187	2774	Economy	11000.00
0005433681215	2774	Economy	11000.00
0005433681196	2774	Economy	11000.00
0005432966981	2774	Economy	11000.00
0005433681177	2774	Economy	11000.00
0005432967061	2774	Economy	11000.00
0005433681202	2774	Economy	11000.00
0005432967055	2774	Economy	11000.00
0005433681216	2774	Economy	11000.00
0005433681200	2774	Economy	11000.00
0005432967038	2774	Economy	11000.00
0005432966952	2774	Economy	11000.00
0005433681207	2774	Economy	11000.00
0005433687715	29145	Business	33000.00
0005433680890	29145	Business	33000.00
0005433681016	29145	Business	33000.00
0005433680821	29145	Business	33000.00
0005433680863	29145	Business	33000.00
0005433680691	29145	Business	33000.00
0005433680861	29145	Business	33000.00
0005433680830	29145	Business	33000.00
0005432967265	29145	Business	33000.00
0005432967280	29145	Business	33000.00
0005432967266	29145	Business	33000.00
0005432967284	29145	Business	33000.00
0005432967268	29145	Economy	11000.00
0005432005252	29145	Economy	11000.00
0005432967275	29145	Economy	11000.00
0005433687711	29145	Economy	11000.00
0005433680709	29145	Economy	11000.00
0005433680801	29145	Economy	11000.00
0005433680889	29145	Economy	11000.00
0005432967273	29145	Economy	11000.00
0005433684434	29145	Economy	11000.00
0005433680724	29145	Economy	11000.00
0005433680802	29145	Economy	12100.00
0005433680652	29145	Economy	12100.00
0005433684427	29145	Economy	12100.00
0005432967282	29145	Economy	12100.00
0005433680743	29145	Economy	12100.00
0005433687716	29145	Economy	11000.00
0005433680899	29145	Economy	11000.00
0005433680897	29145	Economy	11000.00
0005433680846	29145	Economy	11000.00
0005432967272	29145	Economy	11000.00
0005432967267	29145	Economy	11000.00
0005432005251	29145	Economy	11000.00
0005432967283	29145	Economy	11000.00
0005433680745	29145	Economy	11000.00
0005433680797	29145	Economy	11000.00
0005432967264	29145	Economy	11000.00
0005433681022	29145	Economy	11000.00
0005433680784	29145	Economy	11000.00
0005433681041	29145	Economy	11000.00
0005432967269	29145	Economy	11000.00
0005433680710	29145	Economy	11000.00
0005432967285	29145	Economy	11000.00
0005433680931	29145	Economy	11000.00
0005432005250	29145	Economy	11000.00
0005433684424	29145	Economy	11000.00
0005432967271	29145	Economy	11000.00
0005433680847	29145	Economy	11000.00
0005433680887	29145	Economy	11000.00
0005433680893	29145	Economy	11000.00
0005433680785	29145	Economy	11000.00
0005433690922	29145	Economy	11000.00
0005433681040	29145	Economy	11000.00
0005433680615	29145	Economy	11000.00
0005432967281	29145	Economy	11000.00
0005432967277	29145	Economy	11000.00
0005433680651	29145	Economy	11000.00
0005433680913	29145	Economy	11000.00
0005432967286	29145	Economy	11000.00
0005432967287	29145	Economy	11000.00
0005433680774	29145	Economy	11000.00
0005433681017	29145	Economy	11000.00
0005433680845	29145	Economy	11000.00
0005432967270	29145	Economy	11000.00
0005433681039	29145	Economy	11000.00
0005433690931	29145	Economy	11000.00
0005432967278	29145	Economy	11000.00
0005433680796	29145	Economy	11000.00
0005433680588	29145	Economy	11000.00
0005433680690	29145	Economy	11000.00
0005433680904	29145	Economy	11000.00
0005432967288	29145	Economy	11000.00
0005433680905	29145	Economy	11000.00
0005433680930	29145	Economy	11000.00
0005432967276	29145	Economy	11000.00
0005433680895	29145	Economy	11000.00
0005433680714	29145	Economy	11000.00
0005433680742	29145	Economy	11000.00
0005433680898	29145	Economy	11000.00
0005433680928	29145	Economy	11000.00
0005432967274	29145	Economy	11000.00
0005433687712	29145	Economy	11000.00
0005432967263	29145	Economy	11000.00
0005432967289	29145	Economy	11000.00
0005433680864	29145	Economy	11000.00
0005433680862	29145	Economy	11000.00
0005433680896	29145	Economy	11000.00
0005433684428	29145	Economy	11000.00
0005433687705	29145	Economy	11000.00
0005432967279	29145	Economy	11000.00
0005433680932	29145	Economy	11000.00
0005433680823	29145	Economy	11000.00
0005433680715	29145	Economy	11000.00
0005433680872	29145	Economy	11000.00
0005433680982	29145	Economy	11000.00
0005433680822	29145	Economy	11000.00
0005433634231	9297	Business	132900.00
0005433615610	9297	Business	132900.00
0005433615560	9297	Business	132900.00
0005433615602	9297	Business	132900.00
0005433615596	9297	Business	132900.00
0005433615620	9297	Business	132900.00
0005434152802	9297	Business	132900.00
0005433615597	9297	Business	132900.00
0005433615585	9297	Business	132900.00
0005433577984	9297	Business	132900.00
0005434163650	9297	Business	132900.00
0005433615583	9297	Business	132900.00
0005433615628	9297	Business	132900.00
0005433615616	9297	Business	132900.00
0005433615567	9297	Business	132900.00
0005433615605	9297	Business	132900.00
0005433615623	9297	Business	132900.00
0005433615589	9297	Business	132900.00
0005433634230	9297	Business	132900.00
0005433634246	9297	Business	132900.00
0005433634237	9297	Business	132900.00
0005433615613	9297	Business	132900.00
0005433577985	9297	Business	132900.00
0005433615569	9297	Business	132900.00
0005433615615	9297	Business	132900.00
0005434152790	9297	Economy	48700.00
0005433634257	9297	Economy	48700.00
0005433615582	9297	Economy	48700.00
0005433634225	9297	Economy	48700.00
0005433615565	9297	Economy	48700.00
0005433634241	9297	Economy	48700.00
0005432756892	9297	Economy	44300.00
0005434269103	9297	Economy	44300.00
0005433615558	9297	Economy	44300.00
0005433577981	9297	Economy	44300.00
0005433615577	9297	Economy	44300.00
0005433615629	9297	Economy	44300.00
0005433577988	9297	Economy	44300.00
0005433615580	9297	Economy	44300.00
0005433615619	9297	Economy	44300.00
0005433615625	9297	Economy	44300.00
0005433615573	9297	Economy	44300.00
0005433615612	9297	Economy	44300.00
0005433615563	9297	Economy	44300.00
0005433615557	9297	Economy	44300.00
0005433615607	9297	Economy	44300.00
0005433615570	9297	Economy	44300.00
0005433615575	9297	Economy	44300.00
0005433615603	9297	Economy	44300.00
0005433615591	9297	Economy	44300.00
0005433634243	9297	Economy	44300.00
0005433634250	9297	Economy	44300.00
0005433577983	9297	Economy	44300.00
0005433634256	9297	Economy	44300.00
0005433615571	9297	Economy	44300.00
0005433634229	9297	Economy	44300.00
0005434163631	9297	Economy	44300.00
0005433634234	9297	Economy	44300.00
0005433615562	9297	Economy	44300.00
0005433615609	9297	Economy	44300.00
0005434163637	9297	Economy	44300.00
0005433615604	9297	Economy	44300.00
0005433634245	9297	Economy	44300.00
0005434269108	9297	Economy	44300.00
0005433615559	9297	Economy	44300.00
0005433615600	9297	Economy	44300.00
0005433634242	9297	Economy	44300.00
0005433615594	9297	Economy	44300.00
0005432756890	9297	Economy	44300.00
0005432755119	9297	Economy	44300.00
0005433615592	9297	Economy	44300.00
0005433634259	9297	Economy	44300.00
0005434163651	9297	Economy	44300.00
0005433615568	9297	Economy	44300.00
0005433634228	9297	Economy	44300.00
0005432756893	9297	Economy	44300.00
0005433615574	9297	Economy	44300.00
0005433634236	9297	Economy	44300.00
0005433634249	9297	Economy	44300.00
0005433615606	9297	Economy	44300.00
0005433615614	9297	Economy	48700.00
0005433634227	9297	Economy	48700.00
0005433615572	9297	Economy	48700.00
0005434269104	9297	Economy	48700.00
0005433615595	9297	Economy	44300.00
0005433615621	9297	Economy	44300.00
0005433634251	9297	Economy	44300.00
0005432145138	9297	Economy	44300.00
0005433577980	9297	Economy	44300.00
0005433577991	9297	Economy	48700.00
0005433577987	9297	Economy	44300.00
0005433615617	9297	Economy	44300.00
0005434269107	9297	Economy	44300.00
0005433615561	9297	Economy	44300.00
0005433615593	9297	Economy	44300.00
0005433634258	9297	Economy	44300.00
0005433634255	9297	Economy	44300.00
0005433634235	9297	Economy	44300.00
0005433615630	9297	Economy	44300.00
0005433615599	9297	Economy	44300.00
0005433577982	9297	Economy	44300.00
0005434152801	9297	Economy	44300.00
0005433634247	9297	Economy	44300.00
0005433615622	9297	Economy	44300.00
0005433634252	9297	Economy	44300.00
0005433615588	9297	Economy	44300.00
0005432145137	9297	Economy	44300.00
0005433634244	9297	Economy	44300.00
0005433615587	9297	Economy	44300.00
0005433615579	9297	Economy	44300.00
0005433615581	9297	Economy	44300.00
0005433615590	9297	Economy	44300.00
0005433577979	9297	Economy	44300.00
0005433577990	9297	Economy	44300.00
0005433577986	9297	Economy	44300.00
0005433615566	9297	Economy	44300.00
0005433615608	9297	Economy	44300.00
0005433615564	9297	Economy	44300.00
0005433615578	9297	Economy	44300.00
0005433615576	9297	Economy	44300.00
0005432755120	9297	Economy	44300.00
0005434163636	9297	Economy	44300.00
0005433615626	9297	Economy	44300.00
0005433615631	9297	Economy	44300.00
0005433634239	9297	Economy	44300.00
0005433577989	9297	Economy	44300.00
0005433634232	9297	Economy	44300.00
0005433577992	9297	Economy	44300.00
0005433615598	9297	Economy	44300.00
0005433615611	9297	Economy	44300.00
0005433634253	9297	Economy	44300.00
0005433615586	9297	Economy	44300.00
0005433615618	9297	Economy	44300.00
0005433615584	9297	Economy	44300.00
0005433634254	9297	Economy	44300.00
0005433634226	9297	Economy	44300.00
0005433634238	9297	Economy	44300.00
0005433615627	9297	Economy	44300.00
0005433634248	9297	Economy	44300.00
0005433634240	9297	Economy	44300.00
0005432756891	9297	Economy	44300.00
0005433615601	9297	Economy	44300.00
0005433634233	9297	Economy	44300.00
0005433615624	9297	Economy	44300.00
0005433614669	25214	Business	132900.00
0005433577858	25214	Business	132900.00
0005433577880	25214	Business	132900.00
0005433614858	25214	Business	132900.00
0005433633959	25214	Business	132900.00
0005433634012	25214	Business	132900.00
0005433633988	25214	Business	132900.00
0005433614975	25214	Business	132900.00
0005433633828	25214	Business	132900.00
0005433614805	25214	Business	132900.00
0005433614860	25214	Business	132900.00
0005434272211	25214	Business	132900.00
0005433614952	25214	Business	132900.00
0005433614992	25214	Business	132900.00
0005433577881	25214	Business	132900.00
0005433633915	25214	Business	132900.00
0005433614691	25214	Business	132900.00
0005433634047	25214	Business	132900.00
0005433614976	25214	Business	132900.00
0005433615244	25214	Business	132900.00
0005433614832	25214	Business	132900.00
0005433614910	25214	Business	132900.00
0005433615133	25214	Business	132900.00
0005433634013	25214	Business	132900.00
0005433614574	25214	Business	132900.00
0005433615134	25214	Business	132900.00
0005434163744	25214	Business	132900.00
0005433615103	25214	Economy	48700.00
0005433615263	25214	Economy	48700.00
0005433615180	25214	Economy	48700.00
0005433614974	25214	Economy	48700.00
0005433615118	25214	Economy	48700.00
0005433634083	25214	Economy	48700.00
0005434163740	25214	Economy	44300.00
0005433615288	25214	Economy	44300.00
0005433614998	25214	Economy	44300.00
0005433614833	25214	Economy	44300.00
0005433633940	25214	Economy	44300.00
0005433633941	25214	Economy	44300.00
0005433615056	25214	Economy	44300.00
0005434163742	25214	Economy	44300.00
0005433633819	25214	Economy	44300.00
0005433634020	25214	Economy	44300.00
0005433614942	25214	Economy	44300.00
0005433633818	25214	Economy	44300.00
0005433614993	25214	Economy	44300.00
0005433634030	25214	Economy	44300.00
0005433615201	25214	Economy	44300.00
0005433633910	25214	Economy	44300.00
0005433615132	25214	Economy	44300.00
0005433614843	25214	Economy	44300.00
0005433614913	25214	Economy	44300.00
0005433633829	25214	Economy	44300.00
0005433633939	25214	Economy	44300.00
0005433615058	25214	Economy	44300.00
0005433577867	25214	Economy	44300.00
0005433614453	25214	Economy	44300.00
0005433614850	25214	Economy	44300.00
0005433614877	25214	Economy	44300.00
0005433577840	25214	Economy	44300.00
0005433615028	25214	Economy	44300.00
0005433633905	25214	Economy	44300.00
0005433633808	25214	Economy	44300.00
0005433577870	25214	Economy	44300.00
0005433577878	25214	Economy	44300.00
0005433614842	25214	Economy	44300.00
0005433614781	25214	Economy	44300.00
0005433615203	25214	Economy	44300.00
0005433633975	25214	Economy	44300.00
0005433615261	25214	Economy	44300.00
0005433633973	25214	Economy	44300.00
0005433614744	25214	Economy	44300.00
0005433614965	25214	Economy	44300.00
0005433633947	25214	Economy	44300.00
0005433633935	25214	Economy	44300.00
0005433614800	25214	Economy	44300.00
0005433633872	25214	Economy	44300.00
0005433577817	25214	Economy	44300.00
0005433633845	25214	Economy	44300.00
0005433614617	25214	Economy	44300.00
0005433634084	25214	Economy	44300.00
0005433577818	25214	Economy	44300.00
0005433614941	25214	Economy	44300.00
0005433614638	25214	Economy	44300.00
0005433614978	25214	Economy	44300.00
0005433614935	25214	Economy	44300.00
0005434163745	25214	Economy	44300.00
0005433633827	25214	Economy	44300.00
0005433615156	25214	Economy	48700.00
0005433614883	25214	Economy	48700.00
0005434163741	25214	Economy	48700.00
0005433633807	25214	Economy	48700.00
0005433615023	25214	Economy	48700.00
0005433614689	25214	Economy	44300.00
0005433633974	25214	Economy	44300.00
0005433614997	25214	Economy	44300.00
0005433614651	25214	Economy	48700.00
0005433614673	25214	Economy	44300.00
0005433633882	25214	Economy	44300.00
0005434163743	25214	Economy	44300.00
0005433615057	25214	Economy	44300.00
0005434163737	25214	Economy	44300.00
0005433614867	25214	Economy	44300.00
0005434272212	25214	Economy	44300.00
0005433614994	25214	Economy	44300.00
0005433615287	25214	Economy	44300.00
0005434273097	25214	Economy	44300.00
0005433633871	25214	Economy	44300.00
0005433633945	25214	Economy	44300.00
0005434273098	25214	Economy	44300.00
0005433615184	25214	Economy	44300.00
0005433614804	25214	Economy	44300.00
0005433615017	25214	Economy	44300.00
0005433614779	25214	Economy	44300.00
0005433614884	25214	Economy	44300.00
0005433614690	25214	Economy	44300.00
0005433633936	25214	Economy	44300.00
0005433633820	25214	Economy	44300.00
0005433633809	25214	Economy	44300.00
0005433633901	25214	Economy	44300.00
0005433614979	25214	Economy	44300.00
0005434163739	25214	Economy	44300.00
0005433614878	25214	Economy	44300.00
0005433614819	25214	Economy	44300.00
0005433614735	25214	Economy	44300.00
0005433615151	25214	Economy	44300.00
0005433615055	25214	Economy	44300.00
0005433633775	25214	Economy	44300.00
0005433634046	25214	Economy	44300.00
0005433633967	25214	Economy	44300.00
0005433577879	25214	Economy	44300.00
0005433615202	25214	Economy	44300.00
0005434163738	25214	Economy	44300.00
0005433577859	25214	Economy	44300.00
0005433614782	25214	Economy	44300.00
0005433614995	25214	Economy	44300.00
0005433633826	25214	Economy	44300.00
0005433614851	25214	Economy	44300.00
0005433614668	25214	Economy	44300.00
0005433614818	25214	Economy	44300.00
0005433614783	25214	Economy	44300.00
0005433633987	25214	Economy	44300.00
0005434273099	25214	Economy	44300.00
0005433615114	25214	Economy	44300.00
0005433615080	25214	Economy	44300.00
0005433614780	25214	Economy	44300.00
0005433614907	25214	Economy	44300.00
0005433633990	25214	Economy	44300.00
0005433615225	25214	Economy	44300.00
0005433615262	25214	Economy	44300.00
0005433615243	25214	Economy	44300.00
0005433614844	25214	Economy	44300.00
0005433615150	25214	Economy	44300.00
0005433577896	25214	Economy	44300.00
0005433615021	25214	Economy	44300.00
0005433615160	25214	Economy	44300.00
0005433633914	25214	Economy	44300.00
0005433614806	25214	Economy	44300.00
0005433614637	25214	Economy	44300.00
0005433614632	25214	Economy	44300.00
0005433633844	25214	Economy	44300.00
0005432571349	4253	Business	193100.00
0005435947341	4253	Business	193100.00
0005435947356	4253	Business	193100.00
0005434271314	4253	Economy	64400.00
0005435947315	4253	Economy	64400.00
0005432571351	4253	Economy	64400.00
0005435986853	4253	Economy	64400.00
0005435947279	4253	Economy	64400.00
0005435986855	4253	Economy	64400.00
0005435947278	4253	Economy	64400.00
0005432184990	4253	Economy	64400.00
0005435947354	4253	Economy	64400.00
0005435787363	4253	Economy	64400.00
0005434271315	4253	Economy	64400.00
0005435856219	4253	Economy	64400.00
0005435947345	4253	Economy	70800.00
0005432184991	4253	Economy	64400.00
0005435986852	4253	Economy	64400.00
0005435856224	4253	Economy	64400.00
0005432571350	4253	Economy	64400.00
0005435947340	4253	Economy	64400.00
0005435856214	4253	Economy	64400.00
0005432184989	4253	Economy	64400.00
0005435787365	4253	Economy	64400.00
0005435856220	4253	Economy	64400.00
0005435856215	4253	Economy	64400.00
0005435986854	4253	Economy	64400.00
0005435787364	4253	Economy	64400.00
0005435947329	4253	Economy	64400.00
0005435947357	4253	Economy	64400.00
0005435947355	4253	Economy	64400.00
0005435787355	4253	Economy	64400.00
0005435856216	4253	Economy	64400.00
0005435787386	26565	Business	193100.00
0005435947447	26565	Business	193100.00
0005435947454	26565	Business	193100.00
0005435947455	26565	Economy	64400.00
0005435947448	26565	Economy	64400.00
0005435856263	26565	Economy	64400.00
0005435947456	26565	Economy	64400.00
0005435787385	26565	Economy	64400.00
0005432571373	26565	Economy	64400.00
0005432571375	26565	Economy	64400.00
0005432571374	26565	Economy	64400.00
0005435947444	26565	Economy	64400.00
0005435947449	26565	Economy	64400.00
0005435947446	26565	Economy	64400.00
0005432571377	26565	Economy	64400.00
0005435947457	26565	Economy	64400.00
0005435947453	26565	Economy	64400.00
0005435947450	26565	Economy	70800.00
0005435856260	26565	Economy	70800.00
0005435947458	26565	Economy	64400.00
0005432571376	26565	Economy	64400.00
0005435856261	26565	Economy	64400.00
0005435947445	26565	Economy	64400.00
0005435947452	26565	Economy	64400.00
0005435856262	26565	Economy	64400.00
0005435947451	26565	Economy	64400.00
0005433569894	356	Business	21500.00
0005432948509	356	Business	21500.00
0005433074884	356	Business	21500.00
0005433569888	356	Business	21500.00
0005432948717	356	Business	21500.00
0005433569893	356	Business	21500.00
0005432239019	356	Business	21500.00
0005433074909	356	Business	21500.00
0005432948746	356	Business	21500.00
0005433569886	356	Business	21500.00
0005433569841	356	Business	21500.00
0005433569874	356	Business	21500.00
0005432948814	356	Business	21500.00
0005433569862	356	Business	21500.00
0005433074920	356	Business	21500.00
0005432948568	356	Business	21500.00
0005432948628	356	Business	21500.00
0005432948510	356	Business	21500.00
0005433074970	356	Business	21500.00
0005433134164	356	Business	21500.00
0005432948432	356	Business	21500.00
0005432948541	356	Business	21500.00
0005432948580	356	Economy	7900.00
0005433569865	356	Economy	7900.00
0005433569905	356	Economy	7900.00
0005433569847	356	Economy	7900.00
0005432948609	356	Economy	7900.00
0005433074892	356	Economy	7200.00
0005433569901	356	Economy	7200.00
0005433074807	356	Economy	7200.00
0005433569880	356	Economy	7200.00
0005433569857	356	Economy	7200.00
0005433569849	356	Economy	7200.00
0005433569871	356	Economy	7200.00
0005433569858	356	Economy	7200.00
0005433569852	356	Economy	7200.00
0005433569870	356	Economy	7200.00
0005433074761	356	Economy	7200.00
0005433569863	356	Economy	7200.00
0005432948579	356	Economy	7200.00
0005433569907	356	Economy	7200.00
0005433074760	356	Economy	7200.00
0005432948708	356	Economy	7200.00
0005432948675	356	Economy	7200.00
0005432948501	356	Economy	7200.00
0005433074754	356	Economy	7200.00
0005432948519	356	Economy	7200.00
0005433569846	356	Economy	7200.00
0005432948721	356	Economy	7200.00
0005433569891	356	Economy	7200.00
0005433074756	356	Economy	7200.00
0005433074815	356	Economy	7200.00
0005432948542	356	Economy	7200.00
0005433569896	356	Economy	7200.00
0005433134168	356	Economy	7200.00
0005432948813	356	Economy	7200.00
0005433569853	356	Economy	7200.00
0005433074755	356	Economy	7200.00
0005433569890	356	Economy	7200.00
0005433569850	356	Economy	7200.00
0005433074904	356	Economy	7200.00
0005432239018	356	Economy	7200.00
0005433569840	356	Economy	7200.00
0005433569856	356	Economy	7200.00
0005432239020	356	Economy	7200.00
0005433569876	356	Economy	7200.00
0005433074806	356	Economy	7200.00
0005433569867	356	Economy	7200.00
0005433569878	356	Economy	7200.00
0005432239017	356	Economy	7200.00
0005433569872	356	Economy	7200.00
0005433569842	356	Economy	7200.00
0005433134174	356	Economy	7200.00
0005433569859	356	Economy	7200.00
0005433569882	356	Economy	7200.00
0005432239021	356	Economy	7200.00
0005433074932	356	Economy	7200.00
0005432948722	356	Economy	7200.00
0005432948743	356	Economy	7200.00
0005433569843	356	Economy	7200.00
0005433134165	356	Economy	7200.00
0005433134159	356	Economy	7200.00
0005433569868	356	Economy	7200.00
0005433569844	356	Economy	7900.00
0005432948500	356	Economy	7900.00
0005433074801	356	Economy	7900.00
0005433074894	356	Economy	7900.00
0005432948520	356	Economy	7200.00
0005433569866	356	Economy	7900.00
0005433074885	356	Economy	7200.00
0005432948742	356	Economy	7200.00
0005433074758	356	Economy	7200.00
0005432948780	356	Economy	7200.00
0005433569884	356	Economy	7200.00
0005433569879	356	Economy	7200.00
0005433569873	356	Economy	7200.00
0005433074969	356	Economy	7200.00
0005433134156	356	Economy	7200.00
0005433074891	356	Economy	7200.00
0005433569889	356	Economy	7200.00
0005432948444	356	Economy	7200.00
0005433569875	356	Economy	7200.00
0005433569864	356	Economy	7200.00
0005432948629	356	Economy	7200.00
0005433569895	356	Economy	7200.00
0005433074759	356	Economy	7200.00
0005432948514	356	Economy	7200.00
0005433569881	356	Economy	7200.00
0005433569851	356	Economy	7200.00
0005433569837	356	Economy	7200.00
0005432948567	356	Economy	7200.00
0005433074733	356	Economy	7200.00
0005432948589	356	Economy	7200.00
0005432948566	356	Economy	7200.00
0005433569855	356	Economy	7200.00
0005433569902	356	Economy	7200.00
0005433569845	356	Economy	7200.00
0005433569877	356	Economy	7200.00
0005433569906	356	Economy	7200.00
0005432948745	356	Economy	7200.00
0005432948573	356	Economy	7200.00
0005432948569	356	Economy	7200.00
0005432948545	356	Economy	7200.00
0005433569838	356	Economy	7200.00
0005433074919	356	Economy	7200.00
0005433569883	356	Economy	7200.00
0005433569861	356	Economy	7200.00
0005433569887	356	Economy	7200.00
0005432948610	356	Economy	7200.00
0005433074734	356	Economy	7200.00
0005432239016	356	Economy	7200.00
0005433569904	356	Economy	7200.00
0005433074893	356	Economy	7200.00
0005433569892	356	Economy	7200.00
0005433569903	356	Economy	7200.00
0005433569900	356	Economy	7200.00
0005433569860	356	Economy	7200.00
0005432948445	356	Economy	7200.00
0005433569885	356	Economy	7200.00
0005433074931	356	Economy	7200.00
0005433074829	356	Economy	7200.00
0005433569848	356	Economy	7200.00
0005432948778	356	Economy	7200.00
0005433569839	356	Economy	7200.00
0005433569897	356	Economy	7200.00
0005432948671	356	Economy	7200.00
0005433074735	356	Economy	7200.00
0005433569899	356	Economy	7200.00
0005433569869	356	Economy	7200.00
0005432948709	356	Economy	7200.00
0005433569898	356	Economy	7200.00
0005433569854	356	Economy	7200.00
0005433075074	11578	Business	21500.00
0005433075095	11578	Business	21500.00
0005433569040	11578	Business	21500.00
0005433569196	11578	Business	21500.00
0005433134198	11578	Business	21500.00
0005432949014	11578	Business	21500.00
0005433569348	11578	Business	21500.00
0005433075071	11578	Business	21500.00
0005432948996	11578	Business	21500.00
0005432948985	11578	Business	21500.00
0005432949000	11578	Business	21500.00
0005432949012	11578	Business	21500.00
0005432192363	11578	Business	21500.00
0005433075096	11578	Business	21500.00
0005432948983	11578	Business	21500.00
0005433569396	11578	Business	21500.00
0005433569311	11578	Business	21500.00
0005433134200	11578	Business	21500.00
0005433075073	11578	Business	21500.00
0005433569411	11578	Business	21500.00
0005433131769	11578	Business	21500.00
0005432948988	11578	Business	21500.00
0005433075083	11578	Economy	7900.00
0005432948997	11578	Economy	7900.00
0005433569197	11578	Economy	7900.00
0005432948980	11578	Economy	7900.00
0005432949004	11578	Economy	7900.00
0005433075086	11578	Economy	7200.00
0005432949001	11578	Economy	7200.00
0005433568975	11578	Economy	7200.00
0005433075093	11578	Economy	7200.00
0005432949006	11578	Economy	7200.00
0005432948989	11578	Economy	7200.00
0005433569162	11578	Economy	7200.00
0005433569133	11578	Economy	7200.00
0005433075079	11578	Economy	7200.00
0005433569269	11578	Economy	7200.00
0005433569255	11578	Economy	7200.00
0005433075088	11578	Economy	7200.00
0005433569448	11578	Economy	7200.00
0005432948987	11578	Economy	7200.00
0005432949003	11578	Economy	7200.00
0005433569244	11578	Economy	7200.00
0005433075077	11578	Economy	7200.00
0005433569151	11578	Economy	7200.00
0005433569085	11578	Economy	7200.00
0005433569091	11578	Economy	7200.00
0005433569545	11578	Economy	7200.00
0005433075092	11578	Economy	7200.00
0005433075078	11578	Economy	7200.00
0005432949009	11578	Economy	7200.00
0005433075076	11578	Economy	7200.00
0005433569018	11578	Economy	7200.00
0005433569234	11578	Economy	7200.00
0005433569072	11578	Economy	7200.00
0005432948999	11578	Economy	7200.00
0005432948998	11578	Economy	7200.00
0005433134199	11578	Economy	7200.00
0005433569193	11578	Economy	7200.00
0005433568839	11578	Economy	7200.00
0005433569132	11578	Economy	7200.00
0005433569228	11578	Economy	7200.00
0005433075098	11578	Economy	7200.00
0005433569290	11578	Economy	7200.00
0005432948977	11578	Economy	7200.00
0005433569046	11578	Economy	7200.00
0005432948979	11578	Economy	7200.00
0005433569071	11578	Economy	7200.00
0005433568880	11578	Economy	7200.00
0005433569291	11578	Economy	7200.00
0005433075075	11578	Economy	7200.00
0005433569159	11578	Economy	7200.00
0005432948984	11578	Economy	7200.00
0005432949007	11578	Economy	7200.00
0005433075089	11578	Economy	7200.00
0005432948993	11578	Economy	7200.00
0005433569531	11578	Economy	7200.00
0005432949011	11578	Economy	7900.00
0005432948975	11578	Economy	7900.00
0005433569182	11578	Economy	7900.00
0005433075081	11578	Economy	7900.00
0005433569530	11578	Economy	7900.00
0005433569054	11578	Economy	7200.00
0005433131768	11578	Economy	7200.00
0005433075094	11578	Economy	7200.00
0005432192362	11578	Economy	7200.00
0005432948978	11578	Economy	7900.00
0005433568974	11578	Economy	7200.00
0005433131771	11578	Economy	7200.00
0005432948986	11578	Economy	7200.00
0005432948994	11578	Economy	7200.00
0005433569352	11578	Economy	7200.00
0005433569267	11578	Economy	7200.00
0005432949013	11578	Economy	7200.00
0005433569100	11578	Economy	7200.00
0005433569467	11578	Economy	7200.00
0005433075091	11578	Economy	7200.00
0005432948976	11578	Economy	7200.00
0005432948982	11578	Economy	7200.00
0005433075099	11578	Economy	7200.00
0005433569163	11578	Economy	7200.00
0005433075085	11578	Economy	7200.00
0005432948992	11578	Economy	7200.00
0005433569466	11578	Economy	7200.00
0005433134201	11578	Economy	7200.00
0005432949005	11578	Economy	7200.00
0005433075084	11578	Economy	7200.00
0005432948991	11578	Economy	7200.00
0005433131770	11578	Economy	7200.00
0005433569463	11578	Economy	7200.00
0005433569410	11578	Economy	7200.00
0005433569245	11578	Economy	7200.00
0005433569377	11578	Economy	7200.00
0005433569280	11578	Economy	7200.00
0005433569253	11578	Economy	7200.00
0005432948995	11578	Economy	7200.00
0005432192361	11578	Economy	7200.00
0005433569465	11578	Economy	7200.00
0005433569179	11578	Economy	7200.00
0005433569161	11578	Economy	7200.00
0005433075080	11578	Economy	7200.00
0005432948981	11578	Economy	7200.00
0005433569451	11578	Economy	7200.00
0005432948974	11578	Economy	7200.00
0005432949002	11578	Economy	7200.00
0005432949010	11578	Economy	7200.00
0005433075082	11578	Economy	7200.00
0005433075087	11578	Economy	7200.00
0005433569351	11578	Economy	7200.00
0005433569160	11578	Economy	7200.00
0005432949008	11578	Economy	7200.00
0005433569464	11578	Economy	7200.00
0005433075072	11578	Economy	7200.00
0005433075097	11578	Economy	7200.00
0005432948990	11578	Economy	7200.00
0005433568840	11578	Economy	7200.00
0005433075090	11578	Economy	7200.00
0005433568994	11578	Economy	7200.00
0005433569183	11578	Economy	7200.00
0005433817520	9962	Economy	6300.00
0005433817519	9962	Economy	6300.00
0005433817522	9962	Economy	6300.00
0005434733000	9962	Economy	6300.00
0005434733005	9962	Economy	6300.00
0005433817521	9962	Economy	6300.00
0005434733027	13962	Economy	6300.00
0005434733028	13962	Economy	6300.00
0005433817465	13962	Economy	6300.00
0005433817478	13962	Economy	6300.00
0005434733029	13962	Economy	6300.00
0005433817494	13962	Economy	6300.00
0005433817466	13962	Economy	6300.00
0005433817493	13962	Economy	6300.00
0005434733026	13962	Economy	6300.00
0005433754966	2321	Business	184500.00
0005433754989	2321	Business	184500.00
0005435982936	2321	Business	184500.00
0005432226140	2321	Business	184500.00
0005432869560	2321	Business	184500.00
0005435982902	2321	Business	184500.00
0005435982898	2321	Business	184500.00
0005432655697	2321	Business	184500.00
0005432985233	2321	Business	184500.00
0005435982921	2321	Business	184500.00
0005433755002	2321	Business	184500.00
0005432985227	2321	Business	184500.00
0005435982932	2321	Business	184500.00
0005432869553	2321	Business	184500.00
0005435982915	2321	Business	184500.00
0005433754983	2321	Business	184500.00
0005435982916	2321	Business	184500.00
0005433754982	2321	Business	184500.00
0005435982931	2321	Business	184500.00
0005432655699	2321	Business	184500.00
0005433754951	2321	Business	184500.00
0005434731194	2321	Business	184500.00
0005433754960	2321	Business	184500.00
0005433755004	2321	Business	184500.00
0005435982940	2321	Business	184500.00
0005435982914	2321	Business	184500.00
0005433754967	2321	Economy	67700.00
0005433754973	2321	Business	184500.00
0005433754963	2321	Economy	67700.00
0005433434776	2321	Economy	67700.00
0005435982935	2321	Economy	67700.00
0005432869559	2321	Economy	61500.00
0005432985346	2321	Economy	61500.00
0005435982903	2321	Economy	61500.00
0005432869564	2321	Economy	61500.00
0005435982929	2321	Economy	61500.00
0005432985242	2321	Economy	61500.00
0005432985166	2321	Economy	61500.00
0005432985241	2321	Economy	61500.00
0005432300339	2321	Economy	61500.00
0005432985228	2321	Economy	61500.00
0005433754981	2321	Economy	61500.00
0005435982934	2321	Economy	61500.00
0005433754991	2321	Economy	61500.00
0005435982896	2321	Economy	61500.00
0005435982904	2321	Economy	61500.00
0005435982917	2321	Economy	61500.00
0005435982922	2321	Economy	61500.00
0005433754964	2321	Economy	61500.00
0005432985123	2321	Economy	61500.00
0005433754994	2321	Economy	61500.00
0005433754968	2321	Economy	61500.00
0005432985304	2321	Economy	61500.00
0005433434862	2321	Economy	61500.00
0005435982938	2321	Economy	61500.00
0005435982909	2321	Economy	61500.00
0005435982913	2321	Economy	61500.00
0005432226141	2321	Economy	61500.00
0005432985081	2321	Economy	61500.00
0005432869578	2321	Economy	61500.00
0005434731181	2321	Economy	61500.00
0005433766691	2321	Economy	61500.00
0005432985303	2321	Economy	61500.00
0005432655704	2321	Economy	61500.00
0005435982930	2321	Economy	61500.00
0005435982920	2321	Economy	61500.00
0005433754965	2321	Economy	61500.00
0005433434863	2321	Economy	61500.00
0005432300342	2321	Economy	61500.00
0005433434846	2321	Economy	61500.00
0005432985305	2321	Economy	61500.00
0005433754971	2321	Economy	61500.00
0005432869565	2321	Economy	61500.00
0005433754997	2321	Economy	61500.00
0005433754959	2321	Economy	61500.00
0005435982907	2321	Economy	61500.00
0005433754975	2321	Economy	61500.00
0005432985266	2321	Economy	61500.00
0005433754985	2321	Economy	61500.00
0005432985167	2321	Economy	61500.00
0005432985306	2321	Economy	61500.00
0005433754957	2321	Economy	61500.00
0005435982901	2321	Economy	61500.00
0005432985158	2321	Economy	61500.00
0005433755000	2321	Economy	61500.00
0005433764708	2321	Economy	61500.00
0005433754955	2321	Economy	61500.00
0005432985210	2321	Economy	61500.00
0005435982897	2321	Economy	61500.00
0005433754988	2321	Economy	61500.00
0005432985347	2321	Economy	61500.00
0005435982899	2321	Economy	61500.00
0005433754954	2321	Economy	61500.00
0005432300340	2321	Economy	61500.00
0005432985070	2321	Economy	61500.00
0005432985271	2321	Economy	61500.00
0005433434861	2321	Economy	61500.00
0005433754958	2321	Economy	61500.00
0005433754962	2321	Economy	61500.00
0005433754952	2321	Economy	61500.00
0005433754953	2321	Economy	61500.00
0005433754956	2321	Economy	61500.00
0005432300343	2321	Economy	61500.00
0005435982906	2321	Economy	61500.00
0005432300344	2321	Economy	61500.00
0005433434786	2321	Economy	61500.00
0005432655702	2321	Economy	61500.00
0005432985204	2321	Economy	61500.00
0005433766690	2321	Economy	61500.00
0005435982908	2321	Economy	61500.00
0005433434806	2321	Economy	61500.00
0005432985117	2321	Economy	61500.00
0005432655694	2321	Economy	61500.00
0005433754976	2321	Economy	61500.00
0005433434811	2321	Economy	61500.00
0005432985244	2321	Economy	61500.00
0005433434837	2321	Economy	61500.00
0005432655700	2321	Economy	61500.00
0005432655695	2321	Economy	61500.00
0005432985181	2321	Economy	61500.00
0005433434723	2321	Economy	61500.00
0005433755003	2321	Economy	61500.00
0005433755001	2321	Economy	61500.00
0005432985128	2321	Economy	61500.00
0005432655701	2321	Economy	61500.00
0005433754949	2321	Economy	61500.00
0005432985209	2321	Economy	67700.00
0005433754972	2321	Economy	67700.00
0005435982910	2321	Economy	61500.00
0005433434797	2321	Economy	61500.00
0005435982923	2321	Economy	61500.00
0005435982925	2321	Economy	67700.00
0005432985263	2321	Economy	67700.00
0005433754980	2321	Economy	61500.00
0005433766693	2321	Economy	61500.00
0005433766692	2321	Economy	61500.00
0005432985208	2321	Economy	61500.00
0005432985262	2321	Economy	61500.00
0005435982926	2321	Economy	61500.00
0005432869577	2321	Economy	61500.00
0005432985243	2321	Economy	61500.00
0005432226143	2321	Economy	61500.00
0005433754996	2321	Economy	61500.00
0005433434810	2321	Economy	61500.00
0005432985226	2321	Economy	61500.00
0005432655696	2321	Economy	61500.00
0005433754984	2321	Economy	61500.00
0005435982928	2321	Economy	61500.00
0005433754978	2321	Economy	61500.00
0005435982911	2321	Economy	61500.00
0005433434838	2321	Economy	61500.00
0005433434869	2321	Economy	61500.00
0005433754950	2321	Economy	61500.00
0005432985215	2321	Economy	61500.00
0005433754969	2321	Economy	61500.00
0005433434741	2321	Economy	61500.00
0005433434787	2321	Economy	61500.00
0005432985082	2321	Economy	61500.00
0005435982933	2321	Economy	61500.00
0005434731182	2321	Economy	61500.00
0005432655703	2321	Economy	61500.00
0005433754961	2321	Economy	61500.00
0005435982937	2321	Economy	61500.00
0005433434805	2321	Economy	61500.00
0005435982918	2321	Economy	61500.00
0005433754995	2321	Economy	61500.00
0005433434839	2321	Economy	61500.00
0005433754986	2321	Economy	61500.00
0005432985345	2321	Economy	61500.00
0005432869568	2321	Economy	61500.00
0005435982919	2321	Economy	61500.00
0005432985310	2321	Economy	61500.00
0005433754993	2321	Economy	61500.00
0005432655698	2321	Economy	61500.00
0005433434870	2321	Economy	61500.00
0005433754992	2321	Economy	61500.00
0005433434742	2321	Economy	61500.00
0005435982927	2321	Economy	61500.00
0005433434868	2321	Economy	61500.00
0005433754970	2321	Economy	61500.00
0005433754990	2321	Economy	61500.00
0005433434847	2321	Economy	61500.00
0005435982939	2321	Economy	61500.00
0005435982895	2321	Economy	61500.00
0005433754987	2321	Economy	61500.00
0005433754998	2321	Economy	61500.00
0005432300341	2321	Economy	61500.00
0005433434812	2321	Economy	61500.00
0005435982912	2321	Economy	61500.00
0005432985267	2321	Economy	61500.00
0005435982894	2321	Economy	61500.00
0005435982924	2321	Economy	61500.00
0005432226139	2321	Economy	61500.00
0005433754979	2321	Economy	61500.00
0005432869561	2321	Economy	61500.00
0005434731183	2321	Economy	61500.00
0005435982905	2321	Economy	61500.00
0005434731170	2321	Economy	61500.00
0005433434845	2321	Economy	61500.00
0005435982900	2321	Economy	61500.00
0005433764707	2321	Economy	61500.00
0005432985214	2321	Economy	61500.00
0005433754974	2321	Economy	61500.00
0005432985116	2321	Economy	61500.00
0005432226142	2321	Economy	61500.00
0005433754999	2321	Economy	61500.00
0005433754977	2321	Economy	61500.00
0005433754444	26168	Business	184500.00
0005433754599	26168	Business	184500.00
0005435982166	26168	Business	184500.00
0005432655562	26168	Business	184500.00
0005432985524	26168	Business	184500.00
0005432985508	26168	Business	184500.00
0005433754422	26168	Business	184500.00
0005432869608	26168	Business	184500.00
0005433754498	26168	Business	184500.00
0005433754362	26168	Business	184500.00
0005433435063	26168	Business	184500.00
0005433435071	26168	Business	184500.00
0005433435064	26168	Business	184500.00
0005433754491	26168	Business	184500.00
0005433435052	26168	Business	184500.00
0005433435051	26168	Business	184500.00
0005433435069	26168	Business	184500.00
0005432869610	26168	Business	184500.00
0005433435044	26168	Business	184500.00
0005435982465	26168	Business	184500.00
0005433754715	26168	Business	184500.00
0005432985521	26168	Business	184500.00
0005435982457	26168	Business	184500.00
0005432869609	26168	Business	184500.00
0005435982425	26168	Business	184500.00
0005432985502	26168	Business	184500.00
0005433754566	26168	Business	184500.00
0005433754351	26168	Business	184500.00
0005434376159	26168	Economy	67700.00
0005433754365	26168	Economy	67700.00
0005433754537	26168	Economy	67700.00
0005433766665	26168	Economy	67700.00
0005432985514	26168	Economy	61500.00
0005435982442	26168	Economy	61500.00
0005435982598	26168	Economy	61500.00
0005433754490	26168	Economy	61500.00
0005435982424	26168	Economy	61500.00
0005435982493	26168	Economy	61500.00
0005433754557	26168	Economy	61500.00
0005432051171	26168	Economy	61500.00
0005432985510	26168	Economy	61500.00
0005433754554	26168	Economy	61500.00
0005432655584	26168	Economy	61500.00
0005432049510	26168	Economy	61500.00
0005432655585	26168	Economy	61500.00
0005432985516	26168	Economy	61500.00
0005433754567	26168	Economy	61500.00
0005433766675	26168	Economy	61500.00
0005432869607	26168	Economy	61500.00
0005432655552	26168	Economy	61500.00
0005433754370	26168	Economy	61500.00
0005432985518	26168	Economy	61500.00
0005433754640	26168	Economy	61500.00
0005433754766	26168	Economy	61500.00
0005432655578	26168	Economy	61500.00
0005433435062	26168	Economy	61500.00
0005433435047	26168	Economy	61500.00
0005433435043	26168	Economy	61500.00
0005432655520	26168	Economy	61500.00
0005432985506	26168	Economy	61500.00
0005432985522	26168	Economy	61500.00
0005432985503	26168	Economy	61500.00
0005433754547	26168	Economy	61500.00
0005433754306	26168	Economy	61500.00
0005432985515	26168	Economy	61500.00
0005433435058	26168	Economy	61500.00
0005433754543	26168	Economy	61500.00
0005434731228	26168	Economy	61500.00
0005432655553	26168	Economy	61500.00
0005435982464	26168	Economy	61500.00
0005432655530	26168	Economy	61500.00
0005432049513	26168	Economy	61500.00
0005435982324	26168	Economy	61500.00
0005433754616	26168	Economy	61500.00
0005432655579	26168	Economy	61500.00
0005435982593	26168	Economy	61500.00
0005432985495	26168	Economy	61500.00
0005432985525	26168	Economy	61500.00
0005435982467	26168	Economy	61500.00
0005435982568	26168	Economy	61500.00
0005432051170	26168	Economy	61500.00
0005435982567	26168	Economy	61500.00
0005433754364	26168	Economy	61500.00
0005433754439	26168	Economy	61500.00
0005434731227	26168	Economy	61500.00
0005435982486	26168	Economy	61500.00
0005435982435	26168	Economy	61500.00
0005432655627	26168	Economy	61500.00
0005433754376	26168	Economy	61500.00
0005433754352	26168	Economy	61500.00
0005432985509	26168	Economy	61500.00
0005432985497	26168	Economy	61500.00
0005435982543	26168	Economy	61500.00
0005433754433	26168	Economy	61500.00
0005433754275	26168	Economy	61500.00
0005432985523	26168	Economy	61500.00
0005435982394	26168	Economy	61500.00
0005432655550	26168	Economy	61500.00
0005435982557	26168	Economy	61500.00
0005432655529	26168	Economy	61500.00
0005435982294	26168	Economy	61500.00
0005433754500	26168	Economy	61500.00
0005433435050	26168	Economy	61500.00
0005432655515	26168	Economy	61500.00
0005433754538	26168	Economy	61500.00
0005433435046	26168	Economy	61500.00
0005432985498	26168	Economy	61500.00
0005433754343	26168	Economy	61500.00
0005432985501	26168	Economy	61500.00
0005433435056	26168	Economy	61500.00
0005433435048	26168	Economy	61500.00
0005435982485	26168	Economy	61500.00
0005433754474	26168	Economy	61500.00
0005433754625	26168	Economy	61500.00
0005433754492	26168	Economy	61500.00
0005432655589	26168	Economy	61500.00
0005433435057	26168	Economy	61500.00
0005432049514	26168	Economy	61500.00
0005433754617	26168	Economy	61500.00
0005433435049	26168	Economy	61500.00
0005433754553	26168	Economy	61500.00
0005433435045	26168	Economy	61500.00
0005435982532	26168	Economy	61500.00
0005433754548	26168	Economy	61500.00
0005432655597	26168	Economy	61500.00
0005433754454	26168	Economy	61500.00
0005432985517	26168	Economy	61500.00
0005432049511	26168	Economy	61500.00
0005432985500	26168	Economy	67700.00
0005433435061	26168	Economy	61500.00
0005434731229	26168	Economy	67700.00
0005433435060	26168	Economy	61500.00
0005435982360	26168	Economy	67700.00
0005433754291	26168	Economy	67700.00
0005434731226	26168	Economy	61500.00
0005432655577	26168	Economy	61500.00
0005433754693	26168	Economy	61500.00
0005435982293	26168	Economy	61500.00
0005435982494	26168	Economy	61500.00
0005433754486	26168	Economy	61500.00
0005435982565	26168	Economy	61500.00
0005432985505	26168	Economy	61500.00
0005433754473	26168	Economy	61500.00
0005433435067	26168	Economy	61500.00
0005433754717	26168	Economy	61500.00
0005433435054	26168	Economy	61500.00
0005432985519	26168	Economy	61500.00
0005433754402	26168	Economy	61500.00
0005433754598	26168	Economy	61500.00
0005433754363	26168	Economy	61500.00
0005432985511	26168	Economy	61500.00
0005432985526	26168	Economy	61500.00
0005433435065	26168	Economy	61500.00
0005435982571	26168	Economy	61500.00
0005433754344	26168	Economy	61500.00
0005432655531	26168	Economy	61500.00
0005435982549	26168	Economy	61500.00
0005435982332	26168	Economy	61500.00
0005434731230	26168	Economy	61500.00
0005433754712	26168	Economy	61500.00
0005435982534	26168	Economy	61500.00
0005433764688	26168	Economy	61500.00
0005435982487	26168	Economy	61500.00
0005435982520	26168	Economy	61500.00
0005432985520	26168	Economy	61500.00
0005433754489	26168	Economy	61500.00
0005432985512	26168	Economy	61500.00
0005433435055	26168	Economy	61500.00
0005435982456	26168	Economy	61500.00
0005433754238	26168	Economy	61500.00
0005433754395	26168	Economy	61500.00
0005433754394	26168	Economy	61500.00
0005432985507	26168	Economy	61500.00
0005433754716	26168	Economy	61500.00
0005432985513	26168	Economy	61500.00
0005432985504	26168	Economy	61500.00
0005433754393	26168	Economy	61500.00
0005432869614	26168	Economy	61500.00
0005432985527	26168	Economy	61500.00
0005432869612	26168	Economy	61500.00
0005433754382	26168	Economy	61500.00
0005433754290	26168	Economy	61500.00
0005433754371	26168	Economy	61500.00
0005432869615	26168	Economy	61500.00
0005432049512	26168	Economy	61500.00
0005435982535	26168	Economy	61500.00
0005432051169	26168	Economy	61500.00
0005433435070	26168	Economy	61500.00
0005435982361	26168	Economy	61500.00
0005432869613	26168	Economy	61500.00
0005433435066	26168	Economy	61500.00
0005433754713	26168	Economy	61500.00
0005433754499	26168	Economy	61500.00
0005433754536	26168	Economy	61500.00
0005433754480	26168	Economy	61500.00
0005433754720	26168	Economy	61500.00
0005435982326	26168	Economy	61500.00
0005435982564	26168	Economy	61500.00
0005433435059	26168	Economy	61500.00
0005433754509	26168	Economy	61500.00
0005432985499	26168	Economy	61500.00
0005433435068	26168	Economy	61500.00
0005435982563	26168	Economy	61500.00
0005435982533	26168	Economy	61500.00
0005433754434	26168	Economy	61500.00
0005433435053	26168	Economy	61500.00
0005435982403	26168	Economy	61500.00
0005432869611	26168	Economy	61500.00
0005435982578	26168	Economy	61500.00
0005435982466	26168	Economy	61500.00
0005432985496	26168	Economy	61500.00
0005433151604	1503	Business	38900.00
0005433151605	1503	Business	38900.00
0005434375231	1503	Business	38900.00
0005433151456	1503	Business	38900.00
0005434375266	1503	Business	38900.00
0005433460466	1503	Business	38900.00
0005434375262	1503	Business	38900.00
0005434375253	1503	Business	38900.00
0005432267983	1503	Business	38900.00
0005434375259	1503	Business	38900.00
0005433151541	1503	Economy	13000.00
0005434375252	1503	Economy	13000.00
0005434375236	1503	Economy	13000.00
0005434375242	1503	Economy	13000.00
0005434375279	1503	Economy	13000.00
0005432267985	1503	Economy	13000.00
0005433151576	1503	Economy	13000.00
0005433151603	1503	Economy	13000.00
0005434375269	1503	Economy	13000.00
0005433151777	1503	Economy	13000.00
0005434375270	1503	Economy	13000.00
0005433151192	1503	Economy	13000.00
0005433151612	1503	Economy	13000.00
0005434375268	1503	Economy	13000.00
0005433460464	1503	Economy	13000.00
0005434375245	1503	Economy	13000.00
0005434375276	1503	Economy	13000.00
0005434375243	1503	Economy	13000.00
0005433151657	1503	Economy	13000.00
0005433151638	1503	Economy	13000.00
0005433151577	1503	Economy	13000.00
0005433151555	1503	Economy	13000.00
0005434375272	1503	Economy	13000.00
0005434375277	1503	Economy	13000.00
0005434375237	1503	Economy	13000.00
0005433151536	1503	Economy	13000.00
0005433151486	1503	Economy	13000.00
0005434375249	1503	Economy	13000.00
0005432267987	1503	Economy	13000.00
0005432267982	1503	Economy	13000.00
0005434375232	1503	Economy	14300.00
0005434375263	1503	Economy	14300.00
0005434029664	1503	Economy	14300.00
0005433151361	1503	Economy	14300.00
0005434375258	1503	Economy	14300.00
0005433151492	1503	Economy	14300.00
0005434375273	1503	Economy	13000.00
0005434375246	1503	Economy	13000.00
0005434375260	1503	Economy	13000.00
0005433151624	1503	Economy	13000.00
0005433151543	1503	Economy	13000.00
0005433151611	1503	Economy	13000.00
0005433151418	1503	Economy	13000.00
0005433151538	1503	Economy	13000.00
0005434375257	1503	Economy	13000.00
0005434375255	1503	Economy	13000.00
0005434375271	1503	Economy	13000.00
0005433151485	1503	Economy	13000.00
0005433764685	1503	Economy	13000.00
0005434375241	1503	Economy	13000.00
0005434029674	1503	Economy	13000.00
0005434375261	1503	Economy	13000.00
0005433151728	1503	Economy	13000.00
0005433151643	1503	Economy	13000.00
0005434375238	1503	Economy	13000.00
0005434029663	1503	Economy	13000.00
0005434375233	1503	Economy	13000.00
0005434375239	1503	Economy	13000.00
0005434375247	1503	Economy	13000.00
0005434375278	1503	Economy	13000.00
0005434375254	1503	Economy	13000.00
0005433151750	1503	Economy	13000.00
0005434375274	1503	Economy	13000.00
0005434375250	1503	Economy	13000.00
0005434375280	1503	Economy	13000.00
0005434375234	1503	Economy	13000.00
0005433461618	1503	Economy	13000.00
0005433460465	1503	Economy	13000.00
0005433151548	1503	Economy	13000.00
0005434375264	1503	Economy	13000.00
0005433151546	1503	Economy	13000.00
0005433151641	1503	Economy	13000.00
0005434375244	1503	Economy	13000.00
0005433151594	1503	Economy	13000.00
0005433151606	1503	Economy	13000.00
0005434375235	1503	Economy	13000.00
0005433151593	1503	Economy	13000.00
0005432267984	1503	Economy	13000.00
0005433461617	1503	Economy	13000.00
0005433151656	1503	Economy	13000.00
0005434375265	1503	Economy	13000.00
0005433151645	1503	Economy	13000.00
0005434375248	1503	Economy	13000.00
0005434375251	1503	Economy	13000.00
0005434375267	1503	Economy	13000.00
0005433151554	1503	Economy	13000.00
0005433151698	1503	Economy	13000.00
0005433151419	1503	Economy	13000.00
0005434375240	1503	Economy	13000.00
0005433151542	1503	Economy	13000.00
0005433151529	1503	Economy	13000.00
0005433151528	1503	Economy	13000.00
0005434375256	1503	Economy	13000.00
0005432267988	1503	Economy	13000.00
0005432267986	1503	Economy	13000.00
0005434375230	1503	Economy	13000.00
0005433151537	1503	Economy	13000.00
0005434375275	1503	Economy	13000.00
0005434375044	20113	Business	38900.00
0005434374891	20113	Business	38900.00
0005433151863	20113	Business	38900.00
0005433931510	20113	Business	38900.00
0005434374783	20113	Business	38900.00
0005434374923	20113	Business	38900.00
0005433151849	20113	Economy	13000.00
0005434375025	20113	Economy	13000.00
0005434375100	20113	Economy	13000.00
0005433151859	20113	Economy	13000.00
0005433151881	20113	Economy	13000.00
0005434374820	20113	Economy	13000.00
0005434374809	20113	Economy	13000.00
0005434374822	20113	Economy	13000.00
0005434374807	20113	Economy	13000.00
0005434374949	20113	Economy	13000.00
0005433151875	20113	Economy	13000.00
0005433151874	20113	Economy	13000.00
0005433151856	20113	Economy	13000.00
0005433151858	20113	Economy	13000.00
0005433151876	20113	Economy	13000.00
0005434374806	20113	Economy	13000.00
0005432056348	20113	Economy	13000.00
0005433151866	20113	Economy	13000.00
0005433151879	20113	Economy	13000.00
0005433151872	20113	Economy	13000.00
0005433151850	20113	Economy	13000.00
0005433151878	20113	Economy	13000.00
0005434374890	20113	Economy	13000.00
0005434374818	20113	Economy	13000.00
0005433151852	20113	Economy	13000.00
0005434375045	20113	Economy	13000.00
0005433151877	20113	Economy	13000.00
0005432056351	20113	Economy	13000.00
0005432056349	20113	Economy	13000.00
0005433151883	20113	Economy	13000.00
0005433931508	20113	Economy	14300.00
0005434374781	20113	Economy	14300.00
0005434029692	20113	Economy	14300.00
0005434374758	20113	Economy	14300.00
0005433764707	20113	Economy	14300.00
0005433151880	20113	Economy	14300.00
0005433151868	20113	Economy	13000.00
0005433151864	20113	Economy	13000.00
0005434374704	20113	Economy	13000.00
0005434374706	20113	Economy	13000.00
0005434374819	20113	Economy	13000.00
0005434029691	20113	Economy	13000.00
0005433151857	20113	Economy	13000.00
0005434375046	20113	Economy	13000.00
0005434374779	20113	Economy	13000.00
0005434374796	20113	Economy	13000.00
0005434374775	20113	Economy	13000.00
0005434374708	20113	Economy	13000.00
0005433151865	20113	Economy	13000.00
0005434374786	20113	Economy	13000.00
0005434374953	20113	Economy	13000.00
0005433151870	20113	Economy	13000.00
0005434374805	20113	Economy	13000.00
0005434374780	20113	Economy	13000.00
0005434374714	20113	Economy	13000.00
0005432056350	20113	Economy	13000.00
0005434374884	20113	Economy	13000.00
0005433151853	20113	Economy	13000.00
0005433151854	20113	Economy	13000.00
0005433151871	20113	Economy	13000.00
0005434374830	20113	Economy	13000.00
0005433931509	20113	Economy	13000.00
0005433151873	20113	Economy	13000.00
0005433151882	20113	Economy	13000.00
0005434374801	20113	Economy	13000.00
0005433764708	20113	Economy	13000.00
0005434374707	20113	Economy	13000.00
0005434374812	20113	Economy	13000.00
0005433151848	20113	Economy	13000.00
0005434374795	20113	Economy	13000.00
0005434374951	20113	Economy	13000.00
0005434374987	20113	Economy	13000.00
0005433931507	20113	Economy	13000.00
0005434374883	20113	Economy	13000.00
0005433151869	20113	Economy	13000.00
0005433151855	20113	Economy	13000.00
0005433151861	20113	Economy	13000.00
0005434374975	20113	Economy	13000.00
0005434374773	20113	Economy	13000.00
0005433151867	20113	Economy	13000.00
0005434374935	20113	Economy	13000.00
0005434374950	20113	Economy	13000.00
0005433151851	20113	Economy	13000.00
0005433151862	20113	Economy	13000.00
0005433151860	20113	Economy	13000.00
0005434375009	20113	Economy	13000.00
0005434374799	20113	Economy	13000.00
0005434374774	20113	Economy	13000.00
0005432425102	596	Business	27500.00
0005432425082	596	Business	27500.00
0005432425086	596	Business	27500.00
0005432282956	596	Business	27500.00
0005432425103	596	Business	27500.00
0005432425092	596	Business	27500.00
0005432425122	596	Business	27500.00
0005432425078	596	Business	27500.00
0005432425107	596	Business	27500.00
0005432282960	596	Business	27500.00
0005432282961	596	Business	27500.00
0005432425090	596	Business	27500.00
0005432425097	596	Economy	10100.00
0005432425087	596	Economy	9200.00
0005432425085	596	Economy	9200.00
0005432425091	596	Economy	9200.00
0005432425113	596	Economy	9200.00
0005432425120	596	Economy	9200.00
0005432425095	596	Economy	9200.00
0005432425084	596	Economy	9200.00
0005432282957	596	Economy	9200.00
0005432425099	596	Economy	9200.00
0005432425123	596	Economy	9200.00
0005432425077	596	Economy	9200.00
0005432425080	596	Economy	9200.00
0005432425110	596	Economy	9200.00
0005432425100	596	Economy	9200.00
0005432425088	596	Economy	9200.00
0005432425111	596	Economy	9200.00
0005432425121	596	Economy	9200.00
0005432425114	596	Economy	9200.00
0005432425105	596	Economy	9200.00
0005432425093	596	Economy	10100.00
0005432425081	596	Economy	10100.00
0005432425076	596	Economy	9200.00
0005432282959	596	Economy	9200.00
0005432425117	596	Economy	9200.00
0005432282958	596	Economy	9200.00
0005432425096	596	Economy	9200.00
0005432425098	596	Economy	9200.00
0005432425106	596	Economy	9200.00
0005432425094	596	Economy	9200.00
0005432425109	596	Economy	9200.00
0005432425115	596	Economy	9200.00
0005432425104	596	Economy	9200.00
0005432425101	596	Economy	9200.00
0005432425083	596	Economy	9200.00
0005432425119	596	Economy	9200.00
0005432425079	596	Economy	9200.00
0005432425089	596	Economy	9200.00
0005432425116	596	Economy	9200.00
0005432425108	596	Economy	9200.00
0005432425112	596	Economy	9200.00
0005432425118	596	Economy	9200.00
0005432282955	596	Economy	9200.00
0005432302382	12846	Business	27500.00
0005432302380	12846	Business	27500.00
0005432302381	12846	Economy	9200.00
0005434446519	12846	Economy	9200.00
0005433158159	12846	Economy	9200.00
0005433158161	12846	Economy	9200.00
0005433158162	12846	Economy	9200.00
0005433158160	12846	Economy	9200.00
0005432302383	12846	Economy	9200.00
0005433158158	12846	Economy	9200.00
0005432424515	12855	Business	27500.00
0005432424603	12855	Business	27500.00
0005432424379	12855	Business	27500.00
0005432424583	12855	Business	27500.00
0005432424638	12855	Business	27500.00
0005432424537	12855	Economy	10100.00
0005432424578	12855	Economy	10100.00
0005432424393	12855	Economy	9200.00
0005432424577	12855	Economy	9200.00
0005432424595	12855	Economy	9200.00
0005432424637	12855	Economy	9200.00
0005432424538	12855	Economy	9200.00
0005432424647	12855	Economy	9200.00
0005432424650	12855	Economy	9200.00
0005432424634	12855	Economy	9200.00
0005432424601	12855	Economy	9200.00
0005432424619	12855	Economy	9200.00
0005432424633	12855	Economy	9200.00
0005432424635	12855	Economy	9200.00
0005432424626	12855	Economy	9200.00
0005432424627	12855	Economy	9200.00
0005432424473	12855	Economy	9200.00
0005432424590	12855	Economy	9200.00
0005432424639	12855	Economy	9200.00
0005432424582	12855	Economy	9200.00
0005432424614	12855	Economy	9200.00
0005432424526	12855	Economy	9200.00
0005432424471	12855	Economy	10100.00
0005432424474	12855	Economy	9200.00
0005432424609	12855	Economy	9200.00
0005432424378	12855	Economy	9200.00
0005432424584	12855	Economy	9200.00
0005432424525	12855	Economy	9200.00
0005432424587	12855	Economy	9200.00
0005432424673	12855	Economy	9200.00
0005432424510	12855	Economy	9200.00
0005432424469	12855	Economy	9200.00
0005432424630	12855	Economy	9200.00
0005432424491	12855	Economy	9200.00
0005432424629	12855	Economy	9200.00
0005432424631	12855	Economy	9200.00
0005432424600	12855	Economy	9200.00
0005432424654	12855	Economy	9200.00
0005432424606	12855	Economy	9200.00
0005432424620	12855	Economy	9200.00
0005432424663	12855	Economy	9200.00
0005432424664	12855	Economy	9200.00
0005432424632	12855	Economy	9200.00
0005432424470	12855	Economy	9200.00
0005432424338	12855	Economy	9200.00
0005432424670	12855	Economy	9200.00
0005432424448	12855	Economy	9200.00
0005433058122	436	Business	24500.00
0005434029690	436	Business	24500.00
0005434029688	436	Business	24500.00
0005433058080	436	Business	24500.00
0005434024649	436	Business	24500.00
0005434024599	436	Business	24500.00
0005434028336	436	Business	24500.00
0005433058124	436	Business	24500.00
0005434024622	436	Business	24500.00
0005434024640	436	Business	24500.00
0005434024607	436	Business	24500.00
0005433058170	436	Business	24500.00
0005434024619	436	Business	24500.00
0005433058146	436	Business	24500.00
0005433058153	436	Business	24500.00
0005434024625	436	Business	24500.00
0005433058193	436	Economy	8200.00
0005432235740	436	Economy	8200.00
0005434024597	436	Economy	8200.00
0005433058281	436	Economy	8200.00
0005433058272	436	Economy	8200.00
0005433058051	436	Economy	8200.00
0005433058279	436	Economy	8200.00
0005434024616	436	Economy	8200.00
0005433058032	436	Economy	8200.00
0005434024646	436	Economy	8200.00
0005434024610	436	Economy	8200.00
0005434024617	436	Economy	8200.00
0005433058054	436	Economy	8200.00
0005433058125	436	Economy	8200.00
0005434028334	436	Economy	8200.00
0005434024620	436	Economy	8200.00
0005434024630	436	Economy	8200.00
0005434024618	436	Economy	8200.00
0005434024631	436	Economy	8200.00
0005434024615	436	Economy	8200.00
0005434024626	436	Economy	8200.00
0005432235737	436	Economy	8200.00
0005434024643	436	Economy	8200.00
0005434024593	436	Economy	8200.00
0005434024641	436	Economy	8200.00
0005433058280	436	Economy	8200.00
0005433058194	436	Economy	8200.00
0005434024592	436	Economy	8200.00
0005434028337	436	Economy	8200.00
0005433058147	436	Economy	8200.00
0005434024634	436	Economy	8200.00
0005433058081	436	Economy	8200.00
0005434029689	436	Economy	8200.00
0005434024587	436	Economy	8200.00
0005434024602	436	Economy	8200.00
0005434024609	436	Economy	8200.00
0005434024596	436	Economy	8200.00
0005434024603	436	Economy	8200.00
0005432235736	436	Economy	8200.00
0005434024598	436	Economy	8200.00
0005434032080	436	Economy	8200.00
0005434024633	436	Economy	8200.00
0005433058131	436	Economy	8200.00
0005434024595	436	Economy	8200.00
0005433058123	436	Economy	8200.00
0005434024586	436	Economy	8200.00
0005434024583	436	Economy	8200.00
0005433929630	436	Economy	8200.00
0005434024628	436	Economy	8200.00
0005432045639	436	Economy	8200.00
0005433058084	436	Economy	8200.00
0005434024632	436	Economy	8200.00
0005433058118	436	Economy	8200.00
0005434024635	436	Economy	8200.00
0005433057993	436	Economy	8200.00
0005434032081	436	Economy	8200.00
0005433058085	436	Economy	8200.00
0005433058003	436	Economy	8200.00
0005433058050	436	Economy	8200.00
0005434024582	436	Economy	8200.00
0005433058144	436	Economy	8200.00
0005434032083	436	Economy	8200.00
0005432235738	436	Economy	8200.00
0005434024601	436	Economy	8200.00
0005433058143	436	Economy	9000.00
0005433057994	436	Economy	8200.00
0005434024604	436	Economy	8200.00
0005433058208	436	Economy	9000.00
0005434024600	436	Economy	8200.00
0005434024588	436	Economy	8200.00
0005432235739	436	Economy	8200.00
0005434024612	436	Economy	8200.00
0005434024590	436	Economy	8200.00
0005434024648	436	Economy	8200.00
0005434032082	436	Economy	8200.00
0005432045638	436	Economy	8200.00
0005432235742	436	Economy	8200.00
0005434024614	436	Economy	8200.00
0005433058238	436	Economy	8200.00
0005434024594	436	Economy	8200.00
0005434024645	436	Economy	8200.00
0005434024629	436	Economy	8200.00
0005434024647	436	Economy	8200.00
0005434029687	436	Economy	8200.00
0005434024584	436	Economy	8200.00
0005433058135	436	Economy	8200.00
0005434735717	436	Economy	8200.00
0005434024606	436	Economy	8200.00
0005433058103	436	Economy	8200.00
0005433058169	436	Economy	8200.00
0005434024639	436	Economy	8200.00
0005434024621	436	Economy	8200.00
0005434028333	436	Economy	8200.00
0005434024581	436	Economy	8200.00
0005434024627	436	Economy	8200.00
0005434024636	436	Economy	8200.00
0005433058178	436	Economy	8200.00
0005434024638	436	Economy	8200.00
0005434024613	436	Economy	8200.00
0005434024605	436	Economy	8200.00
0005434024624	436	Economy	8200.00
0005434024642	436	Economy	8200.00
0005434024611	436	Economy	8200.00
0005434024589	436	Economy	8200.00
0005433058055	436	Economy	8200.00
0005434024644	436	Economy	8200.00
0005434028335	436	Economy	8200.00
0005434024608	436	Economy	8200.00
0005433058177	436	Economy	8200.00
0005434024585	436	Economy	8200.00
0005432235741	436	Economy	8200.00
0005434024591	436	Economy	8200.00
0005433058149	436	Economy	8200.00
0005434024623	436	Economy	8200.00
0005434024637	436	Economy	8200.00
0005433058083	436	Economy	8200.00
0005433058416	12696	Business	24500.00
0005433058412	12696	Business	24500.00
0005434032031	12696	Business	24500.00
0005434023948	12696	Business	24500.00
0005434735762	12696	Business	24500.00
0005433058415	12696	Business	24500.00
0005434029663	12696	Business	24500.00
0005434024165	12696	Business	24500.00
0005433929668	12696	Business	24500.00
0005434024155	12696	Business	24500.00
0005434023884	12696	Business	24500.00
0005434023975	12696	Business	24500.00
0005434024156	12696	Business	24500.00
0005434024084	12696	Business	24500.00
0005434023934	12696	Business	24500.00
0005434024179	12696	Business	24500.00
0005434024114	12696	Business	24500.00
0005433058409	12696	Business	24500.00
0005434023980	12696	Business	24500.00
0005432156423	12696	Business	24500.00
0005434024293	12696	Business	24500.00
0005434023914	12696	Business	24500.00
0005433058438	12696	Economy	9000.00
0005434029664	12696	Economy	8200.00
0005434023898	12696	Economy	8200.00
0005434024262	12696	Economy	8200.00
0005434024229	12696	Economy	8200.00
0005434024079	12696	Economy	8200.00
0005434024128	12696	Economy	8200.00
0005433058423	12696	Economy	8200.00
0005433058440	12696	Economy	8200.00
0005434024364	12696	Economy	8200.00
0005433058441	12696	Economy	8200.00
0005434024185	12696	Economy	8200.00
0005434024143	12696	Economy	8200.00
0005434735759	12696	Economy	8200.00
0005434024008	12696	Economy	8200.00
0005433929667	12696	Economy	8200.00
0005434024099	12696	Economy	8200.00
0005433058429	12696	Economy	8200.00
0005434024123	12696	Economy	8200.00
0005434023820	12696	Economy	8200.00
0005433058425	12696	Economy	8200.00
0005433058420	12696	Economy	8200.00
0005434023987	12696	Economy	8200.00
0005433058433	12696	Economy	8200.00
0005434024007	12696	Economy	8200.00
0005434023764	12696	Economy	8200.00
0005433058431	12696	Economy	8200.00
0005432156427	12696	Economy	8200.00
0005433929669	12696	Economy	8200.00
0005433058427	12696	Economy	8200.00
0005434023924	12696	Economy	8200.00
0005433058404	12696	Economy	8200.00
0005434023949	12696	Economy	8200.00
0005433058402	12696	Economy	8200.00
0005434024001	12696	Economy	8200.00
0005433058417	12696	Economy	8200.00
0005434023919	12696	Economy	8200.00
0005434024000	12696	Economy	8200.00
0005433929666	12696	Economy	8200.00
0005433058435	12696	Economy	8200.00
0005433058421	12696	Economy	8200.00
0005433058405	12696	Economy	8200.00
0005434024132	12696	Economy	8200.00
0005433684449	12696	Economy	8200.00
0005433058419	12696	Economy	8200.00
0005432156425	12696	Economy	8200.00
0005434023986	12696	Economy	8200.00
0005434024294	12696	Economy	8200.00
0005433929670	12696	Economy	8200.00
0005434023944	12696	Economy	8200.00
0005434024012	12696	Economy	8200.00
0005434735760	12696	Economy	8200.00
0005434024230	12696	Economy	8200.00
0005434024256	12696	Economy	8200.00
0005434024227	12696	Economy	8200.00
0005434024076	12696	Economy	8200.00
0005433058410	12696	Economy	8200.00
0005434023763	12696	Economy	8200.00
0005433058413	12696	Economy	8200.00
0005433058437	12696	Economy	8200.00
0005433058406	12696	Economy	8200.00
0005434024134	12696	Economy	8200.00
0005434023899	12696	Economy	8200.00
0005432157518	12696	Economy	8200.00
0005433058403	12696	Economy	8200.00
0005434032040	12696	Economy	8200.00
0005433058418	12696	Economy	9000.00
0005434028303	12696	Economy	8200.00
0005433058432	12696	Economy	8200.00
0005433058439	12696	Economy	8200.00
0005434024094	12696	Economy	9000.00
0005434024013	12696	Economy	8200.00
0005433058414	12696	Economy	8200.00
0005433058436	12696	Economy	8200.00
0005434024144	12696	Economy	8200.00
0005434024080	12696	Economy	8200.00
0005432156426	12696	Economy	8200.00
0005433058430	12696	Economy	8200.00
0005434023920	12696	Economy	8200.00
0005434024108	12696	Economy	8200.00
0005434024002	12696	Economy	8200.00
0005434024263	12696	Economy	8200.00
0005434024113	12696	Economy	8200.00
0005434028308	12696	Economy	8200.00
0005434029674	12696	Economy	8200.00
0005434024153	12696	Economy	8200.00
0005434032033	12696	Economy	8200.00
0005432156424	12696	Economy	8200.00
0005433058426	12696	Economy	8200.00
0005434024178	12696	Economy	8200.00
0005433684448	12696	Economy	8200.00
0005433058428	12696	Economy	8200.00
0005432157517	12696	Economy	8200.00
0005434735761	12696	Economy	8200.00
0005434023930	12696	Economy	8200.00
0005434024051	12696	Economy	8200.00
0005434028302	12696	Economy	8200.00
0005433058407	12696	Economy	8200.00
0005433058411	12696	Economy	8200.00
0005434024149	12696	Economy	8200.00
0005434023818	12696	Economy	8200.00
0005434032043	12696	Economy	8200.00
0005434032042	12696	Economy	8200.00
0005434024135	12696	Economy	8200.00
0005434023897	12696	Economy	8200.00
0005433058424	12696	Economy	8200.00
0005433058408	12696	Economy	8200.00
0005433058422	12696	Economy	8200.00
0005434023999	12696	Economy	8200.00
0005434023753	12696	Economy	8200.00
0005434024074	12696	Economy	8200.00
0005433058434	12696	Economy	8200.00
0005434024093	12696	Economy	8200.00
0005434028304	12696	Economy	8200.00
0005434023834	12696	Economy	8200.00
0005433924584	2115	Business	34700.00
0005433924601	2115	Business	34700.00
0005433924581	2115	Business	34700.00
0005433924566	2115	Business	34700.00
0005433924546	2115	Business	34700.00
0005433036483	2115	Business	34700.00
0005433036404	2115	Business	34700.00
0005433924534	2115	Business	34700.00
0005433036804	2115	Business	34700.00
0005433924552	2115	Business	34700.00
0005433924565	2115	Business	34700.00
0005433924590	2115	Business	34700.00
0005433924554	2115	Business	34700.00
0005433924600	2115	Business	34700.00
0005433036542	2115	Business	34700.00
0005433036490	2115	Business	34700.00
0005433924571	2115	Business	34700.00
0005433924555	2115	Business	34700.00
0005432231709	2115	Business	34700.00
0005432749791	2115	Business	34700.00
0005433924602	2115	Business	34700.00
0005433036585	2115	Business	34700.00
0005433924630	2115	Business	34700.00
0005433924624	2115	Economy	12700.00
0005433924591	2115	Economy	12700.00
0005433036599	2115	Economy	12700.00
0005433924609	2115	Economy	12700.00
0005433924551	2115	Economy	11600.00
0005433036515	2115	Economy	11600.00
0005433036646	2115	Economy	11600.00
0005433036502	2115	Economy	11600.00
0005433036558	2115	Economy	11600.00
0005433929667	2115	Economy	11600.00
0005433924549	2115	Economy	11600.00
0005433924621	2115	Economy	11600.00
0005433924557	2115	Economy	11600.00
0005433924599	2115	Economy	11600.00
0005433036670	2115	Economy	11600.00
0005433924608	2115	Economy	11600.00
0005433924545	2115	Economy	11600.00
0005432231708	2115	Economy	11600.00
0005432231710	2115	Economy	11600.00
0005433924625	2115	Economy	11600.00
0005433924598	2115	Economy	11600.00
0005433036455	2115	Economy	11600.00
0005433036489	2115	Economy	11600.00
0005433924540	2115	Economy	11600.00
0005433036671	2115	Economy	11600.00
0005433924606	2115	Economy	11600.00
0005433924563	2115	Economy	11600.00
0005433929668	2115	Economy	11600.00
0005433924537	2115	Economy	11600.00
0005433036363	2115	Economy	11600.00
0005433924617	2115	Economy	11600.00
0005433924610	2115	Economy	11600.00
0005433924575	2115	Economy	11600.00
0005433924611	2115	Economy	11600.00
0005433036444	2115	Economy	11600.00
0005433036644	2115	Economy	11600.00
0005433036503	2115	Economy	11600.00
0005432044562	2115	Economy	11600.00
0005433924612	2115	Economy	11600.00
0005434028302	2115	Economy	11600.00
0005432749801	2115	Economy	11600.00
0005432044563	2115	Economy	11600.00
0005433924615	2115	Economy	11600.00
0005433924596	2115	Economy	11600.00
0005433036341	2115	Economy	11600.00
0005432231711	2115	Economy	11600.00
0005433924618	2115	Economy	11600.00
0005433924586	2115	Economy	11600.00
0005433036480	2115	Economy	11600.00
0005433924592	2115	Economy	11600.00
0005433924622	2115	Economy	11600.00
0005433924538	2115	Economy	11600.00
0005433924564	2115	Economy	11600.00
0005432231704	2115	Economy	11600.00
0005433931510	2115	Economy	11600.00
0005433924569	2115	Economy	11600.00
0005433924607	2115	Economy	11600.00
0005433924572	2115	Economy	11600.00
0005432749790	2115	Economy	11600.00
0005433036488	2115	Economy	11600.00
0005433924576	2115	Economy	11600.00
0005433924619	2115	Economy	11600.00
0005433924560	2115	Economy	11600.00
0005433929666	2115	Economy	11600.00
0005433924585	2115	Economy	11600.00
0005433036672	2115	Economy	11600.00
0005433924535	2115	Economy	11600.00
0005433924628	2115	Economy	11600.00
0005433036593	2115	Economy	11600.00
0005433036645	2115	Economy	11600.00
0005433924593	2115	Economy	11600.00
0005433036592	2115	Economy	11600.00
0005433924626	2115	Economy	11600.00
0005433924587	2115	Economy	11600.00
0005432231705	2115	Economy	11600.00
0005433924573	2115	Economy	11600.00
0005433924561	2115	Economy	11600.00
0005432231702	2115	Economy	11600.00
0005433924570	2115	Economy	11600.00
0005433924536	2115	Economy	11600.00
0005433036679	2115	Economy	11600.00
0005433924627	2115	Economy	11600.00
0005433924533	2115	Economy	11600.00
0005433924567	2115	Economy	11600.00
0005432044560	2115	Economy	11600.00
0005433036375	2115	Economy	11600.00
0005433036747	2115	Economy	11600.00
0005433924589	2115	Economy	11600.00
0005434028308	2115	Economy	11600.00
0005433924580	2115	Economy	11600.00
0005433924595	2115	Economy	12700.00
0005432231703	2115	Economy	11600.00
0005433924578	2115	Economy	11600.00
0005433924588	2115	Economy	12700.00
0005433924614	2115	Economy	11600.00
0005433924616	2115	Economy	11600.00
0005433924559	2115	Economy	11600.00
0005433929669	2115	Economy	11600.00
0005433924579	2115	Economy	11600.00
0005432231707	2115	Economy	11600.00
0005433036532	2115	Economy	11600.00
0005433036445	2115	Economy	11600.00
0005432231701	2115	Economy	11600.00
0005433924548	2115	Economy	11600.00
0005433036520	2115	Economy	11600.00
0005433924597	2115	Economy	11600.00
0005433924603	2115	Economy	11600.00
0005433924550	2115	Economy	11600.00
0005433924620	2115	Economy	11600.00
0005433924542	2115	Economy	11600.00
0005433036658	2115	Economy	11600.00
0005433924568	2115	Economy	11600.00
0005433924629	2115	Economy	11600.00
0005433924582	2115	Economy	11600.00
0005433924541	2115	Economy	11600.00
0005433931507	2115	Economy	11600.00
0005433924553	2115	Economy	11600.00
0005434028304	2115	Economy	11600.00
0005433036456	2115	Economy	11600.00
0005433924594	2115	Economy	11600.00
0005433036519	2115	Economy	11600.00
0005433924613	2115	Economy	11600.00
0005433036563	2115	Economy	11600.00
0005433924605	2115	Economy	11600.00
0005433924539	2115	Economy	11600.00
0005433036398	2115	Economy	11600.00
0005433036192	2115	Economy	11600.00
0005433931509	2115	Economy	11600.00
0005433924558	2115	Economy	11600.00
0005433924574	2115	Economy	11600.00
0005433924583	2115	Economy	11600.00
0005433924631	2115	Economy	11600.00
0005432231706	2115	Economy	11600.00
0005433036514	2115	Economy	11600.00
0005433036562	2115	Economy	11600.00
0005433924556	2115	Economy	11600.00
0005433929670	2115	Economy	11600.00
0005432044561	2115	Economy	11600.00
0005434028303	2115	Economy	11600.00
0005433924623	2115	Economy	11600.00
0005433924577	2115	Economy	11600.00
0005433036598	2115	Economy	11600.00
0005433931508	2115	Economy	11600.00
0005433036803	2115	Economy	11600.00
0005433036461	2115	Economy	11600.00
0005433924562	2115	Economy	11600.00
0005433924544	2115	Economy	11600.00
0005433924543	2115	Economy	11600.00
0005433924604	2115	Economy	11600.00
0005433924547	2115	Economy	11600.00
0005433036982	24099	Business	34700.00
0005433923688	24099	Business	34700.00
0005433037004	24099	Business	34700.00
0005433923779	24099	Business	34700.00
0005433923607	24099	Business	34700.00
0005433037019	24099	Business	34700.00
0005433923577	24099	Business	34700.00
0005433037006	24099	Business	34700.00
0005433923862	24099	Business	34700.00
0005433923396	24099	Business	34700.00
0005433923389	24099	Business	34700.00
0005433923857	24099	Business	34700.00
0005433923946	24099	Business	34700.00
0005433923608	24099	Business	34700.00
0005433923931	24099	Business	34700.00
0005433037021	24099	Business	34700.00
0005433036985	24099	Business	34700.00
0005433923630	24099	Business	34700.00
0005433037016	24099	Business	34700.00
0005432207697	24099	Business	34700.00
0005433037026	24099	Economy	12700.00
0005433923690	24099	Economy	12700.00
0005433923850	24099	Economy	11600.00
0005433037005	24099	Economy	11600.00
0005433923769	24099	Economy	11600.00
0005433037009	24099	Economy	11600.00
0005433923856	24099	Economy	11600.00
0005433931489	24099	Economy	11600.00
0005433036979	24099	Economy	11600.00
0005433923768	24099	Economy	11600.00
0005433923728	24099	Economy	11600.00
0005432206272	24099	Economy	11600.00
0005433929633	24099	Economy	11600.00
0005433923913	24099	Economy	11600.00
0005432207696	24099	Economy	11600.00
0005433923520	24099	Economy	11600.00
0005432206274	24099	Economy	11600.00
0005433923847	24099	Economy	11600.00
0005432206276	24099	Economy	11600.00
0005433923677	24099	Economy	11600.00
0005433923639	24099	Economy	11600.00
0005433923318	24099	Economy	11600.00
0005433923928	24099	Economy	11600.00
0005433923665	24099	Economy	11600.00
0005433875392	24099	Economy	11600.00
0005433037010	24099	Economy	11600.00
0005432207698	24099	Economy	11600.00
0005433923910	24099	Economy	11600.00
0005433036998	24099	Economy	11600.00
0005433929637	24099	Economy	11600.00
0005433037002	24099	Economy	11600.00
0005433929638	24099	Economy	11600.00
0005434028339	24099	Economy	11600.00
0005433036999	24099	Economy	11600.00
0005433037023	24099	Economy	11600.00
0005433037007	24099	Economy	11600.00
0005433923809	24099	Economy	11600.00
0005433923660	24099	Economy	11600.00
0005433036993	24099	Economy	11600.00
0005433037028	24099	Economy	11600.00
0005433923984	24099	Economy	11600.00
0005433036986	24099	Economy	11600.00
0005433036991	24099	Economy	11600.00
0005433923519	24099	Economy	11600.00
0005433924017	24099	Economy	11600.00
0005433923359	24099	Economy	11600.00
0005433924391	24099	Economy	11600.00
0005433923486	24099	Economy	11600.00
0005433929639	24099	Economy	11600.00
0005433924165	24099	Economy	11600.00
0005433037008	24099	Economy	11600.00
0005433923487	24099	Economy	11600.00
0005433037025	24099	Economy	11600.00
0005433923994	24099	Economy	11600.00
0005433924168	24099	Economy	11600.00
0005433036978	24099	Economy	11600.00
0005433036994	24099	Economy	11600.00
0005433037001	24099	Economy	11600.00
0005433923452	24099	Economy	11600.00
0005433036980	24099	Economy	11600.00
0005433923583	24099	Economy	11600.00
0005433037024	24099	Economy	11600.00
0005434028338	24099	Economy	11600.00
0005433037020	24099	Economy	11600.00
0005433036989	24099	Economy	11600.00
0005433923940	24099	Economy	11600.00
0005433036984	24099	Economy	11600.00
0005433923463	24099	Economy	11600.00
0005433036992	24099	Economy	11600.00
0005433923436	24099	Economy	11600.00
0005433931486	24099	Economy	11600.00
0005433924282	24099	Economy	11600.00
0005433923961	24099	Economy	12700.00
0005433923736	24099	Economy	12700.00
0005433036987	24099	Economy	11600.00
0005433923571	24099	Economy	11600.00
0005433923481	24099	Economy	11600.00
0005433923488	24099	Economy	12700.00
0005433929632	24099	Economy	11600.00
0005433037014	24099	Economy	11600.00
0005433924013	24099	Economy	11600.00
0005433923960	24099	Economy	11600.00
0005433036977	24099	Economy	11600.00
0005432206275	24099	Economy	11600.00
0005433037015	24099	Economy	11600.00
0005433036988	24099	Economy	11600.00
0005433037013	24099	Economy	11600.00
0005433923797	24099	Economy	11600.00
0005433036995	24099	Economy	11600.00
0005433923908	24099	Economy	11600.00
0005432749815	24099	Economy	11600.00
0005433924167	24099	Economy	11600.00
0005432207695	24099	Economy	11600.00
0005433037011	24099	Economy	11600.00
0005433037000	24099	Economy	11600.00
0005433923462	24099	Economy	11600.00
0005433923480	24099	Economy	11600.00
0005433923655	24099	Economy	11600.00
0005433036981	24099	Economy	11600.00
0005433923798	24099	Economy	11600.00
0005433931488	24099	Economy	11600.00
0005433923632	24099	Economy	11600.00
0005433037003	24099	Economy	11600.00
0005433037017	24099	Economy	11600.00
0005433923780	24099	Economy	11600.00
0005433037022	24099	Economy	11600.00
0005433923907	24099	Economy	11600.00
0005432206271	24099	Economy	11600.00
0005433923959	24099	Economy	11600.00
0005433037029	24099	Economy	11600.00
0005433036990	24099	Economy	11600.00
0005433036997	24099	Economy	11600.00
0005433923849	24099	Economy	11600.00
0005433924014	24099	Economy	11600.00
0005433923663	24099	Economy	11600.00
0005433924012	24099	Economy	11600.00
0005433037012	24099	Economy	11600.00
0005432206273	24099	Economy	11600.00
0005433923434	24099	Economy	11600.00
0005433036976	24099	Economy	11600.00
0005433923870	24099	Economy	11600.00
0005433923552	24099	Economy	11600.00
0005433923770	24099	Economy	11600.00
0005433037018	24099	Economy	11600.00
0005433923871	24099	Economy	11600.00
0005433929635	24099	Economy	11600.00
0005433923932	24099	Economy	11600.00
0005433923518	24099	Economy	11600.00
0005433037027	24099	Economy	11600.00
0005433923600	24099	Economy	11600.00
0005433036983	24099	Economy	11600.00
0005433923895	24099	Economy	11600.00
0005433036996	24099	Economy	11600.00
0005433923664	24099	Economy	11600.00
0005434727077	281	Business	83700.00
0005432277989	281	Business	83700.00
0005433113548	281	Business	83700.00
0005432277994	281	Business	83700.00
0005434727059	281	Business	83700.00
0005433126859	281	Business	83700.00
0005433234370	281	Business	83700.00
0005434727097	281	Business	83700.00
0005434727104	281	Business	83700.00
0005434727047	281	Business	83700.00
0005434727054	281	Business	83700.00
0005434727142	281	Business	83700.00
0005434551950	281	Business	83700.00
0005433234494	281	Business	83700.00
0005433131731	281	Business	83700.00
0005434551990	281	Business	83700.00
0005434727139	281	Business	83700.00
0005434727131	281	Business	83700.00
0005435142758	281	Business	83700.00
0005434727044	281	Comfort	47400.00
0005433181246	281	Business	83700.00
0005433234545	281	Comfort	47400.00
0005434551962	281	Comfort	47400.00
0005434727107	281	Comfort	47400.00
0005432277993	281	Comfort	47400.00
0005433113538	281	Comfort	47400.00
0005433766641	281	Comfort	47400.00
0005434727055	281	Comfort	47400.00
0005434032061	281	Comfort	47400.00
0005434735758	281	Comfort	47400.00
0005434551945	281	Comfort	47400.00
0005435142762	281	Comfort	47400.00
0005433111513	281	Comfort	47400.00
0005432277988	281	Comfort	47400.00
0005433234528	281	Comfort	47400.00
0005434735754	281	Comfort	47400.00
0005434551971	281	Comfort	47400.00
0005434727117	281	Comfort	47400.00
0005433113551	281	Comfort	47400.00
0005434551954	281	Comfort	47400.00
0005434727137	281	Comfort	47400.00
0005434551960	281	Comfort	47400.00
0005434551955	281	Comfort	47400.00
0005434727040	281	Comfort	47400.00
0005434727064	281	Comfort	47400.00
0005435142752	281	Comfort	47400.00
0005433181230	281	Comfort	47400.00
0005434727057	281	Comfort	47400.00
0005433234684	281	Comfort	47400.00
0005432277986	281	Comfort	47400.00
0005434032051	281	Comfort	47400.00
0005434727145	281	Comfort	47400.00
0005434727113	281	Comfort	47400.00
0005434551963	281	Comfort	47400.00
0005433234476	281	Comfort	47400.00
0005433131726	281	Comfort	47400.00
0005434727151	281	Comfort	47400.00
0005434551966	281	Comfort	47400.00
0005434727034	281	Comfort	47400.00
0005433181229	281	Comfort	47400.00
0005432277982	281	Economy	27900.00
0005434727128	281	Comfort	47400.00
0005434551987	281	Economy	27900.00
0005433234655	281	Economy	27900.00
0005434727075	281	Economy	27900.00
0005434727100	281	Economy	27900.00
0005434551968	281	Economy	27900.00
0005434727052	281	Economy	27900.00
0005434727148	281	Economy	27900.00
0005434727122	281	Economy	27900.00
0005434727141	281	Economy	27900.00
0005434727088	281	Economy	27900.00
0005434551957	281	Economy	27900.00
0005434551975	281	Economy	27900.00
0005433234604	281	Economy	27900.00
0005433234266	281	Economy	27900.00
0005435142756	281	Economy	27900.00
0005434727035	281	Economy	27900.00
0005434727063	281	Economy	27900.00
0005433234541	281	Economy	27900.00
0005434727138	281	Economy	27900.00
0005434727144	281	Economy	27900.00
0005434551948	281	Economy	27900.00
0005434727068	281	Economy	27900.00
0005433234628	281	Economy	27900.00
0005433234599	281	Economy	27900.00
0005433234712	281	Economy	27900.00
0005434727043	281	Economy	27900.00
0005434727093	281	Economy	27900.00
0005433766648	281	Economy	27900.00
0005433181123	281	Economy	27900.00
0005433234817	281	Economy	27900.00
0005433234646	281	Economy	27900.00
0005434735757	281	Economy	27900.00
0005434551949	281	Economy	27900.00
0005434727102	281	Economy	27900.00
0005434727083	281	Economy	27900.00
0005434551964	281	Economy	27900.00
0005434727133	281	Economy	27900.00
0005434727134	281	Economy	27900.00
0005434727101	281	Economy	27900.00
0005434727050	281	Economy	27900.00
0005434727058	281	Economy	27900.00
0005433111517	281	Economy	27900.00
0005434727061	281	Economy	27900.00
0005434727103	281	Economy	27900.00
0005434551972	281	Economy	27900.00
0005433126863	281	Economy	27900.00
0005435142760	281	Economy	27900.00
0005433234553	281	Economy	27900.00
0005433234348	281	Economy	27900.00
0005434727123	281	Economy	27900.00
0005435142755	281	Economy	27900.00
0005434727038	281	Economy	27900.00
0005434727120	281	Economy	27900.00
0005433234615	281	Economy	27900.00
0005434727096	281	Economy	27900.00
0005433234603	281	Economy	27900.00
0005434727146	281	Economy	27900.00
0005434727046	281	Economy	27900.00
0005434727031	281	Economy	27900.00
0005433181188	281	Economy	27900.00
0005433234477	281	Economy	30700.00
0005434727135	281	Economy	27900.00
0005432277990	281	Economy	30700.00
0005434727070	281	Economy	27900.00
0005434551989	281	Economy	27900.00
0005434727143	281	Economy	27900.00
0005434551976	281	Economy	30700.00
0005434727037	281	Economy	30700.00
0005434551974	281	Economy	30700.00
0005433234585	281	Economy	27900.00
0005434727051	281	Economy	27900.00
0005432277991	281	Economy	27900.00
0005435142759	281	Economy	27900.00
0005434551988	281	Economy	27900.00
0005434551958	281	Economy	27900.00
0005433181173	281	Economy	27900.00
0005433181172	281	Economy	27900.00
0005434727118	281	Economy	27900.00
0005433234661	281	Economy	27900.00
0005434727072	281	Economy	27900.00
0005434735752	281	Economy	27900.00
0005434551947	281	Economy	27900.00
0005434727108	281	Economy	27900.00
0005434727049	281	Economy	27900.00
0005434551953	281	Economy	27900.00
0005434727149	281	Economy	27900.00
0005434551984	281	Economy	27900.00
0005435142764	281	Economy	27900.00
0005433181321	281	Economy	27900.00
0005434727152	281	Economy	27900.00
0005435142754	281	Economy	27900.00
0005433766649	281	Economy	27900.00
0005434551941	281	Economy	27900.00
0005434727078	281	Economy	27900.00
0005433234530	281	Economy	27900.00
0005434727136	281	Economy	27900.00
0005434731224	281	Economy	27900.00
0005434551946	281	Economy	27900.00
0005434727039	281	Economy	27900.00
0005433181252	281	Economy	27900.00
0005434551991	281	Economy	27900.00
0005434727125	281	Economy	27900.00
0005434551970	281	Economy	27900.00
0005434727092	281	Economy	27900.00
0005434727147	281	Economy	27900.00
0005434727032	281	Economy	27900.00
0005434302516	281	Economy	27900.00
0005434727066	281	Economy	27900.00
0005433131707	281	Economy	27900.00
0005433181241	281	Economy	27900.00
0005433234816	281	Economy	27900.00
0005434727084	281	Economy	27900.00
0005433181122	281	Economy	27900.00
0005434727098	281	Economy	27900.00
0005434727121	281	Economy	27900.00
0005434727076	281	Economy	27900.00
0005434727082	281	Economy	27900.00
0005433289863	281	Economy	27900.00
0005434727116	281	Economy	27900.00
0005434727074	281	Economy	27900.00
0005434727090	281	Economy	27900.00
0005434727095	281	Economy	27900.00
0005434727036	281	Economy	27900.00
0005434551983	281	Economy	27900.00
0005433766656	281	Economy	27900.00
0005434551940	281	Economy	27900.00
0005434032054	281	Economy	27900.00
0005434551992	281	Economy	27900.00
0005434727127	281	Economy	27900.00
0005434727081	281	Economy	27900.00
0005433234427	281	Economy	27900.00
0005433181150	281	Economy	27900.00
0005433234601	281	Economy	27900.00
0005433234602	281	Economy	27900.00
0005434727087	281	Economy	27900.00
0005434735755	281	Economy	27900.00
0005433131704	281	Economy	27900.00
0005434727056	281	Economy	27900.00
0005433234544	281	Economy	27900.00
0005433234566	281	Economy	27900.00
0005434302520	281	Economy	27900.00
0005434727060	281	Economy	27900.00
0005434302517	281	Economy	27900.00
0005434551969	281	Economy	27900.00
0005432277985	281	Economy	27900.00
0005433126865	281	Economy	27900.00
0005433289889	281	Economy	27900.00
0005432277992	281	Economy	27900.00
0005435142763	281	Economy	27900.00
0005433234536	281	Economy	27900.00
0005433766661	281	Economy	27900.00
0005434727033	281	Economy	27900.00
0005433234349	281	Economy	27900.00
0005433234559	281	Economy	27900.00
0005432277983	281	Economy	27900.00
0005434727111	281	Economy	27900.00
0005433234108	281	Economy	27900.00
0005435142753	281	Economy	27900.00
0005434735756	281	Economy	27900.00
0005433234312	281	Economy	27900.00
0005433234535	281	Economy	27900.00
0005433234590	281	Economy	27900.00
0005433234414	281	Economy	27900.00
0005434551943	281	Economy	27900.00
0005434551979	281	Economy	27900.00
0005434032041	281	Economy	27900.00
0005433234656	281	Economy	27900.00
0005434727065	281	Economy	27900.00
0005435142751	281	Economy	27900.00
0005433234489	281	Economy	27900.00
0005434727150	281	Economy	27900.00
0005433181223	281	Economy	27900.00
0005434727130	281	Economy	27900.00
0005433113549	281	Economy	27900.00
0005434302519	281	Economy	27900.00
0005434727132	281	Economy	30700.00
0005433234647	281	Economy	30700.00
0005433131732	281	Economy	30700.00
0005433234654	281	Economy	30700.00
0005433234662	281	Economy	27900.00
0005433234441	281	Economy	30700.00
0005433234695	281	Economy	27900.00
0005433181260	281	Economy	27900.00
0005434727067	281	Economy	27900.00
0005434727140	281	Economy	27900.00
0005434727124	281	Economy	27900.00
0005434727041	281	Economy	27900.00
0005433234571	281	Economy	27900.00
0005434551938	281	Economy	27900.00
0005434551951	281	Economy	27900.00
0005435142757	281	Economy	27900.00
0005434731223	281	Economy	27900.00
0005434727053	281	Economy	27900.00
0005433234572	281	Economy	27900.00
0005434727091	281	Economy	27900.00
0005434727119	281	Economy	27900.00
0005434727109	281	Economy	27900.00
0005434551986	281	Economy	27900.00
0005434727114	281	Economy	27900.00
0005433181236	281	Economy	27900.00
0005433181148	281	Economy	27900.00
0005433234696	281	Economy	27900.00
0005434551967	281	Economy	27900.00
0005433234799	281	Economy	27900.00
0005434551981	281	Economy	27900.00
0005434551942	281	Economy	27900.00
0005433126861	281	Economy	27900.00
0005433234368	281	Economy	27900.00
0005433234738	281	Economy	27900.00
0005434727115	281	Economy	27900.00
0005434731222	281	Economy	27900.00
0005434727110	281	Economy	27900.00
0005434551973	281	Economy	27900.00
0005434727129	281	Economy	27900.00
0005434551952	281	Economy	27900.00
0005434727030	281	Economy	27900.00
0005434727094	281	Economy	27900.00
0005434727089	281	Economy	27900.00
0005434727126	281	Economy	27900.00
0005434727112	281	Economy	27900.00
0005434727086	281	Economy	27900.00
0005434551965	281	Economy	27900.00
0005433234582	281	Economy	27900.00
0005433289862	281	Economy	27900.00
0005434727062	281	Economy	27900.00
0005433111514	281	Economy	27900.00
0005433234440	281	Economy	27900.00
0005432277987	281	Economy	27900.00
0005433113550	281	Economy	27900.00
0005434551982	281	Economy	27900.00
0005434727042	281	Economy	27900.00
0005434727106	281	Economy	27900.00
0005434727048	281	Economy	27900.00
0005433234417	281	Economy	27900.00
0005434551978	281	Economy	27900.00
0005433131725	281	Economy	27900.00
0005434731225	281	Economy	27900.00
0005434727080	281	Economy	27900.00
0005434727073	281	Economy	27900.00
0005434727045	281	Economy	27900.00
0005434551959	281	Economy	27900.00
0005433234371	281	Economy	27900.00
0005433234353	281	Economy	27900.00
0005433234327	281	Economy	27900.00
0005433113537	281	Economy	27900.00
0005432277984	281	Economy	27900.00
0005434551937	281	Economy	27900.00
0005435142761	281	Economy	27900.00
0005434302518	281	Economy	27900.00
0005434727069	281	Economy	27900.00
0005433234623	281	Economy	27900.00
0005434735753	281	Economy	27900.00
0005434727079	281	Economy	27900.00
0005433234369	281	Economy	27900.00
0005434727105	281	Economy	27900.00
0005434551977	281	Economy	27900.00
0005434551961	281	Economy	27900.00
0005433234552	281	Economy	27900.00
0005434727029	281	Economy	27900.00
0005433234627	281	Economy	27900.00
0005434727071	281	Economy	27900.00
0005434727099	281	Economy	27900.00
0005434551956	281	Economy	27900.00
0005433234560	281	Economy	27900.00
0005434551985	281	Economy	27900.00
0005434727085	281	Economy	27900.00
0005434551944	281	Economy	27900.00
0005433234488	281	Economy	27900.00
0005433181224	281	Economy	27900.00
0005434551980	281	Economy	27900.00
0005433234356	281	Economy	27900.00
0005433234404	281	Economy	27900.00
0005433234426	281	Economy	27900.00
0005433181114	281	Economy	27900.00
0005434551939	281	Economy	27900.00
0005433181329	281	Economy	27900.00
0005434726490	9864	Business	83700.00
0005433181447	9864	Business	83700.00
0005434726024	9864	Business	83700.00
0005434725897	9864	Business	83700.00
0005434726269	9864	Business	83700.00
0005433181434	9864	Business	83700.00
0005432199340	9864	Business	83700.00
0005433235044	9864	Business	83700.00
0005434551676	9864	Business	83700.00
0005434302478	9864	Business	83700.00
0005433181440	9864	Business	83700.00
0005434725510	9864	Business	83700.00
0005433289946	9864	Business	83700.00
0005434725681	9864	Business	83700.00
0005433289945	9864	Business	83700.00
0005434726293	9864	Business	83700.00
0005434726360	9864	Business	83700.00
0005434726449	9864	Business	83700.00
0005434726078	9864	Business	83700.00
0005433235030	9864	Business	83700.00
0005433235055	9864	Business	83700.00
0005434726436	9864	Business	83700.00
0005433235052	9864	Business	83700.00
0005434731194	9864	Business	83700.00
0005434726218	9864	Business	83700.00
0005434726304	9864	Comfort	47400.00
0005434551344	9864	Comfort	47400.00
0005435142656	9864	Comfort	47400.00
0005433235058	9864	Comfort	47400.00
0005434726320	9864	Comfort	47400.00
0005433235015	9864	Comfort	47400.00
0005434551361	9864	Comfort	47400.00
0005434551299	9864	Comfort	47400.00
0005433181425	9864	Comfort	47400.00
0005434726341	9864	Comfort	47400.00
0005433235051	9864	Comfort	47400.00
0005433289940	9864	Comfort	47400.00
0005434725701	9864	Comfort	47400.00
0005433126903	9864	Comfort	47400.00
0005433235065	9864	Comfort	47400.00
0005433235069	9864	Comfort	47400.00
0005434725860	9864	Comfort	47400.00
0005433235033	9864	Comfort	47400.00
0005434725937	9864	Comfort	47400.00
0005434725829	9864	Comfort	47400.00
0005433181432	9864	Comfort	47400.00
0005433181427	9864	Comfort	47400.00
0005434725856	9864	Comfort	47400.00
0005434731183	9864	Comfort	47400.00
0005434551566	9864	Comfort	47400.00
0005434551597	9864	Comfort	47400.00
0005434551558	9864	Comfort	47400.00
0005435142642	9864	Comfort	47400.00
0005434551677	9864	Comfort	47400.00
0005434551245	9864	Comfort	47400.00
0005433126907	9864	Comfort	47400.00
0005433235046	9864	Comfort	47400.00
0005434725858	9864	Comfort	47400.00
0005434302492	9864	Comfort	47400.00
0005434032087	9864	Comfort	47400.00
0005434725862	9864	Comfort	47400.00
0005434551595	9864	Comfort	47400.00
0005434726272	9864	Comfort	47400.00
0005434551112	9864	Comfort	47400.00
0005433235068	9864	Comfort	47400.00
0005434726121	9864	Comfort	47400.00
0005434551298	9864	Comfort	47400.00
0005434551392	9864	Comfort	47400.00
0005434725818	9864	Economy	27900.00
0005434725817	9864	Economy	27900.00
0005434726116	9864	Economy	27900.00
0005433235073	9864	Economy	27900.00
0005433235020	9864	Economy	27900.00
0005434726023	9864	Economy	27900.00
0005434551545	9864	Economy	27900.00
0005433181430	9864	Economy	27900.00
0005434551588	9864	Economy	27900.00
0005433235029	9864	Economy	27900.00
0005432199343	9864	Economy	27900.00
0005434726305	9864	Economy	27900.00
0005435142599	9864	Economy	27900.00
0005434551369	9864	Economy	27900.00
0005434551631	9864	Economy	27900.00
0005434725828	9864	Economy	27900.00
0005433113565	9864	Economy	27900.00
0005434551578	9864	Economy	27900.00
0005433766691	9864	Economy	27900.00
0005433181446	9864	Economy	27900.00
0005434725981	9864	Economy	27900.00
0005433235047	9864	Economy	27900.00
0005434725861	9864	Economy	27900.00
0005434726072	9864	Economy	27900.00
0005433235075	9864	Economy	27900.00
0005434551430	9864	Economy	27900.00
0005434551271	9864	Economy	27900.00
0005433181444	9864	Economy	27900.00
0005433289944	9864	Economy	27900.00
0005434726040	9864	Economy	27900.00
0005434726202	9864	Economy	27900.00
0005433289939	9864	Economy	27900.00
0005433235064	9864	Economy	27900.00
0005434725916	9864	Economy	27900.00
0005435142650	9864	Economy	27900.00
0005433235041	9864	Economy	27900.00
0005434725859	9864	Economy	27900.00
0005433126905	9864	Economy	27900.00
0005433235074	9864	Economy	27900.00
0005434726458	9864	Economy	27900.00
0005434551370	9864	Economy	27900.00
0005434725682	9864	Economy	27900.00
0005433181436	9864	Economy	27900.00
0005434726168	9864	Economy	27900.00
0005434551307	9864	Economy	27900.00
0005434032086	9864	Economy	27900.00
0005434551476	9864	Economy	27900.00
0005434735707	9864	Economy	27900.00
0005432199341	9864	Economy	27900.00
0005433235045	9864	Economy	27900.00
0005434725982	9864	Economy	27900.00
0005433766690	9864	Economy	27900.00
0005434725881	9864	Economy	27900.00
0005433235063	9864	Economy	27900.00
0005434551454	9864	Economy	27900.00
0005433235077	9864	Economy	27900.00
0005433235017	9864	Economy	27900.00
0005434726076	9864	Economy	27900.00
0005434726430	9864	Economy	27900.00
0005434726013	9864	Economy	30700.00
0005433235024	9864	Economy	27900.00
0005434551791	9864	Economy	27900.00
0005433126904	9864	Economy	27900.00
0005434725564	9864	Economy	30700.00
0005433289942	9864	Economy	30700.00
0005435142548	9864	Economy	27900.00
0005434725595	9864	Economy	30700.00
0005433235053	9864	Economy	27900.00
0005433181438	9864	Economy	27900.00
0005434726286	9864	Economy	27900.00
0005433181433	9864	Economy	27900.00
0005434551496	9864	Economy	27900.00
0005433181448	9864	Economy	27900.00
0005434551490	9864	Economy	27900.00
0005434726178	9864	Economy	27900.00
0005433113564	9864	Economy	27900.00
0005434725743	9864	Economy	27900.00
0005435142597	9864	Economy	27900.00
0005434726292	9864	Economy	27900.00
0005434725700	9864	Economy	27900.00
0005433181442	9864	Economy	27900.00
0005433181429	9864	Economy	27900.00
0005433181445	9864	Economy	27900.00
0005434725693	9864	Economy	27900.00
0005433235025	9864	Economy	27900.00
0005435142621	9864	Economy	27900.00
0005434725921	9864	Economy	27900.00
0005434551598	9864	Economy	27900.00
0005432199344	9864	Economy	27900.00
0005434551789	9864	Economy	27900.00
0005434551246	9864	Economy	27900.00
0005435142628	9864	Economy	27900.00
0005434551591	9864	Economy	27900.00
0005434726144	9864	Economy	27900.00
0005434726359	9864	Economy	27900.00
0005433235060	9864	Economy	27900.00
0005434725919	9864	Economy	27900.00
0005433235056	9864	Economy	27900.00
0005434725554	9864	Economy	27900.00
0005434725732	9864	Economy	27900.00
0005435142645	9864	Economy	27900.00
0005434726152	9864	Economy	27900.00
0005434726764	9864	Economy	27900.00
0005434551451	9864	Economy	27900.00
0005434726263	9864	Economy	27900.00
0005433129338	9864	Economy	27900.00
0005433235023	9864	Economy	27900.00
0005435142595	9864	Economy	27900.00
0005433289947	9864	Economy	27900.00
0005433235035	9864	Economy	27900.00
0005434726113	9864	Economy	27900.00
0005434725880	9864	Economy	27900.00
0005434725588	9864	Economy	27900.00
0005434551477	9864	Economy	27900.00
0005434725833	9864	Economy	27900.00
0005433235072	9864	Economy	27900.00
0005434551423	9864	Economy	27900.00
0005433181435	9864	Economy	27900.00
0005433235076	9864	Economy	27900.00
0005434725734	9864	Economy	27900.00
0005434725917	9864	Economy	27900.00
0005433235037	9864	Economy	27900.00
0005434551306	9864	Economy	27900.00
0005433235039	9864	Economy	27900.00
0005433235067	9864	Economy	27900.00
0005433181428	9864	Economy	27900.00
0005434725585	9864	Economy	27900.00
0005434302501	9864	Economy	27900.00
0005435142651	9864	Economy	27900.00
0005434735708	9864	Economy	27900.00
0005433766692	9864	Economy	27900.00
0005434726153	9864	Economy	27900.00
0005434726217	9864	Economy	27900.00
0005434725960	9864	Economy	27900.00
0005433235038	9864	Economy	27900.00
0005433235043	9864	Economy	27900.00
0005433235061	9864	Economy	27900.00
0005434726133	9864	Economy	27900.00
0005434726284	9864	Economy	27900.00
0005433289941	9864	Economy	27900.00
0005435142618	9864	Economy	27900.00
0005433235071	9864	Economy	27900.00
0005434551230	9864	Economy	27900.00
0005433181431	9864	Economy	27900.00
0005433235040	9864	Economy	27900.00
0005433235027	9864	Economy	27900.00
0005434551356	9864	Economy	27900.00
0005434551484	9864	Economy	27900.00
0005434726321	9864	Economy	27900.00
0005434551375	9864	Economy	27900.00
0005433235042	9864	Economy	27900.00
0005434731170	9864	Economy	27900.00
0005434725830	9864	Economy	27900.00
0005434726027	9864	Economy	27900.00
0005434725872	9864	Economy	27900.00
0005433181439	9864	Economy	27900.00
0005434551537	9864	Economy	27900.00
0005434725733	9864	Economy	27900.00
0005434551491	9864	Economy	27900.00
0005432199342	9864	Economy	27900.00
0005434735715	9864	Economy	27900.00
0005434551374	9864	Economy	27900.00
0005433129336	9864	Economy	27900.00
0005434725896	9864	Economy	30700.00
0005434302500	9864	Economy	27900.00
0005433235019	9864	Economy	30700.00
0005435142643	9864	Economy	30700.00
0005434726457	9864	Economy	30700.00
0005434725672	9864	Economy	30700.00
0005434726633	9864	Economy	27900.00
0005433235059	9864	Economy	27900.00
0005434726237	9864	Economy	27900.00
0005433181426	9864	Economy	27900.00
0005433235057	9864	Economy	27900.00
0005433181437	9864	Economy	27900.00
0005434726146	9864	Economy	27900.00
0005434551580	9864	Economy	27900.00
0005435142667	9864	Economy	27900.00
0005434726134	9864	Economy	27900.00
0005434726114	9864	Economy	27900.00
0005433235062	9864	Economy	27900.00
0005434725834	9864	Economy	27900.00
0005434726070	9864	Economy	27900.00
0005434726285	9864	Economy	27900.00
0005434726171	9864	Economy	27900.00
0005434551584	9864	Economy	27900.00
0005434032084	9864	Economy	27900.00
0005434551589	9864	Economy	27900.00
0005433235028	9864	Economy	27900.00
0005435142596	9864	Economy	27900.00
0005434735716	9864	Economy	27900.00
0005434725894	9864	Economy	27900.00
0005434551349	9864	Economy	27900.00
0005433235049	9864	Economy	27900.00
0005434726048	9864	Economy	27900.00
0005434551450	9864	Economy	27900.00
0005433235026	9864	Economy	27900.00
0005433235032	9864	Economy	27900.00
0005432199339	9864	Economy	27900.00
0005434726017	9864	Economy	27900.00
0005433235022	9864	Economy	27900.00
0005434551532	9864	Economy	27900.00
0005433235014	9864	Economy	27900.00
0005434551579	9864	Economy	27900.00
0005433113566	9864	Economy	27900.00
0005434551790	9864	Economy	27900.00
0005434032085	9864	Economy	27900.00
0005434725692	9864	Economy	27900.00
0005433181443	9864	Economy	27900.00
0005434726526	9864	Economy	27900.00
0005434551531	9864	Economy	27900.00
0005435142620	9864	Economy	27900.00
0005434731181	9864	Economy	27900.00
0005433235018	9864	Economy	27900.00
0005434032088	9864	Economy	27900.00
0005434302484	9864	Economy	27900.00
0005434731182	9864	Economy	27900.00
0005434725511	9864	Economy	27900.00
0005434551405	9864	Economy	27900.00
0005434725555	9864	Economy	27900.00
0005434726216	9864	Economy	27900.00
0005434302477	9864	Economy	27900.00
0005433235021	9864	Economy	27900.00
0005434551424	9864	Economy	27900.00
0005434551203	9864	Economy	27900.00
0005434551357	9864	Economy	27900.00
0005433235054	9864	Economy	27900.00
0005434551333	9864	Economy	27900.00
0005433766693	9864	Economy	27900.00
0005433235050	9864	Economy	27900.00
0005434726531	9864	Economy	27900.00
0005434726041	9864	Economy	27900.00
0005433129337	9864	Economy	27900.00
0005434726138	9864	Economy	27900.00
0005433181441	9864	Economy	27900.00
0005434551385	9864	Economy	27900.00
0005434725979	9864	Economy	27900.00
0005434551380	9864	Economy	27900.00
0005433235036	9864	Economy	27900.00
0005435142594	9864	Economy	27900.00
0005433129335	9864	Economy	27900.00
0005433235048	9864	Economy	27900.00
0005433235066	9864	Economy	27900.00
0005434735711	9864	Economy	27900.00
0005434302486	9864	Economy	27900.00
0005434725596	9864	Economy	27900.00
0005434726169	9864	Economy	27900.00
0005434551577	9864	Economy	27900.00
0005433289943	9864	Economy	27900.00
0005434725832	9864	Economy	27900.00
0005433235034	9864	Economy	27900.00
0005434726071	9864	Economy	27900.00
0005434725893	9864	Economy	27900.00
0005434725821	9864	Economy	27900.00
0005433126906	9864	Economy	27900.00
0005434551485	9864	Economy	27900.00
0005434725835	9864	Economy	27900.00
0005433235031	9864	Economy	27900.00
0005434551671	9864	Economy	27900.00
0005434725871	9864	Economy	27900.00
0005433235070	9864	Economy	27900.00
0005434725049	9864	Economy	27900.00
0005435142619	9864	Economy	27900.00
0005434725710	9864	Economy	27900.00
0005433235016	9864	Economy	27900.00
0005434551400	9864	Economy	27900.00
0005432529671	7735	Business	42100.00
0005434068521	7735	Business	42100.00
0005432529789	7735	Business	42100.00
0005434068481	7735	Business	42100.00
0005432150296	7735	Business	42100.00
0005432529722	7735	Business	42100.00
0005432529684	7735	Business	42100.00
0005432069854	7735	Business	42100.00
0005432529739	7735	Business	42100.00
0005432529773	7735	Business	42100.00
0005432529701	7735	Business	42100.00
0005434068529	7735	Business	42100.00
0005435213725	7735	Business	42100.00
0005432069849	7735	Business	42100.00
0005432529681	7735	Business	42100.00
0005432533329	7735	Business	42100.00
0005432529688	7735	Business	42100.00
0005435213900	7735	Business	42100.00
0005434068500	7735	Business	42100.00
0005432533330	7735	Business	42100.00
0005434068540	7735	Business	42100.00
0005434068513	7735	Business	42100.00
0005432529774	7735	Business	42100.00
0005432529692	7735	Business	42100.00
0005434068546	7735	Comfort	23900.00
0005432069855	7735	Comfort	23900.00
0005435214034	7735	Comfort	23900.00
0005435213995	7735	Comfort	23900.00
0005432529665	7735	Comfort	23900.00
0005432529775	7735	Comfort	23900.00
0005435213979	7735	Comfort	23900.00
0005434068474	7735	Comfort	23900.00
0005434068495	7735	Comfort	23900.00
0005435213881	7735	Comfort	23900.00
0005432529729	7735	Comfort	23900.00
0005432529750	7735	Comfort	23900.00
0005434068530	7735	Comfort	23900.00
0005434068532	7735	Comfort	23900.00
0005434068498	7735	Comfort	23900.00
0005432529699	7735	Comfort	23900.00
0005432529741	7735	Comfort	23900.00
0005434068535	7735	Comfort	23900.00
0005432529785	7735	Comfort	23900.00
0005434068520	7735	Comfort	23900.00
0005432529760	7735	Comfort	23900.00
0005434068480	7735	Comfort	23900.00
0005432529780	7735	Comfort	23900.00
0005432529735	7735	Comfort	23900.00
0005433656696	7735	Comfort	23900.00
0005435213771	7735	Comfort	23900.00
0005432529749	7735	Comfort	23900.00
0005432529778	7735	Comfort	23900.00
0005435213561	7735	Comfort	23900.00
0005432529786	7735	Comfort	23900.00
0005435214055	7735	Comfort	23900.00
0005432529734	7735	Comfort	23900.00
0005434068475	7735	Comfort	23900.00
0005434068544	7735	Comfort	23900.00
0005432529768	7735	Comfort	23900.00
0005435213893	7735	Comfort	23900.00
0005432428975	7735	Comfort	23900.00
0005432529695	7735	Comfort	23900.00
0005432529661	7735	Economy	14000.00
0005435630975	7735	Economy	14000.00
0005432529715	7735	Economy	14000.00
0005432529777	7735	Economy	14000.00
0005432529683	7735	Economy	14000.00
0005435725629	7735	Economy	14000.00
0005432529720	7735	Economy	14000.00
0005432529691	7735	Economy	14000.00
0005432529756	7735	Economy	14000.00
0005435725613	7735	Economy	14000.00
0005435213991	7735	Economy	14000.00
0005432535898	7735	Economy	14000.00
0005432428973	7735	Economy	14000.00
0005432529660	7735	Economy	14000.00
0005432529668	7735	Economy	14000.00
0005432529659	7735	Economy	14000.00
0005434068508	7735	Economy	14000.00
0005432529746	7735	Economy	14000.00
0005432529667	7735	Economy	14000.00
0005435213912	7735	Economy	14000.00
0005435213843	7735	Economy	14000.00
0005432529723	7735	Economy	14000.00
0005432150300	7735	Economy	14000.00
0005432529758	7735	Economy	14000.00
0005435213768	7735	Economy	14000.00
0005432529730	7735	Economy	14000.00
0005435213827	7735	Economy	14000.00
0005434068493	7735	Economy	14000.00
0005435213936	7735	Economy	14000.00
0005434068533	7735	Economy	14000.00
0005432529790	7735	Economy	14000.00
0005432529744	7735	Economy	14000.00
0005432537085	7735	Economy	14000.00
0005434068510	7735	Economy	14000.00
0005432069853	7735	Economy	14000.00
0005435213935	7735	Economy	14000.00
0005432069845	7735	Economy	14000.00
0005432150299	7735	Economy	14000.00
0005432535897	7735	Economy	14000.00
0005432529719	7735	Economy	14000.00
0005434068514	7735	Economy	14000.00
0005435213878	7735	Economy	14000.00
0005432529664	7735	Economy	14000.00
0005435214129	7735	Economy	14000.00
0005435213978	7735	Economy	14000.00
0005434068527	7735	Economy	14000.00
0005432529779	7735	Economy	14000.00
0005432529772	7735	Economy	14000.00
0005432069851	7735	Economy	14000.00
0005434068539	7735	Economy	14000.00
0005432529711	7735	Economy	14000.00
0005435214088	7735	Economy	14000.00
0005432529685	7735	Economy	14000.00
0005432529742	7735	Economy	14000.00
0005432529788	7735	Economy	14000.00
0005432529751	7735	Economy	14000.00
0005435213842	7735	Economy	14000.00
0005434068512	7735	Economy	14000.00
0005434068483	7735	Economy	14000.00
0005434068545	7735	Economy	14000.00
0005435214007	7735	Economy	14000.00
0005434068482	7735	Economy	15400.00
0005435213854	7735	Economy	15400.00
0005432529682	7735	Economy	14000.00
0005435213851	7735	Economy	14000.00
0005432529697	7735	Economy	14000.00
0005435213690	7735	Economy	15400.00
0005434068486	7735	Economy	15400.00
0005432529693	7735	Economy	14000.00
0005432069852	7735	Economy	15400.00
0005434068496	7735	Economy	14000.00
0005432529673	7735	Economy	14000.00
0005435213908	7735	Economy	14000.00
0005432529714	7735	Economy	14000.00
0005432529784	7735	Economy	14000.00
0005432529763	7735	Economy	14000.00
0005435213983	7735	Economy	14000.00
0005435213833	7735	Economy	14000.00
0005432069846	7735	Economy	14000.00
0005432529710	7735	Economy	14000.00
0005434068543	7735	Economy	14000.00
0005432529766	7735	Economy	14000.00
0005435725609	7735	Economy	14000.00
0005435213671	7735	Economy	14000.00
0005434068489	7735	Economy	14000.00
0005432529680	7735	Economy	14000.00
0005434068499	7735	Economy	14000.00
0005432529666	7735	Economy	14000.00
0005432529669	7735	Economy	14000.00
0005435213770	7735	Economy	14000.00
0005435725627	7735	Economy	14000.00
0005432150297	7735	Economy	14000.00
0005432069842	7735	Economy	14000.00
0005432069848	7735	Economy	14000.00
0005432529726	7735	Economy	14000.00
0005432529761	7735	Economy	14000.00
0005434068484	7735	Economy	14000.00
0005432529783	7735	Economy	14000.00
0005434068525	7735	Economy	14000.00
0005432529745	7735	Economy	14000.00
0005434068497	7735	Economy	14000.00
0005432529754	7735	Economy	14000.00
0005432529771	7735	Economy	14000.00
0005435630984	7735	Economy	14000.00
0005432069841	7735	Economy	14000.00
0005435725628	7735	Economy	14000.00
0005432533331	7735	Economy	14000.00
0005432069847	7735	Economy	14000.00
0005432529743	7735	Economy	14000.00
0005432529738	7735	Economy	14000.00
0005432069850	7735	Economy	14000.00
0005434068494	7735	Economy	14000.00
0005435213961	7735	Economy	14000.00
0005434068504	7735	Economy	14000.00
0005434068507	7735	Economy	14000.00
0005432529764	7735	Economy	14000.00
0005432529678	7735	Economy	14000.00
0005432529696	7735	Economy	14000.00
0005432529753	7735	Economy	14000.00
0005434068538	7735	Economy	14000.00
0005432529759	7735	Economy	14000.00
0005434068503	7735	Economy	14000.00
0005432529757	7735	Economy	14000.00
0005432529690	7735	Economy	14000.00
0005435213950	7735	Economy	14000.00
0005435213921	7735	Economy	14000.00
0005432529765	7735	Economy	14000.00
0005435213879	7735	Economy	14000.00
0005434068517	7735	Economy	14000.00
0005435213832	7735	Economy	14000.00
0005434068523	7735	Economy	14000.00
0005434068476	7735	Economy	14000.00
0005434068492	7735	Economy	14000.00
0005433656695	7735	Economy	14000.00
0005432529725	7735	Economy	14000.00
0005432529679	7735	Economy	14000.00
0005434068490	7735	Economy	14000.00
0005435213772	7735	Economy	14000.00
0005435213909	7735	Economy	14000.00
0005432529767	7735	Economy	14000.00
0005432150302	7735	Economy	14000.00
0005432529718	7735	Economy	14000.00
0005435214128	7735	Economy	14000.00
0005434068516	7735	Economy	14000.00
0005432529731	7735	Economy	14000.00
0005434068542	7735	Economy	14000.00
0005432529705	7735	Economy	14000.00
0005435213780	7735	Economy	14000.00
0005435213882	7735	Economy	14000.00
0005435213905	7735	Economy	14000.00
0005435725599	7735	Economy	14000.00
0005432529716	7735	Economy	14000.00
0005432535896	7735	Economy	14000.00
0005432529662	7735	Economy	14000.00
0005434068528	7735	Economy	14000.00
0005435213971	7735	Economy	14000.00
0005435630978	7735	Economy	14000.00
0005435213911	7735	Economy	14000.00
0005432529787	7735	Economy	14000.00
0005432529769	7735	Economy	14000.00
0005435725600	7735	Economy	14000.00
0005432069843	7735	Economy	14000.00
0005432529700	7735	Economy	15400.00
0005432529717	7735	Economy	15400.00
0005432529672	7735	Economy	15400.00
0005434068488	7735	Economy	14000.00
0005434068515	7735	Economy	15400.00
0005434068531	7735	Economy	14000.00
0005432529732	7735	Economy	14000.00
0005432529713	7735	Economy	14000.00
0005432529670	7735	Economy	14000.00
0005432529689	7735	Economy	14000.00
0005432529752	7735	Economy	14000.00
0005435213899	7735	Economy	14000.00
0005432529733	7735	Economy	14000.00
0005435214011	7735	Economy	14000.00
0005432529770	7735	Economy	14000.00
0005432529708	7735	Economy	14000.00
0005434068524	7735	Economy	14000.00
0005432529727	7735	Economy	14000.00
0005434068505	7735	Economy	14000.00
0005434068478	7735	Economy	14000.00
0005432529791	7735	Economy	14000.00
0005435213840	7735	Economy	14000.00
0005434068536	7735	Economy	14000.00
0005432529776	7735	Economy	14000.00
0005435213855	7735	Economy	14000.00
0005432529721	7735	Economy	14000.00
0005432069844	7735	Economy	14000.00
0005434068522	7735	Economy	14000.00
0005435214040	7735	Economy	14000.00
0005434068526	7735	Economy	14000.00
0005435213933	7735	Economy	14000.00
0005435213895	7735	Economy	14000.00
0005435213984	7735	Economy	14000.00
0005432529712	7735	Economy	14000.00
0005432535900	7735	Economy	14000.00
0005434068518	7735	Economy	14000.00
0005433656688	7735	Economy	14000.00
0005432529737	7735	Economy	14000.00
0005432529781	7735	Economy	14000.00
0005435213962	7735	Economy	14000.00
0005434068479	7735	Economy	14000.00
0005434068502	7735	Economy	14000.00
0005432529698	7735	Economy	14000.00
0005432529755	7735	Economy	14000.00
0005435213964	7735	Economy	14000.00
0005434068534	7735	Economy	14000.00
0005435213670	7735	Economy	14000.00
0005432529748	7735	Economy	14000.00
0005434068511	7735	Economy	14000.00
0005432150298	7735	Economy	14000.00
0005432529703	7735	Economy	14000.00
0005432428974	7735	Economy	14000.00
0005435214041	7735	Economy	14000.00
0005434068485	7735	Economy	14000.00
0005434068519	7735	Economy	14000.00
0005434068501	7735	Economy	14000.00
0005435283408	7735	Economy	14000.00
0005432529676	7735	Economy	14000.00
0005432529694	7735	Economy	14000.00
0005434068487	7735	Economy	14000.00
0005432535899	7735	Economy	14000.00
0005435725612	7735	Economy	14000.00
0005432529663	7735	Economy	14000.00
0005434068541	7735	Economy	14000.00
0005433656672	7735	Economy	14000.00
0005432529747	7735	Economy	14000.00
0005432529675	7735	Economy	14000.00
0005435630972	7735	Economy	14000.00
0005435214084	7735	Economy	14000.00
0005434068506	7735	Economy	14000.00
0005435213826	7735	Economy	14000.00
0005432529702	7735	Economy	14000.00
0005432529728	7735	Economy	14000.00
0005432529707	7735	Economy	14000.00
0005432529736	7735	Economy	14000.00
0005432529709	7735	Economy	14000.00
0005434068473	7735	Economy	14000.00
0005432529762	7735	Economy	14000.00
0005434068509	7735	Economy	14000.00
0005434068477	7735	Economy	14000.00
0005432529677	7735	Economy	14000.00
0005432529706	7735	Economy	14000.00
0005432529740	7735	Economy	14000.00
0005435213880	7735	Economy	14000.00
0005432529687	7735	Economy	14000.00
0005435213932	7735	Economy	14000.00
0005432529686	7735	Economy	14000.00
0005432150303	7735	Economy	14000.00
0005432529782	7735	Economy	14000.00
0005435213977	7735	Economy	14000.00
0005434068537	7735	Economy	14000.00
0005432150301	7735	Economy	14000.00
0005432529724	7735	Economy	14000.00
0005432529704	7735	Economy	14000.00
0005434068491	7735	Economy	14000.00
0005435213850	7735	Economy	14000.00
0005432537086	7735	Economy	14000.00
0005435213773	7735	Economy	14000.00
0005432529674	7735	Economy	14000.00
0005435615099	5344	Business	43100.00
0005435615187	5344	Business	43100.00
0005432047600	5344	Business	43100.00
0005435425208	5344	Business	43100.00
0005435425227	5344	Business	43100.00
0005435425342	5344	Business	43100.00
0005435615111	5344	Business	43100.00
0005435424767	5344	Business	43100.00
0005434573547	5344	Business	43100.00
0005432133416	5344	Business	43100.00
0005435615202	5344	Business	43100.00
0005435615185	5344	Business	43100.00
0005434245098	5344	Business	43100.00
0005435302226	5344	Business	43100.00
0005435615159	5344	Business	43100.00
0005435615179	5344	Business	43100.00
0005435302225	5344	Business	43100.00
0005435425337	5344	Business	43100.00
0005435615170	5344	Business	43100.00
0005432133414	5344	Business	43100.00
0005435425375	5344	Business	43100.00
0005435615121	5344	Business	43100.00
0005434656556	5344	Business	43100.00
0005435319676	5344	Business	43100.00
0005432363439	5344	Business	43100.00
0005434344685	5344	Business	43100.00
0005433719158	5344	Business	43100.00
0005435615180	5344	Comfort	24400.00
0005435615165	5344	Business	43100.00
0005433719150	5344	Comfort	24400.00
0005435305017	5344	Comfort	24400.00
0005435615117	5344	Comfort	24400.00
0005434344706	5344	Comfort	24400.00
0005435615177	5344	Comfort	24400.00
0005435490277	5344	Comfort	24400.00
0005434344703	5344	Comfort	24400.00
0005435615203	5344	Comfort	24400.00
0005435615142	5344	Comfort	24400.00
0005432133411	5344	Comfort	24400.00
0005435425321	5344	Comfort	24400.00
0005435615174	5344	Comfort	24400.00
0005435425162	5344	Comfort	24400.00
0005435425131	5344	Comfort	24400.00
0005432841014	5344	Comfort	24400.00
0005435425258	5344	Comfort	24400.00
0005435615160	5344	Comfort	24400.00
0005435425145	5344	Comfort	24400.00
0005435425044	5344	Comfort	24400.00
0005435615151	5344	Comfort	24400.00
0005434344699	5344	Comfort	24400.00
0005435425297	5344	Comfort	24400.00
0005435615214	5344	Comfort	24400.00
0005435425129	5344	Comfort	24400.00
0005435097338	5344	Comfort	24400.00
0005435425015	5344	Comfort	24400.00
0005434573537	5344	Comfort	24400.00
0005434344693	5344	Comfort	24400.00
0005435615108	5344	Comfort	24400.00
0005435615206	5344	Comfort	24400.00
0005435615144	5344	Comfort	24400.00
0005435615217	5344	Comfort	24400.00
0005435615176	5344	Comfort	24400.00
0005434245246	5344	Comfort	24400.00
0005435425169	5344	Comfort	24400.00
0005434573539	5344	Comfort	24400.00
0005434244991	5344	Comfort	24400.00
0005435615135	5344	Comfort	24400.00
0005434573535	5344	Economy	14400.00
0005435615097	5344	Comfort	24400.00
0005435097333	5344	Economy	14400.00
0005435425135	5344	Economy	14400.00
0005435425242	5344	Economy	14400.00
0005435615210	5344	Economy	14400.00
0005434245015	5344	Economy	14400.00
0005435615158	5344	Economy	14400.00
0005435425097	5344	Economy	14400.00
0005435425389	5344	Economy	14400.00
0005435615120	5344	Economy	14400.00
0005435425388	5344	Economy	14400.00
0005435615213	5344	Economy	14400.00
0005434573548	5344	Economy	14400.00
0005435424801	5344	Economy	14400.00
0005435425482	5344	Economy	14400.00
0005435424928	5344	Economy	14400.00
0005434344695	5344	Economy	14400.00
0005434344687	5344	Economy	14400.00
0005435615205	5344	Economy	14400.00
0005435425128	5344	Economy	14400.00
0005435615122	5344	Economy	14400.00
0005435380315	5344	Economy	14400.00
0005435615104	5344	Economy	14400.00
0005434245219	5344	Economy	14400.00
0005435615199	5344	Economy	14400.00
0005435425240	5344	Economy	14400.00
0005435615126	5344	Economy	14400.00
0005435615164	5344	Economy	14400.00
0005435425192	5344	Economy	14400.00
0005434573540	5344	Economy	14400.00
0005435615115	5344	Economy	14400.00
0005435319597	5344	Economy	14400.00
0005434245045	5344	Economy	14400.00
0005434344678	5344	Economy	14400.00
0005432133412	5344	Economy	14400.00
0005435425303	5344	Economy	14400.00
0005434656565	5344	Economy	14400.00
0005435615196	5344	Economy	14400.00
0005433719157	5344	Economy	14400.00
0005435615207	5344	Economy	14400.00
0005435490278	5344	Economy	14400.00
0005435615169	5344	Economy	14400.00
0005435615195	5344	Economy	14400.00
0005434344691	5344	Economy	14400.00
0005434573538	5344	Economy	14400.00
0005435380323	5344	Economy	14400.00
0005435097336	5344	Economy	14400.00
0005435097342	5344	Economy	14400.00
0005434344688	5344	Economy	14400.00
0005434344704	5344	Economy	14400.00
0005435319623	5344	Economy	14400.00
0005435097335	5344	Economy	14400.00
0005434244999	5344	Economy	14400.00
0005435615178	5344	Economy	14400.00
0005434344707	5344	Economy	14400.00
0005435097341	5344	Economy	14400.00
0005435097334	5344	Economy	14400.00
0005435425319	5344	Economy	14400.00
0005435425174	5344	Economy	14400.00
0005434344682	5344	Economy	14400.00
0005435425095	5344	Economy	15800.00
0005435615107	5344	Economy	15800.00
0005435615125	5344	Economy	14400.00
0005435615119	5344	Economy	14400.00
0005435425265	5344	Economy	14400.00
0005435615166	5344	Economy	14400.00
0005432047598	5344	Economy	15800.00
0005435097332	5344	Economy	15800.00
0005435424934	5344	Economy	14400.00
0005435425444	5344	Economy	14400.00
0005435615175	5344	Economy	14400.00
0005435097339	5344	Economy	14400.00
0005435615106	5344	Economy	14400.00
0005435425320	5344	Economy	14400.00
0005434344697	5344	Economy	14400.00
0005435615172	5344	Economy	14400.00
0005435424917	5344	Economy	14400.00
0005434344681	5344	Economy	14400.00
0005434344708	5344	Economy	14400.00
0005435615184	5344	Economy	14400.00
0005432047601	5344	Economy	14400.00
0005435615129	5344	Economy	14400.00
0005435615141	5344	Economy	14400.00
0005435425057	5344	Economy	14400.00
0005435425445	5344	Economy	14400.00
0005435615124	5344	Economy	14400.00
0005435319624	5344	Economy	14400.00
0005434245137	5344	Economy	14400.00
0005435425077	5344	Economy	14400.00
0005435615173	5344	Economy	14400.00
0005432133420	5344	Economy	14400.00
0005434344700	5344	Economy	14400.00
0005432047599	5344	Economy	14400.00
0005435615147	5344	Economy	14400.00
0005434245099	5344	Economy	14400.00
0005435615192	5344	Economy	14400.00
0005435425184	5344	Economy	14400.00
0005435615137	5344	Economy	14400.00
0005435615191	5344	Economy	14400.00
0005435615198	5344	Economy	14400.00
0005432133407	5344	Economy	14400.00
0005434344686	5344	Economy	14400.00
0005434245108	5344	Economy	14400.00
0005435615101	5344	Economy	14400.00
0005435615112	5344	Economy	14400.00
0005435425163	5344	Economy	14400.00
0005434573544	5344	Economy	14400.00
0005435424899	5344	Economy	14400.00
0005435615216	5344	Economy	14400.00
0005435425253	5344	Economy	14400.00
0005434245170	5344	Economy	14400.00
0005432133418	5344	Economy	14400.00
0005434573549	5344	Economy	14400.00
0005435615194	5344	Economy	14400.00
0005435615154	5344	Economy	14400.00
0005435615168	5344	Economy	14400.00
0005435380334	5344	Economy	14400.00
0005435425264	5344	Economy	14400.00
0005435425262	5344	Economy	14400.00
0005435425096	5344	Economy	14400.00
0005435425246	5344	Economy	14400.00
0005434244992	5344	Economy	14400.00
0005432133406	5344	Economy	14400.00
0005435615143	5344	Economy	14400.00
0005435425043	5344	Economy	14400.00
0005434245199	5344	Economy	14400.00
0005432133419	5344	Economy	14400.00
0005434344694	5344	Economy	14400.00
0005435380307	5344	Economy	14400.00
0005435615149	5344	Economy	14400.00
0005434573536	5344	Economy	14400.00
0005435425219	5344	Economy	14400.00
0005435615212	5344	Economy	14400.00
0005435490276	5344	Economy	14400.00
0005434245245	5344	Economy	14400.00
0005432363438	5344	Economy	14400.00
0005434344689	5344	Economy	14400.00
0005435424929	5344	Economy	14400.00
0005435615103	5344	Economy	14400.00
0005435615163	5344	Economy	14400.00
0005435615145	5344	Economy	14400.00
0005435615150	5344	Economy	14400.00
0005434245166	5344	Economy	14400.00
0005435425014	5344	Economy	14400.00
0005435615156	5344	Economy	14400.00
0005434245057	5344	Economy	14400.00
0005434344684	5344	Economy	14400.00
0005435425286	5344	Economy	14400.00
0005434573543	5344	Economy	14400.00
0005435424881	5344	Economy	14400.00
0005435615148	5344	Economy	14400.00
0005435615153	5344	Economy	14400.00
0005435615190	5344	Economy	14400.00
0005432133405	5344	Economy	14400.00
0005434573541	5344	Economy	14400.00
0005435615211	5344	Economy	14400.00
0005435615215	5344	Economy	14400.00
0005435615100	5344	Economy	14400.00
0005435425275	5344	Economy	14400.00
0005435425136	5344	Economy	14400.00
0005435425250	5344	Economy	14400.00
0005435425285	5344	Economy	14400.00
0005434344690	5344	Economy	14400.00
0005435615110	5344	Economy	14400.00
0005434344676	5344	Economy	14400.00
0005435491466	5344	Economy	14400.00
0005435319598	5344	Economy	14400.00
0005435490275	5344	Economy	14400.00
0005435615157	5344	Economy	14400.00
0005435615193	5344	Economy	14400.00
0005435615138	5344	Economy	14400.00
0005435615133	5344	Economy	14400.00
0005435615139	5344	Economy	15800.00
0005434344679	5344	Economy	14400.00
0005434344683	5344	Economy	15800.00
0005435615186	5344	Economy	15800.00
0005435097337	5344	Economy	15800.00
0005435425229	5344	Economy	15800.00
0005435615181	5344	Economy	14400.00
0005434344698	5344	Economy	14400.00
0005434245058	5344	Economy	14400.00
0005432133409	5344	Economy	14400.00
0005435424933	5344	Economy	14400.00
0005434573545	5344	Economy	14400.00
0005435615201	5344	Economy	14400.00
0005434245105	5344	Economy	14400.00
0005435615161	5344	Economy	14400.00
0005434245132	5344	Economy	14400.00
0005435615197	5344	Economy	14400.00
0005435425188	5344	Economy	14400.00
0005434344674	5344	Economy	14400.00
0005435615146	5344	Economy	14400.00
0005435615128	5344	Economy	14400.00
0005434245200	5344	Economy	14400.00
0005435380308	5344	Economy	14400.00
0005432133408	5344	Economy	14400.00
0005434245255	5344	Economy	14400.00
0005435615171	5344	Economy	14400.00
0005435615132	5344	Economy	14400.00
0005435380324	5344	Economy	14400.00
0005435615182	5344	Economy	14400.00
0005435615130	5344	Economy	14400.00
0005435615155	5344	Economy	14400.00
0005435097340	5344	Economy	14400.00
0005435425149	5344	Economy	14400.00
0005432363428	5344	Economy	14400.00
0005435425524	5344	Economy	14400.00
0005435425241	5344	Economy	14400.00
0005435425119	5344	Economy	14400.00
0005435615218	5344	Economy	14400.00
0005434344692	5344	Economy	14400.00
0005435425252	5344	Economy	14400.00
0005435425347	5344	Economy	14400.00
0005435425104	5344	Economy	14400.00
0005435425483	5344	Economy	14400.00
0005435425374	5344	Economy	14400.00
0005435425132	5344	Economy	14400.00
0005435302221	5344	Economy	14400.00
0005434573542	5344	Economy	14400.00
0005435555396	5344	Economy	14400.00
0005435615109	5344	Economy	14400.00
0005435425338	5344	Economy	14400.00
0005435615131	5344	Economy	14400.00
0005435615152	5344	Economy	14400.00
0005434344705	5344	Economy	14400.00
0005435425212	5344	Economy	14400.00
0005435491467	5344	Economy	14400.00
0005435425146	5344	Economy	14400.00
0005432133415	5344	Economy	14400.00
0005435615134	5344	Economy	14400.00
0005434344701	5344	Economy	14400.00
0005435615162	5344	Economy	14400.00
0005435380328	5344	Economy	14400.00
0005435302222	5344	Economy	14400.00
0005435615208	5344	Economy	14400.00
0005435425301	5344	Economy	14400.00
0005435615189	5344	Economy	14400.00
0005434245034	5344	Economy	14400.00
0005435615098	5344	Economy	14400.00
0005434344680	5344	Economy	14400.00
0005435615114	5344	Economy	14400.00
0005435615113	5344	Economy	14400.00
0005432133417	5344	Economy	14400.00
0005434344696	5344	Economy	14400.00
0005435302236	5344	Economy	14400.00
0005435615209	5344	Economy	14400.00
0005435615136	5344	Economy	14400.00
0005435615123	5344	Economy	14400.00
0005435615127	5344	Economy	14400.00
0005435380294	5344	Economy	14400.00
0005435615105	5344	Economy	14400.00
0005434344677	5344	Economy	14400.00
0005435425207	5344	Economy	14400.00
0005432133410	5344	Economy	14400.00
0005434573546	5344	Economy	14400.00
0005434245198	5344	Economy	14400.00
0005435425302	5344	Economy	14400.00
0005434344702	5344	Economy	14400.00
0005435615188	5344	Economy	14400.00
0005435555395	5344	Economy	14400.00
0005435424918	5344	Economy	14400.00
0005432133413	5344	Economy	14400.00
0005434344675	5344	Economy	14400.00
0005435425120	5344	Economy	14400.00
0005435615140	5344	Economy	14400.00
0005435615102	5344	Economy	14400.00
0005435380317	5344	Economy	14400.00
0005435615183	5344	Economy	14400.00
0005435615118	5344	Economy	14400.00
0005435615204	5344	Economy	14400.00
0005435425251	5344	Economy	14400.00
0005435615200	5344	Economy	14400.00
0005435615116	5344	Economy	14400.00
0005435615167	5344	Economy	14400.00
0005435614302	10922	Business	43100.00
0005435425714	10922	Business	43100.00
0005435425726	10922	Business	43100.00
0005435614123	10922	Business	43100.00
0005435614369	10922	Business	43100.00
0005435425751	10922	Business	43100.00
0005433719187	10922	Business	43100.00
0005435614071	10922	Business	43100.00
0005435614275	10922	Business	43100.00
0005435613934	10922	Business	43100.00
0005435614023	10922	Business	43100.00
0005434245365	10922	Business	43100.00
0005434344380	10922	Business	43100.00
0005435614410	10922	Business	43100.00
0005434573445	10922	Business	43100.00
0005435613899	10922	Business	43100.00
0005435614127	10922	Business	43100.00
0005434245366	10922	Business	43100.00
0005435614268	10922	Business	43100.00
0005434245364	10922	Business	43100.00
0005434245385	10922	Business	43100.00
0005435614194	10922	Business	43100.00
0005435614431	10922	Business	43100.00
0005434344346	10922	Business	43100.00
0005435425722	10922	Business	43100.00
0005435614237	10922	Business	43100.00
0005435425719	10922	Comfort	24400.00
0005435614095	10922	Comfort	24400.00
0005435380356	10922	Comfort	24400.00
0005432165139	10922	Comfort	24400.00
0005434573347	10922	Comfort	24400.00
0005434573399	10922	Comfort	24400.00
0005435614033	10922	Comfort	24400.00
0005435305038	10922	Comfort	24400.00
0005435097243	10922	Comfort	24400.00
0005434245371	10922	Comfort	24400.00
0005434573400	10922	Comfort	24400.00
0005434573413	10922	Comfort	24400.00
0005435614212	10922	Comfort	24400.00
0005434573362	10922	Comfort	24400.00
0005435614378	10922	Comfort	24400.00
0005435097209	10922	Comfort	24400.00
0005435613754	10922	Comfort	24400.00
0005435614036	10922	Comfort	24400.00
0005434344303	10922	Comfort	24400.00
0005434344310	10922	Comfort	24400.00
0005435614057	10922	Comfort	24400.00
0005435614326	10922	Comfort	24400.00
0005432363460	10922	Comfort	24400.00
0005434245370	10922	Comfort	24400.00
0005435613830	10922	Comfort	24400.00
0005432165140	10922	Comfort	24400.00
0005435614034	10922	Comfort	24400.00
0005435614439	10922	Comfort	24400.00
0005435319690	10922	Comfort	24400.00
0005432165137	10922	Comfort	24400.00
0005435425706	10922	Comfort	24400.00
0005434344315	10922	Comfort	24400.00
0005435425695	10922	Comfort	24400.00
0005435425748	10922	Comfort	24400.00
0005434573425	10922	Comfort	24400.00
0005435319693	10922	Comfort	24400.00
0005435425758	10922	Comfort	24400.00
0005435614239	10922	Comfort	24400.00
0005434573372	10922	Comfort	24400.00
0005435425734	10922	Comfort	24400.00
0005435425732	10922	Economy	14400.00
0005435425708	10922	Economy	14400.00
0005432841042	10922	Economy	14400.00
0005434344257	10922	Economy	14400.00
0005435097260	10922	Economy	14400.00
0005434245384	10922	Economy	14400.00
0005435614261	10922	Economy	14400.00
0005434344344	10922	Economy	14400.00
0005434573412	10922	Economy	14400.00
0005435613977	10922	Economy	14400.00
0005434245377	10922	Economy	14400.00
0005435425712	10922	Economy	14400.00
0005435614131	10922	Economy	14400.00
0005432166946	10922	Economy	14400.00
0005435425741	10922	Economy	14400.00
0005435614096	10922	Economy	14400.00
0005435614032	10922	Economy	14400.00
0005434344456	10922	Economy	14400.00
0005435097208	10922	Economy	14400.00
0005435555385	10922	Economy	14400.00
0005435613829	10922	Economy	14400.00
0005434344507	10922	Economy	14400.00
0005435614156	10922	Economy	14400.00
0005435614195	10922	Economy	14400.00
0005435614379	10922	Economy	14400.00
0005434344343	10922	Economy	14400.00
0005434344388	10922	Economy	14400.00
0005435425746	10922	Economy	14400.00
0005435425735	10922	Economy	14400.00
0005434344263	10922	Economy	14400.00
0005435614267	10922	Economy	14400.00
0005435614316	10922	Economy	14400.00
0005435425720	10922	Economy	14400.00
0005434245375	10922	Economy	14400.00
0005435613952	10922	Economy	14400.00
0005435613864	10922	Economy	14400.00
0005435614236	10922	Economy	14400.00
0005434573292	10922	Economy	14400.00
0005435614158	10922	Economy	14400.00
0005435425703	10922	Economy	14400.00
0005435613968	10922	Economy	14400.00
0005434573420	10922	Economy	14400.00
0005435425704	10922	Economy	14400.00
0005435614285	10922	Economy	14400.00
0005435425747	10922	Economy	14400.00
0005435614206	10922	Economy	14400.00
0005432841041	10922	Economy	14400.00
0005435614307	10922	Economy	14400.00
0005435380354	10922	Economy	14400.00
0005435319695	10922	Economy	14400.00
0005435614416	10922	Economy	14400.00
0005434344253	10922	Economy	14400.00
0005434344329	10922	Economy	14400.00
0005435614398	10922	Economy	14400.00
0005435614286	10922	Economy	14400.00
0005435425700	10922	Economy	14400.00
0005434245382	10922	Economy	14400.00
0005435613863	10922	Economy	14400.00
0005435425737	10922	Economy	14400.00
0005434245379	10922	Economy	14400.00
0005435305039	10922	Economy	14400.00
0005435425754	10922	Economy	15800.00
0005435425693	10922	Economy	14400.00
0005434245372	10922	Economy	15800.00
0005435613851	10922	Economy	14400.00
0005435613926	10922	Economy	14400.00
0005434573338	10922	Economy	15800.00
0005435425694	10922	Economy	14400.00
0005434573368	10922	Economy	15800.00
0005434245378	10922	Economy	15800.00
0005435042888	10922	Economy	14400.00
0005435425744	10922	Economy	14400.00
0005435614205	10922	Economy	14400.00
0005435425725	10922	Economy	14400.00
0005435425697	10922	Economy	14400.00
0005434344305	10922	Economy	14400.00
0005435425742	10922	Economy	14400.00
0005432363461	10922	Economy	14400.00
0005435614035	10922	Economy	14400.00
0005435425755	10922	Economy	14400.00
0005435425736	10922	Economy	14400.00
0005435380357	10922	Economy	14400.00
0005435613571	10922	Economy	14400.00
0005435614429	10922	Economy	14400.00
0005435425743	10922	Economy	14400.00
0005434245362	10922	Economy	14400.00
0005432165143	10922	Economy	14400.00
0005435425757	10922	Economy	14400.00
0005435614020	10922	Economy	14400.00
0005434573373	10922	Economy	14400.00
0005435613688	10922	Economy	14400.00
0005435042886	10922	Economy	14400.00
0005435380352	10922	Economy	14400.00
0005435305040	10922	Economy	14400.00
0005435614058	10922	Economy	14400.00
0005435425731	10922	Economy	14400.00
0005435614193	10922	Economy	14400.00
0005435425759	10922	Economy	14400.00
0005435614313	10922	Economy	14400.00
0005434344318	10922	Economy	14400.00
0005435425709	10922	Economy	14400.00
0005434245359	10922	Economy	14400.00
0005432363458	10922	Economy	14400.00
0005435614226	10922	Economy	14400.00
0005435425692	10922	Economy	14400.00
0005435425745	10922	Economy	14400.00
0005434245369	10922	Economy	14400.00
0005435319691	10922	Economy	14400.00
0005435613283	10922	Economy	14400.00
0005435613901	10922	Economy	14400.00
0005435319694	10922	Economy	14400.00
0005435614256	10922	Economy	14400.00
0005434344165	10922	Economy	14400.00
0005435614012	10922	Economy	14400.00
0005434344155	10922	Economy	14400.00
0005433719188	10922	Economy	14400.00
0005435319692	10922	Economy	14400.00
0005435614325	10922	Economy	14400.00
0005435614108	10922	Economy	14400.00
0005434245367	10922	Economy	14400.00
0005435613894	10922	Economy	14400.00
0005435614133	10922	Economy	14400.00
0005434245374	10922	Economy	14400.00
0005435425723	10922	Economy	14400.00
0005435613778	10922	Economy	14400.00
0005434573424	10922	Economy	14400.00
0005435425727	10922	Economy	14400.00
0005435425696	10922	Economy	14400.00
0005435613546	10922	Economy	14400.00
0005435425713	10922	Economy	14400.00
0005434573419	10922	Economy	14400.00
0005435555386	10922	Economy	14400.00
0005435613927	10922	Economy	14400.00
0005435425711	10922	Economy	14400.00
0005435614072	10922	Economy	14400.00
0005435614069	10922	Economy	14400.00
0005435614227	10922	Economy	14400.00
0005435425733	10922	Economy	14400.00
0005434656583	10922	Economy	14400.00
0005435613905	10922	Economy	14400.00
0005435425705	10922	Economy	14400.00
0005435425752	10922	Economy	14400.00
0005434344412	10922	Economy	14400.00
0005435614019	10922	Economy	14400.00
0005435613991	10922	Economy	14400.00
0005435614411	10922	Economy	14400.00
0005435613570	10922	Economy	14400.00
0005434245373	10922	Economy	14400.00
0005435614107	10922	Economy	14400.00
0005435319688	10922	Economy	14400.00
0005434245383	10922	Economy	14400.00
0005434344306	10922	Economy	14400.00
0005435304215	10922	Economy	14400.00
0005432363459	10922	Economy	14400.00
0005435613892	10922	Economy	14400.00
0005434245386	10922	Economy	14400.00
0005434344264	10922	Economy	14400.00
0005435425739	10922	Economy	14400.00
0005435097246	10922	Economy	14400.00
0005435613969	10922	Economy	14400.00
0005434344297	10922	Economy	14400.00
0005435613891	10922	Economy	14400.00
0005432165141	10922	Economy	14400.00
0005434344237	10922	Economy	14400.00
0005435614259	10922	Economy	14400.00
0005434344218	10922	Economy	14400.00
0005435614272	10922	Economy	14400.00
0005435425738	10922	Economy	14400.00
0005434573369	10922	Economy	14400.00
0005434344345	10922	Economy	14400.00
0005435613957	10922	Economy	14400.00
0005435614006	10922	Economy	14400.00
0005434344447	10922	Economy	14400.00
0005435614024	10922	Economy	15800.00
0005434344166	10922	Economy	14400.00
0005432166945	10922	Economy	15800.00
0005435555387	10922	Economy	15800.00
0005435097233	10922	Economy	15800.00
0005435613819	10922	Economy	15800.00
0005435614018	10922	Economy	14400.00
0005435319689	10922	Economy	15800.00
0005435613403	10922	Economy	14400.00
0005434245380	10922	Economy	14400.00
0005434245368	10922	Economy	14400.00
0005435614047	10922	Economy	14400.00
0005435425760	10922	Economy	14400.00
0005435425724	10922	Economy	14400.00
0005435319686	10922	Economy	14400.00
0005435425728	10922	Economy	14400.00
0005434344391	10922	Economy	14400.00
0005435614098	10922	Economy	14400.00
0005434344333	10922	Economy	14400.00
0005435614364	10922	Economy	14400.00
0005435425698	10922	Economy	14400.00
0005434245358	10922	Economy	14400.00
0005434344338	10922	Economy	14400.00
0005435555382	10922	Economy	14400.00
0005434245357	10922	Economy	14400.00
0005435425749	10922	Economy	14400.00
0005434344459	10922	Economy	14400.00
0005435614273	10922	Economy	14400.00
0005435425702	10922	Economy	14400.00
0005435425707	10922	Economy	14400.00
0005435425715	10922	Economy	14400.00
0005435614260	10922	Economy	14400.00
0005434573414	10922	Economy	14400.00
0005435613750	10922	Economy	14400.00
0005435613900	10922	Economy	14400.00
0005435042887	10922	Economy	14400.00
0005435614324	10922	Economy	14400.00
0005435097244	10922	Economy	14400.00
0005435042889	10922	Economy	14400.00
0005434573339	10922	Economy	14400.00
0005434344309	10922	Economy	14400.00
0005432165142	10922	Economy	14400.00
0005434245363	10922	Economy	14400.00
0005435614143	10922	Economy	14400.00
0005435614070	10922	Economy	14400.00
0005435614103	10922	Economy	14400.00
0005435614303	10922	Economy	14400.00
0005435614225	10922	Economy	14400.00
0005435097245	10922	Economy	14400.00
0005434573376	10922	Economy	14400.00
0005434344339	10922	Economy	14400.00
0005434344304	10922	Economy	14400.00
0005435490233	10922	Economy	14400.00
0005435380355	10922	Economy	14400.00
0005435614211	10922	Economy	14400.00
0005435613855	10922	Economy	14400.00
0005435425716	10922	Economy	14400.00
0005435097232	10922	Economy	14400.00
0005435614409	10922	Economy	14400.00
0005434344322	10922	Economy	14400.00
0005435042885	10922	Economy	14400.00
0005435425699	10922	Economy	14400.00
0005435613990	10922	Economy	14400.00
0005434344279	10922	Economy	14400.00
0005434344238	10922	Economy	14400.00
0005435425729	10922	Economy	14400.00
0005435614075	10922	Economy	14400.00
0005435614130	10922	Economy	14400.00
0005435097235	10922	Economy	14400.00
0005435425750	10922	Economy	14400.00
0005432166943	10922	Economy	14400.00
0005435304217	10922	Economy	14400.00
0005432166944	10922	Economy	14400.00
0005435425753	10922	Economy	14400.00
0005435614068	10922	Economy	14400.00
0005435613993	10922	Economy	14400.00
0005434245360	10922	Economy	14400.00
0005435097259	10922	Economy	14400.00
0005435613893	10922	Economy	14400.00
0005435425756	10922	Economy	14400.00
0005434245376	10922	Economy	14400.00
0005435425710	10922	Economy	14400.00
0005435614005	10922	Economy	14400.00
0005435425730	10922	Economy	14400.00
0005434344284	10922	Economy	14400.00
0005434245381	10922	Economy	14400.00
0005434245361	10922	Economy	14400.00
0005435614451	10922	Economy	14400.00
0005435425721	10922	Economy	14400.00
0005435613779	10922	Economy	14400.00
0005435613983	10922	Economy	14400.00
0005434573421	10922	Economy	14400.00
0005435425701	10922	Economy	14400.00
0005435613953	10922	Economy	14400.00
0005435380353	10922	Economy	14400.00
0005435425717	10922	Economy	14400.00
0005435614262	10922	Economy	14400.00
0005435425718	10922	Economy	14400.00
0005435613761	10922	Economy	14400.00
0005432165138	10922	Economy	14400.00
0005435319687	10922	Economy	14400.00
0005435614240	10922	Economy	14400.00
0005435614128	10922	Economy	14400.00
0005435304216	10922	Economy	14400.00
0005433719186	10922	Economy	14400.00
0005435490232	10922	Economy	14400.00
0005435425740	10922	Economy	14400.00
0005433507429	3252	Business	18800.00
0005432459973	3252	Business	18800.00
0005432460231	3252	Business	18800.00
0005433634266	3252	Business	18800.00
0005432182016	3252	Business	18800.00
0005433634275	3252	Business	18800.00
0005432182004	3252	Business	18800.00
0005433507426	3252	Business	18800.00
0005433634277	3252	Business	18800.00
0005432182012	3252	Business	18800.00
0005432460184	3252	Business	18800.00
0005432459901	3252	Business	18800.00
0005432460218	3252	Business	18800.00
0005432459706	3252	Business	18800.00
0005432460165	3252	Business	18800.00
0005432182010	3252	Business	18800.00
0005432459831	3252	Business	18800.00
0005432182018	3252	Business	18800.00
0005432460263	3252	Business	18800.00
0005433507422	3252	Business	18800.00
0005433634284	3252	Business	18800.00
0005432459998	3252	Business	18800.00
0005432460102	3252	Business	18800.00
0005433507410	3252	Business	18800.00
0005432182015	3252	Business	18800.00
0005432460083	3252	Business	18800.00
0005433507407	3252	Business	18800.00
0005433507427	3252	Business	18800.00
0005433805837	3252	Economy	6900.00
0005432182024	3252	Economy	6900.00
0005433634286	3252	Economy	6900.00
0005432460228	3252	Economy	6900.00
0005433805838	3252	Economy	6900.00
0005432459975	3252	Economy	6900.00
0005432460105	3252	Economy	6300.00
0005432459926	3252	Economy	6300.00
0005432460260	3252	Economy	6300.00
0005433634282	3252	Economy	6300.00
0005432182008	3252	Economy	6300.00
0005433507428	3252	Economy	6300.00
0005432460119	3252	Economy	6300.00
0005433507415	3252	Economy	6300.00
0005432460070	3252	Economy	6300.00
0005432460133	3252	Economy	6300.00
0005432182025	3252	Economy	6300.00
0005432460162	3252	Economy	6300.00
0005432460103	3252	Economy	6300.00
0005432182013	3252	Economy	6300.00
0005432459940	3252	Economy	6300.00
0005433634287	3252	Economy	6300.00
0005433805843	3252	Economy	6300.00
0005432460045	3252	Economy	6300.00
0005432460156	3252	Economy	6300.00
0005433634278	3252	Economy	6300.00
0005433507416	3252	Economy	6300.00
0005432459838	3252	Economy	6300.00
0005433805833	3252	Economy	6300.00
0005433634283	3252	Economy	6300.00
0005433805836	3252	Economy	6300.00
0005432460078	3252	Economy	6300.00
0005432182006	3252	Economy	6300.00
0005433507408	3252	Economy	6300.00
0005433634280	3252	Economy	6300.00
0005433634264	3252	Economy	6300.00
0005433634294	3252	Economy	6300.00
0005433507420	3252	Economy	6300.00
0005433634272	3252	Economy	6300.00
0005433805829	3252	Economy	6300.00
0005432460135	3252	Economy	6300.00
0005433507413	3252	Economy	6300.00
0005432460159	3252	Economy	6300.00
0005433507423	3252	Economy	6300.00
0005432460154	3252	Economy	6300.00
0005433634260	3252	Economy	6300.00
0005432460155	3252	Economy	6300.00
0005432459707	3252	Economy	6300.00
0005432182017	3252	Economy	6300.00
0005433805839	3252	Economy	6300.00
0005433634285	3252	Economy	6300.00
0005433805831	3252	Economy	6300.00
0005433805840	3252	Economy	6300.00
0005433507421	3252	Economy	6300.00
0005433634268	3252	Economy	6300.00
0005432460153	3252	Economy	6300.00
0005432459938	3252	Economy	6300.00
0005432182007	3252	Economy	6300.00
0005432460022	3252	Economy	6300.00
0005433634289	3252	Economy	6300.00
0005432459927	3252	Economy	6300.00
0005432460033	3252	Economy	6300.00
0005432459902	3252	Economy	6300.00
0005432459964	3252	Economy	6300.00
0005433507425	3252	Economy	6300.00
0005432459896	3252	Economy	6300.00
0005433634261	3252	Economy	6900.00
0005432460375	3252	Economy	6900.00
0005432460157	3252	Economy	6900.00
0005432460129	3252	Economy	6900.00
0005433634293	3252	Economy	6300.00
0005433634290	3252	Economy	6900.00
0005433805842	3252	Economy	6300.00
0005432182020	3252	Economy	6300.00
0005432460093	3252	Economy	6300.00
0005432459830	3252	Economy	6300.00
0005432182023	3252	Economy	6900.00
0005433507411	3252	Economy	6300.00
0005433634279	3252	Economy	6300.00
0005433634288	3252	Economy	6300.00
0005432460207	3252	Economy	6300.00
0005432460158	3252	Economy	6300.00
0005432182005	3252	Economy	6300.00
0005432459994	3252	Economy	6300.00
0005432460104	3252	Economy	6300.00
0005433805846	3252	Economy	6300.00
0005433805823	3252	Economy	6300.00
0005433805826	3252	Economy	6300.00
0005432182011	3252	Economy	6300.00
0005432460374	3252	Economy	6300.00
0005433805844	3252	Economy	6300.00
0005433805832	3252	Economy	6300.00
0005433805828	3252	Economy	6300.00
0005433634276	3252	Economy	6300.00
0005433507412	3252	Economy	6300.00
0005433634271	3252	Economy	6300.00
0005433805845	3252	Economy	6300.00
0005433507418	3252	Economy	6300.00
0005433634273	3252	Economy	6300.00
0005432182022	3252	Economy	6300.00
0005432460032	3252	Economy	6300.00
0005433634267	3252	Economy	6300.00
0005432460118	3252	Economy	6300.00
0005433634270	3252	Economy	6300.00
0005433634265	3252	Economy	6300.00
0005433507419	3252	Economy	6300.00
0005433634262	3252	Economy	6300.00
0005432182026	3252	Economy	6300.00
0005432182009	3252	Economy	6300.00
0005432460229	3252	Economy	6300.00
0005432460140	3252	Economy	6300.00
0005432460051	3252	Economy	6300.00
0005433634269	3252	Economy	6300.00
0005432460171	3252	Economy	6300.00
0005433634281	3252	Economy	6300.00
0005432460163	3252	Economy	6300.00
0005433805830	3252	Economy	6300.00
0005432460410	3252	Economy	6300.00
0005433805841	3252	Economy	6300.00
0005433634274	3252	Economy	6300.00
0005433507414	3252	Economy	6300.00
0005433805834	3252	Economy	6300.00
0005432182021	3252	Economy	6300.00
0005432459939	3252	Economy	6300.00
0005433805825	3252	Economy	6300.00
0005432459972	3252	Economy	6300.00
0005433805824	3252	Economy	6300.00
0005432460136	3252	Economy	6300.00
0005432182019	3252	Economy	6300.00
0005432460084	3252	Economy	6300.00
0005433805835	3252	Economy	6300.00
0005433507417	3252	Economy	6300.00
0005432460409	3252	Economy	6300.00
0005432459969	3252	Economy	6300.00
0005433634291	3252	Economy	6300.00
0005433507424	3252	Economy	6300.00
0005432182014	3252	Economy	6300.00
0005433634263	3252	Economy	6300.00
0005433634292	3252	Economy	6300.00
0005433805827	3252	Economy	6300.00
0005433507409	3252	Economy	6300.00
0005435885739	3253	Business	18800.00
0005435885609	3253	Business	18800.00
0005435885387	3253	Business	18800.00
0005435885489	3253	Business	18800.00
0005435885555	3253	Business	18800.00
0005435885581	3253	Business	18800.00
0005435885715	3253	Business	18800.00
0005435885259	3253	Business	18800.00
0005435885705	3253	Economy	6900.00
0005435885610	3253	Economy	6900.00
0005435885735	3253	Economy	6300.00
0005435885618	3253	Economy	6300.00
0005435885404	3253	Economy	6300.00
0005435885619	3253	Economy	6300.00
0005435885473	3253	Economy	6300.00
0005435885437	3253	Economy	6300.00
0005435885536	3253	Economy	6300.00
0005435885435	3253	Economy	6300.00
0005435885529	3253	Economy	6300.00
0005435885616	3253	Economy	6300.00
0005435885570	3253	Economy	6300.00
0005435885393	3253	Economy	6300.00
0005435885617	3253	Economy	6300.00
0005435885656	3253	Economy	6300.00
0005435885528	3253	Economy	6300.00
0005435885652	3253	Economy	6300.00
0005435885428	3253	Economy	6300.00
0005435885614	3253	Economy	6300.00
0005435885459	3253	Economy	6300.00
0005435885296	3253	Economy	6300.00
0005435885372	3253	Economy	6300.00
0005435885534	3253	Economy	6300.00
0005435885304	3253	Economy	6300.00
0005435885329	3253	Economy	6300.00
0005435885556	3253	Economy	6300.00
0005435885490	3253	Economy	6300.00
0005435885622	3253	Economy	6300.00
0005435885535	3253	Economy	6900.00
0005435885657	3253	Economy	6900.00
0005435885224	3253	Economy	6900.00
0005435885436	3253	Economy	6300.00
0005435885456	3253	Economy	6300.00
0005435885582	3253	Economy	6300.00
0005435885388	3253	Economy	6300.00
0005435885613	3253	Economy	6300.00
0005435885769	3253	Economy	6300.00
0005435885580	3253	Economy	6300.00
0005435885538	3253	Economy	6300.00
0005435885493	3253	Economy	6300.00
0005435885425	3253	Economy	6300.00
0005435885527	3253	Economy	6300.00
0005435885706	3253	Economy	6300.00
0005435885475	3253	Economy	6300.00
0005435885578	3253	Economy	6300.00
0005435885474	3253	Economy	6300.00
0005435885297	3253	Economy	6300.00
0005435885675	3253	Economy	6300.00
0005435885477	3253	Economy	6300.00
0005435885471	3253	Economy	6300.00
0005435885434	3253	Economy	6300.00
0005435885565	3253	Economy	6300.00
0005435885904	8192	Business	18800.00
0005432460604	8192	Business	18800.00
0005432460566	8192	Business	18800.00
0005435885883	8192	Business	18800.00
0005432460581	8192	Business	18800.00
0005432460585	8192	Business	18800.00
0005432460608	8192	Business	18800.00
0005435885899	8192	Business	18800.00
0005432460588	8192	Business	18800.00
0005432460603	8192	Business	18800.00
0005432460573	8192	Business	18800.00
0005432460570	8192	Business	18800.00
0005432460560	8192	Business	18800.00
0005435885894	8192	Business	18800.00
0005432460567	8192	Business	18800.00
0005435885902	8192	Business	18800.00
0005435885892	8192	Business	18800.00
0005435885898	8192	Business	18800.00
0005432460561	8192	Business	18800.00
0005432460575	8192	Business	18800.00
0005433507251	8192	Business	18800.00
0005432460607	8192	Business	18800.00
0005432460562	8192	Economy	6900.00
0005435885909	8192	Economy	6900.00
0005435885907	8192	Economy	6900.00
0005435885928	8192	Economy	6900.00
0005432460597	8192	Economy	6300.00
0005432460605	8192	Economy	6300.00
0005435885900	8192	Economy	6300.00
0005435885914	8192	Economy	6300.00
0005435885912	8192	Economy	6300.00
0005432460563	8192	Economy	6300.00
0005433507246	8192	Economy	6300.00
0005433507252	8192	Economy	6300.00
0005435885925	8192	Economy	6300.00
0005432460601	8192	Economy	6300.00
0005432460571	8192	Economy	6300.00
0005432460598	8192	Economy	6300.00
0005432042903	8192	Economy	6300.00
0005432042908	8192	Economy	6300.00
0005432460576	8192	Economy	6300.00
0005435885903	8192	Economy	6300.00
0005435885895	8192	Economy	6300.00
0005433507280	8192	Economy	6300.00
0005435885921	8192	Economy	6300.00
0005435885913	8192	Economy	6300.00
0005432460594	8192	Economy	6300.00
0005435885889	8192	Economy	6300.00
0005435885927	8192	Economy	6300.00
0005432042899	8192	Economy	6300.00
0005435885929	8192	Economy	6300.00
0005433507205	8192	Economy	6300.00
0005432460602	8192	Economy	6300.00
0005433507253	8192	Economy	6300.00
0005432460609	8192	Economy	6300.00
0005432042907	8192	Economy	6300.00
0005432460583	8192	Economy	6300.00
0005435885923	8192	Economy	6300.00
0005432460584	8192	Economy	6300.00
0005432460599	8192	Economy	6300.00
0005433507286	8192	Economy	6300.00
0005433507250	8192	Economy	6300.00
0005433507213	8192	Economy	6300.00
0005432460600	8192	Economy	6300.00
0005432460595	8192	Economy	6300.00
0005435885887	8192	Economy	6300.00
0005432460572	8192	Economy	6300.00
0005435885893	8192	Economy	6300.00
0005435885888	8192	Economy	6300.00
0005432042904	8192	Economy	6300.00
0005432460574	8192	Economy	6300.00
0005432042898	8192	Economy	6300.00
0005432460569	8192	Economy	6300.00
0005435885922	8192	Economy	6300.00
0005432460564	8192	Economy	6300.00
0005432042902	8192	Economy	6300.00
0005435885911	8192	Economy	6900.00
0005432460579	8192	Economy	6900.00
0005435885926	8192	Economy	6900.00
0005435885890	8192	Economy	6900.00
0005433507254	8192	Economy	6900.00
0005432460582	8192	Economy	6300.00
0005432460611	8192	Economy	6300.00
0005435885886	8192	Economy	6300.00
0005433507265	8192	Economy	6300.00
0005432042896	8192	Economy	6900.00
0005433507150	8192	Economy	6300.00
0005435885891	8192	Economy	6300.00
0005432042906	8192	Economy	6300.00
0005435885908	8192	Economy	6300.00
0005435885884	8192	Economy	6300.00
0005434312348	8192	Economy	6300.00
0005432460593	8192	Economy	6300.00
0005432460596	8192	Economy	6300.00
0005433507235	8192	Economy	6300.00
0005432460565	8192	Economy	6300.00
0005435885885	8192	Economy	6300.00
0005432042905	8192	Economy	6300.00
0005435885915	8192	Economy	6300.00
0005432460610	8192	Economy	6300.00
0005432460591	8192	Economy	6300.00
0005434312349	8192	Economy	6300.00
0005432042901	8192	Economy	6300.00
0005432460589	8192	Economy	6300.00
0005433507281	8192	Economy	6300.00
0005435885897	8192	Economy	6300.00
0005433507238	8192	Economy	6300.00
0005433507179	8192	Economy	6300.00
0005432460587	8192	Economy	6300.00
0005435885918	8192	Economy	6300.00
0005432460586	8192	Economy	6300.00
0005433507255	8192	Economy	6300.00
0005433507178	8192	Economy	6300.00
0005433507263	8192	Economy	6300.00
0005432460559	8192	Economy	6300.00
0005435885916	8192	Economy	6300.00
0005432460578	8192	Economy	6300.00
0005432460606	8192	Economy	6300.00
0005432460577	8192	Economy	6300.00
0005433507202	8192	Economy	6300.00
0005432460568	8192	Economy	6300.00
0005435885906	8192	Economy	6300.00
0005435885924	8192	Economy	6300.00
0005433507258	8192	Economy	6300.00
0005432042900	8192	Economy	6300.00
0005435885917	8192	Economy	6300.00
0005433507257	8192	Economy	6300.00
0005433507284	8192	Economy	6300.00
0005433507234	8192	Economy	6300.00
0005432460592	8192	Economy	6300.00
0005433507204	8192	Economy	6300.00
0005435885910	8192	Economy	6300.00
0005435885920	8192	Economy	6300.00
0005433507264	8192	Economy	6300.00
0005432460590	8192	Economy	6300.00
0005432042897	8192	Economy	6300.00
0005435885901	8192	Economy	6300.00
0005432460580	8192	Economy	6300.00
0005435885919	8192	Economy	6300.00
0005435885905	8192	Economy	6300.00
0005435885896	8192	Economy	6300.00
0005433805528	8193	Business	18800.00
0005433805551	8193	Business	18800.00
0005433805532	8193	Business	18800.00
0005433634013	8193	Business	18800.00
0005433633935	8193	Business	18800.00
0005433805455	8193	Business	18800.00
0005433805563	8193	Business	18800.00
0005433805463	8193	Business	18800.00
0005433805497	8193	Business	18800.00
0005433805669	8193	Business	18800.00
0005433633829	8193	Business	18800.00
0005434143740	8193	Economy	6900.00
0005433633819	8193	Economy	6900.00
0005433633905	8193	Economy	6300.00
0005433633901	8193	Economy	6300.00
0005433805562	8193	Economy	6300.00
0005433634083	8193	Economy	6300.00
0005433633826	8193	Economy	6300.00
0005433634047	8193	Economy	6300.00
0005434143739	8193	Economy	6300.00
0005433633990	8193	Economy	6300.00
0005433805444	8193	Economy	6300.00
0005433634084	8193	Economy	6300.00
0005433633845	8193	Economy	6300.00
0005433633940	8193	Economy	6300.00
0005433633939	8193	Economy	6300.00
0005434143733	8193	Economy	6300.00
0005433633844	8193	Economy	6300.00
0005433633915	8193	Economy	6300.00
0005433634012	8193	Economy	6300.00
0005433805606	8193	Economy	6300.00
0005433633967	8193	Economy	6300.00
0005433805605	8193	Economy	6300.00
0005433805434	8193	Economy	6300.00
0005433633872	8193	Economy	6300.00
0005433805566	8193	Economy	6300.00
0005433634020	8193	Economy	6300.00
0005433633818	8193	Economy	6300.00
0005433633974	8193	Economy	6300.00
0005433805523	8193	Economy	6300.00
0005433633808	8193	Economy	6900.00
0005433805508	8193	Economy	6300.00
0005433633807	8193	Economy	6900.00
0005433805421	8193	Economy	6900.00
0005434143730	8193	Economy	6300.00
0005433633828	8193	Economy	6300.00
0005433633827	8193	Economy	6900.00
0005433634030	8193	Economy	6300.00
0005433633775	8193	Economy	6300.00
0005433805524	8193	Economy	6300.00
0005433805501	8193	Economy	6300.00
0005433633988	8193	Economy	6300.00
0005433633959	8193	Economy	6300.00
0005433805607	8193	Economy	6300.00
0005433805542	8193	Economy	6300.00
0005433633914	8193	Economy	6300.00
0005433805622	8193	Economy	6300.00
0005433633882	8193	Economy	6300.00
0005433633871	8193	Economy	6300.00
0005433633820	8193	Economy	6300.00
0005433805445	8193	Economy	6300.00
0005433805516	8193	Economy	6300.00
0005433805531	8193	Economy	6300.00
0005433805547	8193	Economy	6300.00
0005433633945	8193	Economy	6300.00
0005433633936	8193	Economy	6300.00
0005433634046	8193	Economy	6300.00
0005433633910	8193	Economy	6300.00
0005433633947	8193	Economy	6300.00
0005433633973	8193	Economy	6300.00
0005433805435	8193	Economy	6300.00
0005434271313	8193	Economy	6300.00
0005433633975	8193	Economy	6300.00
0005433805559	8193	Economy	6300.00
0005433633941	8193	Economy	6300.00
0005433805604	8193	Economy	6300.00
0005433805449	8193	Economy	6300.00
0005433633809	8193	Economy	6300.00
0005433633987	8193	Economy	6300.00
0005434183585	8194	Economy	6300.00
0005434183584	8194	Economy	6300.00
0005434183579	8194	Economy	6300.00
0005434183595	8194	Economy	6300.00
0005434183594	8194	Economy	6300.00
0005433722312	4640	Business	9900.00
0005432383706	4640	Business	9900.00
0005433194894	4640	Business	9900.00
0005432383701	4640	Economy	3300.00
0005433454904	4640	Economy	3300.00
0005432728111	4640	Economy	3300.00
0005432383683	4640	Economy	3300.00
0005433722311	4640	Economy	3300.00
0005432728101	4640	Economy	3300.00
0005432728109	4640	Economy	3600.00
0005432383700	4640	Economy	3600.00
0005433722313	4640	Economy	3600.00
0005432383682	4640	Economy	3600.00
0005432383685	4640	Economy	3300.00
0005432728104	4640	Economy	3300.00
0005432383703	4640	Economy	3300.00
0005433194896	4640	Economy	3300.00
0005432383694	4640	Economy	3300.00
0005433722310	4640	Economy	3300.00
0005432383681	4640	Economy	3300.00
0005432383688	4640	Economy	3300.00
0005433194895	4640	Economy	3300.00
0005432383689	4640	Economy	3300.00
0005432383707	4640	Economy	3300.00
0005432383686	4640	Economy	3300.00
0005432728102	4640	Economy	3300.00
0005432728106	4640	Economy	3300.00
0005432383695	4640	Economy	3300.00
0005432383702	4640	Economy	3300.00
0005433453787	4640	Economy	3300.00
0005432383692	4640	Economy	3300.00
0005432728108	4640	Economy	3300.00
0005433194897	4640	Economy	3300.00
0005432728112	4640	Economy	3300.00
0005432383687	4640	Economy	3300.00
0005433194892	4640	Economy	3300.00
0005432383680	4640	Economy	3300.00
0005432728105	4640	Economy	3300.00
0005432728107	4640	Economy	3300.00
0005432383696	4640	Economy	3300.00
0005432383698	4640	Economy	3300.00
0005433194893	4640	Economy	3300.00
0005432728103	4640	Economy	3300.00
0005432383697	4640	Economy	3300.00
0005433722309	4640	Economy	3300.00
0005432383708	4640	Economy	3300.00
0005432383704	4640	Economy	3300.00
0005432383705	4640	Economy	3300.00
0005432383693	4640	Economy	3300.00
0005432383684	4640	Economy	3300.00
0005432728110	4640	Economy	3300.00
0005433454903	4640	Economy	3300.00
0005432383691	4640	Economy	3300.00
0005432728100	4640	Economy	3300.00
0005432383690	4640	Economy	3300.00
0005432383699	4640	Economy	3300.00
0005432383244	30162	Business	9900.00
0005433722226	30162	Business	9900.00
0005432383215	30162	Business	9900.00
0005432727998	30162	Business	9900.00
0005432728019	30162	Business	9900.00
0005432383259	30162	Business	9900.00
0005432383177	30162	Business	9900.00
0005432728012	30162	Business	9900.00
0005432383296	30162	Economy	3300.00
0005433453771	30162	Economy	3300.00
0005432383328	30162	Economy	3300.00
0005432383145	30162	Economy	3300.00
0005433722223	30162	Economy	3300.00
0005432383250	30162	Economy	3300.00
0005433722209	30162	Economy	3600.00
0005432383258	30162	Economy	3600.00
0005433451622	30162	Economy	3600.00
0005432383251	30162	Economy	3600.00
0005432383383	30162	Economy	3300.00
0005432728017	30162	Economy	3300.00
0005432383249	30162	Economy	3300.00
0005432383182	30162	Economy	3300.00
0005433453774	30162	Economy	3300.00
0005432728016	30162	Economy	3300.00
0005432383272	30162	Economy	3300.00
0005432383214	30162	Economy	3300.00
0005432383246	30162	Economy	3300.00
0005432727935	30162	Economy	3300.00
0005432728041	30162	Economy	3300.00
0005432383108	30162	Economy	3300.00
0005432383263	30162	Economy	3300.00
0005432728011	30162	Economy	3300.00
0005432383195	30162	Economy	3300.00
0005432383175	30162	Economy	3300.00
0005432727936	30162	Economy	3300.00
0005432728000	30162	Economy	3300.00
0005432383196	30162	Economy	3300.00
0005432383294	30162	Economy	3300.00
0005432383427	30162	Economy	3300.00
0005433451625	30162	Economy	3300.00
0005432383363	30162	Economy	3300.00
0005433453768	30162	Economy	3300.00
0005433722222	30162	Economy	3300.00
0005432383176	30162	Economy	3300.00
0005432383341	30162	Economy	3300.00
0005432383305	30162	Economy	3300.00
0005433451623	30162	Economy	3300.00
0005432383172	30162	Economy	3300.00
0005432383181	30162	Economy	3300.00
0005432383339	30162	Economy	3300.00
0005432383441	30162	Economy	3300.00
0005432383144	30162	Economy	3300.00
0005432383231	30162	Economy	3300.00
0005432727933	30162	Economy	3300.00
0005432383204	30162	Economy	3300.00
0005432383165	30162	Economy	3300.00
0005432383426	30162	Economy	3300.00
0005432383295	30162	Economy	3300.00
0005432383205	30162	Economy	3300.00
0005432728040	30162	Economy	3300.00
0005433453773	30162	Economy	3300.00
0005432383319	30162	Economy	3300.00
0005432383166	30162	Economy	3300.00
0005432383271	30162	Economy	3300.00
0005432383047	30162	Economy	3300.00
0005432727984	30162	Economy	3300.00
0005432383184	30162	Economy	3300.00
0005432383106	30162	Economy	3300.00
0005433451624	30162	Economy	3300.00
0005435541298	1731	Business	57200.00
0005433517013	1731	Business	57200.00
0005435529560	1731	Business	57200.00
0005435529544	1731	Business	57200.00
0005435529559	1731	Business	57200.00
0005435541291	1731	Business	57200.00
0005435529551	1731	Business	57200.00
0005435529546	1731	Business	57200.00
0005435541300	1731	Business	57200.00
0005435541293	1731	Economy	19100.00
0005435541288	1731	Economy	19100.00
0005432925066	1731	Economy	19100.00
0005435541289	1731	Economy	19100.00
0005435541287	1731	Economy	19100.00
0005435541308	1731	Economy	19100.00
0005432925049	1731	Economy	21000.00
0005435541292	1731	Economy	21000.00
0005435529553	1731	Economy	21000.00
0005432925062	1731	Economy	19100.00
0005433517011	1731	Economy	19100.00
0005435541294	1731	Economy	19100.00
0005432925045	1731	Economy	19100.00
0005435529558	1731	Economy	19100.00
0005435541306	1731	Economy	19100.00
0005435529555	1731	Economy	19100.00
0005435529547	1731	Economy	19100.00
0005435541299	1731	Economy	19100.00
0005433517010	1731	Economy	19100.00
0005435541310	1731	Economy	19100.00
0005435529550	1731	Economy	19100.00
0005435541302	1731	Economy	19100.00
0005435541295	1731	Economy	19100.00
0005435541307	1731	Economy	19100.00
0005435541303	1731	Economy	19100.00
0005435529561	1731	Economy	19100.00
0005432925038	1731	Economy	19100.00
0005435541304	1731	Economy	19100.00
0005432925046	1731	Economy	19100.00
0005435529562	1731	Economy	19100.00
0005433517017	1731	Economy	19100.00
0005433517012	1731	Economy	19100.00
0005433517015	1731	Economy	19100.00
0005435541297	1731	Economy	19100.00
0005435529543	1731	Economy	19100.00
0005435541290	1731	Economy	19100.00
0005435529549	1731	Economy	19100.00
0005433517018	1731	Economy	19100.00
0005435541309	1731	Economy	19100.00
0005435529548	1731	Economy	19100.00
0005435529557	1731	Economy	19100.00
0005432925065	1731	Economy	19100.00
0005435541305	1731	Economy	19100.00
0005435529563	1731	Economy	19100.00
0005435529552	1731	Economy	19100.00
0005435541296	1731	Economy	19100.00
0005433517014	1731	Economy	19100.00
0005433517009	1731	Economy	19100.00
0005435529545	1731	Economy	19100.00
0005435541301	1731	Economy	19100.00
0005433517016	1731	Economy	19100.00
0005435529564	1731	Economy	19100.00
0005432294520	1731	Economy	19100.00
0005435529556	1731	Economy	19100.00
0005435529554	1731	Economy	19100.00
0005435541037	21971	Business	57200.00
0005435541084	21971	Business	57200.00
0005435517986	21971	Business	57200.00
0005435541184	21971	Business	57200.00
0005435541078	21971	Business	57200.00
0005435541123	21971	Business	57200.00
0005433516884	21971	Business	57200.00
0005435517944	21971	Business	57200.00
0005435541054	21971	Business	57200.00
0005435517959	21971	Economy	19100.00
0005435541055	21971	Economy	19100.00
0005433516885	21971	Economy	19100.00
0005435541104	21971	Economy	19100.00
0005435517985	21971	Economy	21000.00
0005435541043	21971	Economy	21000.00
0005433516856	21971	Economy	21000.00
0005435541034	21971	Economy	21000.00
0005435518075	21971	Economy	21000.00
0005433516944	21971	Economy	19100.00
0005435541063	21971	Economy	19100.00
0005432925102	21971	Economy	19100.00
0005435541058	21971	Economy	19100.00
0005435541120	21971	Economy	19100.00
0005435517997	21971	Economy	19100.00
0005435541067	21971	Economy	19100.00
0005435541091	21971	Economy	19100.00
0005435517916	21971	Economy	19100.00
0005435541031	21971	Economy	19100.00
0005433516945	21971	Economy	19100.00
0005435517941	21971	Economy	19100.00
0005433516912	21971	Economy	19100.00
0005435517956	21971	Economy	19100.00
0005433516933	21971	Economy	19100.00
0005435541053	21971	Economy	19100.00
0005435541108	21971	Economy	19100.00
0005435541025	21971	Economy	19100.00
0005435517917	21971	Economy	19100.00
0005435541092	21971	Economy	19100.00
0005433516939	21971	Economy	19100.00
0005435517940	21971	Economy	19100.00
0005435517980	21971	Economy	19100.00
0005435517984	21971	Economy	19100.00
0005433516961	21971	Economy	19100.00
0005435541068	21971	Economy	19100.00
0005433516866	21971	Economy	19100.00
0005435541038	21971	Economy	19100.00
0005433516867	21971	Economy	19100.00
0005435541090	21971	Economy	19100.00
0005435541109	21971	Economy	19100.00
0005435518027	21971	Economy	19100.00
0005435517983	21971	Economy	19100.00
0005435517925	21971	Economy	19100.00
0005435541105	21971	Economy	19100.00
0005435518044	21971	Economy	19100.00
0005435541133	21971	Economy	19100.00
0005433516932	21971	Economy	19100.00
0005435541119	21971	Economy	19100.00
0005435541093	21971	Economy	19100.00
0005435518029	21971	Economy	19100.00
0005435541012	21971	Economy	19100.00
0005435541129	21971	Economy	19100.00
0005435541113	21971	Economy	19100.00
0005435541013	21971	Economy	19100.00
0005432925101	21971	Economy	19100.00
0005435517943	21971	Economy	19100.00
0005435518026	21971	Economy	19100.00
0005435517996	21971	Economy	19100.00
0005435541024	21971	Economy	19100.00
0005432925100	21971	Economy	19100.00
0005435541124	21971	Economy	19100.00
0005432925099	21971	Economy	19100.00
0005435252794	7397	Business	18500.00
0005435491454	7397	Business	18500.00
0005434664970	7397	Business	18500.00
0005434459084	7397	Business	18500.00
0005432839450	7397	Business	18500.00
0005432839440	7397	Business	18500.00
0005432839466	7397	Business	18500.00
0005432839442	7397	Business	18500.00
0005434459085	7397	Business	18500.00
0005432839443	7397	Business	18500.00
0005434459093	7397	Business	18500.00
0005432839445	7397	Economy	6200.00
0005434459090	7397	Economy	6200.00
0005435252807	7397	Economy	6200.00
0005432839456	7397	Economy	6200.00
0005434459088	7397	Economy	6200.00
0005435252775	7397	Economy	6200.00
0005432839449	7397	Economy	6200.00
0005434459081	7397	Economy	6200.00
0005432839448	7397	Economy	6800.00
0005432841040	7397	Economy	6800.00
0005432073439	7397	Economy	6800.00
0005432839461	7397	Economy	6800.00
0005434459082	7397	Economy	6800.00
0005432839452	7397	Economy	6200.00
0005432839459	7397	Economy	6200.00
0005432839444	7397	Economy	6200.00
0005434459089	7397	Economy	6200.00
0005432841039	7397	Economy	6200.00
0005432823474	7397	Economy	6200.00
0005434459074	7397	Economy	6200.00
0005434459092	7397	Economy	6200.00
0005432839437	7397	Economy	6200.00
0005434459079	7397	Economy	6200.00
0005434459078	7397	Economy	6200.00
0005434459076	7397	Economy	6200.00
0005432839454	7397	Economy	6200.00
0005434664969	7397	Economy	6200.00
0005432073438	7397	Economy	6200.00
0005432839455	7397	Economy	6200.00
0005434459086	7397	Economy	6200.00
0005432839441	7397	Economy	6200.00
0005432839438	7397	Economy	6200.00
0005432823475	7397	Economy	6200.00
0005432839439	7397	Economy	6200.00
0005435252874	7397	Economy	6200.00
0005435491453	7397	Economy	6200.00
0005434664967	7397	Economy	6200.00
0005435252750	7397	Economy	6200.00
0005432839453	7397	Economy	6200.00
0005432839462	7397	Economy	6200.00
0005432839465	7397	Economy	6200.00
0005434664968	7397	Economy	6200.00
0005434459091	7397	Economy	6200.00
0005432073437	7397	Economy	6200.00
0005435252805	7397	Economy	6200.00
0005432839436	7397	Economy	6200.00
0005432839463	7397	Economy	6200.00
0005432839451	7397	Economy	6200.00
0005432839458	7397	Economy	6200.00
0005434459075	7397	Economy	6200.00
0005432073436	7397	Economy	6200.00
0005434459087	7397	Economy	6200.00
0005432839457	7397	Economy	6200.00
0005434459077	7397	Economy	6200.00
0005432839464	7397	Economy	6200.00
0005435252749	7397	Economy	6200.00
0005435252781	7397	Economy	6200.00
0005434459080	7397	Economy	6200.00
0005432839435	7397	Economy	6200.00
0005435252814	7397	Economy	6200.00
0005432839446	7397	Economy	6200.00
0005435252852	7397	Economy	6200.00
0005434459073	7397	Economy	6200.00
0005432839447	7397	Economy	6200.00
0005435252793	7397	Economy	6200.00
0005432839460	7397	Economy	6200.00
0005434459083	7397	Economy	6200.00
0005434458950	28909	Business	18500.00
0005432839240	28909	Business	18500.00
0005432839338	28909	Business	18500.00
0005434458894	28909	Business	18500.00
0005434458890	28909	Business	18500.00
0005435252935	28909	Business	18500.00
0005432839193	28909	Business	18500.00
0005434458896	28909	Business	18500.00
0005434458840	28909	Business	18500.00
0005435252936	28909	Business	18500.00
0005434458897	28909	Business	18500.00
0005432839180	28909	Business	18500.00
0005432839188	28909	Economy	6200.00
0005432839166	28909	Economy	6200.00
0005435252943	28909	Economy	6200.00
0005435252948	28909	Economy	6200.00
0005434458985	28909	Economy	6200.00
0005432839265	28909	Economy	6200.00
0005432839181	28909	Economy	6200.00
0005432839191	28909	Economy	6200.00
0005434458889	28909	Economy	6200.00
0005432839218	28909	Economy	6200.00
0005432839151	28909	Economy	6800.00
0005432839204	28909	Economy	6800.00
0005432823458	28909	Economy	6800.00
0005432823461	28909	Economy	6800.00
0005434458899	28909	Economy	6800.00
0005432839164	28909	Economy	6200.00
0005434664990	28909	Economy	6200.00
0005432823464	28909	Economy	6200.00
0005432839174	28909	Economy	6200.00
0005435252930	28909	Economy	6200.00
0005435252931	28909	Economy	6200.00
0005434458934	28909	Economy	6200.00
0005435252932	28909	Economy	6200.00
0005432001049	28909	Economy	6200.00
0005432839194	28909	Economy	6200.00
0005432839122	28909	Economy	6200.00
0005432839228	28909	Economy	6200.00
0005434458984	28909	Economy	6200.00
0005434458919	28909	Economy	6200.00
0005435252939	28909	Economy	6200.00
0005432839205	28909	Economy	6200.00
0005435252947	28909	Economy	6200.00
0005434458986	28909	Economy	6200.00
0005432839339	28909	Economy	6200.00
0005435252933	28909	Economy	6200.00
0005432001050	28909	Economy	6200.00
0005435491469	28909	Economy	6200.00
0005432839150	28909	Economy	6200.00
0005435252934	28909	Economy	6200.00
0005432839162	28909	Economy	6200.00
0005432839182	28909	Economy	6200.00
0005434664992	28909	Economy	6200.00
0005432839239	28909	Economy	6200.00
0005432839145	28909	Economy	6200.00
0005432823467	28909	Economy	6200.00
0005435252945	28909	Economy	6200.00
0005432839175	28909	Economy	6200.00
0005432839305	28909	Economy	6200.00
0005435491468	28909	Economy	6200.00
0005434458895	28909	Economy	6200.00
0005432839230	28909	Economy	6200.00
0005434458920	28909	Economy	6200.00
0005435252944	28909	Economy	6200.00
0005434458901	28909	Economy	6200.00
0005432839121	28909	Economy	6200.00
0005432839274	28909	Economy	6200.00
0005435252949	28909	Economy	6200.00
0005432839190	28909	Economy	6200.00
0005432839163	28909	Economy	6200.00
0005434458980	28909	Economy	6200.00
0005432839183	28909	Economy	6200.00
0005435252941	28909	Economy	6200.00
0005434458888	28909	Economy	6200.00
0005432841025	28909	Economy	6200.00
0005434458891	28909	Economy	6200.00
0005435252937	28909	Economy	6200.00
0005432839189	28909	Economy	6200.00
0005432839227	28909	Economy	6200.00
0005432839173	28909	Economy	6200.00
0005435252942	28909	Economy	6200.00
0005434458974	28909	Economy	6200.00
0005432839184	28909	Economy	6200.00
0005432839217	28909	Economy	6200.00
0005432839187	28909	Economy	6200.00
0005432839201	28909	Economy	6200.00
0005435252938	28909	Economy	6200.00
0005435252940	28909	Economy	6200.00
0005432839275	28909	Economy	6200.00
0005434458900	28909	Economy	6200.00
0005434458973	28909	Economy	6200.00
0005434664991	28909	Economy	6200.00
0005435252946	28909	Economy	6200.00
0005432841027	28909	Economy	6200.00
0005432839337	28909	Economy	6200.00
0005435990719	8798	Business	145300.00
0005435990717	8798	Business	145300.00
0005435990716	8798	Business	145300.00
0005434276074	8798	Business	145300.00
0005435990720	8798	Business	145300.00
0005434276086	8798	Economy	48400.00
0005434276077	8798	Economy	48400.00
0005434276057	8798	Economy	48400.00
0005434276046	8798	Economy	48400.00
0005435990722	8798	Economy	48400.00
0005434276047	8798	Economy	48400.00
0005434276045	8798	Economy	48400.00
0005434276048	8798	Economy	48400.00
0005434276073	8798	Economy	48400.00
0005435990721	8798	Economy	48400.00
0005434276054	8798	Economy	48400.00
0005435990715	8798	Economy	48400.00
0005435990718	8798	Economy	48400.00
0005434276056	8798	Economy	48400.00
0005435990637	15763	Business	145300.00
0005435990678	15763	Business	145300.00
0005435990636	15763	Business	145300.00
0005435990643	15763	Business	145300.00
0005434276105	15763	Business	145300.00
0005434276103	15763	Economy	48400.00
0005435990644	15763	Economy	48400.00
0005435990679	15763	Economy	48400.00
0005434276106	15763	Economy	48400.00
0005435990659	15763	Economy	48400.00
0005435990628	15763	Economy	48400.00
0005435990660	15763	Economy	48400.00
0005435990627	15763	Economy	48400.00
0005435990642	15763	Economy	48400.00
0005434276101	15763	Economy	48400.00
0005435990682	15763	Economy	48400.00
0005435990670	15763	Economy	48400.00
0005434276102	15763	Economy	48400.00
0005434276104	15763	Economy	48400.00
0005432909300	2077	Economy	13300.00
0005433468450	2077	Economy	13300.00
0005433468444	2077	Economy	13300.00
0005433468455	2077	Economy	12100.00
0005433468449	2077	Economy	12100.00
0005433468451	2077	Economy	12100.00
0005433468461	2077	Economy	12100.00
0005433468448	2077	Economy	12100.00
0005432909310	2077	Economy	12100.00
0005433468457	2077	Economy	12100.00
0005433468458	2077	Economy	12100.00
0005432909318	2077	Economy	12100.00
0005432909304	2077	Economy	12100.00
0005433468453	2077	Economy	12100.00
0005433468447	2077	Economy	12100.00
0005433468454	2077	Economy	12100.00
0005433468460	2077	Economy	12100.00
0005432909303	2077	Economy	12100.00
0005432909308	2077	Economy	12100.00
0005433468456	2077	Economy	12100.00
0005432909299	2077	Economy	12100.00
0005433468452	2077	Economy	12100.00
0005432909291	2077	Economy	12100.00
0005432909315	2077	Economy	12100.00
0005433468446	2077	Economy	12100.00
0005433468459	2077	Economy	12100.00
0005433468445	2077	Economy	12100.00
0005432909352	23842	Economy	13300.00
0005432909358	23842	Economy	13300.00
0005433468361	23842	Economy	13300.00
0005433468354	23842	Economy	13300.00
0005433468375	23842	Economy	12100.00
0005432909350	23842	Economy	12100.00
0005433468341	23842	Economy	12100.00
0005432909343	23842	Economy	12100.00
0005432909354	23842	Economy	12100.00
0005433468391	23842	Economy	12100.00
0005433468373	23842	Economy	12100.00
0005433468343	23842	Economy	12100.00
0005433468338	23842	Economy	12100.00
0005433468382	23842	Economy	12100.00
0005432909345	23842	Economy	12100.00
0005433468336	23842	Economy	12100.00
0005433468374	23842	Economy	12100.00
0005432909348	23842	Economy	12100.00
0005432909353	23842	Economy	12100.00
0005432909351	23842	Economy	12100.00
0005433468385	23842	Economy	12100.00
0005432909344	23842	Economy	12100.00
0005433468367	23842	Economy	12100.00
0005432909346	23842	Economy	12100.00
0005433468353	23842	Economy	12100.00
0005433468339	23842	Economy	12100.00
0005432909357	23842	Economy	12100.00
0005433468384	23842	Economy	12100.00
0005433468366	23842	Economy	12100.00
0005432909356	23842	Economy	12100.00
0005433468397	23842	Economy	12100.00
0005433468314	23842	Economy	12100.00
0005433468342	23842	Economy	12100.00
0005432909349	23842	Economy	12100.00
0005433468396	23842	Economy	12100.00
0005433468360	23842	Economy	12100.00
0005433468363	23842	Economy	12100.00
0005432909355	23842	Economy	12100.00
0005433468376	23842	Economy	12100.00
0005432909347	23842	Economy	12100.00
0005434149830	6393	Business	36600.00
0005434149812	6393	Business	36600.00
0005432062298	6393	Business	36600.00
0005434149750	6393	Business	36600.00
0005432336189	6393	Business	36600.00
0005432336187	6393	Business	36600.00
0005432336194	6393	Business	36600.00
0005432361009	6393	Business	36600.00
0005434149809	6393	Business	36600.00
0005435177288	6393	Business	36600.00
0005435177203	6393	Business	36600.00
0005434149776	6393	Economy	12200.00
0005432361022	6393	Economy	12200.00
0005435177152	6393	Economy	12200.00
0005435177214	6393	Economy	12200.00
0005432360992	6393	Economy	12200.00
0005435177257	6393	Economy	12200.00
0005434149791	6393	Economy	12200.00
0005432363461	6393	Economy	12200.00
0005432062299	6393	Economy	12200.00
0005434149811	6393	Economy	12200.00
0005435177253	6393	Economy	12200.00
0005432360990	6393	Economy	12200.00
0005435490233	6393	Economy	12200.00
0005432336188	6393	Economy	12200.00
0005432360997	6393	Economy	12200.00
0005435177273	6393	Economy	12200.00
0005435177144	6393	Economy	12200.00
0005432360982	6393	Economy	12200.00
0005432361024	6393	Economy	12200.00
0005432361028	6393	Economy	12200.00
0005435177138	6393	Economy	12200.00
0005432360995	6393	Economy	12200.00
0005435177216	6393	Economy	12200.00
0005432336191	6393	Economy	12200.00
0005432361027	6393	Economy	12200.00
0005435177197	6393	Economy	12200.00
0005435177252	6393	Economy	12200.00
0005432363459	6393	Economy	12200.00
0005434149777	6393	Economy	12200.00
0005432062302	6393	Economy	12200.00
0005432360994	6393	Economy	12200.00
0005432360991	6393	Economy	12200.00
0005435177256	6393	Economy	12200.00
0005432361002	6393	Economy	12200.00
0005432363460	6393	Economy	12200.00
0005435177297	6393	Economy	12200.00
0005432361000	6393	Economy	12200.00
0005432361003	6393	Economy	12200.00
0005435177255	6393	Economy	12200.00
0005432361006	6393	Economy	12200.00
0005432361012	6393	Economy	13400.00
0005434149813	6393	Economy	13400.00
0005432361019	6393	Economy	13400.00
0005432360993	6393	Economy	13400.00
0005432360999	6393	Economy	13400.00
0005432361008	6393	Economy	13400.00
0005432361011	6393	Economy	12200.00
0005432336195	6393	Economy	12200.00
0005435177212	6393	Economy	12200.00
0005434149797	6393	Economy	12200.00
0005432336196	6393	Economy	12200.00
0005435177245	6393	Economy	12200.00
0005432361010	6393	Economy	12200.00
0005432336190	6393	Economy	12200.00
0005432361025	6393	Economy	12200.00
0005435177315	6393	Economy	12200.00
0005432361015	6393	Economy	12200.00
0005432361007	6393	Economy	12200.00
0005432360986	6393	Economy	12200.00
0005435177308	6393	Economy	12200.00
0005432360998	6393	Economy	12200.00
0005432361016	6393	Economy	12200.00
0005434149807	6393	Economy	12200.00
0005432336198	6393	Economy	12200.00
0005432062301	6393	Economy	12200.00
0005435177034	6393	Economy	12200.00
0005435177302	6393	Economy	12200.00
0005434149802	6393	Economy	12200.00
0005432361004	6393	Economy	12200.00
0005434149794	6393	Economy	12200.00
0005432336197	6393	Economy	12200.00
0005435177159	6393	Economy	12200.00
0005435177213	6393	Economy	12200.00
0005432360987	6393	Economy	12200.00
0005435177195	6393	Economy	12200.00
0005432361001	6393	Economy	12200.00
0005435177193	6393	Economy	12200.00
0005432360988	6393	Economy	12200.00
0005432336192	6393	Economy	12200.00
0005432336193	6393	Economy	12200.00
0005435177301	6393	Economy	12200.00
0005435177196	6393	Economy	12200.00
0005432361030	6393	Economy	12200.00
0005435177316	6393	Economy	12200.00
0005432360996	6393	Economy	12200.00
0005432360989	6393	Economy	12200.00
0005432361029	6393	Economy	12200.00
0005435177355	6393	Economy	12200.00
0005432361013	6393	Economy	12200.00
0005432361026	6393	Economy	12200.00
0005435177296	6393	Economy	12200.00
0005432361021	6393	Economy	12200.00
0005435177215	6393	Economy	12200.00
0005435177320	6393	Economy	12200.00
0005432360983	6393	Economy	12200.00
0005432062297	6393	Economy	12200.00
0005432361023	6393	Economy	12200.00
0005435177104	6393	Economy	12200.00
0005432361020	6393	Economy	12200.00
0005435177254	6393	Economy	12200.00
0005432361018	6393	Economy	12200.00
0005435177249	6393	Economy	12200.00
0005434149808	6393	Economy	12200.00
0005432361014	6393	Economy	12200.00
0005435177237	6393	Economy	12200.00
0005435490232	6393	Economy	12200.00
0005432062300	6393	Economy	12200.00
0005432336199	6393	Economy	12200.00
0005435177143	6393	Economy	12200.00
0005432360985	6393	Economy	12200.00
0005432360984	6393	Economy	12200.00
0005432361017	6393	Economy	12200.00
0005432363458	6393	Economy	12200.00
0005435177346	6393	Economy	12200.00
0005432361005	6393	Economy	12200.00
0005435177202	6393	Economy	12200.00
0005432360541	21038	Business	36600.00
0005435177432	21038	Business	36600.00
0005432360513	21038	Business	36600.00
0005434149883	21038	Business	36600.00
0005432360349	21038	Business	36600.00
0005435177433	21038	Business	36600.00
0005432360766	21038	Business	36600.00
0005432360512	21038	Business	36600.00
0005435177438	21038	Business	36600.00
0005432360510	21038	Business	36600.00
0005432360671	21038	Business	36600.00
0005435177434	21038	Economy	12200.00
0005435177431	21038	Economy	12200.00
0005432360615	21038	Economy	12200.00
0005435177430	21038	Economy	12200.00
0005432360706	21038	Economy	12200.00
0005432360409	21038	Economy	12200.00
0005432360509	21038	Economy	12200.00
0005435177450	21038	Economy	12200.00
0005432360862	21038	Economy	12200.00
0005434149882	21038	Economy	12200.00
0005435490281	21038	Economy	12200.00
0005432336104	21038	Economy	12200.00
0005435177457	21038	Economy	12200.00
0005434149887	21038	Economy	12200.00
0005432360670	21038	Economy	12200.00
0005432360511	21038	Economy	12200.00
0005432360818	21038	Economy	12200.00
0005432336086	21038	Economy	12200.00
0005432360484	21038	Economy	12200.00
0005435177448	21038	Economy	12200.00
0005435177442	21038	Economy	12200.00
0005432360350	21038	Economy	12200.00
0005432360612	21038	Economy	12200.00
0005432360603	21038	Economy	12200.00
0005432360540	21038	Economy	12200.00
0005432360778	21038	Economy	12200.00
0005432360701	21038	Economy	12200.00
0005432360616	21038	Economy	12200.00
0005432052786	21038	Economy	12200.00
0005434149892	21038	Economy	12200.00
0005432360553	21038	Economy	12200.00
0005432360526	21038	Economy	12200.00
0005432360776	21038	Economy	12200.00
0005434149894	21038	Economy	12200.00
0005432336073	21038	Economy	12200.00
0005435177437	21038	Economy	12200.00
0005432360558	21038	Economy	13400.00
0005434149885	21038	Economy	13400.00
0005435490282	21038	Economy	13400.00
0005432336137	21038	Economy	13400.00
0005432360465	21038	Economy	13400.00
0005432360586	21038	Economy	13400.00
0005435490279	21038	Economy	12200.00
0005435177454	21038	Economy	12200.00
0005435490280	21038	Economy	12200.00
0005432360590	21038	Economy	12200.00
0005432336114	21038	Economy	12200.00
0005432360669	21038	Economy	12200.00
0005432336074	21038	Economy	12200.00
0005435177453	21038	Economy	12200.00
0005432336102	21038	Economy	12200.00
0005435177451	21038	Economy	12200.00
0005432360631	21038	Economy	12200.00
0005432336032	21038	Economy	12200.00
0005432336053	21038	Economy	12200.00
0005435177440	21038	Economy	12200.00
0005434149890	21038	Economy	12200.00
0005435177441	21038	Economy	12200.00
0005435177458	21038	Economy	12200.00
0005432336066	21038	Economy	12200.00
0005435177439	21038	Economy	12200.00
0005435177443	21038	Economy	12200.00
0005432360552	21038	Economy	12200.00
0005432336033	21038	Economy	12200.00
0005434149891	21038	Economy	12200.00
0005434149889	21038	Economy	12200.00
0005432336113	21038	Economy	12200.00
0005432052785	21038	Economy	12200.00
0005435177435	21038	Economy	12200.00
0005432360715	21038	Economy	12200.00
0005432360716	21038	Economy	12200.00
0005435177444	21038	Economy	12200.00
0005432360679	21038	Economy	12200.00
0005434149886	21038	Economy	12200.00
0005432360462	21038	Economy	12200.00
0005435177447	21038	Economy	12200.00
0005432336067	21038	Economy	12200.00
0005432052787	21038	Economy	12200.00
0005432360662	21038	Economy	12200.00
0005435177445	21038	Economy	12200.00
0005435177456	21038	Economy	12200.00
0005432360777	21038	Economy	12200.00
0005432360613	21038	Economy	12200.00
0005435177446	21038	Economy	12200.00
0005432360658	21038	Economy	12200.00
0005432360636	21038	Economy	12200.00
0005435177452	21038	Economy	12200.00
0005435723074	21038	Economy	12200.00
0005432360604	21038	Economy	12200.00
0005432360693	21038	Economy	12200.00
0005432360692	21038	Economy	12200.00
0005432360591	21038	Economy	12200.00
0005432336138	21038	Economy	12200.00
0005435177449	21038	Economy	12200.00
0005432360769	21038	Economy	12200.00
0005432360765	21038	Economy	12200.00
0005435177455	21038	Economy	12200.00
0005434149884	21038	Economy	12200.00
0005432360545	21038	Economy	12200.00
0005434149888	21038	Economy	12200.00
0005432336103	21038	Economy	12200.00
0005432360546	21038	Economy	12200.00
0005435177436	21038	Economy	12200.00
0005432360459	21038	Economy	12200.00
0005432360653	21038	Economy	12200.00
0005432360519	21038	Economy	12200.00
0005434149893	21038	Economy	12200.00
0005432360680	21038	Economy	12200.00
0005434458935	17742	Economy	3400.00
0005434448322	17742	Economy	3400.00
0005434458917	17742	Economy	3100.00
0005434458954	17742	Economy	3100.00
0005434448325	17742	Economy	3100.00
0005434458907	17742	Economy	3100.00
0005434458909	17742	Economy	3100.00
0005434448324	17742	Economy	3100.00
0005434186239	17742	Economy	3100.00
0005434463937	17742	Economy	3100.00
0005434186238	17742	Economy	3100.00
0005434458959	17742	Economy	3100.00
0005434458877	17742	Economy	3100.00
0005434458902	17742	Economy	3100.00
0005434458929	17742	Economy	3100.00
0005434458952	17742	Economy	3100.00
0005434458936	17742	Economy	3100.00
0005434448323	17742	Economy	3100.00
0005434458906	17742	Economy	3100.00
0005434463942	17742	Economy	3100.00
0005434448321	17742	Economy	3100.00
0005434458956	17742	Economy	3100.00
0005434458855	17742	Economy	3100.00
0005434461656	17742	Economy	3100.00
0005434458953	17742	Economy	3100.00
0005434458937	17742	Economy	3100.00
0005434459091	29081	Economy	3400.00
0005434459085	29081	Economy	3400.00
0005434459087	29081	Economy	3100.00
0005434459080	29081	Economy	3100.00
0005434459084	29081	Economy	3100.00
0005434459088	29081	Economy	3100.00
0005434448357	29081	Economy	3100.00
0005434186207	29081	Economy	3100.00
0005434463956	29081	Economy	3100.00
0005434459083	29081	Economy	3100.00
0005434459081	29081	Economy	3100.00
0005434462817	29081	Economy	3100.00
0005434459077	29081	Economy	3100.00
0005434459089	29081	Economy	3100.00
0005434459093	29081	Economy	3100.00
0005434459078	29081	Economy	3100.00
0005434459075	29081	Economy	3100.00
0005434448356	29081	Economy	3100.00
0005434459090	29081	Economy	3100.00
0005434459074	29081	Economy	3100.00
0005434462818	29081	Economy	3100.00
0005434186209	29081	Economy	3100.00
0005434459079	29081	Economy	3100.00
0005434186206	29081	Economy	3100.00
0005434459086	29081	Economy	3100.00
0005434459076	29081	Economy	3100.00
0005434463955	29081	Economy	3100.00
0005434459092	29081	Economy	3100.00
0005434459082	29081	Economy	3100.00
0005434186210	29081	Economy	3100.00
0005434186196	29081	Economy	3100.00
0005434186201	29081	Economy	3100.00
0005434462816	29081	Economy	3100.00
0005434459073	29081	Economy	3100.00
0005434448358	29081	Economy	3100.00
0005434448359	29081	Economy	3100.00
0005434186214	29081	Economy	3100.00
0005434186197	29081	Economy	3100.00
0005432604824	21463	Economy	7300.00
0005432604850	21463	Economy	7300.00
0005432604856	21463	Economy	7300.00
0005432604840	21463	Economy	7300.00
0005432604827	21463	Economy	6600.00
0005432604838	21463	Economy	6600.00
0005435218119	21463	Economy	6600.00
0005432604857	21463	Economy	6600.00
0005432604853	21463	Economy	6600.00
0005432604819	21463	Economy	6600.00
0005432604831	21463	Economy	6600.00
0005432604842	21463	Economy	6600.00
0005432604858	21463	Economy	6600.00
0005432604855	21463	Economy	6600.00
0005432604854	21463	Economy	6600.00
0005432604825	21463	Economy	6600.00
0005432604846	21463	Economy	6600.00
0005432604852	21463	Economy	6600.00
0005432604844	21463	Economy	6600.00
0005432604826	21463	Economy	6600.00
0005432604851	21463	Economy	6600.00
0005432604847	21463	Economy	6600.00
0005432604823	21463	Economy	6600.00
0005432604818	21463	Economy	6600.00
0005432604835	21463	Economy	6600.00
0005432604829	21463	Economy	6600.00
0005432604822	21463	Economy	6600.00
0005432604845	21463	Economy	6600.00
0005432604836	21463	Economy	6600.00
0005432604821	21463	Economy	6600.00
0005432604820	21463	Economy	6600.00
0005432604848	21463	Economy	6600.00
0005432604832	21463	Economy	6600.00
0005432604859	21463	Economy	6600.00
0005432604839	21463	Economy	6600.00
0005432604837	21463	Economy	6600.00
0005432604849	21463	Economy	6600.00
0005432604834	21463	Economy	6600.00
0005432604828	21463	Economy	6600.00
0005432604841	21463	Economy	6600.00
0005432604833	21463	Economy	6600.00
0005432604830	21463	Economy	6600.00
0005432604843	21463	Economy	6600.00
0005432604397	31714	Economy	7300.00
0005432604460	31714	Economy	7300.00
0005432604503	31714	Economy	7300.00
0005432604356	31714	Economy	6600.00
0005432604414	31714	Economy	6600.00
0005432604528	31714	Economy	6600.00
0005432604427	31714	Economy	6600.00
0005432604266	31714	Economy	6600.00
0005432604440	31714	Economy	6600.00
0005432604294	31714	Economy	6600.00
0005432604495	31714	Economy	6600.00
0005432604473	31714	Economy	6600.00
0005432604445	31714	Economy	6600.00
0005432604557	31714	Economy	6600.00
0005432604621	31714	Economy	6600.00
0005432604295	31714	Economy	6600.00
0005432604525	31714	Economy	6600.00
0005432604698	31714	Economy	6600.00
0005432604443	31714	Economy	6600.00
0005432604479	31714	Economy	6600.00
0005432604329	31714	Economy	6600.00
0005432604620	31714	Economy	6600.00
0005432604396	31714	Economy	6600.00
0005432604630	31714	Economy	6600.00
0005432604619	31714	Economy	6600.00
0005432604570	31714	Economy	6600.00
0005432604613	31714	Economy	6600.00
0005432604265	31714	Economy	6600.00
0005432604560	31714	Economy	6600.00
0005432604554	31714	Economy	6600.00
0005432604555	31714	Economy	6600.00
0005432604504	31714	Economy	6600.00
0005432604524	31714	Economy	6600.00
0005432604550	31714	Economy	6600.00
0005432604535	31714	Economy	6600.00
0005432604357	31714	Economy	6600.00
0005432604428	31714	Economy	6600.00
0005432604527	31714	Economy	6600.00
0005432604508	31714	Economy	6600.00
0005432604561	31714	Economy	6600.00
0005432604403	31714	Economy	6600.00
0005432604293	31714	Economy	6600.00
0005432604444	31714	Economy	6600.00
0005433293327	29591	Economy	19500.00
0005433293328	29591	Economy	17800.00
0005433293333	29591	Economy	17800.00
0005433293335	29591	Economy	17800.00
0005433293329	29591	Economy	17800.00
0005433293336	29591	Economy	17800.00
0005433293331	29591	Economy	17800.00
0005433293334	29591	Economy	17800.00
0005433293330	29591	Economy	17800.00
0005433293324	29591	Economy	17800.00
0005433293325	29591	Economy	17800.00
0005433293332	29591	Economy	17800.00
0005433293326	29591	Economy	17800.00
0005433473378	6685	Economy	14000.00
0005433473382	6685	Economy	14000.00
0005435257263	6685	Economy	12700.00
0005433473386	6685	Economy	12700.00
0005433473389	6685	Economy	12700.00
0005433473383	6685	Economy	12700.00
0005433473391	6685	Economy	12700.00
0005433473387	6685	Economy	12700.00
0005433473385	6685	Economy	12700.00
0005433473388	6685	Economy	12700.00
0005433473379	6685	Economy	12700.00
0005433473393	6685	Economy	12700.00
0005433473392	6685	Economy	12700.00
0005433473390	6685	Economy	12700.00
0005433473384	6685	Economy	12700.00
0005435257246	6685	Economy	12700.00
0005433473394	6685	Economy	12700.00
0005435257279	6685	Economy	12700.00
0005433473377	6685	Economy	12700.00
0005435257255	6685	Economy	12700.00
0005433473380	6685	Economy	12700.00
0005433473381	6685	Economy	12700.00
0005435257247	6685	Economy	12700.00
0005433473293	23883	Economy	14000.00
0005435257300	23883	Economy	14000.00
0005433473297	23883	Economy	14000.00
0005433473261	23883	Economy	14000.00
0005433473277	23883	Economy	12700.00
0005433473258	23883	Economy	12700.00
0005433473262	23883	Economy	12700.00
0005433473286	23883	Economy	12700.00
0005433473259	23883	Economy	12700.00
0005435257306	23883	Economy	12700.00
0005435257298	23883	Economy	12700.00
0005433473301	23883	Economy	12700.00
0005433473298	23883	Economy	12700.00
0005433473308	23883	Economy	12700.00
0005435257305	23883	Economy	12700.00
0005433473287	23883	Economy	12700.00
0005433473263	23883	Economy	12700.00
0005433473279	23883	Economy	12700.00
0005433473288	23883	Economy	12700.00
0005433473320	23883	Economy	12700.00
0005433473317	23883	Economy	12700.00
0005433473257	23883	Economy	12700.00
0005433473242	23883	Economy	12700.00
0005435257302	23883	Economy	12700.00
0005433473282	23883	Economy	12700.00
0005433473285	23883	Economy	12700.00
0005433473336	23883	Economy	12700.00
0005433473281	23883	Economy	12700.00
0005433473307	23883	Economy	12700.00
0005433473309	23883	Economy	12700.00
0005433473274	23883	Economy	12700.00
0005433473302	23883	Economy	12700.00
0005433473275	23883	Economy	12700.00
0005433473292	23883	Economy	12700.00
0005433473289	23883	Economy	12700.00
0005433473280	23883	Economy	12700.00
0005433473278	23883	Economy	12700.00
0005435257297	23883	Economy	12700.00
0005435257299	23883	Economy	12700.00
0005433473299	23883	Economy	12700.00
0005435257304	23883	Economy	12700.00
0005433473324	23883	Economy	12700.00
0005433473318	23883	Economy	12700.00
0005433473296	23883	Economy	12700.00
0005433473335	23883	Economy	12700.00
0005433473283	23883	Economy	12700.00
0005435257301	23883	Economy	12700.00
0005435257303	23883	Economy	12700.00
0005433473284	23883	Economy	12700.00
0005433473254	23883	Economy	12700.00
0005434606838	18841	Economy	6600.00
0005434606830	18841	Economy	6600.00
0005434604941	22361	Economy	6600.00
0005434606873	22361	Economy	6600.00
0005434604943	22361	Economy	6600.00
0005434604939	22361	Economy	6600.00
0005434604942	22361	Economy	6600.00
0005434606872	22361	Economy	6600.00
0005434604940	22361	Economy	6600.00
0005434606871	22361	Economy	6600.00
0005434602929	3839	Economy	24900.00
0005434522492	3839	Economy	22600.00
0005434522497	3839	Economy	22600.00
0005434522496	3839	Economy	22600.00
0005434522491	3839	Economy	22600.00
0005434522494	3839	Economy	22600.00
0005434522495	3839	Economy	22600.00
0005434602933	3839	Economy	22600.00
0005434602932	3839	Economy	22600.00
0005434602930	3839	Economy	22600.00
0005434602931	3839	Economy	22600.00
0005435904416	3839	Economy	22600.00
0005434522493	3839	Economy	22600.00
0005435904411	3839	Economy	22600.00
0005434522489	3839	Economy	22600.00
0005434522490	3839	Economy	22600.00
0005435904409	3839	Economy	22600.00
0005434522498	3839	Economy	22600.00
0005435904415	3839	Economy	22600.00
0005435904440	19061	Economy	24900.00
0005434522446	19061	Economy	24900.00
0005434522455	19061	Economy	24900.00
0005434522462	19061	Economy	22600.00
0005434604892	19061	Economy	22600.00
0005434522473	19061	Economy	22600.00
0005434602896	19061	Economy	22600.00
0005434522463	19061	Economy	22600.00
0005435904433	19061	Economy	22600.00
0005434522467	19061	Economy	22600.00
0005434522464	19061	Economy	22600.00
0005435904434	19061	Economy	22600.00
0005434604899	19061	Economy	22600.00
0005434604907	19061	Economy	22600.00
0005434522449	19061	Economy	22600.00
0005434522470	19061	Economy	22600.00
0005434602907	19061	Economy	22600.00
0005434522445	19061	Economy	22600.00
0005434602908	19061	Economy	22600.00
0005434604897	19061	Economy	22600.00
0005434604902	19061	Economy	22600.00
0005435904441	19061	Economy	22600.00
0005434522453	19061	Economy	22600.00
0005434522469	19061	Economy	22600.00
0005435904435	19061	Economy	22600.00
0005435904438	19061	Economy	22600.00
0005434522452	19061	Economy	22600.00
0005434522450	19061	Economy	22600.00
0005434602900	19061	Economy	22600.00
0005434602909	19061	Economy	22600.00
0005434522454	19061	Economy	22600.00
0005434522468	19061	Economy	22600.00
0005434604906	19061	Economy	22600.00
0005435904437	19061	Economy	22600.00
0005434604908	19061	Economy	22600.00
0005435904439	19061	Economy	22600.00
0005435904436	19061	Economy	22600.00
0005434522457	19061	Economy	22600.00
0005434604901	19061	Economy	22600.00
0005434602910	19061	Economy	22600.00
0005434522472	19061	Economy	22600.00
0005433875379	383	Business	44500.00
0005432753341	383	Business	44500.00
0005432748063	383	Business	44500.00
0005432891117	383	Business	44500.00
0005432748066	383	Business	44500.00
0005432220058	383	Business	44500.00
0005432891063	383	Business	44500.00
0005432748058	383	Business	44500.00
0005432748085	383	Business	44500.00
0005432748055	383	Business	44500.00
0005432890997	383	Business	44500.00
0005433293255	383	Economy	14800.00
0005433875383	383	Economy	14800.00
0005432748079	383	Economy	14800.00
0005432891109	383	Economy	14800.00
0005433875380	383	Economy	14800.00
0005432749814	383	Economy	14800.00
0005432753342	383	Economy	14800.00
0005432753343	383	Economy	14800.00
0005433875384	383	Economy	14800.00
0005432748074	383	Economy	16300.00
0005432748073	383	Economy	16300.00
0005433875381	383	Economy	16300.00
0005432748049	383	Economy	16300.00
0005432748061	383	Economy	14800.00
0005432891048	383	Economy	14800.00
0005432748070	383	Economy	14800.00
0005433293278	383	Economy	14800.00
0005432891126	383	Economy	14800.00
0005432891110	383	Economy	14800.00
0005432748057	383	Economy	14800.00
0005432748052	383	Economy	14800.00
0005433293254	383	Economy	14800.00
0005432748080	383	Economy	14800.00
0005432220059	383	Economy	14800.00
0005432748060	383	Economy	14800.00
0005433293279	383	Economy	14800.00
0005432891101	383	Economy	14800.00
0005433293287	383	Economy	14800.00
0005433875382	383	Economy	14800.00
0005432751569	383	Economy	14800.00
0005433293295	383	Economy	14800.00
0005432748081	383	Economy	14800.00
0005433293296	383	Economy	14800.00
0005432748067	383	Economy	14800.00
0005432748050	383	Economy	14800.00
0005432748062	383	Economy	14800.00
0005432748065	383	Economy	14800.00
0005433293280	383	Economy	14800.00
0005432748051	383	Economy	14800.00
0005432748053	383	Economy	14800.00
0005432748064	383	Economy	14800.00
0005432748075	383	Economy	14800.00
0005432748068	383	Economy	14800.00
0005432749813	383	Economy	14800.00
0005432748077	383	Economy	14800.00
0005432748084	383	Economy	14800.00
0005433875378	383	Economy	14800.00
0005432748059	383	Economy	14800.00
0005432891125	383	Economy	14800.00
0005432753344	383	Economy	14800.00
0005432748086	383	Economy	14800.00
0005432749812	383	Economy	14800.00
0005432220060	383	Economy	14800.00
0005432891203	383	Economy	14800.00
0005432748076	383	Economy	14800.00
0005432748056	383	Economy	14800.00
0005432748078	383	Economy	14800.00
0005433875387	383	Economy	14800.00
0005432748083	383	Economy	14800.00
0005432891062	383	Economy	14800.00
0005432751567	383	Economy	14800.00
0005432748071	383	Economy	14800.00
0005432748054	383	Economy	14800.00
0005432748048	383	Economy	14800.00
0005432891047	383	Economy	14800.00
0005432751568	383	Economy	14800.00
0005432748082	383	Economy	14800.00
0005432748069	383	Economy	14800.00
0005432753345	383	Economy	14800.00
0005433293288	383	Economy	14800.00
0005432748072	383	Economy	14800.00
0005432749811	383	Economy	14800.00
0005432891157	383	Economy	14800.00
0005432891119	383	Economy	14800.00
0005432214833	12046	Business	44500.00
0005435627120	12046	Business	44500.00
0005432747737	12046	Business	44500.00
0005433875399	12046	Business	44500.00
0005433875398	12046	Business	44500.00
0005432747747	12046	Business	44500.00
0005432756835	12046	Economy	14800.00
0005432891287	12046	Economy	14800.00
0005432747880	12046	Economy	14800.00
0005432747687	12046	Economy	14800.00
0005432747818	12046	Economy	16300.00
0005432749802	12046	Economy	16300.00
0005432891274	12046	Economy	14800.00
0005432747675	12046	Economy	14800.00
0005432756863	12046	Economy	14800.00
0005432747793	12046	Economy	14800.00
0005432747766	12046	Economy	14800.00
0005432891282	12046	Economy	14800.00
0005432747826	12046	Economy	14800.00
0005432747626	12046	Economy	14800.00
0005432747879	12046	Economy	14800.00
0005432891289	12046	Economy	14800.00
0005432214834	12046	Economy	14800.00
0005432747616	12046	Economy	14800.00
0005432747688	12046	Economy	14800.00
0005432747794	12046	Economy	14800.00
0005432747714	12046	Economy	14800.00
0005432747612	12046	Economy	14800.00
0005432747730	12046	Economy	14800.00
0005432891277	12046	Economy	14800.00
0005432747767	12046	Economy	14800.00
0005432747904	12046	Economy	14800.00
0005432891281	12046	Economy	14800.00
0005432756868	12046	Economy	14800.00
0005432891276	12046	Economy	14800.00
0005432756848	12046	Economy	14800.00
0005432747816	12046	Economy	14800.00
0005432891285	12046	Economy	14800.00
0005432891288	12046	Economy	14800.00
0005432891279	12046	Economy	14800.00
0005432891286	12046	Economy	14800.00
0005432214831	12046	Economy	14800.00
0005432891272	12046	Economy	14800.00
0005432747738	12046	Economy	14800.00
0005432747613	12046	Economy	14800.00
0005432891270	12046	Economy	14800.00
0005432891280	12046	Economy	14800.00
0005432747795	12046	Economy	14800.00
0005432747791	12046	Economy	14800.00
0005435627119	12046	Economy	14800.00
0005432747674	12046	Economy	14800.00
0005432891278	12046	Economy	14800.00
0005432891271	12046	Economy	14800.00
0005432747817	12046	Economy	14800.00
0005432891284	12046	Economy	14800.00
0005432747907	12046	Economy	14800.00
0005432214832	12046	Economy	14800.00
0005432891283	12046	Economy	14800.00
0005432891275	12046	Economy	14800.00
0005432747814	12046	Economy	14800.00
0005432891273	12046	Economy	14800.00
0005433533355	18958	Economy	28200.00
0005433525174	18958	Economy	28200.00
0005433533354	18958	Economy	25700.00
0005433525180	18958	Economy	25700.00
0005433531339	18958	Economy	25700.00
0005433525178	18958	Economy	25700.00
0005433525177	18958	Economy	25700.00
0005432928008	18958	Economy	25700.00
0005433525172	18958	Economy	25700.00
0005432928007	18958	Economy	25700.00
0005433525176	18958	Economy	25700.00
0005433533356	18958	Economy	25700.00
0005433525169	18958	Economy	25700.00
0005433525179	18958	Economy	25700.00
0005433531338	18958	Economy	25700.00
0005433525173	18958	Economy	25700.00
0005433531341	18958	Economy	25700.00
0005433531340	18958	Economy	25700.00
0005432928022	18958	Economy	25700.00
0005433525175	18958	Economy	25700.00
0005433525170	18958	Economy	25700.00
0005433525171	18958	Economy	25700.00
0005433525181	18958	Economy	25700.00
0005432927984	18958	Economy	25700.00
0005433525146	32475	Economy	28200.00
0005432928057	32475	Economy	28200.00
0005433525075	32475	Economy	25700.00
0005433527281	32475	Economy	25700.00
0005433525125	32475	Economy	25700.00
0005432928059	32475	Economy	25700.00
0005433531317	32475	Economy	25700.00
0005433527292	32475	Economy	25700.00
0005433527280	32475	Economy	25700.00
0005432928062	32475	Economy	25700.00
0005432928060	32475	Economy	25700.00
0005433527279	32475	Economy	25700.00
0005433525095	32475	Economy	25700.00
0005433525086	32475	Economy	25700.00
0005433531316	32475	Economy	25700.00
0005433525094	32475	Economy	25700.00
0005433525102	32475	Economy	25700.00
0005432928058	32475	Economy	25700.00
0005433525124	32475	Economy	25700.00
0005433525065	32475	Economy	25700.00
0005433525123	32475	Economy	25700.00
0005432928061	32475	Economy	25700.00
0005433525122	32475	Economy	25700.00
0005433525039	32475	Economy	25700.00
0005433527278	32475	Economy	25700.00
0005433525064	32475	Economy	25700.00
0005435373730	5300	Business	84000.00
0005434825256	5300	Business	84000.00
0005434825336	5300	Business	84000.00
0005435373858	5300	Business	84000.00
0005434825274	5300	Business	84000.00
0005434825228	5300	Business	84000.00
0005434825297	5300	Business	84000.00
0005434825258	5300	Business	84000.00
0005434825303	5300	Business	84000.00
0005434825326	5300	Business	84000.00
0005435373888	5300	Business	84000.00
0005434831211	5300	Business	84000.00
0005432396299	5300	Business	84000.00
0005434825313	5300	Business	84000.00
0005432396297	5300	Business	84000.00
0005434825208	5300	Business	84000.00
0005434825292	5300	Business	84000.00
0005434825257	5300	Business	84000.00
0005435373448	5300	Business	84000.00
0005434558389	5300	Business	84000.00
0005434825254	5300	Comfort	47600.00
0005432121523	5300	Comfort	47600.00
0005434825281	5300	Comfort	47600.00
0005435373719	5300	Comfort	47600.00
0005434825314	5300	Comfort	47600.00
0005434825278	5300	Comfort	47600.00
0005434825269	5300	Comfort	47600.00
0005434558396	5300	Comfort	47600.00
0005432396295	5300	Comfort	47600.00
0005434825317	5300	Comfort	47600.00
0005435150213	5300	Comfort	47600.00
0005435373889	5300	Comfort	47600.00
0005434825299	5300	Comfort	47600.00
0005434825311	5300	Comfort	47600.00
0005434825300	5300	Comfort	47600.00
0005434558395	5300	Comfort	47600.00
0005435150217	5300	Comfort	47600.00
0005435373525	5300	Comfort	47600.00
0005432121524	5300	Comfort	47600.00
0005434825277	5300	Comfort	47600.00
0005434825287	5300	Comfort	47600.00
0005435373306	5300	Comfort	47600.00
0005432394159	5300	Comfort	47600.00
0005434825289	5300	Comfort	47600.00
0005434828732	5300	Comfort	47600.00
0005434825224	5300	Comfort	47600.00
0005434825308	5300	Comfort	47600.00
0005434558385	5300	Comfort	47600.00
0005435373293	5300	Comfort	47600.00
0005434825245	5300	Comfort	47600.00
0005432121519	5300	Comfort	47600.00
0005434825233	5300	Economy	28000.00
0005434825238	5300	Economy	28000.00
0005435373497	5300	Economy	28000.00
0005434825237	5300	Economy	28000.00
0005435373762	5300	Economy	28000.00
0005434825263	5300	Economy	28000.00
0005434825306	5300	Economy	28000.00
0005434825218	5300	Economy	28000.00
0005434825329	5300	Economy	28000.00
0005434825291	5300	Economy	28000.00
0005435150211	5300	Economy	28000.00
0005432394156	5300	Economy	28000.00
0005435150215	5300	Economy	28000.00
0005434825259	5300	Economy	28000.00
0005434825284	5300	Economy	28000.00
0005435150209	5300	Economy	28000.00
0005434825267	5300	Economy	28000.00
0005435299802	5300	Economy	28000.00
0005434664989	5300	Economy	28000.00
0005435373603	5300	Economy	28000.00
0005434825283	5300	Economy	28000.00
0005435150220	5300	Economy	28000.00
0005434825332	5300	Economy	28000.00
0005434825211	5300	Economy	28000.00
0005434825325	5300	Economy	28000.00
0005434825243	5300	Economy	28000.00
0005434825323	5300	Economy	28000.00
0005434825246	5300	Economy	28000.00
0005434825270	5300	Economy	28000.00
0005435373761	5300	Economy	28000.00
0005434825296	5300	Economy	28000.00
0005434825221	5300	Economy	28000.00
0005434825276	5300	Economy	28000.00
0005434825225	5300	Economy	28000.00
0005434825216	5300	Economy	28000.00
0005435150207	5300	Economy	28000.00
0005434825253	5300	Economy	28000.00
0005434825236	5300	Economy	28000.00
0005435304174	5300	Economy	28000.00
0005432121522	5300	Economy	28000.00
0005432121517	5300	Economy	28000.00
0005434825321	5300	Economy	28000.00
0005435373574	5300	Economy	28000.00
0005434825293	5300	Economy	28000.00
0005434825288	5300	Economy	28000.00
0005434825242	5300	Economy	28000.00
0005434825248	5300	Economy	28000.00
0005435373579	5300	Economy	28000.00
0005435735143	5300	Economy	28000.00
0005434825279	5300	Economy	28000.00
0005435373379	5300	Economy	30800.00
0005435373434	5300	Economy	28000.00
0005434825207	5300	Economy	30800.00
0005434558393	5300	Economy	28000.00
0005435299788	5300	Economy	28000.00
0005434825241	5300	Economy	30800.00
0005434825230	5300	Economy	30800.00
0005434825210	5300	Economy	30800.00
0005435373735	5300	Economy	28000.00
0005435178996	5300	Economy	28000.00
0005435386609	5300	Economy	28000.00
0005435373609	5300	Economy	28000.00
0005434825333	5300	Economy	28000.00
0005434825240	5300	Economy	28000.00
0005434825213	5300	Economy	28000.00
0005434825260	5300	Economy	28000.00
0005434825305	5300	Economy	28000.00
0005434558397	5300	Economy	28000.00
0005434825252	5300	Economy	28000.00
0005434825331	5300	Economy	28000.00
0005434825334	5300	Economy	28000.00
0005434825295	5300	Economy	28000.00
0005435150210	5300	Economy	28000.00
0005434825294	5300	Economy	28000.00
0005435373679	5300	Economy	28000.00
0005434825304	5300	Economy	28000.00
0005434825255	5300	Economy	28000.00
0005434825212	5300	Economy	28000.00
0005435373723	5300	Economy	28000.00
0005435373536	5300	Economy	28000.00
0005435373380	5300	Economy	28000.00
0005434825214	5300	Economy	28000.00
0005434828733	5300	Economy	28000.00
0005435150219	5300	Economy	28000.00
0005434825264	5300	Economy	28000.00
0005435373414	5300	Economy	28000.00
0005434825316	5300	Economy	28000.00
0005435735162	5300	Economy	28000.00
0005434825251	5300	Economy	28000.00
0005434825315	5300	Economy	28000.00
0005435373647	5300	Economy	28000.00
0005434825235	5300	Economy	28000.00
0005434825309	5300	Economy	28000.00
0005434825249	5300	Economy	28000.00
0005434825266	5300	Economy	28000.00
0005432121526	5300	Economy	28000.00
0005434825217	5300	Economy	28000.00
0005435373535	5300	Economy	28000.00
0005432396300	5300	Economy	28000.00
0005435386596	5300	Economy	28000.00
0005432121527	5300	Economy	28000.00
0005434558388	5300	Economy	28000.00
0005432121525	5300	Economy	28000.00
0005435386595	5300	Economy	28000.00
0005432396298	5300	Economy	28000.00
0005434558384	5300	Economy	28000.00
0005435150218	5300	Economy	28000.00
0005434828731	5300	Economy	28000.00
0005434825275	5300	Economy	28000.00
0005434825234	5300	Economy	28000.00
0005434825250	5300	Economy	28000.00
0005434825223	5300	Economy	28000.00
0005435373859	5300	Economy	28000.00
0005434825272	5300	Economy	28000.00
0005432121528	5300	Economy	28000.00
0005434825319	5300	Economy	28000.00
0005432121529	5300	Economy	28000.00
0005435304191	5300	Economy	28000.00
0005432396296	5300	Economy	28000.00
0005432121520	5300	Economy	28000.00
0005434558387	5300	Economy	28000.00
0005434825227	5300	Economy	28000.00
0005432394157	5300	Economy	28000.00
0005435373578	5300	Economy	28000.00
0005434825318	5300	Economy	28000.00
0005435150221	5300	Economy	28000.00
0005434825229	5300	Economy	28000.00
0005435373334	5300	Economy	28000.00
0005435373526	5300	Economy	28000.00
0005435386597	5300	Economy	28000.00
0005434825265	5300	Economy	28000.00
0005434825273	5300	Economy	28000.00
0005434825290	5300	Economy	28000.00
0005435373626	5300	Economy	30800.00
0005434825244	5300	Economy	30800.00
0005434825337	5300	Economy	30800.00
0005434825271	5300	Economy	28000.00
0005435735142	5300	Economy	28000.00
0005432121521	5300	Economy	28000.00
0005435373791	5300	Economy	28000.00
0005434825262	5300	Economy	28000.00
0005434825322	5300	Economy	28000.00
0005434831208	5300	Economy	28000.00
0005434825330	5300	Economy	28000.00
0005434558398	5300	Economy	28000.00
0005434558391	5300	Economy	28000.00
0005432121516	5300	Economy	28000.00
0005435373792	5300	Economy	28000.00
0005434825261	5300	Economy	28000.00
0005435150214	5300	Economy	28000.00
0005432121515	5300	Economy	28000.00
0005435373575	5300	Economy	28000.00
0005435373725	5300	Economy	28000.00
0005434825222	5300	Economy	28000.00
0005435150216	5300	Economy	28000.00
0005434825209	5300	Economy	28000.00
0005435373360	5300	Economy	28000.00
0005434831210	5300	Economy	28000.00
0005434825301	5300	Economy	28000.00
0005434825324	5300	Economy	28000.00
0005435373565	5300	Economy	28000.00
0005435304175	5300	Economy	28000.00
0005434825285	5300	Economy	28000.00
0005434825312	5300	Economy	28000.00
0005434825247	5300	Economy	28000.00
0005434825298	5300	Economy	28000.00
0005434825335	5300	Economy	28000.00
0005435373498	5300	Economy	28000.00
0005434558392	5300	Economy	28000.00
0005434825320	5300	Economy	28000.00
0005434825302	5300	Economy	28000.00
0005434558394	5300	Economy	28000.00
0005435373729	5300	Economy	28000.00
0005434825239	5300	Economy	28000.00
0005434825268	5300	Economy	28000.00
0005434825231	5300	Economy	28000.00
0005434831209	5300	Economy	28000.00
0005435373594	5300	Economy	28000.00
0005435150212	5300	Economy	28000.00
0005435373381	5300	Economy	28000.00
0005434825232	5300	Economy	28000.00
0005434558386	5300	Economy	28000.00
0005434825282	5300	Economy	28000.00
0005434825280	5300	Economy	28000.00
0005435150208	5300	Economy	28000.00
0005432394158	5300	Economy	28000.00
0005434825226	5300	Economy	28000.00
0005434825220	5300	Economy	28000.00
0005435373292	5300	Economy	28000.00
0005435373495	5300	Economy	28000.00
0005434825286	5300	Economy	28000.00
0005434825328	5300	Economy	28000.00
0005434825327	5300	Economy	28000.00
0005435373676	5300	Economy	28000.00
0005435373279	5300	Economy	28000.00
0005434825215	5300	Economy	28000.00
0005435373328	5300	Economy	28000.00
0005434558390	5300	Economy	28000.00
0005435386575	5300	Economy	28000.00
0005434831207	5300	Economy	28000.00
0005435373680	5300	Economy	28000.00
0005435373668	5300	Economy	28000.00
0005434825307	5300	Economy	28000.00
0005435373545	5300	Economy	28000.00
0005434825310	5300	Economy	28000.00
0005435373785	5300	Economy	28000.00
0005435373546	5300	Economy	28000.00
0005434825219	5300	Economy	28000.00
0005432121518	5300	Economy	28000.00
0005435374138	9939	Business	84000.00
0005434824794	9939	Business	84000.00
0005435150030	9939	Business	84000.00
0005435374125	9939	Business	84000.00
0005435374150	9939	Business	84000.00
0005434824267	9939	Business	84000.00
0005432823479	9939	Business	84000.00
0005435150105	9939	Business	84000.00
0005432203158	9939	Business	84000.00
0005434823367	9939	Business	84000.00
0005434823369	9939	Business	84000.00
0005434824322	9939	Business	84000.00
0005435374155	9939	Business	84000.00
0005434824101	9939	Business	84000.00
0005434823855	9939	Business	84000.00
0005435299842	9939	Business	84000.00
0005435374110	9939	Comfort	47600.00
0005434824219	9939	Comfort	47600.00
0005435374107	9939	Comfort	47600.00
0005435374100	9939	Comfort	47600.00
0005434824212	9939	Comfort	47600.00
0005435374121	9939	Comfort	47600.00
0005435374116	9939	Comfort	47600.00
0005434824418	9939	Comfort	47600.00
0005435150063	9939	Comfort	47600.00
0005435374104	9939	Comfort	47600.00
0005434558296	9939	Comfort	47600.00
0005434824275	9939	Comfort	47600.00
0005434824023	9939	Comfort	47600.00
0005434824272	9939	Comfort	47600.00
0005434824045	9939	Comfort	47600.00
0005435150066	9939	Comfort	47600.00
0005434824407	9939	Comfort	47600.00
0005434824456	9939	Comfort	47600.00
0005434824409	9939	Comfort	47600.00
0005435374117	9939	Comfort	47600.00
0005434831191	9939	Comfort	47600.00
0005434824510	9939	Comfort	47600.00
0005434824105	9939	Comfort	47600.00
0005435150041	9939	Comfort	47600.00
0005434824595	9939	Comfort	47600.00
0005435374113	9939	Comfort	47600.00
0005435374151	9939	Comfort	47600.00
0005434823779	9939	Comfort	47600.00
0005434824321	9939	Comfort	47600.00
0005434824157	9939	Comfort	47600.00
0005435386658	9939	Comfort	47600.00
0005434831176	9939	Comfort	47600.00
0005434823919	9939	Comfort	47600.00
0005434824073	9939	Comfort	47600.00
0005434824488	9939	Comfort	47600.00
0005434824198	9939	Comfort	47600.00
0005434823940	9939	Comfort	47600.00
0005434823856	9939	Economy	28000.00
0005434824085	9939	Economy	28000.00
0005434823727	9939	Economy	28000.00
0005434824452	9939	Economy	28000.00
0005435374098	9939	Economy	28000.00
0005434824534	9939	Economy	28000.00
0005434824660	9939	Economy	28000.00
0005434823996	9939	Economy	28000.00
0005434824106	9939	Economy	28000.00
0005434824642	9939	Economy	28000.00
0005434831178	9939	Economy	28000.00
0005435374106	9939	Economy	28000.00
0005434824553	9939	Economy	28000.00
0005435299841	9939	Economy	28000.00
0005435386655	9939	Economy	28000.00
0005434664965	9939	Economy	28000.00
0005434831175	9939	Economy	28000.00
0005435299840	9939	Economy	28000.00
0005435302263	9939	Economy	28000.00
0005435150126	9939	Economy	28000.00
0005435386651	9939	Economy	28000.00
0005434824154	9939	Economy	28000.00
0005435386654	9939	Economy	28000.00
0005435661970	9939	Economy	28000.00
0005434824155	9939	Economy	28000.00
0005434824368	9939	Economy	28000.00
0005434824049	9939	Economy	28000.00
0005432203160	9939	Economy	28000.00
0005434824033	9939	Economy	28000.00
0005434823706	9939	Economy	28000.00
0005435374126	9939	Economy	28000.00
0005434824169	9939	Economy	28000.00
0005434823689	9939	Economy	28000.00
0005434823567	9939	Economy	28000.00
0005434824333	9939	Economy	28000.00
0005434824102	9939	Economy	28000.00
0005435302261	9939	Economy	28000.00
0005435374159	9939	Economy	28000.00
0005434824624	9939	Economy	28000.00
0005432400150	9939	Economy	28000.00
0005434824277	9939	Economy	30800.00
0005435374146	9939	Economy	28000.00
0005434824593	9939	Economy	28000.00
0005434664962	9939	Economy	30800.00
0005435386657	9939	Economy	30800.00
0005434823726	9939	Economy	28000.00
0005434823910	9939	Economy	28000.00
0005434823921	9939	Economy	28000.00
0005432203161	9939	Economy	28000.00
0005434824592	9939	Economy	28000.00
0005434824197	9939	Economy	28000.00
0005434824509	9939	Economy	28000.00
0005435302260	9939	Economy	28000.00
0005434824227	9939	Economy	28000.00
0005432400139	9939	Economy	28000.00
0005434824268	9939	Economy	28000.00
0005434824449	9939	Economy	28000.00
0005434824596	9939	Economy	28000.00
0005435374149	9939	Economy	28000.00
0005435179406	9939	Economy	28000.00
0005434823847	9939	Economy	28000.00
0005435374119	9939	Economy	28000.00
0005435374148	9939	Economy	28000.00
0005435735199	9939	Economy	28000.00
0005435374120	9939	Economy	28000.00
0005435735198	9939	Economy	28000.00
0005435374137	9939	Economy	28000.00
0005432400151	9939	Economy	28000.00
0005434664961	9939	Economy	28000.00
0005435374130	9939	Economy	28000.00
0005435150067	9939	Economy	28000.00
0005435374156	9939	Economy	28000.00
0005435374127	9939	Economy	28000.00
0005432203162	9939	Economy	28000.00
0005435150143	9939	Economy	28000.00
0005434824310	9939	Economy	28000.00
0005434664960	9939	Economy	28000.00
0005432203159	9939	Economy	28000.00
0005434824382	9939	Economy	28000.00
0005435374152	9939	Economy	28000.00
0005434824408	9939	Economy	28000.00
0005435374153	9939	Economy	28000.00
0005435374132	9939	Economy	28000.00
0005435374123	9939	Economy	28000.00
0005435374141	9939	Economy	28000.00
0005435735200	9939	Economy	28000.00
0005435374111	9939	Economy	28000.00
0005434823650	9939	Economy	28000.00
0005434824468	9939	Economy	28000.00
0005432823477	9939	Economy	28000.00
0005432396261	9939	Economy	28000.00
0005432396252	9939	Economy	28000.00
0005435374143	9939	Economy	28000.00
0005434824255	9939	Economy	28000.00
0005434824552	9939	Economy	28000.00
0005432400133	9939	Economy	28000.00
0005435374144	9939	Economy	28000.00
0005434824084	9939	Economy	28000.00
0005432823476	9939	Economy	28000.00
0005434824766	9939	Economy	28000.00
0005435735202	9939	Economy	28000.00
0005435299839	9939	Economy	28000.00
0005435374109	9939	Economy	28000.00
0005435374105	9939	Economy	28000.00
0005434824793	9939	Economy	28000.00
0005435374160	9939	Economy	28000.00
0005434824179	9939	Economy	28000.00
0005434824112	9939	Economy	28000.00
0005435374114	9939	Economy	28000.00
0005435661971	9939	Economy	28000.00
0005435374133	9939	Economy	28000.00
0005432400138	9939	Economy	28000.00
0005434824364	9939	Economy	28000.00
0005435299838	9939	Economy	28000.00
0005434823166	9939	Economy	28000.00
0005434824759	9939	Economy	28000.00
0005435374112	9939	Economy	28000.00
0005434824256	9939	Economy	28000.00
0005434823960	9939	Economy	28000.00
0005435302264	9939	Economy	28000.00
0005435302259	9939	Economy	28000.00
0005435374099	9939	Economy	28000.00
0005435374158	9939	Economy	28000.00
0005434824427	9939	Economy	28000.00
0005434824069	9939	Economy	28000.00
0005434824203	9939	Economy	28000.00
0005434558314	9939	Economy	28000.00
0005435374139	9939	Economy	28000.00
0005435299837	9939	Economy	28000.00
0005434824052	9939	Economy	28000.00
0005435150055	9939	Economy	28000.00
0005435374145	9939	Economy	28000.00
0005432400152	9939	Economy	30800.00
0005432400134	9939	Economy	28000.00
0005434824419	9939	Economy	30800.00
0005434831170	9939	Economy	30800.00
0005434824428	9939	Economy	30800.00
0005434824252	9939	Economy	28000.00
0005434823857	9939	Economy	28000.00
0005435150064	9939	Economy	28000.00
0005435374124	9939	Economy	28000.00
0005434823790	9939	Economy	28000.00
0005434824100	9939	Economy	28000.00
0005434823707	9939	Economy	28000.00
0005434824189	9939	Economy	28000.00
0005435374147	9939	Economy	28000.00
0005432823478	9939	Economy	28000.00
0005434824309	9939	Economy	28000.00
0005435374131	9939	Economy	28000.00
0005435374103	9939	Economy	28000.00
0005434824138	9939	Economy	28000.00
0005435374140	9939	Economy	28000.00
0005435386652	9939	Economy	28000.00
0005434823965	9939	Economy	28000.00
0005434824025	9939	Economy	28000.00
0005435374118	9939	Economy	28000.00
0005434824017	9939	Economy	28000.00
0005434824489	9939	Economy	28000.00
0005434824024	9939	Economy	28000.00
0005434824090	9939	Economy	28000.00
0005434824026	9939	Economy	28000.00
0005434824141	9939	Economy	28000.00
0005434824046	9939	Economy	28000.00
0005434823690	9939	Economy	28000.00
0005435374115	9939	Economy	28000.00
0005434823884	9939	Economy	28000.00
0005434824111	9939	Economy	28000.00
0005434824344	9939	Economy	28000.00
0005432396268	9939	Economy	28000.00
0005434824533	9939	Economy	28000.00
0005434824742	9939	Economy	28000.00
0005434824019	9939	Economy	28000.00
0005432396253	9939	Economy	28000.00
0005434824314	9939	Economy	28000.00
0005435386653	9939	Economy	28000.00
0005434824767	9939	Economy	28000.00
0005434824142	9939	Economy	28000.00
0005435374136	9939	Economy	28000.00
0005434824218	9939	Economy	28000.00
0005435374129	9939	Economy	28000.00
0005434823854	9939	Economy	28000.00
0005434824311	9939	Economy	28000.00
0005432203157	9939	Economy	28000.00
0005435374161	9939	Economy	28000.00
0005435386656	9939	Economy	28000.00
0005434824380	9939	Economy	28000.00
0005434823867	9939	Economy	28000.00
0005435374101	9939	Economy	28000.00
0005435374154	9939	Economy	28000.00
0005435374108	9939	Economy	28000.00
0005434824381	9939	Economy	28000.00
0005435374157	9939	Economy	28000.00
0005434824137	9939	Economy	28000.00
0005435374128	9939	Economy	28000.00
0005435150104	9939	Economy	28000.00
0005435302262	9939	Economy	28000.00
0005435374134	9939	Economy	28000.00
0005435374122	9939	Economy	28000.00
0005434823165	9939	Economy	28000.00
0005435150103	9939	Economy	28000.00
0005434824276	9939	Economy	28000.00
0005435374135	9939	Economy	28000.00
0005435374102	9939	Economy	28000.00
0005434823920	9939	Economy	28000.00
0005434824263	9939	Economy	28000.00
0005435735201	9939	Economy	28000.00
0005435374142	9939	Economy	28000.00
0005434824824	9939	Economy	28000.00
0005435150040	9939	Economy	28000.00
0005434824741	9939	Economy	28000.00
0005434823368	9939	Economy	28000.00
0005435790345	7003	Economy	8200.00
0005435790344	7003	Economy	8200.00
0005435082893	7003	Economy	7400.00
0005435082895	7003	Economy	7400.00
0005435082897	7003	Economy	7400.00
0005435082894	7003	Economy	7400.00
0005435790346	7003	Economy	7400.00
0005435082896	7003	Economy	7400.00
0005435082892	7003	Economy	7400.00
0005435082785	25981	Economy	8200.00
0005435082809	25981	Economy	8200.00
0005435082807	25981	Economy	7400.00
0005435082828	25981	Economy	7400.00
0005435790313	25981	Economy	7400.00
0005435082827	25981	Economy	7400.00
0005435790321	25981	Economy	7400.00
0005435790322	25981	Economy	7400.00
0005435790314	25981	Economy	7400.00
0005435082804	25981	Economy	7400.00
0005435082805	25981	Economy	7400.00
0005435082829	25981	Economy	7400.00
0005434214584	9541	Business	32800.00
0005434214731	9541	Business	32800.00
0005434756981	9541	Business	32800.00
0005434756980	9541	Business	32800.00
0005434757004	9541	Business	32800.00
0005434757000	9541	Business	32800.00
0005434757003	9541	Business	32800.00
0005434756983	9541	Business	32800.00
0005434756974	9541	Business	32800.00
0005434214656	9541	Business	32800.00
0005434756966	9541	Business	32800.00
0005434756971	9541	Economy	10900.00
0005434756967	9541	Economy	10900.00
0005434756984	9541	Economy	10900.00
0005434214642	9541	Economy	10900.00
0005434756991	9541	Economy	10900.00
0005434214973	9541	Economy	10900.00
0005434214730	9541	Economy	10900.00
0005434214802	9541	Economy	10900.00
0005434214836	9541	Economy	10900.00
0005434214648	9541	Economy	12000.00
0005434214563	9541	Economy	12000.00
0005434756995	9541	Economy	10900.00
0005434756994	9541	Economy	10900.00
0005434214734	9541	Economy	10900.00
0005434757001	9541	Economy	10900.00
0005434214660	9541	Economy	10900.00
0005434214808	9541	Economy	10900.00
0005434214639	9541	Economy	10900.00
0005434756975	9541	Economy	10900.00
0005434756990	9541	Economy	10900.00
0005434756996	9541	Economy	10900.00
0005434756989	9541	Economy	10900.00
0005434214732	9541	Economy	10900.00
0005434214497	9541	Economy	10900.00
0005434756979	9541	Economy	10900.00
0005434756976	9541	Economy	10900.00
0005434214511	9541	Economy	10900.00
0005434757005	9541	Economy	10900.00
0005434214801	9541	Economy	10900.00
0005434214644	9541	Economy	10900.00
0005434214807	9541	Economy	10900.00
0005434756986	9541	Economy	10900.00
0005434214692	9541	Economy	10900.00
0005434756982	9541	Economy	10900.00
0005434756998	9541	Economy	10900.00
0005434756992	9541	Economy	10900.00
0005434214812	9541	Economy	10900.00
0005434214687	9541	Economy	10900.00
0005434214640	9541	Economy	10900.00
0005434756978	9541	Economy	10900.00
0005434756970	9541	Economy	10900.00
0005434214733	9541	Economy	10900.00
0005434214716	9541	Economy	10900.00
0005434214608	9541	Economy	10900.00
0005434214819	9541	Economy	10900.00
0005434214659	9541	Economy	10900.00
0005434756965	9541	Economy	10900.00
0005434756973	9541	Economy	10900.00
0005434214693	9541	Economy	10900.00
0005434757002	9541	Economy	10900.00
0005434756997	9541	Economy	10900.00
0005434214643	9541	Economy	10900.00
0005434214641	9541	Economy	10900.00
0005434756977	9541	Economy	10900.00
0005434214813	9541	Economy	10900.00
0005434756985	9541	Economy	10900.00
0005434214769	9541	Economy	10900.00
0005434214896	9541	Economy	10900.00
0005434756993	9541	Economy	10900.00
0005434756968	9541	Economy	10900.00
0005434214562	9541	Economy	10900.00
0005434756999	9541	Economy	10900.00
0005434214691	9541	Economy	10900.00
0005434214847	9541	Economy	10900.00
0005434756987	9541	Economy	10900.00
0005434756988	9541	Economy	10900.00
0005434214800	9541	Economy	10900.00
0005434214972	9541	Economy	10900.00
0005434214510	9541	Economy	10900.00
0005434214645	9541	Economy	10900.00
0005434214854	9541	Economy	10900.00
0005434214595	9541	Economy	10900.00
0005434756969	9541	Economy	10900.00
0005434757006	9541	Economy	10900.00
0005434214895	9541	Economy	10900.00
0005434214835	9541	Economy	10900.00
0005434756972	9541	Economy	10900.00
0005434215116	28617	Business	32800.00
0005434215121	28617	Business	32800.00
0005434215111	28617	Business	32800.00
0005434215082	28617	Business	32800.00
0005434215108	28617	Business	32800.00
0005434215087	28617	Business	32800.00
0005434215107	28617	Business	32800.00
0005434215079	28617	Business	32800.00
0005434215086	28617	Business	32800.00
0005434215093	28617	Business	32800.00
0005434215104	28617	Economy	10900.00
0005434215102	28617	Economy	10900.00
0005434215105	28617	Economy	10900.00
0005434756592	28617	Economy	10900.00
0005434215100	28617	Economy	10900.00
0005434215092	28617	Economy	10900.00
0005434756664	28617	Economy	10900.00
0005434215085	28617	Economy	10900.00
0005434215091	28617	Economy	12000.00
0005434215099	28617	Economy	12000.00
0005434756495	28617	Economy	12000.00
0005434756490	28617	Economy	12000.00
0005434756580	28617	Economy	10900.00
0005434215119	28617	Economy	10900.00
0005434215110	28617	Economy	10900.00
0005434215117	28617	Economy	10900.00
0005434215113	28617	Economy	10900.00
0005434215098	28617	Economy	10900.00
0005434756510	28617	Economy	10900.00
0005434215080	28617	Economy	10900.00
0005434756588	28617	Economy	10900.00
0005434756448	28617	Economy	10900.00
0005434215125	28617	Economy	10900.00
0005434756508	28617	Economy	10900.00
0005434215101	28617	Economy	10900.00
0005434215109	28617	Economy	10900.00
0005434756566	28617	Economy	10900.00
0005434215095	28617	Economy	10900.00
0005434756608	28617	Economy	10900.00
0005434215103	28617	Economy	10900.00
0005434215097	28617	Economy	10900.00
0005434756489	28617	Economy	10900.00
0005434215096	28617	Economy	10900.00
0005434756491	28617	Economy	10900.00
0005434215123	28617	Economy	10900.00
0005434215112	28617	Economy	10900.00
0005434215120	28617	Economy	10900.00
0005434756565	28617	Economy	10900.00
0005434756500	28617	Economy	10900.00
0005434756559	28617	Economy	10900.00
0005434215106	28617	Economy	10900.00
0005434756771	28617	Economy	10900.00
0005434215081	28617	Economy	10900.00
0005434756547	28617	Economy	10900.00
0005434756620	28617	Economy	10900.00
0005434215122	28617	Economy	10900.00
0005434756396	28617	Economy	10900.00
0005434756772	28617	Economy	10900.00
0005434756606	28617	Economy	10900.00
0005434215084	28617	Economy	10900.00
0005434756428	28617	Economy	10900.00
0005434756601	28617	Economy	10900.00
0005434215083	28617	Economy	10900.00
0005434215089	28617	Economy	10900.00
0005434756461	28617	Economy	10900.00
0005434756429	28617	Economy	10900.00
0005434215118	28617	Economy	10900.00
0005434215078	28617	Economy	10900.00
0005434756507	28617	Economy	10900.00
0005434215115	28617	Economy	10900.00
0005434756480	28617	Economy	10900.00
0005434215088	28617	Economy	10900.00
0005434756388	28617	Economy	10900.00
0005434756479	28617	Economy	10900.00
0005434756558	28617	Economy	10900.00
0005434756587	28617	Economy	10900.00
0005434215090	28617	Economy	10900.00
0005434215114	28617	Economy	10900.00
0005434215094	28617	Economy	10900.00
0005434215124	28617	Economy	10900.00
0005434756501	28617	Economy	10900.00
0005435100164	10826	Economy	9800.00
0005434760197	10826	Economy	8900.00
0005435100162	10826	Economy	8900.00
0005435100163	10826	Economy	8900.00
0005434760208	10826	Economy	8900.00
0005434760207	10826	Economy	8900.00
0005434760204	10826	Economy	8900.00
0005435100145	31843	Economy	8900.00
0005435100133	31843	Economy	8900.00
0005434760230	31843	Economy	8900.00
0005434760229	31843	Economy	8900.00
0005433202391	1987	Economy	20900.00
0005432290676	1987	Economy	20900.00
0005434639662	1987	Economy	20900.00
0005434639681	1987	Economy	20900.00
0005434639659	1987	Economy	19000.00
0005434639669	1987	Economy	19000.00
0005434639672	1987	Economy	19000.00
0005433202450	1987	Economy	19000.00
0005433202390	1987	Economy	19000.00
0005434639673	1987	Economy	19000.00
0005433202377	1987	Economy	19000.00
0005433202389	1987	Economy	19000.00
0005434639671	1987	Economy	19000.00
0005432290678	1987	Economy	19000.00
0005433202402	1987	Economy	19000.00
0005434639656	1987	Economy	19000.00
0005434639665	1987	Economy	19000.00
0005432290677	1987	Economy	19000.00
0005433202477	1987	Economy	19000.00
0005433202449	1987	Economy	19000.00
0005432290674	1987	Economy	19000.00
0005434639678	1987	Economy	19000.00
0005434639668	1987	Economy	19000.00
0005433202457	1987	Economy	19000.00
0005433202462	1987	Economy	19000.00
0005434639661	1987	Economy	19000.00
0005432290675	1987	Economy	19000.00
0005433202448	1987	Economy	19000.00
0005434639674	1987	Economy	19000.00
0005433202392	1987	Economy	19000.00
0005434639679	1987	Economy	19000.00
0005434639658	1987	Economy	19000.00
0005433202471	1987	Economy	19000.00
0005433202463	1987	Economy	19000.00
0005434639675	1987	Economy	19000.00
0005434639663	1987	Economy	19000.00
0005433202423	1987	Economy	19000.00
0005434639655	1987	Economy	19000.00
0005434639670	1987	Economy	19000.00
0005434639667	1987	Economy	19000.00
0005434639657	1987	Economy	19000.00
0005434639676	1987	Economy	19000.00
0005434639680	1987	Economy	19000.00
0005434639666	1987	Economy	19000.00
0005434639660	1987	Economy	19000.00
0005434639683	1987	Economy	19000.00
0005434639664	1987	Economy	19000.00
0005434639677	1987	Economy	19000.00
0005435948338	1987	Economy	19000.00
0005434639682	1987	Economy	19000.00
0005433202548	23268	Economy	20900.00
0005434639465	23268	Economy	20900.00
0005433202550	23268	Economy	19000.00
0005434639483	23268	Economy	19000.00
0005433202552	23268	Economy	19000.00
0005434639346	23268	Economy	19000.00
0005433202542	23268	Economy	19000.00
0005434639432	23268	Economy	19000.00
0005433202541	23268	Economy	19000.00
0005433202540	23268	Economy	19000.00
0005433202543	23268	Economy	19000.00
0005434639481	23268	Economy	19000.00
0005433202551	23268	Economy	19000.00
0005434639388	23268	Economy	19000.00
0005434639422	23268	Economy	19000.00
0005434639451	23268	Economy	19000.00
0005434639480	23268	Economy	19000.00
0005434639397	23268	Economy	19000.00
0005434639489	23268	Economy	19000.00
0005434639490	23268	Economy	19000.00
0005433202547	23268	Economy	19000.00
0005433202553	23268	Economy	19000.00
0005434639375	23268	Economy	19000.00
0005435948330	23268	Economy	19000.00
0005434639360	23268	Economy	19000.00
0005433202545	23268	Economy	19000.00
0005433202546	23268	Economy	19000.00
0005433202549	23268	Economy	19000.00
0005434639535	23268	Economy	19000.00
0005434639482	23268	Economy	19000.00
0005434639382	23268	Economy	19000.00
0005434639536	23268	Economy	19000.00
0005433202544	23268	Economy	19000.00
0005434639418	23268	Economy	19000.00
0005433533357	6072	Business	69700.00
0005434601169	6072	Business	69700.00
0005434601155	6072	Business	69700.00
0005433531345	6072	Business	69700.00
0005433531346	6072	Business	69700.00
0005434601162	6072	Business	69700.00
0005434601176	6072	Economy	23200.00
0005434601170	6072	Economy	23200.00
0005434601154	6072	Economy	23200.00
0005434601181	6072	Economy	23200.00
0005435326833	6072	Economy	23200.00
0005434601178	6072	Economy	23200.00
0005433531343	6072	Economy	23200.00
0005435326834	6072	Economy	25600.00
0005434601172	6072	Economy	23200.00
0005432111318	6072	Economy	23200.00
0005433533361	6072	Economy	23200.00
0005434601171	6072	Economy	23200.00
0005433533360	6072	Economy	23200.00
0005434601161	6072	Economy	23200.00
0005435326796	6072	Economy	23200.00
0005435326797	6072	Economy	23200.00
0005433533359	6072	Economy	23200.00
0005434601173	6072	Economy	23200.00
0005434601160	6072	Economy	23200.00
0005434601164	6072	Economy	23200.00
0005434601168	6072	Economy	23200.00
0005433531344	6072	Economy	23200.00
0005435326818	6072	Economy	23200.00
0005434601165	6072	Economy	23200.00
0005435326835	6072	Economy	23200.00
0005434601159	6072	Economy	23200.00
0005434601166	6072	Economy	23200.00
0005435326817	6072	Economy	23200.00
0005435326869	6072	Economy	23200.00
0005434601167	6072	Economy	23200.00
0005434601179	6072	Economy	23200.00
0005434601156	6072	Economy	23200.00
0005435326815	6072	Economy	23200.00
0005434601180	6072	Economy	23200.00
0005434601158	6072	Economy	23200.00
0005434601174	6072	Economy	23200.00
0005434601177	6072	Economy	23200.00
0005433533358	6072	Economy	23200.00
0005432111319	6072	Economy	23200.00
0005432111320	6072	Economy	23200.00
0005433531342	6072	Economy	23200.00
0005435326816	6072	Economy	23200.00
0005434601175	6072	Economy	23200.00
0005434601163	6072	Economy	23200.00
0005434601157	6072	Economy	23200.00
0005435326784	6072	Economy	23200.00
0005435326783	6072	Economy	23200.00
0005435326934	18613	Business	69700.00
0005434601014	18613	Business	69700.00
0005434601005	18613	Business	69700.00
0005434600926	18613	Business	69700.00
0005434600801	18613	Business	69700.00
0005433531306	18613	Business	69700.00
0005434600927	18613	Business	69700.00
0005435326929	18613	Economy	23200.00
0005434600817	18613	Economy	23200.00
0005434600851	18613	Economy	23200.00
0005433527261	18613	Economy	23200.00
0005435326933	18613	Economy	25600.00
0005434600818	18613	Economy	25600.00
0005435326928	18613	Economy	25600.00
0005435326936	18613	Economy	23200.00
0005435326924	18613	Economy	23200.00
0005433531304	18613	Economy	23200.00
0005434600825	18613	Economy	23200.00
0005433527262	18613	Economy	23200.00
0005434600931	18613	Economy	23200.00
0005435326931	18613	Economy	23200.00
0005435326925	18613	Economy	23200.00
0005435326926	18613	Economy	23200.00
0005434600857	18613	Economy	23200.00
0005434600948	18613	Economy	23200.00
0005434600881	18613	Economy	23200.00
0005434600932	18613	Economy	23200.00
0005433531292	18613	Economy	23200.00
0005434601082	18613	Economy	23200.00
0005435326937	18613	Economy	23200.00
0005433531308	18613	Economy	23200.00
0005435326932	18613	Economy	23200.00
0005434600819	18613	Economy	23200.00
0005435326930	18613	Economy	23200.00
0005434601004	18613	Economy	23200.00
0005434600925	18613	Economy	23200.00
0005434600882	18613	Economy	23200.00
0005435326927	18613	Economy	23200.00
0005434600870	18613	Economy	23200.00
0005434600956	18613	Economy	23200.00
0005434600991	18613	Economy	23200.00
0005434600864	18613	Economy	23200.00
0005435326935	18613	Economy	23200.00
0005435326922	18613	Economy	23200.00
0005435326923	18613	Economy	23200.00
0005434600974	18613	Economy	23200.00
0005434600929	18613	Economy	23200.00
0005434551927	10652	Business	9100.00
0005434551910	10652	Business	9100.00
0005434551907	10652	Business	9100.00
0005434551897	10652	Business	9100.00
0005434551887	10652	Business	9100.00
0005434554092	10652	Business	9100.00
0005434551924	10652	Business	9100.00
0005434551886	10652	Business	9100.00
0005434551882	10652	Business	9100.00
0005434558377	10652	Business	9100.00
0005434551923	10652	Business	9100.00
0005434551906	10652	Business	9100.00
0005434551919	10652	Economy	3000.00
0005434551911	10652	Economy	3000.00
0005433181108	10652	Economy	3000.00
0005434551901	10652	Economy	3000.00
0005434551913	10652	Economy	3000.00
0005433181125	10652	Economy	3000.00
0005433181175	10652	Economy	3000.00
0005434551891	10652	Economy	3000.00
0005434551900	10652	Economy	3000.00
0005433181165	10652	Economy	3000.00
0005434558382	10652	Economy	3300.00
0005433181265	10652	Economy	3300.00
0005434551905	10652	Economy	3300.00
0005434551909	10652	Economy	3300.00
0005434551935	10652	Economy	3000.00
0005434551889	10652	Economy	3000.00
0005434551933	10652	Economy	3000.00
0005433181166	10652	Economy	3000.00
0005433181121	10652	Economy	3000.00
0005434551934	10652	Economy	3000.00
0005434551888	10652	Economy	3000.00
0005434551930	10652	Economy	3000.00
0005433181231	10652	Economy	3000.00
0005434558376	10652	Economy	3000.00
0005434551883	10652	Economy	3000.00
0005434558379	10652	Economy	3000.00
0005434551893	10652	Economy	3000.00
0005434554091	10652	Economy	3000.00
0005433181211	10652	Economy	3000.00
0005434551894	10652	Economy	3000.00
0005434551936	10652	Economy	3000.00
0005434558381	10652	Economy	3000.00
0005434558380	10652	Economy	3000.00
0005434551926	10652	Economy	3000.00
0005433181258	10652	Economy	3000.00
0005433181266	10652	Economy	3000.00
0005434551928	10652	Economy	3000.00
0005433181232	10652	Economy	3000.00
0005434551884	10652	Economy	3000.00
0005433181107	10652	Economy	3000.00
0005434551921	10652	Economy	3000.00
0005434551925	10652	Economy	3000.00
0005433181239	10652	Economy	3000.00
0005434554089	10652	Economy	3000.00
0005434551922	10652	Economy	3000.00
0005433181171	10652	Economy	3000.00
0005433181212	10652	Economy	3000.00
0005433181186	10652	Economy	3000.00
0005434551892	10652	Economy	3000.00
0005433181255	10652	Economy	3000.00
0005434551914	10652	Economy	3000.00
0005433181238	10652	Economy	3000.00
0005434551917	10652	Economy	3000.00
0005434551912	10652	Economy	3000.00
0005434554090	10652	Economy	3000.00
0005434551890	10652	Economy	3000.00
0005433181242	10652	Economy	3000.00
0005434551915	10652	Economy	3000.00
0005433181145	10652	Economy	3000.00
0005434551899	10652	Economy	3000.00
0005434551918	10652	Economy	3000.00
0005434551902	10652	Economy	3000.00
0005433181176	10652	Economy	3000.00
0005434558383	10652	Economy	3000.00
0005434551885	10652	Economy	3000.00
0005434551931	10652	Economy	3000.00
0005434551916	10652	Economy	3000.00
0005434551920	10652	Economy	3000.00
0005434551932	10652	Economy	3000.00
0005434558378	10652	Economy	3000.00
0005434551896	10652	Economy	3000.00
0005433181235	10652	Economy	3000.00
0005433181088	10652	Economy	3000.00
0005434551881	10652	Economy	3000.00
0005434551898	10652	Economy	3000.00
0005434551908	10652	Economy	3000.00
0005434551929	10652	Economy	3000.00
0005434551903	10652	Economy	3000.00
0005433181267	10652	Economy	3000.00
0005433181177	10652	Economy	3000.00
0005434551904	10652	Economy	3000.00
0005434551895	10652	Economy	3000.00
0005433181243	10652	Economy	3000.00
0005433181126	10652	Economy	3000.00
0005433181431	27712	Business	9100.00
0005433181445	27712	Business	9100.00
0005433181429	27712	Economy	3000.00
0005433181436	27712	Economy	3000.00
0005433181447	27712	Economy	3300.00
0005433181446	27712	Economy	3000.00
0005433181426	27712	Economy	3000.00
0005433181441	27712	Economy	3000.00
0005433181430	27712	Economy	3000.00
0005433181438	27712	Economy	3000.00
0005433181427	27712	Economy	3000.00
0005433181437	27712	Economy	3000.00
0005433181444	27712	Economy	3000.00
0005433181433	27712	Economy	3000.00
0005433181428	27712	Economy	3000.00
0005433181434	27712	Economy	3000.00
0005433181443	27712	Economy	3000.00
0005433181448	27712	Economy	3000.00
0005433181425	27712	Economy	3000.00
0005433181440	27712	Economy	3000.00
0005433181439	27712	Economy	3000.00
0005433181435	27712	Economy	3000.00
0005433181442	27712	Economy	3000.00
0005433181432	27712	Economy	3000.00
0005434551680	27711	Business	9100.00
0005434551642	27711	Business	9100.00
0005434551570	27711	Business	9100.00
0005434551540	27711	Business	9100.00
0005434558289	27711	Business	9100.00
0005434551456	27711	Business	9100.00
0005434551177	27711	Business	9100.00
0005434558317	27711	Economy	3000.00
0005434551599	27711	Economy	3000.00
0005434551553	27711	Economy	3000.00
0005434551156	27711	Economy	3000.00
0005434551489	27711	Economy	3000.00
0005434551635	27711	Economy	3000.00
0005434551793	27711	Economy	3300.00
0005434551457	27711	Economy	3300.00
0005434551619	27711	Economy	3300.00
0005434551332	27711	Economy	3300.00
0005434551555	27711	Economy	3300.00
0005434551492	27711	Economy	3000.00
0005434551542	27711	Economy	3000.00
0005434551214	27711	Economy	3000.00
0005434551620	27711	Economy	3000.00
0005434551441	27711	Economy	3000.00
0005434551464	27711	Economy	3000.00
0005434551407	27711	Economy	3000.00
0005434551499	27711	Economy	3000.00
0005434558290	27711	Economy	3000.00
0005434551541	27711	Economy	3000.00
0005434551733	27711	Economy	3000.00
0005434551681	27711	Economy	3000.00
0005434551428	27711	Economy	3000.00
0005434551482	27711	Economy	3000.00
0005434551518	27711	Economy	3000.00
0005434551406	27711	Economy	3000.00
0005434551398	27711	Economy	3000.00
0005434551279	27711	Economy	3000.00
0005434551583	27711	Economy	3000.00
0005434551474	27711	Economy	3000.00
0005434551621	27711	Economy	3000.00
0005434551822	27711	Economy	3000.00
0005434551503	27711	Economy	3000.00
0005434551494	27711	Economy	3000.00
0005434551641	27711	Economy	3000.00
0005434558288	27711	Economy	3000.00
0005434551612	27711	Economy	3000.00
0005434551554	27711	Economy	3000.00
0005434551427	27711	Economy	3000.00
0005434551611	27711	Economy	3000.00
0005434551465	27711	Economy	3000.00
0005434551493	27711	Economy	3000.00
0005434551504	27711	Economy	3000.00
0005434551529	27711	Economy	3000.00
0005434558321	27711	Economy	3000.00
0005434558316	27711	Economy	3000.00
0005434551397	27711	Economy	3000.00
0005434551550	27711	Economy	3000.00
0005434551794	27711	Economy	3000.00
0005434551539	27711	Economy	3000.00
0005434551440	27711	Economy	3000.00
0005434558300	27711	Economy	3000.00
0005434551572	27711	Economy	3000.00
0005434558287	27711	Economy	3000.00
0005434554074	27711	Economy	3000.00
0005434551386	27711	Economy	3000.00
0005433459277	6120	Economy	11700.00
0005435254481	6120	Economy	11700.00
0005435254479	6120	Economy	11700.00
0005433459274	6120	Economy	11700.00
0005435254482	6120	Economy	11700.00
0005433459276	6120	Economy	11700.00
0005435254480	6120	Economy	11700.00
0005433459278	6120	Economy	11700.00
0005433459275	6120	Economy	11700.00
0005433459239	19306	Economy	11700.00
0005433459238	19306	Economy	11700.00
0005433459235	19306	Economy	11700.00
0005433459243	19306	Economy	11700.00
0005433459250	19306	Economy	11700.00
0005435254505	19306	Economy	11700.00
0005435254506	19306	Economy	11700.00
0005435682661	6766	Business	51100.00
0005432533305	6766	Business	51100.00
0005432136237	6766	Business	51100.00
0005435682675	6766	Business	51100.00
0005435438138	6766	Business	51100.00
0005435438150	6766	Business	51100.00
0005435682676	6766	Business	51100.00
0005435438057	6766	Business	51100.00
0005435682641	6766	Business	51100.00
0005435438077	6766	Business	51100.00
0005435661969	6766	Business	51100.00
0005435682651	6766	Business	51100.00
0005435438071	6766	Economy	17000.00
0005435438025	6766	Economy	17000.00
0005435438115	6766	Economy	17000.00
0005435682662	6766	Economy	17000.00
0005435437968	6766	Economy	17000.00
0005432533306	6766	Economy	17000.00
0005435682667	6766	Economy	17000.00
0005434828701	6766	Economy	17000.00
0005435682639	6766	Economy	17000.00
0005435438070	6766	Economy	17000.00
0005435682679	6766	Economy	18700.00
0005432136235	6766	Economy	18700.00
0005435438165	6766	Economy	18700.00
0005435631005	6766	Economy	18700.00
0005435682652	6766	Economy	18700.00
0005432136233	6766	Economy	17000.00
0005435682660	6766	Economy	17000.00
0005435217718	6766	Economy	17000.00
0005435682677	6766	Economy	17000.00
0005435682656	6766	Economy	17000.00
0005435682647	6766	Economy	17000.00
0005435438123	6766	Economy	17000.00
0005435438137	6766	Economy	17000.00
0005435682666	6766	Economy	17000.00
0005435682673	6766	Economy	17000.00
0005435682672	6766	Economy	17000.00
0005435682659	6766	Economy	17000.00
0005435682681	6766	Economy	17000.00
0005435438041	6766	Economy	17000.00
0005435438053	6766	Economy	17000.00
0005435438111	6766	Economy	17000.00
0005435682671	6766	Economy	17000.00
0005435438064	6766	Economy	17000.00
0005435438055	6766	Economy	17000.00
0005435682664	6766	Economy	17000.00
0005432533307	6766	Economy	17000.00
0005435438023	6766	Economy	17000.00
0005432136232	6766	Economy	17000.00
0005432136234	6766	Economy	17000.00
0005435438136	6766	Economy	17000.00
0005435217725	6766	Economy	17000.00
0005435682674	6766	Economy	17000.00
0005435682654	6766	Economy	17000.00
0005435682649	6766	Economy	17000.00
0005435682642	6766	Economy	17000.00
0005435438043	6766	Economy	17000.00
0005435661968	6766	Economy	17000.00
0005435217727	6766	Economy	17000.00
0005435682648	6766	Economy	17000.00
0005435682650	6766	Economy	17000.00
0005435631004	6766	Economy	17000.00
0005435682646	6766	Economy	17000.00
0005432136236	6766	Economy	17000.00
0005435438063	6766	Economy	17000.00
0005435438149	6766	Economy	17000.00
0005435682669	6766	Economy	17000.00
0005435661966	6766	Economy	17000.00
0005435682645	6766	Economy	17000.00
0005435682643	6766	Economy	17000.00
0005435438122	6766	Economy	17000.00
0005435682653	6766	Economy	17000.00
0005435682658	6766	Economy	17000.00
0005435631006	6766	Economy	17000.00
0005435631007	6766	Economy	17000.00
0005435438026	6766	Economy	17000.00
0005435682663	6766	Economy	17000.00
0005435438104	6766	Economy	17000.00
0005435438103	6766	Economy	17000.00
0005435682668	6766	Economy	17000.00
0005435438024	6766	Economy	17000.00
0005435682665	6766	Economy	17000.00
0005435661967	6766	Economy	17000.00
0005435682655	6766	Economy	17000.00
0005432533304	6766	Economy	17000.00
0005435682657	6766	Economy	17000.00
0005435438042	6766	Economy	17000.00
0005435437967	6766	Economy	17000.00
0005435682644	6766	Economy	17000.00
0005435682670	6766	Economy	17000.00
0005435438164	6766	Economy	17000.00
0005435682678	6766	Economy	17000.00
0005435438027	6766	Economy	17000.00
0005435682680	6766	Economy	17000.00
0005435682640	6766	Economy	17000.00
0005435438105	6766	Economy	17000.00
0005435682380	24605	Business	51100.00
0005435682324	24605	Business	51100.00
0005435682204	24605	Business	51100.00
0005432533331	24605	Business	51100.00
0005435438257	24605	Business	51100.00
0005435438256	24605	Business	51100.00
0005435438254	24605	Business	51100.00
0005435438236	24605	Business	51100.00
0005432533329	24605	Business	51100.00
0005435630984	24605	Business	51100.00
0005435438250	24605	Business	51100.00
0005435682311	24605	Economy	17000.00
0005435438253	24605	Economy	17000.00
0005435682322	24605	Economy	17000.00
0005435682288	24605	Economy	17000.00
0005435438239	24605	Economy	17000.00
0005435682260	24605	Economy	17000.00
0005435630978	24605	Economy	17000.00
0005435682293	24605	Economy	17000.00
0005435682353	24605	Economy	18700.00
0005435720826	24605	Economy	18700.00
0005435720825	24605	Economy	18700.00
0005435438241	24605	Economy	18700.00
0005435682270	24605	Economy	17000.00
0005435682222	24605	Economy	17000.00
0005435682325	24605	Economy	17000.00
0005435438238	24605	Economy	17000.00
0005432305780	24605	Economy	17000.00
0005435682371	24605	Economy	17000.00
0005435438251	24605	Economy	17000.00
0005435682413	24605	Economy	17000.00
0005434828734	24605	Economy	17000.00
0005435682359	24605	Economy	17000.00
0005435438234	24605	Economy	17000.00
0005435438243	24605	Economy	17000.00
0005435682037	24605	Economy	17000.00
0005435682399	24605	Economy	17000.00
0005435682412	24605	Economy	17000.00
0005435682323	24605	Economy	17000.00
0005435682223	24605	Economy	17000.00
0005435682407	24605	Economy	17000.00
0005435682059	24605	Economy	17000.00
0005435438245	24605	Economy	17000.00
0005435682459	24605	Economy	17000.00
0005435682203	24605	Economy	17000.00
0005435438249	24605	Economy	17000.00
0005435438247	24605	Economy	17000.00
0005435438244	24605	Economy	17000.00
0005435682137	24605	Economy	17000.00
0005434828735	24605	Economy	17000.00
0005432305782	24605	Economy	17000.00
0005435682382	24605	Economy	17000.00
0005435682444	24605	Economy	17000.00
0005435682440	24605	Economy	17000.00
0005432305781	24605	Economy	17000.00
0005435682367	24605	Economy	17000.00
0005435661945	24605	Economy	17000.00
0005435682286	24605	Economy	17000.00
0005435630972	24605	Economy	17000.00
0005435438237	24605	Economy	17000.00
0005435682261	24605	Economy	17000.00
0005435682330	24605	Economy	17000.00
0005435438240	24605	Economy	17000.00
0005435438252	24605	Economy	17000.00
0005435438246	24605	Economy	17000.00
0005435438248	24605	Economy	17000.00
0005435661944	24605	Economy	17000.00
0005435682287	24605	Economy	17000.00
0005435438255	24605	Economy	17000.00
0005435682202	24605	Economy	17000.00
0005435682294	24605	Economy	17000.00
0005435682189	24605	Economy	17000.00
0005435682379	24605	Economy	17000.00
0005432533330	24605	Economy	17000.00
0005435682274	24605	Economy	17000.00
0005435438242	24605	Economy	17000.00
0005435682384	24605	Economy	17000.00
0005435682201	24605	Economy	17000.00
0005435630975	24605	Economy	17000.00
0005435682255	24605	Economy	17000.00
0005435682411	24605	Economy	17000.00
0005435682248	24605	Economy	17000.00
0005435438235	24605	Economy	17000.00
0005435126893	11509	Business	26400.00
0005435126861	11509	Business	26400.00
0005435126875	11509	Business	26400.00
0005435126867	11509	Business	26400.00
0005435126860	11509	Business	26400.00
0005435126872	11509	Business	26400.00
0005435126877	11509	Economy	8800.00
0005435126874	11509	Economy	8800.00
0005435126895	11509	Economy	8800.00
0005435126885	11509	Economy	8800.00
0005435126883	11509	Economy	9700.00
0005435558094	11509	Economy	9700.00
0005435126886	11509	Economy	9700.00
0005435126865	11509	Economy	9700.00
0005435126859	11509	Economy	9700.00
0005435106023	11509	Economy	8800.00
0005435126894	11509	Economy	8800.00
0005435126887	11509	Economy	8800.00
0005435126876	11509	Economy	8800.00
0005435126870	11509	Economy	8800.00
0005435126878	11509	Economy	8800.00
0005435126889	11509	Economy	8800.00
0005435126896	11509	Economy	8800.00
0005435558108	11509	Economy	8800.00
0005435126858	11509	Economy	8800.00
0005435126869	11509	Economy	8800.00
0005435126863	11509	Economy	8800.00
0005435126879	11509	Economy	8800.00
0005435126884	11509	Economy	8800.00
0005435126866	11509	Economy	8800.00
0005435106022	11509	Economy	8800.00
0005435126873	11509	Economy	8800.00
0005435126868	11509	Economy	8800.00
0005435126871	11509	Economy	8800.00
0005435126881	11509	Economy	8800.00
0005435126857	11509	Economy	8800.00
0005435126856	11509	Economy	8800.00
0005435126880	11509	Economy	8800.00
0005435126890	11509	Economy	8800.00
0005435126882	11509	Economy	8800.00
0005435126862	11509	Economy	8800.00
0005435126892	11509	Economy	8800.00
0005435126891	11509	Economy	8800.00
0005435126864	11509	Economy	8800.00
0005435558107	11509	Economy	8800.00
0005435126855	11509	Economy	8800.00
0005435126888	11509	Economy	8800.00
0005435126647	31867	Business	26400.00
0005435126498	31867	Business	26400.00
0005435126423	31867	Business	26400.00
0005435126483	31867	Business	26400.00
0005435126548	31867	Business	26400.00
0005435126514	31867	Business	26400.00
0005435126781	31867	Business	26400.00
0005435126610	31867	Economy	8800.00
0005435126632	31867	Economy	8800.00
0005435098568	31867	Economy	8800.00
0005435126512	31867	Economy	9700.00
0005435126609	31867	Economy	9700.00
0005435558122	31867	Economy	9700.00
0005435126484	31867	Economy	8800.00
0005435106002	31867	Economy	8800.00
0005435126549	31867	Economy	8800.00
0005435126502	31867	Economy	8800.00
0005435558123	31867	Economy	8800.00
0005435126411	31867	Economy	8800.00
0005435126678	31867	Economy	8800.00
0005435126664	31867	Economy	8800.00
0005435105984	31867	Economy	8800.00
0005435126572	31867	Economy	8800.00
0005435126500	31867	Economy	8800.00
0005435126487	31867	Economy	8800.00
0005435126539	31867	Economy	8800.00
0005435126526	31867	Economy	8800.00
0005435098567	31867	Economy	8800.00
0005435126646	31867	Economy	8800.00
0005435558121	31867	Economy	8800.00
0005435126625	31867	Economy	8800.00
0005435126782	31867	Economy	8800.00
0005435106011	31867	Economy	8800.00
0005435126522	31867	Economy	8800.00
0005435106012	31867	Economy	8800.00
0005435126424	31867	Economy	8800.00
0005435105991	31867	Economy	8800.00
0005435105996	31867	Economy	8800.00
0005435126565	31867	Economy	8800.00
0005435098569	31867	Economy	8800.00
0005435126612	31867	Economy	8800.00
0005435732348	13543	Business	36600.00
0005435732388	13543	Business	36600.00
0005433398683	13543	Business	36600.00
0005433398690	13543	Business	36600.00
0005433398717	13543	Business	36600.00
0005433398716	13543	Business	36600.00
0005433398672	13543	Business	36600.00
0005433398708	13543	Business	36600.00
0005433398704	13543	Economy	12200.00
0005433398710	13543	Economy	12200.00
0005433398713	13543	Economy	12200.00
0005433398694	13543	Economy	12200.00
0005433398670	13543	Economy	12200.00
0005433398691	13543	Economy	12200.00
0005433398684	13543	Economy	13400.00
0005433398702	13543	Economy	13400.00
0005433398673	13543	Economy	13400.00
0005435732392	13543	Economy	12200.00
0005433398700	13543	Economy	12200.00
0005433398698	13543	Economy	12200.00
0005435732412	13543	Economy	12200.00
0005435732413	13543	Economy	12200.00
0005433398705	13543	Economy	12200.00
0005433398714	13543	Economy	12200.00
0005433398706	13543	Economy	12200.00
0005435732367	13543	Economy	12200.00
0005433398687	13543	Economy	12200.00
0005433398711	13543	Economy	12200.00
0005433398680	13543	Economy	12200.00
0005433398699	13543	Economy	12200.00
0005433398681	13543	Economy	12200.00
0005433398707	13543	Economy	12200.00
0005433398688	13543	Economy	12200.00
0005433398692	13543	Economy	12200.00
0005433398678	13543	Economy	12200.00
0005435732366	13543	Economy	12200.00
0005435732381	13543	Economy	12200.00
0005433398682	13543	Economy	12200.00
0005433398719	13543	Economy	12200.00
0005433398686	13543	Economy	12200.00
0005433398712	13543	Economy	12200.00
0005435732393	13543	Economy	12200.00
0005433398709	13543	Economy	12200.00
0005433398674	13543	Economy	12200.00
0005433398685	13543	Economy	12200.00
0005435732347	13543	Economy	12200.00
0005433398689	13543	Economy	12200.00
0005433398695	13543	Economy	12200.00
0005435732378	13543	Economy	12200.00
0005433398671	13543	Economy	12200.00
0005433398696	13543	Economy	12200.00
0005433398718	13543	Economy	12200.00
0005435732389	13543	Economy	12200.00
0005433398675	13543	Economy	12200.00
0005433398677	13543	Economy	12200.00
0005435732450	13543	Economy	12200.00
0005433398703	13543	Economy	12200.00
0005433398701	13543	Economy	12200.00
0005433398679	13543	Economy	12200.00
0005433398676	13543	Economy	12200.00
0005433398715	13543	Economy	12200.00
0005433398697	13543	Economy	12200.00
0005435732326	13543	Economy	12200.00
0005435732325	13543	Economy	12200.00
0005433398693	13543	Economy	12200.00
0005432297312	19389	Business	36600.00
0005433398111	19389	Business	36600.00
0005433398202	19389	Business	36600.00
0005433398131	19389	Business	36600.00
0005433398130	19389	Business	36600.00
0005433398401	19389	Business	36600.00
0005433398147	19389	Business	36600.00
0005433398238	19389	Business	36600.00
0005433398402	19389	Business	36600.00
0005435732493	19389	Business	36600.00
0005435732496	19389	Economy	12200.00
0005432297313	19389	Economy	12200.00
0005435732510	19389	Economy	12200.00
0005433398336	19389	Economy	12200.00
0005433398058	19389	Economy	12200.00
0005433398209	19389	Economy	12200.00
0005435732507	19389	Economy	12200.00
0005433398403	19389	Economy	13400.00
0005435732501	19389	Economy	13400.00
0005435732495	19389	Economy	13400.00
0005433398286	19389	Economy	12200.00
0005435732503	19389	Economy	12200.00
0005433398304	19389	Economy	12200.00
0005435732508	19389	Economy	12200.00
0005433398239	19389	Economy	12200.00
0005433398259	19389	Economy	12200.00
0005433398285	19389	Economy	12200.00
0005433398284	19389	Economy	12200.00
0005435732505	19389	Economy	12200.00
0005435732504	19389	Economy	12200.00
0005433398249	19389	Economy	12200.00
0005435732494	19389	Economy	12200.00
0005435732502	19389	Economy	12200.00
0005433398313	19389	Economy	12200.00
0005433398182	19389	Economy	12200.00
0005435732506	19389	Economy	12200.00
0005432297311	19389	Economy	12200.00
0005433398385	19389	Economy	12200.00
0005433398422	19389	Economy	12200.00
0005433398236	19389	Economy	12200.00
0005435732497	19389	Economy	12200.00
0005433398387	19389	Economy	12200.00
0005433398230	19389	Economy	12200.00
0005433398370	19389	Economy	12200.00
0005435732511	19389	Economy	12200.00
0005433398242	19389	Economy	12200.00
0005435732499	19389	Economy	12200.00
0005433398148	19389	Economy	12200.00
0005433398335	19389	Economy	12200.00
0005435732500	19389	Economy	12200.00
0005433398205	19389	Economy	12200.00
0005433398567	19389	Economy	12200.00
0005433398203	19389	Economy	12200.00
0005433398204	19389	Economy	12200.00
0005433398112	19389	Economy	12200.00
0005433398191	19389	Economy	12200.00
0005435732498	19389	Economy	12200.00
0005433398404	19389	Economy	12200.00
0005432297314	19389	Economy	12200.00
0005433398237	19389	Economy	12200.00
0005433398513	19389	Economy	12200.00
0005433398303	19389	Economy	12200.00
0005433398334	19389	Economy	12200.00
0005435732509	19389	Economy	12200.00
0005433398388	19389	Economy	12200.00
0005433398312	19389	Economy	12200.00
0005433398368	19389	Economy	12200.00
0005433398159	19389	Economy	12200.00
0005433398129	19389	Economy	12200.00
0005435069233	13147	Business	11300.00
0005435069360	13147	Business	11300.00
0005435069299	13147	Business	11300.00
0005435069374	13147	Business	11300.00
0005435069521	13147	Business	11300.00
0005435069188	13147	Business	11300.00
0005435069251	13147	Business	11300.00
0005435069036	13147	Business	11300.00
0005435069129	13147	Economy	3800.00
0005435069190	13147	Economy	3800.00
0005435069200	13147	Economy	3800.00
0005435069304	13147	Economy	3800.00
0005435069173	13147	Economy	3800.00
0005435069520	13147	Economy	3800.00
0005435068860	13147	Economy	3800.00
0005435069081	13147	Economy	3800.00
0005435069172	13147	Economy	3800.00
0005435069263	13147	Economy	4100.00
0005435069394	13147	Economy	4100.00
0005435069303	13147	Economy	3800.00
0005435069246	13147	Economy	3800.00
0005435925468	13147	Economy	3800.00
0005435069354	13147	Economy	3800.00
0005435069084	13147	Economy	3800.00
0005435069373	13147	Economy	3800.00
0005435069270	13147	Economy	3800.00
0005435069174	13147	Economy	3800.00
0005435069271	13147	Economy	3800.00
0005435069391	13147	Economy	3800.00
0005435925470	13147	Economy	3800.00
0005435069473	13147	Economy	3800.00
0005435069153	13147	Economy	3800.00
0005435069175	13147	Economy	3800.00
0005435069358	13147	Economy	3800.00
0005435925471	13147	Economy	3800.00
0005435069241	13147	Economy	3800.00
0005435069187	13147	Economy	3800.00
0005435069359	13147	Economy	3800.00
0005435069245	13147	Economy	3800.00
0005435069199	13147	Economy	3800.00
0005435069019	13147	Economy	3800.00
0005435069085	13147	Economy	3800.00
0005435069121	13147	Economy	3800.00
0005435069443	13147	Economy	3800.00
0005435069444	13147	Economy	3800.00
0005435069133	13147	Economy	3800.00
0005435925469	13147	Economy	3800.00
0005435925472	13147	Economy	3800.00
0005435069264	13147	Economy	3800.00
0005435069080	13147	Economy	3800.00
0005435069109	13147	Economy	3800.00
0005435069383	13147	Economy	3800.00
0005435069466	13147	Economy	3800.00
0005435069311	13147	Economy	3800.00
0005435069247	13147	Economy	3800.00
0005435069117	13147	Economy	3800.00
0005435069393	13147	Economy	3800.00
0005435069020	13147	Economy	3800.00
0005435069060	13147	Economy	3800.00
0005435069289	13147	Economy	3800.00
0005435069401	13147	Economy	3800.00
0005435069353	13147	Economy	3800.00
0005435069390	13147	Economy	3800.00
0005435069369	13147	Economy	3800.00
0005435069372	13147	Economy	3800.00
0005435069082	13147	Economy	3800.00
0005435069108	13147	Economy	3800.00
0005435069120	13147	Economy	3800.00
0005435069395	13147	Economy	3800.00
0005435069212	13147	Economy	3800.00
0005435069132	13147	Economy	3800.00
0005435925330	15505	Business	11300.00
0005435069696	15505	Business	11300.00
0005435069722	15505	Business	11300.00
0005435069720	15505	Business	11300.00
0005435069710	15505	Business	11300.00
0005435069719	15505	Business	11300.00
0005435069721	15505	Business	11300.00
0005435069745	15505	Business	11300.00
0005435069737	15505	Business	11300.00
0005435069746	15505	Business	11300.00
0005435069709	15505	Business	11300.00
0005435069703	15505	Economy	3800.00
0005435069736	15505	Economy	3800.00
0005435069740	15505	Economy	3800.00
0005435069711	15505	Economy	3800.00
0005435069727	15505	Economy	3800.00
0005435069732	15505	Economy	4100.00
0005435069747	15505	Economy	4100.00
0005435069734	15505	Economy	4100.00
0005435069695	15505	Economy	4100.00
0005435069699	15505	Economy	3800.00
0005435925331	15505	Economy	3800.00
0005435069748	15505	Economy	3800.00
0005435069706	15505	Economy	3800.00
0005435069728	15505	Economy	3800.00
0005435925334	15505	Economy	3800.00
0005435069708	15505	Economy	3800.00
0005435069714	15505	Economy	3800.00
0005435925318	15505	Economy	3800.00
0005435925321	15505	Economy	3800.00
0005435925319	15505	Economy	3800.00
0005435069738	15505	Economy	3800.00
0005435069731	15505	Economy	3800.00
0005435069712	15505	Economy	3800.00
0005435069729	15505	Economy	3800.00
0005435069705	15505	Economy	3800.00
0005435069701	15505	Economy	3800.00
0005435069715	15505	Economy	3800.00
0005435925339	15505	Economy	3800.00
0005435069698	15505	Economy	3800.00
0005435069739	15505	Economy	3800.00
0005435069743	15505	Economy	3800.00
0005435925340	15505	Economy	3800.00
0005435069742	15505	Economy	3800.00
0005435069700	15505	Economy	3800.00
0005435925325	15505	Economy	3800.00
0005435925335	15505	Economy	3800.00
0005435069725	15505	Economy	3800.00
0005435069707	15505	Economy	3800.00
0005435069718	15505	Economy	3800.00
0005435069716	15505	Economy	3800.00
0005435069704	15505	Economy	3800.00
0005435069744	15505	Economy	3800.00
0005435069733	15505	Economy	3800.00
0005435069723	15505	Economy	3800.00
0005435069713	15505	Economy	3800.00
0005435069697	15505	Economy	3800.00
0005435069717	15505	Economy	3800.00
0005435069730	15505	Economy	3800.00
0005435069726	15505	Economy	3800.00
0005435069702	15505	Economy	3800.00
0005435925317	15505	Economy	3800.00
0005435069735	15505	Economy	3800.00
0005435069724	15505	Economy	3800.00
0005435925338	15505	Economy	3800.00
0005435069741	15505	Economy	3800.00
0005435808299	29495	Economy	27100.00
0005433407627	29495	Economy	27100.00
0005435808250	29495	Economy	27100.00
0005435808262	29495	Economy	27100.00
0005433407629	29495	Economy	24700.00
0005435808253	29495	Economy	24700.00
0005435808255	29495	Economy	24700.00
0005435808300	29495	Economy	24700.00
0005435808240	29495	Economy	24700.00
0005433407637	29495	Economy	24700.00
0005435808249	29495	Economy	24700.00
0005435808264	29495	Economy	24700.00
0005433407636	29495	Economy	24700.00
0005435808257	29495	Economy	24700.00
0005435808295	29495	Economy	24700.00
0005435808267	29495	Economy	24700.00
0005435808246	29495	Economy	24700.00
0005433407633	29495	Economy	24700.00
0005433407631	29495	Economy	24700.00
0005435808296	29495	Economy	24700.00
0005435808258	29495	Economy	24700.00
0005433407630	29495	Economy	24700.00
0005435808247	29495	Economy	24700.00
0005435808238	29495	Economy	24700.00
0005433407635	29495	Economy	24700.00
0005433407632	29495	Economy	24700.00
0005435808254	29495	Economy	24700.00
0005435808252	29495	Economy	24700.00
0005433407628	29495	Economy	24700.00
0005435808278	29495	Economy	24700.00
0005435808263	29495	Economy	24700.00
0005435808288	29495	Economy	24700.00
0005435808279	29495	Economy	24700.00
0005435808259	29495	Economy	24700.00
0005435808251	29495	Economy	24700.00
0005435808248	29495	Economy	24700.00
0005433407634	29495	Economy	24700.00
0005434215144	10694	Business	61300.00
0005434756538	10694	Business	61300.00
0005434215166	10694	Business	61300.00
0005434215156	10694	Business	61300.00
0005434215155	10694	Business	61300.00
0005434756617	10694	Business	61300.00
0005434756613	10694	Business	61300.00
0005434756687	10694	Business	61300.00
0005434215157	10694	Business	61300.00
0005434756526	10694	Business	61300.00
0005434215136	10694	Business	61300.00
0005434215147	10694	Economy	20400.00
0005434215142	10694	Economy	20400.00
0005434215164	10694	Economy	20400.00
0005434756590	10694	Economy	20400.00
0005434215130	10694	Economy	20400.00
0005434215134	10694	Economy	20400.00
0005434756568	10694	Economy	20400.00
0005434756632	10694	Economy	20400.00
0005434756573	10694	Economy	20400.00
0005434215167	10694	Economy	20400.00
0005434756529	10694	Economy	22500.00
0005434215131	10694	Economy	22500.00
0005434756706	10694	Economy	22500.00
0005434756513	10694	Economy	22500.00
0005434756552	10694	Economy	20400.00
0005434215154	10694	Economy	20400.00
0005434756574	10694	Economy	20400.00
0005434756618	10694	Economy	20400.00
0005434756530	10694	Economy	20400.00
0005434215168	10694	Economy	20400.00
0005434756499	10694	Economy	20400.00
0005434756537	10694	Economy	20400.00
0005434756689	10694	Economy	20400.00
0005434215133	10694	Economy	20400.00
0005434756514	10694	Economy	20400.00
0005434756567	10694	Economy	20400.00
0005434215158	10694	Economy	20400.00
0005434756570	10694	Economy	20400.00
0005434756688	10694	Economy	20400.00
0005434215171	10694	Economy	20400.00
0005434756412	10694	Economy	20400.00
0005434215161	10694	Economy	20400.00
0005434215165	10694	Economy	20400.00
0005434756619	10694	Economy	20400.00
0005434215135	10694	Economy	20400.00
0005434756704	10694	Economy	20400.00
0005434756630	10694	Economy	20400.00
0005434215127	10694	Economy	20400.00
0005434215141	10694	Economy	20400.00
0005434215149	10694	Economy	20400.00
0005434215172	10694	Economy	20400.00
0005434215145	10694	Economy	20400.00
0005434756416	10694	Economy	20400.00
0005434756403	10694	Economy	20400.00
0005434215163	10694	Economy	20400.00
0005434215159	10694	Economy	20400.00
0005434215153	10694	Economy	20400.00
0005434215170	10694	Economy	20400.00
0005434756564	10694	Economy	20400.00
0005434215162	10694	Economy	20400.00
0005434215148	10694	Economy	20400.00
0005434756671	10694	Economy	20400.00
0005434215151	10694	Economy	20400.00
0005434215146	10694	Economy	20400.00
0005434756544	10694	Economy	20400.00
0005434756609	10694	Economy	20400.00
0005434215169	10694	Economy	20400.00
0005434215126	10694	Economy	20400.00
0005434756404	10694	Economy	20400.00
0005434756536	10694	Economy	20400.00
0005434215128	10694	Economy	20400.00
0005434215129	10694	Economy	20400.00
0005434215137	10694	Economy	20400.00
0005434756681	10694	Economy	20400.00
0005434756471	10694	Economy	20400.00
0005434756454	10694	Economy	20400.00
0005434215150	10694	Economy	20400.00
0005434756543	10694	Economy	20400.00
0005434215139	10694	Economy	20400.00
0005434756453	10694	Economy	20400.00
0005434215138	10694	Economy	20400.00
0005434756583	10694	Economy	20400.00
0005434756411	10694	Economy	20400.00
0005434756652	10694	Economy	20400.00
0005434215152	10694	Economy	20400.00
0005434215132	10694	Economy	20400.00
0005434756651	10694	Economy	20400.00
0005434756604	10694	Economy	20400.00
0005434215143	10694	Economy	20400.00
0005434215140	10694	Economy	20400.00
0005434756569	10694	Economy	20400.00
0005434215160	10694	Economy	20400.00
0005434756957	28693	Business	61300.00
0005434756942	28693	Business	61300.00
0005434214718	28693	Business	61300.00
0005434756947	28693	Business	61300.00
0005434214661	28693	Business	61300.00
0005434214534	28693	Business	61300.00
0005434756941	28693	Business	61300.00
0005434214519	28693	Business	61300.00
0005434214809	28693	Business	61300.00
0005434756955	28693	Business	61300.00
0005434214597	28693	Business	61300.00
0005434214513	28693	Economy	20400.00
0005434214646	28693	Economy	20400.00
0005434756948	28693	Economy	20400.00
0005434756954	28693	Economy	20400.00
0005434756946	28693	Economy	20400.00
0005434214671	28693	Economy	20400.00
0005434214596	28693	Economy	20400.00
0005434756950	28693	Economy	20400.00
0005434756944	28693	Economy	20400.00
0005434214528	28693	Economy	20400.00
0005434756937	28693	Economy	22500.00
0005434214737	28693	Economy	22500.00
0005434214699	28693	Economy	22500.00
0005434214793	28693	Economy	22500.00
0005434214449	28693	Economy	20400.00
0005434214838	28693	Economy	20400.00
0005434214886	28693	Economy	20400.00
0005434214413	28693	Economy	20400.00
0005434756929	28693	Economy	20400.00
0005434214448	28693	Economy	20400.00
0005434214609	28693	Economy	20400.00
0005434214587	28693	Economy	20400.00
0005434756960	28693	Economy	20400.00
0005434214650	28693	Economy	20400.00
0005434756940	28693	Economy	20400.00
0005434756953	28693	Economy	20400.00
0005434214682	28693	Economy	20400.00
0005434214698	28693	Economy	20400.00
0005434214610	28693	Economy	20400.00
0005434214514	28693	Economy	20400.00
0005434214668	28693	Economy	20400.00
0005434214740	28693	Economy	20400.00
0005434756951	28693	Economy	20400.00
0005434214810	28693	Economy	20400.00
0005434756952	28693	Economy	20400.00
0005434756958	28693	Economy	20400.00
0005434214560	28693	Economy	20400.00
0005434214588	28693	Economy	20400.00
0005434756934	28693	Economy	20400.00
0005434214586	28693	Economy	20400.00
0005434214621	28693	Economy	20400.00
0005434756959	28693	Economy	20400.00
0005434214504	28693	Economy	20400.00
0005434756962	28693	Economy	20400.00
0005434756956	28693	Economy	20400.00
0005434214669	28693	Economy	20400.00
0005434214681	28693	Economy	20400.00
0005434756936	28693	Economy	20400.00
0005434214721	28693	Economy	20400.00
0005434214628	28693	Economy	20400.00
0005434214622	28693	Economy	20400.00
0005434214592	28693	Economy	20400.00
0005434756961	28693	Economy	20400.00
0005434214629	28693	Economy	20400.00
0005434756964	28693	Economy	20400.00
0005434214414	28693	Economy	20400.00
0005434214553	28693	Economy	20400.00
0005434756932	28693	Economy	20400.00
0005434214593	28693	Economy	20400.00
0005434214559	28693	Economy	20400.00
0005434214613	28693	Economy	20400.00
0005434756928	28693	Economy	20400.00
0005434214419	28693	Economy	20400.00
0005434756943	28693	Economy	20400.00
0005434756931	28693	Economy	20400.00
0005434214487	28693	Economy	20400.00
0005434214552	28693	Economy	20400.00
0005434756938	28693	Economy	20400.00
0005434214722	28693	Economy	20400.00
0005434214887	28693	Economy	20400.00
0005434756930	28693	Economy	20400.00
0005434756945	28693	Economy	20400.00
0005434756949	28693	Economy	20400.00
0005434214706	28693	Economy	20400.00
0005434756933	28693	Economy	20400.00
0005434756935	28693	Economy	20400.00
0005434756939	28693	Economy	20400.00
0005434214811	28693	Economy	20400.00
0005434756963	28693	Economy	20400.00
0005434229411	5459	Business	29500.00
0005435040595	5459	Business	29500.00
0005435007341	5459	Business	29500.00
0005434229437	5459	Business	29500.00
0005435040647	5459	Business	29500.00
0005435040645	5459	Business	29500.00
0005434229500	5459	Business	29500.00
0005435040618	5459	Business	29500.00
0005435040652	5459	Business	29500.00
0005435040599	5459	Business	29500.00
0005435040641	5459	Business	29500.00
0005435007334	5459	Business	29500.00
0005435040617	5459	Economy	9800.00
0005435040639	5459	Economy	9800.00
0005435007340	5459	Economy	9800.00
0005435040597	5459	Economy	9800.00
0005432125548	5459	Economy	9800.00
0005435040621	5459	Economy	9800.00
0005435040611	5459	Economy	9800.00
0005435007338	5459	Economy	9800.00
0005435040593	5459	Economy	9800.00
0005434229501	5459	Economy	9800.00
0005435040594	5459	Economy	9800.00
0005434229516	5459	Economy	9800.00
0005434229402	5459	Economy	9800.00
0005435042886	5459	Economy	9800.00
0005435007339	5459	Economy	9800.00
0005434229462	5459	Economy	9800.00
0005435007352	5459	Economy	9800.00
0005434229535	5459	Economy	9800.00
0005435040650	5459	Economy	9800.00
0005435040596	5459	Economy	9800.00
0005435040608	5459	Economy	9800.00
0005432125547	5459	Economy	9800.00
0005435007332	5459	Economy	9800.00
0005434229457	5459	Economy	9800.00
0005435040589	5459	Economy	9800.00
0005435040616	5459	Economy	9800.00
0005435040619	5459	Economy	9800.00
0005435040602	5459	Economy	9800.00
0005434229481	5459	Economy	9800.00
0005435040592	5459	Economy	9800.00
0005435007353	5459	Economy	9800.00
0005435040640	5459	Economy	9800.00
0005434229552	5459	Economy	9800.00
0005435040627	5459	Economy	9800.00
0005434229438	5459	Economy	9800.00
0005435007346	5459	Economy	9800.00
0005432125546	5459	Economy	9800.00
0005435007342	5459	Economy	9800.00
0005434229628	5459	Economy	10800.00
0005435040649	5459	Economy	9800.00
0005435040610	5459	Economy	10800.00
0005432125549	5459	Economy	10800.00
0005435040586	5459	Economy	10800.00
0005435040591	5459	Economy	10800.00
0005435040604	5459	Economy	10800.00
0005435040635	5459	Economy	9800.00
0005435040601	5459	Economy	9800.00
0005435040632	5459	Economy	9800.00
0005435040613	5459	Economy	9800.00
0005435007348	5459	Economy	9800.00
0005435040638	5459	Economy	9800.00
0005432125545	5459	Economy	9800.00
0005435040612	5459	Economy	9800.00
0005435040642	5459	Economy	9800.00
0005435007330	5459	Economy	9800.00
0005434229498	5459	Economy	9800.00
0005435040637	5459	Economy	9800.00
0005435040636	5459	Economy	9800.00
0005435007347	5459	Economy	9800.00
0005435040600	5459	Economy	9800.00
0005435040590	5459	Economy	9800.00
0005435007333	5459	Economy	9800.00
0005435040622	5459	Economy	9800.00
0005435040625	5459	Economy	9800.00
0005435040628	5459	Economy	9800.00
0005435043293	5459	Economy	9800.00
0005435040607	5459	Economy	9800.00
0005435040646	5459	Economy	9800.00
0005435040643	5459	Economy	9800.00
0005435040633	5459	Economy	9800.00
0005435040629	5459	Economy	9800.00
0005435007345	5459	Economy	9800.00
0005435040624	5459	Economy	9800.00
0005435042887	5459	Economy	9800.00
0005432125550	5459	Economy	9800.00
0005435007335	5459	Economy	9800.00
0005435040585	5459	Economy	9800.00
0005432125552	5459	Economy	9800.00
0005435040615	5459	Economy	9800.00
0005435043294	5459	Economy	9800.00
0005435040620	5459	Economy	9800.00
0005435040614	5459	Economy	9800.00
0005435040626	5459	Economy	9800.00
0005435007337	5459	Economy	9800.00
0005435007343	5459	Economy	9800.00
0005435007344	5459	Economy	9800.00
0005435040609	5459	Economy	9800.00
0005435040630	5459	Economy	9800.00
0005435042885	5459	Economy	9800.00
0005435007354	5459	Economy	9800.00
0005435042888	5459	Economy	9800.00
0005435040605	5459	Economy	9800.00
0005435007350	5459	Economy	9800.00
0005435007331	5459	Economy	9800.00
0005435007349	5459	Economy	9800.00
0005435040651	5459	Economy	9800.00
0005435042889	5459	Economy	9800.00
0005435007351	5459	Economy	9800.00
0005435040644	5459	Economy	9800.00
0005435040648	5459	Economy	9800.00
0005435007336	5459	Economy	9800.00
0005435040598	5459	Economy	9800.00
0005435040603	5459	Economy	9800.00
0005434229586	5459	Economy	9800.00
0005434229480	5459	Economy	9800.00
0005434229585	5459	Economy	9800.00
0005435040623	5459	Economy	9800.00
0005434229629	5459	Economy	9800.00
0005434229487	5459	Economy	9800.00
0005435040606	5459	Economy	9800.00
0005435040588	5459	Economy	9800.00
0005435040587	5459	Economy	9800.00
0005432125551	5459	Economy	9800.00
0005435040634	5459	Economy	9800.00
0005435007329	5459	Economy	9800.00
0005435040631	5459	Economy	9800.00
0005435007102	12967	Business	29500.00
0005435040043	12967	Business	29500.00
0005435040002	12967	Business	29500.00
0005435040177	12967	Business	29500.00
0005434229670	12967	Business	29500.00
0005435007005	12967	Business	29500.00
0005435007156	12967	Business	29500.00
0005435040300	12967	Business	29500.00
0005435039969	12967	Business	29500.00
0005434229669	12967	Business	29500.00
0005434229665	12967	Business	29500.00
0005435040219	12967	Business	29500.00
0005435039972	12967	Economy	9800.00
0005435007017	12967	Economy	9800.00
0005435040073	12967	Economy	9800.00
0005435040123	12967	Economy	9800.00
0005435007143	12967	Economy	9800.00
0005432304451	12967	Economy	9800.00
0005435039888	12967	Economy	9800.00
0005434229668	12967	Economy	9800.00
0005435039858	12967	Economy	9800.00
0005434229680	12967	Economy	9800.00
0005434229682	12967	Economy	9800.00
0005435040056	12967	Economy	9800.00
0005435040166	12967	Economy	9800.00
0005435040122	12967	Economy	9800.00
0005435007170	12967	Economy	9800.00
0005435040318	12967	Economy	9800.00
0005435040137	12967	Economy	9800.00
0005435007130	12967	Economy	9800.00
0005435040344	12967	Economy	9800.00
0005434229662	12967	Economy	9800.00
0005435007168	12967	Economy	9800.00
0005435007205	12967	Economy	9800.00
0005434229666	12967	Economy	9800.00
0005435040280	12967	Economy	9800.00
0005435040200	12967	Economy	9800.00
0005435040212	12967	Economy	9800.00
0005435007137	12967	Economy	9800.00
0005435040419	12967	Economy	9800.00
0005432304448	12967	Economy	9800.00
0005435042866	12967	Economy	9800.00
0005435040319	12967	Economy	9800.00
0005435039829	12967	Economy	9800.00
0005435040103	12967	Economy	9800.00
0005434229675	12967	Economy	9800.00
0005432304450	12967	Economy	9800.00
0005435039825	12967	Economy	9800.00
0005435040119	12967	Economy	9800.00
0005435007259	12967	Economy	9800.00
0005435040044	12967	Economy	9800.00
0005435042867	12967	Economy	10800.00
0005435040036	12967	Economy	10800.00
0005434229671	12967	Economy	10800.00
0005435040261	12967	Economy	10800.00
0005434229677	12967	Economy	10800.00
0005435040158	12967	Economy	10800.00
0005435007096	12967	Economy	9800.00
0005435040184	12967	Economy	9800.00
0005435007062	12967	Economy	9800.00
0005435040118	12967	Economy	9800.00
0005435040072	12967	Economy	9800.00
0005435042858	12967	Economy	9800.00
0005435040136	12967	Economy	9800.00
0005435039826	12967	Economy	9800.00
0005435040243	12967	Economy	9800.00
0005435040279	12967	Economy	9800.00
0005435040281	12967	Economy	9800.00
0005435039958	12967	Economy	9800.00
0005435007131	12967	Economy	9800.00
0005435040132	12967	Economy	9800.00
0005435039698	12967	Economy	9800.00
0005435040139	12967	Economy	9800.00
0005434229681	12967	Economy	9800.00
0005435040174	12967	Economy	9800.00
0005435040165	12967	Economy	9800.00
0005434229661	12967	Economy	9800.00
0005435040138	12967	Economy	9800.00
0005434229664	12967	Economy	9800.00
0005435040262	12967	Economy	9800.00
0005435007109	12967	Economy	9800.00
0005432304449	12967	Economy	9800.00
0005435040192	12967	Economy	9800.00
0005435007095	12967	Economy	9800.00
0005434229676	12967	Economy	9800.00
0005435040218	12967	Economy	9800.00
0005435039820	12967	Economy	9800.00
0005435040199	12967	Economy	9800.00
0005434229660	12967	Economy	9800.00
0005435039953	12967	Economy	9800.00
0005435039945	12967	Economy	9800.00
0005435039988	12967	Economy	9800.00
0005435007169	12967	Economy	9800.00
0005435040182	12967	Economy	9800.00
0005434229663	12967	Economy	9800.00
0005435039889	12967	Economy	9800.00
0005435040252	12967	Economy	9800.00
0005435039981	12967	Economy	9800.00
0005435040201	12967	Economy	9800.00
0005434229678	12967	Economy	9800.00
0005435040253	12967	Economy	9800.00
0005435007132	12967	Economy	9800.00
0005434229667	12967	Economy	9800.00
0005435007094	12967	Economy	9800.00
0005435040260	12967	Economy	9800.00
0005435039565	12967	Economy	9800.00
0005435040211	12967	Economy	9800.00
0005435040224	12967	Economy	9800.00
0005434229673	12967	Economy	9800.00
0005434229672	12967	Economy	9800.00
0005435039957	12967	Economy	9800.00
0005434229674	12967	Economy	9800.00
0005434229679	12967	Economy	9800.00
0005435007157	12967	Economy	9800.00
0005435040097	12967	Economy	9800.00
0005435039946	12967	Economy	9800.00
0005435040121	12967	Economy	9800.00
0005435007155	12967	Economy	9800.00
0005435040003	12967	Economy	9800.00
0005435007171	12967	Economy	9800.00
0005435040188	12967	Economy	9800.00
0005435040301	12967	Economy	9800.00
0005435040294	12967	Economy	9800.00
0005435007154	12967	Economy	9800.00
0005435040042	12967	Economy	9800.00
0005435007016	12967	Economy	9800.00
0005435042864	12967	Economy	9800.00
0005435040183	12967	Economy	9800.00
0005435902718	14892	Business	52900.00
0005435902704	14892	Business	52900.00
0005434426964	14892	Business	52900.00
0005434411832	14892	Business	52900.00
0005434426976	14892	Business	52900.00
0005434411831	14892	Business	52900.00
0005435554203	14892	Business	52900.00
0005434426984	14892	Economy	17600.00
0005434426981	14892	Economy	17600.00
0005434426987	14892	Economy	17600.00
0005434426974	14892	Economy	17600.00
0005434426983	14892	Economy	17600.00
0005434426980	14892	Economy	17600.00
0005435902751	14892	Economy	19400.00
0005435902837	14892	Economy	17600.00
0005435902703	14892	Economy	17600.00
0005434426960	14892	Economy	17600.00
0005435902717	14892	Economy	17600.00
0005434426979	14892	Economy	17600.00
0005434426966	14892	Economy	17600.00
0005435902702	14892	Economy	17600.00
0005432188650	14892	Economy	17600.00
0005434426986	14892	Economy	17600.00
0005434426970	14892	Economy	17600.00
0005435902836	14892	Economy	17600.00
0005434411830	14892	Economy	17600.00
0005435902778	14892	Economy	17600.00
0005434426978	14892	Economy	17600.00
0005434426963	14892	Economy	17600.00
0005434426973	14892	Economy	17600.00
0005434426971	14892	Economy	17600.00
0005434426969	14892	Economy	17600.00
0005434411833	14892	Economy	17600.00
0005434426962	14892	Economy	17600.00
0005434426985	14892	Economy	17600.00
0005434426975	14892	Economy	17600.00
0005435902727	14892	Economy	17600.00
0005434426988	14892	Economy	17600.00
0005435902792	14892	Economy	17600.00
0005434426961	14892	Economy	17600.00
0005435902793	14892	Economy	17600.00
0005435902830	14892	Economy	17600.00
0005435554213	14892	Economy	17600.00
0005435902767	14892	Economy	17600.00
0005434426972	14892	Economy	17600.00
0005432188648	14892	Economy	17600.00
0005434426977	14892	Economy	17600.00
0005432188649	14892	Economy	17600.00
0005434426982	14892	Economy	17600.00
0005434426968	14892	Economy	17600.00
0005435902719	14892	Economy	17600.00
0005435902787	14892	Economy	17600.00
0005434426967	14892	Economy	17600.00
0005434426965	14892	Economy	17600.00
0005435554253	20187	Business	52900.00
0005434411798	20187	Business	52900.00
0005434426954	20187	Business	52900.00
0005434426847	20187	Business	52900.00
0005434426736	20187	Business	52900.00
0005434426762	20187	Business	52900.00
0005434426790	20187	Business	52900.00
0005435554255	20187	Business	52900.00
0005435902932	20187	Business	52900.00
0005434426821	20187	Business	52900.00
0005435902940	20187	Business	52900.00
0005434426822	20187	Economy	17600.00
0005432059530	20187	Economy	17600.00
0005435902935	20187	Economy	17600.00
0005434426709	20187	Economy	17600.00
0005434426786	20187	Economy	17600.00
0005434426780	20187	Economy	17600.00
0005434426743	20187	Economy	17600.00
0005434411790	20187	Economy	17600.00
0005435902938	20187	Economy	19400.00
0005434426823	20187	Economy	19400.00
0005434426611	20187	Economy	19400.00
0005434411793	20187	Economy	19400.00
0005435554252	20187	Economy	19400.00
0005434426744	20187	Economy	17600.00
0005435554254	20187	Economy	17600.00
0005435902934	20187	Economy	17600.00
0005434411799	20187	Economy	17600.00
0005434426781	20187	Economy	17600.00
0005435902944	20187	Economy	17600.00
0005435902948	20187	Economy	17600.00
0005435554251	20187	Economy	17600.00
0005434411783	20187	Economy	17600.00
0005435902936	20187	Economy	17600.00
0005434426711	20187	Economy	17600.00
0005434426731	20187	Economy	17600.00
0005435902933	20187	Economy	17600.00
0005435902943	20187	Economy	17600.00
0005435902945	20187	Economy	17600.00
0005434426754	20187	Economy	17600.00
0005434426750	20187	Economy	17600.00
0005434426598	20187	Economy	17600.00
0005434411791	20187	Economy	17600.00
0005434411797	20187	Economy	17600.00
0005434426792	20187	Economy	17600.00
0005435902941	20187	Economy	17600.00
0005435902939	20187	Economy	17600.00
0005434426682	20187	Economy	17600.00
0005434426732	20187	Economy	17600.00
0005434426955	20187	Economy	17600.00
0005432059531	20187	Economy	17600.00
0005435902949	20187	Economy	17600.00
0005434426683	20187	Economy	17600.00
0005434426766	20187	Economy	17600.00
0005434426749	20187	Economy	17600.00
0005434426956	20187	Economy	17600.00
0005434411795	20187	Economy	17600.00
0005434426818	20187	Economy	17600.00
0005434426720	20187	Economy	17600.00
0005435902942	20187	Economy	17600.00
0005434411778	20187	Economy	17600.00
0005435902946	20187	Economy	17600.00
0005435902947	20187	Economy	17600.00
0005434426791	20187	Economy	17600.00
0005435902937	20187	Economy	17600.00
0005434426684	20187	Economy	17600.00
0005434426846	20187	Economy	17600.00
0005434426755	20187	Economy	17600.00
0005434426735	20187	Economy	17600.00
0005434523792	28006	Business	106800.00
0005432462542	28006	Economy	35600.00
0005432462541	28006	Economy	35600.00
0005432462539	28006	Economy	35600.00
0005432462538	28006	Economy	35600.00
0005432462543	28006	Economy	35600.00
0005434523778	28006	Economy	35600.00
0005434523782	28006	Economy	35600.00
0005432462540	28006	Economy	35600.00
0005435982876	26532	Business	18500.00
0005435982873	26532	Business	18500.00
0005434270222	26532	Business	18500.00
0005435982852	26532	Business	18500.00
0005435982893	26532	Business	18500.00
0005435982885	26532	Business	18500.00
0005435982851	26532	Business	18500.00
0005432300336	26532	Business	18500.00
0005435982883	26532	Economy	6200.00
0005433434749	26532	Economy	6200.00
0005435982846	26532	Economy	6200.00
0005435982856	26532	Economy	6200.00
0005435982868	26532	Economy	6200.00
0005435982865	26532	Economy	6200.00
0005433434729	26532	Economy	6200.00
0005435982854	26532	Economy	6200.00
0005435982874	26532	Economy	6200.00
0005435982877	26532	Economy	6800.00
0005435982892	26532	Economy	6800.00
0005433434821	26532	Economy	6800.00
0005433434834	26532	Economy	6200.00
0005435982857	26532	Economy	6200.00
0005433434751	26532	Economy	6200.00
0005432300335	26532	Economy	6200.00
0005433434883	26532	Economy	6200.00
0005433434778	26532	Economy	6200.00
0005433434920	26532	Economy	6200.00
0005433434750	26532	Economy	6200.00
0005435982855	26532	Economy	6200.00
0005435982884	26532	Economy	6200.00
0005435982888	26532	Economy	6200.00
0005433434624	26532	Economy	6200.00
0005435982869	26532	Economy	6200.00
0005435982845	26532	Economy	6200.00
0005433434775	26532	Economy	6200.00
0005435982870	26532	Economy	6200.00
0005435982861	26532	Economy	6200.00
0005433434884	26532	Economy	6200.00
0005435982862	26532	Economy	6200.00
0005435982859	26532	Economy	6200.00
0005433434690	26532	Economy	6200.00
0005435982867	26532	Economy	6200.00
0005435982872	26532	Economy	6200.00
0005433434791	26532	Economy	6200.00
0005435982866	26532	Economy	6200.00
0005435982887	26532	Economy	6200.00
0005432300338	26532	Economy	6200.00
0005433434728	26532	Economy	6200.00
0005433434792	26532	Economy	6200.00
0005433434921	26532	Economy	6200.00
0005435982848	26532	Economy	6200.00
0005433434773	26532	Economy	6200.00
0005432300334	26532	Economy	6200.00
0005435982880	26532	Economy	6200.00
0005435982879	26532	Economy	6200.00
0005435982863	26532	Economy	6200.00
0005435982858	26532	Economy	6200.00
0005435982849	26532	Economy	6200.00
0005433434777	26532	Economy	6200.00
0005435982878	26532	Economy	6200.00
0005433434771	26532	Economy	6200.00
0005435982890	26532	Economy	6200.00
0005435982860	26532	Economy	6200.00
0005435982889	26532	Economy	6200.00
0005435982881	26532	Economy	6200.00
0005435982864	26532	Economy	6200.00
0005435982850	26532	Economy	6200.00
0005433434756	26532	Economy	6200.00
0005435982844	26532	Economy	6200.00
0005433434702	26532	Economy	6200.00
0005433434772	26532	Economy	6200.00
0005435982847	26532	Economy	6200.00
0005433434779	26532	Economy	6200.00
0005432300333	26532	Economy	6200.00
0005433434823	26532	Economy	6200.00
0005433434782	26532	Economy	6200.00
0005435982853	26532	Economy	6200.00
0005435982871	26532	Economy	6200.00
0005435982882	26532	Economy	6200.00
0005435982891	26532	Economy	6200.00
0005435982886	26532	Economy	6200.00
0005434270221	26532	Economy	6200.00
0005432300337	26532	Economy	6200.00
0005435982875	26532	Economy	6200.00
0005433434781	26532	Economy	6200.00
0005433435049	26699	Business	18500.00
0005433435055	26699	Business	18500.00
0005435982534	26699	Business	18500.00
0005435982571	26699	Business	18500.00
0005432051171	26699	Business	18500.00
0005435982361	26699	Business	18500.00
0005435982424	26699	Business	18500.00
0005435982567	26699	Business	18500.00
0005435982493	26699	Business	18500.00
0005433435057	26699	Economy	6200.00
0005433435053	26699	Economy	6200.00
0005435982520	26699	Economy	6200.00
0005434269130	26699	Economy	6200.00
0005435982486	26699	Economy	6200.00
0005434270236	26699	Economy	6200.00
0005434271339	26699	Economy	6200.00
0005435982456	26699	Economy	6200.00
0005433435044	26699	Economy	6800.00
0005435982457	26699	Economy	6800.00
0005435982535	26699	Economy	6800.00
0005433435071	26699	Economy	6800.00
0005433435047	26699	Economy	6200.00
0005435982465	26699	Economy	6200.00
0005435982394	26699	Economy	6200.00
0005433435069	26699	Economy	6200.00
0005433435050	26699	Economy	6200.00
0005433435043	26699	Economy	6200.00
0005433435056	26699	Economy	6200.00
0005435982466	26699	Economy	6200.00
0005435982532	26699	Economy	6200.00
0005435982425	26699	Economy	6200.00
0005435982326	26699	Economy	6200.00
0005433435054	26699	Economy	6200.00
0005435982563	26699	Economy	6200.00
0005435982543	26699	Economy	6200.00
0005434270237	26699	Economy	6200.00
0005435982593	26699	Economy	6200.00
0005435982467	26699	Economy	6200.00
0005433435064	26699	Economy	6200.00
0005433435051	26699	Economy	6200.00
0005433435061	26699	Economy	6200.00
0005435982549	26699	Economy	6200.00
0005435982442	26699	Economy	6200.00
0005433435068	26699	Economy	6200.00
0005435982403	26699	Economy	6200.00
0005435982324	26699	Economy	6200.00
0005435982487	26699	Economy	6200.00
0005435982533	26699	Economy	6200.00
0005435982435	26699	Economy	6200.00
0005435982557	26699	Economy	6200.00
0005435982464	26699	Economy	6200.00
0005433435048	26699	Economy	6200.00
0005435982565	26699	Economy	6200.00
0005435982564	26699	Economy	6200.00
0005435982494	26699	Economy	6200.00
0005434271340	26699	Economy	6200.00
0005433435045	26699	Economy	6200.00
0005435982332	26699	Economy	6200.00
0005434270235	26699	Economy	6200.00
0005434269131	26699	Economy	6200.00
0005433435062	26699	Economy	6200.00
0005433435066	26699	Economy	6200.00
0005433435059	26699	Economy	6200.00
0005435982294	26699	Economy	6200.00
0005435982166	26699	Economy	6200.00
0005435982568	26699	Economy	6200.00
0005433435065	26699	Economy	6200.00
0005435982598	26699	Economy	6200.00
0005432051170	26699	Economy	6200.00
0005433435063	26699	Economy	6200.00
0005435982485	26699	Economy	6200.00
0005433435060	26699	Economy	6200.00
0005432051169	26699	Economy	6200.00
0005435982293	26699	Economy	6200.00
0005433435067	26699	Economy	6200.00
0005435982360	26699	Economy	6200.00
0005433435052	26699	Economy	6200.00
0005433435070	26699	Economy	6200.00
0005433435046	26699	Economy	6200.00
0005435982578	26699	Economy	6200.00
0005433435058	26699	Economy	6200.00
0005433689920	29261	Economy	21000.00
0005433686635	29261	Economy	21000.00
0005433689921	29261	Economy	19100.00
0005433689933	29261	Economy	19100.00
0005433686638	29261	Economy	19100.00
0005433686637	29261	Economy	19100.00
0005433686646	29261	Economy	19100.00
0005433686644	29261	Economy	19100.00
0005433689932	29261	Economy	19100.00
0005433689923	29261	Economy	19100.00
0005433686643	29261	Economy	19100.00
0005433689919	29261	Economy	19100.00
0005433686633	29261	Economy	19100.00
0005433686634	29261	Economy	19100.00
0005433686636	29261	Economy	19100.00
0005433686645	29261	Economy	19100.00
0005433689931	29261	Economy	19100.00
0005432584369	3132	Economy	11100.00
0005432584368	3132	Economy	11100.00
0005432584375	3132	Economy	11100.00
0005432584376	3132	Economy	10100.00
0005432584378	3132	Economy	10100.00
0005432584367	3132	Economy	10100.00
0005432858090	3132	Economy	10100.00
0005432584360	3132	Economy	10100.00
0005432216308	3132	Economy	10100.00
0005432584377	3132	Economy	10100.00
0005432858123	3132	Economy	10100.00
0005432858132	3132	Economy	10100.00
0005432858182	3132	Economy	10100.00
0005432584380	3132	Economy	10100.00
0005432584366	3132	Economy	10100.00
0005432584370	3132	Economy	10100.00
0005432584362	3132	Economy	10100.00
0005432216311	3132	Economy	10100.00
0005432584373	3132	Economy	10100.00
0005432584365	3132	Economy	10100.00
0005432584381	3132	Economy	10100.00
0005432584379	3132	Economy	10100.00
0005432584364	3132	Economy	10100.00
0005432584358	3132	Economy	10100.00
0005432858161	3132	Economy	10100.00
0005432584361	3132	Economy	10100.00
0005432584359	3132	Economy	10100.00
0005432584371	3132	Economy	10100.00
0005432858183	3132	Economy	10100.00
0005432584374	3132	Economy	10100.00
0005432584363	3132	Economy	10100.00
0005432216310	3132	Economy	10100.00
0005432858074	3132	Economy	10100.00
0005432584357	3132	Economy	10100.00
0005432216309	3132	Economy	10100.00
0005432584372	3132	Economy	10100.00
0005432858125	3132	Economy	10100.00
0005432584124	31514	Economy	11100.00
0005432858228	31514	Economy	11100.00
0005432584243	31514	Economy	11100.00
0005432584042	31514	Economy	11100.00
0005432584212	31514	Economy	10100.00
0005432584195	31514	Economy	10100.00
0005432584168	31514	Economy	10100.00
0005432584113	31514	Economy	10100.00
0005432584277	31514	Economy	10100.00
0005432584276	31514	Economy	10100.00
0005432858224	31514	Economy	10100.00
0005432858229	31514	Economy	10100.00
0005432584126	31514	Economy	10100.00
0005432858223	31514	Economy	10100.00
0005432584220	31514	Economy	10100.00
0005432584211	31514	Economy	10100.00
0005432584108	31514	Economy	10100.00
0005432858226	31514	Economy	10100.00
0005432584183	31514	Economy	10100.00
0005432858233	31514	Economy	10100.00
0005432584041	31514	Economy	10100.00
0005432858225	31514	Economy	10100.00
0005432858222	31514	Economy	10100.00
0005432584184	31514	Economy	10100.00
0005432584221	31514	Economy	10100.00
0005432584214	31514	Economy	10100.00
0005432858230	31514	Economy	10100.00
0005432584125	31514	Economy	10100.00
0005432584127	31514	Economy	10100.00
0005432858232	31514	Economy	10100.00
0005432584242	31514	Economy	10100.00
0005432858234	31514	Economy	10100.00
0005432584209	31514	Economy	10100.00
0005432858227	31514	Economy	10100.00
0005432858231	31514	Economy	10100.00
0005434943474	905	Economy	8300.00
0005434943477	905	Economy	7500.00
0005434943471	905	Economy	7500.00
0005433255152	905	Economy	7500.00
0005434943469	905	Economy	7500.00
0005433255134	905	Economy	7500.00
0005433255161	905	Economy	7500.00
0005433255160	905	Economy	7500.00
0005433255147	905	Economy	7500.00
0005434943478	905	Economy	7500.00
0005434943475	905	Economy	7500.00
0005433255151	905	Economy	7500.00
0005434943476	905	Economy	7500.00
0005434943470	905	Economy	7500.00
0005433255162	905	Economy	7500.00
0005434943473	905	Economy	7500.00
0005434943472	905	Economy	7500.00
0005433255190	16244	Economy	8300.00
0005433255191	16244	Economy	7500.00
0005434943439	16244	Economy	7500.00
0005433255189	16244	Economy	7500.00
0005434943385	16244	Economy	7500.00
0005434943392	16244	Economy	7500.00
0005433255192	16244	Economy	7500.00
0005434943374	16244	Economy	7500.00
0005433255193	16244	Economy	7500.00
0005434943429	16244	Economy	7500.00
0005434943405	16244	Economy	7500.00
0005433811643	14378	Economy	4400.00
0005433811638	14378	Economy	4400.00
0005433927517	14378	Economy	4400.00
0005433811634	14378	Economy	4400.00
0005435653597	21762	Business	9800.00
0005435653606	21762	Business	9800.00
0005435653603	21762	Business	9800.00
0005435653602	21762	Business	9800.00
0005433367911	21762	Business	9800.00
0005433367987	21762	Business	9800.00
0005433368037	21762	Business	9800.00
0005433367952	21762	Business	9800.00
0005433368027	21762	Business	9800.00
0005433368045	21762	Business	9800.00
0005433368032	21762	Business	9800.00
0005433368079	21762	Economy	3300.00
0005433367912	21762	Economy	3300.00
0005433368151	21762	Economy	3300.00
0005433367906	21762	Economy	3300.00
0005433367838	21762	Economy	3300.00
0005433368129	21762	Economy	3300.00
0005433368038	21762	Economy	3300.00
0005433368240	21762	Economy	3300.00
0005435653595	21762	Economy	3300.00
0005433368054	21762	Economy	3600.00
0005433367976	21762	Economy	3600.00
0005435653604	21762	Economy	3300.00
0005433367973	21762	Economy	3300.00
0005433368104	21762	Economy	3300.00
0005433368100	21762	Economy	3300.00
0005433368188	21762	Economy	3300.00
0005433368187	21762	Economy	3300.00
0005433368062	21762	Economy	3300.00
0005433367866	21762	Economy	3300.00
0005433368071	21762	Economy	3300.00
0005435653610	21762	Economy	3300.00
0005433368050	21762	Economy	3300.00
0005435653608	21762	Economy	3300.00
0005433368139	21762	Economy	3300.00
0005435653599	21762	Economy	3300.00
0005433368072	21762	Economy	3300.00
0005433367931	21762	Economy	3300.00
0005433368021	21762	Economy	3300.00
0005433368033	21762	Economy	3300.00
0005435653600	21762	Economy	3300.00
0005433367930	21762	Economy	3300.00
0005433367978	21762	Economy	3300.00
0005433367953	21762	Economy	3300.00
0005433368035	21762	Economy	3300.00
0005433367979	21762	Economy	3300.00
0005433368039	21762	Economy	3300.00
0005433368134	21762	Economy	3300.00
0005433367937	21762	Economy	3300.00
0005433368125	21762	Economy	3300.00
0005433367936	21762	Economy	3300.00
0005433367991	21762	Economy	3300.00
0005433368029	21762	Economy	3300.00
0005435653607	21762	Economy	3300.00
0005433367975	21762	Economy	3300.00
0005435653601	21762	Economy	3300.00
0005435653593	21762	Economy	3300.00
0005433368137	21762	Economy	3300.00
0005433368044	21762	Economy	3300.00
0005435653594	21762	Economy	3300.00
0005433368106	21762	Economy	3300.00
0005435653609	21762	Economy	3300.00
0005433368108	21762	Economy	3300.00
0005433368078	21762	Economy	3300.00
0005435653605	21762	Economy	3300.00
0005433367929	21762	Economy	3300.00
0005433368107	21762	Economy	3300.00
0005433368239	21762	Economy	3300.00
0005433368051	21762	Economy	3300.00
0005433368150	21762	Economy	3300.00
0005433368099	21762	Economy	3300.00
0005433368138	21762	Economy	3300.00
0005433367884	21762	Economy	3300.00
0005433368101	21762	Economy	3300.00
0005435653598	21762	Economy	3300.00
0005433368102	21762	Economy	3300.00
0005435653596	21762	Economy	3300.00
0005432667482	9347	Business	186200.00
0005433785432	9347	Business	186200.00
0005433763394	9347	Business	186200.00
0005434151722	9347	Business	186200.00
0005433805846	9347	Business	186200.00
0005433785421	9347	Business	186200.00
0005433785433	9347	Business	186200.00
0005434171114	9347	Business	186200.00
0005433785443	9347	Business	186200.00
0005433763399	9347	Business	186200.00
0005433763392	9347	Business	186200.00
0005433763398	9347	Business	186200.00
0005433785444	9347	Business	186200.00
0005433763395	9347	Economy	68300.00
0005434171149	9347	Economy	68300.00
0005433785423	9347	Economy	68300.00
0005433785435	9347	Economy	62100.00
0005433785445	9347	Economy	62100.00
0005432667480	9347	Economy	62100.00
0005433805838	9347	Economy	62100.00
0005433805841	9347	Economy	62100.00
0005434171079	9347	Economy	62100.00
0005432666416	9347	Economy	62100.00
0005433763393	9347	Economy	62100.00
0005434171159	9347	Economy	62100.00
0005433805839	9347	Economy	62100.00
0005433805845	9347	Economy	62100.00
0005433785440	9347	Economy	62100.00
0005433785427	9347	Economy	62100.00
0005433763402	9347	Economy	62100.00
0005434171115	9347	Economy	62100.00
0005433785434	9347	Economy	62100.00
0005434171158	9347	Economy	62100.00
0005432657491	9347	Economy	62100.00
0005433805844	9347	Economy	62100.00
0005433785438	9347	Economy	62100.00
0005433785447	9347	Economy	62100.00
0005433785428	9347	Economy	62100.00
0005432665302	9347	Economy	62100.00
0005433763403	9347	Economy	62100.00
0005433785431	9347	Economy	62100.00
0005434171151	9347	Economy	62100.00
0005434171080	9347	Economy	62100.00
0005433805837	9347	Economy	62100.00
0005433785439	9347	Economy	62100.00
0005433785442	9347	Economy	62100.00
0005433763401	9347	Economy	62100.00
0005433763397	9347	Economy	62100.00
0005433785424	9347	Economy	62100.00
0005433785414	9347	Economy	62100.00
0005434171075	9347	Economy	62100.00
0005433785448	9347	Economy	62100.00
0005433805833	9347	Economy	62100.00
0005433805823	9347	Economy	62100.00
0005434273088	9347	Economy	62100.00
0005433805827	9347	Economy	62100.00
0005433805826	9347	Economy	62100.00
0005433805842	9347	Economy	62100.00
0005433785411	9347	Economy	62100.00
0005433785413	9347	Economy	62100.00
0005433785436	9347	Economy	68300.00
0005433785446	9347	Economy	68300.00
0005432667481	9347	Economy	68300.00
0005433785426	9347	Economy	62100.00
0005432657490	9347	Economy	62100.00
0005433785425	9347	Economy	62100.00
0005433805828	9347	Economy	62100.00
0005434171102	9347	Economy	62100.00
0005433805829	9347	Economy	62100.00
0005433805836	9347	Economy	62100.00
0005433785419	9347	Economy	62100.00
0005434171150	9347	Economy	62100.00
0005433805830	9347	Economy	62100.00
0005432666415	9347	Economy	62100.00
0005434171168	9347	Economy	62100.00
0005434270219	9347	Economy	62100.00
0005433785441	9347	Economy	62100.00
0005433763396	9347	Economy	62100.00
0005433763400	9347	Economy	62100.00
0005434151721	9347	Economy	62100.00
0005433785416	9347	Economy	62100.00
0005433785412	9347	Economy	62100.00
0005433805835	9347	Economy	62100.00
0005433763405	9347	Economy	62100.00
0005433805832	9347	Economy	62100.00
0005433785420	9347	Economy	62100.00
0005433785422	9347	Economy	62100.00
0005433805824	9347	Economy	62100.00
0005433785418	9347	Economy	62100.00
0005433763404	9347	Economy	62100.00
0005433785429	9347	Economy	62100.00
0005433763406	9347	Economy	62100.00
0005433805840	9347	Economy	62100.00
0005433785430	9347	Economy	62100.00
0005433805843	9347	Economy	62100.00
0005433805831	9347	Economy	62100.00
0005433805825	9347	Economy	62100.00
0005433785417	9347	Economy	62100.00
0005433785437	9347	Economy	62100.00
0005433805834	9347	Economy	62100.00
0005433785415	9347	Economy	62100.00
0005434171239	26251	Business	186200.00
0005433784784	26251	Business	186200.00
0005432666397	26251	Business	186200.00
0005433805463	26251	Business	186200.00
0005433805501	26251	Business	186200.00
0005432659714	26251	Business	186200.00
0005434171246	26251	Business	186200.00
0005433805532	26251	Business	186200.00
0005434171244	26251	Business	186200.00
0005433763294	26251	Business	186200.00
0005433785165	26251	Business	186200.00
0005432663051	26251	Business	186200.00
0005434171245	26251	Business	186200.00
0005435269859	26251	Business	186200.00
0005434271338	26251	Business	186200.00
0005432659721	26251	Business	186200.00
0005433805531	26251	Business	186200.00
0005433763295	26251	Business	186200.00
0005433805528	26251	Economy	68300.00
0005433785137	26251	Economy	68300.00
0005432657454	26251	Economy	62100.00
0005433763273	26251	Economy	62100.00
0005434171243	26251	Economy	62100.00
0005434171252	26251	Economy	62100.00
0005433763265	26251	Economy	62100.00
0005434171251	26251	Economy	62100.00
0005433785013	26251	Economy	62100.00
0005433763225	26251	Economy	62100.00
0005433805604	26251	Economy	62100.00
0005433785221	26251	Economy	62100.00
0005435269861	26251	Economy	62100.00
0005434171248	26251	Economy	62100.00
0005433785252	26251	Economy	62100.00
0005433785186	26251	Economy	62100.00
0005433785022	26251	Economy	62100.00
0005433785122	26251	Economy	62100.00
0005433805435	26251	Economy	62100.00
0005434151741	26251	Economy	62100.00
0005434269129	26251	Economy	62100.00
0005435269855	26251	Economy	62100.00
0005433785204	26251	Economy	62100.00
0005433805421	26251	Economy	62100.00
0005434171249	26251	Economy	62100.00
0005432659713	26251	Economy	62100.00
0005433763226	26251	Economy	62100.00
0005433805607	26251	Economy	62100.00
0005433785253	26251	Economy	62100.00
0005435269858	26251	Economy	62100.00
0005433785207	26251	Economy	62100.00
0005433785076	26251	Economy	62100.00
0005433785039	26251	Economy	62100.00
0005433805523	26251	Economy	62100.00
0005434270231	26251	Economy	62100.00
0005434171237	26251	Economy	62100.00
0005433805606	26251	Economy	62100.00
0005433785107	26251	Economy	62100.00
0005435269863	26251	Economy	62100.00
0005434270232	26251	Economy	62100.00
0005432657466	26251	Economy	62100.00
0005433805444	26251	Economy	62100.00
0005433785154	26251	Economy	62100.00
0005433763309	26251	Economy	62100.00
0005434171250	26251	Economy	62100.00
0005435269856	26251	Economy	62100.00
0005433785168	26251	Economy	62100.00
0005433805508	26251	Economy	62100.00
0005432666398	26251	Economy	62100.00
0005433785093	26251	Economy	62100.00
0005435269866	26251	Economy	62100.00
0005434171242	26251	Economy	62100.00
0005433784783	26251	Economy	62100.00
0005434271337	26251	Economy	62100.00
0005433785257	26251	Economy	62100.00
0005433763270	26251	Economy	62100.00
0005433805605	26251	Economy	62100.00
0005433805445	26251	Economy	62100.00
0005433805566	26251	Economy	62100.00
0005433805524	26251	Economy	68300.00
0005434171241	26251	Economy	62100.00
0005432657453	26251	Economy	68300.00
0005433805516	26251	Economy	62100.00
0005435269862	26251	Economy	62100.00
0005434270234	26251	Economy	62100.00
0005433763269	26251	Economy	62100.00
0005435269868	26251	Economy	62100.00
0005434151743	26251	Economy	62100.00
0005433763272	26251	Economy	62100.00
0005433785254	26251	Economy	62100.00
0005434151742	26251	Economy	62100.00
0005433785010	26251	Economy	62100.00
0005433763308	26251	Economy	62100.00
0005433763248	26251	Economy	62100.00
0005435269865	26251	Economy	62100.00
0005433805562	26251	Economy	62100.00
0005433805547	26251	Economy	62100.00
0005432659720	26251	Economy	62100.00
0005433784982	26251	Economy	62100.00
0005435269857	26251	Economy	62100.00
0005433785205	26251	Economy	62100.00
0005434171247	26251	Economy	62100.00
0005433785189	26251	Economy	62100.00
0005433805455	26251	Economy	62100.00
0005435269864	26251	Economy	62100.00
0005432666392	26251	Economy	62100.00
0005433805497	26251	Economy	62100.00
0005433785015	26251	Economy	62100.00
0005432666385	26251	Economy	62100.00
0005433785206	26251	Economy	62100.00
0005433805559	26251	Economy	62100.00
0005433805551	26251	Economy	62100.00
0005433785237	26251	Economy	62100.00
0005433763282	26251	Economy	62100.00
0005435269860	26251	Economy	62100.00
0005434171240	26251	Economy	62100.00
0005433785197	26251	Economy	62100.00
0005434270233	26251	Economy	62100.00
0005433785040	26251	Economy	62100.00
0005433805622	26251	Economy	62100.00
0005433785078	26251	Economy	62100.00
0005433805434	26251	Economy	62100.00
0005433805449	26251	Economy	62100.00
0005433805542	26251	Economy	62100.00
0005432666393	26251	Economy	62100.00
0005434171238	26251	Economy	62100.00
0005435269867	26251	Economy	62100.00
0005433785180	26251	Economy	62100.00
0005433805563	26251	Economy	62100.00
0005433785153	26251	Economy	62100.00
0005433785068	26251	Economy	62100.00
0005433805669	26251	Economy	62100.00
0005435929654	4897	Economy	5900.00
0005435135734	4897	Economy	5300.00
0005435929655	4897	Economy	5300.00
0005435929664	4897	Economy	5300.00
0005435135737	4897	Economy	5300.00
0005435929653	4897	Economy	5300.00
0005435929656	4897	Economy	5300.00
0005435135736	4897	Economy	5300.00
0005435929663	4897	Economy	5300.00
0005435135733	4897	Economy	5300.00
0005435135735	4897	Economy	5300.00
0005435135683	33013	Economy	5900.00
0005435929680	33013	Economy	5300.00
0005435929679	33013	Economy	5300.00
0005435135690	33013	Economy	5300.00
0005435135682	33013	Economy	5300.00
0005435929678	33013	Economy	5300.00
0005435135711	33013	Economy	5300.00
0005434983357	9512	Economy	19700.00
0005434983354	9512	Economy	17900.00
0005434983359	9512	Economy	17900.00
0005434983358	9512	Economy	17900.00
0005434217985	9512	Economy	17900.00
0005434217984	9512	Economy	17900.00
0005434218001	9512	Economy	17900.00
0005434983353	9512	Economy	17900.00
0005434217991	9512	Economy	17900.00
0005434983356	9512	Economy	17900.00
0005434983355	9512	Economy	17900.00
0005434218025	27379	Economy	17900.00
0005434983309	27379	Economy	17900.00
0005434218021	27379	Economy	17900.00
0005434983308	27379	Economy	17900.00
0005434218022	27379	Economy	17900.00
0005434983310	27379	Economy	17900.00
0005434218024	27379	Economy	17900.00
0005434218026	27379	Economy	17900.00
0005434218027	27379	Economy	17900.00
0005434218023	27379	Economy	17900.00
0005433961021	24277	Business	36400.00
0005433986018	24277	Business	36400.00
0005433985908	24277	Business	36400.00
0005433960872	24277	Business	36400.00
0005433986036	24277	Business	36400.00
0005433986111	24277	Business	36400.00
0005433960729	24277	Business	36400.00
0005433986038	24277	Business	36400.00
0005433961036	24277	Business	36400.00
0005433960988	24277	Business	36400.00
0005433986042	24277	Business	36400.00
0005433986291	24277	Business	36400.00
0005433985967	24277	Business	36400.00
0005433960960	24277	Economy	13400.00
0005433986211	24277	Business	36400.00
0005433961164	24277	Economy	13400.00
0005433985964	24277	Economy	13400.00
0005433961118	24277	Economy	13400.00
0005433960887	24277	Economy	12100.00
0005433960942	24277	Economy	12100.00
0005433960929	24277	Economy	12100.00
0005433961048	24277	Economy	12100.00
0005433986084	24277	Economy	12100.00
0005433986100	24277	Economy	12100.00
0005433986337	24277	Economy	12100.00
0005433961047	24277	Economy	12100.00
0005433986212	24277	Economy	12100.00
0005433961001	24277	Economy	12100.00
0005433986263	24277	Economy	12100.00
0005433986171	24277	Economy	12100.00
0005433961032	24277	Economy	12100.00
0005433986185	24277	Economy	12100.00
0005433986228	24277	Economy	12100.00
0005433961117	24277	Economy	12100.00
0005433986213	24277	Economy	12100.00
0005433986085	24277	Economy	12100.00
0005433961161	24277	Economy	12100.00
0005433986122	24277	Economy	12100.00
0005433986081	24277	Economy	12100.00
0005433986145	24277	Economy	12100.00
0005433961035	24277	Economy	12100.00
0005433986240	24277	Economy	12100.00
0005433986035	24277	Economy	12100.00
0005433961162	24277	Economy	12100.00
0005433961052	24277	Economy	12100.00
0005433960895	24277	Economy	12100.00
0005433986017	24277	Economy	12100.00
0005433985981	24277	Economy	12100.00
0005433986180	24277	Economy	12100.00
0005433985909	24277	Economy	12100.00
0005433961010	24277	Economy	12100.00
0005433960927	24277	Economy	12100.00
0005433986198	24277	Economy	12100.00
0005433961108	24277	Economy	12100.00
0005433960832	24277	Economy	12100.00
0005433961143	24277	Economy	12100.00
0005433960825	24277	Economy	12100.00
0005433961155	24277	Economy	12100.00
0005433960781	24277	Economy	12100.00
0005433961146	24277	Economy	12100.00
0005433960928	24277	Economy	12100.00
0005433960970	24277	Economy	12100.00
0005433960728	24277	Economy	12100.00
0005433961000	24277	Economy	12100.00
0005433986250	24277	Economy	12100.00
0005433985913	24277	Economy	12100.00
0005433960917	24277	Economy	12100.00
0005433986069	24277	Economy	12100.00
0005433961038	24277	Economy	12100.00
0005433986248	24277	Economy	12100.00
0005433961037	24277	Economy	12100.00
0005433986230	24277	Economy	12100.00
0005433985797	24277	Economy	12100.00
0005433960919	24277	Economy	12100.00
0005433960943	24277	Economy	12100.00
0005433986043	24277	Economy	12100.00
0005433986032	24277	Economy	12100.00
0005433960918	24277	Economy	12100.00
0005433986191	24277	Economy	12100.00
0005433961053	24277	Economy	12100.00
0005433986127	24277	Economy	12100.00
0005433986187	24277	Economy	12100.00
0005433961102	24277	Economy	12100.00
0005433960999	24277	Economy	12100.00
0005433986237	24277	Economy	12100.00
0005433961182	24277	Economy	12100.00
0005433985903	24277	Economy	12100.00
0005433961173	24277	Economy	12100.00
0005433961070	24277	Economy	12100.00
0005433960916	24277	Economy	12100.00
0005433960980	24277	Economy	12100.00
0005433961014	24277	Economy	12100.00
0005433986247	24277	Economy	12100.00
0005433986210	24277	Economy	12100.00
0005433986094	24277	Economy	12100.00
0005433986186	24277	Economy	12100.00
0005433986197	24277	Economy	12100.00
0005433986226	24277	Economy	12100.00
0005433986249	24277	Economy	12100.00
0005433960941	24277	Economy	12100.00
0005433960959	24277	Economy	12100.00
0005433986170	24277	Economy	12100.00
0005433961157	24277	Economy	12100.00
0005433986205	24277	Economy	12100.00
0005433961174	24277	Economy	12100.00
0005433986051	24277	Economy	12100.00
0005433985904	24277	Economy	12100.00
0005433960967	24277	Economy	12100.00
0005433986188	24277	Economy	12100.00
0005433985963	24277	Economy	12100.00
0005433986227	24277	Economy	12100.00
0005433961022	24277	Economy	12100.00
0005433985914	24277	Economy	12100.00
0005433986099	24277	Economy	12100.00
0005433986238	24277	Economy	12100.00
0005433986385	24277	Economy	12100.00
0005433960989	24277	Economy	12100.00
0005433960961	24277	Economy	12100.00
0005433961124	24277	Economy	12100.00
0005433986083	24277	Economy	12100.00
0005433961156	24277	Economy	12100.00
0005433960870	24277	Economy	12100.00
0005433961006	24277	Economy	12100.00
0005433961172	24277	Economy	12100.00
0005433986516	25946	Business	36400.00
0005433961551	25946	Business	36400.00
0005433986508	25946	Business	36400.00
0005433986532	25946	Business	36400.00
0005433961582	25946	Business	36400.00
0005433986547	25946	Business	36400.00
0005433986545	25946	Business	36400.00
0005433986531	25946	Business	36400.00
0005433961536	25946	Business	36400.00
0005433986520	25946	Business	36400.00
0005433986506	25946	Business	36400.00
0005433961577	25946	Business	36400.00
0005433961586	25946	Economy	13400.00
0005433986514	25946	Economy	13400.00
0005433961575	25946	Economy	12100.00
0005433986509	25946	Economy	12100.00
0005433961569	25946	Economy	12100.00
0005433961563	25946	Economy	12100.00
0005433961554	25946	Economy	12100.00
0005433986542	25946	Economy	12100.00
0005433986510	25946	Economy	12100.00
0005433986519	25946	Economy	12100.00
0005433986528	25946	Economy	12100.00
0005433961580	25946	Economy	12100.00
0005433961540	25946	Economy	12100.00
0005433986533	25946	Economy	12100.00
0005433986546	25946	Economy	12100.00
0005433961564	25946	Economy	12100.00
0005433961568	25946	Economy	12100.00
0005433961552	25946	Economy	12100.00
0005433961549	25946	Economy	12100.00
0005433961546	25946	Economy	12100.00
0005433986525	25946	Economy	12100.00
0005433986507	25946	Economy	12100.00
0005433961534	25946	Economy	12100.00
0005433986534	25946	Economy	12100.00
0005433986537	25946	Economy	12100.00
0005433961535	25946	Economy	12100.00
0005433986526	25946	Economy	12100.00
0005433986535	25946	Economy	12100.00
0005433961545	25946	Economy	12100.00
0005433961533	25946	Economy	12100.00
0005433986518	25946	Economy	12100.00
0005433986515	25946	Economy	12100.00
0005433961576	25946	Economy	12100.00
0005433961588	25946	Economy	12100.00
0005433961579	25946	Economy	12100.00
0005433961587	25946	Economy	12100.00
0005433986522	25946	Economy	12100.00
0005433961542	25946	Economy	12100.00
0005433961561	25946	Economy	12100.00
0005433961565	25946	Economy	12100.00
0005433961557	25946	Economy	12100.00
0005433986539	25946	Economy	12100.00
0005433961570	25946	Economy	12100.00
0005433986536	25946	Economy	12100.00
0005433986511	25946	Economy	12100.00
0005433961538	25946	Economy	13400.00
0005433986517	25946	Economy	12100.00
0005433986538	25946	Economy	12100.00
0005433961566	25946	Economy	13400.00
0005433986512	25946	Economy	12100.00
0005433961543	25946	Economy	12100.00
0005433961547	25946	Economy	12100.00
0005433961532	25946	Economy	12100.00
0005433961578	25946	Economy	12100.00
0005433961574	25946	Economy	12100.00
0005433961550	25946	Economy	12100.00
0005433961556	25946	Economy	12100.00
0005433961571	25946	Economy	12100.00
0005433961581	25946	Economy	12100.00
0005433961560	25946	Economy	12100.00
0005433961590	25946	Economy	12100.00
0005433986530	25946	Economy	12100.00
0005433961559	25946	Economy	12100.00
0005433986521	25946	Economy	12100.00
0005433961544	25946	Economy	12100.00
0005433986524	25946	Economy	12100.00
0005433961572	25946	Economy	12100.00
0005433961589	25946	Economy	12100.00
0005433986527	25946	Economy	12100.00
0005433961562	25946	Economy	12100.00
0005433961541	25946	Economy	12100.00
0005433961537	25946	Economy	12100.00
0005433961584	25946	Economy	12100.00
0005433986540	25946	Economy	12100.00
0005433961585	25946	Economy	12100.00
0005433961583	25946	Economy	12100.00
0005433961558	25946	Economy	12100.00
0005433986529	25946	Economy	12100.00
0005433961553	25946	Economy	12100.00
0005433986543	25946	Economy	12100.00
0005433986544	25946	Economy	12100.00
0005433986523	25946	Economy	12100.00
0005433961567	25946	Economy	12100.00
0005433961573	25946	Economy	12100.00
0005433961591	25946	Economy	12100.00
0005433961539	25946	Economy	12100.00
0005433986513	25946	Economy	12100.00
0005433961548	25946	Economy	12100.00
0005433986541	25946	Economy	12100.00
0005433961555	25946	Economy	12100.00
0005433165940	972	Economy	25400.00
0005432269533	972	Economy	25400.00
0005433165929	972	Economy	25400.00
0005434480674	972	Economy	25400.00
0005434480675	972	Economy	23100.00
0005434480664	972	Economy	23100.00
0005434480667	972	Economy	23100.00
0005434480657	972	Economy	23100.00
0005434480663	972	Economy	23100.00
0005434480671	972	Economy	23100.00
0005434480660	972	Economy	23100.00
0005434480668	972	Economy	23100.00
0005434480673	972	Economy	23100.00
0005433165988	972	Economy	23100.00
0005434480669	972	Economy	23100.00
0005433165953	972	Economy	23100.00
0005434480661	972	Economy	23100.00
0005434480672	972	Economy	23100.00
0005434480655	972	Economy	23100.00
0005433165928	972	Economy	23100.00
0005434480676	972	Economy	23100.00
0005434480654	972	Economy	23100.00
0005433165999	972	Economy	23100.00
0005434480666	972	Economy	23100.00
0005434480659	972	Economy	23100.00
0005434480665	972	Economy	23100.00
0005434480656	972	Economy	23100.00
0005434480658	972	Economy	23100.00
0005433166012	972	Economy	23100.00
0005433165960	972	Economy	23100.00
0005432269531	972	Economy	23100.00
0005434480662	972	Economy	23100.00
0005433165961	972	Economy	23100.00
0005434480670	972	Economy	23100.00
0005432269532	972	Economy	23100.00
0005433165962	972	Economy	23100.00
0005433166079	16573	Economy	25400.00
0005434480506	16573	Economy	25400.00
0005434480507	16573	Economy	25400.00
0005434480475	16573	Economy	23100.00
0005433166074	16573	Economy	23100.00
0005433166077	16573	Economy	23100.00
0005434480447	16573	Economy	23100.00
0005434480554	16573	Economy	23100.00
0005434480495	16573	Economy	23100.00
0005433166078	16573	Economy	23100.00
0005434480398	16573	Economy	23100.00
0005433166073	16573	Economy	23100.00
0005433166082	16573	Economy	23100.00
0005434480444	16573	Economy	23100.00
0005434480443	16573	Economy	23100.00
0005434480617	16573	Economy	23100.00
0005433166072	16573	Economy	23100.00
0005434480431	16573	Economy	23100.00
0005434480469	16573	Economy	23100.00
0005434480439	16573	Economy	23100.00
0005434480508	16573	Economy	23100.00
0005434480616	16573	Economy	23100.00
0005434480372	16573	Economy	23100.00
0005434480445	16573	Economy	23100.00
0005434480474	16573	Economy	23100.00
0005433166075	16573	Economy	23100.00
0005434480365	16573	Economy	23100.00
0005433166076	16573	Economy	23100.00
0005434480477	16573	Economy	23100.00
0005433166081	16573	Economy	23100.00
0005434480420	16573	Economy	23100.00
0005434480505	16573	Economy	23100.00
0005434480494	16573	Economy	23100.00
0005434480476	16573	Economy	23100.00
0005433166071	16573	Economy	23100.00
0005434480553	16573	Economy	23100.00
0005433166080	16573	Economy	23100.00
0005434480427	16573	Economy	23100.00
0005434480430	16573	Economy	23100.00
0005433872532	3209	Economy	19000.00
0005433872531	3209	Economy	17200.00
0005433872527	3209	Economy	17200.00
0005433872528	3209	Economy	17200.00
0005433872533	3209	Economy	17200.00
0005433872530	3209	Economy	17200.00
0005433872529	3209	Economy	17200.00
0005433872496	32549	Economy	19000.00
0005433872501	32549	Economy	17200.00
0005433872492	32549	Economy	17200.00
0005433872493	32549	Economy	17200.00
0005433872502	32549	Economy	17200.00
0005435150202	10320	Economy	17000.00
0005433289861	10320	Economy	17000.00
0005433289853	10320	Economy	17000.00
0005435386604	10320	Economy	17000.00
0005435142744	10320	Economy	15400.00
0005435386617	10320	Economy	15400.00
0005435150196	10320	Economy	15400.00
0005433289892	10320	Economy	15400.00
0005435386580	10320	Economy	15400.00
0005435142738	10320	Economy	15400.00
0005433289860	10320	Economy	15400.00
0005435386603	10320	Economy	15400.00
0005435150194	10320	Economy	15400.00
0005435150204	10320	Economy	15400.00
0005433289846	10320	Economy	15400.00
0005435142745	10320	Economy	15400.00
0005435150201	10320	Economy	15400.00
0005435142740	10320	Economy	15400.00
0005435150205	10320	Economy	15400.00
0005435150203	10320	Economy	15400.00
0005435142742	10320	Economy	15400.00
0005435386602	10320	Economy	15400.00
0005435150199	10320	Economy	15400.00
0005435142750	10320	Economy	15400.00
0005435142748	10320	Economy	15400.00
0005435150198	10320	Economy	15400.00
0005435142746	10320	Economy	15400.00
0005433289864	10320	Economy	15400.00
0005435150197	10320	Economy	15400.00
0005435142749	10320	Economy	15400.00
0005435150193	10320	Economy	15400.00
0005435150206	10320	Economy	15400.00
0005435142739	10320	Economy	15400.00
0005435386621	10320	Economy	15400.00
0005435142747	10320	Economy	15400.00
0005435142743	10320	Economy	15400.00
0005435142741	10320	Economy	15400.00
0005435150200	10320	Economy	15400.00
0005435150195	10320	Economy	15400.00
0005433289953	21952	Economy	17000.00
0005435150066	21952	Economy	17000.00
0005435150064	21952	Economy	15400.00
0005435386652	21952	Economy	15400.00
0005435142607	21952	Economy	15400.00
0005435142634	21952	Economy	15400.00
0005435142576	21952	Economy	15400.00
0005435142633	21952	Economy	15400.00
0005435150067	21952	Economy	15400.00
0005435142662	21952	Economy	15400.00
0005435386656	21952	Economy	15400.00
0005435386653	21952	Economy	15400.00
0005433289948	21952	Economy	15400.00
0005435386655	21952	Economy	15400.00
0005435150055	21952	Economy	15400.00
0005433289950	21952	Economy	15400.00
0005435150030	21952	Economy	15400.00
0005435386651	21952	Economy	15400.00
0005435386658	21952	Economy	15400.00
0005435386657	21952	Economy	15400.00
0005435142661	21952	Economy	15400.00
0005435142575	21952	Economy	15400.00
0005435150041	21952	Economy	15400.00
0005435150063	21952	Economy	15400.00
0005435142627	21952	Economy	15400.00
0005435142689	21952	Economy	15400.00
0005435386654	21952	Economy	15400.00
0005435150040	21952	Economy	15400.00
0005435150143	21952	Economy	15400.00
0005435142623	21952	Economy	15400.00
0005435150105	21952	Economy	15400.00
0005435142608	21952	Economy	15400.00
0005433289951	21952	Economy	15400.00
0005435142658	21952	Economy	15400.00
0005435142635	21952	Economy	15400.00
0005435142688	21952	Economy	15400.00
0005433289952	21952	Economy	15400.00
0005433289949	21952	Economy	15400.00
0005435150103	21952	Economy	15400.00
0005435150104	21952	Economy	15400.00
0005435142655	21952	Economy	15400.00
0005435150126	21952	Economy	15400.00
0005435502327	11218	Business	57200.00
0005434573528	11218	Business	57200.00
0005435529434	11218	Business	57200.00
0005435502443	11218	Business	57200.00
0005435545767	11218	Business	57200.00
0005435502337	11218	Business	57200.00
0005435529390	11218	Business	57200.00
0005434573526	11218	Business	57200.00
0005434573531	11218	Business	57200.00
0005435502465	11218	Business	57200.00
0005435502333	11218	Business	57200.00
0005435319648	11218	Economy	19100.00
0005434573520	11218	Economy	19100.00
0005435529301	11218	Economy	19100.00
0005435502473	11218	Economy	19100.00
0005434573530	11218	Economy	19100.00
0005434573521	11218	Economy	19100.00
0005435502334	11218	Economy	21000.00
0005435319614	11218	Economy	21000.00
0005435502472	11218	Economy	21000.00
0005435529433	11218	Economy	21000.00
0005435502380	11218	Economy	19100.00
0005435502453	11218	Economy	19100.00
0005435529313	11218	Economy	19100.00
0005435529314	11218	Economy	19100.00
0005435502456	11218	Economy	19100.00
0005435502468	11218	Economy	19100.00
0005435319610	11218	Economy	19100.00
0005435502421	11218	Economy	19100.00
0005435502351	11218	Economy	19100.00
0005435319602	11218	Economy	19100.00
0005435502506	11218	Economy	19100.00
0005435529404	11218	Economy	19100.00
0005435529370	11218	Economy	19100.00
0005434573527	11218	Economy	19100.00
0005434573532	11218	Economy	19100.00
0005435502350	11218	Economy	19100.00
0005435319613	11218	Economy	19100.00
0005435502457	11218	Economy	19100.00
0005435502466	11218	Economy	19100.00
0005435502507	11218	Economy	19100.00
0005434573523	11218	Economy	19100.00
0005435502493	11218	Economy	19100.00
0005434573522	11218	Economy	19100.00
0005435529399	11218	Economy	19100.00
0005435529403	11218	Economy	19100.00
0005435502336	11218	Economy	19100.00
0005435502379	11218	Economy	19100.00
0005434573529	11218	Economy	19100.00
0005435529372	11218	Economy	19100.00
0005435529338	11218	Economy	19100.00
0005435502492	11218	Economy	19100.00
0005434573525	11218	Economy	19100.00
0005435529401	11218	Economy	19100.00
0005435502458	11218	Economy	19100.00
0005435529371	11218	Economy	19100.00
0005435319647	11218	Economy	19100.00
0005435529331	11218	Economy	19100.00
0005435502439	11218	Economy	19100.00
0005434573534	11218	Economy	19100.00
0005434573533	11218	Economy	19100.00
0005435529353	11218	Economy	19100.00
0005435319568	11218	Economy	19100.00
0005435529491	11218	Economy	19100.00
0005435502392	11218	Economy	19100.00
0005435502440	11218	Economy	19100.00
0005435529402	11218	Economy	19100.00
0005434573524	11218	Economy	19100.00
0005435529412	11218	Economy	19100.00
0005435502391	11218	Economy	19100.00
0005435529349	11218	Economy	19100.00
0005435529411	11218	Economy	19100.00
0005435508498	20937	Business	57200.00
0005435508499	20937	Business	57200.00
0005434573367	20937	Business	57200.00
0005435518138	20937	Business	57200.00
0005435502584	20937	Business	57200.00
0005434573363	20937	Business	57200.00
0005435319697	20937	Business	57200.00
0005435502587	20937	Business	57200.00
0005435518146	20937	Business	57200.00
0005435502586	20937	Business	57200.00
0005435518140	20937	Business	57200.00
0005435319703	20937	Economy	19100.00
0005435518156	20937	Economy	19100.00
0005434573378	20937	Economy	19100.00
0005435508493	20937	Economy	19100.00
0005434573405	20937	Economy	19100.00
0005435508506	20937	Economy	19100.00
0005435319701	20937	Economy	19100.00
0005435502575	20937	Economy	19100.00
0005434573377	20937	Economy	19100.00
0005434573355	20937	Economy	19100.00
0005435518152	20937	Economy	21000.00
0005435502590	20937	Economy	21000.00
0005432291961	20937	Economy	19100.00
0005435518141	20937	Economy	19100.00
0005435502582	20937	Economy	19100.00
0005435518139	20937	Economy	19100.00
0005434573415	20937	Economy	19100.00
0005435518155	20937	Economy	19100.00
0005435508494	20937	Economy	19100.00
0005435518145	20937	Economy	19100.00
0005435319705	20937	Economy	19100.00
0005435502580	20937	Economy	19100.00
0005435502581	20937	Economy	19100.00
0005435518150	20937	Economy	19100.00
0005435518142	20937	Economy	19100.00
0005435518149	20937	Economy	19100.00
0005435502591	20937	Economy	19100.00
0005434573434	20937	Economy	19100.00
0005435518151	20937	Economy	19100.00
0005434573398	20937	Economy	19100.00
0005435502583	20937	Economy	19100.00
0005435502594	20937	Economy	19100.00
0005434573406	20937	Economy	19100.00
0005435319698	20937	Economy	19100.00
0005435508502	20937	Economy	19100.00
0005435508496	20937	Economy	19100.00
0005434573448	20937	Economy	19100.00
0005435508503	20937	Economy	19100.00
0005434573423	20937	Economy	19100.00
0005435518153	20937	Economy	19100.00
0005435502589	20937	Economy	19100.00
0005435508495	20937	Economy	19100.00
0005435508500	20937	Economy	19100.00
0005435502577	20937	Economy	19100.00
0005435518147	20937	Economy	19100.00
0005435319704	20937	Economy	19100.00
0005432291960	20937	Economy	19100.00
0005435518157	20937	Economy	19100.00
0005435502576	20937	Economy	19100.00
0005434573407	20937	Economy	19100.00
0005434573402	20937	Economy	19100.00
0005435508497	20937	Economy	19100.00
0005435518143	20937	Economy	19100.00
0005435508508	20937	Economy	19100.00
0005434573403	20937	Economy	19100.00
0005435502592	20937	Economy	19100.00
0005435508504	20937	Economy	19100.00
0005435502588	20937	Economy	19100.00
0005435518148	20937	Economy	19100.00
0005434573356	20937	Economy	19100.00
0005434573390	20937	Economy	19100.00
0005435502595	20937	Economy	19100.00
0005435502574	20937	Economy	19100.00
0005435319702	20937	Economy	19100.00
0005435518137	20937	Economy	19100.00
0005435319700	20937	Economy	19100.00
0005435502579	20937	Economy	19100.00
0005435518136	20937	Economy	19100.00
0005435518144	20937	Economy	19100.00
0005435319699	20937	Economy	19100.00
0005435319696	20937	Economy	19100.00
0005435518154	20937	Economy	19100.00
0005435508505	20937	Economy	19100.00
0005435502585	20937	Economy	19100.00
0005435502578	20937	Economy	19100.00
0005435502593	20937	Economy	19100.00
0005435508501	20937	Economy	19100.00
0005435508507	20937	Economy	19100.00
0005434573388	20937	Economy	19100.00
0005432693283	2903	Business	10300.00
0005432693254	2903	Business	10300.00
0005432693239	2903	Business	10300.00
0005432693339	2903	Business	10300.00
0005432693198	2903	Business	10300.00
0005432693017	2903	Economy	3400.00
0005432693200	2903	Economy	3400.00
0005432693255	2903	Economy	3400.00
0005432693075	2903	Economy	3400.00
0005432693145	2903	Economy	3800.00
0005432693055	2903	Economy	3400.00
0005432693240	2903	Economy	3400.00
0005432693124	2903	Economy	3400.00
0005432693201	2903	Economy	3400.00
0005432693282	2903	Economy	3400.00
0005432693064	2903	Economy	3400.00
0005432693337	2903	Economy	3400.00
0005432693071	2903	Economy	3400.00
0005432693197	2903	Economy	3400.00
0005432693162	2903	Economy	3400.00
0005432693016	2903	Economy	3400.00
0005432693059	2903	Economy	3400.00
0005432693184	2903	Economy	3400.00
0005432693193	2903	Economy	3400.00
0005432693228	2903	Economy	3400.00
0005432693199	2903	Economy	3400.00
0005432693125	2903	Economy	3400.00
0005432693325	2903	Economy	3400.00
0005432693174	2903	Economy	3400.00
0005432693119	2903	Economy	3400.00
0005432693120	2903	Economy	3400.00
0005432693146	2903	Economy	3400.00
0005432693290	2903	Economy	3400.00
0005432693056	2903	Economy	3400.00
0005432693227	2903	Economy	3400.00
0005432693336	2903	Economy	3400.00
0005432693126	2903	Economy	3400.00
0005432217812	2909	Business	10300.00
0005432707115	2909	Business	10300.00
0005432880909	2909	Business	10300.00
0005432707118	2909	Business	10300.00
0005433124012	2909	Business	10300.00
0005433123996	2909	Business	10300.00
0005432707097	2909	Business	10300.00
0005433123991	2909	Business	10300.00
0005432707110	2909	Business	10300.00
0005432707098	2909	Business	10300.00
0005432880834	2909	Economy	3400.00
0005432880880	2909	Economy	3400.00
0005432707109	2909	Economy	3400.00
0005433124063	2909	Economy	3400.00
0005432707101	2909	Economy	3400.00
0005432707119	2909	Economy	3400.00
0005432707117	2909	Economy	3400.00
0005432707111	2909	Economy	3400.00
0005432880849	2909	Economy	3800.00
0005432880929	2909	Economy	3800.00
0005432880885	2909	Economy	3800.00
0005432707094	2909	Economy	3800.00
0005432880928	2909	Economy	3800.00
0005433194871	2909	Economy	3400.00
0005432880873	2909	Economy	3400.00
0005432707107	2909	Economy	3400.00
0005432880851	2909	Economy	3400.00
0005432880881	2909	Economy	3400.00
0005432880853	2909	Economy	3400.00
0005432880835	2909	Economy	3400.00
0005432707106	2909	Economy	3400.00
0005433123990	2909	Economy	3400.00
0005432880850	2909	Economy	3400.00
0005432880884	2909	Economy	3400.00
0005433124002	2909	Economy	3400.00
0005432707103	2909	Economy	3400.00
0005432707099	2909	Economy	3400.00
0005432880888	2909	Economy	3400.00
0005433124064	2909	Economy	3400.00
0005432880854	2909	Economy	3400.00
0005433124013	2909	Economy	3400.00
0005432880920	2909	Economy	3400.00
0005433123871	2909	Economy	3400.00
0005432217813	2909	Economy	3400.00
0005432880879	2909	Economy	3400.00
0005432880887	2909	Economy	3400.00
0005433123940	2909	Economy	3400.00
0005432880919	2909	Economy	3400.00
0005433123954	2909	Economy	3400.00
0005433194887	2909	Economy	3400.00
0005433194872	2909	Economy	3400.00
0005432707116	2909	Economy	3400.00
0005432707102	2909	Economy	3400.00
0005432707108	2909	Economy	3400.00
0005432707120	2909	Economy	3400.00
0005432707095	2909	Economy	3400.00
0005432707096	2909	Economy	3400.00
0005432707121	2909	Economy	3400.00
0005433123955	2909	Economy	3400.00
0005432707114	2909	Economy	3400.00
0005432217814	2909	Economy	3400.00
0005433124001	2909	Economy	3400.00
0005432707100	2909	Economy	3400.00
0005432880876	2909	Economy	3400.00
0005432707104	2909	Economy	3400.00
0005432707105	2909	Economy	3400.00
0005433123924	2909	Economy	3400.00
0005433123941	2909	Economy	3400.00
0005432707112	2909	Economy	3400.00
0005432707113	2909	Economy	3400.00
0005432693494	30008	Business	10300.00
0005432706798	30008	Business	10300.00
0005432706910	30008	Business	10300.00
0005432693475	30008	Business	10300.00
0005432693486	30008	Business	10300.00
0005433124200	30008	Business	10300.00
0005432881014	30008	Business	10300.00
0005432693481	30008	Business	10300.00
0005432693476	30008	Business	10300.00
0005433124179	30008	Business	10300.00
0005432693491	30008	Business	10300.00
0005432693483	30008	Business	10300.00
0005432706874	30008	Economy	3400.00
0005432706944	30008	Economy	3400.00
0005432693474	30008	Economy	3400.00
0005432881010	30008	Economy	3400.00
0005433124181	30008	Economy	3400.00
0005432693496	30008	Economy	3400.00
0005432706933	30008	Economy	3400.00
0005433124191	30008	Economy	3400.00
0005433124196	30008	Economy	3400.00
0005432693489	30008	Economy	3400.00
0005433124187	30008	Economy	3800.00
0005433124195	30008	Economy	3800.00
0005432706967	30008	Economy	3800.00
0005432693478	30008	Economy	3800.00
0005432693493	30008	Economy	3800.00
0005433194896	30008	Economy	3400.00
0005432693488	30008	Economy	3400.00
0005432693495	30008	Economy	3400.00
0005432881015	30008	Economy	3400.00
0005433124194	30008	Economy	3400.00
0005432693504	30008	Economy	3400.00
0005433194895	30008	Economy	3400.00
0005432881012	30008	Economy	3400.00
0005433124182	30008	Economy	3400.00
0005432693480	30008	Economy	3400.00
0005433124185	30008	Economy	3400.00
0005432706890	30008	Economy	3400.00
0005432881011	30008	Economy	3400.00
0005433194893	30008	Economy	3400.00
0005433124192	30008	Economy	3400.00
0005432706889	30008	Economy	3400.00
0005432693505	30008	Economy	3400.00
0005432706882	30008	Economy	3400.00
0005433124197	30008	Economy	3400.00
0005432693479	30008	Economy	3400.00
0005432881007	30008	Economy	3400.00
0005432706873	30008	Economy	3400.00
0005432706913	30008	Economy	3400.00
0005432693499	30008	Economy	3400.00
0005432706902	30008	Economy	3400.00
0005433124184	30008	Economy	3400.00
0005432706917	30008	Economy	3400.00
0005433194894	30008	Economy	3400.00
0005432693500	30008	Economy	3400.00
0005433124180	30008	Economy	3400.00
0005432881006	30008	Economy	3400.00
0005432693498	30008	Economy	3400.00
0005433124193	30008	Economy	3400.00
0005433124198	30008	Economy	3400.00
0005432706881	30008	Economy	3400.00
0005432706901	30008	Economy	3400.00
0005433124178	30008	Economy	3400.00
0005433124183	30008	Economy	3400.00
0005432693484	30008	Economy	3400.00
0005432693485	30008	Economy	3400.00
0005432881009	30008	Economy	3400.00
0005433124186	30008	Economy	3400.00
0005432693492	30008	Economy	3400.00
0005432881008	30008	Economy	3400.00
0005432693490	30008	Economy	3400.00
0005432693501	30008	Economy	3400.00
0005432693487	30008	Economy	3400.00
0005432693502	30008	Economy	3400.00
0005432881002	30008	Economy	3400.00
0005432706896	30008	Economy	3400.00
0005433124199	30008	Economy	3400.00
0005432693482	30008	Economy	3400.00
0005432706872	30008	Economy	3400.00
0005432881004	30008	Economy	3400.00
0005432706960	30008	Economy	3400.00
0005432693477	30008	Economy	3400.00
0005432881013	30008	Economy	3400.00
0005433124188	30008	Economy	3400.00
0005433194897	30008	Economy	3400.00
0005433124201	30008	Economy	3400.00
0005432693497	30008	Economy	3400.00
0005432693503	30008	Economy	3400.00
0005433194892	30008	Economy	3400.00
0005432881003	30008	Economy	3400.00
0005432706914	30008	Economy	3400.00
0005432881005	30008	Economy	3400.00
0005432693506	30008	Economy	3400.00
0005433124190	30008	Economy	3400.00
0005433124189	30008	Economy	3400.00
0005434980171	23674	Economy	4000.00
0005434980170	23674	Economy	4000.00
0005434980149	23674	Economy	3600.00
0005434988879	23674	Economy	3600.00
0005434980157	23674	Economy	3600.00
0005434980155	23674	Economy	3600.00
0005434988882	23674	Economy	3600.00
0005434988874	23674	Economy	3600.00
0005434988873	23674	Economy	3600.00
0005434980174	23674	Economy	3600.00
0005434980161	23674	Economy	3600.00
0005434980158	23674	Economy	3600.00
0005434980166	23674	Economy	3600.00
0005434988878	23674	Economy	3600.00
0005434980164	23674	Economy	3600.00
0005434980172	23674	Economy	3600.00
0005434980151	23674	Economy	3600.00
0005434980153	23674	Economy	3600.00
0005434988883	23674	Economy	3600.00
0005434988881	23674	Economy	3600.00
0005434988875	23674	Economy	3600.00
0005434988877	23674	Economy	3600.00
0005434980168	23674	Economy	3600.00
0005434988876	23674	Economy	3600.00
0005434980173	23674	Economy	3600.00
0005434980156	23674	Economy	3600.00
0005434988872	23674	Economy	3600.00
0005434980147	23674	Economy	3600.00
0005434988871	23674	Economy	3600.00
0005434980154	23674	Economy	3600.00
0005434980165	23674	Economy	3600.00
0005434980169	23674	Economy	3600.00
0005434988880	23674	Economy	3600.00
0005434980148	23674	Economy	3600.00
0005434980145	23674	Economy	3600.00
0005434980146	23674	Economy	3600.00
0005434980152	23674	Economy	3600.00
0005434980144	23674	Economy	3600.00
0005434980160	23674	Economy	3600.00
0005434980163	23674	Economy	3600.00
0005434988885	23674	Economy	3600.00
0005434980150	23674	Economy	3600.00
0005434980162	23674	Economy	3600.00
0005434980159	23674	Economy	3600.00
0005434980167	23674	Economy	3600.00
0005434988884	23674	Economy	3600.00
0005434979948	27535	Economy	4000.00
0005434988737	27535	Economy	4000.00
0005434979990	27535	Economy	4000.00
0005434979810	27535	Economy	3600.00
0005434988762	27535	Economy	3600.00
0005434979881	27535	Economy	3600.00
0005434979809	27535	Economy	3600.00
0005434979880	27535	Economy	3600.00
0005434979967	27535	Economy	3600.00
0005434979840	27535	Economy	3600.00
0005434979777	27535	Economy	3600.00
0005434979903	27535	Economy	3600.00
0005434979979	27535	Economy	3600.00
0005434979776	27535	Economy	3600.00
0005434979976	27535	Economy	3600.00
0005434980044	27535	Economy	3600.00
0005434979838	27535	Economy	3600.00
0005434988763	27535	Economy	3600.00
0005434988757	27535	Economy	3600.00
0005434988729	27535	Economy	3600.00
0005434979989	27535	Economy	3600.00
0005434979953	27535	Economy	3600.00
0005434979854	27535	Economy	3600.00
0005434979835	27535	Economy	3600.00
0005434979988	27535	Economy	3600.00
0005434980004	27535	Economy	3600.00
0005434980080	27535	Economy	3600.00
0005434979908	27535	Economy	3600.00
0005434979952	27535	Economy	3600.00
0005434979980	27535	Economy	3600.00
0005434988746	27535	Economy	3600.00
0005434979958	27535	Economy	3600.00
0005434988747	27535	Economy	3600.00
0005434979853	27535	Economy	3600.00
0005434979954	27535	Economy	3600.00
0005434979837	27535	Economy	3600.00
0005434988764	27535	Economy	3600.00
0005434979959	27535	Economy	3600.00
0005434988742	27535	Economy	3600.00
0005434979778	27535	Economy	3600.00
0005434979957	27535	Economy	3600.00
0005434979907	27535	Economy	3600.00
0005434980045	27535	Economy	3600.00
0005434988758	27535	Economy	3600.00
0005434979904	27535	Economy	3600.00
0005434979968	27535	Economy	3600.00
0005434979924	27535	Economy	3600.00
0005434979871	27535	Economy	3600.00
0005433111505	10302	Economy	19700.00
0005434302513	10302	Economy	19700.00
0005434302512	10302	Economy	19700.00
0005434302514	10302	Economy	19700.00
0005434302515	10302	Economy	19700.00
0005433111511	10302	Economy	19700.00
0005434302478	19587	Economy	21600.00
0005434302486	19587	Economy	19700.00
0005434302484	19587	Economy	19700.00
0005434302500	19587	Economy	19700.00
0005434302501	19587	Economy	19700.00
0005433113564	19587	Economy	19700.00
0005434302477	19587	Economy	19700.00
0005434302492	19587	Economy	19700.00
0005433113565	19587	Economy	19700.00
0005433113566	19587	Economy	19700.00
0005435069773	3528	Business	26900.00
0005435925378	3528	Business	26900.00
0005435069796	3528	Business	26900.00
0005435069760	3528	Business	26900.00
0005435069781	3528	Business	26900.00
0005435069767	3528	Business	26900.00
0005435069788	3528	Business	26900.00
0005435925326	3528	Business	26900.00
0005435069754	3528	Business	26900.00
0005435069793	3528	Business	26900.00
0005435069774	3528	Economy	9000.00
0005435069759	3528	Economy	9000.00
0005435069770	3528	Economy	9000.00
0005435069756	3528	Economy	9000.00
0005435069800	3528	Economy	9000.00
0005435069779	3528	Economy	9000.00
0005435925401	3528	Economy	9000.00
0005435925384	3528	Economy	9900.00
0005435069755	3528	Economy	9900.00
0005435939879	3528	Economy	9900.00
0005435719014	3528	Economy	9900.00
0005435069765	3528	Economy	9900.00
0005435069775	3528	Economy	9000.00
0005435069798	3528	Economy	9000.00
0005435069797	3528	Economy	9000.00
0005435069782	3528	Economy	9000.00
0005435719015	3528	Economy	9000.00
0005435925341	3528	Economy	9000.00
0005435719016	3528	Economy	9000.00
0005435069751	3528	Economy	9000.00
0005435925343	3528	Economy	9000.00
0005435925327	3528	Economy	9000.00
0005435719019	3528	Economy	9000.00
0005435069783	3528	Economy	9000.00
0005435069784	3528	Economy	9000.00
0005435939880	3528	Economy	9000.00
0005435069766	3528	Economy	9000.00
0005435069792	3528	Economy	9000.00
0005435069763	3528	Economy	9000.00
0005435069786	3528	Economy	9000.00
0005435925385	3528	Economy	9000.00
0005435069764	3528	Economy	9000.00
0005435069768	3528	Economy	9000.00
0005435069778	3528	Economy	9000.00
0005435925454	3528	Economy	9000.00
0005435069749	3528	Economy	9000.00
0005435925371	3528	Economy	9000.00
0005435719013	3528	Economy	9000.00
0005435939890	3528	Economy	9000.00
0005435925455	3528	Economy	9000.00
0005435069777	3528	Economy	9000.00
0005435069772	3528	Economy	9000.00
0005435069758	3528	Economy	9000.00
0005435069761	3528	Economy	9000.00
0005435069791	3528	Economy	9000.00
0005435069787	3528	Economy	9000.00
0005435069750	3528	Economy	9000.00
0005435069780	3528	Economy	9000.00
0005435069762	3528	Economy	9000.00
0005435925344	3528	Economy	9000.00
0005435069790	3528	Economy	9000.00
0005435939894	3528	Economy	9000.00
0005435069771	3528	Economy	9000.00
0005435939888	3528	Economy	9000.00
0005435925375	3528	Economy	9000.00
0005435069753	3528	Economy	9000.00
0005435069785	3528	Economy	9000.00
0005435069752	3528	Economy	9000.00
0005435719017	3528	Economy	9000.00
0005435069789	3528	Economy	9000.00
0005435925342	3528	Economy	9000.00
0005435069794	3528	Economy	9000.00
0005435069776	3528	Economy	9000.00
0005435719018	3528	Economy	9000.00
0005435719011	3528	Economy	9000.00
0005435069795	3528	Economy	9000.00
0005435950297	3528	Economy	9000.00
0005435069799	3528	Economy	9000.00
0005435939893	3528	Economy	9000.00
0005435925379	3528	Economy	9000.00
0005435939889	3528	Economy	9000.00
0005435719012	3528	Economy	9000.00
0005435069769	3528	Economy	9000.00
0005435069757	3528	Economy	9000.00
0005435069036	15277	Business	26900.00
0005435069199	15277	Business	26900.00
0005435069212	15277	Business	26900.00
0005435069175	15277	Business	26900.00
0005435069360	15277	Business	26900.00
0005435069085	15277	Business	26900.00
0005435069172	15277	Business	26900.00
0005435069129	15277	Business	26900.00
0005435069369	15277	Economy	9000.00
0005435069359	15277	Economy	9000.00
0005435069401	15277	Economy	9000.00
0005435069473	15277	Economy	9000.00
0005435069174	15277	Economy	9000.00
0005435069383	15277	Economy	9000.00
0005435069443	15277	Economy	9000.00
0005435069264	15277	Economy	9000.00
0005435069173	15277	Economy	9000.00
0005435069241	15277	Economy	9900.00
0005435069190	15277	Economy	9900.00
0005435069133	15277	Economy	9900.00
0005435069299	15277	Economy	9000.00
0005435069395	15277	Economy	9000.00
0005435069304	15277	Economy	9000.00
0005435069353	15277	Economy	9000.00
0005435925470	15277	Economy	9000.00
0005435069271	15277	Economy	9000.00
0005435069374	15277	Economy	9000.00
0005435069188	15277	Economy	9000.00
0005435069372	15277	Economy	9000.00
0005435069019	15277	Economy	9000.00
0005435069153	15277	Economy	9000.00
0005435069233	15277	Economy	9000.00
0005435069117	15277	Economy	9000.00
0005435069121	15277	Economy	9000.00
0005435069289	15277	Economy	9000.00
0005435069466	15277	Economy	9000.00
0005435925472	15277	Economy	9000.00
0005435069246	15277	Economy	9000.00
0005435069354	15277	Economy	9000.00
0005435069358	15277	Economy	9000.00
0005435069200	15277	Economy	9000.00
0005435069020	15277	Economy	9000.00
0005435069393	15277	Economy	9000.00
0005435069520	15277	Economy	9000.00
0005435069109	15277	Economy	9000.00
0005435069303	15277	Economy	9000.00
0005435069060	15277	Economy	9000.00
0005435069444	15277	Economy	9000.00
0005435069132	15277	Economy	9000.00
0005435069311	15277	Economy	9000.00
0005435069245	15277	Economy	9000.00
0005435069080	15277	Economy	9000.00
0005435069187	15277	Economy	9000.00
0005435069390	15277	Economy	9000.00
0005435068860	15277	Economy	9000.00
0005435925471	15277	Economy	9000.00
0005435069247	15277	Economy	9000.00
0005435069391	15277	Economy	9000.00
0005435069251	15277	Economy	9000.00
0005435069082	15277	Economy	9000.00
0005435925468	15277	Economy	9000.00
0005435069084	15277	Economy	9000.00
0005435925469	15277	Economy	9000.00
0005435069120	15277	Economy	9000.00
0005435069521	15277	Economy	9000.00
0005435069394	15277	Economy	9000.00
0005435069373	15277	Economy	9000.00
0005435069263	15277	Economy	9000.00
0005435069108	15277	Economy	9000.00
0005435069081	15277	Economy	9000.00
0005435069270	15277	Economy	9000.00
0005432658619	18157	Economy	5900.00
0005432660845	18157	Economy	5900.00
0005432659733	18157	Economy	5900.00
0005432658618	18157	Economy	5900.00
0005432660844	18157	Economy	5900.00
0005432659734	18157	Economy	5900.00
0005432660823	26379	Economy	5900.00
0005432664139	26379	Economy	5900.00
0005432660827	26379	Economy	5900.00
0005432667453	26379	Economy	5900.00
0005432901738	47	Business	20000.00
0005432920002	47	Business	20000.00
0005432901723	47	Business	20000.00
0005433102407	47	Business	20000.00
0005433102373	47	Business	20000.00
0005433102384	47	Business	20000.00
0005432901732	47	Business	20000.00
0005432919890	47	Business	20000.00
0005432901697	47	Business	20000.00
0005432901721	47	Business	20000.00
0005433102417	47	Business	20000.00
0005432919986	47	Business	20000.00
0005433102287	47	Business	20000.00
0005433102216	47	Business	20000.00
0005432901720	47	Business	20000.00
0005433102366	47	Business	20000.00
0005432157517	47	Business	20000.00
0005433102370	47	Business	20000.00
0005432901706	47	Business	20000.00
0005433102355	47	Business	20000.00
0005432919889	47	Business	20000.00
0005433102275	47	Business	20000.00
0005433102421	47	Economy	7300.00
0005433102218	47	Economy	7300.00
0005433102217	47	Economy	7300.00
0005433102418	47	Economy	6700.00
0005433102429	47	Economy	6700.00
0005433102288	47	Economy	6700.00
0005432919987	47	Economy	6700.00
0005433102219	47	Economy	6700.00
0005433102383	47	Economy	6700.00
0005432677601	47	Economy	6700.00
0005433102367	47	Economy	6700.00
0005433102339	47	Economy	6700.00
0005433102369	47	Economy	6700.00
0005432919933	47	Economy	6700.00
0005432677590	47	Economy	6700.00
0005433102402	47	Economy	6700.00
0005432919854	47	Economy	6700.00
0005433102274	47	Economy	6700.00
0005433102304	47	Economy	6700.00
0005433102410	47	Economy	6700.00
0005433102434	47	Economy	6700.00
0005432677599	47	Economy	6700.00
0005433102396	47	Economy	6700.00
0005432919935	47	Economy	6700.00
0005432920023	47	Economy	6700.00
0005432920037	47	Economy	6700.00
0005432157518	47	Economy	6700.00
0005433102141	47	Economy	6700.00
0005433102419	47	Economy	6700.00
0005432919985	47	Economy	6700.00
0005433102377	47	Economy	6700.00
0005432677603	47	Economy	6700.00
0005433102277	47	Economy	6700.00
0005432677600	47	Economy	6700.00
0005432920026	47	Economy	6700.00
0005433102395	47	Economy	6700.00
0005432919903	47	Economy	6700.00
0005433102351	47	Economy	6700.00
0005433102354	47	Economy	6700.00
0005433102386	47	Economy	6700.00
0005432901733	47	Economy	7300.00
0005432919978	47	Economy	7300.00
0005432919930	47	Economy	7300.00
0005433102431	47	Economy	6700.00
0005432901669	47	Economy	7300.00
0005432920036	47	Economy	6700.00
0005433102374	47	Economy	6700.00
0005432920025	47	Economy	6700.00
0005432920013	47	Economy	6700.00
0005432901739	47	Economy	6700.00
0005432920035	47	Economy	6700.00
0005433102338	47	Economy	6700.00
0005432901722	47	Economy	6700.00
0005432920004	47	Economy	6700.00
0005433102416	47	Economy	6700.00
0005433102348	47	Economy	6700.00
0005433102259	47	Economy	6700.00
0005432919948	47	Economy	6700.00
0005432677573	47	Economy	6700.00
0005433102401	47	Economy	6700.00
0005432677598	47	Economy	6700.00
0005432919904	47	Economy	6700.00
0005433102432	47	Economy	6700.00
0005432919953	47	Economy	6700.00
0005433102356	47	Economy	6700.00
0005433102303	47	Economy	6700.00
0005433102260	47	Economy	6700.00
0005432919883	47	Economy	6700.00
0005433102435	47	Economy	6700.00
0005432919955	47	Economy	6700.00
0005432919949	47	Economy	6700.00
0005432920012	47	Economy	6700.00
0005432901719	47	Economy	6700.00
0005432919977	47	Economy	6700.00
0005433102276	47	Economy	6700.00
0005433102349	47	Economy	6700.00
0005433102278	47	Economy	6700.00
0005432901698	47	Economy	6700.00
0005432920003	47	Economy	6700.00
0005432919884	47	Economy	6700.00
0005432901757	47	Economy	6700.00
0005433102376	47	Economy	6700.00
0005433102313	47	Economy	6700.00
0005432817852	46	Business	20000.00
0005432817861	46	Business	20000.00
0005432753301	46	Business	20000.00
0005432817870	46	Business	20000.00
0005432817865	46	Business	20000.00
0005432262524	46	Business	20000.00
0005432817858	46	Business	20000.00
0005432207693	46	Business	20000.00
0005432262532	46	Business	20000.00
0005433690930	46	Business	20000.00
0005432262517	46	Business	20000.00
0005432817878	46	Business	20000.00
0005432756851	46	Business	20000.00
0005432262492	46	Business	20000.00
0005432753307	46	Business	20000.00
0005432817874	46	Business	20000.00
0005432817877	46	Business	20000.00
0005432262495	46	Business	20000.00
0005432756852	46	Economy	7300.00
0005432817879	46	Economy	7300.00
0005432817873	46	Economy	7300.00
0005433690932	46	Economy	7300.00
0005432817872	46	Economy	6700.00
0005432207694	46	Economy	6700.00
0005432262510	46	Economy	6700.00
0005432817866	46	Economy	6700.00
0005432753318	46	Economy	6700.00
0005432289030	46	Economy	6700.00
0005432262519	46	Economy	6700.00
0005432817875	46	Economy	6700.00
0005432262514	46	Economy	6700.00
0005432262526	46	Economy	6700.00
0005432817863	46	Economy	6700.00
0005432289031	46	Economy	6700.00
0005432262511	46	Economy	6700.00
0005432262527	46	Economy	6700.00
0005432817850	46	Economy	6700.00
0005432262515	46	Economy	6700.00
0005432817851	46	Economy	6700.00
0005432262502	46	Economy	6700.00
0005432262523	46	Economy	6700.00
0005432817868	46	Economy	6700.00
0005432262531	46	Economy	6700.00
0005432817857	46	Economy	6700.00
0005432262534	46	Economy	6700.00
0005432262521	46	Economy	6700.00
0005432262501	46	Economy	6700.00
0005432262528	46	Economy	6700.00
0005432817853	46	Economy	6700.00
0005432262513	46	Economy	6700.00
0005432262507	46	Economy	6700.00
0005432753302	46	Economy	6700.00
0005432262498	46	Economy	6700.00
0005432262493	46	Economy	6700.00
0005432262497	46	Economy	6700.00
0005432753303	46	Economy	7300.00
0005432262529	46	Economy	7300.00
0005432262535	46	Economy	7300.00
0005432817876	46	Economy	6700.00
0005432262506	46	Economy	6700.00
0005432817867	46	Economy	6700.00
0005432262500	46	Economy	7300.00
0005432262516	46	Economy	6700.00
0005432753304	46	Economy	6700.00
0005432262504	46	Economy	6700.00
0005432817864	46	Economy	6700.00
0005432262509	46	Economy	6700.00
0005432753319	46	Economy	6700.00
0005432262491	46	Economy	6700.00
0005432817856	46	Economy	6700.00
0005432262533	46	Economy	6700.00
0005432817862	46	Economy	6700.00
0005432289028	46	Economy	6700.00
0005433690929	46	Economy	6700.00
0005432262503	46	Economy	6700.00
0005432262525	46	Economy	6700.00
0005432262530	46	Economy	6700.00
0005432262536	46	Economy	6700.00
0005432262505	46	Economy	6700.00
0005432817869	46	Economy	6700.00
0005432262512	46	Economy	6700.00
0005432262499	46	Economy	6700.00
0005432817871	46	Economy	6700.00
0005432817859	46	Economy	6700.00
0005432289029	46	Economy	6700.00
0005432262520	46	Economy	6700.00
0005432289032	46	Economy	6700.00
0005432262522	46	Economy	6700.00
0005432817860	46	Economy	6700.00
0005433687707	46	Economy	6700.00
0005432262494	46	Economy	6700.00
0005432262518	46	Economy	6700.00
0005432756865	46	Economy	6700.00
0005432817855	46	Economy	6700.00
0005432262496	46	Economy	6700.00
0005432817854	46	Economy	6700.00
0005432262508	46	Economy	6700.00
0005432020623	8011	Business	20000.00
0005432020612	8011	Business	20000.00
0005433102833	8011	Business	20000.00
0005433102844	8011	Business	20000.00
0005432392038	8011	Business	20000.00
0005432020603	8011	Business	20000.00
0005433102845	8011	Business	20000.00
0005432920138	8011	Business	20000.00
0005433102851	8011	Business	20000.00
0005432020618	8011	Business	20000.00
0005432020620	8011	Business	20000.00
0005432920135	8011	Business	20000.00
0005432920125	8011	Business	20000.00
0005433102866	8011	Business	20000.00
0005432920140	8011	Business	20000.00
0005433102865	8011	Business	20000.00
0005433102856	8011	Business	20000.00
0005433102870	8011	Business	20000.00
0005433102828	8011	Business	20000.00
0005432920133	8011	Business	20000.00
0005433102859	8011	Business	20000.00
0005433102853	8011	Business	20000.00
0005433102868	8011	Business	20000.00
0005432920132	8011	Economy	7300.00
0005432677626	8011	Economy	7300.00
0005433102841	8011	Economy	7300.00
0005432920124	8011	Economy	6700.00
0005432020608	8011	Economy	6700.00
0005432753346	8011	Economy	6700.00
0005433102869	8011	Economy	6700.00
0005432044561	8011	Economy	6700.00
0005432044562	8011	Economy	6700.00
0005432044563	8011	Economy	6700.00
0005433102847	8011	Economy	6700.00
0005432020629	8011	Economy	6700.00
0005432020625	8011	Economy	6700.00
0005433102825	8011	Economy	6700.00
0005433102849	8011	Economy	6700.00
0005433102857	8011	Economy	6700.00
0005432020615	8011	Economy	6700.00
0005432020627	8011	Economy	6700.00
0005433102848	8011	Economy	6700.00
0005432020628	8011	Economy	6700.00
0005432920131	8011	Economy	6700.00
0005433102835	8011	Economy	6700.00
0005432920136	8011	Economy	6700.00
0005432920130	8011	Economy	6700.00
0005433102862	8011	Economy	6700.00
0005432920145	8011	Economy	6700.00
0005432920128	8011	Economy	6700.00
0005432020614	8011	Economy	6700.00
0005433102864	8011	Economy	6700.00
0005433102852	8011	Economy	6700.00
0005433102858	8011	Economy	6700.00
0005433102824	8011	Economy	6700.00
0005432020606	8011	Economy	6700.00
0005433102822	8011	Economy	6700.00
0005432020613	8011	Economy	6700.00
0005433102826	8011	Economy	6700.00
0005432753347	8011	Economy	6700.00
0005432677628	8011	Economy	6700.00
0005432753348	8011	Economy	6700.00
0005432020626	8011	Economy	6700.00
0005432920126	8011	Economy	6700.00
0005432751573	8011	Economy	6700.00
0005433102830	8011	Economy	7300.00
0005432920142	8011	Economy	7300.00
0005432751570	8011	Economy	7300.00
0005432920127	8011	Economy	7300.00
0005432677629	8011	Economy	6700.00
0005433102838	8011	Economy	6700.00
0005432392040	8011	Economy	6700.00
0005432020617	8011	Economy	6700.00
0005433102850	8011	Economy	7300.00
0005432920141	8011	Economy	6700.00
0005432020609	8011	Economy	6700.00
0005432392039	8011	Economy	6700.00
0005433102867	8011	Economy	6700.00
0005432045641	8011	Economy	6700.00
0005432920137	8011	Economy	6700.00
0005433102843	8011	Economy	6700.00
0005432920143	8011	Economy	6700.00
0005433102834	8011	Economy	6700.00
0005432020622	8011	Economy	6700.00
0005433102823	8011	Economy	6700.00
0005433102837	8011	Economy	6700.00
0005433102861	8011	Economy	6700.00
0005433102839	8011	Economy	6700.00
0005433102860	8011	Economy	6700.00
0005432020611	8011	Economy	6700.00
0005432020605	8011	Economy	6700.00
0005432751572	8011	Economy	6700.00
0005433102863	8011	Economy	6700.00
0005433102842	8011	Economy	6700.00
0005432677627	8011	Economy	6700.00
0005432045640	8011	Economy	6700.00
0005432920139	8011	Economy	6700.00
0005433102831	8011	Economy	6700.00
0005432920144	8011	Economy	6700.00
0005432751571	8011	Economy	6700.00
0005432677625	8011	Economy	6700.00
0005432020607	8011	Economy	6700.00
0005433102832	8011	Economy	6700.00
0005432920129	8011	Economy	6700.00
0005432920134	8011	Economy	6700.00
0005433102846	8011	Economy	6700.00
0005432020610	8011	Economy	6700.00
0005432044560	8011	Economy	6700.00
0005433102871	8011	Economy	6700.00
0005433102840	8011	Economy	6700.00
0005432020604	8011	Economy	6700.00
0005433102827	8011	Economy	6700.00
0005433102854	8011	Economy	6700.00
0005433102829	8011	Economy	6700.00
0005433102821	8011	Economy	6700.00
0005432020616	8011	Economy	6700.00
0005433102855	8011	Economy	6700.00
0005433102836	8011	Economy	6700.00
0005432020624	8011	Economy	6700.00
0005432020619	8011	Economy	6700.00
0005432020621	8011	Economy	6700.00
0005432817609	8012	Business	20000.00
0005432817660	8012	Business	20000.00
0005432901845	8012	Business	20000.00
0005432901847	8012	Economy	7300.00
0005432901839	8012	Economy	7300.00
0005432901844	8012	Economy	6700.00
0005432817526	8012	Economy	6700.00
0005432901835	8012	Economy	6700.00
0005432817537	8012	Economy	6700.00
0005432817689	8012	Economy	6700.00
0005432817571	8012	Economy	6700.00
0005432817582	8012	Economy	6700.00
0005432901850	8012	Economy	6700.00
0005432901848	8012	Economy	6700.00
0005432901841	8012	Economy	6700.00
0005432817512	8012	Economy	6700.00
0005432901846	8012	Economy	7300.00
0005432901838	8012	Economy	7300.00
0005432817596	8012	Economy	6700.00
0005432817751	8012	Economy	6700.00
0005432901837	8012	Economy	6700.00
0005432817507	8012	Economy	6700.00
0005432817597	8012	Economy	6700.00
0005432901836	8012	Economy	6700.00
0005432817503	8012	Economy	6700.00
0005432901840	8012	Economy	6700.00
0005432901842	8012	Economy	6700.00
0005432817570	8012	Economy	6700.00
0005432817665	8012	Economy	6700.00
0005432817752	8012	Economy	6700.00
0005432901843	8012	Economy	6700.00
0005432901849	8012	Economy	6700.00
0005434175783	9687	Economy	6900.00
0005433870759	9687	Economy	6900.00
0005433870761	9687	Economy	6900.00
0005433870760	9687	Economy	6900.00
0005434175784	9687	Economy	6900.00
0005433870742	32371	Economy	6900.00
0005434175810	32371	Economy	6900.00
0005433870740	32371	Economy	6900.00
0005433870738	32371	Economy	6900.00
0005434175809	32371	Economy	6900.00
0005434175808	32371	Economy	6900.00
0005433870741	32371	Economy	6900.00
0005434879512	3468	Business	35000.00
0005434426995	3468	Business	35000.00
0005434426991	3468	Business	35000.00
0005434427013	3468	Business	35000.00
0005432799825	3468	Business	35000.00
0005435626424	3468	Business	35000.00
0005434879533	3468	Business	35000.00
0005435126931	3468	Business	35000.00
0005434879468	3468	Business	35000.00
0005435126917	3468	Business	35000.00
0005432799838	3468	Business	35000.00
0005435914700	3468	Business	35000.00
0005435126899	3468	Business	35000.00
0005435126903	3468	Business	35000.00
0005435126933	3468	Business	35000.00
0005434879482	3468	Business	35000.00
0005434427002	3468	Business	35000.00
0005434879496	3468	Business	35000.00
0005434879445	3468	Business	35000.00
0005435126924	3468	Comfort	19900.00
0005434879530	3468	Comfort	19900.00
0005434879459	3468	Comfort	19900.00
0005434427007	3468	Comfort	19900.00
0005432799831	3468	Comfort	19900.00
0005435902756	3468	Comfort	19900.00
0005434879520	3468	Comfort	19900.00
0005434938398	3468	Comfort	19900.00
0005432799823	3468	Comfort	19900.00
0005434879513	3468	Comfort	19900.00
0005434938400	3468	Comfort	19900.00
0005434879463	3468	Comfort	19900.00
0005434879487	3468	Comfort	19900.00
0005434879504	3468	Comfort	19900.00
0005434879455	3468	Comfort	19900.00
0005435126937	3468	Comfort	19900.00
0005434427008	3468	Comfort	19900.00
0005432613914	3468	Comfort	19900.00
0005434879529	3468	Comfort	19900.00
0005434938401	3468	Comfort	19900.00
0005434879534	3468	Comfort	19900.00
0005434938395	3468	Comfort	19900.00
0005435126918	3468	Comfort	19900.00
0005435126920	3468	Comfort	19900.00
0005434938409	3468	Comfort	19900.00
0005435126936	3468	Comfort	19900.00
0005434879456	3468	Comfort	19900.00
0005434427000	3468	Economy	11700.00
0005434879447	3468	Economy	11700.00
0005435126922	3468	Economy	11700.00
0005434879507	3468	Economy	11700.00
0005434879483	3468	Economy	11700.00
0005434427012	3468	Economy	11700.00
0005434879443	3468	Economy	11700.00
0005435626429	3468	Economy	11700.00
0005434426998	3468	Economy	11700.00
0005435626427	3468	Economy	11700.00
0005432799830	3468	Economy	11700.00
0005434879535	3468	Economy	11700.00
0005432799843	3468	Economy	11700.00
0005434879476	3468	Economy	11700.00
0005432799834	3468	Economy	11700.00
0005435902736	3468	Economy	11700.00
0005434426997	3468	Economy	11700.00
0005434879458	3468	Economy	11700.00
0005435126897	3468	Economy	11700.00
0005432799848	3468	Economy	11700.00
0005434879462	3468	Economy	11700.00
0005434879442	3468	Economy	11700.00
0005432799826	3468	Economy	11700.00
0005434879527	3468	Economy	11700.00
0005434427006	3468	Economy	11700.00
0005432799842	3468	Economy	11700.00
0005434879460	3468	Economy	11700.00
0005434879485	3468	Economy	11700.00
0005434879467	3468	Economy	11700.00
0005434879525	3468	Economy	11700.00
0005434879523	3468	Economy	11700.00
0005435126898	3468	Economy	11700.00
0005434879499	3468	Economy	11700.00
0005432799840	3468	Economy	11700.00
0005434938405	3468	Economy	11700.00
0005435902811	3468	Economy	11700.00
0005434879464	3468	Economy	11700.00
0005435626423	3468	Economy	11700.00
0005434938402	3468	Economy	11700.00
0005434879494	3468	Economy	11700.00
0005434879495	3468	Economy	11700.00
0005434879469	3468	Economy	11700.00
0005434879475	3468	Economy	11700.00
0005434879446	3468	Economy	11700.00
0005434426992	3468	Economy	11700.00
0005435126905	3468	Economy	11700.00
0005434879502	3468	Economy	11700.00
0005435902735	3468	Economy	12800.00
0005434879480	3468	Economy	11700.00
0005435126934	3468	Economy	11700.00
0005435126923	3468	Economy	11700.00
0005432799829	3468	Economy	12800.00
0005434879473	3468	Economy	11700.00
0005434427017	3468	Economy	12800.00
0005434879465	3468	Economy	11700.00
0005435626422	3468	Economy	12800.00
0005434879516	3468	Economy	11700.00
0005432799822	3468	Economy	11700.00
0005432799824	3468	Economy	11700.00
0005435126921	3468	Economy	11700.00
0005434879521	3468	Economy	11700.00
0005435902752	3468	Economy	11700.00
0005434879493	3468	Economy	11700.00
0005435126911	3468	Economy	11700.00
0005434879522	3468	Economy	11700.00
0005432799844	3468	Economy	11700.00
0005435126900	3468	Economy	11700.00
0005435626430	3468	Economy	11700.00
0005435626421	3468	Economy	11700.00
0005435126904	3468	Economy	11700.00
0005434879514	3468	Economy	11700.00
0005435126932	3468	Economy	11700.00
0005432799833	3468	Economy	11700.00
0005434879479	3468	Economy	11700.00
0005432188651	3468	Economy	11700.00
0005432799845	3468	Economy	11700.00
0005432799837	3468	Economy	11700.00
0005434879503	3468	Economy	11700.00
0005435126908	3468	Economy	11700.00
0005435126927	3468	Economy	11700.00
0005434879505	3468	Economy	11700.00
0005435902847	3468	Economy	11700.00
0005435902765	3468	Economy	11700.00
0005434879508	3468	Economy	11700.00
0005432613918	3468	Economy	11700.00
0005434879453	3468	Economy	11700.00
0005434879511	3468	Economy	11700.00
0005434879501	3468	Economy	11700.00
0005434879484	3468	Economy	11700.00
0005432188652	3468	Economy	11700.00
0005434427015	3468	Economy	11700.00
0005432613916	3468	Economy	11700.00
0005434938404	3468	Economy	11700.00
0005434879452	3468	Economy	11700.00
0005434879517	3468	Economy	11700.00
0005434938396	3468	Economy	11700.00
0005435902774	3468	Economy	11700.00
0005434427009	3468	Economy	11700.00
0005435626428	3468	Economy	11700.00
0005434427011	3468	Economy	11700.00
0005434879486	3468	Economy	11700.00
0005434879491	3468	Economy	11700.00
0005435126907	3468	Economy	11700.00
0005435626419	3468	Economy	11700.00
0005434879497	3468	Economy	11700.00
0005434879537	3468	Economy	11700.00
0005432799836	3468	Economy	11700.00
0005434426990	3468	Economy	11700.00
0005435902757	3468	Economy	11700.00
0005432611762	3468	Economy	11700.00
0005432183496	3468	Economy	11700.00
0005434938412	3468	Economy	11700.00
0005434879518	3468	Economy	11700.00
0005434938393	3468	Economy	11700.00
0005435626432	3468	Economy	11700.00
0005432611759	3468	Economy	11700.00
0005434879481	3468	Economy	11700.00
0005434879489	3468	Economy	11700.00
0005434879444	3468	Economy	11700.00
0005435626416	3468	Economy	11700.00
0005434427005	3468	Economy	11700.00
0005435126926	3468	Economy	11700.00
0005432613917	3468	Economy	11700.00
0005434879448	3468	Economy	11700.00
0005434427001	3468	Economy	11700.00
0005434879510	3468	Economy	11700.00
0005434427018	3468	Economy	11700.00
0005434879526	3468	Economy	11700.00
0005432611763	3468	Economy	11700.00
0005434879454	3468	Economy	11700.00
0005434879474	3468	Economy	11700.00
0005434426993	3468	Economy	11700.00
0005435126916	3468	Economy	11700.00
0005434879515	3468	Economy	11700.00
0005434938399	3468	Economy	11700.00
0005435126913	3468	Economy	11700.00
0005434879524	3468	Economy	11700.00
0005434879536	3468	Economy	11700.00
0005435626420	3468	Economy	11700.00
0005435126914	3468	Economy	11700.00
0005432611760	3468	Economy	11700.00
0005432799847	3468	Economy	11700.00
0005435902737	3468	Economy	11700.00
0005434938407	3468	Economy	11700.00
0005432611761	3468	Economy	11700.00
0005432799841	3468	Economy	11700.00
0005434427010	3468	Economy	12800.00
0005435902806	3468	Economy	12800.00
0005434879461	3468	Economy	11700.00
0005434426999	3468	Economy	11700.00
0005434938403	3468	Economy	11700.00
0005434879528	3468	Economy	11700.00
0005435902763	3468	Economy	11700.00
0005434879472	3468	Economy	11700.00
0005434879488	3468	Economy	11700.00
0005435626425	3468	Economy	11700.00
0005435126925	3468	Economy	11700.00
0005434879478	3468	Economy	11700.00
0005432799832	3468	Economy	11700.00
0005435626418	3468	Economy	11700.00
0005435126909	3468	Economy	11700.00
0005434879490	3468	Economy	11700.00
0005435902782	3468	Economy	11700.00
0005435626426	3468	Economy	11700.00
0005434879531	3468	Economy	11700.00
0005435626417	3468	Economy	11700.00
0005434427004	3468	Economy	11700.00
0005434879509	3468	Economy	11700.00
0005434879519	3468	Economy	11700.00
0005432799846	3468	Economy	11700.00
0005434426989	3468	Economy	11700.00
0005435126919	3468	Economy	11700.00
0005435902762	3468	Economy	11700.00
0005435902784	3468	Economy	11700.00
0005434427003	3468	Economy	11700.00
0005434879498	3468	Economy	11700.00
0005434879532	3468	Economy	11700.00
0005435902819	3468	Economy	11700.00
0005434879506	3468	Economy	11700.00
0005435126910	3468	Economy	11700.00
0005434879492	3468	Economy	11700.00
0005434938397	3468	Economy	11700.00
0005432799849	3468	Economy	11700.00
0005434879500	3468	Economy	11700.00
0005434938411	3468	Economy	11700.00
0005432799828	3468	Economy	11700.00
0005432799835	3468	Economy	11700.00
0005434879466	3468	Economy	11700.00
0005434879451	3468	Economy	11700.00
0005435126930	3468	Economy	11700.00
0005435626414	3468	Economy	11700.00
0005434426994	3468	Economy	11700.00
0005435126915	3468	Economy	11700.00
0005435126935	3468	Economy	11700.00
0005435126901	3468	Economy	11700.00
0005434426996	3468	Economy	11700.00
0005432799827	3468	Economy	11700.00
0005435126906	3468	Economy	11700.00
0005434879457	3468	Economy	11700.00
0005435126912	3468	Economy	11700.00
0005434938410	3468	Economy	11700.00
0005435126929	3468	Economy	11700.00
0005435902818	3468	Economy	11700.00
0005432613915	3468	Economy	11700.00
0005434879471	3468	Economy	11700.00
0005434427014	3468	Economy	11700.00
0005435126902	3468	Economy	11700.00
0005432799839	3468	Economy	11700.00
0005434427016	3468	Economy	11700.00
0005434879450	3468	Economy	11700.00
0005434879470	3468	Economy	11700.00
0005434879477	3468	Economy	11700.00
0005435626415	3468	Economy	11700.00
0005434938408	3468	Economy	11700.00
0005434879449	3468	Economy	11700.00
0005435126928	3468	Economy	11700.00
0005435626431	3468	Economy	11700.00
0005434938394	3468	Economy	11700.00
0005434938406	3468	Economy	11700.00
0005434878921	14589	Business	35000.00
0005435902948	14589	Business	35000.00
0005434879054	14589	Business	35000.00
0005434878263	14589	Business	35000.00
0005432799557	14589	Business	35000.00
0005432799559	14589	Business	35000.00
0005435902937	14589	Business	35000.00
0005434878955	14589	Business	35000.00
0005434938234	14589	Business	35000.00
0005432611726	14589	Business	35000.00
0005434878619	14589	Business	35000.00
0005432607570	14589	Business	35000.00
0005432799544	14589	Business	35000.00
0005435913971	14589	Business	35000.00
0005434878566	14589	Business	35000.00
0005434878697	14589	Business	35000.00
0005435126699	14589	Business	35000.00
0005434878578	14589	Business	35000.00
0005432799560	14589	Business	35000.00
0005432799533	14589	Business	35000.00
0005434426755	14589	Business	35000.00
0005435626220	14589	Business	35000.00
0005435126570	14589	Comfort	19900.00
0005435126503	14589	Business	35000.00
0005435902936	14589	Comfort	19900.00
0005434426821	14589	Comfort	19900.00
0005434878691	14589	Comfort	19900.00
0005432799652	14589	Comfort	19900.00
0005434878228	14589	Comfort	19900.00
0005434938305	14589	Comfort	19900.00
0005434878609	14589	Comfort	19900.00
0005435126374	14589	Comfort	19900.00
0005435902938	14589	Comfort	19900.00
0005434878565	14589	Comfort	19900.00
0005435126373	14589	Comfort	19900.00
0005434878133	14589	Comfort	19900.00
0005434426818	14589	Comfort	19900.00
0005434938199	14589	Comfort	19900.00
0005434938269	14589	Comfort	19900.00
0005434878598	14589	Comfort	19900.00
0005435126462	14589	Comfort	19900.00
0005434426786	14589	Comfort	19900.00
0005434878507	14589	Comfort	19900.00
0005432799592	14589	Comfort	19900.00
0005435626261	14589	Comfort	19900.00
0005434426792	14589	Comfort	19900.00
0005434938294	14589	Comfort	19900.00
0005432799396	14589	Comfort	19900.00
0005434878894	14589	Comfort	19900.00
0005434878305	14589	Comfort	19900.00
0005432799699	14589	Comfort	19900.00
0005434938278	14589	Economy	11700.00
0005434426762	14589	Economy	11700.00
0005432607590	14589	Economy	11700.00
0005432799548	14589	Economy	11700.00
0005435626182	14589	Economy	11700.00
0005435913972	14589	Economy	11700.00
0005434878564	14589	Economy	11700.00
0005435626219	14589	Economy	11700.00
0005434878607	14589	Economy	11700.00
0005434878552	14589	Economy	11700.00
0005435126479	14589	Economy	11700.00
0005435126598	14589	Economy	11700.00
0005434878677	14589	Economy	11700.00
0005435126387	14589	Economy	11700.00
0005435126599	14589	Economy	11700.00
0005435126490	14589	Economy	11700.00
0005435126553	14589	Economy	11700.00
0005434426955	14589	Economy	11700.00
0005435913969	14589	Economy	11700.00
0005434878720	14589	Economy	11700.00
0005434938184	14589	Economy	11700.00
0005434426732	14589	Economy	11700.00
0005435902949	14589	Economy	11700.00
0005435126386	14589	Economy	11700.00
0005435126577	14589	Economy	11700.00
0005434878911	14589	Economy	11700.00
0005435126732	14589	Economy	11700.00
0005435902947	14589	Economy	11700.00
0005435626191	14589	Economy	11700.00
0005435126399	14589	Economy	11700.00
0005434878718	14589	Economy	11700.00
0005432799346	14589	Economy	11700.00
0005434878610	14589	Economy	11700.00
0005434878592	14589	Economy	11700.00
0005432799611	14589	Economy	11700.00
0005435126583	14589	Economy	11700.00
0005434878581	14589	Economy	11700.00
0005434878637	14589	Economy	11700.00
0005432059531	14589	Economy	11700.00
0005432607576	14589	Economy	11700.00
0005435126571	14589	Economy	11700.00
0005434938183	14589	Economy	11700.00
0005432611727	14589	Economy	11700.00
0005435126530	14589	Economy	11700.00
0005435126412	14589	Economy	11700.00
0005434938233	14589	Economy	11700.00
0005435126465	14589	Economy	11700.00
0005434879026	14589	Economy	11700.00
0005434878134	14589	Economy	11700.00
0005434878672	14589	Economy	11700.00
0005434878719	14589	Economy	11700.00
0005434938213	14589	Economy	11700.00
0005432799619	14589	Economy	11700.00
0005435126413	14589	Economy	12800.00
0005434938260	14589	Economy	11700.00
0005434877849	14589	Economy	11700.00
0005434426790	14589	Economy	11700.00
0005434938259	14589	Economy	11700.00
0005435126578	14589	Economy	12800.00
0005434878606	14589	Economy	12800.00
0005435126558	14589	Economy	11700.00
0005435126429	14589	Economy	11700.00
0005435126464	14589	Economy	11700.00
0005434878629	14589	Economy	11700.00
0005435126398	14589	Economy	11700.00
0005434878576	14589	Economy	11700.00
0005434426791	14589	Economy	11700.00
0005434878535	14589	Economy	11700.00
0005434878863	14589	Economy	11700.00
0005434426598	14589	Economy	11700.00
0005432799345	14589	Economy	11700.00
0005435126426	14589	Economy	11700.00
0005432799620	14589	Economy	11700.00
0005435126430	14589	Economy	11700.00
0005434426823	14589	Economy	11700.00
0005434878800	14589	Economy	11700.00
0005434426954	14589	Economy	11700.00
0005434878658	14589	Economy	11700.00
0005435902946	14589	Economy	11700.00
0005435626242	14589	Economy	11700.00
0005434878616	14589	Economy	11700.00
0005434878737	14589	Economy	11700.00
0005434878553	14589	Economy	11700.00
0005432799556	14589	Economy	11700.00
0005434426743	14589	Economy	11700.00
0005435126491	14589	Economy	11700.00
0005435126524	14589	Economy	11700.00
0005432799523	14589	Economy	11700.00
0005434878831	14589	Economy	11700.00
0005435126425	14589	Economy	11700.00
0005434878591	14589	Economy	11700.00
0005434878389	14589	Economy	11700.00
0005432799621	14589	Economy	11700.00
0005434426846	14589	Economy	11700.00
0005434426744	14589	Economy	11700.00
0005434426749	14589	Economy	11700.00
0005434426956	14589	Economy	11700.00
0005435626259	14589	Economy	11700.00
0005435902942	14589	Economy	11700.00
0005434426682	14589	Economy	11700.00
0005435126525	14589	Economy	11700.00
0005434878615	14589	Economy	11700.00
0005434878833	14589	Economy	11700.00
0005434879027	14589	Economy	11700.00
0005434878764	14589	Economy	11700.00
0005434878832	14589	Economy	11700.00
0005435126480	14589	Economy	11700.00
0005434879102	14589	Economy	11700.00
0005434426611	14589	Economy	11700.00
0005435913973	14589	Economy	11700.00
0005432799591	14589	Economy	11700.00
0005435626201	14589	Economy	11700.00
0005434878455	14589	Economy	11700.00
0005435126723	14589	Economy	11700.00
0005435626243	14589	Economy	11700.00
0005432607571	14589	Economy	11700.00
0005435902940	14589	Economy	11700.00
0005435126552	14589	Economy	11700.00
0005434878935	14589	Economy	11700.00
0005434426735	14589	Economy	11700.00
0005435626198	14589	Economy	11700.00
0005434878306	14589	Economy	11700.00
0005435126509	14589	Economy	11700.00
0005434426750	14589	Economy	11700.00
0005435126444	14589	Economy	11700.00
0005434878735	14589	Economy	11700.00
0005435902935	14589	Economy	11700.00
0005435126557	14589	Economy	11700.00
0005434878642	14589	Economy	11700.00
0005434426731	14589	Economy	11700.00
0005432799612	14589	Economy	11700.00
0005434426711	14589	Economy	11700.00
0005434878741	14589	Economy	11700.00
0005435626253	14589	Economy	11700.00
0005434426709	14589	Economy	11700.00
0005434426720	14589	Economy	11700.00
0005432611715	14589	Economy	12800.00
0005432607575	14589	Economy	12800.00
0005432607593	14589	Economy	12800.00
0005435126544	14589	Economy	11700.00
0005434878742	14589	Economy	11700.00
0005435126631	14589	Economy	11700.00
0005434878884	14589	Economy	11700.00
0005434878841	14589	Economy	11700.00
0005432607591	14589	Economy	11700.00
0005434938306	14589	Economy	11700.00
0005434879022	14589	Economy	11700.00
0005434938200	14589	Economy	11700.00
0005435126575	14589	Economy	11700.00
0005435626190	14589	Economy	11700.00
0005435126461	14589	Economy	11700.00
0005434878954	14589	Economy	11700.00
0005434938263	14589	Economy	11700.00
0005434426780	14589	Economy	11700.00
0005434878885	14589	Economy	11700.00
0005434426754	14589	Economy	11700.00
0005434938232	14589	Economy	11700.00
0005434878692	14589	Economy	11700.00
0005435902945	14589	Economy	11700.00
0005434426847	14589	Economy	11700.00
0005434879053	14589	Economy	11700.00
0005434878843	14589	Economy	11700.00
0005435902943	14589	Economy	11700.00
0005435626234	14589	Economy	11700.00
0005434938304	14589	Economy	11700.00
0005432611738	14589	Economy	11700.00
0005434878736	14589	Economy	11700.00
0005434878802	14589	Economy	11700.00
0005432059530	14589	Economy	11700.00
0005434938171	14589	Economy	11700.00
0005435902944	14589	Economy	11700.00
0005432799623	14589	Economy	11700.00
0005434878696	14589	Economy	11700.00
0005434878934	14589	Economy	11700.00
0005434426781	14589	Economy	11700.00
0005434878803	14589	Economy	11700.00
0005435626192	14589	Economy	11700.00
0005434878766	14589	Economy	11700.00
0005434878910	14589	Economy	11700.00
0005432799605	14589	Economy	11700.00
0005434426766	14589	Economy	11700.00
0005432799675	14589	Economy	11700.00
0005435626244	14589	Economy	11700.00
0005434938277	14589	Economy	11700.00
0005434878538	14589	Economy	11700.00
0005434878751	14589	Economy	11700.00
0005434878912	14589	Economy	11700.00
0005434879023	14589	Economy	11700.00
0005435902933	14589	Economy	11700.00
0005435902941	14589	Economy	11700.00
0005432799530	14589	Economy	11700.00
0005435913975	14589	Economy	11700.00
0005434879034	14589	Economy	11700.00
0005434426822	14589	Economy	11700.00
0005434938170	14589	Economy	11700.00
0005434426736	14589	Economy	11700.00
0005435913974	14589	Economy	11700.00
0005434878353	14589	Economy	11700.00
0005434878580	14589	Economy	11700.00
0005434878842	14589	Economy	11700.00
0005434878602	14589	Economy	11700.00
0005434878864	14589	Economy	11700.00
0005434426684	14589	Economy	11700.00
0005434878213	14589	Economy	11700.00
0005435626202	14589	Economy	11700.00
0005434878862	14589	Economy	11700.00
0005435626237	14589	Economy	11700.00
0005434878830	14589	Economy	11700.00
0005435902932	14589	Economy	11700.00
0005434938243	14589	Economy	11700.00
0005435126376	14589	Economy	11700.00
0005434878608	14589	Economy	11700.00
0005435126523	14589	Economy	11700.00
0005435626233	14589	Economy	11700.00
0005432799545	14589	Economy	11700.00
0005432799589	14589	Economy	11700.00
0005432799469	14589	Economy	11700.00
0005435902934	14589	Economy	11700.00
0005432799700	14589	Economy	11700.00
0005432799618	14589	Economy	11700.00
0005434938239	14589	Economy	11700.00
0005434426683	14589	Economy	11700.00
0005435902939	14589	Economy	11700.00
0005432799561	14589	Economy	11700.00
0005434878491	14589	Economy	11700.00
0005435913976	14589	Economy	11700.00
0005434878166	14589	Economy	11700.00
0005434878605	14589	Economy	11700.00
0005434878726	14589	Economy	11700.00
0005435913970	14589	Economy	11700.00
0005434325806	3623	Economy	16300.00
0005435889920	3623	Economy	16300.00
0005434325800	3623	Economy	14800.00
0005434312346	3623	Economy	14800.00
0005435889937	3623	Economy	14800.00
0005434325804	3623	Economy	14800.00
0005434325807	3623	Economy	14800.00
0005435889921	3623	Economy	14800.00
0005434325805	3623	Economy	14800.00
0005434325803	3623	Economy	14800.00
0005434325802	3623	Economy	14800.00
0005435889949	3623	Economy	14800.00
0005435889948	3623	Economy	14800.00
0005435889931	3623	Economy	14800.00
0005434325801	3623	Economy	14800.00
0005435889938	3623	Economy	14800.00
0005434325799	3623	Economy	14800.00
0005434312347	3623	Economy	14800.00
0005434325808	3623	Economy	14800.00
0005434325810	3623	Economy	14800.00
0005434325798	3623	Economy	14800.00
0005434325809	3623	Economy	14800.00
0005434325720	15635	Economy	14800.00
0005434325746	15635	Economy	14800.00
0005435889974	15635	Economy	14800.00
0005434325728	15635	Economy	14800.00
0005435889977	15635	Economy	14800.00
0005434325680	15635	Economy	14800.00
0005434325727	15635	Economy	14800.00
0005434325721	15635	Economy	14800.00
0005434325738	15635	Economy	14800.00
0005434325701	15635	Economy	14800.00
0005435889975	15635	Economy	14800.00
0005435889978	15635	Economy	14800.00
0005435889976	15635	Economy	14800.00
0005435889979	15635	Economy	14800.00
0005435957895	659	Economy	4500.00
0005435957901	659	Economy	4100.00
0005435957896	659	Economy	4100.00
0005433420467	659	Economy	4100.00
0005435957904	659	Economy	4100.00
0005435957899	659	Economy	4100.00
0005435957893	659	Economy	4100.00
0005435957902	659	Economy	4100.00
0005435957894	659	Economy	4100.00
0005435957897	659	Economy	4100.00
0005435957905	659	Economy	4100.00
0005433420468	659	Economy	4100.00
0005433420454	659	Economy	4100.00
0005435957903	659	Economy	4100.00
0005435957898	659	Economy	4100.00
0005433420418	659	Economy	4100.00
0005433420419	659	Economy	4100.00
0005435957892	659	Economy	4100.00
0005433420452	659	Economy	4100.00
0005435957900	659	Economy	4100.00
0005433420435	659	Economy	4100.00
0005433420417	659	Economy	4100.00
0005435957732	15175	Economy	4500.00
0005435957798	15175	Economy	4100.00
0005433420513	15175	Economy	4100.00
0005435957799	15175	Economy	4100.00
0005435957735	15175	Economy	4100.00
0005435957773	15175	Economy	4100.00
0005433420518	15175	Economy	4100.00
0005433420515	15175	Economy	4100.00
0005435957754	15175	Economy	4100.00
0005435957733	15175	Economy	4100.00
0005435957782	15175	Economy	4100.00
0005435957809	15175	Economy	4100.00
0005435957746	15175	Economy	4100.00
0005435957801	15175	Economy	4100.00
0005435957747	15175	Economy	4100.00
0005433420517	15175	Economy	4100.00
0005435957802	15175	Economy	4100.00
0005433420514	15175	Economy	4100.00
0005435957744	15175	Economy	4100.00
0005435957796	15175	Economy	4100.00
0005433420516	15175	Economy	4100.00
0005433420519	15175	Economy	4100.00
0005435629420	8911	Economy	10400.00
0005435629409	16010	Economy	10400.00
0005434247181	16010	Economy	10400.00
0005434247182	16010	Economy	10400.00
0005434096743	11824	Economy	13400.00
0005434096747	11824	Economy	13400.00
0005434096741	11824	Economy	13400.00
0005434096748	11824	Economy	13400.00
0005434096749	11824	Economy	13400.00
0005434096740	11824	Economy	13400.00
0005434096744	11824	Economy	13400.00
0005435163297	4438	Economy	12200.00
0005435933473	4438	Economy	12200.00
0005435163301	4438	Economy	12200.00
0005435163300	4438	Economy	12200.00
0005435933471	4438	Economy	12200.00
0005435933462	4438	Economy	12200.00
0005435163298	4438	Economy	12200.00
0005435163295	4438	Economy	12200.00
0005435163302	4438	Economy	12200.00
0005435163296	4438	Economy	12200.00
0005435163299	4438	Economy	12200.00
0005435933466	4438	Economy	12200.00
0005435163303	4438	Economy	12200.00
0005435933467	4438	Economy	12200.00
0005435163304	4438	Economy	12200.00
0005435933468	4438	Economy	12200.00
0005435933474	4438	Economy	12200.00
0005435163250	29523	Economy	13400.00
0005435933501	29523	Economy	13400.00
0005435163266	29523	Economy	13400.00
0005435163247	29523	Economy	12200.00
0005435163261	29523	Economy	12200.00
0005435163273	29523	Economy	12200.00
0005435933498	29523	Economy	12200.00
0005435163265	29523	Economy	12200.00
0005435163244	29523	Economy	12200.00
0005435163245	29523	Economy	12200.00
0005435163255	29523	Economy	12200.00
0005435163256	29523	Economy	12200.00
0005435933497	29523	Economy	12200.00
0005435163262	29523	Economy	12200.00
0005435933499	29523	Economy	12200.00
0005435933502	29523	Economy	12200.00
0005435933500	29523	Economy	12200.00
0005435163248	29523	Economy	12200.00
0005435933496	29523	Economy	12200.00
0005435163252	29523	Economy	12200.00
0005435163267	29523	Economy	12200.00
0005433404845	2848	Business	12600.00
0005435797661	2848	Business	12600.00
0005435797659	2848	Business	12600.00
0005435797660	2848	Economy	4600.00
0005433404855	2848	Economy	4200.00
0005435797665	2848	Economy	4200.00
0005435797663	2848	Economy	4200.00
0005433404819	2848	Economy	4200.00
0005435797662	2848	Economy	4200.00
0005435797667	2848	Economy	4200.00
0005435797668	2848	Economy	4200.00
0005433404844	2848	Economy	4200.00
0005435797664	2848	Economy	4200.00
0005435797669	2848	Economy	4200.00
0005435797666	2848	Economy	4200.00
0005433404820	2848	Economy	4200.00
0005435797670	2848	Economy	4200.00
0005433404911	29341	Business	12600.00
0005433404912	29341	Business	12600.00
0005435797557	29341	Business	12600.00
0005433404907	29341	Business	12600.00
0005435797563	29341	Economy	4600.00
0005435797560	29341	Economy	4600.00
0005435797565	29341	Economy	4600.00
0005433404908	29341	Economy	4200.00
0005433404909	29341	Economy	4200.00
0005435797559	29341	Economy	4200.00
0005435797536	29341	Economy	4200.00
0005435797562	29341	Economy	4200.00
0005435797525	29341	Economy	4200.00
0005435797594	29341	Economy	4200.00
0005435797535	29341	Economy	4200.00
0005435797517	29341	Economy	4200.00
0005435797593	29341	Economy	4200.00
0005435797515	29341	Economy	4200.00
0005435797592	29341	Economy	4200.00
0005435797598	29341	Economy	4200.00
0005435797566	29341	Economy	4200.00
0005435797577	29341	Economy	4200.00
0005435797576	29341	Economy	4200.00
0005433404910	29341	Economy	4200.00
0005435376364	5745	Economy	6800.00
0005435376355	5745	Economy	6800.00
0005435376356	5745	Economy	6800.00
0005434948131	5771	Economy	6800.00
0005434948132	5771	Economy	6800.00
0005434948133	5771	Economy	6800.00
0005434948135	5771	Economy	6800.00
0005434948134	5771	Economy	6800.00
0005434948136	5771	Economy	6800.00
0005434948071	16335	Economy	6800.00
0005434948082	16335	Economy	6800.00
0005434948073	16335	Economy	6800.00
0005435376390	16335	Economy	6800.00
0005434948070	16335	Economy	6800.00
0005434948075	16335	Economy	6800.00
0005434948058	16335	Economy	6800.00
0005434948080	16335	Economy	6800.00
0005435376391	16335	Economy	6800.00
0005434948083	16335	Economy	6800.00
0005435376389	16335	Economy	6800.00
0005435376388	16335	Economy	6800.00
0005433961599	6929	Business	21400.00
0005433961604	6929	Business	21400.00
0005433961619	6929	Business	21400.00
0005433961603	6929	Business	21400.00
0005433961641	6929	Business	21400.00
0005433961625	6929	Business	21400.00
0005433961630	6929	Business	21400.00
0005433961642	6929	Economy	7100.00
0005433961627	6929	Economy	7100.00
0005433961595	6929	Economy	7100.00
0005433961635	6929	Economy	7100.00
0005433961645	6929	Economy	7100.00
0005433961631	6929	Economy	7100.00
0005433961634	6929	Economy	7100.00
0005433961618	6929	Economy	7100.00
0005433961592	6929	Economy	7800.00
0005433961601	6929	Economy	7800.00
0005433961640	6929	Economy	7800.00
0005433961614	6929	Economy	7800.00
0005433961594	6929	Economy	7100.00
0005433961610	6929	Economy	7100.00
0005433961612	6929	Economy	7100.00
0005433961639	6929	Economy	7100.00
0005433961608	6929	Economy	7100.00
0005433961636	6929	Economy	7100.00
0005433961598	6929	Economy	7100.00
0005433961644	6929	Economy	7100.00
0005433961605	6929	Economy	7100.00
0005433961611	6929	Economy	7100.00
0005433961628	6929	Economy	7100.00
0005433961648	6929	Economy	7100.00
0005433961629	6929	Economy	7100.00
0005433961623	6929	Economy	7100.00
0005433961600	6929	Economy	7100.00
0005433961613	6929	Economy	7100.00
0005433961646	6929	Economy	7100.00
0005433961607	6929	Economy	7100.00
0005433961609	6929	Economy	7100.00
0005433961617	6929	Economy	7100.00
0005433961616	6929	Economy	7100.00
0005433961647	6929	Economy	7100.00
0005433961638	6929	Economy	7100.00
0005433961602	6929	Economy	7100.00
0005433961633	6929	Economy	7100.00
0005433961632	6929	Economy	7100.00
0005433961643	6929	Economy	7100.00
0005433961637	6929	Economy	7100.00
0005433961649	6929	Economy	7100.00
0005433961615	6929	Economy	7100.00
0005433961621	6929	Economy	7100.00
0005433961597	6929	Economy	7100.00
0005433961593	6929	Economy	7100.00
0005433961620	6929	Economy	7100.00
0005433961624	6929	Economy	7100.00
0005433961596	6929	Economy	7100.00
0005433961622	6929	Economy	7100.00
0005433961626	6929	Economy	7100.00
0005433961606	6929	Economy	7100.00
0005433961060	25773	Business	21400.00
0005433961024	25773	Business	21400.00
0005433961017	25773	Business	21400.00
0005433960750	25773	Business	21400.00
0005433961005	25773	Business	21400.00
0005433960905	25773	Business	21400.00
0005433960896	25773	Business	21400.00
0005433961106	25773	Business	21400.00
0005433960751	25773	Economy	7100.00
0005433961089	25773	Economy	7100.00
0005433961049	25773	Economy	7100.00
0005433961030	25773	Economy	7100.00
0005433961027	25773	Economy	7100.00
0005433961055	25773	Economy	7100.00
0005433961086	25773	Economy	7100.00
0005433961092	25773	Economy	7100.00
0005433961009	25773	Economy	7800.00
0005433961008	25773	Economy	7800.00
0005433961090	25773	Economy	7800.00
0005433960958	25773	Economy	7800.00
0005433960949	25773	Economy	7800.00
0005433960992	25773	Economy	7100.00
0005433961088	25773	Economy	7100.00
0005433961059	25773	Economy	7100.00
0005433961011	25773	Economy	7100.00
0005433961023	25773	Economy	7100.00
0005433960891	25773	Economy	7100.00
0005433960890	25773	Economy	7100.00
0005433960978	25773	Economy	7100.00
0005433960881	25773	Economy	7100.00
0005433961081	25773	Economy	7100.00
0005433960831	25773	Economy	7100.00
0005433961082	25773	Economy	7100.00
0005433960944	25773	Economy	7100.00
0005433961025	25773	Economy	7100.00
0005433961075	25773	Economy	7100.00
0005433960951	25773	Economy	7100.00
0005433961013	25773	Economy	7100.00
0005433960898	25773	Economy	7100.00
0005433961004	25773	Economy	7100.00
0005433961003	25773	Economy	7100.00
0005433960994	25773	Economy	7100.00
0005433961058	25773	Economy	7100.00
0005433960855	25773	Economy	7100.00
0005433960793	25773	Economy	7100.00
0005433960991	25773	Economy	7100.00
0005433960908	25773	Economy	7100.00
0005433960892	25773	Economy	7100.00
0005433961026	25773	Economy	7100.00
0005433960969	25773	Economy	7100.00
0005433960869	25773	Economy	7100.00
0005433961028	25773	Economy	7100.00
0005433961012	25773	Economy	7100.00
0005433960979	25773	Economy	7100.00
0005433960897	25773	Economy	7100.00
0005433960830	25773	Economy	7100.00
0005433960911	25773	Economy	7100.00
0005433961091	25773	Economy	7100.00
0005433961031	25773	Economy	7100.00
0005433960965	25773	Economy	7100.00
0005433960966	25773	Economy	7100.00
0005433960910	25773	Economy	7100.00
0005433960996	25773	Economy	7100.00
0005433960995	25773	Economy	7100.00
0005433961050	25773	Economy	7100.00
0005433960997	25773	Economy	7100.00
0005433960945	25773	Economy	7100.00
0005435082804	24503	Economy	3900.00
0005435082809	24503	Economy	3900.00
0005435082828	24503	Economy	3900.00
0005435082827	24503	Economy	3900.00
0005435082829	24503	Economy	3900.00
0005435082807	24503	Economy	3900.00
0005435082805	24503	Economy	3900.00
0005435082785	24503	Economy	3900.00
0005435082883	26113	Economy	3900.00
0005435082889	26113	Economy	3900.00
0005435082885	26113	Economy	3900.00
0005435082882	26113	Economy	3900.00
0005435082888	26113	Economy	3900.00
0005435082887	26113	Economy	3900.00
0005435082884	26113	Economy	3900.00
0005435082886	26113	Economy	3900.00
0005435082891	26113	Economy	3900.00
0005435082890	26113	Economy	3900.00
0005434245385	4978	Business	18000.00
0005432166946	4978	Business	18000.00
0005434245375	4978	Business	18000.00
0005432166945	4978	Business	18000.00
0005433534507	4978	Business	18000.00
0005434245378	4978	Business	18000.00
0005434245382	4978	Economy	6600.00
0005434245359	4978	Economy	6600.00
0005434245363	4978	Economy	6000.00
0005434245376	4978	Economy	6000.00
0005434245361	4978	Economy	6000.00
0005434245373	4978	Economy	6000.00
0005434245369	4978	Economy	6000.00
0005434245358	4978	Economy	6000.00
0005434245365	4978	Economy	6000.00
0005432166943	4978	Economy	6000.00
0005434245386	4978	Economy	6000.00
0005434245380	4978	Economy	6000.00
0005434245366	4978	Economy	6000.00
0005435286657	4978	Economy	6000.00
0005434245384	4978	Economy	6000.00
0005434245367	4978	Economy	6600.00
0005434245383	4978	Economy	6000.00
0005434245371	4978	Economy	6600.00
0005434245370	4978	Economy	6000.00
0005434245368	4978	Economy	6000.00
0005434245381	4978	Economy	6000.00
0005434245374	4978	Economy	6000.00
0005434245364	4978	Economy	6000.00
0005434245362	4978	Economy	6000.00
0005434245372	4978	Economy	6000.00
0005434245377	4978	Economy	6000.00
0005434245360	4978	Economy	6000.00
0005435286643	4978	Economy	6000.00
0005435286656	4978	Economy	6000.00
0005434245357	4978	Economy	6000.00
0005435286655	4978	Economy	6000.00
0005433534506	4978	Economy	6000.00
0005434245379	4978	Economy	6000.00
0005432166944	4978	Economy	6000.00
0005432106187	4977	Business	18000.00
0005433615662	4977	Business	18000.00
0005432106206	4977	Business	18000.00
0005433615639	4977	Business	18000.00
0005433785442	4977	Business	18000.00
0005432106215	4977	Business	18000.00
0005433785431	4977	Business	18000.00
0005432106224	4977	Business	18000.00
0005433785429	4977	Business	18000.00
0005433615665	4977	Business	18000.00
0005433785415	4977	Business	18000.00
0005433615695	4977	Business	18000.00
0005433615653	4977	Business	18000.00
0005432106217	4977	Business	18000.00
0005432106203	4977	Business	18000.00
0005432106225	4977	Business	18000.00
0005433785434	4977	Business	18000.00
0005433785439	4977	Business	18000.00
0005433615694	4977	Business	18000.00
0005433615660	4977	Business	18000.00
0005433785418	4977	Business	18000.00
0005433615670	4977	Business	18000.00
0005433615706	4977	Business	18000.00
0005433785445	4977	Business	18000.00
0005432667481	4977	Business	18000.00
0005433615687	4977	Business	18000.00
0005433615676	4977	Business	18000.00
0005433615698	4977	Business	18000.00
0005433785441	4977	Economy	6600.00
0005433615667	4977	Economy	6600.00
0005433615685	4977	Economy	6600.00
0005432106188	4977	Economy	6600.00
0005433615704	4977	Economy	6600.00
0005432106211	4977	Economy	6600.00
0005433615661	4977	Economy	6000.00
0005432106185	4977	Economy	6000.00
0005433785419	4977	Economy	6000.00
0005432106182	4977	Economy	6000.00
0005432106189	4977	Economy	6000.00
0005433615674	4977	Economy	6000.00
0005433615691	4977	Economy	6000.00
0005432106213	4977	Economy	6000.00
0005433615640	4977	Economy	6000.00
0005432106198	4977	Economy	6000.00
0005432145140	4977	Economy	6000.00
0005433615696	4977	Economy	6000.00
0005432106204	4977	Economy	6000.00
0005433615682	4977	Economy	6000.00
0005433615646	4977	Economy	6000.00
0005433615683	4977	Economy	6000.00
0005432106219	4977	Economy	6000.00
0005432106212	4977	Economy	6000.00
0005432106195	4977	Economy	6000.00
0005433615671	4977	Economy	6000.00
0005432106194	4977	Economy	6000.00
0005433785427	4977	Economy	6000.00
0005433615648	4977	Economy	6000.00
0005432106202	4977	Economy	6000.00
0005433615656	4977	Economy	6000.00
0005432106199	4977	Economy	6000.00
0005432106214	4977	Economy	6000.00
0005433615684	4977	Economy	6000.00
0005433615686	4977	Economy	6000.00
0005433615642	4977	Economy	6000.00
0005433785413	4977	Economy	6000.00
0005433615673	4977	Economy	6000.00
0005432106221	4977	Economy	6000.00
0005433615688	4977	Economy	6000.00
0005433785447	4977	Economy	6000.00
0005432106181	4977	Economy	6000.00
0005433615652	4977	Economy	6000.00
0005433785424	4977	Economy	6000.00
0005433615663	4977	Economy	6000.00
0005432106196	4977	Economy	6000.00
0005433785414	4977	Economy	6000.00
0005432106208	4977	Economy	6000.00
0005433785446	4977	Economy	6000.00
0005432106209	4977	Economy	6000.00
0005433615669	4977	Economy	6000.00
0005433615659	4977	Economy	6000.00
0005432667482	4977	Economy	6000.00
0005433785423	4977	Economy	6000.00
0005433615693	4977	Economy	6000.00
0005433615638	4977	Economy	6000.00
0005433615668	4977	Economy	6000.00
0005433615677	4977	Economy	6000.00
0005433785433	4977	Economy	6000.00
0005433615643	4977	Economy	6000.00
0005433615644	4977	Economy	6000.00
0005433615689	4977	Economy	6000.00
0005433615705	4977	Economy	6000.00
0005433615632	4977	Economy	6000.00
0005433785440	4977	Economy	6000.00
0005433615703	4977	Economy	6600.00
0005433785437	4977	Economy	6600.00
0005432145139	4977	Economy	6600.00
0005433615641	4977	Economy	6600.00
0005432106226	4977	Economy	6000.00
0005433615701	4977	Economy	6600.00
0005432106197	4977	Economy	6000.00
0005433615633	4977	Economy	6000.00
0005432106223	4977	Economy	6000.00
0005433615678	4977	Economy	6600.00
0005433785443	4977	Economy	6000.00
0005433615681	4977	Economy	6000.00
0005433785448	4977	Economy	6000.00
0005433615666	4977	Economy	6000.00
0005432666415	4977	Economy	6000.00
0005432106227	4977	Economy	6000.00
0005433615697	4977	Economy	6000.00
0005432106190	4977	Economy	6000.00
0005433615657	4977	Economy	6000.00
0005433615634	4977	Economy	6000.00
0005433615654	4977	Economy	6000.00
0005433615679	4977	Economy	6000.00
0005433785435	4977	Economy	6000.00
0005433615645	4977	Economy	6000.00
0005433785432	4977	Economy	6000.00
0005433615649	4977	Economy	6000.00
0005432106205	4977	Economy	6000.00
0005432106222	4977	Economy	6000.00
0005433785422	4977	Economy	6000.00
0005432106183	4977	Economy	6000.00
0005432106200	4977	Economy	6000.00
0005433615672	4977	Economy	6000.00
0005433615675	4977	Economy	6000.00
0005433785438	4977	Economy	6000.00
0005433785436	4977	Economy	6000.00
0005433615664	4977	Economy	6000.00
0005433615690	4977	Economy	6000.00
0005433785425	4977	Economy	6000.00
0005433615635	4977	Economy	6000.00
0005433615636	4977	Economy	6000.00
0005432106184	4977	Economy	6000.00
0005433785420	4977	Economy	6000.00
0005432666416	4977	Economy	6000.00
0005433615637	4977	Economy	6000.00
0005433785412	4977	Economy	6000.00
0005433785421	4977	Economy	6000.00
0005432106210	4977	Economy	6000.00
0005432667480	4977	Economy	6000.00
0005432106220	4977	Economy	6000.00
0005433785411	4977	Economy	6000.00
0005433615651	4977	Economy	6000.00
0005433615650	4977	Economy	6000.00
0005433615702	4977	Economy	6000.00
0005432106191	4977	Economy	6000.00
0005433785417	4977	Economy	6000.00
0005432106186	4977	Economy	6000.00
0005433785430	4977	Economy	6000.00
0005433785428	4977	Economy	6000.00
0005432106207	4977	Economy	6000.00
0005433785426	4977	Economy	6000.00
0005433615647	4977	Economy	6000.00
0005433615692	4977	Economy	6000.00
0005432665302	4977	Economy	6000.00
0005432106216	4977	Economy	6000.00
0005433615699	4977	Economy	6000.00
0005433785416	4977	Economy	6000.00
0005433615655	4977	Economy	6000.00
0005433615680	4977	Economy	6000.00
0005433615658	4977	Economy	6000.00
0005432106193	4977	Economy	6000.00
0005432106192	4977	Economy	6000.00
0005433785444	4977	Economy	6000.00
0005432106218	4977	Economy	6000.00
0005432106201	4977	Economy	6000.00
0005433615700	4977	Economy	6000.00
0005432106228	4977	Economy	6000.00
0005432336032	4975	Business	18000.00
0005435007137	4975	Business	18000.00
0005434229674	4975	Business	18000.00
0005434265485	4975	Business	18000.00
0005434265481	4975	Business	18000.00
0005434229667	4975	Business	18000.00
0005433685522	4975	Business	18000.00
0005432336103	4975	Business	18000.00
0005434229680	4975	Business	18000.00
0005435007171	4975	Business	18000.00
0005434265475	4975	Business	18000.00
0005434265480	4975	Business	18000.00
0005434265493	4975	Business	18000.00
0005432336137	4975	Business	18000.00
0005435007259	4975	Business	18000.00
0005432336074	4975	Business	18000.00
0005435007130	4975	Business	18000.00
0005435007005	4975	Business	18000.00
0005434229670	4975	Business	18000.00
0005434265488	4975	Business	18000.00
0005434311235	4975	Business	18000.00
0005434229669	4975	Economy	6600.00
0005434149887	4975	Economy	6600.00
0005434229665	4975	Economy	6600.00
0005434229676	4975	Economy	6000.00
0005435007096	4975	Economy	6000.00
0005434173572	4975	Economy	6000.00
0005434229681	4975	Economy	6000.00
0005432336114	4975	Economy	6000.00
0005433815412	4975	Economy	6000.00
0005434229682	4975	Economy	6000.00
0005434265492	4975	Economy	6000.00
0005435007157	4975	Economy	6000.00
0005432336138	4975	Economy	6000.00
0005434265476	4975	Economy	6000.00
0005434265477	4975	Economy	6000.00
0005433815401	4975	Economy	6000.00
0005433685532	4975	Economy	6000.00
0005434265471	4975	Economy	6000.00
0005434149892	4975	Economy	6000.00
0005435007205	4975	Economy	6000.00
0005433685533	4975	Economy	6000.00
0005434265486	4975	Economy	6000.00
0005434229660	4975	Economy	6000.00
0005432336073	4975	Economy	6000.00
0005434229675	4975	Economy	6000.00
0005435007169	4975	Economy	6000.00
0005433815396	4975	Economy	6000.00
0005434229662	4975	Economy	6000.00
0005435007170	4975	Economy	6000.00
0005434173574	4975	Economy	6000.00
0005434265490	4975	Economy	6000.00
0005435007109	4975	Economy	6000.00
0005434149888	4975	Economy	6000.00
0005434149889	4975	Economy	6000.00
0005435007017	4975	Economy	6000.00
0005434311232	4975	Economy	6000.00
0005434311228	4975	Economy	6000.00
0005434149891	4975	Economy	6000.00
0005432336104	4975	Economy	6000.00
0005433815403	4975	Economy	6000.00
0005434149894	4975	Economy	6000.00
0005434229673	4975	Economy	6000.00
0005435007094	4975	Economy	6000.00
0005435007016	4975	Economy	6000.00
0005434229661	4975	Economy	6000.00
0005434173573	4975	Economy	6000.00
0005435007095	4975	Economy	6000.00
0005434312319	4975	Economy	6000.00
0005435007143	4975	Economy	6000.00
0005434265470	4975	Economy	6000.00
0005434265473	4975	Economy	6000.00
0005434229664	4975	Economy	6600.00
0005432336066	4975	Economy	6600.00
0005434311231	4975	Economy	6600.00
0005434265469	4975	Economy	6600.00
0005433815402	4975	Economy	6000.00
0005435007154	4975	Economy	6600.00
0005434265484	4975	Economy	6000.00
0005435007155	4975	Economy	6000.00
0005434265483	4975	Economy	6000.00
0005435007131	4975	Economy	6000.00
0005434311227	4975	Economy	6000.00
0005434311226	4975	Economy	6000.00
0005434149890	4975	Economy	6000.00
0005434265487	4975	Economy	6000.00
0005434265478	4975	Economy	6000.00
0005435007132	4975	Economy	6000.00
0005432336102	4975	Economy	6000.00
0005434173571	4975	Economy	6000.00
0005434229678	4975	Economy	6000.00
0005434229677	4975	Economy	6000.00
0005433685525	4975	Economy	6000.00
0005434149893	4975	Economy	6000.00
0005433685521	4975	Economy	6000.00
0005434311236	4975	Economy	6000.00
0005434265494	4975	Economy	6000.00
0005434265482	4975	Economy	6000.00
0005434149886	4975	Economy	6000.00
0005434229679	4975	Economy	6000.00
0005434265479	4975	Economy	6000.00
0005434229668	4975	Economy	6000.00
0005432336086	4975	Economy	6000.00
0005432336067	4975	Economy	6000.00
0005434265472	4975	Economy	6000.00
0005432336033	4975	Economy	6000.00
0005432336053	4975	Economy	6000.00
0005435007062	4975	Economy	6000.00
0005433685523	4975	Economy	6000.00
0005434265474	4975	Economy	6000.00
0005434265491	4975	Economy	6000.00
0005435007168	4975	Economy	6000.00
0005434149882	4975	Economy	6000.00
0005435007102	4975	Economy	6000.00
0005434229672	4975	Economy	6000.00
0005434149883	4975	Economy	6000.00
0005434229666	4975	Economy	6000.00
0005434265489	4975	Economy	6000.00
0005434149885	4975	Economy	6000.00
0005435007156	4975	Economy	6000.00
0005434229663	4975	Economy	6000.00
0005432336113	4975	Economy	6000.00
0005434229671	4975	Economy	6000.00
0005434149884	4975	Economy	6000.00
0005435269860	8557	Business	18000.00
0005433785137	8557	Business	18000.00
0005435269864	8557	Business	18000.00
0005434245191	8557	Business	18000.00
0005433785040	8557	Business	18000.00
0005433784784	8557	Business	18000.00
0005434245152	8557	Business	18000.00
0005435269855	8557	Business	18000.00
0005433785076	8557	Business	18000.00
0005432659720	8557	Business	18000.00
0005433785168	8557	Business	18000.00
0005435269858	8557	Business	18000.00
0005433785015	8557	Economy	6600.00
0005433785252	8557	Economy	6600.00
0005433785205	8557	Economy	6000.00
0005433785189	8557	Economy	6000.00
0005434245159	8557	Economy	6000.00
0005434245088	8557	Economy	6000.00
0005434245120	8557	Economy	6000.00
0005434245023	8557	Economy	6000.00
0005434245121	8557	Economy	6000.00
0005433785165	8557	Economy	6000.00
0005434245078	8557	Economy	6000.00
0005433785186	8557	Economy	6000.00
0005432666397	8557	Economy	6000.00
0005434245130	8557	Economy	6000.00
0005432659714	8557	Economy	6000.00
0005434245153	8557	Economy	6000.00
0005432659713	8557	Economy	6000.00
0005433785204	8557	Economy	6000.00
0005435269862	8557	Economy	6000.00
0005433785254	8557	Economy	6000.00
0005433785221	8557	Economy	6000.00
0005433785153	8557	Economy	6000.00
0005434245054	8557	Economy	6000.00
0005435269859	8557	Economy	6000.00
0005433785068	8557	Economy	6000.00
0005434245032	8557	Economy	6000.00
0005433785237	8557	Economy	6000.00
0005432666393	8557	Economy	6000.00
0005432666385	8557	Economy	6000.00
0005434245042	8557	Economy	6000.00
0005433785010	8557	Economy	6000.00
0005433785093	8557	Economy	6000.00
0005433785078	8557	Economy	6000.00
0005435269856	8557	Economy	6000.00
0005435269861	8557	Economy	6600.00
0005433785013	8557	Economy	6600.00
0005433785257	8557	Economy	6000.00
0005434245142	8557	Economy	6000.00
0005435269866	8557	Economy	6000.00
0005434245072	8557	Economy	6000.00
0005435269867	8557	Economy	6000.00
0005434245160	8557	Economy	6000.00
0005433785122	8557	Economy	6000.00
0005434245050	8557	Economy	6000.00
0005433785206	8557	Economy	6000.00
0005433785197	8557	Economy	6000.00
0005433785022	8557	Economy	6000.00
0005433784783	8557	Economy	6000.00
0005433785154	8557	Economy	6000.00
0005434245151	8557	Economy	6000.00
0005432659721	8557	Economy	6000.00
0005433785180	8557	Economy	6000.00
0005432666392	8557	Economy	6000.00
0005435269863	8557	Economy	6000.00
0005432663051	8557	Economy	6000.00
0005435269868	8557	Economy	6000.00
0005433784982	8557	Economy	6000.00
0005433785253	8557	Economy	6000.00
0005434245131	8557	Economy	6000.00
0005432666398	8557	Economy	6000.00
0005435269857	8557	Economy	6000.00
0005433785039	8557	Economy	6000.00
0005433785207	8557	Economy	6000.00
0005434245089	8557	Economy	6000.00
0005435269865	8557	Economy	6000.00
0005434245026	8557	Economy	6000.00
0005433785107	8557	Economy	6000.00
0005433614781	8556	Business	18000.00
0005433615202	8556	Business	18000.00
0005433615028	8556	Business	18000.00
0005433614617	8556	Business	18000.00
0005433614804	8556	Business	18000.00
0005433615288	8556	Business	18000.00
0005433614978	8556	Business	18000.00
0005433614976	8556	Business	18000.00
0005433614689	8556	Business	18000.00
0005433614632	8556	Business	18000.00
0005433615201	8556	Business	18000.00
0005433614992	8556	Business	18000.00
0005433615151	8556	Business	18000.00
0005433615118	8556	Economy	6600.00
0005433615056	8556	Business	18000.00
0005433615058	8556	Economy	6600.00
0005433615203	8556	Economy	6600.00
0005433615055	8556	Economy	6600.00
0005433614993	8556	Economy	6600.00
0005433614833	8556	Economy	6000.00
0005433614668	8556	Economy	6000.00
0005433615023	8556	Economy	6000.00
0005433615244	8556	Economy	6000.00
0005433614877	8556	Economy	6000.00
0005433614669	8556	Economy	6000.00
0005433615225	8556	Economy	6000.00
0005433614800	8556	Economy	6000.00
0005433614907	8556	Economy	6000.00
0005433615287	8556	Economy	6000.00
0005433614994	8556	Economy	6000.00
0005433615263	8556	Economy	6000.00
0005433615103	8556	Economy	6000.00
0005433614850	8556	Economy	6000.00
0005433614453	8556	Economy	6000.00
0005433615262	8556	Economy	6000.00
0005433614783	8556	Economy	6000.00
0005433614858	8556	Economy	6000.00
0005433614735	8556	Economy	6000.00
0005433615156	8556	Economy	6000.00
0005433614673	8556	Economy	6000.00
0005433614965	8556	Economy	6000.00
0005433614779	8556	Economy	6000.00
0005433614975	8556	Economy	6000.00
0005433615132	8556	Economy	6000.00
0005433614744	8556	Economy	6000.00
0005433615134	8556	Economy	6000.00
0005433614651	8556	Economy	6000.00
0005433614974	8556	Economy	6000.00
0005433614832	8556	Economy	6000.00
0005433615180	8556	Economy	6000.00
0005433614844	8556	Economy	6000.00
0005433614979	8556	Economy	6000.00
0005433614913	8556	Economy	6000.00
0005433614995	8556	Economy	6000.00
0005433614952	8556	Economy	6000.00
0005433614818	8556	Economy	6600.00
0005433614941	8556	Economy	6600.00
0005433614935	8556	Economy	6600.00
0005433614997	8556	Economy	6000.00
0005433614574	8556	Economy	6000.00
0005433614884	8556	Economy	6600.00
0005433615184	8556	Economy	6000.00
0005433614910	8556	Economy	6000.00
0005433614690	8556	Economy	6000.00
0005433614878	8556	Economy	6000.00
0005433614998	8556	Economy	6000.00
0005433614851	8556	Economy	6000.00
0005433615261	8556	Economy	6000.00
0005433615243	8556	Economy	6000.00
0005433615057	8556	Economy	6000.00
0005433614883	8556	Economy	6000.00
0005433615017	8556	Economy	6000.00
0005433614842	8556	Economy	6000.00
0005433615150	8556	Economy	6000.00
0005433615133	8556	Economy	6000.00
0005433615021	8556	Economy	6000.00
0005433614780	8556	Economy	6000.00
0005433614843	8556	Economy	6000.00
0005433614819	8556	Economy	6000.00
0005433614691	8556	Economy	6000.00
0005433614805	8556	Economy	6000.00
0005433615080	8556	Economy	6000.00
0005433614638	8556	Economy	6000.00
0005433614637	8556	Economy	6000.00
0005433614942	8556	Economy	6000.00
0005433614806	8556	Economy	6000.00
0005433615114	8556	Economy	6000.00
0005433614867	8556	Economy	6000.00
0005433614782	8556	Economy	6000.00
0005433614860	8556	Economy	6000.00
0005433615160	8556	Economy	6000.00
0005435007333	8555	Business	18000.00
0005432336193	8555	Business	18000.00
0005432047600	8555	Business	18000.00
0005434173550	8555	Business	18000.00
0005432035309	8555	Business	18000.00
0005435007334	8555	Business	18000.00
0005433815449	8555	Business	18000.00
0005435007345	8555	Business	18000.00
0005435007341	8555	Business	18000.00
0005435286693	8555	Business	18000.00
0005435007332	8555	Business	18000.00
0005434229500	8555	Business	18000.00
0005434229411	8555	Business	18000.00
0005432035331	8555	Business	18000.00
0005435286704	8555	Business	18000.00
0005435286705	8555	Business	18000.00
0005432336199	8555	Business	18000.00
0005434229498	8555	Business	18000.00
0005433690951	8555	Business	18000.00
0005434229535	8555	Business	18000.00
0005435286702	8555	Business	18000.00
0005432035329	8555	Business	18000.00
0005432035325	8555	Business	18000.00
0005435286691	8555	Business	18000.00
0005432336189	8555	Business	18000.00
0005434229402	8555	Economy	6600.00
0005432035308	8555	Economy	6600.00
0005434229552	8555	Economy	6600.00
0005432047599	8555	Economy	6600.00
0005434265270	8555	Economy	6000.00
0005434265145	8555	Economy	6600.00
0005435286694	8555	Economy	6000.00
0005432336195	8555	Economy	6000.00
0005434265249	8555	Economy	6000.00
0005434265203	8555	Economy	6000.00
0005434229629	8555	Economy	6000.00
0005432035311	8555	Economy	6000.00
0005432336187	8555	Economy	6000.00
0005432035307	8555	Economy	6000.00
0005432035305	8555	Economy	6000.00
0005435007343	8555	Economy	6000.00
0005435007348	8555	Economy	6000.00
0005435007344	8555	Economy	6000.00
0005434229516	8555	Economy	6000.00
0005434149830	8555	Economy	6000.00
0005432035324	8555	Economy	6000.00
0005433688838	8555	Economy	6000.00
0005434265330	8555	Economy	6000.00
0005434149776	8555	Economy	6000.00
0005435007354	8555	Economy	6000.00
0005434173541	8555	Economy	6000.00
0005434229437	8555	Economy	6000.00
0005435007349	8555	Economy	6000.00
0005435286692	8555	Economy	6000.00
0005434229628	8555	Economy	6000.00
0005432336196	8555	Economy	6000.00
0005434265319	8555	Economy	6000.00
0005435286708	8555	Economy	6000.00
0005433689940	8555	Economy	6000.00
0005432035313	8555	Economy	6000.00
0005435286706	8555	Economy	6000.00
0005434149750	8555	Economy	6000.00
0005435286707	8555	Economy	6000.00
0005435007340	8555	Economy	6000.00
0005434311245	8555	Economy	6000.00
0005435007353	8555	Economy	6000.00
0005435286697	8555	Economy	6000.00
0005434229586	8555	Economy	6000.00
0005432336198	8555	Economy	6000.00
0005432035328	8555	Economy	6000.00
0005435007336	8555	Economy	6000.00
0005434149812	8555	Economy	6000.00
0005435007339	8555	Economy	6000.00
0005435286696	8555	Economy	6000.00
0005434149791	8555	Economy	6000.00
0005435286701	8555	Economy	6000.00
0005434229481	8555	Economy	6000.00
0005435007347	8555	Economy	6000.00
0005433534527	8555	Economy	6000.00
0005432035330	8555	Economy	6000.00
0005432035312	8555	Economy	6000.00
0005432035318	8555	Economy	6000.00
0005434229487	8555	Economy	6000.00
0005434265378	8555	Economy	6000.00
0005432035326	8555	Economy	6000.00
0005435007338	8555	Economy	6600.00
0005432035319	8555	Economy	6600.00
0005432035315	8555	Economy	6600.00
0005434229438	8555	Economy	6000.00
0005435286698	8555	Economy	6600.00
0005434149811	8555	Economy	6000.00
0005435007331	8555	Economy	6000.00
0005432035314	8555	Economy	6000.00
0005435007335	8555	Economy	6600.00
0005432035316	8555	Economy	6000.00
0005435007329	8555	Economy	6000.00
0005432035321	8555	Economy	6000.00
0005432047598	8555	Economy	6000.00
0005435286703	8555	Economy	6000.00
0005434265309	8555	Economy	6000.00
0005433815450	8555	Economy	6000.00
0005434149797	8555	Economy	6000.00
0005432336194	8555	Economy	6000.00
0005432336192	8555	Economy	6000.00
0005434149802	8555	Economy	6000.00
0005435286699	8555	Economy	6000.00
0005433815453	8555	Economy	6000.00
0005432336188	8555	Economy	6000.00
0005434311246	8555	Economy	6000.00
0005434229585	8555	Economy	6000.00
0005432336197	8555	Economy	6000.00
0005434149794	8555	Economy	6000.00
0005434173542	8555	Economy	6000.00
0005432035306	8555	Economy	6000.00
0005435286695	8555	Economy	6000.00
0005434149807	8555	Economy	6000.00
0005435007337	8555	Economy	6000.00
0005434229501	8555	Economy	6000.00
0005435007351	8555	Economy	6000.00
0005433815451	8555	Economy	6000.00
0005434229457	8555	Economy	6000.00
0005432035322	8555	Economy	6000.00
0005435007346	8555	Economy	6000.00
0005434149808	8555	Economy	6000.00
0005432336190	8555	Economy	6000.00
0005432035304	8555	Economy	6000.00
0005433815452	8555	Economy	6000.00
0005434229462	8555	Economy	6000.00
0005432035320	8555	Economy	6000.00
0005434265250	8555	Economy	6000.00
0005434311244	8555	Economy	6000.00
0005435007352	8555	Economy	6000.00
0005434149777	8555	Economy	6000.00
0005433690952	8555	Economy	6000.00
0005435007330	8555	Economy	6000.00
0005432035310	8555	Economy	6000.00
0005432035327	8555	Economy	6000.00
0005432336191	8555	Economy	6000.00
0005435007342	8555	Economy	6000.00
0005434149809	8555	Economy	6000.00
0005433689939	8555	Economy	6000.00
0005435007350	8555	Economy	6000.00
0005434265258	8555	Economy	6000.00
0005432035323	8555	Economy	6000.00
0005435286700	8555	Economy	6000.00
0005432047601	8555	Economy	6000.00
0005434173551	8555	Economy	6000.00
0005433534526	8555	Economy	6000.00
0005434229480	8555	Economy	6000.00
0005432035317	8555	Economy	6000.00
0005434149813	8555	Economy	6000.00
0005434639443	12601	Economy	16200.00
0005434639331	12601	Economy	16200.00
0005434639392	12601	Economy	16200.00
0005434639393	12601	Economy	16200.00
0005434639411	12601	Economy	14800.00
0005434639415	12601	Economy	14800.00
0005434639473	12601	Economy	14800.00
0005434639436	12601	Economy	14800.00
0005434639408	12601	Economy	14800.00
0005434639475	12601	Economy	14800.00
0005434639339	12601	Economy	14800.00
0005434639320	12601	Economy	14800.00
0005434639453	12601	Economy	14800.00
0005434639435	12601	Economy	14800.00
0005433202562	12601	Economy	14800.00
0005433202569	12601	Economy	14800.00
0005433202564	12601	Economy	14800.00
0005434639421	12601	Economy	14800.00
0005433202557	12601	Economy	14800.00
0005434639463	12601	Economy	14800.00
0005434639462	12601	Economy	14800.00
0005433202565	12601	Economy	14800.00
0005434639376	12601	Economy	14800.00
0005434639416	12601	Economy	14800.00
0005433202563	12601	Economy	14800.00
0005434639431	12601	Economy	14800.00
0005433202555	12601	Economy	14800.00
0005434639332	12601	Economy	14800.00
0005434639410	12601	Economy	14800.00
0005433202554	12601	Economy	14800.00
0005434639385	12601	Economy	14800.00
0005434639315	12601	Economy	14800.00
0005433202560	12601	Economy	14800.00
0005434639476	12601	Economy	14800.00
0005434639461	12601	Economy	14800.00
0005433202556	12601	Economy	14800.00
0005433202558	12601	Economy	14800.00
0005434639474	12601	Economy	14800.00
0005434639427	12601	Economy	14800.00
0005434639316	12601	Economy	14800.00
0005433202566	12601	Economy	14800.00
0005433202559	12601	Economy	14800.00
0005434639450	12601	Economy	14800.00
0005433202561	12601	Economy	14800.00
0005434639460	12601	Economy	14800.00
0005433202568	12601	Economy	14800.00
0005433202567	12601	Economy	14800.00
0005434639448	12601	Economy	14800.00
0005434639348	12601	Economy	14800.00
0005434639630	23397	Economy	16200.00
0005434639654	23397	Economy	16200.00
0005433202415	23397	Economy	16200.00
0005434639648	23397	Economy	16200.00
0005434639642	23397	Economy	14800.00
0005432290670	23397	Economy	14800.00
0005434639629	23397	Economy	14800.00
0005433202399	23397	Economy	14800.00
0005433202458	23397	Economy	14800.00
0005434639631	23397	Economy	14800.00
0005434639633	23397	Economy	14800.00
0005432290673	23397	Economy	14800.00
0005434639644	23397	Economy	14800.00
0005434639639	23397	Economy	14800.00
0005434639638	23397	Economy	14800.00
0005434639636	23397	Economy	14800.00
0005434639653	23397	Economy	14800.00
0005433202404	23397	Economy	14800.00
0005434639651	23397	Economy	14800.00
0005434639647	23397	Economy	14800.00
0005433202354	23397	Economy	14800.00
0005432290671	23397	Economy	14800.00
0005434639628	23397	Economy	14800.00
0005434639627	23397	Economy	14800.00
0005433202430	23397	Economy	14800.00
0005434639640	23397	Economy	14800.00
0005433202429	23397	Economy	14800.00
0005434639652	23397	Economy	14800.00
0005434639632	23397	Economy	14800.00
0005434639635	23397	Economy	14800.00
0005434639634	23397	Economy	14800.00
0005432290672	23397	Economy	14800.00
0005434639650	23397	Economy	14800.00
0005434639649	23397	Economy	14800.00
0005434639641	23397	Economy	14800.00
0005434639637	23397	Economy	14800.00
0005433202400	23397	Economy	14800.00
0005434639643	23397	Economy	14800.00
0005433202414	23397	Economy	14800.00
0005434639645	23397	Economy	14800.00
0005433202411	23397	Economy	14800.00
0005433202403	23397	Economy	14800.00
0005433202412	23397	Economy	14800.00
0005433202410	23397	Economy	14800.00
0005434639646	23397	Economy	14800.00
0005433202459	23397	Economy	14800.00
0005432328815	21104	Business	18900.00
0005432329035	21104	Business	18900.00
0005432054342	21104	Business	18900.00
0005432329061	21104	Business	18900.00
0005432383279	21104	Business	18900.00
0005432328869	21104	Business	18900.00
0005432383523	21104	Business	18900.00
0005432054343	21104	Business	18900.00
0005432383261	21104	Business	18900.00
0005432383140	21104	Economy	6300.00
0005432328860	21104	Economy	6300.00
0005432328955	21104	Economy	6300.00
0005432383230	21104	Economy	6300.00
0005432383522	21104	Economy	6300.00
0005432383439	21104	Economy	6300.00
0005432328943	21104	Economy	6300.00
0005432383266	21104	Economy	6300.00
0005432848844	21104	Economy	6900.00
0005432328942	21104	Economy	6900.00
0005432328724	21104	Economy	6900.00
0005432329036	21104	Economy	6300.00
0005432383400	21104	Economy	6300.00
0005432383368	21104	Economy	6300.00
0005432383190	21104	Economy	6300.00
0005432328823	21104	Economy	6300.00
0005432383265	21104	Economy	6300.00
0005432328927	21104	Economy	6300.00
0005432383326	21104	Economy	6300.00
0005432329009	21104	Economy	6300.00
0005432328670	21104	Economy	6300.00
0005432383402	21104	Economy	6300.00
0005432328913	21104	Economy	6300.00
0005432383274	21104	Economy	6300.00
0005432329008	21104	Economy	6300.00
0005432054345	21104	Economy	6300.00
0005432328835	21104	Economy	6300.00
0005432383273	21104	Economy	6300.00
0005432383421	21104	Economy	6300.00
0005432328630	21104	Economy	6300.00
0005432054344	21104	Economy	6300.00
0005432383236	21104	Economy	6300.00
0005432383275	21104	Economy	6300.00
0005432328852	21104	Economy	6300.00
0005432328778	21104	Economy	6300.00
0005432383444	21104	Economy	6300.00
0005432383314	21104	Economy	6300.00
0005432328571	21104	Economy	6300.00
0005432328856	21104	Economy	6300.00
0005432848845	21104	Economy	6300.00
0005432328868	21104	Economy	6300.00
0005432329087	21104	Economy	6300.00
0005432328902	21104	Economy	6300.00
0005432328671	21104	Economy	6300.00
0005432848846	21104	Economy	6300.00
0005432328956	21104	Economy	6300.00
0005432383297	21104	Economy	6300.00
0005432329016	21104	Economy	6300.00
0005432328715	21104	Economy	6300.00
0005432329034	21104	Economy	6300.00
0005432329086	21104	Economy	6300.00
0005432848843	21104	Economy	6300.00
0005432328848	21104	Economy	6300.00
0005432383235	21104	Economy	6300.00
0005432328464	21104	Economy	6300.00
0005432328909	21104	Economy	6300.00
0005432383376	21104	Economy	6300.00
0005432383375	21104	Economy	6300.00
0005432328881	21104	Economy	6300.00
0005432383267	21104	Economy	6300.00
0005432328954	21104	Economy	6300.00
0005432328732	21104	Economy	6300.00
0005432328822	21104	Economy	6300.00
0005432383440	21104	Economy	6300.00
0005432383399	21104	Economy	6300.00
0005432383234	21104	Economy	6300.00
0005432383233	21104	Economy	6300.00
0005432329081	21104	Economy	6300.00
0005432383333	21104	Economy	6300.00
0005432383403	21104	Economy	6300.00
0005432383315	21104	Economy	6300.00
0005432383139	21104	Economy	6300.00
0005432383302	21104	Economy	6300.00
0005432383229	21104	Economy	6300.00
0005432383640	31233	Business	18900.00
0005432329254	31233	Business	18900.00
0005432329284	31233	Business	18900.00
0005432329259	31233	Business	18900.00
0005432329290	31233	Business	18900.00
0005432287255	31233	Business	18900.00
0005432329292	31233	Business	18900.00
0005432383670	31233	Business	18900.00
0005432383641	31233	Business	18900.00
0005432383674	31233	Business	18900.00
0005432329282	31233	Business	18900.00
0005432287253	31233	Economy	6300.00
0005432383645	31233	Economy	6300.00
0005432329261	31233	Economy	6300.00
0005432329277	31233	Economy	6300.00
0005432329281	31233	Economy	6300.00
0005432329260	31233	Economy	6300.00
0005432329269	31233	Economy	6300.00
0005432329287	31233	Economy	6300.00
0005432287252	31233	Economy	6300.00
0005432287254	31233	Economy	6300.00
0005432329297	31233	Economy	6900.00
0005432329285	31233	Economy	6900.00
0005432383679	31233	Economy	6900.00
0005432329253	31233	Economy	6900.00
0005432383667	31233	Economy	6900.00
0005432329262	31233	Economy	6300.00
0005432329298	31233	Economy	6300.00
0005432383677	31233	Economy	6300.00
0005432287251	31233	Economy	6300.00
0005432329270	31233	Economy	6300.00
0005432383644	31233	Economy	6300.00
0005432329272	31233	Economy	6300.00
0005432383662	31233	Economy	6300.00
0005432383664	31233	Economy	6300.00
0005432383653	31233	Economy	6300.00
0005432383650	31233	Economy	6300.00
0005432383654	31233	Economy	6300.00
0005432383643	31233	Economy	6300.00
0005432383665	31233	Economy	6300.00
0005432329274	31233	Economy	6300.00
0005432383668	31233	Economy	6300.00
0005432329289	31233	Economy	6300.00
0005432383657	31233	Economy	6300.00
0005432329293	31233	Economy	6300.00
0005432383649	31233	Economy	6300.00
0005432383647	31233	Economy	6300.00
0005432329268	31233	Economy	6300.00
0005432383661	31233	Economy	6300.00
0005432383656	31233	Economy	6300.00
0005432383652	31233	Economy	6300.00
0005432383660	31233	Economy	6300.00
0005432383648	31233	Economy	6300.00
0005432329266	31233	Economy	6300.00
0005432383659	31233	Economy	6300.00
0005432329258	31233	Economy	6300.00
0005432329295	31233	Economy	6300.00
0005432329267	31233	Economy	6300.00
0005432329278	31233	Economy	6300.00
0005432383658	31233	Economy	6300.00
0005432329275	31233	Economy	6300.00
0005432329288	31233	Economy	6300.00
0005432329257	31233	Economy	6300.00
0005432383673	31233	Economy	6300.00
0005432329276	31233	Economy	6300.00
0005432329273	31233	Economy	6300.00
0005432383651	31233	Economy	6300.00
0005432329264	31233	Economy	6300.00
0005432383639	31233	Economy	6300.00
0005432383666	31233	Economy	6300.00
0005432329294	31233	Economy	6300.00
0005432329271	31233	Economy	6300.00
0005432329280	31233	Economy	6300.00
0005432383646	31233	Economy	6300.00
0005432383671	31233	Economy	6300.00
0005432329296	31233	Economy	6300.00
0005432383678	31233	Economy	6300.00
0005432329283	31233	Economy	6300.00
0005432383669	31233	Economy	6300.00
0005432383663	31233	Economy	6300.00
0005432329256	31233	Economy	6300.00
0005432383655	31233	Economy	6300.00
0005432329279	31233	Economy	6300.00
0005432329263	31233	Economy	6300.00
0005432329291	31233	Economy	6300.00
0005432383642	31233	Economy	6300.00
0005432383676	31233	Economy	6300.00
0005432329286	31233	Economy	6300.00
0005432383672	31233	Economy	6300.00
0005432383675	31233	Economy	6300.00
0005432329265	31233	Economy	6300.00
0005432329255	31233	Economy	6300.00
0005433642541	2473	Business	89600.00
0005432953976	2473	Business	89600.00
0005433642528	2473	Business	89600.00
0005433642542	2473	Economy	29900.00
0005433642521	2473	Economy	29900.00
0005433642538	2473	Economy	29900.00
0005433642527	2473	Economy	29900.00
0005433642531	2473	Economy	29900.00
0005433642532	2473	Economy	29900.00
0005432953969	2473	Economy	29900.00
0005432953962	2473	Economy	29900.00
0005433642533	2473	Economy	29900.00
0005433642537	2473	Economy	32800.00
0005433642526	2473	Economy	32800.00
0005433642549	2473	Economy	29900.00
0005432953943	2473	Economy	29900.00
0005433642520	2473	Economy	29900.00
0005432953945	2473	Economy	29900.00
0005432953946	2473	Economy	29900.00
0005433642546	2473	Economy	29900.00
0005432953985	2473	Economy	29900.00
0005432953940	2473	Economy	29900.00
0005433642529	2473	Economy	29900.00
0005432953982	2473	Economy	29900.00
0005433642539	2473	Economy	29900.00
0005433642524	2473	Economy	29900.00
0005432953981	2473	Economy	29900.00
0005432954010	2473	Economy	29900.00
0005432953984	2473	Economy	29900.00
0005433642548	2473	Economy	29900.00
0005433642543	2473	Economy	29900.00
0005433642547	2473	Economy	29900.00
0005433642534	2473	Economy	29900.00
0005433642544	2473	Economy	29900.00
0005433642523	2473	Economy	29900.00
0005432953968	2473	Economy	29900.00
0005432954011	2473	Economy	29900.00
0005433642540	2473	Economy	29900.00
0005432953983	2473	Economy	29900.00
0005432953958	2473	Economy	29900.00
0005433642530	2473	Economy	29900.00
0005433642536	2473	Economy	29900.00
0005433642545	2473	Economy	29900.00
0005433642525	2473	Economy	29900.00
0005432953957	2473	Economy	29900.00
0005433642522	2473	Economy	29900.00
0005432953993	2473	Economy	29900.00
0005432953939	2473	Economy	29900.00
0005432953967	2473	Economy	29900.00
0005433642535	2473	Economy	29900.00
0005433642432	27589	Business	89600.00
0005433642468	27589	Business	89600.00
0005433642442	27589	Business	89600.00
0005433642397	27589	Business	89600.00
0005432954037	27589	Business	89600.00
0005433642375	27589	Business	89600.00
0005432954042	27589	Business	89600.00
0005433642390	27589	Business	89600.00
0005432954029	27589	Economy	29900.00
0005433642433	27589	Economy	29900.00
0005432954030	27589	Economy	29900.00
0005433642392	27589	Economy	29900.00
0005433642449	27589	Economy	29900.00
0005432954036	27589	Economy	29900.00
0005432954038	27589	Economy	29900.00
0005432954054	27589	Economy	29900.00
0005432954048	27589	Economy	29900.00
0005433642369	27589	Economy	32800.00
0005433642325	27589	Economy	29900.00
0005433642336	27589	Economy	29900.00
0005433642393	27589	Economy	29900.00
0005433642434	27589	Economy	29900.00
0005433642398	27589	Economy	29900.00
0005433642335	27589	Economy	29900.00
0005433642337	27589	Economy	29900.00
0005432954053	27589	Economy	29900.00
0005433642377	27589	Economy	29900.00
0005433642288	27589	Economy	29900.00
0005433642408	27589	Economy	29900.00
0005433642348	27589	Economy	29900.00
0005433642338	27589	Economy	29900.00
0005432954043	27589	Economy	29900.00
0005432954041	27589	Economy	29900.00
0005433642443	27589	Economy	29900.00
0005432954045	27589	Economy	29900.00
0005432954044	27589	Economy	29900.00
0005433642436	27589	Economy	29900.00
0005433642312	27589	Economy	29900.00
0005432954050	27589	Economy	29900.00
0005432954033	27589	Economy	29900.00
0005432954052	27589	Economy	29900.00
0005433642401	27589	Economy	29900.00
0005433642452	27589	Economy	29900.00
0005433642395	27589	Economy	29900.00
0005433642403	27589	Economy	29900.00
0005433642402	27589	Economy	29900.00
0005432954051	27589	Economy	29900.00
0005432954032	27589	Economy	29900.00
0005432954035	27589	Economy	29900.00
0005432954040	27589	Economy	29900.00
0005433642326	27589	Economy	29900.00
0005432954039	27589	Economy	29900.00
0005433642448	27589	Economy	29900.00
0005433642467	27589	Economy	29900.00
0005433642444	27589	Economy	29900.00
0005432954031	27589	Economy	29900.00
0005432954034	27589	Economy	29900.00
0005432954049	27589	Economy	29900.00
0005433642400	27589	Economy	29900.00
0005433642435	27589	Economy	29900.00
0005433642445	27589	Economy	29900.00
0005433642378	27589	Economy	29900.00
0005432954046	27589	Economy	29900.00
0005433642396	27589	Economy	29900.00
0005433642437	27589	Economy	29900.00
0005433642414	27589	Economy	29900.00
0005433642370	27589	Economy	29900.00
0005432954047	27589	Economy	29900.00
0005433642391	27589	Economy	29900.00
0005432425033	13350	Business	12700.00
0005432425032	13350	Business	12700.00
0005432425025	13350	Business	12700.00
0005432425057	13350	Business	12700.00
0005432425036	13350	Business	12700.00
0005432425009	13350	Business	12700.00
0005432425022	13350	Economy	4200.00
0005432425017	13350	Economy	4200.00
0005432425028	13350	Economy	4200.00
0005432425026	13350	Economy	4200.00
0005432425066	13350	Economy	4200.00
0005432425052	13350	Economy	4200.00
0005432425029	13350	Economy	4200.00
0005432425047	13350	Economy	4200.00
0005432425039	13350	Economy	4700.00
0005432425027	13350	Economy	4700.00
0005432425018	13350	Economy	4200.00
0005432425059	13350	Economy	4200.00
0005432425064	13350	Economy	4200.00
0005432425011	13350	Economy	4200.00
0005432425073	13350	Economy	4200.00
0005432425037	13350	Economy	4200.00
0005432425075	13350	Economy	4200.00
0005432425016	13350	Economy	4200.00
0005432425040	13350	Economy	4200.00
0005432425050	13350	Economy	4200.00
0005432425042	13350	Economy	4200.00
0005432425072	13350	Economy	4200.00
0005432425034	13350	Economy	4200.00
0005432425063	13350	Economy	4200.00
0005432425061	13350	Economy	4200.00
0005432425054	13350	Economy	4200.00
0005432425048	13350	Economy	4200.00
0005432425031	13350	Economy	4200.00
0005432425046	13350	Economy	4200.00
0005432425043	13350	Economy	4200.00
0005432425070	13350	Economy	4200.00
0005432425010	13350	Economy	4200.00
0005432425055	13350	Economy	4200.00
0005432425062	13350	Economy	4200.00
0005432425067	13350	Economy	4200.00
0005432425044	13350	Economy	4200.00
0005432425024	13350	Economy	4200.00
0005432425056	13350	Economy	4200.00
0005432425049	13350	Economy	4200.00
0005432425013	13350	Economy	4200.00
0005432425058	13350	Economy	4200.00
0005432425019	13350	Economy	4200.00
0005432425015	13350	Economy	4200.00
0005432425071	13350	Economy	4200.00
0005432425035	13350	Economy	4200.00
0005432425023	13350	Economy	4200.00
0005432425069	13350	Economy	4200.00
0005432425038	13350	Economy	4200.00
0005432425020	13350	Economy	4200.00
0005432425030	13350	Economy	4200.00
0005432425053	13350	Economy	4200.00
0005432425012	13350	Economy	4200.00
0005432425060	13350	Economy	4200.00
0005432425014	13350	Economy	4200.00
0005432425021	13350	Economy	4200.00
0005432425041	13350	Economy	4200.00
0005432425051	13350	Economy	4200.00
0005432425045	13350	Economy	4200.00
0005432425074	13350	Economy	4200.00
0005432425065	13350	Economy	4200.00
0005432425068	13350	Economy	4200.00
0005432424635	30706	Business	12700.00
0005432424338	30706	Business	12700.00
0005432424491	30706	Economy	4200.00
0005432424595	30706	Economy	4200.00
0005432424582	30706	Economy	4700.00
0005432424638	30706	Economy	4700.00
0005432424587	30706	Economy	4200.00
0005432424632	30706	Economy	4200.00
0005432424537	30706	Economy	4200.00
0005432424647	30706	Economy	4200.00
0005432424515	30706	Economy	4200.00
0005432424650	30706	Economy	4200.00
0005432424631	30706	Economy	4200.00
0005432424393	30706	Economy	4200.00
0005432424603	30706	Economy	4200.00
0005432424609	30706	Economy	4200.00
0005432424629	30706	Economy	4200.00
0005432424577	30706	Economy	4200.00
0005432424525	30706	Economy	4200.00
0005432424664	30706	Economy	4200.00
0005432424538	30706	Economy	4200.00
0005432424614	30706	Economy	4200.00
0005432424634	30706	Economy	4200.00
0005432424620	30706	Economy	4200.00
0005432424469	30706	Economy	4200.00
0005432424627	30706	Economy	4200.00
0005432424474	30706	Economy	4200.00
0005432424471	30706	Economy	4200.00
0005432424600	30706	Economy	4200.00
0005432424448	30706	Economy	4200.00
0005432424606	30706	Economy	4200.00
0005432424670	30706	Economy	4200.00
0005432424637	30706	Economy	4200.00
0005432424378	30706	Economy	4200.00
0005432424663	30706	Economy	4200.00
0005432424510	30706	Economy	4200.00
0005432424583	30706	Economy	4200.00
0005432424578	30706	Economy	4200.00
0005432424630	30706	Economy	4200.00
0005432424633	30706	Economy	4200.00
0005432424654	30706	Economy	4200.00
0005432424590	30706	Economy	4200.00
0005432424584	30706	Economy	4200.00
0005432424673	30706	Economy	4200.00
0005432424619	30706	Economy	4200.00
0005432424526	30706	Economy	4200.00
0005432424639	30706	Economy	4200.00
0005432424473	30706	Economy	4200.00
0005432424626	30706	Economy	4200.00
0005432424379	30706	Economy	4200.00
0005432424601	30706	Economy	4200.00
0005432424470	30706	Economy	4200.00
0005432817857	9630	Business	32600.00
0005432822307	9630	Business	32600.00
0005432817873	9630	Business	32600.00
0005432822306	9630	Business	32600.00
0005432817851	9630	Business	32600.00
0005432901718	9630	Business	32600.00
0005432817861	9630	Economy	10900.00
0005432901599	9630	Economy	10900.00
0005432901655	9630	Economy	10900.00
0005432817868	9630	Economy	10900.00
0005432901689	9630	Economy	10900.00
0005432822303	9630	Economy	10900.00
0005432817859	9630	Economy	10900.00
0005432822308	9630	Economy	11900.00
0005434448360	9630	Economy	11900.00
0005432817852	9630	Economy	11900.00
0005432901688	9630	Economy	11900.00
0005434448362	9630	Economy	10900.00
0005432817850	9630	Economy	10900.00
0005432901638	9630	Economy	10900.00
0005432822309	9630	Economy	10900.00
0005432901716	9630	Economy	10900.00
0005432901677	9630	Economy	10900.00
0005434448361	9630	Economy	10900.00
0005432901667	9630	Economy	10900.00
0005434157538	9630	Economy	10900.00
0005432817855	9630	Economy	10900.00
0005432901755	9630	Economy	10900.00
0005432901742	9630	Economy	10900.00
0005432289030	9630	Economy	10900.00
0005432901687	9630	Economy	10900.00
0005432817871	9630	Economy	10900.00
0005432901717	9630	Economy	10900.00
0005432817863	9630	Economy	10900.00
0005432901583	9630	Economy	10900.00
0005432817866	9630	Economy	10900.00
0005432817872	9630	Economy	10900.00
0005432817867	9630	Economy	10900.00
0005432817856	9630	Economy	10900.00
0005432289031	9630	Economy	10900.00
0005432289032	9630	Economy	10900.00
0005432817862	9630	Economy	10900.00
0005432901696	9630	Economy	10900.00
0005432817878	9630	Economy	10900.00
0005432817876	9630	Economy	10900.00
0005432901758	9630	Economy	10900.00
0005432901668	9630	Economy	10900.00
0005432901654	9630	Economy	10900.00
0005432817879	9630	Economy	10900.00
0005432289028	9630	Economy	10900.00
0005432822305	9630	Economy	10900.00
0005432901582	9630	Economy	10900.00
0005432822302	9630	Economy	10900.00
0005432901769	9630	Economy	10900.00
0005432901695	9630	Economy	10900.00
0005432901653	9630	Economy	10900.00
0005432817875	9630	Economy	10900.00
0005432822304	9630	Economy	10900.00
0005432817860	9630	Economy	10900.00
0005432901690	9630	Economy	10900.00
0005432817858	9630	Economy	10900.00
0005432817864	9630	Economy	10900.00
0005432817877	9630	Economy	10900.00
0005432817854	9630	Economy	10900.00
0005432817870	9630	Economy	10900.00
0005432289029	9630	Economy	10900.00
0005432817869	9630	Economy	10900.00
0005432817865	9630	Economy	10900.00
0005432817853	9630	Economy	10900.00
0005432817874	9630	Economy	10900.00
0005432901686	9630	Economy	10900.00
0005434157584	28960	Business	32600.00
0005432901837	28960	Business	32600.00
0005432901843	28960	Business	32600.00
0005432817503	28960	Business	32600.00
0005432817689	28960	Business	32600.00
0005432822209	28960	Business	32600.00
0005432901839	28960	Business	32600.00
0005434448333	28960	Economy	10900.00
0005432901846	28960	Economy	10900.00
0005432817597	28960	Economy	10900.00
0005432817752	28960	Economy	10900.00
0005432817660	28960	Economy	10900.00
0005432822248	28960	Economy	10900.00
0005432817507	28960	Economy	10900.00
0005432822256	28960	Economy	10900.00
0005434157581	28960	Economy	11900.00
0005432901838	28960	Economy	11900.00
0005432817751	28960	Economy	11900.00
0005432822273	28960	Economy	10900.00
0005432901850	28960	Economy	10900.00
0005432817570	28960	Economy	10900.00
0005432817609	28960	Economy	10900.00
0005432901848	28960	Economy	10900.00
0005434186237	28960	Economy	10900.00
0005432817512	28960	Economy	10900.00
0005434186235	28960	Economy	10900.00
0005432817571	28960	Economy	10900.00
0005434448332	28960	Economy	10900.00
0005432901840	28960	Economy	10900.00
0005432817537	28960	Economy	10900.00
0005432817665	28960	Economy	10900.00
0005434157586	28960	Economy	10900.00
0005434157583	28960	Economy	10900.00
0005434157580	28960	Economy	10900.00
0005432822257	28960	Economy	10900.00
0005432901842	28960	Economy	10900.00
0005432817596	28960	Economy	10900.00
0005432822210	28960	Economy	10900.00
0005434157579	28960	Economy	10900.00
0005434448334	28960	Economy	10900.00
0005432901847	28960	Economy	10900.00
0005432901836	28960	Economy	10900.00
0005432901835	28960	Economy	10900.00
0005432901844	28960	Economy	10900.00
0005434157582	28960	Economy	10900.00
0005432901845	28960	Economy	10900.00
0005432901841	28960	Economy	10900.00
0005434186234	28960	Economy	10900.00
0005432817526	28960	Economy	10900.00
0005434448335	28960	Economy	10900.00
0005432901849	28960	Economy	10900.00
0005432822208	28960	Economy	10900.00
0005434186236	28960	Economy	10900.00
0005434157585	28960	Economy	10900.00
0005432822247	28960	Economy	10900.00
0005432817582	28960	Economy	10900.00
0005432822271	28960	Economy	10900.00
0005432611760	15077	Economy	11000.00
0005432613917	15077	Economy	11000.00
0005432611761	15077	Economy	11000.00
0005432613915	15077	Economy	11000.00
0005432613914	15077	Economy	11000.00
0005432611762	15077	Economy	11000.00
0005432613916	15077	Economy	11000.00
0005432611763	15077	Economy	11000.00
0005432613918	15077	Economy	11000.00
0005432611759	15077	Economy	11000.00
0005432607590	31603	Economy	11000.00
0005432607575	31603	Economy	11000.00
0005432607593	31603	Economy	11000.00
0005432607591	31603	Economy	11000.00
0005432607571	31603	Economy	11000.00
0005432607576	31603	Economy	11000.00
0005432607570	31603	Economy	11000.00
0005432611738	31603	Economy	11000.00
0005432611715	31603	Economy	11000.00
0005432611726	31603	Economy	11000.00
0005432611727	31603	Economy	11000.00
0005432948764	11869	Business	105900.00
0005433569767	11869	Business	105900.00
0005432948491	11869	Business	105900.00
0005433569806	11869	Business	105900.00
0005432948543	11869	Business	105900.00
0005433569813	11869	Business	105900.00
0005433569795	11869	Business	105900.00
0005432948641	11869	Business	105900.00
0005433569772	11869	Business	105900.00
0005433569787	11869	Business	105900.00
0005433569798	11869	Business	105900.00
0005432948683	11869	Business	105900.00
0005433569807	11869	Business	105900.00
0005432948727	11869	Business	105900.00
0005432948458	11869	Business	105900.00
0005433569782	11869	Business	105900.00
0005433569834	11869	Business	105900.00
0005433569778	11869	Business	105900.00
0005433569824	11869	Business	105900.00
0005433569805	11869	Business	105900.00
0005433569784	11869	Economy	35300.00
0005432948681	11869	Economy	35300.00
0005433569786	11869	Economy	35300.00
0005433569835	11869	Economy	35300.00
0005433569779	11869	Economy	35300.00
0005432948632	11869	Economy	35300.00
0005433569771	11869	Economy	35300.00
0005432948731	11869	Economy	35300.00
0005432948475	11869	Economy	35300.00
0005432948672	11869	Economy	35300.00
0005432948765	11869	Economy	35300.00
0005433569797	11869	Economy	35300.00
0005433569822	11869	Economy	38800.00
0005433569775	11869	Economy	38800.00
0005433569788	11869	Economy	38800.00
0005432948763	11869	Economy	35300.00
0005433569814	11869	Economy	35300.00
0005433569816	11869	Economy	35300.00
0005433569785	11869	Economy	35300.00
0005433569769	11869	Economy	35300.00
0005433569776	11869	Economy	35300.00
0005433569780	11869	Economy	35300.00
0005432948447	11869	Economy	35300.00
0005432948619	11869	Economy	35300.00
0005432948430	11869	Economy	35300.00
0005433569819	11869	Economy	35300.00
0005433569801	11869	Economy	35300.00
0005432948640	11869	Economy	35300.00
0005432948599	11869	Economy	35300.00
0005433569803	11869	Economy	35300.00
0005433569781	11869	Economy	35300.00
0005432948454	11869	Economy	35300.00
0005432948670	11869	Economy	35300.00
0005433569799	11869	Economy	35300.00
0005433569820	11869	Economy	35300.00
0005432948474	11869	Economy	35300.00
0005432948790	11869	Economy	35300.00
0005433569804	11869	Economy	35300.00
0005432948679	11869	Economy	35300.00
0005433569789	11869	Economy	35300.00
0005432948431	11869	Economy	35300.00
0005433569818	11869	Economy	35300.00
0005433569812	11869	Economy	35300.00
0005432948674	11869	Economy	35300.00
0005432948492	11869	Economy	35300.00
0005432948631	11869	Economy	35300.00
0005432948663	11869	Economy	35300.00
0005433569831	11869	Economy	35300.00
0005433569773	11869	Economy	35300.00
0005433569809	11869	Economy	35300.00
0005433569821	11869	Economy	35300.00
0005432948636	11869	Economy	35300.00
0005433569802	11869	Economy	35300.00
0005432948666	11869	Economy	35300.00
0005433569808	11869	Economy	35300.00
0005433569770	11869	Economy	35300.00
0005433569823	11869	Economy	35300.00
0005432948598	11869	Economy	35300.00
0005433569817	11869	Economy	35300.00
0005433569794	11869	Economy	35300.00
0005433569800	11869	Economy	35300.00
0005433569811	11869	Economy	35300.00
0005433569783	11869	Economy	35300.00
0005433569830	11869	Economy	35300.00
0005433569836	11869	Economy	35300.00
0005433569774	11869	Economy	35300.00
0005432948680	11869	Economy	35300.00
0005432948586	11869	Economy	35300.00
0005433569777	11869	Economy	35300.00
0005433569768	11869	Economy	35300.00
0005432948801	11869	Economy	35300.00
0005433569829	11869	Economy	35300.00
0005433569796	11869	Economy	35300.00
0005433569815	11869	Economy	35300.00
0005433569833	11869	Economy	35300.00
0005433569827	11869	Economy	35300.00
0005433569825	11869	Economy	35300.00
0005433569826	11869	Economy	35300.00
0005433569792	11869	Economy	35300.00
0005433569832	11869	Economy	35300.00
0005432948673	11869	Economy	35300.00
0005432948544	11869	Economy	35300.00
0005433569790	11869	Economy	35300.00
0005432948740	11869	Economy	35300.00
0005432948570	11869	Economy	35300.00
0005432948485	11869	Economy	35300.00
0005433569810	11869	Economy	35300.00
0005433569793	11869	Economy	35300.00
0005433569828	11869	Economy	35300.00
0005433569791	11869	Economy	35300.00
0005433569353	25276	Business	105900.00
0005433569403	25276	Business	105900.00
0005432949026	25276	Business	105900.00
0005433569227	25276	Business	105900.00
0005432949053	25276	Business	105900.00
0005433569099	25276	Business	105900.00
0005432949032	25276	Business	105900.00
0005432949055	25276	Business	105900.00
0005433569314	25276	Business	105900.00
0005432949023	25276	Business	105900.00
0005433568987	25276	Business	105900.00
0005433569268	25276	Business	105900.00
0005433569141	25276	Business	105900.00
0005432949046	25276	Business	105900.00
0005432949034	25276	Business	105900.00
0005433569077	25276	Business	105900.00
0005432949041	25276	Economy	35300.00
0005432949021	25276	Economy	35300.00
0005432949040	25276	Economy	35300.00
0005433569150	25276	Economy	35300.00
0005432949018	25276	Economy	35300.00
0005433569251	25276	Economy	35300.00
0005432949047	25276	Economy	35300.00
0005432949037	25276	Economy	35300.00
0005433569210	25276	Economy	35300.00
0005433569315	25276	Economy	35300.00
0005432949027	25276	Economy	38800.00
0005433569495	25276	Economy	38800.00
0005432949028	25276	Economy	35300.00
0005432949033	25276	Economy	38800.00
0005433569187	25276	Economy	35300.00
0005433569181	25276	Economy	35300.00
0005433569306	25276	Economy	35300.00
0005433569263	25276	Economy	35300.00
0005433569252	25276	Economy	35300.00
0005433569404	25276	Economy	35300.00
0005432949048	25276	Economy	35300.00
0005432949051	25276	Economy	35300.00
0005433569417	25276	Economy	35300.00
0005433569400	25276	Economy	35300.00
0005433569191	25276	Economy	35300.00
0005433569211	25276	Economy	35300.00
0005432949022	25276	Economy	35300.00
0005433569432	25276	Economy	35300.00
0005433569189	25276	Economy	35300.00
0005433569289	25276	Economy	35300.00
0005432949024	25276	Economy	35300.00
0005433569430	25276	Economy	35300.00
0005432949019	25276	Economy	35300.00
0005433569325	25276	Economy	35300.00
0005433569516	25276	Economy	35300.00
0005432949015	25276	Economy	35300.00
0005433569022	25276	Economy	35300.00
0005432949054	25276	Economy	35300.00
0005433569020	25276	Economy	35300.00
0005432949031	25276	Economy	35300.00
0005432949017	25276	Economy	35300.00
0005432949029	25276	Economy	35300.00
0005433569452	25276	Economy	35300.00
0005433569078	25276	Economy	35300.00
0005432949056	25276	Economy	35300.00
0005433569259	25276	Economy	35300.00
0005433569226	25276	Economy	35300.00
0005432949049	25276	Economy	35300.00
0005432949020	25276	Economy	35300.00
0005433569034	25276	Economy	35300.00
0005433569388	25276	Economy	35300.00
0005432949050	25276	Economy	35300.00
0005433569354	25276	Economy	35300.00
0005433569515	25276	Economy	35300.00
0005433569035	25276	Economy	35300.00
0005433569310	25276	Economy	35300.00
0005433569426	25276	Economy	35300.00
0005432949038	25276	Economy	35300.00
0005432949045	25276	Economy	35300.00
0005432949039	25276	Economy	35300.00
0005432949052	25276	Economy	35300.00
0005432949016	25276	Economy	35300.00
0005433569021	25276	Economy	35300.00
0005433569401	25276	Economy	35300.00
0005432949042	25276	Economy	35300.00
0005433569385	25276	Economy	35300.00
0005433569305	25276	Economy	35300.00
0005433569433	25276	Economy	35300.00
0005432949043	25276	Economy	35300.00
0005433569216	25276	Economy	35300.00
0005432949035	25276	Economy	35300.00
0005432949044	25276	Economy	35300.00
0005433569382	25276	Economy	35300.00
0005433569190	25276	Economy	35300.00
0005432949036	25276	Economy	35300.00
0005433569266	25276	Economy	35300.00
0005432949025	25276	Economy	35300.00
0005432949030	25276	Economy	35300.00
0005434656583	5365	Business	67200.00
0005435555386	5365	Business	67200.00
0005435340385	5365	Business	67200.00
0005435340316	5365	Business	67200.00
0005434655074	5365	Business	67200.00
0005435340334	5365	Business	67200.00
0005434655066	5365	Business	67200.00
0005435340335	5365	Economy	22400.00
0005434655078	5365	Economy	22400.00
0005434655083	5365	Economy	22400.00
0005434655064	5365	Economy	22400.00
0005434655069	5365	Economy	22400.00
0005434655065	5365	Economy	24600.00
0005434655082	5365	Economy	24600.00
0005432114245	5365	Economy	24600.00
0005435555385	5365	Economy	24600.00
0005435340384	5365	Economy	22400.00
0005435340345	5365	Economy	22400.00
0005435340342	5365	Economy	22400.00
0005434655061	5365	Economy	22400.00
0005434655084	5365	Economy	22400.00
0005432114247	5365	Economy	22400.00
0005434655076	5365	Economy	22400.00
0005432114244	5365	Economy	22400.00
0005432114246	5365	Economy	22400.00
0005434655081	5365	Economy	22400.00
0005434655073	5365	Economy	22400.00
0005434655070	5365	Economy	22400.00
0005434655060	5365	Economy	22400.00
0005434655067	5365	Economy	22400.00
0005434655062	5365	Economy	22400.00
0005435340377	5365	Economy	22400.00
0005434655071	5365	Economy	22400.00
0005434655058	5365	Economy	22400.00
0005435340297	5365	Economy	22400.00
0005434655072	5365	Economy	22400.00
0005435340279	5365	Economy	22400.00
0005434655059	5365	Economy	22400.00
0005434655057	5365	Economy	22400.00
0005434655079	5365	Economy	22400.00
0005434655063	5365	Economy	22400.00
0005435340379	5365	Economy	22400.00
0005434655075	5365	Economy	22400.00
0005434655068	5365	Economy	22400.00
0005435340321	5365	Economy	22400.00
0005434655077	5365	Economy	22400.00
0005434655080	5365	Economy	22400.00
0005434655085	5365	Economy	22400.00
0005434655056	5365	Economy	22400.00
0005435555382	5365	Economy	22400.00
0005435555387	5365	Economy	22400.00
0005434654769	12515	Business	67200.00
0005435555400	12515	Business	67200.00
0005434654836	12515	Business	67200.00
0005435340459	12515	Business	67200.00
0005434654927	12515	Business	67200.00
0005435340470	12515	Business	67200.00
0005434654919	12515	Business	67200.00
0005435340461	12515	Business	67200.00
0005435340468	12515	Economy	22400.00
0005435340466	12515	Economy	22400.00
0005434654893	12515	Economy	22400.00
0005434654835	12515	Economy	22400.00
0005434654874	12515	Economy	22400.00
0005435340457	12515	Economy	22400.00
0005434654801	12515	Economy	24600.00
0005435555398	12515	Economy	24600.00
0005434654796	12515	Economy	22400.00
0005434654873	12515	Economy	22400.00
0005434654820	12515	Economy	22400.00
0005435340471	12515	Economy	22400.00
0005434654797	12515	Economy	22400.00
0005434654916	12515	Economy	22400.00
0005434654847	12515	Economy	22400.00
0005434654867	12515	Economy	22400.00
0005435340462	12515	Economy	22400.00
0005434654821	12515	Economy	22400.00
0005434654930	12515	Economy	22400.00
0005434654859	12515	Economy	22400.00
0005434654965	12515	Economy	22400.00
0005434654760	12515	Economy	22400.00
0005434654880	12515	Economy	22400.00
0005434654772	12515	Economy	22400.00
0005434654825	12515	Economy	22400.00
0005434654879	12515	Economy	22400.00
0005434654811	12515	Economy	22400.00
0005434654831	12515	Economy	22400.00
0005434654809	12515	Economy	22400.00
0005434654812	12515	Economy	22400.00
0005434656560	12515	Economy	22400.00
0005434654824	12515	Economy	22400.00
0005434654846	12515	Economy	22400.00
0005434654864	12515	Economy	22400.00
0005435340464	12515	Economy	22400.00
0005434654773	12515	Economy	22400.00
0005434654858	12515	Economy	22400.00
0005435340460	12515	Economy	22400.00
0005435555399	12515	Economy	22400.00
0005435340463	12515	Economy	22400.00
0005435340458	12515	Economy	22400.00
0005434654895	12515	Economy	22400.00
0005435340469	12515	Economy	22400.00
0005434656571	12515	Economy	22400.00
0005435555397	12515	Economy	22400.00
0005435340465	12515	Economy	22400.00
0005435340467	12515	Economy	22400.00
0005434654777	12515	Economy	22400.00
0005434654872	12515	Economy	22400.00
0005433716613	7462	Business	32000.00
0005432078182	7462	Business	32000.00
0005433716625	7462	Business	32000.00
0005433716652	7462	Business	32000.00
0005432428950	7462	Business	32000.00
0005433716641	7462	Business	32000.00
0005433716626	7462	Business	32000.00
0005435266144	7462	Business	32000.00
0005433716642	7462	Business	32000.00
0005433716635	7462	Economy	10700.00
0005433716609	7462	Economy	10700.00
0005433716638	7462	Economy	10700.00
0005432078181	7462	Economy	10700.00
0005433716624	7462	Economy	10700.00
0005433716615	7462	Economy	10700.00
0005433716634	7462	Economy	10700.00
0005433716606	7462	Economy	10700.00
0005433719185	7462	Economy	10700.00
0005433722308	7462	Economy	10700.00
0005433716602	7462	Economy	10700.00
0005433716620	7462	Economy	10700.00
0005433716647	7462	Economy	10700.00
0005433716630	7462	Economy	10700.00
0005433722306	7462	Economy	10700.00
0005433719182	7462	Economy	10700.00
0005433722304	7462	Economy	10700.00
0005432428949	7462	Economy	10700.00
0005435266150	7462	Economy	10700.00
0005433716611	7462	Economy	10700.00
0005433690949	7462	Economy	10700.00
0005433716607	7462	Economy	10700.00
0005432078179	7462	Economy	10700.00
0005432078180	7462	Economy	11700.00
0005433716618	7462	Economy	11700.00
0005433716639	7462	Economy	11700.00
0005435266153	7462	Economy	10700.00
0005433716608	7462	Economy	10700.00
0005433716645	7462	Economy	10700.00
0005433688835	7462	Economy	10700.00
0005435266145	7462	Economy	10700.00
0005433716644	7462	Economy	10700.00
0005433716616	7462	Economy	10700.00
0005433716623	7462	Economy	10700.00
0005433716633	7462	Economy	10700.00
0005435266136	7462	Economy	10700.00
0005433716631	7462	Economy	10700.00
0005433690950	7462	Economy	10700.00
0005432078183	7462	Economy	10700.00
0005433716619	7462	Economy	10700.00
0005433716610	7462	Economy	10700.00
0005433716629	7462	Economy	10700.00
0005433716646	7462	Economy	10700.00
0005433716603	7462	Economy	10700.00
0005433716648	7462	Economy	10700.00
0005433716612	7462	Economy	10700.00
0005433719184	7462	Economy	10700.00
0005433722303	7462	Economy	10700.00
0005433716621	7462	Economy	10700.00
0005435266155	7462	Economy	10700.00
0005433719183	7462	Economy	10700.00
0005433688837	7462	Economy	10700.00
0005433716649	7462	Economy	10700.00
0005433716643	7462	Economy	10700.00
0005435266156	7462	Economy	10700.00
0005433716604	7462	Economy	10700.00
0005433656713	7462	Economy	10700.00
0005433716650	7462	Economy	10700.00
0005433716627	7462	Economy	10700.00
0005433716617	7462	Economy	10700.00
0005433716651	7462	Economy	10700.00
0005433716637	7462	Economy	10700.00
0005433688836	7462	Economy	10700.00
0005433688834	7462	Economy	10700.00
0005433722305	7462	Economy	10700.00
0005433656712	7462	Economy	10700.00
0005433716628	7462	Economy	10700.00
0005433716632	7462	Economy	10700.00
0005433716640	7462	Economy	10700.00
0005432428951	7462	Economy	10700.00
0005433716622	7462	Economy	10700.00
0005433716605	7462	Economy	10700.00
0005433716636	7462	Economy	10700.00
0005433716614	7462	Economy	10700.00
0005433722307	7462	Economy	10700.00
0005435266154	7462	Economy	10700.00
0005433689938	7462	Economy	10700.00
0005433656672	29239	Business	32000.00
0005433722276	29239	Business	32000.00
0005433716290	29239	Business	32000.00
0005433685525	29239	Business	32000.00
0005432428973	29239	Business	32000.00
0005433716043	29239	Business	32000.00
0005433716177	29239	Business	32000.00
0005433716231	29239	Business	32000.00
0005433685523	29239	Economy	10700.00
0005432006800	29239	Economy	10700.00
0005433715974	29239	Economy	10700.00
0005433716203	29239	Economy	10700.00
0005433716268	29239	Economy	10700.00
0005435266203	29239	Economy	10700.00
0005433716012	29239	Economy	10700.00
0005433722249	29239	Economy	10700.00
0005433716254	29239	Economy	10700.00
0005433716038	29239	Economy	10700.00
0005433716315	29239	Economy	10700.00
0005433716128	29239	Economy	10700.00
0005433716037	29239	Economy	10700.00
0005433715966	29239	Economy	10700.00
0005433722254	29239	Economy	10700.00
0005433722239	29239	Economy	10700.00
0005433716105	29239	Economy	10700.00
0005433685533	29239	Economy	10700.00
0005432006802	29239	Economy	10700.00
0005433716148	29239	Economy	10700.00
0005433716267	29239	Economy	10700.00
0005433716042	29239	Economy	10700.00
0005433716386	29239	Economy	10700.00
0005433719143	29239	Economy	10700.00
0005433716176	29239	Economy	10700.00
0005433716092	29239	Economy	10700.00
0005433722255	29239	Economy	10700.00
0005433716255	29239	Economy	10700.00
0005433716107	29239	Economy	10700.00
0005435266201	29239	Economy	10700.00
0005433722233	29239	Economy	10700.00
0005433719154	29239	Economy	10700.00
0005432006803	29239	Economy	10700.00
0005433719135	29239	Economy	10700.00
0005432006799	29239	Economy	11700.00
0005433685522	29239	Economy	11700.00
0005433716289	29239	Economy	11700.00
0005433716385	29239	Economy	11700.00
0005433656688	29239	Economy	11700.00
0005433656695	29239	Economy	11700.00
0005433716013	29239	Economy	10700.00
0005433716205	29239	Economy	10700.00
0005433722256	29239	Economy	10700.00
0005433716295	29239	Economy	10700.00
0005433722241	29239	Economy	10700.00
0005433716021	29239	Economy	10700.00
0005433716027	29239	Economy	10700.00
0005433716281	29239	Economy	10700.00
0005433722240	29239	Economy	10700.00
0005433716219	29239	Economy	10700.00
0005433716361	29239	Economy	10700.00
0005433722274	29239	Economy	10700.00
0005433722246	29239	Economy	10700.00
0005433716334	29239	Economy	10700.00
0005433716218	29239	Economy	10700.00
0005433722243	29239	Economy	10700.00
0005433715996	29239	Economy	10700.00
0005433716435	29239	Economy	10700.00
0005433722275	29239	Economy	10700.00
0005433722244	29239	Economy	10700.00
0005432006801	29239	Economy	10700.00
0005433722232	29239	Economy	10700.00
0005433716065	29239	Economy	10700.00
0005433722252	29239	Economy	10700.00
0005433716364	29239	Economy	10700.00
0005433716303	29239	Economy	10700.00
0005433716359	29239	Economy	10700.00
0005433716086	29239	Economy	10700.00
0005433716314	29239	Economy	10700.00
0005435266202	29239	Economy	10700.00
0005433716279	29239	Economy	10700.00
0005433716169	29239	Economy	10700.00
0005433719146	29239	Economy	10700.00
0005433716020	29239	Economy	10700.00
0005433719163	29239	Economy	10700.00
0005433685521	29239	Economy	10700.00
0005433722242	29239	Economy	10700.00
0005433716360	29239	Economy	10700.00
0005433716001	29239	Economy	10700.00
0005433716028	29239	Economy	10700.00
0005433716391	29239	Economy	10700.00
0005433716106	29239	Economy	10700.00
0005433716327	29239	Economy	10700.00
0005433656696	29239	Economy	10700.00
0005433716363	29239	Economy	10700.00
0005433719161	29239	Economy	10700.00
0005433716067	29239	Economy	10700.00
0005432428975	29239	Economy	10700.00
0005433716204	29239	Economy	10700.00
0005433716066	29239	Economy	10700.00
0005433716280	29239	Economy	10700.00
0005433685532	29239	Economy	10700.00
0005433716129	29239	Economy	10700.00
0005432428974	29239	Economy	10700.00
0005433716014	29239	Economy	10700.00
0005433719166	29239	Economy	10700.00
0005433716002	29239	Economy	10700.00
0005434184674	8705	Business	36500.00
0005434184676	8705	Business	36500.00
0005434095468	8705	Business	36500.00
0005434182334	8705	Business	36500.00
0005434182254	8705	Business	36500.00
0005434095469	8705	Economy	12200.00
0005434182236	8705	Economy	12200.00
0005434095460	8705	Economy	12200.00
0005434095465	8705	Economy	12200.00
0005434095472	8705	Economy	12200.00
0005434182235	8705	Economy	12200.00
0005434182287	8705	Economy	12200.00
0005434095467	8705	Economy	12200.00
0005434182234	8705	Economy	12200.00
0005434184680	8705	Economy	12200.00
0005434095459	8705	Economy	12200.00
0005434182291	8705	Economy	12200.00
0005434095461	8705	Economy	12200.00
0005434182255	8705	Economy	12200.00
0005434182240	8705	Economy	12200.00
0005434095466	8705	Economy	12200.00
0005434095470	8705	Economy	12200.00
0005434182239	8705	Economy	12200.00
0005434095471	8705	Economy	12200.00
0005434095462	8705	Economy	12200.00
0005434182265	8705	Economy	12200.00
0005434182218	8705	Economy	12200.00
0005434095463	8705	Economy	12200.00
0005434182195	8705	Economy	12200.00
0005434095464	8705	Economy	12200.00
0005434182264	8705	Economy	12200.00
0005434182263	8705	Economy	12200.00
0005434182219	8705	Economy	12200.00
0005434184681	8705	Economy	12200.00
0005434182333	8705	Economy	12200.00
0005434184689	11671	Business	36500.00
0005434095406	11671	Business	36500.00
0005434182349	11671	Business	36500.00
0005434095330	11671	Business	36500.00
0005434095338	11671	Business	36500.00
0005434095271	11671	Economy	12200.00
0005434095329	11671	Economy	12200.00
0005434182353	11671	Economy	12200.00
0005434143730	11671	Economy	13400.00
0005434182354	11671	Economy	13400.00
0005434095324	11671	Economy	12200.00
0005434182356	11671	Economy	12200.00
0005434143740	11671	Economy	12200.00
0005434095370	11671	Economy	12200.00
0005434095337	11671	Economy	12200.00
0005434182350	11671	Economy	12200.00
0005434095368	11671	Economy	12200.00
0005434184690	11671	Economy	12200.00
0005434095360	11671	Economy	12200.00
0005434182346	11671	Economy	12200.00
0005434143739	11671	Economy	12200.00
0005434095348	11671	Economy	12200.00
0005434183605	11671	Economy	12200.00
0005434182351	11671	Economy	12200.00
0005434183604	11671	Economy	12200.00
0005434182345	11671	Economy	12200.00
0005434182352	11671	Economy	12200.00
0005434095383	11671	Economy	12200.00
0005434182348	11671	Economy	12200.00
0005434182347	11671	Economy	12200.00
0005434095367	11671	Economy	12200.00
0005434182355	11671	Economy	12200.00
0005434095328	11671	Economy	12200.00
0005434143733	11671	Economy	12200.00
0005434095373	11671	Economy	12200.00
0005434095369	11671	Economy	12200.00
0005433398148	1437	Business	33000.00
0005435732498	1437	Business	33000.00
0005435732495	1437	Business	33000.00
0005433457023	1437	Business	33000.00
0005433398401	1437	Business	33000.00
0005435732502	1437	Business	33000.00
0005433398368	1437	Business	33000.00
0005435732493	1437	Business	33000.00
0005433398237	1437	Business	33000.00
0005433398112	1437	Business	33000.00
0005433398182	1437	Business	33000.00
0005433398230	1437	Economy	11000.00
0005433398303	1437	Economy	11000.00
0005435732499	1437	Economy	11000.00
0005435732505	1437	Economy	11000.00
0005433457022	1437	Economy	11000.00
0005433398304	1437	Economy	11000.00
0005433398203	1437	Economy	11000.00
0005433398239	1437	Economy	11000.00
0005433398422	1437	Economy	12100.00
0005433457021	1437	Economy	12100.00
0005433398334	1437	Economy	12100.00
0005435732511	1437	Economy	12100.00
0005435732507	1437	Economy	11000.00
0005433398403	1437	Economy	11000.00
0005432297311	1437	Economy	11000.00
0005435732497	1437	Economy	11000.00
0005435732494	1437	Economy	11000.00
0005433398204	1437	Economy	11000.00
0005433398284	1437	Economy	11000.00
0005433398567	1437	Economy	11000.00
0005435732509	1437	Economy	11000.00
0005435732496	1437	Economy	11000.00
0005433398385	1437	Economy	11000.00
0005432297314	1437	Economy	11000.00
0005433398335	1437	Economy	11000.00
0005433398313	1437	Economy	11000.00
0005433398513	1437	Economy	11000.00
0005433398336	1437	Economy	11000.00
0005433398238	1437	Economy	11000.00
0005433398370	1437	Economy	11000.00
0005432297313	1437	Economy	11000.00
0005433398191	1437	Economy	11000.00
0005433398205	1437	Economy	11000.00
0005435732501	1437	Economy	11000.00
0005433398129	1437	Economy	11000.00
0005433398404	1437	Economy	11000.00
0005433398286	1437	Economy	11000.00
0005435732503	1437	Economy	11000.00
0005433398209	1437	Economy	11000.00
0005433398249	1437	Economy	11000.00
0005433398388	1437	Economy	11000.00
0005435732500	1437	Economy	11000.00
0005433398202	1437	Economy	11000.00
0005433398402	1437	Economy	11000.00
0005433398236	1437	Economy	11000.00
0005433398147	1437	Economy	11000.00
0005435732508	1437	Economy	11000.00
0005435732506	1437	Economy	11000.00
0005433398285	1437	Economy	11000.00
0005433457024	1437	Economy	11000.00
0005433398058	1437	Economy	11000.00
0005433398130	1437	Economy	11000.00
0005433398159	1437	Economy	11000.00
0005433398259	1437	Economy	11000.00
0005433398131	1437	Economy	11000.00
0005433398387	1437	Economy	11000.00
0005435732504	1437	Economy	11000.00
0005433398312	1437	Economy	11000.00
0005432297312	1437	Economy	11000.00
0005435732510	1437	Economy	11000.00
0005433398242	1437	Economy	11000.00
0005433398111	1437	Economy	11000.00
0005433398703	19250	Business	33000.00
0005433398695	19250	Business	33000.00
0005433398715	19250	Business	33000.00
0005433398691	19250	Business	33000.00
0005433398714	19250	Business	33000.00
0005433398683	19250	Business	33000.00
0005433398674	19250	Business	33000.00
0005433398688	19250	Business	33000.00
0005435732413	19250	Economy	11000.00
0005433398680	19250	Economy	11000.00
0005435732381	19250	Economy	11000.00
0005433398677	19250	Economy	11000.00
0005433398689	19250	Economy	11000.00
0005435732392	19250	Economy	11000.00
0005433398718	19250	Economy	12100.00
0005433398670	19250	Economy	12100.00
0005433398701	19250	Economy	12100.00
0005433398711	19250	Economy	12100.00
0005433398672	19250	Economy	11000.00
0005433398681	19250	Economy	11000.00
0005435732389	19250	Economy	11000.00
0005433398687	19250	Economy	11000.00
0005433398676	19250	Economy	11000.00
0005433398690	19250	Economy	11000.00
0005435732366	19250	Economy	11000.00
0005433398671	19250	Economy	11000.00
0005433398713	19250	Economy	11000.00
0005435732326	19250	Economy	11000.00
0005432906568	19250	Economy	11000.00
0005435732412	19250	Economy	11000.00
0005433398685	19250	Economy	11000.00
0005433398706	19250	Economy	11000.00
0005433398705	19250	Economy	11000.00
0005433398697	19250	Economy	11000.00
0005435732347	19250	Economy	11000.00
0005433398696	19250	Economy	11000.00
0005433398682	19250	Economy	11000.00
0005433398675	19250	Economy	11000.00
0005435732367	19250	Economy	11000.00
0005433398698	19250	Economy	11000.00
0005435732348	19250	Economy	11000.00
0005433398716	19250	Economy	11000.00
0005433398717	19250	Economy	11000.00
0005433398679	19250	Economy	11000.00
0005435732325	19250	Economy	11000.00
0005433398686	19250	Economy	11000.00
0005435732378	19250	Economy	11000.00
0005433398704	19250	Economy	11000.00
0005435732450	19250	Economy	11000.00
0005433398693	19250	Economy	11000.00
0005433398712	19250	Economy	11000.00
0005433398708	19250	Economy	11000.00
0005435732393	19250	Economy	11000.00
0005433398692	19250	Economy	11000.00
0005433398707	19250	Economy	11000.00
0005433398694	19250	Economy	11000.00
0005433398702	19250	Economy	11000.00
0005433398699	19250	Economy	11000.00
0005433398684	19250	Economy	11000.00
0005432906570	19250	Economy	11000.00
0005432906569	19250	Economy	11000.00
0005433398673	19250	Economy	11000.00
0005432906567	19250	Economy	11000.00
0005433398700	19250	Economy	11000.00
0005433398719	19250	Economy	11000.00
0005433398710	19250	Economy	11000.00
0005435732388	19250	Economy	11000.00
0005433398709	19250	Economy	11000.00
0005433398678	19250	Economy	11000.00
0005434443803	17343	Economy	14100.00
0005434443826	17343	Economy	14100.00
0005434443771	17343	Economy	14100.00
0005434443829	17343	Economy	14100.00
0005434443760	17343	Economy	14100.00
0005434443762	17343	Economy	14100.00
0005434443701	17343	Economy	14100.00
0005434443761	17343	Economy	14100.00
0005434443729	17343	Economy	14100.00
0005434443784	17343	Economy	14100.00
0005434443773	17343	Economy	14100.00
0005434443857	17343	Economy	14100.00
0005434443774	17343	Economy	14100.00
0005434443804	17343	Economy	14100.00
0005434443769	17343	Economy	14100.00
0005434443772	17343	Economy	14100.00
0005434443908	20595	Economy	15600.00
0005434443917	20595	Economy	14100.00
0005434443913	20595	Economy	14100.00
0005434443919	20595	Economy	14100.00
0005434443911	20595	Economy	14100.00
0005434443904	20595	Economy	14100.00
0005434443918	20595	Economy	14100.00
0005434443905	20595	Economy	14100.00
0005434443912	20595	Economy	14100.00
0005434443910	20595	Economy	14100.00
0005434443909	20595	Economy	14100.00
0005434443916	20595	Economy	14100.00
0005434443903	20595	Economy	14100.00
0005434443907	20595	Economy	14100.00
0005434443906	20595	Economy	14100.00
0005434443914	20595	Economy	14100.00
0005434443915	20595	Economy	14100.00
0005434954660	7263	Economy	5800.00
0005434954662	7263	Economy	5800.00
0005434954661	7263	Economy	5800.00
0005435377611	28339	Economy	5800.00
0005434954619	28339	Economy	5800.00
0005434351863	4480	Economy	15400.00
0005434183591	4480	Economy	15400.00
0005434183592	4480	Economy	15400.00
0005434351865	4480	Economy	14000.00
0005434351869	4480	Economy	14000.00
0005435893680	4480	Economy	14000.00
0005435893668	4480	Economy	14000.00
0005434351860	4480	Economy	14000.00
0005434351862	4480	Economy	14000.00
0005434351864	4480	Economy	14000.00
0005434351867	4480	Economy	14000.00
0005434183588	4480	Economy	14000.00
0005435893665	4480	Economy	14000.00
0005434351866	4480	Economy	14000.00
0005435893692	4480	Economy	14000.00
0005434183581	4480	Economy	14000.00
0005435893671	4480	Economy	14000.00
0005434351859	4480	Economy	14000.00
0005435893693	4480	Economy	14000.00
0005434351857	4480	Economy	14000.00
0005434351868	4480	Economy	14000.00
0005434183589	4480	Economy	14000.00
0005434351858	4480	Economy	14000.00
0005434351861	4480	Economy	14000.00
0005435893725	29649	Economy	15400.00
0005434351747	29649	Economy	15400.00
0005434351702	29649	Economy	15400.00
0005435893726	29649	Economy	14000.00
0005435893723	29649	Economy	14000.00
0005434351746	29649	Economy	14000.00
0005434351757	29649	Economy	14000.00
0005434351731	29649	Economy	14000.00
0005434351772	29649	Economy	14000.00
0005435893724	29649	Economy	14000.00
0005434351756	29649	Economy	14000.00
0005434351710	29649	Economy	14000.00
0005435893728	29649	Economy	14000.00
0005434351793	29649	Economy	14000.00
0005435893727	29649	Economy	14000.00
0005434351718	29649	Economy	14000.00
0005434351741	29649	Economy	14000.00
0005434351792	29649	Economy	14000.00
0005434351761	29649	Economy	14000.00
0005433343662	1060	Business	30600.00
0005433343415	1060	Business	30600.00
0005433343193	1060	Business	30600.00
0005433269741	1060	Business	30600.00
0005433343652	1060	Business	30600.00
0005433342979	1060	Business	30600.00
0005433343739	1060	Business	30600.00
0005433343498	1060	Business	30600.00
0005435092210	1060	Business	30600.00
0005435545845	1060	Business	30600.00
0005433343278	1060	Business	30600.00
0005433342964	1060	Business	30600.00
0005433343405	1060	Business	30600.00
0005433158144	1060	Business	30600.00
0005433343231	1060	Business	30600.00
0005433343567	1060	Business	30600.00
0005433343513	1060	Business	30600.00
0005433343855	1060	Economy	11200.00
0005433343331	1060	Economy	11200.00
0005433343691	1060	Economy	10200.00
0005433343859	1060	Economy	10200.00
0005433343510	1060	Economy	10200.00
0005433343766	1060	Economy	10200.00
0005433342980	1060	Economy	10200.00
0005433343805	1060	Economy	10200.00
0005433343965	1060	Economy	10200.00
0005435092205	1060	Economy	10200.00
0005433343493	1060	Economy	10200.00
0005433343584	1060	Economy	10200.00
0005433158145	1060	Economy	10200.00
0005433343400	1060	Economy	10200.00
0005433343709	1060	Economy	10200.00
0005433269732	1060	Economy	10200.00
0005433342963	1060	Economy	10200.00
0005433343707	1060	Economy	10200.00
0005435092203	1060	Economy	10200.00
0005433343533	1060	Economy	10200.00
0005433343621	1060	Economy	10200.00
0005433343339	1060	Economy	10200.00
0005433343610	1060	Economy	10200.00
0005434446548	1060	Economy	10200.00
0005433343343	1060	Economy	10200.00
0005433343454	1060	Economy	10200.00
0005433343317	1060	Economy	10200.00
0005433343347	1060	Economy	10200.00
0005433159321	1060	Economy	10200.00
0005433343806	1060	Economy	10200.00
0005433343499	1060	Economy	10200.00
0005433343816	1060	Economy	10200.00
0005435092200	1060	Economy	10200.00
0005433462774	1060	Economy	10200.00
0005433343575	1060	Economy	10200.00
0005433343127	1060	Economy	10200.00
0005433343643	1060	Economy	10200.00
0005433343595	1060	Economy	10200.00
0005433343594	1060	Economy	10200.00
0005433343484	1060	Economy	10200.00
0005433343429	1060	Economy	10200.00
0005433343573	1060	Economy	10200.00
0005433343406	1060	Economy	10200.00
0005433343419	1060	Economy	10200.00
0005435092209	1060	Economy	10200.00
0005432293242	1060	Economy	10200.00
0005433462775	1060	Economy	10200.00
0005433343279	1060	Economy	10200.00
0005433343194	1060	Economy	10200.00
0005433269731	1060	Economy	10200.00
0005434446550	1060	Economy	10200.00
0005433343301	1060	Economy	10200.00
0005433343345	1060	Economy	10200.00
0005435092207	1060	Economy	10200.00
0005433343550	1060	Economy	10200.00
0005433343338	1060	Economy	10200.00
0005433269758	1060	Economy	10200.00
0005434446549	1060	Economy	10200.00
0005433343316	1060	Economy	10200.00
0005433343468	1060	Economy	10200.00
0005433343514	1060	Economy	10200.00
0005433343039	1060	Economy	10200.00
0005433343356	1060	Economy	11200.00
0005433343656	1060	Economy	10200.00
0005433343509	1060	Economy	10200.00
0005433343651	1060	Economy	11200.00
0005433343708	1060	Economy	10200.00
0005433343783	1060	Economy	10200.00
0005433343275	1060	Economy	10200.00
0005433343428	1060	Economy	10200.00
0005433343615	1060	Economy	10200.00
0005433343966	1060	Economy	10200.00
0005433343620	1060	Economy	10200.00
0005433343840	1060	Economy	10200.00
0005433342978	1060	Economy	10200.00
0005433343492	1060	Economy	10200.00
0005433343784	1060	Economy	10200.00
0005433343697	1060	Economy	10200.00
0005432293241	1060	Economy	10200.00
0005433343616	1060	Economy	10200.00
0005433343414	1060	Economy	10200.00
0005433343453	1060	Economy	10200.00
0005433343964	1060	Economy	10200.00
0005434445273	1060	Economy	10200.00
0005433343732	1060	Economy	10200.00
0005435092208	1060	Economy	10200.00
0005433343276	1060	Economy	10200.00
0005433343333	1060	Economy	10200.00
0005433343680	1060	Economy	10200.00
0005433343731	1060	Economy	10200.00
0005433343527	1060	Economy	10200.00
0005433343552	1060	Economy	10200.00
0005433343661	1060	Economy	10200.00
0005433343751	1060	Economy	10200.00
0005433343452	1060	Economy	10200.00
0005433343757	1060	Economy	10200.00
0005435545846	1060	Economy	10200.00
0005435092202	1060	Economy	10200.00
0005433343202	1060	Economy	10200.00
0005433343748	1060	Economy	10200.00
0005433343611	1060	Economy	10200.00
0005433269746	1060	Economy	10200.00
0005433343432	1060	Economy	10200.00
0005433343344	1060	Economy	10200.00
0005433343698	1060	Economy	10200.00
0005435092206	1060	Economy	10200.00
0005433343549	1060	Economy	10200.00
0005435092204	1060	Economy	10200.00
0005433343300	1060	Economy	10200.00
0005433343380	1060	Economy	10200.00
0005433343557	1060	Economy	10200.00
0005433159320	1060	Economy	10200.00
0005432293240	1060	Economy	10200.00
0005433343431	1060	Economy	10200.00
0005433343332	1060	Economy	10200.00
0005435092201	1060	Economy	10200.00
0005433343717	1060	Economy	10200.00
0005433343568	1060	Economy	10200.00
0005433343660	1060	Economy	10200.00
0005433344411	17026	Business	30600.00
0005433344339	17026	Business	30600.00
0005433344364	17026	Business	30600.00
0005433344331	17026	Business	30600.00
0005433344427	17026	Business	30600.00
0005435092172	17026	Business	30600.00
0005433344417	17026	Business	30600.00
0005433344397	17026	Business	30600.00
0005433344383	17026	Business	30600.00
0005433344336	17026	Business	30600.00
0005433344334	17026	Business	30600.00
0005433344366	17026	Business	30600.00
0005433344409	17026	Business	30600.00
0005433344333	17026	Business	30600.00
0005433344380	17026	Business	30600.00
0005433344386	17026	Business	30600.00
0005433269789	17026	Business	30600.00
0005433344358	17026	Business	30600.00
0005433344403	17026	Business	30600.00
0005433344350	17026	Business	30600.00
0005433344335	17026	Business	30600.00
0005433344394	17026	Business	30600.00
0005433344388	17026	Economy	11200.00
0005433159342	17026	Economy	11200.00
0005433344422	17026	Economy	10200.00
0005433344340	17026	Economy	10200.00
0005433344429	17026	Economy	10200.00
0005433344342	17026	Economy	10200.00
0005433344381	17026	Economy	10200.00
0005433344416	17026	Economy	10200.00
0005433344385	17026	Economy	10200.00
0005433344365	17026	Economy	10200.00
0005433344371	17026	Economy	10200.00
0005433344360	17026	Economy	10200.00
0005433344379	17026	Economy	10200.00
0005433344343	17026	Economy	10200.00
0005433344410	17026	Economy	10200.00
0005433344404	17026	Economy	10200.00
0005433344396	17026	Economy	10200.00
0005433344398	17026	Economy	10200.00
0005433344359	17026	Economy	10200.00
0005435092143	17026	Economy	10200.00
0005433159341	17026	Economy	10200.00
0005433344418	17026	Economy	10200.00
0005433344375	17026	Economy	10200.00
0005433344373	17026	Economy	10200.00
0005434445250	17026	Economy	10200.00
0005435092136	17026	Economy	10200.00
0005433344413	17026	Economy	10200.00
0005433344330	17026	Economy	10200.00
0005433344428	17026	Economy	10200.00
0005433344357	17026	Economy	10200.00
0005433269788	17026	Economy	10200.00
0005433344415	17026	Economy	10200.00
0005433344332	17026	Economy	10200.00
0005433344382	17026	Economy	10200.00
0005433344352	17026	Economy	10200.00
0005433344387	17026	Economy	10200.00
0005433344419	17026	Economy	10200.00
0005433344425	17026	Economy	10200.00
0005433344376	17026	Economy	10200.00
0005433344346	17026	Economy	10200.00
0005433344374	17026	Economy	10200.00
0005433344420	17026	Economy	10200.00
0005433344431	17026	Economy	10200.00
0005433344405	17026	Economy	10200.00
0005433344355	17026	Economy	10200.00
0005433344377	17026	Economy	10200.00
0005435508377	17026	Economy	10200.00
0005433344424	17026	Economy	10200.00
0005433344345	17026	Economy	10200.00
0005433344432	17026	Economy	10200.00
0005433344402	17026	Economy	10200.00
0005433344344	17026	Economy	10200.00
0005433344423	17026	Economy	10200.00
0005433344370	17026	Economy	10200.00
0005433344430	17026	Economy	10200.00
0005433344362	17026	Economy	10200.00
0005433344395	17026	Economy	10200.00
0005433344353	17026	Economy	10200.00
0005435092167	17026	Economy	10200.00
0005433344338	17026	Economy	11200.00
0005435092166	17026	Economy	11200.00
0005433344363	17026	Economy	11200.00
0005435508361	17026	Economy	10200.00
0005433344412	17026	Economy	10200.00
0005433344393	17026	Economy	10200.00
0005433344369	17026	Economy	10200.00
0005433344356	17026	Economy	10200.00
0005433344341	17026	Economy	10200.00
0005433269790	17026	Economy	10200.00
0005433344391	17026	Economy	10200.00
0005433344368	17026	Economy	10200.00
0005433344389	17026	Economy	10200.00
0005433344361	17026	Economy	10200.00
0005433344337	17026	Economy	10200.00
0005433344349	17026	Economy	10200.00
0005433344351	17026	Economy	10200.00
0005433159343	17026	Economy	10200.00
0005433344400	17026	Economy	10200.00
0005433344401	17026	Economy	10200.00
0005433344367	17026	Economy	10200.00
0005435508369	17026	Economy	10200.00
0005433344354	17026	Economy	10200.00
0005435092149	17026	Economy	10200.00
0005433344372	17026	Economy	10200.00
0005433344406	17026	Economy	10200.00
0005433269792	17026	Economy	10200.00
0005435508376	17026	Economy	10200.00
0005433344407	17026	Economy	10200.00
0005433269791	17026	Economy	10200.00
0005433344390	17026	Economy	10200.00
0005433344408	17026	Economy	10200.00
0005433344399	17026	Economy	10200.00
0005433344414	17026	Economy	10200.00
0005433344421	17026	Economy	10200.00
0005433344348	17026	Economy	10200.00
0005433159340	17026	Economy	10200.00
0005435092173	17026	Economy	10200.00
0005433344426	17026	Economy	10200.00
0005433344384	17026	Economy	10200.00
0005433344378	17026	Economy	10200.00
0005433344392	17026	Economy	10200.00
0005433344347	17026	Economy	10200.00
0005432390272	1338	Business	101000.00
0005432390286	1338	Business	101000.00
0005432390284	1338	Business	101000.00
0005432390275	1338	Business	101000.00
0005432390283	1338	Business	101000.00
0005432851943	1338	Business	101000.00
0005432390295	1338	Business	101000.00
0005432851944	1338	Business	101000.00
0005432390273	1338	Business	101000.00
0005432851940	1338	Economy	33700.00
0005432390279	1338	Economy	33700.00
0005432390277	1338	Economy	33700.00
0005432392034	1338	Economy	33700.00
0005432851955	1338	Economy	33700.00
0005432390267	1338	Economy	33700.00
0005432390293	1338	Economy	33700.00
0005432390299	1338	Economy	37000.00
0005432390290	1338	Economy	37000.00
0005432390271	1338	Economy	37000.00
0005432851930	1338	Economy	33700.00
0005432851921	1338	Economy	33700.00
0005432392031	1338	Economy	33700.00
0005432851914	1338	Economy	33700.00
0005432851931	1338	Economy	33700.00
0005432390280	1338	Economy	33700.00
0005432851934	1338	Economy	33700.00
0005432392030	1338	Economy	33700.00
0005432390288	1338	Economy	33700.00
0005432851939	1338	Economy	33700.00
0005432390287	1338	Economy	33700.00
0005432392033	1338	Economy	33700.00
0005432390269	1338	Economy	33700.00
0005432390276	1338	Economy	33700.00
0005432392032	1338	Economy	33700.00
0005432851949	1338	Economy	33700.00
0005432851957	1338	Economy	33700.00
0005432390266	1338	Economy	33700.00
0005432390294	1338	Economy	33700.00
0005432390278	1338	Economy	33700.00
0005432390298	1338	Economy	33700.00
0005432392035	1338	Economy	33700.00
0005432390282	1338	Economy	33700.00
0005432390281	1338	Economy	33700.00
0005432392037	1338	Economy	33700.00
0005432390300	1338	Economy	33700.00
0005432390291	1338	Economy	33700.00
0005432851948	1338	Economy	33700.00
0005432390285	1338	Economy	33700.00
0005432851919	1338	Economy	33700.00
0005432390274	1338	Economy	33700.00
0005432392036	1338	Economy	33700.00
0005432390289	1338	Economy	33700.00
0005432851927	1338	Economy	33700.00
0005432851929	1338	Economy	33700.00
0005432851935	1338	Economy	33700.00
0005432390297	1338	Economy	33700.00
0005432390270	1338	Economy	33700.00
0005432851947	1338	Economy	33700.00
0005432390292	1338	Economy	33700.00
0005432851920	1338	Economy	33700.00
0005432390268	1338	Economy	33700.00
0005432390296	1338	Economy	33700.00
0005432392029	1338	Economy	33700.00
0005434082091	12793	Business	40300.00
0005434067681	12793	Business	40300.00
0005434067580	12793	Business	40300.00
0005434081959	12793	Business	40300.00
0005434081925	12793	Business	40300.00
0005432161183	12793	Business	40300.00
0005432433750	12793	Business	40300.00
0005434067557	12793	Business	40300.00
0005434067744	12793	Business	40300.00
0005432433751	12793	Business	40300.00
0005434081992	12793	Business	40300.00
0005434067883	12793	Economy	13400.00
0005434081878	12793	Economy	13400.00
0005434082025	12793	Economy	13400.00
0005434081919	12793	Economy	13400.00
0005434067796	12793	Economy	13400.00
0005432159920	12793	Economy	13400.00
0005434067668	12793	Economy	13400.00
0005434067958	12793	Economy	13400.00
0005433989786	12793	Economy	13400.00
0005433989778	12793	Economy	13400.00
0005434068187	12793	Economy	13400.00
0005434068177	12793	Economy	13400.00
0005434067933	12793	Economy	13400.00
0005434067743	12793	Economy	13400.00
0005432161181	12793	Economy	13400.00
0005434067908	12793	Economy	13400.00
0005434067998	12793	Economy	13400.00
0005434067896	12793	Economy	13400.00
0005433989792	12793	Economy	13400.00
0005434067661	12793	Economy	13400.00
0005432433748	12793	Economy	13400.00
0005434068235	12793	Economy	13400.00
0005434068176	12793	Economy	13400.00
0005434081976	12793	Economy	13400.00
0005434067680	12793	Economy	13400.00
0005434067900	12793	Economy	13400.00
0005434082090	12793	Economy	13400.00
0005434067783	12793	Economy	13400.00
0005434081999	12793	Economy	13400.00
0005434082024	12793	Economy	13400.00
0005434067892	12793	Economy	13400.00
0005432159918	12793	Economy	13400.00
0005434067902	12793	Economy	13400.00
0005434067740	12793	Economy	13400.00
0005434067956	12793	Economy	13400.00
0005434067901	12793	Economy	14800.00
0005432433752	12793	Economy	14800.00
0005434067884	12793	Economy	14800.00
0005434068030	12793	Economy	14800.00
0005434082071	12793	Economy	14800.00
0005434081918	12793	Economy	14800.00
0005434067903	12793	Economy	13400.00
0005434067964	12793	Economy	13400.00
0005433989793	12793	Economy	13400.00
0005433989796	12793	Economy	13400.00
0005434067706	12793	Economy	13400.00
0005434067893	12793	Economy	13400.00
0005434081956	12793	Economy	13400.00
0005434067963	12793	Economy	13400.00
0005433989785	12793	Economy	13400.00
0005432159916	12793	Economy	13400.00
0005432159919	12793	Economy	13400.00
0005434082021	12793	Economy	13400.00
0005434067934	12793	Economy	13400.00
0005434067983	12793	Economy	13400.00
0005434081998	12793	Economy	13400.00
0005433989791	12793	Economy	13400.00
0005434082073	12793	Economy	13400.00
0005433812932	12793	Economy	13400.00
0005434068193	12793	Economy	13400.00
0005432159917	12793	Economy	13400.00
0005434067558	12793	Economy	13400.00
0005434067865	12793	Economy	13400.00
0005434081888	12793	Economy	13400.00
0005434067841	12793	Economy	13400.00
0005434081915	12793	Economy	13400.00
0005434067787	12793	Economy	13400.00
0005434067556	12793	Economy	13400.00
0005434068175	12793	Economy	13400.00
0005434067935	12793	Economy	13400.00
0005434081948	12793	Economy	13400.00
0005434067836	12793	Economy	13400.00
0005434081879	12793	Economy	13400.00
0005434067804	12793	Economy	13400.00
0005434067570	12793	Economy	13400.00
0005434082068	12793	Economy	13400.00
0005434067809	12793	Economy	13400.00
0005434081975	12793	Economy	13400.00
0005434067828	12793	Economy	13400.00
0005434067569	12793	Economy	13400.00
0005434067788	12793	Economy	13400.00
0005433989787	12793	Economy	13400.00
0005434081876	12793	Economy	13400.00
0005434068186	12793	Economy	13400.00
0005434081822	12793	Economy	13400.00
0005434067957	12793	Economy	13400.00
0005434081907	12793	Economy	13400.00
0005434081898	12793	Economy	13400.00
0005434068085	12793	Economy	13400.00
0005434067920	12793	Economy	13400.00
0005434068236	12793	Economy	13400.00
0005434067878	12793	Economy	13400.00
0005434067825	12793	Economy	13400.00
0005434081958	12793	Economy	13400.00
0005434067797	12793	Economy	13400.00
0005434081887	12793	Economy	13400.00
0005434081940	12793	Economy	13400.00
0005432161182	12793	Economy	13400.00
0005433812933	12793	Economy	13400.00
0005434081936	12793	Economy	13400.00
0005434067579	12793	Economy	13400.00
0005432433749	12793	Economy	13400.00
0005434081877	12793	Economy	13400.00
0005434068412	30659	Business	40300.00
0005434068437	30659	Business	40300.00
0005434068445	30659	Business	40300.00
0005432433705	30659	Business	40300.00
0005434068405	30659	Business	40300.00
0005432186915	30659	Business	40300.00
0005434068456	30659	Business	40300.00
0005432433703	30659	Business	40300.00
0005434068468	30659	Business	40300.00
0005434068457	30659	Business	40300.00
0005434082182	30659	Business	40300.00
0005434068407	30659	Economy	13400.00
0005432150290	30659	Economy	13400.00
0005434068465	30659	Economy	13400.00
0005433989832	30659	Economy	13400.00
0005434068446	30659	Economy	13400.00
0005434082191	30659	Economy	13400.00
0005434068431	30659	Economy	13400.00
0005434068424	30659	Economy	13400.00
0005434068415	30659	Economy	13400.00
0005434082188	30659	Economy	13400.00
0005434068413	30659	Economy	13400.00
0005434068454	30659	Economy	13400.00
0005432150292	30659	Economy	13400.00
0005434068428	30659	Economy	13400.00
0005434068416	30659	Economy	13400.00
0005434082187	30659	Economy	13400.00
0005432150295	30659	Economy	13400.00
0005434068470	30659	Economy	13400.00
0005434082195	30659	Economy	13400.00
0005434082186	30659	Economy	13400.00
0005434068423	30659	Economy	13400.00
0005434068460	30659	Economy	13400.00
0005433989830	30659	Economy	13400.00
0005434082194	30659	Economy	13400.00
0005434082193	30659	Economy	13400.00
0005432433697	30659	Economy	13400.00
0005434082192	30659	Economy	13400.00
0005434082196	30659	Economy	13400.00
0005434082179	30659	Economy	13400.00
0005432433704	30659	Economy	13400.00
0005434082184	30659	Economy	13400.00
0005434068444	30659	Economy	13400.00
0005432433709	30659	Economy	13400.00
0005434068422	30659	Economy	13400.00
0005434068471	30659	Economy	13400.00
0005432186916	30659	Economy	13400.00
0005434068429	30659	Economy	13400.00
0005433989833	30659	Economy	13400.00
0005434068448	30659	Economy	14800.00
0005434068432	30659	Economy	14800.00
0005434068455	30659	Economy	14800.00
0005434068467	30659	Economy	14800.00
0005432433686	30659	Economy	14800.00
0005434068461	30659	Economy	14800.00
0005434068414	30659	Economy	13400.00
0005434068404	30659	Economy	13400.00
0005434068403	30659	Economy	13400.00
0005434068425	30659	Economy	13400.00
0005434068406	30659	Economy	13400.00
0005434082190	30659	Economy	13400.00
0005434068451	30659	Economy	13400.00
0005434082176	30659	Economy	13400.00
0005433989829	30659	Economy	13400.00
0005434068410	30659	Economy	13400.00
0005434082183	30659	Economy	13400.00
0005432150289	30659	Economy	13400.00
0005434068464	30659	Economy	13400.00
0005434068402	30659	Economy	13400.00
0005434068453	30659	Economy	13400.00
0005432433687	30659	Economy	13400.00
0005434068421	30659	Economy	13400.00
0005434082189	30659	Economy	13400.00
0005433989827	30659	Economy	13400.00
0005434068419	30659	Economy	13400.00
0005434068418	30659	Economy	13400.00
0005434068441	30659	Economy	13400.00
0005434082177	30659	Economy	13400.00
0005432150288	30659	Economy	13400.00
0005433989831	30659	Economy	13400.00
0005434068436	30659	Economy	13400.00
0005434068433	30659	Economy	13400.00
0005434068469	30659	Economy	13400.00
0005434068420	30659	Economy	13400.00
0005432433727	30659	Economy	13400.00
0005434068459	30659	Economy	13400.00
0005434068447	30659	Economy	13400.00
0005434068417	30659	Economy	13400.00
0005434068466	30659	Economy	13400.00
0005434082180	30659	Economy	13400.00
0005434068458	30659	Economy	13400.00
0005432186913	30659	Economy	13400.00
0005434068426	30659	Economy	13400.00
0005432433710	30659	Economy	13400.00
0005434082178	30659	Economy	13400.00
0005434068409	30659	Economy	13400.00
0005434068427	30659	Economy	13400.00
0005434082185	30659	Economy	13400.00
0005432150291	30659	Economy	13400.00
0005434068438	30659	Economy	13400.00
0005434068450	30659	Economy	13400.00
0005434068449	30659	Economy	13400.00
0005434068463	30659	Economy	13400.00
0005432186914	30659	Economy	13400.00
0005434068443	30659	Economy	13400.00
0005434082181	30659	Economy	13400.00
0005434068472	30659	Economy	13400.00
0005434068439	30659	Economy	13400.00
0005434068411	30659	Economy	13400.00
0005433989828	30659	Economy	13400.00
0005434068462	30659	Economy	13400.00
0005432150294	30659	Economy	13400.00
0005434068452	30659	Economy	13400.00
0005434068435	30659	Economy	13400.00
0005434068442	30659	Economy	13400.00
0005434068440	30659	Economy	13400.00
0005432150293	30659	Economy	13400.00
0005434068408	30659	Economy	13400.00
0005434068434	30659	Economy	13400.00
0005434068430	30659	Economy	13400.00
0005435725662	5503	Business	35300.00
0005435722086	5503	Business	35300.00
0005435462578	5503	Business	35300.00
0005435462678	5503	Business	35300.00
0005434265205	5503	Business	35300.00
0005435723073	5503	Business	35300.00
0005434265235	5503	Business	35300.00
0005435462545	5503	Business	35300.00
0005434265174	5503	Business	35300.00
0005435767012	5503	Business	35300.00
0005435767010	5503	Business	35300.00
0005435462552	5503	Business	35300.00
0005435462697	5503	Business	35300.00
0005435766988	5503	Business	35300.00
0005434265153	5503	Business	35300.00
0005432140556	5503	Business	35300.00
0005435725663	5503	Business	35300.00
0005435462602	5503	Business	35300.00
0005434831181	5503	Economy	12900.00
0005435767011	5503	Economy	12900.00
0005434265248	5503	Economy	12900.00
0005435767023	5503	Economy	11800.00
0005434265254	5503	Economy	11800.00
0005435723071	5503	Economy	11800.00
0005433527318	5503	Economy	11800.00
0005435462573	5503	Economy	11800.00
0005432140559	5503	Economy	11800.00
0005433527319	5503	Economy	11800.00
0005435767015	5503	Economy	11800.00
0005435766990	5503	Economy	11800.00
0005435767021	5503	Economy	11800.00
0005433529329	5503	Economy	11800.00
0005435767030	5503	Economy	11800.00
0005435767005	5503	Economy	11800.00
0005435462637	5503	Economy	11800.00
0005435462655	5503	Economy	11800.00
0005435462475	5503	Economy	11800.00
0005434831182	5503	Economy	11800.00
0005435767013	5503	Economy	11800.00
0005434265160	5503	Economy	11800.00
0005435767009	5503	Economy	11800.00
0005435767004	5503	Economy	11800.00
0005432535860	5503	Economy	11800.00
0005435767028	5503	Economy	11800.00
0005435735193	5503	Economy	11800.00
0005434831164	5503	Economy	11800.00
0005435735197	5503	Economy	11800.00
0005435462551	5503	Economy	11800.00
0005435767019	5503	Economy	11800.00
0005435767020	5503	Economy	11800.00
0005435767029	5503	Economy	11800.00
0005435766996	5503	Economy	11800.00
0005435462662	5503	Economy	11800.00
0005432140555	5503	Economy	11800.00
0005432535861	5503	Economy	11800.00
0005435766998	5503	Economy	11800.00
0005435735196	5503	Economy	11800.00
0005435462684	5503	Economy	11800.00
0005432140553	5503	Economy	11800.00
0005434831180	5503	Economy	11800.00
0005435462624	5503	Economy	11800.00
0005435725664	5503	Economy	11800.00
0005434265104	5503	Economy	11800.00
0005434265105	5503	Economy	11800.00
0005435767032	5503	Economy	11800.00
0005435462696	5503	Economy	11800.00
0005435462556	5503	Economy	11800.00
0005434265163	5503	Economy	11800.00
0005434265253	5503	Economy	11800.00
0005434265128	5503	Economy	11800.00
0005435462579	5503	Economy	11800.00
0005435767031	5503	Economy	11800.00
0005434265175	5503	Economy	11800.00
0005435766989	5503	Economy	11800.00
0005432535841	5503	Economy	11800.00
0005435720839	5503	Economy	11800.00
0005435767001	5503	Economy	11800.00
0005435462527	5503	Economy	11800.00
0005433529331	5503	Economy	11800.00
0005433529328	5503	Economy	11800.00
0005435462679	5503	Economy	11800.00
0005432140554	5503	Economy	11800.00
0005434265269	5503	Economy	11800.00
0005435725660	5503	Economy	11800.00
0005435767006	5503	Economy	11800.00
0005435462560	5503	Economy	11800.00
0005432140558	5503	Economy	12900.00
0005435766995	5503	Economy	12900.00
0005434265303	5503	Economy	11800.00
0005435462574	5503	Economy	11800.00
0005435462611	5503	Economy	11800.00
0005432535842	5503	Economy	12900.00
0005434831165	5503	Economy	11800.00
0005434265228	5503	Economy	11800.00
0005435462623	5503	Economy	11800.00
0005435462555	5503	Economy	11800.00
0005435462601	5503	Economy	11800.00
0005434265103	5503	Economy	11800.00
0005434265265	5503	Economy	11800.00
0005435735195	5503	Economy	11800.00
0005434831160	5503	Economy	11800.00
0005435767014	5503	Economy	11800.00
0005435766997	5503	Economy	11800.00
0005435722088	5503	Economy	11800.00
0005435767026	5503	Economy	11800.00
0005432535859	5503	Economy	11800.00
0005435723072	5503	Economy	11800.00
0005432535869	5503	Economy	11800.00
0005435462613	5503	Economy	11800.00
0005434265293	5503	Economy	11800.00
0005435462612	5503	Economy	11800.00
0005434265229	5503	Economy	11800.00
0005432140557	5503	Economy	11800.00
0005432535847	5503	Economy	11800.00
0005435462629	5503	Economy	11800.00
0005434265266	5503	Economy	11800.00
0005435767016	5503	Economy	11800.00
0005435462577	5503	Economy	11800.00
0005435735194	5503	Economy	11800.00
0005435767008	5503	Economy	11800.00
0005435767007	5503	Economy	11800.00
0005433529327	5503	Economy	11800.00
0005435767018	5503	Economy	11800.00
0005435767025	5503	Economy	11800.00
0005435766987	5503	Economy	11800.00
0005435767003	5503	Economy	11800.00
0005435462635	5503	Economy	11800.00
0005434265204	5503	Economy	11800.00
0005435725661	5503	Economy	11800.00
0005435767017	5503	Economy	11800.00
0005433527316	5503	Economy	11800.00
0005435767024	5503	Economy	11800.00
0005434265281	5503	Economy	11800.00
0005435722087	5503	Economy	11800.00
0005435766992	5503	Economy	11800.00
0005435462474	5503	Economy	11800.00
0005435767000	5503	Economy	11800.00
0005435767027	5503	Economy	11800.00
0005435766993	5503	Economy	11800.00
0005435462647	5503	Economy	11800.00
0005433529330	5503	Economy	11800.00
0005435720840	5503	Economy	11800.00
0005435462546	5503	Economy	11800.00
0005435462529	5503	Economy	11800.00
0005432535838	5503	Economy	11800.00
0005435766994	5503	Economy	11800.00
0005434265158	5503	Economy	11800.00
0005435462638	5503	Economy	11800.00
0005435766991	5503	Economy	11800.00
0005435767002	5503	Economy	11800.00
0005435767022	5503	Economy	11800.00
0005433527317	5503	Economy	11800.00
0005435766999	5503	Economy	11800.00
0005435766246	13501	Business	35300.00
0005435043293	13501	Business	35300.00
0005434265492	13501	Business	35300.00
0005435722065	13501	Business	35300.00
0005435766294	13501	Business	35300.00
0005435725600	13501	Business	35300.00
0005432535897	13501	Business	35300.00
0005435766486	13501	Business	35300.00
0005435766385	13501	Business	35300.00
0005432194566	13501	Business	35300.00
0005435735154	13501	Business	35300.00
0005435735153	13501	Business	35300.00
0005435766586	13501	Business	35300.00
0005434265484	13501	Business	35300.00
0005435766620	13501	Business	35300.00
0005434265486	13501	Business	35300.00
0005435043294	13501	Business	35300.00
0005435725599	13501	Business	35300.00
0005435462947	13501	Business	35300.00
0005435462930	13501	Business	35300.00
0005434831212	13501	Business	35300.00
0005435462945	13501	Business	35300.00
0005435766500	13501	Business	35300.00
0005435462934	13501	Business	35300.00
0005435766277	13501	Economy	12900.00
0005432194565	13501	Economy	12900.00
0005434265490	13501	Economy	11800.00
0005435766747	13501	Economy	11800.00
0005434265485	13501	Economy	11800.00
0005435462920	13501	Economy	11800.00
0005435462933	13501	Economy	11800.00
0005432194568	13501	Economy	11800.00
0005435766295	13501	Economy	11800.00
0005435462953	13501	Economy	11800.00
0005435766645	13501	Economy	11800.00
0005434265481	13501	Economy	11800.00
0005435462944	13501	Economy	11800.00
0005435766319	13501	Economy	11800.00
0005435766242	13501	Economy	11800.00
0005435766523	13501	Economy	11800.00
0005435766430	13501	Economy	11800.00
0005434265487	13501	Economy	11800.00
0005435462937	13501	Economy	11800.00
0005434831214	13501	Economy	11800.00
0005432535900	13501	Economy	11800.00
0005435766482	13501	Economy	11800.00
0005435462936	13501	Economy	11800.00
0005435766394	13501	Economy	11800.00
0005435735144	13501	Economy	11800.00
0005435722063	13501	Economy	11800.00
0005434831216	13501	Economy	11800.00
0005435462943	13501	Economy	11800.00
0005435766273	13501	Economy	11800.00
0005435766511	13501	Economy	11800.00
0005434265494	13501	Economy	11800.00
0005435725609	13501	Economy	11800.00
0005435725627	13501	Economy	11800.00
0005435766612	13501	Economy	11800.00
0005435766488	13501	Economy	11800.00
0005435766237	13501	Economy	11800.00
0005434265472	13501	Economy	11800.00
0005435462923	13501	Economy	11800.00
0005435766579	13501	Economy	11800.00
0005435725629	13501	Economy	11800.00
0005435462918	13501	Economy	11800.00
0005435766601	13501	Economy	11800.00
0005434265480	13501	Economy	11800.00
0005435462940	13501	Economy	11800.00
0005435722066	13501	Economy	11800.00
0005435766315	13501	Economy	11800.00
0005435766534	13501	Economy	11800.00
0005435766600	13501	Economy	11800.00
0005434265477	13501	Economy	11800.00
0005435766238	13501	Economy	11800.00
0005435766422	13501	Economy	11800.00
0005435766519	13501	Economy	11800.00
0005435766435	13501	Economy	11800.00
0005435766329	13501	Economy	11800.00
0005435462922	13501	Economy	11800.00
0005435735151	13501	Economy	11800.00
0005432535896	13501	Economy	11800.00
0005434265483	13501	Economy	11800.00
0005435766507	13501	Economy	11800.00
0005435462921	13501	Economy	11800.00
0005435766318	13501	Economy	11800.00
0005435766257	13501	Economy	11800.00
0005435766337	13501	Economy	11800.00
0005434265482	13501	Economy	11800.00
0005435766328	13501	Economy	11800.00
0005435462948	13501	Economy	11800.00
0005435766489	13501	Economy	11800.00
0005435725613	13501	Economy	11800.00
0005435766279	13501	Economy	11800.00
0005435617174	13501	Economy	11800.00
0005434265473	13501	Economy	11800.00
0005435766278	13501	Economy	11800.00
0005435766492	13501	Economy	11800.00
0005435462929	13501	Economy	11800.00
0005435766369	13501	Economy	11800.00
0005435766527	13501	Economy	11800.00
0005435766535	13501	Economy	11800.00
0005435766644	13501	Economy	12900.00
0005434831213	13501	Economy	12900.00
0005435462941	13501	Economy	11800.00
0005435766386	13501	Economy	12900.00
0005435766621	13501	Economy	12900.00
0005434265491	13501	Economy	11800.00
0005434265470	13501	Economy	11800.00
0005435766370	13501	Economy	11800.00
0005435462952	13501	Economy	11800.00
0005435766613	13501	Economy	11800.00
0005435725612	13501	Economy	11800.00
0005435766333	13501	Economy	11800.00
0005435462949	13501	Economy	11800.00
0005435766400	13501	Economy	11800.00
0005434265471	13501	Economy	11800.00
0005435766387	13501	Economy	11800.00
0005435766543	13501	Economy	11800.00
0005435766401	13501	Economy	11800.00
0005435462938	13501	Economy	11800.00
0005435766449	13501	Economy	11800.00
0005434265478	13501	Economy	11800.00
0005435766487	13501	Economy	11800.00
0005435462942	13501	Economy	11800.00
0005435462950	13501	Economy	11800.00
0005435720135	13501	Economy	11800.00
0005432194567	13501	Economy	11800.00
0005435766588	13501	Economy	11800.00
0005435462946	13501	Economy	11800.00
0005435766012	13501	Economy	11800.00
0005435766274	13501	Economy	11800.00
0005435725628	13501	Economy	11800.00
0005434265469	13501	Economy	11800.00
0005435462932	13501	Economy	11800.00
0005435462925	13501	Economy	11800.00
0005435735145	13501	Economy	11800.00
0005435462939	13501	Economy	11800.00
0005435766272	13501	Economy	11800.00
0005434265479	13501	Economy	11800.00
0005434265493	13501	Economy	11800.00
0005434265476	13501	Economy	11800.00
0005432535899	13501	Economy	11800.00
0005434831215	13501	Economy	11800.00
0005435462924	13501	Economy	11800.00
0005435462928	13501	Economy	11800.00
0005435766595	13501	Economy	11800.00
0005435766388	13501	Economy	11800.00
0005435462926	13501	Economy	11800.00
0005435766518	13501	Economy	11800.00
0005435766483	13501	Economy	11800.00
0005435766646	13501	Economy	11800.00
0005435462935	13501	Economy	11800.00
0005435766748	13501	Economy	11800.00
0005435462951	13501	Economy	11800.00
0005435766651	13501	Economy	11800.00
0005435766247	13501	Economy	11800.00
0005435462927	13501	Economy	11800.00
0005434265488	13501	Economy	11800.00
0005434265474	13501	Economy	11800.00
0005435617175	13501	Economy	11800.00
0005435462931	13501	Economy	11800.00
0005435766229	13501	Economy	11800.00
0005434265475	13501	Economy	11800.00
0005434831217	13501	Economy	11800.00
0005434265489	13501	Economy	11800.00
0005435735146	13501	Economy	11800.00
0005435766513	13501	Economy	11800.00
0005432535898	13501	Economy	11800.00
0005435462919	13501	Economy	11800.00
0005434602911	18669	Economy	3300.00
0005434602917	18669	Economy	3300.00
0005434513612	18670	Economy	3300.00
0005434515000	18670	Economy	3300.00
0005434513611	18670	Economy	3300.00
0005434513613	18670	Economy	3300.00
0005434515001	18670	Economy	3300.00
0005434514974	19218	Economy	3300.00
0005432649395	25091	Business	88300.00
0005432649408	25091	Business	88300.00
0005432649425	25091	Economy	29400.00
0005432649432	25091	Economy	29400.00
0005432649429	25091	Economy	29400.00
0005432649415	25091	Economy	32400.00
0005432649418	25091	Economy	29400.00
0005432649434	25091	Economy	29400.00
0005432649409	25091	Economy	29400.00
0005432649413	25091	Economy	29400.00
0005435846298	25091	Economy	29400.00
0005432649412	25091	Economy	29400.00
0005435846303	25091	Economy	29400.00
0005435846302	25091	Economy	29400.00
0005435846296	25091	Economy	29400.00
0005432649400	25091	Economy	29400.00
0005435846297	25091	Economy	29400.00
0005432649445	25091	Economy	29400.00
0005432649430	25091	Economy	29400.00
0005432649426	25091	Economy	29400.00
0005435846301	25091	Economy	29400.00
0005435846299	25091	Economy	29400.00
0005432649448	25091	Economy	29400.00
0005432649446	25091	Economy	29400.00
0005432649431	25091	Economy	29400.00
0005432649419	25091	Economy	29400.00
0005432649417	25091	Economy	29400.00
0005432649447	25091	Economy	29400.00
0005435846300	25091	Economy	29400.00
0005432649453	25091	Economy	29400.00
0005432295913	1832	Business	48700.00
0005433285542	1832	Business	48700.00
0005433008812	1832	Business	48700.00
0005433008954	1832	Business	48700.00
0005433008721	1832	Business	48700.00
0005433008922	1832	Business	48700.00
0005433285476	1832	Business	48700.00
0005433285229	1832	Business	48700.00
0005432295914	1832	Business	48700.00
0005433008953	1832	Business	48700.00
0005433008937	1832	Economy	16200.00
0005433285396	1832	Economy	16200.00
0005433285409	1832	Economy	16200.00
0005433285539	1832	Economy	16200.00
0005433285397	1832	Economy	16200.00
0005433008837	1832	Economy	16200.00
0005433008628	1832	Economy	16200.00
0005433009038	1832	Economy	16200.00
0005433008780	1832	Economy	17900.00
0005433008718	1832	Economy	17900.00
0005433009068	1832	Economy	17900.00
0005433285570	1832	Economy	17900.00
0005433285569	1832	Economy	17900.00
0005433008934	1832	Economy	16200.00
0005433008627	1832	Economy	16200.00
0005433810605	1832	Economy	16200.00
0005433285308	1832	Economy	16200.00
0005433285458	1832	Economy	16200.00
0005433008873	1832	Economy	16200.00
0005433285367	1832	Economy	16200.00
0005433285472	1832	Economy	16200.00
0005433285607	1832	Economy	16200.00
0005433008707	1832	Economy	16200.00
0005433810602	1832	Economy	16200.00
0005433285518	1832	Economy	16200.00
0005433810600	1832	Economy	16200.00
0005433008789	1832	Economy	16200.00
0005433285431	1832	Economy	16200.00
0005433008925	1832	Economy	16200.00
0005433285453	1832	Economy	16200.00
0005433285228	1832	Economy	16200.00
0005433008943	1832	Economy	16200.00
0005433285483	1832	Economy	16200.00
0005432295915	1832	Economy	16200.00
0005433008737	1832	Economy	16200.00
0005433008788	1832	Economy	16200.00
0005433008738	1832	Economy	16200.00
0005433810598	1832	Economy	16200.00
0005433285484	1832	Economy	16200.00
0005433008936	1832	Economy	16200.00
0005433008824	1832	Economy	16200.00
0005433008808	1832	Economy	16200.00
0005433285460	1832	Economy	16200.00
0005433008773	1832	Economy	16200.00
0005433008854	1832	Economy	16200.00
0005433008708	1832	Economy	16200.00
0005433008739	1832	Economy	16200.00
0005433008717	1832	Economy	16200.00
0005433810604	1832	Economy	16200.00
0005433009039	1832	Economy	16200.00
0005433008809	1832	Economy	16200.00
0005433008825	1832	Economy	16200.00
0005433008791	1832	Economy	16200.00
0005433285272	1832	Economy	16200.00
0005433008871	1832	Economy	16200.00
0005433008926	1832	Economy	16200.00
0005433810603	1832	Economy	16200.00
0005433285451	1832	Economy	16200.00
0005433008942	1832	Economy	16200.00
0005433008975	1832	Economy	16200.00
0005433008935	1832	Economy	16200.00
0005433008823	1832	Economy	16200.00
0005433285540	1832	Economy	16200.00
0005433285475	1832	Economy	16200.00
0005433810599	1832	Economy	16200.00
0005433810601	1832	Economy	16200.00
0005433008720	1832	Economy	16200.00
0005433009198	22599	Business	48700.00
0005433009170	22599	Business	48700.00
0005433009193	22599	Business	48700.00
0005433009211	22599	Business	48700.00
0005433810542	22599	Business	48700.00
0005433285676	22599	Business	48700.00
0005433285685	22599	Business	48700.00
0005433009204	22599	Business	48700.00
0005433285679	22599	Economy	16200.00
0005433009182	22599	Economy	16200.00
0005433009208	22599	Economy	16200.00
0005433009185	22599	Economy	16200.00
0005433009188	22599	Economy	16200.00
0005433285677	22599	Economy	16200.00
0005433009184	22599	Economy	16200.00
0005433285707	22599	Economy	16200.00
0005433285706	22599	Economy	16200.00
0005433009214	22599	Economy	17900.00
0005433285704	22599	Economy	17900.00
0005433285701	22599	Economy	17900.00
0005433009199	22599	Economy	17900.00
0005433009181	22599	Economy	17900.00
0005433285689	22599	Economy	16200.00
0005433285694	22599	Economy	16200.00
0005433009201	22599	Economy	16200.00
0005433285695	22599	Economy	16200.00
0005433285678	22599	Economy	16200.00
0005433009191	22599	Economy	16200.00
0005433009203	22599	Economy	16200.00
0005433285682	22599	Economy	16200.00
0005433009186	22599	Economy	16200.00
0005433810554	22599	Economy	16200.00
0005433009194	22599	Economy	16200.00
0005433285691	22599	Economy	16200.00
0005433009196	22599	Economy	16200.00
0005433285692	22599	Economy	16200.00
0005433009213	22599	Economy	16200.00
0005433285693	22599	Economy	16200.00
0005433009192	22599	Economy	16200.00
0005433009200	22599	Economy	16200.00
0005433009183	22599	Economy	16200.00
0005433285700	22599	Economy	16200.00
0005433009176	22599	Economy	16200.00
0005433009205	22599	Economy	16200.00
0005433009210	22599	Economy	16200.00
0005433285696	22599	Economy	16200.00
0005433009172	22599	Economy	16200.00
0005433009209	22599	Economy	16200.00
0005433009168	22599	Economy	16200.00
0005433009189	22599	Economy	16200.00
0005433285683	22599	Economy	16200.00
0005433285686	22599	Economy	16200.00
0005433009175	22599	Economy	16200.00
0005433810536	22599	Economy	16200.00
0005433009178	22599	Economy	16200.00
0005433285688	22599	Economy	16200.00
0005433285684	22599	Economy	16200.00
0005433285687	22599	Economy	16200.00
0005433810535	22599	Economy	16200.00
0005433285681	22599	Economy	16200.00
0005433009197	22599	Economy	16200.00
0005433009179	22599	Economy	16200.00
0005433285703	22599	Economy	16200.00
0005433009180	22599	Economy	16200.00
0005433009173	22599	Economy	16200.00
0005433285697	22599	Economy	16200.00
0005433009174	22599	Economy	16200.00
0005433009171	22599	Economy	16200.00
0005433285699	22599	Economy	16200.00
0005433009212	22599	Economy	16200.00
0005433285705	22599	Economy	16200.00
0005433285680	22599	Economy	16200.00
0005433009195	22599	Economy	16200.00
0005433009202	22599	Economy	16200.00
0005433009207	22599	Economy	16200.00
0005433009206	22599	Economy	16200.00
0005433810530	22599	Economy	16200.00
0005433285698	22599	Economy	16200.00
0005433009177	22599	Economy	16200.00
0005433285690	22599	Economy	16200.00
0005433285702	22599	Economy	16200.00
0005433009169	22599	Economy	16200.00
0005433009190	22599	Economy	16200.00
0005433009187	22599	Economy	16200.00
0005432751543	12286	Business	83800.00
0005432755077	12286	Business	83800.00
0005432751529	12286	Business	83800.00
0005432751512	12286	Business	83800.00
0005432751544	12286	Business	83800.00
0005434152820	12286	Economy	27900.00
0005432751540	12286	Economy	27900.00
0005434152822	12286	Economy	27900.00
0005432755082	12286	Economy	30700.00
0005432751513	12286	Economy	30700.00
0005432751530	12286	Economy	30700.00
0005434152817	12286	Economy	27900.00
0005434152814	12286	Economy	27900.00
0005432751521	12286	Economy	27900.00
0005434152823	12286	Economy	27900.00
0005434152819	12286	Economy	27900.00
0005432751542	12286	Economy	27900.00
0005432755083	12286	Economy	27900.00
0005432755085	12286	Economy	27900.00
0005434152818	12286	Economy	27900.00
0005434152821	12286	Economy	27900.00
0005432751531	12286	Economy	27900.00
0005432751522	12286	Economy	27900.00
0005432751514	12286	Economy	27900.00
0005432755079	12286	Economy	27900.00
0005432751528	12286	Economy	27900.00
0005434152816	12286	Economy	27900.00
0005432755084	12286	Economy	27900.00
0005434152815	12286	Economy	27900.00
0005432751538	12286	Economy	27900.00
0005432755076	12286	Economy	27900.00
0005432751548	12286	Economy	27900.00
0005432755078	12286	Economy	27900.00
0005433847483	5605	Business	99800.00
0005433847489	5605	Business	99800.00
0005435282618	5605	Business	99800.00
0005433847470	5605	Business	99800.00
0005435282683	5605	Business	99800.00
0005433847474	5605	Business	99800.00
0005433847458	5605	Business	99800.00
0005435282744	5605	Business	99800.00
0005435282715	5605	Business	99800.00
0005433815445	5605	Business	99800.00
0005435282567	5605	Business	99800.00
0005433847461	5605	Business	99800.00
0005433847472	5605	Business	99800.00
0005435282655	5605	Business	99800.00
0005433847516	5605	Business	99800.00
0005433847478	5605	Business	99800.00
0005433847463	5605	Economy	33300.00
0005433847507	5605	Business	99800.00
0005433847482	5605	Economy	33300.00
0005433847468	5605	Economy	33300.00
0005432081596	5605	Economy	33300.00
0005433847500	5605	Economy	33300.00
0005433847479	5605	Economy	33300.00
0005433847464	5605	Economy	33300.00
0005433847486	5605	Economy	33300.00
0005435282617	5605	Economy	33300.00
0005433847502	5605	Economy	33300.00
0005433847476	5605	Economy	33300.00
0005435282596	5605	Economy	33300.00
0005433847509	5605	Economy	36600.00
0005433847488	5605	Economy	36600.00
0005433847471	5605	Economy	36600.00
0005432081598	5605	Economy	36600.00
0005435282614	5605	Economy	33300.00
0005433847501	5605	Economy	33300.00
0005433847475	5605	Economy	33300.00
0005433847481	5605	Economy	33300.00
0005434173528	5605	Economy	33300.00
0005434173530	5605	Economy	33300.00
0005433847492	5605	Economy	33300.00
0005433847459	5605	Economy	33300.00
0005433847493	5605	Economy	33300.00
0005433847477	5605	Economy	33300.00
0005433847514	5605	Economy	33300.00
0005433847504	5605	Economy	33300.00
0005433847494	5605	Economy	33300.00
0005433847506	5605	Economy	33300.00
0005435282633	5605	Economy	33300.00
0005432081592	5605	Economy	33300.00
0005433847498	5605	Economy	33300.00
0005435282660	5605	Economy	33300.00
0005433815448	5605	Economy	33300.00
0005433847469	5605	Economy	33300.00
0005432081597	5605	Economy	33300.00
0005435282599	5605	Economy	33300.00
0005435282593	5605	Economy	33300.00
0005432081594	5605	Economy	33300.00
0005433847511	5605	Economy	33300.00
0005433847503	5605	Economy	33300.00
0005434173533	5605	Economy	33300.00
0005433847457	5605	Economy	33300.00
0005433847508	5605	Economy	33300.00
0005433847462	5605	Economy	33300.00
0005433847473	5605	Economy	33300.00
0005432081595	5605	Economy	33300.00
0005433847512	5605	Economy	33300.00
0005435282631	5605	Economy	33300.00
0005435282576	5605	Economy	33300.00
0005433847490	5605	Economy	33300.00
0005435282598	5605	Economy	33300.00
0005433847496	5605	Economy	33300.00
0005433847460	5605	Economy	33300.00
0005435282628	5605	Economy	33300.00
0005433847487	5605	Economy	33300.00
0005433847466	5605	Economy	33300.00
0005433847515	5605	Economy	33300.00
0005433847465	5605	Economy	33300.00
0005433847510	5605	Economy	33300.00
0005433847467	5605	Economy	33300.00
0005433847505	5605	Economy	33300.00
0005435282632	5605	Economy	33300.00
0005433815446	5605	Economy	33300.00
0005433815444	5605	Economy	33300.00
0005433847495	5605	Economy	33300.00
0005433847485	5605	Economy	33300.00
0005433847499	5605	Economy	33300.00
0005433847484	5605	Economy	33300.00
0005432081593	5605	Economy	33300.00
0005433847480	5605	Economy	33300.00
0005433847513	5605	Economy	33300.00
0005433847491	5605	Economy	33300.00
0005433847497	5605	Economy	33300.00
0005433815447	5605	Economy	33300.00
0005434173529	5605	Economy	33300.00
0005433847050	13842	Business	99800.00
0005433846960	13842	Business	99800.00
0005435282818	13842	Business	99800.00
0005432003741	13842	Business	99800.00
0005433847060	13842	Business	99800.00
0005435282819	13842	Business	99800.00
0005433846946	13842	Business	99800.00
0005433847052	13842	Business	99800.00
0005435282822	13842	Business	99800.00
0005435282812	13842	Business	99800.00
0005435282817	13842	Business	99800.00
0005433847056	13842	Business	99800.00
0005433847053	13842	Business	99800.00
0005433846986	13842	Business	99800.00
0005435282836	13842	Business	99800.00
0005433847040	13842	Business	99800.00
0005435282820	13842	Business	99800.00
0005433815403	13842	Business	99800.00
0005433846838	13842	Business	99800.00
0005433847109	13842	Business	99800.00
0005433847127	13842	Economy	33300.00
0005433815396	13842	Economy	33300.00
0005435282825	13842	Economy	33300.00
0005433847025	13842	Economy	33300.00
0005433846957	13842	Economy	33300.00
0005433847028	13842	Economy	33300.00
0005433846839	13842	Economy	33300.00
0005433846947	13842	Economy	33300.00
0005433846988	13842	Economy	33300.00
0005435282831	13842	Economy	33300.00
0005433815412	13842	Economy	33300.00
0005435282839	13842	Economy	33300.00
0005433815401	13842	Economy	36600.00
0005433847205	13842	Economy	36600.00
0005435282816	13842	Economy	36600.00
0005433846970	13842	Economy	33300.00
0005433846857	13842	Economy	33300.00
0005433846991	13842	Economy	33300.00
0005433846798	13842	Economy	33300.00
0005433846978	13842	Economy	33300.00
0005433846952	13842	Economy	33300.00
0005435282835	13842	Economy	33300.00
0005435282815	13842	Economy	33300.00
0005435282832	13842	Economy	33300.00
0005435282841	13842	Economy	33300.00
0005433846858	13842	Economy	33300.00
0005435282837	13842	Economy	33300.00
0005434173573	13842	Economy	33300.00
0005433846884	13842	Economy	33300.00
0005433846987	13842	Economy	33300.00
0005433847064	13842	Economy	33300.00
0005433846783	13842	Economy	33300.00
0005435282814	13842	Economy	33300.00
0005433847063	13842	Economy	33300.00
0005433846852	13842	Economy	33300.00
0005433846996	13842	Economy	33300.00
0005433847069	13842	Economy	33300.00
0005433846885	13842	Economy	33300.00
0005434173574	13842	Economy	33300.00
0005433846945	13842	Economy	33300.00
0005435282821	13842	Economy	33300.00
0005433846886	13842	Economy	33300.00
0005433846799	13842	Economy	33300.00
0005435282834	13842	Economy	33300.00
0005433847033	13842	Economy	33300.00
0005433846995	13842	Economy	33300.00
0005433846853	13842	Economy	33300.00
0005432003744	13842	Economy	33300.00
0005433846818	13842	Economy	33300.00
0005433847096	13842	Economy	33300.00
0005433847041	13842	Economy	33300.00
0005435282838	13842	Economy	33300.00
0005432003743	13842	Economy	33300.00
0005433847022	13842	Economy	33300.00
0005435282824	13842	Economy	33300.00
0005433815402	13842	Economy	33300.00
0005435282833	13842	Economy	33300.00
0005435282823	13842	Economy	33300.00
0005435282840	13842	Economy	33300.00
0005433846967	13842	Economy	33300.00
0005433846958	13842	Economy	33300.00
0005432003742	13842	Economy	33300.00
0005433847039	13842	Economy	33300.00
0005433846890	13842	Economy	33300.00
0005435282813	13842	Economy	33300.00
0005433846833	13842	Economy	33300.00
0005433847055	13842	Economy	33300.00
0005435282829	13842	Economy	33300.00
0005433847010	13842	Economy	33300.00
0005433847029	13842	Economy	33300.00
0005435282830	13842	Economy	33300.00
0005433847051	13842	Economy	33300.00
0005433847054	13842	Economy	33300.00
0005433846979	13842	Economy	33300.00
0005433846964	13842	Economy	33300.00
0005435282828	13842	Economy	33300.00
0005433846990	13842	Economy	33300.00
0005433847034	13842	Economy	33300.00
0005435282827	13842	Economy	33300.00
0005434173572	13842	Economy	33300.00
0005434173571	13842	Economy	33300.00
0005433846971	13842	Economy	33300.00
0005435282826	13842	Economy	33300.00
0005433847011	13842	Economy	33300.00
0005435332385	7808	Economy	16600.00
0005435332408	7808	Economy	16600.00
0005434620869	7808	Economy	16600.00
0005434620856	7808	Economy	15100.00
0005434620871	7808	Economy	15100.00
0005434620868	7808	Economy	15100.00
0005435332386	7808	Economy	15100.00
0005434620861	7808	Economy	15100.00
0005434620860	7808	Economy	15100.00
0005432112546	7808	Economy	15100.00
0005435332421	7808	Economy	15100.00
0005434620867	7808	Economy	15100.00
0005434620872	7808	Economy	15100.00
0005432112547	7808	Economy	15100.00
0005435332352	7808	Economy	15100.00
0005434620865	7808	Economy	15100.00
0005435332418	7808	Economy	15100.00
0005434620855	7808	Economy	15100.00
0005434620858	7808	Economy	15100.00
0005435332404	7808	Economy	15100.00
0005435332400	7808	Economy	15100.00
0005434620854	7808	Economy	15100.00
0005435332367	7808	Economy	15100.00
0005434620863	7808	Economy	15100.00
0005434620866	7808	Economy	15100.00
0005434620859	7808	Economy	15100.00
0005434620857	7808	Economy	15100.00
0005434620862	7808	Economy	15100.00
0005435332422	7808	Economy	15100.00
0005435332353	7808	Economy	15100.00
0005435332423	7808	Economy	15100.00
0005435332362	7808	Economy	15100.00
0005435332419	7808	Economy	15100.00
0005434620873	7808	Economy	15100.00
0005434620870	7808	Economy	15100.00
0005434620864	7808	Economy	15100.00
0005435332475	32988	Economy	15100.00
0005434620640	32988	Economy	15100.00
0005434620714	32988	Economy	15100.00
0005435332468	32988	Economy	15100.00
0005434620713	32988	Economy	15100.00
0005434620656	32988	Economy	15100.00
0005434620637	32988	Economy	15100.00
0005434620732	32988	Economy	15100.00
0005435332467	32988	Economy	15100.00
0005434620679	32988	Economy	15100.00
0005434620579	32988	Economy	15100.00
0005434620733	32988	Economy	15100.00
0005435332474	32988	Economy	15100.00
0005435332473	32988	Economy	15100.00
0005434620641	32988	Economy	15100.00
0005434620716	32988	Economy	15100.00
0005434620749	32988	Economy	15100.00
0005435332470	32988	Economy	15100.00
0005434620687	32988	Economy	15100.00
0005434620734	32988	Economy	15100.00
0005434620664	32988	Economy	15100.00
0005435332469	32988	Economy	15100.00
0005434620735	32988	Economy	15100.00
0005435332471	32988	Economy	15100.00
0005434620719	32988	Economy	15100.00
0005434620659	32988	Economy	15100.00
0005434620655	32988	Economy	15100.00
0005435332472	32988	Economy	15100.00
0005434620717	32988	Economy	15100.00
0005434620745	32988	Economy	15100.00
0005435332466	32988	Economy	15100.00
0005435785822	4309	Business	38000.00
0005434994146	4309	Business	38000.00
0005435785804	4309	Business	38000.00
0005435937394	4309	Business	38000.00
0005432190679	4309	Business	38000.00
0005435918658	4309	Business	38000.00
0005435785810	4309	Economy	12700.00
0005435787384	4309	Economy	12700.00
0005432190678	4309	Economy	12700.00
0005435785802	4309	Economy	12700.00
0005435785796	4309	Economy	12700.00
0005434994147	4309	Economy	12700.00
0005435787382	4309	Economy	13900.00
0005435937397	4309	Economy	13900.00
0005435785794	4309	Economy	13900.00
0005435785814	4309	Economy	12700.00
0005435785798	4309	Economy	12700.00
0005435937398	4309	Economy	12700.00
0005435785803	4309	Economy	12700.00
0005435918673	4309	Economy	12700.00
0005435785807	4309	Economy	12700.00
0005435785824	4309	Economy	12700.00
0005435785819	4309	Economy	12700.00
0005435918682	4309	Economy	12700.00
0005435785817	4309	Economy	12700.00
0005435918672	4309	Economy	12700.00
0005435785800	4309	Economy	12700.00
0005435785821	4309	Economy	12700.00
0005432190681	4309	Economy	12700.00
0005434994145	4309	Economy	12700.00
0005435785801	4309	Economy	12700.00
0005435937399	4309	Economy	12700.00
0005435937396	4309	Economy	12700.00
0005434994149	4309	Economy	12700.00
0005434994150	4309	Economy	12700.00
0005435785791	4309	Economy	12700.00
0005435937391	4309	Economy	12700.00
0005435785812	4309	Economy	12700.00
0005435785811	4309	Economy	12700.00
0005434994151	4309	Economy	12700.00
0005434994154	4309	Economy	12700.00
0005434994153	4309	Economy	12700.00
0005435785820	4309	Economy	12700.00
0005432190680	4309	Economy	12700.00
0005435785799	4309	Economy	12700.00
0005435785816	4309	Economy	12700.00
0005434994148	4309	Economy	12700.00
0005435785795	4309	Economy	12700.00
0005435785808	4309	Economy	12700.00
0005434994152	4309	Economy	12700.00
0005435785805	4309	Economy	12700.00
0005435785825	4309	Economy	12700.00
0005435785806	4309	Economy	12700.00
0005435787383	4309	Economy	12700.00
0005435785809	4309	Economy	12700.00
0005435785797	4309	Economy	12700.00
0005435785826	4309	Economy	12700.00
0005435918688	4309	Economy	12700.00
0005435918700	4309	Economy	12700.00
0005435785818	4309	Economy	12700.00
0005435785815	4309	Economy	12700.00
0005435785813	4309	Economy	12700.00
0005435785823	4309	Economy	12700.00
0005435785793	4309	Economy	12700.00
0005435785792	4309	Economy	12700.00
0005435918701	4309	Economy	12700.00
0005435785347	27291	Business	38000.00
0005434994097	27291	Business	38000.00
0005435785484	27291	Business	38000.00
0005435785520	27291	Business	38000.00
0005435785387	27291	Business	38000.00
0005435787364	27291	Business	38000.00
0005435785399	27291	Economy	12700.00
0005435937439	27291	Economy	12700.00
0005435785455	27291	Economy	12700.00
0005435785430	27291	Economy	12700.00
0005435785398	27291	Economy	12700.00
0005435937437	27291	Economy	12700.00
0005432195718	27291	Economy	12700.00
0005435785468	27291	Economy	12700.00
0005434994111	27291	Economy	13900.00
0005435918721	27291	Economy	13900.00
0005434994112	27291	Economy	13900.00
0005435785471	27291	Economy	12700.00
0005434993997	27291	Economy	12700.00
0005435785417	27291	Economy	12700.00
0005434994039	27291	Economy	12700.00
0005435785376	27291	Economy	12700.00
0005435918717	27291	Economy	12700.00
0005434994068	27291	Economy	12700.00
0005435785364	27291	Economy	12700.00
0005432195719	27291	Economy	12700.00
0005435785441	27291	Economy	12700.00
0005435785466	27291	Economy	12700.00
0005435785259	27291	Economy	12700.00
0005435785363	27291	Economy	12700.00
0005435785499	27291	Economy	12700.00
0005432195720	27291	Economy	12700.00
0005434994075	27291	Economy	12700.00
0005435787365	27291	Economy	12700.00
0005435787363	27291	Economy	12700.00
0005434994080	27291	Economy	12700.00
0005435785431	27291	Economy	12700.00
0005435785540	27291	Economy	12700.00
0005434994079	27291	Economy	12700.00
0005435785396	27291	Economy	12700.00
0005434994038	27291	Economy	12700.00
0005434994076	27291	Economy	12700.00
0005434994081	27291	Economy	12700.00
0005435785496	27291	Economy	12700.00
0005435937438	27291	Economy	12700.00
0005435785495	27291	Economy	12700.00
0005435918720	27291	Economy	12700.00
0005435785485	27291	Economy	12700.00
0005434994074	27291	Economy	12700.00
0005435785348	27291	Economy	12700.00
0005435785394	27291	Economy	12700.00
0005435785393	27291	Economy	12700.00
0005435785567	27291	Economy	12700.00
0005435785320	27291	Economy	12700.00
0005435918718	27291	Economy	12700.00
0005435785397	27291	Economy	12700.00
0005435785319	27291	Economy	12700.00
0005435785401	27291	Economy	12700.00
0005435785558	27291	Economy	12700.00
0005434994101	27291	Economy	12700.00
0005435785409	27291	Economy	12700.00
0005435785400	27291	Economy	12700.00
0005435785372	27291	Economy	12700.00
0005435785452	27291	Economy	12700.00
0005434994093	27291	Economy	12700.00
0005435918719	27291	Economy	12700.00
0005435918716	27291	Economy	12700.00
0005435787355	27291	Economy	12700.00
0005435785377	27291	Economy	12700.00
0005435785503	27291	Economy	12700.00
0005434994066	27291	Economy	12700.00
0005432146223	19899	Economy	12800.00
0005432146225	19899	Economy	12800.00
0005432146226	19899	Economy	12800.00
0005432146224	19899	Economy	12800.00
0005432146227	19899	Economy	12800.00
0005434082207	4701	Business	40900.00
0005432568453	4701	Business	40900.00
0005432186918	4701	Business	40900.00
0005432460551	4701	Business	40900.00
0005432568445	4701	Business	40900.00
0005432568408	4701	Business	40900.00
0005432568430	4701	Business	40900.00
0005434082199	4701	Business	40900.00
0005432170480	4701	Business	40900.00
0005432568436	4701	Business	40900.00
0005432460548	4701	Business	40900.00
0005432460509	4701	Business	40900.00
0005432460506	4701	Business	40900.00
0005432170474	4701	Business	40900.00
0005432568463	4701	Business	40900.00
0005432571372	4701	Business	40900.00
0005432460525	4701	Business	40900.00
0005432460543	4701	Business	40900.00
0005434082198	4701	Business	40900.00
0005432568450	4701	Business	40900.00
0005432460520	4701	Business	40900.00
0005432568415	4701	Business	40900.00
0005434082218	4701	Economy	15000.00
0005432460542	4701	Economy	15000.00
0005432460524	4701	Economy	15000.00
0005433726133	4701	Economy	13600.00
0005432571369	4701	Economy	13600.00
0005432460537	4701	Economy	13600.00
0005434082216	4701	Economy	13600.00
0005432568454	4701	Economy	13600.00
0005432571371	4701	Economy	13600.00
0005434082208	4701	Economy	13600.00
0005432568437	4701	Economy	13600.00
0005432460516	4701	Economy	13600.00
0005432186917	4701	Economy	13600.00
0005432460545	4701	Economy	13600.00
0005432568452	4701	Economy	13600.00
0005432460530	4701	Economy	13600.00
0005432568419	4701	Economy	13600.00
0005432460555	4701	Economy	13600.00
0005432568424	4701	Economy	13600.00
0005432460532	4701	Economy	13600.00
0005433452767	4701	Economy	13600.00
0005433726135	4701	Economy	13600.00
0005432568444	4701	Economy	13600.00
0005432568451	4701	Economy	13600.00
0005432460512	4701	Economy	13600.00
0005433451646	4701	Economy	13600.00
0005433451645	4701	Economy	13600.00
0005434082210	4701	Economy	13600.00
0005432568435	4701	Economy	13600.00
0005432460507	4701	Economy	13600.00
0005432460529	4701	Economy	13600.00
0005432460527	4701	Economy	13600.00
0005434082204	4701	Economy	13600.00
0005434082217	4701	Economy	13600.00
0005432568423	4701	Economy	13600.00
0005432568428	4701	Economy	13600.00
0005432170476	4701	Economy	13600.00
0005432568434	4701	Economy	13600.00
0005432568414	4701	Economy	13600.00
0005432568412	4701	Economy	13600.00
0005432568404	4701	Economy	13600.00
0005432460556	4701	Economy	13600.00
0005432460510	4701	Economy	13600.00
0005432460541	4701	Economy	13600.00
0005432568416	4701	Economy	13600.00
0005432460544	4701	Economy	13600.00
0005434082219	4701	Economy	13600.00
0005432460553	4701	Economy	13600.00
0005432460538	4701	Economy	13600.00
0005432568458	4701	Economy	13600.00
0005432568417	4701	Economy	13600.00
0005434082211	4701	Economy	13600.00
0005433726134	4701	Economy	13600.00
0005434082214	4701	Economy	13600.00
0005432170477	4701	Economy	13600.00
0005432568422	4701	Economy	13600.00
0005432568421	4701	Economy	13600.00
0005432568456	4701	Economy	13600.00
0005432460554	4701	Economy	13600.00
0005434082213	4701	Economy	13600.00
0005434082209	4701	Economy	13600.00
0005432170479	4701	Economy	13600.00
0005434082206	4701	Economy	13600.00
0005432568460	4701	Economy	13600.00
0005432460526	4701	Economy	13600.00
0005434082202	4701	Economy	13600.00
0005432568433	4701	Economy	13600.00
0005432170478	4701	Economy	13600.00
0005432568455	4701	Economy	13600.00
0005432568447	4701	Economy	13600.00
0005432460546	4701	Economy	13600.00
0005432460533	4701	Economy	13600.00
0005432568438	4701	Economy	13600.00
0005432460517	4701	Economy	13600.00
0005432568432	4701	Economy	15000.00
0005432460523	4701	Economy	15000.00
0005432460536	4701	Economy	13600.00
0005434082201	4701	Economy	13600.00
0005432571370	4701	Economy	15000.00
0005432568442	4701	Economy	15000.00
0005432568426	4701	Economy	13600.00
0005432568410	4701	Economy	13600.00
0005432568407	4701	Economy	13600.00
0005432460550	4701	Economy	13600.00
0005432460539	4701	Economy	13600.00
0005432460515	4701	Economy	13600.00
0005432568446	4701	Economy	13600.00
0005432568403	4701	Economy	13600.00
0005434082205	4701	Economy	13600.00
0005432568413	4701	Economy	13600.00
0005432170475	4701	Economy	13600.00
0005432460511	4701	Economy	13600.00
0005432460557	4701	Economy	13600.00
0005432460519	4701	Economy	13600.00
0005432568418	4701	Economy	13600.00
0005432568464	4701	Economy	13600.00
0005434082215	4701	Economy	13600.00
0005432568461	4701	Economy	13600.00
0005432460513	4701	Economy	13600.00
0005434082212	4701	Economy	13600.00
0005432460535	4701	Economy	13600.00
0005432460547	4701	Economy	13600.00
0005432568439	4701	Economy	13600.00
0005432568443	4701	Economy	13600.00
0005432460558	4701	Economy	13600.00
0005432186919	4701	Economy	13600.00
0005434082200	4701	Economy	13600.00
0005432568449	4701	Economy	13600.00
0005432568459	4701	Economy	13600.00
0005432568440	4701	Economy	13600.00
0005432460508	4701	Economy	13600.00
0005432568462	4701	Economy	13600.00
0005432460549	4701	Economy	13600.00
0005432460518	4701	Economy	13600.00
0005432568431	4701	Economy	13600.00
0005432568441	4701	Economy	13600.00
0005432568409	4701	Economy	13600.00
0005432460521	4701	Economy	13600.00
0005432460540	4701	Economy	13600.00
0005432460534	4701	Economy	13600.00
0005432568406	4701	Economy	13600.00
0005432460514	4701	Economy	13600.00
0005432568427	4701	Economy	13600.00
0005434082197	4701	Economy	13600.00
0005432460531	4701	Economy	13600.00
0005432568405	4701	Economy	13600.00
0005434082203	4701	Economy	13600.00
0005432568425	4701	Economy	13600.00
0005432568411	4701	Economy	13600.00
0005432568429	4701	Economy	13600.00
0005432460528	4701	Economy	13600.00
0005432568448	4701	Economy	13600.00
0005432568457	4701	Economy	13600.00
0005432170473	4701	Economy	13600.00
0005432460522	4701	Economy	13600.00
0005432568420	4701	Economy	13600.00
0005432460552	4701	Economy	13600.00
0005432571343	30556	Business	40900.00
0005432567995	30556	Business	40900.00
0005432567996	30556	Business	40900.00
0005434082091	30556	Business	40900.00
0005432460301	30556	Business	40900.00
0005432567976	30556	Business	40900.00
0005432460112	30556	Business	40900.00
0005433726093	30556	Business	40900.00
0005432460090	30556	Business	40900.00
0005432460001	30556	Business	40900.00
0005434081956	30556	Business	40900.00
0005432459928	30556	Business	40900.00
0005432568128	30556	Business	40900.00
0005433454880	30556	Business	40900.00
0005432568034	30556	Business	40900.00
0005432460096	30556	Business	40900.00
0005432568116	30556	Business	40900.00
0005432567749	30556	Business	40900.00
0005432568046	30556	Business	40900.00
0005432460302	30556	Business	40900.00
0005432567997	30556	Business	40900.00
0005432567816	30556	Business	40900.00
0005432460075	30556	Business	40900.00
0005432460113	30556	Business	40900.00
0005432567991	30556	Business	40900.00
0005432571347	30556	Business	40900.00
0005432460271	30556	Business	40900.00
0005434081907	30556	Economy	15000.00
0005433726104	30556	Economy	15000.00
0005432567879	30556	Economy	15000.00
0005432460145	30556	Economy	13600.00
0005432459857	30556	Economy	13600.00
0005432568118	30556	Economy	13600.00
0005433454879	30556	Economy	13600.00
0005432567812	30556	Economy	13600.00
0005432460320	30556	Economy	13600.00
0005432567913	30556	Economy	13600.00
0005432460027	30556	Economy	13600.00
0005432567953	30556	Economy	13600.00
0005432567679	30556	Economy	13600.00
0005434082071	30556	Economy	13600.00
0005433726095	30556	Economy	13600.00
0005432161181	30556	Economy	13600.00
0005434081887	30556	Economy	13600.00
0005434081940	30556	Economy	13600.00
0005434082073	30556	Economy	13600.00
0005432567814	30556	Economy	13600.00
0005432459990	30556	Economy	13600.00
0005432459953	30556	Economy	13600.00
0005432568144	30556	Economy	13600.00
0005432568198	30556	Economy	13600.00
0005434081948	30556	Economy	13600.00
0005432567813	30556	Economy	13600.00
0005432567904	30556	Economy	13600.00
0005432460147	30556	Economy	13600.00
0005434082090	30556	Economy	13600.00
0005432460267	30556	Economy	13600.00
0005432568014	30556	Economy	13600.00
0005432567943	30556	Economy	13600.00
0005432567729	30556	Economy	13600.00
0005432460287	30556	Economy	13600.00
0005432460077	30556	Economy	13600.00
0005432460124	30556	Economy	13600.00
0005433454896	30556	Economy	13600.00
0005434081878	30556	Economy	13600.00
0005432460111	30556	Economy	13600.00
0005433726106	30556	Economy	13600.00
0005432567966	30556	Economy	13600.00
0005432568042	30556	Economy	13600.00
0005432460137	30556	Economy	13600.00
0005432568110	30556	Economy	13600.00
0005432567591	30556	Economy	13600.00
0005432460066	30556	Economy	13600.00
0005432568171	30556	Economy	13600.00
0005432567933	30556	Economy	13600.00
0005434081976	30556	Economy	13600.00
0005432567980	30556	Economy	13600.00
0005432459952	30556	Economy	13600.00
0005434081959	30556	Economy	13600.00
0005432567964	30556	Economy	13600.00
0005432568002	30556	Economy	13600.00
0005432567983	30556	Economy	13600.00
0005433726079	30556	Economy	13600.00
0005434081992	30556	Economy	13600.00
0005432568181	30556	Economy	13600.00
0005433726096	30556	Economy	13600.00
0005433726108	30556	Economy	13600.00
0005432460097	30556	Economy	13600.00
0005432568182	30556	Economy	13600.00
0005432460134	30556	Economy	13600.00
0005432161182	30556	Economy	13600.00
0005432567906	30556	Economy	13600.00
0005432460322	30556	Economy	13600.00
0005432460073	30556	Economy	13600.00
0005434082025	30556	Economy	13600.00
0005432460138	30556	Economy	13600.00
0005432567874	30556	Economy	13600.00
0005434081936	30556	Economy	13600.00
0005432213656	30556	Economy	13600.00
0005432460095	30556	Economy	13600.00
0005432568094	30556	Economy	13600.00
0005432567873	30556	Economy	13600.00
0005432460123	30556	Economy	13600.00
0005432567680	30556	Economy	13600.00
0005433726105	30556	Economy	13600.00
0005432460114	30556	Economy	13600.00
0005434081918	30556	Economy	13600.00
0005434081879	30556	Economy	13600.00
0005432460076	30556	Economy	13600.00
0005432568033	30556	Economy	13600.00
0005432460101	30556	Economy	13600.00
0005432568165	30556	Economy	13600.00
0005432460026	30556	Economy	13600.00
0005434081999	30556	Economy	13600.00
0005433452749	30556	Economy	13600.00
0005432460246	30556	Economy	13600.00
0005432460314	30556	Economy	13600.00
0005432460074	30556	Economy	13600.00
0005432460172	30556	Economy	13600.00
0005432213655	30556	Economy	13600.00
0005432568180	30556	Economy	15000.00
0005433726103	30556	Economy	13600.00
0005434081876	30556	Economy	13600.00
0005432460232	30556	Economy	13600.00
0005432568169	30556	Economy	15000.00
0005432567990	30556	Economy	15000.00
0005432567788	30556	Economy	13600.00
0005432460099	30556	Economy	13600.00
0005433726086	30556	Economy	13600.00
0005432567880	30556	Economy	13600.00
0005432568245	30556	Economy	13600.00
0005433726110	30556	Economy	13600.00
0005432567954	30556	Economy	13600.00
0005434081888	30556	Economy	13600.00
0005432459840	30556	Economy	13600.00
0005432567815	30556	Economy	13600.00
0005434081898	30556	Economy	13600.00
0005432460315	30556	Economy	13600.00
0005434081877	30556	Economy	13600.00
0005432567595	30556	Economy	13600.00
0005432460227	30556	Economy	13600.00
0005432568043	30556	Economy	13600.00
0005432213657	30556	Economy	13600.00
0005432460061	30556	Economy	13600.00
0005432567850	30556	Economy	13600.00
0005432567851	30556	Economy	13600.00
0005432567836	30556	Economy	13600.00
0005432567910	30556	Economy	13600.00
0005434082024	30556	Economy	13600.00
0005434081925	30556	Economy	13600.00
0005434081919	30556	Economy	13600.00
0005434081915	30556	Economy	13600.00
0005434081822	30556	Economy	13600.00
0005432460062	30556	Economy	13600.00
0005432567903	30556	Economy	13600.00
0005432568087	30556	Economy	13600.00
0005432568197	30556	Economy	13600.00
0005432161183	30556	Economy	13600.00
0005432567554	30556	Economy	13600.00
0005432459991	30556	Economy	13600.00
0005434081975	30556	Economy	13600.00
0005432568065	30556	Economy	13600.00
0005434081958	30556	Economy	13600.00
0005433454897	30556	Economy	13600.00
0005434082021	30556	Economy	13600.00
0005432568179	30556	Economy	13600.00
0005432567955	30556	Economy	13600.00
0005432567923	30556	Economy	13600.00
0005432460170	30556	Economy	13600.00
0005432460193	30556	Economy	13600.00
0005432460035	30556	Economy	13600.00
0005432460146	30556	Economy	13600.00
0005434082068	30556	Economy	13600.00
0005432460100	30556	Economy	13600.00
0005432567852	30556	Economy	13600.00
0005432568066	30556	Economy	13600.00
0005432213654	30556	Economy	13600.00
0005434081998	30556	Economy	13600.00
0005432567926	30556	Economy	13600.00
0005432460115	30556	Economy	13600.00
0005432567867	30556	Economy	13600.00
0005433726076	30556	Economy	13600.00
0005433726109	30556	Economy	13600.00
0005432571348	30556	Economy	13600.00
0005433726101	30556	Economy	13600.00
0005432568004	30556	Economy	13600.00
0005432571341	30556	Economy	13600.00
0005432568086	30556	Economy	13600.00
0005432460266	30556	Economy	13600.00
0005432567789	30556	Economy	13600.00
0005432459909	30556	Economy	13600.00
0005432571342	30556	Economy	13600.00
0005432460321	30556	Economy	13600.00
0005433726097	30556	Economy	13600.00
0005435722087	13640	Economy	9900.00
0005435720839	13640	Economy	9900.00
0005435722086	13640	Economy	9900.00
0005435722088	13640	Economy	9900.00
0005435720840	13640	Economy	9900.00
0005435720137	21140	Economy	9900.00
0005435720138	21140	Economy	9900.00
0005435722067	21140	Economy	9900.00
0005435720139	21140	Economy	9900.00
0005435720136	21140	Economy	9900.00
0005432295915	22760	Economy	8800.00
0005432295913	22760	Economy	8800.00
0005432295914	22760	Economy	8800.00
0005433344512	11130	Business	23600.00
0005433344450	11130	Business	23600.00
0005435508415	11130	Business	23600.00
0005433344466	11130	Business	23600.00
0005435508373	11130	Business	23600.00
0005433344477	11130	Business	23600.00
0005433344458	11130	Business	23600.00
0005433344495	11130	Business	23600.00
0005433344436	11130	Business	23600.00
0005433344451	11130	Business	23600.00
0005435508421	11130	Business	23600.00
0005433344513	11130	Business	23600.00
0005433344519	11130	Economy	7900.00
0005435097330	11130	Economy	7900.00
0005435508441	11130	Economy	7900.00
0005435508399	11130	Economy	7900.00
0005433344486	11130	Economy	7900.00
0005435508397	11130	Economy	7900.00
0005433344517	11130	Economy	7900.00
0005433344479	11130	Economy	7900.00
0005433344501	11130	Economy	7900.00
0005433344480	11130	Economy	7900.00
0005433344491	11130	Economy	7900.00
0005433344470	11130	Economy	7900.00
0005435380319	11130	Economy	7900.00
0005433344492	11130	Economy	7900.00
0005433344463	11130	Economy	7900.00
0005433344438	11130	Economy	7900.00
0005433344454	11130	Economy	7900.00
0005433344523	11130	Economy	7900.00
0005433344525	11130	Economy	7900.00
0005433344521	11130	Economy	7900.00
0005433344518	11130	Economy	7900.00
0005433344499	11130	Economy	7900.00
0005433344467	11130	Economy	7900.00
0005433344448	11130	Economy	7900.00
0005433344449	11130	Economy	7900.00
0005433344439	11130	Economy	7900.00
0005433344471	11130	Economy	7900.00
0005433344465	11130	Economy	7900.00
0005435508396	11130	Economy	7900.00
0005433344443	11130	Economy	7900.00
0005435097325	11130	Economy	7900.00
0005433344504	11130	Economy	7900.00
0005435097326	11130	Economy	7900.00
0005435508403	11130	Economy	7900.00
0005433344472	11130	Economy	7900.00
0005433344457	11130	Economy	7900.00
0005433344440	11130	Economy	7900.00
0005433344441	11130	Economy	7900.00
0005435097323	11130	Economy	7900.00
0005433344506	11130	Economy	7900.00
0005435508407	11130	Economy	8600.00
0005433344530	11130	Economy	8600.00
0005435508408	11130	Economy	8600.00
0005435508404	11130	Economy	8600.00
0005433344522	11130	Economy	8600.00
0005433344445	11130	Economy	8600.00
0005433344488	11130	Economy	7900.00
0005433344452	11130	Economy	7900.00
0005433344533	11130	Economy	7900.00
0005435508422	11130	Economy	7900.00
0005435097331	11130	Economy	7900.00
0005435508402	11130	Economy	7900.00
0005433344455	11130	Economy	7900.00
0005433344460	11130	Economy	7900.00
0005433344462	11130	Economy	7900.00
0005433344435	11130	Economy	7900.00
0005433344526	11130	Economy	7900.00
0005433344484	11130	Economy	7900.00
0005433344505	11130	Economy	7900.00
0005433344447	11130	Economy	7900.00
0005433344520	11130	Economy	7900.00
0005433344459	11130	Economy	7900.00
0005433344529	11130	Economy	7900.00
0005435097329	11130	Economy	7900.00
0005433344469	11130	Economy	7900.00
0005433344487	11130	Economy	7900.00
0005433344531	11130	Economy	7900.00
0005433344489	11130	Economy	7900.00
0005433344524	11130	Economy	7900.00
0005433344433	11130	Economy	7900.00
0005435508416	11130	Economy	7900.00
0005433344497	11130	Economy	7900.00
0005433344475	11130	Economy	7900.00
0005433344434	11130	Economy	7900.00
0005435097322	11130	Economy	7900.00
0005433344502	11130	Economy	7900.00
0005433344496	11130	Economy	7900.00
0005433344453	11130	Economy	7900.00
0005433344485	11130	Economy	7900.00
0005435508405	11130	Economy	7900.00
0005433344468	11130	Economy	7900.00
0005433344532	11130	Economy	7900.00
0005433344481	11130	Economy	7900.00
0005433344527	11130	Economy	7900.00
0005433344498	11130	Economy	7900.00
0005435508423	11130	Economy	7900.00
0005433344461	11130	Economy	7900.00
0005433344456	11130	Economy	7900.00
0005433344500	11130	Economy	7900.00
0005433344493	11130	Economy	7900.00
0005433344516	11130	Economy	7900.00
0005433344474	11130	Economy	7900.00
0005433344483	11130	Economy	7900.00
0005435380271	11130	Economy	7900.00
0005433344478	11130	Economy	7900.00
0005433344510	11130	Economy	7900.00
0005435097328	11130	Economy	7900.00
0005433344511	11130	Economy	7900.00
0005433344515	11130	Economy	7900.00
0005433344514	11130	Economy	7900.00
0005433344509	11130	Economy	7900.00
0005433344482	11130	Economy	7900.00
0005433344508	11130	Economy	7900.00
0005433344507	11130	Economy	7900.00
0005433344490	11130	Economy	7900.00
0005433344528	11130	Economy	7900.00
0005433344437	11130	Economy	7900.00
0005433344503	11130	Economy	7900.00
0005433344494	11130	Economy	7900.00
0005433344464	11130	Economy	7900.00
0005433344442	11130	Economy	7900.00
0005433344473	11130	Economy	7900.00
0005433344476	11130	Economy	7900.00
0005433344446	11130	Economy	7900.00
0005433344444	11130	Economy	7900.00
0005435380326	11130	Economy	7900.00
0005435097327	11130	Economy	7900.00
0005435097324	11130	Economy	7900.00
0005433343405	17096	Business	23600.00
0005433343276	17096	Business	23600.00
0005433343784	17096	Business	23600.00
0005433343499	17096	Business	23600.00
0005433343549	17096	Business	23600.00
0005433343594	17096	Business	23600.00
0005433343568	17096	Business	23600.00
0005433343533	17096	Business	23600.00
0005433343651	17096	Business	23600.00
0005435097230	17096	Business	23600.00
0005435097227	17096	Business	23600.00
0005433343468	17096	Business	23600.00
0005433343680	17096	Economy	7900.00
0005432293241	17096	Economy	7900.00
0005433343278	17096	Economy	7900.00
0005433343783	17096	Economy	7900.00
0005433343739	17096	Economy	7900.00
0005433343429	17096	Economy	7900.00
0005433343615	17096	Economy	7900.00
0005433343855	17096	Economy	7900.00
0005433343356	17096	Economy	7900.00
0005433343584	17096	Economy	7900.00
0005435097242	17096	Economy	7900.00
0005433343419	17096	Economy	7900.00
0005433343620	17096	Economy	7900.00
0005433343766	17096	Economy	7900.00
0005433343732	17096	Economy	7900.00
0005435097214	17096	Economy	7900.00
0005433343573	17096	Economy	7900.00
0005433343662	17096	Economy	7900.00
0005433343652	17096	Economy	7900.00
0005433343344	17096	Economy	7900.00
0005433343661	17096	Economy	7900.00
0005433343452	17096	Economy	7900.00
0005433342980	17096	Economy	7900.00
0005433343338	17096	Economy	7900.00
0005433343707	17096	Economy	7900.00
0005433343806	17096	Economy	7900.00
0005433343621	17096	Economy	7900.00
0005435097255	17096	Economy	7900.00
0005433343748	17096	Economy	7900.00
0005433343698	17096	Economy	7900.00
0005433343575	17096	Economy	7900.00
0005433343454	17096	Economy	7900.00
0005433343414	17096	Economy	7900.00
0005433343331	17096	Economy	7900.00
0005433343527	17096	Economy	7900.00
0005433343840	17096	Economy	7900.00
0005433343301	17096	Economy	7900.00
0005433343493	17096	Economy	7900.00
0005433343492	17096	Economy	8600.00
0005433343567	17096	Economy	8600.00
0005433343431	17096	Economy	8600.00
0005433343345	17096	Economy	8600.00
0005435097241	17096	Economy	8600.00
0005433343557	17096	Economy	7900.00
0005433343127	17096	Economy	7900.00
0005433343691	17096	Economy	7900.00
0005433343484	17096	Economy	7900.00
0005433343552	17096	Economy	7900.00
0005435097215	17096	Economy	7900.00
0005433343343	17096	Economy	7900.00
0005433343380	17096	Economy	7900.00
0005433343513	17096	Economy	7900.00
0005433343964	17096	Economy	7900.00
0005433343816	17096	Economy	7900.00
0005433343757	17096	Economy	7900.00
0005433343595	17096	Economy	7900.00
0005433343279	17096	Economy	7900.00
0005433343510	17096	Economy	7900.00
0005433343859	17096	Economy	7900.00
0005435380359	17096	Economy	7900.00
0005433343643	17096	Economy	7900.00
0005433342979	17096	Economy	7900.00
0005433343339	17096	Economy	7900.00
0005435545845	17096	Economy	7900.00
0005433343300	17096	Economy	7900.00
0005435097266	17096	Economy	7900.00
0005433343708	17096	Economy	7900.00
0005433343709	17096	Economy	7900.00
0005435380361	17096	Economy	7900.00
0005433343751	17096	Economy	7900.00
0005433343039	17096	Economy	7900.00
0005435380360	17096	Economy	7900.00
0005432293240	17096	Economy	7900.00
0005433343332	17096	Economy	7900.00
0005433343202	17096	Economy	7900.00
0005432293242	17096	Economy	7900.00
0005433343347	17096	Economy	7900.00
0005433343275	17096	Economy	7900.00
0005433343193	17096	Economy	7900.00
0005433343400	17096	Economy	7900.00
0005433343316	17096	Economy	7900.00
0005433342978	17096	Economy	7900.00
0005433343717	17096	Economy	7900.00
0005435097234	17096	Economy	7900.00
0005433343194	17096	Economy	7900.00
0005433343610	17096	Economy	7900.00
0005433343965	17096	Economy	7900.00
0005433343611	17096	Economy	7900.00
0005433343509	17096	Economy	7900.00
0005433343498	17096	Economy	7900.00
0005433343317	17096	Economy	7900.00
0005433343432	17096	Economy	7900.00
0005433343333	17096	Economy	7900.00
0005433343415	17096	Economy	7900.00
0005435380362	17096	Economy	7900.00
0005433343550	17096	Economy	7900.00
0005433342964	17096	Economy	7900.00
0005433343697	17096	Economy	7900.00
0005433343805	17096	Economy	7900.00
0005435545846	17096	Economy	7900.00
0005433343514	17096	Economy	7900.00
0005433343656	17096	Economy	7900.00
0005433343731	17096	Economy	7900.00
0005433343428	17096	Economy	7900.00
0005433343453	17096	Economy	7900.00
0005433343231	17096	Economy	7900.00
0005433343660	17096	Economy	7900.00
0005433342963	17096	Economy	7900.00
0005433343966	17096	Economy	7900.00
0005433343616	17096	Economy	7900.00
0005435380358	17096	Economy	7900.00
0005433343406	17096	Economy	7900.00
0005432919893	9111	Business	26600.00
0005433507417	9111	Business	26600.00
0005433481273	9111	Business	26600.00
0005433481267	9111	Business	26600.00
0005433507414	9111	Business	26600.00
0005433507427	9111	Business	26600.00
0005433481271	9111	Economy	8900.00
0005432919992	9111	Economy	8900.00
0005433507408	9111	Economy	8900.00
0005432920071	9111	Economy	8900.00
0005433507407	9111	Economy	8900.00
0005433507415	9111	Economy	8900.00
0005433507429	9111	Economy	8900.00
0005432919905	9111	Economy	9800.00
0005433507426	9111	Economy	9800.00
0005433507424	9111	Economy	9800.00
0005433507413	9111	Economy	8900.00
0005432919966	9111	Economy	8900.00
0005432919993	9111	Economy	8900.00
0005433481272	9111	Economy	8900.00
0005433481269	9111	Economy	8900.00
0005433507425	9111	Economy	8900.00
0005433507412	9111	Economy	8900.00
0005433507422	9111	Economy	8900.00
0005433507409	9111	Economy	8900.00
0005432920080	9111	Economy	8900.00
0005433507418	9111	Economy	8900.00
0005432919934	9111	Economy	8900.00
0005432919960	9111	Economy	8900.00
0005433507428	9111	Economy	8900.00
0005433507416	9111	Economy	8900.00
0005432919804	9111	Economy	8900.00
0005432919950	9111	Economy	8900.00
0005432920024	9111	Economy	8900.00
0005432919970	9111	Economy	8900.00
0005432919954	9111	Economy	8900.00
0005432919796	9111	Economy	8900.00
0005433507420	9111	Economy	8900.00
0005433481270	9111	Economy	8900.00
0005433507419	9111	Economy	8900.00
0005433507421	9111	Economy	8900.00
0005432919961	9111	Economy	8900.00
0005432919999	9111	Economy	8900.00
0005432920082	9111	Economy	8900.00
0005433481268	9111	Economy	8900.00
0005432919918	9111	Economy	8900.00
0005433507410	9111	Economy	8900.00
0005432920081	9111	Economy	8900.00
0005433507411	9111	Economy	8900.00
0005433507423	9111	Economy	8900.00
0005432920160	20491	Business	26600.00
0005433507300	20491	Business	26600.00
0005432920149	20491	Business	26600.00
0005432920162	20491	Business	26600.00
0005433507294	20491	Business	26600.00
0005433481213	20491	Business	26600.00
0005433507295	20491	Business	26600.00
0005433481234	20491	Economy	8900.00
0005432920157	20491	Economy	8900.00
0005433481206	20491	Economy	8900.00
0005432920156	20491	Economy	8900.00
0005433481235	20491	Economy	8900.00
0005433507301	20491	Economy	8900.00
0005432920163	20491	Economy	8900.00
0005433507161	20491	Economy	9800.00
0005433507256	20491	Economy	9800.00
0005433507278	20491	Economy	8900.00
0005433481208	20491	Economy	8900.00
0005433507304	20491	Economy	8900.00
0005433507282	20491	Economy	8900.00
0005433507277	20491	Economy	8900.00
0005433507260	20491	Economy	8900.00
0005432920164	20491	Economy	8900.00
0005433507262	20491	Economy	8900.00
0005432920155	20491	Economy	8900.00
0005432920161	20491	Economy	8900.00
0005433507259	20491	Economy	8900.00
0005433481207	20491	Economy	8900.00
0005433507299	20491	Economy	8900.00
0005432920151	20491	Economy	8900.00
0005433507191	20491	Economy	8900.00
0005432920146	20491	Economy	8900.00
0005432920147	20491	Economy	8900.00
0005433507296	20491	Economy	8900.00
0005432920152	20491	Economy	8900.00
0005433507293	20491	Economy	8900.00
0005433507261	20491	Economy	8900.00
0005433507283	20491	Economy	8900.00
0005432920148	20491	Economy	8900.00
0005433481212	20491	Economy	8900.00
0005432920154	20491	Economy	8900.00
0005433507266	20491	Economy	8900.00
0005432920150	20491	Economy	8900.00
0005433507279	20491	Economy	8900.00
0005432920153	20491	Economy	8900.00
0005433507220	20491	Economy	8900.00
0005432920158	20491	Economy	8900.00
0005432920165	20491	Economy	8900.00
0005433507243	20491	Economy	8900.00
0005432920159	20491	Economy	8900.00
0005433507240	20491	Economy	8900.00
0005435179695	10147	Economy	5800.00
0005435178992	10147	Economy	5800.00
0005432394153	10147	Economy	5800.00
0005432396293	10147	Economy	5800.00
0005432394154	10147	Economy	5800.00
0005435178997	10147	Economy	5800.00
0005432396294	10147	Economy	5800.00
0005432394155	10147	Economy	5800.00
0005435179694	10147	Economy	5800.00
0005432396253	18383	Economy	5800.00
0005432400134	18383	Economy	5800.00
0005432396261	18383	Economy	5800.00
0005432400133	18383	Economy	5800.00
0005435179406	18383	Economy	5800.00
0005432400138	18383	Economy	5800.00
0005432396252	18383	Economy	5800.00
0005432396268	18383	Economy	5800.00
0005432400139	18383	Economy	5800.00
0005432400150	18383	Economy	5800.00
0005432400152	18383	Economy	5800.00
0005432400151	18383	Economy	5800.00
0005435126509	10962	Business	9500.00
0005435626198	10962	Business	9500.00
0005435626253	10962	Business	9500.00
0005435626192	10962	Business	9500.00
0005435126552	10962	Business	9500.00
0005435126373	10962	Business	9500.00
0005435126598	10962	Business	9500.00
0005434411837	10962	Business	9500.00
0005435126557	10962	Economy	3200.00
0005435126732	10962	Economy	3200.00
0005435126374	10962	Economy	3200.00
0005434928336	10962	Economy	3200.00
0005435126464	10962	Economy	3200.00
0005435626190	10962	Economy	3200.00
0005435126465	10962	Economy	3200.00
0005435126575	10962	Economy	3200.00
0005435126425	10962	Economy	3500.00
0005435126413	10962	Economy	3500.00
0005434928337	10962	Economy	3500.00
0005435126429	10962	Economy	3500.00
0005435626244	10962	Economy	3200.00
0005435126570	10962	Economy	3200.00
0005435556688	10962	Economy	3200.00
0005435626243	10962	Economy	3200.00
0005435126386	10962	Economy	3200.00
0005435126553	10962	Economy	3200.00
0005435126571	10962	Economy	3200.00
0005435126398	10962	Economy	3200.00
0005435126723	10962	Economy	3200.00
0005435126631	10962	Economy	3200.00
0005434411836	10962	Economy	3200.00
0005435626234	10962	Economy	3200.00
0005435626233	10962	Economy	3200.00
0005435626191	10962	Economy	3200.00
0005435626201	10962	Economy	3200.00
0005434928338	10962	Economy	3200.00
0005434411834	10962	Economy	3200.00
0005435126491	10962	Economy	3200.00
0005435126399	10962	Economy	3200.00
0005435126462	10962	Economy	3200.00
0005435126523	10962	Economy	3200.00
0005435126699	10962	Economy	3200.00
0005434411835	10962	Economy	3200.00
0005435126525	10962	Economy	3200.00
0005435126387	10962	Economy	3200.00
0005435626182	10962	Economy	3200.00
0005435556710	10962	Economy	3200.00
0005435554212	10962	Economy	3200.00
0005435554206	10962	Economy	3200.00
0005435126480	10962	Economy	3200.00
0005435126376	10962	Economy	3200.00
0005435126479	10962	Economy	3200.00
0005435626219	10962	Economy	3200.00
0005435126558	10962	Economy	3200.00
0005435626237	10962	Economy	3200.00
0005435626242	10962	Economy	3200.00
0005435126444	10962	Economy	3200.00
0005435126503	10962	Economy	3200.00
0005435126544	10962	Economy	3200.00
0005435626202	10962	Economy	3200.00
0005435626220	10962	Economy	3200.00
0005435126490	10962	Economy	3200.00
0005435126578	10962	Economy	3200.00
0005435126461	10962	Economy	3200.00
0005435556689	10962	Economy	3200.00
0005435626259	10962	Economy	3200.00
0005435126412	10962	Economy	3200.00
0005435126426	10962	Economy	3200.00
0005435126577	10962	Economy	3200.00
0005435126524	10962	Economy	3200.00
0005435126599	10962	Economy	3200.00
0005435126430	10962	Economy	3200.00
0005435126583	10962	Economy	3200.00
0005435626261	10962	Economy	3200.00
0005435126530	10962	Economy	3200.00
0005434928301	14742	Business	9500.00
0005435126899	14742	Business	9500.00
0005435126897	14742	Business	9500.00
0005435556725	14742	Business	9500.00
0005435626417	14742	Business	9500.00
0005435626423	14742	Business	9500.00
0005435126916	14742	Business	9500.00
0005435126917	14742	Business	9500.00
0005435126919	14742	Economy	3200.00
0005435626415	14742	Economy	3200.00
0005435126905	14742	Economy	3200.00
0005435126934	14742	Economy	3200.00
0005435126935	14742	Economy	3200.00
0005435126926	14742	Economy	3200.00
0005434928307	14742	Economy	3200.00
0005435126937	14742	Economy	3200.00
0005435626430	14742	Economy	3200.00
0005435626426	14742	Economy	3500.00
0005435554248	14742	Economy	3500.00
0005435126901	14742	Economy	3500.00
0005435626432	14742	Economy	3500.00
0005435626421	14742	Economy	3500.00
0005435126912	14742	Economy	3200.00
0005435626418	14742	Economy	3200.00
0005435126928	14742	Economy	3200.00
0005435626414	14742	Economy	3200.00
0005435126930	14742	Economy	3200.00
0005435126904	14742	Economy	3200.00
0005435626422	14742	Economy	3200.00
0005434411781	14742	Economy	3200.00
0005434411785	14742	Economy	3200.00
0005435126900	14742	Economy	3200.00
0005435126911	14742	Economy	3200.00
0005435126903	14742	Economy	3200.00
0005435126924	14742	Economy	3200.00
0005435126932	14742	Economy	3200.00
0005435626425	14742	Economy	3200.00
0005435126902	14742	Economy	3200.00
0005435126915	14742	Economy	3200.00
0005434411792	14742	Economy	3200.00
0005435126908	14742	Economy	3200.00
0005435126920	14742	Economy	3200.00
0005435626428	14742	Economy	3200.00
0005435126921	14742	Economy	3200.00
0005435626419	14742	Economy	3200.00
0005435126918	14742	Economy	3200.00
0005435126923	14742	Economy	3200.00
0005435626431	14742	Economy	3200.00
0005435126929	14742	Economy	3200.00
0005435126927	14742	Economy	3200.00
0005435126906	14742	Economy	3200.00
0005435126936	14742	Economy	3200.00
0005434928316	14742	Economy	3200.00
0005435126933	14742	Economy	3200.00
0005435626427	14742	Economy	3200.00
0005435556726	14742	Economy	3200.00
0005434411786	14742	Economy	3200.00
0005435554250	14742	Economy	3200.00
0005435126922	14742	Economy	3200.00
0005435626416	14742	Economy	3200.00
0005435554247	14742	Economy	3200.00
0005435126913	14742	Economy	3200.00
0005435126909	14742	Economy	3200.00
0005435126914	14742	Economy	3200.00
0005435626420	14742	Economy	3200.00
0005435126910	14742	Economy	3200.00
0005435126931	14742	Economy	3200.00
0005435126925	14742	Economy	3200.00
0005435554249	14742	Economy	3200.00
0005435126898	14742	Economy	3200.00
0005435626424	14742	Economy	3200.00
0005435556727	14742	Economy	3200.00
0005435126907	14742	Economy	3200.00
0005435556724	14742	Economy	3200.00
0005435626429	14742	Economy	3200.00
0005435443373	7127	Business	86900.00
0005435715695	7127	Business	86900.00
0005435179396	7127	Business	86900.00
0005435715705	7127	Business	86900.00
0005435443394	7127	Economy	29000.00
0005432398250	7127	Economy	29000.00
0005435216587	7127	Economy	29000.00
0005435715703	7127	Economy	29000.00
0005435221053	7127	Economy	29000.00
0005435715701	7127	Economy	31900.00
0005435178508	7127	Economy	29000.00
0005435443371	7127	Economy	29000.00
0005435216586	7127	Economy	29000.00
0005432400174	7127	Economy	29000.00
0005435715692	7127	Economy	29000.00
0005432398248	7127	Economy	29000.00
0005435715693	7127	Economy	29000.00
0005435715689	7127	Economy	29000.00
0005435715691	7127	Economy	29000.00
0005435179399	7127	Economy	29000.00
0005435221061	7127	Economy	29000.00
0005435715702	7127	Economy	29000.00
0005435443395	7127	Economy	29000.00
0005435715694	7127	Economy	29000.00
0005435715696	7127	Economy	29000.00
0005435443315	7127	Economy	29000.00
0005432398249	7127	Economy	29000.00
0005435715700	7127	Economy	29000.00
0005435443359	7127	Economy	29000.00
0005435443363	7127	Economy	29000.00
0005435715704	7127	Economy	29000.00
0005435179397	7127	Economy	29000.00
0005435715690	7127	Economy	29000.00
0005432400175	7127	Economy	29000.00
0005435715688	7127	Economy	29000.00
0005435443349	7127	Economy	29000.00
0005435179398	7127	Economy	29000.00
0005435715698	7127	Economy	29000.00
0005432400173	7127	Economy	29000.00
0005435715697	7127	Economy	29000.00
0005435715699	7127	Economy	29000.00
0005435715512	27097	Business	86900.00
0005435715597	27097	Business	86900.00
0005435715511	27097	Business	86900.00
0005432394115	27097	Business	86900.00
0005432394110	27097	Economy	29000.00
0005432394111	27097	Economy	29000.00
0005435443441	27097	Economy	29000.00
0005435715556	27097	Economy	29000.00
0005435715541	27097	Economy	31900.00
0005432398203	27097	Economy	29000.00
0005435715546	27097	Economy	29000.00
0005435443437	27097	Economy	29000.00
0005432394114	27097	Economy	29000.00
0005435443439	27097	Economy	29000.00
0005435715542	27097	Economy	29000.00
0005432398215	27097	Economy	29000.00
0005435715567	27097	Economy	29000.00
0005435443435	27097	Economy	29000.00
0005435715537	27097	Economy	29000.00
0005435715491	27097	Economy	29000.00
0005435443442	27097	Economy	29000.00
0005435715490	27097	Economy	29000.00
0005435715555	27097	Economy	29000.00
0005435443436	27097	Economy	29000.00
0005435715487	27097	Economy	29000.00
0005432398223	27097	Economy	29000.00
0005432398224	27097	Economy	29000.00
0005435715566	27097	Economy	29000.00
0005435443443	27097	Economy	29000.00
0005435715565	27097	Economy	29000.00
0005435443440	27097	Economy	29000.00
0005432394133	27097	Economy	29000.00
0005432398214	27097	Economy	29000.00
0005435443438	27097	Economy	29000.00
0005434084994	2722	Economy	7700.00
0005434084993	2722	Economy	7700.00
0005434084995	2722	Economy	7700.00
0005434084992	2722	Economy	7700.00
0005434084991	2722	Economy	7700.00
0005434084990	2722	Economy	7700.00
0005434084953	28498	Economy	7700.00
0005433060449	28498	Economy	7700.00
0005434084960	28498	Economy	7700.00
0005434084952	28498	Economy	7700.00
0005433060448	28498	Economy	7700.00
0005433060450	28498	Economy	7700.00
0005434084948	28498	Economy	7700.00
0005434084951	28498	Economy	7700.00
0005435541175	11392	Business	20200.00
0005435518025	11392	Business	20200.00
0005435518078	11392	Business	20200.00
0005435518016	11392	Business	20200.00
0005435518024	11392	Business	20200.00
0005435541126	11392	Business	20200.00
0005435517988	11392	Economy	6700.00
0005435541083	11392	Economy	6700.00
0005435541118	11392	Economy	6700.00
0005435517998	11392	Economy	7400.00
0005435517995	11392	Economy	6700.00
0005435541026	11392	Economy	6700.00
0005435541173	11392	Economy	6700.00
0005435518093	11392	Economy	6700.00
0005435517974	11392	Economy	6700.00
0005435541117	11392	Economy	6700.00
0005435518006	11392	Economy	6700.00
0005435541145	11392	Economy	6700.00
0005435517919	11392	Economy	6700.00
0005435517920	11392	Economy	6700.00
0005435517971	11392	Economy	6700.00
0005435517981	11392	Economy	6700.00
0005435517975	11392	Economy	6700.00
0005435517994	11392	Economy	6700.00
0005435541189	11392	Economy	6700.00
0005435541140	11392	Economy	6700.00
0005435517970	11392	Economy	6700.00
0005435518012	11392	Economy	6700.00
0005435541101	11392	Economy	6700.00
0005435541190	11392	Economy	6700.00
0005435518047	11392	Economy	6700.00
0005435517987	11392	Economy	6700.00
0005435518034	11392	Economy	6700.00
0005435541159	11392	Economy	6700.00
0005435541174	11392	Economy	6700.00
0005435541066	11392	Economy	6700.00
0005435541139	11392	Economy	6700.00
0005435517982	11392	Economy	6700.00
0005435541273	22245	Business	20200.00
0005432294519	22245	Business	20200.00
0005435529523	22245	Business	20200.00
0005435529526	22245	Business	20200.00
0005435529539	22245	Business	20200.00
0005435541285	22245	Business	20200.00
0005435529528	22245	Business	20200.00
0005435529525	22245	Economy	6700.00
0005435529524	22245	Economy	6700.00
0005435541265	22245	Economy	6700.00
0005435541279	22245	Economy	6700.00
0005435529537	22245	Economy	7400.00
0005435541275	22245	Economy	7400.00
0005435529538	22245	Economy	6700.00
0005435541271	22245	Economy	6700.00
0005435529540	22245	Economy	6700.00
0005435529521	22245	Economy	6700.00
0005435541281	22245	Economy	6700.00
0005435529529	22245	Economy	6700.00
0005435529534	22245	Economy	6700.00
0005432294518	22245	Economy	6700.00
0005435529536	22245	Economy	6700.00
0005435529530	22245	Economy	6700.00
0005435529531	22245	Economy	6700.00
0005435541269	22245	Economy	6700.00
0005435541282	22245	Economy	6700.00
0005435541284	22245	Economy	6700.00
0005435541283	22245	Economy	6700.00
0005435541267	22245	Economy	6700.00
0005435541280	22245	Economy	6700.00
0005435529535	22245	Economy	6700.00
0005435541268	22245	Economy	6700.00
0005435541266	22245	Economy	6700.00
0005435529541	22245	Economy	6700.00
0005435541276	22245	Economy	6700.00
0005435541286	22245	Economy	6700.00
0005432294516	22245	Economy	6700.00
0005435541277	22245	Economy	6700.00
0005435541278	22245	Economy	6700.00
0005435529532	22245	Economy	6700.00
0005435529522	22245	Economy	6700.00
0005435541272	22245	Economy	6700.00
0005435541274	22245	Economy	6700.00
0005435529542	22245	Economy	6700.00
0005435529533	22245	Economy	6700.00
0005435529527	22245	Economy	6700.00
0005435541270	22245	Economy	6700.00
0005432294517	22245	Economy	6700.00
0005433251678	2288	Business	20200.00
0005434907982	2288	Business	20200.00
0005433251542	2288	Business	20200.00
0005433251478	2288	Business	20200.00
0005433251781	2288	Business	20200.00
0005434907965	2288	Business	20200.00
0005434907981	2288	Business	20200.00
0005433251692	2288	Business	20200.00
0005433251630	2288	Business	20200.00
0005433251479	2288	Business	20200.00
0005434908000	2288	Business	20200.00
0005433251690	2288	Business	20200.00
0005434907970	2288	Economy	6700.00
0005433251701	2288	Economy	6700.00
0005434907985	2288	Economy	6700.00
0005433251689	2288	Economy	6700.00
0005434908018	2288	Economy	6700.00
0005434907988	2288	Economy	6700.00
0005434907964	2288	Economy	6700.00
0005434907971	2288	Economy	6700.00
0005434908004	2288	Economy	6700.00
0005434907996	2288	Economy	7400.00
0005434908011	2288	Economy	7400.00
0005434908014	2288	Economy	7400.00
0005434907997	2288	Economy	7400.00
0005433251693	2288	Economy	7400.00
0005434907987	2288	Economy	6700.00
0005433251674	2288	Economy	6700.00
0005434908017	2288	Economy	6700.00
0005433251695	2288	Economy	6700.00
0005433251591	2288	Economy	6700.00
0005434907973	2288	Economy	6700.00
0005433251780	2288	Economy	6700.00
0005434907986	2288	Economy	6700.00
0005433251694	2288	Economy	6700.00
0005433251789	2288	Economy	6700.00
0005433251702	2288	Economy	6700.00
0005434908009	2288	Economy	6700.00
0005434907999	2288	Economy	6700.00
0005434907968	2288	Economy	6700.00
0005434908020	2288	Economy	6700.00
0005434908006	2288	Economy	6700.00
0005434908016	2288	Economy	6700.00
0005433251637	2288	Economy	6700.00
0005434907991	2288	Economy	6700.00
0005434907994	2288	Economy	6700.00
0005433251577	2288	Economy	6700.00
0005434908015	2288	Economy	6700.00
0005434907984	2288	Economy	6700.00
0005433251672	2288	Economy	6700.00
0005434908021	2288	Economy	6700.00
0005434908002	2288	Economy	6700.00
0005433251766	2288	Economy	6700.00
0005434908013	2288	Economy	6700.00
0005434907989	2288	Economy	6700.00
0005434908022	2288	Economy	6700.00
0005434908010	2288	Economy	6700.00
0005434907992	2288	Economy	6700.00
0005434907977	2288	Economy	6700.00
0005434907974	2288	Economy	6700.00
0005434907969	2288	Economy	6700.00
0005434907961	2288	Economy	6700.00
0005434908019	2288	Economy	6700.00
0005433251673	2288	Economy	6700.00
0005433251703	2288	Economy	6700.00
0005434908005	2288	Economy	6700.00
0005434907979	2288	Economy	6700.00
0005434907966	2288	Economy	6700.00
0005434907963	2288	Economy	6700.00
0005433251704	2288	Economy	6700.00
0005433251677	2288	Economy	6700.00
0005434907998	2288	Economy	6700.00
0005434907993	2288	Economy	6700.00
0005433251767	2288	Economy	6700.00
0005434907980	2288	Economy	6700.00
0005434908003	2288	Economy	6700.00
0005434907962	2288	Economy	6700.00
0005434908008	2288	Economy	6700.00
0005434907990	2288	Economy	6700.00
0005434907978	2288	Economy	6700.00
0005434907975	2288	Economy	6700.00
0005433251602	2288	Economy	6700.00
0005434907983	2288	Economy	6700.00
0005434908001	2288	Economy	6700.00
0005434907967	2288	Economy	6700.00
0005434907995	2288	Economy	6700.00
0005434908012	2288	Economy	6700.00
0005434907972	2288	Economy	6700.00
0005433251735	2288	Economy	6700.00
0005433251691	2288	Economy	6700.00
0005434908007	2288	Economy	6700.00
0005434907976	2288	Economy	6700.00
0005434907432	25593	Business	20200.00
0005434907635	25593	Business	20200.00
0005434907431	25593	Business	20200.00
0005434907398	25593	Business	20200.00
0005434907197	25593	Business	20200.00
0005433251892	25593	Business	20200.00
0005434907528	25593	Business	20200.00
0005433251905	25593	Business	20200.00
0005434907530	25593	Business	20200.00
0005434907517	25593	Business	20200.00
0005434907399	25593	Business	20200.00
0005434907634	25593	Business	20200.00
0005433251881	25593	Economy	6700.00
0005434907460	25593	Economy	6700.00
0005434907513	25593	Economy	6700.00
0005434907419	25593	Economy	6700.00
0005433251883	25593	Economy	6700.00
0005434907166	25593	Economy	6700.00
0005434907493	25593	Economy	6700.00
0005433251879	25593	Economy	6700.00
0005434907629	25593	Economy	6700.00
0005433251896	25593	Economy	7400.00
0005434907393	25593	Economy	7400.00
0005434907640	25593	Economy	7400.00
0005434907472	25593	Economy	7400.00
0005434907504	25593	Economy	7400.00
0005433251906	25593	Economy	6700.00
0005434907531	25593	Economy	6700.00
0005434907400	25593	Economy	6700.00
0005433251878	25593	Economy	6700.00
0005433251901	25593	Economy	6700.00
0005433401024	25593	Economy	6700.00
0005434907506	25593	Economy	6700.00
0005434907627	25593	Economy	6700.00
0005434907650	25593	Economy	6700.00
0005433251876	25593	Economy	6700.00
0005433251884	25593	Economy	6700.00
0005433251880	25593	Economy	6700.00
0005434907348	25593	Economy	6700.00
0005434907450	25593	Economy	6700.00
0005433251886	25593	Economy	6700.00
0005434907521	25593	Economy	6700.00
0005433251882	25593	Economy	6700.00
0005434907451	25593	Economy	6700.00
0005434907462	25593	Economy	6700.00
0005434907527	25593	Economy	6700.00
0005434907555	25593	Economy	6700.00
0005433401023	25593	Economy	6700.00
0005434907167	25593	Economy	6700.00
0005434907443	25593	Economy	6700.00
0005434907364	25593	Economy	6700.00
0005434907473	25593	Economy	6700.00
0005434907459	25593	Economy	6700.00
0005434907469	25593	Economy	6700.00
0005434907503	25593	Economy	6700.00
0005434907641	25593	Economy	6700.00
0005434907630	25593	Economy	6700.00
0005434907562	25593	Economy	6700.00
0005433251900	25593	Economy	6700.00
0005434907512	25593	Economy	6700.00
0005434907421	25593	Economy	6700.00
0005434907356	25593	Economy	6700.00
0005433251894	25593	Economy	6700.00
0005433251902	25593	Economy	6700.00
0005433251904	25593	Economy	6700.00
0005433401025	25593	Economy	6700.00
0005434907516	25593	Economy	6700.00
0005433251891	25593	Economy	6700.00
0005433251897	25593	Economy	6700.00
0005433251888	25593	Economy	6700.00
0005434907463	25593	Economy	6700.00
0005433251887	25593	Economy	6700.00
0005434907639	25593	Economy	6700.00
0005433251903	25593	Economy	6700.00
0005433251899	25593	Economy	6700.00
0005434907536	25593	Economy	6700.00
0005433251893	25593	Economy	6700.00
0005434907430	25593	Economy	6700.00
0005434907537	25593	Economy	6700.00
0005434907284	25593	Economy	6700.00
0005434907474	25593	Economy	6700.00
0005433251877	25593	Economy	6700.00
0005433251890	25593	Economy	6700.00
0005433251889	25593	Economy	6700.00
0005434907358	25593	Economy	6700.00
0005433251898	25593	Economy	6700.00
0005433251885	25593	Economy	6700.00
0005434907505	25593	Economy	6700.00
0005434907420	25593	Economy	6700.00
0005433251895	25593	Economy	6700.00
0005432621233	2498	Economy	13600.00
0005432862320	2498	Economy	13600.00
0005432862368	2498	Economy	13600.00
0005432621222	2498	Economy	12400.00
0005432621231	2498	Economy	12400.00
0005432621228	2498	Economy	12400.00
0005432621234	2498	Economy	12400.00
0005432621227	2498	Economy	12400.00
0005432621230	2498	Economy	12400.00
0005432621221	2498	Economy	12400.00
0005432862314	2498	Economy	12400.00
0005432621229	2498	Economy	12400.00
0005432862329	2498	Economy	12400.00
0005432621224	2498	Economy	12400.00
0005432621223	2498	Economy	12400.00
0005432621232	2498	Economy	12400.00
0005432621225	2498	Economy	12400.00
0005432621226	2498	Economy	12400.00
0005432621077	28081	Economy	13600.00
0005432862406	28081	Economy	13600.00
0005432862409	28081	Economy	12400.00
0005432621063	28081	Economy	12400.00
0005432621202	28081	Economy	12400.00
0005432862408	28081	Economy	12400.00
0005432621127	28081	Economy	12400.00
0005432621057	28081	Economy	12400.00
0005432862404	28081	Economy	12400.00
0005432621096	28081	Economy	12400.00
0005432621203	28081	Economy	12400.00
0005432862407	28081	Economy	12400.00
0005432862402	28081	Economy	12400.00
0005432621126	28081	Economy	12400.00
0005432862405	28081	Economy	12400.00
0005432621062	28081	Economy	12400.00
0005432621201	28081	Economy	12400.00
0005432621141	28081	Economy	12400.00
0005432862403	28081	Economy	12400.00
0005432621143	28081	Economy	12400.00
0005432621142	28081	Economy	12400.00
0005434097482	11717	Economy	11300.00
0005434097485	11717	Economy	11300.00
0005434097484	11717	Economy	11300.00
0005434097483	11717	Economy	11300.00
0005434097495	13020	Economy	11300.00
0005433451645	31033	Economy	8400.00
0005433452767	31033	Economy	8400.00
0005433451646	31033	Economy	8400.00
0005433452749	31452	Economy	8400.00
0005433454896	31452	Economy	8400.00
0005433454880	31452	Economy	8400.00
0005433454879	31452	Economy	8400.00
0005433454897	31452	Economy	8400.00
0005433134164	12029	Economy	6600.00
0005434184673	12029	Economy	6600.00
0005433134165	12029	Economy	6600.00
0005433134159	12029	Economy	6600.00
0005433134168	12029	Economy	6600.00
0005433134156	12029	Economy	6600.00
0005433134174	12029	Economy	6600.00
0005434142630	12029	Economy	6600.00
0005434142629	12029	Economy	6600.00
0005434142661	29864	Economy	6600.00
0005433131769	29864	Economy	6600.00
0005434183607	29864	Economy	6600.00
0005433134198	29864	Economy	6600.00
0005434142658	29864	Economy	6600.00
0005433134199	29864	Economy	6600.00
0005434183606	29864	Economy	6600.00
0005433134201	29864	Economy	6600.00
0005434142660	29864	Economy	6600.00
0005434184692	29864	Economy	6600.00
0005434184691	29864	Economy	6600.00
0005433131770	29864	Economy	6600.00
0005433134200	29864	Economy	6600.00
0005433131771	29864	Economy	6600.00
0005434142659	29864	Economy	6600.00
0005433131768	29864	Economy	6600.00
0005435697686	16455	Economy	19900.00
0005435697701	16455	Economy	19900.00
0005435935064	16455	Economy	19900.00
0005435697696	16455	Economy	18100.00
0005435697681	16455	Economy	18100.00
0005435697685	16455	Economy	18100.00
0005435697676	16455	Economy	18100.00
0005435697684	16455	Economy	18100.00
0005435697691	16455	Economy	18100.00
0005435697697	16455	Economy	18100.00
0005435697700	16455	Economy	18100.00
0005435697692	16455	Economy	18100.00
0005435697687	16455	Economy	18100.00
0005435697689	16455	Economy	18100.00
0005435697682	16455	Economy	18100.00
0005435697693	16455	Economy	18100.00
0005435697702	16455	Economy	18100.00
0005435697678	16455	Economy	18100.00
0005435697695	16455	Economy	18100.00
0005435697699	16455	Economy	18100.00
0005435697683	16455	Economy	18100.00
0005435697690	16455	Economy	18100.00
0005435697704	16455	Economy	18100.00
0005435697703	16455	Economy	18100.00
0005435697694	16455	Economy	18100.00
0005435697698	16455	Economy	18100.00
0005435697679	16455	Economy	18100.00
0005435697677	16455	Economy	18100.00
0005435697680	16455	Economy	18100.00
0005435697688	16455	Economy	18100.00
0005435697475	24696	Economy	19900.00
0005435935087	24696	Economy	19900.00
0005435697494	24696	Economy	19900.00
0005435697406	24696	Economy	19900.00
0005435697437	24696	Economy	18100.00
0005435697488	24696	Economy	18100.00
0005435697407	24696	Economy	18100.00
0005435697474	24696	Economy	18100.00
0005435697548	24696	Economy	18100.00
0005435697514	24696	Economy	18100.00
0005435697450	24696	Economy	18100.00
0005435697449	24696	Economy	18100.00
0005435697477	24696	Economy	18100.00
0005435935084	24696	Economy	18100.00
0005435697606	24696	Economy	18100.00
0005435697482	24696	Economy	18100.00
0005435697461	24696	Economy	18100.00
0005435697400	24696	Economy	18100.00
0005435697408	24696	Economy	18100.00
0005435697581	24696	Economy	18100.00
0005435697489	24696	Economy	18100.00
0005435697396	24696	Economy	18100.00
0005435697395	24696	Economy	18100.00
0005435697460	24696	Economy	18100.00
0005435935085	24696	Economy	18100.00
0005435697351	24696	Economy	18100.00
0005435697528	24696	Economy	18100.00
0005435697399	24696	Economy	18100.00
0005435697405	24696	Economy	18100.00
0005435697583	24696	Economy	18100.00
0005435697553	24696	Economy	18100.00
0005435697381	24696	Economy	18100.00
0005435697447	24696	Economy	18100.00
0005435935086	24696	Economy	18100.00
0005435697584	24696	Economy	18100.00
0005435697352	24696	Economy	18100.00
0005435697401	24696	Economy	18100.00
0005435697479	24696	Economy	18100.00
0005435697459	24696	Economy	18100.00
0005433724861	18800	Economy	4400.00
0005432968846	18800	Economy	4400.00
0005432968847	18800	Economy	4400.00
0005432968843	18800	Economy	4400.00
0005433724864	18800	Economy	4400.00
0005432968857	18800	Economy	4400.00
0005433724863	18800	Economy	4400.00
0005433724862	18800	Economy	4400.00
0005432968856	18800	Economy	4400.00
0005432968872	21596	Economy	4400.00
0005432968874	21596	Economy	4400.00
0005433724827	21596	Economy	4400.00
0005432968873	21596	Economy	4400.00
0005434139285	7335	Business	23100.00
0005434139260	7335	Business	23100.00
0005434139251	7335	Business	23100.00
0005434139287	7335	Business	23100.00
0005434139226	7335	Business	23100.00
0005434139217	7335	Business	23100.00
0005434139255	7335	Business	23100.00
0005434139254	7335	Business	23100.00
0005434139237	7335	Business	23100.00
0005434139222	7335	Business	23100.00
0005434139248	7335	Business	23100.00
0005434139239	7335	Economy	7700.00
0005434139228	7335	Economy	7700.00
0005434087578	7335	Economy	7700.00
0005434139243	7335	Economy	7700.00
0005434139229	7335	Economy	7700.00
0005434139256	7335	Economy	7700.00
0005434139220	7335	Economy	7700.00
0005434139274	7335	Economy	8500.00
0005434139273	7335	Economy	8500.00
0005434139218	7335	Economy	8500.00
0005434139280	7335	Economy	8500.00
0005434139290	7335	Economy	7700.00
0005434139261	7335	Economy	7700.00
0005434139231	7335	Economy	7700.00
0005434139288	7335	Economy	7700.00
0005434139216	7335	Economy	7700.00
0005434139219	7335	Economy	7700.00
0005434139240	7335	Economy	7700.00
0005434139262	7335	Economy	7700.00
0005434139223	7335	Economy	7700.00
0005434139238	7335	Economy	7700.00
0005434139244	7335	Economy	7700.00
0005434139283	7335	Economy	7700.00
0005434139270	7335	Economy	7700.00
0005434139268	7335	Economy	7700.00
0005434139246	7335	Economy	7700.00
0005434139242	7335	Economy	7700.00
0005434139258	7335	Economy	7700.00
0005434139236	7335	Economy	7700.00
0005434139264	7335	Economy	7700.00
0005434087577	7335	Economy	7700.00
0005434139279	7335	Economy	7700.00
0005434139286	7335	Economy	7700.00
0005434139224	7335	Economy	7700.00
0005434139284	7335	Economy	7700.00
0005434087582	7335	Economy	7700.00
0005434139233	7335	Economy	7700.00
0005434087579	7335	Economy	7700.00
0005434139289	7335	Economy	7700.00
0005434139257	7335	Economy	7700.00
0005434139263	7335	Economy	7700.00
0005434139215	7335	Economy	7700.00
0005434087580	7335	Economy	7700.00
0005434139234	7335	Economy	7700.00
0005434139225	7335	Economy	7700.00
0005434139266	7335	Economy	7700.00
0005434139277	7335	Economy	7700.00
0005434139232	7335	Economy	7700.00
0005434139281	7335	Economy	7700.00
0005434139291	7335	Economy	7700.00
0005434139282	7335	Economy	7700.00
0005434139275	7335	Economy	7700.00
0005434139227	7335	Economy	7700.00
0005434087581	7335	Economy	7700.00
0005434139253	7335	Economy	7700.00
0005434139259	7335	Economy	7700.00
0005434139250	7335	Economy	7700.00
0005434139252	7335	Economy	7700.00
0005434139221	7335	Economy	7700.00
0005434139269	7335	Economy	7700.00
0005434139278	7335	Economy	7700.00
0005434139230	7335	Economy	7700.00
0005434139265	7335	Economy	7700.00
0005434139272	7335	Economy	7700.00
0005434139247	7335	Economy	7700.00
0005434139276	7335	Economy	7700.00
0005434139271	7335	Economy	7700.00
0005434139249	7335	Economy	7700.00
0005434139245	7335	Economy	7700.00
0005434139241	7335	Economy	7700.00
0005434139267	7335	Economy	7700.00
0005434139235	7335	Economy	7700.00
0005434138465	28586	Business	23100.00
0005434138466	28586	Business	23100.00
0005434138391	28586	Business	23100.00
0005434138531	28586	Business	23100.00
0005434138585	28586	Business	23100.00
0005435283555	28586	Business	23100.00
0005434138386	28586	Business	23100.00
0005434087542	28586	Business	23100.00
0005434138310	28586	Business	23100.00
0005434087541	28586	Business	23100.00
0005434138195	28586	Economy	7700.00
0005434138303	28586	Economy	7700.00
0005434138573	28586	Economy	7700.00
0005434138845	28586	Economy	7700.00
0005434138605	28586	Economy	7700.00
0005434138654	28586	Economy	7700.00
0005434138312	28586	Economy	7700.00
0005434087527	28586	Economy	7700.00
0005434138503	28586	Economy	8500.00
0005434138775	28586	Economy	8500.00
0005434138922	28586	Economy	7700.00
0005434138761	28586	Economy	7700.00
0005434138574	28586	Economy	7700.00
0005434138653	28586	Economy	7700.00
0005434138385	28586	Economy	7700.00
0005434138499	28586	Economy	7700.00
0005434087557	28586	Economy	7700.00
0005434138399	28586	Economy	7700.00
0005434087550	28586	Economy	7700.00
0005434138506	28586	Economy	7700.00
0005434138145	28586	Economy	7700.00
0005434138471	28586	Economy	7700.00
0005434138243	28586	Economy	7700.00
0005434138437	28586	Economy	7700.00
0005434138263	28586	Economy	7700.00
0005434138125	28586	Economy	7700.00
0005434138655	28586	Economy	7700.00
0005434138333	28586	Economy	7700.00
0005434138606	28586	Economy	7700.00
0005434138481	28586	Economy	7700.00
0005434138393	28586	Economy	7700.00
0005434138354	28586	Economy	7700.00
0005434138464	28586	Economy	7700.00
0005434138619	28586	Economy	7700.00
0005434138353	28586	Economy	7700.00
0005435283567	28586	Economy	7700.00
0005434138395	28586	Economy	7700.00
0005434138006	28586	Economy	7700.00
0005434138417	28586	Economy	7700.00
0005434138510	28586	Economy	7700.00
0005434087549	28586	Economy	7700.00
0005434138242	28586	Economy	7700.00
0005434138457	28586	Economy	7700.00
0005434138511	28586	Economy	7700.00
0005434138413	28586	Economy	7700.00
0005434138419	28586	Economy	7700.00
0005434138504	28586	Economy	7700.00
0005434138322	28586	Economy	7700.00
0005434138486	28586	Economy	7700.00
0005434138622	28586	Economy	7700.00
0005434138407	28586	Economy	7700.00
0005434138321	28586	Economy	7700.00
0005434138222	28586	Economy	7700.00
0005434138617	28586	Economy	7700.00
0005434137689	28586	Economy	7700.00
0005434138449	28586	Economy	7700.00
0005434138495	28586	Economy	7700.00
0005434138844	28586	Economy	7700.00
0005434138664	28586	Economy	7700.00
0005434087548	28586	Economy	7700.00
0005434138682	28586	Economy	7700.00
0005434087507	28586	Economy	7700.00
0005434138328	28586	Economy	7700.00
0005434138575	28586	Economy	7700.00
0005434138309	28586	Economy	7700.00
0005434138601	28586	Economy	7700.00
0005434138480	28586	Economy	7700.00
0005434137688	28586	Economy	7700.00
0005434138683	28586	Economy	7700.00
0005434138479	28586	Economy	7700.00
0005434138507	28586	Economy	7700.00
0005434138502	28586	Economy	7700.00
0005434138390	28586	Economy	7700.00
0005434138461	28586	Economy	7700.00
0005434087558	28586	Economy	7700.00
0005434138982	28586	Economy	7700.00
0005435808379	1952	Economy	23900.00
0005435808370	1952	Economy	23900.00
0005433407593	1952	Economy	21700.00
0005434610277	1952	Economy	21700.00
0005435808375	1952	Economy	21700.00
0005435808377	1952	Economy	21700.00
0005435808380	1952	Economy	21700.00
0005435808372	1952	Economy	21700.00
0005433407594	1952	Economy	21700.00
0005434610276	1952	Economy	21700.00
0005435808371	1952	Economy	21700.00
0005433407576	1952	Economy	21700.00
0005435808374	1952	Economy	21700.00
0005434610279	1952	Economy	21700.00
0005433407575	1952	Economy	21700.00
0005435808381	1952	Economy	21700.00
0005434610278	1952	Economy	21700.00
0005433407592	1952	Economy	21700.00
0005435808376	1952	Economy	21700.00
0005435808373	1952	Economy	21700.00
0005433407569	1952	Economy	21700.00
0005435808378	1952	Economy	21700.00
0005434610240	23071	Economy	21700.00
0005434610249	23071	Economy	21700.00
0005434610254	23071	Economy	21700.00
0005434610253	23071	Economy	21700.00
0005434610239	23071	Economy	21700.00
0005434610236	23071	Economy	21700.00
0005434610238	23071	Economy	21700.00
0005434610237	23071	Economy	21700.00
0005434504249	16712	Economy	7600.00
0005434504358	16712	Economy	7600.00
0005434504137	16712	Economy	7600.00
0005434504312	16712	Economy	7600.00
0005434504426	16712	Economy	6900.00
0005434504272	16712	Economy	6900.00
0005434504309	16712	Economy	6900.00
0005434504311	16712	Economy	6900.00
0005434504333	16712	Economy	6900.00
0005434504155	16712	Economy	6900.00
0005434504315	16712	Economy	6900.00
0005434504242	16712	Economy	6900.00
0005434504181	16712	Economy	6900.00
0005434504330	16712	Economy	6900.00
0005434504299	16712	Economy	6900.00
0005434504304	16712	Economy	6900.00
0005434504344	16712	Economy	6900.00
0005434504316	16712	Economy	6900.00
0005434504308	16712	Economy	6900.00
0005434504396	16712	Economy	6900.00
0005434504288	16712	Economy	6900.00
0005434504241	16712	Economy	6900.00
0005434504262	16712	Economy	6900.00
0005434504379	16712	Economy	6900.00
0005434504071	16712	Economy	6900.00
0005434504353	16712	Economy	6900.00
0005434504378	16712	Economy	6900.00
0005434504357	16712	Economy	6900.00
0005434504261	16712	Economy	6900.00
0005434504302	16712	Economy	6900.00
0005434504287	16712	Economy	6900.00
0005434504402	16712	Economy	6900.00
0005434504215	16712	Economy	6900.00
0005434504350	16712	Economy	6900.00
0005434504329	16712	Economy	6900.00
0005434504256	16712	Economy	6900.00
0005434504322	16712	Economy	6900.00
0005434504420	16712	Economy	6900.00
0005434504428	16712	Economy	6900.00
0005434504349	16712	Economy	6900.00
0005434504303	16712	Economy	6900.00
0005434504321	16712	Economy	6900.00
0005434504252	16712	Economy	6900.00
0005434504314	16712	Economy	6900.00
0005434504317	16712	Economy	6900.00
0005434504300	16712	Economy	6900.00
0005434504257	16712	Economy	6900.00
0005434504334	16712	Economy	6900.00
0005434504655	22884	Economy	7600.00
0005434504643	22884	Economy	7600.00
0005434504639	22884	Economy	7600.00
0005434504626	22884	Economy	7600.00
0005434504648	22884	Economy	6900.00
0005434504650	22884	Economy	6900.00
0005434504662	22884	Economy	6900.00
0005434504633	22884	Economy	6900.00
0005434504640	22884	Economy	6900.00
0005434504647	22884	Economy	6900.00
0005434504623	22884	Economy	6900.00
0005434504641	22884	Economy	6900.00
0005434504659	22884	Economy	6900.00
0005434504642	22884	Economy	6900.00
0005434504644	22884	Economy	6900.00
0005434504645	22884	Economy	6900.00
0005434504652	22884	Economy	6900.00
0005434504661	22884	Economy	6900.00
0005434504625	22884	Economy	6900.00
0005434504632	22884	Economy	6900.00
0005434504631	22884	Economy	6900.00
0005434504636	22884	Economy	6900.00
0005434504653	22884	Economy	6900.00
0005434504635	22884	Economy	6900.00
0005434504638	22884	Economy	6900.00
0005434504660	22884	Economy	6900.00
0005434504656	22884	Economy	6900.00
0005434504657	22884	Economy	6900.00
0005434504651	22884	Economy	6900.00
0005434504627	22884	Economy	6900.00
0005434504624	22884	Economy	6900.00
0005434504649	22884	Economy	6900.00
0005434504637	22884	Economy	6900.00
0005434504663	22884	Economy	6900.00
0005434504646	22884	Economy	6900.00
0005434504654	22884	Economy	6900.00
0005434504628	22884	Economy	6900.00
0005434504629	22884	Economy	6900.00
0005434504658	22884	Economy	6900.00
0005434504634	22884	Economy	6900.00
0005434504630	22884	Economy	6900.00
0005433266735	2172	Economy	7700.00
0005435078543	2172	Economy	7700.00
0005435078553	2172	Economy	7700.00
0005433266722	2172	Economy	7000.00
0005435078552	2172	Economy	7000.00
0005433266721	2172	Economy	7000.00
0005433266739	2172	Economy	7000.00
0005435078548	2172	Economy	7000.00
0005435078551	2172	Economy	7000.00
0005433266723	2172	Economy	7000.00
0005435078556	2172	Economy	7000.00
0005435078550	2172	Economy	7000.00
0005433266782	2172	Economy	7000.00
0005435078545	2172	Economy	7000.00
0005435078547	2172	Economy	7000.00
0005435078558	2172	Economy	7000.00
0005435078554	2172	Economy	7000.00
0005435078557	2172	Economy	7000.00
0005435078544	2172	Economy	7000.00
0005435078555	2172	Economy	7000.00
0005433266720	2172	Economy	7000.00
0005435078549	2172	Economy	7000.00
0005435078546	2172	Economy	7000.00
0005433266847	24366	Economy	7700.00
0005435078428	24366	Economy	7700.00
0005433266846	24366	Economy	7700.00
0005435078445	24366	Economy	7000.00
0005435078452	24366	Economy	7000.00
0005435078395	24366	Economy	7000.00
0005435078401	24366	Economy	7000.00
0005435078454	24366	Economy	7000.00
0005435078434	24366	Economy	7000.00
0005435078402	24366	Economy	7000.00
0005435078424	24366	Economy	7000.00
0005435078433	24366	Economy	7000.00
0005433266852	24366	Economy	7000.00
0005433266850	24366	Economy	7000.00
0005435078435	24366	Economy	7000.00
0005433266843	24366	Economy	7000.00
0005435078492	24366	Economy	7000.00
0005435078455	24366	Economy	7000.00
0005433266848	24366	Economy	7000.00
0005433266844	24366	Economy	7000.00
0005433266849	24366	Economy	7000.00
0005433266845	24366	Economy	7000.00
0005435078423	24366	Economy	7000.00
0005433266851	24366	Economy	7000.00
0005435078378	24366	Economy	7000.00
0005435078418	24366	Economy	7000.00
0005435078444	24366	Economy	7000.00
0005434988888	6613	Economy	9800.00
0005435803299	6613	Economy	9800.00
0005434988889	6613	Economy	9800.00
0005435803298	6613	Economy	9800.00
0005434988887	6613	Economy	9800.00
0005434988886	6613	Economy	9800.00
0005434988890	6613	Economy	9800.00
0005434988891	6613	Economy	9800.00
0005434988893	6613	Economy	9800.00
0005434988892	6613	Economy	9800.00
0005435803300	6613	Economy	9800.00
0005435464535	23605	Economy	9800.00
0005434988722	23605	Economy	9800.00
0005434988723	23605	Economy	9800.00
0005435464536	23605	Economy	9800.00
0005434988735	23605	Economy	9800.00
0005434988748	23605	Economy	9800.00
0005435803274	23605	Economy	9800.00
0005434988713	23605	Economy	9800.00
0005435803270	23605	Economy	9800.00
0005434988736	23605	Economy	9800.00
0005434988759	23605	Economy	9800.00
0005434988714	23605	Economy	9800.00
0005433450253	30475	Business	9900.00
0005432383688	30475	Business	9900.00
0005433450271	30475	Business	9900.00
0005432383697	30475	Business	9900.00
0005432383693	30475	Business	9900.00
0005433450265	30475	Business	9900.00
0005432383701	30475	Business	9900.00
0005432383692	30475	Economy	3300.00
0005433450272	30475	Economy	3300.00
0005432383699	30475	Economy	3300.00
0005433450268	30475	Economy	3300.00
0005433450267	30475	Economy	3600.00
0005432383681	30475	Economy	3600.00
0005432383691	30475	Economy	3600.00
0005433450269	30475	Economy	3300.00
0005433453787	30475	Economy	3300.00
0005432383702	30475	Economy	3300.00
0005433450254	30475	Economy	3300.00
0005433450255	30475	Economy	3300.00
0005432383698	30475	Economy	3300.00
0005432383683	30475	Economy	3300.00
0005432383694	30475	Economy	3300.00
0005432383689	30475	Economy	3300.00
0005433454903	30475	Economy	3300.00
0005433450264	30475	Economy	3300.00
0005433450263	30475	Economy	3300.00
0005432383684	30475	Economy	3300.00
0005432383686	30475	Economy	3300.00
0005432383705	30475	Economy	3300.00
0005433450270	30475	Economy	3300.00
0005433450260	30475	Economy	3300.00
0005433454904	30475	Economy	3300.00
0005432383690	30475	Economy	3300.00
0005433450257	30475	Economy	3300.00
0005432383695	30475	Economy	3300.00
0005433450252	30475	Economy	3300.00
0005432383703	30475	Economy	3300.00
0005432383708	30475	Economy	3300.00
0005432383700	30475	Economy	3300.00
0005432383704	30475	Economy	3300.00
0005432383706	30475	Economy	3300.00
0005433450266	30475	Economy	3300.00
0005433450256	30475	Economy	3300.00
0005433450261	30475	Economy	3300.00
0005432383707	30475	Economy	3300.00
0005432383696	30475	Economy	3300.00
0005432383682	30475	Economy	3300.00
0005432383685	30475	Economy	3300.00
0005432383687	30475	Economy	3300.00
0005432383680	30475	Economy	3300.00
0005433450258	30475	Economy	3300.00
0005433450259	30475	Economy	3300.00
0005433450273	30475	Economy	3300.00
0005433450262	30475	Economy	3300.00
0005432383228	31283	Business	9900.00
0005432383216	31283	Business	9900.00
0005432383282	31283	Business	9900.00
0005433450132	31283	Business	9900.00
0005432383109	31283	Business	9900.00
0005432383193	31283	Business	9900.00
0005432383343	31283	Business	9900.00
0005432383428	31283	Economy	3300.00
0005432383344	31283	Economy	3300.00
0005432383211	31283	Economy	3300.00
0005433450034	31283	Economy	3300.00
0005432383221	31283	Economy	3300.00
0005432383207	31283	Economy	3300.00
0005433450035	31283	Economy	3600.00
0005433450074	31283	Economy	3600.00
0005433450070	31283	Economy	3600.00
0005433450092	31283	Economy	3600.00
0005432383283	31283	Economy	3300.00
0005432383468	31283	Economy	3300.00
0005433450053	31283	Economy	3300.00
0005432383342	31283	Economy	3300.00
0005433450022	31283	Economy	3300.00
0005433450036	31283	Economy	3300.00
0005432383262	31283	Economy	3300.00
0005433450126	31283	Economy	3300.00
0005433450100	31283	Economy	3300.00
0005433449964	31283	Economy	3300.00
0005432383253	31283	Economy	3300.00
0005433450111	31283	Economy	3300.00
0005433449996	31283	Economy	3300.00
0005432383470	31283	Economy	3300.00
0005432383287	31283	Economy	3300.00
0005433450069	31283	Economy	3300.00
0005432383151	31283	Economy	3300.00
0005433450081	31283	Economy	3300.00
0005433453770	31283	Economy	3300.00
0005433450127	31283	Economy	3300.00
0005432383090	31283	Economy	3300.00
0005432383288	31283	Economy	3300.00
0005432383257	31283	Economy	3300.00
0005432383225	31283	Economy	3300.00
0005432383256	31283	Economy	3300.00
0005432383220	31283	Economy	3300.00
0005432383313	31283	Economy	3300.00
0005433450093	31283	Economy	3300.00
0005432383208	31283	Economy	3300.00
0005432383336	31283	Economy	3300.00
0005433450057	31283	Economy	3300.00
0005432383219	31283	Economy	3300.00
0005432383189	31283	Economy	3300.00
0005432383345	31283	Economy	3300.00
0005433449987	31283	Economy	3300.00
0005433451627	31283	Economy	3300.00
0005432383310	31283	Economy	3300.00
0005433450091	31283	Economy	3300.00
0005433450115	31283	Economy	3300.00
0005432383252	31283	Economy	3300.00
0005433450056	31283	Economy	3300.00
0005432383178	31283	Economy	3300.00
0005432383255	31283	Economy	3300.00
0005432383308	31283	Economy	3300.00
0005432383327	31283	Economy	3300.00
0005433450136	31283	Economy	3300.00
0005432383469	31283	Economy	3300.00
0005433449997	31283	Economy	3300.00
0005433453764	31283	Economy	3300.00
0005435548480	20819	Economy	26200.00
0005435548487	20819	Economy	26200.00
0005433788255	20819	Economy	23800.00
0005435548479	20819	Economy	23800.00
0005435548491	20819	Economy	23800.00
0005435548502	20819	Economy	23800.00
0005435548508	20819	Economy	23800.00
0005433788249	20819	Economy	23800.00
0005435548495	20819	Economy	23800.00
0005433788259	20819	Economy	23800.00
0005433788256	20819	Economy	23800.00
0005435548482	20819	Economy	23800.00
0005433788250	20819	Economy	23800.00
0005433788254	20819	Economy	23800.00
0005433788262	20819	Economy	23800.00
0005435548503	20819	Economy	23800.00
0005435548501	20819	Economy	23800.00
0005433788257	20819	Economy	23800.00
0005435548497	20819	Economy	23800.00
0005435548481	20819	Economy	23800.00
0005433788261	20819	Economy	23800.00
0005433788253	20819	Economy	23800.00
0005435548507	20819	Economy	23800.00
0005435548499	20819	Economy	23800.00
0005433788263	20819	Economy	23800.00
0005435548504	20819	Economy	23800.00
0005435548494	20819	Economy	23800.00
0005433788251	20819	Economy	23800.00
0005433788260	20819	Economy	23800.00
0005433788252	20819	Economy	23800.00
0005435548486	20819	Economy	23800.00
0005435548496	20819	Economy	23800.00
0005435548483	20819	Economy	23800.00
0005433788258	20819	Economy	23800.00
0005435548511	20819	Economy	23800.00
0005433788216	26487	Economy	26200.00
0005433788214	26487	Economy	26200.00
0005433788217	26487	Economy	26200.00
0005433788229	26487	Economy	23800.00
0005433788230	26487	Economy	23800.00
0005435548553	26487	Economy	23800.00
0005433788207	26487	Economy	23800.00
0005435548557	26487	Economy	23800.00
0005435548560	26487	Economy	23800.00
0005435548558	26487	Economy	23800.00
0005433788225	26487	Economy	23800.00
0005435548547	26487	Economy	23800.00
0005435548554	26487	Economy	23800.00
0005435548552	26487	Economy	23800.00
0005435548559	26487	Economy	23800.00
0005433788209	26487	Economy	23800.00
0005435548549	26487	Economy	23800.00
0005433788233	26487	Economy	23800.00
0005433788206	26487	Economy	23800.00
0005435548555	26487	Economy	23800.00
0005433788228	26487	Economy	23800.00
0005435548551	26487	Economy	23800.00
0005435548548	26487	Economy	23800.00
0005433788213	26487	Economy	23800.00
0005433788212	26487	Economy	23800.00
0005433788211	26487	Economy	23800.00
0005433788210	26487	Economy	23800.00
0005433788215	26487	Economy	23800.00
0005433788232	26487	Economy	23800.00
0005433788231	26487	Economy	23800.00
0005435548556	26487	Economy	23800.00
0005433788208	26487	Economy	23800.00
0005435548550	26487	Economy	23800.00
0005433788222	26487	Economy	23800.00
0005433131744	10770	Economy	17100.00
0005435299801	10770	Economy	17100.00
0005433126870	10770	Economy	15600.00
0005433126869	10770	Economy	15600.00
0005435304192	10770	Economy	15600.00
0005433131728	10770	Economy	15600.00
0005435304169	10770	Economy	15600.00
0005433131734	10770	Economy	15600.00
0005433126860	10770	Economy	15600.00
0005435304181	10770	Economy	15600.00
0005433131727	10770	Economy	15600.00
0005433126855	10770	Economy	15600.00
0005435304195	10770	Economy	15600.00
0005435304187	10770	Economy	15600.00
0005435304194	10770	Economy	15600.00
0005435304168	10770	Economy	15600.00
0005435299777	10770	Economy	15600.00
0005435302268	29706	Economy	17100.00
0005435302265	29706	Economy	15600.00
0005435299845	29706	Economy	15600.00
0005435299843	29706	Economy	15600.00
0005433129340	29706	Economy	15600.00
0005433126912	29706	Economy	15600.00
0005435302267	29706	Economy	15600.00
0005433129342	29706	Economy	15600.00
0005435302266	29706	Economy	15600.00
0005433126909	29706	Economy	15600.00
0005433126911	29706	Economy	15600.00
0005433126908	29706	Economy	15600.00
0005435299846	29706	Economy	15600.00
0005435299844	29706	Economy	15600.00
0005433129344	29706	Economy	15600.00
0005433129343	29706	Economy	15600.00
0005433126910	29706	Economy	15600.00
0005433129341	29706	Economy	15600.00
0005433129339	29706	Economy	15600.00
0005433110107	2426	Economy	17200.00
0005433110106	2426	Economy	17200.00
0005434287579	2426	Economy	17200.00
0005433110103	2426	Economy	15700.00
0005434287577	2426	Economy	15700.00
0005434287595	2426	Economy	15700.00
0005433110098	2426	Economy	15700.00
0005434287578	2426	Economy	15700.00
0005434287585	2426	Economy	15700.00
0005434287597	2426	Economy	15700.00
0005434287581	2426	Economy	15700.00
0005434287586	2426	Economy	15700.00
0005434287582	2426	Economy	15700.00
0005434287589	2426	Economy	15700.00
0005434287588	2426	Economy	15700.00
0005434287576	2426	Economy	15700.00
0005434287584	2426	Economy	15700.00
0005434287590	2426	Economy	15700.00
0005433110120	2426	Economy	15700.00
0005434287591	2426	Economy	15700.00
0005434287580	2426	Economy	15700.00
0005433110163	2426	Economy	15700.00
0005434287587	2426	Economy	15700.00
0005432264509	2426	Economy	15700.00
0005433110101	2426	Economy	15700.00
0005434287594	2426	Economy	15700.00
0005434287593	2426	Economy	15700.00
0005433110148	2426	Economy	15700.00
0005433110102	2426	Economy	15700.00
0005433110097	2426	Economy	15700.00
0005434287583	2426	Economy	15700.00
0005432264508	2426	Economy	15700.00
0005434287596	2426	Economy	15700.00
0005434287592	2426	Economy	15700.00
0005433110149	2426	Economy	15700.00
0005434287333	26846	Economy	17200.00
0005434287415	26846	Economy	17200.00
0005434287388	26846	Economy	15700.00
0005433110210	26846	Economy	15700.00
0005434287334	26846	Economy	15700.00
0005434287359	26846	Economy	15700.00
0005433110211	26846	Economy	15700.00
0005433110220	26846	Economy	15700.00
0005434287485	26846	Economy	15700.00
0005433110218	26846	Economy	15700.00
0005434287323	26846	Economy	15700.00
0005434287324	26846	Economy	15700.00
0005434287384	26846	Economy	15700.00
0005434287332	26846	Economy	15700.00
0005434287402	26846	Economy	15700.00
0005433110215	26846	Economy	15700.00
0005433110214	26846	Economy	15700.00
0005434287486	26846	Economy	15700.00
0005434287295	26846	Economy	15700.00
0005434287387	26846	Economy	15700.00
0005433110213	26846	Economy	15700.00
0005434287335	26846	Economy	15700.00
0005434287416	26846	Economy	15700.00
0005433110209	26846	Economy	15700.00
0005433110212	26846	Economy	15700.00
0005433110217	26846	Economy	15700.00
0005434287447	26846	Economy	15700.00
0005434287484	26846	Economy	15700.00
0005433110216	26846	Economy	15700.00
0005433110219	26846	Economy	15700.00
0005434287367	26846	Economy	15700.00
0005435856262	25480	Economy	25000.00
0005435856260	25480	Economy	22800.00
0005434269102	25480	Economy	22800.00
0005434272194	25480	Economy	22800.00
0005435856263	25480	Economy	22800.00
0005434272193	25480	Economy	22800.00
0005435856261	25480	Economy	22800.00
0005435856212	26649	Economy	22800.00
0005435856213	26649	Economy	22800.00
0005435856211	26649	Economy	22800.00
0005435856210	26649	Economy	22800.00
0005435856197	26649	Economy	22800.00
0005434520363	6097	Economy	24600.00
0005434520375	6097	Economy	24600.00
0005434520371	6097	Economy	24600.00
0005434520367	6097	Economy	22300.00
0005434520370	6097	Economy	22300.00
0005434520379	6097	Economy	22300.00
0005435314844	6097	Economy	22300.00
0005435314858	6097	Economy	22300.00
0005434520365	6097	Economy	22300.00
0005435314867	6097	Economy	22300.00
0005434520364	6097	Economy	22300.00
0005435314851	6097	Economy	22300.00
0005434520378	6097	Economy	22300.00
0005434520374	6097	Economy	22300.00
0005434520381	6097	Economy	22300.00
0005435314849	6097	Economy	22300.00
0005434520387	6097	Economy	22300.00
0005435314830	6097	Economy	22300.00
0005435314850	6097	Economy	22300.00
0005434520388	6097	Economy	22300.00
0005434520373	6097	Economy	22300.00
0005435314839	6097	Economy	22300.00
0005434520376	6097	Economy	22300.00
0005434520386	6097	Economy	22300.00
0005434520366	6097	Economy	22300.00
0005434520368	6097	Economy	22300.00
0005435314834	6097	Economy	22300.00
0005434520383	6097	Economy	22300.00
0005435314835	6097	Economy	22300.00
0005434520372	6097	Economy	22300.00
0005434520369	6097	Economy	22300.00
0005434520382	6097	Economy	22300.00
0005435314857	6097	Economy	22300.00
0005434520377	6097	Economy	22300.00
0005435314845	6097	Economy	22300.00
0005434520384	6097	Economy	22300.00
0005435314817	6097	Economy	22300.00
0005434520385	6097	Economy	22300.00
0005435314873	6097	Economy	22300.00
0005435314838	6097	Economy	22300.00
0005434520380	6097	Economy	22300.00
0005435314846	6097	Economy	22300.00
0005433650805	7164	Business	89800.00
0005435263673	7164	Business	89800.00
0005433650838	7164	Business	89800.00
0005433650839	7164	Business	89800.00
0005433650856	7164	Business	89800.00
0005433650803	7164	Business	89800.00
0005435263656	7164	Business	89800.00
0005433650831	7164	Business	89800.00
0005433650863	7164	Business	89800.00
0005433650818	7164	Business	89800.00
0005435263618	7164	Business	89800.00
0005433650814	7164	Economy	29900.00
0005433650850	7164	Economy	29900.00
0005433650812	7164	Economy	29900.00
0005433650844	7164	Economy	29900.00
0005433650843	7164	Economy	29900.00
0005433650860	7164	Economy	29900.00
0005433650853	7164	Economy	29900.00
0005433650861	7164	Economy	29900.00
0005433650826	7164	Economy	29900.00
0005433650821	7164	Economy	29900.00
0005433650807	7164	Economy	32900.00
0005435263648	7164	Economy	32900.00
0005435263634	7164	Economy	32900.00
0005433650800	7164	Economy	32900.00
0005435263676	7164	Economy	32900.00
0005433650815	7164	Economy	29900.00
0005433650851	7164	Economy	29900.00
0005435263616	7164	Economy	29900.00
0005433650820	7164	Economy	29900.00
0005433650801	7164	Economy	29900.00
0005435263671	7164	Economy	29900.00
0005433650832	7164	Economy	29900.00
0005433650854	7164	Economy	29900.00
0005433650855	7164	Economy	29900.00
0005433650829	7164	Economy	29900.00
0005433650819	7164	Economy	29900.00
0005433650808	7164	Economy	29900.00
0005433650817	7164	Economy	29900.00
0005433650846	7164	Economy	29900.00
0005435263637	7164	Economy	29900.00
0005435263638	7164	Economy	29900.00
0005433650830	7164	Economy	29900.00
0005433650833	7164	Economy	29900.00
0005435263659	7164	Economy	29900.00
0005433650859	7164	Economy	29900.00
0005433650845	7164	Economy	29900.00
0005433650848	7164	Economy	29900.00
0005433650858	7164	Economy	29900.00
0005433650840	7164	Economy	29900.00
0005435263654	7164	Economy	29900.00
0005435263645	7164	Economy	29900.00
0005433650852	7164	Economy	29900.00
0005435263672	7164	Economy	29900.00
0005435263677	7164	Economy	29900.00
0005435263669	7164	Economy	29900.00
0005435263670	7164	Economy	29900.00
0005435263655	7164	Economy	29900.00
0005435263622	7164	Economy	29900.00
0005435263617	7164	Economy	29900.00
0005433650837	7164	Economy	29900.00
0005433650841	7164	Economy	29900.00
0005435263644	7164	Economy	29900.00
0005433650806	7164	Economy	29900.00
0005435263661	7164	Economy	29900.00
0005435263643	7164	Economy	29900.00
0005433650857	7164	Economy	29900.00
0005433650802	7164	Economy	29900.00
0005433650849	7164	Economy	29900.00
0005435263631	7164	Economy	29900.00
0005433650835	7164	Economy	29900.00
0005433650836	7164	Economy	29900.00
0005433650864	7164	Economy	29900.00
0005433650813	7164	Economy	29900.00
0005433650810	7164	Economy	29900.00
0005435263667	7164	Economy	29900.00
0005435263646	7164	Economy	29900.00
0005433650824	7164	Economy	29900.00
0005433650823	7164	Economy	29900.00
0005433650809	7164	Economy	29900.00
0005435263625	7164	Economy	29900.00
0005433650822	7164	Economy	29900.00
0005433650842	7164	Economy	29900.00
0005433650827	7164	Economy	29900.00
0005433650828	7164	Economy	29900.00
0005433650825	7164	Economy	29900.00
0005435263653	7164	Economy	29900.00
0005433650811	7164	Economy	29900.00
0005433650862	7164	Economy	29900.00
0005433650847	7164	Economy	29900.00
0005433650834	7164	Economy	29900.00
0005435263626	7164	Economy	29900.00
0005433650816	7164	Economy	29900.00
0005435263666	7164	Economy	29900.00
0005433650804	7164	Economy	29900.00
0005435263619	7164	Economy	29900.00
0005433650718	27630	Business	89800.00
0005435263711	27630	Business	89800.00
0005435263703	27630	Business	89800.00
0005433650585	27630	Business	89800.00
0005433650748	27630	Business	89800.00
0005433650697	27630	Business	89800.00
0005435263710	27630	Business	89800.00
0005433650692	27630	Business	89800.00
0005433650731	27630	Business	89800.00
0005433650580	27630	Economy	29900.00
0005433650702	27630	Economy	29900.00
0005433650747	27630	Economy	29900.00
0005435263708	27630	Economy	29900.00
0005435263720	27630	Economy	29900.00
0005433650648	27630	Economy	32900.00
0005435263700	27630	Economy	32900.00
0005435263723	27630	Economy	32900.00
0005433650708	27630	Economy	32900.00
0005435263722	27630	Economy	29900.00
0005433650698	27630	Economy	29900.00
0005435263702	27630	Economy	29900.00
0005435263719	27630	Economy	29900.00
0005433650640	27630	Economy	29900.00
0005433650662	27630	Economy	29900.00
0005433650665	27630	Economy	29900.00
0005435263701	27630	Economy	29900.00
0005433650680	27630	Economy	29900.00
0005433650646	27630	Economy	29900.00
0005435263714	27630	Economy	29900.00
0005433650645	27630	Economy	29900.00
0005433650750	27630	Economy	29900.00
0005435263715	27630	Economy	29900.00
0005433650644	27630	Economy	29900.00
0005435263713	27630	Economy	29900.00
0005433650798	27630	Economy	29900.00
0005433650669	27630	Economy	29900.00
0005435263718	27630	Economy	29900.00
0005433650595	27630	Economy	29900.00
0005433650653	27630	Economy	29900.00
0005433650657	27630	Economy	29900.00
0005433650635	27630	Economy	29900.00
0005433650751	27630	Economy	29900.00
0005433650631	27630	Economy	29900.00
0005433650746	27630	Economy	29900.00
0005435263706	27630	Economy	29900.00
0005433650618	27630	Economy	29900.00
0005433650632	27630	Economy	29900.00
0005435263721	27630	Economy	29900.00
0005433650707	27630	Economy	29900.00
0005433650647	27630	Economy	29900.00
0005433650766	27630	Economy	29900.00
0005433650633	27630	Economy	29900.00
0005433650579	27630	Economy	29900.00
0005435263698	27630	Economy	29900.00
0005435263712	27630	Economy	29900.00
0005433650729	27630	Economy	29900.00
0005433650699	27630	Economy	29900.00
0005435263717	27630	Economy	29900.00
0005433650717	27630	Economy	29900.00
0005435263716	27630	Economy	29900.00
0005435263705	27630	Economy	29900.00
0005433650673	27630	Economy	29900.00
0005433650681	27630	Economy	29900.00
0005433650730	27630	Economy	29900.00
0005433650654	27630	Economy	29900.00
0005433650639	27630	Economy	29900.00
0005435263709	27630	Economy	29900.00
0005433650712	27630	Economy	29900.00
0005433650736	27630	Economy	29900.00
0005435263704	27630	Economy	29900.00
0005435263707	27630	Economy	29900.00
0005435263699	27630	Economy	29900.00
0005433868977	4807	Economy	19400.00
0005433868981	4807	Economy	19400.00
0005433868972	4807	Economy	19400.00
0005433868983	4807	Economy	19400.00
0005433868970	4807	Economy	17600.00
0005435860499	4807	Economy	17600.00
0005433868975	4807	Economy	17600.00
0005433868979	4807	Economy	17600.00
0005433868958	4807	Economy	17600.00
0005433868980	4807	Economy	17600.00
0005433868964	4807	Economy	17600.00
0005433868992	4807	Economy	17600.00
0005435860498	4807	Economy	17600.00
0005433868987	4807	Economy	17600.00
0005433868985	4807	Economy	17600.00
0005433868960	4807	Economy	17600.00
0005433868989	4807	Economy	17600.00
0005433868965	4807	Economy	17600.00
0005433868990	4807	Economy	17600.00
0005433868973	4807	Economy	17600.00
0005433868957	4807	Economy	17600.00
0005433868978	4807	Economy	17600.00
0005433868966	4807	Economy	17600.00
0005433868963	4807	Economy	17600.00
0005433868968	4807	Economy	17600.00
0005433868995	4807	Economy	17600.00
0005433868962	4807	Economy	17600.00
0005433868994	4807	Economy	17600.00
0005433868956	4807	Economy	17600.00
0005433868993	4807	Economy	17600.00
0005433868961	4807	Economy	17600.00
0005433868969	4807	Economy	17600.00
0005433868984	4807	Economy	17600.00
0005433868986	4807	Economy	17600.00
0005433868967	4807	Economy	17600.00
0005433868971	4807	Economy	17600.00
0005433868988	4807	Economy	17600.00
0005433868974	4807	Economy	17600.00
0005433868976	4807	Economy	17600.00
0005433868982	4807	Economy	17600.00
0005433868959	4807	Economy	17600.00
0005433868991	4807	Economy	17600.00
0005433868595	32592	Economy	19400.00
0005433868556	32592	Economy	19400.00
0005433868516	32592	Economy	19400.00
0005433868511	32592	Economy	19400.00
0005433868543	32592	Economy	17600.00
0005435860520	32592	Economy	17600.00
0005433868720	32592	Economy	17600.00
0005433868578	32592	Economy	17600.00
0005433868432	32592	Economy	17600.00
0005433868399	32592	Economy	17600.00
0005433868525	32592	Economy	17600.00
0005433868555	32592	Economy	17600.00
0005433868441	32592	Economy	17600.00
0005433868537	32592	Economy	17600.00
0005435860524	32592	Economy	17600.00
0005433868575	32592	Economy	17600.00
0005433868582	32592	Economy	17600.00
0005433868642	32592	Economy	17600.00
0005435860522	32592	Economy	17600.00
0005433868641	32592	Economy	17600.00
0005433868636	32592	Economy	17600.00
0005433868658	32592	Economy	17600.00
0005433868524	32592	Economy	17600.00
0005433868693	32592	Economy	17600.00
0005433868721	32592	Economy	17600.00
0005433868515	32592	Economy	17600.00
0005433868596	32592	Economy	17600.00
0005433868651	32592	Economy	17600.00
0005433868554	32592	Economy	17600.00
0005433868654	32592	Economy	17600.00
0005433868722	32592	Economy	17600.00
0005433868574	32592	Economy	17600.00
0005433868706	32592	Economy	17600.00
0005435860521	32592	Economy	17600.00
0005433868612	32592	Economy	17600.00
0005433868542	32592	Economy	17600.00
0005433868536	32592	Economy	17600.00
0005435860523	32592	Economy	17600.00
0005433868366	32592	Economy	17600.00
0005433868611	32592	Economy	17600.00
0005433868650	32592	Economy	17600.00
0005433868637	32592	Economy	17600.00
0005433868365	32592	Economy	17600.00
0005433868613	32592	Economy	17600.00
0005433868615	32592	Economy	17600.00
0005433868408	32592	Economy	17600.00
0005433868659	32592	Economy	17600.00
0005433868728	32592	Economy	17600.00
0005434460536	3451	Economy	24800.00
0005435911484	3451	Economy	24800.00
0005434663596	3451	Economy	22600.00
0005435911487	3451	Economy	22600.00
0005434663590	3451	Economy	22600.00
0005434663584	3451	Economy	22600.00
0005434663588	3451	Economy	22600.00
0005434663594	3451	Economy	22600.00
0005435911491	3451	Economy	22600.00
0005434460535	3451	Economy	22600.00
0005434663587	3451	Economy	22600.00
0005434663595	3451	Economy	22600.00
0005434460533	3451	Economy	22600.00
0005434663583	3451	Economy	22600.00
0005435911488	3451	Economy	22600.00
0005435911490	3451	Economy	22600.00
0005434663593	3451	Economy	22600.00
0005434663591	3451	Economy	22600.00
0005434663589	3451	Economy	22600.00
0005434461676	3451	Economy	22600.00
0005434663586	3451	Economy	22600.00
0005434460534	3451	Economy	22600.00
0005434663585	3451	Economy	22600.00
0005435911513	3451	Economy	22600.00
0005435911442	3451	Economy	22600.00
0005435911514	3451	Economy	22600.00
0005434663597	3451	Economy	22600.00
0005434663592	3451	Economy	22600.00
0005435911512	3451	Economy	22600.00
0005434663508	12466	Economy	24800.00
0005434663509	12466	Economy	24800.00
0005434663435	12466	Economy	24800.00
0005435911553	12466	Economy	24800.00
0005434663472	12466	Economy	22600.00
0005435911554	12466	Economy	22600.00
0005434663464	12466	Economy	22600.00
0005435911557	12466	Economy	22600.00
0005434663463	12466	Economy	22600.00
0005434663471	12466	Economy	22600.00
0005434663436	12466	Economy	22600.00
0005435911556	12466	Economy	22600.00
0005434663454	12466	Economy	22600.00
0005434663513	12466	Economy	22600.00
0005435911555	12466	Economy	22600.00
0005435911552	12466	Economy	22600.00
0005435911551	12466	Economy	22600.00
0005434663453	12466	Economy	22600.00
0005434663470	12466	Economy	22600.00
0005434663406	12466	Economy	22600.00
0005434663459	12466	Economy	22600.00
0005433868399	14507	Economy	18500.00
0005433868578	14507	Economy	18500.00
0005433868516	14507	Economy	18500.00
0005435860523	14507	Economy	18500.00
0005433868555	14507	Economy	16800.00
0005433868654	14507	Economy	16800.00
0005433868612	14507	Economy	16800.00
0005433868637	14507	Economy	16800.00
0005433868641	14507	Economy	16800.00
0005433868721	14507	Economy	16800.00
0005433868515	14507	Economy	16800.00
0005433868554	14507	Economy	16800.00
0005433868636	14507	Economy	16800.00
0005433868575	14507	Economy	16800.00
0005433868441	14507	Economy	16800.00
0005433868650	14507	Economy	16800.00
0005433868611	14507	Economy	16800.00
0005435860522	14507	Economy	16800.00
0005433868524	14507	Economy	16800.00
0005433868693	14507	Economy	16800.00
0005433868659	14507	Economy	16800.00
0005433868615	14507	Economy	16800.00
0005435860521	14507	Economy	16800.00
0005435860520	14507	Economy	16800.00
0005433868642	14507	Economy	16800.00
0005433868595	14507	Economy	16800.00
0005433868556	14507	Economy	16800.00
0005435860524	14507	Economy	16800.00
0005433868542	14507	Economy	16800.00
0005433868432	14507	Economy	16800.00
0005433868525	14507	Economy	16800.00
0005433868658	14507	Economy	16800.00
0005433868408	14507	Economy	16800.00
0005433868706	14507	Economy	16800.00
0005433868543	14507	Economy	16800.00
0005433868536	14507	Economy	16800.00
0005433868596	14507	Economy	16800.00
0005433868728	14507	Economy	16800.00
0005433868613	14507	Economy	16800.00
0005433868574	14507	Economy	16800.00
0005433868720	14507	Economy	16800.00
0005433868511	14507	Economy	16800.00
0005433868365	14507	Economy	16800.00
0005433868366	14507	Economy	16800.00
0005433868722	14507	Economy	16800.00
0005433868651	14507	Economy	16800.00
0005433868582	14507	Economy	16800.00
0005433868537	14507	Economy	16800.00
0005433868940	32652	Economy	18500.00
0005433868927	32652	Economy	18500.00
0005433868955	32652	Economy	18500.00
0005433868954	32652	Economy	18500.00
0005433868928	32652	Economy	16800.00
0005433868947	32652	Economy	16800.00
0005433868920	32652	Economy	16800.00
0005433868921	32652	Economy	16800.00
0005433868925	32652	Economy	16800.00
0005433868943	32652	Economy	16800.00
0005433868932	32652	Economy	16800.00
0005433868918	32652	Economy	16800.00
0005433868939	32652	Economy	16800.00
0005433868919	32652	Economy	16800.00
0005433868922	32652	Economy	16800.00
0005433868941	32652	Economy	16800.00
0005433868944	32652	Economy	16800.00
0005433868923	32652	Economy	16800.00
0005433868938	32652	Economy	16800.00
0005433868951	32652	Economy	16800.00
0005433868930	32652	Economy	16800.00
0005435860497	32652	Economy	16800.00
0005433868934	32652	Economy	16800.00
0005433868924	32652	Economy	16800.00
0005433868949	32652	Economy	16800.00
0005433868937	32652	Economy	16800.00
0005433868946	32652	Economy	16800.00
0005433868945	32652	Economy	16800.00
0005433868952	32652	Economy	16800.00
0005433868931	32652	Economy	16800.00
0005433868948	32652	Economy	16800.00
0005433868950	32652	Economy	16800.00
0005433868917	32652	Economy	16800.00
0005433868933	32652	Economy	16800.00
0005433868942	32652	Economy	16800.00
0005433868929	32652	Economy	16800.00
0005433868935	32652	Economy	16800.00
0005433868936	32652	Economy	16800.00
0005433868926	32652	Economy	16800.00
0005433868953	32652	Economy	16800.00
0005432799523	12105	Economy	4900.00
0005432799700	12105	Economy	4900.00
0005432799545	12105	Economy	4900.00
0005432799556	12105	Economy	4900.00
0005432799619	12105	Economy	4400.00
0005432799345	12105	Economy	4400.00
0005432799699	12105	Economy	4400.00
0005432799560	12105	Economy	4400.00
0005432799396	12105	Economy	4400.00
0005432799589	12105	Economy	4400.00
0005432799623	12105	Economy	4400.00
0005432799620	12105	Economy	4400.00
0005432799469	12105	Economy	4400.00
0005432799544	12105	Economy	4400.00
0005432799621	12105	Economy	4400.00
0005432799346	12105	Economy	4400.00
0005432799557	12105	Economy	4400.00
0005432799561	12105	Economy	4400.00
0005432799533	12105	Economy	4400.00
0005432799559	12105	Economy	4400.00
0005432799530	12105	Economy	4400.00
0005432799652	12105	Economy	4400.00
0005432799612	12105	Economy	4400.00
0005432799592	12105	Economy	4400.00
0005432799605	12105	Economy	4400.00
0005432799548	12105	Economy	4400.00
0005432799611	12105	Economy	4400.00
0005432799618	12105	Economy	4400.00
0005432799591	12105	Economy	4400.00
0005432799675	12105	Economy	4400.00
0005432799813	14815	Economy	4900.00
0005432799819	14815	Economy	4900.00
0005432799796	14815	Economy	4900.00
0005432799802	14815	Economy	4400.00
0005432799807	14815	Economy	4400.00
0005432799805	14815	Economy	4400.00
0005432799798	14815	Economy	4400.00
0005432799814	14815	Economy	4400.00
0005432799794	14815	Economy	4400.00
0005432799816	14815	Economy	4400.00
0005432799792	14815	Economy	4400.00
0005432799820	14815	Economy	4400.00
0005432799795	14815	Economy	4400.00
0005432799797	14815	Economy	4400.00
0005432799799	14815	Economy	4400.00
0005432799818	14815	Economy	4400.00
0005432799815	14815	Economy	4400.00
0005432799809	14815	Economy	4400.00
0005432799806	14815	Economy	4400.00
0005432799800	14815	Economy	4400.00
0005432799810	14815	Economy	4400.00
0005432799821	14815	Economy	4400.00
0005432799804	14815	Economy	4400.00
0005432799817	14815	Economy	4400.00
0005432799811	14815	Economy	4400.00
0005432799812	14815	Economy	4400.00
0005432799808	14815	Economy	4400.00
0005432799793	14815	Economy	4400.00
0005432799801	14815	Economy	4400.00
0005432799803	14815	Economy	4400.00
0005434408599	7037	Business	49100.00
0005435311103	7037	Business	49100.00
0005435293304	7037	Business	49100.00
0005434408602	7037	Business	49100.00
0005435311093	7037	Business	49100.00
0005434408613	7037	Business	49100.00
0005432154035	7037	Business	49100.00
0005435293321	7037	Business	49100.00
0005434299871	7037	Business	49100.00
0005434299876	7037	Business	49100.00
0005434408635	7037	Economy	16400.00
0005434408620	7037	Economy	16400.00
0005434408591	7037	Economy	16400.00
0005434408618	7037	Economy	16400.00
0005435293320	7037	Economy	16400.00
0005432154034	7037	Economy	16400.00
0005434408623	7037	Economy	16400.00
0005435311090	7037	Economy	16400.00
0005434408582	7037	Economy	16400.00
0005435311067	7037	Economy	16400.00
0005434408636	7037	Economy	16400.00
0005435293337	7037	Economy	16400.00
0005432108285	7037	Economy	16400.00
0005434408640	7037	Economy	16400.00
0005434408600	7037	Economy	16400.00
0005434408628	7037	Economy	16400.00
0005435293313	7037	Economy	16400.00
0005434299863	7037	Economy	16400.00
0005434299870	7037	Economy	16400.00
0005434408581	7037	Economy	16400.00
0005434408586	7037	Economy	16400.00
0005432154030	7037	Economy	16400.00
0005434299862	7037	Economy	16400.00
0005434408583	7037	Economy	16400.00
0005434408585	7037	Economy	16400.00
0005434408639	7037	Economy	16400.00
0005435311104	7037	Economy	16400.00
0005434408614	7037	Economy	16400.00
0005434408609	7037	Economy	16400.00
0005434299877	7037	Economy	16400.00
0005434408597	7037	Economy	16400.00
0005434408588	7037	Economy	16400.00
0005434408625	7037	Economy	16400.00
0005432154029	7037	Economy	16400.00
0005434408624	7037	Economy	16400.00
0005434408607	7037	Economy	16400.00
0005434408601	7037	Economy	16400.00
0005434408584	7037	Economy	18000.00
0005435293287	7037	Economy	18000.00
0005434299864	7037	Economy	18000.00
0005434299865	7037	Economy	18000.00
0005435311072	7037	Economy	16400.00
0005435311028	7037	Economy	18000.00
0005432154033	7037	Economy	16400.00
0005434408616	7037	Economy	16400.00
0005434299879	7037	Economy	16400.00
0005434408632	7037	Economy	16400.00
0005434408606	7037	Economy	16400.00
0005434299881	7037	Economy	16400.00
0005434299880	7037	Economy	16400.00
0005435311089	7037	Economy	16400.00
0005434299866	7037	Economy	16400.00
0005435311066	7037	Economy	16400.00
0005434299874	7037	Economy	16400.00
0005434299882	7037	Economy	16400.00
0005434299868	7037	Economy	16400.00
0005434408617	7037	Economy	16400.00
0005434408594	7037	Economy	16400.00
0005434299873	7037	Economy	16400.00
0005434408612	7037	Economy	16400.00
0005434408622	7037	Economy	16400.00
0005434408629	7037	Economy	16400.00
0005434299878	7037	Economy	16400.00
0005434299875	7037	Economy	16400.00
0005434299872	7037	Economy	16400.00
0005434408621	7037	Economy	16400.00
0005435311027	7037	Economy	16400.00
0005434408631	7037	Economy	16400.00
0005435311073	7037	Economy	16400.00
0005434408611	7037	Economy	16400.00
0005434408580	7037	Economy	16400.00
0005432154031	7037	Economy	16400.00
0005434408634	7037	Economy	16400.00
0005434408627	7037	Economy	16400.00
0005435311110	7037	Economy	16400.00
0005432154032	7037	Economy	16400.00
0005434408626	7037	Economy	16400.00
0005434408630	7037	Economy	16400.00
0005434299861	7037	Economy	16400.00
0005434408637	7037	Economy	16400.00
0005434408633	7037	Economy	16400.00
0005434408598	7037	Economy	16400.00
0005434408592	7037	Economy	16400.00
0005434408638	7037	Economy	16400.00
0005434299867	7037	Economy	16400.00
0005435311111	7037	Economy	16400.00
0005432108284	7037	Economy	16400.00
0005434408608	7037	Economy	16400.00
0005434408615	7037	Economy	16400.00
0005434408593	7037	Economy	16400.00
0005434408605	7037	Economy	16400.00
0005434408596	7037	Economy	16400.00
0005434408603	7037	Economy	16400.00
0005434408589	7037	Economy	16400.00
0005434408579	7037	Economy	16400.00
0005434408619	7037	Economy	16400.00
0005434408604	7037	Economy	16400.00
0005435311071	7037	Economy	16400.00
0005434408590	7037	Economy	16400.00
0005434408577	7037	Economy	16400.00
0005434408610	7037	Economy	16400.00
0005435311099	7037	Economy	16400.00
0005434299883	7037	Economy	16400.00
0005434408595	7037	Economy	16400.00
0005434408578	7037	Economy	16400.00
0005434408587	7037	Economy	16400.00
0005434299869	7037	Economy	16400.00
0005435293302	7037	Economy	16400.00
0005435293423	26890	Business	49100.00
0005432058430	26890	Business	49100.00
0005434407786	26890	Business	49100.00
0005435293422	26890	Business	49100.00
0005434299634	26890	Business	49100.00
0005434299727	26890	Business	49100.00
0005434407756	26890	Business	49100.00
0005435311223	26890	Business	49100.00
0005434408185	26890	Business	49100.00
0005434408034	26890	Business	49100.00
0005434299825	26890	Economy	16400.00
0005434407729	26890	Economy	16400.00
0005434407810	26890	Economy	16400.00
0005434407978	26890	Economy	16400.00
0005434299810	26890	Economy	16400.00
0005434299636	26890	Economy	16400.00
0005434408046	26890	Economy	16400.00
0005434299679	26890	Economy	16400.00
0005434408033	26890	Economy	16400.00
0005434407807	26890	Economy	16400.00
0005435293415	26890	Economy	16400.00
0005434407808	26890	Economy	16400.00
0005435293426	26890	Economy	16400.00
0005434299649	26890	Economy	16400.00
0005435293424	26890	Economy	16400.00
0005434408214	26890	Economy	16400.00
0005434299728	26890	Economy	16400.00
0005434407757	26890	Economy	16400.00
0005434299606	26890	Economy	16400.00
0005434407903	26890	Economy	16400.00
0005434408182	26890	Economy	16400.00
0005434408287	26890	Economy	16400.00
0005434299654	26890	Economy	16400.00
0005434408211	26890	Economy	16400.00
0005434299811	26890	Economy	16400.00
0005435311221	26890	Economy	16400.00
0005434408015	26890	Economy	16400.00
0005435311224	26890	Economy	16400.00
0005435293420	26890	Economy	16400.00
0005434299517	26890	Economy	16400.00
0005434407904	26890	Economy	16400.00
0005434299664	26890	Economy	16400.00
0005434408055	26890	Economy	16400.00
0005434407973	26890	Economy	16400.00
0005434408053	26890	Economy	16400.00
0005434407616	26890	Economy	16400.00
0005434407670	26890	Economy	16400.00
0005434407863	26890	Economy	16400.00
0005435293421	26890	Economy	16400.00
0005435293417	26890	Economy	18000.00
0005434408205	26890	Economy	18000.00
0005434299672	26890	Economy	18000.00
0005434408029	26890	Economy	18000.00
0005434408174	26890	Economy	18000.00
0005434299670	26890	Economy	16400.00
0005434407811	26890	Economy	16400.00
0005434408067	26890	Economy	16400.00
0005434408060	26890	Economy	16400.00
0005434407946	26890	Economy	16400.00
0005434408042	26890	Economy	16400.00
0005434407997	26890	Economy	16400.00
0005434299750	26890	Economy	16400.00
0005434299721	26890	Economy	16400.00
0005434407809	26890	Economy	16400.00
0005434299690	26890	Economy	16400.00
0005434408000	26890	Economy	16400.00
0005434407949	26890	Economy	16400.00
0005432058431	26890	Economy	16400.00
0005435293416	26890	Economy	16400.00
0005434299648	26890	Economy	16400.00
0005434408203	26890	Economy	16400.00
0005434299661	26890	Economy	16400.00
0005434299677	26890	Economy	16400.00
0005434408206	26890	Economy	16400.00
0005434408043	26890	Economy	16400.00
0005434408030	26890	Economy	16400.00
0005434299718	26890	Economy	16400.00
0005434299618	26890	Economy	16400.00
0005435311222	26890	Economy	16400.00
0005432058432	26890	Economy	16400.00
0005434408045	26890	Economy	16400.00
0005434407671	26890	Economy	16400.00
0005434407947	26890	Economy	16400.00
0005435311225	26890	Economy	16400.00
0005434407918	26890	Economy	16400.00
0005434299709	26890	Economy	16400.00
0005435293418	26890	Economy	16400.00
0005434299761	26890	Economy	16400.00
0005434299645	26890	Economy	16400.00
0005434299696	26890	Economy	16400.00
0005435293419	26890	Economy	16400.00
0005434407983	26890	Economy	16400.00
0005434407770	26890	Economy	16400.00
0005434408196	26890	Economy	16400.00
0005434299722	26890	Economy	16400.00
0005434407932	26890	Economy	16400.00
0005434408201	26890	Economy	16400.00
0005434407933	26890	Economy	16400.00
0005435311220	26890	Economy	16400.00
0005434407706	26890	Economy	16400.00
0005434407862	26890	Economy	16400.00
0005434408157	26890	Economy	16400.00
0005435293425	26890	Economy	16400.00
0005434299689	26890	Economy	16400.00
0005434407945	26890	Economy	16400.00
0005434299720	26890	Economy	16400.00
0005434408068	26890	Economy	16400.00
0005434299739	26890	Economy	16400.00
0005434407543	26890	Economy	16400.00
0005434407952	26890	Economy	16400.00
0005434299724	26890	Economy	16400.00
0005434408072	26890	Economy	16400.00
0005435293414	26890	Economy	16400.00
0005434408172	26890	Economy	16400.00
0005434407847	26890	Economy	16400.00
0005434408173	26890	Economy	16400.00
0005434408198	26890	Economy	16400.00
0005434407785	26890	Economy	16400.00
0005434408288	26890	Economy	16400.00
0005434408212	26890	Economy	16400.00
0005434299678	26890	Economy	16400.00
0005434408061	26890	Economy	16400.00
0005434408200	26890	Economy	16400.00
0005434407829	26890	Economy	16400.00
0005434299605	26890	Economy	16400.00
0005434408213	26890	Economy	16400.00
0005434512176	6480	Economy	16500.00
0005434512173	6480	Economy	16500.00
0005432604884	6480	Economy	16500.00
0005432604897	6480	Economy	16500.00
0005432604872	6480	Economy	15000.00
0005432604866	6480	Economy	15000.00
0005432604874	6480	Economy	15000.00
0005432604861	6480	Economy	15000.00
0005432604873	6480	Economy	15000.00
0005434512177	6480	Economy	15000.00
0005432604894	6480	Economy	15000.00
0005432604883	6480	Economy	15000.00
0005432604881	6480	Economy	15000.00
0005432604889	6480	Economy	15000.00
0005432604878	6480	Economy	15000.00
0005432604899	6480	Economy	15000.00
0005432604860	6480	Economy	15000.00
0005432604891	6480	Economy	15000.00
0005435218116	6480	Economy	15000.00
0005432604867	6480	Economy	15000.00
0005432604871	6480	Economy	15000.00
0005435218118	6480	Economy	15000.00
0005432604865	6480	Economy	15000.00
0005432604870	6480	Economy	15000.00
0005432604886	6480	Economy	15000.00
0005434512172	6480	Economy	15000.00
0005432604885	6480	Economy	15000.00
0005432604893	6480	Economy	15000.00
0005432604898	6480	Economy	15000.00
0005432604892	6480	Economy	15000.00
0005434512174	6480	Economy	15000.00
0005434512175	6480	Economy	15000.00
0005432604875	6480	Economy	15000.00
0005432604864	6480	Economy	15000.00
0005432604863	6480	Economy	15000.00
0005432604880	6480	Economy	15000.00
0005432604888	6480	Economy	15000.00
0005432604877	6480	Economy	15000.00
0005432604862	6480	Economy	15000.00
0005432604882	6480	Economy	15000.00
0005432604876	6480	Economy	15000.00
0005432604887	6480	Economy	15000.00
0005432604890	6480	Economy	15000.00
0005432604895	6480	Economy	15000.00
0005434512171	6480	Economy	15000.00
0005432604896	6480	Economy	15000.00
0005432604869	6480	Economy	15000.00
0005432604868	6480	Economy	15000.00
0005432604879	6480	Economy	15000.00
0005434512170	6480	Economy	15000.00
0005432604503	21384	Economy	16500.00
0005432604329	21384	Economy	16500.00
0005432604698	21384	Economy	16500.00
0005432604293	21384	Economy	16500.00
0005432604525	21384	Economy	15000.00
0005434512135	21384	Economy	15000.00
0005432604444	21384	Economy	15000.00
0005432604428	21384	Economy	15000.00
0005432604619	21384	Economy	15000.00
0005432604443	21384	Economy	15000.00
0005432604555	21384	Economy	15000.00
0005432604266	21384	Economy	15000.00
0005432604527	21384	Economy	15000.00
0005432604620	21384	Economy	15000.00
0005432604295	21384	Economy	15000.00
0005432604397	21384	Economy	15000.00
0005432604528	21384	Economy	15000.00
0005432604460	21384	Economy	15000.00
0005432604396	21384	Economy	15000.00
0005434512142	21384	Economy	15000.00
0005432604440	21384	Economy	15000.00
0005432604473	21384	Economy	15000.00
0005432604427	21384	Economy	15000.00
0005432604508	21384	Economy	15000.00
0005432604479	21384	Economy	15000.00
0005434512139	21384	Economy	15000.00
0005432604265	21384	Economy	15000.00
0005432604445	21384	Economy	15000.00
0005432604630	21384	Economy	15000.00
0005432604294	21384	Economy	15000.00
0005432604570	21384	Economy	15000.00
0005432604403	21384	Economy	15000.00
0005432604557	21384	Economy	15000.00
0005432604504	21384	Economy	15000.00
0005432604357	21384	Economy	15000.00
0005432604550	21384	Economy	15000.00
0005432604613	21384	Economy	15000.00
0005434512138	21384	Economy	15000.00
0005432604621	21384	Economy	15000.00
0005432604535	21384	Economy	15000.00
0005432604356	21384	Economy	15000.00
0005432604561	21384	Economy	15000.00
0005434512141	21384	Economy	15000.00
0005432604414	21384	Economy	15000.00
0005432604554	21384	Economy	15000.00
0005432604524	21384	Economy	15000.00
0005434512150	21384	Economy	15000.00
0005432604495	21384	Economy	15000.00
0005432604560	21384	Economy	15000.00
0005434512146	21384	Economy	15000.00
0005433251895	14999	Business	18900.00
0005433251882	14999	Business	18900.00
0005434907504	14999	Business	18900.00
0005434907505	14999	Business	18900.00
0005433251888	14999	Business	18900.00
0005434907517	14999	Business	18900.00
0005434907459	14999	Business	18900.00
0005433251885	14999	Business	18900.00
0005434907472	14999	Business	18900.00
0005434907521	14999	Business	18900.00
0005434907469	14999	Economy	6300.00
0005434907450	14999	Economy	6300.00
0005434907432	14999	Economy	6300.00
0005434907460	14999	Economy	6300.00
0005434907627	14999	Economy	6300.00
0005434907537	14999	Economy	6300.00
0005434907393	14999	Economy	6300.00
0005434907419	14999	Economy	6300.00
0005434907650	14999	Economy	6300.00
0005433251891	14999	Economy	6900.00
0005433251879	14999	Economy	6900.00
0005433251877	14999	Economy	6900.00
0005434907420	14999	Economy	6900.00
0005434907443	14999	Economy	6900.00
0005434907364	14999	Economy	6300.00
0005433251897	14999	Economy	6300.00
0005434907348	14999	Economy	6300.00
0005434907463	14999	Economy	6300.00
0005433251906	14999	Economy	6300.00
0005433251890	14999	Economy	6300.00
0005434907634	14999	Economy	6300.00
0005434907356	14999	Economy	6300.00
0005434907635	14999	Economy	6300.00
0005434907528	14999	Economy	6300.00
0005433251883	14999	Economy	6300.00
0005434907284	14999	Economy	6300.00
0005434907398	14999	Economy	6300.00
0005434907513	14999	Economy	6300.00
0005434907451	14999	Economy	6300.00
0005434907197	14999	Economy	6300.00
0005433251898	14999	Economy	6300.00
0005433251886	14999	Economy	6300.00
0005434907506	14999	Economy	6300.00
0005433251881	14999	Economy	6300.00
0005434907503	14999	Economy	6300.00
0005434907421	14999	Economy	6300.00
0005434907167	14999	Economy	6300.00
0005434907166	14999	Economy	6300.00
0005433251887	14999	Economy	6300.00
0005434907474	14999	Economy	6300.00
0005434907555	14999	Economy	6300.00
0005433251900	14999	Economy	6300.00
0005434907400	14999	Economy	6300.00
0005434907562	14999	Economy	6300.00
0005434907358	14999	Economy	6300.00
0005434907527	14999	Economy	6300.00
0005434907531	14999	Economy	6300.00
0005433251892	14999	Economy	6300.00
0005434907630	14999	Economy	6300.00
0005433251903	14999	Economy	6300.00
0005433251904	14999	Economy	6300.00
0005433251899	14999	Economy	6300.00
0005433251901	14999	Economy	6300.00
0005434907640	14999	Economy	6300.00
0005434907639	14999	Economy	6300.00
0005433251884	14999	Economy	6300.00
0005434907473	14999	Economy	6300.00
0005433251905	14999	Economy	6300.00
0005433251894	14999	Economy	6300.00
0005433251902	14999	Economy	6300.00
0005433251896	14999	Economy	6300.00
0005434907431	14999	Economy	6300.00
0005433251893	14999	Economy	6300.00
0005433251876	14999	Economy	6300.00
0005434907493	14999	Economy	6300.00
0005434907516	14999	Economy	6300.00
0005434907629	14999	Economy	6300.00
0005434907536	14999	Economy	6300.00
0005434907399	14999	Economy	6300.00
0005434907462	14999	Economy	6300.00
0005434907512	14999	Economy	6300.00
0005433251878	14999	Economy	6300.00
0005434907641	14999	Economy	6300.00
0005434907530	14999	Economy	6300.00
0005434907430	14999	Economy	6300.00
0005433251880	14999	Economy	6300.00
0005433251889	14999	Economy	6300.00
0005433251717	25872	Business	18900.00
0005434907943	25872	Business	18900.00
0005434907947	25872	Business	18900.00
0005434907960	25872	Business	18900.00
0005434907912	25872	Business	18900.00
0005434907959	25872	Business	18900.00
0005434907930	25872	Business	18900.00
0005434907908	25872	Business	18900.00
0005434907925	25872	Business	18900.00
0005433251582	25872	Business	18900.00
0005434907918	25872	Business	18900.00
0005433251517	25872	Business	18900.00
0005433251531	25872	Economy	6300.00
0005434907939	25872	Economy	6300.00
0005433251622	25872	Economy	6300.00
0005434907928	25872	Economy	6300.00
0005434907955	25872	Economy	6300.00
0005434907954	25872	Economy	6300.00
0005433251641	25872	Economy	6300.00
0005434907917	25872	Economy	6300.00
0005434907948	25872	Economy	6300.00
0005434907915	25872	Economy	6300.00
0005434907906	25872	Economy	6900.00
0005434907935	25872	Economy	6900.00
0005434907926	25872	Economy	6900.00
0005434907953	25872	Economy	6900.00
0005434907916	25872	Economy	6900.00
0005433251657	25872	Economy	6300.00
0005434907956	25872	Economy	6300.00
0005434907945	25872	Economy	6300.00
0005433251639	25872	Economy	6300.00
0005434907911	25872	Economy	6300.00
0005434907937	25872	Economy	6300.00
0005433251573	25872	Economy	6300.00
0005434907923	25872	Economy	6300.00
0005433251665	25872	Economy	6300.00
0005434907958	25872	Economy	6300.00
0005434907905	25872	Economy	6300.00
0005433251659	25872	Economy	6300.00
0005434907931	25872	Economy	6300.00
0005433251814	25872	Economy	6300.00
0005434907920	25872	Economy	6300.00
0005434907904	25872	Economy	6300.00
0005433251574	25872	Economy	6300.00
0005434907949	25872	Economy	6300.00
0005433251658	25872	Economy	6300.00
0005433251557	25872	Economy	6300.00
0005434907909	25872	Economy	6300.00
0005434907936	25872	Economy	6300.00
0005433251716	25872	Economy	6300.00
0005434907938	25872	Economy	6300.00
0005434907942	25872	Economy	6300.00
0005434907951	25872	Economy	6300.00
0005433251619	25872	Economy	6300.00
0005433251730	25872	Economy	6300.00
0005434907913	25872	Economy	6300.00
0005434907932	25872	Economy	6300.00
0005433251570	25872	Economy	6300.00
0005434907941	25872	Economy	6300.00
0005434907914	25872	Economy	6300.00
0005433251634	25872	Economy	6300.00
0005433251603	25872	Economy	6300.00
0005433251633	25872	Economy	6300.00
0005434907922	25872	Economy	6300.00
0005434907950	25872	Economy	6300.00
0005433251656	25872	Economy	6300.00
0005434907957	25872	Economy	6300.00
0005433251550	25872	Economy	6300.00
0005433251513	25872	Economy	6300.00
0005433251503	25872	Economy	6300.00
0005434907910	25872	Economy	6300.00
0005433251666	25872	Economy	6300.00
0005434907952	25872	Economy	6300.00
0005433251640	25872	Economy	6300.00
0005434907944	25872	Economy	6300.00
0005433251559	25872	Economy	6300.00
0005434907924	25872	Economy	6300.00
0005433251623	25872	Economy	6300.00
0005433251558	25872	Economy	6300.00
0005434907919	25872	Economy	6300.00
0005434907907	25872	Economy	6300.00
0005433251551	25872	Economy	6300.00
0005434907929	25872	Economy	6300.00
0005433251681	25872	Economy	6300.00
0005434907927	25872	Economy	6300.00
0005433251680	25872	Economy	6300.00
0005434907940	25872	Economy	6300.00
0005434907934	25872	Economy	6300.00
0005434907933	25872	Economy	6300.00
0005433251563	25872	Economy	6300.00
0005433251569	25872	Economy	6300.00
0005434907946	25872	Economy	6300.00
0005433251632	25872	Economy	6300.00
0005434907921	25872	Economy	6300.00
0005433810552	14150	Business	52300.00
0005433810538	14150	Business	52300.00
0005433009222	14150	Business	52300.00
0005433810551	14150	Business	52300.00
0005433009233	14150	Business	52300.00
0005433009240	14150	Business	52300.00
0005433009235	14150	Economy	17400.00
0005433009231	14150	Economy	17400.00
0005433009245	14150	Economy	17400.00
0005433009256	14150	Economy	17400.00
0005433009258	14150	Economy	17400.00
0005433009230	14150	Economy	19200.00
0005433009244	14150	Economy	19200.00
0005433810558	14150	Economy	19200.00
0005433009247	14150	Economy	19200.00
0005433009218	14150	Economy	17400.00
0005433009237	14150	Economy	17400.00
0005433009241	14150	Economy	17400.00
0005433009220	14150	Economy	17400.00
0005433009238	14150	Economy	17400.00
0005433009225	14150	Economy	17400.00
0005433009248	14150	Economy	17400.00
0005433009254	14150	Economy	17400.00
0005433009239	14150	Economy	17400.00
0005433009216	14150	Economy	17400.00
0005433009223	14150	Economy	17400.00
0005433009242	14150	Economy	17400.00
0005433009224	14150	Economy	17400.00
0005433810539	14150	Economy	17400.00
0005433009243	14150	Economy	17400.00
0005433009246	14150	Economy	17400.00
0005433009228	14150	Economy	17400.00
0005433009255	14150	Economy	17400.00
0005433009257	14150	Economy	17400.00
0005433009234	14150	Economy	17400.00
0005433009250	14150	Economy	17400.00
0005433009221	14150	Economy	17400.00
0005433009219	14150	Economy	17400.00
0005433810557	14150	Economy	17400.00
0005433009226	14150	Economy	17400.00
0005433009215	14150	Economy	17400.00
0005433009252	14150	Economy	17400.00
0005433810540	14150	Economy	17400.00
0005433009251	14150	Economy	17400.00
0005433009217	14150	Economy	17400.00
0005433009259	14150	Economy	17400.00
0005433810555	14150	Economy	17400.00
0005433009253	14150	Economy	17400.00
0005433810559	14150	Economy	17400.00
0005433009232	14150	Economy	17400.00
0005433009249	14150	Economy	17400.00
0005433009236	14150	Economy	17400.00
0005433009229	14150	Economy	17400.00
0005433810565	14150	Economy	17400.00
0005433009227	14150	Economy	17400.00
0005433008756	22817	Business	52300.00
0005433008696	22817	Business	52300.00
0005433008777	22817	Business	52300.00
0005433008771	22817	Business	52300.00
0005433008754	22817	Economy	17400.00
0005433008966	22817	Economy	17400.00
0005433008744	22817	Economy	19200.00
0005433008568	22817	Economy	19200.00
0005433008904	22817	Economy	19200.00
0005433008930	22817	Economy	17400.00
0005433008902	22817	Economy	17400.00
0005433008711	22817	Economy	17400.00
0005433008668	22817	Economy	17400.00
0005433008874	22817	Economy	17400.00
0005433008667	22817	Economy	17400.00
0005433008779	22817	Economy	17400.00
0005433008959	22817	Economy	17400.00
0005433008850	22817	Economy	17400.00
0005433009025	22817	Economy	17400.00
0005433008851	22817	Economy	17400.00
0005433008731	22817	Economy	17400.00
0005433008706	22817	Economy	17400.00
0005433008928	22817	Economy	17400.00
0005433008709	22817	Economy	17400.00
0005433008712	22817	Economy	17400.00
0005433008689	22817	Economy	17400.00
0005433008872	22817	Economy	17400.00
0005433008726	22817	Economy	17400.00
0005433008755	22817	Economy	17400.00
0005433009043	22817	Economy	17400.00
0005433008913	22817	Economy	17400.00
0005433008821	22817	Economy	17400.00
0005433008715	22817	Economy	17400.00
0005433008571	22817	Economy	17400.00
0005433008820	22817	Economy	17400.00
0005433008569	22817	Economy	17400.00
0005433008730	22817	Economy	17400.00
0005433008958	22817	Economy	17400.00
0005433008778	22817	Economy	17400.00
0005433008784	22817	Economy	17400.00
0005433008945	22817	Economy	17400.00
0005433008533	22817	Economy	17400.00
0005433008581	22817	Economy	17400.00
0005435718885	27123	Business	85200.00
0005435718939	27123	Business	85200.00
0005435718895	27123	Business	85200.00
0005435718949	27123	Business	85200.00
0005435718935	27123	Economy	28400.00
0005435718938	27123	Economy	28400.00
0005435718933	27123	Economy	31200.00
0005435718951	27123	Economy	31200.00
0005435718936	27123	Economy	28400.00
0005435718945	27123	Economy	28400.00
0005435718930	27123	Economy	28400.00
0005435718920	27123	Economy	28400.00
0005435718894	27123	Economy	28400.00
0005435718888	27123	Economy	28400.00
0005435718953	27123	Economy	28400.00
0005435718955	27123	Economy	28400.00
0005435718886	27123	Economy	28400.00
0005435718950	27123	Economy	28400.00
0005435718977	27123	Economy	28400.00
0005435718959	27123	Economy	28400.00
0005435718961	27123	Economy	28400.00
0005435718965	27123	Economy	28400.00
0005435718976	27123	Economy	28400.00
0005435718960	27123	Economy	28400.00
0005435718928	27123	Economy	28400.00
0005435718907	27123	Economy	28400.00
0005435718952	27123	Economy	28400.00
0005435718964	27123	Economy	28400.00
0005435718937	27123	Economy	28400.00
0005435718898	27123	Economy	28400.00
0005435718934	27123	Economy	28400.00
0005435718925	27123	Economy	28400.00
0005435718946	27123	Economy	28400.00
0005435718906	27123	Economy	28400.00
0005435718966	27123	Economy	28400.00
0005435718932	27123	Economy	28400.00
0005434925842	14947	Business	22900.00
0005434925925	14947	Business	22900.00
0005434925956	14947	Business	22900.00
0005434925914	14947	Economy	7600.00
0005434925935	14947	Economy	7600.00
0005434925870	14947	Economy	7600.00
0005434925952	14947	Economy	7600.00
0005434925841	14947	Economy	7600.00
0005434925844	14947	Economy	8400.00
0005434925938	14947	Economy	8400.00
0005434925927	14947	Economy	8400.00
0005434925884	14947	Economy	7600.00
0005434925876	14947	Economy	7600.00
0005434925957	14947	Economy	7600.00
0005434925843	14947	Economy	7600.00
0005434925877	14947	Economy	7600.00
0005434925840	14947	Economy	7600.00
0005434925875	14947	Economy	7600.00
0005434925869	14947	Economy	7600.00
0005434925917	14947	Economy	7600.00
0005434925881	14947	Economy	7600.00
0005434925954	14947	Economy	7600.00
0005434925950	14947	Economy	7600.00
0005434925868	14947	Economy	7600.00
0005434925953	14947	Economy	7600.00
0005434925955	14947	Economy	7600.00
0005434925934	14947	Economy	7600.00
0005434925911	14947	Economy	7600.00
0005434925929	14947	Economy	7600.00
0005434925880	14947	Economy	7600.00
0005434925928	14947	Economy	7600.00
0005434925926	14947	Economy	7600.00
0005434925937	14947	Economy	7600.00
0005434925861	14947	Economy	7600.00
0005434925795	14947	Economy	7600.00
0005434926190	20499	Business	22900.00
0005434926189	20499	Business	22900.00
0005434926197	20499	Business	22900.00
0005434926191	20499	Business	22900.00
0005434926201	20499	Economy	7600.00
0005434926215	20499	Economy	7600.00
0005434926204	20499	Economy	7600.00
0005434926207	20499	Economy	7600.00
0005434926195	20499	Economy	7600.00
0005434926216	20499	Economy	7600.00
0005434926219	20499	Economy	7600.00
0005434926193	20499	Economy	8400.00
0005434926203	20499	Economy	8400.00
0005434926198	20499	Economy	8400.00
0005434926194	20499	Economy	7600.00
0005434926210	20499	Economy	7600.00
0005434926218	20499	Economy	7600.00
0005434926213	20499	Economy	7600.00
0005434926199	20499	Economy	7600.00
0005434926192	20499	Economy	7600.00
0005434926220	20499	Economy	7600.00
0005434926211	20499	Economy	7600.00
0005434926200	20499	Economy	7600.00
0005434926212	20499	Economy	7600.00
0005434926205	20499	Economy	7600.00
0005434926206	20499	Economy	7600.00
0005434926221	20499	Economy	7600.00
0005434926196	20499	Economy	7600.00
0005434926209	20499	Economy	7600.00
0005434926188	20499	Economy	7600.00
0005434926214	20499	Economy	7600.00
0005434926208	20499	Economy	7600.00
0005434926217	20499	Economy	7600.00
0005434926202	20499	Economy	7600.00
0005435488127	15846	Economy	8900.00
0005435488138	15846	Economy	8900.00
0005435488134	15846	Economy	8900.00
0005435999324	15846	Economy	8100.00
0005435488133	15846	Economy	8100.00
0005435999351	15846	Economy	8100.00
0005435999326	15846	Economy	8100.00
0005435999346	15846	Economy	8100.00
0005435999327	15846	Economy	8100.00
0005435488124	15846	Economy	8100.00
0005435488126	15846	Economy	8100.00
0005435488130	15846	Economy	8100.00
0005435999341	15846	Economy	8100.00
0005435999334	15846	Economy	8100.00
0005435488131	15846	Economy	8100.00
0005435488139	15846	Economy	8100.00
0005435488135	15846	Economy	8100.00
0005435488128	15846	Economy	8100.00
0005435488137	15846	Economy	8100.00
0005435999228	15846	Economy	8100.00
0005435999352	15846	Economy	8100.00
0005435488123	15846	Economy	8100.00
0005435488122	15846	Economy	8100.00
0005435488132	15846	Economy	8100.00
0005435999376	15846	Economy	8100.00
0005435999336	15846	Economy	8100.00
0005435488136	15846	Economy	8100.00
0005435488125	15846	Economy	8100.00
0005435999332	15846	Economy	8100.00
0005435488119	15846	Economy	8100.00
0005435488129	15846	Economy	8100.00
0005435488121	15846	Economy	8100.00
0005435999377	15846	Economy	8100.00
0005435488120	15846	Economy	8100.00
0005435999371	15846	Economy	8100.00
0005435999375	15846	Economy	8100.00
0005435999323	15846	Economy	8100.00
0005435999229	15846	Economy	8100.00
0005435999333	15846	Economy	8100.00
0005435999353	15846	Economy	8100.00
0005435999471	19714	Economy	8900.00
0005435487948	19714	Economy	8900.00
0005435999475	19714	Economy	8900.00
0005435487928	19714	Economy	8100.00
0005435487927	19714	Economy	8100.00
0005435999472	19714	Economy	8100.00
0005435487809	19714	Economy	8100.00
0005435487905	19714	Economy	8100.00
0005435999463	19714	Economy	8100.00
0005435487902	19714	Economy	8100.00
0005435487801	19714	Economy	8100.00
0005435487866	19714	Economy	8100.00
0005435487846	19714	Economy	8100.00
0005435999460	19714	Economy	8100.00
0005435487884	19714	Economy	8100.00
0005435487810	19714	Economy	8100.00
0005435487841	19714	Economy	8100.00
0005435999459	19714	Economy	8100.00
0005435999467	19714	Economy	8100.00
0005435487931	19714	Economy	8100.00
0005435487808	19714	Economy	8100.00
0005435487901	19714	Economy	8100.00
0005435999466	19714	Economy	8100.00
0005435999458	19714	Economy	8100.00
0005435999461	19714	Economy	8100.00
0005435999468	19714	Economy	8100.00
0005435487938	19714	Economy	8100.00
0005435999473	19714	Economy	8100.00
0005435999465	19714	Economy	8100.00
0005435999470	19714	Economy	8100.00
0005435487982	19714	Economy	8100.00
0005435999457	19714	Economy	8100.00
0005435999462	19714	Economy	8100.00
0005435999464	19714	Economy	8100.00
0005435999469	19714	Economy	8100.00
0005435487848	19714	Economy	8100.00
0005435487840	19714	Economy	8100.00
0005435487947	19714	Economy	8100.00
0005435487871	19714	Economy	8100.00
0005435487929	19714	Economy	8100.00
0005435487912	19714	Economy	8100.00
0005435999474	19714	Economy	8100.00
0005435487932	19714	Economy	8100.00
0005432537068	6010	Business	199300.00
0005435839843	6010	Business	199300.00
0005435839828	6010	Business	199300.00
0005435472935	6010	Business	199300.00
0005435472920	6010	Business	199300.00
0005435839841	6010	Business	199300.00
0005435839837	6010	Business	199300.00
0005435472934	6010	Business	199300.00
0005435839838	6010	Business	199300.00
0005435472830	6010	Business	199300.00
0005435839830	6010	Business	199300.00
0005435839826	6010	Economy	66400.00
0005435839829	6010	Economy	66400.00
0005435839823	6010	Economy	66400.00
0005435839846	6010	Economy	66400.00
0005435839831	6010	Economy	66400.00
0005435472827	6010	Economy	66400.00
0005435839845	6010	Economy	66400.00
0005435472826	6010	Economy	66400.00
0005435472872	6010	Economy	73100.00
0005435839836	6010	Economy	73100.00
0005435839833	6010	Economy	73100.00
0005435472864	6010	Economy	66400.00
0005432142293	6010	Economy	66400.00
0005435839848	6010	Economy	66400.00
0005432660846	6010	Economy	66400.00
0005432142295	6010	Economy	66400.00
0005435472869	6010	Economy	66400.00
0005435839825	6010	Economy	66400.00
0005432142294	6010	Economy	66400.00
0005432660847	6010	Economy	66400.00
0005435839840	6010	Economy	66400.00
0005435839822	6010	Economy	66400.00
0005435839850	6010	Economy	66400.00
0005435839834	6010	Economy	66400.00
0005435839839	6010	Economy	66400.00
0005435839835	6010	Economy	66400.00
0005435472873	6010	Economy	66400.00
0005435839821	6010	Economy	66400.00
0005435472879	6010	Economy	66400.00
0005432659735	6010	Economy	66400.00
0005435839849	6010	Economy	66400.00
0005432660848	6010	Economy	66400.00
0005435472898	6010	Economy	66400.00
0005435839842	6010	Economy	66400.00
0005435472946	6010	Economy	66400.00
0005435472928	6010	Economy	66400.00
0005435839844	6010	Economy	66400.00
0005435472828	6010	Economy	66400.00
0005432659736	6010	Economy	66400.00
0005432658621	6010	Economy	66400.00
0005435839827	6010	Economy	66400.00
0005435839847	6010	Economy	66400.00
0005435472868	6010	Economy	66400.00
0005432658620	6010	Economy	66400.00
0005435839824	6010	Economy	66400.00
0005435839832	6010	Economy	66400.00
0005435472924	6010	Economy	66400.00
0005435839630	18083	Business	199300.00
0005435839576	18083	Business	199300.00
0005435473018	18083	Business	199300.00
0005435473031	18083	Business	199300.00
0005435839658	18083	Business	199300.00
0005435839647	18083	Business	199300.00
0005435839705	18083	Economy	66400.00
0005435473028	18083	Economy	66400.00
0005432667459	18083	Economy	66400.00
0005435839558	18083	Economy	73100.00
0005435839584	18083	Economy	73100.00
0005435839514	18083	Economy	66400.00
0005435839628	18083	Economy	66400.00
0005435839702	18083	Economy	66400.00
0005435473034	18083	Economy	66400.00
0005435839618	18083	Economy	66400.00
0005435473027	18083	Economy	66400.00
0005435617236	18083	Economy	66400.00
0005435839629	18083	Economy	66400.00
0005435839511	18083	Economy	66400.00
0005435473030	18083	Economy	66400.00
0005432660828	18083	Economy	66400.00
0005435473019	18083	Economy	66400.00
0005435473020	18083	Economy	66400.00
0005435839657	18083	Economy	66400.00
0005435839617	18083	Economy	66400.00
0005435839583	18083	Economy	66400.00
0005435839663	18083	Economy	66400.00
0005435839534	18083	Economy	66400.00
0005435473023	18083	Economy	66400.00
0005435473024	18083	Economy	66400.00
0005435839610	18083	Economy	66400.00
0005432537087	18083	Economy	66400.00
0005435839486	18083	Economy	66400.00
0005435839594	18083	Economy	66400.00
0005435839703	18083	Economy	66400.00
0005435473025	18083	Economy	66400.00
0005435473026	18083	Economy	66400.00
0005435473033	18083	Economy	66400.00
0005435617237	18083	Economy	66400.00
0005432537088	18083	Economy	66400.00
0005435473021	18083	Economy	66400.00
0005435473029	18083	Economy	66400.00
0005432664135	18083	Economy	66400.00
0005435839512	18083	Economy	66400.00
0005435839611	18083	Economy	66400.00
0005435473032	18083	Economy	66400.00
0005435839598	18083	Economy	66400.00
0005432664140	18083	Economy	66400.00
0005435473022	18083	Economy	66400.00
0005432660824	18083	Economy	66400.00
0005433460427	19910	Business	146400.00
0005433460438	19910	Business	146400.00
0005433460440	19910	Business	146400.00
0005433460413	19910	Economy	48800.00
0005433462735	19910	Economy	48800.00
0005433462751	19910	Economy	48800.00
0005433460444	19910	Economy	48800.00
0005433460441	19910	Economy	48800.00
0005433462734	19910	Economy	48800.00
0005433462749	19910	Economy	48800.00
0005433462744	19910	Economy	48800.00
0005433460442	19910	Economy	48800.00
0005433460432	19910	Economy	48800.00
0005433462743	19910	Economy	48800.00
0005433462742	19910	Economy	48800.00
0005433460430	19910	Economy	48800.00
0005433460426	19910	Economy	48800.00
0005433462750	19910	Economy	48800.00
0005433460443	19910	Economy	48800.00
0005433462748	19910	Economy	48800.00
0005433460429	19910	Economy	53700.00
0005433460428	19910	Economy	48800.00
0005433462747	19910	Economy	48800.00
0005433460414	19910	Economy	48800.00
0005433462727	19910	Economy	48800.00
0005433460439	19910	Economy	48800.00
0005433460437	19910	Economy	48800.00
0005433462726	19910	Economy	48800.00
0005433460431	19910	Economy	48800.00
0005433460419	19910	Economy	48800.00
0005433285475	23057	Business	15700.00
0005435104019	23057	Business	15700.00
0005433285570	23057	Business	15700.00
0005433285396	23057	Business	15700.00
0005433285453	23057	Economy	5200.00
0005435104029	23057	Economy	5200.00
0005433285458	23057	Economy	5200.00
0005433285476	23057	Economy	5200.00
0005435104027	23057	Economy	5200.00
0005433285460	23057	Economy	5200.00
0005435104026	23057	Economy	5200.00
0005433285431	23057	Economy	5200.00
0005433285228	23057	Economy	5200.00
0005433285569	23057	Economy	5200.00
0005433285539	23057	Economy	5200.00
0005435104024	23057	Economy	5200.00
0005433285472	23057	Economy	5700.00
0005433285518	23057	Economy	5700.00
0005433285272	23057	Economy	5200.00
0005433285409	23057	Economy	5200.00
0005433285308	23057	Economy	5200.00
0005435104023	23057	Economy	5200.00
0005435104021	23057	Economy	5200.00
0005433285367	23057	Economy	5200.00
0005433285607	23057	Economy	5200.00
0005435104018	23057	Economy	5200.00
0005433285542	23057	Economy	5200.00
0005435104022	23057	Economy	5200.00
0005435104017	23057	Economy	5200.00
0005435104025	23057	Economy	5200.00
0005435104028	23057	Economy	5200.00
0005433285397	23057	Economy	5200.00
0005435104020	23057	Economy	5200.00
0005433285451	23057	Economy	5200.00
0005433285484	23057	Economy	5200.00
0005433285540	23057	Economy	5200.00
0005433285229	23057	Economy	5200.00
0005433285483	23057	Economy	5200.00
0005433285730	32083	Business	15700.00
0005433285733	32083	Economy	5200.00
0005433285729	32083	Economy	5200.00
0005435103936	32083	Economy	5200.00
0005433285728	32083	Economy	5200.00
0005435103953	32083	Economy	5200.00
0005433285734	32083	Economy	5200.00
0005435103915	32083	Economy	5200.00
0005433285711	32083	Economy	5200.00
0005433285722	32083	Economy	5200.00
0005433285720	32083	Economy	5200.00
0005433285739	32083	Economy	5200.00
0005433285738	32083	Economy	5200.00
0005433285731	32083	Economy	5200.00
0005433285727	32083	Economy	5200.00
0005433285737	32083	Economy	5700.00
0005433285709	32083	Economy	5200.00
0005433285715	32083	Economy	5200.00
0005433285714	32083	Economy	5200.00
0005433285718	32083	Economy	5200.00
0005433285726	32083	Economy	5200.00
0005433285725	32083	Economy	5200.00
0005433285724	32083	Economy	5200.00
0005435103932	32083	Economy	5200.00
0005433285716	32083	Economy	5200.00
0005433285712	32083	Economy	5200.00
0005433285717	32083	Economy	5200.00
0005433285736	32083	Economy	5200.00
0005433285713	32083	Economy	5200.00
0005433285735	32083	Economy	5200.00
0005433285719	32083	Economy	5200.00
0005433285721	32083	Economy	5200.00
0005433285723	32083	Economy	5200.00
0005433285732	32083	Economy	5200.00
0005433285708	32083	Economy	5200.00
0005433285710	32083	Economy	5200.00
0005432802493	19945	Business	150400.00
0005434302866	19945	Business	150400.00
0005434302868	19945	Business	150400.00
0005432802486	19945	Business	150400.00
0005432892787	19945	Business	150400.00
0005432802502	19945	Business	150400.00
0005432802492	19945	Business	150400.00
0005434302854	19945	Business	150400.00
0005434302864	19945	Business	150400.00
0005434302865	19945	Business	150400.00
0005432802483	19945	Business	150400.00
0005434302858	19945	Business	150400.00
0005432892782	19945	Business	150400.00
0005432892778	19945	Business	150400.00
0005432892788	19945	Economy	50100.00
0005433112388	19945	Economy	50100.00
0005432802498	19945	Economy	50100.00
0005432802515	19945	Economy	50100.00
0005433111525	19945	Economy	50100.00
0005433111523	19945	Economy	50100.00
0005434302860	19945	Economy	50100.00
0005432892783	19945	Economy	55200.00
0005432802526	19945	Economy	55200.00
0005432802485	19945	Economy	55200.00
0005432802527	19945	Economy	55200.00
0005432802475	19945	Economy	50100.00
0005433112387	19945	Economy	50100.00
0005434302870	19945	Economy	50100.00
0005432892777	19945	Economy	50100.00
0005433111526	19945	Economy	50100.00
0005433112384	19945	Economy	50100.00
0005433111520	19945	Economy	50100.00
0005433112391	19945	Economy	50100.00
0005434302862	19945	Economy	50100.00
0005432802517	19945	Economy	50100.00
0005433112385	19945	Economy	50100.00
0005432802496	19945	Economy	50100.00
0005433112392	19945	Economy	50100.00
0005433112390	19945	Economy	50100.00
0005432892790	19945	Economy	50100.00
0005432892780	19945	Economy	50100.00
0005432892785	19945	Economy	50100.00
0005432802495	19945	Economy	50100.00
0005432892784	19945	Economy	50100.00
0005433111522	19945	Economy	50100.00
0005434302857	19945	Economy	50100.00
0005432802516	19945	Economy	50100.00
0005432802525	19945	Economy	50100.00
0005432892776	19945	Economy	50100.00
0005432892786	19945	Economy	50100.00
0005434302863	19945	Economy	50100.00
0005434302861	19945	Economy	50100.00
0005432802514	19945	Economy	50100.00
0005432802528	19945	Economy	50100.00
0005432802529	19945	Economy	50100.00
0005434302872	19945	Economy	50100.00
0005434302859	19945	Economy	50100.00
0005432802522	19945	Economy	50100.00
0005433111530	19945	Economy	50100.00
0005432802521	19945	Economy	50100.00
0005434302867	19945	Economy	50100.00
0005432802518	19945	Economy	50100.00
0005433112389	19945	Economy	50100.00
0005432892792	19945	Economy	50100.00
0005433112386	19945	Economy	50100.00
0005433111533	19945	Economy	50100.00
0005432892789	19945	Economy	50100.00
0005432802530	19945	Economy	50100.00
0005432892781	19945	Economy	50100.00
0005433111521	19945	Economy	50100.00
0005432802491	19945	Economy	50100.00
0005433111524	19945	Economy	50100.00
0005434302856	19945	Economy	50100.00
0005432802477	19945	Economy	50100.00
0005432892779	19945	Economy	50100.00
0005433111531	19945	Economy	50100.00
0005432802484	19945	Economy	50100.00
0005433111527	19945	Economy	50100.00
0005433111529	19945	Economy	50100.00
0005432802478	19945	Economy	50100.00
0005433111534	19945	Economy	50100.00
0005433111532	19945	Economy	50100.00
0005433111528	19945	Economy	50100.00
0005434302869	19945	Economy	50100.00
0005434302855	19945	Economy	50100.00
0005434302871	19945	Economy	50100.00
0005432892791	19945	Economy	50100.00
0005432802482	19945	Economy	50100.00
0005432802476	19945	Economy	50100.00
0005434068060	30617	Business	42100.00
0005432528463	30617	Business	42100.00
0005432535853	30617	Business	42100.00
0005435725674	30617	Business	42100.00
0005435214511	30617	Business	42100.00
0005433656720	30617	Business	42100.00
0005434067981	30617	Business	42100.00
0005432528535	30617	Business	42100.00
0005432533303	30617	Business	42100.00
0005435214533	30617	Business	42100.00
0005435214487	30617	Business	42100.00
0005432528716	30617	Business	42100.00
0005435214515	30617	Business	42100.00
0005432528757	30617	Business	42100.00
0005432528175	30617	Business	42100.00
0005432529114	30617	Business	42100.00
0005434067707	30617	Business	42100.00
0005432528668	30617	Business	42100.00
0005435214526	30617	Business	42100.00
0005434068009	30617	Business	42100.00
0005435214501	30617	Business	42100.00
0005432528709	30617	Business	42100.00
0005432159925	30617	Comfort	23900.00
0005435214547	30617	Comfort	23900.00
0005434068130	30617	Comfort	23900.00
0005432528559	30617	Comfort	23900.00
0005434068232	30617	Comfort	23900.00
0005434067939	30617	Comfort	23900.00
0005432528525	30617	Comfort	23900.00
0005435214538	30617	Comfort	23900.00
0005434067879	30617	Comfort	23900.00
0005432529084	30617	Comfort	23900.00
0005432529085	30617	Comfort	23900.00
0005434068077	30617	Comfort	23900.00
0005432528536	30617	Comfort	23900.00
0005432528720	30617	Comfort	23900.00
0005432528982	30617	Comfort	23900.00
0005432528027	30617	Comfort	23900.00
0005432537069	30617	Comfort	23900.00
0005435214513	30617	Comfort	23900.00
0005434067471	30617	Comfort	23900.00
0005432159926	30617	Comfort	23900.00
0005432528683	30617	Comfort	23900.00
0005434067919	30617	Comfort	23900.00
0005434068227	30617	Comfort	23900.00
0005435214506	30617	Comfort	23900.00
0005434067880	30617	Comfort	23900.00
0005435214491	30617	Comfort	23900.00
0005434067868	30617	Comfort	23900.00
0005435214535	30617	Comfort	23900.00
0005435214483	30617	Comfort	23900.00
0005435214519	30617	Comfort	23900.00
0005434068231	30617	Comfort	23900.00
0005434067816	30617	Comfort	23900.00
0005434067931	30617	Comfort	23900.00
0005434067863	30617	Comfort	23900.00
0005434067653	30617	Comfort	23900.00
0005432159924	30617	Comfort	23900.00
0005432528442	30617	Comfort	23900.00
0005435214490	30617	Comfort	23900.00
0005434067665	30617	Comfort	23900.00
0005432528380	30617	Comfort	23900.00
0005435214545	30617	Comfort	23900.00
0005434067979	30617	Comfort	23900.00
0005434068166	30617	Economy	14000.00
0005432528882	30617	Economy	14000.00
0005434067917	30617	Economy	14000.00
0005434067916	30617	Economy	14000.00
0005432528701	30617	Economy	14000.00
0005435214521	30617	Economy	14000.00
0005435214508	30617	Economy	14000.00
0005434067947	30617	Economy	14000.00
0005432528762	30617	Economy	14000.00
0005434068049	30617	Economy	14000.00
0005435214536	30617	Economy	14000.00
0005432535870	30617	Economy	14000.00
0005432528703	30617	Economy	14000.00
0005435631010	30617	Economy	14000.00
0005432528746	30617	Economy	14000.00
0005434067682	30617	Economy	14000.00
0005432529081	30617	Economy	14000.00
0005435214518	30617	Economy	14000.00
0005432528433	30617	Economy	14000.00
0005432528641	30617	Economy	14000.00
0005434067619	30617	Economy	14000.00
0005435214544	30617	Economy	14000.00
0005435214537	30617	Economy	14000.00
0005435214500	30617	Economy	14000.00
0005432528086	30617	Economy	14000.00
0005432159923	30617	Economy	14000.00
0005435631012	30617	Economy	14000.00
0005432528892	30617	Economy	14000.00
0005432528479	30617	Economy	14000.00
0005432528731	30617	Economy	14000.00
0005434067621	30617	Economy	14000.00
0005435214514	30617	Economy	14000.00
0005432529186	30617	Economy	14000.00
0005435214503	30617	Economy	14000.00
0005432528662	30617	Economy	14000.00
0005434067977	30617	Economy	14000.00
0005435214479	30617	Economy	14000.00
0005432528674	30617	Economy	14000.00
0005435214488	30617	Economy	14000.00
0005434067793	30617	Economy	14000.00
0005432528202	30617	Economy	14000.00
0005432528774	30617	Economy	14000.00
0005435214524	30617	Economy	14000.00
0005434067914	30617	Economy	14000.00
0005432528234	30617	Economy	14000.00
0005432528256	30617	Economy	14000.00
0005434068076	30617	Economy	14000.00
0005434067852	30617	Economy	14000.00
0005435214522	30617	Economy	14000.00
0005435214530	30617	Economy	14000.00
0005432528730	30617	Economy	14000.00
0005432528769	30617	Economy	14000.00
0005433656719	30617	Economy	14000.00
0005432529011	30617	Economy	14000.00
0005432528475	30617	Economy	14000.00
0005432528513	30617	Economy	14000.00
0005434067951	30617	Economy	14000.00
0005432528722	30617	Economy	14000.00
0005432528512	30617	Economy	15400.00
0005434068208	30617	Economy	14000.00
0005432528820	30617	Economy	15400.00
0005432211611	30617	Economy	15400.00
0005434068355	30617	Economy	14000.00
0005432528767	30617	Economy	14000.00
0005435214540	30617	Economy	14000.00
0005435214517	30617	Economy	15400.00
0005435214493	30617	Economy	14000.00
0005432528541	30617	Economy	15400.00
0005434067672	30617	Economy	14000.00
0005432159922	30617	Economy	14000.00
0005435214528	30617	Economy	14000.00
0005435214499	30617	Economy	14000.00
0005432528482	30617	Economy	14000.00
0005432528462	30617	Economy	14000.00
0005432428943	30617	Economy	14000.00
0005434067782	30617	Economy	14000.00
0005435725671	30617	Economy	14000.00
0005435214516	30617	Economy	14000.00
0005432528721	30617	Economy	14000.00
0005432528780	30617	Economy	14000.00
0005435214546	30617	Economy	14000.00
0005432528821	30617	Economy	14000.00
0005432528770	30617	Economy	14000.00
0005435214497	30617	Economy	14000.00
0005434067618	30617	Economy	14000.00
0005432528471	30617	Economy	14000.00
0005433656721	30617	Economy	14000.00
0005432528977	30617	Economy	14000.00
0005432528904	30617	Economy	14000.00
0005434067730	30617	Economy	14000.00
0005434068013	30617	Economy	14000.00
0005432528702	30617	Economy	14000.00
0005432528255	30617	Economy	14000.00
0005435214520	30617	Economy	14000.00
0005435214485	30617	Economy	14000.00
0005432528543	30617	Economy	14000.00
0005434068018	30617	Economy	14000.00
0005434067669	30617	Economy	14000.00
0005434067817	30617	Economy	14000.00
0005435214489	30617	Economy	14000.00
0005432428944	30617	Economy	14000.00
0005434067685	30617	Economy	14000.00
0005432528822	30617	Economy	14000.00
0005432528847	30617	Economy	14000.00
0005432528628	30617	Economy	14000.00
0005434067866	30617	Economy	14000.00
0005435214481	30617	Economy	14000.00
0005432528606	30617	Economy	14000.00
0005432528966	30617	Economy	14000.00
0005435214527	30617	Economy	14000.00
0005435214534	30617	Economy	14000.00
0005432528941	30617	Economy	14000.00
0005435214507	30617	Economy	14000.00
0005432529083	30617	Economy	14000.00
0005432528381	30617	Economy	14000.00
0005432528841	30617	Economy	14000.00
0005432528514	30617	Economy	14000.00
0005435214529	30617	Economy	14000.00
0005432528542	30617	Economy	14000.00
0005434068226	30617	Economy	14000.00
0005434068100	30617	Economy	14000.00
0005435214510	30617	Economy	14000.00
0005432535871	30617	Economy	14000.00
0005434068042	30617	Economy	14000.00
0005434067881	30617	Economy	14000.00
0005432159921	30617	Economy	14000.00
0005435214542	30617	Economy	14000.00
0005434067927	30617	Economy	14000.00
0005435214505	30617	Economy	14000.00
0005432528957	30617	Economy	14000.00
0005435725672	30617	Economy	14000.00
0005435214509	30617	Economy	14000.00
0005432529096	30617	Economy	14000.00
0005435214482	30617	Economy	14000.00
0005435214525	30617	Economy	14000.00
0005435214532	30617	Economy	14000.00
0005435725673	30617	Economy	14000.00
0005432528605	30617	Economy	14000.00
0005435214502	30617	Economy	14000.00
0005432535858	30617	Economy	14000.00
0005434067858	30617	Economy	14000.00
0005435214495	30617	Economy	14000.00
0005435214494	30617	Economy	14000.00
0005432528881	30617	Economy	14000.00
0005432528235	30617	Economy	14000.00
0005432528755	30617	Economy	14000.00
0005432529010	30617	Economy	14000.00
0005432528758	30617	Economy	14000.00
0005432528869	30617	Economy	14000.00
0005434067982	30617	Economy	14000.00
0005432529619	30617	Economy	14000.00
0005432528278	30617	Economy	14000.00
0005434068008	30617	Economy	14000.00
0005434067864	30617	Economy	14000.00
0005432528978	30617	Economy	14000.00
0005432528562	30617	Economy	14000.00
0005432528891	30617	Economy	14000.00
0005434067838	30617	Economy	14000.00
0005432528884	30617	Economy	14000.00
0005432528135	30617	Economy	14000.00
0005434068019	30617	Economy	14000.00
0005432528611	30617	Economy	14000.00
0005432528540	30617	Economy	15400.00
0005432528657	30617	Economy	15400.00
0005435214480	30617	Economy	15400.00
0005432528956	30617	Economy	15400.00
0005432529350	30617	Economy	14000.00
0005432211608	30617	Economy	14000.00
0005432529143	30617	Economy	14000.00
0005432211607	30617	Economy	14000.00
0005434067843	30617	Economy	14000.00
0005434067759	30617	Economy	14000.00
0005434067932	30617	Economy	14000.00
0005434067837	30617	Economy	14000.00
0005432528663	30617	Economy	14000.00
0005432529013	30617	Economy	14000.00
0005434067929	30617	Economy	14000.00
0005432528827	30617	Economy	14000.00
0005435214541	30617	Economy	14000.00
0005432529080	30617	Economy	14000.00
0005432528826	30617	Economy	14000.00
0005435214539	30617	Economy	14000.00
0005434067966	30617	Economy	14000.00
0005434067620	30617	Economy	14000.00
0005434067654	30617	Economy	14000.00
0005434067798	30617	Economy	14000.00
0005435214492	30617	Economy	14000.00
0005432211606	30617	Economy	14000.00
0005432211609	30617	Economy	14000.00
0005432537070	30617	Economy	14000.00
0005432528236	30617	Economy	14000.00
0005432528905	30617	Economy	14000.00
0005435214504	30617	Economy	14000.00
0005432528799	30617	Economy	14000.00
0005434068131	30617	Economy	14000.00
0005434068228	30617	Economy	14000.00
0005432528478	30617	Economy	14000.00
0005435214523	30617	Economy	14000.00
0005432528883	30617	Economy	14000.00
0005432529159	30617	Economy	14000.00
0005434067940	30617	Economy	14000.00
0005432528636	30617	Economy	14000.00
0005435214486	30617	Economy	14000.00
0005432528661	30617	Economy	14000.00
0005435214496	30617	Economy	14000.00
0005434068160	30617	Economy	14000.00
0005432528510	30617	Economy	14000.00
0005432528464	30617	Economy	14000.00
0005434068245	30617	Economy	14000.00
0005432528842	30617	Economy	14000.00
0005434067853	30617	Economy	14000.00
0005435214512	30617	Economy	14000.00
0005432528560	30617	Economy	14000.00
0005432528843	30617	Economy	14000.00
0005432528673	30617	Economy	14000.00
0005435214498	30617	Economy	14000.00
0005432528477	30617	Economy	14000.00
0005432528715	30617	Economy	14000.00
0005434067755	30617	Economy	14000.00
0005432537065	30617	Economy	14000.00
0005432528561	30617	Economy	14000.00
0005432528642	30617	Economy	14000.00
0005434067915	30617	Economy	14000.00
0005434067460	30617	Economy	14000.00
0005432528773	30617	Economy	14000.00
0005432535834	30617	Economy	14000.00
0005432528719	30617	Economy	14000.00
0005432528498	30617	Economy	14000.00
0005434067965	30617	Economy	14000.00
0005432529325	30617	Economy	14000.00
0005432529113	30617	Economy	14000.00
0005434067918	30617	Economy	14000.00
0005432211610	30617	Economy	14000.00
0005435214484	30617	Economy	14000.00
0005434067995	30617	Economy	14000.00
0005434067639	30617	Economy	14000.00
0005432528658	30617	Economy	14000.00
0005435214543	30617	Economy	14000.00
0005432535854	30617	Economy	14000.00
0005434067875	30617	Economy	14000.00
0005432529082	30617	Economy	14000.00
0005432528388	30617	Economy	14000.00
0005435214531	30617	Economy	14000.00
0005434067839	30617	Economy	14000.00
0005434067994	30617	Economy	14000.00
0005432528465	30617	Economy	14000.00
0005435214478	30617	Economy	14000.00
0005435631011	30617	Economy	14000.00
0005434068108	30617	Economy	14000.00
0005432529349	30617	Economy	14000.00
0005435725670	30617	Economy	14000.00
0005434067849	30617	Economy	14000.00
0005433368436	24821	Business	9800.00
0005435653311	24821	Business	9800.00
0005433368446	24821	Business	9800.00
0005433368437	24821	Business	9800.00
0005435653396	24821	Business	9800.00
0005435653202	24821	Business	9800.00
0005433368439	24821	Business	9800.00
0005435653041	24821	Business	9800.00
0005433368414	24821	Business	9800.00
0005433368418	24821	Business	9800.00
0005435653119	24821	Business	9800.00
0005435653083	24821	Economy	3300.00
0005435653336	24821	Economy	3300.00
0005435653254	24821	Economy	3300.00
0005435653263	24821	Economy	3300.00
0005433368412	24821	Economy	3300.00
0005435653335	24821	Economy	3300.00
0005435653269	24821	Economy	3300.00
0005433368429	24821	Economy	3300.00
0005433368415	24821	Economy	3300.00
0005435653208	24821	Economy	3600.00
0005435653219	24821	Economy	3600.00
0005433368428	24821	Economy	3600.00
0005435653183	24821	Economy	3600.00
0005433368442	24821	Economy	3300.00
0005433368441	24821	Economy	3300.00
0005435653306	24821	Economy	3300.00
0005435653236	24821	Economy	3300.00
0005435653196	24821	Economy	3300.00
0005433368440	24821	Economy	3300.00
0005435653084	24821	Economy	3300.00
0005433368409	24821	Economy	3300.00
0005433368410	24821	Economy	3300.00
0005433368435	24821	Economy	3300.00
0005433368433	24821	Economy	3300.00
0005435653213	24821	Economy	3300.00
0005435653283	24821	Economy	3300.00
0005433368411	24821	Economy	3300.00
0005433368417	24821	Economy	3300.00
0005433368413	24821	Economy	3300.00
0005435653260	24821	Economy	3300.00
0005433368444	24821	Economy	3300.00
0005435653264	24821	Economy	3300.00
0005435653397	24821	Economy	3300.00
0005433368432	24821	Economy	3300.00
0005433368422	24821	Economy	3300.00
0005435653294	24821	Economy	3300.00
0005435653347	24821	Economy	3300.00
0005435653146	24821	Economy	3300.00
0005433368438	24821	Economy	3300.00
0005435653268	24821	Economy	3300.00
0005435653316	24821	Economy	3300.00
0005435653187	24821	Economy	3300.00
0005433368416	24821	Economy	3300.00
0005435653337	24821	Economy	3300.00
0005435653334	24821	Economy	3300.00
0005435653305	24821	Economy	3300.00
0005435653102	24821	Economy	3300.00
0005435653170	24821	Economy	3300.00
0005435653350	24821	Economy	3300.00
0005435653091	24821	Economy	3300.00
0005433368426	24821	Economy	3300.00
0005433368431	24821	Economy	3300.00
0005435653346	24821	Economy	3300.00
0005433368424	24821	Economy	3300.00
0005433368425	24821	Economy	3300.00
0005435653255	24821	Economy	3300.00
0005433368427	24821	Economy	3300.00
0005435653300	24821	Economy	3300.00
0005433368445	24821	Economy	3300.00
0005435653376	24821	Economy	3300.00
0005435653174	24821	Economy	3300.00
0005435653308	24821	Economy	3300.00
0005435653338	24821	Economy	3300.00
0005435653265	24821	Economy	3300.00
0005433368420	24821	Economy	3300.00
0005435653145	24821	Economy	3300.00
0005433368434	24821	Economy	3300.00
0005433368419	24821	Economy	3300.00
0005435653368	24821	Economy	3300.00
0005435653267	24821	Economy	3300.00
0005433368421	24821	Economy	3300.00
0005435653351	24821	Economy	3300.00
0005435653307	24821	Economy	3300.00
0005433368443	24821	Economy	3300.00
0005435653274	24821	Economy	3300.00
0005433368423	24821	Economy	3300.00
0005433368430	24821	Economy	3300.00
0005435653207	24821	Economy	3300.00
0005435949815	6608	Economy	20600.00
0005435949821	6608	Economy	18700.00
0005435949814	6608	Economy	18700.00
0005435949817	6608	Economy	18700.00
0005435949822	6608	Economy	18700.00
0005435949823	6608	Economy	18700.00
0005435949813	6608	Economy	18700.00
0005435949816	6608	Economy	18700.00
0005435949818	6608	Economy	18700.00
0005435949820	6608	Economy	18700.00
0005435949819	6608	Economy	18700.00
0005434980213	2056	Economy	10500.00
0005434980222	2056	Economy	10500.00
0005434980219	2056	Economy	10500.00
0005435801741	2056	Economy	10500.00
0005434980209	2056	Economy	9500.00
0005434980210	2056	Economy	9500.00
0005435801740	2056	Economy	9500.00
0005434980233	2056	Economy	9500.00
0005434980229	2056	Economy	9500.00
0005434980211	2056	Economy	9500.00
0005434980236	2056	Economy	9500.00
0005434980217	2056	Economy	9500.00
0005434980232	2056	Economy	9500.00
0005434980234	2056	Economy	9500.00
0005434980214	2056	Economy	9500.00
0005434980212	2056	Economy	9500.00
0005434980228	2056	Economy	9500.00
0005434980224	2056	Economy	9500.00
0005434980220	2056	Economy	9500.00
0005434980227	2056	Economy	9500.00
0005434980208	2056	Economy	9500.00
0005434980226	2056	Economy	9500.00
0005434980216	2056	Economy	9500.00
0005434980221	2056	Economy	9500.00
0005434980231	2056	Economy	9500.00
0005434980206	2056	Economy	9500.00
0005434980225	2056	Economy	9500.00
0005435801742	2056	Economy	9500.00
0005434980207	2056	Economy	9500.00
0005434980235	2056	Economy	9500.00
0005434980223	2056	Economy	9500.00
0005434980218	2056	Economy	9500.00
0005435801739	2056	Economy	9500.00
0005434980230	2056	Economy	9500.00
0005434980215	2056	Economy	9500.00
0005434979903	23565	Economy	10500.00
0005434979976	23565	Economy	10500.00
0005434979871	23565	Economy	10500.00
0005434979880	23565	Economy	9500.00
0005435801732	23565	Economy	9500.00
0005434980045	23565	Economy	9500.00
0005435801718	23565	Economy	9500.00
0005434979908	23565	Economy	9500.00
0005434979853	23565	Economy	9500.00
0005434979958	23565	Economy	9500.00
0005434979957	23565	Economy	9500.00
0005434979810	23565	Economy	9500.00
0005434979980	23565	Economy	9500.00
0005434979954	23565	Economy	9500.00
0005434979988	23565	Economy	9500.00
0005434979904	23565	Economy	9500.00
0005434979881	23565	Economy	9500.00
0005434979952	23565	Economy	9500.00
0005434980080	23565	Economy	9500.00
0005434979990	23565	Economy	9500.00
0005434979979	23565	Economy	9500.00
0005434980004	23565	Economy	9500.00
0005434979777	23565	Economy	9500.00
0005434979907	23565	Economy	9500.00
0005435801720	23565	Economy	9500.00
0005434979967	23565	Economy	9500.00
0005434979968	23565	Economy	9500.00
0005434979948	23565	Economy	9500.00
0005434979835	23565	Economy	9500.00
0005434979809	23565	Economy	9500.00
0005434979776	23565	Economy	9500.00
0005434979924	23565	Economy	9500.00
0005434979959	23565	Economy	9500.00
0005434979778	23565	Economy	9500.00
0005434979854	23565	Economy	9500.00
0005434979837	23565	Economy	9500.00
0005434979953	23565	Economy	9500.00
0005434980044	23565	Economy	9500.00
0005434979989	23565	Economy	9500.00
0005434979838	23565	Economy	9500.00
0005434979840	23565	Economy	9500.00
0005434952584	2607	Economy	5300.00
0005434952586	2607	Economy	5300.00
0005434952585	2607	Economy	5300.00
0005433256433	2615	Economy	5300.00
0005433256440	2615	Economy	5300.00
0005433256434	2615	Economy	5300.00
0005433256435	2615	Economy	5300.00
0005433256441	2615	Economy	5300.00
0005433256454	28291	Economy	5300.00
0005433256453	28291	Economy	5300.00
0005434952555	28291	Economy	5300.00
0005433256455	28291	Economy	5300.00
0005433111537	19733	Economy	8700.00
0005433111539	19733	Economy	8700.00
0005433111538	19733	Economy	8700.00
0005433112396	19733	Economy	8700.00
0005434138192	11938	Business	9700.00
0005434138997	11938	Business	9700.00
0005434138420	11938	Business	9700.00
0005434138968	11938	Business	9700.00
0005434138421	11938	Business	9700.00
0005434138569	11938	Business	9700.00
0005434138476	11938	Business	9700.00
0005434138891	11938	Business	9700.00
0005434138799	11938	Business	9700.00
0005434138866	11938	Business	9700.00
0005434138598	11938	Business	9700.00
0005434138538	11938	Economy	3200.00
0005434138215	11938	Economy	3200.00
0005434138677	11938	Economy	3200.00
0005434138406	11938	Economy	3200.00
0005434138578	11938	Economy	3200.00
0005434138590	11938	Economy	3200.00
0005434138951	11938	Economy	3200.00
0005434138669	11938	Economy	3200.00
0005434138536	11938	Economy	3200.00
0005434138662	11938	Economy	3200.00
0005434138644	11938	Economy	3500.00
0005434138624	11938	Economy	3500.00
0005434138447	11938	Economy	3500.00
0005434138560	11938	Economy	3200.00
0005434138861	11938	Economy	3200.00
0005434138712	11938	Economy	3200.00
0005434138555	11938	Economy	3200.00
0005434138860	11938	Economy	3200.00
0005434138893	11938	Economy	3200.00
0005434138777	11938	Economy	3200.00
0005434139080	11938	Economy	3200.00
0005434138587	11938	Economy	3200.00
0005434138405	11938	Economy	3200.00
0005434138774	11938	Economy	3200.00
0005434138411	11938	Economy	3200.00
0005434138888	11938	Economy	3200.00
0005434138433	11938	Economy	3200.00
0005434138652	11938	Economy	3200.00
0005434138549	11938	Economy	3200.00
0005434138548	11938	Economy	3200.00
0005434138784	11938	Economy	3200.00
0005434138727	11938	Economy	3200.00
0005434138550	11938	Economy	3200.00
0005434138623	11938	Economy	3200.00
0005434138597	11938	Economy	3200.00
0005434138492	11938	Economy	3200.00
0005434138410	11938	Economy	3200.00
0005434138864	11938	Economy	3200.00
0005434138996	11938	Economy	3200.00
0005434138472	11938	Economy	3200.00
0005434138576	11938	Economy	3200.00
0005434138869	11938	Economy	3200.00
0005434138728	11938	Economy	3200.00
0005434138473	11938	Economy	3200.00
0005434138591	11938	Economy	3200.00
0005434138785	11938	Economy	3200.00
0005434138530	11938	Economy	3200.00
0005434138443	11938	Economy	3200.00
0005434138720	11938	Economy	3200.00
0005434138776	11938	Economy	3200.00
0005434138670	11938	Economy	3200.00
0005434138870	11938	Economy	3200.00
0005434138537	11938	Economy	3200.00
0005434138865	11938	Economy	3200.00
0005434138972	11938	Economy	3200.00
0005434138432	11938	Economy	3200.00
0005434138556	11938	Economy	3200.00
0005434138412	11938	Economy	3200.00
0005434138248	11938	Economy	3200.00
0005434138973	11938	Economy	3200.00
0005434138832	11938	Economy	3200.00
0005434138672	11938	Economy	3200.00
0005434138717	11938	Economy	3200.00
0005434138613	11938	Economy	3200.00
0005434139108	11938	Economy	3200.00
0005434138952	11938	Economy	3200.00
0005434138475	11938	Economy	3200.00
0005434138409	11938	Economy	3200.00
0005434138713	11938	Economy	3200.00
0005434138577	11938	Economy	3200.00
0005434138750	11938	Economy	3200.00
0005434138746	11938	Economy	3200.00
0005434139247	28756	Business	9700.00
0005434139227	28756	Business	9700.00
0005434139218	28756	Business	9700.00
0005434139222	28756	Business	9700.00
0005434139268	28756	Business	9700.00
0005434139220	28756	Business	9700.00
0005434139272	28756	Business	9700.00
0005434139257	28756	Business	9700.00
0005434139282	28756	Business	9700.00
0005434139243	28756	Business	9700.00
0005434139219	28756	Business	9700.00
0005434139215	28756	Economy	3200.00
0005434139254	28756	Economy	3200.00
0005434139223	28756	Economy	3200.00
0005434139263	28756	Economy	3200.00
0005434139233	28756	Economy	3200.00
0005434139260	28756	Economy	3200.00
0005434139231	28756	Economy	3200.00
0005434139236	28756	Economy	3200.00
0005434139240	28756	Economy	3200.00
0005434139252	28756	Economy	3500.00
0005434139232	28756	Economy	3500.00
0005434139277	28756	Economy	3500.00
0005434139242	28756	Economy	3200.00
0005434139259	28756	Economy	3200.00
0005434139229	28756	Economy	3200.00
0005434139258	28756	Economy	3200.00
0005434139245	28756	Economy	3200.00
0005434139265	28756	Economy	3200.00
0005434139221	28756	Economy	3200.00
0005434139273	28756	Economy	3200.00
0005434139289	28756	Economy	3200.00
0005434139244	28756	Economy	3200.00
0005434139253	28756	Economy	3200.00
0005434139261	28756	Economy	3200.00
0005434139279	28756	Economy	3200.00
0005434139224	28756	Economy	3200.00
0005434139248	28756	Economy	3200.00
0005434139285	28756	Economy	3200.00
0005434139266	28756	Economy	3200.00
0005434139216	28756	Economy	3200.00
0005434139249	28756	Economy	3200.00
0005434139287	28756	Economy	3200.00
0005434139239	28756	Economy	3200.00
0005434139255	28756	Economy	3200.00
0005434139250	28756	Economy	3200.00
0005434139275	28756	Economy	3200.00
0005434139271	28756	Economy	3200.00
0005434139226	28756	Economy	3200.00
0005434139288	28756	Economy	3200.00
0005434139284	28756	Economy	3200.00
0005434139234	28756	Economy	3200.00
0005434139256	28756	Economy	3200.00
0005434139264	28756	Economy	3200.00
0005434139290	28756	Economy	3200.00
0005434139251	28756	Economy	3200.00
0005434139267	28756	Economy	3200.00
0005434139281	28756	Economy	3200.00
0005434139286	28756	Economy	3200.00
0005434139225	28756	Economy	3200.00
0005434139276	28756	Economy	3200.00
0005434139280	28756	Economy	3200.00
0005434139230	28756	Economy	3200.00
0005434139237	28756	Economy	3200.00
0005434139228	28756	Economy	3200.00
0005434139283	28756	Economy	3200.00
0005434139235	28756	Economy	3200.00
0005434139274	28756	Economy	3200.00
0005434139217	28756	Economy	3200.00
0005434139262	28756	Economy	3200.00
0005434139278	28756	Economy	3200.00
0005434139270	28756	Economy	3200.00
0005434139291	28756	Economy	3200.00
0005434139241	28756	Economy	3200.00
0005434139238	28756	Economy	3200.00
0005434139269	28756	Economy	3200.00
0005434139246	28756	Economy	3200.00
0005433538991	6819	Economy	10900.00
0005435259785	6819	Economy	9900.00
0005435259780	6819	Economy	9900.00
0005435259809	6819	Economy	9900.00
0005435259776	6819	Economy	9900.00
0005435259810	6819	Economy	9900.00
0005435259775	6819	Economy	9900.00
0005433538996	6819	Economy	9900.00
0005433538997	6819	Economy	9900.00
0005435259789	6819	Economy	9900.00
0005433538995	6819	Economy	9900.00
0005433538992	6819	Economy	9900.00
0005435259808	6819	Economy	9900.00
0005433538993	6819	Economy	9900.00
0005435259793	6819	Economy	9900.00
0005435259790	6819	Economy	9900.00
0005435259774	6819	Economy	9900.00
0005433534529	6819	Economy	9900.00
0005433534528	6819	Economy	9900.00
0005433538994	6819	Economy	9900.00
0005435259782	6819	Economy	9900.00
0005435259779	6819	Economy	9900.00
0005433538934	25032	Economy	10900.00
0005435259820	25032	Economy	10900.00
0005435259821	25032	Economy	9900.00
0005433538936	25032	Economy	9900.00
0005433538910	25032	Economy	9900.00
0005433538903	25032	Economy	9900.00
0005433538937	25032	Economy	9900.00
0005433538904	25032	Economy	9900.00
0005435259822	25032	Economy	9900.00
0005433538913	25032	Economy	9900.00
0005433538885	25032	Economy	9900.00
0005435259819	25032	Economy	9900.00
0005433538884	25032	Economy	9900.00
0005435259818	25032	Economy	9900.00
0005432922560	817	Economy	14600.00
0005432922535	817	Economy	14600.00
0005433512076	817	Economy	14600.00
0005432922549	817	Economy	14600.00
0005433512070	817	Economy	14600.00
0005433512074	817	Economy	14600.00
0005432922551	817	Economy	14600.00
0005433512073	817	Economy	14600.00
0005433512072	817	Economy	14600.00
0005433512075	817	Economy	14600.00
0005433512071	817	Economy	14600.00
0005432922550	817	Economy	14600.00
0005433511999	16136	Economy	16100.00
0005433512002	16136	Economy	16100.00
0005433512014	16136	Economy	16100.00
0005433512000	16136	Economy	14600.00
0005433511998	16136	Economy	14600.00
0005433512001	16136	Economy	14600.00
0005432922584	16136	Economy	14600.00
0005433512012	16136	Economy	14600.00
0005432922583	16136	Economy	14600.00
0005432922582	16136	Economy	14600.00
0005433512015	16136	Economy	14600.00
0005433512007	16136	Economy	14600.00
0005432922585	16136	Economy	14600.00
0005435697752	3687	Economy	7900.00
0005435697749	3687	Economy	7900.00
0005435697738	3687	Economy	7900.00
0005434950594	3687	Economy	7200.00
0005435697743	3687	Economy	7200.00
0005435697755	3687	Economy	7200.00
0005434950592	3687	Economy	7200.00
0005435697757	3687	Economy	7200.00
0005435697747	3687	Economy	7200.00
0005435697748	3687	Economy	7200.00
0005435935063	3687	Economy	7200.00
0005435935067	3687	Economy	7200.00
0005434950595	3687	Economy	7200.00
0005435697754	3687	Economy	7200.00
0005435697745	3687	Economy	7200.00
0005434950593	3687	Economy	7200.00
0005435697751	3687	Economy	7200.00
0005435916183	3687	Economy	7200.00
0005435697750	3687	Economy	7200.00
0005435697740	3687	Economy	7200.00
0005435697756	3687	Economy	7200.00
0005435697737	3687	Economy	7200.00
0005434950597	3687	Economy	7200.00
0005435697735	3687	Economy	7200.00
0005435697761	3687	Economy	7200.00
0005435697742	3687	Economy	7200.00
0005435697744	3687	Economy	7200.00
0005435935068	3687	Economy	7200.00
0005434950596	3687	Economy	7200.00
0005435697739	3687	Economy	7200.00
0005435697759	3687	Economy	7200.00
0005435697758	3687	Economy	7200.00
0005435697746	3687	Economy	7200.00
0005435697736	3687	Economy	7200.00
0005435697760	3687	Economy	7200.00
0005435697741	3687	Economy	7200.00
0005435697753	3687	Economy	7200.00
0005435697381	16253	Economy	7900.00
0005435697548	16253	Economy	7900.00
0005435697528	16253	Economy	7900.00
0005435697494	16253	Economy	7900.00
0005435697461	16253	Economy	7200.00
0005435697489	16253	Economy	7200.00
0005435697407	16253	Economy	7200.00
0005435697400	16253	Economy	7200.00
0005435697583	16253	Economy	7200.00
0005435697352	16253	Economy	7200.00
0005435697406	16253	Economy	7200.00
0005435697581	16253	Economy	7200.00
0005435697395	16253	Economy	7200.00
0005435697606	16253	Economy	7200.00
0005435916206	16253	Economy	7200.00
0005435697399	16253	Economy	7200.00
0005435697450	16253	Economy	7200.00
0005435697482	16253	Economy	7200.00
0005434950566	16253	Economy	7200.00
0005435935084	16253	Economy	7200.00
0005435935086	16253	Economy	7200.00
0005435697514	16253	Economy	7200.00
0005435697477	16253	Economy	7200.00
0005435697475	16253	Economy	7200.00
0005435697584	16253	Economy	7200.00
0005435697437	16253	Economy	7200.00
0005435697553	16253	Economy	7200.00
0005435935087	16253	Economy	7200.00
0005435697396	16253	Economy	7200.00
0005435697401	16253	Economy	7200.00
0005435697459	16253	Economy	7200.00
0005435697447	16253	Economy	7200.00
0005435697488	16253	Economy	7200.00
0005435935085	16253	Economy	7200.00
0005434950556	16253	Economy	7200.00
0005435697460	16253	Economy	7200.00
0005435697449	16253	Economy	7200.00
0005434950535	16253	Economy	7200.00
0005435697405	16253	Economy	7200.00
0005435697408	16253	Economy	7200.00
0005434950567	16253	Economy	7200.00
0005435697479	16253	Economy	7200.00
0005435916207	16253	Economy	7200.00
0005435697474	16253	Economy	7200.00
0005434950572	16253	Economy	7200.00
0005435697351	16253	Economy	7200.00
0005432607625	3970	Economy	21300.00
0005433519526	3970	Economy	21300.00
0005434604949	3970	Economy	19300.00
0005432609790	3970	Economy	19300.00
0005435904704	3970	Economy	19300.00
0005432609792	3970	Economy	19300.00
0005432609791	3970	Economy	19300.00
0005434606878	3970	Economy	19300.00
0005432607626	3970	Economy	19300.00
0005434604947	3970	Economy	19300.00
0005432609789	3970	Economy	19300.00
0005433519525	3970	Economy	19300.00
0005433519524	3970	Economy	19300.00
0005434604948	3970	Economy	19300.00
0005432607627	3970	Economy	19300.00
0005435853625	3970	Economy	19300.00
0005432607624	3970	Economy	19300.00
0005433519523	3970	Economy	19300.00
0005435853638	22030	Economy	19300.00
0005434606838	22030	Economy	19300.00
0005433519482	22030	Economy	19300.00
0005435853637	22030	Economy	19300.00
0005433519477	22030	Economy	19300.00
0005435853639	22030	Economy	19300.00
0005434606830	22030	Economy	19300.00
0005433349038	706	Economy	3700.00
0005435628769	706	Economy	3700.00
0005435628771	706	Economy	3700.00
0005433349023	706	Economy	3700.00
0005435628770	706	Economy	3700.00
0005435628772	706	Economy	3700.00
0005433349071	15887	Economy	3700.00
0005433349072	15887	Economy	3700.00
0005435628729	15887	Economy	3700.00
0005435628730	15887	Economy	3700.00
0005433349075	15887	Economy	3700.00
0005433349076	15887	Economy	3700.00
0005433349074	15887	Economy	3700.00
0005435628731	15887	Economy	3700.00
0005435628736	15887	Economy	3700.00
0005435628733	15887	Economy	3700.00
0005435628728	15887	Economy	3700.00
0005433349073	15887	Economy	3700.00
0005434446548	17185	Economy	7100.00
0005433158144	17185	Economy	7100.00
0005434445273	17185	Economy	7100.00
0005433159321	17185	Economy	7100.00
0005433158145	17185	Economy	7100.00
0005434446550	17185	Economy	7100.00
0005433159320	17185	Economy	7100.00
0005434446549	17185	Economy	7100.00
0005434445256	17592	Economy	7100.00
0005434445261	17592	Economy	7100.00
0005434445260	17592	Economy	7100.00
0005435133035	7865	Economy	5900.00
0005435133037	7865	Economy	5900.00
0005435133040	7865	Economy	5400.00
0005435133033	7865	Economy	5400.00
0005435383160	7865	Economy	5400.00
0005435133034	7865	Economy	5400.00
0005435133031	7865	Economy	5400.00
0005435383161	7865	Economy	5400.00
0005435133030	7865	Economy	5400.00
0005435133039	7865	Economy	5400.00
0005435383165	7865	Economy	5400.00
0005435133032	7865	Economy	5400.00
0005435383200	7865	Economy	5400.00
0005435383201	7865	Economy	5400.00
0005435383166	7865	Economy	5400.00
0005435133036	7865	Economy	5400.00
0005435133038	7865	Economy	5400.00
0005435383229	33063	Economy	5900.00
0005435383227	33063	Economy	5900.00
0005435132949	33063	Economy	5400.00
0005435132997	33063	Economy	5400.00
0005435132939	33063	Economy	5400.00
0005435132955	33063	Economy	5400.00
0005435132954	33063	Economy	5400.00
0005435132921	33063	Economy	5400.00
0005435383230	33063	Economy	5400.00
0005435383231	33063	Economy	5400.00
0005435132972	33063	Economy	5400.00
0005435383228	33063	Economy	5400.00
0005435132912	33063	Economy	5400.00
0005435132964	33063	Economy	5400.00
0005435132920	33063	Economy	5400.00
0005435132913	33063	Economy	5400.00
0005435160464	7513	Economy	13800.00
0005435160460	7513	Economy	13800.00
0005435160465	7513	Economy	12500.00
0005435160462	7513	Economy	12500.00
0005435160469	7513	Economy	12500.00
0005435160467	7513	Economy	12500.00
0005435390311	7513	Economy	12500.00
0005435160459	7513	Economy	12500.00
0005435160466	7513	Economy	12500.00
0005435160463	7513	Economy	12500.00
0005435390312	7513	Economy	12500.00
0005435390276	7513	Economy	12500.00
0005435390310	7513	Economy	12500.00
0005435390260	7513	Economy	12500.00
0005435160461	7513	Economy	12500.00
0005435390261	7513	Economy	12500.00
0005435390301	7513	Economy	12500.00
0005435390275	7513	Economy	12500.00
0005435160468	7513	Economy	12500.00
0005435390337	29575	Economy	12500.00
0005435390343	29575	Economy	12500.00
0005435160383	29575	Economy	12500.00
0005435160433	29575	Economy	12500.00
0005435160352	29575	Economy	12500.00
0005435160362	29575	Economy	12500.00
0005435390338	29575	Economy	12500.00
0005435160353	29575	Economy	12500.00
0005435160356	29575	Economy	12500.00
0005435390340	29575	Economy	12500.00
0005435390341	29575	Economy	12500.00
0005435390342	29575	Economy	12500.00
0005435160382	29575	Economy	12500.00
0005435160361	29575	Economy	12500.00
0005435390339	29575	Economy	12500.00
0005435390344	29575	Economy	12500.00
0005435178516	18460	Economy	4900.00
0005435179003	18460	Economy	4900.00
0005432394127	18460	Economy	4900.00
0005432394128	18460	Economy	4900.00
0005432398229	18460	Economy	4900.00
0005432394100	18460	Economy	4900.00
0005435179004	18460	Economy	4900.00
0005432394117	18460	Economy	4900.00
0005432394131	18460	Economy	4900.00
0005432394126	18460	Economy	4900.00
0005435178517	18460	Economy	4900.00
0005435179398	27138	Economy	4900.00
0005432398250	27138	Economy	4900.00
0005435179397	27138	Economy	4900.00
0005432400173	27138	Economy	4900.00
0005432400175	27138	Economy	4900.00
0005435179399	27138	Economy	4900.00
0005432400174	27138	Economy	4900.00
0005435179396	27138	Economy	4900.00
0005435178508	27138	Economy	4900.00
0005432398249	27138	Economy	4900.00
0005432398248	27138	Economy	4900.00
0005432663058	21840	Business	92200.00
0005432664167	21840	Business	92200.00
0005432661953	21840	Business	92200.00
0005432663068	21840	Business	92200.00
0005432663066	21840	Business	92200.00
0005432664158	21840	Business	92200.00
0005432664160	21840	Business	92200.00
0005432664164	21840	Business	92200.00
0005432664162	21840	Economy	30700.00
0005432664163	21840	Economy	30700.00
0005432664161	21840	Economy	30700.00
0005432664165	21840	Economy	30700.00
0005432664169	21840	Economy	30700.00
0005432663067	21840	Economy	30700.00
0005432663061	21840	Economy	30700.00
0005432661948	21840	Economy	30700.00
0005432663070	21840	Economy	30700.00
0005432663062	21840	Economy	30700.00
0005432661947	21840	Economy	30700.00
0005432663063	21840	Economy	30700.00
0005432664168	21840	Economy	30700.00
0005432663060	21840	Economy	30700.00
0005432661958	21840	Economy	30700.00
0005432661949	21840	Economy	30700.00
0005432664171	21840	Economy	30700.00
0005432661954	21840	Economy	30700.00
0005432661946	21840	Economy	30700.00
0005432661950	21840	Economy	30700.00
0005432664166	21840	Economy	30700.00
0005432663059	21840	Economy	30700.00
0005432661945	21840	Economy	30700.00
0005432661952	21840	Economy	30700.00
0005432661955	21840	Economy	30700.00
0005432663056	21840	Economy	30700.00
0005432663064	21840	Economy	30700.00
0005432663057	21840	Economy	30700.00
0005432663069	21840	Economy	30700.00
0005432664170	21840	Economy	30700.00
0005432661959	21840	Economy	30700.00
0005432661956	21840	Economy	30700.00
0005432661944	21840	Economy	30700.00
0005432663065	21840	Economy	30700.00
0005432661957	21840	Economy	30700.00
0005432664172	21840	Economy	30700.00
0005432661951	21840	Economy	30700.00
0005432664159	21840	Economy	30700.00
0005435104052	6523	Business	48400.00
0005434504731	6523	Business	48400.00
0005434504733	6523	Business	48400.00
0005434504712	6523	Business	48400.00
0005434504726	6523	Business	48400.00
0005434504736	6523	Business	48400.00
0005435104056	6523	Economy	16100.00
0005435104050	6523	Economy	16100.00
0005434504740	6523	Economy	16100.00
0005434504743	6523	Economy	16100.00
0005434504742	6523	Economy	16100.00
0005434504710	6523	Economy	17800.00
0005434504732	6523	Economy	17800.00
0005434504744	6523	Economy	17800.00
0005435104049	6523	Economy	17800.00
0005434504722	6523	Economy	16100.00
0005435104055	6523	Economy	16100.00
0005434504706	6523	Economy	16100.00
0005434504725	6523	Economy	16100.00
0005434504737	6523	Economy	16100.00
0005434504728	6523	Economy	16100.00
0005434504708	6523	Economy	16100.00
0005434504715	6523	Economy	16100.00
0005434504718	6523	Economy	16100.00
0005435104051	6523	Economy	16100.00
0005434504724	6523	Economy	16100.00
0005434504720	6523	Economy	16100.00
0005434504707	6523	Economy	16100.00
0005434504704	6523	Economy	16100.00
0005434504739	6523	Economy	16100.00
0005434504709	6523	Economy	16100.00
0005435104057	6523	Economy	16100.00
0005434504741	6523	Economy	16100.00
0005435104054	6523	Economy	16100.00
0005434504734	6523	Economy	16100.00
0005434504735	6523	Economy	16100.00
0005434504738	6523	Economy	16100.00
0005434504727	6523	Economy	16100.00
0005434504729	6523	Economy	16100.00
0005434504723	6523	Economy	16100.00
0005434504721	6523	Economy	16100.00
0005434504713	6523	Economy	16100.00
0005435104048	6523	Economy	16100.00
0005434504717	6523	Economy	16100.00
0005434504714	6523	Economy	16100.00
0005435104053	6523	Economy	16100.00
0005434504719	6523	Economy	16100.00
0005434504730	6523	Economy	16100.00
0005434504716	6523	Economy	16100.00
0005434504711	6523	Economy	16100.00
0005434504705	6523	Economy	16100.00
0005434504215	22651	Business	48400.00
0005434504155	22651	Business	48400.00
0005435103932	22651	Business	48400.00
0005434504349	22651	Economy	16100.00
0005434504308	22651	Economy	16100.00
0005434504242	22651	Economy	16100.00
0005434504241	22651	Economy	16100.00
0005434504316	22651	Economy	16100.00
0005434504262	22651	Economy	17800.00
0005434504353	22651	Economy	17800.00
0005434504256	22651	Economy	17800.00
0005434504330	22651	Economy	17800.00
0005434504299	22651	Economy	16100.00
0005434504350	22651	Economy	16100.00
0005434504426	22651	Economy	16100.00
0005434504333	22651	Economy	16100.00
0005434504314	22651	Economy	16100.00
0005434504304	22651	Economy	16100.00
0005434504252	22651	Economy	16100.00
0005434504181	22651	Economy	16100.00
0005434504428	22651	Economy	16100.00
0005434504357	22651	Economy	16100.00
0005434504287	22651	Economy	16100.00
0005434504379	22651	Economy	16100.00
0005434504249	22651	Economy	16100.00
0005434504300	22651	Economy	16100.00
0005434504334	22651	Economy	16100.00
0005434504329	22651	Economy	16100.00
0005434504358	22651	Economy	16100.00
0005434504396	22651	Economy	16100.00
0005434504312	22651	Economy	16100.00
0005434504302	22651	Economy	16100.00
0005434504311	22651	Economy	16100.00
0005434504315	22651	Economy	16100.00
0005434504261	22651	Economy	16100.00
0005434504378	22651	Economy	16100.00
0005434504321	22651	Economy	16100.00
0005435103936	22651	Economy	16100.00
0005434504344	22651	Economy	16100.00
0005434504071	22651	Economy	16100.00
0005434504317	22651	Economy	16100.00
0005434504303	22651	Economy	16100.00
0005435103915	22651	Economy	16100.00
0005434504402	22651	Economy	16100.00
0005434504272	22651	Economy	16100.00
0005434504137	22651	Economy	16100.00
0005434504420	22651	Economy	16100.00
0005434504257	22651	Economy	16100.00
0005434504309	22651	Economy	16100.00
0005434504288	22651	Economy	16100.00
0005435103953	22651	Economy	16100.00
0005434504322	22651	Economy	16100.00
0005435653695	1684	Business	50000.00
0005435653683	1684	Business	50000.00
0005435653705	1684	Business	50000.00
0005435653674	1684	Business	50000.00
0005433368046	1684	Business	50000.00
0005433368020	1684	Business	50000.00
0005435653696	1684	Business	50000.00
0005433368127	1684	Economy	16700.00
0005435653659	1684	Economy	16700.00
0005435653666	1684	Economy	16700.00
0005433368154	1684	Economy	16700.00
0005435653662	1684	Economy	16700.00
0005435653703	1684	Economy	16700.00
0005433368140	1684	Economy	16700.00
0005433368058	1684	Economy	16700.00
0005433368160	1684	Economy	16700.00
0005433368174	1684	Economy	16700.00
0005433367943	1684	Economy	18300.00
0005433368114	1684	Economy	18300.00
0005435653689	1684	Economy	18300.00
0005435653704	1684	Economy	18300.00
0005433368074	1684	Economy	16700.00
0005435653679	1684	Economy	16700.00
0005433368244	1684	Economy	16700.00
0005435653687	1684	Economy	16700.00
0005435653667	1684	Economy	16700.00
0005435653678	1684	Economy	16700.00
0005433367960	1684	Economy	16700.00
0005435653700	1684	Economy	16700.00
0005435653692	1684	Economy	16700.00
0005435653677	1684	Economy	16700.00
0005433367942	1684	Economy	16700.00
0005435653664	1684	Economy	16700.00
0005435653698	1684	Economy	16700.00
0005435653702	1684	Economy	16700.00
0005435653690	1684	Economy	16700.00
0005433368191	1684	Economy	16700.00
0005435653657	1684	Economy	16700.00
0005433368034	1684	Economy	16700.00
0005435653669	1684	Economy	16700.00
0005435653672	1684	Economy	16700.00
0005435653710	1684	Economy	16700.00
0005435653688	1684	Economy	16700.00
0005435653660	1684	Economy	16700.00
0005433368018	1684	Economy	16700.00
0005433367925	1684	Economy	16700.00
0005433368161	1684	Economy	16700.00
0005435653706	1684	Economy	16700.00
0005433368184	1684	Economy	16700.00
0005435653676	1684	Economy	16700.00
0005435653682	1684	Economy	16700.00
0005435653686	1684	Economy	16700.00
0005435653709	1684	Economy	16700.00
0005435653673	1684	Economy	16700.00
0005435653671	1684	Economy	16700.00
0005433368131	1684	Economy	16700.00
0005433368019	1684	Economy	16700.00
0005433368016	1684	Economy	16700.00
0005435653697	1684	Economy	16700.00
0005433367928	1684	Economy	16700.00
0005435653694	1684	Economy	16700.00
0005435653684	1684	Economy	16700.00
0005435653665	1684	Economy	16700.00
0005433368243	1684	Economy	16700.00
0005433368076	1684	Economy	16700.00
0005433368142	1684	Economy	16700.00
0005433367965	1684	Economy	16700.00
0005435653693	1684	Economy	16700.00
0005433368121	1684	Economy	16700.00
0005435653685	1684	Economy	16700.00
0005433368126	1684	Economy	16700.00
0005435653656	1684	Economy	16700.00
0005433367926	1684	Economy	16700.00
0005433368047	1684	Economy	16700.00
0005435653658	1684	Economy	16700.00
0005435653701	1684	Economy	16700.00
0005435653681	1684	Economy	16700.00
0005435653675	1684	Economy	16700.00
0005435653668	1684	Economy	16700.00
0005435653699	1684	Economy	16700.00
0005435653661	1684	Economy	16700.00
0005435653680	1684	Economy	16700.00
0005435653663	1684	Economy	16700.00
0005435653707	1684	Economy	16700.00
0005435653708	1684	Economy	16700.00
0005435653670	1684	Economy	16700.00
0005435653691	1684	Economy	16700.00
0005433368173	1684	Economy	16700.00
0005433368428	21719	Business	50000.00
0005433368415	21719	Business	50000.00
0005435653170	21719	Business	50000.00
0005435653300	21719	Business	50000.00
0005435653396	21719	Business	50000.00
0005435653202	21719	Business	50000.00
0005433368443	21719	Business	50000.00
0005433368422	21719	Business	50000.00
0005435653350	21719	Business	50000.00
0005433368409	21719	Business	50000.00
0005435653260	21719	Business	50000.00
0005435653254	21719	Business	50000.00
0005433368437	21719	Economy	16700.00
0005435653283	21719	Economy	16700.00
0005435653294	21719	Economy	16700.00
0005433368436	21719	Economy	16700.00
0005435653336	21719	Economy	16700.00
0005435653335	21719	Economy	16700.00
0005433368431	21719	Economy	16700.00
0005435653338	21719	Economy	16700.00
0005433368425	21719	Economy	16700.00
0005435653337	21719	Economy	16700.00
0005433368430	21719	Economy	18300.00
0005433368414	21719	Economy	18300.00
0005433368442	21719	Economy	18300.00
0005433368441	21719	Economy	18300.00
0005435653308	21719	Economy	16700.00
0005435653196	21719	Economy	16700.00
0005435653219	21719	Economy	16700.00
0005433368446	21719	Economy	16700.00
0005433368438	21719	Economy	16700.00
0005433368433	21719	Economy	16700.00
0005435653208	21719	Economy	16700.00
0005435653174	21719	Economy	16700.00
0005435653346	21719	Economy	16700.00
0005433368444	21719	Economy	16700.00
0005433368439	21719	Economy	16700.00
0005435653183	21719	Economy	16700.00
0005433368440	21719	Economy	16700.00
0005435653265	21719	Economy	16700.00
0005433368419	21719	Economy	16700.00
0005435653267	21719	Economy	16700.00
0005435653351	21719	Economy	16700.00
0005433368424	21719	Economy	16700.00
0005435653306	21719	Economy	16700.00
0005433368426	21719	Economy	16700.00
0005435653307	21719	Economy	16700.00
0005435653207	21719	Economy	16700.00
0005435653368	21719	Economy	16700.00
0005435653305	21719	Economy	16700.00
0005435653263	21719	Economy	16700.00
0005435653269	21719	Economy	16700.00
0005435653083	21719	Economy	16700.00
0005435653347	21719	Economy	16700.00
0005433368427	21719	Economy	16700.00
0005433368410	21719	Economy	16700.00
0005435653264	21719	Economy	16700.00
0005435653311	21719	Economy	16700.00
0005435653091	21719	Economy	16700.00
0005435653084	21719	Economy	16700.00
0005433368411	21719	Economy	16700.00
0005435653334	21719	Economy	16700.00
0005435653397	21719	Economy	16700.00
0005433368421	21719	Economy	16700.00
0005433368416	21719	Economy	16700.00
0005433368413	21719	Economy	16700.00
0005435653146	21719	Economy	16700.00
0005435653119	21719	Economy	16700.00
0005435653187	21719	Economy	16700.00
0005435653102	21719	Economy	16700.00
0005433368445	21719	Economy	16700.00
0005435653145	21719	Economy	16700.00
0005435653041	21719	Economy	16700.00
0005433368417	21719	Economy	16700.00
0005433368434	21719	Economy	16700.00
0005433368418	21719	Economy	16700.00
0005435653255	21719	Economy	16700.00
0005435653316	21719	Economy	16700.00
0005435653268	21719	Economy	16700.00
0005433368423	21719	Economy	16700.00
0005435653213	21719	Economy	16700.00
0005433368420	21719	Economy	16700.00
0005433368429	21719	Economy	16700.00
0005435653376	21719	Economy	16700.00
0005435653274	21719	Economy	16700.00
0005433368432	21719	Economy	16700.00
0005435653236	21719	Economy	16700.00
0005433368435	21719	Economy	16700.00
0005433368412	21719	Economy	16700.00
0005433986612	4142	Business	21500.00
0005433986643	4142	Business	21500.00
0005433986610	4142	Business	21500.00
0005433986632	4142	Business	21500.00
0005433986602	4142	Business	21500.00
0005433986616	4142	Business	21500.00
0005433986635	4142	Economy	7200.00
0005433986627	4142	Economy	7200.00
0005433986615	4142	Economy	7200.00
0005433986606	4142	Economy	7200.00
0005433986614	4142	Economy	7200.00
0005433986644	4142	Economy	7900.00
0005433986625	4142	Economy	7900.00
0005433986604	4142	Economy	7900.00
0005435788808	4142	Economy	7900.00
0005433986633	4142	Economy	7200.00
0005433986626	4142	Economy	7200.00
0005433986639	4142	Economy	7200.00
0005433986608	4142	Economy	7200.00
0005433986631	4142	Economy	7200.00
0005433986637	4142	Economy	7200.00
0005433986605	4142	Economy	7200.00
0005433986613	4142	Economy	7200.00
0005433986621	4142	Economy	7200.00
0005435788809	4142	Economy	7200.00
0005433986609	4142	Economy	7200.00
0005433986634	4142	Economy	7200.00
0005433986619	4142	Economy	7200.00
0005433986603	4142	Economy	7200.00
0005433986641	4142	Economy	7200.00
0005433986636	4142	Economy	7200.00
0005433986622	4142	Economy	7200.00
0005433986629	4142	Economy	7200.00
0005433986642	4142	Economy	7200.00
0005433986630	4142	Economy	7200.00
0005433986645	4142	Economy	7200.00
0005433986611	4142	Economy	7200.00
0005433986620	4142	Economy	7200.00
0005433986624	4142	Economy	7200.00
0005433986607	4142	Economy	7200.00
0005433986640	4142	Economy	7200.00
0005433986628	4142	Economy	7200.00
0005435788807	4142	Economy	7200.00
0005433986638	4142	Economy	7200.00
0005433986623	4142	Economy	7200.00
0005433986618	4142	Economy	7200.00
0005433986617	4142	Economy	7200.00
0005433986646	4142	Economy	7200.00
0005433985987	25665	Business	21500.00
0005435788785	25665	Economy	7200.00
0005433985989	25665	Economy	7200.00
0005433986131	25665	Economy	7200.00
0005433986121	25665	Economy	7200.00
0005433986080	25665	Economy	7900.00
0005433986114	25665	Economy	7200.00
0005433985990	25665	Economy	7200.00
0005435788786	25665	Economy	7200.00
0005433986039	25665	Economy	7200.00
0005433986109	25665	Economy	7200.00
0005433986108	25665	Economy	7200.00
0005433986087	25665	Economy	7200.00
0005433986120	25665	Economy	7200.00
0005435788787	25665	Economy	7200.00
0005435788792	25665	Economy	7200.00
0005433986058	25665	Economy	7200.00
0005433986130	25665	Economy	7200.00
0005433985916	25665	Economy	7200.00
0005433986086	25665	Economy	7200.00
0005433986115	25665	Economy	7200.00
0005435788791	25665	Economy	7200.00
0005435788781	25665	Economy	7200.00
0005435719569	21287	Economy	9400.00
0005435720833	21287	Economy	9400.00
0005435720832	21287	Economy	9400.00
0005435720827	21287	Economy	9400.00
0005435720828	21287	Economy	9400.00
0005434516103	9028	Economy	26000.00
0005434190411	9028	Economy	26000.00
0005434190420	9028	Economy	26000.00
0005434190410	9028	Economy	23600.00
0005434190416	9028	Economy	23600.00
0005434190412	9028	Economy	23600.00
0005434516110	9028	Economy	23600.00
0005434516105	9028	Economy	23600.00
0005434190415	9028	Economy	23600.00
0005434516107	9028	Economy	23600.00
0005434516112	9028	Economy	23600.00
0005434516104	9028	Economy	23600.00
0005434516106	9028	Economy	23600.00
0005434516111	9028	Economy	23600.00
0005434190419	9028	Economy	23600.00
0005434516109	9028	Economy	23600.00
0005434190417	9028	Economy	23600.00
0005434516108	9028	Economy	23600.00
0005432655598	17828	Business	18000.00
0005432660836	17828	Business	18000.00
0005432655575	17828	Business	18000.00
0005432869627	17828	Business	18000.00
0005432666401	17828	Business	18000.00
0005432655574	17828	Economy	6000.00
0005432664155	17828	Economy	6000.00
0005432665277	17828	Economy	6000.00
0005432665291	17828	Economy	6000.00
0005432663030	17828	Economy	6000.00
0005432655607	17828	Economy	6600.00
0005432655596	17828	Economy	6600.00
0005432657468	17828	Economy	6600.00
0005432657465	17828	Economy	6600.00
0005432869621	17828	Economy	6000.00
0005432661940	17828	Economy	6000.00
0005432661939	17828	Economy	6000.00
0005432660825	17828	Economy	6000.00
0005432658602	17828	Economy	6000.00
0005432666405	17828	Economy	6000.00
0005432659719	17828	Economy	6000.00
0005432655593	17828	Economy	6000.00
0005432869625	17828	Economy	6000.00
0005432869622	17828	Economy	6000.00
0005434151749	17828	Economy	6000.00
0005432664152	17828	Economy	6000.00
0005432666406	17828	Economy	6000.00
0005432869628	17828	Economy	6000.00
0005432655619	17828	Economy	6000.00
0005432664150	17828	Economy	6000.00
0005432664154	17828	Economy	6000.00
0005432663055	17828	Economy	6000.00
0005432666407	17828	Economy	6000.00
0005432666402	17828	Economy	6000.00
0005432657471	17828	Economy	6000.00
0005432664151	17828	Economy	6000.00
0005432655587	17828	Economy	6000.00
0005432655542	17828	Economy	6000.00
0005432869626	17828	Economy	6000.00
0005432667465	17828	Economy	6000.00
0005432660835	17828	Economy	6000.00
0005432665292	17828	Economy	6000.00
0005432655588	17828	Economy	6000.00
0005434151748	17828	Economy	6000.00
0005432655580	17828	Economy	6000.00
0005432655618	17828	Economy	6000.00
0005432869623	17828	Economy	6000.00
0005432869624	17828	Economy	6000.00
0005432655581	17828	Economy	6000.00
0005432655564	17828	Economy	6000.00
0005432661938	17828	Economy	6000.00
0005432869535	26291	Business	18000.00
0005432869547	26291	Business	18000.00
0005432666415	26291	Economy	6000.00
0005432665302	26291	Economy	6000.00
0005432657490	26291	Economy	6000.00
0005432658618	26291	Economy	6600.00
0005432660845	26291	Economy	6600.00
0005432655686	26291	Economy	6000.00
0005434151722	26291	Economy	6000.00
0005432655689	26291	Economy	6000.00
0005432655687	26291	Economy	6000.00
0005432655693	26291	Economy	6000.00
0005432655691	26291	Economy	6000.00
0005432667482	26291	Economy	6000.00
0005432869541	26291	Economy	6000.00
0005432658619	26291	Economy	6000.00
0005432655692	26291	Economy	6000.00
0005432660844	26291	Economy	6000.00
0005432655680	26291	Economy	6000.00
0005432655690	26291	Economy	6000.00
0005432666416	26291	Economy	6000.00
0005434151721	26291	Economy	6000.00
0005432659733	26291	Economy	6000.00
0005432667480	26291	Economy	6000.00
0005432869512	26291	Economy	6000.00
0005432655681	26291	Economy	6000.00
0005432659734	26291	Economy	6000.00
0005432667481	26291	Economy	6000.00
0005432655685	26291	Economy	6000.00
0005432655682	26291	Economy	6000.00
0005432869533	26291	Economy	6000.00
0005432655684	26291	Economy	6000.00
0005432869534	26291	Economy	6000.00
0005432657491	26291	Economy	6000.00
0005432655688	26291	Economy	6000.00
0005432655683	26291	Economy	6000.00
0005432329382	3102	Business	16100.00
0005432329386	3102	Business	16100.00
0005432329388	3102	Business	16100.00
0005432329365	3102	Business	16100.00
0005432848840	3102	Business	16100.00
0005432329357	3102	Business	16100.00
0005432329392	3102	Economy	5400.00
0005432329376	3102	Economy	5400.00
0005432329369	3102	Economy	5900.00
0005432329391	3102	Economy	5900.00
0005432287261	3102	Economy	5900.00
0005432287262	3102	Economy	5400.00
0005432329393	3102	Economy	5400.00
0005432329363	3102	Economy	5400.00
0005432329387	3102	Economy	5400.00
0005432329347	3102	Economy	5400.00
0005432329354	3102	Economy	5400.00
0005432329379	3102	Economy	5400.00
0005432329390	3102	Economy	5400.00
0005432329383	3102	Economy	5400.00
0005432329380	3102	Economy	5400.00
0005432287265	3102	Economy	5400.00
0005432329375	3102	Economy	5400.00
0005432329385	3102	Economy	5400.00
0005432329377	3102	Economy	5400.00
0005432329362	3102	Economy	5400.00
0005432329350	3102	Economy	5400.00
0005432329351	3102	Economy	5400.00
0005432329378	3102	Economy	5400.00
0005432329384	3102	Economy	5400.00
0005432329370	3102	Economy	5400.00
0005432329389	3102	Economy	5400.00
0005432329367	3102	Economy	5400.00
0005432329355	3102	Economy	5400.00
0005432329371	3102	Economy	5400.00
0005432329360	3102	Economy	5400.00
0005432329366	3102	Economy	5400.00
0005432329374	3102	Economy	5400.00
0005432329359	3102	Economy	5400.00
0005432329381	3102	Economy	5400.00
0005432329356	3102	Economy	5400.00
0005432329353	3102	Economy	5400.00
0005432329373	3102	Economy	5400.00
0005432329361	3102	Economy	5400.00
0005432329368	3102	Economy	5400.00
0005432329364	3102	Economy	5400.00
0005432329348	3102	Economy	5400.00
0005432329349	3102	Economy	5400.00
0005432329372	3102	Economy	5400.00
0005432329358	3102	Economy	5400.00
0005432287263	3102	Economy	5400.00
0005432287264	3102	Economy	5400.00
0005432329352	3102	Economy	5400.00
0005432329011	31135	Business	16100.00
0005432328885	31135	Business	16100.00
0005432328861	31135	Business	16100.00
0005432328921	31135	Business	16100.00
0005432328735	31135	Business	16100.00
0005432329017	31135	Business	16100.00
0005432329070	31135	Business	16100.00
0005432328863	31135	Business	16100.00
0005432328924	31135	Economy	5400.00
0005432328862	31135	Economy	5400.00
0005433438931	31135	Economy	5400.00
0005432328901	31135	Economy	5400.00
0005432328738	31135	Economy	5400.00
0005432328962	31135	Economy	5900.00
0005432328949	31135	Economy	5400.00
0005432328785	31135	Economy	5400.00
0005432328797	31135	Economy	5400.00
0005432328859	31135	Economy	5400.00
0005432328850	31135	Economy	5400.00
0005432328946	31135	Economy	5400.00
0005432328742	31135	Economy	5400.00
0005432329012	31135	Economy	5400.00
0005432328963	31135	Economy	5400.00
0005433438930	31135	Economy	5400.00
0005432328922	31135	Economy	5400.00
0005432328964	31135	Economy	5400.00
0005432905211	31135	Economy	5400.00
0005432328959	31135	Economy	5400.00
0005433438912	31135	Economy	5400.00
0005432905210	31135	Economy	5400.00
0005432054347	31135	Economy	5400.00
0005432328925	31135	Economy	5400.00
0005432328961	31135	Economy	5400.00
0005432328953	31135	Economy	5400.00
0005432328884	31135	Economy	5400.00
0005432905212	31135	Economy	5400.00
0005432329000	31135	Economy	5400.00
0005432328899	31135	Economy	5400.00
0005433438965	31135	Economy	5400.00
0005432054346	31135	Economy	5400.00
0005433438928	31135	Economy	5400.00
0005432328824	31135	Economy	5400.00
0005432328737	31135	Economy	5400.00
0005432328743	31135	Economy	5400.00
0005433438915	31135	Economy	5400.00
0005432329096	31135	Economy	5400.00
0005432054348	31135	Economy	5400.00
0005432328920	31135	Economy	5400.00
0005432328937	31135	Economy	5400.00
0005432328947	31135	Economy	5400.00
0005432905213	31135	Economy	5400.00
0005432329013	31135	Economy	5400.00
0005432328799	31135	Economy	5400.00
0005432328736	31135	Economy	5400.00
0005432328923	31135	Economy	5400.00
0005432329107	31135	Economy	5400.00
0005432328945	31135	Economy	5400.00
0005432328851	31135	Economy	5400.00
0005432328864	31135	Economy	5400.00
0005432328844	31135	Economy	5400.00
0005433438929	31135	Economy	5400.00
0005435487907	6229	Business	124600.00
0005435999504	6229	Business	124600.00
0005435999488	6229	Business	124600.00
0005434309944	6229	Business	124600.00
0005435487970	6229	Business	124600.00
0005435999507	6229	Business	124600.00
0005435488052	6229	Business	124600.00
0005434309941	6229	Economy	41500.00
0005435487906	6229	Economy	41500.00
0005435297117	6229	Economy	41500.00
0005434309937	6229	Economy	41500.00
0005435999508	6229	Economy	41500.00
0005434309947	6229	Economy	41500.00
0005435999491	6229	Economy	41500.00
0005434309946	6229	Economy	41500.00
0005435487908	6229	Economy	41500.00
0005435487954	6229	Economy	41500.00
0005435487890	6229	Economy	41500.00
0005435487950	6229	Economy	41500.00
0005434309943	6229	Economy	41500.00
0005434309939	6229	Economy	41500.00
0005435999501	6229	Economy	41500.00
0005434309942	6229	Economy	41500.00
0005435488010	6229	Economy	41500.00
0005435999502	6229	Economy	45700.00
0005435999498	6229	Economy	45700.00
0005435487949	6229	Economy	45700.00
0005435999492	6229	Economy	41500.00
0005435487857	6229	Economy	41500.00
0005435999509	6229	Economy	41500.00
0005435999503	6229	Economy	41500.00
0005435999496	6229	Economy	41500.00
0005435999487	6229	Economy	41500.00
0005434309936	6229	Economy	41500.00
0005434309940	6229	Economy	41500.00
0005432146230	6229	Economy	41500.00
0005434309938	6229	Economy	41500.00
0005435999506	6229	Economy	41500.00
0005435297115	6229	Economy	41500.00
0005434309945	6229	Economy	41500.00
0005435999493	6229	Economy	41500.00
0005432146229	6229	Economy	41500.00
0005435999486	6229	Economy	41500.00
0005435999499	6229	Economy	41500.00
0005435999489	6229	Economy	41500.00
0005435999500	6229	Economy	41500.00
0005435297116	6229	Economy	41500.00
0005435999505	6229	Economy	41500.00
0005435999495	6229	Economy	41500.00
0005435999494	6229	Economy	41500.00
0005435488011	6229	Economy	41500.00
0005435487987	6229	Economy	41500.00
0005435999490	6229	Economy	41500.00
0005435297089	6229	Economy	41500.00
0005435487819	6229	Economy	41500.00
0005435487971	6229	Economy	41500.00
0005435999497	6229	Economy	41500.00
0005435999485	6229	Economy	41500.00
0005432146228	6229	Economy	41500.00
0005434309948	6229	Economy	41500.00
0005434309935	6229	Economy	41500.00
0005435297097	6229	Economy	41500.00
0005435999336	19554	Business	124600.00
0005435297160	19554	Business	124600.00
0005435488124	19554	Business	124600.00
0005435999323	19554	Business	124600.00
0005435488123	19554	Business	124600.00
0005435488127	19554	Business	124600.00
0005435297156	19554	Business	124600.00
0005435488137	19554	Economy	41500.00
0005435999351	19554	Economy	41500.00
0005434309819	19554	Economy	41500.00
0005434309804	19554	Economy	41500.00
0005435488122	19554	Economy	41500.00
0005435488138	19554	Economy	41500.00
0005435999334	19554	Economy	41500.00
0005435999346	19554	Economy	41500.00
0005435999228	19554	Economy	41500.00
0005434309820	19554	Economy	41500.00
0005435488128	19554	Economy	41500.00
0005435488136	19554	Economy	41500.00
0005435999371	19554	Economy	41500.00
0005435999333	19554	Economy	41500.00
0005435999327	19554	Economy	41500.00
0005435297162	19554	Economy	41500.00
0005435999332	19554	Economy	41500.00
0005435488120	19554	Economy	45700.00
0005435488135	19554	Economy	45700.00
0005435488126	19554	Economy	45700.00
0005435999377	19554	Economy	45700.00
0005435297159	19554	Economy	45700.00
0005435488131	19554	Economy	41500.00
0005435488134	19554	Economy	41500.00
0005434309808	19554	Economy	41500.00
0005435488121	19554	Economy	41500.00
0005435297155	19554	Economy	41500.00
0005435488139	19554	Economy	41500.00
0005435999229	19554	Economy	41500.00
0005435488132	19554	Economy	41500.00
0005434309823	19554	Economy	41500.00
0005435488130	19554	Economy	41500.00
0005435297158	19554	Economy	41500.00
0005435297157	19554	Economy	41500.00
0005435999326	19554	Economy	41500.00
0005435488133	19554	Economy	41500.00
0005435999341	19554	Economy	41500.00
0005435999324	19554	Economy	41500.00
0005434309822	19554	Economy	41500.00
0005435999353	19554	Economy	41500.00
0005435297161	19554	Economy	41500.00
0005435999352	19554	Economy	41500.00
0005435488125	19554	Economy	41500.00
0005435999375	19554	Economy	41500.00
0005435488119	19554	Economy	41500.00
0005435488129	19554	Economy	41500.00
0005435999376	19554	Economy	41500.00
0005434309788	19554	Economy	41500.00
0005435518176	1551	Business	86000.00
0005435508515	1551	Business	86000.00
0005433186176	1551	Business	86000.00
0005434566106	1551	Business	86000.00
0005435502627	1551	Business	86000.00
0005435502628	1551	Business	86000.00
0005435518197	1551	Business	86000.00
0005435518186	1551	Business	86000.00
0005434566107	1551	Business	86000.00
0005435518191	1551	Business	86000.00
0005435502638	1551	Business	86000.00
0005435518181	1551	Business	86000.00
0005435502637	1551	Economy	28700.00
0005435502624	1551	Economy	28700.00
0005435508533	1551	Economy	28700.00
0005435502620	1551	Economy	28700.00
0005435502632	1551	Economy	28700.00
0005435508525	1551	Economy	28700.00
0005435502626	1551	Economy	28700.00
0005432291964	1551	Economy	28700.00
0005435508516	1551	Economy	28700.00
0005435508527	1551	Economy	31500.00
0005435502633	1551	Economy	31500.00
0005435508530	1551	Economy	31500.00
0005435502629	1551	Economy	28700.00
0005434566113	1551	Economy	28700.00
0005435502619	1551	Economy	28700.00
0005434566108	1551	Economy	28700.00
0005435518183	1551	Economy	28700.00
0005435518188	1551	Economy	28700.00
0005435508519	1551	Economy	28700.00
0005434566111	1551	Economy	28700.00
0005433186155	1551	Economy	28700.00
0005435502621	1551	Economy	28700.00
0005434566110	1551	Economy	28700.00
0005435502631	1551	Economy	28700.00
0005435508524	1551	Economy	28700.00
0005433186194	1551	Economy	28700.00
0005435518182	1551	Economy	28700.00
0005435508517	1551	Economy	28700.00
0005435518195	1551	Economy	28700.00
0005435518178	1551	Economy	28700.00
0005435508520	1551	Economy	28700.00
0005435518185	1551	Economy	28700.00
0005432291966	1551	Economy	28700.00
0005434566109	1551	Economy	28700.00
0005435518192	1551	Economy	28700.00
0005435502636	1551	Economy	28700.00
0005435508528	1551	Economy	28700.00
0005435518180	1551	Economy	28700.00
0005434566116	1551	Economy	28700.00
0005435502618	1551	Economy	28700.00
0005435518189	1551	Economy	28700.00
0005435502634	1551	Economy	28700.00
0005435508522	1551	Economy	28700.00
0005435502640	1551	Economy	28700.00
0005434566115	1551	Economy	28700.00
0005435518179	1551	Economy	28700.00
0005435502622	1551	Economy	28700.00
0005435502635	1551	Economy	28700.00
0005435508532	1551	Economy	28700.00
0005434566114	1551	Economy	28700.00
0005435508529	1551	Economy	28700.00
0005435502630	1551	Economy	28700.00
0005435508523	1551	Economy	28700.00
0005435518184	1551	Economy	28700.00
0005433186195	1551	Economy	28700.00
0005435502623	1551	Economy	28700.00
0005435518194	1551	Economy	28700.00
0005435502639	1551	Economy	28700.00
0005435518177	1551	Economy	28700.00
0005435508518	1551	Economy	28700.00
0005433186221	1551	Economy	28700.00
0005435508526	1551	Economy	28700.00
0005435502625	1551	Economy	28700.00
0005435508531	1551	Economy	28700.00
0005434566112	1551	Economy	28700.00
0005433186190	1551	Economy	28700.00
0005435508521	1551	Economy	28700.00
0005435518187	1551	Economy	28700.00
0005433186169	1551	Economy	28700.00
0005435518190	1551	Economy	28700.00
0005435518196	1551	Economy	28700.00
0005435518193	1551	Economy	28700.00
0005434566117	1551	Economy	28700.00
0005432291965	1551	Economy	28700.00
0005435529401	20855	Business	86000.00
0005433186246	20855	Business	86000.00
0005435529313	20855	Business	86000.00
0005433186244	20855	Business	86000.00
0005435502458	20855	Business	86000.00
0005435502506	20855	Business	86000.00
0005435529331	20855	Business	86000.00
0005435529491	20855	Business	86000.00
0005435529399	20855	Business	86000.00
0005435502468	20855	Economy	28700.00
0005435502392	20855	Economy	28700.00
0005435502379	20855	Economy	28700.00
0005435529404	20855	Economy	28700.00
0005435529402	20855	Economy	28700.00
0005435502333	20855	Economy	28700.00
0005434565999	20855	Economy	28700.00
0005435529371	20855	Economy	28700.00
0005435502391	20855	Economy	28700.00
0005434566014	20855	Economy	31500.00
0005433186241	20855	Economy	31500.00
0005435502351	20855	Economy	31500.00
0005435529412	20855	Economy	28700.00
0005435529370	20855	Economy	28700.00
0005435529411	20855	Economy	28700.00
0005435529433	20855	Economy	28700.00
0005435529434	20855	Economy	28700.00
0005435502472	20855	Economy	28700.00
0005435529403	20855	Economy	28700.00
0005435502453	20855	Economy	28700.00
0005434566026	20855	Economy	28700.00
0005435502421	20855	Economy	28700.00
0005435502337	20855	Economy	28700.00
0005435529372	20855	Economy	28700.00
0005435502439	20855	Economy	28700.00
0005434565970	20855	Economy	28700.00
0005435502327	20855	Economy	28700.00
0005435529314	20855	Economy	28700.00
0005435502473	20855	Economy	28700.00
0005435502380	20855	Economy	28700.00
0005435502465	20855	Economy	28700.00
0005435529390	20855	Economy	28700.00
0005433186247	20855	Economy	28700.00
0005435502457	20855	Economy	28700.00
0005435529353	20855	Economy	28700.00
0005434565983	20855	Economy	28700.00
0005435502492	20855	Economy	28700.00
0005435502336	20855	Economy	28700.00
0005435502493	20855	Economy	28700.00
0005435529301	20855	Economy	28700.00
0005435502440	20855	Economy	28700.00
0005435502443	20855	Economy	28700.00
0005433186240	20855	Economy	28700.00
0005435502466	20855	Economy	28700.00
0005434565968	20855	Economy	28700.00
0005433186242	20855	Economy	28700.00
0005434565971	20855	Economy	28700.00
0005433186245	20855	Economy	28700.00
0005434565969	20855	Economy	28700.00
0005433186243	20855	Economy	28700.00
0005435529338	20855	Economy	28700.00
0005435529349	20855	Economy	28700.00
0005435545767	20855	Economy	28700.00
0005435502507	20855	Economy	28700.00
0005435502334	20855	Economy	28700.00
0005435502350	20855	Economy	28700.00
0005434565984	20855	Economy	28700.00
0005434565998	20855	Economy	28700.00
0005435502456	20855	Economy	28700.00
0005434566020	20855	Economy	28700.00
0005435931639	3929	Economy	21600.00
0005435153841	3929	Economy	21600.00
0005435931619	3929	Economy	19700.00
0005435153836	3929	Economy	19700.00
0005435153837	3929	Economy	19700.00
0005435153840	3929	Economy	19700.00
0005435931627	3929	Economy	19700.00
0005435153839	3929	Economy	19700.00
0005435931640	3929	Economy	19700.00
0005435153838	3929	Economy	19700.00
0005435153776	21879	Economy	19700.00
0005435153778	21879	Economy	19700.00
0005435931657	21879	Economy	19700.00
0005435931654	21879	Economy	19700.00
0005435931655	21879	Economy	19700.00
0005435153794	21879	Economy	19700.00
0005435153777	21879	Economy	19700.00
0005435931656	21879	Economy	19700.00
0005435153795	21879	Economy	19700.00
0005435153772	21879	Economy	19700.00
0005432629058	7199	Economy	14300.00
0005435225633	7199	Economy	14300.00
0005435225615	7199	Economy	13000.00
0005432629065	7199	Economy	13000.00
0005432629056	7199	Economy	13000.00
0005432629067	7199	Economy	13000.00
0005432629069	7199	Economy	13000.00
0005432629064	7199	Economy	13000.00
0005432629066	7199	Economy	13000.00
0005435225639	7199	Economy	13000.00
0005432629060	7199	Economy	13000.00
0005435225625	7199	Economy	13000.00
0005435225651	7199	Economy	13000.00
0005432629062	7199	Economy	13000.00
0005432629068	7199	Economy	13000.00
0005435225605	7199	Economy	13000.00
0005432629061	7199	Economy	13000.00
0005432629063	7199	Economy	13000.00
0005435225624	7199	Economy	13000.00
0005435225631	7199	Economy	13000.00
0005435225632	7199	Economy	13000.00
0005432629057	7199	Economy	13000.00
0005432629059	7199	Economy	13000.00
0005435225698	28132	Economy	14300.00
0005432628966	28132	Economy	14300.00
0005435225705	28132	Economy	13000.00
0005432628988	28132	Economy	13000.00
0005435225702	28132	Economy	13000.00
0005432628967	28132	Economy	13000.00
0005435225699	28132	Economy	13000.00
0005432628859	28132	Economy	13000.00
0005435225703	28132	Economy	13000.00
0005435225704	28132	Economy	13000.00
0005435225700	28132	Economy	13000.00
0005435225701	28132	Economy	13000.00
0005432628981	28132	Economy	13000.00
0005432629000	28132	Economy	13000.00
0005434267980	8716	Economy	10500.00
0005435960107	8716	Economy	10500.00
0005434267977	8716	Economy	10500.00
0005434267970	8716	Economy	10500.00
0005434267981	8716	Economy	10500.00
0005435960105	8716	Economy	10500.00
0005435960106	8716	Economy	10500.00
0005434267979	8716	Economy	10500.00
0005435960085	15261	Economy	11500.00
0005435960083	15261	Economy	10500.00
0005435960061	15261	Economy	10500.00
0005435960066	15261	Economy	10500.00
0005435960084	15261	Economy	10500.00
0005434268006	15261	Economy	10500.00
0005434268005	15261	Economy	10500.00
0005434268007	15261	Economy	10500.00
0005432675354	1208	Business	115000.00
0005432693493	1208	Business	115000.00
0005432693490	1208	Business	115000.00
0005432693480	1208	Business	115000.00
0005432693485	1208	Business	115000.00
0005432677626	1208	Business	115000.00
0005432693499	1208	Business	115000.00
0005432873332	1208	Business	115000.00
0005432693479	1208	Business	115000.00
0005432693504	1208	Business	115000.00
0005432675355	1208	Business	115000.00
0005432677629	1208	Business	115000.00
0005432693506	1208	Business	115000.00
0005432693496	1208	Business	115000.00
0005432693484	1208	Business	115000.00
0005432675360	1208	Economy	38300.00
0005432873342	1208	Economy	38300.00
0005432677627	1208	Economy	38300.00
0005432693492	1208	Economy	38300.00
0005432693475	1208	Economy	38300.00
0005432693497	1208	Economy	38300.00
0005432693489	1208	Economy	38300.00
0005432693505	1208	Economy	42200.00
0005432693487	1208	Economy	42200.00
0005432873356	1208	Economy	42200.00
0005432693495	1208	Economy	42200.00
0005432677625	1208	Economy	38300.00
0005432693486	1208	Economy	38300.00
0005432675348	1208	Economy	38300.00
0005432675352	1208	Economy	38300.00
0005432693491	1208	Economy	38300.00
0005432693498	1208	Economy	38300.00
0005432675350	1208	Economy	38300.00
0005432693501	1208	Economy	38300.00
0005432675357	1208	Economy	38300.00
0005432693500	1208	Economy	38300.00
0005432693502	1208	Economy	38300.00
0005432675353	1208	Economy	38300.00
0005432693482	1208	Economy	38300.00
0005432677628	1208	Economy	38300.00
0005432873341	1208	Economy	38300.00
0005432675358	1208	Economy	38300.00
0005432693481	1208	Economy	38300.00
0005432693483	1208	Economy	38300.00
0005432693477	1208	Economy	38300.00
0005432693474	1208	Economy	38300.00
0005432873355	1208	Economy	38300.00
0005432693503	1208	Economy	38300.00
0005432675356	1208	Economy	38300.00
0005432693488	1208	Economy	38300.00
0005432675349	1208	Economy	38300.00
0005432693478	1208	Economy	38300.00
0005432675351	1208	Economy	38300.00
0005432693476	1208	Economy	38300.00
0005432693494	1208	Economy	38300.00
0005432675359	1208	Economy	38300.00
0005432693127	17472	Business	115000.00
0005432873396	17472	Business	115000.00
0005432675223	17472	Business	115000.00
0005432693247	17472	Business	115000.00
0005432693192	17472	Business	115000.00
0005432693224	17472	Business	115000.00
0005432675191	17472	Business	115000.00
0005432675210	17472	Business	115000.00
0005432675227	17472	Business	115000.00
0005432693128	17472	Business	115000.00
0005432693250	17472	Business	115000.00
0005432675206	17472	Business	115000.00
0005432675166	17472	Business	115000.00
0005432693221	17472	Economy	38300.00
0005432693169	17472	Economy	38300.00
0005432693259	17472	Economy	38300.00
0005432693153	17472	Economy	38300.00
0005432693154	17472	Economy	38300.00
0005432675189	17472	Economy	38300.00
0005432693208	17472	Economy	42200.00
0005432693311	17472	Economy	42200.00
0005432693203	17472	Economy	42200.00
0005432693293	17472	Economy	38300.00
0005432675281	17472	Economy	38300.00
0005432675282	17472	Economy	38300.00
0005432873395	17472	Economy	38300.00
0005432693202	17472	Economy	38300.00
0005432693191	17472	Economy	38300.00
0005432693216	17472	Economy	38300.00
0005432693144	17472	Economy	38300.00
0005432693225	17472	Economy	38300.00
0005432873392	17472	Economy	38300.00
0005432693294	17472	Economy	38300.00
0005432675204	17472	Economy	38300.00
0005432693133	17472	Economy	38300.00
0005432675167	17472	Economy	38300.00
0005432675165	17472	Economy	38300.00
0005432675270	17472	Economy	38300.00
0005432693222	17472	Economy	38300.00
0005432693230	17472	Economy	38300.00
0005432693185	17472	Economy	38300.00
0005432693166	17472	Economy	38300.00
0005432873398	17472	Economy	38300.00
0005432693209	17472	Economy	38300.00
0005432675222	17472	Economy	38300.00
0005432675190	17472	Economy	38300.00
0005432693170	17472	Economy	38300.00
0005432693152	17472	Economy	38300.00
0005432873393	17472	Economy	38300.00
0005432693210	17472	Economy	38300.00
0005432693076	17472	Economy	38300.00
0005432693167	17472	Economy	38300.00
0005432693312	17472	Economy	38300.00
0005432873397	17472	Economy	38300.00
0005432873394	17472	Economy	38300.00
0005432693194	17472	Economy	38300.00
0005434435405	1126	Economy	15200.00
0005434435404	1126	Economy	15200.00
0005433156841	1126	Economy	15200.00
0005434435402	1126	Economy	13900.00
0005433156836	1126	Economy	13900.00
0005434435407	1126	Economy	13900.00
0005434435412	1126	Economy	13900.00
0005434435403	1126	Economy	13900.00
0005434435410	1126	Economy	13900.00
0005434435409	1126	Economy	13900.00
0005434435400	1126	Economy	13900.00
0005434435413	1126	Economy	13900.00
0005434435411	1126	Economy	13900.00
0005434435401	1126	Economy	13900.00
0005433156813	1126	Economy	13900.00
0005434435406	1126	Economy	13900.00
0005433156835	1126	Economy	13900.00
0005433156832	1126	Economy	13900.00
0005433156800	1126	Economy	13900.00
0005434435408	1126	Economy	13900.00
0005434435265	17309	Economy	15200.00
0005434435302	17309	Economy	15200.00
0005433156876	17309	Economy	15200.00
0005434435297	17309	Economy	13900.00
0005433156877	17309	Economy	13900.00
0005434435232	17309	Economy	13900.00
0005434435267	17309	Economy	13900.00
0005434435315	17309	Economy	13900.00
0005433156874	17309	Economy	13900.00
0005433156875	17309	Economy	13900.00
0005433156872	17309	Economy	13900.00
0005434435303	17309	Economy	13900.00
0005434435262	17309	Economy	13900.00
0005434435316	17309	Economy	13900.00
0005433156873	17309	Economy	13900.00
0005434435259	17309	Economy	13900.00
0005433156879	17309	Economy	13900.00
0005433156878	17309	Economy	13900.00
0005433156871	17309	Economy	13900.00
0005435928168	4093	Economy	8200.00
0005435086943	4093	Economy	7500.00
0005435086942	4093	Economy	7500.00
0005435928152	4093	Economy	7500.00
0005435928173	4093	Economy	7500.00
0005435086944	4093	Economy	7500.00
0005435928163	4093	Economy	7500.00
0005435086948	4093	Economy	7500.00
0005435086941	4093	Economy	7500.00
0005435928169	4093	Economy	7500.00
0005435086946	4093	Economy	7500.00
0005435086947	4093	Economy	7500.00
0005435928170	4093	Economy	7500.00
0005435086945	4093	Economy	7500.00
0005435928171	4093	Economy	7500.00
0005435928172	4093	Economy	7500.00
0005435928213	24420	Economy	8200.00
0005435086860	24420	Economy	8200.00
0005435928215	24420	Economy	7500.00
0005435928214	24420	Economy	7500.00
0005435086862	24420	Economy	7500.00
0005435086859	24420	Economy	7500.00
0005435086835	24420	Economy	7500.00
0005435086893	24420	Economy	7500.00
0005435551616	11070	Business	144300.00
0005435098567	11070	Business	144300.00
0005435098568	11070	Business	144300.00
0005435098557	11070	Business	144300.00
0005435098545	11070	Business	144300.00
0005435551617	11070	Business	144300.00
0005435551637	11070	Economy	48100.00
0005435551631	11070	Economy	48100.00
0005435551636	11070	Economy	48100.00
0005435551621	11070	Economy	48100.00
0005435551639	11070	Economy	48100.00
0005435551640	11070	Economy	48100.00
0005435551615	11070	Economy	48100.00
0005435551638	11070	Economy	48100.00
0005435551632	11070	Economy	48100.00
0005435551641	11070	Economy	48100.00
0005435551628	11070	Economy	48100.00
0005435098546	11070	Economy	48100.00
0005435551627	11070	Economy	48100.00
0005435551598	11070	Economy	48100.00
0005435551604	11070	Economy	48100.00
0005435551619	11070	Economy	48100.00
0005435098566	11070	Economy	48100.00
0005435098569	11070	Economy	48100.00
0005435551670	17002	Business	144300.00
0005435551681	17002	Business	144300.00
0005435551665	17002	Economy	52900.00
0005435098588	17002	Economy	48100.00
0005435551680	17002	Economy	48100.00
0005435551675	17002	Economy	48100.00
0005435551677	17002	Economy	48100.00
0005435551678	17002	Economy	48100.00
0005435551667	17002	Economy	48100.00
0005435551679	17002	Economy	48100.00
0005435098586	17002	Economy	48100.00
0005435098583	17002	Economy	48100.00
0005435551676	17002	Economy	48100.00
0005435098585	17002	Economy	48100.00
0005435551672	17002	Economy	52900.00
0005435551671	17002	Economy	48100.00
0005435551682	17002	Economy	48100.00
0005435098584	17002	Economy	48100.00
0005435551673	17002	Economy	48100.00
0005435551669	17002	Economy	48100.00
0005435551666	17002	Economy	48100.00
0005435551674	17002	Economy	48100.00
0005435098587	17002	Economy	48100.00
0005435551668	17002	Economy	48100.00
0005434964336	18256	Business	203300.00
0005434964312	18256	Business	203300.00
0005434964303	18256	Business	203300.00
0005434964290	18256	Business	203300.00
0005434964335	18256	Business	203300.00
0005434964307	18256	Business	203300.00
0005434964397	18256	Business	203300.00
0005434964327	18256	Business	203300.00
0005433261701	18256	Business	203300.00
0005433261705	18256	Business	203300.00
0005434964369	18256	Business	203300.00
0005433261704	18256	Business	203300.00
0005433261700	18256	Economy	74500.00
0005433261706	18256	Economy	74500.00
0005434964438	18256	Economy	67800.00
0005433261712	18256	Economy	67800.00
0005434964354	18256	Economy	67800.00
0005433261718	18256	Economy	67800.00
0005434964282	18256	Economy	67800.00
0005434964311	18256	Economy	67800.00
0005433261717	18256	Economy	67800.00
0005434964315	18256	Economy	67800.00
0005433261710	18256	Economy	67800.00
0005434964266	18256	Economy	67800.00
0005433261716	18256	Economy	67800.00
0005433261703	18256	Economy	67800.00
0005434964306	18256	Economy	67800.00
0005434964267	18256	Economy	67800.00
0005434964364	18256	Economy	67800.00
0005434964237	18256	Economy	67800.00
0005434964305	18256	Economy	67800.00
0005434964316	18256	Economy	67800.00
0005434964361	18256	Economy	67800.00
0005434964387	18256	Economy	67800.00
0005433261720	18256	Economy	67800.00
0005434964398	18256	Economy	67800.00
0005433261714	18256	Economy	67800.00
0005434964363	18256	Economy	67800.00
0005433261707	18256	Economy	67800.00
0005434964324	18256	Economy	74500.00
0005434964337	18256	Economy	67800.00
0005433261713	18256	Economy	67800.00
0005433261711	18256	Economy	67800.00
0005434964302	18256	Economy	67800.00
0005433261708	18256	Economy	67800.00
0005434964326	18256	Economy	67800.00
0005433261709	18256	Economy	67800.00
0005434964238	18256	Economy	67800.00
0005434964325	18256	Economy	67800.00
0005434964291	18256	Economy	67800.00
0005434964390	18256	Economy	67800.00
0005433261702	18256	Economy	67800.00
0005434964274	18256	Economy	67800.00
0005434964289	18256	Economy	67800.00
0005433261719	18256	Economy	67800.00
0005434964328	18256	Economy	67800.00
0005434964301	18256	Economy	67800.00
0005434964286	18256	Economy	67800.00
0005434964389	18256	Economy	67800.00
0005434964334	18256	Economy	67800.00
0005434964314	18256	Economy	67800.00
0005434964283	18256	Economy	67800.00
0005434964273	18256	Economy	67800.00
0005434964231	18256	Economy	67800.00
0005433261715	18256	Economy	67800.00
0005433194871	4853	Business	44200.00
0005435907529	4853	Business	44200.00
0005434626104	4853	Business	44200.00
0005433194872	4853	Economy	14700.00
0005434626097	4853	Economy	14700.00
0005434626105	4853	Economy	16200.00
0005434626100	4853	Economy	14700.00
0005435907530	4853	Economy	14700.00
0005434626095	4853	Economy	14700.00
0005435907540	4853	Economy	14700.00
0005434626096	4853	Economy	14700.00
0005435907521	4853	Economy	14700.00
0005434626101	4853	Economy	14700.00
0005434626103	4853	Economy	14700.00
0005434626102	4853	Economy	14700.00
0005434626098	4853	Economy	14700.00
0005433194887	4853	Economy	14700.00
0005435907520	4853	Economy	14700.00
0005435907531	4853	Economy	14700.00
0005434626099	4853	Economy	14700.00
0005435907576	32898	Economy	14700.00
0005435907577	32898	Economy	16200.00
0005435907578	32898	Economy	14700.00
0005434626011	32898	Economy	14700.00
0005435907574	32898	Economy	14700.00
0005434626025	32898	Economy	14700.00
0005435907575	32898	Economy	14700.00
0005434626026	32898	Economy	14700.00
0005434626062	32898	Economy	14700.00
0005434626047	32898	Economy	14700.00
0005434626048	32898	Economy	14700.00
0005434626014	32898	Economy	14700.00
0005434625991	32898	Economy	14700.00
0005434626010	32898	Economy	14700.00
0005435785568	13792	Economy	3400.00
0005435785472	13792	Economy	3400.00
0005435785459	13792	Economy	3400.00
0005435937447	13792	Economy	3100.00
0005435785405	13792	Economy	3100.00
0005435785574	13792	Economy	3100.00
0005435785530	13792	Economy	3100.00
0005435785531	13792	Economy	3100.00
0005435785569	13792	Economy	3100.00
0005435785408	13792	Economy	3100.00
0005435785516	13792	Economy	3100.00
0005435785563	13792	Economy	3100.00
0005435937446	13792	Economy	3100.00
0005435785523	13792	Economy	3100.00
0005435785457	13792	Economy	3100.00
0005435937443	13792	Economy	3100.00
0005435785368	13792	Economy	3100.00
0005435785425	13792	Economy	3100.00
0005435785492	13792	Economy	3100.00
0005435785456	13792	Economy	3100.00
0005435937445	13792	Economy	3100.00
0005435785660	13792	Economy	3100.00
0005435785388	13792	Economy	3100.00
0005435785648	13792	Economy	3100.00
0005435937441	13792	Economy	3100.00
0005435785580	13792	Economy	3100.00
0005435785469	13792	Economy	3100.00
0005435785653	13792	Economy	3100.00
0005435937444	13792	Economy	3100.00
0005435785470	13792	Economy	3100.00
0005435785508	13792	Economy	3100.00
0005435937442	13792	Economy	3100.00
0005435785517	13792	Economy	3100.00
0005435785578	13792	Economy	3100.00
0005435785566	13792	Economy	3100.00
0005435785593	13792	Economy	3100.00
0005435785504	13792	Economy	3100.00
0005435785592	13792	Economy	3100.00
0005435785546	13792	Economy	3100.00
0005435785575	13792	Economy	3100.00
0005435785369	13792	Economy	3100.00
0005435937391	27430	Economy	3400.00
0005435785799	27430	Economy	3400.00
0005435785810	27430	Economy	3400.00
0005435785808	27430	Economy	3400.00
0005435785801	27430	Economy	3100.00
0005435785798	27430	Economy	3100.00
0005435937399	27430	Economy	3100.00
0005435785813	27430	Economy	3100.00
0005435785792	27430	Economy	3100.00
0005435785797	27430	Economy	3100.00
0005435785823	27430	Economy	3100.00
0005435785826	27430	Economy	3100.00
0005432190678	27430	Economy	3100.00
0005435785820	27430	Economy	3100.00
0005435785814	27430	Economy	3100.00
0005435787383	27430	Economy	3100.00
0005435785825	27430	Economy	3100.00
0005432190680	27430	Economy	3100.00
0005435785816	27430	Economy	3100.00
0005435785818	27430	Economy	3100.00
0005435785794	27430	Economy	3100.00
0005435785812	27430	Economy	3100.00
0005435785804	27430	Economy	3100.00
0005432190679	27430	Economy	3100.00
0005435787384	27430	Economy	3100.00
0005435785800	27430	Economy	3100.00
0005435785803	27430	Economy	3100.00
0005435785817	27430	Economy	3100.00
0005435785802	27430	Economy	3100.00
0005435937398	27430	Economy	3100.00
0005435937397	27430	Economy	3100.00
0005435785809	27430	Economy	3100.00
0005432190681	27430	Economy	3100.00
0005435785806	27430	Economy	3100.00
0005435937396	27430	Economy	3100.00
0005435785796	27430	Economy	3100.00
0005435785811	27430	Economy	3100.00
0005435785824	27430	Economy	3100.00
0005435785819	27430	Economy	3100.00
0005435785805	27430	Economy	3100.00
0005435785807	27430	Economy	3100.00
0005435785793	27430	Economy	3100.00
0005435785791	27430	Economy	3100.00
0005435785821	27430	Economy	3100.00
0005435937394	27430	Economy	3100.00
0005435785795	27430	Economy	3100.00
0005435785822	27430	Economy	3100.00
0005435787382	27430	Economy	3100.00
0005435785815	27430	Economy	3100.00
0005434408058	20279	Business	12000.00
0005434407882	20279	Business	12000.00
0005434407998	20279	Business	12000.00
0005435311246	20279	Business	12000.00
0005434408204	20279	Business	12000.00
0005434408104	20279	Business	12000.00
0005434408132	20279	Business	12000.00
0005435311245	20279	Business	12000.00
0005434408366	20279	Business	12000.00
0005434408269	20279	Business	12000.00
0005435311239	20279	Economy	4000.00
0005434408216	20279	Economy	4000.00
0005435311244	20279	Economy	4000.00
0005434407759	20279	Economy	4000.00
0005434408012	20279	Economy	4000.00
0005434407938	20279	Economy	4000.00
0005434408057	20279	Economy	4000.00
0005434408235	20279	Economy	4400.00
0005435311243	20279	Economy	4400.00
0005435311238	20279	Economy	4000.00
0005434408270	20279	Economy	4000.00
0005434408133	20279	Economy	4000.00
0005434407919	20279	Economy	4000.00
0005435311237	20279	Economy	4000.00
0005434408253	20279	Economy	4000.00
0005432058438	20279	Economy	4000.00
0005434407854	20279	Economy	4000.00
0005434408118	20279	Economy	4000.00
0005434408227	20279	Economy	4000.00
0005434408039	20279	Economy	4000.00
0005435311240	20279	Economy	4000.00
0005434407999	20279	Economy	4000.00
0005434408208	20279	Economy	4000.00
0005434407941	20279	Economy	4000.00
0005434408032	20279	Economy	4000.00
0005434408065	20279	Economy	4000.00
0005434407956	20279	Economy	4000.00
0005434408041	20279	Economy	4000.00
0005434408114	20279	Economy	4000.00
0005434408251	20279	Economy	4000.00
0005432058437	20279	Economy	4000.00
0005434408140	20279	Economy	4000.00
0005434408134	20279	Economy	4000.00
0005434408179	20279	Economy	4000.00
0005432058441	20279	Economy	4000.00
0005434408066	20279	Economy	4000.00
0005432058440	20279	Economy	4000.00
0005434408059	20279	Economy	4000.00
0005434408138	20279	Economy	4000.00
0005434408113	20279	Economy	4000.00
0005434408245	20279	Economy	4000.00
0005435311241	20279	Economy	4000.00
0005434408240	20279	Economy	4000.00
0005434408141	20279	Economy	4000.00
0005435311247	20279	Economy	4000.00
0005434408252	20279	Economy	4000.00
0005434408090	20279	Economy	4000.00
0005432058439	20279	Economy	4000.00
0005434408246	20279	Economy	4000.00
0005434407930	20279	Economy	4000.00
0005435311242	20279	Economy	4000.00
0005434407994	20279	Economy	4000.00
0005434408013	20279	Economy	4000.00
0005434408642	26978	Business	12000.00
0005434408682	26978	Business	12000.00
0005434408673	26978	Business	12000.00
0005434408684	26978	Business	12000.00
0005434408690	26978	Business	12000.00
0005435311094	26978	Business	12000.00
0005434408705	26978	Business	12000.00
0005434408662	26978	Business	12000.00
0005435311097	26978	Business	12000.00
0005434408696	26978	Business	12000.00
0005435311128	26978	Business	12000.00
0005435311134	26978	Economy	4000.00
0005435311136	26978	Economy	4000.00
0005434408680	26978	Economy	4000.00
0005432154037	26978	Economy	4000.00
0005434408676	26978	Economy	4000.00
0005434408656	26978	Economy	4000.00
0005434408655	26978	Economy	4000.00
0005435311125	26978	Economy	4000.00
0005434408648	26978	Economy	4000.00
0005434408644	26978	Economy	4000.00
0005434408645	26978	Economy	4400.00
0005434408650	26978	Economy	4400.00
0005434408659	26978	Economy	4400.00
0005434408688	26978	Economy	4400.00
0005434408695	26978	Economy	4000.00
0005435311105	26978	Economy	4000.00
0005432154040	26978	Economy	4000.00
0005434408643	26978	Economy	4000.00
0005434408641	26978	Economy	4000.00
0005434408686	26978	Economy	4000.00
0005434408702	26978	Economy	4000.00
0005434408697	26978	Economy	4000.00
0005434408698	26978	Economy	4000.00
0005435311098	26978	Economy	4000.00
0005434408701	26978	Economy	4000.00
0005434408658	26978	Economy	4000.00
0005434408671	26978	Economy	4000.00
0005434408660	26978	Economy	4000.00
0005435311095	26978	Economy	4000.00
0005432154042	26978	Economy	4000.00
0005434408674	26978	Economy	4000.00
0005434408661	26978	Economy	4000.00
0005434408693	26978	Economy	4000.00
0005435311124	26978	Economy	4000.00
0005434408653	26978	Economy	4000.00
0005434408678	26978	Economy	4000.00
0005434408703	26978	Economy	4000.00
0005435311112	26978	Economy	4000.00
0005434408651	26978	Economy	4000.00
0005435311113	26978	Economy	4000.00
0005434408681	26978	Economy	4000.00
0005434408647	26978	Economy	4000.00
0005434408649	26978	Economy	4000.00
0005435311135	26978	Economy	4000.00
0005432154041	26978	Economy	4000.00
0005434408685	26978	Economy	4000.00
0005435311059	26978	Economy	4000.00
0005434408667	26978	Economy	4000.00
0005434408679	26978	Economy	4000.00
0005434408663	26978	Economy	4000.00
0005434408670	26978	Economy	4000.00
0005432154038	26978	Economy	4000.00
0005435311133	26978	Economy	4000.00
0005434408699	26978	Economy	4000.00
0005434408646	26978	Economy	4000.00
0005434408675	26978	Economy	4000.00
0005432154039	26978	Economy	4000.00
0005434408666	26978	Economy	4000.00
0005434408691	26978	Economy	4000.00
0005434408700	26978	Economy	4000.00
0005434408692	26978	Economy	4000.00
0005434408677	26978	Economy	4000.00
0005434408694	26978	Economy	4000.00
0005434408672	26978	Economy	4000.00
0005434408652	26978	Economy	4000.00
0005432154036	26978	Economy	4000.00
0005434408689	26978	Economy	4000.00
0005434408664	26978	Economy	4000.00
0005434408665	26978	Economy	4000.00
0005434408669	26978	Economy	4000.00
0005434408704	26978	Economy	4000.00
0005434408683	26978	Economy	4000.00
0005434408657	26978	Economy	4000.00
0005434408687	26978	Economy	4000.00
0005434408668	26978	Economy	4000.00
0005434408654	26978	Economy	4000.00
0005434319612	5715	Business	43300.00
0005433124107	5715	Business	43300.00
0005433123932	5715	Business	43300.00
0005433124065	5715	Business	43300.00
0005434319610	5715	Economy	14400.00
0005433124036	5715	Economy	14400.00
0005434311248	5715	Economy	14400.00
0005433123939	5715	Economy	14400.00
0005434319607	5715	Economy	14400.00
0005433124094	5715	Economy	14400.00
0005433124004	5715	Economy	14400.00
0005434319608	5715	Economy	15900.00
0005433124103	5715	Economy	15900.00
0005433124122	5715	Economy	15900.00
0005433124019	5715	Economy	14400.00
0005433124014	5715	Economy	14400.00
0005434319609	5715	Economy	14400.00
0005433124018	5715	Economy	14400.00
0005433124060	5715	Economy	14400.00
0005433124062	5715	Economy	14400.00
0005434319605	5715	Economy	14400.00
0005433124058	5715	Economy	14400.00
0005432109743	5715	Economy	14400.00
0005433124108	5715	Economy	14400.00
0005433124106	5715	Economy	14400.00
0005433124030	5715	Economy	14400.00
0005434311247	5715	Economy	14400.00
0005434319615	5715	Economy	14400.00
0005432109744	5715	Economy	14400.00
0005433124039	5715	Economy	14400.00
0005433124029	5715	Economy	14400.00
0005433124104	5715	Economy	14400.00
0005433123951	5715	Economy	14400.00
0005434319618	5715	Economy	14400.00
0005434319613	5715	Economy	14400.00
0005434319603	5715	Economy	14400.00
0005433124031	5715	Economy	14400.00
0005433124023	5715	Economy	14400.00
0005433124076	5715	Economy	14400.00
0005434319617	5715	Economy	14400.00
0005433123999	5715	Economy	14400.00
0005433124044	5715	Economy	14400.00
0005433124005	5715	Economy	14400.00
0005434319606	5715	Economy	14400.00
0005434319614	5715	Economy	14400.00
0005433124035	5715	Economy	14400.00
0005434319611	5715	Economy	14400.00
0005433123931	5715	Economy	14400.00
0005434319616	5715	Economy	14400.00
0005434319604	5715	Economy	14400.00
0005433124231	15669	Business	43300.00
0005434311230	15669	Business	43300.00
0005434312326	15669	Business	43300.00
0005434319439	15669	Business	43300.00
0005434319432	15669	Business	43300.00
0005434312328	15669	Business	43300.00
0005434319558	15669	Economy	14400.00
0005434312325	15669	Economy	14400.00
0005433124224	15669	Economy	14400.00
0005433124233	15669	Economy	15900.00
0005433124219	15669	Economy	15900.00
0005434319446	15669	Economy	15900.00
0005434312334	15669	Economy	14400.00
0005434319440	15669	Economy	14400.00
0005434312333	15669	Economy	14400.00
0005433124237	15669	Economy	14400.00
0005433124228	15669	Economy	14400.00
0005433124220	15669	Economy	14400.00
0005433124226	15669	Economy	14400.00
0005433124236	15669	Economy	14400.00
0005434311233	15669	Economy	14400.00
0005433124239	15669	Economy	14400.00
0005434319445	15669	Economy	14400.00
0005434319515	15669	Economy	14400.00
0005433124222	15669	Economy	14400.00
0005434319459	15669	Economy	14400.00
0005434312321	15669	Economy	14400.00
0005434312335	15669	Economy	14400.00
0005434319514	15669	Economy	14400.00
0005433124238	15669	Economy	14400.00
0005433124223	15669	Economy	14400.00
0005434319509	15669	Economy	14400.00
0005433124225	15669	Economy	14400.00
0005434319484	15669	Economy	14400.00
0005433124229	15669	Economy	14400.00
0005434311229	15669	Economy	14400.00
0005434312320	15669	Economy	14400.00
0005433124235	15669	Economy	14400.00
0005434312327	15669	Economy	14400.00
0005433124227	15669	Economy	14400.00
0005433124234	15669	Economy	14400.00
0005433124232	15669	Economy	14400.00
0005433124240	15669	Economy	14400.00
0005433124221	15669	Economy	14400.00
0005434319520	15669	Economy	14400.00
0005433124230	15669	Economy	14400.00
0005435217718	24981	Economy	17100.00
0005435221520	24981	Economy	17100.00
0005435220330	24981	Economy	15500.00
0005435217721	24981	Economy	15500.00
0005435221519	24981	Economy	15500.00
0005435221521	24981	Economy	15500.00
0005435220319	24981	Economy	15500.00
0005435217725	24981	Economy	15500.00
0005435220323	24981	Economy	15500.00
0005435217727	24981	Economy	15500.00
0005434484447	8971	Economy	24900.00
0005434189195	8971	Economy	24900.00
0005434484442	8971	Economy	24900.00
0005434189197	8971	Economy	24900.00
0005434484443	8971	Economy	24900.00
0005434484446	8971	Economy	24900.00
0005434484445	8971	Economy	24900.00
0005434189196	8971	Economy	24900.00
0005434484441	8971	Economy	24900.00
0005434484444	8971	Economy	24900.00
0005434484440	8971	Economy	24900.00
0005434189260	16664	Economy	27400.00
0005434484368	16664	Economy	27400.00
0005434484405	16664	Economy	24900.00
0005434189259	16664	Economy	24900.00
0005434189264	16664	Economy	24900.00
0005434189262	16664	Economy	24900.00
0005434484377	16664	Economy	24900.00
0005434484386	16664	Economy	24900.00
0005434189261	16664	Economy	24900.00
0005434484376	16664	Economy	24900.00
0005434484385	16664	Economy	24900.00
0005434484404	16664	Economy	24900.00
0005434189265	16664	Economy	24900.00
0005434484375	16664	Economy	24900.00
0005434189263	16664	Economy	24900.00
0005433124229	7564	Business	11100.00
0005433124234	7564	Business	11100.00
0005433722230	7564	Business	11100.00
0005433124223	7564	Business	11100.00
0005433722231	7564	Business	11100.00
0005433124224	7564	Economy	3700.00
0005433124226	7564	Economy	4100.00
0005433124219	7564	Economy	4100.00
0005433124227	7564	Economy	3700.00
0005433124222	7564	Economy	3700.00
0005433722250	7564	Economy	3700.00
0005433124237	7564	Economy	3700.00
0005433124225	7564	Economy	3700.00
0005433722217	7564	Economy	3700.00
0005433124230	7564	Economy	3700.00
0005433124235	7564	Economy	3700.00
0005433124240	7564	Economy	3700.00
0005433124238	7564	Economy	3700.00
0005433124233	7564	Economy	3700.00
0005433124220	7564	Economy	3700.00
0005433722237	7564	Economy	3700.00
0005433124221	7564	Economy	3700.00
0005433124231	7564	Economy	3700.00
0005433124228	7564	Economy	3700.00
0005433124232	7564	Economy	3700.00
0005433124236	7564	Economy	3700.00
0005433722238	7564	Economy	3700.00
0005433124239	7564	Economy	3700.00
0005432721304	7563	Business	11100.00
0005433450284	7563	Business	11100.00
0005432721307	7563	Business	11100.00
0005432693537	7563	Business	11100.00
0005432721292	7563	Business	11100.00
0005432693523	7563	Business	11100.00
0005432721302	7563	Business	11100.00
0005432721305	7563	Business	11100.00
0005432071617	7563	Business	11100.00
0005432721293	7563	Economy	3700.00
0005432721287	7563	Economy	3700.00
0005432693519	7563	Economy	3700.00
0005432693528	7563	Economy	3700.00
0005433450275	7563	Economy	3700.00
0005432693530	7563	Economy	3700.00
0005432693517	7563	Economy	3700.00
0005432721294	7563	Economy	3700.00
0005432721286	7563	Economy	3700.00
0005433450293	7563	Economy	4100.00
0005432693513	7563	Economy	4100.00
0005432721284	7563	Economy	4100.00
0005432693536	7563	Economy	4100.00
0005433450283	7563	Economy	3700.00
0005432693516	7563	Economy	3700.00
0005432721282	7563	Economy	3700.00
0005433450287	7563	Economy	3700.00
0005433450276	7563	Economy	3700.00
0005432721289	7563	Economy	3700.00
0005433450291	7563	Economy	3700.00
0005432693511	7563	Economy	3700.00
0005432693532	7563	Economy	3700.00
0005433450285	7563	Economy	3700.00
0005432693518	7563	Economy	3700.00
0005432721297	7563	Economy	3700.00
0005433450279	7563	Economy	3700.00
0005432693510	7563	Economy	3700.00
0005433450289	7563	Economy	3700.00
0005432721288	7563	Economy	3700.00
0005432693521	7563	Economy	3700.00
0005432693531	7563	Economy	3700.00
0005432721296	7563	Economy	3700.00
0005432721303	7563	Economy	3700.00
0005433450290	7563	Economy	3700.00
0005432721300	7563	Economy	3700.00
0005432693535	7563	Economy	3700.00
0005432693524	7563	Economy	3700.00
0005432693514	7563	Economy	3700.00
0005432693533	7563	Economy	3700.00
0005432071616	7563	Economy	3700.00
0005432693512	7563	Economy	3700.00
0005433450282	7563	Economy	3700.00
0005432693534	7563	Economy	3700.00
0005433450274	7563	Economy	3700.00
0005432693515	7563	Economy	3700.00
0005432721299	7563	Economy	3700.00
0005432693529	7563	Economy	3700.00
0005432693509	7563	Economy	3700.00
0005432693507	7563	Economy	3700.00
0005433450288	7563	Economy	3700.00
0005432721285	7563	Economy	3700.00
0005432693522	7563	Economy	3700.00
0005432693508	7563	Economy	3700.00
0005432721291	7563	Economy	3700.00
0005432721280	7563	Economy	3700.00
0005433450280	7563	Economy	3700.00
0005432721301	7563	Economy	3700.00
0005433450296	7563	Economy	3700.00
0005432721295	7563	Economy	3700.00
0005432693526	7563	Economy	3700.00
0005432693527	7563	Economy	3700.00
0005433450281	7563	Economy	3700.00
0005433450292	7563	Economy	3700.00
0005432721298	7563	Economy	3700.00
0005432721283	7563	Economy	3700.00
0005432721290	7563	Economy	3700.00
0005433450277	7563	Economy	3700.00
0005433450286	7563	Economy	3700.00
0005433450278	7563	Economy	3700.00
0005433450294	7563	Economy	3700.00
0005432721306	7563	Economy	3700.00
0005432721281	7563	Economy	3700.00
0005432693520	7563	Economy	3700.00
0005433450295	7563	Economy	3700.00
0005432693525	7563	Economy	3700.00
0005432693154	30364	Business	11100.00
0005433450032	30364	Business	11100.00
0005432693216	30364	Business	11100.00
0005432693194	30364	Business	11100.00
0005433450004	30364	Business	11100.00
0005433450066	30364	Business	11100.00
0005432693259	30364	Economy	3700.00
0005433450033	30364	Economy	3700.00
0005432693192	30364	Economy	3700.00
0005432693222	30364	Economy	3700.00
0005433450137	30364	Economy	3700.00
0005432693127	30364	Economy	3700.00
0005432693144	30364	Economy	3700.00
0005432693225	30364	Economy	3700.00
0005433450067	30364	Economy	4100.00
0005432693247	30364	Economy	4100.00
0005432693191	30364	Economy	4100.00
0005432693208	30364	Economy	4100.00
0005432693133	30364	Economy	3700.00
0005432693210	30364	Economy	3700.00
0005432693076	30364	Economy	3700.00
0005432693221	30364	Economy	3700.00
0005432693170	30364	Economy	3700.00
0005432693128	30364	Economy	3700.00
0005433450080	30364	Economy	3700.00
0005432693203	30364	Economy	3700.00
0005432693209	30364	Economy	3700.00
0005432693169	30364	Economy	3700.00
0005432693250	30364	Economy	3700.00
0005432693293	30364	Economy	3700.00
0005432693230	30364	Economy	3700.00
0005432693312	30364	Economy	3700.00
0005432693185	30364	Economy	3700.00
0005433450085	30364	Economy	3700.00
0005432693311	30364	Economy	3700.00
0005432693202	30364	Economy	3700.00
0005432693294	30364	Economy	3700.00
0005433450103	30364	Economy	3700.00
0005432693224	30364	Economy	3700.00
0005432693153	30364	Economy	3700.00
0005432693167	30364	Economy	3700.00
0005432693166	30364	Economy	3700.00
0005432693152	30364	Economy	3700.00
0005433124019	30365	Business	11100.00
0005432721107	30365	Business	11100.00
0005432721026	30365	Business	11100.00
0005432721024	30365	Business	11100.00
0005432721167	30365	Business	11100.00
0005432721168	30365	Business	11100.00
0005432720986	30365	Business	11100.00
0005433124104	30365	Business	11100.00
0005432721122	30365	Business	11100.00
0005432721106	30365	Economy	3700.00
0005432721056	30365	Economy	3700.00
0005433124106	30365	Economy	3700.00
0005433124103	30365	Economy	3700.00
0005432721112	30365	Economy	3700.00
0005433124005	30365	Economy	3700.00
0005432721124	30365	Economy	3700.00
0005432721125	30365	Economy	4100.00
0005433124076	30365	Economy	4100.00
0005433722318	30365	Economy	4100.00
0005432721058	30365	Economy	3700.00
0005433124023	30365	Economy	3700.00
0005433124122	30365	Economy	3700.00
0005433124039	30365	Economy	3700.00
0005433124018	30365	Economy	3700.00
0005432721161	30365	Economy	3700.00
0005433123931	30365	Economy	3700.00
0005433124030	30365	Economy	3700.00
0005432721008	30365	Economy	3700.00
0005432721055	30365	Economy	3700.00
0005433722314	30365	Economy	3700.00
0005432721025	30365	Economy	3700.00
0005432721108	30365	Economy	3700.00
0005433124062	30365	Economy	3700.00
0005432721128	30365	Economy	3700.00
0005433123932	30365	Economy	3700.00
0005433123939	30365	Economy	3700.00
0005432721050	30365	Economy	3700.00
0005433124044	30365	Economy	3700.00
0005432721111	30365	Economy	3700.00
0005433124108	30365	Economy	3700.00
0005433124058	30365	Economy	3700.00
0005433124035	30365	Economy	3700.00
0005432721057	30365	Economy	3700.00
0005432721006	30365	Economy	3700.00
0005433124107	30365	Economy	3700.00
0005432721049	30365	Economy	3700.00
0005433722317	30365	Economy	3700.00
0005433124029	30365	Economy	3700.00
0005433722315	30365	Economy	3700.00
0005432721059	30365	Economy	3700.00
0005433123999	30365	Economy	3700.00
0005432721126	30365	Economy	3700.00
0005433124065	30365	Economy	3700.00
0005433124060	30365	Economy	3700.00
0005433124094	30365	Economy	3700.00
0005432720985	30365	Economy	3700.00
0005432721136	30365	Economy	3700.00
0005433124004	30365	Economy	3700.00
0005432721137	30365	Economy	3700.00
0005432721146	30365	Economy	3700.00
0005432721007	30365	Economy	3700.00
0005433124036	30365	Economy	3700.00
0005433123951	30365	Economy	3700.00
0005432721135	30365	Economy	3700.00
0005432721190	30365	Economy	3700.00
0005433722316	30365	Economy	3700.00
0005432721020	30365	Economy	3700.00
0005433124031	30365	Economy	3700.00
0005433124014	30365	Economy	3700.00
0005432721072	30365	Economy	3700.00
0005432721162	30365	Economy	3700.00
0005434513618	1358	Business	70400.00
0005434586980	1358	Business	70400.00
0005433525201	1358	Business	70400.00
0005434586994	1358	Business	70400.00
0005434513617	1358	Business	70400.00
0005434586987	1358	Business	70400.00
0005433525199	1358	Business	70400.00
0005434586975	1358	Business	70400.00
0005432271045	1358	Economy	23500.00
0005434586993	1358	Economy	23500.00
0005433193160	1358	Economy	23500.00
0005434586998	1358	Economy	23500.00
0005433193159	1358	Economy	23500.00
0005434586990	1358	Economy	23500.00
0005433724874	1358	Economy	25800.00
0005434586977	1358	Economy	25800.00
0005434586984	1358	Economy	23500.00
0005433193048	1358	Economy	23500.00
0005434515006	1358	Economy	23500.00
0005434586976	1358	Economy	23500.00
0005433525198	1358	Economy	23500.00
0005434586974	1358	Economy	23500.00
0005433525192	1358	Economy	23500.00
0005433525200	1358	Economy	23500.00
0005433193087	1358	Economy	23500.00
0005433525196	1358	Economy	23500.00
0005433724873	1358	Economy	23500.00
0005433193104	1358	Economy	23500.00
0005433193047	1358	Economy	23500.00
0005433193154	1358	Economy	23500.00
0005434586989	1358	Economy	23500.00
0005433193125	1358	Economy	23500.00
0005433724872	1358	Economy	23500.00
0005434586985	1358	Economy	23500.00
0005434586978	1358	Economy	23500.00
0005434586979	1358	Economy	23500.00
0005433525194	1358	Economy	23500.00
0005433525197	1358	Economy	23500.00
0005434586981	1358	Economy	23500.00
0005434586997	1358	Economy	23500.00
0005434586996	1358	Economy	23500.00
0005434586991	1358	Economy	23500.00
0005434515005	1358	Economy	23500.00
0005434586986	1358	Economy	23500.00
0005433525193	1358	Economy	23500.00
0005433724871	1358	Economy	23500.00
0005433525195	1358	Economy	23500.00
0005434586988	1358	Economy	23500.00
0005433724870	1358	Economy	23500.00
0005434515004	1358	Economy	23500.00
0005433193105	1358	Economy	23500.00
0005433525202	1358	Economy	23500.00
0005433193153	1358	Economy	23500.00
0005434586983	1358	Economy	23500.00
0005434586982	1358	Economy	23500.00
0005434586992	1358	Economy	23500.00
0005434586995	1358	Economy	23500.00
0005432271046	1358	Economy	23500.00
0005434586731	18554	Business	70400.00
0005432968872	18554	Business	70400.00
0005434586809	18554	Business	70400.00
0005432928062	18554	Business	70400.00
0005433525122	18554	Business	70400.00
0005434586631	18554	Business	70400.00
0005432928061	18554	Business	70400.00
0005433193243	18554	Business	70400.00
0005433193238	18554	Economy	23500.00
0005434586784	18554	Economy	23500.00
0005434586727	18554	Economy	23500.00
0005434586698	18554	Economy	23500.00
0005433193239	18554	Economy	23500.00
0005434586741	18554	Economy	23500.00
0005432928060	18554	Economy	23500.00
0005434586629	18554	Economy	25800.00
0005433525039	18554	Economy	25800.00
0005432968873	18554	Economy	25800.00
0005433525094	18554	Economy	25800.00
0005433193246	18554	Economy	25800.00
0005434586712	18554	Economy	23500.00
0005433193235	18554	Economy	23500.00
0005434586783	18554	Economy	23500.00
0005434586859	18554	Economy	23500.00
0005433525123	18554	Economy	23500.00
0005433525102	18554	Economy	23500.00
0005434514974	18554	Economy	23500.00
0005434586904	18554	Economy	23500.00
0005433525125	18554	Economy	23500.00
0005434586740	18554	Economy	23500.00
0005434586707	18554	Economy	23500.00
0005432928059	18554	Economy	23500.00
0005433525146	18554	Economy	23500.00
0005434586777	18554	Economy	23500.00
0005434586833	18554	Economy	23500.00
0005433193242	18554	Economy	23500.00
0005434586753	18554	Economy	23500.00
0005434586708	18554	Economy	23500.00
0005433193240	18554	Economy	23500.00
0005433525124	18554	Economy	23500.00
0005433525095	18554	Economy	23500.00
0005432968874	18554	Economy	23500.00
0005433525064	18554	Economy	23500.00
0005434586673	18554	Economy	23500.00
0005433724827	18554	Economy	23500.00
0005434586608	18554	Economy	23500.00
0005433193234	18554	Economy	23500.00
0005434586780	18554	Economy	23500.00
0005433525086	18554	Economy	23500.00
0005433193244	18554	Economy	23500.00
0005433525065	18554	Economy	23500.00
0005434586755	18554	Economy	23500.00
0005434586860	18554	Economy	23500.00
0005434586747	18554	Economy	23500.00
0005434586808	18554	Economy	23500.00
0005434586748	18554	Economy	23500.00
0005433193245	18554	Economy	23500.00
0005433193236	18554	Economy	23500.00
0005434586699	18554	Economy	23500.00
0005434586674	18554	Economy	23500.00
0005434586665	18554	Economy	23500.00
0005433193237	18554	Economy	23500.00
0005433193241	18554	Economy	23500.00
0005432928057	18554	Economy	23500.00
0005433525075	18554	Economy	23500.00
0005434586633	18554	Economy	23500.00
0005432928058	18554	Economy	23500.00
0005434586678	18554	Economy	23500.00
0005434586754	18554	Economy	23500.00
0005433193233	18554	Economy	23500.00
0005435302222	11457	Economy	4300.00
0005434344686	11457	Economy	4300.00
0005434344674	11457	Economy	4300.00
0005434344694	11457	Economy	4000.00
0005434344704	11457	Economy	4000.00
0005435302236	11457	Economy	4000.00
0005434344682	11457	Economy	4000.00
0005435305017	11457	Economy	4000.00
0005434344691	11457	Economy	4000.00
0005434344700	11457	Economy	4000.00
0005434344677	11457	Economy	4000.00
0005434142670	11457	Economy	4000.00
0005434344707	11457	Economy	4000.00
0005434344681	11457	Economy	4000.00
0005434344685	11457	Economy	4000.00
0005434344696	11457	Economy	4000.00
0005434344687	11457	Economy	4000.00
0005434344702	11457	Economy	4000.00
0005434344676	11457	Economy	4000.00
0005434142666	11457	Economy	4000.00
0005434344705	11457	Economy	4000.00
0005435302226	11457	Economy	4000.00
0005434344678	11457	Economy	4000.00
0005434344697	11457	Economy	4000.00
0005434344675	11457	Economy	4000.00
0005434344679	11457	Economy	4000.00
0005434344701	11457	Economy	4000.00
0005434344699	11457	Economy	4000.00
0005434344708	11457	Economy	4000.00
0005434142669	11457	Economy	4000.00
0005434344692	11457	Economy	4000.00
0005434344689	11457	Economy	4000.00
0005435302225	11457	Economy	4000.00
0005434344698	11457	Economy	4000.00
0005434344693	11457	Economy	4000.00
0005434344688	11457	Economy	4000.00
0005434142668	11457	Economy	4000.00
0005434344690	11457	Economy	4000.00
0005434344680	11457	Economy	4000.00
0005434344695	11457	Economy	4000.00
0005434142667	11457	Economy	4000.00
0005434344703	11457	Economy	4000.00
0005434344706	11457	Economy	4000.00
0005435302221	11457	Economy	4000.00
0005434344684	11457	Economy	4000.00
0005434344683	11457	Economy	4000.00
0005435304223	29804	Economy	4300.00
0005434344355	29804	Economy	4300.00
0005434344389	29804	Economy	4300.00
0005434344430	29804	Economy	4300.00
0005434344480	29804	Economy	4000.00
0005434344256	29804	Economy	4000.00
0005434344294	29804	Economy	4000.00
0005434344209	29804	Economy	4000.00
0005434344383	29804	Economy	4000.00
0005434344399	29804	Economy	4000.00
0005434344319	29804	Economy	4000.00
0005434344407	29804	Economy	4000.00
0005434344488	29804	Economy	4000.00
0005434344320	29804	Economy	4000.00
0005434344282	29804	Economy	4000.00
0005434344420	29804	Economy	4000.00
0005434344479	29804	Economy	4000.00
0005434344335	29804	Economy	4000.00
0005434344347	29804	Economy	4000.00
0005434344366	29804	Economy	4000.00
0005434344472	29804	Economy	4000.00
0005434344374	29804	Economy	4000.00
0005434344375	29804	Economy	4000.00
0005435304225	29804	Economy	4000.00
0005434344299	29804	Economy	4000.00
0005435304224	29804	Economy	4000.00
0005434344255	29804	Economy	4000.00
0005434344365	29804	Economy	4000.00
0005434142630	29804	Economy	4000.00
0005435305043	29804	Economy	4000.00
0005434344503	29804	Economy	4000.00
0005434344371	29804	Economy	4000.00
0005434344424	29804	Economy	4000.00
0005434344298	29804	Economy	4000.00
0005435304226	29804	Economy	4000.00
0005434344370	29804	Economy	4000.00
0005434344382	29804	Economy	4000.00
0005434344367	29804	Economy	4000.00
0005434142629	29804	Economy	4000.00
0005434344368	29804	Economy	4000.00
0005434344334	29804	Economy	4000.00
0005434344296	29804	Economy	4000.00
0005434344300	29804	Economy	4000.00
0005434344457	29804	Economy	4000.00
0005434344478	29804	Economy	4000.00
0005434344406	29804	Economy	4000.00
0005434344475	29804	Economy	4000.00
0005434344460	29804	Economy	4000.00
0005434344369	29804	Economy	4000.00
0005435825019	1279	Business	199800.00
0005433415785	1279	Business	199800.00
0005432284600	1279	Business	199800.00
0005433415724	1279	Business	199800.00
0005433415743	1279	Business	199800.00
0005433415757	1279	Business	199800.00
0005433415755	1279	Business	199800.00
0005433415721	1279	Business	199800.00
0005433415765	1279	Business	199800.00
0005433415778	1279	Business	199800.00
0005435825014	1279	Economy	66600.00
0005435825006	1279	Economy	66600.00
0005435825026	1279	Economy	66600.00
0005435825030	1279	Economy	66600.00
0005432284601	1279	Economy	66600.00
0005433415733	1279	Economy	66600.00
0005433415771	1279	Economy	73200.00
0005433415843	1279	Economy	73200.00
0005433415844	1279	Economy	66600.00
0005433415739	1279	Economy	66600.00
0005435825020	1279	Economy	66600.00
0005435825018	1279	Economy	66600.00
0005433415847	1279	Economy	66600.00
0005433415734	1279	Economy	66600.00
0005435825017	1279	Economy	66600.00
0005435825028	1279	Economy	66600.00
0005433415772	1279	Economy	66600.00
0005435825009	1279	Economy	66600.00
0005433415676	1279	Economy	66600.00
0005432284602	1279	Economy	66600.00
0005435825008	1279	Economy	66600.00
0005435825012	1279	Economy	66600.00
0005433415740	1279	Economy	66600.00
0005435825029	1279	Economy	66600.00
0005433415814	1279	Economy	66600.00
0005435825016	1279	Economy	66600.00
0005433415726	1279	Economy	66600.00
0005435825013	1279	Economy	66600.00
0005435825022	1279	Economy	66600.00
0005435825007	1279	Economy	66600.00
0005435825015	1279	Economy	66600.00
0005435825024	1279	Economy	66600.00
0005433415742	1279	Economy	66600.00
0005435825005	1279	Economy	66600.00
0005433415741	1279	Economy	66600.00
0005435825011	1279	Economy	66600.00
0005435825004	1279	Economy	66600.00
0005435825023	1279	Economy	66600.00
0005435825027	1279	Economy	66600.00
0005435825021	1279	Economy	66600.00
0005433415813	1279	Economy	66600.00
0005433415773	1279	Economy	66600.00
0005433415784	1279	Economy	66600.00
0005435825010	1279	Economy	66600.00
0005433415756	1279	Economy	66600.00
0005435825025	1279	Economy	66600.00
0005435824740	18009	Business	199800.00
0005435824686	18009	Business	199800.00
0005433415891	18009	Business	199800.00
0005435824712	18009	Business	199800.00
0005435824788	18009	Economy	66600.00
0005433415896	18009	Economy	66600.00
0005435824766	18009	Economy	66600.00
0005435824687	18009	Economy	66600.00
0005433415893	18009	Economy	66600.00
0005435824852	18009	Economy	66600.00
0005435824713	18009	Economy	73200.00
0005435824741	18009	Economy	73200.00
0005435824714	18009	Economy	66600.00
0005433415894	18009	Economy	66600.00
0005433415887	18009	Economy	66600.00
0005435824792	18009	Economy	66600.00
0005435824887	18009	Economy	66600.00
0005433415899	18009	Economy	66600.00
0005433415900	18009	Economy	66600.00
0005435824849	18009	Economy	66600.00
0005433415897	18009	Economy	66600.00
0005435824814	18009	Economy	66600.00
0005433415889	18009	Economy	66600.00
0005433415898	18009	Economy	66600.00
0005433415886	18009	Economy	66600.00
0005433415890	18009	Economy	66600.00
0005435824793	18009	Economy	66600.00
0005435824772	18009	Economy	66600.00
0005433415885	18009	Economy	66600.00
0005435824858	18009	Economy	66600.00
0005433415888	18009	Economy	66600.00
0005435824886	18009	Economy	66600.00
0005435824738	18009	Economy	66600.00
0005435824842	18009	Economy	66600.00
0005435824763	18009	Economy	66600.00
0005435824815	18009	Economy	66600.00
0005433415895	18009	Economy	66600.00
0005433415892	18009	Economy	66600.00
0005434462809	17528	Economy	14800.00
0005434462801	17528	Economy	14800.00
0005434460512	17528	Economy	13500.00
0005434462798	17528	Economy	13500.00
0005434462811	17528	Economy	13500.00
0005434460527	17528	Economy	13500.00
0005434460501	17528	Economy	13500.00
0005434460510	17528	Economy	13500.00
0005434460511	17528	Economy	13500.00
0005434460508	17528	Economy	13500.00
0005434460506	17528	Economy	13500.00
0005434460523	17528	Economy	13500.00
0005434460507	17528	Economy	13500.00
0005434460516	17528	Economy	13500.00
0005434460504	17528	Economy	13500.00
0005434460513	17528	Economy	13500.00
0005434460509	17528	Economy	13500.00
0005434462800	17528	Economy	13500.00
0005434460514	17528	Economy	13500.00
0005434462802	17528	Economy	13500.00
0005434462803	17528	Economy	13500.00
0005434460528	17528	Economy	13500.00
0005434460515	17528	Economy	13500.00
0005435243031	5609	Business	27800.00
0005435476793	5609	Business	27800.00
0005432784559	5609	Business	27800.00
0005432784567	5609	Business	27800.00
0005435242965	5609	Business	27800.00
0005432144033	5609	Business	27800.00
0005432784568	5609	Business	27800.00
0005432784570	5609	Business	27800.00
0005432784571	5609	Business	27800.00
0005432144036	5609	Business	27800.00
0005435242983	5609	Economy	9300.00
0005432784549	5609	Economy	9300.00
0005435243010	5609	Economy	9300.00
0005432784595	5609	Economy	9300.00
0005432784591	5609	Economy	9300.00
0005435476772	5609	Economy	9300.00
0005435242964	5609	Economy	9300.00
0005432784562	5609	Economy	9300.00
0005435243017	5609	Economy	9300.00
0005432784553	5609	Economy	9300.00
0005435243014	5609	Economy	10200.00
0005435243015	5609	Economy	10200.00
0005432784573	5609	Economy	10200.00
0005432784552	5609	Economy	10200.00
0005435243018	5609	Economy	10200.00
0005435476794	5609	Economy	9300.00
0005432784596	5609	Economy	9300.00
0005432784584	5609	Economy	9300.00
0005432784566	5609	Economy	9300.00
0005432784585	5609	Economy	9300.00
0005432784577	5609	Economy	9300.00
0005432784574	5609	Economy	9300.00
0005432784558	5609	Economy	9300.00
0005435242990	5609	Economy	9300.00
0005435476806	5609	Economy	9300.00
0005432784555	5609	Economy	9300.00
0005435476770	5609	Economy	9300.00
0005432784572	5609	Economy	9300.00
0005432784551	5609	Economy	9300.00
0005435242975	5609	Economy	9300.00
0005432784580	5609	Economy	9300.00
0005432784563	5609	Economy	9300.00
0005432784569	5609	Economy	9300.00
0005432784561	5609	Economy	9300.00
0005435243009	5609	Economy	9300.00
0005432784575	5609	Economy	9300.00
0005432784578	5609	Economy	9300.00
0005432784592	5609	Economy	9300.00
0005432784589	5609	Economy	9300.00
0005432784556	5609	Economy	9300.00
0005432784588	5609	Economy	9300.00
0005432784583	5609	Economy	9300.00
0005432784590	5609	Economy	9300.00
0005432784557	5609	Economy	9300.00
0005432784597	5609	Economy	9300.00
0005435242976	5609	Economy	9300.00
0005432784579	5609	Economy	9300.00
0005432784594	5609	Economy	9300.00
0005435242954	5609	Economy	9300.00
0005435476787	5609	Economy	9300.00
0005432784598	5609	Economy	9300.00
0005435243016	5609	Economy	9300.00
0005432784587	5609	Economy	9300.00
0005432784581	5609	Economy	9300.00
0005432784550	5609	Economy	9300.00
0005432784564	5609	Economy	9300.00
0005432144034	5609	Economy	9300.00
0005435242991	5609	Economy	9300.00
0005432784565	5609	Economy	9300.00
0005432784586	5609	Economy	9300.00
0005435476769	5609	Economy	9300.00
0005435242988	5609	Economy	9300.00
0005435476771	5609	Economy	9300.00
0005435476808	5609	Economy	9300.00
0005432784560	5609	Economy	9300.00
0005432784554	5609	Economy	9300.00
0005432784593	5609	Economy	9300.00
0005432784576	5609	Economy	9300.00
0005432784547	5609	Economy	9300.00
0005432784548	5609	Economy	9300.00
0005435476795	5609	Economy	9300.00
0005435242955	5609	Economy	9300.00
0005432784600	5609	Economy	9300.00
0005435476824	5609	Economy	9300.00
0005435242943	5609	Economy	9300.00
0005435476809	5609	Economy	9300.00
0005435243011	5609	Economy	9300.00
0005435242947	5609	Economy	9300.00
0005432784599	5609	Economy	9300.00
0005435243029	5609	Economy	9300.00
0005435476792	5609	Economy	9300.00
0005435242961	5609	Economy	9300.00
0005432144035	5609	Economy	9300.00
0005432784582	5609	Economy	9300.00
0005432783961	15340	Business	27800.00
0005432784052	15340	Business	27800.00
0005435243215	15340	Business	27800.00
0005432784059	15340	Business	27800.00
0005432784143	15340	Business	27800.00
0005432783821	15340	Business	27800.00
0005435243213	15340	Business	27800.00
0005432784133	15340	Business	27800.00
0005435243219	15340	Business	27800.00
0005432784000	15340	Business	27800.00
0005432784154	15340	Business	27800.00
0005432783839	15340	Business	27800.00
0005432784036	15340	Economy	9300.00
0005435243222	15340	Economy	9300.00
0005435243234	15340	Economy	9300.00
0005432784155	15340	Economy	9300.00
0005435243235	15340	Economy	9300.00
0005432784058	15340	Economy	9300.00
0005432784239	15340	Economy	9300.00
0005432784129	15340	Economy	9300.00
0005432783910	15340	Economy	9300.00
0005432783822	15340	Economy	10200.00
0005432784235	15340	Economy	10200.00
0005432784242	15340	Economy	10200.00
0005432783838	15340	Economy	10200.00
0005432783912	15340	Economy	10200.00
0005432784214	15340	Economy	9300.00
0005435243224	15340	Economy	9300.00
0005432783862	15340	Economy	9300.00
0005432784241	15340	Economy	9300.00
0005432783990	15340	Economy	9300.00
0005435243228	15340	Economy	9300.00
0005432784035	15340	Economy	9300.00
0005435243217	15340	Economy	9300.00
0005432784034	15340	Economy	9300.00
0005432783913	15340	Economy	9300.00
0005432784018	15340	Economy	9300.00
0005432784140	15340	Economy	9300.00
0005432784142	15340	Economy	9300.00
0005435243223	15340	Economy	9300.00
0005432784130	15340	Economy	9300.00
0005435243225	15340	Economy	9300.00
0005432784076	15340	Economy	9300.00
0005432784029	15340	Economy	9300.00
0005435243230	15340	Economy	9300.00
0005435243221	15340	Economy	9300.00
0005435243216	15340	Economy	9300.00
0005432784085	15340	Economy	9300.00
0005435243231	15340	Economy	9300.00
0005435243214	15340	Economy	9300.00
0005432784152	15340	Economy	9300.00
0005435243210	15340	Economy	9300.00
0005435243218	15340	Economy	9300.00
0005432784045	15340	Economy	9300.00
0005432783965	15340	Economy	9300.00
0005435243236	15340	Economy	9300.00
0005432784114	15340	Economy	9300.00
0005435243227	15340	Economy	9300.00
0005432784216	15340	Economy	9300.00
0005432784153	15340	Economy	9300.00
0005435243220	15340	Economy	9300.00
0005432783937	15340	Economy	9300.00
0005435243229	15340	Economy	9300.00
0005435243212	15340	Economy	9300.00
0005432783989	15340	Economy	9300.00
0005432784236	15340	Economy	9300.00
0005435243232	15340	Economy	9300.00
0005432784240	15340	Economy	9300.00
0005432784081	15340	Economy	9300.00
0005432784053	15340	Economy	9300.00
0005432784115	15340	Economy	9300.00
0005432784078	15340	Economy	9300.00
0005432784038	15340	Economy	9300.00
0005432784279	15340	Economy	9300.00
0005432783999	15340	Economy	9300.00
0005432783911	15340	Economy	9300.00
0005432784093	15340	Economy	9300.00
0005432783903	15340	Economy	9300.00
0005432783905	15340	Economy	9300.00
0005435243233	15340	Economy	9300.00
0005432784300	15340	Economy	9300.00
0005432783966	15340	Economy	9300.00
0005432783863	15340	Economy	9300.00
0005435243211	15340	Economy	9300.00
0005435243237	15340	Economy	9300.00
0005432784037	15340	Economy	9300.00
0005432783904	15340	Economy	9300.00
0005432784215	15340	Economy	9300.00
0005432784030	15340	Economy	9300.00
0005432784009	15340	Economy	9300.00
0005435243209	15340	Economy	9300.00
0005435243226	15340	Economy	9300.00
0005432848527	4345	Economy	7000.00
0005434462821	4345	Economy	6300.00
0005435850980	4345	Economy	6300.00
0005434463962	4345	Economy	6300.00
0005434462822	4345	Economy	6300.00
0005432848522	4345	Economy	6300.00
0005435850979	4345	Economy	6300.00
0005435850938	4345	Economy	6300.00
0005432848528	4345	Economy	6300.00
0005432848529	4345	Economy	6300.00
0005432848515	4345	Economy	6300.00
0005432848523	4345	Economy	6300.00
0005432848526	4345	Economy	6300.00
0005435850972	4345	Economy	6300.00
0005432848516	4345	Economy	6300.00
0005432848518	4345	Economy	6300.00
0005432848517	4345	Economy	6300.00
0005432848519	4345	Economy	6300.00
0005432848524	4345	Economy	6300.00
0005432848520	4345	Economy	6300.00
0005432848525	4345	Economy	6300.00
0005432848530	4345	Economy	6300.00
0005435850990	4345	Economy	6300.00
0005434463961	4345	Economy	6300.00
0005432848521	4345	Economy	6300.00
0005432848398	28872	Economy	7000.00
0005432848390	28872	Economy	7000.00
0005432848431	28872	Economy	7000.00
0005435851044	28872	Economy	6300.00
0005432848421	28872	Economy	6300.00
0005435851041	28872	Economy	6300.00
0005432848365	28872	Economy	6300.00
0005432848337	28872	Economy	6300.00
0005432848397	28872	Economy	6300.00
0005432848392	28872	Economy	6300.00
0005432848368	28872	Economy	6300.00
0005434463937	28872	Economy	6300.00
0005435851045	28872	Economy	6300.00
0005434461656	28872	Economy	6300.00
0005435851040	28872	Economy	6300.00
0005435851038	28872	Economy	6300.00
0005432848366	28872	Economy	6300.00
0005434463942	28872	Economy	6300.00
0005435851039	28872	Economy	6300.00
0005432848438	28872	Economy	6300.00
0005435851046	28872	Economy	6300.00
0005432848420	28872	Economy	6300.00
0005432848391	28872	Economy	6300.00
0005432848389	28872	Economy	6300.00
0005432848422	28872	Economy	6300.00
0005435851043	28872	Economy	6300.00
0005435851042	28872	Economy	6300.00
0005434443950	6295	Business	11900.00
0005433497438	6295	Business	11900.00
0005434443940	6295	Business	11900.00
0005434443941	6295	Business	11900.00
0005434926274	6295	Business	11900.00
0005434926258	6295	Business	11900.00
0005433497418	6295	Business	11900.00
0005433497439	6295	Business	11900.00
0005433497427	6295	Business	11900.00
0005432075279	6295	Business	11900.00
0005434926278	6295	Business	11900.00
0005433497425	6295	Economy	4000.00
0005434926257	6295	Economy	4000.00
0005434926271	6295	Economy	4000.00
0005434443944	6295	Economy	4000.00
0005433497436	6295	Economy	4000.00
0005433497424	6295	Economy	4000.00
0005434443945	6295	Economy	4000.00
0005434443939	6295	Economy	4000.00
0005434443943	6295	Economy	4000.00
0005433497430	6295	Economy	4400.00
0005433497431	6295	Economy	4400.00
0005433497441	6295	Economy	4400.00
0005433497421	6295	Economy	4000.00
0005433497410	6295	Economy	4000.00
0005433497420	6295	Economy	4000.00
0005433497435	6295	Economy	4000.00
0005434926263	6295	Economy	4000.00
0005434926266	6295	Economy	4000.00
0005433497428	6295	Economy	4000.00
0005433497442	6295	Economy	4000.00
0005434443942	6295	Economy	4000.00
0005434926265	6295	Economy	4000.00
0005434926260	6295	Economy	4000.00
0005434926273	6295	Economy	4000.00
0005433497412	6295	Economy	4000.00
0005434926283	6295	Economy	4000.00
0005434443947	6295	Economy	4000.00
0005434926253	6295	Economy	4000.00
0005434926254	6295	Economy	4000.00
0005434926264	6295	Economy	4000.00
0005434926256	6295	Economy	4000.00
0005434926269	6295	Economy	4000.00
0005434926268	6295	Economy	4000.00
0005433497433	6295	Economy	4000.00
0005433497422	6295	Economy	4000.00
0005434926255	6295	Economy	4000.00
0005433497426	6295	Economy	4000.00
0005434926275	6295	Economy	4000.00
0005434926262	6295	Economy	4000.00
0005433497416	6295	Economy	4000.00
0005434926279	6295	Economy	4000.00
0005432075281	6295	Economy	4000.00
0005433497429	6295	Economy	4000.00
0005433497423	6295	Economy	4000.00
0005434926259	6295	Economy	4000.00
0005433497432	6295	Economy	4000.00
0005433497419	6295	Economy	4000.00
0005434443951	6295	Economy	4000.00
0005434926276	6295	Economy	4000.00
0005433497440	6295	Economy	4000.00
0005434926280	6295	Economy	4000.00
0005432075282	6295	Economy	4000.00
0005433497411	6295	Economy	4000.00
0005434926281	6295	Economy	4000.00
0005433497434	6295	Economy	4000.00
0005433497413	6295	Economy	4000.00
0005434443937	6295	Economy	4000.00
0005434926270	6295	Economy	4000.00
0005434926272	6295	Economy	4000.00
0005434926282	6295	Economy	4000.00
0005434926267	6295	Economy	4000.00
0005434443952	6295	Economy	4000.00
0005432075280	6295	Economy	4000.00
0005434926284	6295	Economy	4000.00
0005434926277	6295	Economy	4000.00
0005433497415	6295	Economy	4000.00
0005434926261	6295	Economy	4000.00
0005434443946	6295	Economy	4000.00
0005434443949	6295	Economy	4000.00
0005434443948	6295	Economy	4000.00
0005433497437	6295	Economy	4000.00
0005434443936	6295	Economy	4000.00
0005434443938	6295	Economy	4000.00
0005433497417	6295	Economy	4000.00
0005433497414	6295	Economy	4000.00
0005435257391	20399	Business	11900.00
0005435257392	20399	Economy	4000.00
0005433497201	20398	Business	11900.00
0005434925906	20398	Business	11900.00
0005433497184	20398	Business	11900.00
0005433497200	20398	Business	11900.00
0005434926023	20398	Business	11900.00
0005434925979	20398	Business	11900.00
0005434925989	20398	Business	11900.00
0005434925904	20398	Business	11900.00
0005434925907	20398	Business	11900.00
0005433497182	20398	Economy	4000.00
0005434926016	20398	Economy	4000.00
0005434925913	20398	Economy	4000.00
0005434443764	20398	Economy	4000.00
0005434925902	20398	Economy	4000.00
0005433497210	20398	Economy	4000.00
0005434925905	20398	Economy	4000.00
0005434926022	20398	Economy	4000.00
0005434443763	20398	Economy	4400.00
0005433497246	20398	Economy	4400.00
0005433497274	20398	Economy	4400.00
0005434925980	20398	Economy	4400.00
0005434443791	20398	Economy	4000.00
0005433497125	20398	Economy	4000.00
0005434925924	20398	Economy	4000.00
0005434925994	20398	Economy	4000.00
0005434925995	20398	Economy	4000.00
0005434925940	20398	Economy	4000.00
0005434443757	20398	Economy	4000.00
0005434925900	20398	Economy	4000.00
0005433497242	20398	Economy	4000.00
0005433497138	20398	Economy	4000.00
0005434443756	20398	Economy	4000.00
0005434925969	20398	Economy	4000.00
0005433497244	20398	Economy	4000.00
0005433497191	20398	Economy	4000.00
0005433497185	20398	Economy	4000.00
0005434443718	20398	Economy	4000.00
0005433497249	20398	Economy	4000.00
0005434443823	20398	Economy	4000.00
0005434443767	20398	Economy	4000.00
0005434925963	20398	Economy	4000.00
0005433497196	20398	Economy	4000.00
0005434926024	20398	Economy	4000.00
0005433497211	20398	Economy	4000.00
0005433497167	20398	Economy	4000.00
0005433497212	20398	Economy	4000.00
0005433497104	20398	Economy	4000.00
0005433497366	20398	Economy	4000.00
0005433497107	20398	Economy	4000.00
0005434925941	20398	Economy	4000.00
0005434443790	20398	Economy	4000.00
0005434443787	20398	Economy	4000.00
0005433497114	20398	Economy	4000.00
0005433497115	20398	Economy	4000.00
0005434925987	20398	Economy	4000.00
0005434925951	20398	Economy	4000.00
0005434925901	20398	Economy	4000.00
0005434925829	20398	Economy	4000.00
0005433497181	20398	Economy	4000.00
0005433497247	20398	Economy	4000.00
0005433497215	20398	Economy	4000.00
0005434443758	20398	Economy	4000.00
0005433497168	20398	Economy	4000.00
0005434925990	20398	Economy	4000.00
0005434925998	20398	Economy	4000.00
0005434925828	20398	Economy	4000.00
0005434925912	20398	Economy	4000.00
0005434925846	20398	Economy	4000.00
0005433497166	20398	Economy	4000.00
0005433497245	20398	Economy	4000.00
0005434925949	20398	Economy	4000.00
0005433497108	20398	Economy	4000.00
0005434926025	20398	Economy	4000.00
0005433497179	20398	Economy	4000.00
0005433497106	20398	Economy	4000.00
0005434925873	20398	Economy	4000.00
0005433497190	20398	Economy	4000.00
0005434443827	20398	Economy	4000.00
0005433497365	20398	Economy	4000.00
0005432784148	12199	Business	41200.00
0005435243263	12199	Business	41200.00
0005432783974	12199	Business	41200.00
0005435243257	12199	Business	41200.00
0005432784177	12199	Business	41200.00
0005435243258	12199	Business	41200.00
0005432783969	12199	Business	41200.00
0005435243241	12199	Business	41200.00
0005432784167	12199	Business	41200.00
0005435243253	12199	Business	41200.00
0005432784120	12199	Economy	13700.00
0005432784287	12199	Economy	13700.00
0005435243262	12199	Economy	13700.00
0005432784286	12199	Economy	13700.00
0005435243242	12199	Economy	13700.00
0005432784233	12199	Economy	13700.00
0005432784176	12199	Economy	13700.00
0005435243248	12199	Economy	15100.00
0005432784234	12199	Economy	15100.00
0005432784162	12199	Economy	15100.00
0005432784005	12199	Economy	15100.00
0005435243240	12199	Economy	13700.00
0005432783973	12199	Economy	15100.00
0005432784075	12199	Economy	13700.00
0005432783850	12199	Economy	13700.00
0005435243239	12199	Economy	13700.00
0005432784007	12199	Economy	13700.00
0005432784203	12199	Economy	13700.00
0005432784149	12199	Economy	13700.00
0005432783918	12199	Economy	13700.00
0005435243260	12199	Economy	13700.00
0005435243243	12199	Economy	13700.00
0005432784173	12199	Economy	13700.00
0005435243244	12199	Economy	13700.00
0005435243245	12199	Economy	13700.00
0005432783972	12199	Economy	13700.00
0005432784336	12199	Economy	13700.00
0005432784283	12199	Economy	13700.00
0005432784171	12199	Economy	13700.00
0005432783945	12199	Economy	13700.00
0005432784172	12199	Economy	13700.00
0005432783968	12199	Economy	13700.00
0005432784021	12199	Economy	13700.00
0005435243247	12199	Economy	13700.00
0005432784204	12199	Economy	13700.00
0005432784107	12199	Economy	13700.00
0005435243238	12199	Economy	13700.00
0005435243249	12199	Economy	13700.00
0005432784189	12199	Economy	13700.00
0005432784066	12199	Economy	13700.00
0005435243256	12199	Economy	13700.00
0005432784022	12199	Economy	13700.00
0005432784127	12199	Economy	13700.00
0005432784065	12199	Economy	13700.00
0005435243259	12199	Economy	13700.00
0005435243261	12199	Economy	13700.00
0005435243250	12199	Economy	13700.00
0005435243255	12199	Economy	13700.00
0005432783981	12199	Economy	13700.00
0005435243254	12199	Economy	13700.00
0005432783993	12199	Economy	13700.00
0005432784004	12199	Economy	13700.00
0005435243246	12199	Economy	13700.00
0005435243252	12199	Economy	13700.00
0005432784163	12199	Economy	13700.00
0005432784378	12199	Economy	13700.00
0005435243251	12199	Economy	13700.00
0005432784067	12199	Economy	13700.00
0005432783982	12199	Economy	13700.00
0005432784180	12199	Economy	13700.00
0005432784117	12199	Economy	13700.00
0005432784529	15444	Business	41200.00
0005432784545	15444	Business	41200.00
0005432784532	15444	Business	41200.00
0005435242995	15444	Business	41200.00
0005432784492	15444	Business	41200.00
0005432784520	15444	Business	41200.00
0005435242952	15444	Business	41200.00
0005432784517	15444	Business	41200.00
0005435243153	15444	Business	41200.00
0005432784530	15444	Business	41200.00
0005435242996	15444	Business	41200.00
0005432784503	15444	Economy	13700.00
0005432784521	15444	Economy	13700.00
0005432784509	15444	Economy	13700.00
0005432784511	15444	Economy	13700.00
0005432784542	15444	Economy	13700.00
0005432784546	15444	Economy	13700.00
0005432784544	15444	Economy	13700.00
0005432784499	15444	Economy	13700.00
0005432784525	15444	Economy	15100.00
0005435242951	15444	Economy	15100.00
0005432784518	15444	Economy	15100.00
0005432784507	15444	Economy	13700.00
0005435243020	15444	Economy	13700.00
0005432784497	15444	Economy	13700.00
0005432784516	15444	Economy	13700.00
0005435242994	15444	Economy	13700.00
0005432784513	15444	Economy	13700.00
0005432784543	15444	Economy	13700.00
0005432784531	15444	Economy	13700.00
0005432784493	15444	Economy	13700.00
0005432784527	15444	Economy	13700.00
0005432784535	15444	Economy	13700.00
0005435242862	15444	Economy	13700.00
0005432784537	15444	Economy	13700.00
0005432784523	15444	Economy	13700.00
0005435242886	15444	Economy	13700.00
0005435242863	15444	Economy	13700.00
0005432784505	15444	Economy	13700.00
0005435242802	15444	Economy	13700.00
0005432784524	15444	Economy	13700.00
0005432784495	15444	Economy	13700.00
0005432784496	15444	Economy	13700.00
0005432784526	15444	Economy	13700.00
0005432784533	15444	Economy	13700.00
0005435242907	15444	Economy	13700.00
0005432784528	15444	Economy	13700.00
0005435242919	15444	Economy	13700.00
0005432784500	15444	Economy	13700.00
0005432784534	15444	Economy	13700.00
0005432784515	15444	Economy	13700.00
0005432784522	15444	Economy	13700.00
0005432784514	15444	Economy	13700.00
0005432784512	15444	Economy	13700.00
0005435242902	15444	Economy	13700.00
0005432784506	15444	Economy	13700.00
0005435242960	15444	Economy	13700.00
0005432784494	15444	Economy	13700.00
0005435242985	15444	Economy	13700.00
0005432784536	15444	Economy	13700.00
0005435242912	15444	Economy	13700.00
0005432784501	15444	Economy	13700.00
0005435242984	15444	Economy	13700.00
0005432784498	15444	Economy	13700.00
0005432784502	15444	Economy	13700.00
0005432784539	15444	Economy	13700.00
0005432784504	15444	Economy	13700.00
0005435242901	15444	Economy	13700.00
0005432784510	15444	Economy	13700.00
0005432784540	15444	Economy	13700.00
0005435242933	15444	Economy	13700.00
0005432784541	15444	Economy	13700.00
0005432784519	15444	Economy	13700.00
0005432784538	15444	Economy	13700.00
0005435242903	15444	Economy	13700.00
0005432784491	15444	Economy	13700.00
0005432784508	15444	Economy	13700.00
0005434879076	10094	Business	49700.00
0005434878998	10094	Business	49700.00
0005434878707	10094	Business	49700.00
0005434878870	10094	Business	49700.00
0005434879141	10094	Business	49700.00
0005434879106	10094	Business	49700.00
0005434878702	10094	Business	49700.00
0005434878563	10094	Business	49700.00
0005434878657	10094	Business	49700.00
0005434878541	10094	Business	49700.00
0005434878627	10094	Business	49700.00
0005434910146	10094	Business	49700.00
0005434878960	10094	Business	49700.00
0005435913977	10094	Business	49700.00
0005434878973	10094	Business	49700.00
0005434910147	10094	Business	49700.00
0005434878713	10094	Business	49700.00
0005434878961	10094	Business	49700.00
0005435913978	10094	Business	49700.00
0005434878794	10094	Economy	16600.00
0005434878487	10094	Business	49700.00
0005434878773	10094	Economy	16600.00
0005434878974	10094	Economy	16600.00
0005434878865	10094	Economy	16600.00
0005434878866	10094	Economy	16600.00
0005434878781	10094	Economy	16600.00
0005434879075	10094	Economy	16600.00
0005434879138	10094	Economy	16600.00
0005434878614	10094	Economy	16600.00
0005434878683	10094	Economy	16600.00
0005434878393	10094	Economy	16600.00
0005434878761	10094	Economy	16600.00
0005434878678	10094	Economy	18200.00
0005434878450	10094	Economy	18200.00
0005434878611	10094	Economy	18200.00
0005434878948	10094	Economy	18200.00
0005434878747	10094	Economy	16600.00
0005434878739	10094	Economy	16600.00
0005434879012	10094	Economy	16600.00
0005434878146	10094	Economy	16600.00
0005434878982	10094	Economy	16600.00
0005434878962	10094	Economy	16600.00
0005435913979	10094	Economy	16600.00
0005434878738	10094	Economy	16600.00
0005434878307	10094	Economy	16600.00
0005434878397	10094	Economy	16600.00
0005434878941	10094	Economy	16600.00
0005434878613	10094	Economy	16600.00
0005434878788	10094	Economy	16600.00
0005434878906	10094	Economy	16600.00
0005434878919	10094	Economy	16600.00
0005434878822	10094	Economy	16600.00
0005434878682	10094	Economy	16600.00
0005434878809	10094	Economy	16600.00
0005434878780	10094	Economy	16600.00
0005434878530	10094	Economy	16600.00
0005434878779	10094	Economy	16600.00
0005434878630	10094	Economy	16600.00
0005434878883	10094	Economy	16600.00
0005434878652	10094	Economy	16600.00
0005434758903	10094	Economy	16600.00
0005434878540	10094	Economy	16600.00
0005434758904	10094	Economy	16600.00
0005434878852	10094	Economy	16600.00
0005434878116	10094	Economy	16600.00
0005434879209	10094	Economy	16600.00
0005434878752	10094	Economy	16600.00
0005434878711	10094	Economy	16600.00
0005434878762	10094	Economy	16600.00
0005434878887	10094	Economy	16600.00
0005434878980	10094	Economy	16600.00
0005434878543	10094	Economy	16600.00
0005434879013	10094	Economy	16600.00
0005434878926	10094	Economy	16600.00
0005434878787	10094	Economy	16600.00
0005434878716	10094	Economy	16600.00
0005434878952	10094	Economy	16600.00
0005434879046	10094	Economy	16600.00
0005434878551	10094	Economy	16600.00
0005434879099	10094	Economy	16600.00
0005434910145	10094	Economy	16600.00
0005434878396	10094	Economy	16600.00
0005434878963	10094	Economy	16600.00
0005434878997	10094	Economy	16600.00
0005434878436	10094	Economy	16600.00
0005434878966	10094	Economy	16600.00
0005434879044	10094	Economy	16600.00
0005434878795	10094	Economy	16600.00
0005434878626	10094	Economy	16600.00
0005434878925	10094	Economy	16600.00
0005434878665	10094	Economy	16600.00
0005434878712	10094	Economy	16600.00
0005434879143	10094	Economy	16600.00
0005434878889	10094	Economy	16600.00
0005434879011	10094	Economy	16600.00
0005434878899	10094	Economy	16600.00
0005434879142	10094	Economy	16600.00
0005434878772	10094	Economy	16600.00
0005434878710	10094	Economy	16600.00
0005434878715	10094	Economy	16600.00
0005434879098	10094	Economy	16600.00
0005434878886	10094	Economy	16600.00
0005434878999	10094	Economy	16600.00
0005434878490	10094	Economy	16600.00
0005434879116	10094	Economy	16600.00
0005434878656	10094	Economy	16600.00
0005434758902	10094	Economy	16600.00
0005434879543	14600	Business	49700.00
0005434879564	14600	Business	49700.00
0005434879555	14600	Business	49700.00
0005434758927	14600	Business	49700.00
0005434879620	14600	Business	49700.00
0005434879554	14600	Business	49700.00
0005434879580	14600	Business	49700.00
0005434879542	14600	Business	49700.00
0005434879603	14600	Business	49700.00
0005434879545	14600	Business	49700.00
0005434758928	14600	Business	49700.00
0005434879550	14600	Business	49700.00
0005434879628	14600	Business	49700.00
0005434879567	14600	Business	49700.00
0005434879585	14600	Business	49700.00
0005434879586	14600	Business	49700.00
0005434879551	14600	Business	49700.00
0005434879616	14600	Business	49700.00
0005434879546	14600	Business	49700.00
0005434879563	14600	Business	49700.00
0005435913943	14600	Economy	16600.00
0005434879612	14600	Economy	16600.00
0005434879582	14600	Economy	16600.00
0005434879559	14600	Economy	16600.00
0005434879547	14600	Economy	16600.00
0005434879629	14600	Economy	16600.00
0005434879566	14600	Economy	16600.00
0005434879617	14600	Economy	16600.00
0005434879600	14600	Economy	16600.00
0005434879578	14600	Economy	16600.00
0005435913940	14600	Economy	16600.00
0005434879631	14600	Economy	16600.00
0005434879592	14600	Economy	18200.00
0005434879558	14600	Economy	18200.00
0005434879574	14600	Economy	18200.00
0005434879609	14600	Economy	16600.00
0005434879607	14600	Economy	16600.00
0005434879583	14600	Economy	16600.00
0005434879556	14600	Economy	16600.00
0005434879589	14600	Economy	16600.00
0005434879606	14600	Economy	16600.00
0005434879622	14600	Economy	16600.00
0005434879579	14600	Economy	16600.00
0005434879570	14600	Economy	16600.00
0005434758926	14600	Economy	16600.00
0005434879618	14600	Economy	16600.00
0005434879576	14600	Economy	16600.00
0005434879625	14600	Economy	16600.00
0005435913942	14600	Economy	16600.00
0005434879626	14600	Economy	16600.00
0005434879573	14600	Economy	16600.00
0005434879621	14600	Economy	16600.00
0005434879584	14600	Economy	16600.00
0005434879623	14600	Economy	16600.00
0005434879591	14600	Economy	16600.00
0005434879575	14600	Economy	16600.00
0005434879619	14600	Economy	16600.00
0005434879601	14600	Economy	16600.00
0005434879552	14600	Economy	16600.00
0005434879561	14600	Economy	16600.00
0005434879544	14600	Economy	16600.00
0005434879581	14600	Economy	16600.00
0005434879593	14600	Economy	16600.00
0005434879568	14600	Economy	16600.00
0005434879632	14600	Economy	16600.00
0005435913941	14600	Economy	16600.00
0005435913939	14600	Economy	16600.00
0005434879540	14600	Economy	16600.00
0005434879548	14600	Economy	16600.00
0005434879598	14600	Economy	16600.00
0005434879595	14600	Economy	16600.00
0005434879572	14600	Economy	16600.00
0005434879630	14600	Economy	16600.00
0005434879539	14600	Economy	16600.00
0005434879588	14600	Economy	16600.00
0005434879604	14600	Economy	16600.00
0005435913938	14600	Economy	16600.00
0005434879553	14600	Economy	16600.00
0005434879614	14600	Economy	16600.00
0005434879611	14600	Economy	16600.00
0005434879624	14600	Economy	16600.00
0005434879569	14600	Economy	16600.00
0005434879613	14600	Economy	16600.00
0005434879596	14600	Economy	16600.00
0005434879577	14600	Economy	16600.00
0005434879557	14600	Economy	16600.00
0005434879538	14600	Economy	16600.00
0005434879565	14600	Economy	16600.00
0005434879615	14600	Economy	16600.00
0005435913949	14600	Economy	16600.00
0005434879541	14600	Economy	16600.00
0005434879602	14600	Economy	16600.00
0005434879560	14600	Economy	16600.00
0005434879610	14600	Economy	16600.00
0005434879597	14600	Economy	16600.00
0005434879594	14600	Economy	16600.00
0005434879608	14600	Economy	16600.00
0005434879605	14600	Economy	16600.00
0005434879587	14600	Economy	16600.00
0005434879627	14600	Economy	16600.00
0005434879590	14600	Economy	16600.00
0005434879571	14600	Economy	16600.00
0005434879599	14600	Economy	16600.00
0005434879562	14600	Economy	16600.00
0005434879549	14600	Economy	16600.00
0005435660304	9247	Economy	22400.00
0005434252043	9247	Economy	22400.00
0005434252007	9247	Economy	20300.00
0005435660294	9247	Economy	20300.00
0005434252058	9247	Economy	20300.00
0005435660297	9247	Economy	20300.00
0005435660303	9247	Economy	20300.00
0005435660298	9247	Economy	20300.00
0005435660301	9247	Economy	20300.00
0005434252029	9247	Economy	20300.00
0005435660296	9247	Economy	20300.00
0005434252006	9247	Economy	20300.00
0005434252057	9247	Economy	20300.00
0005435660295	9247	Economy	20300.00
0005435660300	9247	Economy	20300.00
0005434252004	9247	Economy	20300.00
0005435660302	9247	Economy	20300.00
0005434252005	9247	Economy	20300.00
0005435660299	9247	Economy	20300.00
0005435660191	24646	Economy	22400.00
0005434252100	24646	Economy	22400.00
0005435660121	24646	Economy	22400.00
0005435660167	24646	Economy	20300.00
0005435660273	24646	Economy	20300.00
0005435660206	24646	Economy	20300.00
0005434252102	24646	Economy	20300.00
0005435660209	24646	Economy	20300.00
0005434252103	24646	Economy	20300.00
0005435660203	24646	Economy	20300.00
0005435660122	24646	Economy	20300.00
0005434252098	24646	Economy	20300.00
0005435660247	24646	Economy	20300.00
0005435660221	24646	Economy	20300.00
0005434252105	24646	Economy	20300.00
0005435660166	24646	Economy	20300.00
0005434252104	24646	Economy	20300.00
0005435660198	24646	Economy	20300.00
0005434252107	24646	Economy	20300.00
0005435660222	24646	Economy	20300.00
0005435660161	24646	Economy	20300.00
0005434252099	24646	Economy	20300.00
0005434252097	24646	Economy	20300.00
0005435660193	24646	Economy	20300.00
0005435660172	24646	Economy	20300.00
0005435660213	24646	Economy	20300.00
0005434252101	24646	Economy	20300.00
0005434252106	24646	Economy	20300.00
0005435660190	24646	Economy	20300.00
0005435660218	24646	Economy	20300.00
0005433681260	2783	Business	33000.00
0005433681267	2783	Business	33000.00
0005432967148	2783	Business	33000.00
0005433681257	2783	Business	33000.00
0005433681253	2783	Business	33000.00
0005433681238	2783	Business	33000.00
0005433681228	2783	Business	33000.00
0005433681230	2783	Business	33000.00
0005433681233	2783	Economy	11000.00
0005432967247	2783	Economy	11000.00
0005432222856	2783	Economy	11000.00
0005433681244	2783	Economy	11000.00
0005432967195	2783	Economy	11000.00
0005433681241	2783	Economy	11000.00
0005432967071	2783	Economy	11000.00
0005432967024	2783	Economy	11000.00
0005432967144	2783	Economy	11000.00
0005433681258	2783	Economy	12100.00
0005432222859	2783	Economy	12100.00
0005433681264	2783	Economy	12100.00
0005433681232	2783	Economy	12100.00
0005433681236	2783	Economy	11000.00
0005433681248	2783	Economy	11000.00
0005433681268	2783	Economy	11000.00
0005432967124	2783	Economy	11000.00
0005432967092	2783	Economy	11000.00
0005433681261	2783	Economy	11000.00
0005432222855	2783	Economy	11000.00
0005433681237	2783	Economy	11000.00
0005433684448	2783	Economy	11000.00
0005432966971	2783	Economy	11000.00
0005433684449	2783	Economy	11000.00
0005433681227	2783	Economy	11000.00
0005432222857	2783	Economy	11000.00
0005433681262	2783	Economy	11000.00
0005432967059	2783	Economy	11000.00
0005433681234	2783	Economy	11000.00
0005432967093	2783	Economy	11000.00
0005433681229	2783	Economy	11000.00
0005432967023	2783	Economy	11000.00
0005433681247	2783	Economy	11000.00
0005433681255	2783	Economy	11000.00
0005433681226	2783	Economy	11000.00
0005433681266	2783	Economy	11000.00
0005433681259	2783	Economy	11000.00
0005432967137	2783	Economy	11000.00
0005433681250	2783	Economy	11000.00
0005432966900	2783	Economy	11000.00
0005433681270	2783	Economy	11000.00
0005432967123	2783	Economy	11000.00
0005432967058	2783	Economy	11000.00
0005433681224	2783	Economy	11000.00
0005433681272	2783	Economy	11000.00
0005433681271	2783	Economy	11000.00
0005433681246	2783	Economy	11000.00
0005432967070	2783	Economy	11000.00
0005433681265	2783	Economy	11000.00
0005433681254	2783	Economy	11000.00
0005433681243	2783	Economy	11000.00
0005433681231	2783	Economy	11000.00
0005433681252	2783	Economy	11000.00
0005433681269	2783	Economy	11000.00
0005433681256	2783	Economy	11000.00
0005432967145	2783	Economy	11000.00
0005432222860	2783	Economy	11000.00
0005432967072	2783	Economy	11000.00
0005433681249	2783	Economy	11000.00
0005433681273	2783	Economy	11000.00
0005433681239	2783	Economy	11000.00
0005433681263	2783	Economy	11000.00
0005433681225	2783	Economy	11000.00
0005433681251	2783	Economy	11000.00
0005433681240	2783	Economy	11000.00
0005432222858	2783	Economy	11000.00
0005433681242	2783	Economy	11000.00
0005433681235	2783	Economy	11000.00
0005433681245	2783	Economy	11000.00
0005432967290	29161	Business	33000.00
0005432967300	29161	Business	33000.00
0005433680874	29161	Business	33000.00
0005433680875	29161	Business	33000.00
0005432005254	29161	Business	33000.00
0005433681082	29161	Business	33000.00
0005433680938	29161	Business	33000.00
0005433680733	29161	Business	33000.00
0005433680737	29161	Business	33000.00
0005433680781	29161	Business	33000.00
0005433680736	29161	Business	33000.00
0005432967305	29161	Business	33000.00
0005433680757	29161	Economy	11000.00
0005433680761	29161	Economy	11000.00
0005433680836	29161	Economy	11000.00
0005433680886	29161	Economy	11000.00
0005433680958	29161	Economy	11000.00
0005433687710	29161	Economy	11000.00
0005433680849	29161	Economy	11000.00
0005433680927	29161	Economy	11000.00
0005433687709	29161	Economy	11000.00
0005432967307	29161	Economy	11000.00
0005433687708	29161	Economy	12100.00
0005432967308	29161	Economy	12100.00
0005432967297	29161	Economy	12100.00
0005433680526	29161	Economy	11000.00
0005433680969	29161	Economy	11000.00
0005432967294	29161	Economy	11000.00
0005433680914	29161	Economy	11000.00
0005432005255	29161	Economy	11000.00
0005433680782	29161	Economy	11000.00
0005433680885	29161	Economy	11000.00
0005433680790	29161	Economy	11000.00
0005433680791	29161	Economy	11000.00
0005432967302	29161	Economy	11000.00
0005433680811	29161	Economy	11000.00
0005432967301	29161	Economy	11000.00
0005432967313	29161	Economy	11000.00
0005433680918	29161	Economy	11000.00
0005432967293	29161	Economy	11000.00
0005433680867	29161	Economy	11000.00
0005433680788	29161	Economy	11000.00
0005432967306	29161	Economy	11000.00
0005433680917	29161	Economy	11000.00
0005432967312	29161	Economy	11000.00
0005433680809	29161	Economy	11000.00
0005432967299	29161	Economy	11000.00
0005433680527	29161	Economy	11000.00
0005433690940	29161	Economy	11000.00
0005433680937	29161	Economy	11000.00
0005432967310	29161	Economy	11000.00
0005432967292	29161	Economy	11000.00
0005432967314	29161	Economy	11000.00
0005433680786	29161	Economy	11000.00
0005433681009	29161	Economy	11000.00
0005433680760	29161	Economy	11000.00
0005433680787	29161	Economy	11000.00
0005432967303	29161	Economy	11000.00
0005433680868	29161	Economy	11000.00
0005433680970	29161	Economy	11000.00
0005433681021	29161	Economy	11000.00
0005433681053	29161	Economy	11000.00
0005433680804	29161	Economy	11000.00
0005432967311	29161	Economy	11000.00
0005432967298	29161	Economy	11000.00
0005433680794	29161	Economy	11000.00
0005432967309	29161	Economy	11000.00
0005433680953	29161	Economy	11000.00
0005432967304	29161	Economy	11000.00
0005433680912	29161	Economy	11000.00
0005433680840	29161	Economy	11000.00
0005433680954	29161	Economy	11000.00
0005432967296	29161	Economy	11000.00
0005433680884	29161	Economy	11000.00
0005433680881	29161	Economy	11000.00
0005432967291	29161	Economy	11000.00
0005433690941	29161	Economy	11000.00
0005433680758	29161	Economy	11000.00
0005433680678	29161	Economy	11000.00
0005433680789	29161	Economy	11000.00
0005433680911	29161	Economy	11000.00
0005433680734	29161	Economy	11000.00
0005432967295	29161	Economy	11000.00
0005432005253	29161	Economy	11000.00
0005433690939	29161	Economy	11000.00
0005433634277	9273	Business	132900.00
0005433615642	9273	Business	132900.00
0005433615701	9273	Business	132900.00
0005432756894	9273	Business	132900.00
0005432145140	9273	Business	132900.00
0005433615644	9273	Business	132900.00
0005433615640	9273	Business	132900.00
0005433615700	9273	Business	132900.00
0005433634287	9273	Business	132900.00
0005433634279	9273	Business	132900.00
0005434163661	9273	Business	132900.00
0005432755124	9273	Business	132900.00
0005433615649	9273	Business	132900.00
0005433615683	9273	Business	132900.00
0005433577999	9273	Business	132900.00
0005433615672	9273	Business	132900.00
0005433634278	9273	Business	132900.00
0005433634270	9273	Business	132900.00
0005433634275	9273	Business	132900.00
0005433578005	9273	Economy	48700.00
0005433615667	9273	Economy	48700.00
0005433577993	9273	Economy	48700.00
0005433634268	9273	Economy	48700.00
0005432755121	9273	Economy	48700.00
0005433615679	9273	Economy	48700.00
0005433634286	9273	Economy	44300.00
0005434163673	9273	Economy	44300.00
0005433615654	9273	Economy	44300.00
0005433615705	9273	Economy	44300.00
0005433634265	9273	Economy	44300.00
0005434152791	9273	Economy	44300.00
0005433615646	9273	Economy	44300.00
0005433615690	9273	Economy	44300.00
0005433615706	9273	Economy	44300.00
0005433615681	9273	Economy	44300.00
0005433615688	9273	Economy	44300.00
0005433578003	9273	Economy	44300.00
0005433578004	9273	Economy	44300.00
0005433634283	9273	Economy	44300.00
0005433634264	9273	Economy	44300.00
0005433634293	9273	Economy	44300.00
0005433615655	9273	Economy	44300.00
0005433577995	9273	Economy	44300.00
0005433615656	9273	Economy	44300.00
0005432756895	9273	Economy	44300.00
0005433615661	9273	Economy	44300.00
0005433634274	9273	Economy	44300.00
0005433634273	9273	Economy	44300.00
0005433615639	9273	Economy	44300.00
0005434152792	9273	Economy	44300.00
0005433634289	9273	Economy	44300.00
0005433615648	9273	Economy	44300.00
0005433615664	9273	Economy	44300.00
0005433615678	9273	Economy	44300.00
0005433615657	9273	Economy	44300.00
0005433615692	9273	Economy	44300.00
0005433634284	9273	Economy	44300.00
0005433615696	9273	Economy	44300.00
0005433634272	9273	Economy	44300.00
0005433615650	9273	Economy	44300.00
0005433615637	9273	Economy	44300.00
0005433615674	9273	Economy	44300.00
0005433615703	9273	Economy	44300.00
0005433615643	9273	Economy	44300.00
0005433634260	9273	Economy	44300.00
0005433615641	9273	Economy	44300.00
0005433577997	9273	Economy	44300.00
0005433615699	9273	Economy	44300.00
0005434272206	9273	Economy	44300.00
0005433615636	9273	Economy	44300.00
0005433615666	9273	Economy	44300.00
0005433577996	9273	Economy	44300.00
0005433615697	9273	Economy	44300.00
0005432755123	9273	Economy	44300.00
0005433615687	9273	Economy	44300.00
0005433634263	9273	Economy	44300.00
0005433615632	9273	Economy	44300.00
0005433634281	9273	Economy	44300.00
0005433615668	9273	Economy	44300.00
0005434152784	9273	Economy	48700.00
0005433615633	9273	Economy	48700.00
0005433634261	9273	Economy	48700.00
0005433615675	9273	Economy	48700.00
0005433634266	9273	Economy	44300.00
0005433615684	9273	Economy	44300.00
0005433615665	9273	Economy	44300.00
0005433615647	9273	Economy	48700.00
0005433634285	9273	Economy	44300.00
0005433615677	9273	Economy	44300.00
0005433615663	9273	Economy	44300.00
0005434272207	9273	Economy	44300.00
0005433615698	9273	Economy	44300.00
0005432756896	9273	Economy	44300.00
0005433615638	9273	Economy	44300.00
0005432756897	9273	Economy	44300.00
0005433634269	9273	Economy	44300.00
0005433615652	9273	Economy	44300.00
0005432145139	9273	Economy	44300.00
0005433615676	9273	Economy	44300.00
0005433634288	9273	Economy	44300.00
0005433615693	9273	Economy	44300.00
0005433615669	9273	Economy	44300.00
0005433615680	9273	Economy	44300.00
0005433615704	9273	Economy	44300.00
0005433634280	9273	Economy	44300.00
0005433577994	9273	Economy	44300.00
0005433615651	9273	Economy	44300.00
0005433634282	9273	Economy	44300.00
0005434272200	9273	Economy	44300.00
0005433634294	9273	Economy	44300.00
0005433615635	9273	Economy	44300.00
0005433634262	9273	Economy	44300.00
0005433634292	9273	Economy	44300.00
0005433615685	9273	Economy	44300.00
0005433615686	9273	Economy	44300.00
0005433615682	9273	Economy	44300.00
0005433634291	9273	Economy	44300.00
0005433634271	9273	Economy	44300.00
0005433578000	9273	Economy	44300.00
0005433634276	9273	Economy	44300.00
0005433615653	9273	Economy	44300.00
0005433615660	9273	Economy	44300.00
0005434163689	9273	Economy	44300.00
0005433634290	9273	Economy	44300.00
0005433615658	9273	Economy	44300.00
0005433615634	9273	Economy	44300.00
0005433615694	9273	Economy	44300.00
0005433578001	9273	Economy	44300.00
0005433578002	9273	Economy	44300.00
0005433615671	9273	Economy	44300.00
0005433615662	9273	Economy	44300.00
0005433577998	9273	Economy	44300.00
0005433615659	9273	Economy	44300.00
0005433578006	9273	Economy	44300.00
0005434163688	9273	Economy	44300.00
0005433615689	9273	Economy	44300.00
0005433615645	9273	Economy	44300.00
0005432755122	9273	Economy	44300.00
0005433615702	9273	Economy	44300.00
0005433615691	9273	Economy	44300.00
0005433615673	9273	Economy	44300.00
0005433615670	9273	Economy	44300.00
0005433634267	9273	Economy	44300.00
0005433615695	9273	Economy	44300.00
0005433633972	25209	Business	132900.00
0005432751548	25209	Business	132900.00
0005433615226	25209	Business	132900.00
0005433577874	25209	Business	132900.00
0005433633998	25209	Business	132900.00
0005433633948	25209	Business	132900.00
0005433614831	25209	Business	132900.00
0005433633927	25209	Business	132900.00
0005432751542	25209	Business	132900.00
0005433633912	25209	Business	132900.00
0005433634011	25209	Business	132900.00
0005433615046	25209	Business	132900.00
0005433634059	25209	Business	132900.00
0005433614888	25209	Business	132900.00
0005433615078	25209	Business	132900.00
0005432751529	25209	Business	132900.00
0005433614983	25209	Business	132900.00
0005433615077	25209	Business	132900.00
0005433633971	25209	Business	132900.00
0005433615123	25209	Business	132900.00
0005433614856	25209	Business	132900.00
0005433614889	25209	Business	132900.00
0005433633928	25209	Business	132900.00
0005433614957	25209	Business	132900.00
0005433633774	25209	Business	132900.00
0005433633994	25209	Business	132900.00
0005433614680	25209	Economy	48700.00
0005434152819	25209	Economy	48700.00
0005433615236	25209	Economy	48700.00
0005433614679	25209	Economy	48700.00
0005433633978	25209	Economy	48700.00
0005433614912	25209	Economy	44300.00
0005434163746	25209	Economy	44300.00
0005432755082	25209	Economy	44300.00
0005433634009	25209	Economy	44300.00
0005433577908	25209	Economy	44300.00
0005434163752	25209	Economy	44300.00
0005434152817	25209	Economy	44300.00
0005432755076	25209	Economy	44300.00
0005433615269	25209	Economy	44300.00
0005433615297	25209	Economy	44300.00
0005433615235	25209	Economy	44300.00
0005433633865	25209	Economy	44300.00
0005433615136	25209	Economy	44300.00
0005433614542	25209	Economy	44300.00
0005433615007	25209	Economy	44300.00
0005433614890	25209	Economy	44300.00
0005433577871	25209	Economy	44300.00
0005433577909	25209	Economy	44300.00
0005433615230	25209	Economy	44300.00
0005433633811	25209	Economy	44300.00
0005433634042	25209	Economy	44300.00
0005434152818	25209	Economy	44300.00
0005432751528	25209	Economy	44300.00
0005433633812	25209	Economy	44300.00
0005433615093	25209	Economy	44300.00
0005433634035	25209	Economy	44300.00
0005432751544	25209	Economy	44300.00
0005433615035	25209	Economy	44300.00
0005433615229	25209	Economy	44300.00
0005433615006	25209	Economy	44300.00
0005433615163	25209	Economy	44300.00
0005433615079	25209	Economy	44300.00
0005434163753	25209	Economy	44300.00
0005433615045	25209	Economy	44300.00
0005433633866	25209	Economy	44300.00
0005433615157	25209	Economy	44300.00
0005432751512	25209	Economy	44300.00
0005432755078	25209	Economy	44300.00
0005433633810	25209	Economy	44300.00
0005432755084	25209	Economy	44300.00
0005433633868	25209	Economy	44300.00
0005433614938	25209	Economy	44300.00
0005433577900	25209	Economy	44300.00
0005433633949	25209	Economy	44300.00
0005433633773	25209	Economy	44300.00
0005432751514	25209	Economy	44300.00
0005434152823	25209	Economy	44300.00
0005433634000	25209	Economy	44300.00
0005433633964	25209	Economy	44300.00
0005433633960	25209	Economy	44300.00
0005433633911	25209	Economy	44300.00
0005434152820	25209	Economy	44300.00
0005433615232	25209	Economy	44300.00
0005433614811	25209	Economy	44300.00
0005433614857	25209	Economy	44300.00
0005433615233	25209	Economy	44300.00
0005433615256	25209	Economy	48700.00
0005434163748	25209	Economy	48700.00
0005433614915	25209	Economy	48700.00
0005433634136	25209	Economy	48700.00
0005432751538	25209	Economy	44300.00
0005432755085	25209	Economy	44300.00
0005432751531	25209	Economy	44300.00
0005433634067	25209	Economy	44300.00
0005433614920	25209	Economy	44300.00
0005433614810	25209	Economy	48700.00
0005433614882	25209	Economy	44300.00
0005433615052	25209	Economy	44300.00
0005433615124	25209	Economy	44300.00
0005433615036	25209	Economy	44300.00
0005433615105	25209	Economy	44300.00
0005433577899	25209	Economy	44300.00
0005433615116	25209	Economy	44300.00
0005434152815	25209	Economy	44300.00
0005433633993	25209	Economy	44300.00
0005432751530	25209	Economy	44300.00
0005433614914	25209	Economy	44300.00
0005433614939	25209	Economy	44300.00
0005433577872	25209	Economy	44300.00
0005432751522	25209	Economy	44300.00
0005433615234	25209	Economy	44300.00
0005433634058	25209	Economy	44300.00
0005434152816	25209	Economy	44300.00
0005434152822	25209	Economy	44300.00
0005434163750	25209	Economy	44300.00
0005432755083	25209	Economy	44300.00
0005433614928	25209	Economy	44300.00
0005432751513	25209	Economy	44300.00
0005433615211	25209	Economy	44300.00
0005433614950	25209	Economy	44300.00
0005433615324	25209	Economy	44300.00
0005433615106	25209	Economy	44300.00
0005433634048	25209	Economy	44300.00
0005433634135	25209	Economy	44300.00
0005433633965	25209	Economy	44300.00
0005433633999	25209	Economy	44300.00
0005433615047	25209	Economy	44300.00
0005433615237	25209	Economy	44300.00
0005432751521	25209	Economy	44300.00
0005434163749	25209	Economy	44300.00
0005433614835	25209	Economy	44300.00
0005434152814	25209	Economy	44300.00
0005433614681	25209	Economy	44300.00
0005433615076	25209	Economy	44300.00
0005432755077	25209	Economy	44300.00
0005433633957	25209	Economy	44300.00
0005433615117	25209	Economy	44300.00
0005433614919	25209	Economy	44300.00
0005433634045	25209	Economy	44300.00
0005433633944	25209	Economy	44300.00
0005433615060	25209	Economy	44300.00
0005433615210	25209	Economy	44300.00
0005433633919	25209	Economy	44300.00
0005434152821	25209	Economy	44300.00
0005434163751	25209	Economy	44300.00
0005434163747	25209	Economy	44300.00
0005433633784	25209	Economy	44300.00
0005433615085	25209	Economy	44300.00
0005433633867	25209	Economy	44300.00
0005433614682	25209	Economy	44300.00
0005433634010	25209	Economy	44300.00
0005433615061	25209	Economy	44300.00
0005432755079	25209	Economy	44300.00
0005432751543	25209	Economy	44300.00
0005433614937	25209	Economy	44300.00
0005433615128	25209	Economy	44300.00
0005432751540	25209	Economy	44300.00
0005433615095	25209	Economy	44300.00
0005433614991	25209	Economy	44300.00
0005435787361	4217	Business	193100.00
0005432571343	4217	Business	193100.00
0005435986863	4217	Economy	64400.00
0005435787354	4217	Economy	64400.00
0005435947334	4217	Economy	64400.00
0005435986859	4217	Economy	64400.00
0005435947333	4217	Economy	64400.00
0005432184992	4217	Economy	64400.00
0005435986866	4217	Economy	64400.00
0005435986864	4217	Economy	64400.00
0005435986856	4217	Economy	64400.00
0005435787362	4217	Economy	64400.00
0005435856229	4217	Economy	64400.00
0005435947370	4217	Economy	64400.00
0005435947302	4217	Economy	64400.00
0005434271313	4217	Economy	64400.00
0005432184993	4217	Economy	64400.00
0005435986857	4217	Economy	64400.00
0005435947335	4217	Economy	64400.00
0005435986860	4217	Economy	64400.00
0005435947392	4217	Economy	64400.00
0005435947369	4217	Economy	64400.00
0005435947342	4217	Economy	64400.00
0005432571347	4217	Economy	64400.00
0005435986862	4217	Economy	64400.00
0005435986861	4217	Economy	64400.00
0005435947365	4217	Economy	64400.00
0005435947326	4217	Economy	64400.00
0005435947364	4217	Economy	64400.00
0005435947393	4217	Economy	64400.00
0005435947303	4217	Economy	64400.00
0005432571342	4217	Economy	64400.00
0005435854063	4217	Economy	64400.00
0005435986865	4217	Economy	64400.00
0005435986858	4217	Economy	64400.00
0005432184994	4217	Economy	64400.00
0005432571348	4217	Economy	64400.00
0005432571341	4217	Economy	64400.00
0005435947461	26568	Economy	64400.00
0005432571379	26568	Economy	64400.00
0005435947473	26568	Economy	64400.00
0005432571378	26568	Economy	64400.00
0005432571380	26568	Economy	64400.00
0005435787388	26568	Economy	64400.00
0005435947460	26568	Economy	64400.00
0005435856266	26568	Economy	64400.00
0005435856264	26568	Economy	64400.00
0005435947464	26568	Economy	64400.00
0005435947463	26568	Economy	64400.00
0005435787387	26568	Economy	64400.00
0005435986745	26568	Economy	64400.00
0005435856265	26568	Economy	64400.00
0005435947468	26568	Economy	64400.00
0005435947459	26568	Economy	64400.00
0005435947465	26568	Economy	64400.00
0005432571381	26568	Economy	64400.00
0005435947466	26568	Economy	64400.00
0005435947467	26568	Economy	64400.00
0005435947462	26568	Economy	64400.00
0005435947471	26568	Economy	64400.00
0005435947469	26568	Economy	64400.00
0005435947472	26568	Economy	64400.00
0005435986751	26568	Economy	64400.00
0005435947470	26568	Economy	64400.00
0005435986744	26568	Economy	64400.00
0005435856267	26568	Economy	64400.00
0005433129315	349	Business	21500.00
0005433569953	349	Business	21500.00
0005433569949	349	Business	21500.00
0005433569963	349	Business	21500.00
0005433074889	349	Business	21500.00
0005432948602	349	Business	21500.00
0005433569940	349	Business	21500.00
0005433569939	349	Business	21500.00
0005433569918	349	Business	21500.00
0005433569915	349	Business	21500.00
0005433569929	349	Business	21500.00
0005433569937	349	Business	21500.00
0005433134183	349	Business	21500.00
0005433569955	349	Business	21500.00
0005433074751	349	Business	21500.00
0005432948650	349	Business	21500.00
0005433569962	349	Business	21500.00
0005433074804	349	Business	21500.00
0005432239025	349	Business	21500.00
0005433129299	349	Business	21500.00
0005434087919	349	Business	21500.00
0005433569919	349	Business	21500.00
0005433074888	349	Business	21500.00
0005433569946	349	Business	21500.00
0005433569910	349	Economy	7900.00
0005433569952	349	Economy	7900.00
0005433074876	349	Economy	7900.00
0005433074831	349	Economy	7900.00
0005433074795	349	Economy	7900.00
0005433569943	349	Economy	7200.00
0005433569958	349	Economy	7200.00
0005433129300	349	Economy	7200.00
0005433569923	349	Economy	7200.00
0005433569944	349	Economy	7200.00
0005432948633	349	Economy	7200.00
0005433569926	349	Economy	7200.00
0005433569954	349	Economy	7200.00
0005434087920	349	Economy	7200.00
0005433569927	349	Economy	7200.00
0005433569921	349	Economy	7200.00
0005433129316	349	Economy	7200.00
0005433134166	349	Economy	7200.00
0005433569951	349	Economy	7200.00
0005433569965	349	Economy	7200.00
0005432948803	349	Economy	7200.00
0005433569968	349	Economy	7200.00
0005432948736	349	Economy	7200.00
0005433074877	349	Economy	7200.00
0005433569960	349	Economy	7200.00
0005433569941	349	Economy	7200.00
0005432239022	349	Economy	7200.00
0005433569930	349	Economy	7200.00
0005433569947	349	Economy	7200.00
0005433569928	349	Economy	7200.00
0005433074750	349	Economy	7200.00
0005432948810	349	Economy	7200.00
0005432948802	349	Economy	7200.00
0005433569935	349	Economy	7200.00
0005433074841	349	Economy	7200.00
0005432948624	349	Economy	7200.00
0005433134185	349	Economy	7200.00
0005433569914	349	Economy	7200.00
0005432948651	349	Economy	7200.00
0005432948600	349	Economy	7200.00
0005433569932	349	Economy	7200.00
0005432948592	349	Economy	7200.00
0005433569925	349	Economy	7200.00
0005432239024	349	Economy	7200.00
0005433569924	349	Economy	7200.00
0005433569922	349	Economy	7200.00
0005432948737	349	Economy	7200.00
0005433569908	349	Economy	7200.00
0005432948808	349	Economy	7200.00
0005433074836	349	Economy	7200.00
0005433569912	349	Economy	7200.00
0005433134157	349	Economy	7200.00
0005432239023	349	Economy	7900.00
0005433569966	349	Economy	7900.00
0005433074749	349	Economy	7900.00
0005433074887	349	Economy	7900.00
0005433569970	349	Economy	7900.00
0005433569933	349	Economy	7200.00
0005433569917	349	Economy	7200.00
0005433134167	349	Economy	7200.00
0005433569934	349	Economy	7900.00
0005432948920	349	Economy	7200.00
0005432948747	349	Economy	7200.00
0005432948710	349	Economy	7200.00
0005432948613	349	Economy	7200.00
0005433569950	349	Economy	7200.00
0005433569942	349	Economy	7200.00
0005433569920	349	Economy	7200.00
0005433569913	349	Economy	7200.00
0005433074834	349	Economy	7200.00
0005433569956	349	Economy	7200.00
0005433569959	349	Economy	7200.00
0005433134173	349	Economy	7200.00
0005433569909	349	Economy	7200.00
0005432948539	349	Economy	7200.00
0005432948585	349	Economy	7200.00
0005433569938	349	Economy	7200.00
0005433569931	349	Economy	7200.00
0005432948532	349	Economy	7200.00
0005432948634	349	Economy	7200.00
0005433569916	349	Economy	7200.00
0005432948713	349	Economy	7200.00
0005432239026	349	Economy	7200.00
0005433134170	349	Economy	7200.00
0005433129314	349	Economy	7200.00
0005433074860	349	Economy	7200.00
0005433569948	349	Economy	7200.00
0005433074952	349	Economy	7200.00
0005433074820	349	Economy	7200.00
0005433074835	349	Economy	7200.00
0005432239027	349	Economy	7200.00
0005433569945	349	Economy	7200.00
0005433134160	349	Economy	7200.00
0005433569967	349	Economy	7200.00
0005433134162	349	Economy	7200.00
0005432948712	349	Economy	7200.00
0005433569936	349	Economy	7200.00
0005433569969	349	Economy	7200.00
0005433074940	349	Economy	7200.00
0005433569961	349	Economy	7200.00
0005432948540	349	Economy	7200.00
0005432948733	349	Economy	7200.00
0005432948714	349	Economy	7200.00
0005433129317	349	Economy	7200.00
0005433134182	349	Economy	7200.00
0005433074853	349	Economy	7200.00
0005433569911	349	Economy	7200.00
0005432948601	349	Economy	7200.00
0005433074953	349	Economy	7200.00
0005434087921	349	Economy	7200.00
0005433569957	349	Economy	7200.00
0005433569964	349	Economy	7200.00
0005433074956	349	Economy	7200.00
0005432949056	11573	Business	21500.00
0005433569515	11573	Business	21500.00
0005432949024	11573	Business	21500.00
0005433569388	11573	Business	21500.00
0005433569315	11573	Business	21500.00
0005433075104	11573	Business	21500.00
0005432949055	11573	Business	21500.00
0005432949035	11573	Business	21500.00
0005433075116	11573	Business	21500.00
0005432949051	11573	Business	21500.00
0005432949033	11573	Business	21500.00
0005433075127	11573	Business	21500.00
0005432949027	11573	Business	21500.00
0005433075101	11573	Business	21500.00
0005433569020	11573	Business	21500.00
0005432949040	11573	Business	21500.00
0005433134205	11573	Business	21500.00
0005432949037	11573	Business	21500.00
0005433131772	11573	Business	21500.00
0005433569382	11573	Business	21500.00
0005433569268	11573	Business	21500.00
0005433134203	11573	Business	21500.00
0005433134202	11573	Business	21500.00
0005433569289	11573	Business	21500.00
0005433075123	11573	Economy	7900.00
0005432949041	11573	Economy	7900.00
0005433569325	11573	Economy	7900.00
0005432949052	11573	Economy	7900.00
0005433569227	11573	Economy	7900.00
0005433569034	11573	Economy	7900.00
0005432949034	11573	Economy	7200.00
0005432949047	11573	Economy	7200.00
0005433569403	11573	Economy	7200.00
0005433075129	11573	Economy	7200.00
0005433569430	11573	Economy	7200.00
0005433569259	11573	Economy	7200.00
0005433075120	11573	Economy	7200.00
0005432949028	11573	Economy	7200.00
0005433075109	11573	Economy	7200.00
0005432949039	11573	Economy	7200.00
0005432192365	11573	Economy	7200.00
0005432949046	11573	Economy	7200.00
0005432949032	11573	Economy	7200.00
0005433569426	11573	Economy	7200.00
0005433569077	11573	Economy	7200.00
0005433134204	11573	Economy	7200.00
0005432949015	11573	Economy	7200.00
0005433569306	11573	Economy	7200.00
0005433569211	11573	Economy	7200.00
0005433569404	11573	Economy	7200.00
0005433569226	11573	Economy	7200.00
0005433569021	11573	Economy	7200.00
0005433131774	11573	Economy	7200.00
0005433131773	11573	Economy	7200.00
0005433569305	11573	Economy	7200.00
0005433929859	11573	Economy	7200.00
0005432949017	11573	Economy	7200.00
0005432949045	11573	Economy	7200.00
0005433569266	11573	Economy	7200.00
0005433075118	11573	Economy	7200.00
0005433569191	11573	Economy	7200.00
0005433929860	11573	Economy	7200.00
0005433075112	11573	Economy	7200.00
0005432949042	11573	Economy	7200.00
0005433569251	11573	Economy	7200.00
0005433075105	11573	Economy	7200.00
0005432949050	11573	Economy	7200.00
0005432949043	11573	Economy	7200.00
0005433569022	11573	Economy	7200.00
0005433075106	11573	Economy	7200.00
0005433075113	11573	Economy	7200.00
0005433569516	11573	Economy	7200.00
0005432949025	11573	Economy	7200.00
0005433569495	11573	Economy	7200.00
0005433075110	11573	Economy	7200.00
0005433075125	11573	Economy	7200.00
0005433569189	11573	Economy	7900.00
0005433075102	11573	Economy	7900.00
0005433569400	11573	Economy	7900.00
0005432949029	11573	Economy	7900.00
0005433075121	11573	Economy	7900.00
0005433569310	11573	Economy	7200.00
0005432949019	11573	Economy	7200.00
0005433569263	11573	Economy	7200.00
0005433569187	11573	Economy	7900.00
0005433075103	11573	Economy	7200.00
0005433569216	11573	Economy	7200.00
0005433075107	11573	Economy	7200.00
0005433569314	11573	Economy	7200.00
0005432949021	11573	Economy	7200.00
0005433075117	11573	Economy	7200.00
0005433569190	11573	Economy	7200.00
0005433569210	11573	Economy	7200.00
0005433075115	11573	Economy	7200.00
0005432949049	11573	Economy	7200.00
0005432949053	11573	Economy	7200.00
0005432949016	11573	Economy	7200.00
0005433569353	11573	Economy	7200.00
0005433075100	11573	Economy	7200.00
0005432949018	11573	Economy	7200.00
0005433569452	11573	Economy	7200.00
0005433131775	11573	Economy	7200.00
0005433569181	11573	Economy	7200.00
0005433075124	11573	Economy	7200.00
0005432949023	11573	Economy	7200.00
0005433569401	11573	Economy	7200.00
0005432949038	11573	Economy	7200.00
0005433568987	11573	Economy	7200.00
0005433569099	11573	Economy	7200.00
0005432949036	11573	Economy	7200.00
0005433075111	11573	Economy	7200.00
0005432949054	11573	Economy	7200.00
0005433075126	11573	Economy	7200.00
0005433569385	11573	Economy	7200.00
0005432949048	11573	Economy	7200.00
0005432949022	11573	Economy	7200.00
0005433569417	11573	Economy	7200.00
0005433569150	11573	Economy	7200.00
0005432949031	11573	Economy	7200.00
0005433075114	11573	Economy	7200.00
0005433569354	11573	Economy	7200.00
0005432949030	11573	Economy	7200.00
0005433569432	11573	Economy	7200.00
0005432192364	11573	Economy	7200.00
0005433075119	11573	Economy	7200.00
0005433075128	11573	Economy	7200.00
0005433075122	11573	Economy	7200.00
0005433569141	11573	Economy	7200.00
0005433075108	11573	Economy	7200.00
0005433569433	11573	Economy	7200.00
0005432949026	11573	Economy	7200.00
0005432949044	11573	Economy	7200.00
0005433569035	11573	Economy	7200.00
0005432949020	11573	Economy	7200.00
0005433569078	11573	Economy	7200.00
0005433569252	11573	Economy	7200.00
0005432192366	11573	Economy	7200.00
0005434733012	10039	Economy	6300.00
0005433817524	10039	Economy	6300.00
0005434732994	10039	Economy	6300.00
0005433817523	10039	Economy	6300.00
0005434733013	10039	Economy	6300.00
0005434733004	10039	Economy	6300.00
0005434732995	10039	Economy	6300.00
0005433817526	10039	Economy	6300.00
0005434733003	10039	Economy	6300.00
0005433817525	10039	Economy	6300.00
0005434733008	10039	Economy	6300.00
0005433817496	13906	Economy	6300.00
0005433817498	13906	Economy	6300.00
0005433817487	13906	Economy	6300.00
0005434733033	13906	Economy	6300.00
0005434733030	13906	Economy	6300.00
0005434733031	13906	Economy	6300.00
0005433817497	13906	Economy	6300.00
0005434733032	13906	Economy	6300.00
0005432985191	2364	Business	184500.00
0005435982963	2364	Business	184500.00
0005432655714	2364	Business	184500.00
0005432655706	2364	Business	184500.00
0005432655711	2364	Business	184500.00
0005435982948	2364	Business	184500.00
0005435982947	2364	Business	184500.00
0005433434745	2364	Business	184500.00
0005432226148	2364	Business	184500.00
0005433755011	2364	Business	184500.00
0005433755037	2364	Business	184500.00
0005433755009	2364	Business	184500.00
0005432985202	2364	Business	184500.00
0005432655709	2364	Business	184500.00
0005433434902	2364	Business	184500.00
0005433755006	2364	Business	184500.00
0005432869579	2364	Business	184500.00
0005432985280	2364	Business	184500.00
0005433434830	2364	Business	184500.00
0005432985239	2364	Business	184500.00
0005433766695	2364	Business	184500.00
0005433755008	2364	Business	184500.00
0005432985278	2364	Business	184500.00
0005432655707	2364	Business	184500.00
0005435982951	2364	Business	184500.00
0005435982956	2364	Business	184500.00
0005432985297	2364	Business	184500.00
0005433755024	2364	Business	184500.00
0005432226149	2364	Business	184500.00
0005432985288	2364	Economy	67700.00
0005432300345	2364	Economy	67700.00
0005435982942	2364	Economy	67700.00
0005435982952	2364	Economy	61500.00
0005434731199	2364	Economy	67700.00
0005432300349	2364	Economy	61500.00
0005433434800	2364	Economy	61500.00
0005435982961	2364	Economy	61500.00
0005435982941	2364	Economy	61500.00
0005433755044	2364	Economy	61500.00
0005432985287	2364	Economy	61500.00
0005435982965	2364	Economy	61500.00
0005432869567	2364	Economy	61500.00
0005433434829	2364	Economy	61500.00
0005433755017	2364	Economy	61500.00
0005433755062	2364	Economy	61500.00
0005435982959	2364	Economy	61500.00
0005432985157	2364	Economy	61500.00
0005435982945	2364	Economy	61500.00
0005433755031	2364	Economy	61500.00
0005433755018	2364	Economy	61500.00
0005433434828	2364	Economy	61500.00
0005432985203	2364	Economy	61500.00
0005433434833	2364	Economy	61500.00
0005432869566	2364	Economy	61500.00
0005433755007	2364	Economy	61500.00
0005433434836	2364	Economy	61500.00
0005433755021	2364	Economy	61500.00
0005433434856	2364	Economy	61500.00
0005433434835	2364	Economy	61500.00
0005432985279	2364	Economy	61500.00
0005433434618	2364	Economy	61500.00
0005433434795	2364	Economy	61500.00
0005433434849	2364	Economy	61500.00
0005433755032	2364	Economy	61500.00
0005432985248	2364	Economy	61500.00
0005435982962	2364	Economy	61500.00
0005433755061	2364	Economy	61500.00
0005433755036	2364	Economy	61500.00
0005432985329	2364	Economy	61500.00
0005435982978	2364	Economy	61500.00
0005433755014	2364	Economy	61500.00
0005432655708	2364	Economy	61500.00
0005435982964	2364	Economy	61500.00
0005432985312	2364	Economy	61500.00
0005434731196	2364	Economy	61500.00
0005433434887	2364	Economy	61500.00
0005435982968	2364	Economy	61500.00
0005432985368	2364	Economy	61500.00
0005433755050	2364	Economy	61500.00
0005433755046	2364	Economy	61500.00
0005433434859	2364	Economy	61500.00
0005433755022	2364	Economy	61500.00
0005435982977	2364	Economy	61500.00
0005435982950	2364	Economy	61500.00
0005432300348	2364	Economy	61500.00
0005433434822	2364	Economy	61500.00
0005432300350	2364	Economy	61500.00
0005433755026	2364	Economy	61500.00
0005432226152	2364	Economy	61500.00
0005432985235	2364	Economy	61500.00
0005433434867	2364	Economy	61500.00
0005435982946	2364	Economy	61500.00
0005432300346	2364	Economy	61500.00
0005432655705	2364	Economy	61500.00
0005432869589	2364	Economy	61500.00
0005433755035	2364	Economy	61500.00
0005433755030	2364	Economy	61500.00
0005433755058	2364	Economy	61500.00
0005433755047	2364	Economy	61500.00
0005433755040	2364	Economy	61500.00
0005433755049	2364	Economy	61500.00
0005434731190	2364	Economy	61500.00
0005433434944	2364	Economy	61500.00
0005432226151	2364	Economy	61500.00
0005433755042	2364	Economy	61500.00
0005435982960	2364	Economy	61500.00
0005433434945	2364	Economy	61500.00
0005433755048	2364	Economy	61500.00
0005432985153	2364	Economy	61500.00
0005433755025	2364	Economy	61500.00
0005433434843	2364	Economy	61500.00
0005432985219	2364	Economy	61500.00
0005435982979	2364	Economy	61500.00
0005432985240	2364	Economy	61500.00
0005432869539	2364	Economy	61500.00
0005433755041	2364	Economy	61500.00
0005432226150	2364	Economy	61500.00
0005432985268	2364	Economy	61500.00
0005433755015	2364	Economy	61500.00
0005432985330	2364	Economy	61500.00
0005432655712	2364	Economy	61500.00
0005433434851	2364	Economy	61500.00
0005432985156	2364	Economy	61500.00
0005433755012	2364	Economy	61500.00
0005432985520	2364	Economy	61500.00
0005432985457	2364	Economy	61500.00
0005433755038	2364	Economy	61500.00
0005433434888	2364	Economy	61500.00
0005434731195	2364	Economy	61500.00
0005435982969	2364	Economy	61500.00
0005433755010	2364	Economy	61500.00
0005433434942	2364	Economy	67700.00
0005435982944	2364	Economy	67700.00
0005433434943	2364	Economy	61500.00
0005433755053	2364	Economy	61500.00
0005435982967	2364	Economy	61500.00
0005433755057	2364	Economy	67700.00
0005433434950	2364	Economy	67700.00
0005432985327	2364	Economy	61500.00
0005433755055	2364	Economy	61500.00
0005435982974	2364	Economy	61500.00
0005433755059	2364	Economy	61500.00
0005432655716	2364	Economy	61500.00
0005433434875	2364	Economy	61500.00
0005432985326	2364	Economy	61500.00
0005432655713	2364	Economy	61500.00
0005432869540	2364	Economy	61500.00
0005432985294	2364	Economy	61500.00
0005433755019	2364	Economy	61500.00
0005433764709	2364	Economy	61500.00
0005433434796	2364	Economy	61500.00
0005433755052	2364	Economy	61500.00
0005433755034	2364	Economy	61500.00
0005432985456	2364	Economy	61500.00
0005435982973	2364	Economy	61500.00
0005433755027	2364	Economy	61500.00
0005433755028	2364	Economy	61500.00
0005435982943	2364	Economy	61500.00
0005433434832	2364	Economy	61500.00
0005433434831	2364	Economy	61500.00
0005432985298	2364	Economy	61500.00
0005433755054	2364	Economy	61500.00
0005433434940	2364	Economy	61500.00
0005433755060	2364	Economy	61500.00
0005435982953	2364	Economy	61500.00
0005433755005	2364	Economy	61500.00
0005435982957	2364	Economy	61500.00
0005433755043	2364	Economy	61500.00
0005433434848	2364	Economy	61500.00
0005435982976	2364	Economy	61500.00
0005432985334	2364	Economy	61500.00
0005435982954	2364	Economy	61500.00
0005432985458	2364	Economy	61500.00
0005432226146	2364	Economy	61500.00
0005432985192	2364	Economy	61500.00
0005433755051	2364	Economy	61500.00
0005435982975	2364	Economy	61500.00
0005433755029	2364	Economy	61500.00
0005434731198	2364	Economy	61500.00
0005432226147	2364	Economy	61500.00
0005433435010	2364	Economy	61500.00
0005435982966	2364	Economy	61500.00
0005432655715	2364	Economy	61500.00
0005433755013	2364	Economy	61500.00
0005432985247	2364	Economy	61500.00
0005433755045	2364	Economy	61500.00
0005432985218	2364	Economy	61500.00
0005432985367	2364	Economy	61500.00
0005432226153	2364	Economy	61500.00
0005435982972	2364	Economy	61500.00
0005432985282	2364	Economy	61500.00
0005433755033	2364	Economy	61500.00
0005433434916	2364	Economy	61500.00
0005432655710	2364	Economy	61500.00
0005433755020	2364	Economy	61500.00
0005433434941	2364	Economy	61500.00
0005435982958	2364	Economy	61500.00
0005435982955	2364	Economy	61500.00
0005432226145	2364	Economy	61500.00
0005435982971	2364	Economy	61500.00
0005432300347	2364	Economy	61500.00
0005435982970	2364	Economy	61500.00
0005433755016	2364	Economy	61500.00
0005435982980	2364	Economy	61500.00
0005433755056	2364	Economy	61500.00
0005432985238	2364	Economy	61500.00
0005433755023	2364	Economy	61500.00
0005433766694	2364	Economy	61500.00
0005433434949	2364	Economy	61500.00
0005432985281	2364	Economy	61500.00
0005432226144	2364	Economy	61500.00
0005433755039	2364	Economy	61500.00
0005433766696	2364	Economy	61500.00
0005433764710	2364	Economy	61500.00
0005435982981	2364	Economy	61500.00
0005433434850	2364	Economy	61500.00
0005435982949	2364	Economy	61500.00
0005433766677	26165	Business	184500.00
0005433435091	26165	Business	184500.00
0005433754396	26165	Business	184500.00
0005432985545	26165	Business	184500.00
0005433435092	26165	Business	184500.00
0005435982478	26165	Business	184500.00
0005432049516	26165	Business	184500.00
0005435982504	26165	Business	184500.00
0005433754431	26165	Business	184500.00
0005435982430	26165	Business	184500.00
0005432985536	26165	Business	184500.00
0005433754645	26165	Business	184500.00
0005433766657	26165	Business	184500.00
0005433754582	26165	Business	184500.00
0005435982639	26165	Business	184500.00
0005432985541	26165	Business	184500.00
0005433754430	26165	Business	184500.00
0005435982522	26165	Business	184500.00
0005433435077	26165	Business	184500.00
0005435982524	26165	Business	184500.00
0005435982585	26165	Business	184500.00
0005433766655	26165	Business	184500.00
0005433754620	26165	Business	184500.00
0005432985540	26165	Business	184500.00
0005432985556	26165	Business	184500.00
0005433754644	26165	Business	184500.00
0005433435078	26165	Economy	67700.00
0005432655636	26165	Economy	67700.00
0005433435079	26165	Economy	67700.00
0005432985551	26165	Economy	61500.00
0005433754728	26165	Economy	61500.00
0005433754535	26165	Economy	61500.00
0005432655591	26165	Economy	61500.00
0005433435097	26165	Economy	61500.00
0005432051174	26165	Economy	61500.00
0005435982712	26165	Economy	61500.00
0005433754268	26165	Economy	61500.00
0005433435099	26165	Economy	61500.00
0005433435084	26165	Economy	61500.00
0005435982634	26165	Economy	61500.00
0005432985533	26165	Economy	61500.00
0005433754673	26165	Economy	61500.00
0005433754507	26165	Economy	61500.00
0005433754504	26165	Economy	61500.00
0005435982380	26165	Economy	61500.00
0005435982559	26165	Economy	61500.00
0005433435081	26165	Economy	61500.00
0005432985548	26165	Economy	61500.00
0005433766671	26165	Economy	61500.00
0005433754674	26165	Economy	61500.00
0005432985560	26165	Economy	61500.00
0005435982497	26165	Economy	61500.00
0005435982503	26165	Economy	61500.00
0005433754581	26165	Economy	61500.00
0005433766658	26165	Economy	61500.00
0005433435086	26165	Economy	61500.00
0005433435080	26165	Economy	61500.00
0005432051173	26165	Economy	61500.00
0005433754441	26165	Economy	61500.00
0005433754701	26165	Economy	61500.00
0005432985530	26165	Economy	61500.00
0005433435090	26165	Economy	61500.00
0005433754534	26165	Economy	61500.00
0005433435088	26165	Economy	61500.00
0005433766666	26165	Economy	61500.00
0005433435076	26165	Economy	61500.00
0005433754313	26165	Economy	61500.00
0005435982496	26165	Economy	61500.00
0005435982523	26165	Economy	61500.00
0005435982510	26165	Economy	61500.00
0005432985549	26165	Economy	61500.00
0005435982556	26165	Economy	61500.00
0005432655609	26165	Economy	61500.00
0005433766670	26165	Economy	61500.00
0005433754528	26165	Economy	61500.00
0005433754390	26165	Economy	61500.00
0005432985539	26165	Economy	61500.00
0005432985546	26165	Economy	61500.00
0005432869617	26165	Economy	61500.00
0005433435073	26165	Economy	61500.00
0005432051172	26165	Economy	61500.00
0005433754590	26165	Economy	61500.00
0005432985543	26165	Economy	61500.00
0005433754519	26165	Economy	61500.00
0005432985535	26165	Economy	61500.00
0005435982714	26165	Economy	61500.00
0005433754472	26165	Economy	61500.00
0005435982468	26165	Economy	61500.00
0005432049517	26165	Economy	61500.00
0005435982498	26165	Economy	61500.00
0005433754614	26165	Economy	61500.00
0005433754398	26165	Economy	61500.00
0005432985532	26165	Economy	61500.00
0005432985538	26165	Economy	61500.00
0005434731233	26165	Economy	61500.00
0005434731231	26165	Economy	61500.00
0005433754437	26165	Economy	61500.00
0005433754457	26165	Economy	61500.00
0005433766676	26165	Economy	61500.00
0005433754565	26165	Economy	61500.00
0005433754680	26165	Economy	61500.00
0005433754312	26165	Economy	61500.00
0005435982521	26165	Economy	61500.00
0005434731234	26165	Economy	61500.00
0005432655637	26165	Economy	61500.00
0005432049515	26165	Economy	61500.00
0005432985531	26165	Economy	61500.00
0005433435075	26165	Economy	61500.00
0005433754497	26165	Economy	61500.00
0005433435083	26165	Economy	61500.00
0005432655622	26165	Economy	61500.00
0005433435100	26165	Economy	61500.00
0005433754618	26165	Economy	61500.00
0005433754311	26165	Economy	61500.00
0005433754724	26165	Economy	61500.00
0005435982499	26165	Economy	61500.00
0005435982272	26165	Economy	61500.00
0005432985534	26165	Economy	67700.00
0005433754596	26165	Economy	61500.00
0005432869619	26165	Economy	67700.00
0005433754552	26165	Economy	67700.00
0005432985557	26165	Economy	61500.00
0005433754637	26165	Economy	61500.00
0005432985537	26165	Economy	61500.00
0005435982415	26165	Economy	61500.00
0005435982618	26165	Economy	61500.00
0005435982555	26165	Economy	61500.00
0005433766672	26165	Economy	61500.00
0005432985528	26165	Economy	61500.00
0005433435089	26165	Economy	61500.00
0005432985559	26165	Economy	61500.00
0005435982703	26165	Economy	61500.00
0005435982370	26165	Economy	61500.00
0005432869620	26165	Economy	61500.00
0005433754649	26165	Economy	61500.00
0005435982574	26165	Economy	61500.00
0005433764690	26165	Economy	61500.00
0005433754759	26165	Economy	61500.00
0005432985554	26165	Economy	61500.00
0005435982582	26165	Economy	61500.00
0005432655590	26165	Economy	61500.00
0005433435098	26165	Economy	61500.00
0005435982514	26165	Economy	61500.00
0005433754484	26165	Economy	61500.00
0005433435095	26165	Economy	61500.00
0005435982273	26165	Economy	61500.00
0005434731232	26165	Economy	61500.00
0005433754442	26165	Economy	61500.00
0005432985555	26165	Economy	61500.00
0005433754481	26165	Economy	61500.00
0005433754389	26165	Economy	61500.00
0005432985550	26165	Economy	61500.00
0005435982473	26165	Economy	61500.00
0005433435072	26165	Economy	61500.00
0005432985552	26165	Economy	61500.00
0005433435087	26165	Economy	61500.00
0005433435094	26165	Economy	61500.00
0005435982554	26165	Economy	61500.00
0005435982640	26165	Economy	61500.00
0005435982673	26165	Economy	61500.00
0005433754611	26165	Economy	61500.00
0005433435085	26165	Economy	61500.00
0005435982431	26165	Economy	61500.00
0005435982491	26165	Economy	61500.00
0005433764691	26165	Economy	61500.00
0005432655623	26165	Economy	61500.00
0005433754429	26165	Economy	61500.00
0005432985561	26165	Economy	61500.00
0005432985553	26165	Economy	61500.00
0005433754650	26165	Economy	61500.00
0005435982627	26165	Economy	61500.00
0005432985547	26165	Economy	61500.00
0005433435101	26165	Economy	61500.00
0005433754656	26165	Economy	61500.00
0005433435082	26165	Economy	61500.00
0005433435093	26165	Economy	61500.00
0005435982584	26165	Economy	61500.00
0005435982690	26165	Economy	61500.00
0005433435074	26165	Economy	61500.00
0005432985529	26165	Economy	61500.00
0005433754397	26165	Economy	61500.00
0005435982302	26165	Economy	61500.00
0005432655563	26165	Economy	61500.00
0005432985558	26165	Economy	61500.00
0005433754506	26165	Economy	61500.00
0005433754508	26165	Economy	61500.00
0005432985544	26165	Economy	61500.00
0005433435096	26165	Economy	61500.00
0005435982713	26165	Economy	61500.00
0005433766667	26165	Economy	61500.00
0005433754654	26165	Economy	61500.00
0005435982502	26165	Economy	61500.00
0005433766654	26165	Economy	61500.00
0005432985542	26165	Economy	61500.00
0005432869616	26165	Economy	61500.00
0005432869618	26165	Economy	61500.00
0005434375294	1489	Business	38900.00
0005434375288	1489	Business	38900.00
0005434376225	1489	Business	38900.00
0005434375296	1489	Business	38900.00
0005433151583	1489	Business	38900.00
0005433151590	1489	Business	38900.00
0005434375323	1489	Business	38900.00
0005434375303	1489	Business	38900.00
0005432267990	1489	Business	38900.00
0005432267994	1489	Economy	13000.00
0005433151702	1489	Economy	13000.00
0005434375313	1489	Economy	13000.00
0005434375320	1489	Economy	13000.00
0005434375306	1489	Economy	13000.00
0005433931489	1489	Economy	13000.00
0005434375297	1489	Economy	13000.00
0005433151674	1489	Economy	13000.00
0005432267993	1489	Economy	13000.00
0005433461619	1489	Economy	13000.00
0005433151627	1489	Economy	13000.00
0005433151776	1489	Economy	13000.00
0005434375300	1489	Economy	13000.00
0005433151566	1489	Economy	13000.00
0005434375310	1489	Economy	13000.00
0005433931488	1489	Economy	13000.00
0005434375282	1489	Economy	13000.00
0005432267995	1489	Economy	13000.00
0005434375290	1489	Economy	13000.00
0005434375301	1489	Economy	13000.00
0005433460467	1489	Economy	13000.00
0005434375314	1489	Economy	13000.00
0005434375308	1489	Economy	13000.00
0005434029671	1489	Economy	13000.00
0005434029672	1489	Economy	14300.00
0005434375298	1489	Economy	14300.00
0005432267992	1489	Economy	14300.00
0005434375286	1489	Economy	13000.00
0005434375283	1489	Economy	13000.00
0005433151567	1489	Economy	13000.00
0005434375307	1489	Economy	13000.00
0005434376227	1489	Economy	13000.00
0005433151718	1489	Economy	13000.00
0005434375299	1489	Economy	13000.00
0005434375318	1489	Economy	13000.00
0005434375312	1489	Economy	13000.00
0005432267996	1489	Economy	13000.00
0005434375292	1489	Economy	13000.00
0005434376159	1489	Economy	13000.00
0005432267989	1489	Economy	13000.00
0005434375295	1489	Economy	13000.00
0005432267991	1489	Economy	13000.00
0005434029673	1489	Economy	13000.00
0005434375321	1489	Economy	13000.00
0005434375319	1489	Economy	13000.00
0005434375311	1489	Economy	13000.00
0005434375317	1489	Economy	13000.00
0005434375322	1489	Economy	13000.00
0005434375281	1489	Economy	13000.00
0005433151501	1489	Economy	13000.00
0005434375309	1489	Economy	13000.00
0005433151587	1489	Economy	13000.00
0005434375324	1489	Economy	13000.00
0005434375315	1489	Economy	13000.00
0005433151585	1489	Economy	13000.00
0005434375289	1489	Economy	13000.00
0005433460468	1489	Economy	13000.00
0005434375293	1489	Economy	13000.00
0005434375285	1489	Economy	13000.00
0005434375284	1489	Economy	13000.00
0005434375302	1489	Economy	13000.00
0005433764688	1489	Economy	13000.00
0005433151502	1489	Economy	13000.00
0005433151630	1489	Economy	13000.00
0005434375316	1489	Economy	13000.00
0005433931486	1489	Economy	13000.00
0005433461620	1489	Economy	13000.00
0005433151586	1489	Economy	13000.00
0005434375305	1489	Economy	13000.00
0005434375287	1489	Economy	13000.00
0005434375291	1489	Economy	13000.00
0005434375304	1489	Economy	13000.00
0005434376226	1489	Economy	13000.00
0005433151917	20117	Business	38900.00
0005433931511	20117	Business	38900.00
0005434374887	20117	Business	38900.00
0005433151887	20117	Business	38900.00
0005433151888	20117	Business	38900.00
0005433151918	20117	Business	38900.00
0005434374965	20117	Business	38900.00
0005434375011	20117	Business	38900.00
0005434374772	20117	Economy	13000.00
0005434374924	20117	Economy	13000.00
0005433151896	20117	Economy	13000.00
0005434374999	20117	Economy	13000.00
0005434374881	20117	Economy	13000.00
0005434374846	20117	Economy	13000.00
0005434374811	20117	Economy	13000.00
0005434374934	20117	Economy	13000.00
0005434375000	20117	Economy	13000.00
0005433151899	20117	Economy	13000.00
0005433151910	20117	Economy	13000.00
0005432056355	20117	Economy	13000.00
0005433151908	20117	Economy	13000.00
0005434374945	20117	Economy	13000.00
0005434374845	20117	Economy	13000.00
0005433151897	20117	Economy	13000.00
0005434374958	20117	Economy	13000.00
0005433151906	20117	Economy	13000.00
0005433151904	20117	Economy	13000.00
0005433151889	20117	Economy	13000.00
0005432056357	20117	Economy	13000.00
0005434374966	20117	Economy	13000.00
0005433931512	20117	Economy	13000.00
0005434374759	20117	Economy	13000.00
0005434374912	20117	Economy	13000.00
0005434375141	20117	Economy	13000.00
0005434374911	20117	Economy	13000.00
0005434374790	20117	Economy	13000.00
0005433151893	20117	Economy	13000.00
0005433151915	20117	Economy	13000.00
0005434374993	20117	Economy	13000.00
0005433931513	20117	Economy	13000.00
0005434375142	20117	Economy	13000.00
0005433151900	20117	Economy	14300.00
0005433764709	20117	Economy	14300.00
0005433151892	20117	Economy	14300.00
0005434374789	20117	Economy	14300.00
0005433151905	20117	Economy	14300.00
0005433151919	20117	Economy	13000.00
0005433151914	20117	Economy	13000.00
0005433151891	20117	Economy	13000.00
0005434374792	20117	Economy	13000.00
0005433151894	20117	Economy	13000.00
0005432056354	20117	Economy	13000.00
0005434374947	20117	Economy	13000.00
0005434374963	20117	Economy	13000.00
0005433151907	20117	Economy	13000.00
0005433151903	20117	Economy	13000.00
0005434374918	20117	Economy	13000.00
0005433151909	20117	Economy	13000.00
0005434374788	20117	Economy	13000.00
0005433151885	20117	Economy	13000.00
0005434374791	20117	Economy	13000.00
0005434374785	20117	Economy	13000.00
0005434374964	20117	Economy	13000.00
0005434029693	20117	Economy	13000.00
0005433151902	20117	Economy	13000.00
0005434374895	20117	Economy	13000.00
0005432056353	20117	Economy	13000.00
0005434375005	20117	Economy	13000.00
0005434374808	20117	Economy	13000.00
0005433151890	20117	Economy	13000.00
0005434374946	20117	Economy	13000.00
0005434375105	20117	Economy	13000.00
0005432056356	20117	Economy	13000.00
0005434374926	20117	Economy	13000.00
0005434374847	20117	Economy	13000.00
0005433151898	20117	Economy	13000.00
0005433151884	20117	Economy	13000.00
0005433151901	20117	Economy	13000.00
0005434374762	20117	Economy	13000.00
0005434374988	20117	Economy	13000.00
0005434375054	20117	Economy	13000.00
0005432056352	20117	Economy	13000.00
0005434375055	20117	Economy	13000.00
0005433151911	20117	Economy	13000.00
0005434374742	20117	Economy	13000.00
0005433151916	20117	Economy	13000.00
0005433764710	20117	Economy	13000.00
0005433151895	20117	Economy	13000.00
0005434374784	20117	Economy	13000.00
0005434374948	20117	Economy	13000.00
0005433931514	20117	Economy	13000.00
0005434374933	20117	Economy	13000.00
0005434375010	20117	Economy	13000.00
0005434374831	20117	Economy	13000.00
0005433151886	20117	Economy	13000.00
0005434375006	20117	Economy	13000.00
0005433151912	20117	Economy	13000.00
0005434375053	20117	Economy	13000.00
0005434375029	20117	Economy	13000.00
0005433151913	20117	Economy	13000.00
0005434375087	20117	Economy	13000.00
0005434374787	20117	Economy	13000.00
0005432425155	608	Business	27500.00
0005432425144	608	Business	27500.00
0005432425135	608	Business	27500.00
0005432425177	608	Business	27500.00
0005432425136	608	Business	27500.00
0005432425167	608	Business	27500.00
0005432425164	608	Business	27500.00
0005432425147	608	Business	27500.00
0005432425130	608	Business	27500.00
0005432425179	608	Economy	10100.00
0005432425127	608	Economy	10100.00
0005432425134	608	Economy	10100.00
0005432425170	608	Economy	10100.00
0005432425143	608	Economy	9200.00
0005432425132	608	Economy	9200.00
0005432425158	608	Economy	9200.00
0005432282965	608	Economy	9200.00
0005432425142	608	Economy	9200.00
0005432425180	608	Economy	9200.00
0005432425163	608	Economy	9200.00
0005432425141	608	Economy	9200.00
0005432425138	608	Economy	9200.00
0005432425176	608	Economy	9200.00
0005432282966	608	Economy	9200.00
0005432282967	608	Economy	9200.00
0005432425162	608	Economy	9200.00
0005432425156	608	Economy	9200.00
0005432425125	608	Economy	9200.00
0005432425139	608	Economy	9200.00
0005432425126	608	Economy	9200.00
0005432425157	608	Economy	9200.00
0005432425148	608	Economy	9200.00
0005432425171	608	Economy	9200.00
0005432425124	608	Economy	9200.00
0005432425174	608	Economy	9200.00
0005432425168	608	Economy	9200.00
0005432425131	608	Economy	9200.00
0005432425165	608	Economy	9200.00
0005432425128	608	Economy	9200.00
0005432425175	608	Economy	9200.00
0005432425181	608	Economy	9200.00
0005432282963	608	Economy	10100.00
0005432425173	608	Economy	10100.00
0005432282968	608	Economy	9200.00
0005432425178	608	Economy	9200.00
0005432425129	608	Economy	10100.00
0005432425133	608	Economy	9200.00
0005432425159	608	Economy	9200.00
0005432425150	608	Economy	9200.00
0005432425154	608	Economy	9200.00
0005432425182	608	Economy	9200.00
0005432282962	608	Economy	9200.00
0005432425161	608	Economy	9200.00
0005432425160	608	Economy	9200.00
0005432425151	608	Economy	9200.00
0005432425140	608	Economy	9200.00
0005432425183	608	Economy	9200.00
0005432425146	608	Economy	9200.00
0005432425149	608	Economy	9200.00
0005432282964	608	Economy	9200.00
0005432282969	608	Economy	9200.00
0005432425166	608	Economy	9200.00
0005432425145	608	Economy	9200.00
0005432425153	608	Economy	9200.00
0005432425184	608	Economy	9200.00
0005432425169	608	Economy	9200.00
0005432425172	608	Economy	9200.00
0005432425152	608	Economy	9200.00
0005432425137	608	Economy	9200.00
0005432302385	12886	Economy	10100.00
0005432302384	12886	Economy	9200.00
0005432302386	12886	Economy	9200.00
0005432424616	12911	Business	27500.00
0005432424658	12911	Business	27500.00
0005432424722	12911	Business	27500.00
0005432424698	12911	Business	27500.00
0005432424618	12911	Business	27500.00
0005432424666	12911	Business	27500.00
0005432424532	12911	Business	27500.00
0005432424683	12911	Business	27500.00
0005432424676	12911	Economy	10100.00
0005432424693	12911	Economy	9200.00
0005432424553	12911	Economy	9200.00
0005432424602	12911	Economy	9200.00
0005432424661	12911	Economy	9200.00
0005432424617	12911	Economy	9200.00
0005432424422	12911	Economy	9200.00
0005432424610	12911	Economy	9200.00
0005432424607	12911	Economy	9200.00
0005432424677	12911	Economy	9200.00
0005432424640	12911	Economy	9200.00
0005432424686	12911	Economy	9200.00
0005432424721	12911	Economy	9200.00
0005432424662	12911	Economy	9200.00
0005432424689	12911	Economy	9200.00
0005432424540	12911	Economy	9200.00
0005432424684	12911	Economy	9200.00
0005432424704	12911	Economy	9200.00
0005432424711	12911	Economy	9200.00
0005432424729	12911	Economy	9200.00
0005432424731	12911	Economy	9200.00
0005432424723	12911	Economy	9200.00
0005432424554	12911	Economy	9200.00
0005432424690	12911	Economy	9200.00
0005432424688	12911	Economy	10100.00
0005432424730	12911	Economy	9200.00
0005432424665	12911	Economy	9200.00
0005432424718	12911	Economy	9200.00
0005432424712	12911	Economy	9200.00
0005432424715	12911	Economy	9200.00
0005432424562	12911	Economy	9200.00
0005432424539	12911	Economy	9200.00
0005432424733	12911	Economy	9200.00
0005432424691	12911	Economy	9200.00
0005432424561	12911	Economy	9200.00
0005432424685	12911	Economy	9200.00
0005432424531	12911	Economy	9200.00
0005432424719	12911	Economy	9200.00
0005432424574	12911	Economy	9200.00
0005432424557	12911	Economy	9200.00
0005432424687	12911	Economy	9200.00
0005432424705	12911	Economy	9200.00
0005432424720	12911	Economy	9200.00
0005432424556	12911	Economy	9200.00
0005432424615	12911	Economy	9200.00
0005432424533	12911	Economy	9200.00
0005434024672	483	Business	24500.00
0005433929639	483	Business	24500.00
0005434024707	483	Business	24500.00
0005433058077	483	Business	24500.00
0005434024712	483	Business	24500.00
0005434024660	483	Business	24500.00
0005434024697	483	Business	24500.00
0005434024681	483	Business	24500.00
0005433058108	483	Business	24500.00
0005434024683	483	Business	24500.00
0005434028338	483	Business	24500.00
0005433058181	483	Business	24500.00
0005434032084	483	Business	24500.00
0005433057995	483	Business	24500.00
0005433058192	483	Business	24500.00
0005433058062	483	Business	24500.00
0005433929632	483	Business	24500.00
0005432235750	483	Business	24500.00
0005432235744	483	Business	24500.00
0005434024674	483	Business	24500.00
0005434024713	483	Business	24500.00
0005433929638	483	Business	24500.00
0005434735707	483	Economy	9000.00
0005433058078	483	Economy	9000.00
0005433058212	483	Economy	8200.00
0005432235745	483	Economy	8200.00
0005434024699	483	Economy	8200.00
0005434024708	483	Economy	8200.00
0005434024693	483	Economy	8200.00
0005434735708	483	Economy	8200.00
0005434024685	483	Economy	8200.00
0005434032088	483	Economy	8200.00
0005433058072	483	Economy	8200.00
0005432235743	483	Economy	8200.00
0005433058096	483	Economy	8200.00
0005433058204	483	Economy	8200.00
0005434024691	483	Economy	8200.00
0005434032085	483	Economy	8200.00
0005434024673	483	Economy	8200.00
0005433058202	483	Economy	8200.00
0005434024678	483	Economy	8200.00
0005433684428	483	Economy	8200.00
0005434024689	483	Economy	8200.00
0005434024650	483	Economy	8200.00
0005434024698	483	Economy	8200.00
0005432235747	483	Economy	8200.00
0005433058180	483	Economy	8200.00
0005434024662	483	Economy	8200.00
0005433058063	483	Economy	8200.00
0005434024700	483	Economy	8200.00
0005433058370	483	Economy	8200.00
0005434024652	483	Economy	8200.00
0005433058371	483	Economy	8200.00
0005433058263	483	Economy	8200.00
0005434024711	483	Economy	8200.00
0005434024704	483	Economy	8200.00
0005432045640	483	Economy	8200.00
0005434024692	483	Economy	8200.00
0005433684434	483	Economy	8200.00
0005433058265	483	Economy	8200.00
0005434024671	483	Economy	8200.00
0005433058107	483	Economy	8200.00
0005434029691	483	Economy	8200.00
0005434028339	483	Economy	8200.00
0005434024655	483	Economy	8200.00
0005432045641	483	Economy	8200.00
0005433058261	483	Economy	8200.00
0005434024721	483	Economy	8200.00
0005433058307	483	Economy	8200.00
0005434024710	483	Economy	8200.00
0005434024719	483	Economy	8200.00
0005434024702	483	Economy	8200.00
0005434024657	483	Economy	8200.00
0005434735716	483	Economy	8200.00
0005433929635	483	Economy	8200.00
0005434735715	483	Economy	8200.00
0005434024687	483	Economy	8200.00
0005433058264	483	Economy	8200.00
0005433058190	483	Economy	8200.00
0005434024653	483	Economy	8200.00
0005434024664	483	Economy	8200.00
0005432235748	483	Economy	8200.00
0005434024705	483	Economy	8200.00
0005433058276	483	Economy	8200.00
0005434032086	483	Economy	8200.00
0005434024717	483	Economy	8200.00
0005434024680	483	Economy	8200.00
0005433058073	483	Economy	8200.00
0005434024656	483	Economy	9000.00
0005434024677	483	Economy	9000.00
0005434032087	483	Economy	8200.00
0005434024696	483	Economy	8200.00
0005434024690	483	Economy	9000.00
0005434024668	483	Economy	8200.00
0005434024701	483	Economy	8200.00
0005434024718	483	Economy	8200.00
0005434024666	483	Economy	8200.00
0005434024709	483	Economy	8200.00
0005434024676	483	Economy	8200.00
0005434024667	483	Economy	8200.00
0005434024714	483	Economy	8200.00
0005434024695	483	Economy	8200.00
0005434024669	483	Economy	8200.00
0005433058136	483	Economy	8200.00
0005433058088	483	Economy	8200.00
0005434024688	483	Economy	8200.00
0005433058130	483	Economy	8200.00
0005432235749	483	Economy	8200.00
0005433058203	483	Economy	8200.00
0005433058220	483	Economy	8200.00
0005434024694	483	Economy	8200.00
0005434024686	483	Economy	8200.00
0005434024715	483	Economy	8200.00
0005434024661	483	Economy	8200.00
0005433929637	483	Economy	8200.00
0005434024663	483	Economy	8200.00
0005434024654	483	Economy	8200.00
0005434024720	483	Economy	8200.00
0005433929633	483	Economy	8200.00
0005434024658	483	Economy	8200.00
0005433058100	483	Economy	8200.00
0005434024716	483	Economy	8200.00
0005433058061	483	Economy	8200.00
0005433058311	483	Economy	8200.00
0005434024684	483	Economy	8200.00
0005433058139	483	Economy	8200.00
0005432235746	483	Economy	8200.00
0005434024682	483	Economy	8200.00
0005434735711	483	Economy	8200.00
0005434024675	483	Economy	8200.00
0005434024670	483	Economy	8200.00
0005433058065	483	Economy	8200.00
0005434024706	483	Economy	8200.00
0005434024659	483	Economy	8200.00
0005434024665	483	Economy	8200.00
0005433058308	483	Economy	8200.00
0005434024703	483	Economy	8200.00
0005433684427	483	Economy	8200.00
0005434029692	483	Economy	8200.00
0005434024679	483	Economy	8200.00
0005433684424	483	Economy	8200.00
0005434024651	483	Economy	8200.00
0005433058340	483	Economy	8200.00
0005434024186	12698	Business	24500.00
0005434023947	12698	Business	24500.00
0005433058443	12698	Business	24500.00
0005433058444	12698	Business	24500.00
0005433058468	12698	Business	24500.00
0005433058445	12698	Business	24500.00
0005433058466	12698	Business	24500.00
0005434023941	12698	Business	24500.00
0005434023798	12698	Business	24500.00
0005434032045	12698	Business	24500.00
0005433058482	12698	Business	24500.00
0005433058483	12698	Business	24500.00
0005433058470	12698	Business	24500.00
0005434024096	12698	Business	24500.00
0005433058480	12698	Business	24500.00
0005433058471	12698	Business	24500.00
0005433058460	12698	Business	24500.00
0005434024492	12698	Business	24500.00
0005434023988	12698	Economy	9000.00
0005434032056	12698	Economy	9000.00
0005434024045	12698	Economy	8200.00
0005433058457	12698	Economy	8200.00
0005434024031	12698	Economy	8200.00
0005434024378	12698	Economy	8200.00
0005434024198	12698	Economy	8200.00
0005434024041	12698	Economy	8200.00
0005434024151	12698	Economy	8200.00
0005433058464	12698	Economy	8200.00
0005434024064	12698	Economy	8200.00
0005434029672	12698	Economy	8200.00
0005433929671	12698	Economy	8200.00
0005433058472	12698	Economy	8200.00
0005434024056	12698	Economy	8200.00
0005434024348	12698	Economy	8200.00
0005434024190	12698	Economy	8200.00
0005432156429	12698	Economy	8200.00
0005434024055	12698	Economy	8200.00
0005434024199	12698	Economy	8200.00
0005434024115	12698	Economy	8200.00
0005434024281	12698	Economy	8200.00
0005433684450	12698	Economy	8200.00
0005434032046	12698	Economy	8200.00
0005434376227	12698	Economy	8200.00
0005434376226	12698	Economy	8200.00
0005433058451	12698	Economy	8200.00
0005434024167	12698	Economy	8200.00
0005434024048	12698	Economy	8200.00
0005434029673	12698	Economy	8200.00
0005433058459	12698	Economy	8200.00
0005433058449	12698	Economy	8200.00
0005434024180	12698	Economy	8200.00
0005434023513	12698	Economy	8200.00
0005433929672	12698	Economy	8200.00
0005434024181	12698	Economy	8200.00
0005434735767	12698	Economy	8200.00
0005434024038	12698	Economy	8200.00
0005432156428	12698	Economy	8200.00
0005433058463	12698	Economy	8200.00
0005434028305	12698	Economy	8200.00
0005434735766	12698	Economy	8200.00
0005433058465	12698	Economy	8200.00
0005433684451	12698	Economy	8200.00
0005433058454	12698	Economy	8200.00
0005434023840	12698	Economy	8200.00
0005434024187	12698	Economy	8200.00
0005434024102	12698	Economy	8200.00
0005434024491	12698	Economy	8200.00
0005434024291	12698	Economy	8200.00
0005434024215	12698	Economy	8200.00
0005433058450	12698	Economy	8200.00
0005433058453	12698	Economy	8200.00
0005434024204	12698	Economy	8200.00
0005434024090	12698	Economy	8200.00
0005433058474	12698	Economy	8200.00
0005434024490	12698	Economy	8200.00
0005432157520	12698	Economy	8200.00
0005434032052	12698	Economy	8200.00
0005434024208	12698	Economy	8200.00
0005433058478	12698	Economy	8200.00
0005432156431	12698	Economy	8200.00
0005434029671	12698	Economy	8200.00
0005434735768	12698	Economy	9000.00
0005434024095	12698	Economy	8200.00
0005433058458	12698	Economy	8200.00
0005434024347	12698	Economy	8200.00
0005434024049	12698	Economy	9000.00
0005434024209	12698	Economy	8200.00
0005434024183	12698	Economy	8200.00
0005434024157	12698	Economy	8200.00
0005434024116	12698	Economy	8200.00
0005434376225	12698	Economy	8200.00
0005433058456	12698	Economy	8200.00
0005433058469	12698	Economy	8200.00
0005433929673	12698	Economy	8200.00
0005434024361	12698	Economy	8200.00
0005433058461	12698	Economy	8200.00
0005434023946	12698	Economy	8200.00
0005434024184	12698	Economy	8200.00
0005433058455	12698	Economy	8200.00
0005434023994	12698	Economy	8200.00
0005434735764	12698	Economy	8200.00
0005434023906	12698	Economy	8200.00
0005434024320	12698	Economy	8200.00
0005434024092	12698	Economy	8200.00
0005434024043	12698	Economy	8200.00
0005433058475	12698	Economy	8200.00
0005434735763	12698	Economy	8200.00
0005433058477	12698	Economy	8200.00
0005433058467	12698	Economy	8200.00
0005433058462	12698	Economy	8200.00
0005433058476	12698	Economy	8200.00
0005434024148	12698	Economy	8200.00
0005433058452	12698	Economy	8200.00
0005433058479	12698	Economy	8200.00
0005434024168	12698	Economy	8200.00
0005434032058	12698	Economy	8200.00
0005434024270	12698	Economy	8200.00
0005434028306	12698	Economy	8200.00
0005433929674	12698	Economy	8200.00
0005434024101	12698	Economy	8200.00
0005433058442	12698	Economy	8200.00
0005433058473	12698	Economy	8200.00
0005434024379	12698	Economy	8200.00
0005434023940	12698	Economy	8200.00
0005432156430	12698	Economy	8200.00
0005433058448	12698	Economy	8200.00
0005433058446	12698	Economy	8200.00
0005434024237	12698	Economy	8200.00
0005433058481	12698	Economy	8200.00
0005434023979	12698	Economy	8200.00
0005434024147	12698	Economy	8200.00
0005434735765	12698	Economy	8200.00
0005433058447	12698	Economy	8200.00
0005432157519	12698	Economy	8200.00
0005433527314	13809	Business	111600.00
0005433529326	13809	Business	111600.00
0005433529323	13809	Business	111600.00
0005433529320	13809	Business	111600.00
0005433527318	13809	Business	111600.00
0005433529329	13809	Business	111600.00
0005433527315	13809	Economy	37200.00
0005433529321	13809	Economy	37200.00
0005433527312	13809	Economy	40900.00
0005433529325	13809	Economy	37200.00
0005433529319	13809	Economy	37200.00
0005433527319	13809	Economy	37200.00
0005433527313	13809	Economy	37200.00
0005433527316	13809	Economy	37200.00
0005433529327	13809	Economy	37200.00
0005433529324	13809	Economy	37200.00
0005433529322	13809	Economy	37200.00
0005433529331	13809	Economy	37200.00
0005433527311	13809	Economy	37200.00
0005433529330	13809	Economy	37200.00
0005433527317	13809	Economy	37200.00
0005433529328	13809	Economy	37200.00
0005433527310	13809	Economy	37200.00
0005433529300	32445	Business	111600.00
0005433529282	32445	Business	111600.00
0005433529292	32445	Business	111600.00
0005433533314	32445	Business	111600.00
0005433533328	32445	Economy	37200.00
0005433533331	32445	Economy	37200.00
0005433529277	32445	Economy	37200.00
0005433529301	32445	Economy	37200.00
0005433529303	32445	Economy	37200.00
0005433529296	32445	Economy	37200.00
0005433533311	32445	Economy	37200.00
0005433533319	32445	Economy	37200.00
0005433533330	32445	Economy	37200.00
0005433529302	32445	Economy	37200.00
0005433533310	32445	Economy	37200.00
0005433529272	32445	Economy	37200.00
0005433529278	32445	Economy	37200.00
0005433529283	32445	Economy	37200.00
0005433533323	32445	Economy	37200.00
0005433533324	32445	Economy	37200.00
0005433533329	32445	Economy	37200.00
0005433533325	32445	Economy	37200.00
0005433533326	32445	Economy	37200.00
0005433036904	2119	Business	34700.00
0005432231720	2119	Business	34700.00
0005433036687	2119	Business	34700.00
0005433924727	2119	Business	34700.00
0005433924694	2119	Business	34700.00
0005433924692	2119	Business	34700.00
0005433929673	2119	Business	34700.00
0005433924701	2119	Business	34700.00
0005432231712	2119	Business	34700.00
0005433924713	2119	Business	34700.00
0005433036587	2119	Business	34700.00
0005433924691	2119	Business	34700.00
0005432044565	2119	Business	34700.00
0005433924714	2119	Business	34700.00
0005432231721	2119	Business	34700.00
0005433924722	2119	Business	34700.00
0005433036394	2119	Business	34700.00
0005433036466	2119	Business	34700.00
0005432231713	2119	Business	34700.00
0005433924639	2119	Business	34700.00
0005432231714	2119	Business	34700.00
0005432231717	2119	Business	34700.00
0005432044566	2119	Business	34700.00
0005433924665	2119	Business	34700.00
0005433924652	2119	Business	34700.00
0005432231716	2119	Business	34700.00
0005433036550	2119	Business	34700.00
0005433036638	2119	Business	34700.00
0005433924728	2119	Economy	12700.00
0005433924720	2119	Economy	12700.00
0005433924686	2119	Economy	12700.00
0005433924697	2119	Economy	12700.00
0005433036760	2119	Economy	11600.00
0005433924724	2119	Economy	11600.00
0005433924702	2119	Economy	11600.00
0005433036915	2119	Economy	11600.00
0005433931512	2119	Economy	11600.00
0005433036589	2119	Economy	11600.00
0005433924688	2119	Economy	11600.00
0005433924662	2119	Economy	11600.00
0005433924716	2119	Economy	11600.00
0005433924683	2119	Economy	11600.00
0005433924640	2119	Economy	11600.00
0005433924671	2119	Economy	11600.00
0005433036682	2119	Economy	11600.00
0005433924668	2119	Economy	11600.00
0005433924679	2119	Economy	11600.00
0005433931511	2119	Economy	11600.00
0005433924677	2119	Economy	11600.00
0005433036905	2119	Economy	11600.00
0005433924699	2119	Economy	11600.00
0005433036298	2119	Economy	11600.00
0005433924712	2119	Economy	11600.00
0005433924634	2119	Economy	11600.00
0005433036569	2119	Economy	11600.00
0005433924672	2119	Economy	11600.00
0005433924638	2119	Economy	11600.00
0005433924643	2119	Economy	11600.00
0005433924723	2119	Economy	11600.00
0005433036726	2119	Economy	11600.00
0005433036549	2119	Economy	11600.00
0005433036662	2119	Economy	11600.00
0005433924646	2119	Economy	11600.00
0005433036695	2119	Economy	11600.00
0005433924690	2119	Economy	11600.00
0005433924636	2119	Economy	11600.00
0005433036759	2119	Economy	11600.00
0005433924717	2119	Economy	11600.00
0005433036678	2119	Economy	11600.00
0005433036686	2119	Economy	11600.00
0005433036650	2119	Economy	11600.00
0005433036734	2119	Economy	11600.00
0005433924657	2119	Economy	11600.00
0005433036815	2119	Economy	11600.00
0005433924711	2119	Economy	11600.00
0005433036794	2119	Economy	11600.00
0005433924651	2119	Economy	11600.00
0005433924715	2119	Economy	11600.00
0005433036465	2119	Economy	11600.00
0005433924659	2119	Economy	11600.00
0005433924655	2119	Economy	11600.00
0005433036789	2119	Economy	11600.00
0005433931513	2119	Economy	11600.00
0005433924656	2119	Economy	11600.00
0005433036733	2119	Economy	11600.00
0005433931514	2119	Economy	11600.00
0005433036725	2119	Economy	11600.00
0005432749802	2119	Economy	11600.00
0005433924725	2119	Economy	11600.00
0005433924719	2119	Economy	11600.00
0005433924632	2119	Economy	11600.00
0005433036663	2119	Economy	11600.00
0005433036547	2119	Economy	11600.00
0005433924675	2119	Economy	11600.00
0005433924707	2119	Economy	11600.00
0005433036601	2119	Economy	11600.00
0005433924660	2119	Economy	11600.00
0005433924706	2119	Economy	11600.00
0005433036423	2119	Economy	11600.00
0005434028305	2119	Economy	11600.00
0005433924648	2119	Economy	11600.00
0005433924718	2119	Economy	11600.00
0005433036790	2119	Economy	11600.00
0005433036533	2119	Economy	11600.00
0005433929671	2119	Economy	11600.00
0005433036832	2119	Economy	11600.00
0005433036833	2119	Economy	11600.00
0005433036661	2119	Economy	11600.00
0005433924673	2119	Economy	11600.00
0005433036541	2119	Economy	11600.00
0005433036555	2119	Economy	11600.00
0005433036300	2119	Economy	11600.00
0005433036297	2119	Economy	11600.00
0005433924653	2119	Economy	12700.00
0005433036391	2119	Economy	12700.00
0005433036721	2119	Economy	11600.00
0005433036773	2119	Economy	11600.00
0005433036543	2119	Economy	11600.00
0005433036430	2119	Economy	12700.00
0005433924654	2119	Economy	12700.00
0005433036831	2119	Economy	11600.00
0005433924666	2119	Economy	11600.00
0005433924647	2119	Economy	11600.00
0005433924705	2119	Economy	11600.00
0005433924682	2119	Economy	11600.00
0005433924635	2119	Economy	11600.00
0005433924641	2119	Economy	11600.00
0005433924633	2119	Economy	11600.00
0005434028306	2119	Economy	11600.00
0005433924696	2119	Economy	11600.00
0005433924658	2119	Economy	11600.00
0005432231722	2119	Economy	11600.00
0005433924669	2119	Economy	11600.00
0005433924721	2119	Economy	11600.00
0005433924700	2119	Economy	11600.00
0005433924708	2119	Economy	11600.00
0005433924661	2119	Economy	11600.00
0005433924687	2119	Economy	11600.00
0005432231723	2119	Economy	11600.00
0005433924695	2119	Economy	11600.00
0005432044564	2119	Economy	11600.00
0005432231719	2119	Economy	11600.00
0005433924684	2119	Economy	11600.00
0005432231715	2119	Economy	11600.00
0005433924726	2119	Economy	11600.00
0005433924693	2119	Economy	11600.00
0005433036696	2119	Economy	11600.00
0005433924676	2119	Economy	11600.00
0005433036697	2119	Economy	11600.00
0005433036806	2119	Economy	11600.00
0005433036681	2119	Economy	11600.00
0005433036680	2119	Economy	11600.00
0005433924709	2119	Economy	11600.00
0005433036783	2119	Economy	11600.00
0005433924685	2119	Economy	11600.00
0005433036723	2119	Economy	11600.00
0005433924703	2119	Economy	11600.00
0005433924649	2119	Economy	11600.00
0005433036588	2119	Economy	11600.00
0005433036390	2119	Economy	11600.00
0005433036370	2119	Economy	11600.00
0005433924670	2119	Economy	11600.00
0005433924680	2119	Economy	11600.00
0005433036758	2119	Economy	11600.00
0005433929674	2119	Economy	11600.00
0005432231718	2119	Economy	11600.00
0005433036722	2119	Economy	11600.00
0005433875398	2119	Economy	11600.00
0005433036664	2119	Economy	11600.00
0005433924663	2119	Economy	11600.00
0005433924644	2119	Economy	11600.00
0005433924689	2119	Economy	11600.00
0005433036788	2119	Economy	11600.00
0005433924650	2119	Economy	11600.00
0005433036395	2119	Economy	11600.00
0005433875399	2119	Economy	11600.00
0005433924667	2119	Economy	11600.00
0005433924681	2119	Economy	11600.00
0005433924664	2119	Economy	11600.00
0005433924674	2119	Economy	11600.00
0005433924710	2119	Economy	11600.00
0005433036639	2119	Economy	11600.00
0005433924704	2119	Economy	11600.00
0005433924678	2119	Economy	11600.00
0005433924645	2119	Economy	11600.00
0005433924642	2119	Economy	11600.00
0005433036548	2119	Economy	11600.00
0005433036808	2119	Economy	11600.00
0005433929672	2119	Economy	11600.00
0005433036732	2119	Economy	11600.00
0005433924637	2119	Economy	11600.00
0005433924698	2119	Economy	11600.00
0005433037046	24141	Business	34700.00
0005433924409	24141	Business	34700.00
0005432207699	24141	Business	34700.00
0005434028341	24141	Business	34700.00
0005433924127	24141	Business	34700.00
0005432206282	24141	Business	34700.00
0005433037030	24141	Business	34700.00
0005433037082	24141	Business	34700.00
0005433923974	24141	Business	34700.00
0005433037071	24141	Business	34700.00
0005433037077	24141	Business	34700.00
0005433924092	24141	Business	34700.00
0005433037061	24141	Business	34700.00
0005433923883	24141	Business	34700.00
0005433923765	24141	Business	34700.00
0005433923644	24141	Business	34700.00
0005433923955	24141	Business	34700.00
0005433924234	24141	Business	34700.00
0005433924002	24141	Business	34700.00
0005433037054	24141	Business	34700.00
0005433923976	24141	Business	34700.00
0005433037038	24141	Business	34700.00
0005433037068	24141	Business	34700.00
0005433037041	24141	Business	34700.00
0005433923810	24141	Business	34700.00
0005433923915	24141	Economy	12700.00
0005433923708	24141	Economy	12700.00
0005433923636	24141	Economy	12700.00
0005433923678	24141	Economy	11600.00
0005433037055	24141	Economy	11600.00
0005434028342	24141	Economy	11600.00
0005433931484	24141	Economy	11600.00
0005432749817	24141	Economy	11600.00
0005433923645	24141	Economy	11600.00
0005433037045	24141	Economy	11600.00
0005433924408	24141	Economy	11600.00
0005433923465	24141	Economy	11600.00
0005433923747	24141	Economy	11600.00
0005433924271	24141	Economy	11600.00
0005433923846	24141	Economy	11600.00
0005433923476	24141	Economy	11600.00
0005433923492	24141	Economy	11600.00
0005432206277	24141	Economy	11600.00
0005433923755	24141	Economy	11600.00
0005433924018	24141	Economy	11600.00
0005433037080	24141	Economy	11600.00
0005433924154	24141	Economy	11600.00
0005433924058	24141	Economy	11600.00
0005433923741	24141	Economy	11600.00
0005433924213	24141	Economy	11600.00
0005433923825	24141	Economy	11600.00
0005433923918	24141	Economy	11600.00
0005433923541	24141	Economy	11600.00
0005433037052	24141	Economy	11600.00
0005433923613	24141	Economy	11600.00
0005433924132	24141	Economy	11600.00
0005433923337	24141	Economy	11600.00
0005433923954	24141	Economy	11600.00
0005433923431	24141	Economy	11600.00
0005433923477	24141	Economy	11600.00
0005433037036	24141	Economy	11600.00
0005433931492	24141	Economy	11600.00
0005433924107	24141	Economy	11600.00
0005433923493	24141	Economy	11600.00
0005433923589	24141	Economy	11600.00
0005433924129	24141	Economy	11600.00
0005433037072	24141	Economy	11600.00
0005433037073	24141	Economy	11600.00
0005433924072	24141	Economy	11600.00
0005433923892	24141	Economy	11600.00
0005433923338	24141	Economy	11600.00
0005433923866	24141	Economy	11600.00
0005433037060	24141	Economy	11600.00
0005433923689	24141	Economy	11600.00
0005433923884	24141	Economy	11600.00
0005433923877	24141	Economy	11600.00
0005433923588	24141	Economy	11600.00
0005433924267	24141	Economy	11600.00
0005432206279	24141	Economy	11600.00
0005433923889	24141	Economy	11600.00
0005433923673	24141	Economy	11600.00
0005433924099	24141	Economy	11600.00
0005433924214	24141	Economy	11600.00
0005433037069	24141	Economy	11600.00
0005433923685	24141	Economy	11600.00
0005433923372	24141	Economy	11600.00
0005433037050	24141	Economy	11600.00
0005433923621	24141	Economy	11600.00
0005433923725	24141	Economy	11600.00
0005433037074	24141	Economy	11600.00
0005433923766	24141	Economy	11600.00
0005433923590	24141	Economy	11600.00
0005433923587	24141	Economy	11600.00
0005432206280	24141	Economy	11600.00
0005433924008	24141	Economy	11600.00
0005433923851	24141	Economy	11600.00
0005433923716	24141	Economy	11600.00
0005433924037	24141	Economy	11600.00
0005433924071	24141	Economy	11600.00
0005433037078	24141	Economy	11600.00
0005433037059	24141	Economy	11600.00
0005432749816	24141	Economy	11600.00
0005433923746	24141	Economy	11600.00
0005433923378	24141	Economy	11600.00
0005432206281	24141	Economy	11600.00
0005433037079	24141	Economy	11600.00
0005433923622	24141	Economy	11600.00
0005433924034	24141	Economy	11600.00
0005433923643	24141	Economy	11600.00
0005433037035	24141	Economy	11600.00
0005433037032	24141	Economy	11600.00
0005432206278	24141	Economy	11600.00
0005433924113	24141	Economy	11600.00
0005433037065	24141	Economy	11600.00
0005433037083	24141	Economy	11600.00
0005433923764	24141	Economy	11600.00
0005433037076	24141	Economy	11600.00
0005433923842	24141	Economy	11600.00
0005433924108	24141	Economy	11600.00
0005433037033	24141	Economy	12700.00
0005433037048	24141	Economy	11600.00
0005433923748	24141	Economy	11600.00
0005433924325	24141	Economy	11600.00
0005433923962	24141	Economy	12700.00
0005433924033	24141	Economy	12700.00
0005433037043	24141	Economy	11600.00
0005433037058	24141	Economy	11600.00
0005433923834	24141	Economy	11600.00
0005433923592	24141	Economy	11600.00
0005433924324	24141	Economy	11600.00
0005433923558	24141	Economy	11600.00
0005433924270	24141	Economy	11600.00
0005433924098	24141	Economy	11600.00
0005433037053	24141	Economy	11600.00
0005433037044	24141	Economy	11600.00
0005432206283	24141	Economy	11600.00
0005433037040	24141	Economy	11600.00
0005433924056	24141	Economy	11600.00
0005433037049	24141	Economy	11600.00
0005433037066	24141	Economy	11600.00
0005433923995	24141	Economy	11600.00
0005433037056	24141	Economy	11600.00
0005433037042	24141	Economy	11600.00
0005433037034	24141	Economy	11600.00
0005433924057	24141	Economy	11600.00
0005433924212	24141	Economy	11600.00
0005433037064	24141	Economy	11600.00
0005433923540	24141	Economy	11600.00
0005433923975	24141	Economy	11600.00
0005434028340	24141	Economy	11600.00
0005433923652	24141	Economy	11600.00
0005433923637	24141	Economy	11600.00
0005433923793	24141	Economy	11600.00
0005433923679	24141	Economy	11600.00
0005433923651	24141	Economy	11600.00
0005433924128	24141	Economy	11600.00
0005433037037	24141	Economy	11600.00
0005433923373	24141	Economy	11600.00
0005433037039	24141	Economy	11600.00
0005433923586	24141	Economy	11600.00
0005433923672	24141	Economy	11600.00
0005433037070	24141	Economy	11600.00
0005433923684	24141	Economy	11600.00
0005433923763	24141	Economy	11600.00
0005434028344	24141	Economy	11600.00
0005432207700	24141	Economy	11600.00
0005433923775	24141	Economy	11600.00
0005433923893	24141	Economy	11600.00
0005434028343	24141	Economy	11600.00
0005433923776	24141	Economy	11600.00
0005433924055	24141	Economy	11600.00
0005433037081	24141	Economy	11600.00
0005433924153	24141	Economy	11600.00
0005433037031	24141	Economy	11600.00
0005433924266	24141	Economy	11600.00
0005433923034	24141	Economy	11600.00
0005433924003	24141	Economy	11600.00
0005433037075	24141	Economy	11600.00
0005433924085	24141	Economy	11600.00
0005433923891	24141	Economy	11600.00
0005433923919	24141	Economy	11600.00
0005433923977	24141	Economy	11600.00
0005433924103	24141	Economy	11600.00
0005433037047	24141	Economy	11600.00
0005433924019	24141	Economy	11600.00
0005433037067	24141	Economy	11600.00
0005433037051	24141	Economy	11600.00
0005433037057	24141	Economy	11600.00
0005433037063	24141	Economy	11600.00
0005433037062	24141	Economy	11600.00
0005434731230	304	Business	83700.00
0005434302521	304	Business	83700.00
0005434727174	304	Business	83700.00
0005433289871	304	Business	83700.00
0005433234806	304	Business	83700.00
0005433234681	304	Business	83700.00
0005433234665	304	Business	83700.00
0005434727237	304	Business	83700.00
0005434552042	304	Business	83700.00
0005433181233	304	Business	83700.00
0005434552029	304	Business	83700.00
0005433766675	304	Business	83700.00
0005433234688	304	Business	83700.00
0005434727227	304	Business	83700.00
0005433234724	304	Business	83700.00
0005435142771	304	Business	83700.00
0005435142766	304	Business	83700.00
0005432277998	304	Business	83700.00
0005433234558	304	Business	83700.00
0005434552048	304	Business	83700.00
0005434727178	304	Business	83700.00
0005434727272	304	Business	83700.00
0005434727198	304	Business	83700.00
0005433181273	304	Business	83700.00
0005434727242	304	Business	83700.00
0005435142776	304	Comfort	47400.00
0005435142774	304	Comfort	47400.00
0005434727194	304	Comfort	47400.00
0005434552018	304	Comfort	47400.00
0005433234805	304	Comfort	47400.00
0005434727268	304	Comfort	47400.00
0005434552001	304	Comfort	47400.00
0005433126879	304	Comfort	47400.00
0005434727239	304	Comfort	47400.00
0005433126878	304	Comfort	47400.00
0005434302524	304	Comfort	47400.00
0005434727241	304	Comfort	47400.00
0005434731226	304	Comfort	47400.00
0005434735759	304	Comfort	47400.00
0005433181203	304	Comfort	47400.00
0005433181200	304	Comfort	47400.00
0005434552006	304	Comfort	47400.00
0005433181259	304	Comfort	47400.00
0005434551999	304	Comfort	47400.00
0005435142767	304	Comfort	47400.00
0005433181079	304	Comfort	47400.00
0005434735761	304	Comfort	47400.00
0005434552047	304	Comfort	47400.00
0005434727258	304	Comfort	47400.00
0005434727270	304	Comfort	47400.00
0005433234443	304	Comfort	47400.00
0005434302523	304	Comfort	47400.00
0005434735762	304	Comfort	47400.00
0005434727177	304	Comfort	47400.00
0005434551993	304	Comfort	47400.00
0005434727232	304	Comfort	47400.00
0005433126856	304	Comfort	47400.00
0005434727216	304	Comfort	47400.00
0005434727228	304	Comfort	47400.00
0005432277996	304	Comfort	47400.00
0005433234731	304	Comfort	47400.00
0005434727223	304	Comfort	47400.00
0005434552041	304	Comfort	47400.00
0005433234532	304	Comfort	47400.00
0005433234640	304	Economy	27900.00
0005434727179	304	Comfort	47400.00
0005434032042	304	Economy	27900.00
0005434552030	304	Economy	27900.00
0005434727218	304	Economy	27900.00
0005433234461	304	Economy	27900.00
0005433234580	304	Economy	27900.00
0005434727203	304	Economy	27900.00
0005433234669	304	Economy	27900.00
0005433234626	304	Economy	27900.00
0005434552031	304	Economy	27900.00
0005432277995	304	Economy	27900.00
0005433234802	304	Economy	27900.00
0005433234564	304	Economy	27900.00
0005432278007	304	Economy	27900.00
0005434727189	304	Economy	27900.00
0005434552019	304	Economy	27900.00
0005434032043	304	Economy	27900.00
0005433234865	304	Economy	27900.00
0005434727191	304	Economy	27900.00
0005434727246	304	Economy	27900.00
0005433766665	304	Economy	27900.00
0005434552032	304	Economy	27900.00
0005434727256	304	Economy	27900.00
0005433289872	304	Economy	27900.00
0005434552039	304	Economy	27900.00
0005434727196	304	Economy	27900.00
0005434552040	304	Economy	27900.00
0005434727231	304	Economy	27900.00
0005433234608	304	Economy	27900.00
0005434552005	304	Economy	27900.00
0005433234597	304	Economy	27900.00
0005434727220	304	Economy	27900.00
0005434727219	304	Economy	27900.00
0005434727271	304	Economy	27900.00
0005434727235	304	Economy	27900.00
0005433234733	304	Economy	27900.00
0005433181271	304	Economy	27900.00
0005434727187	304	Economy	27900.00
0005434727161	304	Economy	27900.00
0005433234600	304	Economy	27900.00
0005434727267	304	Economy	27900.00
0005433234660	304	Economy	27900.00
0005434727264	304	Economy	27900.00
0005433234247	304	Economy	27900.00
0005434727205	304	Economy	27900.00
0005433234826	304	Economy	27900.00
0005434727244	304	Economy	27900.00
0005434727262	304	Economy	27900.00
0005434552034	304	Economy	27900.00
0005434727170	304	Economy	27900.00
0005434302522	304	Economy	27900.00
0005434727184	304	Economy	27900.00
0005434552046	304	Economy	27900.00
0005434727163	304	Economy	27900.00
0005432277999	304	Economy	27900.00
0005434727225	304	Economy	27900.00
0005433234658	304	Economy	27900.00
0005433181101	304	Economy	27900.00
0005434727224	304	Economy	27900.00
0005434552017	304	Economy	27900.00
0005433126862	304	Economy	27900.00
0005434727192	304	Economy	30700.00
0005433126877	304	Economy	27900.00
0005434552022	304	Economy	30700.00
0005433234844	304	Economy	27900.00
0005433234631	304	Economy	30700.00
0005434727180	304	Economy	27900.00
0005434552045	304	Economy	30700.00
0005434727212	304	Economy	27900.00
0005432277997	304	Economy	30700.00
0005434727153	304	Economy	27900.00
0005434032033	304	Economy	30700.00
0005434727155	304	Economy	27900.00
0005434727157	304	Economy	27900.00
0005433289873	304	Economy	27900.00
0005433234410	304	Economy	27900.00
0005433181278	304	Economy	27900.00
0005434727245	304	Economy	27900.00
0005433234287	304	Economy	27900.00
0005435142769	304	Economy	27900.00
0005434727183	304	Economy	27900.00
0005433234827	304	Economy	27900.00
0005434727154	304	Economy	27900.00
0005434552038	304	Economy	27900.00
0005434727204	304	Economy	27900.00
0005433181204	304	Economy	27900.00
0005434552035	304	Economy	27900.00
0005433234389	304	Economy	27900.00
0005434727208	304	Economy	27900.00
0005434552004	304	Economy	27900.00
0005433234771	304	Economy	27900.00
0005434727236	304	Economy	27900.00
0005433235003	304	Economy	27900.00
0005433181362	304	Economy	27900.00
0005434727226	304	Economy	27900.00
0005432278008	304	Economy	27900.00
0005433131730	304	Economy	27900.00
0005434727243	304	Economy	27900.00
0005434552000	304	Economy	27900.00
0005434727275	304	Economy	27900.00
0005434552002	304	Economy	27900.00
0005434552021	304	Economy	27900.00
0005434727185	304	Economy	27900.00
0005434727171	304	Economy	27900.00
0005434727214	304	Economy	27900.00
0005434731227	304	Economy	27900.00
0005433234540	304	Economy	27900.00
0005435142775	304	Economy	27900.00
0005433234520	304	Economy	27900.00
0005433181250	304	Economy	27900.00
0005434727221	304	Economy	27900.00
0005434735760	304	Economy	27900.00
0005434727190	304	Economy	27900.00
0005434727188	304	Economy	27900.00
0005433234521	304	Economy	27900.00
0005432278000	304	Economy	27900.00
0005434727266	304	Economy	27900.00
0005434727169	304	Economy	27900.00
0005433234732	304	Economy	27900.00
0005433181201	304	Economy	27900.00
0005434731229	304	Economy	27900.00
0005434727176	304	Economy	27900.00
0005434727182	304	Economy	27900.00
0005433181319	304	Economy	27900.00
0005434552028	304	Economy	27900.00
0005433234906	304	Economy	27900.00
0005433234442	304	Economy	27900.00
0005433181256	304	Economy	27900.00
0005434727167	304	Economy	27900.00
0005434552007	304	Economy	27900.00
0005433234341	304	Economy	27900.00
0005435142770	304	Economy	27900.00
0005433234510	304	Economy	27900.00
0005434552012	304	Economy	27900.00
0005434552015	304	Economy	27900.00
0005434552036	304	Economy	27900.00
0005433234569	304	Economy	27900.00
0005434727181	304	Economy	27900.00
0005434727207	304	Economy	27900.00
0005434727234	304	Economy	27900.00
0005433234390	304	Economy	27900.00
0005433234411	304	Economy	27900.00
0005434727175	304	Economy	27900.00
0005434727230	304	Economy	27900.00
0005434551995	304	Economy	27900.00
0005433289890	304	Economy	27900.00
0005434727273	304	Economy	27900.00
0005433234591	304	Economy	27900.00
0005434727209	304	Economy	27900.00
0005434552043	304	Economy	27900.00
0005433234639	304	Economy	27900.00
0005433234542	304	Economy	27900.00
0005434727215	304	Economy	27900.00
0005434727250	304	Economy	27900.00
0005434727193	304	Economy	27900.00
0005433181263	304	Economy	27900.00
0005434727202	304	Economy	27900.00
0005434727253	304	Economy	27900.00
0005434727217	304	Economy	27900.00
0005434727238	304	Economy	27900.00
0005434727257	304	Economy	27900.00
0005434552003	304	Economy	27900.00
0005434552014	304	Economy	27900.00
0005433234429	304	Economy	27900.00
0005433234683	304	Economy	27900.00
0005434727162	304	Economy	27900.00
0005434727197	304	Economy	27900.00
0005433181272	304	Economy	30700.00
0005434552033	304	Economy	30700.00
0005434727265	304	Economy	30700.00
0005434551998	304	Economy	27900.00
0005433234432	304	Economy	27900.00
0005434552024	304	Economy	27900.00
0005434727260	304	Economy	27900.00
0005434552020	304	Economy	27900.00
0005434552013	304	Economy	27900.00
0005434727255	304	Economy	27900.00
0005434727276	304	Economy	27900.00
0005434552010	304	Economy	27900.00
0005435142765	304	Economy	27900.00
0005434032031	304	Economy	27900.00
0005432278002	304	Economy	27900.00
0005433234592	304	Economy	27900.00
0005434727254	304	Economy	27900.00
0005434727166	304	Economy	27900.00
0005433126857	304	Economy	27900.00
0005435142773	304	Economy	27900.00
0005434552027	304	Economy	27900.00
0005433234496	304	Economy	27900.00
0005434727195	304	Economy	27900.00
0005432278001	304	Economy	27900.00
0005434727247	304	Economy	27900.00
0005433181249	304	Economy	27900.00
0005434032040	304	Economy	27900.00
0005433289891	304	Economy	27900.00
0005432278003	304	Economy	27900.00
0005434552037	304	Economy	27900.00
0005434727233	304	Economy	27900.00
0005432278004	304	Economy	27900.00
0005434727201	304	Economy	27900.00
0005433234543	304	Economy	27900.00
0005434552026	304	Economy	27900.00
0005433234462	304	Economy	27900.00
0005434551994	304	Economy	27900.00
0005433181216	304	Economy	27900.00
0005433234428	304	Economy	27900.00
0005434727263	304	Economy	27900.00
0005435142777	304	Economy	27900.00
0005434727251	304	Economy	27900.00
0005434727261	304	Economy	27900.00
0005434727172	304	Economy	27900.00
0005433181291	304	Economy	27900.00
0005434727158	304	Economy	27900.00
0005432278006	304	Economy	27900.00
0005434552009	304	Economy	27900.00
0005434727269	304	Economy	27900.00
0005433181228	304	Economy	27900.00
0005434731228	304	Economy	27900.00
0005433126876	304	Economy	27900.00
0005434727213	304	Economy	27900.00
0005434552011	304	Economy	27900.00
0005434727164	304	Economy	27900.00
0005433234598	304	Economy	27900.00
0005433234527	304	Economy	27900.00
0005434727210	304	Economy	27900.00
0005433234260	304	Economy	27900.00
0005434727165	304	Economy	27900.00
0005433234682	304	Economy	27900.00
0005434552008	304	Economy	27900.00
0005434552016	304	Economy	27900.00
0005434727249	304	Economy	27900.00
0005434727200	304	Economy	27900.00
0005434727186	304	Economy	27900.00
0005433111504	304	Economy	27900.00
0005434551996	304	Economy	27900.00
0005434552023	304	Economy	27900.00
0005433234557	304	Economy	27900.00
0005434727168	304	Economy	27900.00
0005433181290	304	Economy	27900.00
0005434727199	304	Economy	27900.00
0005434727252	304	Economy	27900.00
0005434727229	304	Economy	27900.00
0005434727206	304	Economy	27900.00
0005434727274	304	Economy	27900.00
0005434727222	304	Economy	27900.00
0005434727160	304	Economy	27900.00
0005433126867	304	Economy	27900.00
0005434727240	304	Economy	27900.00
0005434727156	304	Economy	27900.00
0005434727211	304	Economy	27900.00
0005433126868	304	Economy	27900.00
0005433234651	304	Economy	27900.00
0005434552044	304	Economy	27900.00
0005434727248	304	Economy	27900.00
0005433234677	304	Economy	27900.00
0005435142768	304	Economy	27900.00
0005435142772	304	Economy	27900.00
0005432278005	304	Economy	27900.00
0005434551997	304	Economy	27900.00
0005433234801	304	Economy	27900.00
0005433181277	304	Economy	27900.00
0005434727159	304	Economy	27900.00
0005434552025	304	Economy	27900.00
0005435142778	304	Economy	27900.00
0005433234680	304	Economy	27900.00
0005434727173	304	Economy	27900.00
0005434727259	304	Economy	27900.00
0005434551635	9839	Business	83700.00
0005434731199	9839	Business	83700.00
0005434726564	9839	Business	83700.00
0005433235114	9839	Business	83700.00
0005433126911	9839	Business	83700.00
0005435142661	9839	Business	83700.00
0005434726429	9839	Business	83700.00
0005434726376	9839	Business	83700.00
0005434032089	9839	Business	83700.00
0005434032090	9839	Business	83700.00
0005433289948	9839	Business	83700.00
0005434726119	9839	Business	83700.00
0005433289950	9839	Business	83700.00
0005434725910	9839	Business	83700.00
0005434725955	9839	Business	83700.00
0005434735719	9839	Business	83700.00
0005434551550	9839	Business	83700.00
0005434551441	9839	Business	83700.00
0005434551554	9839	Business	83700.00
0005433289953	9839	Business	83700.00
0005434726135	9839	Business	83700.00
0005434735703	9839	Business	83700.00
0005433181469	9839	Business	83700.00
0005433129343	9839	Business	83700.00
0005433235081	9839	Business	83700.00
0005434725840	9839	Comfort	47400.00
0005434725580	9839	Business	83700.00
0005434726231	9839	Comfort	47400.00
0005434551555	9839	Comfort	47400.00
0005432199347	9839	Comfort	47400.00
0005433235091	9839	Comfort	47400.00
0005434726010	9839	Comfort	47400.00
0005434725772	9839	Comfort	47400.00
0005434726194	9839	Comfort	47400.00
0005434551541	9839	Comfort	47400.00
0005434726002	9839	Comfort	47400.00
0005433235133	9839	Comfort	47400.00
0005435142575	9839	Comfort	47400.00
0005433181455	9839	Comfort	47400.00
0005433181468	9839	Comfort	47400.00
0005434551503	9839	Comfort	47400.00
0005433235117	9839	Comfort	47400.00
0005434726369	9839	Comfort	47400.00
0005433235107	9839	Comfort	47400.00
0005434726244	9839	Comfort	47400.00
0005434551440	9839	Comfort	47400.00
0005434726189	9839	Comfort	47400.00
0005434735722	9839	Comfort	47400.00
0005434726254	9839	Comfort	47400.00
0005433181470	9839	Comfort	47400.00
0005434726289	9839	Comfort	47400.00
0005434725942	9839	Comfort	47400.00
0005434725754	9839	Comfort	47400.00
0005434725869	9839	Comfort	47400.00
0005434551553	9839	Comfort	47400.00
0005433289952	9839	Comfort	47400.00
0005434725855	9839	Comfort	47400.00
0005433235121	9839	Comfort	47400.00
0005434726180	9839	Comfort	47400.00
0005433235127	9839	Comfort	47400.00
0005434725868	9839	Comfort	47400.00
0005433235106	9839	Comfort	47400.00
0005434726255	9839	Comfort	47400.00
0005434551407	9839	Comfort	47400.00
0005434726191	9839	Comfort	47400.00
0005433129340	9839	Economy	27900.00
0005434725773	9839	Economy	27900.00
0005434725378	9839	Economy	27900.00
0005434726065	9839	Economy	27900.00
0005433235123	9839	Economy	27900.00
0005435142658	9839	Economy	27900.00
0005434551492	9839	Economy	27900.00
0005434726441	9839	Economy	27900.00
0005434726471	9839	Economy	27900.00
0005433181472	9839	Economy	27900.00
0005433235089	9839	Economy	27900.00
0005433181474	9839	Economy	27900.00
0005434726160	9839	Economy	27900.00
0005433129344	9839	Economy	27900.00
0005434726265	9839	Economy	27900.00
0005434726296	9839	Economy	27900.00
0005433235094	9839	Economy	27900.00
0005434725946	9839	Economy	27900.00
0005434726136	9839	Economy	27900.00
0005434551456	9839	Economy	27900.00
0005434727016	9839	Economy	27900.00
0005433235095	9839	Economy	27900.00
0005434551397	9839	Economy	27900.00
0005433235130	9839	Economy	27900.00
0005434551386	9839	Economy	27900.00
0005434726259	9839	Economy	27900.00
0005435142634	9839	Economy	27900.00
0005434726518	9839	Economy	27900.00
0005433235111	9839	Economy	27900.00
0005434302476	9839	Economy	27900.00
0005434726453	9839	Economy	27900.00
0005433181461	9839	Economy	27900.00
0005434726818	9839	Economy	27900.00
0005434726401	9839	Economy	27900.00
0005434726456	9839	Economy	27900.00
0005434726057	9839	Economy	27900.00
0005433235097	9839	Economy	27900.00
0005433235140	9839	Economy	27900.00
0005433235124	9839	Economy	27900.00
0005435142633	9839	Economy	27900.00
0005433235087	9839	Economy	27900.00
0005434726029	9839	Economy	27900.00
0005434726092	9839	Economy	27900.00
0005433181457	9839	Economy	27900.00
0005433235103	9839	Economy	27900.00
0005434725705	9839	Economy	27900.00
0005433235135	9839	Economy	27900.00
0005433235096	9839	Economy	27900.00
0005433235118	9839	Economy	27900.00
0005433235134	9839	Economy	27900.00
0005434551474	9839	Economy	27900.00
0005435142623	9839	Economy	27900.00
0005434302488	9839	Economy	27900.00
0005434726058	9839	Economy	27900.00
0005434726732	9839	Economy	27900.00
0005434726375	9839	Economy	27900.00
0005434726031	9839	Economy	27900.00
0005433235120	9839	Economy	27900.00
0005434551177	9839	Economy	27900.00
0005434726625	9839	Economy	27900.00
0005434551457	9839	Economy	27900.00
0005434726399	9839	Economy	27900.00
0005433181465	9839	Economy	30700.00
0005434726374	9839	Economy	27900.00
0005433129341	9839	Economy	30700.00
0005434551611	9839	Economy	27900.00
0005435142688	9839	Economy	27900.00
0005434735718	9839	Economy	27900.00
0005434725770	9839	Economy	30700.00
0005433181467	9839	Economy	30700.00
0005433235079	9839	Economy	27900.00
0005433235125	9839	Economy	30700.00
0005433235082	9839	Economy	27900.00
0005434726459	9839	Economy	27900.00
0005435142627	9839	Economy	27900.00
0005434726230	9839	Economy	27900.00
0005434551794	9839	Economy	27900.00
0005433766696	9839	Economy	27900.00
0005434551428	9839	Economy	27900.00
0005434726427	9839	Economy	27900.00
0005433181473	9839	Economy	27900.00
0005433181456	9839	Economy	27900.00
0005434731190	9839	Economy	27900.00
0005434726363	9839	Economy	27900.00
0005434725854	9839	Economy	27900.00
0005433181454	9839	Economy	27900.00
0005433181471	9839	Economy	27900.00
0005434726392	9839	Economy	27900.00
0005434725961	9839	Economy	27900.00
0005434726012	9839	Economy	27900.00
0005433126912	9839	Economy	27900.00
0005433181458	9839	Economy	27900.00
0005433235088	9839	Economy	27900.00
0005435142576	9839	Economy	27900.00
0005434551570	9839	Economy	27900.00
0005433289951	9839	Economy	27900.00
0005434726081	9839	Economy	27900.00
0005433235099	9839	Economy	27900.00
0005433235102	9839	Economy	27900.00
0005434725990	9839	Economy	27900.00
0005433113567	9839	Economy	27900.00
0005433235086	9839	Economy	27900.00
0005433289949	9839	Economy	27900.00
0005434551793	9839	Economy	27900.00
0005433126909	9839	Economy	27900.00
0005434726166	9839	Economy	27900.00
0005434726095	9839	Economy	27900.00
0005434726428	9839	Economy	27900.00
0005433181464	9839	Economy	27900.00
0005433181462	9839	Economy	27900.00
0005434726190	9839	Economy	27900.00
0005434725755	9839	Economy	27900.00
0005433235112	9839	Economy	27900.00
0005434726137	9839	Economy	27900.00
0005433181452	9839	Economy	27900.00
0005433113569	9839	Economy	27900.00
0005433235110	9839	Economy	27900.00
0005433766695	9839	Economy	27900.00
0005434551583	9839	Economy	27900.00
0005434551489	9839	Economy	27900.00
0005434551620	9839	Economy	27900.00
0005434551518	9839	Economy	27900.00
0005433766694	9839	Economy	27900.00
0005433235092	9839	Economy	27900.00
0005433235132	9839	Economy	27900.00
0005433235129	9839	Economy	27900.00
0005434726557	9839	Economy	27900.00
0005434725959	9839	Economy	27900.00
0005434726367	9839	Economy	27900.00
0005434725989	9839	Economy	27900.00
0005434725842	9839	Economy	27900.00
0005433181466	9839	Economy	27900.00
0005435142635	9839	Economy	27900.00
0005433235101	9839	Economy	27900.00
0005434726118	9839	Economy	27900.00
0005434551494	9839	Economy	27900.00
0005434726099	9839	Economy	27900.00
0005434731195	9839	Economy	27900.00
0005434726080	9839	Economy	27900.00
0005433235083	9839	Economy	27900.00
0005434725579	9839	Economy	27900.00
0005435142662	9839	Economy	27900.00
0005434725789	9839	Economy	27900.00
0005434725820	9839	Economy	27900.00
0005433181453	9839	Economy	27900.00
0005434032092	9839	Economy	27900.00
0005433235080	9839	Economy	27900.00
0005433126908	9839	Economy	27900.00
0005434726310	9839	Economy	27900.00
0005433235098	9839	Economy	27900.00
0005434726173	9839	Economy	27900.00
0005433181463	9839	Economy	27900.00
0005433235141	9839	Economy	27900.00
0005434726565	9839	Economy	27900.00
0005434726460	9839	Economy	27900.00
0005433181475	9839	Economy	27900.00
0005434726510	9839	Economy	27900.00
0005434551822	9839	Economy	27900.00
0005435142607	9839	Economy	27900.00
0005434726159	9839	Economy	27900.00
0005434551156	9839	Economy	27900.00
0005434551482	9839	Economy	27900.00
0005432199346	9839	Economy	27900.00
0005434032093	9839	Economy	27900.00
0005434731196	9839	Economy	27900.00
0005433235085	9839	Economy	27900.00
0005434725958	9839	Economy	27900.00
0005434551332	9839	Economy	27900.00
0005434726079	9839	Economy	27900.00
0005433235119	9839	Economy	27900.00
0005434725788	9839	Economy	27900.00
0005434725952	9839	Economy	27900.00
0005434726264	9839	Economy	27900.00
0005433235105	9839	Economy	27900.00
0005434551612	9839	Economy	27900.00
0005434551572	9839	Economy	27900.00
0005434726834	9839	Economy	27900.00
0005434551641	9839	Economy	27900.00
0005433235100	9839	Economy	30700.00
0005433235108	9839	Economy	30700.00
0005434726400	9839	Economy	30700.00
0005434725841	9839	Economy	30700.00
0005433235139	9839	Economy	30700.00
0005433235138	9839	Economy	30700.00
0005434551427	9839	Economy	27900.00
0005433235116	9839	Economy	27900.00
0005433235122	9839	Economy	27900.00
0005434726256	9839	Economy	27900.00
0005432199349	9839	Economy	27900.00
0005433235078	9839	Economy	27900.00
0005433181459	9839	Economy	27900.00
0005434726566	9839	Economy	27900.00
0005434551621	9839	Economy	27900.00
0005434725945	9839	Economy	27900.00
0005434725839	9839	Economy	27900.00
0005434726350	9839	Economy	27900.00
0005433235093	9839	Economy	27900.00
0005434551279	9839	Economy	27900.00
0005434032091	9839	Economy	27900.00
0005433181449	9839	Economy	27900.00
0005434551398	9839	Economy	27900.00
0005434726368	9839	Economy	27900.00
0005434551680	9839	Economy	27900.00
0005433235109	9839	Economy	27900.00
0005433235136	9839	Economy	27900.00
0005433235131	9839	Economy	27900.00
0005433235113	9839	Economy	27900.00
0005434551599	9839	Economy	27900.00
0005434726192	9839	Economy	27900.00
0005434551529	9839	Economy	27900.00
0005434726833	9839	Economy	27900.00
0005433235128	9839	Economy	27900.00
0005434731198	9839	Economy	27900.00
0005434725498	9839	Economy	27900.00
0005433235137	9839	Economy	27900.00
0005434302472	9839	Economy	27900.00
0005435142655	9839	Economy	27900.00
0005434551493	9839	Economy	27900.00
0005434725843	9839	Economy	27900.00
0005434725819	9839	Economy	27900.00
0005434726059	9839	Economy	27900.00
0005434725717	9839	Economy	27900.00
0005434726101	9839	Economy	27900.00
0005434551464	9839	Economy	27900.00
0005434726100	9839	Economy	27900.00
0005434551542	9839	Economy	27900.00
0005434551499	9839	Economy	27900.00
0005434726028	9839	Economy	27900.00
0005433181460	9839	Economy	27900.00
0005434725922	9839	Economy	27900.00
0005434725766	9839	Economy	27900.00
0005433129339	9839	Economy	27900.00
0005434551619	9839	Economy	27900.00
0005433113568	9839	Economy	27900.00
0005434725771	9839	Economy	27900.00
0005434726172	9839	Economy	27900.00
0005435142608	9839	Economy	27900.00
0005434551465	9839	Economy	27900.00
0005434302473	9839	Economy	27900.00
0005432199345	9839	Economy	27900.00
0005432199348	9839	Economy	27900.00
0005433235090	9839	Economy	27900.00
0005434551406	9839	Economy	27900.00
0005434726245	9839	Economy	27900.00
0005434726372	9839	Economy	27900.00
0005434726817	9839	Economy	27900.00
0005434725838	9839	Economy	27900.00
0005434551214	9839	Economy	27900.00
0005434726395	9839	Economy	27900.00
0005435142689	9839	Economy	27900.00
0005433181451	9839	Economy	27900.00
0005432199351	9839	Economy	27900.00
0005434725500	9839	Economy	27900.00
0005433129342	9839	Economy	27900.00
0005434551681	9839	Economy	27900.00
0005433235115	9839	Economy	27900.00
0005434726371	9839	Economy	27900.00
0005434726378	9839	Economy	27900.00
0005434726432	9839	Economy	27900.00
0005434551733	9839	Economy	27900.00
0005434551539	9839	Economy	27900.00
0005433181450	9839	Economy	27900.00
0005433235126	9839	Economy	27900.00
0005434726380	9839	Economy	27900.00
0005433235084	9839	Economy	27900.00
0005434725680	9839	Economy	27900.00
0005434551642	9839	Economy	27900.00
0005434726077	9839	Economy	27900.00
0005434725938	9839	Economy	27900.00
0005433126910	9839	Economy	27900.00
0005434725499	9839	Economy	27900.00
0005434551540	9839	Economy	27900.00
0005432199350	9839	Economy	27900.00
0005433235104	9839	Economy	27900.00
0005434726082	9839	Economy	27900.00
0005434551504	9839	Economy	27900.00
0005432529863	7765	Business	42100.00
0005435214096	7765	Business	42100.00
0005434068565	7765	Business	42100.00
0005435214118	7765	Business	42100.00
0005434068560	7765	Business	42100.00
0005432529872	7765	Business	42100.00
0005435214173	7765	Business	42100.00
0005432529917	7765	Business	42100.00
0005432529897	7765	Business	42100.00
0005432150309	7765	Business	42100.00
0005435214154	7765	Business	42100.00
0005435213500	7765	Business	42100.00
0005435213808	7765	Business	42100.00
0005432529830	7765	Business	42100.00
0005432529880	7765	Business	42100.00
0005432529891	7765	Business	42100.00
0005434068569	7765	Business	42100.00
0005435213689	7765	Business	42100.00
0005435214026	7765	Business	42100.00
0005432428976	7765	Business	42100.00
0005435214113	7765	Business	42100.00
0005432069863	7765	Business	42100.00
0005432529913	7765	Business	42100.00
0005432529870	7765	Business	42100.00
0005432150310	7765	Business	42100.00
0005435213741	7765	Comfort	23900.00
0005434068571	7765	Comfort	23900.00
0005435213875	7765	Comfort	23900.00
0005432069861	7765	Comfort	23900.00
0005434068592	7765	Comfort	23900.00
0005435214099	7765	Comfort	23900.00
0005434068593	7765	Comfort	23900.00
0005432529836	7765	Comfort	23900.00
0005432529835	7765	Comfort	23900.00
0005432529925	7765	Comfort	23900.00
0005435213985	7765	Comfort	23900.00
0005432529859	7765	Comfort	23900.00
0005432529903	7765	Comfort	23900.00
0005432529799	7765	Comfort	23900.00
0005435214119	7765	Comfort	23900.00
0005432529905	7765	Comfort	23900.00
0005434068549	7765	Comfort	23900.00
0005432529800	7765	Comfort	23900.00
0005432529921	7765	Comfort	23900.00
0005435213653	7765	Comfort	23900.00
0005435213948	7765	Comfort	23900.00
0005432533334	7765	Comfort	23900.00
0005435214111	7765	Comfort	23900.00
0005435213871	7765	Comfort	23900.00
0005432428978	7765	Comfort	23900.00
0005434068591	7765	Comfort	23900.00
0005432529817	7765	Comfort	23900.00
0005435213822	7765	Comfort	23900.00
0005434068552	7765	Comfort	23900.00
0005432537088	7765	Comfort	23900.00
0005434068599	7765	Comfort	23900.00
0005432529795	7765	Comfort	23900.00
0005434068610	7765	Comfort	23900.00
0005432529922	7765	Comfort	23900.00
0005432529894	7765	Comfort	23900.00
0005432529811	7765	Comfort	23900.00
0005434068551	7765	Comfort	23900.00
0005432529831	7765	Comfort	23900.00
0005432529862	7765	Comfort	23900.00
0005432150304	7765	Comfort	23900.00
0005434068576	7765	Comfort	23900.00
0005432069866	7765	Comfort	23900.00
0005434068559	7765	Comfort	23900.00
0005432069867	7765	Comfort	23900.00
0005432529904	7765	Economy	14000.00
0005432529902	7765	Comfort	23900.00
0005434068567	7765	Economy	14000.00
0005435213789	7765	Economy	14000.00
0005434068564	7765	Economy	14000.00
0005432529849	7765	Economy	14000.00
0005435214263	7765	Economy	14000.00
0005432529816	7765	Economy	14000.00
0005435214043	7765	Economy	14000.00
0005432529848	7765	Economy	14000.00
0005432529901	7765	Economy	14000.00
0005434068548	7765	Economy	14000.00
0005434068597	7765	Economy	14000.00
0005434068600	7765	Economy	14000.00
0005432529919	7765	Economy	14000.00
0005434068595	7765	Economy	14000.00
0005432529829	7765	Economy	14000.00
0005432529916	7765	Economy	14000.00
0005434068606	7765	Economy	14000.00
0005435213668	7765	Economy	14000.00
0005432529801	7765	Economy	14000.00
0005432529906	7765	Economy	14000.00
0005435214077	7765	Economy	14000.00
0005434068579	7765	Economy	14000.00
0005432535903	7765	Economy	14000.00
0005434068587	7765	Economy	14000.00
0005435213753	7765	Economy	14000.00
0005435213874	7765	Economy	14000.00
0005432150305	7765	Economy	14000.00
0005434068601	7765	Economy	14000.00
0005432535901	7765	Economy	14000.00
0005434068618	7765	Economy	14000.00
0005434068602	7765	Economy	14000.00
0005434068575	7765	Economy	14000.00
0005435214208	7765	Economy	14000.00
0005432529827	7765	Economy	14000.00
0005432529867	7765	Economy	14000.00
0005434068616	7765	Economy	14000.00
0005432529853	7765	Economy	14000.00
0005432529803	7765	Economy	14000.00
0005432069870	7765	Economy	14000.00
0005432069862	7765	Economy	14000.00
0005434068561	7765	Economy	14000.00
0005433656684	7765	Economy	14000.00
0005432529813	7765	Economy	14000.00
0005432529899	7765	Economy	14000.00
0005432529887	7765	Economy	14000.00
0005434068583	7765	Economy	14000.00
0005434068617	7765	Economy	14000.00
0005432529837	7765	Economy	14000.00
0005432069858	7765	Economy	14000.00
0005432529846	7765	Economy	14000.00
0005432529819	7765	Economy	14000.00
0005432529884	7765	Economy	14000.00
0005435630973	7765	Economy	14000.00
0005432529908	7765	Economy	14000.00
0005432529804	7765	Economy	14000.00
0005434068598	7765	Economy	15400.00
0005435214172	7765	Economy	15400.00
0005432529895	7765	Economy	14000.00
0005432529920	7765	Economy	14000.00
0005434068605	7765	Economy	14000.00
0005432529855	7765	Economy	15400.00
0005435213835	7765	Economy	14000.00
0005432529861	7765	Economy	14000.00
0005432529833	7765	Economy	14000.00
0005432529838	7765	Economy	14000.00
0005432069857	7765	Economy	14000.00
0005434068554	7765	Economy	14000.00
0005434068612	7765	Economy	14000.00
0005433656685	7765	Economy	14000.00
0005435213934	7765	Economy	14000.00
0005435214243	7765	Economy	14000.00
0005432533335	7765	Economy	14000.00
0005435213889	7765	Economy	14000.00
0005435213791	7765	Economy	14000.00
0005432529915	7765	Economy	14000.00
0005434068590	7765	Economy	14000.00
0005432529826	7765	Economy	14000.00
0005432529883	7765	Economy	14000.00
0005432529798	7765	Economy	14000.00
0005435630987	7765	Economy	14000.00
0005432529892	7765	Economy	14000.00
0005435213760	7765	Economy	14000.00
0005432529797	7765	Economy	14000.00
0005432529907	7765	Economy	14000.00
0005435214093	7765	Economy	14000.00
0005434068557	7765	Economy	14000.00
0005432069869	7765	Economy	14000.00
0005432529898	7765	Economy	14000.00
0005434068578	7765	Economy	14000.00
0005434068577	7765	Economy	14000.00
0005434068609	7765	Economy	14000.00
0005434068572	7765	Economy	14000.00
0005435213502	7765	Economy	14000.00
0005434068570	7765	Economy	14000.00
0005435214127	7765	Economy	14000.00
0005434068585	7765	Economy	14000.00
0005434068555	7765	Economy	14000.00
0005432529924	7765	Economy	14000.00
0005432529873	7765	Economy	14000.00
0005434068573	7765	Economy	14000.00
0005434068588	7765	Economy	14000.00
0005434068553	7765	Economy	14000.00
0005435214080	7765	Economy	14000.00
0005432529851	7765	Economy	14000.00
0005432529900	7765	Economy	14000.00
0005432529896	7765	Economy	14000.00
0005432529793	7765	Economy	14000.00
0005432529912	7765	Economy	14000.00
0005432529882	7765	Economy	14000.00
0005434068566	7765	Economy	14000.00
0005432150307	7765	Economy	14000.00
0005434068558	7765	Economy	14000.00
0005432529814	7765	Economy	14000.00
0005432069868	7765	Economy	14000.00
0005432529847	7765	Economy	14000.00
0005432529890	7765	Economy	14000.00
0005432529842	7765	Economy	14000.00
0005435214242	7765	Economy	14000.00
0005435213654	7765	Economy	14000.00
0005432428977	7765	Economy	14000.00
0005435213938	7765	Economy	14000.00
0005435213688	7765	Economy	14000.00
0005435213887	7765	Economy	14000.00
0005435214112	7765	Economy	14000.00
0005432529875	7765	Economy	14000.00
0005435213966	7765	Economy	14000.00
0005434068580	7765	Economy	14000.00
0005432529809	7765	Economy	14000.00
0005432535904	7765	Economy	14000.00
0005435213738	7765	Economy	14000.00
0005435213888	7765	Economy	14000.00
0005435214153	7765	Economy	14000.00
0005435213683	7765	Economy	14000.00
0005432533332	7765	Economy	14000.00
0005432529815	7765	Economy	14000.00
0005432529844	7765	Economy	14000.00
0005435214044	7765	Economy	14000.00
0005432529878	7765	Economy	14000.00
0005432529812	7765	Economy	14000.00
0005435213501	7765	Economy	14000.00
0005435213834	7765	Economy	14000.00
0005432069871	7765	Economy	14000.00
0005432529845	7765	Economy	14000.00
0005433656692	7765	Economy	14000.00
0005434068547	7765	Economy	14000.00
0005434068594	7765	Economy	14000.00
0005435214095	7765	Economy	14000.00
0005435213669	7765	Economy	14000.00
0005432529822	7765	Economy	14000.00
0005435214081	7765	Economy	14000.00
0005434068562	7765	Economy	14000.00
0005435213937	7765	Economy	14000.00
0005432529839	7765	Economy	14000.00
0005432529832	7765	Economy	14000.00
0005432529910	7765	Economy	14000.00
0005432529852	7765	Economy	14000.00
0005432529874	7765	Economy	14000.00
0005432529792	7765	Economy	15400.00
0005432537087	7765	Economy	15400.00
0005435214244	7765	Economy	15400.00
0005432069864	7765	Economy	15400.00
0005432529860	7765	Economy	15400.00
0005434068596	7765	Economy	14000.00
0005435213796	7765	Economy	14000.00
0005434068611	7765	Economy	14000.00
0005432529889	7765	Economy	14000.00
0005432069856	7765	Economy	14000.00
0005435214103	7765	Economy	14000.00
0005432529828	7765	Economy	14000.00
0005432529914	7765	Economy	14000.00
0005432529805	7765	Economy	14000.00
0005432529911	7765	Economy	14000.00
0005432069865	7765	Economy	14000.00
0005432529888	7765	Economy	14000.00
0005432529821	7765	Economy	14000.00
0005435213994	7765	Economy	14000.00
0005432529868	7765	Economy	14000.00
0005432529818	7765	Economy	14000.00
0005432529879	7765	Economy	14000.00
0005434068582	7765	Economy	14000.00
0005434068613	7765	Economy	14000.00
0005432069859	7765	Economy	14000.00
0005432529796	7765	Economy	14000.00
0005432529858	7765	Economy	14000.00
0005434068550	7765	Economy	14000.00
0005432529802	7765	Economy	14000.00
0005432150312	7765	Economy	14000.00
0005434068568	7765	Economy	14000.00
0005432150311	7765	Economy	14000.00
0005432529823	7765	Economy	14000.00
0005435214065	7765	Economy	14000.00
0005432535902	7765	Economy	14000.00
0005432529885	7765	Economy	14000.00
0005432529825	7765	Economy	14000.00
0005432529876	7765	Economy	14000.00
0005432533333	7765	Economy	14000.00
0005434068584	7765	Economy	14000.00
0005432529923	7765	Economy	14000.00
0005432529850	7765	Economy	14000.00
0005435213949	7765	Economy	14000.00
0005432529856	7765	Economy	14000.00
0005432529881	7765	Economy	14000.00
0005432529834	7765	Economy	14000.00
0005432529820	7765	Economy	14000.00
0005432529840	7765	Economy	14000.00
0005432529909	7765	Economy	14000.00
0005432529857	7765	Economy	14000.00
0005435213788	7765	Economy	14000.00
0005434068574	7765	Economy	14000.00
0005434068563	7765	Economy	14000.00
0005432529893	7765	Economy	14000.00
0005435213845	7765	Economy	14000.00
0005432150306	7765	Economy	14000.00
0005432529864	7765	Economy	14000.00
0005432529841	7765	Economy	14000.00
0005432529918	7765	Economy	14000.00
0005435214102	7765	Economy	14000.00
0005435214076	7765	Economy	14000.00
0005434068589	7765	Economy	14000.00
0005435630974	7765	Economy	14000.00
0005432529877	7765	Economy	14000.00
0005432529794	7765	Economy	14000.00
0005432535905	7765	Economy	14000.00
0005434068603	7765	Economy	14000.00
0005432529865	7765	Economy	14000.00
0005432529886	7765	Economy	14000.00
0005432529854	7765	Economy	14000.00
0005435213992	7765	Economy	14000.00
0005432529808	7765	Economy	14000.00
0005432529843	7765	Economy	14000.00
0005432529810	7765	Economy	14000.00
0005432529869	7765	Economy	14000.00
0005432529824	7765	Economy	14000.00
0005434068608	7765	Economy	14000.00
0005432150308	7765	Economy	14000.00
0005434068614	7765	Economy	14000.00
0005435213575	7765	Economy	14000.00
0005434068604	7765	Economy	14000.00
0005432428979	7765	Economy	14000.00
0005435214114	7765	Economy	14000.00
0005435214059	7765	Economy	14000.00
0005435214169	7765	Economy	14000.00
0005434068581	7765	Economy	14000.00
0005435213918	7765	Economy	14000.00
0005435213794	7765	Economy	14000.00
0005434068556	7765	Economy	14000.00
0005435213872	7765	Economy	14000.00
0005432529806	7765	Economy	14000.00
0005434068615	7765	Economy	14000.00
0005435213795	7765	Economy	14000.00
0005433656693	7765	Economy	14000.00
0005432069860	7765	Economy	14000.00
0005432529807	7765	Economy	14000.00
0005434068586	7765	Economy	14000.00
0005432529871	7765	Economy	14000.00
0005434068607	7765	Economy	14000.00
0005432529866	7765	Economy	14000.00
0005435615319	5346	Business	43100.00
0005434344738	5346	Business	43100.00
0005435097347	5346	Business	43100.00
0005435491468	5346	Business	43100.00
0005434344744	5346	Business	43100.00
0005435425475	5346	Business	43100.00
0005435097349	5346	Business	43100.00
0005432133431	5346	Business	43100.00
0005434344726	5346	Business	43100.00
0005434344742	5346	Business	43100.00
0005435615342	5346	Business	43100.00
0005432841027	5346	Business	43100.00
0005434573552	5346	Business	43100.00
0005435615341	5346	Business	43100.00
0005434573556	5346	Business	43100.00
0005435425198	5346	Business	43100.00
0005434245042	5346	Business	43100.00
0005435097353	5346	Business	43100.00
0005435615332	5346	Business	43100.00
0005434344709	5346	Business	43100.00
0005435425379	5346	Business	43100.00
0005435319631	5346	Business	43100.00
0005434245072	5346	Comfort	24400.00
0005435615245	5346	Business	43100.00
0005435615322	5346	Comfort	24400.00
0005435615233	5346	Comfort	24400.00
0005435490280	5346	Comfort	24400.00
0005434245152	5346	Comfort	24400.00
0005434344715	5346	Comfort	24400.00
0005434245088	5346	Comfort	24400.00
0005435555397	5346	Comfort	24400.00
0005435425316	5346	Comfort	24400.00
0005435097351	5346	Comfort	24400.00
0005435042866	5346	Comfort	24400.00
0005435615318	5346	Comfort	24400.00
0005435617174	5346	Comfort	24400.00
0005435425292	5346	Comfort	24400.00
0005435425372	5346	Comfort	24400.00
0005435615295	5346	Comfort	24400.00
0005435615263	5346	Comfort	24400.00
0005435615221	5346	Comfort	24400.00
0005434656560	5346	Comfort	24400.00
0005435615327	5346	Comfort	24400.00
0005435425083	5346	Comfort	24400.00
0005435615273	5346	Comfort	24400.00
0005435615315	5346	Comfort	24400.00
0005435615276	5346	Comfort	24400.00
0005434344710	5346	Comfort	24400.00
0005435042864	5346	Comfort	24400.00
0005435615335	5346	Comfort	24400.00
0005433719161	5346	Comfort	24400.00
0005435425308	5346	Comfort	24400.00
0005435425157	5346	Comfort	24400.00
0005435425154	5346	Comfort	24400.00
0005434245191	5346	Comfort	24400.00
0005435425054	5346	Comfort	24400.00
0005435615244	5346	Comfort	24400.00
0005435615262	5346	Comfort	24400.00
0005435615247	5346	Comfort	24400.00
0005435615220	5346	Comfort	24400.00
0005435425051	5346	Comfort	24400.00
0005435615238	5346	Comfort	24400.00
0005434245120	5346	Economy	14400.00
0005435615298	5346	Comfort	24400.00
0005434344725	5346	Economy	14400.00
0005434245032	5346	Economy	14400.00
0005435555398	5346	Economy	14400.00
0005435615346	5346	Economy	14400.00
0005435425199	5346	Economy	14400.00
0005435615236	5346	Economy	14400.00
0005435319606	5346	Economy	14400.00
0005435615333	5346	Economy	14400.00
0005435615321	5346	Economy	14400.00
0005435615316	5346	Economy	14400.00
0005435615253	5346	Economy	14400.00
0005434344745	5346	Economy	14400.00
0005434245089	5346	Economy	14400.00
0005435425324	5346	Economy	14400.00
0005434344719	5346	Economy	14400.00
0005435615324	5346	Economy	14400.00
0005435425023	5346	Economy	14400.00
0005434245159	5346	Economy	14400.00
0005435615234	5346	Economy	14400.00
0005435425532	5346	Economy	14400.00
0005435615270	5346	Economy	14400.00
0005434344723	5346	Economy	14400.00
0005435425053	5346	Economy	14400.00
0005433719135	5346	Economy	14400.00
0005435425460	5346	Economy	14400.00
0005435305021	5346	Economy	14400.00
0005434573555	5346	Economy	14400.00
0005435615275	5346	Economy	14400.00
0005435615260	5346	Economy	14400.00
0005434344733	5346	Economy	14400.00
0005432133421	5346	Economy	14400.00
0005435615248	5346	Economy	14400.00
0005434573554	5346	Economy	14400.00
0005432841025	5346	Economy	14400.00
0005435615305	5346	Economy	14400.00
0005434245050	5346	Economy	14400.00
0005435425274	5346	Economy	14400.00
0005434344714	5346	Economy	14400.00
0005435097350	5346	Economy	14400.00
0005435425176	5346	Economy	14400.00
0005435615278	5346	Economy	14400.00
0005435615297	5346	Economy	14400.00
0005435615231	5346	Economy	14400.00
0005435615222	5346	Economy	14400.00
0005435615264	5346	Economy	14400.00
0005435615255	5346	Economy	14400.00
0005435615237	5346	Economy	14400.00
0005435615259	5346	Economy	14400.00
0005435615242	5346	Economy	14400.00
0005435615323	5346	Economy	14400.00
0005435555400	5346	Economy	14400.00
0005434245023	5346	Economy	14400.00
0005434245160	5346	Economy	14400.00
0005435042867	5346	Economy	14400.00
0005434344720	5346	Economy	14400.00
0005434344722	5346	Economy	14400.00
0005435425469	5346	Economy	14400.00
0005434245151	5346	Economy	14400.00
0005434344713	5346	Economy	15800.00
0005435615296	5346	Economy	15800.00
0005434344717	5346	Economy	14400.00
0005434245054	5346	Economy	15800.00
0005435615328	5346	Economy	14400.00
0005434344729	5346	Economy	15800.00
0005435615290	5346	Economy	15800.00
0005435305022	5346	Economy	14400.00
0005434344736	5346	Economy	14400.00
0005435615344	5346	Economy	14400.00
0005435615326	5346	Economy	14400.00
0005435319603	5346	Economy	14400.00
0005435615283	5346	Economy	14400.00
0005432133423	5346	Economy	14400.00
0005435425609	5346	Economy	14400.00
0005434573562	5346	Economy	14400.00
0005435425328	5346	Economy	14400.00
0005434573550	5346	Economy	14400.00
0005434245078	5346	Economy	14400.00
0005435615303	5346	Economy	14400.00
0005435617236	5346	Economy	14400.00
0005435425533	5346	Economy	14400.00
0005432133425	5346	Economy	14400.00
0005435615258	5346	Economy	14400.00
0005435615282	5346	Economy	14400.00
0005434344730	5346	Economy	14400.00
0005434344734	5346	Economy	14400.00
0005435615219	5346	Economy	14400.00
0005435042858	5346	Economy	14400.00
0005435615261	5346	Economy	14400.00
0005435615232	5346	Economy	14400.00
0005435615228	5346	Economy	14400.00
0005432133429	5346	Economy	14400.00
0005432133430	5346	Economy	14400.00
0005435425380	5346	Economy	14400.00
0005434344732	5346	Economy	14400.00
0005435425542	5346	Economy	14400.00
0005435615266	5346	Economy	14400.00
0005434344737	5346	Economy	14400.00
0005435380314	5346	Economy	14400.00
0005435425166	5346	Economy	14400.00
0005435615306	5346	Economy	14400.00
0005435615331	5346	Economy	14400.00
0005435490282	5346	Economy	14400.00
0005435615289	5346	Economy	14400.00
0005432133428	5346	Economy	14400.00
0005435425333	5346	Economy	14400.00
0005434573561	5346	Economy	14400.00
0005435615224	5346	Economy	14400.00
0005435615227	5346	Economy	14400.00
0005435615320	5346	Economy	14400.00
0005434344735	5346	Economy	14400.00
0005435615338	5346	Economy	14400.00
0005434573560	5346	Economy	14400.00
0005434344740	5346	Economy	14400.00
0005435615285	5346	Economy	14400.00
0005435380311	5346	Economy	14400.00
0005435097352	5346	Economy	14400.00
0005435615268	5346	Economy	14400.00
0005433719146	5346	Economy	14400.00
0005435491469	5346	Economy	14400.00
0005432133433	5346	Economy	14400.00
0005435425414	5346	Economy	14400.00
0005435097346	5346	Economy	14400.00
0005434344746	5346	Economy	14400.00
0005435615325	5346	Economy	14400.00
0005434344741	5346	Economy	14400.00
0005434344721	5346	Economy	14400.00
0005434245142	5346	Economy	14400.00
0005435615239	5346	Economy	14400.00
0005435425156	5346	Economy	14400.00
0005434573559	5346	Economy	14400.00
0005435615249	5346	Economy	14400.00
0005435615277	5346	Economy	14400.00
0005434245131	5346	Economy	14400.00
0005435425277	5346	Economy	14400.00
0005435615281	5346	Economy	14400.00
0005435615294	5346	Economy	14400.00
0005434573558	5346	Economy	14400.00
0005432133427	5346	Economy	14400.00
0005435615302	5346	Economy	14400.00
0005433719166	5346	Economy	14400.00
0005434245121	5346	Economy	14400.00
0005433719154	5346	Economy	14400.00
0005435615288	5346	Economy	14400.00
0005435615269	5346	Economy	14400.00
0005435615254	5346	Economy	14400.00
0005435615250	5346	Economy	14400.00
0005435097348	5346	Economy	14400.00
0005435097344	5346	Economy	14400.00
0005435615292	5346	Economy	14400.00
0005435615235	5346	Economy	14400.00
0005435615336	5346	Economy	14400.00
0005435617175	5346	Economy	14400.00
0005435615293	5346	Economy	14400.00
0005435615246	5346	Economy	14400.00
0005434344727	5346	Economy	14400.00
0005435615267	5346	Economy	14400.00
0005435615286	5346	Economy	14400.00
0005435425063	5346	Economy	14400.00
0005435615317	5346	Economy	15800.00
0005434344728	5346	Economy	14400.00
0005435425412	5346	Economy	15800.00
0005435615280	5346	Economy	15800.00
0005435425064	5346	Economy	15800.00
0005435425413	5346	Economy	15800.00
0005435615240	5346	Economy	14400.00
0005435615314	5346	Economy	14400.00
0005435425536	5346	Economy	14400.00
0005435615272	5346	Economy	14400.00
0005435615287	5346	Economy	14400.00
0005435615243	5346	Economy	14400.00
0005435425535	5346	Economy	14400.00
0005435555399	5346	Economy	14400.00
0005435425323	5346	Economy	14400.00
0005435097343	5346	Economy	14400.00
0005435425273	5346	Economy	14400.00
0005435615330	5346	Economy	14400.00
0005434656571	5346	Economy	14400.00
0005435615299	5346	Economy	14400.00
0005432133432	5346	Economy	14400.00
0005435615334	5346	Economy	14400.00
0005435615284	5346	Economy	14400.00
0005435615265	5346	Economy	14400.00
0005434245153	5346	Economy	14400.00
0005432133426	5346	Economy	14400.00
0005435425238	5346	Economy	14400.00
0005435097345	5346	Economy	14400.00
0005435615226	5346	Economy	14400.00
0005435425307	5346	Economy	14400.00
0005433719163	5346	Economy	14400.00
0005435424939	5346	Economy	14400.00
0005435615345	5346	Economy	14400.00
0005435425052	5346	Economy	14400.00
0005434344718	5346	Economy	14400.00
0005435425384	5346	Economy	14400.00
0005435615274	5346	Economy	14400.00
0005435615251	5346	Economy	14400.00
0005434245026	5346	Economy	14400.00
0005435490279	5346	Economy	14400.00
0005435615271	5346	Economy	14400.00
0005435425383	5346	Economy	14400.00
0005435615313	5346	Economy	14400.00
0005435615300	5346	Economy	14400.00
0005435615343	5346	Economy	14400.00
0005435425271	5346	Economy	14400.00
0005435617237	5346	Economy	14400.00
0005434573563	5346	Economy	14400.00
0005435615279	5346	Economy	14400.00
0005435425079	5346	Economy	14400.00
0005435425378	5346	Economy	14400.00
0005435425153	5346	Economy	14400.00
0005433719143	5346	Economy	14400.00
0005435425158	5346	Economy	14400.00
0005434573557	5346	Economy	14400.00
0005435615257	5346	Economy	14400.00
0005434245130	5346	Economy	14400.00
0005435615304	5346	Economy	14400.00
0005435615337	5346	Economy	14400.00
0005434344743	5346	Economy	14400.00
0005435615310	5346	Economy	14400.00
0005435615329	5346	Economy	14400.00
0005434573551	5346	Economy	14400.00
0005435425167	5346	Economy	14400.00
0005435425334	5346	Economy	14400.00
0005435425094	5346	Economy	14400.00
0005435425608	5346	Economy	14400.00
0005435319618	5346	Economy	14400.00
0005435615339	5346	Economy	14400.00
0005435615223	5346	Economy	14400.00
0005435615225	5346	Economy	14400.00
0005435615291	5346	Economy	14400.00
0005434344731	5346	Economy	14400.00
0005435615241	5346	Economy	14400.00
0005435615307	5346	Economy	14400.00
0005435615256	5346	Economy	14400.00
0005432047605	5346	Economy	14400.00
0005432133435	5346	Economy	14400.00
0005435615312	5346	Economy	14400.00
0005432047604	5346	Economy	14400.00
0005435425058	5346	Economy	14400.00
0005434344724	5346	Economy	14400.00
0005434344716	5346	Economy	14400.00
0005435425226	5346	Economy	14400.00
0005432047602	5346	Economy	14400.00
0005435615340	5346	Economy	14400.00
0005435425200	5346	Economy	14400.00
0005435615311	5346	Economy	14400.00
0005435615230	5346	Economy	14400.00
0005435615252	5346	Economy	14400.00
0005434344712	5346	Economy	14400.00
0005435615309	5346	Economy	14400.00
0005432133422	5346	Economy	14400.00
0005435319626	5346	Economy	14400.00
0005434573553	5346	Economy	14400.00
0005435425237	5346	Economy	14400.00
0005435615308	5346	Economy	14400.00
0005432047603	5346	Economy	14400.00
0005435425351	5346	Economy	14400.00
0005435615301	5346	Economy	14400.00
0005434344739	5346	Economy	14400.00
0005432133434	5346	Economy	14400.00
0005435490281	5346	Economy	14400.00
0005432133424	5346	Economy	14400.00
0005434344711	5346	Economy	14400.00
0005435615229	5346	Economy	14400.00
0005435614462	10927	Business	43100.00
0005435425807	10927	Business	43100.00
0005435425783	10927	Business	43100.00
0005433719189	10927	Business	43100.00
0005435555379	10927	Business	43100.00
0005435319705	10927	Business	43100.00
0005435614293	10927	Business	43100.00
0005435425781	10927	Business	43100.00
0005435614329	10927	Business	43100.00
0005434656585	10927	Business	43100.00
0005435614362	10927	Business	43100.00
0005435425800	10927	Business	43100.00
0005435319701	10927	Business	43100.00
0005432165149	10927	Business	43100.00
0005435614352	10927	Business	43100.00
0005434245390	10927	Business	43100.00
0005435613898	10927	Business	43100.00
0005435555380	10927	Business	43100.00
0005435425824	10927	Business	43100.00
0005434344376	10927	Business	43100.00
0005432363465	10927	Business	43100.00
0005435613912	10927	Business	43100.00
0005435097266	10927	Business	43100.00
0005434245411	10927	Comfort	24400.00
0005435614586	10927	Comfort	24400.00
0005435614452	10927	Comfort	24400.00
0005434573356	10927	Comfort	24400.00
0005435613913	10927	Comfort	24400.00
0005435614092	10927	Comfort	24400.00
0005435425802	10927	Comfort	24400.00
0005435425808	10927	Comfort	24400.00
0005435380361	10927	Comfort	24400.00
0005434344486	10927	Comfort	24400.00
0005435613911	10927	Comfort	24400.00
0005435425805	10927	Comfort	24400.00
0005435614001	10927	Comfort	24400.00
0005435614080	10927	Comfort	24400.00
0005435614246	10927	Comfort	24400.00
0005435490236	10927	Comfort	24400.00
0005435425788	10927	Comfort	24400.00
0005435425792	10927	Comfort	24400.00
0005435490234	10927	Comfort	24400.00
0005435425822	10927	Comfort	24400.00
0005434344307	10927	Comfort	24400.00
0005435380358	10927	Comfort	24400.00
0005435614516	10927	Comfort	24400.00
0005435614168	10927	Comfort	24400.00
0005435613817	10927	Comfort	24400.00
0005432165145	10927	Comfort	24400.00
0005435425823	10927	Comfort	24400.00
0005435425801	10927	Comfort	24400.00
0005435614384	10927	Comfort	24400.00
0005434245410	10927	Comfort	24400.00
0005435613916	10927	Comfort	24400.00
0005435425809	10927	Comfort	24400.00
0005435614599	10927	Comfort	24400.00
0005435613599	10927	Comfort	24400.00
0005435425799	10927	Comfort	24400.00
0005435614144	10927	Comfort	24400.00
0005434245403	10927	Comfort	24400.00
0005434344458	10927	Comfort	24400.00
0005435304219	10927	Comfort	24400.00
0005434344211	10927	Comfort	24400.00
0005432363462	10927	Comfort	24400.00
0005435319702	10927	Comfort	24400.00
0005435425825	10927	Economy	14400.00
0005434344436	10927	Economy	14400.00
0005434344379	10927	Economy	14400.00
0005435425780	10927	Economy	14400.00
0005435614155	10927	Economy	14400.00
0005435097255	10927	Economy	14400.00
0005435614104	10927	Economy	14400.00
0005435425803	10927	Economy	14400.00
0005435425821	10927	Economy	14400.00
0005434656584	10927	Economy	14400.00
0005432166948	10927	Economy	14400.00
0005435614000	10927	Economy	14400.00
0005435614375	10927	Economy	14400.00
0005434344212	10927	Economy	14400.00
0005432363464	10927	Economy	14400.00
0005435614424	10927	Economy	14400.00
0005435614550	10927	Economy	14400.00
0005434573378	10927	Economy	14400.00
0005435490264	10927	Economy	14400.00
0005435614038	10927	Economy	14400.00
0005435613802	10927	Economy	14400.00
0005435097215	10927	Economy	14400.00
0005435097241	10927	Economy	14400.00
0005435425811	10927	Economy	14400.00
0005435319696	10927	Economy	14400.00
0005434573355	10927	Economy	14400.00
0005432165152	10927	Economy	14400.00
0005432165146	10927	Economy	14400.00
0005435425818	10927	Economy	14400.00
0005435425814	10927	Economy	14400.00
0005435614292	10927	Economy	14400.00
0005435614598	10927	Economy	14400.00
0005435614045	10927	Economy	14400.00
0005432841044	10927	Economy	14400.00
0005435614358	10927	Economy	14400.00
0005435614470	10927	Economy	14400.00
0005434344511	10927	Economy	14400.00
0005435425830	10927	Economy	14400.00
0005432165150	10927	Economy	14400.00
0005434344169	10927	Economy	14400.00
0005434573398	10927	Economy	14400.00
0005435614081	10927	Economy	14400.00
0005435614460	10927	Economy	14400.00
0005435490259	10927	Economy	14400.00
0005434573402	10927	Economy	14400.00
0005434245396	10927	Economy	14400.00
0005434245391	10927	Economy	14400.00
0005435425804	10927	Economy	14400.00
0005434245405	10927	Economy	14400.00
0005434573388	10927	Economy	14400.00
0005435425766	10927	Economy	14400.00
0005435613600	10927	Economy	14400.00
0005435614359	10927	Economy	14400.00
0005432363463	10927	Economy	14400.00
0005434344321	10927	Economy	14400.00
0005434344378	10927	Economy	15800.00
0005434245408	10927	Economy	14400.00
0005435614145	10927	Economy	15800.00
0005435614374	10927	Economy	15800.00
0005435491448	10927	Economy	14400.00
0005435614474	10927	Economy	14400.00
0005435425829	10927	Economy	14400.00
0005435380359	10927	Economy	15800.00
0005435425795	10927	Economy	14400.00
0005435425806	10927	Economy	15800.00
0005435613982	10927	Economy	14400.00
0005435614053	10927	Economy	14400.00
0005434573390	10927	Economy	14400.00
0005435613906	10927	Economy	14400.00
0005434245409	10927	Economy	14400.00
0005434245395	10927	Economy	14400.00
0005434245414	10927	Economy	14400.00
0005435614347	10927	Economy	14400.00
0005435614076	10927	Economy	14400.00
0005435097227	10927	Economy	14400.00
0005434344358	10927	Economy	14400.00
0005432166947	10927	Economy	14400.00
0005434573367	10927	Economy	14400.00
0005435425796	10927	Economy	14400.00
0005435614010	10927	Economy	14400.00
0005435614320	10927	Economy	14400.00
0005435425774	10927	Economy	14400.00
0005435425778	10927	Economy	14400.00
0005435425789	10927	Economy	14400.00
0005435305042	10927	Economy	14400.00
0005435425798	10927	Economy	14400.00
0005435490235	10927	Economy	14400.00
0005435304222	10927	Economy	14400.00
0005434245417	10927	Economy	14400.00
0005435491444	10927	Economy	14400.00
0005434245404	10927	Economy	14400.00
0005435425767	10927	Economy	14400.00
0005435319697	10927	Economy	14400.00
0005435614291	10927	Economy	14400.00
0005435319703	10927	Economy	14400.00
0005435425776	10927	Economy	14400.00
0005435614540	10927	Economy	14400.00
0005435425797	10927	Economy	14400.00
0005435614658	10927	Economy	14400.00
0005435614321	10927	Economy	14400.00
0005435425817	10927	Economy	14400.00
0005434573407	10927	Economy	14400.00
0005435425816	10927	Economy	14400.00
0005435425810	10927	Economy	14400.00
0005435613787	10927	Economy	14400.00
0005435614039	10927	Economy	14400.00
0005435490237	10927	Economy	14400.00
0005435614432	10927	Economy	14400.00
0005435613818	10927	Economy	14400.00
0005435614287	10927	Economy	14400.00
0005435425765	10927	Economy	14400.00
0005435614178	10927	Economy	14400.00
0005435380362	10927	Economy	14400.00
0005435614588	10927	Economy	14400.00
0005435425785	10927	Economy	14400.00
0005435304220	10927	Economy	14400.00
0005435425782	10927	Economy	14400.00
0005435614428	10927	Economy	14400.00
0005435425828	10927	Economy	14400.00
0005435425794	10927	Economy	14400.00
0005435614257	10927	Economy	14400.00
0005435425812	10927	Economy	14400.00
0005435614606	10927	Economy	14400.00
0005435614361	10927	Economy	14400.00
0005435614492	10927	Economy	14400.00
0005434344245	10927	Economy	14400.00
0005434344354	10927	Economy	14400.00
0005434573377	10927	Economy	14400.00
0005435614638	10927	Economy	14400.00
0005435425769	10927	Economy	14400.00
0005435425772	10927	Economy	14400.00
0005434245387	10927	Economy	14400.00
0005435614425	10927	Economy	14400.00
0005434573415	10927	Economy	14400.00
0005435614077	10927	Economy	14400.00
0005435614187	10927	Economy	14400.00
0005434573403	10927	Economy	14400.00
0005435614238	10927	Economy	14400.00
0005435613965	10927	Economy	14400.00
0005434344271	10927	Economy	14400.00
0005434573434	10927	Economy	14400.00
0005435425763	10927	Economy	14400.00
0005435319700	10927	Economy	14400.00
0005434344435	10927	Economy	14400.00
0005435614480	10927	Economy	14400.00
0005435425770	10927	Economy	14400.00
0005435305041	10927	Economy	14400.00
0005434573423	10927	Economy	14400.00
0005435614517	10927	Economy	14400.00
0005434245398	10927	Economy	14400.00
0005435614011	10927	Economy	14400.00
0005432165147	10927	Economy	14400.00
0005435614360	10927	Economy	14400.00
0005434245402	10927	Economy	14400.00
0005435097234	10927	Economy	14400.00
0005435097242	10927	Economy	14400.00
0005435614491	10927	Economy	14400.00
0005435425786	10927	Economy	14400.00
0005433719191	10927	Economy	14400.00
0005435614511	10927	Economy	14400.00
0005433719190	10927	Economy	15800.00
0005435425787	10927	Economy	15800.00
0005435380360	10927	Economy	15800.00
0005435613601	10927	Economy	15800.00
0005435613981	10927	Economy	14400.00
0005434245412	10927	Economy	14400.00
0005434344239	10927	Economy	14400.00
0005435425813	10927	Economy	14400.00
0005435097214	10927	Economy	14400.00
0005435614633	10927	Economy	14400.00
0005435555384	10927	Economy	14400.00
0005434245392	10927	Economy	14400.00
0005435425826	10927	Economy	14400.00
0005435425791	10927	Economy	14400.00
0005434245400	10927	Economy	14400.00
0005435425762	10927	Economy	14400.00
0005434573405	10927	Economy	14400.00
0005435614481	10927	Economy	14400.00
0005434245388	10927	Economy	14400.00
0005435490248	10927	Economy	14400.00
0005434245399	10927	Economy	14400.00
0005435614142	10927	Economy	14400.00
0005435097230	10927	Economy	14400.00
0005435425827	10927	Economy	14400.00
0005435614363	10927	Economy	14400.00
0005435614322	10927	Economy	14400.00
0005435614289	10927	Economy	14400.00
0005435425790	10927	Economy	14400.00
0005435425779	10927	Economy	14400.00
0005435614169	10927	Economy	14400.00
0005434573406	10927	Economy	14400.00
0005435614255	10927	Economy	14400.00
0005435614044	10927	Economy	14400.00
0005435555381	10927	Economy	14400.00
0005434344481	10927	Economy	14400.00
0005435425764	10927	Economy	14400.00
0005435614135	10927	Economy	14400.00
0005434245416	10927	Economy	14400.00
0005435425784	10927	Economy	14400.00
0005435304221	10927	Economy	14400.00
0005434573448	10927	Economy	14400.00
0005434245397	10927	Economy	14400.00
0005434245413	10927	Economy	14400.00
0005435614308	10927	Economy	14400.00
0005434344272	10927	Economy	14400.00
0005435614351	10927	Economy	14400.00
0005434245401	10927	Economy	14400.00
0005435614589	10927	Economy	14400.00
0005435614357	10927	Economy	14400.00
0005435425815	10927	Economy	14400.00
0005435614442	10927	Economy	14400.00
0005435614319	10927	Economy	14400.00
0005434656586	10927	Economy	14400.00
0005434245394	10927	Economy	14400.00
0005434245406	10927	Economy	14400.00
0005434245389	10927	Economy	14400.00
0005432165151	10927	Economy	14400.00
0005435425793	10927	Economy	14400.00
0005435555383	10927	Economy	14400.00
0005435614301	10927	Economy	14400.00
0005435614353	10927	Economy	14400.00
0005435614600	10927	Economy	14400.00
0005432166949	10927	Economy	14400.00
0005435614318	10927	Economy	14400.00
0005435614525	10927	Economy	14400.00
0005435304218	10927	Economy	14400.00
0005435425775	10927	Economy	14400.00
0005434344352	10927	Economy	14400.00
0005435425761	10927	Economy	14400.00
0005434573363	10927	Economy	14400.00
0005434344377	10927	Economy	14400.00
0005434344326	10927	Economy	14400.00
0005434245407	10927	Economy	14400.00
0005435425773	10927	Economy	14400.00
0005435613792	10927	Economy	14400.00
0005435425820	10927	Economy	14400.00
0005435425819	10927	Economy	14400.00
0005434344325	10927	Economy	14400.00
0005435319704	10927	Economy	14400.00
0005435614632	10927	Economy	14400.00
0005435614188	10927	Economy	14400.00
0005435614264	10927	Economy	14400.00
0005432841043	10927	Economy	14400.00
0005435425771	10927	Economy	14400.00
0005432165148	10927	Economy	14400.00
0005434344423	10927	Economy	14400.00
0005435614028	10927	Economy	14400.00
0005435614214	10927	Economy	14400.00
0005432165144	10927	Economy	14400.00
0005434245415	10927	Economy	14400.00
0005435614213	10927	Economy	14400.00
0005435319698	10927	Economy	14400.00
0005435425777	10927	Economy	14400.00
0005435425768	10927	Economy	14400.00
0005434245393	10927	Economy	14400.00
0005435319699	10927	Economy	14400.00
0005435490249	10927	Economy	14400.00
0005435613799	10927	Economy	14400.00
0005432460266	3273	Business	18800.00
0005433805868	3273	Business	18800.00
0005432182028	3273	Business	18800.00
0005432460193	3273	Business	18800.00
0005432460138	3273	Business	18800.00
0005433805873	3273	Business	18800.00
0005432459991	3273	Business	18800.00
0005433507437	3273	Business	18800.00
0005432459928	3273	Business	18800.00
0005432182034	3273	Business	18800.00
0005433634317	3273	Business	18800.00
0005433634308	3273	Business	18800.00
0005433634310	3273	Business	18800.00
0005433805856	3273	Business	18800.00
0005433634322	3273	Business	18800.00
0005432460232	3273	Business	18800.00
0005433805878	3273	Business	18800.00
0005432460096	3273	Business	18800.00
0005433507436	3273	Business	18800.00
0005433634296	3273	Business	18800.00
0005433634299	3273	Business	18800.00
0005432460134	3273	Business	18800.00
0005432182040	3273	Business	18800.00
0005433805864	3273	Business	18800.00
0005432460061	3273	Business	18800.00
0005433634307	3273	Economy	6900.00
0005432460001	3273	Economy	6900.00
0005432460035	3273	Economy	6900.00
0005432460123	3273	Economy	6900.00
0005433634316	3273	Economy	6900.00
0005433805848	3273	Economy	6300.00
0005433507435	3273	Economy	6300.00
0005433507430	3273	Economy	6300.00
0005432459840	3273	Economy	6300.00
0005432460315	3273	Economy	6300.00
0005432460227	3273	Economy	6300.00
0005433507438	3273	Economy	6300.00
0005432459857	3273	Economy	6300.00
0005433507441	3273	Economy	6300.00
0005433634319	3273	Economy	6300.00
0005432460246	3273	Economy	6300.00
0005433634303	3273	Economy	6300.00
0005432460322	3273	Economy	6300.00
0005432182045	3273	Economy	6300.00
0005432182041	3273	Economy	6300.00
0005433634315	3273	Economy	6300.00
0005432460100	3273	Economy	6300.00
0005433634314	3273	Economy	6300.00
0005433805871	3273	Economy	6300.00
0005433634302	3273	Economy	6300.00
0005433634325	3273	Economy	6300.00
0005432460026	3273	Economy	6300.00
0005432460090	3273	Economy	6300.00
0005433634327	3273	Economy	6300.00
0005433634328	3273	Economy	6300.00
0005433805867	3273	Economy	6300.00
0005432182036	3273	Economy	6300.00
0005432460112	3273	Economy	6300.00
0005432182044	3273	Economy	6300.00
0005432182046	3273	Economy	6300.00
0005433507431	3273	Economy	6300.00
0005432182038	3273	Economy	6300.00
0005432460075	3273	Economy	6300.00
0005433634330	3273	Economy	6300.00
0005433507442	3273	Economy	6300.00
0005432460113	3273	Economy	6300.00
0005432182032	3273	Economy	6300.00
0005432182027	3273	Economy	6300.00
0005433634318	3273	Economy	6300.00
0005433634301	3273	Economy	6300.00
0005432460077	3273	Economy	6300.00
0005432460076	3273	Economy	6300.00
0005433805862	3273	Economy	6300.00
0005432460145	3273	Economy	6300.00
0005432459953	3273	Economy	6300.00
0005432182048	3273	Economy	6300.00
0005432460170	3273	Economy	6300.00
0005432460314	3273	Economy	6300.00
0005433507440	3273	Economy	6300.00
0005432460124	3273	Economy	6300.00
0005433805847	3273	Economy	6300.00
0005433805851	3273	Economy	6300.00
0005432460097	3273	Economy	6300.00
0005432460267	3273	Economy	6300.00
0005433805849	3273	Economy	6300.00
0005432182042	3273	Economy	6300.00
0005433805861	3273	Economy	6300.00
0005433634295	3273	Economy	6300.00
0005433805866	3273	Economy	6300.00
0005433805877	3273	Economy	6300.00
0005433507434	3273	Economy	6900.00
0005433805854	3273	Economy	6900.00
0005433805860	3273	Economy	6900.00
0005433805869	3273	Economy	6900.00
0005432460099	3273	Economy	6900.00
0005433634320	3273	Economy	6300.00
0005432460074	3273	Economy	6300.00
0005432182047	3273	Economy	6300.00
0005432182035	3273	Economy	6300.00
0005433805863	3273	Economy	6900.00
0005433805857	3273	Economy	6300.00
0005433805865	3273	Economy	6300.00
0005433805876	3273	Economy	6300.00
0005432460137	3273	Economy	6300.00
0005432460114	3273	Economy	6300.00
0005433634298	3273	Economy	6300.00
0005433507432	3273	Economy	6300.00
0005433805858	3273	Economy	6300.00
0005433507433	3273	Economy	6300.00
0005433507439	3273	Economy	6300.00
0005433805853	3273	Economy	6300.00
0005433805870	3273	Economy	6300.00
0005432460172	3273	Economy	6300.00
0005433805874	3273	Economy	6300.00
0005433634313	3273	Economy	6300.00
0005433634324	3273	Economy	6300.00
0005433805850	3273	Economy	6300.00
0005432460302	3273	Economy	6300.00
0005432459909	3273	Economy	6300.00
0005432459990	3273	Economy	6300.00
0005433634329	3273	Economy	6300.00
0005433805859	3273	Economy	6300.00
0005433634311	3273	Economy	6300.00
0005433805875	3273	Economy	6300.00
0005432460115	3273	Economy	6300.00
0005433805855	3273	Economy	6300.00
0005433805879	3273	Economy	6300.00
0005432460321	3273	Economy	6300.00
0005432182029	3273	Economy	6300.00
0005432182037	3273	Economy	6300.00
0005433634309	3273	Economy	6300.00
0005432460111	3273	Economy	6300.00
0005433634297	3273	Economy	6300.00
0005432460101	3273	Economy	6300.00
0005433634321	3273	Economy	6300.00
0005432460027	3273	Economy	6300.00
0005432182039	3273	Economy	6300.00
0005432460073	3273	Economy	6300.00
0005432460287	3273	Economy	6300.00
0005433634300	3273	Economy	6300.00
0005433634323	3273	Economy	6300.00
0005433805872	3273	Economy	6300.00
0005432460147	3273	Economy	6300.00
0005432460062	3273	Economy	6300.00
0005433634326	3273	Economy	6300.00
0005433634305	3273	Economy	6300.00
0005432459952	3273	Economy	6300.00
0005432460095	3273	Economy	6300.00
0005433634312	3273	Economy	6300.00
0005432182033	3273	Economy	6300.00
0005432182043	3273	Economy	6300.00
0005433805852	3273	Economy	6300.00
0005432460066	3273	Economy	6300.00
0005432460301	3273	Economy	6300.00
0005432460271	3273	Economy	6300.00
0005432182030	3273	Economy	6300.00
0005432460146	3273	Economy	6300.00
0005432460320	3273	Economy	6300.00
0005433634304	3273	Economy	6300.00
0005433634306	3273	Economy	6300.00
0005432182031	3273	Economy	6300.00
0005435885478	3274	Business	18800.00
0005435885872	3274	Business	18800.00
0005435885464	3274	Business	18800.00
0005435885531	3274	Business	18800.00
0005435885696	3274	Business	18800.00
0005435885597	3274	Business	18800.00
0005435885567	3274	Business	18800.00
0005435885506	3274	Business	18800.00
0005435885776	3274	Economy	6900.00
0005435885553	3274	Economy	6300.00
0005435885686	3274	Economy	6300.00
0005435885537	3274	Economy	6300.00
0005435885505	3274	Economy	6300.00
0005435885654	3274	Economy	6300.00
0005435885641	3274	Economy	6300.00
0005435885470	3274	Economy	6300.00
0005435885766	3274	Economy	6300.00
0005435885767	3274	Economy	6300.00
0005435885710	3274	Economy	6300.00
0005435885750	3274	Economy	6300.00
0005435885752	3274	Economy	6300.00
0005435885592	3274	Economy	6300.00
0005435885568	3274	Economy	6300.00
0005435885530	3274	Economy	6300.00
0005435885589	3274	Economy	6300.00
0005435885513	3274	Economy	6300.00
0005435885804	3274	Economy	6300.00
0005435885644	3274	Economy	6300.00
0005435885650	3274	Economy	6300.00
0005435885746	3274	Economy	6300.00
0005435885455	3274	Economy	6900.00
0005435885653	3274	Economy	6900.00
0005435885649	3274	Economy	6300.00
0005435885598	3274	Economy	6300.00
0005435885748	3274	Economy	6300.00
0005435885655	3274	Economy	6300.00
0005435885871	3274	Economy	6300.00
0005435885586	3274	Economy	6300.00
0005435885732	3274	Economy	6300.00
0005435885768	3274	Economy	6300.00
0005435885747	3274	Economy	6300.00
0005435885645	3274	Economy	6300.00
0005435885805	3274	Economy	6300.00
0005435885785	3274	Economy	6300.00
0005435885515	3274	Economy	6300.00
0005435885504	3274	Economy	6300.00
0005435885709	3274	Economy	6300.00
0005435885412	3274	Economy	6300.00
0005435885532	3274	Economy	6300.00
0005435885745	3274	Economy	6300.00
0005435885507	3274	Economy	6300.00
0005435885522	3274	Economy	6300.00
0005435885738	3274	Economy	6300.00
0005435885593	3274	Economy	6300.00
0005435885775	3274	Economy	6300.00
0005433507243	8254	Business	18800.00
0005432460618	8254	Business	18800.00
0005432460632	8254	Business	18800.00
0005435885946	8254	Business	18800.00
0005432460619	8254	Business	18800.00
0005435885972	8254	Business	18800.00
0005435885968	8254	Business	18800.00
0005435885948	8254	Business	18800.00
0005432042914	8254	Business	18800.00
0005432042922	8254	Business	18800.00
0005435885967	8254	Business	18800.00
0005435885970	8254	Business	18800.00
0005432460640	8254	Business	18800.00
0005432042916	8254	Business	18800.00
0005433507220	8254	Business	18800.00
0005435885942	8254	Business	18800.00
0005435885935	8254	Business	18800.00
0005432460664	8254	Business	18800.00
0005435885949	8254	Business	18800.00
0005432460613	8254	Business	18800.00
0005432460635	8254	Business	18800.00
0005432042913	8254	Business	18800.00
0005432460650	8254	Business	18800.00
0005432460637	8254	Business	18800.00
0005435885956	8254	Business	18800.00
0005432460623	8254	Economy	6900.00
0005432042910	8254	Economy	6900.00
0005432460624	8254	Economy	6900.00
0005433507191	8254	Economy	6900.00
0005432460646	8254	Economy	6900.00
0005432460641	8254	Economy	6300.00
0005432460642	8254	Economy	6300.00
0005432460644	8254	Economy	6300.00
0005432460636	8254	Economy	6300.00
0005435885971	8254	Economy	6300.00
0005432460634	8254	Economy	6300.00
0005433507278	8254	Economy	6300.00
0005432460660	8254	Economy	6300.00
0005435885938	8254	Economy	6300.00
0005432460617	8254	Economy	6300.00
0005435885958	8254	Economy	6300.00
0005434312351	8254	Economy	6300.00
0005433507300	8254	Economy	6300.00
0005433507259	8254	Economy	6300.00
0005435885966	8254	Economy	6300.00
0005432460647	8254	Economy	6300.00
0005435885973	8254	Economy	6300.00
0005432460638	8254	Economy	6300.00
0005432460659	8254	Economy	6300.00
0005433507283	8254	Economy	6300.00
0005432460648	8254	Economy	6300.00
0005432042920	8254	Economy	6300.00
0005432460622	8254	Economy	6300.00
0005432460639	8254	Economy	6300.00
0005432042921	8254	Economy	6300.00
0005435885959	8254	Economy	6300.00
0005433507295	8254	Economy	6300.00
0005435885965	8254	Economy	6300.00
0005435885933	8254	Economy	6300.00
0005433507282	8254	Economy	6300.00
0005433507261	8254	Economy	6300.00
0005432460616	8254	Economy	6300.00
0005432460629	8254	Economy	6300.00
0005432042918	8254	Economy	6300.00
0005433507301	8254	Economy	6300.00
0005433507260	8254	Economy	6300.00
0005432042909	8254	Economy	6300.00
0005432460628	8254	Economy	6300.00
0005433507279	8254	Economy	6300.00
0005435885937	8254	Economy	6300.00
0005433507266	8254	Economy	6300.00
0005432460626	8254	Economy	6300.00
0005432042919	8254	Economy	6300.00
0005435885951	8254	Economy	6300.00
0005435885953	8254	Economy	6300.00
0005432460645	8254	Economy	6300.00
0005435885969	8254	Economy	6300.00
0005433507277	8254	Economy	6300.00
0005435885931	8254	Economy	6300.00
0005435885930	8254	Economy	6300.00
0005432460653	8254	Economy	6300.00
0005432460652	8254	Economy	6300.00
0005432042917	8254	Economy	6900.00
0005432460649	8254	Economy	6900.00
0005433507161	8254	Economy	6900.00
0005432460643	8254	Economy	6900.00
0005432460630	8254	Economy	6300.00
0005433507304	8254	Economy	6300.00
0005432460614	8254	Economy	6300.00
0005435885961	8254	Economy	6900.00
0005435885952	8254	Economy	6300.00
0005435885941	8254	Economy	6300.00
0005432460612	8254	Economy	6300.00
0005432460654	8254	Economy	6300.00
0005433507240	8254	Economy	6300.00
0005435885957	8254	Economy	6300.00
0005435885943	8254	Economy	6300.00
0005435885962	8254	Economy	6300.00
0005433507299	8254	Economy	6300.00
0005435885960	8254	Economy	6300.00
0005432042915	8254	Economy	6300.00
0005432460631	8254	Economy	6300.00
0005433507294	8254	Economy	6300.00
0005435885932	8254	Economy	6300.00
0005432460655	8254	Economy	6300.00
0005432460661	8254	Economy	6300.00
0005433507262	8254	Economy	6300.00
0005435885934	8254	Economy	6300.00
0005432460662	8254	Economy	6300.00
0005435885944	8254	Economy	6300.00
0005432460658	8254	Economy	6300.00
0005432460620	8254	Economy	6300.00
0005432042912	8254	Economy	6300.00
0005432460625	8254	Economy	6300.00
0005432460627	8254	Economy	6300.00
0005435885945	8254	Economy	6300.00
0005435885950	8254	Economy	6300.00
0005432460621	8254	Economy	6300.00
0005433507256	8254	Economy	6300.00
0005432042911	8254	Economy	6300.00
0005433507293	8254	Economy	6300.00
0005435885964	8254	Economy	6300.00
0005432460656	8254	Economy	6300.00
0005432460665	8254	Economy	6300.00
0005435885963	8254	Economy	6300.00
0005435885939	8254	Economy	6300.00
0005435885940	8254	Economy	6300.00
0005432460657	8254	Economy	6300.00
0005432460615	8254	Economy	6300.00
0005432460663	8254	Economy	6300.00
0005432460633	8254	Economy	6300.00
0005435885936	8254	Economy	6300.00
0005434312350	8254	Economy	6300.00
0005435885955	8254	Economy	6300.00
0005432460651	8254	Economy	6300.00
0005435885947	8254	Economy	6300.00
0005433507296	8254	Economy	6300.00
0005435885954	8254	Economy	6300.00
0005433634011	8304	Business	18800.00
0005433634048	8304	Business	18800.00
0005433633810	8304	Business	18800.00
0005433805509	8304	Business	18800.00
0005433805624	8304	Business	18800.00
0005433633866	8304	Business	18800.00
0005433633867	8304	Business	18800.00
0005433805614	8304	Business	18800.00
0005433633912	8304	Business	18800.00
0005433805470	8304	Business	18800.00
0005433805539	8304	Business	18800.00
0005433805474	8304	Business	18800.00
0005433805678	8304	Business	18800.00
0005433805611	8304	Business	18800.00
0005433634058	8304	Business	18800.00
0005433633944	8304	Economy	6900.00
0005434143736	8304	Economy	6900.00
0005433805534	8304	Economy	6900.00
0005433805655	8304	Economy	6900.00
0005433634135	8304	Economy	6900.00
0005433633773	8304	Economy	6300.00
0005434271319	8304	Economy	6300.00
0005433633994	8304	Economy	6300.00
0005433633948	8304	Economy	6300.00
0005433805657	8304	Economy	6300.00
0005433805653	8304	Economy	6300.00
0005433633949	8304	Economy	6300.00
0005434143732	8304	Economy	6300.00
0005433805527	8304	Economy	6300.00
0005433805358	8304	Economy	6300.00
0005433633998	8304	Economy	6300.00
0005433633927	8304	Economy	6300.00
0005433805584	8304	Economy	6300.00
0005433633965	8304	Economy	6300.00
0005433805620	8304	Economy	6300.00
0005433805482	8304	Economy	6300.00
0005433805410	8304	Economy	6300.00
0005434271328	8304	Economy	6300.00
0005433633964	8304	Economy	6300.00
0005433805556	8304	Economy	6300.00
0005433805518	8304	Economy	6300.00
0005433634067	8304	Economy	6300.00
0005433805599	8304	Economy	6300.00
0005433634009	8304	Economy	6300.00
0005433805533	8304	Economy	6300.00
0005433805481	8304	Economy	6300.00
0005433634059	8304	Economy	6300.00
0005433805645	8304	Economy	6300.00
0005433634042	8304	Economy	6300.00
0005433633911	8304	Economy	6300.00
0005433633784	8304	Economy	6300.00
0005433634035	8304	Economy	6300.00
0005433805564	8304	Economy	6300.00
0005433805591	8304	Economy	6300.00
0005433805473	8304	Economy	6300.00
0005433633960	8304	Economy	6300.00
0005433633999	8304	Economy	6300.00
0005433633868	8304	Economy	6300.00
0005433805656	8304	Economy	6300.00
0005433805575	8304	Economy	6300.00
0005433634136	8304	Economy	6900.00
0005434271322	8304	Economy	6900.00
0005433805526	8304	Economy	6300.00
0005433805585	8304	Economy	6300.00
0005433633978	8304	Economy	6300.00
0005433634045	8304	Economy	6300.00
0005434143725	8304	Economy	6300.00
0005433805659	8304	Economy	6300.00
0005433634010	8304	Economy	6300.00
0005433633971	8304	Economy	6300.00
0005433633919	8304	Economy	6300.00
0005433805623	8304	Economy	6300.00
0005433805644	8304	Economy	6300.00
0005433634000	8304	Economy	6300.00
0005433633972	8304	Economy	6300.00
0005434143731	8304	Economy	6300.00
0005433805519	8304	Economy	6300.00
0005433805550	8304	Economy	6300.00
0005433633993	8304	Economy	6300.00
0005433633928	8304	Economy	6300.00
0005433805520	8304	Economy	6300.00
0005433805682	8304	Economy	6300.00
0005433633865	8304	Economy	6300.00
0005433805610	8304	Economy	6300.00
0005433805621	8304	Economy	6300.00
0005433805372	8304	Economy	6300.00
0005433633774	8304	Economy	6300.00
0005433805628	8304	Economy	6300.00
0005433805677	8304	Economy	6300.00
0005433805598	8304	Economy	6300.00
0005433805619	8304	Economy	6300.00
0005434271327	8304	Economy	6300.00
0005433805615	8304	Economy	6300.00
0005433633812	8304	Economy	6300.00
0005434143726	8304	Economy	6300.00
0005433633811	8304	Economy	6300.00
0005433805573	8304	Economy	6300.00
0005433633957	8304	Economy	6300.00
0005433805683	8304	Economy	6300.00
0005434183590	8280	Business	18800.00
0005432383728	4527	Business	9900.00
0005432383737	4527	Business	9900.00
0005432383718	4527	Business	9900.00
0005432383733	4527	Business	9900.00
0005432728119	4527	Business	9900.00
0005432383720	4527	Economy	3300.00
0005433722315	4527	Economy	3300.00
0005432383716	4527	Economy	3300.00
0005433453788	4527	Economy	3300.00
0005433722314	4527	Economy	3300.00
0005432728117	4527	Economy	3300.00
0005432383740	4527	Economy	3300.00
0005432383717	4527	Economy	3300.00
0005432383725	4527	Economy	3300.00
0005432383727	4527	Economy	3600.00
0005432383732	4527	Economy	3600.00
0005433454906	4527	Economy	3600.00
0005432383722	4527	Economy	3300.00
0005433722318	4527	Economy	3300.00
0005432383746	4527	Economy	3300.00
0005432383734	4527	Economy	3300.00
0005432728116	4527	Economy	3300.00
0005432728120	4527	Economy	3300.00
0005433722317	4527	Economy	3300.00
0005432383730	4527	Economy	3300.00
0005432383736	4527	Economy	3300.00
0005432383710	4527	Economy	3300.00
0005432383742	4527	Economy	3300.00
0005432383729	4527	Economy	3300.00
0005432383721	4527	Economy	3300.00
0005432383713	4527	Economy	3300.00
0005432728124	4527	Economy	3300.00
0005432383723	4527	Economy	3300.00
0005432383735	4527	Economy	3300.00
0005432728118	4527	Economy	3300.00
0005432383724	4527	Economy	3300.00
0005432383739	4527	Economy	3300.00
0005433722316	4527	Economy	3300.00
0005432383743	4527	Economy	3300.00
0005432728115	4527	Economy	3300.00
0005432383711	4527	Economy	3300.00
0005432383714	4527	Economy	3300.00
0005432383719	4527	Economy	3300.00
0005433454905	4527	Economy	3300.00
0005432383744	4527	Economy	3300.00
0005432383715	4527	Economy	3300.00
0005432728114	4527	Economy	3300.00
0005432728122	4527	Economy	3300.00
0005432383748	4527	Economy	3300.00
0005432383745	4527	Economy	3300.00
0005432383726	4527	Economy	3300.00
0005432383731	4527	Economy	3300.00
0005432383738	4527	Economy	3300.00
0005432383747	4527	Economy	3300.00
0005432383709	4527	Economy	3300.00
0005432728125	4527	Economy	3300.00
0005432383741	4527	Economy	3300.00
0005432728121	4527	Economy	3300.00
0005432728123	4527	Economy	3300.00
0005433453789	4527	Economy	3300.00
0005432383712	4527	Economy	3300.00
0005433454907	4527	Economy	3300.00
0005432728113	4527	Economy	3300.00
0005432383749	4527	Economy	3300.00
0005433722254	30267	Business	9900.00
0005432383310	30267	Business	9900.00
0005433194871	30267	Business	9900.00
0005432383255	30267	Business	9900.00
0005432383342	30267	Business	9900.00
0005432728007	30267	Business	9900.00
0005432727991	30267	Business	9900.00
0005432383225	30267	Economy	3300.00
0005432728053	30267	Economy	3300.00
0005433453764	30267	Economy	3300.00
0005432383308	30267	Economy	3300.00
0005432383343	30267	Economy	3300.00
0005433722274	30267	Economy	3300.00
0005432383221	30267	Economy	3300.00
0005432728054	30267	Economy	3300.00
0005433722255	30267	Economy	3600.00
0005432383193	30267	Economy	3600.00
0005432383327	30267	Economy	3600.00
0005432383256	30267	Economy	3600.00
0005433722243	30267	Economy	3300.00
0005433722242	30267	Economy	3300.00
0005432383470	30267	Economy	3300.00
0005433722232	30267	Economy	3300.00
0005432383109	30267	Economy	3300.00
0005433722276	30267	Economy	3300.00
0005432383468	30267	Economy	3300.00
0005433194887	30267	Economy	3300.00
0005432727965	30267	Economy	3300.00
0005432383090	30267	Economy	3300.00
0005432383313	30267	Economy	3300.00
0005432383345	30267	Economy	3300.00
0005433451627	30267	Economy	3300.00
0005433722244	30267	Economy	3300.00
0005432383253	30267	Economy	3300.00
0005432383151	30267	Economy	3300.00
0005433722241	30267	Economy	3300.00
0005432383282	30267	Economy	3300.00
0005432383220	30267	Economy	3300.00
0005432727980	30267	Economy	3300.00
0005433722275	30267	Economy	3300.00
0005432383262	30267	Economy	3300.00
0005432383469	30267	Economy	3300.00
0005432383257	30267	Economy	3300.00
0005432383211	30267	Economy	3300.00
0005433722239	30267	Economy	3300.00
0005433722246	30267	Economy	3300.00
0005432383336	30267	Economy	3300.00
0005432383216	30267	Economy	3300.00
0005432383288	30267	Economy	3300.00
0005432383178	30267	Economy	3300.00
0005432383428	30267	Economy	3300.00
0005432727979	30267	Economy	3300.00
0005433722256	30267	Economy	3300.00
0005432383228	30267	Economy	3300.00
0005432727990	30267	Economy	3300.00
0005432383208	30267	Economy	3300.00
0005432383287	30267	Economy	3300.00
0005432383252	30267	Economy	3300.00
0005433194872	30267	Economy	3300.00
0005432727981	30267	Economy	3300.00
0005433722249	30267	Economy	3300.00
0005432383189	30267	Economy	3300.00
0005433722240	30267	Economy	3300.00
0005433453770	30267	Economy	3300.00
0005432383207	30267	Economy	3300.00
0005432728008	30267	Economy	3300.00
0005433722252	30267	Economy	3300.00
0005432727989	30267	Economy	3300.00
0005432383283	30267	Economy	3300.00
0005433722233	30267	Economy	3300.00
0005432383219	30267	Economy	3300.00
0005432383344	30267	Economy	3300.00
0005435529568	1746	Business	57200.00
0005435529565	1746	Business	57200.00
0005435529577	1746	Business	57200.00
0005435529585	1746	Business	57200.00
0005432925060	1746	Business	57200.00
0005435529975	1746	Business	57200.00
0005435529571	1746	Business	57200.00
0005435541327	1746	Economy	19100.00
0005435541312	1746	Economy	19100.00
0005435529583	1746	Economy	19100.00
0005435529582	1746	Economy	19100.00
0005435541313	1746	Economy	19100.00
0005435541329	1746	Economy	19100.00
0005435529576	1746	Economy	21000.00
0005433517021	1746	Economy	21000.00
0005435529567	1746	Economy	21000.00
0005435541322	1746	Economy	21000.00
0005435541330	1746	Economy	19100.00
0005435529580	1746	Economy	19100.00
0005435529581	1746	Economy	19100.00
0005435529974	1746	Economy	19100.00
0005432294521	1746	Economy	19100.00
0005433517019	1746	Economy	19100.00
0005435529569	1746	Economy	19100.00
0005433517022	1746	Economy	19100.00
0005435541316	1746	Economy	19100.00
0005433517026	1746	Economy	19100.00
0005435541326	1746	Economy	19100.00
0005432294523	1746	Economy	19100.00
0005435529579	1746	Economy	19100.00
0005435541328	1746	Economy	19100.00
0005435541331	1746	Economy	19100.00
0005435529584	1746	Economy	19100.00
0005435529578	1746	Economy	19100.00
0005435529572	1746	Economy	19100.00
0005432925051	1746	Economy	19100.00
0005435529586	1746	Economy	19100.00
0005432294522	1746	Economy	19100.00
0005435541311	1746	Economy	19100.00
0005435541314	1746	Economy	19100.00
0005435541323	1746	Economy	19100.00
0005433517027	1746	Economy	19100.00
0005435541318	1746	Economy	19100.00
0005435529574	1746	Economy	19100.00
0005435541315	1746	Economy	19100.00
0005435541325	1746	Economy	19100.00
0005435541317	1746	Economy	19100.00
0005435529575	1746	Economy	19100.00
0005433517025	1746	Economy	19100.00
0005433517024	1746	Economy	19100.00
0005432925076	1746	Economy	19100.00
0005435541321	1746	Economy	19100.00
0005433517023	1746	Economy	19100.00
0005435541324	1746	Economy	19100.00
0005432925077	1746	Economy	19100.00
0005435529587	1746	Economy	19100.00
0005435529570	1746	Economy	19100.00
0005433517020	1746	Economy	19100.00
0005435529566	1746	Economy	19100.00
0005435529573	1746	Economy	19100.00
0005435541319	1746	Economy	19100.00
0005435541320	1746	Economy	19100.00
0005433516928	21984	Business	57200.00
0005433516940	21984	Business	57200.00
0005435541145	21984	Business	57200.00
0005433516895	21984	Business	57200.00
0005435518078	21984	Business	57200.00
0005435517998	21984	Business	57200.00
0005435517970	21984	Economy	19100.00
0005435541175	21984	Economy	19100.00
0005435541140	21984	Economy	19100.00
0005435541173	21984	Economy	19100.00
0005433516915	21984	Economy	19100.00
0005435517994	21984	Economy	19100.00
0005435518034	21984	Economy	19100.00
0005435541174	21984	Economy	21000.00
0005433516927	21984	Economy	21000.00
0005435541159	21984	Economy	21000.00
0005435541066	21984	Economy	19100.00
0005433517003	21984	Economy	19100.00
0005432925103	21984	Economy	19100.00
0005435518012	21984	Economy	19100.00
0005435518024	21984	Economy	19100.00
0005432925104	21984	Economy	19100.00
0005435541190	21984	Economy	19100.00
0005435541126	21984	Economy	19100.00
0005432925105	21984	Economy	19100.00
0005435541117	21984	Economy	19100.00
0005435541189	21984	Economy	19100.00
0005435517974	21984	Economy	19100.00
0005435517988	21984	Economy	19100.00
0005433516946	21984	Economy	19100.00
0005435517987	21984	Economy	19100.00
0005435517920	21984	Economy	19100.00
0005435518093	21984	Economy	19100.00
0005433516935	21984	Economy	19100.00
0005433516931	21984	Economy	19100.00
0005433516930	21984	Economy	19100.00
0005435541139	21984	Economy	19100.00
0005435541118	21984	Economy	19100.00
0005435518006	21984	Economy	19100.00
0005433516934	21984	Economy	19100.00
0005432925106	21984	Economy	19100.00
0005432925107	21984	Economy	19100.00
0005435517981	21984	Economy	19100.00
0005433516896	21984	Economy	19100.00
0005435517919	21984	Economy	19100.00
0005435517975	21984	Economy	19100.00
0005435541083	21984	Economy	19100.00
0005435518047	21984	Economy	19100.00
0005435517971	21984	Economy	19100.00
0005433516952	21984	Economy	19100.00
0005435517982	21984	Economy	19100.00
0005435518016	21984	Economy	19100.00
0005435541026	21984	Economy	19100.00
0005435517995	21984	Economy	19100.00
0005435518025	21984	Economy	19100.00
0005435541101	21984	Economy	19100.00
0005435252724	7411	Business	18500.00
0005432839478	7411	Business	18500.00
0005434459108	7411	Business	18500.00
0005435252832	7411	Business	18500.00
0005432839476	7411	Business	18500.00
0005434664962	7411	Business	18500.00
0005434459098	7411	Business	18500.00
0005434459112	7411	Business	18500.00
0005435252746	7411	Business	18500.00
0005432839493	7411	Business	18500.00
0005432839479	7411	Business	18500.00
0005435252758	7411	Business	18500.00
0005435252759	7411	Economy	6200.00
0005432841042	7411	Economy	6200.00
0005435252827	7411	Economy	6200.00
0005432839485	7411	Economy	6200.00
0005432839496	7411	Economy	6200.00
0005435252826	7411	Economy	6200.00
0005432839487	7411	Economy	6200.00
0005435252785	7411	Economy	6200.00
0005432073440	7411	Economy	6200.00
0005432839474	7411	Economy	6200.00
0005434459097	7411	Economy	6800.00
0005434459103	7411	Economy	6800.00
0005434459102	7411	Economy	6800.00
0005435252745	7411	Economy	6800.00
0005432839470	7411	Economy	6800.00
0005432839488	7411	Economy	6200.00
0005432823477	7411	Economy	6200.00
0005434459095	7411	Economy	6200.00
0005432839482	7411	Economy	6200.00
0005432839484	7411	Economy	6200.00
0005434459099	7411	Economy	6200.00
0005435252765	7411	Economy	6200.00
0005432839472	7411	Economy	6200.00
0005435252725	7411	Economy	6200.00
0005432823476	7411	Economy	6200.00
0005434459109	7411	Economy	6200.00
0005432839475	7411	Economy	6200.00
0005435252824	7411	Economy	6200.00
0005435252801	7411	Economy	6200.00
0005432839494	7411	Economy	6200.00
0005432841041	7411	Economy	6200.00
0005435252790	7411	Economy	6200.00
0005432839486	7411	Economy	6200.00
0005432839492	7411	Economy	6200.00
0005435252835	7411	Economy	6200.00
0005435252802	7411	Economy	6200.00
0005435252760	7411	Economy	6200.00
0005432839490	7411	Economy	6200.00
0005432839468	7411	Economy	6200.00
0005432839467	7411	Economy	6200.00
0005435252834	7411	Economy	6200.00
0005435252853	7411	Economy	6200.00
0005432839477	7411	Economy	6200.00
0005434459114	7411	Economy	6200.00
0005432839473	7411	Economy	6200.00
0005434459107	7411	Economy	6200.00
0005435252823	7411	Economy	6200.00
0005435252829	7411	Economy	6200.00
0005435252845	7411	Economy	6200.00
0005432839489	7411	Economy	6200.00
0005434459110	7411	Economy	6200.00
0005435252822	7411	Economy	6200.00
0005432839491	7411	Economy	6200.00
0005432823478	7411	Economy	6200.00
0005435252804	7411	Economy	6200.00
0005435252761	7411	Economy	6200.00
0005434459106	7411	Economy	6200.00
0005432839495	7411	Economy	6200.00
0005435252839	7411	Economy	6200.00
0005434664960	7411	Economy	6200.00
0005432823479	7411	Economy	6200.00
0005432839497	7411	Economy	6200.00
0005434459101	7411	Economy	6200.00
0005434459094	7411	Economy	6200.00
0005434664965	7411	Economy	6200.00
0005432839483	7411	Economy	6200.00
0005434459104	7411	Economy	6200.00
0005434664961	7411	Economy	6200.00
0005435252776	7411	Economy	6200.00
0005432839480	7411	Economy	6200.00
0005434459100	7411	Economy	6200.00
0005432839481	7411	Economy	6200.00
0005435252791	7411	Economy	6200.00
0005432839469	7411	Economy	6200.00
0005434459096	7411	Economy	6200.00
0005435252726	7411	Economy	6200.00
0005434459113	7411	Economy	6200.00
0005434459105	7411	Economy	6200.00
0005432073441	7411	Economy	6200.00
0005432839498	7411	Economy	6200.00
0005432839471	7411	Economy	6200.00
0005434459111	7411	Economy	6200.00
0005435252828	7411	Economy	6200.00
0005435252957	28910	Business	18500.00
0005434458935	28910	Business	18500.00
0005435252963	28910	Business	18500.00
0005434664994	28910	Business	18500.00
0005432839099	28910	Business	18500.00
0005434458936	28910	Business	18500.00
0005432841023	28910	Business	18500.00
0005432839310	28910	Business	18500.00
0005432839206	28910	Business	18500.00
0005432839273	28910	Economy	6200.00
0005435252958	28910	Economy	6200.00
0005432823463	28910	Economy	6200.00
0005435252950	28910	Economy	6200.00
0005435252967	28910	Economy	6200.00
0005435491472	28910	Economy	6200.00
0005432839232	28910	Economy	6200.00
0005435491470	28910	Economy	6200.00
0005434458937	28910	Economy	6200.00
0005432839234	28910	Economy	6800.00
0005432839333	28910	Economy	6800.00
0005432839263	28910	Economy	6800.00
0005434458906	28910	Economy	6800.00
0005432001052	28910	Economy	6800.00
0005435252952	28910	Economy	6200.00
0005435252960	28910	Economy	6200.00
0005435252966	28910	Economy	6200.00
0005434458929	28910	Economy	6200.00
0005435252959	28910	Economy	6200.00
0005434458902	28910	Economy	6200.00
0005432839249	28910	Economy	6200.00
0005432839288	28910	Economy	6200.00
0005432841021	28910	Economy	6200.00
0005432839250	28910	Economy	6200.00
0005432839280	28910	Economy	6200.00
0005432001051	28910	Economy	6200.00
0005434458909	28910	Economy	6200.00
0005434458907	28910	Economy	6200.00
0005432839100	28910	Economy	6200.00
0005432839311	28910	Economy	6200.00
0005432839355	28910	Economy	6200.00
0005434458917	28910	Economy	6200.00
0005432839231	28910	Economy	6200.00
0005435252951	28910	Economy	6200.00
0005432839233	28910	Economy	6200.00
0005434664993	28910	Economy	6200.00
0005434458855	28910	Economy	6200.00
0005435252961	28910	Economy	6200.00
0005434458959	28910	Economy	6200.00
0005435491471	28910	Economy	6200.00
0005432841019	28910	Economy	6200.00
0005434458953	28910	Economy	6200.00
0005432823469	28910	Economy	6200.00
0005432839287	28910	Economy	6200.00
0005432839264	28910	Economy	6200.00
0005435252956	28910	Economy	6200.00
0005435252965	28910	Economy	6200.00
0005435252954	28910	Economy	6200.00
0005432841020	28910	Economy	6200.00
0005432839272	28910	Economy	6200.00
0005435252964	28910	Economy	6200.00
0005432839211	28910	Economy	6200.00
0005434664995	28910	Economy	6200.00
0005435252955	28910	Economy	6200.00
0005435252962	28910	Economy	6200.00
0005434458952	28910	Economy	6200.00
0005432839213	28910	Economy	6200.00
0005432839281	28910	Economy	6200.00
0005432841022	28910	Economy	6200.00
0005432839282	28910	Economy	6200.00
0005432823462	28910	Economy	6200.00
0005434458956	28910	Economy	6200.00
0005432839360	28910	Economy	6200.00
0005435252953	28910	Economy	6200.00
0005432839359	28910	Economy	6200.00
0005434458877	28910	Economy	6200.00
0005432839289	28910	Economy	6200.00
0005434458954	28910	Economy	6200.00
0005434276076	8819	Business	145300.00
0005434276068	8819	Business	145300.00
0005435990727	8819	Economy	48400.00
0005435990724	8819	Economy	48400.00
0005434276071	8819	Economy	53300.00
0005434276042	8819	Economy	53300.00
0005434276083	8819	Economy	48400.00
0005434276034	8819	Economy	48400.00
0005435990725	8819	Economy	48400.00
0005435990726	8819	Economy	48400.00
0005435990728	8819	Economy	48400.00
0005434276069	8819	Economy	48400.00
0005435990723	8819	Economy	48400.00
0005435990729	8819	Economy	48400.00
0005434276110	15742	Business	145300.00
0005434276107	15742	Business	145300.00
0005435990690	15742	Economy	48400.00
0005434276112	15742	Economy	48400.00
0005435990662	15742	Economy	48400.00
0005434276111	15742	Economy	48400.00
0005435990673	15742	Economy	48400.00
0005435990677	15742	Economy	48400.00
0005435990664	15742	Economy	48400.00
0005434276109	15742	Economy	48400.00
0005435990680	15742	Economy	48400.00
0005435990672	15742	Economy	48400.00
0005434276108	15742	Economy	48400.00
0005432427171	20623	Economy	14500.00
0005433476905	20623	Economy	14500.00
0005432427174	20623	Economy	14500.00
0005432427172	20623	Economy	14500.00
0005433476902	20623	Economy	14500.00
0005433476904	20623	Economy	14500.00
0005433476906	20623	Economy	14500.00
0005432427173	20623	Economy	14500.00
0005435177304	6377	Business	36600.00
0005432361067	6377	Business	36600.00
0005434149780	6377	Business	36600.00
0005432062305	6377	Business	36600.00
0005432361042	6377	Business	36600.00
0005434149788	6377	Business	36600.00
0005435177309	6377	Business	36600.00
0005432361060	6377	Business	36600.00
0005432361040	6377	Business	36600.00
0005435490259	6377	Business	36600.00
0005435490237	6377	Business	36600.00
0005432361044	6377	Business	36600.00
0005435177122	6377	Economy	12200.00
0005432361065	6377	Economy	12200.00
0005432361051	6377	Economy	12200.00
0005432361076	6377	Economy	12200.00
0005435177354	6377	Economy	12200.00
0005435177209	6377	Economy	12200.00
0005432363462	6377	Economy	12200.00
0005434149779	6377	Economy	12200.00
0005435490264	6377	Economy	12200.00
0005432361054	6377	Economy	12200.00
0005435177210	6377	Economy	12200.00
0005432361048	6377	Economy	12200.00
0005432361073	6377	Economy	12200.00
0005435177185	6377	Economy	12200.00
0005432361039	6377	Economy	12200.00
0005435177163	6377	Economy	12200.00
0005432361050	6377	Economy	12200.00
0005432336210	6377	Economy	12200.00
0005432336207	6377	Economy	12200.00
0005435177162	6377	Economy	12200.00
0005432361046	6377	Economy	12200.00
0005432361041	6377	Economy	12200.00
0005432062304	6377	Economy	12200.00
0005434149753	6377	Economy	12200.00
0005435177206	6377	Economy	12200.00
0005435177164	6377	Economy	12200.00
0005432361053	6377	Economy	12200.00
0005432361071	6377	Economy	12200.00
0005432062303	6377	Economy	12200.00
0005435177291	6377	Economy	12200.00
0005435177364	6377	Economy	12200.00
0005432336201	6377	Economy	12200.00
0005432361045	6377	Economy	12200.00
0005432361032	6377	Economy	12200.00
0005435177240	6377	Economy	12200.00
0005432361043	6377	Economy	12200.00
0005435177219	6377	Economy	12200.00
0005434149790	6377	Economy	12200.00
0005434149820	6377	Economy	12200.00
0005435177077	6377	Economy	12200.00
0005432361037	6377	Economy	13400.00
0005434149785	6377	Economy	13400.00
0005435177208	6377	Economy	13400.00
0005432361058	6377	Economy	13400.00
0005432361031	6377	Economy	13400.00
0005435177286	6377	Economy	13400.00
0005432363464	6377	Economy	12200.00
0005435177321	6377	Economy	12200.00
0005432361079	6377	Economy	12200.00
0005432361038	6377	Economy	12200.00
0005432336204	6377	Economy	12200.00
0005432361055	6377	Economy	12200.00
0005435177066	6377	Economy	12200.00
0005435177351	6377	Economy	12200.00
0005432336206	6377	Economy	12200.00
0005435177241	6377	Economy	12200.00
0005432361052	6377	Economy	12200.00
0005435490235	6377	Economy	12200.00
0005435177186	6377	Economy	12200.00
0005432336209	6377	Economy	12200.00
0005432062307	6377	Economy	12200.00
0005434149810	6377	Economy	12200.00
0005435177336	6377	Economy	12200.00
0005435177189	6377	Economy	12200.00
0005434149821	6377	Economy	12200.00
0005432361033	6377	Economy	12200.00
0005432361035	6377	Economy	12200.00
0005432361069	6377	Economy	12200.00
0005435177311	6377	Economy	12200.00
0005435177074	6377	Economy	12200.00
0005432336200	6377	Economy	12200.00
0005435177190	6377	Economy	12200.00
0005432361059	6377	Economy	12200.00
0005432361072	6377	Economy	12200.00
0005432361064	6377	Economy	12200.00
0005432361061	6377	Economy	12200.00
0005432361075	6377	Economy	12200.00
0005435177335	6377	Economy	12200.00
0005432361063	6377	Economy	12200.00
0005435490248	6377	Economy	12200.00
0005432361068	6377	Economy	12200.00
0005435177207	6377	Economy	12200.00
0005432361057	6377	Economy	12200.00
0005435177158	6377	Economy	12200.00
0005435177310	6377	Economy	12200.00
0005435177079	6377	Economy	12200.00
0005435490234	6377	Economy	12200.00
0005432336203	6377	Economy	12200.00
0005432336208	6377	Economy	12200.00
0005432361036	6377	Economy	12200.00
0005432361078	6377	Economy	12200.00
0005435177166	6377	Economy	12200.00
0005432363463	6377	Economy	12200.00
0005432062306	6377	Economy	12200.00
0005432361056	6377	Economy	12200.00
0005432361049	6377	Economy	12200.00
0005435177184	6377	Economy	12200.00
0005432336205	6377	Economy	12200.00
0005434149803	6377	Economy	12200.00
0005432361074	6377	Economy	12200.00
0005435723050	6377	Economy	12200.00
0005432361077	6377	Economy	12200.00
0005432361047	6377	Economy	12200.00
0005432361062	6377	Economy	12200.00
0005434149796	6377	Economy	12200.00
0005432361070	6377	Economy	12200.00
0005432361034	6377	Economy	12200.00
0005432361066	6377	Economy	12200.00
0005432336202	6377	Economy	12200.00
0005434149795	6377	Economy	12200.00
0005435177350	6377	Economy	12200.00
0005435490249	6377	Economy	12200.00
0005432363465	6377	Economy	12200.00
0005434149778	6377	Economy	12200.00
0005435490236	6377	Economy	12200.00
0005432336211	6377	Economy	12200.00
0005435177078	6377	Economy	12200.00
0005435177352	6377	Economy	12200.00
0005434149896	21003	Business	36600.00
0005432360849	21003	Business	36600.00
0005432360587	21003	Business	36600.00
0005432336090	21003	Business	36600.00
0005435177471	21003	Business	36600.00
0005432360822	21003	Business	36600.00
0005432052791	21003	Business	36600.00
0005435177474	21003	Business	36600.00
0005435177470	21003	Business	36600.00
0005432360419	21003	Business	36600.00
0005432360477	21003	Business	36600.00
0005434149904	21003	Business	36600.00
0005432363435	21003	Economy	12200.00
0005434149898	21003	Economy	12200.00
0005432336065	21003	Economy	12200.00
0005432360543	21003	Economy	12200.00
0005432360814	21003	Economy	12200.00
0005432360850	21003	Economy	12200.00
0005432360761	21003	Economy	12200.00
0005432336184	21003	Economy	12200.00
0005432360756	21003	Economy	12200.00
0005432360657	21003	Economy	12200.00
0005432363427	21003	Economy	12200.00
0005432360420	21003	Economy	12200.00
0005432360673	21003	Economy	12200.00
0005432360829	21003	Economy	12200.00
0005435490286	21003	Economy	12200.00
0005432360811	21003	Economy	12200.00
0005432336118	21003	Economy	12200.00
0005432360527	21003	Economy	12200.00
0005435723076	21003	Economy	12200.00
0005432360784	21003	Economy	12200.00
0005435177477	21003	Economy	12200.00
0005432360478	21003	Economy	12200.00
0005432360644	21003	Economy	12200.00
0005432360421	21003	Economy	12200.00
0005435177472	21003	Economy	12200.00
0005435177459	21003	Economy	12200.00
0005435177464	21003	Economy	12200.00
0005432336175	21003	Economy	12200.00
0005435177462	21003	Economy	12200.00
0005435177460	21003	Economy	12200.00
0005432336105	21003	Economy	12200.00
0005432052790	21003	Economy	12200.00
0005432360684	21003	Economy	12200.00
0005432360542	21003	Economy	12200.00
0005432360672	21003	Economy	12200.00
0005432336064	21003	Economy	13400.00
0005434149900	21003	Economy	13400.00
0005432360625	21003	Economy	13400.00
0005432360823	21003	Economy	13400.00
0005432363441	21003	Economy	12200.00
0005432360544	21003	Economy	12200.00
0005435177467	21003	Economy	12200.00
0005432363440	21003	Economy	12200.00
0005432360581	21003	Economy	12200.00
0005435177481	21003	Economy	12200.00
0005435177479	21003	Economy	12200.00
0005432360642	21003	Economy	12200.00
0005432360624	21003	Economy	12200.00
0005432360374	21003	Economy	12200.00
0005432360398	21003	Economy	12200.00
0005435177480	21003	Economy	12200.00
0005435490284	21003	Economy	12200.00
0005432336174	21003	Economy	12200.00
0005432336083	21003	Economy	12200.00
0005432360650	21003	Economy	12200.00
0005435177469	21003	Economy	12200.00
0005435177484	21003	Economy	12200.00
0005432360821	21003	Economy	12200.00
0005432360815	21003	Economy	12200.00
0005435177461	21003	Economy	12200.00
0005435177485	21003	Economy	12200.00
0005432052789	21003	Economy	12200.00
0005435177476	21003	Economy	12200.00
0005434149901	21003	Economy	12200.00
0005432360454	21003	Economy	12200.00
0005435177463	21003	Economy	12200.00
0005435177473	21003	Economy	12200.00
0005432336089	21003	Economy	12200.00
0005434149899	21003	Economy	12200.00
0005435177483	21003	Economy	12200.00
0005432336091	21003	Economy	12200.00
0005432360471	21003	Economy	12200.00
0005434149903	21003	Economy	12200.00
0005432360649	21003	Economy	12200.00
0005435490283	21003	Economy	12200.00
0005435723075	21003	Economy	12200.00
0005432360588	21003	Economy	12200.00
0005432360782	21003	Economy	12200.00
0005432360783	21003	Economy	12200.00
0005435490285	21003	Economy	12200.00
0005434149897	21003	Economy	12200.00
0005432336142	21003	Economy	12200.00
0005432360824	21003	Economy	12200.00
0005432360508	21003	Economy	12200.00
0005432360593	21003	Economy	12200.00
0005432052788	21003	Economy	12200.00
0005435177475	21003	Economy	12200.00
0005432360696	21003	Economy	12200.00
0005434149902	21003	Economy	12200.00
0005435177478	21003	Economy	12200.00
0005432360656	21003	Economy	12200.00
0005432360570	21003	Economy	12200.00
0005432360638	21003	Economy	12200.00
0005434149895	21003	Economy	12200.00
0005432360559	21003	Economy	12200.00
0005432360599	21003	Economy	12200.00
0005432363436	21003	Economy	12200.00
0005435177465	21003	Economy	12200.00
0005435177468	21003	Economy	12200.00
0005432360637	21003	Economy	12200.00
0005435177482	21003	Economy	12200.00
0005432336070	21003	Economy	12200.00
0005432360550	21003	Economy	12200.00
0005435177466	21003	Economy	12200.00
0005434458849	17705	Economy	3400.00
0005434458944	17705	Economy	3400.00
0005434458922	17705	Economy	3100.00
0005434458869	17705	Economy	3100.00
0005434458946	17705	Economy	3100.00
0005434458921	17705	Economy	3100.00
0005434459025	17705	Economy	3100.00
0005434458878	17705	Economy	3100.00
0005434186241	17705	Economy	3100.00
0005434458965	17705	Economy	3100.00
0005434186242	17705	Economy	3100.00
0005434458926	17705	Economy	3100.00
0005434458911	17705	Economy	3100.00
0005434458976	17705	Economy	3100.00
0005434458979	17705	Economy	3100.00
0005434458988	17705	Economy	3100.00
0005434461654	17705	Economy	3100.00
0005434458945	17705	Economy	3100.00
0005434458879	17705	Economy	3100.00
0005434458923	17705	Economy	3100.00
0005434458977	17705	Economy	3100.00
0005434458989	17705	Economy	3100.00
0005434459018	17705	Economy	3100.00
0005434458848	17705	Economy	3100.00
0005434458868	17705	Economy	3100.00
0005434186240	17705	Economy	3100.00
0005434458912	17705	Economy	3100.00
0005434458978	17705	Economy	3100.00
0005434458943	17705	Economy	3100.00
0005434459109	29130	Economy	3400.00
0005434459099	29130	Economy	3400.00
0005434459103	29130	Economy	3100.00
0005434459110	29130	Economy	3100.00
0005434448360	29130	Economy	3100.00
0005434459111	29130	Economy	3100.00
0005434459112	29130	Economy	3100.00
0005434459107	29130	Economy	3100.00
0005434463957	29130	Economy	3100.00
0005434459097	29130	Economy	3100.00
0005434459106	29130	Economy	3100.00
0005434459102	29130	Economy	3100.00
0005434459095	29130	Economy	3100.00
0005434459100	29130	Economy	3100.00
0005434459094	29130	Economy	3100.00
0005434463959	29130	Economy	3100.00
0005434459101	29130	Economy	3100.00
0005434459098	29130	Economy	3100.00
0005434448362	29130	Economy	3100.00
0005434462819	29130	Economy	3100.00
0005434462820	29130	Economy	3100.00
0005434463958	29130	Economy	3100.00
0005434459104	29130	Economy	3100.00
0005434459108	29130	Economy	3100.00
0005434459096	29130	Economy	3100.00
0005434463960	29130	Economy	3100.00
0005434459114	29130	Economy	3100.00
0005434459113	29130	Economy	3100.00
0005434448361	29130	Economy	3100.00
0005434459105	29130	Economy	3100.00
0005432604877	21416	Economy	7300.00
0005435218118	21416	Economy	7300.00
0005432604898	21416	Economy	6600.00
0005432604873	21416	Economy	6600.00
0005432604875	21416	Economy	6600.00
0005432604899	21416	Economy	6600.00
0005432604867	21416	Economy	6600.00
0005432604892	21416	Economy	6600.00
0005432604890	21416	Economy	6600.00
0005432604879	21416	Economy	6600.00
0005432604886	21416	Economy	6600.00
0005432604869	21416	Economy	6600.00
0005432604876	21416	Economy	6600.00
0005432604888	21416	Economy	6600.00
0005432604891	21416	Economy	6600.00
0005432604885	21416	Economy	6600.00
0005432604874	21416	Economy	6600.00
0005432604883	21416	Economy	6600.00
0005432604871	21416	Economy	6600.00
0005432604881	21416	Economy	6600.00
0005432604864	21416	Economy	6600.00
0005432604882	21416	Economy	6600.00
0005432604868	21416	Economy	6600.00
0005432604862	21416	Economy	6600.00
0005432604889	21416	Economy	6600.00
0005432604870	21416	Economy	6600.00
0005432604861	21416	Economy	6600.00
0005432604865	21416	Economy	6600.00
0005432604896	21416	Economy	6600.00
0005432604863	21416	Economy	6600.00
0005432604872	21416	Economy	6600.00
0005432604897	21416	Economy	6600.00
0005432604866	21416	Economy	6600.00
0005432604884	21416	Economy	6600.00
0005432604887	21416	Economy	6600.00
0005432604893	21416	Economy	6600.00
0005432604878	21416	Economy	6600.00
0005432604860	21416	Economy	6600.00
0005432604894	21416	Economy	6600.00
0005432604880	21416	Economy	6600.00
0005432604895	21416	Economy	6600.00
0005435218116	21416	Economy	6600.00
0005432604400	31661	Economy	7300.00
0005432604471	31661	Economy	7300.00
0005432604691	31661	Economy	7300.00
0005432604425	31661	Economy	7300.00
0005432604407	31661	Economy	6600.00
0005432604649	31661	Economy	6600.00
0005432604408	31661	Economy	6600.00
0005432604483	31661	Economy	6600.00
0005432604401	31661	Economy	6600.00
0005432604629	31661	Economy	6600.00
0005432604581	31661	Economy	6600.00
0005432604461	31661	Economy	6600.00
0005432604663	31661	Economy	6600.00
0005432604389	31661	Economy	6600.00
0005432604521	31661	Economy	6600.00
0005432604416	31661	Economy	6600.00
0005432604539	31661	Economy	6600.00
0005432604490	31661	Economy	6600.00
0005432604661	31661	Economy	6600.00
0005432604572	31661	Economy	6600.00
0005432604610	31661	Economy	6600.00
0005432604462	31661	Economy	6600.00
0005432604531	31661	Economy	6600.00
0005432604540	31661	Economy	6600.00
0005432604484	31661	Economy	6600.00
0005432604491	31661	Economy	6600.00
0005432604586	31661	Economy	6600.00
0005432604662	31661	Economy	6600.00
0005432604548	31661	Economy	6600.00
0005432604573	31661	Economy	6600.00
0005432604480	31661	Economy	6600.00
0005432604453	31661	Economy	6600.00
0005432604522	31661	Economy	6600.00
0005432604481	31661	Economy	6600.00
0005432604583	31661	Economy	6600.00
0005432604549	31661	Economy	6600.00
0005432604538	31661	Economy	6600.00
0005432604424	31661	Economy	6600.00
0005432604605	31661	Economy	6600.00
0005432604690	31661	Economy	6600.00
0005432604654	31661	Economy	6600.00
0005432604603	31661	Economy	6600.00
0005432604582	31661	Economy	6600.00
0005432604602	31661	Economy	6600.00
0005432604587	31661	Economy	6600.00
0005432604454	31661	Economy	6600.00
0005432604599	31661	Economy	6600.00
0005432604406	31661	Economy	6600.00
0005432604530	31661	Economy	6600.00
0005435154620	12314	Economy	19500.00
0005433293288	12314	Economy	19500.00
0005435154616	12314	Economy	17800.00
0005435154617	12314	Economy	17800.00
0005433293280	12314	Economy	17800.00
0005433293295	12314	Economy	17800.00
0005433293257	12314	Economy	17800.00
0005433293296	12314	Economy	17800.00
0005433293255	12314	Economy	17800.00
0005435154619	12314	Economy	17800.00
0005433293245	12314	Economy	17800.00
0005433293287	12314	Economy	17800.00
0005433293278	12314	Economy	17800.00
0005433293279	12314	Economy	17800.00
0005435154618	12314	Economy	17800.00
0005433293254	12314	Economy	17800.00
0005434606852	18888	Economy	6600.00
0005434606853	18888	Economy	6600.00
0005434606854	18888	Economy	6600.00
0005434606874	22339	Economy	6600.00
0005434604945	22339	Economy	6600.00
0005434606876	22339	Economy	6600.00
0005434606875	22339	Economy	6600.00
0005434604944	22339	Economy	6600.00
0005434606877	22339	Economy	6600.00
0005434604946	22339	Economy	6600.00
0005435904897	22339	Economy	6600.00
0005435904706	22339	Economy	6600.00
0005435904896	22339	Economy	6600.00
0005432748088	390	Business	44500.00
0005432753348	390	Business	44500.00
0005432748123	390	Business	44500.00
0005432748117	390	Business	44500.00
0005432748122	390	Business	44500.00
0005432748099	390	Business	44500.00
0005432748118	390	Business	44500.00
0005432753347	390	Business	44500.00
0005433293294	390	Business	44500.00
0005432891142	390	Business	44500.00
0005432748115	390	Economy	14800.00
0005432891123	390	Economy	14800.00
0005432748100	390	Economy	14800.00
0005432748091	390	Economy	14800.00
0005432748120	390	Economy	14800.00
0005432753346	390	Economy	14800.00
0005432748103	390	Economy	14800.00
0005432891159	390	Economy	14800.00
0005432891153	390	Economy	16300.00
0005432891158	390	Economy	16300.00
0005432748095	390	Economy	16300.00
0005432748116	390	Economy	16300.00
0005433293266	390	Economy	16300.00
0005432748111	390	Economy	14800.00
0005432748110	390	Economy	14800.00
0005432748107	390	Economy	14800.00
0005432891079	390	Economy	14800.00
0005432748098	390	Economy	14800.00
0005432748109	390	Economy	14800.00
0005432748106	390	Economy	14800.00
0005432748114	390	Economy	14800.00
0005433875392	390	Economy	14800.00
0005433293293	390	Economy	14800.00
0005432748094	390	Economy	14800.00
0005432748121	390	Economy	14800.00
0005432751572	390	Economy	14800.00
0005432220061	390	Economy	14800.00
0005432748112	390	Economy	14800.00
0005432748092	390	Economy	14800.00
0005432748101	390	Economy	14800.00
0005432748108	390	Economy	14800.00
0005432891133	390	Economy	14800.00
0005432748097	390	Economy	14800.00
0005432748124	390	Economy	14800.00
0005433293284	390	Economy	14800.00
0005432748089	390	Economy	14800.00
0005435627121	390	Economy	14800.00
0005433293283	390	Economy	14800.00
0005435154621	390	Economy	14800.00
0005432749815	390	Economy	14800.00
0005432748102	390	Economy	14800.00
0005433293267	390	Economy	14800.00
0005432891149	390	Economy	14800.00
0005432751573	390	Economy	14800.00
0005432220065	390	Economy	14800.00
0005432748096	390	Economy	14800.00
0005432891195	390	Economy	14800.00
0005432748127	390	Economy	14800.00
0005432220064	390	Economy	14800.00
0005435154622	390	Economy	14800.00
0005432748125	390	Economy	14800.00
0005432751570	390	Economy	14800.00
0005435154623	390	Economy	14800.00
0005432891118	390	Economy	14800.00
0005432891080	390	Economy	14800.00
0005432748113	390	Economy	14800.00
0005432891131	390	Economy	14800.00
0005432748126	390	Economy	14800.00
0005432751571	390	Economy	14800.00
0005432220062	390	Economy	14800.00
0005433293285	390	Economy	14800.00
0005432891139	390	Economy	14800.00
0005432891141	390	Economy	14800.00
0005432891191	390	Economy	14800.00
0005432748093	390	Economy	14800.00
0005432748119	390	Economy	14800.00
0005432891167	390	Economy	14800.00
0005432748104	390	Economy	14800.00
0005432748087	390	Economy	14800.00
0005432748090	390	Economy	14800.00
0005432748105	390	Economy	14800.00
0005432220063	390	Economy	14800.00
0005432891140	390	Economy	14800.00
0005432747787	12065	Business	44500.00
0005432753316	12065	Business	44500.00
0005432747719	12065	Business	44500.00
0005432749797	12065	Business	44500.00
0005432891290	12065	Business	44500.00
0005433293324	12065	Business	44500.00
0005433293334	12065	Business	44500.00
0005432747798	12065	Business	44500.00
0005432753332	12065	Business	44500.00
0005432747858	12065	Business	44500.00
0005432891299	12065	Business	44500.00
0005432747788	12065	Economy	14800.00
0005432891296	12065	Economy	14800.00
0005432747811	12065	Economy	14800.00
0005432753312	12065	Economy	14800.00
0005432747784	12065	Economy	14800.00
0005432891294	12065	Economy	14800.00
0005432747797	12065	Economy	14800.00
0005432891302	12065	Economy	14800.00
0005433293327	12065	Economy	14800.00
0005433293336	12065	Economy	16300.00
0005432756864	12065	Economy	16300.00
0005432747913	12065	Economy	16300.00
0005432747670	12065	Economy	16300.00
0005432747805	12065	Economy	16300.00
0005433875401	12065	Economy	14800.00
0005432747851	12065	Economy	14800.00
0005432891308	12065	Economy	14800.00
0005433293333	12065	Economy	14800.00
0005432753325	12065	Economy	14800.00
0005433293328	12065	Economy	14800.00
0005432747834	12065	Economy	14800.00
0005432749795	12065	Economy	14800.00
0005432753333	12065	Economy	14800.00
0005433293332	12065	Economy	14800.00
0005432891310	12065	Economy	14800.00
0005432747900	12065	Economy	14800.00
0005432891305	12065	Economy	14800.00
0005432891297	12065	Economy	14800.00
0005432747889	12065	Economy	14800.00
0005432891292	12065	Economy	14800.00
0005433293326	12065	Economy	14800.00
0005432747813	12065	Economy	14800.00
0005433293335	12065	Economy	14800.00
0005433293331	12065	Economy	14800.00
0005432747912	12065	Economy	14800.00
0005432753324	12065	Economy	14800.00
0005432747832	12065	Economy	14800.00
0005432747697	12065	Economy	14800.00
0005433293330	12065	Economy	14800.00
0005434153548	12065	Economy	14800.00
0005432747956	12065	Economy	14800.00
0005432747756	12065	Economy	14800.00
0005432747872	12065	Economy	14800.00
0005432747803	12065	Economy	14800.00
0005432747957	12065	Economy	14800.00
0005433293325	12065	Economy	14800.00
0005432891304	12065	Economy	14800.00
0005432891298	12065	Economy	14800.00
0005432747746	12065	Economy	14800.00
0005432747973	12065	Economy	14800.00
0005432749794	12065	Economy	14800.00
0005432747804	12065	Economy	14800.00
0005432891307	12065	Economy	14800.00
0005432747833	12065	Economy	14800.00
0005432747892	12065	Economy	14800.00
0005432891291	12065	Economy	14800.00
0005432891303	12065	Economy	14800.00
0005432747911	12065	Economy	14800.00
0005432747847	12065	Economy	14800.00
0005434153549	12065	Economy	14800.00
0005432214835	12065	Economy	14800.00
0005434153547	12065	Economy	14800.00
0005432891309	12065	Economy	14800.00
0005432747720	12065	Economy	14800.00
0005432891293	12065	Economy	14800.00
0005432747799	12065	Economy	14800.00
0005432891295	12065	Economy	14800.00
0005432891301	12065	Economy	14800.00
0005432747846	12065	Economy	14800.00
0005432747694	12065	Economy	14800.00
0005432747783	12065	Economy	14800.00
0005432747630	12065	Economy	14800.00
0005432749798	12065	Economy	14800.00
0005432747765	12065	Economy	14800.00
0005432891306	12065	Economy	14800.00
0005433875400	12065	Economy	14800.00
0005432747881	12065	Economy	14800.00
0005432747871	12065	Economy	14800.00
0005432891300	12065	Economy	14800.00
0005432747877	12065	Economy	14800.00
0005433293329	12065	Economy	14800.00
0005433531345	18980	Economy	28200.00
0005432928018	18980	Economy	25700.00
0005433525183	18980	Economy	25700.00
0005433531346	18980	Economy	25700.00
0005433531344	18980	Economy	25700.00
0005433525187	18980	Economy	25700.00
0005433525190	18980	Economy	25700.00
0005433525188	18980	Economy	25700.00
0005433533359	18980	Economy	25700.00
0005432928000	18980	Economy	25700.00
0005433533361	18980	Economy	25700.00
0005433525182	18980	Economy	25700.00
0005433525189	18980	Economy	25700.00
0005432927991	18980	Economy	25700.00
0005432928016	18980	Economy	25700.00
0005433525191	18980	Economy	25700.00
0005432928017	18980	Economy	25700.00
0005432928015	18980	Economy	25700.00
0005433531343	18980	Economy	25700.00
0005433531342	18980	Economy	25700.00
0005433525185	18980	Economy	25700.00
0005432927999	18980	Economy	25700.00
0005433525186	18980	Economy	25700.00
0005433533357	18980	Economy	25700.00
0005433525184	18980	Economy	25700.00
0005433533358	18980	Economy	25700.00
0005432928037	18980	Economy	25700.00
0005433533360	18980	Economy	25700.00
0005433527269	32516	Economy	28200.00
0005433525058	32516	Economy	25700.00
0005433525072	32516	Economy	25700.00
0005433527266	32516	Economy	25700.00
0005432928067	32516	Economy	25700.00
0005433531312	32516	Economy	25700.00
0005432928065	32516	Economy	25700.00
0005432928068	32516	Economy	25700.00
0005433525070	32516	Economy	25700.00
0005433531311	32516	Economy	25700.00
0005432928063	32516	Economy	25700.00
0005432928066	32516	Economy	25700.00
0005432928064	32516	Economy	25700.00
0005433527282	32516	Economy	25700.00
0005434558402	5276	Business	84000.00
0005434825354	5276	Business	84000.00
0005434825413	5276	Business	84000.00
0005435386591	5276	Business	84000.00
0005434825415	5276	Business	84000.00
0005435386614	5276	Business	84000.00
0005434825433	5276	Business	84000.00
0005432121540	5276	Business	84000.00
0005434825381	5276	Business	84000.00
0005434825438	5276	Business	84000.00
0005435735153	5276	Business	84000.00
0005434825408	5276	Business	84000.00
0005435373642	5276	Business	84000.00
0005434825405	5276	Business	84000.00
0005434828735	5276	Business	84000.00
0005434825446	5276	Business	84000.00
0005435373645	5276	Business	84000.00
0005434664992	5276	Comfort	47600.00
0005434558400	5276	Business	84000.00
0005434825352	5276	Comfort	47600.00
0005432396301	5276	Comfort	47600.00
0005434825347	5276	Comfort	47600.00
0005435373853	5276	Comfort	47600.00
0005434825376	5276	Comfort	47600.00
0005434825338	5276	Comfort	47600.00
0005435373731	5276	Comfort	47600.00
0005434825385	5276	Comfort	47600.00
0005435373771	5276	Comfort	47600.00
0005435661945	5276	Comfort	47600.00
0005434558408	5276	Comfort	47600.00
0005435373551	5276	Comfort	47600.00
0005435304180	5276	Comfort	47600.00
0005434825340	5276	Comfort	47600.00
0005434825386	5276	Comfort	47600.00
0005434831214	5276	Comfort	47600.00
0005435150228	5276	Comfort	47600.00
0005435373689	5276	Comfort	47600.00
0005434825428	5276	Comfort	47600.00
0005435304179	5276	Comfort	47600.00
0005434825450	5276	Comfort	47600.00
0005434831215	5276	Comfort	47600.00
0005434558405	5276	Comfort	47600.00
0005434825389	5276	Comfort	47600.00
0005432121532	5276	Comfort	47600.00
0005434825378	5276	Comfort	47600.00
0005435373780	5276	Comfort	47600.00
0005435150230	5276	Comfort	47600.00
0005432121533	5276	Comfort	47600.00
0005434825398	5276	Comfort	47600.00
0005434825466	5276	Comfort	47600.00
0005435386628	5276	Comfort	47600.00
0005432121541	5276	Comfort	47600.00
0005434825349	5276	Comfort	47600.00
0005434825383	5276	Economy	28000.00
0005435373627	5276	Economy	28000.00
0005435386629	5276	Economy	28000.00
0005432121536	5276	Economy	28000.00
0005435373612	5276	Economy	28000.00
0005435735151	5276	Economy	28000.00
0005434825437	5276	Economy	28000.00
0005435735144	5276	Economy	28000.00
0005432121531	5276	Economy	28000.00
0005435373632	5276	Economy	28000.00
0005435373707	5276	Economy	28000.00
0005435373808	5276	Economy	28000.00
0005434825410	5276	Economy	28000.00
0005432823458	5276	Economy	28000.00
0005434825459	5276	Economy	28000.00
0005434825380	5276	Economy	28000.00
0005434825373	5276	Economy	28000.00
0005434825463	5276	Economy	28000.00
0005434825430	5276	Economy	28000.00
0005434825427	5276	Economy	28000.00
0005434825397	5276	Economy	28000.00
0005435373640	5276	Economy	28000.00
0005434825346	5276	Economy	28000.00
0005434825402	5276	Economy	28000.00
0005435386613	5276	Economy	28000.00
0005434825350	5276	Economy	28000.00
0005434558407	5276	Economy	28000.00
0005432121534	5276	Economy	28000.00
0005434825401	5276	Economy	28000.00
0005435150224	5276	Economy	28000.00
0005435150233	5276	Economy	28000.00
0005434664990	5276	Economy	28000.00
0005434825372	5276	Economy	28000.00
0005432121543	5276	Economy	28000.00
0005435150232	5276	Economy	28000.00
0005432394160	5276	Economy	28000.00
0005432396303	5276	Economy	28000.00
0005434825366	5276	Economy	28000.00
0005435373426	5276	Economy	28000.00
0005434558409	5276	Economy	28000.00
0005434825382	5276	Economy	28000.00
0005432394161	5276	Economy	28000.00
0005434825440	5276	Economy	28000.00
0005434825458	5276	Economy	28000.00
0005435150226	5276	Economy	28000.00
0005434825461	5276	Economy	28000.00
0005435373629	5276	Economy	28000.00
0005435373224	5276	Economy	28000.00
0005435386581	5276	Economy	30800.00
0005434825406	5276	Economy	28000.00
0005434825370	5276	Economy	30800.00
0005434825384	5276	Economy	30800.00
0005434825445	5276	Economy	30800.00
0005434825362	5276	Economy	30800.00
0005434825452	5276	Economy	28000.00
0005434825456	5276	Economy	28000.00
0005435373628	5276	Economy	28000.00
0005434825399	5276	Economy	28000.00
0005434825419	5276	Economy	28000.00
0005434825454	5276	Economy	28000.00
0005434825392	5276	Economy	28000.00
0005434825355	5276	Economy	28000.00
0005435373726	5276	Economy	28000.00
0005435373839	5276	Economy	28000.00
0005435373542	5276	Economy	28000.00
0005435150223	5276	Economy	28000.00
0005434825356	5276	Economy	28000.00
0005434825417	5276	Economy	28000.00
0005434825369	5276	Economy	28000.00
0005435373695	5276	Economy	28000.00
0005434825364	5276	Economy	28000.00
0005434825436	5276	Economy	28000.00
0005435373840	5276	Economy	28000.00
0005435299799	5276	Economy	28000.00
0005434825371	5276	Economy	28000.00
0005435373737	5276	Economy	28000.00
0005432394163	5276	Economy	28000.00
0005434831212	5276	Economy	28000.00
0005434825425	5276	Economy	28000.00
0005435373781	5276	Economy	28000.00
0005434825414	5276	Economy	28000.00
0005435373641	5276	Economy	28000.00
0005434825357	5276	Economy	28000.00
0005434825409	5276	Economy	28000.00
0005435373510	5276	Economy	28000.00
0005435373772	5276	Economy	28000.00
0005432823464	5276	Economy	28000.00
0005435373449	5276	Economy	28000.00
0005435373658	5276	Economy	28000.00
0005435386592	5276	Economy	28000.00
0005435373619	5276	Economy	28000.00
0005434825363	5276	Economy	28000.00
0005435373522	5276	Economy	28000.00
0005434825412	5276	Economy	28000.00
0005434825439	5276	Economy	28000.00
0005432823467	5276	Economy	28000.00
0005434825443	5276	Economy	28000.00
0005435373399	5276	Economy	28000.00
0005435373493	5276	Economy	28000.00
0005434825467	5276	Economy	28000.00
0005434825465	5276	Economy	28000.00
0005434825353	5276	Economy	28000.00
0005434825451	5276	Economy	28000.00
0005435735154	5276	Economy	28000.00
0005434825448	5276	Economy	28000.00
0005435373633	5276	Economy	28000.00
0005435179698	5276	Economy	28000.00
0005435373732	5276	Economy	28000.00
0005435373521	5276	Economy	28000.00
0005434558401	5276	Economy	28000.00
0005434825348	5276	Economy	28000.00
0005434558399	5276	Economy	28000.00
0005435373733	5276	Economy	28000.00
0005432396302	5276	Economy	28000.00
0005434825441	5276	Economy	28000.00
0005434825424	5276	Economy	28000.00
0005434831217	5276	Economy	28000.00
0005435150235	5276	Economy	28000.00
0005434825416	5276	Economy	28000.00
0005434825374	5276	Economy	28000.00
0005434825345	5276	Economy	28000.00
0005434825361	5276	Economy	28000.00
0005435373541	5276	Economy	28000.00
0005432121542	5276	Economy	28000.00
0005434825404	5276	Economy	28000.00
0005434825403	5276	Economy	28000.00
0005434825396	5276	Economy	28000.00
0005434825426	5276	Economy	28000.00
0005434825339	5276	Economy	28000.00
0005435373646	5276	Economy	28000.00
0005435179697	5276	Economy	28000.00
0005435150225	5276	Economy	28000.00
0005435373528	5276	Economy	28000.00
0005434825365	5276	Economy	28000.00
0005435150229	5276	Economy	28000.00
0005434825390	5276	Economy	28000.00
0005434825421	5276	Economy	28000.00
0005434825432	5276	Economy	28000.00
0005435373787	5276	Economy	28000.00
0005434828734	5276	Economy	28000.00
0005432394162	5276	Economy	28000.00
0005435373537	5276	Economy	28000.00
0005432394164	5276	Economy	28000.00
0005434825453	5276	Economy	30800.00
0005434825462	5276	Economy	30800.00
0005435373648	5276	Economy	30800.00
0005435373431	5276	Economy	30800.00
0005434825411	5276	Economy	30800.00
0005435373400	5276	Economy	28000.00
0005435373795	5276	Economy	28000.00
0005434825394	5276	Economy	28000.00
0005434825444	5276	Economy	28000.00
0005434831216	5276	Economy	28000.00
0005435299806	5276	Economy	28000.00
0005434825434	5276	Economy	28000.00
0005434825341	5276	Economy	28000.00
0005434825418	5276	Economy	28000.00
0005434825359	5276	Economy	28000.00
0005434558404	5276	Economy	28000.00
0005434825431	5276	Economy	28000.00
0005432121537	5276	Economy	28000.00
0005435735145	5276	Economy	28000.00
0005432121535	5276	Economy	28000.00
0005435386627	5276	Economy	28000.00
0005434825395	5276	Economy	28000.00
0005434825351	5276	Economy	28000.00
0005434825377	5276	Economy	28000.00
0005434664991	5276	Economy	28000.00
0005435373637	5276	Economy	28000.00
0005434825422	5276	Economy	28000.00
0005434825442	5276	Economy	28000.00
0005435150231	5276	Economy	28000.00
0005435373303	5276	Economy	28000.00
0005434825423	5276	Economy	28000.00
0005434825343	5276	Economy	28000.00
0005435373223	5276	Economy	28000.00
0005434825455	5276	Economy	28000.00
0005435373222	5276	Economy	28000.00
0005435150227	5276	Economy	28000.00
0005434825460	5276	Economy	28000.00
0005434825464	5276	Economy	28000.00
0005434831213	5276	Economy	28000.00
0005435373268	5276	Economy	28000.00
0005434825435	5276	Economy	28000.00
0005434825344	5276	Economy	28000.00
0005435373754	5276	Economy	28000.00
0005435373659	5276	Economy	28000.00
0005434825429	5276	Economy	28000.00
0005434825388	5276	Economy	28000.00
0005435150222	5276	Economy	28000.00
0005434558406	5276	Economy	28000.00
0005435373563	5276	Economy	28000.00
0005434825447	5276	Economy	28000.00
0005434825379	5276	Economy	28000.00
0005434558410	5276	Economy	28000.00
0005434558403	5276	Economy	28000.00
0005434825400	5276	Economy	28000.00
0005434825368	5276	Economy	28000.00
0005435373692	5276	Economy	28000.00
0005432121530	5276	Economy	28000.00
0005432121538	5276	Economy	28000.00
0005435386618	5276	Economy	28000.00
0005434825342	5276	Economy	28000.00
0005434825360	5276	Economy	28000.00
0005435661944	5276	Economy	28000.00
0005435373779	5276	Economy	28000.00
0005435735146	5276	Economy	28000.00
0005432823461	5276	Economy	28000.00
0005435373897	5276	Economy	28000.00
0005434825367	5276	Economy	28000.00
0005434825393	5276	Economy	28000.00
0005435373511	5276	Economy	28000.00
0005435373643	5276	Economy	28000.00
0005434825457	5276	Economy	28000.00
0005434825375	5276	Economy	28000.00
0005435299800	5276	Economy	28000.00
0005434825449	5276	Economy	28000.00
0005435373855	5276	Economy	28000.00
0005435299790	5276	Economy	28000.00
0005435150234	5276	Economy	28000.00
0005434825391	5276	Economy	28000.00
0005434825358	5276	Economy	28000.00
0005434825387	5276	Economy	28000.00
0005435386606	5276	Economy	28000.00
0005435386582	5276	Economy	28000.00
0005435373520	5276	Economy	28000.00
0005435373803	5276	Economy	28000.00
0005435373753	5276	Economy	28000.00
0005434825407	5276	Economy	28000.00
0005435373690	5276	Economy	28000.00
0005434825420	5276	Economy	28000.00
0005432121539	5276	Economy	28000.00
0005434823623	9920	Business	84000.00
0005434824225	9920	Business	84000.00
0005435150120	9920	Business	84000.00
0005434824082	9920	Business	84000.00
0005434558290	9920	Business	84000.00
0005435386661	9920	Business	84000.00
0005434824372	9920	Business	84000.00
0005432203169	9920	Business	84000.00
0005435374195	9920	Business	84000.00
0005434824450	9920	Business	84000.00
0005434558287	9920	Business	84000.00
0005434824312	9920	Business	84000.00
0005435302265	9920	Business	84000.00
0005434824893	9920	Business	84000.00
0005432203164	9920	Business	84000.00
0005435735206	9920	Business	84000.00
0005435374191	9920	Business	84000.00
0005435374189	9920	Business	84000.00
0005435374211	9920	Business	84000.00
0005434824613	9920	Business	84000.00
0005432823480	9920	Comfort	47600.00
0005434823929	9920	Business	84000.00
0005434831168	9920	Comfort	47600.00
0005434558321	9920	Comfort	47600.00
0005434558300	9920	Comfort	47600.00
0005434824373	9920	Comfort	47600.00
0005435374215	9920	Comfort	47600.00
0005435374228	9920	Comfort	47600.00
0005435299843	9920	Comfort	47600.00
0005435374164	9920	Comfort	47600.00
0005432400140	9920	Comfort	47600.00
0005434824451	9920	Comfort	47600.00
0005434824066	9920	Comfort	47600.00
0005434824800	9920	Comfort	47600.00
0005434824430	9920	Comfort	47600.00
0005435374192	9920	Comfort	47600.00
0005435150033	9920	Comfort	47600.00
0005435150043	9920	Comfort	47600.00
0005434824194	9920	Comfort	47600.00
0005434824518	9920	Comfort	47600.00
0005434823763	9920	Comfort	47600.00
0005434558317	9920	Comfort	47600.00
0005435374198	9920	Comfort	47600.00
0005435374222	9920	Comfort	47600.00
0005434824614	9920	Comfort	47600.00
0005434824609	9920	Comfort	47600.00
0005434824521	9920	Comfort	47600.00
0005434824496	9920	Comfort	47600.00
0005435374229	9920	Comfort	47600.00
0005435374188	9920	Economy	28000.00
0005434824086	9920	Economy	28000.00
0005435374193	9920	Economy	28000.00
0005434823900	9920	Economy	28000.00
0005435374209	9920	Economy	28000.00
0005434824015	9920	Economy	28000.00
0005434824098	9920	Economy	28000.00
0005434824618	9920	Economy	28000.00
0005434824240	9920	Economy	28000.00
0005434824463	9920	Economy	28000.00
0005435302268	9920	Economy	28000.00
0005435374197	9920	Economy	28000.00
0005434824375	9920	Economy	28000.00
0005435374187	9920	Economy	28000.00
0005434823624	9920	Economy	28000.00
0005434824351	9920	Economy	28000.00
0005435374206	9920	Economy	28000.00
0005434831173	9920	Economy	28000.00
0005434824796	9920	Economy	28000.00
0005435374213	9920	Economy	28000.00
0005432203165	9920	Economy	28000.00
0005432203166	9920	Economy	28000.00
0005432400136	9920	Economy	28000.00
0005434831193	9920	Economy	28000.00
0005432396274	9920	Economy	28000.00
0005434823983	9920	Economy	28000.00
0005434824167	9920	Economy	28000.00
0005435661972	9920	Economy	28000.00
0005432396273	9920	Economy	28000.00
0005434824374	9920	Economy	28000.00
0005434823898	9920	Economy	28000.00
0005435374167	9920	Economy	28000.00
0005434824862	9920	Economy	28000.00
0005434824683	9920	Economy	28000.00
0005435302266	9920	Economy	28000.00
0005434824013	9920	Economy	28000.00
0005435149999	9920	Economy	28000.00
0005434824051	9920	Economy	28000.00
0005435661973	9920	Economy	28000.00
0005435374201	9920	Economy	28000.00
0005434824476	9920	Economy	28000.00
0005435374173	9920	Economy	28000.00
0005434824440	9920	Economy	28000.00
0005434823583	9920	Economy	28000.00
0005435299845	9920	Economy	28000.00
0005434824190	9920	Economy	28000.00
0005434824128	9920	Economy	28000.00
0005434824462	9920	Economy	28000.00
0005434824771	9920	Economy	28000.00
0005435374170	9920	Economy	28000.00
0005434831194	9920	Economy	30800.00
0005434824406	9920	Economy	28000.00
0005434824301	9920	Economy	28000.00
0005434824597	9920	Economy	28000.00
0005434824861	9920	Economy	28000.00
0005432203170	9920	Economy	30800.00
0005435374165	9920	Economy	28000.00
0005435374180	9920	Economy	30800.00
0005434828715	9920	Economy	28000.00
0005435299844	9920	Economy	28000.00
0005435374199	9920	Economy	28000.00
0005434823778	9920	Economy	28000.00
0005435299846	9920	Economy	28000.00
0005432400148	9920	Economy	28000.00
0005434824598	9920	Economy	28000.00
0005435374178	9920	Economy	28000.00
0005435374179	9920	Economy	28000.00
0005434824231	9920	Economy	28000.00
0005434824971	9920	Economy	28000.00
0005434828716	9920	Economy	28000.00
0005434824728	9920	Economy	28000.00
0005434558288	9920	Economy	28000.00
0005434824193	9920	Economy	28000.00
0005434824445	9920	Economy	28000.00
0005434824615	9920	Economy	28000.00
0005434824278	9920	Economy	28000.00
0005435374223	9920	Economy	28000.00
0005435150091	9920	Economy	28000.00
0005435374226	9920	Economy	28000.00
0005435150042	9920	Economy	28000.00
0005434823925	9920	Economy	28000.00
0005434823711	9920	Economy	28000.00
0005435661974	9920	Economy	28000.00
0005435374174	9920	Economy	28000.00
0005435374214	9920	Economy	28000.00
0005434824549	9920	Economy	28000.00
0005435374219	9920	Economy	28000.00
0005435374207	9920	Economy	28000.00
0005434824171	9920	Economy	28000.00
0005435374168	9920	Economy	28000.00
0005432400135	9920	Economy	28000.00
0005434824783	9920	Economy	28000.00
0005434824770	9920	Economy	28000.00
0005435374162	9920	Economy	28000.00
0005435374204	9920	Economy	28000.00
0005434824608	9920	Economy	28000.00
0005432400147	9920	Economy	28000.00
0005434558289	9920	Economy	28000.00
0005432396271	9920	Economy	28000.00
0005435302267	9920	Economy	28000.00
0005435386666	9920	Economy	28000.00
0005434824099	9920	Economy	28000.00
0005434824238	9920	Economy	28000.00
0005434824467	9920	Economy	28000.00
0005435386659	9920	Economy	28000.00
0005435735207	9920	Economy	28000.00
0005434831169	9920	Economy	28000.00
0005434823977	9920	Economy	28000.00
0005434824096	9920	Economy	28000.00
0005434824637	9920	Economy	28000.00
0005435735205	9920	Economy	28000.00
0005435374217	9920	Economy	28000.00
0005435374230	9920	Economy	28000.00
0005432400141	9920	Economy	28000.00
0005434824265	9920	Economy	28000.00
0005435374221	9920	Economy	28000.00
0005434824239	9920	Economy	28000.00
0005435374182	9920	Economy	28000.00
0005434824050	9920	Economy	28000.00
0005434824599	9920	Economy	28000.00
0005434824345	9920	Economy	28000.00
0005435374208	9920	Economy	28000.00
0005434664972	9920	Economy	28000.00
0005435374183	9920	Economy	28000.00
0005434824548	9920	Economy	28000.00
0005434824600	9920	Economy	28000.00
0005435735203	9920	Economy	28000.00
0005434824441	9920	Economy	28000.00
0005434831167	9920	Economy	28000.00
0005434824170	9920	Economy	28000.00
0005434824065	9920	Economy	28000.00
0005434824313	9920	Economy	28000.00
0005434823838	9920	Economy	28000.00
0005434824031	9920	Economy	28000.00
0005435374205	9920	Economy	28000.00
0005435374181	9920	Economy	28000.00
0005434824727	9920	Economy	28000.00
0005435374200	9920	Economy	28000.00
0005435374194	9920	Economy	28000.00
0005434831172	9920	Economy	30800.00
0005435150142	9920	Economy	30800.00
0005434824249	9920	Economy	30800.00
0005435374225	9920	Economy	28000.00
0005434824120	9920	Economy	28000.00
0005435374218	9920	Economy	28000.00
0005435374210	9920	Economy	28000.00
0005435374190	9920	Economy	28000.00
0005435374172	9920	Economy	28000.00
0005434824410	9920	Economy	28000.00
0005434824149	9920	Economy	28000.00
0005434824080	9920	Economy	28000.00
0005435374196	9920	Economy	28000.00
0005434824376	9920	Economy	28000.00
0005434824257	9920	Economy	28000.00
0005434824377	9920	Economy	28000.00
0005434824530	9920	Economy	28000.00
0005434824726	9920	Economy	28000.00
0005434824431	9920	Economy	28000.00
0005434824412	9920	Economy	28000.00
0005432396258	9920	Economy	28000.00
0005435374203	9920	Economy	28000.00
0005432203168	9920	Economy	28000.00
0005435374169	9920	Economy	28000.00
0005435374224	9920	Economy	28000.00
0005434824337	9920	Economy	28000.00
0005434824014	9920	Economy	28000.00
0005435735204	9920	Economy	28000.00
0005434824119	9920	Economy	28000.00
0005435150102	9920	Economy	28000.00
0005435374220	9920	Economy	28000.00
0005435386662	9920	Economy	28000.00
0005435386660	9920	Economy	28000.00
0005434824601	9920	Economy	28000.00
0005434824378	9920	Economy	28000.00
0005434824682	9920	Economy	28000.00
0005434824264	9920	Economy	28000.00
0005434823899	9920	Economy	28000.00
0005434824336	9920	Economy	28000.00
0005434824136	9920	Economy	28000.00
0005434824081	9920	Economy	28000.00
0005432203167	9920	Economy	28000.00
0005434823982	9920	Economy	28000.00
0005435386663	9920	Economy	28000.00
0005435374176	9920	Economy	28000.00
0005434824143	9920	Economy	28000.00
0005434824475	9920	Economy	28000.00
0005435374184	9920	Economy	28000.00
0005435374175	9920	Economy	28000.00
0005435374186	9920	Economy	28000.00
0005435374163	9920	Economy	28000.00
0005434824237	9920	Economy	28000.00
0005434823905	9920	Economy	28000.00
0005434824211	9920	Economy	28000.00
0005434824230	9920	Economy	28000.00
0005435374202	9920	Economy	28000.00
0005434823584	9920	Economy	28000.00
0005434824087	9920	Economy	28000.00
0005432203163	9920	Economy	28000.00
0005434824531	9920	Economy	28000.00
0005434825009	9920	Economy	28000.00
0005435374212	9920	Economy	28000.00
0005434824030	9920	Economy	28000.00
0005435150113	9920	Economy	28000.00
0005434824144	9920	Economy	28000.00
0005435386664	9920	Economy	28000.00
0005435374177	9920	Economy	28000.00
0005435374166	9920	Economy	28000.00
0005434824016	9920	Economy	28000.00
0005432400149	9920	Economy	28000.00
0005434823787	9920	Economy	28000.00
0005435374227	9920	Economy	28000.00
0005435386665	9920	Economy	28000.00
0005434558316	9920	Economy	28000.00
0005435374216	9920	Economy	28000.00
0005435374171	9920	Economy	28000.00
0005434824349	9920	Economy	28000.00
0005434824083	9920	Economy	28000.00
0005435374185	9920	Economy	28000.00
0005434824097	9920	Economy	28000.00
0005435082900	7004	Economy	8200.00
0005435082898	7004	Economy	8200.00
0005435082899	7004	Economy	7400.00
0005435790349	7004	Economy	7400.00
0005435082902	7004	Economy	7400.00
0005435790348	7004	Economy	7400.00
0005435082905	7004	Economy	7400.00
0005435082904	7004	Economy	7400.00
0005435082903	7004	Economy	7400.00
0005435082901	7004	Economy	7400.00
0005435790347	7004	Economy	7400.00
0005435082906	7004	Economy	7400.00
0005435082815	25977	Economy	7400.00
0005435790328	25977	Economy	7400.00
0005435790312	25977	Economy	7400.00
0005435082822	25977	Economy	7400.00
0005435082796	25977	Economy	7400.00
0005435082850	25977	Economy	7400.00
0005435082808	25977	Economy	7400.00
0005435790327	25977	Economy	7400.00
0005435082817	25977	Economy	7400.00
0005435790325	25977	Economy	7400.00
0005435082820	25977	Economy	7400.00
0005435082821	25977	Economy	7400.00
0005435082795	25977	Economy	7400.00
0005435790311	25977	Economy	7400.00
0005434214981	9535	Business	32800.00
0005434757050	9535	Business	32800.00
0005434757045	9535	Business	32800.00
0005434757035	9535	Business	32800.00
0005434757025	9535	Business	32800.00
0005434214798	9535	Business	32800.00
0005434214747	9535	Business	32800.00
0005434757008	9535	Business	32800.00
0005434214797	9535	Business	32800.00
0005434214789	9535	Business	32800.00
0005434757021	9535	Business	32800.00
0005434757023	9535	Economy	10900.00
0005434757020	9535	Economy	10900.00
0005434757037	9535	Economy	10900.00
0005434214700	9535	Economy	10900.00
0005434214763	9535	Economy	10900.00
0005434757022	9535	Economy	10900.00
0005434757016	9535	Economy	10900.00
0005434757017	9535	Economy	10900.00
0005434757014	9535	Economy	10900.00
0005434214647	9535	Economy	10900.00
0005434214980	9535	Economy	12000.00
0005434757038	9535	Economy	12000.00
0005434214787	9535	Economy	12000.00
0005434757046	9535	Economy	12000.00
0005434214899	9535	Economy	12000.00
0005434757024	9535	Economy	10900.00
0005434757041	9535	Economy	10900.00
0005434214715	9535	Economy	10900.00
0005434214753	9535	Economy	10900.00
0005434757019	9535	Economy	10900.00
0005434214664	9535	Economy	10900.00
0005434214675	9535	Economy	10900.00
0005434757015	9535	Economy	10900.00
0005434214825	9535	Economy	10900.00
0005434757042	9535	Economy	10900.00
0005434214572	9535	Economy	10900.00
0005434757043	9535	Economy	10900.00
0005434757031	9535	Economy	10900.00
0005434214683	9535	Economy	10900.00
0005434757033	9535	Economy	10900.00
0005434757047	9535	Economy	10900.00
0005434214676	9535	Economy	10900.00
0005434214894	9535	Economy	10900.00
0005434214666	9535	Economy	10900.00
0005434757036	9535	Economy	10900.00
0005434757039	9535	Economy	10900.00
0005434214670	9535	Economy	10900.00
0005434214816	9535	Economy	10900.00
0005434214712	9535	Economy	10900.00
0005434757013	9535	Economy	10900.00
0005434757048	9535	Economy	10900.00
0005434214748	9535	Economy	10900.00
0005434214743	9535	Economy	10900.00
0005434214582	9535	Economy	10900.00
0005434214684	9535	Economy	10900.00
0005434214742	9535	Economy	10900.00
0005434757012	9535	Economy	10900.00
0005434214673	9535	Economy	10900.00
0005434757051	9535	Economy	10900.00
0005434757007	9535	Economy	10900.00
0005434214605	9535	Economy	10900.00
0005434757044	9535	Economy	10900.00
0005434757011	9535	Economy	10900.00
0005434214665	9535	Economy	10900.00
0005434214674	9535	Economy	10900.00
0005434757028	9535	Economy	10900.00
0005434214717	9535	Economy	10900.00
0005434757010	9535	Economy	10900.00
0005434214947	9535	Economy	10900.00
0005434757040	9535	Economy	10900.00
0005434214750	9535	Economy	10900.00
0005434214749	9535	Economy	10900.00
0005434214926	9535	Economy	10900.00
0005434214571	9535	Economy	10900.00
0005434757027	9535	Economy	10900.00
0005434214626	9535	Economy	10900.00
0005434757029	9535	Economy	10900.00
0005434214713	9535	Economy	10900.00
0005434757052	9535	Economy	10900.00
0005434757009	9535	Economy	10900.00
0005434214603	9535	Economy	10900.00
0005434214778	9535	Economy	10900.00
0005434757049	9535	Economy	10900.00
0005434214788	9535	Economy	10900.00
0005434757030	9535	Economy	10900.00
0005434757032	9535	Economy	10900.00
0005434757034	9535	Economy	10900.00
0005434214604	9535	Economy	10900.00
0005434757018	9535	Economy	10900.00
0005434757026	9535	Economy	10900.00
0005434756404	28625	Business	32800.00
0005434756526	28625	Business	32800.00
0005434756651	28625	Business	32800.00
0005434215163	28625	Business	32800.00
0005434756570	28625	Business	32800.00
0005434215134	28625	Business	32800.00
0005434215158	28625	Business	32800.00
0005434215127	28625	Business	32800.00
0005434215150	28625	Business	32800.00
0005434756411	28625	Business	32800.00
0005434215162	28625	Business	32800.00
0005434215132	28625	Economy	10900.00
0005434756681	28625	Economy	10900.00
0005434756573	28625	Economy	10900.00
0005434756543	28625	Economy	10900.00
0005434215148	28625	Economy	10900.00
0005434756453	28625	Economy	10900.00
0005434756513	28625	Economy	10900.00
0005434215128	28625	Economy	10900.00
0005434756454	28625	Economy	10900.00
0005434215171	28625	Economy	12000.00
0005434756618	28625	Economy	12000.00
0005434215170	28625	Economy	12000.00
0005434215161	28625	Economy	12000.00
0005434215130	28625	Economy	12000.00
0005434215153	28625	Economy	10900.00
0005434215160	28625	Economy	10900.00
0005434756689	28625	Economy	10900.00
0005434215154	28625	Economy	10900.00
0005434215172	28625	Economy	10900.00
0005434756536	28625	Economy	10900.00
0005434756514	28625	Economy	10900.00
0005434215151	28625	Economy	10900.00
0005434756416	28625	Economy	10900.00
0005434215147	28625	Economy	10900.00
0005434215135	28625	Economy	10900.00
0005434215156	28625	Economy	10900.00
0005434756499	28625	Economy	10900.00
0005434215139	28625	Economy	10900.00
0005434756706	28625	Economy	10900.00
0005434215140	28625	Economy	10900.00
0005434215145	28625	Economy	10900.00
0005434756583	28625	Economy	10900.00
0005434215126	28625	Economy	10900.00
0005434215144	28625	Economy	10900.00
0005434756471	28625	Economy	10900.00
0005434756671	28625	Economy	10900.00
0005434756529	28625	Economy	10900.00
0005434215143	28625	Economy	10900.00
0005434215141	28625	Economy	10900.00
0005434756567	28625	Economy	10900.00
0005434756630	28625	Economy	10900.00
0005434756544	28625	Economy	10900.00
0005434756652	28625	Economy	10900.00
0005434756574	28625	Economy	10900.00
0005434756609	28625	Economy	10900.00
0005434756704	28625	Economy	10900.00
0005434756619	28625	Economy	10900.00
0005434756412	28625	Economy	10900.00
0005434756604	28625	Economy	10900.00
0005434215146	28625	Economy	10900.00
0005434215133	28625	Economy	10900.00
0005434756617	28625	Economy	10900.00
0005434215155	28625	Economy	10900.00
0005434756538	28625	Economy	10900.00
0005434756530	28625	Economy	10900.00
0005434756568	28625	Economy	10900.00
0005434756687	28625	Economy	10900.00
0005434215167	28625	Economy	10900.00
0005434215165	28625	Economy	10900.00
0005434215166	28625	Economy	10900.00
0005434756590	28625	Economy	10900.00
0005434215169	28625	Economy	10900.00
0005434215142	28625	Economy	10900.00
0005434756569	28625	Economy	10900.00
0005434756537	28625	Economy	10900.00
0005434756403	28625	Economy	10900.00
0005434756688	28625	Economy	10900.00
0005434756613	28625	Economy	10900.00
0005434215159	28625	Economy	10900.00
0005434215164	28625	Economy	10900.00
0005434756564	28625	Economy	10900.00
0005434215152	28625	Economy	10900.00
0005434215168	28625	Economy	10900.00
0005434215131	28625	Economy	10900.00
0005434215157	28625	Economy	10900.00
0005434215137	28625	Economy	10900.00
0005434756552	28625	Economy	10900.00
0005434215129	28625	Economy	10900.00
0005434756632	28625	Economy	10900.00
0005434215136	28625	Economy	10900.00
0005434215138	28625	Economy	10900.00
0005434215149	28625	Economy	10900.00
0005435100167	10819	Economy	8900.00
0005435100165	10819	Economy	8900.00
0005434760210	10819	Economy	8900.00
0005434760212	10819	Economy	8900.00
0005435100166	10819	Economy	8900.00
0005434760232	31803	Economy	8900.00
0005434760233	31803	Economy	8900.00
0005435100135	31803	Economy	8900.00
0005434760231	31803	Economy	8900.00
0005433202447	2005	Economy	20900.00
0005433202454	2005	Economy	20900.00
0005434639703	2005	Economy	19000.00
0005434639704	2005	Economy	19000.00
0005433202455	2005	Economy	19000.00
0005434639690	2005	Economy	19000.00
0005434639685	2005	Economy	19000.00
0005434639695	2005	Economy	19000.00
0005433202427	2005	Economy	19000.00
0005435948339	2005	Economy	19000.00
0005434639699	2005	Economy	19000.00
0005433202446	2005	Economy	19000.00
0005434639686	2005	Economy	19000.00
0005432290679	2005	Economy	19000.00
0005435948340	2005	Economy	19000.00
0005434639705	2005	Economy	19000.00
0005433202431	2005	Economy	19000.00
0005434639694	2005	Economy	19000.00
0005434639696	2005	Economy	19000.00
0005434639702	2005	Economy	19000.00
0005435948341	2005	Economy	19000.00
0005434639688	2005	Economy	19000.00
0005434639706	2005	Economy	19000.00
0005434639691	2005	Economy	19000.00
0005434639687	2005	Economy	19000.00
0005434639692	2005	Economy	19000.00
0005433202432	2005	Economy	19000.00
0005434639700	2005	Economy	19000.00
0005434639698	2005	Economy	19000.00
0005434639697	2005	Economy	19000.00
0005433202467	2005	Economy	19000.00
0005434639689	2005	Economy	19000.00
0005434639701	2005	Economy	19000.00
0005434639693	2005	Economy	19000.00
0005433202439	2005	Economy	19000.00
0005434639684	2005	Economy	19000.00
0005434639315	23278	Economy	20900.00
0005434639463	23278	Economy	20900.00
0005434639410	23278	Economy	20900.00
0005434639443	23278	Economy	20900.00
0005434639427	23278	Economy	19000.00
0005434639421	23278	Economy	19000.00
0005434639474	23278	Economy	19000.00
0005434639436	23278	Economy	19000.00
0005433202562	23278	Economy	19000.00
0005433202563	23278	Economy	19000.00
0005434639476	23278	Economy	19000.00
0005433202560	23278	Economy	19000.00
0005434639431	23278	Economy	19000.00
0005434639393	23278	Economy	19000.00
0005434639453	23278	Economy	19000.00
0005434639320	23278	Economy	19000.00
0005433202569	23278	Economy	19000.00
0005434639461	23278	Economy	19000.00
0005434639408	23278	Economy	19000.00
0005434639475	23278	Economy	19000.00
0005433202568	23278	Economy	19000.00
0005434639460	23278	Economy	19000.00
0005434639411	23278	Economy	19000.00
0005434639435	23278	Economy	19000.00
0005433202556	23278	Economy	19000.00
0005434639448	23278	Economy	19000.00
0005433202555	23278	Economy	19000.00
0005434639416	23278	Economy	19000.00
0005434639316	23278	Economy	19000.00
0005434639392	23278	Economy	19000.00
0005434639332	23278	Economy	19000.00
0005433202567	23278	Economy	19000.00
0005434639385	23278	Economy	19000.00
0005433202554	23278	Economy	19000.00
0005434639462	23278	Economy	19000.00
0005433202566	23278	Economy	19000.00
0005434639473	23278	Economy	19000.00
0005433202565	23278	Economy	19000.00
0005433202564	23278	Economy	19000.00
0005433202559	23278	Economy	19000.00
0005434639450	23278	Economy	19000.00
0005434639339	23278	Economy	19000.00
0005433202561	23278	Economy	19000.00
0005434639376	23278	Economy	19000.00
0005433202557	23278	Economy	19000.00
0005434639331	23278	Economy	19000.00
0005434639415	23278	Economy	19000.00
0005433202558	23278	Economy	19000.00
0005434639348	23278	Economy	19000.00
0005433531347	6067	Business	69700.00
0005435326837	6067	Business	69700.00
0005434601195	6067	Business	69700.00
0005433533363	6067	Business	69700.00
0005434601183	6067	Business	69700.00
0005435326853	6067	Business	69700.00
0005434601187	6067	Economy	23200.00
0005434601199	6067	Economy	23200.00
0005432111321	6067	Economy	23200.00
0005434601200	6067	Economy	23200.00
0005434601185	6067	Economy	23200.00
0005434601204	6067	Economy	23200.00
0005435326831	6067	Economy	23200.00
0005435326802	6067	Economy	25600.00
0005434601201	6067	Economy	25600.00
0005435326801	6067	Economy	23200.00
0005435326836	6067	Economy	23200.00
0005434601196	6067	Economy	23200.00
0005435326832	6067	Economy	23200.00
0005434601190	6067	Economy	23200.00
0005433531349	6067	Economy	23200.00
0005435326780	6067	Economy	23200.00
0005433533362	6067	Economy	23200.00
0005434601192	6067	Economy	23200.00
0005433533364	6067	Economy	23200.00
0005434601189	6067	Economy	23200.00
0005434601198	6067	Economy	23200.00
0005435326788	6067	Economy	23200.00
0005434601205	6067	Economy	23200.00
0005435326854	6067	Economy	23200.00
0005435326830	6067	Economy	23200.00
0005434601182	6067	Economy	23200.00
0005435326785	6067	Economy	23200.00
0005434601184	6067	Economy	23200.00
0005435326857	6067	Economy	23200.00
0005434601191	6067	Economy	23200.00
0005434601188	6067	Economy	23200.00
0005433531348	6067	Economy	23200.00
0005434601194	6067	Economy	23200.00
0005434601203	6067	Economy	23200.00
0005434601202	6067	Economy	23200.00
0005434601207	6067	Economy	23200.00
0005435326787	6067	Economy	23200.00
0005435326786	6067	Economy	23200.00
0005432111322	6067	Economy	23200.00
0005434601186	6067	Economy	23200.00
0005434601206	6067	Economy	23200.00
0005434601193	6067	Economy	23200.00
0005434601208	6067	Economy	23200.00
0005434601197	6067	Economy	23200.00
0005435326846	6067	Economy	23200.00
0005434601042	18567	Business	69700.00
0005435326940	18567	Business	69700.00
0005434600977	18567	Business	69700.00
0005433527280	18567	Business	69700.00
0005434600894	18567	Business	69700.00
0005433531317	18567	Business	69700.00
0005434600944	18567	Business	69700.00
0005435326948	18567	Economy	23200.00
0005434601028	18567	Economy	23200.00
0005433527292	18567	Economy	23200.00
0005434601058	18567	Economy	23200.00
0005435326947	18567	Economy	23200.00
0005435326950	18567	Economy	25600.00
0005434600968	18567	Economy	23200.00
0005434601036	18567	Economy	23200.00
0005435326943	18567	Economy	23200.00
0005434600985	18567	Economy	23200.00
0005434600922	18567	Economy	23200.00
0005435326942	18567	Economy	23200.00
0005434601012	18567	Economy	23200.00
0005435326949	18567	Economy	23200.00
0005435326945	18567	Economy	23200.00
0005434601033	18567	Economy	23200.00
0005434600914	18567	Economy	23200.00
0005435326946	18567	Economy	23200.00
0005434601001	18567	Economy	23200.00
0005434601007	18567	Economy	23200.00
0005433527281	18567	Economy	23200.00
0005434600984	18567	Economy	23200.00
0005434600976	18567	Economy	23200.00
0005434600883	18567	Economy	23200.00
0005435326944	18567	Economy	23200.00
0005434600986	18567	Economy	23200.00
0005434601040	18567	Economy	23200.00
0005434601010	18567	Economy	23200.00
0005434600945	18567	Economy	23200.00
0005434600917	18567	Economy	23200.00
0005435326939	18567	Economy	23200.00
0005434600837	18567	Economy	23200.00
0005435326951	18567	Economy	23200.00
0005434601041	18567	Economy	23200.00
0005433531316	18567	Economy	23200.00
0005434600872	18567	Economy	23200.00
0005433527278	18567	Economy	23200.00
0005434600834	18567	Economy	23200.00
0005434600832	18567	Economy	23200.00
0005434601015	18567	Economy	23200.00
0005435326941	18567	Economy	23200.00
0005433527279	18567	Economy	23200.00
0005434600916	18567	Economy	23200.00
0005434600838	18567	Economy	23200.00
0005434601018	18567	Economy	23200.00
0005434600893	18567	Economy	23200.00
0005435326938	18567	Economy	23200.00
0005434600868	18567	Economy	23200.00
0005434600975	18567	Economy	23200.00
0005434601062	18567	Economy	23200.00
0005434600833	18567	Economy	23200.00
0005434601017	18567	Economy	23200.00
0005434558389	10572	Business	9100.00
0005434558394	10572	Business	9100.00
0005433181172	10572	Business	9100.00
0005434551982	10572	Business	9100.00
0005433181114	10572	Business	9100.00
0005434558388	10572	Business	9100.00
0005434551974	10572	Business	9100.00
0005434558397	10572	Business	9100.00
0005433181148	10572	Business	9100.00
0005434558384	10572	Business	9100.00
0005434551985	10572	Business	9100.00
0005434551975	10572	Economy	3000.00
0005434551981	10572	Economy	3000.00
0005434551956	10572	Economy	3000.00
0005434551972	10572	Economy	3000.00
0005434551989	10572	Economy	3000.00
0005433181230	10572	Economy	3000.00
0005434551984	10572	Economy	3000.00
0005434558391	10572	Economy	3000.00
0005433181122	10572	Economy	3000.00
0005434551939	10572	Economy	3000.00
0005433181241	10572	Economy	3300.00
0005434551990	10572	Economy	3300.00
0005434551987	10572	Economy	3300.00
0005434551965	10572	Economy	3300.00
0005434551986	10572	Economy	3000.00
0005433181246	10572	Economy	3000.00
0005434551992	10572	Economy	3000.00
0005434551952	10572	Economy	3000.00
0005434551951	10572	Economy	3000.00
0005434551942	10572	Economy	3000.00
0005434551964	10572	Economy	3000.00
0005434554093	10572	Economy	3000.00
0005434551967	10572	Economy	3000.00
0005434551937	10572	Economy	3000.00
0005434551955	10572	Economy	3000.00
0005433181173	10572	Economy	3000.00
0005434551962	10572	Economy	3000.00
0005433181224	10572	Economy	3000.00
0005434551963	10572	Economy	3000.00
0005434551953	10572	Economy	3000.00
0005434551983	10572	Economy	3000.00
0005433181260	10572	Economy	3000.00
0005434551980	10572	Economy	3000.00
0005434558385	10572	Economy	3000.00
0005434551946	10572	Economy	3000.00
0005434558386	10572	Economy	3000.00
0005434551949	10572	Economy	3000.00
0005434551960	10572	Economy	3000.00
0005434551941	10572	Economy	3000.00
0005433181229	10572	Economy	3000.00
0005434551940	10572	Economy	3000.00
0005434558395	10572	Economy	3000.00
0005434551966	10572	Economy	3000.00
0005434551957	10572	Economy	3000.00
0005433181188	10572	Economy	3000.00
0005434551948	10572	Economy	3000.00
0005434551978	10572	Economy	3000.00
0005434558390	10572	Economy	3000.00
0005433181329	10572	Economy	3000.00
0005433181321	10572	Economy	3000.00
0005434551945	10572	Economy	3000.00
0005433181252	10572	Economy	3000.00
0005434551938	10572	Economy	3000.00
0005434551944	10572	Economy	3000.00
0005434551950	10572	Economy	3000.00
0005434551973	10572	Economy	3000.00
0005434551976	10572	Economy	3000.00
0005434551991	10572	Economy	3000.00
0005433181123	10572	Economy	3000.00
0005434551968	10572	Economy	3000.00
0005434551958	10572	Economy	3000.00
0005434551961	10572	Economy	3000.00
0005434551971	10572	Economy	3000.00
0005434551988	10572	Economy	3000.00
0005434551943	10572	Economy	3000.00
0005433181150	10572	Economy	3000.00
0005434551969	10572	Economy	3000.00
0005434558396	10572	Economy	3000.00
0005434558387	10572	Economy	3000.00
0005433181223	10572	Economy	3000.00
0005434558393	10572	Economy	3000.00
0005434551947	10572	Economy	3000.00
0005434551959	10572	Economy	3000.00
0005434558392	10572	Economy	3000.00
0005434551977	10572	Economy	3000.00
0005434558398	10572	Economy	3000.00
0005434551970	10572	Economy	3000.00
0005434551954	10572	Economy	3000.00
0005433181236	10572	Economy	3000.00
0005434551979	10572	Economy	3000.00
0005433181470	27734	Business	9100.00
0005433181454	27734	Economy	3000.00
0005433181456	27734	Economy	3300.00
0005433181464	27734	Economy	3300.00
0005433181449	27734	Economy	3300.00
0005433181466	27734	Economy	3000.00
0005433181461	27734	Economy	3000.00
0005433181468	27734	Economy	3000.00
0005433181467	27734	Economy	3000.00
0005433181469	27734	Economy	3000.00
0005433181462	27734	Economy	3000.00
0005433181465	27734	Economy	3000.00
0005433181458	27734	Economy	3000.00
0005433181451	27734	Economy	3000.00
0005433181472	27734	Economy	3000.00
0005433181455	27734	Economy	3000.00
0005433181475	27734	Economy	3000.00
0005433181463	27734	Economy	3000.00
0005433181452	27734	Economy	3000.00
0005433181473	27734	Economy	3000.00
0005433181450	27734	Economy	3000.00
0005433181459	27734	Economy	3000.00
0005433181460	27734	Economy	3000.00
0005433181471	27734	Economy	3000.00
0005433181453	27734	Economy	3000.00
0005433181474	27734	Economy	3000.00
0005433181457	27734	Economy	3000.00
0005434551522	27758	Business	9100.00
0005434551519	27758	Business	9100.00
0005434551352	27758	Business	9100.00
0005434551705	27758	Business	9100.00
0005434551208	27758	Business	9100.00
0005434558313	27758	Business	9100.00
0005434551562	27758	Business	9100.00
0005434551453	27758	Economy	3000.00
0005434551419	27758	Economy	3000.00
0005434551409	27758	Economy	3000.00
0005434551449	27758	Economy	3000.00
0005434551417	27758	Economy	3000.00
0005434554084	27758	Economy	3000.00
0005434551593	27758	Economy	3000.00
0005434551556	27758	Economy	3300.00
0005434558323	27758	Economy	3300.00
0005434551607	27758	Economy	3300.00
0005434551592	27758	Economy	3300.00
0005434558309	27758	Economy	3000.00
0005434551730	27758	Economy	3000.00
0005434551463	27758	Economy	3000.00
0005434551452	27758	Economy	3000.00
0005434551775	27758	Economy	3000.00
0005434551582	27758	Economy	3000.00
0005434551658	27758	Economy	3000.00
0005434551561	27758	Economy	3000.00
0005434551455	27758	Economy	3000.00
0005434551315	27758	Economy	3000.00
0005434558306	27758	Economy	3000.00
0005434551762	27758	Economy	3000.00
0005434554068	27758	Economy	3000.00
0005434551420	27758	Economy	3000.00
0005434551653	27758	Economy	3000.00
0005434558331	27758	Economy	3000.00
0005434554076	27758	Economy	3000.00
0005434558332	27758	Economy	3000.00
0005434551353	27758	Economy	3000.00
0005434551704	27758	Economy	3000.00
0005434551615	27758	Economy	3000.00
0005434558303	27758	Economy	3000.00
0005434551521	27758	Economy	3000.00
0005434558328	27758	Economy	3000.00
0005434551360	27758	Economy	3000.00
0005434551337	27758	Economy	3000.00
0005434551703	27758	Economy	3000.00
0005434558305	27758	Economy	3000.00
0005434551462	27758	Economy	3000.00
0005434551418	27758	Economy	3000.00
0005434551650	27758	Economy	3000.00
0005434558304	27758	Economy	3000.00
0005434551506	27758	Economy	3000.00
0005434551614	27758	Economy	3000.00
0005434551623	27758	Economy	3000.00
0005434551613	27758	Economy	3000.00
0005434558333	27758	Economy	3000.00
0005434551688	27758	Economy	3000.00
0005434558326	27758	Economy	3000.00
0005434558297	27758	Economy	3000.00
0005434551442	27758	Economy	3000.00
0005434551557	27758	Economy	3000.00
0005434551448	27758	Economy	3000.00
0005434551657	27758	Economy	3000.00
0005434558327	27758	Economy	3000.00
0005434558330	27758	Economy	3000.00
0005434558318	27758	Economy	3000.00
0005434551571	27758	Economy	3000.00
0005434551113	27758	Economy	3000.00
0005434551586	27758	Economy	3000.00
0005434551486	27758	Economy	3000.00
0005433459280	6125	Economy	11700.00
0005433459283	6125	Economy	11700.00
0005433459281	6125	Economy	11700.00
0005433459279	6125	Economy	11700.00
0005433459282	6125	Economy	11700.00
0005435254490	6125	Economy	11700.00
0005435254507	19328	Economy	11700.00
0005433459244	19328	Economy	11700.00
0005433459245	19328	Economy	11700.00
0005435254509	19328	Economy	11700.00
0005433459264	19328	Economy	11700.00
0005435254508	19328	Economy	11700.00
0005435682715	6721	Business	51100.00
0005432136239	6721	Business	51100.00
0005435682721	6721	Business	51100.00
0005435682694	6721	Business	51100.00
0005435661970	6721	Business	51100.00
0005432136238	6721	Business	51100.00
0005435682691	6721	Business	51100.00
0005435682695	6721	Business	51100.00
0005435682701	6721	Business	51100.00
0005435220326	6721	Business	51100.00
0005435682712	6721	Business	51100.00
0005435682703	6721	Economy	17000.00
0005435720146	6721	Economy	17000.00
0005435682693	6721	Economy	17000.00
0005435438058	6721	Economy	17000.00
0005435720144	6721	Economy	17000.00
0005435719575	6721	Economy	17000.00
0005435682707	6721	Economy	17000.00
0005435217729	6721	Economy	18700.00
0005435682692	6721	Economy	18700.00
0005435682714	6721	Economy	18700.00
0005435682709	6721	Economy	17000.00
0005435719577	6721	Economy	17000.00
0005435438186	6721	Economy	17000.00
0005435719574	6721	Economy	17000.00
0005435682705	6721	Economy	17000.00
0005435682704	6721	Economy	17000.00
0005435682696	6721	Economy	17000.00
0005435438119	6721	Economy	17000.00
0005435438033	6721	Economy	17000.00
0005435438092	6721	Economy	17000.00
0005435682718	6721	Economy	17000.00
0005435682713	6721	Economy	17000.00
0005435438046	6721	Economy	17000.00
0005435682685	6721	Economy	17000.00
0005435438038	6721	Economy	17000.00
0005435682702	6721	Economy	17000.00
0005435682699	6721	Economy	17000.00
0005435682720	6721	Economy	17000.00
0005435438093	6721	Economy	17000.00
0005435682719	6721	Economy	17000.00
0005435682698	6721	Economy	17000.00
0005435682717	6721	Economy	17000.00
0005435438079	6721	Economy	17000.00
0005435682687	6721	Economy	17000.00
0005435682683	6721	Economy	17000.00
0005435682706	6721	Economy	17000.00
0005435682700	6721	Economy	17000.00
0005435682682	6721	Economy	17000.00
0005435682697	6721	Economy	17000.00
0005435682688	6721	Economy	17000.00
0005435682708	6721	Economy	17000.00
0005435682710	6721	Economy	17000.00
0005435682689	6721	Economy	17000.00
0005435438014	6721	Economy	17000.00
0005432136240	6721	Economy	17000.00
0005435720145	6721	Economy	17000.00
0005435682711	6721	Economy	17000.00
0005435631009	6721	Economy	17000.00
0005435682690	6721	Economy	17000.00
0005435719573	6721	Economy	17000.00
0005435438037	6721	Economy	17000.00
0005435217730	6721	Economy	17000.00
0005432136242	6721	Economy	17000.00
0005435438128	6721	Economy	17000.00
0005435682722	6721	Economy	17000.00
0005435220327	6721	Economy	17000.00
0005435682684	6721	Economy	17000.00
0005435438120	6721	Economy	17000.00
0005435438113	6721	Economy	17000.00
0005435438145	6721	Economy	17000.00
0005432136241	6721	Economy	17000.00
0005435661971	6721	Economy	17000.00
0005435631008	6721	Economy	17000.00
0005435719576	6721	Economy	17000.00
0005435682686	6721	Economy	17000.00
0005435438141	6721	Economy	17000.00
0005435682716	6721	Economy	17000.00
0005435682396	24593	Business	51100.00
0005435682451	24593	Business	51100.00
0005432533333	24593	Business	51100.00
0005435682299	24593	Business	51100.00
0005435438268	24593	Business	51100.00
0005435682344	24593	Business	51100.00
0005435682381	24593	Business	51100.00
0005435682308	24593	Business	51100.00
0005435682266	24593	Business	51100.00
0005435682436	24593	Business	51100.00
0005435682386	24593	Business	51100.00
0005435682264	24593	Economy	17000.00
0005435682401	24593	Economy	17000.00
0005435682446	24593	Economy	17000.00
0005435438273	24593	Economy	17000.00
0005435682453	24593	Economy	17000.00
0005435219230	24593	Economy	17000.00
0005435682378	24593	Economy	17000.00
0005435438258	24593	Economy	17000.00
0005435438262	24593	Economy	17000.00
0005434828737	24593	Economy	18700.00
0005435682309	24593	Economy	18700.00
0005432533332	24593	Economy	18700.00
0005435438267	24593	Economy	18700.00
0005435630987	24593	Economy	18700.00
0005435682182	24593	Economy	17000.00
0005435682400	24593	Economy	17000.00
0005435438275	24593	Economy	17000.00
0005435438260	24593	Economy	17000.00
0005435682318	24593	Economy	17000.00
0005432533335	24593	Economy	17000.00
0005435682351	24593	Economy	17000.00
0005435682332	24593	Economy	17000.00
0005435438278	24593	Economy	17000.00
0005435220347	24593	Economy	17000.00
0005435220349	24593	Economy	17000.00
0005435438266	24593	Economy	17000.00
0005435682331	24593	Economy	17000.00
0005435438265	24593	Economy	17000.00
0005435682282	24593	Economy	17000.00
0005432305785	24593	Economy	17000.00
0005435682317	24593	Economy	17000.00
0005435438277	24593	Economy	17000.00
0005435682305	24593	Economy	17000.00
0005435219228	24593	Economy	17000.00
0005435682284	24593	Economy	17000.00
0005435682234	24593	Economy	17000.00
0005435682190	24593	Economy	17000.00
0005435682452	24593	Economy	17000.00
0005435682385	24593	Economy	17000.00
0005435682300	24593	Economy	17000.00
0005435438269	24593	Economy	17000.00
0005435438272	24593	Economy	17000.00
0005434828738	24593	Economy	17000.00
0005435682377	24593	Economy	17000.00
0005432533334	24593	Economy	17000.00
0005435438261	24593	Economy	17000.00
0005435438276	24593	Economy	17000.00
0005435630973	24593	Economy	17000.00
0005435438263	24593	Economy	17000.00
0005435438264	24593	Economy	17000.00
0005435682395	24593	Economy	17000.00
0005435438259	24593	Economy	17000.00
0005432305784	24593	Economy	17000.00
0005435682429	24593	Economy	17000.00
0005435682296	24593	Economy	17000.00
0005435682233	24593	Economy	17000.00
0005434828736	24593	Economy	17000.00
0005435219229	24593	Economy	17000.00
0005435682280	24593	Economy	17000.00
0005435438274	24593	Economy	17000.00
0005435220346	24593	Economy	17000.00
0005435682283	24593	Economy	17000.00
0005435682205	24593	Economy	17000.00
0005435220348	24593	Economy	17000.00
0005432305783	24593	Economy	17000.00
0005435682428	24593	Economy	17000.00
0005435219227	24593	Economy	17000.00
0005435682352	24593	Economy	17000.00
0005435630974	24593	Economy	17000.00
0005435438279	24593	Economy	17000.00
0005435438271	24593	Economy	17000.00
0005435438270	24593	Economy	17000.00
0005435126924	11527	Business	26400.00
0005435126928	11527	Business	26400.00
0005435126899	11527	Business	26400.00
0005435126902	11527	Business	26400.00
0005435126932	11527	Business	26400.00
0005435126918	11527	Business	26400.00
0005435126910	11527	Business	26400.00
0005435106027	11527	Business	26400.00
0005435126911	11527	Business	26400.00
0005435126903	11527	Economy	8800.00
0005435126917	11527	Economy	8800.00
0005435126937	11527	Economy	8800.00
0005435126916	11527	Economy	8800.00
0005435126919	11527	Economy	8800.00
0005435126923	11527	Economy	8800.00
0005435126925	11527	Economy	8800.00
0005435126907	11527	Economy	9700.00
0005435126929	11527	Economy	9700.00
0005435126927	11527	Economy	8800.00
0005435126922	11527	Economy	8800.00
0005435106024	11527	Economy	8800.00
0005435126908	11527	Economy	8800.00
0005435106026	11527	Economy	8800.00
0005435126933	11527	Economy	8800.00
0005435126900	11527	Economy	8800.00
0005435126901	11527	Economy	8800.00
0005435558105	11527	Economy	8800.00
0005435126898	11527	Economy	8800.00
0005435106025	11527	Economy	8800.00
0005435126913	11527	Economy	8800.00
0005435126915	11527	Economy	8800.00
0005435126897	11527	Economy	8800.00
0005435126921	11527	Economy	8800.00
0005435126905	11527	Economy	8800.00
0005435126934	11527	Economy	8800.00
0005435126909	11527	Economy	8800.00
0005435126926	11527	Economy	8800.00
0005435126904	11527	Economy	8800.00
0005435126930	11527	Economy	8800.00
0005435126936	11527	Economy	8800.00
0005435126906	11527	Economy	8800.00
0005435126914	11527	Economy	8800.00
0005435126931	11527	Economy	8800.00
0005435126920	11527	Economy	8800.00
0005435126935	11527	Economy	8800.00
0005435126912	11527	Economy	8800.00
0005435126828	31854	Business	26400.00
0005435126405	31854	Business	26400.00
0005435126715	31854	Business	26400.00
0005435126693	31854	Business	26400.00
0005435126677	31854	Economy	8800.00
0005435126494	31854	Economy	8800.00
0005435126642	31854	Economy	8800.00
0005435126645	31854	Economy	9700.00
0005435126716	31854	Economy	8800.00
0005435126608	31854	Economy	8800.00
0005435126682	31854	Economy	8800.00
0005435098561	31854	Economy	8800.00
0005435126658	31854	Economy	8800.00
0005435126537	31854	Economy	8800.00
0005435558124	31854	Economy	8800.00
0005435126630	31854	Economy	8800.00
0005435558125	31854	Economy	8800.00
0005435126623	31854	Economy	8800.00
0005435126614	31854	Economy	8800.00
0005435126627	31854	Economy	8800.00
0005435126814	31854	Economy	8800.00
0005435126535	31854	Economy	8800.00
0005435126776	31854	Economy	8800.00
0005435126504	31854	Economy	8800.00
0005435126394	31854	Economy	8800.00
0005435126404	31854	Economy	8800.00
0005435126564	31854	Economy	8800.00
0005435126726	31854	Economy	8800.00
0005435126714	31854	Economy	8800.00
0005435126683	31854	Economy	8800.00
0005435126708	31854	Economy	8800.00
0005435126753	31854	Economy	8800.00
0005435126624	31854	Economy	8800.00
0005435126268	31854	Economy	8800.00
0005435126709	31854	Economy	8800.00
0005435126637	31854	Economy	8800.00
0005435126665	31854	Economy	8800.00
0005435126648	31854	Economy	8800.00
0005435126613	31854	Economy	8800.00
0005435126752	31854	Economy	8800.00
0005435126536	31854	Economy	8800.00
0005435126684	31854	Economy	8800.00
0005435126615	31854	Economy	8800.00
0005435106006	31854	Economy	8800.00
0005433398764	13544	Business	36600.00
0005433398742	13544	Business	36600.00
0005433398726	13544	Business	36600.00
0005435732425	13544	Business	36600.00
0005433398732	13544	Business	36600.00
0005433398722	13544	Business	36600.00
0005433398753	13544	Business	36600.00
0005433398739	13544	Business	36600.00
0005433398758	13544	Business	36600.00
0005433398761	13544	Economy	12200.00
0005433398734	13544	Economy	12200.00
0005433398766	13544	Economy	12200.00
0005435732341	13544	Economy	12200.00
0005433398725	13544	Economy	12200.00
0005433398749	13544	Economy	13400.00
0005435732379	13544	Economy	13400.00
0005433398738	13544	Economy	13400.00
0005435732353	13544	Economy	13400.00
0005433398760	13544	Economy	12200.00
0005433398730	13544	Economy	12200.00
0005435732354	13544	Economy	12200.00
0005433398745	13544	Economy	12200.00
0005435732358	13544	Economy	12200.00
0005435732422	13544	Economy	12200.00
0005433398757	13544	Economy	12200.00
0005433398747	13544	Economy	12200.00
0005433398762	13544	Economy	12200.00
0005433398748	13544	Economy	12200.00
0005433398755	13544	Economy	12200.00
0005435732423	13544	Economy	12200.00
0005433398769	13544	Economy	12200.00
0005433398735	13544	Economy	12200.00
0005433398727	13544	Economy	12200.00
0005433398759	13544	Economy	12200.00
0005433398751	13544	Economy	12200.00
0005433398768	13544	Economy	12200.00
0005433398737	13544	Economy	12200.00
0005433398763	13544	Economy	12200.00
0005435732377	13544	Economy	12200.00
0005433398750	13544	Economy	12200.00
0005433398728	13544	Economy	12200.00
0005433398744	13544	Economy	12200.00
0005433398754	13544	Economy	12200.00
0005433398746	13544	Economy	12200.00
0005435732452	13544	Economy	12200.00
0005433398740	13544	Economy	12200.00
0005433398741	13544	Economy	12200.00
0005435732382	13544	Economy	12200.00
0005435732380	13544	Economy	12200.00
0005433398721	13544	Economy	12200.00
0005433398743	13544	Economy	12200.00
0005433398720	13544	Economy	12200.00
0005435732421	13544	Economy	12200.00
0005433398756	13544	Economy	12200.00
0005433398733	13544	Economy	12200.00
0005433398729	13544	Economy	12200.00
0005435732453	13544	Economy	12200.00
0005433398752	13544	Economy	12200.00
0005435732383	13544	Economy	12200.00
0005433398731	13544	Economy	12200.00
0005433398736	13544	Economy	12200.00
0005433398765	13544	Economy	12200.00
0005433398723	13544	Economy	12200.00
0005433398724	13544	Economy	12200.00
0005435732437	13544	Economy	12200.00
0005435732426	13544	Economy	12200.00
0005433398767	13544	Economy	12200.00
0005432297315	19400	Business	36600.00
0005433398409	19400	Business	36600.00
0005433398430	19400	Business	36600.00
0005433398271	19400	Business	36600.00
0005433398317	19400	Business	36600.00
0005433398201	19400	Business	36600.00
0005433398396	19400	Business	36600.00
0005433398384	19400	Business	36600.00
0005433398456	19400	Economy	12200.00
0005433398348	19400	Economy	12200.00
0005433398308	19400	Economy	12200.00
0005433398267	19400	Economy	12200.00
0005433398300	19400	Economy	12200.00
0005433398103	19400	Economy	12200.00
0005433398325	19400	Economy	12200.00
0005433398165	19400	Economy	13400.00
0005433398339	19400	Economy	13400.00
0005433398338	19400	Economy	13400.00
0005433398326	19400	Economy	12200.00
0005433398509	19400	Economy	12200.00
0005433398446	19400	Economy	12200.00
0005433398364	19400	Economy	12200.00
0005433398510	19400	Economy	12200.00
0005433398266	19400	Economy	12200.00
0005433398324	19400	Economy	12200.00
0005433398197	19400	Economy	12200.00
0005433398542	19400	Economy	12200.00
0005433398395	19400	Economy	12200.00
0005433398318	19400	Economy	12200.00
0005433398173	19400	Economy	12200.00
0005433398506	19400	Economy	12200.00
0005433398420	19400	Economy	12200.00
0005433398309	19400	Economy	12200.00
0005433398128	19400	Economy	12200.00
0005433398464	19400	Economy	12200.00
0005433398363	19400	Economy	12200.00
0005433398411	19400	Economy	12200.00
0005433398323	19400	Economy	12200.00
0005433398518	19400	Economy	12200.00
0005433398166	19400	Economy	12200.00
0005433398418	19400	Economy	12200.00
0005433398265	19400	Economy	12200.00
0005433398460	19400	Economy	12200.00
0005433398337	19400	Economy	12200.00
0005433398272	19400	Economy	12200.00
0005433398199	19400	Economy	12200.00
0005433398289	19400	Economy	12200.00
0005433398462	19400	Economy	12200.00
0005433398158	19400	Economy	12200.00
0005433398508	19400	Economy	12200.00
0005433398269	19400	Economy	12200.00
0005433398283	19400	Economy	12200.00
0005433398206	19400	Economy	12200.00
0005433398270	19400	Economy	12200.00
0005433398172	19400	Economy	12200.00
0005433398282	19400	Economy	12200.00
0005433398193	19400	Economy	12200.00
0005433398419	19400	Economy	12200.00
0005433398288	19400	Economy	12200.00
0005433398365	19400	Economy	12200.00
0005433398276	19400	Economy	12200.00
0005433398394	19400	Economy	12200.00
0005433398415	19400	Economy	12200.00
0005433398463	19400	Economy	12200.00
0005433398101	19400	Economy	12200.00
0005433398507	19400	Economy	12200.00
0005433398355	19400	Economy	12200.00
0005433398389	19400	Economy	12200.00
0005433398102	19400	Economy	12200.00
0005433398417	19400	Economy	12200.00
0005433398356	19400	Economy	12200.00
0005435069352	13160	Business	11300.00
0005435069356	13160	Business	11300.00
0005435069293	13160	Business	11300.00
0005435069341	13160	Business	11300.00
0005435069340	13160	Business	11300.00
0005435069549	13160	Business	11300.00
0005435069351	13160	Business	11300.00
0005435069419	13160	Business	11300.00
0005435069208	13160	Economy	3800.00
0005435069267	13160	Economy	3800.00
0005435069294	13160	Economy	3800.00
0005435069370	13160	Economy	3800.00
0005435069468	13160	Economy	3800.00
0005435925473	13160	Economy	4100.00
0005435069269	13160	Economy	4100.00
0005435069095	13160	Economy	3800.00
0005435069150	13160	Economy	3800.00
0005435069350	13160	Economy	3800.00
0005435069637	13160	Economy	3800.00
0005435069357	13160	Economy	3800.00
0005435069375	13160	Economy	3800.00
0005435069388	13160	Economy	3800.00
0005435069396	13160	Economy	3800.00
0005435069365	13160	Economy	3800.00
0005435925475	13160	Economy	3800.00
0005435925482	13160	Economy	3800.00
0005435069301	13160	Economy	3800.00
0005435069530	13160	Economy	3800.00
0005435925476	13160	Economy	3800.00
0005435925478	13160	Economy	3800.00
0005435925479	13160	Economy	3800.00
0005435069049	13160	Economy	3800.00
0005435925477	13160	Economy	3800.00
0005435925474	13160	Economy	3800.00
0005435069292	13160	Economy	3800.00
0005435069111	13160	Economy	3800.00
0005435069432	13160	Economy	3800.00
0005435069192	13160	Economy	3800.00
0005435069376	13160	Economy	3800.00
0005435069149	13160	Economy	3800.00
0005435069467	13160	Economy	3800.00
0005435069285	13160	Economy	3800.00
0005435069402	13160	Economy	3800.00
0005435069110	13160	Economy	3800.00
0005435925480	13160	Economy	3800.00
0005435069448	13160	Economy	3800.00
0005435069548	13160	Economy	3800.00
0005435069325	13160	Economy	3800.00
0005435069193	13160	Economy	3800.00
0005435069094	13160	Economy	3800.00
0005435069447	13160	Economy	3800.00
0005435069298	13160	Economy	3800.00
0005435069361	13160	Economy	3800.00
0005435069268	13160	Economy	3800.00
0005435069457	13160	Economy	3800.00
0005435925481	13160	Economy	3800.00
0005435069014	13160	Economy	3800.00
0005435069462	13160	Economy	3800.00
0005435069317	13160	Economy	3800.00
0005435925483	13160	Economy	3800.00
0005435925343	15490	Business	11300.00
0005435069773	15490	Business	11300.00
0005435069764	15490	Business	11300.00
0005435069771	15490	Business	11300.00
0005435069784	15490	Business	11300.00
0005435069782	15490	Business	11300.00
0005435069779	15490	Business	11300.00
0005435925384	15490	Business	11300.00
0005435069760	15490	Business	11300.00
0005435069754	15490	Economy	3800.00
0005435069762	15490	Economy	3800.00
0005435925375	15490	Economy	3800.00
0005435925385	15490	Economy	3800.00
0005435069800	15490	Economy	3800.00
0005435069794	15490	Economy	4100.00
0005435925326	15490	Economy	4100.00
0005435069759	15490	Economy	4100.00
0005435069769	15490	Economy	3800.00
0005435069755	15490	Economy	3800.00
0005435069791	15490	Economy	3800.00
0005435925327	15490	Economy	3800.00
0005435069786	15490	Economy	3800.00
0005435925455	15490	Economy	3800.00
0005435069774	15490	Economy	3800.00
0005435069793	15490	Economy	3800.00
0005435069753	15490	Economy	3800.00
0005435069785	15490	Economy	3800.00
0005435925401	15490	Economy	3800.00
0005435069749	15490	Economy	3800.00
0005435069787	15490	Economy	3800.00
0005435069789	15490	Economy	3800.00
0005435925342	15490	Economy	3800.00
0005435069757	15490	Economy	3800.00
0005435069758	15490	Economy	3800.00
0005435069756	15490	Economy	3800.00
0005435069770	15490	Economy	3800.00
0005435069796	15490	Economy	3800.00
0005435069778	15490	Economy	3800.00
0005435925371	15490	Economy	3800.00
0005435069780	15490	Economy	3800.00
0005435069750	15490	Economy	3800.00
0005435069766	15490	Economy	3800.00
0005435069798	15490	Economy	3800.00
0005435925379	15490	Economy	3800.00
0005435069783	15490	Economy	3800.00
0005435925344	15490	Economy	3800.00
0005435069795	15490	Economy	3800.00
0005435069775	15490	Economy	3800.00
0005435069751	15490	Economy	3800.00
0005435069776	15490	Economy	3800.00
0005435069772	15490	Economy	3800.00
0005435925454	15490	Economy	3800.00
0005435069792	15490	Economy	3800.00
0005435069797	15490	Economy	3800.00
0005435069777	15490	Economy	3800.00
0005435069768	15490	Economy	3800.00
0005435069752	15490	Economy	3800.00
0005435925341	15490	Economy	3800.00
0005435069790	15490	Economy	3800.00
0005435069761	15490	Economy	3800.00
0005435069799	15490	Economy	3800.00
0005435069767	15490	Economy	3800.00
0005435069781	15490	Economy	3800.00
0005435925378	15490	Economy	3800.00
0005435069763	15490	Economy	3800.00
0005435069788	15490	Economy	3800.00
0005435069765	15490	Economy	3800.00
0005435808381	23190	Economy	27100.00
0005433407569	23190	Economy	27100.00
0005433407576	23190	Economy	27100.00
0005435808380	23190	Economy	24700.00
0005433407556	23190	Economy	24700.00
0005435808376	23190	Economy	24700.00
0005435808364	23190	Economy	24700.00
0005435808362	23190	Economy	24700.00
0005435808373	23190	Economy	24700.00
0005433407557	23190	Economy	24700.00
0005433407593	23190	Economy	24700.00
0005435808368	23190	Economy	24700.00
0005435808360	23190	Economy	24700.00
0005435808377	23190	Economy	24700.00
0005435808378	23190	Economy	24700.00
0005433407575	23190	Economy	24700.00
0005435808375	23190	Economy	24700.00
0005435808363	23190	Economy	24700.00
0005435808379	23190	Economy	24700.00
0005435808374	23190	Economy	24700.00
0005435808369	23190	Economy	24700.00
0005433407570	23190	Economy	24700.00
0005435808372	23190	Economy	24700.00
0005435808365	23190	Economy	24700.00
0005433407558	23190	Economy	24700.00
0005435808361	23190	Economy	24700.00
0005433407594	23190	Economy	24700.00
0005435808371	23190	Economy	24700.00
0005435808367	23190	Economy	24700.00
0005433407592	23190	Economy	24700.00
0005435808366	23190	Economy	24700.00
0005435808370	23190	Economy	24700.00
0005434215199	10708	Business	61300.00
0005434215213	10708	Business	61300.00
0005434756674	10708	Business	61300.00
0005434215177	10708	Business	61300.00
0005434215181	10708	Business	61300.00
0005434756676	10708	Business	61300.00
0005434215185	10708	Business	61300.00
0005434756584	10708	Business	61300.00
0005434756657	10708	Business	61300.00
0005434756577	10708	Business	61300.00
0005434756576	10708	Business	61300.00
0005434756694	10708	Economy	20400.00
0005434756522	10708	Economy	20400.00
0005434756638	10708	Economy	20400.00
0005434215192	10708	Economy	20400.00
0005434215206	10708	Economy	20400.00
0005434215216	10708	Economy	20400.00
0005434215194	10708	Economy	20400.00
0005434215191	10708	Economy	20400.00
0005434215176	10708	Economy	20400.00
0005434756563	10708	Economy	22500.00
0005434756639	10708	Economy	22500.00
0005434756673	10708	Economy	22500.00
0005434215178	10708	Economy	22500.00
0005434756680	10708	Economy	22500.00
0005434215215	10708	Economy	20400.00
0005434756518	10708	Economy	20400.00
0005434756523	10708	Economy	20400.00
0005434215184	10708	Economy	20400.00
0005434756635	10708	Economy	20400.00
0005434756596	10708	Economy	20400.00
0005434756433	10708	Economy	20400.00
0005434215183	10708	Economy	20400.00
0005434756641	10708	Economy	20400.00
0005434756637	10708	Economy	20400.00
0005434215196	10708	Economy	20400.00
0005434215182	10708	Economy	20400.00
0005434215208	10708	Economy	20400.00
0005434215205	10708	Economy	20400.00
0005434215203	10708	Economy	20400.00
0005434215180	10708	Economy	20400.00
0005434215198	10708	Economy	20400.00
0005434215186	10708	Economy	20400.00
0005434756562	10708	Economy	20400.00
0005434215190	10708	Economy	20400.00
0005434215187	10708	Economy	20400.00
0005434215221	10708	Economy	20400.00
0005434756486	10708	Economy	20400.00
0005434756585	10708	Economy	20400.00
0005434756636	10708	Economy	20400.00
0005434215193	10708	Economy	20400.00
0005434756575	10708	Economy	20400.00
0005434215188	10708	Economy	20400.00
0005434215179	10708	Economy	20400.00
0005434756551	10708	Economy	20400.00
0005434215209	10708	Economy	20400.00
0005434215175	10708	Economy	20400.00
0005434215174	10708	Economy	20400.00
0005434215219	10708	Economy	20400.00
0005434756561	10708	Economy	20400.00
0005434215217	10708	Economy	20400.00
0005434215210	10708	Economy	20400.00
0005434756487	10708	Economy	20400.00
0005434756695	10708	Economy	20400.00
0005434756658	10708	Economy	20400.00
0005434756656	10708	Economy	20400.00
0005434215197	10708	Economy	20400.00
0005434215211	10708	Economy	20400.00
0005434215200	10708	Economy	20400.00
0005434756586	10708	Economy	20400.00
0005434756655	10708	Economy	20400.00
0005434215173	10708	Economy	20400.00
0005434756589	10708	Economy	20400.00
0005434215201	10708	Economy	20400.00
0005434756485	10708	Economy	20400.00
0005434756610	10708	Economy	20400.00
0005434215207	10708	Economy	20400.00
0005434215189	10708	Economy	20400.00
0005434756600	10708	Economy	20400.00
0005434756519	10708	Economy	20400.00
0005434756578	10708	Economy	20400.00
0005434215214	10708	Economy	20400.00
0005434756591	10708	Economy	20400.00
0005434215220	10708	Economy	20400.00
0005434756348	10708	Economy	20400.00
0005434215212	10708	Economy	20400.00
0005434215202	10708	Economy	20400.00
0005434756662	10708	Economy	20400.00
0005434215195	10708	Economy	20400.00
0005434756572	10708	Economy	20400.00
0005434215218	10708	Economy	20400.00
0005434215204	10708	Economy	20400.00
0005434756653	10708	Economy	20400.00
0005434214733	28681	Business	61300.00
0005434214642	28681	Business	61300.00
0005434214716	28681	Business	61300.00
0005434756972	28681	Business	61300.00
0005434756991	28681	Business	61300.00
0005434214734	28681	Business	61300.00
0005434757001	28681	Business	61300.00
0005434214644	28681	Business	61300.00
0005434756987	28681	Business	61300.00
0005434214641	28681	Business	61300.00
0005434756984	28681	Business	61300.00
0005434214847	28681	Business	61300.00
0005434214895	28681	Economy	20400.00
0005434214692	28681	Economy	20400.00
0005434756982	28681	Economy	20400.00
0005434756989	28681	Economy	20400.00
0005434214836	28681	Economy	20400.00
0005434214769	28681	Economy	20400.00
0005434214693	28681	Economy	20400.00
0005434756978	28681	Economy	20400.00
0005434756976	28681	Economy	20400.00
0005434756970	28681	Economy	22500.00
0005434214660	28681	Economy	22500.00
0005434214854	28681	Economy	22500.00
0005434757005	28681	Economy	22500.00
0005434757000	28681	Economy	22500.00
0005434214800	28681	Economy	20400.00
0005434756994	28681	Economy	20400.00
0005434214819	28681	Economy	20400.00
0005434756967	28681	Economy	20400.00
0005434214732	28681	Economy	20400.00
0005434756977	28681	Economy	20400.00
0005434214731	28681	Economy	20400.00
0005434756979	28681	Economy	20400.00
0005434756973	28681	Economy	20400.00
0005434756975	28681	Economy	20400.00
0005434214812	28681	Economy	20400.00
0005434757002	28681	Economy	20400.00
0005434214656	28681	Economy	20400.00
0005434756997	28681	Economy	20400.00
0005434757004	28681	Economy	20400.00
0005434214608	28681	Economy	20400.00
0005434756971	28681	Economy	20400.00
0005434756965	28681	Economy	20400.00
0005434756986	28681	Economy	20400.00
0005434214659	28681	Economy	20400.00
0005434214808	28681	Economy	20400.00
0005434756988	28681	Economy	20400.00
0005434756966	28681	Economy	20400.00
0005434214584	28681	Economy	20400.00
0005434214973	28681	Economy	20400.00
0005434214511	28681	Economy	20400.00
0005434757006	28681	Economy	20400.00
0005434756974	28681	Economy	20400.00
0005434214801	28681	Economy	20400.00
0005434756983	28681	Economy	20400.00
0005434214691	28681	Economy	20400.00
0005434214972	28681	Economy	20400.00
0005434214563	28681	Economy	20400.00
0005434756981	28681	Economy	20400.00
0005434214835	28681	Economy	20400.00
0005434756969	28681	Economy	20400.00
0005434756980	28681	Economy	20400.00
0005434214896	28681	Economy	20400.00
0005434756985	28681	Economy	20400.00
0005434756968	28681	Economy	20400.00
0005434756990	28681	Economy	20400.00
0005434214807	28681	Economy	20400.00
0005434214730	28681	Economy	20400.00
0005434214645	28681	Economy	20400.00
0005434756995	28681	Economy	20400.00
0005434757003	28681	Economy	20400.00
0005434214648	28681	Economy	20400.00
0005434214639	28681	Economy	20400.00
0005434756996	28681	Economy	20400.00
0005434214510	28681	Economy	20400.00
0005434214802	28681	Economy	20400.00
0005434214687	28681	Economy	20400.00
0005434756993	28681	Economy	20400.00
0005434214595	28681	Economy	20400.00
0005434214562	28681	Economy	20400.00
0005434756999	28681	Economy	20400.00
0005434214497	28681	Economy	20400.00
0005434214643	28681	Economy	20400.00
0005434756992	28681	Economy	20400.00
0005434214813	28681	Economy	20400.00
0005434214640	28681	Economy	20400.00
0005434756998	28681	Economy	20400.00
0005434229439	5441	Business	29500.00
0005432125558	5441	Business	29500.00
0005434229421	5441	Business	29500.00
0005434229540	5441	Business	29500.00
0005435040653	5441	Business	29500.00
0005434229494	5441	Business	29500.00
0005435040667	5441	Business	29500.00
0005435040683	5441	Business	29500.00
0005435040661	5441	Business	29500.00
0005435040674	5441	Business	29500.00
0005434229464	5441	Business	29500.00
0005435040666	5441	Business	29500.00
0005435007374	5441	Economy	9800.00
0005435040694	5441	Economy	9800.00
0005435040678	5441	Economy	9800.00
0005435040655	5441	Economy	9800.00
0005435040689	5441	Economy	9800.00
0005434229470	5441	Economy	9800.00
0005435007375	5441	Economy	9800.00
0005435040658	5441	Economy	9800.00
0005435007365	5441	Economy	9800.00
0005435040673	5441	Economy	9800.00
0005435040660	5441	Economy	9800.00
0005435007359	5441	Economy	9800.00
0005435040699	5441	Economy	9800.00
0005435040711	5441	Economy	9800.00
0005435040691	5441	Economy	9800.00
0005434229507	5441	Economy	9800.00
0005435040686	5441	Economy	9800.00
0005435007355	5441	Economy	9800.00
0005435040697	5441	Economy	9800.00
0005435040656	5441	Economy	9800.00
0005432125555	5441	Economy	9800.00
0005434229416	5441	Economy	9800.00
0005435007364	5441	Economy	9800.00
0005435040668	5441	Economy	9800.00
0005434229579	5441	Economy	9800.00
0005435040693	5441	Economy	9800.00
0005435040680	5441	Economy	9800.00
0005435007366	5441	Economy	9800.00
0005434229415	5441	Economy	9800.00
0005435040703	5441	Economy	9800.00
0005435040706	5441	Economy	9800.00
0005435040705	5441	Economy	9800.00
0005435040701	5441	Economy	9800.00
0005435040657	5441	Economy	9800.00
0005435007376	5441	Economy	9800.00
0005434229512	5441	Economy	9800.00
0005435040692	5441	Economy	9800.00
0005435007372	5441	Economy	9800.00
0005434229497	5441	Economy	9800.00
0005435007370	5441	Economy	9800.00
0005435040682	5441	Economy	10800.00
0005435040712	5441	Economy	10800.00
0005434229443	5441	Economy	10800.00
0005434229414	5441	Economy	10800.00
0005432125560	5441	Economy	10800.00
0005435040665	5441	Economy	10800.00
0005434229468	5441	Economy	9800.00
0005435040681	5441	Economy	9800.00
0005435040685	5441	Economy	9800.00
0005434229440	5441	Economy	9800.00
0005434229580	5441	Economy	9800.00
0005435007360	5441	Economy	9800.00
0005435007367	5441	Economy	9800.00
0005435040714	5441	Economy	9800.00
0005435040672	5441	Economy	9800.00
0005435040700	5441	Economy	9800.00
0005434229407	5441	Economy	9800.00
0005434229529	5441	Economy	9800.00
0005435040696	5441	Economy	9800.00
0005434229527	5441	Economy	9800.00
0005435040684	5441	Economy	9800.00
0005432125557	5441	Economy	9800.00
0005434229495	5441	Economy	9800.00
0005432125556	5441	Economy	9800.00
0005435040670	5441	Economy	9800.00
0005435040695	5441	Economy	9800.00
0005435040687	5441	Economy	9800.00
0005435040707	5441	Economy	9800.00
0005435040654	5441	Economy	9800.00
0005435007378	5441	Economy	9800.00
0005432125554	5441	Economy	9800.00
0005435040669	5441	Economy	9800.00
0005434229417	5441	Economy	9800.00
0005434229461	5441	Economy	9800.00
0005435040709	5441	Economy	9800.00
0005432125561	5441	Economy	9800.00
0005435040677	5441	Economy	9800.00
0005432125553	5441	Economy	9800.00
0005435007361	5441	Economy	9800.00
0005435040662	5441	Economy	9800.00
0005434229418	5441	Economy	9800.00
0005435040698	5441	Economy	9800.00
0005435040704	5441	Economy	9800.00
0005434229469	5441	Economy	9800.00
0005435007377	5441	Economy	9800.00
0005435040659	5441	Economy	9800.00
0005434229551	5441	Economy	9800.00
0005435040664	5441	Economy	9800.00
0005435040675	5441	Economy	9800.00
0005435040688	5441	Economy	9800.00
0005435007373	5441	Economy	9800.00
0005435007371	5441	Economy	9800.00
0005434229506	5441	Economy	9800.00
0005434229401	5441	Economy	9800.00
0005435040679	5441	Economy	9800.00
0005435007357	5441	Economy	9800.00
0005434229539	5441	Economy	9800.00
0005434229460	5441	Economy	9800.00
0005434229528	5441	Economy	9800.00
0005435007369	5441	Economy	9800.00
0005435007356	5441	Economy	9800.00
0005434229463	5441	Economy	9800.00
0005435007358	5441	Economy	9800.00
0005435040713	5441	Economy	9800.00
0005435040710	5441	Economy	9800.00
0005435040708	5441	Economy	9800.00
0005435007362	5441	Economy	9800.00
0005435007368	5441	Economy	9800.00
0005435007363	5441	Economy	9800.00
0005435040671	5441	Economy	9800.00
0005435007379	5441	Economy	9800.00
0005434229581	5441	Economy	9800.00
0005435040663	5441	Economy	9800.00
0005435040690	5441	Economy	9800.00
0005435040676	5441	Economy	9800.00
0005432125559	5441	Economy	9800.00
0005435040702	5441	Economy	9800.00
0005434229442	5441	Economy	9800.00
0005435039986	12983	Business	29500.00
0005435040013	12983	Business	29500.00
0005435042873	12983	Business	29500.00
0005435042872	12983	Business	29500.00
0005435039883	12983	Business	29500.00
0005434229693	12983	Business	29500.00
0005435040338	12983	Business	29500.00
0005435007241	12983	Business	29500.00
0005435040215	12983	Business	29500.00
0005435040041	12983	Business	29500.00
0005435040173	12983	Business	29500.00
0005435007120	12983	Economy	9800.00
0005435040270	12983	Economy	9800.00
0005432304453	12983	Economy	9800.00
0005435039716	12983	Economy	9800.00
0005432304452	12983	Economy	9800.00
0005435040085	12983	Economy	9800.00
0005435039907	12983	Economy	9800.00
0005434229702	12983	Economy	9800.00
0005435040292	12983	Economy	9800.00
0005435040133	12983	Economy	9800.00
0005435039885	12983	Economy	9800.00
0005435040217	12983	Economy	9800.00
0005435040310	12983	Economy	9800.00
0005435040092	12983	Economy	9800.00
0005435007239	12983	Economy	9800.00
0005434229684	12983	Economy	9800.00
0005435039967	12983	Economy	9800.00
0005434229689	12983	Economy	9800.00
0005435040210	12983	Economy	9800.00
0005435039882	12983	Economy	9800.00
0005435043286	12983	Economy	9800.00
0005435040440	12983	Economy	9800.00
0005435040202	12983	Economy	9800.00
0005435040015	12983	Economy	9800.00
0005435040141	12983	Economy	9800.00
0005435040160	12983	Economy	9800.00
0005435040306	12983	Economy	9800.00
0005434229697	12983	Economy	9800.00
0005435040228	12983	Economy	9800.00
0005435040125	12983	Economy	9800.00
0005435039776	12983	Economy	9800.00
0005435040370	12983	Economy	9800.00
0005432304457	12983	Economy	9800.00
0005434229694	12983	Economy	9800.00
0005435040244	12983	Economy	9800.00
0005434229704	12983	Economy	9800.00
0005435040223	12983	Economy	10800.00
0005435040214	12983	Economy	9800.00
0005434229696	12983	Economy	10800.00
0005434229686	12983	Economy	10800.00
0005435040307	12983	Economy	10800.00
0005435040172	12983	Economy	9800.00
0005435040297	12983	Economy	10800.00
0005435040237	12983	Economy	9800.00
0005434229695	12983	Economy	9800.00
0005435043287	12983	Economy	9800.00
0005435040333	12983	Economy	9800.00
0005432304456	12983	Economy	9800.00
0005435040415	12983	Economy	9800.00
0005434229703	12983	Economy	9800.00
0005435039828	12983	Economy	9800.00
0005435039975	12983	Economy	9800.00
0005435040051	12983	Economy	9800.00
0005435040124	12983	Economy	9800.00
0005434229701	12983	Economy	9800.00
0005435040364	12983	Economy	9800.00
0005435040098	12983	Economy	9800.00
0005435040189	12983	Economy	9800.00
0005435040040	12983	Economy	9800.00
0005434229698	12983	Economy	9800.00
0005434229692	12983	Economy	9800.00
0005434229685	12983	Economy	9800.00
0005434229688	12983	Economy	9800.00
0005434229690	12983	Economy	9800.00
0005435040004	12983	Economy	9800.00
0005434229687	12983	Economy	9800.00
0005435040216	12983	Economy	9800.00
0005434229700	12983	Economy	9800.00
0005435040093	12983	Economy	9800.00
0005435007142	12983	Economy	9800.00
0005432304454	12983	Economy	9800.00
0005435040178	12983	Economy	9800.00
0005435039985	12983	Economy	9800.00
0005435040339	12983	Economy	9800.00
0005435039884	12983	Economy	9800.00
0005435040001	12983	Economy	9800.00
0005435040131	12983	Economy	9800.00
0005435040251	12983	Economy	9800.00
0005435040245	12983	Economy	9800.00
0005434229699	12983	Economy	9800.00
0005435040293	12983	Economy	9800.00
0005435040332	12983	Economy	9800.00
0005435040351	12983	Economy	9800.00
0005435040065	12983	Economy	9800.00
0005435040066	12983	Economy	9800.00
0005435040014	12983	Economy	9800.00
0005435040099	12983	Economy	9800.00
0005435007122	12983	Economy	9800.00
0005435007240	12983	Economy	9800.00
0005435040152	12983	Economy	9800.00
0005432304455	12983	Economy	9800.00
0005434229705	12983	Economy	9800.00
0005435039983	12983	Economy	9800.00
0005435040159	12983	Economy	9800.00
0005434229691	12983	Economy	9800.00
0005435007158	12983	Economy	9800.00
0005434229683	12983	Economy	9800.00
0005435040120	12983	Economy	9800.00
0005435040227	12983	Economy	9800.00
0005435007189	12983	Economy	9800.00
0005435040309	12983	Economy	9800.00
0005435902765	14855	Business	52900.00
0005434411835	14855	Business	52900.00
0005434426995	14855	Business	52900.00
0005434427010	14855	Business	52900.00
0005435902762	14855	Business	52900.00
0005434427000	14855	Economy	17600.00
0005435902784	14855	Economy	17600.00
0005434427007	14855	Economy	17600.00
0005434426996	14855	Economy	17600.00
0005434426989	14855	Economy	17600.00
0005435902736	14855	Economy	19400.00
0005435902774	14855	Economy	19400.00
0005434427018	14855	Economy	17600.00
0005435554206	14855	Economy	17600.00
0005434411836	14855	Economy	17600.00
0005432188652	14855	Economy	17600.00
0005435902735	14855	Economy	17600.00
0005434427006	14855	Economy	17600.00
0005432188651	14855	Economy	17600.00
0005434427005	14855	Economy	17600.00
0005435902847	14855	Economy	17600.00
0005434426998	14855	Economy	17600.00
0005434427002	14855	Economy	17600.00
0005434427011	14855	Economy	17600.00
0005434426994	14855	Economy	17600.00
0005435554212	14855	Economy	17600.00
0005434426999	14855	Economy	17600.00
0005434427012	14855	Economy	17600.00
0005435902756	14855	Economy	17600.00
0005434426992	14855	Economy	17600.00
0005434426997	14855	Economy	17600.00
0005434427014	14855	Economy	17600.00
0005435902763	14855	Economy	17600.00
0005434427017	14855	Economy	17600.00
0005435902737	14855	Economy	17600.00
0005434427003	14855	Economy	17600.00
0005434427013	14855	Economy	17600.00
0005435902757	14855	Economy	17600.00
0005435902818	14855	Economy	17600.00
0005434426990	14855	Economy	17600.00
0005435902806	14855	Economy	17600.00
0005434427008	14855	Economy	17600.00
0005434427001	14855	Economy	17600.00
0005435902752	14855	Economy	17600.00
0005434411834	14855	Economy	17600.00
0005435902782	14855	Economy	17600.00
0005435902819	14855	Economy	17600.00
0005434427016	14855	Economy	17600.00
0005434427004	14855	Economy	17600.00
0005434411837	14855	Economy	17600.00
0005434426991	14855	Economy	17600.00
0005434427015	14855	Economy	17600.00
0005435902811	14855	Economy	17600.00
0005434426993	14855	Economy	17600.00
0005434427009	14855	Economy	17600.00
0005434426772	20204	Business	52900.00
0005434426784	20204	Business	52900.00
0005434426704	20204	Business	52900.00
0005434426730	20204	Business	52900.00
0005434411814	20204	Business	52900.00
0005434426810	20204	Business	52900.00
0005434426862	20204	Business	52900.00
0005432059532	20204	Business	52900.00
0005435902957	20204	Business	52900.00
0005434426789	20204	Business	52900.00
0005434426809	20204	Economy	17600.00
0005435902959	20204	Economy	17600.00
0005434426828	20204	Economy	17600.00
0005434426770	20204	Economy	17600.00
0005435902951	20204	Economy	19400.00
0005435902953	20204	Economy	19400.00
0005434411800	20204	Economy	19400.00
0005435902958	20204	Economy	17600.00
0005434426778	20204	Economy	17600.00
0005434426655	20204	Economy	17600.00
0005434426748	20204	Economy	17600.00
0005434426936	20204	Economy	17600.00
0005434426827	20204	Economy	17600.00
0005435902960	20204	Economy	17600.00
0005435902965	20204	Economy	17600.00
0005434426859	20204	Economy	17600.00
0005435554258	20204	Economy	17600.00
0005434426698	20204	Economy	17600.00
0005435902956	20204	Economy	17600.00
0005434426716	20204	Economy	17600.00
0005434426832	20204	Economy	17600.00
0005434426811	20204	Economy	17600.00
0005435902954	20204	Economy	17600.00
0005435902964	20204	Economy	17600.00
0005435554259	20204	Economy	17600.00
0005432059533	20204	Economy	17600.00
0005434426817	20204	Economy	17600.00
0005435554260	20204	Economy	17600.00
0005434426935	20204	Economy	17600.00
0005434426930	20204	Economy	17600.00
0005435554257	20204	Economy	17600.00
0005434426833	20204	Economy	17600.00
0005435902955	20204	Economy	17600.00
0005435902950	20204	Economy	17600.00
0005435902963	20204	Economy	17600.00
0005434426699	20204	Economy	17600.00
0005434426771	20204	Economy	17600.00
0005434426816	20204	Economy	17600.00
0005434426787	20204	Economy	17600.00
0005435902952	20204	Economy	17600.00
0005434426773	20204	Economy	17600.00
0005435902962	20204	Economy	17600.00
0005434426727	20204	Economy	17600.00
0005434426779	20204	Economy	17600.00
0005435902961	20204	Economy	17600.00
0005434426826	20204	Economy	17600.00
0005435902966	20204	Economy	17600.00
0005435554256	20204	Economy	17600.00
0005434426742	20204	Economy	17600.00
0005434426788	20204	Economy	17600.00
0005434426863	20204	Economy	17600.00
0005432462515	30885	Business	106800.00
0005434523806	30885	Business	106800.00
0005434523810	30885	Economy	35600.00
0005434523804	30885	Economy	35600.00
0005432462521	30885	Economy	35600.00
0005432462523	30885	Economy	35600.00
0005434523802	30885	Economy	35600.00
0005434523803	30885	Economy	39200.00
0005434523808	30885	Economy	35600.00
0005432462522	30885	Economy	35600.00
0005432462514	30885	Economy	35600.00
0005434523807	30885	Economy	35600.00
0005434523805	30885	Economy	35600.00
0005434523801	30885	Economy	35600.00
0005434523809	30885	Economy	35600.00
0005432462524	30885	Economy	35600.00
0005435982913	26555	Business	18500.00
0005435982919	26555	Business	18500.00
0005434270219	26555	Business	18500.00
0005435982903	26555	Business	18500.00
0005435982898	26555	Business	18500.00
0005433434839	26555	Business	18500.00
0005433434806	26555	Business	18500.00
0005435982907	26555	Business	18500.00
0005435982940	26555	Business	18500.00
0005432300341	26555	Economy	6200.00
0005435982902	26555	Economy	6200.00
0005433434861	26555	Economy	6200.00
0005433434845	26555	Economy	6200.00
0005435982928	26555	Economy	6200.00
0005435982923	26555	Economy	6200.00
0005432300342	26555	Economy	6200.00
0005433434847	26555	Economy	6800.00
0005433434846	26555	Economy	6800.00
0005435982920	26555	Economy	6800.00
0005435982933	26555	Economy	6800.00
0005433434812	26555	Economy	6200.00
0005435982918	26555	Economy	6200.00
0005432300339	26555	Economy	6200.00
0005433434870	26555	Economy	6200.00
0005435982924	26555	Economy	6200.00
0005433434862	26555	Economy	6200.00
0005433434811	26555	Economy	6200.00
0005433434797	26555	Economy	6200.00
0005433434868	26555	Economy	6200.00
0005435982938	26555	Economy	6200.00
0005435982914	26555	Economy	6200.00
0005435982927	26555	Economy	6200.00
0005435982904	26555	Economy	6200.00
0005435982916	26555	Economy	6200.00
0005433434741	26555	Economy	6200.00
0005435982895	26555	Economy	6200.00
0005433434805	26555	Economy	6200.00
0005435982906	26555	Economy	6200.00
0005435982905	26555	Economy	6200.00
0005435982932	26555	Economy	6200.00
0005432300343	26555	Economy	6200.00
0005435982937	26555	Economy	6200.00
0005435982935	26555	Economy	6200.00
0005434273088	26555	Economy	6200.00
0005435982912	26555	Economy	6200.00
0005435982909	26555	Economy	6200.00
0005435982939	26555	Economy	6200.00
0005435982922	26555	Economy	6200.00
0005433434776	26555	Economy	6200.00
0005435982908	26555	Economy	6200.00
0005435982921	26555	Economy	6200.00
0005435982931	26555	Economy	6200.00
0005435982910	26555	Economy	6200.00
0005435982899	26555	Economy	6200.00
0005435982894	26555	Economy	6200.00
0005435982929	26555	Economy	6200.00
0005433434863	26555	Economy	6200.00
0005435982926	26555	Economy	6200.00
0005435982917	26555	Economy	6200.00
0005433434787	26555	Economy	6200.00
0005432300344	26555	Economy	6200.00
0005432300340	26555	Economy	6200.00
0005435982915	26555	Economy	6200.00
0005433434723	26555	Economy	6200.00
0005435982925	26555	Economy	6200.00
0005433434869	26555	Economy	6200.00
0005435982930	26555	Economy	6200.00
0005435982897	26555	Economy	6200.00
0005433434838	26555	Economy	6200.00
0005433434810	26555	Economy	6200.00
0005435982900	26555	Economy	6200.00
0005435982934	26555	Economy	6200.00
0005433434837	26555	Economy	6200.00
0005433434742	26555	Economy	6200.00
0005435982896	26555	Economy	6200.00
0005433434786	26555	Economy	6200.00
0005435982936	26555	Economy	6200.00
0005435982911	26555	Economy	6200.00
0005435982901	26555	Economy	6200.00
0005435982627	26684	Business	18500.00
0005433435099	26684	Business	18500.00
0005433435085	26684	Business	18500.00
0005435982273	26684	Business	18500.00
0005435982522	26684	Business	18500.00
0005434269134	26684	Business	18500.00
0005433435097	26684	Business	18500.00
0005435982415	26684	Business	18500.00
0005435982673	26684	Business	18500.00
0005435982502	26684	Business	18500.00
0005435982618	26684	Economy	6200.00
0005435982478	26684	Economy	6200.00
0005432051174	26684	Economy	6200.00
0005435982574	26684	Economy	6200.00
0005433435090	26684	Economy	6200.00
0005435982690	26684	Economy	6200.00
0005433435084	26684	Economy	6200.00
0005435982431	26684	Economy	6200.00
0005435982430	26684	Economy	6200.00
0005433435091	26684	Economy	6800.00
0005433435080	26684	Economy	6800.00
0005433435087	26684	Economy	6800.00
0005433435079	26684	Economy	6800.00
0005433435072	26684	Economy	6200.00
0005435982703	26684	Economy	6200.00
0005435982639	26684	Economy	6200.00
0005433435095	26684	Economy	6200.00
0005435982559	26684	Economy	6200.00
0005432051173	26684	Economy	6200.00
0005435982514	26684	Economy	6200.00
0005433435077	26684	Economy	6200.00
0005434271341	26684	Economy	6200.00
0005435982496	26684	Economy	6200.00
0005433435075	26684	Economy	6200.00
0005433435082	26684	Economy	6200.00
0005435982491	26684	Economy	6200.00
0005435982524	26684	Economy	6200.00
0005433435089	26684	Economy	6200.00
0005433435078	26684	Economy	6200.00
0005435982713	26684	Economy	6200.00
0005433435092	26684	Economy	6200.00
0005435982473	26684	Economy	6200.00
0005435982498	26684	Economy	6200.00
0005435982497	26684	Economy	6200.00
0005435982272	26684	Economy	6200.00
0005433435074	26684	Economy	6200.00
0005433435100	26684	Economy	6200.00
0005433435096	26684	Economy	6200.00
0005435982370	26684	Economy	6200.00
0005435982504	26684	Economy	6200.00
0005435982555	26684	Economy	6200.00
0005435982499	26684	Economy	6200.00
0005434271342	26684	Economy	6200.00
0005435982582	26684	Economy	6200.00
0005434269133	26684	Economy	6200.00
0005433435076	26684	Economy	6200.00
0005433435093	26684	Economy	6200.00
0005433435101	26684	Economy	6200.00
0005435982634	26684	Economy	6200.00
0005433435073	26684	Economy	6200.00
0005435982468	26684	Economy	6200.00
0005434269132	26684	Economy	6200.00
0005435982584	26684	Economy	6200.00
0005433435094	26684	Economy	6200.00
0005433435088	26684	Economy	6200.00
0005435982712	26684	Economy	6200.00
0005435982302	26684	Economy	6200.00
0005433435098	26684	Economy	6200.00
0005435982640	26684	Economy	6200.00
0005435982585	26684	Economy	6200.00
0005435982523	26684	Economy	6200.00
0005435982554	26684	Economy	6200.00
0005435982510	26684	Economy	6200.00
0005435982714	26684	Economy	6200.00
0005432051172	26684	Economy	6200.00
0005433435086	26684	Economy	6200.00
0005435982521	26684	Economy	6200.00
0005433435083	26684	Economy	6200.00
0005433435081	26684	Economy	6200.00
0005435982556	26684	Economy	6200.00
0005435982380	26684	Economy	6200.00
0005435982503	26684	Economy	6200.00
0005432858168	3140	Economy	11100.00
0005432584406	3140	Economy	11100.00
0005432584395	3140	Economy	11100.00
0005432584404	3140	Economy	11100.00
0005432584383	3140	Economy	10100.00
0005432584392	3140	Economy	10100.00
0005432584385	3140	Economy	10100.00
0005432584407	3140	Economy	10100.00
0005432858091	3140	Economy	10100.00
0005432858109	3140	Economy	10100.00
0005432858148	3140	Economy	10100.00
0005432584382	3140	Economy	10100.00
0005432584391	3140	Economy	10100.00
0005432858118	3140	Economy	10100.00
0005432584386	3140	Economy	10100.00
0005432858160	3140	Economy	10100.00
0005432858184	3140	Economy	10100.00
0005432584389	3140	Economy	10100.00
0005432858201	3140	Economy	10100.00
0005432216313	3140	Economy	10100.00
0005432216312	3140	Economy	10100.00
0005432584402	3140	Economy	10100.00
0005432584400	3140	Economy	10100.00
0005432584388	3140	Economy	10100.00
0005432584399	3140	Economy	10100.00
0005432584393	3140	Economy	10100.00
0005432584384	3140	Economy	10100.00
0005432584390	3140	Economy	10100.00
0005432858124	3140	Economy	10100.00
0005432858153	3140	Economy	10100.00
0005432858152	3140	Economy	10100.00
0005432858147	3140	Economy	10100.00
0005432584401	3140	Economy	10100.00
0005432858076	3140	Economy	10100.00
0005432858129	3140	Economy	10100.00
0005432584387	3140	Economy	10100.00
0005432584403	3140	Economy	10100.00
0005432584394	3140	Economy	10100.00
0005432584397	3140	Economy	10100.00
0005432584396	3140	Economy	10100.00
0005432584398	3140	Economy	10100.00
0005432584408	3140	Economy	10100.00
0005432858119	3140	Economy	10100.00
0005432858106	3140	Economy	10100.00
0005432584405	3140	Economy	10100.00
0005432584103	31502	Economy	11100.00
0005432858237	31502	Economy	10100.00
0005432584269	31502	Economy	10100.00
0005432858246	31502	Economy	10100.00
0005432858248	31502	Economy	10100.00
0005432858244	31502	Economy	10100.00
0005432858242	31502	Economy	10100.00
0005432584264	31502	Economy	10100.00
0005432584165	31502	Economy	10100.00
0005432584323	31502	Economy	10100.00
0005432584232	31502	Economy	10100.00
0005432584268	31502	Economy	10100.00
0005432584069	31502	Economy	10100.00
0005432858247	31502	Economy	10100.00
0005432584179	31502	Economy	10100.00
0005432584213	31502	Economy	10100.00
0005432858235	31502	Economy	10100.00
0005432584191	31502	Economy	10100.00
0005432584178	31502	Economy	10100.00
0005432584217	31502	Economy	10100.00
0005432858241	31502	Economy	10100.00
0005432584122	31502	Economy	10100.00
0005432858245	31502	Economy	10100.00
0005432584083	31502	Economy	10100.00
0005432858238	31502	Economy	10100.00
0005432858239	31502	Economy	10100.00
0005432584170	31502	Economy	10100.00
0005432584130	31502	Economy	10100.00
0005432584231	31502	Economy	10100.00
0005432858240	31502	Economy	10100.00
0005432858243	31502	Economy	10100.00
0005432584056	31502	Economy	10100.00
0005432584250	31502	Economy	10100.00
0005432858236	31502	Economy	10100.00
0005432584263	31502	Economy	10100.00
0005432584218	31502	Economy	10100.00
0005434943480	898	Economy	8300.00
0005434943482	898	Economy	7500.00
0005434943485	898	Economy	7500.00
0005434943481	898	Economy	7500.00
0005434943479	898	Economy	7500.00
0005434943487	898	Economy	7500.00
0005433255156	898	Economy	7500.00
0005433255155	898	Economy	7500.00
0005434943486	898	Economy	7500.00
0005434943484	898	Economy	7500.00
0005434943483	898	Economy	7500.00
0005434943449	16218	Economy	8300.00
0005434943413	16218	Economy	7500.00
0005434943394	16218	Economy	7500.00
0005434943402	16218	Economy	7500.00
0005433255198	16218	Economy	7500.00
0005434943447	16218	Economy	7500.00
0005434943436	16218	Economy	7500.00
0005434943370	16218	Economy	7500.00
0005434943437	16218	Economy	7500.00
0005434943414	16218	Economy	7500.00
0005433255197	16218	Economy	7500.00
0005433255194	16218	Economy	7500.00
0005433255199	16218	Economy	7500.00
0005433255196	16218	Economy	7500.00
0005433255195	16218	Economy	7500.00
0005434943390	16218	Economy	7500.00
0005433255200	16218	Economy	7500.00
0005433654792	27616	Business	90500.00
0005435858613	27616	Business	90500.00
0005433654818	27616	Business	90500.00
0005435858615	27616	Business	90500.00
0005433654784	27616	Business	90500.00
0005435858609	27616	Business	90500.00
0005435858612	27616	Business	90500.00
0005435858621	27616	Business	90500.00
0005433654761	27616	Business	90500.00
0005433654766	27616	Business	90500.00
0005435858624	27616	Economy	30200.00
0005433654768	27616	Economy	30200.00
0005433654836	27616	Economy	30200.00
0005433654782	27616	Economy	30200.00
0005435858614	27616	Economy	30200.00
0005433654783	27616	Economy	30200.00
0005433654791	27616	Economy	33200.00
0005433654770	27616	Economy	33200.00
0005433654807	27616	Economy	33200.00
0005433654827	27616	Economy	30200.00
0005433654812	27616	Economy	30200.00
0005435858611	27616	Economy	30200.00
0005433654765	27616	Economy	30200.00
0005433654819	27616	Economy	30200.00
0005435858622	27616	Economy	30200.00
0005433654760	27616	Economy	30200.00
0005433654795	27616	Economy	30200.00
0005433654785	27616	Economy	30200.00
0005433654799	27616	Economy	30200.00
0005433654797	27616	Economy	30200.00
0005435858618	27616	Economy	30200.00
0005435858610	27616	Economy	30200.00
0005435858616	27616	Economy	30200.00
0005433654790	27616	Economy	30200.00
0005433654796	27616	Economy	30200.00
0005435858623	27616	Economy	30200.00
0005433654813	27616	Economy	30200.00
0005435858625	27616	Economy	30200.00
0005435858608	27616	Economy	30200.00
0005433654793	27616	Economy	30200.00
0005433654839	27616	Economy	30200.00
0005433654802	27616	Economy	30200.00
0005433654779	27616	Economy	30200.00
0005433654803	27616	Economy	30200.00
0005433654804	27616	Economy	30200.00
0005433654833	27616	Economy	30200.00
0005435858617	27616	Economy	30200.00
0005433654798	27616	Economy	30200.00
0005433654808	27616	Economy	30200.00
0005433654821	27616	Economy	30200.00
0005435858619	27616	Economy	30200.00
0005435858620	27616	Economy	30200.00
0005433654769	27616	Economy	30200.00
0005433654817	27616	Economy	30200.00
0005433811639	14335	Economy	4400.00
0005435653632	21767	Business	9800.00
0005433368009	21767	Business	9800.00
0005435653617	21767	Business	9800.00
0005433367992	21767	Business	9800.00
0005433367993	21767	Business	9800.00
0005435653620	21767	Business	9800.00
0005435653621	21767	Business	9800.00
0005435653651	21767	Business	9800.00
0005435653645	21767	Business	9800.00
0005433368113	21767	Business	9800.00
0005433368025	21767	Business	9800.00
0005435653626	21767	Economy	3300.00
0005435653614	21767	Economy	3300.00
0005433368067	21767	Economy	3300.00
0005435653627	21767	Economy	3300.00
0005433367872	21767	Economy	3300.00
0005435653637	21767	Economy	3300.00
0005433368083	21767	Economy	3300.00
0005433368201	21767	Economy	3300.00
0005435653636	21767	Economy	3300.00
0005433368084	21767	Economy	3600.00
0005435653655	21767	Economy	3600.00
0005435653653	21767	Economy	3600.00
0005435653642	21767	Economy	3600.00
0005433367958	21767	Economy	3300.00
0005433368085	21767	Economy	3300.00
0005433367970	21767	Economy	3300.00
0005435653649	21767	Economy	3300.00
0005435653635	21767	Economy	3300.00
0005433368105	21767	Economy	3300.00
0005435653641	21767	Economy	3300.00
0005435653640	21767	Economy	3300.00
0005433368042	21767	Economy	3300.00
0005435653646	21767	Economy	3300.00
0005435653625	21767	Economy	3300.00
0005435653623	21767	Economy	3300.00
0005433368043	21767	Economy	3300.00
0005435653618	21767	Economy	3300.00
0005433368024	21767	Economy	3300.00
0005435653639	21767	Economy	3300.00
0005435653643	21767	Economy	3300.00
0005435653633	21767	Economy	3300.00
0005435653622	21767	Economy	3300.00
0005435653619	21767	Economy	3300.00
0005435653650	21767	Economy	3300.00
0005433368111	21767	Economy	3300.00
0005435653654	21767	Economy	3300.00
0005435653644	21767	Economy	3300.00
0005435653616	21767	Economy	3300.00
0005435653630	21767	Economy	3300.00
0005433368192	21767	Economy	3300.00
0005435653652	21767	Economy	3300.00
0005433367972	21767	Economy	3300.00
0005433368238	21767	Economy	3300.00
0005433368066	21767	Economy	3300.00
0005433367982	21767	Economy	3300.00
0005435653624	21767	Economy	3300.00
0005433367871	21767	Economy	3300.00
0005433368211	21767	Economy	3300.00
0005433367971	21767	Economy	3300.00
0005435653629	21767	Economy	3300.00
0005433367995	21767	Economy	3300.00
0005435653615	21767	Economy	3300.00
0005435653611	21767	Economy	3300.00
0005433367994	21767	Economy	3300.00
0005433368202	21767	Economy	3300.00
0005435653613	21767	Economy	3300.00
0005433367996	21767	Economy	3300.00
0005435653631	21767	Economy	3300.00
0005433368196	21767	Economy	3300.00
0005435653638	21767	Economy	3300.00
0005435653634	21767	Economy	3300.00
0005433368112	21767	Economy	3300.00
0005435653612	21767	Economy	3300.00
0005435653648	21767	Economy	3300.00
0005433368073	21767	Economy	3300.00
0005435653647	21767	Economy	3300.00
0005433368023	21767	Economy	3300.00
0005433367959	21767	Economy	3300.00
0005435653628	21767	Economy	3300.00
0005432667483	9337	Business	186200.00
0005433805855	9337	Business	186200.00
0005433805864	9337	Business	186200.00
0005433763409	9337	Business	186200.00
0005433805869	9337	Business	186200.00
0005433763410	9337	Business	186200.00
0005433805856	9337	Business	186200.00
0005433805863	9337	Business	186200.00
0005433805858	9337	Business	186200.00
0005433805848	9337	Business	186200.00
0005432665305	9337	Business	186200.00
0005433785454	9337	Business	186200.00
0005433763420	9337	Business	186200.00
0005432665304	9337	Business	186200.00
0005433785452	9337	Business	186200.00
0005434171142	9337	Business	186200.00
0005433785471	9337	Business	186200.00
0005433785457	9337	Business	186200.00
0005433805870	9337	Economy	62100.00
0005432666418	9337	Economy	62100.00
0005433785481	9337	Economy	62100.00
0005433805861	9337	Economy	62100.00
0005433785465	9337	Economy	62100.00
0005433805860	9337	Economy	62100.00
0005433805873	9337	Economy	62100.00
0005434270225	9337	Economy	62100.00
0005434270215	9337	Economy	62100.00
0005433763415	9337	Economy	62100.00
0005433805853	9337	Economy	62100.00
0005434171141	9337	Economy	62100.00
0005433805854	9337	Economy	62100.00
0005433785474	9337	Economy	62100.00
0005434171098	9337	Economy	62100.00
0005434151730	9337	Economy	62100.00
0005433763407	9337	Economy	62100.00
0005433785468	9337	Economy	62100.00
0005433805868	9337	Economy	62100.00
0005433785479	9337	Economy	62100.00
0005433785464	9337	Economy	62100.00
0005433763411	9337	Economy	62100.00
0005433805847	9337	Economy	62100.00
0005433763413	9337	Economy	62100.00
0005433805851	9337	Economy	62100.00
0005433805872	9337	Economy	62100.00
0005433805874	9337	Economy	62100.00
0005433785458	9337	Economy	62100.00
0005434273095	9337	Economy	62100.00
0005433805859	9337	Economy	62100.00
0005433785450	9337	Economy	62100.00
0005434171132	9337	Economy	62100.00
0005433805875	9337	Economy	62100.00
0005433785467	9337	Economy	62100.00
0005434171127	9337	Economy	62100.00
0005433763412	9337	Economy	62100.00
0005433763414	9337	Economy	62100.00
0005433763416	9337	Economy	62100.00
0005433805857	9337	Economy	62100.00
0005433785461	9337	Economy	62100.00
0005433785472	9337	Economy	62100.00
0005433763419	9337	Economy	62100.00
0005433805865	9337	Economy	62100.00
0005433763421	9337	Economy	62100.00
0005433805867	9337	Economy	62100.00
0005433785480	9337	Economy	62100.00
0005433785476	9337	Economy	62100.00
0005433785449	9337	Economy	62100.00
0005433785460	9337	Economy	68300.00
0005432666417	9337	Economy	68300.00
0005433763408	9337	Economy	68300.00
0005433785455	9337	Economy	62100.00
0005433785469	9337	Economy	62100.00
0005433785478	9337	Economy	62100.00
0005432657493	9337	Economy	62100.00
0005434270216	9337	Economy	62100.00
0005433805850	9337	Economy	62100.00
0005433805871	9337	Economy	62100.00
0005434171143	9337	Economy	62100.00
0005433805852	9337	Economy	62100.00
0005432665303	9337	Economy	62100.00
0005432667484	9337	Economy	62100.00
0005433805849	9337	Economy	62100.00
0005433785475	9337	Economy	62100.00
0005433805878	9337	Economy	62100.00
0005433805879	9337	Economy	62100.00
0005433785462	9337	Economy	62100.00
0005433785456	9337	Economy	62100.00
0005432657492	9337	Economy	62100.00
0005433785473	9337	Economy	62100.00
0005433805876	9337	Economy	62100.00
0005434171128	9337	Economy	62100.00
0005433785451	9337	Economy	62100.00
0005433805866	9337	Economy	62100.00
0005433785463	9337	Economy	62100.00
0005433785466	9337	Economy	62100.00
0005432667485	9337	Economy	62100.00
0005433785453	9337	Economy	62100.00
0005433763418	9337	Economy	62100.00
0005433785477	9337	Economy	62100.00
0005432657494	9337	Economy	62100.00
0005434171133	9337	Economy	62100.00
0005433763417	9337	Economy	62100.00
0005433805877	9337	Economy	62100.00
0005433785470	9337	Economy	62100.00
0005432666419	9337	Economy	62100.00
0005433785482	9337	Economy	62100.00
0005433805862	9337	Economy	62100.00
0005433785459	9337	Economy	62100.00
0005433805575	26224	Business	186200.00
0005433805659	26224	Business	186200.00
0005433805539	26224	Business	186200.00
0005433805481	26224	Business	186200.00
0005435269871	26224	Business	186200.00
0005433805474	26224	Business	186200.00
0005434271340	26224	Business	186200.00
0005433805628	26224	Business	186200.00
0005434171254	26224	Business	186200.00
0005433785179	26224	Business	186200.00
0005432657464	26224	Business	186200.00
0005433805682	26224	Business	186200.00
0005432663049	26224	Business	186200.00
0005433805645	26224	Business	186200.00
0005434271339	26224	Business	186200.00
0005433785143	26224	Business	186200.00
0005434171256	26224	Economy	68300.00
0005432659716	26224	Economy	68300.00
0005433805611	26224	Economy	68300.00
0005433805410	26224	Economy	62100.00
0005433785218	26224	Economy	62100.00
0005433785259	26224	Economy	62100.00
0005433785308	26224	Economy	62100.00
0005433763220	26224	Economy	62100.00
0005433785018	26224	Economy	62100.00
0005433785212	26224	Economy	62100.00
0005433785145	26224	Economy	62100.00
0005433785103	26224	Economy	62100.00
0005433785147	26224	Economy	62100.00
0005433785178	26224	Economy	62100.00
0005434270236	26224	Economy	62100.00
0005432666399	26224	Economy	62100.00
0005433805677	26224	Economy	62100.00
0005433805520	26224	Economy	62100.00
0005433805533	26224	Economy	62100.00
0005433805470	26224	Economy	62100.00
0005434171265	26224	Economy	62100.00
0005434151747	26224	Economy	62100.00
0005432666390	26224	Economy	62100.00
0005435269869	26224	Economy	62100.00
0005434151745	26224	Economy	62100.00
0005433785187	26224	Economy	62100.00
0005433805519	26224	Economy	62100.00
0005433805527	26224	Economy	62100.00
0005434270235	26224	Economy	62100.00
0005433763249	26224	Economy	62100.00
0005433763326	26224	Economy	62100.00
0005433785217	26224	Economy	62100.00
0005433805482	26224	Economy	62100.00
0005433785007	26224	Economy	62100.00
0005433805598	26224	Economy	62100.00
0005432659718	26224	Economy	62100.00
0005433763291	26224	Economy	62100.00
0005433805621	26224	Economy	62100.00
0005433785198	26224	Economy	62100.00
0005433763344	26224	Economy	62100.00
0005434151746	26224	Economy	62100.00
0005435269873	26224	Economy	62100.00
0005433805534	26224	Economy	62100.00
0005434171260	26224	Economy	62100.00
0005434171253	26224	Economy	62100.00
0005433763277	26224	Economy	62100.00
0005433805585	26224	Economy	62100.00
0005433763343	26224	Economy	62100.00
0005433785080	26224	Economy	62100.00
0005433805620	26224	Economy	62100.00
0005433805683	26224	Economy	62100.00
0005433784965	26224	Economy	62100.00
0005433805584	26224	Economy	62100.00
0005433805473	26224	Economy	62100.00
0005433805655	26224	Economy	62100.00
0005434171266	26224	Economy	62100.00
0005433805656	26224	Economy	62100.00
0005433805614	26224	Economy	62100.00
0005433805619	26224	Economy	62100.00
0005432657462	26224	Economy	62100.00
0005435269870	26224	Economy	62100.00
0005435269872	26224	Economy	62100.00
0005433805624	26224	Economy	62100.00
0005433763276	26224	Economy	62100.00
0005434171264	26224	Economy	62100.00
0005432666389	26224	Economy	62100.00
0005432663050	26224	Economy	62100.00
0005433763335	26224	Economy	62100.00
0005433785020	26224	Economy	62100.00
0005433805615	26224	Economy	68300.00
0005433763311	26224	Economy	62100.00
0005433805591	26224	Economy	62100.00
0005433785203	26224	Economy	62100.00
0005434270237	26224	Economy	68300.00
0005433805623	26224	Economy	62100.00
0005433785301	26224	Economy	62100.00
0005433763280	26224	Economy	62100.00
0005432666388	26224	Economy	62100.00
0005432657451	26224	Economy	62100.00
0005433785128	26224	Economy	62100.00
0005433805657	26224	Economy	62100.00
0005433763296	26224	Economy	62100.00
0005433763221	26224	Economy	62100.00
0005433805644	26224	Economy	62100.00
0005433805509	26224	Economy	62100.00
0005434171261	26224	Economy	62100.00
0005433805678	26224	Economy	62100.00
0005433785019	26224	Economy	62100.00
0005434151744	26224	Economy	62100.00
0005433785102	26224	Economy	62100.00
0005433785082	26224	Economy	62100.00
0005434171257	26224	Economy	62100.00
0005433805610	26224	Economy	62100.00
0005433785126	26224	Economy	62100.00
0005434269131	26224	Economy	62100.00
0005433805556	26224	Economy	62100.00
0005433805550	26224	Economy	62100.00
0005433763281	26224	Economy	62100.00
0005433805372	26224	Economy	62100.00
0005434171258	26224	Economy	62100.00
0005433805518	26224	Economy	62100.00
0005433785302	26224	Economy	62100.00
0005434171259	26224	Economy	62100.00
0005433805564	26224	Economy	62100.00
0005433785081	26224	Economy	62100.00
0005433805653	26224	Economy	62100.00
0005433805358	26224	Economy	62100.00
0005433805526	26224	Economy	62100.00
0005433785016	26224	Economy	62100.00
0005433785101	26224	Economy	62100.00
0005433805599	26224	Economy	62100.00
0005434171263	26224	Economy	62100.00
0005433785060	26224	Economy	62100.00
0005433785017	26224	Economy	62100.00
0005433805573	26224	Economy	62100.00
0005434171255	26224	Economy	62100.00
0005432659717	26224	Economy	62100.00
0005432666404	26224	Economy	62100.00
0005434269130	26224	Economy	62100.00
0005434171262	26224	Economy	62100.00
0005433785138	26224	Economy	62100.00
0005435135738	4915	Economy	5900.00
0005435135740	4915	Economy	5900.00
0005435929658	4915	Economy	5300.00
0005435929657	4915	Economy	5300.00
0005435135741	4915	Economy	5300.00
0005435929661	4915	Economy	5300.00
0005435135739	4915	Economy	5300.00
0005435135742	4915	Economy	5300.00
0005435135706	33043	Economy	5900.00
0005435929682	33043	Economy	5900.00
0005435929684	33043	Economy	5300.00
0005435929681	33043	Economy	5300.00
0005435135701	33043	Economy	5300.00
0005435135712	33043	Economy	5300.00
0005435135679	33043	Economy	5300.00
0005435135677	33043	Economy	5300.00
0005435135703	33043	Economy	5300.00
0005435929683	33043	Economy	5300.00
0005435135678	33043	Economy	5300.00
0005435135713	33043	Economy	5300.00
0005434983360	9485	Economy	19700.00
0005434983362	9485	Economy	17900.00
0005434983363	9485	Economy	17900.00
0005434217987	9485	Economy	17900.00
0005434217986	9485	Economy	17900.00
0005434983361	9485	Economy	17900.00
0005434218028	27343	Economy	17900.00
0005434983328	27343	Economy	17900.00
0005434983305	27343	Economy	17900.00
0005434983307	27343	Economy	17900.00
0005434983321	27343	Economy	17900.00
0005434218029	27343	Economy	17900.00
0005434983325	27343	Economy	17900.00
0005434983306	27343	Economy	17900.00
0005434983322	27343	Economy	17900.00
0005434983320	27343	Economy	17900.00
0005434983329	27343	Economy	17900.00
0005433960964	24264	Business	36400.00
0005433986080	24264	Business	36400.00
0005433961096	24264	Business	36400.00
0005433961110	24264	Business	36400.00
0005433961016	24264	Business	36400.00
0005433961097	24264	Business	36400.00
0005433961085	24264	Business	36400.00
0005433985990	24264	Business	36400.00
0005433961098	24264	Business	36400.00
0005433961165	24264	Business	36400.00
0005433961130	24264	Economy	12100.00
0005433960983	24264	Economy	12100.00
0005433960894	24264	Economy	12100.00
0005433960893	24264	Economy	12100.00
0005433961084	24264	Economy	12100.00
0005433960921	24264	Economy	12100.00
0005433961148	24264	Economy	12100.00
0005433961141	24264	Economy	12100.00
0005433960936	24264	Economy	12100.00
0005433986131	24264	Economy	12100.00
0005433986120	24264	Economy	12100.00
0005433960856	24264	Economy	12100.00
0005433986115	24264	Economy	12100.00
0005433985987	24264	Economy	12100.00
0005433961067	24264	Economy	12100.00
0005433961167	24264	Economy	12100.00
0005433960838	24264	Economy	12100.00
0005433961064	24264	Economy	12100.00
0005433986039	24264	Economy	12100.00
0005433961137	24264	Economy	12100.00
0005433961169	24264	Economy	12100.00
0005433961015	24264	Economy	12100.00
0005433986087	24264	Economy	12100.00
0005433961107	24264	Economy	12100.00
0005433961136	24264	Economy	12100.00
0005433961151	24264	Economy	12100.00
0005433961034	24264	Economy	12100.00
0005433986130	24264	Economy	12100.00
0005433961057	24264	Economy	12100.00
0005433960957	24264	Economy	12100.00
0005433961029	24264	Economy	12100.00
0005433961153	24264	Economy	13400.00
0005433986114	24264	Economy	12100.00
0005433985916	24264	Economy	12100.00
0005433961129	24264	Economy	12100.00
0005433986086	24264	Economy	12100.00
0005433960920	24264	Economy	12100.00
0005433961056	24264	Economy	12100.00
0005433960982	24264	Economy	12100.00
0005433986108	24264	Economy	12100.00
0005433961152	24264	Economy	12100.00
0005433986109	24264	Economy	12100.00
0005433960861	24264	Economy	12100.00
0005433961125	24264	Economy	12100.00
0005433961066	24264	Economy	12100.00
0005433986058	24264	Economy	12100.00
0005433960862	24264	Economy	12100.00
0005433961168	24264	Economy	12100.00
0005433961054	24264	Economy	12100.00
0005433961147	24264	Economy	12100.00
0005433986121	24264	Economy	12100.00
0005433960946	24264	Economy	12100.00
0005433961171	24264	Economy	12100.00
0005433961128	24264	Economy	12100.00
0005433961111	24264	Economy	12100.00
0005433960953	24264	Economy	12100.00
0005433985989	24264	Economy	12100.00
0005433960954	24264	Economy	12100.00
0005433986548	25916	Business	36400.00
0005433961633	25916	Business	36400.00
0005433961625	25916	Business	36400.00
0005433986551	25916	Business	36400.00
0005433986587	25916	Business	36400.00
0005433986572	25916	Business	36400.00
0005433986565	25916	Business	36400.00
0005433986585	25916	Business	36400.00
0005433986600	25916	Business	36400.00
0005433961630	25916	Business	36400.00
0005433986569	25916	Business	36400.00
0005433986575	25916	Business	36400.00
0005433986557	25916	Business	36400.00
0005433961647	25916	Business	36400.00
0005433986553	25916	Business	36400.00
0005433961597	25916	Business	36400.00
0005433961605	25916	Business	36400.00
0005433961619	25916	Economy	12100.00
0005433986573	25916	Economy	13400.00
0005433986556	25916	Economy	12100.00
0005433986567	25916	Economy	12100.00
0005433961611	25916	Economy	12100.00
0005433961641	25916	Economy	12100.00
0005433986581	25916	Economy	12100.00
0005433961595	25916	Economy	12100.00
0005433961624	25916	Economy	12100.00
0005433986549	25916	Economy	12100.00
0005433961622	25916	Economy	12100.00
0005433961626	25916	Economy	12100.00
0005433986566	25916	Economy	12100.00
0005433961607	25916	Economy	12100.00
0005433986578	25916	Economy	12100.00
0005433961623	25916	Economy	12100.00
0005433961640	25916	Economy	12100.00
0005433986564	25916	Economy	12100.00
0005433961593	25916	Economy	12100.00
0005433961629	25916	Economy	12100.00
0005433986552	25916	Economy	12100.00
0005433961628	25916	Economy	12100.00
0005433961600	25916	Economy	12100.00
0005433961609	25916	Economy	12100.00
0005433961621	25916	Economy	12100.00
0005433986570	25916	Economy	12100.00
0005433986550	25916	Economy	12100.00
0005433961610	25916	Economy	12100.00
0005433961612	25916	Economy	12100.00
0005433961645	25916	Economy	12100.00
0005433961603	25916	Economy	12100.00
0005433961631	25916	Economy	12100.00
0005433961639	25916	Economy	12100.00
0005433961632	25916	Economy	12100.00
0005433961596	25916	Economy	12100.00
0005433961646	25916	Economy	12100.00
0005433961649	25916	Economy	12100.00
0005433986579	25916	Economy	12100.00
0005433986596	25916	Economy	12100.00
0005433986598	25916	Economy	12100.00
0005433986554	25916	Economy	12100.00
0005433986576	25916	Economy	12100.00
0005433986563	25916	Economy	12100.00
0005433961617	25916	Economy	12100.00
0005433961616	25916	Economy	12100.00
0005433961599	25916	Economy	12100.00
0005433986590	25916	Economy	12100.00
0005433961627	25916	Economy	12100.00
0005433961638	25916	Economy	12100.00
0005433961604	25916	Economy	12100.00
0005433986595	25916	Economy	12100.00
0005433961608	25916	Economy	12100.00
0005433986597	25916	Economy	13400.00
0005433961636	25916	Economy	13400.00
0005433986561	25916	Economy	12100.00
0005433961615	25916	Economy	13400.00
0005433961606	25916	Economy	12100.00
0005433986571	25916	Economy	12100.00
0005433986582	25916	Economy	12100.00
0005433961635	25916	Economy	12100.00
0005433986594	25916	Economy	12100.00
0005433961602	25916	Economy	12100.00
0005433961634	25916	Economy	12100.00
0005433986584	25916	Economy	12100.00
0005433961620	25916	Economy	12100.00
0005433986601	25916	Economy	12100.00
0005433986560	25916	Economy	12100.00
0005433961637	25916	Economy	12100.00
0005433986568	25916	Economy	12100.00
0005433986559	25916	Economy	12100.00
0005433961598	25916	Economy	12100.00
0005433986591	25916	Economy	12100.00
0005433961601	25916	Economy	12100.00
0005433961614	25916	Economy	12100.00
0005433961644	25916	Economy	12100.00
0005433986558	25916	Economy	12100.00
0005433986593	25916	Economy	12100.00
0005433986588	25916	Economy	12100.00
0005433986562	25916	Economy	12100.00
0005433986555	25916	Economy	12100.00
0005433961613	25916	Economy	12100.00
0005433986589	25916	Economy	12100.00
0005433986592	25916	Economy	12100.00
0005433986580	25916	Economy	12100.00
0005433986586	25916	Economy	12100.00
0005433961592	25916	Economy	12100.00
0005433986583	25916	Economy	12100.00
0005433961643	25916	Economy	12100.00
0005433986599	25916	Economy	12100.00
0005433961618	25916	Economy	12100.00
0005433986577	25916	Economy	12100.00
0005433961648	25916	Economy	12100.00
0005433961642	25916	Economy	12100.00
0005433961594	25916	Economy	12100.00
0005433986574	25916	Economy	12100.00
0005432269536	967	Economy	25400.00
0005433166020	967	Economy	25400.00
0005434480697	967	Economy	25400.00
0005434480701	967	Economy	25400.00
0005432269537	967	Economy	23100.00
0005433165995	967	Economy	23100.00
0005434480694	967	Economy	23100.00
0005434480679	967	Economy	23100.00
0005434480689	967	Economy	23100.00
0005433165964	967	Economy	23100.00
0005433165983	967	Economy	23100.00
0005433166040	967	Economy	23100.00
0005434480682	967	Economy	23100.00
0005433165937	967	Economy	23100.00
0005433165994	967	Economy	23100.00
0005434480699	967	Economy	23100.00
0005434480693	967	Economy	23100.00
0005434480702	967	Economy	23100.00
0005434480687	967	Economy	23100.00
0005434480684	967	Economy	23100.00
0005434480685	967	Economy	23100.00
0005433165958	967	Economy	23100.00
0005433165959	967	Economy	23100.00
0005433165957	967	Economy	23100.00
0005432269535	967	Economy	23100.00
0005434480691	967	Economy	23100.00
0005433165990	967	Economy	23100.00
0005434480680	967	Economy	23100.00
0005434480700	967	Economy	23100.00
0005433165996	967	Economy	23100.00
0005432269534	967	Economy	23100.00
0005434480692	967	Economy	23100.00
0005433166021	967	Economy	23100.00
0005434480678	967	Economy	23100.00
0005434480683	967	Economy	23100.00
0005434480681	967	Economy	23100.00
0005434480677	967	Economy	23100.00
0005434480686	967	Economy	23100.00
0005433166041	967	Economy	23100.00
0005434480688	967	Economy	23100.00
0005434480690	967	Economy	23100.00
0005434480698	967	Economy	23100.00
0005433165997	967	Economy	23100.00
0005433165972	967	Economy	23100.00
0005433165978	967	Economy	23100.00
0005434480696	967	Economy	23100.00
0005433165977	967	Economy	23100.00
0005434480695	967	Economy	23100.00
0005434480388	16557	Economy	25400.00
0005434480539	16557	Economy	25400.00
0005434480453	16557	Economy	25400.00
0005434480479	16557	Economy	25400.00
0005433166096	16557	Economy	23100.00
0005433166083	16557	Economy	23100.00
0005434480467	16557	Economy	23100.00
0005433166084	16557	Economy	23100.00
0005434480407	16557	Economy	23100.00
0005433166085	16557	Economy	23100.00
0005434480370	16557	Economy	23100.00
0005434480486	16557	Economy	23100.00
0005433166088	16557	Economy	23100.00
0005433166092	16557	Economy	23100.00
0005434480478	16557	Economy	23100.00
0005433166087	16557	Economy	23100.00
0005434480421	16557	Economy	23100.00
0005433166094	16557	Economy	23100.00
0005434480491	16557	Economy	23100.00
0005434480434	16557	Economy	23100.00
0005434480369	16557	Economy	23100.00
0005434480484	16557	Economy	23100.00
0005434480461	16557	Economy	23100.00
0005434480485	16557	Economy	23100.00
0005434480499	16557	Economy	23100.00
0005433166089	16557	Economy	23100.00
0005434480532	16557	Economy	23100.00
0005433166093	16557	Economy	23100.00
0005434480435	16557	Economy	23100.00
0005433166091	16557	Economy	23100.00
0005434480452	16557	Economy	23100.00
0005434480337	16557	Economy	23100.00
0005434480385	16557	Economy	23100.00
0005434480490	16557	Economy	23100.00
0005434480411	16557	Economy	23100.00
0005434480324	16557	Economy	23100.00
0005433166090	16557	Economy	23100.00
0005433166086	16557	Economy	23100.00
0005434480548	16557	Economy	23100.00
0005434480325	16557	Economy	23100.00
0005434480570	16557	Economy	23100.00
0005433166095	16557	Economy	23100.00
0005434480487	16557	Economy	23100.00
0005434480351	16557	Economy	23100.00
0005434480371	16557	Economy	23100.00
0005435142752	10347	Economy	17000.00
0005435150217	10347	Economy	17000.00
0005435150219	10347	Economy	15400.00
0005435386597	10347	Economy	15400.00
0005435150221	10347	Economy	15400.00
0005435142756	10347	Economy	15400.00
0005435142760	10347	Economy	15400.00
0005435386609	10347	Economy	15400.00
0005435142755	10347	Economy	15400.00
0005435150211	10347	Economy	15400.00
0005435150208	10347	Economy	15400.00
0005435142761	10347	Economy	15400.00
0005435150209	10347	Economy	15400.00
0005435142764	10347	Economy	15400.00
0005435150215	10347	Economy	15400.00
0005435142758	10347	Economy	15400.00
0005435142762	10347	Economy	15400.00
0005435150210	10347	Economy	15400.00
0005435150220	10347	Economy	15400.00
0005435142759	10347	Economy	15400.00
0005435150216	10347	Economy	15400.00
0005435142757	10347	Economy	15400.00
0005435386575	10347	Economy	15400.00
0005435386596	10347	Economy	15400.00
0005435150218	10347	Economy	15400.00
0005435150214	10347	Economy	15400.00
0005433289889	10347	Economy	15400.00
0005433289862	10347	Economy	15400.00
0005435142754	10347	Economy	15400.00
0005435150207	10347	Economy	15400.00
0005433289863	10347	Economy	15400.00
0005435142751	10347	Economy	15400.00
0005435386595	10347	Economy	15400.00
0005435142763	10347	Economy	15400.00
0005435150213	10347	Economy	15400.00
0005435150212	10347	Economy	15400.00
0005435142753	10347	Economy	15400.00
0005435386663	21928	Economy	17000.00
0005433289954	21928	Economy	17000.00
0005435142687	21928	Economy	17000.00
0005435386666	21928	Economy	17000.00
0005435150113	21928	Economy	15400.00
0005435150043	21928	Economy	15400.00
0005433289955	21928	Economy	15400.00
0005435386661	21928	Economy	15400.00
0005435142685	21928	Economy	15400.00
0005435142692	21928	Economy	15400.00
0005433289957	21928	Economy	15400.00
0005435142693	21928	Economy	15400.00
0005435386662	21928	Economy	15400.00
0005435150042	21928	Economy	15400.00
0005435386664	21928	Economy	15400.00
0005435142606	21928	Economy	15400.00
0005435142646	21928	Economy	15400.00
0005433289958	21928	Economy	15400.00
0005435142699	21928	Economy	15400.00
0005435386660	21928	Economy	15400.00
0005435142682	21928	Economy	15400.00
0005435150102	21928	Economy	15400.00
0005435142683	21928	Economy	15400.00
0005435142676	21928	Economy	15400.00
0005435142638	21928	Economy	15400.00
0005435150091	21928	Economy	15400.00
0005435150033	21928	Economy	15400.00
0005435149999	21928	Economy	15400.00
0005433289961	21928	Economy	15400.00
0005433289960	21928	Economy	15400.00
0005435142600	21928	Economy	15400.00
0005435150142	21928	Economy	15400.00
0005435386659	21928	Economy	15400.00
0005435142673	21928	Economy	15400.00
0005435142664	21928	Economy	15400.00
0005435142622	21928	Economy	15400.00
0005435150120	21928	Economy	15400.00
0005433289956	21928	Economy	15400.00
0005433289959	21928	Economy	15400.00
0005435386665	21928	Economy	15400.00
0005434573549	11183	Business	57200.00
0005435319624	11183	Business	57200.00
0005434573544	11183	Business	57200.00
0005435545772	11183	Business	57200.00
0005435545779	11183	Business	57200.00
0005435502499	11183	Business	57200.00
0005435502436	11183	Business	57200.00
0005435529429	11183	Business	57200.00
0005435545770	11183	Business	57200.00
0005434573536	11183	Business	57200.00
0005435545798	11183	Economy	19100.00
0005435319623	11183	Economy	19100.00
0005434573540	11183	Economy	19100.00
0005435545771	11183	Economy	19100.00
0005435319597	11183	Economy	19100.00
0005435319598	11183	Economy	19100.00
0005435502444	11183	Economy	19100.00
0005435502461	11183	Economy	19100.00
0005435502476	11183	Economy	21000.00
0005435502451	11183	Economy	21000.00
0005434573538	11183	Economy	21000.00
0005435502441	11183	Economy	19100.00
0005435502424	11183	Economy	19100.00
0005435545785	11183	Economy	19100.00
0005435529363	11183	Economy	19100.00
0005435529380	11183	Economy	19100.00
0005435529344	11183	Economy	19100.00
0005435529384	11183	Economy	19100.00
0005435529383	11183	Economy	19100.00
0005435529377	11183	Economy	19100.00
0005435319676	11183	Economy	19100.00
0005435502395	11183	Economy	19100.00
0005435545776	11183	Economy	19100.00
0005434573546	11183	Economy	19100.00
0005435545765	11183	Economy	19100.00
0005434573545	11183	Economy	19100.00
0005435529449	11183	Economy	19100.00
0005435502452	11183	Economy	19100.00
0005434573537	11183	Economy	19100.00
0005435502396	11183	Economy	19100.00
0005434573535	11183	Economy	19100.00
0005435502425	11183	Economy	19100.00
0005435502432	11183	Economy	19100.00
0005434573547	11183	Economy	19100.00
0005435529450	11183	Economy	19100.00
0005434573541	11183	Economy	19100.00
0005435502445	11183	Economy	19100.00
0005435529378	11183	Economy	19100.00
0005434573542	11183	Economy	19100.00
0005435545766	11183	Economy	19100.00
0005435502431	11183	Economy	19100.00
0005435502475	11183	Economy	19100.00
0005435529359	11183	Economy	19100.00
0005434573548	11183	Economy	19100.00
0005435545758	11183	Economy	19100.00
0005435502405	11183	Economy	19100.00
0005435529327	11183	Economy	19100.00
0005435529296	11183	Economy	19100.00
0005435502343	11183	Economy	19100.00
0005435502423	11183	Economy	19100.00
0005435529297	11183	Economy	19100.00
0005435502498	11183	Economy	19100.00
0005434573543	11183	Economy	19100.00
0005435502344	11183	Economy	19100.00
0005435529366	11183	Economy	19100.00
0005434573539	11183	Economy	19100.00
0005435545761	11183	Economy	19100.00
0005435502597	20905	Business	57200.00
0005434573391	20905	Business	57200.00
0005435502616	20905	Business	57200.00
0005435502596	20905	Business	57200.00
0005435502598	20905	Business	57200.00
0005434573428	20905	Business	57200.00
0005435518163	20905	Business	57200.00
0005435518171	20905	Business	57200.00
0005434573401	20905	Business	57200.00
0005435518174	20905	Business	57200.00
0005435502606	20905	Business	57200.00
0005432291963	20905	Economy	19100.00
0005434573457	20905	Economy	19100.00
0005435518162	20905	Economy	19100.00
0005434573393	20905	Economy	19100.00
0005435518160	20905	Economy	19100.00
0005434573392	20905	Economy	19100.00
0005434573466	20905	Economy	19100.00
0005435518167	20905	Economy	21000.00
0005435508511	20905	Economy	21000.00
0005435518170	20905	Economy	21000.00
0005434573430	20905	Economy	21000.00
0005434573335	20905	Economy	21000.00
0005435508512	20905	Economy	19100.00
0005435502601	20905	Economy	19100.00
0005435502599	20905	Economy	19100.00
0005435502613	20905	Economy	19100.00
0005435502612	20905	Economy	19100.00
0005434573408	20905	Economy	19100.00
0005435518165	20905	Economy	19100.00
0005435518175	20905	Economy	19100.00
0005434573382	20905	Economy	19100.00
0005435319710	20905	Economy	19100.00
0005434573383	20905	Economy	19100.00
0005434573455	20905	Economy	19100.00
0005435518168	20905	Economy	19100.00
0005435502608	20905	Economy	19100.00
0005434573395	20905	Economy	19100.00
0005435319708	20905	Economy	19100.00
0005435319711	20905	Economy	19100.00
0005434573467	20905	Economy	19100.00
0005435502604	20905	Economy	19100.00
0005435319713	20905	Economy	19100.00
0005435319709	20905	Economy	19100.00
0005435518166	20905	Economy	19100.00
0005434573454	20905	Economy	19100.00
0005435319707	20905	Economy	19100.00
0005435518172	20905	Economy	19100.00
0005435518173	20905	Economy	19100.00
0005435508513	20905	Economy	19100.00
0005434573334	20905	Economy	19100.00
0005435508514	20905	Economy	19100.00
0005432291962	20905	Economy	19100.00
0005434573431	20905	Economy	19100.00
0005435508509	20905	Economy	19100.00
0005434573456	20905	Economy	19100.00
0005435518164	20905	Economy	19100.00
0005435518159	20905	Economy	19100.00
0005435502615	20905	Economy	19100.00
0005435502605	20905	Economy	19100.00
0005435502607	20905	Economy	19100.00
0005435502602	20905	Economy	19100.00
0005435502614	20905	Economy	19100.00
0005435502603	20905	Economy	19100.00
0005435518169	20905	Economy	19100.00
0005434573429	20905	Economy	19100.00
0005435508510	20905	Economy	19100.00
0005434573396	20905	Economy	19100.00
0005435502609	20905	Economy	19100.00
0005435502600	20905	Economy	19100.00
0005435518161	20905	Economy	19100.00
0005435502610	20905	Economy	19100.00
0005435502617	20905	Economy	19100.00
0005435502611	20905	Economy	19100.00
0005435319712	20905	Economy	19100.00
0005434573440	20905	Economy	19100.00
0005435319706	20905	Economy	19100.00
0005434573409	20905	Economy	19100.00
0005435518158	20905	Economy	19100.00
0005433683376	24317	Economy	17100.00
0005433683377	24317	Economy	17100.00
0005433927459	24317	Economy	17100.00
0005433927447	24317	Economy	17100.00
0005433683374	24317	Economy	17100.00
0005433927458	24317	Economy	17100.00
0005433683378	24317	Economy	17100.00
0005433683373	24317	Economy	17100.00
0005433683375	24317	Economy	17100.00
0005433683371	24317	Economy	17100.00
0005433683372	24317	Economy	17100.00
0005433927474	29282	Economy	18800.00
0005433927480	29282	Economy	17100.00
0005433927477	29282	Economy	17100.00
0005433927473	29282	Economy	17100.00
0005433683350	29282	Economy	17100.00
0005433683357	29282	Economy	17100.00
0005433683345	29282	Economy	17100.00
0005433683348	29282	Economy	17100.00
0005433683341	29282	Economy	17100.00
0005433683351	29282	Economy	17100.00
0005433683354	29282	Economy	17100.00
0005433683344	29282	Economy	17100.00
0005433927475	29282	Economy	17100.00
0005433683358	29282	Economy	17100.00
0005433927476	29282	Economy	17100.00
0005433927479	29282	Economy	17100.00
0005433683342	29282	Economy	17100.00
0005433927478	29282	Economy	17100.00
0005433683353	29282	Economy	17100.00
0005433683343	29282	Economy	17100.00
0005432693144	3026	Business	10300.00
0005432693230	3026	Business	10300.00
0005432693154	3026	Economy	3400.00
0005432693247	3026	Economy	3400.00
0005432693192	3026	Economy	3400.00
0005432693259	3026	Economy	3400.00
0005432693076	3026	Economy	3800.00
0005432693133	3026	Economy	3800.00
0005432693224	3026	Economy	3800.00
0005432693294	3026	Economy	3400.00
0005432693210	3026	Economy	3400.00
0005432693194	3026	Economy	3400.00
0005432693311	3026	Economy	3400.00
0005432693202	3026	Economy	3400.00
0005432693169	3026	Economy	3400.00
0005432693293	3026	Economy	3400.00
0005432693166	3026	Economy	3400.00
0005432693216	3026	Economy	3400.00
0005432693128	3026	Economy	3400.00
0005432693153	3026	Economy	3400.00
0005432693170	3026	Economy	3400.00
0005432693191	3026	Economy	3400.00
0005432693203	3026	Economy	3400.00
0005432693208	3026	Economy	3400.00
0005432693221	3026	Economy	3400.00
0005432693250	3026	Economy	3400.00
0005432693152	3026	Economy	3400.00
0005432693185	3026	Economy	3400.00
0005432693222	3026	Economy	3400.00
0005432693167	3026	Economy	3400.00
0005432693127	3026	Economy	3400.00
0005432693312	3026	Economy	3400.00
0005432693225	3026	Economy	3400.00
0005432693209	3026	Economy	3400.00
0005432880907	3025	Business	10300.00
0005432707131	3025	Business	10300.00
0005432880902	3025	Business	10300.00
0005433123931	3025	Business	10300.00
0005432707136	3025	Business	10300.00
0005432880950	3025	Business	10300.00
0005433124030	3025	Business	10300.00
0005432707132	3025	Business	10300.00
0005433124108	3025	Business	10300.00
0005432707128	3025	Economy	3400.00
0005433124103	3025	Economy	3400.00
0005432707124	3025	Economy	3400.00
0005432707143	3025	Economy	3400.00
0005433124039	3025	Economy	3400.00
0005432707137	3025	Economy	3400.00
0005432217818	3025	Economy	3400.00
0005432707129	3025	Economy	3800.00
0005433194861	3025	Economy	3800.00
0005432880883	3025	Economy	3800.00
0005433124004	3025	Economy	3800.00
0005433124094	3025	Economy	3400.00
0005433124035	3025	Economy	3400.00
0005432217817	3025	Economy	3400.00
0005432217816	3025	Economy	3400.00
0005433124014	3025	Economy	3400.00
0005432880914	3025	Economy	3400.00
0005432707142	3025	Economy	3400.00
0005433124122	3025	Economy	3400.00
0005432707126	3025	Economy	3400.00
0005433124044	3025	Economy	3400.00
0005432880927	3025	Economy	3400.00
0005432880918	3025	Economy	3400.00
0005432707134	3025	Economy	3400.00
0005433124065	3025	Economy	3400.00
0005432707133	3025	Economy	3400.00
0005432880856	3025	Economy	3400.00
0005432880926	3025	Economy	3400.00
0005432880954	3025	Economy	3400.00
0005433124106	3025	Economy	3400.00
0005432707141	3025	Economy	3400.00
0005433124005	3025	Economy	3400.00
0005432707123	3025	Economy	3400.00
0005432707139	3025	Economy	3400.00
0005432707138	3025	Economy	3400.00
0005433124058	3025	Economy	3400.00
0005433124104	3025	Economy	3400.00
0005433124029	3025	Economy	3400.00
0005432217815	3025	Economy	3400.00
0005433124036	3025	Economy	3400.00
0005433124031	3025	Economy	3400.00
0005433124060	3025	Economy	3400.00
0005433124023	3025	Economy	3400.00
0005433123951	3025	Economy	3400.00
0005433194859	3025	Economy	3400.00
0005432707144	3025	Economy	3400.00
0005433124018	3025	Economy	3400.00
0005432707135	3025	Economy	3400.00
0005432707130	3025	Economy	3400.00
0005433194858	3025	Economy	3400.00
0005432707125	3025	Economy	3400.00
0005433124019	3025	Economy	3400.00
0005433123999	3025	Economy	3400.00
0005433123932	3025	Economy	3400.00
0005432707145	3025	Economy	3400.00
0005433124076	3025	Economy	3400.00
0005432707122	3025	Economy	3400.00
0005432707127	3025	Economy	3400.00
0005432707140	3025	Economy	3400.00
0005433123939	3025	Economy	3400.00
0005433124107	3025	Economy	3400.00
0005433124062	3025	Economy	3400.00
0005432693531	30057	Business	10300.00
0005432706871	30057	Business	10300.00
0005432693536	30057	Business	10300.00
0005432881026	30057	Business	10300.00
0005432706979	30057	Business	10300.00
0005433124202	30057	Business	10300.00
0005433124203	30057	Business	10300.00
0005432693522	30057	Business	10300.00
0005432706870	30057	Business	10300.00
0005432707018	30057	Business	10300.00
0005432706987	30057	Business	10300.00
0005432693537	30057	Business	10300.00
0005432693507	30057	Economy	3400.00
0005432707005	30057	Economy	3400.00
0005432706815	30057	Economy	3400.00
0005432693515	30057	Economy	3400.00
0005432706964	30057	Economy	3400.00
0005432693512	30057	Economy	3400.00
0005432706935	30057	Economy	3400.00
0005433124204	30057	Economy	3400.00
0005433124205	30057	Economy	3400.00
0005432707050	30057	Economy	3400.00
0005432706937	30057	Economy	3800.00
0005432693511	30057	Economy	3800.00
0005433124208	30057	Economy	3800.00
0005432881016	30057	Economy	3800.00
0005432881027	30057	Economy	3800.00
0005432706936	30057	Economy	3400.00
0005432706945	30057	Economy	3400.00
0005432881017	30057	Economy	3400.00
0005432693508	30057	Economy	3400.00
0005432881030	30057	Economy	3400.00
0005432693513	30057	Economy	3400.00
0005432707039	30057	Economy	3400.00
0005432693510	30057	Economy	3400.00
0005432707061	30057	Economy	3400.00
0005432693533	30057	Economy	3400.00
0005432706899	30057	Economy	3400.00
0005432881031	30057	Economy	3400.00
0005432881025	30057	Economy	3400.00
0005432693532	30057	Economy	3400.00
0005432706876	30057	Economy	3400.00
0005432706877	30057	Economy	3400.00
0005432706898	30057	Economy	3400.00
0005432707051	30057	Economy	3400.00
0005433124207	30057	Economy	3400.00
0005433124215	30057	Economy	3400.00
0005433124209	30057	Economy	3400.00
0005433124213	30057	Economy	3400.00
0005432707026	30057	Economy	3400.00
0005432881028	30057	Economy	3400.00
0005432706911	30057	Economy	3400.00
0005432693527	30057	Economy	3400.00
0005432881023	30057	Economy	3400.00
0005432706929	30057	Economy	3400.00
0005433124214	30057	Economy	3400.00
0005433124217	30057	Economy	3400.00
0005433124216	30057	Economy	3400.00
0005432693521	30057	Economy	3400.00
0005432693518	30057	Economy	3400.00
0005432707042	30057	Economy	3400.00
0005432706875	30057	Economy	3400.00
0005432706989	30057	Economy	3400.00
0005432693529	30057	Economy	3400.00
0005432706838	30057	Economy	3400.00
0005432693528	30057	Economy	3400.00
0005432881019	30057	Economy	3400.00
0005432881029	30057	Economy	3400.00
0005432693525	30057	Economy	3400.00
0005432693520	30057	Economy	3400.00
0005432707017	30057	Economy	3400.00
0005432693514	30057	Economy	3400.00
0005432693526	30057	Economy	3400.00
0005432881021	30057	Economy	3400.00
0005432693524	30057	Economy	3400.00
0005432707027	30057	Economy	3400.00
0005432693534	30057	Economy	3400.00
0005433124211	30057	Economy	3400.00
0005432707016	30057	Economy	3400.00
0005433124212	30057	Economy	3400.00
0005433124206	30057	Economy	3400.00
0005432693517	30057	Economy	3400.00
0005432881022	30057	Economy	3400.00
0005432693509	30057	Economy	3400.00
0005432693519	30057	Economy	3400.00
0005432706928	30057	Economy	3400.00
0005432706986	30057	Economy	3400.00
0005432693523	30057	Economy	3400.00
0005432693516	30057	Economy	3400.00
0005432693535	30057	Economy	3400.00
0005432881018	30057	Economy	3400.00
0005433124218	30057	Economy	3400.00
0005432881020	30057	Economy	3400.00
0005433124210	30057	Economy	3400.00
0005432881024	30057	Economy	3400.00
0005432693530	30057	Economy	3400.00
0005432706886	30057	Economy	3400.00
0005434980188	23668	Economy	4000.00
0005434980192	23668	Economy	4000.00
0005434980177	23668	Economy	4000.00
0005434980183	23668	Economy	4000.00
0005434980185	23668	Economy	3600.00
0005434980189	23668	Economy	3600.00
0005434988893	23668	Economy	3600.00
0005434988889	23668	Economy	3600.00
0005434980187	23668	Economy	3600.00
0005434980191	23668	Economy	3600.00
0005434980199	23668	Economy	3600.00
0005434980184	23668	Economy	3600.00
0005434980195	23668	Economy	3600.00
0005434980205	23668	Economy	3600.00
0005434988888	23668	Economy	3600.00
0005434980201	23668	Economy	3600.00
0005434980197	23668	Economy	3600.00
0005434980204	23668	Economy	3600.00
0005434988886	23668	Economy	3600.00
0005434980178	23668	Economy	3600.00
0005434980202	23668	Economy	3600.00
0005434980190	23668	Economy	3600.00
0005434980182	23668	Economy	3600.00
0005434980203	23668	Economy	3600.00
0005434988887	23668	Economy	3600.00
0005434980181	23668	Economy	3600.00
0005434980186	23668	Economy	3600.00
0005434980176	23668	Economy	3600.00
0005434980200	23668	Economy	3600.00
0005434980193	23668	Economy	3600.00
0005434980196	23668	Economy	3600.00
0005434980180	23668	Economy	3600.00
0005434980198	23668	Economy	3600.00
0005434980194	23668	Economy	3600.00
0005434980175	23668	Economy	3600.00
0005434988892	23668	Economy	3600.00
0005434988890	23668	Economy	3600.00
0005434980179	23668	Economy	3600.00
0005434988891	23668	Economy	3600.00
0005434979909	27527	Economy	4000.00
0005434979896	27527	Economy	4000.00
0005434979869	27527	Economy	4000.00
0005434979993	27527	Economy	4000.00
0005434979981	27527	Economy	3600.00
0005434979984	27527	Economy	3600.00
0005434988783	27527	Economy	3600.00
0005434988793	27527	Economy	3600.00
0005434988796	27527	Economy	3600.00
0005434988767	27527	Economy	3600.00
0005434988773	27527	Economy	3600.00
0005434988768	27527	Economy	3600.00
0005434980011	27527	Economy	3600.00
0005434988779	27527	Economy	3600.00
0005434988781	27527	Economy	3600.00
0005434979790	27527	Economy	3600.00
0005434979839	27527	Economy	3600.00
0005434988784	27527	Economy	3600.00
0005434979864	27527	Economy	3600.00
0005434979870	27527	Economy	3600.00
0005434988780	27527	Economy	3600.00
0005434988790	27527	Economy	3600.00
0005434988797	27527	Economy	3600.00
0005434979806	27527	Economy	3600.00
0005434979913	27527	Economy	3600.00
0005434979891	27527	Economy	3600.00
0005434988789	27527	Economy	3600.00
0005434979912	27527	Economy	3600.00
0005434988761	27527	Economy	3600.00
0005434979888	27527	Economy	3600.00
0005434980051	27527	Economy	3600.00
0005434980061	27527	Economy	3600.00
0005434980020	27527	Economy	3600.00
0005434980030	27527	Economy	3600.00
0005434980050	27527	Economy	3600.00
0005434988760	27527	Economy	3600.00
0005434979928	27527	Economy	3600.00
0005434979892	27527	Economy	3600.00
0005434988782	27527	Economy	3600.00
0005434979985	27527	Economy	3600.00
0005434979789	27527	Economy	3600.00
0005434979791	27527	Economy	3600.00
0005434988785	27527	Economy	3600.00
0005434302517	10247	Economy	21600.00
0005434302518	10247	Economy	19700.00
0005434302519	10247	Economy	19700.00
0005433113537	10247	Economy	19700.00
0005433111514	10247	Economy	19700.00
0005434302520	10247	Economy	19700.00
0005434302516	10247	Economy	19700.00
0005433113538	10247	Economy	19700.00
0005433113548	10247	Economy	19700.00
0005433111517	10247	Economy	19700.00
0005433113551	10247	Economy	19700.00
0005433113549	10247	Economy	19700.00
0005433113550	10247	Economy	19700.00
0005433111513	10247	Economy	19700.00
0005434302488	19595	Economy	19700.00
0005433113568	19595	Economy	19700.00
0005434302473	19595	Economy	19700.00
0005433113567	19595	Economy	19700.00
0005434302472	19595	Economy	19700.00
0005433113569	19595	Economy	19700.00
0005434302476	19595	Economy	19700.00
0005435069822	3576	Business	26900.00
0005435925299	3576	Business	26900.00
0005435069827	3576	Business	26900.00
0005435719024	3576	Business	26900.00
0005435069815	3576	Business	26900.00
0005435069816	3576	Business	26900.00
0005435925403	3576	Business	26900.00
0005435069803	3576	Business	26900.00
0005435925352	3576	Business	26900.00
0005435069805	3576	Economy	9000.00
0005435719025	3576	Economy	9000.00
0005435069851	3576	Economy	9000.00
0005435069849	3576	Economy	9000.00
0005435069848	3576	Economy	9000.00
0005435069823	3576	Economy	9000.00
0005435069840	3576	Economy	9000.00
0005435069808	3576	Economy	9000.00
0005435925350	3576	Economy	9900.00
0005435069846	3576	Economy	9900.00
0005435719022	3576	Economy	9900.00
0005435069833	3576	Economy	9900.00
0005435719020	3576	Economy	9900.00
0005435069801	3576	Economy	9000.00
0005435069842	3576	Economy	9000.00
0005435069838	3576	Economy	9000.00
0005435069825	3576	Economy	9000.00
0005435069807	3576	Economy	9000.00
0005435069830	3576	Economy	9000.00
0005435069835	3576	Economy	9000.00
0005435069829	3576	Economy	9000.00
0005435069845	3576	Economy	9000.00
0005435069820	3576	Economy	9000.00
0005435069837	3576	Economy	9000.00
0005435939892	3576	Economy	9000.00
0005435069836	3576	Economy	9000.00
0005435925324	3576	Economy	9000.00
0005435069817	3576	Economy	9000.00
0005435069809	3576	Economy	9000.00
0005435069824	3576	Economy	9000.00
0005435069818	3576	Economy	9000.00
0005435719023	3576	Economy	9000.00
0005435069826	3576	Economy	9000.00
0005435069810	3576	Economy	9000.00
0005435069814	3576	Economy	9000.00
0005435069819	3576	Economy	9000.00
0005435925351	3576	Economy	9000.00
0005435069811	3576	Economy	9000.00
0005435069812	3576	Economy	9000.00
0005435939887	3576	Economy	9000.00
0005435925367	3576	Economy	9000.00
0005435069813	3576	Economy	9000.00
0005435069806	3576	Economy	9000.00
0005435719021	3576	Economy	9000.00
0005435925364	3576	Economy	9000.00
0005435069828	3576	Economy	9000.00
0005435069839	3576	Economy	9000.00
0005435925368	3576	Economy	9000.00
0005435069832	3576	Economy	9000.00
0005435069847	3576	Economy	9000.00
0005435719026	3576	Economy	9000.00
0005435069843	3576	Economy	9000.00
0005435069821	3576	Economy	9000.00
0005435925329	3576	Economy	9000.00
0005435925320	3576	Economy	9000.00
0005435925349	3576	Economy	9000.00
0005435069831	3576	Economy	9000.00
0005435925347	3576	Economy	9000.00
0005435069852	3576	Economy	9000.00
0005435069844	3576	Economy	9000.00
0005435925404	3576	Economy	9000.00
0005435925365	3576	Economy	9000.00
0005435069804	3576	Economy	9000.00
0005435939886	3576	Economy	9000.00
0005435069841	3576	Economy	9000.00
0005435925323	3576	Economy	9000.00
0005435069802	3576	Economy	9000.00
0005435069850	3576	Economy	9000.00
0005435069834	3576	Economy	9000.00
0005435069352	15282	Business	26900.00
0005435718953	15282	Business	26900.00
0005435069094	15282	Business	26900.00
0005435069637	15282	Business	26900.00
0005435069549	15282	Business	26900.00
0005435069325	15282	Business	26900.00
0005435925479	15282	Business	26900.00
0005435069447	15282	Business	26900.00
0005435069268	15282	Business	26900.00
0005435925483	15282	Business	26900.00
0005435925482	15282	Business	26900.00
0005435718936	15282	Business	26900.00
0005435718898	15282	Economy	9000.00
0005435718886	15282	Economy	9000.00
0005435069356	15282	Economy	9000.00
0005435069269	15282	Economy	9000.00
0005435718937	15282	Economy	9000.00
0005435925481	15282	Economy	9000.00
0005435718906	15282	Economy	9000.00
0005435925473	15282	Economy	9000.00
0005435718951	15282	Economy	9000.00
0005435718920	15282	Economy	9000.00
0005435069419	15282	Economy	9900.00
0005435718959	15282	Economy	9900.00
0005435069292	15282	Economy	9900.00
0005435069298	15282	Economy	9900.00
0005435925474	15282	Economy	9900.00
0005435718932	15282	Economy	9000.00
0005435069340	15282	Economy	9000.00
0005435718939	15282	Economy	9000.00
0005435069267	15282	Economy	9000.00
0005435069049	15282	Economy	9000.00
0005435069149	15282	Economy	9000.00
0005435069350	15282	Economy	9000.00
0005435069192	15282	Economy	9000.00
0005435069375	15282	Economy	9000.00
0005435069468	15282	Economy	9000.00
0005435069208	15282	Economy	9000.00
0005435069370	15282	Economy	9000.00
0005435069150	15282	Economy	9000.00
0005435069365	15282	Economy	9000.00
0005435069111	15282	Economy	9000.00
0005435069467	15282	Economy	9000.00
0005435718966	15282	Economy	9000.00
0005435069457	15282	Economy	9000.00
0005435069293	15282	Economy	9000.00
0005435718933	15282	Economy	9000.00
0005435069341	15282	Economy	9000.00
0005435718928	15282	Economy	9000.00
0005435718935	15282	Economy	9000.00
0005435069301	15282	Economy	9000.00
0005435925475	15282	Economy	9000.00
0005435069530	15282	Economy	9000.00
0005435718894	15282	Economy	9000.00
0005435718950	15282	Economy	9000.00
0005435718946	15282	Economy	9000.00
0005435718885	15282	Economy	9000.00
0005435925477	15282	Economy	9000.00
0005435069396	15282	Economy	9000.00
0005435718960	15282	Economy	9000.00
0005435718965	15282	Economy	9000.00
0005435069448	15282	Economy	9000.00
0005435069548	15282	Economy	9000.00
0005435718938	15282	Economy	9000.00
0005435718955	15282	Economy	9000.00
0005435069285	15282	Economy	9000.00
0005435925480	15282	Economy	9000.00
0005435925476	15282	Economy	9000.00
0005435718934	15282	Economy	9000.00
0005435069361	15282	Economy	9000.00
0005435718888	15282	Economy	9000.00
0005435069110	15282	Economy	9000.00
0005435069014	15282	Economy	9000.00
0005435718964	15282	Economy	9000.00
0005435069388	15282	Economy	9000.00
0005435069432	15282	Economy	9000.00
0005435069351	15282	Economy	9000.00
0005435069357	15282	Economy	9000.00
0005435718977	15282	Economy	9000.00
0005435718976	15282	Economy	9000.00
0005435069193	15282	Economy	9000.00
0005435718895	15282	Economy	9000.00
0005435069294	15282	Economy	9000.00
0005435718952	15282	Economy	9000.00
0005435069317	15282	Economy	9000.00
0005435718907	15282	Economy	9000.00
0005435718930	15282	Economy	9000.00
0005435718925	15282	Economy	9000.00
0005435069402	15282	Economy	9000.00
0005435718945	15282	Economy	9000.00
0005435718961	15282	Economy	9000.00
0005435069095	15282	Economy	9000.00
0005435069376	15282	Economy	9000.00
0005435925478	15282	Economy	9000.00
0005435718949	15282	Economy	9000.00
0005435069462	15282	Economy	9000.00
0005432658620	18215	Economy	5900.00
0005432659735	18215	Economy	5900.00
0005432660847	18215	Economy	5900.00
0005432659736	18215	Economy	5900.00
0005432658621	18215	Economy	5900.00
0005432660848	18215	Economy	5900.00
0005432660846	18215	Economy	5900.00
0005432660834	26428	Economy	5900.00
0005432664149	26428	Economy	5900.00
0005432667461	26428	Economy	5900.00
0005432664157	26428	Economy	5900.00
0005432660833	26428	Economy	5900.00
0005432664146	26428	Economy	5900.00
0005432667460	26428	Economy	5900.00
0005432664156	26428	Economy	5900.00
0005433102397	6	Business	20000.00
0005432919942	6	Business	20000.00
0005432901788	6	Business	20000.00
0005433102336	6	Business	20000.00
0005432920009	6	Business	20000.00
0005432920033	6	Business	20000.00
0005432919994	6	Business	20000.00
0005433102392	6	Business	20000.00
0005432391994	6	Business	20000.00
0005433102428	6	Business	20000.00
0005433102440	6	Business	20000.00
0005432392025	6	Business	20000.00
0005432901673	6	Business	20000.00
0005432391988	6	Business	20000.00
0005432920018	6	Economy	7300.00
0005433102439	6	Economy	7300.00
0005432920051	6	Economy	7300.00
0005433102405	6	Economy	7300.00
0005432901629	6	Economy	7300.00
0005432919943	6	Economy	6700.00
0005433102147	6	Economy	6700.00
0005432920090	6	Economy	6700.00
0005432919988	6	Economy	6700.00
0005432920034	6	Economy	6700.00
0005433102470	6	Economy	6700.00
0005433102463	6	Economy	6700.00
0005432901745	6	Economy	6700.00
0005432919982	6	Economy	6700.00
0005433102475	6	Economy	6700.00
0005432919974	6	Economy	6700.00
0005433102385	6	Economy	6700.00
0005433102437	6	Economy	6700.00
0005432920078	6	Economy	6700.00
0005432919973	6	Economy	6700.00
0005432919922	6	Economy	6700.00
0005432919984	6	Economy	6700.00
0005432920050	6	Economy	6700.00
0005432391993	6	Economy	6700.00
0005432392004	6	Economy	6700.00
0005433102228	6	Economy	6700.00
0005433102398	6	Economy	6700.00
0005433102477	6	Economy	6700.00
0005433102471	6	Economy	6700.00
0005432920020	6	Economy	6700.00
0005432901729	6	Economy	6700.00
0005432901734	6	Economy	6700.00
0005433102464	6	Economy	6700.00
0005432901700	6	Economy	6700.00
0005433102454	6	Economy	6700.00
0005432919944	6	Economy	6700.00
0005433102436	6	Economy	6700.00
0005432901767	6	Economy	6700.00
0005433102337	6	Economy	6700.00
0005432901754	6	Economy	6700.00
0005432901727	6	Economy	6700.00
0005432919929	6	Economy	6700.00
0005432157520	6	Economy	7300.00
0005432919946	6	Economy	7300.00
0005432901778	6	Economy	7300.00
0005432391986	6	Economy	6700.00
0005432919947	6	Economy	6700.00
0005433102422	6	Economy	7300.00
0005432919965	6	Economy	6700.00
0005432919956	6	Economy	6700.00
0005432392002	6	Economy	6700.00
0005432392003	6	Economy	6700.00
0005432919941	6	Economy	6700.00
0005432901730	6	Economy	6700.00
0005433102441	6	Economy	6700.00
0005433102391	6	Economy	6700.00
0005432920088	6	Economy	6700.00
0005432919945	6	Economy	6700.00
0005432920089	6	Economy	6700.00
0005432901741	6	Economy	6700.00
0005432919909	6	Economy	6700.00
0005433102455	6	Economy	6700.00
0005432920032	6	Economy	6700.00
0005432919976	6	Economy	6700.00
0005432392013	6	Economy	6700.00
0005433102427	6	Economy	6700.00
0005433102444	6	Economy	6700.00
0005432901674	6	Economy	6700.00
0005433102426	6	Economy	6700.00
0005433102430	6	Economy	6700.00
0005432391997	6	Economy	6700.00
0005433102399	6	Economy	6700.00
0005432392001	6	Economy	6700.00
0005432392018	6	Economy	6700.00
0005432919995	6	Economy	6700.00
0005433102465	6	Economy	6700.00
0005432392012	6	Economy	6700.00
0005432920019	6	Economy	6700.00
0005432920006	6	Economy	6700.00
0005432392009	6	Economy	6700.00
0005432901693	6	Economy	6700.00
0005432920005	6	Economy	6700.00
0005433102433	6	Economy	6700.00
0005433102368	6	Economy	6700.00
0005432157519	6	Economy	6700.00
0005432919975	6	Economy	6700.00
0005433102229	6	Economy	6700.00
0005432817885	5	Business	20000.00
0005432262569	5	Business	20000.00
0005432262574	5	Business	20000.00
0005432817900	5	Business	20000.00
0005433687712	5	Business	20000.00
0005432262556	5	Business	20000.00
0005432262543	5	Business	20000.00
0005432262575	5	Business	20000.00
0005432817909	5	Business	20000.00
0005432262558	5	Business	20000.00
0005433690931	5	Business	20000.00
0005432817905	5	Business	20000.00
0005432207697	5	Economy	7300.00
0005432262537	5	Business	20000.00
0005432262559	5	Economy	7300.00
0005432817907	5	Economy	7300.00
0005432817887	5	Economy	7300.00
0005432262540	5	Economy	7300.00
0005432262546	5	Economy	6700.00
0005432262572	5	Economy	6700.00
0005432756868	5	Economy	6700.00
0005432262552	5	Economy	6700.00
0005432207696	5	Economy	6700.00
0005432262579	5	Economy	6700.00
0005432817889	5	Economy	6700.00
0005432262565	5	Economy	6700.00
0005432262545	5	Economy	6700.00
0005433690922	5	Economy	6700.00
0005432262571	5	Economy	6700.00
0005432262573	5	Economy	6700.00
0005432817902	5	Economy	6700.00
0005432817895	5	Economy	6700.00
0005432262555	5	Economy	6700.00
0005432262539	5	Economy	6700.00
0005432817893	5	Economy	6700.00
0005432262547	5	Economy	6700.00
0005432817883	5	Economy	6700.00
0005432262541	5	Economy	6700.00
0005432262581	5	Economy	6700.00
0005433687705	5	Economy	6700.00
0005432817890	5	Economy	6700.00
0005432207695	5	Economy	6700.00
0005432817881	5	Economy	6700.00
0005432289034	5	Economy	6700.00
0005432817880	5	Economy	6700.00
0005432817884	5	Economy	6700.00
0005432817894	5	Economy	6700.00
0005432817896	5	Economy	6700.00
0005432262551	5	Economy	6700.00
0005432817899	5	Economy	7300.00
0005432262548	5	Economy	7300.00
0005432262577	5	Economy	7300.00
0005432262563	5	Economy	6700.00
0005432262561	5	Economy	6700.00
0005432817903	5	Economy	6700.00
0005432262562	5	Economy	6700.00
0005432817908	5	Economy	6700.00
0005432817906	5	Economy	6700.00
0005432207698	5	Economy	6700.00
0005432262550	5	Economy	6700.00
0005432262566	5	Economy	6700.00
0005432756835	5	Economy	6700.00
0005433687716	5	Economy	6700.00
0005432262582	5	Economy	6700.00
0005432817897	5	Economy	6700.00
0005432262568	5	Economy	6700.00
0005432262554	5	Economy	6700.00
0005432262560	5	Economy	6700.00
0005432817886	5	Economy	6700.00
0005432289033	5	Economy	6700.00
0005432262578	5	Economy	6700.00
0005432817898	5	Economy	6700.00
0005432262567	5	Economy	6700.00
0005432817901	5	Economy	6700.00
0005432262580	5	Economy	6700.00
0005432262542	5	Economy	6700.00
0005432817904	5	Economy	6700.00
0005432262544	5	Economy	6700.00
0005432817892	5	Economy	6700.00
0005432262576	5	Economy	6700.00
0005432817888	5	Economy	6700.00
0005432262564	5	Economy	6700.00
0005432262549	5	Economy	6700.00
0005432262538	5	Economy	6700.00
0005432262557	5	Economy	6700.00
0005432817882	5	Economy	6700.00
0005432262570	5	Economy	6700.00
0005432817891	5	Economy	6700.00
0005433687715	5	Economy	6700.00
0005432756863	5	Economy	6700.00
0005432756848	5	Economy	6700.00
0005433687711	5	Economy	6700.00
0005432262553	5	Economy	6700.00
0005432920153	8132	Business	20000.00
0005433102876	8132	Business	20000.00
0005432677633	8132	Business	20000.00
0005432392042	8132	Business	20000.00
0005433102885	8132	Business	20000.00
0005432020647	8132	Business	20000.00
0005433102908	8132	Business	20000.00
0005432020639	8132	Business	20000.00
0005433102887	8132	Business	20000.00
0005432920159	8132	Business	20000.00
0005432020648	8132	Business	20000.00
0005433102897	8132	Business	20000.00
0005432020636	8132	Business	20000.00
0005432020630	8132	Business	20000.00
0005432020651	8132	Business	20000.00
0005432020642	8132	Business	20000.00
0005433102891	8132	Business	20000.00
0005432677630	8132	Business	20000.00
0005432920161	8132	Business	20000.00
0005432920163	8132	Economy	7300.00
0005432020652	8132	Economy	7300.00
0005432677631	8132	Economy	7300.00
0005432020635	8132	Economy	6700.00
0005433102905	8132	Economy	6700.00
0005433102872	8132	Economy	6700.00
0005432020656	8132	Economy	6700.00
0005432920164	8132	Economy	6700.00
0005432020654	8132	Economy	6700.00
0005433102902	8132	Economy	6700.00
0005432020643	8132	Economy	6700.00
0005432920162	8132	Economy	6700.00
0005432920165	8132	Economy	6700.00
0005433102921	8132	Economy	6700.00
0005433102916	8132	Economy	6700.00
0005433102881	8132	Economy	6700.00
0005433102911	8132	Economy	6700.00
0005432020641	8132	Economy	6700.00
0005432044566	8132	Economy	6700.00
0005432020634	8132	Economy	6700.00
0005433102913	8132	Economy	6700.00
0005433102888	8132	Economy	6700.00
0005432751574	8132	Economy	6700.00
0005433102895	8132	Economy	6700.00
0005433102877	8132	Economy	6700.00
0005433102875	8132	Economy	6700.00
0005432044565	8132	Economy	6700.00
0005433102907	8132	Economy	6700.00
0005433102880	8132	Economy	6700.00
0005433102893	8132	Economy	6700.00
0005432920157	8132	Economy	6700.00
0005432753350	8132	Economy	6700.00
0005433102900	8132	Economy	6700.00
0005433102914	8132	Economy	6700.00
0005432020631	8132	Economy	6700.00
0005433102915	8132	Economy	6700.00
0005432044564	8132	Economy	6700.00
0005433102906	8132	Economy	6700.00
0005432751575	8132	Economy	6700.00
0005432020638	8132	Economy	6700.00
0005432020655	8132	Economy	6700.00
0005432920154	8132	Economy	6700.00
0005432392044	8132	Economy	6700.00
0005432920152	8132	Economy	7300.00
0005433102886	8132	Economy	7300.00
0005432045642	8132	Economy	7300.00
0005432920151	8132	Economy	7300.00
0005433102919	8132	Economy	6700.00
0005432392041	8132	Economy	6700.00
0005432020650	8132	Economy	6700.00
0005433102904	8132	Economy	6700.00
0005433102920	8132	Economy	6700.00
0005432020653	8132	Economy	6700.00
0005433102873	8132	Economy	6700.00
0005433102874	8132	Economy	6700.00
0005432020632	8132	Economy	6700.00
0005432920149	8132	Economy	6700.00
0005432920160	8132	Economy	6700.00
0005433102896	8132	Economy	6700.00
0005432920147	8132	Economy	6700.00
0005433102882	8132	Economy	6700.00
0005432020645	8132	Economy	6700.00
0005433102884	8132	Economy	6700.00
0005433102903	8132	Economy	6700.00
0005432677632	8132	Economy	6700.00
0005433102917	8132	Economy	6700.00
0005432020633	8132	Economy	6700.00
0005432753349	8132	Economy	6700.00
0005432920146	8132	Economy	6700.00
0005433102901	8132	Economy	6700.00
0005433102879	8132	Economy	6700.00
0005432920148	8132	Economy	6700.00
0005433102910	8132	Economy	6700.00
0005432020637	8132	Economy	6700.00
0005432020644	8132	Economy	6700.00
0005432020657	8132	Economy	6700.00
0005432920156	8132	Economy	6700.00
0005433102912	8132	Economy	6700.00
0005432751577	8132	Economy	6700.00
0005433102892	8132	Economy	6700.00
0005433102883	8132	Economy	6700.00
0005433102909	8132	Economy	6700.00
0005432020640	8132	Economy	6700.00
0005432920158	8132	Economy	6700.00
0005433102890	8132	Economy	6700.00
0005433102922	8132	Economy	6700.00
0005433102918	8132	Economy	6700.00
0005433102889	8132	Economy	6700.00
0005432020649	8132	Economy	6700.00
0005432020646	8132	Economy	6700.00
0005432920150	8132	Economy	6700.00
0005433102899	8132	Economy	6700.00
0005432751576	8132	Economy	6700.00
0005432392043	8132	Economy	6700.00
0005432920155	8132	Economy	6700.00
0005433102878	8132	Economy	6700.00
0005433102898	8132	Economy	6700.00
0005433102894	8132	Economy	6700.00
0005432677634	8132	Economy	6700.00
0005432002105	8130	Business	20000.00
0005432817581	8130	Business	20000.00
0005432817692	8130	Business	20000.00
0005432817625	8130	Economy	7300.00
0005432817771	8130	Business	20000.00
0005432817612	8130	Economy	7300.00
0005432901862	8130	Economy	6700.00
0005432901859	8130	Economy	6700.00
0005432901853	8130	Economy	6700.00
0005432817641	8130	Economy	6700.00
0005432817595	8130	Economy	6700.00
0005432817611	8130	Economy	6700.00
0005432901863	8130	Economy	6700.00
0005432817691	8130	Economy	6700.00
0005432901851	8130	Economy	6700.00
0005432901854	8130	Economy	6700.00
0005432817613	8130	Economy	6700.00
0005432901856	8130	Economy	6700.00
0005432817610	8130	Economy	6700.00
0005432901865	8130	Economy	6700.00
0005432817504	8130	Economy	6700.00
0005432817770	8130	Economy	6700.00
0005432901867	8130	Economy	6700.00
0005432817740	8130	Economy	6700.00
0005432817619	8130	Economy	6700.00
0005432817464	8130	Economy	6700.00
0005432817659	8130	Economy	6700.00
0005432817599	8130	Economy	7300.00
0005432817661	8130	Economy	6700.00
0005432901866	8130	Economy	7300.00
0005432817694	8130	Economy	6700.00
0005432817572	8130	Economy	6700.00
0005432901861	8130	Economy	6700.00
0005432817644	8130	Economy	6700.00
0005432817723	8130	Economy	6700.00
0005432901855	8130	Economy	6700.00
0005432901852	8130	Economy	6700.00
0005432817678	8130	Economy	6700.00
0005432002106	8130	Economy	6700.00
0005432817600	8130	Economy	6700.00
0005432901864	8130	Economy	6700.00
0005432817658	8130	Economy	6700.00
0005432002107	8130	Economy	6700.00
0005432817642	8130	Economy	6700.00
0005432817724	8130	Economy	6700.00
0005432817628	8130	Economy	6700.00
0005432817505	8130	Economy	6700.00
0005432817631	8130	Economy	6700.00
0005432901868	8130	Economy	6700.00
0005432901857	8130	Economy	6700.00
0005432901858	8130	Economy	6700.00
0005432901860	8130	Economy	6700.00
0005432817643	8130	Economy	6700.00
0005434175763	9672	Economy	6900.00
0005433870763	9672	Economy	6900.00
0005433870762	9672	Economy	6900.00
0005434175815	32340	Economy	6900.00
0005434175812	32340	Economy	6900.00
0005434175813	32340	Economy	6900.00
0005433870747	32340	Economy	6900.00
0005434175811	32340	Economy	6900.00
0005434175814	32340	Economy	6900.00
0005432799873	3481	Business	35000.00
0005434938417	3481	Business	35000.00
0005434879589	3481	Business	35000.00
0005435126969	3481	Business	35000.00
0005435126974	3481	Business	35000.00
0005432188656	3481	Business	35000.00
0005432613920	3481	Business	35000.00
0005434427040	3481	Business	35000.00
0005434879608	3481	Business	35000.00
0005434427041	3481	Business	35000.00
0005435126949	3481	Business	35000.00
0005432183497	3481	Business	35000.00
0005434879607	3481	Business	35000.00
0005434938427	3481	Business	35000.00
0005432611765	3481	Business	35000.00
0005434427035	3481	Business	35000.00
0005434938430	3481	Business	35000.00
0005434879621	3481	Business	35000.00
0005434879601	3481	Business	35000.00
0005435126964	3481	Business	35000.00
0005432799859	3481	Business	35000.00
0005434879555	3481	Comfort	19900.00
0005434879597	3481	Comfort	19900.00
0005434879576	3481	Comfort	19900.00
0005435126938	3481	Comfort	19900.00
0005434427038	3481	Comfort	19900.00
0005434427026	3481	Comfort	19900.00
0005434879539	3481	Comfort	19900.00
0005432613919	3481	Comfort	19900.00
0005435913949	3481	Comfort	19900.00
0005435126970	3481	Comfort	19900.00
0005432183498	3481	Comfort	19900.00
0005434879625	3481	Comfort	19900.00
0005435126962	3481	Comfort	19900.00
0005432188653	3481	Comfort	19900.00
0005435126956	3481	Comfort	19900.00
0005434879622	3481	Comfort	19900.00
0005434879624	3481	Comfort	19900.00
0005432799857	3481	Comfort	19900.00
0005434427028	3481	Comfort	19900.00
0005434938419	3481	Comfort	19900.00
0005434427020	3481	Comfort	19900.00
0005434879614	3481	Comfort	19900.00
0005435126959	3481	Comfort	19900.00
0005435126954	3481	Comfort	19900.00
0005435626436	3481	Comfort	19900.00
0005434879591	3481	Comfort	19900.00
0005434879556	3481	Comfort	19900.00
0005434938425	3481	Comfort	19900.00
0005432611766	3481	Comfort	19900.00
0005434938422	3481	Comfort	19900.00
0005435126955	3481	Comfort	19900.00
0005434879572	3481	Comfort	19900.00
0005435913942	3481	Economy	11700.00
0005435126948	3481	Economy	11700.00
0005434427027	3481	Economy	11700.00
0005435126939	3481	Economy	11700.00
0005434879549	3481	Economy	11700.00
0005434879570	3481	Economy	11700.00
0005432799870	3481	Economy	11700.00
0005432799854	3481	Economy	11700.00
0005435626435	3481	Economy	11700.00
0005434879590	3481	Economy	11700.00
0005435126952	3481	Economy	11700.00
0005434879573	3481	Economy	11700.00
0005434879565	3481	Economy	11700.00
0005434427031	3481	Economy	11700.00
0005435902858	3481	Economy	11700.00
0005432799874	3481	Economy	11700.00
0005435626442	3481	Economy	11700.00
0005432799865	3481	Economy	11700.00
0005435126978	3481	Economy	11700.00
0005434879538	3481	Economy	11700.00
0005434427033	3481	Economy	11700.00
0005435902761	3481	Economy	11700.00
0005432799863	3481	Economy	11700.00
0005435126947	3481	Economy	11700.00
0005434879599	3481	Economy	11700.00
0005434879616	3481	Economy	11700.00
0005432188655	3481	Economy	11700.00
0005434879605	3481	Economy	11700.00
0005434427042	3481	Economy	11700.00
0005435126942	3481	Economy	11700.00
0005434879585	3481	Economy	11700.00
0005434879628	3481	Economy	11700.00
0005434879615	3481	Economy	11700.00
0005435126971	3481	Economy	11700.00
0005432799869	3481	Economy	11700.00
0005435913940	3481	Economy	11700.00
0005435126976	3481	Economy	11700.00
0005435126960	3481	Economy	11700.00
0005434879606	3481	Economy	11700.00
0005435126951	3481	Economy	11700.00
0005434879583	3481	Economy	11700.00
0005435913943	3481	Economy	11700.00
0005434879595	3481	Economy	11700.00
0005435902840	3481	Economy	11700.00
0005435126940	3481	Economy	11700.00
0005435626441	3481	Economy	11700.00
0005434879546	3481	Economy	11700.00
0005435902722	3481	Economy	11700.00
0005434427023	3481	Economy	11700.00
0005434427032	3481	Economy	11700.00
0005434879559	3481	Economy	12800.00
0005434427030	3481	Economy	11700.00
0005434879592	3481	Economy	12800.00
0005432613921	3481	Economy	11700.00
0005434427029	3481	Economy	11700.00
0005434427049	3481	Economy	11700.00
0005434879619	3481	Economy	11700.00
0005434427045	3481	Economy	12800.00
0005435902827	3481	Economy	12800.00
0005432799860	3481	Economy	11700.00
0005434879562	3481	Economy	11700.00
0005434879577	3481	Economy	11700.00
0005434427043	3481	Economy	11700.00
0005434879542	3481	Economy	11700.00
0005432611764	3481	Economy	11700.00
0005434938418	3481	Economy	11700.00
0005435126980	3481	Economy	11700.00
0005434879545	3481	Economy	11700.00
0005434879560	3481	Economy	11700.00
0005432799875	3481	Economy	11700.00
0005434879611	3481	Economy	11700.00
0005435126975	3481	Economy	11700.00
0005435902866	3481	Economy	11700.00
0005435126972	3481	Economy	11700.00
0005432799877	3481	Economy	11700.00
0005434879582	3481	Economy	11700.00
0005435126965	3481	Economy	11700.00
0005432799858	3481	Economy	11700.00
0005435902785	3481	Economy	11700.00
0005434879632	3481	Economy	11700.00
0005435126953	3481	Economy	11700.00
0005434879575	3481	Economy	11700.00
0005434938431	3481	Economy	11700.00
0005434879568	3481	Economy	11700.00
0005435126957	3481	Economy	11700.00
0005434427034	3481	Economy	11700.00
0005435902829	3481	Economy	11700.00
0005435126966	3481	Economy	11700.00
0005435902809	3481	Economy	11700.00
0005434879579	3481	Economy	11700.00
0005435626439	3481	Economy	11700.00
0005434938429	3481	Economy	11700.00
0005435126958	3481	Economy	11700.00
0005435902828	3481	Economy	11700.00
0005435126963	3481	Economy	11700.00
0005435626433	3481	Economy	11700.00
0005435902780	3481	Economy	11700.00
0005434879554	3481	Economy	11700.00
0005434879574	3481	Economy	11700.00
0005432799871	3481	Economy	11700.00
0005435902815	3481	Economy	11700.00
0005434427037	3481	Economy	11700.00
0005434879603	3481	Economy	11700.00
0005434879553	3481	Economy	11700.00
0005435902839	3481	Economy	11700.00
0005434427025	3481	Economy	11700.00
0005435902786	3481	Economy	11700.00
0005435902814	3481	Economy	11700.00
0005432799876	3481	Economy	11700.00
0005434938421	3481	Economy	11700.00
0005435126943	3481	Economy	11700.00
0005434427019	3481	Economy	11700.00
0005435126941	3481	Economy	11700.00
0005434879598	3481	Economy	11700.00
0005435913941	3481	Economy	11700.00
0005434879540	3481	Economy	11700.00
0005432799856	3481	Economy	11700.00
0005434879544	3481	Economy	11700.00
0005434879620	3481	Economy	11700.00
0005432183499	3481	Economy	11700.00
0005434879609	3481	Economy	11700.00
0005435126968	3481	Economy	11700.00
0005432799872	3481	Economy	11700.00
0005432799851	3481	Economy	11700.00
0005434427048	3481	Economy	11700.00
0005434879558	3481	Economy	11700.00
0005432799850	3481	Economy	11700.00
0005434879593	3481	Economy	11700.00
0005434879627	3481	Economy	11700.00
0005434427039	3481	Economy	11700.00
0005434879604	3481	Economy	11700.00
0005434879557	3481	Economy	11700.00
0005434879567	3481	Economy	11700.00
0005434879581	3481	Economy	11700.00
0005434427022	3481	Economy	11700.00
0005434879617	3481	Economy	11700.00
0005434879596	3481	Economy	11700.00
0005434427044	3481	Economy	11700.00
0005434879580	3481	Economy	11700.00
0005434938413	3481	Economy	11700.00
0005434938432	3481	Economy	12800.00
0005434879629	3481	Economy	12800.00
0005435126977	3481	Economy	11700.00
0005434879626	3481	Economy	11700.00
0005435126946	3481	Economy	11700.00
0005434879566	3481	Economy	11700.00
0005434879578	3481	Economy	11700.00
0005435126979	3481	Economy	11700.00
0005434879543	3481	Economy	11700.00
0005434879563	3481	Economy	11700.00
0005435126945	3481	Economy	11700.00
0005434879584	3481	Economy	11700.00
0005434427047	3481	Economy	11700.00
0005435902760	3481	Economy	11700.00
0005435126967	3481	Economy	11700.00
0005435913938	3481	Economy	11700.00
0005434938414	3481	Economy	11700.00
0005435626434	3481	Economy	11700.00
0005435902788	3481	Economy	11700.00
0005435126973	3481	Economy	11700.00
0005432799862	3481	Economy	11700.00
0005434879547	3481	Economy	11700.00
0005432188654	3481	Economy	11700.00
0005434879561	3481	Economy	11700.00
0005435902810	3481	Economy	11700.00
0005432799853	3481	Economy	11700.00
0005434879602	3481	Economy	11700.00
0005434938423	3481	Economy	11700.00
0005435626438	3481	Economy	11700.00
0005434938416	3481	Economy	11700.00
0005432613922	3481	Economy	11700.00
0005434427021	3481	Economy	11700.00
0005432799868	3481	Economy	11700.00
0005434879569	3481	Economy	11700.00
0005434879550	3481	Economy	11700.00
0005432799852	3481	Economy	11700.00
0005434879623	3481	Economy	11700.00
0005435913939	3481	Economy	11700.00
0005435126950	3481	Economy	11700.00
0005435902813	3481	Economy	11700.00
0005434879631	3481	Economy	11700.00
0005434938415	3481	Economy	11700.00
0005434879630	3481	Economy	11700.00
0005434879571	3481	Economy	11700.00
0005434879541	3481	Economy	11700.00
0005432799866	3481	Economy	11700.00
0005435126944	3481	Economy	11700.00
0005434879551	3481	Economy	11700.00
0005434879612	3481	Economy	11700.00
0005434879588	3481	Economy	11700.00
0005434879613	3481	Economy	11700.00
0005434879618	3481	Economy	11700.00
0005434427024	3481	Economy	11700.00
0005435902777	3481	Economy	11700.00
0005434879564	3481	Economy	11700.00
0005434938426	3481	Economy	11700.00
0005434938424	3481	Economy	11700.00
0005434938420	3481	Economy	11700.00
0005434427036	3481	Economy	11700.00
0005435626440	3481	Economy	11700.00
0005434879610	3481	Economy	11700.00
0005434938428	3481	Economy	11700.00
0005432799864	3481	Economy	11700.00
0005435902816	3481	Economy	11700.00
0005434879600	3481	Economy	11700.00
0005434879548	3481	Economy	11700.00
0005432799867	3481	Economy	11700.00
0005435626437	3481	Economy	11700.00
0005434427046	3481	Economy	11700.00
0005435126961	3481	Economy	11700.00
0005434879587	3481	Economy	11700.00
0005434879552	3481	Economy	11700.00
0005434879586	3481	Economy	11700.00
0005432799861	3481	Economy	11700.00
0005432799855	3481	Economy	11700.00
0005434879594	3481	Economy	11700.00
0005432799595	14569	Business	35000.00
0005434878739	14569	Business	35000.00
0005434426716	14569	Business	35000.00
0005432799639	14569	Business	35000.00
0005432799643	14569	Business	35000.00
0005435626255	14569	Business	35000.00
0005434879141	14569	Business	35000.00
0005434938314	14569	Business	35000.00
0005432799607	14569	Business	35000.00
0005435126612	14569	Business	35000.00
0005435914713	14569	Business	35000.00
0005434878887	14569	Business	35000.00
0005435626263	14569	Business	35000.00
0005434938223	14569	Business	35000.00
0005435914716	14569	Business	35000.00
0005435126500	14569	Business	35000.00
0005434878707	14569	Business	35000.00
0005435902961	14569	Business	35000.00
0005435126625	14569	Business	35000.00
0005434878886	14569	Comfort	19900.00
0005432607568	14569	Comfort	19900.00
0005434878747	14569	Comfort	19900.00
0005434878393	14569	Comfort	19900.00
0005434426833	14569	Comfort	19900.00
0005434878490	14569	Comfort	19900.00
0005435126678	14569	Comfort	19900.00
0005434426816	14569	Comfort	19900.00
0005434426810	14569	Comfort	19900.00
0005434879098	14569	Comfort	19900.00
0005434878713	14569	Comfort	19900.00
0005434878974	14569	Comfort	19900.00
0005432059533	14569	Comfort	19900.00
0005434426788	14569	Comfort	19900.00
0005434426936	14569	Comfort	19900.00
0005434878626	14569	Comfort	19900.00
0005434878396	14569	Comfort	19900.00
0005434878997	14569	Comfort	19900.00
0005435626145	14569	Comfort	19900.00
0005432607569	14569	Comfort	19900.00
0005432799650	14569	Comfort	19900.00
0005435902960	14569	Comfort	19900.00
0005434878541	14569	Comfort	19900.00
0005434878436	14569	Comfort	19900.00
0005434938267	14569	Comfort	19900.00
0005434878852	14569	Comfort	19900.00
0005434879116	14569	Comfort	19900.00
0005432799718	14569	Comfort	19900.00
0005434426930	14569	Comfort	19900.00
0005434879209	14569	Comfort	19900.00
0005432607586	14569	Economy	11700.00
0005434938274	14569	Economy	11700.00
0005434878683	14569	Economy	11700.00
0005434878963	14569	Economy	11700.00
0005435902959	14569	Economy	11700.00
0005434878710	14569	Economy	11700.00
0005434878999	14569	Economy	11700.00
0005435626222	14569	Economy	11700.00
0005435626269	14569	Economy	11700.00
0005434879046	14569	Economy	11700.00
0005434426784	14569	Economy	11700.00
0005434426828	14569	Economy	11700.00
0005432799616	14569	Economy	11700.00
0005434878656	14569	Economy	11700.00
0005435914715	14569	Economy	11700.00
0005435126512	14569	Economy	11700.00
0005435902956	14569	Economy	11700.00
0005435626264	14569	Economy	11700.00
0005435902963	14569	Economy	11700.00
0005434878906	14569	Economy	11700.00
0005434878866	14569	Economy	11700.00
0005434878919	14569	Economy	11700.00
0005435126539	14569	Economy	11700.00
0005434426935	14569	Economy	11700.00
0005435126632	14569	Economy	11700.00
0005434426727	14569	Economy	11700.00
0005435902964	14569	Economy	11700.00
0005432799598	14569	Economy	11700.00
0005434878752	14569	Economy	11700.00
0005434878657	14569	Economy	11700.00
0005434878652	14569	Economy	11700.00
0005435902966	14569	Economy	11700.00
0005434938244	14569	Economy	11700.00
0005435626221	14569	Economy	11700.00
0005434878543	14569	Economy	11700.00
0005434426730	14569	Economy	11700.00
0005435626272	14569	Economy	11700.00
0005432799668	14569	Economy	11700.00
0005434426787	14569	Economy	11700.00
0005434426826	14569	Economy	11700.00
0005434878960	14569	Economy	11700.00
0005434878788	14569	Economy	11700.00
0005435126514	14569	Economy	11700.00
0005434879076	14569	Economy	11700.00
0005434938309	14569	Economy	11700.00
0005435126572	14569	Economy	11700.00
0005432799536	14569	Economy	12800.00
0005432611709	14569	Economy	11700.00
0005434938327	14569	Economy	12800.00
0005435126548	14569	Economy	12800.00
0005435626276	14569	Economy	11700.00
0005432799519	14569	Economy	12800.00
0005435126483	14569	Economy	12800.00
0005434878627	14569	Economy	12800.00
0005432799683	14569	Economy	11700.00
0005434878540	14569	Economy	11700.00
0005434878952	14569	Economy	11700.00
0005435126549	14569	Economy	11700.00
0005434878613	14569	Economy	11700.00
0005434878925	14569	Economy	11700.00
0005435126565	14569	Economy	11700.00
0005434878116	14569	Economy	11700.00
0005434938229	14569	Economy	11700.00
0005435914717	14569	Economy	11700.00
0005434878611	14569	Economy	11700.00
0005434426789	14569	Economy	11700.00
0005434878973	14569	Economy	11700.00
0005435126411	14569	Economy	11700.00
0005434426827	14569	Economy	11700.00
0005434878772	14569	Economy	11700.00
0005435913977	14569	Economy	11700.00
0005432799596	14569	Economy	11700.00
0005434878961	14569	Economy	11700.00
0005435902957	14569	Economy	11700.00
0005435126424	14569	Economy	11700.00
0005434426655	14569	Economy	11700.00
0005434879075	14569	Economy	11700.00
0005434878307	14569	Economy	11700.00
0005434878870	14569	Economy	11700.00
0005434938245	14569	Economy	11700.00
0005434938326	14569	Economy	11700.00
0005435626246	14569	Economy	11700.00
0005434878551	14569	Economy	11700.00
0005434878146	14569	Economy	11700.00
0005434938222	14569	Economy	11700.00
0005432611708	14569	Economy	11700.00
0005434878450	14569	Economy	11700.00
0005435902965	14569	Economy	11700.00
0005435626277	14569	Economy	11700.00
0005434878716	14569	Economy	11700.00
0005432799660	14569	Economy	11700.00
0005435914712	14569	Economy	11700.00
0005434426862	14569	Economy	11700.00
0005434938275	14569	Economy	11700.00
0005434879012	14569	Economy	11700.00
0005434426859	14569	Economy	11700.00
0005434878738	14569	Economy	11700.00
0005435126522	14569	Economy	11700.00
0005435902958	14569	Economy	11700.00
0005435626252	14569	Economy	11700.00
0005434426817	14569	Economy	11700.00
0005435126423	14569	Economy	11700.00
0005434879106	14569	Economy	11700.00
0005434878711	14569	Economy	11700.00
0005434426698	14569	Economy	11700.00
0005432799624	14569	Economy	11700.00
0005435626265	14569	Economy	11700.00
0005434878926	14569	Economy	11700.00
0005434879142	14569	Economy	11700.00
0005434878773	14569	Economy	11700.00
0005434878883	14569	Economy	11700.00
0005434878794	14569	Economy	11700.00
0005434426704	14569	Economy	11700.00
0005434879013	14569	Economy	11700.00
0005432799625	14569	Economy	11700.00
0005434426771	14569	Economy	11700.00
0005434878822	14569	Economy	11700.00
0005435902951	14569	Economy	11700.00
0005435902950	14569	Economy	11700.00
0005434878998	14569	Economy	11700.00
0005432799606	14569	Economy	11700.00
0005435626262	14569	Economy	11700.00
0005435126609	14569	Economy	11700.00
0005434878795	14569	Economy	11700.00
0005434879138	14569	Economy	11700.00
0005435626240	14569	Economy	11700.00
0005434938308	14569	Economy	11700.00
0005434879044	14569	Economy	11700.00
0005432607579	14569	Economy	11700.00
0005434426779	14569	Economy	11700.00
0005432799617	14569	Economy	12800.00
0005432611723	14569	Economy	12800.00
0005432799687	14569	Economy	12800.00
0005435902953	14569	Economy	12800.00
0005435126502	14569	Economy	11700.00
0005434878487	14569	Economy	11700.00
0005435126646	14569	Economy	11700.00
0005434426778	14569	Economy	11700.00
0005432799642	14569	Economy	11700.00
0005434878779	14569	Economy	11700.00
0005434878665	14569	Economy	11700.00
0005434426773	14569	Economy	11700.00
0005435914714	14569	Economy	11700.00
0005434878762	14569	Economy	11700.00
0005435626254	14569	Economy	11700.00
0005434426832	14569	Economy	11700.00
0005435126781	14569	Economy	11700.00
0005434426772	14569	Economy	11700.00
0005435126610	14569	Economy	11700.00
0005434878614	14569	Economy	11700.00
0005434879011	14569	Economy	11700.00
0005434878941	14569	Economy	11700.00
0005434426699	14569	Economy	11700.00
0005435913979	14569	Economy	11700.00
0005434426770	14569	Economy	11700.00
0005435126782	14569	Economy	11700.00
0005435126487	14569	Economy	11700.00
0005434878678	14569	Economy	11700.00
0005434878982	14569	Economy	11700.00
0005434878787	14569	Economy	11700.00
0005434879099	14569	Economy	11700.00
0005434878865	14569	Economy	11700.00
0005434426809	14569	Economy	11700.00
0005434938268	14569	Economy	11700.00
0005434938265	14569	Economy	11700.00
0005434426742	14569	Economy	11700.00
0005432059532	14569	Economy	11700.00
0005435914711	14569	Economy	11700.00
0005434878712	14569	Economy	11700.00
0005435126498	14569	Economy	11700.00
0005435913978	14569	Economy	11700.00
0005434938293	14569	Economy	11700.00
0005434878899	14569	Economy	11700.00
0005434878715	14569	Economy	11700.00
0005435626175	14569	Economy	11700.00
0005435126526	14569	Economy	11700.00
0005434878630	14569	Economy	11700.00
0005434878761	14569	Economy	11700.00
0005435902954	14569	Economy	11700.00
0005434878966	14569	Economy	11700.00
0005434426811	14569	Economy	11700.00
0005435126484	14569	Economy	11700.00
0005435626165	14569	Economy	11700.00
0005432799594	14569	Economy	11700.00
0005434878563	14569	Economy	11700.00
0005435126664	14569	Economy	11700.00
0005435126647	14569	Economy	11700.00
0005434878682	14569	Economy	11700.00
0005434426863	14569	Economy	11700.00
0005432799644	14569	Economy	11700.00
0005434878962	14569	Economy	11700.00
0005435626268	14569	Economy	11700.00
0005434878781	14569	Economy	11700.00
0005434878889	14569	Economy	11700.00
0005434426748	14569	Economy	11700.00
0005435902952	14569	Economy	11700.00
0005435902962	14569	Economy	11700.00
0005434878780	14569	Economy	11700.00
0005432799554	14569	Economy	11700.00
0005435626273	14569	Economy	11700.00
0005434878530	14569	Economy	11700.00
0005434878809	14569	Economy	11700.00
0005432799520	14569	Economy	11700.00
0005434878397	14569	Economy	11700.00
0005434878702	14569	Economy	11700.00
0005434878980	14569	Economy	11700.00
0005434878948	14569	Economy	11700.00
0005434879143	14569	Economy	11700.00
0005435902955	14569	Economy	11700.00
0005435626232	14569	Economy	11700.00
0005434325811	3641	Economy	16300.00
0005434325817	3641	Economy	14800.00
0005434325818	3641	Economy	14800.00
0005435889919	3641	Economy	14800.00
0005434325815	3641	Economy	14800.00
0005434325820	3641	Economy	14800.00
0005434325819	3641	Economy	14800.00
0005434325821	3641	Economy	14800.00
0005434325816	3641	Economy	14800.00
0005434325813	3641	Economy	14800.00
0005434312349	3641	Economy	14800.00
0005434325812	3641	Economy	14800.00
0005435889939	3641	Economy	14800.00
0005434325814	3641	Economy	14800.00
0005434312348	3641	Economy	14800.00
0005434325754	15602	Economy	16300.00
0005435889985	15602	Economy	16300.00
0005434325759	15602	Economy	16300.00
0005435889981	15602	Economy	16300.00
0005434325760	15602	Economy	14800.00
0005435889984	15602	Economy	14800.00
0005434325724	15602	Economy	14800.00
0005434325755	15602	Economy	14800.00
0005435889982	15602	Economy	14800.00
0005434325753	15602	Economy	14800.00
0005435889983	15602	Economy	14800.00
0005434325705	15602	Economy	14800.00
0005434325704	15602	Economy	14800.00
0005434325719	15602	Economy	14800.00
0005434325725	15602	Economy	14800.00
0005434325758	15602	Economy	14800.00
0005434325669	15602	Economy	14800.00
0005434325735	15602	Economy	14800.00
0005435889980	15602	Economy	14800.00
0005434325745	15602	Economy	14800.00
0005434325741	15602	Economy	14800.00
0005433420484	653	Economy	4500.00
0005435957921	653	Economy	4500.00
0005433420447	653	Economy	4100.00
0005433420442	653	Economy	4100.00
0005433420443	653	Economy	4100.00
0005435957915	653	Economy	4100.00
0005435957911	653	Economy	4100.00
0005435957920	653	Economy	4100.00
0005433420428	653	Economy	4100.00
0005435957910	653	Economy	4100.00
0005435957918	653	Economy	4100.00
0005435957909	653	Economy	4100.00
0005433420466	653	Economy	4100.00
0005433420481	653	Economy	4100.00
0005435957906	653	Economy	4100.00
0005435957917	653	Economy	4100.00
0005435957919	653	Economy	4100.00
0005433420448	653	Economy	4100.00
0005433420480	653	Economy	4100.00
0005433420453	653	Economy	4100.00
0005435957914	653	Economy	4100.00
0005435957916	653	Economy	4100.00
0005435957907	653	Economy	4100.00
0005433420465	653	Economy	4100.00
0005433420437	653	Economy	4100.00
0005435957908	653	Economy	4100.00
0005433420446	653	Economy	4100.00
0005433420425	653	Economy	4100.00
0005435957912	653	Economy	4100.00
0005435957913	653	Economy	4100.00
0005433420471	653	Economy	4100.00
0005433420523	15179	Economy	4500.00
0005435957737	15179	Economy	4500.00
0005435957807	15179	Economy	4500.00
0005433420520	15179	Economy	4100.00
0005433420522	15179	Economy	4100.00
0005435957790	15179	Economy	4100.00
0005433420529	15179	Economy	4100.00
0005435957766	15179	Economy	4100.00
0005435957837	15179	Economy	4100.00
0005435957840	15179	Economy	4100.00
0005435957823	15179	Economy	4100.00
0005435957841	15179	Economy	4100.00
0005435957824	15179	Economy	4100.00
0005433420524	15179	Economy	4100.00
0005435957780	15179	Economy	4100.00
0005435957763	15179	Economy	4100.00
0005435957772	15179	Economy	4100.00
0005435957765	15179	Economy	4100.00
0005435957838	15179	Economy	4100.00
0005435957762	15179	Economy	4100.00
0005433420528	15179	Economy	4100.00
0005433420521	15179	Economy	4100.00
0005435957764	15179	Economy	4100.00
0005435957827	15179	Economy	4100.00
0005435957779	15179	Economy	4100.00
0005435957771	15179	Economy	4100.00
0005435957828	15179	Economy	4100.00
0005433420527	15179	Economy	4100.00
0005433420526	15179	Economy	4100.00
0005433420525	15179	Economy	4100.00
0005435957797	15179	Economy	4100.00
0005435217746	31771	Economy	25500.00
0005435217741	31771	Economy	25500.00
0005435217739	31771	Economy	25500.00
0005435216618	31771	Economy	25500.00
0005435216620	31771	Economy	25500.00
0005435216617	31771	Economy	25500.00
0005435216619	31771	Economy	25500.00
0005435217742	31771	Economy	25500.00
0005435217740	31771	Economy	25500.00
0005435217744	31771	Economy	25500.00
0005435216615	31771	Economy	25500.00
0005435217745	31771	Economy	25500.00
0005435217743	31771	Economy	25500.00
0005435216616	31771	Economy	25500.00
0005434995333	6704	Business	94000.00
0005434995337	6704	Business	94000.00
0005434995330	6704	Economy	31300.00
0005434995329	6704	Economy	31300.00
0005434995326	6704	Economy	31300.00
0005434995336	6704	Economy	31300.00
0005434995334	6704	Economy	31300.00
0005434995335	6704	Economy	31300.00
0005434995327	6704	Economy	31300.00
0005434995338	6704	Economy	31300.00
0005434995331	6704	Economy	31300.00
0005434995332	6704	Economy	31300.00
0005434995328	6704	Economy	31300.00
0005435629421	8953	Economy	10400.00
0005435629422	8953	Economy	10400.00
0005434247184	16091	Economy	10400.00
0005434247185	16091	Economy	10400.00
0005434247183	16091	Economy	10400.00
0005434247186	16091	Economy	10400.00
0005434467796	4011	Economy	21200.00
0005434467791	4011	Economy	21200.00
0005434467795	4011	Economy	21200.00
0005434467793	4011	Economy	21200.00
0005434467792	4011	Economy	21200.00
0005434467794	4011	Economy	21200.00
0005434467797	4011	Economy	21200.00
0005434467766	23207	Economy	21200.00
0005434467784	23207	Economy	21200.00
0005434467769	23207	Economy	21200.00
0005434467785	23207	Economy	21200.00
0005434467781	23207	Economy	21200.00
0005434467768	23207	Economy	21200.00
0005434467775	23207	Economy	21200.00
0005434467765	23207	Economy	21200.00
0005434467767	23207	Economy	21200.00
0005434467776	23207	Economy	21200.00
0005434467779	23207	Economy	21200.00
0005434096765	20175	Economy	14700.00
0005434096766	20175	Economy	13400.00
0005434096768	20175	Economy	13400.00
0005434096771	20175	Economy	13400.00
0005434096769	20175	Economy	13400.00
0005434096772	20175	Economy	13400.00
0005434096767	20175	Economy	13400.00
0005434096770	20175	Economy	13400.00
0005432646175	6829	Business	87700.00
0005432646172	6829	Business	87700.00
0005432646183	6829	Business	87700.00
0005435229474	6829	Business	87700.00
0005432646163	6829	Business	87700.00
0005432646176	6829	Business	87700.00
0005435229481	6829	Business	87700.00
0005432646152	6829	Business	87700.00
0005435229439	6829	Business	87700.00
0005432646174	6829	Business	87700.00
0005435229478	6829	Business	87700.00
0005435229476	6829	Economy	29200.00
0005432646181	6829	Economy	29200.00
0005432646153	6829	Economy	29200.00
0005435229482	6829	Economy	29200.00
0005432646179	6829	Economy	29200.00
0005432646182	6829	Economy	29200.00
0005435229437	6829	Economy	32200.00
0005432646162	6829	Economy	32200.00
0005432646164	6829	Economy	32200.00
0005432646151	6829	Economy	29200.00
0005435229479	6829	Economy	29200.00
0005432646158	6829	Economy	29200.00
0005435229484	6829	Economy	29200.00
0005435229431	6829	Economy	29200.00
0005432646161	6829	Economy	29200.00
0005435229477	6829	Economy	29200.00
0005432646147	6829	Economy	29200.00
0005432646156	6829	Economy	29200.00
0005435229438	6829	Economy	29200.00
0005432646148	6829	Economy	29200.00
0005435229453	6829	Economy	29200.00
0005435229447	6829	Economy	29200.00
0005432646167	6829	Economy	29200.00
0005435229475	6829	Economy	29200.00
0005432646178	6829	Economy	29200.00
0005432646177	6829	Economy	29200.00
0005432646171	6829	Economy	29200.00
0005432646184	6829	Economy	29200.00
0005432646169	6829	Economy	29200.00
0005432646150	6829	Economy	29200.00
0005432646166	6829	Economy	29200.00
0005435229429	6829	Economy	29200.00
0005432646160	6829	Economy	29200.00
0005432646149	6829	Economy	29200.00
0005435229483	6829	Economy	29200.00
0005432646154	6829	Economy	29200.00
0005432646170	6829	Economy	29200.00
0005432646165	6829	Economy	29200.00
0005432646159	6829	Economy	29200.00
0005432646146	6829	Economy	29200.00
0005435229457	6829	Economy	29200.00
0005432646180	6829	Economy	29200.00
0005432646155	6829	Economy	29200.00
0005432646173	6829	Economy	29200.00
0005435229454	6829	Economy	29200.00
0005435229452	6829	Economy	29200.00
0005432646157	6829	Economy	29200.00
0005432646168	6829	Economy	29200.00
0005435229523	25105	Business	87700.00
0005432646065	25105	Business	87700.00
0005435229515	25105	Business	87700.00
0005432646038	25105	Business	87700.00
0005432646010	25105	Business	87700.00
0005432646062	25105	Business	87700.00
0005435229529	25105	Business	87700.00
0005435229511	25105	Business	87700.00
0005432645991	25105	Business	87700.00
0005432645950	25105	Business	87700.00
0005435229520	25105	Business	87700.00
0005432646042	25105	Business	87700.00
0005432646044	25105	Economy	29200.00
0005435229531	25105	Economy	29200.00
0005432645967	25105	Economy	29200.00
0005432646023	25105	Economy	29200.00
0005432646037	25105	Economy	29200.00
0005432646013	25105	Economy	29200.00
0005435229535	25105	Economy	29200.00
0005432646054	25105	Economy	29200.00
0005432646004	25105	Economy	29200.00
0005432646011	25105	Economy	29200.00
0005432646063	25105	Economy	32200.00
0005432645995	25105	Economy	32200.00
0005435229514	25105	Economy	32200.00
0005432646050	25105	Economy	32200.00
0005432646046	25105	Economy	32200.00
0005435229534	25105	Economy	29200.00
0005432646005	25105	Economy	29200.00
0005435229517	25105	Economy	29200.00
0005435229522	25105	Economy	29200.00
0005432645983	25105	Economy	29200.00
0005432646029	25105	Economy	29200.00
0005432646090	25105	Economy	29200.00
0005432646067	25105	Economy	29200.00
0005435229512	25105	Economy	29200.00
0005432645998	25105	Economy	29200.00
0005432646018	25105	Economy	29200.00
0005435229521	25105	Economy	29200.00
0005435229527	25105	Economy	29200.00
0005432646114	25105	Economy	29200.00
0005435229509	25105	Economy	29200.00
0005432646040	25105	Economy	29200.00
0005432645961	25105	Economy	29200.00
0005432646027	25105	Economy	29200.00
0005432646058	25105	Economy	29200.00
0005432646066	25105	Economy	29200.00
0005432646034	25105	Economy	29200.00
0005432645960	25105	Economy	29200.00
0005432646025	25105	Economy	29200.00
0005432645994	25105	Economy	29200.00
0005432645996	25105	Economy	29200.00
0005432646113	25105	Economy	29200.00
0005435229525	25105	Economy	29200.00
0005432646020	25105	Economy	29200.00
0005432645984	25105	Economy	29200.00
0005432646052	25105	Economy	29200.00
0005432646043	25105	Economy	29200.00
0005432646032	25105	Economy	29200.00
0005432646028	25105	Economy	29200.00
0005432646059	25105	Economy	29200.00
0005432646047	25105	Economy	29200.00
0005432646041	25105	Economy	29200.00
0005435229533	25105	Economy	29200.00
0005432646045	25105	Economy	29200.00
0005432646039	25105	Economy	29200.00
0005435229518	25105	Economy	29200.00
0005432646019	25105	Economy	29200.00
0005435229519	25105	Economy	29200.00
0005432646057	25105	Economy	29200.00
0005432646087	25105	Economy	29200.00
0005435229528	25105	Economy	29200.00
0005435229516	25105	Economy	29200.00
0005432645990	25105	Economy	29200.00
0005435229532	25105	Economy	29200.00
0005432646003	25105	Economy	29200.00
0005432646056	25105	Economy	29200.00
0005435229510	25105	Economy	29200.00
0005432646085	25105	Economy	29200.00
0005432646014	25105	Economy	29200.00
0005432646049	25105	Economy	29200.00
0005432646009	25105	Economy	29200.00
0005435229513	25105	Economy	29200.00
0005432646035	25105	Economy	29200.00
0005432646055	25105	Economy	29200.00
0005432646026	25105	Economy	29200.00
0005432646080	25105	Economy	29200.00
0005432646051	25105	Economy	29200.00
0005432646115	25105	Economy	29200.00
0005435229530	25105	Economy	29200.00
0005432646048	25105	Economy	29200.00
0005432646002	25105	Economy	29200.00
0005435229524	25105	Economy	29200.00
0005435229526	25105	Economy	29200.00
0005432646068	25105	Economy	29200.00
0005432646053	25105	Economy	29200.00
0005432646008	25105	Economy	29200.00
0005435797676	2865	Business	12600.00
0005435797680	2865	Business	12600.00
0005435797682	2865	Business	12600.00
0005433404851	2865	Business	12600.00
0005433404881	2865	Business	12600.00
0005435797678	2865	Economy	4200.00
0005433404830	2865	Economy	4200.00
0005435797672	2865	Economy	4200.00
0005433404831	2865	Economy	4600.00
0005435797673	2865	Economy	4600.00
0005433404852	2865	Economy	4600.00
0005433404843	2865	Economy	4200.00
0005435797683	2865	Economy	4200.00
0005433404889	2865	Economy	4200.00
0005435797684	2865	Economy	4200.00
0005435797677	2865	Economy	4200.00
0005435797681	2865	Economy	4200.00
0005435797675	2865	Economy	4200.00
0005435797671	2865	Economy	4200.00
0005435797674	2865	Economy	4200.00
0005433404849	2865	Economy	4200.00
0005435797679	2865	Economy	4200.00
0005433404853	2865	Economy	4200.00
0005433404864	2865	Economy	4200.00
0005433404848	2865	Economy	4200.00
0005435797585	29308	Business	12600.00
0005433404919	29308	Business	12600.00
0005433404913	29308	Economy	4200.00
0005433404918	29308	Economy	4200.00
0005435797526	29308	Economy	4200.00
0005435797544	29308	Economy	4200.00
0005433404915	29308	Economy	4200.00
0005433404917	29308	Economy	4200.00
0005435797581	29308	Economy	4600.00
0005435797580	29308	Economy	4600.00
0005435797499	29308	Economy	4200.00
0005435797603	29308	Economy	4200.00
0005435797545	29308	Economy	4200.00
0005433404920	29308	Economy	4200.00
0005435797527	29308	Economy	4200.00
0005433404914	29308	Economy	4200.00
0005433404916	29308	Economy	4200.00
0005435797590	29308	Economy	4200.00
0005435797513	29308	Economy	4200.00
0005435797512	29308	Economy	4200.00
0005435376361	5841	Economy	6800.00
0005434948138	5847	Economy	6800.00
0005434948140	5847	Economy	6800.00
0005434948137	5847	Economy	6800.00
0005434948139	5847	Economy	6800.00
0005434948060	16343	Economy	6800.00
0005434948066	16343	Economy	6800.00
0005434948059	16343	Economy	6800.00
0005434948062	16343	Economy	6800.00
0005434948045	16343	Economy	6800.00
0005434948051	16343	Economy	6800.00
0005434948052	16343	Economy	6800.00
0005434948085	16343	Economy	6800.00
0005434948067	16343	Economy	6800.00
0005434948086	16343	Economy	6800.00
0005434948084	16343	Economy	6800.00
0005434948061	16343	Economy	6800.00
0005433961674	6959	Business	21400.00
0005433961666	6959	Business	21400.00
0005433961685	6959	Business	21400.00
0005433961657	6959	Business	21400.00
0005433961704	6959	Business	21400.00
0005433961671	6959	Business	21400.00
0005433961707	6959	Business	21400.00
0005433961655	6959	Business	21400.00
0005433961656	6959	Economy	7100.00
0005433961708	6959	Economy	7100.00
0005433961670	6959	Economy	7100.00
0005433961677	6959	Economy	7100.00
0005433961684	6959	Economy	7100.00
0005433961687	6959	Economy	7100.00
0005433961699	6959	Economy	7100.00
0005433961682	6959	Economy	7100.00
0005433961703	6959	Economy	7800.00
0005433961668	6959	Economy	7800.00
0005433961661	6959	Economy	7800.00
0005433961706	6959	Economy	7100.00
0005433961663	6959	Economy	7100.00
0005433961650	6959	Economy	7100.00
0005433961654	6959	Economy	7100.00
0005433961696	6959	Economy	7100.00
0005433961712	6959	Economy	7100.00
0005433961701	6959	Economy	7100.00
0005433961675	6959	Economy	7100.00
0005433961660	6959	Economy	7100.00
0005433961679	6959	Economy	7100.00
0005433961662	6959	Economy	7100.00
0005433961698	6959	Economy	7100.00
0005433961652	6959	Economy	7100.00
0005433961690	6959	Economy	7100.00
0005433961659	6959	Economy	7100.00
0005433961689	6959	Economy	7100.00
0005433961651	6959	Economy	7100.00
0005433961683	6959	Economy	7100.00
0005433961709	6959	Economy	7100.00
0005433961667	6959	Economy	7100.00
0005433961664	6959	Economy	7100.00
0005433961697	6959	Economy	7100.00
0005433961705	6959	Economy	7100.00
0005433961658	6959	Economy	7100.00
0005433961711	6959	Economy	7100.00
0005433961695	6959	Economy	7100.00
0005433961681	6959	Economy	7100.00
0005433961686	6959	Economy	7100.00
0005433961678	6959	Economy	7100.00
0005433961653	6959	Economy	7100.00
0005433961676	6959	Economy	7100.00
0005433961710	6959	Economy	7100.00
0005433961694	6959	Economy	7100.00
0005433961672	6959	Economy	7100.00
0005433961691	6959	Economy	7100.00
0005433961680	6959	Economy	7100.00
0005433961702	6959	Economy	7100.00
0005433961688	6959	Economy	7100.00
0005433961673	6959	Economy	7100.00
0005433961669	6959	Economy	7100.00
0005433961692	6959	Economy	7100.00
0005433961693	6959	Economy	7100.00
0005433961700	6959	Economy	7100.00
0005433961665	6959	Economy	7100.00
0005433960832	25801	Business	21400.00
0005433960872	25801	Business	21400.00
0005433961172	25801	Business	21400.00
0005433960929	25801	Business	21400.00
0005433961124	25801	Business	21400.00
0005433960980	25801	Economy	7100.00
0005433961014	25801	Economy	7100.00
0005433961006	25801	Economy	7100.00
0005433961143	25801	Economy	7100.00
0005433961146	25801	Economy	7100.00
0005433960919	25801	Economy	7100.00
0005433960988	25801	Economy	7800.00
0005433961037	25801	Economy	7800.00
0005433960941	25801	Economy	7800.00
0005433961173	25801	Economy	7100.00
0005433961157	25801	Economy	7100.00
0005433960960	25801	Economy	7100.00
0005433961108	25801	Economy	7100.00
0005433961022	25801	Economy	7100.00
0005433960999	25801	Economy	7100.00
0005433961161	25801	Economy	7100.00
0005433960942	25801	Economy	7100.00
0005433960989	25801	Economy	7100.00
0005433961174	25801	Economy	7100.00
0005433961156	25801	Economy	7100.00
0005433960870	25801	Economy	7100.00
0005433960943	25801	Economy	7100.00
0005433961048	25801	Economy	7100.00
0005433960917	25801	Economy	7100.00
0005433961032	25801	Economy	7100.00
0005433960967	25801	Economy	7100.00
0005433960927	25801	Economy	7100.00
0005433961102	25801	Economy	7100.00
0005433960970	25801	Economy	7100.00
0005433960895	25801	Economy	7100.00
0005433960825	25801	Economy	7100.00
0005433960916	25801	Economy	7100.00
0005433961021	25801	Economy	7100.00
0005433961001	25801	Economy	7100.00
0005433961038	25801	Economy	7100.00
0005433960961	25801	Economy	7100.00
0005433961047	25801	Economy	7100.00
0005433961070	25801	Economy	7100.00
0005433961162	25801	Economy	7100.00
0005433961000	25801	Economy	7100.00
0005433960959	25801	Economy	7100.00
0005433961164	25801	Economy	7100.00
0005433961010	25801	Economy	7100.00
0005433961182	25801	Economy	7100.00
0005433960781	25801	Economy	7100.00
0005433961035	25801	Economy	7100.00
0005433960728	25801	Economy	7100.00
0005433961052	25801	Economy	7100.00
0005433960729	25801	Economy	7100.00
0005433960887	25801	Economy	7100.00
0005433960918	25801	Economy	7100.00
0005433961036	25801	Economy	7100.00
0005433961053	25801	Economy	7100.00
0005433961118	25801	Economy	7100.00
0005433961117	25801	Economy	7100.00
0005433961155	25801	Economy	7100.00
0005433960928	25801	Economy	7100.00
0005435082795	24489	Economy	3900.00
0005435082850	24489	Economy	3900.00
0005435082822	24489	Economy	3900.00
0005435082815	24489	Economy	3900.00
0005435082808	24489	Economy	3900.00
0005435082817	24489	Economy	3900.00
0005435082796	24489	Economy	3900.00
0005435082821	24489	Economy	3900.00
0005435082820	24489	Economy	3900.00
0005435082893	26151	Economy	3900.00
0005435082896	26151	Economy	3900.00
0005435082895	26151	Economy	3900.00
0005435082897	26151	Economy	3900.00
0005435082892	26151	Economy	3900.00
0005435082894	26151	Economy	3900.00
0005434245413	5041	Business	18000.00
0005434245410	5041	Business	18000.00
0005434245411	5041	Business	18000.00
0005434245392	5041	Business	18000.00
0005434245415	5041	Business	18000.00
0005434245397	5041	Economy	6600.00
0005432166948	5041	Economy	6000.00
0005434245401	5041	Economy	6000.00
0005434245398	5041	Economy	6000.00
0005434245395	5041	Economy	6000.00
0005434245403	5041	Economy	6000.00
0005434245405	5041	Economy	6000.00
0005434245414	5041	Economy	6000.00
0005434245416	5041	Economy	6000.00
0005435286658	5041	Economy	6000.00
0005434245391	5041	Economy	6000.00
0005434245396	5041	Economy	6000.00
0005434245389	5041	Economy	6000.00
0005434245407	5041	Economy	6000.00
0005435286637	5041	Economy	6000.00
0005434245412	5041	Economy	6600.00
0005434245417	5041	Economy	6000.00
0005435286636	5041	Economy	6000.00
0005432166949	5041	Economy	6000.00
0005434245404	5041	Economy	6000.00
0005434245390	5041	Economy	6000.00
0005434245399	5041	Economy	6000.00
0005434245387	5041	Economy	6000.00
0005434245406	5041	Economy	6000.00
0005432166947	5041	Economy	6000.00
0005434245400	5041	Economy	6000.00
0005434245388	5041	Economy	6000.00
0005434245394	5041	Economy	6000.00
0005434245393	5041	Economy	6000.00
0005434245402	5041	Economy	6000.00
0005434245408	5041	Economy	6000.00
0005434245409	5041	Economy	6000.00
0005432106267	5042	Business	18000.00
0005433615752	5042	Business	18000.00
0005433615781	5042	Business	18000.00
0005433615755	5042	Business	18000.00
0005433615773	5042	Business	18000.00
0005433785461	5042	Business	18000.00
0005432106252	5042	Business	18000.00
0005433615708	5042	Business	18000.00
0005433615754	5042	Business	18000.00
0005433785449	5042	Business	18000.00
0005432106251	5042	Business	18000.00
0005433785458	5042	Business	18000.00
0005432106273	5042	Business	18000.00
0005432106242	5042	Business	18000.00
0005433615777	5042	Business	18000.00
0005432106256	5042	Business	18000.00
0005433785482	5042	Business	18000.00
0005433615745	5042	Business	18000.00
0005433785470	5042	Business	18000.00
0005433615720	5042	Business	18000.00
0005433615712	5042	Business	18000.00
0005433615778	5042	Business	18000.00
0005433615756	5042	Business	18000.00
0005432106271	5042	Business	18000.00
0005433785473	5042	Business	18000.00
0005432106250	5042	Business	18000.00
0005432106255	5042	Business	18000.00
0005433615747	5042	Economy	6600.00
0005433615743	5042	Business	18000.00
0005433615758	5042	Economy	6600.00
0005433785463	5042	Economy	6600.00
0005433785453	5042	Economy	6600.00
0005432106272	5042	Economy	6600.00
0005433615730	5042	Economy	6600.00
0005433615725	5042	Economy	6000.00
0005433615775	5042	Economy	6000.00
0005433785459	5042	Economy	6000.00
0005433615724	5042	Economy	6000.00
0005432106263	5042	Economy	6000.00
0005432106259	5042	Economy	6000.00
0005433785474	5042	Economy	6000.00
0005433615765	5042	Economy	6000.00
0005433615710	5042	Economy	6000.00
0005433615728	5042	Economy	6000.00
0005433615729	5042	Economy	6000.00
0005433615722	5042	Economy	6000.00
0005432106240	5042	Economy	6000.00
0005432106254	5042	Economy	6000.00
0005432666417	5042	Economy	6000.00
0005433615713	5042	Economy	6000.00
0005432106258	5042	Economy	6000.00
0005433615772	5042	Economy	6000.00
0005433615738	5042	Economy	6000.00
0005432106275	5042	Economy	6000.00
0005433785460	5042	Economy	6000.00
0005432106231	5042	Economy	6000.00
0005432106248	5042	Economy	6000.00
0005432145142	5042	Economy	6000.00
0005433615721	5042	Economy	6000.00
0005432106246	5042	Economy	6000.00
0005433785476	5042	Economy	6000.00
0005433615742	5042	Economy	6000.00
0005433615776	5042	Economy	6000.00
0005432106238	5042	Economy	6000.00
0005433785479	5042	Economy	6000.00
0005432106270	5042	Economy	6000.00
0005433615736	5042	Economy	6000.00
0005433615766	5042	Economy	6000.00
0005433615737	5042	Economy	6000.00
0005432665304	5042	Economy	6000.00
0005433615764	5042	Economy	6000.00
0005432106260	5042	Economy	6000.00
0005433615726	5042	Economy	6000.00
0005433615732	5042	Economy	6000.00
0005432106274	5042	Economy	6000.00
0005432106264	5042	Economy	6000.00
0005433785472	5042	Economy	6000.00
0005432667485	5042	Economy	6000.00
0005433615748	5042	Economy	6000.00
0005433785457	5042	Economy	6000.00
0005432145141	5042	Economy	6000.00
0005433615727	5042	Economy	6000.00
0005433785466	5042	Economy	6000.00
0005433615753	5042	Economy	6000.00
0005433785452	5042	Economy	6000.00
0005432106237	5042	Economy	6000.00
0005433615707	5042	Economy	6000.00
0005433615735	5042	Economy	6000.00
0005433615770	5042	Economy	6000.00
0005433615763	5042	Economy	6000.00
0005433785477	5042	Economy	6000.00
0005433615734	5042	Economy	6000.00
0005432106269	5042	Economy	6000.00
0005433615771	5042	Economy	6000.00
0005432106233	5042	Economy	6600.00
0005432106257	5042	Economy	6600.00
0005432106229	5042	Economy	6600.00
0005433785478	5042	Economy	6600.00
0005433615751	5042	Economy	6600.00
0005433615716	5042	Economy	6000.00
0005433615739	5042	Economy	6000.00
0005432106236	5042	Economy	6000.00
0005432106253	5042	Economy	6000.00
0005433785455	5042	Economy	6600.00
0005433615731	5042	Economy	6000.00
0005433785481	5042	Economy	6000.00
0005433615761	5042	Economy	6000.00
0005433615718	5042	Economy	6000.00
0005433785465	5042	Economy	6000.00
0005432106244	5042	Economy	6000.00
0005433615741	5042	Economy	6000.00
0005432106239	5042	Economy	6000.00
0005433615769	5042	Economy	6000.00
0005432667483	5042	Economy	6000.00
0005433785475	5042	Economy	6000.00
0005433785469	5042	Economy	6000.00
0005432666418	5042	Economy	6000.00
0005433785468	5042	Economy	6000.00
0005433615709	5042	Economy	6000.00
0005432667484	5042	Economy	6000.00
0005433615768	5042	Economy	6000.00
0005433615719	5042	Economy	6000.00
0005432106261	5042	Economy	6000.00
0005433785471	5042	Economy	6000.00
0005433615746	5042	Economy	6000.00
0005433615711	5042	Economy	6000.00
0005433785462	5042	Economy	6000.00
0005433615714	5042	Economy	6000.00
0005433785464	5042	Economy	6000.00
0005433615750	5042	Economy	6000.00
0005433615715	5042	Economy	6000.00
0005432106232	5042	Economy	6000.00
0005433615733	5042	Economy	6000.00
0005433615717	5042	Economy	6000.00
0005433615762	5042	Economy	6000.00
0005433615759	5042	Economy	6000.00
0005433785467	5042	Economy	6000.00
0005432665305	5042	Economy	6000.00
0005432106245	5042	Economy	6000.00
0005433785454	5042	Economy	6000.00
0005433615774	5042	Economy	6000.00
0005432106265	5042	Economy	6000.00
0005432106249	5042	Economy	6000.00
0005432106262	5042	Economy	6000.00
0005432665303	5042	Economy	6000.00
0005433615749	5042	Economy	6000.00
0005432106276	5042	Economy	6000.00
0005432106243	5042	Economy	6000.00
0005433615779	5042	Economy	6000.00
0005433785451	5042	Economy	6000.00
0005433785450	5042	Economy	6000.00
0005433615740	5042	Economy	6000.00
0005432106235	5042	Economy	6000.00
0005433615780	5042	Economy	6000.00
0005432106230	5042	Economy	6000.00
0005433785480	5042	Economy	6000.00
0005432106234	5042	Economy	6000.00
0005432106277	5042	Economy	6000.00
0005432106266	5042	Economy	6000.00
0005433785456	5042	Economy	6000.00
0005433615744	5042	Economy	6000.00
0005432106268	5042	Economy	6000.00
0005432106247	5042	Economy	6000.00
0005432666419	5042	Economy	6000.00
0005432106241	5042	Economy	6000.00
0005433615760	5042	Economy	6000.00
0005433615723	5042	Economy	6000.00
0005433615757	5042	Economy	6000.00
0005433615767	5042	Economy	6000.00
0005435269781	5044	Business	18000.00
0005432336175	5044	Business	18000.00
0005434149901	5044	Business	18000.00
0005434265510	5044	Business	18000.00
0005434265513	5044	Business	18000.00
0005434312335	5044	Business	18000.00
0005435007120	5044	Business	18000.00
0005434173575	5044	Business	18000.00
0005435269758	5044	Business	18000.00
0005434229694	5044	Business	18000.00
0005434312321	5044	Business	18000.00
0005434312327	5044	Business	18000.00
0005434229689	5044	Business	18000.00
0005433688817	5044	Business	18000.00
0005434265512	5044	Business	18000.00
0005434149903	5044	Business	18000.00
0005434265495	5044	Business	18000.00
0005434173578	5044	Business	18000.00
0005432336091	5044	Business	18000.00
0005434265516	5044	Business	18000.00
0005434265520	5044	Business	18000.00
0005434149898	5044	Business	18000.00
0005435269770	5044	Economy	6600.00
0005435269773	5044	Economy	6600.00
0005435007158	5044	Economy	6600.00
0005435269778	5044	Economy	6000.00
0005434229702	5044	Economy	6000.00
0005435007122	5044	Economy	6000.00
0005434149904	5044	Economy	6000.00
0005435269780	5044	Economy	6000.00
0005434265507	5044	Economy	6000.00
0005435007189	5044	Economy	6000.00
0005434149900	5044	Economy	6000.00
0005435007142	5044	Economy	6000.00
0005434311233	5044	Economy	6000.00
0005432336064	5044	Economy	6000.00
0005434229693	5044	Economy	6000.00
0005434173576	5044	Economy	6000.00
0005434265509	5044	Economy	6000.00
0005435007241	5044	Economy	6000.00
0005434311229	5044	Economy	6000.00
0005434229684	5044	Economy	6000.00
0005434229696	5044	Economy	6000.00
0005434265500	5044	Economy	6000.00
0005434229683	5044	Economy	6000.00
0005435269766	5044	Economy	6000.00
0005434265505	5044	Economy	6000.00
0005434229687	5044	Economy	6000.00
0005432336065	5044	Economy	6000.00
0005432336142	5044	Economy	6000.00
0005434229697	5044	Economy	6000.00
0005434311230	5044	Economy	6000.00
0005434312325	5044	Economy	6000.00
0005434229688	5044	Economy	6000.00
0005434265508	5044	Economy	6000.00
0005434229704	5044	Economy	6000.00
0005434149896	5044	Economy	6000.00
0005434149897	5044	Economy	6000.00
0005433815415	5044	Economy	6000.00
0005433688828	5044	Economy	6000.00
0005434312334	5044	Economy	6000.00
0005434265499	5044	Economy	6000.00
0005434312328	5044	Economy	6000.00
0005434229691	5044	Economy	6600.00
0005434265506	5044	Economy	6600.00
0005435269785	5044	Economy	6000.00
0005434229695	5044	Economy	6000.00
0005435007240	5044	Economy	6600.00
0005434229698	5044	Economy	6000.00
0005434173577	5044	Economy	6000.00
0005434265518	5044	Economy	6000.00
0005432336083	5044	Economy	6000.00
0005432336118	5044	Economy	6000.00
0005434229699	5044	Economy	6000.00
0005432336174	5044	Economy	6000.00
0005434229701	5044	Economy	6000.00
0005434265503	5044	Economy	6000.00
0005433815389	5044	Economy	6000.00
0005432336090	5044	Economy	6000.00
0005434229703	5044	Economy	6000.00
0005434265519	5044	Economy	6000.00
0005434265511	5044	Economy	6000.00
0005434229685	5044	Economy	6000.00
0005434149899	5044	Economy	6000.00
0005435007239	5044	Economy	6000.00
0005434312320	5044	Economy	6000.00
0005433685524	5044	Economy	6000.00
0005434265515	5044	Economy	6000.00
0005434265517	5044	Economy	6000.00
0005433815414	5044	Economy	6000.00
0005434265514	5044	Economy	6000.00
0005434229700	5044	Economy	6000.00
0005434229690	5044	Economy	6000.00
0005434229692	5044	Economy	6000.00
0005434265502	5044	Economy	6000.00
0005434229705	5044	Economy	6000.00
0005434149895	5044	Economy	6000.00
0005434265498	5044	Economy	6000.00
0005434265501	5044	Economy	6000.00
0005435269760	5044	Economy	6000.00
0005435269757	5044	Economy	6000.00
0005434312333	5044	Economy	6000.00
0005432336184	5044	Economy	6000.00
0005432336070	5044	Economy	6000.00
0005434265504	5044	Economy	6000.00
0005435269784	5044	Economy	6000.00
0005435269774	5044	Economy	6000.00
0005434265497	5044	Economy	6000.00
0005435269777	5044	Economy	6000.00
0005434149902	5044	Economy	6000.00
0005435269775	5044	Economy	6000.00
0005434229686	5044	Economy	6000.00
0005435269782	5044	Economy	6000.00
0005433685527	5044	Economy	6000.00
0005434312326	5044	Economy	6000.00
0005432336105	5044	Economy	6000.00
0005435269765	5044	Economy	6000.00
0005432336089	5044	Economy	6000.00
0005434265496	5044	Economy	6000.00
0005435269783	5044	Economy	6000.00
0005434245114	8527	Business	18000.00
0005434245235	8527	Business	18000.00
0005434245282	8527	Business	18000.00
0005433785081	8527	Business	18000.00
0005435269873	8527	Business	18000.00
0005434245236	8527	Business	18000.00
0005433785101	8527	Business	18000.00
0005434245181	8527	Business	18000.00
0005434245180	8527	Business	18000.00
0005434245251	8527	Business	18000.00
0005434245164	8527	Business	18000.00
0005434245197	8527	Business	18000.00
0005433785103	8527	Economy	6600.00
0005434245103	8527	Economy	6600.00
0005434245273	8527	Economy	6000.00
0005433785018	8527	Economy	6000.00
0005434245028	8527	Economy	6000.00
0005434245165	8527	Economy	6000.00
0005432659718	8527	Economy	6000.00
0005432663049	8527	Economy	6000.00
0005433785187	8527	Economy	6000.00
0005434245102	8527	Economy	6000.00
0005434245237	8527	Economy	6000.00
0005432663050	8527	Economy	6000.00
0005434245069	8527	Economy	6000.00
0005432666390	8527	Economy	6000.00
0005433785060	8527	Economy	6000.00
0005435269872	8527	Economy	6000.00
0005433785198	8527	Economy	6000.00
0005432666399	8527	Economy	6000.00
0005432666388	8527	Economy	6000.00
0005433785082	8527	Economy	6000.00
0005434245073	8527	Economy	6000.00
0005433785020	8527	Economy	6000.00
0005435269871	8527	Economy	6000.00
0005433785019	8527	Economy	6000.00
0005433785301	8527	Economy	6000.00
0005432659716	8527	Economy	6000.00
0005434245221	8527	Economy	6000.00
0005434245220	8527	Economy	6000.00
0005434245177	8527	Economy	6000.00
0005434245252	8527	Economy	6000.00
0005433785259	8527	Economy	6000.00
0005433785218	8527	Economy	6000.00
0005433785302	8527	Economy	6000.00
0005435269870	8527	Economy	6600.00
0005434245179	8527	Economy	6600.00
0005434245281	8527	Economy	6000.00
0005433785016	8527	Economy	6000.00
0005434245007	8527	Economy	6000.00
0005433785308	8527	Economy	6000.00
0005433785178	8527	Economy	6000.00
0005433785102	8527	Economy	6000.00
0005433785138	8527	Economy	6000.00
0005433785017	8527	Economy	6000.00
0005434245074	8527	Economy	6000.00
0005434245195	8527	Economy	6000.00
0005433785126	8527	Economy	6000.00
0005433784965	8527	Economy	6000.00
0005434245296	8527	Economy	6000.00
0005434245243	8527	Economy	6000.00
0005433785007	8527	Economy	6000.00
0005434245068	8527	Economy	6000.00
0005433785143	8527	Economy	6000.00
0005434245178	8527	Economy	6000.00
0005434245295	8527	Economy	6000.00
0005434245242	8527	Economy	6000.00
0005434245163	8527	Economy	6000.00
0005433785217	8527	Economy	6000.00
0005433785203	8527	Economy	6000.00
0005433785145	8527	Economy	6000.00
0005433785212	8527	Economy	6000.00
0005432666389	8527	Economy	6000.00
0005433785179	8527	Economy	6000.00
0005434245280	8527	Economy	6000.00
0005432666404	8527	Economy	6000.00
0005433785128	8527	Economy	6000.00
0005434245006	8527	Economy	6000.00
0005432659717	8527	Economy	6000.00
0005434245222	8527	Economy	6000.00
0005433785080	8527	Economy	6000.00
0005433785147	8527	Economy	6000.00
0005434245196	8527	Economy	6000.00
0005435269869	8527	Economy	6000.00
0005433614912	8526	Business	18000.00
0005433614810	8526	Business	18000.00
0005433615045	8526	Business	18000.00
0005433614914	8526	Business	18000.00
0005433615093	8526	Business	18000.00
0005433615047	8526	Business	18000.00
0005433614915	8526	Business	18000.00
0005433615230	8526	Business	18000.00
0005433614890	8526	Business	18000.00
0005433614831	8526	Economy	6600.00
0005433615123	8526	Economy	6000.00
0005433614928	8526	Economy	6000.00
0005433615236	8526	Economy	6000.00
0005433615117	8526	Economy	6000.00
0005433614938	8526	Economy	6000.00
0005433615079	8526	Economy	6000.00
0005433615085	8526	Economy	6000.00
0005433615163	8526	Economy	6000.00
0005433615136	8526	Economy	6000.00
0005433614679	8526	Economy	6000.00
0005433615237	8526	Economy	6000.00
0005433615105	8526	Economy	6000.00
0005433615061	8526	Economy	6000.00
0005433615006	8526	Economy	6000.00
0005433615233	8526	Economy	6000.00
0005433615128	8526	Economy	6000.00
0005433614882	8526	Economy	6000.00
0005433615232	8526	Economy	6000.00
0005433614937	8526	Economy	6000.00
0005433614682	8526	Economy	6000.00
0005433614888	8526	Economy	6000.00
0005433615095	8526	Economy	6000.00
0005433614919	8526	Economy	6000.00
0005433615229	8526	Economy	6000.00
0005433615234	8526	Economy	6000.00
0005433615116	8526	Economy	6000.00
0005433615035	8526	Economy	6000.00
0005433615106	8526	Economy	6000.00
0005433614920	8526	Economy	6600.00
0005433615078	8526	Economy	6600.00
0005433614680	8526	Economy	6600.00
0005433615324	8526	Economy	6600.00
0005433615157	8526	Economy	6000.00
0005433614835	8526	Economy	6000.00
0005433615076	8526	Economy	6000.00
0005433615036	8526	Economy	6000.00
0005433614857	8526	Economy	6000.00
0005433615052	8526	Economy	6000.00
0005433614681	8526	Economy	6000.00
0005433615211	8526	Economy	6000.00
0005433614950	8526	Economy	6000.00
0005433614991	8526	Economy	6000.00
0005433615060	8526	Economy	6000.00
0005433614983	8526	Economy	6000.00
0005433615124	8526	Economy	6000.00
0005433615226	8526	Economy	6000.00
0005433614889	8526	Economy	6000.00
0005433615046	8526	Economy	6000.00
0005433615269	8526	Economy	6000.00
0005433614957	8526	Economy	6000.00
0005433614542	8526	Economy	6000.00
0005433615210	8526	Economy	6000.00
0005433614811	8526	Economy	6000.00
0005433614856	8526	Economy	6000.00
0005433615007	8526	Economy	6000.00
0005433615077	8526	Economy	6000.00
0005433615235	8526	Economy	6000.00
0005433615256	8526	Economy	6000.00
0005433614939	8526	Economy	6000.00
0005433615297	8526	Economy	6000.00
0005434229529	8525	Business	18000.00
0005434229421	8525	Business	18000.00
0005432336205	8525	Business	18000.00
0005434265239	8525	Business	18000.00
0005433534529	8525	Business	18000.00
0005432035342	8525	Business	18000.00
0005432035345	8525	Business	18000.00
0005434229470	8525	Business	18000.00
0005434265300	8525	Business	18000.00
0005434265304	8525	Business	18000.00
0005432035338	8525	Business	18000.00
0005434265295	8525	Business	18000.00
0005434229495	8525	Business	18000.00
0005432336203	8525	Business	18000.00
0005435007365	8525	Business	18000.00
0005432336208	8525	Business	18000.00
0005433688840	8525	Business	18000.00
0005432047605	8525	Business	18000.00
0005434229442	8525	Business	18000.00
0005435007367	8525	Business	18000.00
0005434229463	8525	Business	18000.00
0005435007374	8525	Business	18000.00
0005432035340	8525	Business	18000.00
0005432336210	8525	Business	18000.00
0005434229512	8525	Business	18000.00
0005433689942	8525	Business	18000.00
0005434265299	8525	Economy	6600.00
0005434265364	8525	Economy	6600.00
0005432336206	8525	Economy	6600.00
0005434149810	8525	Economy	6600.00
0005432336202	8525	Economy	6600.00
0005434265252	8525	Economy	6600.00
0005434265234	8525	Economy	6000.00
0005432035350	8525	Economy	6000.00
0005434229460	8525	Economy	6000.00
0005432047603	8525	Economy	6000.00
0005435007359	8525	Economy	6000.00
0005435007376	8525	Economy	6000.00
0005435007370	8525	Economy	6000.00
0005434229551	8525	Economy	6000.00
0005434229401	8525	Economy	6000.00
0005434149803	8525	Economy	6000.00
0005433690953	8525	Economy	6000.00
0005434149788	8525	Economy	6000.00
0005432035341	8525	Economy	6000.00
0005434265189	8525	Economy	6000.00
0005434229579	8525	Economy	6000.00
0005435007358	8525	Economy	6000.00
0005432047604	8525	Economy	6000.00
0005432035353	8525	Economy	6000.00
0005432035339	8525	Economy	6000.00
0005434229580	8525	Economy	6000.00
0005435007371	8525	Economy	6000.00
0005434229469	8525	Economy	6000.00
0005434265294	8525	Economy	6000.00
0005434149779	8525	Economy	6000.00
0005435286709	8525	Economy	6000.00
0005434265166	8525	Economy	6000.00
0005435007377	8525	Economy	6000.00
0005433815458	8525	Economy	6000.00
0005434265360	8525	Economy	6000.00
0005434149778	8525	Economy	6000.00
0005432035348	8525	Economy	6000.00
0005434149753	8525	Economy	6000.00
0005434265233	8525	Economy	6000.00
0005434229494	8525	Economy	6000.00
0005432035336	8525	Economy	6000.00
0005434265314	8525	Economy	6000.00
0005432035351	8525	Economy	6000.00
0005434265216	8525	Economy	6000.00
0005432035354	8525	Economy	6000.00
0005434229418	8525	Economy	6000.00
0005435007379	8525	Economy	6000.00
0005432035333	8525	Economy	6000.00
0005432336204	8525	Economy	6000.00
0005435007368	8525	Economy	6000.00
0005432035343	8525	Economy	6000.00
0005433534528	8525	Economy	6000.00
0005434229443	8525	Economy	6000.00
0005434229415	8525	Economy	6000.00
0005433815454	8525	Economy	6000.00
0005434229539	8525	Economy	6000.00
0005432035344	8525	Economy	6000.00
0005434229416	8525	Economy	6000.00
0005432035337	8525	Economy	6000.00
0005433689941	8525	Economy	6000.00
0005434229497	8525	Economy	6000.00
0005434229464	8525	Economy	6000.00
0005434265308	8525	Economy	6600.00
0005434229439	8525	Economy	6600.00
0005434229440	8525	Economy	6600.00
0005435007361	8525	Economy	6600.00
0005434173534	8525	Economy	6600.00
0005434229468	8525	Economy	6000.00
0005434229527	8525	Economy	6000.00
0005434149821	8525	Economy	6000.00
0005434265298	8525	Economy	6000.00
0005435007366	8525	Economy	6600.00
0005434265214	8525	Economy	6000.00
0005433690955	8525	Economy	6000.00
0005435007369	8525	Economy	6000.00
0005434311247	8525	Economy	6000.00
0005434229540	8525	Economy	6000.00
0005432035357	8525	Economy	6000.00
0005433815455	8525	Economy	6000.00
0005435007360	8525	Economy	6000.00
0005434229507	8525	Economy	6000.00
0005433688841	8525	Economy	6000.00
0005435007373	8525	Economy	6000.00
0005434149795	8525	Economy	6000.00
0005432035334	8525	Economy	6000.00
0005434229506	8525	Economy	6000.00
0005432336201	8525	Economy	6000.00
0005435007378	8525	Economy	6000.00
0005434265194	8525	Economy	6000.00
0005432035332	8525	Economy	6000.00
0005432035358	8525	Economy	6000.00
0005432035349	8525	Economy	6000.00
0005434229528	8525	Economy	6000.00
0005434149780	8525	Economy	6000.00
0005432336200	8525	Economy	6000.00
0005434149790	8525	Economy	6000.00
0005432035355	8525	Economy	6000.00
0005432035347	8525	Economy	6000.00
0005432336211	8525	Economy	6000.00
0005432035359	8525	Economy	6000.00
0005434229461	8525	Economy	6000.00
0005432035335	8525	Economy	6000.00
0005435007375	8525	Economy	6000.00
0005435007372	8525	Economy	6000.00
0005435007355	8525	Economy	6000.00
0005432047602	8525	Economy	6000.00
0005432035360	8525	Economy	6000.00
0005435007362	8525	Economy	6000.00
0005434149785	8525	Economy	6000.00
0005434265215	8525	Economy	6000.00
0005434265359	8525	Economy	6000.00
0005434149820	8525	Economy	6000.00
0005435286710	8525	Economy	6000.00
0005434229417	8525	Economy	6000.00
0005433815456	8525	Economy	6000.00
0005432035346	8525	Economy	6000.00
0005433688839	8525	Economy	6000.00
0005434311248	8525	Economy	6000.00
0005432035352	8525	Economy	6000.00
0005434149796	8525	Economy	6000.00
0005435007357	8525	Economy	6000.00
0005434265251	8525	Economy	6000.00
0005435007356	8525	Economy	6000.00
0005435007364	8525	Economy	6000.00
0005432336207	8525	Economy	6000.00
0005432336209	8525	Economy	6000.00
0005434229414	8525	Economy	6000.00
0005433690954	8525	Economy	6000.00
0005434229407	8525	Economy	6000.00
0005433815457	8525	Economy	6000.00
0005434229581	8525	Economy	6000.00
0005434265240	8525	Economy	6000.00
0005435286711	8525	Economy	6000.00
0005432035356	8525	Economy	6000.00
0005435007363	8525	Economy	6000.00
0005433815459	8525	Economy	6000.00
0005434639433	12582	Economy	16200.00
0005433202582	12582	Economy	16200.00
0005434639377	12582	Economy	16200.00
0005433202576	12582	Economy	14800.00
0005433202579	12582	Economy	14800.00
0005434639478	12582	Economy	14800.00
0005434639568	12582	Economy	14800.00
0005434639577	12582	Economy	14800.00
0005433202572	12582	Economy	14800.00
0005433202571	12582	Economy	14800.00
0005434639430	12582	Economy	14800.00
0005433202583	12582	Economy	14800.00
0005434639501	12582	Economy	14800.00
0005434639559	12582	Economy	14800.00
0005434639567	12582	Economy	14800.00
0005433202573	12582	Economy	14800.00
0005434639449	12582	Economy	14800.00
0005433202580	12582	Economy	14800.00
0005433202577	12582	Economy	14800.00
0005434639554	12582	Economy	14800.00
0005433202575	12582	Economy	14800.00
0005434639510	12582	Economy	14800.00
0005433202578	12582	Economy	14800.00
0005434639477	12582	Economy	14800.00
0005433202570	12582	Economy	14800.00
0005434639378	12582	Economy	14800.00
0005433202581	12582	Economy	14800.00
0005434639509	12582	Economy	14800.00
0005434639428	12582	Economy	14800.00
0005434639371	12582	Economy	14800.00
0005434639434	12582	Economy	14800.00
0005433202574	12582	Economy	14800.00
0005433202584	12582	Economy	14800.00
0005434639682	23387	Economy	16200.00
0005434639677	23387	Economy	16200.00
0005434639680	23387	Economy	16200.00
0005434639665	23387	Economy	16200.00
0005433202477	23387	Economy	14800.00
0005434639663	23387	Economy	14800.00
0005433202389	23387	Economy	14800.00
0005434639656	23387	Economy	14800.00
0005433202462	23387	Economy	14800.00
0005434639666	23387	Economy	14800.00
0005434639655	23387	Economy	14800.00
0005433202423	23387	Economy	14800.00
0005434639683	23387	Economy	14800.00
0005434639672	23387	Economy	14800.00
0005434639676	23387	Economy	14800.00
0005433202457	23387	Economy	14800.00
0005433202450	23387	Economy	14800.00
0005432290675	23387	Economy	14800.00
0005433202402	23387	Economy	14800.00
0005434639662	23387	Economy	14800.00
0005434639664	23387	Economy	14800.00
0005432290677	23387	Economy	14800.00
0005434639678	23387	Economy	14800.00
0005434639657	23387	Economy	14800.00
0005433202391	23387	Economy	14800.00
0005432290678	23387	Economy	14800.00
0005434639667	23387	Economy	14800.00
0005434639679	23387	Economy	14800.00
0005434639660	23387	Economy	14800.00
0005433202449	23387	Economy	14800.00
0005434639668	23387	Economy	14800.00
0005434639658	23387	Economy	14800.00
0005434639675	23387	Economy	14800.00
0005434639674	23387	Economy	14800.00
0005434639670	23387	Economy	14800.00
0005434639659	23387	Economy	14800.00
0005434639673	23387	Economy	14800.00
0005432290676	23387	Economy	14800.00
0005433202392	23387	Economy	14800.00
0005433202471	23387	Economy	14800.00
0005434639671	23387	Economy	14800.00
0005434639661	23387	Economy	14800.00
0005434639681	23387	Economy	14800.00
0005432290674	23387	Economy	14800.00
0005433202390	23387	Economy	14800.00
0005433202448	23387	Economy	14800.00
0005433202463	23387	Economy	14800.00
0005433202377	23387	Economy	14800.00
0005434639669	23387	Economy	14800.00
0005432329096	21092	Business	18900.00
0005432383406	21092	Business	18900.00
0005432383456	21092	Business	18900.00
0005432328850	21092	Business	18900.00
0005432328945	21092	Business	18900.00
0005432383412	21092	Business	18900.00
0005432383212	21092	Business	18900.00
0005432383334	21092	Business	18900.00
0005432383380	21092	Business	18900.00
0005432328797	21092	Business	18900.00
0005432328946	21092	Business	18900.00
0005432383369	21092	Business	18900.00
0005432383316	21092	Economy	6300.00
0005432383286	21092	Economy	6300.00
0005432329107	21092	Economy	6300.00
0005432383471	21092	Economy	6300.00
0005432383379	21092	Economy	6300.00
0005432383293	21092	Economy	6300.00
0005432383405	21092	Economy	6300.00
0005432383534	21092	Economy	6300.00
0005432328925	21092	Economy	6300.00
0005432383413	21092	Economy	6300.00
0005432328947	21092	Economy	6900.00
0005432383299	21092	Economy	6900.00
0005432383303	21092	Economy	6900.00
0005432329013	21092	Economy	6900.00
0005432328961	21092	Economy	6900.00
0005432383457	21092	Economy	6300.00
0005432383281	21092	Economy	6300.00
0005432383301	21092	Economy	6300.00
0005432383404	21092	Economy	6300.00
0005432383420	21092	Economy	6300.00
0005432328884	21092	Economy	6300.00
0005432328963	21092	Economy	6300.00
0005432329070	21092	Economy	6300.00
0005432383455	21092	Economy	6300.00
0005432328737	21092	Economy	6300.00
0005432328861	21092	Economy	6300.00
0005432328863	21092	Economy	6300.00
0005432328964	21092	Economy	6300.00
0005432328742	21092	Economy	6300.00
0005432328735	21092	Economy	6300.00
0005432328962	21092	Economy	6300.00
0005432328785	21092	Economy	6300.00
0005432054348	21092	Economy	6300.00
0005432383352	21092	Economy	6300.00
0005432383346	21092	Economy	6300.00
0005432329011	21092	Economy	6300.00
0005432383398	21092	Economy	6300.00
0005432383381	21092	Economy	6300.00
0005432383304	21092	Economy	6300.00
0005432328824	21092	Economy	6300.00
0005432383374	21092	Economy	6300.00
0005432383394	21092	Economy	6300.00
0005432383517	21092	Economy	6300.00
0005432383209	21092	Economy	6300.00
0005432328920	21092	Economy	6300.00
0005432328743	21092	Economy	6300.00
0005432328924	21092	Economy	6300.00
0005432329012	21092	Economy	6300.00
0005432328899	21092	Economy	6300.00
0005432328885	21092	Economy	6300.00
0005432328738	21092	Economy	6300.00
0005432328859	21092	Economy	6300.00
0005432383536	21092	Economy	6300.00
0005432383516	21092	Economy	6300.00
0005432383535	21092	Economy	6300.00
0005432383247	21092	Economy	6300.00
0005432328799	21092	Economy	6300.00
0005432383419	21092	Economy	6300.00
0005432329017	21092	Economy	6300.00
0005432383378	21092	Economy	6300.00
0005432054346	21092	Economy	6300.00
0005432383210	21092	Economy	6300.00
0005432383280	21092	Economy	6300.00
0005432329000	21092	Economy	6300.00
0005432328953	21092	Economy	6300.00
0005432383382	21092	Economy	6300.00
0005432328736	21092	Economy	6300.00
0005432328864	21092	Economy	6300.00
0005432328862	21092	Economy	6300.00
0005432328901	21092	Economy	6300.00
0005432328851	21092	Economy	6300.00
0005432328937	21092	Economy	6300.00
0005432383397	21092	Economy	6300.00
0005432328949	21092	Economy	6300.00
0005432328923	21092	Economy	6300.00
0005432328844	21092	Economy	6300.00
0005432383300	21092	Economy	6300.00
0005432328921	21092	Economy	6300.00
0005432054347	21092	Economy	6300.00
0005432328922	21092	Economy	6300.00
0005432383317	21092	Economy	6300.00
0005432383347	21092	Economy	6300.00
0005432383373	21092	Economy	6300.00
0005432383466	21092	Economy	6300.00
0005432328959	21092	Economy	6300.00
0005432383704	31238	Business	18900.00
0005432329304	31238	Business	18900.00
0005432383691	31238	Business	18900.00
0005432383700	31238	Business	18900.00
0005432329326	31238	Business	18900.00
0005432383680	31238	Business	18900.00
0005432383689	31238	Business	18900.00
0005432383708	31238	Business	18900.00
0005432329333	31238	Business	18900.00
0005432383701	31238	Business	18900.00
0005432383684	31238	Business	18900.00
0005432383687	31238	Economy	6300.00
0005432329331	31238	Economy	6300.00
0005432329344	31238	Economy	6300.00
0005432329299	31238	Economy	6300.00
0005432329302	31238	Economy	6300.00
0005432383688	31238	Economy	6300.00
0005432383681	31238	Economy	6300.00
0005432329334	31238	Economy	6300.00
0005432329305	31238	Economy	6300.00
0005432383685	31238	Economy	6300.00
0005432329314	31238	Economy	6900.00
0005432329321	31238	Economy	6900.00
0005432383695	31238	Economy	6900.00
0005432329319	31238	Economy	6900.00
0005432329343	31238	Economy	6300.00
0005432383694	31238	Economy	6300.00
0005432329309	31238	Economy	6300.00
0005432287260	31238	Economy	6300.00
0005432329307	31238	Economy	6300.00
0005432329310	31238	Economy	6300.00
0005432383703	31238	Economy	6300.00
0005432383686	31238	Economy	6300.00
0005432329342	31238	Economy	6300.00
0005432329322	31238	Economy	6300.00
0005432329317	31238	Economy	6300.00
0005432329308	31238	Economy	6300.00
0005432329318	31238	Economy	6300.00
0005432383692	31238	Economy	6300.00
0005432383690	31238	Economy	6300.00
0005432329325	31238	Economy	6300.00
0005432329337	31238	Economy	6300.00
0005432383697	31238	Economy	6300.00
0005432287259	31238	Economy	6300.00
0005432329320	31238	Economy	6300.00
0005432383705	31238	Economy	6300.00
0005432329324	31238	Economy	6300.00
0005432329300	31238	Economy	6300.00
0005432329301	31238	Economy	6300.00
0005432329323	31238	Economy	6300.00
0005432287257	31238	Economy	6300.00
0005432383698	31238	Economy	6300.00
0005432329335	31238	Economy	6300.00
0005432329311	31238	Economy	6300.00
0005432287256	31238	Economy	6300.00
0005432329315	31238	Economy	6300.00
0005432329312	31238	Economy	6300.00
0005432383706	31238	Economy	6300.00
0005432329313	31238	Economy	6300.00
0005432329336	31238	Economy	6300.00
0005432329345	31238	Economy	6300.00
0005432383696	31238	Economy	6300.00
0005432329303	31238	Economy	6300.00
0005432383683	31238	Economy	6300.00
0005432329327	31238	Economy	6300.00
0005432383693	31238	Economy	6300.00
0005432329306	31238	Economy	6300.00
0005432287258	31238	Economy	6300.00
0005432329340	31238	Economy	6300.00
0005432329341	31238	Economy	6300.00
0005432329346	31238	Economy	6300.00
0005432329329	31238	Economy	6300.00
0005432329330	31238	Economy	6300.00
0005432329339	31238	Economy	6300.00
0005432329332	31238	Economy	6300.00
0005432383699	31238	Economy	6300.00
0005432329338	31238	Economy	6300.00
0005432383682	31238	Economy	6300.00
0005432329316	31238	Economy	6300.00
0005432329328	31238	Economy	6300.00
0005432383702	31238	Economy	6300.00
0005432383707	31238	Economy	6300.00
0005432425096	13270	Business	12700.00
0005432425116	13270	Business	12700.00
0005432425110	13270	Business	12700.00
0005432425100	13270	Business	12700.00
0005432425084	13270	Business	12700.00
0005432425079	13270	Business	12700.00
0005432425102	13270	Economy	4200.00
0005432425088	13270	Economy	4200.00
0005432425083	13270	Economy	4200.00
0005432425101	13270	Economy	4700.00
0005432425097	13270	Economy	4700.00
0005432425114	13270	Economy	4700.00
0005432425120	13270	Economy	4700.00
0005432425103	13270	Economy	4200.00
0005432425119	13270	Economy	4200.00
0005432425081	13270	Economy	4200.00
0005432425121	13270	Economy	4200.00
0005432425112	13270	Economy	4200.00
0005432425092	13270	Economy	4200.00
0005432425123	13270	Economy	4200.00
0005432425118	13270	Economy	4200.00
0005432425109	13270	Economy	4200.00
0005432425093	13270	Economy	4200.00
0005432425098	13270	Economy	4200.00
0005432425113	13270	Economy	4200.00
0005432425107	13270	Economy	4200.00
0005432425105	13270	Economy	4200.00
0005432425087	13270	Economy	4200.00
0005432425077	13270	Economy	4200.00
0005432425111	13270	Economy	4200.00
0005432425085	13270	Economy	4200.00
0005432425080	13270	Economy	4200.00
0005432425089	13270	Economy	4200.00
0005432425106	13270	Economy	4200.00
0005432425082	13270	Economy	4200.00
0005432425117	13270	Economy	4200.00
0005432425122	13270	Economy	4200.00
0005432425115	13270	Economy	4200.00
0005432425076	13270	Economy	4200.00
0005432425091	13270	Economy	4200.00
0005432425086	13270	Economy	4200.00
0005432425104	13270	Economy	4200.00
0005432425095	13270	Economy	4200.00
0005432425094	13270	Economy	4200.00
0005432425090	13270	Economy	4200.00
0005432425099	13270	Economy	4200.00
0005432425108	13270	Economy	4200.00
0005432425078	13270	Economy	4200.00
0005432424712	30805	Business	12700.00
0005432424677	30805	Business	12700.00
0005432424686	30805	Business	12700.00
0005432424562	30805	Business	12700.00
0005432424554	30805	Business	12700.00
0005432424532	30805	Business	12700.00
0005432424693	30805	Business	12700.00
0005432424730	30805	Business	12700.00
0005432424540	30805	Economy	4200.00
0005432424533	30805	Economy	4200.00
0005432424704	30805	Economy	4200.00
0005432424607	30805	Economy	4700.00
0005432424684	30805	Economy	4700.00
0005432424610	30805	Economy	4700.00
0005432424617	30805	Economy	4200.00
0005432424698	30805	Economy	4200.00
0005432424715	30805	Economy	4200.00
0005432424690	30805	Economy	4200.00
0005432424723	30805	Economy	4200.00
0005432424729	30805	Economy	4200.00
0005432424557	30805	Economy	4200.00
0005432424687	30805	Economy	4200.00
0005432424640	30805	Economy	4200.00
0005432424602	30805	Economy	4200.00
0005432424561	30805	Economy	4200.00
0005432424711	30805	Economy	4200.00
0005432424531	30805	Economy	4200.00
0005432424683	30805	Economy	4200.00
0005432424720	30805	Economy	4200.00
0005432424553	30805	Economy	4200.00
0005432424731	30805	Economy	4200.00
0005432424422	30805	Economy	4200.00
0005432424618	30805	Economy	4200.00
0005432424616	30805	Economy	4200.00
0005432424689	30805	Economy	4200.00
0005432424666	30805	Economy	4200.00
0005432424676	30805	Economy	4200.00
0005432424722	30805	Economy	4200.00
0005432424556	30805	Economy	4200.00
0005432424615	30805	Economy	4200.00
0005432424688	30805	Economy	4200.00
0005432424658	30805	Economy	4200.00
0005432424539	30805	Economy	4200.00
0005432424661	30805	Economy	4200.00
0005432424685	30805	Economy	4200.00
0005432424721	30805	Economy	4200.00
0005432424662	30805	Economy	4200.00
0005432424733	30805	Economy	4200.00
0005432424574	30805	Economy	4200.00
0005432424705	30805	Economy	4200.00
0005432424718	30805	Economy	4200.00
0005432424665	30805	Economy	4200.00
0005432424719	30805	Economy	4200.00
0005432424691	30805	Economy	4200.00
0005434157549	9590	Business	32600.00
0005434157548	9590	Business	32600.00
0005434448363	9590	Business	32600.00
0005432901697	9590	Business	32600.00
0005432817909	9590	Business	32600.00
0005434448367	9590	Business	32600.00
0005432817899	9590	Economy	10900.00
0005432817893	9590	Economy	10900.00
0005432901738	9590	Economy	10900.00
0005432817886	9590	Economy	10900.00
0005432817894	9590	Economy	10900.00
0005432817881	9590	Economy	10900.00
0005432817897	9590	Economy	10900.00
0005432901720	9590	Economy	10900.00
0005432817880	9590	Economy	11900.00
0005432901721	9590	Economy	11900.00
0005432817892	9590	Economy	11900.00
0005432817891	9590	Economy	10900.00
0005432901722	9590	Economy	10900.00
0005432822312	9590	Economy	10900.00
0005432817898	9590	Economy	10900.00
0005432817907	9590	Economy	10900.00
0005434157511	9590	Economy	10900.00
0005432822313	9590	Economy	10900.00
0005432289034	9590	Economy	10900.00
0005434448366	9590	Economy	10900.00
0005432817890	9590	Economy	10900.00
0005432817885	9590	Economy	10900.00
0005432901739	9590	Economy	10900.00
0005432817900	9590	Economy	10900.00
0005432901706	9590	Economy	10900.00
0005434448365	9590	Economy	10900.00
0005432901732	9590	Economy	10900.00
0005432901733	9590	Economy	10900.00
0005432817901	9590	Economy	10900.00
0005432822314	9590	Economy	10900.00
0005432817883	9590	Economy	10900.00
0005434157510	9590	Economy	10900.00
0005432817902	9590	Economy	10900.00
0005434448364	9590	Economy	10900.00
0005432817906	9590	Economy	10900.00
0005432817904	9590	Economy	10900.00
0005432817882	9590	Economy	10900.00
0005432901723	9590	Economy	10900.00
0005434157533	9590	Economy	10900.00
0005434186217	9590	Economy	10900.00
0005432817905	9590	Economy	10900.00
0005432901719	9590	Economy	10900.00
0005434186221	9590	Economy	10900.00
0005434157526	9590	Economy	10900.00
0005432817903	9590	Economy	10900.00
0005434186211	9590	Economy	10900.00
0005432817887	9590	Economy	10900.00
0005432901698	9590	Economy	10900.00
0005434186218	9590	Economy	10900.00
0005432817908	9590	Economy	10900.00
0005432817896	9590	Economy	10900.00
0005432817889	9590	Economy	10900.00
0005432817884	9590	Economy	10900.00
0005432901669	9590	Economy	10900.00
0005432822316	9590	Economy	10900.00
0005432901757	9590	Economy	10900.00
0005432817888	9590	Economy	10900.00
0005432822311	9590	Economy	10900.00
0005432817895	9590	Economy	10900.00
0005434157525	9590	Economy	10900.00
0005432822310	9590	Economy	10900.00
0005432822317	9590	Economy	10900.00
0005432289033	9590	Economy	10900.00
0005432822315	9590	Economy	10900.00
0005432817595	28959	Business	32600.00
0005432817723	28959	Business	32600.00
0005434157595	28959	Business	32600.00
0005432817611	28959	Business	32600.00
0005432901867	28959	Business	32600.00
0005434448325	28959	Business	32600.00
0005432817599	28959	Business	32600.00
0005432817724	28959	Business	32600.00
0005432901863	28959	Business	32600.00
0005432817625	28959	Economy	10900.00
0005434157592	28959	Economy	10900.00
0005432817644	28959	Economy	10900.00
0005432817642	28959	Economy	10900.00
0005432817770	28959	Economy	10900.00
0005432817464	28959	Economy	10900.00
0005432002106	28959	Economy	10900.00
0005432901866	28959	Economy	10900.00
0005434157590	28959	Economy	10900.00
0005432822254	28959	Economy	11900.00
0005432901852	28959	Economy	11900.00
0005432901868	28959	Economy	11900.00
0005432817610	28959	Economy	11900.00
0005432817631	28959	Economy	11900.00
0005432817678	28959	Economy	10900.00
0005434157597	28959	Economy	10900.00
0005432901865	28959	Economy	10900.00
0005432901851	28959	Economy	10900.00
0005432822244	28959	Economy	10900.00
0005434186239	28959	Economy	10900.00
0005434157588	28959	Economy	10900.00
0005432817694	28959	Economy	10900.00
0005432822231	28959	Economy	10900.00
0005432002105	28959	Economy	10900.00
0005432901859	28959	Economy	10900.00
0005432901853	28959	Economy	10900.00
0005432817612	28959	Economy	10900.00
0005432901860	28959	Economy	10900.00
0005432817641	28959	Economy	10900.00
0005432817504	28959	Economy	10900.00
0005432901864	28959	Economy	10900.00
0005432817619	28959	Economy	10900.00
0005434157587	28959	Economy	10900.00
0005432901861	28959	Economy	10900.00
0005432817628	28959	Economy	10900.00
0005434157596	28959	Economy	10900.00
0005432817659	28959	Economy	10900.00
0005434448323	28959	Economy	10900.00
0005434448324	28959	Economy	10900.00
0005432817661	28959	Economy	10900.00
0005434186238	28959	Economy	10900.00
0005434448321	28959	Economy	10900.00
0005432822245	28959	Economy	10900.00
0005432817658	28959	Economy	10900.00
0005432817740	28959	Economy	10900.00
0005434157591	28959	Economy	10900.00
0005432901854	28959	Economy	10900.00
0005432817691	28959	Economy	10900.00
0005432817581	28959	Economy	10900.00
0005432817643	28959	Economy	10900.00
0005432002107	28959	Economy	10900.00
0005432901856	28959	Economy	10900.00
0005432817505	28959	Economy	10900.00
0005434157594	28959	Economy	10900.00
0005434448322	28959	Economy	10900.00
0005432901857	28959	Economy	10900.00
0005432817572	28959	Economy	10900.00
0005434157593	28959	Economy	10900.00
0005432817600	28959	Economy	10900.00
0005432901862	28959	Economy	10900.00
0005432817771	28959	Economy	10900.00
0005432817613	28959	Economy	10900.00
0005432817692	28959	Economy	10900.00
0005432901855	28959	Economy	10900.00
0005432901858	28959	Economy	10900.00
0005434157589	28959	Economy	10900.00
0005432822250	28959	Economy	10900.00
0005432613921	15052	Economy	11000.00
0005432611766	15052	Economy	11000.00
0005432611764	15052	Economy	11000.00
0005432613919	15052	Economy	11000.00
0005432613920	15052	Economy	11000.00
0005432611765	15052	Economy	11000.00
0005432613922	15052	Economy	11000.00
0005432607568	31611	Economy	11000.00
0005432611709	31611	Economy	11000.00
0005432611708	31611	Economy	11000.00
0005432607569	31611	Economy	11000.00
0005432607579	31611	Economy	11000.00
0005432611723	31611	Economy	11000.00
0005432607586	31611	Economy	11000.00
0005433569837	11839	Business	105900.00
0005433569903	11839	Business	105900.00
0005432948708	11839	Business	105900.00
0005432948567	11839	Business	105900.00
0005432948432	11839	Business	105900.00
0005433569854	11839	Business	105900.00
0005433569884	11839	Business	105900.00
0005433569855	11839	Business	105900.00
0005433569849	11839	Business	105900.00
0005432948568	11839	Business	105900.00
0005432948514	11839	Business	105900.00
0005432948721	11839	Business	105900.00
0005432948628	11839	Business	105900.00
0005433569892	11839	Business	105900.00
0005432948510	11839	Business	105900.00
0005433569859	11839	Business	105900.00
0005432948573	11839	Business	105900.00
0005433569843	11839	Business	105900.00
0005433569872	11839	Business	105900.00
0005433569899	11839	Economy	35300.00
0005432948520	11839	Economy	35300.00
0005433569890	11839	Economy	35300.00
0005433569887	11839	Economy	35300.00
0005433569848	11839	Economy	35300.00
0005433569901	11839	Economy	35300.00
0005432948519	11839	Economy	35300.00
0005433569864	11839	Economy	35300.00
0005433569866	11839	Economy	35300.00
0005432948589	11839	Economy	35300.00
0005432948675	11839	Economy	35300.00
0005433569873	11839	Economy	35300.00
0005433569858	11839	Economy	35300.00
0005433569894	11839	Economy	38800.00
0005433569865	11839	Economy	38800.00
0005433569906	11839	Economy	38800.00
0005433569871	11839	Economy	35300.00
0005433569896	11839	Economy	38800.00
0005433569844	11839	Economy	35300.00
0005433569898	11839	Economy	35300.00
0005432948629	11839	Economy	35300.00
0005432948579	11839	Economy	35300.00
0005432948609	11839	Economy	35300.00
0005433569861	11839	Economy	35300.00
0005433569879	11839	Economy	35300.00
0005433569867	11839	Economy	35300.00
0005433569875	11839	Economy	35300.00
0005432948722	11839	Economy	35300.00
0005433569847	11839	Economy	35300.00
0005433569902	11839	Economy	35300.00
0005432948717	11839	Economy	35300.00
0005432948569	11839	Economy	35300.00
0005433569852	11839	Economy	35300.00
0005433569881	11839	Economy	35300.00
0005432948778	11839	Economy	35300.00
0005433569868	11839	Economy	35300.00
0005433569883	11839	Economy	35300.00
0005432948709	11839	Economy	35300.00
0005433569856	11839	Economy	35300.00
0005432948745	11839	Economy	35300.00
0005433569904	11839	Economy	35300.00
0005432948444	11839	Economy	35300.00
0005433569893	11839	Economy	35300.00
0005433569850	11839	Economy	35300.00
0005433569842	11839	Economy	35300.00
0005433569885	11839	Economy	35300.00
0005432948742	11839	Economy	35300.00
0005433569878	11839	Economy	35300.00
0005433569841	11839	Economy	35300.00
0005432948509	11839	Economy	35300.00
0005433569840	11839	Economy	35300.00
0005432948743	11839	Economy	35300.00
0005432948541	11839	Economy	35300.00
0005432948814	11839	Economy	35300.00
0005433569900	11839	Economy	35300.00
0005432948445	11839	Economy	35300.00
0005433569862	11839	Economy	35300.00
0005432948545	11839	Economy	35300.00
0005432948780	11839	Economy	35300.00
0005433569863	11839	Economy	35300.00
0005433569869	11839	Economy	35300.00
0005433569860	11839	Economy	35300.00
0005433569891	11839	Economy	35300.00
0005433569853	11839	Economy	35300.00
0005433569876	11839	Economy	35300.00
0005432948746	11839	Economy	35300.00
0005433569877	11839	Economy	35300.00
0005433569905	11839	Economy	35300.00
0005433569889	11839	Economy	35300.00
0005433569874	11839	Economy	35300.00
0005432948501	11839	Economy	35300.00
0005433569838	11839	Economy	35300.00
0005433569839	11839	Economy	35300.00
0005433569870	11839	Economy	35300.00
0005433569907	11839	Economy	35300.00
0005432948813	11839	Economy	35300.00
0005433569897	11839	Economy	35300.00
0005433569886	11839	Economy	35300.00
0005433569880	11839	Economy	35300.00
0005433569882	11839	Economy	35300.00
0005433569857	11839	Economy	35300.00
0005432948542	11839	Economy	35300.00
0005433569851	11839	Economy	35300.00
0005432948671	11839	Economy	35300.00
0005432948610	11839	Economy	35300.00
0005433569895	11839	Economy	35300.00
0005433569846	11839	Economy	35300.00
0005432948580	11839	Economy	35300.00
0005432948500	11839	Economy	35300.00
0005432948566	11839	Economy	35300.00
0005433569845	11839	Economy	35300.00
0005433569888	11839	Economy	35300.00
0005432949087	25308	Business	105900.00
0005432949065	25308	Business	105900.00
0005433569192	25308	Business	105900.00
0005432949072	25308	Business	105900.00
0005432949089	25308	Business	105900.00
0005433569375	25308	Business	105900.00
0005433569397	25308	Business	105900.00
0005432949075	25308	Business	105900.00
0005433569279	25308	Business	105900.00
0005432949086	25308	Business	105900.00
0005432949082	25308	Business	105900.00
0005433569350	25308	Business	105900.00
0005432949061	25308	Business	105900.00
0005433569319	25308	Business	105900.00
0005433569424	25308	Business	105900.00
0005433569164	25308	Business	105900.00
0005432949064	25308	Business	105900.00
0005432949074	25308	Economy	35300.00
0005433569213	25308	Business	105900.00
0005433569357	25308	Economy	35300.00
0005433569349	25308	Economy	35300.00
0005432949096	25308	Economy	35300.00
0005432949097	25308	Economy	35300.00
0005433569214	25308	Economy	35300.00
0005432949080	25308	Economy	35300.00
0005433569212	25308	Economy	35300.00
0005433569406	25308	Economy	35300.00
0005433569338	25308	Economy	35300.00
0005433569333	25308	Economy	38800.00
0005433569273	25308	Economy	38800.00
0005432949085	25308	Economy	38800.00
0005433569284	25308	Economy	38800.00
0005432949069	25308	Economy	35300.00
0005433569053	25308	Economy	35300.00
0005433569209	25308	Economy	35300.00
0005433569323	25308	Economy	35300.00
0005433569178	25308	Economy	35300.00
0005433569218	25308	Economy	35300.00
0005433569347	25308	Economy	35300.00
0005433569332	25308	Economy	35300.00
0005432949070	25308	Economy	35300.00
0005433569376	25308	Economy	35300.00
0005433569154	25308	Economy	35300.00
0005432949067	25308	Economy	35300.00
0005433569328	25308	Economy	35300.00
0005433569322	25308	Economy	35300.00
0005432949093	25308	Economy	35300.00
0005433569391	25308	Economy	35300.00
0005433569358	25308	Economy	35300.00
0005432949057	25308	Economy	35300.00
0005433569052	25308	Economy	35300.00
0005432949059	25308	Economy	35300.00
0005433569327	25308	Economy	35300.00
0005432949068	25308	Economy	35300.00
0005433569261	25308	Economy	35300.00
0005432949058	25308	Economy	35300.00
0005433569313	25308	Economy	35300.00
0005433569423	25308	Economy	35300.00
0005433569301	25308	Economy	35300.00
0005432949078	25308	Economy	35300.00
0005433569138	25308	Economy	35300.00
0005432949073	25308	Economy	35300.00
0005433569215	25308	Economy	35300.00
0005432949066	25308	Economy	35300.00
0005432949092	25308	Economy	35300.00
0005433569260	25308	Economy	35300.00
0005432949083	25308	Economy	35300.00
0005433569262	25308	Economy	35300.00
0005432949084	25308	Economy	35300.00
0005433569059	25308	Economy	35300.00
0005433569173	25308	Economy	35300.00
0005433569272	25308	Economy	35300.00
0005432949077	25308	Economy	35300.00
0005433569393	25308	Economy	35300.00
0005432949081	25308	Economy	35300.00
0005433569235	25308	Economy	35300.00
0005433569300	25308	Economy	35300.00
0005432949094	25308	Economy	35300.00
0005433569439	25308	Economy	35300.00
0005433569003	25308	Economy	35300.00
0005433569229	25308	Economy	35300.00
0005432949079	25308	Economy	35300.00
0005432949090	25308	Economy	35300.00
0005433569004	25308	Economy	35300.00
0005433569188	25308	Economy	35300.00
0005432949060	25308	Economy	35300.00
0005433569222	25308	Economy	35300.00
0005433569204	25308	Economy	35300.00
0005433569369	25308	Economy	35300.00
0005432949063	25308	Economy	35300.00
0005433569124	25308	Economy	35300.00
0005433569278	25308	Economy	35300.00
0005433569399	25308	Economy	35300.00
0005433569177	25308	Economy	35300.00
0005432949095	25308	Economy	35300.00
0005432949088	25308	Economy	35300.00
0005432949071	25308	Economy	35300.00
0005433569233	25308	Economy	35300.00
0005433569058	25308	Economy	35300.00
0005432949062	25308	Economy	35300.00
0005433569140	25308	Economy	35300.00
0005432949091	25308	Economy	35300.00
0005433569312	25308	Economy	35300.00
0005433569088	25308	Economy	35300.00
0005433569254	25308	Economy	35300.00
0005432949076	25308	Economy	35300.00
0005432430889	30830	Business	117400.00
0005433808427	30830	Business	117400.00
0005433808423	30830	Business	117400.00
0005434026706	30830	Business	117400.00
0005433812929	30830	Business	117400.00
0005433808431	30830	Business	117400.00
0005432430887	30830	Economy	39100.00
0005433812926	30830	Economy	39100.00
0005434026711	30830	Economy	39100.00
0005433812930	30830	Economy	39100.00
0005433808432	30830	Economy	39100.00
0005433808428	30830	Economy	39100.00
0005433808426	30830	Economy	39100.00
0005432430888	30830	Economy	39100.00
0005433812932	30830	Economy	39100.00
0005433808422	30830	Economy	39100.00
0005433808424	30830	Economy	39100.00
0005432430880	30830	Economy	39100.00
0005432430873	30830	Economy	39100.00
0005434026713	30830	Economy	39100.00
0005433812933	30830	Economy	39100.00
0005432430876	30830	Economy	39100.00
0005433808429	30830	Economy	39100.00
0005434026710	30830	Economy	39100.00
0005432430877	30830	Economy	39100.00
0005432430875	30830	Economy	39100.00
0005434026709	30830	Economy	39100.00
0005432430879	30830	Economy	39100.00
0005434026705	30830	Economy	39100.00
0005434026704	30830	Economy	39100.00
0005432430891	30830	Economy	39100.00
0005433808430	30830	Economy	39100.00
0005433808425	30830	Economy	39100.00
0005433812928	30830	Economy	39100.00
0005433812927	30830	Economy	39100.00
0005433812931	30830	Economy	39100.00
0005434026712	30830	Economy	39100.00
0005434655099	5370	Business	67200.00
0005434655090	5370	Business	67200.00
0005435340323	5370	Business	67200.00
0005435555379	5370	Business	67200.00
0005434656584	5370	Business	67200.00
0005434655098	5370	Business	67200.00
0005435340358	5370	Business	67200.00
0005434655110	5370	Economy	22400.00
0005435555384	5370	Economy	22400.00
0005434655101	5370	Economy	22400.00
0005435340313	5370	Economy	22400.00
0005432114249	5370	Economy	22400.00
0005434655089	5370	Economy	22400.00
0005434655108	5370	Economy	22400.00
0005435340322	5370	Economy	22400.00
0005435555383	5370	Economy	22400.00
0005434655104	5370	Economy	24600.00
0005435555380	5370	Economy	24600.00
0005434655095	5370	Economy	24600.00
0005432114248	5370	Economy	24600.00
0005435340365	5370	Economy	22400.00
0005434655097	5370	Economy	22400.00
0005434655094	5370	Economy	22400.00
0005434655102	5370	Economy	22400.00
0005435340344	5370	Economy	22400.00
0005434655092	5370	Economy	22400.00
0005435340355	5370	Economy	22400.00
0005435340291	5370	Economy	22400.00
0005434655088	5370	Economy	22400.00
0005435555381	5370	Economy	22400.00
0005434655109	5370	Economy	22400.00
0005434655091	5370	Economy	22400.00
0005435340364	5370	Economy	22400.00
0005434655105	5370	Economy	22400.00
0005435340312	5370	Economy	22400.00
0005434655113	5370	Economy	22400.00
0005434655093	5370	Economy	22400.00
0005434656586	5370	Economy	22400.00
0005434655086	5370	Economy	22400.00
0005435340361	5370	Economy	22400.00
0005435340343	5370	Economy	22400.00
0005434656585	5370	Economy	22400.00
0005434655111	5370	Economy	22400.00
0005434655112	5370	Economy	22400.00
0005434655100	5370	Economy	22400.00
0005435340351	5370	Economy	22400.00
0005434655103	5370	Economy	22400.00
0005434655107	5370	Economy	22400.00
0005435340362	5370	Economy	22400.00
0005434655115	5370	Economy	22400.00
0005434655106	5370	Economy	22400.00
0005434655114	5370	Economy	22400.00
0005432114250	5370	Economy	22400.00
0005435340381	5370	Economy	22400.00
0005434655087	5370	Economy	22400.00
0005434655096	5370	Economy	22400.00
0005435340482	12530	Business	67200.00
0005434654896	12530	Business	67200.00
0005434654982	12530	Business	67200.00
0005434654951	12530	Business	67200.00
0005434654905	12530	Business	67200.00
0005434654794	12530	Business	67200.00
0005435340474	12530	Business	67200.00
0005435340484	12530	Economy	22400.00
0005435340481	12530	Economy	22400.00
0005435340477	12530	Economy	22400.00
0005435340485	12530	Economy	22400.00
0005435340473	12530	Economy	22400.00
0005435555402	12530	Economy	24600.00
0005435340476	12530	Economy	24600.00
0005434654850	12530	Economy	22400.00
0005435340478	12530	Economy	22400.00
0005434654878	12530	Economy	22400.00
0005435340472	12530	Economy	22400.00
0005434654793	12530	Economy	22400.00
0005435555401	12530	Economy	22400.00
0005434654790	12530	Economy	22400.00
0005434654863	12530	Economy	22400.00
0005435340479	12530	Economy	22400.00
0005435340475	12530	Economy	22400.00
0005434654721	12530	Economy	22400.00
0005434654861	12530	Economy	22400.00
0005434654860	12530	Economy	22400.00
0005435340487	12530	Economy	22400.00
0005434654739	12530	Economy	22400.00
0005434654849	12530	Economy	22400.00
0005434654841	12530	Economy	22400.00
0005434654842	12530	Economy	22400.00
0005434654865	12530	Economy	22400.00
0005435340486	12530	Economy	22400.00
0005435340480	12530	Economy	22400.00
0005435340483	12530	Economy	22400.00
0005434654853	12530	Economy	22400.00
0005434654799	12530	Economy	22400.00
0005434654788	12530	Economy	22400.00
0005434654837	12530	Economy	22400.00
0005434654765	12530	Economy	22400.00
0005434654915	12530	Economy	22400.00
0005434654897	12530	Economy	22400.00
0005433716680	7443	Business	32000.00
0005433716701	7443	Business	32000.00
0005433716700	7443	Business	32000.00
0005433716679	7443	Business	32000.00
0005433689939	7443	Business	32000.00
0005433716698	7443	Business	32000.00
0005432078188	7443	Business	32000.00
0005432428952	7443	Business	32000.00
0005433722311	7443	Economy	10700.00
0005433716658	7443	Economy	10700.00
0005433716683	7443	Economy	10700.00
0005432428927	7443	Economy	10700.00
0005433719186	7443	Economy	10700.00
0005433716702	7443	Economy	10700.00
0005433656718	7443	Economy	10700.00
0005433716659	7443	Economy	10700.00
0005433716666	7443	Economy	10700.00
0005433716697	7443	Economy	10700.00
0005432428941	7443	Economy	10700.00
0005433716681	7443	Economy	10700.00
0005433716668	7443	Economy	10700.00
0005433716703	7443	Economy	10700.00
0005433716661	7443	Economy	10700.00
0005433716677	7443	Economy	10700.00
0005432428928	7443	Economy	10700.00
0005433716699	7443	Economy	10700.00
0005432078186	7443	Economy	11700.00
0005433716654	7443	Economy	11700.00
0005433716678	7443	Economy	11700.00
0005433716693	7443	Economy	11700.00
0005433716682	7443	Economy	11700.00
0005433716667	7443	Economy	10700.00
0005433716674	7443	Economy	10700.00
0005433716663	7443	Economy	10700.00
0005433716696	7443	Economy	10700.00
0005433690952	7443	Economy	10700.00
0005433716657	7443	Economy	10700.00
0005433716653	7443	Economy	10700.00
0005433716670	7443	Economy	10700.00
0005433716695	7443	Economy	10700.00
0005433716673	7443	Economy	10700.00
0005433722312	7443	Economy	10700.00
0005433722309	7443	Economy	10700.00
0005433716671	7443	Economy	10700.00
0005433716655	7443	Economy	10700.00
0005435266157	7443	Economy	10700.00
0005432078184	7443	Economy	10700.00
0005433716694	7443	Economy	10700.00
0005433716685	7443	Economy	10700.00
0005433656715	7443	Economy	10700.00
0005433688838	7443	Economy	10700.00
0005433716704	7443	Economy	10700.00
0005433722313	7443	Economy	10700.00
0005433716686	7443	Economy	10700.00
0005432078187	7443	Economy	10700.00
0005433716691	7443	Economy	10700.00
0005433716687	7443	Economy	10700.00
0005433719188	7443	Economy	10700.00
0005433716665	7443	Economy	10700.00
0005433716669	7443	Economy	10700.00
0005433716656	7443	Economy	10700.00
0005433722310	7443	Economy	10700.00
0005433716688	7443	Economy	10700.00
0005432428940	7443	Economy	10700.00
0005433716690	7443	Economy	10700.00
0005432078185	7443	Economy	10700.00
0005433690951	7443	Economy	10700.00
0005433656717	7443	Economy	10700.00
0005433716660	7443	Economy	10700.00
0005432428953	7443	Economy	10700.00
0005433656714	7443	Economy	10700.00
0005433719187	7443	Economy	10700.00
0005433716664	7443	Economy	10700.00
0005433716672	7443	Economy	10700.00
0005433716676	7443	Economy	10700.00
0005433689940	7443	Economy	10700.00
0005432078189	7443	Economy	10700.00
0005433716675	7443	Economy	10700.00
0005433716662	7443	Economy	10700.00
0005433716692	7443	Economy	10700.00
0005433716689	7443	Economy	10700.00
0005433716684	7443	Economy	10700.00
0005433656716	7443	Economy	10700.00
0005432428978	29200	Business	32000.00
0005433716347	29200	Business	32000.00
0005433716214	29200	Business	32000.00
0005433716018	29200	Business	32000.00
0005433716206	29200	Business	32000.00
0005433716324	29200	Business	32000.00
0005433716120	29200	Business	32000.00
0005433716265	29200	Business	32000.00
0005433716260	29200	Economy	10700.00
0005433716420	29200	Economy	10700.00
0005433716307	29200	Economy	10700.00
0005433716157	29200	Economy	10700.00
0005433716228	29200	Economy	10700.00
0005433716093	29200	Economy	10700.00
0005433656684	29200	Economy	10700.00
0005432006805	29200	Economy	10700.00
0005433719168	29200	Economy	10700.00
0005433716421	29200	Economy	10700.00
0005435266207	29200	Economy	10700.00
0005433716104	29200	Economy	10700.00
0005433688817	29200	Economy	10700.00
0005433716141	29200	Economy	10700.00
0005433716216	29200	Economy	10700.00
0005433716156	29200	Economy	10700.00
0005433716101	29200	Economy	10700.00
0005433719149	29200	Economy	10700.00
0005433716376	29200	Economy	10700.00
0005433716339	29200	Economy	10700.00
0005433656693	29200	Economy	10700.00
0005433716318	29200	Economy	10700.00
0005433722238	29200	Economy	10700.00
0005433716061	29200	Economy	10700.00
0005433716184	29200	Economy	10700.00
0005433716284	29200	Economy	10700.00
0005433716168	29200	Economy	10700.00
0005433716308	29200	Economy	10700.00
0005432428977	29200	Economy	10700.00
0005433716250	29200	Economy	10700.00
0005433722250	29200	Economy	11700.00
0005433716059	29200	Economy	11700.00
0005433716102	29200	Economy	11700.00
0005433716212	29200	Economy	10700.00
0005433722217	29200	Economy	11700.00
0005433685524	29200	Economy	10700.00
0005433716246	29200	Economy	10700.00
0005435266205	29200	Economy	10700.00
0005433716186	29200	Economy	10700.00
0005433716227	29200	Economy	10700.00
0005433716276	29200	Economy	10700.00
0005435266206	29200	Economy	10700.00
0005433685527	29200	Economy	10700.00
0005433716319	29200	Economy	10700.00
0005433716145	29200	Economy	10700.00
0005433716245	29200	Economy	10700.00
0005433716146	29200	Economy	10700.00
0005433716207	29200	Economy	10700.00
0005432428976	29200	Economy	10700.00
0005433722237	29200	Economy	10700.00
0005433716338	29200	Economy	10700.00
0005433656685	29200	Economy	10700.00
0005433716375	29200	Economy	10700.00
0005433688828	29200	Economy	10700.00
0005433716235	29200	Economy	10700.00
0005433716215	29200	Economy	10700.00
0005433716252	29200	Economy	10700.00
0005433716060	29200	Economy	10700.00
0005433716118	29200	Economy	10700.00
0005433716170	29200	Economy	10700.00
0005433716317	29200	Economy	10700.00
0005433716310	29200	Economy	10700.00
0005435266204	29200	Economy	10700.00
0005433656692	29200	Economy	10700.00
0005433722231	29200	Economy	10700.00
0005432428979	29200	Economy	10700.00
0005433716119	29200	Economy	10700.00
0005433716117	29200	Economy	10700.00
0005433716178	29200	Economy	10700.00
0005433716123	29200	Economy	10700.00
0005433716374	29200	Economy	10700.00
0005433716261	29200	Economy	10700.00
0005433716309	29200	Economy	10700.00
0005433716056	29200	Economy	10700.00
0005433716140	29200	Economy	10700.00
0005433722230	29200	Economy	10700.00
0005432006804	29200	Economy	10700.00
0005433716371	29200	Economy	10700.00
0005433716238	29200	Economy	10700.00
0005433716147	29200	Economy	10700.00
0005433716164	29200	Economy	10700.00
0005433716187	29200	Economy	10700.00
0005433716213	29200	Economy	10700.00
0005433716416	29200	Economy	10700.00
0005434182231	8708	Business	36500.00
0005434182251	8708	Business	36500.00
0005434095487	8708	Business	36500.00
0005434095480	8708	Business	36500.00
0005434182250	8708	Business	36500.00
0005434182279	8708	Business	36500.00
0005434095476	8708	Business	36500.00
0005434095484	8708	Economy	12200.00
0005434095485	8708	Economy	12200.00
0005434182267	8708	Economy	12200.00
0005434095483	8708	Economy	12200.00
0005434182316	8708	Economy	12200.00
0005434095481	8708	Economy	13400.00
0005434182259	8708	Economy	13400.00
0005434182286	8708	Economy	12200.00
0005434184677	8708	Economy	12200.00
0005434182280	8708	Economy	12200.00
0005434095486	8708	Economy	12200.00
0005434182260	8708	Economy	12200.00
0005434095475	8708	Economy	12200.00
0005434095474	8708	Economy	12200.00
0005434182294	8708	Economy	12200.00
0005434182256	8708	Economy	12200.00
0005434095482	8708	Economy	12200.00
0005434184678	8708	Economy	12200.00
0005434182252	8708	Economy	12200.00
0005434095478	8708	Economy	12200.00
0005434095479	8708	Economy	12200.00
0005434095473	8708	Economy	12200.00
0005434184682	8708	Economy	12200.00
0005434095477	8708	Economy	12200.00
0005434182335	8708	Economy	12200.00
0005434182230	8708	Economy	12200.00
0005434184692	11655	Business	36500.00
0005434182364	11655	Business	36500.00
0005434095326	11655	Business	36500.00
0005434182359	11655	Business	36500.00
0005434182369	11655	Economy	12200.00
0005434182365	11655	Economy	12200.00
0005434143732	11655	Economy	12200.00
0005434095349	11655	Economy	12200.00
0005434095350	11655	Economy	13400.00
0005434182363	11655	Economy	12200.00
0005434095336	11655	Economy	12200.00
0005434095366	11655	Economy	12200.00
0005434095292	11655	Economy	12200.00
0005434095340	11655	Economy	12200.00
0005434095393	11655	Economy	12200.00
0005434143726	11655	Economy	12200.00
0005434182366	11655	Economy	12200.00
0005434095327	11655	Economy	12200.00
0005434143736	11655	Economy	12200.00
0005434184691	11655	Economy	12200.00
0005434095282	11655	Economy	12200.00
0005434182368	11655	Economy	12200.00
0005434095315	11655	Economy	12200.00
0005434182362	11655	Economy	12200.00
0005434095364	11655	Economy	12200.00
0005434143731	11655	Economy	12200.00
0005434182367	11655	Economy	12200.00
0005434182361	11655	Economy	12200.00
0005434182358	11655	Economy	12200.00
0005434182360	11655	Economy	12200.00
0005434095363	11655	Economy	12200.00
0005434095341	11655	Economy	12200.00
0005434143725	11655	Economy	12200.00
0005434182357	11655	Economy	12200.00
0005434095283	11655	Economy	12200.00
0005434095345	11655	Economy	12200.00
0005434183607	11655	Economy	12200.00
0005434183606	11655	Economy	12200.00
0005433398508	1421	Business	33000.00
0005433398384	1421	Business	33000.00
0005433398206	1421	Business	33000.00
0005433398323	1421	Business	33000.00
0005433398102	1421	Business	33000.00
0005433398269	1421	Business	33000.00
0005433398289	1421	Business	33000.00
0005433398158	1421	Business	33000.00
0005433398103	1421	Economy	11000.00
0005433398308	1421	Economy	11000.00
0005433398365	1421	Economy	11000.00
0005433398542	1421	Economy	11000.00
0005433398288	1421	Economy	11000.00
0005433457025	1421	Economy	11000.00
0005433457028	1421	Economy	11000.00
0005433398339	1421	Economy	11000.00
0005433398276	1421	Economy	11000.00
0005433398318	1421	Economy	12100.00
0005433398265	1421	Economy	12100.00
0005433398300	1421	Economy	12100.00
0005433398128	1421	Economy	12100.00
0005433398463	1421	Economy	12100.00
0005433398325	1421	Economy	11000.00
0005432297315	1421	Economy	11000.00
0005433398462	1421	Economy	11000.00
0005433398509	1421	Economy	11000.00
0005433398199	1421	Economy	11000.00
0005433398173	1421	Economy	11000.00
0005432906554	1421	Economy	11000.00
0005433398420	1421	Economy	11000.00
0005433398417	1421	Economy	11000.00
0005433398363	1421	Economy	11000.00
0005433457027	1421	Economy	11000.00
0005432906552	1421	Economy	11000.00
0005433398464	1421	Economy	11000.00
0005433398337	1421	Economy	11000.00
0005433398409	1421	Economy	11000.00
0005432906553	1421	Economy	11000.00
0005433398394	1421	Economy	11000.00
0005433398418	1421	Economy	11000.00
0005433398272	1421	Economy	11000.00
0005433398506	1421	Economy	11000.00
0005433398283	1421	Economy	11000.00
0005433398395	1421	Economy	11000.00
0005433398419	1421	Economy	11000.00
0005433398309	1421	Economy	11000.00
0005433398165	1421	Economy	11000.00
0005433398415	1421	Economy	11000.00
0005433398338	1421	Economy	11000.00
0005433398172	1421	Economy	11000.00
0005433398356	1421	Economy	11000.00
0005433398201	1421	Economy	11000.00
0005433398446	1421	Economy	11000.00
0005433398364	1421	Economy	11000.00
0005433398326	1421	Economy	11000.00
0005433398166	1421	Economy	11000.00
0005433398270	1421	Economy	11000.00
0005433457026	1421	Economy	11000.00
0005433398389	1421	Economy	11000.00
0005433398348	1421	Economy	11000.00
0005433398507	1421	Economy	11000.00
0005433398510	1421	Economy	11000.00
0005433398396	1421	Economy	11000.00
0005433398411	1421	Economy	11000.00
0005433398317	1421	Economy	11000.00
0005433398197	1421	Economy	11000.00
0005433398355	1421	Economy	11000.00
0005433398101	1421	Economy	11000.00
0005433398271	1421	Economy	11000.00
0005433398456	1421	Economy	11000.00
0005433398193	1421	Economy	11000.00
0005433398324	1421	Economy	11000.00
0005433398460	1421	Economy	11000.00
0005433398430	1421	Economy	11000.00
0005433398267	1421	Economy	11000.00
0005433398282	1421	Economy	11000.00
0005433398518	1421	Economy	11000.00
0005433398266	1421	Economy	11000.00
0005435732425	19233	Business	33000.00
0005433398734	19233	Business	33000.00
0005435732341	19233	Business	33000.00
0005433398746	19233	Business	33000.00
0005433398759	19233	Business	33000.00
0005435732452	19233	Business	33000.00
0005435732383	19233	Business	33000.00
0005433398767	19233	Economy	11000.00
0005433398736	19233	Economy	11000.00
0005435732377	19233	Economy	11000.00
0005433398753	19233	Economy	11000.00
0005433398742	19233	Economy	11000.00
0005433398726	19233	Economy	11000.00
0005433398750	19233	Economy	11000.00
0005435732426	19233	Economy	12100.00
0005433398763	19233	Economy	12100.00
0005433398756	19233	Economy	11000.00
0005433398725	19233	Economy	11000.00
0005435732453	19233	Economy	11000.00
0005433398745	19233	Economy	11000.00
0005433398733	19233	Economy	11000.00
0005433398730	19233	Economy	11000.00
0005433398741	19233	Economy	11000.00
0005433398766	19233	Economy	11000.00
0005433398743	19233	Economy	11000.00
0005432906571	19233	Economy	11000.00
0005433398747	19233	Economy	11000.00
0005433398761	19233	Economy	11000.00
0005433398737	19233	Economy	11000.00
0005435732382	19233	Economy	11000.00
0005433398751	19233	Economy	11000.00
0005433398757	19233	Economy	11000.00
0005433398720	19233	Economy	11000.00
0005433398727	19233	Economy	11000.00
0005433398723	19233	Economy	11000.00
0005433398748	19233	Economy	11000.00
0005433398765	19233	Economy	11000.00
0005435732437	19233	Economy	11000.00
0005433398724	19233	Economy	11000.00
0005433398769	19233	Economy	11000.00
0005435732422	19233	Economy	11000.00
0005435732423	19233	Economy	11000.00
0005433398755	19233	Economy	11000.00
0005433398749	19233	Economy	11000.00
0005433398732	19233	Economy	11000.00
0005433398739	19233	Economy	11000.00
0005433398754	19233	Economy	11000.00
0005433456989	19233	Economy	11000.00
0005433456990	19233	Economy	11000.00
0005433457005	19233	Economy	11000.00
0005433398728	19233	Economy	11000.00
0005433398758	19233	Economy	11000.00
0005433398731	19233	Economy	11000.00
0005433398752	19233	Economy	11000.00
0005433398729	19233	Economy	11000.00
0005433398764	19233	Economy	11000.00
0005433398721	19233	Economy	11000.00
0005435732421	19233	Economy	11000.00
0005433398740	19233	Economy	11000.00
0005435732358	19233	Economy	11000.00
0005435732380	19233	Economy	11000.00
0005435732379	19233	Economy	11000.00
0005433398735	19233	Economy	11000.00
0005433398744	19233	Economy	11000.00
0005435732354	19233	Economy	11000.00
0005433398760	19233	Economy	11000.00
0005433398722	19233	Economy	11000.00
0005433398762	19233	Economy	11000.00
0005435732353	19233	Economy	11000.00
0005433398768	19233	Economy	11000.00
0005433398738	19233	Economy	11000.00
0005434443756	17349	Economy	15600.00
0005434443790	17349	Economy	15600.00
0005434443758	17349	Economy	14100.00
0005434443764	17349	Economy	14100.00
0005434443787	17349	Economy	14100.00
0005434443763	17349	Economy	14100.00
0005434443823	17349	Economy	14100.00
0005434443827	17349	Economy	14100.00
0005434443718	17349	Economy	14100.00
0005434443791	17349	Economy	14100.00
0005434443767	17349	Economy	14100.00
0005434443757	17349	Economy	14100.00
0005434443931	20594	Economy	15600.00
0005434443932	20594	Economy	15600.00
0005434443933	20594	Economy	15600.00
0005434443934	20594	Economy	14100.00
0005434443926	20594	Economy	14100.00
0005434443928	20594	Economy	14100.00
0005434443929	20594	Economy	14100.00
0005434443924	20594	Economy	14100.00
0005434443935	20594	Economy	14100.00
0005434443921	20594	Economy	14100.00
0005434443922	20594	Economy	14100.00
0005434443923	20594	Economy	14100.00
0005434443925	20594	Economy	14100.00
0005434443930	20594	Economy	14100.00
0005434443920	20594	Economy	14100.00
0005434443927	20594	Economy	14100.00
0005435377598	7249	Economy	5800.00
0005435377585	7249	Economy	5800.00
0005435377590	7249	Economy	5800.00
0005434954665	7249	Economy	5800.00
0005434954666	7249	Economy	5800.00
0005435377586	7249	Economy	5800.00
0005434954664	7249	Economy	5800.00
0005434954667	7249	Economy	5800.00
0005434954663	7249	Economy	5800.00
0005435377615	28354	Economy	5800.00
0005435377613	28354	Economy	5800.00
0005434954623	28354	Economy	5800.00
0005435377612	28354	Economy	5800.00
0005434954622	28354	Economy	5800.00
0005435377614	28354	Economy	5800.00
0005434183595	4468	Economy	15400.00
0005434351874	4468	Economy	15400.00
0005434183579	4468	Economy	14000.00
0005434351871	4468	Economy	14000.00
0005434183594	4468	Economy	14000.00
0005434351870	4468	Economy	14000.00
0005434351876	4468	Economy	14000.00
0005435893681	4468	Economy	14000.00
0005434183584	4468	Economy	14000.00
0005435893699	4468	Economy	14000.00
0005434351878	4468	Economy	14000.00
0005435893656	4468	Economy	14000.00
0005435893664	4468	Economy	14000.00
0005434351882	4468	Economy	14000.00
0005435893698	4468	Economy	14000.00
0005435893657	4468	Economy	14000.00
0005434351875	4468	Economy	14000.00
0005434183585	4468	Economy	14000.00
0005435893669	4468	Economy	14000.00
0005435893663	4468	Economy	14000.00
0005434351883	4468	Economy	14000.00
0005434351879	4468	Economy	14000.00
0005434351873	4468	Economy	14000.00
0005434351877	4468	Economy	14000.00
0005434351872	4468	Economy	14000.00
0005435893694	4468	Economy	14000.00
0005435893670	4468	Economy	14000.00
0005434351881	4468	Economy	14000.00
0005434351880	4468	Economy	14000.00
0005434351705	29636	Economy	15400.00
0005434351716	29636	Economy	14000.00
0005435893732	29636	Economy	14000.00
0005435893734	29636	Economy	14000.00
0005434351744	29636	Economy	14000.00
0005434351767	29636	Economy	14000.00
0005434351704	29636	Economy	14000.00
0005434351717	29636	Economy	14000.00
0005435893729	29636	Economy	14000.00
0005434351755	29636	Economy	14000.00
0005434351754	29636	Economy	14000.00
0005434351739	29636	Economy	14000.00
0005435893735	29636	Economy	14000.00
0005434351768	29636	Economy	14000.00
0005435893733	29636	Economy	14000.00
0005434351738	29636	Economy	14000.00
0005434351748	29636	Economy	14000.00
0005435893731	29636	Economy	14000.00
0005435893730	29636	Economy	14000.00
0005434351751	29636	Economy	14000.00
0005434351745	29636	Economy	14000.00
0005433343937	1098	Business	30600.00
0005433343404	1098	Business	30600.00
0005433343916	1098	Business	30600.00
0005435092216	1098	Business	30600.00
0005433343907	1098	Business	30600.00
0005433343424	1098	Business	30600.00
0005433343613	1098	Business	30600.00
0005433343534	1098	Business	30600.00
0005433343801	1098	Business	30600.00
0005433343626	1098	Business	30600.00
0005433343592	1098	Business	30600.00
0005433343625	1098	Business	30600.00
0005433158151	1098	Business	30600.00
0005433342955	1098	Business	30600.00
0005434446552	1098	Business	30600.00
0005433343517	1098	Business	30600.00
0005433343293	1098	Economy	11200.00
0005435092218	1098	Economy	11200.00
0005433344028	1098	Economy	10200.00
0005433343556	1098	Economy	10200.00
0005433343638	1098	Economy	10200.00
0005433343528	1098	Economy	10200.00
0005432293243	1098	Economy	10200.00
0005433343515	1098	Economy	10200.00
0005433343449	1098	Economy	10200.00
0005433342838	1098	Economy	10200.00
0005433343200	1098	Economy	10200.00
0005433462778	1098	Economy	10200.00
0005433343612	1098	Economy	10200.00
0005433343118	1098	Economy	10200.00
0005433343719	1098	Economy	10200.00
0005433343872	1098	Economy	10200.00
0005433343501	1098	Economy	10200.00
0005433343367	1098	Economy	10200.00
0005433343214	1098	Economy	10200.00
0005433344002	1098	Economy	10200.00
0005433343507	1098	Economy	10200.00
0005433343684	1098	Economy	10200.00
0005433158142	1098	Economy	10200.00
0005433343294	1098	Economy	10200.00
0005433343800	1098	Economy	10200.00
0005433343198	1098	Economy	10200.00
0005433343442	1098	Economy	10200.00
0005435545847	1098	Economy	10200.00
0005433343082	1098	Economy	10200.00
0005433343695	1098	Economy	10200.00
0005433343502	1098	Economy	10200.00
0005433343423	1098	Economy	10200.00
0005433343440	1098	Economy	10200.00
0005433343448	1098	Economy	10200.00
0005433343366	1098	Economy	10200.00
0005433343743	1098	Economy	10200.00
0005433344003	1098	Economy	10200.00
0005433343768	1098	Economy	10200.00
0005433343330	1098	Economy	10200.00
0005435092213	1098	Economy	10200.00
0005433343653	1098	Economy	10200.00
0005433343545	1098	Economy	10200.00
0005433343443	1098	Economy	10200.00
0005433343234	1098	Economy	10200.00
0005433343792	1098	Economy	10200.00
0005433343694	1098	Economy	10200.00
0005434446553	1098	Economy	10200.00
0005433343530	1098	Economy	10200.00
0005433343329	1098	Economy	10200.00
0005433343425	1098	Economy	10200.00
0005433343858	1098	Economy	10200.00
0005433343236	1098	Economy	10200.00
0005433343902	1098	Economy	10200.00
0005433343588	1098	Economy	10200.00
0005434446551	1098	Economy	10200.00
0005433343471	1098	Economy	10200.00
0005433343927	1098	Economy	10200.00
0005433343906	1098	Economy	10200.00
0005433343679	1098	Economy	10200.00
0005433343479	1098	Economy	10200.00
0005433343589	1098	Economy	10200.00
0005433343771	1098	Economy	10200.00
0005433342839	1098	Economy	10200.00
0005433343546	1098	Economy	10200.00
0005435545848	1098	Economy	10200.00
0005433343734	1098	Economy	10200.00
0005433462777	1098	Economy	10200.00
0005433343910	1098	Economy	10200.00
0005435092212	1098	Economy	10200.00
0005433343178	1098	Economy	10200.00
0005433343456	1098	Economy	10200.00
0005433343851	1098	Economy	10200.00
0005433343774	1098	Economy	10200.00
0005433158143	1098	Economy	11200.00
0005433269733	1098	Economy	10200.00
0005433343199	1098	Economy	10200.00
0005433343706	1098	Economy	10200.00
0005433343179	1098	Economy	10200.00
0005433343837	1098	Economy	11200.00
0005433463932	1098	Economy	10200.00
0005433343441	1098	Economy	10200.00
0005435545849	1098	Economy	10200.00
0005433159319	1098	Economy	10200.00
0005433343218	1098	Economy	10200.00
0005435092215	1098	Economy	10200.00
0005433343936	1098	Economy	10200.00
0005433343675	1098	Economy	10200.00
0005433343714	1098	Economy	10200.00
0005433344178	1098	Economy	10200.00
0005435092220	1098	Economy	10200.00
0005433343713	1098	Economy	10200.00
0005433343908	1098	Economy	10200.00
0005433343789	1098	Economy	10200.00
0005433343769	1098	Economy	10200.00
0005433343767	1098	Economy	10200.00
0005433343518	1098	Economy	10200.00
0005433269739	1098	Economy	10200.00
0005433343235	1098	Economy	10200.00
0005433463931	1098	Economy	10200.00
0005433343820	1098	Economy	10200.00
0005433343838	1098	Economy	10200.00
0005433342840	1098	Economy	10200.00
0005433269737	1098	Economy	10200.00
0005435092214	1098	Economy	10200.00
0005433343909	1098	Economy	10200.00
0005433343192	1098	Economy	10200.00
0005433343815	1098	Economy	10200.00
0005433343654	1098	Economy	10200.00
0005433343928	1098	Economy	10200.00
0005433344004	1098	Economy	10200.00
0005433462776	1098	Economy	10200.00
0005433343772	1098	Economy	10200.00
0005435092219	1098	Economy	10200.00
0005433343699	1098	Economy	10200.00
0005433343565	1098	Economy	10200.00
0005433343640	1098	Economy	10200.00
0005433343455	1098	Economy	10200.00
0005433463930	1098	Economy	10200.00
0005433343593	1098	Economy	10200.00
0005433343083	1098	Economy	10200.00
0005433343799	1098	Economy	10200.00
0005434445274	1098	Economy	10200.00
0005433343324	1098	Economy	10200.00
0005433343350	1098	Economy	10200.00
0005435092217	1098	Economy	10200.00
0005433269751	1098	Economy	10200.00
0005435092211	1098	Economy	10200.00
0005433343898	1098	Economy	10200.00
0005433344518	17065	Business	30600.00
0005433344485	17065	Business	30600.00
0005433344460	17065	Business	30600.00
0005433344461	17065	Business	30600.00
0005433269793	17065	Business	30600.00
0005433344532	17065	Business	30600.00
0005433344466	17065	Business	30600.00
0005433344525	17065	Business	30600.00
0005433344524	17065	Business	30600.00
0005433344531	17065	Business	30600.00
0005433344440	17065	Business	30600.00
0005433344435	17065	Business	30600.00
0005435508404	17065	Business	30600.00
0005433462735	17065	Business	30600.00
0005433344444	17065	Business	30600.00
0005433344441	17065	Business	30600.00
0005433344527	17065	Business	30600.00
0005433460444	17065	Business	30600.00
0005433344533	17065	Business	30600.00
0005433344503	17065	Business	30600.00
0005433344501	17065	Business	30600.00
0005433344497	17065	Business	30600.00
0005435508408	17065	Business	30600.00
0005433344486	17065	Economy	11200.00
0005433462734	17065	Economy	11200.00
0005434445253	17065	Economy	11200.00
0005433344493	17065	Economy	10200.00
0005433344453	17065	Economy	10200.00
0005433460430	17065	Economy	10200.00
0005433460437	17065	Economy	10200.00
0005435508415	17065	Economy	10200.00
0005435092144	17065	Economy	10200.00
0005433344492	17065	Economy	10200.00
0005433462744	17065	Economy	10200.00
0005433344499	17065	Economy	10200.00
0005433460442	17065	Economy	10200.00
0005433344519	17065	Economy	10200.00
0005433460413	17065	Economy	10200.00
0005433269796	17065	Economy	10200.00
0005433344523	17065	Economy	10200.00
0005433344437	17065	Economy	10200.00
0005433344488	17065	Economy	10200.00
0005433344476	17065	Economy	10200.00
0005433460440	17065	Economy	10200.00
0005433344451	17065	Economy	10200.00
0005433460427	17065	Economy	10200.00
0005433344498	17065	Economy	10200.00
0005435092169	17065	Economy	10200.00
0005433344511	17065	Economy	10200.00
0005433344442	17065	Economy	10200.00
0005433344502	17065	Economy	10200.00
0005433344468	17065	Economy	10200.00
0005433344473	17065	Economy	10200.00
0005435508399	17065	Economy	10200.00
0005435508397	17065	Economy	10200.00
0005435092129	17065	Economy	10200.00
0005433344455	17065	Economy	10200.00
0005435092077	17065	Economy	10200.00
0005433344509	17065	Economy	10200.00
0005435508402	17065	Economy	10200.00
0005433344454	17065	Economy	10200.00
0005433460432	17065	Economy	10200.00
0005435508407	17065	Economy	10200.00
0005433344512	17065	Economy	10200.00
0005433344487	17065	Economy	10200.00
0005433344484	17065	Economy	10200.00
0005433344526	17065	Economy	10200.00
0005433344478	17065	Economy	10200.00
0005433344450	17065	Economy	10200.00
0005433344447	17065	Economy	10200.00
0005433344491	17065	Economy	10200.00
0005433269795	17065	Economy	10200.00
0005433344449	17065	Economy	10200.00
0005433344443	17065	Economy	10200.00
0005433460441	17065	Economy	10200.00
0005434445255	17065	Economy	10200.00
0005433344520	17065	Economy	10200.00
0005435092132	17065	Economy	10200.00
0005433344471	17065	Economy	10200.00
0005433344495	17065	Economy	10200.00
0005433344530	17065	Economy	10200.00
0005433344504	17065	Economy	10200.00
0005433462749	17065	Economy	10200.00
0005433462726	17065	Economy	10200.00
0005433344505	17065	Economy	10200.00
0005433462742	17065	Economy	10200.00
0005433344452	17065	Economy	10200.00
0005433344510	17065	Economy	10200.00
0005433344480	17065	Economy	10200.00
0005433159345	17065	Economy	10200.00
0005433344472	17065	Economy	10200.00
0005433462751	17065	Economy	10200.00
0005434445252	17065	Economy	10200.00
0005433344483	17065	Economy	10200.00
0005435508422	17065	Economy	10200.00
0005433344436	17065	Economy	10200.00
0005433344474	17065	Economy	10200.00
0005435508416	17065	Economy	10200.00
0005433344516	17065	Economy	10200.00
0005435508405	17065	Economy	10200.00
0005435508396	17065	Economy	10200.00
0005433159346	17065	Economy	11200.00
0005433344528	17065	Economy	10200.00
0005433344445	17065	Economy	11200.00
0005433269797	17065	Economy	10200.00
0005433344477	17065	Economy	11200.00
0005435508441	17065	Economy	10200.00
0005433344470	17065	Economy	10200.00
0005433344500	17065	Economy	10200.00
0005433344508	17065	Economy	10200.00
0005433460429	17065	Economy	10200.00
0005435092128	17065	Economy	10200.00
0005433269794	17065	Economy	10200.00
0005433344522	17065	Economy	10200.00
0005433344517	17065	Economy	10200.00
0005433344482	17065	Economy	10200.00
0005433344490	17065	Economy	10200.00
0005433344457	17065	Economy	10200.00
0005433344481	17065	Economy	10200.00
0005433344439	17065	Economy	10200.00
0005433462748	17065	Economy	10200.00
0005435508403	17065	Economy	10200.00
0005433344438	17065	Economy	10200.00
0005433344456	17065	Economy	10200.00
0005433460439	17065	Economy	10200.00
0005433344467	17065	Economy	10200.00
0005433344479	17065	Economy	10200.00
0005433344506	17065	Economy	10200.00
0005433344529	17065	Economy	10200.00
0005433344496	17065	Economy	10200.00
0005433344507	17065	Economy	10200.00
0005433344459	17065	Economy	10200.00
0005433344463	17065	Economy	10200.00
0005435092115	17065	Economy	10200.00
0005433344475	17065	Economy	10200.00
0005433344462	17065	Economy	10200.00
0005434445254	17065	Economy	10200.00
0005433344515	17065	Economy	10200.00
0005433462743	17065	Economy	10200.00
0005433344458	17065	Economy	10200.00
0005433460431	17065	Economy	10200.00
0005433460414	17065	Economy	10200.00
0005433460438	17065	Economy	10200.00
0005433462747	17065	Economy	10200.00
0005435508373	17065	Economy	10200.00
0005433344464	17065	Economy	10200.00
0005433344433	17065	Economy	10200.00
0005433344434	17065	Economy	10200.00
0005433344448	17065	Economy	10200.00
0005433344514	17065	Economy	10200.00
0005433460419	17065	Economy	10200.00
0005433344469	17065	Economy	10200.00
0005433462750	17065	Economy	10200.00
0005433344494	17065	Economy	10200.00
0005433460443	17065	Economy	10200.00
0005433344489	17065	Economy	10200.00
0005433460428	17065	Economy	10200.00
0005433344521	17065	Economy	10200.00
0005433344446	17065	Economy	10200.00
0005433159344	17065	Economy	10200.00
0005433460426	17065	Economy	10200.00
0005433344465	17065	Economy	10200.00
0005433344513	17065	Economy	10200.00
0005435508421	17065	Economy	10200.00
0005435508423	17065	Economy	10200.00
0005433462727	17065	Economy	10200.00
0005432852000	18267	Business	101000.00
0005432392025	18267	Business	101000.00
0005432852010	18267	Business	101000.00
0005432390176	18267	Business	101000.00
0005432390185	18267	Business	101000.00
0005432852002	18267	Business	101000.00
0005432851993	18267	Business	101000.00
0005432392004	18267	Business	101000.00
0005432390163	18267	Business	101000.00
0005432390213	18267	Business	101000.00
0005432851995	18267	Business	101000.00
0005432390191	18267	Economy	33700.00
0005432392009	18267	Economy	33700.00
0005432852001	18267	Economy	33700.00
0005432852006	18267	Economy	33700.00
0005432390209	18267	Economy	33700.00
0005432390173	18267	Economy	33700.00
0005432390177	18267	Economy	33700.00
0005432392018	18267	Economy	33700.00
0005432851996	18267	Economy	37000.00
0005432390180	18267	Economy	33700.00
0005432390138	18267	Economy	33700.00
0005432392013	18267	Economy	33700.00
0005432391994	18267	Economy	33700.00
0005432391993	18267	Economy	33700.00
0005432851997	18267	Economy	33700.00
0005432390201	18267	Economy	33700.00
0005432851998	18267	Economy	33700.00
0005432391997	18267	Economy	33700.00
0005432852009	18267	Economy	33700.00
0005432390190	18267	Economy	33700.00
0005432852012	18267	Economy	33700.00
0005432390150	18267	Economy	33700.00
0005432390166	18267	Economy	33700.00
0005432852011	18267	Economy	33700.00
0005432851999	18267	Economy	33700.00
0005432390155	18267	Economy	33700.00
0005432391988	18267	Economy	33700.00
0005432390199	18267	Economy	33700.00
0005432390193	18267	Economy	33700.00
0005432852007	18267	Economy	33700.00
0005432390189	18267	Economy	33700.00
0005432392001	18267	Economy	33700.00
0005432852013	18267	Economy	33700.00
0005432390172	18267	Economy	33700.00
0005432390170	18267	Economy	33700.00
0005432391986	18267	Economy	33700.00
0005432851994	18267	Economy	33700.00
0005432390137	18267	Economy	33700.00
0005432392003	18267	Economy	33700.00
0005432852003	18267	Economy	33700.00
0005432390165	18267	Economy	33700.00
0005432392002	18267	Economy	33700.00
0005432390192	18267	Economy	33700.00
0005432390139	18267	Economy	33700.00
0005432852004	18267	Economy	33700.00
0005432390200	18267	Economy	33700.00
0005432390207	18267	Economy	33700.00
0005432390154	18267	Economy	33700.00
0005432852005	18267	Economy	33700.00
0005432392012	18267	Economy	33700.00
0005432852008	18267	Economy	33700.00
0005432390208	18267	Economy	33700.00
0005434067994	12773	Business	40300.00
0005434067816	12773	Business	40300.00
0005432161185	12773	Business	40300.00
0005434068131	12773	Business	40300.00
0005433812934	12773	Business	40300.00
0005434067864	12773	Business	40300.00
0005434067639	12773	Business	40300.00
0005434067947	12773	Business	40300.00
0005434068077	12773	Business	40300.00
0005434068108	12773	Business	40300.00
0005432159922	12773	Business	40300.00
0005434067965	12773	Business	40300.00
0005432159923	12773	Economy	13400.00
0005434067939	12773	Economy	13400.00
0005434081920	12773	Economy	13400.00
0005434067665	12773	Economy	13400.00
0005434067866	12773	Economy	13400.00
0005434068049	12773	Economy	13400.00
0005434067793	12773	Economy	13400.00
0005434067682	12773	Economy	13400.00
0005434067927	12773	Economy	13400.00
0005434067914	12773	Economy	13400.00
0005434068228	12773	Economy	13400.00
0005434068042	12773	Economy	13400.00
0005434068130	12773	Economy	13400.00
0005432433758	12773	Economy	13400.00
0005432159921	12773	Economy	13400.00
0005433989790	12773	Economy	13400.00
0005432159924	12773	Economy	13400.00
0005434067858	12773	Economy	13400.00
0005434067672	12773	Economy	13400.00
0005434067932	12773	Economy	13400.00
0005434081969	12773	Economy	13400.00
0005434026702	12773	Economy	13400.00
0005434067880	12773	Economy	13400.00
0005434082006	12773	Economy	13400.00
0005434081981	12773	Economy	13400.00
0005434067868	12773	Economy	13400.00
0005434068018	12773	Economy	13400.00
0005433812935	12773	Economy	13400.00
0005434081946	12773	Economy	13400.00
0005434067966	12773	Economy	13400.00
0005434081968	12773	Economy	13400.00
0005434081945	12773	Economy	13400.00
0005434068166	12773	Economy	13400.00
0005434067919	12773	Economy	13400.00
0005434067782	12773	Economy	13400.00
0005434067685	12773	Economy	13400.00
0005434067951	12773	Economy	13400.00
0005434067875	12773	Economy	13400.00
0005434067843	12773	Economy	13400.00
0005432433756	12773	Economy	13400.00
0005432159926	12773	Economy	14800.00
0005434067759	12773	Economy	14800.00
0005434081985	12773	Economy	14800.00
0005434067929	12773	Economy	14800.00
0005432433754	12773	Economy	14800.00
0005434068019	12773	Economy	13400.00
0005434067863	12773	Economy	13400.00
0005434067620	12773	Economy	13400.00
0005434067915	12773	Economy	13400.00
0005434081942	12773	Economy	13400.00
0005434067839	12773	Economy	13400.00
0005434067654	12773	Economy	13400.00
0005434068076	12773	Economy	13400.00
0005434067460	12773	Economy	13400.00
0005434067837	12773	Economy	13400.00
0005432433753	12773	Economy	13400.00
0005434067879	12773	Economy	13400.00
0005434068208	12773	Economy	13400.00
0005434067995	12773	Economy	13400.00
0005434067940	12773	Economy	13400.00
0005434067817	12773	Economy	13400.00
0005434067618	12773	Economy	13400.00
0005434081989	12773	Economy	13400.00
0005434067853	12773	Economy	13400.00
0005434068160	12773	Economy	13400.00
0005434067979	12773	Economy	13400.00
0005432161184	12773	Economy	13400.00
0005433989797	12773	Economy	13400.00
0005434068227	12773	Economy	13400.00
0005434067916	12773	Economy	13400.00
0005434081864	12773	Economy	13400.00
0005434082005	12773	Economy	13400.00
0005432433757	12773	Economy	13400.00
0005434068245	12773	Economy	13400.00
0005434067730	12773	Economy	13400.00
0005434081990	12773	Economy	13400.00
0005434068008	12773	Economy	13400.00
0005432433755	12773	Economy	13400.00
0005432433759	12773	Economy	13400.00
0005434068100	12773	Economy	13400.00
0005434067707	12773	Economy	13400.00
0005434068013	12773	Economy	13400.00
0005434068009	12773	Economy	13400.00
0005434081973	12773	Economy	13400.00
0005434067981	12773	Economy	13400.00
0005434067669	12773	Economy	13400.00
0005434067982	12773	Economy	13400.00
0005434081987	12773	Economy	13400.00
0005434081991	12773	Economy	13400.00
0005434067838	12773	Economy	13400.00
0005434081970	12773	Economy	13400.00
0005434068232	12773	Economy	13400.00
0005434026701	12773	Economy	13400.00
0005434067917	12773	Economy	13400.00
0005434068355	12773	Economy	13400.00
0005434067471	12773	Economy	13400.00
0005434081932	12773	Economy	13400.00
0005434067918	12773	Economy	13400.00
0005434081949	12773	Economy	13400.00
0005434082007	12773	Economy	13400.00
0005434068060	12773	Economy	13400.00
0005434067653	12773	Economy	13400.00
0005434067931	12773	Economy	13400.00
0005434067621	12773	Economy	13400.00
0005434067798	12773	Economy	13400.00
0005434067977	12773	Economy	13400.00
0005434068231	12773	Economy	13400.00
0005434067852	12773	Economy	13400.00
0005434081986	12773	Economy	13400.00
0005434067881	12773	Economy	13400.00
0005432159925	12773	Economy	13400.00
0005433989789	12773	Economy	13400.00
0005434067849	12773	Economy	13400.00
0005434067619	12773	Economy	13400.00
0005434067755	12773	Economy	13400.00
0005434068226	12773	Economy	13400.00
0005434068476	30648	Business	40300.00
0005434068528	30648	Business	40300.00
0005434068534	30648	Business	40300.00
0005434068474	30648	Business	40300.00
0005434068512	30648	Business	40300.00
0005434068500	30648	Business	40300.00
0005434068511	30648	Business	40300.00
0005434068541	30648	Business	40300.00
0005434068489	30648	Business	40300.00
0005434068518	30648	Business	40300.00
0005434068499	30648	Economy	13400.00
0005434082205	30648	Economy	13400.00
0005434068479	30648	Economy	13400.00
0005434068492	30648	Economy	13400.00
0005434068478	30648	Economy	13400.00
0005433989834	30648	Economy	13400.00
0005433989835	30648	Economy	13400.00
0005434082218	30648	Economy	13400.00
0005434068503	30648	Economy	13400.00
0005434068521	30648	Economy	13400.00
0005434068484	30648	Economy	13400.00
0005434068509	30648	Economy	13400.00
0005434068496	30648	Economy	13400.00
0005432150302	30648	Economy	13400.00
0005434068525	30648	Economy	13400.00
0005434068526	30648	Economy	13400.00
0005434068481	30648	Economy	13400.00
0005434068539	30648	Economy	13400.00
0005434068545	30648	Economy	13400.00
0005434068516	30648	Economy	13400.00
0005434082207	30648	Economy	13400.00
0005434068514	30648	Economy	13400.00
0005434068536	30648	Economy	13400.00
0005434082212	30648	Economy	13400.00
0005434068477	30648	Economy	13400.00
0005434068520	30648	Economy	13400.00
0005434082219	30648	Economy	13400.00
0005434068544	30648	Economy	13400.00
0005434068480	30648	Economy	13400.00
0005432150296	30648	Economy	13400.00
0005434068475	30648	Economy	13400.00
0005434068533	30648	Economy	13400.00
0005434068543	30648	Economy	13400.00
0005432186918	30648	Economy	13400.00
0005434068501	30648	Economy	13400.00
0005434082198	30648	Economy	13400.00
0005434082200	30648	Economy	14800.00
0005434082202	30648	Economy	14800.00
0005434068523	30648	Economy	14800.00
0005434068532	30648	Economy	14800.00
0005434082201	30648	Economy	14800.00
0005434082203	30648	Economy	13400.00
0005434082208	30648	Economy	13400.00
0005434068538	30648	Economy	13400.00
0005434068497	30648	Economy	13400.00
0005434068508	30648	Economy	13400.00
0005432150301	30648	Economy	13400.00
0005434068498	30648	Economy	13400.00
0005434068546	30648	Economy	13400.00
0005434068529	30648	Economy	13400.00
0005434068537	30648	Economy	13400.00
0005434068530	30648	Economy	13400.00
0005434068486	30648	Economy	13400.00
0005434068510	30648	Economy	13400.00
0005434082215	30648	Economy	13400.00
0005434082214	30648	Economy	13400.00
0005434082199	30648	Economy	13400.00
0005434068527	30648	Economy	13400.00
0005434082216	30648	Economy	13400.00
0005434068488	30648	Economy	13400.00
0005432150303	30648	Economy	13400.00
0005434068487	30648	Economy	13400.00
0005435283408	30648	Economy	13400.00
0005434082204	30648	Economy	13400.00
0005434082206	30648	Economy	13400.00
0005434082211	30648	Economy	13400.00
0005432186919	30648	Economy	13400.00
0005434068524	30648	Economy	13400.00
0005434068504	30648	Economy	13400.00
0005432150298	30648	Economy	13400.00
0005434068483	30648	Economy	13400.00
0005434068485	30648	Economy	13400.00
0005434068522	30648	Economy	13400.00
0005434068491	30648	Economy	13400.00
0005434082210	30648	Economy	13400.00
0005432150297	30648	Economy	13400.00
0005434068502	30648	Economy	13400.00
0005434068531	30648	Economy	13400.00
0005434068494	30648	Economy	13400.00
0005434068473	30648	Economy	13400.00
0005432433721	30648	Economy	13400.00
0005434082217	30648	Economy	13400.00
0005434068506	30648	Economy	13400.00
0005434068505	30648	Economy	13400.00
0005434082209	30648	Economy	13400.00
0005434068542	30648	Economy	13400.00
0005433989837	30648	Economy	13400.00
0005434068515	30648	Economy	13400.00
0005434068535	30648	Economy	13400.00
0005434068519	30648	Economy	13400.00
0005432150300	30648	Economy	13400.00
0005434068513	30648	Economy	13400.00
0005434068493	30648	Economy	13400.00
0005434082197	30648	Economy	13400.00
0005434068507	30648	Economy	13400.00
0005434068517	30648	Economy	13400.00
0005434068490	30648	Economy	13400.00
0005434082213	30648	Economy	13400.00
0005434068482	30648	Economy	13400.00
0005433989836	30648	Economy	13400.00
0005432186917	30648	Economy	13400.00
0005434068540	30648	Economy	13400.00
0005432150299	30648	Economy	13400.00
0005434068495	30648	Economy	13400.00
0005433687736	9035	Economy	19300.00
0005433685556	9035	Economy	19300.00
0005433687740	9035	Economy	19300.00
0005433685553	9035	Economy	17600.00
0005433687738	9035	Economy	17600.00
0005433685557	9035	Economy	17600.00
0005433686663	9035	Economy	17600.00
0005433686669	9035	Economy	17600.00
0005433687737	9035	Economy	17600.00
0005433687735	9035	Economy	17600.00
0005433686668	9035	Economy	17600.00
0005433685559	9035	Economy	17600.00
0005433686665	9035	Economy	17600.00
0005433685554	9035	Economy	17600.00
0005433685552	9035	Economy	17600.00
0005433687739	9035	Economy	17600.00
0005433686664	9035	Economy	17600.00
0005433685555	9035	Economy	17600.00
0005433686666	9035	Economy	17600.00
0005433686670	9035	Economy	17600.00
0005433686667	9035	Economy	17600.00
0005433687741	9035	Economy	17600.00
0005433687734	9035	Economy	17600.00
0005433685558	9035	Economy	17600.00
0005432140566	5512	Business	35300.00
0005435767047	5512	Business	35300.00
0005435462523	5512	Business	35300.00
0005434265319	5512	Business	35300.00
0005435767035	5512	Business	35300.00
0005434265203	5512	Business	35300.00
0005434265378	5512	Business	35300.00
0005435767078	5512	Business	35300.00
0005435735200	5512	Business	35300.00
0005435767062	5512	Business	35300.00
0005435735199	5512	Business	35300.00
0005435767055	5512	Business	35300.00
0005435462729	5512	Business	35300.00
0005435767075	5512	Business	35300.00
0005435767048	5512	Business	35300.00
0005435462592	5512	Business	35300.00
0005432140568	5512	Economy	12900.00
0005432140567	5512	Economy	12900.00
0005435767058	5512	Economy	12900.00
0005435462730	5512	Economy	11800.00
0005435462563	5512	Economy	11800.00
0005432535846	5512	Economy	11800.00
0005434265145	5512	Economy	11800.00
0005435767046	5512	Economy	11800.00
0005435767044	5512	Economy	11800.00
0005432140565	5512	Economy	11800.00
0005435735198	5512	Economy	11800.00
0005435725665	5512	Economy	11800.00
0005435767071	5512	Economy	11800.00
0005435462666	5512	Economy	11800.00
0005435767041	5512	Economy	11800.00
0005435462735	5512	Economy	11800.00
0005433529334	5512	Economy	11800.00
0005435722090	5512	Economy	11800.00
0005434265270	5512	Economy	11800.00
0005435462607	5512	Economy	11800.00
0005435767068	5512	Economy	11800.00
0005435767076	5512	Economy	11800.00
0005435720841	5512	Economy	11800.00
0005435767045	5512	Economy	11800.00
0005435767042	5512	Economy	11800.00
0005434831191	5512	Economy	11800.00
0005435767059	5512	Economy	11800.00
0005435462770	5512	Economy	11800.00
0005435462626	5512	Economy	11800.00
0005435767056	5512	Economy	11800.00
0005435767070	5512	Economy	11800.00
0005435462504	5512	Economy	11800.00
0005435462736	5512	Economy	11800.00
0005435767049	5512	Economy	11800.00
0005434265250	5512	Economy	11800.00
0005435767053	5512	Economy	11800.00
0005435767074	5512	Economy	11800.00
0005434831178	5512	Economy	11800.00
0005435462665	5512	Economy	11800.00
0005435767080	5512	Economy	11800.00
0005435767039	5512	Economy	11800.00
0005434265258	5512	Economy	11800.00
0005435462656	5512	Economy	11800.00
0005434831175	5512	Economy	11800.00
0005435725666	5512	Economy	11800.00
0005434831176	5512	Economy	11800.00
0005435725668	5512	Economy	11800.00
0005432535864	5512	Economy	11800.00
0005435767067	5512	Economy	11800.00
0005435767037	5512	Economy	11800.00
0005435462554	5512	Economy	11800.00
0005435767081	5512	Economy	11800.00
0005435767087	5512	Economy	11800.00
0005434265309	5512	Economy	11800.00
0005435462497	5512	Economy	11800.00
0005435767033	5512	Economy	11800.00
0005435767089	5512	Economy	11800.00
0005435767060	5512	Economy	11800.00
0005435767083	5512	Economy	11800.00
0005435767051	5512	Economy	11800.00
0005435767054	5512	Economy	11800.00
0005435767072	5512	Economy	11800.00
0005435462503	5512	Economy	11800.00
0005433529332	5512	Economy	11800.00
0005435725669	5512	Economy	11800.00
0005432140563	5512	Economy	11800.00
0005435462657	5512	Economy	11800.00
0005433527323	5512	Economy	12900.00
0005432140561	5512	Economy	11800.00
0005435767069	5512	Economy	11800.00
0005433529335	5512	Economy	11800.00
0005435767086	5512	Economy	12900.00
0005434831170	5512	Economy	12900.00
0005435767038	5512	Economy	11800.00
0005435462634	5512	Economy	11800.00
0005435462468	5512	Economy	11800.00
0005435462706	5512	Economy	11800.00
0005435462715	5512	Economy	11800.00
0005435767052	5512	Economy	11800.00
0005435462771	5512	Economy	11800.00
0005435767092	5512	Economy	11800.00
0005435767085	5512	Economy	11800.00
0005435767057	5512	Economy	11800.00
0005435767077	5512	Economy	11800.00
0005435767090	5512	Economy	11800.00
0005435767084	5512	Economy	11800.00
0005435735201	5512	Economy	11800.00
0005435767050	5512	Economy	11800.00
0005435767091	5512	Economy	11800.00
0005435767065	5512	Economy	11800.00
0005435767040	5512	Economy	11800.00
0005435767063	5512	Economy	11800.00
0005435722089	5512	Economy	11800.00
0005435767034	5512	Economy	11800.00
0005432140562	5512	Economy	11800.00
0005435462593	5512	Economy	11800.00
0005435767061	5512	Economy	11800.00
0005434265249	5512	Economy	11800.00
0005435735202	5512	Economy	11800.00
0005434265330	5512	Economy	11800.00
0005435462795	5512	Economy	11800.00
0005435462692	5512	Economy	11800.00
0005435767036	5512	Economy	11800.00
0005432140564	5512	Economy	11800.00
0005435462524	5512	Economy	11800.00
0005435462498	5512	Economy	11800.00
0005435767079	5512	Economy	11800.00
0005433527322	5512	Economy	11800.00
0005435767088	5512	Economy	11800.00
0005435767066	5512	Economy	11800.00
0005432140560	5512	Economy	11800.00
0005435462509	5512	Economy	11800.00
0005433529333	5512	Economy	11800.00
0005435767073	5512	Economy	11800.00
0005435767082	5512	Economy	11800.00
0005435725667	5512	Economy	11800.00
0005435767064	5512	Economy	11800.00
0005433527321	5512	Economy	11800.00
0005435723074	5512	Economy	11800.00
0005435462525	5512	Economy	11800.00
0005432535863	5512	Economy	11800.00
0005435462591	5512	Economy	11800.00
0005433527320	5512	Economy	11800.00
0005435767043	5512	Economy	11800.00
0005435462595	5512	Economy	11800.00
0005435462986	13446	Business	35300.00
0005435766538	13446	Business	35300.00
0005435766418	13446	Business	35300.00
0005435462980	13446	Business	35300.00
0005435766580	13446	Business	35300.00
0005435462956	13446	Business	35300.00
0005435462975	13446	Business	35300.00
0005435766597	13446	Business	35300.00
0005435766309	13446	Business	35300.00
0005434831221	13446	Business	35300.00
0005434265507	13446	Business	35300.00
0005435723050	13446	Business	35300.00
0005435766593	13446	Business	35300.00
0005434265502	13446	Business	35300.00
0005435766539	13446	Business	35300.00
0005434265503	13446	Business	35300.00
0005435766537	13446	Business	35300.00
0005435720139	13446	Business	35300.00
0005435462991	13446	Business	35300.00
0005435462987	13446	Business	35300.00
0005435462978	13446	Business	35300.00
0005435735161	13446	Economy	12900.00
0005435462960	13446	Economy	12900.00
0005435766495	13446	Economy	12900.00
0005434265505	13446	Economy	11800.00
0005435766450	13446	Economy	11800.00
0005434265506	13446	Economy	11800.00
0005435462970	13446	Economy	11800.00
0005435462985	13446	Economy	11800.00
0005434265504	13446	Economy	11800.00
0005435766267	13446	Economy	11800.00
0005435462954	13446	Economy	11800.00
0005435766461	13446	Economy	11800.00
0005435766567	13446	Economy	11800.00
0005435766742	13446	Economy	11800.00
0005434265499	13446	Economy	11800.00
0005435766679	13446	Economy	11800.00
0005435462958	13446	Economy	11800.00
0005435766659	13446	Economy	11800.00
0005435462976	13446	Economy	11800.00
0005434265515	13446	Economy	11800.00
0005435766576	13446	Economy	11800.00
0005435462988	13446	Economy	11800.00
0005435766397	13446	Economy	11800.00
0005435766629	13446	Economy	11800.00
0005435766847	13446	Economy	11800.00
0005435766763	13446	Economy	11800.00
0005435766520	13446	Economy	11800.00
0005435766702	13446	Economy	11800.00
0005435766542	13446	Economy	11800.00
0005432535901	13446	Economy	11800.00
0005435462955	13446	Economy	11800.00
0005435766575	13446	Economy	11800.00
0005435462968	13446	Economy	11800.00
0005432194570	13446	Economy	11800.00
0005435462969	13446	Economy	11800.00
0005435462965	13446	Economy	11800.00
0005435766749	13446	Economy	11800.00
0005435766848	13446	Economy	11800.00
0005435462963	13446	Economy	11800.00
0005434265518	13446	Economy	11800.00
0005435766694	13446	Economy	11800.00
0005435766410	13446	Economy	11800.00
0005435766404	13446	Economy	11800.00
0005434265496	13446	Economy	11800.00
0005435720138	13446	Economy	11800.00
0005435722067	13446	Economy	11800.00
0005432194571	13446	Economy	11800.00
0005435766367	13446	Economy	11800.00
0005435766632	13446	Economy	11800.00
0005435766509	13446	Economy	11800.00
0005435462962	13446	Economy	11800.00
0005435766431	13446	Economy	11800.00
0005435720137	13446	Economy	11800.00
0005434265519	13446	Economy	11800.00
0005435462964	13446	Economy	11800.00
0005434265497	13446	Economy	11800.00
0005434265495	13446	Economy	11800.00
0005435462977	13446	Economy	11800.00
0005435462990	13446	Economy	11800.00
0005435462981	13446	Economy	11800.00
0005434265520	13446	Economy	11800.00
0005435462983	13446	Economy	11800.00
0005435766596	13446	Economy	11800.00
0005432535904	13446	Economy	11800.00
0005435462989	13446	Economy	11800.00
0005434265498	13446	Economy	11800.00
0005435462971	13446	Economy	11800.00
0005434265511	13446	Economy	11800.00
0005435766817	13446	Economy	11800.00
0005432535903	13446	Economy	11800.00
0005432535905	13446	Economy	11800.00
0005435462967	13446	Economy	11800.00
0005432194572	13446	Economy	11800.00
0005434831218	13446	Economy	11800.00
0005434265509	13446	Economy	12900.00
0005434265516	13446	Economy	11800.00
0005435766547	13446	Economy	11800.00
0005435766379	13446	Economy	11800.00
0005435462959	13446	Economy	12900.00
0005435766549	13446	Economy	11800.00
0005435766445	13446	Economy	11800.00
0005435720136	13446	Economy	11800.00
0005435462974	13446	Economy	11800.00
0005434831219	13446	Economy	11800.00
0005434265508	13446	Economy	11800.00
0005435462957	13446	Economy	11800.00
0005435766407	13446	Economy	11800.00
0005435735171	13446	Economy	11800.00
0005435735160	13446	Economy	11800.00
0005435766442	13446	Economy	11800.00
0005435462973	13446	Economy	11800.00
0005435766762	13446	Economy	11800.00
0005435766741	13446	Economy	11800.00
0005434265500	13446	Economy	11800.00
0005435766368	13446	Economy	11800.00
0005435766552	13446	Economy	11800.00
0005435766545	13446	Economy	11800.00
0005435766556	13446	Economy	11800.00
0005435766590	13446	Economy	11800.00
0005435766628	13446	Economy	11800.00
0005435766611	13446	Economy	11800.00
0005434265501	13446	Economy	11800.00
0005434265510	13446	Economy	11800.00
0005435766578	13446	Economy	11800.00
0005435766764	13446	Economy	11800.00
0005435766383	13446	Economy	11800.00
0005435462992	13446	Economy	11800.00
0005434265513	13446	Economy	11800.00
0005435766577	13446	Economy	11800.00
0005435766268	13446	Economy	11800.00
0005435766494	13446	Economy	11800.00
0005435462966	13446	Economy	11800.00
0005435766546	13446	Economy	11800.00
0005435766701	13446	Economy	11800.00
0005435462982	13446	Economy	11800.00
0005434265514	13446	Economy	11800.00
0005435462972	13446	Economy	11800.00
0005435766432	13446	Economy	11800.00
0005435766703	13446	Economy	11800.00
0005434831220	13446	Economy	11800.00
0005434265517	13446	Economy	11800.00
0005435766207	13446	Economy	11800.00
0005435766510	13446	Economy	11800.00
0005432535902	13446	Economy	11800.00
0005432194569	13446	Economy	11800.00
0005435462961	13446	Economy	11800.00
0005435462979	13446	Economy	11800.00
0005435766553	13446	Economy	11800.00
0005435735181	13446	Economy	11800.00
0005435462984	13446	Economy	11800.00
0005434265512	13446	Economy	11800.00
0005434604904	18750	Economy	3300.00
0005434513614	18750	Economy	3300.00
0005434604919	18750	Economy	3300.00
0005434515002	18750	Economy	3300.00
0005434604924	18750	Economy	3300.00
0005434604918	18750	Economy	3300.00
0005434513616	18750	Economy	3300.00
0005434515003	18750	Economy	3300.00
0005434604917	18750	Economy	3300.00
0005434604916	18750	Economy	3300.00
0005434513615	18750	Economy	3300.00
0005434604915	18750	Economy	3300.00
0005434602930	19185	Economy	3300.00
0005434602933	19185	Economy	3300.00
0005434514979	19185	Economy	3300.00
0005434602931	19185	Economy	3300.00
0005434514978	19185	Economy	3300.00
0005434602932	19185	Economy	3300.00
0005434514994	19185	Economy	3300.00
0005434602929	19185	Economy	3300.00
0005433008768	1872	Business	48700.00
0005433008869	1872	Business	48700.00
0005433285279	1872	Business	48700.00
0005432295916	1872	Business	48700.00
0005433285505	1872	Business	48700.00
0005433285558	1872	Business	48700.00
0005433009065	1872	Business	48700.00
0005433008838	1872	Business	48700.00
0005433008748	1872	Business	48700.00
0005433008900	1872	Business	48700.00
0005433009061	1872	Business	48700.00
0005433810608	1872	Economy	16200.00
0005433008749	1872	Economy	16200.00
0005433008895	1872	Economy	16200.00
0005433008901	1872	Economy	16200.00
0005433008927	1872	Economy	16200.00
0005432295917	1872	Economy	16200.00
0005433008834	1872	Economy	17900.00
0005433008853	1872	Economy	17900.00
0005433009015	1872	Economy	17900.00
0005433009016	1872	Economy	16200.00
0005433008974	1872	Economy	16200.00
0005433285441	1872	Economy	16200.00
0005433285366	1872	Economy	16200.00
0005433285492	1872	Economy	16200.00
0005433008742	1872	Economy	16200.00
0005432295919	1872	Economy	16200.00
0005433008757	1872	Economy	16200.00
0005433008893	1872	Economy	16200.00
0005433285533	1872	Economy	16200.00
0005433285564	1872	Economy	16200.00
0005433008864	1872	Economy	16200.00
0005433008946	1872	Economy	16200.00
0005433008833	1872	Economy	16200.00
0005433285494	1872	Economy	16200.00
0005433008767	1872	Economy	16200.00
0005433008835	1872	Economy	16200.00
0005433008929	1872	Economy	16200.00
0005433008955	1872	Economy	16200.00
0005433285493	1872	Economy	16200.00
0005433008948	1872	Economy	16200.00
0005433008917	1872	Economy	16200.00
0005433008859	1872	Economy	16200.00
0005433008978	1872	Economy	16200.00
0005433810609	1872	Economy	16200.00
0005433008829	1872	Economy	16200.00
0005433009070	1872	Economy	16200.00
0005433008758	1872	Economy	16200.00
0005433285278	1872	Economy	16200.00
0005433285532	1872	Economy	16200.00
0005433008972	1872	Economy	16200.00
0005433285673	1872	Economy	16200.00
0005433285382	1872	Economy	16200.00
0005433008826	1872	Economy	16200.00
0005433008947	1872	Economy	16200.00
0005433009006	1872	Economy	16200.00
0005433008952	1872	Economy	16200.00
0005433008892	1872	Economy	16200.00
0005433008870	1872	Economy	16200.00
0005433008728	1872	Economy	16200.00
0005433008861	1872	Economy	16200.00
0005433008898	1872	Economy	16200.00
0005433008973	1872	Economy	16200.00
0005433008924	1872	Economy	16200.00
0005433285515	1872	Economy	16200.00
0005433008770	1872	Economy	16200.00
0005433285440	1872	Economy	16200.00
0005433008911	1872	Economy	16200.00
0005433285563	1872	Economy	16200.00
0005433285443	1872	Economy	16200.00
0005433810606	1872	Economy	16200.00
0005433009066	1872	Economy	16200.00
0005433008863	1872	Economy	16200.00
0005432295920	1872	Economy	16200.00
0005433008965	1872	Economy	16200.00
0005433285442	1872	Economy	16200.00
0005433008941	1872	Economy	16200.00
0005433008957	1872	Economy	16200.00
0005432295918	1872	Economy	16200.00
0005433810607	1872	Economy	16200.00
0005433285526	1872	Economy	16200.00
0005433008940	1872	Economy	16200.00
0005433008769	1872	Economy	16200.00
0005433009235	22612	Business	48700.00
0005433285734	22612	Business	48700.00
0005433285714	22612	Business	48700.00
0005433009217	22612	Business	48700.00
0005433810551	22612	Business	48700.00
0005433285717	22612	Business	48700.00
0005433009233	22612	Business	48700.00
0005433009251	22612	Business	48700.00
0005433285731	22612	Business	48700.00
0005433009228	22612	Business	48700.00
0005433285715	22612	Business	48700.00
0005433009230	22612	Business	48700.00
0005433009221	22612	Economy	16200.00
0005433285739	22612	Economy	16200.00
0005433285710	22612	Economy	16200.00
0005433009250	22612	Economy	16200.00
0005433009240	22612	Economy	16200.00
0005433285729	22612	Economy	16200.00
0005433810558	22612	Economy	16200.00
0005433285712	22612	Economy	16200.00
0005433285720	22612	Economy	16200.00
0005433009253	22612	Economy	17900.00
0005433285716	22612	Economy	17900.00
0005433009248	22612	Economy	16200.00
0005433810555	22612	Economy	16200.00
0005433009257	22612	Economy	16200.00
0005433285709	22612	Economy	16200.00
0005433009216	22612	Economy	16200.00
0005433285736	22612	Economy	16200.00
0005433009258	22612	Economy	16200.00
0005433810557	22612	Economy	16200.00
0005433009239	22612	Economy	16200.00
0005433009238	22612	Economy	16200.00
0005433009222	22612	Economy	16200.00
0005433285737	22612	Economy	16200.00
0005433009256	22612	Economy	16200.00
0005433009241	22612	Economy	16200.00
0005433285722	22612	Economy	16200.00
0005433285721	22612	Economy	16200.00
0005433285728	22612	Economy	16200.00
0005433285726	22612	Economy	16200.00
0005433009234	22612	Economy	16200.00
0005433009220	22612	Economy	16200.00
0005433810540	22612	Economy	16200.00
0005433285725	22612	Economy	16200.00
0005433285723	22612	Economy	16200.00
0005433009232	22612	Economy	16200.00
0005433009215	22612	Economy	16200.00
0005433810559	22612	Economy	16200.00
0005433009245	22612	Economy	16200.00
0005433285732	22612	Economy	16200.00
0005433009225	22612	Economy	16200.00
0005433009254	22612	Economy	16200.00
0005433810538	22612	Economy	16200.00
0005433810552	22612	Economy	16200.00
0005433285711	22612	Economy	16200.00
0005433285713	22612	Economy	16200.00
0005433285733	22612	Economy	16200.00
0005433009252	22612	Economy	16200.00
0005433009237	22612	Economy	16200.00
0005433009227	22612	Economy	16200.00
0005433285730	22612	Economy	16200.00
0005433285719	22612	Economy	16200.00
0005433009255	22612	Economy	16200.00
0005433009247	22612	Economy	16200.00
0005433285724	22612	Economy	16200.00
0005433009219	22612	Economy	16200.00
0005433009226	22612	Economy	16200.00
0005433285727	22612	Economy	16200.00
0005433285718	22612	Economy	16200.00
0005433009223	22612	Economy	16200.00
0005433009249	22612	Economy	16200.00
0005433285735	22612	Economy	16200.00
0005433285738	22612	Economy	16200.00
0005433009244	22612	Economy	16200.00
0005433009259	22612	Economy	16200.00
0005433009243	22612	Economy	16200.00
0005433009242	22612	Economy	16200.00
0005433009224	22612	Economy	16200.00
0005433009246	22612	Economy	16200.00
0005433285708	22612	Economy	16200.00
0005433009236	22612	Economy	16200.00
0005433009231	22612	Economy	16200.00
0005433810565	22612	Economy	16200.00
0005433810539	22612	Economy	16200.00
0005433009218	22612	Economy	16200.00
0005433009229	22612	Economy	16200.00
0005432756891	25341	Business	83800.00
0005432755119	25341	Business	83800.00
0005434152786	25341	Economy	27900.00
0005432756884	25341	Economy	27900.00
0005434152801	25341	Economy	27900.00
0005432755112	25341	Economy	27900.00
0005434152785	25341	Economy	30700.00
0005434152790	25341	Economy	27900.00
0005434152794	25341	Economy	27900.00
0005432756892	25341	Economy	27900.00
0005432755115	25341	Economy	27900.00
0005432755114	25341	Economy	27900.00
0005432755116	25341	Economy	27900.00
0005432755118	25341	Economy	27900.00
0005432755120	25341	Economy	27900.00
0005432756888	25341	Economy	27900.00
0005432755113	25341	Economy	27900.00
0005432755117	25341	Economy	27900.00
0005432756887	25341	Economy	27900.00
0005434152802	25341	Economy	27900.00
0005434152795	25341	Economy	27900.00
0005432756889	25341	Economy	27900.00
0005432756893	25341	Economy	27900.00
0005432756890	25341	Economy	27900.00
0005434152793	25341	Economy	27900.00
0005432756883	25341	Economy	27900.00
0005432756886	25341	Economy	27900.00
0005432756885	25341	Economy	27900.00
0005434152796	25341	Economy	27900.00
0005433847525	5577	Business	99800.00
0005433847556	5577	Business	99800.00
0005435282606	5577	Business	99800.00
0005433847523	5577	Business	99800.00
0005432081602	5577	Business	99800.00
0005435282692	5577	Business	99800.00
0005433847575	5577	Business	99800.00
0005432081606	5577	Business	99800.00
0005435282529	5577	Business	99800.00
0005433847517	5577	Business	99800.00
0005433847553	5577	Business	99800.00
0005433847546	5577	Business	99800.00
0005435282605	5577	Business	99800.00
0005435282520	5577	Business	99800.00
0005435282602	5577	Business	99800.00
0005433847543	5577	Business	99800.00
0005433847555	5577	Business	99800.00
0005433847538	5577	Economy	33300.00
0005435282556	5577	Business	99800.00
0005433847526	5577	Economy	33300.00
0005433847534	5577	Economy	33300.00
0005435282555	5577	Economy	33300.00
0005434173542	5577	Economy	33300.00
0005433847522	5577	Economy	33300.00
0005435282530	5577	Economy	33300.00
0005433847564	5577	Economy	33300.00
0005435282625	5577	Economy	33300.00
0005435282738	5577	Economy	33300.00
0005433847571	5577	Economy	33300.00
0005433847572	5577	Economy	33300.00
0005433847569	5577	Economy	33300.00
0005433847561	5577	Economy	36600.00
0005433847531	5577	Economy	36600.00
0005433815450	5577	Economy	33300.00
0005433847537	5577	Economy	36600.00
0005433847562	5577	Economy	33300.00
0005433847544	5577	Economy	33300.00
0005435282564	5577	Economy	33300.00
0005433847528	5577	Economy	33300.00
0005432081603	5577	Economy	33300.00
0005433847551	5577	Economy	33300.00
0005435282554	5577	Economy	33300.00
0005432081600	5577	Economy	33300.00
0005433847532	5577	Economy	33300.00
0005433847570	5577	Economy	33300.00
0005433847566	5577	Economy	33300.00
0005435282718	5577	Economy	33300.00
0005433847540	5577	Economy	33300.00
0005433847573	5577	Economy	33300.00
0005435282531	5577	Economy	33300.00
0005432081601	5577	Economy	33300.00
0005435282603	5577	Economy	33300.00
0005433847559	5577	Economy	33300.00
0005433847548	5577	Economy	33300.00
0005433847530	5577	Economy	33300.00
0005435282622	5577	Economy	33300.00
0005433847550	5577	Economy	33300.00
0005433847557	5577	Economy	33300.00
0005434173550	5577	Economy	33300.00
0005433847565	5577	Economy	33300.00
0005432081599	5577	Economy	33300.00
0005433847574	5577	Economy	33300.00
0005433847558	5577	Economy	33300.00
0005432081605	5577	Economy	33300.00
0005435282712	5577	Economy	33300.00
0005433815449	5577	Economy	33300.00
0005433815451	5577	Economy	33300.00
0005433847536	5577	Economy	33300.00
0005433847519	5577	Economy	33300.00
0005433847520	5577	Economy	33300.00
0005433847568	5577	Economy	33300.00
0005433847576	5577	Economy	33300.00
0005435282661	5577	Economy	33300.00
0005433847547	5577	Economy	33300.00
0005433847529	5577	Economy	33300.00
0005433847524	5577	Economy	33300.00
0005433847552	5577	Economy	33300.00
0005433847518	5577	Economy	33300.00
0005435282711	5577	Economy	33300.00
0005435282611	5577	Economy	33300.00
0005435282637	5577	Economy	33300.00
0005433847541	5577	Economy	33300.00
0005433847539	5577	Economy	33300.00
0005435282604	5577	Economy	33300.00
0005432081604	5577	Economy	33300.00
0005433815453	5577	Economy	33300.00
0005434173551	5577	Economy	33300.00
0005435282621	5577	Economy	33300.00
0005433847549	5577	Economy	33300.00
0005434173541	5577	Economy	33300.00
0005433847533	5577	Economy	33300.00
0005435282581	5577	Economy	33300.00
0005433847542	5577	Economy	33300.00
0005433847527	5577	Economy	33300.00
0005433847545	5577	Economy	33300.00
0005433847535	5577	Economy	33300.00
0005435282739	5577	Economy	33300.00
0005433847521	5577	Economy	33300.00
0005435282624	5577	Economy	33300.00
0005433847560	5577	Economy	33300.00
0005435282693	5577	Economy	33300.00
0005433847554	5577	Economy	33300.00
0005433815452	5577	Economy	33300.00
0005435282666	5577	Economy	33300.00
0005433847567	5577	Economy	33300.00
0005433847563	5577	Economy	33300.00
0005433847112	13841	Business	99800.00
0005433846851	13841	Business	99800.00
0005435282860	13841	Business	99800.00
0005433846800	13841	Business	99800.00
0005433846916	13841	Business	99800.00
0005435282842	13841	Business	99800.00
0005435282861	13841	Business	99800.00
0005433846895	13841	Business	99800.00
0005433846849	13841	Business	99800.00
0005433846932	13841	Business	99800.00
0005435282865	13841	Business	99800.00
0005433846850	13841	Business	99800.00
0005433847012	13841	Business	99800.00
0005433847094	13841	Business	99800.00
0005435282855	13841	Business	99800.00
0005435282854	13841	Business	99800.00
0005433847132	13841	Economy	33300.00
0005433847027	13841	Economy	33300.00
0005433847004	13841	Economy	33300.00
0005433847208	13841	Economy	33300.00
0005433846994	13841	Economy	33300.00
0005433847015	13841	Economy	33300.00
0005433846894	13841	Economy	33300.00
0005433847174	13841	Economy	33300.00
0005434173576	13841	Economy	33300.00
0005433846974	13841	Economy	33300.00
0005433846993	13841	Economy	33300.00
0005435282848	13841	Economy	36600.00
0005433847317	13841	Economy	36600.00
0005434173577	13841	Economy	36600.00
0005433846861	13841	Economy	36600.00
0005433847182	13841	Economy	33300.00
0005433847031	13841	Economy	33300.00
0005435282853	13841	Economy	33300.00
0005432003746	13841	Economy	33300.00
0005433847125	13841	Economy	33300.00
0005434173578	13841	Economy	33300.00
0005433846898	13841	Economy	33300.00
0005433846931	13841	Economy	33300.00
0005433847017	13841	Economy	33300.00
0005435282862	13841	Economy	33300.00
0005435282864	13841	Economy	33300.00
0005433815389	13841	Economy	33300.00
0005433846972	13841	Economy	33300.00
0005435282856	13841	Economy	33300.00
0005433846836	13841	Economy	33300.00
0005435282857	13841	Economy	33300.00
0005433847108	13841	Economy	33300.00
0005433847204	13841	Economy	33300.00
0005433847175	13841	Economy	33300.00
0005433846905	13841	Economy	33300.00
0005435282851	13841	Economy	33300.00
0005433846940	13841	Economy	33300.00
0005433847097	13841	Economy	33300.00
0005433847030	13841	Economy	33300.00
0005432003747	13841	Economy	33300.00
0005433847128	13841	Economy	33300.00
0005433846879	13841	Economy	33300.00
0005435282866	13841	Economy	33300.00
0005435282845	13841	Economy	33300.00
0005435282863	13841	Economy	33300.00
0005433847223	13841	Economy	33300.00
0005433847091	13841	Economy	33300.00
0005433846862	13841	Economy	33300.00
0005435282850	13841	Economy	33300.00
0005433846930	13841	Economy	33300.00
0005434173575	13841	Economy	33300.00
0005435282844	13841	Economy	33300.00
0005433847124	13841	Economy	33300.00
0005433846878	13841	Economy	33300.00
0005435282847	13841	Economy	33300.00
0005435282843	13841	Economy	33300.00
0005435282859	13841	Economy	33300.00
0005432003745	13841	Economy	33300.00
0005433846718	13841	Economy	33300.00
0005433846860	13841	Economy	33300.00
0005435282849	13841	Economy	33300.00
0005433847271	13841	Economy	33300.00
0005433847092	13841	Economy	33300.00
0005435282846	13841	Economy	33300.00
0005433846975	13841	Economy	33300.00
0005433847043	13841	Economy	33300.00
0005433815415	13841	Economy	33300.00
0005433846956	13841	Economy	33300.00
0005435282858	13841	Economy	33300.00
0005433847107	13841	Economy	33300.00
0005433815414	13841	Economy	33300.00
0005433846883	13841	Economy	33300.00
0005433847126	13841	Economy	33300.00
0005435282852	13841	Economy	33300.00
0005433847016	13841	Economy	33300.00
0005434620893	7806	Economy	16600.00
0005434620881	7806	Economy	16600.00
0005434620891	7806	Economy	15100.00
0005435332414	7806	Economy	15100.00
0005434620883	7806	Economy	15100.00
0005432112549	7806	Economy	15100.00
0005434620879	7806	Economy	15100.00
0005435332395	7806	Economy	15100.00
0005435332415	7806	Economy	15100.00
0005434620885	7806	Economy	15100.00
0005432112548	7806	Economy	15100.00
0005434620888	7806	Economy	15100.00
0005434620882	7806	Economy	15100.00
0005434620892	7806	Economy	15100.00
0005434620878	7806	Economy	15100.00
0005434620887	7806	Economy	15100.00
0005435332402	7806	Economy	15100.00
0005435332405	7806	Economy	15100.00
0005434620884	7806	Economy	15100.00
0005435332383	7806	Economy	15100.00
0005434620876	7806	Economy	15100.00
0005434620889	7806	Economy	15100.00
0005435332375	7806	Economy	15100.00
0005434620874	7806	Economy	15100.00
0005434620890	7806	Economy	15100.00
0005434620875	7806	Economy	15100.00
0005435332384	7806	Economy	15100.00
0005435332407	7806	Economy	15100.00
0005434620886	7806	Economy	15100.00
0005435332397	7806	Economy	15100.00
0005435332401	7806	Economy	15100.00
0005435332396	7806	Economy	15100.00
0005435332374	7806	Economy	15100.00
0005434620880	7806	Economy	15100.00
0005434620894	7806	Economy	15100.00
0005434620877	7806	Economy	15100.00
0005435332479	32959	Economy	16600.00
0005434620665	32959	Economy	16600.00
0005435332477	32959	Economy	16600.00
0005435332481	32959	Economy	15100.00
0005434620691	32959	Economy	15100.00
0005434620730	32959	Economy	15100.00
0005435332484	32959	Economy	15100.00
0005434620703	32959	Economy	15100.00
0005435332476	32959	Economy	15100.00
0005434620686	32959	Economy	15100.00
0005434620610	32959	Economy	15100.00
0005434620667	32959	Economy	15100.00
0005434620668	32959	Economy	15100.00
0005434620685	32959	Economy	15100.00
0005435332483	32959	Economy	15100.00
0005435332478	32959	Economy	15100.00
0005435332482	32959	Economy	15100.00
0005434620690	32959	Economy	15100.00
0005434620718	32959	Economy	15100.00
0005434620696	32959	Economy	15100.00
0005434620773	32959	Economy	15100.00
0005434620780	32959	Economy	15100.00
0005434620684	32959	Economy	15100.00
0005434620779	32959	Economy	15100.00
0005435332485	32959	Economy	15100.00
0005435332486	32959	Economy	15100.00
0005434620649	32959	Economy	15100.00
0005434620702	32959	Economy	15100.00
0005434620772	32959	Economy	15100.00
0005434620654	32959	Economy	15100.00
0005435332480	32959	Economy	15100.00
0005435785852	4264	Business	38000.00
0005434994156	4264	Business	38000.00
0005435785832	4264	Business	38000.00
0005435785855	4264	Business	38000.00
0005435785837	4264	Business	38000.00
0005435785843	4264	Business	38000.00
0005435937409	4264	Economy	12700.00
0005435785860	4264	Economy	12700.00
0005434994162	4264	Economy	12700.00
0005435785831	4264	Economy	12700.00
0005435918689	4264	Economy	12700.00
0005435785830	4264	Economy	13900.00
0005435785856	4264	Economy	13900.00
0005434994164	4264	Economy	13900.00
0005435785835	4264	Economy	13900.00
0005435787385	4264	Economy	12700.00
0005435785849	4264	Economy	12700.00
0005435785841	4264	Economy	12700.00
0005435785859	4264	Economy	12700.00
0005435785839	4264	Economy	12700.00
0005435785838	4264	Economy	12700.00
0005434994161	4264	Economy	12700.00
0005432190683	4264	Economy	12700.00
0005435785828	4264	Economy	12700.00
0005435918680	4264	Economy	12700.00
0005434994159	4264	Economy	12700.00
0005435785853	4264	Economy	12700.00
0005435918674	4264	Economy	12700.00
0005434994157	4264	Economy	12700.00
0005435785842	4264	Economy	12700.00
0005435785833	4264	Economy	12700.00
0005435785844	4264	Economy	12700.00
0005435785862	4264	Economy	12700.00
0005435785845	4264	Economy	12700.00
0005434994158	4264	Economy	12700.00
0005435785829	4264	Economy	12700.00
0005434994165	4264	Economy	12700.00
0005435785854	4264	Economy	12700.00
0005435937407	4264	Economy	12700.00
0005435918670	4264	Economy	12700.00
0005432190685	4264	Economy	12700.00
0005435785846	4264	Economy	12700.00
0005434994166	4264	Economy	12700.00
0005435918681	4264	Economy	12700.00
0005434994163	4264	Economy	12700.00
0005435785834	4264	Economy	12700.00
0005435785851	4264	Economy	12700.00
0005435785848	4264	Economy	12700.00
0005434994167	4264	Economy	12700.00
0005435787386	4264	Economy	12700.00
0005435785857	4264	Economy	12700.00
0005435785858	4264	Economy	12700.00
0005435785861	4264	Economy	12700.00
0005435785850	4264	Economy	12700.00
0005434994155	4264	Economy	12700.00
0005435785836	4264	Economy	12700.00
0005435785827	4264	Economy	12700.00
0005435785840	4264	Economy	12700.00
0005432190682	4264	Economy	12700.00
0005432190684	4264	Economy	12700.00
0005434994160	4264	Economy	12700.00
0005435785847	4264	Economy	12700.00
0005435785532	27319	Business	38000.00
0005435785411	27319	Business	38000.00
0005435785385	27319	Business	38000.00
0005435785440	27319	Business	38000.00
0005435785533	27319	Business	38000.00
0005434994110	27319	Business	38000.00
0005434994069	27319	Business	38000.00
0005435785335	27319	Business	38000.00
0005435785407	27319	Business	38000.00
0005435785519	27319	Business	38000.00
0005435918722	27319	Economy	12700.00
0005435785535	27319	Economy	12700.00
0005432195722	27319	Economy	12700.00
0005434994103	27319	Economy	12700.00
0005432195723	27319	Economy	12700.00
0005435785498	27319	Economy	12700.00
0005435785502	27319	Economy	12700.00
0005435785428	27319	Economy	12700.00
0005435785514	27319	Economy	13900.00
0005434994073	27319	Economy	13900.00
0005435787362	27319	Economy	13900.00
0005435785378	27319	Economy	12700.00
0005435787354	27319	Economy	12700.00
0005434994054	27319	Economy	12700.00
0005435785406	27319	Economy	12700.00
0005435785322	27319	Economy	12700.00
0005435785497	27319	Economy	12700.00
0005435918724	27319	Economy	12700.00
0005435785321	27319	Economy	12700.00
0005435918725	27319	Economy	12700.00
0005435785386	27319	Economy	12700.00
0005435785448	27319	Economy	12700.00
0005435785536	27319	Economy	12700.00
0005434994032	27319	Economy	12700.00
0005435785515	27319	Economy	12700.00
0005432195721	27319	Economy	12700.00
0005434994056	27319	Economy	12700.00
0005435785489	27319	Economy	12700.00
0005435785579	27319	Economy	12700.00
0005432195724	27319	Economy	12700.00
0005435918723	27319	Economy	12700.00
0005435785584	27319	Economy	12700.00
0005435785362	27319	Economy	12700.00
0005435785427	27319	Economy	12700.00
0005435785572	27319	Economy	12700.00
0005435785338	27319	Economy	12700.00
0005435785505	27319	Economy	12700.00
0005435937440	27319	Economy	12700.00
0005435785512	27319	Economy	12700.00
0005435785617	27319	Economy	12700.00
0005434994031	27319	Economy	12700.00
0005435785513	27319	Economy	12700.00
0005435785336	27319	Economy	12700.00
0005435785450	27319	Economy	12700.00
0005434994055	27319	Economy	12700.00
0005435785538	27319	Economy	12700.00
0005435785326	27319	Economy	12700.00
0005435787361	27319	Economy	12700.00
0005435785506	27319	Economy	12700.00
0005434994104	27319	Economy	12700.00
0005435785518	27319	Economy	12700.00
0005435785511	27319	Economy	12700.00
0005435785314	27319	Economy	12700.00
0005432460559	4734	Business	40900.00
0005432460584	4734	Business	40900.00
0005432568525	4734	Business	40900.00
0005433726137	4734	Business	40900.00
0005432568488	4734	Business	40900.00
0005432186921	4734	Business	40900.00
0005434082240	4734	Business	40900.00
0005432460576	4734	Business	40900.00
0005434082223	4734	Business	40900.00
0005432568501	4734	Business	40900.00
0005432460575	4734	Business	40900.00
0005432568474	4734	Business	40900.00
0005434082238	4734	Business	40900.00
0005432170486	4734	Business	40900.00
0005434082244	4734	Business	40900.00
0005432568490	4734	Business	40900.00
0005434082226	4734	Business	40900.00
0005432460598	4734	Business	40900.00
0005432568497	4734	Business	40900.00
0005434082237	4734	Business	40900.00
0005434082230	4734	Economy	15000.00
0005432460607	4734	Business	40900.00
0005432460590	4734	Economy	15000.00
0005432460605	4734	Economy	15000.00
0005432568479	4734	Economy	15000.00
0005432460594	4734	Economy	13600.00
0005433451648	4734	Economy	13600.00
0005434082243	4734	Economy	13600.00
0005432568468	4734	Economy	13600.00
0005432568508	4734	Economy	13600.00
0005433452768	4734	Economy	13600.00
0005432568486	4734	Economy	13600.00
0005432568493	4734	Economy	13600.00
0005432170482	4734	Economy	13600.00
0005432568471	4734	Economy	13600.00
0005432568494	4734	Economy	13600.00
0005434082231	4734	Economy	13600.00
0005432460604	4734	Economy	13600.00
0005433452770	4734	Economy	13600.00
0005432568521	4734	Economy	13600.00
0005432568495	4734	Economy	13600.00
0005432568491	4734	Economy	13600.00
0005432460578	4734	Economy	13600.00
0005434082247	4734	Economy	13600.00
0005432568523	4734	Economy	13600.00
0005432568502	4734	Economy	13600.00
0005432568489	4734	Economy	13600.00
0005432568500	4734	Economy	13600.00
0005432460577	4734	Economy	13600.00
0005432460567	4734	Economy	13600.00
0005432568478	4734	Economy	13600.00
0005434082220	4734	Economy	13600.00
0005432460606	4734	Economy	13600.00
0005432186923	4734	Economy	13600.00
0005432568520	4734	Economy	13600.00
0005432460560	4734	Economy	13600.00
0005433726136	4734	Economy	13600.00
0005432568498	4734	Economy	13600.00
0005432460586	4734	Economy	13600.00
0005432568481	4734	Economy	13600.00
0005432170481	4734	Economy	13600.00
0005432170483	4734	Economy	13600.00
0005432568477	4734	Economy	13600.00
0005432460582	4734	Economy	13600.00
0005433451649	4734	Economy	13600.00
0005432568475	4734	Economy	13600.00
0005432460596	4734	Economy	13600.00
0005432568473	4734	Economy	13600.00
0005432568483	4734	Economy	13600.00
0005432568510	4734	Economy	13600.00
0005432460570	4734	Economy	13600.00
0005432460593	4734	Economy	13600.00
0005432568517	4734	Economy	13600.00
0005432460601	4734	Economy	13600.00
0005432460603	4734	Economy	13600.00
0005432568507	4734	Economy	13600.00
0005433452769	4734	Economy	13600.00
0005432460583	4734	Economy	13600.00
0005434082242	4734	Economy	13600.00
0005432460562	4734	Economy	13600.00
0005432568496	4734	Economy	13600.00
0005432460585	4734	Economy	13600.00
0005432460600	4734	Economy	13600.00
0005434082246	4734	Economy	13600.00
0005432460581	4734	Economy	13600.00
0005432568465	4734	Economy	13600.00
0005432568522	4734	Economy	13600.00
0005432568484	4734	Economy	13600.00
0005432460589	4734	Economy	13600.00
0005432186922	4734	Economy	13600.00
0005432568499	4734	Economy	13600.00
0005432460568	4734	Economy	13600.00
0005432571373	4734	Economy	13600.00
0005434082235	4734	Economy	13600.00
0005432568515	4734	Economy	13600.00
0005432571374	4734	Economy	13600.00
0005432568482	4734	Economy	15000.00
0005432460563	4734	Economy	13600.00
0005434082229	4734	Economy	15000.00
0005432568526	4734	Economy	13600.00
0005432568467	4734	Economy	13600.00
0005432568505	4734	Economy	13600.00
0005434082222	4734	Economy	15000.00
0005432460611	4734	Economy	13600.00
0005432568469	4734	Economy	15000.00
0005432568480	4734	Economy	13600.00
0005434082221	4734	Economy	13600.00
0005434082236	4734	Economy	13600.00
0005432568503	4734	Economy	13600.00
0005432571377	4734	Economy	13600.00
0005432186920	4734	Economy	13600.00
0005432460595	4734	Economy	13600.00
0005432460592	4734	Economy	13600.00
0005432460564	4734	Economy	13600.00
0005432460599	4734	Economy	13600.00
0005434082248	4734	Economy	13600.00
0005432568485	4734	Economy	13600.00
0005434082241	4734	Economy	13600.00
0005432568506	4734	Economy	13600.00
0005432568519	4734	Economy	13600.00
0005432568470	4734	Economy	13600.00
0005432460587	4734	Economy	13600.00
0005432568512	4734	Economy	13600.00
0005432568509	4734	Economy	13600.00
0005434082227	4734	Economy	13600.00
0005434082224	4734	Economy	13600.00
0005432460566	4734	Economy	13600.00
0005432460597	4734	Economy	13600.00
0005432460574	4734	Economy	13600.00
0005432571376	4734	Economy	13600.00
0005434082225	4734	Economy	13600.00
0005432571375	4734	Economy	13600.00
0005432460579	4734	Economy	13600.00
0005434082239	4734	Economy	13600.00
0005434082232	4734	Economy	13600.00
0005434082249	4734	Economy	13600.00
0005432460609	4734	Economy	13600.00
0005432568476	4734	Economy	13600.00
0005432568466	4734	Economy	13600.00
0005432460588	4734	Economy	13600.00
0005432460580	4734	Economy	13600.00
0005432460571	4734	Economy	13600.00
0005432460608	4734	Economy	13600.00
0005434082233	4734	Economy	13600.00
0005434559105	4734	Economy	13600.00
0005432568487	4734	Economy	13600.00
0005432460573	4734	Economy	13600.00
0005432170485	4734	Economy	13600.00
0005434082228	4734	Economy	13600.00
0005432460565	4734	Economy	13600.00
0005432568518	4734	Economy	13600.00
0005432568504	4734	Economy	13600.00
0005432568472	4734	Economy	13600.00
0005434082234	4734	Economy	13600.00
0005433451647	4734	Economy	13600.00
0005432568513	4734	Economy	13600.00
0005432170484	4734	Economy	13600.00
0005432460569	4734	Economy	13600.00
0005432568516	4734	Economy	13600.00
0005432460572	4734	Economy	13600.00
0005432568511	4734	Economy	13600.00
0005434082245	4734	Economy	13600.00
0005432460591	4734	Economy	13600.00
0005432568524	4734	Economy	13600.00
0005432568514	4734	Economy	13600.00
0005432460610	4734	Economy	13600.00
0005432460602	4734	Economy	13600.00
0005432460561	4734	Economy	13600.00
0005432568492	4734	Economy	13600.00
0005432568253	30532	Business	40900.00
0005434081949	30532	Business	40900.00
0005432568021	30532	Business	40900.00
0005432568270	30532	Business	40900.00
0005432567917	30532	Business	40900.00
0005432567760	30532	Business	40900.00
0005432567751	30532	Business	40900.00
0005432568269	30532	Business	40900.00
0005432460306	30532	Business	40900.00
0005432568053	30532	Business	40900.00
0005432568211	30532	Business	40900.00
0005432568089	30532	Business	40900.00
0005433454888	30532	Business	40900.00
0005432567902	30532	Business	40900.00
0005432460177	30532	Business	40900.00
0005434081970	30532	Business	40900.00
0005432460224	30532	Business	40900.00
0005432460269	30532	Business	40900.00
0005432459814	30532	Business	40900.00
0005432567730	30532	Business	40900.00
0005432567909	30532	Business	40900.00
0005432568358	30532	Business	40900.00
0005432460351	30532	Economy	15000.00
0005432568019	30532	Economy	15000.00
0005432567837	30532	Economy	15000.00
0005432459828	30532	Economy	13600.00
0005432460057	30532	Economy	13600.00
0005432568006	30532	Economy	13600.00
0005432568236	30532	Economy	13600.00
0005432460282	30532	Economy	13600.00
0005432568283	30532	Economy	13600.00
0005432568138	30532	Economy	13600.00
0005432567952	30532	Economy	13600.00
0005432568079	30532	Economy	13600.00
0005434081968	30532	Economy	13600.00
0005432460151	30532	Economy	13600.00
0005434081932	30532	Economy	13600.00
0005432571346	30532	Economy	13600.00
0005433452751	30532	Economy	13600.00
0005434081864	30532	Economy	13600.00
0005432568271	30532	Economy	13600.00
0005432460149	30532	Economy	13600.00
0005432460336	30532	Economy	13600.00
0005432568142	30532	Economy	13600.00
0005432567872	30532	Economy	13600.00
0005434081985	30532	Economy	13600.00
0005432568088	30532	Economy	13600.00
0005432567858	30532	Economy	13600.00
0005432567869	30532	Economy	13600.00
0005434081991	30532	Economy	13600.00
0005432460223	30532	Economy	13600.00
0005432213658	30532	Economy	13600.00
0005432567759	30532	Economy	13600.00
0005432460296	30532	Economy	13600.00
0005432460288	30532	Economy	13600.00
0005432568064	30532	Economy	13600.00
0005432460175	30532	Economy	13600.00
0005432460304	30532	Economy	13600.00
0005432460283	30532	Economy	13600.00
0005434081989	30532	Economy	13600.00
0005434082006	30532	Economy	13600.00
0005432161185	30532	Economy	13600.00
0005432460069	30532	Economy	13600.00
0005432460132	30532	Economy	13600.00
0005432567889	30532	Economy	13600.00
0005432567962	30532	Economy	13600.00
0005432568067	30532	Economy	13600.00
0005432568005	30532	Economy	13600.00
0005434082007	30532	Economy	13600.00
0005432568007	30532	Economy	13600.00
0005432568117	30532	Economy	13600.00
0005432568151	30532	Economy	13600.00
0005432460277	30532	Economy	13600.00
0005432460274	30532	Economy	13600.00
0005432567918	30532	Economy	13600.00
0005432568282	30532	Economy	13600.00
0005432460243	30532	Economy	13600.00
0005432567890	30532	Economy	13600.00
0005432460014	30532	Economy	13600.00
0005432568115	30532	Economy	13600.00
0005432460235	30532	Economy	13600.00
0005432567963	30532	Economy	13600.00
0005432568206	30532	Economy	13600.00
0005432568133	30532	Economy	13600.00
0005432460150	30532	Economy	13600.00
0005432567886	30532	Economy	13600.00
0005432460216	30532	Economy	13600.00
0005432567877	30532	Economy	13600.00
0005434081981	30532	Economy	13600.00
0005432460161	30532	Economy	13600.00
0005432568018	30532	Economy	13600.00
0005432568140	30532	Economy	13600.00
0005432568312	30532	Economy	13600.00
0005432568062	30532	Economy	13600.00
0005432567993	30532	Economy	13600.00
0005432460025	30532	Economy	13600.00
0005432567951	30532	Economy	13600.00
0005432567992	30532	Economy	15000.00
0005432460036	30532	Economy	15000.00
0005432567882	30532	Economy	13600.00
0005432460060	30532	Economy	13600.00
0005434081945	30532	Economy	13600.00
0005434081986	30532	Economy	15000.00
0005432568174	30532	Economy	13600.00
0005432568156	30532	Economy	15000.00
0005433454894	30532	Economy	13600.00
0005432567979	30532	Economy	13600.00
0005432568085	30532	Economy	13600.00
0005432568068	30532	Economy	13600.00
0005432460226	30532	Economy	13600.00
0005432568175	30532	Economy	13600.00
0005433452742	30532	Economy	13600.00
0005432568149	30532	Economy	13600.00
0005434081969	30532	Economy	13600.00
0005432460273	30532	Economy	13600.00
0005432568008	30532	Economy	13600.00
0005432567700	30532	Economy	13600.00
0005432460013	30532	Economy	13600.00
0005432567927	30532	Economy	13600.00
0005432568232	30532	Economy	13600.00
0005432567929	30532	Economy	13600.00
0005432460210	30532	Economy	13600.00
0005432567994	30532	Economy	13600.00
0005432460180	30532	Economy	13600.00
0005432460308	30532	Economy	13600.00
0005432213659	30532	Economy	13600.00
0005432567752	30532	Economy	13600.00
0005432567876	30532	Economy	13600.00
0005432460268	30532	Economy	13600.00
0005432460332	30532	Economy	13600.00
0005432460240	30532	Economy	13600.00
0005432161184	30532	Economy	13600.00
0005432568078	30532	Economy	13600.00
0005432460176	30532	Economy	13600.00
0005432460328	30532	Economy	13600.00
0005432568143	30532	Economy	13600.00
0005434082005	30532	Economy	13600.00
0005434081920	30532	Economy	13600.00
0005432568095	30532	Economy	13600.00
0005432568233	30532	Economy	13600.00
0005432567940	30532	Economy	13600.00
0005432568070	30532	Economy	13600.00
0005432460059	30532	Economy	13600.00
0005432568150	30532	Economy	13600.00
0005434081946	30532	Economy	13600.00
0005432567908	30532	Economy	13600.00
0005432460222	30532	Economy	13600.00
0005432567901	30532	Economy	13600.00
0005432460209	30532	Economy	13600.00
0005432213660	30532	Economy	13600.00
0005432567930	30532	Economy	13600.00
0005432567870	30532	Economy	13600.00
0005432459815	30532	Economy	13600.00
0005434081973	30532	Economy	13600.00
0005432568205	30532	Economy	13600.00
0005434081987	30532	Economy	13600.00
0005432460350	30532	Economy	13600.00
0005432460305	30532	Economy	13600.00
0005434081942	30532	Economy	13600.00
0005432568148	30532	Economy	13600.00
0005432460081	30532	Economy	13600.00
0005433452741	30532	Economy	13600.00
0005434081990	30532	Economy	13600.00
0005432568207	30532	Economy	13600.00
0005435722089	13599	Economy	9900.00
0005435722090	13599	Economy	9900.00
0005435720841	13599	Economy	9900.00
0005435722070	21223	Economy	9900.00
0005435722071	21223	Economy	9900.00
0005435722056	21223	Economy	9900.00
0005435722072	21223	Economy	9900.00
0005435722057	21223	Economy	9900.00
0005432295919	22790	Economy	8800.00
0005432295918	22790	Economy	8800.00
0005432295917	22790	Economy	8800.00
0005432295916	22790	Economy	8800.00
0005432295920	22790	Economy	8800.00
0005433344559	11124	Business	23600.00
0005433344621	11124	Business	23600.00
0005433344614	11124	Business	23600.00
0005433344560	11124	Business	23600.00
0005433344588	11124	Business	23600.00
0005433344540	11124	Business	23600.00
0005435097340	11124	Business	23600.00
0005435380294	11124	Business	23600.00
0005433344600	11124	Business	23600.00
0005433344617	11124	Business	23600.00
0005433344598	11124	Business	23600.00
0005433344589	11124	Business	23600.00
0005433344539	11124	Economy	7900.00
0005433344535	11124	Economy	7900.00
0005433344553	11124	Economy	7900.00
0005433344607	11124	Economy	7900.00
0005433344615	11124	Economy	7900.00
0005433344558	11124	Economy	7900.00
0005433344613	11124	Economy	7900.00
0005433344562	11124	Economy	7900.00
0005433344536	11124	Economy	7900.00
0005433344625	11124	Economy	7900.00
0005433344626	11124	Economy	7900.00
0005433344619	11124	Economy	7900.00
0005435380334	11124	Economy	7900.00
0005433344557	11124	Economy	7900.00
0005433344545	11124	Economy	7900.00
0005433344616	11124	Economy	7900.00
0005433344555	11124	Economy	7900.00
0005433344603	11124	Economy	7900.00
0005433344549	11124	Economy	7900.00
0005433344591	11124	Economy	7900.00
0005433344602	11124	Economy	7900.00
0005433344597	11124	Economy	7900.00
0005433344537	11124	Economy	7900.00
0005435508383	11124	Economy	7900.00
0005433344599	11124	Economy	7900.00
0005433344542	11124	Economy	7900.00
0005435380307	11124	Economy	7900.00
0005433344590	11124	Economy	7900.00
0005433344543	11124	Economy	7900.00
0005435097337	11124	Economy	7900.00
0005433344567	11124	Economy	7900.00
0005435380323	11124	Economy	7900.00
0005435380308	11124	Economy	7900.00
0005433344573	11124	Economy	7900.00
0005433344577	11124	Economy	7900.00
0005433344580	11124	Economy	7900.00
0005433344593	11124	Economy	7900.00
0005433344552	11124	Economy	7900.00
0005435097333	11124	Economy	7900.00
0005433344594	11124	Economy	7900.00
0005435380328	11124	Economy	8600.00
0005435508394	11124	Economy	8600.00
0005433344620	11124	Economy	8600.00
0005433344630	11124	Economy	8600.00
0005433344566	11124	Economy	8600.00
0005435097342	11124	Economy	7900.00
0005433344544	11124	Economy	7900.00
0005435097332	11124	Economy	7900.00
0005433344551	11124	Economy	7900.00
0005435097341	11124	Economy	7900.00
0005433344585	11124	Economy	7900.00
0005433344596	11124	Economy	7900.00
0005433344570	11124	Economy	7900.00
0005433344623	11124	Economy	7900.00
0005433344592	11124	Economy	7900.00
0005435097335	11124	Economy	7900.00
0005433344569	11124	Economy	7900.00
0005433344627	11124	Economy	7900.00
0005433344624	11124	Economy	7900.00
0005433344629	11124	Economy	7900.00
0005433344541	11124	Economy	7900.00
0005433344548	11124	Economy	7900.00
0005433344571	11124	Economy	7900.00
0005433344572	11124	Economy	7900.00
0005435097339	11124	Economy	7900.00
0005433344612	11124	Economy	7900.00
0005433344581	11124	Economy	7900.00
0005433344575	11124	Economy	7900.00
0005433344556	11124	Economy	7900.00
0005433344568	11124	Economy	7900.00
0005433344554	11124	Economy	7900.00
0005433344633	11124	Economy	7900.00
0005435508384	11124	Economy	7900.00
0005433344618	11124	Economy	7900.00
0005433344634	11124	Economy	7900.00
0005435380324	11124	Economy	7900.00
0005433344550	11124	Economy	7900.00
0005435508395	11124	Economy	7900.00
0005433344583	11124	Economy	7900.00
0005433344576	11124	Economy	7900.00
0005433344563	11124	Economy	7900.00
0005433344608	11124	Economy	7900.00
0005433344546	11124	Economy	7900.00
0005433344604	11124	Economy	7900.00
0005435097338	11124	Economy	7900.00
0005433344622	11124	Economy	7900.00
0005433344579	11124	Economy	7900.00
0005433344605	11124	Economy	7900.00
0005433344586	11124	Economy	7900.00
0005435097334	11124	Economy	7900.00
0005433344574	11124	Economy	7900.00
0005433344601	11124	Economy	7900.00
0005435380317	11124	Economy	7900.00
0005433344547	11124	Economy	7900.00
0005435380315	11124	Economy	7900.00
0005433344632	11124	Economy	7900.00
0005433344564	11124	Economy	7900.00
0005433344606	11124	Economy	7900.00
0005433344610	11124	Economy	7900.00
0005435508382	11124	Economy	7900.00
0005433344584	11124	Economy	7900.00
0005433344635	11124	Economy	7900.00
0005433344578	11124	Economy	7900.00
0005433344609	11124	Economy	7900.00
0005433344611	11124	Economy	7900.00
0005433344587	11124	Economy	7900.00
0005433344561	11124	Economy	7900.00
0005433344628	11124	Economy	7900.00
0005433344631	11124	Economy	7900.00
0005433344595	11124	Economy	7900.00
0005433344582	11124	Economy	7900.00
0005433344565	11124	Economy	7900.00
0005433344538	11124	Economy	7900.00
0005435097336	11124	Economy	7900.00
0005433344534	11124	Economy	7900.00
0005433343589	17123	Business	23600.00
0005433343442	17123	Business	23600.00
0005433344002	17123	Business	23600.00
0005433343625	17123	Business	23600.00
0005435097263	17123	Business	23600.00
0005433343192	17123	Business	23600.00
0005433343449	17123	Business	23600.00
0005433343588	17123	Business	23600.00
0005435380364	17123	Business	23600.00
0005435097264	17123	Business	23600.00
0005433343771	17123	Business	23600.00
0005433343719	17123	Business	23600.00
0005433343801	17123	Economy	7900.00
0005433343613	17123	Economy	7900.00
0005435545849	17123	Economy	7900.00
0005433343872	17123	Economy	7900.00
0005433343898	17123	Economy	7900.00
0005433343800	17123	Economy	7900.00
0005433344004	17123	Economy	7900.00
0005433342955	17123	Economy	7900.00
0005433343837	17123	Economy	7900.00
0005433343694	17123	Economy	7900.00
0005433343082	17123	Economy	7900.00
0005433343424	17123	Economy	7900.00
0005433343556	17123	Economy	7900.00
0005433344003	17123	Economy	7900.00
0005433343638	17123	Economy	7900.00
0005433343528	17123	Economy	7900.00
0005433343612	17123	Economy	7900.00
0005433343713	17123	Economy	7900.00
0005433343118	17123	Economy	7900.00
0005433343769	17123	Economy	7900.00
0005433343471	17123	Economy	7900.00
0005433343640	17123	Economy	7900.00
0005433343714	17123	Economy	7900.00
0005433343789	17123	Economy	7900.00
0005433343907	17123	Economy	7900.00
0005433343772	17123	Economy	7900.00
0005433343366	17123	Economy	7900.00
0005433343517	17123	Economy	7900.00
0005433343214	17123	Economy	7900.00
0005433343423	17123	Economy	7900.00
0005435380365	17123	Economy	7900.00
0005433343545	17123	Economy	7900.00
0005435097223	17123	Economy	7900.00
0005433343743	17123	Economy	7900.00
0005435380366	17123	Economy	7900.00
0005433343200	17123	Economy	7900.00
0005433343936	17123	Economy	7900.00
0005433343350	17123	Economy	7900.00
0005433343329	17123	Economy	7900.00
0005433343565	17123	Economy	7900.00
0005433343902	17123	Economy	8600.00
0005433343734	17123	Economy	8600.00
0005435545847	17123	Economy	8600.00
0005433344028	17123	Economy	8600.00
0005433343820	17123	Economy	8600.00
0005433343699	17123	Economy	7900.00
0005433343479	17123	Economy	8600.00
0005433343518	17123	Economy	7900.00
0005433343294	17123	Economy	7900.00
0005433343909	17123	Economy	7900.00
0005433343367	17123	Economy	7900.00
0005433343530	17123	Economy	7900.00
0005433343441	17123	Economy	7900.00
0005433343448	17123	Economy	7900.00
0005435097321	17123	Economy	7900.00
0005433343906	17123	Economy	7900.00
0005433343178	17123	Economy	7900.00
0005433343815	17123	Economy	7900.00
0005433343455	17123	Economy	7900.00
0005433343695	17123	Economy	7900.00
0005433343218	17123	Economy	7900.00
0005433343928	17123	Economy	7900.00
0005433343456	17123	Economy	7900.00
0005433343792	17123	Economy	7900.00
0005435097320	17123	Economy	7900.00
0005433343684	17123	Economy	7900.00
0005433343324	17123	Economy	7900.00
0005433343626	17123	Economy	7900.00
0005433343593	17123	Economy	7900.00
0005433343774	17123	Economy	7900.00
0005435545848	17123	Economy	7900.00
0005433343234	17123	Economy	7900.00
0005433343501	17123	Economy	7900.00
0005433343179	17123	Economy	7900.00
0005433343546	17123	Economy	7900.00
0005433343838	17123	Economy	7900.00
0005433343851	17123	Economy	7900.00
0005433343916	17123	Economy	7900.00
0005433343858	17123	Economy	7900.00
0005433343293	17123	Economy	7900.00
0005435097249	17123	Economy	7900.00
0005433343799	17123	Economy	7900.00
0005433343927	17123	Economy	7900.00
0005433343236	17123	Economy	7900.00
0005433343507	17123	Economy	7900.00
0005433343440	17123	Economy	7900.00
0005433343534	17123	Economy	7900.00
0005433343937	17123	Economy	7900.00
0005433343515	17123	Economy	7900.00
0005433343592	17123	Economy	7900.00
0005433343653	17123	Economy	7900.00
0005433343654	17123	Economy	7900.00
0005433343908	17123	Economy	7900.00
0005433343443	17123	Economy	7900.00
0005435380367	17123	Economy	7900.00
0005433343768	17123	Economy	7900.00
0005433342839	17123	Economy	7900.00
0005435097219	17123	Economy	7900.00
0005433343706	17123	Economy	7900.00
0005433342838	17123	Economy	7900.00
0005433342840	17123	Economy	7900.00
0005433343910	17123	Economy	7900.00
0005433343502	17123	Economy	7900.00
0005433343675	17123	Economy	7900.00
0005433343679	17123	Economy	7900.00
0005433343404	17123	Economy	7900.00
0005433343235	17123	Economy	7900.00
0005433343083	17123	Economy	7900.00
0005435380363	17123	Economy	7900.00
0005432293243	17123	Economy	7900.00
0005433343198	17123	Economy	7900.00
0005435097218	17123	Economy	7900.00
0005433343330	17123	Economy	7900.00
0005433343199	17123	Economy	7900.00
0005433343767	17123	Economy	7900.00
0005433343425	17123	Economy	7900.00
0005435097265	17123	Economy	7900.00
0005433344178	17123	Economy	7900.00
0005433481274	9095	Business	26600.00
0005433507442	9095	Business	26600.00
0005432920004	9095	Business	26600.00
0005433507436	9095	Business	26600.00
0005433507432	9095	Business	26600.00
0005433507441	9095	Business	26600.00
0005433507438	9095	Business	26600.00
0005433507439	9095	Business	26600.00
0005432920002	9095	Business	26600.00
0005432920035	9095	Economy	8900.00
0005432920012	9095	Economy	8900.00
0005432919890	9095	Economy	9800.00
0005432920003	9095	Economy	9800.00
0005433481280	9095	Economy	9800.00
0005433481279	9095	Economy	8900.00
0005432920037	9095	Economy	8900.00
0005432919986	9095	Economy	8900.00
0005432919977	9095	Economy	8900.00
0005432919948	9095	Economy	8900.00
0005432920036	9095	Economy	8900.00
0005432920026	9095	Economy	8900.00
0005433507440	9095	Economy	8900.00
0005433481281	9095	Economy	8900.00
0005432919903	9095	Economy	8900.00
0005432919904	9095	Economy	8900.00
0005433481278	9095	Economy	8900.00
0005433481276	9095	Economy	8900.00
0005432919854	9095	Economy	8900.00
0005432919883	9095	Economy	8900.00
0005432919978	9095	Economy	8900.00
0005432919953	9095	Economy	8900.00
0005432919935	9095	Economy	8900.00
0005432919930	9095	Economy	8900.00
0005432919949	9095	Economy	8900.00
0005433507430	9095	Economy	8900.00
0005432919933	9095	Economy	8900.00
0005433507434	9095	Economy	8900.00
0005432919884	9095	Economy	8900.00
0005432920013	9095	Economy	8900.00
0005432919955	9095	Economy	8900.00
0005433507431	9095	Economy	8900.00
0005432919889	9095	Economy	8900.00
0005432919985	9095	Economy	8900.00
0005432920023	9095	Economy	8900.00
0005433481277	9095	Economy	8900.00
0005433481275	9095	Economy	8900.00
0005433507435	9095	Economy	8900.00
0005433507437	9095	Economy	8900.00
0005433507433	9095	Economy	8900.00
0005432919987	9095	Economy	8900.00
0005432920025	9095	Economy	8900.00
0005433507319	20480	Business	26600.00
0005432920181	20480	Business	26600.00
0005432920173	20480	Business	26600.00
0005433507344	20480	Business	26600.00
0005433507275	20480	Business	26600.00
0005433481218	20480	Business	26600.00
0005433507357	20480	Business	26600.00
0005433507339	20480	Economy	8900.00
0005433481224	20480	Economy	8900.00
0005433507358	20480	Economy	8900.00
0005432920166	20480	Economy	8900.00
0005432920179	20480	Economy	8900.00
0005432920186	20480	Economy	8900.00
0005433507274	20480	Economy	8900.00
0005432920188	20480	Economy	9800.00
0005433507377	20480	Economy	9800.00
0005433507314	20480	Economy	9800.00
0005433507231	20480	Economy	8900.00
0005433507340	20480	Economy	8900.00
0005432920172	20480	Economy	8900.00
0005432920183	20480	Economy	8900.00
0005432920176	20480	Economy	8900.00
0005433507318	20480	Economy	8900.00
0005433481203	20480	Economy	8900.00
0005433507308	20480	Economy	8900.00
0005432920174	20480	Economy	8900.00
0005433507249	20480	Economy	8900.00
0005433507366	20480	Economy	8900.00
0005433507198	20480	Economy	8900.00
0005433481219	20480	Economy	8900.00
0005433481210	20480	Economy	8900.00
0005433507272	20480	Economy	8900.00
0005433507273	20480	Economy	8900.00
0005432920180	20480	Economy	8900.00
0005433481209	20480	Economy	8900.00
0005433507313	20480	Economy	8900.00
0005432920169	20480	Economy	8900.00
0005433481220	20480	Economy	8900.00
0005432920187	20480	Economy	8900.00
0005432920184	20480	Economy	8900.00
0005433507342	20480	Economy	8900.00
0005432920167	20480	Economy	8900.00
0005433507248	20480	Economy	8900.00
0005433507285	20480	Economy	8900.00
0005432920171	20480	Economy	8900.00
0005433481240	20480	Economy	8900.00
0005433507224	20480	Economy	8900.00
0005433507311	20480	Economy	8900.00
0005433507239	20480	Economy	8900.00
0005432920175	20480	Economy	8900.00
0005432920182	20480	Economy	8900.00
0005432920170	20480	Economy	8900.00
0005432920185	20480	Economy	8900.00
0005432920177	20480	Economy	8900.00
0005432920178	20480	Economy	8900.00
0005432920168	20480	Economy	8900.00
0005433507276	20480	Economy	8900.00
0005433507302	20480	Economy	8900.00
0005433507361	20480	Economy	8900.00
0005433507378	20480	Economy	8900.00
0005433507225	20480	Economy	8900.00
0005433481255	20480	Economy	8900.00
0005432394158	10216	Economy	5800.00
0005435178996	10216	Economy	5800.00
0005432396295	10216	Economy	5800.00
0005432394156	10216	Economy	5800.00
0005432396298	10216	Economy	5800.00
0005432396296	10216	Economy	5800.00
0005432396297	10216	Economy	5800.00
0005432396300	10216	Economy	5800.00
0005432394157	10216	Economy	5800.00
0005432394159	10216	Economy	5800.00
0005432396299	10216	Economy	5800.00
0005432396273	18321	Economy	5800.00
0005432400148	18321	Economy	5800.00
0005432400136	18321	Economy	5800.00
0005432396274	18321	Economy	5800.00
0005432400135	18321	Economy	5800.00
0005432400140	18321	Economy	5800.00
0005432400149	18321	Economy	5800.00
0005432400147	18321	Economy	5800.00
0005432400141	18321	Economy	5800.00
0005432396271	18321	Economy	5800.00
0005432396258	18321	Economy	5800.00
0005435626264	11016	Business	9500.00
0005435126526	11016	Business	9500.00
0005435554219	11016	Business	9500.00
0005435626252	11016	Business	9500.00
0005435126483	11016	Business	9500.00
0005435126512	11016	Business	9500.00
0005435126647	11016	Business	9500.00
0005435126646	11016	Business	9500.00
0005435626269	11016	Business	9500.00
0005435626265	11016	Economy	3200.00
0005435626268	11016	Economy	3200.00
0005435626222	11016	Economy	3200.00
0005435626254	11016	Economy	3200.00
0005434411838	11016	Economy	3200.00
0005435626263	11016	Economy	3500.00
0005435126609	11016	Economy	3500.00
0005435626276	11016	Economy	3500.00
0005435556713	11016	Economy	3500.00
0005435554216	11016	Economy	3200.00
0005435126500	11016	Economy	3200.00
0005435626145	11016	Economy	3200.00
0005435626165	11016	Economy	3200.00
0005435626221	11016	Economy	3200.00
0005435126610	11016	Economy	3200.00
0005435626255	11016	Economy	3200.00
0005435626272	11016	Economy	3200.00
0005435126565	11016	Economy	3200.00
0005435126632	11016	Economy	3200.00
0005435126781	11016	Economy	3200.00
0005434928339	11016	Economy	3200.00
0005435126625	11016	Economy	3200.00
0005435126423	11016	Economy	3200.00
0005435626262	11016	Economy	3200.00
0005435126539	11016	Economy	3200.00
0005435626277	11016	Economy	3200.00
0005435126782	11016	Economy	3200.00
0005435556714	11016	Economy	3200.00
0005435626240	11016	Economy	3200.00
0005435126522	11016	Economy	3200.00
0005435126548	11016	Economy	3200.00
0005435554218	11016	Economy	3200.00
0005435126498	11016	Economy	3200.00
0005435554199	11016	Economy	3200.00
0005435126502	11016	Economy	3200.00
0005435554215	11016	Economy	3200.00
0005435126424	11016	Economy	3200.00
0005435554201	11016	Economy	3200.00
0005435126411	11016	Economy	3200.00
0005434928341	11016	Economy	3200.00
0005435126514	11016	Economy	3200.00
0005435126664	11016	Economy	3200.00
0005434411839	11016	Economy	3200.00
0005435126487	11016	Economy	3200.00
0005435126678	11016	Economy	3200.00
0005435626232	11016	Economy	3200.00
0005434411840	11016	Economy	3200.00
0005435126484	11016	Economy	3200.00
0005434411841	11016	Economy	3200.00
0005435126549	11016	Economy	3200.00
0005435554217	11016	Economy	3200.00
0005434411842	11016	Economy	3200.00
0005434928340	11016	Economy	3200.00
0005435126572	11016	Economy	3200.00
0005435626175	11016	Economy	3200.00
0005435626273	11016	Economy	3200.00
0005435626246	11016	Economy	3200.00
0005435126612	11016	Economy	3200.00
0005435556711	11016	Economy	3200.00
0005435554209	11016	Economy	3200.00
0005435554200	11016	Economy	3200.00
0005435126959	14761	Business	9500.00
0005435126951	14761	Business	9500.00
0005435126961	14761	Business	9500.00
0005434411795	14761	Business	9500.00
0005435126964	14761	Business	9500.00
0005435126978	14761	Business	9500.00
0005435126946	14761	Business	9500.00
0005434411793	14761	Business	9500.00
0005435126938	14761	Business	9500.00
0005435626441	14761	Economy	3200.00
0005435126963	14761	Economy	3200.00
0005435126969	14761	Economy	3200.00
0005435126945	14761	Economy	3200.00
0005434411797	14761	Economy	3200.00
0005435126977	14761	Economy	3200.00
0005435626439	14761	Economy	3200.00
0005435126970	14761	Economy	3200.00
0005435126950	14761	Economy	3500.00
0005434928319	14761	Economy	3500.00
0005435626438	14761	Economy	3500.00
0005435126954	14761	Economy	3500.00
0005435126948	14761	Economy	3500.00
0005435556728	14761	Economy	3200.00
0005435626434	14761	Economy	3200.00
0005435126956	14761	Economy	3200.00
0005435554255	14761	Economy	3200.00
0005435126952	14761	Economy	3200.00
0005435126968	14761	Economy	3200.00
0005435126960	14761	Economy	3200.00
0005435626437	14761	Economy	3200.00
0005435126942	14761	Economy	3200.00
0005435626440	14761	Economy	3200.00
0005435126940	14761	Economy	3200.00
0005435126966	14761	Economy	3200.00
0005435126973	14761	Economy	3200.00
0005435126947	14761	Economy	3200.00
0005435126980	14761	Economy	3200.00
0005435126962	14761	Economy	3200.00
0005435126971	14761	Economy	3200.00
0005435126953	14761	Economy	3200.00
0005435126955	14761	Economy	3200.00
0005435554251	14761	Economy	3200.00
0005435126943	14761	Economy	3200.00
0005435554252	14761	Economy	3200.00
0005435126965	14761	Economy	3200.00
0005434411791	14761	Economy	3200.00
0005435126976	14761	Economy	3200.00
0005434928314	14761	Economy	3200.00
0005435126979	14761	Economy	3200.00
0005434928320	14761	Economy	3200.00
0005435126941	14761	Economy	3200.00
0005435126957	14761	Economy	3200.00
0005434411778	14761	Economy	3200.00
0005435126974	14761	Economy	3200.00
0005435126958	14761	Economy	3200.00
0005434411798	14761	Economy	3200.00
0005435126949	14761	Economy	3200.00
0005435626433	14761	Economy	3200.00
0005435126972	14761	Economy	3200.00
0005434411790	14761	Economy	3200.00
0005435554254	14761	Economy	3200.00
0005435626436	14761	Economy	3200.00
0005435126939	14761	Economy	3200.00
0005434411783	14761	Economy	3200.00
0005435126944	14761	Economy	3200.00
0005435556729	14761	Economy	3200.00
0005434411799	14761	Economy	3200.00
0005434928321	14761	Economy	3200.00
0005435626442	14761	Economy	3200.00
0005435554253	14761	Economy	3200.00
0005435126967	14761	Economy	3200.00
0005435626435	14761	Economy	3200.00
0005435126975	14761	Economy	3200.00
0005435443386	7105	Business	86900.00
0005435715718	7105	Business	86900.00
0005435443330	7105	Economy	29000.00
0005432398251	7105	Economy	29000.00
0005435715712	7105	Economy	29000.00
0005435715710	7105	Economy	29000.00
0005432398253	7105	Economy	29000.00
0005435443358	7105	Economy	31900.00
0005435715706	7105	Economy	31900.00
0005435715709	7105	Economy	29000.00
0005435443365	7105	Economy	29000.00
0005435715715	7105	Economy	29000.00
0005432400176	7105	Economy	29000.00
0005435443364	7105	Economy	29000.00
0005435715716	7105	Economy	29000.00
0005435715711	7105	Economy	29000.00
0005435715713	7105	Economy	29000.00
0005432400177	7105	Economy	29000.00
0005435443374	7105	Economy	29000.00
0005435715721	7105	Economy	29000.00
0005435715714	7105	Economy	29000.00
0005435715720	7105	Economy	29000.00
0005435715708	7105	Economy	29000.00
0005435715722	7105	Economy	29000.00
0005435715719	7105	Economy	29000.00
0005435715707	7105	Economy	29000.00
0005435179395	7105	Economy	29000.00
0005435216599	7105	Economy	29000.00
0005435715717	7105	Economy	29000.00
0005435216596	7105	Economy	29000.00
0005432398252	7105	Economy	29000.00
0005432400178	7105	Economy	29000.00
0005435443449	27058	Business	86900.00
0005435715599	27058	Business	86900.00
0005435178515	27058	Business	86900.00
0005435715573	27058	Business	86900.00
0005435443447	27058	Business	86900.00
0005435715526	27058	Economy	29000.00
0005435715570	27058	Economy	29000.00
0005435443444	27058	Economy	29000.00
0005435715517	27058	Economy	31900.00
0005435715596	27058	Economy	29000.00
0005435715534	27058	Economy	29000.00
0005432398211	27058	Economy	29000.00
0005435443445	27058	Economy	29000.00
0005435443450	27058	Economy	29000.00
0005435715664	27058	Economy	29000.00
0005435179002	27058	Economy	29000.00
0005435715600	27058	Economy	29000.00
0005435715488	27058	Economy	29000.00
0005432398206	27058	Economy	29000.00
0005432398219	27058	Economy	29000.00
0005435715598	27058	Economy	29000.00
0005432394116	27058	Economy	29000.00
0005435715604	27058	Economy	29000.00
0005432394125	27058	Economy	29000.00
0005435715578	27058	Economy	29000.00
0005432394121	27058	Economy	29000.00
0005435443448	27058	Economy	29000.00
0005432398212	27058	Economy	29000.00
0005435443451	27058	Economy	29000.00
0005435715569	27058	Economy	29000.00
0005435443446	27058	Economy	29000.00
0005435443452	27058	Economy	29000.00
0005435715489	27058	Economy	29000.00
0005432394124	27058	Economy	29000.00
0005432398217	27058	Economy	29000.00
0005434084998	2737	Economy	7700.00
0005433060427	2737	Economy	7700.00
0005433060421	2737	Economy	7700.00
0005434084997	2737	Economy	7700.00
0005434084996	2737	Economy	7700.00
0005433060422	2737	Economy	7700.00
0005434084999	2737	Economy	7700.00
0005434084958	28489	Economy	7700.00
0005434084967	28489	Economy	7700.00
0005434084965	28489	Economy	7700.00
0005434084966	28489	Economy	7700.00
0005434084971	28489	Economy	7700.00
0005433060451	28489	Economy	7700.00
0005434084930	28489	Economy	7700.00
0005434084961	28489	Economy	7700.00
0005433060453	28489	Economy	7700.00
0005433060452	28489	Economy	7700.00
0005432632817	25193	Economy	29000.00
0005435844328	25193	Economy	29000.00
0005432632807	25193	Economy	29000.00
0005432632822	25193	Economy	29000.00
0005435844319	25193	Economy	26400.00
0005435844321	25193	Economy	26400.00
0005435844336	25193	Economy	26400.00
0005432632828	25193	Economy	26400.00
0005432632827	25193	Economy	26400.00
0005435844331	25193	Economy	26400.00
0005432632824	25193	Economy	26400.00
0005435844333	25193	Economy	26400.00
0005435844287	25193	Economy	26400.00
0005432632813	25193	Economy	26400.00
0005435844323	25193	Economy	26400.00
0005435844335	25193	Economy	26400.00
0005432632831	25193	Economy	26400.00
0005432632820	25193	Economy	26400.00
0005432632823	25193	Economy	26400.00
0005435844330	25193	Economy	26400.00
0005432632818	25193	Economy	26400.00
0005435844314	25193	Economy	26400.00
0005435844337	25193	Economy	26400.00
0005435844326	25193	Economy	26400.00
0005435844324	25193	Economy	26400.00
0005435844290	25193	Economy	26400.00
0005435844320	25193	Economy	26400.00
0005432632812	25193	Economy	26400.00
0005435844325	25193	Economy	26400.00
0005432632814	25193	Economy	26400.00
0005432632809	25193	Economy	26400.00
0005432632811	25193	Economy	26400.00
0005435844322	25193	Economy	26400.00
0005432632808	25193	Economy	26400.00
0005432632825	25193	Economy	26400.00
0005432632826	25193	Economy	26400.00
0005432632810	25193	Economy	26400.00
0005432632819	25193	Economy	26400.00
0005432632805	25193	Economy	26400.00
0005435844286	25193	Economy	26400.00
0005435844334	25193	Economy	26400.00
0005432632816	25193	Economy	26400.00
0005435844332	25193	Economy	26400.00
0005432632815	25193	Economy	26400.00
0005432632829	25193	Economy	26400.00
0005432632821	25193	Economy	26400.00
0005432632806	25193	Economy	26400.00
0005432632830	25193	Economy	26400.00
0005435844374	28165	Economy	29000.00
0005432632767	28165	Economy	29000.00
0005435844368	28165	Economy	29000.00
0005435844363	28165	Economy	26400.00
0005435844372	28165	Economy	26400.00
0005435844367	28165	Economy	26400.00
0005432632739	28165	Economy	26400.00
0005435844378	28165	Economy	26400.00
0005432632742	28165	Economy	26400.00
0005435844370	28165	Economy	26400.00
0005432632760	28165	Economy	26400.00
0005432632740	28165	Economy	26400.00
0005432632746	28165	Economy	26400.00
0005432632756	28165	Economy	26400.00
0005432632768	28165	Economy	26400.00
0005435844373	28165	Economy	26400.00
0005432632774	28165	Economy	26400.00
0005435844371	28165	Economy	26400.00
0005432632744	28165	Economy	26400.00
0005432632757	28165	Economy	26400.00
0005435844366	28165	Economy	26400.00
0005435844375	28165	Economy	26400.00
0005432632766	28165	Economy	26400.00
0005432632715	28165	Economy	26400.00
0005435844377	28165	Economy	26400.00
0005435844365	28165	Economy	26400.00
0005432632716	28165	Economy	26400.00
0005432632747	28165	Economy	26400.00
0005432632802	28165	Economy	26400.00
0005432632741	28165	Economy	26400.00
0005432632801	28165	Economy	26400.00
0005432632793	28165	Economy	26400.00
0005432632755	28165	Economy	26400.00
0005435844364	28165	Economy	26400.00
0005432632748	28165	Economy	26400.00
0005435844376	28165	Economy	26400.00
0005432632733	28165	Economy	26400.00
0005435844369	28165	Economy	26400.00
0005435541146	11382	Business	20200.00
0005435541080	11382	Business	20200.00
0005435518007	11382	Business	20200.00
0005435541081	11382	Economy	6700.00
0005435541060	11382	Economy	6700.00
0005435541114	11382	Economy	6700.00
0005435541136	11382	Economy	6700.00
0005435518090	11382	Economy	6700.00
0005435518083	11382	Economy	6700.00
0005435541150	11382	Economy	7400.00
0005435518032	11382	Economy	7400.00
0005435518031	11382	Economy	6700.00
0005435517999	11382	Economy	6700.00
0005435541075	11382	Economy	6700.00
0005435517972	11382	Economy	6700.00
0005435541122	11382	Economy	6700.00
0005435518099	11382	Economy	6700.00
0005435541151	11382	Economy	6700.00
0005435518048	11382	Economy	6700.00
0005435541267	11382	Economy	6700.00
0005435518041	11382	Economy	6700.00
0005435541103	11382	Economy	6700.00
0005435541196	11382	Economy	6700.00
0005435541166	11382	Economy	6700.00
0005435541106	11382	Economy	6700.00
0005435541203	11382	Economy	6700.00
0005435540978	11382	Economy	6700.00
0005435518000	11382	Economy	6700.00
0005435518033	11382	Economy	6700.00
0005435517965	11382	Economy	6700.00
0005435541082	11382	Economy	6700.00
0005435541088	11382	Economy	6700.00
0005435518008	11382	Economy	6700.00
0005435541074	11382	Economy	6700.00
0005435517990	11382	Economy	6700.00
0005435541121	11382	Economy	6700.00
0005435517973	11382	Economy	6700.00
0005435541232	11382	Economy	6700.00
0005435518030	11382	Economy	6700.00
0005435518070	11382	Economy	6700.00
0005435541087	11382	Economy	6700.00
0005435541162	11382	Economy	6700.00
0005435541157	11382	Economy	6700.00
0005435518067	11382	Economy	6700.00
0005435541231	11382	Economy	6700.00
0005435517966	11382	Economy	6700.00
0005435541085	11382	Economy	6700.00
0005435541299	22267	Business	20200.00
0005435541291	22267	Business	20200.00
0005435541295	22267	Business	20200.00
0005435529557	22267	Business	20200.00
0005435529552	22267	Economy	6700.00
0005435529550	22267	Economy	6700.00
0005435529555	22267	Economy	6700.00
0005435529556	22267	Economy	6700.00
0005435541301	22267	Economy	7400.00
0005435529563	22267	Economy	7400.00
0005435541297	22267	Economy	6700.00
0005435529551	22267	Economy	6700.00
0005435541307	22267	Economy	6700.00
0005435541287	22267	Economy	6700.00
0005435541308	22267	Economy	6700.00
0005435529553	22267	Economy	6700.00
0005435529547	22267	Economy	6700.00
0005435529546	22267	Economy	6700.00
0005435529548	22267	Economy	6700.00
0005435541296	22267	Economy	6700.00
0005432294520	22267	Economy	6700.00
0005435541303	22267	Economy	6700.00
0005435529561	22267	Economy	6700.00
0005435541300	22267	Economy	6700.00
0005435541293	22267	Economy	6700.00
0005435541304	22267	Economy	6700.00
0005435529554	22267	Economy	6700.00
0005435541294	22267	Economy	6700.00
0005435541310	22267	Economy	6700.00
0005435529560	22267	Economy	6700.00
0005435541289	22267	Economy	6700.00
0005435529545	22267	Economy	6700.00
0005435541292	22267	Economy	6700.00
0005435529549	22267	Economy	6700.00
0005435541302	22267	Economy	6700.00
0005435529543	22267	Economy	6700.00
0005435541309	22267	Economy	6700.00
0005435541298	22267	Economy	6700.00
0005435529562	22267	Economy	6700.00
0005435529544	22267	Economy	6700.00
0005435529564	22267	Economy	6700.00
0005435529559	22267	Economy	6700.00
0005435529558	22267	Economy	6700.00
0005435541305	22267	Economy	6700.00
0005435541288	22267	Economy	6700.00
0005435541290	22267	Economy	6700.00
0005435541306	22267	Economy	6700.00
0005433251645	2269	Business	20200.00
0005434908058	2269	Business	20200.00
0005433251605	2269	Business	20200.00
0005433251643	2269	Business	20200.00
0005433251615	2269	Business	20200.00
0005434908056	2269	Business	20200.00
0005433401007	2269	Business	20200.00
0005433251642	2269	Business	20200.00
0005434908061	2269	Business	20200.00
0005433251798	2269	Business	20200.00
0005433251727	2269	Economy	6700.00
0005433251578	2269	Economy	6700.00
0005434908040	2269	Economy	6700.00
0005434908029	2269	Economy	6700.00
0005434908046	2269	Economy	6700.00
0005433251556	2269	Economy	6700.00
0005433251606	2269	Economy	6700.00
0005434908067	2269	Economy	6700.00
0005434908038	2269	Economy	6700.00
0005434908045	2269	Economy	6700.00
0005433251726	2269	Economy	7400.00
0005434908047	2269	Economy	7400.00
0005433251638	2269	Economy	7400.00
0005433251497	2269	Economy	7400.00
0005433401006	2269	Economy	6700.00
0005433251800	2269	Economy	6700.00
0005434908066	2269	Economy	6700.00
0005434908039	2269	Economy	6700.00
0005433251664	2269	Economy	6700.00
0005434908043	2269	Economy	6700.00
0005434908068	2269	Economy	6700.00
0005434908051	2269	Economy	6700.00
0005433251718	2269	Economy	6700.00
0005433251564	2269	Economy	6700.00
0005434908059	2269	Economy	6700.00
0005433251743	2269	Economy	6700.00
0005434908024	2269	Economy	6700.00
0005434908041	2269	Economy	6700.00
0005434908064	2269	Economy	6700.00
0005433251661	2269	Economy	6700.00
0005434908036	2269	Economy	6700.00
0005434908048	2269	Economy	6700.00
0005434908060	2269	Economy	6700.00
0005433251614	2269	Economy	6700.00
0005434908057	2269	Economy	6700.00
0005433251736	2269	Economy	6700.00
0005434908032	2269	Economy	6700.00
0005434908031	2269	Economy	6700.00
0005433251682	2269	Economy	6700.00
0005434908065	2269	Economy	6700.00
0005434908062	2269	Economy	6700.00
0005434908027	2269	Economy	6700.00
0005433251660	2269	Economy	6700.00
0005433251669	2269	Economy	6700.00
0005434908034	2269	Economy	6700.00
0005433251799	2269	Economy	6700.00
0005434908063	2269	Economy	6700.00
0005433400999	2269	Economy	6700.00
0005433251725	2269	Economy	6700.00
0005434908052	2269	Economy	6700.00
0005433251644	2269	Economy	6700.00
0005433251685	2269	Economy	6700.00
0005433251671	2269	Economy	6700.00
0005434908054	2269	Economy	6700.00
0005434908028	2269	Economy	6700.00
0005434908035	2269	Economy	6700.00
0005433401002	2269	Economy	6700.00
0005433251728	2269	Economy	6700.00
0005433251773	2269	Economy	6700.00
0005434908033	2269	Economy	6700.00
0005434908053	2269	Economy	6700.00
0005434908025	2269	Economy	6700.00
0005434908026	2269	Economy	6700.00
0005434908049	2269	Economy	6700.00
0005433251655	2269	Economy	6700.00
0005434908023	2269	Economy	6700.00
0005434908042	2269	Economy	6700.00
0005433251541	2269	Economy	6700.00
0005433400998	2269	Economy	6700.00
0005433251742	2269	Economy	6700.00
0005433251683	2269	Economy	6700.00
0005434908050	2269	Economy	6700.00
0005433251670	2269	Economy	6700.00
0005434908030	2269	Economy	6700.00
0005434908055	2269	Economy	6700.00
0005433251547	2269	Economy	6700.00
0005434908037	2269	Economy	6700.00
0005434908044	2269	Economy	6700.00
0005433251734	2269	Economy	6700.00
0005434907678	25622	Business	20200.00
0005434907466	25622	Business	20200.00
0005433251929	25622	Business	20200.00
0005433251914	25622	Business	20200.00
0005434907461	25622	Business	20200.00
0005433401026	25622	Business	20200.00
0005433251919	25622	Business	20200.00
0005434907571	25622	Business	20200.00
0005434907569	25622	Business	20200.00
0005434907679	25622	Business	20200.00
0005433251936	25622	Business	20200.00
0005434907648	25622	Business	20200.00
0005434907465	25622	Economy	6700.00
0005433251927	25622	Economy	6700.00
0005434907502	25622	Economy	6700.00
0005434907631	25622	Economy	6700.00
0005434907540	25622	Economy	6700.00
0005434907414	25622	Economy	6700.00
0005433251907	25622	Economy	6700.00
0005434907652	25622	Economy	6700.00
0005433251933	25622	Economy	6700.00
0005434907589	25622	Economy	7400.00
0005434907649	25622	Economy	7400.00
0005433251918	25622	Economy	7400.00
0005433251924	25622	Economy	7400.00
0005434907476	25622	Economy	6700.00
0005434907467	25622	Economy	6700.00
0005434907344	25622	Economy	6700.00
0005433401028	25622	Economy	6700.00
0005433251912	25622	Economy	6700.00
0005434907350	25622	Economy	6700.00
0005433251931	25622	Economy	6700.00
0005433251925	25622	Economy	6700.00
0005433251913	25622	Economy	6700.00
0005434907406	25622	Economy	6700.00
0005434907242	25622	Economy	6700.00
0005434907458	25622	Economy	6700.00
0005434907455	25622	Economy	6700.00
0005433251910	25622	Economy	6700.00
0005434907417	25622	Economy	6700.00
0005433401029	25622	Economy	6700.00
0005433251926	25622	Economy	6700.00
0005434907376	25622	Economy	6700.00
0005434907683	25622	Economy	6700.00
0005434907494	25622	Economy	6700.00
0005434907572	25622	Economy	6700.00
0005433251938	25622	Economy	6700.00
0005434907243	25622	Economy	6700.00
0005434907449	25622	Economy	6700.00
0005434907539	25622	Economy	6700.00
0005434907563	25622	Economy	6700.00
0005434907486	25622	Economy	6700.00
0005433251920	25622	Economy	6700.00
0005433251937	25622	Economy	6700.00
0005434907653	25622	Economy	6700.00
0005434907479	25622	Economy	6700.00
0005434907477	25622	Economy	6700.00
0005434907299	25622	Economy	6700.00
0005433251908	25622	Economy	6700.00
0005434907497	25622	Economy	6700.00
0005434907435	25622	Economy	6700.00
0005434907586	25622	Economy	6700.00
0005433251930	25622	Economy	6700.00
0005434907438	25622	Economy	6700.00
0005433251928	25622	Economy	6700.00
0005434907375	25622	Economy	6700.00
0005433251935	25622	Economy	6700.00
0005433251916	25622	Economy	6700.00
0005433251915	25622	Economy	6700.00
0005433251909	25622	Economy	6700.00
0005434907684	25622	Economy	6700.00
0005433251922	25622	Economy	6700.00
0005434907454	25622	Economy	6700.00
0005433251932	25622	Economy	6700.00
0005434907241	25622	Economy	6700.00
0005433251923	25622	Economy	6700.00
0005433251917	25622	Economy	6700.00
0005433251921	25622	Economy	6700.00
0005433251911	25622	Economy	6700.00
0005434907377	25622	Economy	6700.00
0005434907590	25622	Economy	6700.00
0005433251934	25622	Economy	6700.00
0005434907480	25622	Economy	6700.00
0005434907578	25622	Economy	6700.00
0005434907682	25622	Economy	6700.00
0005434907597	25622	Economy	6700.00
0005433401027	25622	Economy	6700.00
0005432621245	2523	Economy	13600.00
0005432621240	2523	Economy	13600.00
0005432621235	2523	Economy	13600.00
0005432862373	2523	Economy	12400.00
0005432862339	2523	Economy	12400.00
0005432862321	2523	Economy	12400.00
0005432621243	2523	Economy	12400.00
0005432862341	2523	Economy	12400.00
0005432862359	2523	Economy	12400.00
0005432621238	2523	Economy	12400.00
0005432621248	2523	Economy	12400.00
0005432862360	2523	Economy	12400.00
0005432621244	2523	Economy	12400.00
0005432621236	2523	Economy	12400.00
0005432621239	2523	Economy	12400.00
0005432862322	2523	Economy	12400.00
0005432621242	2523	Economy	12400.00
0005432862364	2523	Economy	12400.00
0005432862340	2523	Economy	12400.00
0005432621241	2523	Economy	12400.00
0005432862342	2523	Economy	12400.00
0005432621237	2523	Economy	12400.00
0005432621247	2523	Economy	12400.00
0005432862323	2523	Economy	12400.00
0005432862365	2523	Economy	12400.00
0005432621246	2523	Economy	12400.00
0005432621035	28065	Economy	13600.00
0005432862413	28065	Economy	13600.00
0005432862417	28065	Economy	13600.00
0005432621107	28065	Economy	13600.00
0005432621121	28065	Economy	12400.00
0005432862411	28065	Economy	12400.00
0005432862414	28065	Economy	12400.00
0005432621085	28065	Economy	12400.00
0005432862410	28065	Economy	12400.00
0005432621153	28065	Economy	12400.00
0005432621129	28065	Economy	12400.00
0005432621106	28065	Economy	12400.00
0005432621113	28065	Economy	12400.00
0005432621155	28065	Economy	12400.00
0005432621086	28065	Economy	12400.00
0005432621151	28065	Economy	12400.00
0005432621173	28065	Economy	12400.00
0005432621090	28065	Economy	12400.00
0005432621108	28065	Economy	12400.00
0005432621075	28065	Economy	12400.00
0005432862415	28065	Economy	12400.00
0005432621170	28065	Economy	12400.00
0005432621117	28065	Economy	12400.00
0005432621128	28065	Economy	12400.00
0005432621089	28065	Economy	12400.00
0005432862412	28065	Economy	12400.00
0005432621105	28065	Economy	12400.00
0005432621114	28065	Economy	12400.00
0005432621152	28065	Economy	12400.00
0005432621154	28065	Economy	12400.00
0005432621078	28065	Economy	12400.00
0005432862416	28065	Economy	12400.00
0005434097486	11703	Economy	11300.00
0005434097496	13065	Economy	11300.00
0005433452768	31072	Economy	8400.00
0005433452770	31072	Economy	8400.00
0005433452769	31072	Economy	8400.00
0005433451649	31072	Economy	8400.00
0005433451648	31072	Economy	8400.00
0005433451647	31072	Economy	8400.00
0005433452741	31363	Economy	8400.00
0005433454888	31363	Economy	8400.00
0005433454894	31363	Economy	8400.00
0005433452742	31363	Economy	8400.00
0005433452751	31363	Economy	8400.00
0005434142639	12025	Economy	6600.00
0005434142621	12025	Economy	6600.00
0005433134166	12025	Economy	6600.00
0005433134173	12025	Economy	6600.00
0005434184681	12025	Economy	6600.00
0005433134183	12025	Economy	6600.00
0005433129317	12025	Economy	6600.00
0005433134162	12025	Economy	6600.00
0005434142622	12025	Economy	6600.00
0005433129299	12025	Economy	6600.00
0005434142637	12025	Economy	6600.00
0005433134167	12025	Economy	6600.00
0005434142638	12025	Economy	6600.00
0005433134157	12025	Economy	6600.00
0005433134160	12025	Economy	6600.00
0005434184674	12025	Economy	6600.00
0005434142620	12025	Economy	6600.00
0005434184676	12025	Economy	6600.00
0005433129316	12025	Economy	6600.00
0005433129315	12025	Economy	6600.00
0005434142624	12025	Economy	6600.00
0005433134185	12025	Economy	6600.00
0005433134170	12025	Economy	6600.00
0005433134182	12025	Economy	6600.00
0005433129300	12025	Economy	6600.00
0005434184680	12025	Economy	6600.00
0005433129314	12025	Economy	6600.00
0005434142623	12025	Economy	6600.00
0005433131772	29865	Economy	7200.00
0005433134205	29865	Economy	7200.00
0005434184694	29865	Economy	6600.00
0005434326273	29865	Economy	6600.00
0005434184695	29865	Economy	6600.00
0005433131775	29865	Economy	6600.00
0005433134204	29865	Economy	6600.00
0005434184693	29865	Economy	6600.00
0005434142665	29865	Economy	6600.00
0005433131774	29865	Economy	6600.00
0005434142662	29865	Economy	6600.00
0005434142663	29865	Economy	6600.00
0005434183608	29865	Economy	6600.00
0005434142664	29865	Economy	6600.00
0005433134202	29865	Economy	6600.00
0005434326272	29865	Economy	6600.00
0005434183609	29865	Economy	6600.00
0005433131773	29865	Economy	6600.00
0005433134203	29865	Economy	6600.00
0005435697730	16479	Economy	19900.00
0005435935072	16479	Economy	19900.00
0005435697723	16479	Economy	19900.00
0005435697720	16479	Economy	18100.00
0005435697731	16479	Economy	18100.00
0005435697713	16479	Economy	18100.00
0005435697727	16479	Economy	18100.00
0005435697716	16479	Economy	18100.00
0005435697722	16479	Economy	18100.00
0005435697733	16479	Economy	18100.00
0005435697712	16479	Economy	18100.00
0005435697725	16479	Economy	18100.00
0005435697734	16479	Economy	18100.00
0005435697707	16479	Economy	18100.00
0005435697709	16479	Economy	18100.00
0005435697711	16479	Economy	18100.00
0005435697715	16479	Economy	18100.00
0005435935060	16479	Economy	18100.00
0005435697718	16479	Economy	18100.00
0005435697728	16479	Economy	18100.00
0005435697719	16479	Economy	18100.00
0005435697705	16479	Economy	18100.00
0005435697726	16479	Economy	18100.00
0005435697729	16479	Economy	18100.00
0005435697710	16479	Economy	18100.00
0005435697724	16479	Economy	18100.00
0005435697717	16479	Economy	18100.00
0005435697732	16479	Economy	18100.00
0005435697714	16479	Economy	18100.00
0005435697721	16479	Economy	18100.00
0005435697708	16479	Economy	18100.00
0005435697706	16479	Economy	18100.00
0005435697544	24733	Economy	19900.00
0005435935088	24733	Economy	19900.00
0005435697524	24733	Economy	18100.00
0005435697466	24733	Economy	18100.00
0005435697454	24733	Economy	18100.00
0005435697532	24733	Economy	18100.00
0005435697465	24733	Economy	18100.00
0005435935089	24733	Economy	18100.00
0005435697642	24733	Economy	18100.00
0005435697357	24733	Economy	18100.00
0005435697456	24733	Economy	18100.00
0005435935090	24733	Economy	18100.00
0005435697469	24733	Economy	18100.00
0005435697543	24733	Economy	18100.00
0005435697547	24733	Economy	18100.00
0005435697468	24733	Economy	18100.00
0005435697508	24733	Economy	18100.00
0005435935091	24733	Economy	18100.00
0005435697560	24733	Economy	18100.00
0005435697523	24733	Economy	18100.00
0005435697643	24733	Economy	18100.00
0005435697453	24733	Economy	18100.00
0005435697549	24733	Economy	18100.00
0005435697492	24733	Economy	18100.00
0005435935092	24733	Economy	18100.00
0005432968855	18799	Economy	4400.00
0005432968861	18799	Economy	4400.00
0005433724867	18799	Economy	4400.00
0005433724869	18799	Economy	4400.00
0005433724866	18799	Economy	4400.00
0005433724868	18799	Economy	4400.00
0005433724865	18799	Economy	4400.00
0005433724844	21643	Economy	4400.00
0005433724845	21643	Economy	4400.00
0005433724835	21643	Economy	4400.00
0005432968876	21643	Economy	4400.00
0005432968875	21643	Economy	4400.00
0005434139373	7338	Business	23100.00
0005434139319	7338	Business	23100.00
0005434139363	7338	Business	23100.00
0005434139337	7338	Business	23100.00
0005434139325	7338	Business	23100.00
0005434139362	7338	Business	23100.00
0005434139339	7338	Business	23100.00
0005434139378	7338	Business	23100.00
0005434139293	7338	Business	23100.00
0005434139336	7338	Business	23100.00
0005434139371	7338	Business	23100.00
0005434139353	7338	Business	23100.00
0005434139374	7338	Economy	7700.00
0005434139365	7338	Economy	7700.00
0005434139302	7338	Economy	7700.00
0005434139354	7338	Economy	7700.00
0005434139318	7338	Economy	7700.00
0005434139303	7338	Economy	7700.00
0005434139294	7338	Economy	7700.00
0005434139345	7338	Economy	7700.00
0005434139347	7338	Economy	7700.00
0005434139361	7338	Economy	7700.00
0005434139313	7338	Economy	8500.00
0005434139310	7338	Economy	8500.00
0005434139338	7338	Economy	8500.00
0005434087584	7338	Economy	8500.00
0005434139368	7338	Economy	8500.00
0005434139297	7338	Economy	7700.00
0005434139320	7338	Economy	7700.00
0005434139333	7338	Economy	7700.00
0005434139323	7338	Economy	7700.00
0005434139327	7338	Economy	7700.00
0005434139317	7338	Economy	7700.00
0005434139309	7338	Economy	7700.00
0005434087586	7338	Economy	7700.00
0005434139305	7338	Economy	7700.00
0005434139292	7338	Economy	7700.00
0005434139316	7338	Economy	7700.00
0005434139321	7338	Economy	7700.00
0005434139334	7338	Economy	7700.00
0005434139304	7338	Economy	7700.00
0005434139375	7338	Economy	7700.00
0005434139306	7338	Economy	7700.00
0005434139377	7338	Economy	7700.00
0005434139360	7338	Economy	7700.00
0005434139357	7338	Economy	7700.00
0005434139359	7338	Economy	7700.00
0005434139311	7338	Economy	7700.00
0005434139349	7338	Economy	7700.00
0005434139308	7338	Economy	7700.00
0005434139364	7338	Economy	7700.00
0005434139351	7338	Economy	7700.00
0005434087585	7338	Economy	7700.00
0005434139299	7338	Economy	7700.00
0005434139295	7338	Economy	7700.00
0005434139346	7338	Economy	7700.00
0005434139358	7338	Economy	7700.00
0005434139380	7338	Economy	7700.00
0005434139331	7338	Economy	7700.00
0005434139301	7338	Economy	7700.00
0005434139352	7338	Economy	7700.00
0005434139314	7338	Economy	7700.00
0005434139326	7338	Economy	7700.00
0005434139341	7338	Economy	7700.00
0005434139379	7338	Economy	7700.00
0005434139367	7338	Economy	7700.00
0005434087587	7338	Economy	7700.00
0005434139370	7338	Economy	7700.00
0005434139335	7338	Economy	7700.00
0005434139312	7338	Economy	7700.00
0005434139344	7338	Economy	7700.00
0005434139342	7338	Economy	7700.00
0005434139340	7338	Economy	7700.00
0005434139329	7338	Economy	7700.00
0005434139376	7338	Economy	7700.00
0005434139355	7338	Economy	7700.00
0005434139382	7338	Economy	7700.00
0005434139296	7338	Economy	7700.00
0005434139322	7338	Economy	7700.00
0005434139356	7338	Economy	7700.00
0005434139350	7338	Economy	7700.00
0005434139324	7338	Economy	7700.00
0005434139366	7338	Economy	7700.00
0005434139332	7338	Economy	7700.00
0005434139298	7338	Economy	7700.00
0005434139381	7338	Economy	7700.00
0005434139372	7338	Economy	7700.00
0005434139315	7338	Economy	7700.00
0005434139307	7338	Economy	7700.00
0005434139328	7338	Economy	7700.00
0005434139300	7338	Economy	7700.00
0005434139348	7338	Economy	7700.00
0005434139369	7338	Economy	7700.00
0005434139343	7338	Economy	7700.00
0005434087583	7338	Economy	7700.00
0005434139330	7338	Economy	7700.00
0005434087539	28526	Business	23100.00
0005434138256	28526	Business	23100.00
0005434138561	28526	Business	23100.00
0005434138396	28526	Business	23100.00
0005434138563	28526	Business	23100.00
0005434138595	28526	Business	23100.00
0005434138291	28526	Business	23100.00
0005434138580	28526	Business	23100.00
0005434138836	28526	Business	23100.00
0005434138772	28526	Business	23100.00
0005434138807	28526	Business	23100.00
0005434138190	28526	Economy	7700.00
0005434138137	28526	Economy	7700.00
0005434138460	28526	Economy	7700.00
0005434138188	28526	Economy	7700.00
0005434138501	28526	Economy	7700.00
0005434138621	28526	Economy	7700.00
0005434138562	28526	Economy	7700.00
0005434138365	28526	Economy	7700.00
0005434138808	28526	Economy	7700.00
0005434138478	28526	Economy	7700.00
0005434138358	28526	Economy	8500.00
0005434138517	28526	Economy	8500.00
0005434138518	28526	Economy	8500.00
0005434138482	28526	Economy	8500.00
0005434138505	28526	Economy	8500.00
0005434138255	28526	Economy	7700.00
0005434138794	28526	Economy	7700.00
0005434138582	28526	Economy	7700.00
0005434138675	28526	Economy	7700.00
0005434138793	28526	Economy	7700.00
0005434138366	28526	Economy	7700.00
0005434138823	28526	Economy	7700.00
0005434138362	28526	Economy	7700.00
0005434138477	28526	Economy	7700.00
0005434138782	28526	Economy	7700.00
0005434138835	28526	Economy	7700.00
0005434138795	28526	Economy	7700.00
0005434138459	28526	Economy	7700.00
0005434138708	28526	Economy	7700.00
0005434138136	28526	Economy	7700.00
0005434138766	28526	Economy	7700.00
0005434138534	28526	Economy	7700.00
0005434138792	28526	Economy	7700.00
0005434138357	28526	Economy	7700.00
0005434138127	28526	Economy	7700.00
0005434138535	28526	Economy	7700.00
0005434138344	28526	Economy	7700.00
0005434138659	28526	Economy	7700.00
0005434138803	28526	Economy	7700.00
0005434138302	28526	Economy	7700.00
0005434138292	28526	Economy	7700.00
0005434138676	28526	Economy	7700.00
0005434138751	28526	Economy	7700.00
0005434138401	28526	Economy	7700.00
0005434087538	28526	Economy	7700.00
0005434138567	28526	Economy	7700.00
0005434138674	28526	Economy	7700.00
0005434138671	28526	Economy	7700.00
0005434138657	28526	Economy	7700.00
0005434138768	28526	Economy	7700.00
0005434138485	28526	Economy	7700.00
0005434138658	28526	Economy	7700.00
0005434138816	28526	Economy	7700.00
0005434138446	28526	Economy	7700.00
0005434138697	28526	Economy	7700.00
0005434138719	28526	Economy	7700.00
0005434138404	28526	Economy	7700.00
0005434138467	28526	Economy	7700.00
0005434138257	28526	Economy	7700.00
0005434138579	28526	Economy	7700.00
0005434138367	28526	Economy	7700.00
0005434138490	28526	Economy	7700.00
0005434138189	28526	Economy	7700.00
0005434138834	28526	Economy	7700.00
0005434138228	28526	Economy	7700.00
0005434138436	28526	Economy	7700.00
0005434138514	28526	Economy	7700.00
0005434087543	28526	Economy	7700.00
0005434138489	28526	Economy	7700.00
0005434138452	28526	Economy	7700.00
0005434087540	28526	Economy	7700.00
0005434138441	28526	Economy	7700.00
0005434138364	28526	Economy	7700.00
0005434138581	28526	Economy	7700.00
0005434138515	28526	Economy	7700.00
0005434138229	28526	Economy	7700.00
0005434138566	28526	Economy	7700.00
0005434138203	28526	Economy	7700.00
0005434138825	28526	Economy	7700.00
0005434138752	28526	Economy	7700.00
0005435808388	1926	Economy	23900.00
0005435808386	1926	Economy	23900.00
0005433407598	1926	Economy	23900.00
0005434610281	1926	Economy	21700.00
0005433407571	1926	Economy	21700.00
0005433407597	1926	Economy	21700.00
0005435808389	1926	Economy	21700.00
0005435808387	1926	Economy	21700.00
0005434610280	1926	Economy	21700.00
0005435808382	1926	Economy	21700.00
0005435808384	1926	Economy	21700.00
0005434610282	1926	Economy	21700.00
0005435808383	1926	Economy	21700.00
0005435808385	1926	Economy	21700.00
0005433407566	1926	Economy	21700.00
0005435808390	1926	Economy	21700.00
0005435808262	23086	Economy	23900.00
0005433407632	23086	Economy	23900.00
0005433407636	23086	Economy	21700.00
0005435808279	23086	Economy	21700.00
0005435808278	23086	Economy	21700.00
0005433407635	23086	Economy	21700.00
0005435808253	23086	Economy	21700.00
0005435808240	23086	Economy	21700.00
0005435808249	23086	Economy	21700.00
0005435808288	23086	Economy	21700.00
0005434610250	23086	Economy	21700.00
0005435808263	23086	Economy	21700.00
0005435808251	23086	Economy	21700.00
0005435808259	23086	Economy	21700.00
0005435808250	23086	Economy	21700.00
0005433407628	23086	Economy	21700.00
0005434610251	23086	Economy	21700.00
0005435808296	23086	Economy	21700.00
0005433407633	23086	Economy	21700.00
0005435808248	23086	Economy	21700.00
0005434610241	23086	Economy	21700.00
0005435808267	23086	Economy	21700.00
0005435808246	23086	Economy	21700.00
0005435808299	23086	Economy	21700.00
0005433407629	23086	Economy	21700.00
0005435808264	23086	Economy	21700.00
0005435808258	23086	Economy	21700.00
0005433407631	23086	Economy	21700.00
0005433407634	23086	Economy	21700.00
0005433407627	23086	Economy	21700.00
0005435808257	23086	Economy	21700.00
0005435808255	23086	Economy	21700.00
0005435808295	23086	Economy	21700.00
0005435808247	23086	Economy	21700.00
0005433407637	23086	Economy	21700.00
0005435808300	23086	Economy	21700.00
0005433407630	23086	Economy	21700.00
0005435808238	23086	Economy	21700.00
0005435808254	23086	Economy	21700.00
0005435808252	23086	Economy	21700.00
0005434504278	16700	Economy	7600.00
0005434504347	16700	Economy	7600.00
0005434504463	16700	Economy	7600.00
0005434504057	16700	Economy	7600.00
0005434504404	16700	Economy	6900.00
0005434504359	16700	Economy	6900.00
0005434504441	16700	Economy	6900.00
0005434504143	16700	Economy	6900.00
0005434504264	16700	Economy	6900.00
0005434504222	16700	Economy	6900.00
0005434504276	16700	Economy	6900.00
0005434504331	16700	Economy	6900.00
0005434504360	16700	Economy	6900.00
0005434504380	16700	Economy	6900.00
0005434504268	16700	Economy	6900.00
0005434504381	16700	Economy	6900.00
0005434504281	16700	Economy	6900.00
0005434504460	16700	Economy	6900.00
0005434504265	16700	Economy	6900.00
0005434504260	16700	Economy	6900.00
0005434504277	16700	Economy	6900.00
0005434504332	16700	Economy	6900.00
0005434504263	16700	Economy	6900.00
0005434504157	16700	Economy	6900.00
0005434504291	16700	Economy	6900.00
0005434504142	16700	Economy	6900.00
0005434504267	16700	Economy	6900.00
0005434504266	16700	Economy	6900.00
0005434504240	16700	Economy	6900.00
0005434504348	16700	Economy	6900.00
0005434504221	16700	Economy	6900.00
0005434504362	16700	Economy	6900.00
0005434504415	16700	Economy	6900.00
0005434504440	16700	Economy	6900.00
0005434504421	16700	Economy	6900.00
0005434504293	16700	Economy	6900.00
0005434504239	16700	Economy	6900.00
0005434504259	16700	Economy	6900.00
0005434504414	16700	Economy	6900.00
0005434504439	16700	Economy	6900.00
0005434504284	16700	Economy	6900.00
0005434504361	16700	Economy	6900.00
0005434504280	16700	Economy	6900.00
0005434504195	16700	Economy	6900.00
0005434504369	16700	Economy	6900.00
0005434504388	16700	Economy	6900.00
0005434504370	16700	Economy	6900.00
0005434504341	16700	Economy	6900.00
0005434504403	16700	Economy	6900.00
0005434504365	16700	Economy	6900.00
0005434504675	22895	Economy	7600.00
0005434504684	22895	Economy	7600.00
0005434504687	22895	Economy	7600.00
0005434504697	22895	Economy	7600.00
0005434504672	22895	Economy	6900.00
0005434504689	22895	Economy	6900.00
0005434504676	22895	Economy	6900.00
0005434504686	22895	Economy	6900.00
0005434504703	22895	Economy	6900.00
0005434504678	22895	Economy	6900.00
0005434504671	22895	Economy	6900.00
0005434504665	22895	Economy	6900.00
0005434504669	22895	Economy	6900.00
0005434504699	22895	Economy	6900.00
0005434504680	22895	Economy	6900.00
0005434504694	22895	Economy	6900.00
0005434504666	22895	Economy	6900.00
0005434504681	22895	Economy	6900.00
0005434504667	22895	Economy	6900.00
0005434504700	22895	Economy	6900.00
0005434504677	22895	Economy	6900.00
0005434504702	22895	Economy	6900.00
0005434504688	22895	Economy	6900.00
0005434504679	22895	Economy	6900.00
0005434504682	22895	Economy	6900.00
0005434504673	22895	Economy	6900.00
0005434504693	22895	Economy	6900.00
0005434504690	22895	Economy	6900.00
0005434504664	22895	Economy	6900.00
0005434504691	22895	Economy	6900.00
0005434504670	22895	Economy	6900.00
0005434504698	22895	Economy	6900.00
0005434504668	22895	Economy	6900.00
0005434504695	22895	Economy	6900.00
0005434504692	22895	Economy	6900.00
0005434504696	22895	Economy	6900.00
0005434504685	22895	Economy	6900.00
0005434504674	22895	Economy	6900.00
0005434504701	22895	Economy	6900.00
0005434504683	22895	Economy	6900.00
0005435078560	2194	Economy	7700.00
0005433266778	2194	Economy	7000.00
0005435078559	2194	Economy	7000.00
0005433266791	2194	Economy	7000.00
0005433266746	2194	Economy	7000.00
0005435078565	2194	Economy	7000.00
0005435078564	2194	Economy	7000.00
0005435078566	2194	Economy	7000.00
0005435078570	2194	Economy	7000.00
0005435078569	2194	Economy	7000.00
0005433266755	2194	Economy	7000.00
0005435078563	2194	Economy	7000.00
0005433266751	2194	Economy	7000.00
0005435078567	2194	Economy	7000.00
0005435078562	2194	Economy	7000.00
0005435078568	2194	Economy	7000.00
0005435078561	2194	Economy	7000.00
0005433266784	2194	Economy	7000.00
0005435078572	2194	Economy	7000.00
0005433266779	2194	Economy	7000.00
0005433266736	2194	Economy	7000.00
0005433266729	2194	Economy	7000.00
0005435078571	2194	Economy	7000.00
0005435078437	24343	Economy	7700.00
0005433266855	24343	Economy	7700.00
0005435078375	24343	Economy	7000.00
0005435078376	24343	Economy	7000.00
0005435078368	24343	Economy	7000.00
0005435078427	24343	Economy	7000.00
0005433266857	24343	Economy	7000.00
0005435078487	24343	Economy	7000.00
0005433266856	24343	Economy	7000.00
0005435078348	24343	Economy	7000.00
0005435078436	24343	Economy	7000.00
0005433266860	24343	Economy	7000.00
0005435078419	24343	Economy	7000.00
0005435078460	24343	Economy	7000.00
0005435078416	24343	Economy	7000.00
0005433266858	24343	Economy	7000.00
0005435078438	24343	Economy	7000.00
0005435078421	24343	Economy	7000.00
0005433266854	24343	Economy	7000.00
0005435078425	24343	Economy	7000.00
0005435078422	24343	Economy	7000.00
0005435078456	24343	Economy	7000.00
0005435078377	24343	Economy	7000.00
0005433266853	24343	Economy	7000.00
0005435078420	24343	Economy	7000.00
0005435078426	24343	Economy	7000.00
0005433266859	24343	Economy	7000.00
0005433266861	24343	Economy	7000.00
0005435078417	24343	Economy	7000.00
0005434988895	6624	Economy	9800.00
0005435803301	6624	Economy	9800.00
0005435464527	6624	Economy	9800.00
0005435803303	6624	Economy	9800.00
0005435464526	6624	Economy	9800.00
0005435464529	6624	Economy	9800.00
0005434988899	6624	Economy	9800.00
0005434988898	6624	Economy	9800.00
0005435803302	6624	Economy	9800.00
0005435464528	6624	Economy	9800.00
0005435464520	6624	Economy	9800.00
0005435803304	6624	Economy	9800.00
0005434988897	6624	Economy	9800.00
0005435464519	6624	Economy	9800.00
0005434988894	6624	Economy	9800.00
0005434988896	6624	Economy	9800.00
0005435803263	23598	Economy	10800.00
0005435803262	23598	Economy	9800.00
0005434988737	23598	Economy	9800.00
0005434988757	23598	Economy	9800.00
0005434988762	23598	Economy	9800.00
0005435803282	23598	Economy	9800.00
0005434988746	23598	Economy	9800.00
0005434988742	23598	Economy	9800.00
0005435464538	23598	Economy	9800.00
0005434988729	23598	Economy	9800.00
0005434988763	23598	Economy	9800.00
0005435803281	23598	Economy	9800.00
0005434988747	23598	Economy	9800.00
0005435803280	23598	Economy	9800.00
0005434988758	23598	Economy	9800.00
0005435464539	23598	Economy	9800.00
0005434988764	23598	Economy	9800.00
0005435464537	23598	Economy	9800.00
0005432383738	30470	Business	9900.00
0005433450280	30470	Business	9900.00
0005432383746	30470	Business	9900.00
0005432383739	30470	Business	9900.00
0005432383725	30470	Business	9900.00
0005432383722	30470	Business	9900.00
0005433450285	30470	Business	9900.00
0005433450289	30470	Business	9900.00
0005432383740	30470	Business	9900.00
0005432383735	30470	Business	9900.00
0005433450290	30470	Economy	3300.00
0005433450292	30470	Economy	3300.00
0005432383744	30470	Economy	3300.00
0005432383713	30470	Economy	3300.00
0005432383717	30470	Economy	3300.00
0005432383745	30470	Economy	3600.00
0005433450281	30470	Economy	3600.00
0005432383728	30470	Economy	3600.00
0005432383718	30470	Economy	3600.00
0005432383747	30470	Economy	3300.00
0005433450296	30470	Economy	3300.00
0005432383715	30470	Economy	3300.00
0005433454907	30470	Economy	3300.00
0005432383714	30470	Economy	3300.00
0005433450278	30470	Economy	3300.00
0005433450291	30470	Economy	3300.00
0005433450288	30470	Economy	3300.00
0005433450294	30470	Economy	3300.00
0005432383730	30470	Economy	3300.00
0005432383734	30470	Economy	3300.00
0005432383742	30470	Economy	3300.00
0005432383720	30470	Economy	3300.00
0005432383748	30470	Economy	3300.00
0005433450293	30470	Economy	3300.00
0005433454905	30470	Economy	3300.00
0005433450274	30470	Economy	3300.00
0005433453788	30470	Economy	3300.00
0005433450283	30470	Economy	3300.00
0005433450282	30470	Economy	3300.00
0005433450277	30470	Economy	3300.00
0005432383724	30470	Economy	3300.00
0005432383723	30470	Economy	3300.00
0005432383709	30470	Economy	3300.00
0005433450279	30470	Economy	3300.00
0005433450284	30470	Economy	3300.00
0005432383737	30470	Economy	3300.00
0005432383741	30470	Economy	3300.00
0005433453789	30470	Economy	3300.00
0005432383727	30470	Economy	3300.00
0005432383743	30470	Economy	3300.00
0005432383726	30470	Economy	3300.00
0005433450275	30470	Economy	3300.00
0005433450287	30470	Economy	3300.00
0005432383710	30470	Economy	3300.00
0005432383732	30470	Economy	3300.00
0005432383721	30470	Economy	3300.00
0005433450276	30470	Economy	3300.00
0005432383711	30470	Economy	3300.00
0005432383719	30470	Economy	3300.00
0005432383731	30470	Economy	3300.00
0005432383733	30470	Economy	3300.00
0005432383729	30470	Economy	3300.00
0005433454906	30470	Economy	3300.00
0005432383736	30470	Economy	3300.00
0005433450286	30470	Economy	3300.00
0005432383716	30470	Economy	3300.00
0005432383749	30470	Economy	3300.00
0005433450295	30470	Economy	3300.00
0005432383712	30470	Economy	3300.00
0005432383403	31299	Business	9900.00
0005433450032	31299	Business	9900.00
0005432383266	31299	Business	9900.00
0005433451633	31299	Business	9900.00
0005433450137	31299	Business	9900.00
0005432383267	31299	Business	9900.00
0005432383140	31299	Business	9900.00
0005433450067	31299	Business	9900.00
0005432383236	31299	Business	9900.00
0005432383326	31299	Economy	3300.00
0005432383523	31299	Economy	3300.00
0005432383233	31299	Economy	3300.00
0005432383421	31299	Economy	3300.00
0005433450033	31299	Economy	3300.00
0005432383375	31299	Economy	3600.00
0005432383444	31299	Economy	3600.00
0005432383368	31299	Economy	3600.00
0005432383402	31299	Economy	3300.00
0005433451626	31299	Economy	3300.00
0005433451636	31299	Economy	3300.00
0005432383376	31299	Economy	3300.00
0005432383440	31299	Economy	3300.00
0005433450066	31299	Economy	3300.00
0005433450085	31299	Economy	3300.00
0005433451630	31299	Economy	3300.00
0005432383399	31299	Economy	3300.00
0005433450080	31299	Economy	3300.00
0005432383229	31299	Economy	3300.00
0005432383230	31299	Economy	3300.00
0005433451628	31299	Economy	3300.00
0005432383522	31299	Economy	3300.00
0005433453777	31299	Economy	3300.00
0005432383274	31299	Economy	3300.00
0005432383302	31299	Economy	3300.00
0005432383439	31299	Economy	3300.00
0005432383235	31299	Economy	3300.00
0005432383333	31299	Economy	3300.00
0005432383261	31299	Economy	3300.00
0005432383265	31299	Economy	3300.00
0005432383400	31299	Economy	3300.00
0005433451640	31299	Economy	3300.00
0005432383190	31299	Economy	3300.00
0005432383139	31299	Economy	3300.00
0005432383279	31299	Economy	3300.00
0005432383297	31299	Economy	3300.00
0005432383275	31299	Economy	3300.00
0005433450004	31299	Economy	3300.00
0005432383234	31299	Economy	3300.00
0005433453772	31299	Economy	3300.00
0005432383314	31299	Economy	3300.00
0005432383315	31299	Economy	3300.00
0005433450103	31299	Economy	3300.00
0005432383273	31299	Economy	3300.00
0005433126865	10758	Economy	17100.00
0005435304191	10758	Economy	15600.00
0005433131731	10758	Economy	15600.00
0005433131732	10758	Economy	15600.00
0005433131725	10758	Economy	15600.00
0005433131704	10758	Economy	15600.00
0005433131726	10758	Economy	15600.00
0005433131707	10758	Economy	15600.00
0005435304174	10758	Economy	15600.00
0005435299788	10758	Economy	15600.00
0005435304175	10758	Economy	15600.00
0005433126861	10758	Economy	15600.00
0005433126863	10758	Economy	15600.00
0005433126859	10758	Economy	15600.00
0005435299802	10758	Economy	15600.00
0005433129346	29742	Economy	17100.00
0005435302272	29742	Economy	17100.00
0005435302271	29742	Economy	15600.00
0005435299849	29742	Economy	15600.00
0005435299848	29742	Economy	15600.00
0005435302269	29742	Economy	15600.00
0005433126913	29742	Economy	15600.00
0005435299847	29742	Economy	15600.00
0005435302270	29742	Economy	15600.00
0005433126914	29742	Economy	15600.00
0005435299850	29742	Economy	15600.00
0005433129347	29742	Economy	15600.00
0005433129345	29742	Economy	15600.00
0005433126916	29742	Economy	15600.00
0005433126915	29742	Economy	15600.00
0005434287617	2427	Economy	17200.00
0005434287616	2427	Economy	17200.00
0005434287612	2427	Economy	17200.00
0005434287609	2427	Economy	15700.00
0005434287606	2427	Economy	15700.00
0005433110091	2427	Economy	15700.00
0005434287601	2427	Economy	15700.00
0005434287607	2427	Economy	15700.00
0005433110100	2427	Economy	15700.00
0005434287611	2427	Economy	15700.00
0005433110130	2427	Economy	15700.00
0005433110067	2427	Economy	15700.00
0005434287614	2427	Economy	15700.00
0005434287613	2427	Economy	15700.00
0005434287600	2427	Economy	15700.00
0005433110175	2427	Economy	15700.00
0005433110128	2427	Economy	15700.00
0005433110115	2427	Economy	15700.00
0005434287605	2427	Economy	15700.00
0005434287618	2427	Economy	15700.00
0005433110181	2427	Economy	15700.00
0005434287604	2427	Economy	15700.00
0005433110125	2427	Economy	15700.00
0005434287602	2427	Economy	15700.00
0005433110138	2427	Economy	15700.00
0005434287619	2427	Economy	15700.00
0005433110127	2427	Economy	15700.00
0005433110176	2427	Economy	15700.00
0005433110126	2427	Economy	15700.00
0005433110137	2427	Economy	15700.00
0005432264510	2427	Economy	15700.00
0005434287599	2427	Economy	15700.00
0005433110174	2427	Economy	15700.00
0005434287598	2427	Economy	15700.00
0005432264511	2427	Economy	15700.00
0005434287615	2427	Economy	15700.00
0005434287610	2427	Economy	15700.00
0005433110180	2427	Economy	15700.00
0005434287608	2427	Economy	15700.00
0005434287603	2427	Economy	15700.00
0005434287515	26829	Economy	17200.00
0005433110231	26829	Economy	17200.00
0005433110222	26829	Economy	15700.00
0005434287425	26829	Economy	15700.00
0005433110223	26829	Economy	15700.00
0005434287378	26829	Economy	15700.00
0005433110230	26829	Economy	15700.00
0005434287458	26829	Economy	15700.00
0005434287379	26829	Economy	15700.00
0005434287423	26829	Economy	15700.00
0005434287404	26829	Economy	15700.00
0005434287424	26829	Economy	15700.00
0005433110225	26829	Economy	15700.00
0005434287456	26829	Economy	15700.00
0005433110224	26829	Economy	15700.00
0005433110234	26829	Economy	15700.00
0005434287422	26829	Economy	15700.00
0005434287457	26829	Economy	15700.00
0005433110232	26829	Economy	15700.00
0005434287397	26829	Economy	15700.00
0005433110227	26829	Economy	15700.00
0005434287483	26829	Economy	15700.00
0005433110233	26829	Economy	15700.00
0005434287403	26829	Economy	15700.00
0005434287482	26829	Economy	15700.00
0005434287499	26829	Economy	15700.00
0005433110221	26829	Economy	15700.00
0005434287393	26829	Economy	15700.00
0005433110228	26829	Economy	15700.00
0005434287396	26829	Economy	15700.00
0005433110229	26829	Economy	15700.00
0005433110226	26829	Economy	15700.00
0005435856267	25451	Economy	22800.00
0005435856265	25451	Economy	22800.00
0005434269104	25451	Economy	22800.00
0005435856266	25451	Economy	22800.00
0005434269108	25451	Economy	22800.00
0005434269107	25451	Economy	22800.00
0005435856264	25451	Economy	22800.00
0005434269103	25451	Economy	22800.00
0005434273101	26656	Economy	25000.00
0005434273100	26656	Economy	25000.00
0005435856230	26656	Economy	22800.00
0005435856195	26656	Economy	22800.00
0005435856231	26656	Economy	22800.00
0005435854061	26656	Economy	22800.00
0005435856218	26656	Economy	22800.00
0005435856232	26656	Economy	22800.00
0005435856194	26656	Economy	22800.00
0005435856239	26656	Economy	22800.00
0005435860494	4769	Economy	19400.00
0005433869008	4769	Economy	19400.00
0005433869015	4769	Economy	19400.00
0005433869002	4769	Economy	19400.00
0005433869005	4769	Economy	17600.00
0005433869019	4769	Economy	17600.00
0005433869025	4769	Economy	17600.00
0005433869027	4769	Economy	17600.00
0005433869018	4769	Economy	17600.00
0005435860496	4769	Economy	17600.00
0005433869000	4769	Economy	17600.00
0005433868997	4769	Economy	17600.00
0005433869030	4769	Economy	17600.00
0005435860495	4769	Economy	17600.00
0005433868999	4769	Economy	17600.00
0005433869017	4769	Economy	17600.00
0005433869034	4769	Economy	17600.00
0005433869035	4769	Economy	17600.00
0005435860501	4769	Economy	17600.00
0005433869004	4769	Economy	17600.00
0005433869014	4769	Economy	17600.00
0005435860507	4769	Economy	17600.00
0005433869037	4769	Economy	17600.00
0005433869033	4769	Economy	17600.00
0005433869013	4769	Economy	17600.00
0005433869016	4769	Economy	17600.00
0005433869028	4769	Economy	17600.00
0005433869023	4769	Economy	17600.00
0005433868998	4769	Economy	17600.00
0005433869032	4769	Economy	17600.00
0005433869031	4769	Economy	17600.00
0005433869003	4769	Economy	17600.00
0005433869021	4769	Economy	17600.00
0005433869020	4769	Economy	17600.00
0005433869026	4769	Economy	17600.00
0005433869009	4769	Economy	17600.00
0005435860500	4769	Economy	17600.00
0005433869006	4769	Economy	17600.00
0005433869011	4769	Economy	17600.00
0005433869029	4769	Economy	17600.00
0005433869036	4769	Economy	17600.00
0005433869007	4769	Economy	17600.00
0005433869022	4769	Economy	17600.00
0005433869001	4769	Economy	17600.00
0005433869024	4769	Economy	17600.00
0005433869012	4769	Economy	17600.00
0005433868996	4769	Economy	17600.00
0005433869010	4769	Economy	17600.00
0005433868589	32569	Economy	19400.00
0005433868660	32569	Economy	19400.00
0005433868622	32569	Economy	19400.00
0005433868818	32569	Economy	17600.00
0005433868697	32569	Economy	17600.00
0005433868638	32569	Economy	17600.00
0005435860526	32569	Economy	17600.00
0005433868684	32569	Economy	17600.00
0005433868482	32569	Economy	17600.00
0005433868661	32569	Economy	17600.00
0005433868643	32569	Economy	17600.00
0005433868590	32569	Economy	17600.00
0005435860525	32569	Economy	17600.00
0005433868592	32569	Economy	17600.00
0005433868477	32569	Economy	17600.00
0005433868566	32569	Economy	17600.00
0005433868655	32569	Economy	17600.00
0005433868496	32569	Economy	17600.00
0005433868645	32569	Economy	17600.00
0005433868653	32569	Economy	17600.00
0005433868766	32569	Economy	17600.00
0005433868676	32569	Economy	17600.00
0005433868571	32569	Economy	17600.00
0005433868751	32569	Economy	17600.00
0005433868699	32569	Economy	17600.00
0005433868737	32569	Economy	17600.00
0005435860528	32569	Economy	17600.00
0005433868683	32569	Economy	17600.00
0005433868652	32569	Economy	17600.00
0005433868682	32569	Economy	17600.00
0005433868793	32569	Economy	17600.00
0005433868457	32569	Economy	17600.00
0005435860529	32569	Economy	17600.00
0005433868534	32569	Economy	17600.00
0005433868532	32569	Economy	17600.00
0005433868563	32569	Economy	17600.00
0005433868456	32569	Economy	17600.00
0005433868521	32569	Economy	17600.00
0005433868604	32569	Economy	17600.00
0005435860527	32569	Economy	17600.00
0005433868605	32569	Economy	17600.00
0005433868723	32569	Economy	17600.00
0005433868765	32569	Economy	17600.00
0005433868644	32569	Economy	17600.00
0005433868675	32569	Economy	17600.00
0005433868621	32569	Economy	17600.00
0005435911505	3426	Economy	24800.00
0005434663607	3426	Economy	22600.00
0005434663606	3426	Economy	22600.00
0005434663609	3426	Economy	22600.00
0005434663602	3426	Economy	22600.00
0005435911504	3426	Economy	22600.00
0005434663598	3426	Economy	22600.00
0005434461678	3426	Economy	22600.00
0005434460537	3426	Economy	22600.00
0005434663601	3426	Economy	22600.00
0005435911502	3426	Economy	22600.00
0005434663605	3426	Economy	22600.00
0005434663600	3426	Economy	22600.00
0005434663604	3426	Economy	22600.00
0005434663603	3426	Economy	22600.00
0005435911498	3426	Economy	22600.00
0005434663599	3426	Economy	22600.00
0005434663608	3426	Economy	22600.00
0005434461677	3426	Economy	22600.00
0005434663610	3426	Economy	22600.00
0005435911477	3426	Economy	22600.00
0005435911559	12493	Economy	24800.00
0005434663462	12493	Economy	22600.00
0005434663461	12493	Economy	22600.00
0005434663494	12493	Economy	22600.00
0005435911558	12493	Economy	22600.00
0005434663502	12493	Economy	22600.00
0005434663476	12493	Economy	22600.00
0005434663528	12493	Economy	22600.00
0005434663517	12493	Economy	22600.00
0005435911563	12493	Economy	22600.00
0005435911564	12493	Economy	22600.00
0005434663540	12493	Economy	22600.00
0005435911565	12493	Economy	22600.00
0005435911562	12493	Economy	22600.00
0005434663444	12493	Economy	22600.00
0005434663489	12493	Economy	22600.00
0005434663538	12493	Economy	22600.00
0005434663495	12493	Economy	22600.00
0005435911561	12493	Economy	22600.00
0005434663510	12493	Economy	22600.00
0005434663539	12493	Economy	22600.00
0005434663477	12493	Economy	22600.00
0005435911560	12493	Economy	22600.00
0005435860527	14515	Economy	18500.00
0005433868818	14515	Economy	18500.00
0005433868589	14515	Economy	18500.00
0005433868482	14515	Economy	16800.00
0005433868683	14515	Economy	16800.00
0005433868604	14515	Economy	16800.00
0005433868643	14515	Economy	16800.00
0005433868456	14515	Economy	16800.00
0005433868699	14515	Economy	16800.00
0005433868534	14515	Economy	16800.00
0005435860526	14515	Economy	16800.00
0005433868684	14515	Economy	16800.00
0005433868655	14515	Economy	16800.00
0005433868660	14515	Economy	16800.00
0005433868644	14515	Economy	16800.00
0005433868563	14515	Economy	16800.00
0005433868457	14515	Economy	16800.00
0005433868653	14515	Economy	16800.00
0005433868496	14515	Economy	16800.00
0005433868793	14515	Economy	16800.00
0005435860529	14515	Economy	16800.00
0005435860528	14515	Economy	16800.00
0005433868645	14515	Economy	16800.00
0005433868590	14515	Economy	16800.00
0005433868605	14515	Economy	16800.00
0005433868521	14515	Economy	16800.00
0005433868751	14515	Economy	16800.00
0005433868675	14515	Economy	16800.00
0005433868766	14515	Economy	16800.00
0005433868621	14515	Economy	16800.00
0005433868697	14515	Economy	16800.00
0005433868652	14515	Economy	16800.00
0005433868661	14515	Economy	16800.00
0005433868676	14515	Economy	16800.00
0005433868723	14515	Economy	16800.00
0005433868477	14515	Economy	16800.00
0005435860525	14515	Economy	16800.00
0005433868638	14515	Economy	16800.00
0005433868566	14515	Economy	16800.00
0005433868532	14515	Economy	16800.00
0005433868571	14515	Economy	16800.00
0005433868592	14515	Economy	16800.00
0005433868622	14515	Economy	16800.00
0005433868682	14515	Economy	16800.00
0005433868765	14515	Economy	16800.00
0005433868737	14515	Economy	16800.00
0005433868974	32663	Economy	18500.00
0005433868978	32663	Economy	18500.00
0005433868965	32663	Economy	18500.00
0005433868979	32663	Economy	16800.00
0005433868976	32663	Economy	16800.00
0005433868981	32663	Economy	16800.00
0005433868994	32663	Economy	16800.00
0005433868959	32663	Economy	16800.00
0005433868958	32663	Economy	16800.00
0005433868983	32663	Economy	16800.00
0005435860498	32663	Economy	16800.00
0005433868961	32663	Economy	16800.00
0005433868995	32663	Economy	16800.00
0005433868985	32663	Economy	16800.00
0005433868971	32663	Economy	16800.00
0005433868992	32663	Economy	16800.00
0005433868988	32663	Economy	16800.00
0005433868962	32663	Economy	16800.00
0005433868973	32663	Economy	16800.00
0005433868960	32663	Economy	16800.00
0005433868957	32663	Economy	16800.00
0005433868964	32663	Economy	16800.00
0005433868987	32663	Economy	16800.00
0005433868969	32663	Economy	16800.00
0005433868984	32663	Economy	16800.00
0005435860499	32663	Economy	16800.00
0005433868968	32663	Economy	16800.00
0005433868982	32663	Economy	16800.00
0005433868991	32663	Economy	16800.00
0005433868975	32663	Economy	16800.00
0005433868989	32663	Economy	16800.00
0005433868970	32663	Economy	16800.00
0005433868977	32663	Economy	16800.00
0005433868966	32663	Economy	16800.00
0005433868986	32663	Economy	16800.00
0005433868993	32663	Economy	16800.00
0005433868967	32663	Economy	16800.00
0005433868963	32663	Economy	16800.00
0005433868956	32663	Economy	16800.00
0005433868980	32663	Economy	16800.00
0005433868990	32663	Economy	16800.00
0005433868972	32663	Economy	16800.00
0005432799594	12102	Economy	4900.00
0005432799644	12102	Economy	4900.00
0005432799598	12102	Economy	4900.00
0005432799554	12102	Economy	4400.00
0005432799718	12102	Economy	4400.00
0005432799625	12102	Economy	4400.00
0005432799642	12102	Economy	4400.00
0005432799536	12102	Economy	4400.00
0005432799624	12102	Economy	4400.00
0005432799606	12102	Economy	4400.00
0005432799519	12102	Economy	4400.00
0005432799643	12102	Economy	4400.00
0005432799683	12102	Economy	4400.00
0005432799668	12102	Economy	4400.00
0005432799595	12102	Economy	4400.00
0005432799616	12102	Economy	4400.00
0005432799660	12102	Economy	4400.00
0005432799639	12102	Economy	4400.00
0005432799617	12102	Economy	4400.00
0005432799650	12102	Economy	4400.00
0005432799596	12102	Economy	4400.00
0005432799520	12102	Economy	4400.00
0005432799687	12102	Economy	4400.00
0005432799607	12102	Economy	4400.00
0005432799844	14808	Economy	4900.00
0005432799834	14808	Economy	4900.00
0005432799848	14808	Economy	4400.00
0005432799827	14808	Economy	4400.00
0005432799826	14808	Economy	4400.00
0005432799832	14808	Economy	4400.00
0005432799843	14808	Economy	4400.00
0005432799849	14808	Economy	4400.00
0005432799825	14808	Economy	4400.00
0005432799835	14808	Economy	4400.00
0005432799839	14808	Economy	4400.00
0005432799836	14808	Economy	4400.00
0005432799830	14808	Economy	4400.00
0005432799847	14808	Economy	4400.00
0005432799822	14808	Economy	4400.00
0005432799837	14808	Economy	4400.00
0005432799831	14808	Economy	4400.00
0005432799842	14808	Economy	4400.00
0005432799829	14808	Economy	4400.00
0005432799846	14808	Economy	4400.00
0005432799838	14808	Economy	4400.00
0005432799833	14808	Economy	4400.00
0005432799823	14808	Economy	4400.00
0005432799828	14808	Economy	4400.00
0005432799840	14808	Economy	4400.00
0005432799824	14808	Economy	4400.00
0005432799845	14808	Economy	4400.00
0005432799841	14808	Economy	4400.00
0005434299902	7032	Business	49100.00
0005435293350	7032	Business	49100.00
0005434408705	7032	Business	49100.00
0005434408681	7032	Business	49100.00
0005435311097	7032	Business	49100.00
0005434299892	7032	Business	49100.00
0005432154041	7032	Business	49100.00
0005432108288	7032	Business	49100.00
0005434408704	7032	Business	49100.00
0005434408687	7032	Business	49100.00
0005435311095	7032	Business	49100.00
0005432108287	7032	Business	49100.00
0005434299906	7032	Economy	16400.00
0005434408672	7032	Economy	16400.00
0005432154042	7032	Economy	16400.00
0005434299891	7032	Economy	16400.00
0005434299900	7032	Economy	16400.00
0005434408688	7032	Economy	16400.00
0005434408673	7032	Economy	16400.00
0005435311134	7032	Economy	16400.00
0005434408702	7032	Economy	16400.00
0005434408669	7032	Economy	16400.00
0005435311135	7032	Economy	16400.00
0005434408690	7032	Economy	16400.00
0005434408643	7032	Economy	16400.00
0005434408662	7032	Economy	16400.00
0005434408692	7032	Economy	16400.00
0005434299899	7032	Economy	16400.00
0005435293303	7032	Economy	16400.00
0005434408644	7032	Economy	16400.00
0005434299905	7032	Economy	16400.00
0005435293319	7032	Economy	16400.00
0005434408666	7032	Economy	16400.00
0005434408650	7032	Economy	16400.00
0005434408653	7032	Economy	16400.00
0005435293332	7032	Economy	16400.00
0005432154040	7032	Economy	16400.00
0005434408679	7032	Economy	16400.00
0005434408699	7032	Economy	16400.00
0005434408677	7032	Economy	16400.00
0005434408698	7032	Economy	16400.00
0005434408651	7032	Economy	16400.00
0005432154038	7032	Economy	16400.00
0005434408675	7032	Economy	16400.00
0005434408657	7032	Economy	16400.00
0005435311112	7032	Economy	16400.00
0005434408686	7032	Economy	16400.00
0005434408680	7032	Economy	16400.00
0005434408656	7032	Economy	16400.00
0005434408663	7032	Economy	16400.00
0005434408678	7032	Economy	18000.00
0005434408671	7032	Economy	18000.00
0005434408667	7032	Economy	18000.00
0005434408641	7032	Economy	18000.00
0005434408703	7032	Economy	18000.00
0005434299904	7032	Economy	18000.00
0005434408684	7032	Economy	16400.00
0005434408664	7032	Economy	16400.00
0005432108289	7032	Economy	16400.00
0005434408682	7032	Economy	16400.00
0005434408660	7032	Economy	16400.00
0005432154037	7032	Economy	16400.00
0005434408665	7032	Economy	16400.00
0005434299885	7032	Economy	16400.00
0005434408691	7032	Economy	16400.00
0005434408658	7032	Economy	16400.00
0005434408670	7032	Economy	16400.00
0005434408697	7032	Economy	16400.00
0005434299888	7032	Economy	16400.00
0005434408689	7032	Economy	16400.00
0005435311128	7032	Economy	16400.00
0005434299897	7032	Economy	16400.00
0005435311113	7032	Economy	16400.00
0005434299901	7032	Economy	16400.00
0005434408683	7032	Economy	16400.00
0005434408693	7032	Economy	16400.00
0005434299895	7032	Economy	16400.00
0005434299893	7032	Economy	16400.00
0005434299889	7032	Economy	16400.00
0005434408659	7032	Economy	16400.00
0005432108286	7032	Economy	16400.00
0005434299903	7032	Economy	16400.00
0005434408695	7032	Economy	16400.00
0005434408647	7032	Economy	16400.00
0005434408694	7032	Economy	16400.00
0005435311136	7032	Economy	16400.00
0005434408648	7032	Economy	16400.00
0005434299896	7032	Economy	16400.00
0005434408649	7032	Economy	16400.00
0005434408696	7032	Economy	16400.00
0005434408676	7032	Economy	16400.00
0005435311125	7032	Economy	16400.00
0005435293353	7032	Economy	16400.00
0005434408645	7032	Economy	16400.00
0005435311059	7032	Economy	16400.00
0005435311094	7032	Economy	16400.00
0005434299890	7032	Economy	16400.00
0005435311105	7032	Economy	16400.00
0005434299907	7032	Economy	16400.00
0005435293354	7032	Economy	16400.00
0005434408655	7032	Economy	16400.00
0005434408661	7032	Economy	16400.00
0005434299884	7032	Economy	16400.00
0005434299886	7032	Economy	16400.00
0005435311133	7032	Economy	16400.00
0005434408652	7032	Economy	16400.00
0005435293318	7032	Economy	16400.00
0005434408674	7032	Economy	16400.00
0005432154036	7032	Economy	16400.00
0005434299887	7032	Economy	16400.00
0005434408642	7032	Economy	16400.00
0005434299898	7032	Economy	16400.00
0005435311124	7032	Economy	16400.00
0005434408685	7032	Economy	16400.00
0005435311098	7032	Economy	16400.00
0005432154039	7032	Economy	16400.00
0005434408701	7032	Economy	16400.00
0005435293333	7032	Economy	16400.00
0005434408668	7032	Economy	16400.00
0005434299894	7032	Economy	16400.00
0005434408654	7032	Economy	16400.00
0005434408646	7032	Economy	16400.00
0005434408700	7032	Economy	16400.00
0005434407769	26898	Business	49100.00
0005434299684	26898	Business	49100.00
0005434407720	26898	Business	49100.00
0005434408112	26898	Business	49100.00
0005434408004	26898	Business	49100.00
0005434408006	26898	Business	49100.00
0005434407870	26898	Business	49100.00
0005434408073	26898	Business	49100.00
0005434408049	26898	Business	49100.00
0005434408044	26898	Business	49100.00
0005435293431	26898	Business	49100.00
0005434408099	26898	Economy	16400.00
0005435293436	26898	Economy	16400.00
0005434299611	26898	Economy	16400.00
0005434299610	26898	Economy	16400.00
0005432058433	26898	Economy	16400.00
0005435293427	26898	Economy	16400.00
0005434408152	26898	Economy	16400.00
0005434407721	26898	Economy	16400.00
0005434408207	26898	Economy	16400.00
0005434407865	26898	Economy	16400.00
0005434299687	26898	Economy	16400.00
0005435293438	26898	Economy	16400.00
0005434408306	26898	Economy	16400.00
0005434408225	26898	Economy	16400.00
0005434408286	26898	Economy	16400.00
0005434407659	26898	Economy	16400.00
0005435293433	26898	Economy	16400.00
0005434407886	26898	Economy	16400.00
0005435293429	26898	Economy	16400.00
0005435311229	26898	Economy	16400.00
0005434299584	26898	Economy	16400.00
0005434408135	26898	Economy	16400.00
0005432058435	26898	Economy	16400.00
0005434299711	26898	Economy	16400.00
0005434408095	26898	Economy	16400.00
0005434407752	26898	Economy	16400.00
0005434299701	26898	Economy	16400.00
0005434407831	26898	Economy	16400.00
0005434408276	26898	Economy	16400.00
0005434299629	26898	Economy	16400.00
0005434408027	26898	Economy	16400.00
0005434407924	26898	Economy	16400.00
0005434299583	26898	Economy	16400.00
0005434407937	26898	Economy	16400.00
0005435293430	26898	Economy	16400.00
0005434407966	26898	Economy	18000.00
0005434408217	26898	Economy	18000.00
0005435311226	26898	Economy	18000.00
0005434407995	26898	Economy	18000.00
0005434408139	26898	Economy	18000.00
0005435293428	26898	Economy	16400.00
0005434407883	26898	Economy	16400.00
0005434407891	26898	Economy	16400.00
0005434408019	26898	Economy	16400.00
0005434407867	26898	Economy	16400.00
0005434408126	26898	Economy	16400.00
0005434407923	26898	Economy	16400.00
0005434407948	26898	Economy	16400.00
0005434407887	26898	Economy	16400.00
0005434408275	26898	Economy	16400.00
0005435311227	26898	Economy	16400.00
0005435311232	26898	Economy	16400.00
0005434408117	26898	Economy	16400.00
0005434407864	26898	Economy	16400.00
0005434407975	26898	Economy	16400.00
0005435311230	26898	Economy	16400.00
0005434408028	26898	Economy	16400.00
0005434408160	26898	Economy	16400.00
0005435311233	26898	Economy	16400.00
0005434408159	26898	Economy	16400.00
0005434299784	26898	Economy	16400.00
0005434299785	26898	Economy	16400.00
0005434407871	26898	Economy	16400.00
0005435311231	26898	Economy	16400.00
0005434408070	26898	Economy	16400.00
0005434408226	26898	Economy	16400.00
0005434408014	26898	Economy	16400.00
0005434408076	26898	Economy	16400.00
0005434408161	26898	Economy	16400.00
0005435293432	26898	Economy	16400.00
0005435293437	26898	Economy	16400.00
0005434299609	26898	Economy	16400.00
0005434408005	26898	Economy	16400.00
0005434299630	26898	Economy	16400.00
0005434408018	26898	Economy	16400.00
0005432058434	26898	Economy	16400.00
0005434299807	26898	Economy	16400.00
0005434407830	26898	Economy	16400.00
0005435311228	26898	Economy	16400.00
0005434408103	26898	Economy	16400.00
0005434407570	26898	Economy	16400.00
0005434408100	26898	Economy	16400.00
0005434407888	26898	Economy	16400.00
0005434407974	26898	Economy	16400.00
0005434299607	26898	Economy	16400.00
0005434408279	26898	Economy	16400.00
0005434408224	26898	Economy	16400.00
0005435311236	26898	Economy	16400.00
0005434407922	26898	Economy	16400.00
0005435293434	26898	Economy	16400.00
0005434407866	26898	Economy	16400.00
0005435293435	26898	Economy	16400.00
0005434408020	26898	Economy	16400.00
0005434299675	26898	Economy	16400.00
0005434408175	26898	Economy	16400.00
0005434407719	26898	Economy	16400.00
0005434408102	26898	Economy	16400.00
0005432058436	26898	Economy	16400.00
0005434299619	26898	Economy	16400.00
0005434299800	26898	Economy	16400.00
0005435311235	26898	Economy	16400.00
0005435311234	26898	Economy	16400.00
0005434408130	26898	Economy	16400.00
0005434299713	26898	Economy	16400.00
0005434408153	26898	Economy	16400.00
0005434408166	26898	Economy	16400.00
0005432604921	6486	Economy	16500.00
0005432604916	6486	Economy	16500.00
0005432604933	6486	Economy	16500.00
0005434512178	6486	Economy	16500.00
0005432604926	6486	Economy	15000.00
0005432604929	6486	Economy	15000.00
0005432604902	6486	Economy	15000.00
0005432604908	6486	Economy	15000.00
0005432604920	6486	Economy	15000.00
0005432604911	6486	Economy	15000.00
0005432604906	6486	Economy	15000.00
0005432604915	6486	Economy	15000.00
0005432604918	6486	Economy	15000.00
0005432604935	6486	Economy	15000.00
0005434512179	6486	Economy	15000.00
0005432604923	6486	Economy	15000.00
0005432604914	6486	Economy	15000.00
0005432604919	6486	Economy	15000.00
0005434512180	6486	Economy	15000.00
0005432604907	6486	Economy	15000.00
0005434512181	6486	Economy	15000.00
0005432604912	6486	Economy	15000.00
0005432604924	6486	Economy	15000.00
0005432604909	6486	Economy	15000.00
0005432604934	6486	Economy	15000.00
0005432604936	6486	Economy	15000.00
0005432604931	6486	Economy	15000.00
0005432604937	6486	Economy	15000.00
0005432604917	6486	Economy	15000.00
0005432604910	6486	Economy	15000.00
0005432604928	6486	Economy	15000.00
0005432604905	6486	Economy	15000.00
0005432604922	6486	Economy	15000.00
0005432604900	6486	Economy	15000.00
0005432604904	6486	Economy	15000.00
0005432604939	6486	Economy	15000.00
0005432604925	6486	Economy	15000.00
0005432604901	6486	Economy	15000.00
0005432604913	6486	Economy	15000.00
0005432604932	6486	Economy	15000.00
0005432604903	6486	Economy	15000.00
0005432604927	6486	Economy	15000.00
0005432604938	6486	Economy	15000.00
0005432604930	6486	Economy	15000.00
0005435218117	6486	Economy	15000.00
0005432604582	21358	Economy	16500.00
0005432604424	21358	Economy	16500.00
0005432604407	21358	Economy	16500.00
0005432604603	21358	Economy	16500.00
0005432604629	21358	Economy	15000.00
0005432604491	21358	Economy	15000.00
0005432604462	21358	Economy	15000.00
0005432604586	21358	Economy	15000.00
0005432604522	21358	Economy	15000.00
0005432604400	21358	Economy	15000.00
0005432604406	21358	Economy	15000.00
0005432604540	21358	Economy	15000.00
0005432604583	21358	Economy	15000.00
0005432604691	21358	Economy	15000.00
0005432604599	21358	Economy	15000.00
0005432604401	21358	Economy	15000.00
0005432604690	21358	Economy	15000.00
0005432604572	21358	Economy	15000.00
0005432604662	21358	Economy	15000.00
0005432604661	21358	Economy	15000.00
0005432604454	21358	Economy	15000.00
0005432604538	21358	Economy	15000.00
0005432604531	21358	Economy	15000.00
0005432604548	21358	Economy	15000.00
0005432604471	21358	Economy	15000.00
0005432604480	21358	Economy	15000.00
0005432604581	21358	Economy	15000.00
0005432604490	21358	Economy	15000.00
0005432604663	21358	Economy	15000.00
0005432604549	21358	Economy	15000.00
0005432604610	21358	Economy	15000.00
0005432604605	21358	Economy	15000.00
0005432604408	21358	Economy	15000.00
0005432604573	21358	Economy	15000.00
0005432604425	21358	Economy	15000.00
0005432604649	21358	Economy	15000.00
0005432604530	21358	Economy	15000.00
0005432604539	21358	Economy	15000.00
0005432604416	21358	Economy	15000.00
0005432604654	21358	Economy	15000.00
0005432604587	21358	Economy	15000.00
0005432604389	21358	Economy	15000.00
0005432604453	21358	Economy	15000.00
0005432604481	21358	Economy	15000.00
0005432604461	21358	Economy	15000.00
0005432604483	21358	Economy	15000.00
0005432604484	21358	Economy	15000.00
0005432604602	21358	Economy	15000.00
0005432604521	21358	Economy	15000.00
0005433251913	15012	Business	18900.00
0005434907502	15012	Business	18900.00
0005433251930	15012	Business	18900.00
0005434907480	15012	Business	18900.00
0005434907465	15012	Business	18900.00
0005434907299	15012	Business	18900.00
0005433251937	15012	Business	18900.00
0005434907571	15012	Business	18900.00
0005433251915	15012	Business	18900.00
0005434907479	15012	Business	18900.00
0005434907597	15012	Business	18900.00
0005434907406	15012	Business	18900.00
0005433251911	15012	Economy	6300.00
0005433251908	15012	Economy	6300.00
0005434907684	15012	Economy	6300.00
0005434907649	15012	Economy	6300.00
0005433251934	15012	Economy	6300.00
0005433251914	15012	Economy	6300.00
0005434907683	15012	Economy	6300.00
0005433251926	15012	Economy	6300.00
0005433251931	15012	Economy	6300.00
0005433251920	15012	Economy	6900.00
0005434907467	15012	Economy	6900.00
0005433251927	15012	Economy	6900.00
0005434907652	15012	Economy	6900.00
0005434907438	15012	Economy	6300.00
0005434907578	15012	Economy	6300.00
0005434907586	15012	Economy	6300.00
0005434907653	15012	Economy	6300.00
0005433251936	15012	Economy	6300.00
0005434907494	15012	Economy	6300.00
0005434907476	15012	Economy	6300.00
0005434907377	15012	Economy	6300.00
0005434907477	15012	Economy	6300.00
0005433251909	15012	Economy	6300.00
0005433251923	15012	Economy	6300.00
0005434907241	15012	Economy	6300.00
0005434907461	15012	Economy	6300.00
0005434907679	15012	Economy	6300.00
0005434907376	15012	Economy	6300.00
0005434907375	15012	Economy	6300.00
0005434907242	15012	Economy	6300.00
0005433251924	15012	Economy	6300.00
0005434907648	15012	Economy	6300.00
0005434907631	15012	Economy	6300.00
0005434907243	15012	Economy	6300.00
0005434907435	15012	Economy	6300.00
0005434907414	15012	Economy	6300.00
0005434907569	15012	Economy	6300.00
0005433251929	15012	Economy	6300.00
0005434907497	15012	Economy	6300.00
0005433251919	15012	Economy	6300.00
0005433251917	15012	Economy	6300.00
0005433251922	15012	Economy	6300.00
0005433251918	15012	Economy	6300.00
0005434907417	15012	Economy	6300.00
0005433251912	15012	Economy	6300.00
0005434907466	15012	Economy	6300.00
0005434907572	15012	Economy	6300.00
0005433251925	15012	Economy	6300.00
0005434907458	15012	Economy	6300.00
0005433251938	15012	Economy	6300.00
0005434907539	15012	Economy	6300.00
0005433251932	15012	Economy	6300.00
0005433251910	15012	Economy	6300.00
0005433251916	15012	Economy	6300.00
0005433251907	15012	Economy	6300.00
0005434907455	15012	Economy	6300.00
0005434907682	15012	Economy	6300.00
0005433251933	15012	Economy	6300.00
0005434907678	15012	Economy	6300.00
0005434907454	15012	Economy	6300.00
0005434907590	15012	Economy	6300.00
0005434907589	15012	Economy	6300.00
0005434907563	15012	Economy	6300.00
0005434907449	15012	Economy	6300.00
0005434907350	15012	Economy	6300.00
0005433251928	15012	Economy	6300.00
0005433251935	15012	Economy	6300.00
0005434907540	15012	Economy	6300.00
0005434907344	15012	Economy	6300.00
0005434907486	15012	Economy	6300.00
0005433251921	15012	Economy	6300.00
0005434908015	25819	Business	18900.00
0005434907978	25819	Business	18900.00
0005434908010	25819	Business	18900.00
0005433251692	25819	Business	18900.00
0005433251637	25819	Business	18900.00
0005433251704	25819	Business	18900.00
0005434908002	25819	Business	18900.00
0005434907993	25819	Business	18900.00
0005434907973	25819	Business	18900.00
0005434908020	25819	Business	18900.00
0005434907988	25819	Business	18900.00
0005434907964	25819	Business	18900.00
0005433251781	25819	Economy	6300.00
0005434907982	25819	Economy	6300.00
0005433251577	25819	Economy	6300.00
0005434907971	25819	Economy	6300.00
0005434907981	25819	Economy	6300.00
0005434908005	25819	Economy	6300.00
0005434907965	25819	Economy	6300.00
0005433251735	25819	Economy	6300.00
0005434907989	25819	Economy	6300.00
0005434908022	25819	Economy	6900.00
0005433251673	25819	Economy	6900.00
0005434908017	25819	Economy	6900.00
0005433251789	25819	Economy	6900.00
0005434907990	25819	Economy	6300.00
0005434907976	25819	Economy	6300.00
0005434907980	25819	Economy	6300.00
0005434908000	25819	Economy	6300.00
0005433251674	25819	Economy	6300.00
0005434907996	25819	Economy	6300.00
0005434907966	25819	Economy	6300.00
0005434908019	25819	Economy	6300.00
0005434908004	25819	Economy	6300.00
0005434907975	25819	Economy	6300.00
0005434907967	25819	Economy	6300.00
0005434907984	25819	Economy	6300.00
0005433251478	25819	Economy	6300.00
0005434907998	25819	Economy	6300.00
0005434908003	25819	Economy	6300.00
0005433251695	25819	Economy	6300.00
0005434908008	25819	Economy	6300.00
0005433251780	25819	Economy	6300.00
0005434908013	25819	Economy	6300.00
0005434907997	25819	Economy	6300.00
0005434907999	25819	Economy	6300.00
0005434907972	25819	Economy	6300.00
0005434907994	25819	Economy	6300.00
0005433251542	25819	Economy	6300.00
0005433251602	25819	Economy	6300.00
0005434907992	25819	Economy	6300.00
0005433251479	25819	Economy	6300.00
0005434907986	25819	Economy	6300.00
0005434908007	25819	Economy	6300.00
0005433251672	25819	Economy	6300.00
0005434908012	25819	Economy	6300.00
0005434907961	25819	Economy	6300.00
0005433251702	25819	Economy	6300.00
0005434907983	25819	Economy	6300.00
0005434908018	25819	Economy	6300.00
0005434907985	25819	Economy	6300.00
0005434907995	25819	Economy	6300.00
0005434907991	25819	Economy	6300.00
0005434908016	25819	Economy	6300.00
0005434908011	25819	Economy	6300.00
0005433251701	25819	Economy	6300.00
0005433251677	25819	Economy	6300.00
0005433251689	25819	Economy	6300.00
0005434907974	25819	Economy	6300.00
0005433251690	25819	Economy	6300.00
0005434907962	25819	Economy	6300.00
0005433251678	25819	Economy	6300.00
0005433251766	25819	Economy	6300.00
0005434907979	25819	Economy	6300.00
0005434908006	25819	Economy	6300.00
0005433251703	25819	Economy	6300.00
0005434908009	25819	Economy	6300.00
0005434908014	25819	Economy	6300.00
0005433251691	25819	Economy	6300.00
0005434907970	25819	Economy	6300.00
0005433251630	25819	Economy	6300.00
0005433251693	25819	Economy	6300.00
0005434907969	25819	Economy	6300.00
0005434908001	25819	Economy	6300.00
0005433251767	25819	Economy	6300.00
0005434907963	25819	Economy	6300.00
0005434907968	25819	Economy	6300.00
0005434907977	25819	Economy	6300.00
0005433251694	25819	Economy	6300.00
0005434907987	25819	Economy	6300.00
0005434908021	25819	Economy	6300.00
0005433251591	25819	Economy	6300.00
0005432607623	22471	Economy	16400.00
0005432609787	22471	Economy	16400.00
0005432607615	22471	Economy	16400.00
0005432609780	22471	Economy	14900.00
0005435842330	22471	Economy	14900.00
0005432609788	22471	Economy	14900.00
0005432609778	22471	Economy	14900.00
0005432609777	22471	Economy	14900.00
0005432609779	22471	Economy	14900.00
0005432607621	22471	Economy	14900.00
0005432607619	22471	Economy	14900.00
0005432607612	22471	Economy	14900.00
0005432609776	22471	Economy	14900.00
0005432609784	22471	Economy	14900.00
0005432609783	22471	Economy	14900.00
0005432607613	22471	Economy	14900.00
0005432607622	22471	Economy	14900.00
0005432607616	22471	Economy	14900.00
0005432609786	22471	Economy	14900.00
0005432609785	22471	Economy	14900.00
0005432607618	22471	Economy	14900.00
0005435841476	22471	Economy	14900.00
0005432607620	22471	Economy	14900.00
0005432609782	22471	Economy	14900.00
0005435842329	22471	Economy	14900.00
0005432607617	22471	Economy	14900.00
0005432609781	22471	Economy	14900.00
0005432607614	22471	Economy	14900.00
0005435841480	31731	Economy	16400.00
0005432613892	31731	Economy	16400.00
0005435841110	31731	Economy	16400.00
0005432613868	31731	Economy	14900.00
0005435841478	31731	Economy	14900.00
0005435841107	31731	Economy	14900.00
0005435841104	31731	Economy	14900.00
0005435841109	31731	Economy	14900.00
0005435841481	31731	Economy	14900.00
0005432613888	31731	Economy	14900.00
0005432609769	31731	Economy	14900.00
0005432613899	31731	Economy	14900.00
0005435841105	31731	Economy	14900.00
0005432609736	31731	Economy	14900.00
0005432613884	31731	Economy	14900.00
0005432613891	31731	Economy	14900.00
0005432613883	31731	Economy	14900.00
0005435841479	31731	Economy	14900.00
0005432609738	31731	Economy	14900.00
0005432609741	31731	Economy	14900.00
0005432613880	31731	Economy	14900.00
0005432609759	31731	Economy	14900.00
0005432609757	31731	Economy	14900.00
0005435841108	31731	Economy	14900.00
0005435841477	31731	Economy	14900.00
0005432609743	31731	Economy	14900.00
0005435841106	31731	Economy	14900.00
0005432613893	31731	Economy	14900.00
0005432609735	31731	Economy	14900.00
0005432609768	31731	Economy	14900.00
0005432613885	31731	Economy	14900.00
0005432609758	31731	Economy	14900.00
0005432613889	31731	Economy	14900.00
0005432609740	31731	Economy	14900.00
0005432613879	31731	Economy	14900.00
0005435841482	31731	Economy	14900.00
0005432609737	31731	Economy	14900.00
0005432609730	31731	Economy	14900.00
0005432609749	31731	Economy	14900.00
0005432609756	31731	Economy	14900.00
0005432613881	31731	Economy	14900.00
0005433009272	14197	Business	52300.00
0005433009296	14197	Business	52300.00
0005433009305	14197	Business	52300.00
0005433009298	14197	Business	52300.00
0005433009284	14197	Business	52300.00
0005433009274	14197	Economy	17400.00
0005433009299	14197	Economy	17400.00
0005433009300	14197	Economy	17400.00
0005433009281	14197	Economy	17400.00
0005433009292	14197	Economy	17400.00
0005433009291	14197	Economy	17400.00
0005433009269	14197	Economy	17400.00
0005433009282	14197	Economy	19200.00
0005433009286	14197	Economy	19200.00
0005433009278	14197	Economy	19200.00
0005433009263	14197	Economy	17400.00
0005433009273	14197	Economy	17400.00
0005433009270	14197	Economy	17400.00
0005433009287	14197	Economy	17400.00
0005433009280	14197	Economy	17400.00
0005433009303	14197	Economy	17400.00
0005433009268	14197	Economy	17400.00
0005433810560	14197	Economy	17400.00
0005433009262	14197	Economy	17400.00
0005433009304	14197	Economy	17400.00
0005433009266	14197	Economy	17400.00
0005433009276	14197	Economy	17400.00
0005433009301	14197	Economy	17400.00
0005433009285	14197	Economy	17400.00
0005433009265	14197	Economy	17400.00
0005433009261	14197	Economy	17400.00
0005433009297	14197	Economy	17400.00
0005433009271	14197	Economy	17400.00
0005433009277	14197	Economy	17400.00
0005433810564	14197	Economy	17400.00
0005433810561	14197	Economy	17400.00
0005433009294	14197	Economy	17400.00
0005433009293	14197	Economy	17400.00
0005433009260	14197	Economy	17400.00
0005433009283	14197	Economy	17400.00
0005433009275	14197	Economy	17400.00
0005433009279	14197	Economy	17400.00
0005433009288	14197	Economy	17400.00
0005433009295	14197	Economy	17400.00
0005433009289	14197	Economy	17400.00
0005433009290	14197	Economy	17400.00
0005433009264	14197	Economy	17400.00
0005433009267	14197	Economy	17400.00
0005433009302	14197	Economy	17400.00
0005433008953	22858	Business	52300.00
0005433810599	22858	Business	52300.00
0005433008925	22858	Business	52300.00
0005433008708	22858	Business	52300.00
0005433008809	22858	Business	52300.00
0005433008873	22858	Economy	17400.00
0005433008942	22858	Economy	17400.00
0005433810604	22858	Economy	17400.00
0005433008854	22858	Economy	17400.00
0005433008943	22858	Economy	17400.00
0005433008936	22858	Economy	19200.00
0005433008791	22858	Economy	19200.00
0005433810602	22858	Economy	19200.00
0005433810598	22858	Economy	17400.00
0005433008934	22858	Economy	17400.00
0005433008926	22858	Economy	17400.00
0005433008773	22858	Economy	17400.00
0005433008737	22858	Economy	17400.00
0005433008707	22858	Economy	17400.00
0005433008718	22858	Economy	17400.00
0005433008780	22858	Economy	17400.00
0005433008789	22858	Economy	17400.00
0005433008837	22858	Economy	17400.00
0005433009039	22858	Economy	17400.00
0005433008823	22858	Economy	17400.00
0005433008738	22858	Economy	17400.00
0005433810603	22858	Economy	17400.00
0005433008721	22858	Economy	17400.00
0005433008720	22858	Economy	17400.00
0005433810605	22858	Economy	17400.00
0005433008824	22858	Economy	17400.00
0005433008739	22858	Economy	17400.00
0005433009068	22858	Economy	17400.00
0005433008975	22858	Economy	17400.00
0005433008937	22858	Economy	17400.00
0005433810600	22858	Economy	17400.00
0005433008812	22858	Economy	17400.00
0005433008825	22858	Economy	17400.00
0005433008627	22858	Economy	17400.00
0005433009038	22858	Economy	17400.00
0005433008922	22858	Economy	17400.00
0005433008808	22858	Economy	17400.00
0005433008935	22858	Economy	17400.00
0005433008628	22858	Economy	17400.00
0005433008717	22858	Economy	17400.00
0005433008871	22858	Economy	17400.00
0005433008788	22858	Economy	17400.00
0005433008954	22858	Economy	17400.00
0005433810601	22858	Economy	17400.00
0005434925998	14956	Business	22900.00
0005434925989	14956	Business	22900.00
0005434925905	14956	Business	22900.00
0005434925913	14956	Economy	7600.00
0005434925829	14956	Economy	7600.00
0005434925940	14956	Economy	7600.00
0005434925979	14956	Economy	8400.00
0005434925941	14956	Economy	8400.00
0005434925912	14956	Economy	7600.00
0005434925951	14956	Economy	7600.00
0005434926022	14956	Economy	7600.00
0005434925901	14956	Economy	7600.00
0005434925987	14956	Economy	7600.00
0005434925949	14956	Economy	7600.00
0005434926016	14956	Economy	7600.00
0005434925904	14956	Economy	7600.00
0005434925980	14956	Economy	7600.00
0005434925846	14956	Economy	7600.00
0005434925828	14956	Economy	7600.00
0005434925995	14956	Economy	7600.00
0005434925900	14956	Economy	7600.00
0005434926024	14956	Economy	7600.00
0005434925994	14956	Economy	7600.00
0005434925907	14956	Economy	7600.00
0005434925873	14956	Economy	7600.00
0005434925902	14956	Economy	7600.00
0005434925906	14956	Economy	7600.00
0005434925990	14956	Economy	7600.00
0005434925963	14956	Economy	7600.00
0005434926023	14956	Economy	7600.00
0005434926025	14956	Economy	7600.00
0005434925969	14956	Economy	7600.00
0005434925924	14956	Economy	7600.00
0005434926233	20509	Business	22900.00
0005434926252	20509	Business	22900.00
0005434926228	20509	Business	22900.00
0005434926249	20509	Business	22900.00
0005434926251	20509	Business	22900.00
0005434926243	20509	Economy	7600.00
0005434926226	20509	Economy	7600.00
0005434926234	20509	Economy	7600.00
0005434926223	20509	Economy	7600.00
0005434926230	20509	Economy	8400.00
0005434926250	20509	Economy	7600.00
0005434926225	20509	Economy	7600.00
0005434926244	20509	Economy	7600.00
0005434926227	20509	Economy	7600.00
0005434926238	20509	Economy	7600.00
0005434926248	20509	Economy	7600.00
0005434926235	20509	Economy	7600.00
0005434926236	20509	Economy	7600.00
0005434926241	20509	Economy	7600.00
0005434926239	20509	Economy	7600.00
0005434926240	20509	Economy	7600.00
0005434926231	20509	Economy	7600.00
0005434926224	20509	Economy	7600.00
0005434926237	20509	Economy	7600.00
0005434926232	20509	Economy	7600.00
0005434926222	20509	Economy	7600.00
0005434926242	20509	Economy	7600.00
0005434926245	20509	Economy	7600.00
0005434926229	20509	Economy	7600.00
0005434926247	20509	Economy	7600.00
0005434926246	20509	Economy	7600.00
0005435488160	15839	Economy	8900.00
0005435999301	15839	Economy	8900.00
0005435488157	15839	Economy	8900.00
0005435488141	15839	Economy	8100.00
0005435488162	15839	Economy	8100.00
0005435488155	15839	Economy	8100.00
0005435999339	15839	Economy	8100.00
0005435999365	15839	Economy	8100.00
0005435999356	15839	Economy	8100.00
0005435488150	15839	Economy	8100.00
0005435488154	15839	Economy	8100.00
0005435999337	15839	Economy	8100.00
0005435999340	15839	Economy	8100.00
0005435488145	15839	Economy	8100.00
0005435999315	15839	Economy	8100.00
0005435488159	15839	Economy	8100.00
0005435999314	15839	Economy	8100.00
0005435488153	15839	Economy	8100.00
0005435999302	15839	Economy	8100.00
0005435488147	15839	Economy	8100.00
0005435488148	15839	Economy	8100.00
0005435999299	15839	Economy	8100.00
0005435488144	15839	Economy	8100.00
0005435488158	15839	Economy	8100.00
0005435488143	15839	Economy	8100.00
0005435999361	15839	Economy	8100.00
0005435999362	15839	Economy	8100.00
0005435488156	15839	Economy	8100.00
0005435488161	15839	Economy	8100.00
0005435999319	15839	Economy	8100.00
0005435999318	15839	Economy	8100.00
0005435999306	15839	Economy	8100.00
0005435488152	15839	Economy	8100.00
0005435488140	15839	Economy	8100.00
0005435488151	15839	Economy	8100.00
0005435999305	15839	Economy	8100.00
0005435488142	15839	Economy	8100.00
0005435999328	15839	Economy	8100.00
0005435488146	15839	Economy	8100.00
0005435999313	15839	Economy	8100.00
0005435488149	15839	Economy	8100.00
0005435999480	19700	Economy	8900.00
0005435487917	19700	Economy	8900.00
0005435487922	19700	Economy	8100.00
0005435488041	19700	Economy	8100.00
0005435487909	19700	Economy	8100.00
0005435487959	19700	Economy	8100.00
0005435487843	19700	Economy	8100.00
0005435487920	19700	Economy	8100.00
0005435487977	19700	Economy	8100.00
0005435487940	19700	Economy	8100.00
0005435487774	19700	Economy	8100.00
0005435487898	19700	Economy	8100.00
0005435487930	19700	Economy	8100.00
0005435488039	19700	Economy	8100.00
0005435488040	19700	Economy	8100.00
0005435999483	19700	Economy	8100.00
0005435487958	19700	Economy	8100.00
0005435487933	19700	Economy	8100.00
0005435999476	19700	Economy	8100.00
0005435487921	19700	Economy	8100.00
0005435487875	19700	Economy	8100.00
0005435999481	19700	Economy	8100.00
0005435487876	19700	Economy	8100.00
0005435487874	19700	Economy	8100.00
0005435999478	19700	Economy	8100.00
0005435487842	19700	Economy	8100.00
0005435487946	19700	Economy	8100.00
0005435999477	19700	Economy	8100.00
0005435487961	19700	Economy	8100.00
0005435487896	19700	Economy	8100.00
0005435999482	19700	Economy	8100.00
0005435487844	19700	Economy	8100.00
0005435999479	19700	Economy	8100.00
0005435487916	19700	Economy	8100.00
0005435487939	19700	Economy	8100.00
0005435999484	19700	Economy	8100.00
0005435487957	19700	Economy	8100.00
0005435487897	19700	Economy	8100.00
0005435839868	5990	Business	199300.00
0005435472887	5990	Business	199300.00
0005435472892	5990	Business	199300.00
0005435472896	5990	Business	199300.00
0005435472943	5990	Business	199300.00
0005435839873	5990	Business	199300.00
0005432659737	5990	Business	199300.00
0005432659739	5990	Business	199300.00
0005435839875	5990	Business	199300.00
0005435472859	5990	Business	199300.00
0005435472912	5990	Business	199300.00
0005435839863	5990	Business	199300.00
0005435839851	5990	Economy	66400.00
0005435839877	5990	Business	199300.00
0005432142298	5990	Economy	66400.00
0005435839869	5990	Economy	66400.00
0005435839870	5990	Economy	66400.00
0005435839852	5990	Economy	66400.00
0005435472908	5990	Economy	66400.00
0005435839871	5990	Economy	73100.00
0005435472860	5990	Economy	66400.00
0005435839864	5990	Economy	66400.00
0005435839856	5990	Economy	66400.00
0005435839867	5990	Economy	66400.00
0005432658623	5990	Economy	66400.00
0005435839866	5990	Economy	66400.00
0005432659740	5990	Economy	66400.00
0005432142297	5990	Economy	66400.00
0005435839859	5990	Economy	66400.00
0005435472889	5990	Economy	66400.00
0005435839860	5990	Economy	66400.00
0005435472942	5990	Economy	66400.00
0005432660849	5990	Economy	66400.00
0005435472950	5990	Economy	66400.00
0005435839855	5990	Economy	66400.00
0005435472878	5990	Economy	66400.00
0005435839872	5990	Economy	66400.00
0005435472886	5990	Economy	66400.00
0005435839878	5990	Economy	66400.00
0005435839854	5990	Economy	66400.00
0005435472848	5990	Economy	66400.00
0005432658622	5990	Economy	66400.00
0005435839853	5990	Economy	66400.00
0005435472911	5990	Economy	66400.00
0005432142296	5990	Economy	66400.00
0005435839874	5990	Economy	66400.00
0005435839876	5990	Economy	66400.00
0005435472822	5990	Economy	66400.00
0005435839857	5990	Economy	66400.00
0005435472890	5990	Economy	66400.00
0005432660850	5990	Economy	66400.00
0005435839862	5990	Economy	66400.00
0005435472900	5990	Economy	66400.00
0005435839865	5990	Economy	66400.00
0005432659738	5990	Economy	66400.00
0005435472919	5990	Economy	66400.00
0005435839858	5990	Economy	66400.00
0005435472956	5990	Economy	66400.00
0005435472951	5990	Economy	66400.00
0005435839861	5990	Economy	66400.00
0005435473042	18040	Business	199300.00
0005435839745	18040	Business	199300.00
0005435473038	18040	Business	199300.00
0005435839620	18040	Business	199300.00
0005435839681	18040	Business	199300.00
0005435839633	18040	Business	199300.00
0005435839695	18040	Business	199300.00
0005435839642	18040	Business	199300.00
0005435839648	18040	Business	199300.00
0005435839513	18040	Business	199300.00
0005435473035	18040	Economy	66400.00
0005435473044	18040	Economy	66400.00
0005435839561	18040	Economy	66400.00
0005435839602	18040	Economy	66400.00
0005435839746	18040	Economy	66400.00
0005435839535	18040	Economy	66400.00
0005435473051	18040	Economy	73100.00
0005435839725	18040	Economy	66400.00
0005435473040	18040	Economy	66400.00
0005435473036	18040	Economy	66400.00
0005432667453	18040	Economy	66400.00
0005435473048	18040	Economy	66400.00
0005435473043	18040	Economy	66400.00
0005432664139	18040	Economy	66400.00
0005435839608	18040	Economy	66400.00
0005435839626	18040	Economy	66400.00
0005435473037	18040	Economy	66400.00
0005435839541	18040	Economy	66400.00
0005432537089	18040	Economy	66400.00
0005432537091	18040	Economy	66400.00
0005432660823	18040	Economy	66400.00
0005435839604	18040	Economy	66400.00
0005435839614	18040	Economy	66400.00
0005435473047	18040	Economy	66400.00
0005435473041	18040	Economy	66400.00
0005435839601	18040	Economy	66400.00
0005435473039	18040	Economy	66400.00
0005435473045	18040	Economy	66400.00
0005435839446	18040	Economy	66400.00
0005435473050	18040	Economy	66400.00
0005435839694	18040	Economy	66400.00
0005435839540	18040	Economy	66400.00
0005435839619	18040	Economy	66400.00
0005435473049	18040	Economy	66400.00
0005435839678	18040	Economy	66400.00
0005435839693	18040	Economy	66400.00
0005435839724	18040	Economy	66400.00
0005435839444	18040	Economy	66400.00
0005435839677	18040	Economy	66400.00
0005435473046	18040	Economy	66400.00
0005435839603	18040	Economy	66400.00
0005435839527	18040	Economy	66400.00
0005435839701	18040	Economy	66400.00
0005435839580	18040	Economy	66400.00
0005435839607	18040	Economy	66400.00
0005432537090	18040	Economy	66400.00
0005432660827	18040	Economy	66400.00
0005435839713	18040	Economy	66400.00
0005435839606	18040	Economy	66400.00
0005435839560	18040	Economy	66400.00
0005433285532	23004	Business	15700.00
0005435104033	23004	Business	15700.00
0005435104035	23004	Business	15700.00
0005435104032	23004	Business	15700.00
0005435104034	23004	Economy	5200.00
0005433285278	23004	Economy	5200.00
0005435104037	23004	Economy	5200.00
0005433285673	23004	Economy	5200.00
0005435104046	23004	Economy	5200.00
0005433285492	23004	Economy	5200.00
0005433285494	23004	Economy	5200.00
0005433285558	23004	Economy	5200.00
0005433285526	23004	Economy	5200.00
0005433285441	23004	Economy	5200.00
0005433285564	23004	Economy	5200.00
0005435104038	23004	Economy	5200.00
0005433285279	23004	Economy	5700.00
0005435104036	23004	Economy	5700.00
0005433285563	23004	Economy	5200.00
0005435104047	23004	Economy	5200.00
0005433285382	23004	Economy	5200.00
0005433285366	23004	Economy	5200.00
0005433285443	23004	Economy	5200.00
0005435104044	23004	Economy	5200.00
0005435104039	23004	Economy	5200.00
0005435104040	23004	Economy	5200.00
0005435104043	23004	Economy	5200.00
0005433285442	23004	Economy	5200.00
0005435104042	23004	Economy	5200.00
0005433285440	23004	Economy	5200.00
0005433285533	23004	Economy	5200.00
0005435104030	23004	Economy	5200.00
0005435104041	23004	Economy	5200.00
0005435104045	23004	Economy	5200.00
0005433285505	23004	Economy	5200.00
0005435104031	23004	Economy	5200.00
0005433285515	23004	Economy	5200.00
0005433285493	23004	Economy	5200.00
0005433285769	32041	Business	15700.00
0005433285767	32041	Business	15700.00
0005433285761	32041	Business	15700.00
0005433285741	32041	Economy	5200.00
0005435103945	32041	Economy	5200.00
0005433285749	32041	Economy	5200.00
0005433285753	32041	Economy	5200.00
0005433285751	32041	Economy	5200.00
0005435103952	32041	Economy	5200.00
0005433285750	32041	Economy	5200.00
0005435103949	32041	Economy	5200.00
0005435103956	32041	Economy	5200.00
0005435103951	32041	Economy	5200.00
0005433285768	32041	Economy	5200.00
0005435103950	32041	Economy	5200.00
0005433285770	32041	Economy	5200.00
0005433285763	32041	Economy	5200.00
0005433285754	32041	Economy	5200.00
0005433285746	32041	Economy	5700.00
0005433285759	32041	Economy	5200.00
0005433285747	32041	Economy	5200.00
0005433285743	32041	Economy	5200.00
0005433285740	32041	Economy	5200.00
0005435103957	32041	Economy	5200.00
0005433285757	32041	Economy	5200.00
0005435103963	32041	Economy	5200.00
0005433285762	32041	Economy	5200.00
0005433285765	32041	Economy	5200.00
0005433285752	32041	Economy	5200.00
0005435103959	32041	Economy	5200.00
0005433285764	32041	Economy	5200.00
0005433285744	32041	Economy	5200.00
0005433285742	32041	Economy	5200.00
0005433285755	32041	Economy	5200.00
0005435103948	32041	Economy	5200.00
0005433285760	32041	Economy	5200.00
0005433285756	32041	Economy	5200.00
0005433285745	32041	Economy	5200.00
0005433285766	32041	Economy	5200.00
0005433285748	32041	Economy	5200.00
0005433285758	32041	Economy	5200.00
0005435103955	32041	Economy	5200.00
0005433285771	32041	Economy	5200.00
0005433475715	23868	Economy	13500.00
0005435852615	23868	Economy	13500.00
0005433475737	23868	Economy	12300.00
0005433475735	23868	Economy	12300.00
0005435852617	23868	Economy	12300.00
0005433475734	23868	Economy	12300.00
0005433475723	23868	Economy	12300.00
0005435852616	23868	Economy	12300.00
0005433475736	23868	Economy	12300.00
0005433475722	23868	Economy	12300.00
0005435852614	23868	Economy	12300.00
0005433475710	23868	Economy	12300.00
0005433475747	23868	Economy	12300.00
0005434068120	30634	Business	42100.00
0005432528810	30634	Business	42100.00
0005432528458	30634	Business	42100.00
0005432528616	30634	Business	42100.00
0005435214580	30634	Business	42100.00
0005434067790	30634	Business	42100.00
0005435214576	30634	Business	42100.00
0005435725676	30634	Business	42100.00
0005432533321	30634	Business	42100.00
0005432528389	30634	Business	42100.00
0005432528992	30634	Business	42100.00
0005434068167	30634	Business	42100.00
0005432529055	30634	Business	42100.00
0005432529206	30634	Business	42100.00
0005432529023	30634	Business	42100.00
0005435214559	30634	Business	42100.00
0005435214571	30634	Business	42100.00
0005434068045	30634	Business	42100.00
0005432529099	30634	Business	42100.00
0005432528928	30634	Business	42100.00
0005435214599	30634	Business	42100.00
0005432535884	30634	Business	42100.00
0005434067887	30634	Business	42100.00
0005432529238	30634	Business	42100.00
0005434068090	30634	Business	42100.00
0005434068275	30634	Business	42100.00
0005432529254	30634	Comfort	23900.00
0005434067695	30634	Comfort	23900.00
0005434068023	30634	Comfort	23900.00
0005432528777	30634	Comfort	23900.00
0005435214588	30634	Comfort	23900.00
0005432528711	30634	Comfort	23900.00
0005432528476	30634	Comfort	23900.00
0005432528976	30634	Comfort	23900.00
0005432529354	30634	Comfort	23900.00
0005434068044	30634	Comfort	23900.00
0005432428945	30634	Comfort	23900.00
0005432529026	30634	Comfort	23900.00
0005432528824	30634	Comfort	23900.00
0005432211618	30634	Comfort	23900.00
0005435214610	30634	Comfort	23900.00
0005434067534	30634	Comfort	23900.00
0005434068115	30634	Comfort	23900.00
0005432528351	30634	Comfort	23900.00
0005435214585	30634	Comfort	23900.00
0005432529035	30634	Comfort	23900.00
0005432529481	30634	Comfort	23900.00
0005435214577	30634	Comfort	23900.00
0005434067765	30634	Comfort	23900.00
0005434068119	30634	Comfort	23900.00
0005434068051	30634	Comfort	23900.00
0005435214566	30634	Comfort	23900.00
0005432529094	30634	Comfort	23900.00
0005432528457	30634	Comfort	23900.00
0005434067810	30634	Comfort	23900.00
0005435214604	30634	Comfort	23900.00
0005435214612	30634	Comfort	23900.00
0005432528485	30634	Comfort	23900.00
0005432529125	30634	Comfort	23900.00
0005435214591	30634	Comfort	23900.00
0005434067500	30634	Economy	14000.00
0005434068021	30634	Comfort	23900.00
0005435214615	30634	Economy	14000.00
0005432528804	30634	Economy	14000.00
0005435214597	30634	Economy	14000.00
0005432529036	30634	Economy	14000.00
0005432528840	30634	Economy	14000.00
0005435214590	30634	Economy	14000.00
0005435214581	30634	Economy	14000.00
0005434068243	30634	Economy	14000.00
0005432528619	30634	Economy	14000.00
0005432528550	30634	Economy	14000.00
0005435214550	30634	Economy	14000.00
0005432529174	30634	Economy	14000.00
0005435725678	30634	Economy	14000.00
0005432528914	30634	Economy	14000.00
0005434067756	30634	Economy	14000.00
0005432528630	30634	Economy	14000.00
0005434067714	30634	Economy	14000.00
0005435214579	30634	Economy	14000.00
0005434067517	30634	Economy	14000.00
0005432211614	30634	Economy	14000.00
0005434067975	30634	Economy	14000.00
0005434067757	30634	Economy	14000.00
0005433656723	30634	Economy	14000.00
0005435214616	30634	Economy	14000.00
0005432528390	30634	Economy	14000.00
0005434068046	30634	Economy	14000.00
0005432528639	30634	Economy	14000.00
0005432529355	30634	Economy	14000.00
0005432528756	30634	Economy	14000.00
0005435725675	30634	Economy	14000.00
0005432528867	30634	Economy	14000.00
0005432528551	30634	Economy	14000.00
0005432529037	30634	Economy	14000.00
0005432528868	30634	Economy	14000.00
0005434068241	30634	Economy	14000.00
0005434067678	30634	Economy	14000.00
0005434067758	30634	Economy	14000.00
0005432529183	30634	Economy	14000.00
0005432529131	30634	Economy	14000.00
0005432528659	30634	Economy	14000.00
0005434067713	30634	Economy	14000.00
0005434068159	30634	Economy	14000.00
0005434067732	30634	Economy	14000.00
0005432528489	30634	Economy	14000.00
0005434067930	30634	Economy	14000.00
0005435725677	30634	Economy	14000.00
0005434067985	30634	Economy	14000.00
0005434068022	30634	Economy	14000.00
0005435214600	30634	Economy	14000.00
0005435283415	30634	Economy	14000.00
0005435214552	30634	Economy	14000.00
0005435214561	30634	Economy	14000.00
0005432528744	30634	Economy	15400.00
0005432528418	30634	Economy	15400.00
0005432529239	30634	Economy	15400.00
0005434067731	30634	Economy	14000.00
0005432528764	30634	Economy	15400.00
0005432529435	30634	Economy	15400.00
0005435214598	30634	Economy	15400.00
0005434068182	30634	Economy	14000.00
0005435214589	30634	Economy	14000.00
0005432529373	30634	Economy	14000.00
0005432528710	30634	Economy	14000.00
0005432528631	30634	Economy	14000.00
0005435214560	30634	Economy	14000.00
0005434068039	30634	Economy	14000.00
0005432528491	30634	Economy	14000.00
0005432528508	30634	Economy	14000.00
0005435631014	30634	Economy	14000.00
0005432528460	30634	Economy	14000.00
0005432528890	30634	Economy	14000.00
0005435214595	30634	Economy	14000.00
0005434068089	30634	Economy	14000.00
0005435214564	30634	Economy	14000.00
0005435214570	30634	Economy	14000.00
0005432528993	30634	Economy	14000.00
0005432529006	30634	Economy	14000.00
0005434067873	30634	Economy	14000.00
0005432529476	30634	Economy	14000.00
0005435214587	30634	Economy	14000.00
0005432211617	30634	Economy	14000.00
0005432529185	30634	Economy	14000.00
0005434067886	30634	Economy	14000.00
0005432528473	30634	Economy	14000.00
0005432529097	30634	Economy	14000.00
0005435214606	30634	Economy	14000.00
0005434068092	30634	Economy	14000.00
0005434067766	30634	Economy	14000.00
0005432529175	30634	Economy	14000.00
0005435214608	30634	Economy	14000.00
0005432528539	30634	Economy	14000.00
0005435214567	30634	Economy	14000.00
0005432528670	30634	Economy	14000.00
0005432529004	30634	Economy	14000.00
0005435214569	30634	Economy	14000.00
0005433656724	30634	Economy	14000.00
0005435214602	30634	Economy	14000.00
0005434067749	30634	Economy	14000.00
0005435214556	30634	Economy	14000.00
0005434067791	30634	Economy	14000.00
0005434067767	30634	Economy	14000.00
0005435214614	30634	Economy	14000.00
0005432528072	30634	Economy	14000.00
0005432528851	30634	Economy	14000.00
0005435214555	30634	Economy	14000.00
0005432528637	30634	Economy	14000.00
0005435214562	30634	Economy	14000.00
0005435214575	30634	Economy	14000.00
0005432528765	30634	Economy	14000.00
0005432528778	30634	Economy	14000.00
0005434067516	30634	Economy	14000.00
0005435631013	30634	Economy	14000.00
0005432528507	30634	Economy	14000.00
0005432529205	30634	Economy	14000.00
0005432528546	30634	Economy	14000.00
0005432211616	30634	Economy	14000.00
0005432528672	30634	Economy	14000.00
0005434067748	30634	Economy	14000.00
0005432211619	30634	Economy	14000.00
0005432528654	30634	Economy	14000.00
0005432528790	30634	Economy	14000.00
0005435214584	30634	Economy	14000.00
0005434067909	30634	Economy	14000.00
0005435214609	30634	Economy	14000.00
0005432527932	30634	Economy	14000.00
0005435214594	30634	Economy	14000.00
0005435214573	30634	Economy	14000.00
0005432528779	30634	Economy	14000.00
0005432529255	30634	Economy	14000.00
0005433656722	30634	Economy	14000.00
0005435214557	30634	Economy	14000.00
0005432528511	30634	Economy	14000.00
0005432529253	30634	Economy	14000.00
0005432159928	30634	Economy	14000.00
0005434068054	30634	Economy	14000.00
0005432528973	30634	Economy	14000.00
0005435214565	30634	Economy	14000.00
0005432528742	30634	Economy	14000.00
0005432528377	30634	Economy	14000.00
0005435214583	30634	Economy	14000.00
0005434068242	30634	Economy	14000.00
0005432529028	30634	Economy	14000.00
0005435283414	30634	Economy	14000.00
0005434067501	30634	Economy	14000.00
0005432528098	30634	Economy	14000.00
0005432529372	30634	Economy	14000.00
0005435214586	30634	Economy	14000.00
0005435214613	30634	Economy	14000.00
0005432528360	30634	Economy	14000.00
0005432211615	30634	Economy	14000.00
0005432528814	30634	Economy	14000.00
0005432528959	30634	Economy	14000.00
0005435214592	30634	Economy	14000.00
0005435214553	30634	Economy	14000.00
0005432528995	30634	Economy	14000.00
0005432529207	30634	Economy	15400.00
0005435214603	30634	Economy	15400.00
0005435283413	30634	Economy	15400.00
0005432528545	30634	Economy	15400.00
0005432529003	30634	Economy	15400.00
0005432528900	30634	Economy	15400.00
0005435214582	30634	Economy	14000.00
0005434067976	30634	Economy	14000.00
0005432529136	30634	Economy	14000.00
0005432528552	30634	Economy	14000.00
0005434068040	30634	Economy	14000.00
0005434068052	30634	Economy	14000.00
0005434067855	30634	Economy	14000.00
0005432528576	30634	Economy	14000.00
0005435214607	30634	Economy	14000.00
0005435283412	30634	Economy	14000.00
0005435214551	30634	Economy	14000.00
0005432528461	30634	Economy	14000.00
0005435214611	30634	Economy	14000.00
0005432528556	30634	Economy	14000.00
0005432528901	30634	Economy	14000.00
0005432529169	30634	Economy	14000.00
0005435631015	30634	Economy	14000.00
0005432528972	30634	Economy	14000.00
0005435214568	30634	Economy	14000.00
0005435214558	30634	Economy	14000.00
0005434067848	30634	Economy	14000.00
0005432529475	30634	Economy	14000.00
0005432528927	30634	Economy	14000.00
0005432528729	30634	Economy	14000.00
0005432529027	30634	Economy	14000.00
0005432529124	30634	Economy	14000.00
0005432528728	30634	Economy	14000.00
0005434068143	30634	Economy	14000.00
0005432528802	30634	Economy	14000.00
0005435725679	30634	Economy	14000.00
0005432529005	30634	Economy	14000.00
0005434068091	30634	Economy	14000.00
0005435214578	30634	Economy	14000.00
0005434068158	30634	Economy	14000.00
0005432528801	30634	Economy	14000.00
0005432159929	30634	Economy	14000.00
0005435214548	30634	Economy	14000.00
0005432529098	30634	Economy	14000.00
0005435214572	30634	Economy	14000.00
0005432529352	30634	Economy	14000.00
0005432211612	30634	Economy	14000.00
0005434068168	30634	Economy	14000.00
0005435214563	30634	Economy	14000.00
0005435214601	30634	Economy	14000.00
0005432528862	30634	Economy	14000.00
0005434067845	30634	Economy	14000.00
0005435214605	30634	Economy	14000.00
0005432528656	30634	Economy	14000.00
0005435214574	30634	Economy	14000.00
0005435214596	30634	Economy	14000.00
0005434067974	30634	Economy	14000.00
0005432528544	30634	Economy	14000.00
0005435725680	30634	Economy	14000.00
0005432528745	30634	Economy	14000.00
0005432529184	30634	Economy	14000.00
0005432528609	30634	Economy	14000.00
0005435214549	30634	Economy	14000.00
0005434067811	30634	Economy	14000.00
0005434068043	30634	Economy	14000.00
0005434068050	30634	Economy	14000.00
0005432528620	30634	Economy	14000.00
0005432528474	30634	Economy	14000.00
0005432529130	30634	Economy	14000.00
0005432528655	30634	Economy	14000.00
0005432528387	30634	Economy	14000.00
0005432529024	30634	Economy	14000.00
0005434067899	30634	Economy	14000.00
0005434067789	30634	Economy	14000.00
0005432159927	30634	Economy	14000.00
0005432528638	30634	Economy	14000.00
0005432528998	30634	Economy	14000.00
0005432528960	30634	Economy	14000.00
0005432528803	30634	Economy	14000.00
0005435214554	30634	Economy	14000.00
0005432528490	30634	Economy	14000.00
0005432211613	30634	Economy	14000.00
0005434067889	30634	Economy	14000.00
0005435214593	30634	Economy	14000.00
0005433368457	24851	Business	9800.00
0005433368454	24851	Business	9800.00
0005435653290	24851	Business	9800.00
0005433368464	24851	Business	9800.00
0005435653414	24851	Business	9800.00
0005435653139	24851	Business	9800.00
0005433368483	24851	Business	9800.00
0005433368448	24851	Business	9800.00
0005433368465	24851	Business	9800.00
0005435653204	24851	Business	9800.00
0005435653296	24851	Business	9800.00
0005435653328	24851	Business	9800.00
0005433368455	24851	Economy	3300.00
0005435653433	24851	Economy	3300.00
0005435653272	24851	Economy	3300.00
0005435653241	24851	Economy	3300.00
0005435653168	24851	Economy	3300.00
0005433368447	24851	Economy	3300.00
0005435653448	24851	Economy	3300.00
0005435653257	24851	Economy	3300.00
0005435653250	24851	Economy	3300.00
0005433368472	24851	Economy	3300.00
0005435653226	24851	Economy	3600.00
0005433368485	24851	Economy	3600.00
0005435653358	24851	Economy	3600.00
0005433368478	24851	Economy	3600.00
0005433368452	24851	Economy	3300.00
0005435653281	24851	Economy	3300.00
0005433368482	24851	Economy	3300.00
0005433368481	24851	Economy	3300.00
0005433368468	24851	Economy	3300.00
0005435653285	24851	Economy	3300.00
0005435653327	24851	Economy	3300.00
0005435653209	24851	Economy	3300.00
0005435653289	24851	Economy	3300.00
0005433368466	24851	Economy	3300.00
0005435653437	24851	Economy	3300.00
0005435653452	24851	Economy	3300.00
0005433368461	24851	Economy	3300.00
0005433368450	24851	Economy	3300.00
0005435653438	24851	Economy	3300.00
0005433368477	24851	Economy	3300.00
0005433368463	24851	Economy	3300.00
0005433368473	24851	Economy	3300.00
0005433368462	24851	Economy	3300.00
0005433368449	24851	Economy	3300.00
0005435653278	24851	Economy	3300.00
0005433368469	24851	Economy	3300.00
0005435653321	24851	Economy	3300.00
0005435653322	24851	Economy	3300.00
0005435653280	24851	Economy	3300.00
0005433368480	24851	Economy	3300.00
0005435653256	24851	Economy	3300.00
0005433368467	24851	Economy	3300.00
0005435653293	24851	Economy	3300.00
0005433368471	24851	Economy	3300.00
0005435653304	24851	Economy	3300.00
0005435653286	24851	Economy	3300.00
0005433368479	24851	Economy	3300.00
0005435653329	24851	Economy	3300.00
0005433368459	24851	Economy	3300.00
0005435653332	24851	Economy	3300.00
0005433368474	24851	Economy	3300.00
0005433368476	24851	Economy	3300.00
0005433368486	24851	Economy	3300.00
0005435653333	24851	Economy	3300.00
0005435653359	24851	Economy	3300.00
0005433368458	24851	Economy	3300.00
0005435653460	24851	Economy	3300.00
0005435653453	24851	Economy	3300.00
0005435653279	24851	Economy	3300.00
0005433368475	24851	Economy	3300.00
0005433368470	24851	Economy	3300.00
0005433368456	24851	Economy	3300.00
0005435653339	24851	Economy	3300.00
0005435653106	24851	Economy	3300.00
0005435653249	24851	Economy	3300.00
0005435653298	24851	Economy	3300.00
0005435653425	24851	Economy	3300.00
0005435653439	24851	Economy	3300.00
0005433368484	24851	Economy	3300.00
0005433368460	24851	Economy	3300.00
0005435653355	24851	Economy	3300.00
0005433368451	24851	Economy	3300.00
0005435653343	24851	Economy	3300.00
0005435653259	24851	Economy	3300.00
0005433368453	24851	Economy	3300.00
0005435653292	24851	Economy	3300.00
0005435949783	23312	Economy	18700.00
0005435949799	23312	Economy	18700.00
0005435949784	23312	Economy	18700.00
0005435949801	23312	Economy	18700.00
0005435949785	23312	Economy	18700.00
0005435949786	23312	Economy	18700.00
0005435949789	23312	Economy	18700.00
0005435949802	23312	Economy	18700.00
0005435949798	23312	Economy	18700.00
0005434980259	2046	Economy	10500.00
0005434980242	2046	Economy	10500.00
0005434980248	2046	Economy	9500.00
0005434980257	2046	Economy	9500.00
0005434980261	2046	Economy	9500.00
0005434980246	2046	Economy	9500.00
0005434980266	2046	Economy	9500.00
0005435801744	2046	Economy	9500.00
0005434980265	2046	Economy	9500.00
0005434980262	2046	Economy	9500.00
0005435801745	2046	Economy	9500.00
0005434980243	2046	Economy	9500.00
0005434980252	2046	Economy	9500.00
0005434980244	2046	Economy	9500.00
0005434980253	2046	Economy	9500.00
0005434980255	2046	Economy	9500.00
0005434980258	2046	Economy	9500.00
0005434980240	2046	Economy	9500.00
0005434980239	2046	Economy	9500.00
0005434980264	2046	Economy	9500.00
0005434980241	2046	Economy	9500.00
0005434980251	2046	Economy	9500.00
0005434980260	2046	Economy	9500.00
0005434980254	2046	Economy	9500.00
0005434980238	2046	Economy	9500.00
0005434980245	2046	Economy	9500.00
0005434980263	2046	Economy	9500.00
0005435801743	2046	Economy	9500.00
0005434980250	2046	Economy	9500.00
0005434980249	2046	Economy	9500.00
0005434980256	2046	Economy	9500.00
0005434980247	2046	Economy	9500.00
0005434980237	2046	Economy	9500.00
0005434979869	23566	Economy	10500.00
0005434980011	23566	Economy	10500.00
0005434979913	23566	Economy	10500.00
0005434979790	23566	Economy	10500.00
0005434980030	23566	Economy	9500.00
0005434979791	23566	Economy	9500.00
0005434979839	23566	Economy	9500.00
0005435801706	23566	Economy	9500.00
0005434980051	23566	Economy	9500.00
0005434979984	23566	Economy	9500.00
0005434979870	23566	Economy	9500.00
0005434979912	23566	Economy	9500.00
0005434979789	23566	Economy	9500.00
0005434979993	23566	Economy	9500.00
0005434979985	23566	Economy	9500.00
0005434979909	23566	Economy	9500.00
0005434979806	23566	Economy	9500.00
0005434980020	23566	Economy	9500.00
0005434980061	23566	Economy	9500.00
0005434979891	23566	Economy	9500.00
0005434979892	23566	Economy	9500.00
0005434979928	23566	Economy	9500.00
0005434980050	23566	Economy	9500.00
0005434979864	23566	Economy	9500.00
0005434979896	23566	Economy	9500.00
0005434979888	23566	Economy	9500.00
0005434979981	23566	Economy	9500.00
0005434952590	2646	Economy	5300.00
0005434952587	2646	Economy	5300.00
0005434952588	2646	Economy	5300.00
0005434952589	2646	Economy	5300.00
0005433256444	2647	Economy	5300.00
0005433256442	2647	Economy	5300.00
0005433256443	2647	Economy	5300.00
0005434952546	28288	Economy	5300.00
0005434952550	28288	Economy	5300.00
0005434952547	28288	Economy	5300.00
0005433256456	28288	Economy	5300.00
0005433256457	28288	Economy	5300.00
0005433256459	28288	Economy	5300.00
0005433256458	28288	Economy	5300.00
0005433111542	19747	Economy	8700.00
0005433111541	19747	Economy	8700.00
0005433112398	19747	Economy	8700.00
0005433111540	19747	Economy	8700.00
0005433112397	19747	Economy	8700.00
0005434138547	11913	Business	9700.00
0005434138634	11913	Business	9700.00
0005434138753	11913	Business	9700.00
0005434138820	11913	Business	9700.00
0005434138819	11913	Business	9700.00
0005434138948	11913	Business	9700.00
0005434138355	11913	Business	9700.00
0005434138666	11913	Business	9700.00
0005434138800	11913	Business	9700.00
0005434138647	11913	Business	9700.00
0005434138687	11913	Economy	3200.00
0005434138572	11913	Economy	3200.00
0005434138805	11913	Economy	3200.00
0005434138519	11913	Economy	3200.00
0005434138895	11913	Economy	3200.00
0005434138685	11913	Economy	3200.00
0005434138596	11913	Economy	3200.00
0005434138497	11913	Economy	3200.00
0005434138551	11913	Economy	3200.00
0005434138616	11913	Economy	3200.00
0005434138686	11913	Economy	3500.00
0005434138862	11913	Economy	3500.00
0005434138762	11913	Economy	3500.00
0005434138929	11913	Economy	3500.00
0005434138801	11913	Economy	3500.00
0005434138568	11913	Economy	3200.00
0005434138715	11913	Economy	3200.00
0005434138851	11913	Economy	3200.00
0005434138311	11913	Economy	3200.00
0005434138331	11913	Economy	3200.00
0005434138400	11913	Economy	3200.00
0005434138593	11913	Economy	3200.00
0005434138894	11913	Economy	3200.00
0005434138859	11913	Economy	3200.00
0005434138930	11913	Economy	3200.00
0005434138594	11913	Economy	3200.00
0005434138627	11913	Economy	3200.00
0005434138945	11913	Economy	3200.00
0005434138826	11913	Economy	3200.00
0005434138586	11913	Economy	3200.00
0005434138498	11913	Economy	3200.00
0005434138939	11913	Economy	3200.00
0005434138660	11913	Economy	3200.00
0005434138804	11913	Economy	3200.00
0005434138398	11913	Economy	3200.00
0005434138500	11913	Economy	3200.00
0005434138940	11913	Economy	3200.00
0005434138620	11913	Economy	3200.00
0005434138434	11913	Economy	3200.00
0005434138325	11913	Economy	3200.00
0005434138668	11913	Economy	3200.00
0005434138626	11913	Economy	3200.00
0005434138564	11913	Economy	3200.00
0005434138827	11913	Economy	3200.00
0005434138332	11913	Economy	3200.00
0005434138790	11913	Economy	3200.00
0005434138602	11913	Economy	3200.00
0005434138625	11913	Economy	3200.00
0005434138789	11913	Economy	3200.00
0005434138235	11913	Economy	3200.00
0005434138907	11913	Economy	3200.00
0005434138628	11913	Economy	3200.00
0005434138771	11913	Economy	3200.00
0005434138356	11913	Economy	3200.00
0005434138667	11913	Economy	3200.00
0005434138112	11913	Economy	3200.00
0005434138484	11913	Economy	3200.00
0005434138744	11913	Economy	3200.00
0005434138592	11913	Economy	3200.00
0005434138559	11913	Economy	3200.00
0005434138928	11913	Economy	3200.00
0005434138546	11913	Economy	3200.00
0005434138614	11913	Economy	3200.00
0005434138740	11913	Economy	3200.00
0005434138754	11913	Economy	3200.00
0005434138706	11913	Economy	3200.00
0005434138791	11913	Economy	3200.00
0005434138788	11913	Economy	3200.00
0005434138802	11913	Economy	3200.00
0005434138850	11913	Economy	3200.00
0005434138584	11913	Economy	3200.00
0005434138615	11913	Economy	3200.00
0005434138397	11913	Economy	3200.00
0005434139318	28747	Business	9700.00
0005434139367	28747	Business	9700.00
0005434139342	28747	Business	9700.00
0005434139365	28747	Business	9700.00
0005434139316	28747	Business	9700.00
0005434139336	28747	Business	9700.00
0005434139319	28747	Business	9700.00
0005434139310	28747	Business	9700.00
0005434139314	28747	Business	9700.00
0005434139335	28747	Business	9700.00
0005434139345	28747	Business	9700.00
0005434139363	28747	Economy	3200.00
0005434139369	28747	Economy	3200.00
0005434139332	28747	Economy	3200.00
0005434139330	28747	Economy	3200.00
0005434139308	28747	Economy	3200.00
0005434139356	28747	Economy	3200.00
0005434139352	28747	Economy	3200.00
0005434139325	28747	Economy	3200.00
0005434139306	28747	Economy	3200.00
0005434139301	28747	Economy	3200.00
0005434139362	28747	Economy	3500.00
0005434139357	28747	Economy	3500.00
0005434139298	28747	Economy	3500.00
0005434139382	28747	Economy	3500.00
0005434139377	28747	Economy	3500.00
0005434139321	28747	Economy	3200.00
0005434139294	28747	Economy	3200.00
0005434139373	28747	Economy	3200.00
0005434139323	28747	Economy	3200.00
0005434139354	28747	Economy	3200.00
0005434139295	28747	Economy	3200.00
0005434139347	28747	Economy	3200.00
0005434139378	28747	Economy	3200.00
0005434139344	28747	Economy	3200.00
0005434139302	28747	Economy	3200.00
0005434139343	28747	Economy	3200.00
0005434139375	28747	Economy	3200.00
0005434139315	28747	Economy	3200.00
0005434139376	28747	Economy	3200.00
0005434139296	28747	Economy	3200.00
0005434139341	28747	Economy	3200.00
0005434139372	28747	Economy	3200.00
0005434139368	28747	Economy	3200.00
0005434139359	28747	Economy	3200.00
0005434139358	28747	Economy	3200.00
0005434139338	28747	Economy	3200.00
0005434139355	28747	Economy	3200.00
0005434139353	28747	Economy	3200.00
0005434139309	28747	Economy	3200.00
0005434139379	28747	Economy	3200.00
0005434139329	28747	Economy	3200.00
0005434139333	28747	Economy	3200.00
0005434139350	28747	Economy	3200.00
0005434139360	28747	Economy	3200.00
0005434139326	28747	Economy	3200.00
0005434139349	28747	Economy	3200.00
0005434139361	28747	Economy	3200.00
0005434139313	28747	Economy	3200.00
0005434139351	28747	Economy	3200.00
0005434139327	28747	Economy	3200.00
0005434139312	28747	Economy	3200.00
0005434139311	28747	Economy	3200.00
0005434139300	28747	Economy	3200.00
0005434139371	28747	Economy	3200.00
0005434139304	28747	Economy	3200.00
0005434139331	28747	Economy	3200.00
0005434139366	28747	Economy	3200.00
0005434139293	28747	Economy	3200.00
0005434139380	28747	Economy	3200.00
0005434139292	28747	Economy	3200.00
0005434139317	28747	Economy	3200.00
0005434139334	28747	Economy	3200.00
0005434139370	28747	Economy	3200.00
0005434139337	28747	Economy	3200.00
0005434139346	28747	Economy	3200.00
0005434139374	28747	Economy	3200.00
0005434139307	28747	Economy	3200.00
0005434139381	28747	Economy	3200.00
0005434139364	28747	Economy	3200.00
0005434139320	28747	Economy	3200.00
0005434139322	28747	Economy	3200.00
0005434139340	28747	Economy	3200.00
0005434139297	28747	Economy	3200.00
0005434139328	28747	Economy	3200.00
0005434139348	28747	Economy	3200.00
0005434139305	28747	Economy	3200.00
0005434139324	28747	Economy	3200.00
0005434139339	28747	Economy	3200.00
0005434139303	28747	Economy	3200.00
0005434139299	28747	Economy	3200.00
0005434466537	6584	Economy	23000.00
0005434466538	6584	Economy	23000.00
0005434466536	6584	Economy	20900.00
0005434466539	6584	Economy	20900.00
0005434466533	6584	Economy	20900.00
0005434466531	6584	Economy	20900.00
0005434466530	6584	Economy	20900.00
0005435312828	6584	Economy	20900.00
0005435312819	6584	Economy	20900.00
0005434466535	6584	Economy	20900.00
0005435312827	6584	Economy	20900.00
0005434466534	6584	Economy	20900.00
0005434466529	6584	Economy	20900.00
0005434466532	6584	Economy	20900.00
0005434513595	19088	Economy	26000.00
0005434516083	19088	Economy	26000.00
0005434516092	19088	Economy	23600.00
0005434190436	19088	Economy	23600.00
0005434516085	19088	Economy	23600.00
0005434513592	19088	Economy	23600.00
0005434513606	19088	Economy	23600.00
0005434516078	19088	Economy	23600.00
0005434513599	19088	Economy	23600.00
0005434516080	19088	Economy	23600.00
0005434190434	19088	Economy	23600.00
0005434190432	19088	Economy	23600.00
0005434190431	19088	Economy	23600.00
0005434190435	19088	Economy	23600.00
0005434513598	19088	Economy	23600.00
0005434513594	19088	Economy	23600.00
0005434516088	19088	Economy	23600.00
0005434190438	19088	Economy	23600.00
0005434513603	19088	Economy	23600.00
0005434190437	19088	Economy	23600.00
0005434190430	19088	Economy	23600.00
0005434190439	19088	Economy	23600.00
0005434516084	19088	Economy	23600.00
0005434190433	19088	Economy	23600.00
0005434513593	19088	Economy	23600.00
0005433539004	6767	Economy	10900.00
0005433539002	6767	Economy	10900.00
0005433539003	6767	Economy	9900.00
0005433539005	6767	Economy	9900.00
0005433539006	6767	Economy	9900.00
0005433538998	6767	Economy	9900.00
0005433534532	6767	Economy	9900.00
0005433538999	6767	Economy	9900.00
0005435259786	6767	Economy	9900.00
0005433534533	6767	Economy	9900.00
0005433534530	6767	Economy	9900.00
0005433539000	6767	Economy	9900.00
0005433539001	6767	Economy	9900.00
0005435259817	6767	Economy	9900.00
0005433534531	6767	Economy	9900.00
0005433539007	6767	Economy	9900.00
0005435259823	25048	Economy	10900.00
0005433538902	25048	Economy	9900.00
0005433534511	25048	Economy	9900.00
0005435259825	25048	Economy	9900.00
0005433538897	25048	Economy	9900.00
0005433534512	25048	Economy	9900.00
0005433538898	25048	Economy	9900.00
0005433538899	25048	Economy	9900.00
0005433538925	25048	Economy	9900.00
0005433538907	25048	Economy	9900.00
0005435259824	25048	Economy	9900.00
0005433538920	25048	Economy	9900.00
0005433538926	25048	Economy	9900.00
0005435259826	25048	Economy	9900.00
0005433512081	827	Economy	14600.00
0005433512084	827	Economy	14600.00
0005433512077	827	Economy	14600.00
0005432922540	827	Economy	14600.00
0005433512080	827	Economy	14600.00
0005433512086	827	Economy	14600.00
0005433512078	827	Economy	14600.00
0005432922567	827	Economy	14600.00
0005432922555	827	Economy	14600.00
0005433512083	827	Economy	14600.00
0005432922554	827	Economy	14600.00
0005433512082	827	Economy	14600.00
0005433512085	827	Economy	14600.00
0005433512079	827	Economy	14600.00
0005433512017	16167	Economy	14600.00
0005432922587	16167	Economy	14600.00
0005433512074	16167	Economy	14600.00
0005433511987	16167	Economy	14600.00
0005433512043	16167	Economy	14600.00
0005432922589	16167	Economy	14600.00
0005433512047	16167	Economy	14600.00
0005433512018	16167	Economy	14600.00
0005433511986	16167	Economy	14600.00
0005433512008	16167	Economy	14600.00
0005432922588	16167	Economy	14600.00
0005432922590	16167	Economy	14600.00
0005433512030	16167	Economy	14600.00
0005432922591	16167	Economy	14600.00
0005432922586	16167	Economy	14600.00
0005433512075	16167	Economy	14600.00
0005435697776	3685	Economy	7900.00
0005435697779	3685	Economy	7200.00
0005435916187	3685	Economy	7200.00
0005435697787	3685	Economy	7200.00
0005435697774	3685	Economy	7200.00
0005435697778	3685	Economy	7200.00
0005435916188	3685	Economy	7200.00
0005434950600	3685	Economy	7200.00
0005435916186	3685	Economy	7200.00
0005435935066	3685	Economy	7200.00
0005434950601	3685	Economy	7200.00
0005435697770	3685	Economy	7200.00
0005435697785	3685	Economy	7200.00
0005435697780	3685	Economy	7200.00
0005434950599	3685	Economy	7200.00
0005435697773	3685	Economy	7200.00
0005435697789	3685	Economy	7200.00
0005434950598	3685	Economy	7200.00
0005435697777	3685	Economy	7200.00
0005435697782	3685	Economy	7200.00
0005435697768	3685	Economy	7200.00
0005435697766	3685	Economy	7200.00
0005435697765	3685	Economy	7200.00
0005435697784	3685	Economy	7200.00
0005435697783	3685	Economy	7200.00
0005435697781	3685	Economy	7200.00
0005435697767	3685	Economy	7200.00
0005435697786	3685	Economy	7200.00
0005435697769	3685	Economy	7200.00
0005435697764	3685	Economy	7200.00
0005435697763	3685	Economy	7200.00
0005435697762	3685	Economy	7200.00
0005435697772	3685	Economy	7200.00
0005435697775	3685	Economy	7200.00
0005435697771	3685	Economy	7200.00
0005435697788	3685	Economy	7200.00
0005435697790	3685	Economy	7200.00
0005435697642	16285	Economy	7900.00
0005435697643	16285	Economy	7900.00
0005435916209	16285	Economy	7200.00
0005435697543	16285	Economy	7200.00
0005435697492	16285	Economy	7200.00
0005434950548	16285	Economy	7200.00
0005435935088	16285	Economy	7200.00
0005435697468	16285	Economy	7200.00
0005435935090	16285	Economy	7200.00
0005435697508	16285	Economy	7200.00
0005435697456	16285	Economy	7200.00
0005435697547	16285	Economy	7200.00
0005435916208	16285	Economy	7200.00
0005435916210	16285	Economy	7200.00
0005435697465	16285	Economy	7200.00
0005435697549	16285	Economy	7200.00
0005435697454	16285	Economy	7200.00
0005435697357	16285	Economy	7200.00
0005435697560	16285	Economy	7200.00
0005435935092	16285	Economy	7200.00
0005435935091	16285	Economy	7200.00
0005435697453	16285	Economy	7200.00
0005435697466	16285	Economy	7200.00
0005435697544	16285	Economy	7200.00
0005435935089	16285	Economy	7200.00
0005435697469	16285	Economy	7200.00
0005435697524	16285	Economy	7200.00
0005434950550	16285	Economy	7200.00
0005435697532	16285	Economy	7200.00
0005435697523	16285	Economy	7200.00
0005433519527	3935	Economy	21300.00
0005432609794	3935	Economy	21300.00
0005434604950	3935	Economy	19300.00
0005432609793	3935	Economy	19300.00
0005433519528	3935	Economy	19300.00
0005435904898	3935	Economy	19300.00
0005432607630	3935	Economy	19300.00
0005434604951	3935	Economy	19300.00
0005434604952	3935	Economy	19300.00
0005432607629	3935	Economy	19300.00
0005432609796	3935	Economy	19300.00
0005433519529	3935	Economy	19300.00
0005433519530	3935	Economy	19300.00
0005434606880	3935	Economy	19300.00
0005432609795	3935	Economy	19300.00
0005434606879	3935	Economy	19300.00
0005432607631	3935	Economy	19300.00
0005435904899	3935	Economy	19300.00
0005432607628	3935	Economy	19300.00
0005432609768	22047	Economy	21300.00
0005432613892	22047	Economy	21300.00
0005432609757	22047	Economy	21300.00
0005432609756	22047	Economy	21300.00
0005435841104	22047	Economy	19300.00
0005435841110	22047	Economy	19300.00
0005432613884	22047	Economy	19300.00
0005432609736	22047	Economy	19300.00
0005432613880	22047	Economy	19300.00
0005435841477	22047	Economy	19300.00
0005435841107	22047	Economy	19300.00
0005435841109	22047	Economy	19300.00
0005432609737	22047	Economy	19300.00
0005432609735	22047	Economy	19300.00
0005432609758	22047	Economy	19300.00
0005435841480	22047	Economy	19300.00
0005432609741	22047	Economy	19300.00
0005435841478	22047	Economy	19300.00
0005432613885	22047	Economy	19300.00
0005432613889	22047	Economy	19300.00
0005432613893	22047	Economy	19300.00
0005432613888	22047	Economy	19300.00
0005432609743	22047	Economy	19300.00
0005435841106	22047	Economy	19300.00
0005432609730	22047	Economy	19300.00
0005432609740	22047	Economy	19300.00
0005432609738	22047	Economy	19300.00
0005435841108	22047	Economy	19300.00
0005434606852	22047	Economy	19300.00
0005432609749	22047	Economy	19300.00
0005435841481	22047	Economy	19300.00
0005435841105	22047	Economy	19300.00
0005432609769	22047	Economy	19300.00
0005435841482	22047	Economy	19300.00
0005432613891	22047	Economy	19300.00
0005435841479	22047	Economy	19300.00
0005432613879	22047	Economy	19300.00
0005432613868	22047	Economy	19300.00
0005432613899	22047	Economy	19300.00
0005434606854	22047	Economy	19300.00
0005432609759	22047	Economy	19300.00
0005433519497	22047	Economy	19300.00
0005433519481	22047	Economy	19300.00
0005434606853	22047	Economy	19300.00
0005432613881	22047	Economy	19300.00
0005432613883	22047	Economy	19300.00
0005435628775	760	Economy	3700.00
0005435628774	760	Economy	3700.00
0005435628779	760	Economy	3700.00
0005435628777	760	Economy	3700.00
0005433349035	760	Economy	3700.00
0005435628773	760	Economy	3700.00
0005435628776	760	Economy	3700.00
0005435628778	760	Economy	3700.00
0005435628745	15951	Economy	3700.00
0005435628744	15951	Economy	3700.00
0005435628746	15951	Economy	3700.00
0005433349079	15951	Economy	3700.00
0005433349078	15951	Economy	3700.00
0005433349077	15951	Economy	3700.00
0005433349081	15951	Economy	3700.00
0005433349080	15951	Economy	3700.00
0005433349082	15951	Economy	3700.00
0005434445274	17225	Economy	7100.00
0005434446552	17225	Economy	7100.00
0005433158151	17225	Economy	7100.00
0005433158143	17225	Economy	7100.00
0005434446551	17225	Economy	7100.00
0005434446553	17225	Economy	7100.00
0005433159319	17225	Economy	7100.00
0005433158142	17225	Economy	7100.00
0005433159348	17584	Economy	7100.00
0005433159349	17584	Economy	7100.00
0005433159347	17584	Economy	7100.00
0005435133052	7897	Economy	5900.00
0005435383192	7897	Economy	5400.00
0005435133045	7897	Economy	5400.00
0005435133043	7897	Economy	5400.00
0005435383191	7897	Economy	5400.00
0005435133051	7897	Economy	5400.00
0005435133042	7897	Economy	5400.00
0005435133044	7897	Economy	5400.00
0005435383188	7897	Economy	5400.00
0005435133047	7897	Economy	5400.00
0005435133049	7897	Economy	5400.00
0005435383170	7897	Economy	5400.00
0005435133041	7897	Economy	5400.00
0005435133048	7897	Economy	5400.00
0005435383194	7897	Economy	5400.00
0005435383186	7897	Economy	5400.00
0005435383195	7897	Economy	5400.00
0005435133046	7897	Economy	5400.00
0005435383154	7897	Economy	5400.00
0005435133050	7897	Economy	5400.00
0005435383193	7897	Economy	5400.00
0005435383189	7897	Economy	5400.00
0005435132935	33082	Economy	5900.00
0005435383236	33082	Economy	5900.00
0005435383232	33082	Economy	5400.00
0005435383234	33082	Economy	5400.00
0005435132946	33082	Economy	5400.00
0005435132977	33082	Economy	5400.00
0005435383233	33082	Economy	5400.00
0005435132976	33082	Economy	5400.00
0005435132993	33082	Economy	5400.00
0005435132985	33082	Economy	5400.00
0005435132934	33082	Economy	5400.00
0005435132971	33082	Economy	5400.00
0005435132933	33082	Economy	5400.00
0005435132974	33082	Economy	5400.00
0005435132975	33082	Economy	5400.00
0005435383235	33082	Economy	5400.00
0005435938910	4414	Business	133200.00
0005435811150	4414	Business	133200.00
0005435811155	4414	Economy	44400.00
0005435938897	4414	Economy	44400.00
0005435938909	4414	Economy	44400.00
0005435811152	4414	Economy	44400.00
0005435811146	4414	Economy	48800.00
0005435811156	4414	Economy	44400.00
0005435938899	4414	Economy	44400.00
0005435938898	4414	Economy	44400.00
0005435811147	4414	Economy	44400.00
0005435938900	4414	Economy	44400.00
0005435811142	4414	Economy	44400.00
0005435811148	4414	Economy	44400.00
0005435811151	4414	Economy	44400.00
0005435811144	4414	Economy	44400.00
0005435938890	4414	Economy	44400.00
0005435811145	4414	Economy	44400.00
0005435938908	4414	Economy	44400.00
0005435811143	4414	Economy	44400.00
0005435811157	4414	Economy	44400.00
0005435811153	4414	Economy	44400.00
0005435811154	4414	Economy	44400.00
0005435811149	4414	Economy	44400.00
0005435938929	29449	Business	133200.00
0005435811112	29449	Business	133200.00
0005435811101	29449	Business	133200.00
0005435938925	29449	Business	133200.00
0005435938926	29449	Business	133200.00
0005435811089	29449	Economy	44400.00
0005435811128	29449	Economy	44400.00
0005435811091	29449	Economy	48800.00
0005435938928	29449	Economy	44400.00
0005435811098	29449	Economy	44400.00
0005435811088	29449	Economy	44400.00
0005435938923	29449	Economy	44400.00
0005435811092	29449	Economy	44400.00
0005435811087	29449	Economy	44400.00
0005435811113	29449	Economy	44400.00
0005435811118	29449	Economy	44400.00
0005435938922	29449	Economy	44400.00
0005435938927	29449	Economy	44400.00
0005435938924	29449	Economy	44400.00
0005435811086	29449	Economy	44400.00
0005435811099	29449	Economy	44400.00
0005435160477	7493	Economy	13800.00
0005435390252	7493	Economy	13800.00
0005435160478	7493	Economy	13800.00
0005435160476	7493	Economy	12500.00
0005435390317	7493	Economy	12500.00
0005435390318	7493	Economy	12500.00
0005435160474	7493	Economy	12500.00
0005435160471	7493	Economy	12500.00
0005435160479	7493	Economy	12500.00
0005435160475	7493	Economy	12500.00
0005435390306	7493	Economy	12500.00
0005435160480	7493	Economy	12500.00
0005435160473	7493	Economy	12500.00
0005435390305	7493	Economy	12500.00
0005435160472	7493	Economy	12500.00
0005435160470	7493	Economy	12500.00
0005435390282	7493	Economy	12500.00
0005435390345	29578	Economy	13800.00
0005435160346	29578	Economy	13800.00
0005435160411	29578	Economy	12500.00
0005435390350	29578	Economy	12500.00
0005435160409	29578	Economy	12500.00
0005435160408	29578	Economy	12500.00
0005435390351	29578	Economy	12500.00
0005435390347	29578	Economy	12500.00
0005435390349	29578	Economy	12500.00
0005435160410	29578	Economy	12500.00
0005435390346	29578	Economy	12500.00
0005435160412	29578	Economy	12500.00
0005435160345	29578	Economy	12500.00
0005435390348	29578	Economy	12500.00
0005435160347	29578	Economy	12500.00
0005435160405	29578	Economy	12500.00
0005435160402	29578	Economy	12500.00
0005435179005	18482	Economy	4900.00
0005435178518	18482	Economy	4900.00
0005432394129	18482	Economy	4900.00
0005435178519	18482	Economy	4900.00
0005432394130	18482	Economy	4900.00
0005435179006	18482	Economy	4900.00
0005432398222	18482	Economy	4900.00
0005432398221	18482	Economy	4900.00
0005432400176	27137	Economy	4900.00
0005432398252	27137	Economy	4900.00
0005432398253	27137	Economy	4900.00
0005432400177	27137	Economy	4900.00
0005432398251	27137	Economy	4900.00
0005435179395	27137	Economy	4900.00
0005432400178	27137	Economy	4900.00
0005432639330	2250	Business	87300.00
0005432639326	2250	Business	87300.00
0005432639314	2250	Business	87300.00
0005432639316	2250	Business	87300.00
0005432866066	2250	Business	87300.00
0005432866057	2250	Business	87300.00
0005432639310	2250	Business	87300.00
0005432639320	2250	Business	87300.00
0005432639325	2250	Economy	29100.00
0005432866055	2250	Economy	29100.00
0005432639315	2250	Economy	29100.00
0005432639309	2250	Economy	29100.00
0005432639317	2250	Economy	32000.00
0005432866054	2250	Economy	32000.00
0005432639333	2250	Economy	32000.00
0005432639327	2250	Economy	32000.00
0005432866035	2250	Economy	29100.00
0005432866062	2250	Economy	29100.00
0005432866058	2250	Economy	29100.00
0005432866056	2250	Economy	29100.00
0005432866044	2250	Economy	29100.00
0005432639313	2250	Economy	29100.00
0005432866046	2250	Economy	29100.00
0005432639322	2250	Economy	29100.00
0005432639311	2250	Economy	29100.00
0005432639323	2250	Economy	29100.00
0005432866074	2250	Economy	29100.00
0005432639318	2250	Economy	29100.00
0005432639321	2250	Economy	29100.00
0005432639329	2250	Economy	29100.00
0005432866028	2250	Economy	29100.00
0005432639332	2250	Economy	29100.00
0005432866048	2250	Economy	29100.00
0005432639312	2250	Economy	29100.00
0005432639331	2250	Economy	29100.00
0005432866064	2250	Economy	29100.00
0005432639319	2250	Economy	29100.00
0005432866049	2250	Economy	29100.00
0005432866065	2250	Economy	29100.00
0005432866045	2250	Economy	29100.00
0005432639328	2250	Economy	29100.00
0005432866061	2250	Economy	29100.00
0005432639324	2250	Economy	29100.00
0005432866050	2250	Economy	29100.00
0005435104061	6546	Business	48400.00
0005434504766	6546	Business	48400.00
0005434504774	6546	Business	48400.00
0005434504770	6546	Business	48400.00
0005434504747	6546	Business	48400.00
0005434504776	6546	Economy	16100.00
0005434504768	6546	Economy	16100.00
0005434504763	6546	Economy	16100.00
0005434504750	6546	Economy	16100.00
0005434504761	6546	Economy	17800.00
0005434504746	6546	Economy	17800.00
0005435104058	6546	Economy	17800.00
0005434504759	6546	Economy	17800.00
0005434504782	6546	Economy	16100.00
0005434504762	6546	Economy	16100.00
0005434504769	6546	Economy	16100.00
0005434504785	6546	Economy	16100.00
0005434504765	6546	Economy	16100.00
0005435104060	6546	Economy	16100.00
0005434504755	6546	Economy	16100.00
0005434504767	6546	Economy	16100.00
0005434504779	6546	Economy	16100.00
0005434504784	6546	Economy	16100.00
0005434504771	6546	Economy	16100.00
0005434504753	6546	Economy	16100.00
0005434504760	6546	Economy	16100.00
0005434504783	6546	Economy	16100.00
0005434504781	6546	Economy	16100.00
0005434504778	6546	Economy	16100.00
0005434504764	6546	Economy	16100.00
0005434504777	6546	Economy	16100.00
0005434504756	6546	Economy	16100.00
0005434504745	6546	Economy	16100.00
0005434504748	6546	Economy	16100.00
0005434504780	6546	Economy	16100.00
0005434504773	6546	Economy	16100.00
0005434504749	6546	Economy	16100.00
0005434504757	6546	Economy	16100.00
0005434504786	6546	Economy	16100.00
0005434504772	6546	Economy	16100.00
0005434504758	6546	Economy	16100.00
0005434504751	6546	Economy	16100.00
0005434504754	6546	Economy	16100.00
0005435104059	6546	Economy	16100.00
0005434504775	6546	Economy	16100.00
0005434504752	6546	Economy	16100.00
0005434504370	22636	Business	48400.00
0005434504362	22636	Business	48400.00
0005434504361	22636	Business	48400.00
0005434504195	22636	Business	48400.00
0005434504341	22636	Business	48400.00
0005434504460	22636	Business	48400.00
0005434504057	22636	Business	48400.00
0005434504439	22636	Business	48400.00
0005434504263	22636	Economy	16100.00
0005434504331	22636	Economy	16100.00
0005434504414	22636	Economy	16100.00
0005434504348	22636	Economy	16100.00
0005434504291	22636	Economy	16100.00
0005434504360	22636	Economy	16100.00
0005434504222	22636	Economy	16100.00
0005434504264	22636	Economy	17800.00
0005434504143	22636	Economy	17800.00
0005434504404	22636	Economy	17800.00
0005434504293	22636	Economy	17800.00
0005434504268	22636	Economy	16100.00
0005434504369	22636	Economy	16100.00
0005434504463	22636	Economy	16100.00
0005434504359	22636	Economy	16100.00
0005434504267	22636	Economy	16100.00
0005434504260	22636	Economy	16100.00
0005434504240	22636	Economy	16100.00
0005434504265	22636	Economy	16100.00
0005434504280	22636	Economy	16100.00
0005434504365	22636	Economy	16100.00
0005434504332	22636	Economy	16100.00
0005434504276	22636	Economy	16100.00
0005435103951	22636	Economy	16100.00
0005434504259	22636	Economy	16100.00
0005435103948	22636	Economy	16100.00
0005434504440	22636	Economy	16100.00
0005434504381	22636	Economy	16100.00
0005434504380	22636	Economy	16100.00
0005434504221	22636	Economy	16100.00
0005435103950	22636	Economy	16100.00
0005435103956	22636	Economy	16100.00
0005434504347	22636	Economy	16100.00
0005434504415	22636	Economy	16100.00
0005434504441	22636	Economy	16100.00
0005435103955	22636	Economy	16100.00
0005434504281	22636	Economy	16100.00
0005434504142	22636	Economy	16100.00
0005435103945	22636	Economy	16100.00
0005434504421	22636	Economy	16100.00
0005435103952	22636	Economy	16100.00
0005434504403	22636	Economy	16100.00
0005435103957	22636	Economy	16100.00
0005434504266	22636	Economy	16100.00
0005434504278	22636	Economy	16100.00
0005435103959	22636	Economy	16100.00
0005434504239	22636	Economy	16100.00
0005435103963	22636	Economy	16100.00
0005434504277	22636	Economy	16100.00
0005435103949	22636	Economy	16100.00
0005434504388	22636	Economy	16100.00
0005434504157	22636	Economy	16100.00
0005434504284	22636	Economy	16100.00
0005433368285	1685	Business	50000.00
0005435653732	1685	Business	50000.00
0005435653727	1685	Business	50000.00
0005433368156	1685	Business	50000.00
0005435653753	1685	Business	50000.00
0005435653734	1685	Business	50000.00
0005435653731	1685	Business	50000.00
0005435653728	1685	Business	50000.00
0005435653729	1685	Business	50000.00
0005435653744	1685	Economy	16700.00
0005435653746	1685	Economy	16700.00
0005433368221	1685	Economy	16700.00
0005435653716	1685	Economy	16700.00
0005433368153	1685	Economy	16700.00
0005433368177	1685	Economy	16700.00
0005433368213	1685	Economy	16700.00
0005435653718	1685	Economy	16700.00
0005435653754	1685	Economy	16700.00
0005435653711	1685	Economy	16700.00
0005435653750	1685	Economy	18300.00
0005433368223	1685	Economy	18300.00
0005433368222	1685	Economy	18300.00
0005435653724	1685	Economy	18300.00
0005435653713	1685	Economy	18300.00
0005433368289	1685	Economy	16700.00
0005435653751	1685	Economy	16700.00
0005433368176	1685	Economy	16700.00
0005433368109	1685	Economy	16700.00
0005435653730	1685	Economy	16700.00
0005433368031	1685	Economy	16700.00
0005435653721	1685	Economy	16700.00
0005435653747	1685	Economy	16700.00
0005433368030	1685	Economy	16700.00
0005435653735	1685	Economy	16700.00
0005435653722	1685	Economy	16700.00
0005433368152	1685	Economy	16700.00
0005435653714	1685	Economy	16700.00
0005435653749	1685	Economy	16700.00
0005435653725	1685	Economy	16700.00
0005433368235	1685	Economy	16700.00
0005433368171	1685	Economy	16700.00
0005433368086	1685	Economy	16700.00
0005435653745	1685	Economy	16700.00
0005435653726	1685	Economy	16700.00
0005433368145	1685	Economy	16700.00
0005435653756	1685	Economy	16700.00
0005433368055	1685	Economy	16700.00
0005433368146	1685	Economy	16700.00
0005435653748	1685	Economy	16700.00
0005435653743	1685	Economy	16700.00
0005435653723	1685	Economy	16700.00
0005435653742	1685	Economy	16700.00
0005433368165	1685	Economy	16700.00
0005433368090	1685	Economy	16700.00
0005435653733	1685	Economy	16700.00
0005433368182	1685	Economy	16700.00
0005433368178	1685	Economy	16700.00
0005433368429	1685	Economy	16700.00
0005435653737	1685	Economy	16700.00
0005433368166	1685	Economy	16700.00
0005435653720	1685	Economy	16700.00
0005433368218	1685	Economy	16700.00
0005433368089	1685	Economy	16700.00
0005435653741	1685	Economy	16700.00
0005435653739	1685	Economy	16700.00
0005433368318	1685	Economy	16700.00
0005433368193	1685	Economy	16700.00
0005433368175	1685	Economy	16700.00
0005435653717	1685	Economy	16700.00
0005435653715	1685	Economy	16700.00
0005435653719	1685	Economy	16700.00
0005433367956	1685	Economy	16700.00
0005435653752	1685	Economy	16700.00
0005433368162	1685	Economy	16700.00
0005435653738	1685	Economy	16700.00
0005435653740	1685	Economy	16700.00
0005435653712	1685	Economy	16700.00
0005435653736	1685	Economy	16700.00
0005435653755	1685	Economy	16700.00
0005433368195	1685	Economy	16700.00
0005433368236	1685	Economy	16700.00
0005433367957	1685	Economy	16700.00
0005435653293	21666	Business	50000.00
0005433368450	21666	Business	50000.00
0005433368447	21666	Business	50000.00
0005435653343	21666	Business	50000.00
0005435653339	21666	Business	50000.00
0005435653296	21666	Business	50000.00
0005435653433	21666	Business	50000.00
0005435653168	21666	Business	50000.00
0005435653439	21666	Business	50000.00
0005435653278	21666	Business	50000.00
0005433368456	21666	Business	50000.00
0005435653286	21666	Business	50000.00
0005433368468	21666	Economy	16700.00
0005433368470	21666	Economy	16700.00
0005435653414	21666	Economy	16700.00
0005435653292	21666	Economy	16700.00
0005433368474	21666	Economy	16700.00
0005435653290	21666	Economy	16700.00
0005433368473	21666	Economy	16700.00
0005433368451	21666	Economy	16700.00
0005435653280	21666	Economy	16700.00
0005435653453	21666	Economy	18300.00
0005435653355	21666	Economy	18300.00
0005433368448	21666	Economy	18300.00
0005435653298	21666	Economy	18300.00
0005435653322	21666	Economy	18300.00
0005435653304	21666	Economy	16700.00
0005435653204	21666	Economy	16700.00
0005433368459	21666	Economy	16700.00
0005433368482	21666	Economy	16700.00
0005433368483	21666	Economy	16700.00
0005433368460	21666	Economy	16700.00
0005433368472	21666	Economy	16700.00
0005433368449	21666	Economy	16700.00
0005433368462	21666	Economy	16700.00
0005435653272	21666	Economy	16700.00
0005435653285	21666	Economy	16700.00
0005435653259	21666	Economy	16700.00
0005435653249	21666	Economy	16700.00
0005435653321	21666	Economy	16700.00
0005435653332	21666	Economy	16700.00
0005433368478	21666	Economy	16700.00
0005433368467	21666	Economy	16700.00
0005433368481	21666	Economy	16700.00
0005435653437	21666	Economy	16700.00
0005433368464	21666	Economy	16700.00
0005435653452	21666	Economy	16700.00
0005433368476	21666	Economy	16700.00
0005433368463	21666	Economy	16700.00
0005433368480	21666	Economy	16700.00
0005435653359	21666	Economy	16700.00
0005433368455	21666	Economy	16700.00
0005433368475	21666	Economy	16700.00
0005435653281	21666	Economy	16700.00
0005433368461	21666	Economy	16700.00
0005433368452	21666	Economy	16700.00
0005435653327	21666	Economy	16700.00
0005435653250	21666	Economy	16700.00
0005435653438	21666	Economy	16700.00
0005435653425	21666	Economy	16700.00
0005435653257	21666	Economy	16700.00
0005433368458	21666	Economy	16700.00
0005435653139	21666	Economy	16700.00
0005435653329	21666	Economy	16700.00
0005433368457	21666	Economy	16700.00
0005435653358	21666	Economy	16700.00
0005435653241	21666	Economy	16700.00
0005435653448	21666	Economy	16700.00
0005435653256	21666	Economy	16700.00
0005433368486	21666	Economy	16700.00
0005435653460	21666	Economy	16700.00
0005435653279	21666	Economy	16700.00
0005433368479	21666	Economy	16700.00
0005435653106	21666	Economy	16700.00
0005433368477	21666	Economy	16700.00
0005435653209	21666	Economy	16700.00
0005433368471	21666	Economy	16700.00
0005435653226	21666	Economy	16700.00
0005433368465	21666	Economy	16700.00
0005433368454	21666	Economy	16700.00
0005433368469	21666	Economy	16700.00
0005435653333	21666	Economy	16700.00
0005433368466	21666	Economy	16700.00
0005433368453	21666	Economy	16700.00
0005433368484	21666	Economy	16700.00
0005435653289	21666	Economy	16700.00
0005433368485	21666	Economy	16700.00
0005435653328	21666	Economy	16700.00
0005435627121	12247	Economy	11200.00
0005435312843	23240	Economy	23000.00
0005434466478	23240	Economy	23000.00
0005434466485	23240	Economy	20900.00
0005435312845	23240	Economy	20900.00
0005434466503	23240	Economy	20900.00
0005434466482	23240	Economy	20900.00
0005434466502	23240	Economy	20900.00
0005434466474	23240	Economy	20900.00
0005434466483	23240	Economy	20900.00
0005434466496	23240	Economy	20900.00
0005434466507	23240	Economy	20900.00
0005435312844	23240	Economy	20900.00
0005434466504	23240	Economy	20900.00
0005434466508	23240	Economy	20900.00
0005435312842	23240	Economy	20900.00
0005434466494	23240	Economy	20900.00
0005434466486	23240	Economy	20900.00
0005434466492	23240	Economy	20900.00
0005434466509	23240	Economy	20900.00
0005433986674	4158	Business	21500.00
0005433986690	4158	Business	21500.00
0005433986686	4158	Business	21500.00
0005433986680	4158	Business	21500.00
0005433986662	4158	Business	21500.00
0005433986669	4158	Business	21500.00
0005433986681	4158	Business	21500.00
0005433986672	4158	Business	21500.00
0005433986679	4158	Economy	7200.00
0005433986648	4158	Economy	7200.00
0005435788812	4158	Economy	7200.00
0005433986656	4158	Economy	7200.00
0005433986664	4158	Economy	7200.00
0005435788811	4158	Economy	7900.00
0005433986652	4158	Economy	7900.00
0005433986655	4158	Economy	7900.00
0005433986647	4158	Economy	7200.00
0005433986649	4158	Economy	7200.00
0005433986676	4158	Economy	7200.00
0005433986673	4158	Economy	7200.00
0005433986661	4158	Economy	7200.00
0005433986657	4158	Economy	7200.00
0005433986685	4158	Economy	7200.00
0005433986684	4158	Economy	7200.00
0005433986659	4158	Economy	7200.00
0005433986668	4158	Economy	7200.00
0005433986663	4158	Economy	7200.00
0005433986658	4158	Economy	7200.00
0005435788810	4158	Economy	7200.00
0005433986660	4158	Economy	7200.00
0005433986654	4158	Economy	7200.00
0005433986650	4158	Economy	7200.00
0005433986667	4158	Economy	7200.00
0005433986675	4158	Economy	7200.00
0005433986683	4158	Economy	7200.00
0005433986692	4158	Economy	7200.00
0005433986687	4158	Economy	7200.00
0005433986653	4158	Economy	7200.00
0005433986666	4158	Economy	7200.00
0005433986651	4158	Economy	7200.00
0005433986689	4158	Economy	7200.00
0005433986665	4158	Economy	7200.00
0005433986677	4158	Economy	7200.00
0005433986682	4158	Economy	7200.00
0005433986688	4158	Economy	7200.00
0005433986671	4158	Economy	7200.00
0005433986670	4158	Economy	7200.00
0005433986678	4158	Economy	7200.00
0005433986691	4158	Economy	7200.00
0005433986206	25685	Business	21500.00
0005433986174	25685	Business	21500.00
0005433986093	25685	Business	21500.00
0005433986173	25685	Business	21500.00
0005435788796	25685	Business	21500.00
0005433986236	25685	Business	21500.00
0005433986268	25685	Business	21500.00
0005433986235	25685	Business	21500.00
0005433986147	25685	Economy	7200.00
0005433986286	25685	Economy	7200.00
0005433986309	25685	Economy	7200.00
0005433986189	25685	Economy	7200.00
0005433986269	25685	Economy	7200.00
0005433986331	25685	Economy	7900.00
0005433986154	25685	Economy	7200.00
0005433986088	25685	Economy	7200.00
0005433986231	25685	Economy	7200.00
0005433986322	25685	Economy	7200.00
0005433986270	25685	Economy	7200.00
0005433986183	25685	Economy	7200.00
0005433986319	25685	Economy	7200.00
0005433986178	25685	Economy	7200.00
0005433986311	25685	Economy	7200.00
0005433986245	25685	Economy	7200.00
0005433986307	25685	Economy	7200.00
0005433986334	25685	Economy	7200.00
0005433986295	25685	Economy	7200.00
0005433986101	25685	Economy	7200.00
0005433986296	25685	Economy	7200.00
0005433986276	25685	Economy	7200.00
0005433986308	25685	Economy	7200.00
0005433986089	25685	Economy	7200.00
0005433986262	25685	Economy	7200.00
0005433986220	25685	Economy	7200.00
0005433985978	25685	Economy	7200.00
0005433986335	25685	Economy	7200.00
0005433986232	25685	Economy	7200.00
0005433986278	25685	Economy	7200.00
0005435788795	25685	Economy	7200.00
0005433986190	25685	Economy	7200.00
0005433986277	25685	Economy	7200.00
0005433986310	25685	Economy	7200.00
0005433986177	25685	Economy	7200.00
0005433986148	25685	Economy	7200.00
0005433986146	25685	Economy	7200.00
0005433986305	25685	Economy	7200.00
0005433986184	25685	Economy	7200.00
0005433985979	25685	Economy	7200.00
0005433986155	25685	Economy	7200.00
0005433986172	25685	Economy	7200.00
0005433986285	25685	Economy	7200.00
0005433986175	25685	Economy	7200.00
0005433986176	25685	Economy	7200.00
0005433461586	19917	Business	201300.00
0005433463902	19917	Business	201300.00
0005433463899	19917	Business	201300.00
0005433461588	19917	Business	201300.00
0005433461585	19917	Economy	67100.00
0005433461581	19917	Economy	67100.00
0005433463909	19917	Economy	67100.00
0005433463896	19917	Economy	67100.00
0005433461589	19917	Economy	67100.00
0005433461594	19917	Economy	67100.00
0005433461590	19917	Economy	67100.00
0005433463897	19917	Economy	67100.00
0005433461598	19917	Economy	67100.00
0005433463895	19917	Economy	67100.00
0005433461593	19917	Economy	67100.00
0005433463907	19917	Economy	67100.00
0005433463908	19917	Economy	67100.00
0005433463906	19917	Economy	67100.00
0005433461597	19917	Economy	67100.00
0005433463903	19917	Economy	67100.00
0005433463910	19917	Economy	67100.00
0005433461582	19917	Economy	67100.00
0005433463905	19917	Economy	67100.00
0005433463898	19917	Economy	67100.00
0005433461587	19917	Economy	67100.00
0005435720144	24759	Economy	9400.00
0005435719576	24759	Economy	9400.00
0005435719577	24759	Economy	9400.00
0005435719574	24759	Economy	9400.00
0005435719573	24759	Economy	9400.00
0005435720146	24759	Economy	9400.00
0005435719575	24759	Economy	9400.00
0005435720145	24759	Economy	9400.00
0005433168404	1638	Economy	17000.00
0005434509269	1638	Economy	17000.00
0005434509271	1638	Economy	15500.00
0005433168393	1638	Economy	15500.00
0005434509264	1638	Economy	15500.00
0005433168385	1638	Economy	15500.00
0005434509266	1638	Economy	15500.00
0005433168417	1638	Economy	15500.00
0005434509257	1638	Economy	15500.00
0005433168382	1638	Economy	15500.00
0005434509272	1638	Economy	15500.00
0005434509260	1638	Economy	15500.00
0005434509270	1638	Economy	15500.00
0005434509263	1638	Economy	15500.00
0005434509254	1638	Economy	15500.00
0005433168397	1638	Economy	15500.00
0005433168400	1638	Economy	15500.00
0005433168383	1638	Economy	15500.00
0005434509268	1638	Economy	15500.00
0005433168384	1638	Economy	15500.00
0005434509255	1638	Economy	15500.00
0005434509256	1638	Economy	15500.00
0005434509267	1638	Economy	15500.00
0005434509252	1638	Economy	15500.00
0005434509265	1638	Economy	15500.00
0005434509258	1638	Economy	15500.00
0005433168395	1638	Economy	15500.00
0005434509259	1638	Economy	15500.00
0005434509262	1638	Economy	15500.00
0005434509273	1638	Economy	15500.00
0005434509261	1638	Economy	15500.00
0005433168381	1638	Economy	15500.00
0005434509251	1638	Economy	15500.00
0005434509253	1638	Economy	15500.00
0005433168386	1638	Economy	15500.00
0005433168398	1638	Economy	15500.00
0005433168399	1638	Economy	15500.00
0005432869629	17845	Business	18000.00
0005432869630	17845	Business	18000.00
0005432666403	17845	Business	18000.00
0005432660832	17845	Business	18000.00
0005434151753	17845	Business	18000.00
0005432655605	17845	Business	18000.00
0005434151750	17845	Business	18000.00
0005432667457	17845	Economy	6000.00
0005432655560	17845	Economy	6000.00
0005432666410	17845	Economy	6000.00
0005432667467	17845	Economy	6000.00
0005432655608	17845	Economy	6000.00
0005432655601	17845	Economy	6600.00
0005432655603	17845	Economy	6600.00
0005432655604	17845	Economy	6600.00
0005432869634	17845	Economy	6000.00
0005434151751	17845	Economy	6000.00
0005432657472	17845	Economy	6000.00
0005432658605	17845	Economy	6000.00
0005432658603	17845	Economy	6000.00
0005432655612	17845	Economy	6000.00
0005432660830	17845	Economy	6000.00
0005432664145	17845	Economy	6000.00
0005432664148	17845	Economy	6000.00
0005432869631	17845	Economy	6000.00
0005432665281	17845	Economy	6000.00
0005432655592	17845	Economy	6000.00
0005432665298	17845	Economy	6000.00
0005432664144	17845	Economy	6000.00
0005432658604	17845	Economy	6000.00
0005434151752	17845	Economy	6000.00
0005432658615	17845	Economy	6000.00
0005432657475	17845	Economy	6000.00
0005432655602	17845	Economy	6000.00
0005432664130	17845	Economy	6000.00
0005432869632	17845	Economy	6000.00
0005432661941	17845	Economy	6000.00
0005432869633	17845	Economy	6000.00
0005432667468	17845	Economy	6000.00
0005432664129	17845	Economy	6000.00
0005432655638	17845	Economy	6000.00
0005432663047	17845	Economy	6000.00
0005432663041	17845	Economy	6000.00
0005432655561	17845	Economy	6000.00
0005432660829	17845	Economy	6000.00
0005432661937	17845	Economy	6000.00
0005432664143	17845	Economy	6000.00
0005432664165	26319	Business	18000.00
0005432661946	26319	Business	18000.00
0005432655694	26319	Business	18000.00
0005432663058	26319	Business	18000.00
0005432666418	26319	Business	18000.00
0005432661955	26319	Business	18000.00
0005432869568	26319	Business	18000.00
0005432664160	26319	Business	18000.00
0005432661950	26319	Business	18000.00
0005432664168	26319	Business	18000.00
0005432655700	26319	Economy	6000.00
0005432869561	26319	Economy	6000.00
0005432655699	26319	Economy	6000.00
0005432661952	26319	Economy	6000.00
0005432664163	26319	Economy	6000.00
0005432663069	26319	Economy	6000.00
0005434151730	26319	Economy	6000.00
0005432657492	26319	Economy	6000.00
0005432665304	26319	Economy	6000.00
0005432664159	26319	Economy	6600.00
0005432663068	26319	Economy	6600.00
0005432661944	26319	Economy	6600.00
0005432869565	26319	Economy	6600.00
0005432663056	26319	Economy	6600.00
0005432655704	26319	Economy	6000.00
0005432869553	26319	Economy	6000.00
0005432869577	26319	Economy	6000.00
0005432660846	26319	Economy	6000.00
0005432663070	26319	Economy	6000.00
0005432661956	26319	Economy	6000.00
0005432663066	26319	Economy	6000.00
0005432664169	26319	Economy	6000.00
0005432664162	26319	Economy	6000.00
0005432664171	26319	Economy	6000.00
0005432655701	26319	Economy	6000.00
0005432661948	26319	Economy	6000.00
0005432660847	26319	Economy	6000.00
0005432661951	26319	Economy	6000.00
0005432667485	26319	Economy	6000.00
0005432663067	26319	Economy	6000.00
0005432664158	26319	Economy	6000.00
0005432657493	26319	Economy	6000.00
0005432655695	26319	Economy	6000.00
0005432661949	26319	Economy	6000.00
0005432664167	26319	Economy	6000.00
0005432659736	26319	Economy	6000.00
0005432655702	26319	Economy	6000.00
0005432665303	26319	Economy	6000.00
0005432657494	26319	Economy	6000.00
0005432658620	26319	Economy	6000.00
0005432665305	26319	Economy	6000.00
0005432663061	26319	Economy	6000.00
0005432655696	26319	Economy	6000.00
0005432661957	26319	Economy	6000.00
0005432655698	26319	Economy	6000.00
0005432655703	26319	Economy	6000.00
0005432667483	26319	Economy	6000.00
0005432661954	26319	Economy	6000.00
0005432667484	26319	Economy	6000.00
0005432664170	26319	Economy	6000.00
0005432658621	26319	Economy	6000.00
0005432663060	26319	Economy	6000.00
0005432655697	26319	Economy	6000.00
0005432663064	26319	Economy	6000.00
0005432666417	26319	Economy	6000.00
0005432869578	26319	Economy	6000.00
0005432663059	26319	Economy	6000.00
0005432664161	26319	Economy	6000.00
0005432664166	26319	Economy	6000.00
0005432663062	26319	Economy	6000.00
0005432869559	26319	Economy	6000.00
0005432663057	26319	Economy	6000.00
0005432666419	26319	Economy	6000.00
0005432661958	26319	Economy	6000.00
0005432661959	26319	Economy	6000.00
0005432869560	26319	Economy	6000.00
0005432869564	26319	Economy	6000.00
0005432659735	26319	Economy	6000.00
0005432664172	26319	Economy	6000.00
0005432663065	26319	Economy	6000.00
0005432661947	26319	Economy	6000.00
0005432664164	26319	Economy	6000.00
0005432661953	26319	Economy	6000.00
0005432661945	26319	Economy	6000.00
0005432660848	26319	Economy	6000.00
0005432663063	26319	Economy	6000.00
0005432866119	25051	Business	87300.00
0005432639141	25051	Business	87300.00
0005432639187	25051	Business	87300.00
0005432639233	25051	Business	87300.00
0005432639179	25051	Business	87300.00
0005432639140	25051	Business	87300.00
0005432639242	25051	Business	87300.00
0005432866129	25051	Economy	29100.00
0005432866114	25051	Economy	29100.00
0005432639185	25051	Economy	29100.00
0005432639263	25051	Economy	29100.00
0005432639226	25051	Economy	29100.00
0005432639149	25051	Economy	29100.00
0005432639192	25051	Economy	32000.00
0005432639270	25051	Economy	32000.00
0005432639224	25051	Economy	32000.00
0005432866124	25051	Economy	32000.00
0005432639262	25051	Economy	29100.00
0005432866128	25051	Economy	29100.00
0005432639213	25051	Economy	29100.00
0005432639199	25051	Economy	29100.00
0005432639271	25051	Economy	29100.00
0005432639183	25051	Economy	29100.00
0005432866122	25051	Economy	29100.00
0005432866118	25051	Economy	29100.00
0005432639206	25051	Economy	29100.00
0005432866126	25051	Economy	29100.00
0005432639171	25051	Economy	29100.00
0005432639178	25051	Economy	29100.00
0005432639221	25051	Economy	29100.00
0005432639207	25051	Economy	29100.00
0005432639116	25051	Economy	29100.00
0005432639184	25051	Economy	29100.00
0005432639200	25051	Economy	29100.00
0005432866117	25051	Economy	29100.00
0005432866123	25051	Economy	29100.00
0005432866111	25051	Economy	29100.00
0005432866110	25051	Economy	29100.00
0005432639150	25051	Economy	29100.00
0005432639191	25051	Economy	29100.00
0005432639204	25051	Economy	29100.00
0005432639232	25051	Economy	29100.00
0005432866121	25051	Economy	29100.00
0005432639194	25051	Economy	29100.00
0005432639205	25051	Economy	29100.00
0005432866115	25051	Economy	29100.00
0005432639222	25051	Economy	29100.00
0005432639151	25051	Economy	29100.00
0005432866113	25051	Economy	29100.00
0005432866109	25051	Economy	29100.00
0005432866125	25051	Economy	29100.00
0005432639212	25051	Economy	29100.00
0005432639225	25051	Economy	29100.00
0005432639201	25051	Economy	29100.00
0005432866127	25051	Economy	29100.00
0005432866120	25051	Economy	29100.00
0005432639186	25051	Economy	29100.00
0005432639180	25051	Economy	29100.00
0005432639115	25051	Economy	29100.00
0005432866116	25051	Economy	29100.00
0005432639223	25051	Economy	29100.00
0005432639198	25051	Economy	29100.00
0005432639170	25051	Economy	29100.00
0005432639188	25051	Economy	29100.00
0005432866112	25051	Economy	29100.00
0005432639172	25051	Economy	29100.00
0005432905146	3073	Business	16100.00
0005432905183	3073	Business	16100.00
0005432329413	3073	Business	16100.00
0005432287269	3073	Business	16100.00
0005432329420	3073	Business	16100.00
0005432287270	3073	Business	16100.00
0005432905185	3073	Business	16100.00
0005432329394	3073	Business	16100.00
0005432329395	3073	Business	16100.00
0005432329427	3073	Business	16100.00
0005432329417	3073	Economy	5400.00
0005432329416	3073	Economy	5400.00
0005432329430	3073	Economy	5400.00
0005432329397	3073	Economy	5400.00
0005432329421	3073	Economy	5400.00
0005432329414	3073	Economy	5400.00
0005432329412	3073	Economy	5900.00
0005432329407	3073	Economy	5900.00
0005432905182	3073	Economy	5900.00
0005432848838	3073	Economy	5400.00
0005432905147	3073	Economy	5400.00
0005432905180	3073	Economy	5400.00
0005433438974	3073	Economy	5400.00
0005432287268	3073	Economy	5400.00
0005432329419	3073	Economy	5400.00
0005432329422	3073	Economy	5400.00
0005432848839	3073	Economy	5400.00
0005432329429	3073	Economy	5400.00
0005432329415	3073	Economy	5400.00
0005432329410	3073	Economy	5400.00
0005432329425	3073	Economy	5400.00
0005432329408	3073	Economy	5400.00
0005432329439	3073	Economy	5400.00
0005432329401	3073	Economy	5400.00
0005432329406	3073	Economy	5400.00
0005432329400	3073	Economy	5400.00
0005432329435	3073	Economy	5400.00
0005432905169	3073	Economy	5400.00
0005432329402	3073	Economy	5400.00
0005432329432	3073	Economy	5400.00
0005432329433	3073	Economy	5400.00
0005432329404	3073	Economy	5400.00
0005432329426	3073	Economy	5400.00
0005432329409	3073	Economy	5400.00
0005433438973	3073	Economy	5400.00
0005432329399	3073	Economy	5400.00
0005432329403	3073	Economy	5400.00
0005432329405	3073	Economy	5400.00
0005432905156	3073	Economy	5400.00
0005432329437	3073	Economy	5400.00
0005432329398	3073	Economy	5400.00
0005432905181	3073	Economy	5400.00
0005432905175	3073	Economy	5400.00
0005432329438	3073	Economy	5400.00
0005432329428	3073	Economy	5400.00
0005432329436	3073	Economy	5400.00
0005432329396	3073	Economy	5400.00
0005432287266	3073	Economy	5400.00
0005432329431	3073	Economy	5400.00
0005432329423	3073	Economy	5400.00
0005432905170	3073	Economy	5400.00
0005432287267	3073	Economy	5400.00
0005432329434	3073	Economy	5400.00
0005432329418	3073	Economy	5400.00
0005432329424	3073	Economy	5400.00
0005432329411	3073	Economy	5400.00
0005432848854	31153	Business	16100.00
0005432848848	31153	Business	16100.00
0005433438900	31153	Business	16100.00
0005432848855	31153	Business	16100.00
0005432329050	31153	Business	16100.00
0005432054349	31153	Business	16100.00
0005433438927	31153	Business	16100.00
0005432328872	31153	Economy	5400.00
0005432328933	31153	Economy	5400.00
0005432848847	31153	Economy	5400.00
0005433438936	31153	Economy	5400.00
0005432328892	31153	Economy	5400.00
0005432328893	31153	Economy	5400.00
0005432905215	31153	Economy	5400.00
0005432848849	31153	Economy	5900.00
0005433438941	31153	Economy	5900.00
0005432848850	31153	Economy	5900.00
0005432054351	31153	Economy	5900.00
0005432329053	31153	Economy	5400.00
0005432848852	31153	Economy	5400.00
0005432329010	31153	Economy	5400.00
0005432328981	31153	Economy	5400.00
0005432329188	31153	Economy	5400.00
0005432054350	31153	Economy	5400.00
0005432329044	31153	Economy	5400.00
0005432328877	31153	Economy	5400.00
0005433438926	31153	Economy	5400.00
0005432329051	31153	Economy	5400.00
0005432848851	31153	Economy	5400.00
0005432329250	31153	Economy	5400.00
0005433438902	31153	Economy	5400.00
0005433438923	31153	Economy	5400.00
0005432329085	31153	Economy	5400.00
0005432328958	31153	Economy	5400.00
0005432848856	31153	Economy	5400.00
0005432905214	31153	Economy	5400.00
0005432328898	31153	Economy	5400.00
0005432329090	31153	Economy	5400.00
0005432329187	31153	Economy	5400.00
0005432329045	31153	Economy	5400.00
0005432328993	31153	Economy	5400.00
0005433438922	31153	Economy	5400.00
0005433438871	31153	Economy	5400.00
0005432329014	31153	Economy	5400.00
0005432328948	31153	Economy	5400.00
0005432328926	31153	Economy	5400.00
0005432328832	31153	Economy	5400.00
0005432328980	31153	Economy	5400.00
0005432328873	31153	Economy	5400.00
0005432328997	31153	Economy	5400.00
0005432328944	31153	Economy	5400.00
0005433438951	31153	Economy	5400.00
0005432328766	31153	Economy	5400.00
0005432328879	31153	Economy	5400.00
0005433438872	31153	Economy	5400.00
0005432328891	31153	Economy	5400.00
0005433438950	31153	Economy	5400.00
0005432328897	31153	Economy	5400.00
0005432848853	31153	Economy	5400.00
0005433438901	31153	Economy	5400.00
0005432329052	31153	Economy	5400.00
0005432329110	31153	Economy	5400.00
0005432328816	31153	Economy	5400.00
0005433438905	31153	Economy	5400.00
0005435999518	6221	Business	124600.00
0005435999529	6221	Business	124600.00
0005434309949	6221	Business	124600.00
0005435487868	6221	Business	124600.00
0005435999523	6221	Business	124600.00
0005435487833	6221	Economy	41500.00
0005435999511	6221	Economy	41500.00
0005434309953	6221	Economy	41500.00
0005435999514	6221	Economy	41500.00
0005432146231	6221	Economy	41500.00
0005435999527	6221	Economy	41500.00
0005435487984	6221	Economy	41500.00
0005434309962	6221	Economy	41500.00
0005435999519	6221	Economy	41500.00
0005435487983	6221	Economy	41500.00
0005435999513	6221	Economy	41500.00
0005435999516	6221	Economy	41500.00
0005435487967	6221	Economy	41500.00
0005435999512	6221	Economy	41500.00
0005434309959	6221	Economy	41500.00
0005435999524	6221	Economy	41500.00
0005435297093	6221	Economy	41500.00
0005435999521	6221	Economy	41500.00
0005434309950	6221	Economy	41500.00
0005435297120	6221	Economy	41500.00
0005435999528	6221	Economy	41500.00
0005435999526	6221	Economy	41500.00
0005435999525	6221	Economy	45700.00
0005435488026	6221	Economy	45700.00
0005435487994	6221	Economy	41500.00
0005434309961	6221	Economy	41500.00
0005435999522	6221	Economy	41500.00
0005435487913	6221	Economy	41500.00
0005434309960	6221	Economy	41500.00
0005435488013	6221	Economy	41500.00
0005434309958	6221	Economy	41500.00
0005434309955	6221	Economy	41500.00
0005435488028	6221	Economy	41500.00
0005434309957	6221	Economy	41500.00
0005435487956	6221	Economy	41500.00
0005434309956	6221	Economy	41500.00
0005435487934	6221	Economy	41500.00
0005435999515	6221	Economy	41500.00
0005435488063	6221	Economy	41500.00
0005434309952	6221	Economy	41500.00
0005435297119	6221	Economy	41500.00
0005435999520	6221	Economy	41500.00
0005435487995	6221	Economy	41500.00
0005435487915	6221	Economy	41500.00
0005435487955	6221	Economy	41500.00
0005434309954	6221	Economy	41500.00
0005435487953	6221	Economy	41500.00
0005432146232	6221	Economy	41500.00
0005435487936	6221	Economy	41500.00
0005434309951	6221	Economy	41500.00
0005435999517	6221	Economy	41500.00
0005435999510	6221	Economy	41500.00
0005435999339	19583	Business	124600.00
0005435999305	19583	Business	124600.00
0005435488142	19583	Business	124600.00
0005435999365	19583	Business	124600.00
0005435488155	19583	Business	124600.00
0005435999340	19583	Economy	41500.00
0005435488151	19583	Economy	41500.00
0005435488141	19583	Economy	41500.00
0005435488146	19583	Economy	41500.00
0005435999315	19583	Economy	41500.00
0005435488152	19583	Economy	41500.00
0005435999318	19583	Economy	41500.00
0005434309837	19583	Economy	41500.00
0005435999301	19583	Economy	41500.00
0005435297164	19583	Economy	41500.00
0005435488160	19583	Economy	41500.00
0005434309860	19583	Economy	41500.00
0005435488159	19583	Economy	41500.00
0005435297166	19583	Economy	41500.00
0005434309803	19583	Economy	41500.00
0005435488143	19583	Economy	41500.00
0005435488161	19583	Economy	41500.00
0005435297168	19583	Economy	45700.00
0005435488148	19583	Economy	45700.00
0005435488145	19583	Economy	41500.00
0005435999302	19583	Economy	41500.00
0005435488153	19583	Economy	41500.00
0005435488144	19583	Economy	41500.00
0005435488147	19583	Economy	41500.00
0005435999313	19583	Economy	41500.00
0005434309845	19583	Economy	41500.00
0005435488154	19583	Economy	41500.00
0005435999361	19583	Economy	41500.00
0005434309826	19583	Economy	41500.00
0005435999362	19583	Economy	41500.00
0005434309844	19583	Economy	41500.00
0005435488162	19583	Economy	41500.00
0005434309839	19583	Economy	41500.00
0005435488156	19583	Economy	41500.00
0005435297163	19583	Economy	41500.00
0005434309798	19583	Economy	41500.00
0005435999314	19583	Economy	41500.00
0005435297167	19583	Economy	41500.00
0005435488157	19583	Economy	41500.00
0005435999356	19583	Economy	41500.00
0005434309878	19583	Economy	41500.00
0005435488140	19583	Economy	41500.00
0005435488149	19583	Economy	41500.00
0005435999299	19583	Economy	41500.00
0005435999328	19583	Economy	41500.00
0005435488150	19583	Economy	41500.00
0005435999319	19583	Economy	41500.00
0005434309846	19583	Economy	41500.00
0005435999337	19583	Economy	41500.00
0005434309879	19583	Economy	41500.00
0005435297165	19583	Economy	41500.00
0005435488158	19583	Economy	41500.00
0005435999306	19583	Economy	41500.00
0005433158163	17540	Economy	12300.00
0005434446534	17540	Economy	12300.00
0005433158165	17540	Economy	12300.00
0005434446535	17540	Economy	12300.00
0005433158167	17540	Economy	12300.00
0005434446536	17540	Economy	12300.00
0005433158164	17540	Economy	12300.00
0005433158166	17540	Economy	12300.00
0005434446524	17540	Economy	12300.00
0005434446523	17540	Economy	12300.00
0005435518204	1562	Business	86000.00
0005435502646	1562	Business	86000.00
0005435518212	1562	Business	86000.00
0005435518203	1562	Business	86000.00
0005435502642	1562	Business	86000.00
0005435502643	1562	Business	86000.00
0005435502641	1562	Business	86000.00
0005434566128	1562	Business	86000.00
0005434566130	1562	Business	86000.00
0005434566131	1562	Business	86000.00
0005435518214	1562	Business	86000.00
0005435518200	1562	Economy	28700.00
0005435502653	1562	Economy	28700.00
0005435502647	1562	Economy	28700.00
0005435502652	1562	Economy	28700.00
0005435502649	1562	Economy	28700.00
0005435508535	1562	Economy	28700.00
0005435508539	1562	Economy	28700.00
0005435518201	1562	Economy	28700.00
0005435508544	1562	Economy	28700.00
0005435508543	1562	Economy	31500.00
0005433186162	1562	Economy	31500.00
0005435518211	1562	Economy	31500.00
0005434566119	1562	Economy	31500.00
0005433186198	1562	Economy	31500.00
0005435518207	1562	Economy	28700.00
0005435518213	1562	Economy	28700.00
0005435518215	1562	Economy	28700.00
0005434566122	1562	Economy	28700.00
0005435508540	1562	Economy	28700.00
0005433186152	1562	Economy	28700.00
0005435508548	1562	Economy	28700.00
0005435518206	1562	Economy	28700.00
0005435518202	1562	Economy	28700.00
0005434566126	1562	Economy	28700.00
0005435518209	1562	Economy	28700.00
0005432291968	1562	Economy	28700.00
0005433186177	1562	Economy	28700.00
0005435502661	1562	Economy	28700.00
0005435518210	1562	Economy	28700.00
0005435508542	1562	Economy	28700.00
0005435502659	1562	Economy	28700.00
0005435502651	1562	Economy	28700.00
0005434566125	1562	Economy	28700.00
0005435502644	1562	Economy	28700.00
0005435502655	1562	Economy	28700.00
0005432291967	1562	Economy	28700.00
0005435502650	1562	Economy	28700.00
0005435518208	1562	Economy	28700.00
0005435502656	1562	Economy	28700.00
0005435508538	1562	Economy	28700.00
0005434566121	1562	Economy	28700.00
0005434566127	1562	Economy	28700.00
0005435502648	1562	Economy	28700.00
0005435508541	1562	Economy	28700.00
0005435508536	1562	Economy	28700.00
0005435518205	1562	Economy	28700.00
0005435518199	1562	Economy	28700.00
0005435508545	1562	Economy	28700.00
0005434566124	1562	Economy	28700.00
0005434566118	1562	Economy	28700.00
0005435508549	1562	Economy	28700.00
0005435518216	1562	Economy	28700.00
0005434566129	1562	Economy	28700.00
0005435502662	1562	Economy	28700.00
0005434566123	1562	Economy	28700.00
0005435508547	1562	Economy	28700.00
0005435508537	1562	Economy	28700.00
0005434566120	1562	Economy	28700.00
0005435518198	1562	Economy	28700.00
0005433186164	1562	Economy	28700.00
0005435502658	1562	Economy	28700.00
0005433186226	1562	Economy	28700.00
0005433186156	1562	Economy	28700.00
0005433186182	1562	Economy	28700.00
0005435502657	1562	Economy	28700.00
0005435508546	1562	Economy	28700.00
0005435508534	1562	Economy	28700.00
0005435518217	1562	Economy	28700.00
0005435502654	1562	Economy	28700.00
0005433186154	1562	Economy	28700.00
0005433186153	1562	Economy	28700.00
0005435502645	1562	Economy	28700.00
0005435502660	1562	Economy	28700.00
0005433186186	1562	Economy	28700.00
0005434566034	20860	Business	86000.00
0005435502436	20860	Business	86000.00
0005435545771	20860	Business	86000.00
0005435529363	20860	Business	86000.00
0005435545758	20860	Business	86000.00
0005434566040	20860	Business	86000.00
0005434566066	20860	Business	86000.00
0005433186250	20860	Business	86000.00
0005435529327	20860	Business	86000.00
0005435545785	20860	Economy	28700.00
0005435502432	20860	Economy	28700.00
0005433186257	20860	Economy	28700.00
0005435545798	20860	Economy	28700.00
0005435502396	20860	Economy	28700.00
0005434565975	20860	Economy	31500.00
0005435529450	20860	Economy	31500.00
0005435545770	20860	Economy	31500.00
0005433186251	20860	Economy	31500.00
0005433186255	20860	Economy	28700.00
0005435502431	20860	Economy	28700.00
0005435529366	20860	Economy	28700.00
0005435529429	20860	Economy	28700.00
0005435545779	20860	Economy	28700.00
0005435545776	20860	Economy	28700.00
0005435545765	20860	Economy	28700.00
0005435529296	20860	Economy	28700.00
0005435529383	20860	Economy	28700.00
0005435502498	20860	Economy	28700.00
0005435502445	20860	Economy	28700.00
0005435545772	20860	Economy	28700.00
0005435545761	20860	Economy	28700.00
0005435502423	20860	Economy	28700.00
0005433186253	20860	Economy	28700.00
0005434566019	20860	Economy	28700.00
0005435502461	20860	Economy	28700.00
0005435502343	20860	Economy	28700.00
0005435502425	20860	Economy	28700.00
0005433186249	20860	Economy	28700.00
0005435502451	20860	Economy	28700.00
0005435529359	20860	Economy	28700.00
0005435529377	20860	Economy	28700.00
0005434565993	20860	Economy	28700.00
0005434565995	20860	Economy	28700.00
0005435502395	20860	Economy	28700.00
0005435529344	20860	Economy	28700.00
0005434566009	20860	Economy	28700.00
0005434566002	20860	Economy	28700.00
0005435502499	20860	Economy	28700.00
0005434566030	20860	Economy	28700.00
0005435529378	20860	Economy	28700.00
0005435502476	20860	Economy	28700.00
0005434565994	20860	Economy	28700.00
0005433186256	20860	Economy	28700.00
0005435529297	20860	Economy	28700.00
0005435529380	20860	Economy	28700.00
0005435502424	20860	Economy	28700.00
0005435502475	20860	Economy	28700.00
0005434566008	20860	Economy	28700.00
0005433186252	20860	Economy	28700.00
0005435502444	20860	Economy	28700.00
0005434566067	20860	Economy	28700.00
0005435502441	20860	Economy	28700.00
0005435502344	20860	Economy	28700.00
0005435502452	20860	Economy	28700.00
0005434566006	20860	Economy	28700.00
0005435529449	20860	Economy	28700.00
0005435529384	20860	Economy	28700.00
0005435545766	20860	Economy	28700.00
0005433186248	20860	Economy	28700.00
0005434565992	20860	Economy	28700.00
0005433186254	20860	Economy	28700.00
0005435502405	20860	Economy	28700.00
0005435153843	3892	Economy	21600.00
0005435931624	3892	Economy	21600.00
0005435153847	3892	Economy	19700.00
0005435153842	3892	Economy	19700.00
0005435931625	3892	Economy	19700.00
0005435931612	3892	Economy	19700.00
0005435931613	3892	Economy	19700.00
0005435153846	3892	Economy	19700.00
0005435153845	3892	Economy	19700.00
0005435153844	3892	Economy	19700.00
0005435153848	3892	Economy	19700.00
0005435931621	3892	Economy	19700.00
0005435153787	21880	Economy	19700.00
0005435153774	21880	Economy	19700.00
0005435153788	21880	Economy	19700.00
0005435931660	21880	Economy	19700.00
0005435153785	21880	Economy	19700.00
0005435153775	21880	Economy	19700.00
0005435153786	21880	Economy	19700.00
0005435931658	21880	Economy	19700.00
0005435153784	21880	Economy	19700.00
0005435153737	21880	Economy	19700.00
0005435931662	21880	Economy	19700.00
0005435153738	21880	Economy	19700.00
0005435153789	21880	Economy	19700.00
0005435931659	21880	Economy	19700.00
0005435931661	21880	Economy	19700.00
0005432629077	7208	Economy	14300.00
0005435225599	7208	Economy	14300.00
0005432629084	7208	Economy	14300.00
0005432629080	7208	Economy	14300.00
0005435225671	7208	Economy	13000.00
0005435225656	7208	Economy	13000.00
0005432629081	7208	Economy	13000.00
0005432629074	7208	Economy	13000.00
0005432629075	7208	Economy	13000.00
0005435225638	7208	Economy	13000.00
0005432629070	7208	Economy	13000.00
0005432629078	7208	Economy	13000.00
0005432629071	7208	Economy	13000.00
0005432629072	7208	Economy	13000.00
0005432629082	7208	Economy	13000.00
0005432629076	7208	Economy	13000.00
0005432629083	7208	Economy	13000.00
0005432629079	7208	Economy	13000.00
0005432629073	7208	Economy	13000.00
0005435225653	7208	Economy	13000.00
0005435225708	28112	Economy	14300.00
0005435225710	28112	Economy	14300.00
0005435225706	28112	Economy	13000.00
0005435225711	28112	Economy	13000.00
0005432628986	28112	Economy	13000.00
0005435225713	28112	Economy	13000.00
0005432628942	28112	Economy	13000.00
0005432628998	28112	Economy	13000.00
0005432629012	28112	Economy	13000.00
0005432629003	28112	Economy	13000.00
0005432628961	28112	Economy	13000.00
0005432628977	28112	Economy	13000.00
0005435225707	28112	Economy	13000.00
0005435225709	28112	Economy	13000.00
0005432628932	28112	Economy	13000.00
0005432628957	28112	Economy	13000.00
0005432629011	28112	Economy	13000.00
0005432628987	28112	Economy	13000.00
0005435225712	28112	Economy	13000.00
0005432628941	28112	Economy	13000.00
0005432628983	28112	Economy	13000.00
0005432628951	28112	Economy	13000.00
0005432628916	28112	Economy	13000.00
0005432628878	28112	Economy	13000.00
0005432628993	28112	Economy	13000.00
0005432629002	28112	Economy	13000.00
0005435225714	28112	Economy	13000.00
0005432628877	28112	Economy	13000.00
0005435960111	8727	Economy	11500.00
0005435960109	8727	Economy	10500.00
0005434267957	8727	Economy	10500.00
0005435960110	8727	Economy	10500.00
0005435960108	8727	Economy	10500.00
0005434267983	8727	Economy	10500.00
0005434267984	8727	Economy	10500.00
0005434268010	15250	Economy	10500.00
0005435960073	15250	Economy	10500.00
0005435960080	15250	Economy	10500.00
0005434268009	15250	Economy	10500.00
0005435960090	15250	Economy	10500.00
0005435960072	15250	Economy	10500.00
0005434268008	15250	Economy	10500.00
0005432693519	1178	Business	115000.00
0005432693529	1178	Business	115000.00
0005432693508	1178	Business	115000.00
0005432677632	1178	Business	115000.00
0005432693515	1178	Business	115000.00
0005432677630	1178	Business	115000.00
0005432693522	1178	Business	115000.00
0005432675376	1178	Business	115000.00
0005432873354	1178	Business	115000.00
0005432693537	1178	Business	115000.00
0005432675361	1178	Business	115000.00
0005432675370	1178	Business	115000.00
0005432675365	1178	Economy	38300.00
0005432675372	1178	Economy	38300.00
0005432693532	1178	Economy	38300.00
0005432675362	1178	Economy	38300.00
0005432693517	1178	Economy	42200.00
0005432675375	1178	Economy	42200.00
0005432693513	1178	Economy	38300.00
0005432675377	1178	Economy	38300.00
0005432693514	1178	Economy	38300.00
0005432873333	1178	Economy	38300.00
0005432873340	1178	Economy	38300.00
0005432693526	1178	Economy	38300.00
0005432677633	1178	Economy	38300.00
0005432675367	1178	Economy	38300.00
0005432693516	1178	Economy	38300.00
0005432693524	1178	Economy	38300.00
0005432675364	1178	Economy	38300.00
0005432675371	1178	Economy	38300.00
0005432693525	1178	Economy	38300.00
0005432693527	1178	Economy	38300.00
0005432677634	1178	Economy	38300.00
0005432693518	1178	Economy	38300.00
0005432693512	1178	Economy	38300.00
0005432693536	1178	Economy	38300.00
0005432675373	1178	Economy	38300.00
0005432675368	1178	Economy	38300.00
0005432873370	1178	Economy	38300.00
0005432675369	1178	Economy	38300.00
0005432693534	1178	Economy	38300.00
0005432693507	1178	Economy	38300.00
0005432693509	1178	Economy	38300.00
0005432693521	1178	Economy	38300.00
0005432693510	1178	Economy	38300.00
0005432675374	1178	Economy	38300.00
0005432693535	1178	Economy	38300.00
0005432675366	1178	Economy	38300.00
0005432693533	1178	Economy	38300.00
0005432693530	1178	Economy	38300.00
0005432873347	1178	Economy	38300.00
0005432675363	1178	Economy	38300.00
0005432693520	1178	Economy	38300.00
0005432693523	1178	Economy	38300.00
0005432693528	1178	Economy	38300.00
0005432873360	1178	Economy	38300.00
0005432873371	1178	Economy	38300.00
0005432677631	1178	Economy	38300.00
0005432873353	1178	Economy	38300.00
0005432693511	1178	Economy	38300.00
0005432693531	1178	Economy	38300.00
0005432693172	17486	Business	115000.00
0005432675252	17486	Business	115000.00
0005432693235	17486	Business	115000.00
0005432693161	17486	Business	115000.00
0005432873406	17486	Business	115000.00
0005432693327	17486	Business	115000.00
0005432693288	17486	Business	115000.00
0005432693207	17486	Business	115000.00
0005432693315	17486	Business	115000.00
0005432873405	17486	Business	115000.00
0005432675291	17486	Economy	38300.00
0005432693173	17486	Economy	38300.00
0005432693189	17486	Economy	42200.00
0005432693281	17486	Economy	38300.00
0005432873403	17486	Economy	38300.00
0005432693319	17486	Economy	38300.00
0005432675251	17486	Economy	38300.00
0005432675242	17486	Economy	38300.00
0005432693256	17486	Economy	38300.00
0005432693212	17486	Economy	38300.00
0005432675250	17486	Economy	38300.00
0005432675207	17486	Economy	38300.00
0005432677588	17486	Economy	38300.00
0005432675239	17486	Economy	38300.00
0005432873400	17486	Economy	38300.00
0005432873399	17486	Economy	38300.00
0005432693280	17486	Economy	38300.00
0005432693333	17486	Economy	38300.00
0005432693320	17486	Economy	38300.00
0005432675249	17486	Economy	38300.00
0005432693269	17486	Economy	38300.00
0005432873404	17486	Economy	38300.00
0005432693182	17486	Economy	38300.00
0005432675205	17486	Economy	38300.00
0005432693314	17486	Economy	38300.00
0005432693265	17486	Economy	38300.00
0005432873402	17486	Economy	38300.00
0005432675263	17486	Economy	38300.00
0005432675235	17486	Economy	38300.00
0005432693264	17486	Economy	38300.00
0005432693183	17486	Economy	38300.00
0005432693206	17486	Economy	38300.00
0005432693328	17486	Economy	38300.00
0005432693213	17486	Economy	38300.00
0005432693171	17486	Economy	38300.00
0005432693289	17486	Economy	38300.00
0005432693234	17486	Economy	38300.00
0005432873401	17486	Economy	38300.00
0005432693266	17486	Economy	38300.00
0005432675240	17486	Economy	38300.00
0005434435429	1142	Economy	15200.00
0005434435414	1142	Economy	15200.00
0005433156857	1142	Economy	15200.00
0005434435417	1142	Economy	13900.00
0005434435420	1142	Economy	13900.00
0005434435421	1142	Economy	13900.00
0005433156848	1142	Economy	13900.00
0005434435415	1142	Economy	13900.00
0005434435418	1142	Economy	13900.00
0005434435423	1142	Economy	13900.00
0005433156847	1142	Economy	13900.00
0005434435416	1142	Economy	13900.00
0005434435425	1142	Economy	13900.00
0005433156826	1142	Economy	13900.00
0005433156858	1142	Economy	13900.00
0005434435427	1142	Economy	13900.00
0005434435419	1142	Economy	13900.00
0005434435422	1142	Economy	13900.00
0005434435426	1142	Economy	13900.00
0005433156837	1142	Economy	13900.00
0005434435428	1142	Economy	13900.00
0005434435424	1142	Economy	13900.00
0005433156883	17296	Economy	15200.00
0005434435286	17296	Economy	15200.00
0005434435293	17296	Economy	15200.00
0005434435256	17296	Economy	13900.00
0005433156889	17296	Economy	13900.00
0005433156885	17296	Economy	13900.00
0005434435257	17296	Economy	13900.00
0005433156886	17296	Economy	13900.00
0005433156887	17296	Economy	13900.00
0005434435288	17296	Economy	13900.00
0005434435292	17296	Economy	13900.00
0005434435328	17296	Economy	13900.00
0005433156884	17296	Economy	13900.00
0005434435366	17296	Economy	13900.00
0005434435365	17296	Economy	13900.00
0005434435314	17296	Economy	13900.00
0005433156881	17296	Economy	13900.00
0005433156882	17296	Economy	13900.00
0005434435275	17296	Economy	13900.00
0005434435313	17296	Economy	13900.00
0005434435247	17296	Economy	13900.00
0005434435311	17296	Economy	13900.00
0005434435279	17296	Economy	13900.00
0005433156880	17296	Economy	13900.00
0005434435283	17296	Economy	13900.00
0005433156888	17296	Economy	13900.00
0005434435287	17296	Economy	13900.00
0005435086950	4067	Economy	8200.00
0005435928191	4067	Economy	8200.00
0005435928167	4067	Economy	7500.00
0005435086954	4067	Economy	7500.00
0005435928197	4067	Economy	7500.00
0005435086949	4067	Economy	7500.00
0005435086955	4067	Economy	7500.00
0005435928166	4067	Economy	7500.00
0005435928188	4067	Economy	7500.00
0005435928185	4067	Economy	7500.00
0005435086953	4067	Economy	7500.00
0005435086952	4067	Economy	7500.00
0005435086951	4067	Economy	7500.00
0005435086904	24425	Economy	8200.00
0005435086875	24425	Economy	8200.00
0005435928219	24425	Economy	7500.00
0005435086874	24425	Economy	7500.00
0005435086889	24425	Economy	7500.00
0005435928216	24425	Economy	7500.00
0005435086895	24425	Economy	7500.00
0005435086905	24425	Economy	7500.00
0005435086900	24425	Economy	7500.00
0005435928218	24425	Economy	7500.00
0005435086886	24425	Economy	7500.00
0005435086892	24425	Economy	7500.00
0005435928217	24425	Economy	7500.00
0005435086866	24425	Economy	7500.00
0005435086864	24425	Economy	7500.00
0005435086865	24425	Economy	7500.00
0005433373624	2466	Business	86800.00
0005433373610	2466	Business	86800.00
0005435706645	2466	Business	86800.00
0005435706640	2466	Business	86800.00
0005433373538	2466	Business	86800.00
0005435706625	2466	Business	86800.00
0005433373611	2466	Business	86800.00
0005435706623	2466	Economy	28900.00
0005433373575	2466	Economy	28900.00
0005435706647	2466	Economy	28900.00
0005435706639	2466	Economy	28900.00
0005435706636	2466	Economy	28900.00
0005433373573	2466	Economy	28900.00
0005433373608	2466	Economy	31800.00
0005435706643	2466	Economy	31800.00
0005435706642	2466	Economy	31800.00
0005435706641	2466	Economy	31800.00
0005435706631	2466	Economy	28900.00
0005433373609	2466	Economy	28900.00
0005435706617	2466	Economy	28900.00
0005435706635	2466	Economy	28900.00
0005435706624	2466	Economy	28900.00
0005433373574	2466	Economy	28900.00
0005433373579	2466	Economy	28900.00
0005433373595	2466	Economy	28900.00
0005435706630	2466	Economy	28900.00
0005435706629	2466	Economy	28900.00
0005433373612	2466	Economy	28900.00
0005435706628	2466	Economy	28900.00
0005435706622	2466	Economy	28900.00
0005435706627	2466	Economy	28900.00
0005433373607	2466	Economy	28900.00
0005435706621	2466	Economy	28900.00
0005433373600	2466	Economy	28900.00
0005433373558	2466	Economy	28900.00
0005433373572	2466	Economy	28900.00
0005433373605	2466	Economy	28900.00
0005433373539	2466	Economy	28900.00
0005435706646	2466	Economy	28900.00
0005435706649	2466	Economy	28900.00
0005435706634	2466	Economy	28900.00
0005435706650	2466	Economy	28900.00
0005433373578	2466	Economy	28900.00
0005435706632	2466	Economy	28900.00
0005435706620	2466	Economy	28900.00
0005435706633	2466	Economy	28900.00
0005435706638	2466	Economy	28900.00
0005433373613	2466	Economy	28900.00
0005433373601	2466	Economy	28900.00
0005435706618	2466	Economy	28900.00
0005435706651	2466	Economy	28900.00
0005435706626	2466	Economy	28900.00
0005435706644	2466	Economy	28900.00
0005435706619	2466	Economy	28900.00
0005435706648	2466	Economy	28900.00
0005433373599	2466	Economy	28900.00
0005435706637	2466	Economy	28900.00
0005435706538	27042	Business	86800.00
0005435706485	27042	Business	86800.00
0005435706537	27042	Business	86800.00
0005435706534	27042	Business	86800.00
0005435706423	27042	Business	86800.00
0005435706443	27042	Business	86800.00
0005433373673	27042	Business	86800.00
0005435706546	27042	Business	86800.00
0005435706474	27042	Business	86800.00
0005433373675	27042	Economy	28900.00
0005433373677	27042	Economy	28900.00
0005435706492	27042	Economy	28900.00
0005433373669	27042	Economy	28900.00
0005435706496	27042	Economy	28900.00
0005435706509	27042	Economy	28900.00
0005433373671	27042	Economy	28900.00
0005435706447	27042	Economy	31800.00
0005433373679	27042	Economy	31800.00
0005435706472	27042	Economy	31800.00
0005433373676	27042	Economy	31800.00
0005433373664	27042	Economy	28900.00
0005435706498	27042	Economy	28900.00
0005435706436	27042	Economy	28900.00
0005435706520	27042	Economy	28900.00
0005433373663	27042	Economy	28900.00
0005435706473	27042	Economy	28900.00
0005435706457	27042	Economy	28900.00
0005433373682	27042	Economy	28900.00
0005433373666	27042	Economy	28900.00
0005433373678	27042	Economy	28900.00
0005435706524	27042	Economy	28900.00
0005435706525	27042	Economy	28900.00
0005435706453	27042	Economy	28900.00
0005435706471	27042	Economy	28900.00
0005435706456	27042	Economy	28900.00
0005435706479	27042	Economy	28900.00
0005433373668	27042	Economy	28900.00
0005435706448	27042	Economy	28900.00
0005435706467	27042	Economy	28900.00
0005435706455	27042	Economy	28900.00
0005435706552	27042	Economy	28900.00
0005435706478	27042	Economy	28900.00
0005433373670	27042	Economy	28900.00
0005435706430	27042	Economy	28900.00
0005435706451	27042	Economy	28900.00
0005435706545	27042	Economy	28900.00
0005433373667	27042	Economy	28900.00
0005435706442	27042	Economy	28900.00
0005435706551	27042	Economy	28900.00
0005435706466	27042	Economy	28900.00
0005435706491	27042	Economy	28900.00
0005433373683	27042	Economy	28900.00
0005435706424	27042	Economy	28900.00
0005435706494	27042	Economy	28900.00
0005433373674	27042	Economy	28900.00
0005433373672	27042	Economy	28900.00
0005433373665	27042	Economy	28900.00
0005435706465	27042	Economy	28900.00
0005433373680	27042	Economy	28900.00
0005435706454	27042	Economy	28900.00
0005433373681	27042	Economy	28900.00
0005435706477	27042	Economy	28900.00
0005435706495	27042	Economy	28900.00
0005434964506	1318	Business	203300.00
0005433261596	1318	Business	203300.00
0005434964523	1318	Business	203300.00
0005434964526	1318	Business	203300.00
0005434964502	1318	Business	203300.00
0005434964512	1318	Business	203300.00
0005434964534	1318	Business	203300.00
0005433261607	1318	Business	203300.00
0005434964525	1318	Business	203300.00
0005434964528	1318	Business	203300.00
0005434964540	1318	Business	203300.00
0005434964516	1318	Economy	74500.00
0005433261671	1318	Economy	74500.00
0005434964511	1318	Economy	74500.00
0005434964488	1318	Economy	67800.00
0005434964513	1318	Economy	67800.00
0005434964504	1318	Economy	67800.00
0005434964507	1318	Economy	67800.00
0005433261649	1318	Economy	67800.00
0005434964496	1318	Economy	67800.00
0005434964520	1318	Economy	67800.00
0005432279306	1318	Economy	67800.00
0005434964535	1318	Economy	67800.00
0005434964518	1318	Economy	67800.00
0005433261630	1318	Economy	67800.00
0005434964532	1318	Economy	67800.00
0005434964486	1318	Economy	67800.00
0005432279300	1318	Economy	67800.00
0005434964527	1318	Economy	67800.00
0005433261618	1318	Economy	67800.00
0005433261642	1318	Economy	67800.00
0005432279304	1318	Economy	67800.00
0005433261632	1318	Economy	67800.00
0005433261675	1318	Economy	67800.00
0005433261629	1318	Economy	67800.00
0005433261615	1318	Economy	67800.00
0005433261676	1318	Economy	67800.00
0005433261612	1318	Economy	67800.00
0005433261631	1318	Economy	67800.00
0005433261617	1318	Economy	67800.00
0005434964487	1318	Economy	67800.00
0005432279308	1318	Economy	67800.00
0005434964491	1318	Economy	67800.00
0005433261606	1318	Economy	67800.00
0005434964529	1318	Economy	67800.00
0005434964541	1318	Economy	67800.00
0005433261576	1318	Economy	67800.00
0005433261591	1318	Economy	67800.00
0005433261637	1318	Economy	67800.00
0005433261581	1318	Economy	67800.00
0005434964482	1318	Economy	67800.00
0005434964515	1318	Economy	67800.00
0005433261677	1318	Economy	67800.00
0005434964522	1318	Economy	67800.00
0005434964505	1318	Economy	67800.00
0005434964493	1318	Economy	74500.00
0005434964517	1318	Economy	67800.00
0005432279305	1318	Economy	74500.00
0005433261613	1318	Economy	67800.00
0005434964521	1318	Economy	67800.00
0005434964508	1318	Economy	67800.00
0005434964489	1318	Economy	67800.00
0005434964494	1318	Economy	67800.00
0005434964481	1318	Economy	67800.00
0005432279307	1318	Economy	67800.00
0005433261608	1318	Economy	67800.00
0005433261628	1318	Economy	67800.00
0005434964533	1318	Economy	67800.00
0005433261614	1318	Economy	67800.00
0005432279303	1318	Economy	67800.00
0005434964497	1318	Economy	67800.00
0005434964519	1318	Economy	67800.00
0005434964484	1318	Economy	67800.00
0005433261582	1318	Economy	67800.00
0005434964524	1318	Economy	67800.00
0005434964538	1318	Economy	67800.00
0005433261670	1318	Economy	67800.00
0005434964490	1318	Economy	67800.00
0005434964503	1318	Economy	67800.00
0005433261639	1318	Economy	67800.00
0005434964495	1318	Economy	67800.00
0005434964499	1318	Economy	67800.00
0005434964530	1318	Economy	67800.00
0005434964498	1318	Economy	67800.00
0005433261583	1318	Economy	67800.00
0005434964531	1318	Economy	67800.00
0005432279301	1318	Economy	67800.00
0005434964539	1318	Economy	67800.00
0005434964509	1318	Economy	67800.00
0005434964501	1318	Economy	67800.00
0005434964485	1318	Economy	67800.00
0005434964536	1318	Economy	67800.00
0005434964537	1318	Economy	67800.00
0005434964500	1318	Economy	67800.00
0005432279302	1318	Economy	67800.00
0005433261616	1318	Economy	67800.00
0005434964483	1318	Economy	67800.00
0005434964492	1318	Economy	67800.00
0005434964514	1318	Economy	67800.00
0005434964510	1318	Economy	67800.00
0005434626110	4852	Business	44200.00
0005434626114	4852	Business	44200.00
0005434626107	4852	Business	44200.00
0005434626108	4852	Economy	14700.00
0005434626109	4852	Economy	14700.00
0005433194861	4852	Economy	14700.00
0005435907543	4852	Economy	14700.00
0005435907538	4852	Economy	14700.00
0005433194859	4852	Economy	14700.00
0005434626106	4852	Economy	14700.00
0005434626112	4852	Economy	14700.00
0005435907542	4852	Economy	14700.00
0005434626113	4852	Economy	14700.00
0005435907524	4852	Economy	14700.00
0005435907523	4852	Economy	14700.00
0005433194858	4852	Economy	14700.00
0005434626111	4852	Economy	14700.00
0005435907544	4852	Economy	14700.00
0005435907555	4852	Economy	14700.00
0005434626018	32903	Business	44200.00
0005433194898	32903	Business	44200.00
0005435907584	32903	Business	44200.00
0005434626019	32903	Business	44200.00
0005435907579	32903	Business	44200.00
0005434626030	32903	Economy	16200.00
0005434626061	32903	Economy	16200.00
0005434626081	32903	Economy	14700.00
0005434626063	32903	Economy	14700.00
0005435907581	32903	Economy	14700.00
0005434626033	32903	Economy	14700.00
0005434626082	32903	Economy	14700.00
0005434626031	32903	Economy	14700.00
0005434626034	32903	Economy	14700.00
0005435907585	32903	Economy	14700.00
0005433194899	32903	Economy	14700.00
0005435907583	32903	Economy	14700.00
0005434626049	32903	Economy	14700.00
0005434626050	32903	Economy	14700.00
0005434626008	32903	Economy	14700.00
0005435907582	32903	Economy	14700.00
0005434626009	32903	Economy	14700.00
0005434625976	32903	Economy	14700.00
0005435907580	32903	Economy	14700.00
0005432195728	13751	Economy	3400.00
0005435785551	13751	Economy	3400.00
0005432195726	13751	Economy	3400.00
0005435785541	13751	Economy	3400.00
0005435937450	13751	Economy	3100.00
0005435937454	13751	Economy	3100.00
0005435785474	13751	Economy	3100.00
0005435785549	13751	Economy	3100.00
0005432195725	13751	Economy	3100.00
0005435937452	13751	Economy	3100.00
0005435785643	13751	Economy	3100.00
0005435785581	13751	Economy	3100.00
0005435785608	13751	Economy	3100.00
0005435785623	13751	Economy	3100.00
0005435785548	13751	Economy	3100.00
0005435785665	13751	Economy	3100.00
0005435785463	13751	Economy	3100.00
0005435785607	13751	Economy	3100.00
0005435785704	13751	Economy	3100.00
0005435785521	13751	Economy	3100.00
0005432195727	13751	Economy	3100.00
0005435787368	13751	Economy	3100.00
0005435937449	13751	Economy	3100.00
0005435785604	13751	Economy	3100.00
0005435937448	13751	Economy	3100.00
0005435937453	13751	Economy	3100.00
0005435937456	13751	Economy	3100.00
0005435785481	13751	Economy	3100.00
0005435785554	13751	Economy	3100.00
0005435785526	13751	Economy	3100.00
0005435785482	13751	Economy	3100.00
0005432195729	13751	Economy	3100.00
0005435785529	13751	Economy	3100.00
0005435785522	13751	Economy	3100.00
0005435785539	13751	Economy	3100.00
0005435785544	13751	Economy	3100.00
0005435937455	13751	Economy	3100.00
0005435785543	13751	Economy	3100.00
0005435785528	13751	Economy	3100.00
0005435785445	13751	Economy	3100.00
0005435937451	13751	Economy	3100.00
0005435785525	13751	Economy	3100.00
0005435785844	27438	Economy	3400.00
0005435785837	27438	Economy	3400.00
0005435785850	27438	Economy	3400.00
0005432190683	27438	Economy	3100.00
0005435785857	27438	Economy	3100.00
0005435785829	27438	Economy	3100.00
0005435785830	27438	Economy	3100.00
0005435785845	27438	Economy	3100.00
0005435785836	27438	Economy	3100.00
0005435785858	27438	Economy	3100.00
0005435785827	27438	Economy	3100.00
0005435937409	27438	Economy	3100.00
0005435785852	27438	Economy	3100.00
0005435785834	27438	Economy	3100.00
0005435785860	27438	Economy	3100.00
0005435785849	27438	Economy	3100.00
0005435785855	27438	Economy	3100.00
0005435787386	27438	Economy	3100.00
0005432190682	27438	Economy	3100.00
0005435785832	27438	Economy	3100.00
0005435785851	27438	Economy	3100.00
0005435785840	27438	Economy	3100.00
0005432190684	27438	Economy	3100.00
0005435785847	27438	Economy	3100.00
0005435785848	27438	Economy	3100.00
0005435785833	27438	Economy	3100.00
0005435785831	27438	Economy	3100.00
0005435785841	27438	Economy	3100.00
0005435785843	27438	Economy	3100.00
0005435785835	27438	Economy	3100.00
0005435785842	27438	Economy	3100.00
0005435785839	27438	Economy	3100.00
0005435785862	27438	Economy	3100.00
0005435785854	27438	Economy	3100.00
0005435785853	27438	Economy	3100.00
0005435785859	27438	Economy	3100.00
0005435785861	27438	Economy	3100.00
0005432190685	27438	Economy	3100.00
0005435785846	27438	Economy	3100.00
0005435787385	27438	Economy	3100.00
0005435937407	27438	Economy	3100.00
0005435785856	27438	Economy	3100.00
0005435785838	27438	Economy	3100.00
0005435785828	27438	Economy	3100.00
0005434408075	20308	Business	12000.00
0005434408311	20308	Business	12000.00
0005434408082	20308	Business	12000.00
0005434407916	20308	Business	12000.00
0005435311250	20308	Business	12000.00
0005435311255	20308	Business	12000.00
0005434408340	20308	Business	12000.00
0005434408085	20308	Business	12000.00
0005434408151	20308	Business	12000.00
0005434408195	20308	Business	12000.00
0005434408443	20308	Business	12000.00
0005434408223	20308	Economy	4000.00
0005434408093	20308	Economy	4000.00
0005434407912	20308	Economy	4000.00
0005434408002	20308	Economy	4000.00
0005434408372	20308	Economy	4000.00
0005434408464	20308	Economy	4400.00
0005434408123	20308	Economy	4400.00
0005434408071	20308	Economy	4400.00
0005434408063	20308	Economy	4400.00
0005434408074	20308	Economy	4400.00
0005434408218	20308	Economy	4000.00
0005434408298	20308	Economy	4000.00
0005434408167	20308	Economy	4000.00
0005435311252	20308	Economy	4000.00
0005434408322	20308	Economy	4000.00
0005434408022	20308	Economy	4000.00
0005434408064	20308	Economy	4000.00
0005434408124	20308	Economy	4000.00
0005434408444	20308	Economy	4000.00
0005434408086	20308	Economy	4000.00
0005434408249	20308	Economy	4000.00
0005434408209	20308	Economy	4000.00
0005434408259	20308	Economy	4000.00
0005434408341	20308	Economy	4000.00
0005434408122	20308	Economy	4000.00
0005434408125	20308	Economy	4000.00
0005432058443	20308	Economy	4000.00
0005434408094	20308	Economy	4000.00
0005435311251	20308	Economy	4000.00
0005434408323	20308	Economy	4000.00
0005434408021	20308	Economy	4000.00
0005434407911	20308	Economy	4000.00
0005435311254	20308	Economy	4000.00
0005434407936	20308	Economy	4000.00
0005434408431	20308	Economy	4000.00
0005434408131	20308	Economy	4000.00
0005435311253	20308	Economy	4000.00
0005434408121	20308	Economy	4000.00
0005432058444	20308	Economy	4000.00
0005434408192	20308	Economy	4000.00
0005434408416	20308	Economy	4000.00
0005435311248	20308	Economy	4000.00
0005435311258	20308	Economy	4000.00
0005434408371	20308	Economy	4000.00
0005434407636	20308	Economy	4000.00
0005434408463	20308	Economy	4000.00
0005434408258	20308	Economy	4000.00
0005434407877	20308	Economy	4000.00
0005434408111	20308	Economy	4000.00
0005435311259	20308	Economy	4000.00
0005434408186	20308	Economy	4000.00
0005435311257	20308	Economy	4000.00
0005434408398	20308	Economy	4000.00
0005435311256	20308	Economy	4000.00
0005434408310	20308	Economy	4000.00
0005434408171	20308	Economy	4000.00
0005434408347	20308	Economy	4000.00
0005434408110	20308	Economy	4000.00
0005434407637	20308	Economy	4000.00
0005434408154	20308	Economy	4000.00
0005434408150	20308	Economy	4000.00
0005434408178	20308	Economy	4000.00
0005434408285	20308	Economy	4000.00
0005434408003	20308	Economy	4000.00
0005432058442	20308	Economy	4000.00
0005434408079	20308	Economy	4000.00
0005434408137	20308	Economy	4000.00
0005435311249	20308	Economy	4000.00
0005434408346	20308	Economy	4000.00
0005434408405	20308	Economy	4000.00
0005434408127	20308	Economy	4000.00
0005434408406	20308	Economy	4000.00
0005434408001	20308	Economy	4000.00
0005434408749	26969	Business	12000.00
0005432154048	26969	Business	12000.00
0005434408741	26969	Business	12000.00
0005434408769	26969	Business	12000.00
0005435311101	26969	Business	12000.00
0005434408715	26969	Business	12000.00
0005434408744	26969	Business	12000.00
0005435311117	26969	Business	12000.00
0005434408711	26969	Economy	4000.00
0005434408751	26969	Economy	4000.00
0005434408717	26969	Economy	4000.00
0005432154046	26969	Economy	4000.00
0005432154050	26969	Economy	4000.00
0005435311137	26969	Economy	4000.00
0005434408743	26969	Economy	4000.00
0005434408735	26969	Economy	4000.00
0005434408758	26969	Economy	4400.00
0005434408709	26969	Economy	4400.00
0005434408722	26969	Economy	4400.00
0005434408714	26969	Economy	4400.00
0005432154045	26969	Economy	4400.00
0005434408732	26969	Economy	4000.00
0005434408739	26969	Economy	4000.00
0005435311118	26969	Economy	4000.00
0005434408750	26969	Economy	4000.00
0005434408761	26969	Economy	4000.00
0005434408770	26969	Economy	4000.00
0005434408754	26969	Economy	4000.00
0005434408706	26969	Economy	4000.00
0005434408748	26969	Economy	4000.00
0005434408729	26969	Economy	4000.00
0005432154044	26969	Economy	4000.00
0005434408756	26969	Economy	4000.00
0005434408718	26969	Economy	4000.00
0005434408737	26969	Economy	4000.00
0005434408712	26969	Economy	4000.00
0005434408708	26969	Economy	4000.00
0005435311070	26969	Economy	4000.00
0005434408757	26969	Economy	4000.00
0005434408759	26969	Economy	4000.00
0005435311109	26969	Economy	4000.00
0005434408762	26969	Economy	4000.00
0005434408740	26969	Economy	4000.00
0005434408727	26969	Economy	4000.00
0005434408725	26969	Economy	4000.00
0005434408719	26969	Economy	4000.00
0005434408768	26969	Economy	4000.00
0005434408766	26969	Economy	4000.00
0005434408736	26969	Economy	4000.00
0005434408733	26969	Economy	4000.00
0005434408746	26969	Economy	4000.00
0005434408760	26969	Economy	4000.00
0005434408763	26969	Economy	4000.00
0005435311119	26969	Economy	4000.00
0005434408747	26969	Economy	4000.00
0005434408710	26969	Economy	4000.00
0005434408738	26969	Economy	4000.00
0005434408721	26969	Economy	4000.00
0005434408731	26969	Economy	4000.00
0005434408753	26969	Economy	4000.00
0005434408720	26969	Economy	4000.00
0005432154047	26969	Economy	4000.00
0005434408726	26969	Economy	4000.00
0005434408752	26969	Economy	4000.00
0005434408728	26969	Economy	4000.00
0005434408723	26969	Economy	4000.00
0005434408734	26969	Economy	4000.00
0005432154043	26969	Economy	4000.00
0005434408764	26969	Economy	4000.00
0005434408713	26969	Economy	4000.00
0005435311102	26969	Economy	4000.00
0005434408765	26969	Economy	4000.00
0005434408767	26969	Economy	4000.00
0005435311100	26969	Economy	4000.00
0005434408716	26969	Economy	4000.00
0005432154049	26969	Economy	4000.00
0005434408724	26969	Economy	4000.00
0005434408742	26969	Economy	4000.00
0005434408755	26969	Economy	4000.00
0005435311120	26969	Economy	4000.00
0005434408730	26969	Economy	4000.00
0005434408745	26969	Economy	4000.00
0005434408707	26969	Economy	4000.00
0005433124071	5711	Business	43300.00
0005432109745	5711	Economy	14400.00
0005433123916	5711	Economy	14400.00
0005434319620	5711	Economy	14400.00
0005433124070	5711	Economy	14400.00
0005433124061	5711	Economy	14400.00
0005433123917	5711	Economy	14400.00
0005433124078	5711	Economy	14400.00
0005434311250	5711	Economy	14400.00
0005433124048	5711	Economy	14400.00
0005433124049	5711	Economy	14400.00
0005433124068	5711	Economy	14400.00
0005432109746	5711	Economy	14400.00
0005433123989	5711	Economy	14400.00
0005433124131	5711	Economy	14400.00
0005434311249	5711	Economy	14400.00
0005434311251	5711	Economy	14400.00
0005433123988	5711	Economy	14400.00
0005433124032	5711	Economy	14400.00
0005433124069	5711	Economy	14400.00
0005433124052	5711	Economy	14400.00
0005433124033	5711	Economy	14400.00
0005432109747	5711	Economy	14400.00
0005433124112	5711	Economy	14400.00
0005434319619	5711	Economy	14400.00
0005433124077	5711	Economy	14400.00
0005433124247	15709	Business	43300.00
0005434319512	15709	Business	43300.00
0005434319448	15709	Business	43300.00
0005433124252	15709	Business	43300.00
0005433124260	15709	Economy	14400.00
0005433124261	15709	Economy	14400.00
0005433124248	15709	Economy	14400.00
0005434319530	15709	Economy	14400.00
0005434319449	15709	Economy	14400.00
0005434319513	15709	Economy	15900.00
0005433124242	15709	Economy	15900.00
0005434319493	15709	Economy	14400.00
0005433124250	15709	Economy	14400.00
0005434319497	15709	Economy	14400.00
0005433124263	15709	Economy	14400.00
0005433124255	15709	Economy	14400.00
0005433124259	15709	Economy	14400.00
0005433124251	15709	Economy	14400.00
0005434319537	15709	Economy	14400.00
0005434319507	15709	Economy	14400.00
0005433124243	15709	Economy	14400.00
0005433124245	15709	Economy	14400.00
0005433124257	15709	Economy	14400.00
0005434319476	15709	Economy	14400.00
0005434319436	15709	Economy	14400.00
0005433124244	15709	Economy	14400.00
0005433124241	15709	Economy	14400.00
0005433124249	15709	Economy	14400.00
0005434319529	15709	Economy	14400.00
0005433124262	15709	Economy	14400.00
0005433124253	15709	Economy	14400.00
0005433124246	15709	Economy	14400.00
0005434319510	15709	Economy	14400.00
0005434319477	15709	Economy	14400.00
0005434319526	15709	Economy	14400.00
0005434319527	15709	Economy	14400.00
0005434319435	15709	Economy	14400.00
0005434312330	15709	Economy	14400.00
0005434319532	15709	Economy	14400.00
0005433124256	15709	Economy	14400.00
0005434319538	15709	Economy	14400.00
0005433124258	15709	Economy	14400.00
0005433124254	15709	Economy	14400.00
0005435219231	31739	Economy	17100.00
0005435220351	31739	Economy	15500.00
0005435219235	31739	Economy	15500.00
0005435220494	31739	Economy	15500.00
0005435220496	31739	Economy	15500.00
0005435220352	31739	Economy	15500.00
0005435219232	31739	Economy	15500.00
0005435220353	31739	Economy	15500.00
0005435220350	31739	Economy	15500.00
0005435220493	31739	Economy	15500.00
0005435220495	31739	Economy	15500.00
0005435219234	31739	Economy	15500.00
0005435219233	31739	Economy	15500.00
0005434189210	8991	Economy	27400.00
0005434484453	8991	Economy	27400.00
0005434484449	8991	Economy	24900.00
0005434189211	8991	Economy	24900.00
0005434189221	8991	Economy	24900.00
0005434484451	8991	Economy	24900.00
0005434484448	8991	Economy	24900.00
0005434189199	8991	Economy	24900.00
0005434189198	8991	Economy	24900.00
0005434189226	8991	Economy	24900.00
0005434484452	8991	Economy	24900.00
0005434484450	8991	Economy	24900.00
0005434189232	8991	Economy	24900.00
0005434189227	8991	Economy	24900.00
0005434189233	8991	Economy	24900.00
0005434189266	16636	Economy	27400.00
0005434484387	16636	Economy	24900.00
0005434189268	16636	Economy	24900.00
0005434189267	16636	Economy	24900.00
0005434189271	16636	Economy	24900.00
0005434189270	16636	Economy	24900.00
0005434484416	16636	Economy	24900.00
0005434484415	16636	Economy	24900.00
0005434189269	16636	Economy	24900.00
0005433124248	7648	Business	11100.00
0005433124241	7648	Business	11100.00
0005433124261	7648	Business	11100.00
0005433124247	7648	Economy	3700.00
0005433722260	7648	Economy	3700.00
0005433722248	7648	Economy	3700.00
0005433124262	7648	Economy	3700.00
0005433124243	7648	Economy	3700.00
0005433124245	7648	Economy	4100.00
0005433124253	7648	Economy	3700.00
0005433124249	7648	Economy	3700.00
0005433124256	7648	Economy	3700.00
0005433124260	7648	Economy	3700.00
0005433124259	7648	Economy	3700.00
0005433124255	7648	Economy	3700.00
0005433124257	7648	Economy	3700.00
0005433124254	7648	Economy	3700.00
0005433124242	7648	Economy	3700.00
0005433722259	7648	Economy	3700.00
0005433722269	7648	Economy	3700.00
0005433124250	7648	Economy	3700.00
0005433722247	7648	Economy	3700.00
0005433124251	7648	Economy	3700.00
0005433124258	7648	Economy	3700.00
0005433124252	7648	Economy	3700.00
0005433124263	7648	Economy	3700.00
0005433124244	7648	Economy	3700.00
0005433124246	7648	Economy	3700.00
0005432721320	7649	Business	11100.00
0005432693559	7649	Business	11100.00
0005432721333	7649	Business	11100.00
0005432693568	7649	Business	11100.00
0005432721329	7649	Business	11100.00
0005432721315	7649	Business	11100.00
0005432693553	7649	Business	11100.00
0005432721318	7649	Business	11100.00
0005433450299	7649	Economy	3700.00
0005432693548	7649	Economy	3700.00
0005433450310	7649	Economy	3700.00
0005432721325	7649	Economy	3700.00
0005432693550	7649	Economy	3700.00
0005432721313	7649	Economy	3700.00
0005432071620	7649	Economy	3700.00
0005432693540	7649	Economy	3700.00
0005432693538	7649	Economy	3700.00
0005432721319	7649	Economy	3700.00
0005432693560	7649	Economy	4100.00
0005433450307	7649	Economy	4100.00
0005432721316	7649	Economy	4100.00
0005433450311	7649	Economy	4100.00
0005432693554	7649	Economy	3700.00
0005432721314	7649	Economy	3700.00
0005432693547	7649	Economy	3700.00
0005432721328	7649	Economy	3700.00
0005432721312	7649	Economy	3700.00
0005433450309	7649	Economy	3700.00
0005432721308	7649	Economy	3700.00
0005433450302	7649	Economy	3700.00
0005432693552	7649	Economy	3700.00
0005433450317	7649	Economy	3700.00
0005433450316	7649	Economy	3700.00
0005432721311	7649	Economy	3700.00
0005433450308	7649	Economy	3700.00
0005432693563	7649	Economy	3700.00
0005432721334	7649	Economy	3700.00
0005432721310	7649	Economy	3700.00
0005433450303	7649	Economy	3700.00
0005432071618	7649	Economy	3700.00
0005432721322	7649	Economy	3700.00
0005432693555	7649	Economy	3700.00
0005432693556	7649	Economy	3700.00
0005432721326	7649	Economy	3700.00
0005432693549	7649	Economy	3700.00
0005432721309	7649	Economy	3700.00
0005433450301	7649	Economy	3700.00
0005432693539	7649	Economy	3700.00
0005432693545	7649	Economy	3700.00
0005432721332	7649	Economy	3700.00
0005432693543	7649	Economy	3700.00
0005432693551	7649	Economy	3700.00
0005432693566	7649	Economy	3700.00
0005432693542	7649	Economy	3700.00
0005433450305	7649	Economy	3700.00
0005433450298	7649	Economy	3700.00
0005433450315	7649	Economy	3700.00
0005432693562	7649	Economy	3700.00
0005433450297	7649	Economy	3700.00
0005432693558	7649	Economy	3700.00
0005432693541	7649	Economy	3700.00
0005432721323	7649	Economy	3700.00
0005432721331	7649	Economy	3700.00
0005432721321	7649	Economy	3700.00
0005432693557	7649	Economy	3700.00
0005432693564	7649	Economy	3700.00
0005432693567	7649	Economy	3700.00
0005433450306	7649	Economy	3700.00
0005432721317	7649	Economy	3700.00
0005432721327	7649	Economy	3700.00
0005433450313	7649	Economy	3700.00
0005433450314	7649	Economy	3700.00
0005432721330	7649	Economy	3700.00
0005433450300	7649	Economy	3700.00
0005432721324	7649	Economy	3700.00
0005432693565	7649	Economy	3700.00
0005433450312	7649	Economy	3700.00
0005432693561	7649	Economy	3700.00
0005432693544	7649	Economy	3700.00
0005433450304	7649	Economy	3700.00
0005433450318	7649	Economy	3700.00
0005432071619	7649	Economy	3700.00
0005432693546	7649	Economy	3700.00
0005432693265	30376	Business	11100.00
0005432693289	30376	Business	11100.00
0005432693264	30376	Business	11100.00
0005432693213	30376	Business	11100.00
0005433450147	30376	Business	11100.00
0005432693328	30376	Business	11100.00
0005432693161	30376	Business	11100.00
0005432693182	30376	Economy	3700.00
0005432693280	30376	Economy	3700.00
0005433450110	30376	Economy	3700.00
0005433450178	30376	Economy	3700.00
0005432693172	30376	Economy	3700.00
0005432693314	30376	Economy	3700.00
0005432693333	30376	Economy	3700.00
0005433450191	30376	Economy	4100.00
0005432693320	30376	Economy	3700.00
0005432693235	30376	Economy	3700.00
0005433450146	30376	Economy	3700.00
0005432693212	30376	Economy	3700.00
0005432693256	30376	Economy	3700.00
0005432693269	30376	Economy	3700.00
0005432693189	30376	Economy	3700.00
0005432693315	30376	Economy	3700.00
0005432693327	30376	Economy	3700.00
0005433450134	30376	Economy	3700.00
0005432693183	30376	Economy	3700.00
0005433450145	30376	Economy	3700.00
0005432693171	30376	Economy	3700.00
0005433450141	30376	Economy	3700.00
0005432693266	30376	Economy	3700.00
0005432693288	30376	Economy	3700.00
0005432693281	30376	Economy	3700.00
0005432693206	30376	Economy	3700.00
0005432693319	30376	Economy	3700.00
0005433450016	30376	Economy	3700.00
0005433450176	30376	Economy	3700.00
0005433450177	30376	Economy	3700.00
0005433450109	30376	Economy	3700.00
0005432693173	30376	Economy	3700.00
0005433450121	30376	Economy	3700.00
0005432693234	30376	Economy	3700.00
0005432693207	30376	Economy	3700.00
0005433450149	30376	Economy	3700.00
0005433450131	30376	Economy	3700.00
0005432721153	30377	Business	11100.00
0005433124068	30377	Business	11100.00
0005432721095	30377	Business	11100.00
0005432721196	30377	Business	11100.00
0005432721014	30377	Business	11100.00
0005432721040	30377	Business	11100.00
0005433722322	30377	Economy	3700.00
0005433722321	30377	Economy	3700.00
0005433124070	30377	Economy	3700.00
0005433123916	30377	Economy	3700.00
0005433722324	30377	Economy	3700.00
0005433722319	30377	Economy	4100.00
0005433722328	30377	Economy	4100.00
0005433124032	30377	Economy	3700.00
0005432721140	30377	Economy	3700.00
0005433124069	30377	Economy	3700.00
0005433123917	30377	Economy	3700.00
0005432721041	30377	Economy	3700.00
0005433124033	30377	Economy	3700.00
0005432721220	30377	Economy	3700.00
0005433124078	30377	Economy	3700.00
0005433722323	30377	Economy	3700.00
0005432721051	30377	Economy	3700.00
0005433124071	30377	Economy	3700.00
0005432721123	30377	Economy	3700.00
0005433124077	30377	Economy	3700.00
0005433123989	30377	Economy	3700.00
0005432721094	30377	Economy	3700.00
0005432721152	30377	Economy	3700.00
0005433124052	30377	Economy	3700.00
0005433722329	30377	Economy	3700.00
0005433124048	30377	Economy	3700.00
0005433722320	30377	Economy	3700.00
0005432721068	30377	Economy	3700.00
0005433124131	30377	Economy	3700.00
0005432721219	30377	Economy	3700.00
0005432721197	30377	Economy	3700.00
0005433124112	30377	Economy	3700.00
0005432721157	30377	Economy	3700.00
0005433124061	30377	Economy	3700.00
0005432721156	30377	Economy	3700.00
0005433722327	30377	Economy	3700.00
0005433124049	30377	Economy	3700.00
0005432721042	30377	Economy	3700.00
0005433722326	30377	Economy	3700.00
0005433123988	30377	Economy	3700.00
0005433722325	30377	Economy	3700.00
0005434587003	1354	Business	70400.00
0005434587007	1354	Business	70400.00
0005432928054	1354	Business	70400.00
0005432271047	1354	Business	70400.00
0005432968862	1354	Business	70400.00
0005433525208	1354	Business	70400.00
0005432928055	1354	Business	70400.00
0005433525209	1354	Business	70400.00
0005433193114	1354	Business	70400.00
0005434587016	1354	Business	70400.00
0005432928013	1354	Business	70400.00
0005433193172	1354	Business	70400.00
0005432928023	1354	Economy	23500.00
0005433193188	1354	Economy	23500.00
0005433724878	1354	Economy	23500.00
0005433525210	1354	Economy	23500.00
0005432928011	1354	Economy	23500.00
0005433193149	1354	Economy	23500.00
0005434587004	1354	Economy	23500.00
0005434515010	1354	Economy	23500.00
0005433193142	1354	Economy	23500.00
0005432968859	1354	Economy	23500.00
0005432928009	1354	Economy	25800.00
0005433525213	1354	Economy	25800.00
0005434515009	1354	Economy	25800.00
0005433193143	1354	Economy	25800.00
0005432968858	1354	Economy	25800.00
0005432928012	1354	Economy	23500.00
0005434513620	1354	Economy	23500.00
0005434587023	1354	Economy	23500.00
0005434587000	1354	Economy	23500.00
0005434587021	1354	Economy	23500.00
0005434587019	1354	Economy	23500.00
0005433525214	1354	Economy	23500.00
0005434587010	1354	Economy	23500.00
0005432968848	1354	Economy	23500.00
0005433193164	1354	Economy	23500.00
0005432928024	1354	Economy	23500.00
0005433525211	1354	Economy	23500.00
0005434515007	1354	Economy	23500.00
0005432968867	1354	Economy	23500.00
0005434587013	1354	Economy	23500.00
0005433525207	1354	Economy	23500.00
0005434587011	1354	Economy	23500.00
0005433724877	1354	Economy	23500.00
0005433525204	1354	Economy	23500.00
0005434587012	1354	Economy	23500.00
0005433525203	1354	Economy	23500.00
0005434587015	1354	Economy	23500.00
0005432271048	1354	Economy	23500.00
0005433525212	1354	Economy	23500.00
0005433193185	1354	Economy	23500.00
0005434587017	1354	Economy	23500.00
0005434587014	1354	Economy	23500.00
0005434587002	1354	Economy	23500.00
0005433193152	1354	Economy	23500.00
0005432968863	1354	Economy	23500.00
0005433525206	1354	Economy	23500.00
0005433193161	1354	Economy	23500.00
0005432271049	1354	Economy	23500.00
0005433193146	1354	Economy	23500.00
0005434587009	1354	Economy	23500.00
0005434513619	1354	Economy	23500.00
0005433525205	1354	Economy	23500.00
0005434587024	1354	Economy	23500.00
0005432928014	1354	Economy	23500.00
0005434587020	1354	Economy	23500.00
0005433193148	1354	Economy	23500.00
0005433724876	1354	Economy	23500.00
0005434513621	1354	Economy	23500.00
0005434587018	1354	Economy	23500.00
0005432928053	1354	Economy	23500.00
0005434586999	1354	Economy	23500.00
0005433724875	1354	Economy	23500.00
0005433724879	1354	Economy	23500.00
0005434587006	1354	Economy	23500.00
0005433193130	1354	Economy	23500.00
0005434587008	1354	Economy	23500.00
0005434587022	1354	Economy	23500.00
0005434587001	1354	Economy	23500.00
0005434587005	1354	Economy	23500.00
0005434515008	1354	Economy	23500.00
0005433193182	1354	Economy	23500.00
0005434586793	18533	Business	70400.00
0005434586766	18533	Business	70400.00
0005434586794	18533	Business	70400.00
0005434586826	18533	Business	70400.00
0005434586789	18533	Business	70400.00
0005434586790	18533	Business	70400.00
0005434586865	18533	Business	70400.00
0005432928063	18533	Business	70400.00
0005433193254	18533	Economy	23500.00
0005433525058	18533	Economy	23500.00
0005434586791	18533	Economy	23500.00
0005432928067	18533	Economy	23500.00
0005434586862	18533	Economy	23500.00
0005432928065	18533	Economy	23500.00
0005432928064	18533	Economy	23500.00
0005433724835	18533	Economy	25800.00
0005433193252	18533	Economy	25800.00
0005434586968	18533	Economy	25800.00
0005433193258	18533	Economy	25800.00
0005433193259	18533	Economy	23500.00
0005433193247	18533	Economy	23500.00
0005434586830	18533	Economy	23500.00
0005433193256	18533	Economy	23500.00
0005434586686	18533	Economy	23500.00
0005433193249	18533	Economy	23500.00
0005433193253	18533	Economy	23500.00
0005434514979	18533	Economy	23500.00
0005434586768	18533	Economy	23500.00
0005434514994	18533	Economy	23500.00
0005432928068	18533	Economy	23500.00
0005434514978	18533	Economy	23500.00
0005433193257	18533	Economy	23500.00
0005433724845	18533	Economy	23500.00
0005434586778	18533	Economy	23500.00
0005434586782	18533	Economy	23500.00
0005434586831	18533	Economy	23500.00
0005434586864	18533	Economy	23500.00
0005434586969	18533	Economy	23500.00
0005434586729	18533	Economy	23500.00
0005433193255	18533	Economy	23500.00
0005433525070	18533	Economy	23500.00
0005434586924	18533	Economy	23500.00
0005432968876	18533	Economy	23500.00
0005434586906	18533	Economy	23500.00
0005434586751	18533	Economy	23500.00
0005433193250	18533	Economy	23500.00
0005434586687	18533	Economy	23500.00
0005434586684	18533	Economy	23500.00
0005433724844	18533	Economy	23500.00
0005434586804	18533	Economy	23500.00
0005434586781	18533	Economy	23500.00
0005433525072	18533	Economy	23500.00
0005434586677	18533	Economy	23500.00
0005433193251	18533	Economy	23500.00
0005434586970	18533	Economy	23500.00
0005434586785	18533	Economy	23500.00
0005432928066	18533	Economy	23500.00
0005434586713	18533	Economy	23500.00
0005433193248	18533	Economy	23500.00
0005434586728	18533	Economy	23500.00
0005432968875	18533	Economy	23500.00
0005434344713	11451	Economy	4300.00
0005434344724	11451	Economy	4300.00
0005434344720	11451	Economy	4300.00
0005434344739	11451	Economy	4000.00
0005434344716	11451	Economy	4000.00
0005434344721	11451	Economy	4000.00
0005434344727	11451	Economy	4000.00
0005434344726	11451	Economy	4000.00
0005434344712	11451	Economy	4000.00
0005434344737	11451	Economy	4000.00
0005434344740	11451	Economy	4000.00
0005434344733	11451	Economy	4000.00
0005434142671	11451	Economy	4000.00
0005434344742	11451	Economy	4000.00
0005434344734	11451	Economy	4000.00
0005434344725	11451	Economy	4000.00
0005434344745	11451	Economy	4000.00
0005434344709	11451	Economy	4000.00
0005434344715	11451	Economy	4000.00
0005434142672	11451	Economy	4000.00
0005434344719	11451	Economy	4000.00
0005434344738	11451	Economy	4000.00
0005434344718	11451	Economy	4000.00
0005434344743	11451	Economy	4000.00
0005434344741	11451	Economy	4000.00
0005434344730	11451	Economy	4000.00
0005434344728	11451	Economy	4000.00
0005434344729	11451	Economy	4000.00
0005434344731	11451	Economy	4000.00
0005434344723	11451	Economy	4000.00
0005434344732	11451	Economy	4000.00
0005434344746	11451	Economy	4000.00
0005434344735	11451	Economy	4000.00
0005435305021	11451	Economy	4000.00
0005434344711	11451	Economy	4000.00
0005434344714	11451	Economy	4000.00
0005434344736	11451	Economy	4000.00
0005434344722	11451	Economy	4000.00
0005434344744	11451	Economy	4000.00
0005434142673	11451	Economy	4000.00
0005434344710	11451	Economy	4000.00
0005434344717	11451	Economy	4000.00
0005435305022	11451	Economy	4000.00
0005434344214	29801	Economy	4300.00
0005434344314	29801	Economy	4300.00
0005434344427	29801	Economy	4300.00
0005434344426	29801	Economy	4300.00
0005434344291	29801	Economy	4000.00
0005434344293	29801	Economy	4000.00
0005434344384	29801	Economy	4000.00
0005434344213	29801	Economy	4000.00
0005434344416	29801	Economy	4000.00
0005434344348	29801	Economy	4000.00
0005434344381	29801	Economy	4000.00
0005434344349	29801	Economy	4000.00
0005434142637	29801	Economy	4000.00
0005434142623	29801	Economy	4000.00
0005434344393	29801	Economy	4000.00
0005434344386	29801	Economy	4000.00
0005434344422	29801	Economy	4000.00
0005434344415	29801	Economy	4000.00
0005434142639	29801	Economy	4000.00
0005434344413	29801	Economy	4000.00
0005434344292	29801	Economy	4000.00
0005434344414	29801	Economy	4000.00
0005434344421	29801	Economy	4000.00
0005434344409	29801	Economy	4000.00
0005434344223	29801	Economy	4000.00
0005434344442	29801	Economy	4000.00
0005434344453	29801	Economy	4000.00
0005434344224	29801	Economy	4000.00
0005434142624	29801	Economy	4000.00
0005434344398	29801	Economy	4000.00
0005434344288	29801	Economy	4000.00
0005434344290	29801	Economy	4000.00
0005434142622	29801	Economy	4000.00
0005434142620	29801	Economy	4000.00
0005434344395	29801	Economy	4000.00
0005434344408	29801	Economy	4000.00
0005434344327	29801	Economy	4000.00
0005434344364	29801	Economy	4000.00
0005434344313	29801	Economy	4000.00
0005434344356	29801	Economy	4000.00
0005434344428	29801	Economy	4000.00
0005434142638	29801	Economy	4000.00
0005434344287	29801	Economy	4000.00
0005434344397	29801	Economy	4000.00
0005434344394	29801	Economy	4000.00
0005434344417	29801	Economy	4000.00
0005434344425	29801	Economy	4000.00
0005434142621	29801	Economy	4000.00
0005434344357	29801	Economy	4000.00
0005434344410	29801	Economy	4000.00
0005435825052	1270	Business	199800.00
0005435825055	1270	Business	199800.00
0005435825038	1270	Business	199800.00
0005435825053	1270	Business	199800.00
0005433415710	1270	Business	199800.00
0005435825054	1270	Business	199800.00
0005435825046	1270	Business	199800.00
0005433415817	1270	Economy	66600.00
0005435825042	1270	Economy	66600.00
0005435825037	1270	Economy	66600.00
0005435825051	1270	Economy	66600.00
0005435825035	1270	Economy	66600.00
0005435825043	1270	Economy	73200.00
0005433415782	1270	Economy	66600.00
0005435825050	1270	Economy	66600.00
0005433415711	1270	Economy	66600.00
0005433415730	1270	Economy	66600.00
0005433415861	1270	Economy	66600.00
0005435825040	1270	Economy	66600.00
0005433415882	1270	Economy	66600.00
0005435825057	1270	Economy	66600.00
0005435825044	1270	Economy	66600.00
0005435825056	1270	Economy	66600.00
0005432284605	1270	Economy	66600.00
0005435825039	1270	Economy	66600.00
0005435825049	1270	Economy	66600.00
0005435825045	1270	Economy	66600.00
0005432284603	1270	Economy	66600.00
0005435825033	1270	Economy	66600.00
0005432284604	1270	Economy	66600.00
0005435825047	1270	Economy	66600.00
0005433415816	1270	Economy	66600.00
0005435825048	1270	Economy	66600.00
0005435825034	1270	Economy	66600.00
0005435825032	1270	Economy	66600.00
0005435825036	1270	Economy	66600.00
0005432284606	1270	Economy	66600.00
0005433415731	1270	Economy	66600.00
0005435825041	1270	Economy	66600.00
0005435825031	1270	Economy	66600.00
0005435824796	18023	Business	199800.00
0005435824818	18023	Business	199800.00
0005433415914	18023	Business	199800.00
0005433415901	18023	Business	199800.00
0005435824831	18023	Economy	66600.00
0005433415906	18023	Economy	66600.00
0005435824879	18023	Economy	66600.00
0005435824921	18023	Economy	66600.00
0005435824781	18023	Economy	66600.00
0005435824735	18023	Economy	66600.00
0005435824733	18023	Economy	66600.00
0005435824734	18023	Economy	66600.00
0005435824716	18023	Economy	66600.00
0005433415905	18023	Economy	66600.00
0005435824931	18023	Economy	66600.00
0005433415909	18023	Economy	66600.00
0005435824782	18023	Economy	66600.00
0005433415911	18023	Economy	66600.00
0005435824868	18023	Economy	66600.00
0005435824764	18023	Economy	66600.00
0005433415907	18023	Economy	66600.00
0005435824830	18023	Economy	66600.00
0005435824804	18023	Economy	66600.00
0005435824888	18023	Economy	66600.00
0005435824801	18023	Economy	66600.00
0005435824884	18023	Economy	66600.00
0005433415915	18023	Economy	66600.00
0005435824885	18023	Economy	66600.00
0005435824737	18023	Economy	66600.00
0005433415904	18023	Economy	66600.00
0005433415910	18023	Economy	66600.00
0005435824780	18023	Economy	66600.00
0005433415902	18023	Economy	66600.00
0005433415912	18023	Economy	66600.00
0005435824820	18023	Economy	66600.00
0005435824821	18023	Economy	66600.00
0005435824761	18023	Economy	66600.00
0005433415908	18023	Economy	66600.00
0005435824805	18023	Economy	66600.00
0005435824736	18023	Economy	66600.00
0005433415903	18023	Economy	66600.00
0005433415913	18023	Economy	66600.00
0005435824765	18023	Economy	66600.00
0005435824715	18023	Economy	66600.00
0005432784601	5654	Business	27800.00
0005432144037	5654	Business	27800.00
0005432784620	5654	Business	27800.00
0005435476785	5654	Business	27800.00
0005432784637	5654	Business	27800.00
0005432784606	5654	Business	27800.00
0005432784616	5654	Business	27800.00
0005435476754	5654	Business	27800.00
0005435242909	5654	Business	27800.00
0005432784609	5654	Business	27800.00
0005432784605	5654	Business	27800.00
0005435243037	5654	Business	27800.00
0005435243093	5654	Economy	9300.00
0005435243022	5654	Economy	9300.00
0005435242892	5654	Economy	9300.00
0005432784628	5654	Economy	9300.00
0005435476786	5654	Economy	9300.00
0005432784627	5654	Economy	9300.00
0005435243054	5654	Economy	9300.00
0005432784622	5654	Economy	9300.00
0005435242910	5654	Economy	9300.00
0005432784610	5654	Economy	9300.00
0005432784635	5654	Economy	10200.00
0005432784607	5654	Economy	10200.00
0005435242948	5654	Economy	10200.00
0005435242936	5654	Economy	10200.00
0005435243092	5654	Economy	10200.00
0005435242924	5654	Economy	9300.00
0005435243113	5654	Economy	9300.00
0005435242980	5654	Economy	9300.00
0005432784644	5654	Economy	9300.00
0005432784645	5654	Economy	9300.00
0005432784618	5654	Economy	9300.00
0005435243013	5654	Economy	9300.00
0005432784631	5654	Economy	9300.00
0005432784646	5654	Economy	9300.00
0005432784634	5654	Economy	9300.00
0005432784614	5654	Economy	9300.00
0005435243065	5654	Economy	9300.00
0005432784642	5654	Economy	9300.00
0005432784624	5654	Economy	9300.00
0005432784611	5654	Economy	9300.00
0005435243005	5654	Economy	9300.00
0005432784655	5654	Economy	9300.00
0005432784617	5654	Economy	9300.00
0005432784641	5654	Economy	9300.00
0005435243066	5654	Economy	9300.00
0005432784638	5654	Economy	9300.00
0005435243053	5654	Economy	9300.00
0005435243115	5654	Economy	9300.00
0005435242894	5654	Economy	9300.00
0005432784633	5654	Economy	9300.00
0005432784621	5654	Economy	9300.00
0005432784649	5654	Economy	9300.00
0005435243012	5654	Economy	9300.00
0005432784604	5654	Economy	9300.00
0005432784630	5654	Economy	9300.00
0005432784632	5654	Economy	9300.00
0005435243049	5654	Economy	9300.00
0005432784613	5654	Economy	9300.00
0005432784612	5654	Economy	9300.00
0005435243072	5654	Economy	9300.00
0005432784640	5654	Economy	9300.00
0005435243050	5654	Economy	9300.00
0005435243048	5654	Economy	9300.00
0005432144040	5654	Economy	9300.00
0005435243038	5654	Economy	9300.00
0005432784639	5654	Economy	9300.00
0005435243047	5654	Economy	9300.00
0005432784652	5654	Economy	9300.00
0005432784636	5654	Economy	9300.00
0005432784602	5654	Economy	9300.00
0005432784629	5654	Economy	9300.00
0005432784603	5654	Economy	9300.00
0005432784650	5654	Economy	9300.00
0005432784626	5654	Economy	9300.00
0005435242908	5654	Economy	9300.00
0005435242981	5654	Economy	9300.00
0005435243114	5654	Economy	9300.00
0005435242966	5654	Economy	9300.00
0005432784653	5654	Economy	9300.00
0005432784651	5654	Economy	9300.00
0005435476790	5654	Economy	9300.00
0005432784625	5654	Economy	9300.00
0005432784647	5654	Economy	9300.00
0005432784619	5654	Economy	9300.00
0005432144038	5654	Economy	9300.00
0005432784608	5654	Economy	9300.00
0005432144039	5654	Economy	9300.00
0005432784623	5654	Economy	9300.00
0005435243021	5654	Economy	9300.00
0005432784615	5654	Economy	9300.00
0005432784643	5654	Economy	9300.00
0005435243052	5654	Economy	9300.00
0005432784654	5654	Economy	9300.00
0005435243062	5654	Economy	9300.00
0005432784648	5654	Economy	9300.00
0005432784172	15363	Business	27800.00
0005432783918	15363	Business	27800.00
0005435476857	15363	Business	27800.00
0005432784336	15363	Business	27800.00
0005432784022	15363	Business	27800.00
0005432784148	15363	Business	27800.00
0005435243261	15363	Business	27800.00
0005435243257	15363	Economy	9300.00
0005432784167	15363	Economy	9300.00
0005435243253	15363	Economy	9300.00
0005432784120	15363	Economy	9300.00
0005435476858	15363	Economy	9300.00
0005432784117	15363	Economy	9300.00
0005435243263	15363	Economy	9300.00
0005432784234	15363	Economy	9300.00
0005435243249	15363	Economy	9300.00
0005432784180	15363	Economy	10200.00
0005435243254	15363	Economy	10200.00
0005432784065	15363	Economy	10200.00
0005432783993	15363	Economy	10200.00
0005435243259	15363	Economy	10200.00
0005435243243	15363	Economy	9300.00
0005432784283	15363	Economy	9300.00
0005432784189	15363	Economy	9300.00
0005432783974	15363	Economy	9300.00
0005432783981	15363	Economy	9300.00
0005432783850	15363	Economy	9300.00
0005432784203	15363	Economy	9300.00
0005432784075	15363	Economy	9300.00
0005432784162	15363	Economy	9300.00
0005435476854	15363	Economy	9300.00
0005432784204	15363	Economy	9300.00
0005435243247	15363	Economy	9300.00
0005435243241	15363	Economy	9300.00
0005432784286	15363	Economy	9300.00
0005435476856	15363	Economy	9300.00
0005432784177	15363	Economy	9300.00
0005432784007	15363	Economy	9300.00
0005432783982	15363	Economy	9300.00
0005435243260	15363	Economy	9300.00
0005432784233	15363	Economy	9300.00
0005435243250	15363	Economy	9300.00
0005432784066	15363	Economy	9300.00
0005432784107	15363	Economy	9300.00
0005435476852	15363	Economy	9300.00
0005435243256	15363	Economy	9300.00
0005435243258	15363	Economy	9300.00
0005435243239	15363	Economy	9300.00
0005432784067	15363	Economy	9300.00
0005435243252	15363	Economy	9300.00
0005432784163	15363	Economy	9300.00
0005432784171	15363	Economy	9300.00
0005432783972	15363	Economy	9300.00
0005435476855	15363	Economy	9300.00
0005432784149	15363	Economy	9300.00
0005432784378	15363	Economy	9300.00
0005435476853	15363	Economy	9300.00
0005435243248	15363	Economy	9300.00
0005432783968	15363	Economy	9300.00
0005435243244	15363	Economy	9300.00
0005432783945	15363	Economy	9300.00
0005435243262	15363	Economy	9300.00
0005432784004	15363	Economy	9300.00
0005432784176	15363	Economy	9300.00
0005435243240	15363	Economy	9300.00
0005432784173	15363	Economy	9300.00
0005435243246	15363	Economy	9300.00
0005435243245	15363	Economy	9300.00
0005432783973	15363	Economy	9300.00
0005435243238	15363	Economy	9300.00
0005432784021	15363	Economy	9300.00
0005432784005	15363	Economy	9300.00
0005435243255	15363	Economy	9300.00
0005435243251	15363	Economy	9300.00
0005435243242	15363	Economy	9300.00
0005435476851	15363	Economy	9300.00
0005432783969	15363	Economy	9300.00
0005432784127	15363	Economy	9300.00
0005432784287	15363	Economy	9300.00
0005432848531	4366	Economy	7000.00
0005432848535	4366	Economy	7000.00
0005435850959	4366	Economy	7000.00
0005432848540	4366	Economy	7000.00
0005434462823	4366	Economy	6300.00
0005434462824	4366	Economy	6300.00
0005432848532	4366	Economy	6300.00
0005435850984	4366	Economy	6300.00
0005435850933	4366	Economy	6300.00
0005434463964	4366	Economy	6300.00
0005432848536	4366	Economy	6300.00
0005435850941	4366	Economy	6300.00
0005432848544	4366	Economy	6300.00
0005432848541	4366	Economy	6300.00
0005435850954	4366	Economy	6300.00
0005435850965	4366	Economy	6300.00
0005435850942	4366	Economy	6300.00
0005432848543	4366	Economy	6300.00
0005432848534	4366	Economy	6300.00
0005432848538	4366	Economy	6300.00
0005432848545	4366	Economy	6300.00
0005432848539	4366	Economy	6300.00
0005434463963	4366	Economy	6300.00
0005432848542	4366	Economy	6300.00
0005435850995	4366	Economy	6300.00
0005432848537	4366	Economy	6300.00
0005435850929	4366	Economy	6300.00
0005435850981	4366	Economy	6300.00
0005432848533	4366	Economy	6300.00
0005432848363	28833	Economy	7000.00
0005432848367	28833	Economy	7000.00
0005432848439	28833	Economy	7000.00
0005432848424	28833	Economy	7000.00
0005432848361	28833	Economy	6300.00
0005435851055	28833	Economy	6300.00
0005435851047	28833	Economy	6300.00
0005432848357	28833	Economy	6300.00
0005432848429	28833	Economy	6300.00
0005435851050	28833	Economy	6300.00
0005432848440	28833	Economy	6300.00
0005432848374	28833	Economy	6300.00
0005432848418	28833	Economy	6300.00
0005432848348	28833	Economy	6300.00
0005432848423	28833	Economy	6300.00
0005432848409	28833	Economy	6300.00
0005435851049	28833	Economy	6300.00
0005432848380	28833	Economy	6300.00
0005432848413	28833	Economy	6300.00
0005435851048	28833	Economy	6300.00
0005432848406	28833	Economy	6300.00
0005432848381	28833	Economy	6300.00
0005432848453	28833	Economy	6300.00
0005432848349	28833	Economy	6300.00
0005432848414	28833	Economy	6300.00
0005435851052	28833	Economy	6300.00
0005435851054	28833	Economy	6300.00
0005435851056	28833	Economy	6300.00
0005432848394	28833	Economy	6300.00
0005432848362	28833	Economy	6300.00
0005434461654	28833	Economy	6300.00
0005432848428	28833	Economy	6300.00
0005432848430	28833	Economy	6300.00
0005435851051	28833	Economy	6300.00
0005432848441	28833	Economy	6300.00
0005432848417	28833	Economy	6300.00
0005432848373	28833	Economy	6300.00
0005432848452	28833	Economy	6300.00
0005432848405	28833	Economy	6300.00
0005435851053	28833	Economy	6300.00
0005432848382	28833	Economy	6300.00
0005432848410	28833	Economy	6300.00
0005434926319	6289	Business	11900.00
0005434926311	6289	Business	11900.00
0005433497450	6289	Business	11900.00
0005433497445	6289	Business	11900.00
0005434443958	6289	Business	11900.00
0005433497455	6289	Business	11900.00
0005432075285	6289	Business	11900.00
0005434926299	6289	Business	11900.00
0005434443967	6289	Business	11900.00
0005434926310	6289	Business	11900.00
0005434926296	6289	Business	11900.00
0005434443963	6289	Business	11900.00
0005433497474	6289	Economy	4000.00
0005434926294	6289	Economy	4000.00
0005434926293	6289	Economy	4000.00
0005434926304	6289	Economy	4000.00
0005433497447	6289	Economy	4000.00
0005434926307	6289	Economy	4000.00
0005434926316	6289	Economy	4000.00
0005433497444	6289	Economy	4000.00
0005433497452	6289	Economy	4000.00
0005433497461	6289	Economy	4000.00
0005434926313	6289	Economy	4400.00
0005434443962	6289	Economy	4400.00
0005434926297	6289	Economy	4400.00
0005433497473	6289	Economy	4400.00
0005434926309	6289	Economy	4400.00
0005433497464	6289	Economy	4000.00
0005433497458	6289	Economy	4000.00
0005433497470	6289	Economy	4000.00
0005434443954	6289	Economy	4000.00
0005433497460	6289	Economy	4000.00
0005434926302	6289	Economy	4000.00
0005434926317	6289	Economy	4000.00
0005434926289	6289	Economy	4000.00
0005434926303	6289	Economy	4000.00
0005433497472	6289	Economy	4000.00
0005433497463	6289	Economy	4000.00
0005433497456	6289	Economy	4000.00
0005434926312	6289	Economy	4000.00
0005432075283	6289	Economy	4000.00
0005434926322	6289	Economy	4000.00
0005434926305	6289	Economy	4000.00
0005434926308	6289	Economy	4000.00
0005433497451	6289	Economy	4000.00
0005434443964	6289	Economy	4000.00
0005433497468	6289	Economy	4000.00
0005434443965	6289	Economy	4000.00
0005434926324	6289	Economy	4000.00
0005434443961	6289	Economy	4000.00
0005433497469	6289	Economy	4000.00
0005434926285	6289	Economy	4000.00
0005433497454	6289	Economy	4000.00
0005433497459	6289	Economy	4000.00
0005434926290	6289	Economy	4000.00
0005433497449	6289	Economy	4000.00
0005434926323	6289	Economy	4000.00
0005433497446	6289	Economy	4000.00
0005434926301	6289	Economy	4000.00
0005434926314	6289	Economy	4000.00
0005434443960	6289	Economy	4000.00
0005434926315	6289	Economy	4000.00
0005434926287	6289	Economy	4000.00
0005434926298	6289	Economy	4000.00
0005434443953	6289	Economy	4000.00
0005433497462	6289	Economy	4000.00
0005434926320	6289	Economy	4000.00
0005434443957	6289	Economy	4000.00
0005433497443	6289	Economy	4000.00
0005434926326	6289	Economy	4000.00
0005434926292	6289	Economy	4000.00
0005434443959	6289	Economy	4000.00
0005434926325	6289	Economy	4000.00
0005434926288	6289	Economy	4000.00
0005432075284	6289	Economy	4000.00
0005434443955	6289	Economy	4000.00
0005434926321	6289	Economy	4000.00
0005433497465	6289	Economy	4000.00
0005434926291	6289	Economy	4000.00
0005433497466	6289	Economy	4000.00
0005434926300	6289	Economy	4000.00
0005434926306	6289	Economy	4000.00
0005434926318	6289	Economy	4000.00
0005433497471	6289	Economy	4000.00
0005434443966	6289	Economy	4000.00
0005433497457	6289	Economy	4000.00
0005433497467	6289	Economy	4000.00
0005434926286	6289	Economy	4000.00
0005434443968	6289	Economy	4000.00
0005434926295	6289	Economy	4000.00
0005433497453	6289	Economy	4000.00
0005433497448	6289	Economy	4000.00
0005434443956	6289	Economy	4000.00
0005435257393	20348	Economy	4000.00
0005434925918	20338	Business	11900.00
0005434443797	20338	Business	11900.00
0005434443873	20338	Business	11900.00
0005434926053	20338	Business	11900.00
0005433497254	20338	Business	11900.00
0005434925866	20338	Business	11900.00
0005434925893	20338	Business	11900.00
0005433497149	20338	Business	11900.00
0005433497232	20338	Business	11900.00
0005434925903	20338	Business	11900.00
0005434925898	20338	Economy	4000.00
0005434925991	20338	Economy	4000.00
0005434925992	20338	Economy	4000.00
0005434925813	20338	Economy	4000.00
0005434925889	20338	Economy	4000.00
0005434925897	20338	Economy	4000.00
0005434925966	20338	Economy	4000.00
0005433497139	20338	Economy	4000.00
0005434925944	20338	Economy	4000.00
0005434925958	20338	Economy	4400.00
0005433497150	20338	Economy	4400.00
0005433497306	20338	Economy	4400.00
0005434926031	20338	Economy	4400.00
0005433497279	20338	Economy	4400.00
0005434925936	20338	Economy	4000.00
0005434926012	20338	Economy	4000.00
0005433497284	20338	Economy	4000.00
0005434443862	20338	Economy	4000.00
0005434926007	20338	Economy	4000.00
0005434443813	20338	Economy	4000.00
0005434443825	20338	Economy	4000.00
0005433497335	20338	Economy	4000.00
0005433497231	20338	Economy	4000.00
0005434443836	20338	Economy	4000.00
0005434926001	20338	Economy	4000.00
0005434926037	20338	Economy	4000.00
0005434925993	20338	Economy	4000.00
0005434925716	20338	Economy	4000.00
0005433497238	20338	Economy	4000.00
0005433497236	20338	Economy	4000.00
0005434925878	20338	Economy	4000.00
0005433497198	20338	Economy	4000.00
0005434926054	20338	Economy	4000.00
0005434925919	20338	Economy	4000.00
0005434926005	20338	Economy	4000.00
0005434443735	20338	Economy	4000.00
0005434926042	20338	Economy	4000.00
0005434443734	20338	Economy	4000.00
0005434925864	20338	Economy	4000.00
0005434443798	20338	Economy	4000.00
0005434926017	20338	Economy	4000.00
0005434443835	20338	Economy	4000.00
0005434925997	20338	Economy	4000.00
0005433497263	20338	Economy	4000.00
0005434926033	20338	Economy	4000.00
0005434925923	20338	Economy	4000.00
0005434925894	20338	Economy	4000.00
0005434925863	20338	Economy	4000.00
0005434925879	20338	Economy	4000.00
0005434925970	20338	Economy	4000.00
0005434925872	20338	Economy	4000.00
0005434443849	20338	Economy	4000.00
0005434926055	20338	Economy	4000.00
0005434443822	20338	Economy	4000.00
0005433497199	20338	Economy	4000.00
0005434925871	20338	Economy	4000.00
0005433497294	20338	Economy	4000.00
0005434925862	20338	Economy	4000.00
0005434925945	20338	Economy	4000.00
0005433497237	20338	Economy	4000.00
0005433497321	20338	Economy	4000.00
0005434926011	20338	Economy	4000.00
0005434925939	20338	Economy	4000.00
0005433497239	20338	Economy	4000.00
0005434926035	20338	Economy	4000.00
0005433497222	20338	Economy	4000.00
0005434925999	20338	Economy	4000.00
0005433497277	20338	Economy	4000.00
0005434925890	20338	Economy	4000.00
0005435243285	12207	Business	41200.00
0005432784256	12207	Business	41200.00
0005432784363	12207	Business	41200.00
0005435243274	12207	Business	41200.00
0005432784124	12207	Business	41200.00
0005435243269	12207	Business	41200.00
0005432784306	12207	Business	41200.00
0005432784258	12207	Business	41200.00
0005432784169	12207	Business	41200.00
0005432784145	12207	Business	41200.00
0005432783935	12207	Economy	13700.00
0005432784374	12207	Economy	13700.00
0005435243283	12207	Economy	13700.00
0005435243281	12207	Economy	13700.00
0005435243279	12207	Economy	13700.00
0005432784031	12207	Economy	13700.00
0005432784168	12207	Economy	13700.00
0005435243278	12207	Economy	13700.00
0005432784104	12207	Economy	13700.00
0005432784303	12207	Economy	13700.00
0005435243266	12207	Economy	15100.00
0005432784255	12207	Economy	15100.00
0005435243273	12207	Economy	15100.00
0005432784211	12207	Economy	15100.00
0005432784183	12207	Economy	15100.00
0005432784046	12207	Economy	13700.00
0005432784327	12207	Economy	13700.00
0005432784092	12207	Economy	13700.00
0005432784156	12207	Economy	13700.00
0005432784178	12207	Economy	13700.00
0005432784254	12207	Economy	13700.00
0005432784105	12207	Economy	13700.00
0005432784187	12207	Economy	13700.00
0005432784184	12207	Economy	13700.00
0005432784188	12207	Economy	13700.00
0005432784084	12207	Economy	13700.00
0005435243272	12207	Economy	13700.00
0005432784157	12207	Economy	13700.00
0005432784267	12207	Economy	13700.00
0005435243282	12207	Economy	13700.00
0005432783975	12207	Economy	13700.00
0005432784175	12207	Economy	13700.00
0005432784266	12207	Economy	13700.00
0005432783996	12207	Economy	13700.00
0005432784159	12207	Economy	13700.00
0005435243271	12207	Economy	13700.00
0005432784212	12207	Economy	13700.00
0005435243270	12207	Economy	13700.00
0005435243284	12207	Economy	13700.00
0005432784192	12207	Economy	13700.00
0005435243265	12207	Economy	13700.00
0005432784304	12207	Economy	13700.00
0005432784006	12207	Economy	13700.00
0005435243287	12207	Economy	13700.00
0005432784225	12207	Economy	13700.00
0005432784193	12207	Economy	13700.00
0005432784125	12207	Economy	13700.00
0005435243264	12207	Economy	13700.00
0005435243276	12207	Economy	13700.00
0005432783846	12207	Economy	13700.00
0005432784226	12207	Economy	13700.00
0005432784202	12207	Economy	13700.00
0005435243275	12207	Economy	13700.00
0005432784174	12207	Economy	13700.00
0005432783917	12207	Economy	13700.00
0005432783936	12207	Economy	13700.00
0005435243267	12207	Economy	13700.00
0005432784144	12207	Economy	13700.00
0005432784224	12207	Economy	13700.00
0005435243286	12207	Economy	13700.00
0005432784291	12207	Economy	13700.00
0005432784077	12207	Economy	13700.00
0005435243280	12207	Economy	13700.00
0005432784024	12207	Economy	13700.00
0005435243277	12207	Economy	13700.00
0005435243268	12207	Economy	13700.00
0005435243288	12207	Economy	13700.00
0005432784292	12207	Economy	13700.00
0005432784328	12207	Economy	13700.00
0005432784231	12207	Economy	13700.00
0005432784563	15445	Business	41200.00
0005432784558	15445	Business	41200.00
0005432784564	15445	Business	41200.00
0005432784566	15445	Business	41200.00
0005432784577	15445	Business	41200.00
0005435242983	15445	Business	41200.00
0005435243029	15445	Business	41200.00
0005435242965	15445	Business	41200.00
0005432784573	15445	Business	41200.00
0005435242955	15445	Economy	13700.00
0005432784551	15445	Economy	13700.00
0005432784587	15445	Economy	13700.00
0005435243011	15445	Economy	13700.00
0005432784561	15445	Economy	13700.00
0005432784598	15445	Economy	13700.00
0005435242990	15445	Economy	13700.00
0005432784595	15445	Economy	13700.00
0005432784586	15445	Economy	13700.00
0005432784588	15445	Economy	15100.00
0005435242988	15445	Economy	15100.00
0005432784593	15445	Economy	15100.00
0005432784581	15445	Economy	13700.00
0005432784576	15445	Economy	13700.00
0005435242947	15445	Economy	13700.00
0005435243014	15445	Economy	13700.00
0005432784568	15445	Economy	13700.00
0005432784590	15445	Economy	13700.00
0005432784584	15445	Economy	13700.00
0005435242976	15445	Economy	13700.00
0005432784569	15445	Economy	13700.00
0005435242961	15445	Economy	13700.00
0005435242954	15445	Economy	13700.00
0005432784589	15445	Economy	13700.00
0005432784597	15445	Economy	13700.00
0005432784559	15445	Economy	13700.00
0005432784553	15445	Economy	13700.00
0005432784552	15445	Economy	13700.00
0005432784600	15445	Economy	13700.00
0005435243017	15445	Economy	13700.00
0005435243009	15445	Economy	13700.00
0005432784547	15445	Economy	13700.00
0005432784550	15445	Economy	13700.00
0005432784599	15445	Economy	13700.00
0005432784575	15445	Economy	13700.00
0005432784567	15445	Economy	13700.00
0005435242943	15445	Economy	13700.00
0005432784594	15445	Economy	13700.00
0005435243015	15445	Economy	13700.00
0005432784555	15445	Economy	13700.00
0005435243016	15445	Economy	13700.00
0005432784592	15445	Economy	13700.00
0005432784554	15445	Economy	13700.00
0005432784583	15445	Economy	13700.00
0005435243010	15445	Economy	13700.00
0005432784556	15445	Economy	13700.00
0005432784557	15445	Economy	13700.00
0005432784570	15445	Economy	13700.00
0005432784549	15445	Economy	13700.00
0005432784562	15445	Economy	13700.00
0005432784560	15445	Economy	13700.00
0005435243031	15445	Economy	13700.00
0005432784582	15445	Economy	13700.00
0005435243018	15445	Economy	13700.00
0005432784548	15445	Economy	13700.00
0005432784580	15445	Economy	13700.00
0005432784565	15445	Economy	13700.00
0005435242991	15445	Economy	13700.00
0005432784585	15445	Economy	13700.00
0005432784579	15445	Economy	13700.00
0005432784578	15445	Economy	13700.00
0005432784591	15445	Economy	13700.00
0005432784574	15445	Economy	13700.00
0005435242964	15445	Economy	13700.00
0005432784596	15445	Economy	13700.00
0005432784572	15445	Economy	13700.00
0005435242975	15445	Economy	13700.00
0005432784571	15445	Economy	13700.00
0005434878651	10092	Business	49700.00
0005434878731	10092	Business	49700.00
0005434879043	10092	Business	49700.00
0005434878877	10092	Business	49700.00
0005434879028	10092	Business	49700.00
0005434879032	10092	Business	49700.00
0005434879155	10092	Business	49700.00
0005434878775	10092	Business	49700.00
0005434910149	10092	Business	49700.00
0005434879150	10092	Business	49700.00
0005434878515	10092	Business	49700.00
0005434879156	10092	Business	49700.00
0005434878991	10092	Business	49700.00
0005434879115	10092	Business	49700.00
0005434878971	10092	Business	49700.00
0005434879234	10092	Business	49700.00
0005434758909	10092	Business	49700.00
0005434878516	10092	Business	49700.00
0005434878684	10092	Economy	16600.00
0005434878895	10092	Economy	16600.00
0005434878820	10092	Economy	16600.00
0005434878903	10092	Economy	16600.00
0005434878902	10092	Economy	16600.00
0005434878990	10092	Economy	16600.00
0005434878799	10092	Economy	16600.00
0005434878595	10092	Economy	16600.00
0005434878850	10092	Economy	16600.00
0005434878824	10092	Economy	16600.00
0005434910148	10092	Economy	16600.00
0005434878964	10092	Economy	16600.00
0005434878834	10092	Economy	18200.00
0005435913980	10092	Economy	18200.00
0005434878812	10092	Economy	18200.00
0005434878601	10092	Economy	18200.00
0005434878854	10092	Economy	16600.00
0005434878913	10092	Economy	16600.00
0005434879016	10092	Economy	16600.00
0005434879074	10092	Economy	16600.00
0005434878817	10092	Economy	16600.00
0005434878829	10092	Economy	16600.00
0005434878920	10092	Economy	16600.00
0005434878404	10092	Economy	16600.00
0005434878641	10092	Economy	16600.00
0005434878965	10092	Economy	16600.00
0005434758908	10092	Economy	16600.00
0005434878484	10092	Economy	16600.00
0005434878907	10092	Economy	16600.00
0005434878819	10092	Economy	16600.00
0005434878740	10092	Economy	16600.00
0005434878951	10092	Economy	16600.00
0005434878593	10092	Economy	16600.00
0005434878774	10092	Economy	16600.00
0005434878872	10092	Economy	16600.00
0005434878759	10092	Economy	16600.00
0005434878792	10092	Economy	16600.00
0005434878517	10092	Economy	16600.00
0005434878989	10092	Economy	16600.00
0005434758918	10092	Economy	16600.00
0005434758907	10092	Economy	16600.00
0005434878936	10092	Economy	16600.00
0005434878805	10092	Economy	16600.00
0005434878815	10092	Economy	16600.00
0005434879048	10092	Economy	16600.00
0005434878970	10092	Economy	16600.00
0005434879003	10092	Economy	16600.00
0005434878975	10092	Economy	16600.00
0005434879058	10092	Economy	16600.00
0005434878789	10092	Economy	16600.00
0005434878804	10092	Economy	16600.00
0005434878976	10092	Economy	16600.00
0005434879059	10092	Economy	16600.00
0005434878823	10092	Economy	16600.00
0005434878835	10092	Economy	16600.00
0005434879197	10092	Economy	16600.00
0005434879233	10092	Economy	16600.00
0005434878459	10092	Economy	16600.00
0005434879101	10092	Economy	16600.00
0005434879062	10092	Economy	16600.00
0005434878816	10092	Economy	16600.00
0005434910150	10092	Economy	16600.00
0005434879029	10092	Economy	16600.00
0005434879015	10092	Economy	16600.00
0005434879198	10092	Economy	16600.00
0005434879042	10092	Economy	16600.00
0005434879213	10092	Economy	16600.00
0005434879109	10092	Economy	16600.00
0005434878853	10092	Economy	16600.00
0005434878778	10092	Economy	16600.00
0005434879036	10092	Economy	16600.00
0005434879037	10092	Economy	16600.00
0005434878992	10092	Economy	16600.00
0005434878403	10092	Economy	16600.00
0005434878896	10092	Economy	16600.00
0005434878485	10092	Economy	16600.00
0005434878807	10092	Economy	16600.00
0005434878851	10092	Economy	16600.00
0005434878847	10092	Economy	16600.00
0005434878806	10092	Economy	16600.00
0005434879010	10092	Economy	16600.00
0005434878818	10092	Economy	16600.00
0005434878508	10092	Economy	16600.00
0005434878953	10092	Economy	16600.00
0005434879180	10092	Economy	16600.00
0005434878880	10092	Economy	16600.00
0005434879149	10092	Economy	16600.00
0005434879723	14630	Business	49700.00
0005434879643	14630	Business	49700.00
0005434879716	14630	Business	49700.00
0005434879641	14630	Business	49700.00
0005434879718	14630	Business	49700.00
0005434879639	14630	Business	49700.00
0005434879724	14630	Business	49700.00
0005434910131	14630	Business	49700.00
0005434879680	14630	Business	49700.00
0005434879725	14630	Business	49700.00
0005434879637	14630	Business	49700.00
0005434879686	14630	Business	49700.00
0005434879694	14630	Business	49700.00
0005434879651	14630	Business	49700.00
0005434879652	14630	Business	49700.00
0005434879648	14630	Economy	16600.00
0005434879679	14630	Economy	16600.00
0005434879693	14630	Economy	16600.00
0005434879714	14630	Economy	16600.00
0005434879717	14630	Economy	16600.00
0005434879640	14630	Economy	16600.00
0005434879683	14630	Economy	16600.00
0005434879668	14630	Economy	16600.00
0005434879647	14630	Economy	16600.00
0005434879644	14630	Economy	16600.00
0005434879681	14630	Economy	16600.00
0005434879726	14630	Economy	16600.00
0005434879689	14630	Economy	18200.00
0005434879710	14630	Economy	18200.00
0005434879666	14630	Economy	18200.00
0005434879707	14630	Economy	16600.00
0005434879650	14630	Economy	18200.00
0005434879719	14630	Economy	16600.00
0005434879690	14630	Economy	16600.00
0005434879655	14630	Economy	16600.00
0005434879661	14630	Economy	16600.00
0005434879633	14630	Economy	16600.00
0005434879685	14630	Economy	16600.00
0005434879665	14630	Economy	16600.00
0005434910130	14630	Economy	16600.00
0005434910133	14630	Economy	16600.00
0005434879676	14630	Economy	16600.00
0005434879708	14630	Economy	16600.00
0005434879698	14630	Economy	16600.00
0005435913946	14630	Economy	16600.00
0005434879663	14630	Economy	16600.00
0005434879673	14630	Economy	16600.00
0005434879700	14630	Economy	16600.00
0005434879635	14630	Economy	16600.00
0005434879699	14630	Economy	16600.00
0005434879712	14630	Economy	16600.00
0005434879684	14630	Economy	16600.00
0005434879657	14630	Economy	16600.00
0005434879654	14630	Economy	16600.00
0005434879656	14630	Economy	16600.00
0005434879720	14630	Economy	16600.00
0005434879678	14630	Economy	16600.00
0005434879713	14630	Economy	16600.00
0005434879697	14630	Economy	16600.00
0005434879709	14630	Economy	16600.00
0005434879715	14630	Economy	16600.00
0005434879696	14630	Economy	16600.00
0005434879634	14630	Economy	16600.00
0005434879677	14630	Economy	16600.00
0005434879701	14630	Economy	16600.00
0005434879692	14630	Economy	16600.00
0005434879672	14630	Economy	16600.00
0005434879695	14630	Economy	16600.00
0005434758929	14630	Economy	16600.00
0005434879669	14630	Economy	16600.00
0005434879702	14630	Economy	16600.00
0005434879667	14630	Economy	16600.00
0005434879638	14630	Economy	16600.00
0005434879706	14630	Economy	16600.00
0005434879662	14630	Economy	16600.00
0005434879727	14630	Economy	16600.00
0005434879687	14630	Economy	16600.00
0005434879645	14630	Economy	16600.00
0005434879682	14630	Economy	16600.00
0005434879711	14630	Economy	16600.00
0005434879675	14630	Economy	16600.00
0005434879653	14630	Economy	16600.00
0005434879688	14630	Economy	16600.00
0005434879659	14630	Economy	16600.00
0005434879721	14630	Economy	16600.00
0005434879660	14630	Economy	16600.00
0005434879691	14630	Economy	16600.00
0005434879649	14630	Economy	16600.00
0005434879671	14630	Economy	16600.00
0005434879674	14630	Economy	16600.00
0005434879636	14630	Economy	16600.00
0005434879704	14630	Economy	16600.00
0005434879722	14630	Economy	16600.00
0005434879642	14630	Economy	16600.00
0005434879703	14630	Economy	16600.00
0005434758930	14630	Economy	16600.00
0005434879646	14630	Economy	16600.00
0005434879664	14630	Economy	16600.00
0005434910125	14630	Economy	16600.00
0005434879658	14630	Economy	16600.00
0005434879705	14630	Economy	16600.00
0005434879670	14630	Economy	16600.00
0005435660306	9240	Economy	22400.00
0005434252002	9240	Economy	20300.00
0005434252053	9240	Economy	20300.00
0005434252050	9240	Economy	20300.00
0005435660312	9240	Economy	20300.00
0005435660311	9240	Economy	20300.00
0005435660314	9240	Economy	20300.00
0005435660305	9240	Economy	20300.00
0005434252008	9240	Economy	20300.00
0005435660307	9240	Economy	20300.00
0005435660316	9240	Economy	20300.00
0005435660315	9240	Economy	20300.00
0005434252066	9240	Economy	20300.00
0005434252013	9240	Economy	20300.00
0005435660313	9240	Economy	20300.00
0005435660309	9240	Economy	20300.00
0005434252014	9240	Economy	20300.00
0005434252052	9240	Economy	20300.00
0005435660310	9240	Economy	20300.00
0005434251998	9240	Economy	20300.00
0005435660308	9240	Economy	20300.00
0005435660200	24671	Economy	22400.00
0005435660232	24671	Economy	22400.00
0005434252115	24671	Economy	20300.00
0005434252108	24671	Economy	20300.00
0005435660205	24671	Economy	20300.00
0005435660239	24671	Economy	20300.00
0005434252112	24671	Economy	20300.00
0005434252111	24671	Economy	20300.00
0005435660201	24671	Economy	20300.00
0005435660240	24671	Economy	20300.00
0005435660241	24671	Economy	20300.00
0005434252113	24671	Economy	20300.00
0005434252116	24671	Economy	20300.00
0005434252110	24671	Economy	20300.00
0005435660194	24671	Economy	20300.00
0005435660231	24671	Economy	20300.00
0005434252109	24671	Economy	20300.00
0005434252114	24671	Economy	20300.00
0005433681292	2799	Business	33000.00
0005433681279	2799	Business	33000.00
0005433681288	2799	Business	33000.00
0005433681299	2799	Business	33000.00
0005432222864	2799	Business	33000.00
0005432967194	2799	Business	33000.00
0005432967173	2799	Business	33000.00
0005433681304	2799	Business	33000.00
0005433681318	2799	Business	33000.00
0005433681274	2799	Economy	11000.00
0005433681293	2799	Economy	11000.00
0005433681315	2799	Economy	11000.00
0005433684451	2799	Economy	11000.00
0005433681286	2799	Economy	11000.00
0005432967193	2799	Economy	11000.00
0005433681282	2799	Economy	11000.00
0005432967174	2799	Economy	12100.00
0005433681306	2799	Economy	12100.00
0005433681302	2799	Economy	12100.00
0005432967091	2799	Economy	12100.00
0005433681313	2799	Economy	12100.00
0005432966962	2799	Economy	11000.00
0005433681298	2799	Economy	11000.00
0005432222862	2799	Economy	11000.00
0005432966961	2799	Economy	11000.00
0005433681300	2799	Economy	11000.00
0005432967068	2799	Economy	11000.00
0005432967129	2799	Economy	11000.00
0005433681296	2799	Economy	11000.00
0005432967188	2799	Economy	11000.00
0005432967087	2799	Economy	11000.00
0005432967034	2799	Economy	11000.00
0005432222865	2799	Economy	11000.00
0005433681301	2799	Economy	11000.00
0005433681294	2799	Economy	11000.00
0005432967114	2799	Economy	11000.00
0005433681312	2799	Economy	11000.00
0005432967094	2799	Economy	11000.00
0005433681316	2799	Economy	11000.00
0005433681317	2799	Economy	11000.00
0005433681314	2799	Economy	11000.00
0005433681285	2799	Economy	11000.00
0005433681276	2799	Economy	11000.00
0005432967138	2799	Economy	11000.00
0005432967051	2799	Economy	11000.00
0005433681275	2799	Economy	11000.00
0005433681289	2799	Economy	11000.00
0005433681297	2799	Economy	11000.00
0005433684450	2799	Economy	11000.00
0005433681308	2799	Economy	11000.00
0005433681277	2799	Economy	11000.00
0005433681280	2799	Economy	11000.00
0005433681283	2799	Economy	11000.00
0005432967090	2799	Economy	11000.00
0005432967183	2799	Economy	11000.00
0005432967039	2799	Economy	11000.00
0005432967115	2799	Economy	11000.00
0005432222863	2799	Economy	11000.00
0005432966982	2799	Economy	11000.00
0005433681310	2799	Economy	11000.00
0005432967032	2799	Economy	11000.00
0005433681320	2799	Economy	11000.00
0005433681311	2799	Economy	11000.00
0005433681307	2799	Economy	11000.00
0005432967104	2799	Economy	11000.00
0005433681281	2799	Economy	11000.00
0005432222861	2799	Economy	11000.00
0005432967130	2799	Economy	11000.00
0005433681305	2799	Economy	11000.00
0005433681284	2799	Economy	11000.00
0005433681287	2799	Economy	11000.00
0005433681295	2799	Economy	11000.00
0005433681321	2799	Economy	11000.00
0005433681303	2799	Economy	11000.00
0005433681319	2799	Economy	11000.00
0005432967041	2799	Economy	11000.00
0005433681291	2799	Economy	11000.00
0005433681309	2799	Economy	11000.00
0005433681290	2799	Economy	11000.00
0005433681278	2799	Economy	11000.00
0005432967318	29174	Business	33000.00
0005433680983	29174	Business	33000.00
0005433680963	29174	Business	33000.00
0005433681008	29174	Business	33000.00
0005432967330	29174	Business	33000.00
0005433680975	29174	Business	33000.00
0005432967339	29174	Business	33000.00
0005433680988	29174	Business	33000.00
0005432967319	29174	Business	33000.00
0005433680814	29174	Business	33000.00
0005432967338	29174	Economy	11000.00
0005433681034	29174	Economy	11000.00
0005432967325	29174	Economy	11000.00
0005432967324	29174	Economy	11000.00
0005433690943	29174	Economy	11000.00
0005433680964	29174	Economy	11000.00
0005432967333	29174	Economy	11000.00
0005433680996	29174	Economy	11000.00
0005433680999	29174	Economy	11000.00
0005432967327	29174	Economy	12100.00
0005433681091	29174	Economy	12100.00
0005433680962	29174	Economy	12100.00
0005433690942	29174	Economy	12100.00
0005433684439	29174	Economy	11000.00
0005433680960	29174	Economy	11000.00
0005432967329	29174	Economy	11000.00
0005432967341	29174	Economy	11000.00
0005433680831	29174	Economy	11000.00
0005432005256	29174	Economy	11000.00
0005433681000	29174	Economy	11000.00
0005433681064	29174	Economy	11000.00
0005432005257	29174	Economy	11000.00
0005432967321	29174	Economy	11000.00
0005432967331	29174	Economy	11000.00
0005433680880	29174	Economy	11000.00
0005433680925	29174	Economy	11000.00
0005433680834	29174	Economy	11000.00
0005433680926	29174	Economy	11000.00
0005433680981	29174	Economy	11000.00
0005433684435	29174	Economy	11000.00
0005433680992	29174	Economy	11000.00
0005432967336	29174	Economy	11000.00
0005433680672	29174	Economy	11000.00
0005433681063	29174	Economy	11000.00
0005433680832	29174	Economy	11000.00
0005433681057	29174	Economy	11000.00
0005433680865	29174	Economy	11000.00
0005433680833	29174	Economy	11000.00
0005432967335	29174	Economy	11000.00
0005432967317	29174	Economy	11000.00
0005433681035	29174	Economy	11000.00
0005433680841	29174	Economy	11000.00
0005433680858	29174	Economy	11000.00
0005433681018	29174	Economy	11000.00
0005432967328	29174	Economy	11000.00
0005433680933	29174	Economy	11000.00
0005432967337	29174	Economy	11000.00
0005432967315	29174	Economy	11000.00
0005433680735	29174	Economy	11000.00
0005432967334	29174	Economy	11000.00
0005433687725	29174	Economy	11000.00
0005433681129	29174	Economy	11000.00
0005433680993	29174	Economy	11000.00
0005432967323	29174	Economy	11000.00
0005433680741	29174	Economy	11000.00
0005432967316	29174	Economy	11000.00
0005432967340	29174	Economy	11000.00
0005433680819	29174	Economy	11000.00
0005433680842	29174	Economy	11000.00
0005433680857	29174	Economy	11000.00
0005433680649	29174	Economy	11000.00
0005433681011	29174	Economy	11000.00
0005432967320	29174	Economy	11000.00
0005432967322	29174	Economy	11000.00
0005433687706	29174	Economy	11000.00
0005433681085	29174	Economy	11000.00
0005433680866	29174	Economy	11000.00
0005433680994	29174	Economy	11000.00
0005432005258	29174	Economy	11000.00
0005433680991	29174	Economy	11000.00
0005433690944	29174	Economy	11000.00
0005432967326	29174	Economy	11000.00
0005432967332	29174	Economy	11000.00
0005433680844	29174	Economy	11000.00
0005433680903	29174	Economy	11000.00
0005433615769	9300	Business	132900.00
0005434269114	9300	Business	132900.00
0005433634310	9300	Business	132900.00
0005433615746	9300	Business	132900.00
0005433615753	9300	Business	132900.00
0005432756898	9300	Business	132900.00
0005433615757	9300	Business	132900.00
0005433615739	9300	Business	132900.00
0005433578011	9300	Business	132900.00
0005433615766	9300	Business	132900.00
0005433634309	9300	Business	132900.00
0005433615764	9300	Business	132900.00
0005433634316	9300	Business	132900.00
0005433615709	9300	Business	132900.00
0005433615770	9300	Business	132900.00
0005433615756	9300	Business	132900.00
0005433615731	9300	Business	132900.00
0005433615743	9300	Business	132900.00
0005433615712	9300	Business	132900.00
0005433615771	9300	Business	132900.00
0005433615716	9300	Business	132900.00
0005434269121	9300	Business	132900.00
0005434163700	9300	Business	132900.00
0005433615732	9300	Business	132900.00
0005433578019	9300	Business	132900.00
0005433578009	9300	Business	132900.00
0005433615767	9300	Economy	48700.00
0005433634326	9300	Economy	48700.00
0005433615762	9300	Economy	48700.00
0005433578022	9300	Economy	48700.00
0005433634314	9300	Economy	48700.00
0005433615750	9300	Economy	48700.00
0005434163687	9300	Economy	44300.00
0005432145141	9300	Economy	44300.00
0005433634324	9300	Economy	44300.00
0005433634296	9300	Economy	44300.00
0005433578021	9300	Economy	44300.00
0005433615733	9300	Economy	44300.00
0005433615710	9300	Economy	44300.00
0005433615722	9300	Economy	44300.00
0005434152797	9300	Economy	44300.00
0005433615765	9300	Economy	44300.00
0005432755125	9300	Economy	44300.00
0005433615774	9300	Economy	44300.00
0005433615713	9300	Economy	44300.00
0005434152798	9300	Economy	44300.00
0005433634328	9300	Economy	44300.00
0005433634320	9300	Economy	44300.00
0005433615755	9300	Economy	44300.00
0005433634308	9300	Economy	44300.00
0005433615707	9300	Economy	44300.00
0005433615778	9300	Economy	44300.00
0005433578017	9300	Economy	44300.00
0005433634302	9300	Economy	44300.00
0005433634319	9300	Economy	44300.00
0005433578008	9300	Economy	44300.00
0005434152799	9300	Economy	44300.00
0005433615727	9300	Economy	44300.00
0005433634318	9300	Economy	44300.00
0005433634327	9300	Economy	44300.00
0005433615726	9300	Economy	44300.00
0005434153536	9300	Economy	44300.00
0005434163692	9300	Economy	44300.00
0005433615717	9300	Economy	44300.00
0005434152782	9300	Economy	44300.00
0005434153539	9300	Economy	44300.00
0005433615711	9300	Economy	44300.00
0005433578014	9300	Economy	44300.00
0005433615776	9300	Economy	44300.00
0005433634317	9300	Economy	44300.00
0005433615738	9300	Economy	44300.00
0005433615729	9300	Economy	44300.00
0005433634321	9300	Economy	44300.00
0005433578012	9300	Economy	44300.00
0005433578007	9300	Economy	44300.00
0005433615720	9300	Economy	44300.00
0005434163690	9300	Economy	44300.00
0005433578015	9300	Economy	44300.00
0005433634305	9300	Economy	44300.00
0005433615741	9300	Economy	44300.00
0005433634312	9300	Economy	44300.00
0005433634298	9300	Economy	44300.00
0005433634304	9300	Economy	44300.00
0005433634315	9300	Economy	44300.00
0005433615715	9300	Economy	44300.00
0005433615734	9300	Economy	44300.00
0005433615724	9300	Economy	44300.00
0005433578020	9300	Economy	44300.00
0005434163699	9300	Economy	44300.00
0005433634323	9300	Economy	48700.00
0005432756899	9300	Economy	48700.00
0005433615772	9300	Economy	48700.00
0005433615742	9300	Economy	48700.00
0005433578016	9300	Economy	48700.00
0005433615728	9300	Economy	44300.00
0005433634313	9300	Economy	44300.00
0005433634303	9300	Economy	44300.00
0005433634295	9300	Economy	44300.00
0005433615740	9300	Economy	48700.00
0005433615749	9300	Economy	44300.00
0005433615752	9300	Economy	44300.00
0005434163685	9300	Economy	44300.00
0005434272209	9300	Economy	44300.00
0005434163686	9300	Economy	44300.00
0005433634322	9300	Economy	44300.00
0005433615763	9300	Economy	44300.00
0005433634297	9300	Economy	44300.00
0005433615751	9300	Economy	44300.00
0005433615708	9300	Economy	44300.00
0005434163652	9300	Economy	44300.00
0005433615747	9300	Economy	44300.00
0005433634330	9300	Economy	44300.00
0005433615718	9300	Economy	44300.00
0005434269109	9300	Economy	44300.00
0005433615714	9300	Economy	44300.00
0005434269115	9300	Economy	44300.00
0005433615735	9300	Economy	44300.00
0005432755126	9300	Economy	44300.00
0005434163711	9300	Economy	44300.00
0005433615754	9300	Economy	44300.00
0005433634299	9300	Economy	44300.00
0005433615780	9300	Economy	44300.00
0005433615761	9300	Economy	44300.00
0005433615768	9300	Economy	44300.00
0005433615760	9300	Economy	44300.00
0005433615775	9300	Economy	44300.00
0005433615725	9300	Economy	44300.00
0005433578010	9300	Economy	44300.00
0005433615744	9300	Economy	44300.00
0005433615723	9300	Economy	44300.00
0005433615759	9300	Economy	44300.00
0005433634306	9300	Economy	44300.00
0005433615773	9300	Economy	44300.00
0005433615777	9300	Economy	44300.00
0005433578013	9300	Economy	44300.00
0005433615721	9300	Economy	44300.00
0005433615745	9300	Economy	44300.00
0005433634307	9300	Economy	44300.00
0005433615758	9300	Economy	44300.00
0005433578018	9300	Economy	44300.00
0005433615737	9300	Economy	44300.00
0005432145142	9300	Economy	44300.00
0005433615730	9300	Economy	44300.00
0005433615719	9300	Economy	44300.00
0005434163712	9300	Economy	44300.00
0005433615748	9300	Economy	44300.00
0005433615781	9300	Economy	44300.00
0005433634300	9300	Economy	44300.00
0005433634301	9300	Economy	44300.00
0005433634325	9300	Economy	44300.00
0005433615779	9300	Economy	44300.00
0005434153546	9300	Economy	44300.00
0005432755127	9300	Economy	44300.00
0005434163691	9300	Economy	44300.00
0005434163672	9300	Economy	44300.00
0005433634311	9300	Economy	44300.00
0005434272208	9300	Economy	44300.00
0005433615736	9300	Economy	44300.00
0005433634329	9300	Economy	44300.00
0005433634007	25235	Business	132900.00
0005434163762	25235	Business	132900.00
0005433615149	25235	Business	132900.00
0005433614984	25235	Business	132900.00
0005434163757	25235	Business	132900.00
0005433633962	25235	Business	132900.00
0005433615062	25235	Business	132900.00
0005433614969	25235	Business	132900.00
0005433633838	25235	Business	132900.00
0005433615063	25235	Business	132900.00
0005434163755	25235	Business	132900.00
0005433615075	25235	Business	132900.00
0005433634092	25235	Business	132900.00
0005433634110	25235	Business	132900.00
0005433615081	25235	Business	132900.00
0005433615022	25235	Business	132900.00
0005433615198	25235	Business	132900.00
0005433614911	25235	Business	132900.00
0005433577886	25235	Business	132900.00
0005434163760	25235	Business	132900.00
0005433615317	25235	Business	132900.00
0005433615131	25235	Business	132900.00
0005433614949	25235	Business	132900.00
0005433615218	25235	Business	132900.00
0005433615130	25235	Business	132900.00
0005433634187	25235	Economy	48700.00
0005433633904	25235	Economy	48700.00
0005433634027	25235	Economy	48700.00
0005433614948	25235	Economy	48700.00
0005433615223	25235	Economy	48700.00
0005433615208	25235	Economy	44300.00
0005433577943	25235	Economy	44300.00
0005433615141	25235	Economy	44300.00
0005433634112	25235	Economy	44300.00
0005433577942	25235	Economy	44300.00
0005433614748	25235	Economy	44300.00
0005433577854	25235	Economy	44300.00
0005433614827	25235	Economy	44300.00
0005433615016	25235	Economy	44300.00
0005433634093	25235	Economy	44300.00
0005433615199	25235	Economy	44300.00
0005433614820	25235	Economy	44300.00
0005433615108	25235	Economy	44300.00
0005433634034	25235	Economy	44300.00
0005433615178	25235	Economy	44300.00
0005433615179	25235	Economy	44300.00
0005434163761	25235	Economy	44300.00
0005433577885	25235	Economy	44300.00
0005433634078	25235	Economy	44300.00
0005433615224	25235	Economy	44300.00
0005433615135	25235	Economy	44300.00
0005433614982	25235	Economy	44300.00
0005433615200	25235	Economy	44300.00
0005433634096	25235	Economy	44300.00
0005433577907	25235	Economy	44300.00
0005433577897	25235	Economy	44300.00
0005433634066	25235	Economy	44300.00
0005433615164	25235	Economy	44300.00
0005433634039	25235	Economy	44300.00
0005433615109	25235	Economy	44300.00
0005433615074	25235	Economy	44300.00
0005433614828	25235	Economy	44300.00
0005433614880	25235	Economy	44300.00
0005433615050	25235	Economy	44300.00
0005433634107	25235	Economy	44300.00
0005433615271	25235	Economy	44300.00
0005433614739	25235	Economy	44300.00
0005433615148	25235	Economy	44300.00
0005433614821	25235	Economy	44300.00
0005433577888	25235	Economy	44300.00
0005433577944	25235	Economy	44300.00
0005433615165	25235	Economy	44300.00
0005433614829	25235	Economy	44300.00
0005433615082	25235	Economy	44300.00
0005433634076	25235	Economy	44300.00
0005433633976	25235	Economy	44300.00
0005433577887	25235	Economy	44300.00
0005434273100	25235	Economy	44300.00
0005433634043	25235	Economy	44300.00
0005433634037	25235	Economy	44300.00
0005433634038	25235	Economy	44300.00
0005433614898	25235	Economy	44300.00
0005433615073	25235	Economy	44300.00
0005433615316	25235	Economy	44300.00
0005433615166	25235	Economy	44300.00
0005433633839	25235	Economy	44300.00
0005433634109	25235	Economy	48700.00
0005433615010	25235	Economy	48700.00
0005433615299	25235	Economy	48700.00
0005433577929	25235	Economy	48700.00
0005433614981	25235	Economy	48700.00
0005433615340	25235	Economy	44300.00
0005434273101	25235	Economy	44300.00
0005433615397	25235	Economy	44300.00
0005433615304	25235	Economy	44300.00
0005433615272	25235	Economy	48700.00
0005433615273	25235	Economy	44300.00
0005433614848	25235	Economy	44300.00
0005433633903	25235	Economy	44300.00
0005433615311	25235	Economy	44300.00
0005433633894	25235	Economy	44300.00
0005433615197	25235	Economy	44300.00
0005433577835	25235	Economy	44300.00
0005433577865	25235	Economy	44300.00
0005433614904	25235	Economy	44300.00
0005433615102	25235	Economy	44300.00
0005433633893	25235	Economy	44300.00
0005433615412	25235	Economy	44300.00
0005433614676	25235	Economy	44300.00
0005433615376	25235	Economy	44300.00
0005433615125	25235	Economy	44300.00
0005433615312	25235	Economy	44300.00
0005433615228	25235	Economy	44300.00
0005433614849	25235	Economy	44300.00
0005433615349	25235	Economy	44300.00
0005433615122	25235	Economy	44300.00
0005433634091	25235	Economy	44300.00
0005434163759	25235	Economy	44300.00
0005433615176	25235	Economy	44300.00
0005433634028	25235	Economy	44300.00
0005433615042	25235	Economy	44300.00
0005433615300	25235	Economy	44300.00
0005433633961	25235	Economy	44300.00
0005434163764	25235	Economy	44300.00
0005433634062	25235	Economy	44300.00
0005433615005	25235	Economy	44300.00
0005433615069	25235	Economy	44300.00
0005433577884	25235	Economy	44300.00
0005433615525	25235	Economy	44300.00
0005433614859	25235	Economy	44300.00
0005433634054	25235	Economy	44300.00
0005433634029	25235	Economy	44300.00
0005433634142	25235	Economy	44300.00
0005433615015	25235	Economy	44300.00
0005433615172	25235	Economy	44300.00
0005433614929	25235	Economy	44300.00
0005433634095	25235	Economy	44300.00
0005434163763	25235	Economy	44300.00
0005433615126	25235	Economy	44300.00
0005433615398	25235	Economy	44300.00
0005433615142	25235	Economy	44300.00
0005434163758	25235	Economy	44300.00
0005433614868	25235	Economy	44300.00
0005433615209	25235	Economy	44300.00
0005434163756	25235	Economy	44300.00
0005433615348	25235	Economy	44300.00
0005433614775	25235	Economy	44300.00
0005433634055	25235	Economy	44300.00
0005433634087	25235	Economy	44300.00
0005434163754	25235	Economy	44300.00
0005433615110	25235	Economy	44300.00
0005433634108	25235	Economy	44300.00
0005433615043	25235	Economy	44300.00
0005433577830	25235	Economy	44300.00
0005433614881	25235	Economy	44300.00
0005433614970	25235	Economy	44300.00
0005433634044	25235	Economy	44300.00
0005433577813	25235	Economy	44300.00
0005433614677	25235	Economy	44300.00
0005434271327	4242	Business	193100.00
0005435947319	4242	Business	193100.00
0005435947420	4242	Business	193100.00
0005435947343	4242	Business	193100.00
0005434271319	4242	Business	193100.00
0005435947363	4242	Economy	70800.00
0005435986877	4242	Economy	70800.00
0005435986875	4242	Economy	64400.00
0005435947323	4242	Economy	64400.00
0005435986867	4242	Economy	64400.00
0005435947382	4242	Economy	64400.00
0005435986870	4242	Economy	64400.00
0005435947344	4242	Economy	64400.00
0005435986871	4242	Economy	64400.00
0005435947353	4242	Economy	64400.00
0005435986868	4242	Economy	64400.00
0005435947324	4242	Economy	64400.00
0005435986874	4242	Economy	64400.00
0005435947318	4242	Economy	64400.00
0005435986869	4242	Economy	64400.00
0005435986872	4242	Economy	64400.00
0005432184996	4242	Economy	64400.00
0005434271322	4242	Economy	64400.00
0005435986876	4242	Economy	64400.00
0005435947372	4242	Economy	70800.00
0005435947312	4242	Economy	64400.00
0005435986873	4242	Economy	64400.00
0005435986878	4242	Economy	64400.00
0005434271328	4242	Economy	64400.00
0005435947336	4242	Economy	64400.00
0005432571346	4242	Economy	64400.00
0005435947366	4242	Economy	64400.00
0005435947325	4242	Economy	64400.00
0005435947374	4242	Economy	64400.00
0005432184995	4242	Economy	64400.00
0005435947362	4242	Economy	64400.00
0005435947371	4242	Economy	64400.00
0005432184997	4242	Economy	64400.00
0005435947322	4242	Economy	64400.00
0005435947478	26606	Business	193100.00
0005432571382	26606	Business	193100.00
0005435947482	26606	Business	193100.00
0005435947485	26606	Economy	64400.00
0005435947474	26606	Economy	64400.00
0005435986786	26606	Economy	64400.00
0005435787390	26606	Economy	64400.00
0005435787389	26606	Economy	64400.00
0005435947477	26606	Economy	64400.00
0005435986779	26606	Economy	64400.00
0005435856270	26606	Economy	64400.00
0005435986781	26606	Economy	64400.00
0005435986787	26606	Economy	64400.00
0005435856269	26606	Economy	64400.00
0005435947476	26606	Economy	64400.00
0005435947479	26606	Economy	64400.00
0005435947481	26606	Economy	64400.00
0005435947475	26606	Economy	64400.00
0005435947487	26606	Economy	64400.00
0005432571385	26606	Economy	64400.00
0005435856272	26606	Economy	64400.00
0005435856268	26606	Economy	64400.00
0005432571383	26606	Economy	64400.00
0005432571384	26606	Economy	64400.00
0005435947488	26606	Economy	64400.00
0005435947480	26606	Economy	64400.00
0005435856271	26606	Economy	64400.00
0005435947483	26606	Economy	64400.00
0005435947484	26606	Economy	64400.00
0005435947486	26606	Economy	64400.00
0005433074824	338	Business	21500.00
0005433074902	338	Business	21500.00
0005433129313	338	Business	21500.00
0005433570013	338	Business	21500.00
0005433074901	338	Business	21500.00
0005433074906	338	Business	21500.00
0005433129305	338	Business	21500.00
0005433569978	338	Business	21500.00
0005433074951	338	Business	21500.00
0005432948560	338	Business	21500.00
0005433134171	338	Business	21500.00
0005433569989	338	Business	21500.00
0005433569973	338	Business	21500.00
0005433570010	338	Business	21500.00
0005432948753	338	Business	21500.00
0005432948698	338	Business	21500.00
0005432948697	338	Business	21500.00
0005432948661	338	Business	21500.00
0005432948788	338	Business	21500.00
0005433569988	338	Business	21500.00
0005432948669	338	Business	21500.00
0005433570001	338	Business	21500.00
0005432948660	338	Business	21500.00
0005433129312	338	Economy	7900.00
0005433570014	338	Business	21500.00
0005432948729	338	Economy	7900.00
0005433570007	338	Economy	7900.00
0005433074826	338	Economy	7900.00
0005432948621	338	Economy	7200.00
0005433074899	338	Economy	7200.00
0005433570000	338	Economy	7200.00
0005432239034	338	Economy	7200.00
0005433570019	338	Economy	7200.00
0005433570018	338	Economy	7200.00
0005433570023	338	Economy	7200.00
0005433074802	338	Economy	7200.00
0005433570024	338	Economy	7200.00
0005433074886	338	Economy	7200.00
0005433569990	338	Economy	7200.00
0005433074983	338	Economy	7200.00
0005433569985	338	Economy	7200.00
0005432948739	338	Economy	7200.00
0005433569998	338	Economy	7200.00
0005433074929	338	Economy	7200.00
0005433074930	338	Economy	7200.00
0005433570026	338	Economy	7200.00
0005433074771	338	Economy	7200.00
0005433074870	338	Economy	7200.00
0005433074890	338	Economy	7200.00
0005433570009	338	Economy	7200.00
0005432948700	338	Economy	7200.00
0005433074959	338	Economy	7200.00
0005432948668	338	Economy	7200.00
0005432948611	338	Economy	7200.00
0005433570017	338	Economy	7200.00
0005433570011	338	Economy	7200.00
0005432948620	338	Economy	7200.00
0005432948759	338	Economy	7200.00
0005433074905	338	Economy	7200.00
0005432948507	338	Economy	7200.00
0005432948761	338	Economy	7200.00
0005432948685	338	Economy	7200.00
0005432948702	338	Economy	7200.00
0005432239029	338	Economy	7200.00
0005433569984	338	Economy	7200.00
0005433074961	338	Economy	7200.00
0005433569976	338	Economy	7200.00
0005433569987	338	Economy	7200.00
0005432948796	338	Economy	7200.00
0005433570006	338	Economy	7200.00
0005433569971	338	Economy	7200.00
0005433570022	338	Economy	7200.00
0005433570004	338	Economy	7200.00
0005432948615	338	Economy	7200.00
0005432948607	338	Economy	7200.00
0005432948691	338	Economy	7200.00
0005432948732	338	Economy	7200.00
0005433074908	338	Economy	7200.00
0005433569995	338	Economy	7200.00
0005433569999	338	Economy	7200.00
0005433569991	338	Economy	7200.00
0005433569993	338	Economy	7200.00
0005432948767	338	Economy	7900.00
0005433074770	338	Economy	7900.00
0005433570028	338	Economy	7900.00
0005432948606	338	Economy	7900.00
0005432948676	338	Economy	7900.00
0005432239030	338	Economy	7200.00
0005433129306	338	Economy	7200.00
0005432948766	338	Economy	7200.00
0005432948690	338	Economy	7200.00
0005432948724	338	Economy	7900.00
0005433129295	338	Economy	7200.00
0005433569981	338	Economy	7200.00
0005433570016	338	Economy	7200.00
0005433074878	338	Economy	7200.00
0005433570012	338	Economy	7200.00
0005432239031	338	Economy	7200.00
0005433570025	338	Economy	7200.00
0005433569986	338	Economy	7200.00
0005432948481	338	Economy	7200.00
0005432948728	338	Economy	7200.00
0005432948800	338	Economy	7200.00
0005432948701	338	Economy	7200.00
0005433570005	338	Economy	7200.00
0005433074950	338	Economy	7200.00
0005432948706	338	Economy	7200.00
0005432948659	338	Economy	7200.00
0005432948819	338	Economy	7200.00
0005433569979	338	Economy	7200.00
0005433075084	338	Economy	7200.00
0005432239032	338	Economy	7200.00
0005433570008	338	Economy	7200.00
0005433570015	338	Economy	7200.00
0005432948760	338	Economy	7200.00
0005433569974	338	Economy	7200.00
0005432948799	338	Economy	7200.00
0005432948665	338	Economy	7200.00
0005433569980	338	Economy	7200.00
0005433134126	338	Economy	7200.00
0005433570003	338	Economy	7200.00
0005433074776	338	Economy	7200.00
0005432948730	338	Economy	7200.00
0005433074907	338	Economy	7200.00
0005433569982	338	Economy	7200.00
0005432948707	338	Economy	7200.00
0005433569977	338	Economy	7200.00
0005432948749	338	Economy	7200.00
0005433570027	338	Economy	7200.00
0005433570020	338	Economy	7200.00
0005433569994	338	Economy	7200.00
0005432948797	338	Economy	7200.00
0005433570021	338	Economy	7200.00
0005433129284	338	Economy	7200.00
0005432948682	338	Economy	7200.00
0005433570002	338	Economy	7200.00
0005432239033	338	Economy	7200.00
0005432948622	338	Economy	7200.00
0005433134172	338	Economy	7200.00
0005432239028	338	Economy	7200.00
0005433569997	338	Economy	7200.00
0005432948703	338	Economy	7200.00
0005433569983	338	Economy	7200.00
0005433569972	338	Economy	7200.00
0005433569975	338	Economy	7200.00
0005432948694	338	Economy	7200.00
0005433074954	338	Economy	7200.00
0005432948748	338	Economy	7200.00
0005433129311	338	Economy	7200.00
0005433074803	338	Economy	7200.00
0005433074903	338	Economy	7200.00
0005433569992	338	Economy	7200.00
0005433074925	338	Economy	7200.00
0005433569996	338	Economy	7200.00
0005432949096	11591	Business	21500.00
0005433075144	11591	Business	21500.00
0005433569233	11591	Business	21500.00
0005433569272	11591	Business	21500.00
0005432949092	11591	Business	21500.00
0005433569218	11591	Business	21500.00
0005432949064	11591	Business	21500.00
0005433569138	11591	Business	21500.00
0005433569333	11591	Business	21500.00
0005433075137	11591	Business	21500.00
0005433075150	11591	Business	21500.00
0005433131776	11591	Business	21500.00
0005432949058	11591	Business	21500.00
0005433075154	11591	Business	21500.00
0005433569391	11591	Business	21500.00
0005432949059	11591	Business	21500.00
0005433569328	11591	Business	21500.00
0005432192369	11591	Business	21500.00
0005433569124	11591	Business	21500.00
0005433569301	11591	Business	21500.00
0005432949072	11591	Business	21500.00
0005433569053	11591	Business	21500.00
0005433569212	11591	Business	21500.00
0005433569284	11591	Business	21500.00
0005433569178	11591	Business	21500.00
0005433569088	11591	Economy	7900.00
0005433569439	11591	Economy	7900.00
0005432949061	11591	Economy	7900.00
0005432192370	11591	Economy	7900.00
0005433569204	11591	Economy	7900.00
0005433569278	11591	Economy	7900.00
0005433075148	11591	Economy	7200.00
0005432949086	11591	Economy	7200.00
0005433569397	11591	Economy	7200.00
0005433075133	11591	Economy	7200.00
0005433569349	11591	Economy	7200.00
0005433569261	11591	Economy	7200.00
0005433075131	11591	Economy	7200.00
0005433569327	11591	Economy	7200.00
0005433569300	11591	Economy	7200.00
0005433569209	11591	Economy	7200.00
0005433569358	11591	Economy	7200.00
0005433569177	11591	Economy	7200.00
0005432949094	11591	Economy	7200.00
0005433569399	11591	Economy	7200.00
0005432949084	11591	Economy	7200.00
0005432949082	11591	Economy	7200.00
0005432949074	11591	Economy	7200.00
0005433131780	11591	Economy	7200.00
0005433134208	11591	Economy	7200.00
0005433131779	11591	Economy	7200.00
0005433075147	11591	Economy	7200.00
0005433075139	11591	Economy	7200.00
0005433075149	11591	Economy	7200.00
0005432949076	11591	Economy	7200.00
0005433569004	11591	Economy	7200.00
0005432949090	11591	Economy	7200.00
0005433569164	11591	Economy	7200.00
0005433075143	11591	Economy	7200.00
0005433075159	11591	Economy	7200.00
0005433569059	11591	Economy	7200.00
0005433569058	11591	Economy	7200.00
0005432949066	11591	Economy	7200.00
0005432949097	11591	Economy	7200.00
0005433075153	11591	Economy	7200.00
0005432192368	11591	Economy	7200.00
0005432949088	11591	Economy	7200.00
0005433569357	11591	Economy	7200.00
0005432949062	11591	Economy	7200.00
0005432949079	11591	Economy	7200.00
0005433569375	11591	Economy	7200.00
0005433569279	11591	Economy	7200.00
0005432949089	11591	Economy	7200.00
0005433075152	11591	Economy	7200.00
0005433569052	11591	Economy	7200.00
0005433569347	11591	Economy	7200.00
0005432949069	11591	Economy	7200.00
0005433569423	11591	Economy	7200.00
0005432949060	11591	Economy	7200.00
0005433075156	11591	Economy	7200.00
0005432949063	11591	Economy	7200.00
0005433569254	11591	Economy	7200.00
0005432949095	11591	Economy	7200.00
0005433131778	11591	Economy	7200.00
0005433075158	11591	Economy	7200.00
0005433569215	11591	Economy	7900.00
0005432949071	11591	Economy	7900.00
0005433569312	11591	Economy	7900.00
0005433075157	11591	Economy	7900.00
0005433075151	11591	Economy	7900.00
0005432949065	11591	Economy	7200.00
0005433134211	11591	Economy	7200.00
0005433134210	11591	Economy	7200.00
0005433075155	11591	Economy	7200.00
0005433569393	11591	Economy	7900.00
0005433075140	11591	Economy	7200.00
0005433075130	11591	Economy	7200.00
0005432949070	11591	Economy	7200.00
0005433075138	11591	Economy	7200.00
0005433569192	11591	Economy	7200.00
0005433134206	11591	Economy	7200.00
0005432949091	11591	Economy	7200.00
0005433569322	11591	Economy	7200.00
0005432949068	11591	Economy	7200.00
0005432949067	11591	Economy	7200.00
0005432949083	11591	Economy	7200.00
0005433569235	11591	Economy	7200.00
0005433569213	11591	Economy	7200.00
0005433569332	11591	Economy	7200.00
0005433569229	11591	Economy	7200.00
0005433569369	11591	Economy	7200.00
0005433131777	11591	Economy	7200.00
0005432949081	11591	Economy	7200.00
0005433569214	11591	Economy	7200.00
0005433075141	11591	Economy	7200.00
0005433075145	11591	Economy	7200.00
0005432949087	11591	Economy	7200.00
0005432949075	11591	Economy	7200.00
0005433569222	11591	Economy	7200.00
0005433075142	11591	Economy	7200.00
0005432192367	11591	Economy	7200.00
0005433569140	11591	Economy	7200.00
0005433075134	11591	Economy	7200.00
0005432949073	11591	Economy	7200.00
0005433569260	11591	Economy	7200.00
0005433569188	11591	Economy	7200.00
0005433569313	11591	Economy	7200.00
0005433569406	11591	Economy	7200.00
0005433569323	11591	Economy	7200.00
0005433134207	11591	Economy	7200.00
0005432949057	11591	Economy	7200.00
0005433569003	11591	Economy	7200.00
0005433569273	11591	Economy	7200.00
0005433569319	11591	Economy	7200.00
0005432949093	11591	Economy	7200.00
0005433569338	11591	Economy	7200.00
0005432949078	11591	Economy	7200.00
0005433569376	11591	Economy	7200.00
0005433075132	11591	Economy	7200.00
0005432949085	11591	Economy	7200.00
0005432949080	11591	Economy	7200.00
0005433075135	11591	Economy	7200.00
0005433075136	11591	Economy	7200.00
0005432949077	11591	Economy	7200.00
0005433134209	11591	Economy	7200.00
0005433075146	11591	Economy	7200.00
0005433569262	11591	Economy	7200.00
0005433569424	11591	Economy	7200.00
0005433569350	11591	Economy	7200.00
0005433569154	11591	Economy	7200.00
0005433569173	11591	Economy	7200.00
0005434733022	10010	Economy	6300.00
0005434732992	10010	Economy	6300.00
0005433817530	10010	Economy	6300.00
0005434733021	10010	Economy	6300.00
0005433817528	10010	Economy	6300.00
0005434732991	10010	Economy	6300.00
0005433817527	10010	Economy	6300.00
0005434732998	10010	Economy	6300.00
0005434732999	10010	Economy	6300.00
0005433817529	10010	Economy	6300.00
0005434732997	10010	Economy	6300.00
0005434733034	13900	Economy	6300.00
0005433817502	13900	Economy	6300.00
0005434733035	13900	Economy	6300.00
0005434733036	13900	Economy	6300.00
0005432985325	2337	Business	184500.00
0005432226155	2337	Business	184500.00
0005432655718	2337	Business	184500.00
0005435982992	2337	Business	184500.00
0005432655719	2337	Business	184500.00
0005433755080	2337	Business	184500.00
0005432985177	2337	Business	184500.00
0005433755079	2337	Business	184500.00
0005435982993	2337	Business	184500.00
0005435982999	2337	Business	184500.00
0005434731197	2337	Business	184500.00
0005435982984	2337	Business	184500.00
0005435983005	2337	Business	184500.00
0005433434882	2337	Business	184500.00
0005433434855	2337	Business	184500.00
0005432985333	2337	Business	184500.00
0005432985201	2337	Business	184500.00
0005433434744	2337	Business	184500.00
0005432985470	2337	Business	184500.00
0005433434881	2337	Business	184500.00
0005433755104	2337	Business	184500.00
0005432226156	2337	Business	184500.00
0005432985388	2337	Business	184500.00
0005433755090	2337	Business	184500.00
0005435983006	2337	Business	184500.00
0005432655729	2337	Business	184500.00
0005433434876	2337	Business	184500.00
0005433755088	2337	Business	184500.00
0005432655725	2337	Business	184500.00
0005432300356	2337	Economy	67700.00
0005433755064	2337	Economy	67700.00
0005433755071	2337	Economy	67700.00
0005435983007	2337	Economy	67700.00
0005433755073	2337	Economy	61500.00
0005432985269	2337	Economy	61500.00
0005433434939	2337	Economy	61500.00
0005433755117	2337	Economy	61500.00
0005433434844	2337	Economy	61500.00
0005435983003	2337	Economy	61500.00
0005435983000	2337	Economy	61500.00
0005433434746	2337	Economy	61500.00
0005432226157	2337	Economy	61500.00
0005432869554	2337	Economy	61500.00
0005435983008	2337	Economy	61500.00
0005433755078	2337	Economy	61500.00
0005432985291	2337	Economy	61500.00
0005435983009	2337	Economy	61500.00
0005433764711	2337	Economy	61500.00
0005433755114	2337	Economy	61500.00
0005433755097	2337	Economy	61500.00
0005432655724	2337	Economy	61500.00
0005434731192	2337	Economy	61500.00
0005435982997	2337	Economy	61500.00
0005433755091	2337	Economy	61500.00
0005435982985	2337	Economy	61500.00
0005435983016	2337	Economy	61500.00
0005433434878	2337	Economy	61500.00
0005433434879	2337	Economy	61500.00
0005433434897	2337	Economy	61500.00
0005432985391	2337	Economy	61500.00
0005433755094	2337	Economy	61500.00
0005433755089	2337	Economy	61500.00
0005432985469	2337	Economy	61500.00
0005433435014	2337	Economy	61500.00
0005432985352	2337	Economy	61500.00
0005433434858	2337	Economy	61500.00
0005432985392	2337	Economy	61500.00
0005433755086	2337	Economy	61500.00
0005433755067	2337	Economy	61500.00
0005433434908	2337	Economy	61500.00
0005432985321	2337	Economy	61500.00
0005432655728	2337	Economy	61500.00
0005433755101	2337	Economy	61500.00
0005432655720	2337	Economy	61500.00
0005435982982	2337	Economy	61500.00
0005433755118	2337	Economy	61500.00
0005433434877	2337	Economy	61500.00
0005432985292	2337	Economy	61500.00
0005433434788	2337	Economy	61500.00
0005435983001	2337	Economy	61500.00
0005435982991	2337	Economy	61500.00
0005432300352	2337	Economy	61500.00
0005433434815	2337	Economy	61500.00
0005435983004	2337	Economy	61500.00
0005435983013	2337	Economy	61500.00
0005433434813	2337	Economy	61500.00
0005432300353	2337	Economy	61500.00
0005433434853	2337	Economy	61500.00
0005433434789	2337	Economy	61500.00
0005433766698	2337	Economy	61500.00
0005432985324	2337	Economy	61500.00
0005432226158	2337	Economy	61500.00
0005433434886	2337	Economy	61500.00
0005432300357	2337	Economy	61500.00
0005433755072	2337	Economy	61500.00
0005435983014	2337	Economy	61500.00
0005433755107	2337	Economy	61500.00
0005432985320	2337	Economy	61500.00
0005433755083	2337	Economy	61500.00
0005433755066	2337	Economy	61500.00
0005433755106	2337	Economy	61500.00
0005433755111	2337	Economy	61500.00
0005433755076	2337	Economy	61500.00
0005434731193	2337	Economy	61500.00
0005433755115	2337	Economy	61500.00
0005433766697	2337	Economy	61500.00
0005435982989	2337	Economy	61500.00
0005433755081	2337	Economy	61500.00
0005433434842	2337	Economy	61500.00
0005433434820	2337	Economy	61500.00
0005435982986	2337	Economy	61500.00
0005432655726	2337	Economy	61500.00
0005432655721	2337	Economy	61500.00
0005432985358	2337	Economy	61500.00
0005433755063	2337	Economy	61500.00
0005433755109	2337	Economy	61500.00
0005432655717	2337	Economy	61500.00
0005432985422	2337	Economy	61500.00
0005432985145	2337	Economy	61500.00
0005433755084	2337	Economy	61500.00
0005433434794	2337	Economy	61500.00
0005433755098	2337	Economy	61500.00
0005435983002	2337	Economy	61500.00
0005433755105	2337	Economy	67700.00
0005435982983	2337	Economy	61500.00
0005433434857	2337	Economy	61500.00
0005432985468	2337	Economy	61500.00
0005433755103	2337	Economy	67700.00
0005433755065	2337	Economy	61500.00
0005432985205	2337	Economy	61500.00
0005432869550	2337	Economy	61500.00
0005433434898	2337	Economy	61500.00
0005433434736	2337	Economy	61500.00
0005433764712	2337	Economy	61500.00
0005432869555	2337	Economy	61500.00
0005433755113	2337	Economy	61500.00
0005432985319	2337	Economy	61500.00
0005432985270	2337	Economy	61500.00
0005433434896	2337	Economy	61500.00
0005433766700	2337	Economy	61500.00
0005433755077	2337	Economy	61500.00
0005435982998	2337	Economy	61500.00
0005433434905	2337	Economy	61500.00
0005432869551	2337	Economy	61500.00
0005433755110	2337	Economy	61500.00
0005432300354	2337	Economy	61500.00
0005435983011	2337	Economy	61500.00
0005433755108	2337	Economy	61500.00
0005432985379	2337	Economy	61500.00
0005433755074	2337	Economy	61500.00
0005433766699	2337	Economy	61500.00
0005433755096	2337	Economy	61500.00
0005432300355	2337	Economy	61500.00
0005433755099	2337	Economy	61500.00
0005433755085	2337	Economy	61500.00
0005433755093	2337	Economy	61500.00
0005435982995	2337	Economy	61500.00
0005433766701	2337	Economy	61500.00
0005435982994	2337	Economy	61500.00
0005432985207	2337	Economy	61500.00
0005433755068	2337	Economy	61500.00
0005432985290	2337	Economy	61500.00
0005433434814	2337	Economy	61500.00
0005433755102	2337	Economy	61500.00
0005432985353	2337	Economy	61500.00
0005433755119	2337	Economy	61500.00
0005435983015	2337	Economy	61500.00
0005433755100	2337	Economy	61500.00
0005435982990	2337	Economy	61500.00
0005433755095	2337	Economy	61500.00
0005435982987	2337	Economy	61500.00
0005432985176	2337	Economy	61500.00
0005432655722	2337	Economy	61500.00
0005432655723	2337	Economy	61500.00
0005433755075	2337	Economy	61500.00
0005435982988	2337	Economy	61500.00
0005433755070	2337	Economy	61500.00
0005433434817	2337	Economy	61500.00
0005433434819	2337	Economy	61500.00
0005432985178	2337	Economy	61500.00
0005433755092	2337	Economy	61500.00
0005435982996	2337	Economy	61500.00
0005432985311	2337	Economy	61500.00
0005433755069	2337	Economy	61500.00
0005432226154	2337	Economy	61500.00
0005435983012	2337	Economy	61500.00
0005435983010	2337	Economy	61500.00
0005432226159	2337	Economy	61500.00
0005433755112	2337	Economy	61500.00
0005433755116	2337	Economy	61500.00
0005433755082	2337	Economy	61500.00
0005432655727	2337	Economy	61500.00
0005432985234	2337	Economy	61500.00
0005432300351	2337	Economy	61500.00
0005433755087	2337	Economy	61500.00
0005432985151	2337	Economy	61500.00
0005432985357	2337	Economy	61500.00
0005432985302	2337	Economy	61500.00
0005433434907	2337	Economy	61500.00
0005433434816	2337	Economy	61500.00
0005433435114	26193	Business	184500.00
0005433754696	26193	Business	184500.00
0005433435118	26193	Business	184500.00
0005433754627	26193	Business	184500.00
0005433754652	26193	Business	184500.00
0005433435108	26193	Business	184500.00
0005432051175	26193	Business	184500.00
0005433754571	26193	Business	184500.00
0005435982603	26193	Business	184500.00
0005435982390	26193	Business	184500.00
0005433754803	26193	Business	184500.00
0005432869622	26193	Business	184500.00
0005434731235	26193	Business	184500.00
0005435982529	26193	Business	184500.00
0005433754292	26193	Business	184500.00
0005432049520	26193	Business	184500.00
0005435982495	26193	Business	184500.00
0005432655619	26193	Business	184500.00
0005432985580	26193	Business	184500.00
0005435982519	26193	Business	184500.00
0005433754624	26193	Business	184500.00
0005433754532	26193	Business	184500.00
0005432985577	26193	Business	184500.00
0005432985587	26193	Business	184500.00
0005433754651	26193	Business	184500.00
0005433754501	26193	Business	184500.00
0005433754524	26193	Business	184500.00
0005432985588	26193	Economy	67700.00
0005433754574	26193	Economy	67700.00
0005432985589	26193	Economy	67700.00
0005433754301	26193	Economy	67700.00
0005433435119	26193	Economy	61500.00
0005432655618	26193	Economy	61500.00
0005435982518	26193	Economy	61500.00
0005433754710	26193	Economy	61500.00
0005433754641	26193	Economy	61500.00
0005432985567	26193	Economy	61500.00
0005432869626	26193	Economy	61500.00
0005435982558	26193	Economy	61500.00
0005433754471	26193	Economy	61500.00
0005433435123	26193	Economy	61500.00
0005433435113	26193	Economy	61500.00
0005433754241	26193	Economy	61500.00
0005432655542	26193	Economy	61500.00
0005433435116	26193	Economy	61500.00
0005433435109	26193	Economy	61500.00
0005435982428	26193	Economy	61500.00
0005433754530	26193	Economy	61500.00
0005433754764	26193	Economy	61500.00
0005433435102	26193	Economy	61500.00
0005432985593	26193	Economy	61500.00
0005433435103	26193	Economy	61500.00
0005432985582	26193	Economy	61500.00
0005433435117	26193	Economy	61500.00
0005432985592	26193	Economy	61500.00
0005433754585	26193	Economy	61500.00
0005433435122	26193	Economy	61500.00
0005433754540	26193	Economy	61500.00
0005433754572	26193	Economy	61500.00
0005433766659	26193	Economy	61500.00
0005433754914	26193	Economy	61500.00
0005433435121	26193	Economy	61500.00
0005432869628	26193	Economy	61500.00
0005432655598	26193	Economy	61500.00
0005432985562	26193	Economy	61500.00
0005435982581	26193	Economy	61500.00
0005432985585	26193	Economy	61500.00
0005433435107	26193	Economy	61500.00
0005432985571	26193	Economy	61500.00
0005433754573	26193	Economy	61500.00
0005432985573	26193	Economy	61500.00
0005433754460	26193	Economy	61500.00
0005433754805	26193	Economy	61500.00
0005432049518	26193	Economy	61500.00
0005432655564	26193	Economy	61500.00
0005433435120	26193	Economy	61500.00
0005432985569	26193	Economy	61500.00
0005433754426	26193	Economy	61500.00
0005432051176	26193	Economy	61500.00
0005433754704	26193	Economy	61500.00
0005432985590	26193	Economy	61500.00
0005433754753	26193	Economy	61500.00
0005433754703	26193	Economy	61500.00
0005432655607	26193	Economy	61500.00
0005435982536	26193	Economy	61500.00
0005433754517	26193	Economy	61500.00
0005433754555	26193	Economy	61500.00
0005432985595	26193	Economy	61500.00
0005435982448	26193	Economy	61500.00
0005432869624	26193	Economy	61500.00
0005432655587	26193	Economy	61500.00
0005432985574	26193	Economy	61500.00
0005433754516	26193	Economy	61500.00
0005433754459	26193	Economy	61500.00
0005432985570	26193	Economy	61500.00
0005433754550	26193	Economy	61500.00
0005435982621	26193	Economy	61500.00
0005433754373	26193	Economy	61500.00
0005432985584	26193	Economy	61500.00
0005433754711	26193	Economy	61500.00
0005433754577	26193	Economy	61500.00
0005433754427	26193	Economy	61500.00
0005433754642	26193	Economy	61500.00
0005433435106	26193	Economy	61500.00
0005433766682	26193	Economy	61500.00
0005433754529	26193	Economy	61500.00
0005433754621	26193	Economy	61500.00
0005435982513	26193	Economy	61500.00
0005432655581	26193	Economy	61500.00
0005433754646	26193	Economy	61500.00
0005433754754	26193	Economy	61500.00
0005435982645	26193	Economy	61500.00
0005433754432	26193	Economy	61500.00
0005433754564	26193	Economy	61500.00
0005432985583	26193	Economy	61500.00
0005432985563	26193	Economy	61500.00
0005432985581	26193	Economy	61500.00
0005433754622	26193	Economy	61500.00
0005435982429	26193	Economy	61500.00
0005432869621	26193	Economy	61500.00
0005433435127	26193	Economy	61500.00
0005432985578	26193	Economy	61500.00
0005433754765	26193	Economy	61500.00
0005434731236	26193	Economy	61500.00
0005432985564	26193	Economy	61500.00
0005435982433	26193	Economy	67700.00
0005433435111	26193	Economy	67700.00
0005432985568	26193	Economy	61500.00
0005432985576	26193	Economy	61500.00
0005433754531	26193	Economy	61500.00
0005435982329	26193	Economy	67700.00
0005433754518	26193	Economy	67700.00
0005433754453	26193	Economy	61500.00
0005433435126	26193	Economy	61500.00
0005433435105	26193	Economy	61500.00
0005432985594	26193	Economy	61500.00
0005433435125	26193	Economy	61500.00
0005435982527	26193	Economy	61500.00
0005435982592	26193	Economy	61500.00
0005435982545	26193	Economy	61500.00
0005432985579	26193	Economy	61500.00
0005435982646	26193	Economy	61500.00
0005432655574	26193	Economy	61500.00
0005434731237	26193	Economy	61500.00
0005432869623	26193	Economy	61500.00
0005433435124	26193	Economy	61500.00
0005433754584	26193	Economy	61500.00
0005432985575	26193	Economy	61500.00
0005435982398	26193	Economy	61500.00
0005435982591	26193	Economy	61500.00
0005432869627	26193	Economy	61500.00
0005433754664	26193	Economy	61500.00
0005435982602	26193	Economy	61500.00
0005435982531	26193	Economy	61500.00
0005433754503	26193	Economy	61500.00
0005432985586	26193	Economy	61500.00
0005433754523	26193	Economy	61500.00
0005433754709	26193	Economy	61500.00
0005432985566	26193	Economy	61500.00
0005435982530	26193	Economy	61500.00
0005433435129	26193	Economy	61500.00
0005435982432	26193	Economy	61500.00
0005433754714	26193	Economy	61500.00
0005433754665	26193	Economy	61500.00
0005435982449	26193	Economy	61500.00
0005433754752	26193	Economy	61500.00
0005435982619	26193	Economy	61500.00
0005432869625	26193	Economy	61500.00
0005433754425	26193	Economy	61500.00
0005432985591	26193	Economy	61500.00
0005432655596	26193	Economy	61500.00
0005435982469	26193	Economy	61500.00
0005433754502	26193	Economy	61500.00
0005435982572	26193	Economy	61500.00
0005432051177	26193	Economy	61500.00
0005432985565	26193	Economy	61500.00
0005435982516	26193	Economy	61500.00
0005432655580	26193	Economy	61500.00
0005433754702	26193	Economy	61500.00
0005433754479	26193	Economy	61500.00
0005432655575	26193	Economy	61500.00
0005434731238	26193	Economy	61500.00
0005433754751	26193	Economy	61500.00
0005435982397	26193	Economy	61500.00
0005433435110	26193	Economy	61500.00
0005433435112	26193	Economy	61500.00
0005435982408	26193	Economy	61500.00
0005433435115	26193	Economy	61500.00
0005435982427	26193	Economy	61500.00
0005433754494	26193	Economy	61500.00
0005433754687	26193	Economy	61500.00
0005433435128	26193	Economy	61500.00
0005433435104	26193	Economy	61500.00
0005435982412	26193	Economy	61500.00
0005433754586	26193	Economy	61500.00
0005432049519	26193	Economy	61500.00
0005432655588	26193	Economy	61500.00
0005435982537	26193	Economy	61500.00
0005435982389	26193	Economy	61500.00
0005433754804	26193	Economy	61500.00
0005433754668	26193	Economy	61500.00
0005433754591	26193	Economy	61500.00
0005432985572	26193	Economy	61500.00
0005432655593	26193	Economy	61500.00
0005435982573	26193	Economy	61500.00
0005433754493	26193	Economy	61500.00
0005433766660	26193	Economy	61500.00
0005435982606	26193	Economy	61500.00
0005434375325	1509	Business	38900.00
0005432268001	1509	Business	38900.00
0005433151812	1509	Business	38900.00
0005434375350	1509	Business	38900.00
0005434375348	1509	Business	38900.00
0005434375345	1509	Business	38900.00
0005434029670	1509	Business	38900.00
0005434375357	1509	Business	38900.00
0005433151633	1509	Business	38900.00
0005433151592	1509	Business	38900.00
0005433764690	1509	Economy	13000.00
0005433151729	1509	Economy	13000.00
0005434375329	1509	Economy	13000.00
0005434375337	1509	Economy	13000.00
0005433151724	1509	Economy	13000.00
0005433461622	1509	Economy	13000.00
0005434375331	1509	Economy	13000.00
0005433151616	1509	Economy	13000.00
0005433151617	1509	Economy	13000.00
0005434375327	1509	Economy	13000.00
0005434375338	1509	Economy	13000.00
0005433931492	1509	Economy	13000.00
0005433461621	1509	Economy	13000.00
0005433460470	1509	Economy	13000.00
0005434375332	1509	Economy	13000.00
0005433461623	1509	Economy	13000.00
0005433151651	1509	Economy	13000.00
0005434375330	1509	Economy	13000.00
0005433151706	1509	Economy	13000.00
0005433460469	1509	Economy	13000.00
0005434375328	1509	Economy	13000.00
0005434375344	1509	Economy	13000.00
0005434375356	1509	Economy	13000.00
0005434375339	1509	Economy	13000.00
0005434375347	1509	Economy	13000.00
0005434029676	1509	Economy	13000.00
0005433151696	1509	Economy	13000.00
0005433151654	1509	Economy	13000.00
0005433151655	1509	Economy	13000.00
0005434375355	1509	Economy	14300.00
0005432268000	1509	Economy	14300.00
0005434375341	1509	Economy	14300.00
0005434029667	1509	Economy	14300.00
0005433764691	1509	Economy	13000.00
0005433151837	1509	Economy	13000.00
0005434375346	1509	Economy	13000.00
0005433151684	1509	Economy	13000.00
0005433151632	1509	Economy	13000.00
0005434375343	1509	Economy	13000.00
0005434375353	1509	Economy	13000.00
0005433151715	1509	Economy	13000.00
0005433151677	1509	Economy	13000.00
0005433151620	1509	Economy	13000.00
0005433151535	1509	Economy	13000.00
0005434375335	1509	Economy	13000.00
0005434375354	1509	Economy	13000.00
0005433151670	1509	Economy	13000.00
0005433151667	1509	Economy	13000.00
0005433151784	1509	Economy	13000.00
0005432267999	1509	Economy	13000.00
0005434375349	1509	Economy	13000.00
0005432268004	1509	Economy	13000.00
0005433151673	1509	Economy	13000.00
0005434375326	1509	Economy	13000.00
0005433151634	1509	Economy	13000.00
0005432268002	1509	Economy	13000.00
0005433931484	1509	Economy	13000.00
0005432267997	1509	Economy	13000.00
0005434375334	1509	Economy	13000.00
0005433151716	1509	Economy	13000.00
0005433151705	1509	Economy	13000.00
0005432267998	1509	Economy	13000.00
0005433151717	1509	Economy	13000.00
0005433151714	1509	Economy	13000.00
0005434375336	1509	Economy	13000.00
0005434375351	1509	Economy	13000.00
0005434029675	1509	Economy	13000.00
0005433151697	1509	Economy	13000.00
0005433151828	1509	Economy	13000.00
0005433151652	1509	Economy	13000.00
0005434375340	1509	Economy	13000.00
0005432268003	1509	Economy	13000.00
0005433151665	1509	Economy	13000.00
0005433151631	1509	Economy	13000.00
0005433151666	1509	Economy	13000.00
0005434375342	1509	Economy	13000.00
0005434375333	1509	Economy	13000.00
0005433151725	1509	Economy	13000.00
0005433151553	1509	Economy	13000.00
0005433151695	1509	Economy	13000.00
0005434375352	1509	Economy	13000.00
0005433151685	1509	Economy	13000.00
0005434374898	20127	Business	38900.00
0005434375060	20127	Business	38900.00
0005434375017	20127	Business	38900.00
0005433151932	20127	Business	38900.00
0005434374930	20127	Business	38900.00
0005433764711	20127	Business	38900.00
0005434374942	20127	Business	38900.00
0005433151934	20127	Business	38900.00
0005433151922	20127	Business	38900.00
0005434374929	20127	Business	38900.00
0005434374875	20127	Business	38900.00
0005434375022	20127	Economy	13000.00
0005434375058	20127	Economy	13000.00
0005434374889	20127	Economy	13000.00
0005434374944	20127	Economy	13000.00
0005432056358	20127	Economy	13000.00
0005433151921	20127	Economy	13000.00
0005434374835	20127	Economy	13000.00
0005434375082	20127	Economy	13000.00
0005434029696	20127	Economy	13000.00
0005434375063	20127	Economy	13000.00
0005433151943	20127	Economy	13000.00
0005433151924	20127	Economy	13000.00
0005433151946	20127	Economy	13000.00
0005433151938	20127	Economy	13000.00
0005434375008	20127	Economy	13000.00
0005434374941	20127	Economy	13000.00
0005434374814	20127	Economy	13000.00
0005434374815	20127	Economy	13000.00
0005433151927	20127	Economy	13000.00
0005433151923	20127	Economy	13000.00
0005434374986	20127	Economy	13000.00
0005434374974	20127	Economy	13000.00
0005433931516	20127	Economy	13000.00
0005434374969	20127	Economy	13000.00
0005433151935	20127	Economy	13000.00
0005433151949	20127	Economy	13000.00
0005434374970	20127	Economy	13000.00
0005433151952	20127	Economy	13000.00
0005434375043	20127	Economy	14300.00
0005433764712	20127	Economy	13000.00
0005434374816	20127	Economy	14300.00
0005432056359	20127	Economy	14300.00
0005433151948	20127	Economy	14300.00
0005434374849	20127	Economy	13000.00
0005434375042	20127	Economy	13000.00
0005434374771	20127	Economy	13000.00
0005434374850	20127	Economy	13000.00
0005433151929	20127	Economy	13000.00
0005433151940	20127	Economy	13000.00
0005433151947	20127	Economy	13000.00
0005433151926	20127	Economy	13000.00
0005433151951	20127	Economy	13000.00
0005434374679	20127	Economy	13000.00
0005434374854	20127	Economy	13000.00
0005433151939	20127	Economy	13000.00
0005433151937	20127	Economy	13000.00
0005434375052	20127	Economy	13000.00
0005434374940	20127	Economy	13000.00
0005434374909	20127	Economy	13000.00
0005433151944	20127	Economy	13000.00
0005434374904	20127	Economy	13000.00
0005434374667	20127	Economy	13000.00
0005434374897	20127	Economy	13000.00
0005433151941	20127	Economy	13000.00
0005433151936	20127	Economy	13000.00
0005433151933	20127	Economy	13000.00
0005433151920	20127	Economy	13000.00
0005434374957	20127	Economy	13000.00
0005433151931	20127	Economy	13000.00
0005434374927	20127	Economy	13000.00
0005434029697	20127	Economy	13000.00
0005433151945	20127	Economy	13000.00
0005434029695	20127	Economy	13000.00
0005434374907	20127	Economy	13000.00
0005434374905	20127	Economy	13000.00
0005433151930	20127	Economy	13000.00
0005433151928	20127	Economy	13000.00
0005433931515	20127	Economy	13000.00
0005434375041	20127	Economy	13000.00
0005433931518	20127	Economy	13000.00
0005434375016	20127	Economy	13000.00
0005434374943	20127	Economy	13000.00
0005433151942	20127	Economy	13000.00
0005434375114	20127	Economy	13000.00
0005433151925	20127	Economy	13000.00
0005434374908	20127	Economy	13000.00
0005434374901	20127	Economy	13000.00
0005434374834	20127	Economy	13000.00
0005434375092	20127	Economy	13000.00
0005434374858	20127	Economy	13000.00
0005434374903	20127	Economy	13000.00
0005433151950	20127	Economy	13000.00
0005434374736	20127	Economy	13000.00
0005433931517	20127	Economy	13000.00
0005434374928	20127	Economy	13000.00
0005434375059	20127	Economy	13000.00
0005433151953	20127	Economy	13000.00
0005434029694	20127	Economy	13000.00
0005432425187	572	Business	27500.00
0005432425190	572	Business	27500.00
0005432282971	572	Business	27500.00
0005432425201	572	Business	27500.00
0005432425219	572	Business	27500.00
0005432425222	572	Business	27500.00
0005432425220	572	Business	27500.00
0005432425192	572	Business	27500.00
0005432425227	572	Business	27500.00
0005432425209	572	Business	27500.00
0005432425191	572	Economy	10100.00
0005432282970	572	Economy	10100.00
0005432425225	572	Economy	9200.00
0005432425223	572	Economy	9200.00
0005432425226	572	Economy	9200.00
0005432425229	572	Economy	9200.00
0005432425193	572	Economy	9200.00
0005432425204	572	Economy	9200.00
0005432425218	572	Economy	9200.00
0005432425215	572	Economy	9200.00
0005432425216	572	Economy	9200.00
0005432425213	572	Economy	9200.00
0005432425196	572	Economy	9200.00
0005432425205	572	Economy	9200.00
0005432425189	572	Economy	9200.00
0005432425203	572	Economy	9200.00
0005432282976	572	Economy	9200.00
0005432425210	572	Economy	9200.00
0005432425234	572	Economy	9200.00
0005432425194	572	Economy	9200.00
0005432425231	572	Economy	9200.00
0005432425206	572	Economy	9200.00
0005432282972	572	Economy	10100.00
0005432425233	572	Economy	9200.00
0005432425207	572	Economy	9200.00
0005432282975	572	Economy	9200.00
0005432425228	572	Economy	9200.00
0005432425235	572	Economy	9200.00
0005432425195	572	Economy	9200.00
0005432425188	572	Economy	9200.00
0005432425197	572	Economy	9200.00
0005432425198	572	Economy	9200.00
0005432425202	572	Economy	9200.00
0005432425230	572	Economy	9200.00
0005432425224	572	Economy	9200.00
0005432425199	572	Economy	9200.00
0005432282973	572	Economy	9200.00
0005432425214	572	Economy	9200.00
0005432282974	572	Economy	9200.00
0005432425211	572	Economy	9200.00
0005432425185	572	Economy	9200.00
0005432425212	572	Economy	9200.00
0005432425221	572	Economy	9200.00
0005432425186	572	Economy	9200.00
0005432425232	572	Economy	9200.00
0005432425200	572	Economy	9200.00
0005432425217	572	Economy	9200.00
0005432425208	572	Economy	9200.00
0005433158163	12910	Business	27500.00
0005432302388	12910	Economy	9200.00
0005434446534	12910	Economy	9200.00
0005432302390	12910	Economy	9200.00
0005434446535	12910	Economy	9200.00
0005432302389	12910	Economy	9200.00
0005432302387	12910	Economy	9200.00
0005433158167	12910	Economy	9200.00
0005433158164	12910	Economy	9200.00
0005434446536	12910	Economy	9200.00
0005434446523	12910	Economy	10100.00
0005434446524	12910	Economy	10100.00
0005433158166	12910	Economy	9200.00
0005433158165	12910	Economy	9200.00
0005432424738	12908	Business	27500.00
0005432424766	12908	Business	27500.00
0005432424612	12908	Business	27500.00
0005432424653	12908	Business	27500.00
0005432424586	12908	Business	27500.00
0005432424675	12908	Economy	10100.00
0005432424651	12908	Economy	10100.00
0005432424678	12908	Economy	9200.00
0005432424667	12908	Economy	9200.00
0005432424709	12908	Economy	9200.00
0005432424752	12908	Economy	9200.00
0005432424774	12908	Economy	9200.00
0005432424572	12908	Economy	9200.00
0005432424592	12908	Economy	9200.00
0005432424585	12908	Economy	9200.00
0005432424611	12908	Economy	9200.00
0005432424613	12908	Economy	9200.00
0005432424625	12908	Economy	9200.00
0005432424699	12908	Economy	9200.00
0005432424741	12908	Economy	9200.00
0005432424571	12908	Economy	9200.00
0005432424447	12908	Economy	9200.00
0005432424682	12908	Economy	10100.00
0005432424724	12908	Economy	10100.00
0005432424680	12908	Economy	9200.00
0005432424550	12908	Economy	10100.00
0005432424694	12908	Economy	9200.00
0005432424767	12908	Economy	9200.00
0005432424700	12908	Economy	9200.00
0005432424695	12908	Economy	9200.00
0005432424739	12908	Economy	9200.00
0005432424652	12908	Economy	9200.00
0005432424755	12908	Economy	9200.00
0005432424717	12908	Economy	9200.00
0005432424775	12908	Economy	9200.00
0005432424660	12908	Economy	9200.00
0005432424624	12908	Economy	9200.00
0005432424751	12908	Economy	9200.00
0005432424773	12908	Economy	9200.00
0005432424604	12908	Economy	9200.00
0005432424728	12908	Economy	9200.00
0005432424659	12908	Economy	9200.00
0005432424671	12908	Economy	9200.00
0005432424487	12908	Economy	9200.00
0005434024743	459	Business	24500.00
0005434024777	459	Business	24500.00
0005434024741	459	Business	24500.00
0005433058092	459	Business	24500.00
0005433058201	459	Business	24500.00
0005433058094	459	Business	24500.00
0005434024742	459	Business	24500.00
0005434024752	459	Business	24500.00
0005432045642	459	Business	24500.00
0005433058016	459	Business	24500.00
0005434032091	459	Business	24500.00
0005434024738	459	Business	24500.00
0005433058120	459	Business	24500.00
0005434735718	459	Business	24500.00
0005433058200	459	Business	24500.00
0005433058152	459	Business	24500.00
0005434735719	459	Business	24500.00
0005434024760	459	Economy	9000.00
0005434032090	459	Economy	9000.00
0005433058161	459	Economy	8200.00
0005432235752	459	Economy	8200.00
0005434029693	459	Economy	8200.00
0005433058006	459	Economy	8200.00
0005433058236	459	Economy	8200.00
0005434024781	459	Economy	8200.00
0005434024786	459	Economy	8200.00
0005434024755	459	Economy	8200.00
0005434024774	459	Economy	8200.00
0005434024761	459	Economy	8200.00
0005434024744	459	Economy	8200.00
0005434032089	459	Economy	8200.00
0005433058312	459	Economy	8200.00
0005432235757	459	Economy	8200.00
0005434024748	459	Economy	8200.00
0005434024767	459	Economy	8200.00
0005433058227	459	Economy	8200.00
0005433058298	459	Economy	8200.00
0005434024747	459	Economy	8200.00
0005433058173	459	Economy	8200.00
0005434024729	459	Economy	8200.00
0005433058162	459	Economy	8200.00
0005432235753	459	Economy	8200.00
0005434024745	459	Economy	8200.00
0005434024779	459	Economy	8200.00
0005433058007	459	Economy	8200.00
0005434024771	459	Economy	8200.00
0005433058217	459	Economy	8200.00
0005434024722	459	Economy	8200.00
0005433058093	459	Economy	8200.00
0005434028340	459	Economy	8200.00
0005434024766	459	Economy	8200.00
0005434024730	459	Economy	8200.00
0005433058119	459	Economy	8200.00
0005434024780	459	Economy	8200.00
0005434024751	459	Economy	8200.00
0005434024725	459	Economy	8200.00
0005433058224	459	Economy	8200.00
0005434024768	459	Economy	8200.00
0005434024733	459	Economy	8200.00
0005433058058	459	Economy	8200.00
0005434024772	459	Economy	8200.00
0005434024749	459	Economy	8200.00
0005434024740	459	Economy	8200.00
0005434024724	459	Economy	8200.00
0005432235755	459	Economy	8200.00
0005433058199	459	Economy	8200.00
0005434024758	459	Economy	8200.00
0005433058134	459	Economy	8200.00
0005433057974	459	Economy	8200.00
0005434024723	459	Economy	8200.00
0005433058148	459	Economy	8200.00
0005434028344	459	Economy	8200.00
0005432235756	459	Economy	8200.00
0005434024788	459	Economy	9000.00
0005433058391	459	Economy	9000.00
0005433058216	459	Economy	8200.00
0005434028342	459	Economy	8200.00
0005433058033	459	Economy	8200.00
0005433058414	459	Economy	8200.00
0005434024756	459	Economy	8200.00
0005434024784	459	Economy	8200.00
0005433058137	459	Economy	8200.00
0005434024765	459	Economy	8200.00
0005434024763	459	Economy	8200.00
0005433058097	459	Economy	8200.00
0005434024787	459	Economy	8200.00
0005434024757	459	Economy	8200.00
0005434024769	459	Economy	8200.00
0005434024746	459	Economy	8200.00
0005434024750	459	Economy	8200.00
0005433058037	459	Economy	8200.00
0005434024753	459	Economy	8200.00
0005434024783	459	Economy	8200.00
0005433058098	459	Economy	8200.00
0005434024778	459	Economy	8200.00
0005434024775	459	Economy	8200.00
0005434024728	459	Economy	8200.00
0005434024759	459	Economy	8200.00
0005433058160	459	Economy	8200.00
0005434024736	459	Economy	8200.00
0005433058349	459	Economy	8200.00
0005434024782	459	Economy	8200.00
0005434024739	459	Economy	8200.00
0005432235754	459	Economy	8200.00
0005434024770	459	Economy	8200.00
0005434024737	459	Economy	8200.00
0005434024734	459	Economy	8200.00
0005434032093	459	Economy	8200.00
0005433058303	459	Economy	8200.00
0005434024732	459	Economy	8200.00
0005434735722	459	Economy	8200.00
0005434028343	459	Economy	8200.00
0005434028341	459	Economy	8200.00
0005434024727	459	Economy	8200.00
0005434024762	459	Economy	8200.00
0005434024785	459	Economy	8200.00
0005434024789	459	Economy	8200.00
0005434024773	459	Economy	8200.00
0005434024735	459	Economy	8200.00
0005433058392	459	Economy	8200.00
0005433058172	459	Economy	8200.00
0005433058361	459	Economy	8200.00
0005432235751	459	Economy	8200.00
0005434024754	459	Economy	8200.00
0005434024726	459	Economy	8200.00
0005434024731	459	Economy	8200.00
0005434735703	459	Economy	8200.00
0005433058225	459	Economy	8200.00
0005433058215	459	Economy	8200.00
0005434024776	459	Economy	8200.00
0005434024764	459	Economy	8200.00
0005434032092	459	Economy	8200.00
0005433058505	12685	Business	24500.00
0005433058492	12685	Business	24500.00
0005434029667	12685	Business	24500.00
0005433058497	12685	Business	24500.00
0005433058504	12685	Business	24500.00
0005433058519	12685	Business	24500.00
0005434024173	12685	Business	24500.00
0005434024337	12685	Business	24500.00
0005433058484	12685	Business	24500.00
0005434023790	12685	Business	24500.00
0005434028313	12685	Business	24500.00
0005434032044	12685	Business	24500.00
0005433058507	12685	Business	24500.00
0005434024442	12685	Business	24500.00
0005434024192	12685	Business	24500.00
0005434024345	12685	Business	24500.00
0005434024353	12685	Business	24500.00
0005433058508	12685	Business	24500.00
0005434024032	12685	Business	24500.00
0005434024202	12685	Business	24500.00
0005433929675	12685	Economy	9000.00
0005433929676	12685	Economy	9000.00
0005434024009	12685	Economy	8200.00
0005433058495	12685	Economy	8200.00
0005434024191	12685	Economy	8200.00
0005434024232	12685	Economy	8200.00
0005434024459	12685	Economy	8200.00
0005434028312	12685	Economy	8200.00
0005433058501	12685	Economy	8200.00
0005433929678	12685	Economy	8200.00
0005432157523	12685	Economy	8200.00
0005434024430	12685	Economy	8200.00
0005433058512	12685	Economy	8200.00
0005433058485	12685	Economy	8200.00
0005434028309	12685	Economy	8200.00
0005434024234	12685	Economy	8200.00
0005434023950	12685	Economy	8200.00
0005434023835	12685	Economy	8200.00
0005434024342	12685	Economy	8200.00
0005434024054	12685	Economy	8200.00
0005433058523	12685	Economy	8200.00
0005434024352	12685	Economy	8200.00
0005434735773	12685	Economy	8200.00
0005434024142	12685	Economy	8200.00
0005433058502	12685	Economy	8200.00
0005434735770	12685	Economy	8200.00
0005433058486	12685	Economy	8200.00
0005433058520	12685	Economy	8200.00
0005434024244	12685	Economy	8200.00
0005433058506	12685	Economy	8200.00
0005432157522	12685	Economy	8200.00
0005434024058	12685	Economy	8200.00
0005433684452	12685	Economy	8200.00
0005433058509	12685	Economy	8200.00
0005434024569	12685	Economy	8200.00
0005434024344	12685	Economy	8200.00
0005433058521	12685	Economy	8200.00
0005434735771	12685	Economy	8200.00
0005434024346	12685	Economy	8200.00
0005434024220	12685	Economy	8200.00
0005433058503	12685	Economy	8200.00
0005434032055	12685	Economy	8200.00
0005434028317	12685	Economy	8200.00
0005433058496	12685	Economy	8200.00
0005432157521	12685	Economy	8200.00
0005433058493	12685	Economy	8200.00
0005434024431	12685	Economy	8200.00
0005432156433	12685	Economy	8200.00
0005434023961	12685	Economy	8200.00
0005434024172	12685	Economy	8200.00
0005434023830	12685	Economy	8200.00
0005434032050	12685	Economy	8200.00
0005434024290	12685	Economy	8200.00
0005432156436	12685	Economy	8200.00
0005433058514	12685	Economy	8200.00
0005434024152	12685	Economy	8200.00
0005434024452	12685	Economy	8200.00
0005433684453	12685	Economy	8200.00
0005434024460	12685	Economy	8200.00
0005433058500	12685	Economy	8200.00
0005434024405	12685	Economy	8200.00
0005434029675	12685	Economy	8200.00
0005434024196	12685	Economy	9000.00
0005433058499	12685	Economy	8200.00
0005434023960	12685	Economy	8200.00
0005432156432	12685	Economy	9000.00
0005434024318	12685	Economy	8200.00
0005434024154	12685	Economy	8200.00
0005434024425	12685	Economy	8200.00
0005434024224	12685	Economy	8200.00
0005434024288	12685	Economy	8200.00
0005434024404	12685	Economy	8200.00
0005433058511	12685	Economy	8200.00
0005434024287	12685	Economy	8200.00
0005433058510	12685	Economy	8200.00
0005434029676	12685	Economy	8200.00
0005433058489	12685	Economy	8200.00
0005434024242	12685	Economy	8200.00
0005433058515	12685	Economy	8200.00
0005433058517	12685	Economy	8200.00
0005433058513	12685	Economy	8200.00
0005434023977	12685	Economy	8200.00
0005434024336	12685	Economy	8200.00
0005434023873	12685	Economy	8200.00
0005434028320	12685	Economy	8200.00
0005434024203	12685	Economy	8200.00
0005433058491	12685	Economy	8200.00
0005433058516	12685	Economy	8200.00
0005434024118	12685	Economy	8200.00
0005433058498	12685	Economy	8200.00
0005434024057	12685	Economy	8200.00
0005434024243	12685	Economy	8200.00
0005434028310	12685	Economy	8200.00
0005434028319	12685	Economy	8200.00
0005433058490	12685	Economy	8200.00
0005433058487	12685	Economy	8200.00
0005434024221	12685	Economy	8200.00
0005434024289	12685	Economy	8200.00
0005433058522	12685	Economy	8200.00
0005433058494	12685	Economy	8200.00
0005434024269	12685	Economy	8200.00
0005432156434	12685	Economy	8200.00
0005434024197	12685	Economy	8200.00
0005434024233	12685	Economy	8200.00
0005432156435	12685	Economy	8200.00
0005433929677	12685	Economy	8200.00
0005434735772	12685	Economy	8200.00
0005434023789	12685	Economy	8200.00
0005434024641	12685	Economy	8200.00
0005434024112	12685	Economy	8200.00
0005434735769	12685	Economy	8200.00
0005433058488	12685	Economy	8200.00
0005433058518	12685	Economy	8200.00
0005434029670	12685	Economy	8200.00
0005434024568	12685	Economy	8200.00
0005433924745	2122	Business	34700.00
0005433036382	2122	Business	34700.00
0005433924784	2122	Business	34700.00
0005433924795	2122	Business	34700.00
0005433036727	2122	Business	34700.00
0005433924807	2122	Business	34700.00
0005433036778	2122	Business	34700.00
0005433036579	2122	Business	34700.00
0005433924734	2122	Business	34700.00
0005433036383	2122	Business	34700.00
0005433924758	2122	Business	34700.00
0005433924739	2122	Business	34700.00
0005433875400	2122	Business	34700.00
0005433924819	2122	Business	34700.00
0005433036782	2122	Business	34700.00
0005433924751	2122	Business	34700.00
0005433924731	2122	Business	34700.00
0005433924746	2122	Business	34700.00
0005433036405	2122	Business	34700.00
0005433924806	2122	Business	34700.00
0005432044569	2122	Business	34700.00
0005433924780	2122	Business	34700.00
0005433924733	2122	Business	34700.00
0005433924826	2122	Economy	12700.00
0005433924763	2122	Business	34700.00
0005433931516	2122	Economy	12700.00
0005433924764	2122	Economy	12700.00
0005433924803	2122	Economy	12700.00
0005433924792	2122	Economy	11600.00
0005433924787	2122	Economy	11600.00
0005432044567	2122	Economy	11600.00
0005433924808	2122	Economy	11600.00
0005433924749	2122	Economy	11600.00
0005433924754	2122	Economy	11600.00
0005433036736	2122	Economy	11600.00
0005433875401	2122	Economy	11600.00
0005433924744	2122	Economy	11600.00
0005433924740	2122	Economy	11600.00
0005433924793	2122	Economy	11600.00
0005433924742	2122	Economy	11600.00
0005433036571	2122	Economy	11600.00
0005433036406	2122	Economy	11600.00
0005433036728	2122	Economy	11600.00
0005433036699	2122	Economy	11600.00
0005432231725	2122	Economy	11600.00
0005433924796	2122	Economy	11600.00
0005433931517	2122	Economy	11600.00
0005433924759	2122	Economy	11600.00
0005433929676	2122	Economy	11600.00
0005433924770	2122	Economy	11600.00
0005434028312	2122	Economy	11600.00
0005433924767	2122	Economy	11600.00
0005433924738	2122	Economy	11600.00
0005433924813	2122	Economy	11600.00
0005433924736	2122	Economy	11600.00
0005433924786	2122	Economy	11600.00
0005433924825	2122	Economy	11600.00
0005433036640	2122	Economy	11600.00
0005433036527	2122	Economy	11600.00
0005433036580	2122	Economy	11600.00
0005433924794	2122	Economy	11600.00
0005433924804	2122	Economy	11600.00
0005433036735	2122	Economy	11600.00
0005433924824	2122	Economy	11600.00
0005433924741	2122	Economy	11600.00
0005434028320	2122	Economy	11600.00
0005432231726	2122	Economy	11600.00
0005433924757	2122	Economy	11600.00
0005433929675	2122	Economy	11600.00
0005433924811	2122	Economy	11600.00
0005433924815	2122	Economy	11600.00
0005433924802	2122	Economy	11600.00
0005432749798	2122	Economy	11600.00
0005433924760	2122	Economy	11600.00
0005432749795	2122	Economy	11600.00
0005433929860	2122	Economy	11600.00
0005433924814	2122	Economy	11600.00
0005433929677	2122	Economy	11600.00
0005433924732	2122	Economy	11600.00
0005433036642	2122	Economy	11600.00
0005433924816	2122	Economy	11600.00
0005434028310	2122	Economy	11600.00
0005434028319	2122	Economy	11600.00
0005433924748	2122	Economy	11600.00
0005433924817	2122	Economy	11600.00
0005433924818	2122	Economy	11600.00
0005433036698	2122	Economy	11600.00
0005434028309	2122	Economy	11600.00
0005432231728	2122	Economy	11600.00
0005433924750	2122	Economy	11600.00
0005433924781	2122	Economy	11600.00
0005432231733	2122	Economy	11600.00
0005433036867	2122	Economy	11600.00
0005433036247	2122	Economy	11600.00
0005432231734	2122	Economy	11600.00
0005433924797	2122	Economy	11600.00
0005433036612	2122	Economy	11600.00
0005434028317	2122	Economy	11600.00
0005433924762	2122	Economy	11600.00
0005433924785	2122	Economy	11600.00
0005433036630	2122	Economy	11600.00
0005433924753	2122	Economy	11600.00
0005433924769	2122	Economy	12700.00
0005433929859	2122	Economy	11600.00
0005433924820	2122	Economy	11600.00
0005433924756	2122	Economy	11600.00
0005433924809	2122	Economy	12700.00
0005433924775	2122	Economy	12700.00
0005434028313	2122	Economy	11600.00
0005433924766	2122	Economy	11600.00
0005433924822	2122	Economy	11600.00
0005433924791	2122	Economy	11600.00
0005433924799	2122	Economy	11600.00
0005433036570	2122	Economy	11600.00
0005433036649	2122	Economy	11600.00
0005433924774	2122	Economy	11600.00
0005433924789	2122	Economy	11600.00
0005432231730	2122	Economy	11600.00
0005433924778	2122	Economy	11600.00
0005433924812	2122	Economy	11600.00
0005432749794	2122	Economy	11600.00
0005433036397	2122	Economy	11600.00
0005433924800	2122	Economy	11600.00
0005433036740	2122	Economy	11600.00
0005433924798	2122	Economy	11600.00
0005433924729	2122	Economy	11600.00
0005433036559	2122	Economy	11600.00
0005433036624	2122	Economy	11600.00
0005432231731	2122	Economy	11600.00
0005433036396	2122	Economy	11600.00
0005433924805	2122	Economy	11600.00
0005433924735	2122	Economy	11600.00
0005433924765	2122	Economy	11600.00
0005433036643	2122	Economy	11600.00
0005433924782	2122	Economy	11600.00
0005433924755	2122	Economy	11600.00
0005433036796	2122	Economy	11600.00
0005433924771	2122	Economy	11600.00
0005433036715	2122	Economy	11600.00
0005433929678	2122	Economy	11600.00
0005433924783	2122	Economy	11600.00
0005433036744	2122	Economy	11600.00
0005433931518	2122	Economy	11600.00
0005433924779	2122	Economy	11600.00
0005433036811	2122	Economy	11600.00
0005433924747	2122	Economy	11600.00
0005433036745	2122	Economy	11600.00
0005432231732	2122	Economy	11600.00
0005433924823	2122	Economy	11600.00
0005433924768	2122	Economy	11600.00
0005433924801	2122	Economy	11600.00
0005433924743	2122	Economy	11600.00
0005432044568	2122	Economy	11600.00
0005433924737	2122	Economy	11600.00
0005432231727	2122	Economy	11600.00
0005433931515	2122	Economy	11600.00
0005432231729	2122	Economy	11600.00
0005432231724	2122	Economy	11600.00
0005433924810	2122	Economy	11600.00
0005433036586	2122	Economy	11600.00
0005433924788	2122	Economy	11600.00
0005433036440	2122	Economy	11600.00
0005433036714	2122	Economy	11600.00
0005433036600	2122	Economy	11600.00
0005433924821	2122	Economy	11600.00
0005433924772	2122	Economy	11600.00
0005433924752	2122	Economy	11600.00
0005433036572	2122	Economy	11600.00
0005432749797	2122	Economy	11600.00
0005433924777	2122	Economy	11600.00
0005433924761	2122	Economy	11600.00
0005433924776	2122	Economy	11600.00
0005433924773	2122	Economy	11600.00
0005433924730	2122	Economy	11600.00
0005433924790	2122	Economy	11600.00
0005433037091	24115	Business	34700.00
0005433923997	24115	Business	34700.00
0005434028346	24115	Business	34700.00
0005433037134	24115	Business	34700.00
0005433037102	24115	Business	34700.00
0005433923807	24115	Business	34700.00
0005433037124	24115	Business	34700.00
0005433924148	24115	Business	34700.00
0005433037136	24115	Business	34700.00
0005433924120	24115	Business	34700.00
0005433037097	24115	Business	34700.00
0005433924042	24115	Business	34700.00
0005432206284	24115	Business	34700.00
0005433923560	24115	Business	34700.00
0005433923979	24115	Business	34700.00
0005433923711	24115	Business	34700.00
0005432749818	24115	Business	34700.00
0005433037130	24115	Business	34700.00
0005433924032	24115	Business	34700.00
0005433924093	24115	Business	34700.00
0005432206286	24115	Business	34700.00
0005433875388	24115	Business	34700.00
0005433923838	24115	Business	34700.00
0005433924204	24115	Business	34700.00
0005433037116	24115	Economy	12700.00
0005433923855	24115	Economy	12700.00
0005433037112	24115	Economy	12700.00
0005433923705	24115	Economy	12700.00
0005433037107	24115	Economy	11600.00
0005433037084	24115	Economy	11600.00
0005433037108	24115	Economy	11600.00
0005433037135	24115	Economy	11600.00
0005432206287	24115	Economy	11600.00
0005433923950	24115	Economy	11600.00
0005433931477	24115	Economy	11600.00
0005433924284	24115	Economy	11600.00
0005433037094	24115	Economy	11600.00
0005433923829	24115	Economy	11600.00
0005433931469	24115	Economy	11600.00
0005433929624	24115	Economy	11600.00
0005433931491	24115	Economy	11600.00
0005433924038	24115	Economy	11600.00
0005433923564	24115	Economy	11600.00
0005433923704	24115	Economy	11600.00
0005432206288	24115	Economy	11600.00
0005433923980	24115	Economy	11600.00
0005433037095	24115	Economy	11600.00
0005433924009	24115	Economy	11600.00
0005432206285	24115	Economy	11600.00
0005433924291	24115	Economy	11600.00
0005433037098	24115	Economy	11600.00
0005433037126	24115	Economy	11600.00
0005433037114	24115	Economy	11600.00
0005433037085	24115	Economy	11600.00
0005433037121	24115	Economy	11600.00
0005433924054	24115	Economy	11600.00
0005433037088	24115	Economy	11600.00
0005433923854	24115	Economy	11600.00
0005433923864	24115	Economy	11600.00
0005433924184	24115	Economy	11600.00
0005433924358	24115	Economy	11600.00
0005433924104	24115	Economy	11600.00
0005433037101	24115	Economy	11600.00
0005433923886	24115	Economy	11600.00
0005433037127	24115	Economy	11600.00
0005433931468	24115	Economy	11600.00
0005433923391	24115	Economy	11600.00
0005433037128	24115	Economy	11600.00
0005433923522	24115	Economy	11600.00
0005433923867	24115	Economy	11600.00
0005433037109	24115	Economy	11600.00
0005433037104	24115	Economy	11600.00
0005433923392	24115	Economy	11600.00
0005433037129	24115	Economy	11600.00
0005433037096	24115	Economy	11600.00
0005433037113	24115	Economy	11600.00
0005433923772	24115	Economy	11600.00
0005433924300	24115	Economy	11600.00
0005433037118	24115	Economy	11600.00
0005433929634	24115	Economy	11600.00
0005433923839	24115	Economy	11600.00
0005433923841	24115	Economy	11600.00
0005433924053	24115	Economy	11600.00
0005433037137	24115	Economy	11600.00
0005433923355	24115	Economy	11600.00
0005433923686	24115	Economy	11600.00
0005433037105	24115	Economy	11600.00
0005434028345	24115	Economy	11600.00
0005433923827	24115	Economy	11600.00
0005433923949	24115	Economy	11600.00
0005433923669	24115	Economy	11600.00
0005433923731	24115	Economy	11600.00
0005433037133	24115	Economy	11600.00
0005433923978	24115	Economy	11600.00
0005433923653	24115	Economy	11600.00
0005433929625	24115	Economy	11600.00
0005433923695	24115	Economy	11600.00
0005433923832	24115	Economy	11600.00
0005433923929	24115	Economy	11600.00
0005433924221	24115	Economy	11600.00
0005434028347	24115	Economy	11600.00
0005433924043	24115	Economy	11600.00
0005433923863	24115	Economy	11600.00
0005433923967	24115	Economy	11600.00
0005433924185	24115	Economy	11600.00
0005433924052	24115	Economy	11600.00
0005433037115	24115	Economy	11600.00
0005433923757	24115	Economy	11600.00
0005433923942	24115	Economy	11600.00
0005433037110	24115	Economy	11600.00
0005433924169	24115	Economy	11600.00
0005433924036	24115	Economy	11600.00
0005433923826	24115	Economy	11600.00
0005432207701	24115	Economy	12700.00
0005433037092	24115	Economy	12700.00
0005433923789	24115	Economy	11600.00
0005433923758	24115	Economy	11600.00
0005433037099	24115	Economy	11600.00
0005433924035	24115	Economy	11600.00
0005433923796	24115	Economy	11600.00
0005433923687	24115	Economy	11600.00
0005433931476	24115	Economy	11600.00
0005433037123	24115	Economy	11600.00
0005433924222	24115	Economy	11600.00
0005433931490	24115	Economy	11600.00
0005433037120	24115	Economy	11600.00
0005433923475	24115	Economy	11600.00
0005433923410	24115	Economy	11600.00
0005433923642	24115	Economy	11600.00
0005433923996	24115	Economy	11600.00
0005433037117	24115	Economy	11600.00
0005433923706	24115	Economy	11600.00
0005433924188	24115	Economy	11600.00
0005433037090	24115	Economy	11600.00
0005433923737	24115	Economy	11600.00
0005433923771	24115	Economy	11600.00
0005433924179	24115	Economy	11600.00
0005433037119	24115	Economy	11600.00
0005433923723	24115	Economy	11600.00
0005433037093	24115	Economy	11600.00
0005433037089	24115	Economy	11600.00
0005433923429	24115	Economy	11600.00
0005433923981	24115	Economy	11600.00
0005433923840	24115	Economy	11600.00
0005433923909	24115	Economy	11600.00
0005433037131	24115	Economy	11600.00
0005433923781	24115	Economy	11600.00
0005433037122	24115	Economy	11600.00
0005433037125	24115	Economy	11600.00
0005433923676	24115	Economy	11600.00
0005433037087	24115	Economy	11600.00
0005433924210	24115	Economy	11600.00
0005432749819	24115	Economy	11600.00
0005433037103	24115	Economy	11600.00
0005432207702	24115	Economy	11600.00
0005433923694	24115	Economy	11600.00
0005433037111	24115	Economy	11600.00
0005433923561	24115	Economy	11600.00
0005433923724	24115	Economy	11600.00
0005433923390	24115	Economy	11600.00
0005433923833	24115	Economy	11600.00
0005433923808	24115	Economy	11600.00
0005433923917	24115	Economy	11600.00
0005433037100	24115	Economy	11600.00
0005433923885	24115	Economy	11600.00
0005433037086	24115	Economy	11600.00
0005433923865	24115	Economy	11600.00
0005433037106	24115	Economy	11600.00
0005433924007	24115	Economy	11600.00
0005433037132	24115	Economy	11600.00
0005433924211	24115	Economy	11600.00
0005433924319	24115	Economy	11600.00
0005433929648	24115	Economy	11600.00
0005433923861	24115	Economy	11600.00
0005433924023	24115	Economy	11600.00
0005433923654	24115	Economy	11600.00
0005434727283	260	Business	83700.00
0005434552074	260	Business	83700.00
0005433289886	260	Business	83700.00
0005434727324	260	Business	83700.00
0005433235024	260	Business	83700.00
0005434727317	260	Business	83700.00
0005433181333	260	Business	83700.00
0005433234773	260	Business	83700.00
0005434727345	260	Business	83700.00
0005434727336	260	Business	83700.00
0005433234465	260	Business	83700.00
0005434727288	260	Business	83700.00
0005434552084	260	Business	83700.00
0005434552059	260	Business	83700.00
0005434552068	260	Business	83700.00
0005434727393	260	Business	83700.00
0005434727330	260	Business	83700.00
0005433181134	260	Business	83700.00
0005433234579	260	Business	83700.00
0005434552082	260	Business	83700.00
0005435142784	260	Business	83700.00
0005433289887	260	Business	83700.00
0005433234856	260	Business	83700.00
0005434727292	260	Business	83700.00
0005434552091	260	Business	83700.00
0005432278016	260	Business	83700.00
0005434552092	260	Business	83700.00
0005434552087	260	Business	83700.00
0005434727320	260	Comfort	47400.00
0005434727318	260	Comfort	47400.00
0005433234632	260	Comfort	47400.00
0005434727310	260	Comfort	47400.00
0005433111515	260	Comfort	47400.00
0005434727285	260	Comfort	47400.00
0005434727284	260	Comfort	47400.00
0005432278017	260	Comfort	47400.00
0005433181363	260	Comfort	47400.00
0005434727334	260	Comfort	47400.00
0005434727311	260	Comfort	47400.00
0005434552057	260	Comfort	47400.00
0005434727376	260	Comfort	47400.00
0005433234500	260	Comfort	47400.00
0005433289908	260	Comfort	47400.00
0005435142780	260	Comfort	47400.00
0005434727342	260	Comfort	47400.00
0005433766677	260	Comfort	47400.00
0005434552100	260	Comfort	47400.00
0005433234614	260	Comfort	47400.00
0005434727309	260	Comfort	47400.00
0005434552093	260	Comfort	47400.00
0005433234570	260	Comfort	47400.00
0005434552101	260	Comfort	47400.00
0005433131737	260	Comfort	47400.00
0005434552099	260	Comfort	47400.00
0005434727364	260	Comfort	47400.00
0005433113553	260	Comfort	47400.00
0005434727390	260	Comfort	47400.00
0005435142785	260	Comfort	47400.00
0005434727306	260	Comfort	47400.00
0005434727300	260	Comfort	47400.00
0005435142790	260	Comfort	47400.00
0005434727293	260	Comfort	47400.00
0005434727328	260	Comfort	47400.00
0005433234785	260	Comfort	47400.00
0005433181209	260	Comfort	47400.00
0005434727346	260	Comfort	47400.00
0005433131747	260	Comfort	47400.00
0005434727316	260	Comfort	47400.00
0005434552073	260	Comfort	47400.00
0005434552049	260	Comfort	47400.00
0005433113545	260	Comfort	47400.00
0005434727392	260	Comfort	47400.00
0005434727279	260	Economy	27900.00
0005434727315	260	Comfort	47400.00
0005433234636	260	Economy	27900.00
0005434552053	260	Economy	27900.00
0005434727355	260	Economy	27900.00
0005433181262	260	Economy	27900.00
0005434727363	260	Economy	27900.00
0005434727331	260	Economy	27900.00
0005433181308	260	Economy	27900.00
0005433181275	260	Economy	27900.00
0005433766676	260	Economy	27900.00
0005433234819	260	Economy	27900.00
0005432278011	260	Economy	27900.00
0005434552089	260	Economy	27900.00
0005433111510	260	Economy	27900.00
0005434727398	260	Economy	27900.00
0005433113547	260	Economy	27900.00
0005434552104	260	Economy	27900.00
0005434727343	260	Economy	27900.00
0005434727385	260	Economy	27900.00
0005433234622	260	Economy	27900.00
0005434552077	260	Economy	27900.00
0005433234473	260	Economy	27900.00
0005433234634	260	Economy	27900.00
0005434727281	260	Economy	27900.00
0005434552072	260	Economy	27900.00
0005434727326	260	Economy	27900.00
0005433234264	260	Economy	27900.00
0005434552083	260	Economy	27900.00
0005435142787	260	Economy	27900.00
0005433113542	260	Economy	27900.00
0005434032056	260	Economy	27900.00
0005433766667	260	Economy	27900.00
0005434727369	260	Economy	27900.00
0005434552069	260	Economy	27900.00
0005434727380	260	Economy	27900.00
0005433181334	260	Economy	27900.00
0005433234613	260	Economy	27900.00
0005433234772	260	Economy	27900.00
0005433234577	260	Economy	27900.00
0005434727297	260	Economy	27900.00
0005434552071	260	Economy	27900.00
0005434727339	260	Economy	27900.00
0005434727375	260	Economy	27900.00
0005432278022	260	Economy	27900.00
0005434727349	260	Economy	27900.00
0005433234645	260	Economy	27900.00
0005434727304	260	Economy	27900.00
0005433131752	260	Economy	27900.00
0005433234764	260	Economy	27900.00
0005434727295	260	Economy	27900.00
0005434552067	260	Economy	27900.00
0005434727361	260	Economy	27900.00
0005434727335	260	Economy	27900.00
0005434727373	260	Economy	27900.00
0005434735768	260	Economy	27900.00
0005433181221	260	Economy	27900.00
0005433234858	260	Economy	27900.00
0005434552063	260	Economy	27900.00
0005433234574	260	Economy	27900.00
0005433289897	260	Economy	27900.00
0005434727278	260	Economy	27900.00
0005434727333	260	Economy	27900.00
0005433181227	260	Economy	27900.00
0005435142783	260	Economy	27900.00
0005434552085	260	Economy	27900.00
0005433234486	260	Economy	27900.00
0005434727357	260	Economy	27900.00
0005434727329	260	Economy	30700.00
0005433234402	260	Economy	30700.00
0005434552061	260	Economy	27900.00
0005433181157	260	Economy	27900.00
0005434552078	260	Economy	27900.00
0005434552086	260	Economy	30700.00
0005434727399	260	Economy	30700.00
0005434727322	260	Economy	30700.00
0005434727287	260	Economy	27900.00
0005433766670	260	Economy	27900.00
0005432278014	260	Economy	27900.00
0005434727340	260	Economy	27900.00
0005435142786	260	Economy	27900.00
0005433234908	260	Economy	27900.00
0005433234434	260	Economy	27900.00
0005434727296	260	Economy	27900.00
0005433234372	260	Economy	27900.00
0005434552098	260	Economy	27900.00
0005434552064	260	Economy	27900.00
0005433289865	260	Economy	27900.00
0005434552055	260	Economy	27900.00
0005433234378	260	Economy	27900.00
0005434731233	260	Economy	27900.00
0005434727308	260	Economy	27900.00
0005433131733	260	Economy	27900.00
0005435142789	260	Economy	27900.00
0005434727280	260	Economy	27900.00
0005434552103	260	Economy	27900.00
0005434727395	260	Economy	27900.00
0005434727351	260	Economy	27900.00
0005433181276	260	Economy	27900.00
0005433234474	260	Economy	27900.00
0005434727368	260	Economy	27900.00
0005433234753	260	Economy	27900.00
0005433235025	260	Economy	27900.00
0005433181306	260	Economy	27900.00
0005434552102	260	Economy	27900.00
0005434731231	260	Economy	27900.00
0005433181257	260	Economy	27900.00
0005433126887	260	Economy	27900.00
0005433234445	260	Economy	27900.00
0005434727350	260	Economy	27900.00
0005433234435	260	Economy	27900.00
0005433234484	260	Economy	27900.00
0005435142788	260	Economy	27900.00
0005434552095	260	Economy	27900.00
0005433181364	260	Economy	27900.00
0005434552075	260	Economy	27900.00
0005434302526	260	Economy	27900.00
0005434727374	260	Economy	27900.00
0005434552090	260	Economy	27900.00
0005432278013	260	Economy	27900.00
0005433234674	260	Economy	27900.00
0005433113552	260	Economy	27900.00
0005434735764	260	Economy	27900.00
0005434727294	260	Economy	27900.00
0005432278009	260	Economy	27900.00
0005434727353	260	Economy	27900.00
0005433111516	260	Economy	27900.00
0005433234565	260	Economy	27900.00
0005434727400	260	Economy	27900.00
0005434552076	260	Economy	27900.00
0005434727290	260	Economy	27900.00
0005434552066	260	Economy	27900.00
0005434727302	260	Economy	27900.00
0005433181156	260	Economy	27900.00
0005433126883	260	Economy	27900.00
0005434727356	260	Economy	27900.00
0005434727372	260	Economy	27900.00
0005434552050	260	Economy	27900.00
0005434727360	260	Economy	27900.00
0005433181174	260	Economy	27900.00
0005433234710	260	Economy	27900.00
0005434727388	260	Economy	27900.00
0005433131738	260	Economy	27900.00
0005433234342	260	Economy	27900.00
0005433234343	260	Economy	27900.00
0005433234479	260	Economy	27900.00
0005432278021	260	Economy	27900.00
0005433234412	260	Economy	27900.00
0005434302527	260	Economy	27900.00
0005434552070	260	Economy	27900.00
0005434727377	260	Economy	27900.00
0005434727307	260	Economy	27900.00
0005434727323	260	Economy	27900.00
0005434727401	260	Economy	27900.00
0005433234752	260	Economy	27900.00
0005433234548	260	Economy	27900.00
0005433234377	260	Economy	27900.00
0005434727381	260	Economy	27900.00
0005433181285	260	Economy	27900.00
0005434727301	260	Economy	27900.00
0005433766655	260	Economy	27900.00
0005433234638	260	Economy	27900.00
0005435142781	260	Economy	27900.00
0005434552051	260	Economy	27900.00
0005434727303	260	Economy	27900.00
0005434552062	260	Economy	27900.00
0005433131748	260	Economy	27900.00
0005434727289	260	Economy	27900.00
0005435142782	260	Economy	27900.00
0005433234714	260	Economy	27900.00
0005433234507	260	Economy	27900.00
0005433766672	260	Economy	27900.00
0005434727367	260	Economy	27900.00
0005435142792	260	Economy	27900.00
0005433234715	260	Economy	27900.00
0005433766666	260	Economy	27900.00
0005433234857	260	Economy	27900.00
0005433126884	260	Economy	27900.00
0005434727362	260	Economy	27900.00
0005433181222	260	Economy	27900.00
0005434727382	260	Economy	27900.00
0005434032046	260	Economy	27900.00
0005433181347	260	Economy	27900.00
0005433181274	260	Economy	27900.00
0005433766658	260	Economy	27900.00
0005434552094	260	Economy	27900.00
0005434735763	260	Economy	27900.00
0005434727396	260	Economy	27900.00
0005434552054	260	Economy	27900.00
0005433234501	260	Economy	30700.00
0005434727347	260	Economy	27900.00
0005434727319	260	Economy	30700.00
0005433234464	260	Economy	30700.00
0005434727299	260	Economy	30700.00
0005432278015	260	Economy	30700.00
0005434727397	260	Economy	30700.00
0005434727371	260	Economy	27900.00
0005434727291	260	Economy	27900.00
0005434727277	260	Economy	27900.00
0005434727282	260	Economy	27900.00
0005434032052	260	Economy	27900.00
0005434727366	260	Economy	27900.00
0005433181210	260	Economy	27900.00
0005434727341	260	Economy	27900.00
0005434727305	260	Economy	27900.00
0005434032045	260	Economy	27900.00
0005434552079	260	Economy	27900.00
0005433234263	260	Economy	27900.00
0005434552080	260	Economy	27900.00
0005434727358	260	Economy	27900.00
0005434727354	260	Economy	27900.00
0005433181298	260	Economy	27900.00
0005434727389	260	Economy	27900.00
0005434727338	260	Economy	27900.00
0005433234506	260	Economy	27900.00
0005433234653	260	Economy	27900.00
0005433131739	260	Economy	27900.00
0005434727314	260	Economy	27900.00
0005433234547	260	Economy	27900.00
0005433234578	260	Economy	27900.00
0005432278010	260	Economy	27900.00
0005435142791	260	Economy	27900.00
0005434735766	260	Economy	27900.00
0005433289870	260	Economy	27900.00
0005433181284	260	Economy	27900.00
0005434727332	260	Economy	27900.00
0005432278018	260	Economy	27900.00
0005433234815	260	Economy	27900.00
0005433766657	260	Economy	27900.00
0005434032058	260	Economy	27900.00
0005434552056	260	Economy	27900.00
0005433234478	260	Economy	27900.00
0005434302878	260	Economy	27900.00
0005432278012	260	Economy	27900.00
0005434727394	260	Economy	27900.00
0005434302525	260	Economy	27900.00
0005433234671	260	Economy	27900.00
0005432278020	260	Economy	27900.00
0005433126882	260	Economy	27900.00
0005433181135	260	Economy	27900.00
0005434727391	260	Economy	27900.00
0005433234475	260	Economy	27900.00
0005432278019	260	Economy	27900.00
0005433234853	260	Economy	27900.00
0005434727384	260	Economy	27900.00
0005433234561	260	Economy	27900.00
0005433234709	260	Economy	27900.00
0005434302528	260	Economy	27900.00
0005433234637	260	Economy	27900.00
0005434727312	260	Economy	27900.00
0005433766654	260	Economy	27900.00
0005434727378	260	Economy	27900.00
0005434727298	260	Economy	27900.00
0005434727313	260	Economy	27900.00
0005433181348	260	Economy	27900.00
0005433234485	260	Economy	27900.00
0005433234516	260	Economy	27900.00
0005434302877	260	Economy	27900.00
0005434727337	260	Economy	27900.00
0005433234670	260	Economy	27900.00
0005433234747	260	Economy	27900.00
0005434727387	260	Economy	27900.00
0005434727286	260	Economy	27900.00
0005434727348	260	Economy	27900.00
0005434727327	260	Economy	27900.00
0005434727370	260	Economy	27900.00
0005434727383	260	Economy	27900.00
0005433234457	260	Economy	27900.00
0005434727352	260	Economy	27900.00
0005434552081	260	Economy	27900.00
0005433234818	260	Economy	27900.00
0005434731234	260	Economy	27900.00
0005433234499	260	Economy	27900.00
0005433234765	260	Economy	27900.00
0005434552097	260	Economy	27900.00
0005433234504	260	Economy	27900.00
0005434735767	260	Economy	27900.00
0005434727365	260	Economy	27900.00
0005434552052	260	Economy	27900.00
0005434727344	260	Economy	27900.00
0005434552060	260	Economy	27900.00
0005434552065	260	Economy	27900.00
0005433181261	260	Economy	27900.00
0005435142779	260	Economy	27900.00
0005434727386	260	Economy	27900.00
0005434727379	260	Economy	27900.00
0005433234401	260	Economy	27900.00
0005434727359	260	Economy	27900.00
0005434727325	260	Economy	27900.00
0005434552096	260	Economy	27900.00
0005433766671	260	Economy	27900.00
0005433234633	260	Economy	27900.00
0005434552058	260	Economy	27900.00
0005434735765	260	Economy	27900.00
0005434727321	260	Economy	27900.00
0005434552088	260	Economy	27900.00
0005433289888	260	Economy	27900.00
0005434731232	260	Economy	27900.00
0005434726252	9871	Business	83700.00
0005434735704	9871	Business	83700.00
0005434725742	9871	Business	83700.00
0005434731192	9871	Business	83700.00
0005433181499	9871	Business	83700.00
0005434735723	9871	Business	83700.00
0005435142699	9871	Business	83700.00
0005434551352	9871	Business	83700.00
0005435142692	9871	Business	83700.00
0005434726391	9871	Business	83700.00
0005434726343	9871	Business	83700.00
0005433126915	9871	Business	83700.00
0005433113571	9871	Business	83700.00
0005433235163	9871	Business	83700.00
0005434726064	9871	Business	83700.00
0005433235195	9871	Business	83700.00
0005433235181	9871	Business	83700.00
0005433235192	9871	Business	83700.00
0005433235155	9871	Business	83700.00
0005434551315	9871	Business	83700.00
0005433289956	9871	Business	83700.00
0005434726953	9871	Business	83700.00
0005434726954	9871	Business	83700.00
0005434726044	9871	Business	83700.00
0005433766699	9871	Business	83700.00
0005433235173	9871	Comfort	47400.00
0005434735736	9871	Business	83700.00
0005432199352	9871	Comfort	47400.00
0005434726161	9871	Comfort	47400.00
0005434551418	9871	Comfort	47400.00
0005435142687	9871	Comfort	47400.00
0005433113570	9871	Comfort	47400.00
0005434725944	9871	Comfort	47400.00
0005434726415	9871	Comfort	47400.00
0005434726508	9871	Comfort	47400.00
0005433129345	9871	Comfort	47400.00
0005433235161	9871	Comfort	47400.00
0005434551704	9871	Comfort	47400.00
0005434551703	9871	Comfort	47400.00
0005434726088	9871	Comfort	47400.00
0005434726664	9871	Comfort	47400.00
0005434726674	9871	Comfort	47400.00
0005434726348	9871	Comfort	47400.00
0005434726366	9871	Comfort	47400.00
0005433235185	9871	Comfort	47400.00
0005434551208	9871	Comfort	47400.00
0005433235200	9871	Comfort	47400.00
0005434726345	9871	Comfort	47400.00
0005433181480	9871	Comfort	47400.00
0005434726600	9871	Comfort	47400.00
0005434726382	9871	Comfort	47400.00
0005435142664	9871	Comfort	47400.00
0005434551653	9871	Comfort	47400.00
0005433181495	9871	Comfort	47400.00
0005434551462	9871	Comfort	47400.00
0005434726714	9871	Comfort	47400.00
0005434726383	9871	Comfort	47400.00
0005433766700	9871	Comfort	47400.00
0005434725943	9871	Comfort	47400.00
0005434726708	9871	Comfort	47400.00
0005433235152	9871	Comfort	47400.00
0005433129347	9871	Comfort	47400.00
0005433289960	9871	Comfort	47400.00
0005433235156	9871	Comfort	47400.00
0005433235198	9871	Comfort	47400.00
0005432199358	9871	Economy	27900.00
0005434726592	9871	Economy	27900.00
0005433235144	9871	Economy	27900.00
0005434726507	9871	Economy	27900.00
0005434726615	9871	Economy	27900.00
0005433181494	9871	Economy	27900.00
0005433235151	9871	Economy	27900.00
0005434551113	9871	Economy	27900.00
0005434725878	9871	Economy	27900.00
0005434726054	9871	Economy	27900.00
0005433235193	9871	Economy	27900.00
0005434551705	9871	Economy	27900.00
0005433235169	9871	Economy	27900.00
0005434726351	9871	Economy	27900.00
0005434726597	9871	Economy	27900.00
0005434726409	9871	Economy	27900.00
0005434726742	9871	Economy	27900.00
0005433181482	9871	Economy	27900.00
0005433181491	9871	Economy	27900.00
0005433235203	9871	Economy	27900.00
0005434726318	9871	Economy	27900.00
0005433235143	9871	Economy	27900.00
0005433235202	9871	Economy	27900.00
0005434551486	9871	Economy	27900.00
0005434726062	9871	Economy	27900.00
0005433235178	9871	Economy	27900.00
0005433235196	9871	Economy	27900.00
0005434551557	9871	Economy	27900.00
0005434726139	9871	Economy	27900.00
0005434726358	9871	Economy	27900.00
0005434725905	9871	Economy	27900.00
0005434551360	9871	Economy	27900.00
0005434551615	9871	Economy	27900.00
0005433181493	9871	Economy	27900.00
0005434726257	9871	Economy	27900.00
0005433235172	9871	Economy	27900.00
0005433235150	9871	Economy	27900.00
0005434725796	9871	Economy	27900.00
0005434726312	9871	Economy	27900.00
0005433235194	9871	Economy	27900.00
0005434725969	9871	Economy	27900.00
0005434726123	9871	Economy	27900.00
0005434551420	9871	Economy	27900.00
0005434726381	9871	Economy	27900.00
0005433181498	9871	Economy	27900.00
0005434726659	9871	Economy	27900.00
0005433235204	9871	Economy	27900.00
0005434551521	9871	Economy	27900.00
0005433181490	9871	Economy	27900.00
0005432199354	9871	Economy	27900.00
0005434302489	9871	Economy	27900.00
0005434302475	9871	Economy	27900.00
0005434726301	9871	Economy	27900.00
0005433235160	9871	Economy	27900.00
0005433235187	9871	Economy	27900.00
0005434551614	9871	Economy	27900.00
0005433235142	9871	Economy	27900.00
0005434551561	9871	Economy	27900.00
0005433235166	9871	Economy	27900.00
0005434551506	9871	Economy	27900.00
0005434726203	9871	Economy	27900.00
0005433766697	9871	Economy	30700.00
0005434551607	9871	Economy	30700.00
0005434551449	9871	Economy	27900.00
0005435142600	9871	Economy	27900.00
0005434731193	9871	Economy	27900.00
0005433181496	9871	Economy	30700.00
0005434735737	9871	Economy	30700.00
0005433235197	9871	Economy	30700.00
0005434725947	9871	Economy	27900.00
0005433235174	9871	Economy	27900.00
0005434551650	9871	Economy	27900.00
0005434726084	9871	Economy	27900.00
0005433235201	9871	Economy	27900.00
0005434032097	9871	Economy	27900.00
0005434726221	9871	Economy	27900.00
0005434726108	9871	Economy	27900.00
0005434032098	9871	Economy	27900.00
0005434726295	9871	Economy	27900.00
0005434735724	9871	Economy	27900.00
0005434735714	9871	Economy	27900.00
0005434551762	9871	Economy	27900.00
0005433181486	9871	Economy	27900.00
0005434551562	9871	Economy	27900.00
0005434302483	9871	Economy	27900.00
0005434725879	9871	Economy	27900.00
0005434726324	9871	Economy	27900.00
0005434726709	9871	Economy	27900.00
0005434726408	9871	Economy	27900.00
0005434726314	9871	Economy	27900.00
0005434551571	9871	Economy	27900.00
0005434551657	9871	Economy	27900.00
0005433235180	9871	Economy	27900.00
0005433181492	9871	Economy	27900.00
0005434551592	9871	Economy	27900.00
0005434551775	9871	Economy	27900.00
0005434551688	9871	Economy	27900.00
0005434551455	9871	Economy	27900.00
0005434726142	9871	Economy	27900.00
0005433181479	9871	Economy	27900.00
0005434726106	9871	Economy	27900.00
0005433235191	9871	Economy	27900.00
0005433181483	9871	Economy	27900.00
0005434726844	9871	Economy	27900.00
0005434726482	9871	Economy	27900.00
0005434735706	9871	Economy	27900.00
0005433235186	9871	Economy	27900.00
0005434726018	9871	Economy	27900.00
0005434726517	9871	Economy	27900.00
0005435142682	9871	Economy	27900.00
0005434726319	9871	Economy	27900.00
0005434726352	9871	Economy	27900.00
0005433235171	9871	Economy	27900.00
0005433235188	9871	Economy	27900.00
0005434726313	9871	Economy	27900.00
0005435142646	9871	Economy	27900.00
0005433235177	9871	Economy	27900.00
0005434551417	9871	Economy	27900.00
0005434551519	9871	Economy	27900.00
0005433235184	9871	Economy	27900.00
0005434726340	9871	Economy	27900.00
0005433766701	9871	Economy	27900.00
0005434551586	9871	Economy	27900.00
0005434302481	9871	Economy	27900.00
0005434726009	9871	Economy	27900.00
0005434726614	9871	Economy	27900.00
0005434726258	9871	Economy	27900.00
0005434726266	9871	Economy	27900.00
0005433235149	9871	Economy	27900.00
0005433235168	9871	Economy	27900.00
0005433235145	9871	Economy	27900.00
0005434551353	9871	Economy	27900.00
0005432199357	9871	Economy	27900.00
0005433181485	9871	Economy	27900.00
0005433235146	9871	Economy	27900.00
0005434725551	9871	Economy	27900.00
0005434726214	9871	Economy	27900.00
0005434726451	9871	Economy	27900.00
0005434726480	9871	Economy	27900.00
0005434032095	9871	Economy	27900.00
0005434726329	9871	Economy	27900.00
0005434032094	9871	Economy	27900.00
0005433235148	9871	Economy	27900.00
0005432199356	9871	Economy	27900.00
0005433235164	9871	Economy	27900.00
0005433289961	9871	Economy	27900.00
0005433181484	9871	Economy	27900.00
0005433235165	9871	Economy	27900.00
0005434726056	9871	Economy	27900.00
0005434302468	9871	Economy	27900.00
0005434551337	9871	Economy	27900.00
0005434726315	9871	Economy	27900.00
0005434731197	9871	Economy	27900.00
0005433235158	9871	Economy	27900.00
0005434725915	9871	Economy	27900.00
0005434726143	9871	Economy	27900.00
0005434726952	9871	Economy	27900.00
0005435142638	9871	Economy	27900.00
0005433235167	9871	Economy	27900.00
0005433289959	9871	Economy	27900.00
0005434725926	9871	Economy	27900.00
0005434725957	9871	Economy	27900.00
0005434726261	9871	Economy	27900.00
0005434726402	9871	Economy	27900.00
0005434726330	9871	Economy	27900.00
0005433289955	9871	Economy	30700.00
0005434726481	9871	Economy	27900.00
0005433126914	9871	Economy	30700.00
0005433181481	9871	Economy	30700.00
0005434551730	9871	Economy	30700.00
0005434726416	9871	Economy	30700.00
0005433129346	9871	Economy	27900.00
0005433235159	9871	Economy	27900.00
0005434726437	9871	Economy	27900.00
0005433181478	9871	Economy	27900.00
0005434726422	9871	Economy	27900.00
0005435142685	9871	Economy	27900.00
0005433235170	9871	Economy	27900.00
0005433235189	9871	Economy	27900.00
0005434726267	9871	Economy	27900.00
0005434726213	9871	Economy	27900.00
0005434735705	9871	Economy	27900.00
0005434726204	9871	Economy	27900.00
0005433126916	9871	Economy	27900.00
0005434726222	9871	Economy	27900.00
0005434551522	9871	Economy	27900.00
0005433289958	9871	Economy	27900.00
0005434726684	9871	Economy	27900.00
0005434726347	9871	Economy	27900.00
0005434551409	9871	Economy	27900.00
0005434551613	9871	Economy	27900.00
0005434551442	9871	Economy	27900.00
0005433235190	9871	Economy	27900.00
0005433181476	9871	Economy	27900.00
0005433235176	9871	Economy	27900.00
0005434726271	9871	Economy	27900.00
0005434551419	9871	Economy	27900.00
0005434726511	9871	Economy	27900.00
0005435142622	9871	Economy	27900.00
0005434726061	9871	Economy	27900.00
0005435142676	9871	Economy	27900.00
0005434551463	9871	Economy	27900.00
0005434726179	9871	Economy	27900.00
0005433126913	9871	Economy	27900.00
0005434032096	9871	Economy	27900.00
0005434726421	9871	Economy	27900.00
0005433235147	9871	Economy	27900.00
0005433235153	9871	Economy	27900.00
0005434551582	9871	Economy	27900.00
0005434726440	9871	Economy	27900.00
0005434302467	9871	Economy	27900.00
0005434551453	9871	Economy	27900.00
0005434726060	9871	Economy	27900.00
0005435142606	9871	Economy	27900.00
0005434726483	9871	Economy	27900.00
0005433181487	9871	Economy	27900.00
0005434551452	9871	Economy	27900.00
0005434551658	9871	Economy	27900.00
0005434551593	9871	Economy	27900.00
0005434725920	9871	Economy	27900.00
0005434725837	9871	Economy	27900.00
0005434726484	9871	Economy	27900.00
0005434726379	9871	Economy	27900.00
0005434726055	9871	Economy	27900.00
0005434725965	9871	Economy	27900.00
0005434726470	9871	Economy	27900.00
0005434726063	9871	Economy	27900.00
0005433235175	9871	Economy	27900.00
0005434726120	9871	Economy	27900.00
0005433235162	9871	Economy	27900.00
0005434302479	9871	Economy	27900.00
0005434725811	9871	Economy	27900.00
0005434726270	9871	Economy	27900.00
0005432199353	9871	Economy	27900.00
0005434726262	9871	Economy	27900.00
0005433235183	9871	Economy	27900.00
0005433235199	9871	Economy	27900.00
0005434726300	9871	Economy	27900.00
0005433766698	9871	Economy	27900.00
0005434726520	9871	Economy	27900.00
0005433181500	9871	Economy	27900.00
0005435142683	9871	Economy	27900.00
0005433289954	9871	Economy	27900.00
0005433235154	9871	Economy	27900.00
0005433181497	9871	Economy	27900.00
0005433235179	9871	Economy	27900.00
0005433181477	9871	Economy	27900.00
0005434726045	9871	Economy	27900.00
0005433235157	9871	Economy	27900.00
0005434726232	9871	Economy	27900.00
0005433235182	9871	Economy	27900.00
0005434726299	9871	Economy	27900.00
0005434551556	9871	Economy	27900.00
0005433181488	9871	Economy	27900.00
0005433289957	9871	Economy	27900.00
0005433181489	9871	Economy	27900.00
0005434551448	9871	Economy	27900.00
0005433235205	9871	Economy	27900.00
0005434551623	9871	Economy	27900.00
0005432199355	9871	Economy	27900.00
0005434726323	9871	Economy	27900.00
0005434302480	9871	Economy	27900.00
0005435142673	9871	Economy	27900.00
0005435142693	9871	Economy	27900.00
0005434068686	7722	Business	42100.00
0005435214052	7722	Business	42100.00
0005435630988	7722	Business	42100.00
0005435214105	7722	Business	42100.00
0005432529926	7722	Business	42100.00
0005432530001	7722	Business	42100.00
0005434068684	7722	Business	42100.00
0005434068656	7722	Business	42100.00
0005433656681	7722	Business	42100.00
0005432533337	7722	Business	42100.00
0005432529964	7722	Business	42100.00
0005435214063	7722	Business	42100.00
0005432530028	7722	Business	42100.00
0005432150317	7722	Business	42100.00
0005432529971	7722	Business	42100.00
0005435213939	7722	Business	42100.00
0005434068645	7722	Business	42100.00
0005435214166	7722	Business	42100.00
0005432529933	7722	Business	42100.00
0005435214094	7722	Business	42100.00
0005432530054	7722	Business	42100.00
0005435214179	7722	Business	42100.00
0005432529996	7722	Comfort	23900.00
0005435214109	7722	Business	42100.00
0005432529934	7722	Comfort	23900.00
0005432529984	7722	Comfort	23900.00
0005435214053	7722	Comfort	23900.00
0005434068621	7722	Comfort	23900.00
0005432069885	7722	Comfort	23900.00
0005432535907	7722	Comfort	23900.00
0005435214110	7722	Comfort	23900.00
0005434068634	7722	Comfort	23900.00
0005435214033	7722	Comfort	23900.00
0005432530010	7722	Comfort	23900.00
0005435214086	7722	Comfort	23900.00
0005432530014	7722	Comfort	23900.00
0005432530013	7722	Comfort	23900.00
0005432150313	7722	Comfort	23900.00
0005434068668	7722	Comfort	23900.00
0005432530057	7722	Comfort	23900.00
0005432428980	7722	Comfort	23900.00
0005432529949	7722	Comfort	23900.00
0005434068639	7722	Comfort	23900.00
0005434068626	7722	Comfort	23900.00
0005432529986	7722	Comfort	23900.00
0005432530040	7722	Comfort	23900.00
0005432069879	7722	Comfort	23900.00
0005432529961	7722	Comfort	23900.00
0005435213942	7722	Comfort	23900.00
0005434068688	7722	Comfort	23900.00
0005432530060	7722	Comfort	23900.00
0005432530047	7722	Comfort	23900.00
0005435630989	7722	Comfort	23900.00
0005435214221	7722	Comfort	23900.00
0005435214097	7722	Comfort	23900.00
0005432069882	7722	Comfort	23900.00
0005435213862	7722	Comfort	23900.00
0005434068641	7722	Comfort	23900.00
0005434068660	7722	Comfort	23900.00
0005432530042	7722	Comfort	23900.00
0005435213786	7722	Comfort	23900.00
0005432529959	7722	Comfort	23900.00
0005432530050	7722	Comfort	23900.00
0005432069874	7722	Comfort	23900.00
0005435213998	7722	Comfort	23900.00
0005432529953	7722	Comfort	23900.00
0005432529956	7722	Economy	14000.00
0005432529995	7722	Economy	14000.00
0005432530025	7722	Economy	14000.00
0005435213968	7722	Economy	14000.00
0005435214146	7722	Economy	14000.00
0005432529931	7722	Economy	14000.00
0005432530012	7722	Economy	14000.00
0005432529929	7722	Economy	14000.00
0005432530034	7722	Economy	14000.00
0005432535910	7722	Economy	14000.00
0005432530002	7722	Economy	14000.00
0005432530037	7722	Economy	14000.00
0005435725652	7722	Economy	14000.00
0005435214015	7722	Economy	14000.00
0005432529954	7722	Economy	14000.00
0005432530029	7722	Economy	14000.00
0005432529972	7722	Economy	14000.00
0005432535908	7722	Economy	14000.00
0005435214147	7722	Economy	14000.00
0005432530052	7722	Economy	14000.00
0005434068673	7722	Economy	14000.00
0005432529991	7722	Economy	14000.00
0005435214235	7722	Economy	14000.00
0005432530035	7722	Economy	14000.00
0005434068687	7722	Economy	14000.00
0005434068650	7722	Economy	14000.00
0005432530032	7722	Economy	14000.00
0005435725654	7722	Economy	14000.00
0005432069872	7722	Economy	14000.00
0005432529975	7722	Economy	14000.00
0005432530031	7722	Economy	14000.00
0005432529982	7722	Economy	14000.00
0005432069878	7722	Economy	14000.00
0005432529948	7722	Economy	14000.00
0005435214181	7722	Economy	14000.00
0005432529969	7722	Economy	14000.00
0005435213886	7722	Economy	14000.00
0005432529952	7722	Economy	14000.00
0005432150315	7722	Economy	14000.00
0005435214325	7722	Economy	14000.00
0005434068652	7722	Economy	14000.00
0005434068675	7722	Economy	14000.00
0005434068681	7722	Economy	14000.00
0005434068630	7722	Economy	14000.00
0005435214089	7722	Economy	14000.00
0005435725618	7722	Economy	14000.00
0005432530036	7722	Economy	14000.00
0005434068636	7722	Economy	14000.00
0005434068670	7722	Economy	14000.00
0005432529989	7722	Economy	14000.00
0005435214132	7722	Economy	14000.00
0005435214016	7722	Economy	14000.00
0005434068632	7722	Economy	14000.00
0005434068651	7722	Economy	14000.00
0005432530059	7722	Economy	14000.00
0005432529973	7722	Economy	14000.00
0005432530017	7722	Economy	14000.00
0005434068677	7722	Economy	14000.00
0005432530039	7722	Economy	14000.00
0005434068628	7722	Economy	14000.00
0005432529980	7722	Economy	14000.00
0005434068638	7722	Economy	15400.00
0005435214098	7722	Economy	15400.00
0005432529935	7722	Economy	14000.00
0005432529938	7722	Economy	14000.00
0005432530008	7722	Economy	14000.00
0005432529999	7722	Economy	15400.00
0005435725630	7722	Economy	15400.00
0005434068676	7722	Economy	15400.00
0005434068662	7722	Economy	14000.00
0005432530033	7722	Economy	14000.00
0005435213941	7722	Economy	14000.00
0005432069875	7722	Economy	14000.00
0005434068631	7722	Economy	14000.00
0005434068690	7722	Economy	14000.00
0005435213969	7722	Economy	14000.00
0005432535909	7722	Economy	14000.00
0005432530003	7722	Economy	14000.00
0005434068640	7722	Economy	14000.00
0005435214054	7722	Economy	14000.00
0005432069886	7722	Economy	14000.00
0005432069876	7722	Economy	14000.00
0005435214223	7722	Economy	14000.00
0005432529928	7722	Economy	14000.00
0005433656677	7722	Economy	14000.00
0005435725653	7722	Economy	14000.00
0005432530049	7722	Economy	14000.00
0005434068629	7722	Economy	14000.00
0005434068663	7722	Economy	14000.00
0005434068689	7722	Economy	14000.00
0005432529998	7722	Economy	14000.00
0005432533336	7722	Economy	14000.00
0005432530045	7722	Economy	14000.00
0005434068667	7722	Economy	14000.00
0005432530053	7722	Economy	14000.00
0005435214326	7722	Economy	14000.00
0005434068680	7722	Economy	14000.00
0005432529985	7722	Economy	14000.00
0005432529994	7722	Economy	14000.00
0005432529962	7722	Economy	14000.00
0005434068654	7722	Economy	14000.00
0005432529966	7722	Economy	14000.00
0005435725651	7722	Economy	14000.00
0005432529930	7722	Economy	14000.00
0005432537090	7722	Economy	14000.00
0005433656680	7722	Economy	14000.00
0005432530023	7722	Economy	14000.00
0005432529957	7722	Economy	14000.00
0005432069873	7722	Economy	14000.00
0005432530000	7722	Economy	14000.00
0005434068658	7722	Economy	14000.00
0005434068646	7722	Economy	14000.00
0005432529932	7722	Economy	14000.00
0005432529978	7722	Economy	14000.00
0005435214090	7722	Economy	14000.00
0005434068619	7722	Economy	14000.00
0005435213940	7722	Economy	14000.00
0005435213952	7722	Economy	14000.00
0005434068674	7722	Economy	14000.00
0005432529976	7722	Economy	14000.00
0005432530056	7722	Economy	14000.00
0005432529992	7722	Economy	14000.00
0005432069880	7722	Economy	14000.00
0005435214190	7722	Economy	14000.00
0005432529977	7722	Economy	14000.00
0005435214215	7722	Economy	14000.00
0005432529937	7722	Economy	14000.00
0005435213997	7722	Economy	14000.00
0005435213980	7722	Economy	14000.00
0005432529942	7722	Economy	14000.00
0005435213970	7722	Economy	14000.00
0005432530055	7722	Economy	14000.00
0005432529939	7722	Economy	14000.00
0005432150318	7722	Economy	14000.00
0005435214187	7722	Economy	14000.00
0005432529968	7722	Economy	14000.00
0005434068653	7722	Economy	14000.00
0005435725617	7722	Economy	14000.00
0005432535906	7722	Economy	14000.00
0005432529987	7722	Economy	14000.00
0005434068659	7722	Economy	14000.00
0005432150314	7722	Economy	14000.00
0005432150319	7722	Economy	14000.00
0005432529993	7722	Economy	14000.00
0005432529947	7722	Economy	14000.00
0005432529946	7722	Economy	14000.00
0005434068682	7722	Economy	14000.00
0005435214186	7722	Economy	14000.00
0005434068627	7722	Economy	14000.00
0005435214017	7722	Economy	14000.00
0005435213838	7722	Economy	14000.00
0005432530030	7722	Economy	14000.00
0005432529944	7722	Economy	14000.00
0005434068633	7722	Economy	14000.00
0005432069883	7722	Economy	14000.00
0005432529988	7722	Economy	14000.00
0005432529936	7722	Economy	14000.00
0005434068666	7722	Economy	14000.00
0005435214180	7722	Economy	14000.00
0005432530026	7722	Economy	14000.00
0005432530015	7722	Economy	14000.00
0005433656703	7722	Economy	14000.00
0005434068648	7722	Economy	15400.00
0005434068622	7722	Economy	14000.00
0005434068649	7722	Economy	15400.00
0005432530005	7722	Economy	15400.00
0005432529960	7722	Economy	15400.00
0005435214120	7722	Economy	15400.00
0005432530018	7722	Economy	14000.00
0005432529958	7722	Economy	14000.00
0005435214106	7722	Economy	14000.00
0005432537091	7722	Economy	14000.00
0005435630983	7722	Economy	14000.00
0005432530020	7722	Economy	14000.00
0005432529950	7722	Economy	14000.00
0005435213828	7722	Economy	14000.00
0005434068657	7722	Economy	14000.00
0005435214167	7722	Economy	14000.00
0005432529970	7722	Economy	14000.00
0005432530058	7722	Economy	14000.00
0005432530011	7722	Economy	14000.00
0005435214177	7722	Economy	14000.00
0005432529983	7722	Economy	14000.00
0005432529997	7722	Economy	14000.00
0005432069881	7722	Economy	14000.00
0005432529940	7722	Economy	14000.00
0005435214082	7722	Economy	14000.00
0005432529974	7722	Economy	14000.00
0005432530044	7722	Economy	14000.00
0005432529963	7722	Economy	14000.00
0005434068637	7722	Economy	14000.00
0005432530019	7722	Economy	14000.00
0005434068672	7722	Economy	14000.00
0005434068665	7722	Economy	14000.00
0005435725643	7722	Economy	14000.00
0005435214032	7722	Economy	14000.00
0005432530016	7722	Economy	14000.00
0005435214133	7722	Economy	14000.00
0005435213861	7722	Economy	14000.00
0005434068683	7722	Economy	14000.00
0005432530043	7722	Economy	14000.00
0005434068669	7722	Economy	14000.00
0005434068644	7722	Economy	14000.00
0005434068661	7722	Economy	14000.00
0005435213883	7722	Economy	14000.00
0005434068647	7722	Economy	14000.00
0005432530006	7722	Economy	14000.00
0005434068671	7722	Economy	14000.00
0005435213910	7722	Economy	14000.00
0005432529965	7722	Economy	14000.00
0005432530021	7722	Economy	14000.00
0005432428981	7722	Economy	14000.00
0005434068635	7722	Economy	14000.00
0005435725631	7722	Economy	14000.00
0005435214083	7722	Economy	14000.00
0005434068620	7722	Economy	14000.00
0005434068655	7722	Economy	14000.00
0005432069877	7722	Economy	14000.00
0005435213853	7722	Economy	14000.00
0005432529945	7722	Economy	14000.00
0005432530004	7722	Economy	14000.00
0005432529990	7722	Economy	14000.00
0005432530027	7722	Economy	14000.00
0005432530009	7722	Economy	14000.00
0005432537089	7722	Economy	14000.00
0005435213860	7722	Economy	14000.00
0005432529979	7722	Economy	14000.00
0005432530038	7722	Economy	14000.00
0005432530024	7722	Economy	14000.00
0005434068685	7722	Economy	14000.00
0005432530046	7722	Economy	14000.00
0005432529927	7722	Economy	14000.00
0005432529943	7722	Economy	14000.00
0005432529967	7722	Economy	14000.00
0005432529941	7722	Economy	14000.00
0005432069884	7722	Economy	14000.00
0005432529951	7722	Economy	14000.00
0005435214087	7722	Economy	14000.00
0005432530007	7722	Economy	14000.00
0005435214252	7722	Economy	14000.00
0005432530051	7722	Economy	14000.00
0005432530022	7722	Economy	14000.00
0005434068624	7722	Economy	14000.00
0005434068679	7722	Economy	14000.00
0005432529955	7722	Economy	14000.00
0005432530041	7722	Economy	14000.00
0005434068664	7722	Economy	14000.00
0005435214148	7722	Economy	14000.00
0005435213953	7722	Economy	14000.00
0005432150316	7722	Economy	14000.00
0005435213863	7722	Economy	14000.00
0005432529981	7722	Economy	14000.00
0005435725632	7722	Economy	14000.00
0005435214251	7722	Economy	14000.00
0005434068623	7722	Economy	14000.00
0005435214234	7722	Economy	14000.00
0005434068642	7722	Economy	14000.00
0005434068625	7722	Economy	14000.00
0005432428982	7722	Economy	14000.00
0005435214162	7722	Economy	14000.00
0005435213852	7722	Economy	14000.00
0005432530048	7722	Economy	14000.00
0005434068643	7722	Economy	14000.00
0005434068678	7722	Economy	14000.00
0005435725616	7722	Economy	14000.00
0005435425144	5311	Business	43100.00
0005435425317	5311	Business	43100.00
0005435425426	5311	Business	43100.00
0005435615450	5311	Business	43100.00
0005432047606	5311	Business	43100.00
0005434344765	5311	Business	43100.00
0005435615408	5311	Business	43100.00
0005432133444	5311	Business	43100.00
0005435319667	5311	Business	43100.00
0005434245280	5311	Business	43100.00
0005434344768	5311	Business	43100.00
0005434245074	5311	Business	43100.00
0005435425197	5311	Business	43100.00
0005435615446	5311	Business	43100.00
0005434344776	5311	Business	43100.00
0005435615436	5311	Business	43100.00
0005435319653	5311	Business	43100.00
0005434344777	5311	Business	43100.00
0005435615371	5311	Business	43100.00
0005435615397	5311	Business	43100.00
0005434245237	5311	Business	43100.00
0005435615417	5311	Business	43100.00
0005435615377	5311	Business	43100.00
0005434344772	5311	Business	43100.00
0005435615429	5311	Business	43100.00
0005435042872	5311	Business	43100.00
0005434245195	5311	Business	43100.00
0005432133440	5311	Business	43100.00
0005435615379	5311	Business	43100.00
0005435319706	5311	Comfort	24400.00
0005435615348	5311	Comfort	24400.00
0005435425254	5311	Comfort	24400.00
0005435615409	5311	Comfort	24400.00
0005435097363	5311	Comfort	24400.00
0005435302223	5311	Comfort	24400.00
0005435615441	5311	Comfort	24400.00
0005435305029	5311	Comfort	24400.00
0005434245028	5311	Comfort	24400.00
0005435302231	5311	Comfort	24400.00
0005435615402	5311	Comfort	24400.00
0005434344759	5311	Comfort	24400.00
0005434344763	5311	Comfort	24400.00
0005434344756	5311	Comfort	24400.00
0005435615413	5311	Comfort	24400.00
0005435615406	5311	Comfort	24400.00
0005434245180	5311	Comfort	24400.00
0005435425182	5311	Comfort	24400.00
0005435615354	5311	Comfort	24400.00
0005434344778	5311	Comfort	24400.00
0005433719149	5311	Comfort	24400.00
0005435319638	5311	Comfort	24400.00
0005434245282	5311	Comfort	24400.00
0005435555401	5311	Comfort	24400.00
0005435615386	5311	Comfort	24400.00
0005435615444	5311	Comfort	24400.00
0005435615425	5311	Comfort	24400.00
0005435425330	5311	Comfort	24400.00
0005435615361	5311	Comfort	24400.00
0005434245236	5311	Comfort	24400.00
0005435555402	5311	Comfort	24400.00
0005435615404	5311	Comfort	24400.00
0005435615407	5311	Comfort	24400.00
0005435615443	5311	Comfort	24400.00
0005434344761	5311	Comfort	24400.00
0005434344771	5311	Comfort	24400.00
0005433719168	5311	Comfort	24400.00
0005434573576	5311	Comfort	24400.00
0005435615382	5311	Comfort	24400.00
0005435615399	5311	Economy	14400.00
0005435615451	5311	Economy	14400.00
0005435615439	5311	Economy	14400.00
0005435615410	5311	Economy	14400.00
0005434573577	5311	Economy	14400.00
0005434245114	5311	Economy	14400.00
0005435319656	5311	Economy	14400.00
0005435615347	5311	Economy	14400.00
0005434573566	5311	Economy	14400.00
0005432841019	5311	Economy	14400.00
0005435615447	5311	Economy	14400.00
0005435425385	5311	Economy	14400.00
0005434344748	5311	Economy	14400.00
0005435615356	5311	Economy	14400.00
0005435615369	5311	Economy	14400.00
0005434344773	5311	Economy	14400.00
0005435425045	5311	Economy	14400.00
0005435490286	5311	Economy	14400.00
0005434344779	5311	Economy	14400.00
0005432047607	5311	Economy	14400.00
0005435425382	5311	Economy	14400.00
0005435097360	5311	Economy	14400.00
0005435615411	5311	Economy	14400.00
0005435615373	5311	Economy	14400.00
0005435425195	5311	Economy	14400.00
0005434344752	5311	Economy	14400.00
0005434573575	5311	Economy	14400.00
0005435615433	5311	Economy	14400.00
0005434245296	5311	Economy	14400.00
0005435615442	5311	Economy	14400.00
0005435615412	5311	Economy	14400.00
0005435425443	5311	Economy	14400.00
0005435425403	5311	Economy	14400.00
0005434245181	5311	Economy	14400.00
0005435319666	5311	Economy	14400.00
0005435615353	5311	Economy	14400.00
0005435425442	5311	Economy	14400.00
0005435615392	5311	Economy	14400.00
0005434573564	5311	Economy	14400.00
0005435425419	5311	Economy	14400.00
0005435425391	5311	Economy	14400.00
0005435425155	5311	Economy	14400.00
0005435615367	5311	Economy	14400.00
0005435425060	5311	Economy	14400.00
0005435305023	5311	Economy	14400.00
0005435097355	5311	Economy	14400.00
0005434245163	5311	Economy	14400.00
0005435615384	5311	Economy	14400.00
0005435319593	5311	Economy	14400.00
0005434344769	5311	Economy	14400.00
0005435615414	5311	Economy	14400.00
0005432841023	5311	Economy	14400.00
0005432363441	5311	Economy	14400.00
0005434344757	5311	Economy	14400.00
0005432363427	5311	Economy	14400.00
0005435615421	5311	Economy	14400.00
0005435380322	5311	Economy	14400.00
0005434344775	5311	Economy	14400.00
0005435425538	5311	Economy	14400.00
0005435425213	5311	Economy	15800.00
0005435425435	5311	Economy	14400.00
0005434573573	5311	Economy	14400.00
0005434344753	5311	Economy	14400.00
0005434344758	5311	Economy	15800.00
0005435425467	5311	Economy	14400.00
0005435425209	5311	Economy	15800.00
0005435425260	5311	Economy	15800.00
0005434344770	5311	Economy	14400.00
0005435491471	5311	Economy	14400.00
0005435615432	5311	Economy	14400.00
0005435425360	5311	Economy	14400.00
0005435615378	5311	Economy	14400.00
0005435097357	5311	Economy	14400.00
0005435615428	5311	Economy	14400.00
0005435491472	5311	Economy	14400.00
0005435615358	5311	Economy	14400.00
0005435380321	5311	Economy	14400.00
0005435425106	5311	Economy	14400.00
0005435615351	5311	Economy	14400.00
0005435425211	5311	Economy	14400.00
0005434245222	5311	Economy	14400.00
0005435615422	5311	Economy	14400.00
0005435425451	5311	Economy	14400.00
0005435615357	5311	Economy	14400.00
0005435615372	5311	Economy	14400.00
0005435425210	5311	Economy	14400.00
0005435615374	5311	Economy	14400.00
0005432133441	5311	Economy	14400.00
0005432133438	5311	Economy	14400.00
0005435615430	5311	Economy	14400.00
0005434245068	5311	Economy	14400.00
0005434245251	5311	Economy	14400.00
0005435319673	5311	Economy	14400.00
0005435615437	5311	Economy	14400.00
0005435615388	5311	Economy	14400.00
0005432841020	5311	Economy	14400.00
0005435490285	5311	Economy	14400.00
0005434573572	5311	Economy	14400.00
0005435425390	5311	Economy	14400.00
0005434245242	5311	Economy	14400.00
0005435425187	5311	Economy	14400.00
0005435615448	5311	Economy	14400.00
0005435425434	5311	Economy	14400.00
0005434573574	5311	Economy	14400.00
0005434245069	5311	Economy	14400.00
0005435097362	5311	Economy	14400.00
0005434245235	5311	Economy	14400.00
0005435615403	5311	Economy	14400.00
0005434245281	5311	Economy	14400.00
0005434344751	5311	Economy	14400.00
0005435425168	5311	Economy	14400.00
0005435615449	5311	Economy	14400.00
0005435319646	5311	Economy	14400.00
0005432133442	5311	Economy	14400.00
0005435615350	5311	Economy	14400.00
0005435425404	5311	Economy	14400.00
0005435097358	5311	Economy	14400.00
0005435425218	5311	Economy	14400.00
0005435380332	5311	Economy	14400.00
0005435319586	5311	Economy	14400.00
0005435615438	5311	Economy	14400.00
0005435425215	5311	Economy	14400.00
0005435615390	5311	Economy	14400.00
0005435615355	5311	Economy	14400.00
0005435425091	5311	Economy	14400.00
0005434344781	5311	Economy	14400.00
0005432133451	5311	Economy	14400.00
0005435425294	5311	Economy	14400.00
0005434344762	5311	Economy	14400.00
0005434344766	5311	Economy	14400.00
0005435097364	5311	Economy	14400.00
0005435615363	5311	Economy	14400.00
0005435425450	5311	Economy	14400.00
0005435425448	5311	Economy	14400.00
0005435615365	5311	Economy	14400.00
0005432133437	5311	Economy	14400.00
0005435615395	5311	Economy	14400.00
0005432363436	5311	Economy	14400.00
0005435615381	5311	Economy	14400.00
0005434344750	5311	Economy	14400.00
0005435425293	5311	Economy	14400.00
0005435490284	5311	Economy	14400.00
0005435425400	5311	Economy	14400.00
0005432133450	5311	Economy	14400.00
0005435097354	5311	Economy	14400.00
0005432133445	5311	Economy	14400.00
0005434573567	5311	Economy	14400.00
0005434245006	5311	Economy	14400.00
0005435615445	5311	Economy	14400.00
0005434245007	5311	Economy	14400.00
0005435615419	5311	Economy	14400.00
0005434245273	5311	Economy	14400.00
0005434245165	5311	Economy	14400.00
0005435615431	5311	Economy	14400.00
0005432133447	5311	Economy	14400.00
0005432133448	5311	Economy	14400.00
0005435425398	5311	Economy	14400.00
0005434344767	5311	Economy	14400.00
0005435425196	5311	Economy	14400.00
0005435615393	5311	Economy	14400.00
0005435615416	5311	Economy	14400.00
0005435615387	5311	Economy	14400.00
0005434245196	5311	Economy	14400.00
0005435425203	5311	Economy	15800.00
0005434245252	5311	Economy	15800.00
0005435615360	5311	Economy	15800.00
0005435425631	5311	Economy	15800.00
0005435425537	5311	Economy	15800.00
0005435425315	5311	Economy	15800.00
0005435305024	5311	Economy	14400.00
0005435305030	5311	Economy	14400.00
0005435615391	5311	Economy	14400.00
0005434245221	5311	Economy	14400.00
0005435425090	5311	Economy	14400.00
0005434344749	5311	Economy	14400.00
0005432133443	5311	Economy	14400.00
0005434344755	5311	Economy	14400.00
0005434573568	5311	Economy	14400.00
0005434245103	5311	Economy	14400.00
0005435425194	5311	Economy	14400.00
0005434245102	5311	Economy	14400.00
0005435615418	5311	Economy	14400.00
0005435615452	5311	Economy	14400.00
0005435425395	5311	Economy	14400.00
0005432363440	5311	Economy	14400.00
0005435615426	5311	Economy	14400.00
0005435097356	5311	Economy	14400.00
0005434344747	5311	Economy	14400.00
0005435425589	5311	Economy	14400.00
0005435490283	5311	Economy	14400.00
0005434245179	5311	Economy	14400.00
0005435425471	5311	Economy	14400.00
0005435097361	5311	Economy	14400.00
0005435615389	5311	Economy	14400.00
0005435615380	5311	Economy	14400.00
0005434245220	5311	Economy	14400.00
0005435615385	5311	Economy	14400.00
0005432133439	5311	Economy	14400.00
0005435615415	5311	Economy	14400.00
0005435425269	5311	Economy	14400.00
0005435425214	5311	Economy	14400.00
0005435615366	5311	Economy	14400.00
0005435425370	5311	Economy	14400.00
0005435615400	5311	Economy	14400.00
0005434573570	5311	Economy	14400.00
0005435425193	5311	Economy	14400.00
0005434245073	5311	Economy	14400.00
0005432133449	5311	Economy	14400.00
0005434245177	5311	Economy	14400.00
0005435615398	5311	Economy	14400.00
0005435425363	5311	Economy	14400.00
0005435425405	5311	Economy	14400.00
0005435615394	5311	Economy	14400.00
0005434245178	5311	Economy	14400.00
0005435615375	5311	Economy	14400.00
0005435615427	5311	Economy	14400.00
0005432047609	5311	Economy	14400.00
0005435615362	5311	Economy	14400.00
0005435425361	5311	Economy	14400.00
0005434344774	5311	Economy	14400.00
0005435615401	5311	Economy	14400.00
0005435425523	5311	Economy	14400.00
0005435042873	5311	Economy	14400.00
0005435319650	5311	Economy	14400.00
0005435615396	5311	Economy	14400.00
0005435615370	5311	Economy	14400.00
0005435615423	5311	Economy	14400.00
0005435319705	5311	Economy	14400.00
0005435425399	5311	Economy	14400.00
0005434245243	5311	Economy	14400.00
0005435615440	5311	Economy	14400.00
0005434344760	5311	Economy	14400.00
0005434245164	5311	Economy	14400.00
0005434245197	5311	Economy	14400.00
0005435615434	5311	Economy	14400.00
0005432133436	5311	Economy	14400.00
0005435615420	5311	Economy	14400.00
0005434573569	5311	Economy	14400.00
0005435425618	5311	Economy	14400.00
0005435615368	5311	Economy	14400.00
0005434573565	5311	Economy	14400.00
0005435615352	5311	Economy	14400.00
0005435615349	5311	Economy	14400.00
0005435319651	5311	Economy	14400.00
0005434344780	5311	Economy	14400.00
0005432047608	5311	Economy	14400.00
0005434245295	5311	Economy	14400.00
0005432363435	5311	Economy	14400.00
0005435425376	5311	Economy	14400.00
0005435615435	5311	Economy	14400.00
0005434344764	5311	Economy	14400.00
0005435425143	5311	Economy	14400.00
0005435425468	5311	Economy	14400.00
0005435615364	5311	Economy	14400.00
0005435425105	5311	Economy	14400.00
0005435491470	5311	Economy	14400.00
0005434344754	5311	Economy	14400.00
0005435425371	5311	Economy	14400.00
0005435615376	5311	Economy	14400.00
0005435615383	5311	Economy	14400.00
0005435425332	5311	Economy	14400.00
0005432841022	5311	Economy	14400.00
0005432133446	5311	Economy	14400.00
0005432841021	5311	Economy	14400.00
0005435615424	5311	Economy	14400.00
0005434573571	5311	Economy	14400.00
0005435615405	5311	Economy	14400.00
0005435615359	5311	Economy	14400.00
0005435097359	5311	Economy	14400.00
0005435319704	5311	Economy	14400.00
0005435425584	5311	Economy	14400.00
0005435425224	5311	Economy	14400.00
0005435425854	10925	Business	43100.00
0005434573456	10925	Business	43100.00
0005435097320	10925	Business	43100.00
0005435304226	10925	Business	43100.00
0005434573334	10925	Business	43100.00
0005435425852	10925	Business	43100.00
0005435425869	10925	Business	43100.00
0005435425845	10925	Business	43100.00
0005435614149	10925	Business	43100.00
0005434573429	10925	Business	43100.00
0005435305043	10925	Business	43100.00
0005435425853	10925	Business	43100.00
0005435380363	10925	Business	43100.00
0005435319707	10925	Business	43100.00
0005432165153	10925	Business	43100.00
0005435614623	10925	Business	43100.00
0005435614449	10925	Business	43100.00
0005435614118	10925	Business	43100.00
0005435614575	10925	Comfort	24400.00
0005435614592	10925	Comfort	24400.00
0005435614148	10925	Comfort	24400.00
0005435425855	10925	Comfort	24400.00
0005434344320	10925	Comfort	24400.00
0005434245442	10925	Comfort	24400.00
0005434344457	10925	Comfort	24400.00
0005433719193	10925	Comfort	24400.00
0005435425890	10925	Comfort	24400.00
0005435425835	10925	Comfort	24400.00
0005435425900	10925	Comfort	24400.00
0005434344298	10925	Comfort	24400.00
0005435425875	10925	Comfort	24400.00
0005434245428	10925	Comfort	24400.00
0005435425858	10925	Comfort	24400.00
0005435614183	10925	Comfort	24400.00
0005434245419	10925	Comfort	24400.00
0005434245426	10925	Comfort	24400.00
0005435614232	10925	Comfort	24400.00
0005435425902	10925	Comfort	24400.00
0005434245422	10925	Comfort	24400.00
0005435614331	10925	Comfort	24400.00
0005435614373	10925	Comfort	24400.00
0005435425892	10925	Comfort	24400.00
0005434573455	10925	Comfort	24400.00
0005434573383	10925	Comfort	24400.00
0005435425837	10925	Comfort	24400.00
0005435614454	10925	Comfort	24400.00
0005435614354	10925	Comfort	24400.00
0005435425873	10925	Comfort	24400.00
0005432841045	10925	Comfort	24400.00
0005434656587	10925	Comfort	24400.00
0005432166952	10925	Comfort	24400.00
0005435614673	10925	Comfort	24400.00
0005435425831	10925	Comfort	24400.00
0005435425879	10925	Comfort	24400.00
0005435613848	10925	Comfort	24400.00
0005434245439	10925	Comfort	24400.00
0005435614535	10925	Comfort	24400.00
0005435614631	10925	Comfort	24400.00
0005435425881	10925	Comfort	24400.00
0005435614609	10925	Comfort	24400.00
0005435613958	10925	Economy	14400.00
0005435425839	10925	Economy	14400.00
0005435491456	10925	Economy	14400.00
0005434344367	10925	Economy	14400.00
0005435614534	10925	Economy	14400.00
0005434344420	10925	Economy	14400.00
0005435614656	10925	Economy	14400.00
0005435555388	10925	Economy	14400.00
0005435425861	10925	Economy	14400.00
0005435380365	10925	Economy	14400.00
0005434245421	10925	Economy	14400.00
0005434573409	10925	Economy	14400.00
0005435614388	10925	Economy	14400.00
0005435425859	10925	Economy	14400.00
0005434245445	10925	Economy	14400.00
0005435614215	10925	Economy	14400.00
0005435425866	10925	Economy	14400.00
0005435614277	10925	Economy	14400.00
0005432165155	10925	Economy	14400.00
0005434344282	10925	Economy	14400.00
0005434344406	10925	Economy	14400.00
0005435614672	10925	Economy	14400.00
0005435613849	10925	Economy	14400.00
0005433719192	10925	Economy	14400.00
0005435425893	10925	Economy	14400.00
0005435097219	10925	Economy	14400.00
0005435425882	10925	Economy	14400.00
0005435614366	10925	Economy	14400.00
0005435614266	10925	Economy	14400.00
0005434245434	10925	Economy	14400.00
0005435613918	10925	Economy	14400.00
0005432165156	10925	Economy	14400.00
0005435380364	10925	Economy	14400.00
0005434245436	10925	Economy	14400.00
0005435613767	10925	Economy	14400.00
0005434573395	10925	Economy	14400.00
0005435614427	10925	Economy	14400.00
0005435425886	10925	Economy	14400.00
0005434344256	10925	Economy	14400.00
0005435614450	10925	Economy	14400.00
0005434344488	10925	Economy	14400.00
0005434573391	10925	Economy	14400.00
0005434344383	10925	Economy	14400.00
0005435614385	10925	Economy	14400.00
0005435614265	10925	Economy	14400.00
0005435425838	10925	Economy	14400.00
0005435425844	10925	Economy	14400.00
0005434344366	10925	Economy	14400.00
0005435614121	10925	Economy	14400.00
0005435319709	10925	Economy	14400.00
0005434344480	10925	Economy	14400.00
0005434344460	10925	Economy	14400.00
0005435425850	10925	Economy	14400.00
0005435491449	10925	Economy	14400.00
0005434344365	10925	Economy	14400.00
0005434245420	10925	Economy	14400.00
0005435097218	10925	Economy	14400.00
0005435425877	10925	Economy	14400.00
0005434245432	10925	Economy	14400.00
0005435097263	10925	Economy	14400.00
0005435614613	10925	Economy	14400.00
0005435614210	10925	Economy	14400.00
0005434573457	10925	Economy	14400.00
0005435425868	10925	Economy	15800.00
0005435614065	10925	Economy	15800.00
0005433719194	10925	Economy	14400.00
0005435425856	10925	Economy	15800.00
0005435614219	10925	Economy	14400.00
0005435614185	10925	Economy	14400.00
0005435425898	10925	Economy	14400.00
0005435425842	10925	Economy	14400.00
0005435614290	10925	Economy	14400.00
0005434245425	10925	Economy	14400.00
0005435425888	10925	Economy	14400.00
0005434573466	10925	Economy	14400.00
0005435425851	10925	Economy	14400.00
0005435614619	10925	Economy	14400.00
0005434245427	10925	Economy	14400.00
0005435614510	10925	Economy	14400.00
0005434344355	10925	Economy	14400.00
0005434344503	10925	Economy	14400.00
0005435614175	10925	Economy	14400.00
0005435425841	10925	Economy	14400.00
0005435490250	10925	Economy	14400.00
0005435613972	10925	Economy	14400.00
0005435614122	10925	Economy	14400.00
0005434245418	10925	Economy	14400.00
0005435097264	10925	Economy	14400.00
0005435425899	10925	Economy	14400.00
0005434344209	10925	Economy	14400.00
0005434344478	10925	Economy	14400.00
0005435425891	10925	Economy	14400.00
0005435304225	10925	Economy	14400.00
0005435613941	10925	Economy	14400.00
0005435425846	10925	Economy	14400.00
0005435425863	10925	Economy	14400.00
0005435097223	10925	Economy	14400.00
0005435614348	10925	Economy	14400.00
0005435425895	10925	Economy	14400.00
0005435614396	10925	Economy	14400.00
0005432165158	10925	Economy	14400.00
0005435613943	10925	Economy	14400.00
0005434344299	10925	Economy	14400.00
0005435614310	10925	Economy	14400.00
0005435425871	10925	Economy	14400.00
0005435614399	10925	Economy	14400.00
0005435425883	10925	Economy	14400.00
0005434344472	10925	Economy	14400.00
0005432841046	10925	Economy	14400.00
0005435425870	10925	Economy	14400.00
0005435425867	10925	Economy	14400.00
0005434573440	10925	Economy	14400.00
0005435425847	10925	Economy	14400.00
0005435097265	10925	Economy	14400.00
0005435425836	10925	Economy	14400.00
0005435380366	10925	Economy	14400.00
0005432363466	10925	Economy	14400.00
0005435425862	10925	Economy	14400.00
0005434245435	10925	Economy	14400.00
0005435614515	10925	Economy	14400.00
0005435425857	10925	Economy	14400.00
0005435425848	10925	Economy	14400.00
0005435425843	10925	Economy	14400.00
0005434344334	10925	Economy	14400.00
0005432166950	10925	Economy	14400.00
0005435614493	10925	Economy	14400.00
0005435613917	10925	Economy	14400.00
0005435425833	10925	Economy	14400.00
0005434344374	10925	Economy	14400.00
0005435614182	10925	Economy	14400.00
0005434573454	10925	Economy	14400.00
0005434344399	10925	Economy	14400.00
0005435614372	10925	Economy	14400.00
0005435425897	10925	Economy	14400.00
0005434573467	10925	Economy	14400.00
0005435614504	10925	Economy	14400.00
0005434573401	10925	Economy	14400.00
0005435614218	10925	Economy	14400.00
0005435425860	10925	Economy	14400.00
0005435614614	10925	Economy	14400.00
0005434245446	10925	Economy	14400.00
0005435380367	10925	Economy	14400.00
0005434245444	10925	Economy	14400.00
0005435319706	10925	Economy	14400.00
0005435614503	10925	Economy	14400.00
0005435614209	10925	Economy	14400.00
0005434573431	10925	Economy	14400.00
0005435319712	10925	Economy	14400.00
0005432165154	10925	Economy	14400.00
0005435614401	10925	Economy	14400.00
0005435614536	10925	Economy	14400.00
0005435614017	10925	Economy	14400.00
0005434245431	10925	Economy	14400.00
0005435614355	10925	Economy	14400.00
0005435614615	10925	Economy	14400.00
0005434344407	10925	Economy	14400.00
0005435614469	10925	Economy	14400.00
0005434344335	10925	Economy	14400.00
0005435614184	10925	Economy	14400.00
0005435425884	10925	Economy	14400.00
0005435097249	10925	Economy	14400.00
0005435614691	10925	Economy	14400.00
0005435425885	10925	Economy	14400.00
0005435614154	10925	Economy	14400.00
0005434344430	10925	Economy	14400.00
0005434344255	10925	Economy	15800.00
0005435425889	10925	Economy	15800.00
0005434573382	10925	Economy	14400.00
0005435425876	10925	Economy	15800.00
0005435614330	10925	Economy	14400.00
0005435425894	10925	Economy	14400.00
0005434573392	10925	Economy	14400.00
0005435613854	10925	Economy	14400.00
0005435425832	10925	Economy	14400.00
0005435614629	10925	Economy	14400.00
0005432363467	10925	Economy	14400.00
0005435614610	10925	Economy	14400.00
0005432166951	10925	Economy	14400.00
0005435319711	10925	Economy	14400.00
0005434573430	10925	Economy	14400.00
0005434245447	10925	Economy	14400.00
0005435614052	10925	Economy	14400.00
0005435613951	10925	Economy	14400.00
0005435425874	10925	Economy	14400.00
0005434245443	10925	Economy	14400.00
0005435614678	10925	Economy	14400.00
0005434245438	10925	Economy	14400.00
0005433719195	10925	Economy	14400.00
0005435614713	10925	Economy	14400.00
0005435614367	10925	Economy	14400.00
0005435425865	10925	Economy	14400.00
0005435614150	10925	Economy	14400.00
0005435614426	10925	Economy	14400.00
0005435425840	10925	Economy	14400.00
0005434344368	10925	Economy	14400.00
0005435614489	10925	Economy	14400.00
0005435614288	10925	Economy	14400.00
0005435614441	10925	Economy	14400.00
0005435319710	10925	Economy	14400.00
0005435425880	10925	Economy	14400.00
0005434344371	10925	Economy	14400.00
0005434344479	10925	Economy	14400.00
0005434245430	10925	Economy	14400.00
0005435614274	10925	Economy	14400.00
0005434245433	10925	Economy	14400.00
0005434245429	10925	Economy	14400.00
0005434344475	10925	Economy	14400.00
0005434344375	10925	Economy	14400.00
0005434245440	10925	Economy	14400.00
0005435319708	10925	Economy	14400.00
0005435425901	10925	Economy	14400.00
0005434344296	10925	Economy	14400.00
0005434344300	10925	Economy	14400.00
0005435304223	10925	Economy	14400.00
0005434344319	10925	Economy	14400.00
0005434573335	10925	Economy	14400.00
0005435614494	10925	Economy	14400.00
0005435614309	10925	Economy	14400.00
0005435613766	10925	Economy	14400.00
0005435614397	10925	Economy	14400.00
0005435614448	10925	Economy	14400.00
0005435425864	10925	Economy	14400.00
0005434344294	10925	Economy	14400.00
0005434245423	10925	Economy	14400.00
0005435425849	10925	Economy	14400.00
0005435425878	10925	Economy	14400.00
0005435425887	10925	Economy	14400.00
0005435304224	10925	Economy	14400.00
0005434344369	10925	Economy	14400.00
0005435614328	10925	Economy	14400.00
0005435614400	10925	Economy	14400.00
0005435425872	10925	Economy	14400.00
0005434344389	10925	Economy	14400.00
0005435614370	10925	Economy	14400.00
0005435614630	10925	Economy	14400.00
0005435614530	10925	Economy	14400.00
0005434245437	10925	Economy	14400.00
0005435614671	10925	Economy	14400.00
0005434573408	10925	Economy	14400.00
0005435425896	10925	Economy	14400.00
0005435614518	10925	Economy	14400.00
0005435613978	10925	Economy	14400.00
0005435613989	10925	Economy	14400.00
0005435613942	10925	Economy	14400.00
0005434245424	10925	Economy	14400.00
0005434573396	10925	Economy	14400.00
0005435614475	10925	Economy	14400.00
0005435425834	10925	Economy	14400.00
0005434344424	10925	Economy	14400.00
0005434573428	10925	Economy	14400.00
0005434344370	10925	Economy	14400.00
0005434344382	10925	Economy	14400.00
0005435614197	10925	Economy	14400.00
0005434245441	10925	Economy	14400.00
0005434344347	10925	Economy	14400.00
0005432165157	10925	Economy	14400.00
0005435097321	10925	Economy	14400.00
0005435319713	10925	Economy	14400.00
0005434573393	10925	Economy	14400.00
0005433634339	3302	Business	18800.00
0005433507449	3302	Business	18800.00
0005433507450	3302	Business	18800.00
0005433634349	3302	Business	18800.00
0005432460057	3302	Business	18800.00
0005433634358	3302	Business	18800.00
0005432182060	3302	Business	18800.00
0005433507446	3302	Business	18800.00
0005433805886	3302	Business	18800.00
0005432460306	3302	Business	18800.00
0005433805881	3302	Business	18800.00
0005433805895	3302	Business	18800.00
0005432460308	3302	Business	18800.00
0005432460240	3302	Business	18800.00
0005433634348	3302	Business	18800.00
0005433805880	3302	Business	18800.00
0005432182056	3302	Business	18800.00
0005433507443	3302	Business	18800.00
0005433805882	3302	Business	18800.00
0005432460288	3302	Business	18800.00
0005432460277	3302	Business	18800.00
0005432460161	3302	Business	18800.00
0005433805919	3302	Business	18800.00
0005432460304	3302	Business	18800.00
0005433805906	3302	Business	18800.00
0005433634350	3302	Economy	6900.00
0005432460336	3302	Business	18800.00
0005433634345	3302	Economy	6900.00
0005432182066	3302	Economy	6900.00
0005432460081	3302	Economy	6900.00
0005432460176	3302	Economy	6900.00
0005433805917	3302	Economy	6900.00
0005432182051	3302	Economy	6300.00
0005432460235	3302	Economy	6300.00
0005433805904	3302	Economy	6300.00
0005432460151	3302	Economy	6300.00
0005433805884	3302	Economy	6300.00
0005432182071	3302	Economy	6300.00
0005433634355	3302	Economy	6300.00
0005433507447	3302	Economy	6300.00
0005433805912	3302	Economy	6300.00
0005433805891	3302	Economy	6300.00
0005433805911	3302	Economy	6300.00
0005432182070	3302	Economy	6300.00
0005432460283	3302	Economy	6300.00
0005433634335	3302	Economy	6300.00
0005433634361	3302	Economy	6300.00
0005432460175	3302	Economy	6300.00
0005433805883	3302	Economy	6300.00
0005433805901	3302	Economy	6300.00
0005433805897	3302	Economy	6300.00
0005432182067	3302	Economy	6300.00
0005432460069	3302	Economy	6300.00
0005432460328	3302	Economy	6300.00
0005433805903	3302	Economy	6300.00
0005433634359	3302	Economy	6300.00
0005432182061	3302	Economy	6300.00
0005433507448	3302	Economy	6300.00
0005432460243	3302	Economy	6300.00
0005432182054	3302	Economy	6300.00
0005433805915	3302	Economy	6300.00
0005432182049	3302	Economy	6300.00
0005433805898	3302	Economy	6300.00
0005433634332	3302	Economy	6300.00
0005432460060	3302	Economy	6300.00
0005433805890	3302	Economy	6300.00
0005433634364	3302	Economy	6300.00
0005432460223	3302	Economy	6300.00
0005433805913	3302	Economy	6300.00
0005433805905	3302	Economy	6300.00
0005433805885	3302	Economy	6300.00
0005432182055	3302	Economy	6300.00
0005432182069	3302	Economy	6300.00
0005433805896	3302	Economy	6300.00
0005433634363	3302	Economy	6300.00
0005432460014	3302	Economy	6300.00
0005433805907	3302	Economy	6300.00
0005433805920	3302	Economy	6300.00
0005432460177	3302	Economy	6300.00
0005433634344	3302	Economy	6300.00
0005432459815	3302	Economy	6300.00
0005433805893	3302	Economy	6300.00
0005433805918	3302	Economy	6300.00
0005433634351	3302	Economy	6300.00
0005432460150	3302	Economy	6300.00
0005433634340	3302	Economy	6300.00
0005432460273	3302	Economy	6300.00
0005433634346	3302	Economy	6900.00
0005432460351	3302	Economy	6900.00
0005433805899	3302	Economy	6900.00
0005433634342	3302	Economy	6900.00
0005432460013	3302	Economy	6300.00
0005433805914	3302	Economy	6900.00
0005432182065	3302	Economy	6300.00
0005433634338	3302	Economy	6300.00
0005433805892	3302	Economy	6300.00
0005432460274	3302	Economy	6300.00
0005432460226	3302	Economy	6300.00
0005432182064	3302	Economy	6300.00
0005432460332	3302	Economy	6300.00
0005432460180	3302	Economy	6300.00
0005433805908	3302	Economy	6300.00
0005432460269	3302	Economy	6300.00
0005432460132	3302	Economy	6300.00
0005433634341	3302	Economy	6300.00
0005432460296	3302	Economy	6300.00
0005433805916	3302	Economy	6300.00
0005432459828	3302	Economy	6300.00
0005433507445	3302	Economy	6300.00
0005433805887	3302	Economy	6300.00
0005432460282	3302	Economy	6300.00
0005432460216	3302	Economy	6300.00
0005433805921	3302	Economy	6300.00
0005433634353	3302	Economy	6300.00
0005433634356	3302	Economy	6300.00
0005432182050	3302	Economy	6300.00
0005433805894	3302	Economy	6300.00
0005432459814	3302	Economy	6300.00
0005433805902	3302	Economy	6300.00
0005432460149	3302	Economy	6300.00
0005433634360	3302	Economy	6300.00
0005432182058	3302	Economy	6300.00
0005432460209	3302	Economy	6300.00
0005433634333	3302	Economy	6300.00
0005432182052	3302	Economy	6300.00
0005433507444	3302	Economy	6300.00
0005432182062	3302	Economy	6300.00
0005432460210	3302	Economy	6300.00
0005433634336	3302	Economy	6300.00
0005433805910	3302	Economy	6300.00
0005433634334	3302	Economy	6300.00
0005432460350	3302	Economy	6300.00
0005432460059	3302	Economy	6300.00
0005432182063	3302	Economy	6300.00
0005433805888	3302	Economy	6300.00
0005433634343	3302	Economy	6300.00
0005432460222	3302	Economy	6300.00
0005433634331	3302	Economy	6300.00
0005433634337	3302	Economy	6300.00
0005433805909	3302	Economy	6300.00
0005432182059	3302	Economy	6300.00
0005432182068	3302	Economy	6300.00
0005433805889	3302	Economy	6300.00
0005432460268	3302	Economy	6300.00
0005432460025	3302	Economy	6300.00
0005432182057	3302	Economy	6300.00
0005433634357	3302	Economy	6300.00
0005432182053	3302	Economy	6300.00
0005433634352	3302	Economy	6300.00
0005432460305	3302	Economy	6300.00
0005433634347	3302	Economy	6300.00
0005433805900	3302	Economy	6300.00
0005432460224	3302	Economy	6300.00
0005432460036	3302	Economy	6300.00
0005433634354	3302	Economy	6300.00
0005433634362	3302	Economy	6300.00
0005435885511	3303	Business	18800.00
0005435885647	3303	Business	18800.00
0005435885612	3303	Business	18800.00
0005435885590	3303	Business	18800.00
0005435885563	3303	Business	18800.00
0005435885517	3303	Business	18800.00
0005435885603	3303	Business	18800.00
0005435885778	3303	Economy	6900.00
0005435885632	3303	Economy	6900.00
0005435885539	3303	Economy	6900.00
0005435885658	3303	Economy	6900.00
0005435885711	3303	Economy	6300.00
0005435885651	3303	Economy	6300.00
0005435885631	3303	Economy	6300.00
0005435885701	3303	Economy	6300.00
0005435885558	3303	Economy	6300.00
0005435885702	3303	Economy	6300.00
0005435885636	3303	Economy	6300.00
0005435885604	3303	Economy	6300.00
0005435885637	3303	Economy	6300.00
0005435885635	3303	Economy	6300.00
0005435885557	3303	Economy	6300.00
0005435885803	3303	Economy	6300.00
0005435885772	3303	Economy	6300.00
0005435885467	3303	Economy	6300.00
0005435885700	3303	Economy	6900.00
0005435885576	3303	Economy	6300.00
0005435885860	3303	Economy	6300.00
0005435885684	3303	Economy	6300.00
0005435885683	3303	Economy	6300.00
0005435885677	3303	Economy	6300.00
0005435885639	3303	Economy	6300.00
0005435885744	3303	Economy	6300.00
0005435885905	3303	Economy	6300.00
0005435885554	3303	Economy	6300.00
0005435885630	3303	Economy	6300.00
0005435885771	3303	Economy	6300.00
0005435885795	3303	Economy	6300.00
0005435885575	3303	Economy	6300.00
0005435885564	3303	Economy	6300.00
0005435885468	3303	Economy	6300.00
0005435885743	3303	Economy	6300.00
0005435885453	3303	Economy	6300.00
0005435885831	3303	Economy	6300.00
0005435885859	3303	Economy	6300.00
0005435885646	3303	Economy	6300.00
0005435885975	8246	Business	18800.00
0005435885980	8246	Business	18800.00
0005433507198	8246	Business	18800.00
0005435886005	8246	Business	18800.00
0005433507239	8246	Business	18800.00
0005434312352	8246	Business	18800.00
0005433507342	8246	Business	18800.00
0005435885994	8246	Business	18800.00
0005432460700	8246	Business	18800.00
0005433507249	8246	Business	18800.00
0005432460711	8246	Business	18800.00
0005432460693	8246	Business	18800.00
0005432042937	8246	Business	18800.00
0005435885974	8246	Business	18800.00
0005433507248	8246	Business	18800.00
0005432460718	8246	Business	18800.00
0005435886003	8246	Business	18800.00
0005432460697	8246	Business	18800.00
0005435886015	8246	Business	18800.00
0005432460666	8246	Business	18800.00
0005432460674	8246	Business	18800.00
0005432460698	8246	Business	18800.00
0005432460692	8246	Business	18800.00
0005435885986	8246	Economy	6900.00
0005435885983	8246	Economy	6900.00
0005432460679	8246	Economy	6900.00
0005433507285	8246	Economy	6900.00
0005432042926	8246	Economy	6900.00
0005432460713	8246	Economy	6300.00
0005432460687	8246	Economy	6300.00
0005432460708	8246	Economy	6300.00
0005432460681	8246	Economy	6300.00
0005432042923	8246	Economy	6300.00
0005432460689	8246	Economy	6300.00
0005435886012	8246	Economy	6300.00
0005435885989	8246	Economy	6300.00
0005432460685	8246	Economy	6300.00
0005432460694	8246	Economy	6300.00
0005435886007	8246	Economy	6300.00
0005432460707	8246	Economy	6300.00
0005432460703	8246	Economy	6300.00
0005433507344	8246	Economy	6300.00
0005435885976	8246	Economy	6300.00
0005432042932	8246	Economy	6300.00
0005432460682	8246	Economy	6300.00
0005435886001	8246	Economy	6300.00
0005432460710	8246	Economy	6300.00
0005432460668	8246	Economy	6300.00
0005435886008	8246	Economy	6300.00
0005435885987	8246	Economy	6300.00
0005435885985	8246	Economy	6300.00
0005432460695	8246	Economy	6300.00
0005435885998	8246	Economy	6300.00
0005433507231	8246	Economy	6300.00
0005435885982	8246	Economy	6300.00
0005435886004	8246	Economy	6300.00
0005433507275	8246	Economy	6300.00
0005433507358	8246	Economy	6300.00
0005433507378	8246	Economy	6300.00
0005432460716	8246	Economy	6300.00
0005433507273	8246	Economy	6300.00
0005432460677	8246	Economy	6300.00
0005435885991	8246	Economy	6300.00
0005432460678	8246	Economy	6300.00
0005433507311	8246	Economy	6300.00
0005433507339	8246	Economy	6300.00
0005433507225	8246	Economy	6300.00
0005433507276	8246	Economy	6300.00
0005432460680	8246	Economy	6300.00
0005432460691	8246	Economy	6300.00
0005432460704	8246	Economy	6300.00
0005432460715	8246	Economy	6300.00
0005432042924	8246	Economy	6300.00
0005432460709	8246	Economy	6300.00
0005432042928	8246	Economy	6300.00
0005435885984	8246	Economy	6300.00
0005433507318	8246	Economy	6300.00
0005433507357	8246	Economy	6300.00
0005433507340	8246	Economy	6900.00
0005432042936	8246	Economy	6900.00
0005433507302	8246	Economy	6900.00
0005435886016	8246	Economy	6900.00
0005435885997	8246	Economy	6900.00
0005432460670	8246	Economy	6300.00
0005435885990	8246	Economy	6300.00
0005435885979	8246	Economy	6300.00
0005432460699	8246	Economy	6300.00
0005432042934	8246	Economy	6900.00
0005432460690	8246	Economy	6300.00
0005435886011	8246	Economy	6300.00
0005432460701	8246	Economy	6300.00
0005432460688	8246	Economy	6300.00
0005433507308	8246	Economy	6300.00
0005432460669	8246	Economy	6300.00
0005433507319	8246	Economy	6300.00
0005432042929	8246	Economy	6300.00
0005433507224	8246	Economy	6300.00
0005435885999	8246	Economy	6300.00
0005435885988	8246	Economy	6300.00
0005432460712	8246	Economy	6300.00
0005435886010	8246	Economy	6300.00
0005432460714	8246	Economy	6300.00
0005432460676	8246	Economy	6300.00
0005435885993	8246	Economy	6300.00
0005435885992	8246	Economy	6300.00
0005432460705	8246	Economy	6300.00
0005433507361	8246	Economy	6300.00
0005432460683	8246	Economy	6300.00
0005435886000	8246	Economy	6300.00
0005435885977	8246	Economy	6300.00
0005432042931	8246	Economy	6300.00
0005435886014	8246	Economy	6300.00
0005432042925	8246	Economy	6300.00
0005432460706	8246	Economy	6300.00
0005432460673	8246	Economy	6300.00
0005433507314	8246	Economy	6300.00
0005435886009	8246	Economy	6300.00
0005435885996	8246	Economy	6300.00
0005432042927	8246	Economy	6300.00
0005432460686	8246	Economy	6300.00
0005435886002	8246	Economy	6300.00
0005432460675	8246	Economy	6300.00
0005435886006	8246	Economy	6300.00
0005432460696	8246	Economy	6300.00
0005433507313	8246	Economy	6300.00
0005432460667	8246	Economy	6300.00
0005433507366	8246	Economy	6300.00
0005435885978	8246	Economy	6300.00
0005432460672	8246	Economy	6300.00
0005432042935	8246	Economy	6300.00
0005432042933	8246	Economy	6300.00
0005432042930	8246	Economy	6300.00
0005433507272	8246	Economy	6300.00
0005435885995	8246	Economy	6300.00
0005432460717	8246	Economy	6300.00
0005434312353	8246	Economy	6300.00
0005433507274	8246	Economy	6300.00
0005432460702	8246	Economy	6300.00
0005432460684	8246	Economy	6300.00
0005432460671	8246	Economy	6300.00
0005435885981	8246	Economy	6300.00
0005435886013	8246	Economy	6300.00
0005433507377	8246	Economy	6300.00
0005433805652	8253	Business	18800.00
0005433805698	8253	Business	18800.00
0005433634092	8253	Business	18800.00
0005433633962	8253	Business	18800.00
0005433805687	8253	Business	18800.00
0005433805641	8253	Business	18800.00
0005433805684	8253	Business	18800.00
0005433634054	8253	Business	18800.00
0005434271332	8253	Business	18800.00
0005433805651	8253	Business	18800.00
0005433633961	8253	Business	18800.00
0005433634087	8253	Business	18800.00
0005433633904	8253	Economy	6900.00
0005433634187	8253	Economy	6900.00
0005433634028	8253	Economy	6900.00
0005433805685	8253	Economy	6900.00
0005433634108	8253	Economy	6900.00
0005433634078	8253	Economy	6300.00
0005433634142	8253	Economy	6300.00
0005433634043	8253	Economy	6300.00
0005433805688	8253	Economy	6300.00
0005434143735	8253	Economy	6300.00
0005433634062	8253	Economy	6300.00
0005433634029	8253	Economy	6300.00
0005433805763	8253	Economy	6300.00
0005433634066	8253	Economy	6300.00
0005433634039	8253	Economy	6300.00
0005433805594	8253	Economy	6300.00
0005433805452	8253	Economy	6300.00
0005433634112	8253	Economy	6300.00
0005433634027	8253	Economy	6300.00
0005433633976	8253	Economy	6300.00
0005433805783	8253	Economy	6300.00
0005433805555	8253	Economy	6300.00
0005433634055	8253	Economy	6300.00
0005433634096	8253	Economy	6300.00
0005433634093	8253	Economy	6300.00
0005433805650	8253	Economy	6300.00
0005433634034	8253	Economy	6300.00
0005433805699	8253	Economy	6300.00
0005433805582	8253	Economy	6300.00
0005433805576	8253	Economy	6300.00
0005433805511	8253	Economy	6900.00
0005433633893	8253	Economy	6900.00
0005433633894	8253	Economy	6300.00
0005434271326	8253	Economy	6300.00
0005433805680	8253	Economy	6300.00
0005433633839	8253	Economy	6300.00
0005433634091	8253	Economy	6300.00
0005433634110	8253	Economy	6300.00
0005433805586	8253	Economy	6300.00
0005433634109	8253	Economy	6300.00
0005433805557	8253	Economy	6300.00
0005433805538	8253	Economy	6300.00
0005433805740	8253	Economy	6300.00
0005433805581	8253	Economy	6300.00
0005433805782	8253	Economy	6300.00
0005434271325	8253	Economy	6300.00
0005433634076	8253	Economy	6300.00
0005433805700	8253	Economy	6300.00
0005433805460	8253	Economy	6300.00
0005433634007	8253	Economy	6300.00
0005433805461	8253	Economy	6300.00
0005433634044	8253	Economy	6300.00
0005433634095	8253	Economy	6300.00
0005433805654	8253	Economy	6300.00
0005433634107	8253	Economy	6300.00
0005433805686	8253	Economy	6300.00
0005433805549	8253	Economy	6300.00
0005433805587	8253	Economy	6300.00
0005433633903	8253	Economy	6300.00
0005433805548	8253	Economy	6300.00
0005433633838	8253	Economy	6300.00
0005433805679	8253	Economy	6300.00
0005433805681	8253	Economy	6300.00
0005433805642	8253	Economy	6300.00
0005433805558	8253	Economy	6300.00
0005433634038	8253	Economy	6300.00
0005433634037	8253	Economy	6300.00
0005432383771	4589	Business	9900.00
0005432383772	4589	Business	9900.00
0005432383767	4589	Business	9900.00
0005432728131	4589	Business	9900.00
0005432728134	4589	Business	9900.00
0005432728136	4589	Business	9900.00
0005432383754	4589	Business	9900.00
0005432728126	4589	Business	9900.00
0005432383768	4589	Business	9900.00
0005432383751	4589	Business	9900.00
0005432728132	4589	Economy	3300.00
0005433453793	4589	Economy	3300.00
0005432383783	4589	Economy	3300.00
0005432383763	4589	Economy	3300.00
0005432383790	4589	Economy	3300.00
0005432383756	4589	Economy	3300.00
0005432383760	4589	Economy	3300.00
0005432383770	4589	Economy	3300.00
0005432383789	4589	Economy	3600.00
0005432728128	4589	Economy	3600.00
0005433722320	4589	Economy	3600.00
0005433454909	4589	Economy	3600.00
0005432728137	4589	Economy	3300.00
0005433453791	4589	Economy	3300.00
0005432383785	4589	Economy	3300.00
0005432728130	4589	Economy	3300.00
0005432728135	4589	Economy	3300.00
0005432383753	4589	Economy	3300.00
0005432383777	4589	Economy	3300.00
0005433722319	4589	Economy	3300.00
0005432383791	4589	Economy	3300.00
0005433453792	4589	Economy	3300.00
0005432383755	4589	Economy	3300.00
0005432383752	4589	Economy	3300.00
0005432383769	4589	Economy	3300.00
0005433722321	4589	Economy	3300.00
0005433722329	4589	Economy	3300.00
0005432383773	4589	Economy	3300.00
0005433722327	4589	Economy	3300.00
0005432383786	4589	Economy	3300.00
0005432383761	4589	Economy	3300.00
0005432383779	4589	Economy	3300.00
0005432383782	4589	Economy	3300.00
0005432383780	4589	Economy	3300.00
0005432383762	4589	Economy	3300.00
0005432383750	4589	Economy	3300.00
0005432728127	4589	Economy	3300.00
0005432383759	4589	Economy	3300.00
0005432728129	4589	Economy	3300.00
0005432383758	4589	Economy	3300.00
0005432383776	4589	Economy	3300.00
0005432383787	4589	Economy	3300.00
0005433454908	4589	Economy	3300.00
0005433722322	4589	Economy	3300.00
0005433453790	4589	Economy	3300.00
0005433722325	4589	Economy	3300.00
0005432383757	4589	Economy	3300.00
0005433722323	4589	Economy	3300.00
0005432383781	4589	Economy	3300.00
0005432383784	4589	Economy	3300.00
0005433722328	4589	Economy	3300.00
0005433722324	4589	Economy	3300.00
0005432383774	4589	Economy	3300.00
0005432383765	4589	Economy	3300.00
0005433722326	4589	Economy	3300.00
0005432383775	4589	Economy	3300.00
0005432728133	4589	Economy	3300.00
0005432383778	4589	Economy	3300.00
0005432383788	4589	Economy	3300.00
0005432383764	4589	Economy	3300.00
0005432383766	4589	Economy	3300.00
0005432383333	30087	Business	9900.00
0005432383403	30087	Business	9900.00
0005432383266	30087	Business	9900.00
0005432383140	30087	Business	9900.00
0005433451633	30087	Business	9900.00
0005432728033	30087	Business	9900.00
0005432383267	30087	Business	9900.00
0005432383234	30087	Business	9900.00
0005432728078	30087	Business	9900.00
0005432383261	30087	Economy	3300.00
0005432383402	30087	Economy	3300.00
0005432383400	30087	Economy	3300.00
0005432383326	30087	Economy	3300.00
0005433722238	30087	Economy	3600.00
0005432383275	30087	Economy	3600.00
0005432383274	30087	Economy	3600.00
0005432728005	30087	Economy	3300.00
0005433453772	30087	Economy	3300.00
0005432383297	30087	Economy	3300.00
0005433451636	30087	Economy	3300.00
0005432727973	30087	Economy	3300.00
0005432383273	30087	Economy	3300.00
0005432383368	30087	Economy	3300.00
0005433194858	30087	Economy	3300.00
0005433194859	30087	Economy	3300.00
0005432383376	30087	Economy	3300.00
0005432383235	30087	Economy	3300.00
0005433722250	30087	Economy	3300.00
0005432383279	30087	Economy	3300.00
0005432383302	30087	Economy	3300.00
0005432727974	30087	Economy	3300.00
0005432383522	30087	Economy	3300.00
0005433722237	30087	Economy	3300.00
0005432383233	30087	Economy	3300.00
0005432728077	30087	Economy	3300.00
0005432383421	30087	Economy	3300.00
0005432383375	30087	Economy	3300.00
0005432383439	30087	Economy	3300.00
0005432383230	30087	Economy	3300.00
0005432728002	30087	Economy	3300.00
0005432727972	30087	Economy	3300.00
0005432383229	30087	Economy	3300.00
0005432383444	30087	Economy	3300.00
0005433722217	30087	Economy	3300.00
0005432383399	30087	Economy	3300.00
0005432383236	30087	Economy	3300.00
0005433722231	30087	Economy	3300.00
0005432728027	30087	Economy	3300.00
0005432728058	30087	Economy	3300.00
0005433194861	30087	Economy	3300.00
0005432728059	30087	Economy	3300.00
0005433451628	30087	Economy	3300.00
0005433451640	30087	Economy	3300.00
0005432383315	30087	Economy	3300.00
0005432383265	30087	Economy	3300.00
0005432383314	30087	Economy	3300.00
0005432383190	30087	Economy	3300.00
0005433453777	30087	Economy	3300.00
0005433451630	30087	Economy	3300.00
0005433722230	30087	Economy	3300.00
0005432383523	30087	Economy	3300.00
0005432383440	30087	Economy	3300.00
0005433451626	30087	Economy	3300.00
0005432728001	30087	Economy	3300.00
0005432383139	30087	Economy	3300.00
0005435541334	1762	Business	57200.00
0005432925081	1762	Business	57200.00
0005433517031	1762	Business	57200.00
0005435541351	1762	Business	57200.00
0005432925075	1762	Business	57200.00
0005435541346	1762	Business	57200.00
0005435541342	1762	Business	57200.00
0005435541350	1762	Economy	19100.00
0005435541337	1762	Economy	19100.00
0005435529598	1762	Economy	19100.00
0005435529605	1762	Economy	19100.00
0005435529590	1762	Economy	19100.00
0005435541349	1762	Economy	21000.00
0005435541347	1762	Economy	21000.00
0005433517036	1762	Economy	21000.00
0005435529588	1762	Economy	21000.00
0005432294524	1762	Economy	21000.00
0005433517029	1762	Economy	19100.00
0005435541341	1762	Economy	19100.00
0005433517034	1762	Economy	19100.00
0005435529602	1762	Economy	19100.00
0005435529589	1762	Economy	19100.00
0005435529603	1762	Economy	19100.00
0005435541353	1762	Economy	19100.00
0005435529604	1762	Economy	19100.00
0005435529977	1762	Economy	19100.00
0005435541336	1762	Economy	19100.00
0005435529976	1762	Economy	19100.00
0005433517033	1762	Economy	19100.00
0005435529601	1762	Economy	19100.00
0005435541348	1762	Economy	19100.00
0005435529592	1762	Economy	19100.00
0005435541344	1762	Economy	19100.00
0005433517032	1762	Economy	19100.00
0005435529599	1762	Economy	19100.00
0005435541333	1762	Economy	19100.00
0005433517035	1762	Economy	19100.00
0005435529608	1762	Economy	19100.00
0005435529596	1762	Economy	19100.00
0005435541340	1762	Economy	19100.00
0005433517030	1762	Economy	19100.00
0005435541343	1762	Economy	19100.00
0005435529591	1762	Economy	19100.00
0005435529593	1762	Economy	19100.00
0005435541338	1762	Economy	19100.00
0005432294525	1762	Economy	19100.00
0005435529607	1762	Economy	19100.00
0005435529606	1762	Economy	19100.00
0005435541332	1762	Economy	19100.00
0005435541352	1762	Economy	19100.00
0005432925080	1762	Economy	19100.00
0005435541339	1762	Economy	19100.00
0005435529595	1762	Economy	19100.00
0005435541335	1762	Economy	19100.00
0005435529609	1762	Economy	19100.00
0005435541345	1762	Economy	19100.00
0005435529594	1762	Economy	19100.00
0005433517028	1762	Economy	19100.00
0005435529600	1762	Economy	19100.00
0005435529978	1762	Economy	19100.00
0005432925074	1762	Economy	19100.00
0005432925082	1762	Economy	19100.00
0005435529597	1762	Economy	19100.00
0005435541121	21973	Business	57200.00
0005435541136	21973	Business	57200.00
0005435541166	21973	Business	57200.00
0005432925108	21973	Business	57200.00
0005435541074	21973	Business	57200.00
0005435518048	21973	Business	57200.00
0005435518030	21973	Business	57200.00
0005435517973	21973	Business	57200.00
0005435541060	21973	Business	57200.00
0005435541081	21973	Business	57200.00
0005435518067	21973	Economy	19100.00
0005435541122	21973	Economy	19100.00
0005435541088	21973	Economy	19100.00
0005435541103	21973	Economy	19100.00
0005433516953	21973	Economy	19100.00
0005432925112	21973	Economy	19100.00
0005435541087	21973	Economy	19100.00
0005435518007	21973	Economy	19100.00
0005435541231	21973	Economy	21000.00
0005435541150	21973	Economy	21000.00
0005435518031	21973	Economy	21000.00
0005433516964	21973	Economy	21000.00
0005435541203	21973	Economy	19100.00
0005435541085	21973	Economy	19100.00
0005435518032	21973	Economy	19100.00
0005433516916	21973	Economy	19100.00
0005433516959	21973	Economy	19100.00
0005433516956	21973	Economy	19100.00
0005433516947	21973	Economy	19100.00
0005435517990	21973	Economy	19100.00
0005435541106	21973	Economy	19100.00
0005432925113	21973	Economy	19100.00
0005433516963	21973	Economy	19100.00
0005435517999	21973	Economy	19100.00
0005435541267	21973	Economy	19100.00
0005435517966	21973	Economy	19100.00
0005435541080	21973	Economy	19100.00
0005435541146	21973	Economy	19100.00
0005435541075	21973	Economy	19100.00
0005435541151	21973	Economy	19100.00
0005435517972	21973	Economy	19100.00
0005435518083	21973	Economy	19100.00
0005435518033	21973	Economy	19100.00
0005433516957	21973	Economy	19100.00
0005435518008	21973	Economy	19100.00
0005433516965	21973	Economy	19100.00
0005435518000	21973	Economy	19100.00
0005432925111	21973	Economy	19100.00
0005435517965	21973	Economy	19100.00
0005435518090	21973	Economy	19100.00
0005435541114	21973	Economy	19100.00
0005435518099	21973	Economy	19100.00
0005435518070	21973	Economy	19100.00
0005435518041	21973	Economy	19100.00
0005435541082	21973	Economy	19100.00
0005435541162	21973	Economy	19100.00
0005435541157	21973	Economy	19100.00
0005433516949	21973	Economy	19100.00
0005435541196	21973	Economy	19100.00
0005433516970	21973	Economy	19100.00
0005435540978	21973	Economy	19100.00
0005432925109	21973	Economy	19100.00
0005432925110	21973	Economy	19100.00
0005435541232	21973	Economy	19100.00
0005435252825	7394	Business	18500.00
0005435491448	7394	Business	18500.00
0005434459117	7394	Business	18500.00
0005432839528	7394	Business	18500.00
0005432841044	7394	Business	18500.00
0005432839525	7394	Business	18500.00
0005435252847	7394	Business	18500.00
0005432839522	7394	Business	18500.00
0005432839503	7394	Business	18500.00
0005432823480	7394	Economy	6200.00
0005435252819	7394	Economy	6200.00
0005432839518	7394	Economy	6200.00
0005435252780	7394	Economy	6200.00
0005432073443	7394	Economy	6200.00
0005432839523	7394	Economy	6200.00
0005434459135	7394	Economy	6200.00
0005432839513	7394	Economy	6200.00
0005434459128	7394	Economy	6200.00
0005432839519	7394	Economy	6800.00
0005432839500	7394	Economy	6800.00
0005432839505	7394	Economy	6800.00
0005434459132	7394	Economy	6800.00
0005435252778	7394	Economy	6800.00
0005434459133	7394	Economy	6200.00
0005432839526	7394	Economy	6200.00
0005432839514	7394	Economy	6200.00
0005432839512	7394	Economy	6200.00
0005432073445	7394	Economy	6200.00
0005432839516	7394	Economy	6200.00
0005432073442	7394	Economy	6200.00
0005434459125	7394	Economy	6200.00
0005432839529	7394	Economy	6200.00
0005434459121	7394	Economy	6200.00
0005432073444	7394	Economy	6200.00
0005435252810	7394	Economy	6200.00
0005432839515	7394	Economy	6200.00
0005435252748	7394	Economy	6200.00
0005432839509	7394	Economy	6200.00
0005435252771	7394	Economy	6200.00
0005432839517	7394	Economy	6200.00
0005434459124	7394	Economy	6200.00
0005434664972	7394	Economy	6200.00
0005435252779	7394	Economy	6200.00
0005435252809	7394	Economy	6200.00
0005434459120	7394	Economy	6200.00
0005434459123	7394	Economy	6200.00
0005434459127	7394	Economy	6200.00
0005435252806	7394	Economy	6200.00
0005432839527	7394	Economy	6200.00
0005432839511	7394	Economy	6200.00
0005434459119	7394	Economy	6200.00
0005434459118	7394	Economy	6200.00
0005432841043	7394	Economy	6200.00
0005435252784	7394	Economy	6200.00
0005434459116	7394	Economy	6200.00
0005432839510	7394	Economy	6200.00
0005435252820	7394	Economy	6200.00
0005432839504	7394	Economy	6200.00
0005432839499	7394	Economy	6200.00
0005432839521	7394	Economy	6200.00
0005435491444	7394	Economy	6200.00
0005435252830	7394	Economy	6200.00
0005434459126	7394	Economy	6200.00
0005435252811	7394	Economy	6200.00
0005434459134	7394	Economy	6200.00
0005432839507	7394	Economy	6200.00
0005434459115	7394	Economy	6200.00
0005432839506	7394	Economy	6200.00
0005432839520	7394	Economy	6200.00
0005434459136	7394	Economy	6200.00
0005434459130	7394	Economy	6200.00
0005432839502	7394	Economy	6200.00
0005434459131	7394	Economy	6200.00
0005432839508	7394	Economy	6200.00
0005435252747	7394	Economy	6200.00
0005435252767	7394	Economy	6200.00
0005434459129	7394	Economy	6200.00
0005434459122	7394	Economy	6200.00
0005432839501	7394	Economy	6200.00
0005435252766	7394	Economy	6200.00
0005432839530	7394	Economy	6200.00
0005432839524	7394	Economy	6200.00
0005432841026	28916	Business	18500.00
0005432839257	28916	Business	18500.00
0005434458911	28916	Business	18500.00
0005435491474	28916	Business	18500.00
0005434458926	28916	Business	18500.00
0005432839327	28916	Business	18500.00
0005432839196	28916	Business	18500.00
0005434458976	28916	Business	18500.00
0005435252985	28916	Business	18500.00
0005432839322	28916	Business	18500.00
0005432823470	28916	Business	18500.00
0005434458965	28916	Business	18500.00
0005435252984	28916	Economy	6200.00
0005434458979	28916	Economy	6200.00
0005434458879	28916	Economy	6200.00
0005435252974	28916	Economy	6200.00
0005434458989	28916	Economy	6200.00
0005434459018	28916	Economy	6200.00
0005432839179	28916	Economy	6200.00
0005432839294	28916	Economy	6200.00
0005434458988	28916	Economy	6200.00
0005432839369	28916	Economy	6200.00
0005432839237	28916	Economy	6800.00
0005434458943	28916	Economy	6800.00
0005432839318	28916	Economy	6800.00
0005432839255	28916	Economy	6800.00
0005434458923	28916	Economy	6200.00
0005435252983	28916	Economy	6200.00
0005434459025	28916	Economy	6200.00
0005432839256	28916	Economy	6200.00
0005432839244	28916	Economy	6200.00
0005432839226	28916	Economy	6200.00
0005434458878	28916	Economy	6200.00
0005432839323	28916	Economy	6200.00
0005432823456	28916	Economy	6200.00
0005435491473	28916	Economy	6200.00
0005435252968	28916	Economy	6200.00
0005434458849	28916	Economy	6200.00
0005432839267	28916	Economy	6200.00
0005435252975	28916	Economy	6200.00
0005432839314	28916	Economy	6200.00
0005435252978	28916	Economy	6200.00
0005435252973	28916	Economy	6200.00
0005432839133	28916	Economy	6200.00
0005435252969	28916	Economy	6200.00
0005432839269	28916	Economy	6200.00
0005435252976	28916	Economy	6200.00
0005434458848	28916	Economy	6200.00
0005432839268	28916	Economy	6200.00
0005434664996	28916	Economy	6200.00
0005432823457	28916	Economy	6200.00
0005434458978	28916	Economy	6200.00
0005434458921	28916	Economy	6200.00
0005432839370	28916	Economy	6200.00
0005432839238	28916	Economy	6200.00
0005432839212	28916	Economy	6200.00
0005435252979	28916	Economy	6200.00
0005432001055	28916	Economy	6200.00
0005434458912	28916	Economy	6200.00
0005435252971	28916	Economy	6200.00
0005434458922	28916	Economy	6200.00
0005435252977	28916	Economy	6200.00
0005435252981	28916	Economy	6200.00
0005434458869	28916	Economy	6200.00
0005432839290	28916	Economy	6200.00
0005432839139	28916	Economy	6200.00
0005435252972	28916	Economy	6200.00
0005432839319	28916	Economy	6200.00
0005432839304	28916	Economy	6200.00
0005432839236	28916	Economy	6200.00
0005432839243	28916	Economy	6200.00
0005432001054	28916	Economy	6200.00
0005434458944	28916	Economy	6200.00
0005432841031	28916	Economy	6200.00
0005432839134	28916	Economy	6200.00
0005435252982	28916	Economy	6200.00
0005434458868	28916	Economy	6200.00
0005435252970	28916	Economy	6200.00
0005434458946	28916	Economy	6200.00
0005434458945	28916	Economy	6200.00
0005432839253	28916	Economy	6200.00
0005432839278	28916	Economy	6200.00
0005432001053	28916	Economy	6200.00
0005434458977	28916	Economy	6200.00
0005432839195	28916	Economy	6200.00
0005435252980	28916	Economy	6200.00
0005435990730	8799	Business	145300.00
0005435990732	8799	Economy	48400.00
0005435990734	8799	Economy	48400.00
0005435990735	8799	Economy	48400.00
0005435990736	8799	Economy	48400.00
0005435990733	8799	Economy	48400.00
0005435990731	8799	Economy	48400.00
0005434276055	8799	Economy	48400.00
0005435990737	8799	Economy	48400.00
0005434276085	8799	Economy	48400.00
0005434276113	15723	Business	145300.00
0005435990696	15723	Business	145300.00
0005435990671	15723	Business	145300.00
0005435990635	15723	Business	145300.00
0005435990689	15723	Business	145300.00
0005434276115	15723	Economy	48400.00
0005434276117	15723	Economy	48400.00
0005434276114	15723	Economy	48400.00
0005434276118	15723	Economy	48400.00
0005435990697	15723	Economy	48400.00
0005434276116	15723	Economy	48400.00
0005435990681	15723	Economy	48400.00
0005434276119	15723	Economy	48400.00
0005432427154	30838	Economy	15900.00
0005433476924	30838	Economy	14500.00
0005433476922	30838	Economy	14500.00
0005433476921	30838	Economy	14500.00
0005433476923	30838	Economy	14500.00
0005433476925	30838	Economy	14500.00
0005433476926	30838	Economy	14500.00
0005433468372	23848	Economy	13300.00
0005433468417	23848	Economy	13300.00
0005432909368	23848	Economy	13300.00
0005433468368	23848	Economy	12100.00
0005432909360	23848	Economy	12100.00
0005433468389	23848	Economy	12100.00
0005432909362	23848	Economy	12100.00
0005433468345	23848	Economy	12100.00
0005433468370	23848	Economy	12100.00
0005432909363	23848	Economy	12100.00
0005433468424	23848	Economy	12100.00
0005432909359	23848	Economy	12100.00
0005432909366	23848	Economy	12100.00
0005433468422	23848	Economy	12100.00
0005433468388	23848	Economy	12100.00
0005433468369	23848	Economy	12100.00
0005432909365	23848	Economy	12100.00
0005433468398	23848	Economy	12100.00
0005433468392	23848	Economy	12100.00
0005432909361	23848	Economy	12100.00
0005433468390	23848	Economy	12100.00
0005433468393	23848	Economy	12100.00
0005432909369	23848	Economy	12100.00
0005433468425	23848	Economy	12100.00
0005433468371	23848	Economy	12100.00
0005432909364	23848	Economy	12100.00
0005432909367	23848	Economy	12100.00
0005432361082	6358	Business	36600.00
0005435177334	6358	Business	36600.00
0005432361089	6358	Business	36600.00
0005435177369	6358	Business	36600.00
0005432361107	6358	Business	36600.00
0005432361081	6358	Business	36600.00
0005435177363	6358	Business	36600.00
0005435177170	6358	Business	36600.00
0005432361090	6358	Business	36600.00
0005432363467	6358	Business	36600.00
0005435177359	6358	Economy	12200.00
0005432361095	6358	Economy	12200.00
0005435177333	6358	Economy	12200.00
0005435177293	6358	Economy	12200.00
0005435177251	6358	Economy	12200.00
0005432336221	6358	Economy	12200.00
0005435177365	6358	Economy	12200.00
0005435177314	6358	Economy	12200.00
0005435177250	6358	Economy	12200.00
0005432361120	6358	Economy	12200.00
0005432336218	6358	Economy	12200.00
0005432361093	6358	Economy	12200.00
0005432336217	6358	Economy	12200.00
0005432361126	6358	Economy	12200.00
0005435177313	6358	Economy	12200.00
0005435177222	6358	Economy	12200.00
0005432361102	6358	Economy	12200.00
0005432361109	6358	Economy	12200.00
0005435177238	6358	Economy	12200.00
0005432361085	6358	Economy	12200.00
0005432336214	6358	Economy	12200.00
0005432361100	6358	Economy	12200.00
0005432361125	6358	Economy	12200.00
0005435177328	6358	Economy	12200.00
0005432361113	6358	Economy	12200.00
0005432361114	6358	Economy	12200.00
0005432361106	6358	Economy	12200.00
0005432361105	6358	Economy	12200.00
0005432361111	6358	Economy	12200.00
0005432361110	6358	Economy	12200.00
0005432062309	6358	Economy	12200.00
0005434149818	6358	Economy	12200.00
0005435177265	6358	Economy	13400.00
0005432361080	6358	Economy	12200.00
0005432361122	6358	Economy	13400.00
0005435177270	6358	Economy	13400.00
0005432062310	6358	Economy	13400.00
0005432361094	6358	Economy	13400.00
0005432062311	6358	Economy	13400.00
0005432336212	6358	Economy	12200.00
0005432361121	6358	Economy	12200.00
0005432361118	6358	Economy	12200.00
0005432361083	6358	Economy	12200.00
0005432361097	6358	Economy	12200.00
0005435723061	6358	Economy	12200.00
0005432336219	6358	Economy	12200.00
0005435177169	6358	Economy	12200.00
0005435177269	6358	Economy	12200.00
0005432361104	6358	Economy	12200.00
0005432361099	6358	Economy	12200.00
0005432361101	6358	Economy	12200.00
0005435177171	6358	Economy	12200.00
0005435177295	6358	Economy	12200.00
0005434149773	6358	Economy	12200.00
0005432062308	6358	Economy	12200.00
0005435177339	6358	Economy	12200.00
0005432336223	6358	Economy	12200.00
0005434149819	6358	Economy	12200.00
0005432361119	6358	Economy	12200.00
0005432361103	6358	Economy	12200.00
0005434149804	6358	Economy	12200.00
0005432361084	6358	Economy	12200.00
0005435177329	6358	Economy	12200.00
0005432361086	6358	Economy	12200.00
0005435177376	6358	Economy	12200.00
0005432062312	6358	Economy	12200.00
0005432361096	6358	Economy	12200.00
0005434149772	6358	Economy	12200.00
0005432336220	6358	Economy	12200.00
0005432336215	6358	Economy	12200.00
0005435177347	6358	Economy	12200.00
0005435177337	6358	Economy	12200.00
0005434149806	6358	Economy	12200.00
0005432361124	6358	Economy	12200.00
0005435177284	6358	Economy	12200.00
0005435490250	6358	Economy	12200.00
0005432361116	6358	Economy	12200.00
0005432361117	6358	Economy	12200.00
0005432361098	6358	Economy	12200.00
0005432062313	6358	Economy	12200.00
0005432361115	6358	Economy	12200.00
0005435177294	6358	Economy	12200.00
0005432361088	6358	Economy	12200.00
0005432361112	6358	Economy	12200.00
0005435177340	6358	Economy	12200.00
0005432361108	6358	Economy	12200.00
0005432336216	6358	Economy	12200.00
0005432363466	6358	Economy	12200.00
0005435177259	6358	Economy	12200.00
0005432361091	6358	Economy	12200.00
0005432361127	6358	Economy	12200.00
0005432361128	6358	Economy	12200.00
0005435177287	6358	Economy	12200.00
0005435177330	6358	Economy	12200.00
0005432361087	6358	Economy	12200.00
0005435177264	6358	Economy	12200.00
0005432336213	6358	Economy	12200.00
0005435177292	6358	Economy	12200.00
0005432361123	6358	Economy	12200.00
0005435177283	6358	Economy	12200.00
0005434149874	6358	Economy	12200.00
0005435177239	6358	Economy	12200.00
0005432361092	6358	Economy	12200.00
0005435177260	6358	Economy	12200.00
0005435177370	6358	Economy	12200.00
0005432336222	6358	Economy	12200.00
0005432360660	21008	Business	36600.00
0005432360893	21008	Business	36600.00
0005432360628	21008	Business	36600.00
0005432336143	21008	Business	36600.00
0005432360698	21008	Business	36600.00
0005432336144	21008	Business	36600.00
0005435723078	21008	Business	36600.00
0005432360498	21008	Business	36600.00
0005432336125	21008	Business	36600.00
0005435177513	21008	Business	36600.00
0005435177512	21008	Business	36600.00
0005434149912	21008	Business	36600.00
0005435177505	21008	Economy	12200.00
0005432360710	21008	Economy	12200.00
0005435177488	21008	Economy	12200.00
0005435177491	21008	Economy	12200.00
0005435177514	21008	Economy	12200.00
0005435177507	21008	Economy	12200.00
0005432336081	21008	Economy	12200.00
0005432360676	21008	Economy	12200.00
0005432360720	21008	Economy	12200.00
0005432360577	21008	Economy	12200.00
0005432360694	21008	Economy	12200.00
0005432360730	21008	Economy	12200.00
0005434149915	21008	Economy	12200.00
0005432360562	21008	Economy	12200.00
0005435177494	21008	Economy	12200.00
0005435177511	21008	Economy	12200.00
0005432052793	21008	Economy	12200.00
0005435177490	21008	Economy	12200.00
0005435177489	21008	Economy	12200.00
0005432360576	21008	Economy	12200.00
0005432360843	21008	Economy	12200.00
0005432360795	21008	Economy	12200.00
0005432360623	21008	Economy	12200.00
0005435177503	21008	Economy	12200.00
0005434149906	21008	Economy	12200.00
0005432360432	21008	Economy	12200.00
0005432360608	21008	Economy	12200.00
0005432363430	21008	Economy	12200.00
0005432052794	21008	Economy	12200.00
0005432360804	21008	Economy	12200.00
0005435490288	21008	Economy	12200.00
0005435177497	21008	Economy	12200.00
0005432360549	21008	Economy	12200.00
0005432336115	21008	Economy	12200.00
0005432363442	21008	Economy	12200.00
0005432336168	21008	Economy	12200.00
0005432360867	21008	Economy	12200.00
0005432336128	21008	Economy	12200.00
0005435490289	21008	Economy	12200.00
0005432363434	21008	Economy	12200.00
0005432336107	21008	Economy	13400.00
0005432360827	21008	Economy	13400.00
0005432360805	21008	Economy	13400.00
0005432360602	21008	Economy	13400.00
0005432360732	21008	Economy	13400.00
0005432336126	21008	Economy	13400.00
0005434149910	21008	Economy	12200.00
0005432360796	21008	Economy	12200.00
0005432363431	21008	Economy	12200.00
0005435177487	21008	Economy	12200.00
0005432360709	21008	Economy	12200.00
0005435177510	21008	Economy	12200.00
0005435177486	21008	Economy	12200.00
0005435723077	21008	Economy	12200.00
0005432360729	21008	Economy	12200.00
0005432336112	21008	Economy	12200.00
0005432360740	21008	Economy	12200.00
0005435490287	21008	Economy	12200.00
0005432360431	21008	Economy	12200.00
0005432336110	21008	Economy	12200.00
0005432360793	21008	Economy	12200.00
0005435177500	21008	Economy	12200.00
0005435177501	21008	Economy	12200.00
0005432336111	21008	Economy	12200.00
0005432336080	21008	Economy	12200.00
0005435177506	21008	Economy	12200.00
0005435177504	21008	Economy	12200.00
0005435177496	21008	Economy	12200.00
0005432360702	21008	Economy	12200.00
0005432360575	21008	Economy	12200.00
0005435177492	21008	Economy	12200.00
0005434149914	21008	Economy	12200.00
0005434149911	21008	Economy	12200.00
0005432336160	21008	Economy	12200.00
0005432336109	21008	Economy	12200.00
0005432336159	21008	Economy	12200.00
0005432360741	21008	Economy	12200.00
0005432360779	21008	Economy	12200.00
0005432360801	21008	Economy	12200.00
0005432052792	21008	Economy	12200.00
0005432360607	21008	Economy	12200.00
0005432363429	21008	Economy	12200.00
0005435177509	21008	Economy	12200.00
0005432336106	21008	Economy	12200.00
0005435177495	21008	Economy	12200.00
0005432360806	21008	Economy	12200.00
0005432360866	21008	Economy	12200.00
0005434149909	21008	Economy	12200.00
0005432360606	21008	Economy	12200.00
0005432336129	21008	Economy	12200.00
0005432360764	21008	Economy	12200.00
0005432360548	21008	Economy	12200.00
0005432336120	21008	Economy	12200.00
0005435177499	21008	Economy	12200.00
0005432360828	21008	Economy	12200.00
0005432360807	21008	Economy	12200.00
0005432360668	21008	Economy	12200.00
0005435177493	21008	Economy	12200.00
0005432360802	21008	Economy	12200.00
0005434149913	21008	Economy	12200.00
0005435177502	21008	Economy	12200.00
0005435177498	21008	Economy	12200.00
0005432360794	21008	Economy	12200.00
0005432360579	21008	Economy	12200.00
0005434149908	21008	Economy	12200.00
0005432363443	21008	Economy	12200.00
0005434149917	21008	Economy	12200.00
0005434149916	21008	Economy	12200.00
0005432360659	21008	Economy	12200.00
0005432336092	21008	Economy	12200.00
0005435490290	21008	Economy	12200.00
0005432336121	21008	Economy	12200.00
0005432360460	21008	Economy	12200.00
0005434149907	21008	Economy	12200.00
0005434149905	21008	Economy	12200.00
0005432360733	21008	Economy	12200.00
0005432363437	21008	Economy	12200.00
0005435177508	21008	Economy	12200.00
0005434458892	17739	Economy	3400.00
0005434458949	17739	Economy	3400.00
0005434458884	17739	Economy	3400.00
0005434458994	17739	Economy	3100.00
0005434458971	17739	Economy	3100.00
0005434458839	17739	Economy	3100.00
0005434459006	17739	Economy	3100.00
0005434186245	17739	Economy	3100.00
0005434458960	17739	Economy	3100.00
0005434458972	17739	Economy	3100.00
0005434186243	17739	Economy	3100.00
0005434448331	17739	Economy	3100.00
0005434458883	17739	Economy	3100.00
0005434458893	17739	Economy	3100.00
0005434458961	17739	Economy	3100.00
0005434186244	17739	Economy	3100.00
0005434458958	17739	Economy	3100.00
0005434186246	17739	Economy	3100.00
0005434463938	17739	Economy	3100.00
0005434186247	17739	Economy	3100.00
0005434458957	17739	Economy	3100.00
0005434448329	17739	Economy	3100.00
0005434458991	17739	Economy	3100.00
0005434461667	17739	Economy	3100.00
0005434459008	17739	Economy	3100.00
0005434458947	17739	Economy	3100.00
0005434459009	17739	Economy	3100.00
0005434458970	17739	Economy	3100.00
0005434458995	17739	Economy	3100.00
0005434448330	17739	Economy	3100.00
0005434448366	29116	Economy	3400.00
0005434448364	29116	Economy	3400.00
0005434459128	29116	Economy	3400.00
0005434459133	29116	Economy	3100.00
0005434448367	29116	Economy	3100.00
0005434459127	29116	Economy	3100.00
0005434459116	29116	Economy	3100.00
0005434459117	29116	Economy	3100.00
0005434459120	29116	Economy	3100.00
0005434459132	29116	Economy	3100.00
0005434459134	29116	Economy	3100.00
0005434459136	29116	Economy	3100.00
0005434459125	29116	Economy	3100.00
0005434462822	29116	Economy	3100.00
0005434459129	29116	Economy	3100.00
0005434459118	29116	Economy	3100.00
0005434459122	29116	Economy	3100.00
0005434459121	29116	Economy	3100.00
0005434448363	29116	Economy	3100.00
0005434459119	29116	Economy	3100.00
0005434463962	29116	Economy	3100.00
0005434463961	29116	Economy	3100.00
0005434459124	29116	Economy	3100.00
0005434448365	29116	Economy	3100.00
0005434462821	29116	Economy	3100.00
0005434459130	29116	Economy	3100.00
0005434186221	29116	Economy	3100.00
0005434459123	29116	Economy	3100.00
0005434459131	29116	Economy	3100.00
0005434459126	29116	Economy	3100.00
0005434459135	29116	Economy	3100.00
0005434459115	29116	Economy	3100.00
0005434186217	29116	Economy	3100.00
0005434186218	29116	Economy	3100.00
0005434186211	29116	Economy	3100.00
0005432658586	21833	Business	185300.00
0005432661915	21833	Business	185300.00
0005432661914	21833	Business	185300.00
0005432665278	21833	Business	185300.00
0005432658579	21833	Business	185300.00
0005432661911	21833	Business	185300.00
0005432661918	21833	Economy	61800.00
0005432658590	21833	Economy	61800.00
0005432658600	21833	Economy	61800.00
0005432665272	21833	Economy	61800.00
0005432665270	21833	Economy	61800.00
0005432661900	21833	Economy	61800.00
0005432661922	21833	Economy	67900.00
0005432658588	21833	Economy	61800.00
0005432658601	21833	Economy	61800.00
0005432658578	21833	Economy	61800.00
0005432665262	21833	Economy	61800.00
0005432661923	21833	Economy	61800.00
0005432665261	21833	Economy	61800.00
0005432658583	21833	Economy	61800.00
0005432658582	21833	Economy	61800.00
0005432658584	21833	Economy	61800.00
0005432665274	21833	Economy	61800.00
0005432661919	21833	Economy	61800.00
0005432665279	21833	Economy	61800.00
0005432658592	21833	Economy	61800.00
0005432665273	21833	Economy	61800.00
0005432658591	21833	Economy	61800.00
0005432658572	21833	Economy	61800.00
0005432665271	21833	Economy	61800.00
0005432665264	21833	Economy	61800.00
0005432658585	21833	Economy	61800.00
0005432658589	21833	Economy	61800.00
0005432661924	21833	Economy	61800.00
0005432665263	21833	Economy	61800.00
0005432665269	21833	Economy	61800.00
0005432665275	21833	Economy	61800.00
0005432658587	21833	Economy	61800.00
0005432604907	21421	Economy	7300.00
0005432604930	21421	Economy	7300.00
0005432604914	21421	Economy	7300.00
0005432604922	21421	Economy	7300.00
0005432604931	21421	Economy	6600.00
0005432604936	21421	Economy	6600.00
0005432604937	21421	Economy	6600.00
0005432604938	21421	Economy	6600.00
0005432604915	21421	Economy	6600.00
0005432604924	21421	Economy	6600.00
0005432604919	21421	Economy	6600.00
0005432604902	21421	Economy	6600.00
0005435218117	21421	Economy	6600.00
0005432604939	21421	Economy	6600.00
0005432604926	21421	Economy	6600.00
0005432604905	21421	Economy	6600.00
0005432604933	21421	Economy	6600.00
0005432604908	21421	Economy	6600.00
0005432604916	21421	Economy	6600.00
0005432604910	21421	Economy	6600.00
0005432604913	21421	Economy	6600.00
0005432604904	21421	Economy	6600.00
0005432604928	21421	Economy	6600.00
0005432604932	21421	Economy	6600.00
0005432604903	21421	Economy	6600.00
0005432604923	21421	Economy	6600.00
0005432604935	21421	Economy	6600.00
0005432604929	21421	Economy	6600.00
0005432604927	21421	Economy	6600.00
0005432604921	21421	Economy	6600.00
0005432604925	21421	Economy	6600.00
0005432604909	21421	Economy	6600.00
0005432604911	21421	Economy	6600.00
0005432604917	21421	Economy	6600.00
0005432604920	21421	Economy	6600.00
0005432604901	21421	Economy	6600.00
0005432604912	21421	Economy	6600.00
0005432604906	21421	Economy	6600.00
0005432604918	21421	Economy	6600.00
0005432604934	21421	Economy	6600.00
0005432604900	21421	Economy	6600.00
0005432604652	31689	Economy	7300.00
0005432604731	31689	Economy	7300.00
0005432604604	31689	Economy	7300.00
0005432604552	31689	Economy	7300.00
0005432604576	31689	Economy	6600.00
0005432604625	31689	Economy	6600.00
0005432604517	31689	Economy	6600.00
0005432604644	31689	Economy	6600.00
0005432604710	31689	Economy	6600.00
0005432604656	31689	Economy	6600.00
0005432604579	31689	Economy	6600.00
0005432604755	31689	Economy	6600.00
0005432604672	31689	Economy	6600.00
0005432604666	31689	Economy	6600.00
0005432604607	31689	Economy	6600.00
0005432604506	31689	Economy	6600.00
0005432604615	31689	Economy	6600.00
0005432604507	31689	Economy	6600.00
0005432604614	31689	Economy	6600.00
0005432604747	31689	Economy	6600.00
0005432604651	31689	Economy	6600.00
0005432604488	31689	Economy	6600.00
0005432604642	31689	Economy	6600.00
0005432604515	31689	Economy	6600.00
0005432604553	31689	Economy	6600.00
0005432604693	31689	Economy	6600.00
0005432604806	31689	Economy	6600.00
0005432604574	31689	Economy	6600.00
0005432604748	31689	Economy	6600.00
0005432604494	31689	Economy	6600.00
0005432604564	31689	Economy	6600.00
0005432604805	31689	Economy	6600.00
0005432604709	31689	Economy	6600.00
0005432604492	31689	Economy	6600.00
0005432604464	31689	Economy	6600.00
0005432604536	31689	Economy	6600.00
0005432604575	31689	Economy	6600.00
0005432604732	31689	Economy	6600.00
0005432604845	31689	Economy	6600.00
0005432604505	31689	Economy	6600.00
0005432604684	31689	Economy	6600.00
0005432604523	31689	Economy	6600.00
0005432604694	31689	Economy	6600.00
0005432604493	31689	Economy	6600.00
0005432604685	31689	Economy	6600.00
0005432604754	31689	Economy	6600.00
0005433293338	29605	Economy	19500.00
0005433293349	29605	Economy	17800.00
0005433293351	29605	Economy	17800.00
0005433293345	29605	Economy	17800.00
0005433293342	29605	Economy	17800.00
0005433293340	29605	Economy	17800.00
0005433293341	29605	Economy	17800.00
0005433293350	29605	Economy	17800.00
0005433293346	29605	Economy	17800.00
0005433293343	29605	Economy	17800.00
0005433293348	29605	Economy	17800.00
0005433293344	29605	Economy	17800.00
0005433293347	29605	Economy	17800.00
0005433293339	29605	Economy	17800.00
0005435154597	29605	Economy	17800.00
0005435154596	29605	Economy	17800.00
0005433293337	29605	Economy	17800.00
0005435257250	6677	Economy	14000.00
0005433473395	6677	Economy	14000.00
0005433473398	6677	Economy	14000.00
0005435257259	6677	Economy	12700.00
0005433473409	6677	Economy	12700.00
0005435257270	6677	Economy	12700.00
0005433473397	6677	Economy	12700.00
0005433473404	6677	Economy	12700.00
0005433473407	6677	Economy	12700.00
0005435257268	6677	Economy	12700.00
0005433473408	6677	Economy	12700.00
0005435257252	6677	Economy	12700.00
0005433473412	6677	Economy	12700.00
0005433473400	6677	Economy	12700.00
0005433473413	6677	Economy	12700.00
0005433473410	6677	Economy	12700.00
0005433473406	6677	Economy	12700.00
0005433473402	6677	Economy	12700.00
0005435257266	6677	Economy	12700.00
0005435257269	6677	Economy	12700.00
0005433473399	6677	Economy	12700.00
0005433473401	6677	Economy	12700.00
0005435257280	6677	Economy	12700.00
0005433473396	6677	Economy	12700.00
0005433473403	6677	Economy	12700.00
0005433473411	6677	Economy	12700.00
0005433473405	6677	Economy	12700.00
0005435257251	6677	Economy	12700.00
0005435257274	6677	Economy	12700.00
0005435257276	6677	Economy	12700.00
0005435257312	23884	Economy	14000.00
0005435257311	23884	Economy	14000.00
0005433473343	23884	Economy	12700.00
0005435257308	23884	Economy	12700.00
0005433473322	23884	Economy	12700.00
0005435257316	23884	Economy	12700.00
0005435257309	23884	Economy	12700.00
0005433473325	23884	Economy	12700.00
0005433473312	23884	Economy	12700.00
0005433473323	23884	Economy	12700.00
0005433473294	23884	Economy	12700.00
0005433473341	23884	Economy	12700.00
0005435257313	23884	Economy	12700.00
0005435257317	23884	Economy	12700.00
0005433473310	23884	Economy	12700.00
0005433473339	23884	Economy	12700.00
0005433473344	23884	Economy	12700.00
0005433473311	23884	Economy	12700.00
0005433473304	23884	Economy	12700.00
0005435257310	23884	Economy	12700.00
0005433473313	23884	Economy	12700.00
0005433473303	23884	Economy	12700.00
0005433473295	23884	Economy	12700.00
0005435257314	23884	Economy	12700.00
0005435257307	23884	Economy	12700.00
0005435257315	23884	Economy	12700.00
0005433473338	23884	Economy	12700.00
0005434606834	18831	Economy	6600.00
0005434606836	18831	Economy	6600.00
0005434606857	18831	Economy	6600.00
0005434606856	18831	Economy	6600.00
0005434606837	18831	Economy	6600.00
0005434604947	22323	Economy	6600.00
0005434604948	22323	Economy	6600.00
0005435904704	22323	Economy	6600.00
0005434604949	22323	Economy	6600.00
0005434606878	22323	Economy	6600.00
0005434602937	3853	Economy	22600.00
0005435904423	3853	Economy	22600.00
0005434602936	3853	Economy	22600.00
0005434522503	3853	Economy	22600.00
0005434522506	3853	Economy	22600.00
0005435904427	3853	Economy	22600.00
0005435904424	3853	Economy	22600.00
0005434602935	3853	Economy	22600.00
0005434522502	3853	Economy	22600.00
0005434602939	3853	Economy	22600.00
0005434522499	3853	Economy	22600.00
0005434522501	3853	Economy	22600.00
0005434602938	3853	Economy	22600.00
0005434522500	3853	Economy	22600.00
0005435904420	3853	Economy	22600.00
0005434602934	3853	Economy	22600.00
0005434522505	3853	Economy	22600.00
0005434522504	3853	Economy	22600.00
0005434604916	19052	Economy	24900.00
0005434604918	19052	Economy	24900.00
0005434522476	19052	Economy	24900.00
0005434522460	19052	Economy	22600.00
0005435904713	19052	Economy	22600.00
0005435904712	19052	Economy	22600.00
0005434602911	19052	Economy	22600.00
0005434604919	19052	Economy	22600.00
0005435904444	19052	Economy	22600.00
0005434602917	19052	Economy	22600.00
0005434522477	19052	Economy	22600.00
0005434522483	19052	Economy	22600.00
0005434604904	19052	Economy	22600.00
0005434604917	19052	Economy	22600.00
0005435904442	19052	Economy	22600.00
0005434604924	19052	Economy	22600.00
0005435904445	19052	Economy	22600.00
0005434522444	19052	Economy	22600.00
0005435904711	19052	Economy	22600.00
0005435904443	19052	Economy	22600.00
0005434522461	19052	Economy	22600.00
0005434604921	19052	Economy	22600.00
0005434604915	19052	Economy	22600.00
0005432748142	400	Business	44500.00
0005432748163	400	Business	44500.00
0005432891144	400	Business	44500.00
0005432748141	400	Business	44500.00
0005432748155	400	Business	44500.00
0005432751577	400	Business	44500.00
0005432751575	400	Business	44500.00
0005432891099	400	Business	44500.00
0005435154625	400	Business	44500.00
0005432220067	400	Business	44500.00
0005435154624	400	Business	44500.00
0005432891161	400	Economy	14800.00
0005432748159	400	Economy	14800.00
0005432748134	400	Economy	14800.00
0005432891134	400	Economy	14800.00
0005432748139	400	Economy	14800.00
0005432748164	400	Economy	14800.00
0005432748165	400	Economy	14800.00
0005432891124	400	Economy	14800.00
0005432891182	400	Economy	14800.00
0005432748156	400	Economy	14800.00
0005432748128	400	Economy	16300.00
0005432748154	400	Economy	16300.00
0005432891076	400	Economy	16300.00
0005432748137	400	Economy	16300.00
0005432891091	400	Economy	14800.00
0005432891190	400	Economy	14800.00
0005432891107	400	Economy	14800.00
0005432891145	400	Economy	14800.00
0005432748136	400	Economy	14800.00
0005432891072	400	Economy	14800.00
0005432891103	400	Economy	14800.00
0005432748138	400	Economy	14800.00
0005433293256	400	Economy	14800.00
0005432748157	400	Economy	14800.00
0005432748152	400	Economy	14800.00
0005432749817	400	Economy	14800.00
0005432891096	400	Economy	14800.00
0005432748150	400	Economy	14800.00
0005432891248	400	Economy	14800.00
0005432748149	400	Economy	14800.00
0005432748148	400	Economy	14800.00
0005432891102	400	Economy	14800.00
0005432748161	400	Economy	14800.00
0005432753349	400	Economy	14800.00
0005432748133	400	Economy	14800.00
0005432748144	400	Economy	14800.00
0005432748158	400	Economy	14800.00
0005432891114	400	Economy	14800.00
0005432220069	400	Economy	14800.00
0005432748146	400	Economy	14800.00
0005432891166	400	Economy	14800.00
0005432891050	400	Economy	14800.00
0005432748129	400	Economy	14800.00
0005432891092	400	Economy	14800.00
0005432891170	400	Economy	14800.00
0005432891077	400	Economy	14800.00
0005432748160	400	Economy	14800.00
0005432891196	400	Economy	14800.00
0005432751576	400	Economy	14800.00
0005435154626	400	Economy	14800.00
0005432891086	400	Economy	14800.00
0005432220066	400	Economy	14800.00
0005432220070	400	Economy	14800.00
0005432220068	400	Economy	14800.00
0005432891181	400	Economy	14800.00
0005432748151	400	Economy	14800.00
0005432891115	400	Economy	14800.00
0005432748131	400	Economy	14800.00
0005432748132	400	Economy	14800.00
0005432748143	400	Economy	14800.00
0005432748147	400	Economy	14800.00
0005432751574	400	Economy	14800.00
0005432748135	400	Economy	14800.00
0005432748153	400	Economy	14800.00
0005432748145	400	Economy	14800.00
0005432749816	400	Economy	14800.00
0005432891073	400	Economy	14800.00
0005432891100	400	Economy	14800.00
0005433293244	400	Economy	14800.00
0005432891090	400	Economy	14800.00
0005433293306	400	Economy	14800.00
0005432748130	400	Economy	14800.00
0005432748140	400	Economy	14800.00
0005432753350	400	Economy	14800.00
0005433293269	400	Economy	14800.00
0005432891093	400	Economy	14800.00
0005432748162	400	Economy	14800.00
0005432753337	12043	Business	44500.00
0005434153552	12043	Business	44500.00
0005432747864	12043	Business	44500.00
0005432747718	12043	Business	44500.00
0005432753326	12043	Business	44500.00
0005432891323	12043	Business	44500.00
0005432891321	12043	Business	44500.00
0005432747823	12043	Business	44500.00
0005433875402	12043	Economy	14800.00
0005432747967	12043	Economy	14800.00
0005432747806	12043	Economy	14800.00
0005432749796	12043	Economy	14800.00
0005432749799	12043	Economy	14800.00
0005432891329	12043	Economy	14800.00
0005432747981	12043	Economy	14800.00
0005432747940	12043	Economy	14800.00
0005432747839	12043	Economy	16300.00
0005432753320	12043	Economy	16300.00
0005432214836	12043	Economy	16300.00
0005432891319	12043	Economy	14800.00
0005432891320	12043	Economy	14800.00
0005432747698	12043	Economy	14800.00
0005432891328	12043	Economy	14800.00
0005432891325	12043	Economy	14800.00
0005432747822	12043	Economy	14800.00
0005432747732	12043	Economy	14800.00
0005432891322	12043	Economy	14800.00
0005432747933	12043	Economy	14800.00
0005432747745	12043	Economy	14800.00
0005432891326	12043	Economy	14800.00
0005432891318	12043	Economy	14800.00
0005432747830	12043	Economy	14800.00
0005432747876	12043	Economy	14800.00
0005432747966	12043	Economy	14800.00
0005432214837	12043	Economy	14800.00
0005432891315	12043	Economy	14800.00
0005432756879	12043	Economy	14800.00
0005432747928	12043	Economy	14800.00
0005432747807	12043	Economy	14800.00
0005432747890	12043	Economy	14800.00
0005434153550	12043	Economy	14800.00
0005432747955	12043	Economy	14800.00
0005434153553	12043	Economy	14800.00
0005432747914	12043	Economy	14800.00
0005432747631	12043	Economy	14800.00
0005434153551	12043	Economy	14800.00
0005432891313	12043	Economy	14800.00
0005432747958	12043	Economy	14800.00
0005432747909	12043	Economy	14800.00
0005432753322	12043	Economy	14800.00
0005432891327	12043	Economy	14800.00
0005432747850	12043	Economy	14800.00
0005432891316	12043	Economy	14800.00
0005432747699	12043	Economy	14800.00
0005432747980	12043	Economy	14800.00
0005432891314	12043	Economy	14800.00
0005432747918	12043	Economy	14800.00
0005432747840	12043	Economy	14800.00
0005432891312	12043	Economy	14800.00
0005432747915	12043	Economy	14800.00
0005433875403	12043	Economy	14800.00
0005432891317	12043	Economy	14800.00
0005432747910	12043	Economy	14800.00
0005432747979	12043	Economy	14800.00
0005432747771	12043	Economy	14800.00
0005432891324	12043	Economy	14800.00
0005432891311	12043	Economy	14800.00
0005432747926	12043	Economy	14800.00
0005432747996	12043	Economy	14800.00
0005433531347	18979	Economy	28200.00
0005433525198	18979	Economy	28200.00
0005433533363	18979	Economy	25700.00
0005433533362	18979	Economy	25700.00
0005433533364	18979	Economy	25700.00
0005433525201	18979	Economy	25700.00
0005433525196	18979	Economy	25700.00
0005433525199	18979	Economy	25700.00
0005433525194	18979	Economy	25700.00
0005433525192	18979	Economy	25700.00
0005433525200	18979	Economy	25700.00
0005433531348	18979	Economy	25700.00
0005433525195	18979	Economy	25700.00
0005433531349	18979	Economy	25700.00
0005433525197	18979	Economy	25700.00
0005433525202	18979	Economy	25700.00
0005433525193	18979	Economy	25700.00
0005433531322	32470	Economy	28200.00
0005432928070	32470	Economy	28200.00
0005433527287	32470	Economy	28200.00
0005432928073	32470	Economy	25700.00
0005433525073	32470	Economy	25700.00
0005433525082	32470	Economy	25700.00
0005433531337	32470	Economy	25700.00
0005432928072	32470	Economy	25700.00
0005433525110	32470	Economy	25700.00
0005433527288	32470	Economy	25700.00
0005433527284	32470	Economy	25700.00
0005433525111	32470	Economy	25700.00
0005433525129	32470	Economy	25700.00
0005432928069	32470	Economy	25700.00
0005432928071	32470	Economy	25700.00
0005433525121	32470	Economy	25700.00
0005433525103	32470	Economy	25700.00
0005433527283	32470	Economy	25700.00
0005433525116	32470	Economy	25700.00
0005433525099	32470	Economy	25700.00
0005433531323	32470	Economy	25700.00
0005432928074	32470	Economy	25700.00
0005435373867	5296	Business	84000.00
0005432121556	5296	Business	84000.00
0005434825478	5296	Business	84000.00
0005434825483	5296	Business	84000.00
0005435386626	5296	Business	84000.00
0005435373623	5296	Business	84000.00
0005434825551	5296	Business	84000.00
0005434825486	5296	Business	84000.00
0005434825513	5296	Business	84000.00
0005435373704	5296	Business	84000.00
0005435373600	5296	Business	84000.00
0005435373402	5296	Business	84000.00
0005435150250	5296	Business	84000.00
0005434825497	5296	Business	84000.00
0005434825500	5296	Business	84000.00
0005435150242	5296	Business	84000.00
0005434825581	5296	Business	84000.00
0005435373494	5296	Business	84000.00
0005435373921	5296	Business	84000.00
0005435150247	5296	Business	84000.00
0005435373876	5296	Comfort	47600.00
0005434825528	5296	Comfort	47600.00
0005434825503	5296	Comfort	47600.00
0005434825541	5296	Comfort	47600.00
0005434825477	5296	Comfort	47600.00
0005435179696	5296	Comfort	47600.00
0005434825557	5296	Comfort	47600.00
0005435299805	5296	Comfort	47600.00
0005434825491	5296	Comfort	47600.00
0005434831221	5296	Comfort	47600.00
0005434825547	5296	Comfort	47600.00
0005434825569	5296	Comfort	47600.00
0005432121551	5296	Comfort	47600.00
0005435373826	5296	Comfort	47600.00
0005434825480	5296	Comfort	47600.00
0005435150240	5296	Comfort	47600.00
0005432394167	5296	Comfort	47600.00
0005434825473	5296	Comfort	47600.00
0005435373845	5296	Comfort	47600.00
0005435373503	5296	Comfort	47600.00
0005435150237	5296	Comfort	47600.00
0005434825559	5296	Comfort	47600.00
0005434825506	5296	Comfort	47600.00
0005434825548	5296	Comfort	47600.00
0005434825544	5296	Comfort	47600.00
0005435735171	5296	Comfort	47600.00
0005434825566	5296	Comfort	47600.00
0005434825571	5296	Comfort	47600.00
0005434825484	5296	Economy	28000.00
0005434825531	5296	Economy	28000.00
0005434558418	5296	Economy	28000.00
0005432394165	5296	Economy	28000.00
0005432121550	5296	Economy	28000.00
0005432121555	5296	Economy	28000.00
0005434825588	5296	Economy	28000.00
0005434825502	5296	Economy	28000.00
0005435373468	5296	Economy	28000.00
0005434558412	5296	Economy	28000.00
0005435386634	5296	Economy	28000.00
0005434825574	5296	Economy	28000.00
0005435373933	5296	Economy	28000.00
0005435735160	5296	Economy	28000.00
0005432823462	5296	Economy	28000.00
0005432121547	5296	Economy	28000.00
0005434825472	5296	Economy	28000.00
0005435386615	5296	Economy	28000.00
0005434825590	5296	Economy	28000.00
0005434825580	5296	Economy	28000.00
0005435299796	5296	Economy	28000.00
0005434825529	5296	Economy	28000.00
0005434825591	5296	Economy	28000.00
0005435373763	5296	Economy	28000.00
0005434825578	5296	Economy	28000.00
0005435373802	5296	Economy	28000.00
0005434825595	5296	Economy	28000.00
0005435373483	5296	Economy	28000.00
0005435299798	5296	Economy	28000.00
0005435373502	5296	Economy	28000.00
0005434825518	5296	Economy	28000.00
0005434825554	5296	Economy	28000.00
0005434825532	5296	Economy	28000.00
0005435373401	5296	Economy	28000.00
0005434664995	5296	Economy	28000.00
0005435373804	5296	Economy	28000.00
0005432121549	5296	Economy	28000.00
0005435373586	5296	Economy	28000.00
0005435373649	5296	Economy	28000.00
0005432121553	5296	Economy	28000.00
0005435373655	5296	Economy	28000.00
0005434825487	5296	Economy	28000.00
0005435373459	5296	Economy	28000.00
0005434825577	5296	Economy	28000.00
0005435386584	5296	Economy	28000.00
0005434825542	5296	Economy	28000.00
0005435373437	5296	Economy	28000.00
0005434825537	5296	Economy	28000.00
0005435373651	5296	Economy	28000.00
0005434825538	5296	Economy	28000.00
0005435735161	5296	Economy	28000.00
0005432394166	5296	Economy	28000.00
0005435373805	5296	Economy	28000.00
0005434825511	5296	Economy	28000.00
0005434825526	5296	Economy	28000.00
0005435373587	5296	Economy	30800.00
0005435373715	5296	Economy	30800.00
0005434825556	5296	Economy	28000.00
0005434664994	5296	Economy	30800.00
0005435373577	5296	Economy	28000.00
0005434828737	5296	Economy	28000.00
0005435150238	5296	Economy	28000.00
0005434664993	5296	Economy	30800.00
0005434825594	5296	Economy	30800.00
0005434825540	5296	Economy	28000.00
0005434558417	5296	Economy	28000.00
0005434825555	5296	Economy	28000.00
0005434825479	5296	Economy	28000.00
0005434825489	5296	Economy	28000.00
0005434825509	5296	Economy	28000.00
0005434825576	5296	Economy	28000.00
0005434825558	5296	Economy	28000.00
0005434825585	5296	Economy	28000.00
0005435373844	5296	Economy	28000.00
0005435373458	5296	Economy	28000.00
0005434825562	5296	Economy	28000.00
0005434825524	5296	Economy	28000.00
0005434825596	5296	Economy	28000.00
0005434825573	5296	Economy	28000.00
0005435373557	5296	Economy	28000.00
0005435735181	5296	Economy	28000.00
0005434825589	5296	Economy	28000.00
0005435150239	5296	Economy	28000.00
0005434825488	5296	Economy	28000.00
0005434825549	5296	Economy	28000.00
0005435299820	5296	Economy	28000.00
0005435373901	5296	Economy	28000.00
0005435373687	5296	Economy	28000.00
0005434825474	5296	Economy	28000.00
0005435373686	5296	Economy	28000.00
0005434825501	5296	Economy	28000.00
0005434825546	5296	Economy	28000.00
0005434825563	5296	Economy	28000.00
0005435373927	5296	Economy	28000.00
0005434825527	5296	Economy	28000.00
0005435373757	5296	Economy	28000.00
0005435373752	5296	Economy	28000.00
0005434825516	5296	Economy	28000.00
0005434831220	5296	Economy	28000.00
0005434828738	5296	Economy	28000.00
0005435373801	5296	Economy	28000.00
0005434825564	5296	Economy	28000.00
0005435373531	5296	Economy	28000.00
0005432823469	5296	Economy	28000.00
0005434828736	5296	Economy	28000.00
0005434825560	5296	Economy	28000.00
0005434825530	5296	Economy	28000.00
0005434825552	5296	Economy	28000.00
0005435373505	5296	Economy	28000.00
0005434825514	5296	Economy	28000.00
0005435373558	5296	Economy	28000.00
0005434825525	5296	Economy	28000.00
0005432121548	5296	Economy	28000.00
0005435373775	5296	Economy	28000.00
0005435374021	5296	Economy	28000.00
0005434825593	5296	Economy	28000.00
0005434825543	5296	Economy	28000.00
0005432121552	5296	Economy	28000.00
0005434825481	5296	Economy	28000.00
0005434825534	5296	Economy	28000.00
0005434825568	5296	Economy	28000.00
0005435386589	5296	Economy	28000.00
0005434825494	5296	Economy	28000.00
0005435373532	5296	Economy	28000.00
0005435373554	5296	Economy	28000.00
0005434825592	5296	Economy	28000.00
0005435299797	5296	Economy	28000.00
0005434825550	5296	Economy	28000.00
0005435386586	5296	Economy	28000.00
0005435373656	5296	Economy	28000.00
0005434825492	5296	Economy	28000.00
0005435373501	5296	Economy	28000.00
0005435373703	5296	Economy	28000.00
0005434825535	5296	Economy	28000.00
0005434825561	5296	Economy	28000.00
0005435373699	5296	Economy	28000.00
0005434825512	5296	Economy	28000.00
0005434825553	5296	Economy	28000.00
0005435299795	5296	Economy	28000.00
0005435373635	5296	Economy	28000.00
0005434558415	5296	Economy	28000.00
0005432121545	5296	Economy	28000.00
0005434825575	5296	Economy	28000.00
0005434825510	5296	Economy	30800.00
0005434825476	5296	Economy	30800.00
0005434825470	5296	Economy	30800.00
0005434825523	5296	Economy	30800.00
0005434825584	5296	Economy	30800.00
0005435373688	5296	Economy	28000.00
0005432396306	5296	Economy	28000.00
0005434825520	5296	Economy	28000.00
0005434825485	5296	Economy	28000.00
0005434825468	5296	Economy	28000.00
0005434825490	5296	Economy	28000.00
0005435373700	5296	Economy	28000.00
0005434825482	5296	Economy	28000.00
0005435150241	5296	Economy	28000.00
0005434825469	5296	Economy	28000.00
0005434825565	5296	Economy	28000.00
0005434825471	5296	Economy	28000.00
0005435150245	5296	Economy	28000.00
0005435150236	5296	Economy	28000.00
0005434825587	5296	Economy	28000.00
0005434825504	5296	Economy	28000.00
0005432396304	5296	Economy	28000.00
0005434825508	5296	Economy	28000.00
0005434558416	5296	Economy	28000.00
0005432396305	5296	Economy	28000.00
0005432121544	5296	Economy	28000.00
0005434825475	5296	Economy	28000.00
0005434825499	5296	Economy	28000.00
0005434825572	5296	Economy	28000.00
0005434831219	5296	Economy	28000.00
0005434831218	5296	Economy	28000.00
0005435299793	5296	Economy	28000.00
0005434558411	5296	Economy	28000.00
0005435150248	5296	Economy	28000.00
0005435373881	5296	Economy	28000.00
0005435373984	5296	Economy	28000.00
0005432121557	5296	Economy	28000.00
0005434825521	5296	Economy	28000.00
0005435373630	5296	Economy	28000.00
0005434558414	5296	Economy	28000.00
0005434825586	5296	Economy	28000.00
0005434825570	5296	Economy	28000.00
0005435150243	5296	Economy	28000.00
0005434825515	5296	Economy	28000.00
0005434825498	5296	Economy	28000.00
0005435373639	5296	Economy	28000.00
0005434825495	5296	Economy	28000.00
0005435299794	5296	Economy	28000.00
0005434825539	5296	Economy	28000.00
0005432823463	5296	Economy	28000.00
0005434825507	5296	Economy	28000.00
0005434825519	5296	Economy	28000.00
0005434558413	5296	Economy	28000.00
0005435150246	5296	Economy	28000.00
0005435374028	5296	Economy	28000.00
0005434825583	5296	Economy	28000.00
0005435373905	5296	Economy	28000.00
0005434825579	5296	Economy	28000.00
0005435299804	5296	Economy	28000.00
0005434825536	5296	Economy	28000.00
0005435373666	5296	Economy	28000.00
0005434825522	5296	Economy	28000.00
0005434825545	5296	Economy	28000.00
0005434825533	5296	Economy	28000.00
0005434825582	5296	Economy	28000.00
0005435373479	5296	Economy	28000.00
0005435373634	5296	Economy	28000.00
0005435386585	5296	Economy	28000.00
0005434825567	5296	Economy	28000.00
0005434825493	5296	Economy	28000.00
0005435373457	5296	Economy	28000.00
0005434825517	5296	Economy	28000.00
0005435386590	5296	Economy	28000.00
0005435150249	5296	Economy	28000.00
0005435150244	5296	Economy	28000.00
0005434825496	5296	Economy	28000.00
0005432121554	5296	Economy	28000.00
0005435373415	5296	Economy	28000.00
0005435304186	5296	Economy	28000.00
0005432121546	5296	Economy	28000.00
0005434825505	5296	Economy	28000.00
0005435299819	5296	Economy	28000.00
0005435374251	9894	Business	84000.00
0005435374236	9894	Business	84000.00
0005434824514	9894	Business	84000.00
0005435150095	9894	Business	84000.00
0005435374252	9894	Business	84000.00
0005434558330	9894	Business	84000.00
0005435374283	9894	Business	84000.00
0005434824396	9894	Business	84000.00
0005435150130	9894	Business	84000.00
0005434825004	9894	Business	84000.00
0005434824517	9894	Business	84000.00
0005435150083	9894	Business	84000.00
0005434824575	9894	Business	84000.00
0005435374276	9894	Business	84000.00
0005434824122	9894	Business	84000.00
0005435374247	9894	Comfort	47600.00
0005432203171	9894	Business	84000.00
0005432396260	9894	Comfort	47600.00
0005434824384	9894	Comfort	47600.00
0005434824421	9894	Comfort	47600.00
0005435299849	9894	Comfort	47600.00
0005435150094	9894	Comfort	47600.00
0005435374272	9894	Comfort	47600.00
0005434824060	9894	Comfort	47600.00
0005434824546	9894	Comfort	47600.00
0005434824213	9894	Comfort	47600.00
0005434824389	9894	Comfort	47600.00
0005435661979	9894	Comfort	47600.00
0005434824554	9894	Comfort	47600.00
0005434824587	9894	Comfort	47600.00
0005435374271	9894	Comfort	47600.00
0005435386667	9894	Comfort	47600.00
0005435386671	9894	Comfort	47600.00
0005434824555	9894	Comfort	47600.00
0005434824388	9894	Comfort	47600.00
0005434824961	9894	Comfort	47600.00
0005434825076	9894	Comfort	47600.00
0005434824258	9894	Comfort	47600.00
0005434824480	9894	Comfort	47600.00
0005434824250	9894	Comfort	47600.00
0005434824840	9894	Comfort	47600.00
0005434824581	9894	Comfort	47600.00
0005434824536	9894	Comfort	47600.00
0005434558318	9894	Comfort	47600.00
0005434824515	9894	Comfort	47600.00
0005435374282	9894	Comfort	47600.00
0005434825003	9894	Comfort	47600.00
0005434558306	9894	Comfort	47600.00
0005434824047	9894	Comfort	47600.00
0005435661978	9894	Economy	28000.00
0005434824302	9894	Economy	28000.00
0005434824544	9894	Economy	28000.00
0005435150081	9894	Economy	28000.00
0005435179407	9894	Economy	28000.00
0005435374254	9894	Economy	28000.00
0005435150101	9894	Economy	28000.00
0005435374256	9894	Economy	28000.00
0005434824632	9894	Economy	28000.00
0005434824658	9894	Economy	28000.00
0005434824879	9894	Economy	28000.00
0005434824490	9894	Economy	28000.00
0005434824061	9894	Economy	28000.00
0005435374266	9894	Economy	28000.00
0005434824659	9894	Economy	28000.00
0005435299848	9894	Economy	28000.00
0005434824631	9894	Economy	28000.00
0005435374270	9894	Economy	28000.00
0005434824443	9894	Economy	28000.00
0005435374294	9894	Economy	28000.00
0005434824646	9894	Economy	28000.00
0005434558333	9894	Economy	28000.00
0005434824387	9894	Economy	28000.00
0005435374288	9894	Economy	28000.00
0005434823968	9894	Economy	28000.00
0005435374240	9894	Economy	28000.00
0005435302270	9894	Economy	28000.00
0005435374265	9894	Economy	28000.00
0005435386672	9894	Economy	28000.00
0005434824103	9894	Economy	28000.00
0005434824434	9894	Economy	28000.00
0005434558323	9894	Economy	28000.00
0005434824702	9894	Economy	28000.00
0005434824413	9894	Economy	28000.00
0005434824436	9894	Economy	28000.00
0005435374260	9894	Economy	28000.00
0005432396264	9894	Economy	28000.00
0005434558313	9894	Economy	28000.00
0005434824591	9894	Economy	28000.00
0005434824491	9894	Economy	28000.00
0005432203176	9894	Economy	28000.00
0005434824545	9894	Economy	28000.00
0005435374284	9894	Economy	28000.00
0005434824928	9894	Economy	28000.00
0005435374257	9894	Economy	28000.00
0005435150111	9894	Economy	28000.00
0005435374238	9894	Economy	28000.00
0005434824214	9894	Economy	28000.00
0005434823797	9894	Economy	28000.00
0005435374234	9894	Economy	28000.00
0005435661977	9894	Economy	28000.00
0005434824018	9894	Economy	28000.00
0005434824672	9894	Economy	28000.00
0005435374280	9894	Economy	28000.00
0005435150079	9894	Economy	28000.00
0005434824293	9894	Economy	28000.00
0005434824424	9894	Economy	30800.00
0005434824402	9894	Economy	28000.00
0005434824245	9894	Economy	28000.00
0005435150132	9894	Economy	28000.00
0005434824352	9894	Economy	28000.00
0005434823750	9894	Economy	30800.00
0005432203173	9894	Economy	30800.00
0005434824550	9894	Economy	28000.00
0005435661976	9894	Economy	28000.00
0005435374232	9894	Economy	28000.00
0005434824841	9894	Economy	28000.00
0005434824494	9894	Economy	28000.00
0005432823481	9894	Economy	28000.00
0005434824524	9894	Economy	28000.00
0005434824694	9894	Economy	28000.00
0005434824478	9894	Economy	28000.00
0005434824625	9894	Economy	28000.00
0005434824472	9894	Economy	28000.00
0005434824588	9894	Economy	28000.00
0005434824437	9894	Economy	28000.00
0005434824108	9894	Economy	28000.00
0005434824583	9894	Economy	28000.00
0005434824358	9894	Economy	28000.00
0005434824205	9894	Economy	28000.00
0005435374233	9894	Economy	28000.00
0005435302269	9894	Economy	28000.00
0005434824303	9894	Economy	28000.00
0005434824005	9894	Economy	28000.00
0005435374243	9894	Economy	28000.00
0005432203177	9894	Economy	28000.00
0005434824648	9894	Economy	28000.00
0005432396262	9894	Economy	28000.00
0005435150100	9894	Economy	28000.00
0005435735211	9894	Economy	28000.00
0005434824461	9894	Economy	28000.00
0005435374245	9894	Economy	28000.00
0005434824404	9894	Economy	28000.00
0005434558327	9894	Economy	28000.00
0005434824525	9894	Economy	28000.00
0005434824397	9894	Economy	28000.00
0005435374231	9894	Economy	28000.00
0005435150097	9894	Economy	28000.00
0005434558326	9894	Economy	28000.00
0005434558309	9894	Economy	28000.00
0005435386670	9894	Economy	28000.00
0005432203175	9894	Economy	28000.00
0005434824821	9894	Economy	28000.00
0005434824679	9894	Economy	28000.00
0005435374268	9894	Economy	28000.00
0005434824439	9894	Economy	28000.00
0005435374259	9894	Economy	28000.00
0005432203174	9894	Economy	28000.00
0005434824383	9894	Economy	28000.00
0005434824535	9894	Economy	28000.00
0005434824755	9894	Economy	28000.00
0005434824778	9894	Economy	28000.00
0005434824183	9894	Economy	28000.00
0005432823482	9894	Economy	28000.00
0005435302271	9894	Economy	28000.00
0005435374289	9894	Economy	28000.00
0005434558297	9894	Economy	28000.00
0005432396263	9894	Economy	28000.00
0005432396283	9894	Economy	28000.00
0005434558332	9894	Economy	28000.00
0005435374249	9894	Economy	28000.00
0005435374275	9894	Economy	28000.00
0005435374286	9894	Economy	28000.00
0005434824034	9894	Economy	28000.00
0005434558305	9894	Economy	28000.00
0005434824649	9894	Economy	28000.00
0005435386668	9894	Economy	28000.00
0005435374274	9894	Economy	28000.00
0005434824104	9894	Economy	28000.00
0005435299847	9894	Economy	28000.00
0005434824053	9894	Economy	28000.00
0005435150084	9894	Economy	28000.00
0005434824574	9894	Economy	28000.00
0005435179408	9894	Economy	28000.00
0005434824493	9894	Economy	28000.00
0005435374281	9894	Economy	28000.00
0005435150152	9894	Economy	28000.00
0005434824068	9894	Economy	28000.00
0005435374292	9894	Economy	28000.00
0005435374242	9894	Economy	28000.00
0005435374287	9894	Economy	28000.00
0005435386669	9894	Economy	28000.00
0005434824610	9894	Economy	28000.00
0005434824611	9894	Economy	30800.00
0005434824260	9894	Economy	30800.00
0005434824470	9894	Economy	30800.00
0005435374241	9894	Economy	30800.00
0005434824423	9894	Economy	30800.00
0005434558328	9894	Economy	28000.00
0005435374248	9894	Economy	28000.00
0005435374235	9894	Economy	28000.00
0005435374244	9894	Economy	28000.00
0005435374253	9894	Economy	28000.00
0005435299850	9894	Economy	28000.00
0005434824292	9894	Economy	28000.00
0005434823804	9894	Economy	28000.00
0005434824582	9894	Economy	28000.00
0005435150131	9894	Economy	28000.00
0005434824273	9894	Economy	28000.00
0005434824640	9894	Economy	28000.00
0005435386673	9894	Economy	28000.00
0005435302272	9894	Economy	28000.00
0005434824703	9894	Economy	28000.00
0005435374258	9894	Economy	28000.00
0005432400146	9894	Economy	28000.00
0005435374291	9894	Economy	28000.00
0005434824962	9894	Economy	28000.00
0005434824259	9894	Economy	28000.00
0005435374237	9894	Economy	28000.00
0005435735210	9894	Economy	28000.00
0005434824673	9894	Economy	28000.00
0005434824779	9894	Economy	28000.00
0005435374246	9894	Economy	28000.00
0005435374279	9894	Economy	28000.00
0005434824645	9894	Economy	28000.00
0005434824822	9894	Economy	28000.00
0005434824395	9894	Economy	28000.00
0005434824422	9894	Economy	28000.00
0005435150160	9894	Economy	28000.00
0005435735209	9894	Economy	28000.00
0005435374293	9894	Economy	28000.00
0005434824487	9894	Economy	28000.00
0005434824350	9894	Economy	28000.00
0005435374250	9894	Economy	28000.00
0005434824580	9894	Economy	28000.00
0005435374263	9894	Economy	28000.00
0005435374277	9894	Economy	28000.00
0005435374239	9894	Economy	28000.00
0005435374262	9894	Economy	28000.00
0005435150141	9894	Economy	28000.00
0005434823530	9894	Economy	28000.00
0005432400153	9894	Economy	28000.00
0005434824492	9894	Economy	28000.00
0005434824605	9894	Economy	28000.00
0005434824612	9894	Economy	28000.00
0005434824161	9894	Economy	28000.00
0005435374261	9894	Economy	28000.00
0005435150082	9894	Economy	28000.00
0005435374295	9894	Economy	28000.00
0005434824678	9894	Economy	28000.00
0005434558304	9894	Economy	28000.00
0005434823830	9894	Economy	28000.00
0005434824537	9894	Economy	28000.00
0005435374285	9894	Economy	28000.00
0005435374290	9894	Economy	28000.00
0005434824400	9894	Economy	28000.00
0005435374267	9894	Economy	28000.00
0005434824641	9894	Economy	28000.00
0005435374264	9894	Economy	28000.00
0005434823875	9894	Economy	28000.00
0005435661975	9894	Economy	28000.00
0005434824438	9894	Economy	28000.00
0005432400157	9894	Economy	28000.00
0005435374278	9894	Economy	28000.00
0005434824180	9894	Economy	28000.00
0005434824403	9894	Economy	28000.00
0005434664973	9894	Economy	28000.00
0005435374269	9894	Economy	28000.00
0005434558303	9894	Economy	28000.00
0005435150080	9894	Economy	28000.00
0005435374273	9894	Economy	28000.00
0005434558331	9894	Economy	28000.00
0005434823603	9894	Economy	28000.00
0005432203172	9894	Economy	28000.00
0005434824481	9894	Economy	28000.00
0005435735208	9894	Economy	28000.00
0005434823580	9894	Economy	28000.00
0005435374255	9894	Economy	28000.00
0005435082912	6970	Economy	8200.00
0005435082913	6970	Economy	7400.00
0005435082909	6970	Economy	7400.00
0005435790352	6970	Economy	7400.00
0005435082910	6970	Economy	7400.00
0005435082911	6970	Economy	7400.00
0005435082908	6970	Economy	7400.00
0005435082915	6970	Economy	7400.00
0005435790351	6970	Economy	7400.00
0005435082914	6970	Economy	7400.00
0005435790350	6970	Economy	7400.00
0005435082907	6970	Economy	7400.00
0005435082832	25972	Economy	7400.00
0005435082830	25972	Economy	7400.00
0005435082846	25972	Economy	7400.00
0005435082825	25972	Economy	7400.00
0005435082814	25972	Economy	7400.00
0005435790335	25972	Economy	7400.00
0005435082833	25972	Economy	7400.00
0005435790336	25972	Economy	7400.00
0005435082816	25972	Economy	7400.00
0005435082826	25972	Economy	7400.00
0005435082840	25972	Economy	7400.00
0005435082813	25972	Economy	7400.00
0005435790329	25972	Economy	7400.00
0005434757061	9543	Business	32800.00
0005434757083	9543	Business	32800.00
0005434757095	9543	Business	32800.00
0005434757098	9543	Business	32800.00
0005434757063	9543	Business	32800.00
0005434214780	9543	Economy	10900.00
0005434757075	9543	Economy	10900.00
0005434214930	9543	Economy	10900.00
0005434757069	9543	Economy	10900.00
0005434214948	9543	Economy	10900.00
0005434757090	9543	Economy	10900.00
0005434214549	9543	Economy	10900.00
0005434214796	9543	Economy	10900.00
0005434757064	9543	Economy	10900.00
0005434757086	9543	Economy	12000.00
0005434757070	9543	Economy	12000.00
0005434757071	9543	Economy	12000.00
0005434757094	9543	Economy	12000.00
0005434757062	9543	Economy	12000.00
0005434214912	9543	Economy	10900.00
0005434214832	9543	Economy	10900.00
0005434214883	9543	Economy	10900.00
0005434757080	9543	Economy	10900.00
0005434757099	9543	Economy	10900.00
0005434214880	9543	Economy	10900.00
0005434757054	9543	Economy	10900.00
0005434757084	9543	Economy	10900.00
0005434214911	9543	Economy	10900.00
0005434214630	9543	Economy	10900.00
0005434757066	9543	Economy	10900.00
0005434214779	9543	Economy	10900.00
0005434757073	9543	Economy	10900.00
0005434214888	9543	Economy	10900.00
0005434757096	9543	Economy	10900.00
0005434757053	9543	Economy	10900.00
0005434214910	9543	Economy	10900.00
0005434757081	9543	Economy	10900.00
0005434214754	9543	Economy	10900.00
0005434757060	9543	Economy	10900.00
0005434757072	9543	Economy	10900.00
0005434214768	9543	Economy	10900.00
0005434214672	9543	Economy	10900.00
0005434757087	9543	Economy	10900.00
0005434215002	9543	Economy	10900.00
0005434214882	9543	Economy	10900.00
0005434757059	9543	Economy	10900.00
0005434214837	9543	Economy	10900.00
0005434757093	9543	Economy	10900.00
0005434214617	9543	Economy	10900.00
0005434757088	9543	Economy	10900.00
0005434757077	9543	Economy	10900.00
0005434214929	9543	Economy	10900.00
0005434757089	9543	Economy	10900.00
0005434757055	9543	Economy	10900.00
0005434757074	9543	Economy	10900.00
0005434757076	9543	Economy	10900.00
0005434757092	9543	Economy	10900.00
0005434757091	9543	Economy	10900.00
0005434757085	9543	Economy	10900.00
0005434214820	9543	Economy	10900.00
0005434757068	9543	Economy	10900.00
0005434757078	9543	Economy	10900.00
0005434757065	9543	Economy	10900.00
0005434214767	9543	Economy	10900.00
0005434757082	9543	Economy	10900.00
0005434757079	9543	Economy	10900.00
0005434214550	9543	Economy	10900.00
0005434757097	9543	Economy	10900.00
0005434757067	9543	Economy	10900.00
0005434757057	9543	Economy	10900.00
0005434757058	9543	Economy	10900.00
0005434757056	9543	Economy	10900.00
0005434215188	28640	Business	32800.00
0005434756658	28640	Business	32800.00
0005434215206	28640	Business	32800.00
0005434756433	28640	Business	32800.00
0005434215184	28640	Business	32800.00
0005434756653	28640	Business	32800.00
0005434215204	28640	Business	32800.00
0005434215216	28640	Business	32800.00
0005434215180	28640	Business	32800.00
0005434215182	28640	Business	32800.00
0005434215207	28640	Business	32800.00
0005434215201	28640	Business	32800.00
0005434215192	28640	Economy	10900.00
0005434756637	28640	Economy	10900.00
0005434756676	28640	Economy	10900.00
0005434756519	28640	Economy	10900.00
0005434756486	28640	Economy	10900.00
0005434756638	28640	Economy	10900.00
0005434215202	28640	Economy	10900.00
0005434215210	28640	Economy	10900.00
0005434215190	28640	Economy	10900.00
0005434215200	28640	Economy	10900.00
0005434756348	28640	Economy	12000.00
0005434756636	28640	Economy	12000.00
0005434215194	28640	Economy	12000.00
0005434215219	28640	Economy	12000.00
0005434215213	28640	Economy	12000.00
0005434215205	28640	Economy	10900.00
0005434756657	28640	Economy	10900.00
0005434215203	28640	Economy	10900.00
0005434756655	28640	Economy	10900.00
0005434756680	28640	Economy	10900.00
0005434215217	28640	Economy	10900.00
0005434756487	28640	Economy	10900.00
0005434756586	28640	Economy	10900.00
0005434756523	28640	Economy	10900.00
0005434756562	28640	Economy	10900.00
0005434215174	28640	Economy	10900.00
0005434756674	28640	Economy	10900.00
0005434215187	28640	Economy	10900.00
0005434756518	28640	Economy	10900.00
0005434756485	28640	Economy	10900.00
0005434215221	28640	Economy	10900.00
0005434215212	28640	Economy	10900.00
0005434756600	28640	Economy	10900.00
0005434215195	28640	Economy	10900.00
0005434215215	28640	Economy	10900.00
0005434756589	28640	Economy	10900.00
0005434756641	28640	Economy	10900.00
0005434215181	28640	Economy	10900.00
0005434215220	28640	Economy	10900.00
0005434215185	28640	Economy	10900.00
0005434756610	28640	Economy	10900.00
0005434215178	28640	Economy	10900.00
0005434215211	28640	Economy	10900.00
0005434756561	28640	Economy	10900.00
0005434215176	28640	Economy	10900.00
0005434756639	28640	Economy	10900.00
0005434756551	28640	Economy	10900.00
0005434756577	28640	Economy	10900.00
0005434215209	28640	Economy	10900.00
0005434756635	28640	Economy	10900.00
0005434215173	28640	Economy	10900.00
0005434215183	28640	Economy	10900.00
0005434756578	28640	Economy	10900.00
0005434756596	28640	Economy	10900.00
0005434215186	28640	Economy	10900.00
0005434215177	28640	Economy	10900.00
0005434756572	28640	Economy	10900.00
0005434215191	28640	Economy	10900.00
0005434756673	28640	Economy	10900.00
0005434215198	28640	Economy	10900.00
0005434756522	28640	Economy	10900.00
0005434215199	28640	Economy	10900.00
0005434215197	28640	Economy	10900.00
0005434215175	28640	Economy	10900.00
0005434756585	28640	Economy	10900.00
0005434756662	28640	Economy	10900.00
0005434215214	28640	Economy	10900.00
0005434756656	28640	Economy	10900.00
0005434756584	28640	Economy	10900.00
0005434756695	28640	Economy	10900.00
0005434756575	28640	Economy	10900.00
0005434756563	28640	Economy	10900.00
0005434215193	28640	Economy	10900.00
0005434756576	28640	Economy	10900.00
0005434756694	28640	Economy	10900.00
0005434215196	28640	Economy	10900.00
0005434756591	28640	Economy	10900.00
0005434215208	28640	Economy	10900.00
0005434215218	28640	Economy	10900.00
0005434215179	28640	Economy	10900.00
0005434215189	28640	Economy	10900.00
0005435100169	10810	Economy	9800.00
0005434760211	10810	Economy	8900.00
0005434760215	10810	Economy	8900.00
0005434760209	10810	Economy	8900.00
0005434760217	10810	Economy	8900.00
0005435100168	10810	Economy	8900.00
0005434760216	10810	Economy	8900.00
0005434760205	10810	Economy	8900.00
0005435100170	10810	Economy	8900.00
0005434760218	10810	Economy	8900.00
0005435100138	31830	Economy	8900.00
0005435100150	31830	Economy	8900.00
0005434760234	31830	Economy	8900.00
0005435100121	31830	Economy	8900.00
0005435100149	31830	Economy	8900.00
0005435100139	31830	Economy	8900.00
0005434760235	31830	Economy	8900.00
0005433202375	1964	Economy	20900.00
0005433202420	1964	Economy	20900.00
0005434639708	1964	Economy	20900.00
0005432290681	1964	Economy	20900.00
0005434639718	1964	Economy	19000.00
0005434639714	1964	Economy	19000.00
0005434639726	1964	Economy	19000.00
0005432290684	1964	Economy	19000.00
0005434639723	1964	Economy	19000.00
0005433202473	1964	Economy	19000.00
0005434639717	1964	Economy	19000.00
0005434639716	1964	Economy	19000.00
0005434639729	1964	Economy	19000.00
0005433202474	1964	Economy	19000.00
0005434639715	1964	Economy	19000.00
0005434639712	1964	Economy	19000.00
0005434639724	1964	Economy	19000.00
0005433202491	1964	Economy	19000.00
0005434639720	1964	Economy	19000.00
0005433202470	1964	Economy	19000.00
0005433202452	1964	Economy	19000.00
0005434639722	1964	Economy	19000.00
0005433202401	1964	Economy	19000.00
0005433202421	1964	Economy	19000.00
0005433202469	1964	Economy	19000.00
0005434639725	1964	Economy	19000.00
0005432290685	1964	Economy	19000.00
0005432290682	1964	Economy	19000.00
0005434639719	1964	Economy	19000.00
0005434639713	1964	Economy	19000.00
0005434639710	1964	Economy	19000.00
0005434639709	1964	Economy	19000.00
0005433202425	1964	Economy	19000.00
0005432290683	1964	Economy	19000.00
0005433202416	1964	Economy	19000.00
0005434639707	1964	Economy	19000.00
0005434639727	1964	Economy	19000.00
0005433202490	1964	Economy	19000.00
0005434639730	1964	Economy	19000.00
0005433202499	1964	Economy	19000.00
0005434639728	1964	Economy	19000.00
0005433202468	1964	Economy	19000.00
0005433202424	1964	Economy	19000.00
0005434639731	1964	Economy	19000.00
0005434639711	1964	Economy	19000.00
0005432290680	1964	Economy	19000.00
0005434639721	1964	Economy	19000.00
0005435948335	23287	Economy	20900.00
0005434639509	23287	Economy	20900.00
0005434639428	23287	Economy	20900.00
0005433202573	23287	Economy	19000.00
0005433202576	23287	Economy	19000.00
0005434639434	23287	Economy	19000.00
0005433202580	23287	Economy	19000.00
0005433202584	23287	Economy	19000.00
0005434639510	23287	Economy	19000.00
0005434639478	23287	Economy	19000.00
0005433202574	23287	Economy	19000.00
0005434639501	23287	Economy	19000.00
0005433202579	23287	Economy	19000.00
0005434639378	23287	Economy	19000.00
0005433202571	23287	Economy	19000.00
0005433202583	23287	Economy	19000.00
0005434639567	23287	Economy	19000.00
0005434639577	23287	Economy	19000.00
0005434639449	23287	Economy	19000.00
0005433202575	23287	Economy	19000.00
0005433202572	23287	Economy	19000.00
0005433202570	23287	Economy	19000.00
0005433202577	23287	Economy	19000.00
0005434639559	23287	Economy	19000.00
0005434639371	23287	Economy	19000.00
0005434639430	23287	Economy	19000.00
0005435948334	23287	Economy	19000.00
0005434639477	23287	Economy	19000.00
0005434639377	23287	Economy	19000.00
0005433202582	23287	Economy	19000.00
0005434639568	23287	Economy	19000.00
0005433202578	23287	Economy	19000.00
0005434639433	23287	Economy	19000.00
0005433202581	23287	Economy	19000.00
0005434639554	23287	Economy	19000.00
0005435948333	23287	Economy	19000.00
0005433533366	6084	Business	69700.00
0005432111324	6084	Business	69700.00
0005435326828	6084	Business	69700.00
0005435326900	6084	Business	69700.00
0005434601222	6084	Business	69700.00
0005435326781	6084	Business	69700.00
0005433533365	6084	Business	69700.00
0005434601230	6084	Business	69700.00
0005433533369	6084	Business	69700.00
0005435326898	6084	Economy	23200.00
0005434601219	6084	Economy	23200.00
0005434601235	6084	Economy	23200.00
0005432111323	6084	Economy	23200.00
0005432111325	6084	Economy	23200.00
0005435326838	6084	Economy	25600.00
0005435326873	6084	Economy	25600.00
0005435326872	6084	Economy	25600.00
0005435326856	6084	Economy	23200.00
0005434601228	6084	Economy	23200.00
0005434601217	6084	Economy	23200.00
0005435326839	6084	Economy	23200.00
0005434601227	6084	Economy	23200.00
0005435326810	6084	Economy	23200.00
0005434601224	6084	Economy	23200.00
0005434601232	6084	Economy	23200.00
0005434601211	6084	Economy	23200.00
0005434601209	6084	Economy	23200.00
0005435326871	6084	Economy	23200.00
0005434601216	6084	Economy	23200.00
0005435326880	6084	Economy	23200.00
0005434601210	6084	Economy	23200.00
0005433533367	6084	Economy	23200.00
0005435326829	6084	Economy	23200.00
0005434601223	6084	Economy	23200.00
0005434601231	6084	Economy	23200.00
0005435326809	6084	Economy	23200.00
0005433531351	6084	Economy	23200.00
0005435326858	6084	Economy	23200.00
0005434601212	6084	Economy	23200.00
0005434601220	6084	Economy	23200.00
0005434601233	6084	Economy	23200.00
0005433531350	6084	Economy	23200.00
0005435326881	6084	Economy	23200.00
0005434601234	6084	Economy	23200.00
0005434601215	6084	Economy	23200.00
0005435326859	6084	Economy	23200.00
0005435326845	6084	Economy	23200.00
0005433533368	6084	Economy	23200.00
0005434601225	6084	Economy	23200.00
0005434601226	6084	Economy	23200.00
0005433531352	6084	Economy	23200.00
0005434601236	6084	Economy	23200.00
0005435326899	6084	Economy	23200.00
0005434601229	6084	Economy	23200.00
0005434601214	6084	Economy	23200.00
0005435326844	6084	Economy	23200.00
0005434601218	6084	Economy	23200.00
0005434601221	6084	Economy	23200.00
0005434601213	6084	Economy	23200.00
0005435326862	6084	Economy	23200.00
0005433531353	6084	Economy	23200.00
0005434600866	18575	Business	69700.00
0005433527282	18575	Business	69700.00
0005435326963	18575	Business	69700.00
0005434601016	18575	Business	69700.00
0005434600915	18575	Business	69700.00
0005435326955	18575	Business	69700.00
0005433527269	18575	Business	69700.00
0005434601023	18575	Business	69700.00
0005435326961	18575	Economy	23200.00
0005433531312	18575	Economy	23200.00
0005435326954	18575	Economy	23200.00
0005435326958	18575	Economy	23200.00
0005434600867	18575	Economy	23200.00
0005435326960	18575	Economy	25600.00
0005434600979	18575	Economy	25600.00
0005435326962	18575	Economy	23200.00
0005434600951	18575	Economy	23200.00
0005433531311	18575	Economy	23200.00
0005434600997	18575	Economy	23200.00
0005434601006	18575	Economy	23200.00
0005434600964	18575	Economy	23200.00
0005434600907	18575	Economy	23200.00
0005434601038	18575	Economy	23200.00
0005435326953	18575	Economy	23200.00
0005434601034	18575	Economy	23200.00
0005433527266	18575	Economy	23200.00
0005434601022	18575	Economy	23200.00
0005434600970	18575	Economy	23200.00
0005434601021	18575	Economy	23200.00
0005435326964	18575	Economy	23200.00
0005434600937	18575	Economy	23200.00
0005435326956	18575	Economy	23200.00
0005434601032	18575	Economy	23200.00
0005434601031	18575	Economy	23200.00
0005434601037	18575	Economy	23200.00
0005435326957	18575	Economy	23200.00
0005435326959	18575	Economy	23200.00
0005435326952	18575	Economy	23200.00
0005434600965	18575	Economy	23200.00
0005434601025	18575	Economy	23200.00
0005434601024	18575	Economy	23200.00
0005434600990	18575	Economy	23200.00
0005434552008	10580	Business	9100.00
0005433181216	10580	Business	9100.00
0005434552004	10580	Business	9100.00
0005434552024	10580	Business	9100.00
0005434551995	10580	Business	9100.00
0005434552011	10580	Business	9100.00
0005433181079	10580	Business	9100.00
0005434552002	10580	Business	9100.00
0005433181259	10580	Business	9100.00
0005434552021	10580	Business	9100.00
0005434552043	10580	Business	9100.00
0005434551994	10580	Business	9100.00
0005433181271	10580	Economy	3000.00
0005434552031	10580	Economy	3000.00
0005434552012	10580	Economy	3000.00
0005434552030	10580	Economy	3000.00
0005433181101	10580	Economy	3000.00
0005434551993	10580	Economy	3000.00
0005434554096	10580	Economy	3000.00
0005434558410	10580	Economy	3000.00
0005433181273	10580	Economy	3000.00
0005434558401	10580	Economy	3000.00
0005433181291	10580	Economy	3300.00
0005434552029	10580	Economy	3300.00
0005434552000	10580	Economy	3300.00
0005434552046	10580	Economy	3300.00
0005434552003	10580	Economy	3300.00
0005434552041	10580	Economy	3000.00
0005434552006	10580	Economy	3000.00
0005433181204	10580	Economy	3000.00
0005434552007	10580	Economy	3000.00
0005433181277	10580	Economy	3000.00
0005434558406	10580	Economy	3000.00
0005433181228	10580	Economy	3000.00
0005434552013	10580	Economy	3000.00
0005434552009	10580	Economy	3000.00
0005434558407	10580	Economy	3000.00
0005434558399	10580	Economy	3000.00
0005434552005	10580	Economy	3000.00
0005433181278	10580	Economy	3000.00
0005434558402	10580	Economy	3000.00
0005434552033	10580	Economy	3000.00
0005434552034	10580	Economy	3000.00
0005433181203	10580	Economy	3000.00
0005433181263	10580	Economy	3000.00
0005434558403	10580	Economy	3000.00
0005434558404	10580	Economy	3000.00
0005433181201	10580	Economy	3000.00
0005434552035	10580	Economy	3000.00
0005434552027	10580	Economy	3000.00
0005434558405	10580	Economy	3000.00
0005434552032	10580	Economy	3000.00
0005433181233	10580	Economy	3000.00
0005434551999	10580	Economy	3000.00
0005434552023	10580	Economy	3000.00
0005434558408	10580	Economy	3000.00
0005434554095	10580	Economy	3000.00
0005434552047	10580	Economy	3000.00
0005434552019	10580	Economy	3000.00
0005434552020	10580	Economy	3000.00
0005434552037	10580	Economy	3000.00
0005434552028	10580	Economy	3000.00
0005434552048	10580	Economy	3000.00
0005433181256	10580	Economy	3000.00
0005434551996	10580	Economy	3000.00
0005434552010	10580	Economy	3000.00
0005434552014	10580	Economy	3000.00
0005434558400	10580	Economy	3000.00
0005433181290	10580	Economy	3000.00
0005434552044	10580	Economy	3000.00
0005434551998	10580	Economy	3000.00
0005434552025	10580	Economy	3000.00
0005433181250	10580	Economy	3000.00
0005434551997	10580	Economy	3000.00
0005433181200	10580	Economy	3000.00
0005434552042	10580	Economy	3000.00
0005433181362	10580	Economy	3000.00
0005434552022	10580	Economy	3000.00
0005434552045	10580	Economy	3000.00
0005434552017	10580	Economy	3000.00
0005434552039	10580	Economy	3000.00
0005434552040	10580	Economy	3000.00
0005434552018	10580	Economy	3000.00
0005434552038	10580	Economy	3000.00
0005434552026	10580	Economy	3000.00
0005434552016	10580	Economy	3000.00
0005434554094	10580	Economy	3000.00
0005433181319	10580	Economy	3000.00
0005434558409	10580	Economy	3000.00
0005433181272	10580	Economy	3000.00
0005434552015	10580	Economy	3000.00
0005434552001	10580	Economy	3000.00
0005434552036	10580	Economy	3000.00
0005433181249	10580	Economy	3000.00
0005433181486	27705	Business	9100.00
0005433181499	27705	Business	9100.00
0005433181483	27705	Business	9100.00
0005433181476	27705	Economy	3000.00
0005433181487	27705	Economy	3000.00
0005433181478	27705	Economy	3000.00
0005433181497	27705	Economy	3000.00
0005433181500	27705	Economy	3000.00
0005433181482	27705	Economy	3000.00
0005433181481	27705	Economy	3000.00
0005433181479	27705	Economy	3000.00
0005433181490	27705	Economy	3000.00
0005433181484	27705	Economy	3000.00
0005433181496	27705	Economy	3000.00
0005433181477	27705	Economy	3000.00
0005433181489	27705	Economy	3000.00
0005433181493	27705	Economy	3000.00
0005433181495	27705	Economy	3000.00
0005433181488	27705	Economy	3000.00
0005433181480	27705	Economy	3000.00
0005433181494	27705	Economy	3000.00
0005433181491	27705	Economy	3000.00
0005433181498	27705	Economy	3000.00
0005433181485	27705	Economy	3000.00
0005433181492	27705	Economy	3000.00
0005434551563	27706	Business	9100.00
0005434551764	27706	Business	9100.00
0005434551606	27706	Business	9100.00
0005434551528	27706	Business	9100.00
0005434551800	27706	Business	9100.00
0005434551426	27706	Business	9100.00
0005434558307	27706	Business	9100.00
0005434551649	27706	Business	9100.00
0005434554083	27706	Business	9100.00
0005434551647	27706	Economy	3000.00
0005434551602	27706	Economy	3000.00
0005434551458	27706	Economy	3000.00
0005434551763	27706	Economy	3000.00
0005434551748	27706	Economy	3000.00
0005434551402	27706	Economy	3000.00
0005434551338	27706	Economy	3000.00
0005434551594	27706	Economy	3000.00
0005434554078	27706	Economy	3000.00
0005434551648	27706	Economy	3300.00
0005434551460	27706	Economy	3300.00
0005434551640	27706	Economy	3300.00
0005434551438	27706	Economy	3300.00
0005434551616	27706	Economy	3000.00
0005434551787	27706	Economy	3000.00
0005434551459	27706	Economy	3000.00
0005434551516	27706	Economy	3000.00
0005434551575	27706	Economy	3000.00
0005434551698	27706	Economy	3000.00
0005434551699	27706	Economy	3000.00
0005434558299	27706	Economy	3000.00
0005434551776	27706	Economy	3000.00
0005434558324	27706	Economy	3000.00
0005434551707	27706	Economy	3000.00
0005434551737	27706	Economy	3000.00
0005434551617	27706	Economy	3000.00
0005434551564	27706	Economy	3000.00
0005434551605	27706	Economy	3000.00
0005434551756	27706	Economy	3000.00
0005434554079	27706	Economy	3000.00
0005434551777	27706	Economy	3000.00
0005434551495	27706	Economy	3000.00
0005434554080	27706	Economy	3000.00
0005434551546	27706	Economy	3000.00
0005434551576	27706	Economy	3000.00
0005434551673	27706	Economy	3000.00
0005434551547	27706	Economy	3000.00
0005434551709	27706	Economy	3000.00
0005434551565	27706	Economy	3000.00
0005434558315	27706	Economy	3000.00
0005434551551	27706	Economy	3000.00
0005434551761	27706	Economy	3000.00
0005434551478	27706	Economy	3000.00
0005434551567	27706	Economy	3000.00
0005434551527	27706	Economy	3000.00
0005434554077	27706	Economy	3000.00
0005434551636	27706	Economy	3000.00
0005434551652	27706	Economy	3000.00
0005434551952	27706	Economy	3000.00
0005434554081	27706	Economy	3000.00
0005434551755	27706	Economy	3000.00
0005434551639	27706	Economy	3000.00
0005434558320	27706	Economy	3000.00
0005434551687	27706	Economy	3000.00
0005434551951	27706	Economy	3000.00
0005434551345	27706	Economy	3000.00
0005434558308	27706	Economy	3000.00
0005434558319	27706	Economy	3000.00
0005434551738	27706	Economy	3000.00
0005434551601	27706	Economy	3000.00
0005434551696	27706	Economy	3000.00
0005434551439	27706	Economy	3000.00
0005434551964	27706	Economy	3000.00
0005434551618	27706	Economy	3000.00
0005434551530	27706	Economy	3000.00
0005434551927	27706	Economy	3000.00
0005435254500	6121	Economy	11700.00
0005435254501	6121	Economy	11700.00
0005433459285	6121	Economy	11700.00
0005433459287	6121	Economy	11700.00
0005433459286	6121	Economy	11700.00
0005435254489	6121	Economy	11700.00
0005433459284	6121	Economy	11700.00
0005433459248	19305	Economy	11700.00
0005433459249	19305	Economy	11700.00
0005435254510	19305	Economy	11700.00
0005433459246	19305	Economy	11700.00
0005435254511	19305	Economy	11700.00
0005433459247	19305	Economy	11700.00
0005435220329	6755	Business	51100.00
0005434828716	6755	Business	51100.00
0005435220324	6755	Business	51100.00
0005435682725	6755	Business	51100.00
0005435682766	6755	Business	51100.00
0005435682763	6755	Business	51100.00
0005435682759	6755	Business	51100.00
0005435682744	6755	Business	51100.00
0005435438170	6755	Business	51100.00
0005435682732	6755	Business	51100.00
0005435682729	6755	Business	51100.00
0005435438006	6755	Business	51100.00
0005435682760	6755	Economy	17000.00
0005435631012	6755	Economy	17000.00
0005435682765	6755	Economy	17000.00
0005435682767	6755	Economy	17000.00
0005435720147	6755	Economy	17000.00
0005435438118	6755	Economy	17000.00
0005435661973	6755	Economy	17000.00
0005435682754	6755	Economy	17000.00
0005435682734	6755	Economy	17000.00
0005432136247	6755	Economy	18700.00
0005435682746	6755	Economy	18700.00
0005435438091	6755	Economy	18700.00
0005435682733	6755	Economy	18700.00
0005435682738	6755	Economy	18700.00
0005435438174	6755	Economy	17000.00
0005432136246	6755	Economy	17000.00
0005435438130	6755	Economy	17000.00
0005435438081	6755	Economy	17000.00
0005435661974	6755	Economy	17000.00
0005435682740	6755	Economy	17000.00
0005435682757	6755	Economy	17000.00
0005435682739	6755	Economy	17000.00
0005432136244	6755	Economy	17000.00
0005435682726	6755	Economy	17000.00
0005435682723	6755	Economy	17000.00
0005435682758	6755	Economy	17000.00
0005435682764	6755	Economy	17000.00
0005435682737	6755	Economy	17000.00
0005435682731	6755	Economy	17000.00
0005435438163	6755	Economy	17000.00
0005435682752	6755	Economy	17000.00
0005435682745	6755	Economy	17000.00
0005435438185	6755	Economy	17000.00
0005435438140	6755	Economy	17000.00
0005435438102	6755	Economy	17000.00
0005435438085	6755	Economy	17000.00
0005435438007	6755	Economy	17000.00
0005435438143	6755	Economy	17000.00
0005435682756	6755	Economy	17000.00
0005435631011	6755	Economy	17000.00
0005435682728	6755	Economy	17000.00
0005435682743	6755	Economy	17000.00
0005435682742	6755	Economy	17000.00
0005435682727	6755	Economy	17000.00
0005435682750	6755	Economy	17000.00
0005435720148	6755	Economy	17000.00
0005435682735	6755	Economy	17000.00
0005435438129	6755	Economy	17000.00
0005432136245	6755	Economy	17000.00
0005435682753	6755	Economy	17000.00
0005435438090	6755	Economy	17000.00
0005435438114	6755	Economy	17000.00
0005435631010	6755	Economy	17000.00
0005435438133	6755	Economy	17000.00
0005435682749	6755	Economy	17000.00
0005435661972	6755	Economy	17000.00
0005435438083	6755	Economy	17000.00
0005435682730	6755	Economy	17000.00
0005432136243	6755	Economy	17000.00
0005435682761	6755	Economy	17000.00
0005435438082	6755	Economy	17000.00
0005435438184	6755	Economy	17000.00
0005432533303	6755	Economy	17000.00
0005435682751	6755	Economy	17000.00
0005435682755	6755	Economy	17000.00
0005434828715	6755	Economy	17000.00
0005435682724	6755	Economy	17000.00
0005435438125	6755	Economy	17000.00
0005435682736	6755	Economy	17000.00
0005435682747	6755	Economy	17000.00
0005435438112	6755	Economy	17000.00
0005435438169	6755	Economy	17000.00
0005435682741	6755	Economy	17000.00
0005435682762	6755	Economy	17000.00
0005435438134	6755	Economy	17000.00
0005435682748	6755	Economy	17000.00
0005434828739	24622	Business	51100.00
0005435682356	24622	Business	51100.00
0005435682327	24622	Business	51100.00
0005435682438	24622	Business	51100.00
0005432533337	24622	Business	51100.00
0005435682241	24622	Business	51100.00
0005435438280	24622	Business	51100.00
0005435438281	24622	Business	51100.00
0005435682408	24622	Business	51100.00
0005435682432	24622	Economy	17000.00
0005435720832	24622	Economy	17000.00
0005435438287	24622	Economy	17000.00
0005435630983	24622	Economy	17000.00
0005435720833	24622	Economy	17000.00
0005435438294	24622	Economy	17000.00
0005435682542	24622	Economy	17000.00
0005435682439	24622	Economy	17000.00
0005435682482	24622	Economy	18700.00
0005435720828	24622	Economy	18700.00
0005435682507	24622	Economy	18700.00
0005435438295	24622	Economy	18700.00
0005435661956	24622	Economy	18700.00
0005435438282	24622	Economy	17000.00
0005432533336	24622	Economy	17000.00
0005435438285	24622	Economy	17000.00
0005435438292	24622	Economy	17000.00
0005435438286	24622	Economy	17000.00
0005435682481	24622	Economy	17000.00
0005435682449	24622	Economy	17000.00
0005435682485	24622	Economy	17000.00
0005435438296	24622	Economy	17000.00
0005435682364	24622	Economy	17000.00
0005435438300	24622	Economy	17000.00
0005435438302	24622	Economy	17000.00
0005435682569	24622	Economy	17000.00
0005435682354	24622	Economy	17000.00
0005435682425	24622	Economy	17000.00
0005435720827	24622	Economy	17000.00
0005435438291	24622	Economy	17000.00
0005435682463	24622	Economy	17000.00
0005435438284	24622	Economy	17000.00
0005435682339	24622	Economy	17000.00
0005435438301	24622	Economy	17000.00
0005435682509	24622	Economy	17000.00
0005435682265	24622	Economy	17000.00
0005435682426	24622	Economy	17000.00
0005435682301	24622	Economy	17000.00
0005435630989	24622	Economy	17000.00
0005435682409	24622	Economy	17000.00
0005435682450	24622	Economy	17000.00
0005432305787	24622	Economy	17000.00
0005432305786	24622	Economy	17000.00
0005435719569	24622	Economy	17000.00
0005435438299	24622	Economy	17000.00
0005435630988	24622	Economy	17000.00
0005435661941	24622	Economy	17000.00
0005435682358	24622	Economy	17000.00
0005435682362	24622	Economy	17000.00
0005434828741	24622	Economy	17000.00
0005435438298	24622	Economy	17000.00
0005435682363	24622	Economy	17000.00
0005435438288	24622	Economy	17000.00
0005435682570	24622	Economy	17000.00
0005435438297	24622	Economy	17000.00
0005435438293	24622	Economy	17000.00
0005435682537	24622	Economy	17000.00
0005435438290	24622	Economy	17000.00
0005435438283	24622	Economy	17000.00
0005435661958	24622	Economy	17000.00
0005435682355	24622	Economy	17000.00
0005434828740	24622	Economy	17000.00
0005435438289	24622	Economy	17000.00
0005435682464	24622	Economy	17000.00
0005435682478	24622	Economy	17000.00
0005435682486	24622	Economy	17000.00
0005435682586	24622	Economy	17000.00
0005435661957	24622	Economy	17000.00
0005435682508	24622	Economy	17000.00
0005435126968	11548	Business	26400.00
0005435126943	11548	Business	26400.00
0005435126959	11548	Business	26400.00
0005435126949	11548	Economy	8800.00
0005435126971	11548	Economy	8800.00
0005435126953	11548	Economy	8800.00
0005435126976	11548	Economy	8800.00
0005435126977	11548	Economy	8800.00
0005435126970	11548	Economy	8800.00
0005435558101	11548	Economy	8800.00
0005435558104	11548	Economy	8800.00
0005435126965	11548	Economy	8800.00
0005435126947	11548	Economy	8800.00
0005435558110	11548	Economy	9700.00
0005435126973	11548	Economy	9700.00
0005435106028	11548	Economy	9700.00
0005435558109	11548	Economy	9700.00
0005435126939	11548	Economy	8800.00
0005435098586	11548	Economy	8800.00
0005435126950	11548	Economy	8800.00
0005435126967	11548	Economy	8800.00
0005435126975	11548	Economy	8800.00
0005435126958	11548	Economy	8800.00
0005435126938	11548	Economy	8800.00
0005435126961	11548	Economy	8800.00
0005435126944	11548	Economy	8800.00
0005435126960	11548	Economy	8800.00
0005435126952	11548	Economy	8800.00
0005435126941	11548	Economy	8800.00
0005435126963	11548	Economy	8800.00
0005435126979	11548	Economy	8800.00
0005435126957	11548	Economy	8800.00
0005435126962	11548	Economy	8800.00
0005435126978	11548	Economy	8800.00
0005435126956	11548	Economy	8800.00
0005435098584	11548	Economy	8800.00
0005435106029	11548	Economy	8800.00
0005435098583	11548	Economy	8800.00
0005435098588	11548	Economy	8800.00
0005435558106	11548	Economy	8800.00
0005435126972	11548	Economy	8800.00
0005435126964	11548	Economy	8800.00
0005435126969	11548	Economy	8800.00
0005435126942	11548	Economy	8800.00
0005435126948	11548	Economy	8800.00
0005435098587	11548	Economy	8800.00
0005435126974	11548	Economy	8800.00
0005435126946	11548	Economy	8800.00
0005435098585	11548	Economy	8800.00
0005435126980	11548	Economy	8800.00
0005435126966	11548	Economy	8800.00
0005435126951	11548	Economy	8800.00
0005435126954	11548	Economy	8800.00
0005435558102	11548	Economy	8800.00
0005435126955	11548	Economy	8800.00
0005435106030	11548	Economy	8800.00
0005435126940	11548	Economy	8800.00
0005435126945	11548	Economy	8800.00
0005435126687	31850	Business	26400.00
0005435126550	31850	Business	26400.00
0005435098562	31850	Business	26400.00
0005435558126	31850	Business	26400.00
0005435126543	31850	Business	26400.00
0005435126763	31850	Business	26400.00
0005435126611	31850	Business	26400.00
0005435126659	31850	Economy	8800.00
0005435126778	31850	Economy	8800.00
0005435126586	31850	Economy	8800.00
0005435098565	31850	Economy	8800.00
0005435105999	31850	Economy	8800.00
0005435126604	31850	Economy	8800.00
0005435126676	31850	Economy	8800.00
0005435126518	31850	Economy	9700.00
0005435098564	31850	Economy	9700.00
0005435126629	31850	Economy	9700.00
0005435126603	31850	Economy	9700.00
0005435126600	31850	Economy	9700.00
0005435098563	31850	Economy	8800.00
0005435126804	31850	Economy	8800.00
0005435126674	31850	Economy	8800.00
0005435126746	31850	Economy	8800.00
0005435126595	31850	Economy	8800.00
0005435126516	31850	Economy	8800.00
0005435126513	31850	Economy	8800.00
0005435126707	31850	Economy	8800.00
0005435126669	31850	Economy	8800.00
0005435126593	31850	Economy	8800.00
0005435126767	31850	Economy	8800.00
0005435126661	31850	Economy	8800.00
0005435126698	31850	Economy	8800.00
0005435126671	31850	Economy	8800.00
0005435126662	31850	Economy	8800.00
0005435126644	31850	Economy	8800.00
0005435126660	31850	Economy	8800.00
0005435126745	31850	Economy	8800.00
0005435126696	31850	Economy	8800.00
0005435126626	31850	Economy	8800.00
0005435126695	31850	Economy	8800.00
0005435126686	31850	Economy	8800.00
0005435126587	31850	Economy	8800.00
0005435126680	31850	Economy	8800.00
0005435126619	31850	Economy	8800.00
0005435126588	31850	Economy	8800.00
0005435126643	31850	Economy	8800.00
0005435126579	31850	Economy	8800.00
0005435126713	31850	Economy	8800.00
0005435098570	31850	Economy	8800.00
0005435126769	31850	Economy	8800.00
0005435126679	31850	Economy	8800.00
0005435126601	31850	Economy	8800.00
0005435126663	31850	Economy	8800.00
0005435098572	31850	Economy	8800.00
0005435126839	31850	Economy	8800.00
0005435558127	31850	Economy	8800.00
0005435126563	31850	Economy	8800.00
0005435126706	31850	Economy	8800.00
0005435126668	31850	Economy	8800.00
0005435126650	31850	Economy	8800.00
0005435126602	31850	Economy	8800.00
0005435126597	31850	Economy	8800.00
0005435105998	31850	Economy	8800.00
0005435126652	31850	Economy	8800.00
0005435126667	31850	Economy	8800.00
0005435126751	31850	Economy	8800.00
0005435126768	31850	Economy	8800.00
0005435126703	31850	Economy	8800.00
0005435126736	31850	Economy	8800.00
0005435126596	31850	Economy	8800.00
0005435105997	31850	Economy	8800.00
0005435126675	31850	Economy	8800.00
0005435126685	31850	Economy	8800.00
0005435126592	31850	Economy	8800.00
0005435126628	31850	Economy	8800.00
0005433398799	13559	Business	36600.00
0005433398791	13559	Business	36600.00
0005433398810	13559	Business	36600.00
0005433398815	13559	Business	36600.00
0005433398809	13559	Business	36600.00
0005435732446	13559	Business	36600.00
0005433398774	13559	Business	36600.00
0005433398796	13559	Business	36600.00
0005433398773	13559	Economy	12200.00
0005433398813	13559	Economy	12200.00
0005433398781	13559	Economy	12200.00
0005433398807	13559	Economy	12200.00
0005433398779	13559	Economy	12200.00
0005433398802	13559	Economy	12200.00
0005433398775	13559	Economy	12200.00
0005433398772	13559	Economy	13400.00
0005433398783	13559	Economy	13400.00
0005433398777	13559	Economy	13400.00
0005433398801	13559	Economy	13400.00
0005435732438	13559	Economy	12200.00
0005433398797	13559	Economy	12200.00
0005433398800	13559	Economy	12200.00
0005435732349	13559	Economy	12200.00
0005435732350	13559	Economy	12200.00
0005433398798	13559	Economy	12200.00
0005433398771	13559	Economy	12200.00
0005433398784	13559	Economy	12200.00
0005435732387	13559	Economy	12200.00
0005433398786	13559	Economy	12200.00
0005433398793	13559	Economy	12200.00
0005433398789	13559	Economy	12200.00
0005433398804	13559	Economy	12200.00
0005433398795	13559	Economy	12200.00
0005435732399	13559	Economy	12200.00
0005433398817	13559	Economy	12200.00
0005433398788	13559	Economy	12200.00
0005433398816	13559	Economy	12200.00
0005433398782	13559	Economy	12200.00
0005433398790	13559	Economy	12200.00
0005433398785	13559	Economy	12200.00
0005433398787	13559	Economy	12200.00
0005433398808	13559	Economy	12200.00
0005433398778	13559	Economy	12200.00
0005433398770	13559	Economy	12200.00
0005433398776	13559	Economy	12200.00
0005433398812	13559	Economy	12200.00
0005435732417	13559	Economy	12200.00
0005433398818	13559	Economy	12200.00
0005433398811	13559	Economy	12200.00
0005433398803	13559	Economy	12200.00
0005435732384	13559	Economy	12200.00
0005433398805	13559	Economy	12200.00
0005433398780	13559	Economy	12200.00
0005433398814	13559	Economy	12200.00
0005433398792	13559	Economy	12200.00
0005433398806	13559	Economy	12200.00
0005433398794	13559	Economy	12200.00
0005433398557	19374	Business	36600.00
0005435732520	19374	Business	36600.00
0005435732518	19374	Business	36600.00
0005435732529	19374	Business	36600.00
0005432297316	19374	Business	36600.00
0005433398441	19374	Business	36600.00
0005433398427	19374	Economy	12200.00
0005435732525	19374	Economy	12200.00
0005433398194	19374	Economy	12200.00
0005435732528	19374	Economy	12200.00
0005433398146	19374	Economy	13400.00
0005435732533	19374	Economy	13400.00
0005435732535	19374	Economy	12200.00
0005433398400	19374	Economy	12200.00
0005435732526	19374	Economy	12200.00
0005432297318	19374	Economy	12200.00
0005435732527	19374	Economy	12200.00
0005433398245	19374	Economy	12200.00
0005435732514	19374	Economy	12200.00
0005433398399	19374	Economy	12200.00
0005432297317	19374	Economy	12200.00
0005435732531	19374	Economy	12200.00
0005433398453	19374	Economy	12200.00
0005435732512	19374	Economy	12200.00
0005433398302	19374	Economy	12200.00
0005433398397	19374	Economy	12200.00
0005433398423	19374	Economy	12200.00
0005435732534	19374	Economy	12200.00
0005433398398	19374	Economy	12200.00
0005433398393	19374	Economy	12200.00
0005433398390	19374	Economy	12200.00
0005435732521	19374	Economy	12200.00
0005435732532	19374	Economy	12200.00
0005435732516	19374	Economy	12200.00
0005433397975	19374	Economy	12200.00
0005435732515	19374	Economy	12200.00
0005433398556	19374	Economy	12200.00
0005435732513	19374	Economy	12200.00
0005433398448	19374	Economy	12200.00
0005435732536	19374	Economy	12200.00
0005435732522	19374	Economy	12200.00
0005435732537	19374	Economy	12200.00
0005433398436	19374	Economy	12200.00
0005435732530	19374	Economy	12200.00
0005433398428	19374	Economy	12200.00
0005433398429	19374	Economy	12200.00
0005435732517	19374	Economy	12200.00
0005435732524	19374	Economy	12200.00
0005435732523	19374	Economy	12200.00
0005435732519	19374	Economy	12200.00
0005433398301	19374	Economy	12200.00
0005435069296	13138	Business	11300.00
0005435925499	13138	Business	11300.00
0005435069416	13138	Business	11300.00
0005435069295	13138	Business	11300.00
0005435069476	13138	Business	11300.00
0005435069297	13138	Business	11300.00
0005435069412	13138	Business	11300.00
0005435069616	13138	Business	11300.00
0005435925486	13138	Economy	3800.00
0005435069336	13138	Economy	3800.00
0005435069210	13138	Economy	3800.00
0005435069558	13138	Economy	3800.00
0005435925488	13138	Economy	3800.00
0005435069344	13138	Economy	3800.00
0005435925500	13138	Economy	3800.00
0005435069452	13138	Economy	3800.00
0005435069528	13138	Economy	3800.00
0005435069411	13138	Economy	3800.00
0005435069362	13138	Economy	4100.00
0005435069433	13138	Economy	4100.00
0005435069371	13138	Economy	4100.00
0005435069277	13138	Economy	4100.00
0005435925494	13138	Economy	4100.00
0005435069398	13138	Economy	3800.00
0005435069343	13138	Economy	3800.00
0005435069434	13138	Economy	3800.00
0005435069617	13138	Economy	3800.00
0005435069282	13138	Economy	3800.00
0005435925496	13138	Economy	3800.00
0005435069436	13138	Economy	3800.00
0005435925485	13138	Economy	3800.00
0005435069170	13138	Economy	3800.00
0005435069235	13138	Economy	3800.00
0005435069342	13138	Economy	3800.00
0005435069288	13138	Economy	3800.00
0005435069234	13138	Economy	3800.00
0005435069196	13138	Economy	3800.00
0005435069529	13138	Economy	3800.00
0005435069405	13138	Economy	3800.00
0005435069209	13138	Economy	3800.00
0005435069222	13138	Economy	3800.00
0005435069641	13138	Economy	3800.00
0005435069327	13138	Economy	3800.00
0005435069642	13138	Economy	3800.00
0005435069399	13138	Economy	3800.00
0005435069527	13138	Economy	3800.00
0005435925492	13138	Economy	3800.00
0005435925491	13138	Economy	3800.00
0005435069429	13138	Economy	3800.00
0005435069244	13138	Economy	3800.00
0005435069347	13138	Economy	3800.00
0005435069283	13138	Economy	3800.00
0005435069417	13138	Economy	3800.00
0005435069392	13138	Economy	3800.00
0005435925493	13138	Economy	3800.00
0005435925497	13138	Economy	3800.00
0005435925490	13138	Economy	3800.00
0005435069413	13138	Economy	3800.00
0005435069278	13138	Economy	3800.00
0005435925484	13138	Economy	3800.00
0005435069328	13138	Economy	3800.00
0005435925501	13138	Economy	3800.00
0005435925495	13138	Economy	3800.00
0005435069161	13138	Economy	3800.00
0005435069266	13138	Economy	3800.00
0005435069453	13138	Economy	3800.00
0005435069377	13138	Economy	3800.00
0005435925489	13138	Economy	3800.00
0005435069378	13138	Economy	3800.00
0005435069335	13138	Economy	3800.00
0005435069410	13138	Economy	3800.00
0005435925487	13138	Economy	3800.00
0005435069599	13138	Economy	3800.00
0005435069435	13138	Economy	3800.00
0005435069425	13138	Economy	3800.00
0005435069284	13138	Economy	3800.00
0005435925498	13138	Economy	3800.00
0005435069265	13138	Economy	3800.00
0005435925329	15457	Business	11300.00
0005435069839	15457	Business	11300.00
0005435069823	15457	Business	11300.00
0005435069812	15457	Business	11300.00
0005435069819	15457	Business	11300.00
0005435069846	15457	Business	11300.00
0005435069850	15457	Business	11300.00
0005435069838	15457	Business	11300.00
0005435069828	15457	Business	11300.00
0005435069826	15457	Economy	3800.00
0005435069835	15457	Economy	3800.00
0005435925403	15457	Economy	3800.00
0005435925299	15457	Economy	3800.00
0005435925323	15457	Economy	3800.00
0005435069818	15457	Economy	4100.00
0005435069848	15457	Economy	4100.00
0005435069806	15457	Economy	4100.00
0005435925320	15457	Economy	4100.00
0005435069849	15457	Economy	3800.00
0005435925368	15457	Economy	3800.00
0005435069852	15457	Economy	3800.00
0005435925365	15457	Economy	3800.00
0005435069822	15457	Economy	3800.00
0005435069844	15457	Economy	3800.00
0005435069815	15457	Economy	3800.00
0005435069801	15457	Economy	3800.00
0005435069841	15457	Economy	3800.00
0005435069833	15457	Economy	3800.00
0005435925404	15457	Economy	3800.00
0005435069824	15457	Economy	3800.00
0005435069827	15457	Economy	3800.00
0005435069831	15457	Economy	3800.00
0005435069845	15457	Economy	3800.00
0005435069804	15457	Economy	3800.00
0005435069851	15457	Economy	3800.00
0005435069820	15457	Economy	3800.00
0005435069813	15457	Economy	3800.00
0005435069825	15457	Economy	3800.00
0005435069836	15457	Economy	3800.00
0005435069810	15457	Economy	3800.00
0005435069805	15457	Economy	3800.00
0005435925367	15457	Economy	3800.00
0005435925364	15457	Economy	3800.00
0005435069803	15457	Economy	3800.00
0005435069840	15457	Economy	3800.00
0005435925350	15457	Economy	3800.00
0005435069842	15457	Economy	3800.00
0005435069807	15457	Economy	3800.00
0005435069834	15457	Economy	3800.00
0005435069843	15457	Economy	3800.00
0005435069837	15457	Economy	3800.00
0005435925351	15457	Economy	3800.00
0005435925349	15457	Economy	3800.00
0005435925347	15457	Economy	3800.00
0005435925324	15457	Economy	3800.00
0005435069808	15457	Economy	3800.00
0005435069802	15457	Economy	3800.00
0005435069816	15457	Economy	3800.00
0005435069817	15457	Economy	3800.00
0005435069811	15457	Economy	3800.00
0005435069830	15457	Economy	3800.00
0005435069821	15457	Economy	3800.00
0005435925352	15457	Economy	3800.00
0005435069809	15457	Economy	3800.00
0005435069829	15457	Economy	3800.00
0005435069832	15457	Economy	3800.00
0005435069847	15457	Economy	3800.00
0005435069814	15457	Economy	3800.00
0005435808277	29496	Economy	27100.00
0005435808276	29496	Economy	27100.00
0005435808215	29496	Economy	24700.00
0005433407644	29496	Economy	24700.00
0005435808270	29496	Economy	24700.00
0005435808271	29496	Economy	24700.00
0005435808284	29496	Economy	24700.00
0005433407642	29496	Economy	24700.00
0005435808287	29496	Economy	24700.00
0005433407646	29496	Economy	24700.00
0005433407643	29496	Economy	24700.00
0005435808285	29496	Economy	24700.00
0005435808268	29496	Economy	24700.00
0005433407639	29496	Economy	24700.00
0005435808311	29496	Economy	24700.00
0005435808236	29496	Economy	24700.00
0005433407640	29496	Economy	24700.00
0005435808216	29496	Economy	24700.00
0005433407641	29496	Economy	24700.00
0005435808243	29496	Economy	24700.00
0005433407647	29496	Economy	24700.00
0005435808266	29496	Economy	24700.00
0005435808269	29496	Economy	24700.00
0005435808294	29496	Economy	24700.00
0005433407645	29496	Economy	24700.00
0005435808235	29496	Economy	24700.00
0005435808289	29496	Economy	24700.00
0005435808275	29496	Economy	24700.00
0005433407638	29496	Economy	24700.00
0005434215247	10709	Business	61300.00
0005434756629	10709	Business	61300.00
0005434215251	10709	Business	61300.00
0005434756546	10709	Business	61300.00
0005434215238	10709	Business	61300.00
0005434756712	10709	Business	61300.00
0005434756732	10709	Business	61300.00
0005434215240	10709	Business	61300.00
0005434756723	10709	Business	61300.00
0005434215231	10709	Business	61300.00
0005434215226	10709	Business	61300.00
0005434215255	10709	Economy	20400.00
0005434215257	10709	Economy	20400.00
0005434215258	10709	Economy	20400.00
0005434756626	10709	Economy	20400.00
0005434215237	10709	Economy	20400.00
0005434215249	10709	Economy	20400.00
0005434215244	10709	Economy	20400.00
0005434756524	10709	Economy	20400.00
0005434215256	10709	Economy	20400.00
0005434756605	10709	Economy	20400.00
0005434215265	10709	Economy	22500.00
0005434756721	10709	Economy	22500.00
0005434215230	10709	Economy	22500.00
0005434215253	10709	Economy	22500.00
0005434756727	10709	Economy	22500.00
0005434756696	10709	Economy	20400.00
0005434756796	10709	Economy	20400.00
0005434756740	10709	Economy	20400.00
0005434756661	10709	Economy	20400.00
0005434756481	10709	Economy	20400.00
0005434215243	10709	Economy	20400.00
0005434756733	10709	Economy	20400.00
0005434756705	10709	Economy	20400.00
0005434756797	10709	Economy	20400.00
0005434756734	10709	Economy	20400.00
0005434215223	10709	Economy	20400.00
0005434215250	10709	Economy	20400.00
0005434756720	10709	Economy	20400.00
0005434756731	10709	Economy	20400.00
0005434215262	10709	Economy	20400.00
0005434215229	10709	Economy	20400.00
0005434215252	10709	Economy	20400.00
0005434756614	10709	Economy	20400.00
0005434756758	10709	Economy	20400.00
0005434756468	10709	Economy	20400.00
0005434756628	10709	Economy	20400.00
0005434756693	10709	Economy	20400.00
0005434215234	10709	Economy	20400.00
0005434756682	10709	Economy	20400.00
0005434756665	10709	Economy	20400.00
0005434215261	10709	Economy	20400.00
0005434756644	10709	Economy	20400.00
0005434215263	10709	Economy	20400.00
0005434756708	10709	Economy	20400.00
0005434756545	10709	Economy	20400.00
0005434756627	10709	Economy	20400.00
0005434756666	10709	Economy	20400.00
0005434756579	10709	Economy	20400.00
0005434215242	10709	Economy	20400.00
0005434756467	10709	Economy	20400.00
0005434756760	10709	Economy	20400.00
0005434215233	10709	Economy	20400.00
0005434756645	10709	Economy	20400.00
0005434756422	10709	Economy	20400.00
0005434756525	10709	Economy	20400.00
0005434215232	10709	Economy	20400.00
0005434215266	10709	Economy	20400.00
0005434215248	10709	Economy	20400.00
0005434215225	10709	Economy	20400.00
0005434756722	10709	Economy	20400.00
0005434215235	10709	Economy	20400.00
0005434215228	10709	Economy	20400.00
0005434215264	10709	Economy	20400.00
0005434215241	10709	Economy	20400.00
0005434756798	10709	Economy	20400.00
0005434756823	10709	Economy	20400.00
0005434756811	10709	Economy	20400.00
0005434215254	10709	Economy	20400.00
0005434215267	10709	Economy	20400.00
0005434215224	10709	Economy	20400.00
0005434215259	10709	Economy	20400.00
0005434215260	10709	Economy	20400.00
0005434215246	10709	Economy	20400.00
0005434756660	10709	Economy	20400.00
0005434756735	10709	Economy	20400.00
0005434215245	10709	Economy	20400.00
0005434215227	10709	Economy	20400.00
0005434756679	10709	Economy	20400.00
0005434215222	10709	Economy	20400.00
0005434215236	10709	Economy	20400.00
0005434215239	10709	Economy	20400.00
0005434756795	10709	Economy	20400.00
0005434214743	28694	Business	61300.00
0005434214899	28694	Business	61300.00
0005434757018	28694	Business	61300.00
0005434757031	28694	Business	61300.00
0005434757038	28694	Business	61300.00
0005434214778	28694	Business	61300.00
0005434214572	28694	Business	61300.00
0005434214604	28694	Business	61300.00
0005434757016	28694	Business	61300.00
0005434214749	28694	Business	61300.00
0005434214605	28694	Economy	20400.00
0005434757021	28694	Economy	20400.00
0005434214665	28694	Economy	20400.00
0005434214712	28694	Economy	20400.00
0005434214717	28694	Economy	20400.00
0005434214747	28694	Economy	20400.00
0005434757041	28694	Economy	20400.00
0005434757052	28694	Economy	20400.00
0005434757026	28694	Economy	20400.00
0005434757051	28694	Economy	20400.00
0005434757023	28694	Economy	22500.00
0005434214647	28694	Economy	22500.00
0005434214980	28694	Economy	22500.00
0005434214797	28694	Economy	22500.00
0005434214816	28694	Economy	22500.00
0005434757042	28694	Economy	20400.00
0005434757015	28694	Economy	20400.00
0005434757024	28694	Economy	20400.00
0005434757039	28694	Economy	20400.00
0005434214674	28694	Economy	20400.00
0005434214666	28694	Economy	20400.00
0005434757045	28694	Economy	20400.00
0005434757034	28694	Economy	20400.00
0005434214715	28694	Economy	20400.00
0005434214750	28694	Economy	20400.00
0005434214626	28694	Economy	20400.00
0005434757030	28694	Economy	20400.00
0005434757049	28694	Economy	20400.00
0005434757040	28694	Economy	20400.00
0005434214748	28694	Economy	20400.00
0005434757048	28694	Economy	20400.00
0005434757007	28694	Economy	20400.00
0005434214683	28694	Economy	20400.00
0005434757013	28694	Economy	20400.00
0005434214742	28694	Economy	20400.00
0005434214763	28694	Economy	20400.00
0005434214753	28694	Economy	20400.00
0005434214825	28694	Economy	20400.00
0005434757036	28694	Economy	20400.00
0005434757014	28694	Economy	20400.00
0005434757043	28694	Economy	20400.00
0005434757025	28694	Economy	20400.00
0005434214981	28694	Economy	20400.00
0005434214664	28694	Economy	20400.00
0005434214789	28694	Economy	20400.00
0005434757037	28694	Economy	20400.00
0005434214926	28694	Economy	20400.00
0005434757050	28694	Economy	20400.00
0005434757012	28694	Economy	20400.00
0005434757009	28694	Economy	20400.00
0005434214787	28694	Economy	20400.00
0005434757027	28694	Economy	20400.00
0005434757020	28694	Economy	20400.00
0005434214798	28694	Economy	20400.00
0005434214676	28694	Economy	20400.00
0005434214684	28694	Economy	20400.00
0005434757011	28694	Economy	20400.00
0005434757044	28694	Economy	20400.00
0005434757017	28694	Economy	20400.00
0005434214788	28694	Economy	20400.00
0005434757022	28694	Economy	20400.00
0005434214673	28694	Economy	20400.00
0005434757032	28694	Economy	20400.00
0005434757019	28694	Economy	20400.00
0005434214713	28694	Economy	20400.00
0005434757035	28694	Economy	20400.00
0005434214603	28694	Economy	20400.00
0005434214675	28694	Economy	20400.00
0005434214700	28694	Economy	20400.00
0005434757029	28694	Economy	20400.00
0005434757028	28694	Economy	20400.00
0005434757047	28694	Economy	20400.00
0005434757010	28694	Economy	20400.00
0005434757008	28694	Economy	20400.00
0005434214571	28694	Economy	20400.00
0005434214894	28694	Economy	20400.00
0005434757046	28694	Economy	20400.00
0005434214670	28694	Economy	20400.00
0005434214582	28694	Economy	20400.00
0005434757033	28694	Economy	20400.00
0005434214947	28694	Economy	20400.00
0005434229488	5463	Business	29500.00
0005435040732	5463	Business	29500.00
0005434229458	5463	Business	29500.00
0005434229456	5463	Business	29500.00
0005435040742	5463	Business	29500.00
0005435040726	5463	Business	29500.00
0005435040753	5463	Business	29500.00
0005435007383	5463	Business	29500.00
0005435040781	5463	Business	29500.00
0005434229521	5463	Business	29500.00
0005435040764	5463	Business	29500.00
0005435040725	5463	Business	29500.00
0005435040739	5463	Economy	9800.00
0005435040729	5463	Economy	9800.00
0005434229490	5463	Economy	9800.00
0005435040765	5463	Economy	9800.00
0005435040718	5463	Economy	9800.00
0005434229424	5463	Economy	9800.00
0005435040717	5463	Economy	9800.00
0005434229510	5463	Economy	9800.00
0005435040741	5463	Economy	9800.00
0005435007392	5463	Economy	9800.00
0005435007380	5463	Economy	9800.00
0005435040755	5463	Economy	9800.00
0005434229602	5463	Economy	9800.00
0005432125564	5463	Economy	9800.00
0005434229478	5463	Economy	9800.00
0005435040759	5463	Economy	9800.00
0005435007386	5463	Economy	9800.00
0005435007384	5463	Economy	9800.00
0005435040751	5463	Economy	9800.00
0005432125563	5463	Economy	9800.00
0005435040760	5463	Economy	9800.00
0005435040783	5463	Economy	9800.00
0005435040716	5463	Economy	9800.00
0005435040736	5463	Economy	9800.00
0005434229517	5463	Economy	9800.00
0005435040776	5463	Economy	9800.00
0005434229561	5463	Economy	9800.00
0005435040721	5463	Economy	9800.00
0005434229452	5463	Economy	9800.00
0005435007391	5463	Economy	9800.00
0005435040773	5463	Economy	9800.00
0005432125562	5463	Economy	9800.00
0005435007400	5463	Economy	9800.00
0005435040744	5463	Economy	9800.00
0005435040745	5463	Economy	9800.00
0005435040715	5463	Economy	9800.00
0005435040730	5463	Economy	9800.00
0005435040777	5463	Economy	9800.00
0005435040723	5463	Economy	9800.00
0005435040771	5463	Economy	10800.00
0005435007395	5463	Economy	10800.00
0005435040734	5463	Economy	10800.00
0005435007401	5463	Economy	10800.00
0005435007397	5463	Economy	10800.00
0005434229455	5463	Economy	9800.00
0005435040724	5463	Economy	9800.00
0005434229519	5463	Economy	9800.00
0005432125565	5463	Economy	9800.00
0005434229509	5463	Economy	9800.00
0005435040722	5463	Economy	9800.00
0005434229600	5463	Economy	9800.00
0005435007388	5463	Economy	9800.00
0005435040737	5463	Economy	9800.00
0005435007382	5463	Economy	9800.00
0005435007398	5463	Economy	9800.00
0005435040758	5463	Economy	9800.00
0005435007387	5463	Economy	9800.00
0005435040746	5463	Economy	9800.00
0005435040779	5463	Economy	9800.00
0005435040766	5463	Economy	9800.00
0005435040731	5463	Economy	9800.00
0005435007399	5463	Economy	9800.00
0005435007381	5463	Economy	9800.00
0005435007389	5463	Economy	9800.00
0005435040756	5463	Economy	9800.00
0005435040774	5463	Economy	9800.00
0005435040749	5463	Economy	9800.00
0005434229515	5463	Economy	9800.00
0005435040743	5463	Economy	9800.00
0005435040719	5463	Economy	9800.00
0005435040748	5463	Economy	9800.00
0005434229514	5463	Economy	9800.00
0005434229518	5463	Economy	9800.00
0005432125566	5463	Economy	9800.00
0005435040747	5463	Economy	9800.00
0005435040757	5463	Economy	9800.00
0005435040735	5463	Economy	9800.00
0005435040768	5463	Economy	9800.00
0005434229537	5463	Economy	9800.00
0005435040772	5463	Economy	9800.00
0005434229536	5463	Economy	9800.00
0005434229472	5463	Economy	9800.00
0005435040740	5463	Economy	9800.00
0005432125567	5463	Economy	9800.00
0005435007385	5463	Economy	9800.00
0005435040728	5463	Economy	9800.00
0005435040752	5463	Economy	9800.00
0005435040767	5463	Economy	9800.00
0005435040727	5463	Economy	9800.00
0005435040750	5463	Economy	9800.00
0005434229601	5463	Economy	9800.00
0005434229459	5463	Economy	9800.00
0005435040720	5463	Economy	9800.00
0005435040733	5463	Economy	9800.00
0005435007390	5463	Economy	9800.00
0005435040770	5463	Economy	9800.00
0005435007394	5463	Economy	9800.00
0005435040780	5463	Economy	9800.00
0005435040775	5463	Economy	9800.00
0005435040763	5463	Economy	9800.00
0005435040761	5463	Economy	9800.00
0005435040738	5463	Economy	9800.00
0005435040762	5463	Economy	9800.00
0005435040778	5463	Economy	9800.00
0005435040769	5463	Economy	9800.00
0005435007393	5463	Economy	9800.00
0005435040782	5463	Economy	9800.00
0005435040754	5463	Economy	9800.00
0005435007396	5463	Economy	9800.00
0005435040127	12986	Business	29500.00
0005435043291	12986	Business	29500.00
0005434229712	12986	Business	29500.00
0005435040185	12986	Business	29500.00
0005434229728	12986	Business	29500.00
0005435007089	12986	Business	29500.00
0005435007192	12986	Business	29500.00
0005434229707	12986	Business	29500.00
0005435040369	12986	Business	29500.00
0005435007246	12986	Business	29500.00
0005435040220	12986	Business	29500.00
0005435040247	12986	Economy	9800.00
0005434229715	12986	Economy	9800.00
0005435040054	12986	Economy	9800.00
0005435040326	12986	Economy	9800.00
0005435040081	12986	Economy	9800.00
0005435007162	12986	Economy	9800.00
0005435040186	12986	Economy	9800.00
0005434229721	12986	Economy	9800.00
0005435040468	12986	Economy	9800.00
0005435040232	12986	Economy	9800.00
0005435007110	12986	Economy	9800.00
0005435040203	12986	Economy	9800.00
0005434229724	12986	Economy	9800.00
0005435040264	12986	Economy	9800.00
0005435040094	12986	Economy	9800.00
0005435040204	12986	Economy	9800.00
0005434229714	12986	Economy	9800.00
0005435040205	12986	Economy	9800.00
0005435040271	12986	Economy	9800.00
0005435040487	12986	Economy	9800.00
0005435040206	12986	Economy	9800.00
0005434229722	12986	Economy	9800.00
0005435007088	12986	Economy	9800.00
0005435377908	12986	Economy	9800.00
0005435007190	12986	Economy	9800.00
0005435039914	12986	Economy	9800.00
0005435040343	12986	Economy	9800.00
0005435007123	12986	Economy	9800.00
0005435040108	12986	Economy	9800.00
0005435040193	12986	Economy	9800.00
0005434229716	12986	Economy	9800.00
0005435040368	12986	Economy	9800.00
0005435040299	12986	Economy	9800.00
0005434229709	12986	Economy	9800.00
0005435377909	12986	Economy	9800.00
0005432304458	12986	Economy	9800.00
0005435040107	12986	Economy	9800.00
0005435040342	12986	Economy	10800.00
0005435007236	12986	Economy	10800.00
0005435040106	12986	Economy	10800.00
0005435040278	12986	Economy	10800.00
0005434229723	12986	Economy	9800.00
0005435040190	12986	Economy	9800.00
0005435040179	12986	Economy	9800.00
0005435040171	12986	Economy	9800.00
0005434229710	12986	Economy	9800.00
0005435040372	12986	Economy	9800.00
0005435040296	12986	Economy	9800.00
0005432304459	12986	Economy	9800.00
0005434229706	12986	Economy	9800.00
0005435040126	12986	Economy	9800.00
0005434229711	12986	Economy	9800.00
0005435040236	12986	Economy	9800.00
0005435043290	12986	Economy	9800.00
0005434229713	12986	Economy	9800.00
0005435040114	12986	Economy	9800.00
0005435007061	12986	Economy	9800.00
0005434229708	12986	Economy	9800.00
0005435007248	12986	Economy	9800.00
0005435377907	12986	Economy	9800.00
0005435040030	12986	Economy	9800.00
0005435040191	12986	Economy	9800.00
0005435040438	12986	Economy	9800.00
0005434229727	12986	Economy	9800.00
0005435007141	12986	Economy	9800.00
0005435040039	12986	Economy	9800.00
0005435007118	12986	Economy	9800.00
0005435040057	12986	Economy	9800.00
0005435007191	12986	Economy	9800.00
0005435040194	12986	Economy	9800.00
0005435040187	12986	Economy	9800.00
0005435007193	12986	Economy	9800.00
0005434229726	12986	Economy	9800.00
0005435040265	12986	Economy	9800.00
0005435040049	12986	Economy	9800.00
0005435039915	12986	Economy	9800.00
0005435007224	12986	Economy	9800.00
0005435040128	12986	Economy	9800.00
0005435377906	12986	Economy	9800.00
0005434229725	12986	Economy	9800.00
0005435007247	12986	Economy	9800.00
0005435007119	12986	Economy	9800.00
0005435040031	12986	Economy	9800.00
0005434229717	12986	Economy	9800.00
0005435040161	12986	Economy	9800.00
0005435040469	12986	Economy	9800.00
0005434229719	12986	Economy	9800.00
0005435040082	12986	Economy	9800.00
0005435040209	12986	Economy	9800.00
0005434229718	12986	Economy	9800.00
0005435040071	12986	Economy	9800.00
0005434229720	12986	Economy	9800.00
0005435040129	12986	Economy	9800.00
0005435007194	12986	Economy	9800.00
0005435040109	12986	Economy	9800.00
0005435040282	12986	Economy	9800.00
0005435039966	12986	Economy	9800.00
0005435007060	12986	Economy	9800.00
0005435040367	12986	Economy	9800.00
0005435040295	12986	Economy	9800.00
0005435007133	12986	Economy	9800.00
0005435043288	12986	Economy	9800.00
0005435040176	12986	Economy	9800.00
0005435040149	12986	Economy	9800.00
0005434411840	14874	Business	52900.00
0005435902840	14874	Business	52900.00
0005434427022	14874	Business	52900.00
0005434427025	14874	Business	52900.00
0005435554209	14874	Business	52900.00
0005434427049	14874	Business	52900.00
0005435554217	14874	Business	52900.00
0005435902761	14874	Business	52900.00
0005434427020	14874	Business	52900.00
0005434427021	14874	Business	52900.00
0005435902829	14874	Economy	17600.00
0005434427048	14874	Economy	17600.00
0005434427029	14874	Economy	17600.00
0005434427033	14874	Economy	17600.00
0005434427047	14874	Economy	17600.00
0005435902786	14874	Economy	17600.00
0005434427024	14874	Economy	17600.00
0005435902815	14874	Economy	19400.00
0005434427040	14874	Economy	19400.00
0005435902816	14874	Economy	19400.00
0005435554215	14874	Economy	17600.00
0005434427039	14874	Economy	17600.00
0005435902828	14874	Economy	17600.00
0005435902827	14874	Economy	17600.00
0005432188653	14874	Economy	17600.00
0005435902777	14874	Economy	17600.00
0005434427046	14874	Economy	17600.00
0005435902810	14874	Economy	17600.00
0005435902858	14874	Economy	17600.00
0005435554218	14874	Economy	17600.00
0005435554199	14874	Economy	17600.00
0005435902760	14874	Economy	17600.00
0005434427019	14874	Economy	17600.00
0005435554216	14874	Economy	17600.00
0005434427023	14874	Economy	17600.00
0005434427027	14874	Economy	17600.00
0005434427041	14874	Economy	17600.00
0005434427031	14874	Economy	17600.00
0005434411841	14874	Economy	17600.00
0005435902866	14874	Economy	17600.00
0005434427028	14874	Economy	17600.00
0005434427043	14874	Economy	17600.00
0005434411842	14874	Economy	17600.00
0005434427044	14874	Economy	17600.00
0005434427032	14874	Economy	17600.00
0005434427034	14874	Economy	17600.00
0005434427045	14874	Economy	17600.00
0005435902785	14874	Economy	17600.00
0005435554200	14874	Economy	17600.00
0005435902813	14874	Economy	17600.00
0005432188656	14874	Economy	17600.00
0005434411838	14874	Economy	17600.00
0005435554201	14874	Economy	17600.00
0005434427030	14874	Economy	17600.00
0005434427042	14874	Economy	17600.00
0005434427026	14874	Economy	17600.00
0005432188654	14874	Economy	17600.00
0005435554219	14874	Economy	17600.00
0005434427038	14874	Economy	17600.00
0005434427035	14874	Economy	17600.00
0005434411839	14874	Economy	17600.00
0005435902788	14874	Economy	17600.00
0005435902722	14874	Economy	17600.00
0005432188655	14874	Economy	17600.00
0005435902814	14874	Economy	17600.00
0005435902839	14874	Economy	17600.00
0005435902780	14874	Economy	17600.00
0005434427036	14874	Economy	17600.00
0005435902809	14874	Economy	17600.00
0005434427037	14874	Economy	17600.00
0005434426850	20189	Business	52900.00
0005435902970	20189	Business	52900.00
0005434426895	20189	Business	52900.00
0005435554263	20189	Business	52900.00
0005434426903	20189	Business	52900.00
0005435902974	20189	Business	52900.00
0005434426851	20189	Business	52900.00
0005434426829	20189	Economy	17600.00
0005435902978	20189	Economy	17600.00
0005434426977	20189	Economy	17600.00
0005435902981	20189	Economy	17600.00
0005434426902	20189	Economy	17600.00
0005435554265	20189	Economy	17600.00
0005435902982	20189	Economy	19400.00
0005435902977	20189	Economy	19400.00
0005434426886	20189	Economy	17600.00
0005434426896	20189	Economy	17600.00
0005435902976	20189	Economy	17600.00
0005434426831	20189	Economy	17600.00
0005434411804	20189	Economy	17600.00
0005434426897	20189	Economy	17600.00
0005435902967	20189	Economy	17600.00
0005434426868	20189	Economy	17600.00
0005434426878	20189	Economy	17600.00
0005435902969	20189	Economy	17600.00
0005432059534	20189	Economy	17600.00
0005434426820	20189	Economy	17600.00
0005434426690	20189	Economy	17600.00
0005434426921	20189	Economy	17600.00
0005434426769	20189	Economy	17600.00
0005434426913	20189	Economy	17600.00
0005434426819	20189	Economy	17600.00
0005435554264	20189	Economy	17600.00
0005435902979	20189	Economy	17600.00
0005434426689	20189	Economy	17600.00
0005434426876	20189	Economy	17600.00
0005435554262	20189	Economy	17600.00
0005434426724	20189	Economy	17600.00
0005434426852	20189	Economy	17600.00
0005435902972	20189	Economy	17600.00
0005434426922	20189	Economy	17600.00
0005434426830	20189	Economy	17600.00
0005435902980	20189	Economy	17600.00
0005434411789	20189	Economy	17600.00
0005434426894	20189	Economy	17600.00
0005435902973	20189	Economy	17600.00
0005434426843	20189	Economy	17600.00
0005435902983	20189	Economy	17600.00
0005434426869	20189	Economy	17600.00
0005434426853	20189	Economy	17600.00
0005435902971	20189	Economy	17600.00
0005435902975	20189	Economy	17600.00
0005434426877	20189	Economy	17600.00
0005434426889	20189	Economy	17600.00
0005435554266	20189	Economy	17600.00
0005435902968	20189	Economy	17600.00
0005434426697	20189	Economy	17600.00
0005435902984	20189	Economy	17600.00
0005435554261	20189	Economy	17600.00
0005432059535	20189	Economy	17600.00
0005434426870	20189	Economy	17600.00
0005434426976	20189	Economy	17600.00
0005433434943	26499	Business	18500.00
0005433434618	26499	Business	18500.00
0005435982948	26499	Business	18500.00
0005435982961	26499	Business	18500.00
0005435982957	26499	Business	18500.00
0005433434829	26499	Business	18500.00
0005433434843	26499	Business	18500.00
0005433434850	26499	Business	18500.00
0005433434949	26499	Business	18500.00
0005433434856	26499	Economy	6200.00
0005432300348	26499	Economy	6200.00
0005433434867	26499	Economy	6200.00
0005432300345	26499	Economy	6200.00
0005435982966	26499	Economy	6200.00
0005435982954	26499	Economy	6200.00
0005435982949	26499	Economy	6200.00
0005433434848	26499	Economy	6200.00
0005435982941	26499	Economy	6200.00
0005433434831	26499	Economy	6200.00
0005433434945	26499	Economy	6800.00
0005435982951	26499	Economy	6800.00
0005435982963	26499	Economy	6800.00
0005435982965	26499	Economy	6800.00
0005435982977	26499	Economy	6800.00
0005435982981	26499	Economy	6200.00
0005432300346	26499	Economy	6200.00
0005435982971	26499	Economy	6200.00
0005435982973	26499	Economy	6200.00
0005433434851	26499	Economy	6200.00
0005435982972	26499	Economy	6200.00
0005433434950	26499	Economy	6200.00
0005435982946	26499	Economy	6200.00
0005433434875	26499	Economy	6200.00
0005433434795	26499	Economy	6200.00
0005433434830	26499	Economy	6200.00
0005435982959	26499	Economy	6200.00
0005433434888	26499	Economy	6200.00
0005434273095	26499	Economy	6200.00
0005435982955	26499	Economy	6200.00
0005433434833	26499	Economy	6200.00
0005433434941	26499	Economy	6200.00
0005435982975	26499	Economy	6200.00
0005435982956	26499	Economy	6200.00
0005433434944	26499	Economy	6200.00
0005435982943	26499	Economy	6200.00
0005435982964	26499	Economy	6200.00
0005435982968	26499	Economy	6200.00
0005435982960	26499	Economy	6200.00
0005433434940	26499	Economy	6200.00
0005433434822	26499	Economy	6200.00
0005435982958	26499	Economy	6200.00
0005433434942	26499	Economy	6200.00
0005435982970	26499	Economy	6200.00
0005432300349	26499	Economy	6200.00
0005435982979	26499	Economy	6200.00
0005433434796	26499	Economy	6200.00
0005435982980	26499	Economy	6200.00
0005433435010	26499	Economy	6200.00
0005433434849	26499	Economy	6200.00
0005433434745	26499	Economy	6200.00
0005433434828	26499	Economy	6200.00
0005435982962	26499	Economy	6200.00
0005435982969	26499	Economy	6200.00
0005435982947	26499	Economy	6200.00
0005434270225	26499	Economy	6200.00
0005435982978	26499	Economy	6200.00
0005433434859	26499	Economy	6200.00
0005434270215	26499	Economy	6200.00
0005435982974	26499	Economy	6200.00
0005435982976	26499	Economy	6200.00
0005435982945	26499	Economy	6200.00
0005433434916	26499	Economy	6200.00
0005433434902	26499	Economy	6200.00
0005432300350	26499	Economy	6200.00
0005433434836	26499	Economy	6200.00
0005433434832	26499	Economy	6200.00
0005435982950	26499	Economy	6200.00
0005435982952	26499	Economy	6200.00
0005435982953	26499	Economy	6200.00
0005433434835	26499	Economy	6200.00
0005435982942	26499	Economy	6200.00
0005435982967	26499	Economy	6200.00
0005433434887	26499	Economy	6200.00
0005432300347	26499	Economy	6200.00
0005434270216	26499	Economy	6200.00
0005433434800	26499	Economy	6200.00
0005435982944	26499	Economy	6200.00
0005433435106	26733	Business	18500.00
0005433435102	26733	Business	18500.00
0005432051176	26733	Business	18500.00
0005435982527	26733	Business	18500.00
0005433435126	26733	Business	18500.00
0005433435117	26733	Business	18500.00
0005435982329	26733	Business	18500.00
0005434270238	26733	Business	18500.00
0005434269136	26733	Business	18500.00
0005434271343	26733	Business	18500.00
0005435982621	26733	Business	18500.00
0005435982398	26733	Economy	6200.00
0005433435111	26733	Economy	6200.00
0005435982397	26733	Economy	6200.00
0005433435124	26733	Economy	6200.00
0005435982448	26733	Economy	6200.00
0005435982606	26733	Economy	6200.00
0005435982592	26733	Economy	6200.00
0005435982412	26733	Economy	6200.00
0005433435128	26733	Economy	6800.00
0005433435103	26733	Economy	6800.00
0005435982619	26733	Economy	6800.00
0005435982603	26733	Economy	6200.00
0005432051177	26733	Economy	6200.00
0005433435109	26733	Economy	6200.00
0005435982537	26733	Economy	6200.00
0005433435107	26733	Economy	6200.00
0005433435125	26733	Economy	6200.00
0005435982389	26733	Economy	6200.00
0005435982427	26733	Economy	6200.00
0005434269135	26733	Economy	6200.00
0005435982513	26733	Economy	6200.00
0005433435127	26733	Economy	6200.00
0005435982581	26733	Economy	6200.00
0005435982573	26733	Economy	6200.00
0005435982572	26733	Economy	6200.00
0005435982429	26733	Economy	6200.00
0005433435112	26733	Economy	6200.00
0005435982645	26733	Economy	6200.00
0005435982531	26733	Economy	6200.00
0005435982558	26733	Economy	6200.00
0005435982530	26733	Economy	6200.00
0005433435129	26733	Economy	6200.00
0005435982428	26733	Economy	6200.00
0005433435120	26733	Economy	6200.00
0005435982646	26733	Economy	6200.00
0005435982495	26733	Economy	6200.00
0005435982390	26733	Economy	6200.00
0005435982536	26733	Economy	6200.00
0005433435119	26733	Economy	6200.00
0005433435122	26733	Economy	6200.00
0005433435118	26733	Economy	6200.00
0005433435116	26733	Economy	6200.00
0005433435115	26733	Economy	6200.00
0005435982529	26733	Economy	6200.00
0005433435113	26733	Economy	6200.00
0005435982432	26733	Economy	6200.00
0005435982545	26733	Economy	6200.00
0005435982469	26733	Economy	6200.00
0005433435110	26733	Economy	6200.00
0005434270239	26733	Economy	6200.00
0005434270240	26733	Economy	6200.00
0005433435104	26733	Economy	6200.00
0005435982408	26733	Economy	6200.00
0005435982449	26733	Economy	6200.00
0005433435105	26733	Economy	6200.00
0005432051175	26733	Economy	6200.00
0005435982433	26733	Economy	6200.00
0005434271344	26733	Economy	6200.00
0005434271345	26733	Economy	6200.00
0005435982591	26733	Economy	6200.00
0005435982516	26733	Economy	6200.00
0005435982518	26733	Economy	6200.00
0005435982519	26733	Economy	6200.00
0005433435114	26733	Economy	6200.00
0005435982602	26733	Economy	6200.00
0005433435123	26733	Economy	6200.00
0005433435108	26733	Economy	6200.00
0005433435121	26733	Economy	6200.00
0005432858140	3179	Economy	11100.00
0005432584410	3179	Economy	11100.00
0005432216315	3179	Economy	11100.00
0005432584415	3179	Economy	11100.00
0005432858131	3179	Economy	10100.00
0005432584433	3179	Economy	10100.00
0005432584416	3179	Economy	10100.00
0005432858170	3179	Economy	10100.00
0005432584430	3179	Economy	10100.00
0005432584418	3179	Economy	10100.00
0005432584429	3179	Economy	10100.00
0005432858139	3179	Economy	10100.00
0005432584426	3179	Economy	10100.00
0005432584431	3179	Economy	10100.00
0005432584411	3179	Economy	10100.00
0005432858133	3179	Economy	10100.00
0005432584414	3179	Economy	10100.00
0005432858135	3179	Economy	10100.00
0005432584422	3179	Economy	10100.00
0005432584425	3179	Economy	10100.00
0005432216314	3179	Economy	10100.00
0005432858143	3179	Economy	10100.00
0005432584421	3179	Economy	10100.00
0005432584419	3179	Economy	10100.00
0005432216317	3179	Economy	10100.00
0005432858169	3179	Economy	10100.00
0005432858167	3179	Economy	10100.00
0005432584420	3179	Economy	10100.00
0005432584412	3179	Economy	10100.00
0005432584432	3179	Economy	10100.00
0005432584423	3179	Economy	10100.00
0005432584428	3179	Economy	10100.00
0005432584427	3179	Economy	10100.00
0005432216316	3179	Economy	10100.00
0005432858165	3179	Economy	10100.00
0005432584409	3179	Economy	10100.00
0005432584417	3179	Economy	10100.00
0005432584413	3179	Economy	10100.00
0005432858141	3179	Economy	10100.00
0005432584424	3179	Economy	10100.00
0005432584166	31470	Economy	11100.00
0005432584163	31470	Economy	11100.00
0005432584347	31470	Economy	11100.00
0005432584275	31470	Economy	11100.00
0005432858257	31470	Economy	10100.00
0005432584254	31470	Economy	10100.00
0005432858259	31470	Economy	10100.00
0005432584198	31470	Economy	10100.00
0005432584346	31470	Economy	10100.00
0005432584246	31470	Economy	10100.00
0005432584222	31470	Economy	10100.00
0005432584297	31470	Economy	10100.00
0005432858256	31470	Economy	10100.00
0005432584200	31470	Economy	10100.00
0005432584274	31470	Economy	10100.00
0005432858252	31470	Economy	10100.00
0005432858251	31470	Economy	10100.00
0005432584241	31470	Economy	10100.00
0005432858254	31470	Economy	10100.00
0005432584164	31470	Economy	10100.00
0005432584253	31470	Economy	10100.00
0005432584167	31470	Economy	10100.00
0005432858249	31470	Economy	10100.00
0005432584157	31470	Economy	10100.00
0005432858258	31470	Economy	10100.00
0005432584216	31470	Economy	10100.00
0005432584182	31470	Economy	10100.00
0005432584245	31470	Economy	10100.00
0005432584345	31470	Economy	10100.00
0005432584142	31470	Economy	10100.00
0005432584189	31470	Economy	10100.00
0005432584208	31470	Economy	10100.00
0005432584256	31470	Economy	10100.00
0005432584257	31470	Economy	10100.00
0005432584199	31470	Economy	10100.00
0005432584150	31470	Economy	10100.00
0005432584215	31470	Economy	10100.00
0005432858253	31470	Economy	10100.00
0005432858255	31470	Economy	10100.00
0005432858250	31470	Economy	10100.00
0005432584238	31470	Economy	10100.00
0005432584149	31470	Economy	10100.00
0005434943488	908	Economy	7500.00
0005433255138	908	Economy	7500.00
0005433255140	908	Economy	7500.00
0005434943494	908	Economy	7500.00
0005434943490	908	Economy	7500.00
0005434943489	908	Economy	7500.00
0005433255157	908	Economy	7500.00
0005433255141	908	Economy	7500.00
0005434943492	908	Economy	7500.00
0005434943497	908	Economy	7500.00
0005434943493	908	Economy	7500.00
0005434943496	908	Economy	7500.00
0005434943495	908	Economy	7500.00
0005434943491	908	Economy	7500.00
0005434943423	16195	Economy	7500.00
0005433255204	16195	Economy	7500.00
0005434943451	16195	Economy	7500.00
0005434943424	16195	Economy	7500.00
0005433255203	16195	Economy	7500.00
0005433255201	16195	Economy	7500.00
0005433255202	16195	Economy	7500.00
0005434943403	16195	Economy	7500.00
0005434943430	16195	Economy	7500.00
0005434943416	16195	Economy	7500.00
0005434943418	16195	Economy	7500.00
0005434943431	16195	Economy	7500.00
0005433654895	4334	Business	90500.00
0005433654875	4334	Business	90500.00
0005433654896	4334	Business	90500.00
0005433654880	4334	Business	90500.00
0005433654871	4334	Business	90500.00
0005433654868	4334	Business	90500.00
0005435858568	4334	Economy	30200.00
0005433654881	4334	Economy	30200.00
0005435858581	4334	Economy	30200.00
0005433654882	4334	Economy	30200.00
0005433654894	4334	Economy	30200.00
0005433654884	4334	Economy	33200.00
0005435858559	4334	Economy	30200.00
0005433654870	4334	Economy	30200.00
0005433654890	4334	Economy	30200.00
0005435858569	4334	Economy	30200.00
0005435858597	4334	Economy	30200.00
0005435858582	4334	Economy	30200.00
0005433654874	4334	Economy	30200.00
0005435858563	4334	Economy	30200.00
0005435858599	4334	Economy	30200.00
0005433654877	4334	Economy	30200.00
0005433654876	4334	Economy	30200.00
0005433654892	4334	Economy	30200.00
0005433654885	4334	Economy	30200.00
0005433654883	4334	Economy	30200.00
0005433654865	4334	Economy	30200.00
0005433654872	4334	Economy	30200.00
0005435858585	4334	Economy	30200.00
0005433654888	4334	Economy	30200.00
0005435858598	4334	Economy	30200.00
0005433654867	4334	Economy	30200.00
0005433654889	4334	Economy	30200.00
0005435858588	4334	Economy	30200.00
0005435858567	4334	Economy	30200.00
0005435858583	4334	Economy	30200.00
0005433654878	4334	Economy	30200.00
0005433654891	4334	Economy	30200.00
0005433654866	4334	Economy	30200.00
0005433654873	4334	Economy	30200.00
0005435858593	4334	Economy	30200.00
0005433654893	4334	Economy	30200.00
0005433654887	4334	Economy	30200.00
0005433654869	4334	Economy	30200.00
0005435858566	4334	Economy	30200.00
0005435858564	4334	Economy	30200.00
0005433654879	4334	Economy	30200.00
0005433654886	4334	Economy	30200.00
0005433368076	21725	Business	9800.00
0005435653667	21725	Business	9800.00
0005435653710	21725	Business	9800.00
0005435653703	21725	Business	9800.00
0005435653682	21725	Business	9800.00
0005435653685	21725	Business	9800.00
0005435653676	21725	Business	9800.00
0005435653694	21725	Business	9800.00
0005435653687	21725	Business	9800.00
0005435653708	21725	Business	9800.00
0005435653657	21725	Economy	3300.00
0005435653673	21725	Economy	3300.00
0005433368142	21725	Economy	3300.00
0005435653702	21725	Economy	3300.00
0005435653689	21725	Economy	3300.00
0005435653684	21725	Economy	3300.00
0005433368058	21725	Economy	3300.00
0005435653664	21725	Economy	3300.00
0005435653701	21725	Economy	3300.00
0005433368121	21725	Economy	3600.00
0005435653688	21725	Economy	3600.00
0005433368019	21725	Economy	3600.00
0005435653697	21725	Economy	3300.00
0005433368016	21725	Economy	3300.00
0005433368020	21725	Economy	3300.00
0005433368243	21725	Economy	3300.00
0005435653698	21725	Economy	3300.00
0005435653659	21725	Economy	3300.00
0005433368161	21725	Economy	3300.00
0005435653660	21725	Economy	3300.00
0005433368131	21725	Economy	3300.00
0005435653677	21725	Economy	3300.00
0005435653661	21725	Economy	3300.00
0005433368047	21725	Economy	3300.00
0005435653695	21725	Economy	3300.00
0005435653691	21725	Economy	3300.00
0005435653696	21725	Economy	3300.00
0005435653690	21725	Economy	3300.00
0005435653671	21725	Economy	3300.00
0005435653683	21725	Economy	3300.00
0005435653704	21725	Economy	3300.00
0005435653705	21725	Economy	3300.00
0005435653693	21725	Economy	3300.00
0005433368114	21725	Economy	3300.00
0005433367960	21725	Economy	3300.00
0005433367965	21725	Economy	3300.00
0005435653665	21725	Economy	3300.00
0005435653679	21725	Economy	3300.00
0005435653700	21725	Economy	3300.00
0005433368173	21725	Economy	3300.00
0005435653692	21725	Economy	3300.00
0005433368244	21725	Economy	3300.00
0005433367926	21725	Economy	3300.00
0005435653707	21725	Economy	3300.00
0005435653686	21725	Economy	3300.00
0005435653675	21725	Economy	3300.00
0005433368174	21725	Economy	3300.00
0005433368154	21725	Economy	3300.00
0005433368046	21725	Economy	3300.00
0005433368160	21725	Economy	3300.00
0005433368018	21725	Economy	3300.00
0005433367925	21725	Economy	3300.00
0005433367943	21725	Economy	3300.00
0005433367942	21725	Economy	3300.00
0005433368034	21725	Economy	3300.00
0005435653669	21725	Economy	3300.00
0005435653674	21725	Economy	3300.00
0005435653656	21725	Economy	3300.00
0005433368140	21725	Economy	3300.00
0005433368184	21725	Economy	3300.00
0005433368126	21725	Economy	3300.00
0005435653662	21725	Economy	3300.00
0005435653709	21725	Economy	3300.00
0005435653678	21725	Economy	3300.00
0005435653668	21725	Economy	3300.00
0005433368074	21725	Economy	3300.00
0005435653681	21725	Economy	3300.00
0005433367928	21725	Economy	3300.00
0005435653672	21725	Economy	3300.00
0005435653666	21725	Economy	3300.00
0005435653699	21725	Economy	3300.00
0005435653658	21725	Economy	3300.00
0005435653680	21725	Economy	3300.00
0005435653663	21725	Economy	3300.00
0005433368127	21725	Economy	3300.00
0005435653670	21725	Economy	3300.00
0005433368191	21725	Economy	3300.00
0005435653706	21725	Economy	3300.00
0005432657497	9375	Business	186200.00
0005433805884	9375	Business	186200.00
0005433785516	9375	Business	186200.00
0005435269781	9375	Business	186200.00
0005433785521	9375	Business	186200.00
0005433805889	9375	Business	186200.00
0005433805903	9375	Business	186200.00
0005433805911	9375	Business	186200.00
0005433805881	9375	Business	186200.00
0005433785483	9375	Business	186200.00
0005435269774	9375	Business	186200.00
0005433805913	9375	Business	186200.00
0005433785513	9375	Business	186200.00
0005433805905	9375	Business	186200.00
0005435269785	9375	Business	186200.00
0005433805898	9375	Business	186200.00
0005433763434	9375	Business	186200.00
0005435269770	9375	Business	186200.00
0005433805894	9375	Business	186200.00
0005434151710	9375	Business	186200.00
0005433785488	9375	Economy	68300.00
0005433805907	9375	Economy	68300.00
0005433805919	9375	Economy	62100.00
0005433763423	9375	Economy	62100.00
0005433785493	9375	Economy	62100.00
0005434171135	9375	Economy	62100.00
0005433805886	9375	Economy	62100.00
0005433785512	9375	Economy	62100.00
0005434171205	9375	Economy	62100.00
0005434273090	9375	Economy	62100.00
0005434171138	9375	Economy	62100.00
0005435269780	9375	Economy	62100.00
0005433763428	9375	Economy	62100.00
0005434270217	9375	Economy	62100.00
0005433785514	9375	Economy	62100.00
0005432665306	9375	Economy	62100.00
0005432665307	9375	Economy	62100.00
0005433763422	9375	Economy	62100.00
0005433805918	9375	Economy	62100.00
0005435269775	9375	Economy	62100.00
0005434171134	9375	Economy	62100.00
0005433785517	9375	Economy	62100.00
0005433785515	9375	Economy	62100.00
0005433785486	9375	Economy	62100.00
0005433785520	9375	Economy	62100.00
0005433805899	9375	Economy	62100.00
0005434273081	9375	Economy	62100.00
0005433785501	9375	Economy	62100.00
0005434151737	9375	Economy	62100.00
0005433785504	9375	Economy	62100.00
0005433805883	9375	Economy	62100.00
0005433785497	9375	Economy	62100.00
0005433785492	9375	Economy	62100.00
0005434273086	9375	Economy	62100.00
0005433785489	9375	Economy	62100.00
0005433785506	9375	Economy	62100.00
0005433785491	9375	Economy	62100.00
0005433805912	9375	Economy	62100.00
0005432657495	9375	Economy	62100.00
0005433805895	9375	Economy	62100.00
0005433763436	9375	Economy	62100.00
0005434171139	9375	Economy	62100.00
0005433785507	9375	Economy	62100.00
0005433785502	9375	Economy	62100.00
0005432666420	9375	Economy	62100.00
0005434151724	9375	Economy	62100.00
0005433805900	9375	Economy	62100.00
0005433805891	9375	Economy	62100.00
0005433785500	9375	Economy	62100.00
0005435269758	9375	Economy	62100.00
0005433805915	9375	Economy	62100.00
0005433785518	9375	Economy	62100.00
0005433805893	9375	Economy	62100.00
0005435269778	9375	Economy	62100.00
0005433785490	9375	Economy	62100.00
0005435269777	9375	Economy	62100.00
0005433785505	9375	Economy	62100.00
0005433785485	9375	Economy	62100.00
0005432666421	9375	Economy	62100.00
0005433805914	9375	Economy	62100.00
0005433785499	9375	Economy	62100.00
0005433785484	9375	Economy	62100.00
0005433785519	9375	Economy	62100.00
0005433805880	9375	Economy	62100.00
0005433805901	9375	Economy	62100.00
0005435269773	9375	Economy	62100.00
0005433805897	9375	Economy	62100.00
0005433763429	9375	Economy	62100.00
0005434273089	9375	Economy	62100.00
0005434273083	9375	Economy	62100.00
0005433805896	9375	Economy	62100.00
0005433785495	9375	Economy	68300.00
0005433785487	9375	Economy	62100.00
0005433763432	9375	Economy	68300.00
0005435269766	9375	Economy	68300.00
0005433805885	9375	Economy	62100.00
0005433805908	9375	Economy	62100.00
0005435269782	9375	Economy	62100.00
0005434171167	9375	Economy	62100.00
0005433805921	9375	Economy	62100.00
0005434171137	9375	Economy	62100.00
0005433805909	9375	Economy	62100.00
0005433805906	9375	Economy	62100.00
0005433785498	9375	Economy	62100.00
0005432657496	9375	Economy	62100.00
0005434171164	9375	Economy	62100.00
0005435269765	9375	Economy	62100.00
0005434171110	9375	Economy	62100.00
0005433763424	9375	Economy	62100.00
0005433785494	9375	Economy	62100.00
0005433805892	9375	Economy	62100.00
0005433785511	9375	Economy	62100.00
0005434171166	9375	Economy	62100.00
0005433785496	9375	Economy	62100.00
0005433785522	9375	Economy	62100.00
0005433763433	9375	Economy	62100.00
0005434270226	9375	Economy	62100.00
0005433785510	9375	Economy	62100.00
0005433785508	9375	Economy	62100.00
0005435269760	9375	Economy	62100.00
0005433805887	9375	Economy	62100.00
0005434171087	9375	Economy	62100.00
0005435269783	9375	Economy	62100.00
0005432667486	9375	Economy	62100.00
0005433785509	9375	Economy	62100.00
0005433763430	9375	Economy	62100.00
0005433805917	9375	Economy	62100.00
0005433785503	9375	Economy	62100.00
0005433805920	9375	Economy	62100.00
0005433763426	9375	Economy	62100.00
0005433805888	9375	Economy	62100.00
0005433805904	9375	Economy	62100.00
0005433805910	9375	Economy	62100.00
0005433763425	9375	Economy	62100.00
0005435269784	9375	Economy	62100.00
0005433763427	9375	Economy	62100.00
0005433805902	9375	Economy	62100.00
0005433763435	9375	Economy	62100.00
0005433805882	9375	Economy	62100.00
0005435269757	9375	Economy	62100.00
0005433805890	9375	Economy	62100.00
0005433763431	9375	Economy	62100.00
0005434171204	9375	Economy	62100.00
0005433805916	9375	Economy	62100.00
0005433763390	26239	Business	186200.00
0005433805650	26239	Business	186200.00
0005433785160	26239	Business	186200.00
0005433805652	26239	Business	186200.00
0005433805783	26239	Business	186200.00
0005433805581	26239	Business	186200.00
0005434171275	26239	Business	186200.00
0005433805740	26239	Business	186200.00
0005433785156	26239	Business	186200.00
0005433805576	26239	Business	186200.00
0005433805684	26239	Business	186200.00
0005433785046	26239	Business	186200.00
0005433785320	26239	Business	186200.00
0005432657468	26239	Business	186200.00
0005433785114	26239	Business	186200.00
0005434269133	26239	Business	186200.00
0005433805700	26239	Economy	68300.00
0005433805538	26239	Economy	68300.00
0005433785263	26239	Economy	68300.00
0005433805654	26239	Economy	68300.00
0005432657465	26239	Economy	62100.00
0005433805460	26239	Economy	62100.00
0005433805651	26239	Economy	62100.00
0005433805642	26239	Economy	62100.00
0005433805586	26239	Economy	62100.00
0005433805685	26239	Economy	62100.00
0005432666407	26239	Economy	62100.00
0005433763293	26239	Economy	62100.00
0005432657471	26239	Economy	62100.00
0005433763315	26239	Economy	62100.00
0005432663030	26239	Economy	62100.00
0005433785077	26239	Economy	62100.00
0005434171279	26239	Economy	62100.00
0005433785167	26239	Economy	62100.00
0005433763316	26239	Economy	62100.00
0005433763243	26239	Economy	62100.00
0005434171273	26239	Economy	62100.00
0005434171274	26239	Economy	62100.00
0005433805686	26239	Economy	62100.00
0005433763307	26239	Economy	62100.00
0005433785087	26239	Economy	62100.00
0005433805461	26239	Economy	62100.00
0005434171281	26239	Economy	62100.00
0005433805548	26239	Economy	62100.00
0005434151749	26239	Economy	62100.00
0005433763290	26239	Economy	62100.00
0005435269876	26239	Economy	62100.00
0005433763391	26239	Economy	62100.00
0005433763234	26239	Economy	62100.00
0005433785238	26239	Economy	62100.00
0005433785159	26239	Economy	62100.00
0005433763319	26239	Economy	62100.00
0005433763337	26239	Economy	62100.00
0005434171277	26239	Economy	62100.00
0005433785048	26239	Economy	62100.00
0005433785282	26239	Economy	62100.00
0005433785131	26239	Economy	62100.00
0005434171280	26239	Economy	62100.00
0005434271341	26239	Economy	62100.00
0005433805511	26239	Economy	62100.00
0005433785201	26239	Economy	62100.00
0005433785211	26239	Economy	62100.00
0005432666406	26239	Economy	62100.00
0005434171272	26239	Economy	62100.00
0005434171276	26239	Economy	62100.00
0005433785146	26239	Economy	62100.00
0005433763262	26239	Economy	62100.00
0005433805587	26239	Economy	62100.00
0005433785057	26239	Economy	62100.00
0005433805687	26239	Economy	62100.00
0005433805699	26239	Economy	62100.00
0005435269878	26239	Economy	62100.00
0005433785139	26239	Economy	62100.00
0005434171278	26239	Economy	62100.00
0005434171271	26239	Economy	62100.00
0005433785262	26239	Economy	62100.00
0005433805688	26239	Economy	62100.00
0005433805582	26239	Economy	62100.00
0005432659719	26239	Economy	62100.00
0005433805557	26239	Economy	62100.00
0005434151748	26239	Economy	68300.00
0005433785210	26239	Economy	62100.00
0005433763320	26239	Economy	62100.00
0005433805549	26239	Economy	62100.00
0005435269877	26239	Economy	62100.00
0005435269874	26239	Economy	62100.00
0005433785325	26239	Economy	62100.00
0005432666401	26239	Economy	62100.00
0005433805641	26239	Economy	62100.00
0005433805680	26239	Economy	62100.00
0005433805594	26239	Economy	62100.00
0005434269132	26239	Economy	62100.00
0005434269134	26239	Economy	62100.00
0005433763325	26239	Economy	62100.00
0005432666402	26239	Economy	62100.00
0005433805681	26239	Economy	62100.00
0005435269875	26239	Economy	62100.00
0005434171269	26239	Economy	62100.00
0005432663055	26239	Economy	62100.00
0005434171267	26239	Economy	62100.00
0005433785171	26239	Economy	62100.00
0005432666405	26239	Economy	62100.00
0005434271342	26239	Economy	62100.00
0005433805555	26239	Economy	62100.00
0005433785239	26239	Economy	62100.00
0005433785231	26239	Economy	62100.00
0005434171270	26239	Economy	62100.00
0005433805782	26239	Economy	62100.00
0005433805558	26239	Economy	62100.00
0005433763331	26239	Economy	62100.00
0005433805452	26239	Economy	62100.00
0005433785166	26239	Economy	62100.00
0005433785130	26239	Economy	62100.00
0005433785283	26239	Economy	62100.00
0005433805679	26239	Economy	62100.00
0005433785045	26239	Economy	62100.00
0005433763303	26239	Economy	62100.00
0005433805698	26239	Economy	62100.00
0005433805763	26239	Economy	62100.00
0005434171268	26239	Economy	62100.00
0005433763292	26239	Economy	62100.00
0005433785319	26239	Economy	62100.00
0005433763364	26239	Economy	62100.00
0005435135747	4885	Economy	5300.00
0005435135745	4885	Economy	5300.00
0005435929659	4885	Economy	5300.00
0005435135746	4885	Economy	5300.00
0005435135744	4885	Economy	5300.00
0005435135743	4885	Economy	5300.00
0005435929686	33009	Economy	5300.00
0005435135716	33009	Economy	5300.00
0005435929685	33009	Economy	5300.00
0005435135720	33009	Economy	5300.00
0005434217978	9495	Economy	17900.00
0005434983364	9495	Economy	17900.00
0005434217982	9495	Economy	17900.00
0005434983368	9495	Economy	17900.00
0005434218003	9495	Economy	17900.00
0005434983367	9495	Economy	17900.00
0005434983366	9495	Economy	17900.00
0005434983365	9495	Economy	17900.00
0005434983369	9495	Economy	17900.00
0005434983300	27385	Economy	19700.00
0005434983338	27385	Economy	17900.00
0005434218032	27385	Economy	17900.00
0005434218031	27385	Economy	17900.00
0005434983339	27385	Economy	17900.00
0005434218030	27385	Economy	17900.00
0005433961186	24244	Business	36400.00
0005433961078	24244	Business	36400.00
0005433961018	24244	Business	36400.00
0005433986276	24244	Business	36400.00
0005433961041	24244	Business	36400.00
0005433986175	24244	Business	36400.00
0005433961199	24244	Business	36400.00
0005433986231	24244	Business	36400.00
0005433961069	24244	Business	36400.00
0005433960938	24244	Business	36400.00
0005433986206	24244	Business	36400.00
0005433961033	24244	Business	36400.00
0005433986296	24244	Business	36400.00
0005433961159	24244	Business	36400.00
0005433961219	24244	Business	36400.00
0005433961150	24244	Economy	13400.00
0005433986088	24244	Economy	13400.00
0005433961104	24244	Economy	12100.00
0005433961262	24244	Economy	12100.00
0005433961253	24244	Economy	12100.00
0005433986147	24244	Economy	12100.00
0005433961123	24244	Economy	12100.00
0005433986093	24244	Economy	12100.00
0005433961065	24244	Economy	12100.00
0005433961160	24244	Economy	12100.00
0005433961103	24244	Economy	12100.00
0005433986089	24244	Economy	12100.00
0005433986174	24244	Economy	12100.00
0005433986220	24244	Economy	12100.00
0005433961099	24244	Economy	12100.00
0005433961062	24244	Economy	12100.00
0005433986285	24244	Economy	12100.00
0005433961208	24244	Economy	12100.00
0005433961207	24244	Economy	12100.00
0005433960974	24244	Economy	12100.00
0005433961149	24244	Economy	12100.00
0005433961002	24244	Economy	12100.00
0005433986322	24244	Economy	12100.00
0005433961175	24244	Economy	12100.00
0005433985978	24244	Economy	12100.00
0005433986307	24244	Economy	12100.00
0005433961243	24244	Economy	12100.00
0005433961040	24244	Economy	12100.00
0005433986262	24244	Economy	12100.00
0005433986101	24244	Economy	12100.00
0005433986146	24244	Economy	12100.00
0005433961044	24244	Economy	12100.00
0005433986268	24244	Economy	12100.00
0005433961158	24244	Economy	12100.00
0005433961221	24244	Economy	12100.00
0005433961200	24244	Economy	12100.00
0005433986311	24244	Economy	12100.00
0005433986278	24244	Economy	12100.00
0005433986305	24244	Economy	12100.00
0005433986235	24244	Economy	12100.00
0005433986148	24244	Economy	12100.00
0005433986245	24244	Economy	12100.00
0005433961019	24244	Economy	12100.00
0005433961203	24244	Economy	12100.00
0005433961063	24244	Economy	12100.00
0005433986155	24244	Economy	12100.00
0005433986295	24244	Economy	12100.00
0005433961105	24244	Economy	12100.00
0005433986232	24244	Economy	12100.00
0005433961122	24244	Economy	12100.00
0005433961220	24244	Economy	12100.00
0005433986308	24244	Economy	12100.00
0005433986269	24244	Economy	12100.00
0005433961252	24244	Economy	13400.00
0005433986173	24244	Economy	12100.00
0005433961120	24244	Economy	12100.00
0005433986335	24244	Economy	13400.00
0005433986172	24244	Economy	12100.00
0005433986183	24244	Economy	12100.00
0005433961094	24244	Economy	12100.00
0005433986154	24244	Economy	12100.00
0005433986286	24244	Economy	12100.00
0005433986319	24244	Economy	12100.00
0005433961042	24244	Economy	12100.00
0005433986177	24244	Economy	12100.00
0005433961241	24244	Economy	12100.00
0005433961180	24244	Economy	12100.00
0005433961121	24244	Economy	12100.00
0005433961206	24244	Economy	12100.00
0005433985979	24244	Economy	12100.00
0005433961261	24244	Economy	12100.00
0005433986176	24244	Economy	12100.00
0005433960971	24244	Economy	12100.00
0005433961039	24244	Economy	12100.00
0005433986190	24244	Economy	12100.00
0005433961073	24244	Economy	12100.00
0005433960972	24244	Economy	12100.00
0005433986270	24244	Economy	12100.00
0005433961119	24244	Economy	12100.00
0005433961246	24244	Economy	12100.00
0005433960937	24244	Economy	12100.00
0005433986184	24244	Economy	12100.00
0005433961043	24244	Economy	12100.00
0005433961068	24244	Economy	12100.00
0005433986310	24244	Economy	12100.00
0005433961093	24244	Economy	12100.00
0005433986236	24244	Economy	12100.00
0005433986334	24244	Economy	12100.00
0005433961170	24244	Economy	12100.00
0005433986331	24244	Economy	12100.00
0005433961079	24244	Economy	12100.00
0005433961080	24244	Economy	12100.00
0005433961255	24244	Economy	12100.00
0005433986277	24244	Economy	12100.00
0005433986178	24244	Economy	12100.00
0005433986309	24244	Economy	12100.00
0005433986189	24244	Economy	12100.00
0005433986623	25906	Business	36400.00
0005433986615	25906	Business	36400.00
0005433986638	25906	Business	36400.00
0005433961685	25906	Business	36400.00
0005433961658	25906	Business	36400.00
0005433961710	25906	Business	36400.00
0005433961668	25906	Business	36400.00
0005433986607	25906	Business	36400.00
0005433961676	25906	Business	36400.00
0005433961673	25906	Business	36400.00
0005433961661	25906	Business	36400.00
0005433961669	25906	Business	36400.00
0005433961653	25906	Business	36400.00
0005433961689	25906	Economy	13400.00
0005433986629	25906	Economy	13400.00
0005433986630	25906	Economy	12100.00
0005433961659	25906	Economy	12100.00
0005433961700	25906	Economy	12100.00
0005433961672	25906	Economy	12100.00
0005433961701	25906	Economy	12100.00
0005433986606	25906	Economy	12100.00
0005433961675	25906	Economy	12100.00
0005433961662	25906	Economy	12100.00
0005433986634	25906	Economy	12100.00
0005433986618	25906	Economy	12100.00
0005433986624	25906	Economy	12100.00
0005433986625	25906	Economy	12100.00
0005433961679	25906	Economy	12100.00
0005433961708	25906	Economy	12100.00
0005433961678	25906	Economy	12100.00
0005433986631	25906	Economy	12100.00
0005433961690	25906	Economy	12100.00
0005433961712	25906	Economy	12100.00
0005433961666	25906	Economy	12100.00
0005433986640	25906	Economy	12100.00
0005433961707	25906	Economy	12100.00
0005433986613	25906	Economy	12100.00
0005433961677	25906	Economy	12100.00
0005433961693	25906	Economy	12100.00
0005433986611	25906	Economy	12100.00
0005433986633	25906	Economy	12100.00
0005433986610	25906	Economy	12100.00
0005433961694	25906	Economy	12100.00
0005433961664	25906	Economy	12100.00
0005433961674	25906	Economy	12100.00
0005433961681	25906	Economy	12100.00
0005433986632	25906	Economy	12100.00
0005433961682	25906	Economy	12100.00
0005433986642	25906	Economy	12100.00
0005433986636	25906	Economy	12100.00
0005433961697	25906	Economy	12100.00
0005433961680	25906	Economy	12100.00
0005433986635	25906	Economy	12100.00
0005433961684	25906	Economy	12100.00
0005433961655	25906	Economy	12100.00
0005433986643	25906	Economy	12100.00
0005433961698	25906	Economy	12100.00
0005433986604	25906	Economy	12100.00
0005433961656	25906	Economy	12100.00
0005433986639	25906	Economy	12100.00
0005433961650	25906	Economy	13400.00
0005433986627	25906	Economy	13400.00
0005433961702	25906	Economy	12100.00
0005433986608	25906	Economy	13400.00
0005433986641	25906	Economy	12100.00
0005433986603	25906	Economy	12100.00
0005433986609	25906	Economy	12100.00
0005433986645	25906	Economy	12100.00
0005433961704	25906	Economy	12100.00
0005433961660	25906	Economy	12100.00
0005433961695	25906	Economy	12100.00
0005433961703	25906	Economy	12100.00
0005433961686	25906	Economy	12100.00
0005433961654	25906	Economy	12100.00
0005433961671	25906	Economy	12100.00
0005433961651	25906	Economy	12100.00
0005433961670	25906	Economy	12100.00
0005433986616	25906	Economy	12100.00
0005433961711	25906	Economy	12100.00
0005433961691	25906	Economy	12100.00
0005433961709	25906	Economy	12100.00
0005433986614	25906	Economy	12100.00
0005433986621	25906	Economy	12100.00
0005433961665	25906	Economy	12100.00
0005433986605	25906	Economy	12100.00
0005433961688	25906	Economy	12100.00
0005433986646	25906	Economy	12100.00
0005433961667	25906	Economy	12100.00
0005433986617	25906	Economy	12100.00
0005433986626	25906	Economy	12100.00
0005433961699	25906	Economy	12100.00
0005433961706	25906	Economy	12100.00
0005433986602	25906	Economy	12100.00
0005433961683	25906	Economy	12100.00
0005433961687	25906	Economy	12100.00
0005433961657	25906	Economy	12100.00
0005433986620	25906	Economy	12100.00
0005433961692	25906	Economy	12100.00
0005433961705	25906	Economy	12100.00
0005433986619	25906	Economy	12100.00
0005433961696	25906	Economy	12100.00
0005433986612	25906	Economy	12100.00
0005433961663	25906	Economy	12100.00
0005433961652	25906	Economy	12100.00
0005433986622	25906	Economy	12100.00
0005433986644	25906	Economy	12100.00
0005433986637	25906	Economy	12100.00
0005433986628	25906	Economy	12100.00
0005434480714	958	Economy	25400.00
0005434480719	958	Economy	25400.00
0005433165980	958	Economy	25400.00
0005433165974	958	Economy	23100.00
0005434480721	958	Economy	23100.00
0005434480710	958	Economy	23100.00
0005434480726	958	Economy	23100.00
0005432269539	958	Economy	23100.00
0005434480727	958	Economy	23100.00
0005434480703	958	Economy	23100.00
0005433165986	958	Economy	23100.00
0005433166029	958	Economy	23100.00
0005434480717	958	Economy	23100.00
0005434480712	958	Economy	23100.00
0005433166023	958	Economy	23100.00
0005434480715	958	Economy	23100.00
0005432269538	958	Economy	23100.00
0005433166074	958	Economy	23100.00
0005433166027	958	Economy	23100.00
0005434480706	958	Economy	23100.00
0005434480718	958	Economy	23100.00
0005433165987	958	Economy	23100.00
0005434480728	958	Economy	23100.00
0005434480716	958	Economy	23100.00
0005434480725	958	Economy	23100.00
0005433166003	958	Economy	23100.00
0005434480722	958	Economy	23100.00
0005434480720	958	Economy	23100.00
0005433166031	958	Economy	23100.00
0005434480724	958	Economy	23100.00
0005433165973	958	Economy	23100.00
0005434480709	958	Economy	23100.00
0005433166030	958	Economy	23100.00
0005434480713	958	Economy	23100.00
0005433166024	958	Economy	23100.00
0005434480711	958	Economy	23100.00
0005434480708	958	Economy	23100.00
0005434480705	958	Economy	23100.00
0005434480707	958	Economy	23100.00
0005433165979	958	Economy	23100.00
0005434480704	958	Economy	23100.00
0005434480729	958	Economy	23100.00
0005434480723	958	Economy	23100.00
0005434480393	16589	Economy	25400.00
0005434480441	16589	Economy	25400.00
0005434480455	16589	Economy	25400.00
0005434480432	16589	Economy	23100.00
0005434480643	16589	Economy	23100.00
0005434480473	16589	Economy	23100.00
0005433166107	16589	Economy	23100.00
0005433166097	16589	Economy	23100.00
0005434480533	16589	Economy	23100.00
0005434480518	16589	Economy	23100.00
0005434480551	16589	Economy	23100.00
0005433166098	16589	Economy	23100.00
0005434480480	16589	Economy	23100.00
0005433166103	16589	Economy	23100.00
0005434480550	16589	Economy	23100.00
0005434480569	16589	Economy	23100.00
0005434480552	16589	Economy	23100.00
0005434480545	16589	Economy	23100.00
0005434480472	16589	Economy	23100.00
0005434480442	16589	Economy	23100.00
0005433166099	16589	Economy	23100.00
0005433166101	16589	Economy	23100.00
0005434480543	16589	Economy	23100.00
0005433166106	16589	Economy	23100.00
0005433166104	16589	Economy	23100.00
0005434480536	16589	Economy	23100.00
0005434480373	16589	Economy	23100.00
0005434480409	16589	Economy	23100.00
0005434480410	16589	Economy	23100.00
0005434480544	16589	Economy	23100.00
0005433166102	16589	Economy	23100.00
0005434480374	16589	Economy	23100.00
0005433166110	16589	Economy	23100.00
0005434480524	16589	Economy	23100.00
0005434480448	16589	Economy	23100.00
0005434480558	16589	Economy	23100.00
0005433166105	16589	Economy	23100.00
0005434480598	16589	Economy	23100.00
0005433166108	16589	Economy	23100.00
0005434480460	16589	Economy	23100.00
0005434480412	16589	Economy	23100.00
0005433166100	16589	Economy	23100.00
0005434480481	16589	Economy	23100.00
0005434480496	16589	Economy	23100.00
0005434480422	16589	Economy	23100.00
0005433166109	16589	Economy	23100.00
0005434480423	16589	Economy	23100.00
0005434480424	16589	Economy	23100.00
0005433872539	3201	Economy	17200.00
0005433872535	3201	Economy	17200.00
0005433872537	3201	Economy	17200.00
0005433872538	3201	Economy	17200.00
0005433872536	3201	Economy	17200.00
0005433872534	3201	Economy	17200.00
0005433872497	32548	Economy	17200.00
0005433872498	32548	Economy	17200.00
0005433872503	32548	Economy	17200.00
0005433872491	32548	Economy	17200.00
0005433872515	32548	Economy	17200.00
0005433872512	32548	Economy	17200.00
0005433872518	32548	Economy	17200.00
0005433872511	32548	Economy	17200.00
0005433872516	32548	Economy	17200.00
0005433289891	10350	Economy	17000.00
0005435150223	10350	Economy	17000.00
0005435142766	10350	Economy	17000.00
0005435150224	10350	Economy	15400.00
0005435150234	10350	Economy	15400.00
0005435142765	10350	Economy	15400.00
0005435386628	10350	Economy	15400.00
0005435150227	10350	Economy	15400.00
0005435386613	10350	Economy	15400.00
0005433289871	10350	Economy	15400.00
0005435150228	10350	Economy	15400.00
0005435386582	10350	Economy	15400.00
0005435150229	10350	Economy	15400.00
0005435386629	10350	Economy	15400.00
0005435150231	10350	Economy	15400.00
0005433289890	10350	Economy	15400.00
0005435142774	10350	Economy	15400.00
0005435142769	10350	Economy	15400.00
0005435386591	10350	Economy	15400.00
0005435150222	10350	Economy	15400.00
0005435386592	10350	Economy	15400.00
0005435150230	10350	Economy	15400.00
0005435386618	10350	Economy	15400.00
0005435142771	10350	Economy	15400.00
0005435142776	10350	Economy	15400.00
0005435142778	10350	Economy	15400.00
0005435150235	10350	Economy	15400.00
0005435142775	10350	Economy	15400.00
0005435386627	10350	Economy	15400.00
0005435142770	10350	Economy	15400.00
0005435150233	10350	Economy	15400.00
0005435386606	10350	Economy	15400.00
0005433289873	10350	Economy	15400.00
0005435150226	10350	Economy	15400.00
0005435142768	10350	Economy	15400.00
0005435150232	10350	Economy	15400.00
0005435142772	10350	Economy	15400.00
0005435150225	10350	Economy	15400.00
0005435386614	10350	Economy	15400.00
0005435386581	10350	Economy	15400.00
0005435142777	10350	Economy	15400.00
0005433289872	10350	Economy	15400.00
0005435142767	10350	Economy	15400.00
0005435142773	10350	Economy	15400.00
0005435142598	21943	Economy	17000.00
0005435150101	21943	Economy	17000.00
0005435150152	21943	Economy	17000.00
0005435150160	21943	Economy	17000.00
0005435386668	21943	Economy	15400.00
0005435142718	21943	Economy	15400.00
0005435142629	21943	Economy	15400.00
0005435150097	21943	Economy	15400.00
0005435150084	21943	Economy	15400.00
0005435386673	21943	Economy	15400.00
0005435386672	21943	Economy	15400.00
0005435386667	21943	Economy	15400.00
0005435150141	21943	Economy	15400.00
0005435150095	21943	Economy	15400.00
0005435150100	21943	Economy	15400.00
0005435386670	21943	Economy	15400.00
0005435142626	21943	Economy	15400.00
0005435142686	21943	Economy	15400.00
0005435142737	21943	Economy	15400.00
0005435150082	21943	Economy	15400.00
0005435150081	21943	Economy	15400.00
0005435386671	21943	Economy	15400.00
0005435142630	21943	Economy	15400.00
0005433289965	21943	Economy	15400.00
0005433289966	21943	Economy	15400.00
0005435150130	21943	Economy	15400.00
0005433289963	21943	Economy	15400.00
0005435150132	21943	Economy	15400.00
0005433289962	21943	Economy	15400.00
0005433289968	21943	Economy	15400.00
0005435150094	21943	Economy	15400.00
0005435142717	21943	Economy	15400.00
0005435150080	21943	Economy	15400.00
0005433289969	21943	Economy	15400.00
0005433289964	21943	Economy	15400.00
0005435150083	21943	Economy	15400.00
0005435150079	21943	Economy	15400.00
0005435150111	21943	Economy	15400.00
0005435142625	21943	Economy	15400.00
0005433289967	21943	Economy	15400.00
0005435386669	21943	Economy	15400.00
0005435150131	21943	Economy	15400.00
0005435142719	21943	Economy	15400.00
0005435502505	11211	Business	57200.00
0005435502371	11211	Business	57200.00
0005434573558	11211	Business	57200.00
0005434573557	11211	Business	57200.00
0005435545787	11211	Business	57200.00
0005435502462	11211	Business	57200.00
0005435529354	11211	Business	57200.00
0005435529400	11211	Business	57200.00
0005435502490	11211	Economy	19100.00
0005435502388	11211	Economy	19100.00
0005435502488	11211	Economy	19100.00
0005435529339	11211	Economy	19100.00
0005435502504	11211	Economy	21000.00
0005435502487	11211	Economy	21000.00
0005435545811	11211	Economy	21000.00
0005435529414	11211	Economy	19100.00
0005435529468	11211	Economy	19100.00
0005435529425	11211	Economy	19100.00
0005434573560	11211	Economy	19100.00
0005435529388	11211	Economy	19100.00
0005434573552	11211	Economy	19100.00
0005435502500	11211	Economy	19100.00
0005434573562	11211	Economy	19100.00
0005435529389	11211	Economy	19100.00
0005435502387	11211	Economy	19100.00
0005435529358	11211	Economy	19100.00
0005434573561	11211	Economy	19100.00
0005435502370	11211	Economy	19100.00
0005434573553	11211	Economy	19100.00
0005435529512	11211	Economy	19100.00
0005435529376	11211	Economy	19100.00
0005435529375	11211	Economy	19100.00
0005435319631	11211	Economy	19100.00
0005435529362	11211	Economy	19100.00
0005435529405	11211	Economy	19100.00
0005435529459	11211	Economy	19100.00
0005435529415	11211	Economy	19100.00
0005435502491	11211	Economy	19100.00
0005435545807	11211	Economy	19100.00
0005435319618	11211	Economy	19100.00
0005435502410	11211	Economy	19100.00
0005434573555	11211	Economy	19100.00
0005435529453	11211	Economy	19100.00
0005435529460	11211	Economy	19100.00
0005435502428	11211	Economy	19100.00
0005435545828	11211	Economy	19100.00
0005435529350	11211	Economy	19100.00
0005434573559	11211	Economy	19100.00
0005435529426	11211	Economy	19100.00
0005435529381	11211	Economy	19100.00
0005435529500	11211	Economy	19100.00
0005435502464	11211	Economy	19100.00
0005435545814	11211	Economy	19100.00
0005435319606	11211	Economy	19100.00
0005435319603	11211	Economy	19100.00
0005435502467	11211	Economy	19100.00
0005435319626	11211	Economy	19100.00
0005435529417	11211	Economy	19100.00
0005435529340	11211	Economy	19100.00
0005435502477	11211	Economy	19100.00
0005435502447	11211	Economy	19100.00
0005435529416	11211	Economy	19100.00
0005435529374	11211	Economy	19100.00
0005435529318	11211	Economy	19100.00
0005435529452	11211	Economy	19100.00
0005434573551	11211	Economy	19100.00
0005434573554	11211	Economy	19100.00
0005435529367	11211	Economy	19100.00
0005434573563	11211	Economy	19100.00
0005434573556	11211	Economy	19100.00
0005434573550	11211	Economy	19100.00
0005435529379	11211	Economy	19100.00
0005435518197	20940	Business	57200.00
0005435508520	20940	Business	57200.00
0005435502633	20940	Business	57200.00
0005435508528	20940	Business	57200.00
0005435508530	20940	Business	57200.00
0005435508532	20940	Business	57200.00
0005435319714	20940	Business	57200.00
0005435502632	20940	Business	57200.00
0005435508524	20940	Business	57200.00
0005435518178	20940	Business	57200.00
0005435518188	20940	Business	57200.00
0005435502621	20940	Economy	19100.00
0005435319719	20940	Economy	19100.00
0005434573458	20940	Economy	19100.00
0005435508517	20940	Economy	19100.00
0005435518182	20940	Economy	19100.00
0005435502623	20940	Economy	19100.00
0005435508526	20940	Economy	21000.00
0005432291966	20940	Economy	21000.00
0005435518184	20940	Economy	21000.00
0005435518194	20940	Economy	21000.00
0005435319720	20940	Economy	21000.00
0005435502624	20940	Economy	19100.00
0005435502638	20940	Economy	19100.00
0005435508531	20940	Economy	19100.00
0005435319722	20940	Economy	19100.00
0005435518196	20940	Economy	19100.00
0005435518192	20940	Economy	19100.00
0005435508518	20940	Economy	19100.00
0005435502629	20940	Economy	19100.00
0005434573397	20940	Economy	19100.00
0005435502619	20940	Economy	19100.00
0005435502637	20940	Economy	19100.00
0005435502639	20940	Economy	19100.00
0005435518186	20940	Economy	19100.00
0005435319715	20940	Economy	19100.00
0005435319717	20940	Economy	19100.00
0005435518190	20940	Economy	19100.00
0005435518189	20940	Economy	19100.00
0005435508522	20940	Economy	19100.00
0005435518177	20940	Economy	19100.00
0005435319718	20940	Economy	19100.00
0005435502620	20940	Economy	19100.00
0005435502627	20940	Economy	19100.00
0005435502618	20940	Economy	19100.00
0005435502628	20940	Economy	19100.00
0005435502635	20940	Economy	19100.00
0005435518193	20940	Economy	19100.00
0005434573447	20940	Economy	19100.00
0005435518180	20940	Economy	19100.00
0005435508527	20940	Economy	19100.00
0005432291965	20940	Economy	19100.00
0005435518185	20940	Economy	19100.00
0005434573364	20940	Economy	19100.00
0005434573463	20940	Economy	19100.00
0005435508533	20940	Economy	19100.00
0005435518183	20940	Economy	19100.00
0005435518195	20940	Economy	19100.00
0005435508529	20940	Economy	19100.00
0005435518191	20940	Economy	19100.00
0005435502631	20940	Economy	19100.00
0005435518179	20940	Economy	19100.00
0005435518181	20940	Economy	19100.00
0005435502630	20940	Economy	19100.00
0005435508519	20940	Economy	19100.00
0005435508516	20940	Economy	19100.00
0005432291964	20940	Economy	19100.00
0005435502634	20940	Economy	19100.00
0005435508523	20940	Economy	19100.00
0005435518176	20940	Economy	19100.00
0005435518187	20940	Economy	19100.00
0005435508515	20940	Economy	19100.00
0005435502636	20940	Economy	19100.00
0005435508521	20940	Economy	19100.00
0005435508525	20940	Economy	19100.00
0005435502640	20940	Economy	19100.00
0005435502625	20940	Economy	19100.00
0005434573435	20940	Economy	19100.00
0005435319716	20940	Economy	19100.00
0005435319721	20940	Economy	19100.00
0005435502622	20940	Economy	19100.00
0005435502626	20940	Economy	19100.00
0005434573446	20940	Economy	19100.00
0005432693281	3008	Business	10300.00
0005432693289	3008	Business	10300.00
0005432693256	3008	Business	10300.00
0005432693328	3008	Business	10300.00
0005432693189	3008	Business	10300.00
0005432693314	3008	Economy	3400.00
0005432693234	3008	Economy	3400.00
0005432693280	3008	Economy	3400.00
0005432693171	3008	Economy	3400.00
0005432693173	3008	Economy	3800.00
0005432693327	3008	Economy	3400.00
0005432693288	3008	Economy	3400.00
0005432693182	3008	Economy	3400.00
0005432693207	3008	Economy	3400.00
0005432693266	3008	Economy	3400.00
0005432693213	3008	Economy	3400.00
0005432693265	3008	Economy	3400.00
0005432693183	3008	Economy	3400.00
0005432693212	3008	Economy	3400.00
0005432693172	3008	Economy	3400.00
0005432693333	3008	Economy	3400.00
0005432693269	3008	Economy	3400.00
0005432693235	3008	Economy	3400.00
0005432693264	3008	Economy	3400.00
0005432693315	3008	Economy	3400.00
0005432693206	3008	Economy	3400.00
0005432693319	3008	Economy	3400.00
0005432693320	3008	Economy	3400.00
0005432693161	3008	Economy	3400.00
0005432880960	3009	Business	10300.00
0005432707162	3009	Business	10300.00
0005433124032	3009	Business	10300.00
0005433124069	3009	Business	10300.00
0005432707156	3009	Business	10300.00
0005432707164	3009	Business	10300.00
0005433123917	3009	Business	10300.00
0005432707169	3009	Business	10300.00
0005433123988	3009	Business	10300.00
0005433124049	3009	Economy	3400.00
0005433124052	3009	Economy	3400.00
0005432707167	3009	Economy	3400.00
0005432707154	3009	Economy	3400.00
0005432707151	3009	Economy	3400.00
0005432217819	3009	Economy	3400.00
0005433124112	3009	Economy	3400.00
0005432707147	3009	Economy	3400.00
0005432707163	3009	Economy	3800.00
0005433123989	3009	Economy	3400.00
0005432707153	3009	Economy	3400.00
0005432880891	3009	Economy	3400.00
0005432880968	3009	Economy	3400.00
0005432880859	3009	Economy	3400.00
0005432707148	3009	Economy	3400.00
0005432217821	3009	Economy	3400.00
0005432880964	3009	Economy	3400.00
0005432707171	3009	Economy	3400.00
0005432707170	3009	Economy	3400.00
0005432707159	3009	Economy	3400.00
0005432707157	3009	Economy	3400.00
0005433124077	3009	Economy	3400.00
0005432707155	3009	Economy	3400.00
0005432880894	3009	Economy	3400.00
0005432880858	3009	Economy	3400.00
0005432707168	3009	Economy	3400.00
0005432707152	3009	Economy	3400.00
0005433194876	3009	Economy	3400.00
0005433124071	3009	Economy	3400.00
0005432880963	3009	Economy	3400.00
0005432880895	3009	Economy	3400.00
0005432880896	3009	Economy	3400.00
0005432880983	3009	Economy	3400.00
0005433124033	3009	Economy	3400.00
0005432880967	3009	Economy	3400.00
0005432707149	3009	Economy	3400.00
0005432880892	3009	Economy	3400.00
0005432217822	3009	Economy	3400.00
0005432707160	3009	Economy	3400.00
0005433124061	3009	Economy	3400.00
0005433123916	3009	Economy	3400.00
0005433194864	3009	Economy	3400.00
0005432707158	3009	Economy	3400.00
0005432707150	3009	Economy	3400.00
0005433124068	3009	Economy	3400.00
0005432707166	3009	Economy	3400.00
0005432707165	3009	Economy	3400.00
0005433124131	3009	Economy	3400.00
0005432880916	3009	Economy	3400.00
0005432707161	3009	Economy	3400.00
0005432217820	3009	Economy	3400.00
0005432707146	3009	Economy	3400.00
0005433124048	3009	Economy	3400.00
0005433124078	3009	Economy	3400.00
0005432880925	3009	Economy	3400.00
0005433124070	3009	Economy	3400.00
0005432693567	29904	Business	10300.00
0005432706925	29904	Business	10300.00
0005432881036	29904	Business	10300.00
0005432693556	29904	Business	10300.00
0005432707037	29904	Business	10300.00
0005432693548	29904	Business	10300.00
0005433124224	29904	Business	10300.00
0005432693557	29904	Business	10300.00
0005432881039	29904	Business	10300.00
0005432706966	29904	Business	10300.00
0005433124230	29904	Business	10300.00
0005432706985	29904	Business	10300.00
0005432693541	29904	Economy	3400.00
0005433124237	29904	Economy	3400.00
0005432707049	29904	Economy	3400.00
0005432881034	29904	Economy	3400.00
0005432706970	29904	Economy	3400.00
0005432707003	29904	Economy	3400.00
0005432706894	29904	Economy	3400.00
0005433124226	29904	Economy	3400.00
0005432706912	29904	Economy	3400.00
0005432881035	29904	Economy	3400.00
0005432693563	29904	Economy	3800.00
0005432881045	29904	Economy	3800.00
0005433124235	29904	Economy	3800.00
0005432706972	29904	Economy	3800.00
0005433124227	29904	Economy	3800.00
0005433124222	29904	Economy	3400.00
0005432693544	29904	Economy	3400.00
0005432706955	29904	Economy	3400.00
0005432693561	29904	Economy	3400.00
0005432693555	29904	Economy	3400.00
0005432706965	29904	Economy	3400.00
0005432881046	29904	Economy	3400.00
0005432707047	29904	Economy	3400.00
0005432707048	29904	Economy	3400.00
0005432693550	29904	Economy	3400.00
0005432707036	29904	Economy	3400.00
0005432693545	29904	Economy	3400.00
0005432707009	29904	Economy	3400.00
0005433124228	29904	Economy	3400.00
0005432693549	29904	Economy	3400.00
0005433124233	29904	Economy	3400.00
0005432693547	29904	Economy	3400.00
0005432881037	29904	Economy	3400.00
0005432707004	29904	Economy	3400.00
0005433124240	29904	Economy	3400.00
0005432881032	29904	Economy	3400.00
0005432693554	29904	Economy	3400.00
0005433124234	29904	Economy	3400.00
0005432693539	29904	Economy	3400.00
0005432881043	29904	Economy	3400.00
0005432706923	29904	Economy	3400.00
0005432693564	29904	Economy	3400.00
0005432706927	29904	Economy	3400.00
0005433124239	29904	Economy	3400.00
0005433124220	29904	Economy	3400.00
0005433124232	29904	Economy	3400.00
0005432881033	29904	Economy	3400.00
0005433124221	29904	Economy	3400.00
0005432693562	29904	Economy	3400.00
0005432706922	29904	Economy	3400.00
0005432706984	29904	Economy	3400.00
0005432693553	29904	Economy	3400.00
0005432693568	29904	Economy	3400.00
0005432881042	29904	Economy	3400.00
0005432693560	29904	Economy	3400.00
0005433124229	29904	Economy	3400.00
0005432706887	29904	Economy	3400.00
0005432693558	29904	Economy	3400.00
0005432693542	29904	Economy	3400.00
0005432881041	29904	Economy	3400.00
0005433124236	29904	Economy	3400.00
0005433124238	29904	Economy	3400.00
0005433124225	29904	Economy	3400.00
0005432706954	29904	Economy	3400.00
0005432693551	29904	Economy	3400.00
0005432693559	29904	Economy	3400.00
0005432693565	29904	Economy	3400.00
0005432693543	29904	Economy	3400.00
0005433124219	29904	Economy	3400.00
0005433124223	29904	Economy	3400.00
0005432881038	29904	Economy	3400.00
0005432881044	29904	Economy	3400.00
0005432706888	29904	Economy	3400.00
0005432693566	29904	Economy	3400.00
0005433124231	29904	Economy	3400.00
0005432693538	29904	Economy	3400.00
0005432693540	29904	Economy	3400.00
0005432693552	29904	Economy	3400.00
0005432706974	29904	Economy	3400.00
0005432693546	29904	Economy	3400.00
0005432706946	29904	Economy	3400.00
0005432881040	29904	Economy	3400.00
0005432707033	29904	Economy	3400.00
0005432707008	29904	Economy	3400.00
0005432707034	29904	Economy	3400.00
0005434980217	23651	Economy	4000.00
0005434980230	23651	Economy	4000.00
0005434980231	23651	Economy	4000.00
0005434988896	23651	Economy	4000.00
0005434980223	23651	Economy	3600.00
0005434980232	23651	Economy	3600.00
0005434980215	23651	Economy	3600.00
0005434980212	23651	Economy	3600.00
0005434980213	23651	Economy	3600.00
0005434980207	23651	Economy	3600.00
0005434980233	23651	Economy	3600.00
0005434980209	23651	Economy	3600.00
0005434980224	23651	Economy	3600.00
0005434980214	23651	Economy	3600.00
0005434980228	23651	Economy	3600.00
0005434980216	23651	Economy	3600.00
0005434980220	23651	Economy	3600.00
0005434988898	23651	Economy	3600.00
0005434980236	23651	Economy	3600.00
0005434980235	23651	Economy	3600.00
0005434988897	23651	Economy	3600.00
0005434988895	23651	Economy	3600.00
0005434980222	23651	Economy	3600.00
0005434980218	23651	Economy	3600.00
0005434980227	23651	Economy	3600.00
0005434980225	23651	Economy	3600.00
0005434980206	23651	Economy	3600.00
0005434988899	23651	Economy	3600.00
0005434980219	23651	Economy	3600.00
0005434988894	23651	Economy	3600.00
0005434980208	23651	Economy	3600.00
0005434980210	23651	Economy	3600.00
0005434980234	23651	Economy	3600.00
0005434980229	23651	Economy	3600.00
0005434980221	23651	Economy	3600.00
0005434980226	23651	Economy	3600.00
0005434980211	23651	Economy	3600.00
0005434979944	27532	Economy	4000.00
0005434979943	27532	Economy	4000.00
0005434988778	27532	Economy	4000.00
0005434980019	27532	Economy	4000.00
0005434988777	27532	Economy	3600.00
0005434979961	27532	Economy	3600.00
0005434980015	27532	Economy	3600.00
0005434979935	27532	Economy	3600.00
0005434979800	27532	Economy	3600.00
0005434980001	27532	Economy	3600.00
0005434979852	27532	Economy	3600.00
0005434979926	27532	Economy	3600.00
0005434980028	27532	Economy	3600.00
0005434988749	27532	Economy	3600.00
0005434979942	27532	Economy	3600.00
0005434979927	27532	Economy	3600.00
0005434980046	27532	Economy	3600.00
0005434979997	27532	Economy	3600.00
0005434980005	27532	Economy	3600.00
0005434980082	27532	Economy	3600.00
0005434979914	27532	Economy	3600.00
0005434980089	27532	Economy	3600.00
0005434979910	27532	Economy	3600.00
0005434979916	27532	Economy	3600.00
0005434980021	27532	Economy	3600.00
0005434979890	27532	Economy	3600.00
0005434980039	27532	Economy	3600.00
0005434980016	27532	Economy	3600.00
0005434979867	27532	Economy	3600.00
0005434980088	27532	Economy	3600.00
0005434980047	27532	Economy	3600.00
0005434979946	27532	Economy	3600.00
0005434980002	27532	Economy	3600.00
0005434979960	27532	Economy	3600.00
0005434980009	27532	Economy	3600.00
0005434980022	27532	Economy	3600.00
0005434979887	27532	Economy	3600.00
0005434979934	27532	Economy	3600.00
0005434980048	27532	Economy	3600.00
0005434980075	27532	Economy	3600.00
0005434979915	27532	Economy	3600.00
0005434980040	27532	Economy	3600.00
0005434979883	27532	Economy	3600.00
0005434302524	10264	Economy	19700.00
0005434302523	10264	Economy	19700.00
0005434302522	10264	Economy	19700.00
0005434302521	10264	Economy	19700.00
0005433111504	10264	Economy	19700.00
0005434302479	19630	Economy	21600.00
0005434302475	19630	Economy	21600.00
0005433113570	19630	Economy	19700.00
0005434302480	19630	Economy	19700.00
0005433113571	19630	Economy	19700.00
0005434302481	19630	Economy	19700.00
0005434302489	19630	Economy	19700.00
0005434302467	19630	Economy	19700.00
0005434302468	19630	Economy	19700.00
0005434302483	19630	Economy	19700.00
0005435069886	3572	Business	26900.00
0005435069862	3572	Business	26900.00
0005435719029	3572	Business	26900.00
0005435925316	3572	Business	26900.00
0005435069902	3572	Business	26900.00
0005435069867	3572	Business	26900.00
0005435069883	3572	Business	26900.00
0005435069890	3572	Economy	9000.00
0005435069891	3572	Economy	9000.00
0005435069905	3572	Economy	9000.00
0005435069860	3572	Economy	9000.00
0005435719028	3572	Economy	9000.00
0005435925345	3572	Economy	9000.00
0005435069878	3572	Economy	9900.00
0005435925314	3572	Economy	9900.00
0005435069864	3572	Economy	9900.00
0005435925358	3572	Economy	9900.00
0005435069901	3572	Economy	9900.00
0005435925389	3572	Economy	9000.00
0005435069877	3572	Economy	9000.00
0005435069892	3572	Economy	9000.00
0005435069868	3572	Economy	9000.00
0005435719030	3572	Economy	9000.00
0005435719032	3572	Economy	9000.00
0005435069897	3572	Economy	9000.00
0005435069866	3572	Economy	9000.00
0005435069865	3572	Economy	9000.00
0005435069863	3572	Economy	9000.00
0005435069899	3572	Economy	9000.00
0005435069880	3572	Economy	9000.00
0005435925359	3572	Economy	9000.00
0005435069854	3572	Economy	9000.00
0005435069869	3572	Economy	9000.00
0005435069859	3572	Economy	9000.00
0005435925353	3572	Economy	9000.00
0005435069885	3572	Economy	9000.00
0005435719033	3572	Economy	9000.00
0005435719027	3572	Economy	9000.00
0005435069879	3572	Economy	9000.00
0005435069858	3572	Economy	9000.00
0005435719034	3572	Economy	9000.00
0005435069856	3572	Economy	9000.00
0005435069875	3572	Economy	9000.00
0005435069882	3572	Economy	9000.00
0005435925369	3572	Economy	9000.00
0005435069888	3572	Economy	9000.00
0005435069855	3572	Economy	9000.00
0005435069894	3572	Economy	9000.00
0005435069857	3572	Economy	9000.00
0005435069898	3572	Economy	9000.00
0005435069861	3572	Economy	9000.00
0005435069876	3572	Economy	9000.00
0005435925357	3572	Economy	9000.00
0005435069900	3572	Economy	9000.00
0005435069881	3572	Economy	9000.00
0005435069884	3572	Economy	9000.00
0005435069896	3572	Economy	9000.00
0005435069904	3572	Economy	9000.00
0005435925354	3572	Economy	9000.00
0005435069870	3572	Economy	9000.00
0005435939891	3572	Economy	9000.00
0005435069853	3572	Economy	9000.00
0005435925346	3572	Economy	9000.00
0005435069893	3572	Economy	9000.00
0005435069874	3572	Economy	9000.00
0005435069871	3572	Economy	9000.00
0005435719031	3572	Economy	9000.00
0005435069872	3572	Economy	9000.00
0005435069887	3572	Economy	9000.00
0005435069895	3572	Economy	9000.00
0005435069889	3572	Economy	9000.00
0005435069873	3572	Economy	9000.00
0005435925315	3572	Economy	9000.00
0005435069903	3572	Economy	9000.00
0005435069362	15285	Business	26900.00
0005435939905	15285	Business	26900.00
0005435069476	15285	Business	26900.00
0005435069453	15285	Business	26900.00
0005435069642	15285	Business	26900.00
0005435069297	15285	Business	26900.00
0005435925492	15285	Business	26900.00
0005435925493	15285	Business	26900.00
0005435925487	15285	Business	26900.00
0005435925494	15285	Business	26900.00
0005435069398	15285	Business	26900.00
0005435069209	15285	Business	26900.00
0005435069413	15285	Economy	9000.00
0005435069641	15285	Economy	9000.00
0005435925500	15285	Economy	9000.00
0005435069410	15285	Economy	9000.00
0005435069429	15285	Economy	9000.00
0005435069411	15285	Economy	9000.00
0005435069392	15285	Economy	9000.00
0005435069170	15285	Economy	9000.00
0005435069417	15285	Economy	9900.00
0005435925497	15285	Economy	9900.00
0005435069405	15285	Economy	9900.00
0005435069425	15285	Economy	9900.00
0005435069436	15285	Economy	9000.00
0005435069343	15285	Economy	9000.00
0005435069161	15285	Economy	9000.00
0005435069377	15285	Economy	9000.00
0005435069222	15285	Economy	9000.00
0005435069336	15285	Economy	9000.00
0005435939909	15285	Economy	9000.00
0005435069328	15285	Economy	9000.00
0005435925498	15285	Economy	9000.00
0005435069452	15285	Economy	9000.00
0005435069529	15285	Economy	9000.00
0005435939907	15285	Economy	9000.00
0005435069278	15285	Economy	9000.00
0005435069244	15285	Economy	9000.00
0005435069282	15285	Economy	9000.00
0005435939906	15285	Economy	9000.00
0005435925488	15285	Economy	9000.00
0005435925496	15285	Economy	9000.00
0005435069527	15285	Economy	9000.00
0005435069528	15285	Economy	9000.00
0005435069599	15285	Economy	9000.00
0005435069378	15285	Economy	9000.00
0005435925495	15285	Economy	9000.00
0005435069327	15285	Economy	9000.00
0005435925499	15285	Economy	9000.00
0005435925486	15285	Economy	9000.00
0005435925484	15285	Economy	9000.00
0005435069434	15285	Economy	9000.00
0005435069412	15285	Economy	9000.00
0005435925491	15285	Economy	9000.00
0005435069335	15285	Economy	9000.00
0005435069435	15285	Economy	9000.00
0005435069210	15285	Economy	9000.00
0005435069235	15285	Economy	9000.00
0005435069283	15285	Economy	9000.00
0005435925485	15285	Economy	9000.00
0005435069344	15285	Economy	9000.00
0005435069433	15285	Economy	9000.00
0005435069234	15285	Economy	9000.00
0005435069266	15285	Economy	9000.00
0005435069284	15285	Economy	9000.00
0005435069616	15285	Economy	9000.00
0005435069265	15285	Economy	9000.00
0005435925501	15285	Economy	9000.00
0005435069558	15285	Economy	9000.00
0005435069347	15285	Economy	9000.00
0005435069196	15285	Economy	9000.00
0005435925489	15285	Economy	9000.00
0005435925490	15285	Economy	9000.00
0005435069617	15285	Economy	9000.00
0005435069416	15285	Economy	9000.00
0005435069371	15285	Economy	9000.00
0005435069277	15285	Economy	9000.00
0005435069288	15285	Economy	9000.00
0005435069399	15285	Economy	9000.00
0005435069342	15285	Economy	9000.00
0005435069296	15285	Economy	9000.00
0005435069295	15285	Economy	9000.00
0005435939908	15285	Economy	9000.00
0005432659737	18210	Economy	5900.00
0005432658623	18210	Economy	5900.00
0005432659740	18210	Economy	5900.00
0005432660849	18210	Economy	5900.00
0005432659739	18210	Economy	5900.00
0005432658622	18210	Economy	5900.00
0005432660850	18210	Economy	5900.00
0005432659738	18210	Economy	5900.00
0005432664152	26436	Economy	5900.00
0005432660825	26436	Economy	5900.00
0005432660835	26436	Economy	5900.00
0005432667465	26436	Economy	5900.00
0005432664151	26436	Economy	5900.00
0005432664155	26436	Economy	5900.00
0005432660836	26436	Economy	5900.00
0005432664154	26436	Economy	5900.00
0005432664150	26436	Economy	5900.00
0005432901765	202	Business	20000.00
0005433102557	202	Business	20000.00
0005433102423	202	Business	20000.00
0005432920070	202	Business	20000.00
0005432919957	202	Business	20000.00
0005433102388	202	Business	20000.00
0005433102483	202	Business	20000.00
0005433102449	202	Business	20000.00
0005432920068	202	Business	20000.00
0005433102499	202	Business	20000.00
0005432919989	202	Business	20000.00
0005433102549	202	Business	20000.00
0005432920043	202	Business	20000.00
0005433102559	202	Economy	7300.00
0005432901694	202	Economy	7300.00
0005433102493	202	Economy	7300.00
0005433102387	202	Economy	7300.00
0005433102576	202	Economy	6700.00
0005433102572	202	Economy	6700.00
0005432919979	202	Economy	6700.00
0005433102492	202	Economy	6700.00
0005433102390	202	Economy	6700.00
0005433102529	202	Economy	6700.00
0005432901813	202	Economy	6700.00
0005433102382	202	Economy	6700.00
0005433102457	202	Economy	6700.00
0005432920014	202	Economy	6700.00
0005432901743	202	Economy	6700.00
0005433102533	202	Economy	6700.00
0005433102232	202	Economy	6700.00
0005433102528	202	Economy	6700.00
0005433102394	202	Economy	6700.00
0005433102580	202	Economy	6700.00
0005433102592	202	Economy	6700.00
0005433102545	202	Economy	6700.00
0005433102507	202	Economy	6700.00
0005433102411	202	Economy	6700.00
0005432157521	202	Economy	6700.00
0005432919958	202	Economy	6700.00
0005432157522	202	Economy	6700.00
0005433102486	202	Economy	6700.00
0005433102591	202	Economy	6700.00
0005433102579	202	Economy	6700.00
0005433102585	202	Economy	6700.00
0005432920069	202	Economy	6700.00
0005432901790	202	Economy	6700.00
0005433102443	202	Economy	6700.00
0005433102353	202	Economy	6700.00
0005433102487	202	Economy	6700.00
0005433102453	202	Economy	7300.00
0005432920049	202	Economy	7300.00
0005433102584	202	Economy	6700.00
0005432901763	202	Economy	7300.00
0005433102548	202	Economy	6700.00
0005433102509	202	Economy	6700.00
0005433102502	202	Economy	6700.00
0005432677588	202	Economy	6700.00
0005433102482	202	Economy	6700.00
0005432901671	202	Economy	6700.00
0005432901724	202	Economy	6700.00
0005433102481	202	Economy	6700.00
0005433102508	202	Economy	6700.00
0005432901764	202	Economy	6700.00
0005433102501	202	Economy	6700.00
0005432901744	202	Economy	6700.00
0005433102381	202	Economy	6700.00
0005432919959	202	Economy	6700.00
0005432919981	202	Economy	6700.00
0005432901809	202	Economy	6700.00
0005433102532	202	Economy	6700.00
0005433102459	202	Economy	6700.00
0005433102458	202	Economy	6700.00
0005433102360	202	Economy	6700.00
0005433102448	202	Economy	6700.00
0005432901748	202	Economy	6700.00
0005432157523	202	Economy	6700.00
0005433102531	202	Economy	6700.00
0005433102489	202	Economy	6700.00
0005432919971	202	Economy	6700.00
0005433102540	202	Economy	6700.00
0005433102389	202	Economy	6700.00
0005433102547	202	Economy	6700.00
0005432919983	202	Economy	6700.00
0005432920031	202	Economy	6700.00
0005433102546	202	Economy	6700.00
0005432817925	201	Business	20000.00
0005432262616	201	Business	20000.00
0005432262624	201	Business	20000.00
0005432262586	201	Business	20000.00
0005432262601	201	Business	20000.00
0005433687710	201	Business	20000.00
0005432817923	201	Business	20000.00
0005432262598	201	Business	20000.00
0005432817926	201	Business	20000.00
0005432262590	201	Business	20000.00
0005432262615	201	Business	20000.00
0005432817919	201	Business	20000.00
0005432817937	201	Business	20000.00
0005432262599	201	Business	20000.00
0005432262629	201	Business	20000.00
0005432753333	201	Business	20000.00
0005432262597	201	Business	20000.00
0005434153549	201	Business	20000.00
0005432817938	201	Business	20000.00
0005432262622	201	Business	20000.00
0005432817913	201	Business	20000.00
0005432262587	201	Economy	7300.00
0005432817918	201	Economy	7300.00
0005432289038	201	Economy	7300.00
0005432817939	201	Economy	6700.00
0005432262600	201	Economy	6700.00
0005432817916	201	Economy	6700.00
0005432262627	201	Economy	6700.00
0005432817930	201	Economy	6700.00
0005432262611	201	Economy	6700.00
0005432262592	201	Economy	6700.00
0005433690941	201	Economy	6700.00
0005432289035	201	Economy	6700.00
0005432262612	201	Economy	6700.00
0005433690939	201	Economy	6700.00
0005432262623	201	Economy	6700.00
0005432262625	201	Economy	6700.00
0005432817927	201	Economy	6700.00
0005432817912	201	Economy	6700.00
0005432817917	201	Economy	6700.00
0005432289036	201	Economy	6700.00
0005432262588	201	Economy	6700.00
0005432262585	201	Economy	6700.00
0005432817931	201	Economy	6700.00
0005432753312	201	Economy	6700.00
0005432817929	201	Economy	6700.00
0005432262620	201	Economy	6700.00
0005432262604	201	Economy	6700.00
0005432262596	201	Economy	6700.00
0005432817910	201	Economy	6700.00
0005432262607	201	Economy	6700.00
0005434153548	201	Economy	6700.00
0005432817920	201	Economy	6700.00
0005432262602	201	Economy	6700.00
0005432262589	201	Economy	7300.00
0005432817928	201	Economy	7300.00
0005432817922	201	Economy	6700.00
0005432262591	201	Economy	6700.00
0005432262613	201	Economy	6700.00
0005433687709	201	Economy	6700.00
0005432262593	201	Economy	6700.00
0005432262617	201	Economy	6700.00
0005432817935	201	Economy	6700.00
0005432262594	201	Economy	6700.00
0005432262619	201	Economy	6700.00
0005432817921	201	Economy	6700.00
0005432817914	201	Economy	6700.00
0005432262628	201	Economy	6700.00
0005432756864	201	Economy	6700.00
0005432817934	201	Economy	6700.00
0005432817915	201	Economy	6700.00
0005434153547	201	Economy	6700.00
0005432817924	201	Economy	6700.00
0005433687708	201	Economy	6700.00
0005432753332	201	Economy	6700.00
0005432817932	201	Economy	6700.00
0005432262610	201	Economy	6700.00
0005432817933	201	Economy	6700.00
0005432753325	201	Economy	6700.00
0005432817936	201	Economy	6700.00
0005432262609	201	Economy	6700.00
0005432753316	201	Economy	6700.00
0005432262618	201	Economy	6700.00
0005432753324	201	Economy	6700.00
0005432262605	201	Economy	6700.00
0005432262595	201	Economy	6700.00
0005432817911	201	Economy	6700.00
0005432207699	201	Economy	6700.00
0005432262614	201	Economy	6700.00
0005432262583	201	Economy	6700.00
0005432262626	201	Economy	6700.00
0005432207700	201	Economy	6700.00
0005432262603	201	Economy	6700.00
0005432262606	201	Economy	6700.00
0005432262621	201	Economy	6700.00
0005432262608	201	Economy	6700.00
0005432262584	201	Economy	6700.00
0005432289037	201	Economy	6700.00
0005433690940	201	Economy	6700.00
0005433102936	8144	Business	20000.00
0005432020662	8144	Business	20000.00
0005432392047	8144	Business	20000.00
0005432920187	8144	Business	20000.00
0005433102965	8144	Business	20000.00
0005433102949	8144	Business	20000.00
0005433102963	8144	Business	20000.00
0005433102951	8144	Business	20000.00
0005432920173	8144	Business	20000.00
0005432020672	8144	Business	20000.00
0005432920177	8144	Business	20000.00
0005432045644	8144	Business	20000.00
0005432920186	8144	Business	20000.00
0005432920175	8144	Business	20000.00
0005433102928	8144	Business	20000.00
0005433102972	8144	Business	20000.00
0005433102940	8144	Business	20000.00
0005433102932	8144	Business	20000.00
0005433102946	8144	Business	20000.00
0005433102960	8144	Business	20000.00
0005432044567	8144	Business	20000.00
0005432020670	8144	Business	20000.00
0005433102927	8144	Business	20000.00
0005432920166	8144	Business	20000.00
0005433102941	8144	Business	20000.00
0005433102959	8144	Economy	7300.00
0005433102924	8144	Economy	7300.00
0005432753351	8144	Economy	7300.00
0005432753352	8144	Economy	7300.00
0005432920185	8144	Economy	7300.00
0005432920180	8144	Economy	6700.00
0005432020659	8144	Economy	6700.00
0005432920183	8144	Economy	6700.00
0005432920172	8144	Economy	6700.00
0005433102958	8144	Economy	6700.00
0005432920171	8144	Economy	6700.00
0005432677636	8144	Economy	6700.00
0005432020683	8144	Economy	6700.00
0005432920181	8144	Economy	6700.00
0005433102943	8144	Economy	6700.00
0005433102971	8144	Economy	6700.00
0005432020666	8144	Economy	6700.00
0005433102975	8144	Economy	6700.00
0005433102930	8144	Economy	6700.00
0005432044569	8144	Economy	6700.00
0005432020680	8144	Economy	6700.00
0005432020674	8144	Economy	6700.00
0005432920188	8144	Economy	6700.00
0005432020667	8144	Economy	6700.00
0005433102967	8144	Economy	6700.00
0005432753354	8144	Economy	6700.00
0005432920182	8144	Economy	6700.00
0005433102955	8144	Economy	6700.00
0005432392046	8144	Economy	6700.00
0005433102948	8144	Economy	6700.00
0005433102939	8144	Economy	6700.00
0005432677635	8144	Economy	6700.00
0005432020661	8144	Economy	6700.00
0005433102970	8144	Economy	6700.00
0005433102933	8144	Economy	6700.00
0005433102962	8144	Economy	6700.00
0005432020677	8144	Economy	6700.00
0005433102966	8144	Economy	6700.00
0005432020658	8144	Economy	6700.00
0005433102957	8144	Economy	6700.00
0005433102938	8144	Economy	6700.00
0005432045643	8144	Economy	6700.00
0005433102954	8144	Economy	6700.00
0005432920184	8144	Economy	6700.00
0005432920167	8144	Economy	6700.00
0005432020675	8144	Economy	6700.00
0005432020679	8144	Economy	6700.00
0005432020669	8144	Economy	6700.00
0005432020682	8144	Economy	6700.00
0005433102952	8144	Economy	6700.00
0005432920174	8144	Economy	6700.00
0005433102931	8144	Economy	7300.00
0005433102926	8144	Economy	7300.00
0005433102937	8144	Economy	7300.00
0005433102947	8144	Economy	6700.00
0005432392045	8144	Economy	7300.00
0005432020668	8144	Economy	6700.00
0005433102968	8144	Economy	6700.00
0005433102923	8144	Economy	6700.00
0005433102925	8144	Economy	6700.00
0005433102969	8144	Economy	6700.00
0005432020671	8144	Economy	6700.00
0005433102945	8144	Economy	6700.00
0005433102961	8144	Economy	6700.00
0005432677637	8144	Economy	6700.00
0005432020673	8144	Economy	6700.00
0005433102976	8144	Economy	6700.00
0005433102935	8144	Economy	6700.00
0005432020663	8144	Economy	6700.00
0005433102934	8144	Economy	6700.00
0005433102953	8144	Economy	6700.00
0005432020685	8144	Economy	6700.00
0005432920178	8144	Economy	6700.00
0005432920179	8144	Economy	6700.00
0005432020681	8144	Economy	6700.00
0005432020660	8144	Economy	6700.00
0005433102942	8144	Economy	6700.00
0005433102929	8144	Economy	6700.00
0005433102944	8144	Economy	6700.00
0005432020684	8144	Economy	6700.00
0005433102974	8144	Economy	6700.00
0005433102956	8144	Economy	6700.00
0005432020676	8144	Economy	6700.00
0005432920168	8144	Economy	6700.00
0005432677638	8144	Economy	6700.00
0005432920170	8144	Economy	6700.00
0005433102950	8144	Economy	6700.00
0005432020664	8144	Economy	6700.00
0005433102973	8144	Economy	6700.00
0005432753353	8144	Economy	6700.00
0005432044568	8144	Economy	6700.00
0005432920169	8144	Economy	6700.00
0005432751579	8144	Economy	6700.00
0005433102964	8144	Economy	6700.00
0005432751578	8144	Economy	6700.00
0005432020665	8144	Economy	6700.00
0005432920176	8144	Economy	6700.00
0005432020678	8144	Economy	6700.00
0005432392048	8144	Economy	6700.00
0005432817684	8143	Business	20000.00
0005432817741	8143	Business	20000.00
0005434513603	8143	Business	20000.00
0005432817685	8143	Business	20000.00
0005432901879	8143	Business	20000.00
0005432901886	8143	Business	20000.00
0005432002109	8143	Business	20000.00
0005432817730	8143	Business	20000.00
0005432901878	8143	Business	20000.00
0005432817652	8143	Business	20000.00
0005432817645	8143	Business	20000.00
0005432817728	8143	Economy	7300.00
0005432901884	8143	Economy	7300.00
0005434513593	8143	Economy	7300.00
0005432817578	8143	Economy	7300.00
0005432817785	8143	Economy	6700.00
0005432901869	8143	Economy	6700.00
0005432901882	8143	Economy	6700.00
0005432901883	8143	Economy	6700.00
0005432817742	8143	Economy	6700.00
0005432901874	8143	Economy	6700.00
0005432901881	8143	Economy	6700.00
0005432817696	8143	Economy	6700.00
0005432817729	8143	Economy	6700.00
0005434513606	8143	Economy	6700.00
0005432901885	8143	Economy	6700.00
0005432817632	8143	Economy	6700.00
0005432817703	8143	Economy	6700.00
0005432901870	8143	Economy	6700.00
0005432901887	8143	Economy	6700.00
0005432901871	8143	Economy	6700.00
0005434513595	8143	Economy	6700.00
0005432817564	8143	Economy	6700.00
0005432817640	8143	Economy	6700.00
0005432817697	8143	Economy	6700.00
0005434513598	8143	Economy	6700.00
0005434513592	8143	Economy	7300.00
0005434513599	8143	Economy	6700.00
0005432817626	8143	Economy	6700.00
0005432817676	8143	Economy	6700.00
0005432901880	8143	Economy	6700.00
0005432817629	8143	Economy	6700.00
0005432817707	8143	Economy	6700.00
0005432901875	8143	Economy	6700.00
0005432817735	8143	Economy	6700.00
0005432901876	8143	Economy	6700.00
0005434513594	8143	Economy	6700.00
0005432901873	8143	Economy	6700.00
0005432002108	8143	Economy	6700.00
0005432901872	8143	Economy	6700.00
0005432817583	8143	Economy	6700.00
0005432817630	8143	Economy	6700.00
0005432817633	8143	Economy	6700.00
0005432817646	8143	Economy	6700.00
0005432817734	8143	Economy	6700.00
0005432901877	8143	Economy	6700.00
0005432817651	8143	Economy	6700.00
0005434175790	9652	Economy	6900.00
0005434175777	9652	Economy	6900.00
0005433870765	9652	Economy	6900.00
0005434175766	9652	Economy	6900.00
0005434175792	9652	Economy	6900.00
0005433870764	9652	Economy	6900.00
0005434175793	9652	Economy	6900.00
0005434175778	9652	Economy	6900.00
0005434175817	32344	Economy	6900.00
0005433870743	32344	Economy	6900.00
0005434175819	32344	Economy	6900.00
0005434175820	32344	Economy	6900.00
0005434175816	32344	Economy	6900.00
0005433870753	32344	Economy	6900.00
0005434175818	32344	Economy	6900.00
0005434879725	3521	Business	35000.00
0005434879673	3521	Business	35000.00
0005434879709	3521	Business	35000.00
0005432799885	3521	Business	35000.00
0005434938436	3521	Business	35000.00
0005435626459	3521	Business	35000.00
0005435626453	3521	Business	35000.00
0005434427077	3521	Business	35000.00
0005435126984	3521	Business	35000.00
0005434938437	3521	Business	35000.00
0005434938449	3521	Business	35000.00
0005434879649	3521	Business	35000.00
0005432613924	3521	Business	35000.00
0005435127019	3521	Business	35000.00
0005434879705	3521	Business	35000.00
0005434879701	3521	Business	35000.00
0005434427060	3521	Business	35000.00
0005434879683	3521	Business	35000.00
0005434879723	3521	Business	35000.00
0005434879680	3521	Business	35000.00
0005434427061	3521	Comfort	19900.00
0005435626456	3521	Comfort	19900.00
0005435626454	3521	Comfort	19900.00
0005432188657	3521	Comfort	19900.00
0005434879700	3521	Comfort	19900.00
0005434879666	3521	Comfort	19900.00
0005435127009	3521	Comfort	19900.00
0005432613925	3521	Comfort	19900.00
0005432613926	3521	Comfort	19900.00
0005434427069	3521	Comfort	19900.00
0005434879646	3521	Comfort	19900.00
0005434938445	3521	Comfort	19900.00
0005434427058	3521	Comfort	19900.00
0005435626446	3521	Comfort	19900.00
0005434938433	3521	Comfort	19900.00
0005434879679	3521	Comfort	19900.00
0005435126991	3521	Comfort	19900.00
0005434879687	3521	Comfort	19900.00
0005435902861	3521	Comfort	19900.00
0005434427059	3521	Comfort	19900.00
0005435626457	3521	Comfort	19900.00
0005434879727	3521	Comfort	19900.00
0005435127007	3521	Comfort	19900.00
0005434879676	3521	Comfort	19900.00
0005434879654	3521	Comfort	19900.00
0005432799887	3521	Comfort	19900.00
0005434879662	3521	Comfort	19900.00
0005434879634	3521	Comfort	19900.00
0005432799897	3521	Comfort	19900.00
0005434879706	3521	Comfort	19900.00
0005434427076	3521	Comfort	19900.00
0005435126992	3521	Comfort	19900.00
0005435626460	3521	Comfort	19900.00
0005435902857	3521	Comfort	19900.00
0005435902856	3521	Economy	11700.00
0005435902848	3521	Economy	11700.00
0005434879660	3521	Economy	11700.00
0005434879636	3521	Economy	11700.00
0005435902832	3521	Economy	11700.00
0005435902831	3521	Economy	11700.00
0005434879648	3521	Economy	11700.00
0005435126994	3521	Economy	11700.00
0005434879698	3521	Economy	11700.00
0005435902713	3521	Economy	11700.00
0005434879643	3521	Economy	11700.00
0005432799891	3521	Economy	11700.00
0005434938451	3521	Economy	11700.00
0005434879671	3521	Economy	11700.00
0005434879641	3521	Economy	11700.00
0005435127010	3521	Economy	11700.00
0005434879674	3521	Economy	11700.00
0005434427065	3521	Economy	11700.00
0005434938442	3521	Economy	11700.00
0005434879668	3521	Economy	11700.00
0005434879644	3521	Economy	11700.00
0005435127020	3521	Economy	11700.00
0005434427073	3521	Economy	11700.00
0005432799895	3521	Economy	11700.00
0005435902808	3521	Economy	11700.00
0005434879691	3521	Economy	11700.00
0005434879726	3521	Economy	11700.00
0005434879686	3521	Economy	11700.00
0005434938452	3521	Economy	11700.00
0005432799902	3521	Economy	11700.00
0005435126986	3521	Economy	11700.00
0005432188659	3521	Economy	11700.00
0005432799879	3521	Economy	11700.00
0005434427064	3521	Economy	11700.00
0005434879689	3521	Economy	11700.00
0005434879663	3521	Economy	11700.00
0005434879702	3521	Economy	11700.00
0005432799890	3521	Economy	11700.00
0005434427053	3521	Economy	11700.00
0005434938441	3521	Economy	11700.00
0005435902807	3521	Economy	11700.00
0005434879694	3521	Economy	11700.00
0005435127008	3521	Economy	11700.00
0005434938440	3521	Economy	11700.00
0005435126995	3521	Economy	11700.00
0005432799905	3521	Economy	12800.00
0005435127003	3521	Economy	12800.00
0005432799892	3521	Economy	12800.00
0005434879635	3521	Economy	11700.00
0005435126982	3521	Economy	11700.00
0005435126997	3521	Economy	12800.00
0005434879655	3521	Economy	11700.00
0005434427066	3521	Economy	11700.00
0005435902817	3521	Economy	11700.00
0005434879645	3521	Economy	11700.00
0005435626451	3521	Economy	11700.00
0005432799900	3521	Economy	11700.00
0005434427080	3521	Economy	11700.00
0005435902835	3521	Economy	11700.00
0005434938447	3521	Economy	11700.00
0005435913946	3521	Economy	11700.00
0005434879675	3521	Economy	11700.00
0005435127013	3521	Economy	11700.00
0005432799901	3521	Economy	11700.00
0005432799883	3521	Economy	11700.00
0005435626445	3521	Economy	11700.00
0005434427057	3521	Economy	11700.00
0005435127014	3521	Economy	11700.00
0005434938444	3521	Economy	11700.00
0005432799888	3521	Economy	11700.00
0005434879688	3521	Economy	11700.00
0005434879678	3521	Economy	11700.00
0005434879681	3521	Economy	11700.00
0005434879672	3521	Economy	11700.00
0005432799907	3521	Economy	11700.00
0005435902886	3521	Economy	11700.00
0005434879638	3521	Economy	11700.00
0005432799880	3521	Economy	11700.00
0005435127016	3521	Economy	11700.00
0005435902804	3521	Economy	11700.00
0005432799896	3521	Economy	11700.00
0005434879642	3521	Economy	11700.00
0005434879707	3521	Economy	11700.00
0005434879703	3521	Economy	11700.00
0005434879640	3521	Economy	11700.00
0005432613923	3521	Economy	11700.00
0005435626452	3521	Economy	11700.00
0005434879719	3521	Economy	11700.00
0005432799894	3521	Economy	11700.00
0005435626447	3521	Economy	11700.00
0005434938446	3521	Economy	11700.00
0005435126981	3521	Economy	11700.00
0005434879715	3521	Economy	11700.00
0005435126990	3521	Economy	11700.00
0005435626450	3521	Economy	11700.00
0005435902749	3521	Economy	11700.00
0005434879639	3521	Economy	11700.00
0005434879682	3521	Economy	11700.00
0005435127001	3521	Economy	11700.00
0005432183500	3521	Economy	11700.00
0005432799903	3521	Economy	11700.00
0005435902800	3521	Economy	11700.00
0005432799884	3521	Economy	11700.00
0005434938443	3521	Economy	11700.00
0005434879653	3521	Economy	11700.00
0005432799886	3521	Economy	11700.00
0005434427062	3521	Economy	11700.00
0005435902753	3521	Economy	11700.00
0005434879651	3521	Economy	11700.00
0005435902834	3521	Economy	11700.00
0005434938434	3521	Economy	11700.00
0005434938435	3521	Economy	11700.00
0005434427072	3521	Economy	11700.00
0005434427070	3521	Economy	11700.00
0005435626455	3521	Economy	11700.00
0005434427063	3521	Economy	11700.00
0005434879692	3521	Economy	11700.00
0005434879669	3521	Economy	11700.00
0005435902844	3521	Economy	11700.00
0005435126987	3521	Economy	11700.00
0005435626458	3521	Economy	11700.00
0005434879713	3521	Economy	11700.00
0005435126989	3521	Economy	11700.00
0005432611767	3521	Economy	11700.00
0005435626462	3521	Economy	11700.00
0005435902850	3521	Economy	11700.00
0005434879633	3521	Economy	11700.00
0005435126999	3521	Economy	11700.00
0005434879724	3521	Economy	11700.00
0005434879690	3521	Economy	11700.00
0005435127017	3521	Economy	11700.00
0005434938448	3521	Economy	11700.00
0005434879650	3521	Economy	11700.00
0005432799899	3521	Economy	11700.00
0005434879717	3521	Economy	12800.00
0005434879667	3521	Economy	12800.00
0005432799881	3521	Economy	12800.00
0005435127015	3521	Economy	12800.00
0005434427054	3521	Economy	12800.00
0005434879721	3521	Economy	11700.00
0005432799893	3521	Economy	11700.00
0005434879708	3521	Economy	11700.00
0005435127000	3521	Economy	11700.00
0005435626443	3521	Economy	11700.00
0005434879710	3521	Economy	11700.00
0005434427052	3521	Economy	11700.00
0005435127012	3521	Economy	11700.00
0005432611769	3521	Economy	11700.00
0005434938439	3521	Economy	11700.00
0005434879699	3521	Economy	11700.00
0005435626448	3521	Economy	11700.00
0005432611768	3521	Economy	11700.00
0005434427074	3521	Economy	11700.00
0005432799878	3521	Economy	11700.00
0005434879652	3521	Economy	11700.00
0005435126996	3521	Economy	11700.00
0005434879704	3521	Economy	11700.00
0005435126988	3521	Economy	11700.00
0005434938450	3521	Economy	11700.00
0005432799904	3521	Economy	11700.00
0005434879665	3521	Economy	11700.00
0005434879658	3521	Economy	11700.00
0005434879684	3521	Economy	11700.00
0005434879670	3521	Economy	11700.00
0005432799898	3521	Economy	11700.00
0005434879696	3521	Economy	11700.00
0005434879714	3521	Economy	11700.00
0005434427056	3521	Economy	11700.00
0005434427071	3521	Economy	11700.00
0005435127018	3521	Economy	11700.00
0005434427051	3521	Economy	11700.00
0005434879722	3521	Economy	11700.00
0005434427075	3521	Economy	11700.00
0005434879695	3521	Economy	11700.00
0005435127004	3521	Economy	11700.00
0005434879657	3521	Economy	11700.00
0005435127005	3521	Economy	11700.00
0005432799889	3521	Economy	11700.00
0005435127006	3521	Economy	11700.00
0005432799882	3521	Economy	11700.00
0005435126993	3521	Economy	11700.00
0005434879656	3521	Economy	11700.00
0005434427067	3521	Economy	11700.00
0005434879659	3521	Economy	11700.00
0005434879720	3521	Economy	11700.00
0005435126985	3521	Economy	11700.00
0005434427068	3521	Economy	11700.00
0005432188660	3521	Economy	11700.00
0005434879697	3521	Economy	11700.00
0005432799906	3521	Economy	11700.00
0005434427050	3521	Economy	11700.00
0005435127011	3521	Economy	11700.00
0005435902805	3521	Economy	11700.00
0005432188658	3521	Economy	11700.00
0005435626449	3521	Economy	11700.00
0005434879677	3521	Economy	11700.00
0005435902855	3521	Economy	11700.00
0005434427079	3521	Economy	11700.00
0005435126998	3521	Economy	11700.00
0005435902849	3521	Economy	11700.00
0005434879685	3521	Economy	11700.00
0005435902873	3521	Economy	11700.00
0005434427078	3521	Economy	11700.00
0005432183501	3521	Economy	11700.00
0005434427055	3521	Economy	11700.00
0005434879712	3521	Economy	11700.00
0005434879647	3521	Economy	11700.00
0005434879661	3521	Economy	11700.00
0005435126983	3521	Economy	11700.00
0005434938438	3521	Economy	11700.00
0005435127002	3521	Economy	11700.00
0005434879693	3521	Economy	11700.00
0005435626461	3521	Economy	11700.00
0005434879711	3521	Economy	11700.00
0005434879637	3521	Economy	11700.00
0005435626444	3521	Economy	11700.00
0005435626463	3521	Economy	11700.00
0005434879718	3521	Economy	11700.00
0005434879664	3521	Economy	11700.00
0005434879716	3521	Economy	11700.00
0005434878990	14577	Business	35000.00
0005432059535	14577	Business	35000.00
0005435126405	14577	Business	35000.00
0005435126714	14577	Business	35000.00
0005435626270	14577	Business	35000.00
0005432799788	14577	Business	35000.00
0005434878953	14577	Business	35000.00
0005435902984	14577	Business	35000.00
0005434938225	14577	Business	35000.00
0005434878854	14577	Business	35000.00
0005434938287	14577	Business	35000.00
0005434878834	14577	Business	35000.00
0005434878976	14577	Business	35000.00
0005435126615	14577	Business	35000.00
0005435626274	14577	Business	35000.00
0005435626286	14577	Business	35000.00
0005434426895	14577	Business	35000.00
0005434878989	14577	Business	35000.00
0005432607566	14577	Business	35000.00
0005434878853	14577	Business	35000.00
0005435126645	14577	Business	35000.00
0005435126494	14577	Business	35000.00
0005434878601	14577	Business	35000.00
0005434878880	14577	Comfort	19900.00
0005435902972	14577	Comfort	19900.00
0005434878970	14577	Comfort	19900.00
0005435126709	14577	Comfort	19900.00
0005434878971	14577	Comfort	19900.00
0005435902969	14577	Comfort	19900.00
0005432799610	14577	Comfort	19900.00
0005435126536	14577	Comfort	19900.00
0005434878778	14577	Comfort	19900.00
0005435902980	14577	Comfort	19900.00
0005435126683	14577	Comfort	19900.00
0005435126623	14577	Comfort	19900.00
0005435126608	14577	Comfort	19900.00
0005435902975	14577	Comfort	19900.00
0005432799654	14577	Comfort	19900.00
0005432799446	14577	Comfort	19900.00
0005435902971	14577	Comfort	19900.00
0005432799698	14577	Comfort	19900.00
0005434878872	14577	Comfort	19900.00
0005435126682	14577	Comfort	19900.00
0005434426894	14577	Comfort	19900.00
0005434878485	14577	Comfort	19900.00
0005434878812	14577	Comfort	19900.00
0005434878936	14577	Comfort	19900.00
0005434879150	14577	Comfort	19900.00
0005434938365	14577	Comfort	19900.00
0005432799634	14577	Comfort	19900.00
0005434878804	14577	Comfort	19900.00
0005432799566	14577	Comfort	19900.00
0005434879101	14577	Comfort	19900.00
0005435126630	14577	Comfort	19900.00
0005434878907	14577	Economy	11700.00
0005434878807	14577	Economy	11700.00
0005432799649	14577	Economy	11700.00
0005432611728	14577	Economy	11700.00
0005434878818	14577	Economy	11700.00
0005434938356	14577	Economy	11700.00
0005434426829	14577	Economy	11700.00
0005435902968	14577	Economy	11700.00
0005435126648	14577	Economy	11700.00
0005434878992	14577	Economy	11700.00
0005434426889	14577	Economy	11700.00
0005432799630	14577	Economy	11700.00
0005434938217	14577	Economy	11700.00
0005434426689	14577	Economy	11700.00
0005435126715	14577	Economy	11700.00
0005432799696	14577	Economy	11700.00
0005434878651	14577	Economy	11700.00
0005434426903	14577	Economy	11700.00
0005434878920	14577	Economy	11700.00
0005432799445	14577	Economy	11700.00
0005434879156	14577	Economy	11700.00
0005435626280	14577	Economy	11700.00
0005434426913	14577	Economy	11700.00
0005434426976	14577	Economy	11700.00
0005435902967	14577	Economy	11700.00
0005434878951	14577	Economy	11700.00
0005435126504	14577	Economy	11700.00
0005434879180	14577	Economy	11700.00
0005435626282	14577	Economy	11700.00
0005434879074	14577	Economy	11700.00
0005432799603	14577	Economy	11700.00
0005434879036	14577	Economy	11700.00
0005434878731	14577	Economy	11700.00
0005434938271	14577	Economy	11700.00
0005434878593	14577	Economy	11700.00
0005435126828	14577	Economy	11700.00
0005435902981	14577	Economy	11700.00
0005434879198	14577	Economy	11700.00
0005435913980	14577	Economy	11700.00
0005435902978	14577	Economy	11700.00
0005434879109	14577	Economy	11700.00
0005434426902	14577	Economy	11700.00
0005432799636	14577	Economy	11700.00
0005434878684	14577	Economy	11700.00
0005435126693	14577	Economy	11700.00
0005435626275	14577	Economy	11700.00
0005434879015	14577	Economy	11700.00
0005434426869	14577	Economy	11700.00
0005432611732	14577	Economy	11700.00
0005432611735	14577	Economy	11700.00
0005435126708	14577	Economy	11700.00
0005434938385	14577	Economy	11700.00
0005432607587	14577	Economy	12800.00
0005435841834	14577	Economy	12800.00
0005434426896	14577	Economy	11700.00
0005434878850	14577	Economy	11700.00
0005435626231	14577	Economy	11700.00
0005434426697	14577	Economy	11700.00
0005434878484	14577	Economy	12800.00
0005434426868	14577	Economy	11700.00
0005432799604	14577	Economy	11700.00
0005435902977	14577	Economy	11700.00
0005435626266	14577	Economy	11700.00
0005434426870	14577	Economy	11700.00
0005432059534	14577	Economy	11700.00
0005434878792	14577	Economy	11700.00
0005435842337	14577	Economy	11700.00
0005435126684	14577	Economy	11700.00
0005434426769	14577	Economy	11700.00
0005434426853	14577	Economy	11700.00
0005435626267	14577	Economy	11700.00
0005434879149	14577	Economy	11700.00
0005434878964	14577	Economy	11700.00
0005432799622	14577	Economy	11700.00
0005435902979	14577	Economy	11700.00
0005434426819	14577	Economy	11700.00
0005435626250	14577	Economy	11700.00
0005434938310	14577	Economy	11700.00
0005434879058	14577	Economy	11700.00
0005434879197	14577	Economy	11700.00
0005435626224	14577	Economy	11700.00
0005434938325	14577	Economy	11700.00
0005434879048	14577	Economy	11700.00
0005434879115	14577	Economy	11700.00
0005435126753	14577	Economy	11700.00
0005435126394	14577	Economy	11700.00
0005435902976	14577	Economy	11700.00
0005434878819	14577	Economy	11700.00
0005434878641	14577	Economy	11700.00
0005435126658	14577	Economy	11700.00
0005434938357	14577	Economy	11700.00
0005434426876	14577	Economy	11700.00
0005434426843	14577	Economy	11700.00
0005435626247	14577	Economy	11700.00
0005434879029	14577	Economy	11700.00
0005435626248	14577	Economy	11700.00
0005435126776	14577	Economy	11700.00
0005435841833	14577	Economy	11700.00
0005434878789	14577	Economy	11700.00
0005435126624	14577	Economy	11700.00
0005435626281	14577	Economy	11700.00
0005432799583	14577	Economy	11700.00
0005434938224	14577	Economy	11700.00
0005434878965	14577	Economy	11700.00
0005434878829	14577	Economy	11700.00
0005435126637	14577	Economy	11700.00
0005434879059	14577	Economy	11700.00
0005435902973	14577	Economy	11700.00
0005434938219	14577	Economy	11700.00
0005432611736	14577	Economy	11700.00
0005434878815	14577	Economy	11700.00
0005435126752	14577	Economy	11700.00
0005434879155	14577	Economy	11700.00
0005434878903	14577	Economy	11700.00
0005434878902	14577	Economy	11700.00
0005435626287	14577	Economy	11700.00
0005434938258	14577	Economy	11700.00
0005434878820	14577	Economy	11700.00
0005435126726	14577	Economy	11700.00
0005434878740	14577	Economy	11700.00
0005434878975	14577	Economy	11700.00
0005434426690	14577	Economy	11700.00
0005434426897	14577	Economy	11700.00
0005434426851	14577	Economy	11700.00
0005432799786	14577	Economy	11700.00
0005435126404	14577	Economy	11700.00
0005432799669	14577	Economy	11700.00
0005434426724	14577	Economy	11700.00
0005432799664	14577	Economy	11700.00
0005434878823	14577	Economy	11700.00
0005434878759	14577	Economy	11700.00
0005434938262	14577	Economy	11700.00
0005434878595	14577	Economy	11700.00
0005435626205	14577	Economy	11700.00
0005435626249	14577	Economy	11700.00
0005434878895	14577	Economy	12800.00
0005435126716	14577	Economy	12800.00
0005434879028	14577	Economy	12800.00
0005434878459	14577	Economy	12800.00
0005432611734	14577	Economy	12800.00
0005432799787	14577	Economy	12800.00
0005434879042	14577	Economy	11700.00
0005434426878	14577	Economy	11700.00
0005434938218	14577	Economy	11700.00
0005434878835	14577	Economy	11700.00
0005434879233	14577	Economy	11700.00
0005432799629	14577	Economy	11700.00
0005432611745	14577	Economy	11700.00
0005432799632	14577	Economy	11700.00
0005435902982	14577	Economy	11700.00
0005434879016	14577	Economy	11700.00
0005434426852	14577	Economy	11700.00
0005434426922	14577	Economy	11700.00
0005434879003	14577	Economy	11700.00
0005434879213	14577	Economy	11700.00
0005434879043	14577	Economy	11700.00
0005434878403	14577	Economy	11700.00
0005432799684	14577	Economy	11700.00
0005435126627	14577	Economy	11700.00
0005434879062	14577	Economy	11700.00
0005435126665	14577	Economy	11700.00
0005434938363	14577	Economy	11700.00
0005435626204	14577	Economy	11700.00
0005435126537	14577	Economy	11700.00
0005435842338	14577	Economy	11700.00
0005434879010	14577	Economy	11700.00
0005434878806	14577	Economy	11700.00
0005434426921	14577	Economy	11700.00
0005435126814	14577	Economy	11700.00
0005435902970	14577	Economy	11700.00
0005434879037	14577	Economy	11700.00
0005434426831	14577	Economy	11700.00
0005432799695	14577	Economy	11700.00
0005434426877	14577	Economy	11700.00
0005434878851	14577	Economy	11700.00
0005434878805	14577	Economy	11700.00
0005434426850	14577	Economy	11700.00
0005435902974	14577	Economy	11700.00
0005434878877	14577	Economy	11700.00
0005434878515	14577	Economy	11700.00
0005434878816	14577	Economy	11700.00
0005434426830	14577	Economy	11700.00
0005432799663	14577	Economy	11700.00
0005434878775	14577	Economy	11700.00
0005434426977	14577	Economy	11700.00
0005432799673	14577	Economy	11700.00
0005432799676	14577	Economy	11700.00
0005434878774	14577	Economy	11700.00
0005435126564	14577	Economy	11700.00
0005434426886	14577	Economy	11700.00
0005434878991	14577	Economy	11700.00
0005434878896	14577	Economy	11700.00
0005434878847	14577	Economy	11700.00
0005434879234	14577	Economy	11700.00
0005435126535	14577	Economy	11700.00
0005434426820	14577	Economy	11700.00
0005434878824	14577	Economy	11700.00
0005435626297	14577	Economy	11700.00
0005432799584	14577	Economy	11700.00
0005434938270	14577	Economy	11700.00
0005435126268	14577	Economy	11700.00
0005435126677	14577	Economy	11700.00
0005434878913	14577	Economy	11700.00
0005435902983	14577	Economy	11700.00
0005435126614	14577	Economy	11700.00
0005434878516	14577	Economy	11700.00
0005435126642	14577	Economy	11700.00
0005434878799	14577	Economy	11700.00
0005435126613	14577	Economy	11700.00
0005434878404	14577	Economy	11700.00
0005434938257	14577	Economy	11700.00
0005434878508	14577	Economy	11700.00
0005434878517	14577	Economy	11700.00
0005435626298	14577	Economy	11700.00
0005434879032	14577	Economy	11700.00
0005434878817	14577	Economy	11700.00
0005432799690	14577	Economy	11700.00
0005434938280	14577	Economy	11700.00
0005434938364	14577	Economy	11700.00
0005434312351	3618	Economy	16300.00
0005434325823	3618	Economy	14800.00
0005434325825	3618	Economy	14800.00
0005435889942	3618	Economy	14800.00
0005434325830	3618	Economy	14800.00
0005435889935	3618	Economy	14800.00
0005434325829	3618	Economy	14800.00
0005434325827	3618	Economy	14800.00
0005434325832	3618	Economy	14800.00
0005435889950	3618	Economy	14800.00
0005434325833	3618	Economy	14800.00
0005435889940	3618	Economy	14800.00
0005434325828	3618	Economy	14800.00
0005434325826	3618	Economy	14800.00
0005434312350	3618	Economy	14800.00
0005434325822	3618	Economy	14800.00
0005434325824	3618	Economy	14800.00
0005434325831	3618	Economy	14800.00
0005435889941	3618	Economy	14800.00
0005435889989	15612	Economy	16300.00
0005434325707	15612	Economy	16300.00
0005435889988	15612	Economy	14800.00
0005434325732	15612	Economy	14800.00
0005435889990	15612	Economy	14800.00
0005434325768	15612	Economy	14800.00
0005435889993	15612	Economy	14800.00
0005434325773	15612	Economy	14800.00
0005435889991	15612	Economy	14800.00
0005434325718	15612	Economy	14800.00
0005434325706	15612	Economy	14800.00
0005434325761	15612	Economy	14800.00
0005434325762	15612	Economy	14800.00
0005434325731	15612	Economy	14800.00
0005434325708	15612	Economy	14800.00
0005435889992	15612	Economy	14800.00
0005434325703	15612	Economy	14800.00
0005434325764	15612	Economy	14800.00
0005434325747	15612	Economy	14800.00
0005435889986	15612	Economy	14800.00
0005435889987	15612	Economy	14800.00
0005435957930	629	Economy	4500.00
0005435957922	629	Economy	4500.00
0005435957923	629	Economy	4100.00
0005435957933	629	Economy	4100.00
0005433420487	629	Economy	4100.00
0005435957934	629	Economy	4100.00
0005433420421	629	Economy	4100.00
0005433420436	629	Economy	4100.00
0005435957929	629	Economy	4100.00
0005433420462	629	Economy	4100.00
0005435957926	629	Economy	4100.00
0005435957925	629	Economy	4100.00
0005435957932	629	Economy	4100.00
0005435957928	629	Economy	4100.00
0005433420486	629	Economy	4100.00
0005435957936	629	Economy	4100.00
0005435957927	629	Economy	4100.00
0005435957935	629	Economy	4100.00
0005435957924	629	Economy	4100.00
0005435957931	629	Economy	4100.00
0005433420420	629	Economy	4100.00
0005435957788	15165	Economy	4500.00
0005433420536	15165	Economy	4500.00
0005433420537	15165	Economy	4100.00
0005435957805	15165	Economy	4100.00
0005435957816	15165	Economy	4100.00
0005435957787	15165	Economy	4100.00
0005435957822	15165	Economy	4100.00
0005435957861	15165	Economy	4100.00
0005435957821	15165	Economy	4100.00
0005433420533	15165	Economy	4100.00
0005435957778	15165	Economy	4100.00
0005435957791	15165	Economy	4100.00
0005435957815	15165	Economy	4100.00
0005435957784	15165	Economy	4100.00
0005435957743	15165	Economy	4100.00
0005435957745	15165	Economy	4100.00
0005433420532	15165	Economy	4100.00
0005435957777	15165	Economy	4100.00
0005433420534	15165	Economy	4100.00
0005435957820	15165	Economy	4100.00
0005435957806	15165	Economy	4100.00
0005433420535	15165	Economy	4100.00
0005435957833	15165	Economy	4100.00
0005433420531	15165	Economy	4100.00
0005435957859	15165	Economy	4100.00
0005433420530	15165	Economy	4100.00
0005435216586	27266	Economy	28100.00
0005435221058	27266	Economy	28100.00
0005435221055	27266	Economy	28100.00
0005435219214	27266	Economy	25500.00
0005435221059	27266	Economy	25500.00
0005435219217	27266	Economy	25500.00
0005435221056	27266	Economy	25500.00
0005435216594	27266	Economy	25500.00
0005435216599	27266	Economy	25500.00
0005435216585	27266	Economy	25500.00
0005435216587	27266	Economy	25500.00
0005435216593	27266	Economy	25500.00
0005435216596	27266	Economy	25500.00
0005435216598	27266	Economy	25500.00
0005435216602	27266	Economy	25500.00
0005435219215	27266	Economy	25500.00
0005435221061	27266	Economy	25500.00
0005435221053	27266	Economy	25500.00
0005434247165	8890	Economy	10400.00
0005434247168	8890	Economy	10400.00
0005435629414	16069	Economy	10400.00
0005434247188	16069	Economy	10400.00
0005434247187	16069	Economy	10400.00
0005435163309	4448	Economy	13400.00
0005435163312	4448	Economy	13400.00
0005435163313	4448	Economy	13400.00
0005435163316	4448	Economy	12200.00
0005435163311	4448	Economy	12200.00
0005435163308	4448	Economy	12200.00
0005435933476	4448	Economy	12200.00
0005435933495	4448	Economy	12200.00
0005435163310	4448	Economy	12200.00
0005435163307	4448	Economy	12200.00
0005435933488	4448	Economy	12200.00
0005435163305	4448	Economy	12200.00
0005435163315	4448	Economy	12200.00
0005435933472	4448	Economy	12200.00
0005435933487	4448	Economy	12200.00
0005435163314	4448	Economy	12200.00
0005435163306	4448	Economy	12200.00
0005433404859	2836	Business	12600.00
0005435797686	2836	Business	12600.00
0005435797699	2836	Business	12600.00
0005433404869	2836	Economy	4200.00
0005433404846	2836	Economy	4200.00
0005433404847	2836	Economy	4600.00
0005433404883	2836	Economy	4600.00
0005433404860	2836	Economy	4200.00
0005435797685	2836	Economy	4200.00
0005435797696	2836	Economy	4200.00
0005435797690	2836	Economy	4200.00
0005435797697	2836	Economy	4200.00
0005435797698	2836	Economy	4200.00
0005435797691	2836	Economy	4200.00
0005435797694	2836	Economy	4200.00
0005435797689	2836	Economy	4200.00
0005435797688	2836	Economy	4200.00
0005433404885	2836	Economy	4200.00
0005435797692	2836	Economy	4200.00
0005433404873	2836	Economy	4200.00
0005435797695	2836	Economy	4200.00
0005435797693	2836	Economy	4200.00
0005435797687	2836	Economy	4200.00
0005433404923	29349	Business	12600.00
0005433404922	29349	Economy	4200.00
0005435797625	29349	Economy	4200.00
0005435797626	29349	Economy	4200.00
0005433404924	29349	Economy	4200.00
0005433404928	29349	Economy	4200.00
0005435797618	29349	Economy	4200.00
0005433404927	29349	Economy	4200.00
0005435797584	29349	Economy	4200.00
0005435797579	29349	Economy	4200.00
0005433404926	29349	Economy	4200.00
0005433404921	29349	Economy	4200.00
0005435797597	29349	Economy	4200.00
0005435797578	29349	Economy	4200.00
0005435797624	29349	Economy	4200.00
0005433404925	29349	Economy	4200.00
0005435376371	5742	Economy	6800.00
0005434948145	5739	Economy	6800.00
0005434948146	5739	Economy	6800.00
0005434948148	5739	Economy	6800.00
0005434948149	5739	Economy	6800.00
0005434948143	5739	Economy	6800.00
0005434948147	5739	Economy	6800.00
0005434948144	5739	Economy	6800.00
0005434948142	5739	Economy	6800.00
0005434948141	5739	Economy	6800.00
0005435376397	16357	Economy	6800.00
0005435376395	16357	Economy	6800.00
0005434948077	16357	Economy	6800.00
0005434948076	16357	Economy	6800.00
0005434948091	16357	Economy	6800.00
0005435376394	16357	Economy	6800.00
0005435376396	16357	Economy	6800.00
0005434948078	16357	Economy	6800.00
0005435376392	16357	Economy	6800.00
0005434948124	16357	Economy	6800.00
0005435376393	16357	Economy	6800.00
0005433961754	6893	Business	21400.00
0005433961741	6893	Business	21400.00
0005433961752	6893	Business	21400.00
0005433961749	6893	Business	21400.00
0005433961729	6893	Business	21400.00
0005433961755	6893	Business	21400.00
0005433961767	6893	Business	21400.00
0005433961740	6893	Business	21400.00
0005433961753	6893	Business	21400.00
0005433961732	6893	Economy	7100.00
0005433961726	6893	Economy	7100.00
0005433961737	6893	Economy	7100.00
0005433961772	6893	Economy	7100.00
0005433961768	6893	Economy	7100.00
0005433961771	6893	Economy	7100.00
0005433961718	6893	Economy	7100.00
0005433961735	6893	Economy	7800.00
0005433961745	6893	Economy	7800.00
0005433961743	6893	Economy	7800.00
0005433961761	6893	Economy	7800.00
0005433961765	6893	Economy	7800.00
0005433961721	6893	Economy	7100.00
0005433961758	6893	Economy	7100.00
0005433961717	6893	Economy	7100.00
0005433961727	6893	Economy	7100.00
0005433961763	6893	Economy	7100.00
0005433961762	6893	Economy	7100.00
0005433961736	6893	Economy	7100.00
0005433961756	6893	Economy	7100.00
0005433961731	6893	Economy	7100.00
0005433961713	6893	Economy	7100.00
0005433961728	6893	Economy	7100.00
0005433961744	6893	Economy	7100.00
0005433961719	6893	Economy	7100.00
0005433961766	6893	Economy	7100.00
0005433961759	6893	Economy	7100.00
0005433961746	6893	Economy	7100.00
0005433961764	6893	Economy	7100.00
0005433961777	6893	Economy	7100.00
0005433961738	6893	Economy	7100.00
0005433961742	6893	Economy	7100.00
0005433961748	6893	Economy	7100.00
0005433961747	6893	Economy	7100.00
0005433961757	6893	Economy	7100.00
0005433961769	6893	Economy	7100.00
0005433961715	6893	Economy	7100.00
0005433961770	6893	Economy	7100.00
0005433961775	6893	Economy	7100.00
0005433961725	6893	Economy	7100.00
0005433961723	6893	Economy	7100.00
0005433961750	6893	Economy	7100.00
0005433961720	6893	Economy	7100.00
0005433961734	6893	Economy	7100.00
0005433961716	6893	Economy	7100.00
0005433961776	6893	Economy	7100.00
0005433961760	6893	Economy	7100.00
0005433961722	6893	Economy	7100.00
0005433961724	6893	Economy	7100.00
0005433961773	6893	Economy	7100.00
0005433961714	6893	Economy	7100.00
0005433961751	6893	Economy	7100.00
0005433961774	6893	Economy	7100.00
0005433961730	6893	Economy	7100.00
0005433961739	6893	Economy	7100.00
0005433961733	6893	Economy	7100.00
0005433961064	25797	Business	21400.00
0005433961054	25797	Business	21400.00
0005433961129	25797	Business	21400.00
0005433960957	25797	Business	21400.00
0005433960953	25797	Business	21400.00
0005433960856	25797	Business	21400.00
0005433960894	25797	Business	21400.00
0005433961136	25797	Business	21400.00
0005433961084	25797	Economy	7100.00
0005433961111	25797	Economy	7100.00
0005433961128	25797	Economy	7100.00
0005433961141	25797	Economy	7100.00
0005433960921	25797	Economy	7100.00
0005433961096	25797	Economy	7800.00
0005433961098	25797	Economy	7800.00
0005433960946	25797	Economy	7100.00
0005433961029	25797	Economy	7100.00
0005433961148	25797	Economy	7100.00
0005433961067	25797	Economy	7100.00
0005433961107	25797	Economy	7100.00
0005433960982	25797	Economy	7100.00
0005433961016	25797	Economy	7100.00
0005433961167	25797	Economy	7100.00
0005433960838	25797	Economy	7100.00
0005433960964	25797	Economy	7100.00
0005433960954	25797	Economy	7100.00
0005433961056	25797	Economy	7100.00
0005433960861	25797	Economy	7100.00
0005433961110	25797	Economy	7100.00
0005433961125	25797	Economy	7100.00
0005433961057	25797	Economy	7100.00
0005433960862	25797	Economy	7100.00
0005433960936	25797	Economy	7100.00
0005433961153	25797	Economy	7100.00
0005433960983	25797	Economy	7100.00
0005433961137	25797	Economy	7100.00
0005433961015	25797	Economy	7100.00
0005433960893	25797	Economy	7100.00
0005433961152	25797	Economy	7100.00
0005433961168	25797	Economy	7100.00
0005433961171	25797	Economy	7100.00
0005433961147	25797	Economy	7100.00
0005433961169	25797	Economy	7100.00
0005433961165	25797	Economy	7100.00
0005433961066	25797	Economy	7100.00
0005433961034	25797	Economy	7100.00
0005433961151	25797	Economy	7100.00
0005433961085	25797	Economy	7100.00
0005433960920	25797	Economy	7100.00
0005433961097	25797	Economy	7100.00
0005433961130	25797	Economy	7100.00
0005435082833	24472	Economy	3900.00
0005435082832	24472	Economy	3900.00
0005435082816	24472	Economy	3900.00
0005435082826	24472	Economy	3900.00
0005435082814	24472	Economy	3900.00
0005435082830	24472	Economy	3900.00
0005435082846	24472	Economy	3900.00
0005435082840	24472	Economy	3900.00
0005435082825	24472	Economy	3900.00
0005435082813	24472	Economy	3900.00
0005435082899	26135	Economy	3900.00
0005435082902	26135	Economy	3900.00
0005435082904	26135	Economy	3900.00
0005435082906	26135	Economy	3900.00
0005435082898	26135	Economy	3900.00
0005435082900	26135	Economy	3900.00
0005435082901	26135	Economy	3900.00
0005435082903	26135	Economy	3900.00
0005435082905	26135	Economy	3900.00
0005434245438	5030	Business	18000.00
0005434245443	5030	Business	18000.00
0005434245427	5030	Business	18000.00
0005434245435	5030	Economy	6600.00
0005434245429	5030	Economy	6600.00
0005434245433	5030	Economy	6000.00
0005434245442	5030	Economy	6000.00
0005432166951	5030	Economy	6000.00
0005434245432	5030	Economy	6000.00
0005432166950	5030	Economy	6000.00
0005434245421	5030	Economy	6000.00
0005434245445	5030	Economy	6000.00
0005434245444	5030	Economy	6000.00
0005434245422	5030	Economy	6000.00
0005434245447	5030	Economy	6000.00
0005434245434	5030	Economy	6000.00
0005433534512	5030	Economy	6000.00
0005434245430	5030	Economy	6000.00
0005435286652	5030	Economy	6000.00
0005434245423	5030	Economy	6000.00
0005432166952	5030	Economy	6000.00
0005434245424	5030	Economy	6000.00
0005434245425	5030	Economy	6000.00
0005434245428	5030	Economy	6000.00
0005434245418	5030	Economy	6000.00
0005434245419	5030	Economy	6000.00
0005434245437	5030	Economy	6000.00
0005433534511	5030	Economy	6000.00
0005434245441	5030	Economy	6000.00
0005434245439	5030	Economy	6000.00
0005434245431	5030	Economy	6000.00
0005434245426	5030	Economy	6000.00
0005434245440	5030	Economy	6000.00
0005434245436	5030	Economy	6000.00
0005434245420	5030	Economy	6000.00
0005435286653	5030	Economy	6000.00
0005434245446	5030	Economy	6000.00
0005432106300	5011	Business	18000.00
0005432667486	5011	Business	18000.00
0005433785497	5011	Business	18000.00
0005432106311	5011	Business	18000.00
0005433615820	5011	Business	18000.00
0005433615784	5011	Business	18000.00
0005432106310	5011	Business	18000.00
0005433615829	5011	Business	18000.00
0005433615832	5011	Business	18000.00
0005432665307	5011	Business	18000.00
0005433785521	5011	Business	18000.00
0005432106281	5011	Business	18000.00
0005433615802	5011	Business	18000.00
0005433615810	5011	Business	18000.00
0005433785508	5011	Business	18000.00
0005432106326	5011	Business	18000.00
0005432106282	5011	Business	18000.00
0005433785486	5011	Business	18000.00
0005433615816	5011	Business	18000.00
0005432106297	5011	Business	18000.00
0005433615808	5011	Business	18000.00
0005433615851	5011	Business	18000.00
0005433615794	5011	Business	18000.00
0005433615792	5011	Business	18000.00
0005432106284	5011	Business	18000.00
0005432106321	5011	Business	18000.00
0005432106324	5011	Business	18000.00
0005432106307	5011	Business	18000.00
0005432106280	5011	Economy	6600.00
0005433615843	5011	Economy	6600.00
0005432106306	5011	Economy	6600.00
0005433785494	5011	Economy	6600.00
0005433785504	5011	Economy	6600.00
0005433615799	5011	Economy	6600.00
0005432106294	5011	Economy	6000.00
0005433615788	5011	Economy	6000.00
0005433785490	5011	Economy	6000.00
0005433785500	5011	Economy	6000.00
0005433615830	5011	Economy	6000.00
0005433785503	5011	Economy	6000.00
0005433615850	5011	Economy	6000.00
0005433615827	5011	Economy	6000.00
0005432106304	5011	Economy	6000.00
0005432666420	5011	Economy	6000.00
0005433615785	5011	Economy	6000.00
0005433785517	5011	Economy	6000.00
0005432106312	5011	Economy	6000.00
0005433785510	5011	Economy	6000.00
0005433785511	5011	Economy	6000.00
0005433615790	5011	Economy	6000.00
0005433615783	5011	Economy	6000.00
0005432106295	5011	Economy	6000.00
0005432106325	5011	Economy	6000.00
0005433615803	5011	Economy	6000.00
0005433615823	5011	Economy	6000.00
0005432106319	5011	Economy	6000.00
0005433785498	5011	Economy	6000.00
0005433785489	5011	Economy	6000.00
0005433615782	5011	Economy	6000.00
0005432106302	5011	Economy	6000.00
0005433615825	5011	Economy	6000.00
0005433615814	5011	Economy	6000.00
0005432106322	5011	Economy	6000.00
0005433615809	5011	Economy	6000.00
0005433615837	5011	Economy	6000.00
0005433615835	5011	Economy	6000.00
0005433615844	5011	Economy	6000.00
0005433615789	5011	Economy	6000.00
0005432145143	5011	Economy	6000.00
0005433785516	5011	Economy	6000.00
0005433615821	5011	Economy	6000.00
0005433615842	5011	Economy	6000.00
0005433615838	5011	Economy	6000.00
0005433785499	5011	Economy	6000.00
0005433615806	5011	Economy	6000.00
0005433785506	5011	Economy	6000.00
0005432106278	5011	Economy	6000.00
0005433785495	5011	Economy	6000.00
0005433615813	5011	Economy	6000.00
0005433615786	5011	Economy	6000.00
0005432106314	5011	Economy	6000.00
0005433785522	5011	Economy	6000.00
0005432106317	5011	Economy	6000.00
0005433785502	5011	Economy	6000.00
0005433785483	5011	Economy	6000.00
0005433785518	5011	Economy	6000.00
0005432106299	5011	Economy	6000.00
0005432106303	5011	Economy	6000.00
0005433615807	5011	Economy	6000.00
0005433785513	5011	Economy	6000.00
0005433615847	5011	Economy	6000.00
0005433615787	5011	Economy	6000.00
0005432106293	5011	Economy	6000.00
0005433785487	5011	Economy	6000.00
0005433785488	5011	Economy	6600.00
0005433785507	5011	Economy	6600.00
0005432106323	5011	Economy	6600.00
0005433615804	5011	Economy	6600.00
0005433785501	5011	Economy	6600.00
0005433615853	5011	Economy	6000.00
0005433785493	5011	Economy	6000.00
0005433615819	5011	Economy	6000.00
0005433615818	5011	Economy	6000.00
0005433615839	5011	Economy	6600.00
0005432665306	5011	Economy	6000.00
0005432106301	5011	Economy	6000.00
0005432106298	5011	Economy	6000.00
0005433785485	5011	Economy	6000.00
0005432106305	5011	Economy	6000.00
0005433615797	5011	Economy	6000.00
0005433615793	5011	Economy	6000.00
0005432106309	5011	Economy	6000.00
0005433615849	5011	Economy	6000.00
0005433785509	5011	Economy	6000.00
0005432106290	5011	Economy	6000.00
0005432145144	5011	Economy	6000.00
0005432106313	5011	Economy	6000.00
0005432106286	5011	Economy	6000.00
0005433615836	5011	Economy	6000.00
0005432106289	5011	Economy	6000.00
0005433615798	5011	Economy	6000.00
0005433615811	5011	Economy	6000.00
0005432106320	5011	Economy	6000.00
0005433785515	5011	Economy	6000.00
0005432106318	5011	Economy	6000.00
0005433615800	5011	Economy	6000.00
0005433615834	5011	Economy	6000.00
0005433615841	5011	Economy	6000.00
0005433615833	5011	Economy	6000.00
0005433615846	5011	Economy	6000.00
0005433615801	5011	Economy	6000.00
0005433785505	5011	Economy	6000.00
0005433615828	5011	Economy	6000.00
0005433615840	5011	Economy	6000.00
0005432106308	5011	Economy	6000.00
0005432106287	5011	Economy	6000.00
0005433615831	5011	Economy	6000.00
0005433785512	5011	Economy	6000.00
0005433615795	5011	Economy	6000.00
0005433785492	5011	Economy	6000.00
0005433785496	5011	Economy	6000.00
0005432106296	5011	Economy	6000.00
0005433615805	5011	Economy	6000.00
0005433615815	5011	Economy	6000.00
0005433615817	5011	Economy	6000.00
0005432106291	5011	Economy	6000.00
0005433785520	5011	Economy	6000.00
0005432666421	5011	Economy	6000.00
0005433615822	5011	Economy	6000.00
0005433615826	5011	Economy	6000.00
0005433785484	5011	Economy	6000.00
0005433785519	5011	Economy	6000.00
0005433615796	5011	Economy	6000.00
0005433615852	5011	Economy	6000.00
0005433615855	5011	Economy	6000.00
0005433615845	5011	Economy	6000.00
0005433615824	5011	Economy	6000.00
0005432106279	5011	Economy	6000.00
0005433615791	5011	Economy	6000.00
0005432106283	5011	Economy	6000.00
0005433615854	5011	Economy	6000.00
0005433785514	5011	Economy	6000.00
0005432106292	5011	Economy	6000.00
0005432106316	5011	Economy	6000.00
0005433785491	5011	Economy	6000.00
0005432106285	5011	Economy	6000.00
0005433615848	5011	Economy	6000.00
0005433615812	5011	Economy	6000.00
0005432106288	5011	Economy	6000.00
0005432106315	5011	Economy	6000.00
0005432336081	4948	Business	18000.00
0005434149916	4948	Business	18000.00
0005434229723	4948	Business	18000.00
0005432336111	4948	Business	18000.00
0005434229708	4948	Business	18000.00
0005434173581	4948	Business	18000.00
0005434265540	4948	Business	18000.00
0005432336143	4948	Business	18000.00
0005434149914	4948	Business	18000.00
0005434265535	4948	Business	18000.00
0005433815419	4948	Business	18000.00
0005434229725	4948	Business	18000.00
0005434149912	4948	Business	18000.00
0005434229724	4948	Business	18000.00
0005433688819	4948	Business	18000.00
0005434229728	4948	Business	18000.00
0005434229714	4948	Business	18000.00
0005434265534	4948	Business	18000.00
0005435007119	4948	Business	18000.00
0005434265546	4948	Business	18000.00
0005432336144	4948	Economy	6600.00
0005434149907	4948	Economy	6600.00
0005434173583	4948	Economy	6600.00
0005433688821	4948	Economy	6600.00
0005435007110	4948	Economy	6600.00
0005434229715	4948	Economy	6000.00
0005435007061	4948	Economy	6000.00
0005434229709	4948	Economy	6000.00
0005434149910	4948	Economy	6000.00
0005432336126	4948	Economy	6000.00
0005435007060	4948	Economy	6000.00
0005432336160	4948	Economy	6000.00
0005433815424	4948	Economy	6000.00
0005434149908	4948	Economy	6000.00
0005434265526	4948	Economy	6000.00
0005434265523	4948	Economy	6000.00
0005434265531	4948	Economy	6000.00
0005432336106	4948	Economy	6000.00
0005434265539	4948	Economy	6000.00
0005433815427	4948	Economy	6000.00
0005434229716	4948	Economy	6000.00
0005434229711	4948	Economy	6000.00
0005434149917	4948	Economy	6000.00
0005434265548	4948	Economy	6000.00
0005434265529	4948	Economy	6000.00
0005434265522	4948	Economy	6000.00
0005435007246	4948	Economy	6000.00
0005434229721	4948	Economy	6000.00
0005434173582	4948	Economy	6000.00
0005433815426	4948	Economy	6000.00
0005434265524	4948	Economy	6000.00
0005434265525	4948	Economy	6000.00
0005435007236	4948	Economy	6000.00
0005434265530	4948	Economy	6000.00
0005434265527	4948	Economy	6000.00
0005435007191	4948	Economy	6000.00
0005433685535	4948	Economy	6000.00
0005435007248	4948	Economy	6000.00
0005435007141	4948	Economy	6000.00
0005433688822	4948	Economy	6000.00
0005434229719	4948	Economy	6000.00
0005434173580	4948	Economy	6000.00
0005432336115	4948	Economy	6000.00
0005432336110	4948	Economy	6000.00
0005432336168	4948	Economy	6000.00
0005434265543	4948	Economy	6000.00
0005434229706	4948	Economy	6000.00
0005435007247	4948	Economy	6000.00
0005433815423	4948	Economy	6000.00
0005434265544	4948	Economy	6000.00
0005432336080	4948	Economy	6000.00
0005434265542	4948	Economy	6000.00
0005433815400	4948	Economy	6000.00
0005434265521	4948	Economy	6600.00
0005434229718	4948	Economy	6600.00
0005432336107	4948	Economy	6600.00
0005435007088	4948	Economy	6000.00
0005434229726	4948	Economy	6600.00
0005432336121	4948	Economy	6000.00
0005432336128	4948	Economy	6000.00
0005433815435	4948	Economy	6600.00
0005432336120	4948	Economy	6000.00
0005433815422	4948	Economy	6000.00
0005432336112	4948	Economy	6000.00
0005434265547	4948	Economy	6000.00
0005433685526	4948	Economy	6000.00
0005434229727	4948	Economy	6000.00
0005434229717	4948	Economy	6000.00
0005433815406	4948	Economy	6000.00
0005433688820	4948	Economy	6000.00
0005435007224	4948	Economy	6000.00
0005434149913	4948	Economy	6000.00
0005433685534	4948	Economy	6000.00
0005435007089	4948	Economy	6000.00
0005434265528	4948	Economy	6000.00
0005435007123	4948	Economy	6000.00
0005434229713	4948	Economy	6000.00
0005434229720	4948	Economy	6000.00
0005435007118	4948	Economy	6000.00
0005434265537	4948	Economy	6000.00
0005434229707	4948	Economy	6000.00
0005434229712	4948	Economy	6000.00
0005435007133	4948	Economy	6000.00
0005434265536	4948	Economy	6000.00
0005435007190	4948	Economy	6000.00
0005432336109	4948	Economy	6000.00
0005434265545	4948	Economy	6000.00
0005432336129	4948	Economy	6000.00
0005434229710	4948	Economy	6000.00
0005434312330	4948	Economy	6000.00
0005434265533	4948	Economy	6000.00
0005432336159	4948	Economy	6000.00
0005434149909	4948	Economy	6000.00
0005434149905	4948	Economy	6000.00
0005435007194	4948	Economy	6000.00
0005434265538	4948	Economy	6000.00
0005435007162	4948	Economy	6000.00
0005434149915	4948	Economy	6000.00
0005433815436	4948	Economy	6000.00
0005433815420	4948	Economy	6000.00
0005434265541	4948	Economy	6000.00
0005434229722	4948	Economy	6000.00
0005432336125	4948	Economy	6000.00
0005435007193	4948	Economy	6000.00
0005433815418	4948	Economy	6000.00
0005434149906	4948	Economy	6000.00
0005434173579	4948	Economy	6000.00
0005434265532	4948	Economy	6000.00
0005432336092	4948	Economy	6000.00
0005434149911	4948	Economy	6000.00
0005433688823	4948	Economy	6000.00
0005435007192	4948	Economy	6000.00
0005433785156	8472	Business	18000.00
0005433785319	8472	Business	18000.00
0005434245090	8472	Business	18000.00
0005434245274	8472	Business	18000.00
0005433785320	8472	Business	18000.00
0005434245202	8472	Business	18000.00
0005433785130	8472	Business	18000.00
0005434245216	8472	Business	18000.00
0005433785057	8472	Business	18000.00
0005432666407	8472	Economy	6600.00
0005434245101	8472	Economy	6600.00
0005434245162	8472	Economy	6000.00
0005434245083	8472	Economy	6000.00
0005434245174	8472	Economy	6000.00
0005435269875	8472	Economy	6000.00
0005432666402	8472	Economy	6000.00
0005433785282	8472	Economy	6000.00
0005433785263	8472	Economy	6000.00
0005433785201	8472	Economy	6000.00
0005434245150	8472	Economy	6000.00
0005433785239	8472	Economy	6000.00
0005434245175	8472	Economy	6000.00
0005433785238	8472	Economy	6000.00
0005433785283	8472	Economy	6000.00
0005432666405	8472	Economy	6000.00
0005434245154	8472	Economy	6000.00
0005434245329	8472	Economy	6000.00
0005434245217	8472	Economy	6000.00
0005433785166	8472	Economy	6000.00
0005434245230	8472	Economy	6000.00
0005433785048	8472	Economy	6000.00
0005434245234	8472	Economy	6000.00
0005434245190	8472	Economy	6000.00
0005434245325	8472	Economy	6000.00
0005432663055	8472	Economy	6000.00
0005434245176	8472	Economy	6000.00
0005433785077	8472	Economy	6000.00
0005432663030	8472	Economy	6000.00
0005435269878	8472	Economy	6000.00
0005434245100	8472	Economy	6000.00
0005433785159	8472	Economy	6600.00
0005433785171	8472	Economy	6600.00
0005432666401	8472	Economy	6600.00
0005434245167	8472	Economy	6000.00
0005433785139	8472	Economy	6000.00
0005434245118	8472	Economy	6600.00
0005433785131	8472	Economy	6000.00
0005433785262	8472	Economy	6000.00
0005435269877	8472	Economy	6000.00
0005433785045	8472	Economy	6000.00
0005433785231	8472	Economy	6000.00
0005432666406	8472	Economy	6000.00
0005434245316	8472	Economy	6000.00
0005434245155	8472	Economy	6000.00
0005434245291	8472	Economy	6000.00
0005434245229	8472	Economy	6000.00
0005434245215	8472	Economy	6000.00
0005434245326	8472	Economy	6000.00
0005434245115	8472	Economy	6000.00
0005433785146	8472	Economy	6000.00
0005433785211	8472	Economy	6000.00
0005432659719	8472	Economy	6000.00
0005434245248	8472	Economy	6000.00
0005433785325	8472	Economy	6000.00
0005434245192	8472	Economy	6000.00
0005433785160	8472	Economy	6000.00
0005433785114	8472	Economy	6000.00
0005434245141	8472	Economy	6000.00
0005433785046	8472	Economy	6000.00
0005433785167	8472	Economy	6000.00
0005435269876	8472	Economy	6000.00
0005434245244	8472	Economy	6000.00
0005434245201	8472	Economy	6000.00
0005435269874	8472	Economy	6000.00
0005434245119	8472	Economy	6000.00
0005434245158	8472	Economy	6000.00
0005434245218	8472	Economy	6000.00
0005434245247	8472	Economy	6000.00
0005433785087	8472	Economy	6000.00
0005433785210	8472	Economy	6000.00
0005433615069	8471	Business	18000.00
0005433614970	8471	Business	18000.00
0005433615141	8471	Business	18000.00
0005433614828	8471	Business	18000.00
0005433615135	8471	Business	18000.00
0005433615073	8471	Business	18000.00
0005433614821	8471	Business	18000.00
0005433614859	8471	Business	18000.00
0005433614949	8471	Business	18000.00
0005433614775	8471	Business	18000.00
0005433614984	8471	Business	18000.00
0005433615131	8471	Business	18000.00
0005433615272	8471	Business	18000.00
0005433615312	8471	Economy	6600.00
0005433615208	8471	Economy	6600.00
0005433614848	8471	Economy	6000.00
0005433615223	8471	Economy	6000.00
0005433614904	8471	Economy	6000.00
0005433615063	8471	Economy	6000.00
0005433615218	8471	Economy	6000.00
0005433615300	8471	Economy	6000.00
0005433615108	8471	Economy	6000.00
0005433615316	8471	Economy	6000.00
0005433615197	8471	Economy	6000.00
0005433615074	8471	Economy	6000.00
0005433615348	8471	Economy	6000.00
0005433615165	8471	Economy	6000.00
0005433615178	8471	Economy	6000.00
0005433615317	8471	Economy	6000.00
0005433615304	8471	Economy	6000.00
0005433614820	8471	Economy	6000.00
0005433615042	8471	Economy	6000.00
0005433615082	8471	Economy	6000.00
0005433615015	8471	Economy	6000.00
0005433614739	8471	Economy	6000.00
0005433615271	8471	Economy	6000.00
0005433615022	8471	Economy	6000.00
0005433615273	8471	Economy	6000.00
0005433615062	8471	Economy	6000.00
0005433615005	8471	Economy	6000.00
0005433615228	8471	Economy	6000.00
0005433614898	8471	Economy	6000.00
0005433615125	8471	Economy	6000.00
0005433615081	8471	Economy	6000.00
0005433615142	8471	Economy	6000.00
0005433615224	8471	Economy	6000.00
0005433615340	8471	Economy	6000.00
0005433615166	8471	Economy	6000.00
0005433614881	8471	Economy	6600.00
0005433615311	8471	Economy	6600.00
0005433615412	8471	Economy	6000.00
0005433614981	8471	Economy	6600.00
0005433615200	8471	Economy	6000.00
0005433614677	8471	Economy	6000.00
0005433615130	8471	Economy	6000.00
0005433614827	8471	Economy	6000.00
0005433614948	8471	Economy	6000.00
0005433615525	8471	Economy	6000.00
0005433614676	8471	Economy	6000.00
0005433614880	8471	Economy	6000.00
0005433614911	8471	Economy	6000.00
0005433615198	8471	Economy	6000.00
0005433615149	8471	Economy	6000.00
0005433615398	8471	Economy	6000.00
0005433615122	8471	Economy	6000.00
0005433615299	8471	Economy	6000.00
0005433615176	8471	Economy	6000.00
0005433615209	8471	Economy	6000.00
0005433615050	8471	Economy	6000.00
0005433615126	8471	Economy	6000.00
0005433615148	8471	Economy	6000.00
0005433615075	8471	Economy	6000.00
0005433614929	8471	Economy	6000.00
0005433614868	8471	Economy	6000.00
0005433614829	8471	Economy	6000.00
0005433615397	8471	Economy	6000.00
0005433615376	8471	Economy	6000.00
0005433615349	8471	Economy	6000.00
0005433615109	8471	Economy	6000.00
0005433615199	8471	Economy	6000.00
0005433615043	8471	Economy	6000.00
0005433615172	8471	Economy	6000.00
0005433615164	8471	Economy	6000.00
0005433615016	8471	Economy	6000.00
0005433615179	8471	Economy	6000.00
0005433614849	8471	Economy	6000.00
0005433614982	8471	Economy	6000.00
0005433615102	8471	Economy	6000.00
0005433615110	8471	Economy	6000.00
0005433614748	8471	Economy	6000.00
0005433615010	8471	Economy	6000.00
0005433614969	8471	Economy	6000.00
0005435007394	8470	Business	18000.00
0005435007395	8470	Business	18000.00
0005435007399	8470	Business	18000.00
0005434265212	8470	Business	18000.00
0005432035376	8470	Business	18000.00
0005434265262	8470	Business	18000.00
0005433689944	8470	Business	18000.00
0005434265387	8470	Business	18000.00
0005433815461	8470	Business	18000.00
0005432035369	8470	Business	18000.00
0005434265284	8470	Business	18000.00
0005434265323	8470	Business	18000.00
0005434265268	8470	Business	18000.00
0005432047606	8470	Business	18000.00
0005434265396	8470	Business	18000.00
0005435007389	8470	Business	18000.00
0005432035378	8470	Business	18000.00
0005434265288	8470	Business	18000.00
0005432035363	8470	Business	18000.00
0005432336215	8470	Business	18000.00
0005434265350	8470	Business	18000.00
0005434229509	8470	Business	18000.00
0005434265283	8470	Business	18000.00
0005432035377	8470	Business	18000.00
0005432035383	8470	Economy	6600.00
0005435007388	8470	Economy	6600.00
0005434229510	8470	Economy	6600.00
0005433815460	8470	Economy	6600.00
0005434149819	8470	Economy	6600.00
0005435007392	8470	Economy	6600.00
0005434265374	8470	Economy	6000.00
0005434229519	8470	Economy	6000.00
0005432035382	8470	Economy	6000.00
0005434229518	8470	Economy	6000.00
0005434265349	8470	Economy	6000.00
0005432035365	8470	Economy	6000.00
0005434311250	8470	Economy	6000.00
0005433534531	8470	Economy	6000.00
0005435007386	8470	Economy	6000.00
0005435007393	8470	Economy	6000.00
0005432336213	8470	Economy	6000.00
0005435007382	8470	Economy	6000.00
0005434265263	8470	Economy	6000.00
0005434229478	8470	Economy	6000.00
0005434265244	8470	Economy	6000.00
0005435007385	8470	Economy	6000.00
0005433688842	8470	Economy	6000.00
0005434229490	8470	Economy	6000.00
0005432336222	8470	Economy	6000.00
0005433815463	8470	Economy	6000.00
0005432035370	8470	Economy	6000.00
0005434265404	8470	Economy	6000.00
0005432035380	8470	Economy	6000.00
0005434265197	8470	Economy	6000.00
0005434265272	8470	Economy	6000.00
0005434173538	8470	Economy	6000.00
0005432035381	8470	Economy	6000.00
0005434265347	8470	Economy	6000.00
0005432336218	8470	Economy	6000.00
0005434229600	8470	Economy	6000.00
0005432035361	8470	Economy	6000.00
0005434229517	8470	Economy	6000.00
0005432035367	8470	Economy	6000.00
0005434173543	8470	Economy	6000.00
0005434265282	8470	Economy	6000.00
0005434265241	8470	Economy	6000.00
0005434229472	8470	Economy	6000.00
0005432035374	8470	Economy	6000.00
0005434311251	8470	Economy	6000.00
0005434265463	8470	Economy	6000.00
0005432035379	8470	Economy	6000.00
0005434265296	8470	Economy	6000.00
0005432047607	8470	Economy	6000.00
0005434265279	8470	Economy	6000.00
0005434229515	8470	Economy	6000.00
0005434265462	8470	Economy	6000.00
0005434173544	8470	Economy	6000.00
0005433534533	8470	Economy	6000.00
0005435007384	8470	Economy	6000.00
0005432336212	8470	Economy	6000.00
0005432035368	8470	Economy	6000.00
0005433689943	8470	Economy	6000.00
0005434229601	8470	Economy	6000.00
0005433534530	8470	Economy	6600.00
0005434229452	8470	Economy	6600.00
0005434149874	8470	Economy	6600.00
0005435007381	8470	Economy	6600.00
0005434265238	8470	Economy	6000.00
0005432035384	8470	Economy	6000.00
0005434265344	8470	Economy	6000.00
0005433690957	8470	Economy	6000.00
0005432047609	8470	Economy	6600.00
0005434229488	8470	Economy	6000.00
0005434149818	8470	Economy	6000.00
0005433534532	8470	Economy	6000.00
0005435007391	8470	Economy	6000.00
0005435007380	8470	Economy	6000.00
0005434265289	8470	Economy	6000.00
0005435007401	8470	Economy	6000.00
0005432035375	8470	Economy	6000.00
0005434173546	8470	Economy	6000.00
0005434265243	8470	Economy	6000.00
0005434229521	8470	Economy	6000.00
0005432336223	8470	Economy	6000.00
0005432047608	8470	Economy	6000.00
0005432336216	8470	Economy	6000.00
0005432035387	8470	Economy	6000.00
0005434265277	8470	Economy	6000.00
0005432035372	8470	Economy	6000.00
0005434229602	8470	Economy	6000.00
0005432035385	8470	Economy	6000.00
0005434229456	8470	Economy	6000.00
0005435007383	8470	Economy	6000.00
0005432035364	8470	Economy	6000.00
0005434229514	8470	Economy	6000.00
0005435007400	8470	Economy	6000.00
0005432035362	8470	Economy	6000.00
0005434149804	8470	Economy	6000.00
0005434149806	8470	Economy	6000.00
0005434265280	8470	Economy	6000.00
0005434311249	8470	Economy	6000.00
0005432035366	8470	Economy	6000.00
0005434229537	8470	Economy	6000.00
0005434149773	8470	Economy	6000.00
0005434229458	8470	Economy	6000.00
0005434229424	8470	Economy	6000.00
0005432336217	8470	Economy	6000.00
0005432336219	8470	Economy	6000.00
0005434149772	8470	Economy	6000.00
0005434265312	8470	Economy	6000.00
0005435007396	8470	Economy	6000.00
0005434265285	8470	Economy	6000.00
0005434229459	8470	Economy	6000.00
0005434265375	8470	Economy	6000.00
0005434265343	8470	Economy	6000.00
0005434265297	8470	Economy	6000.00
0005435007398	8470	Economy	6000.00
0005432336214	8470	Economy	6000.00
0005432035386	8470	Economy	6000.00
0005432035371	8470	Economy	6000.00
0005434229536	8470	Economy	6000.00
0005435007390	8470	Economy	6000.00
0005433690956	8470	Economy	6000.00
0005434265403	8470	Economy	6000.00
0005432035373	8470	Economy	6000.00
0005434173545	8470	Economy	6000.00
0005434229455	8470	Economy	6000.00
0005433815462	8470	Economy	6000.00
0005432336221	8470	Economy	6000.00
0005434265278	8470	Economy	6000.00
0005432035388	8470	Economy	6000.00
0005435007387	8470	Economy	6000.00
0005435007397	8470	Economy	6000.00
0005432336220	8470	Economy	6000.00
0005434229561	8470	Economy	6000.00
0005433202596	12632	Economy	16200.00
0005434639581	12632	Economy	16200.00
0005434639570	12632	Economy	16200.00
0005433202588	12632	Economy	16200.00
0005434639457	12632	Economy	14800.00
0005433202594	12632	Economy	14800.00
0005433202597	12632	Economy	14800.00
0005434639458	12632	Economy	14800.00
0005434639512	12632	Economy	14800.00
0005433202593	12632	Economy	14800.00
0005433202592	12632	Economy	14800.00
0005434639495	12632	Economy	14800.00
0005434639555	12632	Economy	14800.00
0005433202587	12632	Economy	14800.00
0005434639500	12632	Economy	14800.00
0005434639499	12632	Economy	14800.00
0005433202595	12632	Economy	14800.00
0005433202585	12632	Economy	14800.00
0005434639471	12632	Economy	14800.00
0005434639440	12632	Economy	14800.00
0005434639533	12632	Economy	14800.00
0005434639582	12632	Economy	14800.00
0005434639531	12632	Economy	14800.00
0005434639439	12632	Economy	14800.00
0005434639459	12632	Economy	14800.00
0005434639519	12632	Economy	14800.00
0005433202586	12632	Economy	14800.00
0005434639502	12632	Economy	14800.00
0005433202591	12632	Economy	14800.00
0005434639492	12632	Economy	14800.00
0005433202589	12632	Economy	14800.00
0005433202598	12632	Economy	14800.00
0005434639549	12632	Economy	14800.00
0005434639545	12632	Economy	14800.00
0005434639518	12632	Economy	14800.00
0005434639494	12632	Economy	14800.00
0005434639534	12632	Economy	14800.00
0005434639513	12632	Economy	14800.00
0005434639441	12632	Economy	14800.00
0005434639442	12632	Economy	14800.00
0005434639543	12632	Economy	14800.00
0005434639524	12632	Economy	14800.00
0005434639542	12632	Economy	14800.00
0005434639511	12632	Economy	14800.00
0005434639493	12632	Economy	14800.00
0005434639452	12632	Economy	14800.00
0005434639550	12632	Economy	14800.00
0005433202590	12632	Economy	14800.00
0005434639557	12632	Economy	14800.00
0005434639553	12632	Economy	14800.00
0005434639691	23373	Economy	16200.00
0005434639695	23373	Economy	16200.00
0005434639705	23373	Economy	14800.00
0005433202432	23373	Economy	14800.00
0005434639700	23373	Economy	14800.00
0005433202467	23373	Economy	14800.00
0005434639706	23373	Economy	14800.00
0005433202431	23373	Economy	14800.00
0005434639699	23373	Economy	14800.00
0005434639701	23373	Economy	14800.00
0005434639684	23373	Economy	14800.00
0005433202447	23373	Economy	14800.00
0005433202446	23373	Economy	14800.00
0005433202454	23373	Economy	14800.00
0005434639697	23373	Economy	14800.00
0005434639702	23373	Economy	14800.00
0005434639704	23373	Economy	14800.00
0005434639693	23373	Economy	14800.00
0005434639692	23373	Economy	14800.00
0005434639696	23373	Economy	14800.00
0005434639689	23373	Economy	14800.00
0005432290679	23373	Economy	14800.00
0005434639685	23373	Economy	14800.00
0005434639698	23373	Economy	14800.00
0005434639694	23373	Economy	14800.00
0005433202455	23373	Economy	14800.00
0005433202439	23373	Economy	14800.00
0005434639687	23373	Economy	14800.00
0005433202427	23373	Economy	14800.00
0005434639690	23373	Economy	14800.00
0005434639688	23373	Economy	14800.00
0005434639686	23373	Economy	14800.00
0005434639703	23373	Economy	14800.00
0005432329014	21076	Business	18900.00
0005432383553	21076	Business	18900.00
0005432383483	21076	Business	18900.00
0005432383543	21076	Business	18900.00
0005432329051	21076	Business	18900.00
0005432383436	21076	Business	18900.00
0005432848849	21076	Business	18900.00
0005432848853	21076	Business	18900.00
0005432383389	21076	Business	18900.00
0005432328879	21076	Business	18900.00
0005432329045	21076	Economy	6300.00
0005432383355	21076	Economy	6300.00
0005432848856	21076	Economy	6300.00
0005432383370	21076	Economy	6300.00
0005432383488	21076	Economy	6300.00
0005432329085	21076	Economy	6300.00
0005432328948	21076	Economy	6300.00
0005432328997	21076	Economy	6300.00
0005432848850	21076	Economy	6900.00
0005432328981	21076	Economy	6900.00
0005432329250	21076	Economy	6900.00
0005432328926	21076	Economy	6900.00
0005432329090	21076	Economy	6900.00
0005432328993	21076	Economy	6300.00
0005432383371	21076	Economy	6300.00
0005432328877	21076	Economy	6300.00
0005432328958	21076	Economy	6300.00
0005432054350	21076	Economy	6300.00
0005432383359	21076	Economy	6300.00
0005432328873	21076	Economy	6300.00
0005432383409	21076	Economy	6300.00
0005432383322	21076	Economy	6300.00
0005432383206	21076	Economy	6300.00
0005432383356	21076	Economy	6300.00
0005432054349	21076	Economy	6300.00
0005432328944	21076	Economy	6300.00
0005432383449	21076	Economy	6300.00
0005432328980	21076	Economy	6300.00
0005432329053	21076	Economy	6300.00
0005432383537	21076	Economy	6300.00
0005432329052	21076	Economy	6300.00
0005432383335	21076	Economy	6300.00
0005432328891	21076	Economy	6300.00
0005432054351	21076	Economy	6300.00
0005432328897	21076	Economy	6300.00
0005432328872	21076	Economy	6300.00
0005432383401	21076	Economy	6300.00
0005432848855	21076	Economy	6300.00
0005432383372	21076	Economy	6300.00
0005432848852	21076	Economy	6300.00
0005432329188	21076	Economy	6300.00
0005432328766	21076	Economy	6300.00
0005432848847	21076	Economy	6300.00
0005432383443	21076	Economy	6300.00
0005432329110	21076	Economy	6300.00
0005432329050	21076	Economy	6300.00
0005432848848	21076	Economy	6300.00
0005432328832	21076	Economy	6300.00
0005432383292	21076	Economy	6300.00
0005432848851	21076	Economy	6300.00
0005432383564	21076	Economy	6300.00
0005432329187	21076	Economy	6300.00
0005432383329	21076	Economy	6300.00
0005432328933	21076	Economy	6300.00
0005432383291	21076	Economy	6300.00
0005432383360	21076	Economy	6300.00
0005432328893	21076	Economy	6300.00
0005432383486	21076	Economy	6300.00
0005432328892	21076	Economy	6300.00
0005432848854	21076	Economy	6300.00
0005432329010	21076	Economy	6300.00
0005432329044	21076	Economy	6300.00
0005432383338	21076	Economy	6300.00
0005432328898	21076	Economy	6300.00
0005432383351	21076	Economy	6300.00
0005432383390	21076	Economy	6300.00
0005432328816	21076	Economy	6300.00
0005432383248	21076	Economy	6300.00
0005432383499	21076	Economy	6300.00
0005432383437	21076	Economy	6300.00
0005432383461	21076	Economy	6300.00
0005432383472	21076	Economy	6300.00
0005432383290	21076	Economy	6300.00
0005432383391	21076	Economy	6300.00
0005432329390	31246	Business	18900.00
0005432383719	31246	Business	18900.00
0005432383721	31246	Business	18900.00
0005432383710	31246	Business	18900.00
0005432383745	31246	Business	18900.00
0005432329352	31246	Business	18900.00
0005432329376	31246	Business	18900.00
0005432329355	31246	Business	18900.00
0005432329388	31246	Business	18900.00
0005432383715	31246	Business	18900.00
0005432329360	31246	Business	18900.00
0005432383742	31246	Business	18900.00
0005432383728	31246	Economy	6300.00
0005432383713	31246	Economy	6300.00
0005432329386	31246	Economy	6300.00
0005432848840	31246	Economy	6300.00
0005432383749	31246	Economy	6300.00
0005432329353	31246	Economy	6300.00
0005432329358	31246	Economy	6300.00
0005432329361	31246	Economy	6300.00
0005432383735	31246	Economy	6300.00
0005432329378	31246	Economy	6300.00
0005432329350	31246	Economy	6900.00
0005432383709	31246	Economy	6900.00
0005432383747	31246	Economy	6900.00
0005432287262	31246	Economy	6900.00
0005432329380	31246	Economy	6900.00
0005432329347	31246	Economy	6300.00
0005432329362	31246	Economy	6300.00
0005432329359	31246	Economy	6300.00
0005432329382	31246	Economy	6300.00
0005432329367	31246	Economy	6300.00
0005432329372	31246	Economy	6300.00
0005432329370	31246	Economy	6300.00
0005432383727	31246	Economy	6300.00
0005432329365	31246	Economy	6300.00
0005432383746	31246	Economy	6300.00
0005432383730	31246	Economy	6300.00
0005432383725	31246	Economy	6300.00
0005432383724	31246	Economy	6300.00
0005432329351	31246	Economy	6300.00
0005432329348	31246	Economy	6300.00
0005432329356	31246	Economy	6300.00
0005432329391	31246	Economy	6300.00
0005432383731	31246	Economy	6300.00
0005432383729	31246	Economy	6300.00
0005432329363	31246	Economy	6300.00
0005432329385	31246	Economy	6300.00
0005432329379	31246	Economy	6300.00
0005432329381	31246	Economy	6300.00
0005432329377	31246	Economy	6300.00
0005432383740	31246	Economy	6300.00
0005432383716	31246	Economy	6300.00
0005432383718	31246	Economy	6300.00
0005432383736	31246	Economy	6300.00
0005432329357	31246	Economy	6300.00
0005432329384	31246	Economy	6300.00
0005432383748	31246	Economy	6300.00
0005432383712	31246	Economy	6300.00
0005432329387	31246	Economy	6300.00
0005432383738	31246	Economy	6300.00
0005432383722	31246	Economy	6300.00
0005432287264	31246	Economy	6300.00
0005432329366	31246	Economy	6300.00
0005432329373	31246	Economy	6300.00
0005432329364	31246	Economy	6300.00
0005432383723	31246	Economy	6300.00
0005432383720	31246	Economy	6300.00
0005432287263	31246	Economy	6300.00
0005432383717	31246	Economy	6300.00
0005432329369	31246	Economy	6300.00
0005432329393	31246	Economy	6300.00
0005432383739	31246	Economy	6300.00
0005432383714	31246	Economy	6300.00
0005432287261	31246	Economy	6300.00
0005432329368	31246	Economy	6300.00
0005432329389	31246	Economy	6300.00
0005432383733	31246	Economy	6300.00
0005432383741	31246	Economy	6300.00
0005432383732	31246	Economy	6300.00
0005432329371	31246	Economy	6300.00
0005432329349	31246	Economy	6300.00
0005432329375	31246	Economy	6300.00
0005432287265	31246	Economy	6300.00
0005432383711	31246	Economy	6300.00
0005432329392	31246	Economy	6300.00
0005432329354	31246	Economy	6300.00
0005432383743	31246	Economy	6300.00
0005432383726	31246	Economy	6300.00
0005432383744	31246	Economy	6300.00
0005432329374	31246	Economy	6300.00
0005432329383	31246	Economy	6300.00
0005432383734	31246	Economy	6300.00
0005432383737	31246	Economy	6300.00
0005432954013	2467	Business	89600.00
0005433642561	2467	Business	89600.00
0005433642565	2467	Business	89600.00
0005432953996	2467	Business	89600.00
0005433642579	2467	Business	89600.00
0005433642570	2467	Business	89600.00
0005433642556	2467	Business	89600.00
0005432954008	2467	Economy	29900.00
0005433642576	2467	Economy	29900.00
0005432954023	2467	Economy	29900.00
0005433642560	2467	Economy	29900.00
0005432953977	2467	Economy	29900.00
0005433642577	2467	Economy	32800.00
0005433642562	2467	Economy	32800.00
0005432953992	2467	Economy	32800.00
0005432953971	2467	Economy	32800.00
0005433642568	2467	Economy	29900.00
0005432953979	2467	Economy	29900.00
0005432953956	2467	Economy	29900.00
0005432953998	2467	Economy	29900.00
0005432953978	2467	Economy	29900.00
0005432954002	2467	Economy	29900.00
0005432954001	2467	Economy	29900.00
0005433642557	2467	Economy	29900.00
0005433642580	2467	Economy	29900.00
0005433642573	2467	Economy	29900.00
0005433642559	2467	Economy	29900.00
0005433642575	2467	Economy	29900.00
0005433642550	2467	Economy	29900.00
0005432953997	2467	Economy	29900.00
0005433642567	2467	Economy	29900.00
0005433642553	2467	Economy	29900.00
0005432954019	2467	Economy	29900.00
0005433642571	2467	Economy	29900.00
0005433642569	2467	Economy	29900.00
0005433642563	2467	Economy	29900.00
0005433642578	2467	Economy	29900.00
0005432953970	2467	Economy	29900.00
0005432954014	2467	Economy	29900.00
0005432953988	2467	Economy	29900.00
0005433642558	2467	Economy	29900.00
0005433642552	2467	Economy	29900.00
0005433642554	2467	Economy	29900.00
0005433642551	2467	Economy	29900.00
0005432953973	2467	Economy	29900.00
0005432954028	2467	Economy	29900.00
0005433642564	2467	Economy	29900.00
0005433642566	2467	Economy	29900.00
0005433642574	2467	Economy	29900.00
0005433642572	2467	Economy	29900.00
0005433642555	2467	Economy	29900.00
0005432954056	27595	Business	89600.00
0005432954059	27595	Business	89600.00
0005433642349	27595	Business	89600.00
0005433642457	27595	Business	89600.00
0005433642415	27595	Business	89600.00
0005433642350	27595	Business	89600.00
0005433642413	27595	Business	89600.00
0005433642473	27595	Business	89600.00
0005433642431	27595	Economy	29900.00
0005433642427	27595	Economy	29900.00
0005432954063	27595	Economy	29900.00
0005433642381	27595	Economy	29900.00
0005433642490	27595	Economy	32800.00
0005433642429	27595	Economy	32800.00
0005432954069	27595	Economy	29900.00
0005433642438	27595	Economy	29900.00
0005433642463	27595	Economy	29900.00
0005433642356	27595	Economy	29900.00
0005433642386	27595	Economy	29900.00
0005433642489	27595	Economy	29900.00
0005432954070	27595	Economy	29900.00
0005433642399	27595	Economy	29900.00
0005433642404	27595	Economy	29900.00
0005432954064	27595	Economy	29900.00
0005433642428	27595	Economy	29900.00
0005433642422	27595	Economy	29900.00
0005433642501	27595	Economy	29900.00
0005433642453	27595	Economy	29900.00
0005433642502	27595	Economy	29900.00
0005432954058	27595	Economy	29900.00
0005432954072	27595	Economy	29900.00
0005432954057	27595	Economy	29900.00
0005433642506	27595	Economy	29900.00
0005433642458	27595	Economy	29900.00
0005433642462	27595	Economy	29900.00
0005432954068	27595	Economy	29900.00
0005433642472	27595	Economy	29900.00
0005433642355	27595	Economy	29900.00
0005432954071	27595	Economy	29900.00
0005432954066	27595	Economy	29900.00
0005433642507	27595	Economy	29900.00
0005433642340	27595	Economy	29900.00
0005433642405	27595	Economy	29900.00
0005433642387	27595	Economy	29900.00
0005433642451	27595	Economy	29900.00
0005432954067	27595	Economy	29900.00
0005432954062	27595	Economy	29900.00
0005433642358	27595	Economy	29900.00
0005433642450	27595	Economy	29900.00
0005432954055	27595	Economy	29900.00
0005433642440	27595	Economy	29900.00
0005433642357	27595	Economy	29900.00
0005433642439	27595	Economy	29900.00
0005432954060	27595	Economy	29900.00
0005433642373	27595	Economy	29900.00
0005433642374	27595	Economy	29900.00
0005433642417	27595	Economy	29900.00
0005432954061	27595	Economy	29900.00
0005432954065	27595	Economy	29900.00
0005433642426	27595	Economy	29900.00
0005433642412	27595	Economy	29900.00
0005432425129	13300	Business	12700.00
0005432425160	13300	Business	12700.00
0005432425171	13300	Business	12700.00
0005432425183	13300	Business	12700.00
0005432425124	13300	Business	12700.00
0005432425150	13300	Business	12700.00
0005432425167	13300	Business	12700.00
0005432425148	13300	Business	12700.00
0005432425132	13300	Economy	4200.00
0005432425166	13300	Economy	4200.00
0005432425159	13300	Economy	4200.00
0005432425182	13300	Economy	4200.00
0005432425149	13300	Economy	4200.00
0005432425176	13300	Economy	4200.00
0005432425164	13300	Economy	4200.00
0005432425163	13300	Economy	4200.00
0005432425127	13300	Economy	4700.00
0005432425141	13300	Economy	4700.00
0005432425181	13300	Economy	4700.00
0005432425125	13300	Economy	4200.00
0005432425145	13300	Economy	4200.00
0005432425173	13300	Economy	4200.00
0005432425140	13300	Economy	4200.00
0005432425153	13300	Economy	4200.00
0005432425170	13300	Economy	4200.00
0005432425180	13300	Economy	4200.00
0005432425131	13300	Economy	4200.00
0005432425184	13300	Economy	4200.00
0005432425139	13300	Economy	4200.00
0005432425157	13300	Economy	4200.00
0005432425138	13300	Economy	4200.00
0005432425144	13300	Economy	4200.00
0005432425152	13300	Economy	4200.00
0005432425156	13300	Economy	4200.00
0005432425130	13300	Economy	4200.00
0005432425136	13300	Economy	4200.00
0005432425135	13300	Economy	4200.00
0005432425177	13300	Economy	4200.00
0005432425178	13300	Economy	4200.00
0005432425175	13300	Economy	4200.00
0005432425151	13300	Economy	4200.00
0005432425137	13300	Economy	4200.00
0005432425126	13300	Economy	4200.00
0005432425165	13300	Economy	4200.00
0005432425128	13300	Economy	4200.00
0005432425155	13300	Economy	4200.00
0005432425162	13300	Economy	4200.00
0005432425168	13300	Economy	4200.00
0005432425154	13300	Economy	4200.00
0005432425133	13300	Economy	4200.00
0005432425169	13300	Economy	4200.00
0005432425147	13300	Economy	4200.00
0005432425174	13300	Economy	4200.00
0005432425142	13300	Economy	4200.00
0005432425158	13300	Economy	4200.00
0005432425161	13300	Economy	4200.00
0005432425172	13300	Economy	4200.00
0005432425179	13300	Economy	4200.00
0005432425146	13300	Economy	4200.00
0005432425143	13300	Economy	4200.00
0005432425134	13300	Economy	4200.00
0005432424699	30733	Business	12700.00
0005432424773	30733	Business	12700.00
0005432424678	30733	Business	12700.00
0005432424652	30733	Business	12700.00
0005432424604	30733	Business	12700.00
0005432424659	30733	Business	12700.00
0005432424660	30733	Economy	4200.00
0005432424752	30733	Economy	4200.00
0005432424682	30733	Economy	4200.00
0005432424572	30733	Economy	4700.00
0005432424671	30733	Economy	4200.00
0005432424624	30733	Economy	4200.00
0005432424774	30733	Economy	4200.00
0005432424680	30733	Economy	4200.00
0005432424592	30733	Economy	4200.00
0005432424717	30733	Economy	4200.00
0005432424667	30733	Economy	4200.00
0005432424550	30733	Economy	4200.00
0005432424586	30733	Economy	4200.00
0005432424766	30733	Economy	4200.00
0005432424612	30733	Economy	4200.00
0005432424775	30733	Economy	4200.00
0005432424571	30733	Economy	4200.00
0005432424651	30733	Economy	4200.00
0005432424487	30733	Economy	4200.00
0005432424447	30733	Economy	4200.00
0005432424739	30733	Economy	4200.00
0005432424751	30733	Economy	4200.00
0005432424767	30733	Economy	4200.00
0005432424611	30733	Economy	4200.00
0005432424585	30733	Economy	4200.00
0005432424709	30733	Economy	4200.00
0005432424675	30733	Economy	4200.00
0005432424613	30733	Economy	4200.00
0005432424694	30733	Economy	4200.00
0005432424741	30733	Economy	4200.00
0005432424755	30733	Economy	4200.00
0005432424625	30733	Economy	4200.00
0005432424724	30733	Economy	4200.00
0005432424700	30733	Economy	4200.00
0005432424695	30733	Economy	4200.00
0005432424653	30733	Economy	4200.00
0005432424738	30733	Economy	4200.00
0005432424728	30733	Economy	4200.00
0005434157516	9608	Business	32600.00
0005434157535	9608	Business	32600.00
0005434157555	9608	Business	32600.00
0005432822319	9608	Business	32600.00
0005432817936	9608	Business	32600.00
0005432901673	9608	Business	32600.00
0005432901729	9608	Business	32600.00
0005432817932	9608	Business	32600.00
0005432817935	9608	Business	32600.00
0005432817915	9608	Business	32600.00
0005432817929	9608	Business	32600.00
0005434157495	9608	Business	32600.00
0005434186216	9608	Economy	10900.00
0005432901693	9608	Economy	10900.00
0005432901754	9608	Economy	10900.00
0005432817922	9608	Economy	10900.00
0005432822326	9608	Economy	10900.00
0005432817927	9608	Economy	10900.00
0005432817937	9608	Economy	10900.00
0005432901745	9608	Economy	11900.00
0005432817910	9608	Economy	11900.00
0005432817917	9608	Economy	11900.00
0005432817921	9608	Economy	11900.00
0005432817916	9608	Economy	10900.00
0005432901788	9608	Economy	10900.00
0005434157539	9608	Economy	10900.00
0005434448370	9608	Economy	10900.00
0005432289035	9608	Economy	10900.00
0005432901727	9608	Economy	10900.00
0005432901778	9608	Economy	10900.00
0005432901734	9608	Economy	10900.00
0005432817919	9608	Economy	10900.00
0005432817934	9608	Economy	10900.00
0005432289038	9608	Economy	10900.00
0005434157517	9608	Economy	10900.00
0005432822324	9608	Economy	10900.00
0005432901730	9608	Economy	10900.00
0005432822322	9608	Economy	10900.00
0005432822318	9608	Economy	10900.00
0005432817939	9608	Economy	10900.00
0005432817913	9608	Economy	10900.00
0005432822325	9608	Economy	10900.00
0005434157514	9608	Economy	10900.00
0005432817924	9608	Economy	10900.00
0005434157561	9608	Economy	10900.00
0005434448369	9608	Economy	10900.00
0005432817928	9608	Economy	10900.00
0005432817925	9608	Economy	10900.00
0005432901700	9608	Economy	10900.00
0005432289037	9608	Economy	10900.00
0005432817914	9608	Economy	10900.00
0005434157534	9608	Economy	10900.00
0005432822321	9608	Economy	10900.00
0005434157554	9608	Economy	10900.00
0005432901674	9608	Economy	10900.00
0005432817931	9608	Economy	10900.00
0005432817920	9608	Economy	10900.00
0005432817926	9608	Economy	10900.00
0005432822320	9608	Economy	10900.00
0005432901629	9608	Economy	10900.00
0005432901767	9608	Economy	10900.00
0005434157496	9608	Economy	10900.00
0005434157515	9608	Economy	10900.00
0005434157557	9608	Economy	10900.00
0005432901741	9608	Economy	10900.00
0005432817923	9608	Economy	10900.00
0005432817912	9608	Economy	10900.00
0005434448368	9608	Economy	10900.00
0005432817930	9608	Economy	10900.00
0005432817911	9608	Economy	10900.00
0005432822323	9608	Economy	10900.00
0005432817933	9608	Economy	10900.00
0005432817938	9608	Economy	10900.00
0005432289036	9608	Economy	10900.00
0005432817918	9608	Economy	10900.00
0005432822269	28957	Business	32600.00
0005432817646	28957	Business	32600.00
0005432817730	28957	Business	32600.00
0005432822239	28957	Business	32600.00
0005432817735	28957	Business	32600.00
0005432817729	28957	Business	32600.00
0005434186240	28957	Business	32600.00
0005432822262	28957	Business	32600.00
0005432822222	28957	Economy	10900.00
0005432901886	28957	Economy	10900.00
0005434186241	28957	Economy	10900.00
0005432901873	28957	Economy	10900.00
0005432002108	28957	Economy	10900.00
0005432901870	28957	Economy	10900.00
0005432822253	28957	Economy	10900.00
0005432901880	28957	Economy	11900.00
0005432901877	28957	Economy	11900.00
0005432822261	28957	Economy	11900.00
0005434157600	28957	Economy	10900.00
0005432822241	28957	Economy	10900.00
0005432817742	28957	Economy	10900.00
0005432817785	28957	Economy	10900.00
0005432822255	28957	Economy	10900.00
0005432817564	28957	Economy	10900.00
0005432901872	28957	Economy	10900.00
0005432901879	28957	Economy	10900.00
0005432822259	28957	Economy	10900.00
0005432817703	28957	Economy	10900.00
0005432817578	28957	Economy	10900.00
0005432822277	28957	Economy	10900.00
0005432817696	28957	Economy	10900.00
0005432817685	28957	Economy	10900.00
0005432817652	28957	Economy	10900.00
0005432901881	28957	Economy	10900.00
0005432817629	28957	Economy	10900.00
0005432822264	28957	Economy	10900.00
0005432901875	28957	Economy	10900.00
0005434157598	28957	Economy	10900.00
0005434186242	28957	Economy	10900.00
0005434157599	28957	Economy	10900.00
0005432901869	28957	Economy	10900.00
0005432901883	28957	Economy	10900.00
0005432901887	28957	Economy	10900.00
0005432817734	28957	Economy	10900.00
0005432822258	28957	Economy	10900.00
0005432901884	28957	Economy	10900.00
0005432817684	28957	Economy	10900.00
0005432817583	28957	Economy	10900.00
0005432822240	28957	Economy	10900.00
0005432817632	28957	Economy	10900.00
0005432822243	28957	Economy	10900.00
0005432817626	28957	Economy	10900.00
0005432817630	28957	Economy	10900.00
0005432901885	28957	Economy	10900.00
0005432901882	28957	Economy	10900.00
0005432901871	28957	Economy	10900.00
0005432822242	28957	Economy	10900.00
0005434157601	28957	Economy	10900.00
0005432817697	28957	Economy	10900.00
0005432817645	28957	Economy	10900.00
0005432901876	28957	Economy	10900.00
0005432817728	28957	Economy	10900.00
0005434157602	28957	Economy	10900.00
0005432817741	28957	Economy	10900.00
0005432901878	28957	Economy	10900.00
0005432817640	28957	Economy	10900.00
0005432817633	28957	Economy	10900.00
0005432817651	28957	Economy	10900.00
0005432822252	28957	Economy	10900.00
0005432817676	28957	Economy	10900.00
0005432901874	28957	Economy	10900.00
0005432822276	28957	Economy	10900.00
0005432822221	28957	Economy	10900.00
0005432822263	28957	Economy	10900.00
0005432002109	28957	Economy	10900.00
0005432817707	28957	Economy	10900.00
0005432613924	15151	Economy	11000.00
0005432613926	15151	Economy	11000.00
0005432613925	15151	Economy	11000.00
0005432611767	15151	Economy	11000.00
0005432611769	15151	Economy	11000.00
0005432613923	15151	Economy	11000.00
0005432611768	15151	Economy	11000.00
0005435842338	31567	Economy	11000.00
0005435842337	31567	Economy	11000.00
0005432607566	31567	Economy	11000.00
0005435841834	31567	Economy	11000.00
0005432611734	31567	Economy	11000.00
0005432611745	31567	Economy	11000.00
0005432611732	31567	Economy	11000.00
0005432607587	31567	Economy	11000.00
0005432611735	31567	Economy	11000.00
0005432611736	31567	Economy	11000.00
0005432611728	31567	Economy	11000.00
0005435841833	31567	Economy	11000.00
0005432948737	11883	Business	105900.00
0005433569919	11883	Business	105900.00
0005433569952	11883	Business	105900.00
0005432948920	11883	Business	105900.00
0005433569920	11883	Business	105900.00
0005433569937	11883	Business	105900.00
0005432948651	11883	Business	105900.00
0005433569940	11883	Business	105900.00
0005433569957	11883	Business	105900.00
0005433569922	11883	Business	105900.00
0005433569908	11883	Business	105900.00
0005433569935	11883	Business	105900.00
0005432948713	11883	Business	105900.00
0005432948714	11883	Business	105900.00
0005433569927	11883	Business	105900.00
0005433569944	11883	Business	105900.00
0005433569914	11883	Business	105900.00
0005433569962	11883	Business	105900.00
0005433569909	11883	Business	105900.00
0005433569951	11883	Economy	35300.00
0005433569945	11883	Economy	35300.00
0005433569931	11883	Economy	35300.00
0005433569960	11883	Economy	35300.00
0005433569961	11883	Economy	35300.00
0005433569932	11883	Economy	35300.00
0005432948733	11883	Economy	35300.00
0005433569917	11883	Economy	35300.00
0005432948802	11883	Economy	35300.00
0005433569970	11883	Economy	38800.00
0005432948624	11883	Economy	38800.00
0005433569946	11883	Economy	38800.00
0005433569925	11883	Economy	38800.00
0005432948634	11883	Economy	35300.00
0005432948600	11883	Economy	35300.00
0005433569950	11883	Economy	35300.00
0005433569963	11883	Economy	35300.00
0005433569968	11883	Economy	35300.00
0005432948613	11883	Economy	35300.00
0005433569966	11883	Economy	35300.00
0005433569930	11883	Economy	35300.00
0005432948633	11883	Economy	35300.00
0005433569921	11883	Economy	35300.00
0005433569934	11883	Economy	35300.00
0005433569929	11883	Economy	35300.00
0005432948601	11883	Economy	35300.00
0005433569954	11883	Economy	35300.00
0005433569924	11883	Economy	35300.00
0005433569969	11883	Economy	35300.00
0005433569967	11883	Economy	35300.00
0005433569959	11883	Economy	35300.00
0005433569956	11883	Economy	35300.00
0005433569912	11883	Economy	35300.00
0005433569916	11883	Economy	35300.00
0005433569943	11883	Economy	35300.00
0005433569938	11883	Economy	35300.00
0005433569926	11883	Economy	35300.00
0005433569947	11883	Economy	35300.00
0005432948540	11883	Economy	35300.00
0005433569913	11883	Economy	35300.00
0005432948532	11883	Economy	35300.00
0005432948585	11883	Economy	35300.00
0005433569953	11883	Economy	35300.00
0005433569928	11883	Economy	35300.00
0005432948539	11883	Economy	35300.00
0005432948810	11883	Economy	35300.00
0005432948650	11883	Economy	35300.00
0005432948747	11883	Economy	35300.00
0005432948712	11883	Economy	35300.00
0005433569939	11883	Economy	35300.00
0005433569918	11883	Economy	35300.00
0005432948710	11883	Economy	35300.00
0005433569955	11883	Economy	35300.00
0005433569910	11883	Economy	35300.00
0005433569949	11883	Economy	35300.00
0005433569941	11883	Economy	35300.00
0005433569958	11883	Economy	35300.00
0005432948602	11883	Economy	35300.00
0005432948592	11883	Economy	35300.00
0005433569923	11883	Economy	35300.00
0005433569964	11883	Economy	35300.00
0005432948803	11883	Economy	35300.00
0005433569942	11883	Economy	35300.00
0005433569933	11883	Economy	35300.00
0005433569965	11883	Economy	35300.00
0005433569948	11883	Economy	35300.00
0005433569915	11883	Economy	35300.00
0005432948808	11883	Economy	35300.00
0005433569936	11883	Economy	35300.00
0005432948736	11883	Economy	35300.00
0005433569911	11883	Economy	35300.00
0005433569487	25268	Business	105900.00
0005432949108	25268	Business	105900.00
0005432949132	25268	Business	105900.00
0005432949138	25268	Business	105900.00
0005432949116	25268	Business	105900.00
0005433569596	25268	Business	105900.00
0005432949127	25268	Business	105900.00
0005432949118	25268	Business	105900.00
0005433569398	25268	Business	105900.00
0005433569418	25268	Business	105900.00
0005432949102	25268	Business	105900.00
0005432949112	25268	Business	105900.00
0005433569409	25268	Business	105900.00
0005433569270	25268	Business	105900.00
0005433569330	25268	Business	105900.00
0005433569308	25268	Economy	35300.00
0005433569594	25268	Economy	35300.00
0005432949098	25268	Economy	35300.00
0005432949126	25268	Economy	35300.00
0005433569386	25268	Economy	35300.00
0005433569428	25268	Economy	35300.00
0005433569326	25268	Economy	35300.00
0005432949135	25268	Economy	35300.00
0005433569512	25268	Economy	35300.00
0005433569390	25268	Economy	35300.00
0005433569422	25268	Economy	35300.00
0005432949122	25268	Economy	35300.00
0005433569595	25268	Economy	38800.00
0005433569294	25268	Economy	38800.00
0005433569413	25268	Economy	38800.00
0005433569455	25268	Economy	35300.00
0005433569389	25268	Economy	35300.00
0005433569309	25268	Economy	35300.00
0005433569507	25268	Economy	35300.00
0005433569317	25268	Economy	35300.00
0005433569514	25268	Economy	35300.00
0005432949114	25268	Economy	35300.00
0005432949139	25268	Economy	35300.00
0005432949099	25268	Economy	35300.00
0005432949137	25268	Economy	35300.00
0005432949109	25268	Economy	35300.00
0005433569293	25268	Economy	35300.00
0005432949128	25268	Economy	35300.00
0005432949131	25268	Economy	35300.00
0005433569185	25268	Economy	35300.00
0005432949105	25268	Economy	35300.00
0005433569508	25268	Economy	35300.00
0005433569331	25268	Economy	35300.00
0005432949119	25268	Economy	35300.00
0005433569329	25268	Economy	35300.00
0005433569556	25268	Economy	35300.00
0005432949130	25268	Economy	35300.00
0005432949113	25268	Economy	35300.00
0005432949117	25268	Economy	35300.00
0005432949129	25268	Economy	35300.00
0005433569292	25268	Economy	35300.00
0005432949120	25268	Economy	35300.00
0005432949115	25268	Economy	35300.00
0005432949136	25268	Economy	35300.00
0005432949107	25268	Economy	35300.00
0005433569303	25268	Economy	35300.00
0005433569318	25268	Economy	35300.00
0005433569420	25268	Economy	35300.00
0005433569537	25268	Economy	35300.00
0005432949110	25268	Economy	35300.00
0005432949100	25268	Economy	35300.00
0005433569128	25268	Economy	35300.00
0005433569367	25268	Economy	35300.00
0005433569593	25268	Economy	35300.00
0005432949134	25268	Economy	35300.00
0005433569429	25268	Economy	35300.00
0005433569230	25268	Economy	35300.00
0005433569316	25268	Economy	35300.00
0005433569299	25268	Economy	35300.00
0005433569217	25268	Economy	35300.00
0005433569271	25268	Economy	35300.00
0005433569368	25268	Economy	35300.00
0005432949124	25268	Economy	35300.00
0005433569184	25268	Economy	35300.00
0005432949101	25268	Economy	35300.00
0005432949104	25268	Economy	35300.00
0005432949133	25268	Economy	35300.00
0005433569509	25268	Economy	35300.00
0005433569527	25268	Economy	35300.00
0005432949106	25268	Economy	35300.00
0005433569412	25268	Economy	35300.00
0005432949103	25268	Economy	35300.00
0005432949121	25268	Economy	35300.00
0005432949125	25268	Economy	35300.00
0005433569486	25268	Economy	35300.00
0005433569473	25268	Economy	35300.00
0005432949111	25268	Economy	35300.00
0005433569528	25268	Economy	35300.00
0005433569419	25268	Economy	35300.00
0005432949123	25268	Economy	35300.00
0005433569304	25268	Economy	35300.00
0005433569456	25268	Economy	35300.00
0005433808399	14462	Business	117400.00
0005432430917	14462	Business	117400.00
0005433808396	14462	Business	117400.00
0005433808394	14462	Business	117400.00
0005432430915	14462	Economy	39100.00
0005434026732	14462	Economy	39100.00
0005433808357	14462	Economy	39100.00
0005433812899	14462	Economy	43000.00
0005432430909	14462	Economy	43000.00
0005434026730	14462	Economy	39100.00
0005434026734	14462	Economy	39100.00
0005433808381	14462	Economy	39100.00
0005433812900	14462	Economy	39100.00
0005433808392	14462	Economy	39100.00
0005433812913	14462	Economy	39100.00
0005432430910	14462	Economy	39100.00
0005433808379	14462	Economy	39100.00
0005432430913	14462	Economy	39100.00
0005432430912	14462	Economy	39100.00
0005432430918	14462	Economy	39100.00
0005432430911	14462	Economy	39100.00
0005433812904	14462	Economy	39100.00
0005433812910	14462	Economy	39100.00
0005433808380	14462	Economy	39100.00
0005433808386	14462	Economy	39100.00
0005434026736	14462	Economy	39100.00
0005433808383	14462	Economy	39100.00
0005432430921	14462	Economy	39100.00
0005432430919	14462	Economy	39100.00
0005434026731	14462	Economy	39100.00
0005433812903	14462	Economy	39100.00
0005434026735	14462	Economy	39100.00
0005432430914	14462	Economy	39100.00
0005432430920	14462	Economy	39100.00
0005433808384	14462	Economy	39100.00
0005433812901	14462	Economy	39100.00
0005432430922	14462	Economy	39100.00
0005433808400	14462	Economy	39100.00
0005433812906	14462	Economy	39100.00
0005434026733	14462	Economy	39100.00
0005432430924	14462	Economy	39100.00
0005433808401	14462	Economy	39100.00
0005432430923	14462	Economy	39100.00
0005433812902	14462	Economy	39100.00
0005433808385	14462	Economy	39100.00
0005434026729	14462	Economy	39100.00
0005433808387	14462	Economy	39100.00
0005432430916	14462	Economy	39100.00
0005434655124	5395	Business	67200.00
0005434655141	5395	Business	67200.00
0005434656587	5395	Business	67200.00
0005435340374	5395	Business	67200.00
0005434655133	5395	Business	67200.00
0005435340347	5395	Business	67200.00
0005435340434	5395	Economy	22400.00
0005434655127	5395	Economy	22400.00
0005434655128	5395	Economy	22400.00
0005434655130	5395	Economy	22400.00
0005434655117	5395	Economy	22400.00
0005434655145	5395	Economy	24600.00
0005432114253	5395	Economy	24600.00
0005435340346	5395	Economy	24600.00
0005434655142	5395	Economy	24600.00
0005434655123	5395	Economy	22400.00
0005434655118	5395	Economy	22400.00
0005432114254	5395	Economy	22400.00
0005435340391	5395	Economy	22400.00
0005435340406	5395	Economy	22400.00
0005434655120	5395	Economy	22400.00
0005434655132	5395	Economy	22400.00
0005434655121	5395	Economy	22400.00
0005434655129	5395	Economy	22400.00
0005435340453	5395	Economy	22400.00
0005435340390	5395	Economy	22400.00
0005434655135	5395	Economy	22400.00
0005434655136	5395	Economy	22400.00
0005434655143	5395	Economy	22400.00
0005434655125	5395	Economy	22400.00
0005435340398	5395	Economy	22400.00
0005434655144	5395	Economy	22400.00
0005434655122	5395	Economy	22400.00
0005435340340	5395	Economy	22400.00
0005434655137	5395	Economy	22400.00
0005434655119	5395	Economy	22400.00
0005435340407	5395	Economy	22400.00
0005434655138	5395	Economy	22400.00
0005432114252	5395	Economy	22400.00
0005432114251	5395	Economy	22400.00
0005434655134	5395	Economy	22400.00
0005434655131	5395	Economy	22400.00
0005434655126	5395	Economy	22400.00
0005434655116	5395	Economy	22400.00
0005435340307	5395	Economy	22400.00
0005435340383	5395	Economy	22400.00
0005435340386	5395	Economy	22400.00
0005434655139	5395	Economy	22400.00
0005434655140	5395	Economy	22400.00
0005435340306	5395	Economy	22400.00
0005435555388	5395	Economy	22400.00
0005434654942	12512	Business	67200.00
0005435340492	12512	Business	67200.00
0005434654754	12512	Business	67200.00
0005434654817	12512	Economy	22400.00
0005434654976	12512	Economy	22400.00
0005434654779	12512	Economy	22400.00
0005434654886	12512	Economy	22400.00
0005435340493	12512	Economy	22400.00
0005434654819	12512	Economy	22400.00
0005434656569	12512	Economy	24600.00
0005434654742	12512	Economy	24600.00
0005435340496	12512	Economy	22400.00
0005434654902	12512	Economy	22400.00
0005435555403	12512	Economy	22400.00
0005434654970	12512	Economy	22400.00
0005435340488	12512	Economy	22400.00
0005435340491	12512	Economy	22400.00
0005435340498	12512	Economy	22400.00
0005434654735	12512	Economy	22400.00
0005434654816	12512	Economy	22400.00
0005434654981	12512	Economy	22400.00
0005435340495	12512	Economy	22400.00
0005435340500	12512	Economy	22400.00
0005434654866	12512	Economy	22400.00
0005435340490	12512	Economy	22400.00
0005434654883	12512	Economy	22400.00
0005435340499	12512	Economy	22400.00
0005434654767	12512	Economy	22400.00
0005434656570	12512	Economy	22400.00
0005435340489	12512	Economy	22400.00
0005434654881	12512	Economy	22400.00
0005434654869	12512	Economy	22400.00
0005434654900	12512	Economy	22400.00
0005435340502	12512	Economy	22400.00
0005434654789	12512	Economy	22400.00
0005434655038	12512	Economy	22400.00
0005434654935	12512	Economy	22400.00
0005435340501	12512	Economy	22400.00
0005434654870	12512	Economy	22400.00
0005434654899	12512	Economy	22400.00
0005434654871	12512	Economy	22400.00
0005435340497	12512	Economy	22400.00
0005434654985	12512	Economy	22400.00
0005434654941	12512	Economy	22400.00
0005435340494	12512	Economy	22400.00
0005434654857	12512	Economy	22400.00
0005434654734	12512	Economy	22400.00
0005433716710	7415	Business	32000.00
0005432078193	7415	Business	32000.00
0005433690953	7415	Business	32000.00
0005433722316	7415	Business	32000.00
0005433716749	7415	Business	32000.00
0005433716738	7415	Business	32000.00
0005433716719	7415	Business	32000.00
0005433716722	7415	Business	32000.00
0005433716715	7415	Economy	10700.00
0005433716741	7415	Economy	10700.00
0005433716740	7415	Economy	10700.00
0005435266172	7415	Economy	10700.00
0005432428943	7415	Economy	10700.00
0005433722318	7415	Economy	10700.00
0005432078190	7415	Economy	10700.00
0005435266160	7415	Economy	10700.00
0005435266171	7415	Economy	10700.00
0005433716717	7415	Economy	10700.00
0005433716721	7415	Economy	10700.00
0005433716743	7415	Economy	10700.00
0005435266166	7415	Economy	10700.00
0005433716728	7415	Economy	10700.00
0005433716712	7415	Economy	10700.00
0005433719191	7415	Economy	10700.00
0005433716730	7415	Economy	10700.00
0005433690955	7415	Economy	10700.00
0005433716748	7415	Economy	10700.00
0005433716707	7415	Economy	10700.00
0005435266159	7415	Economy	10700.00
0005433716754	7415	Economy	10700.00
0005433716729	7415	Economy	10700.00
0005435266167	7415	Economy	10700.00
0005433716716	7415	Economy	10700.00
0005433688840	7415	Economy	10700.00
0005432428944	7415	Economy	10700.00
0005433716726	7415	Economy	10700.00
0005433716737	7415	Economy	10700.00
0005433716739	7415	Economy	10700.00
0005433716750	7415	Economy	10700.00
0005435266161	7415	Economy	11700.00
0005433716714	7415	Economy	11700.00
0005433722314	7415	Economy	11700.00
0005433716705	7415	Economy	10700.00
0005433716713	7415	Economy	10700.00
0005433689941	7415	Economy	10700.00
0005433722315	7415	Economy	10700.00
0005433716706	7415	Economy	10700.00
0005433716724	7415	Economy	10700.00
0005433719190	7415	Economy	10700.00
0005433656720	7415	Economy	10700.00
0005433716747	7415	Economy	10700.00
0005435266146	7415	Economy	10700.00
0005435266164	7415	Economy	10700.00
0005433716736	7415	Economy	10700.00
0005433716742	7415	Economy	10700.00
0005433716745	7415	Economy	10700.00
0005433688841	7415	Economy	10700.00
0005432078191	7415	Economy	10700.00
0005433716708	7415	Economy	10700.00
0005433716751	7415	Economy	10700.00
0005433716718	7415	Economy	10700.00
0005432078195	7415	Economy	10700.00
0005433656719	7415	Economy	10700.00
0005433716725	7415	Economy	10700.00
0005432078194	7415	Economy	10700.00
0005433716731	7415	Economy	10700.00
0005433716746	7415	Economy	10700.00
0005432078192	7415	Economy	10700.00
0005433722317	7415	Economy	10700.00
0005433656721	7415	Economy	10700.00
0005433716733	7415	Economy	10700.00
0005433716711	7415	Economy	10700.00
0005435266168	7415	Economy	10700.00
0005433716727	7415	Economy	10700.00
0005433716735	7415	Economy	10700.00
0005433716723	7415	Economy	10700.00
0005435266165	7415	Economy	10700.00
0005433716709	7415	Economy	10700.00
0005433716744	7415	Economy	10700.00
0005433719189	7415	Economy	10700.00
0005433716752	7415	Economy	10700.00
0005433688839	7415	Economy	10700.00
0005433690954	7415	Economy	10700.00
0005433716734	7415	Economy	10700.00
0005433716720	7415	Economy	10700.00
0005433716753	7415	Economy	10700.00
0005433716732	7415	Economy	10700.00
0005433689942	7415	Economy	10700.00
0005433716259	29198	Business	32000.00
0005433685534	29198	Business	32000.00
0005433716337	29198	Business	32000.00
0005433716548	29198	Business	32000.00
0005433716262	29198	Business	32000.00
0005433716329	29198	Business	32000.00
0005433716515	29198	Business	32000.00
0005433716257	29198	Economy	10700.00
0005432428980	29198	Economy	10700.00
0005433716232	29198	Economy	10700.00
0005433685535	29198	Economy	10700.00
0005433716430	29198	Economy	10700.00
0005433719165	29198	Economy	10700.00
0005433716438	29198	Economy	10700.00
0005435266209	29198	Economy	10700.00
0005433716109	29198	Economy	10700.00
0005433716229	29198	Economy	10700.00
0005433716298	29198	Economy	10700.00
0005433688820	29198	Economy	10700.00
0005433716325	29198	Economy	10700.00
0005433715935	29198	Economy	10700.00
0005433716516	29198	Economy	10700.00
0005433716344	29198	Economy	10700.00
0005433656703	29198	Economy	10700.00
0005433716429	29198	Economy	10700.00
0005435266210	29198	Economy	10700.00
0005433716094	29198	Economy	10700.00
0005433719164	29198	Economy	10700.00
0005433688821	29198	Economy	11700.00
0005433688823	29198	Economy	11700.00
0005433716446	29198	Economy	11700.00
0005433722248	29198	Economy	10700.00
0005433716258	29198	Economy	10700.00
0005433656680	29198	Economy	10700.00
0005433715958	29198	Economy	10700.00
0005433716266	29198	Economy	10700.00
0005433716244	29198	Economy	10700.00
0005433688819	29198	Economy	10700.00
0005433685526	29198	Economy	10700.00
0005433656677	29198	Economy	10700.00
0005433716239	29198	Economy	10700.00
0005432428981	29198	Economy	10700.00
0005433716243	29198	Economy	10700.00
0005433716326	29198	Economy	10700.00
0005433716496	29198	Economy	10700.00
0005435266208	29198	Economy	10700.00
0005433716313	29198	Economy	10700.00
0005433716395	29198	Economy	10700.00
0005433722260	29198	Economy	10700.00
0005433716330	29198	Economy	10700.00
0005432006807	29198	Economy	10700.00
0005433716335	29198	Economy	10700.00
0005433716336	29198	Economy	10700.00
0005433716441	29198	Economy	10700.00
0005433716547	29198	Economy	10700.00
0005433722269	29198	Economy	10700.00
0005433656681	29198	Economy	10700.00
0005432428982	29198	Economy	10700.00
0005433716331	29198	Economy	10700.00
0005433716300	29198	Economy	10700.00
0005433716263	29198	Economy	10700.00
0005432006806	29198	Economy	10700.00
0005433688822	29198	Economy	10700.00
0005433716440	29198	Economy	10700.00
0005433716220	29198	Economy	10700.00
0005433722247	29198	Economy	10700.00
0005433722259	29198	Economy	10700.00
0005433716233	29198	Economy	10700.00
0005433716036	29198	Economy	10700.00
0005433716285	29198	Economy	10700.00
0005434095497	8651	Business	36500.00
0005434095490	8651	Economy	12200.00
0005434095498	8651	Economy	13400.00
0005434182312	8651	Economy	12200.00
0005434182266	8651	Economy	12200.00
0005434095496	8651	Economy	12200.00
0005434182300	8651	Economy	12200.00
0005434095501	8651	Economy	12200.00
0005434095500	8651	Economy	12200.00
0005434182299	8651	Economy	12200.00
0005434095499	8651	Economy	12200.00
0005434095495	8651	Economy	12200.00
0005434182216	8651	Economy	12200.00
0005434095491	8651	Economy	12200.00
0005434095493	8651	Economy	12200.00
0005434095494	8651	Economy	12200.00
0005434095503	8651	Economy	12200.00
0005434182290	8651	Economy	12200.00
0005434095489	8651	Economy	12200.00
0005434182317	8651	Economy	12200.00
0005434182268	8651	Economy	12200.00
0005434095502	8651	Economy	12200.00
0005434095492	8651	Economy	12200.00
0005434095488	8651	Economy	12200.00
0005434182382	11648	Business	36500.00
0005434182377	11648	Business	36500.00
0005434095376	11648	Business	36500.00
0005434182380	11648	Business	36500.00
0005434182376	11648	Business	36500.00
0005434184694	11648	Business	36500.00
0005434095412	11648	Economy	12200.00
0005434095357	11648	Economy	12200.00
0005434326273	11648	Economy	12200.00
0005434182381	11648	Economy	12200.00
0005434095414	11648	Economy	13400.00
0005434095455	11648	Economy	13400.00
0005434095420	11648	Economy	13400.00
0005434183609	11648	Economy	13400.00
0005434182371	11648	Economy	12200.00
0005434182379	11648	Economy	12200.00
0005434182372	11648	Economy	12200.00
0005434143735	11648	Economy	12200.00
0005434095451	11648	Economy	12200.00
0005434095430	11648	Economy	12200.00
0005434095411	11648	Economy	12200.00
0005434095379	11648	Economy	12200.00
0005434184693	11648	Economy	12200.00
0005434182378	11648	Economy	12200.00
0005434183608	11648	Economy	12200.00
0005434182374	11648	Economy	12200.00
0005434095415	11648	Economy	12200.00
0005434095456	11648	Economy	12200.00
0005434184695	11648	Economy	12200.00
0005434095359	11648	Economy	12200.00
0005434095452	11648	Economy	12200.00
0005434095392	11648	Economy	12200.00
0005434095275	11648	Economy	12200.00
0005434182370	11648	Economy	12200.00
0005434095426	11648	Economy	12200.00
0005434326272	11648	Economy	12200.00
0005434182375	11648	Economy	12200.00
0005434182373	11648	Economy	12200.00
0005434095358	11648	Economy	12200.00
0005433398441	1470	Business	33000.00
0005432297318	1470	Business	33000.00
0005435732531	1470	Business	33000.00
0005435732526	1470	Business	33000.00
0005433398146	1470	Business	33000.00
0005433398398	1470	Business	33000.00
0005435732534	1470	Business	33000.00
0005435732525	1470	Business	33000.00
0005433397975	1470	Economy	11000.00
0005433398429	1470	Economy	11000.00
0005432906550	1470	Economy	11000.00
0005435732513	1470	Economy	11000.00
0005433457031	1470	Economy	11000.00
0005433398390	1470	Economy	11000.00
0005435732518	1470	Economy	11000.00
0005433398400	1470	Economy	12100.00
0005435732520	1470	Economy	12100.00
0005433398556	1470	Economy	12100.00
0005433457032	1470	Economy	12100.00
0005433398453	1470	Economy	11000.00
0005433398423	1470	Economy	11000.00
0005435732524	1470	Economy	11000.00
0005435732522	1470	Economy	11000.00
0005433398436	1470	Economy	11000.00
0005433457029	1470	Economy	11000.00
0005432297316	1470	Economy	11000.00
0005433398448	1470	Economy	11000.00
0005435732512	1470	Economy	11000.00
0005435732519	1470	Economy	11000.00
0005433398397	1470	Economy	11000.00
0005435732537	1470	Economy	11000.00
0005432906549	1470	Economy	11000.00
0005433398428	1470	Economy	11000.00
0005433457030	1470	Economy	11000.00
0005435732523	1470	Economy	11000.00
0005435732535	1470	Economy	11000.00
0005435732532	1470	Economy	11000.00
0005433398393	1470	Economy	11000.00
0005435732527	1470	Economy	11000.00
0005435732521	1470	Economy	11000.00
0005435732517	1470	Economy	11000.00
0005433398399	1470	Economy	11000.00
0005433398557	1470	Economy	11000.00
0005435732516	1470	Economy	11000.00
0005433398301	1470	Economy	11000.00
0005432906558	1470	Economy	11000.00
0005435732530	1470	Economy	11000.00
0005433398245	1470	Economy	11000.00
0005433398194	1470	Economy	11000.00
0005433398302	1470	Economy	11000.00
0005435732533	1470	Economy	11000.00
0005435732529	1470	Economy	11000.00
0005432906557	1470	Economy	11000.00
0005433398427	1470	Economy	11000.00
0005432297317	1470	Economy	11000.00
0005435732528	1470	Economy	11000.00
0005435732515	1470	Economy	11000.00
0005435732514	1470	Economy	11000.00
0005435732536	1470	Economy	11000.00
0005433398771	19287	Business	33000.00
0005435732349	19287	Business	33000.00
0005433398804	19287	Business	33000.00
0005433398789	19287	Business	33000.00
0005433398778	19287	Business	33000.00
0005433398783	19287	Business	33000.00
0005435732384	19287	Economy	11000.00
0005432906573	19287	Economy	11000.00
0005433398795	19287	Economy	11000.00
0005433398775	19287	Economy	11000.00
0005433398814	19287	Economy	11000.00
0005435732399	19287	Economy	11000.00
0005433398803	19287	Economy	11000.00
0005433398782	19287	Economy	11000.00
0005433398816	19287	Economy	11000.00
0005433456991	19287	Economy	12100.00
0005433398788	19287	Economy	12100.00
0005435732417	19287	Economy	12100.00
0005435732387	19287	Economy	12100.00
0005433398805	19287	Economy	11000.00
0005432906574	19287	Economy	11000.00
0005433398802	19287	Economy	11000.00
0005433456988	19287	Economy	11000.00
0005433398806	19287	Economy	11000.00
0005433398815	19287	Economy	11000.00
0005433398800	19287	Economy	11000.00
0005433398798	19287	Economy	11000.00
0005433398797	19287	Economy	11000.00
0005433398813	19287	Economy	11000.00
0005433398807	19287	Economy	11000.00
0005433398812	19287	Economy	11000.00
0005433398799	19287	Economy	11000.00
0005433398794	19287	Economy	11000.00
0005433398772	19287	Economy	11000.00
0005433398781	19287	Economy	11000.00
0005433398780	19287	Economy	11000.00
0005433398777	19287	Economy	11000.00
0005433456992	19287	Economy	11000.00
0005433457013	19287	Economy	11000.00
0005433398792	19287	Economy	11000.00
0005433398785	19287	Economy	11000.00
0005433398784	19287	Economy	11000.00
0005433398809	19287	Economy	11000.00
0005433398811	19287	Economy	11000.00
0005433398786	19287	Economy	11000.00
0005433398770	19287	Economy	11000.00
0005433457012	19287	Economy	11000.00
0005433398817	19287	Economy	11000.00
0005435732446	19287	Economy	11000.00
0005433398787	19287	Economy	11000.00
0005432906572	19287	Economy	11000.00
0005433398779	19287	Economy	11000.00
0005433398818	19287	Economy	11000.00
0005433398774	19287	Economy	11000.00
0005433398796	19287	Economy	11000.00
0005433398773	19287	Economy	11000.00
0005433456993	19287	Economy	11000.00
0005433398793	19287	Economy	11000.00
0005435732350	19287	Economy	11000.00
0005433398801	19287	Economy	11000.00
0005433398776	19287	Economy	11000.00
0005433398810	19287	Economy	11000.00
0005433398791	19287	Economy	11000.00
0005433398808	19287	Economy	11000.00
0005435732438	19287	Economy	11000.00
0005433398790	19287	Economy	11000.00
0005434443825	17359	Economy	15600.00
0005434443873	17359	Economy	15600.00
0005434443734	17359	Economy	14100.00
0005434443735	17359	Economy	14100.00
0005434443798	17359	Economy	14100.00
0005434443836	17359	Economy	14100.00
0005434443797	17359	Economy	14100.00
0005434443849	17359	Economy	14100.00
0005434443813	17359	Economy	14100.00
0005434443822	17359	Economy	14100.00
0005434443862	17359	Economy	14100.00
0005434443835	17359	Economy	14100.00
0005434443952	20578	Economy	15600.00
0005434443950	20578	Economy	14100.00
0005434443937	20578	Economy	14100.00
0005434443951	20578	Economy	14100.00
0005434443940	20578	Economy	14100.00
0005434443942	20578	Economy	14100.00
0005434443943	20578	Economy	14100.00
0005434443936	20578	Economy	14100.00
0005434443938	20578	Economy	14100.00
0005434443949	20578	Economy	14100.00
0005434443941	20578	Economy	14100.00
0005434443944	20578	Economy	14100.00
0005434443945	20578	Economy	14100.00
0005434443947	20578	Economy	14100.00
0005434443948	20578	Economy	14100.00
0005434443946	20578	Economy	14100.00
0005434443939	20578	Economy	14100.00
0005435377601	7283	Economy	5800.00
0005434954669	7283	Economy	5800.00
0005434954671	7283	Economy	5800.00
0005435377596	7283	Economy	5800.00
0005435377597	7283	Economy	5800.00
0005434954668	7283	Economy	5800.00
0005434954672	7283	Economy	5800.00
0005434954670	7283	Economy	5800.00
0005434954639	28320	Economy	5800.00
0005435377618	28320	Economy	5800.00
0005434954645	28320	Economy	5800.00
0005434954616	28320	Economy	5800.00
0005434954638	28320	Economy	5800.00
0005435377617	28320	Economy	5800.00
0005434954634	28320	Economy	5800.00
0005435377616	28320	Economy	5800.00
0005434351887	4506	Economy	14000.00
0005434351884	4506	Economy	14000.00
0005434351892	4506	Economy	14000.00
0005434351894	4506	Economy	14000.00
0005434351888	4506	Economy	14000.00
0005434351893	4506	Economy	14000.00
0005434351889	4506	Economy	14000.00
0005434351891	4506	Economy	14000.00
0005435893708	4506	Economy	14000.00
0005434351885	4506	Economy	14000.00
0005434351886	4506	Economy	14000.00
0005434351895	4506	Economy	14000.00
0005434183590	4506	Economy	14000.00
0005435893713	4506	Economy	14000.00
0005434351890	4506	Economy	14000.00
0005434351784	29670	Economy	15400.00
0005434351801	29670	Economy	15400.00
0005435893737	29670	Economy	14000.00
0005434351730	29670	Economy	14000.00
0005435893742	29670	Economy	14000.00
0005434351763	29670	Economy	14000.00
0005434351764	29670	Economy	14000.00
0005434351750	29670	Economy	14000.00
0005434351782	29670	Economy	14000.00
0005435893741	29670	Economy	14000.00
0005435893743	29670	Economy	14000.00
0005434351725	29670	Economy	14000.00
0005434351788	29670	Economy	14000.00
0005435893740	29670	Economy	14000.00
0005434351781	29670	Economy	14000.00
0005435893738	29670	Economy	14000.00
0005435893736	29670	Economy	14000.00
0005434351765	29670	Economy	14000.00
0005434351709	29670	Economy	14000.00
0005435893739	29670	Economy	14000.00
0005434351776	29670	Economy	14000.00
0005434351760	29670	Economy	14000.00
0005434351779	29670	Economy	14000.00
0005434351783	29670	Economy	14000.00
0005433343777	1058	Business	30600.00
0005433343737	1058	Business	30600.00
0005433344177	1058	Business	30600.00
0005433158141	1058	Business	30600.00
0005433343570	1058	Business	30600.00
0005433343738	1058	Business	30600.00
0005433343564	1058	Business	30600.00
0005433343924	1058	Business	30600.00
0005433269757	1058	Business	30600.00
0005433344087	1058	Business	30600.00
0005435092224	1058	Business	30600.00
0005433343747	1058	Business	30600.00
0005434446554	1058	Business	30600.00
0005433344117	1058	Business	30600.00
0005433343461	1058	Business	30600.00
0005433343586	1058	Business	30600.00
0005433269729	1058	Business	30600.00
0005433343272	1058	Business	30600.00
0005433343659	1058	Business	30600.00
0005433343667	1058	Business	30600.00
0005433343674	1058	Business	30600.00
0005433343628	1058	Economy	11200.00
0005433343669	1058	Economy	11200.00
0005433343445	1058	Economy	10200.00
0005433343403	1058	Economy	10200.00
0005433344165	1058	Economy	10200.00
0005433344116	1058	Economy	10200.00
0005433343297	1058	Economy	10200.00
0005433343901	1058	Economy	10200.00
0005433269728	1058	Economy	10200.00
0005433343778	1058	Economy	10200.00
0005435092230	1058	Economy	10200.00
0005433343535	1058	Economy	10200.00
0005435092227	1058	Economy	10200.00
0005433344109	1058	Economy	10200.00
0005433463933	1058	Economy	10200.00
0005433343379	1058	Economy	10200.00
0005433159334	1058	Economy	10200.00
0005433343841	1058	Economy	10200.00
0005433344107	1058	Economy	10200.00
0005433463934	1058	Economy	10200.00
0005433344089	1058	Economy	10200.00
0005433343576	1058	Economy	10200.00
0005433343480	1058	Economy	10200.00
0005433344022	1058	Economy	10200.00
0005433343340	1058	Economy	10200.00
0005433269765	1058	Economy	10200.00
0005433344154	1058	Economy	10200.00
0005433269764	1058	Economy	10200.00
0005433343730	1058	Economy	10200.00
0005433343915	1058	Economy	10200.00
0005433343715	1058	Economy	10200.00
0005433343922	1058	Economy	10200.00
0005432293244	1058	Economy	10200.00
0005433343587	1058	Economy	10200.00
0005433343842	1058	Economy	10200.00
0005435092225	1058	Economy	10200.00
0005433343887	1058	Economy	10200.00
0005433269766	1058	Economy	10200.00
0005434445276	1058	Economy	10200.00
0005433343736	1058	Economy	10200.00
0005433269747	1058	Economy	10200.00
0005435092221	1058	Economy	10200.00
0005433343230	1058	Economy	10200.00
0005435092228	1058	Economy	10200.00
0005433344095	1058	Economy	10200.00
0005432293246	1058	Economy	10200.00
0005435545851	1058	Economy	10200.00
0005433159333	1058	Economy	10200.00
0005433343229	1058	Economy	10200.00
0005433343765	1058	Economy	10200.00
0005433344260	1058	Economy	10200.00
0005433343228	1058	Economy	10200.00
0005433343711	1058	Economy	10200.00
0005433343991	1058	Economy	10200.00
0005433344221	1058	Economy	10200.00
0005433343921	1058	Economy	10200.00
0005433344220	1058	Economy	10200.00
0005434445277	1058	Economy	10200.00
0005433462779	1058	Economy	10200.00
0005433343261	1058	Economy	10200.00
0005434445275	1058	Economy	10200.00
0005433343521	1058	Economy	11200.00
0005433343446	1058	Economy	10200.00
0005433343781	1058	Economy	10200.00
0005433343522	1058	Economy	10200.00
0005433343665	1058	Economy	11200.00
0005433343758	1058	Economy	11200.00
0005433343666	1058	Economy	10200.00
0005433343834	1058	Economy	10200.00
0005433343658	1058	Economy	10200.00
0005433343378	1058	Economy	10200.00
0005433344155	1058	Economy	10200.00
0005433343488	1058	Economy	10200.00
0005433462781	1058	Economy	10200.00
0005433343462	1058	Economy	10200.00
0005433343863	1058	Economy	10200.00
0005433344091	1058	Economy	10200.00
0005433343780	1058	Economy	10200.00
0005433343598	1058	Economy	10200.00
0005433343364	1058	Economy	10200.00
0005435092229	1058	Economy	10200.00
0005433344108	1058	Economy	10200.00
0005433343437	1058	Economy	10200.00
0005433343536	1058	Economy	10200.00
0005433343864	1058	Economy	10200.00
0005433343923	1058	Economy	10200.00
0005433343878	1058	Economy	10200.00
0005433343718	1058	Economy	10200.00
0005433343724	1058	Economy	10200.00
0005433343824	1058	Economy	10200.00
0005433343866	1058	Economy	10200.00
0005433158146	1058	Economy	10200.00
0005433343365	1058	Economy	10200.00
0005433343818	1058	Economy	10200.00
0005433462780	1058	Economy	10200.00
0005433159323	1058	Economy	10200.00
0005433343996	1058	Economy	10200.00
0005433343341	1058	Economy	10200.00
0005433343670	1058	Economy	10200.00
0005435092222	1058	Economy	10200.00
0005433343537	1058	Economy	10200.00
0005432293245	1058	Economy	10200.00
0005433344016	1058	Economy	10200.00
0005433269773	1058	Economy	10200.00
0005433343647	1058	Economy	10200.00
0005433269772	1058	Economy	10200.00
0005433343438	1058	Economy	10200.00
0005433159322	1058	Economy	10200.00
0005433343577	1058	Economy	10200.00
0005433343542	1058	Economy	10200.00
0005433344017	1058	Economy	10200.00
0005433343580	1058	Economy	10200.00
0005433344021	1058	Economy	10200.00
0005433343779	1058	Economy	10200.00
0005433343402	1058	Economy	10200.00
0005433344088	1058	Economy	10200.00
0005435092223	1058	Economy	10200.00
0005433343627	1058	Economy	10200.00
0005433343807	1058	Economy	10200.00
0005433343563	1058	Economy	10200.00
0005433343562	1058	Economy	10200.00
0005433343420	1058	Economy	10200.00
0005433343746	1058	Economy	10200.00
0005433343541	1058	Economy	10200.00
0005435545850	1058	Economy	10200.00
0005435092226	1058	Economy	10200.00
0005435545852	1058	Economy	10200.00
0005433269803	17028	Business	30600.00
0005433344586	17028	Business	30600.00
0005433344559	17028	Business	30600.00
0005433344624	17028	Business	30600.00
0005433269802	17028	Business	30600.00
0005435092165	17028	Business	30600.00
0005435092159	17028	Business	30600.00
0005433344629	17028	Business	30600.00
0005435092174	17028	Business	30600.00
0005433344579	17028	Business	30600.00
0005433344632	17028	Business	30600.00
0005433344625	17028	Business	30600.00
0005433344620	17028	Business	30600.00
0005433344622	17028	Business	30600.00
0005433344538	17028	Business	30600.00
0005433344542	17028	Business	30600.00
0005435508383	17028	Business	30600.00
0005433344609	17028	Business	30600.00
0005433344548	17028	Economy	11200.00
0005433269801	17028	Economy	11200.00
0005433269799	17028	Economy	10200.00
0005435092162	17028	Economy	10200.00
0005433344565	17028	Economy	10200.00
0005433344610	17028	Economy	10200.00
0005433344615	17028	Economy	10200.00
0005433344582	17028	Economy	10200.00
0005433344550	17028	Economy	10200.00
0005433344635	17028	Economy	10200.00
0005434445256	17028	Economy	10200.00
0005433344633	17028	Economy	10200.00
0005433344601	17028	Economy	10200.00
0005433344549	17028	Economy	10200.00
0005433344630	17028	Economy	10200.00
0005435092158	17028	Economy	10200.00
0005433344607	17028	Economy	10200.00
0005435092153	17028	Economy	10200.00
0005433344562	17028	Economy	10200.00
0005433344595	17028	Economy	10200.00
0005433344545	17028	Economy	10200.00
0005433344590	17028	Economy	10200.00
0005433344537	17028	Economy	10200.00
0005435092130	17028	Economy	10200.00
0005433344578	17028	Economy	10200.00
0005433344570	17028	Economy	10200.00
0005435092160	17028	Economy	10200.00
0005433344539	17028	Economy	10200.00
0005433344604	17028	Economy	10200.00
0005433344600	17028	Economy	10200.00
0005433344588	17028	Economy	10200.00
0005433344572	17028	Economy	10200.00
0005433269800	17028	Economy	10200.00
0005433344554	17028	Economy	10200.00
0005433344581	17028	Economy	10200.00
0005435508384	17028	Economy	10200.00
0005433344628	17028	Economy	10200.00
0005433344568	17028	Economy	10200.00
0005433344621	17028	Economy	10200.00
0005434445261	17028	Economy	10200.00
0005434445260	17028	Economy	10200.00
0005433344584	17028	Economy	10200.00
0005435092175	17028	Economy	10200.00
0005433344613	17028	Economy	10200.00
0005433344617	17028	Economy	10200.00
0005433344634	17028	Economy	10200.00
0005433344576	17028	Economy	10200.00
0005433344623	17028	Economy	10200.00
0005433344564	17028	Economy	10200.00
0005435092133	17028	Economy	10200.00
0005435508395	17028	Economy	10200.00
0005433344573	17028	Economy	10200.00
0005433344627	17028	Economy	10200.00
0005433344558	17028	Economy	10200.00
0005433344571	17028	Economy	10200.00
0005433344555	17028	Economy	10200.00
0005433344552	17028	Economy	10200.00
0005435092121	17028	Economy	10200.00
0005433344553	17028	Economy	10200.00
0005433344544	17028	Economy	10200.00
0005433344560	17028	Economy	11200.00
0005433344599	17028	Economy	11200.00
0005433344535	17028	Economy	10200.00
0005433344591	17028	Economy	10200.00
0005435508382	17028	Economy	10200.00
0005435508394	17028	Economy	11200.00
0005433344563	17028	Economy	10200.00
0005433344598	17028	Economy	10200.00
0005433344580	17028	Economy	10200.00
0005435092120	17028	Economy	10200.00
0005433344593	17028	Economy	10200.00
0005433344569	17028	Economy	10200.00
0005433344574	17028	Economy	10200.00
0005433344557	17028	Economy	10200.00
0005435092119	17028	Economy	10200.00
0005433344541	17028	Economy	10200.00
0005433344606	17028	Economy	10200.00
0005433269798	17028	Economy	10200.00
0005433344536	17028	Economy	10200.00
0005433344603	17028	Economy	10200.00
0005433344547	17028	Economy	10200.00
0005435092168	17028	Economy	10200.00
0005433344616	17028	Economy	10200.00
0005433344631	17028	Economy	10200.00
0005433344551	17028	Economy	10200.00
0005433344577	17028	Economy	10200.00
0005433344583	17028	Economy	10200.00
0005433344592	17028	Economy	10200.00
0005433344626	17028	Economy	10200.00
0005433344597	17028	Economy	10200.00
0005433344589	17028	Economy	10200.00
0005433344618	17028	Economy	10200.00
0005433344587	17028	Economy	10200.00
0005433344602	17028	Economy	10200.00
0005433344556	17028	Economy	10200.00
0005433344540	17028	Economy	10200.00
0005433344614	17028	Economy	10200.00
0005433344596	17028	Economy	10200.00
0005433344619	17028	Economy	10200.00
0005433344594	17028	Economy	10200.00
0005433344608	17028	Economy	10200.00
0005433344534	17028	Economy	10200.00
0005433344561	17028	Economy	10200.00
0005433344567	17028	Economy	10200.00
0005433269804	17028	Economy	10200.00
0005433344611	17028	Economy	10200.00
0005433344566	17028	Economy	10200.00
0005433344605	17028	Economy	10200.00
0005433344575	17028	Economy	10200.00
0005433344612	17028	Economy	10200.00
0005433344543	17028	Economy	10200.00
0005433344585	17028	Economy	10200.00
0005435092131	17028	Economy	10200.00
0005433344546	17028	Economy	10200.00
0005432433760	12822	Business	40300.00
0005434067985	12822	Business	40300.00
0005434081943	12822	Business	40300.00
0005434067748	12822	Business	40300.00
0005434081921	12822	Business	40300.00
0005433812936	12822	Business	40300.00
0005434082058	12822	Business	40300.00
0005434067517	12822	Business	40300.00
0005434068120	12822	Business	40300.00
0005432161187	12822	Business	40300.00
0005432433764	12822	Business	40300.00
0005433989801	12822	Business	40300.00
0005432161188	12822	Economy	13400.00
0005435283412	12822	Economy	13400.00
0005434068089	12822	Economy	13400.00
0005434067765	12822	Economy	13400.00
0005434026722	12822	Economy	13400.00
0005434082139	12822	Economy	13400.00
0005434067899	12822	Economy	13400.00
0005434068039	12822	Economy	13400.00
0005434082119	12822	Economy	13400.00
0005434067516	12822	Economy	13400.00
0005434068050	12822	Economy	13400.00
0005434068159	12822	Economy	13400.00
0005434067534	12822	Economy	13400.00
0005434067873	12822	Economy	13400.00
0005434068158	12822	Economy	13400.00
0005434068092	12822	Economy	13400.00
0005434082056	12822	Economy	13400.00
0005434082008	12822	Economy	13400.00
0005434082052	12822	Economy	13400.00
0005435283414	12822	Economy	13400.00
0005434067500	12822	Economy	13400.00
0005434068023	12822	Economy	13400.00
0005434082140	12822	Economy	13400.00
0005434067758	12822	Economy	13400.00
0005434068022	12822	Economy	13400.00
0005433812938	12822	Economy	13400.00
0005434068275	12822	Economy	13400.00
0005434067791	12822	Economy	13400.00
0005434082027	12822	Economy	13400.00
0005434068241	12822	Economy	13400.00
0005434067713	12822	Economy	13400.00
0005434067767	12822	Economy	13400.00
0005432433761	12822	Economy	13400.00
0005434068090	12822	Economy	13400.00
0005434068044	12822	Economy	13400.00
0005434067976	12822	Economy	13400.00
0005434067887	12822	Economy	13400.00
0005434067766	12822	Economy	13400.00
0005434067889	12822	Economy	13400.00
0005434026723	12822	Economy	14800.00
0005434068091	12822	Economy	14800.00
0005434082053	12822	Economy	14800.00
0005434081988	12822	Economy	14800.00
0005434067909	12822	Economy	13400.00
0005434068168	12822	Economy	14800.00
0005434068143	12822	Economy	13400.00
0005434067756	12822	Economy	13400.00
0005434067501	12822	Economy	13400.00
0005434082017	12822	Economy	13400.00
0005432433762	12822	Economy	13400.00
0005434068242	12822	Economy	13400.00
0005434067845	12822	Economy	13400.00
0005434068054	12822	Economy	13400.00
0005434067810	12822	Economy	13400.00
0005434067714	12822	Economy	13400.00
0005434067732	12822	Economy	13400.00
0005434081929	12822	Economy	13400.00
0005434081930	12822	Economy	13400.00
0005434068115	12822	Economy	13400.00
0005433989804	12822	Economy	13400.00
0005435283415	12822	Economy	13400.00
0005434068119	12822	Economy	13400.00
0005434082026	12822	Economy	13400.00
0005434068045	12822	Economy	13400.00
0005434067731	12822	Economy	13400.00
0005434067757	12822	Economy	13400.00
0005434068052	12822	Economy	13400.00
0005434067974	12822	Economy	13400.00
0005434068043	12822	Economy	13400.00
0005434081905	12822	Economy	13400.00
0005434067975	12822	Economy	13400.00
0005432433763	12822	Economy	13400.00
0005434082041	12822	Economy	13400.00
0005432159927	12822	Economy	13400.00
0005434082011	12822	Economy	13400.00
0005434082118	12822	Economy	13400.00
0005434067749	12822	Economy	13400.00
0005434067855	12822	Economy	13400.00
0005434082103	12822	Economy	13400.00
0005434067678	12822	Economy	13400.00
0005433989805	12822	Economy	13400.00
0005434026715	12822	Economy	13400.00
0005433812937	12822	Economy	13400.00
0005433989798	12822	Economy	13400.00
0005434082082	12822	Economy	13400.00
0005434067886	12822	Economy	13400.00
0005434081906	12822	Economy	13400.00
0005434067695	12822	Economy	13400.00
0005434068182	12822	Economy	13400.00
0005433989788	12822	Economy	13400.00
0005434068046	12822	Economy	13400.00
0005434067811	12822	Economy	13400.00
0005434068051	12822	Economy	13400.00
0005435283413	12822	Economy	13400.00
0005434081983	12822	Economy	13400.00
0005434067930	12822	Economy	13400.00
0005434067789	12822	Economy	13400.00
0005434068243	12822	Economy	13400.00
0005434068167	12822	Economy	13400.00
0005434082105	12822	Economy	13400.00
0005434068021	12822	Economy	13400.00
0005432159928	12822	Economy	13400.00
0005434067790	12822	Economy	13400.00
0005434068040	12822	Economy	13400.00
0005434067848	12822	Economy	13400.00
0005432159929	12822	Economy	13400.00
0005432161186	12822	Economy	13400.00
0005434068562	30680	Business	40300.00
0005434068590	30680	Business	40300.00
0005434068571	30680	Business	40300.00
0005434068598	30680	Business	40300.00
0005434068580	30680	Business	40300.00
0005434068609	30680	Business	40300.00
0005434068553	30680	Business	40300.00
0005434068614	30680	Business	40300.00
0005434082224	30680	Business	40300.00
0005434068607	30680	Business	40300.00
0005434068592	30680	Economy	13400.00
0005434068551	30680	Economy	13400.00
0005434068560	30680	Economy	13400.00
0005434068613	30680	Economy	13400.00
0005434068556	30680	Economy	13400.00
0005434068597	30680	Economy	13400.00
0005434082244	30680	Economy	13400.00
0005434068604	30680	Economy	13400.00
0005434068594	30680	Economy	13400.00
0005434068584	30680	Economy	13400.00
0005434082237	30680	Economy	13400.00
0005434082220	30680	Economy	13400.00
0005434068565	30680	Economy	13400.00
0005434068572	30680	Economy	13400.00
0005434068586	30680	Economy	13400.00
0005434082239	30680	Economy	13400.00
0005434068569	30680	Economy	13400.00
0005432150305	30680	Economy	13400.00
0005434068611	30680	Economy	13400.00
0005434068566	30680	Economy	13400.00
0005434068570	30680	Economy	13400.00
0005434068576	30680	Economy	13400.00
0005434082238	30680	Economy	13400.00
0005432433722	30680	Economy	13400.00
0005433989841	30680	Economy	13400.00
0005434082225	30680	Economy	13400.00
0005434082232	30680	Economy	13400.00
0005434082230	30680	Economy	13400.00
0005434068606	30680	Economy	13400.00
0005434068555	30680	Economy	13400.00
0005434068563	30680	Economy	13400.00
0005434068608	30680	Economy	13400.00
0005434068587	30680	Economy	13400.00
0005434068578	30680	Economy	13400.00
0005434082242	30680	Economy	13400.00
0005432433708	30680	Economy	13400.00
0005434082247	30680	Economy	13400.00
0005432150308	30680	Economy	13400.00
0005434082229	30680	Economy	14800.00
0005434082226	30680	Economy	14800.00
0005434068610	30680	Economy	14800.00
0005432186922	30680	Economy	14800.00
0005434068615	30680	Economy	14800.00
0005434082243	30680	Economy	14800.00
0005432186920	30680	Economy	13400.00
0005432150311	30680	Economy	13400.00
0005434068583	30680	Economy	13400.00
0005434068559	30680	Economy	13400.00
0005432186921	30680	Economy	13400.00
0005434068589	30680	Economy	13400.00
0005434082231	30680	Economy	13400.00
0005434068612	30680	Economy	13400.00
0005434068603	30680	Economy	13400.00
0005434082228	30680	Economy	13400.00
0005434068602	30680	Economy	13400.00
0005434068573	30680	Economy	13400.00
0005434082249	30680	Economy	13400.00
0005434068582	30680	Economy	13400.00
0005434068549	30680	Economy	13400.00
0005434068567	30680	Economy	13400.00
0005434068554	30680	Economy	13400.00
0005434082235	30680	Economy	13400.00
0005434082246	30680	Economy	13400.00
0005434068591	30680	Economy	13400.00
0005432433737	30680	Economy	13400.00
0005434082223	30680	Economy	13400.00
0005434068550	30680	Economy	13400.00
0005433989838	30680	Economy	13400.00
0005434068548	30680	Economy	13400.00
0005434082222	30680	Economy	13400.00
0005434068557	30680	Economy	13400.00
0005434068577	30680	Economy	13400.00
0005434068593	30680	Economy	13400.00
0005433989839	30680	Economy	13400.00
0005434068547	30680	Economy	13400.00
0005432433724	30680	Economy	13400.00
0005434082240	30680	Economy	13400.00
0005434068581	30680	Economy	13400.00
0005432186923	30680	Economy	13400.00
0005432150312	30680	Economy	13400.00
0005434068617	30680	Economy	13400.00
0005434068574	30680	Economy	13400.00
0005434082221	30680	Economy	13400.00
0005432150304	30680	Economy	13400.00
0005434082233	30680	Economy	13400.00
0005432150306	30680	Economy	13400.00
0005434068568	30680	Economy	13400.00
0005434082248	30680	Economy	13400.00
0005434068605	30680	Economy	13400.00
0005434068561	30680	Economy	13400.00
0005434068552	30680	Economy	13400.00
0005432433725	30680	Economy	13400.00
0005434082241	30680	Economy	13400.00
0005434068585	30680	Economy	13400.00
0005434068558	30680	Economy	13400.00
0005434068596	30680	Economy	13400.00
0005434082236	30680	Economy	13400.00
0005434068579	30680	Economy	13400.00
0005434068600	30680	Economy	13400.00
0005434068575	30680	Economy	13400.00
0005434082234	30680	Economy	13400.00
0005433989840	30680	Economy	13400.00
0005434068616	30680	Economy	13400.00
0005434068595	30680	Economy	13400.00
0005434068599	30680	Economy	13400.00
0005434068618	30680	Economy	13400.00
0005432150310	30680	Economy	13400.00
0005434068564	30680	Economy	13400.00
0005432150307	30680	Economy	13400.00
0005432150309	30680	Economy	13400.00
0005434068588	30680	Economy	13400.00
0005434068601	30680	Economy	13400.00
0005434082227	30680	Economy	13400.00
0005434082245	30680	Economy	13400.00
0005433689933	19356	Economy	19300.00
0005433686637	19356	Economy	19300.00
0005433686633	19356	Economy	17600.00
0005433686646	19356	Economy	17600.00
0005433686643	19356	Economy	17600.00
0005433686645	19356	Economy	17600.00
0005433689920	19356	Economy	17600.00
0005433686636	19356	Economy	17600.00
0005433686635	19356	Economy	17600.00
0005433686634	19356	Economy	17600.00
0005433689923	19356	Economy	17600.00
0005433689932	19356	Economy	17600.00
0005433689931	19356	Economy	17600.00
0005433689919	19356	Economy	17600.00
0005433686644	19356	Economy	17600.00
0005433686638	19356	Economy	17600.00
0005433689921	19356	Economy	17600.00
0005435462670	5518	Business	35300.00
0005433527325	5518	Business	35300.00
0005434265251	5518	Business	35300.00
0005435462671	5518	Business	35300.00
0005435462596	5518	Business	35300.00
0005432140570	5518	Business	35300.00
0005435767118	5518	Business	35300.00
0005435767130	5518	Business	35300.00
0005435767097	5518	Business	35300.00
0005434831194	5518	Business	35300.00
0005432140574	5518	Business	35300.00
0005435462766	5518	Business	35300.00
0005435767147	5518	Business	35300.00
0005434265364	5518	Business	35300.00
0005435767146	5518	Business	35300.00
0005435767107	5518	Business	35300.00
0005435462717	5518	Business	35300.00
0005434265166	5518	Business	35300.00
0005435735205	5518	Business	35300.00
0005435462748	5518	Business	35300.00
0005435043287	5518	Economy	12900.00
0005435767117	5518	Economy	12900.00
0005433529338	5518	Economy	12900.00
0005435462597	5518	Economy	11800.00
0005435462557	5518	Economy	11800.00
0005433527327	5518	Economy	11800.00
0005435767133	5518	Economy	11800.00
0005434831167	5518	Economy	11800.00
0005435767102	5518	Economy	11800.00
0005435725673	5518	Economy	11800.00
0005435767122	5518	Economy	11800.00
0005433527326	5518	Economy	11800.00
0005432535858	5518	Economy	11800.00
0005432535871	5518	Economy	11800.00
0005435767141	5518	Economy	11800.00
0005435462716	5518	Economy	11800.00
0005435767145	5518	Economy	11800.00
0005435462645	5518	Economy	11800.00
0005435462690	5518	Economy	11800.00
0005435767099	5518	Economy	11800.00
0005435462750	5518	Economy	11800.00
0005435767148	5518	Economy	11800.00
0005435767149	5518	Economy	11800.00
0005435767110	5518	Economy	11800.00
0005435767113	5518	Economy	11800.00
0005434265308	5518	Economy	11800.00
0005434265299	5518	Economy	11800.00
0005435767115	5518	Economy	11800.00
0005435462796	5518	Economy	11800.00
0005435725671	5518	Economy	11800.00
0005435725672	5518	Economy	11800.00
0005434265252	5518	Economy	11800.00
0005434831172	5518	Economy	11800.00
0005432140571	5518	Economy	11800.00
0005434265359	5518	Economy	11800.00
0005435767134	5518	Economy	11800.00
0005434265215	5518	Economy	11800.00
0005435723076	5518	Economy	11800.00
0005435462830	5518	Economy	11800.00
0005435767104	5518	Economy	11800.00
0005435462713	5518	Economy	11800.00
0005435462693	5518	Economy	11800.00
0005435767119	5518	Economy	11800.00
0005435767123	5518	Economy	11800.00
0005435462718	5518	Economy	11800.00
0005435767143	5518	Economy	11800.00
0005435767120	5518	Economy	11800.00
0005432140576	5518	Economy	11800.00
0005435767127	5518	Economy	11800.00
0005432140572	5518	Economy	11800.00
0005435462617	5518	Economy	11800.00
0005435735203	5518	Economy	11800.00
0005435462765	5518	Economy	11800.00
0005435462609	5518	Economy	11800.00
0005432140573	5518	Economy	11800.00
0005434831173	5518	Economy	11800.00
0005435767121	5518	Economy	11800.00
0005434831193	5518	Economy	11800.00
0005435462687	5518	Economy	11800.00
0005435462618	5518	Economy	11800.00
0005434265298	5518	Economy	11800.00
0005435767103	5518	Economy	11800.00
0005432535870	5518	Economy	11800.00
0005435462812	5518	Economy	11800.00
0005434265360	5518	Economy	11800.00
0005435462832	5518	Economy	11800.00
0005434265189	5518	Economy	11800.00
0005435462610	5518	Economy	11800.00
0005435462673	5518	Economy	11800.00
0005435767153	5518	Economy	11800.00
0005433527324	5518	Economy	11800.00
0005434265240	5518	Economy	11800.00
0005435462496	5518	Economy	11800.00
0005434831168	5518	Economy	11800.00
0005434265194	5518	Economy	11800.00
0005434265304	5518	Economy	11800.00
0005435462654	5518	Economy	11800.00
0005435462622	5518	Economy	11800.00
0005432535834	5518	Economy	11800.00
0005435767095	5518	Economy	11800.00
0005435767150	5518	Economy	11800.00
0005435767109	5518	Economy	11800.00
0005435462831	5518	Economy	12900.00
0005434265233	5518	Economy	11800.00
0005435725674	5518	Economy	12900.00
0005435767151	5518	Economy	12900.00
0005435735207	5518	Economy	12900.00
0005435767094	5518	Economy	11800.00
0005435767111	5518	Economy	11800.00
0005432140575	5518	Economy	11800.00
0005435722091	5518	Economy	11800.00
0005435767137	5518	Economy	11800.00
0005435767128	5518	Economy	11800.00
0005434265314	5518	Economy	11800.00
0005432140569	5518	Economy	11800.00
0005434265295	5518	Economy	11800.00
0005435462691	5518	Economy	11800.00
0005435767093	5518	Economy	11800.00
0005434265216	5518	Economy	11800.00
0005435767140	5518	Economy	11800.00
0005435723075	5518	Economy	11800.00
0005435767142	5518	Economy	11800.00
0005435767114	5518	Economy	11800.00
0005434265214	5518	Economy	11800.00
0005433529337	5518	Economy	11800.00
0005434831169	5518	Economy	11800.00
0005435767129	5518	Economy	11800.00
0005435725670	5518	Economy	11800.00
0005435462672	5518	Economy	11800.00
0005432535853	5518	Economy	11800.00
0005435767152	5518	Economy	11800.00
0005432535854	5518	Economy	11800.00
0005435735206	5518	Economy	11800.00
0005435462695	5518	Economy	11800.00
0005435767116	5518	Economy	11800.00
0005435767154	5518	Economy	11800.00
0005435767096	5518	Economy	11800.00
0005435462677	5518	Economy	11800.00
0005434265239	5518	Economy	11800.00
0005435462646	5518	Economy	11800.00
0005435462710	5518	Economy	11800.00
0005434265294	5518	Economy	11800.00
0005435767138	5518	Economy	11800.00
0005433529336	5518	Economy	11800.00
0005435767135	5518	Economy	11800.00
0005435767101	5518	Economy	11800.00
0005435767136	5518	Economy	11800.00
0005435767098	5518	Economy	11800.00
0005435462756	5518	Economy	11800.00
0005435767106	5518	Economy	11800.00
0005435767100	5518	Economy	11800.00
0005435767125	5518	Economy	11800.00
0005435462747	5518	Economy	11800.00
0005435767126	5518	Economy	11800.00
0005435767131	5518	Economy	11800.00
0005434265234	5518	Economy	11800.00
0005435735204	5518	Economy	11800.00
0005435462694	5518	Economy	11800.00
0005435767108	5518	Economy	11800.00
0005435462868	5518	Economy	11800.00
0005435767132	5518	Economy	11800.00
0005435043286	5518	Economy	11800.00
0005434265300	5518	Economy	11800.00
0005435767112	5518	Economy	11800.00
0005435767124	5518	Economy	11800.00
0005435767139	5518	Economy	11800.00
0005435722092	5518	Economy	11800.00
0005435462616	5518	Economy	11800.00
0005435767144	5518	Economy	11800.00
0005435767105	5518	Economy	11800.00
0005435463002	13475	Business	35300.00
0005434265533	13475	Business	35300.00
0005433533310	13475	Business	35300.00
0005434265530	13475	Business	35300.00
0005434265545	13475	Business	35300.00
0005435462999	13475	Business	35300.00
0005434265542	13475	Business	35300.00
0005433529272	13475	Business	35300.00
0005434265539	13475	Business	35300.00
0005435766736	13475	Business	35300.00
0005433533325	13475	Business	35300.00
0005433533319	13475	Business	35300.00
0005433529296	13475	Business	35300.00
0005435723061	13475	Business	35300.00
0005433533311	13475	Business	35300.00
0005435463020	13475	Business	35300.00
0005435463005	13475	Business	35300.00
0005435463028	13475	Business	35300.00
0005434265547	13475	Business	35300.00
0005435463029	13475	Business	35300.00
0005435766657	13475	Business	35300.00
0005435725631	13475	Business	35300.00
0005435766607	13475	Business	35300.00
0005433529283	13475	Business	35300.00
0005435735134	13475	Business	35300.00
0005435766669	13475	Business	35300.00
0005433529300	13475	Economy	12900.00
0005435463001	13475	Economy	12900.00
0005435463022	13475	Economy	12900.00
0005435766617	13475	Economy	11800.00
0005435735163	13475	Economy	11800.00
0005435766444	13475	Economy	11800.00
0005435722070	13475	Economy	11800.00
0005435463011	13475	Economy	11800.00
0005435766647	13475	Economy	11800.00
0005434831222	13475	Economy	11800.00
0005435766735	13475	Economy	11800.00
0005435463006	13475	Economy	11800.00
0005434265540	13475	Economy	11800.00
0005435766638	13475	Economy	11800.00
0005434265541	13475	Economy	11800.00
0005435462996	13475	Economy	11800.00
0005433533331	13475	Economy	11800.00
0005435766389	13475	Economy	11800.00
0005435463015	13475	Economy	11800.00
0005435463024	13475	Economy	11800.00
0005435766499	13475	Economy	11800.00
0005434265526	13475	Economy	11800.00
0005435463004	13475	Economy	11800.00
0005435766594	13475	Economy	11800.00
0005435463003	13475	Economy	11800.00
0005435735159	13475	Economy	11800.00
0005435463031	13475	Economy	11800.00
0005435725654	13475	Economy	11800.00
0005435462998	13475	Economy	11800.00
0005435725616	13475	Economy	11800.00
0005434265524	13475	Economy	11800.00
0005435766443	13475	Economy	11800.00
0005433533329	13475	Economy	11800.00
0005433529301	13475	Economy	11800.00
0005435725652	13475	Economy	11800.00
0005433533324	13475	Economy	11800.00
0005435725632	13475	Economy	11800.00
0005432194577	13475	Economy	11800.00
0005435766464	13475	Economy	11800.00
0005435766455	13475	Economy	11800.00
0005432194573	13475	Economy	11800.00
0005435766427	13475	Economy	11800.00
0005435766771	13475	Economy	11800.00
0005435766636	13475	Economy	11800.00
0005435462997	13475	Economy	11800.00
0005435766678	13475	Economy	11800.00
0005435725617	13475	Economy	11800.00
0005435463023	13475	Economy	11800.00
0005435463000	13475	Economy	11800.00
0005435463009	13475	Economy	11800.00
0005434265548	13475	Economy	11800.00
0005435725643	13475	Economy	11800.00
0005434831224	13475	Economy	11800.00
0005435735164	13475	Economy	11800.00
0005435725653	13475	Economy	11800.00
0005435766544	13475	Economy	11800.00
0005434265529	13475	Economy	11800.00
0005435735147	13475	Economy	11800.00
0005433533328	13475	Economy	11800.00
0005432194576	13475	Economy	11800.00
0005434831225	13475	Economy	11800.00
0005434265531	13475	Economy	11800.00
0005435463026	13475	Economy	11800.00
0005432535906	13475	Economy	11800.00
0005434265543	13475	Economy	11800.00
0005434265528	13475	Economy	11800.00
0005435766677	13475	Economy	11800.00
0005435766583	13475	Economy	11800.00
0005435463014	13475	Economy	11800.00
0005435766472	13475	Economy	11800.00
0005433529277	13475	Economy	11800.00
0005435463010	13475	Economy	11800.00
0005435766640	13475	Economy	11800.00
0005435463008	13475	Economy	11800.00
0005433533326	13475	Economy	11800.00
0005434831223	13475	Economy	11800.00
0005435463013	13475	Economy	11800.00
0005433529282	13475	Economy	11800.00
0005435463027	13475	Economy	11800.00
0005434265527	13475	Economy	11800.00
0005435463025	13475	Economy	11800.00
0005434265544	13475	Economy	11800.00
0005435766473	13475	Economy	11800.00
0005435766761	13475	Economy	11800.00
0005435722072	13475	Economy	11800.00
0005432194574	13475	Economy	11800.00
0005435766729	13475	Economy	11800.00
0005435766478	13475	Economy	11800.00
0005435463012	13475	Economy	12900.00
0005435766568	13475	Economy	12900.00
0005435735170	13475	Economy	11800.00
0005435735141	13475	Economy	12900.00
0005435766554	13475	Economy	11800.00
0005434265534	13475	Economy	12900.00
0005435462994	13475	Economy	11800.00
0005432535908	13475	Economy	11800.00
0005435766668	13475	Economy	11800.00
0005434265546	13475	Economy	11800.00
0005435463030	13475	Economy	11800.00
0005435735169	13475	Economy	11800.00
0005433529303	13475	Economy	11800.00
0005435766374	13475	Economy	11800.00
0005435462995	13475	Economy	11800.00
0005435463021	13475	Economy	11800.00
0005435766561	13475	Economy	11800.00
0005435766738	13475	Economy	11800.00
0005432535910	13475	Economy	11800.00
0005434265535	13475	Economy	11800.00
0005435766658	13475	Economy	11800.00
0005434265536	13475	Economy	11800.00
0005435722057	13475	Economy	11800.00
0005435766710	13475	Economy	11800.00
0005435766263	13475	Economy	11800.00
0005435766562	13475	Economy	11800.00
0005434265532	13475	Economy	11800.00
0005435766734	13475	Economy	11800.00
0005433533330	13475	Economy	11800.00
0005434265521	13475	Economy	11800.00
0005433529302	13475	Economy	11800.00
0005434265538	13475	Economy	11800.00
0005432535907	13475	Economy	11800.00
0005435722056	13475	Economy	11800.00
0005435766245	13475	Economy	11800.00
0005435766637	13475	Economy	11800.00
0005435766471	13475	Economy	11800.00
0005435463016	13475	Economy	11800.00
0005435766690	13475	Economy	11800.00
0005433533323	13475	Economy	11800.00
0005435766312	13475	Economy	11800.00
0005435766717	13475	Economy	11800.00
0005435722071	13475	Economy	11800.00
0005434831226	13475	Economy	11800.00
0005432194575	13475	Economy	11800.00
0005435462993	13475	Economy	11800.00
0005435766447	13475	Economy	11800.00
0005435766376	13475	Economy	11800.00
0005435463018	13475	Economy	11800.00
0005434265537	13475	Economy	11800.00
0005434265522	13475	Economy	11800.00
0005435463019	13475	Economy	11800.00
0005435725651	13475	Economy	11800.00
0005435725630	13475	Economy	11800.00
0005435766728	13475	Economy	11800.00
0005432535909	13475	Economy	11800.00
0005434265525	13475	Economy	11800.00
0005435766737	13475	Economy	11800.00
0005435766691	13475	Economy	11800.00
0005435766667	13475	Economy	11800.00
0005433529278	13475	Economy	11800.00
0005435463007	13475	Economy	11800.00
0005433529292	13475	Economy	11800.00
0005435725618	13475	Economy	11800.00
0005434265523	13475	Economy	11800.00
0005433533314	13475	Economy	11800.00
0005435766641	13475	Economy	11800.00
0005435766311	13475	Economy	11800.00
0005435463017	13475	Economy	11800.00
0005435766555	13475	Economy	11800.00
0005435766614	13475	Economy	11800.00
0005434602914	18737	Economy	3300.00
0005434602915	18737	Economy	3300.00
0005434602921	18737	Economy	3300.00
0005434602922	18737	Economy	3300.00
0005434515004	18738	Economy	3300.00
0005435904711	18738	Economy	3300.00
0005434515005	18738	Economy	3300.00
0005434604921	18738	Economy	3300.00
0005434513618	18738	Economy	3300.00
0005434515006	18738	Economy	3300.00
0005435904712	18738	Economy	3300.00
0005435904713	18738	Economy	3300.00
0005434513617	18738	Economy	3300.00
0005434514982	19154	Economy	3300.00
0005434514983	19154	Economy	3300.00
0005434514986	19154	Economy	3300.00
0005432649493	4126	Business	88300.00
0005435846273	4126	Business	88300.00
0005435846279	4126	Business	88300.00
0005432649496	4126	Business	88300.00
0005435846268	4126	Business	88300.00
0005432649498	4126	Business	88300.00
0005432649499	4126	Business	88300.00
0005432632841	4126	Economy	29400.00
0005432632838	4126	Economy	29400.00
0005435846261	4126	Economy	29400.00
0005435844327	4126	Economy	29400.00
0005432632837	4126	Economy	29400.00
0005432632849	4126	Economy	29400.00
0005435846277	4126	Economy	29400.00
0005435846269	4126	Economy	32400.00
0005432649485	4126	Economy	32400.00
0005432632834	4126	Economy	29400.00
0005432632833	4126	Economy	29400.00
0005432649492	4126	Economy	29400.00
0005432632850	4126	Economy	29400.00
0005432632853	4126	Economy	29400.00
0005432649488	4126	Economy	29400.00
0005432632845	4126	Economy	29400.00
0005432632832	4126	Economy	29400.00
0005432632851	4126	Economy	29400.00
0005435844313	4126	Economy	29400.00
0005432649490	4126	Economy	29400.00
0005432632840	4126	Economy	29400.00
0005432632846	4126	Economy	29400.00
0005432632836	4126	Economy	29400.00
0005432649486	4126	Economy	29400.00
0005435844329	4126	Economy	29400.00
0005432632844	4126	Economy	29400.00
0005435846278	4126	Economy	29400.00
0005435846274	4126	Economy	29400.00
0005432632842	4126	Economy	29400.00
0005432649495	4126	Economy	29400.00
0005432632848	4126	Economy	29400.00
0005432649491	4126	Economy	29400.00
0005432632843	4126	Economy	29400.00
0005432632852	4126	Economy	29400.00
0005435844343	4126	Economy	29400.00
0005432632839	4126	Economy	29400.00
0005435844345	4126	Economy	29400.00
0005432649484	4126	Economy	29400.00
0005432649497	4126	Economy	29400.00
0005432649487	4126	Economy	29400.00
0005432649494	4126	Economy	29400.00
0005432632835	4126	Economy	29400.00
0005435844315	4126	Economy	29400.00
0005432649489	4126	Economy	29400.00
0005435846258	4126	Economy	29400.00
0005432632847	4126	Economy	29400.00
0005432649500	4126	Economy	29400.00
0005433285612	1865	Business	48700.00
0005433009019	1865	Business	48700.00
0005433009022	1865	Business	48700.00
0005433285609	1865	Business	48700.00
0005433008733	1865	Business	48700.00
0005433008939	1865	Business	48700.00
0005433285371	1865	Business	48700.00
0005433008889	1865	Economy	16200.00
0005433008867	1865	Economy	16200.00
0005433008993	1865	Economy	16200.00
0005433285512	1865	Economy	16200.00
0005433285445	1865	Economy	16200.00
0005433008772	1865	Economy	16200.00
0005433285608	1865	Economy	16200.00
0005433008888	1865	Economy	16200.00
0005433008710	1865	Economy	16200.00
0005433008990	1865	Economy	17900.00
0005433285611	1865	Economy	17900.00
0005433008884	1865	Economy	17900.00
0005433285488	1865	Economy	17900.00
0005433008912	1865	Economy	16200.00
0005433285610	1865	Economy	16200.00
0005433008987	1865	Economy	16200.00
0005433285495	1865	Economy	16200.00
0005433008862	1865	Economy	16200.00
0005433008920	1865	Economy	16200.00
0005433008841	1865	Economy	16200.00
0005433009054	1865	Economy	16200.00
0005433008921	1865	Economy	16200.00
0005433285454	1865	Economy	16200.00
0005433008885	1865	Economy	16200.00
0005433008880	1865	Economy	16200.00
0005433285541	1865	Economy	16200.00
0005433810612	1865	Economy	16200.00
0005433285668	1865	Economy	16200.00
0005433285574	1865	Economy	16200.00
0005433810610	1865	Economy	16200.00
0005433008992	1865	Economy	16200.00
0005433285496	1865	Economy	16200.00
0005433285491	1865	Economy	16200.00
0005433285516	1865	Economy	16200.00
0005433285497	1865	Economy	16200.00
0005433810611	1865	Economy	16200.00
0005433008796	1865	Economy	16200.00
0005433285511	1865	Economy	16200.00
0005433008860	1865	Economy	16200.00
0005433008831	1865	Economy	16200.00
0005433008858	1865	Economy	16200.00
0005433008795	1865	Economy	16200.00
0005433810613	1865	Economy	16200.00
0005433009053	1865	Economy	16200.00
0005433008989	1865	Economy	16200.00
0005433285517	1865	Economy	16200.00
0005433008830	1865	Economy	16200.00
0005433008832	1865	Economy	16200.00
0005433285444	1865	Economy	16200.00
0005433008876	1865	Economy	16200.00
0005433009052	1865	Economy	16200.00
0005433008857	1865	Economy	16200.00
0005433009020	1865	Economy	16200.00
0005433008881	1865	Economy	16200.00
0005433009021	1865	Economy	16200.00
0005433008856	1865	Economy	16200.00
0005433008855	1865	Economy	16200.00
0005433008819	1865	Economy	16200.00
0005433285490	1865	Economy	16200.00
0005433285416	1865	Economy	16200.00
0005433285580	1865	Economy	16200.00
0005433008984	1865	Economy	16200.00
0005433009105	1865	Economy	16200.00
0005433285555	1865	Economy	16200.00
0005433008998	1865	Economy	16200.00
0005433009018	1865	Economy	16200.00
0005433008732	1865	Economy	16200.00
0005433285573	1865	Economy	16200.00
0005433285455	1865	Economy	16200.00
0005433009269	22619	Business	48700.00
0005433009288	22619	Business	48700.00
0005433009280	22619	Business	48700.00
0005433009274	22619	Business	48700.00
0005433009297	22619	Business	48700.00
0005433009261	22619	Business	48700.00
0005433009278	22619	Business	48700.00
0005433285748	22619	Business	48700.00
0005433009302	22619	Business	48700.00
0005433009301	22619	Economy	16200.00
0005433009279	22619	Economy	16200.00
0005433009277	22619	Economy	16200.00
0005433285751	22619	Economy	16200.00
0005433285756	22619	Economy	16200.00
0005433285749	22619	Economy	16200.00
0005433009305	22619	Economy	16200.00
0005433009268	22619	Economy	16200.00
0005433285747	22619	Economy	17900.00
0005433810560	22619	Economy	17900.00
0005433285770	22619	Economy	17900.00
0005433285760	22619	Economy	17900.00
0005433285745	22619	Economy	17900.00
0005433009266	22619	Economy	16200.00
0005433285757	22619	Economy	16200.00
0005433009284	22619	Economy	16200.00
0005433285765	22619	Economy	16200.00
0005433009262	22619	Economy	16200.00
0005433285766	22619	Economy	16200.00
0005433285761	22619	Economy	16200.00
0005433285771	22619	Economy	16200.00
0005433285762	22619	Economy	16200.00
0005433009275	22619	Economy	16200.00
0005433285769	22619	Economy	16200.00
0005433285758	22619	Economy	16200.00
0005433009292	22619	Economy	16200.00
0005433009281	22619	Economy	16200.00
0005433009286	22619	Economy	16200.00
0005433009273	22619	Economy	16200.00
0005433285755	22619	Economy	16200.00
0005433285742	22619	Economy	16200.00
0005433810561	22619	Economy	16200.00
0005433285753	22619	Economy	16200.00
0005433009291	22619	Economy	16200.00
0005433009272	22619	Economy	16200.00
0005433009264	22619	Economy	16200.00
0005433285743	22619	Economy	16200.00
0005433009265	22619	Economy	16200.00
0005433285741	22619	Economy	16200.00
0005433285744	22619	Economy	16200.00
0005433009296	22619	Economy	16200.00
0005433009271	22619	Economy	16200.00
0005433009276	22619	Economy	16200.00
0005433009293	22619	Economy	16200.00
0005433009294	22619	Economy	16200.00
0005433285752	22619	Economy	16200.00
0005433009282	22619	Economy	16200.00
0005433009295	22619	Economy	16200.00
0005433009298	22619	Economy	16200.00
0005433285750	22619	Economy	16200.00
0005433009303	22619	Economy	16200.00
0005433810564	22619	Economy	16200.00
0005433009283	22619	Economy	16200.00
0005433009260	22619	Economy	16200.00
0005433285764	22619	Economy	16200.00
0005433285759	22619	Economy	16200.00
0005433009267	22619	Economy	16200.00
0005433009289	22619	Economy	16200.00
0005433009300	22619	Economy	16200.00
0005433009287	22619	Economy	16200.00
0005433285754	22619	Economy	16200.00
0005433285746	22619	Economy	16200.00
0005433285740	22619	Economy	16200.00
0005433285767	22619	Economy	16200.00
0005433285763	22619	Economy	16200.00
0005433009270	22619	Economy	16200.00
0005433009290	22619	Economy	16200.00
0005433285768	22619	Economy	16200.00
0005433009299	22619	Economy	16200.00
0005433009263	22619	Economy	16200.00
0005433009285	22619	Economy	16200.00
0005433009304	22619	Economy	16200.00
0005433815459	5606	Business	99800.00
0005433847597	5606	Business	99800.00
0005435282689	5606	Business	99800.00
0005435282640	5606	Business	99800.00
0005432081607	5606	Business	99800.00
0005433847588	5606	Business	99800.00
0005432081609	5606	Business	99800.00
0005435282775	5606	Business	99800.00
0005435282656	5606	Business	99800.00
0005433847612	5606	Business	99800.00
0005433847634	5606	Business	99800.00
0005433847583	5606	Business	99800.00
0005433847606	5606	Business	99800.00
0005433847602	5606	Business	99800.00
0005433815456	5606	Business	99800.00
0005433847579	5606	Economy	33300.00
0005433847592	5606	Economy	33300.00
0005433847585	5606	Economy	33300.00
0005435282688	5606	Economy	33300.00
0005433847587	5606	Economy	33300.00
0005432081610	5606	Economy	33300.00
0005433847630	5606	Economy	33300.00
0005433847581	5606	Economy	33300.00
0005433847593	5606	Economy	33300.00
0005433847621	5606	Economy	33300.00
0005433847620	5606	Economy	33300.00
0005433847632	5606	Economy	36600.00
0005433847603	5606	Economy	36600.00
0005435282699	5606	Economy	36600.00
0005433847595	5606	Economy	36600.00
0005433847616	5606	Economy	33300.00
0005433847591	5606	Economy	33300.00
0005435282535	5606	Economy	33300.00
0005433847622	5606	Economy	33300.00
0005433847599	5606	Economy	33300.00
0005433847627	5606	Economy	33300.00
0005433847600	5606	Economy	33300.00
0005433847611	5606	Economy	33300.00
0005433847577	5606	Economy	33300.00
0005433847584	5606	Economy	33300.00
0005433847596	5606	Economy	33300.00
0005433847631	5606	Economy	33300.00
0005433847598	5606	Economy	33300.00
0005433847608	5606	Economy	33300.00
0005435282696	5606	Economy	33300.00
0005433847623	5606	Economy	33300.00
0005433847625	5606	Economy	33300.00
0005435282703	5606	Economy	33300.00
0005433847633	5606	Economy	33300.00
0005433847590	5606	Economy	33300.00
0005433847618	5606	Economy	33300.00
0005433847605	5606	Economy	33300.00
0005435282702	5606	Economy	33300.00
0005433847626	5606	Economy	33300.00
0005433847624	5606	Economy	33300.00
0005433847578	5606	Economy	33300.00
0005433847610	5606	Economy	33300.00
0005433847607	5606	Economy	33300.00
0005433847614	5606	Economy	33300.00
0005435282701	5606	Economy	33300.00
0005435282776	5606	Economy	33300.00
0005433847609	5606	Economy	33300.00
0005433847635	5606	Economy	33300.00
0005433847615	5606	Economy	33300.00
0005435282700	5606	Economy	33300.00
0005433847613	5606	Economy	33300.00
0005433815458	5606	Economy	33300.00
0005435282639	5606	Economy	33300.00
0005435282697	5606	Economy	33300.00
0005433847580	5606	Economy	33300.00
0005435282672	5606	Economy	33300.00
0005433847582	5606	Economy	33300.00
0005434173534	5606	Economy	33300.00
0005433847629	5606	Economy	33300.00
0005435282690	5606	Economy	33300.00
0005435282638	5606	Economy	33300.00
0005433815455	5606	Economy	33300.00
0005435282685	5606	Economy	33300.00
0005433847594	5606	Economy	33300.00
0005435282667	5606	Economy	33300.00
0005433847604	5606	Economy	33300.00
0005435282734	5606	Economy	33300.00
0005433847617	5606	Economy	33300.00
0005433847601	5606	Economy	33300.00
0005433847628	5606	Economy	33300.00
0005432081611	5606	Economy	33300.00
0005435282698	5606	Economy	33300.00
0005432081608	5606	Economy	33300.00
0005433815454	5606	Economy	33300.00
0005433847586	5606	Economy	33300.00
0005433815457	5606	Economy	33300.00
0005435282704	5606	Economy	33300.00
0005433847619	5606	Economy	33300.00
0005433847589	5606	Economy	33300.00
0005435282877	13829	Business	99800.00
0005435282868	13829	Business	99800.00
0005433847062	13829	Business	99800.00
0005433815406	13829	Business	99800.00
0005433847046	13829	Business	99800.00
0005433815419	13829	Business	99800.00
0005433847190	13829	Business	99800.00
0005433847120	13829	Business	99800.00
0005435282871	13829	Business	99800.00
0005433847331	13829	Business	99800.00
0005433847280	13829	Business	99800.00
0005432003748	13829	Business	99800.00
0005433847189	13829	Business	99800.00
0005433847269	13829	Business	99800.00
0005433847140	13829	Business	99800.00
0005434173583	13829	Business	99800.00
0005433847246	13829	Business	99800.00
0005433815435	13829	Economy	33300.00
0005433846941	13829	Economy	33300.00
0005434173581	13829	Economy	33300.00
0005433815426	13829	Economy	33300.00
0005433815436	13829	Economy	33300.00
0005433847137	13829	Economy	33300.00
0005433847082	13829	Economy	33300.00
0005435282876	13829	Economy	33300.00
0005433847330	13829	Economy	33300.00
0005435282873	13829	Economy	33300.00
0005433847156	13829	Economy	33300.00
0005435282872	13829	Economy	33300.00
0005433847267	13829	Economy	36600.00
0005433815424	13829	Economy	36600.00
0005433847081	13829	Economy	33300.00
0005433847077	13829	Economy	33300.00
0005433815427	13829	Economy	33300.00
0005435282869	13829	Economy	33300.00
0005433847153	13829	Economy	33300.00
0005433847186	13829	Economy	33300.00
0005433847248	13829	Economy	33300.00
0005433846992	13829	Economy	33300.00
0005433847263	13829	Economy	33300.00
0005433846775	13829	Economy	33300.00
0005435282878	13829	Economy	33300.00
0005433847111	13829	Economy	33300.00
0005434173579	13829	Economy	33300.00
0005435282881	13829	Economy	33300.00
0005433847406	13829	Economy	33300.00
0005433815418	13829	Economy	33300.00
0005433847188	13829	Economy	33300.00
0005433847187	13829	Economy	33300.00
0005433847036	13829	Economy	33300.00
0005433846981	13829	Economy	33300.00
0005434173580	13829	Economy	33300.00
0005433847226	13829	Economy	33300.00
0005433847083	13829	Economy	33300.00
0005435282874	13829	Economy	33300.00
0005433847145	13829	Economy	33300.00
0005433846748	13829	Economy	33300.00
0005435282882	13829	Economy	33300.00
0005435282875	13829	Economy	33300.00
0005435282870	13829	Economy	33300.00
0005433846774	13829	Economy	33300.00
0005433846882	13829	Economy	33300.00
0005433847084	13829	Economy	33300.00
0005433846929	13829	Economy	33300.00
0005433815420	13829	Economy	33300.00
0005433847080	13829	Economy	33300.00
0005433847138	13829	Economy	33300.00
0005433847389	13829	Economy	33300.00
0005435282879	13829	Economy	33300.00
0005435282880	13829	Economy	33300.00
0005435282883	13829	Economy	33300.00
0005433847044	13829	Economy	33300.00
0005433846881	13829	Economy	33300.00
0005433847170	13829	Economy	33300.00
0005433847391	13829	Economy	33300.00
0005433847110	13829	Economy	33300.00
0005433847023	13829	Economy	33300.00
0005433847045	13829	Economy	33300.00
0005433847122	13829	Economy	33300.00
0005433815422	13829	Economy	33300.00
0005433847235	13829	Economy	33300.00
0005433847024	13829	Economy	33300.00
0005433847154	13829	Economy	33300.00
0005433815423	13829	Economy	33300.00
0005433847160	13829	Economy	33300.00
0005432003749	13829	Economy	33300.00
0005435282867	13829	Economy	33300.00
0005433815400	13829	Economy	33300.00
0005433847068	13829	Economy	33300.00
0005434173582	13829	Economy	33300.00
0005433847390	13829	Economy	33300.00
0005433847268	13829	Economy	33300.00
0005433847135	13829	Economy	33300.00
0005432003750	13829	Economy	33300.00
0005433847234	13829	Economy	33300.00
0005433847247	13829	Economy	33300.00
0005434620906	7833	Economy	16600.00
0005434620907	7833	Economy	16600.00
0005434620908	7833	Economy	16600.00
0005432112550	7833	Economy	16600.00
0005435332430	7833	Economy	15100.00
0005434620897	7833	Economy	15100.00
0005435332424	7833	Economy	15100.00
0005435332390	7833	Economy	15100.00
0005435332432	7833	Economy	15100.00
0005435332389	7833	Economy	15100.00
0005435332392	7833	Economy	15100.00
0005434620910	7833	Economy	15100.00
0005434620904	7833	Economy	15100.00
0005435332406	7833	Economy	15100.00
0005434620898	7833	Economy	15100.00
0005434620911	7833	Economy	15100.00
0005434620909	7833	Economy	15100.00
0005435332394	7833	Economy	15100.00
0005434620902	7833	Economy	15100.00
0005434620912	7833	Economy	15100.00
0005434620913	7833	Economy	15100.00
0005434620905	7833	Economy	15100.00
0005435332426	7833	Economy	15100.00
0005435332440	7833	Economy	15100.00
0005435332399	7833	Economy	15100.00
0005434620896	7833	Economy	15100.00
0005434620903	7833	Economy	15100.00
0005434620900	7833	Economy	15100.00
0005434620901	7833	Economy	15100.00
0005434620916	7833	Economy	15100.00
0005435332393	7833	Economy	15100.00
0005434620914	7833	Economy	15100.00
0005432112551	7833	Economy	15100.00
0005434620915	7833	Economy	15100.00
0005434620899	7833	Economy	15100.00
0005434620895	7833	Economy	15100.00
0005435332420	7833	Economy	15100.00
0005434620746	32970	Economy	16600.00
0005434620777	32970	Economy	15100.00
0005434620688	32970	Economy	15100.00
0005434620720	32970	Economy	15100.00
0005435332487	32970	Economy	15100.00
0005434620750	32970	Economy	15100.00
0005434620726	32970	Economy	15100.00
0005434620766	32970	Economy	15100.00
0005434620736	32970	Economy	15100.00
0005435332495	32970	Economy	15100.00
0005434620834	32970	Economy	15100.00
0005434620721	32970	Economy	15100.00
0005434620767	32970	Economy	15100.00
0005434620737	32970	Economy	15100.00
0005434620739	32970	Economy	15100.00
0005435332494	32970	Economy	15100.00
0005435332492	32970	Economy	15100.00
0005434620738	32970	Economy	15100.00
0005434620689	32970	Economy	15100.00
0005434620785	32970	Economy	15100.00
0005435332491	32970	Economy	15100.00
0005435332490	32970	Economy	15100.00
0005435332489	32970	Economy	15100.00
0005434620744	32970	Economy	15100.00
0005435332488	32970	Economy	15100.00
0005435332496	32970	Economy	15100.00
0005435332493	32970	Economy	15100.00
0005434620747	32970	Economy	15100.00
0005434620710	32970	Economy	15100.00
0005434620786	32970	Economy	15100.00
0005434620748	32970	Economy	15100.00
0005435785869	4307	Business	38000.00
0005435787388	4307	Business	38000.00
0005435937403	4307	Business	38000.00
0005435785873	4307	Business	38000.00
0005435785893	4307	Business	38000.00
0005435785871	4307	Business	38000.00
0005435785872	4307	Business	38000.00
0005432190686	4307	Economy	12700.00
0005435785876	4307	Economy	12700.00
0005435785896	4307	Economy	12700.00
0005434994176	4307	Economy	12700.00
0005435785884	4307	Economy	12700.00
0005435785897	4307	Economy	12700.00
0005432190687	4307	Economy	13900.00
0005435785883	4307	Economy	13900.00
0005435785895	4307	Economy	13900.00
0005434994171	4307	Economy	12700.00
0005435937402	4307	Economy	12700.00
0005435918694	4307	Economy	12700.00
0005435785870	4307	Economy	12700.00
0005435785864	4307	Economy	12700.00
0005435918690	4307	Economy	12700.00
0005435785881	4307	Economy	12700.00
0005435787387	4307	Economy	12700.00
0005435785866	4307	Economy	12700.00
0005434994172	4307	Economy	12700.00
0005432190688	4307	Economy	12700.00
0005435785886	4307	Economy	12700.00
0005435785885	4307	Economy	12700.00
0005435785868	4307	Economy	12700.00
0005435785863	4307	Economy	12700.00
0005434994168	4307	Economy	12700.00
0005435785882	4307	Economy	12700.00
0005432190689	4307	Economy	12700.00
0005435785865	4307	Economy	12700.00
0005435937412	4307	Economy	12700.00
0005435785891	4307	Economy	12700.00
0005434994174	4307	Economy	12700.00
0005435785874	4307	Economy	12700.00
0005435785892	4307	Economy	12700.00
0005434994169	4307	Economy	12700.00
0005435785879	4307	Economy	12700.00
0005435785878	4307	Economy	12700.00
0005435785875	4307	Economy	12700.00
0005435785889	4307	Economy	12700.00
0005435937411	4307	Economy	12700.00
0005435785888	4307	Economy	12700.00
0005434994173	4307	Economy	12700.00
0005435937410	4307	Economy	12700.00
0005435785887	4307	Economy	12700.00
0005435785880	4307	Economy	12700.00
0005435785890	4307	Economy	12700.00
0005435785894	4307	Economy	12700.00
0005435785867	4307	Economy	12700.00
0005435785877	4307	Economy	12700.00
0005434994175	4307	Economy	12700.00
0005434994170	4307	Economy	12700.00
0005435918729	27307	Business	38000.00
0005435785504	27307	Business	38000.00
0005435785492	27307	Business	38000.00
0005435937444	27307	Business	38000.00
0005435785593	27307	Business	38000.00
0005435785408	27307	Economy	12700.00
0005435785388	27307	Economy	12700.00
0005434994072	27307	Economy	12700.00
0005435785580	27307	Economy	12700.00
0005434994096	27307	Economy	12700.00
0005435918728	27307	Economy	13900.00
0005435785660	27307	Economy	13900.00
0005435937446	27307	Economy	13900.00
0005434994085	27307	Economy	13900.00
0005434994071	27307	Economy	13900.00
0005435785530	27307	Economy	12700.00
0005435785457	27307	Economy	12700.00
0005435785574	27307	Economy	12700.00
0005435785566	27307	Economy	12700.00
0005435785531	27307	Economy	12700.00
0005435785648	27307	Economy	12700.00
0005435937442	27307	Economy	12700.00
0005435937443	27307	Economy	12700.00
0005435785563	27307	Economy	12700.00
0005434994102	27307	Economy	12700.00
0005435937447	27307	Economy	12700.00
0005435785653	27307	Economy	12700.00
0005435785369	27307	Economy	12700.00
0005435785569	27307	Economy	12700.00
0005434994061	27307	Economy	12700.00
0005435785516	27307	Economy	12700.00
0005435918730	27307	Economy	12700.00
0005435785472	27307	Economy	12700.00
0005435785405	27307	Economy	12700.00
0005435785425	27307	Economy	12700.00
0005435937445	27307	Economy	12700.00
0005434994092	27307	Economy	12700.00
0005435785456	27307	Economy	12700.00
0005435918726	27307	Economy	12700.00
0005435785546	27307	Economy	12700.00
0005435785368	27307	Economy	12700.00
0005435785592	27307	Economy	12700.00
0005435937441	27307	Economy	12700.00
0005435785459	27307	Economy	12700.00
0005435785517	27307	Economy	12700.00
0005435785470	27307	Economy	12700.00
0005435785575	27307	Economy	12700.00
0005434994107	27307	Economy	12700.00
0005434994091	27307	Economy	12700.00
0005434994050	27307	Economy	12700.00
0005435785469	27307	Economy	12700.00
0005435785568	27307	Economy	12700.00
0005435785523	27307	Economy	12700.00
0005435918727	27307	Economy	12700.00
0005435785578	27307	Economy	12700.00
0005435785508	27307	Economy	12700.00
0005434994049	27307	Economy	12700.00
0005432146230	19866	Economy	12800.00
0005432146229	19866	Economy	12800.00
0005432146228	19866	Economy	12800.00
0005434082252	4740	Business	40900.00
0005432568565	4740	Business	40900.00
0005432571380	4740	Business	40900.00
0005432170492	4740	Business	40900.00
0005432460665	4740	Business	40900.00
0005432568533	4740	Business	40900.00
0005432568582	4740	Business	40900.00
0005432568587	4740	Business	40900.00
0005432460627	4740	Business	40900.00
0005432460628	4740	Business	40900.00
0005433726140	4740	Business	40900.00
0005434082256	4740	Business	40900.00
0005432460645	4740	Business	40900.00
0005434082259	4740	Business	40900.00
0005432186925	4740	Business	40900.00
0005432568531	4740	Business	40900.00
0005432568553	4740	Business	40900.00
0005433452771	4740	Business	40900.00
0005432460662	4740	Business	40900.00
0005432568558	4740	Business	40900.00
0005432568560	4740	Business	40900.00
0005432460618	4740	Business	40900.00
0005434082250	4740	Business	40900.00
0005432568567	4740	Economy	15000.00
0005432460631	4740	Economy	15000.00
0005432568584	4740	Economy	13600.00
0005432460616	4740	Economy	13600.00
0005432568579	4740	Economy	13600.00
0005432571379	4740	Economy	13600.00
0005432460626	4740	Economy	13600.00
0005432460623	4740	Economy	13600.00
0005434082261	4740	Economy	13600.00
0005433452772	4740	Economy	13600.00
0005432568583	4740	Economy	13600.00
0005432460622	4740	Economy	13600.00
0005432568572	4740	Economy	13600.00
0005434559106	4740	Economy	13600.00
0005432186924	4740	Economy	13600.00
0005432460664	4740	Economy	13600.00
0005432460641	4740	Economy	13600.00
0005432568573	4740	Economy	13600.00
0005432460615	4740	Economy	13600.00
0005432568545	4740	Economy	13600.00
0005433451650	4740	Economy	13600.00
0005432568564	4740	Economy	13600.00
0005432568536	4740	Economy	13600.00
0005432568554	4740	Economy	13600.00
0005432460661	4740	Economy	13600.00
0005432170488	4740	Economy	13600.00
0005434082254	4740	Economy	13600.00
0005432568529	4740	Economy	13600.00
0005432460660	4740	Economy	13600.00
0005432170490	4740	Economy	13600.00
0005432568589	4740	Economy	13600.00
0005434082260	4740	Economy	13600.00
0005432460617	4740	Economy	13600.00
0005434082258	4740	Economy	13600.00
0005432460651	4740	Economy	13600.00
0005432568576	4740	Economy	13600.00
0005432568534	4740	Economy	13600.00
0005432460636	4740	Economy	13600.00
0005432460655	4740	Economy	13600.00
0005432460637	4740	Economy	13600.00
0005432568528	4740	Economy	13600.00
0005432568588	4740	Economy	13600.00
0005432460659	4740	Economy	13600.00
0005432170487	4740	Economy	13600.00
0005432460653	4740	Economy	13600.00
0005432568530	4740	Economy	13600.00
0005432460633	4740	Economy	13600.00
0005432568577	4740	Economy	13600.00
0005432170494	4740	Economy	13600.00
0005433726139	4740	Economy	13600.00
0005432460614	4740	Economy	13600.00
0005432460656	4740	Economy	13600.00
0005432568559	4740	Economy	13600.00
0005432571378	4740	Economy	13600.00
0005432568556	4740	Economy	13600.00
0005432568586	4740	Economy	13600.00
0005432568550	4740	Economy	13600.00
0005432460648	4740	Economy	13600.00
0005432170491	4740	Economy	13600.00
0005432186926	4740	Economy	13600.00
0005432568585	4740	Economy	13600.00
0005432568555	4740	Economy	13600.00
0005432568568	4740	Economy	13600.00
0005432568540	4740	Economy	13600.00
0005432460647	4740	Economy	13600.00
0005432571381	4740	Economy	13600.00
0005432460629	4740	Economy	13600.00
0005432568548	4740	Economy	15000.00
0005434082257	4740	Economy	13600.00
0005432460634	4740	Economy	13600.00
0005433726138	4740	Economy	15000.00
0005432568527	4740	Economy	15000.00
0005432460639	4740	Economy	13600.00
0005432568566	4740	Economy	13600.00
0005432568547	4740	Economy	13600.00
0005434082253	4740	Economy	13600.00
0005432460624	4740	Economy	13600.00
0005432568538	4740	Economy	13600.00
0005432460638	4740	Economy	13600.00
0005432568574	4740	Economy	13600.00
0005432568575	4740	Economy	13600.00
0005432460642	4740	Economy	13600.00
0005432460635	4740	Economy	13600.00
0005432568557	4740	Economy	13600.00
0005432460654	4740	Economy	13600.00
0005432460613	4740	Economy	13600.00
0005432460640	4740	Economy	13600.00
0005432568581	4740	Economy	13600.00
0005432460644	4740	Economy	13600.00
0005432568551	4740	Economy	13600.00
0005432568542	4740	Economy	13600.00
0005432170489	4740	Economy	13600.00
0005432460650	4740	Economy	13600.00
0005432170493	4740	Economy	13600.00
0005432568541	4740	Economy	13600.00
0005432568571	4740	Economy	13600.00
0005432568532	4740	Economy	13600.00
0005432568543	4740	Economy	13600.00
0005432568539	4740	Economy	13600.00
0005432460632	4740	Economy	13600.00
0005434082255	4740	Economy	13600.00
0005432568563	4740	Economy	13600.00
0005432460625	4740	Economy	13600.00
0005432568569	4740	Economy	13600.00
0005432460663	4740	Economy	13600.00
0005432460652	4740	Economy	13600.00
0005432568561	4740	Economy	13600.00
0005432460612	4740	Economy	13600.00
0005432568537	4740	Economy	13600.00
0005432460646	4740	Economy	13600.00
0005432460657	4740	Economy	13600.00
0005432568570	4740	Economy	13600.00
0005432460643	4740	Economy	13600.00
0005432460658	4740	Economy	13600.00
0005432460621	4740	Economy	13600.00
0005432568544	4740	Economy	13600.00
0005432568552	4740	Economy	13600.00
0005432568546	4740	Economy	13600.00
0005434082251	4740	Economy	13600.00
0005432460619	4740	Economy	13600.00
0005432568562	4740	Economy	13600.00
0005432460649	4740	Economy	13600.00
0005432568578	4740	Economy	13600.00
0005432568535	4740	Economy	13600.00
0005432460630	4740	Economy	13600.00
0005432460620	4740	Economy	13600.00
0005432568549	4740	Economy	13600.00
0005432568580	4740	Economy	13600.00
0005432568369	30542	Business	40900.00
0005434082056	30542	Business	40900.00
0005432567838	30542	Business	40900.00
0005434082140	30542	Business	40900.00
0005432460152	30542	Business	40900.00
0005432460334	30542	Business	40900.00
0005432568012	30542	Business	40900.00
0005432460238	30542	Business	40900.00
0005433452747	30542	Business	40900.00
0005432460160	30542	Business	40900.00
0005434082118	30542	Business	40900.00
0005432568009	30542	Business	40900.00
0005432567973	30542	Business	40900.00
0005432568061	30542	Business	40900.00
0005432568367	30542	Business	40900.00
0005432568221	30542	Business	40900.00
0005432460389	30542	Business	40900.00
0005432460034	30542	Business	40900.00
0005432460294	30542	Business	40900.00
0005432460255	30542	Business	40900.00
0005432568295	30542	Business	40900.00
0005432568259	30542	Business	40900.00
0005432459947	30542	Business	40900.00
0005432568132	30542	Business	40900.00
0005432568072	30542	Business	40900.00
0005432568213	30542	Business	40900.00
0005432460126	30542	Economy	15000.00
0005432568238	30542	Economy	15000.00
0005434082139	30542	Economy	13600.00
0005432568099	30542	Economy	13600.00
0005432568237	30542	Economy	13600.00
0005432568304	30542	Economy	13600.00
0005432568189	30542	Economy	13600.00
0005433452754	30542	Economy	13600.00
0005432568336	30542	Economy	13600.00
0005433454890	30542	Economy	13600.00
0005432568425	30542	Economy	13600.00
0005432213662	30542	Economy	13600.00
0005432460391	30542	Economy	13600.00
0005432571352	30542	Economy	13600.00
0005433454887	30542	Economy	13600.00
0005432460242	30542	Economy	13600.00
0005432460396	30542	Economy	13600.00
0005434082052	30542	Economy	13600.00
0005432460309	30542	Economy	13600.00
0005432568286	30542	Economy	13600.00
0005434081905	30542	Economy	13600.00
0005432460080	30542	Economy	13600.00
0005432460148	30542	Economy	13600.00
0005434081983	30542	Economy	13600.00
0005432460173	30542	Economy	13600.00
0005432460213	30542	Economy	13600.00
0005432568368	30542	Economy	13600.00
0005432460362	30542	Economy	13600.00
0005434082026	30542	Economy	13600.00
0005434082119	30542	Economy	13600.00
0005432568172	30542	Economy	13600.00
0005432568239	30542	Economy	13600.00
0005432460168	30542	Economy	13600.00
0005432568130	30542	Economy	13600.00
0005432460361	30542	Economy	13600.00
0005434081988	30542	Economy	13600.00
0005432213663	30542	Economy	13600.00
0005433454882	30542	Economy	13600.00
0005432460220	30542	Economy	13600.00
0005432460201	30542	Economy	13600.00
0005432460297	30542	Economy	13600.00
0005432571353	30542	Economy	13600.00
0005432460125	30542	Economy	13600.00
0005434082041	30542	Economy	13600.00
0005432567925	30542	Economy	13600.00
0005432460284	30542	Economy	13600.00
0005432568011	30542	Economy	13600.00
0005432460186	30542	Economy	13600.00
0005432161187	30542	Economy	13600.00
0005432460293	30542	Economy	13600.00
0005432460174	30542	Economy	13600.00
0005432568010	30542	Economy	13600.00
0005432568048	30542	Economy	13600.00
0005432568296	30542	Economy	13600.00
0005432213661	30542	Economy	13600.00
0005432568216	30542	Economy	13600.00
0005432567974	30542	Economy	13600.00
0005432568103	30542	Economy	13600.00
0005432568101	30542	Economy	13600.00
0005432460383	30542	Economy	13600.00
0005432460272	30542	Economy	13600.00
0005432460185	30542	Economy	13600.00
0005433454889	30542	Economy	13600.00
0005432567921	30542	Economy	13600.00
0005434082105	30542	Economy	13600.00
0005432460310	30542	Economy	13600.00
0005432460285	30542	Economy	13600.00
0005432460286	30542	Economy	13600.00
0005432567875	30542	Economy	13600.00
0005432567782	30542	Economy	13600.00
0005432460252	30542	Economy	13600.00
0005432568020	30542	Economy	13600.00
0005432460214	30542	Economy	13600.00
0005432460239	30542	Economy	13600.00
0005434082058	30542	Economy	13600.00
0005432568176	30542	Economy	13600.00
0005433454891	30542	Economy	13600.00
0005432568287	30542	Economy	13600.00
0005434081929	30542	Economy	13600.00
0005432567944	30542	Economy	15000.00
0005432460298	30542	Economy	13600.00
0005435840362	30542	Economy	13600.00
0005432460082	30542	Economy	15000.00
0005434082017	30542	Economy	13600.00
0005432568060	30542	Economy	13600.00
0005432568214	30542	Economy	13600.00
0005434082053	30542	Economy	13600.00
0005432568126	30542	Economy	13600.00
0005432567945	30542	Economy	13600.00
0005432460289	30542	Economy	13600.00
0005432567975	30542	Economy	13600.00
0005432568063	30542	Economy	13600.00
0005432568074	30542	Economy	13600.00
0005432568305	30542	Economy	13600.00
0005434081943	30542	Economy	13600.00
0005435840360	30542	Economy	13600.00
0005432460388	30542	Economy	13600.00
0005432460144	30542	Economy	13600.00
0005432460381	30542	Economy	13600.00
0005434082008	30542	Economy	13600.00
0005432460169	30542	Economy	13600.00
0005434082027	30542	Economy	13600.00
0005432460017	30542	Economy	13600.00
0005435840363	30542	Economy	13600.00
0005434081906	30542	Economy	13600.00
0005432161186	30542	Economy	13600.00
0005432460245	30542	Economy	13600.00
0005434082082	30542	Economy	13600.00
0005432568052	30542	Economy	13600.00
0005432567920	30542	Economy	13600.00
0005432568096	30542	Economy	13600.00
0005432568104	30542	Economy	13600.00
0005432460390	30542	Economy	13600.00
0005434082011	30542	Economy	13600.00
0005432568177	30542	Economy	13600.00
0005432568073	30542	Economy	13600.00
0005432460212	30542	Economy	13600.00
0005434082103	30542	Economy	13600.00
0005432567914	30542	Economy	13600.00
0005432460244	30542	Economy	13600.00
0005432571366	30542	Economy	13600.00
0005434081930	30542	Economy	13600.00
0005432460063	30542	Economy	13600.00
0005432567857	30542	Economy	13600.00
0005432568231	30542	Economy	13600.00
0005435840361	30542	Economy	13600.00
0005432568102	30542	Economy	13600.00
0005434081921	30542	Economy	13600.00
0005432568249	30542	Economy	13600.00
0005432460198	30542	Economy	13600.00
0005432568081	30542	Economy	13600.00
0005432460079	30542	Economy	13600.00
0005432568131	30542	Economy	13600.00
0005432567987	30542	Economy	13600.00
0005432213664	30542	Economy	13600.00
0005432568215	30542	Economy	13600.00
0005432161188	30542	Economy	13600.00
0005432460031	30542	Economy	13600.00
0005432460300	30542	Economy	13600.00
0005432568250	30542	Economy	13600.00
0005435722091	13659	Economy	9900.00
0005435722092	13659	Economy	9900.00
0005435722062	21126	Economy	9900.00
0005435722075	21126	Economy	9900.00
0005435722074	21126	Economy	9900.00
0005433344680	11133	Business	23600.00
0005433344712	11133	Business	23600.00
0005435508428	11133	Business	23600.00
0005435508434	11133	Business	23600.00
0005435097350	11133	Business	23600.00
0005433344657	11133	Business	23600.00
0005435097343	11133	Business	23600.00
0005435508427	11133	Business	23600.00
0005433344718	11133	Business	23600.00
0005433344655	11133	Business	23600.00
0005433344691	11133	Business	23600.00
0005433344673	11133	Business	23600.00
0005433344689	11133	Economy	7900.00
0005433344678	11133	Economy	7900.00
0005433344697	11133	Economy	7900.00
0005433344706	11133	Economy	7900.00
0005435097351	11133	Economy	7900.00
0005433344667	11133	Economy	7900.00
0005433344679	11133	Economy	7900.00
0005435380314	11133	Economy	7900.00
0005435097348	11133	Economy	7900.00
0005433344650	11133	Economy	7900.00
0005433344654	11133	Economy	7900.00
0005433344645	11133	Economy	7900.00
0005433344662	11133	Economy	7900.00
0005433344647	11133	Economy	7900.00
0005433344722	11133	Economy	7900.00
0005433344702	11133	Economy	7900.00
0005433344669	11133	Economy	7900.00
0005433344643	11133	Economy	7900.00
0005433344693	11133	Economy	7900.00
0005433344710	11133	Economy	7900.00
0005433344638	11133	Economy	7900.00
0005433344651	11133	Economy	7900.00
0005435508444	11133	Economy	7900.00
0005433344636	11133	Economy	7900.00
0005433344708	11133	Economy	7900.00
0005433344734	11133	Economy	7900.00
0005435097349	11133	Economy	7900.00
0005433344728	11133	Economy	7900.00
0005433344729	11133	Economy	7900.00
0005435097347	11133	Economy	7900.00
0005433344723	11133	Economy	7900.00
0005433344687	11133	Economy	7900.00
0005433344685	11133	Economy	7900.00
0005433344696	11133	Economy	7900.00
0005435508446	11133	Economy	7900.00
0005433344713	11133	Economy	7900.00
0005433344670	11133	Economy	7900.00
0005433344711	11133	Economy	7900.00
0005433344682	11133	Economy	7900.00
0005433344659	11133	Economy	7900.00
0005433344715	11133	Economy	8600.00
0005433344698	11133	Economy	8600.00
0005433344725	11133	Economy	8600.00
0005433344639	11133	Economy	8600.00
0005433344695	11133	Economy	8600.00
0005433344684	11133	Economy	7900.00
0005433344701	11133	Economy	8600.00
0005433344665	11133	Economy	7900.00
0005433344724	11133	Economy	7900.00
0005433344668	11133	Economy	7900.00
0005433344641	11133	Economy	7900.00
0005433344656	11133	Economy	7900.00
0005433344705	11133	Economy	7900.00
0005433344719	11133	Economy	7900.00
0005433344717	11133	Economy	7900.00
0005433344676	11133	Economy	7900.00
0005435097344	11133	Economy	7900.00
0005435097352	11133	Economy	7900.00
0005433344646	11133	Economy	7900.00
0005433344674	11133	Economy	7900.00
0005433344649	11133	Economy	7900.00
0005435508429	11133	Economy	7900.00
0005433344663	11133	Economy	7900.00
0005433344675	11133	Economy	7900.00
0005433344694	11133	Economy	7900.00
0005433344700	11133	Economy	7900.00
0005433344699	11133	Economy	7900.00
0005433344733	11133	Economy	7900.00
0005433344736	11133	Economy	7900.00
0005433344648	11133	Economy	7900.00
0005435508406	11133	Economy	7900.00
0005433344727	11133	Economy	7900.00
0005433344703	11133	Economy	7900.00
0005433344707	11133	Economy	7900.00
0005433344653	11133	Economy	7900.00
0005433344681	11133	Economy	7900.00
0005433344704	11133	Economy	7900.00
0005433344642	11133	Economy	7900.00
0005433344677	11133	Economy	7900.00
0005433344720	11133	Economy	7900.00
0005433344661	11133	Economy	7900.00
0005433344690	11133	Economy	7900.00
0005433344640	11133	Economy	7900.00
0005433344721	11133	Economy	7900.00
0005435097346	11133	Economy	7900.00
0005433344730	11133	Economy	7900.00
0005433344716	11133	Economy	7900.00
0005435097353	11133	Economy	7900.00
0005433344683	11133	Economy	7900.00
0005435508400	11133	Economy	7900.00
0005433344658	11133	Economy	7900.00
0005433344709	11133	Economy	7900.00
0005435508401	11133	Economy	7900.00
0005433344735	11133	Economy	7900.00
0005433344660	11133	Economy	7900.00
0005433344652	11133	Economy	7900.00
0005433344692	11133	Economy	7900.00
0005435508445	11133	Economy	7900.00
0005435097345	11133	Economy	7900.00
0005433344637	11133	Economy	7900.00
0005435508420	11133	Economy	7900.00
0005435508424	11133	Economy	7900.00
0005433344737	11133	Economy	7900.00
0005433344671	11133	Economy	7900.00
0005433344688	11133	Economy	7900.00
0005433344672	11133	Economy	7900.00
0005433344731	11133	Economy	7900.00
0005433344732	11133	Economy	7900.00
0005433344726	11133	Economy	7900.00
0005433344666	11133	Economy	7900.00
0005433344644	11133	Economy	7900.00
0005433344664	11133	Economy	7900.00
0005433344714	11133	Economy	7900.00
0005433344686	11133	Economy	7900.00
0005435380311	11133	Economy	7900.00
0005433343996	17118	Business	23600.00
0005433343297	17118	Business	23600.00
0005433343866	17118	Business	23600.00
0005433343521	17118	Business	23600.00
0005433343576	17118	Business	23600.00
0005433343863	17118	Business	23600.00
0005433343403	17118	Business	23600.00
0005435097199	17118	Business	23600.00
0005433343542	17118	Business	23600.00
0005433343659	17118	Business	23600.00
0005433343587	17118	Business	23600.00
0005433344117	17118	Business	23600.00
0005433343261	17118	Economy	7900.00
0005433343364	17118	Economy	7900.00
0005433343437	17118	Economy	7900.00
0005433343627	17118	Economy	7900.00
0005433343824	17118	Economy	7900.00
0005433343340	17118	Economy	7900.00
0005433343841	17118	Economy	7900.00
0005435545852	17118	Economy	7900.00
0005433343564	17118	Economy	7900.00
0005435097216	17118	Economy	7900.00
0005433343670	17118	Economy	7900.00
0005433343780	17118	Economy	7900.00
0005433343586	17118	Economy	7900.00
0005433344116	17118	Economy	7900.00
0005433343746	17118	Economy	7900.00
0005433343535	17118	Economy	7900.00
0005433343924	17118	Economy	7900.00
0005433344089	17118	Economy	7900.00
0005433343715	17118	Economy	7900.00
0005433343669	17118	Economy	7900.00
0005433343570	17118	Economy	7900.00
0005433343718	17118	Economy	7900.00
0005433344165	17118	Economy	7900.00
0005433343537	17118	Economy	7900.00
0005433343667	17118	Economy	7900.00
0005435545851	17118	Economy	7900.00
0005433344017	17118	Economy	7900.00
0005433343438	17118	Economy	7900.00
0005433343488	17118	Economy	7900.00
0005432293246	17118	Economy	7900.00
0005433343923	17118	Economy	7900.00
0005433343842	17118	Economy	7900.00
0005433343445	17118	Economy	7900.00
0005435097252	17118	Economy	7900.00
0005433343229	17118	Economy	7900.00
0005433343541	17118	Economy	7900.00
0005433344021	17118	Economy	7900.00
0005433344091	17118	Economy	7900.00
0005433343778	17118	Economy	8600.00
0005435097275	17118	Economy	8600.00
0005433343878	17118	Economy	8600.00
0005433343758	17118	Economy	8600.00
0005433343781	17118	Economy	8600.00
0005435380369	17118	Economy	8600.00
0005433343563	17118	Economy	7900.00
0005433343921	17118	Economy	7900.00
0005433343378	17118	Economy	7900.00
0005435097251	17118	Economy	7900.00
0005433343402	17118	Economy	7900.00
0005432293244	17118	Economy	7900.00
0005433343666	17118	Economy	7900.00
0005433344108	17118	Economy	7900.00
0005433343730	17118	Economy	7900.00
0005433343480	17118	Economy	7900.00
0005433344260	17118	Economy	7900.00
0005433344022	17118	Economy	7900.00
0005435380370	17118	Economy	7900.00
0005433343522	17118	Economy	7900.00
0005433343461	17118	Economy	7900.00
0005433343765	17118	Economy	7900.00
0005433343777	17118	Economy	7900.00
0005433343834	17118	Economy	7900.00
0005433344221	17118	Economy	7900.00
0005433343779	17118	Economy	7900.00
0005433343736	17118	Economy	7900.00
0005433343747	17118	Economy	7900.00
0005433343379	17118	Economy	7900.00
0005435380371	17118	Economy	7900.00
0005433344087	17118	Economy	7900.00
0005433344154	17118	Economy	7900.00
0005433344109	17118	Economy	7900.00
0005433343628	17118	Economy	7900.00
0005433344177	17118	Economy	7900.00
0005433343365	17118	Economy	7900.00
0005433343724	17118	Economy	7900.00
0005435097217	17118	Economy	7900.00
0005433344088	17118	Economy	7900.00
0005433343738	17118	Economy	7900.00
0005433343807	17118	Economy	7900.00
0005433343674	17118	Economy	7900.00
0005433343462	17118	Economy	7900.00
0005433343915	17118	Economy	7900.00
0005433343272	17118	Economy	7900.00
0005433343887	17118	Economy	7900.00
0005432293245	17118	Economy	7900.00
0005433343341	17118	Economy	7900.00
0005433343580	17118	Economy	7900.00
0005433343647	17118	Economy	7900.00
0005433343665	17118	Economy	7900.00
0005433344016	17118	Economy	7900.00
0005433343230	17118	Economy	7900.00
0005433343922	17118	Economy	7900.00
0005433343562	17118	Economy	7900.00
0005433343737	17118	Economy	7900.00
0005433343711	17118	Economy	7900.00
0005433343598	17118	Economy	7900.00
0005435380372	17118	Economy	7900.00
0005433344095	17118	Economy	7900.00
0005433343446	17118	Economy	7900.00
0005433343420	17118	Economy	7900.00
0005435380368	17118	Economy	7900.00
0005433343818	17118	Economy	7900.00
0005433343577	17118	Economy	7900.00
0005433344220	17118	Economy	7900.00
0005433344107	17118	Economy	7900.00
0005433343536	17118	Economy	7900.00
0005433343658	17118	Economy	7900.00
0005433343901	17118	Economy	7900.00
0005433343864	17118	Economy	7900.00
0005433343228	17118	Economy	7900.00
0005435097248	17118	Economy	7900.00
0005433344155	17118	Economy	7900.00
0005433343991	17118	Economy	7900.00
0005435380373	17118	Economy	7900.00
0005435545850	17118	Economy	7900.00
0005432920089	9102	Business	26600.00
0005432919942	9102	Business	26600.00
0005433507445	9102	Business	26600.00
0005433481284	9102	Business	26600.00
0005432920009	9102	Business	26600.00
0005432919909	9102	Business	26600.00
0005432919946	9102	Business	26600.00
0005433507448	9102	Business	26600.00
0005433507444	9102	Business	26600.00
0005432919984	9102	Economy	8900.00
0005432919965	9102	Economy	8900.00
0005433481288	9102	Economy	8900.00
0005432920050	9102	Economy	8900.00
0005433507443	9102	Economy	9800.00
0005432919973	9102	Economy	9800.00
0005432920032	9102	Economy	8900.00
0005432919982	9102	Economy	8900.00
0005432919945	9102	Economy	8900.00
0005433481290	9102	Economy	8900.00
0005432919941	9102	Economy	8900.00
0005432919975	9102	Economy	8900.00
0005433507449	9102	Economy	8900.00
0005432920019	9102	Economy	8900.00
0005432919976	9102	Economy	8900.00
0005432919994	9102	Economy	8900.00
0005432920051	9102	Economy	8900.00
0005433481287	9102	Economy	8900.00
0005432919922	9102	Economy	8900.00
0005432919929	9102	Economy	8900.00
0005433507446	9102	Economy	8900.00
0005432919947	9102	Economy	8900.00
0005432920090	9102	Economy	8900.00
0005432920020	9102	Economy	8900.00
0005432920006	9102	Economy	8900.00
0005432920005	9102	Economy	8900.00
0005432920033	9102	Economy	8900.00
0005432919974	9102	Economy	8900.00
0005433481283	9102	Economy	8900.00
0005433481285	9102	Economy	8900.00
0005433481282	9102	Economy	8900.00
0005433481289	9102	Economy	8900.00
0005433507447	9102	Economy	8900.00
0005432919956	9102	Economy	8900.00
0005433507450	9102	Economy	8900.00
0005432919944	9102	Economy	8900.00
0005432919995	9102	Economy	8900.00
0005432920078	9102	Economy	8900.00
0005433481286	9102	Economy	8900.00
0005432919988	9102	Economy	8900.00
0005432919943	9102	Economy	8900.00
0005432920034	9102	Economy	8900.00
0005432920018	9102	Economy	8900.00
0005432920088	9102	Economy	8900.00
0005432920206	20469	Business	26600.00
0005432920192	20469	Business	26600.00
0005432920195	20469	Business	26600.00
0005432920190	20469	Business	26600.00
0005433507241	20469	Economy	8900.00
0005433507336	20469	Economy	8900.00
0005434159010	20469	Economy	8900.00
0005433507321	20469	Economy	8900.00
0005434159015	20469	Economy	8900.00
0005434159012	20469	Economy	8900.00
0005433507324	20469	Economy	8900.00
0005432920203	20469	Economy	8900.00
0005432920193	20469	Economy	8900.00
0005432920202	20469	Economy	8900.00
0005432920197	20469	Economy	8900.00
0005433507267	20469	Economy	8900.00
0005433507218	20469	Economy	8900.00
0005433507329	20469	Economy	8900.00
0005433507289	20469	Economy	8900.00
0005432920194	20469	Economy	8900.00
0005433507242	20469	Economy	8900.00
0005432920189	20469	Economy	8900.00
0005432920191	20469	Economy	8900.00
0005432920199	20469	Economy	8900.00
0005432920201	20469	Economy	8900.00
0005433507380	20469	Economy	8900.00
0005433507337	20469	Economy	8900.00
0005434159013	20469	Economy	8900.00
0005433507338	20469	Economy	8900.00
0005433507320	20469	Economy	8900.00
0005434159011	20469	Economy	8900.00
0005432920205	20469	Economy	8900.00
0005432920198	20469	Economy	8900.00
0005432920208	20469	Economy	8900.00
0005432920196	20469	Economy	8900.00
0005434159014	20469	Economy	8900.00
0005434159016	20469	Economy	8900.00
0005432920200	20469	Economy	8900.00
0005433507370	20469	Economy	8900.00
0005432920204	20469	Economy	8900.00
0005433507290	20469	Economy	8900.00
0005432920207	20469	Economy	8900.00
0005432394161	10199	Economy	5800.00
0005432396301	10199	Economy	5800.00
0005432396302	10199	Economy	5800.00
0005432394164	10199	Economy	5800.00
0005435179698	10199	Economy	5800.00
0005432394163	10199	Economy	5800.00
0005432394162	10199	Economy	5800.00
0005435179697	10199	Economy	5800.00
0005432394160	10199	Economy	5800.00
0005432396303	10199	Economy	5800.00
0005432396264	18397	Economy	5800.00
0005435179408	18397	Economy	5800.00
0005432400157	18397	Economy	5800.00
0005432396262	18397	Economy	5800.00
0005432396263	18397	Economy	5800.00
0005435179407	18397	Economy	5800.00
0005432400146	18397	Economy	5800.00
0005432396283	18397	Economy	5800.00
0005432400153	18397	Economy	5800.00
0005432396260	18397	Economy	5800.00
0005435626281	11000	Business	9500.00
0005435126613	11000	Business	9500.00
0005435126630	11000	Business	9500.00
0005434411843	11000	Business	9500.00
0005435626231	11000	Business	9500.00
0005435626266	11000	Business	9500.00
0005435126405	11000	Business	9500.00
0005435126709	11000	Business	9500.00
0005435126404	11000	Business	9500.00
0005435626267	11000	Business	9500.00
0005434928344	11000	Economy	3200.00
0005435626280	11000	Economy	3200.00
0005435626286	11000	Economy	3200.00
0005435556716	11000	Economy	3200.00
0005435126504	11000	Economy	3200.00
0005435126535	11000	Economy	3200.00
0005435126642	11000	Economy	3200.00
0005435126564	11000	Economy	3200.00
0005435126268	11000	Economy	3200.00
0005435126624	11000	Economy	3500.00
0005435126708	11000	Economy	3500.00
0005435626224	11000	Economy	3500.00
0005435126776	11000	Economy	3200.00
0005435126537	11000	Economy	3200.00
0005435126658	11000	Economy	3200.00
0005435126684	11000	Economy	3200.00
0005435126814	11000	Economy	3200.00
0005435126682	11000	Economy	3200.00
0005435626298	11000	Economy	3200.00
0005435126394	11000	Economy	3200.00
0005435126536	11000	Economy	3200.00
0005435126752	11000	Economy	3200.00
0005435626282	11000	Economy	3200.00
0005435126637	11000	Economy	3200.00
0005435554227	11000	Economy	3200.00
0005435126645	11000	Economy	3200.00
0005435126693	11000	Economy	3200.00
0005435626248	11000	Economy	3200.00
0005435626247	11000	Economy	3200.00
0005435126716	11000	Economy	3200.00
0005435126726	11000	Economy	3200.00
0005435626270	11000	Economy	3200.00
0005435126648	11000	Economy	3200.00
0005435126714	11000	Economy	3200.00
0005435626249	11000	Economy	3200.00
0005435126615	11000	Economy	3200.00
0005435126683	11000	Economy	3200.00
0005435556705	11000	Economy	3200.00
0005435626297	11000	Economy	3200.00
0005434411844	11000	Economy	3200.00
0005434411845	11000	Economy	3200.00
0005435126665	11000	Economy	3200.00
0005435126614	11000	Economy	3200.00
0005434411846	11000	Economy	3200.00
0005435126677	11000	Economy	3200.00
0005435556706	11000	Economy	3200.00
0005435626275	11000	Economy	3200.00
0005435126623	11000	Economy	3200.00
0005435126715	11000	Economy	3200.00
0005435126828	11000	Economy	3200.00
0005434928343	11000	Economy	3200.00
0005435554223	11000	Economy	3200.00
0005435626204	11000	Economy	3200.00
0005435626205	11000	Economy	3200.00
0005435554222	11000	Economy	3200.00
0005435126608	11000	Economy	3200.00
0005435626274	11000	Economy	3200.00
0005435126753	11000	Economy	3200.00
0005435126494	11000	Economy	3200.00
0005435626250	11000	Economy	3200.00
0005434928342	11000	Economy	3200.00
0005435126627	11000	Economy	3200.00
0005435626287	11000	Economy	3200.00
0005435126990	14679	Business	9500.00
0005435626458	14679	Business	9500.00
0005435126987	14679	Business	9500.00
0005435127019	14679	Business	9500.00
0005435626450	14679	Business	9500.00
0005435126988	14679	Business	9500.00
0005435127008	14679	Business	9500.00
0005435126995	14679	Business	9500.00
0005435626447	14679	Business	9500.00
0005435127016	14679	Business	9500.00
0005435127009	14679	Economy	3200.00
0005435126991	14679	Economy	3200.00
0005435554258	14679	Economy	3200.00
0005435626459	14679	Economy	3200.00
0005435127011	14679	Economy	3200.00
0005435127017	14679	Economy	3200.00
0005435626462	14679	Economy	3200.00
0005435127013	14679	Economy	3500.00
0005435626445	14679	Economy	3500.00
0005435127012	14679	Economy	3500.00
0005435127014	14679	Economy	3500.00
0005435126993	14679	Economy	3200.00
0005435126986	14679	Economy	3200.00
0005435126994	14679	Economy	3200.00
0005434928315	14679	Economy	3200.00
0005434411800	14679	Economy	3200.00
0005435626457	14679	Economy	3200.00
0005435126997	14679	Economy	3200.00
0005435626452	14679	Economy	3200.00
0005435127000	14679	Economy	3200.00
0005435554259	14679	Economy	3200.00
0005435626461	14679	Economy	3200.00
0005435127018	14679	Economy	3200.00
0005435126998	14679	Economy	3200.00
0005435127002	14679	Economy	3200.00
0005435126984	14679	Economy	3200.00
0005434411814	14679	Economy	3200.00
0005435127020	14679	Economy	3200.00
0005435626453	14679	Economy	3200.00
0005435126989	14679	Economy	3200.00
0005435126999	14679	Economy	3200.00
0005435127003	14679	Economy	3200.00
0005435626456	14679	Economy	3200.00
0005434928305	14679	Economy	3200.00
0005435554260	14679	Economy	3200.00
0005435127004	14679	Economy	3200.00
0005435126996	14679	Economy	3200.00
0005435626460	14679	Economy	3200.00
0005435126985	14679	Economy	3200.00
0005435127015	14679	Economy	3200.00
0005435626451	14679	Economy	3200.00
0005435126992	14679	Economy	3200.00
0005435126983	14679	Economy	3200.00
0005435127001	14679	Economy	3200.00
0005435626448	14679	Economy	3200.00
0005435554257	14679	Economy	3200.00
0005435556731	14679	Economy	3200.00
0005435556730	14679	Economy	3200.00
0005435127007	14679	Economy	3200.00
0005435127005	14679	Economy	3200.00
0005435126982	14679	Economy	3200.00
0005435626454	14679	Economy	3200.00
0005435626443	14679	Economy	3200.00
0005435127006	14679	Economy	3200.00
0005435554256	14679	Economy	3200.00
0005435127010	14679	Economy	3200.00
0005435626449	14679	Economy	3200.00
0005435126981	14679	Economy	3200.00
0005435626444	14679	Economy	3200.00
0005435626463	14679	Economy	3200.00
0005435626455	14679	Economy	3200.00
0005435626446	14679	Economy	3200.00
0005435715733	7101	Business	86900.00
0005435443375	7101	Business	86900.00
0005435715727	7101	Business	86900.00
0005435715729	7101	Business	86900.00
0005435715737	7101	Business	86900.00
0005435715735	7101	Business	86900.00
0005435216602	7101	Business	86900.00
0005435179400	7101	Economy	29000.00
0005435715726	7101	Economy	29000.00
0005432400182	7101	Economy	29000.00
0005432398257	7101	Economy	29000.00
0005435443376	7101	Economy	29000.00
0005435715740	7101	Economy	29000.00
0005435221055	7101	Economy	29000.00
0005435715734	7101	Economy	29000.00
0005435715730	7101	Economy	29000.00
0005435216598	7101	Economy	29000.00
0005435715724	7101	Economy	29000.00
0005435715728	7101	Economy	29000.00
0005435443372	7101	Economy	29000.00
0005435443388	7101	Economy	29000.00
0005435178498	7101	Economy	29000.00
0005435443354	7101	Economy	29000.00
0005435715736	7101	Economy	29000.00
0005432400179	7101	Economy	29000.00
0005435715723	7101	Economy	29000.00
0005435715739	7101	Economy	29000.00
0005435178504	7101	Economy	29000.00
0005432400181	7101	Economy	29000.00
0005435221056	7101	Economy	29000.00
0005435715731	7101	Economy	29000.00
0005435443401	7101	Economy	29000.00
0005435179401	7101	Economy	29000.00
0005432400180	7101	Economy	29000.00
0005435443355	7101	Economy	29000.00
0005435219217	7101	Economy	29000.00
0005435715732	7101	Economy	29000.00
0005435715725	7101	Economy	29000.00
0005432398255	7101	Economy	29000.00
0005432398256	7101	Economy	29000.00
0005435715738	7101	Economy	29000.00
0005432398254	7101	Economy	29000.00
0005435715544	27103	Business	86900.00
0005435715562	27103	Business	86900.00
0005435715561	27103	Business	86900.00
0005435216619	27103	Business	86900.00
0005435217745	27103	Business	86900.00
0005435715583	27103	Business	86900.00
0005435715616	27103	Economy	29000.00
0005435715563	27103	Economy	29000.00
0005435443461	27103	Economy	29000.00
0005435443455	27103	Economy	29000.00
0005432394117	27103	Economy	29000.00
0005435443462	27103	Economy	29000.00
0005435216617	27103	Economy	31900.00
0005432394131	27103	Economy	31900.00
0005432394128	27103	Economy	31900.00
0005435178517	27103	Economy	29000.00
0005435216618	27103	Economy	29000.00
0005435715545	27103	Economy	29000.00
0005432394127	27103	Economy	29000.00
0005435715601	27103	Economy	29000.00
0005435715612	27103	Economy	29000.00
0005435715533	27103	Economy	29000.00
0005435715618	27103	Economy	29000.00
0005435179003	27103	Economy	29000.00
0005435715614	27103	Economy	29000.00
0005435216616	27103	Economy	29000.00
0005435217741	27103	Economy	29000.00
0005435178516	27103	Economy	29000.00
0005435216620	27103	Economy	29000.00
0005435715588	27103	Economy	29000.00
0005435715627	27103	Economy	29000.00
0005432394126	27103	Economy	29000.00
0005435443453	27103	Economy	29000.00
0005432394100	27103	Economy	29000.00
0005435217746	27103	Economy	29000.00
0005435443459	27103	Economy	29000.00
0005435217742	27103	Economy	29000.00
0005435715613	27103	Economy	29000.00
0005435217739	27103	Economy	29000.00
0005435217744	27103	Economy	29000.00
0005435217740	27103	Economy	29000.00
0005432398229	27103	Economy	29000.00
0005435443454	27103	Economy	29000.00
0005435217743	27103	Economy	29000.00
0005435443458	27103	Economy	29000.00
0005435715524	27103	Economy	29000.00
0005435443457	27103	Economy	29000.00
0005435715615	27103	Economy	29000.00
0005435715584	27103	Economy	29000.00
0005435443460	27103	Economy	29000.00
0005435715589	27103	Economy	29000.00
0005435715581	27103	Economy	29000.00
0005435443456	27103	Economy	29000.00
0005435715543	27103	Economy	29000.00
0005435715539	27103	Economy	29000.00
0005435715540	27103	Economy	29000.00
0005435715580	27103	Economy	29000.00
0005435179004	27103	Economy	29000.00
0005435715617	27103	Economy	29000.00
0005435216615	27103	Economy	29000.00
0005434085000	2713	Economy	7700.00
0005433060429	2713	Economy	7700.00
0005434085004	2713	Economy	7700.00
0005434085003	2713	Economy	7700.00
0005434085001	2713	Economy	7700.00
0005434085002	2713	Economy	7700.00
0005434085005	2713	Economy	7700.00
0005433060426	2713	Economy	7700.00
0005433060447	2713	Economy	7700.00
0005433060455	28510	Economy	7700.00
0005433060456	28510	Economy	7700.00
0005434084944	28510	Economy	7700.00
0005434084943	28510	Economy	7700.00
0005433060457	28510	Economy	7700.00
0005433060454	28510	Economy	7700.00
0005433788270	11164	Economy	27100.00
0005435548525	11164	Economy	24600.00
0005433788268	11164	Economy	24600.00
0005435548498	11164	Economy	24600.00
0005433788271	11164	Economy	24600.00
0005435548509	11164	Economy	24600.00
0005433788266	11164	Economy	24600.00
0005433788276	11164	Economy	24600.00
0005435548510	11164	Economy	24600.00
0005433788264	11164	Economy	24600.00
0005435548500	11164	Economy	24600.00
0005433788269	11164	Economy	24600.00
0005433788267	11164	Economy	24600.00
0005435548506	11164	Economy	24600.00
0005435548527	11164	Economy	24600.00
0005435548524	11164	Economy	24600.00
0005433788273	11164	Economy	24600.00
0005435548528	11164	Economy	24600.00
0005435548512	11164	Economy	24600.00
0005433788274	11164	Economy	24600.00
0005433788275	11164	Economy	24600.00
0005433788272	11164	Economy	24600.00
0005435548531	11164	Economy	24600.00
0005435548513	11164	Economy	24600.00
0005433788265	11164	Economy	24600.00
0005435548523	11164	Economy	24600.00
0005435548526	11164	Economy	24600.00
0005435548505	11164	Economy	24600.00
0005433788232	20670	Economy	27100.00
0005433788223	20670	Economy	27100.00
0005435548557	20670	Economy	27100.00
0005435548555	20670	Economy	24600.00
0005435548552	20670	Economy	24600.00
0005435548547	20670	Economy	24600.00
0005435548560	20670	Economy	24600.00
0005435548551	20670	Economy	24600.00
0005435548564	20670	Economy	24600.00
0005435548566	20670	Economy	24600.00
0005433788215	20670	Economy	24600.00
0005435548554	20670	Economy	24600.00
0005435548548	20670	Economy	24600.00
0005433788214	20670	Economy	24600.00
0005435548567	20670	Economy	24600.00
0005433788234	20670	Economy	24600.00
0005435548563	20670	Economy	24600.00
0005433788217	20670	Economy	24600.00
0005433788213	20670	Economy	24600.00
0005435548562	20670	Economy	24600.00
0005435548558	20670	Economy	24600.00
0005433788233	20670	Economy	24600.00
0005433788228	20670	Economy	24600.00
0005433788248	20670	Economy	24600.00
0005433788210	20670	Economy	24600.00
0005433788212	20670	Economy	24600.00
0005433788229	20670	Economy	24600.00
0005433788222	20670	Economy	24600.00
0005433788247	20670	Economy	24600.00
0005433788230	20670	Economy	24600.00
0005435548556	20670	Economy	24600.00
0005435548559	20670	Economy	24600.00
0005433788225	20670	Economy	24600.00
0005435548550	20670	Economy	24600.00
0005435548549	20670	Economy	24600.00
0005435548568	20670	Economy	24600.00
0005433788216	20670	Economy	24600.00
0005435548569	20670	Economy	24600.00
0005433788208	20670	Economy	24600.00
0005435548553	20670	Economy	24600.00
0005433788209	20670	Economy	24600.00
0005435548570	20670	Economy	24600.00
0005435548561	20670	Economy	24600.00
0005433788231	20670	Economy	24600.00
0005433788207	20670	Economy	24600.00
0005433788211	20670	Economy	24600.00
0005433788206	20670	Economy	24600.00
0005435548565	20670	Economy	24600.00
0005433788246	20670	Economy	24600.00
0005435518003	11369	Business	20200.00
0005435517979	11369	Business	20200.00
0005435518013	11369	Business	20200.00
0005435518002	11369	Business	20200.00
0005435518062	11369	Business	20200.00
0005435541222	11369	Business	20200.00
0005435518009	11369	Economy	6700.00
0005435541167	11369	Economy	6700.00
0005435517955	11369	Economy	6700.00
0005435518065	11369	Economy	7400.00
0005435541181	11369	Economy	7400.00
0005435541110	11369	Economy	7400.00
0005435541057	11369	Economy	7400.00
0005435541144	11369	Economy	6700.00
0005435517978	11369	Economy	6700.00
0005435541086	11369	Economy	6700.00
0005435518077	11369	Economy	6700.00
0005435518066	11369	Economy	6700.00
0005435518076	11369	Economy	6700.00
0005435541154	11369	Economy	6700.00
0005435541182	11369	Economy	6700.00
0005435518064	11369	Economy	6700.00
0005435518082	11369	Economy	6700.00
0005435518080	11369	Economy	6700.00
0005435541213	11369	Economy	6700.00
0005435541130	11369	Economy	6700.00
0005435541111	11369	Economy	6700.00
0005435518014	11369	Economy	6700.00
0005435518020	11369	Economy	6700.00
0005435541163	11369	Economy	6700.00
0005435518018	11369	Economy	6700.00
0005435517961	11369	Economy	6700.00
0005435541132	11369	Economy	6700.00
0005435541155	11369	Economy	6700.00
0005435517991	11369	Economy	6700.00
0005435517992	11369	Economy	6700.00
0005435541214	11369	Economy	6700.00
0005435518054	11369	Economy	6700.00
0005435518004	11369	Economy	6700.00
0005435518010	11369	Economy	6700.00
0005435518019	11369	Economy	6700.00
0005435541237	11369	Economy	6700.00
0005435541212	11369	Economy	6700.00
0005435518081	11369	Economy	6700.00
0005435517977	11369	Economy	6700.00
0005435541056	11369	Economy	6700.00
0005435529566	22231	Business	20200.00
0005432294523	22231	Business	20200.00
0005435529573	22231	Business	20200.00
0005435541331	22231	Business	20200.00
0005435541326	22231	Business	20200.00
0005435529574	22231	Economy	6700.00
0005435529576	22231	Economy	6700.00
0005435529579	22231	Economy	6700.00
0005435541324	22231	Economy	6700.00
0005435529586	22231	Economy	6700.00
0005435541322	22231	Economy	6700.00
0005435529583	22231	Economy	7400.00
0005435541325	22231	Economy	7400.00
0005435541317	22231	Economy	7400.00
0005435529568	22231	Economy	7400.00
0005435541319	22231	Economy	6700.00
0005435541315	22231	Economy	6700.00
0005435529571	22231	Economy	6700.00
0005435541314	22231	Economy	6700.00
0005435541312	22231	Economy	6700.00
0005435541316	22231	Economy	6700.00
0005435529975	22231	Economy	6700.00
0005435541330	22231	Economy	6700.00
0005435541323	22231	Economy	6700.00
0005432294521	22231	Economy	6700.00
0005435529572	22231	Economy	6700.00
0005435529569	22231	Economy	6700.00
0005435529575	22231	Economy	6700.00
0005435529974	22231	Economy	6700.00
0005435529580	22231	Economy	6700.00
0005435529565	22231	Economy	6700.00
0005435529587	22231	Economy	6700.00
0005435529584	22231	Economy	6700.00
0005435541327	22231	Economy	6700.00
0005435529567	22231	Economy	6700.00
0005435541313	22231	Economy	6700.00
0005435529585	22231	Economy	6700.00
0005435541320	22231	Economy	6700.00
0005435529578	22231	Economy	6700.00
0005435529577	22231	Economy	6700.00
0005435541328	22231	Economy	6700.00
0005435529570	22231	Economy	6700.00
0005435541318	22231	Economy	6700.00
0005432294522	22231	Economy	6700.00
0005435541311	22231	Economy	6700.00
0005435529582	22231	Economy	6700.00
0005435541321	22231	Economy	6700.00
0005435529581	22231	Economy	6700.00
0005435541329	22231	Economy	6700.00
0005434908089	2290	Business	20200.00
0005434908108	2290	Business	20200.00
0005433251724	2290	Business	20200.00
0005434908090	2290	Business	20200.00
0005434908117	2290	Business	20200.00
0005434908075	2290	Business	20200.00
0005434908069	2290	Business	20200.00
0005433251714	2290	Business	20200.00
0005433401008	2290	Business	20200.00
0005434908071	2290	Business	20200.00
0005434908073	2290	Business	20200.00
0005434908122	2290	Economy	6700.00
0005434908110	2290	Economy	6700.00
0005433251733	2290	Economy	6700.00
0005433251571	2290	Economy	6700.00
0005434908084	2290	Economy	6700.00
0005434908106	2290	Economy	6700.00
0005433251699	2290	Economy	6700.00
0005433251616	2290	Economy	6700.00
0005434908115	2290	Economy	7400.00
0005434908080	2290	Economy	7400.00
0005434908076	2290	Economy	7400.00
0005433251598	2290	Economy	7400.00
0005433251654	2290	Economy	6700.00
0005433251787	2290	Economy	6700.00
0005434908121	2290	Economy	6700.00
0005434908116	2290	Economy	6700.00
0005434908125	2290	Economy	6700.00
0005434908085	2290	Economy	6700.00
0005433251536	2290	Economy	6700.00
0005433251769	2290	Economy	6700.00
0005434908077	2290	Economy	6700.00
0005434908113	2290	Economy	6700.00
0005434908099	2290	Economy	6700.00
0005434908100	2290	Economy	6700.00
0005434908097	2290	Economy	6700.00
0005433251768	2290	Economy	6700.00
0005434908091	2290	Economy	6700.00
0005434908079	2290	Economy	6700.00
0005434908092	2290	Economy	6700.00
0005433251700	2290	Economy	6700.00
0005434908088	2290	Economy	6700.00
0005434908074	2290	Economy	6700.00
0005434908103	2290	Economy	6700.00
0005434908081	2290	Economy	6700.00
0005433251679	2290	Economy	6700.00
0005434908078	2290	Economy	6700.00
0005433251698	2290	Economy	6700.00
0005434908094	2290	Economy	6700.00
0005434908120	2290	Economy	6700.00
0005433400991	2290	Economy	6700.00
0005434908109	2290	Economy	6700.00
0005433251764	2290	Economy	6700.00
0005434908101	2290	Economy	6700.00
0005434908119	2290	Economy	6700.00
0005434908102	2290	Economy	6700.00
0005434908093	2290	Economy	6700.00
0005433251675	2290	Economy	6700.00
0005434908123	2290	Economy	6700.00
0005434908087	2290	Economy	6700.00
0005434908124	2290	Economy	6700.00
0005434908112	2290	Economy	6700.00
0005434908083	2290	Economy	6700.00
0005433251676	2290	Economy	6700.00
0005434908105	2290	Economy	6700.00
0005434908118	2290	Economy	6700.00
0005434908082	2290	Economy	6700.00
0005433251756	2290	Economy	6700.00
0005434908107	2290	Economy	6700.00
0005434908114	2290	Economy	6700.00
0005433251744	2290	Economy	6700.00
0005433251832	2290	Economy	6700.00
0005434908070	2290	Economy	6700.00
0005433401005	2290	Economy	6700.00
0005433251738	2290	Economy	6700.00
0005434908072	2290	Economy	6700.00
0005434908095	2290	Economy	6700.00
0005434908111	2290	Economy	6700.00
0005434908098	2290	Economy	6700.00
0005434908096	2290	Economy	6700.00
0005433251765	2290	Economy	6700.00
0005433251879	2290	Economy	6700.00
0005434908086	2290	Economy	6700.00
0005434908104	2290	Economy	6700.00
0005433251966	25590	Business	20200.00
0005434907580	25590	Business	20200.00
0005434907693	25590	Business	20200.00
0005434907564	25590	Business	20200.00
0005433251951	25590	Business	20200.00
0005433251958	25590	Business	20200.00
0005434907500	25590	Business	20200.00
0005433251953	25590	Business	20200.00
0005434907522	25590	Business	20200.00
0005433251961	25590	Business	20200.00
0005434907606	25590	Business	20200.00
0005434907736	25590	Economy	6700.00
0005434907510	25590	Economy	6700.00
0005434907485	25590	Economy	6700.00
0005434907384	25590	Economy	6700.00
0005434907403	25590	Economy	6700.00
0005434907692	25590	Economy	6700.00
0005433251940	25590	Economy	6700.00
0005434907570	25590	Economy	6700.00
0005433251949	25590	Economy	6700.00
0005434907457	25590	Economy	6700.00
0005434907566	25590	Economy	7400.00
0005434907489	25590	Economy	7400.00
0005433251960	25590	Economy	7400.00
0005434907574	25590	Economy	7400.00
0005433251948	25590	Economy	7400.00
0005434907742	25590	Economy	6700.00
0005434907636	25590	Economy	6700.00
0005434907436	25590	Economy	6700.00
0005433251939	25590	Economy	6700.00
0005434907490	25590	Economy	6700.00
0005434907591	25590	Economy	6700.00
0005433251959	25590	Economy	6700.00
0005434907437	25590	Economy	6700.00
0005434907385	25590	Economy	6700.00
0005433401030	25590	Economy	6700.00
0005433251962	25590	Economy	6700.00
0005433251954	25590	Economy	6700.00
0005433251963	25590	Economy	6700.00
0005434907323	25590	Economy	6700.00
0005433251946	25590	Economy	6700.00
0005433251945	25590	Economy	6700.00
0005434907282	25590	Economy	6700.00
0005434907710	25590	Economy	6700.00
0005433251941	25590	Economy	6700.00
0005434907664	25590	Economy	6700.00
0005434907604	25590	Economy	6700.00
0005433251950	25590	Economy	6700.00
0005434907584	25590	Economy	6700.00
0005433251965	25590	Economy	6700.00
0005434907410	25590	Economy	6700.00
0005434907592	25590	Economy	6700.00
0005433251957	25590	Economy	6700.00
0005434907605	25590	Economy	6700.00
0005433251967	25590	Economy	6700.00
0005434907588	25590	Economy	6700.00
0005434907662	25590	Economy	6700.00
0005433251943	25590	Economy	6700.00
0005434907404	25590	Economy	6700.00
0005434907567	25590	Economy	6700.00
0005434907672	25590	Economy	6700.00
0005433251944	25590	Economy	6700.00
0005434907383	25590	Economy	6700.00
0005434907559	25590	Economy	6700.00
0005434907405	25590	Economy	6700.00
0005433251942	25590	Economy	6700.00
0005434907324	25590	Economy	6700.00
0005433251947	25590	Economy	6700.00
0005434907730	25590	Economy	6700.00
0005433251968	25590	Economy	6700.00
0005434907509	25590	Economy	6700.00
0005434907577	25590	Economy	6700.00
0005434907471	25590	Economy	6700.00
0005434907573	25590	Economy	6700.00
0005434907558	25590	Economy	6700.00
0005434907637	25590	Economy	6700.00
0005434907484	25590	Economy	6700.00
0005433251969	25590	Economy	6700.00
0005434907661	25590	Economy	6700.00
0005434907468	25590	Economy	6700.00
0005434907735	25590	Economy	6700.00
0005433251952	25590	Economy	6700.00
0005433251956	25590	Economy	6700.00
0005433251955	25590	Economy	6700.00
0005434907557	25590	Economy	6700.00
0005434907501	25590	Economy	6700.00
0005434907541	25590	Economy	6700.00
0005433401031	25590	Economy	6700.00
0005434907415	25590	Economy	6700.00
0005434907328	25590	Economy	6700.00
0005434907667	25590	Economy	6700.00
0005433251970	25590	Economy	6700.00
0005433251964	25590	Economy	6700.00
0005434907626	25590	Economy	6700.00
0005434907499	25590	Economy	6700.00
0005434907620	25590	Economy	6700.00
0005432862349	2510	Economy	13600.00
0005432621260	2510	Economy	13600.00
0005432862331	2510	Economy	13600.00
0005432862366	2510	Economy	13600.00
0005432862332	2510	Economy	12400.00
0005432621262	2510	Economy	12400.00
0005432621252	2510	Economy	12400.00
0005432862343	2510	Economy	12400.00
0005432862358	2510	Economy	12400.00
0005432621254	2510	Economy	12400.00
0005432862378	2510	Economy	12400.00
0005432621259	2510	Economy	12400.00
0005432621257	2510	Economy	12400.00
0005432621251	2510	Economy	12400.00
0005432621256	2510	Economy	12400.00
0005432621255	2510	Economy	12400.00
0005432621249	2510	Economy	12400.00
0005432621263	2510	Economy	12400.00
0005432621261	2510	Economy	12400.00
0005432621258	2510	Economy	12400.00
0005432621250	2510	Economy	12400.00
0005432621253	2510	Economy	12400.00
0005432862420	28060	Economy	13600.00
0005432862418	28060	Economy	12400.00
0005432621156	28060	Economy	12400.00
0005432621138	28060	Economy	12400.00
0005432862423	28060	Economy	12400.00
0005432621094	28060	Economy	12400.00
0005432621149	28060	Economy	12400.00
0005432621157	28060	Economy	12400.00
0005432862419	28060	Economy	12400.00
0005432862426	28060	Economy	12400.00
0005432621174	28060	Economy	12400.00
0005432862424	28060	Economy	12400.00
0005432621150	28060	Economy	12400.00
0005432862422	28060	Economy	12400.00
0005432621104	28060	Economy	12400.00
0005432621144	28060	Economy	12400.00
0005432862425	28060	Economy	12400.00
0005432621095	28060	Economy	12400.00
0005432621139	28060	Economy	12400.00
0005432862421	28060	Economy	12400.00
0005432621133	28060	Economy	12400.00
0005432621148	28060	Economy	12400.00
0005432621102	28060	Economy	12400.00
0005433452772	31017	Economy	8400.00
0005433452771	31017	Economy	8400.00
0005433451650	31017	Economy	8400.00
0005433454890	31365	Economy	8400.00
0005433454887	31365	Economy	8400.00
0005433454882	31365	Economy	8400.00
0005433452754	31365	Economy	8400.00
0005433454889	31365	Economy	8400.00
0005433452747	31365	Economy	8400.00
0005433454891	31365	Economy	8400.00
0005433129305	12021	Economy	7200.00
0005433129312	12021	Economy	6600.00
0005433129295	12021	Economy	6600.00
0005434184678	12021	Economy	6600.00
0005433134172	12021	Economy	6600.00
0005433134171	12021	Economy	6600.00
0005433129311	12021	Economy	6600.00
0005433134126	12021	Economy	6600.00
0005434184682	12021	Economy	6600.00
0005433129306	12021	Economy	6600.00
0005433129313	12021	Economy	6600.00
0005433129284	12021	Economy	6600.00
0005434184677	12021	Economy	6600.00
0005433131779	29847	Economy	7200.00
0005434183611	29847	Economy	6600.00
0005433134207	29847	Economy	6600.00
0005433131778	29847	Economy	6600.00
0005433134210	29847	Economy	6600.00
0005434142669	29847	Economy	6600.00
0005434142667	29847	Economy	6600.00
0005434183610	29847	Economy	6600.00
0005433131780	29847	Economy	6600.00
0005434142670	29847	Economy	6600.00
0005434142668	29847	Economy	6600.00
0005434142666	29847	Economy	6600.00
0005433134211	29847	Economy	6600.00
0005434184696	29847	Economy	6600.00
0005433134209	29847	Economy	6600.00
0005433134206	29847	Economy	6600.00
0005433131776	29847	Economy	6600.00
0005433134208	29847	Economy	6600.00
0005433131777	29847	Economy	6600.00
0005435935068	16443	Economy	19900.00
0005435697743	16443	Economy	19900.00
0005435697744	16443	Economy	19900.00
0005435697750	16443	Economy	19900.00
0005435697760	16443	Economy	18100.00
0005435697755	16443	Economy	18100.00
0005435697756	16443	Economy	18100.00
0005435697747	16443	Economy	18100.00
0005435697745	16443	Economy	18100.00
0005435697737	16443	Economy	18100.00
0005435697754	16443	Economy	18100.00
0005435697740	16443	Economy	18100.00
0005435697758	16443	Economy	18100.00
0005435697757	16443	Economy	18100.00
0005435697761	16443	Economy	18100.00
0005435697738	16443	Economy	18100.00
0005435697736	16443	Economy	18100.00
0005435697759	16443	Economy	18100.00
0005435935067	16443	Economy	18100.00
0005435697749	16443	Economy	18100.00
0005435697753	16443	Economy	18100.00
0005435697741	16443	Economy	18100.00
0005435697739	16443	Economy	18100.00
0005435697735	16443	Economy	18100.00
0005435697752	16443	Economy	18100.00
0005435935063	16443	Economy	18100.00
0005435697746	16443	Economy	18100.00
0005435697748	16443	Economy	18100.00
0005435697742	16443	Economy	18100.00
0005435697751	16443	Economy	18100.00
0005435697588	24694	Economy	19900.00
0005435697597	24694	Economy	18100.00
0005435697585	24694	Economy	18100.00
0005435697567	24694	Economy	18100.00
0005435697476	24694	Economy	18100.00
0005435697559	24694	Economy	18100.00
0005435697529	24694	Economy	18100.00
0005435697587	24694	Economy	18100.00
0005435697572	24694	Economy	18100.00
0005435697535	24694	Economy	18100.00
0005435697448	24694	Economy	18100.00
0005435697598	24694	Economy	18100.00
0005435697616	24694	Economy	18100.00
0005435697534	24694	Economy	18100.00
0005435935093	24694	Economy	18100.00
0005435697480	24694	Economy	18100.00
0005435935094	24694	Economy	18100.00
0005435697617	24694	Economy	18100.00
0005435697557	24694	Economy	18100.00
0005435697511	24694	Economy	18100.00
0005435697531	24694	Economy	18100.00
0005435697487	24694	Economy	18100.00
0005435697573	24694	Economy	18100.00
0005435697478	24694	Economy	18100.00
0005435697481	24694	Economy	18100.00
0005435697575	24694	Economy	18100.00
0005435697496	24694	Economy	18100.00
0005433724870	18771	Economy	4400.00
0005433724871	18771	Economy	4400.00
0005433724872	18771	Economy	4400.00
0005433724873	18771	Economy	4400.00
0005433724874	18771	Economy	4400.00
0005433724829	21617	Economy	4400.00
0005432968877	21617	Economy	4400.00
0005433724846	21617	Economy	4400.00
0005433724830	21617	Economy	4400.00
0005432968878	21617	Economy	4400.00
0005434139452	7324	Business	23100.00
0005434139414	7324	Business	23100.00
0005434139413	7324	Business	23100.00
0005434139461	7324	Business	23100.00
0005434139451	7324	Business	23100.00
0005434139460	7324	Business	23100.00
0005434139454	7324	Business	23100.00
0005434139434	7324	Business	23100.00
0005434139443	7324	Business	23100.00
0005434139401	7324	Business	23100.00
0005434139417	7324	Business	23100.00
0005434139399	7324	Business	23100.00
0005434139445	7324	Economy	7700.00
0005434139390	7324	Economy	7700.00
0005434139412	7324	Economy	7700.00
0005434139423	7324	Economy	7700.00
0005434139458	7324	Economy	7700.00
0005434139398	7324	Economy	7700.00
0005434139395	7324	Economy	7700.00
0005434139422	7324	Economy	7700.00
0005434139393	7324	Economy	7700.00
0005434139442	7324	Economy	8500.00
0005434139459	7324	Economy	8500.00
0005434139424	7324	Economy	8500.00
0005434139387	7324	Economy	8500.00
0005434139415	7324	Economy	8500.00
0005434139456	7324	Economy	7700.00
0005434139388	7324	Economy	7700.00
0005434139428	7324	Economy	7700.00
0005434139462	7324	Economy	7700.00
0005434139416	7324	Economy	7700.00
0005434139397	7324	Economy	7700.00
0005434139449	7324	Economy	7700.00
0005434139407	7324	Economy	7700.00
0005434139418	7324	Economy	7700.00
0005434139384	7324	Economy	7700.00
0005434139410	7324	Economy	7700.00
0005434139437	7324	Economy	7700.00
0005434139440	7324	Economy	7700.00
0005434139394	7324	Economy	7700.00
0005434139386	7324	Economy	7700.00
0005434139404	7324	Economy	7700.00
0005434139457	7324	Economy	7700.00
0005434139433	7324	Economy	7700.00
0005434139450	7324	Economy	7700.00
0005434139448	7324	Economy	7700.00
0005434139431	7324	Economy	7700.00
0005434139402	7324	Economy	7700.00
0005434139392	7324	Economy	7700.00
0005434139403	7324	Economy	7700.00
0005434139453	7324	Economy	7700.00
0005434139421	7324	Economy	7700.00
0005434139408	7324	Economy	7700.00
0005434139405	7324	Economy	7700.00
0005434139426	7324	Economy	7700.00
0005434139436	7324	Economy	7700.00
0005434087588	7324	Economy	7700.00
0005434139391	7324	Economy	7700.00
0005434087589	7324	Economy	7700.00
0005434139427	7324	Economy	7700.00
0005434139406	7324	Economy	7700.00
0005434139435	7324	Economy	7700.00
0005434139446	7324	Economy	7700.00
0005434139455	7324	Economy	7700.00
0005434139389	7324	Economy	7700.00
0005434139400	7324	Economy	7700.00
0005434087590	7324	Economy	7700.00
0005434139429	7324	Economy	7700.00
0005434139439	7324	Economy	7700.00
0005434139444	7324	Economy	7700.00
0005434139420	7324	Economy	7700.00
0005434139383	7324	Economy	7700.00
0005434139419	7324	Economy	7700.00
0005434139425	7324	Economy	7700.00
0005434139409	7324	Economy	7700.00
0005434139441	7324	Economy	7700.00
0005434139438	7324	Economy	7700.00
0005434139396	7324	Economy	7700.00
0005434139411	7324	Economy	7700.00
0005434139432	7324	Economy	7700.00
0005434139447	7324	Economy	7700.00
0005434139385	7324	Economy	7700.00
0005434139430	7324	Economy	7700.00
0005434087591	7324	Economy	7700.00
0005434087544	28583	Business	23100.00
0005434138432	28583	Business	23100.00
0005434138410	28583	Business	23100.00
0005434138784	28583	Business	23100.00
0005434138420	28583	Business	23100.00
0005434087568	28583	Business	23100.00
0005434138472	28583	Business	23100.00
0005434138799	28583	Business	23100.00
0005434138536	28583	Business	23100.00
0005434138578	28583	Business	23100.00
0005434138776	28583	Business	23100.00
0005434138832	28583	Economy	7700.00
0005434138591	28583	Economy	7700.00
0005434138870	28583	Economy	7700.00
0005434138644	28583	Economy	7700.00
0005434138727	28583	Economy	7700.00
0005434139108	28583	Economy	7700.00
0005434138972	28583	Economy	7700.00
0005434138893	28583	Economy	7700.00
0005434138777	28583	Economy	7700.00
0005434087559	28583	Economy	7700.00
0005434138728	28583	Economy	8500.00
0005434138951	28583	Economy	8500.00
0005434138587	28583	Economy	8500.00
0005434138677	28583	Economy	8500.00
0005434138720	28583	Economy	8500.00
0005434138569	28583	Economy	7700.00
0005434087551	28583	Economy	7700.00
0005434138973	28583	Economy	7700.00
0005434138785	28583	Economy	7700.00
0005434138598	28583	Economy	7700.00
0005434087556	28583	Economy	7700.00
0005434138476	28583	Economy	7700.00
0005434138433	28583	Economy	7700.00
0005434138248	28583	Economy	7700.00
0005434138412	28583	Economy	7700.00
0005434138576	28583	Economy	7700.00
0005434138577	28583	Economy	7700.00
0005434138613	28583	Economy	7700.00
0005434138750	28583	Economy	7700.00
0005434138550	28583	Economy	7700.00
0005434138556	28583	Economy	7700.00
0005434138670	28583	Economy	7700.00
0005434138860	28583	Economy	7700.00
0005434138717	28583	Economy	7700.00
0005434138215	28583	Economy	7700.00
0005434138774	28583	Economy	7700.00
0005434138869	28583	Economy	7700.00
0005434138952	28583	Economy	7700.00
0005434138597	28583	Economy	7700.00
0005434138590	28583	Economy	7700.00
0005434138891	28583	Economy	7700.00
0005434087560	28583	Economy	7700.00
0005434087537	28583	Economy	7700.00
0005434138864	28583	Economy	7700.00
0005434138861	28583	Economy	7700.00
0005434138530	28583	Economy	7700.00
0005434138409	28583	Economy	7700.00
0005434138473	28583	Economy	7700.00
0005434138475	28583	Economy	7700.00
0005434138669	28583	Economy	7700.00
0005434138492	28583	Economy	7700.00
0005434138192	28583	Economy	7700.00
0005434138411	28583	Economy	7700.00
0005434138713	28583	Economy	7700.00
0005434138865	28583	Economy	7700.00
0005434138421	28583	Economy	7700.00
0005434138447	28583	Economy	7700.00
0005434138549	28583	Economy	7700.00
0005434138405	28583	Economy	7700.00
0005434138662	28583	Economy	7700.00
0005434138623	28583	Economy	7700.00
0005434139080	28583	Economy	7700.00
0005434138888	28583	Economy	7700.00
0005434138746	28583	Economy	7700.00
0005434138997	28583	Economy	7700.00
0005434138560	28583	Economy	7700.00
0005434087555	28583	Economy	7700.00
0005434138555	28583	Economy	7700.00
0005434138996	28583	Economy	7700.00
0005434138672	28583	Economy	7700.00
0005434138443	28583	Economy	7700.00
0005434138866	28583	Economy	7700.00
0005434138406	28583	Economy	7700.00
0005434138548	28583	Economy	7700.00
0005434138652	28583	Economy	7700.00
0005434138712	28583	Economy	7700.00
0005434138624	28583	Economy	7700.00
0005434138538	28583	Economy	7700.00
0005434138537	28583	Economy	7700.00
0005434138968	28583	Economy	7700.00
0005435808399	1935	Economy	21700.00
0005434610283	1935	Economy	21700.00
0005433407595	1935	Economy	21700.00
0005435808397	1935	Economy	21700.00
0005435808392	1935	Economy	21700.00
0005433407596	1935	Economy	21700.00
0005433407600	1935	Economy	21700.00
0005435808394	1935	Economy	21700.00
0005434610285	1935	Economy	21700.00
0005433407591	1935	Economy	21700.00
0005434610286	1935	Economy	21700.00
0005434610284	1935	Economy	21700.00
0005435808396	1935	Economy	21700.00
0005435808400	1935	Economy	21700.00
0005433407608	1935	Economy	21700.00
0005435808398	1935	Economy	21700.00
0005433407590	1935	Economy	21700.00
0005435808391	1935	Economy	21700.00
0005435808395	1935	Economy	21700.00
0005435808393	1935	Economy	21700.00
0005434610244	23098	Economy	23900.00
0005434610246	23098	Economy	21700.00
0005434610245	23098	Economy	21700.00
0005434504486	16672	Economy	7600.00
0005434504376	16672	Economy	7600.00
0005434504196	16672	Economy	7600.00
0005434504363	16672	Economy	7600.00
0005434504448	16672	Economy	6900.00
0005434504524	16672	Economy	6900.00
0005434504417	16672	Economy	6900.00
0005434504504	16672	Economy	6900.00
0005434504233	16672	Economy	6900.00
0005434504501	16672	Economy	6900.00
0005434504413	16672	Economy	6900.00
0005434504197	16672	Economy	6900.00
0005434504424	16672	Economy	6900.00
0005434504335	16672	Economy	6900.00
0005434504351	16672	Economy	6900.00
0005434504336	16672	Economy	6900.00
0005434504453	16672	Economy	6900.00
0005434504073	16672	Economy	6900.00
0005434504482	16672	Economy	6900.00
0005434504521	16672	Economy	6900.00
0005434504230	16672	Economy	6900.00
0005434504481	16672	Economy	6900.00
0005434504622	16672	Economy	6900.00
0005434504384	16672	Economy	6900.00
0005434504072	16672	Economy	6900.00
0005434504503	16672	Economy	6900.00
0005434504199	16672	Economy	6900.00
0005434504326	16672	Economy	6900.00
0005434504442	16672	Economy	6900.00
0005434504198	16672	Economy	6900.00
0005434504419	16672	Economy	6900.00
0005434504541	16672	Economy	6900.00
0005434504364	16672	Economy	6900.00
0005434504523	16672	Economy	6900.00
0005434504542	16672	Economy	6900.00
0005434504318	16672	Economy	6900.00
0005434504478	16672	Economy	6900.00
0005434504732	22886	Economy	7600.00
0005434504708	22886	Economy	7600.00
0005434504716	22886	Economy	6900.00
0005434504707	22886	Economy	6900.00
0005434504704	22886	Economy	6900.00
0005434504739	22886	Economy	6900.00
0005434504719	22886	Economy	6900.00
0005434504744	22886	Economy	6900.00
0005434504722	22886	Economy	6900.00
0005434504741	22886	Economy	6900.00
0005434504723	22886	Economy	6900.00
0005434504720	22886	Economy	6900.00
0005434504728	22886	Economy	6900.00
0005434504713	22886	Economy	6900.00
0005434504734	22886	Economy	6900.00
0005434504736	22886	Economy	6900.00
0005434504711	22886	Economy	6900.00
0005434504706	22886	Economy	6900.00
0005434504730	22886	Economy	6900.00
0005434504737	22886	Economy	6900.00
0005434504733	22886	Economy	6900.00
0005434504714	22886	Economy	6900.00
0005434504724	22886	Economy	6900.00
0005434504709	22886	Economy	6900.00
0005434504729	22886	Economy	6900.00
0005434504725	22886	Economy	6900.00
0005434504718	22886	Economy	6900.00
0005434504715	22886	Economy	6900.00
0005434504731	22886	Economy	6900.00
0005434504710	22886	Economy	6900.00
0005434504705	22886	Economy	6900.00
0005434504742	22886	Economy	6900.00
0005434504727	22886	Economy	6900.00
0005434504717	22886	Economy	6900.00
0005434504721	22886	Economy	6900.00
0005434504712	22886	Economy	6900.00
0005434504735	22886	Economy	6900.00
0005434504726	22886	Economy	6900.00
0005434504738	22886	Economy	6900.00
0005434504740	22886	Economy	6900.00
0005434504743	22886	Economy	6900.00
0005435078574	2206	Economy	7700.00
0005435078575	2206	Economy	7000.00
0005433266794	2206	Economy	7000.00
0005435078578	2206	Economy	7000.00
0005435078584	2206	Economy	7000.00
0005435078579	2206	Economy	7000.00
0005433266773	2206	Economy	7000.00
0005435078576	2206	Economy	7000.00
0005435078582	2206	Economy	7000.00
0005435078580	2206	Economy	7000.00
0005433266780	2206	Economy	7000.00
0005435078583	2206	Economy	7000.00
0005435078587	2206	Economy	7000.00
0005435078586	2206	Economy	7000.00
0005433266781	2206	Economy	7000.00
0005433266775	2206	Economy	7000.00
0005435078588	2206	Economy	7000.00
0005435078573	2206	Economy	7000.00
0005433266797	2206	Economy	7000.00
0005435078585	2206	Economy	7000.00
0005435078581	2206	Economy	7000.00
0005435078577	2206	Economy	7000.00
0005433266863	24338	Economy	7700.00
0005433266871	24338	Economy	7700.00
0005435078453	24338	Economy	7000.00
0005435078448	24338	Economy	7000.00
0005435078500	24338	Economy	7000.00
0005435078468	24338	Economy	7000.00
0005435078486	24338	Economy	7000.00
0005433266866	24338	Economy	7000.00
0005433266867	24338	Economy	7000.00
0005433266868	24338	Economy	7000.00
0005435078439	24338	Economy	7000.00
0005435078494	24338	Economy	7000.00
0005435078449	24338	Economy	7000.00
0005435078469	24338	Economy	7000.00
0005435078463	24338	Economy	7000.00
0005435078458	24338	Economy	7000.00
0005435078474	24338	Economy	7000.00
0005433266865	24338	Economy	7000.00
0005435078480	24338	Economy	7000.00
0005435078501	24338	Economy	7000.00
0005433266864	24338	Economy	7000.00
0005433266862	24338	Economy	7000.00
0005433266870	24338	Economy	7000.00
0005435078505	24338	Economy	7000.00
0005435078499	24338	Economy	7000.00
0005435078457	24338	Economy	7000.00
0005435078464	24338	Economy	7000.00
0005433266869	24338	Economy	7000.00
0005435078485	24338	Economy	7000.00
0005434988908	6653	Economy	9800.00
0005434988909	6653	Economy	9800.00
0005434988905	6653	Economy	9800.00
0005435464518	6653	Economy	9800.00
0005434988903	6653	Economy	9800.00
0005434988906	6653	Economy	9800.00
0005434988907	6653	Economy	9800.00
0005435803307	6653	Economy	9800.00
0005435464516	6653	Economy	9800.00
0005434988911	6653	Economy	9800.00
0005435803305	6653	Economy	9800.00
0005434988910	6653	Economy	9800.00
0005435464517	6653	Economy	9800.00
0005434988900	6653	Economy	9800.00
0005434988902	6653	Economy	9800.00
0005434988904	6653	Economy	9800.00
0005435803306	6653	Economy	9800.00
0005435464521	6653	Economy	9800.00
0005434988901	6653	Economy	9800.00
0005435803294	23628	Economy	10800.00
0005434988785	23628	Economy	10800.00
0005434988783	23628	Economy	10800.00
0005434988793	23628	Economy	9800.00
0005434988780	23628	Economy	9800.00
0005435803276	23628	Economy	9800.00
0005434988761	23628	Economy	9800.00
0005434988767	23628	Economy	9800.00
0005435464540	23628	Economy	9800.00
0005435464541	23628	Economy	9800.00
0005434988797	23628	Economy	9800.00
0005434988781	23628	Economy	9800.00
0005434988789	23628	Economy	9800.00
0005434988796	23628	Economy	9800.00
0005434988784	23628	Economy	9800.00
0005435803279	23628	Economy	9800.00
0005434988768	23628	Economy	9800.00
0005435803291	23628	Economy	9800.00
0005435803275	23628	Economy	9800.00
0005434988790	23628	Economy	9800.00
0005435803283	23628	Economy	9800.00
0005434988782	23628	Economy	9800.00
0005434988773	23628	Economy	9800.00
0005434988779	23628	Economy	9800.00
0005434988760	23628	Economy	9800.00
0005432383782	30487	Business	9900.00
0005433450309	30487	Business	9900.00
0005432383758	30487	Business	9900.00
0005432383770	30487	Business	9900.00
0005432383783	30487	Business	9900.00
0005432383753	30487	Business	9900.00
0005432383756	30487	Business	9900.00
0005433450312	30487	Business	9900.00
0005432383766	30487	Business	9900.00
0005433450316	30487	Business	9900.00
0005433453792	30487	Business	9900.00
0005432383774	30487	Economy	3300.00
0005432383759	30487	Economy	3300.00
0005432383752	30487	Economy	3300.00
0005432383764	30487	Economy	3300.00
0005432383769	30487	Economy	3300.00
0005433450301	30487	Economy	3300.00
0005432383754	30487	Economy	3300.00
0005432383788	30487	Economy	3600.00
0005432383787	30487	Economy	3600.00
0005433450298	30487	Economy	3600.00
0005432383791	30487	Economy	3600.00
0005432383781	30487	Economy	3300.00
0005433450304	30487	Economy	3300.00
0005433450299	30487	Economy	3300.00
0005432383784	30487	Economy	3300.00
0005432383750	30487	Economy	3300.00
0005433450305	30487	Economy	3300.00
0005433450317	30487	Economy	3300.00
0005433450300	30487	Economy	3300.00
0005432383768	30487	Economy	3300.00
0005433450307	30487	Economy	3300.00
0005432383767	30487	Economy	3300.00
0005432383760	30487	Economy	3300.00
0005432383778	30487	Economy	3300.00
0005433450313	30487	Economy	3300.00
0005432383757	30487	Economy	3300.00
0005433453793	30487	Economy	3300.00
0005432383789	30487	Economy	3300.00
0005432383755	30487	Economy	3300.00
0005432383779	30487	Economy	3300.00
0005433450308	30487	Economy	3300.00
0005432383790	30487	Economy	3300.00
0005433454909	30487	Economy	3300.00
0005433453791	30487	Economy	3300.00
0005433450303	30487	Economy	3300.00
0005432383773	30487	Economy	3300.00
0005433450310	30487	Economy	3300.00
0005432383761	30487	Economy	3300.00
0005432383776	30487	Economy	3300.00
0005433450297	30487	Economy	3300.00
0005433450302	30487	Economy	3300.00
0005432383763	30487	Economy	3300.00
0005432383751	30487	Economy	3300.00
0005432383785	30487	Economy	3300.00
0005433450311	30487	Economy	3300.00
0005432383762	30487	Economy	3300.00
0005433453790	30487	Economy	3300.00
0005433450314	30487	Economy	3300.00
0005432383765	30487	Economy	3300.00
0005433450318	30487	Economy	3300.00
0005433450306	30487	Economy	3300.00
0005432383777	30487	Economy	3300.00
0005432383775	30487	Economy	3300.00
0005432383772	30487	Economy	3300.00
0005433450315	30487	Economy	3300.00
0005432383771	30487	Economy	3300.00
0005432383786	30487	Economy	3300.00
0005432383780	30487	Economy	3300.00
0005433454908	30487	Economy	3300.00
0005432383300	31326	Business	9900.00
0005432383303	31326	Business	9900.00
0005433450131	31326	Business	9900.00
0005432383381	31326	Business	9900.00
0005433450121	31326	Business	9900.00
0005432383380	31326	Business	9900.00
0005432383398	31326	Business	9900.00
0005432383536	31326	Business	9900.00
0005433450134	31326	Economy	3300.00
0005432383394	31326	Economy	3300.00
0005432383281	31326	Economy	3300.00
0005432383317	31326	Economy	3300.00
0005432383404	31326	Economy	3300.00
0005432383210	31326	Economy	3300.00
0005432383412	31326	Economy	3300.00
0005433450141	31326	Economy	3300.00
0005432383374	31326	Economy	3600.00
0005432383457	31326	Economy	3600.00
0005432383379	31326	Economy	3300.00
0005432383247	31326	Economy	3300.00
0005433450016	31326	Economy	3300.00
0005432383397	31326	Economy	3300.00
0005432383212	31326	Economy	3300.00
0005432383382	31326	Economy	3300.00
0005432383466	31326	Economy	3300.00
0005432383293	31326	Economy	3300.00
0005432383299	31326	Economy	3300.00
0005432383455	31326	Economy	3300.00
0005432383346	31326	Economy	3300.00
0005432383369	31326	Economy	3300.00
0005432383456	31326	Economy	3300.00
0005433450149	31326	Economy	3300.00
0005433450177	31326	Economy	3300.00
0005432383420	31326	Economy	3300.00
0005433450178	31326	Economy	3300.00
0005433453780	31326	Economy	3300.00
0005433450191	31326	Economy	3300.00
0005433451635	31326	Economy	3300.00
0005432383301	31326	Economy	3300.00
0005433450110	31326	Economy	3300.00
0005433451634	31326	Economy	3300.00
0005432383316	31326	Economy	3300.00
0005432383516	31326	Economy	3300.00
0005433450147	31326	Economy	3300.00
0005432383334	31326	Economy	3300.00
0005432383406	31326	Economy	3300.00
0005432383471	31326	Economy	3300.00
0005433450146	31326	Economy	3300.00
0005432383419	31326	Economy	3300.00
0005432383304	31326	Economy	3300.00
0005432383534	31326	Economy	3300.00
0005432383535	31326	Economy	3300.00
0005433450109	31326	Economy	3300.00
0005432383280	31326	Economy	3300.00
0005432383286	31326	Economy	3300.00
0005432383347	31326	Economy	3300.00
0005432383209	31326	Economy	3300.00
0005432383352	31326	Economy	3300.00
0005433453781	31326	Economy	3300.00
0005432383378	31326	Economy	3300.00
0005433450176	31326	Economy	3300.00
0005432383405	31326	Economy	3300.00
0005433450145	31326	Economy	3300.00
0005432383373	31326	Economy	3300.00
0005432383517	31326	Economy	3300.00
0005432383413	31326	Economy	3300.00
0005435548567	26477	Economy	26200.00
0005435548565	26477	Economy	23800.00
0005435548564	26477	Economy	23800.00
0005433788246	26477	Economy	23800.00
0005435548562	26477	Economy	23800.00
0005433788223	26477	Economy	23800.00
0005433788234	26477	Economy	23800.00
0005435548569	26477	Economy	23800.00
0005433788248	26477	Economy	23800.00
0005435548561	26477	Economy	23800.00
0005433788247	26477	Economy	23800.00
0005435548570	26477	Economy	23800.00
0005435548563	26477	Economy	23800.00
0005435548566	26477	Economy	23800.00
0005435548568	26477	Economy	23800.00
0005433126856	10795	Economy	15600.00
0005435304180	10795	Economy	15600.00
0005433131730	10795	Economy	15600.00
0005433126876	10795	Economy	15600.00
0005433126879	10795	Economy	15600.00
0005435299800	10795	Economy	15600.00
0005435299806	10795	Economy	15600.00
0005433126868	10795	Economy	15600.00
0005435299799	10795	Economy	15600.00
0005433126867	10795	Economy	15600.00
0005433126857	10795	Economy	15600.00
0005433126878	10795	Economy	15600.00
0005433126877	10795	Economy	15600.00
0005435299790	10795	Economy	15600.00
0005435304179	10795	Economy	15600.00
0005433126862	10795	Economy	15600.00
0005435302273	29715	Economy	17100.00
0005433129351	29715	Economy	15600.00
0005433126921	29715	Economy	15600.00
0005435299852	29715	Economy	15600.00
0005435299855	29715	Economy	15600.00
0005433129352	29715	Economy	15600.00
0005435299853	29715	Economy	15600.00
0005435302276	29715	Economy	15600.00
0005435302277	29715	Economy	15600.00
0005433129349	29715	Economy	15600.00
0005435299854	29715	Economy	15600.00
0005433126918	29715	Economy	15600.00
0005433126919	29715	Economy	15600.00
0005435302274	29715	Economy	15600.00
0005435302275	29715	Economy	15600.00
0005435299851	29715	Economy	15600.00
0005433126920	29715	Economy	15600.00
0005433129348	29715	Economy	15600.00
0005433129350	29715	Economy	15600.00
0005433126917	29715	Economy	15600.00
0005434287628	2389	Economy	17200.00
0005434287630	2389	Economy	17200.00
0005433110165	2389	Economy	17200.00
0005434287620	2389	Economy	15700.00
0005433110147	2389	Economy	15700.00
0005433110162	2389	Economy	15700.00
0005434287642	2389	Economy	15700.00
0005433110085	2389	Economy	15700.00
0005432264512	2389	Economy	15700.00
0005434287633	2389	Economy	15700.00
0005433110220	2389	Economy	15700.00
0005434287640	2389	Economy	15700.00
0005433110154	2389	Economy	15700.00
0005432264513	2389	Economy	15700.00
0005433110088	2389	Economy	15700.00
0005434287621	2389	Economy	15700.00
0005434287626	2389	Economy	15700.00
0005433110132	2389	Economy	15700.00
0005432264514	2389	Economy	15700.00
0005433110119	2389	Economy	15700.00
0005433110129	2389	Economy	15700.00
0005434287624	2389	Economy	15700.00
0005433110155	2389	Economy	15700.00
0005433110160	2389	Economy	15700.00
0005433110124	2389	Economy	15700.00
0005434287625	2389	Economy	15700.00
0005434287634	2389	Economy	15700.00
0005434287638	2389	Economy	15700.00
0005434287632	2389	Economy	15700.00
0005434287636	2389	Economy	15700.00
0005434287635	2389	Economy	15700.00
0005433110150	2389	Economy	15700.00
0005434287623	2389	Economy	15700.00
0005434287627	2389	Economy	15700.00
0005434287629	2389	Economy	15700.00
0005433110084	2389	Economy	15700.00
0005434287641	2389	Economy	15700.00
0005434287622	2389	Economy	15700.00
0005434287639	2389	Economy	15700.00
0005434287631	2389	Economy	15700.00
0005432264515	2389	Economy	15700.00
0005434287637	2389	Economy	15700.00
0005433110157	2389	Economy	15700.00
0005433110118	2389	Economy	15700.00
0005433110153	2389	Economy	15700.00
0005433110121	2389	Economy	15700.00
0005433110156	2389	Economy	15700.00
0005433110219	2389	Economy	15700.00
0005434287394	26851	Economy	17200.00
0005434287357	26851	Economy	17200.00
0005434287477	26851	Economy	17200.00
0005433110246	26851	Economy	15700.00
0005433110242	26851	Economy	15700.00
0005433110238	26851	Economy	15700.00
0005434287511	26851	Economy	15700.00
0005434287437	26851	Economy	15700.00
0005434287358	26851	Economy	15700.00
0005433110235	26851	Economy	15700.00
0005433110240	26851	Economy	15700.00
0005434287438	26851	Economy	15700.00
0005434287389	26851	Economy	15700.00
0005434287356	26851	Economy	15700.00
0005433110241	26851	Economy	15700.00
0005434287444	26851	Economy	15700.00
0005434287406	26851	Economy	15700.00
0005434287462	26851	Economy	15700.00
0005434287443	26851	Economy	15700.00
0005433110237	26851	Economy	15700.00
0005434287412	26851	Economy	15700.00
0005433110244	26851	Economy	15700.00
0005434287341	26851	Economy	15700.00
0005433110236	26851	Economy	15700.00
0005434287445	26851	Economy	15700.00
0005434287448	26851	Economy	15700.00
0005434287451	26851	Economy	15700.00
0005434287432	26851	Economy	15700.00
0005434287465	26851	Economy	15700.00
0005434287407	26851	Economy	15700.00
0005434287442	26851	Economy	15700.00
0005434287479	26851	Economy	15700.00
0005434287475	26851	Economy	15700.00
0005434287510	26851	Economy	15700.00
0005434287452	26851	Economy	15700.00
0005434287430	26851	Economy	15700.00
0005433110239	26851	Economy	15700.00
0005433110245	26851	Economy	15700.00
0005434287476	26851	Economy	15700.00
0005433110243	26851	Economy	15700.00
0005434287453	26851	Economy	15700.00
0005434287395	26851	Economy	15700.00
0005434287449	26851	Economy	15700.00
0005434287463	26851	Economy	15700.00
0005434287520	26851	Economy	15700.00
0005434287439	26851	Economy	15700.00
0005434287518	26851	Economy	15700.00
0005434287514	26851	Economy	15700.00
0005434272207	25473	Economy	25000.00
0005435856270	25473	Economy	22800.00
0005434272206	25473	Economy	22800.00
0005435856269	25473	Economy	22800.00
0005435856271	25473	Economy	22800.00
0005434272200	25473	Economy	22800.00
0005435856268	25473	Economy	22800.00
0005435856272	25473	Economy	22800.00
0005434272215	26664	Economy	25000.00
0005435856216	26664	Economy	22800.00
0005434272213	26664	Economy	22800.00
0005434272214	26664	Economy	22800.00
0005435856220	26664	Economy	22800.00
0005435856215	26664	Economy	22800.00
0005435856224	26664	Economy	22800.00
0005435856214	26664	Economy	22800.00
0005435856219	26664	Economy	22800.00
0005434273103	26664	Economy	22800.00
0005434273102	26664	Economy	22800.00
0005434520320	19073	Economy	24600.00
0005434520323	19073	Economy	24600.00
0005435314899	19073	Economy	24600.00
0005434520315	19073	Economy	24600.00
0005434520292	19073	Economy	22300.00
0005435314896	19073	Economy	22300.00
0005434520277	19073	Economy	22300.00
0005434520305	19073	Economy	22300.00
0005434520308	19073	Economy	22300.00
0005434520285	19073	Economy	22300.00
0005434520274	19073	Economy	22300.00
0005435314893	19073	Economy	22300.00
0005435314884	19073	Economy	22300.00
0005434520312	19073	Economy	22300.00
0005434520306	19073	Economy	22300.00
0005434520294	19073	Economy	22300.00
0005434520329	19073	Economy	22300.00
0005435314894	19073	Economy	22300.00
0005435314886	19073	Economy	22300.00
0005435314888	19073	Economy	22300.00
0005434520275	19073	Economy	22300.00
0005434520327	19073	Economy	22300.00
0005434520284	19073	Economy	22300.00
0005435314889	19073	Economy	22300.00
0005435314890	19073	Economy	22300.00
0005434520297	19073	Economy	22300.00
0005435314892	19073	Economy	22300.00
0005434520330	19073	Economy	22300.00
0005434520272	19073	Economy	22300.00
0005435314885	19073	Economy	22300.00
0005435314887	19073	Economy	22300.00
0005434520291	19073	Economy	22300.00
0005434520289	19073	Economy	22300.00
0005434520298	19073	Economy	22300.00
0005434520256	19073	Economy	22300.00
0005435314898	19073	Economy	22300.00
0005434520314	19073	Economy	22300.00
0005434520328	19073	Economy	22300.00
0005434520309	19073	Economy	22300.00
0005434520286	19073	Economy	22300.00
0005435314897	19073	Economy	22300.00
0005435314891	19073	Economy	22300.00
0005434520326	19073	Economy	22300.00
0005434520296	19073	Economy	22300.00
0005434520264	19073	Economy	22300.00
0005435314895	19073	Economy	22300.00
0005434520293	19073	Economy	22300.00
0005434520295	19073	Economy	22300.00
0005434520278	19073	Economy	22300.00
0005434520304	19073	Economy	22300.00
0005433874402	7792	Economy	19200.00
0005433874404	7792	Economy	19200.00
0005433874408	7792	Economy	19200.00
0005433874398	7792	Economy	17400.00
0005433874403	7792	Economy	17400.00
0005433874409	7792	Economy	17400.00
0005433874400	7792	Economy	17400.00
0005433874406	7792	Economy	17400.00
0005433874401	7792	Economy	17400.00
0005433874396	7792	Economy	17400.00
0005433874399	7792	Economy	17400.00
0005433874410	7792	Economy	17400.00
0005433874405	7792	Economy	17400.00
0005433874407	7792	Economy	17400.00
0005433874397	7792	Economy	17400.00
0005433874369	32639	Economy	19200.00
0005433874382	32639	Economy	19200.00
0005433874372	32639	Economy	19200.00
0005433874361	32639	Economy	17400.00
0005433874367	32639	Economy	17400.00
0005433874380	32639	Economy	17400.00
0005433874370	32639	Economy	17400.00
0005433874362	32639	Economy	17400.00
0005433874381	32639	Economy	17400.00
0005433874379	32639	Economy	17400.00
0005433874366	32639	Economy	17400.00
0005433874375	32639	Economy	17400.00
0005433874374	32639	Economy	17400.00
0005433874365	32639	Economy	17400.00
0005433874384	32639	Economy	17400.00
0005433874373	32639	Economy	17400.00
0005433874383	32639	Economy	17400.00
0005433874378	32639	Economy	17400.00
0005433874393	32639	Economy	17400.00
0005433874371	32639	Economy	17400.00
0005433874368	32639	Economy	17400.00
0005433874392	32639	Economy	17400.00
0005433874377	32639	Economy	17400.00
0005433874360	32639	Economy	17400.00
0005433869055	4780	Economy	19400.00
0005433869054	4780	Economy	19400.00
0005433869049	4780	Economy	19400.00
0005433869061	4780	Economy	19400.00
0005433869042	4780	Economy	17600.00
0005433869046	4780	Economy	17600.00
0005433869053	4780	Economy	17600.00
0005433869069	4780	Economy	17600.00
0005433869052	4780	Economy	17600.00
0005433869044	4780	Economy	17600.00
0005433869060	4780	Economy	17600.00
0005433869076	4780	Economy	17600.00
0005433869040	4780	Economy	17600.00
0005433869047	4780	Economy	17600.00
0005433869068	4780	Economy	17600.00
0005433869058	4780	Economy	17600.00
0005433869063	4780	Economy	17600.00
0005433869045	4780	Economy	17600.00
0005433869067	4780	Economy	17600.00
0005433869066	4780	Economy	17600.00
0005433869039	4780	Economy	17600.00
0005433869070	4780	Economy	17600.00
0005435860502	4780	Economy	17600.00
0005433869075	4780	Economy	17600.00
0005433869051	4780	Economy	17600.00
0005433869038	4780	Economy	17600.00
0005433869065	4780	Economy	17600.00
0005433869059	4780	Economy	17600.00
0005433869048	4780	Economy	17600.00
0005433869043	4780	Economy	17600.00
0005433869057	4780	Economy	17600.00
0005433869056	4780	Economy	17600.00
0005433869064	4780	Economy	17600.00
0005433869078	4780	Economy	17600.00
0005433869074	4780	Economy	17600.00
0005433869077	4780	Economy	17600.00
0005433869062	4780	Economy	17600.00
0005435860503	4780	Economy	17600.00
0005433869041	4780	Economy	17600.00
0005433869073	4780	Economy	17600.00
0005433869050	4780	Economy	17600.00
0005433869071	4780	Economy	17600.00
0005433869072	4780	Economy	17600.00
0005435860530	32602	Economy	19400.00
0005435860531	32602	Economy	19400.00
0005435860540	32602	Economy	19400.00
0005435860536	32602	Economy	17600.00
0005435860539	32602	Economy	17600.00
0005433868665	32602	Economy	17600.00
0005435860534	32602	Economy	17600.00
0005433868646	32602	Economy	17600.00
0005433868498	32602	Economy	17600.00
0005433868805	32602	Economy	17600.00
0005433868662	32602	Economy	17600.00
0005433868648	32602	Economy	17600.00
0005435860537	32602	Economy	17600.00
0005433868791	32602	Economy	17600.00
0005433868523	32602	Economy	17600.00
0005433868623	32602	Economy	17600.00
0005433868750	32602	Economy	17600.00
0005433868588	32602	Economy	17600.00
0005433868628	32602	Economy	17600.00
0005435860532	32602	Economy	17600.00
0005435860533	32602	Economy	17600.00
0005433868664	32602	Economy	17600.00
0005433868549	32602	Economy	17600.00
0005435860538	32602	Economy	17600.00
0005433868716	32602	Economy	17600.00
0005433868673	32602	Economy	17600.00
0005433868593	32602	Economy	17600.00
0005433868690	32602	Economy	17600.00
0005435860535	32602	Economy	17600.00
0005433868587	32602	Economy	17600.00
0005433868609	32602	Economy	17600.00
0005433868735	32602	Economy	17600.00
0005433868695	32602	Economy	17600.00
0005433868790	32602	Economy	17600.00
0005433868663	32602	Economy	17600.00
0005433868670	32602	Economy	17600.00
0005433868499	32602	Economy	17600.00
0005433868586	32602	Economy	17600.00
0005433868647	32602	Economy	17600.00
0005433868559	32602	Economy	17600.00
0005433868583	32602	Economy	17600.00
0005433868632	32602	Economy	17600.00
0005434663620	3456	Economy	24800.00
0005434460538	3456	Economy	24800.00
0005435911507	3456	Economy	22600.00
0005434663618	3456	Economy	22600.00
0005434461681	3456	Economy	22600.00
0005435911478	3456	Economy	22600.00
0005435911495	3456	Economy	22600.00
0005434663624	3456	Economy	22600.00
0005434460539	3456	Economy	22600.00
0005434663614	3456	Economy	22600.00
0005435911508	3456	Economy	22600.00
0005434663623	3456	Economy	22600.00
0005434663617	3456	Economy	22600.00
0005435911510	3456	Economy	22600.00
0005434663616	3456	Economy	22600.00
0005434663615	3456	Economy	22600.00
0005434663619	3456	Economy	22600.00
0005434663622	3456	Economy	22600.00
0005434663625	3456	Economy	22600.00
0005434663612	3456	Economy	22600.00
0005434663611	3456	Economy	22600.00
0005434663621	3456	Economy	22600.00
0005434461679	3456	Economy	22600.00
0005434663613	3456	Economy	22600.00
0005434461680	3456	Economy	22600.00
0005434663403	12501	Economy	24800.00
0005435911568	12501	Economy	24800.00
0005434460516	12501	Economy	24800.00
0005434663565	12501	Economy	22600.00
0005434460514	12501	Economy	22600.00
0005434663515	12501	Economy	22600.00
0005434663526	12501	Economy	22600.00
0005434663566	12501	Economy	22600.00
0005434460504	12501	Economy	22600.00
0005435911571	12501	Economy	22600.00
0005434462802	12501	Economy	22600.00
0005434663516	12501	Economy	22600.00
0005434460527	12501	Economy	22600.00
0005434460501	12501	Economy	22600.00
0005434462800	12501	Economy	22600.00
0005434663455	12501	Economy	22600.00
0005434460513	12501	Economy	22600.00
0005434663417	12501	Economy	22600.00
0005435911567	12501	Economy	22600.00
0005435911570	12501	Economy	22600.00
0005434663514	12501	Economy	22600.00
0005434462801	12501	Economy	22600.00
0005434663474	12501	Economy	22600.00
0005434460508	12501	Economy	22600.00
0005434460511	12501	Economy	22600.00
0005434460506	12501	Economy	22600.00
0005434663506	12501	Economy	22600.00
0005434460509	12501	Economy	22600.00
0005435911569	12501	Economy	22600.00
0005434460507	12501	Economy	22600.00
0005434462803	12501	Economy	22600.00
0005434460515	12501	Economy	22600.00
0005434663531	12501	Economy	22600.00
0005434663507	12501	Economy	22600.00
0005434462809	12501	Economy	22600.00
0005435911572	12501	Economy	22600.00
0005435911566	12501	Economy	22600.00
0005434460528	12501	Economy	22600.00
0005434460523	12501	Economy	22600.00
0005434460510	12501	Economy	22600.00
0005434460512	12501	Economy	22600.00
0005434462798	12501	Economy	22600.00
0005434462811	12501	Economy	22600.00
0005433868670	14501	Economy	18500.00
0005435860530	14501	Economy	18500.00
0005433868805	14501	Economy	18500.00
0005433868735	14501	Economy	16800.00
0005433868609	14501	Economy	16800.00
0005433868750	14501	Economy	16800.00
0005433868632	14501	Economy	16800.00
0005433868648	14501	Economy	16800.00
0005435860535	14501	Economy	16800.00
0005433868663	14501	Economy	16800.00
0005433868665	14501	Economy	16800.00
0005435860539	14501	Economy	16800.00
0005433868673	14501	Economy	16800.00
0005433868664	14501	Economy	16800.00
0005433868647	14501	Economy	16800.00
0005433868623	14501	Economy	16800.00
0005433868593	14501	Economy	16800.00
0005433868690	14501	Economy	16800.00
0005433868498	14501	Economy	16800.00
0005435860538	14501	Economy	16800.00
0005435860531	14501	Economy	16800.00
0005433868587	14501	Economy	16800.00
0005433868716	14501	Economy	16800.00
0005433868588	14501	Economy	16800.00
0005433868662	14501	Economy	16800.00
0005433868559	14501	Economy	16800.00
0005435860533	14501	Economy	16800.00
0005435860534	14501	Economy	16800.00
0005433868586	14501	Economy	16800.00
0005433868646	14501	Economy	16800.00
0005435860532	14501	Economy	16800.00
0005435860537	14501	Economy	16800.00
0005433868499	14501	Economy	16800.00
0005435860536	14501	Economy	16800.00
0005433868549	14501	Economy	16800.00
0005433868523	14501	Economy	16800.00
0005433868791	14501	Economy	16800.00
0005433868583	14501	Economy	16800.00
0005433868790	14501	Economy	16800.00
0005433868628	14501	Economy	16800.00
0005435860540	14501	Economy	16800.00
0005433868695	14501	Economy	16800.00
0005433869006	32673	Economy	18500.00
0005433869017	32673	Economy	18500.00
0005433869005	32673	Economy	18500.00
0005433869023	32673	Economy	16800.00
0005433869024	32673	Economy	16800.00
0005433869026	32673	Economy	16800.00
0005433869027	32673	Economy	16800.00
0005433869034	32673	Economy	16800.00
0005435860496	32673	Economy	16800.00
0005433869001	32673	Economy	16800.00
0005433869016	32673	Economy	16800.00
0005433869009	32673	Economy	16800.00
0005435860495	32673	Economy	16800.00
0005433869018	32673	Economy	16800.00
0005433869000	32673	Economy	16800.00
0005433869033	32673	Economy	16800.00
0005433869007	32673	Economy	16800.00
0005433869036	32673	Economy	16800.00
0005433869004	32673	Economy	16800.00
0005433869035	32673	Economy	16800.00
0005433868996	32673	Economy	16800.00
0005433869021	32673	Economy	16800.00
0005433869002	32673	Economy	16800.00
0005433869020	32673	Economy	16800.00
0005435860494	32673	Economy	16800.00
0005433869019	32673	Economy	16800.00
0005435860500	32673	Economy	16800.00
0005433869032	32673	Economy	16800.00
0005433869037	32673	Economy	16800.00
0005433869013	32673	Economy	16800.00
0005433869022	32673	Economy	16800.00
0005433869015	32673	Economy	16800.00
0005433869003	32673	Economy	16800.00
0005433868998	32673	Economy	16800.00
0005433869028	32673	Economy	16800.00
0005433869012	32673	Economy	16800.00
0005433868999	32673	Economy	16800.00
0005433868997	32673	Economy	16800.00
0005433869030	32673	Economy	16800.00
0005433869014	32673	Economy	16800.00
0005433869008	32673	Economy	16800.00
0005433869031	32673	Economy	16800.00
0005435860501	32673	Economy	16800.00
0005435860507	32673	Economy	16800.00
0005433869025	32673	Economy	16800.00
0005433869011	32673	Economy	16800.00
0005433869029	32673	Economy	16800.00
0005433869010	32673	Economy	16800.00
0005432799696	12109	Economy	4900.00
0005432799583	12109	Economy	4900.00
0005432799690	12109	Economy	4900.00
0005432799632	12109	Economy	4900.00
0005432799654	12109	Economy	4400.00
0005432799664	12109	Economy	4400.00
0005432799629	12109	Economy	4400.00
0005432799649	12109	Economy	4400.00
0005432799446	12109	Economy	4400.00
0005432799603	12109	Economy	4400.00
0005432799684	12109	Economy	4400.00
0005432799695	12109	Economy	4400.00
0005432799634	12109	Economy	4400.00
0005432799610	12109	Economy	4400.00
0005432799788	12109	Economy	4400.00
0005432799630	12109	Economy	4400.00
0005432799622	12109	Economy	4400.00
0005432799604	12109	Economy	4400.00
0005432799673	12109	Economy	4400.00
0005432799663	12109	Economy	4400.00
0005432799676	12109	Economy	4400.00
0005432799698	12109	Economy	4400.00
0005432799636	12109	Economy	4400.00
0005432799786	12109	Economy	4400.00
0005432799787	12109	Economy	4400.00
0005432799669	12109	Economy	4400.00
0005432799566	12109	Economy	4400.00
0005432799584	12109	Economy	4400.00
0005432799445	12109	Economy	4400.00
0005432799853	14832	Economy	4900.00
0005432799874	14832	Economy	4900.00
0005432799850	14832	Economy	4900.00
0005432799857	14832	Economy	4400.00
0005432799865	14832	Economy	4400.00
0005432799861	14832	Economy	4400.00
0005432799866	14832	Economy	4400.00
0005432799858	14832	Economy	4400.00
0005432799871	14832	Economy	4400.00
0005432799855	14832	Economy	4400.00
0005432799854	14832	Economy	4400.00
0005432799862	14832	Economy	4400.00
0005432799868	14832	Economy	4400.00
0005432799873	14832	Economy	4400.00
0005432799856	14832	Economy	4400.00
0005432799867	14832	Economy	4400.00
0005432799872	14832	Economy	4400.00
0005432799876	14832	Economy	4400.00
0005432799869	14832	Economy	4400.00
0005432799863	14832	Economy	4400.00
0005432799852	14832	Economy	4400.00
0005432799851	14832	Economy	4400.00
0005432799859	14832	Economy	4400.00
0005432799877	14832	Economy	4400.00
0005432799860	14832	Economy	4400.00
0005432799870	14832	Economy	4400.00
0005432799875	14832	Economy	4400.00
0005432799864	14832	Economy	4400.00
0005432154046	7069	Business	49100.00
0005434299916	7069	Business	49100.00
0005432154044	7069	Business	49100.00
0005435293349	7069	Business	49100.00
0005435293341	7069	Business	49100.00
0005434408727	7069	Business	49100.00
0005434299915	7069	Business	49100.00
0005434408723	7069	Business	49100.00
0005434408735	7069	Business	49100.00
0005434408767	7069	Business	49100.00
0005434299929	7069	Business	49100.00
0005434408719	7069	Business	49100.00
0005434408716	7069	Economy	16400.00
0005435293351	7069	Economy	16400.00
0005435293355	7069	Economy	16400.00
0005434408718	7069	Economy	16400.00
0005435311101	7069	Economy	16400.00
0005434299912	7069	Economy	16400.00
0005435311137	7069	Economy	16400.00
0005435311117	7069	Economy	16400.00
0005434408744	7069	Economy	16400.00
0005434408746	7069	Economy	16400.00
0005434408740	7069	Economy	16400.00
0005434408733	7069	Economy	16400.00
0005434408759	7069	Economy	16400.00
0005434299932	7069	Economy	16400.00
0005434408750	7069	Economy	16400.00
0005435311102	7069	Economy	16400.00
0005432154045	7069	Economy	16400.00
0005434408732	7069	Economy	16400.00
0005434408712	7069	Economy	16400.00
0005434299909	7069	Economy	16400.00
0005434408724	7069	Economy	16400.00
0005434408742	7069	Economy	16400.00
0005435293334	7069	Economy	16400.00
0005434408737	7069	Economy	16400.00
0005434299923	7069	Economy	16400.00
0005434299914	7069	Economy	16400.00
0005434408729	7069	Economy	16400.00
0005434408748	7069	Economy	16400.00
0005434408756	7069	Economy	16400.00
0005432154048	7069	Economy	16400.00
0005435311118	7069	Economy	16400.00
0005434408751	7069	Economy	16400.00
0005434299910	7069	Economy	16400.00
0005434408714	7069	Economy	16400.00
0005434408741	7069	Economy	16400.00
0005434408758	7069	Economy	16400.00
0005434408710	7069	Economy	18000.00
0005434299911	7069	Economy	18000.00
0005434299926	7069	Economy	18000.00
0005434408715	7069	Economy	18000.00
0005434299919	7069	Economy	18000.00
0005435311070	7069	Economy	16400.00
0005432154049	7069	Economy	16400.00
0005434299920	7069	Economy	16400.00
0005434408752	7069	Economy	16400.00
0005434408736	7069	Economy	16400.00
0005432108291	7069	Economy	16400.00
0005432154050	7069	Economy	16400.00
0005434408768	7069	Economy	16400.00
0005434408734	7069	Economy	16400.00
0005434408765	7069	Economy	16400.00
0005432154047	7069	Economy	16400.00
0005434408721	7069	Economy	16400.00
0005434408755	7069	Economy	16400.00
0005434299930	7069	Economy	16400.00
0005435293339	7069	Economy	16400.00
0005434299925	7069	Economy	16400.00
0005434408706	7069	Economy	16400.00
0005434408754	7069	Economy	16400.00
0005435293294	7069	Economy	16400.00
0005434408747	7069	Economy	16400.00
0005434408769	7069	Economy	16400.00
0005434408739	7069	Economy	16400.00
0005434408760	7069	Economy	16400.00
0005434408708	7069	Economy	16400.00
0005434299908	7069	Economy	16400.00
0005434299928	7069	Economy	16400.00
0005432154043	7069	Economy	16400.00
0005435311119	7069	Economy	16400.00
0005435293338	7069	Economy	16400.00
0005434299917	7069	Economy	16400.00
0005434299922	7069	Economy	16400.00
0005435311100	7069	Economy	16400.00
0005434408720	7069	Economy	16400.00
0005434408717	7069	Economy	16400.00
0005434408757	7069	Economy	16400.00
0005434299921	7069	Economy	16400.00
0005434408722	7069	Economy	16400.00
0005435293322	7069	Economy	16400.00
0005434299918	7069	Economy	16400.00
0005434408709	7069	Economy	16400.00
0005434299927	7069	Economy	16400.00
0005434408731	7069	Economy	16400.00
0005434408728	7069	Economy	16400.00
0005432108290	7069	Economy	16400.00
0005434408738	7069	Economy	16400.00
0005434408766	7069	Economy	16400.00
0005435311120	7069	Economy	16400.00
0005434299924	7069	Economy	16400.00
0005435293342	7069	Economy	16400.00
0005435311109	7069	Economy	16400.00
0005434408770	7069	Economy	16400.00
0005434299931	7069	Economy	16400.00
0005434408726	7069	Economy	16400.00
0005434408763	7069	Economy	16400.00
0005434408730	7069	Economy	16400.00
0005434408707	7069	Economy	16400.00
0005434408749	7069	Economy	16400.00
0005434408725	7069	Economy	16400.00
0005434408762	7069	Economy	16400.00
0005434408753	7069	Economy	16400.00
0005434408745	7069	Economy	16400.00
0005434408711	7069	Economy	16400.00
0005434408764	7069	Economy	16400.00
0005434299913	7069	Economy	16400.00
0005434408743	7069	Economy	16400.00
0005434408761	7069	Economy	16400.00
0005434408713	7069	Economy	16400.00
0005435293452	26916	Business	49100.00
0005434408065	26916	Business	49100.00
0005434408245	26916	Business	49100.00
0005434408138	26916	Business	49100.00
0005434408012	26916	Business	49100.00
0005434299734	26916	Business	49100.00
0005435311243	26916	Business	49100.00
0005434299733	26916	Business	49100.00
0005434408246	26916	Business	49100.00
0005432058438	26916	Economy	16400.00
0005434407882	26916	Economy	16400.00
0005434407854	26916	Economy	16400.00
0005432058437	26916	Economy	16400.00
0005434299875	26916	Economy	16400.00
0005434408059	26916	Economy	16400.00
0005434299703	26916	Economy	16400.00
0005434408235	26916	Economy	16400.00
0005434299796	26916	Economy	16400.00
0005434408066	26916	Economy	16400.00
0005432058441	26916	Economy	16400.00
0005434299726	26916	Economy	16400.00
0005434299760	26916	Economy	16400.00
0005434408204	26916	Economy	16400.00
0005434408140	26916	Economy	16400.00
0005435293445	26916	Economy	16400.00
0005434299745	26916	Economy	16400.00
0005434407994	26916	Economy	16400.00
0005435311241	26916	Economy	16400.00
0005434407919	26916	Economy	16400.00
0005435311238	26916	Economy	16400.00
0005434408252	26916	Economy	16400.00
0005434299774	26916	Economy	16400.00
0005434408032	26916	Economy	16400.00
0005434408269	26916	Economy	16400.00
0005435311244	26916	Economy	16400.00
0005432058440	26916	Economy	16400.00
0005434299700	26916	Economy	16400.00
0005435311242	26916	Economy	16400.00
0005434299775	26916	Economy	16400.00
0005434408179	26916	Economy	16400.00
0005435293450	26916	Economy	16400.00
0005434299714	26916	Economy	16400.00
0005434408134	26916	Economy	16400.00
0005434299686	26916	Economy	16400.00
0005435311247	26916	Economy	18000.00
0005435311239	26916	Economy	18000.00
0005435293439	26916	Economy	18000.00
0005434408058	26916	Economy	18000.00
0005434299732	26916	Economy	18000.00
0005434299603	26916	Economy	18000.00
0005434408251	26916	Economy	16400.00
0005435311240	26916	Economy	16400.00
0005434408113	26916	Economy	16400.00
0005434299717	26916	Economy	16400.00
0005434408133	26916	Economy	16400.00
0005434408366	26916	Economy	16400.00
0005434408041	26916	Economy	16400.00
0005434299731	26916	Economy	16400.00
0005434408090	26916	Economy	16400.00
0005434408039	26916	Economy	16400.00
0005435293451	26916	Economy	16400.00
0005434408208	26916	Economy	16400.00
0005434408057	26916	Economy	16400.00
0005435293449	26916	Economy	16400.00
0005434407759	26916	Economy	16400.00
0005435293441	26916	Economy	16400.00
0005434408253	26916	Economy	16400.00
0005434299758	26916	Economy	16400.00
0005434408118	26916	Economy	16400.00
0005434408216	26916	Economy	16400.00
0005435293446	26916	Economy	16400.00
0005435293447	26916	Economy	16400.00
0005434407998	26916	Economy	16400.00
0005434299759	26916	Economy	16400.00
0005434408114	26916	Economy	16400.00
0005432058439	26916	Economy	16400.00
0005434299719	26916	Economy	16400.00
0005434299795	26916	Economy	16400.00
0005434299801	26916	Economy	16400.00
0005434408013	26916	Economy	16400.00
0005435293443	26916	Economy	16400.00
0005434408104	26916	Economy	16400.00
0005434407956	26916	Economy	16400.00
0005434299706	26916	Economy	16400.00
0005435311245	26916	Economy	16400.00
0005434407999	26916	Economy	16400.00
0005434408227	26916	Economy	16400.00
0005435311246	26916	Economy	16400.00
0005434408141	26916	Economy	16400.00
0005435293442	26916	Economy	16400.00
0005434407941	26916	Economy	16400.00
0005434299685	26916	Economy	16400.00
0005434299754	26916	Economy	16400.00
0005434299671	26916	Economy	16400.00
0005435293444	26916	Economy	16400.00
0005434299802	26916	Economy	16400.00
0005435293440	26916	Economy	16400.00
0005434407938	26916	Economy	16400.00
0005435293448	26916	Economy	16400.00
0005434408240	26916	Economy	16400.00
0005435311237	26916	Economy	16400.00
0005434408132	26916	Economy	16400.00
0005434299809	26916	Economy	16400.00
0005434408270	26916	Economy	16400.00
0005434407930	26916	Economy	16400.00
0005432604962	6448	Economy	16500.00
0005432604965	6448	Economy	16500.00
0005432604972	6448	Economy	16500.00
0005432604968	6448	Economy	16500.00
0005432604970	6448	Economy	15000.00
0005432604944	6448	Economy	15000.00
0005432604976	6448	Economy	15000.00
0005432604954	6448	Economy	15000.00
0005432604963	6448	Economy	15000.00
0005434512187	6448	Economy	15000.00
0005434512184	6448	Economy	15000.00
0005432604953	6448	Economy	15000.00
0005432604964	6448	Economy	15000.00
0005432604961	6448	Economy	15000.00
0005432604975	6448	Economy	15000.00
0005432604941	6448	Economy	15000.00
0005432604945	6448	Economy	15000.00
0005432604952	6448	Economy	15000.00
0005432604974	6448	Economy	15000.00
0005434512183	6448	Economy	15000.00
0005434512185	6448	Economy	15000.00
0005432604966	6448	Economy	15000.00
0005432604969	6448	Economy	15000.00
0005432604979	6448	Economy	15000.00
0005432604946	6448	Economy	15000.00
0005432604940	6448	Economy	15000.00
0005432604956	6448	Economy	15000.00
0005432604967	6448	Economy	15000.00
0005432604971	6448	Economy	15000.00
0005432604951	6448	Economy	15000.00
0005432604943	6448	Economy	15000.00
0005432604948	6448	Economy	15000.00
0005434512189	6448	Economy	15000.00
0005432604980	6448	Economy	15000.00
0005432604955	6448	Economy	15000.00
0005432604973	6448	Economy	15000.00
0005434512182	6448	Economy	15000.00
0005432604960	6448	Economy	15000.00
0005432604957	6448	Economy	15000.00
0005434512188	6448	Economy	15000.00
0005432604942	6448	Economy	15000.00
0005434512186	6448	Economy	15000.00
0005432604949	6448	Economy	15000.00
0005432604978	6448	Economy	15000.00
0005432604958	6448	Economy	15000.00
0005432604977	6448	Economy	15000.00
0005432604950	6448	Economy	15000.00
0005432604947	6448	Economy	15000.00
0005432604959	6448	Economy	15000.00
0005432604694	21353	Economy	16500.00
0005432604685	21353	Economy	16500.00
0005432604515	21353	Economy	16500.00
0005432604805	21353	Economy	16500.00
0005432604552	21353	Economy	15000.00
0005434512137	21353	Economy	15000.00
0005432604845	21353	Economy	15000.00
0005432604517	21353	Economy	15000.00
0005434512136	21353	Economy	15000.00
0005432604607	21353	Economy	15000.00
0005432604579	21353	Economy	15000.00
0005432604464	21353	Economy	15000.00
0005432604493	21353	Economy	15000.00
0005432604564	21353	Economy	15000.00
0005432604755	21353	Economy	15000.00
0005432604652	21353	Economy	15000.00
0005432604625	21353	Economy	15000.00
0005432604506	21353	Economy	15000.00
0005432604806	21353	Economy	15000.00
0005432604494	21353	Economy	15000.00
0005432604576	21353	Economy	15000.00
0005432604651	21353	Economy	15000.00
0005432604614	21353	Economy	15000.00
0005432604604	21353	Economy	15000.00
0005432604574	21353	Economy	15000.00
0005432604684	21353	Economy	15000.00
0005432604732	21353	Economy	15000.00
0005432604709	21353	Economy	15000.00
0005432604754	21353	Economy	15000.00
0005432604575	21353	Economy	15000.00
0005432604644	21353	Economy	15000.00
0005434512144	21353	Economy	15000.00
0005432604536	21353	Economy	15000.00
0005432604747	21353	Economy	15000.00
0005434512143	21353	Economy	15000.00
0005432604488	21353	Economy	15000.00
0005432604693	21353	Economy	15000.00
0005432604507	21353	Economy	15000.00
0005432604666	21353	Economy	15000.00
0005432604553	21353	Economy	15000.00
0005432604615	21353	Economy	15000.00
0005432604505	21353	Economy	15000.00
0005432604731	21353	Economy	15000.00
0005432604748	21353	Economy	15000.00
0005432604642	21353	Economy	15000.00
0005432604672	21353	Economy	15000.00
0005432604523	21353	Economy	15000.00
0005432604492	21353	Economy	15000.00
0005432604656	21353	Economy	15000.00
0005432604710	21353	Economy	15000.00
0005434907541	14987	Business	18900.00
0005434907637	14987	Business	18900.00
0005433251958	14987	Business	18900.00
0005434907328	14987	Business	18900.00
0005434907584	14987	Business	18900.00
0005433251961	14987	Business	18900.00
0005434907410	14987	Business	18900.00
0005434907580	14987	Business	18900.00
0005434907672	14987	Business	18900.00
0005434907605	14987	Business	18900.00
0005434907384	14987	Business	18900.00
0005434907620	14987	Business	18900.00
0005434907323	14987	Economy	6300.00
0005433251964	14987	Economy	6300.00
0005433251954	14987	Economy	6300.00
0005434907509	14987	Economy	6300.00
0005434907404	14987	Economy	6300.00
0005434907566	14987	Economy	6300.00
0005433251945	14987	Economy	6300.00
0005433251941	14987	Economy	6300.00
0005433251942	14987	Economy	6300.00
0005433251943	14987	Economy	6900.00
0005434907489	14987	Economy	6900.00
0005434907500	14987	Economy	6900.00
0005434907403	14987	Economy	6900.00
0005434907490	14987	Economy	6900.00
0005434907693	14987	Economy	6300.00
0005433251949	14987	Economy	6300.00
0005434907606	14987	Economy	6300.00
0005434907557	14987	Economy	6300.00
0005434907282	14987	Economy	6300.00
0005434907405	14987	Economy	6300.00
0005434907667	14987	Economy	6300.00
0005433251970	14987	Economy	6300.00
0005434907588	14987	Economy	6300.00
0005434907415	14987	Economy	6300.00
0005434907742	14987	Economy	6300.00
0005433251960	14987	Economy	6300.00
0005434907662	14987	Economy	6300.00
0005434907564	14987	Economy	6300.00
0005434907559	14987	Economy	6300.00
0005433251951	14987	Economy	6300.00
0005434907457	14987	Economy	6300.00
0005434907324	14987	Economy	6300.00
0005433251969	14987	Economy	6300.00
0005433251953	14987	Economy	6300.00
0005434907574	14987	Economy	6300.00
0005433251946	14987	Economy	6300.00
0005433251952	14987	Economy	6300.00
0005434907501	14987	Economy	6300.00
0005433251957	14987	Economy	6300.00
0005433251948	14987	Economy	6300.00
0005434907499	14987	Economy	6300.00
0005434907484	14987	Economy	6300.00
0005434907485	14987	Economy	6300.00
0005434907577	14987	Economy	6300.00
0005434907436	14987	Economy	6300.00
0005433251947	14987	Economy	6300.00
0005434907468	14987	Economy	6300.00
0005433251955	14987	Economy	6300.00
0005433251940	14987	Economy	6300.00
0005433251967	14987	Economy	6300.00
0005434907636	14987	Economy	6300.00
0005433251968	14987	Economy	6300.00
0005434907385	14987	Economy	6300.00
0005434907710	14987	Economy	6300.00
0005433251956	14987	Economy	6300.00
0005434907437	14987	Economy	6300.00
0005434907570	14987	Economy	6300.00
0005433251966	14987	Economy	6300.00
0005433251959	14987	Economy	6300.00
0005433251965	14987	Economy	6300.00
0005434907692	14987	Economy	6300.00
0005434907735	14987	Economy	6300.00
0005434907522	14987	Economy	6300.00
0005433251950	14987	Economy	6300.00
0005434907604	14987	Economy	6300.00
0005434907591	14987	Economy	6300.00
0005433251944	14987	Economy	6300.00
0005434907626	14987	Economy	6300.00
0005433251962	14987	Economy	6300.00
0005433251939	14987	Economy	6300.00
0005434907383	14987	Economy	6300.00
0005434907471	14987	Economy	6300.00
0005434907573	14987	Economy	6300.00
0005434907664	14987	Economy	6300.00
0005434907558	14987	Economy	6300.00
0005434907592	14987	Economy	6300.00
0005434907567	14987	Economy	6300.00
0005433251963	14987	Economy	6300.00
0005434907736	14987	Economy	6300.00
0005434907510	14987	Economy	6300.00
0005434907661	14987	Economy	6300.00
0005434907730	14987	Economy	6300.00
0005433251655	25829	Business	18900.00
0005434908057	25829	Business	18900.00
0005434908041	25829	Business	18900.00
0005434908055	25829	Business	18900.00
0005434908056	25829	Business	18900.00
0005434908023	25829	Business	18900.00
0005433251743	25829	Business	18900.00
0005433251683	25829	Business	18900.00
0005434908052	25829	Business	18900.00
0005434908038	25829	Business	18900.00
0005434908045	25829	Economy	6300.00
0005434908066	25829	Economy	6300.00
0005434908025	25829	Economy	6300.00
0005433251773	25829	Economy	6300.00
0005433251605	25829	Economy	6300.00
0005434908054	25829	Economy	6300.00
0005434908026	25829	Economy	6300.00
0005433251644	25829	Economy	6300.00
0005434908033	25829	Economy	6300.00
0005433251664	25829	Economy	6900.00
0005433251726	25829	Economy	6900.00
0005433251799	25829	Economy	6900.00
0005433251671	25829	Economy	6900.00
0005433251645	25829	Economy	6900.00
0005433251685	25829	Economy	6300.00
0005433251798	25829	Economy	6300.00
0005433251541	25829	Economy	6300.00
0005434908068	25829	Economy	6300.00
0005433251725	25829	Economy	6300.00
0005433251742	25829	Economy	6300.00
0005433251736	25829	Economy	6300.00
0005434908061	25829	Economy	6300.00
0005434908046	25829	Economy	6300.00
0005433251800	25829	Economy	6300.00
0005434908029	25829	Economy	6300.00
0005434908051	25829	Economy	6300.00
0005434908059	25829	Economy	6300.00
0005433251718	25829	Economy	6300.00
0005433251615	25829	Economy	6300.00
0005433251547	25829	Economy	6300.00
0005433251497	25829	Economy	6300.00
0005434908040	25829	Economy	6300.00
0005434908042	25829	Economy	6300.00
0005434908067	25829	Economy	6300.00
0005434908047	25829	Economy	6300.00
0005434908063	25829	Economy	6300.00
0005434908032	25829	Economy	6300.00
0005433251670	25829	Economy	6300.00
0005433251638	25829	Economy	6300.00
0005433251564	25829	Economy	6300.00
0005434908064	25829	Economy	6300.00
0005434908044	25829	Economy	6300.00
0005433251660	25829	Economy	6300.00
0005433251728	25829	Economy	6300.00
0005434908030	25829	Economy	6300.00
0005434908062	25829	Economy	6300.00
0005434908039	25829	Economy	6300.00
0005433251578	25829	Economy	6300.00
0005434908027	25829	Economy	6300.00
0005434908058	25829	Economy	6300.00
0005434908065	25829	Economy	6300.00
0005434908048	25829	Economy	6300.00
0005434908024	25829	Economy	6300.00
0005433251642	25829	Economy	6300.00
0005434908053	25829	Economy	6300.00
0005433251727	25829	Economy	6300.00
0005433251614	25829	Economy	6300.00
0005433251643	25829	Economy	6300.00
0005434908034	25829	Economy	6300.00
0005433251661	25829	Economy	6300.00
0005433251734	25829	Economy	6300.00
0005433251669	25829	Economy	6300.00
0005434908031	25829	Economy	6300.00
0005434908028	25829	Economy	6300.00
0005433251556	25829	Economy	6300.00
0005434908060	25829	Economy	6300.00
0005434908049	25829	Economy	6300.00
0005434908050	25829	Economy	6300.00
0005434908043	25829	Economy	6300.00
0005433251682	25829	Economy	6300.00
0005434908036	25829	Economy	6300.00
0005434908035	25829	Economy	6300.00
0005434908037	25829	Economy	6300.00
0005433251606	25829	Economy	6300.00
0005433009332	14195	Business	52300.00
0005433009319	14195	Business	52300.00
0005433009327	14195	Business	52300.00
0005433009322	14195	Business	52300.00
0005433810562	14195	Business	52300.00
0005433009351	14195	Business	52300.00
0005433009336	14195	Business	52300.00
0005433810537	14195	Business	52300.00
0005433009340	14195	Economy	17400.00
0005433009308	14195	Economy	17400.00
0005433009329	14195	Economy	17400.00
0005433009325	14195	Economy	17400.00
0005433009343	14195	Economy	17400.00
0005433009333	14195	Economy	17400.00
0005433009352	14195	Economy	17400.00
0005433009328	14195	Economy	17400.00
0005433810556	14195	Economy	19200.00
0005433009318	14195	Economy	19200.00
0005433009311	14195	Economy	17400.00
0005433009341	14195	Economy	17400.00
0005433009350	14195	Economy	17400.00
0005433009335	14195	Economy	17400.00
0005433009307	14195	Economy	17400.00
0005433009337	14195	Economy	17400.00
0005433810563	14195	Economy	17400.00
0005433009345	14195	Economy	17400.00
0005433009324	14195	Economy	17400.00
0005433810548	14195	Economy	17400.00
0005433009316	14195	Economy	17400.00
0005433009349	14195	Economy	17400.00
0005433810549	14195	Economy	17400.00
0005433009314	14195	Economy	17400.00
0005433009320	14195	Economy	17400.00
0005433009310	14195	Economy	17400.00
0005433810546	14195	Economy	17400.00
0005433009315	14195	Economy	17400.00
0005433810550	14195	Economy	17400.00
0005433009312	14195	Economy	17400.00
0005433009339	14195	Economy	17400.00
0005433009347	14195	Economy	17400.00
0005433009313	14195	Economy	17400.00
0005433009346	14195	Economy	17400.00
0005433009323	14195	Economy	17400.00
0005433009309	14195	Economy	17400.00
0005433009306	14195	Economy	17400.00
0005433009321	14195	Economy	17400.00
0005433810553	14195	Economy	17400.00
0005433009338	14195	Economy	17400.00
0005433009334	14195	Economy	17400.00
0005433009344	14195	Economy	17400.00
0005433009348	14195	Economy	17400.00
0005433009317	14195	Economy	17400.00
0005433009331	14195	Economy	17400.00
0005433009326	14195	Economy	17400.00
0005433009330	14195	Economy	17400.00
0005433009342	14195	Economy	17400.00
0005433008972	22843	Business	52300.00
0005433008863	22843	Business	52300.00
0005433008768	22843	Business	52300.00
0005433008748	22843	Business	52300.00
0005433008869	22843	Business	52300.00
0005433008757	22843	Business	52300.00
0005433008770	22843	Business	52300.00
0005433008974	22843	Business	52300.00
0005433008864	22843	Economy	17400.00
0005433008833	22843	Economy	17400.00
0005433008973	22843	Economy	17400.00
0005433009015	22843	Economy	17400.00
0005433008901	22843	Economy	17400.00
0005433008929	22843	Economy	17400.00
0005433008947	22843	Economy	17400.00
0005433008829	22843	Economy	19200.00
0005433008835	22843	Economy	17400.00
0005433009016	22843	Economy	17400.00
0005433008978	22843	Economy	17400.00
0005433009006	22843	Economy	17400.00
0005433008965	22843	Economy	17400.00
0005433008892	22843	Economy	17400.00
0005433008728	22843	Economy	17400.00
0005433009066	22843	Economy	17400.00
0005433008859	22843	Economy	17400.00
0005433008767	22843	Economy	17400.00
0005433008952	22843	Economy	17400.00
0005433008838	22843	Economy	17400.00
0005433008758	22843	Economy	17400.00
0005433008749	22843	Economy	17400.00
0005433008870	22843	Economy	17400.00
0005433008898	22843	Economy	17400.00
0005433008861	22843	Economy	17400.00
0005433810606	22843	Economy	17400.00
0005433008893	22843	Economy	17400.00
0005433008769	22843	Economy	17400.00
0005433008924	22843	Economy	17400.00
0005433008900	22843	Economy	17400.00
0005433810607	22843	Economy	17400.00
0005433008955	22843	Economy	17400.00
0005433008834	22843	Economy	17400.00
0005433008917	22843	Economy	17400.00
0005433810609	22843	Economy	17400.00
0005433008895	22843	Economy	17400.00
0005433008957	22843	Economy	17400.00
0005433008948	22843	Economy	17400.00
0005433810608	22843	Economy	17400.00
0005433009070	22843	Economy	17400.00
0005433009065	22843	Economy	17400.00
0005433008941	22843	Economy	17400.00
0005433008940	22843	Economy	17400.00
0005433009061	22843	Economy	17400.00
0005433008927	22843	Economy	17400.00
0005433008853	22843	Economy	17400.00
0005433008911	22843	Economy	17400.00
0005433008826	22843	Economy	17400.00
0005433008742	22843	Economy	17400.00
0005433008946	22843	Economy	17400.00
0005434925862	14915	Business	22900.00
0005434925970	14915	Business	22900.00
0005434926005	14915	Business	22900.00
0005434926033	14915	Business	22900.00
0005434925871	14915	Business	22900.00
0005434925903	14915	Economy	7600.00
0005434925944	14915	Economy	7600.00
0005434926011	14915	Economy	7600.00
0005434925866	14915	Economy	7600.00
0005434925999	14915	Economy	8400.00
0005434926037	14915	Economy	8400.00
0005434925992	14915	Economy	8400.00
0005434925864	14915	Economy	7600.00
0005434925936	14915	Economy	7600.00
0005434925993	14915	Economy	7600.00
0005434925716	14915	Economy	7600.00
0005434925966	14915	Economy	7600.00
0005434925945	14915	Economy	7600.00
0005434925997	14915	Economy	7600.00
0005434925898	14915	Economy	7600.00
0005434925878	14915	Economy	7600.00
0005434926042	14915	Economy	7600.00
0005434925813	14915	Economy	7600.00
0005434926055	14915	Economy	7600.00
0005434925918	14915	Economy	7600.00
0005434926031	14915	Economy	7600.00
0005434926035	14915	Economy	7600.00
0005434926054	14915	Economy	7600.00
0005434925889	14915	Economy	7600.00
0005434925939	14915	Economy	7600.00
0005434925863	14915	Economy	7600.00
0005434926001	14915	Economy	7600.00
0005434925923	14915	Economy	7600.00
0005434925991	14915	Economy	7600.00
0005434925919	14915	Economy	7600.00
0005434926053	14915	Economy	7600.00
0005434925958	14915	Economy	7600.00
0005434926017	14915	Economy	7600.00
0005434925897	14915	Economy	7600.00
0005434926012	14915	Economy	7600.00
0005434925879	14915	Economy	7600.00
0005434925890	14915	Economy	7600.00
0005434925894	14915	Economy	7600.00
0005434925872	14915	Economy	7600.00
0005434926007	14915	Economy	7600.00
0005434925893	14915	Economy	7600.00
0005434926268	20502	Business	22900.00
0005434926257	20502	Business	22900.00
0005434926263	20502	Business	22900.00
0005434926282	20502	Business	22900.00
0005434926272	20502	Business	22900.00
0005434926273	20502	Economy	7600.00
0005434926259	20502	Economy	7600.00
0005434926266	20502	Economy	7600.00
0005434926255	20502	Economy	8400.00
0005434926284	20502	Economy	8400.00
0005434926262	20502	Economy	8400.00
0005434926267	20502	Economy	8400.00
0005434926264	20502	Economy	7600.00
0005434926271	20502	Economy	7600.00
0005434926261	20502	Economy	7600.00
0005434926270	20502	Economy	7600.00
0005434926260	20502	Economy	7600.00
0005434926283	20502	Economy	7600.00
0005434926277	20502	Economy	7600.00
0005434926280	20502	Economy	7600.00
0005434926269	20502	Economy	7600.00
0005434926276	20502	Economy	7600.00
0005434926253	20502	Economy	7600.00
0005434926258	20502	Economy	7600.00
0005434926254	20502	Economy	7600.00
0005434926274	20502	Economy	7600.00
0005434926265	20502	Economy	7600.00
0005434926256	20502	Economy	7600.00
0005434926281	20502	Economy	7600.00
0005434926278	20502	Economy	7600.00
0005434926275	20502	Economy	7600.00
0005434926279	20502	Economy	7600.00
0005435999366	15834	Economy	8900.00
0005435488172	15834	Economy	8900.00
0005435488173	15834	Economy	8900.00
0005435488184	15834	Economy	8900.00
0005435488185	15834	Economy	8100.00
0005435488174	15834	Economy	8100.00
0005435999342	15834	Economy	8100.00
0005435999309	15834	Economy	8100.00
0005435999360	15834	Economy	8100.00
0005435999289	15834	Economy	8100.00
0005435488178	15834	Economy	8100.00
0005435999312	15834	Economy	8100.00
0005435488164	15834	Economy	8100.00
0005435999357	15834	Economy	8100.00
0005435488171	15834	Economy	8100.00
0005435488181	15834	Economy	8100.00
0005435488163	15834	Economy	8100.00
0005435488168	15834	Economy	8100.00
0005435488165	15834	Economy	8100.00
0005435488169	15834	Economy	8100.00
0005435488177	15834	Economy	8100.00
0005435999311	15834	Economy	8100.00
0005435488183	15834	Economy	8100.00
0005435999374	15834	Economy	8100.00
0005435488167	15834	Economy	8100.00
0005435999304	15834	Economy	8100.00
0005435488179	15834	Economy	8100.00
0005435488170	15834	Economy	8100.00
0005435999335	15834	Economy	8100.00
0005435488180	15834	Economy	8100.00
0005435999270	15834	Economy	8100.00
0005435999310	15834	Economy	8100.00
0005435999269	15834	Economy	8100.00
0005435999345	15834	Economy	8100.00
0005435488175	15834	Economy	8100.00
0005435488182	15834	Economy	8100.00
0005435999322	15834	Economy	8100.00
0005435488166	15834	Economy	8100.00
0005435999281	15834	Economy	8100.00
0005435488176	15834	Economy	8100.00
0005435999494	19664	Economy	8900.00
0005435999488	19664	Economy	8900.00
0005435999507	19664	Economy	8900.00
0005435487954	19664	Economy	8900.00
0005435487949	19664	Economy	8100.00
0005435487857	19664	Economy	8100.00
0005435999490	19664	Economy	8100.00
0005435487971	19664	Economy	8100.00
0005435488011	19664	Economy	8100.00
0005435999502	19664	Economy	8100.00
0005435999501	19664	Economy	8100.00
0005435487819	19664	Economy	8100.00
0005435999505	19664	Economy	8100.00
0005435999504	19664	Economy	8100.00
0005435999486	19664	Economy	8100.00
0005435999487	19664	Economy	8100.00
0005435999485	19664	Economy	8100.00
0005435487908	19664	Economy	8100.00
0005435999506	19664	Economy	8100.00
0005435487907	19664	Economy	8100.00
0005435487970	19664	Economy	8100.00
0005435999498	19664	Economy	8100.00
0005435999492	19664	Economy	8100.00
0005435487906	19664	Economy	8100.00
0005435487890	19664	Economy	8100.00
0005435487950	19664	Economy	8100.00
0005435488010	19664	Economy	8100.00
0005435487987	19664	Economy	8100.00
0005435999509	19664	Economy	8100.00
0005435999491	19664	Economy	8100.00
0005435999499	19664	Economy	8100.00
0005435999496	19664	Economy	8100.00
0005435999489	19664	Economy	8100.00
0005435488052	19664	Economy	8100.00
0005435999508	19664	Economy	8100.00
0005435999495	19664	Economy	8100.00
0005435999503	19664	Economy	8100.00
0005435999500	19664	Economy	8100.00
0005435999497	19664	Economy	8100.00
0005435999493	19664	Economy	8100.00
0005435472853	6022	Business	199300.00
0005435839897	6022	Business	199300.00
0005432142300	6022	Business	199300.00
0005435839885	6022	Business	199300.00
0005435472930	6022	Business	199300.00
0005435839889	6022	Business	199300.00
0005435839894	6022	Business	199300.00
0005435839899	6022	Economy	66400.00
0005435472905	6022	Economy	66400.00
0005435839905	6022	Economy	66400.00
0005435839891	6022	Economy	66400.00
0005432142301	6022	Economy	66400.00
0005435839883	6022	Economy	73100.00
0005435839900	6022	Economy	73100.00
0005435472885	6022	Economy	66400.00
0005435839892	6022	Economy	66400.00
0005432660851	6022	Economy	66400.00
0005435839888	6022	Economy	66400.00
0005432658627	6022	Economy	66400.00
0005435472932	6022	Economy	66400.00
0005435839879	6022	Economy	66400.00
0005435839890	6022	Economy	66400.00
0005435472902	6022	Economy	66400.00
0005435839907	6022	Economy	66400.00
0005432658626	6022	Economy	66400.00
0005435839898	6022	Economy	66400.00
0005435472941	6022	Economy	66400.00
0005432142302	6022	Economy	66400.00
0005435839882	6022	Economy	66400.00
0005435472903	6022	Economy	66400.00
0005435472926	6022	Economy	66400.00
0005435839904	6022	Economy	66400.00
0005435472965	6022	Economy	66400.00
0005432537069	6022	Economy	66400.00
0005435472931	6022	Economy	66400.00
0005435839903	6022	Economy	66400.00
0005435472915	6022	Economy	66400.00
0005435839901	6022	Economy	66400.00
0005435472888	6022	Economy	66400.00
0005435839906	6022	Economy	66400.00
0005432142299	6022	Economy	66400.00
0005435839881	6022	Economy	66400.00
0005432658625	6022	Economy	66400.00
0005435839896	6022	Economy	66400.00
0005435472914	6022	Economy	66400.00
0005432537070	6022	Economy	66400.00
0005435839902	6022	Economy	66400.00
0005432537065	6022	Economy	66400.00
0005432660852	6022	Economy	66400.00
0005435472916	6022	Economy	66400.00
0005435472904	6022	Economy	66400.00
0005435472994	6022	Economy	66400.00
0005435839884	6022	Economy	66400.00
0005435472901	6022	Economy	66400.00
0005435839893	6022	Economy	66400.00
0005435839880	6022	Economy	66400.00
0005435839887	6022	Economy	66400.00
0005435839895	6022	Economy	66400.00
0005432658624	6022	Economy	66400.00
0005435839886	6022	Economy	66400.00
0005435839640	18042	Business	199300.00
0005432664156	18042	Business	199300.00
0005435473068	18042	Business	199300.00
0005435473052	18042	Business	199300.00
0005435839651	18042	Business	199300.00
0005435473059	18042	Business	199300.00
0005435839719	18042	Business	199300.00
0005432667461	18042	Business	199300.00
0005435839622	18042	Business	199300.00
0005435839621	18042	Business	199300.00
0005435839545	18042	Economy	66400.00
0005435839585	18042	Economy	66400.00
0005432667460	18042	Economy	73100.00
0005435473066	18042	Economy	73100.00
0005435839683	18042	Economy	66400.00
0005435473055	18042	Economy	66400.00
0005435839553	18042	Economy	66400.00
0005432660833	18042	Economy	66400.00
0005432537093	18042	Economy	66400.00
0005435839667	18042	Economy	66400.00
0005435473069	18042	Economy	66400.00
0005435839590	18042	Economy	66400.00
0005435839691	18042	Economy	66400.00
0005435473058	18042	Economy	66400.00
0005435473061	18042	Economy	66400.00
0005435839682	18042	Economy	66400.00
0005435839674	18042	Economy	66400.00
0005432660834	18042	Economy	66400.00
0005435839692	18042	Economy	66400.00
0005435473054	18042	Economy	66400.00
0005435473053	18042	Economy	66400.00
0005435839572	18042	Economy	66400.00
0005435473067	18042	Economy	66400.00
0005435839659	18042	Economy	66400.00
0005435473064	18042	Economy	66400.00
0005432537094	18042	Economy	66400.00
0005435839631	18042	Economy	66400.00
0005435473062	18042	Economy	66400.00
0005432664157	18042	Economy	66400.00
0005435839700	18042	Economy	66400.00
0005435839599	18042	Economy	66400.00
0005435473060	18042	Economy	66400.00
0005435473063	18042	Economy	66400.00
0005435473065	18042	Economy	66400.00
0005435839686	18042	Economy	66400.00
0005432664149	18042	Economy	66400.00
0005435473057	18042	Economy	66400.00
0005435839780	18042	Economy	66400.00
0005435839650	18042	Economy	66400.00
0005435473056	18042	Economy	66400.00
0005435839567	18042	Economy	66400.00
0005435839546	18042	Economy	66400.00
0005432537092	18042	Economy	66400.00
0005432664146	18042	Economy	66400.00
0005435839568	18042	Economy	66400.00
0005433285371	23008	Business	15700.00
0005435104050	23008	Business	15700.00
0005433285611	23008	Business	15700.00
0005433285496	23008	Economy	5200.00
0005435104055	23008	Economy	5200.00
0005433285609	23008	Economy	5200.00
0005433285573	23008	Economy	5200.00
0005433285555	23008	Economy	5200.00
0005433285495	23008	Economy	5200.00
0005435104052	23008	Economy	5200.00
0005433285580	23008	Economy	5200.00
0005433285444	23008	Economy	5200.00
0005433285512	23008	Economy	5200.00
0005435104048	23008	Economy	5700.00
0005433285490	23008	Economy	5200.00
0005433285541	23008	Economy	5200.00
0005433285455	23008	Economy	5200.00
0005433285497	23008	Economy	5200.00
0005433285668	23008	Economy	5200.00
0005433285491	23008	Economy	5200.00
0005435104056	23008	Economy	5200.00
0005435104054	23008	Economy	5200.00
0005433285574	23008	Economy	5200.00
0005435104049	23008	Economy	5200.00
0005435104053	23008	Economy	5200.00
0005433285516	23008	Economy	5200.00
0005433285610	23008	Economy	5200.00
0005433285488	23008	Economy	5200.00
0005435104057	23008	Economy	5200.00
0005433285517	23008	Economy	5200.00
0005433285454	23008	Economy	5200.00
0005433285608	23008	Economy	5200.00
0005433285612	23008	Economy	5200.00
0005433285445	23008	Economy	5200.00
0005435104051	23008	Economy	5200.00
0005433285416	23008	Economy	5200.00
0005433285511	23008	Economy	5200.00
0005435103964	32054	Business	15700.00
0005433285786	32054	Business	15700.00
0005433285778	32054	Business	15700.00
0005433285785	32054	Business	15700.00
0005435103954	32054	Economy	5200.00
0005433285799	32054	Economy	5200.00
0005433285803	32054	Economy	5200.00
0005433285779	32054	Economy	5200.00
0005433285784	32054	Economy	5200.00
0005433285801	32054	Economy	5200.00
0005433285782	32054	Economy	5200.00
0005433285775	32054	Economy	5200.00
0005433285783	32054	Economy	5200.00
0005433285793	32054	Economy	5200.00
0005433285790	32054	Economy	5200.00
0005433285773	32054	Economy	5200.00
0005433285772	32054	Economy	5200.00
0005433285804	32054	Economy	5200.00
0005433285798	32054	Economy	5700.00
0005433285776	32054	Economy	5700.00
0005433285792	32054	Economy	5700.00
0005433285794	32054	Economy	5200.00
0005433285796	32054	Economy	5200.00
0005435103958	32054	Economy	5200.00
0005433285802	32054	Economy	5200.00
0005433285788	32054	Economy	5200.00
0005435103967	32054	Economy	5200.00
0005433285787	32054	Economy	5200.00
0005433285777	32054	Economy	5200.00
0005435103965	32054	Economy	5200.00
0005433285800	32054	Economy	5200.00
0005433285781	32054	Economy	5200.00
0005433285780	32054	Economy	5200.00
0005433285789	32054	Economy	5200.00
0005433285797	32054	Economy	5200.00
0005435103966	32054	Economy	5200.00
0005433285791	32054	Economy	5200.00
0005433285774	32054	Economy	5200.00
0005433285795	32054	Economy	5200.00
0005432528531	30600	Business	42100.00
0005434067583	30600	Business	42100.00
0005435214628	30600	Business	42100.00
0005432537076	30600	Business	42100.00
0005432528538	30600	Business	42100.00
0005435214666	30600	Business	42100.00
0005432529314	30600	Business	42100.00
0005432529383	30600	Business	42100.00
0005435214638	30600	Business	42100.00
0005435214641	30600	Business	42100.00
0005432528939	30600	Business	42100.00
0005434067754	30600	Business	42100.00
0005432529179	30600	Business	42100.00
0005434068129	30600	Business	42100.00
0005432528794	30600	Business	42100.00
0005432529313	30600	Business	42100.00
0005434068324	30600	Business	42100.00
0005435214631	30600	Business	42100.00
0005433656726	30600	Business	42100.00
0005432528334	30600	Business	42100.00
0005435214663	30600	Business	42100.00
0005435214639	30600	Business	42100.00
0005432528581	30600	Business	42100.00
0005432528416	30600	Business	42100.00
0005435214669	30600	Business	42100.00
0005432529147	30600	Comfort	23900.00
0005435214658	30600	Comfort	23900.00
0005434068105	30600	Comfort	23900.00
0005432528400	30600	Comfort	23900.00
0005434067952	30600	Comfort	23900.00
0005435214648	30600	Comfort	23900.00
0005435283418	30600	Comfort	23900.00
0005432529078	30600	Comfort	23900.00
0005432529148	30600	Comfort	23900.00
0005432528980	30600	Comfort	23900.00
0005434067926	30600	Comfort	23900.00
0005432529274	30600	Comfort	23900.00
0005435214619	30600	Comfort	23900.00
0005432535876	30600	Comfort	23900.00
0005432529060	30600	Comfort	23900.00
0005432529330	30600	Comfort	23900.00
0005434068360	30600	Comfort	23900.00
0005435214634	30600	Comfort	23900.00
0005435214675	30600	Comfort	23900.00
0005432529248	30600	Comfort	23900.00
0005432529199	30600	Comfort	23900.00
0005432528684	30600	Comfort	23900.00
0005432528446	30600	Comfort	23900.00
0005432529109	30600	Comfort	23900.00
0005432529040	30600	Comfort	23900.00
0005435214635	30600	Comfort	23900.00
0005432159930	30600	Comfort	23900.00
0005434067870	30600	Comfort	23900.00
0005432528502	30600	Comfort	23900.00
0005434068062	30600	Comfort	23900.00
0005432529542	30600	Comfort	23900.00
0005432529252	30600	Comfort	23900.00
0005432528985	30600	Comfort	23900.00
0005435214674	30600	Comfort	23900.00
0005432529278	30600	Comfort	23900.00
0005434068041	30600	Comfort	23900.00
0005432535865	30600	Economy	14000.00
0005435631017	30600	Economy	14000.00
0005432528885	30600	Economy	14000.00
0005432529119	30600	Economy	14000.00
0005435214623	30600	Economy	14000.00
0005435214653	30600	Economy	14000.00
0005434068162	30600	Economy	14000.00
0005434068161	30600	Economy	14000.00
0005432428955	30600	Economy	14000.00
0005434067923	30600	Economy	14000.00
0005432529048	30600	Economy	14000.00
0005435214677	30600	Economy	14000.00
0005434068233	30600	Economy	14000.00
0005435214678	30600	Economy	14000.00
0005435214672	30600	Economy	14000.00
0005432428947	30600	Economy	14000.00
0005434067922	30600	Economy	14000.00
0005432528588	30600	Economy	14000.00
0005434067944	30600	Economy	14000.00
0005435214644	30600	Economy	14000.00
0005432528886	30600	Economy	14000.00
0005434067897	30600	Economy	14000.00
0005432529345	30600	Economy	14000.00
0005432529318	30600	Economy	14000.00
0005432528615	30600	Economy	14000.00
0005432528873	30600	Economy	14000.00
0005432529263	30600	Economy	14000.00
0005435214649	30600	Economy	14000.00
0005435214684	30600	Economy	14000.00
0005435283419	30600	Economy	14000.00
0005432159931	30600	Economy	14000.00
0005434067938	30600	Economy	14000.00
0005434067844	30600	Economy	14000.00
0005432529158	30600	Economy	14000.00
0005432529616	30600	Economy	14000.00
0005432529615	30600	Economy	14000.00
0005435214656	30600	Economy	14000.00
0005432529049	30600	Economy	14000.00
0005435214650	30600	Economy	14000.00
0005432535877	30600	Economy	14000.00
0005435214633	30600	Economy	14000.00
0005432529008	30600	Economy	14000.00
0005432211622	30600	Economy	14000.00
0005435725682	30600	Economy	14000.00
0005432529703	30600	Economy	14000.00
0005435214679	30600	Economy	14000.00
0005435214685	30600	Economy	14000.00
0005432528948	30600	Economy	14000.00
0005432529154	30600	Economy	14000.00
0005432528733	30600	Economy	14000.00
0005435631019	30600	Economy	14000.00
0005432529426	30600	Economy	14000.00
0005435214636	30600	Economy	14000.00
0005434068064	30600	Economy	14000.00
0005432529079	30600	Economy	14000.00
0005434068063	30600	Economy	14000.00
0005435214637	30600	Economy	14000.00
0005434067997	30600	Economy	14000.00
0005432528922	30600	Economy	15400.00
0005432211624	30600	Economy	14000.00
0005435214676	30600	Economy	15400.00
0005435214643	30600	Economy	15400.00
0005432529237	30600	Economy	14000.00
0005435631016	30600	Economy	14000.00
0005435214665	30600	Economy	15400.00
0005432529704	30600	Economy	15400.00
0005432533317	30600	Economy	14000.00
0005435214618	30600	Economy	15400.00
0005432529118	30600	Economy	14000.00
0005435214671	30600	Economy	14000.00
0005432528933	30600	Economy	14000.00
0005435214662	30600	Economy	14000.00
0005432528946	30600	Economy	14000.00
0005432535867	30600	Economy	14000.00
0005435283416	30600	Economy	14000.00
0005432537075	30600	Economy	14000.00
0005434067891	30600	Economy	14000.00
0005432528530	30600	Economy	14000.00
0005435631020	30600	Economy	14000.00
0005434067924	30600	Economy	14000.00
0005434067925	30600	Economy	14000.00
0005435214647	30600	Economy	14000.00
0005434068230	30600	Economy	14000.00
0005434068126	30600	Economy	14000.00
0005434067808	30600	Economy	14000.00
0005432159935	30600	Economy	14000.00
0005435214659	30600	Economy	14000.00
0005432529636	30600	Economy	14000.00
0005432528795	30600	Economy	14000.00
0005432528945	30600	Economy	14000.00
0005432528844	30600	Economy	14000.00
0005432529249	30600	Economy	14000.00
0005434068072	30600	Economy	14000.00
0005435214668	30600	Economy	14000.00
0005435214681	30600	Economy	14000.00
0005432528897	30600	Economy	14000.00
0005435214621	30600	Economy	14000.00
0005435214622	30600	Economy	14000.00
0005432529637	30600	Economy	14000.00
0005432529217	30600	Economy	14000.00
0005434068000	30600	Economy	14000.00
0005434067946	30600	Economy	14000.00
0005432528921	30600	Economy	14000.00
0005432529121	30600	Economy	14000.00
0005434067913	30600	Economy	14000.00
0005435725684	30600	Economy	14000.00
0005432529276	30600	Economy	14000.00
0005432529168	30600	Economy	14000.00
0005432528750	30600	Economy	14000.00
0005432528896	30600	Economy	14000.00
0005435214657	30600	Economy	14000.00
0005435283417	30600	Economy	14000.00
0005432529292	30600	Economy	14000.00
0005432528893	30600	Economy	14000.00
0005432533318	30600	Economy	14000.00
0005432535873	30600	Economy	14000.00
0005435214655	30600	Economy	14000.00
0005432528567	30600	Economy	14000.00
0005432528908	30600	Economy	14000.00
0005435214683	30600	Economy	14000.00
0005435214661	30600	Economy	14000.00
0005432529425	30600	Economy	14000.00
0005432211625	30600	Economy	14000.00
0005434068194	30600	Economy	14000.00
0005432528495	30600	Economy	14000.00
0005435214620	30600	Economy	14000.00
0005432428956	30600	Economy	14000.00
0005432529002	30600	Economy	14000.00
0005432529001	30600	Economy	14000.00
0005432528601	30600	Economy	14000.00
0005434067871	30600	Economy	14000.00
0005432529829	30600	Economy	14000.00
0005432533324	30600	Economy	14000.00
0005434068359	30600	Economy	14000.00
0005432529058	30600	Economy	14000.00
0005432537080	30600	Economy	14000.00
0005434068038	30600	Economy	14000.00
0005432533309	30600	Economy	14000.00
0005434068137	30600	Economy	14000.00
0005435214652	30600	Economy	14000.00
0005434067860	30600	Economy	14000.00
0005432528322	30600	Economy	14000.00
0005432528335	30600	Economy	14000.00
0005432528752	30600	Economy	14000.00
0005435214627	30600	Economy	14000.00
0005432211623	30600	Economy	14000.00
0005435214640	30600	Economy	14000.00
0005432529380	30600	Economy	14000.00
0005435214670	30600	Economy	14000.00
0005432537071	30600	Economy	14000.00
0005434068139	30600	Economy	14000.00
0005434068136	30600	Economy	14000.00
0005432529273	30600	Economy	14000.00
0005435214680	30600	Economy	14000.00
0005435725683	30600	Economy	14000.00
0005434068066	30600	Economy	15400.00
0005432528706	30600	Economy	15400.00
0005432528934	30600	Economy	15400.00
0005434068095	30600	Economy	15400.00
0005432529073	30600	Economy	15400.00
0005434068237	30600	Economy	14000.00
0005434067905	30600	Economy	14000.00
0005432528895	30600	Economy	14000.00
0005432528923	30600	Economy	14000.00
0005435214630	30600	Economy	14000.00
0005434068181	30600	Economy	14000.00
0005434067869	30600	Economy	14000.00
0005434067643	30600	Economy	14000.00
0005432528924	30600	Economy	14000.00
0005435214642	30600	Economy	14000.00
0005432528323	30600	Economy	14000.00
0005432529391	30600	Economy	14000.00
0005432528763	30600	Economy	14000.00
0005432528781	30600	Economy	14000.00
0005432529123	30600	Economy	14000.00
0005432529219	30600	Economy	14000.00
0005435214625	30600	Economy	14000.00
0005435214673	30600	Economy	14000.00
0005435214629	30600	Economy	14000.00
0005432528979	30600	Economy	14000.00
0005432211620	30600	Economy	14000.00
0005432159932	30600	Economy	14000.00
0005432211626	30600	Economy	14000.00
0005435214646	30600	Economy	14000.00
0005435214651	30600	Economy	14000.00
0005434068189	30600	Economy	14000.00
0005435214632	30600	Economy	14000.00
0005432528587	30600	Economy	14000.00
0005435214667	30600	Economy	14000.00
0005435214654	30600	Economy	14000.00
0005432529351	30600	Economy	14000.00
0005432529453	30600	Economy	14000.00
0005435214645	30600	Economy	14000.00
0005435214617	30600	Economy	14000.00
0005432529296	30600	Economy	14000.00
0005432529377	30600	Economy	14000.00
0005434068094	30600	Economy	14000.00
0005432529277	30600	Economy	14000.00
0005432535872	30600	Economy	14000.00
0005434067715	30600	Economy	14000.00
0005432529163	30600	Economy	14000.00
0005434068107	30600	Economy	14000.00
0005433656727	30600	Economy	14000.00
0005432528991	30600	Economy	14000.00
0005434068053	30600	Economy	14000.00
0005434067945	30600	Economy	14000.00
0005432529122	30600	Economy	14000.00
0005434067960	30600	Economy	14000.00
0005434068097	30600	Economy	14000.00
0005434067581	30600	Economy	14000.00
0005432533308	30600	Economy	14000.00
0005432528894	30600	Economy	14000.00
0005434068253	30600	Economy	14000.00
0005432528751	30600	Economy	14000.00
0005433656725	30600	Economy	14000.00
0005432529635	30600	Economy	14000.00
0005432159934	30600	Economy	14000.00
0005434067890	30600	Economy	14000.00
0005434068024	30600	Economy	14000.00
0005435214624	30600	Economy	14000.00
0005435631018	30600	Economy	14000.00
0005434068067	30600	Economy	14000.00
0005435725681	30600	Economy	14000.00
0005432528529	30600	Economy	14000.00
0005432528580	30600	Economy	14000.00
0005432529331	30600	Economy	14000.00
0005435214626	30600	Economy	14000.00
0005434067717	30600	Economy	14000.00
0005432529412	30600	Economy	14000.00
0005432528573	30600	Economy	14000.00
0005434067874	30600	Economy	14000.00
0005432528938	30600	Economy	14000.00
0005434067859	30600	Economy	14000.00
0005434068153	30600	Economy	14000.00
0005435214664	30600	Economy	14000.00
0005432211621	30600	Economy	14000.00
0005435214660	30600	Economy	14000.00
0005435214682	30600	Economy	14000.00
0005432159933	30600	Economy	14000.00
0005434068140	30600	Economy	14000.00
0005434067716	30600	Economy	14000.00
0005432529382	30600	Economy	14000.00
0005432529117	30600	Economy	14000.00
0005434068188	30600	Economy	14000.00
0005432528579	30600	Economy	14000.00
0005432528667	30600	Economy	14000.00
0005432529257	30600	Economy	14000.00
0005432529291	30600	Economy	14000.00
0005432537074	30600	Economy	14000.00
0005432529451	30600	Economy	14000.00
0005432529009	30600	Economy	14000.00
0005434067582	30600	Economy	14000.00
0005435653301	24876	Business	9800.00
0005435653392	24876	Business	9800.00
0005435653354	24876	Business	9800.00
0005435653357	24876	Business	9800.00
0005433368511	24876	Business	9800.00
0005435653403	24876	Business	9800.00
0005435653363	24876	Business	9800.00
0005433368509	24876	Business	9800.00
0005433368506	24876	Business	9800.00
0005433368507	24876	Business	9800.00
0005435653240	24876	Economy	3300.00
0005433368501	24876	Economy	3300.00
0005433368494	24876	Economy	3300.00
0005433368492	24876	Economy	3300.00
0005435653277	24876	Economy	3300.00
0005435653291	24876	Economy	3300.00
0005433368508	24876	Economy	3300.00
0005435653352	24876	Economy	3600.00
0005435653342	24876	Economy	3600.00
0005435653158	24876	Economy	3600.00
0005435653266	24876	Economy	3600.00
0005435653375	24876	Economy	3600.00
0005433368521	24876	Economy	3300.00
0005433368518	24876	Economy	3300.00
0005435653402	24876	Economy	3300.00
0005433368499	24876	Economy	3300.00
0005435653320	24876	Economy	3300.00
0005433368487	24876	Economy	3300.00
0005435653275	24876	Economy	3300.00
0005435653282	24876	Economy	3300.00
0005435653302	24876	Economy	3300.00
0005435653319	24876	Economy	3300.00
0005435653373	24876	Economy	3300.00
0005435653395	24876	Economy	3300.00
0005435653313	24876	Economy	3300.00
0005433368520	24876	Economy	3300.00
0005433368510	24876	Economy	3300.00
0005433368519	24876	Economy	3300.00
0005435653393	24876	Economy	3300.00
0005433368513	24876	Economy	3300.00
0005433368512	24876	Economy	3300.00
0005433368516	24876	Economy	3300.00
0005433368497	24876	Economy	3300.00
0005433368502	24876	Economy	3300.00
0005435653374	24876	Economy	3300.00
0005435653356	24876	Economy	3300.00
0005435653231	24876	Economy	3300.00
0005433368503	24876	Economy	3300.00
0005435653203	24876	Economy	3300.00
0005433368515	24876	Economy	3300.00
0005435653345	24876	Economy	3300.00
0005435653366	24876	Economy	3300.00
0005435653299	24876	Economy	3300.00
0005435653404	24876	Economy	3300.00
0005433368523	24876	Economy	3300.00
0005435653276	24876	Economy	3300.00
0005433368493	24876	Economy	3300.00
0005435653284	24876	Economy	3300.00
0005433368522	24876	Economy	3300.00
0005435653394	24876	Economy	3300.00
0005433368498	24876	Economy	3300.00
0005433368491	24876	Economy	3300.00
0005435653143	24876	Economy	3300.00
0005435653273	24876	Economy	3300.00
0005435653312	24876	Economy	3300.00
0005435653171	24876	Economy	3300.00
0005435653235	24876	Economy	3300.00
0005433368505	24876	Economy	3300.00
0005433368489	24876	Economy	3300.00
0005433368517	24876	Economy	3300.00
0005433368495	24876	Economy	3300.00
0005435653341	24876	Economy	3300.00
0005435653232	24876	Economy	3300.00
0005433368490	24876	Economy	3300.00
0005435653230	24876	Economy	3300.00
0005435653096	24876	Economy	3300.00
0005433368488	24876	Economy	3300.00
0005435653388	24876	Economy	3300.00
0005435653353	24876	Economy	3300.00
0005435653364	24876	Economy	3300.00
0005433368500	24876	Economy	3300.00
0005433368496	24876	Economy	3300.00
0005433368514	24876	Economy	3300.00
0005433368504	24876	Economy	3300.00
0005434980274	2073	Economy	10500.00
0005434980292	2073	Economy	10500.00
0005434980277	2073	Economy	10500.00
0005434980286	2073	Economy	9500.00
0005434980278	2073	Economy	9500.00
0005435801746	2073	Economy	9500.00
0005434980268	2073	Economy	9500.00
0005435801747	2073	Economy	9500.00
0005434980290	2073	Economy	9500.00
0005434980293	2073	Economy	9500.00
0005434980291	2073	Economy	9500.00
0005434980297	2073	Economy	9500.00
0005434980279	2073	Economy	9500.00
0005434980285	2073	Economy	9500.00
0005434980289	2073	Economy	9500.00
0005434980275	2073	Economy	9500.00
0005434980294	2073	Economy	9500.00
0005434980295	2073	Economy	9500.00
0005434980276	2073	Economy	9500.00
0005434980296	2073	Economy	9500.00
0005434980273	2073	Economy	9500.00
0005434980272	2073	Economy	9500.00
0005435801748	2073	Economy	9500.00
0005434980281	2073	Economy	9500.00
0005434980284	2073	Economy	9500.00
0005434980271	2073	Economy	9500.00
0005434980288	2073	Economy	9500.00
0005434980287	2073	Economy	9500.00
0005434980269	2073	Economy	9500.00
0005434980283	2073	Economy	9500.00
0005434980282	2073	Economy	9500.00
0005434980280	2073	Economy	9500.00
0005434980270	2073	Economy	9500.00
0005434980267	2073	Economy	9500.00
0005434979943	23529	Economy	10500.00
0005434979926	23529	Economy	10500.00
0005434979960	23529	Economy	9500.00
0005434979935	23529	Economy	9500.00
0005434979946	23529	Economy	9500.00
0005434979852	23529	Economy	9500.00
0005434980028	23529	Economy	9500.00
0005434980005	23529	Economy	9500.00
0005434979997	23529	Economy	9500.00
0005434980046	23529	Economy	9500.00
0005434980021	23529	Economy	9500.00
0005434980009	23529	Economy	9500.00
0005434980082	23529	Economy	9500.00
0005434979915	23529	Economy	9500.00
0005434979910	23529	Economy	9500.00
0005434980047	23529	Economy	9500.00
0005434980016	23529	Economy	9500.00
0005434980002	23529	Economy	9500.00
0005434980040	23529	Economy	9500.00
0005434979883	23529	Economy	9500.00
0005434980089	23529	Economy	9500.00
0005434979916	23529	Economy	9500.00
0005434980039	23529	Economy	9500.00
0005434979800	23529	Economy	9500.00
0005434979944	23529	Economy	9500.00
0005434980088	23529	Economy	9500.00
0005434980022	23529	Economy	9500.00
0005434980048	23529	Economy	9500.00
0005434979942	23529	Economy	9500.00
0005434979887	23529	Economy	9500.00
0005434980019	23529	Economy	9500.00
0005434979927	23529	Economy	9500.00
0005434980001	23529	Economy	9500.00
0005434979961	23529	Economy	9500.00
0005434980075	23529	Economy	9500.00
0005434979934	23529	Economy	9500.00
0005435801731	23529	Economy	9500.00
0005434979914	23529	Economy	9500.00
0005435801734	23529	Economy	9500.00
0005435801714	23529	Economy	9500.00
0005434979890	23529	Economy	9500.00
0005434979867	23529	Economy	9500.00
0005434980015	23529	Economy	9500.00
0005434952591	2567	Economy	5300.00
0005434952592	2567	Economy	5300.00
0005434952594	2567	Economy	5300.00
0005434952593	2567	Economy	5300.00
0005433256449	2676	Economy	5300.00
0005433256448	2676	Economy	5300.00
0005434952559	28251	Economy	5300.00
0005434952548	28251	Economy	5300.00
0005434952560	28251	Economy	5300.00
0005434952558	28251	Economy	5300.00
0005434952561	28251	Economy	5300.00
0005434952565	28251	Economy	5300.00
0005434952549	28251	Economy	5300.00
0005433111543	19759	Economy	8700.00
0005433112400	19759	Economy	8700.00
0005433112401	19759	Economy	8700.00
0005433112399	19759	Economy	8700.00
0005434138916	11914	Business	9700.00
0005434138533	11914	Business	9700.00
0005434138600	11914	Business	9700.00
0005434138646	11914	Business	9700.00
0005434138210	11914	Business	9700.00
0005434138964	11914	Business	9700.00
0005434138532	11914	Business	9700.00
0005434138821	11914	Business	9700.00
0005434138917	11914	Business	9700.00
0005434138552	11914	Economy	3200.00
0005434138737	11914	Economy	3200.00
0005434138797	11914	Economy	3200.00
0005434138513	11914	Economy	3200.00
0005434138609	11914	Economy	3200.00
0005434138716	11914	Economy	3200.00
0005434138755	11914	Economy	3200.00
0005434138886	11914	Economy	3200.00
0005434138978	11914	Economy	3500.00
0005434138250	11914	Economy	3500.00
0005434138649	11914	Economy	3500.00
0005434138046	11914	Economy	3500.00
0005434138424	11914	Economy	3500.00
0005434138681	11914	Economy	3200.00
0005434138571	11914	Economy	3200.00
0005434138631	11914	Economy	3200.00
0005434138045	11914	Economy	3200.00
0005434138700	11914	Economy	3200.00
0005434138812	11914	Economy	3200.00
0005434138570	11914	Economy	3200.00
0005434138759	11914	Economy	3200.00
0005434138607	11914	Economy	3200.00
0005434138840	11914	Economy	3200.00
0005434138810	11914	Economy	3200.00
0005434138608	11914	Economy	3200.00
0005434138527	11914	Economy	3200.00
0005434138934	11914	Economy	3200.00
0005434138887	11914	Economy	3200.00
0005434138796	11914	Economy	3200.00
0005434138813	11914	Economy	3200.00
0005434138565	11914	Economy	3200.00
0005434138783	11914	Economy	3200.00
0005434138691	11914	Economy	3200.00
0005434138376	11914	Economy	3200.00
0005434138969	11914	Economy	3200.00
0005434138892	11914	Economy	3200.00
0005434138554	11914	Economy	3200.00
0005434138610	11914	Economy	3200.00
0005434138971	11914	Economy	3200.00
0005434138680	11914	Economy	3200.00
0005434138941	11914	Economy	3200.00
0005434138756	11914	Economy	3200.00
0005434138375	11914	Economy	3200.00
0005434138526	11914	Economy	3200.00
0005434138645	11914	Economy	3200.00
0005434138211	11914	Economy	3200.00
0005434138767	11914	Economy	3200.00
0005434138811	11914	Economy	3200.00
0005434138858	11914	Economy	3200.00
0005434138879	11914	Economy	3200.00
0005434138963	11914	Economy	3200.00
0005434138612	11914	Economy	3200.00
0005434138739	11914	Economy	3200.00
0005434138882	11914	Economy	3200.00
0005434138942	11914	Economy	3200.00
0005434138611	11914	Economy	3200.00
0005434138856	11914	Economy	3200.00
0005434138692	11914	Economy	3200.00
0005434138857	11914	Economy	3200.00
0005434138629	11914	Economy	3200.00
0005434138867	11914	Economy	3200.00
0005434138630	11914	Economy	3200.00
0005434138846	11914	Economy	3200.00
0005434138679	11914	Economy	3200.00
0005434138933	11914	Economy	3200.00
0005434138599	11914	Economy	3200.00
0005434138636	11914	Economy	3200.00
0005434138918	11914	Economy	3200.00
0005434138635	11914	Economy	3200.00
0005434138470	11914	Economy	3200.00
0005434138648	11914	Economy	3200.00
0005434138684	11914	Economy	3200.00
0005434138553	11914	Economy	3200.00
0005434138881	11914	Economy	3200.00
0005434138944	11914	Economy	3200.00
0005434138738	11914	Economy	3200.00
0005434138773	11914	Economy	3200.00
0005434139400	28712	Business	9700.00
0005434139426	28712	Business	9700.00
0005434139459	28712	Business	9700.00
0005434139391	28712	Business	9700.00
0005434139418	28712	Business	9700.00
0005434139432	28712	Business	9700.00
0005434139420	28712	Business	9700.00
0005434139404	28712	Business	9700.00
0005434139407	28712	Economy	3200.00
0005434139397	28712	Economy	3200.00
0005434139411	28712	Economy	3200.00
0005434139424	28712	Economy	3200.00
0005434139393	28712	Economy	3200.00
0005434139394	28712	Economy	3200.00
0005434139440	28712	Economy	3200.00
0005434139384	28712	Economy	3200.00
0005434139436	28712	Economy	3200.00
0005434139405	28712	Economy	3500.00
0005434139410	28712	Economy	3500.00
0005434139453	28712	Economy	3500.00
0005434139438	28712	Economy	3500.00
0005434139419	28712	Economy	3200.00
0005434139388	28712	Economy	3200.00
0005434139398	28712	Economy	3200.00
0005434139451	28712	Economy	3200.00
0005434139430	28712	Economy	3200.00
0005434139422	28712	Economy	3200.00
0005434139425	28712	Economy	3200.00
0005434139383	28712	Economy	3200.00
0005434139428	28712	Economy	3200.00
0005434139415	28712	Economy	3200.00
0005434139385	28712	Economy	3200.00
0005434139435	28712	Economy	3200.00
0005434139401	28712	Economy	3200.00
0005434139458	28712	Economy	3200.00
0005434139441	28712	Economy	3200.00
0005434139446	28712	Economy	3200.00
0005434139456	28712	Economy	3200.00
0005434139445	28712	Economy	3200.00
0005434139417	28712	Economy	3200.00
0005434139448	28712	Economy	3200.00
0005434139414	28712	Economy	3200.00
0005434139447	28712	Economy	3200.00
0005434139408	28712	Economy	3200.00
0005434139444	28712	Economy	3200.00
0005434139434	28712	Economy	3200.00
0005434139421	28712	Economy	3200.00
0005434139423	28712	Economy	3200.00
0005434139437	28712	Economy	3200.00
0005434139431	28712	Economy	3200.00
0005434139427	28712	Economy	3200.00
0005434139387	28712	Economy	3200.00
0005434139390	28712	Economy	3200.00
0005434139399	28712	Economy	3200.00
0005434139395	28712	Economy	3200.00
0005434139389	28712	Economy	3200.00
0005434139449	28712	Economy	3200.00
0005434139386	28712	Economy	3200.00
0005434139439	28712	Economy	3200.00
0005434139461	28712	Economy	3200.00
0005434139413	28712	Economy	3200.00
0005434139412	28712	Economy	3200.00
0005434139409	28712	Economy	3200.00
0005434139442	28712	Economy	3200.00
0005434139392	28712	Economy	3200.00
0005434139403	28712	Economy	3200.00
0005434139455	28712	Economy	3200.00
0005434139457	28712	Economy	3200.00
0005434139450	28712	Economy	3200.00
0005434139429	28712	Economy	3200.00
0005434139460	28712	Economy	3200.00
0005434139462	28712	Economy	3200.00
0005434139396	28712	Economy	3200.00
0005434139454	28712	Economy	3200.00
0005434139402	28712	Economy	3200.00
0005434139443	28712	Economy	3200.00
0005434139406	28712	Economy	3200.00
0005434139452	28712	Economy	3200.00
0005434139433	28712	Economy	3200.00
0005434139416	28712	Economy	3200.00
0005433539009	6804	Economy	9900.00
0005433539011	6804	Economy	9900.00
0005435259787	6804	Economy	9900.00
0005433539014	6804	Economy	9900.00
0005435259777	6804	Economy	9900.00
0005433539015	6804	Economy	9900.00
0005435259802	6804	Economy	9900.00
0005433539008	6804	Economy	9900.00
0005433534535	6804	Economy	9900.00
0005433539012	6804	Economy	9900.00
0005435259778	6804	Economy	9900.00
0005433534534	6804	Economy	9900.00
0005433539010	6804	Economy	9900.00
0005433539013	6804	Economy	9900.00
0005433538935	25011	Economy	10900.00
0005433534508	25011	Economy	9900.00
0005433538986	25011	Economy	9900.00
0005433534516	25011	Economy	9900.00
0005433534510	25011	Economy	9900.00
0005433538985	25011	Economy	9900.00
0005435259831	25011	Economy	9900.00
0005435259829	25011	Economy	9900.00
0005433538979	25011	Economy	9900.00
0005433538928	25011	Economy	9900.00
0005433534517	25011	Economy	9900.00
0005433538912	25011	Economy	9900.00
0005435259828	25011	Economy	9900.00
0005433534515	25011	Economy	9900.00
0005435259830	25011	Economy	9900.00
0005433538963	25011	Economy	9900.00
0005435259827	25011	Economy	9900.00
0005433538901	25011	Economy	9900.00
0005433538911	25011	Economy	9900.00
0005432922548	802	Economy	16100.00
0005432922559	802	Economy	16100.00
0005432922561	802	Economy	14600.00
0005433512087	802	Economy	14600.00
0005432922565	802	Economy	14600.00
0005433512094	802	Economy	14600.00
0005433512092	802	Economy	14600.00
0005433512089	802	Economy	14600.00
0005433512088	802	Economy	14600.00
0005433512093	802	Economy	14600.00
0005432922562	802	Economy	14600.00
0005433512090	802	Economy	14600.00
0005433512091	802	Economy	14600.00
0005432922592	16175	Economy	14600.00
0005433512023	16175	Economy	14600.00
0005433512004	16175	Economy	14600.00
0005433512037	16175	Economy	14600.00
0005432922593	16175	Economy	14600.00
0005432922594	16175	Economy	14600.00
0005433512029	16175	Economy	14600.00
0005433512038	16175	Economy	14600.00
0005433512028	16175	Economy	14600.00
0005435852611	4040	Economy	13500.00
0005433475769	4040	Economy	12300.00
0005435852598	4040	Economy	12300.00
0005435852592	4040	Economy	12300.00
0005433475775	4040	Economy	12300.00
0005435852595	4040	Economy	12300.00
0005433475777	4040	Economy	12300.00
0005433475780	4040	Economy	12300.00
0005433475778	4040	Economy	12300.00
0005435852588	4040	Economy	12300.00
0005435852590	4040	Economy	12300.00
0005433475779	4040	Economy	12300.00
0005433475770	4040	Economy	12300.00
0005435852599	4040	Economy	12300.00
0005433475773	4040	Economy	12300.00
0005433475768	4040	Economy	12300.00
0005433475776	4040	Economy	12300.00
0005435852581	4040	Economy	12300.00
0005433475771	4040	Economy	12300.00
0005435852580	4040	Economy	12300.00
0005433475772	4040	Economy	12300.00
0005435852593	4040	Economy	12300.00
0005433475774	4040	Economy	12300.00
0005435697803	3670	Economy	7900.00
0005435697804	3670	Economy	7900.00
0005435697792	3670	Economy	7900.00
0005435697814	3670	Economy	7900.00
0005435697798	3670	Economy	7200.00
0005435697794	3670	Economy	7200.00
0005434950602	3670	Economy	7200.00
0005435697793	3670	Economy	7200.00
0005435697812	3670	Economy	7200.00
0005435697796	3670	Economy	7200.00
0005435697791	3670	Economy	7200.00
0005435697802	3670	Economy	7200.00
0005435697800	3670	Economy	7200.00
0005435697807	3670	Economy	7200.00
0005435697806	3670	Economy	7200.00
0005435697797	3670	Economy	7200.00
0005435697810	3670	Economy	7200.00
0005435697809	3670	Economy	7200.00
0005435697818	3670	Economy	7200.00
0005435697811	3670	Economy	7200.00
0005435697815	3670	Economy	7200.00
0005435697805	3670	Economy	7200.00
0005434950603	3670	Economy	7200.00
0005435697816	3670	Economy	7200.00
0005435697795	3670	Economy	7200.00
0005434950605	3670	Economy	7200.00
0005434950604	3670	Economy	7200.00
0005435697817	3670	Economy	7200.00
0005435697808	3670	Economy	7200.00
0005435697801	3670	Economy	7200.00
0005435697799	3670	Economy	7200.00
0005435697813	3670	Economy	7200.00
0005435697529	16264	Economy	7900.00
0005435697585	16264	Economy	7900.00
0005435697478	16264	Economy	7900.00
0005434950545	16264	Economy	7200.00
0005435697535	16264	Economy	7200.00
0005435697481	16264	Economy	7200.00
0005434950543	16264	Economy	7200.00
0005435697575	16264	Economy	7200.00
0005435697559	16264	Economy	7200.00
0005435697476	16264	Economy	7200.00
0005435697480	16264	Economy	7200.00
0005435697557	16264	Economy	7200.00
0005435697531	16264	Economy	7200.00
0005434950574	16264	Economy	7200.00
0005435697597	16264	Economy	7200.00
0005435697587	16264	Economy	7200.00
0005435697616	16264	Economy	7200.00
0005435916211	16264	Economy	7200.00
0005435697573	16264	Economy	7200.00
0005435935093	16264	Economy	7200.00
0005434950576	16264	Economy	7200.00
0005435697588	16264	Economy	7200.00
0005435697598	16264	Economy	7200.00
0005435697448	16264	Economy	7200.00
0005435697496	16264	Economy	7200.00
0005434950546	16264	Economy	7200.00
0005435697567	16264	Economy	7200.00
0005434950575	16264	Economy	7200.00
0005435697487	16264	Economy	7200.00
0005435697572	16264	Economy	7200.00
0005435697511	16264	Economy	7200.00
0005434950554	16264	Economy	7200.00
0005435916213	16264	Economy	7200.00
0005434950544	16264	Economy	7200.00
0005435916214	16264	Economy	7200.00
0005435916212	16264	Economy	7200.00
0005435935094	16264	Economy	7200.00
0005435697617	16264	Economy	7200.00
0005435697534	16264	Economy	7200.00
0005432609797	3946	Economy	21300.00
0005432609800	3946	Economy	21300.00
0005432607637	3946	Economy	19300.00
0005432607635	3946	Economy	19300.00
0005432607632	3946	Economy	19300.00
0005435842335	3946	Economy	19300.00
0005434604954	3946	Economy	19300.00
0005432607636	3946	Economy	19300.00
0005433519532	3946	Economy	19300.00
0005432609798	3946	Economy	19300.00
0005435904708	3946	Economy	19300.00
0005435853626	3946	Economy	19300.00
0005433519534	3946	Economy	19300.00
0005434606881	3946	Economy	19300.00
0005434604953	3946	Economy	19300.00
0005433519535	3946	Economy	19300.00
0005434604955	3946	Economy	19300.00
0005433519533	3946	Economy	19300.00
0005432607633	3946	Economy	19300.00
0005434604956	3946	Economy	19300.00
0005432607634	3946	Economy	19300.00
0005433519531	3946	Economy	19300.00
0005434606882	3946	Economy	19300.00
0005435842336	3946	Economy	19300.00
0005432609799	3946	Economy	19300.00
0005434606857	22031	Economy	19300.00
0005434606836	22031	Economy	19300.00
0005435853642	22031	Economy	19300.00
0005435853641	22031	Economy	19300.00
0005433519496	22031	Economy	19300.00
0005433519500	22031	Economy	19300.00
0005434606837	22031	Economy	19300.00
0005433519495	22031	Economy	19300.00
0005435853640	22031	Economy	19300.00
0005434606834	22031	Economy	19300.00
0005434606856	22031	Economy	19300.00
0005433349021	691	Economy	3700.00
0005433349043	691	Economy	3700.00
0005433349033	691	Economy	3700.00
0005433349042	691	Economy	3700.00
0005435628780	691	Economy	3700.00
0005435628781	691	Economy	3700.00
0005433349084	15884	Economy	3700.00
0005435628748	15884	Economy	3700.00
0005435628753	15884	Economy	3700.00
0005433349087	15884	Economy	3700.00
0005435628758	15884	Economy	3700.00
0005435628732	15884	Economy	3700.00
0005433349083	15884	Economy	3700.00
0005433349085	15884	Economy	3700.00
0005433349088	15884	Economy	3700.00
0005433349086	15884	Economy	3700.00
0005433158146	17246	Economy	7100.00
0005434445276	17246	Economy	7100.00
0005434445275	17246	Economy	7100.00
0005433159323	17246	Economy	7100.00
0005433159333	17246	Economy	7100.00
0005434445277	17246	Economy	7100.00
0005434446554	17246	Economy	7100.00
0005433159322	17246	Economy	7100.00
0005433158141	17246	Economy	7100.00
0005433159334	17246	Economy	7100.00
0005433159351	17643	Economy	7100.00
0005433159350	17643	Economy	7100.00
0005435383208	7902	Economy	5900.00
0005435133061	7902	Economy	5900.00
0005435133056	7902	Economy	5400.00
0005435133054	7902	Economy	5400.00
0005435133053	7902	Economy	5400.00
0005435133062	7902	Economy	5400.00
0005435383206	7902	Economy	5400.00
0005435133057	7902	Economy	5400.00
0005435133055	7902	Economy	5400.00
0005435133059	7902	Economy	5400.00
0005435383207	7902	Economy	5400.00
0005435383196	7902	Economy	5400.00
0005435133060	7902	Economy	5400.00
0005435383204	7902	Economy	5400.00
0005435133058	7902	Economy	5400.00
0005435383240	33091	Economy	5900.00
0005435383238	33091	Economy	5900.00
0005435132952	33091	Economy	5400.00
0005435383241	33091	Economy	5400.00
0005435383237	33091	Economy	5400.00
0005435383242	33091	Economy	5400.00
0005435132970	33091	Economy	5400.00
0005435132951	33091	Economy	5400.00
0005435383239	33091	Economy	5400.00
0005435132983	33091	Economy	5400.00
0005435160485	7511	Economy	13800.00
0005435160486	7511	Economy	12500.00
0005435390274	7511	Economy	12500.00
0005435390287	7511	Economy	12500.00
0005435160484	7511	Economy	12500.00
0005435160483	7511	Economy	12500.00
0005435390272	7511	Economy	12500.00
0005435390299	7511	Economy	12500.00
0005435390313	7511	Economy	12500.00
0005435160488	7511	Economy	12500.00
0005435160491	7511	Economy	12500.00
0005435390273	7511	Economy	12500.00
0005435160482	7511	Economy	12500.00
0005435390291	7511	Economy	12500.00
0005435160487	7511	Economy	12500.00
0005435390290	7511	Economy	12500.00
0005435160489	7511	Economy	12500.00
0005435390292	7511	Economy	12500.00
0005435160481	7511	Economy	12500.00
0005435390288	7511	Economy	12500.00
0005435160490	7511	Economy	12500.00
0005435160492	7511	Economy	12500.00
0005435390314	7511	Economy	12500.00
0005435390268	7511	Economy	12500.00
0005435390298	7511	Economy	12500.00
0005435390355	29576	Economy	13800.00
0005435160401	29576	Economy	13800.00
0005435160324	29576	Economy	12500.00
0005435390354	29576	Economy	12500.00
0005435390358	29576	Economy	12500.00
0005435160422	29576	Economy	12500.00
0005435160365	29576	Economy	12500.00
0005435160400	29576	Economy	12500.00
0005435160380	29576	Economy	12500.00
0005435160415	29576	Economy	12500.00
0005435160388	29576	Economy	12500.00
0005435160399	29576	Economy	12500.00
0005435160387	29576	Economy	12500.00
0005435160446	29576	Economy	12500.00
0005435160447	29576	Economy	12500.00
0005435160416	29576	Economy	12500.00
0005435390356	29576	Economy	12500.00
0005435160325	29576	Economy	12500.00
0005435160358	29576	Economy	12500.00
0005435160417	29576	Economy	12500.00
0005435390352	29576	Economy	12500.00
0005435390353	29576	Economy	12500.00
0005435160391	29576	Economy	12500.00
0005435390357	29576	Economy	12500.00
0005435160381	29576	Economy	12500.00
0005435160432	29576	Economy	12500.00
0005435160390	29576	Economy	12500.00
0005435179007	18434	Economy	4900.00
0005432394154	18434	Economy	4900.00
0005432398234	18434	Economy	4900.00
0005432394153	18434	Economy	4900.00
0005432398220	18434	Economy	4900.00
0005435178521	18434	Economy	4900.00
0005432398233	18434	Economy	4900.00
0005435179008	18434	Economy	4900.00
0005435178520	18434	Economy	4900.00
0005432398256	27135	Economy	4900.00
0005432400180	27135	Economy	4900.00
0005432400182	27135	Economy	4900.00
0005432398255	27135	Economy	4900.00
0005432398254	27135	Economy	4900.00
0005432398257	27135	Economy	4900.00
0005435179400	27135	Economy	4900.00
0005435179401	27135	Economy	4900.00
0005435178504	27135	Economy	4900.00
0005432400181	27135	Economy	4900.00
0005432400179	27135	Economy	4900.00
0005435178498	27135	Economy	4900.00
0005434191293	9752	Economy	4400.00
0005434504809	6513	Business	48400.00
0005434504817	6513	Business	48400.00
0005434504800	6513	Business	48400.00
0005434504805	6513	Business	48400.00
0005434504819	6513	Economy	16100.00
0005434504788	6513	Economy	16100.00
0005434504813	6513	Economy	17800.00
0005434504811	6513	Economy	16100.00
0005434504816	6513	Economy	16100.00
0005434504787	6513	Economy	16100.00
0005434504792	6513	Economy	16100.00
0005435104062	6513	Economy	16100.00
0005435104064	6513	Economy	16100.00
0005435104063	6513	Economy	16100.00
0005434504795	6513	Economy	16100.00
0005435104066	6513	Economy	16100.00
0005434504802	6513	Economy	16100.00
0005434504810	6513	Economy	16100.00
0005434504822	6513	Economy	16100.00
0005434504824	6513	Economy	16100.00
0005434504797	6513	Economy	16100.00
0005434504808	6513	Economy	16100.00
0005434504793	6513	Economy	16100.00
0005434504807	6513	Economy	16100.00
0005434504789	6513	Economy	16100.00
0005434504806	6513	Economy	16100.00
0005434504790	6513	Economy	16100.00
0005434504803	6513	Economy	16100.00
0005434504825	6513	Economy	16100.00
0005434504798	6513	Economy	16100.00
0005434504799	6513	Economy	16100.00
0005435104065	6513	Economy	16100.00
0005434504821	6513	Economy	16100.00
0005434504801	6513	Economy	16100.00
0005434504814	6513	Economy	16100.00
0005434504791	6513	Economy	16100.00
0005434504820	6513	Economy	16100.00
0005434504815	6513	Economy	16100.00
0005434504812	6513	Economy	16100.00
0005434504796	6513	Economy	16100.00
0005434504794	6513	Economy	16100.00
0005434504823	6513	Economy	16100.00
0005434504818	6513	Economy	16100.00
0005434504804	6513	Economy	16100.00
0005434504318	22668	Business	48400.00
0005434504523	22668	Business	48400.00
0005434504442	22668	Business	48400.00
0005434504504	22668	Economy	16100.00
0005434504351	22668	Economy	16100.00
0005434504336	22668	Economy	16100.00
0005434504524	22668	Economy	16100.00
0005434504326	22668	Economy	16100.00
0005434504419	22668	Economy	17800.00
0005435103965	22668	Economy	17800.00
0005434504364	22668	Economy	16100.00
0005434504196	22668	Economy	16100.00
0005434504453	22668	Economy	16100.00
0005435103958	22668	Economy	16100.00
0005434504542	22668	Economy	16100.00
0005434504197	22668	Economy	16100.00
0005435103954	22668	Economy	16100.00
0005434504521	22668	Economy	16100.00
0005435103967	22668	Economy	16100.00
0005434504501	22668	Economy	16100.00
0005434504482	22668	Economy	16100.00
0005434504199	22668	Economy	16100.00
0005434504541	22668	Economy	16100.00
0005434504478	22668	Economy	16100.00
0005434504230	22668	Economy	16100.00
0005434504376	22668	Economy	16100.00
0005435103964	22668	Economy	16100.00
0005434504503	22668	Economy	16100.00
0005434504481	22668	Economy	16100.00
0005434504622	22668	Economy	16100.00
0005434504413	22668	Economy	16100.00
0005434504198	22668	Economy	16100.00
0005434504073	22668	Economy	16100.00
0005434504486	22668	Economy	16100.00
0005434504335	22668	Economy	16100.00
0005434504384	22668	Economy	16100.00
0005434504072	22668	Economy	16100.00
0005435103966	22668	Economy	16100.00
0005434504424	22668	Economy	16100.00
0005434504233	22668	Economy	16100.00
0005434504363	22668	Economy	16100.00
0005434504448	22668	Economy	16100.00
0005434504417	22668	Economy	16100.00
0005433368143	1665	Business	50000.00
0005433368264	1665	Business	50000.00
0005435653778	1665	Business	50000.00
0005433368110	1665	Business	50000.00
0005435653763	1665	Business	50000.00
0005435653805	1665	Business	50000.00
0005435653768	1665	Business	50000.00
0005435653774	1665	Business	50000.00
0005435653790	1665	Business	50000.00
0005435653771	1665	Business	50000.00
0005435653781	1665	Business	50000.00
0005433368265	1665	Business	50000.00
0005435653764	1665	Economy	16700.00
0005435653804	1665	Economy	16700.00
0005433368206	1665	Economy	16700.00
0005435653769	1665	Economy	16700.00
0005435653765	1665	Economy	16700.00
0005433368317	1665	Economy	16700.00
0005433368118	1665	Economy	16700.00
0005435653797	1665	Economy	16700.00
0005433368246	1665	Economy	16700.00
0005433368059	1665	Economy	18300.00
0005433368273	1665	Economy	18300.00
0005435653757	1665	Economy	18300.00
0005433368103	1665	Economy	18300.00
0005433368245	1665	Economy	18300.00
0005435653788	1665	Economy	16700.00
0005435653777	1665	Economy	16700.00
0005435653807	1665	Economy	16700.00
0005433368064	1665	Economy	16700.00
0005435653766	1665	Economy	16700.00
0005433368065	1665	Economy	16700.00
0005435653791	1665	Economy	16700.00
0005435653758	1665	Economy	16700.00
0005435653796	1665	Economy	16700.00
0005433368070	1665	Economy	16700.00
0005435653780	1665	Economy	16700.00
0005435653759	1665	Economy	16700.00
0005435653767	1665	Economy	16700.00
0005435653762	1665	Economy	16700.00
0005433368207	1665	Economy	16700.00
0005435653782	1665	Economy	16700.00
0005435653776	1665	Economy	16700.00
0005433368194	1665	Economy	16700.00
0005435653801	1665	Economy	16700.00
0005435653795	1665	Economy	16700.00
0005433368237	1665	Economy	16700.00
0005433368075	1665	Economy	16700.00
0005435653809	1665	Economy	16700.00
0005433368186	1665	Economy	16700.00
0005433368366	1665	Economy	16700.00
0005435653773	1665	Economy	16700.00
0005435653803	1665	Economy	16700.00
0005433368017	1665	Economy	16700.00
0005435653784	1665	Economy	16700.00
0005435653792	1665	Economy	16700.00
0005435653802	1665	Economy	16700.00
0005433368060	1665	Economy	16700.00
0005433368310	1665	Economy	16700.00
0005435653770	1665	Economy	16700.00
0005433368205	1665	Economy	16700.00
0005435653786	1665	Economy	16700.00
0005435653808	1665	Economy	16700.00
0005435653783	1665	Economy	16700.00
0005433368303	1665	Economy	16700.00
0005435653787	1665	Economy	16700.00
0005433368130	1665	Economy	16700.00
0005435653775	1665	Economy	16700.00
0005433368367	1665	Economy	16700.00
0005435653789	1665	Economy	16700.00
0005433368304	1665	Economy	16700.00
0005435653806	1665	Economy	16700.00
0005433368069	1665	Economy	16700.00
0005433368149	1665	Economy	16700.00
0005435653794	1665	Economy	16700.00
0005435653799	1665	Economy	16700.00
0005435653798	1665	Economy	16700.00
0005433368116	1665	Economy	16700.00
0005435653760	1665	Economy	16700.00
0005433368302	1665	Economy	16700.00
0005433368208	1665	Economy	16700.00
0005433368199	1665	Economy	16700.00
0005435653793	1665	Economy	16700.00
0005433368172	1665	Economy	16700.00
0005433368274	1665	Economy	16700.00
0005435653810	1665	Economy	16700.00
0005435653800	1665	Economy	16700.00
0005433368117	1665	Economy	16700.00
0005435653785	1665	Economy	16700.00
0005435653761	1665	Economy	16700.00
0005435653779	1665	Economy	16700.00
0005435653772	1665	Economy	16700.00
0005433368511	21720	Business	50000.00
0005433368490	21720	Business	50000.00
0005433368496	21720	Business	50000.00
0005435653266	21720	Business	50000.00
0005433368503	21720	Business	50000.00
0005435653231	21720	Business	50000.00
0005433368506	21720	Business	50000.00
0005433368492	21720	Business	50000.00
0005433368501	21720	Business	50000.00
0005435653402	21720	Business	50000.00
0005435653356	21720	Business	50000.00
0005433368517	21720	Economy	16700.00
0005433368514	21720	Economy	16700.00
0005435653374	21720	Economy	16700.00
0005433368510	21720	Economy	16700.00
0005433368507	21720	Economy	16700.00
0005433368521	21720	Economy	16700.00
0005433368512	21720	Economy	16700.00
0005435653230	21720	Economy	18300.00
0005435653282	21720	Economy	18300.00
0005435653320	21720	Economy	18300.00
0005433368500	21720	Economy	18300.00
0005433368495	21720	Economy	18300.00
0005435653353	21720	Economy	16700.00
0005435653403	21720	Economy	16700.00
0005433368497	21720	Economy	16700.00
0005433368508	21720	Economy	16700.00
0005435653277	21720	Economy	16700.00
0005433368522	21720	Economy	16700.00
0005435653143	21720	Economy	16700.00
0005433368494	21720	Economy	16700.00
0005433368523	21720	Economy	16700.00
0005435653171	21720	Economy	16700.00
0005435653366	21720	Economy	16700.00
0005435653302	21720	Economy	16700.00
0005435653395	21720	Economy	16700.00
0005433368519	21720	Economy	16700.00
0005435653357	21720	Economy	16700.00
0005435653392	21720	Economy	16700.00
0005435653404	21720	Economy	16700.00
0005435653291	21720	Economy	16700.00
0005433368509	21720	Economy	16700.00
0005435653284	21720	Economy	16700.00
0005435653373	21720	Economy	16700.00
0005435653275	21720	Economy	16700.00
0005435653341	21720	Economy	16700.00
0005433368513	21720	Economy	16700.00
0005433368499	21720	Economy	16700.00
0005433368489	21720	Economy	16700.00
0005433368515	21720	Economy	16700.00
0005435653299	21720	Economy	16700.00
0005435653203	21720	Economy	16700.00
0005435653232	21720	Economy	16700.00
0005435653388	21720	Economy	16700.00
0005435653273	21720	Economy	16700.00
0005435653364	21720	Economy	16700.00
0005433368487	21720	Economy	16700.00
0005435653301	21720	Economy	16700.00
0005435653345	21720	Economy	16700.00
0005433368520	21720	Economy	16700.00
0005435653393	21720	Economy	16700.00
0005435653375	21720	Economy	16700.00
0005435653276	21720	Economy	16700.00
0005435653319	21720	Economy	16700.00
0005433368488	21720	Economy	16700.00
0005435653363	21720	Economy	16700.00
0005435653240	21720	Economy	16700.00
0005435653342	21720	Economy	16700.00
0005433368505	21720	Economy	16700.00
0005435653235	21720	Economy	16700.00
0005435653394	21720	Economy	16700.00
0005433368493	21720	Economy	16700.00
0005435653352	21720	Economy	16700.00
0005435653313	21720	Economy	16700.00
0005433368502	21720	Economy	16700.00
0005433368504	21720	Economy	16700.00
0005433368516	21720	Economy	16700.00
0005435653312	21720	Economy	16700.00
0005435653354	21720	Economy	16700.00
0005433368518	21720	Economy	16700.00
0005435653158	21720	Economy	16700.00
0005433368491	21720	Economy	16700.00
0005433368498	21720	Economy	16700.00
0005435653096	21720	Economy	16700.00
0005433986742	4153	Business	21500.00
0005433986727	4153	Business	21500.00
0005433986744	4153	Business	21500.00
0005433986743	4153	Business	21500.00
0005433986718	4153	Business	21500.00
0005433986741	4153	Business	21500.00
0005433986693	4153	Business	21500.00
0005433986738	4153	Business	21500.00
0005433986696	4153	Business	21500.00
0005433986698	4153	Economy	7200.00
0005433986734	4153	Economy	7200.00
0005433986701	4153	Economy	7200.00
0005433986728	4153	Economy	7200.00
0005433986733	4153	Economy	7200.00
0005433986723	4153	Economy	7200.00
0005433986712	4153	Economy	7200.00
0005433986736	4153	Economy	7200.00
0005433986731	4153	Economy	7900.00
0005433986739	4153	Economy	7900.00
0005433986715	4153	Economy	7900.00
0005433986709	4153	Economy	7900.00
0005433986699	4153	Economy	7900.00
0005433986748	4153	Economy	7200.00
0005433986724	4153	Economy	7200.00
0005433986721	4153	Economy	7200.00
0005433986703	4153	Economy	7200.00
0005435788814	4153	Economy	7200.00
0005433986716	4153	Economy	7200.00
0005433986726	4153	Economy	7200.00
0005433986706	4153	Economy	7200.00
0005433986747	4153	Economy	7200.00
0005433986737	4153	Economy	7200.00
0005433986717	4153	Economy	7200.00
0005433986729	4153	Economy	7200.00
0005433986735	4153	Economy	7200.00
0005433986705	4153	Economy	7200.00
0005433986749	4153	Economy	7200.00
0005433986700	4153	Economy	7200.00
0005433986704	4153	Economy	7200.00
0005433986695	4153	Economy	7200.00
0005433986702	4153	Economy	7200.00
0005433986740	4153	Economy	7200.00
0005433986710	4153	Economy	7200.00
0005433986697	4153	Economy	7200.00
0005433986694	4153	Economy	7200.00
0005433986725	4153	Economy	7200.00
0005433986745	4153	Economy	7200.00
0005435788813	4153	Economy	7200.00
0005433986722	4153	Economy	7200.00
0005433986711	4153	Economy	7200.00
0005433986720	4153	Economy	7200.00
0005433986746	4153	Economy	7200.00
0005433986732	4153	Economy	7200.00
0005433986719	4153	Economy	7200.00
0005433986708	4153	Economy	7200.00
0005433986707	4153	Economy	7200.00
0005433986713	4153	Economy	7200.00
0005433986714	4153	Economy	7200.00
0005433986730	4153	Economy	7200.00
0005433986107	25690	Business	21500.00
0005433986259	25690	Business	21500.00
0005433986123	25690	Business	21500.00
0005433986225	25690	Business	21500.00
0005433986272	25690	Economy	7200.00
0005433986312	25690	Economy	7200.00
0005433986274	25690	Economy	7200.00
0005433986412	25690	Economy	7200.00
0005433986260	25690	Economy	7200.00
0005433986182	25690	Economy	7200.00
0005433986275	25690	Economy	7200.00
0005433986167	25690	Economy	7900.00
0005433986169	25690	Economy	7900.00
0005433986313	25690	Economy	7900.00
0005433986314	25690	Economy	7200.00
0005433986179	25690	Economy	7200.00
0005433986431	25690	Economy	7200.00
0005433986138	25690	Economy	7200.00
0005433986015	25690	Economy	7200.00
0005433986332	25690	Economy	7200.00
0005433986168	25690	Economy	7200.00
0005433986181	25690	Economy	7200.00
0005433986261	25690	Economy	7200.00
0005433986328	25690	Economy	7200.00
0005433986386	25690	Economy	7200.00
0005433985865	25690	Economy	7200.00
0005433986343	25690	Economy	7200.00
0005433986266	25690	Economy	7200.00
0005433986411	25690	Economy	7200.00
0005433986224	25690	Economy	7200.00
0005433986432	25690	Economy	7200.00
0005433986327	25690	Economy	7200.00
0005433986344	25690	Economy	7200.00
0005433986267	25690	Economy	7200.00
0005433986333	25690	Economy	7200.00
0005433986303	25690	Economy	7200.00
0005433986246	25690	Economy	7200.00
0005433986336	25690	Economy	7200.00
0005433986166	25690	Economy	7200.00
0005433986207	25690	Economy	7200.00
0005433986273	25690	Economy	7200.00
0005433986135	25690	Economy	7200.00
0005433986306	25690	Economy	7200.00
0005435720829	21276	Economy	10400.00
0005435720835	21276	Economy	9400.00
0005435720830	21276	Economy	9400.00
0005435720831	21276	Economy	9400.00
0005435720147	24776	Economy	9400.00
0005435720148	24776	Economy	9400.00
0005434509211	21325	Economy	17000.00
0005433168433	21325	Economy	17000.00
0005434509231	21325	Economy	17000.00
0005434509206	21325	Economy	15500.00
0005434509216	21325	Economy	15500.00
0005434509234	21325	Economy	15500.00
0005433168436	21325	Economy	15500.00
0005433168439	21325	Economy	15500.00
0005434509205	21325	Economy	15500.00
0005434509209	21325	Economy	15500.00
0005433168443	21325	Economy	15500.00
0005434509232	21325	Economy	15500.00
0005433168440	21325	Economy	15500.00
0005433168444	21325	Economy	15500.00
0005433168441	21325	Economy	15500.00
0005434509215	21325	Economy	15500.00
0005434509159	21325	Economy	15500.00
0005434509224	21325	Economy	15500.00
0005434509184	21325	Economy	15500.00
0005433168435	21325	Economy	15500.00
0005434509214	21325	Economy	15500.00
0005433168437	21325	Economy	15500.00
0005434509177	21325	Economy	15500.00
0005434509210	21325	Economy	15500.00
0005434509197	21325	Economy	15500.00
0005434509198	21325	Economy	15500.00
0005433168438	21325	Economy	15500.00
0005433168434	21325	Economy	15500.00
0005434509233	21325	Economy	15500.00
0005434509223	21325	Economy	15500.00
0005434509225	21325	Economy	15500.00
0005434509196	21325	Economy	15500.00
0005433168442	21325	Economy	15500.00
0005432667474	17859	Business	18000.00
0005432657481	17859	Business	18000.00
0005432869639	17859	Economy	6000.00
0005432667462	17859	Economy	6000.00
0005432869635	17859	Economy	6000.00
0005432665284	17859	Economy	6000.00
0005432659728	17859	Economy	6600.00
0005432869640	17859	Economy	6600.00
0005434151756	17859	Economy	6000.00
0005432667475	17859	Economy	6000.00
0005432667466	17859	Economy	6000.00
0005432655621	17859	Economy	6000.00
0005432659712	17859	Economy	6000.00
0005432655625	17859	Economy	6000.00
0005432658611	17859	Economy	6000.00
0005432655620	17859	Economy	6000.00
0005432655600	17859	Economy	6000.00
0005432869637	17859	Economy	6000.00
0005432667477	17859	Economy	6000.00
0005432661936	17859	Economy	6000.00
0005432659711	17859	Economy	6000.00
0005432869638	17859	Economy	6000.00
0005432667463	17859	Economy	6000.00
0005432664153	17859	Economy	6000.00
0005432658610	17859	Economy	6000.00
0005432869636	17859	Economy	6000.00
0005434151755	17859	Economy	6000.00
0005432664147	17859	Economy	6000.00
0005432655599	17859	Economy	6000.00
0005434151754	17859	Economy	6000.00
0005432869579	26318	Business	18000.00
0005432659738	26318	Business	18000.00
0005432665307	26318	Business	18000.00
0005432869540	26318	Economy	6000.00
0005432869589	26318	Economy	6000.00
0005432655706	26318	Economy	6600.00
0005434151724	26318	Economy	6600.00
0005432655705	26318	Economy	6600.00
0005432665306	26318	Economy	6000.00
0005432655707	26318	Economy	6000.00
0005432657495	26318	Economy	6000.00
0005432655708	26318	Economy	6000.00
0005432657496	26318	Economy	6000.00
0005432655716	26318	Economy	6000.00
0005432666420	26318	Economy	6000.00
0005432655712	26318	Economy	6000.00
0005432666421	26318	Economy	6000.00
0005432658622	26318	Economy	6000.00
0005432655715	26318	Economy	6000.00
0005434151737	26318	Economy	6000.00
0005432667486	26318	Economy	6000.00
0005432660850	26318	Economy	6000.00
0005432655710	26318	Economy	6000.00
0005432869567	26318	Economy	6000.00
0005432657497	26318	Economy	6000.00
0005432655711	26318	Economy	6000.00
0005432660849	26318	Economy	6000.00
0005432659740	26318	Economy	6000.00
0005432869539	26318	Economy	6000.00
0005432659739	26318	Economy	6000.00
0005432655709	26318	Economy	6000.00
0005432655714	26318	Economy	6000.00
0005432658623	26318	Economy	6000.00
0005432655713	26318	Economy	6000.00
0005432869566	26318	Economy	6000.00
0005432659737	26318	Economy	6000.00
0005434151710	26318	Economy	6000.00
0005432329473	3120	Business	16100.00
0005432329457	3120	Business	16100.00
0005432329465	3120	Business	16100.00
0005432329481	3120	Business	16100.00
0005432287272	3120	Business	16100.00
0005432905179	3120	Business	16100.00
0005433438979	3120	Business	16100.00
0005432329486	3120	Business	16100.00
0005432287274	3120	Economy	5400.00
0005433438976	3120	Economy	5400.00
0005432329478	3120	Economy	5400.00
0005432329445	3120	Economy	5400.00
0005432287275	3120	Economy	5900.00
0005432287271	3120	Economy	5900.00
0005432329485	3120	Economy	5900.00
0005432329482	3120	Economy	5900.00
0005432329444	3120	Economy	5900.00
0005432329483	3120	Economy	5400.00
0005432287277	3120	Economy	5400.00
0005433438981	3120	Economy	5400.00
0005432329452	3120	Economy	5400.00
0005432329470	3120	Economy	5400.00
0005432329471	3120	Economy	5400.00
0005432329476	3120	Economy	5400.00
0005432329446	3120	Economy	5400.00
0005432287273	3120	Economy	5400.00
0005432329458	3120	Economy	5400.00
0005432329450	3120	Economy	5400.00
0005433438975	3120	Economy	5400.00
0005432329463	3120	Economy	5400.00
0005433438977	3120	Economy	5400.00
0005432329455	3120	Economy	5400.00
0005432329440	3120	Economy	5400.00
0005432329474	3120	Economy	5400.00
0005432329454	3120	Economy	5400.00
0005432329469	3120	Economy	5400.00
0005432329460	3120	Economy	5400.00
0005432329477	3120	Economy	5400.00
0005432329453	3120	Economy	5400.00
0005432329456	3120	Economy	5400.00
0005432329475	3120	Economy	5400.00
0005432287276	3120	Economy	5400.00
0005432329448	3120	Economy	5400.00
0005433438982	3120	Economy	5400.00
0005432905188	3120	Economy	5400.00
0005432329462	3120	Economy	5400.00
0005432329443	3120	Economy	5400.00
0005432329472	3120	Economy	5400.00
0005432329451	3120	Economy	5400.00
0005432329479	3120	Economy	5400.00
0005433438980	3120	Economy	5400.00
0005432905191	3120	Economy	5400.00
0005432329461	3120	Economy	5400.00
0005432329467	3120	Economy	5400.00
0005432329442	3120	Economy	5400.00
0005432329480	3120	Economy	5400.00
0005432329464	3120	Economy	5400.00
0005433438978	3120	Economy	5400.00
0005432329487	3120	Economy	5400.00
0005432329468	3120	Economy	5400.00
0005432329449	3120	Economy	5400.00
0005432329484	3120	Economy	5400.00
0005432329447	3120	Economy	5400.00
0005432329459	3120	Economy	5400.00
0005432329441	3120	Economy	5400.00
0005432329466	3120	Economy	5400.00
0005432329057	31148	Business	16100.00
0005432328836	31148	Business	16100.00
0005432329031	31148	Business	16100.00
0005432905217	31148	Business	16100.00
0005432328994	31148	Business	16100.00
0005432329041	31148	Economy	5400.00
0005433438940	31148	Economy	5400.00
0005432329047	31148	Economy	5400.00
0005432328969	31148	Economy	5400.00
0005432905222	31148	Economy	5400.00
0005432329095	31148	Economy	5400.00
0005432054354	31148	Economy	5400.00
0005432328992	31148	Economy	5400.00
0005432329236	31148	Economy	5900.00
0005432329125	31148	Economy	5900.00
0005432905218	31148	Economy	5900.00
0005432328918	31148	Economy	5900.00
0005432329069	31148	Economy	5400.00
0005432905220	31148	Economy	5400.00
0005432329094	31148	Economy	5400.00
0005432328914	31148	Economy	5400.00
0005433438952	31148	Economy	5400.00
0005432328970	31148	Economy	5400.00
0005432329172	31148	Economy	5400.00
0005432905219	31148	Economy	5400.00
0005432054352	31148	Economy	5400.00
0005432329037	31148	Economy	5400.00
0005432329055	31148	Economy	5400.00
0005432329133	31148	Economy	5400.00
0005432329150	31148	Economy	5400.00
0005432329068	31148	Economy	5400.00
0005432329033	31148	Economy	5400.00
0005432329027	31148	Economy	5400.00
0005432329151	31148	Economy	5400.00
0005432329140	31148	Economy	5400.00
0005432054353	31148	Economy	5400.00
0005432329001	31148	Economy	5400.00
0005433438914	31148	Economy	5400.00
0005432905216	31148	Economy	5400.00
0005432328896	31148	Economy	5400.00
0005432329026	31148	Economy	5400.00
0005432328889	31148	Economy	5400.00
0005432329038	31148	Economy	5400.00
0005432328883	31148	Economy	5400.00
0005432328880	31148	Economy	5400.00
0005432329134	31148	Economy	5400.00
0005432329165	31148	Economy	5400.00
0005432329139	31148	Economy	5400.00
0005432329054	31148	Economy	5400.00
0005432328882	31148	Economy	5400.00
0005432905221	31148	Economy	5400.00
0005432328758	31148	Economy	5400.00
0005433438913	31148	Economy	5400.00
0005432329167	31148	Economy	5400.00
0005432329032	31148	Economy	5400.00
0005432329216	31148	Economy	5400.00
0005432329168	31148	Economy	5400.00
0005435487943	6189	Business	124600.00
0005435999538	6189	Business	124600.00
0005435999543	6189	Business	124600.00
0005435999546	6189	Business	124600.00
0005434309970	6189	Business	124600.00
0005435999532	6189	Business	124600.00
0005435487969	6189	Economy	41500.00
0005435487945	6189	Economy	41500.00
0005434309971	6189	Economy	41500.00
0005434309968	6189	Economy	41500.00
0005435999536	6189	Economy	41500.00
0005434309965	6189	Economy	41500.00
0005435999539	6189	Economy	41500.00
0005435297112	6189	Economy	41500.00
0005435488050	6189	Economy	41500.00
0005435999549	6189	Economy	41500.00
0005434309963	6189	Economy	41500.00
0005432146235	6189	Economy	41500.00
0005435297109	6189	Economy	41500.00
0005435999550	6189	Economy	41500.00
0005435487858	6189	Economy	41500.00
0005435999551	6189	Economy	41500.00
0005435487976	6189	Economy	41500.00
0005435488007	6189	Economy	41500.00
0005435487968	6189	Economy	41500.00
0005435999535	6189	Economy	41500.00
0005435487952	6189	Economy	45700.00
0005435487999	6189	Economy	45700.00
0005435487963	6189	Economy	45700.00
0005435488000	6189	Economy	45700.00
0005435999537	6189	Economy	41500.00
0005435297101	6189	Economy	41500.00
0005435999534	6189	Economy	41500.00
0005435487975	6189	Economy	41500.00
0005432146234	6189	Economy	41500.00
0005435999541	6189	Economy	41500.00
0005435487926	6189	Economy	41500.00
0005434309975	6189	Economy	41500.00
0005434309974	6189	Economy	41500.00
0005434309967	6189	Economy	41500.00
0005434309973	6189	Economy	41500.00
0005435487937	6189	Economy	41500.00
0005435297108	6189	Economy	41500.00
0005435487981	6189	Economy	41500.00
0005435297139	6189	Economy	41500.00
0005435297110	6189	Economy	41500.00
0005435297118	6189	Economy	41500.00
0005435487859	6189	Economy	41500.00
0005435487962	6189	Economy	41500.00
0005435999533	6189	Economy	41500.00
0005435999545	6189	Economy	41500.00
0005434309964	6189	Economy	41500.00
0005435999542	6189	Economy	41500.00
0005435999540	6189	Economy	41500.00
0005435999530	6189	Economy	41500.00
0005435999544	6189	Economy	41500.00
0005435999548	6189	Economy	41500.00
0005432146233	6189	Economy	41500.00
0005435999531	6189	Economy	41500.00
0005435999547	6189	Economy	41500.00
0005435487996	6189	Economy	41500.00
0005435487944	6189	Economy	41500.00
0005434309969	6189	Economy	41500.00
0005435297111	6189	Economy	41500.00
0005435488001	6189	Economy	41500.00
0005435297140	6189	Economy	41500.00
0005435297103	6189	Economy	41500.00
0005434309966	6189	Economy	41500.00
0005434309972	6189	Economy	41500.00
0005435488182	19542	Business	124600.00
0005435297176	19542	Business	124600.00
0005435999357	19542	Business	124600.00
0005435297170	19542	Business	124600.00
0005435297171	19542	Business	124600.00
0005435488179	19542	Business	124600.00
0005434309875	19542	Business	124600.00
0005435999270	19542	Economy	41500.00
0005435488185	19542	Economy	41500.00
0005435999345	19542	Economy	41500.00
0005435999281	19542	Economy	41500.00
0005434309902	19542	Economy	41500.00
0005435297173	19542	Economy	41500.00
0005435297169	19542	Economy	41500.00
0005435488178	19542	Economy	41500.00
0005435488181	19542	Economy	41500.00
0005435999311	19542	Economy	41500.00
0005435488180	19542	Economy	41500.00
0005435999304	19542	Economy	41500.00
0005435297174	19542	Economy	41500.00
0005434309843	19542	Economy	41500.00
0005434309805	19542	Economy	41500.00
0005434309867	19542	Economy	41500.00
0005435488175	19542	Economy	41500.00
0005435999322	19542	Economy	41500.00
0005434309807	19542	Economy	41500.00
0005435488166	19542	Economy	41500.00
0005434309806	19542	Economy	45700.00
0005435999312	19542	Economy	45700.00
0005435999269	19542	Economy	45700.00
0005434309775	19542	Economy	41500.00
0005435488169	19542	Economy	41500.00
0005435297175	19542	Economy	41500.00
0005435488168	19542	Economy	41500.00
0005435488167	19542	Economy	41500.00
0005435488183	19542	Economy	41500.00
0005434309842	19542	Economy	41500.00
0005435999335	19542	Economy	41500.00
0005435999289	19542	Economy	41500.00
0005434309841	19542	Economy	41500.00
0005435999374	19542	Economy	41500.00
0005435999360	19542	Economy	41500.00
0005435488170	19542	Economy	41500.00
0005434309831	19542	Economy	41500.00
0005434309858	19542	Economy	41500.00
0005435488173	19542	Economy	41500.00
0005434309904	19542	Economy	41500.00
0005434309905	19542	Economy	41500.00
0005435488172	19542	Economy	41500.00
0005434309832	19542	Economy	41500.00
0005435999366	19542	Economy	41500.00
0005434309903	19542	Economy	41500.00
0005434309859	19542	Economy	41500.00
0005434309900	19542	Economy	41500.00
0005435488171	19542	Economy	41500.00
0005435488176	19542	Economy	41500.00
0005435488174	19542	Economy	41500.00
0005435999342	19542	Economy	41500.00
0005435488184	19542	Economy	41500.00
0005435488177	19542	Economy	41500.00
0005435488164	19542	Economy	41500.00
0005435297172	19542	Economy	41500.00
0005434309789	19542	Economy	41500.00
0005435488163	19542	Economy	41500.00
0005435999309	19542	Economy	41500.00
0005435999310	19542	Economy	41500.00
0005435488165	19542	Economy	41500.00
0005435502683	1597	Business	86000.00
0005433186191	1597	Business	86000.00
0005435508563	1597	Business	86000.00
0005432291971	1597	Business	86000.00
0005433186204	1597	Business	86000.00
0005433186215	1597	Business	86000.00
0005435502675	1597	Business	86000.00
0005433186185	1597	Business	86000.00
0005434566140	1597	Business	86000.00
0005435502665	1597	Economy	28700.00
0005435502685	1597	Economy	28700.00
0005435502684	1597	Economy	28700.00
0005435502669	1597	Economy	28700.00
0005434566136	1597	Economy	28700.00
0005435518218	1597	Economy	28700.00
0005435518223	1597	Economy	28700.00
0005435518222	1597	Economy	28700.00
0005433186216	1597	Economy	31500.00
0005432291974	1597	Economy	31500.00
0005434566139	1597	Economy	31500.00
0005435508556	1597	Economy	28700.00
0005434566135	1597	Economy	28700.00
0005435502677	1597	Economy	28700.00
0005435502674	1597	Economy	28700.00
0005435508555	1597	Economy	28700.00
0005435502672	1597	Economy	28700.00
0005435508551	1597	Economy	28700.00
0005435508560	1597	Economy	28700.00
0005434566143	1597	Economy	28700.00
0005434566133	1597	Economy	28700.00
0005434566145	1597	Economy	28700.00
0005433186230	1597	Economy	28700.00
0005435502686	1597	Economy	28700.00
0005435508559	1597	Economy	28700.00
0005435508557	1597	Economy	28700.00
0005435502681	1597	Economy	28700.00
0005435502678	1597	Economy	28700.00
0005435502667	1597	Economy	28700.00
0005435502671	1597	Economy	28700.00
0005435502673	1597	Economy	28700.00
0005435518219	1597	Economy	28700.00
0005434566134	1597	Economy	28700.00
0005435508550	1597	Economy	28700.00
0005432291969	1597	Economy	28700.00
0005434566132	1597	Economy	28700.00
0005434566146	1597	Economy	28700.00
0005435502663	1597	Economy	28700.00
0005435502670	1597	Economy	28700.00
0005435518221	1597	Economy	28700.00
0005432291970	1597	Economy	28700.00
0005435508552	1597	Economy	28700.00
0005433186181	1597	Economy	28700.00
0005435502664	1597	Economy	28700.00
0005435508561	1597	Economy	28700.00
0005435508558	1597	Economy	28700.00
0005435508562	1597	Economy	28700.00
0005435508553	1597	Economy	28700.00
0005435502676	1597	Economy	28700.00
0005434566141	1597	Economy	28700.00
0005435502680	1597	Economy	28700.00
0005434566144	1597	Economy	28700.00
0005435518220	1597	Economy	28700.00
0005435502679	1597	Economy	28700.00
0005435502666	1597	Economy	28700.00
0005432291973	1597	Economy	28700.00
0005434566137	1597	Economy	28700.00
0005432291972	1597	Economy	28700.00
0005434566138	1597	Economy	28700.00
0005435508554	1597	Economy	28700.00
0005434566142	1597	Economy	28700.00
0005435502682	1597	Economy	28700.00
0005435502668	1597	Economy	28700.00
0005435529417	20873	Business	86000.00
0005435529415	20873	Business	86000.00
0005435502500	20873	Business	86000.00
0005435502371	20873	Business	86000.00
0005435545807	20873	Business	86000.00
0005435529512	20873	Business	86000.00
0005435529405	20873	Business	86000.00
0005435529388	20873	Business	86000.00
0005433186258	20873	Business	86000.00
0005435502504	20873	Economy	28700.00
0005435529452	20873	Economy	28700.00
0005435529379	20873	Economy	28700.00
0005435502428	20873	Economy	28700.00
0005435545811	20873	Economy	28700.00
0005434566023	20873	Economy	28700.00
0005434566011	20873	Economy	28700.00
0005435529375	20873	Economy	31500.00
0005435529400	20873	Economy	31500.00
0005433186263	20873	Economy	31500.00
0005435529358	20873	Economy	31500.00
0005435529350	20873	Economy	28700.00
0005435529367	20873	Economy	28700.00
0005435529340	20873	Economy	28700.00
0005433186260	20873	Economy	28700.00
0005433186265	20873	Economy	28700.00
0005435529500	20873	Economy	28700.00
0005435502462	20873	Economy	28700.00
0005435529374	20873	Economy	28700.00
0005435529362	20873	Economy	28700.00
0005435545787	20873	Economy	28700.00
0005435529376	20873	Economy	28700.00
0005435502387	20873	Economy	28700.00
0005435529459	20873	Economy	28700.00
0005435502490	20873	Economy	28700.00
0005435502477	20873	Economy	28700.00
0005434566032	20873	Economy	28700.00
0005435529414	20873	Economy	28700.00
0005433186261	20873	Economy	28700.00
0005435529425	20873	Economy	28700.00
0005435529453	20873	Economy	28700.00
0005435502467	20873	Economy	28700.00
0005435529354	20873	Economy	28700.00
0005435502491	20873	Economy	28700.00
0005433186262	20873	Economy	28700.00
0005435502505	20873	Economy	28700.00
0005434566043	20873	Economy	28700.00
0005433186264	20873	Economy	28700.00
0005435529339	20873	Economy	28700.00
0005435529416	20873	Economy	28700.00
0005435529468	20873	Economy	28700.00
0005435502410	20873	Economy	28700.00
0005435529318	20873	Economy	28700.00
0005435502388	20873	Economy	28700.00
0005435502447	20873	Economy	28700.00
0005435529389	20873	Economy	28700.00
0005434566010	20873	Economy	28700.00
0005435502370	20873	Economy	28700.00
0005433186259	20873	Economy	28700.00
0005435502488	20873	Economy	28700.00
0005435545814	20873	Economy	28700.00
0005435502464	20873	Economy	28700.00
0005435545828	20873	Economy	28700.00
0005434566044	20873	Economy	28700.00
0005435529426	20873	Economy	28700.00
0005435502487	20873	Economy	28700.00
0005434566031	20873	Economy	28700.00
0005435529381	20873	Economy	28700.00
0005435529460	20873	Economy	28700.00
0005435153850	3881	Economy	19700.00
0005435153853	3881	Economy	19700.00
0005435931620	3881	Economy	19700.00
0005435153854	3881	Economy	19700.00
0005435931644	3881	Economy	19700.00
0005435153849	3881	Economy	19700.00
0005435153851	3881	Economy	19700.00
0005435153855	3881	Economy	19700.00
0005435153852	3881	Economy	19700.00
0005435153811	21881	Economy	21600.00
0005435931663	21881	Economy	19700.00
0005435153828	21881	Economy	19700.00
0005435153827	21881	Economy	19700.00
0005435153801	21881	Economy	19700.00
0005435931664	21881	Economy	19700.00
0005435153809	21881	Economy	19700.00
0005435931666	21881	Economy	19700.00
0005435153812	21881	Economy	19700.00
0005435153800	21881	Economy	19700.00
0005435931665	21881	Economy	19700.00
0005432629099	7221	Economy	14300.00
0005432629096	7221	Economy	14300.00
0005432629091	7221	Economy	13000.00
0005432629086	7221	Economy	13000.00
0005432629088	7221	Economy	13000.00
0005432629092	7221	Economy	13000.00
0005432629090	7221	Economy	13000.00
0005435225664	7221	Economy	13000.00
0005435225657	7221	Economy	13000.00
0005432629089	7221	Economy	13000.00
0005435225647	7221	Economy	13000.00
0005432629093	7221	Economy	13000.00
0005432629098	7221	Economy	13000.00
0005432629087	7221	Economy	13000.00
0005432629095	7221	Economy	13000.00
0005435225666	7221	Economy	13000.00
0005432629097	7221	Economy	13000.00
0005432629094	7221	Economy	13000.00
0005432629100	7221	Economy	13000.00
0005432629085	7221	Economy	13000.00
0005435225660	7221	Economy	13000.00
0005435225665	7221	Economy	13000.00
0005432628973	28130	Economy	14300.00
0005432628976	28130	Economy	14300.00
0005432629007	28130	Economy	14300.00
0005432628989	28130	Economy	13000.00
0005435225718	28130	Economy	13000.00
0005432629069	28130	Economy	13000.00
0005432628939	28130	Economy	13000.00
0005432628940	28130	Economy	13000.00
0005432628990	28130	Economy	13000.00
0005435225722	28130	Economy	13000.00
0005435225717	28130	Economy	13000.00
0005432628964	28130	Economy	13000.00
0005435225720	28130	Economy	13000.00
0005432628972	28130	Economy	13000.00
0005432628997	28130	Economy	13000.00
0005432628953	28130	Economy	13000.00
0005435225721	28130	Economy	13000.00
0005435225715	28130	Economy	13000.00
0005432629018	28130	Economy	13000.00
0005432629008	28130	Economy	13000.00
0005435225719	28130	Economy	13000.00
0005432628954	28130	Economy	13000.00
0005432629001	28130	Economy	13000.00
0005435225716	28130	Economy	13000.00
0005434267987	8764	Economy	10500.00
0005435960113	8764	Economy	10500.00
0005434267978	8764	Economy	10500.00
0005434267964	8764	Economy	10500.00
0005435960114	8764	Economy	10500.00
0005434267985	8764	Economy	10500.00
0005434267982	8764	Economy	10500.00
0005435960112	8764	Economy	10500.00
0005435960115	8764	Economy	10500.00
0005435960116	8764	Economy	10500.00
0005434268011	15253	Economy	10500.00
0005434268015	15253	Economy	10500.00
0005434268014	15253	Economy	10500.00
0005434268013	15253	Economy	10500.00
0005434268012	15253	Economy	10500.00
0005432693553	1169	Business	115000.00
0005432873339	1169	Business	115000.00
0005432675380	1169	Business	115000.00
0005432675387	1169	Business	115000.00
0005432693546	1169	Business	115000.00
0005432693563	1169	Business	115000.00
0005432873361	1169	Business	115000.00
0005432693541	1169	Business	115000.00
0005432693549	1169	Business	115000.00
0005432675385	1169	Business	115000.00
0005432693556	1169	Business	115000.00
0005432693552	1169	Business	115000.00
0005432675391	1169	Economy	38300.00
0005432677636	1169	Economy	38300.00
0005432693555	1169	Economy	42200.00
0005432693540	1169	Economy	42200.00
0005432693562	1169	Economy	42200.00
0005432675381	1169	Economy	42200.00
0005432873338	1169	Economy	38300.00
0005432693567	1169	Economy	38300.00
0005432693566	1169	Economy	38300.00
0005432693561	1169	Economy	38300.00
0005432675389	1169	Economy	38300.00
0005432693542	1169	Economy	38300.00
0005432675378	1169	Economy	38300.00
0005432675384	1169	Economy	38300.00
0005432677635	1169	Economy	38300.00
0005432873362	1169	Economy	38300.00
0005432675382	1169	Economy	38300.00
0005432693557	1169	Economy	38300.00
0005432677637	1169	Economy	38300.00
0005432693559	1169	Economy	38300.00
0005432675388	1169	Economy	38300.00
0005432693538	1169	Economy	38300.00
0005432693564	1169	Economy	38300.00
0005432693565	1169	Economy	38300.00
0005432873336	1169	Economy	38300.00
0005432675383	1169	Economy	38300.00
0005432693550	1169	Economy	38300.00
0005432693554	1169	Economy	38300.00
0005432693568	1169	Economy	38300.00
0005432693543	1169	Economy	38300.00
0005432693539	1169	Economy	38300.00
0005432675379	1169	Economy	38300.00
0005432693558	1169	Economy	38300.00
0005432675386	1169	Economy	38300.00
0005432693545	1169	Economy	38300.00
0005432693547	1169	Economy	38300.00
0005432675390	1169	Economy	38300.00
0005432693551	1169	Economy	38300.00
0005432675392	1169	Economy	38300.00
0005432677638	1169	Economy	38300.00
0005432693560	1169	Economy	38300.00
0005432873348	1169	Economy	38300.00
0005432693548	1169	Economy	38300.00
0005432693544	1169	Economy	38300.00
0005432675268	17469	Business	115000.00
0005432675247	17469	Business	115000.00
0005432693270	17469	Business	115000.00
0005432675248	17469	Business	115000.00
0005432675195	17469	Business	115000.00
0005432675293	17469	Business	115000.00
0005432693371	17469	Business	115000.00
0005432873410	17469	Business	115000.00
0005432693187	17469	Business	115000.00
0005432693353	17469	Business	115000.00
0005432693299	17469	Business	115000.00
0005432693274	17469	Economy	38300.00
0005432693347	17469	Economy	38300.00
0005432693373	17469	Economy	38300.00
0005432677602	17469	Economy	38300.00
0005432693344	17469	Economy	38300.00
0005432675295	17469	Economy	38300.00
0005432677610	17469	Economy	38300.00
0005432693354	17469	Economy	42200.00
0005432693382	17469	Economy	42200.00
0005432693434	17469	Economy	38300.00
0005432873412	17469	Economy	38300.00
0005432693346	17469	Economy	38300.00
0005432693188	17469	Economy	38300.00
0005432675286	17469	Economy	38300.00
0005432693219	17469	Economy	38300.00
0005432873413	17469	Economy	38300.00
0005432675194	17469	Economy	38300.00
0005432693305	17469	Economy	38300.00
0005432675269	17469	Economy	38300.00
0005432693306	17469	Economy	38300.00
0005432693263	17469	Economy	38300.00
0005432693388	17469	Economy	38300.00
0005432675253	17469	Economy	38300.00
0005432675229	17469	Economy	38300.00
0005432873407	17469	Economy	38300.00
0005432693276	17469	Economy	38300.00
0005432693433	17469	Economy	38300.00
0005432693284	17469	Economy	38300.00
0005432873411	17469	Economy	38300.00
0005432693220	17469	Economy	38300.00
0005432693246	17469	Economy	38300.00
0005432675226	17469	Economy	38300.00
0005432693195	17469	Economy	38300.00
0005432693237	17469	Economy	38300.00
0005432693304	17469	Economy	38300.00
0005432675278	17469	Economy	38300.00
0005432693275	17469	Economy	38300.00
0005432675225	17469	Economy	38300.00
0005432693365	17469	Economy	38300.00
0005432693341	17469	Economy	38300.00
0005432693277	17469	Economy	38300.00
0005432675279	17469	Economy	38300.00
0005432693300	17469	Economy	38300.00
0005432873408	17469	Economy	38300.00
0005432675228	17469	Economy	38300.00
0005432693217	17469	Economy	38300.00
0005432675289	17469	Economy	38300.00
0005432693381	17469	Economy	38300.00
0005432693215	17469	Economy	38300.00
0005432677597	17469	Economy	38300.00
0005432693342	17469	Economy	38300.00
0005432873409	17469	Economy	38300.00
0005432693223	17469	Economy	38300.00
0005434435441	1151	Economy	15200.00
0005433156830	1151	Economy	13900.00
0005433156828	1151	Economy	13900.00
0005434435442	1151	Economy	13900.00
0005434435431	1151	Economy	13900.00
0005434435443	1151	Economy	13900.00
0005433156820	1151	Economy	13900.00
0005433156831	1151	Economy	13900.00
0005434435439	1151	Economy	13900.00
0005434435433	1151	Economy	13900.00
0005434435432	1151	Economy	13900.00
0005434435435	1151	Economy	13900.00
0005433156852	1151	Economy	13900.00
0005434435446	1151	Economy	13900.00
0005434435444	1151	Economy	13900.00
0005434435445	1151	Economy	13900.00
0005433156799	1151	Economy	13900.00
0005434435436	1151	Economy	13900.00
0005433156821	1151	Economy	13900.00
0005434435440	1151	Economy	13900.00
0005434435437	1151	Economy	13900.00
0005434435430	1151	Economy	13900.00
0005434435434	1151	Economy	13900.00
0005433156838	1151	Economy	13900.00
0005434435438	1151	Economy	13900.00
0005434435353	17302	Economy	13900.00
0005434435307	17302	Economy	13900.00
0005433156897	17302	Economy	13900.00
0005433156894	17302	Economy	13900.00
0005433156895	17302	Economy	13900.00
0005434435333	17302	Economy	13900.00
0005434435305	17302	Economy	13900.00
0005433156893	17302	Economy	13900.00
0005433156892	17302	Economy	13900.00
0005434435306	17302	Economy	13900.00
0005433156890	17302	Economy	13900.00
0005434435295	17302	Economy	13900.00
0005433156896	17302	Economy	13900.00
0005434435278	17302	Economy	13900.00
0005434435277	17302	Economy	13900.00
0005434435246	17302	Economy	13900.00
0005434435360	17302	Economy	13900.00
0005434435348	17302	Economy	13900.00
0005433156898	17302	Economy	13900.00
0005433156891	17302	Economy	13900.00
0005434435245	17302	Economy	13900.00
0005434435341	17302	Economy	13900.00
0005434435332	17302	Economy	13900.00
0005434435296	17302	Economy	13900.00
0005434435340	17302	Economy	13900.00
0005434435294	17302	Economy	13900.00
0005434435317	17302	Economy	13900.00
0005434435308	17302	Economy	13900.00
0005435928175	4066	Economy	7500.00
0005435086961	4066	Economy	7500.00
0005435928179	4066	Economy	7500.00
0005435928178	4066	Economy	7500.00
0005435086958	4066	Economy	7500.00
0005435086959	4066	Economy	7500.00
0005435086957	4066	Economy	7500.00
0005435086963	4066	Economy	7500.00
0005435086956	4066	Economy	7500.00
0005435086960	4066	Economy	7500.00
0005435928174	4066	Economy	7500.00
0005435928177	4066	Economy	7500.00
0005435928195	4066	Economy	7500.00
0005435086962	4066	Economy	7500.00
0005435086934	24394	Economy	8200.00
0005435086887	24394	Economy	8200.00
0005435928222	24394	Economy	7500.00
0005435928221	24394	Economy	7500.00
0005435086883	24394	Economy	7500.00
0005435086902	24394	Economy	7500.00
0005435086888	24394	Economy	7500.00
0005435928223	24394	Economy	7500.00
0005435086897	24394	Economy	7500.00
0005435086885	24394	Economy	7500.00
0005435086884	24394	Economy	7500.00
0005435086896	24394	Economy	7500.00
0005435928220	24394	Economy	7500.00
0005435928224	24394	Economy	7500.00
0005435086863	24394	Economy	7500.00
0005435086901	24394	Economy	7500.00
0005435086932	24394	Economy	7500.00
0005435086933	24394	Economy	7500.00
0005435907535	4831	Business	44200.00
0005434626117	4831	Business	44200.00
0005434626119	4831	Business	44200.00
0005434626121	4831	Economy	14700.00
0005433194876	4831	Economy	14700.00
0005435907541	4831	Economy	16200.00
0005434626118	4831	Economy	16200.00
0005434626115	4831	Economy	14700.00
0005433194864	4831	Economy	14700.00
0005435907525	4831	Economy	14700.00
0005434626124	4831	Economy	14700.00
0005434626116	4831	Economy	14700.00
0005435907532	4831	Economy	14700.00
0005434626123	4831	Economy	14700.00
0005434626120	4831	Economy	14700.00
0005434626122	4831	Economy	14700.00
0005434625982	32922	Business	44200.00
0005434626000	32922	Business	44200.00
0005434626035	32922	Business	44200.00
0005434626057	32922	Economy	16200.00
0005435907587	32922	Economy	14700.00
0005435907586	32922	Economy	14700.00
0005435907589	32922	Economy	14700.00
0005434626041	32922	Economy	14700.00
0005434626036	32922	Economy	14700.00
0005434626032	32922	Economy	14700.00
0005434626040	32922	Economy	14700.00
0005435907588	32922	Economy	14700.00
0005434626056	32922	Economy	14700.00
0005434626038	32922	Economy	14700.00
0005435787367	13749	Economy	3400.00
0005435785556	13749	Economy	3400.00
0005435785564	13749	Economy	3400.00
0005435785618	13749	Economy	3400.00
0005435785619	13749	Economy	3100.00
0005435785599	13749	Economy	3100.00
0005435785537	13749	Economy	3100.00
0005435785587	13749	Economy	3100.00
0005435937458	13749	Economy	3100.00
0005435785446	13749	Economy	3100.00
0005435785507	13749	Economy	3100.00
0005435785473	13749	Economy	3100.00
0005435785477	13749	Economy	3100.00
0005435785429	13749	Economy	3100.00
0005435785716	13749	Economy	3100.00
0005435785635	13749	Economy	3100.00
0005435785612	13749	Economy	3100.00
0005435785557	13749	Economy	3100.00
0005435785478	13749	Economy	3100.00
0005435785613	13749	Economy	3100.00
0005435785565	13749	Economy	3100.00
0005435785509	13749	Economy	3100.00
0005435937459	13749	Economy	3100.00
0005435785649	13749	Economy	3100.00
0005435785510	13749	Economy	3100.00
0005435785382	13749	Economy	3100.00
0005435785555	13749	Economy	3100.00
0005435785589	13749	Economy	3100.00
0005435785627	13749	Economy	3100.00
0005435785588	13749	Economy	3100.00
0005435937460	13749	Economy	3100.00
0005435785577	13749	Economy	3100.00
0005435937457	13749	Economy	3100.00
0005435785491	13749	Economy	3100.00
0005435785636	13749	Economy	3100.00
0005435785487	13749	Economy	3100.00
0005435787366	13749	Economy	3100.00
0005435785490	13749	Economy	3100.00
0005435785451	13749	Economy	3100.00
0005435785884	27415	Economy	3400.00
0005435785889	27415	Economy	3400.00
0005435785883	27415	Economy	3400.00
0005435937410	27415	Economy	3400.00
0005435785870	27415	Economy	3100.00
0005435785892	27415	Economy	3100.00
0005435787387	27415	Economy	3100.00
0005432190687	27415	Economy	3100.00
0005435785880	27415	Economy	3100.00
0005435785893	27415	Economy	3100.00
0005435785888	27415	Economy	3100.00
0005435937411	27415	Economy	3100.00
0005435785886	27415	Economy	3100.00
0005435785873	27415	Economy	3100.00
0005435785887	27415	Economy	3100.00
0005432190689	27415	Economy	3100.00
0005435785879	27415	Economy	3100.00
0005435785878	27415	Economy	3100.00
0005435937412	27415	Economy	3100.00
0005435785865	27415	Economy	3100.00
0005435785882	27415	Economy	3100.00
0005435785866	27415	Economy	3100.00
0005435785881	27415	Economy	3100.00
0005432190686	27415	Economy	3100.00
0005435785868	27415	Economy	3100.00
0005435785876	27415	Economy	3100.00
0005435785874	27415	Economy	3100.00
0005435785875	27415	Economy	3100.00
0005435785877	27415	Economy	3100.00
0005435785895	27415	Economy	3100.00
0005435937402	27415	Economy	3100.00
0005435785864	27415	Economy	3100.00
0005435785891	27415	Economy	3100.00
0005432190688	27415	Economy	3100.00
0005435937403	27415	Economy	3100.00
0005435785885	27415	Economy	3100.00
0005435785872	27415	Economy	3100.00
0005435787388	27415	Economy	3100.00
0005435785896	27415	Economy	3100.00
0005435785869	27415	Economy	3100.00
0005435785871	27415	Economy	3100.00
0005435785867	27415	Economy	3100.00
0005435785890	27415	Economy	3100.00
0005435785897	27415	Economy	3100.00
0005435785894	27415	Economy	3100.00
0005435785863	27415	Economy	3100.00
0005434408400	20274	Business	12000.00
0005434408309	20274	Business	12000.00
0005434408536	20274	Business	12000.00
0005435311267	20274	Business	12000.00
0005434408441	20274	Business	12000.00
0005435311266	20274	Business	12000.00
0005434407834	20274	Business	12000.00
0005435311261	20274	Business	12000.00
0005434408457	20274	Business	12000.00
0005434408261	20274	Business	12000.00
0005434408376	20274	Economy	4000.00
0005434408353	20274	Economy	4000.00
0005434408187	20274	Economy	4000.00
0005434408247	20274	Economy	4000.00
0005434408129	20274	Economy	4000.00
0005435311274	20274	Economy	4000.00
0005434408484	20274	Economy	4000.00
0005434408284	20274	Economy	4000.00
0005435311273	20274	Economy	4000.00
0005434408364	20274	Economy	4000.00
0005435311264	20274	Economy	4400.00
0005434408348	20274	Economy	4400.00
0005434408422	20274	Economy	4400.00
0005434408051	20274	Economy	4400.00
0005434408423	20274	Economy	4400.00
0005432058448	20274	Economy	4000.00
0005434408241	20274	Economy	4000.00
0005432058446	20274	Economy	4000.00
0005432058445	20274	Economy	4000.00
0005434408361	20274	Economy	4000.00
0005435311272	20274	Economy	4000.00
0005434408222	20274	Economy	4000.00
0005434408188	20274	Economy	4000.00
0005434408155	20274	Economy	4000.00
0005434408109	20274	Economy	4000.00
0005435311268	20274	Economy	4000.00
0005434408532	20274	Economy	4000.00
0005434408377	20274	Economy	4000.00
0005434408219	20274	Economy	4000.00
0005434408289	20274	Economy	4000.00
0005434407931	20274	Economy	4000.00
0005434408304	20274	Economy	4000.00
0005434408319	20274	Economy	4000.00
0005434408397	20274	Economy	4000.00
0005434408500	20274	Economy	4000.00
0005434407895	20274	Economy	4000.00
0005434408308	20274	Economy	4000.00
0005432058447	20274	Economy	4000.00
0005434408499	20274	Economy	4000.00
0005434408504	20274	Economy	4000.00
0005434408128	20274	Economy	4000.00
0005435311260	20274	Economy	4000.00
0005434408169	20274	Economy	4000.00
0005434408339	20274	Economy	4000.00
0005434408238	20274	Economy	4000.00
0005434408362	20274	Economy	4000.00
0005434408375	20274	Economy	4000.00
0005434407872	20274	Economy	4000.00
0005434408388	20274	Economy	4000.00
0005434408402	20274	Economy	4000.00
0005434408156	20274	Economy	4000.00
0005434408297	20274	Economy	4000.00
0005434408639	20274	Economy	4000.00
0005434408239	20274	Economy	4000.00
0005434408559	20274	Economy	4000.00
0005435311265	20274	Economy	4000.00
0005434408144	20274	Economy	4000.00
0005434407944	20274	Economy	4000.00
0005435311263	20274	Economy	4000.00
0005435311271	20274	Economy	4000.00
0005434408242	20274	Economy	4000.00
0005434408314	20274	Economy	4000.00
0005434408349	20274	Economy	4000.00
0005434408170	20274	Economy	4000.00
0005434408191	20274	Economy	4000.00
0005434408101	20274	Economy	4000.00
0005434408350	20274	Economy	4000.00
0005434408327	20274	Economy	4000.00
0005435311262	20274	Economy	4000.00
0005434408401	20274	Economy	4000.00
0005434408305	20274	Economy	4000.00
0005434408352	20274	Economy	4000.00
0005434408116	20274	Economy	4000.00
0005434408168	20274	Economy	4000.00
0005435311269	20274	Economy	4000.00
0005434408069	20274	Economy	4000.00
0005434408303	20274	Economy	4000.00
0005434408307	20274	Economy	4000.00
0005435311270	20274	Economy	4000.00
0005434408833	26990	Business	12000.00
0005435311115	26990	Business	12000.00
0005432154051	26990	Business	12000.00
0005434408803	26990	Business	12000.00
0005435311074	26990	Business	12000.00
0005434408777	26990	Business	12000.00
0005434408802	26990	Business	12000.00
0005434408782	26990	Business	12000.00
0005434408787	26990	Business	12000.00
0005434408794	26990	Economy	4000.00
0005435311114	26990	Economy	4000.00
0005434408775	26990	Economy	4000.00
0005434408822	26990	Economy	4000.00
0005434408808	26990	Economy	4000.00
0005434408816	26990	Economy	4000.00
0005434408815	26990	Economy	4000.00
0005434408824	26990	Economy	4400.00
0005435311131	26990	Economy	4400.00
0005434408795	26990	Economy	4400.00
0005434408772	26990	Economy	4400.00
0005434408826	26990	Economy	4000.00
0005434408813	26990	Economy	4000.00
0005434408827	26990	Economy	4000.00
0005434408830	26990	Economy	4000.00
0005434408798	26990	Economy	4000.00
0005435311116	26990	Economy	4000.00
0005434408785	26990	Economy	4000.00
0005434408814	26990	Economy	4000.00
0005434408799	26990	Economy	4000.00
0005434408828	26990	Economy	4000.00
0005434408780	26990	Economy	4000.00
0005434408818	26990	Economy	4000.00
0005435311106	26990	Economy	4000.00
0005434408778	26990	Economy	4000.00
0005434408774	26990	Economy	4000.00
0005434408804	26990	Economy	4000.00
0005434408792	26990	Economy	4000.00
0005434408820	26990	Economy	4000.00
0005434408793	26990	Economy	4000.00
0005434408823	26990	Economy	4000.00
0005432154055	26990	Economy	4000.00
0005434408831	26990	Economy	4000.00
0005434408821	26990	Economy	4000.00
0005434408784	26990	Economy	4000.00
0005434408812	26990	Economy	4000.00
0005435311092	26990	Economy	4000.00
0005432154056	26990	Economy	4000.00
0005434408819	26990	Economy	4000.00
0005432154052	26990	Economy	4000.00
0005434408817	26990	Economy	4000.00
0005435311132	26990	Economy	4000.00
0005434408806	26990	Economy	4000.00
0005434408797	26990	Economy	4000.00
0005434408825	26990	Economy	4000.00
0005434408783	26990	Economy	4000.00
0005434408807	26990	Economy	4000.00
0005434408788	26990	Economy	4000.00
0005434408779	26990	Economy	4000.00
0005434408786	26990	Economy	4000.00
0005434408796	26990	Economy	4000.00
0005432154053	26990	Economy	4000.00
0005435311121	26990	Economy	4000.00
0005434408781	26990	Economy	4000.00
0005434408771	26990	Economy	4000.00
0005432154054	26990	Economy	4000.00
0005435311088	26990	Economy	4000.00
0005434408800	26990	Economy	4000.00
0005434408805	26990	Economy	4000.00
0005435311107	26990	Economy	4000.00
0005435311091	26990	Economy	4000.00
0005434408791	26990	Economy	4000.00
0005434408801	26990	Economy	4000.00
0005434408776	26990	Economy	4000.00
0005434408829	26990	Economy	4000.00
0005434408832	26990	Economy	4000.00
0005434408809	26990	Economy	4000.00
0005434408789	26990	Economy	4000.00
0005434408834	26990	Economy	4000.00
0005435311108	26990	Economy	4000.00
0005435311129	26990	Economy	4000.00
0005434408810	26990	Economy	4000.00
0005434408773	26990	Economy	4000.00
0005434408811	26990	Economy	4000.00
0005434408790	26990	Economy	4000.00
0005433124009	5704	Business	43300.00
0005433124056	5704	Business	43300.00
0005434319625	5704	Business	43300.00
0005433124129	5704	Business	43300.00
0005434319622	5704	Business	43300.00
0005433124123	5704	Business	43300.00
0005432109748	5704	Business	43300.00
0005433124091	5704	Economy	14400.00
0005432109749	5704	Economy	14400.00
0005433124017	5704	Economy	14400.00
0005433124160	5704	Economy	14400.00
0005434319624	5704	Economy	15900.00
0005433124124	5704	Economy	15900.00
0005434319621	5704	Economy	14400.00
0005433124128	5704	Economy	14400.00
0005433124159	5704	Economy	14400.00
0005434319623	5704	Economy	14400.00
0005433124092	5704	Economy	14400.00
0005433124083	5704	Economy	14400.00
0005433124075	5704	Economy	14400.00
0005433124085	5704	Economy	14400.00
0005433124090	5704	Economy	14400.00
0005433124084	5704	Economy	14400.00
0005433124082	5704	Economy	14400.00
0005433124074	5704	Economy	14400.00
0005434311253	5704	Economy	14400.00
0005434319627	5704	Economy	14400.00
0005434311252	5704	Economy	14400.00
0005433124087	5704	Economy	14400.00
0005433124081	5704	Economy	14400.00
0005434319626	5704	Economy	14400.00
0005433124008	5704	Economy	14400.00
0005433124272	15676	Business	43300.00
0005433124280	15676	Business	43300.00
0005433124271	15676	Business	43300.00
0005433124273	15676	Business	43300.00
0005433124278	15676	Business	43300.00
0005434319495	15676	Economy	14400.00
0005433124277	15676	Economy	14400.00
0005433124268	15676	Economy	14400.00
0005433124265	15676	Economy	14400.00
0005433124266	15676	Economy	14400.00
0005433124267	15676	Economy	14400.00
0005433124274	15676	Economy	14400.00
0005433124276	15676	Economy	14400.00
0005434319528	15676	Economy	14400.00
0005433124264	15676	Economy	14400.00
0005434319487	15676	Economy	14400.00
0005433124270	15676	Economy	14400.00
0005434319508	15676	Economy	14400.00
0005434311234	15676	Economy	14400.00
0005434319425	15676	Economy	14400.00
0005433124284	15676	Economy	14400.00
0005433124282	15676	Economy	14400.00
0005434319486	15676	Economy	14400.00
0005433124281	15676	Economy	14400.00
0005434319496	15676	Economy	14400.00
0005434319461	15676	Economy	14400.00
0005433124283	15676	Economy	14400.00
0005433124269	15676	Economy	14400.00
0005433124279	15676	Economy	14400.00
0005433124275	15676	Economy	14400.00
0005434319462	15676	Economy	14400.00
0005434189240	9000	Economy	27400.00
0005434189225	9000	Economy	27400.00
0005434189224	9000	Economy	27400.00
0005434484457	9000	Economy	24900.00
0005434189237	9000	Economy	24900.00
0005434189229	9000	Economy	24900.00
0005434189213	9000	Economy	24900.00
0005434189222	9000	Economy	24900.00
0005434484458	9000	Economy	24900.00
0005434484459	9000	Economy	24900.00
0005434189223	9000	Economy	24900.00
0005434189206	9000	Economy	24900.00
0005434189228	9000	Economy	24900.00
0005434189205	9000	Economy	24900.00
0005434189207	9000	Economy	24900.00
0005434484455	9000	Economy	24900.00
0005434189208	9000	Economy	24900.00
0005434484456	9000	Economy	24900.00
0005434189212	9000	Economy	24900.00
0005434484454	9000	Economy	24900.00
0005434189238	9000	Economy	24900.00
0005434484407	16635	Economy	27400.00
0005434484372	16635	Economy	24900.00
0005434484418	16635	Economy	24900.00
0005434189276	16635	Economy	24900.00
0005434189272	16635	Economy	24900.00
0005434484423	16635	Economy	24900.00
0005434484424	16635	Economy	24900.00
0005434189273	16635	Economy	24900.00
0005434484406	16635	Economy	24900.00
0005434484371	16635	Economy	24900.00
0005434484389	16635	Economy	24900.00
0005434189274	16635	Economy	24900.00
0005434484388	16635	Economy	24900.00
0005434484408	16635	Economy	24900.00
0005434484420	16635	Economy	24900.00
0005434189275	16635	Economy	24900.00
0005434484399	16635	Economy	24900.00
0005433124281	7623	Business	11100.00
0005433124269	7623	Business	11100.00
0005433722245	7623	Business	11100.00
0005433722264	7623	Business	11100.00
0005433722266	7623	Economy	3700.00
0005433124284	7623	Economy	3700.00
0005433124270	7623	Economy	3700.00
0005433124275	7623	Economy	3700.00
0005433722251	7623	Economy	3700.00
0005433722258	7623	Economy	3700.00
0005433722263	7623	Economy	3700.00
0005433124271	7623	Economy	4100.00
0005433124265	7623	Economy	3700.00
0005433124279	7623	Economy	3700.00
0005433124277	7623	Economy	3700.00
0005433124266	7623	Economy	3700.00
0005433124276	7623	Economy	3700.00
0005433722267	7623	Economy	3700.00
0005433722253	7623	Economy	3700.00
0005433124264	7623	Economy	3700.00
0005433124272	7623	Economy	3700.00
0005433124278	7623	Economy	3700.00
0005433722236	7623	Economy	3700.00
0005433124268	7623	Economy	3700.00
0005433124274	7623	Economy	3700.00
0005433124273	7623	Economy	3700.00
0005433722273	7623	Economy	3700.00
0005433124282	7623	Economy	3700.00
0005433722270	7623	Economy	3700.00
0005433722235	7623	Economy	3700.00
0005433124267	7623	Economy	3700.00
0005433722234	7623	Economy	3700.00
0005433124280	7623	Economy	3700.00
0005433124283	7623	Economy	3700.00
0005433722257	7623	Economy	3700.00
0005432721361	7622	Business	11100.00
0005433450320	7622	Business	11100.00
0005432693594	7622	Business	11100.00
0005432693596	7622	Business	11100.00
0005433450327	7622	Business	11100.00
0005433450336	7622	Business	11100.00
0005432721335	7622	Business	11100.00
0005432693588	7622	Business	11100.00
0005433450323	7622	Business	11100.00
0005432693578	7622	Business	11100.00
0005433450337	7622	Economy	3700.00
0005432721349	7622	Economy	3700.00
0005433450322	7622	Economy	3700.00
0005432693574	7622	Economy	3700.00
0005432721362	7622	Economy	3700.00
0005433450324	7622	Economy	3700.00
0005432693572	7622	Economy	3700.00
0005432721354	7622	Economy	3700.00
0005432721344	7622	Economy	3700.00
0005433450340	7622	Economy	3700.00
0005432721340	7622	Economy	4100.00
0005432693575	7622	Economy	4100.00
0005433450339	7622	Economy	4100.00
0005432721341	7622	Economy	4100.00
0005432721355	7622	Economy	4100.00
0005433450326	7622	Economy	3700.00
0005432721351	7622	Economy	3700.00
0005432693598	7622	Economy	3700.00
0005432693595	7622	Economy	3700.00
0005433450335	7622	Economy	3700.00
0005433450342	7622	Economy	3700.00
0005432721358	7622	Economy	3700.00
0005432693569	7622	Economy	3700.00
0005433450321	7622	Economy	3700.00
0005432721345	7622	Economy	3700.00
0005432071622	7622	Economy	3700.00
0005433450319	7622	Economy	3700.00
0005433450331	7622	Economy	3700.00
0005432693584	7622	Economy	3700.00
0005432693570	7622	Economy	3700.00
0005433450334	7622	Economy	3700.00
0005432693599	7622	Economy	3700.00
0005433450338	7622	Economy	3700.00
0005432693586	7622	Economy	3700.00
0005432693590	7622	Economy	3700.00
0005433450341	7622	Economy	3700.00
0005433450330	7622	Economy	3700.00
0005432693581	7622	Economy	3700.00
0005432071623	7622	Economy	3700.00
0005432693582	7622	Economy	3700.00
0005433450329	7622	Economy	3700.00
0005432693597	7622	Economy	3700.00
0005432693593	7622	Economy	3700.00
0005432721338	7622	Economy	3700.00
0005432693580	7622	Economy	3700.00
0005433450328	7622	Economy	3700.00
0005432721337	7622	Economy	3700.00
0005432721356	7622	Economy	3700.00
0005433450325	7622	Economy	3700.00
0005432721347	7622	Economy	3700.00
0005432721343	7622	Economy	3700.00
0005432721359	7622	Economy	3700.00
0005432071621	7622	Economy	3700.00
0005433450333	7622	Economy	3700.00
0005432693577	7622	Economy	3700.00
0005432721342	7622	Economy	3700.00
0005432693573	7622	Economy	3700.00
0005433450332	7622	Economy	3700.00
0005432693585	7622	Economy	3700.00
0005432693571	7622	Economy	3700.00
0005432721357	7622	Economy	3700.00
0005432721352	7622	Economy	3700.00
0005432721348	7622	Economy	3700.00
0005432693579	7622	Economy	3700.00
0005432721339	7622	Economy	3700.00
0005432693576	7622	Economy	3700.00
0005432721360	7622	Economy	3700.00
0005432721346	7622	Economy	3700.00
0005432693592	7622	Economy	3700.00
0005432721336	7622	Economy	3700.00
0005432693589	7622	Economy	3700.00
0005432693583	7622	Economy	3700.00
0005432693591	7622	Economy	3700.00
0005432721350	7622	Economy	3700.00
0005432693587	7622	Economy	3700.00
0005432721353	7622	Economy	3700.00
0005432693300	30385	Business	11100.00
0005433450166	30385	Business	11100.00
0005433450195	30385	Business	11100.00
0005432693188	30385	Business	11100.00
0005432693433	30385	Business	11100.00
0005432693346	30385	Business	11100.00
0005432693434	30385	Business	11100.00
0005432693306	30385	Business	11100.00
0005432693217	30385	Economy	3700.00
0005432693215	30385	Economy	3700.00
0005432693299	30385	Economy	3700.00
0005432693270	30385	Economy	3700.00
0005432693237	30385	Economy	3700.00
0005433450162	30385	Economy	4100.00
0005432693274	30385	Economy	4100.00
0005433450119	30385	Economy	4100.00
0005432693353	30385	Economy	4100.00
0005433450114	30385	Economy	3700.00
0005432693347	30385	Economy	3700.00
0005433450024	30385	Economy	3700.00
0005433450140	30385	Economy	3700.00
0005433450113	30385	Economy	3700.00
0005432693305	30385	Economy	3700.00
0005432693284	30385	Economy	3700.00
0005433450161	30385	Economy	3700.00
0005432693275	30385	Economy	3700.00
0005433450234	30385	Economy	3700.00
0005433450182	30385	Economy	3700.00
0005433450045	30385	Economy	3700.00
0005432693277	30385	Economy	3700.00
0005433450160	30385	Economy	3700.00
0005432693195	30385	Economy	3700.00
0005433450148	30385	Economy	3700.00
0005432693263	30385	Economy	3700.00
0005432693220	30385	Economy	3700.00
0005433450171	30385	Economy	3700.00
0005432693276	30385	Economy	3700.00
0005432693371	30385	Economy	3700.00
0005432693304	30385	Economy	3700.00
0005432693223	30385	Economy	3700.00
0005432693354	30385	Economy	3700.00
0005433450068	30385	Economy	3700.00
0005432693381	30385	Economy	3700.00
0005432693341	30385	Economy	3700.00
0005432693219	30385	Economy	3700.00
0005432693373	30385	Economy	3700.00
0005432693342	30385	Economy	3700.00
0005432693246	30385	Economy	3700.00
0005432693187	30385	Economy	3700.00
0005432693382	30385	Economy	3700.00
0005432693365	30385	Economy	3700.00
0005432693388	30385	Economy	3700.00
0005433450153	30385	Economy	3700.00
0005432693344	30385	Economy	3700.00
0005433450139	30385	Economy	3700.00
0005432721159	30386	Business	11100.00
0005433124084	30386	Business	11100.00
0005433124009	30386	Business	11100.00
0005433124056	30386	Business	11100.00
0005432721129	30386	Business	11100.00
0005432721148	30386	Business	11100.00
0005432721166	30386	Economy	3700.00
0005432721183	30386	Economy	3700.00
0005432721064	30386	Economy	3700.00
0005432721154	30386	Economy	3700.00
0005432721035	30386	Economy	3700.00
0005432721060	30386	Economy	3700.00
0005433124128	30386	Economy	4100.00
0005432721264	30386	Economy	3700.00
0005433124075	30386	Economy	4100.00
0005433124160	30386	Economy	4100.00
0005432721155	30386	Economy	4100.00
0005432721290	30386	Economy	4100.00
0005432721222	30386	Economy	3700.00
0005432721278	30386	Economy	3700.00
0005432721291	30386	Economy	3700.00
0005433124083	30386	Economy	3700.00
0005432721279	30386	Economy	3700.00
0005433124123	30386	Economy	3700.00
0005432721090	30386	Economy	3700.00
0005432721215	30386	Economy	3700.00
0005432721091	30386	Economy	3700.00
0005433124017	30386	Economy	3700.00
0005432721130	30386	Economy	3700.00
0005433124129	30386	Economy	3700.00
0005433124008	30386	Economy	3700.00
0005433124082	30386	Economy	3700.00
0005432721184	30386	Economy	3700.00
0005433124159	30386	Economy	3700.00
0005433124091	30386	Economy	3700.00
0005433124085	30386	Economy	3700.00
0005432721127	30386	Economy	3700.00
0005433124087	30386	Economy	3700.00
0005433722336	30386	Economy	3700.00
0005433124124	30386	Economy	3700.00
0005432720984	30386	Economy	3700.00
0005432721213	30386	Economy	3700.00
0005432721251	30386	Economy	3700.00
0005433722331	30386	Economy	3700.00
0005432721151	30386	Economy	3700.00
0005433124092	30386	Economy	3700.00
0005432721185	30386	Economy	3700.00
0005433722334	30386	Economy	3700.00
0005433124090	30386	Economy	3700.00
0005432721292	30386	Economy	3700.00
0005432721158	30386	Economy	3700.00
0005432721221	30386	Economy	3700.00
0005433722330	30386	Economy	3700.00
0005433722332	30386	Economy	3700.00
0005433722333	30386	Economy	3700.00
0005433124074	30386	Economy	3700.00
0005433722335	30386	Economy	3700.00
0005433124081	30386	Economy	3700.00
0005434515011	1383	Business	70400.00
0005432928028	1383	Business	70400.00
0005432271051	1383	Business	70400.00
0005432968860	1383	Business	70400.00
0005433724883	1383	Business	70400.00
0005434587050	1383	Business	70400.00
0005433724884	1383	Business	70400.00
0005432968854	1383	Business	70400.00
0005434587038	1383	Economy	23500.00
0005434587046	1383	Economy	23500.00
0005434587043	1383	Economy	23500.00
0005432271054	1383	Economy	23500.00
0005434587044	1383	Economy	23500.00
0005433193106	1383	Economy	23500.00
0005433525218	1383	Economy	23500.00
0005434587025	1383	Economy	25800.00
0005434587034	1383	Economy	25800.00
0005434513623	1383	Economy	25800.00
0005432928047	1383	Economy	25800.00
0005434587028	1383	Economy	25800.00
0005434587032	1383	Economy	23500.00
0005433525217	1383	Economy	23500.00
0005433724882	1383	Economy	23500.00
0005434587039	1383	Economy	23500.00
0005433525219	1383	Economy	23500.00
0005434515012	1383	Economy	23500.00
0005434513624	1383	Economy	23500.00
0005433193121	1383	Economy	23500.00
0005434587036	1383	Economy	23500.00
0005434513625	1383	Economy	23500.00
0005433193138	1383	Economy	23500.00
0005434587041	1383	Economy	23500.00
0005433724880	1383	Economy	23500.00
0005432928019	1383	Economy	23500.00
0005434587049	1383	Economy	23500.00
0005433193186	1383	Economy	23500.00
0005434587026	1383	Economy	23500.00
0005433193124	1383	Economy	23500.00
0005432928027	1383	Economy	23500.00
0005433525222	1383	Economy	23500.00
0005432928021	1383	Economy	23500.00
0005433525215	1383	Economy	23500.00
0005433193131	1383	Economy	23500.00
0005433525224	1383	Economy	23500.00
0005434587048	1383	Economy	23500.00
0005432928048	1383	Economy	23500.00
0005433724881	1383	Economy	23500.00
0005432271050	1383	Economy	23500.00
0005434587030	1383	Economy	23500.00
0005434587047	1383	Economy	23500.00
0005433525223	1383	Economy	23500.00
0005433193193	1383	Economy	23500.00
0005434513622	1383	Economy	23500.00
0005434587035	1383	Economy	23500.00
0005434587033	1383	Economy	23500.00
0005433525220	1383	Economy	23500.00
0005433193108	1383	Economy	23500.00
0005433193132	1383	Economy	23500.00
0005434587040	1383	Economy	23500.00
0005433525221	1383	Economy	23500.00
0005432928026	1383	Economy	23500.00
0005432271052	1383	Economy	23500.00
0005434587045	1383	Economy	23500.00
0005433193196	1383	Economy	23500.00
0005433193107	1383	Economy	23500.00
0005433525216	1383	Economy	23500.00
0005432968853	1383	Economy	23500.00
0005434587051	1383	Economy	23500.00
0005434587029	1383	Economy	23500.00
0005434587042	1383	Economy	23500.00
0005432928020	1383	Economy	23500.00
0005432271053	1383	Economy	23500.00
0005434587037	1383	Economy	23500.00
0005433193120	1383	Economy	23500.00
0005434587031	1383	Economy	23500.00
0005434587027	1383	Economy	23500.00
0005433193139	1383	Economy	23500.00
0005433525121	18535	Business	70400.00
0005434586813	18535	Business	70400.00
0005434586846	18535	Business	70400.00
0005433193268	18535	Business	70400.00
0005433193261	18535	Business	70400.00
0005433525073	18535	Business	70400.00
0005433525116	18535	Business	70400.00
0005433193269	18535	Economy	23500.00
0005432928073	18535	Economy	23500.00
0005432928071	18535	Economy	23500.00
0005433193262	18535	Economy	23500.00
0005432928069	18535	Economy	23500.00
0005433525082	18535	Economy	23500.00
0005433193267	18535	Economy	23500.00
0005432928074	18535	Economy	25800.00
0005434586814	18535	Economy	25800.00
0005433193266	18535	Economy	25800.00
0005434586726	18535	Economy	23500.00
0005433525103	18535	Economy	23500.00
0005434586844	18535	Economy	23500.00
0005433193263	18535	Economy	23500.00
0005433724830	18535	Economy	23500.00
0005433193270	18535	Economy	23500.00
0005433525110	18535	Economy	23500.00
0005433193265	18535	Economy	23500.00
0005433525129	18535	Economy	23500.00
0005434586964	18535	Economy	23500.00
0005433193264	18535	Economy	23500.00
0005433193260	18535	Economy	23500.00
0005433525099	18535	Economy	23500.00
0005434586850	18535	Economy	23500.00
0005432928072	18535	Economy	23500.00
0005434514983	18535	Economy	23500.00
0005434586832	18535	Economy	23500.00
0005434586725	18535	Economy	23500.00
0005434514986	18535	Economy	23500.00
0005432968878	18535	Economy	23500.00
0005433193273	18535	Economy	23500.00
0005433525111	18535	Economy	23500.00
0005433193271	18535	Economy	23500.00
0005432928070	18535	Economy	23500.00
0005434514982	18535	Economy	23500.00
0005434586669	18535	Economy	23500.00
0005433724846	18535	Economy	23500.00
0005432968877	18535	Economy	23500.00
0005434586836	18535	Economy	23500.00
0005433193272	18535	Economy	23500.00
0005434586825	18535	Economy	23500.00
0005433724829	18535	Economy	23500.00
0005434344764	11425	Economy	4300.00
0005434344772	11425	Economy	4300.00
0005434344773	11425	Economy	4300.00
0005434344781	11425	Economy	4300.00
0005434344766	11425	Economy	4000.00
0005435302223	11425	Economy	4000.00
0005434344778	11425	Economy	4000.00
0005434344763	11425	Economy	4000.00
0005434344771	11425	Economy	4000.00
0005434344761	11425	Economy	4000.00
0005434344760	11425	Economy	4000.00
0005434344780	11425	Economy	4000.00
0005434344762	11425	Economy	4000.00
0005434344754	11425	Economy	4000.00
0005434344757	11425	Economy	4000.00
0005434344750	11425	Economy	4000.00
0005434344774	11425	Economy	4000.00
0005434344747	11425	Economy	4000.00
0005434142674	11425	Economy	4000.00
0005434142676	11425	Economy	4000.00
0005434344775	11425	Economy	4000.00
0005434344758	11425	Economy	4000.00
0005434344755	11425	Economy	4000.00
0005434344768	11425	Economy	4000.00
0005435305030	11425	Economy	4000.00
0005435305029	11425	Economy	4000.00
0005435302231	11425	Economy	4000.00
0005434344748	11425	Economy	4000.00
0005434344759	11425	Economy	4000.00
0005434344749	11425	Economy	4000.00
0005434344767	11425	Economy	4000.00
0005434344751	11425	Economy	4000.00
0005434344779	11425	Economy	4000.00
0005434344776	11425	Economy	4000.00
0005435305023	11425	Economy	4000.00
0005434344752	11425	Economy	4000.00
0005434344770	11425	Economy	4000.00
0005434344765	11425	Economy	4000.00
0005434344777	11425	Economy	4000.00
0005434344756	11425	Economy	4000.00
0005434142675	11425	Economy	4000.00
0005434142677	11425	Economy	4000.00
0005435305024	11425	Economy	4000.00
0005434344753	11425	Economy	4000.00
0005434344769	11425	Economy	4000.00
0005434344499	29771	Economy	4300.00
0005435304231	29771	Economy	4300.00
0005435305044	29771	Economy	4300.00
0005434344461	29771	Economy	4000.00
0005434344587	29771	Economy	4000.00
0005434344455	29771	Economy	4000.00
0005435304227	29771	Economy	4000.00
0005435304229	29771	Economy	4000.00
0005434344402	29771	Economy	4000.00
0005434344331	29771	Economy	4000.00
0005434344450	29771	Economy	4000.00
0005434344493	29771	Economy	4000.00
0005435305045	29771	Economy	4000.00
0005434344390	29771	Economy	4000.00
0005434344490	29771	Economy	4000.00
0005435305047	29771	Economy	4000.00
0005434344330	29771	Economy	4000.00
0005435304230	29771	Economy	4000.00
0005434344588	29771	Economy	4000.00
0005434344451	29771	Economy	4000.00
0005434344462	29771	Economy	4000.00
0005435305046	29771	Economy	4000.00
0005434344533	29771	Economy	4000.00
0005434344494	29771	Economy	4000.00
0005434344589	29771	Economy	4000.00
0005434344452	29771	Economy	4000.00
0005434344454	29771	Economy	4000.00
0005434344496	29771	Economy	4000.00
0005434344403	29771	Economy	4000.00
0005434344495	29771	Economy	4000.00
0005434344500	29771	Economy	4000.00
0005435304228	29771	Economy	4000.00
0005434344502	29771	Economy	4000.00
0005434344467	29771	Economy	4000.00
0005434344506	29771	Economy	4000.00
0005434344332	29771	Economy	4000.00
0005435825072	1300	Business	199800.00
0005435825075	1300	Business	199800.00
0005433415788	1300	Business	199800.00
0005435825069	1300	Business	199800.00
0005435825077	1300	Business	199800.00
0005433415798	1300	Business	199800.00
0005433415836	1300	Business	199800.00
0005433415789	1300	Business	199800.00
0005435825084	1300	Economy	66600.00
0005433415840	1300	Economy	66600.00
0005433415842	1300	Economy	66600.00
0005433415841	1300	Economy	66600.00
0005435825079	1300	Economy	73200.00
0005435825062	1300	Economy	73200.00
0005432284609	1300	Economy	66600.00
0005433415752	1300	Economy	66600.00
0005433415805	1300	Economy	66600.00
0005435825074	1300	Economy	66600.00
0005433415832	1300	Economy	66600.00
0005435825060	1300	Economy	66600.00
0005432284608	1300	Economy	66600.00
0005433415777	1300	Economy	66600.00
0005435825081	1300	Economy	66600.00
0005435825073	1300	Economy	66600.00
0005435825080	1300	Economy	66600.00
0005433415783	1300	Economy	66600.00
0005435825061	1300	Economy	66600.00
0005435825065	1300	Economy	66600.00
0005435825064	1300	Economy	66600.00
0005435825068	1300	Economy	66600.00
0005435825059	1300	Economy	66600.00
0005433415804	1300	Economy	66600.00
0005435825063	1300	Economy	66600.00
0005433415751	1300	Economy	66600.00
0005435825076	1300	Economy	66600.00
0005433415828	1300	Economy	66600.00
0005435825067	1300	Economy	66600.00
0005432284607	1300	Economy	66600.00
0005433415796	1300	Economy	66600.00
0005433415764	1300	Economy	66600.00
0005435825058	1300	Economy	66600.00
0005435825066	1300	Economy	66600.00
0005435825078	1300	Economy	66600.00
0005435825083	1300	Economy	66600.00
0005435825071	1300	Economy	66600.00
0005433415837	1300	Economy	66600.00
0005433415815	1300	Economy	66600.00
0005433415797	1300	Economy	66600.00
0005435825070	1300	Economy	66600.00
0005435825082	1300	Economy	66600.00
0005435824819	18021	Business	199800.00
0005435824790	18021	Business	199800.00
0005435824767	18021	Business	199800.00
0005435824776	18021	Business	199800.00
0005433415925	18021	Business	199800.00
0005435824909	18021	Business	199800.00
0005435824946	18021	Business	199800.00
0005435824817	18021	Business	199800.00
0005435824889	18021	Business	199800.00
0005435824813	18021	Business	199800.00
0005435824850	18021	Economy	66600.00
0005433415923	18021	Economy	66600.00
0005435824938	18021	Economy	66600.00
0005435824906	18021	Economy	66600.00
0005433415920	18021	Economy	73200.00
0005435824768	18021	Economy	73200.00
0005435824937	18021	Economy	66600.00
0005435824786	18021	Economy	66600.00
0005435824698	18021	Economy	66600.00
0005435824827	18021	Economy	66600.00
0005435824730	18021	Economy	66600.00
0005433415916	18021	Economy	66600.00
0005433415931	18021	Economy	66600.00
0005433415917	18021	Economy	66600.00
0005433415921	18021	Economy	66600.00
0005435824890	18021	Economy	66600.00
0005433415929	18021	Economy	66600.00
0005433415918	18021	Economy	66600.00
0005433415926	18021	Economy	66600.00
0005435824809	18021	Economy	66600.00
0005433415928	18021	Economy	66600.00
0005433415930	18021	Economy	66600.00
0005435824829	18021	Economy	66600.00
0005435824904	18021	Economy	66600.00
0005433415924	18021	Economy	66600.00
0005435824838	18021	Economy	66600.00
0005433415922	18021	Economy	66600.00
0005435824839	18021	Economy	66600.00
0005435824789	18021	Economy	66600.00
0005435824917	18021	Economy	66600.00
0005435824773	18021	Economy	66600.00
0005435824969	18021	Economy	66600.00
0005435824787	18021	Economy	66600.00
0005435824863	18021	Economy	66600.00
0005433415927	18021	Economy	66600.00
0005435824828	18021	Economy	66600.00
0005435824699	18021	Economy	66600.00
0005435824942	18021	Economy	66600.00
0005433415919	18021	Economy	66600.00
0005435824785	18021	Economy	66600.00
0005435824774	18021	Economy	66600.00
0005435824816	18021	Economy	66600.00
0005435824947	18021	Economy	66600.00
0005435824857	18021	Economy	66600.00
0005434460533	12564	Economy	14800.00
0005434461679	12564	Economy	14800.00
0005434460537	12564	Economy	13500.00
0005434460534	12564	Economy	13500.00
0005434461674	12564	Economy	13500.00
0005434461678	12564	Economy	13500.00
0005434461680	12564	Economy	13500.00
0005434460535	12564	Economy	13500.00
0005434461677	12564	Economy	13500.00
0005434460538	12564	Economy	13500.00
0005434460532	12564	Economy	13500.00
0005434461675	12564	Economy	13500.00
0005434460539	12564	Economy	13500.00
0005434460536	12564	Economy	13500.00
0005434460531	12564	Economy	13500.00
0005434461681	12564	Economy	13500.00
0005434461676	12564	Economy	13500.00
0005435243125	5650	Business	27800.00
0005435242993	5650	Business	27800.00
0005432784692	5650	Business	27800.00
0005435243121	5650	Business	27800.00
0005432784680	5650	Business	27800.00
0005432784668	5650	Business	27800.00
0005435242881	5650	Business	27800.00
0005432784678	5650	Business	27800.00
0005435242987	5650	Business	27800.00
0005432784673	5650	Business	27800.00
0005435243071	5650	Business	27800.00
0005432784702	5650	Business	27800.00
0005435242997	5650	Economy	9300.00
0005435243004	5650	Economy	9300.00
0005432784665	5650	Economy	9300.00
0005435243144	5650	Economy	9300.00
0005432784701	5650	Economy	9300.00
0005432784709	5650	Economy	9300.00
0005432784684	5650	Economy	9300.00
0005432784691	5650	Economy	9300.00
0005435243044	5650	Economy	9300.00
0005432784695	5650	Economy	9300.00
0005432784707	5650	Economy	10200.00
0005435243019	5650	Economy	10200.00
0005435243028	5650	Economy	10200.00
0005432784659	5650	Economy	10200.00
0005432784689	5650	Economy	10200.00
0005432784666	5650	Economy	9300.00
0005432784661	5650	Economy	9300.00
0005432784703	5650	Economy	9300.00
0005432784674	5650	Economy	9300.00
0005432784700	5650	Economy	9300.00
0005432784687	5650	Economy	9300.00
0005435243070	5650	Economy	9300.00
0005432784670	5650	Economy	9300.00
0005435243179	5650	Economy	9300.00
0005435242958	5650	Economy	9300.00
0005435476797	5650	Economy	9300.00
0005435243064	5650	Economy	9300.00
0005432784664	5650	Economy	9300.00
0005432784688	5650	Economy	9300.00
0005432784677	5650	Economy	9300.00
0005432784658	5650	Economy	9300.00
0005435242949	5650	Economy	9300.00
0005432784710	5650	Economy	9300.00
0005435242971	5650	Economy	9300.00
0005432784696	5650	Economy	9300.00
0005432784693	5650	Economy	9300.00
0005432784708	5650	Economy	9300.00
0005432784686	5650	Economy	9300.00
0005435243094	5650	Economy	9300.00
0005435242950	5650	Economy	9300.00
0005435243003	5650	Economy	9300.00
0005432784690	5650	Economy	9300.00
0005432784694	5650	Economy	9300.00
0005432784697	5650	Economy	9300.00
0005432784698	5650	Economy	9300.00
0005432784663	5650	Economy	9300.00
0005435242986	5650	Economy	9300.00
0005432144043	5650	Economy	9300.00
0005435242992	5650	Economy	9300.00
0005435243122	5650	Economy	9300.00
0005435243026	5650	Economy	9300.00
0005435243162	5650	Economy	9300.00
0005435242969	5650	Economy	9300.00
0005432784662	5650	Economy	9300.00
0005432784656	5650	Economy	9300.00
0005435476796	5650	Economy	9300.00
0005432144042	5650	Economy	9300.00
0005435243027	5650	Economy	9300.00
0005432784657	5650	Economy	9300.00
0005435243074	5650	Economy	9300.00
0005435242970	5650	Economy	9300.00
0005435243063	5650	Economy	9300.00
0005432784683	5650	Economy	9300.00
0005432784704	5650	Economy	9300.00
0005432784685	5650	Economy	9300.00
0005432784676	5650	Economy	9300.00
0005432784671	5650	Economy	9300.00
0005432784667	5650	Economy	9300.00
0005432784669	5650	Economy	9300.00
0005432784679	5650	Economy	9300.00
0005435243043	5650	Economy	9300.00
0005432784675	5650	Economy	9300.00
0005435243178	5650	Economy	9300.00
0005435242963	5650	Economy	9300.00
0005432144041	5650	Economy	9300.00
0005432784706	5650	Economy	9300.00
0005432784705	5650	Economy	9300.00
0005435242880	5650	Economy	9300.00
0005435243100	5650	Economy	9300.00
0005432784681	5650	Economy	9300.00
0005435242998	5650	Economy	9300.00
0005432784660	5650	Economy	9300.00
0005432784672	5650	Economy	9300.00
0005432784682	5650	Economy	9300.00
0005432784699	5650	Economy	9300.00
0005432784258	15339	Business	27800.00
0005432783936	15339	Business	27800.00
0005435243275	15339	Business	27800.00
0005432784124	15339	Business	27800.00
0005435243265	15339	Business	27800.00
0005435243288	15339	Business	27800.00
0005435243281	15339	Business	27800.00
0005435243277	15339	Business	27800.00
0005432784168	15339	Business	27800.00
0005432784212	15339	Business	27800.00
0005435476861	15339	Business	27800.00
0005432784187	15339	Business	27800.00
0005432784178	15339	Economy	9300.00
0005435243287	15339	Economy	9300.00
0005435476862	15339	Economy	9300.00
0005435243284	15339	Economy	9300.00
0005435243268	15339	Economy	9300.00
0005435476868	15339	Economy	9300.00
0005432784174	15339	Economy	9300.00
0005435476865	15339	Economy	9300.00
0005432784291	15339	Economy	9300.00
0005435476864	15339	Economy	9300.00
0005435243273	15339	Economy	10200.00
0005435243285	15339	Economy	10200.00
0005432784225	15339	Economy	10200.00
0005435243267	15339	Economy	10200.00
0005432784156	15339	Economy	9300.00
0005435243278	15339	Economy	9300.00
0005432784254	15339	Economy	9300.00
0005432784193	15339	Economy	9300.00
0005432783935	15339	Economy	9300.00
0005432784092	15339	Economy	9300.00
0005432784292	15339	Economy	9300.00
0005432784144	15339	Economy	9300.00
0005435243274	15339	Economy	9300.00
0005432784304	15339	Economy	9300.00
0005432784188	15339	Economy	9300.00
0005432784105	15339	Economy	9300.00
0005432783996	15339	Economy	9300.00
0005435243272	15339	Economy	9300.00
0005432784104	15339	Economy	9300.00
0005432784159	15339	Economy	9300.00
0005432784231	15339	Economy	9300.00
0005432784145	15339	Economy	9300.00
0005435476867	15339	Economy	9300.00
0005432784046	15339	Economy	9300.00
0005435476866	15339	Economy	9300.00
0005432783846	15339	Economy	9300.00
0005435243270	15339	Economy	9300.00
0005432784363	15339	Economy	9300.00
0005432784267	15339	Economy	9300.00
0005432784255	15339	Economy	9300.00
0005432784224	15339	Economy	9300.00
0005432783917	15339	Economy	9300.00
0005432784169	15339	Economy	9300.00
0005432784256	15339	Economy	9300.00
0005432784202	15339	Economy	9300.00
0005432784303	15339	Economy	9300.00
0005435243282	15339	Economy	9300.00
0005435243264	15339	Economy	9300.00
0005432784077	15339	Economy	9300.00
0005435476860	15339	Economy	9300.00
0005432784183	15339	Economy	9300.00
0005432784184	15339	Economy	9300.00
0005435243276	15339	Economy	9300.00
0005435243271	15339	Economy	9300.00
0005435243283	15339	Economy	9300.00
0005432784327	15339	Economy	9300.00
0005432784266	15339	Economy	9300.00
0005435243266	15339	Economy	9300.00
0005435243269	15339	Economy	9300.00
0005435476863	15339	Economy	9300.00
0005432784192	15339	Economy	9300.00
0005432784374	15339	Economy	9300.00
0005432784157	15339	Economy	9300.00
0005435243279	15339	Economy	9300.00
0005432784024	15339	Economy	9300.00
0005432783975	15339	Economy	9300.00
0005432784031	15339	Economy	9300.00
0005432784306	15339	Economy	9300.00
0005435476859	15339	Economy	9300.00
0005435243286	15339	Economy	9300.00
0005432784006	15339	Economy	9300.00
0005432784125	15339	Economy	9300.00
0005435243280	15339	Economy	9300.00
0005432784226	15339	Economy	9300.00
0005432784084	15339	Economy	9300.00
0005432784328	15339	Economy	9300.00
0005432784175	15339	Economy	9300.00
0005432784211	15339	Economy	9300.00
0005432848547	4342	Economy	7000.00
0005434463967	4342	Economy	7000.00
0005432848559	4342	Economy	6300.00
0005432848554	4342	Economy	6300.00
0005432848557	4342	Economy	6300.00
0005434463965	4342	Economy	6300.00
0005432848556	4342	Economy	6300.00
0005434463966	4342	Economy	6300.00
0005435851003	4342	Economy	6300.00
0005435850992	4342	Economy	6300.00
0005432848553	4342	Economy	6300.00
0005434462826	4342	Economy	6300.00
0005432848549	4342	Economy	6300.00
0005434462825	4342	Economy	6300.00
0005435850948	4342	Economy	6300.00
0005432848548	4342	Economy	6300.00
0005432848552	4342	Economy	6300.00
0005435851004	4342	Economy	6300.00
0005432848558	4342	Economy	6300.00
0005432848555	4342	Economy	6300.00
0005432848550	4342	Economy	6300.00
0005435850964	4342	Economy	6300.00
0005432848551	4342	Economy	6300.00
0005432848546	4342	Economy	6300.00
0005432848388	28862	Economy	6300.00
0005435851063	28862	Economy	6300.00
0005435851064	28862	Economy	6300.00
0005435851061	28862	Economy	6300.00
0005432848407	28862	Economy	6300.00
0005435851058	28862	Economy	6300.00
0005432848434	28862	Economy	6300.00
0005432848455	28862	Economy	6300.00
0005432848404	28862	Economy	6300.00
0005432848387	28862	Economy	6300.00
0005434461667	28862	Economy	6300.00
0005432848470	28862	Economy	6300.00
0005435851059	28862	Economy	6300.00
0005434463938	28862	Economy	6300.00
0005432848403	28862	Economy	6300.00
0005435851057	28862	Economy	6300.00
0005435851060	28862	Economy	6300.00
0005432848402	28862	Economy	6300.00
0005432848469	28862	Economy	6300.00
0005432848456	28862	Economy	6300.00
0005435851062	28862	Economy	6300.00
0005435851065	28862	Economy	6300.00
0005432075289	6277	Business	11900.00
0005433497506	6277	Business	11900.00
0005434443979	6277	Business	11900.00
0005434443975	6277	Business	11900.00
0005433497496	6277	Business	11900.00
0005434926329	6277	Economy	4000.00
0005433497505	6277	Economy	4000.00
0005434443971	6277	Economy	4000.00
0005434443982	6277	Economy	4000.00
0005432075286	6277	Economy	4000.00
0005434443980	6277	Economy	4000.00
0005433497503	6277	Economy	4000.00
0005433497490	6277	Economy	4000.00
0005434926334	6277	Economy	4400.00
0005434443972	6277	Economy	4400.00
0005433497497	6277	Economy	4400.00
0005433497500	6277	Economy	4400.00
0005433497476	6277	Economy	4400.00
0005434926341	6277	Economy	4000.00
0005433497487	6277	Economy	4000.00
0005432075291	6277	Economy	4000.00
0005434926332	6277	Economy	4000.00
0005433497489	6277	Economy	4000.00
0005433497502	6277	Economy	4000.00
0005433497491	6277	Economy	4000.00
0005433497480	6277	Economy	4000.00
0005434926338	6277	Economy	4000.00
0005434443983	6277	Economy	4000.00
0005433497477	6277	Economy	4000.00
0005434926336	6277	Economy	4000.00
0005434443969	6277	Economy	4000.00
0005434926328	6277	Economy	4000.00
0005433497504	6277	Economy	4000.00
0005434926337	6277	Economy	4000.00
0005433497493	6277	Economy	4000.00
0005434443984	6277	Economy	4000.00
0005434443978	6277	Economy	4000.00
0005433497499	6277	Economy	4000.00
0005433497486	6277	Economy	4000.00
0005434926340	6277	Economy	4000.00
0005434443973	6277	Economy	4000.00
0005432075290	6277	Economy	4000.00
0005433497501	6277	Economy	4000.00
0005434443985	6277	Economy	4000.00
0005433497482	6277	Economy	4000.00
0005433497492	6277	Economy	4000.00
0005433497494	6277	Economy	4000.00
0005433497481	6277	Economy	4000.00
0005433497488	6277	Economy	4000.00
0005433497484	6277	Economy	4000.00
0005434926331	6277	Economy	4000.00
0005434443970	6277	Economy	4000.00
0005434926330	6277	Economy	4000.00
0005433497478	6277	Economy	4000.00
0005434926335	6277	Economy	4000.00
0005433497498	6277	Economy	4000.00
0005434926327	6277	Economy	4000.00
0005433497507	6277	Economy	4000.00
0005434443977	6277	Economy	4000.00
0005434926342	6277	Economy	4000.00
0005433497483	6277	Economy	4000.00
0005434926339	6277	Economy	4000.00
0005434926333	6277	Economy	4000.00
0005432075288	6277	Economy	4000.00
0005433497495	6277	Economy	4000.00
0005434443976	6277	Economy	4000.00
0005433497475	6277	Economy	4000.00
0005434443974	6277	Economy	4000.00
0005432075287	6277	Economy	4000.00
0005433497485	6277	Economy	4000.00
0005433497479	6277	Economy	4000.00
0005434443981	6277	Economy	4000.00
0005433497251	20410	Business	11900.00
0005434443882	20410	Business	11900.00
0005434926048	20410	Business	11900.00
0005433497382	20410	Business	11900.00
0005434926010	20410	Business	11900.00
0005434443832	20410	Business	11900.00
0005434926071	20410	Business	11900.00
0005433497173	20410	Business	11900.00
0005433497350	20410	Business	11900.00
0005434926032	20410	Economy	4000.00
0005434443861	20410	Economy	4000.00
0005434925916	20410	Economy	4000.00
0005434443795	20410	Economy	4000.00
0005433497383	20410	Economy	4000.00
0005434926043	20410	Economy	4000.00
0005434925996	20410	Economy	4400.00
0005434925972	20410	Economy	4400.00
0005434443810	20410	Economy	4400.00
0005434926052	20410	Economy	4400.00
0005434443883	20410	Economy	4000.00
0005434926008	20410	Economy	4000.00
0005434926073	20410	Economy	4000.00
0005434925887	20410	Economy	4000.00
0005433497282	20410	Economy	4000.00
0005434926057	20410	Economy	4000.00
0005433497330	20410	Economy	4000.00
0005434443811	20410	Economy	4000.00
0005434443830	20410	Economy	4000.00
0005434925943	20410	Economy	4000.00
0005434443894	20410	Economy	4000.00
0005433497272	20410	Economy	4000.00
0005434443839	20410	Economy	4000.00
0005434926083	20410	Economy	4000.00
0005434443828	20410	Economy	4000.00
0005434926049	20410	Economy	4000.00
0005433497171	20410	Economy	4000.00
0005433497281	20410	Economy	4000.00
0005434925933	20410	Economy	4000.00
0005433497286	20410	Economy	4000.00
0005433497336	20410	Economy	4000.00
0005434926056	20410	Economy	4000.00
0005434443789	20410	Economy	4000.00
0005434925882	20410	Economy	4000.00
0005434443853	20410	Economy	4000.00
0005434443833	20410	Economy	4000.00
0005434443863	20410	Economy	4000.00
0005433497217	20410	Economy	4000.00
0005434443765	20410	Economy	4000.00
0005434925942	20410	Economy	4000.00
0005434443834	20410	Economy	4000.00
0005434925968	20410	Economy	4000.00
0005433497189	20410	Economy	4000.00
0005434443821	20410	Economy	4000.00
0005434926038	20410	Economy	4000.00
0005434926009	20410	Economy	4000.00
0005433497287	20410	Economy	4000.00
0005434926034	20410	Economy	4000.00
0005433497233	20410	Economy	4000.00
0005434443788	20410	Economy	4000.00
0005434925959	20410	Economy	4000.00
0005434926080	20410	Economy	4000.00
0005434925860	20410	Economy	4000.00
0005434926065	20410	Economy	4000.00
0005433497250	20410	Economy	4000.00
0005434443860	20410	Economy	4000.00
0005434926072	20410	Economy	4000.00
0005434443820	20410	Economy	4000.00
0005434926046	20410	Economy	4000.00
0005433497271	20410	Economy	4000.00
0005433497124	20410	Economy	4000.00
0005434443848	20410	Economy	4000.00
0005434443841	20410	Economy	4000.00
0005434443831	20410	Economy	4000.00
0005434926028	20410	Economy	4000.00
0005434926036	20410	Economy	4000.00
0005434443845	20410	Economy	4000.00
0005435243301	12173	Business	41200.00
0005432784321	12173	Business	41200.00
0005432784285	12173	Business	41200.00
0005432784108	12173	Business	41200.00
0005432784194	12173	Business	41200.00
0005435243315	12173	Business	41200.00
0005435243296	12173	Business	41200.00
0005432784257	12173	Business	41200.00
0005432784488	12173	Business	41200.00
0005435243294	12173	Business	41200.00
0005432784220	12173	Business	41200.00
0005432784118	12173	Economy	13700.00
0005435243311	12173	Economy	13700.00
0005432784207	12173	Economy	13700.00
0005432784436	12173	Economy	13700.00
0005432783925	12173	Economy	13700.00
0005432784251	12173	Economy	13700.00
0005432784119	12173	Economy	13700.00
0005435243300	12173	Economy	13700.00
0005435243303	12173	Economy	13700.00
0005435243307	12173	Economy	15100.00
0005432784348	12173	Economy	15100.00
0005435243302	12173	Economy	15100.00
0005435243295	12173	Economy	15100.00
0005432783924	12173	Economy	13700.00
0005432784200	12173	Economy	13700.00
0005432784199	12173	Economy	13700.00
0005435243292	12173	Economy	13700.00
0005435243293	12173	Economy	13700.00
0005432784284	12173	Economy	13700.00
0005432784311	12173	Economy	13700.00
0005432784201	12173	Economy	13700.00
0005435243304	12173	Economy	13700.00
0005435243314	12173	Economy	13700.00
0005432784136	12173	Economy	13700.00
0005435243310	12173	Economy	13700.00
0005432784253	12173	Economy	13700.00
0005432784309	12173	Economy	13700.00
0005432784196	12173	Economy	13700.00
0005432784016	12173	Economy	13700.00
0005435243289	12173	Economy	13700.00
0005435243309	12173	Economy	13700.00
0005432784268	12173	Economy	13700.00
0005432784170	12173	Economy	13700.00
0005435243316	12173	Economy	13700.00
0005435243298	12173	Economy	13700.00
0005435243299	12173	Economy	13700.00
0005435243290	12173	Economy	13700.00
0005432784106	12173	Economy	13700.00
0005432784132	12173	Economy	13700.00
0005435243312	12173	Economy	13700.00
0005432784123	12173	Economy	13700.00
0005432784015	12173	Economy	13700.00
0005432784083	12173	Economy	13700.00
0005432784131	12173	Economy	13700.00
0005432784218	12173	Economy	13700.00
0005432784017	12173	Economy	13700.00
0005435243291	12173	Economy	13700.00
0005435243317	12173	Economy	13700.00
0005432784478	12173	Economy	13700.00
0005432784032	12173	Economy	13700.00
0005435243305	12173	Economy	13700.00
0005432784370	12173	Economy	13700.00
0005432784347	12173	Economy	13700.00
0005432784208	12173	Economy	13700.00
0005435243308	12173	Economy	13700.00
0005435243313	12173	Economy	13700.00
0005435243297	12173	Economy	13700.00
0005432784082	12173	Economy	13700.00
0005432784054	12173	Economy	13700.00
0005432784310	12173	Economy	13700.00
0005432784237	12173	Economy	13700.00
0005432784410	12173	Economy	13700.00
0005435243306	12173	Economy	13700.00
0005432784290	12173	Economy	13700.00
0005432784219	12173	Economy	13700.00
0005432784477	12173	Economy	13700.00
0005432784033	12173	Economy	13700.00
0005435243052	15447	Business	41200.00
0005435242894	15447	Business	41200.00
0005432784634	15447	Business	41200.00
0005432784604	15447	Business	41200.00
0005435242966	15447	Business	41200.00
0005432784608	15447	Business	41200.00
0005432784647	15447	Business	41200.00
0005432784626	15447	Business	41200.00
0005435242981	15447	Business	41200.00
0005432784648	15447	Business	41200.00
0005432784633	15447	Economy	13700.00
0005432784638	15447	Economy	13700.00
0005435243053	15447	Economy	13700.00
0005435243115	15447	Economy	13700.00
0005432784651	15447	Economy	13700.00
0005435243022	15447	Economy	13700.00
0005435242980	15447	Economy	13700.00
0005432784625	15447	Economy	13700.00
0005432784654	15447	Economy	13700.00
0005435243037	15447	Economy	15100.00
0005432784636	15447	Economy	15100.00
0005432784614	15447	Economy	15100.00
0005432784621	15447	Economy	15100.00
0005432784616	15447	Economy	15100.00
0005432784632	15447	Economy	13700.00
0005432784629	15447	Economy	13700.00
0005432784610	15447	Economy	13700.00
0005435243049	15447	Economy	13700.00
0005435243021	15447	Economy	13700.00
0005435243065	15447	Economy	13700.00
0005432784641	15447	Economy	13700.00
0005435243048	15447	Economy	13700.00
0005435243092	15447	Economy	13700.00
0005432784601	15447	Economy	13700.00
0005435242910	15447	Economy	13700.00
0005432784644	15447	Economy	13700.00
0005435242936	15447	Economy	13700.00
0005435243114	15447	Economy	13700.00
0005432784637	15447	Economy	13700.00
0005432784618	15447	Economy	13700.00
0005432784603	15447	Economy	13700.00
0005432784609	15447	Economy	13700.00
0005435243113	15447	Economy	13700.00
0005432784650	15447	Economy	13700.00
0005432784652	15447	Economy	13700.00
0005432784624	15447	Economy	13700.00
0005435243038	15447	Economy	13700.00
0005432784606	15447	Economy	13700.00
0005432784642	15447	Economy	13700.00
0005432784630	15447	Economy	13700.00
0005432784619	15447	Economy	13700.00
0005435243062	15447	Economy	13700.00
0005432784631	15447	Economy	13700.00
0005432784643	15447	Economy	13700.00
0005432784607	15447	Economy	13700.00
0005432784653	15447	Economy	13700.00
0005435242909	15447	Economy	13700.00
0005432784615	15447	Economy	13700.00
0005432784627	15447	Economy	13700.00
0005432784649	15447	Economy	13700.00
0005432784605	15447	Economy	13700.00
0005435243012	15447	Economy	13700.00
0005435243093	15447	Economy	13700.00
0005432784645	15447	Economy	13700.00
0005435243072	15447	Economy	13700.00
0005435243013	15447	Economy	13700.00
0005435243066	15447	Economy	13700.00
0005432784602	15447	Economy	13700.00
0005432784655	15447	Economy	13700.00
0005432784640	15447	Economy	13700.00
0005432784635	15447	Economy	13700.00
0005432784620	15447	Economy	13700.00
0005435243050	15447	Economy	13700.00
0005435242908	15447	Economy	13700.00
0005432784639	15447	Economy	13700.00
0005435243054	15447	Economy	13700.00
0005435243047	15447	Economy	13700.00
0005435242948	15447	Economy	13700.00
0005435242924	15447	Economy	13700.00
0005432784613	15447	Economy	13700.00
0005432784646	15447	Economy	13700.00
0005432784623	15447	Economy	13700.00
0005432784622	15447	Economy	13700.00
0005432784617	15447	Economy	13700.00
0005432784628	15447	Economy	13700.00
0005432784612	15447	Economy	13700.00
0005432784611	15447	Economy	13700.00
0005435243005	15447	Economy	13700.00
0005435242892	15447	Economy	13700.00
0005434878916	10115	Business	49700.00
0005434879353	10115	Business	49700.00
0005434878814	10115	Business	49700.00
0005435913982	10115	Business	49700.00
0005434878917	10115	Business	49700.00
0005434878704	10115	Business	49700.00
0005434878679	10115	Business	49700.00
0005434879124	10115	Business	49700.00
0005434878914	10115	Business	49700.00
0005435913995	10115	Business	49700.00
0005434879170	10115	Business	49700.00
0005435913988	10115	Business	49700.00
0005434879018	10115	Business	49700.00
0005434878985	10115	Business	49700.00
0005434879017	10115	Business	49700.00
0005435913993	10115	Business	49700.00
0005434879112	10115	Business	49700.00
0005434878319	10115	Business	49700.00
0005434878621	10115	Economy	16600.00
0005435913991	10115	Economy	16600.00
0005434878769	10115	Economy	16600.00
0005434878700	10115	Economy	16600.00
0005434879311	10115	Economy	16600.00
0005434879246	10115	Economy	16600.00
0005434878984	10115	Economy	16600.00
0005434878734	10115	Economy	16600.00
0005434878320	10115	Economy	16600.00
0005435913984	10115	Economy	16600.00
0005434878662	10115	Economy	16600.00
0005434879096	10115	Economy	16600.00
0005434878915	10115	Economy	18200.00
0005434879020	10115	Economy	18200.00
0005435913985	10115	Economy	18200.00
0005434878957	10115	Economy	16600.00
0005434879187	10115	Economy	16600.00
0005434878705	10115	Economy	16600.00
0005434878685	10115	Economy	16600.00
0005434879162	10115	Economy	16600.00
0005434878987	10115	Economy	16600.00
0005434878825	10115	Economy	16600.00
0005434878453	10115	Economy	16600.00
0005434879084	10115	Economy	16600.00
0005435913986	10115	Economy	16600.00
0005434879160	10115	Economy	16600.00
0005434878923	10115	Economy	16600.00
0005434878828	10115	Economy	16600.00
0005435913981	10115	Economy	16600.00
0005434910151	10115	Economy	16600.00
0005434878918	10115	Economy	16600.00
0005434878932	10115	Economy	16600.00
0005434878493	10115	Economy	16600.00
0005435913992	10115	Economy	16600.00
0005434878867	10115	Economy	16600.00
0005434878663	10115	Economy	16600.00
0005434910153	10115	Economy	16600.00
0005434878699	10115	Economy	16600.00
0005434878612	10115	Economy	16600.00
0005434878703	10115	Economy	16600.00
0005434878680	10115	Economy	16600.00
0005434878826	10115	Economy	16600.00
0005434878786	10115	Economy	16600.00
0005434879068	10115	Economy	16600.00
0005435913994	10115	Economy	16600.00
0005435913989	10115	Economy	16600.00
0005434878342	10115	Economy	16600.00
0005434879123	10115	Economy	16600.00
0005434878956	10115	Economy	16600.00
0005434878908	10115	Economy	16600.00
0005434879247	10115	Economy	16600.00
0005434878494	10115	Economy	16600.00
0005434758899	10115	Economy	16600.00
0005434878483	10115	Economy	16600.00
0005434878840	10115	Economy	16600.00
0005434758917	10115	Economy	16600.00
0005434879333	10115	Economy	16600.00
0005434879025	10115	Economy	16600.00
0005434879227	10115	Economy	16600.00
0005434879002	10115	Economy	16600.00
0005434879041	10115	Economy	16600.00
0005435913990	10115	Economy	16600.00
0005434879184	10115	Economy	16600.00
0005434879183	10115	Economy	16600.00
0005434879186	10115	Economy	16600.00
0005434879169	10115	Economy	16600.00
0005434879111	10115	Economy	16600.00
0005434878972	10115	Economy	16600.00
0005434878900	10115	Economy	16600.00
0005434879067	10115	Economy	16600.00
0005434878770	10115	Economy	16600.00
0005434878983	10115	Economy	16600.00
0005435913987	10115	Economy	16600.00
0005434879052	10115	Economy	16600.00
0005435913983	10115	Economy	16600.00
0005434878793	10115	Economy	16600.00
0005434878988	10115	Economy	16600.00
0005434879069	10115	Economy	16600.00
0005434910152	10115	Economy	16600.00
0005434878767	10115	Economy	16600.00
0005434878765	10115	Economy	16600.00
0005434878808	10115	Economy	16600.00
0005434878924	10115	Economy	16600.00
0005434879130	10115	Economy	16600.00
0005434878940	10115	Economy	16600.00
0005434879802	14606	Business	49700.00
0005434879764	14606	Business	49700.00
0005434879790	14606	Business	49700.00
0005434879781	14606	Business	49700.00
0005434879739	14606	Business	49700.00
0005434879798	14606	Business	49700.00
0005434879734	14606	Business	49700.00
0005434879788	14606	Business	49700.00
0005434879792	14606	Business	49700.00
0005434879732	14606	Business	49700.00
0005434879743	14606	Business	49700.00
0005434879745	14606	Business	49700.00
0005434879774	14606	Business	49700.00
0005434879776	14606	Business	49700.00
0005434879737	14606	Business	49700.00
0005434879760	14606	Business	49700.00
0005434879761	14606	Business	49700.00
0005434879770	14606	Business	49700.00
0005434879730	14606	Economy	16600.00
0005434910122	14606	Economy	16600.00
0005434879813	14606	Economy	16600.00
0005434879799	14606	Economy	16600.00
0005434879809	14606	Economy	16600.00
0005434879794	14606	Economy	16600.00
0005434879823	14606	Economy	16600.00
0005434879814	14606	Economy	16600.00
0005434879772	14606	Economy	16600.00
0005434879780	14606	Economy	16600.00
0005434879786	14606	Economy	16600.00
0005434879800	14606	Economy	16600.00
0005434879807	14606	Economy	16600.00
0005434879748	14606	Economy	18200.00
0005434879755	14606	Economy	18200.00
0005434879767	14606	Economy	18200.00
0005434879768	14606	Economy	18200.00
0005435913948	14606	Economy	16600.00
0005434879749	14606	Economy	16600.00
0005434879793	14606	Economy	16600.00
0005434879812	14606	Economy	16600.00
0005434879821	14606	Economy	16600.00
0005434879824	14606	Economy	16600.00
0005434879750	14606	Economy	16600.00
0005434879804	14606	Economy	16600.00
0005434879785	14606	Economy	16600.00
0005434879773	14606	Economy	16600.00
0005434879783	14606	Economy	16600.00
0005434879747	14606	Economy	16600.00
0005434879752	14606	Economy	16600.00
0005434910127	14606	Economy	16600.00
0005434879754	14606	Economy	16600.00
0005434758932	14606	Economy	16600.00
0005434879763	14606	Economy	16600.00
0005434879762	14606	Economy	16600.00
0005434879817	14606	Economy	16600.00
0005434879775	14606	Economy	16600.00
0005434879758	14606	Economy	16600.00
0005434879738	14606	Economy	16600.00
0005434879746	14606	Economy	16600.00
0005434758934	14606	Economy	16600.00
0005434879816	14606	Economy	16600.00
0005434879729	14606	Economy	16600.00
0005434879818	14606	Economy	16600.00
0005434879777	14606	Economy	16600.00
0005434879822	14606	Economy	16600.00
0005434910128	14606	Economy	16600.00
0005434879808	14606	Economy	16600.00
0005434879765	14606	Economy	16600.00
0005434879742	14606	Economy	16600.00
0005434879771	14606	Economy	16600.00
0005434879801	14606	Economy	16600.00
0005434879740	14606	Economy	16600.00
0005434879759	14606	Economy	16600.00
0005434910121	14606	Economy	16600.00
0005434879815	14606	Economy	16600.00
0005434879757	14606	Economy	16600.00
0005434879825	14606	Economy	16600.00
0005435913952	14606	Economy	16600.00
0005434879797	14606	Economy	16600.00
0005434879795	14606	Economy	16600.00
0005435913951	14606	Economy	16600.00
0005434879819	14606	Economy	16600.00
0005434879803	14606	Economy	16600.00
0005434910129	14606	Economy	16600.00
0005434879805	14606	Economy	16600.00
0005434879820	14606	Economy	16600.00
0005435913947	14606	Economy	16600.00
0005434879787	14606	Economy	16600.00
0005434758931	14606	Economy	16600.00
0005434910126	14606	Economy	16600.00
0005434879811	14606	Economy	16600.00
0005434879778	14606	Economy	16600.00
0005434879733	14606	Economy	16600.00
0005434879731	14606	Economy	16600.00
0005434879791	14606	Economy	16600.00
0005434879779	14606	Economy	16600.00
0005434879736	14606	Economy	16600.00
0005434879744	14606	Economy	16600.00
0005434879769	14606	Economy	16600.00
0005434879766	14606	Economy	16600.00
0005434879728	14606	Economy	16600.00
0005434879782	14606	Economy	16600.00
0005434879741	14606	Economy	16600.00
0005434879753	14606	Economy	16600.00
0005434879756	14606	Economy	16600.00
0005434879806	14606	Economy	16600.00
0005434758933	14606	Economy	16600.00
0005434879810	14606	Economy	16600.00
0005434879796	14606	Economy	16600.00
0005434879751	14606	Economy	16600.00
0005434879784	14606	Economy	16600.00
0005434879735	14606	Economy	16600.00
0005434879789	14606	Economy	16600.00
0005435660322	9220	Economy	22400.00
0005435660325	9220	Economy	20300.00
0005435660319	9220	Economy	20300.00
0005435660318	9220	Economy	20300.00
0005435660327	9220	Economy	20300.00
0005434252009	9220	Economy	20300.00
0005435660317	9220	Economy	20300.00
0005435660323	9220	Economy	20300.00
0005435660324	9220	Economy	20300.00
0005435660321	9220	Economy	20300.00
0005434252011	9220	Economy	20300.00
0005435660320	9220	Economy	20300.00
0005435660328	9220	Economy	20300.00
0005434252010	9220	Economy	20300.00
0005434252051	9220	Economy	20300.00
0005435660326	9220	Economy	20300.00
0005435660238	24683	Economy	22400.00
0005434252124	24683	Economy	20300.00
0005435660229	24683	Economy	20300.00
0005434252121	24683	Economy	20300.00
0005435660256	24683	Economy	20300.00
0005435660234	24683	Economy	20300.00
0005434252123	24683	Economy	20300.00
0005434252125	24683	Economy	20300.00
0005434252117	24683	Economy	20300.00
0005434252118	24683	Economy	20300.00
0005435660233	24683	Economy	20300.00
0005434252120	24683	Economy	20300.00
0005434252122	24683	Economy	20300.00
0005434252126	24683	Economy	20300.00
0005434252119	24683	Economy	20300.00
0005435660202	24683	Economy	20300.00
0005433681369	2805	Business	33000.00
0005433681351	2805	Business	33000.00
0005433681365	2805	Business	33000.00
0005432967103	2805	Business	33000.00
0005432967140	2805	Business	33000.00
0005433681352	2805	Business	33000.00
0005433681360	2805	Business	33000.00
0005432967163	2805	Business	33000.00
0005433681322	2805	Business	33000.00
0005433681342	2805	Business	33000.00
0005433681348	2805	Economy	11000.00
0005433681354	2805	Economy	11000.00
0005433681350	2805	Economy	11000.00
0005433681364	2805	Economy	11000.00
0005432222869	2805	Economy	11000.00
0005433681344	2805	Economy	11000.00
0005432222867	2805	Economy	11000.00
0005432222871	2805	Economy	11000.00
0005432967168	2805	Economy	11000.00
0005432967027	2805	Economy	12100.00
0005433681362	2805	Economy	12100.00
0005432967171	2805	Economy	12100.00
0005433681327	2805	Economy	11000.00
0005433681331	2805	Economy	11000.00
0005433681368	2805	Economy	11000.00
0005433681338	2805	Economy	11000.00
0005432222866	2805	Economy	11000.00
0005433681343	2805	Economy	11000.00
0005433681355	2805	Economy	11000.00
0005432967204	2805	Economy	11000.00
0005432967165	2805	Economy	11000.00
0005432967139	2805	Economy	11000.00
0005433681361	2805	Economy	11000.00
0005432967154	2805	Economy	11000.00
0005433681358	2805	Economy	11000.00
0005432222870	2805	Economy	11000.00
0005432967080	2805	Economy	11000.00
0005433681349	2805	Economy	11000.00
0005432967179	2805	Economy	11000.00
0005432967082	2805	Economy	11000.00
0005433681336	2805	Economy	11000.00
0005433681346	2805	Economy	11000.00
0005433684453	2805	Economy	11000.00
0005433681328	2805	Economy	11000.00
0005433681345	2805	Economy	11000.00
0005432967192	2805	Economy	11000.00
0005432967081	2805	Economy	11000.00
0005432967028	2805	Economy	11000.00
0005433681359	2805	Economy	11000.00
0005433681337	2805	Economy	11000.00
0005433681367	2805	Economy	11000.00
0005432967191	2805	Economy	11000.00
0005432967155	2805	Economy	11000.00
0005432967169	2805	Economy	11000.00
0005432222868	2805	Economy	11000.00
0005433681363	2805	Economy	11000.00
0005433681325	2805	Economy	11000.00
0005432967172	2805	Economy	11000.00
0005433681357	2805	Economy	11000.00
0005433684452	2805	Economy	11000.00
0005433681323	2805	Economy	11000.00
0005433681356	2805	Economy	11000.00
0005432967095	2805	Economy	11000.00
0005433681347	2805	Economy	11000.00
0005433681324	2805	Economy	11000.00
0005433681339	2805	Economy	11000.00
0005433681341	2805	Economy	11000.00
0005432967164	2805	Economy	11000.00
0005433681353	2805	Economy	11000.00
0005433681340	2805	Economy	11000.00
0005433681333	2805	Economy	11000.00
0005433681329	2805	Economy	11000.00
0005432967180	2805	Economy	11000.00
0005433681335	2805	Economy	11000.00
0005433681366	2805	Economy	11000.00
0005432967175	2805	Economy	11000.00
0005433681334	2805	Economy	11000.00
0005433681370	2805	Economy	11000.00
0005433681332	2805	Economy	11000.00
0005432967118	2805	Economy	11000.00
0005433681330	2805	Economy	11000.00
0005433681326	2805	Economy	11000.00
0005432967348	29153	Business	33000.00
0005433681179	29153	Business	33000.00
0005433681014	29153	Business	33000.00
0005433681171	29153	Business	33000.00
0005432967366	29153	Business	33000.00
0005433681047	29153	Business	33000.00
0005432967347	29153	Business	33000.00
0005433680829	29153	Business	33000.00
0005433681045	29153	Business	33000.00
0005432967350	29153	Business	33000.00
0005432967353	29153	Business	33000.00
0005433681031	29153	Economy	11000.00
0005433680921	29153	Economy	11000.00
0005433680776	29153	Economy	11000.00
0005432967351	29153	Economy	11000.00
0005432967344	29153	Economy	11000.00
0005433680828	29153	Economy	11000.00
0005432967364	29153	Economy	11000.00
0005432967363	29153	Economy	12100.00
0005432005259	29153	Economy	12100.00
0005433680942	29153	Economy	12100.00
0005433680919	29153	Economy	12100.00
0005433680961	29153	Economy	12100.00
0005433681007	29153	Economy	11000.00
0005433684425	29153	Economy	11000.00
0005433680920	29153	Economy	11000.00
0005433681013	29153	Economy	11000.00
0005433680947	29153	Economy	11000.00
0005433680955	29153	Economy	11000.00
0005433681026	29153	Economy	11000.00
0005433681078	29153	Economy	11000.00
0005432967362	29153	Economy	11000.00
0005432967357	29153	Economy	11000.00
0005433684426	29153	Economy	11000.00
0005433681050	29153	Economy	11000.00
0005432967345	29153	Economy	11000.00
0005433680746	29153	Economy	11000.00
0005432967346	29153	Economy	11000.00
0005432967356	29153	Economy	11000.00
0005433681015	29153	Economy	11000.00
0005433681134	29153	Economy	11000.00
0005432967361	29153	Economy	11000.00
0005432005260	29153	Economy	11000.00
0005432967358	29153	Economy	11000.00
0005433681012	29153	Economy	11000.00
0005433680995	29153	Economy	11000.00
0005433680980	29153	Economy	11000.00
0005432967342	29153	Economy	11000.00
0005432967354	29153	Economy	11000.00
0005433680777	29153	Economy	11000.00
0005433681178	29153	Economy	11000.00
0005433680934	29153	Economy	11000.00
0005433681133	29153	Economy	11000.00
0005433680935	29153	Economy	11000.00
0005433680848	29153	Economy	11000.00
0005433680772	29153	Economy	11000.00
0005433684432	29153	Economy	11000.00
0005432967367	29153	Economy	11000.00
0005433681072	29153	Economy	11000.00
0005433681010	29153	Economy	11000.00
0005433681170	29153	Economy	11000.00
0005432967360	29153	Economy	11000.00
0005433680924	29153	Economy	11000.00
0005433681027	29153	Economy	11000.00
0005433681071	29153	Economy	11000.00
0005433681169	29153	Economy	11000.00
0005433680946	29153	Economy	11000.00
0005432967349	29153	Economy	11000.00
0005432967355	29153	Economy	11000.00
0005433681032	29153	Economy	11000.00
0005433680703	29153	Economy	11000.00
0005433680719	29153	Economy	11000.00
0005433681077	29153	Economy	11000.00
0005432967365	29153	Economy	11000.00
0005432967359	29153	Economy	11000.00
0005432967343	29153	Economy	11000.00
0005433680941	29153	Economy	11000.00
0005432967352	29153	Economy	11000.00
0005433680949	29153	Economy	11000.00
0005433680936	29153	Economy	11000.00
0005433680891	29153	Economy	11000.00
0005433681006	29153	Economy	11000.00
0005433615815	9312	Business	132900.00
0005433615819	9312	Business	132900.00
0005433615848	9312	Business	132900.00
0005433615821	9312	Business	132900.00
0005433615812	9312	Business	132900.00
0005433615810	9312	Business	132900.00
0005432756903	9312	Business	132900.00
0005433615823	9312	Business	132900.00
0005434163677	9312	Business	132900.00
0005433634356	9312	Business	132900.00
0005433615835	9312	Business	132900.00
0005433634343	9312	Business	132900.00
0005434269111	9312	Business	132900.00
0005433615817	9312	Business	132900.00
0005433578030	9312	Business	132900.00
0005433615798	9312	Business	132900.00
0005433615811	9312	Business	132900.00
0005434163722	9312	Business	132900.00
0005434163681	9312	Business	132900.00
0005433578028	9312	Business	132900.00
0005433615816	9312	Business	132900.00
0005433578027	9312	Business	132900.00
0005433615825	9312	Business	132900.00
0005434269112	9312	Economy	48700.00
0005434163662	9312	Economy	48700.00
0005433634332	9312	Economy	48700.00
0005433615794	9312	Economy	48700.00
0005433634351	9312	Economy	48700.00
0005433615854	9312	Economy	44300.00
0005433578031	9312	Economy	44300.00
0005433634341	9312	Economy	44300.00
0005433634360	9312	Economy	44300.00
0005433634355	9312	Economy	44300.00
0005433615855	9312	Economy	44300.00
0005433578023	9312	Economy	44300.00
0005433634359	9312	Economy	44300.00
0005433615827	9312	Economy	44300.00
0005434163740	9312	Economy	44300.00
0005433615786	9312	Economy	44300.00
0005432145143	9312	Economy	44300.00
0005434163676	9312	Economy	44300.00
0005433578033	9312	Economy	44300.00
0005433615793	9312	Economy	44300.00
0005434163703	9312	Economy	44300.00
0005433615789	9312	Economy	44300.00
0005434163739	9312	Economy	44300.00
0005433615795	9312	Economy	44300.00
0005433615843	9312	Economy	44300.00
0005434163678	9312	Economy	44300.00
0005433615836	9312	Economy	44300.00
0005433615805	9312	Economy	44300.00
0005433615822	9312	Economy	44300.00
0005433615824	9312	Economy	44300.00
0005434152800	9312	Economy	44300.00
0005434163714	9312	Economy	44300.00
0005433634349	9312	Economy	44300.00
0005434163679	9312	Economy	44300.00
0005433615800	9312	Economy	44300.00
0005433615845	9312	Economy	44300.00
0005432756900	9312	Economy	44300.00
0005433615790	9312	Economy	44300.00
0005433634339	9312	Economy	44300.00
0005433634358	9312	Economy	44300.00
0005433615832	9312	Economy	44300.00
0005433634335	9312	Economy	44300.00
0005433615807	9312	Economy	44300.00
0005433578032	9312	Economy	44300.00
0005432755130	9312	Economy	44300.00
0005432755128	9312	Economy	44300.00
0005434163721	9312	Economy	44300.00
0005433634336	9312	Economy	44300.00
0005432756901	9312	Economy	44300.00
0005433634333	9312	Economy	44300.00
0005434163660	9312	Economy	44300.00
0005433615785	9312	Economy	44300.00
0005433615841	9312	Economy	44300.00
0005433634340	9312	Economy	44300.00
0005433615838	9312	Economy	44300.00
0005433615837	9312	Economy	44300.00
0005433634337	9312	Economy	44300.00
0005433615828	9312	Economy	44300.00
0005432145144	9312	Economy	44300.00
0005434272199	9312	Economy	48700.00
0005433615808	9312	Economy	48700.00
0005433615850	9312	Economy	48700.00
0005433615797	9312	Economy	48700.00
0005433615851	9312	Economy	48700.00
0005433615831	9312	Economy	44300.00
0005433634353	9312	Economy	44300.00
0005433615802	9312	Economy	44300.00
0005433615809	9312	Economy	48700.00
0005433615820	9312	Economy	44300.00
0005433634361	9312	Economy	44300.00
0005434163680	9312	Economy	44300.00
0005432755129	9312	Economy	44300.00
0005433615782	9312	Economy	44300.00
0005433615846	9312	Economy	44300.00
0005433615806	9312	Economy	44300.00
0005433578034	9312	Economy	44300.00
0005433615801	9312	Economy	44300.00
0005433615844	9312	Economy	44300.00
0005433615826	9312	Economy	44300.00
0005433578029	9312	Economy	44300.00
0005433615842	9312	Economy	44300.00
0005433634334	9312	Economy	44300.00
0005434272201	9312	Economy	44300.00
0005433615813	9312	Economy	44300.00
0005433578024	9312	Economy	44300.00
0005433615803	9312	Economy	44300.00
0005432756902	9312	Economy	44300.00
0005434163659	9312	Economy	44300.00
0005433634347	9312	Economy	44300.00
0005433578025	9312	Economy	44300.00
0005433634344	9312	Economy	44300.00
0005433634338	9312	Economy	44300.00
0005433615791	9312	Economy	44300.00
0005433615853	9312	Economy	44300.00
0005433634346	9312	Economy	44300.00
0005433615833	9312	Economy	44300.00
0005433615783	9312	Economy	44300.00
0005433615830	9312	Economy	44300.00
0005433615849	9312	Economy	44300.00
0005433615799	9312	Economy	44300.00
0005433615839	9312	Economy	44300.00
0005433634354	9312	Economy	44300.00
0005433634362	9312	Economy	44300.00
0005434163664	9312	Economy	44300.00
0005433615814	9312	Economy	44300.00
0005433615818	9312	Economy	44300.00
0005433615792	9312	Economy	44300.00
0005433615788	9312	Economy	44300.00
0005433615847	9312	Economy	44300.00
0005433615829	9312	Economy	44300.00
0005433615852	9312	Economy	44300.00
0005433615840	9312	Economy	44300.00
0005433634331	9312	Economy	44300.00
0005433634350	9312	Economy	44300.00
0005434163710	9312	Economy	44300.00
0005433615804	9312	Economy	44300.00
0005433615784	9312	Economy	44300.00
0005433634357	9312	Economy	44300.00
0005433615787	9312	Economy	44300.00
0005433634342	9312	Economy	44300.00
0005433634363	9312	Economy	44300.00
0005433634345	9312	Economy	44300.00
0005433634364	9312	Economy	44300.00
0005433634348	9312	Economy	44300.00
0005433634352	9312	Economy	44300.00
0005433615834	9312	Economy	44300.00
0005433615796	9312	Economy	44300.00
0005433578026	9312	Economy	44300.00
0005434269113	9312	Economy	44300.00
0005433614874	25253	Business	132900.00
0005434163767	25253	Business	132900.00
0005433577910	25253	Business	132900.00
0005433633943	25253	Business	132900.00
0005433634070	25253	Business	132900.00
0005433615291	25253	Business	132900.00
0005433615393	25253	Business	132900.00
0005433577911	25253	Business	132900.00
0005433615034	25253	Business	132900.00
0005433614918	25253	Business	132900.00
0005433615384	25253	Business	132900.00
0005433615161	25253	Business	132900.00
0005433615187	25253	Business	132900.00
0005433615054	25253	Business	132900.00
0005433634005	25253	Business	132900.00
0005433615293	25253	Business	132900.00
0005433615473	25253	Business	132900.00
0005433577903	25253	Business	132900.00
0005433633937	25253	Business	132900.00
0005433615147	25253	Business	132900.00
0005433615252	25253	Business	132900.00
0005433615138	25253	Business	132900.00
0005433615416	25253	Business	132900.00
0005434272214	25253	Business	132900.00
0005433615253	25253	Business	132900.00
0005433634082	25253	Business	132900.00
0005433614645	25253	Economy	48700.00
0005433615339	25253	Economy	48700.00
0005433634018	25253	Economy	48700.00
0005433614999	25253	Economy	48700.00
0005434163768	25253	Economy	48700.00
0005434163772	25253	Economy	44300.00
0005433615051	25253	Economy	44300.00
0005433615112	25253	Economy	44300.00
0005433615113	25253	Economy	44300.00
0005433615186	25253	Economy	44300.00
0005433615001	25253	Economy	44300.00
0005433634024	25253	Economy	44300.00
0005433634041	25253	Economy	44300.00
0005433634057	25253	Economy	44300.00
0005433615188	25253	Economy	44300.00
0005433614985	25253	Economy	44300.00
0005433633895	25253	Economy	44300.00
0005434163774	25253	Economy	44300.00
0005433634213	25253	Economy	44300.00
0005433615394	25253	Economy	44300.00
0005433615039	25253	Economy	44300.00
0005433615177	25253	Economy	44300.00
0005433615298	25253	Economy	44300.00
0005433577922	25253	Economy	44300.00
0005433615168	25253	Economy	44300.00
0005433634002	25253	Economy	44300.00
0005433634023	25253	Economy	44300.00
0005433615359	25253	Economy	44300.00
0005434273103	25253	Economy	44300.00
0005433615000	25253	Economy	44300.00
0005433615167	25253	Economy	44300.00
0005433634102	25253	Economy	44300.00
0005433615251	25253	Economy	44300.00
0005433634053	25253	Economy	44300.00
0005433633968	25253	Economy	44300.00
0005433634150	25253	Economy	44300.00
0005433615435	25253	Economy	44300.00
0005434163771	25253	Economy	44300.00
0005433615038	25253	Economy	44300.00
0005433615405	25253	Economy	44300.00
0005433633938	25253	Economy	44300.00
0005434163765	25253	Economy	44300.00
0005433634031	25253	Economy	44300.00
0005433615292	25253	Economy	44300.00
0005433615104	25253	Economy	44300.00
0005433615037	25253	Economy	44300.00
0005433615049	25253	Economy	44300.00
0005433615053	25253	Economy	44300.00
0005433615153	25253	Economy	44300.00
0005433615066	25253	Economy	44300.00
0005433577904	25253	Economy	44300.00
0005433614903	25253	Economy	44300.00
0005433634022	25253	Economy	48700.00
0005433615207	25253	Economy	48700.00
0005434272215	25253	Economy	48700.00
0005433634075	25253	Economy	48700.00
0005433615383	25253	Economy	44300.00
0005433614787	25253	Economy	44300.00
0005434163769	25253	Economy	48700.00
0005433634127	25253	Economy	44300.00
0005434273102	25253	Economy	44300.00
0005433634019	25253	Economy	44300.00
0005433615567	25253	Economy	44300.00
0005433634233	25253	Economy	44300.00
0005433577917	25253	Economy	44300.00
0005433615170	25253	Economy	44300.00
0005433577919	25253	Economy	44300.00
0005433634133	25253	Economy	44300.00
0005433615129	25253	Economy	44300.00
0005433615424	25253	Economy	44300.00
0005433634169	25253	Economy	44300.00
0005433577873	25253	Economy	44300.00
0005433615189	25253	Economy	44300.00
0005433634247	25253	Economy	44300.00
0005433615248	25253	Economy	44300.00
0005433615535	25253	Economy	44300.00
0005433634120	25253	Economy	44300.00
0005433633896	25253	Economy	44300.00
0005433615347	25253	Economy	44300.00
0005433615323	25253	Economy	44300.00
0005433577902	25253	Economy	44300.00
0005433615534	25253	Economy	44300.00
0005433615048	25253	Economy	44300.00
0005434163770	25253	Economy	44300.00
0005433633909	25253	Economy	44300.00
0005433634140	25253	Economy	44300.00
0005433577916	25253	Economy	44300.00
0005433577882	25253	Economy	44300.00
0005433615194	25253	Economy	44300.00
0005433634151	25253	Economy	44300.00
0005433634149	25253	Economy	44300.00
0005433633983	25253	Economy	44300.00
0005433615152	25253	Economy	44300.00
0005433577920	25253	Economy	44300.00
0005433615322	25253	Economy	44300.00
0005433615064	25253	Economy	44300.00
0005433615344	25253	Economy	44300.00
0005433614875	25253	Economy	44300.00
0005433615065	25253	Economy	44300.00
0005433615137	25253	Economy	44300.00
0005434163773	25253	Economy	44300.00
0005433634040	25253	Economy	44300.00
0005433634052	25253	Economy	44300.00
0005433615027	25253	Economy	44300.00
0005433577921	25253	Economy	44300.00
0005433615206	25253	Economy	44300.00
0005433634134	25253	Economy	44300.00
0005433633908	25253	Economy	44300.00
0005433634088	25253	Economy	44300.00
0005434163766	25253	Economy	44300.00
0005433614786	25253	Economy	44300.00
0005433634063	25253	Economy	44300.00
0005434272213	25253	Economy	44300.00
0005435947349	4231	Business	193100.00
0005435856245	4231	Business	193100.00
0005435856241	4231	Business	193100.00
0005435947390	4231	Business	193100.00
0005435986879	4231	Business	193100.00
0005435947391	4231	Economy	64400.00
0005435947380	4231	Economy	64400.00
0005435856244	4231	Economy	64400.00
0005435856240	4231	Economy	64400.00
0005435947389	4231	Economy	64400.00
0005435986881	4231	Economy	64400.00
0005435947350	4231	Economy	64400.00
0005435947368	4231	Economy	64400.00
0005435947384	4231	Economy	64400.00
0005432571353	4231	Economy	64400.00
0005435947394	4231	Economy	64400.00
0005435947413	4231	Economy	64400.00
0005435947348	4231	Economy	64400.00
0005435947361	4231	Economy	70800.00
0005435947388	4231	Economy	64400.00
0005435986880	4231	Economy	64400.00
0005432184999	4231	Economy	64400.00
0005435947396	4231	Economy	64400.00
0005435787368	4231	Economy	64400.00
0005434271325	4231	Economy	64400.00
0005432571366	4231	Economy	64400.00
0005432184998	4231	Economy	64400.00
0005435947383	4231	Economy	64400.00
0005434271326	4231	Economy	64400.00
0005435856243	4231	Economy	64400.00
0005432571352	4231	Economy	64400.00
0005435856242	4231	Economy	64400.00
0005435947367	4231	Economy	64400.00
0005434271332	4231	Economy	64400.00
0005435947397	4231	Economy	64400.00
0005435947502	26589	Business	193100.00
0005435947490	26589	Business	193100.00
0005435986799	26589	Business	193100.00
0005435986810	26589	Business	193100.00
0005435986806	26589	Business	193100.00
0005435986820	26589	Business	193100.00
0005435856275	26589	Business	193100.00
0005435947501	26589	Economy	64400.00
0005432571388	26589	Economy	64400.00
0005435947497	26589	Economy	64400.00
0005435986794	26589	Economy	64400.00
0005435856273	26589	Economy	64400.00
0005432571386	26589	Economy	64400.00
0005432571387	26589	Economy	64400.00
0005435986813	26589	Economy	64400.00
0005435986822	26589	Economy	64400.00
0005435986811	26589	Economy	64400.00
0005435986808	26589	Economy	64400.00
0005435787391	26589	Economy	64400.00
0005435986795	26589	Economy	64400.00
0005435986802	26589	Economy	64400.00
0005435947491	26589	Economy	64400.00
0005435947492	26589	Economy	64400.00
0005435947496	26589	Economy	70800.00
0005435947494	26589	Economy	64400.00
0005435856274	26589	Economy	64400.00
0005435947493	26589	Economy	64400.00
0005435986807	26589	Economy	64400.00
0005435947498	26589	Economy	64400.00
0005435947499	26589	Economy	64400.00
0005435947500	26589	Economy	64400.00
0005435947495	26589	Economy	64400.00
0005435947489	26589	Economy	64400.00
0005435986821	26589	Economy	64400.00
0005435986812	26589	Economy	64400.00
0005435986804	26589	Economy	64400.00
0005433074962	329	Business	21500.00
0005432948829	329	Business	21500.00
0005432948770	329	Business	21500.00
0005432948888	329	Business	21500.00
0005433074978	329	Business	21500.00
0005432948635	329	Business	21500.00
0005433075010	329	Business	21500.00
0005433074867	329	Business	21500.00
0005433074723	329	Business	21500.00
0005433570031	329	Business	21500.00
0005433570057	329	Business	21500.00
0005433570063	329	Business	21500.00
0005433570038	329	Business	21500.00
0005432948781	329	Business	21500.00
0005433074895	329	Business	21500.00
0005432948787	329	Business	21500.00
0005433074848	329	Business	21500.00
0005433570054	329	Business	21500.00
0005432948847	329	Business	21500.00
0005432239039	329	Business	21500.00
0005433074979	329	Business	21500.00
0005433075064	329	Business	21500.00
0005432239037	329	Business	21500.00
0005432239038	329	Business	21500.00
0005433074974	329	Business	21500.00
0005433074942	329	Business	21500.00
0005432948821	329	Economy	7900.00
0005433570039	329	Economy	7900.00
0005432948755	329	Economy	7900.00
0005432948688	329	Economy	7900.00
0005433570060	329	Economy	7900.00
0005433075055	329	Economy	7900.00
0005432948896	329	Economy	7200.00
0005432948744	329	Economy	7200.00
0005433074943	329	Economy	7200.00
0005433570050	329	Economy	7200.00
0005433074861	329	Economy	7200.00
0005433570055	329	Economy	7200.00
0005433075054	329	Economy	7200.00
0005433570059	329	Economy	7200.00
0005433075015	329	Economy	7200.00
0005433570065	329	Economy	7200.00
0005432948840	329	Economy	7200.00
0005432948911	329	Economy	7200.00
0005433134169	329	Economy	7200.00
0005432948734	329	Economy	7200.00
0005433075063	329	Economy	7200.00
0005432948772	329	Economy	7200.00
0005432948889	329	Economy	7200.00
0005432948833	329	Economy	7200.00
0005432948646	329	Economy	7200.00
0005433570037	329	Economy	7200.00
0005433134186	329	Economy	7200.00
0005432948890	329	Economy	7200.00
0005433074898	329	Economy	7200.00
0005433074869	329	Economy	7200.00
0005432239036	329	Economy	7200.00
0005433074941	329	Economy	7200.00
0005433570044	329	Economy	7200.00
0005432948793	329	Economy	7200.00
0005432948735	329	Economy	7200.00
0005432948756	329	Economy	7200.00
0005433570048	329	Economy	7200.00
0005433570074	329	Economy	7200.00
0005432948647	329	Economy	7200.00
0005432239041	329	Economy	7200.00
0005432948577	329	Economy	7200.00
0005433074856	329	Economy	7200.00
0005433074896	329	Economy	7200.00
0005433570042	329	Economy	7200.00
0005432948518	329	Economy	7200.00
0005433570064	329	Economy	7200.00
0005432948604	329	Economy	7200.00
0005432948792	329	Economy	7200.00
0005433570058	329	Economy	7200.00
0005432948771	329	Economy	7200.00
0005433570067	329	Economy	7200.00
0005432948578	329	Economy	7200.00
0005433570041	329	Economy	7200.00
0005432948994	329	Economy	7200.00
0005433570073	329	Economy	7200.00
0005432948841	329	Economy	7200.00
0005433074977	329	Economy	7200.00
0005433570047	329	Economy	7200.00
0005432948830	329	Economy	7200.00
0005432948720	329	Economy	7200.00
0005433570040	329	Economy	7200.00
0005432948719	329	Economy	7200.00
0005433570069	329	Economy	7900.00
0005433570046	329	Economy	7900.00
0005433074838	329	Economy	7900.00
0005433570033	329	Economy	7900.00
0005433570043	329	Economy	7900.00
0005433570076	329	Economy	7200.00
0005433570066	329	Economy	7200.00
0005433570052	329	Economy	7200.00
0005433074855	329	Economy	7200.00
0005432948757	329	Economy	7200.00
0005433570061	329	Economy	7200.00
0005432948689	329	Economy	7200.00
0005432948897	329	Economy	7200.00
0005433570053	329	Economy	7200.00
0005432948603	329	Economy	7200.00
0005433074724	329	Economy	7200.00
0005433570068	329	Economy	7200.00
0005432948777	329	Economy	7200.00
0005433570070	329	Economy	7200.00
0005432948887	329	Economy	7200.00
0005433075006	329	Economy	7200.00
0005433074992	329	Economy	7200.00
0005433570045	329	Economy	7200.00
0005433074897	329	Economy	7200.00
0005432948822	329	Economy	7200.00
0005432948741	329	Economy	7200.00
0005432948776	329	Economy	7200.00
0005432948699	329	Economy	7200.00
0005433570075	329	Economy	7200.00
0005433570035	329	Economy	7200.00
0005433570071	329	Economy	7200.00
0005433570072	329	Economy	7200.00
0005433570032	329	Economy	7200.00
0005433570036	329	Economy	7200.00
0005433570051	329	Economy	7200.00
0005433074911	329	Economy	7200.00
0005433570029	329	Economy	7200.00
0005432948993	329	Economy	7200.00
0005432948861	329	Economy	7200.00
0005433074814	329	Economy	7200.00
0005432948773	329	Economy	7200.00
0005432948656	329	Economy	7200.00
0005432948653	329	Economy	7200.00
0005433570034	329	Economy	7200.00
0005432239040	329	Economy	7200.00
0005432948695	329	Economy	7200.00
0005433570049	329	Economy	7200.00
0005432948667	329	Economy	7200.00
0005433074849	329	Economy	7200.00
0005433570030	329	Economy	7200.00
0005432948791	329	Economy	7200.00
0005432948696	329	Economy	7200.00
0005433134187	329	Economy	7200.00
0005433074868	329	Economy	7200.00
0005432948782	329	Economy	7200.00
0005433074923	329	Economy	7200.00
0005432948877	329	Economy	7200.00
0005432948614	329	Economy	7200.00
0005433074857	329	Economy	7200.00
0005433129304	329	Economy	7200.00
0005432239035	329	Economy	7200.00
0005433074922	329	Economy	7200.00
0005433570062	329	Economy	7200.00
0005433570056	329	Economy	7200.00
0005433074912	329	Economy	7200.00
0005432949124	11588	Business	21500.00
0005433569508	11588	Business	21500.00
0005433569537	11588	Business	21500.00
0005433131781	11588	Business	21500.00
0005432949103	11588	Business	21500.00
0005432949134	11588	Business	21500.00
0005432949111	11588	Business	21500.00
0005433569390	11588	Business	21500.00
0005432949115	11588	Business	21500.00
0005433569329	11588	Business	21500.00
0005433569316	11588	Business	21500.00
0005433075168	11588	Business	21500.00
0005432949102	11588	Business	21500.00
0005433075173	11588	Business	21500.00
0005433569456	11588	Business	21500.00
0005433569318	11588	Business	21500.00
0005433569331	11588	Business	21500.00
0005433569512	11588	Business	21500.00
0005433569271	11588	Business	21500.00
0005432949131	11588	Business	21500.00
0005433569420	11588	Business	21500.00
0005432949114	11588	Business	21500.00
0005433569185	11588	Business	21500.00
0005433075184	11588	Business	21500.00
0005433075182	11588	Business	21500.00
0005433569422	11588	Economy	7900.00
0005433569389	11588	Economy	7900.00
0005433131784	11588	Economy	7900.00
0005433134212	11588	Economy	7900.00
0005433075160	11588	Economy	7900.00
0005433075170	11588	Economy	7200.00
0005433569429	11588	Economy	7200.00
0005433134215	11588	Economy	7200.00
0005433134214	11588	Economy	7200.00
0005433075164	11588	Economy	7200.00
0005433569527	11588	Economy	7200.00
0005432949137	11588	Economy	7200.00
0005433131785	11588	Economy	7200.00
0005433569270	11588	Economy	7200.00
0005433075174	11588	Economy	7200.00
0005432949109	11588	Economy	7200.00
0005432949129	11588	Economy	7200.00
0005433075165	11588	Economy	7200.00
0005433075179	11588	Economy	7200.00
0005432949098	11588	Economy	7200.00
0005432949112	11588	Economy	7200.00
0005432949116	11588	Economy	7200.00
0005432949121	11588	Economy	7200.00
0005433569294	11588	Economy	7200.00
0005433569230	11588	Economy	7200.00
0005433569418	11588	Economy	7200.00
0005433569303	11588	Economy	7200.00
0005433569309	11588	Economy	7200.00
0005433569330	11588	Economy	7200.00
0005432949110	11588	Economy	7200.00
0005432949104	11588	Economy	7200.00
0005433569128	11588	Economy	7200.00
0005433075161	11588	Economy	7200.00
0005433569428	11588	Economy	7200.00
0005433075178	11588	Economy	7200.00
0005433569367	11588	Economy	7200.00
0005432949133	11588	Economy	7200.00
0005432949113	11588	Economy	7200.00
0005432949117	11588	Economy	7200.00
0005433569556	11588	Economy	7200.00
0005433569486	11588	Economy	7200.00
0005433569409	11588	Economy	7200.00
0005433929862	11588	Economy	7200.00
0005432949125	11588	Economy	7200.00
0005433569487	11588	Economy	7200.00
0005433075163	11588	Economy	7200.00
0005433131783	11588	Economy	7200.00
0005433569299	11588	Economy	7200.00
0005433929861	11588	Economy	7200.00
0005432949107	11588	Economy	7200.00
0005433569593	11588	Economy	7200.00
0005433569596	11588	Economy	7200.00
0005433569412	11588	Economy	7900.00
0005433075186	11588	Economy	7200.00
0005433569304	11588	Economy	7900.00
0005432949128	11588	Economy	7900.00
0005432949138	11588	Economy	7900.00
0005433569528	11588	Economy	7200.00
0005433075177	11588	Economy	7200.00
0005433075162	11588	Economy	7200.00
0005433131782	11588	Economy	7200.00
0005433569413	11588	Economy	7900.00
0005432949139	11588	Economy	7200.00
0005433569509	11588	Economy	7200.00
0005433569507	11588	Economy	7200.00
0005433569368	11588	Economy	7200.00
0005433075181	11588	Economy	7200.00
0005433569398	11588	Economy	7200.00
0005433569473	11588	Economy	7200.00
0005432949130	11588	Economy	7200.00
0005433569594	11588	Economy	7200.00
0005433075167	11588	Economy	7200.00
0005432949120	11588	Economy	7200.00
0005432949123	11588	Economy	7200.00
0005432192371	11588	Economy	7200.00
0005433569317	11588	Economy	7200.00
0005433569308	11588	Economy	7200.00
0005432192372	11588	Economy	7200.00
0005433569184	11588	Economy	7200.00
0005432949118	11588	Economy	7200.00
0005433569386	11588	Economy	7200.00
0005433075172	11588	Economy	7200.00
0005433569419	11588	Economy	7200.00
0005432949122	11588	Economy	7200.00
0005433569292	11588	Economy	7200.00
0005433569217	11588	Economy	7200.00
0005433569293	11588	Economy	7200.00
0005433075183	11588	Economy	7200.00
0005432949126	11588	Economy	7200.00
0005432949100	11588	Economy	7200.00
0005433075180	11588	Economy	7200.00
0005432949132	11588	Economy	7200.00
0005433075171	11588	Economy	7200.00
0005432949105	11588	Economy	7200.00
0005433075185	11588	Economy	7200.00
0005433569326	11588	Economy	7200.00
0005432949127	11588	Economy	7200.00
0005433075166	11588	Economy	7200.00
0005433075187	11588	Economy	7200.00
0005433134213	11588	Economy	7200.00
0005433569514	11588	Economy	7200.00
0005433075175	11588	Economy	7200.00
0005432949106	11588	Economy	7200.00
0005433075176	11588	Economy	7200.00
0005432949136	11588	Economy	7200.00
0005432949119	11588	Economy	7200.00
0005433569595	11588	Economy	7200.00
0005433075169	11588	Economy	7200.00
0005432949135	11588	Economy	7200.00
0005433569455	11588	Economy	7200.00
0005432949099	11588	Economy	7200.00
0005432949108	11588	Economy	7200.00
0005432949101	11588	Economy	7200.00
0005433817533	10016	Economy	6300.00
0005434733017	10016	Economy	6300.00
0005433817535	10016	Economy	6300.00
0005433817534	10016	Economy	6300.00
0005433817532	10016	Economy	6300.00
0005434733018	10016	Economy	6300.00
0005434733016	10016	Economy	6300.00
0005433817531	10016	Economy	6300.00
0005433817488	13980	Economy	6300.00
0005433817505	13980	Economy	6300.00
0005434733041	13980	Economy	6300.00
0005433817495	13980	Economy	6300.00
0005434733039	13980	Economy	6300.00
0005433817489	13980	Economy	6300.00
0005434733037	13980	Economy	6300.00
0005434733040	13980	Economy	6300.00
0005433817507	13980	Economy	6300.00
0005434733038	13980	Economy	6300.00
0005435983030	2339	Business	184500.00
0005435983018	2339	Business	184500.00
0005432985418	2339	Business	184500.00
0005433755149	2339	Business	184500.00
0005433434964	2339	Business	184500.00
0005435983028	2339	Business	184500.00
0005432985396	2339	Business	184500.00
0005433434963	2339	Business	184500.00
0005432985196	2339	Business	184500.00
0005433434768	2339	Business	184500.00
0005432655737	2339	Business	184500.00
0005432985460	2339	Business	184500.00
0005435983024	2339	Business	184500.00
0005433755172	2339	Business	184500.00
0005435983027	2339	Business	184500.00
0005432985359	2339	Business	184500.00
0005432985257	2339	Business	184500.00
0005433755164	2339	Business	184500.00
0005432985461	2339	Business	184500.00
0005433755155	2339	Business	184500.00
0005432985376	2339	Business	184500.00
0005432300362	2339	Business	184500.00
0005435983038	2339	Business	184500.00
0005433755127	2339	Business	184500.00
0005433764714	2339	Economy	67700.00
0005433434919	2339	Economy	67700.00
0005433755151	2339	Economy	67700.00
0005432655734	2339	Economy	67700.00
0005435983035	2339	Economy	61500.00
0005432655739	2339	Economy	61500.00
0005432869569	2339	Economy	61500.00
0005432985284	2339	Economy	61500.00
0005433755147	2339	Economy	61500.00
0005433755131	2339	Economy	61500.00
0005433755171	2339	Economy	61500.00
0005432300359	2339	Economy	61500.00
0005435983033	2339	Economy	61500.00
0005432985255	2339	Economy	61500.00
0005432655736	2339	Economy	61500.00
0005433755157	2339	Economy	61500.00
0005432655742	2339	Economy	61500.00
0005435983050	2339	Economy	61500.00
0005432226162	2339	Economy	61500.00
0005432655731	2339	Economy	61500.00
0005433434798	2339	Economy	61500.00
0005435983031	2339	Economy	61500.00
0005432985360	2339	Economy	61500.00
0005435983025	2339	Economy	61500.00
0005432985250	2339	Economy	61500.00
0005433755120	2339	Economy	61500.00
0005435983036	2339	Economy	61500.00
0005433434866	2339	Economy	61500.00
0005435983021	2339	Economy	61500.00
0005433755138	2339	Economy	61500.00
0005433434953	2339	Economy	61500.00
0005433755175	2339	Economy	61500.00
0005433755128	2339	Economy	61500.00
0005433434860	2339	Economy	61500.00
0005433755132	2339	Economy	61500.00
0005432985295	2339	Economy	61500.00
0005432985459	2339	Economy	61500.00
0005435983037	2339	Economy	61500.00
0005433434951	2339	Economy	61500.00
0005434731191	2339	Economy	61500.00
0005433755158	2339	Economy	61500.00
0005433755124	2339	Economy	61500.00
0005432985377	2339	Economy	61500.00
0005433755174	2339	Economy	61500.00
0005432985276	2339	Economy	61500.00
0005433764713	2339	Economy	61500.00
0005433434984	2339	Economy	61500.00
0005432655735	2339	Economy	61500.00
0005435983041	2339	Economy	61500.00
0005433755170	2339	Economy	61500.00
0005432985361	2339	Economy	61500.00
0005433755153	2339	Economy	61500.00
0005433755139	2339	Economy	61500.00
0005432985274	2339	Economy	61500.00
0005435983046	2339	Economy	61500.00
0005433434962	2339	Economy	61500.00
0005433755168	2339	Economy	61500.00
0005432985286	2339	Economy	61500.00
0005432985293	2339	Economy	61500.00
0005432985402	2339	Economy	61500.00
0005433434931	2339	Economy	61500.00
0005433755176	2339	Economy	61500.00
0005432985275	2339	Economy	61500.00
0005435983045	2339	Economy	61500.00
0005433755122	2339	Economy	61500.00
0005432655741	2339	Economy	61500.00
0005433755141	2339	Economy	61500.00
0005433755133	2339	Economy	61500.00
0005433755160	2339	Economy	61500.00
0005433766703	2339	Economy	61500.00
0005433434925	2339	Economy	61500.00
0005433755143	2339	Economy	61500.00
0005432655738	2339	Economy	61500.00
0005432985398	2339	Economy	61500.00
0005435983048	2339	Economy	61500.00
0005433755135	2339	Economy	61500.00
0005433755165	2339	Economy	61500.00
0005433755154	2339	Economy	61500.00
0005435983034	2339	Economy	61500.00
0005433755173	2339	Economy	61500.00
0005433434936	2339	Economy	61500.00
0005435983040	2339	Economy	61500.00
0005433755144	2339	Economy	61500.00
0005435983049	2339	Economy	61500.00
0005433755125	2339	Economy	61500.00
0005435983043	2339	Economy	61500.00
0005433755159	2339	Economy	61500.00
0005433755169	2339	Economy	61500.00
0005433434952	2339	Economy	61500.00
0005432985332	2339	Economy	67700.00
0005435983032	2339	Economy	61500.00
0005432985229	2339	Economy	61500.00
0005432985197	2339	Economy	61500.00
0005435983042	2339	Economy	67700.00
0005435983051	2339	Economy	67700.00
0005432226161	2339	Economy	61500.00
0005433434854	2339	Economy	61500.00
0005433766704	2339	Economy	61500.00
0005435983017	2339	Economy	61500.00
0005433755140	2339	Economy	61500.00
0005432300361	2339	Economy	61500.00
0005432869584	2339	Economy	61500.00
0005433434924	2339	Economy	61500.00
0005433434799	2339	Economy	61500.00
0005432985273	2339	Economy	61500.00
0005432985272	2339	Economy	61500.00
0005432985420	2339	Economy	61500.00
0005433755134	2339	Economy	61500.00
0005433755123	2339	Economy	61500.00
0005433755148	2339	Economy	61500.00
0005433755146	2339	Economy	61500.00
0005433755130	2339	Economy	61500.00
0005435983020	2339	Economy	61500.00
0005432985277	2339	Economy	61500.00
0005433434906	2339	Economy	61500.00
0005432300360	2339	Economy	61500.00
0005433755121	2339	Economy	61500.00
0005435983052	2339	Economy	61500.00
0005432985318	2339	Economy	61500.00
0005433755129	2339	Economy	61500.00
0005435983022	2339	Economy	61500.00
0005433766702	2339	Economy	61500.00
0005432985411	2339	Economy	61500.00
0005433755142	2339	Economy	61500.00
0005432985338	2339	Economy	61500.00
0005433434938	2339	Economy	61500.00
0005435983026	2339	Economy	61500.00
0005433755136	2339	Economy	61500.00
0005433434966	2339	Economy	61500.00
0005433755167	2339	Economy	61500.00
0005433755137	2339	Economy	61500.00
0005433755152	2339	Economy	61500.00
0005432655730	2339	Economy	61500.00
0005433755161	2339	Economy	61500.00
0005432655732	2339	Economy	61500.00
0005433755177	2339	Economy	61500.00
0005432226160	2339	Economy	61500.00
0005433434864	2339	Economy	61500.00
0005432869570	2339	Economy	61500.00
0005432985397	2339	Economy	61500.00
0005435983053	2339	Economy	61500.00
0005433755150	2339	Economy	61500.00
0005433434983	2339	Economy	61500.00
0005435983054	2339	Economy	61500.00
0005435983044	2339	Economy	61500.00
0005435983039	2339	Economy	61500.00
0005433755166	2339	Economy	61500.00
0005435983047	2339	Economy	61500.00
0005433755156	2339	Economy	61500.00
0005433755145	2339	Economy	61500.00
0005432985419	2339	Economy	61500.00
0005433755162	2339	Economy	61500.00
0005433755126	2339	Economy	61500.00
0005432300358	2339	Economy	61500.00
0005432869585	2339	Economy	61500.00
0005435983023	2339	Economy	61500.00
0005433434923	2339	Economy	61500.00
0005435983029	2339	Economy	61500.00
0005435983019	2339	Economy	61500.00
0005432985462	2339	Economy	61500.00
0005433755163	2339	Economy	61500.00
0005432655740	2339	Economy	61500.00
0005433434865	2339	Economy	61500.00
0005432655733	2339	Economy	61500.00
0005432985616	26170	Business	184500.00
0005433754722	26170	Business	184500.00
0005433754613	26170	Business	184500.00
0005435982590	26170	Business	184500.00
0005433435154	26170	Business	184500.00
0005433754626	26170	Business	184500.00
0005432985604	26170	Business	184500.00
0005432985600	26170	Business	184500.00
0005433754321	26170	Business	184500.00
0005433435151	26170	Business	184500.00
0005432051181	26170	Business	184500.00
0005433754562	26170	Business	184500.00
0005435982705	26170	Business	184500.00
0005435982773	26170	Business	184500.00
0005433764692	26170	Business	184500.00
0005434731241	26170	Business	184500.00
0005435982921	26170	Business	184500.00
0005433435141	26170	Business	184500.00
0005433754560	26170	Business	184500.00
0005433435150	26170	Business	184500.00
0005432985597	26170	Business	184500.00
0005432655602	26170	Business	184500.00
0005432985607	26170	Business	184500.00
0005432985612	26170	Business	184500.00
0005435982552	26170	Business	184500.00
0005433754758	26170	Economy	67700.00
0005432985621	26170	Economy	67700.00
0005433754609	26170	Economy	67700.00
0005432051180	26170	Economy	61500.00
0005432985624	26170	Economy	61500.00
0005432985610	26170	Economy	61500.00
0005433766663	26170	Economy	61500.00
0005433754697	26170	Economy	61500.00
0005433435137	26170	Economy	61500.00
0005432985627	26170	Economy	61500.00
0005432985623	26170	Economy	61500.00
0005432985617	26170	Economy	61500.00
0005433435133	26170	Economy	61500.00
0005433435156	26170	Economy	61500.00
0005433754608	26170	Economy	61500.00
0005433754791	26170	Economy	61500.00
0005435982500	26170	Economy	61500.00
0005433754511	26170	Economy	61500.00
0005433754719	26170	Economy	61500.00
0005435982710	26170	Economy	61500.00
0005432985596	26170	Economy	61500.00
0005433435130	26170	Economy	61500.00
0005432985620	26170	Economy	61500.00
0005433754610	26170	Economy	61500.00
0005432985626	26170	Economy	61500.00
0005432985601	26170	Economy	61500.00
0005433754388	26170	Economy	61500.00
0005432655561	26170	Economy	61500.00
0005435982658	26170	Economy	61500.00
0005433435132	26170	Economy	61500.00
0005432985606	26170	Economy	61500.00
0005435982551	26170	Economy	61500.00
0005432985609	26170	Economy	61500.00
0005435982546	26170	Economy	61500.00
0005432869632	26170	Economy	61500.00
0005433435135	26170	Economy	61500.00
0005435982580	26170	Economy	61500.00
0005435982655	26170	Economy	61500.00
0005432655603	26170	Economy	61500.00
0005435982547	26170	Economy	61500.00
0005433435146	26170	Economy	61500.00
0005435982608	26170	Economy	61500.00
0005435982492	26170	Economy	61500.00
0005432985614	26170	Economy	61500.00
0005433754718	26170	Economy	61500.00
0005432985622	26170	Economy	61500.00
0005432985605	26170	Economy	61500.00
0005433754345	26170	Economy	61500.00
0005432985625	26170	Economy	61500.00
0005433754800	26170	Economy	61500.00
0005435982620	26170	Economy	61500.00
0005433754695	26170	Economy	61500.00
0005433754771	26170	Economy	61500.00
0005435982266	26170	Economy	61500.00
0005434731242	26170	Economy	61500.00
0005433435145	26170	Economy	61500.00
0005432985608	26170	Economy	61500.00
0005432655592	26170	Economy	61500.00
0005435982708	26170	Economy	61500.00
0005433435142	26170	Economy	61500.00
0005435982490	26170	Economy	61500.00
0005435982622	26170	Economy	61500.00
0005432655604	26170	Economy	61500.00
0005433754558	26170	Economy	61500.00
0005435982659	26170	Economy	61500.00
0005432869634	26170	Economy	61500.00
0005435982596	26170	Economy	61500.00
0005432869629	26170	Economy	61500.00
0005435982576	26170	Economy	61500.00
0005433754878	26170	Economy	61500.00
0005432655601	26170	Economy	61500.00
0005433435134	26170	Economy	61500.00
0005433754592	26170	Economy	61500.00
0005433754762	26170	Economy	61500.00
0005432985602	26170	Economy	61500.00
0005433764697	26170	Economy	61500.00
0005435982721	26170	Economy	61500.00
0005435982509	26170	Economy	61500.00
0005432655605	26170	Economy	61500.00
0005433435148	26170	Economy	61500.00
0005433754512	26170	Economy	61500.00
0005432655608	26170	Economy	61500.00
0005433754872	26170	Economy	61500.00
0005433435138	26170	Economy	61500.00
0005432869631	26170	Economy	61500.00
0005435982455	26170	Economy	61500.00
0005435982635	26170	Economy	67700.00
0005435982919	26170	Economy	67700.00
0005433754801	26170	Economy	61500.00
0005434731239	26170	Economy	61500.00
0005433754374	26170	Economy	67700.00
0005432655560	26170	Economy	67700.00
0005435982577	26170	Economy	61500.00
0005434731240	26170	Economy	61500.00
0005433754708	26170	Economy	61500.00
0005435982607	26170	Economy	61500.00
0005435982508	26170	Economy	61500.00
0005433754777	26170	Economy	61500.00
0005435982711	26170	Economy	61500.00
0005432985611	26170	Economy	61500.00
0005433435155	26170	Economy	61500.00
0005433754679	26170	Economy	61500.00
0005433754655	26170	Economy	61500.00
0005432049521	26170	Economy	61500.00
0005433754763	26170	Economy	61500.00
0005433764696	26170	Economy	61500.00
0005433754879	26170	Economy	61500.00
0005432985619	26170	Economy	61500.00
0005433754375	26170	Economy	61500.00
0005433754505	26170	Economy	61500.00
0005435982579	26170	Economy	61500.00
0005432985603	26170	Economy	61500.00
0005432985599	26170	Economy	61500.00
0005433766689	26170	Economy	61500.00
0005433766664	26170	Economy	61500.00
0005433754837	26170	Economy	61500.00
0005433435149	26170	Economy	61500.00
0005435982454	26170	Economy	61500.00
0005432985618	26170	Economy	61500.00
0005432655612	26170	Economy	61500.00
0005432051179	26170	Economy	61500.00
0005434731243	26170	Economy	61500.00
0005433754648	26170	Economy	61500.00
0005433435147	26170	Economy	61500.00
0005432655638	26170	Economy	61500.00
0005432985598	26170	Economy	61500.00
0005433435153	26170	Economy	61500.00
0005433754387	26170	Economy	61500.00
0005433754884	26170	Economy	61500.00
0005432051178	26170	Economy	61500.00
0005433435136	26170	Economy	61500.00
0005433435143	26170	Economy	61500.00
0005432049522	26170	Economy	61500.00
0005433435157	26170	Economy	61500.00
0005433435152	26170	Economy	61500.00
0005435982704	26170	Economy	61500.00
0005433435139	26170	Economy	61500.00
0005435982604	26170	Economy	61500.00
0005432049523	26170	Economy	61500.00
0005432049524	26170	Economy	61500.00
0005435982920	26170	Economy	61500.00
0005433764698	26170	Economy	61500.00
0005433754705	26170	Economy	61500.00
0005433435140	26170	Economy	61500.00
0005432985615	26170	Economy	61500.00
0005433766688	26170	Economy	61500.00
0005433754561	26170	Economy	61500.00
0005433766662	26170	Economy	61500.00
0005433435144	26170	Economy	61500.00
0005433754885	26170	Economy	61500.00
0005432869633	26170	Economy	61500.00
0005433754905	26170	Economy	61500.00
0005432869630	26170	Economy	61500.00
0005435982553	26170	Economy	61500.00
0005432985613	26170	Economy	61500.00
0005433754619	26170	Economy	61500.00
0005435982709	26170	Economy	61500.00
0005433754806	26170	Economy	61500.00
0005435982653	26170	Economy	61500.00
0005435982501	26170	Economy	61500.00
0005433754706	26170	Economy	61500.00
0005433435131	26170	Economy	61500.00
0005434375390	1507	Business	38900.00
0005432268008	1507	Business	38900.00
0005434375379	1507	Business	38900.00
0005434375384	1507	Business	38900.00
0005433151682	1507	Business	38900.00
0005433151726	1507	Business	38900.00
0005433151769	1507	Business	38900.00
0005433931491	1507	Business	38900.00
0005433151816	1507	Economy	13000.00
0005434375383	1507	Economy	13000.00
0005434375365	1507	Economy	13000.00
0005434375372	1507	Economy	13000.00
0005433151639	1507	Economy	13000.00
0005433151625	1507	Economy	13000.00
0005432268005	1507	Economy	13000.00
0005434375370	1507	Economy	13000.00
0005434375382	1507	Economy	13000.00
0005433151467	1507	Economy	13000.00
0005433151772	1507	Economy	13000.00
0005432268007	1507	Economy	13000.00
0005434375388	1507	Economy	13000.00
0005434375359	1507	Economy	13000.00
0005433151762	1507	Economy	13000.00
0005434375381	1507	Economy	13000.00
0005433151642	1507	Economy	13000.00
0005434375361	1507	Economy	13000.00
0005433151671	1507	Economy	13000.00
0005433151788	1507	Economy	13000.00
0005433151753	1507	Economy	13000.00
0005434375393	1507	Economy	13000.00
0005433151681	1507	Economy	13000.00
0005434375392	1507	Economy	13000.00
0005434375378	1507	Economy	13000.00
0005433151680	1507	Economy	14300.00
0005433151679	1507	Economy	14300.00
0005434375374	1507	Economy	14300.00
0005433931477	1507	Economy	13000.00
0005433151708	1507	Economy	13000.00
0005434375394	1507	Economy	13000.00
0005433151842	1507	Economy	13000.00
0005434375385	1507	Economy	13000.00
0005433151763	1507	Economy	13000.00
0005434375366	1507	Economy	13000.00
0005433931468	1507	Economy	13000.00
0005434375391	1507	Economy	13000.00
0005434375395	1507	Economy	13000.00
0005434375397	1507	Economy	13000.00
0005433151678	1507	Economy	13000.00
0005433151646	1507	Economy	13000.00
0005433151805	1507	Economy	13000.00
0005434375358	1507	Economy	13000.00
0005434375362	1507	Economy	13000.00
0005434375376	1507	Economy	13000.00
0005433151789	1507	Economy	13000.00
0005434375369	1507	Economy	13000.00
0005433931490	1507	Economy	13000.00
0005434375380	1507	Economy	13000.00
0005434375387	1507	Economy	13000.00
0005433151787	1507	Economy	13000.00
0005434375367	1507	Economy	13000.00
0005434375364	1507	Economy	13000.00
0005433151669	1507	Economy	13000.00
0005433151468	1507	Economy	13000.00
0005433151722	1507	Economy	13000.00
0005433151626	1507	Economy	13000.00
0005434375386	1507	Economy	13000.00
0005433931476	1507	Economy	13000.00
0005433931469	1507	Economy	13000.00
0005433461624	1507	Economy	13000.00
0005433151672	1507	Economy	13000.00
0005434375360	1507	Economy	13000.00
0005434375368	1507	Economy	13000.00
0005433151689	1507	Economy	13000.00
0005433151819	1507	Economy	13000.00
0005433151709	1507	Economy	13000.00
0005434375373	1507	Economy	13000.00
0005434375375	1507	Economy	13000.00
0005433151827	1507	Economy	13000.00
0005432268006	1507	Economy	13000.00
0005433151653	1507	Economy	13000.00
0005433460472	1507	Economy	13000.00
0005434375377	1507	Economy	13000.00
0005434375396	1507	Economy	13000.00
0005434375371	1507	Economy	13000.00
0005433151773	1507	Economy	13000.00
0005433151649	1507	Economy	13000.00
0005434375389	1507	Economy	13000.00
0005433151650	1507	Economy	13000.00
0005433151790	1507	Economy	13000.00
0005434375363	1507	Economy	13000.00
0005433460471	1507	Economy	13000.00
0005433463899	20146	Business	38900.00
0005433463895	20146	Business	38900.00
0005433151983	20146	Business	38900.00
0005434374998	20146	Business	38900.00
0005434374961	20146	Business	38900.00
0005433151963	20146	Business	38900.00
0005433463910	20146	Business	38900.00
0005434374878	20146	Business	38900.00
0005433461594	20146	Business	38900.00
0005433463909	20146	Business	38900.00
0005433764714	20146	Business	38900.00
0005433151955	20146	Business	38900.00
0005433463898	20146	Economy	13000.00
0005432056362	20146	Economy	13000.00
0005433151957	20146	Economy	13000.00
0005434029700	20146	Economy	13000.00
0005434374916	20146	Economy	13000.00
0005433151988	20146	Economy	13000.00
0005434374994	20146	Economy	13000.00
0005433151958	20146	Economy	13000.00
0005432056363	20146	Economy	13000.00
0005434374959	20146	Economy	13000.00
0005433151961	20146	Economy	13000.00
0005434374979	20146	Economy	13000.00
0005434374962	20146	Economy	13000.00
0005433151978	20146	Economy	13000.00
0005433151962	20146	Economy	13000.00
0005433151972	20146	Economy	13000.00
0005432056361	20146	Economy	13000.00
0005434374910	20146	Economy	13000.00
0005434374869	20146	Economy	13000.00
0005433151985	20146	Economy	13000.00
0005433151973	20146	Economy	13000.00
0005434029698	20146	Economy	13000.00
0005433461587	20146	Economy	13000.00
0005433151968	20146	Economy	13000.00
0005433461593	20146	Economy	13000.00
0005433461581	20146	Economy	13000.00
0005433151964	20146	Economy	13000.00
0005433151959	20146	Economy	13000.00
0005434374731	20146	Economy	13000.00
0005434374896	20146	Economy	13000.00
0005434374931	20146	Economy	13000.00
0005433463903	20146	Economy	13000.00
0005433463905	20146	Economy	13000.00
0005434374838	20146	Economy	13000.00
0005434374879	20146	Economy	14300.00
0005434374972	20146	Economy	14300.00
0005433151970	20146	Economy	14300.00
0005433151974	20146	Economy	14300.00
0005434374839	20146	Economy	14300.00
0005433151960	20146	Economy	13000.00
0005433151966	20146	Economy	13000.00
0005434374991	20146	Economy	13000.00
0005434375019	20146	Economy	13000.00
0005433463896	20146	Economy	13000.00
0005433461585	20146	Economy	13000.00
0005433463902	20146	Economy	13000.00
0005433151987	20146	Economy	13000.00
0005434374841	20146	Economy	13000.00
0005433463906	20146	Economy	13000.00
0005433463907	20146	Economy	13000.00
0005434374915	20146	Economy	13000.00
0005433151954	20146	Economy	13000.00
0005433151986	20146	Economy	13000.00
0005433151975	20146	Economy	13000.00
0005434374768	20146	Economy	13000.00
0005434374730	20146	Economy	13000.00
0005433461586	20146	Economy	13000.00
0005434029699	20146	Economy	13000.00
0005433461597	20146	Economy	13000.00
0005433151976	20146	Economy	13000.00
0005434374990	20146	Economy	13000.00
0005433151971	20146	Economy	13000.00
0005433151982	20146	Economy	13000.00
0005433151965	20146	Economy	13000.00
0005433461582	20146	Economy	13000.00
0005433461589	20146	Economy	13000.00
0005434374902	20146	Economy	13000.00
0005433764713	20146	Economy	13000.00
0005433151980	20146	Economy	13000.00
0005433461588	20146	Economy	13000.00
0005434374981	20146	Economy	13000.00
0005433151979	20146	Economy	13000.00
0005433151967	20146	Economy	13000.00
0005433151977	20146	Economy	13000.00
0005434374922	20146	Economy	13000.00
0005434374960	20146	Economy	13000.00
0005433463908	20146	Economy	13000.00
0005433461590	20146	Economy	13000.00
0005434374892	20146	Economy	13000.00
0005433151984	20146	Economy	13000.00
0005433461598	20146	Economy	13000.00
0005433151981	20146	Economy	13000.00
0005434374893	20146	Economy	13000.00
0005433463897	20146	Economy	13000.00
0005434374976	20146	Economy	13000.00
0005434374906	20146	Economy	13000.00
0005434374977	20146	Economy	13000.00
0005434374978	20146	Economy	13000.00
0005433151969	20146	Economy	13000.00
0005434374992	20146	Economy	13000.00
0005434374982	20146	Economy	13000.00
0005432056360	20146	Economy	13000.00
0005434374983	20146	Economy	13000.00
0005433151956	20146	Economy	13000.00
0005432425236	578	Business	27500.00
0005432425251	578	Business	27500.00
0005432425279	578	Business	27500.00
0005432425280	578	Business	27500.00
0005432425238	578	Business	27500.00
0005432425262	578	Business	27500.00
0005432282978	578	Business	27500.00
0005432282977	578	Business	27500.00
0005432425287	578	Business	27500.00
0005432425250	578	Business	27500.00
0005432425268	578	Business	27500.00
0005432425289	578	Business	27500.00
0005432425285	578	Business	27500.00
0005432425272	578	Business	27500.00
0005432425244	578	Business	27500.00
0005432425246	578	Economy	10100.00
0005432282979	578	Economy	10100.00
0005432425260	578	Economy	9200.00
0005432425261	578	Economy	9200.00
0005432425265	578	Economy	9200.00
0005432425273	578	Economy	9200.00
0005432425253	578	Economy	9200.00
0005432425243	578	Economy	9200.00
0005432425252	578	Economy	9200.00
0005432425267	578	Economy	9200.00
0005432425283	578	Economy	9200.00
0005432425275	578	Economy	9200.00
0005432282981	578	Economy	9200.00
0005432425237	578	Economy	9200.00
0005432425245	578	Economy	9200.00
0005432425254	578	Economy	9200.00
0005432425291	578	Economy	9200.00
0005432425270	578	Economy	9200.00
0005432425241	578	Economy	9200.00
0005432425259	578	Economy	9200.00
0005432425286	578	Economy	9200.00
0005432425281	578	Economy	9200.00
0005432282983	578	Economy	9200.00
0005432425242	578	Economy	9200.00
0005432425293	578	Economy	9200.00
0005432425256	578	Economy	9200.00
0005432425284	578	Economy	9200.00
0005432425240	578	Economy	9200.00
0005432425292	578	Economy	9200.00
0005432425269	578	Economy	10100.00
0005432425278	578	Economy	10100.00
0005432425239	578	Economy	10100.00
0005432425248	578	Economy	9200.00
0005432425258	578	Economy	10100.00
0005432425263	578	Economy	9200.00
0005432425277	578	Economy	9200.00
0005432425274	578	Economy	9200.00
0005432425255	578	Economy	9200.00
0005432425282	578	Economy	9200.00
0005432425249	578	Economy	9200.00
0005432425257	578	Economy	9200.00
0005432425288	578	Economy	9200.00
0005432425266	578	Economy	9200.00
0005432282980	578	Economy	9200.00
0005432425290	578	Economy	9200.00
0005432425247	578	Economy	9200.00
0005432425271	578	Economy	9200.00
0005432425276	578	Economy	9200.00
0005432425264	578	Economy	9200.00
0005432282982	578	Economy	9200.00
0005432302393	12883	Economy	9200.00
0005432302391	12883	Economy	9200.00
0005432302395	12883	Economy	10100.00
0005433261869	12883	Economy	9200.00
0005432302394	12883	Economy	9200.00
0005432302392	12883	Economy	9200.00
0005433261870	12883	Economy	9200.00
0005432424812	12882	Business	27500.00
0005432424768	12882	Business	27500.00
0005432424769	12882	Business	27500.00
0005432424743	12882	Business	27500.00
0005432424758	12882	Business	27500.00
0005432424820	12882	Economy	10100.00
0005432424642	12882	Economy	9200.00
0005432424793	12882	Economy	9200.00
0005432424692	12882	Economy	9200.00
0005432424777	12882	Economy	9200.00
0005432424657	12882	Economy	9200.00
0005432424641	12882	Economy	9200.00
0005432424549	12882	Economy	9200.00
0005432424792	12882	Economy	9200.00
0005432424622	12882	Economy	9200.00
0005432424778	12882	Economy	9200.00
0005432424819	12882	Economy	9200.00
0005432424771	12882	Economy	9200.00
0005432424464	12882	Economy	9200.00
0005432424760	12882	Economy	9200.00
0005432424779	12882	Economy	9200.00
0005432424713	12882	Economy	9200.00
0005432424655	12882	Economy	10100.00
0005432424814	12882	Economy	10100.00
0005432424776	12882	Economy	9200.00
0005432424740	12882	Economy	9200.00
0005432424710	12882	Economy	9200.00
0005432424706	12882	Economy	9200.00
0005432424804	12882	Economy	9200.00
0005432424668	12882	Economy	9200.00
0005432424726	12882	Economy	9200.00
0005432424764	12882	Economy	9200.00
0005432424714	12882	Economy	9200.00
0005432424763	12882	Economy	9200.00
0005432424672	12882	Economy	9200.00
0005432424648	12882	Economy	9200.00
0005432424656	12882	Economy	9200.00
0005432424734	12882	Economy	9200.00
0005432424725	12882	Economy	9200.00
0005432424801	12882	Economy	9200.00
0005432424805	12882	Economy	9200.00
0005432424548	12882	Economy	9200.00
0005432424787	12882	Economy	9200.00
0005432424465	12882	Economy	9200.00
0005432424821	12882	Economy	9200.00
0005432424649	12882	Economy	9200.00
0005433684439	445	Business	24500.00
0005434024814	445	Business	24500.00
0005434024848	445	Business	24500.00
0005433058207	445	Business	24500.00
0005433058157	445	Business	24500.00
0005434735706	445	Business	24500.00
0005433058306	445	Business	24500.00
0005433058419	445	Business	24500.00
0005434032098	445	Business	24500.00
0005434024834	445	Business	24500.00
0005434024845	445	Business	24500.00
0005434024795	445	Business	24500.00
0005434024824	445	Business	24500.00
0005434024841	445	Business	24500.00
0005433058187	445	Business	24500.00
0005434024847	445	Business	24500.00
0005434032097	445	Business	24500.00
0005434024842	445	Business	24500.00
0005434024853	445	Business	24500.00
0005433058252	445	Economy	9000.00
0005433058140	445	Business	24500.00
0005433058174	445	Economy	9000.00
0005434032096	445	Economy	9000.00
0005433058345	445	Economy	8200.00
0005433058259	445	Economy	8200.00
0005434735736	445	Economy	8200.00
0005434024825	445	Economy	8200.00
0005432235763	445	Economy	8200.00
0005434024801	445	Economy	8200.00
0005434024810	445	Economy	8200.00
0005433058342	445	Economy	8200.00
0005433058293	445	Economy	8200.00
0005434024793	445	Economy	8200.00
0005434024835	445	Economy	8200.00
0005433058163	445	Economy	8200.00
0005434024808	445	Economy	8200.00
0005433929634	445	Economy	8200.00
0005434024826	445	Economy	8200.00
0005433058326	445	Economy	8200.00
0005434024820	445	Economy	8200.00
0005434029695	445	Economy	8200.00
0005434735704	445	Economy	8200.00
0005433058315	445	Economy	8200.00
0005434024833	445	Economy	8200.00
0005433058341	445	Economy	8200.00
0005433058325	445	Economy	8200.00
0005433058358	445	Economy	8200.00
0005434024819	445	Economy	8200.00
0005433058197	445	Economy	8200.00
0005433058196	445	Economy	8200.00
0005434024800	445	Economy	8200.00
0005434024806	445	Economy	8200.00
0005433058133	445	Economy	8200.00
0005433058294	445	Economy	8200.00
0005434735737	445	Economy	8200.00
0005432235765	445	Economy	8200.00
0005434024855	445	Economy	8200.00
0005434024798	445	Economy	8200.00
0005433058158	445	Economy	8200.00
0005434024812	445	Economy	8200.00
0005434024838	445	Economy	8200.00
0005434024811	445	Economy	8200.00
0005434024839	445	Economy	8200.00
0005433058176	445	Economy	8200.00
0005433058251	445	Economy	8200.00
0005434032094	445	Economy	8200.00
0005433684435	445	Economy	8200.00
0005432045643	445	Economy	8200.00
0005433058418	445	Economy	8200.00
0005434024828	445	Economy	8200.00
0005434024807	445	Economy	8200.00
0005434024836	445	Economy	8200.00
0005434024843	445	Economy	8200.00
0005434735724	445	Economy	8200.00
0005433929624	445	Economy	8200.00
0005434024799	445	Economy	8200.00
0005432235762	445	Economy	8200.00
0005434024813	445	Economy	8200.00
0005434024818	445	Economy	8200.00
0005434029697	445	Economy	8200.00
0005434024817	445	Economy	8200.00
0005433058273	445	Economy	8200.00
0005434024805	445	Economy	8200.00
0005433058141	445	Economy	8200.00
0005434024816	445	Economy	8200.00
0005433058346	445	Economy	8200.00
0005433058258	445	Economy	8200.00
0005434024831	445	Economy	8200.00
0005432045644	445	Economy	8200.00
0005434028345	445	Economy	8200.00
0005434024857	445	Economy	8200.00
0005434029694	445	Economy	8200.00
0005434024832	445	Economy	8200.00
0005434028346	445	Economy	8200.00
0005434024804	445	Economy	8200.00
0005433058313	445	Economy	8200.00
0005433058328	445	Economy	8200.00
0005434024791	445	Economy	9000.00
0005434735723	445	Economy	9000.00
0005434024837	445	Economy	8200.00
0005434024829	445	Economy	8200.00
0005433058234	445	Economy	8200.00
0005434024822	445	Economy	9000.00
0005433058142	445	Economy	8200.00
0005433058247	445	Economy	8200.00
0005433058292	445	Economy	8200.00
0005434024849	445	Economy	8200.00
0005432235759	445	Economy	8200.00
0005434024794	445	Economy	8200.00
0005433929625	445	Economy	8200.00
0005434024840	445	Economy	8200.00
0005434024823	445	Economy	8200.00
0005433058231	445	Economy	8200.00
0005434029696	445	Economy	8200.00
0005433058195	445	Economy	8200.00
0005434024850	445	Economy	8200.00
0005434024852	445	Economy	8200.00
0005434024797	445	Economy	8200.00
0005433058336	445	Economy	8200.00
0005434024854	445	Economy	8200.00
0005434024803	445	Economy	8200.00
0005434024851	445	Economy	8200.00
0005433058314	445	Economy	8200.00
0005433058132	445	Economy	8200.00
0005433058305	445	Economy	8200.00
0005432235761	445	Economy	8200.00
0005434032095	445	Economy	8200.00
0005434735714	445	Economy	8200.00
0005433058248	445	Economy	8200.00
0005434028347	445	Economy	8200.00
0005434024844	445	Economy	8200.00
0005433058175	445	Economy	8200.00
0005434024790	445	Economy	8200.00
0005433058159	445	Economy	8200.00
0005434024846	445	Economy	8200.00
0005433058206	445	Economy	8200.00
0005433058241	445	Economy	8200.00
0005433058327	445	Economy	8200.00
0005434024815	445	Economy	8200.00
0005434024830	445	Economy	8200.00
0005434024792	445	Economy	8200.00
0005434024796	445	Economy	8200.00
0005434024821	445	Economy	8200.00
0005432235760	445	Economy	8200.00
0005434024827	445	Economy	8200.00
0005432235764	445	Economy	8200.00
0005432235758	445	Economy	8200.00
0005434024856	445	Economy	8200.00
0005434024802	445	Economy	8200.00
0005433058235	445	Economy	8200.00
0005434024809	445	Economy	8200.00
0005433058260	445	Economy	8200.00
0005433058337	445	Economy	8200.00
0005433058156	445	Economy	8200.00
0005433058198	445	Economy	8200.00
0005433058310	445	Economy	8200.00
0005433929648	445	Economy	8200.00
0005434735705	445	Economy	8200.00
0005434024591	12686	Business	24500.00
0005434024017	12686	Business	24500.00
0005433058555	12686	Business	24500.00
0005434024598	12686	Business	24500.00
0005434024189	12686	Business	24500.00
0005433058552	12686	Business	24500.00
0005434735779	12686	Business	24500.00
0005432156438	12686	Business	24500.00
0005433058558	12686	Business	24500.00
0005434024282	12686	Business	24500.00
0005433684456	12686	Business	24500.00
0005433058526	12686	Business	24500.00
0005433058554	12686	Business	24500.00
0005434735775	12686	Business	24500.00
0005434024036	12686	Business	24500.00
0005434023885	12686	Business	24500.00
0005434024326	12686	Business	24500.00
0005434024370	12686	Economy	9000.00
0005433929681	12686	Economy	9000.00
0005433058530	12686	Economy	9000.00
0005434024195	12686	Economy	8200.00
0005434024358	12686	Economy	8200.00
0005433058543	12686	Economy	8200.00
0005433058560	12686	Economy	8200.00
0005434024097	12686	Economy	8200.00
0005434024432	12686	Economy	8200.00
0005434024508	12686	Economy	8200.00
0005434023850	12686	Economy	8200.00
0005433058545	12686	Economy	8200.00
0005434024339	12686	Economy	8200.00
0005434024253	12686	Economy	8200.00
0005434024024	12686	Economy	8200.00
0005434024312	12686	Economy	8200.00
0005434024369	12686	Economy	8200.00
0005433058561	12686	Economy	8200.00
0005434024121	12686	Economy	8200.00
0005434024271	12686	Economy	8200.00
0005433058531	12686	Economy	8200.00
0005433929680	12686	Economy	8200.00
0005433929683	12686	Economy	8200.00
0005434024376	12686	Economy	8200.00
0005434024194	12686	Economy	8200.00
0005433058546	12686	Economy	8200.00
0005434024272	12686	Economy	8200.00
0005434024335	12686	Economy	8200.00
0005434023963	12686	Economy	8200.00
0005433058536	12686	Economy	8200.00
0005434024311	12686	Economy	8200.00
0005434024409	12686	Economy	8200.00
0005433058524	12686	Economy	8200.00
0005434024098	12686	Economy	8200.00
0005433058562	12686	Economy	8200.00
0005434024117	12686	Economy	8200.00
0005433058549	12686	Economy	8200.00
0005433058547	12686	Economy	8200.00
0005434735777	12686	Economy	8200.00
0005434024438	12686	Economy	8200.00
0005434024277	12686	Economy	8200.00
0005433058540	12686	Economy	8200.00
0005433058529	12686	Economy	8200.00
0005432156439	12686	Economy	8200.00
0005434024025	12686	Economy	8200.00
0005433058535	12686	Economy	8200.00
0005434024284	12686	Economy	8200.00
0005434024445	12686	Economy	8200.00
0005434024122	12686	Economy	8200.00
0005433058563	12686	Economy	8200.00
0005433058559	12686	Economy	8200.00
0005434024268	12686	Economy	8200.00
0005434024382	12686	Economy	8200.00
0005434024362	12686	Economy	8200.00
0005434024285	12686	Economy	8200.00
0005433058548	12686	Economy	8200.00
0005433058553	12686	Economy	8200.00
0005432156437	12686	Economy	8200.00
0005434024236	12686	Economy	8200.00
0005434024309	12686	Economy	8200.00
0005433058537	12686	Economy	8200.00
0005434024018	12686	Economy	8200.00
0005433058544	12686	Economy	8200.00
0005434032062	12686	Economy	8200.00
0005434024059	12686	Economy	8200.00
0005434735776	12686	Economy	8200.00
0005432156440	12686	Economy	8200.00
0005434024433	12686	Economy	9000.00
0005434024310	12686	Economy	8200.00
0005434024363	12686	Economy	9000.00
0005433684454	12686	Economy	9000.00
0005433929679	12686	Economy	8200.00
0005434024304	12686	Economy	8200.00
0005433058527	12686	Economy	8200.00
0005434024231	12686	Economy	8200.00
0005434032065	12686	Economy	8200.00
0005434032083	12686	Economy	8200.00
0005434735774	12686	Economy	8200.00
0005434032057	12686	Economy	8200.00
0005433058556	12686	Economy	8200.00
0005432157525	12686	Economy	8200.00
0005433058533	12686	Economy	8200.00
0005433684455	12686	Economy	8200.00
0005434024225	12686	Economy	8200.00
0005434024060	12686	Economy	8200.00
0005433058528	12686	Economy	8200.00
0005434024371	12686	Economy	8200.00
0005433058538	12686	Economy	8200.00
0005434023886	12686	Economy	8200.00
0005434024717	12686	Economy	8200.00
0005433058542	12686	Economy	8200.00
0005434024437	12686	Economy	8200.00
0005434024325	12686	Economy	8200.00
0005433058557	12686	Economy	8200.00
0005433929682	12686	Economy	8200.00
0005433058541	12686	Economy	8200.00
0005434032069	12686	Economy	8200.00
0005433058534	12686	Economy	8200.00
0005434024327	12686	Economy	8200.00
0005434024359	12686	Economy	8200.00
0005432157524	12686	Economy	8200.00
0005433058550	12686	Economy	8200.00
0005434024381	12686	Economy	8200.00
0005433058532	12686	Economy	8200.00
0005434024207	12686	Economy	8200.00
0005434024252	12686	Economy	8200.00
0005433058551	12686	Economy	8200.00
0005434024436	12686	Economy	8200.00
0005433058525	12686	Economy	8200.00
0005434024133	12686	Economy	8200.00
0005434024314	12686	Economy	8200.00
0005434032068	12686	Economy	8200.00
0005434024419	12686	Economy	8200.00
0005434735778	12686	Economy	8200.00
0005434024188	12686	Economy	8200.00
0005434024392	12686	Economy	8200.00
0005433058564	12686	Economy	8200.00
0005433058539	12686	Economy	8200.00
0005434024355	12686	Economy	8200.00
0005433924841	2150	Business	34700.00
0005433924898	2150	Business	34700.00
0005433924916	2150	Business	34700.00
0005433924913	2150	Business	34700.00
0005433929682	2150	Business	34700.00
0005433924895	2150	Business	34700.00
0005433036469	2150	Business	34700.00
0005433924851	2150	Business	34700.00
0005433924872	2150	Business	34700.00
0005433924886	2150	Business	34700.00
0005433924915	2150	Business	34700.00
0005433036914	2150	Business	34700.00
0005433036597	2150	Business	34700.00
0005433924868	2150	Business	34700.00
0005433036556	2150	Business	34700.00
0005433036623	2150	Business	34700.00
0005433924894	2150	Business	34700.00
0005433924828	2150	Business	34700.00
0005433924899	2150	Business	34700.00
0005432231736	2150	Business	34700.00
0005433036700	2150	Business	34700.00
0005433924897	2150	Business	34700.00
0005433036849	2150	Business	34700.00
0005433036485	2150	Business	34700.00
0005432231738	2150	Business	34700.00
0005433924831	2150	Business	34700.00
0005432749799	2150	Economy	12700.00
0005433036764	2150	Economy	12700.00
0005433036958	2150	Economy	12700.00
0005433924893	2150	Economy	12700.00
0005433924835	2150	Economy	11600.00
0005433036596	2150	Economy	11600.00
0005433924876	2150	Economy	11600.00
0005433036486	2150	Economy	11600.00
0005433036713	2150	Economy	11600.00
0005433036743	2150	Economy	11600.00
0005433924908	2150	Economy	11600.00
0005433924883	2150	Economy	11600.00
0005433924911	2150	Economy	11600.00
0005433036848	2150	Economy	11600.00
0005433036438	2150	Economy	11600.00
0005433036757	2150	Economy	11600.00
0005433924864	2150	Economy	11600.00
0005433924904	2150	Economy	11600.00
0005433036711	2150	Economy	11600.00
0005433924923	2150	Economy	11600.00
0005433924900	2150	Economy	11600.00
0005433924909	2150	Economy	11600.00
0005433924867	2150	Economy	11600.00
0005433036805	2150	Economy	11600.00
0005433924903	2150	Economy	11600.00
0005433924921	2150	Economy	11600.00
0005433924890	2150	Economy	11600.00
0005433036635	2150	Economy	11600.00
0005433036525	2150	Economy	11600.00
0005433924906	2150	Economy	11600.00
0005433924834	2150	Economy	11600.00
0005433924888	2150	Economy	11600.00
0005433924884	2150	Economy	11600.00
0005433036717	2150	Economy	11600.00
0005433036810	2150	Economy	11600.00
0005433924879	2150	Economy	11600.00
0005433924856	2150	Economy	11600.00
0005433036653	2150	Economy	11600.00
0005433924854	2150	Economy	11600.00
0005433924887	2150	Economy	11600.00
0005432044570	2150	Economy	11600.00
0005433036651	2150	Economy	11600.00
0005432231742	2150	Economy	11600.00
0005433036703	2150	Economy	11600.00
0005433924833	2150	Economy	11600.00
0005433036501	2150	Economy	11600.00
0005433036578	2150	Economy	11600.00
0005433036704	2150	Economy	11600.00
0005433924889	2150	Economy	11600.00
0005433929680	2150	Economy	11600.00
0005433924840	2150	Economy	11600.00
0005433036573	2150	Economy	11600.00
0005433036604	2150	Economy	11600.00
0005433924859	2150	Economy	11600.00
0005433924914	2150	Economy	11600.00
0005433924924	2150	Economy	11600.00
0005433924922	2150	Economy	11600.00
0005432231741	2150	Economy	11600.00
0005433924902	2150	Economy	11600.00
0005433036812	2150	Economy	11600.00
0005433036763	2150	Economy	11600.00
0005433036684	2150	Economy	11600.00
0005433924878	2150	Economy	11600.00
0005433036552	2150	Economy	11600.00
0005433924881	2150	Economy	11600.00
0005433036741	2150	Economy	11600.00
0005433924829	2150	Economy	11600.00
0005433036561	2150	Economy	11600.00
0005433924910	2150	Economy	11600.00
0005433036694	2150	Economy	11600.00
0005433924919	2150	Economy	11600.00
0005432044571	2150	Economy	11600.00
0005433924844	2150	Economy	11600.00
0005433036749	2150	Economy	11600.00
0005433036632	2150	Economy	11600.00
0005433924870	2150	Economy	11600.00
0005432231739	2150	Economy	11600.00
0005433036685	2150	Economy	11600.00
0005433036526	2150	Economy	11600.00
0005433036621	2150	Economy	11600.00
0005433924871	2150	Economy	11600.00
0005433036595	2150	Economy	11600.00
0005433924874	2150	Economy	11600.00
0005433924853	2150	Economy	11600.00
0005433036818	2150	Economy	11600.00
0005433036724	2150	Economy	11600.00
0005433924857	2150	Economy	11600.00
0005433036459	2150	Economy	11600.00
0005433036961	2150	Economy	11600.00
0005433036847	2150	Economy	11600.00
0005433924880	2150	Economy	11600.00
0005432231737	2150	Economy	11600.00
0005433036706	2150	Economy	11600.00
0005433924837	2150	Economy	12700.00
0005433036634	2150	Economy	12700.00
0005433036731	2150	Economy	11600.00
0005433036702	2150	Economy	11600.00
0005433036631	2150	Economy	11600.00
0005433924839	2150	Economy	12700.00
0005433036553	2150	Economy	12700.00
0005433036705	2150	Economy	11600.00
0005433924827	2150	Economy	11600.00
0005433924830	2150	Economy	11600.00
0005433924843	2150	Economy	11600.00
0005433924875	2150	Economy	11600.00
0005433924873	2150	Economy	11600.00
0005433036913	2150	Economy	11600.00
0005433036765	2150	Economy	11600.00
0005433924858	2150	Economy	11600.00
0005433036617	2150	Economy	11600.00
0005433036470	2150	Economy	11600.00
0005433036633	2150	Economy	11600.00
0005433036751	2150	Economy	11600.00
0005433924849	2150	Economy	11600.00
0005433036560	2150	Economy	11600.00
0005433036813	2150	Economy	11600.00
0005433924861	2150	Economy	11600.00
0005432749796	2150	Economy	11600.00
0005433036861	2150	Economy	11600.00
0005432231743	2150	Economy	11600.00
0005433924865	2150	Economy	11600.00
0005433036750	2150	Economy	11600.00
0005433924918	2150	Economy	11600.00
0005433929683	2150	Economy	11600.00
0005433924847	2150	Economy	11600.00
0005433036665	2150	Economy	11600.00
0005433036752	2150	Economy	11600.00
0005433924842	2150	Economy	11600.00
0005433924869	2150	Economy	11600.00
0005433924877	2150	Economy	11600.00
0005433036557	2150	Economy	11600.00
0005433036506	2150	Economy	11600.00
0005432231744	2150	Economy	11600.00
0005433924850	2150	Economy	11600.00
0005432231740	2150	Economy	11600.00
0005433036505	2150	Economy	11600.00
0005433875402	2150	Economy	11600.00
0005433036281	2150	Economy	11600.00
0005433924860	2150	Economy	11600.00
0005433924917	2150	Economy	11600.00
0005433036577	2150	Economy	11600.00
0005433036609	2150	Economy	11600.00
0005433924885	2150	Economy	11600.00
0005433924896	2150	Economy	11600.00
0005433036712	2150	Economy	11600.00
0005432231735	2150	Economy	11600.00
0005433924832	2150	Economy	11600.00
0005433036668	2150	Economy	11600.00
0005433924836	2150	Economy	11600.00
0005433924912	2150	Economy	11600.00
0005433036504	2150	Economy	11600.00
0005433929679	2150	Economy	11600.00
0005433924862	2150	Economy	11600.00
0005433924892	2150	Economy	11600.00
0005433929681	2150	Economy	11600.00
0005433036742	2150	Economy	11600.00
0005433924866	2150	Economy	11600.00
0005433924891	2150	Economy	11600.00
0005433924852	2150	Economy	11600.00
0005433924901	2150	Economy	11600.00
0005433924848	2150	Economy	11600.00
0005433875403	2150	Economy	11600.00
0005433924907	2150	Economy	11600.00
0005433036659	2150	Economy	11600.00
0005433924920	2150	Economy	11600.00
0005433036528	2150	Economy	11600.00
0005433924863	2150	Economy	11600.00
0005433036766	2150	Economy	11600.00
0005433924846	2150	Economy	11600.00
0005433924845	2150	Economy	11600.00
0005433924882	2150	Economy	11600.00
0005433036652	2150	Economy	11600.00
0005433924855	2150	Economy	11600.00
0005433924905	2150	Economy	11600.00
0005433924838	2150	Economy	11600.00
0005433036551	2150	Economy	11600.00
0005433924123	24120	Business	34700.00
0005433931498	24120	Business	34700.00
0005433037178	24120	Business	34700.00
0005433924049	24120	Business	34700.00
0005433924011	24120	Business	34700.00
0005433924192	24120	Business	34700.00
0005433924024	24120	Business	34700.00
0005433037169	24120	Business	34700.00
0005433037161	24120	Business	34700.00
0005433037171	24120	Business	34700.00
0005433923743	24120	Business	34700.00
0005433931487	24120	Business	34700.00
0005433924166	24120	Business	34700.00
0005433037182	24120	Business	34700.00
0005433924046	24120	Business	34700.00
0005432749822	24120	Business	34700.00
0005433037149	24120	Business	34700.00
0005433923951	24120	Business	34700.00
0005433037154	24120	Business	34700.00
0005433924027	24120	Business	34700.00
0005433037183	24120	Business	34700.00
0005433037179	24120	Business	34700.00
0005433037165	24120	Business	34700.00
0005433923966	24120	Business	34700.00
0005433037181	24120	Business	34700.00
0005433924125	24120	Economy	12700.00
0005433924031	24120	Economy	12700.00
0005433037157	24120	Economy	11600.00
0005433924323	24120	Economy	12700.00
0005433924394	24120	Economy	11600.00
0005433923773	24120	Economy	11600.00
0005433924066	24120	Economy	11600.00
0005433929650	24120	Economy	11600.00
0005433923878	24120	Economy	11600.00
0005433037150	24120	Economy	11600.00
0005433037168	24120	Economy	11600.00
0005433924126	24120	Economy	11600.00
0005433037167	24120	Economy	11600.00
0005433037188	24120	Economy	11600.00
0005433924160	24120	Economy	11600.00
0005433037191	24120	Economy	11600.00
0005433931482	24120	Economy	11600.00
0005432207706	24120	Economy	11600.00
0005432207704	24120	Economy	11600.00
0005433924029	24120	Economy	11600.00
0005433037172	24120	Economy	11600.00
0005433923936	24120	Economy	11600.00
0005433924079	24120	Economy	11600.00
0005433923938	24120	Economy	11600.00
0005433923852	24120	Economy	11600.00
0005432749820	24120	Economy	11600.00
0005433923985	24120	Economy	11600.00
0005433924337	24120	Economy	11600.00
0005432206293	24120	Economy	11600.00
0005433929649	24120	Economy	11600.00
0005432206292	24120	Economy	11600.00
0005432749821	24120	Economy	11600.00
0005433037180	24120	Economy	11600.00
0005433931505	24120	Economy	11600.00
0005433929636	24120	Economy	11600.00
0005433037170	24120	Economy	11600.00
0005433924161	24120	Economy	11600.00
0005433924156	24120	Economy	11600.00
0005433037140	24120	Economy	11600.00
0005433924208	24120	Economy	11600.00
0005433924124	24120	Economy	11600.00
0005433924097	24120	Economy	11600.00
0005432207703	24120	Economy	11600.00
0005433924073	24120	Economy	11600.00
0005433037175	24120	Economy	11600.00
0005433037148	24120	Economy	11600.00
0005433037162	24120	Economy	11600.00
0005433037185	24120	Economy	11600.00
0005433923952	24120	Economy	11600.00
0005433037142	24120	Economy	11600.00
0005433923848	24120	Economy	11600.00
0005433037177	24120	Economy	11600.00
0005433924136	24120	Economy	11600.00
0005433924268	24120	Economy	11600.00
0005433923991	24120	Economy	11600.00
0005433037147	24120	Economy	11600.00
0005433037153	24120	Economy	11600.00
0005433924030	24120	Economy	11600.00
0005433924090	24120	Economy	11600.00
0005433929642	24120	Economy	11600.00
0005433924068	24120	Economy	11600.00
0005433037151	24120	Economy	11600.00
0005433923799	24120	Economy	11600.00
0005433924070	24120	Economy	11600.00
0005433931483	24120	Economy	11600.00
0005433924022	24120	Economy	11600.00
0005433924393	24120	Economy	11600.00
0005433923873	24120	Economy	11600.00
0005433924240	24120	Economy	11600.00
0005433037155	24120	Economy	11600.00
0005433924015	24120	Economy	11600.00
0005433923879	24120	Economy	11600.00
0005433923935	24120	Economy	11600.00
0005433924159	24120	Economy	11600.00
0005433924021	24120	Economy	11600.00
0005433037159	24120	Economy	11600.00
0005433037139	24120	Economy	11600.00
0005433037189	24120	Economy	11600.00
0005433924199	24120	Economy	11600.00
0005433931485	24120	Economy	11600.00
0005433923971	24120	Economy	11600.00
0005433037184	24120	Economy	11600.00
0005433924083	24120	Economy	11600.00
0005433929646	24120	Economy	11600.00
0005433923550	24120	Economy	12700.00
0005433923906	24120	Economy	11600.00
0005434028351	24120	Economy	11600.00
0005433037143	24120	Economy	11600.00
0005433924333	24120	Economy	12700.00
0005433924340	24120	Economy	12700.00
0005433037166	24120	Economy	11600.00
0005433924321	24120	Economy	11600.00
0005433924134	24120	Economy	11600.00
0005433924088	24120	Economy	11600.00
0005433923629	24120	Economy	11600.00
0005433924016	24120	Economy	11600.00
0005434028349	24120	Economy	11600.00
0005434028352	24120	Economy	11600.00
0005433037173	24120	Economy	11600.00
0005433924028	24120	Economy	11600.00
0005433924241	24120	Economy	11600.00
0005433924089	24120	Economy	11600.00
0005433923930	24120	Economy	11600.00
0005433037186	24120	Economy	11600.00
0005433923783	24120	Economy	11600.00
0005433037190	24120	Economy	11600.00
0005433923547	24120	Economy	11600.00
0005432206290	24120	Economy	11600.00
0005433924517	24120	Economy	11600.00
0005433037156	24120	Economy	11600.00
0005432207705	24120	Economy	11600.00
0005433037158	24120	Economy	11600.00
0005433037145	24120	Economy	11600.00
0005433924059	24120	Economy	11600.00
0005433037163	24120	Economy	11600.00
0005432206289	24120	Economy	11600.00
0005432206291	24120	Economy	11600.00
0005433931499	24120	Economy	11600.00
0005433929655	24120	Economy	11600.00
0005433037160	24120	Economy	11600.00
0005433037152	24120	Economy	11600.00
0005433923853	24120	Economy	11600.00
0005433924220	24120	Economy	11600.00
0005433923937	24120	Economy	11600.00
0005433037174	24120	Economy	11600.00
0005434028350	24120	Economy	11600.00
0005433924091	24120	Economy	11600.00
0005433924322	24120	Economy	11600.00
0005433924050	24120	Economy	11600.00
0005433924005	24120	Economy	11600.00
0005433037176	24120	Economy	11600.00
0005433037146	24120	Economy	11600.00
0005433037187	24120	Economy	11600.00
0005433037141	24120	Economy	11600.00
0005433924207	24120	Economy	11600.00
0005433924086	24120	Economy	11600.00
0005433924067	24120	Economy	11600.00
0005433923800	24120	Economy	11600.00
0005433924006	24120	Economy	11600.00
0005434028348	24120	Economy	11600.00
0005433037144	24120	Economy	11600.00
0005433924001	24120	Economy	11600.00
0005433037138	24120	Economy	11600.00
0005433924069	24120	Economy	11600.00
0005433037164	24120	Economy	11600.00
0005433924181	24120	Economy	11600.00
0005433923551	24120	Economy	11600.00
0005432206294	24120	Economy	11600.00
0005433923939	24120	Economy	11600.00
0005433924081	24120	Economy	11600.00
0005433924332	24120	Economy	11600.00
0005433924084	24120	Economy	11600.00
0005433924062	24120	Economy	11600.00
0005433924326	24120	Economy	11600.00
0005433923782	24120	Economy	11600.00
0005433924669	24120	Economy	11600.00
0005434727510	294	Business	83700.00
0005434032050	294	Business	83700.00
0005433181392	294	Business	83700.00
0005434552151	294	Business	83700.00
0005434302532	294	Business	83700.00
0005434727489	294	Business	83700.00
0005433126881	294	Business	83700.00
0005434552130	294	Business	83700.00
0005433131718	294	Business	83700.00
0005433234823	294	Business	83700.00
0005434727492	294	Business	83700.00
0005433234672	294	Business	83700.00
0005434552135	294	Business	83700.00
0005434727480	294	Business	83700.00
0005433234791	294	Business	83700.00
0005433131740	294	Business	83700.00
0005434727418	294	Business	83700.00
0005434735773	294	Business	83700.00
0005434727457	294	Business	83700.00
0005434727512	294	Business	83700.00
0005434727501	294	Business	83700.00
0005432278031	294	Business	83700.00
0005434552117	294	Business	83700.00
0005434552108	294	Comfort	47400.00
0005434552159	294	Comfort	47400.00
0005433181302	294	Comfort	47400.00
0005433181254	294	Comfort	47400.00
0005434727409	294	Comfort	47400.00
0005432278030	294	Comfort	47400.00
0005433234676	294	Comfort	47400.00
0005433289895	294	Comfort	47400.00
0005433181367	294	Comfort	47400.00
0005434552137	294	Comfort	47400.00
0005433234620	294	Comfort	47400.00
0005434552124	294	Comfort	47400.00
0005434727420	294	Comfort	47400.00
0005434727475	294	Comfort	47400.00
0005432278027	294	Comfort	47400.00
0005434727476	294	Comfort	47400.00
0005434727488	294	Comfort	47400.00
0005434727507	294	Comfort	47400.00
0005433181327	294	Comfort	47400.00
0005433234939	294	Comfort	47400.00
0005433234769	294	Comfort	47400.00
0005435142801	294	Comfort	47400.00
0005433289884	294	Comfort	47400.00
0005434727416	294	Comfort	47400.00
0005433234693	294	Comfort	47400.00
0005434727511	294	Comfort	47400.00
0005433234843	294	Comfort	47400.00
0005435142795	294	Comfort	47400.00
0005433234522	294	Comfort	47400.00
0005434727493	294	Comfort	47400.00
0005434552138	294	Comfort	47400.00
0005434727427	294	Comfort	47400.00
0005433234846	294	Comfort	47400.00
0005434727408	294	Comfort	47400.00
0005433234498	294	Comfort	47400.00
0005434727434	294	Comfort	47400.00
0005434727521	294	Comfort	47400.00
0005434552160	294	Comfort	47400.00
0005433113556	294	Comfort	47400.00
0005435142805	294	Comfort	47400.00
0005433181253	294	Comfort	47400.00
0005434727449	294	Economy	27900.00
0005434552144	294	Economy	27900.00
0005434552122	294	Economy	27900.00
0005434727495	294	Economy	27900.00
0005434727515	294	Economy	27900.00
0005434552147	294	Economy	27900.00
0005434302529	294	Economy	27900.00
0005434727456	294	Economy	27900.00
0005433234719	294	Economy	27900.00
0005434727461	294	Economy	27900.00
0005433234789	294	Economy	27900.00
0005434552143	294	Economy	27900.00
0005434727525	294	Economy	27900.00
0005435142803	294	Economy	27900.00
0005434727523	294	Economy	27900.00
0005433234754	294	Economy	27900.00
0005434727509	294	Economy	27900.00
0005433234562	294	Economy	27900.00
0005432278026	294	Economy	27900.00
0005434727453	294	Economy	27900.00
0005433234374	294	Economy	27900.00
0005434727460	294	Economy	27900.00
0005434727481	294	Economy	27900.00
0005434552131	294	Economy	27900.00
0005434727415	294	Economy	27900.00
0005433234643	294	Economy	27900.00
0005434727466	294	Economy	27900.00
0005435142796	294	Economy	27900.00
0005434727519	294	Economy	27900.00
0005434727411	294	Economy	27900.00
0005433289885	294	Economy	27900.00
0005434552146	294	Economy	27900.00
0005433234185	294	Economy	27900.00
0005434727414	294	Economy	27900.00
0005433181393	294	Economy	27900.00
0005434727451	294	Economy	27900.00
0005434727439	294	Economy	27900.00
0005433234862	294	Economy	27900.00
0005434727479	294	Economy	27900.00
0005434727496	294	Economy	27900.00
0005434552116	294	Economy	27900.00
0005434552141	294	Economy	27900.00
0005434727435	294	Economy	27900.00
0005434727468	294	Economy	27900.00
0005435142802	294	Economy	27900.00
0005434727490	294	Economy	27900.00
0005434727486	294	Economy	27900.00
0005434727517	294	Economy	27900.00
0005434727471	294	Economy	27900.00
0005433234625	294	Economy	27900.00
0005434727417	294	Economy	27900.00
0005434727487	294	Economy	27900.00
0005434727433	294	Economy	27900.00
0005434727474	294	Economy	27900.00
0005434727422	294	Economy	27900.00
0005433234783	294	Economy	27900.00
0005435142794	294	Economy	27900.00
0005434552149	294	Economy	27900.00
0005434727443	294	Economy	30700.00
0005433131742	294	Economy	27900.00
0005434552155	294	Economy	30700.00
0005433234890	294	Economy	30700.00
0005433181339	294	Economy	30700.00
0005434727440	294	Economy	27900.00
0005433234790	294	Economy	30700.00
0005433181338	294	Economy	27900.00
0005434552107	294	Economy	27900.00
0005433289881	294	Economy	27900.00
0005434727441	294	Economy	27900.00
0005434727505	294	Economy	27900.00
0005435142807	294	Economy	27900.00
0005433234717	294	Economy	27900.00
0005433234895	294	Economy	27900.00
0005434552156	294	Economy	27900.00
0005434552110	294	Economy	27900.00
0005434731236	294	Economy	27900.00
0005434727419	294	Economy	27900.00
0005434727402	294	Economy	27900.00
0005433126873	294	Economy	27900.00
0005434552126	294	Economy	27900.00
0005434735770	294	Economy	27900.00
0005433289904	294	Economy	27900.00
0005434727520	294	Economy	27900.00
0005433181190	294	Economy	27900.00
0005433234687	294	Economy	27900.00
0005434727464	294	Economy	27900.00
0005434552129	294	Economy	27900.00
0005432278034	294	Economy	27900.00
0005434552109	294	Economy	27900.00
0005432278035	294	Economy	27900.00
0005434727503	294	Economy	27900.00
0005434731238	294	Economy	27900.00
0005433113546	294	Economy	27900.00
0005434727524	294	Economy	27900.00
0005432278023	294	Economy	27900.00
0005435142797	294	Economy	27900.00
0005434032055	294	Economy	27900.00
0005434552115	294	Economy	27900.00
0005434552152	294	Economy	27900.00
0005434727413	294	Economy	27900.00
0005434735771	294	Economy	27900.00
0005433234675	294	Economy	27900.00
0005433131717	294	Economy	27900.00
0005434727428	294	Economy	27900.00
0005434727482	294	Economy	27900.00
0005434727478	294	Economy	27900.00
0005433234686	294	Economy	27900.00
0005434727407	294	Economy	27900.00
0005434552150	294	Economy	27900.00
0005432278033	294	Economy	27900.00
0005435142804	294	Economy	27900.00
0005434727436	294	Economy	27900.00
0005433111520	294	Economy	27900.00
0005433131743	294	Economy	27900.00
0005434727455	294	Economy	27900.00
0005434552154	294	Economy	27900.00
0005435142799	294	Economy	27900.00
0005433234692	294	Economy	27900.00
0005434727405	294	Economy	27900.00
0005434552133	294	Economy	27900.00
0005434727500	294	Economy	27900.00
0005434727438	294	Economy	27900.00
0005434727454	294	Economy	27900.00
0005434552161	294	Economy	27900.00
0005432278029	294	Economy	27900.00
0005433234720	294	Economy	27900.00
0005433234188	294	Economy	27900.00
0005433289901	294	Economy	27900.00
0005434552114	294	Economy	27900.00
0005434727459	294	Economy	27900.00
0005433234575	294	Economy	27900.00
0005433234539	294	Economy	27900.00
0005434727477	294	Economy	27900.00
0005434727426	294	Economy	27900.00
0005434552106	294	Economy	27900.00
0005433181309	294	Economy	27900.00
0005435142800	294	Economy	27900.00
0005434727470	294	Economy	27900.00
0005434727462	294	Economy	27900.00
0005433181296	294	Economy	27900.00
0005434727513	294	Economy	27900.00
0005435142793	294	Economy	27900.00
0005434302531	294	Economy	27900.00
0005433234621	294	Economy	27900.00
0005434552112	294	Economy	27900.00
0005434727502	294	Economy	27900.00
0005434727499	294	Economy	27900.00
0005434727406	294	Economy	27900.00
0005434735772	294	Economy	27900.00
0005434552121	294	Economy	27900.00
0005434727444	294	Economy	27900.00
0005434552148	294	Economy	27900.00
0005434727447	294	Economy	27900.00
0005433234761	294	Economy	27900.00
0005433234697	294	Economy	27900.00
0005432278032	294	Economy	27900.00
0005434727437	294	Economy	27900.00
0005434727446	294	Economy	27900.00
0005434727494	294	Economy	27900.00
0005434552132	294	Economy	27900.00
0005434552127	294	Economy	27900.00
0005434727445	294	Economy	30700.00
0005434552145	294	Economy	30700.00
0005434727465	294	Economy	30700.00
0005433234667	294	Economy	30700.00
0005434735769	294	Economy	30700.00
0005434552125	294	Economy	27900.00
0005433234523	294	Economy	27900.00
0005434727410	294	Economy	27900.00
0005434552153	294	Economy	27900.00
0005433131719	294	Economy	27900.00
0005434727458	294	Economy	27900.00
0005433181328	294	Economy	27900.00
0005433234644	294	Economy	27900.00
0005434727504	294	Economy	27900.00
0005434727404	294	Economy	27900.00
0005433234749	294	Economy	27900.00
0005434727469	294	Economy	27900.00
0005433181314	294	Economy	27900.00
0005434727463	294	Economy	27900.00
0005432278025	294	Economy	27900.00
0005434727497	294	Economy	27900.00
0005434727452	294	Economy	27900.00
0005434727450	294	Economy	27900.00
0005434727522	294	Economy	27900.00
0005434727514	294	Economy	27900.00
0005433181366	294	Economy	27900.00
0005432278036	294	Economy	27900.00
0005433234768	294	Economy	27900.00
0005434552157	294	Economy	27900.00
0005433126880	294	Economy	27900.00
0005434727424	294	Economy	27900.00
0005433181240	294	Economy	27900.00
0005433131751	294	Economy	27900.00
0005434727516	294	Economy	27900.00
0005433766660	294	Economy	27900.00
0005434552139	294	Economy	27900.00
0005434727403	294	Economy	27900.00
0005433234782	294	Economy	27900.00
0005434727472	294	Economy	27900.00
0005433234505	294	Economy	27900.00
0005434727430	294	Economy	27900.00
0005434302530	294	Economy	27900.00
0005434727425	294	Economy	27900.00
0005435142798	294	Economy	27900.00
0005434552134	294	Economy	27900.00
0005434727484	294	Economy	27900.00
0005434727508	294	Economy	27900.00
0005434552119	294	Economy	27900.00
0005433181159	294	Economy	27900.00
0005432278028	294	Economy	27900.00
0005433234375	294	Economy	27900.00
0005434552105	294	Economy	27900.00
0005434552118	294	Economy	27900.00
0005434727442	294	Economy	27900.00
0005434727429	294	Economy	27900.00
0005434552120	294	Economy	27900.00
0005433234804	294	Economy	27900.00
0005433181192	294	Economy	27900.00
0005432278024	294	Economy	27900.00
0005434727498	294	Economy	27900.00
0005434727473	294	Economy	27900.00
0005433131741	294	Economy	27900.00
0005433234896	294	Economy	27900.00
0005434552142	294	Economy	27900.00
0005433234483	294	Economy	27900.00
0005433234673	294	Economy	27900.00
0005434727491	294	Economy	27900.00
0005435142806	294	Economy	27900.00
0005434727412	294	Economy	27900.00
0005434727423	294	Economy	27900.00
0005433181313	294	Economy	27900.00
0005434552111	294	Economy	27900.00
0005434727432	294	Economy	27900.00
0005433289905	294	Economy	27900.00
0005434727518	294	Economy	27900.00
0005434727483	294	Economy	27900.00
0005434731235	294	Economy	27900.00
0005434727506	294	Economy	27900.00
0005433234842	294	Economy	27900.00
0005434552123	294	Economy	27900.00
0005434731237	294	Economy	27900.00
0005433234748	294	Economy	27900.00
0005433766659	294	Economy	27900.00
0005433234694	294	Economy	27900.00
0005433234497	294	Economy	27900.00
0005433234405	294	Economy	27900.00
0005434552113	294	Economy	27900.00
0005434552140	294	Economy	27900.00
0005434727421	294	Economy	27900.00
0005433234471	294	Economy	27900.00
0005434552136	294	Economy	27900.00
0005434727431	294	Economy	27900.00
0005434727448	294	Economy	27900.00
0005434032044	294	Economy	27900.00
0005434552158	294	Economy	27900.00
0005434727467	294	Economy	27900.00
0005433234891	294	Economy	27900.00
0005434727485	294	Economy	27900.00
0005433766682	294	Economy	27900.00
0005434552128	294	Economy	27900.00
0005434726129	9822	Business	83700.00
0005433181509	9822	Business	83700.00
0005434726588	9822	Business	83700.00
0005434735709	9822	Business	83700.00
0005434726608	9822	Business	83700.00
0005434726302	9822	Business	83700.00
0005432199364	9822	Business	83700.00
0005434726611	9822	Business	83700.00
0005433235249	9822	Business	83700.00
0005434726932	9822	Business	83700.00
0005434726229	9822	Business	83700.00
0005434726555	9822	Business	83700.00
0005433235206	9822	Business	83700.00
0005434735720	9822	Business	83700.00
0005434551952	9822	Business	83700.00
0005433181502	9822	Business	83700.00
0005434551495	9822	Business	83700.00
0005433766702	9822	Business	83700.00
0005433126920	9822	Comfort	47400.00
0005434551618	9822	Business	83700.00
0005434726246	9822	Comfort	47400.00
0005434726546	9822	Comfort	47400.00
0005433235225	9822	Comfort	47400.00
0005433235269	9822	Comfort	47400.00
0005433126918	9822	Comfort	47400.00
0005434726540	9822	Comfort	47400.00
0005434726607	9822	Comfort	47400.00
0005433235227	9822	Comfort	47400.00
0005433235241	9822	Comfort	47400.00
0005433235234	9822	Comfort	47400.00
0005435142737	9822	Comfort	47400.00
0005434726238	9822	Comfort	47400.00
0005433181511	9822	Comfort	47400.00
0005434726656	9822	Comfort	47400.00
0005434726501	9822	Comfort	47400.00
0005434551761	9822	Comfort	47400.00
0005434726642	9822	Comfort	47400.00
0005434726015	9822	Comfort	47400.00
0005434726910	9822	Comfort	47400.00
0005434725603	9822	Comfort	47400.00
0005433235256	9822	Comfort	47400.00
0005434726552	9822	Comfort	47400.00
0005434726025	9822	Comfort	47400.00
0005433181527	9822	Comfort	47400.00
0005434735721	9822	Comfort	47400.00
0005434726931	9822	Comfort	47400.00
0005434551649	9822	Comfort	47400.00
0005434551516	9822	Comfort	47400.00
0005433181503	9822	Comfort	47400.00
0005434726515	9822	Comfort	47400.00
0005434551564	9822	Comfort	47400.00
0005434726198	9822	Comfort	47400.00
0005434551699	9822	Comfort	47400.00
0005434726609	9822	Comfort	47400.00
0005433235251	9822	Comfort	47400.00
0005433181501	9822	Economy	27900.00
0005434726651	9822	Economy	27900.00
0005434551748	9822	Economy	27900.00
0005434725930	9822	Economy	27900.00
0005433235239	9822	Economy	27900.00
0005434551617	9822	Economy	27900.00
0005434726201	9822	Economy	27900.00
0005434551755	9822	Economy	27900.00
0005433113572	9822	Economy	27900.00
0005433235248	9822	Economy	27900.00
0005434551547	9822	Economy	27900.00
0005433235257	9822	Economy	27900.00
0005434726208	9822	Economy	27900.00
0005434726491	9822	Economy	27900.00
0005433235250	9822	Economy	27900.00
0005434725936	9822	Economy	27900.00
0005434551738	9822	Economy	27900.00
0005434726199	9822	Economy	27900.00
0005433181520	9822	Economy	27900.00
0005434726982	9822	Economy	27900.00
0005432199363	9822	Economy	27900.00
0005433181521	9822	Economy	27900.00
0005434726488	9822	Economy	27900.00
0005433235255	9822	Economy	27900.00
0005434032099	9822	Economy	27900.00
0005433235222	9822	Economy	27900.00
0005434726434	9822	Economy	27900.00
0005433235220	9822	Economy	27900.00
0005433181522	9822	Economy	27900.00
0005433235233	9822	Economy	27900.00
0005435142625	9822	Economy	27900.00
0005434725968	9822	Economy	27900.00
0005434726290	9822	Economy	27900.00
0005434551647	9822	Economy	27900.00
0005433235235	9822	Economy	27900.00
0005433235226	9822	Economy	27900.00
0005434726573	9822	Economy	27900.00
0005434302487	9822	Economy	27900.00
0005434726349	9822	Economy	27900.00
0005435142718	9822	Economy	27900.00
0005435142629	9822	Economy	27900.00
0005434726344	9822	Economy	27900.00
0005434551764	9822	Economy	27900.00
0005434551563	9822	Economy	27900.00
0005434551460	9822	Economy	27900.00
0005433126919	9822	Economy	27900.00
0005435142717	9822	Economy	27900.00
0005433235215	9822	Economy	27900.00
0005434726746	9822	Economy	27900.00
0005433181505	9822	Economy	27900.00
0005434551605	9822	Economy	27900.00
0005434726193	9822	Economy	27900.00
0005433126921	9822	Economy	27900.00
0005434551338	9822	Economy	27900.00
0005434726998	9822	Economy	27900.00
0005433181525	9822	Economy	27900.00
0005434551787	9822	Economy	27900.00
0005434551776	9822	Economy	27900.00
0005434726589	9822	Economy	27900.00
0005434302495	9822	Economy	30700.00
0005435142686	9822	Economy	30700.00
0005434726248	9822	Economy	30700.00
0005434551698	9822	Economy	27900.00
0005434726551	9822	Economy	27900.00
0005434726636	9822	Economy	27900.00
0005433129352	9822	Economy	30700.00
0005434725844	9822	Economy	27900.00
0005434551648	9822	Economy	30700.00
0005434726239	9822	Economy	27900.00
0005432199365	9822	Economy	30700.00
0005434726197	9822	Economy	27900.00
0005434726163	9822	Economy	27900.00
0005435142598	9822	Economy	27900.00
0005434726454	9822	Economy	27900.00
0005433129349	9822	Economy	27900.00
0005434726542	9822	Economy	27900.00
0005434551551	9822	Economy	27900.00
0005435142626	9822	Economy	27900.00
0005434731191	9822	Economy	27900.00
0005434551696	9822	Economy	27900.00
0005433235243	9822	Economy	27900.00
0005434726632	9822	Economy	27900.00
0005434551602	9822	Economy	27900.00
0005434726524	9822	Economy	27900.00
0005434726541	9822	Economy	27900.00
0005434551927	9822	Economy	27900.00
0005433235210	9822	Economy	27900.00
0005434551964	9822	Economy	27900.00
0005433235261	9822	Economy	27900.00
0005432199362	9822	Economy	27900.00
0005432199359	9822	Economy	27900.00
0005433289963	9822	Economy	27900.00
0005434551709	9822	Economy	27900.00
0005434726983	9822	Economy	27900.00
0005434726282	9822	Economy	27900.00
0005434726840	9822	Economy	27900.00
0005434726364	9822	Economy	27900.00
0005433235252	9822	Economy	27900.00
0005433235207	9822	Economy	27900.00
0005434726584	9822	Economy	27900.00
0005433235236	9822	Economy	27900.00
0005433235230	9822	Economy	27900.00
0005434726398	9822	Economy	27900.00
0005433181516	9822	Economy	27900.00
0005433235242	9822	Economy	27900.00
0005434726177	9822	Economy	27900.00
0005434726898	9822	Economy	27900.00
0005434726994	9822	Economy	27900.00
0005434726610	9822	Economy	27900.00
0005433181517	9822	Economy	27900.00
0005434726308	9822	Economy	27900.00
0005433235258	9822	Economy	27900.00
0005434551606	9822	Economy	27900.00
0005433235247	9822	Economy	27900.00
0005435142719	9822	Economy	27900.00
0005434726439	9822	Economy	27900.00
0005433235265	9822	Economy	27900.00
0005433181524	9822	Economy	27900.00
0005434725935	9822	Economy	27900.00
0005434726556	9822	Economy	27900.00
0005434551478	9822	Economy	27900.00
0005434726497	9822	Economy	27900.00
0005434726631	9822	Economy	27900.00
0005433181519	9822	Economy	27900.00
0005433235267	9822	Economy	27900.00
0005433181506	9822	Economy	27900.00
0005433235218	9822	Economy	27900.00
0005434726162	9822	Economy	27900.00
0005434726207	9822	Economy	27900.00
0005434726505	9822	Economy	27900.00
0005433289968	9822	Economy	27900.00
0005433126917	9822	Economy	27900.00
0005434726291	9822	Economy	27900.00
0005434726506	9822	Economy	27900.00
0005433766703	9822	Economy	27900.00
0005433235263	9822	Economy	27900.00
0005434551439	9822	Economy	27900.00
0005433235245	9822	Economy	27900.00
0005434726661	9822	Economy	27900.00
0005433181507	9822	Economy	27900.00
0005433129350	9822	Economy	27900.00
0005434726528	9822	Economy	27900.00
0005434551528	9822	Economy	27900.00
0005433181513	9822	Economy	27900.00
0005434302503	9822	Economy	27900.00
0005434726543	9822	Economy	27900.00
0005433181508	9822	Economy	27900.00
0005434551530	9822	Economy	27900.00
0005434551345	9822	Economy	27900.00
0005433181510	9822	Economy	27900.00
0005433129351	9822	Economy	27900.00
0005434726502	9822	Economy	27900.00
0005433289966	9822	Economy	27900.00
0005433235229	9822	Economy	27900.00
0005434726275	9822	Economy	27900.00
0005433235209	9822	Economy	27900.00
0005434551652	9822	Economy	27900.00
0005434551527	9822	Economy	30700.00
0005434726260	9822	Economy	30700.00
0005435142630	9822	Economy	30700.00
0005433235244	9822	Economy	30700.00
0005432199361	9822	Economy	27900.00
0005434726866	9822	Economy	27900.00
0005434551575	9822	Economy	27900.00
0005434726240	9822	Economy	27900.00
0005433181504	9822	Economy	27900.00
0005433235231	9822	Economy	27900.00
0005434726637	9822	Economy	27900.00
0005434551438	9822	Economy	27900.00
0005433235238	9822	Economy	27900.00
0005434726051	9822	Economy	27900.00
0005432199360	9822	Economy	27900.00
0005434032101	9822	Economy	27900.00
0005433235266	9822	Economy	27900.00
0005433289962	9822	Economy	27900.00
0005433235219	9822	Economy	27900.00
0005434551636	9822	Economy	27900.00
0005434551458	9822	Economy	27900.00
0005434726287	9822	Economy	27900.00
0005434725602	9822	Economy	27900.00
0005433235232	9822	Economy	27900.00
0005434726525	9822	Economy	27900.00
0005434551687	9822	Economy	27900.00
0005434032102	9822	Economy	27900.00
0005433181518	9822	Economy	27900.00
0005433235259	9822	Economy	27900.00
0005434726729	9822	Economy	27900.00
0005433129348	9822	Economy	27900.00
0005434551707	9822	Economy	27900.00
0005434726657	9822	Economy	27900.00
0005434551800	9822	Economy	27900.00
0005434551616	9822	Economy	27900.00
0005433181515	9822	Economy	27900.00
0005433235228	9822	Economy	27900.00
0005434726307	9822	Economy	27900.00
0005433235262	9822	Economy	27900.00
0005433289965	9822	Economy	27900.00
0005433235212	9822	Economy	27900.00
0005433235216	9822	Economy	27900.00
0005434726073	9822	Economy	27900.00
0005433235211	9822	Economy	27900.00
0005433235214	9822	Economy	27900.00
0005434551459	9822	Economy	27900.00
0005434725706	9822	Economy	27900.00
0005434726740	9822	Economy	27900.00
0005434726580	9822	Economy	27900.00
0005434726519	9822	Economy	27900.00
0005433181514	9822	Economy	27900.00
0005434551426	9822	Economy	27900.00
0005434302491	9822	Economy	27900.00
0005434726747	9822	Economy	27900.00
0005433235260	9822	Economy	27900.00
0005434726728	9822	Economy	27900.00
0005433235224	9822	Economy	27900.00
0005434551777	9822	Economy	27900.00
0005434726281	9822	Economy	27900.00
0005434551737	9822	Economy	27900.00
0005434551402	9822	Economy	27900.00
0005434726839	9822	Economy	27900.00
0005434551546	9822	Economy	27900.00
0005434551763	9822	Economy	27900.00
0005434735710	9822	Economy	27900.00
0005434726247	9822	Economy	27900.00
0005433235217	9822	Economy	27900.00
0005434551594	9822	Economy	27900.00
0005434032100	9822	Economy	27900.00
0005433235240	9822	Economy	27900.00
0005433235254	9822	Economy	27900.00
0005434726365	9822	Economy	27900.00
0005433235253	9822	Economy	27900.00
0005434551567	9822	Economy	27900.00
0005434726016	9822	Economy	27900.00
0005433235208	9822	Economy	27900.00
0005434726623	9822	Economy	27900.00
0005433235213	9822	Economy	27900.00
0005434551565	9822	Economy	27900.00
0005434551673	9822	Economy	27900.00
0005434726117	9822	Economy	27900.00
0005434726652	9822	Economy	27900.00
0005433289969	9822	Economy	27900.00
0005434726570	9822	Economy	27900.00
0005433235264	9822	Economy	27900.00
0005433235223	9822	Economy	27900.00
0005433235237	9822	Economy	27900.00
0005433235268	9822	Economy	27900.00
0005434726370	9822	Economy	27900.00
0005434551951	9822	Economy	27900.00
0005433235221	9822	Economy	27900.00
0005434551640	9822	Economy	27900.00
0005434726276	9822	Economy	27900.00
0005433181523	9822	Economy	27900.00
0005433289967	9822	Economy	27900.00
0005434735741	9822	Economy	27900.00
0005434551576	9822	Economy	27900.00
0005434551639	9822	Economy	27900.00
0005434726498	9822	Economy	27900.00
0005433235246	9822	Economy	27900.00
0005433289964	9822	Economy	27900.00
0005433766704	9822	Economy	27900.00
0005433181512	9822	Economy	27900.00
0005434551601	9822	Economy	27900.00
0005433181526	9822	Economy	27900.00
0005434551756	9822	Economy	27900.00
0005435213999	7759	Business	42100.00
0005432530130	7759	Business	42100.00
0005432530170	7759	Business	42100.00
0005434068720	7759	Business	42100.00
0005435214048	7759	Business	42100.00
0005432530161	7759	Business	42100.00
0005435214125	7759	Business	42100.00
0005434068704	7759	Business	42100.00
0005434068737	7759	Business	42100.00
0005432530091	7759	Business	42100.00
0005432530078	7759	Business	42100.00
0005435213818	7759	Business	42100.00
0005432530075	7759	Business	42100.00
0005432530106	7759	Business	42100.00
0005434068759	7759	Business	42100.00
0005434068762	7759	Business	42100.00
0005435213987	7759	Business	42100.00
0005432530085	7759	Business	42100.00
0005432530156	7759	Business	42100.00
0005432150320	7759	Business	42100.00
0005434068755	7759	Business	42100.00
0005432069889	7759	Business	42100.00
0005435214104	7759	Business	42100.00
0005435214027	7759	Business	42100.00
0005432530070	7759	Business	42100.00
0005432530168	7759	Business	42100.00
0005432069893	7759	Comfort	23900.00
0005432530181	7759	Comfort	23900.00
0005432530088	7759	Comfort	23900.00
0005434068742	7759	Comfort	23900.00
0005434068706	7759	Comfort	23900.00
0005432530068	7759	Comfort	23900.00
0005434068728	7759	Comfort	23900.00
0005432530099	7759	Comfort	23900.00
0005432530157	7759	Comfort	23900.00
0005435214018	7759	Comfort	23900.00
0005435725620	7759	Comfort	23900.00
0005434068753	7759	Comfort	23900.00
0005432530182	7759	Comfort	23900.00
0005434068747	7759	Comfort	23900.00
0005432530081	7759	Comfort	23900.00
0005432530179	7759	Comfort	23900.00
0005435214126	7759	Comfort	23900.00
0005434068736	7759	Comfort	23900.00
0005434068692	7759	Comfort	23900.00
0005434068734	7759	Comfort	23900.00
0005432530086	7759	Comfort	23900.00
0005434068711	7759	Comfort	23900.00
0005432530061	7759	Comfort	23900.00
0005435214194	7759	Comfort	23900.00
0005434068744	7759	Comfort	23900.00
0005435213673	7759	Comfort	23900.00
0005435214009	7759	Comfort	23900.00
0005432530094	7759	Comfort	23900.00
0005435630997	7759	Comfort	23900.00
0005435213814	7759	Comfort	23900.00
0005434068693	7759	Comfort	23900.00
0005434068750	7759	Comfort	23900.00
0005435213957	7759	Comfort	23900.00
0005432530074	7759	Comfort	23900.00
0005432530138	7759	Comfort	23900.00
0005435214407	7759	Comfort	23900.00
0005432530109	7759	Comfort	23900.00
0005435214383	7759	Comfort	23900.00
0005432530177	7759	Comfort	23900.00
0005432530195	7759	Comfort	23900.00
0005435214332	7759	Comfort	23900.00
0005432150323	7759	Comfort	23900.00
0005432530184	7759	Comfort	23900.00
0005435214068	7759	Comfort	23900.00
0005432530155	7759	Comfort	23900.00
0005432069890	7759	Comfort	23900.00
0005432150321	7759	Economy	14000.00
0005435213759	7759	Economy	14000.00
0005435213945	7759	Economy	14000.00
0005432530108	7759	Economy	14000.00
0005435214042	7759	Economy	14000.00
0005435213982	7759	Economy	14000.00
0005432069894	7759	Economy	14000.00
0005432530113	7759	Economy	14000.00
0005432530185	7759	Economy	14000.00
0005432530141	7759	Economy	14000.00
0005435630996	7759	Economy	14000.00
0005435214149	7759	Economy	14000.00
0005434068740	7759	Economy	14000.00
0005432530064	7759	Economy	14000.00
0005432530079	7759	Economy	14000.00
0005432530069	7759	Economy	14000.00
0005432530171	7759	Economy	14000.00
0005432530133	7759	Economy	14000.00
0005432069895	7759	Economy	14000.00
0005432150326	7759	Economy	14000.00
0005434068726	7759	Economy	14000.00
0005434068696	7759	Economy	14000.00
0005434068722	7759	Economy	14000.00
0005435630980	7759	Economy	14000.00
0005432530183	7759	Economy	14000.00
0005432530142	7759	Economy	14000.00
0005434068752	7759	Economy	14000.00
0005435213965	7759	Economy	14000.00
0005434068714	7759	Economy	14000.00
0005432530152	7759	Economy	14000.00
0005432530098	7759	Economy	14000.00
0005435213831	7759	Economy	14000.00
0005434068729	7759	Economy	14000.00
0005435214075	7759	Economy	14000.00
0005435213943	7759	Economy	14000.00
0005434068694	7759	Economy	14000.00
0005434068695	7759	Economy	14000.00
0005432428983	7759	Economy	14000.00
0005432530150	7759	Economy	14000.00
0005432069896	7759	Economy	14000.00
0005434068763	7759	Economy	14000.00
0005432530140	7759	Economy	14000.00
0005432530146	7759	Economy	14000.00
0005432530137	7759	Economy	14000.00
0005432530148	7759	Economy	14000.00
0005432535914	7759	Economy	14000.00
0005432530153	7759	Economy	14000.00
0005435213830	7759	Economy	14000.00
0005432530124	7759	Economy	14000.00
0005432150325	7759	Economy	14000.00
0005432530121	7759	Economy	14000.00
0005432530067	7759	Economy	14000.00
0005434068725	7759	Economy	14000.00
0005434068756	7759	Economy	14000.00
0005432530163	7759	Economy	14000.00
0005432530151	7759	Economy	14000.00
0005434068745	7759	Economy	14000.00
0005435214115	7759	Economy	14000.00
0005435214290	7759	Economy	14000.00
0005435213877	7759	Economy	14000.00
0005434068738	7759	Economy	14000.00
0005434068713	7759	Economy	14000.00
0005434068758	7759	Economy	14000.00
0005435213904	7759	Economy	14000.00
0005435213674	7759	Economy	15400.00
0005435630994	7759	Economy	14000.00
0005432150327	7759	Economy	15400.00
0005435214028	7759	Economy	14000.00
0005435213989	7759	Economy	14000.00
0005432537094	7759	Economy	14000.00
0005432533340	7759	Economy	15400.00
0005435213817	7759	Economy	14000.00
0005432530104	7759	Economy	14000.00
0005432530131	7759	Economy	14000.00
0005432530065	7759	Economy	14000.00
0005432530186	7759	Economy	14000.00
0005432069900	7759	Economy	14000.00
0005434068697	7759	Economy	14000.00
0005434068746	7759	Economy	14000.00
0005432069898	7759	Economy	14000.00
0005432530084	7759	Economy	14000.00
0005432530102	7759	Economy	14000.00
0005432530125	7759	Economy	14000.00
0005433656691	7759	Economy	14000.00
0005432530144	7759	Economy	14000.00
0005432530115	7759	Economy	14000.00
0005432530165	7759	Economy	14000.00
0005432537092	7759	Economy	14000.00
0005435214184	7759	Economy	14000.00
0005434068708	7759	Economy	14000.00
0005432530178	7759	Economy	14000.00
0005434068761	7759	Economy	14000.00
0005432535912	7759	Economy	14000.00
0005432530123	7759	Economy	14000.00
0005435214001	7759	Economy	14000.00
0005432530132	7759	Economy	14000.00
0005432530072	7759	Economy	14000.00
0005432069891	7759	Economy	14000.00
0005432530097	7759	Economy	14000.00
0005435214136	7759	Economy	14000.00
0005435214137	7759	Economy	14000.00
0005432530149	7759	Economy	14000.00
0005434068701	7759	Economy	14000.00
0005432530120	7759	Economy	14000.00
0005435630979	7759	Economy	14000.00
0005434068723	7759	Economy	14000.00
0005432530136	7759	Economy	14000.00
0005434068748	7759	Economy	14000.00
0005435214025	7759	Economy	14000.00
0005435725622	7759	Economy	14000.00
0005432530087	7759	Economy	14000.00
0005435214382	7759	Economy	14000.00
0005432530110	7759	Economy	14000.00
0005432530114	7759	Economy	14000.00
0005435283409	7759	Economy	14000.00
0005435214067	7759	Economy	14000.00
0005435214071	7759	Economy	14000.00
0005432530073	7759	Economy	14000.00
0005434068760	7759	Economy	14000.00
0005434068724	7759	Economy	14000.00
0005432150322	7759	Economy	14000.00
0005432530166	7759	Economy	14000.00
0005432428986	7759	Economy	14000.00
0005432530117	7759	Economy	14000.00
0005435214010	7759	Economy	14000.00
0005432530083	7759	Economy	14000.00
0005432530194	7759	Economy	14000.00
0005434068732	7759	Economy	14000.00
0005434068699	7759	Economy	14000.00
0005432530077	7759	Economy	14000.00
0005432530126	7759	Economy	14000.00
0005435214291	7759	Economy	14000.00
0005432530128	7759	Economy	14000.00
0005434068719	7759	Economy	14000.00
0005432535915	7759	Economy	14000.00
0005434068700	7759	Economy	14000.00
0005435214183	7759	Economy	14000.00
0005435214334	7759	Economy	14000.00
0005435214254	7759	Economy	14000.00
0005435725619	7759	Economy	14000.00
0005435214262	7759	Economy	14000.00
0005432530175	7759	Economy	14000.00
0005434068733	7759	Economy	14000.00
0005435214321	7759	Economy	14000.00
0005432530162	7759	Economy	14000.00
0005435214255	7759	Economy	14000.00
0005432533339	7759	Economy	14000.00
0005432530180	7759	Economy	14000.00
0005432530172	7759	Economy	14000.00
0005432530071	7759	Economy	14000.00
0005435213981	7759	Economy	14000.00
0005435213988	7759	Economy	14000.00
0005435214000	7759	Economy	14000.00
0005432530095	7759	Economy	14000.00
0005432533338	7759	Economy	14000.00
0005432530089	7759	Economy	14000.00
0005432428985	7759	Economy	14000.00
0005435214049	7759	Economy	14000.00
0005432535913	7759	Economy	14000.00
0005434068754	7759	Economy	14000.00
0005432530158	7759	Economy	14000.00
0005434068715	7759	Economy	14000.00
0005434068749	7759	Economy	14000.00
0005432530193	7759	Economy	14000.00
0005435214384	7759	Economy	14000.00
0005434068731	7759	Economy	14000.00
0005432530062	7759	Economy	14000.00
0005432150324	7759	Economy	14000.00
0005432530164	7759	Economy	14000.00
0005435214008	7759	Economy	15400.00
0005432537093	7759	Economy	15400.00
0005432530191	7759	Economy	15400.00
0005435213944	7759	Economy	15400.00
0005432530100	7759	Economy	15400.00
0005432069899	7759	Economy	14000.00
0005434068743	7759	Economy	14000.00
0005432530119	7759	Economy	14000.00
0005432530066	7759	Economy	14000.00
0005435214039	7759	Economy	14000.00
0005432530154	7759	Economy	14000.00
0005433656694	7759	Economy	14000.00
0005432530160	7759	Economy	14000.00
0005435213959	7759	Economy	14000.00
0005434068717	7759	Economy	14000.00
0005432530080	7759	Economy	14000.00
0005432530176	7759	Economy	14000.00
0005432530096	7759	Economy	14000.00
0005435725621	7759	Economy	14000.00
0005435630986	7759	Economy	14000.00
0005434068741	7759	Economy	14000.00
0005434068735	7759	Economy	14000.00
0005434068709	7759	Economy	14000.00
0005435214023	7759	Economy	14000.00
0005435725626	7759	Economy	14000.00
0005432530188	7759	Economy	14000.00
0005435214138	7759	Economy	14000.00
0005432069887	7759	Economy	14000.00
0005434068739	7759	Economy	14000.00
0005434068702	7759	Economy	14000.00
0005435214134	7759	Economy	14000.00
0005435213946	7759	Economy	14000.00
0005432530129	7759	Economy	14000.00
0005434068730	7759	Economy	14000.00
0005435214333	7759	Economy	14000.00
0005432530143	7759	Economy	14000.00
0005434068712	7759	Economy	14000.00
0005432530139	7759	Economy	14000.00
0005432530107	7759	Economy	14000.00
0005434068710	7759	Economy	14000.00
0005435725623	7759	Economy	14000.00
0005432530147	7759	Economy	14000.00
0005435213947	7759	Economy	14000.00
0005432530122	7759	Economy	14000.00
0005432530092	7759	Economy	14000.00
0005434068718	7759	Economy	14000.00
0005434068705	7759	Economy	14000.00
0005435214182	7759	Economy	14000.00
0005432530063	7759	Economy	14000.00
0005432530134	7759	Economy	14000.00
0005435214045	7759	Economy	14000.00
0005434068727	7759	Economy	14000.00
0005434068721	7759	Economy	14000.00
0005435213958	7759	Economy	14000.00
0005435214151	7759	Economy	14000.00
0005432530187	7759	Economy	14000.00
0005432530192	7759	Economy	14000.00
0005435213931	7759	Economy	14000.00
0005432530118	7759	Economy	14000.00
0005432530076	7759	Economy	14000.00
0005432530090	7759	Economy	14000.00
0005432428984	7759	Economy	14000.00
0005432530116	7759	Economy	14000.00
0005432530159	7759	Economy	14000.00
0005432069888	7759	Economy	14000.00
0005432530111	7759	Economy	14000.00
0005432530145	7759	Economy	14000.00
0005435214060	7759	Economy	14000.00
0005432535911	7759	Economy	14000.00
0005432530093	7759	Economy	14000.00
0005432530101	7759	Economy	14000.00
0005432530127	7759	Economy	14000.00
0005432069892	7759	Economy	14000.00
0005432530190	7759	Economy	14000.00
0005435214050	7759	Economy	14000.00
0005432069897	7759	Economy	14000.00
0005432530167	7759	Economy	14000.00
0005435283410	7759	Economy	14000.00
0005434068716	7759	Economy	14000.00
0005435214069	7759	Economy	14000.00
0005434068757	7759	Economy	14000.00
0005432530169	7759	Economy	14000.00
0005435725624	7759	Economy	14000.00
0005432530103	7759	Economy	14000.00
0005434068707	7759	Economy	14000.00
0005432530174	7759	Economy	14000.00
0005434068703	7759	Economy	14000.00
0005434068691	7759	Economy	14000.00
0005432069901	7759	Economy	14000.00
0005432530135	7759	Economy	14000.00
0005432530112	7759	Economy	14000.00
0005434068751	7759	Economy	14000.00
0005432530173	7759	Economy	14000.00
0005432530189	7759	Economy	14000.00
0005435213996	7759	Economy	14000.00
0005432530105	7759	Economy	14000.00
0005432530082	7759	Economy	14000.00
0005435214135	7759	Economy	14000.00
0005435725625	7759	Economy	14000.00
0005434068698	7759	Economy	14000.00
0005435425495	5347	Business	43100.00
0005435615554	5347	Business	43100.00
0005435490287	5347	Business	43100.00
0005435302238	5347	Business	43100.00
0005435319635	5347	Business	43100.00
0005435425431	5347	Business	43100.00
0005435615468	5347	Business	43100.00
0005435615530	5347	Business	43100.00
0005435425550	5347	Business	43100.00
0005435615476	5347	Business	43100.00
0005435615456	5347	Business	43100.00
0005435425598	5347	Business	43100.00
0005434344783	5347	Business	43100.00
0005435425593	5347	Business	43100.00
0005435615528	5347	Business	43100.00
0005435615464	5347	Business	43100.00
0005434245215	5347	Business	43100.00
0005434344786	5347	Business	43100.00
0005435615470	5347	Business	43100.00
0005435425531	5347	Business	43100.00
0005432133468	5347	Business	43100.00
0005434245291	5347	Business	43100.00
0005434245190	5347	Business	43100.00
0005434344814	5347	Comfort	24400.00
0005435615513	5347	Business	43100.00
0005435425529	5347	Comfort	24400.00
0005432363437	5347	Comfort	24400.00
0005435425348	5347	Comfort	24400.00
0005435425291	5347	Comfort	24400.00
0005435425204	5347	Comfort	24400.00
0005434573588	5347	Comfort	24400.00
0005434344805	5347	Comfort	24400.00
0005434245325	5347	Comfort	24400.00
0005435425514	5347	Comfort	24400.00
0005434245247	5347	Comfort	24400.00
0005434245174	5347	Comfort	24400.00
0005435615501	5347	Comfort	24400.00
0005435425280	5347	Comfort	24400.00
0005434245101	5347	Comfort	24400.00
0005435425080	5347	Comfort	24400.00
0005434344798	5347	Comfort	24400.00
0005432047611	5347	Comfort	24400.00
0005434245230	5347	Comfort	24400.00
0005435615552	5347	Comfort	24400.00
0005432133460	5347	Comfort	24400.00
0005435615480	5347	Comfort	24400.00
0005435615523	5347	Comfort	24400.00
0005434344815	5347	Comfort	24400.00
0005432363442	5347	Comfort	24400.00
0005435615465	5347	Comfort	24400.00
0005435425081	5347	Comfort	24400.00
0005435319645	5347	Comfort	24400.00
0005435615504	5347	Comfort	24400.00
0005432841031	5347	Comfort	24400.00
0005435615553	5347	Comfort	24400.00
0005435615529	5347	Comfort	24400.00
0005435615454	5347	Comfort	24400.00
0005435615500	5347	Comfort	24400.00
0005435615545	5347	Comfort	24400.00
0005435425624	5347	Comfort	24400.00
0005434344816	5347	Comfort	24400.00
0005432363430	5347	Comfort	24400.00
0005435615531	5347	Comfort	24400.00
0005435615518	5347	Comfort	24400.00
0005435425322	5347	Comfort	24400.00
0005434344793	5347	Economy	14400.00
0005435425366	5347	Comfort	24400.00
0005435097366	5347	Economy	14400.00
0005435425424	5347	Economy	14400.00
0005435615475	5347	Economy	14400.00
0005435319659	5347	Economy	14400.00
0005432133467	5347	Economy	14400.00
0005433719165	5347	Economy	14400.00
0005434245326	5347	Economy	14400.00
0005435615503	5347	Economy	14400.00
0005435425613	5347	Economy	14400.00
0005435425526	5347	Economy	14400.00
0005435425645	5347	Economy	14400.00
0005432133462	5347	Economy	14400.00
0005435615507	5347	Economy	14400.00
0005435615509	5347	Economy	14400.00
0005435425481	5347	Economy	14400.00
0005435425257	5347	Economy	14400.00
0005434245100	5347	Economy	14400.00
0005432363431	5347	Economy	14400.00
0005434573582	5347	Economy	14400.00
0005434245118	5347	Economy	14400.00
0005435615481	5347	Economy	14400.00
0005434245216	5347	Economy	14400.00
0005435425440	5347	Economy	14400.00
0005435615524	5347	Economy	14400.00
0005435615517	5347	Economy	14400.00
0005435425525	5347	Economy	14400.00
0005435319637	5347	Economy	14400.00
0005434344808	5347	Economy	14400.00
0005435425341	5347	Economy	14400.00
0005435425425	5347	Economy	14400.00
0005434573590	5347	Economy	14400.00
0005435615537	5347	Economy	14400.00
0005435615491	5347	Economy	14400.00
0005434245115	5347	Economy	14400.00
0005434344804	5347	Economy	14400.00
0005435425441	5347	Economy	14400.00
0005435097370	5347	Economy	14400.00
0005434245234	5347	Economy	14400.00
0005435615548	5347	Economy	14400.00
0005435491473	5347	Economy	14400.00
0005434344818	5347	Economy	14400.00
0005435425571	5347	Economy	14400.00
0005434573584	5347	Economy	14400.00
0005435555403	5347	Economy	14400.00
0005435615467	5347	Economy	14400.00
0005435302242	5347	Economy	14400.00
0005435491474	5347	Economy	14400.00
0005432363443	5347	Economy	14400.00
0005435425687	5347	Economy	14400.00
0005432047614	5347	Economy	14400.00
0005434573580	5347	Economy	14400.00
0005435615484	5347	Economy	14400.00
0005435490288	5347	Economy	14400.00
0005435615551	5347	Economy	14400.00
0005434344799	5347	Economy	14400.00
0005435319644	5347	Economy	15800.00
0005435425717	5347	Economy	14400.00
0005434344811	5347	Economy	15800.00
0005434573585	5347	Economy	14400.00
0005435425644	5347	Economy	14400.00
0005435615508	5347	Economy	14400.00
0005434245162	5347	Economy	15800.00
0005434245083	5347	Economy	14400.00
0005434245229	5347	Economy	15800.00
0005435425276	5347	Economy	14400.00
0005435425003	5347	Economy	14400.00
0005435615557	5347	Economy	14400.00
0005432133459	5347	Economy	14400.00
0005432133456	5347	Economy	14400.00
0005434245217	5347	Economy	14400.00
0005432133454	5347	Economy	14400.00
0005435615486	5347	Economy	14400.00
0005434573586	5347	Economy	14400.00
0005435615526	5347	Economy	14400.00
0005434245316	5347	Economy	14400.00
0005435615460	5347	Economy	14400.00
0005435097367	5347	Economy	14400.00
0005434656570	5347	Economy	14400.00
0005434344795	5347	Economy	14400.00
0005435425647	5347	Economy	14400.00
0005435425314	5347	Economy	14400.00
0005435305027	5347	Economy	14400.00
0005434344809	5347	Economy	14400.00
0005435319643	5347	Economy	14400.00
0005432363429	5347	Economy	14400.00
0005435425171	5347	Economy	14400.00
0005434344794	5347	Economy	14400.00
0005435615489	5347	Economy	14400.00
0005434573583	5347	Economy	14400.00
0005435615520	5347	Economy	14400.00
0005435615555	5347	Economy	14400.00
0005435615544	5347	Economy	14400.00
0005432133453	5347	Economy	14400.00
0005435319636	5347	Economy	14400.00
0005435615533	5347	Economy	14400.00
0005434344817	5347	Economy	14400.00
0005435097368	5347	Economy	14400.00
0005435615499	5347	Economy	14400.00
0005435425377	5347	Economy	14400.00
0005434344806	5347	Economy	14400.00
0005434245119	5347	Economy	14400.00
0005434573579	5347	Economy	14400.00
0005435615477	5347	Economy	14400.00
0005434245218	5347	Economy	14400.00
0005435615490	5347	Economy	14400.00
0005435425438	5347	Economy	14400.00
0005434245150	5347	Economy	14400.00
0005434344800	5347	Economy	14400.00
0005435302237	5347	Economy	14400.00
0005434245167	5347	Economy	14400.00
0005435615455	5347	Economy	14400.00
0005432047612	5347	Economy	14400.00
0005435302244	5347	Economy	14400.00
0005434245329	5347	Economy	14400.00
0005434344782	5347	Economy	14400.00
0005434245176	5347	Economy	14400.00
0005435615453	5347	Economy	14400.00
0005435425586	5347	Economy	14400.00
0005435615525	5347	Economy	14400.00
0005435425306	5347	Economy	14400.00
0005434245175	5347	Economy	14400.00
0005432133457	5347	Economy	14400.00
0005435615514	5347	Economy	14400.00
0005435615558	5347	Economy	14400.00
0005432133466	5347	Economy	14400.00
0005435097372	5347	Economy	14400.00
0005435615493	5347	Economy	14400.00
0005434344812	5347	Economy	14400.00
0005435615466	5347	Economy	14400.00
0005435615496	5347	Economy	14400.00
0005435615540	5347	Economy	14400.00
0005435615547	5347	Economy	14400.00
0005435615546	5347	Economy	14400.00
0005432133461	5347	Economy	14400.00
0005434245248	5347	Economy	14400.00
0005432133458	5347	Economy	14400.00
0005435615536	5347	Economy	14400.00
0005434245274	5347	Economy	14400.00
0005434344802	5347	Economy	14400.00
0005435615541	5347	Economy	14400.00
0005435615487	5347	Economy	14400.00
0005435615510	5347	Economy	14400.00
0005432133463	5347	Economy	14400.00
0005435615521	5347	Economy	14400.00
0005434344803	5347	Economy	14400.00
0005435615473	5347	Economy	14400.00
0005435615538	5347	Economy	14400.00
0005434344796	5347	Economy	14400.00
0005434344813	5347	Economy	14400.00
0005432047610	5347	Economy	14400.00
0005435615539	5347	Economy	14400.00
0005435425549	5347	Economy	14400.00
0005435615532	5347	Economy	14400.00
0005435097365	5347	Economy	14400.00
0005434245201	5347	Economy	14400.00
0005435615462	5347	Economy	14400.00
0005435425386	5347	Economy	14400.00
0005434573578	5347	Economy	14400.00
0005434344797	5347	Economy	15800.00
0005434344807	5347	Economy	14400.00
0005435615505	5347	Economy	15800.00
0005434245202	5347	Economy	15800.00
0005435425548	5347	Economy	15800.00
0005435425387	5347	Economy	15800.00
0005435425272	5347	Economy	14400.00
0005434344788	5347	Economy	14400.00
0005435380329	5347	Economy	14400.00
0005434573589	5347	Economy	14400.00
0005434245090	5347	Economy	14400.00
0005433719164	5347	Economy	14400.00
0005435615474	5347	Economy	14400.00
0005434245192	5347	Economy	14400.00
0005434344810	5347	Economy	14400.00
0005434573581	5347	Economy	14400.00
0005432133464	5347	Economy	14400.00
0005435425299	5347	Economy	14400.00
0005435615461	5347	Economy	14400.00
0005435425130	5347	Economy	14400.00
0005435319629	5347	Economy	14400.00
0005432133455	5347	Economy	14400.00
0005435097369	5347	Economy	14400.00
0005435425279	5347	Economy	14400.00
0005435615498	5347	Economy	14400.00
0005435615497	5347	Economy	14400.00
0005435425310	5347	Economy	14400.00
0005434344791	5347	Economy	14400.00
0005435615494	5347	Economy	14400.00
0005435319658	5347	Economy	14400.00
0005434245141	5347	Economy	14400.00
0005434245244	5347	Economy	14400.00
0005435615458	5347	Economy	14400.00
0005435615459	5347	Economy	14400.00
0005435615469	5347	Economy	14400.00
0005432047613	5347	Economy	14400.00
0005434344785	5347	Economy	14400.00
0005435425349	5347	Economy	14400.00
0005432363434	5347	Economy	14400.00
0005435490289	5347	Economy	14400.00
0005435425612	5347	Economy	14400.00
0005432133465	5347	Economy	14400.00
0005435615463	5347	Economy	14400.00
0005435425233	5347	Economy	14400.00
0005435615479	5347	Economy	14400.00
0005434245158	5347	Economy	14400.00
0005435615535	5347	Economy	14400.00
0005435302243	5347	Economy	14400.00
0005434573591	5347	Economy	14400.00
0005435425585	5347	Economy	14400.00
0005435615506	5347	Economy	14400.00
0005435425461	5347	Economy	14400.00
0005434344790	5347	Economy	14400.00
0005435425449	5347	Economy	14400.00
0005435615483	5347	Economy	14400.00
0005435615472	5347	Economy	14400.00
0005435615511	5347	Economy	14400.00
0005435615488	5347	Economy	14400.00
0005434245155	5347	Economy	14400.00
0005435615527	5347	Economy	14400.00
0005435615550	5347	Economy	14400.00
0005434245154	5347	Economy	14400.00
0005435490290	5347	Economy	14400.00
0005435425430	5347	Economy	14400.00
0005435615549	5347	Economy	14400.00
0005435097371	5347	Economy	14400.00
0005435425256	5347	Economy	14400.00
0005435615485	5347	Economy	14400.00
0005435425416	5347	Economy	14400.00
0005435097373	5347	Economy	14400.00
0005435615502	5347	Economy	14400.00
0005435615495	5347	Economy	14400.00
0005434344792	5347	Economy	14400.00
0005435615457	5347	Economy	14400.00
0005435615522	5347	Economy	14400.00
0005435615519	5347	Economy	14400.00
0005432133452	5347	Economy	14400.00
0005435615512	5347	Economy	14400.00
0005434656569	5347	Economy	14400.00
0005435425170	5347	Economy	14400.00
0005435425530	5347	Economy	14400.00
0005435319595	5347	Economy	14400.00
0005435615543	5347	Economy	14400.00
0005434344784	5347	Economy	14400.00
0005434344801	5347	Economy	14400.00
0005435615471	5347	Economy	14400.00
0005435305034	5347	Economy	14400.00
0005434573587	5347	Economy	14400.00
0005435380333	5347	Economy	14400.00
0005432841026	5347	Economy	14400.00
0005434344789	5347	Economy	14400.00
0005435615515	5347	Economy	14400.00
0005434344819	5347	Economy	14400.00
0005435425056	5347	Economy	14400.00
0005435615556	5347	Economy	14400.00
0005435615534	5347	Economy	14400.00
0005435615478	5347	Economy	14400.00
0005435615516	5347	Economy	14400.00
0005435425439	5347	Economy	14400.00
0005434344787	5347	Economy	14400.00
0005435615482	5347	Economy	14400.00
0005435425597	5347	Economy	14400.00
0005435425494	5347	Economy	14400.00
0005435615492	5347	Economy	14400.00
0005435425336	5347	Economy	14400.00
0005435615542	5347	Economy	14400.00
0005435319720	10899	Business	43100.00
0005435425924	10899	Business	43100.00
0005435425934	10899	Business	43100.00
0005435425948	10899	Business	43100.00
0005435614748	10899	Business	43100.00
0005435614597	10899	Business	43100.00
0005435425906	10899	Business	43100.00
0005432165165	10899	Business	43100.00
0005434344421	10899	Business	43100.00
0005435097199	10899	Business	43100.00
0005435614594	10899	Business	43100.00
0005435380369	10899	Business	43100.00
0005435614711	10899	Business	43100.00
0005435425913	10899	Business	43100.00
0005435614094	10899	Business	43100.00
0005435614402	10899	Business	43100.00
0005434573364	10899	Business	43100.00
0005435614732	10899	Business	43100.00
0005435614342	10899	Business	43100.00
0005435425935	10899	Business	43100.00
0005435425956	10899	Business	43100.00
0005435425952	10899	Business	43100.00
0005432363469	10899	Business	43100.00
0005435097252	10899	Comfort	24400.00
0005435614739	10899	Business	43100.00
0005435425916	10899	Comfort	24400.00
0005435614421	10899	Comfort	24400.00
0005435614712	10899	Comfort	24400.00
0005434344415	10899	Comfort	24400.00
0005435425920	10899	Comfort	24400.00
0005435380368	10899	Comfort	24400.00
0005435614430	10899	Comfort	24400.00
0005435613885	10899	Comfort	24400.00
0005435614716	10899	Comfort	24400.00
0005435425905	10899	Comfort	24400.00
0005432165162	10899	Comfort	24400.00
0005434344314	10899	Comfort	24400.00
0005435425910	10899	Comfort	24400.00
0005432165166	10899	Comfort	24400.00
0005434573463	10899	Comfort	24400.00
0005435491459	10899	Comfort	24400.00
0005434573435	10899	Comfort	24400.00
0005435614345	10899	Comfort	24400.00
0005435319714	10899	Comfort	24400.00
0005435425960	10899	Comfort	24400.00
0005435097275	10899	Comfort	24400.00
0005435614697	10899	Comfort	24400.00
0005434245454	10899	Comfort	24400.00
0005432363470	10899	Comfort	24400.00
0005432841048	10899	Comfort	24400.00
0005432363468	10899	Comfort	24400.00
0005435319717	10899	Comfort	24400.00
0005435425970	10899	Comfort	24400.00
0005434344394	10899	Comfort	24400.00
0005435425932	10899	Comfort	24400.00
0005435491455	10899	Comfort	24400.00
0005435425925	10899	Comfort	24400.00
0005435425922	10899	Comfort	24400.00
0005435425947	10899	Comfort	24400.00
0005435614417	10899	Comfort	24400.00
0005434245476	10899	Economy	14400.00
0005435614506	10899	Economy	14400.00
0005435614681	10899	Economy	14400.00
0005434344410	10899	Economy	14400.00
0005435614269	10899	Economy	14400.00
0005434245460	10899	Economy	14400.00
0005435614380	10899	Economy	14400.00
0005435614551	10899	Economy	14400.00
0005435613873	10899	Economy	14400.00
0005434245474	10899	Economy	14400.00
0005433719197	10899	Economy	14400.00
0005435614624	10899	Economy	14400.00
0005435614413	10899	Economy	14400.00
0005435614661	10899	Economy	14400.00
0005434344425	10899	Economy	14400.00
0005435491443	10899	Economy	14400.00
0005435614744	10899	Economy	14400.00
0005434344428	10899	Economy	14400.00
0005434344427	10899	Economy	14400.00
0005432165161	10899	Economy	14400.00
0005435614471	10899	Economy	14400.00
0005434344213	10899	Economy	14400.00
0005435614453	10899	Economy	14400.00
0005435425945	10899	Economy	14400.00
0005435614693	10899	Economy	14400.00
0005435425915	10899	Economy	14400.00
0005435614725	10899	Economy	14400.00
0005435613988	10899	Economy	14400.00
0005435614433	10899	Economy	14400.00
0005435425951	10899	Economy	14400.00
0005432165159	10899	Economy	14400.00
0005435614733	10899	Economy	14400.00
0005435614717	10899	Economy	14400.00
0005434344393	10899	Economy	14400.00
0005435614043	10899	Economy	14400.00
0005434344327	10899	Economy	14400.00
0005434245458	10899	Economy	14400.00
0005435425944	10899	Economy	14400.00
0005435555374	10899	Economy	14400.00
0005435425965	10899	Economy	14400.00
0005434344290	10899	Economy	14400.00
0005435614641	10899	Economy	14400.00
0005434245464	10899	Economy	14400.00
0005435425939	10899	Economy	14400.00
0005435319715	10899	Economy	14400.00
0005435319719	10899	Economy	14400.00
0005435614202	10899	Economy	14400.00
0005434344384	10899	Economy	14400.00
0005435490246	10899	Economy	14400.00
0005434245452	10899	Economy	14400.00
0005432165164	10899	Economy	14400.00
0005435613914	10899	Economy	14400.00
0005435614643	10899	Economy	14400.00
0005435614747	10899	Economy	14400.00
0005435425907	10899	Economy	15800.00
0005434344223	10899	Economy	15800.00
0005435614552	10899	Economy	14400.00
0005434344291	10899	Economy	14400.00
0005435614709	10899	Economy	15800.00
0005435425929	10899	Economy	14400.00
0005435614802	10899	Economy	14400.00
0005435425931	10899	Economy	14400.00
0005435425936	10899	Economy	14400.00
0005434245477	10899	Economy	14400.00
0005435614199	10899	Economy	14400.00
0005435614591	10899	Economy	14400.00
0005433719196	10899	Economy	14400.00
0005432166957	10899	Economy	14400.00
0005435425903	10899	Economy	14400.00
0005435614772	10899	Economy	14400.00
0005434344395	10899	Economy	14400.00
0005434245469	10899	Economy	14400.00
0005434245472	10899	Economy	14400.00
0005432166955	10899	Economy	14400.00
0005435380373	10899	Economy	14400.00
0005435614822	10899	Economy	14400.00
0005435425946	10899	Economy	14400.00
0005435614596	10899	Economy	14400.00
0005435614688	10899	Economy	14400.00
0005434344413	10899	Economy	14400.00
0005435490247	10899	Economy	14400.00
0005434344288	10899	Economy	14400.00
0005435097248	10899	Economy	14400.00
0005435425958	10899	Economy	14400.00
0005435614278	10899	Economy	14400.00
0005434344397	10899	Economy	14400.00
0005435380371	10899	Economy	14400.00
0005434245462	10899	Economy	14400.00
0005434656589	10899	Economy	14400.00
0005434344364	10899	Economy	14400.00
0005434344292	10899	Economy	14400.00
0005435614198	10899	Economy	14400.00
0005434344381	10899	Economy	14400.00
0005435097217	10899	Economy	14400.00
0005435614466	10899	Economy	14400.00
0005435425927	10899	Economy	14400.00
0005435614207	10899	Economy	14400.00
0005435425938	10899	Economy	14400.00
0005435425949	10899	Economy	14400.00
0005435614311	10899	Economy	14400.00
0005435425953	10899	Economy	14400.00
0005435425933	10899	Economy	14400.00
0005435614200	10899	Economy	14400.00
0005435614465	10899	Economy	14400.00
0005435491446	10899	Economy	14400.00
0005435425921	10899	Economy	14400.00
0005435425969	10899	Economy	14400.00
0005435614559	10899	Economy	14400.00
0005435425941	10899	Economy	14400.00
0005435425908	10899	Economy	14400.00
0005434344409	10899	Economy	14400.00
0005435614790	10899	Economy	14400.00
0005435425967	10899	Economy	14400.00
0005435614229	10899	Economy	14400.00
0005434344356	10899	Economy	14400.00
0005434344349	10899	Economy	14400.00
0005435614419	10899	Economy	14400.00
0005435614422	10899	Economy	14400.00
0005434245471	10899	Economy	14400.00
0005435097251	10899	Economy	14400.00
0005434245459	10899	Economy	14400.00
0005434245470	10899	Economy	14400.00
0005435425955	10899	Economy	14400.00
0005435614495	10899	Economy	14400.00
0005435425966	10899	Economy	14400.00
0005432165163	10899	Economy	14400.00
0005434344293	10899	Economy	14400.00
0005434245465	10899	Economy	14400.00
0005434344442	10899	Economy	14400.00
0005434245455	10899	Economy	14400.00
0005432363471	10899	Economy	14400.00
0005435614824	10899	Economy	14400.00
0005435425961	10899	Economy	14400.00
0005435425959	10899	Economy	14400.00
0005435614346	10899	Economy	14400.00
0005435380372	10899	Economy	14400.00
0005435319722	10899	Economy	14400.00
0005434245461	10899	Economy	14400.00
0005434245450	10899	Economy	14400.00
0005435425904	10899	Economy	14400.00
0005435614203	10899	Economy	14400.00
0005435425919	10899	Economy	14400.00
0005435425963	10899	Economy	14400.00
0005434245466	10899	Economy	14400.00
0005435614208	10899	Economy	14400.00
0005435614731	10899	Economy	14400.00
0005435319721	10899	Economy	14400.00
0005435614312	10899	Economy	14400.00
0005434344453	10899	Economy	14400.00
0005432166956	10899	Economy	14400.00
0005435425930	10899	Economy	15800.00
0005434573447	10899	Economy	14400.00
0005435425968	10899	Economy	15800.00
0005434245448	10899	Economy	15800.00
0005435425957	10899	Economy	15800.00
0005435425937	10899	Economy	15800.00
0005434245467	10899	Economy	14400.00
0005435425964	10899	Economy	14400.00
0005434245449	10899	Economy	14400.00
0005434344422	10899	Economy	14400.00
0005435425911	10899	Economy	14400.00
0005435614270	10899	Economy	14400.00
0005435425971	10899	Economy	14400.00
0005434344398	10899	Economy	14400.00
0005434656588	10899	Economy	14400.00
0005433719198	10899	Economy	14400.00
0005434344313	10899	Economy	14400.00
0005434344287	10899	Economy	14400.00
0005435425928	10899	Economy	14400.00
0005434344348	10899	Economy	14400.00
0005435097216	10899	Economy	14400.00
0005434245473	10899	Economy	14400.00
0005434344426	10899	Economy	14400.00
0005435614715	10899	Economy	14400.00
0005434573458	10899	Economy	14400.00
0005434245457	10899	Economy	14400.00
0005434344224	10899	Economy	14400.00
0005435614407	10899	Economy	14400.00
0005435614423	10899	Economy	14400.00
0005434656590	10899	Economy	14400.00
0005432165160	10899	Economy	14400.00
0005432841047	10899	Economy	14400.00
0005432166953	10899	Economy	14400.00
0005434245453	10899	Economy	14400.00
0005435614593	10899	Economy	14400.00
0005435490243	10899	Economy	14400.00
0005434344357	10899	Economy	14400.00
0005434573397	10899	Economy	14400.00
0005435613904	10899	Economy	14400.00
0005435614381	10899	Economy	14400.00
0005435319718	10899	Economy	14400.00
0005435614078	10899	Economy	14400.00
0005435613872	10899	Economy	14400.00
0005435614368	10899	Economy	14400.00
0005434344408	10899	Economy	14400.00
0005435425918	10899	Economy	14400.00
0005435425923	10899	Economy	14400.00
0005435614393	10899	Economy	14400.00
0005435614505	10899	Economy	14400.00
0005435614279	10899	Economy	14400.00
0005435425926	10899	Economy	14400.00
0005435380370	10899	Economy	14400.00
0005435425950	10899	Economy	14400.00
0005434245463	10899	Economy	14400.00
0005435613852	10899	Economy	14400.00
0005435614634	10899	Economy	14400.00
0005435614204	10899	Economy	14400.00
0005435425912	10899	Economy	14400.00
0005434344214	10899	Economy	14400.00
0005435614635	10899	Economy	14400.00
0005435614341	10899	Economy	14400.00
0005435614757	10899	Economy	14400.00
0005434245456	10899	Economy	14400.00
0005434344416	10899	Economy	14400.00
0005435614073	10899	Economy	14400.00
0005435425942	10899	Economy	14400.00
0005435614685	10899	Economy	14400.00
0005435614801	10899	Economy	14400.00
0005435614543	10899	Economy	14400.00
0005434245468	10899	Economy	14400.00
0005435614418	10899	Economy	14400.00
0005434344386	10899	Economy	14400.00
0005435425954	10899	Economy	14400.00
0005435614694	10899	Economy	14400.00
0005435614690	10899	Economy	14400.00
0005435319716	10899	Economy	14400.00
0005435425943	10899	Economy	14400.00
0005435614684	10899	Economy	14400.00
0005434344414	10899	Economy	14400.00
0005435425917	10899	Economy	14400.00
0005435613884	10899	Economy	14400.00
0005432166954	10899	Economy	14400.00
0005435425909	10899	Economy	14400.00
0005435614412	10899	Economy	14400.00
0005434245451	10899	Economy	14400.00
0005435614728	10899	Economy	14400.00
0005435614528	10899	Economy	14400.00
0005435425914	10899	Economy	14400.00
0005435614570	10899	Economy	14400.00
0005434245475	10899	Economy	14400.00
0005435425940	10899	Economy	14400.00
0005435425962	10899	Economy	14400.00
0005434573446	10899	Economy	14400.00
0005434344417	10899	Economy	14400.00
0005435614714	10899	Economy	14400.00
0005435614414	10899	Economy	14400.00
0005435614660	10899	Economy	14400.00
0005433805950	3329	Business	18800.00
0005433805930	3329	Business	18800.00
0005432460198	3329	Business	18800.00
0005432460144	3329	Business	18800.00
0005433507456	3329	Business	18800.00
0005432460310	3329	Business	18800.00
0005432460212	3329	Business	18800.00
0005432460238	3329	Business	18800.00
0005433805922	3329	Business	18800.00
0005433634380	3329	Business	18800.00
0005432182088	3329	Business	18800.00
0005433634393	3329	Business	18800.00
0005433805926	3329	Business	18800.00
0005432182093	3329	Business	18800.00
0005432460381	3329	Business	18800.00
0005432460362	3329	Business	18800.00
0005433634392	3329	Business	18800.00
0005432460168	3329	Business	18800.00
0005433634366	3329	Business	18800.00
0005433805933	3329	Business	18800.00
0005433805939	3329	Business	18800.00
0005433805934	3329	Business	18800.00
0005432460298	3329	Business	18800.00
0005433634367	3329	Business	18800.00
0005432460201	3329	Business	18800.00
0005433507461	3329	Business	18800.00
0005433805944	3329	Economy	6900.00
0005432182092	3329	Business	18800.00
0005433634389	3329	Economy	6900.00
0005432460300	3329	Economy	6900.00
0005432460080	3329	Economy	6900.00
0005433507454	3329	Economy	6900.00
0005432460034	3329	Economy	6900.00
0005433634368	3329	Economy	6300.00
0005433507457	3329	Economy	6300.00
0005432459947	3329	Economy	6300.00
0005433634374	3329	Economy	6300.00
0005432460391	3329	Economy	6300.00
0005433805938	3329	Economy	6300.00
0005432182076	3329	Economy	6300.00
0005432460388	3329	Economy	6300.00
0005433634387	3329	Economy	6300.00
0005432460174	3329	Economy	6300.00
0005432460390	3329	Economy	6300.00
0005433634382	3329	Economy	6300.00
0005433634397	3329	Economy	6300.00
0005432460082	3329	Economy	6300.00
0005433634376	3329	Economy	6300.00
0005433507459	3329	Economy	6300.00
0005433805924	3329	Economy	6300.00
0005433507451	3329	Economy	6300.00
0005432460169	3329	Economy	6300.00
0005432182072	3329	Economy	6300.00
0005433805943	3329	Economy	6300.00
0005432460031	3329	Economy	6300.00
0005433634384	3329	Economy	6300.00
0005433507469	3329	Economy	6300.00
0005433805953	3329	Economy	6300.00
0005432182074	3329	Economy	6300.00
0005432460160	3329	Economy	6300.00
0005433805942	3329	Economy	6300.00
0005433805928	3329	Economy	6300.00
0005432182085	3329	Economy	6300.00
0005432182087	3329	Economy	6300.00
0005432460214	3329	Economy	6300.00
0005433805927	3329	Economy	6300.00
0005433507470	3329	Economy	6300.00
0005432460148	3329	Economy	6300.00
0005432460213	3329	Economy	6300.00
0005432460125	3329	Economy	6300.00
0005433805923	3329	Economy	6300.00
0005432460289	3329	Economy	6300.00
0005432182084	3329	Economy	6300.00
0005433634371	3329	Economy	6300.00
0005433805936	3329	Economy	6300.00
0005432460334	3329	Economy	6300.00
0005432182094	3329	Economy	6300.00
0005432460244	3329	Economy	6300.00
0005433634391	3329	Economy	6300.00
0005433634390	3329	Economy	6300.00
0005433507467	3329	Economy	6300.00
0005433507460	3329	Economy	6300.00
0005433507453	3329	Economy	6300.00
0005432460173	3329	Economy	6300.00
0005432182086	3329	Economy	6300.00
0005433634395	3329	Economy	6300.00
0005433805932	3329	Economy	6300.00
0005432460185	3329	Economy	6300.00
0005433634373	3329	Economy	6300.00
0005433507452	3329	Economy	6300.00
0005433634379	3329	Economy	6300.00
0005432460284	3329	Economy	6900.00
0005432182091	3329	Economy	6300.00
0005432182083	3329	Economy	6900.00
0005432182079	3329	Economy	6900.00
0005433507463	3329	Economy	6900.00
0005433634385	3329	Economy	6900.00
0005432182077	3329	Economy	6300.00
0005433507458	3329	Economy	6300.00
0005432460242	3329	Economy	6300.00
0005432460220	3329	Economy	6300.00
0005433805937	3329	Economy	6900.00
0005433634399	3329	Economy	6300.00
0005432460272	3329	Economy	6300.00
0005433507468	3329	Economy	6300.00
0005433805949	3329	Economy	6300.00
0005432460255	3329	Economy	6300.00
0005432182081	3329	Economy	6300.00
0005433805940	3329	Economy	6300.00
0005433634377	3329	Economy	6300.00
0005432460293	3329	Economy	6300.00
0005432460383	3329	Economy	6300.00
0005432460361	3329	Economy	6300.00
0005433805941	3329	Economy	6300.00
0005433805951	3329	Economy	6300.00
0005432460285	3329	Economy	6300.00
0005432460126	3329	Economy	6300.00
0005433805954	3329	Economy	6300.00
0005433805929	3329	Economy	6300.00
0005433805948	3329	Economy	6300.00
0005433634372	3329	Economy	6300.00
0005433805925	3329	Economy	6300.00
0005432460152	3329	Economy	6300.00
0005432182078	3329	Economy	6300.00
0005433634383	3329	Economy	6300.00
0005432460389	3329	Economy	6300.00
0005433507465	3329	Economy	6300.00
0005433507455	3329	Economy	6300.00
0005433507466	3329	Economy	6300.00
0005433634398	3329	Economy	6300.00
0005433634388	3329	Economy	6300.00
0005432460186	3329	Economy	6300.00
0005432182090	3329	Economy	6300.00
0005432182089	3329	Economy	6300.00
0005433805935	3329	Economy	6300.00
0005433805945	3329	Economy	6300.00
0005432460017	3329	Economy	6300.00
0005433634370	3329	Economy	6300.00
0005433634369	3329	Economy	6300.00
0005433634386	3329	Economy	6300.00
0005432182080	3329	Economy	6300.00
0005433805947	3329	Economy	6300.00
0005433634394	3329	Economy	6300.00
0005432460239	3329	Economy	6300.00
0005432460309	3329	Economy	6300.00
0005433805955	3329	Economy	6300.00
0005432182075	3329	Economy	6300.00
0005432460286	3329	Economy	6300.00
0005432460396	3329	Economy	6300.00
0005432460063	3329	Economy	6300.00
0005432460252	3329	Economy	6300.00
0005432182073	3329	Economy	6300.00
0005433634378	3329	Economy	6300.00
0005433507462	3329	Economy	6300.00
0005432460297	3329	Economy	6300.00
0005432182082	3329	Economy	6300.00
0005433634365	3329	Economy	6300.00
0005432460294	3329	Economy	6300.00
0005433805952	3329	Economy	6300.00
0005433507464	3329	Economy	6300.00
0005433805946	3329	Economy	6300.00
0005433805931	3329	Economy	6300.00
0005432460079	3329	Economy	6300.00
0005432460245	3329	Economy	6300.00
0005433634381	3329	Economy	6300.00
0005433634375	3329	Economy	6300.00
0005433634396	3329	Economy	6300.00
0005435885726	3330	Business	18800.00
0005435885813	3330	Business	18800.00
0005435885375	3330	Business	18800.00
0005435885881	3330	Business	18800.00
0005435885561	3330	Business	18800.00
0005435885780	3330	Business	18800.00
0005435885917	3330	Business	18800.00
0005435885466	3330	Business	18800.00
0005435885783	3330	Business	18800.00
0005435885643	3330	Business	18800.00
0005435885784	3330	Economy	6900.00
0005435885574	3330	Economy	6900.00
0005435885392	3330	Economy	6900.00
0005435885486	3330	Economy	6300.00
0005435885781	3330	Economy	6300.00
0005435885764	3330	Economy	6300.00
0005435885566	3330	Economy	6300.00
0005435885765	3330	Economy	6300.00
0005435885673	3330	Economy	6300.00
0005435885562	3330	Economy	6300.00
0005435885692	3330	Economy	6300.00
0005435885693	3330	Economy	6300.00
0005435885915	3330	Economy	6300.00
0005435885912	3330	Economy	6300.00
0005435885760	3330	Economy	6300.00
0005435885583	3330	Economy	6300.00
0005435885703	3330	Economy	6300.00
0005435885642	3330	Economy	6300.00
0005435885761	3330	Economy	6300.00
0005435885916	3330	Economy	6900.00
0005435885421	3330	Economy	6300.00
0005435885596	3330	Economy	6300.00
0005435885723	3330	Economy	6300.00
0005435885588	3330	Economy	6300.00
0005435885599	3330	Economy	6300.00
0005435885540	3330	Economy	6300.00
0005435885510	3330	Economy	6300.00
0005435885595	3330	Economy	6300.00
0005435885694	3330	Economy	6300.00
0005435885698	3330	Economy	6300.00
0005435885913	3330	Economy	6300.00
0005435885708	3330	Economy	6300.00
0005435885812	3330	Economy	6300.00
0005435885679	3330	Economy	6300.00
0005435885782	3330	Economy	6300.00
0005435885882	3330	Economy	6300.00
0005435885487	3330	Economy	6300.00
0005435885430	3330	Economy	6300.00
0005435885509	3330	Economy	6300.00
0005435885695	3330	Economy	6300.00
0005435885541	3330	Economy	6300.00
0005435885690	3330	Economy	6300.00
0005435885678	3330	Economy	6300.00
0005435885600	3330	Economy	6300.00
0005435885722	3330	Economy	6300.00
0005435885488	3330	Economy	6300.00
0005435885533	3330	Economy	6300.00
0005435885707	3330	Economy	6300.00
0005435885680	3330	Economy	6300.00
0005432042950	8342	Business	18800.00
0005432460755	8342	Business	18800.00
0005432042943	8342	Business	18800.00
0005432460738	8342	Business	18800.00
0005435886055	8342	Business	18800.00
0005433507338	8342	Business	18800.00
0005432042941	8342	Business	18800.00
0005432460754	8342	Business	18800.00
0005435886078	8342	Business	18800.00
0005432460723	8342	Business	18800.00
0005432460740	8342	Business	18800.00
0005432460759	8342	Business	18800.00
0005432042948	8342	Business	18800.00
0005435886017	8342	Business	18800.00
0005435886023	8342	Business	18800.00
0005433507289	8342	Business	18800.00
0005432460762	8342	Business	18800.00
0005433507337	8342	Business	18800.00
0005433507321	8342	Business	18800.00
0005435886030	8342	Business	18800.00
0005433507290	8342	Business	18800.00
0005432460752	8342	Business	18800.00
0005432042939	8342	Business	18800.00
0005432460721	8342	Business	18800.00
0005432042949	8342	Business	18800.00
0005432460726	8342	Business	18800.00
0005432460745	8342	Economy	6900.00
0005432042940	8342	Economy	6900.00
0005432042942	8342	Economy	6900.00
0005432042944	8342	Economy	6900.00
0005432460744	8342	Economy	6900.00
0005432460741	8342	Economy	6300.00
0005435886080	8342	Economy	6300.00
0005433507320	8342	Economy	6300.00
0005435886068	8342	Economy	6300.00
0005433507242	8342	Economy	6300.00
0005432460743	8342	Economy	6300.00
0005435886058	8342	Economy	6300.00
0005432460765	8342	Economy	6300.00
0005432042938	8342	Economy	6300.00
0005435886073	8342	Economy	6300.00
0005435886069	8342	Economy	6300.00
0005435886071	8342	Economy	6300.00
0005435886045	8342	Economy	6300.00
0005435886050	8342	Economy	6300.00
0005435886034	8342	Economy	6300.00
0005432460760	8342	Economy	6300.00
0005435886053	8342	Economy	6300.00
0005432460764	8342	Economy	6300.00
0005435886061	8342	Economy	6300.00
0005435886079	8342	Economy	6300.00
0005435886035	8342	Economy	6300.00
0005432460767	8342	Economy	6300.00
0005435886042	8342	Economy	6300.00
0005432460758	8342	Economy	6300.00
0005435886026	8342	Economy	6300.00
0005435886041	8342	Economy	6300.00
0005432460730	8342	Economy	6300.00
0005435886028	8342	Economy	6300.00
0005435886074	8342	Economy	6300.00
0005435886048	8342	Economy	6300.00
0005432042951	8342	Economy	6300.00
0005435886059	8342	Economy	6300.00
0005435886054	8342	Economy	6300.00
0005435886060	8342	Economy	6300.00
0005432460724	8342	Economy	6300.00
0005435886040	8342	Economy	6300.00
0005432460746	8342	Economy	6300.00
0005433507241	8342	Economy	6300.00
0005435886021	8342	Economy	6300.00
0005435886025	8342	Economy	6300.00
0005433507218	8342	Economy	6300.00
0005435886077	8342	Economy	6300.00
0005433507329	8342	Economy	6300.00
0005432460722	8342	Economy	6300.00
0005432460766	8342	Economy	6300.00
0005435886043	8342	Economy	6300.00
0005432460771	8342	Economy	6300.00
0005432460735	8342	Economy	6300.00
0005435886072	8342	Economy	6300.00
0005432460731	8342	Economy	6300.00
0005432460768	8342	Economy	6300.00
0005435886033	8342	Economy	6300.00
0005435886047	8342	Economy	6300.00
0005435886052	8342	Economy	6300.00
0005435886067	8342	Economy	6300.00
0005432460733	8342	Economy	6300.00
0005435886066	8342	Economy	6900.00
0005433507336	8342	Economy	6900.00
0005432460742	8342	Economy	6900.00
0005432460748	8342	Economy	6900.00
0005435886051	8342	Economy	6300.00
0005435886036	8342	Economy	6300.00
0005435886022	8342	Economy	6900.00
0005432460739	8342	Economy	6300.00
0005435886062	8342	Economy	6300.00
0005433507380	8342	Economy	6300.00
0005434312355	8342	Economy	6300.00
0005435886032	8342	Economy	6300.00
0005432460750	8342	Economy	6300.00
0005435886039	8342	Economy	6300.00
0005432460751	8342	Economy	6300.00
0005434312354	8342	Economy	6300.00
0005435886046	8342	Economy	6300.00
0005435886020	8342	Economy	6300.00
0005433507324	8342	Economy	6300.00
0005433507370	8342	Economy	6300.00
0005432460719	8342	Economy	6300.00
0005435886063	8342	Economy	6300.00
0005435886019	8342	Economy	6300.00
0005432460720	8342	Economy	6300.00
0005432460732	8342	Economy	6300.00
0005435886029	8342	Economy	6300.00
0005435886065	8342	Economy	6300.00
0005432460769	8342	Economy	6300.00
0005432460725	8342	Economy	6300.00
0005432460772	8342	Economy	6300.00
0005432460770	8342	Economy	6300.00
0005432460757	8342	Economy	6300.00
0005432460749	8342	Economy	6300.00
0005435886076	8342	Economy	6300.00
0005432460763	8342	Economy	6300.00
0005432460756	8342	Economy	6300.00
0005435886027	8342	Economy	6300.00
0005432460761	8342	Economy	6300.00
0005432460727	8342	Economy	6300.00
0005435886070	8342	Economy	6300.00
0005435886024	8342	Economy	6300.00
0005432460729	8342	Economy	6300.00
0005435886057	8342	Economy	6300.00
0005432460747	8342	Economy	6300.00
0005432460737	8342	Economy	6300.00
0005433507267	8342	Economy	6300.00
0005432042945	8342	Economy	6300.00
0005432460736	8342	Economy	6300.00
0005435886031	8342	Economy	6300.00
0005435886064	8342	Economy	6300.00
0005432460734	8342	Economy	6300.00
0005432042947	8342	Economy	6300.00
0005432460728	8342	Economy	6300.00
0005435886044	8342	Economy	6300.00
0005435886038	8342	Economy	6300.00
0005435886075	8342	Economy	6300.00
0005432460753	8342	Economy	6300.00
0005435886037	8342	Economy	6300.00
0005435886049	8342	Economy	6300.00
0005435886056	8342	Economy	6300.00
0005432042946	8342	Economy	6300.00
0005435886018	8342	Economy	6300.00
0005433634075	8343	Business	18800.00
0005433634052	8343	Business	18800.00
0005433805666	8343	Business	18800.00
0005433805739	8343	Business	18800.00
0005433634140	8343	Business	18800.00
0005433805704	8343	Business	18800.00
0005434271330	8343	Business	18800.00
0005433634151	8343	Business	18800.00
0005433633983	8343	Business	18800.00
0005433805706	8343	Business	18800.00
0005433634102	8343	Business	18800.00
0005433633968	8343	Business	18800.00
0005433633943	8343	Business	18800.00
0005433634149	8343	Business	18800.00
0005433634169	8343	Business	18800.00
0005433634088	8343	Economy	6900.00
0005433634247	8343	Economy	6900.00
0005433805796	8343	Economy	6900.00
0005433634040	8343	Economy	6900.00
0005433633938	8343	Economy	6300.00
0005433805665	8343	Economy	6300.00
0005433633895	8343	Economy	6300.00
0005433805727	8343	Economy	6300.00
0005433805530	8343	Economy	6300.00
0005433805636	8343	Economy	6300.00
0005434271329	8343	Economy	6300.00
0005433633896	8343	Economy	6300.00
0005433634024	8343	Economy	6300.00
0005434271324	8343	Economy	6300.00
0005433634082	8343	Economy	6300.00
0005433633909	8343	Economy	6300.00
0005434143743	8343	Economy	6300.00
0005433634053	8343	Economy	6300.00
0005433634023	8343	Economy	6300.00
0005433805647	8343	Economy	6300.00
0005433634018	8343	Economy	6300.00
0005433634019	8343	Economy	6300.00
0005433805552	8343	Economy	6300.00
0005433634063	8343	Economy	6300.00
0005433805697	8343	Economy	6300.00
0005433634150	8343	Economy	6300.00
0005433805480	8343	Economy	6300.00
0005433805797	8343	Economy	6300.00
0005433805668	8343	Economy	6300.00
0005433634041	8343	Economy	6300.00
0005433634233	8343	Economy	6900.00
0005433634127	8343	Economy	6900.00
0005433634002	8343	Economy	6300.00
0005433633908	8343	Economy	6300.00
0005433805574	8343	Economy	6300.00
0005433634133	8343	Economy	6300.00
0005433634022	8343	Economy	6300.00
0005433805477	8343	Economy	6300.00
0005433805667	8343	Economy	6300.00
0005433634005	8343	Economy	6300.00
0005433805728	8343	Economy	6300.00
0005433634057	8343	Economy	6300.00
0005433805718	8343	Economy	6300.00
0005433805635	8343	Economy	6300.00
0005433805691	8343	Economy	6300.00
0005433805612	8343	Economy	6300.00
0005433805674	8343	Economy	6300.00
0005433634120	8343	Economy	6300.00
0005433634070	8343	Economy	6300.00
0005433634031	8343	Economy	6300.00
0005433805618	8343	Economy	6300.00
0005433634213	8343	Economy	6300.00
0005433805629	8343	Economy	6300.00
0005433633937	8343	Economy	6300.00
0005433805705	8343	Economy	6300.00
0005433634134	8343	Economy	6300.00
0005433805769	8343	Economy	6300.00
0005433722336	4623	Business	9900.00
0005433453795	4623	Business	9900.00
0005432383815	4623	Business	9900.00
0005432383809	4623	Business	9900.00
0005432383796	4623	Business	9900.00
0005432383812	4623	Business	9900.00
0005432728146	4623	Economy	3300.00
0005433454910	4623	Economy	3300.00
0005432383811	4623	Economy	3300.00
0005432728140	4623	Economy	3300.00
0005432383808	4623	Economy	3300.00
0005432383804	4623	Economy	3300.00
0005433722335	4623	Economy	3600.00
0005432383817	4623	Economy	3600.00
0005432728144	4623	Economy	3600.00
0005432383821	4623	Economy	3600.00
0005432383818	4623	Economy	3300.00
0005432383831	4623	Economy	3300.00
0005432383816	4623	Economy	3300.00
0005432383797	4623	Economy	3300.00
0005432383826	4623	Economy	3300.00
0005432383828	4623	Economy	3300.00
0005432383820	4623	Economy	3300.00
0005432383795	4623	Economy	3300.00
0005432383800	4623	Economy	3300.00
0005432728141	4623	Economy	3300.00
0005432383814	4623	Economy	3300.00
0005432383813	4623	Economy	3300.00
0005432383805	4623	Economy	3300.00
0005432383823	4623	Economy	3300.00
0005432383792	4623	Economy	3300.00
0005432383801	4623	Economy	3300.00
0005432728149	4623	Economy	3300.00
0005432728139	4623	Economy	3300.00
0005432728142	4623	Economy	3300.00
0005433722330	4623	Economy	3300.00
0005432383798	4623	Economy	3300.00
0005433194899	4623	Economy	3300.00
0005433453794	4623	Economy	3300.00
0005432383824	4623	Economy	3300.00
0005433722332	4623	Economy	3300.00
0005433722334	4623	Economy	3300.00
0005432383822	4623	Economy	3300.00
0005432728145	4623	Economy	3300.00
0005432728147	4623	Economy	3300.00
0005432383799	4623	Economy	3300.00
0005432383803	4623	Economy	3300.00
0005433722333	4623	Economy	3300.00
0005432383793	4623	Economy	3300.00
0005432383802	4623	Economy	3300.00
0005432728148	4623	Economy	3300.00
0005432728138	4623	Economy	3300.00
0005432383827	4623	Economy	3300.00
0005433722331	4623	Economy	3300.00
0005432383807	4623	Economy	3300.00
0005432383830	4623	Economy	3300.00
0005432383806	4623	Economy	3300.00
0005432728150	4623	Economy	3300.00
0005432383829	4623	Economy	3300.00
0005433454911	4623	Economy	3300.00
0005432383825	4623	Economy	3300.00
0005432383810	4623	Economy	3300.00
0005432383794	4623	Economy	3300.00
0005432383819	4623	Economy	3300.00
0005432728143	4623	Economy	3300.00
0005433194898	4623	Economy	3300.00
0005432383413	30113	Business	9900.00
0005432383281	30113	Business	9900.00
0005433722260	30113	Business	9900.00
0005432383374	30113	Business	9900.00
0005432383535	30113	Business	9900.00
0005432728031	30113	Business	9900.00
0005432383517	30113	Business	9900.00
0005432383299	30113	Business	9900.00
0005432383334	30113	Business	9900.00
0005433722248	30113	Business	9900.00
0005432383471	30113	Economy	3300.00
0005432728032	30113	Economy	3300.00
0005432383212	30113	Economy	3300.00
0005432383455	30113	Economy	3300.00
0005432383394	30113	Economy	3300.00
0005433194864	30113	Economy	3300.00
0005432383378	30113	Economy	3300.00
0005432383247	30113	Economy	3300.00
0005432383405	30113	Economy	3600.00
0005432383369	30113	Economy	3600.00
0005432383210	30113	Economy	3600.00
0005432383456	30113	Economy	3600.00
0005433453780	30113	Economy	3300.00
0005432728036	30113	Economy	3300.00
0005433194876	30113	Economy	3300.00
0005432383419	30113	Economy	3300.00
0005432383420	30113	Economy	3300.00
0005432383352	30113	Economy	3300.00
0005433722247	30113	Economy	3300.00
0005432383347	30113	Economy	3300.00
0005432728030	30113	Economy	3300.00
0005432383304	30113	Economy	3300.00
0005432383466	30113	Economy	3300.00
0005432728013	30113	Economy	3300.00
0005432728034	30113	Economy	3300.00
0005432383406	30113	Economy	3300.00
0005432383380	30113	Economy	3300.00
0005432383404	30113	Economy	3300.00
0005432383373	30113	Economy	3300.00
0005432383536	30113	Economy	3300.00
0005432383457	30113	Economy	3300.00
0005433451635	30113	Economy	3300.00
0005433453781	30113	Economy	3300.00
0005432383317	30113	Economy	3300.00
0005432383534	30113	Economy	3300.00
0005432383303	30113	Economy	3300.00
0005432728035	30113	Economy	3300.00
0005432383379	30113	Economy	3300.00
0005432728024	30113	Economy	3300.00
0005432383346	30113	Economy	3300.00
0005433722269	30113	Economy	3300.00
0005432383293	30113	Economy	3300.00
0005432727999	30113	Economy	3300.00
0005432383381	30113	Economy	3300.00
0005432383286	30113	Economy	3300.00
0005432383398	30113	Economy	3300.00
0005432383382	30113	Economy	3300.00
0005432383516	30113	Economy	3300.00
0005433451634	30113	Economy	3300.00
0005432383412	30113	Economy	3300.00
0005432383300	30113	Economy	3300.00
0005432383316	30113	Economy	3300.00
0005433722259	30113	Economy	3300.00
0005432383280	30113	Economy	3300.00
0005432383397	30113	Economy	3300.00
0005432383301	30113	Economy	3300.00
0005432383209	30113	Economy	3300.00
0005435529628	1759	Business	57200.00
0005435529615	1759	Business	57200.00
0005435529986	1759	Business	57200.00
0005435541369	1759	Business	57200.00
0005432925055	1759	Business	57200.00
0005435529622	1759	Business	57200.00
0005433517043	1759	Business	57200.00
0005433517041	1759	Economy	19100.00
0005433517045	1759	Economy	19100.00
0005435529630	1759	Economy	19100.00
0005435541366	1759	Economy	19100.00
0005435541362	1759	Economy	19100.00
0005432925071	1759	Economy	19100.00
0005435541356	1759	Economy	19100.00
0005432294528	1759	Economy	19100.00
0005435529614	1759	Economy	19100.00
0005433517038	1759	Economy	19100.00
0005435529981	1759	Economy	21000.00
0005433517039	1759	Economy	21000.00
0005435529618	1759	Economy	21000.00
0005435529611	1759	Economy	21000.00
0005435529627	1759	Economy	21000.00
0005435541376	1759	Economy	19100.00
0005435541368	1759	Economy	19100.00
0005435541363	1759	Economy	19100.00
0005435529617	1759	Economy	19100.00
0005435541360	1759	Economy	19100.00
0005435541361	1759	Economy	19100.00
0005435529979	1759	Economy	19100.00
0005435541357	1759	Economy	19100.00
0005435541355	1759	Economy	19100.00
0005435541367	1759	Economy	19100.00
0005435541358	1759	Economy	19100.00
0005433517037	1759	Economy	19100.00
0005435529610	1759	Economy	19100.00
0005433517044	1759	Economy	19100.00
0005432294526	1759	Economy	19100.00
0005435529613	1759	Economy	19100.00
0005435541371	1759	Economy	19100.00
0005435529623	1759	Economy	19100.00
0005435541375	1759	Economy	19100.00
0005435529612	1759	Economy	19100.00
0005435529619	1759	Economy	19100.00
0005435541364	1759	Economy	19100.00
0005432925070	1759	Economy	19100.00
0005435529620	1759	Economy	19100.00
0005433517046	1759	Economy	19100.00
0005435541354	1759	Economy	19100.00
0005435541373	1759	Economy	19100.00
0005435529987	1759	Economy	19100.00
0005435541374	1759	Economy	19100.00
0005435529989	1759	Economy	19100.00
0005435529985	1759	Economy	19100.00
0005435529988	1759	Economy	19100.00
0005435541365	1759	Economy	19100.00
0005435529621	1759	Economy	19100.00
0005435529980	1759	Economy	19100.00
0005435529616	1759	Economy	19100.00
0005435529983	1759	Economy	19100.00
0005433517040	1759	Economy	19100.00
0005435529982	1759	Economy	19100.00
0005435529631	1759	Economy	19100.00
0005432925054	1759	Economy	19100.00
0005435541372	1759	Economy	19100.00
0005435529984	1759	Economy	19100.00
0005435529625	1759	Economy	19100.00
0005435541370	1759	Economy	19100.00
0005435529626	1759	Economy	19100.00
0005435529624	1759	Economy	19100.00
0005432925067	1759	Economy	19100.00
0005432925056	1759	Economy	19100.00
0005432294527	1759	Economy	19100.00
0005433517042	1759	Economy	19100.00
0005435541359	1759	Economy	19100.00
0005435529629	1759	Economy	19100.00
0005435541163	22007	Business	57200.00
0005435541155	22007	Business	57200.00
0005435518077	22007	Business	57200.00
0005435541132	22007	Business	57200.00
0005432925117	22007	Business	57200.00
0005435518019	22007	Business	57200.00
0005432925118	22007	Business	57200.00
0005433517011	22007	Business	57200.00
0005435541057	22007	Business	57200.00
0005433516948	22007	Economy	19100.00
0005435517977	22007	Economy	19100.00
0005435518081	22007	Economy	19100.00
0005432925115	22007	Economy	19100.00
0005435518054	22007	Economy	19100.00
0005435517978	22007	Economy	19100.00
0005435518014	22007	Economy	21000.00
0005433516968	22007	Economy	21000.00
0005432925114	22007	Economy	21000.00
0005435518018	22007	Economy	19100.00
0005433516958	22007	Economy	19100.00
0005435541182	22007	Economy	19100.00
0005435517955	22007	Economy	19100.00
0005435541130	22007	Economy	19100.00
0005435518010	22007	Economy	19100.00
0005435541213	22007	Economy	19100.00
0005435518065	22007	Economy	19100.00
0005435518062	22007	Economy	19100.00
0005435541111	22007	Economy	19100.00
0005433516966	22007	Economy	19100.00
0005435518009	22007	Economy	19100.00
0005435518013	22007	Economy	19100.00
0005433516967	22007	Economy	19100.00
0005435517979	22007	Economy	19100.00
0005435541237	22007	Economy	19100.00
0005435517992	22007	Economy	19100.00
0005433517010	22007	Economy	19100.00
0005433516942	22007	Economy	19100.00
0005433516941	22007	Economy	19100.00
0005433516969	22007	Economy	19100.00
0005435518064	22007	Economy	19100.00
0005435518082	22007	Economy	19100.00
0005433516988	22007	Economy	19100.00
0005435518076	22007	Economy	19100.00
0005435541167	22007	Economy	19100.00
0005435541222	22007	Economy	19100.00
0005435518003	22007	Economy	19100.00
0005435541144	22007	Economy	19100.00
0005435541181	22007	Economy	19100.00
0005435518080	22007	Economy	19100.00
0005435541214	22007	Economy	19100.00
0005435541154	22007	Economy	19100.00
0005435518020	22007	Economy	19100.00
0005435518004	22007	Economy	19100.00
0005435517991	22007	Economy	19100.00
0005435517961	22007	Economy	19100.00
0005435541212	22007	Economy	19100.00
0005435541110	22007	Economy	19100.00
0005432925116	22007	Economy	19100.00
0005435518002	22007	Economy	19100.00
0005435541086	22007	Economy	19100.00
0005435518066	22007	Economy	19100.00
0005435541056	22007	Economy	19100.00
0005435252883	7367	Business	18500.00
0005432839556	7367	Business	18500.00
0005432839531	7367	Business	18500.00
0005434459143	7367	Business	18500.00
0005434459153	7367	Business	18500.00
0005432839545	7367	Business	18500.00
0005435252880	7367	Business	18500.00
0005432839548	7367	Business	18500.00
0005432839557	7367	Economy	6200.00
0005432839535	7367	Economy	6200.00
0005434459138	7367	Economy	6200.00
0005432839559	7367	Economy	6200.00
0005434459140	7367	Economy	6200.00
0005432841046	7367	Economy	6200.00
0005434664973	7367	Economy	6200.00
0005435252768	7367	Economy	6200.00
0005434459149	7367	Economy	6800.00
0005434459144	7367	Economy	6800.00
0005432839541	7367	Economy	6800.00
0005434459152	7367	Economy	6800.00
0005432839543	7367	Economy	6800.00
0005434459154	7367	Economy	6200.00
0005434459157	7367	Economy	6200.00
0005434459148	7367	Economy	6200.00
0005435252816	7367	Economy	6200.00
0005432839552	7367	Economy	6200.00
0005435252854	7367	Economy	6200.00
0005434459146	7367	Economy	6200.00
0005435252859	7367	Economy	6200.00
0005432073448	7367	Economy	6200.00
0005432839547	7367	Economy	6200.00
0005435491449	7367	Economy	6200.00
0005434459156	7367	Economy	6200.00
0005432073446	7367	Economy	6200.00
0005432839562	7367	Economy	6200.00
0005432839560	7367	Economy	6200.00
0005432839533	7367	Economy	6200.00
0005432839538	7367	Economy	6200.00
0005432823481	7367	Economy	6200.00
0005432839534	7367	Economy	6200.00
0005432839539	7367	Economy	6200.00
0005435252787	7367	Economy	6200.00
0005434459147	7367	Economy	6200.00
0005432839544	7367	Economy	6200.00
0005434459150	7367	Economy	6200.00
0005432839555	7367	Economy	6200.00
0005435252866	7367	Economy	6200.00
0005434459151	7367	Economy	6200.00
0005432839549	7367	Economy	6200.00
0005435252884	7367	Economy	6200.00
0005432839561	7367	Economy	6200.00
0005434459142	7367	Economy	6200.00
0005435252858	7367	Economy	6200.00
0005432839532	7367	Economy	6200.00
0005432839536	7367	Economy	6200.00
0005432839537	7367	Economy	6200.00
0005432839558	7367	Economy	6200.00
0005432839553	7367	Economy	6200.00
0005432839542	7367	Economy	6200.00
0005432823482	7367	Economy	6200.00
0005434459145	7367	Economy	6200.00
0005434459155	7367	Economy	6200.00
0005432839551	7367	Economy	6200.00
0005435252815	7367	Economy	6200.00
0005432839546	7367	Economy	6200.00
0005432839554	7367	Economy	6200.00
0005432073447	7367	Economy	6200.00
0005435252856	7367	Economy	6200.00
0005435252857	7367	Economy	6200.00
0005435491456	7367	Economy	6200.00
0005434459141	7367	Economy	6200.00
0005435252813	7367	Economy	6200.00
0005432841045	7367	Economy	6200.00
0005432839540	7367	Economy	6200.00
0005432839550	7367	Economy	6200.00
0005434459139	7367	Economy	6200.00
0005434459137	7367	Economy	6200.00
0005435252855	7367	Economy	6200.00
0005435252808	7367	Economy	6200.00
0005434458995	28897	Business	18500.00
0005432839157	28897	Business	18500.00
0005434664999	28897	Business	18500.00
0005432839480	28897	Business	18500.00
0005432839118	28897	Business	18500.00
0005434458892	28897	Business	18500.00
0005432841028	28897	Business	18500.00
0005434458949	28897	Business	18500.00
0005435491477	28897	Business	18500.00
0005434458994	28897	Business	18500.00
0005432001057	28897	Business	18500.00
0005432839320	28897	Economy	6200.00
0005435252990	28897	Economy	6200.00
0005434459006	28897	Economy	6200.00
0005432841034	28897	Economy	6200.00
0005435252993	28897	Economy	6200.00
0005432839279	28897	Economy	6200.00
0005435252996	28897	Economy	6200.00
0005432839215	28897	Economy	6200.00
0005435253004	28897	Economy	6800.00
0005434458972	28897	Economy	6800.00
0005435491476	28897	Economy	6800.00
0005432839346	28897	Economy	6200.00
0005432839142	28897	Economy	6200.00
0005435252994	28897	Economy	6200.00
0005435253003	28897	Economy	6200.00
0005434458839	28897	Economy	6200.00
0005435252986	28897	Economy	6200.00
0005435252997	28897	Economy	6200.00
0005434458958	28897	Economy	6200.00
0005432839426	28897	Economy	6200.00
0005435491475	28897	Economy	6200.00
0005432839387	28897	Economy	6200.00
0005435252987	28897	Economy	6200.00
0005435252992	28897	Economy	6200.00
0005434458971	28897	Economy	6200.00
0005434458947	28897	Economy	6200.00
0005432839345	28897	Economy	6200.00
0005434664997	28897	Economy	6200.00
0005432001056	28897	Economy	6200.00
0005434458883	28897	Economy	6200.00
0005434459008	28897	Economy	6200.00
0005435252995	28897	Economy	6200.00
0005432841029	28897	Economy	6200.00
0005432839354	28897	Economy	6200.00
0005434458893	28897	Economy	6200.00
0005435253002	28897	Economy	6200.00
0005432839398	28897	Economy	6200.00
0005432839309	28897	Economy	6200.00
0005434665000	28897	Economy	6200.00
0005432841030	28897	Economy	6200.00
0005432839308	28897	Economy	6200.00
0005432839312	28897	Economy	6200.00
0005435252988	28897	Economy	6200.00
0005432839156	28897	Economy	6200.00
0005432839321	28897	Economy	6200.00
0005432841035	28897	Economy	6200.00
0005435253000	28897	Economy	6200.00
0005435252989	28897	Economy	6200.00
0005432839302	28897	Economy	6200.00
0005435252999	28897	Economy	6200.00
0005432839119	28897	Economy	6200.00
0005434458970	28897	Economy	6200.00
0005434459009	28897	Economy	6200.00
0005434458957	28897	Economy	6200.00
0005432823476	28897	Economy	6200.00
0005435253001	28897	Economy	6200.00
0005434458961	28897	Economy	6200.00
0005432839301	28897	Economy	6200.00
0005434664998	28897	Economy	6200.00
0005435252998	28897	Economy	6200.00
0005432001058	28897	Economy	6200.00
0005434458960	28897	Economy	6200.00
0005435252991	28897	Economy	6200.00
0005434458884	28897	Economy	6200.00
0005434458991	28897	Economy	6200.00
0005435990741	8827	Business	145300.00
0005435990742	8827	Business	145300.00
0005435990738	8827	Business	145300.00
0005434276092	8827	Economy	53300.00
0005434276075	8827	Economy	48400.00
0005435990744	8827	Economy	48400.00
0005435990739	8827	Economy	48400.00
0005434276070	8827	Economy	48400.00
0005434276091	8827	Economy	48400.00
0005435990740	8827	Economy	48400.00
0005435990743	8827	Economy	48400.00
0005434276062	8827	Economy	48400.00
0005435990705	15769	Business	145300.00
0005434276122	15769	Business	145300.00
0005434276120	15769	Economy	48400.00
0005434276124	15769	Economy	48400.00
0005435990706	15769	Economy	48400.00
0005435990658	15769	Economy	48400.00
0005435990684	15769	Economy	48400.00
0005434276121	15769	Economy	48400.00
0005435990683	15769	Economy	48400.00
0005434276123	15769	Economy	48400.00
0005435990707	15769	Economy	48400.00
0005433468469	2088	Economy	13300.00
0005433468486	2088	Economy	13300.00
0005433468487	2088	Economy	13300.00
0005433468479	2088	Economy	13300.00
0005432909319	2088	Economy	12100.00
0005433468477	2088	Economy	12100.00
0005432909312	2088	Economy	12100.00
0005432909330	2088	Economy	12100.00
0005432909322	2088	Economy	12100.00
0005433468474	2088	Economy	12100.00
0005433468468	2088	Economy	12100.00
0005432909316	2088	Economy	12100.00
0005433468466	2088	Economy	12100.00
0005432909314	2088	Economy	12100.00
0005432909301	2088	Economy	12100.00
0005433468481	2088	Economy	12100.00
0005432909342	2088	Economy	12100.00
0005433468464	2088	Economy	12100.00
0005433468462	2088	Economy	12100.00
0005432909305	2088	Economy	12100.00
0005433468463	2088	Economy	12100.00
0005432909317	2088	Economy	12100.00
0005433468476	2088	Economy	12100.00
0005432909329	2088	Economy	12100.00
0005433468480	2088	Economy	12100.00
0005432909309	2088	Economy	12100.00
0005433468473	2088	Economy	12100.00
0005432909302	2088	Economy	12100.00
0005433468467	2088	Economy	12100.00
0005433468484	2088	Economy	12100.00
0005433468475	2088	Economy	12100.00
0005432909326	2088	Economy	12100.00
0005433468482	2088	Economy	12100.00
0005433468472	2088	Economy	12100.00
0005432909347	2088	Economy	12100.00
0005432909284	2088	Economy	12100.00
0005432909332	2088	Economy	12100.00
0005433468478	2088	Economy	12100.00
0005432909306	2088	Economy	12100.00
0005432909283	2088	Economy	12100.00
0005433468471	2088	Economy	12100.00
0005433468470	2088	Economy	12100.00
0005433468465	2088	Economy	12100.00
0005432909325	2088	Economy	12100.00
0005432909331	2088	Economy	12100.00
0005432909333	2088	Economy	12100.00
0005433468483	2088	Economy	12100.00
0005432909348	2088	Economy	12100.00
0005433468485	2088	Economy	12100.00
0005432909313	2088	Economy	12100.00
0005432361135	6407	Business	36600.00
0005432361178	6407	Business	36600.00
0005434149846	6407	Business	36600.00
0005435177341	6407	Business	36600.00
0005434149798	6407	Business	36600.00
0005434149856	6407	Business	36600.00
0005435177362	6407	Business	36600.00
0005432361177	6407	Business	36600.00
0005432361145	6407	Business	36600.00
0005432062316	6407	Business	36600.00
0005432361151	6407	Economy	12200.00
0005432361167	6407	Economy	12200.00
0005432361130	6407	Economy	12200.00
0005435723066	6407	Economy	12200.00
0005435723055	6407	Economy	12200.00
0005432336230	6407	Economy	12200.00
0005432361134	6407	Economy	12200.00
0005432361161	6407	Economy	12200.00
0005432336228	6407	Economy	12200.00
0005432363471	6407	Economy	12200.00
0005432361176	6407	Economy	12200.00
0005432361131	6407	Economy	12200.00
0005432062314	6407	Economy	12200.00
0005432336233	6407	Economy	12200.00
0005435177303	6407	Economy	12200.00
0005435490246	6407	Economy	12200.00
0005432361164	6407	Economy	12200.00
0005432361156	6407	Economy	12200.00
0005432336231	6407	Economy	12200.00
0005435177300	6407	Economy	12200.00
0005432336227	6407	Economy	12200.00
0005432361170	6407	Economy	12200.00
0005432361165	6407	Economy	12200.00
0005435177236	6407	Economy	12200.00
0005432361147	6407	Economy	12200.00
0005432336225	6407	Economy	12200.00
0005435177289	6407	Economy	12200.00
0005434149789	6407	Economy	12200.00
0005435490243	6407	Economy	12200.00
0005432361133	6407	Economy	12200.00
0005435177452	6407	Economy	13400.00
0005435177372	6407	Economy	13400.00
0005432361132	6407	Economy	13400.00
0005432361136	6407	Economy	13400.00
0005432363469	6407	Economy	13400.00
0005432361152	6407	Economy	12200.00
0005432361175	6407	Economy	12200.00
0005432062315	6407	Economy	12200.00
0005432361159	6407	Economy	12200.00
0005434149847	6407	Economy	12200.00
0005435177342	6407	Economy	12200.00
0005432361172	6407	Economy	12200.00
0005432363470	6407	Economy	12200.00
0005435177282	6407	Economy	12200.00
0005432363468	6407	Economy	12200.00
0005434149831	6407	Economy	12200.00
0005432361148	6407	Economy	12200.00
0005432336235	6407	Economy	12200.00
0005432361140	6407	Economy	12200.00
0005435177248	6407	Economy	12200.00
0005432361169	6407	Economy	12200.00
0005435177345	6407	Economy	12200.00
0005435177400	6407	Economy	12200.00
0005434149832	6407	Economy	12200.00
0005432361150	6407	Economy	12200.00
0005432361129	6407	Economy	12200.00
0005432361139	6407	Economy	12200.00
0005432062318	6407	Economy	12200.00
0005432361168	6407	Economy	12200.00
0005432336234	6407	Economy	12200.00
0005435177401	6407	Economy	12200.00
0005434149839	6407	Economy	12200.00
0005432062317	6407	Economy	12200.00
0005432361154	6407	Economy	12200.00
0005432361138	6407	Economy	12200.00
0005432361143	6407	Economy	12200.00
0005435723056	6407	Economy	12200.00
0005435177247	6407	Economy	12200.00
0005432336226	6407	Economy	12200.00
0005435490247	6407	Economy	12200.00
0005432361162	6407	Economy	12200.00
0005432361144	6407	Economy	12200.00
0005432336229	6407	Economy	12200.00
0005434149851	6407	Economy	12200.00
0005432361142	6407	Economy	12200.00
0005435177456	6407	Economy	12200.00
0005432361173	6407	Economy	12200.00
0005432361160	6407	Economy	12200.00
0005432361171	6407	Economy	12200.00
0005435723057	6407	Economy	12200.00
0005434149774	6407	Economy	12200.00
0005432361146	6407	Economy	12200.00
0005432361141	6407	Economy	12200.00
0005432361174	6407	Economy	12200.00
0005432361157	6407	Economy	12200.00
0005432361149	6407	Economy	12200.00
0005432361153	6407	Economy	12200.00
0005432361163	6407	Economy	12200.00
0005435177344	6407	Economy	12200.00
0005432336224	6407	Economy	12200.00
0005432336232	6407	Economy	12200.00
0005434149775	6407	Economy	12200.00
0005432361158	6407	Economy	12200.00
0005432361155	6407	Economy	12200.00
0005432361166	6407	Economy	12200.00
0005432361137	6407	Economy	12200.00
0005432336119	21018	Business	36600.00
0005435177538	21018	Business	36600.00
0005435177530	21018	Business	36600.00
0005434149920	21018	Business	36600.00
0005432360594	21018	Business	36600.00
0005432360725	21018	Business	36600.00
0005432360412	21018	Business	36600.00
0005432360610	21018	Business	36600.00
0005435490291	21018	Business	36600.00
0005435177520	21018	Business	36600.00
0005432360872	21018	Business	36600.00
0005432336108	21018	Business	36600.00
0005432360786	21018	Economy	12200.00
0005432360785	21018	Economy	12200.00
0005435177519	21018	Economy	12200.00
0005432360635	21018	Economy	12200.00
0005432363445	21018	Economy	12200.00
0005435177532	21018	Economy	12200.00
0005432360915	21018	Economy	12200.00
0005432360856	21018	Economy	12200.00
0005432360780	21018	Economy	12200.00
0005434149926	21018	Economy	12200.00
0005435177524	21018	Economy	12200.00
0005432360890	21018	Economy	12200.00
0005435177527	21018	Economy	12200.00
0005432363432	21018	Economy	12200.00
0005432360808	21018	Economy	12200.00
0005435177536	21018	Economy	12200.00
0005432360690	21018	Economy	12200.00
0005432360810	21018	Economy	12200.00
0005432360727	21018	Economy	12200.00
0005435177535	21018	Economy	12200.00
0005432052797	21018	Economy	12200.00
0005432360809	21018	Economy	12200.00
0005434149925	21018	Economy	12200.00
0005432360717	21018	Economy	12200.00
0005432363448	21018	Economy	12200.00
0005432360744	21018	Economy	12200.00
0005432360728	21018	Economy	12200.00
0005435490292	21018	Economy	12200.00
0005432360718	21018	Economy	12200.00
0005435177531	21018	Economy	12200.00
0005432360700	21018	Economy	12200.00
0005432360689	21018	Economy	12200.00
0005432336124	21018	Economy	12200.00
0005434149921	21018	Economy	12200.00
0005432336145	21018	Economy	12200.00
0005432052795	21018	Economy	12200.00
0005435177528	21018	Economy	12200.00
0005432360595	21018	Economy	12200.00
0005432360752	21018	Economy	12200.00
0005435177537	21018	Economy	12200.00
0005434149928	21018	Economy	13400.00
0005432360622	21018	Economy	13400.00
0005432360665	21018	Economy	13400.00
0005432360753	21018	Economy	13400.00
0005432360803	21018	Economy	13400.00
0005432336084	21018	Economy	12200.00
0005435177515	21018	Economy	13400.00
0005432363446	21018	Economy	12200.00
0005432360413	21018	Economy	12200.00
0005432360754	21018	Economy	12200.00
0005432360908	21018	Economy	12200.00
0005432360675	21018	Economy	12200.00
0005432360525	21018	Economy	12200.00
0005432360977	21018	Economy	12200.00
0005432336058	21018	Economy	12200.00
0005432360929	21018	Economy	12200.00
0005432363433	21018	Economy	12200.00
0005432360742	21018	Economy	12200.00
0005432360643	21018	Economy	12200.00
0005432360666	21018	Economy	12200.00
0005434149922	21018	Economy	12200.00
0005432360755	21018	Economy	12200.00
0005432360634	21018	Economy	12200.00
0005432360976	21018	Economy	12200.00
0005432052796	21018	Economy	12200.00
0005432360820	21018	Economy	12200.00
0005435177539	21018	Economy	12200.00
0005432336122	21018	Economy	12200.00
0005432360596	21018	Economy	12200.00
0005432360848	21018	Economy	12200.00
0005432336134	21018	Economy	12200.00
0005432360685	21018	Economy	12200.00
0005434149919	21018	Economy	12200.00
0005434149918	21018	Economy	12200.00
0005435177523	21018	Economy	12200.00
0005435177518	21018	Economy	12200.00
0005432336130	21018	Economy	12200.00
0005432360978	21018	Economy	12200.00
0005432360894	21018	Economy	12200.00
0005432360882	21018	Economy	12200.00
0005435177529	21018	Economy	12200.00
0005432363447	21018	Economy	12200.00
0005432360500	21018	Economy	12200.00
0005432360674	21018	Economy	12200.00
0005432360758	21018	Economy	12200.00
0005435177540	21018	Economy	12200.00
0005432360855	21018	Economy	12200.00
0005432360743	21018	Economy	12200.00
0005435177522	21018	Economy	12200.00
0005432336131	21018	Economy	12200.00
0005435177521	21018	Economy	12200.00
0005432360859	21018	Economy	12200.00
0005434149929	21018	Economy	12200.00
0005435177525	21018	Economy	12200.00
0005434149924	21018	Economy	12200.00
0005432360875	21018	Economy	12200.00
0005432360749	21018	Economy	12200.00
0005435177534	21018	Economy	12200.00
0005434149927	21018	Economy	12200.00
0005432360646	21018	Economy	12200.00
0005432360621	21018	Economy	12200.00
0005435177516	21018	Economy	12200.00
0005432360699	21018	Economy	12200.00
0005432336117	21018	Economy	12200.00
0005432336161	21018	Economy	12200.00
0005435177526	21018	Economy	12200.00
0005435177541	21018	Economy	12200.00
0005434149923	21018	Economy	12200.00
0005432360697	21018	Economy	12200.00
0005432360787	21018	Economy	12200.00
0005432336127	21018	Economy	12200.00
0005435177542	21018	Economy	12200.00
0005432360574	21018	Economy	12200.00
0005435177533	21018	Economy	12200.00
0005435177543	21018	Economy	12200.00
0005435177517	21018	Economy	12200.00
0005432360813	21018	Economy	12200.00
0005432360609	21018	Economy	12200.00
0005434459015	17707	Economy	3400.00
0005434459010	17707	Economy	3400.00
0005434458983	17707	Economy	3400.00
0005434459040	17707	Economy	3100.00
0005434459052	17707	Economy	3100.00
0005434459014	17707	Economy	3100.00
0005434459020	17707	Economy	3100.00
0005434463950	17707	Economy	3100.00
0005434458933	17707	Economy	3100.00
0005434459068	17707	Economy	3100.00
0005434459067	17707	Economy	3100.00
0005434459029	17707	Economy	3100.00
0005434458928	17707	Economy	3100.00
0005434459030	17707	Economy	3100.00
0005434459061	17707	Economy	3100.00
0005434448336	17707	Economy	3100.00
0005434458996	17707	Economy	3100.00
0005434459053	17707	Economy	3100.00
0005434458932	17707	Economy	3100.00
0005434458982	17707	Economy	3100.00
0005434459096	17707	Economy	3100.00
0005434459019	17707	Economy	3100.00
0005434458948	17707	Economy	3100.00
0005434448342	17707	Economy	3100.00
0005434458931	17707	Economy	3100.00
0005434458975	17707	Economy	3100.00
0005434458981	17707	Economy	3100.00
0005434458927	17707	Economy	3100.00
0005434463941	17707	Economy	3100.00
0005434186248	17707	Economy	3100.00
0005434458955	17707	Economy	3100.00
0005434463946	17707	Economy	3100.00
0005434463951	17707	Economy	3100.00
0005434448341	17707	Economy	3100.00
0005434459028	17707	Economy	3100.00
0005434186216	29133	Economy	3400.00
0005434459145	29133	Economy	3400.00
0005434459156	29133	Economy	3100.00
0005434463964	29133	Economy	3100.00
0005434459148	29133	Economy	3100.00
0005434459155	29133	Economy	3100.00
0005434459153	29133	Economy	3100.00
0005434448370	29133	Economy	3100.00
0005434459149	29133	Economy	3100.00
0005434459147	29133	Economy	3100.00
0005434448369	29133	Economy	3100.00
0005434459146	29133	Economy	3100.00
0005434463963	29133	Economy	3100.00
0005434459154	29133	Economy	3100.00
0005434459143	29133	Economy	3100.00
0005434459141	29133	Economy	3100.00
0005434462823	29133	Economy	3100.00
0005434448368	29133	Economy	3100.00
0005434459144	29133	Economy	3100.00
0005434459139	29133	Economy	3100.00
0005434459138	29133	Economy	3100.00
0005434462824	29133	Economy	3100.00
0005434459152	29133	Economy	3100.00
0005434459137	29133	Economy	3100.00
0005434459140	29133	Economy	3100.00
0005434459142	29133	Economy	3100.00
0005434459157	29133	Economy	3100.00
0005434459151	29133	Economy	3100.00
0005434459150	29133	Economy	3100.00
0005432604970	21415	Economy	7300.00
0005432604943	21415	Economy	7300.00
0005432604967	21415	Economy	7300.00
0005432604979	21415	Economy	7300.00
0005432604971	21415	Economy	6600.00
0005432604980	21415	Economy	6600.00
0005432604956	21415	Economy	6600.00
0005432604962	21415	Economy	6600.00
0005432604960	21415	Economy	6600.00
0005432604942	21415	Economy	6600.00
0005432604944	21415	Economy	6600.00
0005432604966	21415	Economy	6600.00
0005432604957	21415	Economy	6600.00
0005432604974	21415	Economy	6600.00
0005432604961	21415	Economy	6600.00
0005432604959	21415	Economy	6600.00
0005432604950	21415	Economy	6600.00
0005432604941	21415	Economy	6600.00
0005432604965	21415	Economy	6600.00
0005432604958	21415	Economy	6600.00
0005432604977	21415	Economy	6600.00
0005432604948	21415	Economy	6600.00
0005432604955	21415	Economy	6600.00
0005432604963	21415	Economy	6600.00
0005432604940	21415	Economy	6600.00
0005432604952	21415	Economy	6600.00
0005432604947	21415	Economy	6600.00
0005432604946	21415	Economy	6600.00
0005432604964	21415	Economy	6600.00
0005432604968	21415	Economy	6600.00
0005432604951	21415	Economy	6600.00
0005432604954	21415	Economy	6600.00
0005432604973	21415	Economy	6600.00
0005432604953	21415	Economy	6600.00
0005432604949	21415	Economy	6600.00
0005432604972	21415	Economy	6600.00
0005432604975	21415	Economy	6600.00
0005432604945	21415	Economy	6600.00
0005432604976	21415	Economy	6600.00
0005432604978	21415	Economy	6600.00
0005432604969	21415	Economy	6600.00
0005432604590	31681	Economy	7300.00
0005435221547	31681	Economy	7300.00
0005432604448	31681	Economy	7300.00
0005432604577	31681	Economy	7300.00
0005432604447	31681	Economy	6600.00
0005432604600	31681	Economy	6600.00
0005432604547	31681	Economy	6600.00
0005432604567	31681	Economy	6600.00
0005432604394	31681	Economy	6600.00
0005432604606	31681	Economy	6600.00
0005432604592	31681	Economy	6600.00
0005432604726	31681	Economy	6600.00
0005432604601	31681	Economy	6600.00
0005432604375	31681	Economy	6600.00
0005432604578	31681	Economy	6600.00
0005432604682	31681	Economy	6600.00
0005432604499	31681	Economy	6600.00
0005432604498	31681	Economy	6600.00
0005432604677	31681	Economy	6600.00
0005432604568	31681	Economy	6600.00
0005432604545	31681	Economy	6600.00
0005432604559	31681	Economy	6600.00
0005435221524	31681	Economy	6600.00
0005432604513	31681	Economy	6600.00
0005432604753	31681	Economy	6600.00
0005432604595	31681	Economy	6600.00
0005432604376	31681	Economy	6600.00
0005432604593	31681	Economy	6600.00
0005432604752	31681	Economy	6600.00
0005432604393	31681	Economy	6600.00
0005432604645	31681	Economy	6600.00
0005432604436	31681	Economy	6600.00
0005432604551	31681	Economy	6600.00
0005432604788	31681	Economy	6600.00
0005432604857	31681	Economy	6600.00
0005432604781	31681	Economy	6600.00
0005435221066	31681	Economy	6600.00
0005432604546	31681	Economy	6600.00
0005432604596	31681	Economy	6600.00
0005432604512	31681	Economy	6600.00
0005435221525	31681	Economy	6600.00
0005432604542	31681	Economy	6600.00
0005432604496	31681	Economy	6600.00
0005432604648	31681	Economy	6600.00
0005432604609	31681	Economy	6600.00
0005435221067	31681	Economy	6600.00
0005434606858	18877	Economy	6600.00
0005435904904	18877	Economy	6600.00
0005435904905	18877	Economy	6600.00
0005434604952	22305	Economy	6600.00
0005435904898	22305	Economy	6600.00
0005434604950	22305	Economy	6600.00
0005435904899	22305	Economy	6600.00
0005434606879	22305	Economy	6600.00
0005434604951	22305	Economy	6600.00
0005434606880	22305	Economy	6600.00
0005432891162	407	Business	44500.00
0005432748204	407	Business	44500.00
0005432748200	407	Business	44500.00
0005432748175	407	Business	44500.00
0005432748168	407	Business	44500.00
0005432748177	407	Business	44500.00
0005432748176	407	Business	44500.00
0005432748190	407	Business	44500.00
0005432748202	407	Business	44500.00
0005435154627	407	Economy	14800.00
0005432891169	407	Business	44500.00
0005432891068	407	Economy	14800.00
0005432748174	407	Economy	14800.00
0005433293298	407	Economy	14800.00
0005432748179	407	Economy	14800.00
0005433293300	407	Economy	14800.00
0005432748199	407	Economy	14800.00
0005432748188	407	Economy	14800.00
0005432220073	407	Economy	14800.00
0005432891143	407	Economy	14800.00
0005432749819	407	Economy	16300.00
0005432891174	407	Economy	16300.00
0005432220071	407	Economy	16300.00
0005432748180	407	Economy	16300.00
0005433293289	407	Economy	14800.00
0005432891168	407	Economy	14800.00
0005432891163	407	Economy	14800.00
0005432891111	407	Economy	14800.00
0005432748186	407	Economy	14800.00
0005432891242	407	Economy	14800.00
0005432220074	407	Economy	14800.00
0005432748184	407	Economy	14800.00
0005432891221	407	Economy	14800.00
0005433293290	407	Economy	14800.00
0005432748197	407	Economy	14800.00
0005432753352	407	Economy	14800.00
0005432220072	407	Economy	14800.00
0005432748193	407	Economy	14800.00
0005432749818	407	Economy	14800.00
0005432748187	407	Economy	14800.00
0005432748173	407	Economy	14800.00
0005432748201	407	Economy	14800.00
0005432748191	407	Economy	14800.00
0005432753353	407	Economy	14800.00
0005432748172	407	Economy	14800.00
0005432891185	407	Economy	14800.00
0005432748203	407	Economy	14800.00
0005435154628	407	Economy	14800.00
0005432748166	407	Economy	14800.00
0005432748170	407	Economy	14800.00
0005432748181	407	Economy	14800.00
0005432748178	407	Economy	14800.00
0005432891183	407	Economy	14800.00
0005432748192	407	Economy	14800.00
0005433293299	407	Economy	14800.00
0005432891222	407	Economy	14800.00
0005432748196	407	Economy	14800.00
0005432751578	407	Economy	14800.00
0005432753354	407	Economy	14800.00
0005432891186	407	Economy	14800.00
0005432891176	407	Economy	14800.00
0005433293268	407	Economy	14800.00
0005432748194	407	Economy	14800.00
0005432748195	407	Economy	14800.00
0005432753351	407	Economy	14800.00
0005432748167	407	Economy	14800.00
0005432748198	407	Economy	14800.00
0005432748205	407	Economy	14800.00
0005433293297	407	Economy	14800.00
0005433875388	407	Economy	14800.00
0005432748169	407	Economy	14800.00
0005432891175	407	Economy	14800.00
0005432891177	407	Economy	14800.00
0005432751579	407	Economy	14800.00
0005432748171	407	Economy	14800.00
0005432748189	407	Economy	14800.00
0005432748183	407	Economy	14800.00
0005432748185	407	Economy	14800.00
0005432748182	407	Economy	14800.00
0005433293351	12075	Business	44500.00
0005432747681	12075	Business	44500.00
0005432749804	12075	Business	44500.00
0005432891350	12075	Business	44500.00
0005432747849	12075	Business	44500.00
0005433293348	12075	Business	44500.00
0005433875405	12075	Business	44500.00
0005433875406	12075	Business	44500.00
0005433875404	12075	Business	44500.00
0005433293350	12075	Business	44500.00
0005435154596	12075	Business	44500.00
0005432747790	12075	Business	44500.00
0005433293344	12075	Economy	14800.00
0005433293338	12075	Economy	14800.00
0005432891337	12075	Economy	14800.00
0005433293347	12075	Economy	14800.00
0005432891335	12075	Economy	14800.00
0005432749807	12075	Economy	14800.00
0005432891347	12075	Economy	14800.00
0005432747885	12075	Economy	14800.00
0005432747884	12075	Economy	14800.00
0005432748001	12075	Economy	14800.00
0005433293341	12075	Economy	16300.00
0005433875407	12075	Economy	16300.00
0005432756861	12075	Economy	16300.00
0005432747863	12075	Economy	16300.00
0005432747999	12075	Economy	16300.00
0005435154597	12075	Economy	14800.00
0005432747908	12075	Economy	14800.00
0005432756862	12075	Economy	14800.00
0005432756874	12075	Economy	14800.00
0005434153554	12075	Economy	14800.00
0005432747664	12075	Economy	14800.00
0005433293337	12075	Economy	14800.00
0005432891332	12075	Economy	14800.00
0005432214839	12075	Economy	14800.00
0005433293345	12075	Economy	14800.00
0005432747831	12075	Economy	14800.00
0005432747989	12075	Economy	14800.00
0005432747779	12075	Economy	14800.00
0005432891331	12075	Economy	14800.00
0005432756873	12075	Economy	14800.00
0005432747906	12075	Economy	14800.00
0005432753321	12075	Economy	14800.00
0005432748015	12075	Economy	14800.00
0005432753336	12075	Economy	14800.00
0005432747861	12075	Economy	14800.00
0005432747888	12075	Economy	14800.00
0005432891333	12075	Economy	14800.00
0005433293339	12075	Economy	14800.00
0005432747780	12075	Economy	14800.00
0005432214838	12075	Economy	14800.00
0005432749805	12075	Economy	14800.00
0005433293342	12075	Economy	14800.00
0005432747917	12075	Economy	14800.00
0005432747696	12075	Economy	14800.00
0005432748002	12075	Economy	14800.00
0005432749808	12075	Economy	14800.00
0005432748086	12075	Economy	14800.00
0005432891342	12075	Economy	14800.00
0005433293340	12075	Economy	14800.00
0005432749806	12075	Economy	14800.00
0005432747862	12075	Economy	14800.00
0005432747768	12075	Economy	14800.00
0005432747946	12075	Economy	14800.00
0005432891348	12075	Economy	14800.00
0005432749809	12075	Economy	14800.00
0005432891336	12075	Economy	14800.00
0005432747792	12075	Economy	14800.00
0005433293343	12075	Economy	14800.00
0005432748085	12075	Economy	14800.00
0005432891339	12075	Economy	14800.00
0005432891345	12075	Economy	14800.00
0005432748000	12075	Economy	14800.00
0005433293346	12075	Economy	14800.00
0005432747774	12075	Economy	14800.00
0005432891341	12075	Economy	14800.00
0005432753327	12075	Economy	14800.00
0005432747947	12075	Economy	14800.00
0005432891330	12075	Economy	14800.00
0005432891349	12075	Economy	14800.00
0005432891344	12075	Economy	14800.00
0005432891346	12075	Economy	14800.00
0005432747836	12075	Economy	14800.00
0005432891340	12075	Economy	14800.00
0005432891343	12075	Economy	14800.00
0005432891338	12075	Economy	14800.00
0005432747824	12075	Economy	14800.00
0005432747848	12075	Economy	14800.00
0005432747942	12075	Economy	14800.00
0005432891334	12075	Economy	14800.00
0005433293349	12075	Economy	14800.00
0005432928023	18988	Economy	28200.00
0005433533368	18988	Economy	28200.00
0005433525206	18988	Economy	28200.00
0005433533369	18988	Economy	25700.00
0005433531350	18988	Economy	25700.00
0005432928013	18988	Economy	25700.00
0005433525203	18988	Economy	25700.00
0005433531352	18988	Economy	25700.00
0005433533365	18988	Economy	25700.00
0005432928009	18988	Economy	25700.00
0005432928024	18988	Economy	25700.00
0005433525205	18988	Economy	25700.00
0005433533367	18988	Economy	25700.00
0005433525207	18988	Economy	25700.00
0005433525210	18988	Economy	25700.00
0005432928014	18988	Economy	25700.00
0005432928054	18988	Economy	25700.00
0005433525211	18988	Economy	25700.00
0005433525212	18988	Economy	25700.00
0005432928012	18988	Economy	25700.00
0005433533366	18988	Economy	25700.00
0005433525204	18988	Economy	25700.00
0005433525213	18988	Economy	25700.00
0005432928055	18988	Economy	25700.00
0005433525208	18988	Economy	25700.00
0005433531351	18988	Economy	25700.00
0005433525209	18988	Economy	25700.00
0005433531353	18988	Economy	25700.00
0005433525214	18988	Economy	25700.00
0005432928011	18988	Economy	25700.00
0005432928053	18988	Economy	25700.00
0005433525151	32483	Economy	28200.00
0005433531325	32483	Economy	25700.00
0005433525141	32483	Economy	25700.00
0005433531313	32483	Economy	25700.00
0005433525131	32483	Economy	25700.00
0005433525132	32483	Economy	25700.00
0005433525147	32483	Economy	25700.00
0005433531324	32483	Economy	25700.00
0005433525119	32483	Economy	25700.00
0005433525088	32483	Economy	25700.00
0005433527267	32483	Economy	25700.00
0005432928075	32483	Economy	25700.00
0005433525089	32483	Economy	25700.00
0005433531315	32483	Economy	25700.00
0005432928077	32483	Economy	25700.00
0005433525163	32483	Economy	25700.00
0005433525148	32483	Economy	25700.00
0005432928078	32483	Economy	25700.00
0005433525120	32483	Economy	25700.00
0005432928079	32483	Economy	25700.00
0005433525118	32483	Economy	25700.00
0005433525117	32483	Economy	25700.00
0005432928076	32483	Economy	25700.00
0005432394172	5282	Business	84000.00
0005434825694	5282	Business	84000.00
0005434825668	5282	Business	84000.00
0005434825633	5282	Business	84000.00
0005435661957	5282	Business	84000.00
0005435373806	5282	Business	84000.00
0005434825687	5282	Business	84000.00
0005432823470	5282	Business	84000.00
0005432121561	5282	Business	84000.00
0005435373768	5282	Business	84000.00
0005435373670	5282	Business	84000.00
0005432394173	5282	Business	84000.00
0005434558425	5282	Business	84000.00
0005435373597	5282	Business	84000.00
0005432121559	5282	Business	84000.00
0005432121572	5282	Business	84000.00
0005435373760	5282	Business	84000.00
0005432121562	5282	Business	84000.00
0005435304202	5282	Business	84000.00
0005435386611	5282	Business	84000.00
0005434825669	5282	Business	84000.00
0005434825607	5282	Business	84000.00
0005434825684	5282	Business	84000.00
0005435735141	5282	Comfort	47600.00
0005434825697	5282	Business	84000.00
0005434825726	5282	Comfort	47600.00
0005435373744	5282	Comfort	47600.00
0005435374018	5282	Comfort	47600.00
0005435299826	5282	Comfort	47600.00
0005434558427	5282	Comfort	47600.00
0005434825678	5282	Comfort	47600.00
0005435373807	5282	Comfort	47600.00
0005434825640	5282	Comfort	47600.00
0005434825712	5282	Comfort	47600.00
0005435150262	5282	Comfort	47600.00
0005434558419	5282	Comfort	47600.00
0005434825683	5282	Comfort	47600.00
0005434825691	5282	Comfort	47600.00
0005432121567	5282	Comfort	47600.00
0005434558420	5282	Comfort	47600.00
0005435304197	5282	Comfort	47600.00
0005434825627	5282	Comfort	47600.00
0005434825686	5282	Comfort	47600.00
0005435373964	5282	Comfort	47600.00
0005435373873	5282	Comfort	47600.00
0005432396308	5282	Comfort	47600.00
0005432121569	5282	Comfort	47600.00
0005435386607	5282	Comfort	47600.00
0005435373830	5282	Comfort	47600.00
0005432121571	5282	Comfort	47600.00
0005434825707	5282	Comfort	47600.00
0005435373672	5282	Comfort	47600.00
0005434825685	5282	Comfort	47600.00
0005435374027	5282	Comfort	47600.00
0005434825602	5282	Comfort	47600.00
0005434825617	5282	Comfort	47600.00
0005434825717	5282	Comfort	47600.00
0005434831223	5282	Economy	28000.00
0005434825700	5282	Economy	28000.00
0005434825689	5282	Economy	28000.00
0005434558422	5282	Economy	28000.00
0005435150253	5282	Economy	28000.00
0005435373696	5282	Economy	28000.00
0005434825620	5282	Economy	28000.00
0005435373799	5282	Economy	28000.00
0005434825677	5282	Economy	28000.00
0005434825708	5282	Economy	28000.00
0005435373928	5282	Economy	28000.00
0005435304188	5282	Economy	28000.00
0005434828739	5282	Economy	28000.00
0005434825622	5282	Economy	28000.00
0005435373681	5282	Economy	28000.00
0005434825716	5282	Economy	28000.00
0005435373793	5282	Economy	28000.00
0005434825664	5282	Economy	28000.00
0005434825599	5282	Economy	28000.00
0005435150254	5282	Economy	28000.00
0005435373576	5282	Economy	28000.00
0005434825618	5282	Economy	28000.00
0005434825647	5282	Economy	28000.00
0005432121568	5282	Economy	28000.00
0005434825710	5282	Economy	28000.00
0005434825651	5282	Economy	28000.00
0005434825670	5282	Economy	28000.00
0005434825623	5282	Economy	28000.00
0005434825600	5282	Economy	28000.00
0005434825696	5282	Economy	28000.00
0005434825625	5282	Economy	28000.00
0005432121558	5282	Economy	28000.00
0005435373824	5282	Economy	28000.00
0005435374148	5282	Economy	28000.00
0005434825718	5282	Economy	28000.00
0005432823456	5282	Economy	28000.00
0005435299832	5282	Economy	28000.00
0005434825654	5282	Economy	28000.00
0005435150252	5282	Economy	28000.00
0005435373678	5282	Economy	28000.00
0005435373682	5282	Economy	28000.00
0005434825662	5282	Economy	28000.00
0005434825653	5282	Economy	28000.00
0005434825621	5282	Economy	28000.00
0005435373810	5282	Economy	28000.00
0005434825665	5282	Economy	28000.00
0005434825702	5282	Economy	28000.00
0005435373750	5282	Economy	28000.00
0005435373660	5282	Economy	28000.00
0005435299822	5282	Economy	28000.00
0005434825666	5282	Economy	28000.00
0005435735147	5282	Economy	28000.00
0005435373749	5282	Economy	28000.00
0005435373794	5282	Economy	30800.00
0005435373677	5282	Economy	28000.00
0005434825661	5282	Economy	30800.00
0005435373809	5282	Economy	28000.00
0005432394170	5282	Economy	28000.00
0005435299809	5282	Economy	28000.00
0005434825721	5282	Economy	28000.00
0005434825628	5282	Economy	28000.00
0005434825714	5282	Economy	28000.00
0005435150257	5282	Economy	28000.00
0005434825720	5282	Economy	28000.00
0005435373671	5282	Economy	28000.00
0005434825679	5282	Economy	28000.00
0005434825709	5282	Economy	28000.00
0005434825719	5282	Economy	28000.00
0005434825727	5282	Economy	28000.00
0005435373825	5282	Economy	28000.00
0005435150264	5282	Economy	28000.00
0005434825609	5282	Economy	28000.00
0005435150261	5282	Economy	28000.00
0005434825674	5282	Economy	28000.00
0005434825638	5282	Economy	28000.00
0005435374026	5282	Economy	28000.00
0005434558423	5282	Economy	28000.00
0005435373667	5282	Economy	28000.00
0005434825612	5282	Economy	28000.00
0005435661956	5282	Economy	28000.00
0005435373774	5282	Economy	28000.00
0005434825637	5282	Economy	28000.00
0005435386601	5282	Economy	28000.00
0005434828740	5282	Economy	28000.00
0005434825606	5282	Economy	28000.00
0005434825682	5282	Economy	28000.00
0005435373854	5282	Economy	28000.00
0005434558426	5282	Economy	28000.00
0005434825648	5282	Economy	28000.00
0005435150251	5282	Economy	28000.00
0005435150258	5282	Economy	28000.00
0005434664996	5282	Economy	28000.00
0005435373383	5282	Economy	28000.00
0005435373812	5282	Economy	28000.00
0005435373813	5282	Economy	28000.00
0005434825659	5282	Economy	28000.00
0005434825604	5282	Economy	28000.00
0005435374036	5282	Economy	28000.00
0005434825642	5282	Economy	28000.00
0005434825630	5282	Economy	28000.00
0005435304204	5282	Economy	28000.00
0005434825646	5282	Economy	28000.00
0005434825713	5282	Economy	28000.00
0005434825667	5282	Economy	28000.00
0005434825632	5282	Economy	28000.00
0005435735134	5282	Economy	28000.00
0005434825603	5282	Economy	28000.00
0005432121560	5282	Economy	28000.00
0005434825680	5282	Economy	28000.00
0005435386641	5282	Economy	28000.00
0005434825649	5282	Economy	28000.00
0005435386608	5282	Economy	28000.00
0005435299833	5282	Economy	28000.00
0005434825615	5282	Economy	28000.00
0005432121563	5282	Economy	28000.00
0005432394168	5282	Economy	28000.00
0005432121564	5282	Economy	28000.00
0005432121566	5282	Economy	28000.00
0005434825671	5282	Economy	28000.00
0005434825692	5282	Economy	28000.00
0005435150263	5282	Economy	28000.00
0005435373706	5282	Economy	28000.00
0005435373769	5282	Economy	28000.00
0005434825690	5282	Economy	28000.00
0005432121570	5282	Economy	28000.00
0005434825693	5282	Economy	28000.00
0005434825611	5282	Economy	28000.00
0005435373767	5282	Economy	28000.00
0005435373756	5282	Economy	28000.00
0005434825629	5282	Economy	28000.00
0005432396309	5282	Economy	28000.00
0005434825703	5282	Economy	28000.00
0005435373743	5282	Economy	30800.00
0005435735159	5282	Economy	28000.00
0005435299810	5282	Economy	30800.00
0005434825635	5282	Economy	30800.00
0005434828741	5282	Economy	30800.00
0005435373748	5282	Economy	30800.00
0005435150260	5282	Economy	30800.00
0005434825706	5282	Economy	28000.00
0005434825658	5282	Economy	28000.00
0005435373770	5282	Economy	28000.00
0005435150255	5282	Economy	28000.00
0005432121565	5282	Economy	28000.00
0005434825641	5282	Economy	28000.00
0005434825610	5282	Economy	28000.00
0005432394169	5282	Economy	28000.00
0005435150256	5282	Economy	28000.00
0005434825608	5282	Economy	28000.00
0005434825723	5282	Economy	28000.00
0005434831225	5282	Economy	28000.00
0005435373755	5282	Economy	28000.00
0005434825614	5282	Economy	28000.00
0005434558421	5282	Economy	28000.00
0005435373962	5282	Economy	28000.00
0005434825695	5282	Economy	28000.00
0005434825652	5282	Economy	28000.00
0005432823457	5282	Economy	28000.00
0005435373718	5282	Economy	28000.00
0005432394171	5282	Economy	28000.00
0005434825656	5282	Economy	28000.00
0005434825715	5282	Economy	28000.00
0005434825699	5282	Economy	28000.00
0005435373724	5282	Economy	28000.00
0005435373929	5282	Economy	28000.00
0005434825601	5282	Economy	28000.00
0005434825639	5282	Economy	28000.00
0005435373675	5282	Economy	28000.00
0005435386594	5282	Economy	28000.00
0005435373963	5282	Economy	28000.00
0005434825631	5282	Economy	28000.00
0005434825672	5282	Economy	28000.00
0005435735170	5282	Economy	28000.00
0005435304189	5282	Economy	28000.00
0005435735169	5282	Economy	28000.00
0005434825675	5282	Economy	28000.00
0005434825681	5282	Economy	28000.00
0005434825645	5282	Economy	28000.00
0005434825657	5282	Economy	28000.00
0005434825613	5282	Economy	28000.00
0005434825655	5282	Economy	28000.00
0005435304196	5282	Economy	28000.00
0005434831222	5282	Economy	28000.00
0005435661941	5282	Economy	28000.00
0005434825688	5282	Economy	28000.00
0005435304200	5282	Economy	28000.00
0005434825701	5282	Economy	28000.00
0005435373850	5282	Economy	28000.00
0005434831224	5282	Economy	28000.00
0005434825704	5282	Economy	28000.00
0005434825650	5282	Economy	28000.00
0005435386612	5282	Economy	28000.00
0005435373747	5282	Economy	28000.00
0005435661958	5282	Economy	28000.00
0005435150259	5282	Economy	28000.00
0005432396310	5282	Economy	28000.00
0005434825597	5282	Economy	28000.00
0005434825644	5282	Economy	28000.00
0005432396307	5282	Economy	28000.00
0005434825698	5282	Economy	28000.00
0005435304203	5282	Economy	28000.00
0005434825660	5282	Economy	28000.00
0005434825626	5282	Economy	28000.00
0005434825711	5282	Economy	28000.00
0005435304205	5282	Economy	28000.00
0005434825605	5282	Economy	28000.00
0005434825619	5282	Economy	28000.00
0005434825598	5282	Economy	28000.00
0005435735164	5282	Economy	28000.00
0005434825636	5282	Economy	28000.00
0005434831226	5282	Economy	28000.00
0005434825663	5282	Economy	28000.00
0005434825673	5282	Economy	28000.00
0005434825722	5282	Economy	28000.00
0005434825643	5282	Economy	28000.00
0005435735163	5282	Economy	28000.00
0005434825725	5282	Economy	28000.00
0005434825676	5282	Economy	28000.00
0005435373784	5282	Economy	28000.00
0005435373862	5282	Economy	28000.00
0005434825705	5282	Economy	28000.00
0005434825724	5282	Economy	28000.00
0005434825634	5282	Economy	28000.00
0005434825624	5282	Economy	28000.00
0005435373384	5282	Economy	28000.00
0005434825616	5282	Economy	28000.00
0005434558424	5282	Economy	28000.00
0005435304201	5282	Economy	28000.00
0005434824823	9911	Business	84000.00
0005435374319	9911	Business	84000.00
0005434824221	9911	Business	84000.00
0005434824865	9911	Business	84000.00
0005434824385	9911	Business	84000.00
0005434824215	9911	Business	84000.00
0005432203178	9911	Business	84000.00
0005434824949	9911	Business	84000.00
0005434824825	9911	Business	84000.00
0005434823670	9911	Business	84000.00
0005434824185	9911	Business	84000.00
0005435374337	9911	Business	84000.00
0005435374320	9911	Business	84000.00
0005435374297	9911	Business	84000.00
0005434824367	9911	Business	84000.00
0005435374300	9911	Business	84000.00
0005434825010	9911	Business	84000.00
0005435374309	9911	Business	84000.00
0005434824342	9911	Business	84000.00
0005432203185	9911	Business	84000.00
0005434824674	9911	Business	84000.00
0005435735216	9911	Business	84000.00
0005435299853	9911	Business	84000.00
0005432400172	9911	Comfort	47600.00
0005435150118	9911	Business	84000.00
0005434824294	9911	Comfort	47600.00
0005435374351	9911	Comfort	47600.00
0005434824571	9911	Comfort	47600.00
0005434824343	9911	Comfort	47600.00
0005435150145	9911	Comfort	47600.00
0005434824220	9911	Comfort	47600.00
0005434824647	9911	Comfort	47600.00
0005434824748	9911	Comfort	47600.00
0005434824371	9911	Comfort	47600.00
0005435299855	9911	Comfort	47600.00
0005435374342	9911	Comfort	47600.00
0005435374330	9911	Comfort	47600.00
0005435374321	9911	Comfort	47600.00
0005435302275	9911	Comfort	47600.00
0005435374334	9911	Comfort	47600.00
0005435150089	9911	Comfort	47600.00
0005434823671	9911	Comfort	47600.00
0005435374355	9911	Comfort	47600.00
0005434825014	9911	Comfort	47600.00
0005434825194	9911	Comfort	47600.00
0005434824222	9911	Comfort	47600.00
0005432203184	9911	Comfort	47600.00
0005435302276	9911	Comfort	47600.00
0005434824740	9911	Comfort	47600.00
0005434558315	9911	Comfort	47600.00
0005434824710	9911	Comfort	47600.00
0005435735215	9911	Comfort	47600.00
0005434824338	9911	Comfort	47600.00
0005434824607	9911	Comfort	47600.00
0005435374301	9911	Comfort	47600.00
0005434664986	9911	Comfort	47600.00
0005435374340	9911	Comfort	47600.00
0005435374308	9911	Economy	28000.00
0005434824271	9911	Economy	28000.00
0005434824414	9911	Economy	28000.00
0005434824223	9911	Economy	28000.00
0005435374356	9911	Economy	28000.00
0005434824749	9911	Economy	28000.00
0005435374333	9911	Economy	28000.00
0005435150090	9911	Economy	28000.00
0005435386678	9911	Economy	28000.00
0005435374324	9911	Economy	28000.00
0005434824559	9911	Economy	28000.00
0005432203181	9911	Economy	28000.00
0005435374341	9911	Economy	28000.00
0005434824585	9911	Economy	28000.00
0005434824558	9911	Economy	28000.00
0005435374317	9911	Economy	28000.00
0005434824573	9911	Economy	28000.00
0005435299852	9911	Economy	28000.00
0005435735214	9911	Economy	28000.00
0005434831174	9911	Economy	28000.00
0005434824675	9911	Economy	28000.00
0005435735212	9911	Economy	28000.00
0005435374325	9911	Economy	28000.00
0005434558319	9911	Economy	28000.00
0005434824950	9911	Economy	28000.00
0005432396272	9911	Economy	28000.00
0005434824334	9911	Economy	28000.00
0005432400154	9911	Economy	28000.00
0005435374347	9911	Economy	28000.00
0005434824932	9911	Economy	28000.00
0005435150054	9911	Economy	28000.00
0005434824497	9911	Economy	28000.00
0005434828722	9911	Economy	28000.00
0005435150115	9911	Economy	28000.00
0005434824308	9911	Economy	28000.00
0005435735217	9911	Economy	28000.00
0005434558307	9911	Economy	28000.00
0005434824713	9911	Economy	28000.00
0005434824495	9911	Economy	28000.00
0005435374348	9911	Economy	28000.00
0005435374313	9911	Economy	28000.00
0005432396277	9911	Economy	28000.00
0005434824362	9911	Economy	28000.00
0005434824681	9911	Economy	28000.00
0005435374358	9911	Economy	28000.00
0005434824191	9911	Economy	28000.00
0005434664985	9911	Economy	28000.00
0005435374339	9911	Economy	28000.00
0005435374352	9911	Economy	28000.00
0005434824283	9911	Economy	28000.00
0005434824724	9911	Economy	28000.00
0005434664975	9911	Economy	28000.00
0005435386676	9911	Economy	30800.00
0005432823483	9911	Economy	28000.00
0005434824584	9911	Economy	30800.00
0005434824780	9911	Economy	28000.00
0005435302273	9911	Economy	28000.00
0005434824446	9911	Economy	28000.00
0005434824184	9911	Economy	28000.00
0005434823810	9911	Economy	30800.00
0005432396282	9911	Economy	30800.00
0005434824572	9911	Economy	30800.00
0005434824532	9911	Economy	28000.00
0005434824858	9911	Economy	28000.00
0005435150134	9911	Economy	28000.00
0005435302274	9911	Economy	28000.00
0005435374316	9911	Economy	28000.00
0005435374323	9911	Economy	28000.00
0005434824284	9911	Economy	28000.00
0005435150099	9911	Economy	28000.00
0005432396276	9911	Economy	28000.00
0005434823751	9911	Economy	28000.00
0005435374326	9911	Economy	28000.00
0005435374305	9911	Economy	28000.00
0005435299854	9911	Economy	28000.00
0005434824733	9911	Economy	28000.00
0005435374311	9911	Economy	28000.00
0005434558308	9911	Economy	28000.00
0005434824931	9911	Economy	28000.00
0005435374345	9911	Economy	28000.00
0005434824831	9911	Economy	28000.00
0005435374359	9911	Economy	28000.00
0005434824217	9911	Economy	28000.00
0005434828719	9911	Economy	28000.00
0005435150108	9911	Economy	28000.00
0005435374350	9911	Economy	28000.00
0005434824135	9911	Economy	28000.00
0005434823979	9911	Economy	28000.00
0005435374361	9911	Economy	28000.00
0005435386675	9911	Economy	28000.00
0005434828704	9911	Economy	28000.00
0005435374331	9911	Economy	28000.00
0005432400168	9911	Economy	28000.00
0005434824498	9911	Economy	28000.00
0005435386677	9911	Economy	28000.00
0005435374306	9911	Economy	28000.00
0005434824386	9911	Economy	28000.00
0005434824224	9911	Economy	28000.00
0005434831179	9911	Economy	28000.00
0005434664974	9911	Economy	28000.00
0005434824226	9911	Economy	28000.00
0005434824936	9911	Economy	28000.00
0005432203183	9911	Economy	28000.00
0005434825074	9911	Economy	28000.00
0005434824216	9911	Economy	28000.00
0005434558320	9911	Economy	28000.00
0005434664978	9911	Economy	28000.00
0005434824188	9911	Economy	28000.00
0005435374332	9911	Economy	28000.00
0005432400171	9911	Economy	28000.00
0005434824849	9911	Economy	28000.00
0005434824714	9911	Economy	28000.00
0005434824323	9911	Economy	28000.00
0005434828718	9911	Economy	28000.00
0005434824339	9911	Economy	28000.00
0005435374328	9911	Economy	28000.00
0005435374338	9911	Economy	28000.00
0005435374357	9911	Economy	28000.00
0005435150146	9911	Economy	28000.00
0005434824830	9911	Economy	28000.00
0005435374336	9911	Economy	28000.00
0005434824519	9911	Economy	28000.00
0005434824182	9911	Economy	28000.00
0005434824242	9911	Economy	28000.00
0005435735213	9911	Economy	28000.00
0005434824850	9911	Economy	28000.00
0005435374314	9911	Economy	28000.00
0005435374362	9911	Economy	28000.00
0005434824187	9911	Economy	28000.00
0005435302277	9911	Economy	28000.00
0005435374346	9911	Economy	28000.00
0005435150116	9911	Economy	28000.00
0005434824739	9911	Economy	30800.00
0005434824769	9911	Economy	30800.00
0005434824306	9911	Economy	30800.00
0005434824712	9911	Economy	28000.00
0005435386674	9911	Economy	30800.00
0005435374360	9911	Economy	28000.00
0005435374307	9911	Economy	28000.00
0005435374335	9911	Economy	28000.00
0005434823980	9911	Economy	28000.00
0005434825193	9911	Economy	28000.00
0005434558324	9911	Economy	28000.00
0005434824687	9911	Economy	28000.00
0005434824619	9911	Economy	28000.00
0005435386679	9911	Economy	28000.00
0005434824747	9911	Economy	28000.00
0005435374299	9911	Economy	28000.00
0005435374296	9911	Economy	28000.00
0005435150147	9911	Economy	28000.00
0005435386680	9911	Economy	28000.00
0005434824241	9911	Economy	28000.00
0005435374354	9911	Economy	28000.00
0005435374318	9911	Economy	28000.00
0005434824628	9911	Economy	28000.00
0005435374344	9911	Economy	28000.00
0005435374303	9911	Economy	28000.00
0005435374329	9911	Economy	28000.00
0005435374327	9911	Economy	28000.00
0005435299851	9911	Economy	28000.00
0005435150133	9911	Economy	28000.00
0005434824937	9911	Economy	28000.00
0005435374298	9911	Economy	28000.00
0005434824363	9911	Economy	28000.00
0005434824832	9911	Economy	28000.00
0005434824665	9911	Economy	28000.00
0005434825088	9911	Economy	28000.00
0005435314954	9911	Economy	28000.00
0005434825195	9911	Economy	28000.00
0005434824590	9911	Economy	28000.00
0005435374353	9911	Economy	28000.00
0005434824826	9911	Economy	28000.00
0005434824192	9911	Economy	28000.00
0005434825096	9911	Economy	28000.00
0005435374302	9911	Economy	28000.00
0005432203186	9911	Economy	28000.00
0005435374349	9911	Economy	28000.00
0005434824711	9911	Economy	28000.00
0005435374304	9911	Economy	28000.00
0005434823889	9911	Economy	28000.00
0005432400155	9911	Economy	28000.00
0005435150110	9911	Economy	28000.00
0005434825087	9911	Economy	28000.00
0005432823484	9911	Economy	28000.00
0005432203182	9911	Economy	28000.00
0005434824857	9911	Economy	28000.00
0005435150109	9911	Economy	28000.00
0005434824160	9911	Economy	28000.00
0005435150114	9911	Economy	28000.00
0005434828720	9911	Economy	28000.00
0005434824564	9911	Economy	28000.00
0005434558299	9911	Economy	28000.00
0005434824974	9911	Economy	28000.00
0005434824768	9911	Economy	28000.00
0005435374315	9911	Economy	28000.00
0005434824447	9911	Economy	28000.00
0005435374310	9911	Economy	28000.00
0005432203180	9911	Economy	28000.00
0005434824776	9911	Economy	28000.00
0005435314953	9911	Economy	28000.00
0005435374322	9911	Economy	28000.00
0005434824671	9911	Economy	28000.00
0005435374312	9911	Economy	28000.00
0005434824680	9911	Economy	28000.00
0005434824792	9911	Economy	28000.00
0005434664977	9911	Economy	28000.00
0005434824295	9911	Economy	28000.00
0005434823809	9911	Economy	28000.00
0005434824725	9911	Economy	28000.00
0005435374343	9911	Economy	28000.00
0005435661980	9911	Economy	28000.00
0005434824181	9911	Economy	28000.00
0005434823874	9911	Economy	28000.00
0005434824202	9911	Economy	28000.00
0005435150128	9911	Economy	28000.00
0005432203179	9911	Economy	28000.00
0005434824791	9911	Economy	28000.00
0005434824448	9911	Economy	28000.00
0005432396281	9911	Economy	28000.00
0005435082920	6985	Economy	8200.00
0005435790353	6985	Economy	8200.00
0005435082923	6985	Economy	7400.00
0005435082921	6985	Economy	7400.00
0005435082926	6985	Economy	7400.00
0005435082922	6985	Economy	7400.00
0005435082918	6985	Economy	7400.00
0005435082924	6985	Economy	7400.00
0005435082917	6985	Economy	7400.00
0005435082919	6985	Economy	7400.00
0005435082916	6985	Economy	7400.00
0005435082925	6985	Economy	7400.00
0005435790354	6985	Economy	7400.00
0005435790355	6985	Economy	7400.00
0005435082848	25980	Economy	8200.00
0005435082845	25980	Economy	8200.00
0005435082831	25980	Economy	7400.00
0005435790320	25980	Economy	7400.00
0005435082842	25980	Economy	7400.00
0005435790326	25980	Economy	7400.00
0005435790334	25980	Economy	7400.00
0005435082841	25980	Economy	7400.00
0005435082835	25980	Economy	7400.00
0005435082834	25980	Economy	7400.00
0005435790333	25980	Economy	7400.00
0005435082847	25980	Economy	7400.00
0005435790319	25980	Economy	7400.00
0005434214803	9542	Business	32800.00
0005434214771	9542	Business	32800.00
0005434757100	9542	Business	32800.00
0005434214892	9542	Business	32800.00
0005434214795	9542	Business	32800.00
0005434757129	9542	Business	32800.00
0005434215044	9542	Business	32800.00
0005434757104	9542	Business	32800.00
0005434214956	9542	Business	32800.00
0005434214762	9542	Business	32800.00
0005434214920	9542	Business	32800.00
0005434757119	9542	Business	32800.00
0005434214658	9542	Economy	10900.00
0005434214701	9542	Economy	10900.00
0005434214850	9542	Economy	10900.00
0005434757116	9542	Economy	10900.00
0005434214955	9542	Economy	10900.00
0005434214979	9542	Economy	10900.00
0005434214889	9542	Economy	10900.00
0005434214842	9542	Economy	10900.00
0005434214815	9542	Economy	10900.00
0005434757114	9542	Economy	12000.00
0005434757128	9542	Economy	12000.00
0005434214953	9542	Economy	12000.00
0005434214821	9542	Economy	12000.00
0005434757120	9542	Economy	12000.00
0005434214805	9542	Economy	10900.00
0005434757124	9542	Economy	10900.00
0005434757121	9542	Economy	10900.00
0005434757112	9542	Economy	10900.00
0005434757108	9542	Economy	10900.00
0005434214773	9542	Economy	10900.00
0005434214708	9542	Economy	10900.00
0005434214893	9542	Economy	10900.00
0005434214872	9542	Economy	10900.00
0005434214746	9542	Economy	10900.00
0005434214620	9542	Economy	10900.00
0005434214874	9542	Economy	10900.00
0005434757106	9542	Economy	10900.00
0005434757111	9542	Economy	10900.00
0005434757127	9542	Economy	10900.00
0005434757126	9542	Economy	10900.00
0005434214881	9542	Economy	10900.00
0005434214776	9542	Economy	10900.00
0005434214772	9542	Economy	10900.00
0005434214657	9542	Economy	10900.00
0005434214957	9542	Economy	10900.00
0005434214794	9542	Economy	10900.00
0005434757107	9542	Economy	10900.00
0005434757109	9542	Economy	10900.00
0005434214857	9542	Economy	10900.00
0005434214728	9542	Economy	10900.00
0005434214849	9542	Economy	10900.00
0005434214871	9542	Economy	10900.00
0005434757125	9542	Economy	10900.00
0005434214774	9542	Economy	10900.00
0005434214989	9542	Economy	10900.00
0005434214725	9542	Economy	10900.00
0005434757102	9542	Economy	10900.00
0005434214824	9542	Economy	10900.00
0005434757101	9542	Economy	10900.00
0005434214804	9542	Economy	10900.00
0005434757117	9542	Economy	10900.00
0005434757123	9542	Economy	10900.00
0005434215035	9542	Economy	10900.00
0005434214688	9542	Economy	10900.00
0005434757103	9542	Economy	10900.00
0005434215106	9542	Economy	10900.00
0005434214978	9542	Economy	10900.00
0005434214738	9542	Economy	10900.00
0005434214662	9542	Economy	10900.00
0005434214954	9542	Economy	10900.00
0005434214689	9542	Economy	10900.00
0005434214927	9542	Economy	10900.00
0005434214784	9542	Economy	10900.00
0005434214919	9542	Economy	10900.00
0005434214905	9542	Economy	10900.00
0005434214990	9542	Economy	10900.00
0005434214907	9542	Economy	10900.00
0005434757113	9542	Economy	10900.00
0005434214876	9542	Economy	10900.00
0005434214785	9542	Economy	10900.00
0005434214727	9542	Economy	10900.00
0005434214906	9542	Economy	10900.00
0005434757122	9542	Economy	10900.00
0005434214707	9542	Economy	10900.00
0005434757105	9542	Economy	10900.00
0005434757118	9542	Economy	10900.00
0005434214786	9542	Economy	10900.00
0005434214873	9542	Economy	10900.00
0005434214690	9542	Economy	10900.00
0005434214735	9542	Economy	10900.00
0005434757115	9542	Economy	10900.00
0005434214991	9542	Economy	10900.00
0005434757110	9542	Economy	10900.00
0005434215227	28587	Business	32800.00
0005434756614	28587	Business	32800.00
0005434756705	28587	Business	32800.00
0005434215236	28587	Business	32800.00
0005434756481	28587	Business	32800.00
0005434756545	28587	Business	32800.00
0005434215247	28587	Business	32800.00
0005434215266	28587	Business	32800.00
0005434215263	28587	Business	32800.00
0005434215230	28587	Business	32800.00
0005434215255	28587	Business	32800.00
0005434756740	28587	Business	32800.00
0005434215257	28587	Economy	10900.00
0005434756796	28587	Economy	10900.00
0005434215223	28587	Economy	10900.00
0005434756731	28587	Economy	10900.00
0005434215265	28587	Economy	10900.00
0005434756712	28587	Economy	10900.00
0005434215259	28587	Economy	10900.00
0005434756798	28587	Economy	10900.00
0005434756605	28587	Economy	10900.00
0005434215226	28587	Economy	12000.00
0005434756644	28587	Economy	12000.00
0005434215258	28587	Economy	12000.00
0005434215254	28587	Economy	12000.00
0005434756795	28587	Economy	10900.00
0005434756721	28587	Economy	10900.00
0005434215232	28587	Economy	10900.00
0005434215251	28587	Economy	10900.00
0005434756733	28587	Economy	10900.00
0005434215231	28587	Economy	10900.00
0005434756734	28587	Economy	10900.00
0005434215262	28587	Economy	10900.00
0005434215225	28587	Economy	10900.00
0005434756665	28587	Economy	10900.00
0005434215242	28587	Economy	10900.00
0005434756629	28587	Economy	10900.00
0005434215245	28587	Economy	10900.00
0005434756696	28587	Economy	10900.00
0005434215235	28587	Economy	10900.00
0005434756467	28587	Economy	10900.00
0005434756811	28587	Economy	10900.00
0005434756525	28587	Economy	10900.00
0005434215267	28587	Economy	10900.00
0005434215252	28587	Economy	10900.00
0005434215241	28587	Economy	10900.00
0005434215240	28587	Economy	10900.00
0005434756679	28587	Economy	10900.00
0005434215224	28587	Economy	10900.00
0005434756708	28587	Economy	10900.00
0005434756422	28587	Economy	10900.00
0005434756645	28587	Economy	10900.00
0005434215256	28587	Economy	10900.00
0005434756627	28587	Economy	10900.00
0005434756579	28587	Economy	10900.00
0005434756797	28587	Economy	10900.00
0005434756682	28587	Economy	10900.00
0005434756661	28587	Economy	10900.00
0005434215243	28587	Economy	10900.00
0005434215253	28587	Economy	10900.00
0005434215222	28587	Economy	10900.00
0005434756722	28587	Economy	10900.00
0005434215249	28587	Economy	10900.00
0005434215248	28587	Economy	10900.00
0005434756723	28587	Economy	10900.00
0005434215260	28587	Economy	10900.00
0005434756823	28587	Economy	10900.00
0005434215228	28587	Economy	10900.00
0005434756626	28587	Economy	10900.00
0005434215233	28587	Economy	10900.00
0005434756720	28587	Economy	10900.00
0005434756735	28587	Economy	10900.00
0005434215244	28587	Economy	10900.00
0005434215238	28587	Economy	10900.00
0005434756693	28587	Economy	10900.00
0005434756758	28587	Economy	10900.00
0005434756727	28587	Economy	10900.00
0005434215239	28587	Economy	10900.00
0005434756660	28587	Economy	10900.00
0005434215250	28587	Economy	10900.00
0005434756666	28587	Economy	10900.00
0005434215264	28587	Economy	10900.00
0005434756546	28587	Economy	10900.00
0005434756468	28587	Economy	10900.00
0005434215246	28587	Economy	10900.00
0005434756760	28587	Economy	10900.00
0005434215261	28587	Economy	10900.00
0005434756732	28587	Economy	10900.00
0005434215234	28587	Economy	10900.00
0005434215237	28587	Economy	10900.00
0005434756628	28587	Economy	10900.00
0005434756524	28587	Economy	10900.00
0005434215229	28587	Economy	10900.00
0005435100171	10843	Economy	8900.00
0005435100172	10843	Economy	8900.00
0005435100173	10843	Economy	8900.00
0005435100157	31795	Economy	9800.00
0005434760236	31795	Economy	8900.00
0005435100148	31795	Economy	8900.00
0005434760238	31795	Economy	8900.00
0005434760237	31795	Economy	8900.00
0005435948343	1984	Economy	20900.00
0005434639734	1984	Economy	20900.00
0005434639743	1984	Economy	20900.00
0005434639750	1984	Economy	19000.00
0005434639746	1984	Economy	19000.00
0005434639754	1984	Economy	19000.00
0005434639740	1984	Economy	19000.00
0005434639753	1984	Economy	19000.00
0005433202478	1984	Economy	19000.00
0005433202476	1984	Economy	19000.00
0005434639747	1984	Economy	19000.00
0005434639757	1984	Economy	19000.00
0005434639752	1984	Economy	19000.00
0005433202484	1984	Economy	19000.00
0005434639733	1984	Economy	19000.00
0005433202409	1984	Economy	19000.00
0005433202433	1984	Economy	19000.00
0005433202503	1984	Economy	19000.00
0005433202475	1984	Economy	19000.00
0005434639745	1984	Economy	19000.00
0005434639736	1984	Economy	19000.00
0005434639742	1984	Economy	19000.00
0005434639737	1984	Economy	19000.00
0005433202486	1984	Economy	19000.00
0005434639732	1984	Economy	19000.00
0005433202434	1984	Economy	19000.00
0005433202479	1984	Economy	19000.00
0005433202453	1984	Economy	19000.00
0005433202485	1984	Economy	19000.00
0005434639738	1984	Economy	19000.00
0005434639739	1984	Economy	19000.00
0005434639741	1984	Economy	19000.00
0005434639748	1984	Economy	19000.00
0005434639755	1984	Economy	19000.00
0005434639758	1984	Economy	19000.00
0005434639749	1984	Economy	19000.00
0005434639744	1984	Economy	19000.00
0005433202445	1984	Economy	19000.00
0005434639756	1984	Economy	19000.00
0005433202480	1984	Economy	19000.00
0005434639751	1984	Economy	19000.00
0005433202519	1984	Economy	19000.00
0005435948342	1984	Economy	19000.00
0005434639735	1984	Economy	19000.00
0005434639557	23295	Economy	20900.00
0005434639493	23295	Economy	20900.00
0005434639542	23295	Economy	20900.00
0005433202587	23295	Economy	20900.00
0005434639581	23295	Economy	19000.00
0005434639511	23295	Economy	19000.00
0005434639441	23295	Economy	19000.00
0005433202598	23295	Economy	19000.00
0005433202593	23295	Economy	19000.00
0005434639531	23295	Economy	19000.00
0005434639513	23295	Economy	19000.00
0005434639570	23295	Economy	19000.00
0005434639534	23295	Economy	19000.00
0005434639495	23295	Economy	19000.00
0005434639442	23295	Economy	19000.00
0005434639471	23295	Economy	19000.00
0005434639512	23295	Economy	19000.00
0005434639492	23295	Economy	19000.00
0005434639500	23295	Economy	19000.00
0005434639524	23295	Economy	19000.00
0005434639440	23295	Economy	19000.00
0005434639452	23295	Economy	19000.00
0005434639499	23295	Economy	19000.00
0005434639545	23295	Economy	19000.00
0005433202596	23295	Economy	19000.00
0005433202594	23295	Economy	19000.00
0005434639519	23295	Economy	19000.00
0005433202595	23295	Economy	19000.00
0005433202588	23295	Economy	19000.00
0005434639555	23295	Economy	19000.00
0005433202592	23295	Economy	19000.00
0005434639549	23295	Economy	19000.00
0005434639458	23295	Economy	19000.00
0005434639494	23295	Economy	19000.00
0005433202585	23295	Economy	19000.00
0005433202591	23295	Economy	19000.00
0005434639502	23295	Economy	19000.00
0005434639533	23295	Economy	19000.00
0005434639457	23295	Economy	19000.00
0005434639518	23295	Economy	19000.00
0005434639439	23295	Economy	19000.00
0005434639459	23295	Economy	19000.00
0005433202589	23295	Economy	19000.00
0005433202597	23295	Economy	19000.00
0005434639582	23295	Economy	19000.00
0005434639553	23295	Economy	19000.00
0005433202586	23295	Economy	19000.00
0005434639543	23295	Economy	19000.00
0005434639550	23295	Economy	19000.00
0005433202590	23295	Economy	19000.00
0005432111327	6051	Business	69700.00
0005434601260	6051	Business	69700.00
0005434601246	6051	Business	69700.00
0005434601259	6051	Business	69700.00
0005434601239	6051	Business	69700.00
0005434601237	6051	Business	69700.00
0005434601238	6051	Business	69700.00
0005434601257	6051	Economy	23200.00
0005433533372	6051	Economy	23200.00
0005433531356	6051	Economy	23200.00
0005435326779	6051	Economy	23200.00
0005434601261	6051	Economy	23200.00
0005434601240	6051	Economy	25600.00
0005435326901	6051	Economy	23200.00
0005434601252	6051	Economy	23200.00
0005434601263	6051	Economy	23200.00
0005435326884	6051	Economy	23200.00
0005433531354	6051	Economy	23200.00
0005435326865	6051	Economy	23200.00
0005433531355	6051	Economy	23200.00
0005434601245	6051	Economy	23200.00
0005435326775	6051	Economy	23200.00
0005434601242	6051	Economy	23200.00
0005434601258	6051	Economy	23200.00
0005434601248	6051	Economy	23200.00
0005434601262	6051	Economy	23200.00
0005433531357	6051	Economy	23200.00
0005435326890	6051	Economy	23200.00
0005433533371	6051	Economy	23200.00
0005435326851	6051	Economy	23200.00
0005435326843	6051	Economy	23200.00
0005434601247	6051	Economy	23200.00
0005435326852	6051	Economy	23200.00
0005434601256	6051	Economy	23200.00
0005432111328	6051	Economy	23200.00
0005434601251	6051	Economy	23200.00
0005434601243	6051	Economy	23200.00
0005434601264	6051	Economy	23200.00
0005435326855	6051	Economy	23200.00
0005434601244	6051	Economy	23200.00
0005435326825	6051	Economy	23200.00
0005434601253	6051	Economy	23200.00
0005435326827	6051	Economy	23200.00
0005434601250	6051	Economy	23200.00
0005434601241	6051	Economy	23200.00
0005435326778	6051	Economy	23200.00
0005434601254	6051	Economy	23200.00
0005434601255	6051	Economy	23200.00
0005433533370	6051	Economy	23200.00
0005435326889	6051	Economy	23200.00
0005434601249	6051	Economy	23200.00
0005432111326	6051	Economy	23200.00
0005435326971	18585	Business	69700.00
0005435326972	18585	Business	69700.00
0005434601043	18585	Business	69700.00
0005433527283	18585	Business	69700.00
0005435326974	18585	Business	69700.00
0005434600920	18585	Business	69700.00
0005435326967	18585	Business	69700.00
0005434601083	18585	Business	69700.00
0005435326976	18585	Business	69700.00
0005434601029	18585	Economy	23200.00
0005434601046	18585	Economy	23200.00
0005434600989	18585	Economy	23200.00
0005434601061	18585	Economy	25600.00
0005434601053	18585	Economy	23200.00
0005434601027	18585	Economy	23200.00
0005435326978	18585	Economy	23200.00
0005434601070	18585	Economy	23200.00
0005434601019	18585	Economy	23200.00
0005433527287	18585	Economy	23200.00
0005434600933	18585	Economy	23200.00
0005433531337	18585	Economy	23200.00
0005435326965	18585	Economy	23200.00
0005434600969	18585	Economy	23200.00
0005435326973	18585	Economy	23200.00
0005434601039	18585	Economy	23200.00
0005433531322	18585	Economy	23200.00
0005434601110	18585	Economy	23200.00
0005434600993	18585	Economy	23200.00
0005435326969	18585	Economy	23200.00
0005434601084	18585	Economy	23200.00
0005434600940	18585	Economy	23200.00
0005434601052	18585	Economy	23200.00
0005435326966	18585	Economy	23200.00
0005435326975	18585	Economy	23200.00
0005433527288	18585	Economy	23200.00
0005434600941	18585	Economy	23200.00
0005433527284	18585	Economy	23200.00
0005434601000	18585	Economy	23200.00
0005433531323	18585	Economy	23200.00
0005434601067	18585	Economy	23200.00
0005434600934	18585	Economy	23200.00
0005435326968	18585	Economy	23200.00
0005434601030	18585	Economy	23200.00
0005434600988	18585	Economy	23200.00
0005435326977	18585	Economy	23200.00
0005435326970	18585	Economy	23200.00
0005434552051	10633	Business	9100.00
0005434552095	10633	Business	9100.00
0005433181257	10633	Business	9100.00
0005433181174	10633	Business	9100.00
0005434552074	10633	Business	9100.00
0005434558413	10633	Business	9100.00
0005433181222	10633	Business	9100.00
0005434552059	10633	Business	9100.00
0005433181306	10633	Business	9100.00
0005433181348	10633	Business	9100.00
0005434552101	10633	Economy	3000.00
0005434552055	10633	Economy	3000.00
0005434552066	10633	Economy	3000.00
0005434552069	10633	Economy	3000.00
0005434552079	10633	Economy	3000.00
0005433181134	10633	Economy	3000.00
0005433181364	10633	Economy	3000.00
0005434558414	10633	Economy	3000.00
0005434552068	10633	Economy	3000.00
0005434552080	10633	Economy	3300.00
0005434552073	10633	Economy	3300.00
0005434552090	10633	Economy	3300.00
0005434552062	10633	Economy	3300.00
0005434552054	10633	Economy	3300.00
0005433181209	10633	Economy	3000.00
0005434552050	10633	Economy	3000.00
0005433181262	10633	Economy	3000.00
0005433181135	10633	Economy	3000.00
0005434552093	10633	Economy	3000.00
0005434552082	10633	Economy	3000.00
0005434552091	10633	Economy	3000.00
0005434552086	10633	Economy	3000.00
0005433181156	10633	Economy	3000.00
0005433181274	10633	Economy	3000.00
0005434558412	10633	Economy	3000.00
0005434552064	10633	Economy	3000.00
0005433181363	10633	Economy	3000.00
0005434552085	10633	Economy	3000.00
0005434558411	10633	Economy	3000.00
0005434552070	10633	Economy	3000.00
0005434552060	10633	Economy	3000.00
0005434552072	10633	Economy	3000.00
0005434552083	10633	Economy	3000.00
0005433181157	10633	Economy	3000.00
0005434552063	10633	Economy	3000.00
0005434552094	10633	Economy	3000.00
0005433181275	10633	Economy	3000.00
0005434552067	10633	Economy	3000.00
0005434552092	10633	Economy	3000.00
0005433181261	10633	Economy	3000.00
0005434552077	10633	Economy	3000.00
0005434552049	10633	Economy	3000.00
0005434552071	10633	Economy	3000.00
0005434552099	10633	Economy	3000.00
0005434552061	10633	Economy	3000.00
0005434552078	10633	Economy	3000.00
0005434552100	10633	Economy	3000.00
0005434552057	10633	Economy	3000.00
0005434552096	10633	Economy	3000.00
0005433181308	10633	Economy	3000.00
0005434552076	10633	Economy	3000.00
0005434554098	10633	Economy	3000.00
0005434552058	10633	Economy	3000.00
0005434552089	10633	Economy	3000.00
0005434552081	10633	Economy	3000.00
0005434552102	10633	Economy	3000.00
0005434558416	10633	Economy	3000.00
0005434552104	10633	Economy	3000.00
0005433181227	10633	Economy	3000.00
0005433181347	10633	Economy	3000.00
0005433181276	10633	Economy	3000.00
0005433181210	10633	Economy	3000.00
0005433181333	10633	Economy	3000.00
0005433181285	10633	Economy	3000.00
0005434558415	10633	Economy	3000.00
0005434558417	10633	Economy	3000.00
0005434552056	10633	Economy	3000.00
0005434552097	10633	Economy	3000.00
0005434552084	10633	Economy	3000.00
0005434552087	10633	Economy	3000.00
0005434552053	10633	Economy	3000.00
0005434558418	10633	Economy	3000.00
0005434552088	10633	Economy	3000.00
0005433181298	10633	Economy	3000.00
0005434552075	10633	Economy	3000.00
0005433181334	10633	Economy	3000.00
0005434552103	10633	Economy	3000.00
0005434552065	10633	Economy	3000.00
0005434554097	10633	Economy	3000.00
0005433181221	10633	Economy	3000.00
0005434552052	10633	Economy	3000.00
0005433181284	10633	Economy	3000.00
0005434552098	10633	Economy	3000.00
0005433181522	27755	Business	9100.00
0005433181527	27755	Business	9100.00
0005433181514	27755	Business	9100.00
0005433181503	27755	Business	9100.00
0005435314954	27755	Economy	3000.00
0005433181523	27755	Economy	3300.00
0005433181505	27755	Economy	3000.00
0005433181516	27755	Economy	3000.00
0005433181510	27755	Economy	3000.00
0005433181524	27755	Economy	3000.00
0005433181520	27755	Economy	3000.00
0005433181519	27755	Economy	3000.00
0005433181507	27755	Economy	3000.00
0005435314953	27755	Economy	3000.00
0005433181501	27755	Economy	3000.00
0005433181509	27755	Economy	3000.00
0005433181521	27755	Economy	3000.00
0005433181513	27755	Economy	3000.00
0005433181504	27755	Economy	3000.00
0005433181502	27755	Economy	3000.00
0005433181526	27755	Economy	3000.00
0005433181518	27755	Economy	3000.00
0005433181515	27755	Economy	3000.00
0005433181511	27755	Economy	3000.00
0005433181506	27755	Economy	3000.00
0005433181525	27755	Economy	3000.00
0005433181508	27755	Economy	3000.00
0005433181512	27755	Economy	3000.00
0005433181517	27755	Economy	3000.00
0005434551644	27756	Business	9100.00
0005434551675	27756	Business	9100.00
0005434558286	27756	Business	9100.00
0005434551684	27756	Business	9100.00
0005434558344	27756	Business	9100.00
0005434554086	27756	Business	9100.00
0005434551722	27756	Business	9100.00
0005434551626	27756	Economy	3000.00
0005434551728	27756	Economy	3000.00
0005434551727	27756	Economy	3000.00
0005434551758	27756	Economy	3300.00
0005434551743	27756	Economy	3300.00
0005434551697	27756	Economy	3000.00
0005434551809	27756	Economy	3000.00
0005434551812	27756	Economy	3000.00
0005434558311	27756	Economy	3000.00
0005434551801	27756	Economy	3000.00
0005434551734	27756	Economy	3000.00
0005434558346	27756	Economy	3000.00
0005434551637	27756	Economy	3000.00
0005434558342	27756	Economy	3000.00
0005434558298	27756	Economy	3000.00
0005434551622	27756	Economy	3000.00
0005434551645	27756	Economy	3000.00
0005434551381	27756	Economy	3000.00
0005434551852	27756	Economy	3000.00
0005434551382	27756	Economy	3000.00
0005434558325	27756	Economy	3000.00
0005434551674	27756	Economy	3000.00
0005434551805	27756	Economy	3000.00
0005434551655	27756	Economy	3000.00
0005434551726	27756	Economy	3000.00
0005434551638	27756	Economy	3000.00
0005434551788	27756	Economy	3000.00
0005434558349	27756	Economy	3000.00
0005434551596	27756	Economy	3000.00
0005434551695	27756	Economy	3000.00
0005434551979	27756	Economy	3000.00
0005434551685	27756	Economy	3000.00
0005434558353	27756	Economy	3000.00
0005434558310	27756	Economy	3000.00
0005434551505	27756	Economy	3000.00
0005434551581	27756	Economy	3000.00
0005434551721	27756	Economy	3000.00
0005434551600	27756	Economy	3000.00
0005433459289	6149	Economy	11700.00
0005433459288	6149	Economy	11700.00
0005435254494	6149	Economy	11700.00
0005435254495	6149	Economy	11700.00
0005435254496	6149	Economy	11700.00
0005435254488	6149	Economy	11700.00
0005433459290	6149	Economy	11700.00
0005433459268	19342	Economy	11700.00
0005435254513	19342	Economy	11700.00
0005435254514	19342	Economy	11700.00
0005435254512	19342	Economy	11700.00
0005432136248	6737	Business	51100.00
0005435438017	6737	Business	51100.00
0005435682776	6737	Business	51100.00
0005435682805	6737	Business	51100.00
0005435682800	6737	Business	51100.00
0005435682775	6737	Business	51100.00
0005435682781	6737	Business	51100.00
0005435682809	6737	Business	51100.00
0005432533321	6737	Business	51100.00
0005435438135	6737	Business	51100.00
0005435438160	6737	Business	51100.00
0005435682793	6737	Business	51100.00
0005432136250	6737	Economy	17000.00
0005435719579	6737	Economy	17000.00
0005435661978	6737	Economy	17000.00
0005435438146	6737	Economy	17000.00
0005435438156	6737	Economy	17000.00
0005435682772	6737	Economy	17000.00
0005435682801	6737	Economy	17000.00
0005435682770	6737	Economy	17000.00
0005435438159	6737	Economy	17000.00
0005435682803	6737	Economy	17000.00
0005435661976	6737	Economy	18700.00
0005435720150	6737	Economy	18700.00
0005435220333	6737	Economy	18700.00
0005435661977	6737	Economy	18700.00
0005435631015	6737	Economy	18700.00
0005435682811	6737	Economy	17000.00
0005435438013	6737	Economy	17000.00
0005435438084	6737	Economy	17000.00
0005435682786	6737	Economy	17000.00
0005435682792	6737	Economy	17000.00
0005435682783	6737	Economy	17000.00
0005435220345	6737	Economy	17000.00
0005435719578	6737	Economy	17000.00
0005435221523	6737	Economy	17000.00
0005435682804	6737	Economy	17000.00
0005435438076	6737	Economy	17000.00
0005435682789	6737	Economy	17000.00
0005432136252	6737	Economy	17000.00
0005435438172	6737	Economy	17000.00
0005435682796	6737	Economy	17000.00
0005435682787	6737	Economy	17000.00
0005435631013	6737	Economy	17000.00
0005435682773	6737	Economy	17000.00
0005435682808	6737	Economy	17000.00
0005435631014	6737	Economy	17000.00
0005435217728	6737	Economy	17000.00
0005432136253	6737	Economy	17000.00
0005435220332	6737	Economy	17000.00
0005435682768	6737	Economy	17000.00
0005432136251	6737	Economy	17000.00
0005435682771	6737	Economy	17000.00
0005435682784	6737	Economy	17000.00
0005435438154	6737	Economy	17000.00
0005435438147	6737	Economy	17000.00
0005435220331	6737	Economy	17000.00
0005435682774	6737	Economy	17000.00
0005435682806	6737	Economy	17000.00
0005435438200	6737	Economy	17000.00
0005435682798	6737	Economy	17000.00
0005435438173	6737	Economy	17000.00
0005435682778	6737	Economy	17000.00
0005435661975	6737	Economy	17000.00
0005435682797	6737	Economy	17000.00
0005435682788	6737	Economy	17000.00
0005435661979	6737	Economy	17000.00
0005435720149	6737	Economy	17000.00
0005435682790	6737	Economy	17000.00
0005435682807	6737	Economy	17000.00
0005435682799	6737	Economy	17000.00
0005435682782	6737	Economy	17000.00
0005435682795	6737	Economy	17000.00
0005435438124	6737	Economy	17000.00
0005435682794	6737	Economy	17000.00
0005435438155	6737	Economy	17000.00
0005435682802	6737	Economy	17000.00
0005435438075	6737	Economy	17000.00
0005435438157	6737	Economy	17000.00
0005435682785	6737	Economy	17000.00
0005435438162	6737	Economy	17000.00
0005435682777	6737	Economy	17000.00
0005435438171	6737	Economy	17000.00
0005435682812	6737	Economy	17000.00
0005435682769	6737	Economy	17000.00
0005435719580	6737	Economy	17000.00
0005435682791	6737	Economy	17000.00
0005435438199	6737	Economy	17000.00
0005435682779	6737	Economy	17000.00
0005435682780	6737	Economy	17000.00
0005435682813	6737	Economy	17000.00
0005435438204	6737	Economy	17000.00
0005435438089	6737	Economy	17000.00
0005435682810	6737	Economy	17000.00
0005432136249	6737	Economy	17000.00
0005435682251	24621	Business	51100.00
0005435438323	24621	Business	51100.00
0005435220495	24621	Business	51100.00
0005435682418	24621	Business	51100.00
0005435438324	24621	Business	51100.00
0005432533339	24621	Business	51100.00
0005435682484	24621	Business	51100.00
0005434828745	24621	Business	51100.00
0005435682276	24621	Business	51100.00
0005434828744	24621	Business	51100.00
0005435661954	24621	Economy	17000.00
0005435219232	24621	Economy	17000.00
0005435438315	24621	Economy	17000.00
0005435438308	24621	Economy	17000.00
0005435682252	24621	Economy	17000.00
0005435661951	24621	Economy	17000.00
0005435682489	24621	Economy	17000.00
0005435220350	24621	Economy	17000.00
0005435682369	24621	Economy	17000.00
0005435220353	24621	Economy	17000.00
0005435220493	24621	Economy	18700.00
0005435682348	24621	Economy	18700.00
0005432305790	24621	Economy	18700.00
0005435220351	24621	Economy	18700.00
0005435219235	24621	Economy	18700.00
0005435682388	24621	Economy	17000.00
0005435438311	24621	Economy	17000.00
0005435438316	24621	Economy	17000.00
0005432533338	24621	Economy	17000.00
0005435682387	24621	Economy	17000.00
0005432305789	24621	Economy	17000.00
0005435661955	24621	Economy	17000.00
0005435220496	24621	Economy	17000.00
0005432533340	24621	Economy	17000.00
0005435438309	24621	Economy	17000.00
0005435682389	24621	Economy	17000.00
0005435682304	24621	Economy	17000.00
0005435682476	24621	Economy	17000.00
0005435438322	24621	Economy	17000.00
0005435682454	24621	Economy	17000.00
0005435630980	24621	Economy	17000.00
0005434828742	24621	Economy	17000.00
0005435682455	24621	Economy	17000.00
0005435438313	24621	Economy	17000.00
0005435438306	24621	Economy	17000.00
0005435438317	24621	Economy	17000.00
0005435630996	24621	Economy	17000.00
0005435682419	24621	Economy	17000.00
0005435682391	24621	Economy	17000.00
0005435219233	24621	Economy	17000.00
0005435438314	24621	Economy	17000.00
0005435438318	24621	Economy	17000.00
0005435630986	24621	Economy	17000.00
0005435682307	24621	Economy	17000.00
0005435682390	24621	Economy	17000.00
0005435682402	24621	Economy	17000.00
0005432305788	24621	Economy	17000.00
0005435438304	24621	Economy	17000.00
0005435630994	24621	Economy	17000.00
0005435682373	24621	Economy	17000.00
0005435682435	24621	Economy	17000.00
0005435682275	24621	Economy	17000.00
0005435438305	24621	Economy	17000.00
0005435438303	24621	Economy	17000.00
0005435682306	24621	Economy	17000.00
0005435682475	24621	Economy	17000.00
0005435438319	24621	Economy	17000.00
0005435682474	24621	Economy	17000.00
0005435438325	24621	Economy	17000.00
0005435438312	24621	Economy	17000.00
0005435661950	24621	Economy	17000.00
0005435438307	24621	Economy	17000.00
0005435630997	24621	Economy	17000.00
0005435682403	24621	Economy	17000.00
0005435682421	24621	Economy	17000.00
0005435682460	24621	Economy	17000.00
0005435682372	24621	Economy	17000.00
0005435220494	24621	Economy	17000.00
0005435682434	24621	Economy	17000.00
0005435438321	24621	Economy	17000.00
0005434828743	24621	Economy	17000.00
0005435682477	24621	Economy	17000.00
0005435438320	24621	Economy	17000.00
0005435682365	24621	Economy	17000.00
0005435219231	24621	Economy	17000.00
0005435682469	24621	Economy	17000.00
0005435438310	24621	Economy	17000.00
0005435219234	24621	Economy	17000.00
0005435220352	24621	Economy	17000.00
0005435682492	24621	Economy	17000.00
0005435630979	24621	Economy	17000.00
0005435661948	24621	Economy	17000.00
0005435127018	11552	Business	26400.00
0005435126988	11552	Business	26400.00
0005435126990	11552	Business	26400.00
0005435127014	11552	Business	26400.00
0005435126981	11552	Business	26400.00
0005435127002	11552	Business	26400.00
0005435558097	11552	Business	26400.00
0005435127015	11552	Business	26400.00
0005435127005	11552	Economy	8800.00
0005435126997	11552	Economy	8800.00
0005435127013	11552	Economy	8800.00
0005435126985	11552	Economy	8800.00
0005435127010	11552	Economy	9700.00
0005435127003	11552	Economy	8800.00
0005435106033	11552	Economy	8800.00
0005435126983	11552	Economy	8800.00
0005435126994	11552	Economy	8800.00
0005435126987	11552	Economy	8800.00
0005435127016	11552	Economy	8800.00
0005435127020	11552	Economy	8800.00
0005435127007	11552	Economy	8800.00
0005435126999	11552	Economy	8800.00
0005435127004	11552	Economy	8800.00
0005435126996	11552	Economy	8800.00
0005435127012	11552	Economy	8800.00
0005435126993	11552	Economy	8800.00
0005435127017	11552	Economy	8800.00
0005435126984	11552	Economy	8800.00
0005435558098	11552	Economy	8800.00
0005435127019	11552	Economy	8800.00
0005435126992	11552	Economy	8800.00
0005435106031	11552	Economy	8800.00
0005435127000	11552	Economy	8800.00
0005435126998	11552	Economy	8800.00
0005435127008	11552	Economy	8800.00
0005435127009	11552	Economy	8800.00
0005435127006	11552	Economy	8800.00
0005435126995	11552	Economy	8800.00
0005435127011	11552	Economy	8800.00
0005435127001	11552	Economy	8800.00
0005435126982	11552	Economy	8800.00
0005435126986	11552	Economy	8800.00
0005435126991	11552	Economy	8800.00
0005435126989	11552	Economy	8800.00
0005435106032	11552	Economy	8800.00
0005435126651	31902	Business	26400.00
0005435126798	31902	Business	26400.00
0005435126556	31902	Business	26400.00
0005435126730	31902	Business	26400.00
0005435126534	31902	Business	26400.00
0005435126681	31902	Business	26400.00
0005435126641	31902	Business	26400.00
0005435126770	31902	Economy	8800.00
0005435126606	31902	Economy	9700.00
0005435126638	31902	Economy	9700.00
0005435126777	31902	Economy	9700.00
0005435126848	31902	Economy	9700.00
0005435558130	31902	Economy	8800.00
0005435126728	31902	Economy	8800.00
0005435126617	31902	Economy	8800.00
0005435558129	31902	Economy	8800.00
0005435126718	31902	Economy	8800.00
0005435126560	31902	Economy	8800.00
0005435126860	31902	Economy	8800.00
0005435126731	31902	Economy	8800.00
0005435126584	31902	Economy	8800.00
0005435126605	31902	Economy	8800.00
0005435126738	31902	Economy	8800.00
0005435126729	31902	Economy	8800.00
0005435126585	31902	Economy	8800.00
0005435126559	31902	Economy	8800.00
0005435126591	31902	Economy	8800.00
0005435126633	31902	Economy	8800.00
0005435126737	31902	Economy	8800.00
0005435126849	31902	Economy	8800.00
0005435106010	31902	Economy	8800.00
0005435106009	31902	Economy	8800.00
0005435126607	31902	Economy	8800.00
0005435126756	31902	Economy	8800.00
0005435126533	31902	Economy	8800.00
0005435126702	31902	Economy	8800.00
0005435558128	31902	Economy	8800.00
0005435126594	31902	Economy	8800.00
0005435126616	31902	Economy	8800.00
0005435126859	31902	Economy	8800.00
0005435126727	31902	Economy	8800.00
0005435126796	31902	Economy	8800.00
0005435126639	31902	Economy	8800.00
0005435126618	31902	Economy	8800.00
0005435126894	31902	Economy	8800.00
0005435126719	31902	Economy	8800.00
0005433398848	13527	Business	36600.00
0005433398867	13527	Business	36600.00
0005433398824	13527	Business	36600.00
0005433398844	13527	Business	36600.00
0005435732457	13527	Business	36600.00
0005433398857	13527	Business	36600.00
0005433398829	13527	Business	36600.00
0005435732370	13527	Business	36600.00
0005435732420	13527	Economy	12200.00
0005433398842	13527	Economy	12200.00
0005433398849	13527	Economy	12200.00
0005435732434	13527	Economy	12200.00
0005433398830	13527	Economy	12200.00
0005435732396	13527	Economy	12200.00
0005433398828	13527	Economy	12200.00
0005433398820	13527	Economy	13400.00
0005435732480	13527	Economy	13400.00
0005433398847	13527	Economy	13400.00
0005433398843	13527	Economy	13400.00
0005433398854	13527	Economy	12200.00
0005433398866	13527	Economy	12200.00
0005435732408	13527	Economy	12200.00
0005433398853	13527	Economy	12200.00
0005433398822	13527	Economy	12200.00
0005433398858	13527	Economy	12200.00
0005433398856	13527	Economy	12200.00
0005435732475	13527	Economy	12200.00
0005433398825	13527	Economy	12200.00
0005433398868	13527	Economy	12200.00
0005433398834	13527	Economy	12200.00
0005433398831	13527	Economy	12200.00
0005435732432	13527	Economy	12200.00
0005435732455	13527	Economy	12200.00
0005433398840	13527	Economy	12200.00
0005433398836	13527	Economy	12200.00
0005433398833	13527	Economy	12200.00
0005433398855	13527	Economy	12200.00
0005433398838	13527	Economy	12200.00
0005433398827	13527	Economy	12200.00
0005433398846	13527	Economy	12200.00
0005435732407	13527	Economy	12200.00
0005435732451	13527	Economy	12200.00
0005433398839	13527	Economy	12200.00
0005433398861	13527	Economy	12200.00
0005433398865	13527	Economy	12200.00
0005435732481	13527	Economy	12200.00
0005433398863	13527	Economy	12200.00
0005433398826	13527	Economy	12200.00
0005433398851	13527	Economy	12200.00
0005433398823	13527	Economy	12200.00
0005433398821	13527	Economy	12200.00
0005433398860	13527	Economy	12200.00
0005433398841	13527	Economy	12200.00
0005435732394	13527	Economy	12200.00
0005433398835	13527	Economy	12200.00
0005433398859	13527	Economy	12200.00
0005433398845	13527	Economy	12200.00
0005435732400	13527	Economy	12200.00
0005433398837	13527	Economy	12200.00
0005435732401	13527	Economy	12200.00
0005433398850	13527	Economy	12200.00
0005433398819	13527	Economy	12200.00
0005433398862	13527	Economy	12200.00
0005433398852	13527	Economy	12200.00
0005435732456	13527	Economy	12200.00
0005435732447	13527	Economy	12200.00
0005433398864	13527	Economy	12200.00
0005433398832	13527	Economy	12200.00
0005435732540	19382	Business	36600.00
0005433398413	19382	Business	36600.00
0005433398524	19382	Business	36600.00
0005433398468	19382	Business	36600.00
0005433398328	19382	Business	36600.00
0005433398344	19382	Business	36600.00
0005433398478	19382	Business	36600.00
0005433398410	19382	Business	36600.00
0005433398366	19382	Economy	12200.00
0005433398224	19382	Economy	12200.00
0005433398475	19382	Economy	12200.00
0005433398358	19382	Economy	12200.00
0005433398608	19382	Economy	12200.00
0005433398225	19382	Economy	12200.00
0005433398572	19382	Economy	12200.00
0005433398477	19382	Economy	13400.00
0005433398607	19382	Economy	13400.00
0005433398574	19382	Economy	13400.00
0005435732544	19382	Economy	13400.00
0005433398585	19382	Economy	12200.00
0005435732541	19382	Economy	12200.00
0005433398605	19382	Economy	12200.00
0005433398602	19382	Economy	12200.00
0005433398434	19382	Economy	12200.00
0005433398435	19382	Economy	12200.00
0005433398226	19382	Economy	12200.00
0005433398484	19382	Economy	12200.00
0005435732538	19382	Economy	12200.00
0005433398275	19382	Economy	12200.00
0005433398372	19382	Economy	12200.00
0005433398357	19382	Economy	12200.00
0005435732539	19382	Economy	12200.00
0005433398386	19382	Economy	12200.00
0005433398437	19382	Economy	12200.00
0005433398454	19382	Economy	12200.00
0005435732542	19382	Economy	12200.00
0005433398278	19382	Economy	12200.00
0005433398467	19382	Economy	12200.00
0005435732543	19382	Economy	12200.00
0005433398606	19382	Economy	12200.00
0005433398504	19382	Economy	12200.00
0005432297321	19382	Economy	12200.00
0005433398362	19382	Economy	12200.00
0005433398452	19382	Economy	12200.00
0005432297319	19382	Economy	12200.00
0005433398354	19382	Economy	12200.00
0005433398353	19382	Economy	12200.00
0005433398593	19382	Economy	12200.00
0005433398227	19382	Economy	12200.00
0005433398476	19382	Economy	12200.00
0005435732545	19382	Economy	12200.00
0005433398479	19382	Economy	12200.00
0005433398097	19382	Economy	12200.00
0005433398310	19382	Economy	12200.00
0005433398352	19382	Economy	12200.00
0005433398414	19382	Economy	12200.00
0005432297320	19382	Economy	12200.00
0005433398247	19382	Economy	12200.00
0005433398280	19382	Economy	12200.00
0005433398573	19382	Economy	12200.00
0005433398432	19382	Economy	12200.00
0005433398470	19382	Economy	12200.00
0005433398433	19382	Economy	12200.00
0005433398371	19382	Economy	12200.00
0005433398603	19382	Economy	12200.00
0005433398248	19382	Economy	12200.00
0005433398604	19382	Economy	12200.00
0005435925505	13190	Business	11300.00
0005435069440	13190	Business	11300.00
0005435069321	13190	Business	11300.00
0005435925511	13190	Business	11300.00
0005435069469	13190	Business	11300.00
0005435069323	13190	Business	11300.00
0005435069409	13190	Business	11300.00
0005435925521	13190	Business	11300.00
0005435069334	13190	Economy	3800.00
0005435925519	13190	Economy	3800.00
0005435925522	13190	Economy	3800.00
0005435069500	13190	Economy	3800.00
0005435069438	13190	Economy	3800.00
0005435069575	13190	Economy	4100.00
0005435925518	13190	Economy	4100.00
0005435069389	13190	Economy	4100.00
0005435925520	13190	Economy	4100.00
0005435069484	13190	Economy	4100.00
0005435925527	13190	Economy	3800.00
0005435925502	13190	Economy	3800.00
0005435069522	13190	Economy	3800.00
0005435925509	13190	Economy	3800.00
0005435069254	13190	Economy	3800.00
0005435925524	13190	Economy	3800.00
0005435925526	13190	Economy	3800.00
0005435925516	13190	Economy	3800.00
0005435069400	13190	Economy	3800.00
0005435925508	13190	Economy	3800.00
0005435069483	13190	Economy	3800.00
0005435069441	13190	Economy	3800.00
0005435069408	13190	Economy	3800.00
0005435925515	13190	Economy	3800.00
0005435069307	13190	Economy	3800.00
0005435925523	13190	Economy	3800.00
0005435925504	13190	Economy	3800.00
0005435925512	13190	Economy	3800.00
0005435925507	13190	Economy	3800.00
0005435069337	13190	Economy	3800.00
0005435069559	13190	Economy	3800.00
0005435069560	13190	Economy	3800.00
0005435925525	13190	Economy	3800.00
0005435925514	13190	Economy	3800.00
0005435925517	13190	Economy	3800.00
0005435925503	13190	Economy	3800.00
0005435069198	13190	Economy	3800.00
0005435069454	13190	Economy	3800.00
0005435069306	13190	Economy	3800.00
0005435069501	13190	Economy	3800.00
0005435925506	13190	Economy	3800.00
0005435069290	13190	Economy	3800.00
0005435069477	13190	Economy	3800.00
0005435069364	13190	Economy	3800.00
0005435069387	13190	Economy	3800.00
0005435069272	13190	Economy	3800.00
0005435069584	13190	Economy	3800.00
0005435925510	13190	Economy	3800.00
0005435069320	13190	Economy	3800.00
0005435925513	13190	Economy	3800.00
0005435925314	15517	Business	11300.00
0005435925357	15517	Business	11300.00
0005435925354	15517	Business	11300.00
0005435069902	15517	Business	11300.00
0005435069875	15517	Business	11300.00
0005435925346	15517	Business	11300.00
0005435069880	15517	Business	11300.00
0005435069889	15517	Business	11300.00
0005435069879	15517	Economy	3800.00
0005435925316	15517	Economy	3800.00
0005435069863	15517	Economy	3800.00
0005435069884	15517	Economy	3800.00
0005435069871	15517	Economy	3800.00
0005435925353	15517	Economy	3800.00
0005435925315	15517	Economy	3800.00
0005435069905	15517	Economy	3800.00
0005435069894	15517	Economy	3800.00
0005435069886	15517	Economy	4100.00
0005435069866	15517	Economy	4100.00
0005435925389	15517	Economy	4100.00
0005435069865	15517	Economy	3800.00
0005435069903	15517	Economy	3800.00
0005435069864	15517	Economy	3800.00
0005435069858	15517	Economy	3800.00
0005435069885	15517	Economy	3800.00
0005435069876	15517	Economy	3800.00
0005435925359	15517	Economy	3800.00
0005435069893	15517	Economy	3800.00
0005435069898	15517	Economy	3800.00
0005435069881	15517	Economy	3800.00
0005435069862	15517	Economy	3800.00
0005435069869	15517	Economy	3800.00
0005435069892	15517	Economy	3800.00
0005435069901	15517	Economy	3800.00
0005435069883	15517	Economy	3800.00
0005435069888	15517	Economy	3800.00
0005435069868	15517	Economy	3800.00
0005435925345	15517	Economy	3800.00
0005435925358	15517	Economy	3800.00
0005435069857	15517	Economy	3800.00
0005435069861	15517	Economy	3800.00
0005435925369	15517	Economy	3800.00
0005435069891	15517	Economy	3800.00
0005435069873	15517	Economy	3800.00
0005435069870	15517	Economy	3800.00
0005435069900	15517	Economy	3800.00
0005435069896	15517	Economy	3800.00
0005435069890	15517	Economy	3800.00
0005435069895	15517	Economy	3800.00
0005435069897	15517	Economy	3800.00
0005435069899	15517	Economy	3800.00
0005435069874	15517	Economy	3800.00
0005435069904	15517	Economy	3800.00
0005435069853	15517	Economy	3800.00
0005435069872	15517	Economy	3800.00
0005435069856	15517	Economy	3800.00
0005435069859	15517	Economy	3800.00
0005435069887	15517	Economy	3800.00
0005435069860	15517	Economy	3800.00
0005435069855	15517	Economy	3800.00
0005435069854	15517	Economy	3800.00
0005435069878	15517	Economy	3800.00
0005435069867	15517	Economy	3800.00
0005435069877	15517	Economy	3800.00
0005435069882	15517	Economy	3800.00
0005434756768	10721	Business	61300.00
0005434215304	10721	Business	61300.00
0005434215296	10721	Business	61300.00
0005434215289	10721	Business	61300.00
0005434756739	10721	Business	61300.00
0005434215282	10721	Business	61300.00
0005434215294	10721	Business	61300.00
0005434756631	10721	Business	61300.00
0005434756738	10721	Business	61300.00
0005434215270	10721	Business	61300.00
0005434756692	10721	Economy	20400.00
0005434215287	10721	Economy	20400.00
0005434215293	10721	Economy	20400.00
0005434756870	10721	Economy	20400.00
0005434215276	10721	Economy	20400.00
0005434215298	10721	Economy	20400.00
0005434756615	10721	Economy	20400.00
0005434215279	10721	Economy	20400.00
0005434215312	10721	Economy	20400.00
0005434215273	10721	Economy	22500.00
0005434215288	10721	Economy	22500.00
0005434215313	10721	Economy	22500.00
0005434756832	10721	Economy	22500.00
0005434215305	10721	Economy	22500.00
0005434215284	10721	Economy	20400.00
0005434215286	10721	Economy	20400.00
0005434756672	10721	Economy	20400.00
0005434756557	10721	Economy	20400.00
0005434756808	10721	Economy	20400.00
0005434215303	10721	Economy	20400.00
0005434215301	10721	Economy	20400.00
0005434756763	10721	Economy	20400.00
0005434215309	10721	Economy	20400.00
0005434756699	10721	Economy	20400.00
0005434215275	10721	Economy	20400.00
0005434756711	10721	Economy	20400.00
0005434756846	10721	Economy	20400.00
0005434215310	10721	Economy	20400.00
0005434215307	10721	Economy	20400.00
0005434215272	10721	Economy	20400.00
0005434215299	10721	Economy	20400.00
0005434756634	10721	Economy	20400.00
0005434215274	10721	Economy	20400.00
0005434215297	10721	Economy	20400.00
0005434215268	10721	Economy	20400.00
0005434215269	10721	Economy	20400.00
0005434215285	10721	Economy	20400.00
0005434756869	10721	Economy	20400.00
0005434215306	10721	Economy	20400.00
0005434756715	10721	Economy	20400.00
0005434756701	10721	Economy	20400.00
0005434756774	10721	Economy	20400.00
0005434215271	10721	Economy	20400.00
0005434756826	10721	Economy	20400.00
0005434756827	10721	Economy	20400.00
0005434215295	10721	Economy	20400.00
0005434756836	10721	Economy	20400.00
0005434215277	10721	Economy	20400.00
0005434215283	10721	Economy	20400.00
0005434215315	10721	Economy	20400.00
0005434215314	10721	Economy	20400.00
0005434215281	10721	Economy	20400.00
0005434756719	10721	Economy	20400.00
0005434756647	10721	Economy	20400.00
0005434215302	10721	Economy	20400.00
0005434215291	10721	Economy	20400.00
0005434756709	10721	Economy	20400.00
0005434756659	10721	Economy	20400.00
0005434756595	10721	Economy	20400.00
0005434756616	10721	Economy	20400.00
0005434756603	10721	Economy	20400.00
0005434215292	10721	Economy	20400.00
0005434756698	10721	Economy	20400.00
0005434756602	10721	Economy	20400.00
0005434215278	10721	Economy	20400.00
0005434215280	10721	Economy	20400.00
0005434215300	10721	Economy	20400.00
0005434756710	10721	Economy	20400.00
0005434215308	10721	Economy	20400.00
0005434756643	10721	Economy	20400.00
0005434215290	10721	Economy	20400.00
0005434756714	10721	Economy	20400.00
0005434756773	10721	Economy	20400.00
0005434756646	10721	Economy	20400.00
0005434756736	10721	Economy	20400.00
0005434215311	10721	Economy	20400.00
0005434756594	10721	Economy	20400.00
0005434757072	28698	Business	61300.00
0005434214911	28698	Business	61300.00
0005434757089	28698	Business	61300.00
0005434214882	28698	Business	61300.00
0005434215002	28698	Business	61300.00
0005434214832	28698	Business	61300.00
0005434757099	28698	Business	61300.00
0005434757077	28698	Business	61300.00
0005434214550	28698	Business	61300.00
0005434214796	28698	Business	61300.00
0005434757058	28698	Economy	20400.00
0005434757080	28698	Economy	20400.00
0005434757092	28698	Economy	20400.00
0005434757054	28698	Economy	20400.00
0005434214929	28698	Economy	20400.00
0005434214912	28698	Economy	20400.00
0005434214672	28698	Economy	20400.00
0005434757063	28698	Economy	20400.00
0005434214837	28698	Economy	20400.00
0005434757053	28698	Economy	20400.00
0005434757082	28698	Economy	22500.00
0005434757095	28698	Economy	22500.00
0005434214630	28698	Economy	22500.00
0005434757074	28698	Economy	20400.00
0005434757094	28698	Economy	20400.00
0005434214754	28698	Economy	20400.00
0005434757055	28698	Economy	20400.00
0005434214768	28698	Economy	20400.00
0005434757083	28698	Economy	20400.00
0005434757075	28698	Economy	20400.00
0005434214617	28698	Economy	20400.00
0005434214820	28698	Economy	20400.00
0005434757071	28698	Economy	20400.00
0005434757057	28698	Economy	20400.00
0005434757056	28698	Economy	20400.00
0005434757061	28698	Economy	20400.00
0005434757090	28698	Economy	20400.00
0005434757060	28698	Economy	20400.00
0005434757098	28698	Economy	20400.00
0005434757088	28698	Economy	20400.00
0005434214948	28698	Economy	20400.00
0005434757062	28698	Economy	20400.00
0005434757067	28698	Economy	20400.00
0005434214549	28698	Economy	20400.00
0005434214780	28698	Economy	20400.00
0005434757076	28698	Economy	20400.00
0005434214880	28698	Economy	20400.00
0005434757064	28698	Economy	20400.00
0005434757091	28698	Economy	20400.00
0005434214888	28698	Economy	20400.00
0005434757066	28698	Economy	20400.00
0005434757093	28698	Economy	20400.00
0005434757096	28698	Economy	20400.00
0005434214883	28698	Economy	20400.00
0005434757081	28698	Economy	20400.00
0005434757085	28698	Economy	20400.00
0005434214930	28698	Economy	20400.00
0005434757073	28698	Economy	20400.00
0005434757068	28698	Economy	20400.00
0005434214779	28698	Economy	20400.00
0005434757097	28698	Economy	20400.00
0005434757078	28698	Economy	20400.00
0005434757084	28698	Economy	20400.00
0005434757079	28698	Economy	20400.00
0005434757087	28698	Economy	20400.00
0005434214910	28698	Economy	20400.00
0005434214767	28698	Economy	20400.00
0005434757070	28698	Economy	20400.00
0005434757069	28698	Economy	20400.00
0005434757059	28698	Economy	20400.00
0005434757086	28698	Economy	20400.00
0005434757065	28698	Economy	20400.00
0005434229562	5466	Business	29500.00
0005435007414	5466	Business	29500.00
0005435040826	5466	Business	29500.00
0005435040805	5466	Business	29500.00
0005435040831	5466	Business	29500.00
0005435040842	5466	Business	29500.00
0005435040788	5466	Business	29500.00
0005434229549	5466	Business	29500.00
0005435040837	5466	Business	29500.00
0005435040838	5466	Business	29500.00
0005434229508	5466	Business	29500.00
0005435040836	5466	Economy	9800.00
0005435040806	5466	Economy	9800.00
0005435007415	5466	Economy	9800.00
0005432125572	5466	Economy	9800.00
0005435040809	5466	Economy	9800.00
0005434229492	5466	Economy	9800.00
0005434229563	5466	Economy	9800.00
0005435007405	5466	Economy	9800.00
0005435007413	5466	Economy	9800.00
0005435040784	5466	Economy	9800.00
0005435007410	5466	Economy	9800.00
0005435040819	5466	Economy	9800.00
0005435040835	5466	Economy	9800.00
0005435040841	5466	Economy	9800.00
0005435040832	5466	Economy	9800.00
0005435040845	5466	Economy	9800.00
0005434229533	5466	Economy	9800.00
0005434229550	5466	Economy	9800.00
0005435007406	5466	Economy	9800.00
0005435040786	5466	Economy	9800.00
0005434229493	5466	Economy	9800.00
0005435040802	5466	Economy	9800.00
0005435007404	5466	Economy	9800.00
0005435040804	5466	Economy	9800.00
0005435040825	5466	Economy	9800.00
0005435040848	5466	Economy	9800.00
0005435007411	5466	Economy	9800.00
0005435040821	5466	Economy	9800.00
0005435040823	5466	Economy	9800.00
0005432125570	5466	Economy	9800.00
0005432125569	5466	Economy	9800.00
0005435040828	5466	Economy	9800.00
0005435040850	5466	Economy	9800.00
0005435040794	5466	Economy	10800.00
0005434229557	5466	Economy	10800.00
0005435040787	5466	Economy	10800.00
0005435040827	5466	Economy	10800.00
0005435040846	5466	Economy	10800.00
0005435040799	5466	Economy	10800.00
0005435040815	5466	Economy	9800.00
0005435007407	5466	Economy	9800.00
0005435040833	5466	Economy	9800.00
0005435040822	5466	Economy	9800.00
0005435040792	5466	Economy	9800.00
0005434229503	5466	Economy	9800.00
0005435040790	5466	Economy	9800.00
0005432125573	5466	Economy	9800.00
0005435040812	5466	Economy	9800.00
0005435040817	5466	Economy	9800.00
0005432125571	5466	Economy	9800.00
0005435040847	5466	Economy	9800.00
0005435007408	5466	Economy	9800.00
0005435040795	5466	Economy	9800.00
0005435040798	5466	Economy	9800.00
0005434229607	5466	Economy	9800.00
0005435040843	5466	Economy	9800.00
0005435040849	5466	Economy	9800.00
0005435040813	5466	Economy	9800.00
0005434229570	5466	Economy	9800.00
0005435040800	5466	Economy	9800.00
0005434229475	5466	Economy	9800.00
0005435040840	5466	Economy	9800.00
0005434229505	5466	Economy	9800.00
0005434229605	5466	Economy	9800.00
0005435040807	5466	Economy	9800.00
0005435007412	5466	Economy	9800.00
0005435040793	5466	Economy	9800.00
0005435040811	5466	Economy	9800.00
0005435040797	5466	Economy	9800.00
0005434229524	5466	Economy	9800.00
0005435040816	5466	Economy	9800.00
0005435007403	5466	Economy	9800.00
0005432125574	5466	Economy	9800.00
0005435040844	5466	Economy	9800.00
0005435007402	5466	Economy	9800.00
0005435040803	5466	Economy	9800.00
0005435040820	5466	Economy	9800.00
0005435040796	5466	Economy	9800.00
0005435040839	5466	Economy	9800.00
0005435040814	5466	Economy	9800.00
0005434229525	5466	Economy	9800.00
0005435040808	5466	Economy	9800.00
0005432125575	5466	Economy	9800.00
0005435040834	5466	Economy	9800.00
0005434229467	5466	Economy	9800.00
0005435007409	5466	Economy	9800.00
0005435040801	5466	Economy	9800.00
0005435040818	5466	Economy	9800.00
0005435040824	5466	Economy	9800.00
0005434229571	5466	Economy	9800.00
0005435040829	5466	Economy	9800.00
0005432125576	5466	Economy	9800.00
0005435040789	5466	Economy	9800.00
0005434229526	5466	Economy	9800.00
0005435040810	5466	Economy	9800.00
0005434229504	5466	Economy	9800.00
0005435040785	5466	Economy	9800.00
0005435040830	5466	Economy	9800.00
0005435040791	5466	Economy	9800.00
0005432125568	5466	Economy	9800.00
0005435007416	5466	Economy	9800.00
0005434229745	12974	Business	29500.00
0005435007140	12974	Business	29500.00
0005435040302	12974	Business	29500.00
0005435007180	12974	Business	29500.00
0005434229742	12974	Business	29500.00
0005435007197	12974	Business	29500.00
0005434229732	12974	Business	29500.00
0005432304463	12974	Business	29500.00
0005435040377	12974	Business	29500.00
0005435040275	12974	Business	29500.00
0005434229739	12974	Business	29500.00
0005435007200	12974	Economy	9800.00
0005435040277	12974	Economy	9800.00
0005434229741	12974	Economy	9800.00
0005435040381	12974	Economy	9800.00
0005435040428	12974	Economy	9800.00
0005434229738	12974	Economy	9800.00
0005435007203	12974	Economy	9800.00
0005435040430	12974	Economy	9800.00
0005434229743	12974	Economy	9800.00
0005435040142	12974	Economy	9800.00
0005435040329	12974	Economy	9800.00
0005434229733	12974	Economy	9800.00
0005435007215	12974	Economy	9800.00
0005435040213	12974	Economy	9800.00
0005435040284	12974	Economy	9800.00
0005435007198	12974	Economy	9800.00
0005435007219	12974	Economy	9800.00
0005434229749	12974	Economy	9800.00
0005435007199	12974	Economy	9800.00
0005435007274	12974	Economy	9800.00
0005435007228	12974	Economy	9800.00
0005435377911	12974	Economy	9800.00
0005435039995	12974	Economy	9800.00
0005435040026	12974	Economy	9800.00
0005435040168	12974	Economy	9800.00
0005435040314	12974	Economy	9800.00
0005435007181	12974	Economy	9800.00
0005435040104	12974	Economy	9800.00
0005435040239	12974	Economy	9800.00
0005435040352	12974	Economy	9800.00
0005435040240	12974	Economy	9800.00
0005435040476	12974	Economy	9800.00
0005435040167	12974	Economy	9800.00
0005435040230	12974	Economy	9800.00
0005435040180	12974	Economy	9800.00
0005435040197	12974	Economy	9800.00
0005435007121	12974	Economy	9800.00
0005435040084	12974	Economy	9800.00
0005435040447	12974	Economy	9800.00
0005434229734	12974	Economy	10800.00
0005434229740	12974	Economy	10800.00
0005435007220	12974	Economy	10800.00
0005432304460	12974	Economy	10800.00
0005435040376	12974	Economy	10800.00
0005434229744	12974	Economy	9800.00
0005432304461	12974	Economy	9800.00
0005435039993	12974	Economy	9800.00
0005435040361	12974	Economy	9800.00
0005435040303	12974	Economy	9800.00
0005435007208	12974	Economy	9800.00
0005435377912	12974	Economy	9800.00
0005435007249	12974	Economy	9800.00
0005434229746	12974	Economy	9800.00
0005435040330	12974	Economy	9800.00
0005435040360	12974	Economy	9800.00
0005434229748	12974	Economy	9800.00
0005435042876	12974	Economy	9800.00
0005434229731	12974	Economy	9800.00
0005432304462	12974	Economy	9800.00
0005434229747	12974	Economy	9800.00
0005435377910	12974	Economy	9800.00
0005435040241	12974	Economy	9800.00
0005435040393	12974	Economy	9800.00
0005435039994	12974	Economy	9800.00
0005435040181	12974	Economy	9800.00
0005435040248	12974	Economy	9800.00
0005435040322	12974	Economy	9800.00
0005434229736	12974	Economy	9800.00
0005435040134	12974	Economy	9800.00
0005434229751	12974	Economy	9800.00
0005435042860	12974	Economy	9800.00
0005435040234	12974	Economy	9800.00
0005435040135	12974	Economy	9800.00
0005435040233	12974	Economy	9800.00
0005435040359	12974	Economy	9800.00
0005435040403	12974	Economy	9800.00
0005435040027	12974	Economy	9800.00
0005435040198	12974	Economy	9800.00
0005435040231	12974	Economy	9800.00
0005435040353	12974	Economy	9800.00
0005434229737	12974	Economy	9800.00
0005435007275	12974	Economy	9800.00
0005435007250	12974	Economy	9800.00
0005435040272	12974	Economy	9800.00
0005435007258	12974	Economy	9800.00
0005434229730	12974	Economy	9800.00
0005435040504	12974	Economy	9800.00
0005435040053	12974	Economy	9800.00
0005435040196	12974	Economy	9800.00
0005435040356	12974	Economy	9800.00
0005435040274	12974	Economy	9800.00
0005434229735	12974	Economy	9800.00
0005435040283	12974	Economy	9800.00
0005435040267	12974	Economy	9800.00
0005435040311	12974	Economy	9800.00
0005435040276	12974	Economy	9800.00
0005435007212	12974	Economy	9800.00
0005435040229	12974	Economy	9800.00
0005434229750	12974	Economy	9800.00
0005435040143	12974	Economy	9800.00
0005435040382	12974	Economy	9800.00
0005435040083	12974	Economy	9800.00
0005435040062	12974	Economy	9800.00
0005434229729	12974	Economy	9800.00
0005435007273	12974	Economy	9800.00
0005435040315	12974	Economy	9800.00
0005435040254	12974	Economy	9800.00
0005435007204	12974	Economy	9800.00
0005435040263	12974	Economy	9800.00
0005435007234	12974	Economy	9800.00
0005435040449	12974	Economy	9800.00
0005435554222	14887	Business	52900.00
0005434427063	14887	Business	52900.00
0005435902849	14887	Business	52900.00
0005435902857	14887	Business	52900.00
0005435902850	14887	Business	52900.00
0005434427061	14887	Business	52900.00
0005432188659	14887	Business	52900.00
0005434427067	14887	Business	52900.00
0005434427068	14887	Business	52900.00
0005435902848	14887	Economy	17600.00
0005435902844	14887	Economy	17600.00
0005434411844	14887	Economy	17600.00
0005435902861	14887	Economy	17600.00
0005435902834	14887	Economy	17600.00
0005434427071	14887	Economy	17600.00
0005434427080	14887	Economy	17600.00
0005434427075	14887	Economy	19400.00
0005434427062	14887	Economy	19400.00
0005434427057	14887	Economy	17600.00
0005434427055	14887	Economy	17600.00
0005435902817	14887	Economy	17600.00
0005434427069	14887	Economy	17600.00
0005435902855	14887	Economy	17600.00
0005434411843	14887	Economy	17600.00
0005434427064	14887	Economy	17600.00
0005435902800	14887	Economy	17600.00
0005434427052	14887	Economy	17600.00
0005435902713	14887	Economy	17600.00
0005434427066	14887	Economy	17600.00
0005434427078	14887	Economy	17600.00
0005434427074	14887	Economy	17600.00
0005435902886	14887	Economy	17600.00
0005434427050	14887	Economy	17600.00
0005435902873	14887	Economy	17600.00
0005434427077	14887	Economy	17600.00
0005434427065	14887	Economy	17600.00
0005432188658	14887	Economy	17600.00
0005435902808	14887	Economy	17600.00
0005435902749	14887	Economy	17600.00
0005434411845	14887	Economy	17600.00
0005434427053	14887	Economy	17600.00
0005432188657	14887	Economy	17600.00
0005434427079	14887	Economy	17600.00
0005434427056	14887	Economy	17600.00
0005434427070	14887	Economy	17600.00
0005434427073	14887	Economy	17600.00
0005434411846	14887	Economy	17600.00
0005435902807	14887	Economy	17600.00
0005434427059	14887	Economy	17600.00
0005434427076	14887	Economy	17600.00
0005435902832	14887	Economy	17600.00
0005432188660	14887	Economy	17600.00
0005434427054	14887	Economy	17600.00
0005435902804	14887	Economy	17600.00
0005435902831	14887	Economy	17600.00
0005435902856	14887	Economy	17600.00
0005435554227	14887	Economy	17600.00
0005435554223	14887	Economy	17600.00
0005434427060	14887	Economy	17600.00
0005435902753	14887	Economy	17600.00
0005435902805	14887	Economy	17600.00
0005435902835	14887	Economy	17600.00
0005434427072	14887	Economy	17600.00
0005434427058	14887	Economy	17600.00
0005434427051	14887	Economy	17600.00
0005435902990	20211	Business	52900.00
0005434411811	20211	Business	52900.00
0005434411821	20211	Business	52900.00
0005435902995	20211	Business	52900.00
0005432059539	20211	Business	52900.00
0005434426951	20211	Business	52900.00
0005435902993	20211	Economy	17600.00
0005435903002	20211	Economy	17600.00
0005434426814	20211	Economy	17600.00
0005434426702	20211	Economy	17600.00
0005435902988	20211	Economy	17600.00
0005434426835	20211	Economy	17600.00
0005435554268	20211	Economy	17600.00
0005435902985	20211	Economy	19400.00
0005434426907	20211	Economy	19400.00
0005435902997	20211	Economy	19400.00
0005434426887	20211	Economy	19400.00
0005434426703	20211	Economy	17600.00
0005434411817	20211	Economy	17600.00
0005434426824	20211	Economy	17600.00
0005434411816	20211	Economy	17600.00
0005435554267	20211	Economy	17600.00
0005434426891	20211	Economy	17600.00
0005435902998	20211	Economy	17600.00
0005435554269	20211	Economy	17600.00
0005434411836	20211	Economy	17600.00
0005432059536	20211	Economy	17600.00
0005435903003	20211	Economy	17600.00
0005435902999	20211	Economy	17600.00
0005434426752	20211	Economy	17600.00
0005434426783	20211	Economy	17600.00
0005434426805	20211	Economy	17600.00
0005435902991	20211	Economy	17600.00
0005434426840	20211	Economy	17600.00
0005434426782	20211	Economy	17600.00
0005435902986	20211	Economy	17600.00
0005434426797	20211	Economy	17600.00
0005435554271	20211	Economy	17600.00
0005434426813	20211	Economy	17600.00
0005434411794	20211	Economy	17600.00
0005434426751	20211	Economy	17600.00
0005432059537	20211	Economy	17600.00
0005434426980	20211	Economy	17600.00
0005432059538	20211	Economy	17600.00
0005434426796	20211	Economy	17600.00
0005435902992	20211	Economy	17600.00
0005434426906	20211	Economy	17600.00
0005434426890	20211	Economy	17600.00
0005434426892	20211	Economy	17600.00
0005435902994	20211	Economy	17600.00
0005435903001	20211	Economy	17600.00
0005434426834	20211	Economy	17600.00
0005434411815	20211	Economy	17600.00
0005435554270	20211	Economy	17600.00
0005434426837	20211	Economy	17600.00
0005434426795	20211	Economy	17600.00
0005435902996	20211	Economy	17600.00
0005434411801	20211	Economy	17600.00
0005435902989	20211	Economy	17600.00
0005435903000	20211	Economy	17600.00
0005435902987	20211	Economy	17600.00
0005432300354	26502	Business	18500.00
0005435982987	26502	Business	18500.00
0005435983016	26502	Business	18500.00
0005435982992	26502	Business	18500.00
0005435982988	26502	Business	18500.00
0005433434898	26502	Business	18500.00
0005433434882	26502	Business	18500.00
0005435983015	26502	Business	18500.00
0005435983003	26502	Business	18500.00
0005435982997	26502	Business	18500.00
0005433434744	26502	Business	18500.00
0005433434746	26502	Economy	6200.00
0005435982998	26502	Economy	6200.00
0005433434788	26502	Economy	6200.00
0005433434819	26502	Economy	6200.00
0005433434896	26502	Economy	6200.00
0005432300353	26502	Economy	6200.00
0005433434879	26502	Economy	6200.00
0005432300352	26502	Economy	6200.00
0005433434855	26502	Economy	6800.00
0005435983002	26502	Economy	6800.00
0005433434815	26502	Economy	6800.00
0005433434736	26502	Economy	6800.00
0005433434813	26502	Economy	6800.00
0005433434897	26502	Economy	6200.00
0005434270217	26502	Economy	6200.00
0005435983014	26502	Economy	6200.00
0005435983004	26502	Economy	6200.00
0005435982996	26502	Economy	6200.00
0005432300357	26502	Economy	6200.00
0005432300351	26502	Economy	6200.00
0005434273089	26502	Economy	6200.00
0005433434939	26502	Economy	6200.00
0005433434794	26502	Economy	6200.00
0005435983007	26502	Economy	6200.00
0005433434878	26502	Economy	6200.00
0005435982983	26502	Economy	6200.00
0005435983012	26502	Economy	6200.00
0005435982986	26502	Economy	6200.00
0005435982995	26502	Economy	6200.00
0005435983013	26502	Economy	6200.00
0005435982990	26502	Economy	6200.00
0005435983005	26502	Economy	6200.00
0005433434877	26502	Economy	6200.00
0005432300356	26502	Economy	6200.00
0005433434857	26502	Economy	6200.00
0005433434789	26502	Economy	6200.00
0005434273083	26502	Economy	6200.00
0005435983008	26502	Economy	6200.00
0005433434844	26502	Economy	6200.00
0005433434814	26502	Economy	6200.00
0005433434817	26502	Economy	6200.00
0005435982999	26502	Economy	6200.00
0005435982985	26502	Economy	6200.00
0005434273081	26502	Economy	6200.00
0005435982991	26502	Economy	6200.00
0005433434876	26502	Economy	6200.00
0005435983001	26502	Economy	6200.00
0005435982994	26502	Economy	6200.00
0005435982982	26502	Economy	6200.00
0005435983010	26502	Economy	6200.00
0005433434907	26502	Economy	6200.00
0005435983011	26502	Economy	6200.00
0005435982989	26502	Economy	6200.00
0005435983009	26502	Economy	6200.00
0005434273086	26502	Economy	6200.00
0005435982984	26502	Economy	6200.00
0005432300355	26502	Economy	6200.00
0005434273090	26502	Economy	6200.00
0005435983006	26502	Economy	6200.00
0005433434853	26502	Economy	6200.00
0005435982993	26502	Economy	6200.00
0005435983000	26502	Economy	6200.00
0005433434908	26502	Economy	6200.00
0005433434842	26502	Economy	6200.00
0005433434886	26502	Economy	6200.00
0005433434881	26502	Economy	6200.00
0005433434905	26502	Economy	6200.00
0005433435014	26502	Economy	6200.00
0005433434816	26502	Economy	6200.00
0005434270226	26502	Economy	6200.00
0005433434858	26502	Economy	6200.00
0005433434820	26502	Economy	6200.00
0005435982622	26702	Business	18500.00
0005435982635	26702	Business	18500.00
0005435982546	26702	Business	18500.00
0005433435154	26702	Business	18500.00
0005433435147	26702	Business	18500.00
0005435982590	26702	Business	18500.00
0005433435151	26702	Business	18500.00
0005435982596	26702	Business	18500.00
0005435982721	26702	Business	18500.00
0005433435133	26702	Economy	6200.00
0005435982492	26702	Economy	6200.00
0005435982455	26702	Economy	6200.00
0005433435150	26702	Economy	6200.00
0005435982501	26702	Economy	6200.00
0005433435156	26702	Economy	6200.00
0005432051179	26702	Economy	6800.00
0005433435153	26702	Economy	6800.00
0005433435130	26702	Economy	6800.00
0005433435155	26702	Economy	6800.00
0005435982653	26702	Economy	6800.00
0005433435146	26702	Economy	6200.00
0005433435157	26702	Economy	6200.00
0005435982552	26702	Economy	6200.00
0005435982553	26702	Economy	6200.00
0005435982659	26702	Economy	6200.00
0005435982576	26702	Economy	6200.00
0005434269138	26702	Economy	6200.00
0005433435143	26702	Economy	6200.00
0005433435142	26702	Economy	6200.00
0005435982604	26702	Economy	6200.00
0005435982608	26702	Economy	6200.00
0005435982705	26702	Economy	6200.00
0005435982711	26702	Economy	6200.00
0005434271346	26702	Economy	6200.00
0005435982454	26702	Economy	6200.00
0005433435149	26702	Economy	6200.00
0005435982710	26702	Economy	6200.00
0005435982607	26702	Economy	6200.00
0005435982508	26702	Economy	6200.00
0005434270242	26702	Economy	6200.00
0005435982658	26702	Economy	6200.00
0005433435135	26702	Economy	6200.00
0005435982704	26702	Economy	6200.00
0005435982266	26702	Economy	6200.00
0005434269137	26702	Economy	6200.00
0005435982579	26702	Economy	6200.00
0005435982551	26702	Economy	6200.00
0005435982509	26702	Economy	6200.00
0005435982919	26702	Economy	6200.00
0005435982490	26702	Economy	6200.00
0005433435131	26702	Economy	6200.00
0005433435148	26702	Economy	6200.00
0005432051178	26702	Economy	6200.00
0005435982709	26702	Economy	6200.00
0005435982920	26702	Economy	6200.00
0005433435134	26702	Economy	6200.00
0005432051181	26702	Economy	6200.00
0005433435137	26702	Economy	6200.00
0005435982655	26702	Economy	6200.00
0005433435138	26702	Economy	6200.00
0005433435139	26702	Economy	6200.00
0005433435140	26702	Economy	6200.00
0005435982580	26702	Economy	6200.00
0005435982708	26702	Economy	6200.00
0005435982921	26702	Economy	6200.00
0005435982547	26702	Economy	6200.00
0005435982500	26702	Economy	6200.00
0005433435136	26702	Economy	6200.00
0005432051180	26702	Economy	6200.00
0005435982577	26702	Economy	6200.00
0005433435141	26702	Economy	6200.00
0005433435152	26702	Economy	6200.00
0005433435132	26702	Economy	6200.00
0005434270241	26702	Economy	6200.00
0005435982620	26702	Economy	6200.00
0005433435144	26702	Economy	6200.00
0005433435145	26702	Economy	6200.00
0005435982773	26702	Economy	6200.00
0005432584449	3138	Economy	11100.00
0005432584456	3138	Economy	11100.00
0005432858156	3138	Economy	11100.00
0005432858117	3138	Economy	11100.00
0005432584437	3138	Economy	10100.00
0005432584455	3138	Economy	10100.00
0005432584440	3138	Economy	10100.00
0005432858210	3138	Economy	10100.00
0005432584454	3138	Economy	10100.00
0005432858130	3138	Economy	10100.00
0005432584444	3138	Economy	10100.00
0005432584434	3138	Economy	10100.00
0005432584442	3138	Economy	10100.00
0005432858174	3138	Economy	10100.00
0005432858162	3138	Economy	10100.00
0005432584436	3138	Economy	10100.00
0005432584451	3138	Economy	10100.00
0005432584443	3138	Economy	10100.00
0005432584448	3138	Economy	10100.00
0005432858186	3138	Economy	10100.00
0005432584450	3138	Economy	10100.00
0005432584445	3138	Economy	10100.00
0005432216318	3138	Economy	10100.00
0005432584439	3138	Economy	10100.00
0005432216319	3138	Economy	10100.00
0005432584460	3138	Economy	10100.00
0005432858176	3138	Economy	10100.00
0005432584453	3138	Economy	10100.00
0005432584438	3138	Economy	10100.00
0005432584457	3138	Economy	10100.00
0005432858211	3138	Economy	10100.00
0005432584441	3138	Economy	10100.00
0005432584447	3138	Economy	10100.00
0005432584452	3138	Economy	10100.00
0005432584435	3138	Economy	10100.00
0005432584459	3138	Economy	10100.00
0005432858175	3138	Economy	10100.00
0005432584458	3138	Economy	10100.00
0005432584446	3138	Economy	10100.00
0005432858260	31481	Economy	11100.00
0005432584249	31481	Economy	11100.00
0005432858263	31481	Economy	11100.00
0005432858264	31481	Economy	11100.00
0005432858262	31481	Economy	10100.00
0005432584308	31481	Economy	10100.00
0005432584237	31481	Economy	10100.00
0005432584159	31481	Economy	10100.00
0005432584205	31481	Economy	10100.00
0005432584207	31481	Economy	10100.00
0005432858268	31481	Economy	10100.00
0005432584204	31481	Economy	10100.00
0005432858270	31481	Economy	10100.00
0005432858265	31481	Economy	10100.00
0005432584293	31481	Economy	10100.00
0005432584185	31481	Economy	10100.00
0005432584248	31481	Economy	10100.00
0005432858261	31481	Economy	10100.00
0005432858267	31481	Economy	10100.00
0005432584136	31481	Economy	10100.00
0005432584132	31481	Economy	10100.00
0005432858269	31481	Economy	10100.00
0005432584292	31481	Economy	10100.00
0005432584306	31481	Economy	10100.00
0005432584251	31481	Economy	10100.00
0005432584203	31481	Economy	10100.00
0005432584137	31481	Economy	10100.00
0005432584186	31481	Economy	10100.00
0005432584295	31481	Economy	10100.00
0005432584265	31481	Economy	10100.00
0005432858266	31481	Economy	10100.00
0005432584258	31481	Economy	10100.00
0005432584262	31481	Economy	10100.00
0005432858271	31481	Economy	10100.00
0005432584338	31481	Economy	10100.00
0005432584187	31481	Economy	10100.00
0005432584206	31481	Economy	10100.00
0005432584296	31481	Economy	10100.00
0005432584294	31481	Economy	10100.00
0005434943502	864	Economy	7500.00
0005434943498	864	Economy	7500.00
0005434943504	864	Economy	7500.00
0005433255164	864	Economy	7500.00
0005434943506	864	Economy	7500.00
0005434943507	864	Economy	7500.00
0005434943499	864	Economy	7500.00
0005433255163	864	Economy	7500.00
0005434943503	864	Economy	7500.00
0005434943501	864	Economy	7500.00
0005434943505	864	Economy	7500.00
0005433255176	864	Economy	7500.00
0005434943500	864	Economy	7500.00
0005433255181	864	Economy	7500.00
0005433255165	864	Economy	7500.00
0005434943427	16239	Economy	8300.00
0005433255210	16239	Economy	8300.00
0005434943443	16239	Economy	7500.00
0005434943461	16239	Economy	7500.00
0005433255207	16239	Economy	7500.00
0005434943458	16239	Economy	7500.00
0005434943407	16239	Economy	7500.00
0005434943419	16239	Economy	7500.00
0005434943412	16239	Economy	7500.00
0005434943454	16239	Economy	7500.00
0005434943420	16239	Economy	7500.00
0005433255205	16239	Economy	7500.00
0005434943477	16239	Economy	7500.00
0005433255208	16239	Economy	7500.00
0005433255206	16239	Economy	7500.00
0005434943466	16239	Economy	7500.00
0005434943444	16239	Economy	7500.00
0005434943457	16239	Economy	7500.00
0005433255209	16239	Economy	7500.00
0005434943428	16239	Economy	7500.00
0005434943426	16239	Economy	7500.00
0005434943425	16239	Economy	7500.00
0005433811646	14448	Economy	4400.00
0005433368176	21764	Business	9800.00
0005435653723	21764	Business	9800.00
0005433368221	21764	Business	9800.00
0005435653735	21764	Business	9800.00
0005435653742	21764	Business	9800.00
0005435653737	21764	Business	9800.00
0005435653716	21764	Business	9800.00
0005433368086	21764	Business	9800.00
0005435653717	21764	Business	9800.00
0005433368213	21764	Economy	3300.00
0005435653730	21764	Economy	3300.00
0005435653752	21764	Economy	3300.00
0005433368162	21764	Economy	3300.00
0005433368429	21764	Economy	3300.00
0005433368152	21764	Economy	3300.00
0005435653713	21764	Economy	3300.00
0005435653748	21764	Economy	3300.00
0005433368090	21764	Economy	3600.00
0005435653724	21764	Economy	3600.00
0005435653725	21764	Economy	3600.00
0005433368166	21764	Economy	3600.00
0005433368218	21764	Economy	3600.00
0005435653747	21764	Economy	3300.00
0005433368193	21764	Economy	3300.00
0005435653722	21764	Economy	3300.00
0005435653734	21764	Economy	3300.00
0005435653755	21764	Economy	3300.00
0005433368171	21764	Economy	3300.00
0005435653738	21764	Economy	3300.00
0005435653728	21764	Economy	3300.00
0005435653714	21764	Economy	3300.00
0005435653754	21764	Economy	3300.00
0005433368175	21764	Economy	3300.00
0005435653719	21764	Economy	3300.00
0005433367957	21764	Economy	3300.00
0005433368031	21764	Economy	3300.00
0005435653736	21764	Economy	3300.00
0005435653745	21764	Economy	3300.00
0005433368285	21764	Economy	3300.00
0005435653741	21764	Economy	3300.00
0005433368235	21764	Economy	3300.00
0005435653739	21764	Economy	3300.00
0005435653732	21764	Economy	3300.00
0005433368177	21764	Economy	3300.00
0005433368145	21764	Economy	3300.00
0005433368055	21764	Economy	3300.00
0005435653715	21764	Economy	3300.00
0005435653733	21764	Economy	3300.00
0005435653720	21764	Economy	3300.00
0005433368109	21764	Economy	3300.00
0005435653712	21764	Economy	3300.00
0005435653721	21764	Economy	3300.00
0005433368146	21764	Economy	3300.00
0005433368223	21764	Economy	3300.00
0005433368318	21764	Economy	3300.00
0005435653726	21764	Economy	3300.00
0005433368165	21764	Economy	3300.00
0005435653746	21764	Economy	3300.00
0005433368030	21764	Economy	3300.00
0005435653740	21764	Economy	3300.00
0005433367956	21764	Economy	3300.00
0005435653727	21764	Economy	3300.00
0005435653743	21764	Economy	3300.00
0005433368156	21764	Economy	3300.00
0005433368195	21764	Economy	3300.00
0005433368153	21764	Economy	3300.00
0005433368222	21764	Economy	3300.00
0005435653711	21764	Economy	3300.00
0005435653756	21764	Economy	3300.00
0005435653718	21764	Economy	3300.00
0005435653744	21764	Economy	3300.00
0005433368089	21764	Economy	3300.00
0005435653750	21764	Economy	3300.00
0005433368289	21764	Economy	3300.00
0005435653751	21764	Economy	3300.00
0005435653753	21764	Economy	3300.00
0005433368236	21764	Economy	3300.00
0005435653749	21764	Economy	3300.00
0005435653729	21764	Economy	3300.00
0005433368178	21764	Economy	3300.00
0005435653731	21764	Economy	3300.00
0005433368182	21764	Economy	3300.00
0005434171147	9346	Business	186200.00
0005433805926	9346	Business	186200.00
0005433785553	9346	Business	186200.00
0005432665310	9346	Business	186200.00
0005433763451	9346	Business	186200.00
0005434171171	9346	Business	186200.00
0005433785537	9346	Business	186200.00
0005433785549	9346	Business	186200.00
0005433763438	9346	Business	186200.00
0005434171140	9346	Business	186200.00
0005434171179	9346	Business	186200.00
0005433805952	9346	Business	186200.00
0005433805949	9346	Business	186200.00
0005432667487	9346	Business	186200.00
0005434151728	9346	Business	186200.00
0005433785550	9346	Business	186200.00
0005433805934	9346	Business	186200.00
0005433785527	9346	Business	186200.00
0005433785552	9346	Business	186200.00
0005434171180	9346	Business	186200.00
0005433785536	9346	Business	186200.00
0005433763441	9346	Economy	68300.00
0005434171156	9346	Economy	68300.00
0005433785534	9346	Economy	62100.00
0005434270218	9346	Economy	62100.00
0005433785530	9346	Economy	62100.00
0005433805954	9346	Economy	62100.00
0005433763448	9346	Economy	62100.00
0005433805947	9346	Economy	62100.00
0005433805936	9346	Economy	62100.00
0005434171148	9346	Economy	62100.00
0005433763447	9346	Economy	62100.00
0005434171155	9346	Economy	62100.00
0005433785533	9346	Economy	62100.00
0005433785529	9346	Economy	62100.00
0005433785548	9346	Economy	62100.00
0005434151741	9346	Economy	62100.00
0005433785524	9346	Economy	62100.00
0005434151732	9346	Economy	62100.00
0005434171234	9346	Economy	62100.00
0005433805932	9346	Economy	62100.00
0005432657499	9346	Economy	62100.00
0005433805935	9346	Economy	62100.00
0005433805955	9346	Economy	62100.00
0005433785555	9346	Economy	62100.00
0005433785556	9346	Economy	62100.00
0005433805942	9346	Economy	62100.00
0005433785528	9346	Economy	62100.00
0005433785526	9346	Economy	62100.00
0005433805945	9346	Economy	62100.00
0005434171186	9346	Economy	62100.00
0005433785545	9346	Economy	62100.00
0005433805946	9346	Economy	62100.00
0005433763440	9346	Economy	62100.00
0005433763437	9346	Economy	62100.00
0005433805953	9346	Economy	62100.00
0005433785551	9346	Economy	62100.00
0005433785525	9346	Economy	62100.00
0005433805928	9346	Economy	62100.00
0005434171235	9346	Economy	62100.00
0005434171192	9346	Economy	62100.00
0005433785538	9346	Economy	62100.00
0005433805930	9346	Economy	62100.00
0005432657498	9346	Economy	62100.00
0005433805940	9346	Economy	62100.00
0005433785546	9346	Economy	62100.00
0005433763439	9346	Economy	62100.00
0005433763445	9346	Economy	62100.00
0005433805923	9346	Economy	62100.00
0005433805927	9346	Economy	62100.00
0005433805925	9346	Economy	62100.00
0005433763443	9346	Economy	62100.00
0005433785535	9346	Economy	62100.00
0005433785544	9346	Economy	62100.00
0005433805948	9346	Economy	62100.00
0005433805941	9346	Economy	62100.00
0005433805944	9346	Economy	68300.00
0005433763442	9346	Economy	62100.00
0005433805931	9346	Economy	62100.00
0005433785547	9346	Economy	62100.00
0005433763444	9346	Economy	62100.00
0005434171146	9346	Economy	62100.00
0005434151725	9346	Economy	62100.00
0005433785541	9346	Economy	62100.00
0005433805933	9346	Economy	62100.00
0005433805922	9346	Economy	62100.00
0005432665308	9346	Economy	62100.00
0005433763449	9346	Economy	62100.00
0005433805937	9346	Economy	62100.00
0005432667488	9346	Economy	62100.00
0005434151729	9346	Economy	62100.00
0005432665309	9346	Economy	62100.00
0005433785523	9346	Economy	62100.00
0005432657500	9346	Economy	62100.00
0005433785539	9346	Economy	62100.00
0005433785540	9346	Economy	62100.00
0005433805951	9346	Economy	62100.00
0005434273087	9346	Economy	62100.00
0005433785557	9346	Economy	62100.00
0005433785531	9346	Economy	62100.00
0005433785554	9346	Economy	62100.00
0005433805929	9346	Economy	62100.00
0005433785542	9346	Economy	62100.00
0005432666423	9346	Economy	62100.00
0005433805950	9346	Economy	62100.00
0005432666422	9346	Economy	62100.00
0005433763450	9346	Economy	62100.00
0005433763446	9346	Economy	62100.00
0005434171136	9346	Economy	62100.00
0005433805943	9346	Economy	62100.00
0005433805938	9346	Economy	62100.00
0005433785543	9346	Economy	62100.00
0005433785532	9346	Economy	62100.00
0005434171176	9346	Economy	62100.00
0005433805924	9346	Economy	62100.00
0005433805939	9346	Economy	62100.00
0005433785200	26222	Business	186200.00
0005433805796	26222	Business	186200.00
0005433785092	26222	Business	186200.00
0005433763301	26222	Business	186200.00
0005433785182	26222	Business	186200.00
0005433805727	26222	Business	186200.00
0005433785224	26222	Business	186200.00
0005433763321	26222	Business	186200.00
0005433785129	26222	Business	186200.00
0005434171289	26222	Business	186200.00
0005434271343	26222	Business	186200.00
0005433763345	26222	Business	186200.00
0005432663041	26222	Business	186200.00
0005433785169	26222	Business	186200.00
0005433785223	26222	Business	186200.00
0005433805797	26222	Business	186200.00
0005433805552	26222	Economy	68300.00
0005433785227	26222	Economy	68300.00
0005433785284	26222	Economy	62100.00
0005433805668	26222	Economy	62100.00
0005432663047	26222	Economy	62100.00
0005433805612	26222	Economy	62100.00
0005433763348	26222	Economy	62100.00
0005433763330	26222	Economy	62100.00
0005433785225	26222	Economy	62100.00
0005433785181	26222	Economy	62100.00
0005433785326	26222	Economy	62100.00
0005433805691	26222	Economy	62100.00
0005433805706	26222	Economy	62100.00
0005433763322	26222	Economy	62100.00
0005434151750	26222	Economy	62100.00
0005433785287	26222	Economy	62100.00
0005433785334	26222	Economy	62100.00
0005433805718	26222	Economy	62100.00
0005432657472	26222	Economy	62100.00
0005433785234	26222	Economy	62100.00
0005433785094	26222	Economy	62100.00
0005433785285	26222	Economy	62100.00
0005433805667	26222	Economy	62100.00
0005433805477	26222	Economy	62100.00
0005433785258	26222	Economy	62100.00
0005433763310	26222	Economy	62100.00
0005433805480	26222	Economy	62100.00
0005434171294	26222	Economy	62100.00
0005433763356	26222	Economy	62100.00
0005433763329	26222	Economy	62100.00
0005433785132	26222	Economy	62100.00
0005434171293	26222	Economy	62100.00
0005434151753	26222	Economy	62100.00
0005433785351	26222	Economy	62100.00
0005434270239	26222	Economy	62100.00
0005434171290	26222	Economy	62100.00
0005433805635	26222	Economy	62100.00
0005433805574	26222	Economy	62100.00
0005433785240	26222	Economy	62100.00
0005433763334	26222	Economy	62100.00
0005434271345	26222	Economy	62100.00
0005434171295	26222	Economy	62100.00
0005432666410	26222	Economy	62100.00
0005433785033	26222	Economy	62100.00
0005432666403	26222	Economy	62100.00
0005434171282	26222	Economy	62100.00
0005433805666	26222	Economy	62100.00
0005433785188	26222	Economy	62100.00
0005433785335	26222	Economy	62100.00
0005433785174	26222	Economy	62100.00
0005433785289	26222	Economy	62100.00
0005433805665	26222	Economy	62100.00
0005434171286	26222	Economy	62100.00
0005434269135	26222	Economy	62100.00
0005433805618	26222	Economy	62100.00
0005433785222	26222	Economy	62100.00
0005434151752	26222	Economy	62100.00
0005433805705	26222	Economy	62100.00
0005433785274	26222	Economy	62100.00
0005433805704	26222	Economy	62100.00
0005434171288	26222	Economy	62100.00
0005434171292	26222	Economy	62100.00
0005433785344	26222	Economy	62100.00
0005433785148	26222	Economy	68300.00
0005433785193	26222	Economy	62100.00
0005433805674	26222	Economy	62100.00
0005434171283	26222	Economy	62100.00
0005434171284	26222	Economy	62100.00
0005435269882	26222	Economy	62100.00
0005433785215	26222	Economy	62100.00
0005433763354	26222	Economy	62100.00
0005433785170	26222	Economy	62100.00
0005433785273	26222	Economy	62100.00
0005433763324	26222	Economy	62100.00
0005433785233	26222	Economy	62100.00
0005434270238	26222	Economy	62100.00
0005433763300	26222	Economy	62100.00
0005434270240	26222	Economy	62100.00
0005434171287	26222	Economy	62100.00
0005433763314	26222	Economy	62100.00
0005433785149	26222	Economy	62100.00
0005433785333	26222	Economy	62100.00
0005433805697	26222	Economy	62100.00
0005433805636	26222	Economy	62100.00
0005434171291	26222	Economy	62100.00
0005433805530	26222	Economy	62100.00
0005433785047	26222	Economy	62100.00
0005433785109	26222	Economy	62100.00
0005433763355	26222	Economy	62100.00
0005435269879	26222	Economy	62100.00
0005433805739	26222	Economy	62100.00
0005434151751	26222	Economy	62100.00
0005434171296	26222	Economy	62100.00
0005433785316	26222	Economy	62100.00
0005435269880	26222	Economy	62100.00
0005434269136	26222	Economy	62100.00
0005433805629	26222	Economy	62100.00
0005433805728	26222	Economy	62100.00
0005432657475	26222	Economy	62100.00
0005434171285	26222	Economy	62100.00
0005433805647	26222	Economy	62100.00
0005434271344	26222	Economy	62100.00
0005433785095	26222	Economy	62100.00
0005433785288	26222	Economy	62100.00
0005433763323	26222	Economy	62100.00
0005435269881	26222	Economy	62100.00
0005433763298	26222	Economy	62100.00
0005433805769	26222	Economy	62100.00
0005433785104	26222	Economy	62100.00
0005433785208	26222	Economy	62100.00
0005435135751	4925	Economy	5300.00
0005435135752	4925	Economy	5300.00
0005435929665	4925	Economy	5300.00
0005435135753	4925	Economy	5300.00
0005435135748	4925	Economy	5300.00
0005435135750	4925	Economy	5300.00
0005435135749	4925	Economy	5300.00
0005435135721	33040	Economy	5300.00
0005435929688	33040	Economy	5300.00
0005435135704	33040	Economy	5300.00
0005435135731	33040	Economy	5300.00
0005435929687	33040	Economy	5300.00
0005435135726	33040	Economy	5300.00
0005435135702	33040	Economy	5300.00
0005435135729	33040	Economy	5300.00
0005434218008	9458	Economy	19700.00
0005434983371	9458	Economy	19700.00
0005434983373	9458	Economy	17900.00
0005434217994	9458	Economy	17900.00
0005434217995	9458	Economy	17900.00
0005434983370	9458	Economy	17900.00
0005434218009	9458	Economy	17900.00
0005434218005	9458	Economy	17900.00
0005434983372	9458	Economy	17900.00
0005434983374	9458	Economy	17900.00
0005434218036	27371	Economy	17900.00
0005434983342	27371	Economy	17900.00
0005434983312	27371	Economy	17900.00
0005434218034	27371	Economy	17900.00
0005434218033	27371	Economy	17900.00
0005434983343	27371	Economy	17900.00
0005434983333	27371	Economy	17900.00
0005434983352	27371	Economy	17900.00
0005434218035	27371	Economy	17900.00
0005434983334	27371	Economy	17900.00
0005433961135	24267	Business	36400.00
0005433986135	24267	Business	36400.00
0005433961074	24267	Business	36400.00
0005433986181	24267	Business	36400.00
0005433961134	24267	Business	36400.00
0005433961318	24267	Business	36400.00
0005433986275	24267	Business	36400.00
0005433986332	24267	Business	36400.00
0005433961266	24267	Business	36400.00
0005433986168	24267	Business	36400.00
0005433961109	24267	Business	36400.00
0005433961279	24267	Business	36400.00
0005433986343	24267	Business	36400.00
0005433986260	24267	Business	36400.00
0005433986138	24267	Business	36400.00
0005433986225	24267	Economy	13400.00
0005433986259	24267	Economy	12100.00
0005433961212	24267	Economy	12100.00
0005433986431	24267	Economy	12100.00
0005433961185	24267	Economy	12100.00
0005433961132	24267	Economy	12100.00
0005433986182	24267	Economy	12100.00
0005433986261	24267	Economy	12100.00
0005433961251	24267	Economy	12100.00
0005433961274	24267	Economy	12100.00
0005433986314	24267	Economy	12100.00
0005433986273	24267	Economy	12100.00
0005433961205	24267	Economy	12100.00
0005433961209	24267	Economy	12100.00
0005433961236	24267	Economy	12100.00
0005433961303	24267	Economy	12100.00
0005433961250	24267	Economy	12100.00
0005433961213	24267	Economy	12100.00
0005433986344	24267	Economy	12100.00
0005433986169	24267	Economy	12100.00
0005433961260	24267	Economy	12100.00
0005433961178	24267	Economy	12100.00
0005433961289	24267	Economy	12100.00
0005433961232	24267	Economy	12100.00
0005433986166	24267	Economy	12100.00
0005433961190	24267	Economy	12100.00
0005433961312	24267	Economy	12100.00
0005433961087	24267	Economy	12100.00
0005433986272	24267	Economy	12100.00
0005433961020	24267	Economy	12100.00
0005433986274	24267	Economy	12100.00
0005433986328	24267	Economy	12100.00
0005433961076	24267	Economy	12100.00
0005433961267	24267	Economy	12100.00
0005433986179	24267	Economy	12100.00
0005433961216	24267	Economy	12100.00
0005433986246	24267	Economy	12100.00
0005433986107	24267	Economy	12100.00
0005433986303	24267	Economy	12100.00
0005433961133	24267	Economy	12100.00
0005433986224	24267	Economy	12100.00
0005433961295	24267	Economy	12100.00
0005433961264	24267	Economy	12100.00
0005433961235	24267	Economy	12100.00
0005433986432	24267	Economy	12100.00
0005433961302	24267	Economy	12100.00
0005433961139	24267	Economy	12100.00
0005433986123	24267	Economy	12100.00
0005433961051	24267	Economy	12100.00
0005433960906	24267	Economy	12100.00
0005433961191	24267	Economy	12100.00
0005433961299	24267	Economy	13400.00
0005433986412	24267	Economy	12100.00
0005433961314	24267	Economy	12100.00
0005433986333	24267	Economy	13400.00
0005433961145	24267	Economy	13400.00
0005433961007	24267	Economy	12100.00
0005433961177	24267	Economy	12100.00
0005433961224	24267	Economy	12100.00
0005433961095	24267	Economy	12100.00
0005433986167	24267	Economy	12100.00
0005433961077	24267	Economy	12100.00
0005433961140	24267	Economy	12100.00
0005433961265	24267	Economy	12100.00
0005433961296	24267	Economy	12100.00
0005433986336	24267	Economy	12100.00
0005433961210	24267	Economy	12100.00
0005433986411	24267	Economy	12100.00
0005433961201	24267	Economy	12100.00
0005433986327	24267	Economy	12100.00
0005433961313	24267	Economy	12100.00
0005433961301	24267	Economy	12100.00
0005433986313	24267	Economy	12100.00
0005433986267	24267	Economy	12100.00
0005433986306	24267	Economy	12100.00
0005433961198	24267	Economy	12100.00
0005433986207	24267	Economy	12100.00
0005433961231	24267	Economy	12100.00
0005433986015	24267	Economy	12100.00
0005433986386	24267	Economy	12100.00
0005433960981	24267	Economy	12100.00
0005433961275	24267	Economy	12100.00
0005433961045	24267	Economy	12100.00
0005433986266	24267	Economy	12100.00
0005433961317	24267	Economy	12100.00
0005433961223	24267	Economy	12100.00
0005433986312	24267	Economy	12100.00
0005433961046	24267	Economy	12100.00
0005433985865	24267	Economy	12100.00
0005433961290	24267	Economy	12100.00
0005433961138	24267	Economy	12100.00
0005433986674	25913	Business	36400.00
0005433986671	25913	Business	36400.00
0005433986661	25913	Business	36400.00
0005433986663	25913	Business	36400.00
0005433961758	25913	Business	36400.00
0005433961766	25913	Business	36400.00
0005433961763	25913	Business	36400.00
0005433961748	25913	Business	36400.00
0005433961737	25913	Business	36400.00
0005433961727	25913	Business	36400.00
0005433961757	25913	Business	36400.00
0005433961773	25913	Business	36400.00
0005433986676	25913	Business	36400.00
0005433961762	25913	Business	36400.00
0005433961765	25913	Business	36400.00
0005433961777	25913	Business	36400.00
0005433986655	25913	Business	36400.00
0005433961764	25913	Business	36400.00
0005433986686	25913	Economy	13400.00
0005433961750	25913	Economy	12100.00
0005433986669	25913	Economy	12100.00
0005433961724	25913	Economy	12100.00
0005433961730	25913	Economy	12100.00
0005433961717	25913	Economy	12100.00
0005433961771	25913	Economy	12100.00
0005433961747	25913	Economy	12100.00
0005433961752	25913	Economy	12100.00
0005433961738	25913	Economy	12100.00
0005433986650	25913	Economy	12100.00
0005433961726	25913	Economy	12100.00
0005433986672	25913	Economy	12100.00
0005433961728	25913	Economy	12100.00
0005433986683	25913	Economy	12100.00
0005433961745	25913	Economy	12100.00
0005433986656	25913	Economy	12100.00
0005433961719	25913	Economy	12100.00
0005433961721	25913	Economy	12100.00
0005433986670	25913	Economy	12100.00
0005433961739	25913	Economy	12100.00
0005433986660	25913	Economy	12100.00
0005433961749	25913	Economy	12100.00
0005433961735	25913	Economy	12100.00
0005433961770	25913	Economy	12100.00
0005433961731	25913	Economy	12100.00
0005433986679	25913	Economy	12100.00
0005433986657	25913	Economy	12100.00
0005433961768	25913	Economy	12100.00
0005433986647	25913	Economy	12100.00
0005433986678	25913	Economy	12100.00
0005433961741	25913	Economy	12100.00
0005433961776	25913	Economy	12100.00
0005433961723	25913	Economy	12100.00
0005433986689	25913	Economy	12100.00
0005433986648	25913	Economy	12100.00
0005433961732	25913	Economy	12100.00
0005433986665	25913	Economy	12100.00
0005433961746	25913	Economy	12100.00
0005433986685	25913	Economy	12100.00
0005433961769	25913	Economy	12100.00
0005433961729	25913	Economy	12100.00
0005433986680	25913	Economy	12100.00
0005433961713	25913	Economy	12100.00
0005433986666	25913	Economy	12100.00
0005433986675	25913	Economy	12100.00
0005433961714	25913	Economy	12100.00
0005433961775	25913	Economy	12100.00
0005433986658	25913	Economy	12100.00
0005433986690	25913	Economy	12100.00
0005433986649	25913	Economy	12100.00
0005433986667	25913	Economy	12100.00
0005433961759	25913	Economy	12100.00
0005433961756	25913	Economy	12100.00
0005433986688	25913	Economy	12100.00
0005433961774	25913	Economy	12100.00
0005433986662	25913	Economy	13400.00
0005433986684	25913	Economy	13400.00
0005433961755	25913	Economy	12100.00
0005433986653	25913	Economy	12100.00
0005433961718	25913	Economy	12100.00
0005433961720	25913	Economy	12100.00
0005433961772	25913	Economy	12100.00
0005433961716	25913	Economy	12100.00
0005433986664	25913	Economy	12100.00
0005433986659	25913	Economy	12100.00
0005433961725	25913	Economy	12100.00
0005433961754	25913	Economy	12100.00
0005433961715	25913	Economy	12100.00
0005433986682	25913	Economy	12100.00
0005433986692	25913	Economy	12100.00
0005433986651	25913	Economy	12100.00
0005433986691	25913	Economy	12100.00
0005433986673	25913	Economy	12100.00
0005433961761	25913	Economy	12100.00
0005433961734	25913	Economy	12100.00
0005433961760	25913	Economy	12100.00
0005433986677	25913	Economy	12100.00
0005433961743	25913	Economy	12100.00
0005433961736	25913	Economy	12100.00
0005433961744	25913	Economy	12100.00
0005433986652	25913	Economy	12100.00
0005433961753	25913	Economy	12100.00
0005433961733	25913	Economy	12100.00
0005433961740	25913	Economy	12100.00
0005433961722	25913	Economy	12100.00
0005433986687	25913	Economy	12100.00
0005433986668	25913	Economy	12100.00
0005433986681	25913	Economy	12100.00
0005433961767	25913	Economy	12100.00
0005433961742	25913	Economy	12100.00
0005433986654	25913	Economy	12100.00
0005433961751	25913	Economy	12100.00
0005433166001	949	Economy	25400.00
0005432269540	949	Economy	25400.00
0005433166014	949	Economy	25400.00
0005433166011	949	Economy	23100.00
0005434480742	949	Economy	23100.00
0005433166015	949	Economy	23100.00
0005434480745	949	Economy	23100.00
0005434480744	949	Economy	23100.00
0005433166038	949	Economy	23100.00
0005434480736	949	Economy	23100.00
0005434480737	949	Economy	23100.00
0005433166045	949	Economy	23100.00
0005433166037	949	Economy	23100.00
0005434480735	949	Economy	23100.00
0005432269541	949	Economy	23100.00
0005433166028	949	Economy	23100.00
0005434480733	949	Economy	23100.00
0005434480734	949	Economy	23100.00
0005433166002	949	Economy	23100.00
0005434480740	949	Economy	23100.00
0005434480746	949	Economy	23100.00
0005433166036	949	Economy	23100.00
0005433166044	949	Economy	23100.00
0005433166039	949	Economy	23100.00
0005434480731	949	Economy	23100.00
0005434480739	949	Economy	23100.00
0005434480738	949	Economy	23100.00
0005433166006	949	Economy	23100.00
0005432269542	949	Economy	23100.00
0005434480730	949	Economy	23100.00
0005434480732	949	Economy	23100.00
0005434480743	949	Economy	23100.00
0005433166035	949	Economy	23100.00
0005434480741	949	Economy	23100.00
0005434480659	16558	Economy	25400.00
0005433166118	16558	Economy	25400.00
0005433166114	16558	Economy	23100.00
0005434480493	16558	Economy	23100.00
0005433166117	16558	Economy	23100.00
0005433166120	16558	Economy	23100.00
0005434480538	16558	Economy	23100.00
0005434480451	16558	Economy	23100.00
0005434480515	16558	Economy	23100.00
0005434480468	16558	Economy	23100.00
0005434480602	16558	Economy	23100.00
0005434480595	16558	Economy	23100.00
0005434480574	16558	Economy	23100.00
0005434480403	16558	Economy	23100.00
0005433166115	16558	Economy	23100.00
0005434480492	16558	Economy	23100.00
0005434480601	16558	Economy	23100.00
0005433166124	16558	Economy	23100.00
0005433166121	16558	Economy	23100.00
0005433166122	16558	Economy	23100.00
0005433166111	16558	Economy	23100.00
0005434480599	16558	Economy	23100.00
0005433166112	16558	Economy	23100.00
0005433166119	16558	Economy	23100.00
0005434480419	16558	Economy	23100.00
0005434480575	16558	Economy	23100.00
0005433166113	16558	Economy	23100.00
0005433166123	16558	Economy	23100.00
0005433166116	16558	Economy	23100.00
0005434480454	16558	Economy	23100.00
0005435142779	10334	Economy	17000.00
0005435386615	10334	Economy	17000.00
0005435142780	10334	Economy	17000.00
0005435150236	10334	Economy	15400.00
0005435150249	10334	Economy	15400.00
0005435386585	10334	Economy	15400.00
0005435386626	10334	Economy	15400.00
0005435150248	10334	Economy	15400.00
0005433289865	10334	Economy	15400.00
0005435386584	10334	Economy	15400.00
0005435142782	10334	Economy	15400.00
0005435142784	10334	Economy	15400.00
0005433289870	10334	Economy	15400.00
0005435386634	10334	Economy	15400.00
0005433289897	10334	Economy	15400.00
0005433289908	10334	Economy	15400.00
0005435142789	10334	Economy	15400.00
0005435142785	10334	Economy	15400.00
0005435142790	10334	Economy	15400.00
0005435150243	10334	Economy	15400.00
0005435142786	10334	Economy	15400.00
0005435142787	10334	Economy	15400.00
0005435150244	10334	Economy	15400.00
0005435150247	10334	Economy	15400.00
0005435386586	10334	Economy	15400.00
0005435150250	10334	Economy	15400.00
0005433289886	10334	Economy	15400.00
0005435142783	10334	Economy	15400.00
0005435150238	10334	Economy	15400.00
0005435150240	10334	Economy	15400.00
0005435142781	10334	Economy	15400.00
0005433289888	10334	Economy	15400.00
0005435142788	10334	Economy	15400.00
0005435150237	10334	Economy	15400.00
0005435386590	10334	Economy	15400.00
0005435150241	10334	Economy	15400.00
0005435386589	10334	Economy	15400.00
0005435142792	10334	Economy	15400.00
0005433289887	10334	Economy	15400.00
0005435150246	10334	Economy	15400.00
0005435150242	10334	Economy	15400.00
0005435150239	10334	Economy	15400.00
0005435142791	10334	Economy	15400.00
0005435150245	10334	Economy	15400.00
0005435142732	21961	Economy	17000.00
0005435150089	21961	Economy	17000.00
0005435142691	21961	Economy	17000.00
0005435142726	21961	Economy	17000.00
0005435142632	21961	Economy	15400.00
0005435142727	21961	Economy	15400.00
0005433289976	21961	Economy	15400.00
0005435150114	21961	Economy	15400.00
0005435142672	21961	Economy	15400.00
0005435386679	21961	Economy	15400.00
0005435150147	21961	Economy	15400.00
0005435150090	21961	Economy	15400.00
0005435142714	21961	Economy	15400.00
0005435142659	21961	Economy	15400.00
0005433289970	21961	Economy	15400.00
0005435142666	21961	Economy	15400.00
0005435386675	21961	Economy	15400.00
0005435150145	21961	Economy	15400.00
0005433289975	21961	Economy	15400.00
0005435150133	21961	Economy	15400.00
0005435386677	21961	Economy	15400.00
0005435142694	21961	Economy	15400.00
0005435386678	21961	Economy	15400.00
0005435142660	21961	Economy	15400.00
0005435150128	21961	Economy	15400.00
0005435142631	21961	Economy	15400.00
0005433289972	21961	Economy	15400.00
0005435150109	21961	Economy	15400.00
0005435386680	21961	Economy	15400.00
0005435150110	21961	Economy	15400.00
0005435150054	21961	Economy	15400.00
0005435142657	21961	Economy	15400.00
0005435150108	21961	Economy	15400.00
0005435142668	21961	Economy	15400.00
0005435142654	21961	Economy	15400.00
0005435150146	21961	Economy	15400.00
0005435142725	21961	Economy	15400.00
0005433289971	21961	Economy	15400.00
0005435150099	21961	Economy	15400.00
0005433289974	21961	Economy	15400.00
0005435150115	21961	Economy	15400.00
0005435150134	21961	Economy	15400.00
0005435150118	21961	Economy	15400.00
0005435386674	21961	Economy	15400.00
0005435142663	21961	Economy	15400.00
0005433289973	21961	Economy	15400.00
0005435150116	21961	Economy	15400.00
0005435386676	21961	Economy	15400.00
0005434573570	11237	Business	57200.00
0005435502568	11237	Business	57200.00
0005435502479	11237	Business	57200.00
0005435319651	11237	Business	57200.00
0005435502555	11237	Business	57200.00
0005434573574	11237	Business	57200.00
0005435545782	11237	Business	57200.00
0005435545784	11237	Business	57200.00
0005435502588	11237	Business	57200.00
0005435502539	11237	Business	57200.00
0005435502384	11237	Business	57200.00
0005435529408	11237	Economy	19100.00
0005435319706	11237	Economy	19100.00
0005435502503	11237	Economy	19100.00
0005435529467	11237	Economy	19100.00
0005434573577	11237	Economy	19100.00
0005435502581	11237	Economy	19100.00
0005435319650	11237	Economy	19100.00
0005435529511	11237	Economy	19100.00
0005435545775	11237	Economy	19100.00
0005435529283	11237	Economy	21000.00
0005435529396	11237	Economy	21000.00
0005435319666	11237	Economy	21000.00
0005435545786	11237	Economy	21000.00
0005435319704	11237	Economy	21000.00
0005434573573	11237	Economy	19100.00
0005434573565	11237	Economy	19100.00
0005435529310	11237	Economy	19100.00
0005435502572	11237	Economy	19100.00
0005435502463	11237	Economy	19100.00
0005435529368	11237	Economy	19100.00
0005435502484	11237	Economy	19100.00
0005435502554	11237	Economy	19100.00
0005435502502	11237	Economy	19100.00
0005434573572	11237	Economy	19100.00
0005435529398	11237	Economy	19100.00
0005435502516	11237	Economy	19100.00
0005435502542	11237	Economy	19100.00
0005435529410	11237	Economy	19100.00
0005435529406	11237	Economy	19100.00
0005435502513	11237	Economy	19100.00
0005435529397	11237	Economy	19100.00
0005435502486	11237	Economy	19100.00
0005435319667	11237	Economy	19100.00
0005434573566	11237	Economy	19100.00
0005435502450	11237	Economy	19100.00
0005434573569	11237	Economy	19100.00
0005435319653	11237	Economy	19100.00
0005435502567	11237	Economy	19100.00
0005435529407	11237	Economy	19100.00
0005435319586	11237	Economy	19100.00
0005434573571	11237	Economy	19100.00
0005435529413	11237	Economy	19100.00
0005435529458	11237	Economy	19100.00
0005435319638	11237	Economy	19100.00
0005435502383	11237	Economy	19100.00
0005435502442	11237	Economy	19100.00
0005435502497	11237	Economy	19100.00
0005435319646	11237	Economy	19100.00
0005434573564	11237	Economy	19100.00
0005435502480	11237	Economy	19100.00
0005435502582	11237	Economy	19100.00
0005435502543	11237	Economy	19100.00
0005435319656	11237	Economy	19100.00
0005435502427	11237	Economy	19100.00
0005434573567	11237	Economy	19100.00
0005435529424	11237	Economy	19100.00
0005434573568	11237	Economy	19100.00
0005435502417	11237	Economy	19100.00
0005435319673	11237	Economy	19100.00
0005435502429	11237	Economy	19100.00
0005434573575	11237	Economy	19100.00
0005435529457	11237	Economy	19100.00
0005435502496	11237	Economy	19100.00
0005435529369	11237	Economy	19100.00
0005435502587	11237	Economy	19100.00
0005435502470	11237	Economy	19100.00
0005435529385	11237	Economy	19100.00
0005435529282	11237	Economy	19100.00
0005435502426	11237	Economy	19100.00
0005434573576	11237	Economy	19100.00
0005435502481	11237	Economy	19100.00
0005435502512	11237	Economy	19100.00
0005435502446	11237	Economy	19100.00
0005435529456	11237	Economy	19100.00
0005435502638	11237	Economy	19100.00
0005435319593	11237	Economy	19100.00
0005435529409	11237	Economy	19100.00
0005435319705	11237	Economy	19100.00
0005435508537	20960	Business	57200.00
0005435502653	20960	Business	57200.00
0005435502657	20960	Business	57200.00
0005435502643	20960	Business	57200.00
0005434573404	20960	Business	57200.00
0005435508534	20960	Business	57200.00
0005435319724	20960	Business	57200.00
0005435502654	20960	Business	57200.00
0005435508536	20960	Business	57200.00
0005435502655	20960	Business	57200.00
0005435518205	20960	Business	57200.00
0005435319729	20960	Business	57200.00
0005435508544	20960	Economy	19100.00
0005434573461	20960	Economy	19100.00
0005435508542	20960	Economy	19100.00
0005435319731	20960	Economy	19100.00
0005435518204	20960	Economy	19100.00
0005435502660	20960	Economy	19100.00
0005435518214	20960	Economy	19100.00
0005434573495	20960	Economy	19100.00
0005435502656	20960	Economy	21000.00
0005434573487	20960	Economy	21000.00
0005434573380	20960	Economy	21000.00
0005435518209	20960	Economy	21000.00
0005435319723	20960	Economy	19100.00
0005435502662	20960	Economy	19100.00
0005435518213	20960	Economy	19100.00
0005435502644	20960	Economy	19100.00
0005434573411	20960	Economy	19100.00
0005434573479	20960	Economy	19100.00
0005435502641	20960	Economy	19100.00
0005434573494	20960	Economy	19100.00
0005435518211	20960	Economy	19100.00
0005434573460	20960	Economy	19100.00
0005435518199	20960	Economy	19100.00
0005435508543	20960	Economy	19100.00
0005435518200	20960	Economy	19100.00
0005435518210	20960	Economy	19100.00
0005435508541	20960	Economy	19100.00
0005435518203	20960	Economy	19100.00
0005434573517	20960	Economy	19100.00
0005435518217	20960	Economy	19100.00
0005435502645	20960	Economy	19100.00
0005435518202	20960	Economy	19100.00
0005435319726	20960	Economy	19100.00
0005435502652	20960	Economy	19100.00
0005435508546	20960	Economy	19100.00
0005434573453	20960	Economy	19100.00
0005435502651	20960	Economy	19100.00
0005434573410	20960	Economy	19100.00
0005435518212	20960	Economy	19100.00
0005435508548	20960	Economy	19100.00
0005435319730	20960	Economy	19100.00
0005435518215	20960	Economy	19100.00
0005435319725	20960	Economy	19100.00
0005435502648	20960	Economy	19100.00
0005435502650	20960	Economy	19100.00
0005435518216	20960	Economy	19100.00
0005432291967	20960	Economy	19100.00
0005435502658	20960	Economy	19100.00
0005435502661	20960	Economy	19100.00
0005435508547	20960	Economy	19100.00
0005435508545	20960	Economy	19100.00
0005435508535	20960	Economy	19100.00
0005435502647	20960	Economy	19100.00
0005435518208	20960	Economy	19100.00
0005434573381	20960	Economy	19100.00
0005432291968	20960	Economy	19100.00
0005435518207	20960	Economy	19100.00
0005435508549	20960	Economy	19100.00
0005435502646	20960	Economy	19100.00
0005435508539	20960	Economy	19100.00
0005435502642	20960	Economy	19100.00
0005435319728	20960	Economy	19100.00
0005435518198	20960	Economy	19100.00
0005435502659	20960	Economy	19100.00
0005435502649	20960	Economy	19100.00
0005435518201	20960	Economy	19100.00
0005435508540	20960	Economy	19100.00
0005435319727	20960	Economy	19100.00
0005434573444	20960	Economy	19100.00
0005435518206	20960	Economy	19100.00
0005434573443	20960	Economy	19100.00
0005435508538	20960	Economy	19100.00
0005432693300	2932	Business	10300.00
0005432693275	2932	Business	10300.00
0005432693188	2932	Business	10300.00
0005432693306	2932	Business	10300.00
0005432693237	2932	Economy	3400.00
0005432693284	2932	Economy	3400.00
0005432693263	2932	Economy	3400.00
0005432693299	2932	Economy	3400.00
0005432693354	2932	Economy	3400.00
0005432693433	2932	Economy	3400.00
0005432693382	2932	Economy	3400.00
0005432693187	2932	Economy	3400.00
0005432693388	2932	Economy	3400.00
0005432693434	2932	Economy	3400.00
0005432693381	2932	Economy	3400.00
0005432693305	2932	Economy	3400.00
0005432693276	2932	Economy	3400.00
0005432693346	2932	Economy	3400.00
0005432693215	2932	Economy	3400.00
0005432693277	2932	Economy	3400.00
0005432693217	2932	Economy	3400.00
0005432693353	2932	Economy	3400.00
0005432693195	2932	Economy	3400.00
0005432693274	2932	Economy	3400.00
0005432693341	2932	Economy	3400.00
0005432693342	2932	Economy	3400.00
0005432693304	2932	Economy	3400.00
0005432693344	2932	Economy	3400.00
0005432693270	2932	Economy	3400.00
0005432693219	2932	Economy	3400.00
0005432693371	2932	Economy	3400.00
0005432693246	2932	Economy	3400.00
0005432693373	2932	Economy	3400.00
0005432693347	2932	Economy	3400.00
0005432693365	2932	Economy	3400.00
0005432693223	2932	Economy	3400.00
0005432693220	2932	Economy	3400.00
0005432880872	2933	Business	10300.00
0005433124123	2933	Business	10300.00
0005433124008	2933	Business	10300.00
0005432880882	2933	Business	10300.00
0005432880978	2933	Business	10300.00
0005432880945	2933	Business	10300.00
0005433124159	2933	Business	10300.00
0005432707186	2933	Economy	3400.00
0005433124091	2933	Economy	3400.00
0005433124075	2933	Economy	3400.00
0005432707189	2933	Economy	3400.00
0005432707195	2933	Economy	3400.00
0005432880904	2933	Economy	3400.00
0005432707199	2933	Economy	3400.00
0005433124129	2933	Economy	3400.00
0005433124082	2933	Economy	3400.00
0005433124009	2933	Economy	3800.00
0005433124074	2933	Economy	3800.00
0005433124160	2933	Economy	3400.00
0005432707190	2933	Economy	3400.00
0005432707187	2933	Economy	3400.00
0005433124083	2933	Economy	3400.00
0005432707191	2933	Economy	3400.00
0005432880840	2933	Economy	3400.00
0005432880993	2933	Economy	3400.00
0005433124081	2933	Economy	3400.00
0005433124017	2933	Economy	3400.00
0005432880957	2933	Economy	3400.00
0005433124092	2933	Economy	3400.00
0005432880946	2933	Economy	3400.00
0005432707196	2933	Economy	3400.00
0005432707188	2933	Economy	3400.00
0005432880956	2933	Economy	3400.00
0005432707194	2933	Economy	3400.00
0005432880921	2933	Economy	3400.00
0005432880973	2933	Economy	3400.00
0005433124084	2933	Economy	3400.00
0005432707175	2933	Economy	3400.00
0005432707197	2933	Economy	3400.00
0005433194862	2933	Economy	3400.00
0005433124128	2933	Economy	3400.00
0005432880908	2933	Economy	3400.00
0005432880965	2933	Economy	3400.00
0005433194885	2933	Economy	3400.00
0005432707180	2933	Economy	3400.00
0005432707176	2933	Economy	3400.00
0005432707173	2933	Economy	3400.00
0005432707182	2933	Economy	3400.00
0005432217823	2933	Economy	3400.00
0005433194865	2933	Economy	3400.00
0005433124090	2933	Economy	3400.00
0005432707181	2933	Economy	3400.00
0005432707185	2933	Economy	3400.00
0005432707174	2933	Economy	3400.00
0005432707179	2933	Economy	3400.00
0005433124124	2933	Economy	3400.00
0005432707172	2933	Economy	3400.00
0005432707192	2933	Economy	3400.00
0005432707184	2933	Economy	3400.00
0005432880922	2933	Economy	3400.00
0005432707183	2933	Economy	3400.00
0005432707178	2933	Economy	3400.00
0005432707177	2933	Economy	3400.00
0005433124085	2933	Economy	3400.00
0005432707193	2933	Economy	3400.00
0005432880977	2933	Economy	3400.00
0005433124056	2933	Economy	3400.00
0005432880974	2933	Economy	3400.00
0005433194863	2933	Economy	3400.00
0005433124087	2933	Economy	3400.00
0005432880846	2933	Economy	3400.00
0005432880949	2933	Economy	3400.00
0005433194866	2933	Economy	3400.00
0005432880910	2933	Economy	3400.00
0005432707198	2933	Economy	3400.00
0005433194899	29951	Business	10300.00
0005432693581	29951	Business	10300.00
0005432707057	29951	Business	10300.00
0005432881060	29951	Business	10300.00
0005432881056	29951	Business	10300.00
0005432706990	29951	Business	10300.00
0005432706991	29951	Business	10300.00
0005433124252	29951	Business	10300.00
0005432706962	29951	Business	10300.00
0005433124263	29951	Business	10300.00
0005432693585	29951	Business	10300.00
0005432693591	29951	Business	10300.00
0005432706978	29951	Economy	3400.00
0005432881049	29951	Economy	3400.00
0005433194898	29951	Economy	3400.00
0005432706953	29951	Economy	3400.00
0005432881048	29951	Economy	3400.00
0005432881053	29951	Economy	3400.00
0005432707097	29951	Economy	3400.00
0005433124250	29951	Economy	3400.00
0005432706992	29951	Economy	3400.00
0005432706993	29951	Economy	3800.00
0005432693571	29951	Economy	3800.00
0005432706973	29951	Economy	3800.00
0005432706983	29951	Economy	3800.00
0005432706982	29951	Economy	3800.00
0005432693599	29951	Economy	3400.00
0005432693583	29951	Economy	3400.00
0005432706963	29951	Economy	3400.00
0005433124248	29951	Economy	3400.00
0005432706784	29951	Economy	3400.00
0005432693574	29951	Economy	3400.00
0005432881058	29951	Economy	3400.00
0005432693589	29951	Economy	3400.00
0005433124257	29951	Economy	3400.00
0005432706952	29951	Economy	3400.00
0005433124261	29951	Economy	3400.00
0005432881047	29951	Economy	3400.00
0005433124255	29951	Economy	3400.00
0005432693569	29951	Economy	3400.00
0005432706926	29951	Economy	3400.00
0005433124242	29951	Economy	3400.00
0005432693579	29951	Economy	3400.00
0005433124247	29951	Economy	3400.00
0005432707019	29951	Economy	3400.00
0005432693573	29951	Economy	3400.00
0005432707002	29951	Economy	3400.00
0005433124245	29951	Economy	3400.00
0005432693577	29951	Economy	3400.00
0005432693588	29951	Economy	3400.00
0005432693578	29951	Economy	3400.00
0005432693594	29951	Economy	3400.00
0005432693580	29951	Economy	3400.00
0005433124254	29951	Economy	3400.00
0005433124246	29951	Economy	3400.00
0005432706783	29951	Economy	3400.00
0005432706988	29951	Economy	3400.00
0005432881057	29951	Economy	3400.00
0005432706908	29951	Economy	3400.00
0005433124256	29951	Economy	3400.00
0005432693584	29951	Economy	3400.00
0005432693576	29951	Economy	3400.00
0005432693598	29951	Economy	3400.00
0005433124258	29951	Economy	3400.00
0005432707038	29951	Economy	3400.00
0005432881055	29951	Economy	3400.00
0005432693575	29951	Economy	3400.00
0005432706961	29951	Economy	3400.00
0005432693595	29951	Economy	3400.00
0005432881054	29951	Economy	3400.00
0005433124251	29951	Economy	3400.00
0005433124259	29951	Economy	3400.00
0005432881052	29951	Economy	3400.00
0005433124244	29951	Economy	3400.00
0005432693593	29951	Economy	3400.00
0005433124249	29951	Economy	3400.00
0005432693596	29951	Economy	3400.00
0005432693586	29951	Economy	3400.00
0005433124241	29951	Economy	3400.00
0005433124262	29951	Economy	3400.00
0005432693572	29951	Economy	3400.00
0005433124253	29951	Economy	3400.00
0005432693582	29951	Economy	3400.00
0005433124260	29951	Economy	3400.00
0005432881050	29951	Economy	3400.00
0005432693592	29951	Economy	3400.00
0005432693597	29951	Economy	3400.00
0005432706998	29951	Economy	3400.00
0005432693587	29951	Economy	3400.00
0005432881059	29951	Economy	3400.00
0005432706977	29951	Economy	3400.00
0005432693590	29951	Economy	3400.00
0005432693570	29951	Economy	3400.00
0005432881051	29951	Economy	3400.00
0005433124243	29951	Economy	3400.00
0005434988911	23684	Economy	4000.00
0005434980244	23684	Economy	4000.00
0005434980254	23684	Economy	4000.00
0005434980265	23684	Economy	4000.00
0005434980264	23684	Economy	3600.00
0005434980245	23684	Economy	3600.00
0005434988907	23684	Economy	3600.00
0005434980260	23684	Economy	3600.00
0005434988906	23684	Economy	3600.00
0005434988903	23684	Economy	3600.00
0005434980262	23684	Economy	3600.00
0005434988902	23684	Economy	3600.00
0005434980238	23684	Economy	3600.00
0005434980247	23684	Economy	3600.00
0005434988908	23684	Economy	3600.00
0005434980259	23684	Economy	3600.00
0005434988909	23684	Economy	3600.00
0005434980266	23684	Economy	3600.00
0005434980242	23684	Economy	3600.00
0005434980258	23684	Economy	3600.00
0005434980251	23684	Economy	3600.00
0005434980240	23684	Economy	3600.00
0005434988901	23684	Economy	3600.00
0005434980239	23684	Economy	3600.00
0005434980248	23684	Economy	3600.00
0005434980252	23684	Economy	3600.00
0005434980250	23684	Economy	3600.00
0005434980241	23684	Economy	3600.00
0005434988905	23684	Economy	3600.00
0005434980261	23684	Economy	3600.00
0005434980257	23684	Economy	3600.00
0005434980255	23684	Economy	3600.00
0005434980237	23684	Economy	3600.00
0005434980263	23684	Economy	3600.00
0005434988904	23684	Economy	3600.00
0005434980253	23684	Economy	3600.00
0005434980243	23684	Economy	3600.00
0005434980246	23684	Economy	3600.00
0005434980256	23684	Economy	3600.00
0005434988900	23684	Economy	3600.00
0005434980249	23684	Economy	3600.00
0005434988910	23684	Economy	3600.00
0005434979965	27554	Economy	4000.00
0005434980008	27554	Economy	4000.00
0005434988810	27554	Economy	3600.00
0005434980012	27554	Economy	3600.00
0005434979834	27554	Economy	3600.00
0005434988811	27554	Economy	3600.00
0005434980013	27554	Economy	3600.00
0005434980027	27554	Economy	3600.00
0005434979977	27554	Economy	3600.00
0005434979811	27554	Economy	3600.00
0005434980014	27554	Economy	3600.00
0005434980006	27554	Economy	3600.00
0005434988812	27554	Economy	3600.00
0005434979876	27554	Economy	3600.00
0005434988791	27554	Economy	3600.00
0005434980066	27554	Economy	3600.00
0005434980000	27554	Economy	3600.00
0005434988815	27554	Economy	3600.00
0005434979847	27554	Economy	3600.00
0005434979812	27554	Economy	3600.00
0005434980064	27554	Economy	3600.00
0005434988788	27554	Economy	3600.00
0005434979868	27554	Economy	3600.00
0005434979975	27554	Economy	3600.00
0005434979964	27554	Economy	3600.00
0005434988813	27554	Economy	3600.00
0005434980141	27554	Economy	3600.00
0005434979996	27554	Economy	3600.00
0005434980062	27554	Economy	3600.00
0005434979986	27554	Economy	3600.00
0005434980142	27554	Economy	3600.00
0005434980094	27554	Economy	3600.00
0005434980031	27554	Economy	3600.00
0005434980026	27554	Economy	3600.00
0005434980095	27554	Economy	3600.00
0005434980025	27554	Economy	3600.00
0005434979978	27554	Economy	3600.00
0005434988792	27554	Economy	3600.00
0005434980065	27554	Economy	3600.00
0005433113553	10269	Economy	21600.00
0005433113552	10269	Economy	21600.00
0005434302526	10269	Economy	19700.00
0005433113547	10269	Economy	19700.00
0005433113545	10269	Economy	19700.00
0005433111510	10269	Economy	19700.00
0005434302528	10269	Economy	19700.00
0005433111516	10269	Economy	19700.00
0005433113542	10269	Economy	19700.00
0005434302525	10269	Economy	19700.00
0005434302527	10269	Economy	19700.00
0005434302878	10269	Economy	19700.00
0005434302877	10269	Economy	19700.00
0005433111515	10269	Economy	19700.00
0005433113572	19620	Economy	19700.00
0005434302491	19620	Economy	19700.00
0005434302503	19620	Economy	19700.00
0005434302495	19620	Economy	19700.00
0005434302487	19620	Economy	19700.00
0005435069943	3525	Business	26900.00
0005435069949	3525	Business	26900.00
0005435925405	3525	Business	26900.00
0005435069916	3525	Business	26900.00
0005435069915	3525	Business	26900.00
0005435069940	3525	Business	26900.00
0005435069928	3525	Business	26900.00
0005435069910	3525	Business	26900.00
0005435069932	3525	Economy	9000.00
0005435925394	3525	Economy	9000.00
0005435069937	3525	Economy	9000.00
0005435069948	3525	Economy	9000.00
0005435925406	3525	Economy	9000.00
0005435069942	3525	Economy	9000.00
0005435069946	3525	Economy	9000.00
0005435069919	3525	Economy	9900.00
0005435069908	3525	Economy	9900.00
0005435069923	3525	Economy	9900.00
0005435069927	3525	Economy	9900.00
0005435069906	3525	Economy	9000.00
0005435069914	3525	Economy	9000.00
0005435069936	3525	Economy	9000.00
0005435069921	3525	Economy	9000.00
0005435069909	3525	Economy	9000.00
0005435069941	3525	Economy	9000.00
0005435925411	3525	Economy	9000.00
0005435925356	3525	Economy	9000.00
0005435925373	3525	Economy	9000.00
0005435069913	3525	Economy	9000.00
0005435069931	3525	Economy	9000.00
0005435069929	3525	Economy	9000.00
0005435069925	3525	Economy	9000.00
0005435069935	3525	Economy	9000.00
0005435925409	3525	Economy	9000.00
0005435069911	3525	Economy	9000.00
0005435069956	3525	Economy	9000.00
0005435069952	3525	Economy	9000.00
0005435069917	3525	Economy	9000.00
0005435925392	3525	Economy	9000.00
0005435069907	3525	Economy	9000.00
0005435069938	3525	Economy	9000.00
0005435069957	3525	Economy	9000.00
0005435069951	3525	Economy	9000.00
0005435925391	3525	Economy	9000.00
0005435069924	3525	Economy	9000.00
0005435069945	3525	Economy	9000.00
0005435719035	3525	Economy	9000.00
0005435069953	3525	Economy	9000.00
0005435925390	3525	Economy	9000.00
0005435069918	3525	Economy	9000.00
0005435069950	3525	Economy	9000.00
0005435069934	3525	Economy	9000.00
0005435069922	3525	Economy	9000.00
0005435069955	3525	Economy	9000.00
0005435925395	3525	Economy	9000.00
0005435069947	3525	Economy	9000.00
0005435069954	3525	Economy	9000.00
0005435069944	3525	Economy	9000.00
0005435069933	3525	Economy	9000.00
0005435069958	3525	Economy	9000.00
0005435069930	3525	Economy	9000.00
0005435925363	3525	Economy	9000.00
0005435069912	3525	Economy	9000.00
0005435069939	3525	Economy	9000.00
0005435925355	3525	Economy	9000.00
0005435069920	3525	Economy	9000.00
0005435069926	3525	Economy	9000.00
0005435925374	3525	Economy	9000.00
0005435069575	15281	Business	26900.00
0005435925506	15281	Business	26900.00
0005435925515	15281	Business	26900.00
0005435925520	15281	Business	26900.00
0005435925522	15281	Business	26900.00
0005435925512	15281	Business	26900.00
0005435925517	15281	Business	26900.00
0005435069522	15281	Business	26900.00
0005435069290	15281	Business	26900.00
0005435069484	15281	Economy	9000.00
0005435925514	15281	Economy	9000.00
0005435069364	15281	Economy	9000.00
0005435925526	15281	Economy	9000.00
0005435069500	15281	Economy	9000.00
0005435069560	15281	Economy	9000.00
0005435925509	15281	Economy	9900.00
0005435069389	15281	Economy	9900.00
0005435925504	15281	Economy	9900.00
0005435069559	15281	Economy	9000.00
0005435925510	15281	Economy	9000.00
0005435925519	15281	Economy	9000.00
0005435069272	15281	Economy	9000.00
0005435069334	15281	Economy	9000.00
0005435069438	15281	Economy	9000.00
0005435069409	15281	Economy	9000.00
0005435069387	15281	Economy	9000.00
0005435069441	15281	Economy	9000.00
0005435925513	15281	Economy	9000.00
0005435069320	15281	Economy	9000.00
0005435069400	15281	Economy	9000.00
0005435925502	15281	Economy	9000.00
0005435069454	15281	Economy	9000.00
0005435925524	15281	Economy	9000.00
0005435925521	15281	Economy	9000.00
0005435069323	15281	Economy	9000.00
0005435069501	15281	Economy	9000.00
0005435925527	15281	Economy	9000.00
0005435925508	15281	Economy	9000.00
0005435069440	15281	Economy	9000.00
0005435069584	15281	Economy	9000.00
0005435925503	15281	Economy	9000.00
0005435069408	15281	Economy	9000.00
0005435925525	15281	Economy	9000.00
0005435069469	15281	Economy	9000.00
0005435925505	15281	Economy	9000.00
0005435069321	15281	Economy	9000.00
0005435925507	15281	Economy	9000.00
0005435069483	15281	Economy	9000.00
0005435925511	15281	Economy	9000.00
0005435939910	15281	Economy	9000.00
0005435069306	15281	Economy	9000.00
0005435069337	15281	Economy	9000.00
0005435069198	15281	Economy	9000.00
0005435069307	15281	Economy	9000.00
0005435925518	15281	Economy	9000.00
0005435925523	15281	Economy	9000.00
0005435069477	15281	Economy	9000.00
0005435069254	15281	Economy	9000.00
0005435925516	15281	Economy	9000.00
0005432660852	18203	Economy	5900.00
0005432658626	18203	Economy	5900.00
0005432658624	18203	Economy	5900.00
0005432658627	18203	Economy	5900.00
0005432660851	18203	Economy	5900.00
0005432658625	18203	Economy	5900.00
0005432660829	26459	Economy	5900.00
0005432664130	26459	Economy	5900.00
0005432664145	26459	Economy	5900.00
0005432667457	26459	Economy	5900.00
0005432664144	26459	Economy	5900.00
0005432660830	26459	Economy	5900.00
0005432667468	26459	Economy	5900.00
0005432664129	26459	Economy	5900.00
0005432667467	26459	Economy	5900.00
0005432664143	26459	Economy	5900.00
0005432660832	26459	Economy	5900.00
0005432664148	26459	Economy	5900.00
0005432901780	164	Business	20000.00
0005432920021	164	Business	20000.00
0005432920108	164	Business	20000.00
0005433102516	164	Business	20000.00
0005433102611	164	Business	20000.00
0005432901815	164	Business	20000.00
0005433102639	164	Business	20000.00
0005432920010	164	Business	20000.00
0005433102438	164	Business	20000.00
0005433102565	164	Business	20000.00
0005432920079	164	Business	20000.00
0005433102469	164	Business	20000.00
0005432920074	164	Business	20000.00
0005433102262	164	Business	20000.00
0005432920039	164	Business	20000.00
0005433102462	164	Business	20000.00
0005432920011	164	Business	20000.00
0005433102597	164	Business	20000.00
0005432920046	164	Business	20000.00
0005433102664	164	Business	20000.00
0005433102534	164	Business	20000.00
0005433102560	164	Economy	7300.00
0005432919969	164	Economy	7300.00
0005432677610	164	Economy	7300.00
0005433102601	164	Economy	7300.00
0005433102491	164	Economy	7300.00
0005433102604	164	Economy	7300.00
0005432920073	164	Economy	6700.00
0005432901762	164	Economy	6700.00
0005432920040	164	Economy	6700.00
0005433102600	164	Economy	6700.00
0005433102504	164	Economy	6700.00
0005433102577	164	Economy	6700.00
0005433102468	164	Economy	6700.00
0005433102646	164	Economy	6700.00
0005432901713	164	Economy	6700.00
0005433102403	164	Economy	6700.00
0005433102638	164	Economy	6700.00
0005433102263	164	Economy	6700.00
0005432677597	164	Economy	6700.00
0005433102535	164	Economy	6700.00
0005432901740	164	Economy	6700.00
0005433102408	164	Economy	6700.00
0005432920022	164	Economy	6700.00
0005433102476	164	Economy	6700.00
0005432901823	164	Economy	6700.00
0005432901798	164	Economy	6700.00
0005433102566	164	Economy	6700.00
0005433102658	164	Economy	6700.00
0005432901783	164	Economy	6700.00
0005432901779	164	Economy	6700.00
0005433102404	164	Economy	6700.00
0005433102503	164	Economy	6700.00
0005433102442	164	Economy	6700.00
0005432901781	164	Economy	6700.00
0005433102538	164	Economy	6700.00
0005432901770	164	Economy	6700.00
0005433102479	164	Economy	6700.00
0005433102400	164	Economy	6700.00
0005432920041	164	Economy	6700.00
0005432901708	164	Economy	6700.00
0005432920007	164	Economy	6700.00
0005433102663	164	Economy	6700.00
0005433102667	164	Economy	6700.00
0005432901756	164	Economy	6700.00
0005433102612	164	Economy	6700.00
0005432920072	164	Economy	6700.00
0005433102526	164	Economy	7300.00
0005432157524	164	Economy	7300.00
0005433102473	164	Economy	7300.00
0005432920127	164	Economy	6700.00
0005433102603	164	Economy	6700.00
0005432901725	164	Economy	6700.00
0005432901814	164	Economy	6700.00
0005433102578	164	Economy	6700.00
0005433102445	164	Economy	6700.00
0005433102362	164	Economy	6700.00
0005432901699	164	Economy	6700.00
0005432920047	164	Economy	6700.00
0005433102630	164	Economy	6700.00
0005433102472	164	Economy	6700.00
0005432901760	164	Economy	6700.00
0005433102647	164	Economy	6700.00
0005433102512	164	Economy	6700.00
0005433102648	164	Economy	6700.00
0005433102452	164	Economy	6700.00
0005432919980	164	Economy	6700.00
0005432901782	164	Economy	6700.00
0005433102513	164	Economy	6700.00
0005432157525	164	Economy	6700.00
0005432677602	164	Economy	6700.00
0005432920008	164	Economy	6700.00
0005432901776	164	Economy	6700.00
0005433102393	164	Economy	6700.00
0005433102527	164	Economy	6700.00
0005433102640	164	Economy	6700.00
0005432901771	164	Economy	6700.00
0005432901726	164	Economy	6700.00
0005433102480	164	Economy	6700.00
0005433102488	164	Economy	6700.00
0005433102656	164	Economy	6700.00
0005432920038	164	Economy	6700.00
0005433102596	164	Economy	6700.00
0005433102322	164	Economy	6700.00
0005434153551	162	Business	20000.00
0005432262658	162	Business	20000.00
0005432817946	162	Business	20000.00
0005432262641	162	Business	20000.00
0005432262667	162	Business	20000.00
0005433690943	162	Business	20000.00
0005432262643	162	Business	20000.00
0005432289042	162	Business	20000.00
0005432817955	162	Business	20000.00
0005432262637	162	Business	20000.00
0005432817945	162	Business	20000.00
0005434153550	162	Business	20000.00
0005433476957	162	Business	20000.00
0005433687706	162	Business	20000.00
0005432207702	162	Business	20000.00
0005433690944	162	Business	20000.00
0005432817940	162	Business	20000.00
0005432817968	162	Business	20000.00
0005432262662	162	Business	20000.00
0005432756879	162	Business	20000.00
0005432262635	162	Economy	7300.00
0005432817941	162	Economy	7300.00
0005432289041	162	Economy	7300.00
0005432262671	162	Economy	6700.00
0005432262666	162	Economy	6700.00
0005432289040	162	Economy	6700.00
0005432817943	162	Economy	6700.00
0005432817961	162	Economy	6700.00
0005432817960	162	Economy	6700.00
0005432817967	162	Economy	6700.00
0005432817953	162	Economy	6700.00
0005432817957	162	Economy	6700.00
0005432262654	162	Economy	6700.00
0005432817947	162	Economy	6700.00
0005432262634	162	Economy	6700.00
0005432262639	162	Economy	6700.00
0005432262672	162	Economy	6700.00
0005432262670	162	Economy	6700.00
0005432262644	162	Economy	6700.00
0005432262630	162	Economy	6700.00
0005432262665	162	Economy	6700.00
0005432817964	162	Economy	6700.00
0005432262642	162	Economy	6700.00
0005432262675	162	Economy	6700.00
0005432262660	162	Economy	6700.00
0005432817942	162	Economy	6700.00
0005432817948	162	Economy	6700.00
0005432753320	162	Economy	6700.00
0005432817965	162	Economy	6700.00
0005432262645	162	Economy	6700.00
0005432817951	162	Economy	6700.00
0005432817944	162	Economy	6700.00
0005432262640	162	Economy	6700.00
0005432262647	162	Economy	6700.00
0005432817970	162	Economy	6700.00
0005432262657	162	Economy	6700.00
0005432262659	162	Economy	6700.00
0005432817952	162	Economy	6700.00
0005432262652	162	Economy	7300.00
0005432817959	162	Economy	6700.00
0005432262633	162	Economy	6700.00
0005432262656	162	Economy	6700.00
0005432817956	162	Economy	6700.00
0005432262649	162	Economy	6700.00
0005432207701	162	Economy	6700.00
0005432262661	162	Economy	6700.00
0005432262650	162	Economy	6700.00
0005432262663	162	Economy	6700.00
0005432262631	162	Economy	6700.00
0005432262669	162	Economy	6700.00
0005432262636	162	Economy	6700.00
0005432817958	162	Economy	6700.00
0005432817963	162	Economy	6700.00
0005432262646	162	Economy	6700.00
0005432817969	162	Economy	6700.00
0005432753326	162	Economy	6700.00
0005432262655	162	Economy	6700.00
0005432753337	162	Economy	6700.00
0005432262651	162	Economy	6700.00
0005432289043	162	Economy	6700.00
0005432262653	162	Economy	6700.00
0005433690942	162	Economy	6700.00
0005432289039	162	Economy	6700.00
0005432817962	162	Economy	6700.00
0005432817966	162	Economy	6700.00
0005434153552	162	Economy	6700.00
0005433687725	162	Economy	6700.00
0005432262676	162	Economy	6700.00
0005432262664	162	Economy	6700.00
0005432262632	162	Economy	6700.00
0005432817954	162	Economy	6700.00
0005432262668	162	Economy	6700.00
0005432817950	162	Economy	6700.00
0005432262638	162	Economy	6700.00
0005432262673	162	Economy	6700.00
0005432753322	162	Economy	6700.00
0005432262648	162	Economy	6700.00
0005432817949	162	Economy	6700.00
0005434153553	162	Economy	6700.00
0005432262674	162	Economy	6700.00
0005433103013	8135	Business	20000.00
0005433103004	8135	Business	20000.00
0005433102980	8135	Business	20000.00
0005433103033	8135	Business	20000.00
0005433103020	8135	Business	20000.00
0005433103024	8135	Business	20000.00
0005433103034	8135	Business	20000.00
0005432753355	8135	Business	20000.00
0005432920192	8135	Business	20000.00
0005433102990	8135	Business	20000.00
0005432751584	8135	Business	20000.00
0005432920193	8135	Business	20000.00
0005432751583	8135	Business	20000.00
0005432751585	8135	Business	20000.00
0005432020694	8135	Business	20000.00
0005433102995	8135	Business	20000.00
0005433102993	8135	Business	20000.00
0005432020697	8135	Business	20000.00
0005432044571	8135	Business	20000.00
0005432020708	8135	Business	20000.00
0005433103011	8135	Business	20000.00
0005432920207	8135	Business	20000.00
0005432020698	8135	Business	20000.00
0005432920196	8135	Economy	7300.00
0005433102989	8135	Economy	7300.00
0005433102983	8135	Economy	7300.00
0005433102984	8135	Economy	7300.00
0005432920194	8135	Economy	6700.00
0005432020699	8135	Economy	6700.00
0005433103000	8135	Economy	6700.00
0005433102987	8135	Economy	6700.00
0005432392051	8135	Economy	6700.00
0005433102998	8135	Economy	6700.00
0005432020691	8135	Economy	6700.00
0005432920191	8135	Economy	6700.00
0005432020692	8135	Economy	6700.00
0005433103002	8135	Economy	6700.00
0005433102986	8135	Economy	6700.00
0005433103022	8135	Economy	6700.00
0005432020687	8135	Economy	6700.00
0005432920189	8135	Economy	6700.00
0005433103012	8135	Economy	6700.00
0005432920208	8135	Economy	6700.00
0005433102978	8135	Economy	6700.00
0005433103010	8135	Economy	6700.00
0005433103030	8135	Economy	6700.00
0005433102991	8135	Economy	6700.00
0005432044570	8135	Economy	6700.00
0005433103021	8135	Economy	6700.00
0005432020686	8135	Economy	6700.00
0005432920195	8135	Economy	6700.00
0005432020709	8135	Economy	6700.00
0005432020689	8135	Economy	6700.00
0005432020711	8135	Economy	6700.00
0005432020701	8135	Economy	6700.00
0005433103003	8135	Economy	6700.00
0005433102996	8135	Economy	6700.00
0005432920203	8135	Economy	6700.00
0005432751582	8135	Economy	6700.00
0005433103027	8135	Economy	6700.00
0005433103032	8135	Economy	6700.00
0005433103009	8135	Economy	6700.00
0005433103018	8135	Economy	6700.00
0005433103006	8135	Economy	6700.00
0005433102981	8135	Economy	6700.00
0005433102992	8135	Economy	6700.00
0005432751580	8135	Economy	6700.00
0005432753357	8135	Economy	6700.00
0005432020693	8135	Economy	6700.00
0005432920197	8135	Economy	7300.00
0005433102977	8135	Economy	7300.00
0005432020707	8135	Economy	7300.00
0005432392049	8135	Economy	7300.00
0005433103019	8135	Economy	6700.00
0005432753356	8135	Economy	7300.00
0005432920206	8135	Economy	6700.00
0005432020712	8135	Economy	6700.00
0005432020705	8135	Economy	7300.00
0005433103015	8135	Economy	6700.00
0005433103016	8135	Economy	6700.00
0005432920200	8135	Economy	6700.00
0005433103029	8135	Economy	6700.00
0005432920204	8135	Economy	6700.00
0005433103036	8135	Economy	6700.00
0005433103014	8135	Economy	6700.00
0005432020696	8135	Economy	6700.00
0005432020702	8135	Economy	6700.00
0005432020704	8135	Economy	6700.00
0005433103017	8135	Economy	6700.00
0005432920190	8135	Economy	6700.00
0005433102994	8135	Economy	6700.00
0005432920205	8135	Economy	6700.00
0005432920199	8135	Economy	6700.00
0005432920198	8135	Economy	6700.00
0005433103035	8135	Economy	6700.00
0005433102997	8135	Economy	6700.00
0005433103023	8135	Economy	6700.00
0005433102999	8135	Economy	6700.00
0005433102979	8135	Economy	6700.00
0005433103007	8135	Economy	6700.00
0005433103031	8135	Economy	6700.00
0005432020706	8135	Economy	6700.00
0005432020688	8135	Economy	6700.00
0005432920201	8135	Economy	6700.00
0005432020690	8135	Economy	6700.00
0005433103028	8135	Economy	6700.00
0005433103025	8135	Economy	6700.00
0005433103005	8135	Economy	6700.00
0005432020700	8135	Economy	6700.00
0005433103001	8135	Economy	6700.00
0005433102988	8135	Economy	6700.00
0005433102982	8135	Economy	6700.00
0005433102985	8135	Economy	6700.00
0005433103026	8135	Economy	6700.00
0005432920202	8135	Economy	6700.00
0005432392050	8135	Economy	6700.00
0005432020695	8135	Economy	6700.00
0005432677640	8135	Economy	6700.00
0005432045645	8135	Economy	6700.00
0005433103008	8135	Economy	6700.00
0005432020703	8135	Economy	6700.00
0005432677639	8135	Economy	6700.00
0005432020710	8135	Economy	6700.00
0005432753358	8135	Economy	6700.00
0005432677641	8135	Economy	6700.00
0005432045646	8135	Economy	6700.00
0005432751581	8135	Economy	6700.00
0005432817732	8136	Business	20000.00
0005432817769	8136	Business	20000.00
0005432817677	8136	Business	20000.00
0005432817725	8136	Business	20000.00
0005432817757	8136	Business	20000.00
0005432901903	8136	Business	20000.00
0005432817649	8136	Business	20000.00
0005432002111	8136	Business	20000.00
0005432817639	8136	Business	20000.00
0005432817638	8136	Business	20000.00
0005432901894	8136	Business	20000.00
0005432817669	8136	Business	20000.00
0005432002110	8136	Economy	7300.00
0005432817773	8136	Business	20000.00
0005432817859	8136	Economy	7300.00
0005432817733	8136	Economy	7300.00
0005432817670	8136	Economy	6700.00
0005432901897	8136	Economy	6700.00
0005432817756	8136	Economy	6700.00
0005432817809	8136	Economy	6700.00
0005432817653	8136	Economy	6700.00
0005432901898	8136	Economy	6700.00
0005432901902	8136	Economy	6700.00
0005432901901	8136	Economy	6700.00
0005432817731	8136	Economy	6700.00
0005432817655	8136	Economy	6700.00
0005432817690	8136	Economy	6700.00
0005432817650	8136	Economy	6700.00
0005432901896	8136	Economy	6700.00
0005432817693	8136	Economy	6700.00
0005432817713	8136	Economy	6700.00
0005432817761	8136	Economy	6700.00
0005432817497	8136	Economy	6700.00
0005432901904	8136	Economy	6700.00
0005432901900	8136	Economy	6700.00
0005432901892	8136	Economy	6700.00
0005432817748	8136	Economy	6700.00
0005432817774	8136	Economy	6700.00
0005432901889	8136	Economy	6700.00
0005432817654	8136	Economy	6700.00
0005432901888	8136	Economy	6700.00
0005432817739	8136	Economy	6700.00
0005432901893	8136	Economy	6700.00
0005432817577	8136	Economy	6700.00
0005432817621	8136	Economy	6700.00
0005432901895	8136	Economy	6700.00
0005432817671	8136	Economy	6700.00
0005432817711	8136	Economy	6700.00
0005432901899	8136	Economy	6700.00
0005432817712	8136	Economy	6700.00
0005432901891	8136	Economy	6700.00
0005432901890	8136	Economy	6700.00
0005432817648	8136	Economy	6700.00
0005433870766	9686	Economy	6900.00
0005434175787	9686	Economy	6900.00
0005434175786	9686	Economy	6900.00
0005434175785	9686	Economy	6900.00
0005434175782	9686	Economy	6900.00
0005434175781	9686	Economy	6900.00
0005434175791	9686	Economy	6900.00
0005434175773	9686	Economy	6900.00
0005433870767	9686	Economy	6900.00
0005433870749	32369	Economy	6900.00
0005434175823	32369	Economy	6900.00
0005434175821	32369	Economy	6900.00
0005434175822	32369	Economy	6900.00
0005435626465	3469	Business	35000.00
0005434879814	3469	Business	35000.00
0005434938466	3469	Business	35000.00
0005435127047	3469	Business	35000.00
0005435127032	3469	Business	35000.00
0005435626475	3469	Business	35000.00
0005435902842	3469	Business	35000.00
0005434879772	3469	Business	35000.00
0005434938464	3469	Business	35000.00
0005435127021	3469	Business	35000.00
0005434879766	3469	Business	35000.00
0005435902910	3469	Business	35000.00
0005435127025	3469	Business	35000.00
0005434879758	3469	Business	35000.00
0005434427094	3469	Business	35000.00
0005435626480	3469	Business	35000.00
0005434879795	3469	Business	35000.00
0005435902838	3469	Business	35000.00
0005432799928	3469	Business	35000.00
0005434879771	3469	Business	35000.00
0005434879786	3469	Comfort	19900.00
0005432799915	3469	Comfort	19900.00
0005434879747	3469	Comfort	19900.00
0005432799929	3469	Comfort	19900.00
0005434879752	3469	Comfort	19900.00
0005434427098	3469	Comfort	19900.00
0005434427102	3469	Comfort	19900.00
0005434879769	3469	Comfort	19900.00
0005434879796	3469	Comfort	19900.00
0005432799910	3469	Comfort	19900.00
0005435841099	3469	Comfort	19900.00
0005435626476	3469	Comfort	19900.00
0005434879799	3469	Comfort	19900.00
0005434427097	3469	Comfort	19900.00
0005435626479	3469	Comfort	19900.00
0005434427090	3469	Comfort	19900.00
0005435626486	3469	Comfort	19900.00
0005432799914	3469	Comfort	19900.00
0005434879810	3469	Comfort	19900.00
0005435626472	3469	Comfort	19900.00
0005435127041	3469	Comfort	19900.00
0005434879823	3469	Comfort	19900.00
0005435127029	3469	Comfort	19900.00
0005434879729	3469	Comfort	19900.00
0005434879805	3469	Comfort	19900.00
0005434879822	3469	Comfort	19900.00
0005435902843	3469	Comfort	19900.00
0005434427088	3469	Comfort	19900.00
0005435913947	3469	Comfort	19900.00
0005432613929	3469	Comfort	19900.00
0005435902846	3469	Comfort	19900.00
0005434879776	3469	Economy	11700.00
0005434879728	3469	Economy	11700.00
0005434879803	3469	Economy	11700.00
0005434879742	3469	Economy	11700.00
0005432613927	3469	Economy	11700.00
0005435127055	3469	Economy	11700.00
0005435127036	3469	Economy	11700.00
0005435626464	3469	Economy	11700.00
0005435841830	3469	Economy	11700.00
0005435127031	3469	Economy	11700.00
0005434879789	3469	Economy	11700.00
0005435902909	3469	Economy	11700.00
0005432799913	3469	Economy	11700.00
0005434427085	3469	Economy	11700.00
0005434879751	3469	Economy	11700.00
0005434427086	3469	Economy	11700.00
0005432799908	3469	Economy	11700.00
0005434938472	3469	Economy	11700.00
0005434879794	3469	Economy	11700.00
0005434938471	3469	Economy	11700.00
0005435902794	3469	Economy	11700.00
0005432799921	3469	Economy	11700.00
0005434879748	3469	Economy	11700.00
0005434879762	3469	Economy	11700.00
0005434938463	3469	Economy	11700.00
0005434879749	3469	Economy	11700.00
0005434879806	3469	Economy	11700.00
0005435127060	3469	Economy	11700.00
0005435127057	3469	Economy	11700.00
0005434427107	3469	Economy	11700.00
0005435626468	3469	Economy	11700.00
0005434938470	3469	Economy	11700.00
0005432799909	3469	Economy	11700.00
0005432799931	3469	Economy	11700.00
0005432188663	3469	Economy	11700.00
0005432799912	3469	Economy	11700.00
0005432799920	3469	Economy	11700.00
0005434879764	3469	Economy	11700.00
0005434938453	3469	Economy	11700.00
0005435902868	3469	Economy	11700.00
0005434879815	3469	Economy	11700.00
0005432799924	3469	Economy	11700.00
0005435127049	3469	Economy	11700.00
0005435127053	3469	Economy	11700.00
0005435127039	3469	Economy	11700.00
0005434879817	3469	Economy	12800.00
0005435127024	3469	Economy	12800.00
0005434879744	3469	Economy	11700.00
0005435127034	3469	Economy	11700.00
0005434879793	3469	Economy	12800.00
0005432799916	3469	Economy	12800.00
0005435626478	3469	Economy	11700.00
0005432799925	3469	Economy	11700.00
0005434938454	3469	Economy	11700.00
0005434938461	3469	Economy	11700.00
0005435127043	3469	Economy	11700.00
0005432799918	3469	Economy	11700.00
0005434879753	3469	Economy	11700.00
0005435902768	3469	Economy	11700.00
0005434427099	3469	Economy	11700.00
0005434879778	3469	Economy	11700.00
0005434879797	3469	Economy	11700.00
0005432799930	3469	Economy	11700.00
0005434879807	3469	Economy	11700.00
0005435626469	3469	Economy	11700.00
0005432799923	3469	Economy	11700.00
0005434879755	3469	Economy	11700.00
0005434879740	3469	Economy	11700.00
0005434879821	3469	Economy	11700.00
0005435127042	3469	Economy	11700.00
0005434879798	3469	Economy	11700.00
0005434879820	3469	Economy	11700.00
0005434938469	3469	Economy	11700.00
0005434879760	3469	Economy	11700.00
0005434427100	3469	Economy	11700.00
0005434879824	3469	Economy	11700.00
0005432799922	3469	Economy	11700.00
0005435127026	3469	Economy	11700.00
0005435127058	3469	Economy	11700.00
0005434879732	3469	Economy	11700.00
0005435626482	3469	Economy	11700.00
0005434879783	3469	Economy	11700.00
0005432799927	3469	Economy	11700.00
0005432799926	3469	Economy	11700.00
0005434427108	3469	Economy	11700.00
0005435626474	3469	Economy	11700.00
0005435913952	3469	Economy	11700.00
0005432611772	3469	Economy	11700.00
0005435902820	3469	Economy	11700.00
0005435127059	3469	Economy	11700.00
0005434879750	3469	Economy	11700.00
0005435626471	3469	Economy	11700.00
0005434879735	3469	Economy	11700.00
0005432799911	3469	Economy	11700.00
0005435902789	3469	Economy	11700.00
0005434879759	3469	Economy	11700.00
0005435127050	3469	Economy	11700.00
0005434879777	3469	Economy	11700.00
0005434879809	3469	Economy	11700.00
0005432799919	3469	Economy	11700.00
0005434938459	3469	Economy	11700.00
0005435626470	3469	Economy	11700.00
0005435626467	3469	Economy	11700.00
0005435127037	3469	Economy	11700.00
0005435913951	3469	Economy	11700.00
0005434879736	3469	Economy	11700.00
0005435127045	3469	Economy	11700.00
0005434879784	3469	Economy	11700.00
0005434879801	3469	Economy	11700.00
0005435127023	3469	Economy	11700.00
0005434427106	3469	Economy	11700.00
0005435626466	3469	Economy	11700.00
0005432188661	3469	Economy	11700.00
0005435127022	3469	Economy	11700.00
0005435127028	3469	Economy	11700.00
0005434879808	3469	Economy	11700.00
0005432183502	3469	Economy	11700.00
0005434879774	3469	Economy	11700.00
0005434427084	3469	Economy	11700.00
0005434427083	3469	Economy	11700.00
0005434879768	3469	Economy	11700.00
0005434879746	3469	Economy	11700.00
0005435902911	3469	Economy	11700.00
0005434427104	3469	Economy	11700.00
0005435127056	3469	Economy	11700.00
0005435626484	3469	Economy	11700.00
0005435626477	3469	Economy	11700.00
0005434427109	3469	Economy	11700.00
0005434879741	3469	Economy	11700.00
0005434879731	3469	Economy	11700.00
0005434427082	3469	Economy	11700.00
0005435902841	3469	Economy	11700.00
0005432183503	3469	Economy	11700.00
0005435127054	3469	Economy	11700.00
0005432611771	3469	Economy	11700.00
0005434879813	3469	Economy	11700.00
0005434879754	3469	Economy	11700.00
0005434427095	3469	Economy	11700.00
0005434879819	3469	Economy	11700.00
0005434879767	3469	Economy	11700.00
0005434879745	3469	Economy	11700.00
0005434879825	3469	Economy	11700.00
0005434879743	3469	Economy	11700.00
0005432188662	3469	Economy	11700.00
0005435127044	3469	Economy	11700.00
0005434938460	3469	Economy	11700.00
0005434879790	3469	Economy	12800.00
0005434879781	3469	Economy	12800.00
0005435127046	3469	Economy	12800.00
0005435626483	3469	Economy	12800.00
0005434427096	3469	Economy	11700.00
0005434879816	3469	Economy	11700.00
0005435902908	3469	Economy	11700.00
0005432799934	3469	Economy	11700.00
0005434938462	3469	Economy	11700.00
0005434879773	3469	Economy	11700.00
0005434879763	3469	Economy	11700.00
0005435902880	3469	Economy	11700.00
0005434427103	3469	Economy	11700.00
0005434879780	3469	Economy	11700.00
0005434879804	3469	Economy	11700.00
0005434427101	3469	Economy	11700.00
0005434938455	3469	Economy	11700.00
0005434879792	3469	Economy	11700.00
0005435626481	3469	Economy	11700.00
0005435127062	3469	Economy	11700.00
0005435127040	3469	Economy	11700.00
0005432613928	3469	Economy	11700.00
0005434879802	3469	Economy	11700.00
0005434879788	3469	Economy	11700.00
0005434879812	3469	Economy	11700.00
0005434879734	3469	Economy	11700.00
0005434938458	3469	Economy	11700.00
0005434427092	3469	Economy	11700.00
0005434879791	3469	Economy	11700.00
0005432799933	3469	Economy	11700.00
0005434879787	3469	Economy	11700.00
0005434427105	3469	Economy	11700.00
0005435841826	3469	Economy	11700.00
0005435902845	3469	Economy	11700.00
0005432613930	3469	Economy	11700.00
0005434427081	3469	Economy	11700.00
0005432799932	3469	Economy	11700.00
0005435127061	3469	Economy	11700.00
0005435626485	3469	Economy	11700.00
0005434427093	3469	Economy	11700.00
0005432799936	3469	Economy	11700.00
0005435913948	3469	Economy	11700.00
0005434879775	3469	Economy	11700.00
0005434938456	3469	Economy	11700.00
0005434879761	3469	Economy	11700.00
0005432799917	3469	Economy	11700.00
0005434427087	3469	Economy	11700.00
0005434879757	3469	Economy	11700.00
0005435902769	3469	Economy	11700.00
0005434879739	3469	Economy	11700.00
0005435902801	3469	Economy	11700.00
0005434938467	3469	Economy	11700.00
0005434938465	3469	Economy	11700.00
0005434879770	3469	Economy	11700.00
0005435127030	3469	Economy	11700.00
0005434879785	3469	Economy	11700.00
0005434879765	3469	Economy	11700.00
0005435902869	3469	Economy	11700.00
0005435127052	3469	Economy	11700.00
0005435127051	3469	Economy	11700.00
0005434879756	3469	Economy	11700.00
0005434427089	3469	Economy	11700.00
0005434879738	3469	Economy	11700.00
0005434879800	3469	Economy	11700.00
0005435127033	3469	Economy	11700.00
0005434879733	3469	Economy	11700.00
0005432799935	3469	Economy	11700.00
0005435626473	3469	Economy	11700.00
0005432611770	3469	Economy	11700.00
0005434879779	3469	Economy	11700.00
0005435127027	3469	Economy	11700.00
0005435127035	3469	Economy	11700.00
0005434427091	3469	Economy	11700.00
0005434879811	3469	Economy	11700.00
0005434879818	3469	Economy	11700.00
0005434938468	3469	Economy	11700.00
0005434938457	3469	Economy	11700.00
0005435127038	3469	Economy	11700.00
0005434879737	3469	Economy	11700.00
0005435902881	3469	Economy	11700.00
0005434879782	3469	Economy	11700.00
0005434879730	3469	Economy	11700.00
0005435127048	3469	Economy	11700.00
0005434938290	14554	Business	35000.00
0005434878483	14554	Business	35000.00
0005434878825	14554	Business	35000.00
0005432059537	14554	Business	35000.00
0005434938332	14554	Business	35000.00
0005434426751	14554	Business	35000.00
0005435126746	14554	Business	35000.00
0005434878917	14554	Business	35000.00
0005434426814	14554	Business	35000.00
0005432799614	14554	Business	35000.00
0005434426907	14554	Business	35000.00
0005434878814	14554	Business	35000.00
0005435902991	14554	Business	35000.00
0005434879025	14554	Business	35000.00
0005435126660	14554	Business	35000.00
0005434938313	14554	Business	35000.00
0005434426891	14554	Business	35000.00
0005434879186	14554	Business	35000.00
0005432607584	14554	Business	35000.00
0005434426837	14554	Business	35000.00
0005435126686	14554	Business	35000.00
0005434938354	14554	Business	35000.00
0005435126644	14554	Business	35000.00
0005435126588	14554	Comfort	19900.00
0005432607578	14554	Comfort	19900.00
0005434878662	14554	Comfort	19900.00
0005434879170	14554	Comfort	19900.00
0005432799739	14554	Comfort	19900.00
0005434879067	14554	Comfort	19900.00
0005434879353	14554	Comfort	19900.00
0005435913989	14554	Comfort	19900.00
0005435126839	14554	Comfort	19900.00
0005434879020	14554	Comfort	19900.00
0005434938382	14554	Comfort	19900.00
0005434879162	14554	Comfort	19900.00
0005434426782	14554	Comfort	19900.00
0005435126518	14554	Comfort	19900.00
0005434426795	14554	Comfort	19900.00
0005434878493	14554	Comfort	19900.00
0005435902999	14554	Comfort	19900.00
0005434878320	14554	Comfort	19900.00
0005435126804	14554	Comfort	19900.00
0005434938380	14554	Comfort	19900.00
0005434426834	14554	Comfort	19900.00
0005435126707	14554	Comfort	19900.00
0005434878663	14554	Comfort	19900.00
0005434879333	14554	Comfort	19900.00
0005435126619	14554	Comfort	19900.00
0005434879018	14554	Comfort	19900.00
0005434426892	14554	Comfort	19900.00
0005434878984	14554	Comfort	19900.00
0005434878988	14554	Comfort	19900.00
0005434879160	14554	Economy	11700.00
0005434426840	14554	Economy	11700.00
0005434938366	14554	Economy	11700.00
0005434938324	14554	Economy	11700.00
0005435913981	14554	Economy	11700.00
0005434426702	14554	Economy	11700.00
0005434878700	14554	Economy	11700.00
0005434938207	14554	Economy	11700.00
0005432799657	14554	Economy	11700.00
0005434878704	14554	Economy	11700.00
0005435902994	14554	Economy	11700.00
0005435902988	14554	Economy	11700.00
0005434879227	14554	Economy	11700.00
0005434878923	14554	Economy	11700.00
0005432799723	14554	Economy	11700.00
0005435126550	14554	Economy	11700.00
0005434879002	14554	Economy	11700.00
0005432799666	14554	Economy	11700.00
0005434879169	14554	Economy	11700.00
0005435902989	14554	Economy	11700.00
0005435842340	14554	Economy	11700.00
0005434878840	14554	Economy	11700.00
0005435913984	14554	Economy	11700.00
0005435626260	14554	Economy	11700.00
0005435913986	14554	Economy	11700.00
0005435902987	14554	Economy	11700.00
0005434426813	14554	Economy	11700.00
0005434878918	14554	Economy	11700.00
0005434878957	14554	Economy	11700.00
0005434879084	14554	Economy	11700.00
0005432799818	14554	Economy	11700.00
0005435126650	14554	Economy	11700.00
0005434878924	14554	Economy	11700.00
0005434426951	14554	Economy	11700.00
0005434878699	14554	Economy	11700.00
0005435626230	14554	Economy	11700.00
0005435626225	14554	Economy	11700.00
0005435902985	14554	Economy	11700.00
0005435126671	14554	Economy	11700.00
0005434879096	14554	Economy	11700.00
0005434426980	14554	Economy	11700.00
0005434878679	14554	Economy	11700.00
0005434878826	14554	Economy	11700.00
0005432799697	14554	Economy	11700.00
0005432799537	14554	Economy	11700.00
0005434426752	14554	Economy	11700.00
0005435126592	14554	Economy	12800.00
0005434878786	14554	Economy	11700.00
0005434878956	14554	Economy	12800.00
0005435126768	14554	Economy	11700.00
0005435902992	14554	Economy	11700.00
0005435902996	14554	Economy	12800.00
0005435902990	14554	Economy	12800.00
0005435126676	14554	Economy	11700.00
0005435913983	14554	Economy	11700.00
0005434879041	14554	Economy	11700.00
0005435903001	14554	Economy	11700.00
0005432799667	14554	Economy	11700.00
0005434878680	14554	Economy	11700.00
0005434879311	14554	Economy	11700.00
0005435126563	14554	Economy	11700.00
0005432799615	14554	Economy	11700.00
0005434938240	14554	Economy	11700.00
0005434878828	14554	Economy	11700.00
0005435126736	14554	Economy	11700.00
0005435913988	14554	Economy	11700.00
0005435126698	14554	Economy	11700.00
0005435913982	14554	Economy	11700.00
0005434426824	14554	Economy	11700.00
0005435902995	14554	Economy	11700.00
0005435126679	14554	Economy	11700.00
0005435842341	14554	Economy	11700.00
0005435126745	14554	Economy	11700.00
0005435126513	14554	Economy	11700.00
0005435126659	14554	Economy	11700.00
0005434879052	14554	Economy	11700.00
0005435126706	14554	Economy	11700.00
0005434878770	14554	Economy	11700.00
0005435126696	14554	Economy	11700.00
0005435126593	14554	Economy	11700.00
0005434878342	14554	Economy	11700.00
0005435913993	14554	Economy	11700.00
0005435126603	14554	Economy	11700.00
0005434878734	14554	Economy	11700.00
0005435126767	14554	Economy	11700.00
0005435842339	14554	Economy	11700.00
0005435126516	14554	Economy	11700.00
0005434426703	14554	Economy	11700.00
0005434938311	14554	Economy	11700.00
0005435126628	14554	Economy	11700.00
0005434878621	14554	Economy	11700.00
0005435126652	14554	Economy	11700.00
0005435126604	14554	Economy	11700.00
0005434878940	14554	Economy	11700.00
0005435626194	14554	Economy	11700.00
0005435903002	14554	Economy	11700.00
0005435913991	14554	Economy	11700.00
0005434879112	14554	Economy	11700.00
0005432059536	14554	Economy	11700.00
0005435126751	14554	Economy	11700.00
0005435126703	14554	Economy	11700.00
0005434878765	14554	Economy	11700.00
0005434878685	14554	Economy	11700.00
0005435126668	14554	Economy	11700.00
0005434879184	14554	Economy	11700.00
0005435126669	14554	Economy	11700.00
0005435126661	14554	Economy	11700.00
0005435126586	14554	Economy	11700.00
0005435126663	14554	Economy	11700.00
0005434879183	14554	Economy	11700.00
0005434878767	14554	Economy	11700.00
0005432611748	14554	Economy	11700.00
0005435126579	14554	Economy	11700.00
0005435126626	14554	Economy	11700.00
0005434878908	14554	Economy	11700.00
0005434878983	14554	Economy	11700.00
0005435126602	14554	Economy	11700.00
0005434878914	14554	Economy	11700.00
0005434938178	14554	Economy	11700.00
0005435913987	14554	Economy	11700.00
0005432059539	14554	Economy	11700.00
0005435126600	14554	Economy	11700.00
0005435902986	14554	Economy	11700.00
0005435126662	14554	Economy	11700.00
0005435126595	14554	Economy	11700.00
0005435913985	14554	Economy	11700.00
0005435126687	14554	Economy	11700.00
0005435903003	14554	Economy	11700.00
0005435126695	14554	Economy	11700.00
0005432611747	14554	Economy	11700.00
0005435913995	14554	Economy	11700.00
0005435126543	14554	Economy	11700.00
0005435126769	14554	Economy	11700.00
0005434426796	14554	Economy	11700.00
0005434878972	14554	Economy	11700.00
0005435126685	14554	Economy	11700.00
0005432799672	14554	Economy	11700.00
0005434938312	14554	Economy	12800.00
0005434878900	14554	Economy	12800.00
0005434879247	14554	Economy	12800.00
0005434938328	14554	Economy	12800.00
0005435126643	14554	Economy	11700.00
0005432799638	14554	Economy	11700.00
0005432799656	14554	Economy	11700.00
0005435126675	14554	Economy	11700.00
0005435126680	14554	Economy	11700.00
0005435126674	14554	Economy	11700.00
0005434878867	14554	Economy	11700.00
0005434879017	14554	Economy	11700.00
0005435626215	14554	Economy	11700.00
0005434426783	14554	Economy	11700.00
0005432059538	14554	Economy	11700.00
0005435913992	14554	Economy	11700.00
0005435841835	14554	Economy	11700.00
0005434426797	14554	Economy	11700.00
0005434938381	14554	Economy	11700.00
0005435903000	14554	Economy	11700.00
0005435126667	14554	Economy	11700.00
0005435126596	14554	Economy	11700.00
0005435126611	14554	Economy	11700.00
0005434878932	14554	Economy	11700.00
0005434878808	14554	Economy	11700.00
0005434878494	14554	Economy	11700.00
0005434426906	14554	Economy	11700.00
0005434938323	14554	Economy	11700.00
0005434938283	14554	Economy	11700.00
0005434878703	14554	Economy	11700.00
0005434426835	14554	Economy	11700.00
0005434878987	14554	Economy	11700.00
0005435902993	14554	Economy	11700.00
0005434879187	14554	Economy	11700.00
0005435126601	14554	Economy	11700.00
0005432611746	14554	Economy	11700.00
0005432799716	14554	Economy	11700.00
0005434878612	14554	Economy	11700.00
0005435626195	14554	Economy	11700.00
0005432799613	14554	Economy	11700.00
0005434879123	14554	Economy	11700.00
0005434878319	14554	Economy	11700.00
0005435126713	14554	Economy	11700.00
0005435913990	14554	Economy	11700.00
0005434938383	14554	Economy	11700.00
0005434878985	14554	Economy	11700.00
0005435626235	14554	Economy	11700.00
0005435126597	14554	Economy	11700.00
0005432607585	14554	Economy	11700.00
0005435902997	14554	Economy	11700.00
0005434878453	14554	Economy	11700.00
0005435626245	14554	Economy	11700.00
0005434878705	14554	Economy	11700.00
0005432799681	14554	Economy	11700.00
0005434879246	14554	Economy	11700.00
0005434938208	14554	Economy	11700.00
0005432799665	14554	Economy	11700.00
0005434878915	14554	Economy	11700.00
0005432799715	14554	Economy	11700.00
0005435626271	14554	Economy	11700.00
0005435902998	14554	Economy	11700.00
0005434878793	14554	Economy	11700.00
0005432607583	14554	Economy	11700.00
0005435126587	14554	Economy	11700.00
0005435126763	14554	Economy	11700.00
0005434426805	14554	Economy	11700.00
0005434426887	14554	Economy	11700.00
0005435126778	14554	Economy	11700.00
0005434879068	14554	Economy	11700.00
0005434878769	14554	Economy	11700.00
0005435126629	14554	Economy	11700.00
0005435913994	14554	Economy	11700.00
0005434879111	14554	Economy	11700.00
0005432799637	14554	Economy	11700.00
0005435841836	14554	Economy	11700.00
0005434879069	14554	Economy	11700.00
0005434879130	14554	Economy	11700.00
0005434879124	14554	Economy	11700.00
0005434426890	14554	Economy	11700.00
0005434878916	14554	Economy	11700.00
0005432799817	14554	Economy	11700.00
0005434325839	3640	Economy	16300.00
0005434325841	3640	Economy	16300.00
0005434312353	3640	Economy	14800.00
0005434325835	3640	Economy	14800.00
0005434325834	3640	Economy	14800.00
0005435889951	3640	Economy	14800.00
0005434325844	3640	Economy	14800.00
0005434325845	3640	Economy	14800.00
0005434325843	3640	Economy	14800.00
0005434325842	3640	Economy	14800.00
0005435889933	3640	Economy	14800.00
0005434325836	3640	Economy	14800.00
0005434325837	3640	Economy	14800.00
0005434325838	3640	Economy	14800.00
0005435889934	3640	Economy	14800.00
0005434312352	3640	Economy	14800.00
0005435889952	3640	Economy	14800.00
0005435889973	3640	Economy	14800.00
0005434325840	3640	Economy	14800.00
0005435889998	15626	Economy	14800.00
0005434325763	15626	Economy	14800.00
0005434325780	15626	Economy	14800.00
0005435889997	15626	Economy	14800.00
0005435889995	15626	Economy	14800.00
0005435889996	15626	Economy	14800.00
0005434325744	15626	Economy	14800.00
0005435889994	15626	Economy	14800.00
0005433420483	614	Economy	4500.00
0005435957945	614	Economy	4500.00
0005435957937	614	Economy	4100.00
0005435957944	614	Economy	4100.00
0005435957943	614	Economy	4100.00
0005435957946	614	Economy	4100.00
0005433420482	614	Economy	4100.00
0005433420451	614	Economy	4100.00
0005435957947	614	Economy	4100.00
0005433420445	614	Economy	4100.00
0005435957940	614	Economy	4100.00
0005435957941	614	Economy	4100.00
0005435957948	614	Economy	4100.00
0005433420444	614	Economy	4100.00
0005435957951	614	Economy	4100.00
0005433420449	614	Economy	4100.00
0005435957938	614	Economy	4100.00
0005433420450	614	Economy	4100.00
0005435957942	614	Economy	4100.00
0005435957950	614	Economy	4100.00
0005435957939	614	Economy	4100.00
0005435957949	614	Economy	4100.00
0005435957811	15171	Economy	4500.00
0005435957775	15171	Economy	4500.00
0005433420539	15171	Economy	4500.00
0005435957835	15171	Economy	4100.00
0005435957808	15171	Economy	4100.00
0005435957761	15171	Economy	4100.00
0005433420541	15171	Economy	4100.00
0005435957800	15171	Economy	4100.00
0005435957842	15171	Economy	4100.00
0005435957882	15171	Economy	4100.00
0005433420545	15171	Economy	4100.00
0005435957855	15171	Economy	4100.00
0005435957810	15171	Economy	4100.00
0005433420540	15171	Economy	4100.00
0005435957881	15171	Economy	4100.00
0005433420543	15171	Economy	4100.00
0005433420546	15171	Economy	4100.00
0005435957781	15171	Economy	4100.00
0005435957879	15171	Economy	4100.00
0005435957880	15171	Economy	4100.00
0005435957851	15171	Economy	4100.00
0005433420538	15171	Economy	4100.00
0005433420542	15171	Economy	4100.00
0005435957834	15171	Economy	4100.00
0005433420544	15171	Economy	4100.00
0005435957852	15171	Economy	4100.00
0005435629424	8839	Economy	10400.00
0005435629423	8839	Economy	10400.00
0005434247161	8839	Economy	10400.00
0005434247172	8839	Economy	10400.00
0005434247190	16043	Economy	10400.00
0005434247189	16043	Economy	10400.00
0005435933509	29508	Economy	13400.00
0005435163278	29508	Economy	12200.00
0005435163287	29508	Economy	12200.00
0005435163258	29508	Economy	12200.00
0005435933504	29508	Economy	12200.00
0005435933513	29508	Economy	12200.00
0005435163246	29508	Economy	12200.00
0005435163277	29508	Economy	12200.00
0005435933503	29508	Economy	12200.00
0005435933505	29508	Economy	12200.00
0005435933512	29508	Economy	12200.00
0005435163295	29508	Economy	12200.00
0005435163263	29508	Economy	12200.00
0005435163249	29508	Economy	12200.00
0005435163275	29508	Economy	12200.00
0005435933506	29508	Economy	12200.00
0005435163257	29508	Economy	12200.00
0005435933510	29508	Economy	12200.00
0005435933507	29508	Economy	12200.00
0005435163259	29508	Economy	12200.00
0005435163254	29508	Economy	12200.00
0005435933508	29508	Economy	12200.00
0005435163276	29508	Economy	12200.00
0005435163268	29508	Economy	12200.00
0005435933511	29508	Economy	12200.00
0005435797713	2873	Business	12600.00
0005435797700	2873	Business	12600.00
0005433404876	2873	Business	12600.00
0005435797711	2873	Business	12600.00
0005433404877	2873	Business	12600.00
0005435797708	2873	Economy	4600.00
0005433404840	2873	Economy	4600.00
0005433404870	2873	Economy	4200.00
0005435797703	2873	Economy	4200.00
0005433404896	2873	Economy	4200.00
0005435797710	2873	Economy	4200.00
0005435797706	2873	Economy	4200.00
0005433404882	2873	Economy	4200.00
0005435797707	2873	Economy	4200.00
0005435797705	2873	Economy	4200.00
0005433404836	2873	Economy	4200.00
0005435797709	2873	Economy	4200.00
0005433404837	2873	Economy	4200.00
0005433404865	2873	Economy	4200.00
0005435797702	2873	Economy	4200.00
0005433404854	2873	Economy	4200.00
0005435797701	2873	Economy	4200.00
0005435797704	2873	Economy	4200.00
0005435797712	2873	Economy	4200.00
0005433404934	29352	Business	12600.00
0005435797607	29352	Economy	4200.00
0005433404930	29352	Economy	4200.00
0005433404935	29352	Economy	4600.00
0005435797648	29352	Economy	4200.00
0005435797601	29352	Economy	4200.00
0005435797582	29352	Economy	4200.00
0005433404936	29352	Economy	4200.00
0005435797541	29352	Economy	4200.00
0005435797642	29352	Economy	4200.00
0005435797604	29352	Economy	4200.00
0005435797558	29352	Economy	4200.00
0005435797587	29352	Economy	4200.00
0005433404931	29352	Economy	4200.00
0005433404932	29352	Economy	4200.00
0005433404929	29352	Economy	4200.00
0005433404933	29352	Economy	4200.00
0005435376387	5835	Economy	6800.00
0005435376386	5835	Economy	6800.00
0005434948152	5845	Economy	6800.00
0005434948157	5845	Economy	6800.00
0005434948156	5845	Economy	6800.00
0005434948150	5845	Economy	6800.00
0005434948154	5845	Economy	6800.00
0005434948159	5845	Economy	6800.00
0005434948151	5845	Economy	6800.00
0005434948160	5845	Economy	6800.00
0005434948158	5845	Economy	6800.00
0005434948153	5845	Economy	6800.00
0005434948155	5845	Economy	6800.00
0005434948089	16364	Economy	6800.00
0005434948088	16364	Economy	6800.00
0005434948081	16364	Economy	6800.00
0005434948093	16364	Economy	6800.00
0005434948117	16364	Economy	6800.00
0005434948116	16364	Economy	6800.00
0005434948090	16364	Economy	6800.00
0005434948132	16364	Economy	6800.00
0005434948072	16364	Economy	6800.00
0005434948092	16364	Economy	6800.00
0005434948131	16364	Economy	6800.00
0005434948087	16364	Economy	6800.00
0005433961785	6917	Business	21400.00
0005433961835	6917	Business	21400.00
0005433961779	6917	Business	21400.00
0005433961819	6917	Business	21400.00
0005433961839	6917	Business	21400.00
0005433961781	6917	Business	21400.00
0005433961852	6917	Business	21400.00
0005433961809	6917	Business	21400.00
0005433961838	6917	Business	21400.00
0005433961840	6917	Economy	7100.00
0005433961795	6917	Economy	7100.00
0005433961842	6917	Economy	7100.00
0005433961806	6917	Economy	7100.00
0005433961833	6917	Economy	7100.00
0005433961847	6917	Economy	7100.00
0005433961820	6917	Economy	7100.00
0005433961815	6917	Economy	7100.00
0005433961805	6917	Economy	7100.00
0005433961782	6917	Economy	7800.00
0005433961827	6917	Economy	7800.00
0005433961825	6917	Economy	7800.00
0005433961784	6917	Economy	7800.00
0005433961816	6917	Economy	7100.00
0005433961814	6917	Economy	7100.00
0005433961837	6917	Economy	7100.00
0005433961783	6917	Economy	7100.00
0005433961780	6917	Economy	7100.00
0005433961796	6917	Economy	7100.00
0005433961828	6917	Economy	7100.00
0005433961787	6917	Economy	7100.00
0005433961834	6917	Economy	7100.00
0005433961832	6917	Economy	7100.00
0005433961790	6917	Economy	7100.00
0005433961797	6917	Economy	7100.00
0005433961822	6917	Economy	7100.00
0005433961807	6917	Economy	7100.00
0005433961808	6917	Economy	7100.00
0005433961812	6917	Economy	7100.00
0005433961831	6917	Economy	7100.00
0005433961802	6917	Economy	7100.00
0005433961786	6917	Economy	7100.00
0005433961850	6917	Economy	7100.00
0005433961841	6917	Economy	7100.00
0005433961849	6917	Economy	7100.00
0005433961794	6917	Economy	7100.00
0005433961813	6917	Economy	7100.00
0005433961788	6917	Economy	7100.00
0005433961821	6917	Economy	7100.00
0005433961800	6917	Economy	7100.00
0005433961844	6917	Economy	7100.00
0005433961818	6917	Economy	7100.00
0005433961792	6917	Economy	7100.00
0005433961843	6917	Economy	7100.00
0005433961791	6917	Economy	7100.00
0005433961793	6917	Economy	7100.00
0005433961836	6917	Economy	7100.00
0005433961823	6917	Economy	7100.00
0005433961811	6917	Economy	7100.00
0005433961830	6917	Economy	7100.00
0005433961810	6917	Economy	7100.00
0005433961824	6917	Economy	7100.00
0005433961778	6917	Economy	7100.00
0005433961851	6917	Economy	7100.00
0005433961826	6917	Economy	7100.00
0005433961789	6917	Economy	7100.00
0005433961817	6917	Economy	7100.00
0005433961801	6917	Economy	7100.00
0005433961798	6917	Economy	7100.00
0005433961799	6917	Economy	7100.00
0005433961829	6917	Economy	7100.00
0005433961846	6917	Economy	7100.00
0005433961803	6917	Economy	7100.00
0005433961845	6917	Economy	7100.00
0005433961804	6917	Economy	7100.00
0005433961848	6917	Economy	7100.00
0005433961080	25740	Business	21400.00
0005433961119	25740	Business	21400.00
0005433961122	25740	Business	21400.00
0005433961068	25740	Business	21400.00
0005433961120	25740	Business	21400.00
0005433961206	25740	Business	21400.00
0005433961158	25740	Business	21400.00
0005433961150	25740	Business	21400.00
0005433960937	25740	Business	21400.00
0005433961203	25740	Business	21400.00
0005433961019	25740	Economy	7100.00
0005433961219	25740	Economy	7100.00
0005433961180	25740	Economy	7100.00
0005433961175	25740	Economy	7100.00
0005433961221	25740	Economy	7800.00
0005433960938	25740	Economy	7800.00
0005433961243	25740	Economy	7800.00
0005433961073	25740	Economy	7100.00
0005433961123	25740	Economy	7100.00
0005433961079	25740	Economy	7100.00
0005433961255	25740	Economy	7100.00
0005433961033	25740	Economy	7100.00
0005433961039	25740	Economy	7100.00
0005433961040	25740	Economy	7100.00
0005433961002	25740	Economy	7100.00
0005433961253	25740	Economy	7100.00
0005433961104	25740	Economy	7100.00
0005433961043	25740	Economy	7100.00
0005433961103	25740	Economy	7100.00
0005433961078	25740	Economy	7100.00
0005433961042	25740	Economy	7100.00
0005433960974	25740	Economy	7100.00
0005433961063	25740	Economy	7100.00
0005433961093	25740	Economy	7100.00
0005433961099	25740	Economy	7100.00
0005433961149	25740	Economy	7100.00
0005433961065	25740	Economy	7100.00
0005433961121	25740	Economy	7100.00
0005433961044	25740	Economy	7100.00
0005433961160	25740	Economy	7100.00
0005433961246	25740	Economy	7100.00
0005433961200	25740	Economy	7100.00
0005433961220	25740	Economy	7100.00
0005433961105	25740	Economy	7100.00
0005433961062	25740	Economy	7100.00
0005433961208	25740	Economy	7100.00
0005433961041	25740	Economy	7100.00
0005433961170	25740	Economy	7100.00
0005433961199	25740	Economy	7100.00
0005433961262	25740	Economy	7100.00
0005433960972	25740	Economy	7100.00
0005433961261	25740	Economy	7100.00
0005433961252	25740	Economy	7100.00
0005433960971	25740	Economy	7100.00
0005433961094	25740	Economy	7100.00
0005433961159	25740	Economy	7100.00
0005433961018	25740	Economy	7100.00
0005433961241	25740	Economy	7100.00
0005433961069	25740	Economy	7100.00
0005433961207	25740	Economy	7100.00
0005433961186	25740	Economy	7100.00
0005435082835	24450	Economy	3900.00
0005435082834	24450	Economy	3900.00
0005435082848	24450	Economy	3900.00
0005435082841	24450	Economy	3900.00
0005435082842	24450	Economy	3900.00
0005435082847	24450	Economy	3900.00
0005435082831	24450	Economy	3900.00
0005435082845	24450	Economy	3900.00
0005435082908	26060	Economy	3900.00
0005435082909	26060	Economy	3900.00
0005435082907	26060	Economy	3900.00
0005435082913	26060	Economy	3900.00
0005435082910	26060	Economy	3900.00
0005435082911	26060	Economy	3900.00
0005435082915	26060	Economy	3900.00
0005435082914	26060	Economy	3900.00
0005435082912	26060	Economy	3900.00
0005432166954	5085	Business	18000.00
0005434245454	5085	Business	18000.00
0005434245472	5085	Business	18000.00
0005434245456	5085	Economy	6600.00
0005434245473	5085	Economy	6000.00
0005433534508	5085	Economy	6000.00
0005434245449	5085	Economy	6000.00
0005434245471	5085	Economy	6000.00
0005433534510	5085	Economy	6000.00
0005434245477	5085	Economy	6000.00
0005434245475	5085	Economy	6000.00
0005433534516	5085	Economy	6000.00
0005434245468	5085	Economy	6000.00
0005434245476	5085	Economy	6000.00
0005434245465	5085	Economy	6000.00
0005434245462	5085	Economy	6000.00
0005434245460	5085	Economy	6000.00
0005434245451	5085	Economy	6000.00
0005433534517	5085	Economy	6000.00
0005434245448	5085	Economy	6000.00
0005432166955	5085	Economy	6000.00
0005432166956	5085	Economy	6000.00
0005434245455	5085	Economy	6000.00
0005433534515	5085	Economy	6000.00
0005434245457	5085	Economy	6600.00
0005434245458	5085	Economy	6600.00
0005434245461	5085	Economy	6000.00
0005434245474	5085	Economy	6600.00
0005435286665	5085	Economy	6000.00
0005434245450	5085	Economy	6000.00
0005434245453	5085	Economy	6000.00
0005432166957	5085	Economy	6000.00
0005434245467	5085	Economy	6000.00
0005434245459	5085	Economy	6000.00
0005434245452	5085	Economy	6000.00
0005434245466	5085	Economy	6000.00
0005432166953	5085	Economy	6000.00
0005435286666	5085	Economy	6000.00
0005434245469	5085	Economy	6000.00
0005434245463	5085	Economy	6000.00
0005434245470	5085	Economy	6000.00
0005434245464	5085	Economy	6000.00
0005433785555	5084	Business	18000.00
0005433785548	5084	Business	18000.00
0005433615860	5084	Business	18000.00
0005433785546	5084	Business	18000.00
0005433615918	5084	Business	18000.00
0005433615922	5084	Business	18000.00
0005433615916	5084	Business	18000.00
0005433615914	5084	Business	18000.00
0005433615869	5084	Business	18000.00
0005433785537	5084	Business	18000.00
0005433615884	5084	Business	18000.00
0005432106337	5084	Business	18000.00
0005432106334	5084	Business	18000.00
0005432106345	5084	Business	18000.00
0005432106368	5084	Business	18000.00
0005433615863	5084	Business	18000.00
0005433615873	5084	Business	18000.00
0005433785543	5084	Business	18000.00
0005432106358	5084	Business	18000.00
0005433785533	5084	Business	18000.00
0005433785528	5084	Business	18000.00
0005433615928	5084	Business	18000.00
0005432145146	5084	Business	18000.00
0005432106374	5084	Business	18000.00
0005433615894	5084	Business	18000.00
0005433785549	5084	Business	18000.00
0005433785541	5084	Business	18000.00
0005432106338	5084	Business	18000.00
0005433615875	5084	Economy	6600.00
0005433615861	5084	Economy	6600.00
0005433615891	5084	Economy	6600.00
0005432106375	5084	Economy	6600.00
0005432106329	5084	Economy	6600.00
0005432106336	5084	Economy	6600.00
0005433785525	5084	Economy	6000.00
0005433615906	5084	Economy	6000.00
0005432106363	5084	Economy	6000.00
0005433785523	5084	Economy	6000.00
0005432106340	5084	Economy	6000.00
0005433615888	5084	Economy	6000.00
0005433785542	5084	Economy	6000.00
0005432106372	5084	Economy	6000.00
0005432667488	5084	Economy	6000.00
0005433615887	5084	Economy	6000.00
0005433615898	5084	Economy	6000.00
0005433615862	5084	Economy	6000.00
0005432106352	5084	Economy	6000.00
0005433615929	5084	Economy	6000.00
0005432106367	5084	Economy	6000.00
0005433615903	5084	Economy	6000.00
0005432106371	5084	Economy	6000.00
0005433615909	5084	Economy	6000.00
0005432106346	5084	Economy	6000.00
0005433615870	5084	Economy	6000.00
0005433615879	5084	Economy	6000.00
0005433615890	5084	Economy	6000.00
0005433785534	5084	Economy	6000.00
0005432106339	5084	Economy	6000.00
0005432665310	5084	Economy	6000.00
0005433615878	5084	Economy	6000.00
0005433785527	5084	Economy	6000.00
0005433615886	5084	Economy	6000.00
0005433615892	5084	Economy	6000.00
0005433785551	5084	Economy	6000.00
0005432106327	5084	Economy	6000.00
0005433615924	5084	Economy	6000.00
0005432106376	5084	Economy	6000.00
0005433615905	5084	Economy	6000.00
0005433615912	5084	Economy	6000.00
0005433615921	5084	Economy	6000.00
0005432665309	5084	Economy	6000.00
0005432106354	5084	Economy	6000.00
0005432106349	5084	Economy	6000.00
0005433615857	5084	Economy	6000.00
0005433785532	5084	Economy	6000.00
0005433615889	5084	Economy	6000.00
0005433615919	5084	Economy	6000.00
0005433785536	5084	Economy	6000.00
0005433615871	5084	Economy	6000.00
0005433615927	5084	Economy	6000.00
0005433615866	5084	Economy	6000.00
0005432106350	5084	Economy	6000.00
0005433615867	5084	Economy	6000.00
0005433615882	5084	Economy	6000.00
0005433785539	5084	Economy	6000.00
0005432106364	5084	Economy	6000.00
0005432106328	5084	Economy	6000.00
0005433785538	5084	Economy	6000.00
0005433615876	5084	Economy	6000.00
0005432106332	5084	Economy	6000.00
0005432106347	5084	Economy	6000.00
0005433615900	5084	Economy	6000.00
0005433785553	5084	Economy	6000.00
0005433785547	5084	Economy	6000.00
0005433615926	5084	Economy	6600.00
0005433615913	5084	Economy	6600.00
0005433785529	5084	Economy	6600.00
0005433615896	5084	Economy	6600.00
0005432106365	5084	Economy	6600.00
0005433785530	5084	Economy	6000.00
0005433615883	5084	Economy	6000.00
0005432106343	5084	Economy	6000.00
0005432106344	5084	Economy	6000.00
0005433615881	5084	Economy	6600.00
0005433615893	5084	Economy	6000.00
0005433785524	5084	Economy	6000.00
0005432106330	5084	Economy	6000.00
0005432106342	5084	Economy	6000.00
0005432665308	5084	Economy	6000.00
0005432106373	5084	Economy	6000.00
0005433785556	5084	Economy	6000.00
0005433615868	5084	Economy	6000.00
0005433615920	5084	Economy	6000.00
0005432106360	5084	Economy	6000.00
0005433785545	5084	Economy	6000.00
0005433615865	5084	Economy	6000.00
0005433615872	5084	Economy	6000.00
0005433615874	5084	Economy	6000.00
0005432106353	5084	Economy	6000.00
0005432106356	5084	Economy	6000.00
0005432106369	5084	Economy	6000.00
0005432106361	5084	Economy	6000.00
0005432106359	5084	Economy	6000.00
0005433615925	5084	Economy	6000.00
0005432666423	5084	Economy	6000.00
0005433615902	5084	Economy	6000.00
0005432106348	5084	Economy	6000.00
0005433615895	5084	Economy	6000.00
0005433615930	5084	Economy	6000.00
0005433785531	5084	Economy	6000.00
0005432106377	5084	Economy	6000.00
0005432145145	5084	Economy	6000.00
0005433615856	5084	Economy	6000.00
0005432666422	5084	Economy	6000.00
0005433615923	5084	Economy	6000.00
0005433615880	5084	Economy	6000.00
0005433785550	5084	Economy	6000.00
0005432106366	5084	Economy	6000.00
0005433615864	5084	Economy	6000.00
0005432667487	5084	Economy	6000.00
0005432106362	5084	Economy	6000.00
0005433785540	5084	Economy	6000.00
0005433785544	5084	Economy	6000.00
0005432106357	5084	Economy	6000.00
0005433615910	5084	Economy	6000.00
0005433785552	5084	Economy	6000.00
0005433615885	5084	Economy	6000.00
0005433785535	5084	Economy	6000.00
0005432106335	5084	Economy	6000.00
0005432106333	5084	Economy	6000.00
0005433615877	5084	Economy	6000.00
0005433615901	5084	Economy	6000.00
0005433785557	5084	Economy	6000.00
0005433615858	5084	Economy	6000.00
0005433785526	5084	Economy	6000.00
0005433615908	5084	Economy	6000.00
0005433785554	5084	Economy	6000.00
0005433615899	5084	Economy	6000.00
0005432106355	5084	Economy	6000.00
0005432106341	5084	Economy	6000.00
0005433615911	5084	Economy	6000.00
0005433615897	5084	Economy	6000.00
0005432106370	5084	Economy	6000.00
0005433615915	5084	Economy	6000.00
0005433615917	5084	Economy	6000.00
0005432106331	5084	Economy	6000.00
0005432106351	5084	Economy	6000.00
0005433615859	5084	Economy	6000.00
0005433615907	5084	Economy	6000.00
0005433615904	5084	Economy	6000.00
0005434265564	5082	Business	18000.00
0005435269808	5082	Business	18000.00
0005435269811	5082	Business	18000.00
0005435269759	5082	Business	18000.00
0005435007200	5082	Business	18000.00
0005435269801	5082	Business	18000.00
0005435269779	5082	Business	18000.00
0005435269809	5082	Business	18000.00
0005435007198	5082	Business	18000.00
0005435007208	5082	Business	18000.00
0005435269799	5082	Business	18000.00
0005433815411	5082	Business	18000.00
0005434265558	5082	Business	18000.00
0005435007197	5082	Business	18000.00
0005434265565	5082	Business	18000.00
0005434265549	5082	Business	18000.00
0005435007203	5082	Business	18000.00
0005435007274	5082	Business	18000.00
0005434173586	5082	Business	18000.00
0005434149918	5082	Business	18000.00
0005435269788	5082	Business	18000.00
0005434149924	5082	Business	18000.00
0005432336122	5082	Economy	6600.00
0005432336124	5082	Economy	6600.00
0005434265550	5082	Economy	6600.00
0005434229731	5082	Economy	6600.00
0005435269810	5082	Economy	6000.00
0005435007234	5082	Economy	6000.00
0005432336058	5082	Economy	6000.00
0005434149925	5082	Economy	6000.00
0005434149928	5082	Economy	6000.00
0005435007228	5082	Economy	6000.00
0005434229737	5082	Economy	6000.00
0005435007219	5082	Economy	6000.00
0005434149919	5082	Economy	6000.00
0005434229751	5082	Economy	6000.00
0005434265561	5082	Economy	6000.00
0005435269826	5082	Economy	6000.00
0005435269817	5082	Economy	6000.00
0005432336117	5082	Economy	6000.00
0005434265571	5082	Economy	6000.00
0005434265559	5082	Economy	6000.00
0005434229736	5082	Economy	6000.00
0005434265552	5082	Economy	6000.00
0005434229742	5082	Economy	6000.00
0005432336145	5082	Economy	6000.00
0005434229741	5082	Economy	6000.00
0005432336127	5082	Economy	6000.00
0005432336134	5082	Economy	6000.00
0005434149927	5082	Economy	6000.00
0005434265568	5082	Economy	6000.00
0005434149922	5082	Economy	6000.00
0005435269789	5082	Economy	6000.00
0005434229730	5082	Economy	6000.00
0005434229740	5082	Economy	6000.00
0005434149921	5082	Economy	6000.00
0005435007140	5082	Economy	6000.00
0005435007181	5082	Economy	6000.00
0005435007273	5082	Economy	6000.00
0005434265570	5082	Economy	6000.00
0005434229732	5082	Economy	6000.00
0005434229749	5082	Economy	6000.00
0005435007215	5082	Economy	6000.00
0005434173587	5082	Economy	6000.00
0005434265560	5082	Economy	6000.00
0005435007121	5082	Economy	6000.00
0005434265567	5082	Economy	6600.00
0005435007258	5082	Economy	6600.00
0005434265555	5082	Economy	6000.00
0005434149926	5082	Economy	6000.00
0005432336130	5082	Economy	6000.00
0005435007249	5082	Economy	6000.00
0005434265556	5082	Economy	6600.00
0005435007275	5082	Economy	6000.00
0005434229738	5082	Economy	6000.00
0005434265551	5082	Economy	6000.00
0005435007220	5082	Economy	6000.00
0005434173584	5082	Economy	6000.00
0005434311234	5082	Economy	6000.00
0005434265562	5082	Economy	6000.00
0005435007250	5082	Economy	6000.00
0005434265557	5082	Economy	6000.00
0005434229734	5082	Economy	6000.00
0005434265566	5082	Economy	6000.00
0005432336084	5082	Economy	6000.00
0005434229750	5082	Economy	6000.00
0005434149923	5082	Economy	6000.00
0005432336161	5082	Economy	6000.00
0005432336119	5082	Economy	6000.00
0005434149929	5082	Economy	6000.00
0005434229739	5082	Economy	6000.00
0005434265553	5082	Economy	6000.00
0005435269795	5082	Economy	6000.00
0005434149920	5082	Economy	6000.00
0005434229733	5082	Economy	6000.00
0005434229743	5082	Economy	6000.00
0005432336108	5082	Economy	6000.00
0005434265569	5082	Economy	6000.00
0005434265573	5082	Economy	6000.00
0005432336131	5082	Economy	6000.00
0005434229729	5082	Economy	6000.00
0005434229744	5082	Economy	6000.00
0005434229748	5082	Economy	6000.00
0005434265563	5082	Economy	6000.00
0005433815397	5082	Economy	6000.00
0005434229746	5082	Economy	6000.00
0005434265554	5082	Economy	6000.00
0005435269802	5082	Economy	6000.00
0005435007212	5082	Economy	6000.00
0005434229745	5082	Economy	6000.00
0005435007180	5082	Economy	6000.00
0005434265574	5082	Economy	6000.00
0005434229747	5082	Economy	6000.00
0005435269803	5082	Economy	6000.00
0005434265572	5082	Economy	6000.00
0005435007199	5082	Economy	6000.00
0005435269800	5082	Economy	6000.00
0005434229735	5082	Economy	6000.00
0005435007204	5082	Economy	6000.00
0005434173585	5082	Economy	6000.00
0005432666410	8437	Business	18000.00
0005434245075	8437	Business	18000.00
0005434245209	8437	Business	18000.00
0005433785316	8437	Business	18000.00
0005434245194	8437	Business	18000.00
0005433785334	8437	Business	18000.00
0005434245212	8437	Business	18000.00
0005434245188	8437	Business	18000.00
0005434245169	8437	Business	18000.00
0005433785344	8437	Business	18000.00
0005433785188	8437	Business	18000.00
0005434245374	8437	Business	18000.00
0005433785289	8437	Business	18000.00
0005433785227	8437	Business	18000.00
0005434245228	8437	Business	18000.00
0005433785193	8437	Business	18000.00
0005434245297	8437	Economy	6600.00
0005434245317	8437	Economy	6600.00
0005433785132	8437	Economy	6000.00
0005434245189	8437	Economy	6000.00
0005433785200	8437	Economy	6000.00
0005433785181	8437	Economy	6000.00
0005434245303	8437	Economy	6000.00
0005434245145	8437	Economy	6000.00
0005433785288	8437	Economy	6000.00
0005433785284	8437	Economy	6000.00
0005433785182	8437	Economy	6000.00
0005434245294	8437	Economy	6000.00
0005433785092	8437	Economy	6000.00
0005434245232	8437	Economy	6000.00
0005433785223	8437	Economy	6000.00
0005434245146	8437	Economy	6000.00
0005432663047	8437	Economy	6000.00
0005433785234	8437	Economy	6000.00
0005433785033	8437	Economy	6000.00
0005433785273	8437	Economy	6000.00
0005433785129	8437	Economy	6000.00
0005433785094	8437	Economy	6000.00
0005433785287	8437	Economy	6000.00
0005434245231	8437	Economy	6000.00
0005433785258	8437	Economy	6000.00
0005435269880	8437	Economy	6000.00
0005435269879	8437	Economy	6000.00
0005433785335	8437	Economy	6000.00
0005433785326	8437	Economy	6000.00
0005434245213	8437	Economy	6000.00
0005435269882	8437	Economy	6600.00
0005433785351	8437	Economy	6600.00
0005433785333	8437	Economy	6600.00
0005432666403	8437	Economy	6000.00
0005434245371	8437	Economy	6000.00
0005433785169	8437	Economy	6000.00
0005433785222	8437	Economy	6000.00
0005433785148	8437	Economy	6000.00
0005433785285	8437	Economy	6000.00
0005435269881	8437	Economy	6000.00
0005433785170	8437	Economy	6000.00
0005434245168	8437	Economy	6000.00
0005433785149	8437	Economy	6000.00
0005433785225	8437	Economy	6000.00
0005434245322	8437	Economy	6000.00
0005433785109	8437	Economy	6000.00
0005434245183	8437	Economy	6000.00
0005434245193	8437	Economy	6000.00
0005433785104	8437	Economy	6000.00
0005434245267	8437	Economy	6000.00
0005433785274	8437	Economy	6000.00
0005434245182	8437	Economy	6000.00
0005434245318	8437	Economy	6000.00
0005434245076	8437	Economy	6000.00
0005433785224	8437	Economy	6000.00
0005434245268	8437	Economy	6000.00
0005433785174	8437	Economy	6000.00
0005433785208	8437	Economy	6000.00
0005433785215	8437	Economy	6000.00
0005433785047	8437	Economy	6000.00
0005434245161	8437	Economy	6000.00
0005432663041	8437	Economy	6000.00
0005433785233	8437	Economy	6000.00
0005434245302	8437	Economy	6000.00
0005434245319	8437	Economy	6000.00
0005434245233	8437	Economy	6000.00
0005433785240	8437	Economy	6000.00
0005433785095	8437	Economy	6000.00
0005433615339	8436	Business	18000.00
0005433615187	8436	Business	18000.00
0005433615189	8436	Business	18000.00
0005433614787	8436	Business	18000.00
0005433615170	8436	Business	18000.00
0005433615138	8436	Business	18000.00
0005433615292	8436	Business	18000.00
0005433614985	8436	Business	18000.00
0005433615027	8436	Business	18000.00
0005433615066	8436	Business	18000.00
0005433615206	8436	Business	18000.00
0005433615473	8436	Economy	6600.00
0005433615034	8436	Economy	6600.00
0005433615248	8436	Economy	6000.00
0005433615534	8436	Economy	6000.00
0005433614875	8436	Economy	6000.00
0005433615137	8436	Economy	6000.00
0005433615251	8436	Economy	6000.00
0005433615253	8436	Economy	6000.00
0005433615038	8436	Economy	6000.00
0005433615194	8436	Economy	6000.00
0005433615001	8436	Economy	6000.00
0005433615322	8436	Economy	6000.00
0005433615416	8436	Economy	6000.00
0005433615291	8436	Economy	6000.00
0005433615393	8436	Economy	6000.00
0005433615207	8436	Economy	6000.00
0005433615051	8436	Economy	6000.00
0005433615383	8436	Economy	6000.00
0005433615323	8436	Economy	6000.00
0005433615535	8436	Economy	6000.00
0005433615161	8436	Economy	6000.00
0005433615168	8436	Economy	6000.00
0005433615435	8436	Economy	6000.00
0005433615112	8436	Economy	6000.00
0005433615065	8436	Economy	6000.00
0005433615053	8436	Economy	6000.00
0005433615293	8436	Economy	6000.00
0005433615167	8436	Economy	6000.00
0005433615104	8436	Economy	6000.00
0005433615424	8436	Economy	6600.00
0005433615177	8436	Economy	6600.00
0005433615252	8436	Economy	6000.00
0005433614645	8436	Economy	6000.00
0005433615153	8436	Economy	6000.00
0005433615048	8436	Economy	6000.00
0005433615037	8436	Economy	6000.00
0005433615344	8436	Economy	6000.00
0005433614999	8436	Economy	6000.00
0005433615394	8436	Economy	6000.00
0005433615359	8436	Economy	6000.00
0005433614874	8436	Economy	6000.00
0005433615064	8436	Economy	6000.00
0005433615186	8436	Economy	6000.00
0005433615000	8436	Economy	6000.00
0005433615567	8436	Economy	6000.00
0005433615152	8436	Economy	6000.00
0005433615405	8436	Economy	6000.00
0005433615113	8436	Economy	6000.00
0005433614918	8436	Economy	6000.00
0005433615147	8436	Economy	6000.00
0005433615049	8436	Economy	6000.00
0005433615054	8436	Economy	6000.00
0005433615188	8436	Economy	6000.00
0005433615039	8436	Economy	6000.00
0005433615129	8436	Economy	6000.00
0005433615384	8436	Economy	6000.00
0005433615298	8436	Economy	6000.00
0005433614786	8436	Economy	6000.00
0005433615347	8436	Economy	6000.00
0005433614903	8436	Economy	6000.00
0005434265388	8435	Business	18000.00
0005433815468	8435	Business	18000.00
0005432336226	8435	Business	18000.00
0005434229525	8435	Business	18000.00
0005435007416	8435	Business	18000.00
0005433689947	8435	Business	18000.00
0005434229492	8435	Business	18000.00
0005432047614	8435	Business	18000.00
0005432035400	8435	Business	18000.00
0005434229508	8435	Business	18000.00
0005434149847	8435	Business	18000.00
0005434265341	8435	Business	18000.00
0005432035411	8435	Business	18000.00
0005432047610	8435	Business	18000.00
0005434265356	8435	Business	18000.00
0005434265340	8435	Business	18000.00
0005432035397	8435	Business	18000.00
0005433815464	8435	Business	18000.00
0005432035391	8435	Business	18000.00
0005434229493	8435	Business	18000.00
0005432336228	8435	Business	18000.00
0005434265434	8435	Business	18000.00
0005434265386	8435	Business	18000.00
0005434149789	8435	Business	18000.00
0005434265342	8435	Business	18000.00
0005432035394	8435	Business	18000.00
0005434149839	8435	Economy	6600.00
0005434173557	8435	Business	18000.00
0005434229570	8435	Economy	6600.00
0005434229503	8435	Economy	6600.00
0005434265418	8435	Economy	6600.00
0005435007406	8435	Economy	6600.00
0005432035390	8435	Economy	6000.00
0005435007402	8435	Economy	6000.00
0005434265414	8435	Economy	6000.00
0005432035410	8435	Economy	6000.00
0005432035414	8435	Economy	6000.00
0005434265413	8435	Economy	6000.00
0005434229533	8435	Economy	6000.00
0005434265358	8435	Economy	6000.00
0005435007413	8435	Economy	6000.00
0005434265422	8435	Economy	6000.00
0005432047611	8435	Economy	6000.00
0005434265301	8435	Economy	6000.00
0005434229562	8435	Economy	6000.00
0005432035402	8435	Economy	6000.00
0005434265385	8435	Economy	6000.00
0005434265352	8435	Economy	6000.00
0005434229467	8435	Economy	6000.00
0005434265236	8435	Economy	6000.00
0005433690958	8435	Economy	6000.00
0005432035405	8435	Economy	6000.00
0005434265292	8435	Economy	6000.00
0005434265417	8435	Economy	6000.00
0005433688845	8435	Economy	6000.00
0005434229505	8435	Economy	6000.00
0005434229550	8435	Economy	6000.00
0005432047613	8435	Economy	6000.00
0005433534535	8435	Economy	6000.00
0005432336233	8435	Economy	6000.00
0005434229607	8435	Economy	6000.00
0005434229475	8435	Economy	6000.00
0005434149775	8435	Economy	6000.00
0005434149846	8435	Economy	6000.00
0005432336234	8435	Economy	6000.00
0005432336224	8435	Economy	6000.00
0005434149851	8435	Economy	6000.00
0005435007403	8435	Economy	6000.00
0005432035417	8435	Economy	6000.00
0005432336229	8435	Economy	6000.00
0005432035398	8435	Economy	6000.00
0005434173549	8435	Economy	6000.00
0005433689946	8435	Economy	6000.00
0005434229557	8435	Economy	6000.00
0005434265348	8435	Economy	6000.00
0005435007405	8435	Economy	6000.00
0005434265332	8435	Economy	6000.00
0005432035408	8435	Economy	6000.00
0005432035393	8435	Economy	6000.00
0005432035416	8435	Economy	6000.00
0005432047612	8435	Economy	6000.00
0005432336231	8435	Economy	6000.00
0005434265321	8435	Economy	6000.00
0005432035395	8435	Economy	6600.00
0005435007408	8435	Economy	6600.00
0005432336235	8435	Economy	6600.00
0005432035412	8435	Economy	6600.00
0005434173561	8435	Economy	6000.00
0005434173562	8435	Economy	6000.00
0005432035399	8435	Economy	6000.00
0005434149774	8435	Economy	6000.00
0005434265237	8435	Economy	6600.00
0005435007409	8435	Economy	6000.00
0005434265333	8435	Economy	6000.00
0005435007410	8435	Economy	6000.00
0005434265326	8435	Economy	6000.00
0005434229563	8435	Economy	6000.00
0005432336232	8435	Economy	6000.00
0005434173553	8435	Economy	6000.00
0005434265271	8435	Economy	6000.00
0005432336230	8435	Economy	6000.00
0005434265290	8435	Economy	6000.00
0005432035409	8435	Economy	6000.00
0005434173554	8435	Economy	6000.00
0005434265276	8435	Economy	6000.00
0005432035401	8435	Economy	6000.00
0005432035415	8435	Economy	6000.00
0005434265354	8435	Economy	6000.00
0005434173560	8435	Economy	6000.00
0005435007414	8435	Economy	6000.00
0005435007411	8435	Economy	6000.00
0005433815465	8435	Economy	6000.00
0005433815469	8435	Economy	6000.00
0005434265351	8435	Economy	6000.00
0005433815466	8435	Economy	6000.00
0005434265357	8435	Economy	6000.00
0005434229504	8435	Economy	6000.00
0005434265291	8435	Economy	6000.00
0005432035389	8435	Economy	6000.00
0005435007407	8435	Economy	6000.00
0005434311253	8435	Economy	6000.00
0005434265410	8435	Economy	6000.00
0005433534534	8435	Economy	6000.00
0005432035396	8435	Economy	6000.00
0005433689945	8435	Economy	6000.00
0005432035406	8435	Economy	6000.00
0005432336227	8435	Economy	6000.00
0005434149798	8435	Economy	6000.00
0005435007415	8435	Economy	6000.00
0005433688843	8435	Economy	6000.00
0005434149831	8435	Economy	6000.00
0005433815467	8435	Economy	6000.00
0005434229549	8435	Economy	6000.00
0005434149832	8435	Economy	6000.00
0005434265302	8435	Economy	6000.00
0005434173563	8435	Economy	6000.00
0005434311252	8435	Economy	6000.00
0005432035392	8435	Economy	6000.00
0005434265275	8435	Economy	6000.00
0005433688844	8435	Economy	6000.00
0005432035407	8435	Economy	6000.00
0005434229605	8435	Economy	6000.00
0005434229571	8435	Economy	6000.00
0005434229524	8435	Economy	6000.00
0005432035403	8435	Economy	6000.00
0005433815470	8435	Economy	6000.00
0005432336225	8435	Economy	6000.00
0005434265478	8435	Economy	6000.00
0005434229526	8435	Economy	6000.00
0005434149856	8435	Economy	6000.00
0005433690959	8435	Economy	6000.00
0005432035404	8435	Economy	6000.00
0005432035413	8435	Economy	6000.00
0005435007412	8435	Economy	6000.00
0005435007404	8435	Economy	6000.00
0005434639529	12594	Economy	16200.00
0005434639466	12594	Economy	16200.00
0005434639516	12594	Economy	16200.00
0005434639525	12594	Economy	14800.00
0005434639520	12594	Economy	14800.00
0005434639596	12594	Economy	14800.00
0005434639400	12594	Economy	14800.00
0005433202607	12594	Economy	14800.00
0005433202610	12594	Economy	14800.00
0005433202606	12594	Economy	14800.00
0005434639521	12594	Economy	14800.00
0005434639592	12594	Economy	14800.00
0005434639560	12594	Economy	14800.00
0005434639562	12594	Economy	14800.00
0005434639496	12594	Economy	14800.00
0005434639540	12594	Economy	14800.00
0005433202599	12594	Economy	14800.00
0005433202613	12594	Economy	14800.00
0005434639526	12594	Economy	14800.00
0005433202605	12594	Economy	14800.00
0005433202604	12594	Economy	14800.00
0005433202601	12594	Economy	14800.00
0005434639497	12594	Economy	14800.00
0005433202614	12594	Economy	14800.00
0005433202612	12594	Economy	14800.00
0005434639515	12594	Economy	14800.00
0005433202611	12594	Economy	14800.00
0005434639424	12594	Economy	14800.00
0005434639487	12594	Economy	14800.00
0005434639564	12594	Economy	14800.00
0005433202600	12594	Economy	14800.00
0005433202609	12594	Economy	14800.00
0005433202603	12594	Economy	14800.00
0005434639563	12594	Economy	14800.00
0005434639597	12594	Economy	14800.00
0005434639527	12594	Economy	14800.00
0005434639541	12594	Economy	14800.00
0005434639561	12594	Economy	14800.00
0005433202608	12594	Economy	14800.00
0005434639488	12594	Economy	14800.00
0005433202602	12594	Economy	14800.00
0005434639401	12594	Economy	14800.00
0005434639530	12594	Economy	14800.00
0005434639715	23374	Economy	16200.00
0005433202452	23374	Economy	16200.00
0005433202470	23374	Economy	16200.00
0005433202416	23374	Economy	16200.00
0005434639710	23374	Economy	14800.00
0005434639723	23374	Economy	14800.00
0005433202421	23374	Economy	14800.00
0005432290683	23374	Economy	14800.00
0005434639722	23374	Economy	14800.00
0005434639712	23374	Economy	14800.00
0005434639708	23374	Economy	14800.00
0005433202474	23374	Economy	14800.00
0005434639721	23374	Economy	14800.00
0005434639719	23374	Economy	14800.00
0005434639727	23374	Economy	14800.00
0005434639725	23374	Economy	14800.00
0005434639720	23374	Economy	14800.00
0005432290681	23374	Economy	14800.00
0005433202473	23374	Economy	14800.00
0005434639724	23374	Economy	14800.00
0005432290685	23374	Economy	14800.00
0005434639726	23374	Economy	14800.00
0005434639729	23374	Economy	14800.00
0005433202468	23374	Economy	14800.00
0005433202424	23374	Economy	14800.00
0005433202491	23374	Economy	14800.00
0005434639714	23374	Economy	14800.00
0005433202375	23374	Economy	14800.00
0005434639713	23374	Economy	14800.00
0005433202401	23374	Economy	14800.00
0005433202425	23374	Economy	14800.00
0005434639718	23374	Economy	14800.00
0005432290684	23374	Economy	14800.00
0005434639716	23374	Economy	14800.00
0005434639731	23374	Economy	14800.00
0005434639707	23374	Economy	14800.00
0005434639728	23374	Economy	14800.00
0005433202490	23374	Economy	14800.00
0005433202499	23374	Economy	14800.00
0005434639711	23374	Economy	14800.00
0005434639730	23374	Economy	14800.00
0005434639717	23374	Economy	14800.00
0005432290680	23374	Economy	14800.00
0005434639709	23374	Economy	14800.00
0005433202420	23374	Economy	14800.00
0005432290682	23374	Economy	14800.00
0005433202469	23374	Economy	14800.00
0005432329172	21063	Business	18900.00
0005432329068	21063	Business	18900.00
0005432329027	21063	Business	18900.00
0005432383395	21063	Business	18900.00
0005432329125	21063	Business	18900.00
0005432328992	21063	Business	18900.00
0005432383424	21063	Business	18900.00
0005432329165	21063	Business	18900.00
0005432383498	21063	Business	18900.00
0005432383384	21063	Business	18900.00
0005432328896	21063	Business	18900.00
0005432329140	21063	Business	18900.00
0005432329031	21063	Economy	6300.00
0005432383509	21063	Economy	6300.00
0005432383387	21063	Economy	6300.00
0005432383487	21063	Economy	6300.00
0005432329150	21063	Economy	6300.00
0005432054352	21063	Economy	6300.00
0005432329167	21063	Economy	6300.00
0005432329133	21063	Economy	6300.00
0005432383460	21063	Economy	6300.00
0005432383417	21063	Economy	6300.00
0005432383484	21063	Economy	6900.00
0005432383478	21063	Economy	6900.00
0005432383510	21063	Economy	6900.00
0005432383324	21063	Economy	6900.00
0005432383353	21063	Economy	6900.00
0005432329054	21063	Economy	6300.00
0005432383418	21063	Economy	6300.00
0005432383485	21063	Economy	6300.00
0005432383298	21063	Economy	6300.00
0005432329055	21063	Economy	6300.00
0005432383497	21063	Economy	6300.00
0005432383386	21063	Economy	6300.00
0005432383358	21063	Economy	6300.00
0005432329041	21063	Economy	6300.00
0005432383396	21063	Economy	6300.00
0005432383285	21063	Economy	6300.00
0005432383422	21063	Economy	6300.00
0005432329216	21063	Economy	6300.00
0005432329026	21063	Economy	6300.00
0005432383477	21063	Economy	6300.00
0005432329001	21063	Economy	6300.00
0005432383496	21063	Economy	6300.00
0005432383423	21063	Economy	6300.00
0005432328836	21063	Economy	6300.00
0005432328880	21063	Economy	6300.00
0005432383325	21063	Economy	6300.00
0005432383451	21063	Economy	6300.00
0005432383330	21063	Economy	6300.00
0005432383526	21063	Economy	6300.00
0005432329151	21063	Economy	6300.00
0005432383546	21063	Economy	6300.00
0005432329168	21063	Economy	6300.00
0005432383438	21063	Economy	6300.00
0005432328969	21063	Economy	6300.00
0005432329037	21063	Economy	6300.00
0005432383545	21063	Economy	6300.00
0005432383361	21063	Economy	6300.00
0005432383385	21063	Economy	6300.00
0005432328883	21063	Economy	6300.00
0005432383362	21063	Economy	6300.00
0005432383392	21063	Economy	6300.00
0005432329139	21063	Economy	6300.00
0005432383434	21063	Economy	6300.00
0005432329057	21063	Economy	6300.00
0005432383357	21063	Economy	6300.00
0005432328918	21063	Economy	6300.00
0005432329038	21063	Economy	6300.00
0005432328889	21063	Economy	6300.00
0005432383503	21063	Economy	6300.00
0005432383489	21063	Economy	6300.00
0005432328914	21063	Economy	6300.00
0005432328970	21063	Economy	6300.00
0005432054354	21063	Economy	6300.00
0005432329095	21063	Economy	6300.00
0005432383435	21063	Economy	6300.00
0005432329032	21063	Economy	6300.00
0005432383377	21063	Economy	6300.00
0005432054353	21063	Economy	6300.00
0005432328994	21063	Economy	6300.00
0005432328882	21063	Economy	6300.00
0005432329094	21063	Economy	6300.00
0005432383393	21063	Economy	6300.00
0005432383433	21063	Economy	6300.00
0005432383388	21063	Economy	6300.00
0005432383490	21063	Economy	6300.00
0005432329236	21063	Economy	6300.00
0005432329134	21063	Economy	6300.00
0005432328758	21063	Economy	6300.00
0005432329047	21063	Economy	6300.00
0005432383284	21063	Economy	6300.00
0005432329033	21063	Economy	6300.00
0005432329069	21063	Economy	6300.00
0005432383775	31220	Business	18900.00
0005432383779	31220	Business	18900.00
0005432383754	31220	Business	18900.00
0005432383767	31220	Business	18900.00
0005432383762	31220	Business	18900.00
0005432329411	31220	Business	18900.00
0005432383788	31220	Business	18900.00
0005432329416	31220	Business	18900.00
0005432383776	31220	Business	18900.00
0005432383761	31220	Business	18900.00
0005432329395	31220	Business	18900.00
0005432383774	31220	Economy	6300.00
0005432329421	31220	Economy	6300.00
0005432848838	31220	Economy	6300.00
0005432383782	31220	Economy	6300.00
0005432383760	31220	Economy	6300.00
0005432329415	31220	Economy	6300.00
0005432329397	31220	Economy	6300.00
0005432329417	31220	Economy	6300.00
0005432329420	31220	Economy	6300.00
0005432329404	31220	Economy	6300.00
0005432383755	31220	Economy	6900.00
0005432383787	31220	Economy	6900.00
0005432329408	31220	Economy	6900.00
0005432383765	31220	Economy	6900.00
0005432329401	31220	Economy	6900.00
0005432383766	31220	Economy	6300.00
0005432383780	31220	Economy	6300.00
0005432383772	31220	Economy	6300.00
0005432329400	31220	Economy	6300.00
0005432329436	31220	Economy	6300.00
0005432329438	31220	Economy	6300.00
0005432329399	31220	Economy	6300.00
0005432287267	31220	Economy	6300.00
0005432383768	31220	Economy	6300.00
0005432329402	31220	Economy	6300.00
0005432287266	31220	Economy	6300.00
0005432329413	31220	Economy	6300.00
0005432329418	31220	Economy	6300.00
0005432329422	31220	Economy	6300.00
0005432383777	31220	Economy	6300.00
0005432383753	31220	Economy	6300.00
0005432329425	31220	Economy	6300.00
0005432329398	31220	Economy	6300.00
0005432329433	31220	Economy	6300.00
0005432329405	31220	Economy	6300.00
0005432329434	31220	Economy	6300.00
0005432383771	31220	Economy	6300.00
0005432383783	31220	Economy	6300.00
0005432383784	31220	Economy	6300.00
0005432329432	31220	Economy	6300.00
0005432383752	31220	Economy	6300.00
0005432383791	31220	Economy	6300.00
0005432329394	31220	Economy	6300.00
0005432329414	31220	Economy	6300.00
0005432329430	31220	Economy	6300.00
0005432383781	31220	Economy	6300.00
0005432287269	31220	Economy	6300.00
0005432329423	31220	Economy	6300.00
0005432329419	31220	Economy	6300.00
0005432329426	31220	Economy	6300.00
0005432383778	31220	Economy	6300.00
0005432329406	31220	Economy	6300.00
0005432329431	31220	Economy	6300.00
0005432329435	31220	Economy	6300.00
0005432329439	31220	Economy	6300.00
0005432329403	31220	Economy	6300.00
0005432329429	31220	Economy	6300.00
0005432329424	31220	Economy	6300.00
0005432329407	31220	Economy	6300.00
0005432383763	31220	Economy	6300.00
0005432383764	31220	Economy	6300.00
0005432383773	31220	Economy	6300.00
0005432383757	31220	Economy	6300.00
0005432383758	31220	Economy	6300.00
0005432383790	31220	Economy	6300.00
0005432383770	31220	Economy	6300.00
0005432329396	31220	Economy	6300.00
0005432287268	31220	Economy	6300.00
0005432329410	31220	Economy	6300.00
0005432383786	31220	Economy	6300.00
0005432329412	31220	Economy	6300.00
0005432383785	31220	Economy	6300.00
0005432848839	31220	Economy	6300.00
0005432329428	31220	Economy	6300.00
0005432383769	31220	Economy	6300.00
0005432329409	31220	Economy	6300.00
0005432383756	31220	Economy	6300.00
0005432329437	31220	Economy	6300.00
0005432383750	31220	Economy	6300.00
0005432383759	31220	Economy	6300.00
0005432287270	31220	Economy	6300.00
0005432383751	31220	Economy	6300.00
0005432329427	31220	Economy	6300.00
0005432383789	31220	Economy	6300.00
0005432425199	13327	Business	12700.00
0005432425223	13327	Business	12700.00
0005432425186	13327	Business	12700.00
0005432425192	13327	Business	12700.00
0005432425220	13327	Business	12700.00
0005432425213	13327	Business	12700.00
0005432425196	13327	Business	12700.00
0005432425209	13327	Economy	4200.00
0005432425222	13327	Economy	4200.00
0005432425200	13327	Economy	4200.00
0005432425211	13327	Economy	4200.00
0005432425230	13327	Economy	4200.00
0005432425189	13327	Economy	4200.00
0005432425218	13327	Economy	4200.00
0005432425229	13327	Economy	4700.00
0005432425235	13327	Economy	4700.00
0005432425219	13327	Economy	4700.00
0005432425233	13327	Economy	4200.00
0005432425207	13327	Economy	4200.00
0005432425202	13327	Economy	4200.00
0005432425188	13327	Economy	4200.00
0005432425214	13327	Economy	4200.00
0005432425228	13327	Economy	4200.00
0005432425191	13327	Economy	4200.00
0005432425231	13327	Economy	4200.00
0005432425185	13327	Economy	4200.00
0005432425203	13327	Economy	4200.00
0005432425190	13327	Economy	4200.00
0005432425201	13327	Economy	4200.00
0005432425224	13327	Economy	4200.00
0005432425195	13327	Economy	4200.00
0005432425210	13327	Economy	4200.00
0005432425216	13327	Economy	4200.00
0005432425205	13327	Economy	4200.00
0005432425193	13327	Economy	4200.00
0005432425226	13327	Economy	4200.00
0005432425221	13327	Economy	4200.00
0005432425208	13327	Economy	4200.00
0005432425206	13327	Economy	4200.00
0005432425212	13327	Economy	4200.00
0005432425217	13327	Economy	4200.00
0005432425234	13327	Economy	4200.00
0005432425215	13327	Economy	4200.00
0005432425225	13327	Economy	4200.00
0005432425198	13327	Economy	4200.00
0005432425197	13327	Economy	4200.00
0005432425232	13327	Economy	4200.00
0005432425204	13327	Economy	4200.00
0005432425194	13327	Economy	4200.00
0005432425187	13327	Economy	4200.00
0005432425227	13327	Economy	4200.00
0005432424740	30784	Business	12700.00
0005432424464	30784	Business	12700.00
0005432424622	30784	Business	12700.00
0005432424778	30784	Business	12700.00
0005432424820	30784	Business	12700.00
0005432424805	30784	Business	12700.00
0005432424549	30784	Business	12700.00
0005432424668	30784	Economy	4200.00
0005432424710	30784	Economy	4200.00
0005432424548	30784	Economy	4200.00
0005432424642	30784	Economy	4200.00
0005432424672	30784	Economy	4200.00
0005432424657	30784	Economy	4700.00
0005432424812	30784	Economy	4200.00
0005432424819	30784	Economy	4200.00
0005432424777	30784	Economy	4200.00
0005432424768	30784	Economy	4200.00
0005432424771	30784	Economy	4200.00
0005432424649	30784	Economy	4200.00
0005432424814	30784	Economy	4200.00
0005432424776	30784	Economy	4200.00
0005432424793	30784	Economy	4200.00
0005432424801	30784	Economy	4200.00
0005432424655	30784	Economy	4200.00
0005432424821	30784	Economy	4200.00
0005432424726	30784	Economy	4200.00
0005432424692	30784	Economy	4200.00
0005432424648	30784	Economy	4200.00
0005432424713	30784	Economy	4200.00
0005432424714	30784	Economy	4200.00
0005432424725	30784	Economy	4200.00
0005432424656	30784	Economy	4200.00
0005432424764	30784	Economy	4200.00
0005432424760	30784	Economy	4200.00
0005432424641	30784	Economy	4200.00
0005432424779	30784	Economy	4200.00
0005432424804	30784	Economy	4200.00
0005432424763	30784	Economy	4200.00
0005432424706	30784	Economy	4200.00
0005432424787	30784	Economy	4200.00
0005432424465	30784	Economy	4200.00
0005432424758	30784	Economy	4200.00
0005432424734	30784	Economy	4200.00
0005432424743	30784	Economy	4200.00
0005432424792	30784	Economy	4200.00
0005432424769	30784	Economy	4200.00
0005432817948	9579	Business	32600.00
0005434186225	9579	Business	32600.00
0005432817966	9579	Business	32600.00
0005434157565	9579	Business	32600.00
0005432901671	9579	Business	32600.00
0005432289039	9579	Business	32600.00
0005432901724	9579	Business	32600.00
0005434157551	9579	Business	32600.00
0005434157521	9579	Business	32600.00
0005432817951	9579	Business	32600.00
0005432817960	9579	Business	32600.00
0005432817970	9579	Business	32600.00
0005432817964	9579	Economy	10900.00
0005434157537	9579	Economy	10900.00
0005432289040	9579	Economy	10900.00
0005432817958	9579	Economy	10900.00
0005432817954	9579	Economy	10900.00
0005432817943	9579	Economy	10900.00
0005432901809	9579	Economy	10900.00
0005434157542	9579	Economy	11900.00
0005432901763	9579	Economy	11900.00
0005432901744	9579	Economy	10900.00
0005432822327	9579	Economy	10900.00
0005432817968	9579	Economy	10900.00
0005432817965	9579	Economy	10900.00
0005432817955	9579	Economy	10900.00
0005434448372	9579	Economy	10900.00
0005434157540	9579	Economy	10900.00
0005432817953	9579	Economy	10900.00
0005434157550	9579	Economy	10900.00
0005432901765	9579	Economy	10900.00
0005432901748	9579	Economy	10900.00
0005432817946	9579	Economy	10900.00
0005432817961	9579	Economy	10900.00
0005432822330	9579	Economy	10900.00
0005432901743	9579	Economy	10900.00
0005432817956	9579	Economy	10900.00
0005432817963	9579	Economy	10900.00
0005432901694	9579	Economy	10900.00
0005432817962	9579	Economy	10900.00
0005432817941	9579	Economy	10900.00
0005432817967	9579	Economy	10900.00
0005432822329	9579	Economy	10900.00
0005434157522	9579	Economy	10900.00
0005434186212	9579	Economy	10900.00
0005432817950	9579	Economy	10900.00
0005434157541	9579	Economy	10900.00
0005434448374	9579	Economy	10900.00
0005434186223	9579	Economy	10900.00
0005434157546	9579	Economy	10900.00
0005434448371	9579	Economy	10900.00
0005432817949	9579	Economy	10900.00
0005434186224	9579	Economy	10900.00
0005432822331	9579	Economy	10900.00
0005432822332	9579	Economy	10900.00
0005434157547	9579	Economy	10900.00
0005432901813	9579	Economy	10900.00
0005432817942	9579	Economy	10900.00
0005432817945	9579	Economy	10900.00
0005434448373	9579	Economy	10900.00
0005432822328	9579	Economy	10900.00
0005432289043	9579	Economy	10900.00
0005432817969	9579	Economy	10900.00
0005432817944	9579	Economy	10900.00
0005432901790	9579	Economy	10900.00
0005432817952	9579	Economy	10900.00
0005432817959	9579	Economy	10900.00
0005432822333	9579	Economy	10900.00
0005432817957	9579	Economy	10900.00
0005434186213	9579	Economy	10900.00
0005432289042	9579	Economy	10900.00
0005432289041	9579	Economy	10900.00
0005432901764	9579	Economy	10900.00
0005434186229	9579	Economy	10900.00
0005432817940	9579	Economy	10900.00
0005432817947	9579	Economy	10900.00
0005434448329	28974	Business	32600.00
0005432817859	28974	Business	32600.00
0005432817639	28974	Business	32600.00
0005432822235	28974	Business	32600.00
0005432002110	28974	Business	32600.00
0005432817713	28974	Business	32600.00
0005434157603	28974	Business	32600.00
0005432901900	28974	Business	32600.00
0005434448331	28974	Economy	10900.00
0005432901899	28974	Economy	10900.00
0005434186246	28974	Economy	10900.00
0005432901897	28974	Economy	10900.00
0005434157605	28974	Economy	10900.00
0005434186245	28974	Economy	10900.00
0005434157609	28974	Economy	10900.00
0005432817773	28974	Economy	10900.00
0005432817809	28974	Economy	11900.00
0005434157604	28974	Economy	11900.00
0005432901893	28974	Economy	11900.00
0005432901892	28974	Economy	11900.00
0005432822238	28974	Economy	11900.00
0005434186244	28974	Economy	10900.00
0005432817756	28974	Economy	10900.00
0005432817712	28974	Economy	10900.00
0005432901888	28974	Economy	10900.00
0005432817693	28974	Economy	10900.00
0005432817769	28974	Economy	10900.00
0005432822284	28974	Economy	10900.00
0005432901891	28974	Economy	10900.00
0005434157611	28974	Economy	10900.00
0005434157608	28974	Economy	10900.00
0005432817653	28974	Economy	10900.00
0005432901894	28974	Economy	10900.00
0005432817725	28974	Economy	10900.00
0005432817690	28974	Economy	10900.00
0005432901889	28974	Economy	10900.00
0005432817761	28974	Economy	10900.00
0005434157606	28974	Economy	10900.00
0005432817638	28974	Economy	10900.00
0005434448330	28974	Economy	10900.00
0005432817732	28974	Economy	10900.00
0005432817497	28974	Economy	10900.00
0005432901890	28974	Economy	10900.00
0005432822283	28974	Economy	10900.00
0005432817654	28974	Economy	10900.00
0005432817669	28974	Economy	10900.00
0005432901901	28974	Economy	10900.00
0005432817748	28974	Economy	10900.00
0005432817774	28974	Economy	10900.00
0005432817670	28974	Economy	10900.00
0005432002111	28974	Economy	10900.00
0005432817655	28974	Economy	10900.00
0005432817711	28974	Economy	10900.00
0005432817731	28974	Economy	10900.00
0005432901903	28974	Economy	10900.00
0005432817650	28974	Economy	10900.00
0005432901902	28974	Economy	10900.00
0005432817733	28974	Economy	10900.00
0005434157610	28974	Economy	10900.00
0005432817671	28974	Economy	10900.00
0005432901898	28974	Economy	10900.00
0005432901895	28974	Economy	10900.00
0005432817757	28974	Economy	10900.00
0005432817739	28974	Economy	10900.00
0005432817649	28974	Economy	10900.00
0005434186247	28974	Economy	10900.00
0005432901896	28974	Economy	10900.00
0005432901904	28974	Economy	10900.00
0005432817677	28974	Economy	10900.00
0005432817577	28974	Economy	10900.00
0005432817621	28974	Economy	10900.00
0005434157607	28974	Economy	10900.00
0005434186243	28974	Economy	10900.00
0005432817648	28974	Economy	10900.00
0005435841826	15142	Economy	11000.00
0005432613927	15142	Economy	11000.00
0005432613930	15142	Economy	11000.00
0005432613929	15142	Economy	11000.00
0005432611771	15142	Economy	11000.00
0005435841099	15142	Economy	11000.00
0005432611772	15142	Economy	11000.00
0005432613928	15142	Economy	11000.00
0005432611770	15142	Economy	11000.00
0005435841830	15142	Economy	11000.00
0005435842340	31549	Economy	11000.00
0005432611746	31549	Economy	11000.00
0005435841835	31549	Economy	11000.00
0005432607585	31549	Economy	11000.00
0005432611748	31549	Economy	11000.00
0005435841836	31549	Economy	11000.00
0005435842339	31549	Economy	11000.00
0005432607583	31549	Economy	11000.00
0005432611747	31549	Economy	11000.00
0005432607584	31549	Economy	11000.00
0005432607578	31549	Economy	11000.00
0005435842341	31549	Economy	11000.00
0005432948669	11840	Business	105900.00
0005432948707	11840	Business	105900.00
0005433570020	11840	Business	105900.00
0005432948799	11840	Business	105900.00
0005433569996	11840	Business	105900.00
0005433569992	11840	Business	105900.00
0005433569976	11840	Business	105900.00
0005433569977	11840	Business	105900.00
0005432948660	11840	Business	105900.00
0005433569972	11840	Business	105900.00
0005433569978	11840	Business	105900.00
0005433569973	11840	Business	105900.00
0005433570024	11840	Business	105900.00
0005433570015	11840	Business	105900.00
0005433569981	11840	Business	105900.00
0005433569994	11840	Business	105900.00
0005433569979	11840	Business	105900.00
0005433569990	11840	Business	105900.00
0005432948607	11840	Economy	35300.00
0005432948760	11840	Business	105900.00
0005433569995	11840	Economy	35300.00
0005432948761	11840	Economy	35300.00
0005433570009	11840	Economy	35300.00
0005432948732	11840	Economy	35300.00
0005432948703	11840	Economy	35300.00
0005433570027	11840	Economy	35300.00
0005432948560	11840	Economy	35300.00
0005432948685	11840	Economy	35300.00
0005432948759	11840	Economy	35300.00
0005433570002	11840	Economy	35300.00
0005432948698	11840	Economy	38800.00
0005432948690	11840	Economy	38800.00
0005433569991	11840	Economy	38800.00
0005432948753	11840	Economy	38800.00
0005432948481	11840	Economy	35300.00
0005433570008	11840	Economy	35300.00
0005433569980	11840	Economy	35300.00
0005433569997	11840	Economy	35300.00
0005433569988	11840	Economy	35300.00
0005433569987	11840	Economy	35300.00
0005432948800	11840	Economy	35300.00
0005432948700	11840	Economy	35300.00
0005432948606	11840	Economy	35300.00
0005433570003	11840	Economy	35300.00
0005433570017	11840	Economy	35300.00
0005433569999	11840	Economy	35300.00
0005432948702	11840	Economy	35300.00
0005433570013	11840	Economy	35300.00
0005432948766	11840	Economy	35300.00
0005433570012	11840	Economy	35300.00
0005432948729	11840	Economy	35300.00
0005432948819	11840	Economy	35300.00
0005433570028	11840	Economy	35300.00
0005433570022	11840	Economy	35300.00
0005432948665	11840	Economy	35300.00
0005433569983	11840	Economy	35300.00
0005433570005	11840	Economy	35300.00
0005433570021	11840	Economy	35300.00
0005433569974	11840	Economy	35300.00
0005432948694	11840	Economy	35300.00
0005432948797	11840	Economy	35300.00
0005433570019	11840	Economy	35300.00
0005432948668	11840	Economy	35300.00
0005432948659	11840	Economy	35300.00
0005432948676	11840	Economy	35300.00
0005433570011	11840	Economy	35300.00
0005433570014	11840	Economy	35300.00
0005433570016	11840	Economy	35300.00
0005433570023	11840	Economy	35300.00
0005432948739	11840	Economy	35300.00
0005433570026	11840	Economy	35300.00
0005432948691	11840	Economy	35300.00
0005432948507	11840	Economy	35300.00
0005432948701	11840	Economy	35300.00
0005433570001	11840	Economy	35300.00
0005432948788	11840	Economy	35300.00
0005432948661	11840	Economy	35300.00
0005432948621	11840	Economy	35300.00
0005433569998	11840	Economy	35300.00
0005432948620	11840	Economy	35300.00
0005433569985	11840	Economy	35300.00
0005433570010	11840	Economy	35300.00
0005433569982	11840	Economy	35300.00
0005432948724	11840	Economy	35300.00
0005432948730	11840	Economy	35300.00
0005432948706	11840	Economy	35300.00
0005433570007	11840	Economy	35300.00
0005433569993	11840	Economy	35300.00
0005433569989	11840	Economy	35300.00
0005432948796	11840	Economy	35300.00
0005432948611	11840	Economy	35300.00
0005433569984	11840	Economy	35300.00
0005433570025	11840	Economy	35300.00
0005433570004	11840	Economy	35300.00
0005432948697	11840	Economy	35300.00
0005432948622	11840	Economy	35300.00
0005432948728	11840	Economy	35300.00
0005433569975	11840	Economy	35300.00
0005432948749	11840	Economy	35300.00
0005433570006	11840	Economy	35300.00
0005432948748	11840	Economy	35300.00
0005432948767	11840	Economy	35300.00
0005432948682	11840	Economy	35300.00
0005433570018	11840	Economy	35300.00
0005433569971	11840	Economy	35300.00
0005432948615	11840	Economy	35300.00
0005433569986	11840	Economy	35300.00
0005433570000	11840	Economy	35300.00
0005432949144	25282	Business	105900.00
0005432949180	25282	Business	105900.00
0005433569484	25282	Business	105900.00
0005433569344	25282	Business	105900.00
0005432949182	25282	Business	105900.00
0005432949177	25282	Business	105900.00
0005433569343	25282	Business	105900.00
0005433569488	25282	Business	105900.00
0005433569363	25282	Business	105900.00
0005433569371	25282	Business	105900.00
0005433569445	25282	Business	105900.00
0005432949172	25282	Business	105900.00
0005433569434	25282	Business	105900.00
0005432949155	25282	Business	105900.00
0005433569468	25282	Business	105900.00
0005433569387	25282	Business	105900.00
0005432949146	25282	Business	105900.00
0005433569483	25282	Business	105900.00
0005432949154	25282	Business	105900.00
0005433569372	25282	Economy	35300.00
0005433569362	25282	Economy	35300.00
0005433569381	25282	Economy	35300.00
0005433569460	25282	Economy	35300.00
0005433569425	25282	Economy	35300.00
0005433569453	25282	Economy	35300.00
0005433569336	25282	Economy	35300.00
0005433569274	25282	Economy	35300.00
0005432949173	25282	Economy	35300.00
0005433569384	25282	Economy	35300.00
0005433569444	25282	Economy	38800.00
0005432949143	25282	Economy	38800.00
0005433569373	25282	Economy	38800.00
0005432949153	25282	Economy	38800.00
0005433569395	25282	Economy	35300.00
0005433569480	25282	Economy	35300.00
0005433569374	25282	Economy	35300.00
0005433569494	25282	Economy	35300.00
0005433569275	25282	Economy	35300.00
0005432949174	25282	Economy	35300.00
0005432949152	25282	Economy	35300.00
0005432949158	25282	Economy	35300.00
0005433569421	25282	Economy	35300.00
0005433569447	25282	Economy	35300.00
0005433569370	25282	Economy	35300.00
0005433569246	25282	Economy	35300.00
0005432949168	25282	Economy	35300.00
0005432949166	25282	Economy	35300.00
0005432949163	25282	Economy	35300.00
0005432949164	25282	Economy	35300.00
0005432949171	25282	Economy	35300.00
0005433569459	25282	Economy	35300.00
0005432949167	25282	Economy	35300.00
0005432949181	25282	Economy	35300.00
0005432949156	25282	Economy	35300.00
0005432949170	25282	Economy	35300.00
0005433569513	25282	Economy	35300.00
0005432949175	25282	Economy	35300.00
0005433569380	25282	Economy	35300.00
0005432949179	25282	Economy	35300.00
0005433569392	25282	Economy	35300.00
0005433569340	25282	Economy	35300.00
0005433569247	25282	Economy	35300.00
0005432949159	25282	Economy	35300.00
0005433569511	25282	Economy	35300.00
0005432949165	25282	Economy	35300.00
0005432949145	25282	Economy	35300.00
0005433569493	25282	Economy	35300.00
0005433569454	25282	Economy	35300.00
0005433569458	25282	Economy	35300.00
0005433569443	25282	Economy	35300.00
0005432949147	25282	Economy	35300.00
0005433569518	25282	Economy	35300.00
0005433569342	25282	Economy	35300.00
0005433569446	25282	Economy	35300.00
0005432949148	25282	Economy	35300.00
0005433569334	25282	Economy	35300.00
0005433569364	25282	Economy	35300.00
0005432949178	25282	Economy	35300.00
0005432949160	25282	Economy	35300.00
0005432949149	25282	Economy	35300.00
0005433569361	25282	Economy	35300.00
0005432949161	25282	Economy	35300.00
0005432949142	25282	Economy	35300.00
0005433569237	25282	Economy	35300.00
0005433569541	25282	Economy	35300.00
0005432949150	25282	Economy	35300.00
0005432949151	25282	Economy	35300.00
0005432949176	25282	Economy	35300.00
0005432949157	25282	Economy	35300.00
0005432949141	25282	Economy	35300.00
0005433569427	25282	Economy	35300.00
0005432949169	25282	Economy	35300.00
0005433569526	25282	Economy	35300.00
0005433569402	25282	Economy	35300.00
0005433569337	25282	Economy	35300.00
0005433569457	25282	Economy	35300.00
0005432949140	25282	Economy	35300.00
0005432949162	25282	Economy	35300.00
0005433569481	25282	Economy	35300.00
0005433569339	25282	Economy	35300.00
0005434655176	5416	Business	67200.00
0005434655154	5416	Business	67200.00
0005434655169	5416	Business	67200.00
0005434655152	5416	Business	67200.00
0005435340387	5416	Business	67200.00
0005434655173	5416	Business	67200.00
0005435340354	5416	Business	67200.00
0005434655158	5416	Economy	22400.00
0005434655149	5416	Economy	22400.00
0005434655162	5416	Economy	22400.00
0005434655161	5416	Economy	22400.00
0005434656589	5416	Economy	22400.00
0005434655146	5416	Economy	22400.00
0005435340349	5416	Economy	22400.00
0005435340360	5416	Economy	24600.00
0005435340339	5416	Economy	24600.00
0005435340378	5416	Economy	22400.00
0005434655150	5416	Economy	22400.00
0005434655170	5416	Economy	22400.00
0005434656588	5416	Economy	22400.00
0005434655166	5416	Economy	22400.00
0005434655172	5416	Economy	22400.00
0005434655174	5416	Economy	22400.00
0005434655171	5416	Economy	22400.00
0005435340338	5416	Economy	22400.00
0005434655151	5416	Economy	22400.00
0005435340394	5416	Economy	22400.00
0005434655167	5416	Economy	22400.00
0005434655175	5416	Economy	22400.00
0005434655148	5416	Economy	22400.00
0005432114255	5416	Economy	22400.00
0005435555374	5416	Economy	22400.00
0005434655153	5416	Economy	22400.00
0005435340353	5416	Economy	22400.00
0005435340395	5416	Economy	22400.00
0005435340382	5416	Economy	22400.00
0005434655159	5416	Economy	22400.00
0005434655165	5416	Economy	22400.00
0005434655155	5416	Economy	22400.00
0005434655164	5416	Economy	22400.00
0005434655157	5416	Economy	22400.00
0005434655156	5416	Economy	22400.00
0005435340393	5416	Economy	22400.00
0005435340359	5416	Economy	22400.00
0005434655160	5416	Economy	22400.00
0005435340352	5416	Economy	22400.00
0005432114257	5416	Economy	22400.00
0005434656590	5416	Economy	22400.00
0005434655147	5416	Economy	22400.00
0005434655168	5416	Economy	22400.00
0005435340392	5416	Economy	22400.00
0005432114256	5416	Economy	22400.00
0005434655163	5416	Economy	22400.00
0005434654969	12518	Business	67200.00
0005434655015	12518	Business	67200.00
0005434654939	12518	Business	67200.00
0005435340516	12518	Business	67200.00
0005434654988	12518	Economy	22400.00
0005434654956	12518	Economy	22400.00
0005435340511	12518	Economy	22400.00
0005435340507	12518	Economy	22400.00
0005434654918	12518	Economy	24600.00
0005434654829	12518	Economy	22400.00
0005435555405	12518	Economy	22400.00
0005435340512	12518	Economy	22400.00
0005434654948	12518	Economy	22400.00
0005435340510	12518	Economy	22400.00
0005434654928	12518	Economy	22400.00
0005434654940	12518	Economy	22400.00
0005434654967	12518	Economy	22400.00
0005434655005	12518	Economy	22400.00
0005434654917	12518	Economy	22400.00
0005434654885	12518	Economy	22400.00
0005434654898	12518	Economy	22400.00
0005435340517	12518	Economy	22400.00
0005434654968	12518	Economy	22400.00
0005435340518	12518	Economy	22400.00
0005435340505	12518	Economy	22400.00
0005434654966	12518	Economy	22400.00
0005434656575	12518	Economy	22400.00
0005435340513	12518	Economy	22400.00
0005435555404	12518	Economy	22400.00
0005434654907	12518	Economy	22400.00
0005435340506	12518	Economy	22400.00
0005434654884	12518	Economy	22400.00
0005435340515	12518	Economy	22400.00
0005434654937	12518	Economy	22400.00
0005435340514	12518	Economy	22400.00
0005434655014	12518	Economy	22400.00
0005435340504	12518	Economy	22400.00
0005435340503	12518	Economy	22400.00
0005434654964	12518	Economy	22400.00
0005435340508	12518	Economy	22400.00
0005435340509	12518	Economy	22400.00
0005434654959	12518	Economy	22400.00
0005433716779	7434	Business	32000.00
0005433719195	7434	Business	32000.00
0005432078197	7434	Business	32000.00
0005433716796	7434	Business	32000.00
0005435266158	7434	Business	32000.00
0005433716771	7434	Business	32000.00
0005433716776	7434	Economy	10700.00
0005433716803	7434	Economy	10700.00
0005433716782	7434	Economy	10700.00
0005432078198	7434	Economy	10700.00
0005433722328	7434	Economy	10700.00
0005433716774	7434	Economy	10700.00
0005433716760	7434	Economy	10700.00
0005433716793	7434	Economy	10700.00
0005435266177	7434	Economy	10700.00
0005433688842	7434	Economy	10700.00
0005433716798	7434	Economy	10700.00
0005433719194	7434	Economy	10700.00
0005433690956	7434	Economy	10700.00
0005433716804	7434	Economy	10700.00
0005433656723	7434	Economy	10700.00
0005433716757	7434	Economy	10700.00
0005433722327	7434	Economy	10700.00
0005433716770	7434	Economy	10700.00
0005432428945	7434	Economy	10700.00
0005433689943	7434	Economy	10700.00
0005433716761	7434	Economy	10700.00
0005433719193	7434	Economy	10700.00
0005433716790	7434	Economy	10700.00
0005433716764	7434	Economy	10700.00
0005433722325	7434	Economy	10700.00
0005433722320	7434	Economy	10700.00
0005433722329	7434	Economy	10700.00
0005433690957	7434	Economy	10700.00
0005435266181	7434	Economy	11700.00
0005433716787	7434	Economy	11700.00
0005433722322	7434	Economy	11700.00
0005433716783	7434	Economy	11700.00
0005433716759	7434	Economy	10700.00
0005433716799	7434	Economy	10700.00
0005433716766	7434	Economy	10700.00
0005433716797	7434	Economy	10700.00
0005435266180	7434	Economy	10700.00
0005433716758	7434	Economy	10700.00
0005433656724	7434	Economy	10700.00
0005433719192	7434	Economy	10700.00
0005433722323	7434	Economy	10700.00
0005435266174	7434	Economy	10700.00
0005433716794	7434	Economy	10700.00
0005433716784	7434	Economy	10700.00
0005433716795	7434	Economy	10700.00
0005432078201	7434	Economy	10700.00
0005433716767	7434	Economy	10700.00
0005433716775	7434	Economy	10700.00
0005433722324	7434	Economy	10700.00
0005433716778	7434	Economy	10700.00
0005433716785	7434	Economy	10700.00
0005433716762	7434	Economy	10700.00
0005433716781	7434	Economy	10700.00
0005433716755	7434	Economy	10700.00
0005433716769	7434	Economy	10700.00
0005432078200	7434	Economy	10700.00
0005433716773	7434	Economy	10700.00
0005433716765	7434	Economy	10700.00
0005433716792	7434	Economy	10700.00
0005433716788	7434	Economy	10700.00
0005433716777	7434	Economy	10700.00
0005433656722	7434	Economy	10700.00
0005433716768	7434	Economy	10700.00
0005433716763	7434	Economy	10700.00
0005433716789	7434	Economy	10700.00
0005432078199	7434	Economy	10700.00
0005433722319	7434	Economy	10700.00
0005433689944	7434	Economy	10700.00
0005433716780	7434	Economy	10700.00
0005433716800	7434	Economy	10700.00
0005433716786	7434	Economy	10700.00
0005433716791	7434	Economy	10700.00
0005433722326	7434	Economy	10700.00
0005433716802	7434	Economy	10700.00
0005433716801	7434	Economy	10700.00
0005435266173	7434	Economy	10700.00
0005433716805	7434	Economy	10700.00
0005433722321	7434	Economy	10700.00
0005433716772	7434	Economy	10700.00
0005432078196	7434	Economy	10700.00
0005433716756	7434	Economy	10700.00
0005432006808	29242	Business	32000.00
0005433716191	29242	Business	32000.00
0005433716182	29242	Business	32000.00
0005433716403	29242	Business	32000.00
0005433716332	29242	Business	32000.00
0005433716372	29242	Business	32000.00
0005433722235	29242	Business	32000.00
0005432428986	29242	Business	32000.00
0005433722253	29242	Economy	10700.00
0005433722258	29242	Economy	10700.00
0005435266218	29242	Economy	10700.00
0005433716323	29242	Economy	10700.00
0005433716277	29242	Economy	10700.00
0005433716087	29242	Economy	10700.00
0005433722234	29242	Economy	10700.00
0005433716373	29242	Economy	10700.00
0005433716242	29242	Economy	10700.00
0005433716422	29242	Economy	10700.00
0005433722263	29242	Economy	10700.00
0005433716382	29242	Economy	10700.00
0005433722251	29242	Economy	10700.00
0005433716208	29242	Economy	10700.00
0005433722236	29242	Economy	10700.00
0005433716294	29242	Economy	10700.00
0005433716461	29242	Economy	10700.00
0005433716463	29242	Economy	10700.00
0005435266216	29242	Economy	10700.00
0005433716251	29242	Economy	10700.00
0005433722264	29242	Economy	10700.00
0005435266212	29242	Economy	10700.00
0005433716225	29242	Economy	10700.00
0005433716402	29242	Economy	10700.00
0005435266213	29242	Economy	10700.00
0005433716381	29242	Economy	10700.00
0005435266217	29242	Economy	10700.00
0005433722245	29242	Economy	10700.00
0005433716241	29242	Economy	11700.00
0005433716161	29242	Economy	11700.00
0005433716272	29242	Economy	11700.00
0005433716278	29242	Economy	10700.00
0005433716201	29242	Economy	10700.00
0005433716273	29242	Economy	10700.00
0005433716365	29242	Economy	10700.00
0005433656694	29242	Economy	10700.00
0005433716189	29242	Economy	10700.00
0005433719167	29242	Economy	10700.00
0005433716293	29242	Economy	10700.00
0005432428985	29242	Economy	10700.00
0005433656691	29242	Economy	10700.00
0005432006810	29242	Economy	10700.00
0005432006809	29242	Economy	10700.00
0005433716350	29242	Economy	10700.00
0005433722267	29242	Economy	10700.00
0005433722270	29242	Economy	10700.00
0005433716089	29242	Economy	10700.00
0005433722273	29242	Economy	10700.00
0005433722257	29242	Economy	10700.00
0005435266215	29242	Economy	10700.00
0005432428983	29242	Economy	10700.00
0005433716088	29242	Economy	10700.00
0005435266211	29242	Economy	10700.00
0005433716181	29242	Economy	10700.00
0005433716351	29242	Economy	10700.00
0005433716202	29242	Economy	10700.00
0005433716226	29242	Economy	10700.00
0005433716296	29242	Economy	10700.00
0005433716090	29242	Economy	10700.00
0005433716236	29242	Economy	10700.00
0005432428984	29242	Economy	10700.00
0005433716462	29242	Economy	10700.00
0005433716209	29242	Economy	10700.00
0005433716195	29242	Economy	10700.00
0005435266214	29242	Economy	10700.00
0005433716264	29242	Economy	10700.00
0005433716333	29242	Economy	10700.00
0005433722266	29242	Economy	10700.00
0005433716491	29242	Economy	10700.00
0005434182323	8694	Business	36500.00
0005434182356	8694	Business	36500.00
0005434095518	8694	Business	36500.00
0005434095517	8694	Economy	12200.00
0005434095507	8694	Economy	13400.00
0005434095514	8694	Economy	13400.00
0005434182307	8694	Economy	13400.00
0005434182324	8694	Economy	12200.00
0005434182313	8694	Economy	12200.00
0005434182217	8694	Economy	12200.00
0005434095506	8694	Economy	12200.00
0005434182310	8694	Economy	12200.00
0005434182282	8694	Economy	12200.00
0005434182281	8694	Economy	12200.00
0005434182269	8694	Economy	12200.00
0005434095510	8694	Economy	12200.00
0005434095504	8694	Economy	12200.00
0005434095512	8694	Economy	12200.00
0005434095513	8694	Economy	12200.00
0005434095516	8694	Economy	12200.00
0005434095505	8694	Economy	12200.00
0005434095515	8694	Economy	12200.00
0005434182306	8694	Economy	12200.00
0005434095508	8694	Economy	12200.00
0005434095511	8694	Economy	12200.00
0005434095509	8694	Economy	12200.00
0005434182322	8694	Economy	12200.00
0005434095388	11631	Business	36500.00
0005434095385	11631	Business	36500.00
0005434182385	11631	Business	36500.00
0005434182386	11631	Economy	12200.00
0005434095380	11631	Economy	12200.00
0005434095339	11631	Economy	12200.00
0005434095381	11631	Economy	12200.00
0005434095384	11631	Economy	13400.00
0005434095319	11631	Economy	13400.00
0005434095344	11631	Economy	12200.00
0005434182394	11631	Economy	12200.00
0005434182388	11631	Economy	12200.00
0005434183610	11631	Economy	12200.00
0005434182384	11631	Economy	12200.00
0005434182391	11631	Economy	12200.00
0005434183611	11631	Economy	12200.00
0005434143743	11631	Economy	12200.00
0005434095386	11631	Economy	12200.00
0005434095335	11631	Economy	12200.00
0005434182393	11631	Economy	12200.00
0005434182383	11631	Economy	12200.00
0005434095365	11631	Economy	12200.00
0005434182387	11631	Economy	12200.00
0005434182392	11631	Economy	12200.00
0005434095320	11631	Economy	12200.00
0005434184696	11631	Economy	12200.00
0005434182389	11631	Economy	12200.00
0005434182390	11631	Economy	12200.00
0005434095387	11631	Economy	12200.00
0005433398467	1427	Business	33000.00
0005435732539	1427	Business	33000.00
0005435732540	1427	Business	33000.00
0005433398604	1427	Business	33000.00
0005433398224	1427	Business	33000.00
0005435732544	1427	Business	33000.00
0005433457036	1427	Business	33000.00
0005435732543	1427	Business	33000.00
0005433398573	1427	Business	33000.00
0005433398504	1427	Business	33000.00
0005433398585	1427	Business	33000.00
0005432297321	1427	Economy	11000.00
0005433398452	1427	Economy	11000.00
0005433398477	1427	Economy	11000.00
0005433398476	1427	Economy	11000.00
0005435732538	1427	Economy	11000.00
0005433398433	1427	Economy	11000.00
0005433398354	1427	Economy	11000.00
0005433398357	1427	Economy	11000.00
0005433398605	1427	Economy	12100.00
0005433398603	1427	Economy	12100.00
0005432297319	1427	Economy	12100.00
0005433398413	1427	Economy	11000.00
0005433457037	1427	Economy	11000.00
0005433457035	1427	Economy	11000.00
0005433398352	1427	Economy	11000.00
0005432297320	1427	Economy	11000.00
0005433398607	1427	Economy	11000.00
0005433398484	1427	Economy	11000.00
0005433457033	1427	Economy	11000.00
0005433398572	1427	Economy	11000.00
0005433398593	1427	Economy	11000.00
0005435732545	1427	Economy	11000.00
0005433398470	1427	Economy	11000.00
0005433457034	1427	Economy	11000.00
0005433398475	1427	Economy	11000.00
0005433398248	1427	Economy	11000.00
0005433398414	1427	Economy	11000.00
0005433398328	1427	Economy	11000.00
0005433398410	1427	Economy	11000.00
0005433398435	1427	Economy	11000.00
0005433398247	1427	Economy	11000.00
0005433398602	1427	Economy	11000.00
0005433398479	1427	Economy	11000.00
0005433398225	1427	Economy	11000.00
0005433398434	1427	Economy	11000.00
0005433398478	1427	Economy	11000.00
0005433398353	1427	Economy	11000.00
0005433398280	1427	Economy	11000.00
0005433398097	1427	Economy	11000.00
0005433398454	1427	Economy	11000.00
0005433398608	1427	Economy	11000.00
0005433398310	1427	Economy	11000.00
0005433398606	1427	Economy	11000.00
0005433398372	1427	Economy	11000.00
0005433398227	1427	Economy	11000.00
0005435732541	1427	Economy	11000.00
0005433398574	1427	Economy	11000.00
0005433398275	1427	Economy	11000.00
0005433398386	1427	Economy	11000.00
0005433398432	1427	Economy	11000.00
0005433398358	1427	Economy	11000.00
0005433398371	1427	Economy	11000.00
0005433398226	1427	Economy	11000.00
0005433398437	1427	Economy	11000.00
0005433398344	1427	Economy	11000.00
0005433398366	1427	Economy	11000.00
0005433398468	1427	Economy	11000.00
0005433398524	1427	Economy	11000.00
0005433398362	1427	Economy	11000.00
0005435732542	1427	Economy	11000.00
0005433398278	1427	Economy	11000.00
0005433398825	19265	Business	33000.00
0005433398841	19265	Business	33000.00
0005433398833	19265	Business	33000.00
0005433398865	19265	Business	33000.00
0005435732447	19265	Business	33000.00
0005433398821	19265	Business	33000.00
0005433398855	19265	Business	33000.00
0005433398840	19265	Business	33000.00
0005433398849	19265	Business	33000.00
0005433457014	19265	Business	33000.00
0005433398846	19265	Economy	11000.00
0005433398835	19265	Economy	11000.00
0005433398861	19265	Economy	11000.00
0005433398836	19265	Economy	11000.00
0005433398831	19265	Economy	11000.00
0005433398867	19265	Economy	11000.00
0005433398862	19265	Economy	11000.00
0005433398845	19265	Economy	12100.00
0005435732400	19265	Economy	12100.00
0005433398848	19265	Economy	12100.00
0005435732407	19265	Economy	12100.00
0005433398866	19265	Economy	12100.00
0005433398857	19265	Economy	11000.00
0005433398854	19265	Economy	11000.00
0005433398823	19265	Economy	11000.00
0005433398832	19265	Economy	11000.00
0005433398830	19265	Economy	11000.00
0005433398826	19265	Economy	11000.00
0005435732420	19265	Economy	11000.00
0005433398842	19265	Economy	11000.00
0005435732480	19265	Economy	11000.00
0005433398829	19265	Economy	11000.00
0005433398852	19265	Economy	11000.00
0005433398843	19265	Economy	11000.00
0005433398828	19265	Economy	11000.00
0005433398827	19265	Economy	11000.00
0005433398834	19265	Economy	11000.00
0005433398838	19265	Economy	11000.00
0005435732370	19265	Economy	11000.00
0005435732408	19265	Economy	11000.00
0005433398860	19265	Economy	11000.00
0005435732401	19265	Economy	11000.00
0005433457011	19265	Economy	11000.00
0005433398856	19265	Economy	11000.00
0005433398853	19265	Economy	11000.00
0005433398822	19265	Economy	11000.00
0005432906576	19265	Economy	11000.00
0005433398851	19265	Economy	11000.00
0005435732434	19265	Economy	11000.00
0005433398844	19265	Economy	11000.00
0005435732457	19265	Economy	11000.00
0005433398858	19265	Economy	11000.00
0005433398824	19265	Economy	11000.00
0005435732475	19265	Economy	11000.00
0005435732455	19265	Economy	11000.00
0005435732394	19265	Economy	11000.00
0005432906575	19265	Economy	11000.00
0005433398839	19265	Economy	11000.00
0005433398837	19265	Economy	11000.00
0005435732481	19265	Economy	11000.00
0005433398863	19265	Economy	11000.00
0005433398859	19265	Economy	11000.00
0005433398847	19265	Economy	11000.00
0005433398820	19265	Economy	11000.00
0005433398864	19265	Economy	11000.00
0005433398850	19265	Economy	11000.00
0005435732396	19265	Economy	11000.00
0005435732432	19265	Economy	11000.00
0005433398868	19265	Economy	11000.00
0005435732456	19265	Economy	11000.00
0005433398819	19265	Economy	11000.00
0005435732451	19265	Economy	11000.00
0005434443828	17354	Economy	15600.00
0005434443853	17354	Economy	15600.00
0005434443841	17354	Economy	15600.00
0005434443810	17354	Economy	14100.00
0005434443765	17354	Economy	14100.00
0005434443860	17354	Economy	14100.00
0005434443789	17354	Economy	14100.00
0005434443834	17354	Economy	14100.00
0005434443830	17354	Economy	14100.00
0005434443883	17354	Economy	14100.00
0005434443811	17354	Economy	14100.00
0005434443845	17354	Economy	14100.00
0005434443820	17354	Economy	14100.00
0005434443795	17354	Economy	14100.00
0005434443848	17354	Economy	14100.00
0005434443833	17354	Economy	14100.00
0005434443821	17354	Economy	14100.00
0005434443863	17354	Economy	14100.00
0005434443861	17354	Economy	14100.00
0005434443832	17354	Economy	14100.00
0005434443839	17354	Economy	14100.00
0005434443894	17354	Economy	14100.00
0005434443788	17354	Economy	14100.00
0005434443831	17354	Economy	14100.00
0005434443882	17354	Economy	14100.00
0005434443962	20569	Economy	15600.00
0005434443961	20569	Economy	14100.00
0005434443965	20569	Economy	14100.00
0005434443968	20569	Economy	14100.00
0005434443966	20569	Economy	14100.00
0005434443959	20569	Economy	14100.00
0005434443963	20569	Economy	14100.00
0005434443967	20569	Economy	14100.00
0005434443958	20569	Economy	14100.00
0005434443953	20569	Economy	14100.00
0005434443964	20569	Economy	14100.00
0005434443954	20569	Economy	14100.00
0005434443955	20569	Economy	14100.00
0005434443960	20569	Economy	14100.00
0005434443956	20569	Economy	14100.00
0005434443957	20569	Economy	14100.00
0005434954673	7252	Economy	5800.00
0005434954674	7252	Economy	5800.00
0005434954642	28321	Economy	5800.00
0005434954643	28321	Economy	5800.00
0005435377619	28321	Economy	5800.00
0005434351898	4449	Economy	15400.00
0005434351896	4449	Economy	15400.00
0005434351904	4449	Economy	14000.00
0005434351908	4449	Economy	14000.00
0005435893695	4449	Economy	14000.00
0005434351897	4449	Economy	14000.00
0005434351903	4449	Economy	14000.00
0005435893686	4449	Economy	14000.00
0005435893696	4449	Economy	14000.00
0005435893689	4449	Economy	14000.00
0005434351906	4449	Economy	14000.00
0005435893679	4449	Economy	14000.00
0005435893672	4449	Economy	14000.00
0005434351907	4449	Economy	14000.00
0005435893683	4449	Economy	14000.00
0005435893726	4449	Economy	14000.00
0005434351909	4449	Economy	14000.00
0005434351905	4449	Economy	14000.00
0005434351901	4449	Economy	14000.00
0005434351902	4449	Economy	14000.00
0005434351900	4449	Economy	14000.00
0005435893687	4449	Economy	14000.00
0005435893690	4449	Economy	14000.00
0005434351899	4449	Economy	14000.00
0005434351771	29657	Economy	15400.00
0005435893747	29657	Economy	15400.00
0005434351798	29657	Economy	15400.00
0005434351773	29657	Economy	14000.00
0005435893746	29657	Economy	14000.00
0005434351770	29657	Economy	14000.00
0005434351766	29657	Economy	14000.00
0005434351762	29657	Economy	14000.00
0005434351817	29657	Economy	14000.00
0005435893748	29657	Economy	14000.00
0005434351799	29657	Economy	14000.00
0005434351821	29657	Economy	14000.00
0005435893750	29657	Economy	14000.00
0005434351814	29657	Economy	14000.00
0005434351774	29657	Economy	14000.00
0005435893744	29657	Economy	14000.00
0005434351795	29657	Economy	14000.00
0005434351796	29657	Economy	14000.00
0005435893745	29657	Economy	14000.00
0005434351813	29657	Economy	14000.00
0005434351785	29657	Economy	14000.00
0005434351797	29657	Economy	14000.00
0005434351820	29657	Economy	14000.00
0005435893749	29657	Economy	14000.00
0005435092232	1080	Business	30600.00
0005433159339	1080	Business	30600.00
0005433343601	1080	Business	30600.00
0005435545856	1080	Business	30600.00
0005433462782	1080	Business	30600.00
0005433344193	1080	Business	30600.00
0005434445279	1080	Business	30600.00
0005433269769	1080	Business	30600.00
0005435092236	1080	Business	30600.00
0005432293248	1080	Business	30600.00
0005433343710	1080	Business	30600.00
0005433344086	1080	Business	30600.00
0005433343458	1080	Business	30600.00
0005433343760	1080	Business	30600.00
0005435092239	1080	Business	30600.00
0005435545857	1080	Business	30600.00
0005435545853	1080	Business	30600.00
0005435092238	1080	Business	30600.00
0005433269752	1080	Business	30600.00
0005433343478	1080	Business	30600.00
0005433343995	1080	Business	30600.00
0005433158149	1080	Economy	11200.00
0005433463937	1080	Economy	11200.00
0005433269771	1080	Economy	10200.00
0005433343813	1080	Economy	10200.00
0005433344046	1080	Economy	10200.00
0005434445280	1080	Economy	10200.00
0005433343759	1080	Economy	10200.00
0005433343642	1080	Economy	10200.00
0005433343467	1080	Economy	10200.00
0005433343876	1080	Economy	10200.00
0005433343599	1080	Economy	10200.00
0005433343904	1080	Economy	10200.00
0005434446557	1080	Economy	10200.00
0005433343926	1080	Economy	10200.00
0005433343888	1080	Economy	10200.00
0005433343722	1080	Economy	10200.00
0005433343825	1080	Economy	10200.00
0005433343803	1080	Economy	10200.00
0005433344247	1080	Economy	10200.00
0005433343856	1080	Economy	10200.00
0005433269770	1080	Economy	10200.00
0005433343617	1080	Economy	10200.00
0005433344076	1080	Economy	10200.00
0005435545855	1080	Economy	10200.00
0005433343168	1080	Economy	10200.00
0005433343934	1080	Economy	10200.00
0005433343814	1080	Economy	10200.00
0005433344429	1080	Economy	10200.00
0005433463936	1080	Economy	10200.00
0005433269750	1080	Economy	10200.00
0005435092231	1080	Economy	10200.00
0005433343327	1080	Economy	10200.00
0005433344015	1080	Economy	10200.00
0005433343809	1080	Economy	10200.00
0005433343764	1080	Economy	10200.00
0005433343828	1080	Economy	10200.00
0005433343912	1080	Economy	10200.00
0005433343269	1080	Economy	10200.00
0005435545863	1080	Economy	10200.00
0005435092233	1080	Economy	10200.00
0005433463935	1080	Economy	10200.00
0005433343618	1080	Economy	10200.00
0005433343844	1080	Economy	10200.00
0005433343875	1080	Economy	10200.00
0005433343395	1080	Economy	10200.00
0005433343860	1080	Economy	10200.00
0005433344246	1080	Economy	10200.00
0005435545860	1080	Economy	10200.00
0005433343524	1080	Economy	10200.00
0005433343997	1080	Economy	10200.00
0005433344519	1080	Economy	10200.00
0005433343457	1080	Economy	10200.00
0005433269762	1080	Economy	10200.00
0005435092235	1080	Economy	10200.00
0005433343451	1080	Economy	10200.00
0005434446556	1080	Economy	10200.00
0005433344078	1080	Economy	10200.00
0005433343865	1080	Economy	10200.00
0005433343917	1080	Economy	10200.00
0005435092234	1080	Economy	10200.00
0005433343634	1080	Economy	10200.00
0005433344520	1080	Economy	10200.00
0005433344039	1080	Economy	10200.00
0005433343422	1080	Economy	10200.00
0005432293247	1080	Economy	10200.00
0005433343994	1080	Economy	10200.00
0005433343600	1080	Economy	10200.00
0005433343782	1080	Economy	11200.00
0005433343578	1080	Economy	10200.00
0005433343631	1080	Economy	11200.00
0005433343843	1080	Economy	11200.00
0005433343978	1080	Economy	10200.00
0005433343721	1080	Economy	10200.00
0005435545859	1080	Economy	10200.00
0005433344318	1080	Economy	10200.00
0005433269759	1080	Economy	10200.00
0005433344077	1080	Economy	10200.00
0005433343704	1080	Economy	10200.00
0005433343703	1080	Economy	10200.00
0005433343925	1080	Economy	10200.00
0005433343979	1080	Economy	10200.00
0005433343883	1080	Economy	10200.00
0005433343882	1080	Economy	10200.00
0005433343829	1080	Economy	10200.00
0005433343671	1080	Economy	10200.00
0005433343723	1080	Economy	10200.00
0005435545865	1080	Economy	10200.00
0005433343581	1080	Economy	10200.00
0005433343826	1080	Economy	10200.00
0005434445278	1080	Economy	10200.00
0005433343817	1080	Economy	10200.00
0005435545862	1080	Economy	10200.00
0005433343847	1080	Economy	10200.00
0005433343672	1080	Economy	10200.00
0005433344018	1080	Economy	10200.00
0005435545854	1080	Economy	10200.00
0005433343802	1080	Economy	10200.00
0005433343861	1080	Economy	10200.00
0005435092237	1080	Economy	10200.00
0005434446555	1080	Economy	10200.00
0005433343745	1080	Economy	10200.00
0005433344037	1080	Economy	10200.00
0005433343523	1080	Economy	10200.00
0005433343354	1080	Economy	10200.00
0005435545858	1080	Economy	10200.00
0005433343911	1080	Economy	10200.00
0005433343720	1080	Economy	10200.00
0005433343394	1080	Economy	10200.00
0005434445281	1080	Economy	10200.00
0005435092240	1080	Economy	10200.00
0005435545864	1080	Economy	10200.00
0005433159325	1080	Economy	10200.00
0005433344194	1080	Economy	10200.00
0005433343756	1080	Economy	10200.00
0005433343466	1080	Economy	10200.00
0005433269760	1080	Economy	10200.00
0005433343355	1080	Economy	10200.00
0005435545861	1080	Economy	10200.00
0005433344710	17054	Business	30600.00
0005433269808	17054	Business	30600.00
0005433344644	17054	Business	30600.00
0005433344681	17054	Business	30600.00
0005433344643	17054	Business	30600.00
0005433344656	17054	Business	30600.00
0005433344719	17054	Business	30600.00
0005435508446	17054	Business	30600.00
0005433344686	17054	Business	30600.00
0005433344732	17054	Business	30600.00
0005433344638	17054	Business	30600.00
0005433344708	17054	Business	30600.00
0005433344726	17054	Business	30600.00
0005435508420	17054	Business	30600.00
0005433344661	17054	Business	30600.00
0005433344669	17054	Business	30600.00
0005433344663	17054	Business	30600.00
0005433344735	17054	Business	30600.00
0005433344671	17054	Business	30600.00
0005433159348	17054	Economy	11200.00
0005433344677	17054	Economy	11200.00
0005433344636	17054	Economy	10200.00
0005433344701	17054	Economy	10200.00
0005435092138	17054	Economy	10200.00
0005435092157	17054	Economy	10200.00
0005433344702	17054	Economy	10200.00
0005433344727	17054	Economy	10200.00
0005433344672	17054	Economy	10200.00
0005435508444	17054	Economy	10200.00
0005435508429	17054	Economy	10200.00
0005435092183	17054	Economy	10200.00
0005433344653	17054	Economy	10200.00
0005433344685	17054	Economy	10200.00
0005433344639	17054	Economy	10200.00
0005433344647	17054	Economy	10200.00
0005433344658	17054	Economy	10200.00
0005433344736	17054	Economy	10200.00
0005435092156	17054	Economy	10200.00
0005435092187	17054	Economy	10200.00
0005433344670	17054	Economy	10200.00
0005433344687	17054	Economy	10200.00
0005435508401	17054	Economy	10200.00
0005435092178	17054	Economy	10200.00
0005433344655	17054	Economy	10200.00
0005433344654	17054	Economy	10200.00
0005433344659	17054	Economy	10200.00
0005433344721	17054	Economy	10200.00
0005433344722	17054	Economy	10200.00
0005433344667	17054	Economy	10200.00
0005433344704	17054	Economy	10200.00
0005433344682	17054	Economy	10200.00
0005433344731	17054	Economy	10200.00
0005433344717	17054	Economy	10200.00
0005433344716	17054	Economy	10200.00
0005433344698	17054	Economy	10200.00
0005433159347	17054	Economy	10200.00
0005433159349	17054	Economy	10200.00
0005433344725	17054	Economy	10200.00
0005435508424	17054	Economy	10200.00
0005433344720	17054	Economy	10200.00
0005433344715	17054	Economy	10200.00
0005435508400	17054	Economy	10200.00
0005433344674	17054	Economy	10200.00
0005433344641	17054	Economy	10200.00
0005433344642	17054	Economy	10200.00
0005433344684	17054	Economy	10200.00
0005433344664	17054	Economy	10200.00
0005433344694	17054	Economy	10200.00
0005435508434	17054	Economy	10200.00
0005433269807	17054	Economy	10200.00
0005433344729	17054	Economy	10200.00
0005433269805	17054	Economy	10200.00
0005433344680	17054	Economy	10200.00
0005433344723	17054	Economy	10200.00
0005435092184	17054	Economy	10200.00
0005433344678	17054	Economy	10200.00
0005433344649	17054	Economy	10200.00
0005433344718	17054	Economy	10200.00
0005435092185	17054	Economy	10200.00
0005435508427	17054	Economy	10200.00
0005433344724	17054	Economy	10200.00
0005433344691	17054	Economy	10200.00
0005433344673	17054	Economy	10200.00
0005433344666	17054	Economy	10200.00
0005433344650	17054	Economy	11200.00
0005433344668	17054	Economy	10200.00
0005433344700	17054	Economy	11200.00
0005433344730	17054	Economy	10200.00
0005433344713	17054	Economy	10200.00
0005433344692	17054	Economy	10200.00
0005433344683	17054	Economy	10200.00
0005433344648	17054	Economy	10200.00
0005435508406	17054	Economy	10200.00
0005433344660	17054	Economy	10200.00
0005433344693	17054	Economy	10200.00
0005433344711	17054	Economy	10200.00
0005433344707	17054	Economy	10200.00
0005433344640	17054	Economy	10200.00
0005433344689	17054	Economy	10200.00
0005435092192	17054	Economy	10200.00
0005433344688	17054	Economy	10200.00
0005433344696	17054	Economy	10200.00
0005435092186	17054	Economy	10200.00
0005433344657	17054	Economy	10200.00
0005433344652	17054	Economy	10200.00
0005433344646	17054	Economy	10200.00
0005433344712	17054	Economy	10200.00
0005433269806	17054	Economy	10200.00
0005433344662	17054	Economy	10200.00
0005433344737	17054	Economy	10200.00
0005433344695	17054	Economy	10200.00
0005433344733	17054	Economy	10200.00
0005435092139	17054	Economy	10200.00
0005433344709	17054	Economy	10200.00
0005433344714	17054	Economy	10200.00
0005435092161	17054	Economy	10200.00
0005433344734	17054	Economy	10200.00
0005433344679	17054	Economy	10200.00
0005433344690	17054	Economy	10200.00
0005433344676	17054	Economy	10200.00
0005433344706	17054	Economy	10200.00
0005433344637	17054	Economy	10200.00
0005433344703	17054	Economy	10200.00
0005435508428	17054	Economy	10200.00
0005435508445	17054	Economy	10200.00
0005433344651	17054	Economy	10200.00
0005433344705	17054	Economy	10200.00
0005433344675	17054	Economy	10200.00
0005433344645	17054	Economy	10200.00
0005433344699	17054	Economy	10200.00
0005433344665	17054	Economy	10200.00
0005433344728	17054	Economy	10200.00
0005433344697	17054	Economy	10200.00
0005434082033	12788	Business	40300.00
0005432159934	12788	Business	40300.00
0005434067860	12788	Business	40300.00
0005434082062	12788	Business	40300.00
0005434082152	12788	Business	40300.00
0005434068181	12788	Business	40300.00
0005434068230	12788	Business	40300.00
0005434082002	12788	Business	40300.00
0005434068237	12788	Business	40300.00
0005434067808	12788	Business	40300.00
0005434068072	12788	Economy	13400.00
0005434067869	12788	Economy	13400.00
0005432161189	12788	Economy	13400.00
0005432159932	12788	Economy	13400.00
0005433989803	12788	Economy	13400.00
0005432159931	12788	Economy	13400.00
0005432159933	12788	Economy	13400.00
0005432159935	12788	Economy	13400.00
0005434068064	12788	Economy	13400.00
0005434068161	12788	Economy	13400.00
0005434068126	12788	Economy	13400.00
0005434067960	12788	Economy	13400.00
0005434068038	12788	Economy	13400.00
0005434082067	12788	Economy	13400.00
0005434067924	12788	Economy	13400.00
0005435283419	12788	Economy	13400.00
0005432159930	12788	Economy	13400.00
0005434082122	12788	Economy	13400.00
0005434067583	12788	Economy	13400.00
0005434068062	12788	Economy	13400.00
0005434082038	12788	Economy	13400.00
0005434082032	12788	Economy	13400.00
0005434067716	12788	Economy	13400.00
0005434082042	12788	Economy	13400.00
0005434067952	12788	Economy	13400.00
0005434067754	12788	Economy	13400.00
0005434067922	12788	Economy	13400.00
0005434082020	12788	Economy	13400.00
0005434067582	12788	Economy	13400.00
0005432433768	12788	Economy	13400.00
0005434067897	12788	Economy	13400.00
0005434068053	12788	Economy	13400.00
0005434081993	12788	Economy	13400.00
0005435283416	12788	Economy	13400.00
0005434068041	12788	Economy	13400.00
0005434068153	12788	Economy	13400.00
0005434067844	12788	Economy	14800.00
0005434068129	12788	Economy	14800.00
0005434082153	12788	Economy	14800.00
0005434068097	12788	Economy	14800.00
0005434068188	12788	Economy	13400.00
0005432433769	12788	Economy	13400.00
0005434081939	12788	Economy	13400.00
0005434067643	12788	Economy	13400.00
0005434068359	12788	Economy	13400.00
0005434067905	12788	Economy	13400.00
0005434068000	12788	Economy	13400.00
0005434067925	12788	Economy	13400.00
0005434082076	12788	Economy	13400.00
0005434068136	12788	Economy	13400.00
0005434067859	12788	Economy	13400.00
0005434082003	12788	Economy	13400.00
0005434082075	12788	Economy	13400.00
0005434068137	12788	Economy	13400.00
0005434068194	12788	Economy	13400.00
0005434067944	12788	Economy	13400.00
0005434067715	12788	Economy	13400.00
0005434067717	12788	Economy	13400.00
0005432433767	12788	Economy	13400.00
0005435283417	12788	Economy	13400.00
0005433812939	12788	Economy	13400.00
0005434067874	12788	Economy	13400.00
0005434068253	12788	Economy	13400.00
0005434068105	12788	Economy	13400.00
0005434068233	12788	Economy	13400.00
0005434067581	12788	Economy	13400.00
0005434067871	12788	Economy	13400.00
0005434067913	12788	Economy	13400.00
0005434082114	12788	Economy	13400.00
0005432433766	12788	Economy	13400.00
0005434068024	12788	Economy	13400.00
0005432433765	12788	Economy	13400.00
0005434068107	12788	Economy	13400.00
0005434068140	12788	Economy	13400.00
0005434068139	12788	Economy	13400.00
0005434082019	12788	Economy	13400.00
0005434068095	12788	Economy	13400.00
0005434082009	12788	Economy	13400.00
0005434067891	12788	Economy	13400.00
0005433989784	12788	Economy	13400.00
0005435283418	12788	Economy	13400.00
0005434067997	12788	Economy	13400.00
0005432161190	12788	Economy	13400.00
0005434067923	12788	Economy	13400.00
0005434067938	12788	Economy	13400.00
0005434082066	12788	Economy	13400.00
0005433989811	12788	Economy	13400.00
0005434082018	12788	Economy	13400.00
0005434067870	12788	Economy	13400.00
0005434067946	12788	Economy	13400.00
0005434067945	12788	Economy	13400.00
0005434068324	12788	Economy	13400.00
0005434068067	12788	Economy	13400.00
0005434067926	12788	Economy	13400.00
0005434068063	12788	Economy	13400.00
0005434082121	12788	Economy	13400.00
0005434067890	12788	Economy	13400.00
0005434082115	12788	Economy	13400.00
0005434068189	12788	Economy	13400.00
0005434068162	12788	Economy	13400.00
0005433812940	12788	Economy	13400.00
0005434082117	12788	Economy	13400.00
0005434068094	12788	Economy	13400.00
0005434068360	12788	Economy	13400.00
0005434068066	12788	Economy	13400.00
0005434068687	30685	Business	40300.00
0005434068675	30685	Business	40300.00
0005434068676	30685	Business	40300.00
0005434068654	30685	Business	40300.00
0005432186925	30685	Business	40300.00
0005434068639	30685	Business	40300.00
0005434068665	30685	Business	40300.00
0005434068634	30685	Business	40300.00
0005434068666	30685	Business	40300.00
0005434068679	30685	Economy	13400.00
0005434068638	30685	Business	40300.00
0005432186924	30685	Economy	13400.00
0005432150316	30685	Economy	13400.00
0005433812900	30685	Economy	13400.00
0005434026735	30685	Economy	13400.00
0005434068690	30685	Economy	13400.00
0005434068664	30685	Economy	13400.00
0005434026732	30685	Economy	13400.00
0005434068685	30685	Economy	13400.00
0005434068671	30685	Economy	13400.00
0005434068627	30685	Economy	13400.00
0005433812913	30685	Economy	13400.00
0005434068682	30685	Economy	13400.00
0005434068624	30685	Economy	13400.00
0005434068642	30685	Economy	13400.00
0005434068640	30685	Economy	13400.00
0005434068652	30685	Economy	13400.00
0005434082252	30685	Economy	13400.00
0005434068625	30685	Economy	13400.00
0005433812899	30685	Economy	13400.00
0005434026736	30685	Economy	13400.00
0005434026733	30685	Economy	13400.00
0005432433730	30685	Economy	13400.00
0005434068683	30685	Economy	13400.00
0005434068659	30685	Economy	13400.00
0005434068636	30685	Economy	13400.00
0005432150317	30685	Economy	13400.00
0005434068643	30685	Economy	13400.00
0005434068619	30685	Economy	13400.00
0005434068684	30685	Economy	13400.00
0005434068633	30685	Economy	13400.00
0005434026731	30685	Economy	13400.00
0005434068621	30685	Economy	13400.00
0005433812902	30685	Economy	13400.00
0005434068646	30685	Economy	13400.00
0005433989846	30685	Economy	13400.00
0005434068651	30685	Economy	13400.00
0005434068660	30685	Economy	13400.00
0005434068658	30685	Economy	14800.00
0005434082259	30685	Economy	14800.00
0005434082255	30685	Economy	14800.00
0005434068674	30685	Economy	14800.00
0005434082258	30685	Economy	14800.00
0005434026730	30685	Economy	14800.00
0005434068678	30685	Economy	13400.00
0005432150318	30685	Economy	13400.00
0005432186926	30685	Economy	13400.00
0005434068629	30685	Economy	13400.00
0005434068631	30685	Economy	13400.00
0005434082257	30685	Economy	13400.00
0005434068661	30685	Economy	13400.00
0005434068677	30685	Economy	13400.00
0005434082260	30685	Economy	13400.00
0005434068635	30685	Economy	13400.00
0005434068626	30685	Economy	13400.00
0005434068648	30685	Economy	13400.00
0005434068650	30685	Economy	13400.00
0005434068686	30685	Economy	13400.00
0005434068669	30685	Economy	13400.00
0005434068632	30685	Economy	13400.00
0005434068620	30685	Economy	13400.00
0005433812901	30685	Economy	13400.00
0005434068641	30685	Economy	13400.00
0005434026734	30685	Economy	13400.00
0005433812903	30685	Economy	13400.00
0005434068628	30685	Economy	13400.00
0005434068630	30685	Economy	13400.00
0005434068655	30685	Economy	13400.00
0005434026729	30685	Economy	13400.00
0005432150313	30685	Economy	13400.00
0005434068637	30685	Economy	13400.00
0005432150314	30685	Economy	13400.00
0005434082250	30685	Economy	13400.00
0005434068672	30685	Economy	13400.00
0005434082253	30685	Economy	13400.00
0005433812904	30685	Economy	13400.00
0005433989842	30685	Economy	13400.00
0005434068649	30685	Economy	13400.00
0005432433732	30685	Economy	13400.00
0005434068662	30685	Economy	13400.00
0005434068647	30685	Economy	13400.00
0005434068680	30685	Economy	13400.00
0005434068667	30685	Economy	13400.00
0005432433731	30685	Economy	13400.00
0005434068645	30685	Economy	13400.00
0005432150315	30685	Economy	13400.00
0005432433733	30685	Economy	13400.00
0005434082254	30685	Economy	13400.00
0005434068670	30685	Economy	13400.00
0005434068689	30685	Economy	13400.00
0005434068623	30685	Economy	13400.00
0005434082251	30685	Economy	13400.00
0005433989844	30685	Economy	13400.00
0005432150319	30685	Economy	13400.00
0005434068663	30685	Economy	13400.00
0005433812906	30685	Economy	13400.00
0005434068622	30685	Economy	13400.00
0005432433729	30685	Economy	13400.00
0005434068668	30685	Economy	13400.00
0005434068657	30685	Economy	13400.00
0005434068653	30685	Economy	13400.00
0005434068656	30685	Economy	13400.00
0005434068673	30685	Economy	13400.00
0005433989845	30685	Economy	13400.00
0005433989843	30685	Economy	13400.00
0005434082261	30685	Economy	13400.00
0005432433707	30685	Economy	13400.00
0005434068681	30685	Economy	13400.00
0005433812910	30685	Economy	13400.00
0005434082256	30685	Economy	13400.00
0005434068688	30685	Economy	13400.00
0005434068644	30685	Economy	13400.00
0005435720842	5498	Business	35300.00
0005435462667	5498	Business	35300.00
0005435735209	5498	Business	35300.00
0005435462749	5498	Business	35300.00
0005434265387	5498	Business	35300.00
0005435462834	5498	Business	35300.00
0005435735211	5498	Business	35300.00
0005432535884	5498	Business	35300.00
0005435462640	5498	Business	35300.00
0005433527332	5498	Business	35300.00
0005435767216	5498	Business	35300.00
0005434265283	5498	Business	35300.00
0005435767206	5498	Business	35300.00
0005435462627	5498	Business	35300.00
0005433527328	5498	Business	35300.00
0005433527330	5498	Business	35300.00
0005435462639	5498	Business	35300.00
0005434265404	5498	Business	35300.00
0005432140583	5498	Business	35300.00
0005433527331	5498	Business	35300.00
0005435767217	5498	Business	35300.00
0005435462797	5498	Business	35300.00
0005434265312	5498	Business	35300.00
0005435767185	5498	Business	35300.00
0005435767222	5498	Business	35300.00
0005435767204	5498	Economy	12900.00
0005434265323	5498	Economy	12900.00
0005435462709	5498	Economy	12900.00
0005435767162	5498	Economy	12900.00
0005435462878	5498	Economy	11800.00
0005435722093	5498	Economy	11800.00
0005435767163	5498	Economy	11800.00
0005435767212	5498	Economy	11800.00
0005434265285	5498	Economy	11800.00
0005435767203	5498	Economy	11800.00
0005433529344	5498	Economy	11800.00
0005435767198	5498	Economy	11800.00
0005435725677	5498	Economy	11800.00
0005434265347	5498	Economy	11800.00
0005435767220	5498	Economy	11800.00
0005435767169	5498	Economy	11800.00
0005435725679	5498	Economy	11800.00
0005432140582	5498	Economy	11800.00
0005435043291	5498	Economy	11800.00
0005435043288	5498	Economy	11800.00
0005435767174	5498	Economy	11800.00
0005435462676	5498	Economy	11800.00
0005434265289	5498	Economy	11800.00
0005435462852	5498	Economy	11800.00
0005433529341	5498	Economy	11800.00
0005435462698	5498	Economy	11800.00
0005435767221	5498	Economy	11800.00
0005435723078	5498	Economy	11800.00
0005435767223	5498	Economy	11800.00
0005435462744	5498	Economy	11800.00
0005435767202	5498	Economy	11800.00
0005434265288	5498	Economy	11800.00
0005435767191	5498	Economy	11800.00
0005434265212	5498	Economy	11800.00
0005435767224	5498	Economy	11800.00
0005434265277	5498	Economy	11800.00
0005435767192	5498	Economy	11800.00
0005434265350	5498	Economy	11800.00
0005435767184	5498	Economy	11800.00
0005435767187	5498	Economy	11800.00
0005435462829	5498	Economy	11800.00
0005435767186	5498	Economy	11800.00
0005435767155	5498	Economy	11800.00
0005434265197	5498	Economy	11800.00
0005435462517	5498	Economy	11800.00
0005435767168	5498	Economy	11800.00
0005433529340	5498	Economy	11800.00
0005435725680	5498	Economy	11800.00
0005434265268	5498	Economy	11800.00
0005435462817	5498	Economy	11800.00
0005435767218	5498	Economy	11800.00
0005434265396	5498	Economy	11800.00
0005435767194	5498	Economy	11800.00
0005435767183	5498	Economy	11800.00
0005434265262	5498	Economy	11800.00
0005435767181	5498	Economy	11800.00
0005435462732	5498	Economy	11800.00
0005435767165	5498	Economy	11800.00
0005434265403	5498	Economy	11800.00
0005433527329	5498	Economy	11800.00
0005435767178	5498	Economy	11800.00
0005435767193	5498	Economy	11800.00
0005435462754	5498	Economy	11800.00
0005432140578	5498	Economy	11800.00
0005435767197	5498	Economy	11800.00
0005434265279	5498	Economy	11800.00
0005434265263	5498	Economy	11800.00
0005435767171	5498	Economy	11800.00
0005432140584	5498	Economy	11800.00
0005435767170	5498	Economy	11800.00
0005434265284	5498	Economy	11800.00
0005435767190	5498	Economy	11800.00
0005435462793	5498	Economy	11800.00
0005435767156	5498	Economy	11800.00
0005435725676	5498	Economy	11800.00
0005435767211	5498	Economy	11800.00
0005434265375	5498	Economy	11800.00
0005434265244	5498	Economy	11800.00
0005435722094	5498	Economy	11800.00
0005435462688	5498	Economy	11800.00
0005435462680	5498	Economy	11800.00
0005435462877	5498	Economy	11800.00
0005435767167	5498	Economy	11800.00
0005434265462	5498	Economy	12900.00
0005432140579	5498	Economy	11800.00
0005435043290	5498	Economy	12900.00
0005435767214	5498	Economy	11800.00
0005434265296	5498	Economy	11800.00
0005433529343	5498	Economy	12900.00
0005435767166	5498	Economy	11800.00
0005435767175	5498	Economy	11800.00
0005435767177	5498	Economy	11800.00
0005434265278	5498	Economy	11800.00
0005434265344	5498	Economy	11800.00
0005434265280	5498	Economy	11800.00
0005435767196	5498	Economy	11800.00
0005435767208	5498	Economy	11800.00
0005434265272	5498	Economy	11800.00
0005435767215	5498	Economy	11800.00
0005435767161	5498	Economy	11800.00
0005435767182	5498	Economy	11800.00
0005435462714	5498	Economy	11800.00
0005435767195	5498	Economy	11800.00
0005435767159	5498	Economy	11800.00
0005435462628	5498	Economy	11800.00
0005432140585	5498	Economy	11800.00
0005433529342	5498	Economy	11800.00
0005435767199	5498	Economy	11800.00
0005435767164	5498	Economy	11800.00
0005435462792	5498	Economy	11800.00
0005433529339	5498	Economy	11800.00
0005435767210	5498	Economy	11800.00
0005435767205	5498	Economy	11800.00
0005434265238	5498	Economy	11800.00
0005435735208	5498	Economy	11800.00
0005435767179	5498	Economy	11800.00
0005434265297	5498	Economy	11800.00
0005432140577	5498	Economy	11800.00
0005435462686	5498	Economy	11800.00
0005434265241	5498	Economy	11800.00
0005435767207	5498	Economy	11800.00
0005434265463	5498	Economy	11800.00
0005435462707	5498	Economy	11800.00
0005435723077	5498	Economy	11800.00
0005435767200	5498	Economy	11800.00
0005434265282	5498	Economy	11800.00
0005435767180	5498	Economy	11800.00
0005435767213	5498	Economy	11800.00
0005435725675	5498	Economy	11800.00
0005434265343	5498	Economy	11800.00
0005435735210	5498	Economy	11800.00
0005435767209	5498	Economy	11800.00
0005435767157	5498	Economy	11800.00
0005435725678	5498	Economy	11800.00
0005435462689	5498	Economy	11800.00
0005435767160	5498	Economy	11800.00
0005435767219	5498	Economy	11800.00
0005435462708	5498	Economy	11800.00
0005432140581	5498	Economy	11800.00
0005435462798	5498	Economy	11800.00
0005432140580	5498	Economy	11800.00
0005435767201	5498	Economy	11800.00
0005435767188	5498	Economy	11800.00
0005434265374	5498	Economy	11800.00
0005435767189	5498	Economy	11800.00
0005435767173	5498	Economy	11800.00
0005435767158	5498	Economy	11800.00
0005435767176	5498	Economy	11800.00
0005434265349	5498	Economy	11800.00
0005434265243	5498	Economy	11800.00
0005435767172	5498	Economy	11800.00
0005435463063	13496	Business	35300.00
0005435766871	13496	Business	35300.00
0005435766602	13496	Business	35300.00
0005435766797	13496	Business	35300.00
0005435766358	13496	Business	35300.00
0005435766529	13496	Business	35300.00
0005434265557	13496	Business	35300.00
0005435766573	13496	Business	35300.00
0005435766485	13496	Business	35300.00
0005435767046	13496	Business	35300.00
0005435766650	13496	Business	35300.00
0005435463062	13496	Business	35300.00
0005435766713	13496	Business	35300.00
0005435766704	13496	Business	35300.00
0005435766862	13496	Business	35300.00
0005434265562	13496	Business	35300.00
0005435723066	13496	Business	35300.00
0005435766405	13496	Business	35300.00
0005434265565	13496	Business	35300.00
0005435766928	13496	Business	35300.00
0005434265574	13496	Economy	12900.00
0005435463043	13496	Economy	12900.00
0005434831231	13496	Economy	12900.00
0005435766689	13496	Economy	12900.00
0005434265572	13496	Economy	11800.00
0005435463055	13496	Economy	11800.00
0005435463032	13496	Economy	11800.00
0005434265566	13496	Economy	11800.00
0005435766888	13496	Economy	11800.00
0005435735166	13496	Economy	11800.00
0005432535915	13496	Economy	11800.00
0005435766673	13496	Economy	11800.00
0005434831229	13496	Economy	11800.00
0005435735186	13496	Economy	11800.00
0005435722062	13496	Economy	11800.00
0005435766662	13496	Economy	11800.00
0005435766795	13496	Economy	11800.00
0005435463047	13496	Economy	11800.00
0005435463041	13496	Economy	11800.00
0005434265555	13496	Economy	11800.00
0005434265549	13496	Economy	11800.00
0005435766517	13496	Economy	11800.00
0005435725624	13496	Economy	11800.00
0005435766516	13496	Economy	11800.00
0005435766623	13496	Economy	11800.00
0005435766587	13496	Economy	11800.00
0005435766479	13496	Economy	11800.00
0005435725620	13496	Economy	11800.00
0005434265570	13496	Economy	11800.00
0005435735158	13496	Economy	11800.00
0005434265563	13496	Economy	11800.00
0005434265573	13496	Economy	11800.00
0005435766796	13496	Economy	11800.00
0005435766533	13496	Economy	11800.00
0005432194579	13496	Economy	11800.00
0005435463068	13496	Economy	11800.00
0005435766931	13496	Economy	11800.00
0005435766457	13496	Economy	11800.00
0005434265560	13496	Economy	11800.00
0005435766558	13496	Economy	11800.00
0005435463042	13496	Economy	11800.00
0005432535912	13496	Economy	11800.00
0005434265561	13496	Economy	11800.00
0005435766863	13496	Economy	11800.00
0005435725619	13496	Economy	11800.00
0005434265571	13496	Economy	11800.00
0005435766531	13496	Economy	11800.00
0005435766750	13496	Economy	11800.00
0005435463064	13496	Economy	11800.00
0005435463058	13496	Economy	11800.00
0005435722075	13496	Economy	11800.00
0005434265568	13496	Economy	11800.00
0005435766458	13496	Economy	11800.00
0005435463061	13496	Economy	11800.00
0005435766622	13496	Economy	11800.00
0005435766786	13496	Economy	11800.00
0005435766809	13496	Economy	11800.00
0005434265550	13496	Economy	11800.00
0005435722074	13496	Economy	11800.00
0005435463053	13496	Economy	11800.00
0005435766674	13496	Economy	11800.00
0005435463051	13496	Economy	11800.00
0005435463049	13496	Economy	11800.00
0005434265559	13496	Economy	11800.00
0005434265556	13496	Economy	11800.00
0005434265554	13496	Economy	11800.00
0005435725626	13496	Economy	11800.00
0005435766571	13496	Economy	11800.00
0005435463065	13496	Economy	11800.00
0005435723056	13496	Economy	11800.00
0005435463044	13496	Economy	11800.00
0005435463069	13496	Economy	11800.00
0005435766744	13496	Economy	11800.00
0005435463039	13496	Economy	11800.00
0005435463066	13496	Economy	11800.00
0005435725622	13496	Economy	11800.00
0005435463056	13496	Economy	11800.00
0005435463067	13496	Economy	12900.00
0005435463059	13496	Economy	12900.00
0005435766927	13496	Economy	11800.00
0005435766680	13496	Economy	11800.00
0005434831230	13496	Economy	12900.00
0005432194578	13496	Economy	12900.00
0005434831228	13496	Economy	11800.00
0005434831227	13496	Economy	11800.00
0005435463050	13496	Economy	11800.00
0005434265553	13496	Economy	11800.00
0005435766743	13496	Economy	11800.00
0005435463052	13496	Economy	11800.00
0005435766530	13496	Economy	11800.00
0005434265564	13496	Economy	11800.00
0005435463054	13496	Economy	11800.00
0005435766705	13496	Economy	11800.00
0005435766608	13496	Economy	11800.00
0005435766945	13496	Economy	11800.00
0005435463045	13496	Economy	11800.00
0005434265558	13496	Economy	11800.00
0005435766706	13496	Economy	11800.00
0005435463060	13496	Economy	11800.00
0005435766688	13496	Economy	11800.00
0005435463046	13496	Economy	11800.00
0005435766864	13496	Economy	11800.00
0005435766889	13496	Economy	11800.00
0005434265569	13496	Economy	11800.00
0005435463034	13496	Economy	11800.00
0005435735157	13496	Economy	11800.00
0005435463040	13496	Economy	11800.00
0005435766813	13496	Economy	11800.00
0005432535911	13496	Economy	11800.00
0005435463057	13496	Economy	11800.00
0005435767045	13496	Economy	11800.00
0005435735185	13496	Economy	11800.00
0005435725623	13496	Economy	11800.00
0005432535913	13496	Economy	11800.00
0005435766753	13496	Economy	11800.00
0005435463037	13496	Economy	11800.00
0005434265551	13496	Economy	11800.00
0005435766756	13496	Economy	11800.00
0005435463038	13496	Economy	11800.00
0005435766480	13496	Economy	11800.00
0005434265567	13496	Economy	11800.00
0005435735156	13496	Economy	11800.00
0005432194580	13496	Economy	11800.00
0005435723057	13496	Economy	11800.00
0005432535914	13496	Economy	11800.00
0005435766557	13496	Economy	11800.00
0005435766664	13496	Economy	11800.00
0005435463036	13496	Economy	11800.00
0005435463033	13496	Economy	11800.00
0005435463035	13496	Economy	11800.00
0005435766787	13496	Economy	11800.00
0005435723055	13496	Economy	11800.00
0005435725621	13496	Economy	11800.00
0005435725625	13496	Economy	11800.00
0005435463048	13496	Economy	11800.00
0005434265552	13496	Economy	11800.00
0005434602919	18692	Economy	3300.00
0005434602920	18692	Economy	3300.00
0005434602928	18692	Economy	3300.00
0005434602918	18692	Economy	3300.00
0005434602912	18692	Economy	3300.00
0005434602916	18692	Economy	3300.00
0005434515009	18691	Economy	3300.00
0005434513620	18691	Economy	3300.00
0005435904714	18691	Economy	3300.00
0005434604933	18691	Economy	3300.00
0005434513619	18691	Economy	3300.00
0005434515007	18691	Economy	3300.00
0005434513621	18691	Economy	3300.00
0005434515010	18691	Economy	3300.00
0005434515008	18691	Economy	3300.00
0005434604934	18691	Economy	3300.00
0005434602934	19121	Economy	3300.00
0005434602938	19121	Economy	3300.00
0005434602937	19121	Economy	3300.00
0005434602935	19121	Economy	3300.00
0005434602939	19121	Economy	3300.00
0005434602936	19121	Economy	3300.00
0005432649451	25095	Business	88300.00
0005435844374	25095	Business	88300.00
0005435844369	25095	Business	88300.00
0005435844364	25095	Business	88300.00
0005435844376	25095	Business	88300.00
0005432632740	25095	Business	88300.00
0005432649452	25095	Business	88300.00
0005432649437	25095	Business	88300.00
0005435844363	25095	Business	88300.00
0005435844366	25095	Economy	29400.00
0005435844375	25095	Economy	29400.00
0005435846304	25095	Economy	29400.00
0005432632757	25095	Economy	29400.00
0005432649423	25095	Economy	29400.00
0005435844367	25095	Economy	29400.00
0005432632748	25095	Economy	32400.00
0005432632739	25095	Economy	32400.00
0005435846306	25095	Economy	32400.00
0005435846308	25095	Economy	32400.00
0005432632741	25095	Economy	29400.00
0005435844372	25095	Economy	29400.00
0005432632746	25095	Economy	29400.00
0005435844370	25095	Economy	29400.00
0005432632747	25095	Economy	29400.00
0005432632793	25095	Economy	29400.00
0005432649458	25095	Economy	29400.00
0005432649454	25095	Economy	29400.00
0005435846311	25095	Economy	29400.00
0005432632755	25095	Economy	29400.00
0005432632744	25095	Economy	29400.00
0005432632802	25095	Economy	29400.00
0005432649442	25095	Economy	29400.00
0005432649422	25095	Economy	29400.00
0005432632733	25095	Economy	29400.00
0005432632774	25095	Economy	29400.00
0005435844371	25095	Economy	29400.00
0005432632716	25095	Economy	29400.00
0005432649424	25095	Economy	29400.00
0005432649459	25095	Economy	29400.00
0005432649460	25095	Economy	29400.00
0005435846313	25095	Economy	29400.00
0005432632767	25095	Economy	29400.00
0005432649435	25095	Economy	29400.00
0005432649443	25095	Economy	29400.00
0005435846310	25095	Economy	29400.00
0005435844373	25095	Economy	29400.00
0005435844365	25095	Economy	29400.00
0005435846312	25095	Economy	29400.00
0005432649471	25095	Economy	29400.00
0005432649482	25095	Economy	29400.00
0005432632715	25095	Economy	29400.00
0005435846309	25095	Economy	29400.00
0005435844377	25095	Economy	29400.00
0005432632801	25095	Economy	29400.00
0005432649436	25095	Economy	29400.00
0005435846305	25095	Economy	29400.00
0005432649472	25095	Economy	29400.00
0005435844378	25095	Economy	29400.00
0005432649483	25095	Economy	29400.00
0005432632756	25095	Economy	29400.00
0005432649481	25095	Economy	29400.00
0005435844368	25095	Economy	29400.00
0005432632768	25095	Economy	29400.00
0005435846307	25095	Economy	29400.00
0005432632760	25095	Economy	29400.00
0005432632766	25095	Economy	29400.00
0005432632742	25095	Economy	29400.00
0005433008944	1773	Business	48700.00
0005433008817	1773	Business	48700.00
0005432295924	1773	Business	48700.00
0005433285467	1773	Business	48700.00
0005433008878	1773	Business	48700.00
0005433009161	1773	Business	48700.00
0005433285586	1773	Business	48700.00
0005432295921	1773	Business	48700.00
0005433285557	1773	Business	48700.00
0005433285651	1773	Business	48700.00
0005433008914	1773	Business	48700.00
0005433285468	1773	Business	48700.00
0005433009044	1773	Economy	16200.00
0005433285594	1773	Economy	16200.00
0005433009071	1773	Economy	16200.00
0005433008896	1773	Economy	16200.00
0005433008897	1773	Economy	16200.00
0005433285473	1773	Economy	16200.00
0005433285531	1773	Economy	16200.00
0005433009003	1773	Economy	16200.00
0005433285576	1773	Economy	16200.00
0005433009090	1773	Economy	17900.00
0005433009073	1773	Economy	17900.00
0005433009045	1773	Economy	17900.00
0005433285571	1773	Economy	17900.00
0005433008969	1773	Economy	17900.00
0005433009198	1773	Economy	16200.00
0005433285522	1773	Economy	16200.00
0005433285461	1773	Economy	16200.00
0005433008894	1773	Economy	16200.00
0005433285593	1773	Economy	16200.00
0005433009050	1773	Economy	16200.00
0005433009091	1773	Economy	16200.00
0005433008906	1773	Economy	16200.00
0005433008938	1773	Economy	16200.00
0005433009033	1773	Economy	16200.00
0005433009162	1773	Economy	16200.00
0005433009294	1773	Economy	16200.00
0005433285601	1773	Economy	16200.00
0005433009139	1773	Economy	16200.00
0005433285552	1773	Economy	16200.00
0005433008877	1773	Economy	16200.00
0005433285530	1773	Economy	16200.00
0005433008967	1773	Economy	16200.00
0005433009004	1773	Economy	16200.00
0005433285474	1773	Economy	16200.00
0005433285527	1773	Economy	16200.00
0005433285524	1773	Economy	16200.00
0005433009141	1773	Economy	16200.00
0005433285464	1773	Economy	16200.00
0005433008903	1773	Economy	16200.00
0005433285591	1773	Economy	16200.00
0005433008879	1773	Economy	16200.00
0005433008905	1773	Economy	16200.00
0005433009089	1773	Economy	16200.00
0005433009158	1773	Economy	16200.00
0005433285642	1773	Economy	16200.00
0005433285551	1773	Economy	16200.00
0005433009088	1773	Economy	16200.00
0005433285465	1773	Economy	16200.00
0005433008790	1773	Economy	16200.00
0005433009159	1773	Economy	16200.00
0005433009049	1773	Economy	16200.00
0005433008923	1773	Economy	16200.00
0005432295922	1773	Economy	16200.00
0005432295923	1773	Economy	16200.00
0005433008991	1773	Economy	16200.00
0005433008816	1773	Economy	16200.00
0005433009012	1773	Economy	16200.00
0005433009072	1773	Economy	16200.00
0005433285380	1773	Economy	16200.00
0005433008890	1773	Economy	16200.00
0005433285639	1773	Economy	16200.00
0005433285546	1773	Economy	16200.00
0005433285529	1773	Economy	16200.00
0005433009034	1773	Economy	16200.00
0005433285466	1773	Economy	16200.00
0005433285590	1773	Economy	16200.00
0005433285462	1773	Economy	16200.00
0005433285595	1773	Economy	16200.00
0005433009035	1773	Economy	16200.00
0005433285381	1773	Economy	16200.00
0005433009140	1773	Economy	16200.00
0005433008891	1773	Economy	16200.00
0005433285592	1773	Economy	16200.00
0005433008915	1773	Economy	16200.00
0005433008654	1773	Economy	16200.00
0005433285523	1773	Economy	16200.00
0005433285528	1773	Economy	16200.00
0005433285627	1773	Economy	16200.00
0005433009293	1773	Economy	16200.00
0005433008968	1773	Economy	16200.00
0005433285603	1773	Economy	16200.00
0005433009087	1773	Economy	16200.00
0005433009160	1773	Economy	16200.00
0005433285525	1773	Economy	16200.00
0005433009350	22631	Business	48700.00
0005433810556	22631	Business	48700.00
0005433285797	22631	Business	48700.00
0005433285790	22631	Business	48700.00
0005433009343	22631	Business	48700.00
0005433285799	22631	Business	48700.00
0005433285776	22631	Business	48700.00
0005433285803	22631	Business	48700.00
0005433009308	22631	Business	48700.00
0005433009340	22631	Economy	16200.00
0005433009316	22631	Economy	16200.00
0005433009337	22631	Economy	16200.00
0005433009336	22631	Economy	16200.00
0005433009317	22631	Economy	16200.00
0005433009331	22631	Economy	16200.00
0005433009347	22631	Economy	16200.00
0005433009338	22631	Economy	16200.00
0005433009352	22631	Economy	16200.00
0005433285780	22631	Economy	17900.00
0005433009312	22631	Economy	17900.00
0005433285773	22631	Economy	17900.00
0005433009323	22631	Economy	17900.00
0005433009322	22631	Economy	16200.00
0005433285800	22631	Economy	16200.00
0005433009346	22631	Economy	16200.00
0005433009328	22631	Economy	16200.00
0005433810553	22631	Economy	16200.00
0005433285795	22631	Economy	16200.00
0005433009332	22631	Economy	16200.00
0005433009334	22631	Economy	16200.00
0005433009345	22631	Economy	16200.00
0005433810550	22631	Economy	16200.00
0005433810546	22631	Economy	16200.00
0005433810562	22631	Economy	16200.00
0005433285801	22631	Economy	16200.00
0005433285782	22631	Economy	16200.00
0005433009329	22631	Economy	16200.00
0005433009326	22631	Economy	16200.00
0005433009348	22631	Economy	16200.00
0005433009342	22631	Economy	16200.00
0005433009324	22631	Economy	16200.00
0005433285783	22631	Economy	16200.00
0005433285788	22631	Economy	16200.00
0005433009333	22631	Economy	16200.00
0005433285789	22631	Economy	16200.00
0005433285793	22631	Economy	16200.00
0005433285794	22631	Economy	16200.00
0005433285784	22631	Economy	16200.00
0005433285778	22631	Economy	16200.00
0005433009306	22631	Economy	16200.00
0005433285774	22631	Economy	16200.00
0005433285802	22631	Economy	16200.00
0005433009307	22631	Economy	16200.00
0005433009311	22631	Economy	16200.00
0005433285787	22631	Economy	16200.00
0005433285786	22631	Economy	16200.00
0005433009314	22631	Economy	16200.00
0005433009320	22631	Economy	16200.00
0005433009327	22631	Economy	16200.00
0005433009339	22631	Economy	16200.00
0005433009313	22631	Economy	16200.00
0005433285781	22631	Economy	16200.00
0005433285785	22631	Economy	16200.00
0005433009310	22631	Economy	16200.00
0005433009325	22631	Economy	16200.00
0005433009330	22631	Economy	16200.00
0005433810548	22631	Economy	16200.00
0005433285777	22631	Economy	16200.00
0005433009319	22631	Economy	16200.00
0005433009349	22631	Economy	16200.00
0005433285772	22631	Economy	16200.00
0005433285792	22631	Economy	16200.00
0005433009309	22631	Economy	16200.00
0005433810549	22631	Economy	16200.00
0005433009321	22631	Economy	16200.00
0005433009344	22631	Economy	16200.00
0005433009318	22631	Economy	16200.00
0005433285804	22631	Economy	16200.00
0005433285791	22631	Economy	16200.00
0005433810537	22631	Economy	16200.00
0005433285798	22631	Economy	16200.00
0005433285796	22631	Economy	16200.00
0005433810563	22631	Economy	16200.00
0005433009315	22631	Economy	16200.00
0005433009335	22631	Economy	16200.00
0005433009351	22631	Economy	16200.00
0005433285779	22631	Economy	16200.00
0005433285775	22631	Economy	16200.00
0005433009341	22631	Economy	16200.00
0005435282714	5604	Business	99800.00
0005433847672	5604	Business	99800.00
0005435282724	5604	Business	99800.00
0005433847670	5604	Business	99800.00
0005432081617	5604	Business	99800.00
0005433847671	5604	Business	99800.00
0005433847637	5604	Business	99800.00
0005433847661	5604	Business	99800.00
0005435282694	5604	Business	99800.00
0005432081612	5604	Business	99800.00
0005432081619	5604	Business	99800.00
0005433847694	5604	Business	99800.00
0005435282720	5604	Business	99800.00
0005433847666	5604	Business	99800.00
0005433847677	5604	Business	99800.00
0005435282743	5604	Business	99800.00
0005433847673	5604	Business	99800.00
0005433847642	5604	Economy	33300.00
0005435282726	5604	Business	99800.00
0005435282653	5604	Economy	33300.00
0005435282684	5604	Economy	33300.00
0005433815462	5604	Economy	33300.00
0005435282680	5604	Economy	33300.00
0005433847641	5604	Economy	33300.00
0005432081615	5604	Economy	33300.00
0005433847659	5604	Economy	33300.00
0005435282591	5604	Economy	33300.00
0005433847653	5604	Economy	33300.00
0005433847638	5604	Economy	33300.00
0005433847650	5604	Economy	36600.00
0005435282708	5604	Economy	36600.00
0005434173544	5604	Economy	36600.00
0005433847679	5604	Economy	36600.00
0005435282580	5604	Economy	33300.00
0005433847686	5604	Economy	33300.00
0005433847639	5604	Economy	33300.00
0005435282742	5604	Economy	33300.00
0005433847676	5604	Economy	33300.00
0005432081613	5604	Economy	33300.00
0005433847654	5604	Economy	33300.00
0005432081614	5604	Economy	33300.00
0005432081618	5604	Economy	33300.00
0005433847658	5604	Economy	33300.00
0005433847685	5604	Economy	33300.00
0005432081616	5604	Economy	33300.00
0005433847665	5604	Economy	33300.00
0005433847648	5604	Economy	33300.00
0005435282687	5604	Economy	33300.00
0005433847678	5604	Economy	33300.00
0005435282719	5604	Economy	33300.00
0005433847636	5604	Economy	33300.00
0005433847651	5604	Economy	33300.00
0005433847691	5604	Economy	33300.00
0005433847652	5604	Economy	33300.00
0005433847646	5604	Economy	33300.00
0005433847657	5604	Economy	33300.00
0005435282677	5604	Economy	33300.00
0005435282579	5604	Economy	33300.00
0005433847692	5604	Economy	33300.00
0005434173538	5604	Economy	33300.00
0005435282681	5604	Economy	33300.00
0005433847669	5604	Economy	33300.00
0005433847649	5604	Economy	33300.00
0005435282745	5604	Economy	33300.00
0005433815461	5604	Economy	33300.00
0005433847674	5604	Economy	33300.00
0005433815460	5604	Economy	33300.00
0005433847690	5604	Economy	33300.00
0005435282725	5604	Economy	33300.00
0005435282643	5604	Economy	33300.00
0005433847687	5604	Economy	33300.00
0005433847645	5604	Economy	33300.00
0005433847667	5604	Economy	33300.00
0005433847683	5604	Economy	33300.00
0005433847682	5604	Economy	33300.00
0005433847643	5604	Economy	33300.00
0005433847668	5604	Economy	33300.00
0005433847681	5604	Economy	33300.00
0005435282695	5604	Economy	33300.00
0005433847680	5604	Economy	33300.00
0005433847656	5604	Economy	33300.00
0005435282590	5604	Economy	33300.00
0005433847660	5604	Economy	33300.00
0005433847640	5604	Economy	33300.00
0005433847684	5604	Economy	33300.00
0005433847693	5604	Economy	33300.00
0005433847664	5604	Economy	33300.00
0005433847688	5604	Economy	33300.00
0005433847675	5604	Economy	33300.00
0005432081620	5604	Economy	33300.00
0005433847662	5604	Economy	33300.00
0005434173546	5604	Economy	33300.00
0005433847663	5604	Economy	33300.00
0005434173543	5604	Economy	33300.00
0005434173545	5604	Economy	33300.00
0005433847644	5604	Economy	33300.00
0005433847689	5604	Economy	33300.00
0005435282682	5604	Economy	33300.00
0005433847647	5604	Economy	33300.00
0005433847655	5604	Economy	33300.00
0005435282654	5604	Economy	33300.00
0005433815463	5604	Economy	33300.00
0005433846983	13860	Business	99800.00
0005435282885	13860	Business	99800.00
0005433847222	13860	Business	99800.00
0005433847146	13860	Business	99800.00
0005435282898	13860	Business	99800.00
0005433847038	13860	Business	99800.00
0005433847013	13860	Business	99800.00
0005435282891	13860	Business	99800.00
0005433847198	13860	Business	99800.00
0005433847224	13860	Business	99800.00
0005433847199	13860	Business	99800.00
0005433846963	13860	Business	99800.00
0005435282892	13860	Business	99800.00
0005435282884	13860	Business	99800.00
0005435282907	13860	Business	99800.00
0005435282895	13860	Business	99800.00
0005435282893	13860	Business	99800.00
0005433847131	13860	Economy	33300.00
0005435282906	13860	Economy	33300.00
0005434173585	13860	Economy	33300.00
0005433847440	13860	Economy	33300.00
0005435282904	13860	Economy	33300.00
0005435282894	13860	Economy	33300.00
0005433847249	13860	Economy	33300.00
0005433847202	13860	Economy	33300.00
0005433847272	13860	Economy	33300.00
0005435282899	13860	Economy	33300.00
0005433846962	13860	Economy	33300.00
0005435282905	13860	Economy	33300.00
0005434173586	13860	Economy	36600.00
0005433847297	13860	Economy	36600.00
0005433847114	13860	Economy	36600.00
0005433815397	13860	Economy	36600.00
0005433847115	13860	Economy	33300.00
0005433847347	13860	Economy	33300.00
0005435282902	13860	Economy	33300.00
0005433847099	13860	Economy	33300.00
0005432003752	13860	Economy	33300.00
0005433847215	13860	Economy	33300.00
0005435282887	13860	Economy	33300.00
0005433847176	13860	Economy	33300.00
0005433847421	13860	Economy	33300.00
0005433847250	13860	Economy	33300.00
0005433847133	13860	Economy	33300.00
0005435282888	13860	Economy	33300.00
0005433847251	13860	Economy	33300.00
0005435282901	13860	Economy	33300.00
0005432003753	13860	Economy	33300.00
0005433847042	13860	Economy	33300.00
0005433847275	13860	Economy	33300.00
0005433847345	13860	Economy	33300.00
0005433847143	13860	Economy	33300.00
0005433847161	13860	Economy	33300.00
0005433846977	13860	Economy	33300.00
0005433847087	13860	Economy	33300.00
0005433847181	13860	Economy	33300.00
0005433847211	13860	Economy	33300.00
0005433847070	13860	Economy	33300.00
0005433847420	13860	Economy	33300.00
0005433847318	13860	Economy	33300.00
0005435282896	13860	Economy	33300.00
0005433847150	13860	Economy	33300.00
0005433847141	13860	Economy	33300.00
0005435282908	13860	Economy	33300.00
0005433847123	13860	Economy	33300.00
0005435282900	13860	Economy	33300.00
0005433847346	13860	Economy	33300.00
0005433847142	13860	Economy	33300.00
0005435282897	13860	Economy	33300.00
0005435282910	13860	Economy	33300.00
0005433847144	13860	Economy	33300.00
0005435282889	13860	Economy	33300.00
0005435282890	13860	Economy	33300.00
0005433846976	13860	Economy	33300.00
0005435282909	13860	Economy	33300.00
0005433847076	13860	Economy	33300.00
0005433847201	13860	Economy	33300.00
0005433847049	13860	Economy	33300.00
0005433847085	13860	Economy	33300.00
0005433847273	13860	Economy	33300.00
0005435282903	13860	Economy	33300.00
0005433847101	13860	Economy	33300.00
0005433847210	13860	Economy	33300.00
0005433847086	13860	Economy	33300.00
0005433847214	13860	Economy	33300.00
0005432003751	13860	Economy	33300.00
0005433847100	13860	Economy	33300.00
0005433847075	13860	Economy	33300.00
0005434173587	13860	Economy	33300.00
0005433846891	13860	Economy	33300.00
0005434173584	13860	Economy	33300.00
0005433847257	13860	Economy	33300.00
0005433847386	13860	Economy	33300.00
0005433847104	13860	Economy	33300.00
0005433846980	13860	Economy	33300.00
0005435282886	13860	Economy	33300.00
0005433847225	13860	Economy	33300.00
0005432003754	13860	Economy	33300.00
0005433847162	13860	Economy	33300.00
0005433815411	13860	Economy	33300.00
0005434620917	7855	Economy	16600.00
0005434620930	7855	Economy	15100.00
0005435332431	7855	Economy	15100.00
0005434620931	7855	Economy	15100.00
0005434620923	7855	Economy	15100.00
0005434620918	7855	Economy	15100.00
0005435332447	7855	Economy	15100.00
0005432112552	7855	Economy	15100.00
0005434620925	7855	Economy	15100.00
0005434620927	7855	Economy	15100.00
0005435332451	7855	Economy	15100.00
0005435332412	7855	Economy	15100.00
0005434620936	7855	Economy	15100.00
0005435332413	7855	Economy	15100.00
0005434620922	7855	Economy	15100.00
0005434620928	7855	Economy	15100.00
0005434620932	7855	Economy	15100.00
0005435332446	7855	Economy	15100.00
0005434620921	7855	Economy	15100.00
0005435332452	7855	Economy	15100.00
0005434620919	7855	Economy	15100.00
0005434620926	7855	Economy	15100.00
0005432112553	7855	Economy	15100.00
0005434620934	7855	Economy	15100.00
0005434620929	7855	Economy	15100.00
0005434620920	7855	Economy	15100.00
0005434620933	7855	Economy	15100.00
0005434620924	7855	Economy	15100.00
0005435332445	7855	Economy	15100.00
0005434620935	7855	Economy	15100.00
0005434620741	32940	Economy	16600.00
0005434620729	32940	Economy	16600.00
0005435332503	32940	Economy	16600.00
0005435332500	32940	Economy	16600.00
0005435332499	32940	Economy	15100.00
0005435332507	32940	Economy	15100.00
0005434620740	32940	Economy	15100.00
0005435332497	32940	Economy	15100.00
0005434620753	32940	Economy	15100.00
0005434620754	32940	Economy	15100.00
0005434620724	32940	Economy	15100.00
0005434620742	32940	Economy	15100.00
0005434620778	32940	Economy	15100.00
0005435332504	32940	Economy	15100.00
0005434620793	32940	Economy	15100.00
0005435332505	32940	Economy	15100.00
0005434620672	32940	Economy	15100.00
0005435332501	32940	Economy	15100.00
0005434620683	32940	Economy	15100.00
0005435332498	32940	Economy	15100.00
0005434620648	32940	Economy	15100.00
0005434620743	32940	Economy	15100.00
0005435332502	32940	Economy	15100.00
0005434620756	32940	Economy	15100.00
0005434620725	32940	Economy	15100.00
0005434620652	32940	Economy	15100.00
0005435332506	32940	Economy	15100.00
0005434620796	32940	Economy	15100.00
0005434620751	32940	Economy	15100.00
0005434620752	32940	Economy	15100.00
0005434620827	32940	Economy	15100.00
0005434620728	32940	Economy	15100.00
0005434620671	32940	Economy	15100.00
0005434620731	32940	Economy	15100.00
0005434620653	32940	Economy	15100.00
0005434620647	32940	Economy	15100.00
0005435918687	4266	Business	38000.00
0005435918686	4266	Business	38000.00
0005435785928	4266	Business	38000.00
0005435785900	4266	Business	38000.00
0005434994183	4266	Business	38000.00
0005435785909	4266	Business	38000.00
0005435918720	4266	Business	38000.00
0005434994184	4266	Economy	12700.00
0005434994185	4266	Economy	12700.00
0005435785925	4266	Economy	12700.00
0005435785926	4266	Economy	12700.00
0005435785903	4266	Economy	12700.00
0005435785930	4266	Economy	12700.00
0005435785921	4266	Economy	12700.00
0005435785901	4266	Economy	13900.00
0005432190690	4266	Economy	13900.00
0005434994179	4266	Economy	13900.00
0005435785910	4266	Economy	13900.00
0005435785929	4266	Economy	12700.00
0005434994177	4266	Economy	12700.00
0005435787389	4266	Economy	12700.00
0005435918712	4266	Economy	12700.00
0005435785931	4266	Economy	12700.00
0005435785902	4266	Economy	12700.00
0005435787390	4266	Economy	12700.00
0005435785904	4266	Economy	12700.00
0005435785911	4266	Economy	12700.00
0005435785915	4266	Economy	12700.00
0005435918692	4266	Economy	12700.00
0005432190692	4266	Economy	12700.00
0005435785920	4266	Economy	12700.00
0005434994181	4266	Economy	12700.00
0005435785912	4266	Economy	12700.00
0005434994180	4266	Economy	12700.00
0005435785907	4266	Economy	12700.00
0005435785923	4266	Economy	12700.00
0005435937417	4266	Economy	12700.00
0005435937416	4266	Economy	12700.00
0005432190691	4266	Economy	12700.00
0005435785916	4266	Economy	12700.00
0005435918684	4266	Economy	12700.00
0005435785924	4266	Economy	12700.00
0005435785905	4266	Economy	12700.00
0005435785918	4266	Economy	12700.00
0005435785919	4266	Economy	12700.00
0005435918721	4266	Economy	12700.00
0005435785906	4266	Economy	12700.00
0005435785914	4266	Economy	12700.00
0005435918683	4266	Economy	12700.00
0005435785922	4266	Economy	12700.00
0005435785908	4266	Economy	12700.00
0005432190693	4266	Economy	12700.00
0005435785899	4266	Economy	12700.00
0005435785927	4266	Economy	12700.00
0005435785932	4266	Economy	12700.00
0005434994182	4266	Economy	12700.00
0005435785898	4266	Economy	12700.00
0005435785917	4266	Economy	12700.00
0005435785913	4266	Economy	12700.00
0005434994178	4266	Economy	12700.00
0005435785539	27320	Business	38000.00
0005432195726	27320	Business	38000.00
0005435918735	27320	Business	38000.00
0005435785482	27320	Business	38000.00
0005434994099	27320	Business	38000.00
0005434994083	27320	Business	38000.00
0005435785526	27320	Business	38000.00
0005434994044	27320	Business	38000.00
0005435785474	27320	Economy	12700.00
0005435785525	27320	Economy	12700.00
0005432195729	27320	Economy	12700.00
0005435785604	27320	Economy	12700.00
0005435785541	27320	Economy	12700.00
0005435785548	27320	Economy	13900.00
0005435785445	27320	Economy	13900.00
0005435918731	27320	Economy	13900.00
0005434994084	27320	Economy	13900.00
0005434994057	27320	Economy	12700.00
0005435937455	27320	Economy	12700.00
0005435785554	27320	Economy	12700.00
0005435937449	27320	Economy	12700.00
0005434994065	27320	Economy	12700.00
0005435785463	27320	Economy	12700.00
0005435785623	27320	Economy	12700.00
0005435785551	27320	Economy	12700.00
0005435937450	27320	Economy	12700.00
0005435918732	27320	Economy	12700.00
0005432195727	27320	Economy	12700.00
0005435785643	27320	Economy	12700.00
0005435937448	27320	Economy	12700.00
0005434994053	27320	Economy	12700.00
0005435785529	27320	Economy	12700.00
0005435785481	27320	Economy	12700.00
0005435785544	27320	Economy	12700.00
0005432195725	27320	Economy	12700.00
0005435918734	27320	Economy	12700.00
0005435785543	27320	Economy	12700.00
0005435785665	27320	Economy	12700.00
0005434994108	27320	Economy	12700.00
0005435785608	27320	Economy	12700.00
0005435937451	27320	Economy	12700.00
0005432195728	27320	Economy	12700.00
0005435937453	27320	Economy	12700.00
0005435787368	27320	Economy	12700.00
0005435918733	27320	Economy	12700.00
0005435785607	27320	Economy	12700.00
0005435785581	27320	Economy	12700.00
0005435785521	27320	Economy	12700.00
0005435937452	27320	Economy	12700.00
0005435937454	27320	Economy	12700.00
0005435937456	27320	Economy	12700.00
0005435785528	27320	Economy	12700.00
0005435785704	27320	Economy	12700.00
0005435785549	27320	Economy	12700.00
0005435785522	27320	Economy	12700.00
0005432146232	19847	Economy	12800.00
0005432146231	19847	Economy	12800.00
0005432568646	4728	Business	40900.00
0005432460671	4728	Business	40900.00
0005434082283	4728	Business	40900.00
0005432186928	4728	Business	40900.00
0005432170496	4728	Business	40900.00
0005432568648	4728	Business	40900.00
0005434082278	4728	Business	40900.00
0005432170495	4728	Business	40900.00
0005432460677	4728	Business	40900.00
0005434082271	4728	Business	40900.00
0005432568647	4728	Business	40900.00
0005432460709	4728	Business	40900.00
0005432460687	4728	Business	40900.00
0005432568639	4728	Business	40900.00
0005432568643	4728	Business	40900.00
0005434082277	4728	Business	40900.00
0005432568609	4728	Business	40900.00
0005434082282	4728	Economy	15000.00
0005432568649	4728	Economy	15000.00
0005432460710	4728	Economy	15000.00
0005432568592	4728	Economy	13600.00
0005432568633	4728	Economy	13600.00
0005432568631	4728	Economy	13600.00
0005434082264	4728	Economy	13600.00
0005432170497	4728	Economy	13600.00
0005432568608	4728	Economy	13600.00
0005432170500	4728	Economy	13600.00
0005432568641	4728	Economy	13600.00
0005432460714	4728	Economy	13600.00
0005432460670	4728	Economy	13600.00
0005432568636	4728	Economy	13600.00
0005432568611	4728	Economy	13600.00
0005432568612	4728	Economy	13600.00
0005432186930	4728	Economy	13600.00
0005432568623	4728	Economy	13600.00
0005433451651	4728	Economy	13600.00
0005432460685	4728	Economy	13600.00
0005432568619	4728	Economy	13600.00
0005432568622	4728	Economy	13600.00
0005432460683	4728	Economy	13600.00
0005432460686	4728	Economy	13600.00
0005432568596	4728	Economy	13600.00
0005434082279	4728	Economy	13600.00
0005432571383	4728	Economy	13600.00
0005432568642	4728	Economy	13600.00
0005434082268	4728	Economy	13600.00
0005432460701	4728	Economy	13600.00
0005432460716	4728	Economy	13600.00
0005433726142	4728	Economy	13600.00
0005432460676	4728	Economy	13600.00
0005432460672	4728	Economy	13600.00
0005432460704	4728	Economy	13600.00
0005433726141	4728	Economy	13600.00
0005432460700	4728	Economy	13600.00
0005432568615	4728	Economy	13600.00
0005433451652	4728	Economy	13600.00
0005432460706	4728	Economy	13600.00
0005432568610	4728	Economy	13600.00
0005432460684	4728	Economy	13600.00
0005432568624	4728	Economy	13600.00
0005432460669	4728	Economy	13600.00
0005432568591	4728	Economy	13600.00
0005432568651	4728	Economy	13600.00
0005432460679	4728	Economy	13600.00
0005432568645	4728	Economy	13600.00
0005432568620	4728	Economy	13600.00
0005432568595	4728	Economy	13600.00
0005432460691	4728	Economy	13600.00
0005432460666	4728	Economy	13600.00
0005432460711	4728	Economy	13600.00
0005432170498	4728	Economy	13600.00
0005432568640	4728	Economy	13600.00
0005434082272	4728	Economy	13600.00
0005432568613	4728	Economy	13600.00
0005434082266	4728	Economy	13600.00
0005432460703	4728	Economy	13600.00
0005434082276	4728	Economy	13600.00
0005432568600	4728	Economy	13600.00
0005432568627	4728	Economy	13600.00
0005432460695	4728	Economy	13600.00
0005434082281	4728	Economy	13600.00
0005434082275	4728	Economy	13600.00
0005432568635	4728	Economy	13600.00
0005432460694	4728	Economy	13600.00
0005432568638	4728	Economy	13600.00
0005432568630	4728	Economy	13600.00
0005432460674	4728	Economy	13600.00
0005432568605	4728	Economy	13600.00
0005432568617	4728	Economy	13600.00
0005432568598	4728	Economy	15000.00
0005432568616	4728	Economy	15000.00
0005434082270	4728	Economy	13600.00
0005432460717	4728	Economy	13600.00
0005434082269	4728	Economy	13600.00
0005432460673	4728	Economy	15000.00
0005432568626	4728	Economy	15000.00
0005432460713	4728	Economy	13600.00
0005432568625	4728	Economy	13600.00
0005432571382	4728	Economy	13600.00
0005432568621	4728	Economy	13600.00
0005432571384	4728	Economy	13600.00
0005432460712	4728	Economy	13600.00
0005432568604	4728	Economy	13600.00
0005432568594	4728	Economy	13600.00
0005432460688	4728	Economy	13600.00
0005432568601	4728	Economy	13600.00
0005432460689	4728	Economy	13600.00
0005432568632	4728	Economy	13600.00
0005432460682	4728	Economy	13600.00
0005432568637	4728	Economy	13600.00
0005432460667	4728	Economy	13600.00
0005432460698	4728	Economy	13600.00
0005432460692	4728	Economy	13600.00
0005432460699	4728	Economy	13600.00
0005432460680	4728	Economy	13600.00
0005434082267	4728	Economy	13600.00
0005432460693	4728	Economy	13600.00
0005432568603	4728	Economy	13600.00
0005432571385	4728	Economy	13600.00
0005432568628	4728	Economy	13600.00
0005432170499	4728	Economy	13600.00
0005434082273	4728	Economy	13600.00
0005432460702	4728	Economy	13600.00
0005432460697	4728	Economy	13600.00
0005432568599	4728	Economy	13600.00
0005433452774	4728	Economy	13600.00
0005432460705	4728	Economy	13600.00
0005432460707	4728	Economy	13600.00
0005432568593	4728	Economy	13600.00
0005432460668	4728	Economy	13600.00
0005432460675	4728	Economy	13600.00
0005432568607	4728	Economy	13600.00
0005434082280	4728	Economy	13600.00
0005432460696	4728	Economy	13600.00
0005432460708	4728	Economy	13600.00
0005434082265	4728	Economy	13600.00
0005432460718	4728	Economy	13600.00
0005433452773	4728	Economy	13600.00
0005432460678	4728	Economy	13600.00
0005432460715	4728	Economy	13600.00
0005434082284	4728	Economy	13600.00
0005432568644	4728	Economy	13600.00
0005432568634	4728	Economy	13600.00
0005434082262	4728	Economy	13600.00
0005432568618	4728	Economy	13600.00
0005432568629	4728	Economy	13600.00
0005432568590	4728	Economy	13600.00
0005432460681	4728	Economy	13600.00
0005432568606	4728	Economy	13600.00
0005432568602	4728	Economy	13600.00
0005434082263	4728	Economy	13600.00
0005432186927	4728	Economy	13600.00
0005434082274	4728	Economy	13600.00
0005432568597	4728	Economy	13600.00
0005432186929	4728	Economy	13600.00
0005432568650	4728	Economy	13600.00
0005432460690	4728	Economy	13600.00
0005432568614	4728	Economy	13600.00
0005432460340	30548	Business	40900.00
0005434082062	30548	Business	40900.00
0005432460456	30548	Business	40900.00
0005434082067	30548	Business	40900.00
0005434082117	30548	Business	40900.00
0005434082032	30548	Business	40900.00
0005432568098	30548	Business	40900.00
0005432460360	30548	Business	40900.00
0005432568092	30548	Business	40900.00
0005432567928	30548	Business	40900.00
0005432567799	30548	Business	40900.00
0005432568230	30548	Business	40900.00
0005432568050	30548	Business	40900.00
0005432568111	30548	Business	40900.00
0005432568332	30548	Business	40900.00
0005432460326	30548	Business	40900.00
0005432460465	30548	Business	40900.00
0005432568121	30548	Business	40900.00
0005432460299	30548	Business	40900.00
0005432567916	30548	Business	40900.00
0005435840367	30548	Business	40900.00
0005432459934	30548	Business	40900.00
0005432568049	30548	Business	40900.00
0005432213668	30548	Business	40900.00
0005432460339	30548	Economy	15000.00
0005432460386	30548	Economy	15000.00
0005432460221	30548	Economy	13600.00
0005432460461	30548	Economy	13600.00
0005432568260	30548	Economy	13600.00
0005432460333	30548	Economy	13600.00
0005432568227	30548	Economy	13600.00
0005434082020	30548	Economy	13600.00
0005432460412	30548	Economy	13600.00
0005432568041	30548	Economy	13600.00
0005432460312	30548	Economy	13600.00
0005432459979	30548	Economy	13600.00
0005432571354	30548	Economy	13600.00
0005432568023	30548	Economy	13600.00
0005432568261	30548	Economy	13600.00
0005434082122	30548	Economy	13600.00
0005432568262	30548	Economy	13600.00
0005432568208	30548	Economy	13600.00
0005434082076	30548	Economy	13600.00
0005432460503	30548	Economy	13600.00
0005432460426	30548	Economy	13600.00
0005432460219	30548	Economy	13600.00
0005434082019	30548	Economy	13600.00
0005432161190	30548	Economy	13600.00
0005433452757	30548	Economy	13600.00
0005432568038	30548	Economy	13600.00
0005432568093	30548	Economy	13600.00
0005432567905	30548	Economy	13600.00
0005432568069	30548	Economy	13600.00
0005432460311	30548	Economy	13600.00
0005434082018	30548	Economy	13600.00
0005434082042	30548	Economy	13600.00
0005432568035	30548	Economy	13600.00
0005432460303	30548	Economy	13600.00
0005432568051	30548	Economy	13600.00
0005433452756	30548	Economy	13600.00
0005432568113	30548	Economy	13600.00
0005435840370	30548	Economy	13600.00
0005432568047	30548	Economy	13600.00
0005432568370	30548	Economy	13600.00
0005434081993	30548	Economy	13600.00
0005435840369	30548	Economy	13600.00
0005432460459	30548	Economy	13600.00
0005432460313	30548	Economy	13600.00
0005432568186	30548	Economy	13600.00
0005432460251	30548	Economy	13600.00
0005434082121	30548	Economy	13600.00
0005432567897	30548	Economy	13600.00
0005435840372	30548	Economy	13600.00
0005432460341	30548	Economy	13600.00
0005432460348	30548	Economy	13600.00
0005434082002	30548	Economy	13600.00
0005432568166	30548	Economy	13600.00
0005432568195	30548	Economy	13600.00
0005432460109	30548	Economy	13600.00
0005435840375	30548	Economy	13600.00
0005434082114	30548	Economy	13600.00
0005432460466	30548	Economy	13600.00
0005432568036	30548	Economy	13600.00
0005432568090	30548	Economy	13600.00
0005432568204	30548	Economy	13600.00
0005432460415	30548	Economy	13600.00
0005432568040	30548	Economy	13600.00
0005432213665	30548	Economy	13600.00
0005432568244	30548	Economy	15000.00
0005435840374	30548	Economy	15000.00
0005432568347	30548	Economy	13600.00
0005434082009	30548	Economy	13600.00
0005432571344	30548	Economy	15000.00
0005432568210	30548	Economy	15000.00
0005432460393	30548	Economy	13600.00
0005432568209	30548	Economy	13600.00
0005432568037	30548	Economy	13600.00
0005432571345	30548	Economy	13600.00
0005432460110	30548	Economy	13600.00
0005432568325	30548	Economy	13600.00
0005433454898	30548	Economy	13600.00
0005432460446	30548	Economy	13600.00
0005432568022	30548	Economy	13600.00
0005432568194	30548	Economy	13600.00
0005432460397	30548	Economy	13600.00
0005435840371	30548	Economy	13600.00
0005432568322	30548	Economy	13600.00
0005432568193	30548	Economy	13600.00
0005432460359	30548	Economy	13600.00
0005432213667	30548	Economy	13600.00
0005434082003	30548	Economy	13600.00
0005434082115	30548	Economy	13600.00
0005432213666	30548	Economy	13600.00
0005432568243	30548	Economy	13600.00
0005434081939	30548	Economy	13600.00
0005435840365	30548	Economy	13600.00
0005434082153	30548	Economy	13600.00
0005432568123	30548	Economy	13600.00
0005432568114	30548	Economy	13600.00
0005432568112	30548	Economy	13600.00
0005432567949	30548	Economy	13600.00
0005432568080	30548	Economy	13600.00
0005432568242	30548	Economy	13600.00
0005432460325	30548	Economy	13600.00
0005434082033	30548	Economy	13600.00
0005435840366	30548	Economy	13600.00
0005432460241	30548	Economy	13600.00
0005432460278	30548	Economy	13600.00
0005432460427	30548	Economy	13600.00
0005434082066	30548	Economy	13600.00
0005432568058	30548	Economy	13600.00
0005432568124	30548	Economy	13600.00
0005432567841	30548	Economy	13600.00
0005432460356	30548	Economy	13600.00
0005432568091	30548	Economy	13600.00
0005432161189	30548	Economy	13600.00
0005435840373	30548	Economy	13600.00
0005432460392	30548	Economy	13600.00
0005434082038	30548	Economy	13600.00
0005432567924	30548	Economy	13600.00
0005435840364	30548	Economy	13600.00
0005434082152	30548	Economy	13600.00
0005432568234	30548	Economy	13600.00
0005432568071	30548	Economy	13600.00
0005435840368	30548	Economy	13600.00
0005434082075	30548	Economy	13600.00
0005432567977	30548	Economy	13600.00
0005432460504	30548	Economy	13600.00
0005432460460	30548	Economy	13600.00
0005435722093	13657	Economy	9900.00
0005435720842	13657	Economy	9900.00
0005435722094	13657	Economy	9900.00
0005435722068	21172	Economy	9900.00
0005435722058	21172	Economy	9900.00
0005435722069	21172	Economy	9900.00
0005432295922	22792	Economy	9700.00
0005432295924	22792	Economy	8800.00
0005432295921	22792	Economy	8800.00
0005432295923	22792	Economy	8800.00
0005433344824	11132	Business	23600.00
0005433344749	11132	Business	23600.00
0005433344831	11132	Business	23600.00
0005433344836	11132	Business	23600.00
0005433344822	11132	Business	23600.00
0005435097355	11132	Business	23600.00
0005433344783	11132	Business	23600.00
0005433344777	11132	Business	23600.00
0005433344759	11132	Business	23600.00
0005433344814	11132	Business	23600.00
0005433344786	11132	Business	23600.00
0005433344837	11132	Business	23600.00
0005433344767	11132	Economy	7900.00
0005433344746	11132	Economy	7900.00
0005433344764	11132	Economy	7900.00
0005433344750	11132	Economy	7900.00
0005433344766	11132	Economy	7900.00
0005433344781	11132	Economy	7900.00
0005433344745	11132	Economy	7900.00
0005433344794	11132	Economy	7900.00
0005433344838	11132	Economy	7900.00
0005433344835	11132	Economy	7900.00
0005433344763	11132	Economy	7900.00
0005435097363	11132	Economy	7900.00
0005435097357	11132	Economy	7900.00
0005433344793	11132	Economy	7900.00
0005435097361	11132	Economy	7900.00
0005435508438	11132	Economy	7900.00
0005435380321	11132	Economy	7900.00
0005433344833	11132	Economy	7900.00
0005435380322	11132	Economy	7900.00
0005433344807	11132	Economy	7900.00
0005433344839	11132	Economy	7900.00
0005433344797	11132	Economy	7900.00
0005433344776	11132	Economy	7900.00
0005433344825	11132	Economy	7900.00
0005433344803	11132	Economy	7900.00
0005433344760	11132	Economy	7900.00
0005435508443	11132	Economy	7900.00
0005433344784	11132	Economy	7900.00
0005433344787	11132	Economy	7900.00
0005433344747	11132	Economy	7900.00
0005433344811	11132	Economy	7900.00
0005433344829	11132	Economy	7900.00
0005433344816	11132	Economy	7900.00
0005433344800	11132	Economy	7900.00
0005433344742	11132	Economy	7900.00
0005435508410	11132	Economy	7900.00
0005433344768	11132	Economy	7900.00
0005433344788	11132	Economy	7900.00
0005433344834	11132	Economy	8600.00
0005433344772	11132	Economy	8600.00
0005433344738	11132	Economy	8600.00
0005433344804	11132	Economy	8600.00
0005433344832	11132	Economy	8600.00
0005433344791	11132	Economy	8600.00
0005433344758	11132	Economy	7900.00
0005433344756	11132	Economy	7900.00
0005435380332	11132	Economy	7900.00
0005433344753	11132	Economy	7900.00
0005433344789	11132	Economy	7900.00
0005435097360	11132	Economy	7900.00
0005435097362	11132	Economy	7900.00
0005433344779	11132	Economy	7900.00
0005433344755	11132	Economy	7900.00
0005433344782	11132	Economy	7900.00
0005433344802	11132	Economy	7900.00
0005433344799	11132	Economy	7900.00
0005433344775	11132	Economy	7900.00
0005433344796	11132	Economy	7900.00
0005433344761	11132	Economy	7900.00
0005433344773	11132	Economy	7900.00
0005433344818	11132	Economy	7900.00
0005435097364	11132	Economy	7900.00
0005433344739	11132	Economy	7900.00
0005433344785	11132	Economy	7900.00
0005433344795	11132	Economy	7900.00
0005435508411	11132	Economy	7900.00
0005433344790	11132	Economy	7900.00
0005433344827	11132	Economy	7900.00
0005433344817	11132	Economy	7900.00
0005433344823	11132	Economy	7900.00
0005435508432	11132	Economy	7900.00
0005433344828	11132	Economy	7900.00
0005433344805	11132	Economy	7900.00
0005433344809	11132	Economy	7900.00
0005433344740	11132	Economy	7900.00
0005433344812	11132	Economy	7900.00
0005433344752	11132	Economy	7900.00
0005433344820	11132	Economy	7900.00
0005433344801	11132	Economy	7900.00
0005433344792	11132	Economy	7900.00
0005435508409	11132	Economy	7900.00
0005433344751	11132	Economy	7900.00
0005435508412	11132	Economy	7900.00
0005433344813	11132	Economy	7900.00
0005433344821	11132	Economy	7900.00
0005433344808	11132	Economy	7900.00
0005433344815	11132	Economy	7900.00
0005433344778	11132	Economy	7900.00
0005433344770	11132	Economy	7900.00
0005433344774	11132	Economy	7900.00
0005435508426	11132	Economy	7900.00
0005435097354	11132	Economy	7900.00
0005433344826	11132	Economy	7900.00
0005435097359	11132	Economy	7900.00
0005433344741	11132	Economy	7900.00
0005435097356	11132	Economy	7900.00
0005433344757	11132	Economy	7900.00
0005433344780	11132	Economy	7900.00
0005433344744	11132	Economy	7900.00
0005435508425	11132	Economy	7900.00
0005435508439	11132	Economy	7900.00
0005433344743	11132	Economy	7900.00
0005433344754	11132	Economy	7900.00
0005435097358	11132	Economy	7900.00
0005433344748	11132	Economy	7900.00
0005433344769	11132	Economy	7900.00
0005433344762	11132	Economy	7900.00
0005433344830	11132	Economy	7900.00
0005433344819	11132	Economy	7900.00
0005433344771	11132	Economy	7900.00
0005433344806	11132	Economy	7900.00
0005433344810	11132	Economy	7900.00
0005433344798	11132	Economy	7900.00
0005433344765	11132	Economy	7900.00
0005433343618	17104	Business	23600.00
0005433344086	17104	Business	23600.00
0005433343912	17104	Business	23600.00
0005433343634	17104	Business	23600.00
0005433343458	17104	Business	23600.00
0005433344015	17104	Business	23600.00
0005435097280	17104	Business	23600.00
0005435545863	17104	Business	23600.00
0005435545856	17104	Business	23600.00
0005433343723	17104	Business	23600.00
0005433343883	17104	Business	23600.00
0005435545854	17104	Economy	7900.00
0005435097272	17104	Economy	7900.00
0005435097296	17104	Economy	7900.00
0005433343876	17104	Economy	7900.00
0005433344039	17104	Economy	7900.00
0005433343745	17104	Economy	7900.00
0005435097250	17104	Economy	7900.00
0005433343782	17104	Economy	7900.00
0005433343926	17104	Economy	7900.00
0005433343600	17104	Economy	7900.00
0005433343599	17104	Economy	7900.00
0005433343395	17104	Economy	7900.00
0005433343925	17104	Economy	7900.00
0005435380379	17104	Economy	7900.00
0005433344520	17104	Economy	7900.00
0005433343671	17104	Economy	7900.00
0005433344247	17104	Economy	7900.00
0005433343422	17104	Economy	7900.00
0005433343478	17104	Economy	7900.00
0005433343642	17104	Economy	7900.00
0005433344078	17104	Economy	7900.00
0005433343631	17104	Economy	7900.00
0005435545859	17104	Economy	7900.00
0005433344046	17104	Economy	7900.00
0005433343917	17104	Economy	7900.00
0005433343813	17104	Economy	7900.00
0005433344037	17104	Economy	7900.00
0005433343856	17104	Economy	7900.00
0005433343911	17104	Economy	7900.00
0005435545858	17104	Economy	7900.00
0005435380377	17104	Economy	7900.00
0005433343803	17104	Economy	7900.00
0005435545865	17104	Economy	7900.00
0005433343617	17104	Economy	7900.00
0005433343467	17104	Economy	7900.00
0005433343865	17104	Economy	7900.00
0005435097270	17104	Economy	7900.00
0005433343994	17104	Economy	7900.00
0005433343523	17104	Economy	7900.00
0005433344077	17104	Economy	7900.00
0005433343760	17104	Economy	8600.00
0005435545862	17104	Economy	8600.00
0005435545864	17104	Economy	8600.00
0005435097268	17104	Economy	8600.00
0005433344519	17104	Economy	8600.00
0005433343888	17104	Economy	8600.00
0005433343934	17104	Economy	7900.00
0005433343703	17104	Economy	7900.00
0005435545853	17104	Economy	7900.00
0005435097271	17104	Economy	7900.00
0005433343995	17104	Economy	7900.00
0005433343847	17104	Economy	7900.00
0005432293248	17104	Economy	7900.00
0005433343979	17104	Economy	7900.00
0005435545855	17104	Economy	7900.00
0005435097291	17104	Economy	7900.00
0005433343354	17104	Economy	7900.00
0005433343764	17104	Economy	7900.00
0005433343466	17104	Economy	7900.00
0005433343451	17104	Economy	7900.00
0005433343826	17104	Economy	7900.00
0005433343860	17104	Economy	7900.00
0005433343825	17104	Economy	7900.00
0005435097292	17104	Economy	7900.00
0005435097261	17104	Economy	7900.00
0005433343710	17104	Economy	7900.00
0005433344318	17104	Economy	7900.00
0005433343997	17104	Economy	7900.00
0005433344246	17104	Economy	7900.00
0005435097282	17104	Economy	7900.00
0005433343844	17104	Economy	7900.00
0005433344018	17104	Economy	7900.00
0005435545857	17104	Economy	7900.00
0005435097297	17104	Economy	7900.00
0005433343756	17104	Economy	7900.00
0005433343809	17104	Economy	7900.00
0005433343904	17104	Economy	7900.00
0005433343327	17104	Economy	7900.00
0005433343269	17104	Economy	7900.00
0005433343882	17104	Economy	7900.00
0005433343722	17104	Economy	7900.00
0005433343843	17104	Economy	7900.00
0005433343704	17104	Economy	7900.00
0005433343802	17104	Economy	7900.00
0005435380376	17104	Economy	7900.00
0005433344193	17104	Economy	7900.00
0005433343875	17104	Economy	7900.00
0005435545861	17104	Economy	7900.00
0005435097281	17104	Economy	7900.00
0005435545860	17104	Economy	7900.00
0005433344194	17104	Economy	7900.00
0005433343720	17104	Economy	7900.00
0005433343828	17104	Economy	7900.00
0005433343581	17104	Economy	7900.00
0005433343524	17104	Economy	7900.00
0005433343672	17104	Economy	7900.00
0005435380375	17104	Economy	7900.00
0005433343978	17104	Economy	7900.00
0005435097258	17104	Economy	7900.00
0005433343829	17104	Economy	7900.00
0005433343394	17104	Economy	7900.00
0005433344429	17104	Economy	7900.00
0005433343721	17104	Economy	7900.00
0005433343814	17104	Economy	7900.00
0005433344076	17104	Economy	7900.00
0005435380374	17104	Economy	7900.00
0005433343817	17104	Economy	7900.00
0005433343759	17104	Economy	7900.00
0005435380378	17104	Economy	7900.00
0005433343168	17104	Economy	7900.00
0005432293247	17104	Economy	7900.00
0005433343578	17104	Economy	7900.00
0005433343601	17104	Economy	7900.00
0005433343861	17104	Economy	7900.00
0005433343355	17104	Economy	7900.00
0005433343457	17104	Economy	7900.00
0005434158990	9073	Business	26600.00
0005432920043	9073	Business	26600.00
0005433481292	9073	Business	26600.00
0005432920031	9073	Business	26600.00
0005434159004	9073	Business	26600.00
0005433507467	9073	Business	26600.00
0005433507468	9073	Economy	8900.00
0005432919983	9073	Economy	8900.00
0005433507464	9073	Economy	8900.00
0005432919981	9073	Economy	8900.00
0005433507456	9073	Economy	8900.00
0005434159001	9073	Economy	8900.00
0005433507466	9073	Economy	8900.00
0005433507457	9073	Economy	9800.00
0005433507451	9073	Economy	9800.00
0005433481291	9073	Economy	9800.00
0005433507455	9073	Economy	8900.00
0005432920069	9073	Economy	8900.00
0005432919957	9073	Economy	8900.00
0005433507462	9073	Economy	8900.00
0005433507461	9073	Economy	8900.00
0005433507469	9073	Economy	8900.00
0005433481297	9073	Economy	8900.00
0005434159005	9073	Economy	8900.00
0005432919958	9073	Economy	8900.00
0005433507463	9073	Economy	8900.00
0005433507459	9073	Economy	8900.00
0005432919979	9073	Economy	8900.00
0005433507453	9073	Economy	8900.00
0005432920070	9073	Economy	8900.00
0005433481296	9073	Economy	8900.00
0005433476957	9073	Economy	8900.00
0005433507454	9073	Economy	8900.00
0005433507470	9073	Economy	8900.00
0005433507465	9073	Economy	8900.00
0005433481295	9073	Economy	8900.00
0005433507452	9073	Economy	8900.00
0005434158996	9073	Economy	8900.00
0005433507460	9073	Economy	8900.00
0005432920068	9073	Economy	8900.00
0005434158978	9073	Economy	8900.00
0005433481294	9073	Economy	8900.00
0005432920049	9073	Economy	8900.00
0005434158998	9073	Economy	8900.00
0005432919989	9073	Economy	8900.00
0005433481298	9073	Economy	8900.00
0005433507458	9073	Economy	8900.00
0005432919971	9073	Economy	8900.00
0005432920014	9073	Economy	8900.00
0005432919959	9073	Economy	8900.00
0005433481293	9073	Economy	8900.00
0005433507305	20456	Business	26600.00
0005433507349	20456	Business	26600.00
0005433481223	20456	Business	26600.00
0005433507347	20456	Business	26600.00
0005433507328	20456	Business	26600.00
0005433507346	20456	Business	26600.00
0005433481254	20456	Business	26600.00
0005433507303	20456	Business	26600.00
0005432920214	20456	Economy	8900.00
0005432920217	20456	Economy	8900.00
0005432920222	20456	Economy	9800.00
0005432920225	20456	Economy	8900.00
0005433481246	20456	Economy	8900.00
0005432920226	20456	Economy	8900.00
0005432920220	20456	Economy	8900.00
0005432920213	20456	Economy	8900.00
0005433507331	20456	Economy	8900.00
0005433507326	20456	Economy	8900.00
0005433507351	20456	Economy	8900.00
0005432920221	20456	Economy	8900.00
0005432920218	20456	Economy	8900.00
0005432920209	20456	Economy	8900.00
0005432920210	20456	Economy	8900.00
0005433481239	20456	Economy	8900.00
0005432920229	20456	Economy	8900.00
0005433481238	20456	Economy	8900.00
0005433507341	20456	Economy	8900.00
0005432920223	20456	Economy	8900.00
0005432920228	20456	Economy	8900.00
0005432920219	20456	Economy	8900.00
0005432920216	20456	Economy	8900.00
0005433507307	20456	Economy	8900.00
0005433507350	20456	Economy	8900.00
0005433481221	20456	Economy	8900.00
0005432920224	20456	Economy	8900.00
0005433481222	20456	Economy	8900.00
0005433507327	20456	Economy	8900.00
0005433507229	20456	Economy	8900.00
0005432920212	20456	Economy	8900.00
0005433507345	20456	Economy	8900.00
0005433507306	20456	Economy	8900.00
0005432920211	20456	Economy	8900.00
0005432920215	20456	Economy	8900.00
0005433507291	20456	Economy	8900.00
0005433481270	20456	Economy	8900.00
0005432920227	20456	Economy	8900.00
0005432396304	10167	Economy	5800.00
0005435179696	10167	Economy	5800.00
0005432394166	10167	Economy	5800.00
0005432396306	10167	Economy	5800.00
0005432394165	10167	Economy	5800.00
0005432396305	10167	Economy	5800.00
0005432394167	10167	Economy	5800.00
0005432400155	18363	Economy	5800.00
0005432396272	18363	Economy	5800.00
0005432396277	18363	Economy	5800.00
0005432396276	18363	Economy	5800.00
0005432396281	18363	Economy	5800.00
0005432400154	18363	Economy	5800.00
0005432396282	18363	Economy	5800.00
0005432400172	18363	Economy	5800.00
0005432400171	18363	Economy	5800.00
0005432400168	18363	Economy	5800.00
0005435126804	10948	Business	9500.00
0005434928345	10948	Business	9500.00
0005435126703	10948	Business	9500.00
0005435126661	10948	Business	9500.00
0005435126660	10948	Business	9500.00
0005434411847	10948	Business	9500.00
0005434411850	10948	Business	9500.00
0005435126707	10948	Business	9500.00
0005434928346	10948	Business	9500.00
0005435126679	10948	Business	9500.00
0005435126593	10948	Economy	3200.00
0005435126763	10948	Economy	3200.00
0005435126662	10948	Economy	3200.00
0005435126611	10948	Economy	3200.00
0005434411849	10948	Economy	3200.00
0005435126601	10948	Economy	3200.00
0005435126592	10948	Economy	3200.00
0005435126706	10948	Economy	3200.00
0005435126644	10948	Economy	3500.00
0005435626195	10948	Economy	3500.00
0005435126669	10948	Economy	3500.00
0005435126736	10948	Economy	3500.00
0005435126602	10948	Economy	3200.00
0005435126695	10948	Economy	3200.00
0005435126713	10948	Economy	3200.00
0005435126518	10948	Economy	3200.00
0005435126596	10948	Economy	3200.00
0005435126603	10948	Economy	3200.00
0005435126767	10948	Economy	3200.00
0005435126586	10948	Economy	3200.00
0005435626194	10948	Economy	3200.00
0005434928348	10948	Economy	3200.00
0005435126745	10948	Economy	3200.00
0005435126587	10948	Economy	3200.00
0005435626245	10948	Economy	3200.00
0005434411848	10948	Economy	3200.00
0005435126543	10948	Economy	3200.00
0005435126604	10948	Economy	3200.00
0005435126626	10948	Economy	3200.00
0005435126746	10948	Economy	3200.00
0005435126769	10948	Economy	3200.00
0005435126685	10948	Economy	3200.00
0005435626225	10948	Economy	3200.00
0005435126667	10948	Economy	3200.00
0005435126663	10948	Economy	3200.00
0005435554221	10948	Economy	3200.00
0005435126687	10948	Economy	3200.00
0005435126588	10948	Economy	3200.00
0005435126595	10948	Economy	3200.00
0005435126680	10948	Economy	3200.00
0005435126751	10948	Economy	3200.00
0005435126778	10948	Economy	3200.00
0005435126650	10948	Economy	3200.00
0005435626235	10948	Economy	3200.00
0005435126597	10948	Economy	3200.00
0005435126550	10948	Economy	3200.00
0005435554225	10948	Economy	3200.00
0005435126600	10948	Economy	3200.00
0005435126768	10948	Economy	3200.00
0005435126628	10948	Economy	3200.00
0005435126659	10948	Economy	3200.00
0005435126671	10948	Economy	3200.00
0005435126686	10948	Economy	3200.00
0005435126839	10948	Economy	3200.00
0005435126516	10948	Economy	3200.00
0005435626260	10948	Economy	3200.00
0005435126652	10948	Economy	3200.00
0005435554226	10948	Economy	3200.00
0005435126579	10948	Economy	3200.00
0005435126513	10948	Economy	3200.00
0005435626215	10948	Economy	3200.00
0005434928347	10948	Economy	3200.00
0005435126674	10948	Economy	3200.00
0005435126675	10948	Economy	3200.00
0005435126619	10948	Economy	3200.00
0005435554220	10948	Economy	3200.00
0005435126698	10948	Economy	3200.00
0005435126696	10948	Economy	3200.00
0005435126629	10948	Economy	3200.00
0005435626230	10948	Economy	3200.00
0005435126676	10948	Economy	3200.00
0005435126668	10948	Economy	3200.00
0005434411851	10948	Economy	3200.00
0005435626271	10948	Economy	3200.00
0005435126643	10948	Economy	3200.00
0005435126563	10948	Economy	3200.00
0005435626481	14754	Business	9500.00
0005435127038	14754	Business	9500.00
0005435626484	14754	Business	9500.00
0005435626466	14754	Business	9500.00
0005435626464	14754	Business	9500.00
0005435127040	14754	Business	9500.00
0005435127021	14754	Business	9500.00
0005435554266	14754	Business	9500.00
0005435127045	14754	Business	9500.00
0005435626479	14754	Business	9500.00
0005435127058	14754	Business	9500.00
0005435127039	14754	Business	9500.00
0005434928331	14754	Economy	3200.00
0005435626467	14754	Economy	3200.00
0005435127055	14754	Economy	3200.00
0005435127048	14754	Economy	3200.00
0005435127056	14754	Economy	3200.00
0005435626474	14754	Economy	3200.00
0005435626475	14754	Economy	3200.00
0005435127037	14754	Economy	3500.00
0005435127031	14754	Economy	3500.00
0005435127054	14754	Economy	3500.00
0005434928322	14754	Economy	3500.00
0005435554261	14754	Economy	3500.00
0005435626472	14754	Economy	3200.00
0005435626468	14754	Economy	3200.00
0005435127060	14754	Economy	3200.00
0005435127043	14754	Economy	3200.00
0005435626480	14754	Economy	3200.00
0005435626476	14754	Economy	3200.00
0005435556734	14754	Economy	3200.00
0005435127049	14754	Economy	3200.00
0005435127030	14754	Economy	3200.00
0005435127044	14754	Economy	3200.00
0005435127034	14754	Economy	3200.00
0005435626477	14754	Economy	3200.00
0005435127053	14754	Economy	3200.00
0005435626471	14754	Economy	3200.00
0005435554265	14754	Economy	3200.00
0005435127033	14754	Economy	3200.00
0005435127025	14754	Economy	3200.00
0005435127026	14754	Economy	3200.00
0005435554262	14754	Economy	3200.00
0005435127028	14754	Economy	3200.00
0005435626473	14754	Economy	3200.00
0005435127042	14754	Economy	3200.00
0005435626486	14754	Economy	3200.00
0005435626485	14754	Economy	3200.00
0005435127046	14754	Economy	3200.00
0005435127047	14754	Economy	3200.00
0005435127050	14754	Economy	3200.00
0005435127059	14754	Economy	3200.00
0005434411789	14754	Economy	3200.00
0005435554263	14754	Economy	3200.00
0005435127024	14754	Economy	3200.00
0005435127061	14754	Economy	3200.00
0005434411804	14754	Economy	3200.00
0005435127041	14754	Economy	3200.00
0005435127051	14754	Economy	3200.00
0005435626470	14754	Economy	3200.00
0005435127057	14754	Economy	3200.00
0005435127062	14754	Economy	3200.00
0005435127032	14754	Economy	3200.00
0005435556732	14754	Economy	3200.00
0005435127027	14754	Economy	3200.00
0005434928330	14754	Economy	3200.00
0005435127023	14754	Economy	3200.00
0005435626483	14754	Economy	3200.00
0005435127052	14754	Economy	3200.00
0005435626465	14754	Economy	3200.00
0005435127035	14754	Economy	3200.00
0005435556733	14754	Economy	3200.00
0005435127036	14754	Economy	3200.00
0005435127022	14754	Economy	3200.00
0005435626478	14754	Economy	3200.00
0005435626469	14754	Economy	3200.00
0005435626482	14754	Economy	3200.00
0005435127029	14754	Economy	3200.00
0005435554264	14754	Economy	3200.00
0005432400187	7123	Business	86900.00
0005435715757	7123	Business	86900.00
0005435443344	7123	Business	86900.00
0005432400183	7123	Business	86900.00
0005435443352	7123	Business	86900.00
0005435715751	7123	Business	86900.00
0005435715758	7123	Economy	29000.00
0005435715753	7123	Economy	29000.00
0005435715756	7123	Economy	29000.00
0005435715746	7123	Economy	29000.00
0005435443380	7123	Economy	29000.00
0005435715744	7123	Economy	31900.00
0005435443367	7123	Economy	31900.00
0005435216601	7123	Economy	29000.00
0005435221063	7123	Economy	29000.00
0005432400185	7123	Economy	29000.00
0005432400186	7123	Economy	29000.00
0005435715743	7123	Economy	29000.00
0005435715745	7123	Economy	29000.00
0005435221062	7123	Economy	29000.00
0005435219212	7123	Economy	29000.00
0005435715741	7123	Economy	29000.00
0005435715742	7123	Economy	29000.00
0005432398259	7123	Economy	29000.00
0005435715752	7123	Economy	29000.00
0005435715755	7123	Economy	29000.00
0005435216600	7123	Economy	29000.00
0005435443390	7123	Economy	29000.00
0005435443406	7123	Economy	29000.00
0005435443389	7123	Economy	29000.00
0005435443378	7123	Economy	29000.00
0005432398258	7123	Economy	29000.00
0005435443345	7123	Economy	29000.00
0005435443366	7123	Economy	29000.00
0005435443377	7123	Economy	29000.00
0005435219205	7123	Economy	29000.00
0005435443379	7123	Economy	29000.00
0005435219209	7123	Economy	29000.00
0005435443357	7123	Economy	29000.00
0005435443356	7123	Economy	29000.00
0005432398260	7123	Economy	29000.00
0005435219210	7123	Economy	29000.00
0005435715750	7123	Economy	29000.00
0005432400184	7123	Economy	29000.00
0005435715749	7123	Economy	29000.00
0005435715747	7123	Economy	29000.00
0005435715748	7123	Economy	29000.00
0005435715754	7123	Economy	29000.00
0005435178510	7123	Economy	29000.00
0005435178505	7123	Economy	29000.00
0005435715649	27067	Business	86900.00
0005435443468	27067	Business	86900.00
0005435179005	27067	Business	86900.00
0005435715610	27067	Economy	29000.00
0005435443469	27067	Economy	29000.00
0005435443473	27067	Economy	29000.00
0005435715675	27067	Economy	31900.00
0005432394129	27067	Economy	29000.00
0005435715671	27067	Economy	29000.00
0005435443464	27067	Economy	29000.00
0005435715633	27067	Economy	29000.00
0005435178519	27067	Economy	29000.00
0005435715662	27067	Economy	29000.00
0005435715607	27067	Economy	29000.00
0005435715611	27067	Economy	29000.00
0005435715663	27067	Economy	29000.00
0005435715559	27067	Economy	29000.00
0005435443470	27067	Economy	29000.00
0005432398221	27067	Economy	29000.00
0005435443465	27067	Economy	29000.00
0005435178518	27067	Economy	29000.00
0005435715632	27067	Economy	29000.00
0005435715620	27067	Economy	29000.00
0005435715619	27067	Economy	29000.00
0005435715582	27067	Economy	29000.00
0005435179006	27067	Economy	29000.00
0005435443466	27067	Economy	29000.00
0005435715568	27067	Economy	29000.00
0005435715609	27067	Economy	29000.00
0005435715605	27067	Economy	29000.00
0005435715674	27067	Economy	29000.00
0005435443471	27067	Economy	29000.00
0005435443463	27067	Economy	29000.00
0005435443474	27067	Economy	29000.00
0005435715648	27067	Economy	29000.00
0005432394130	27067	Economy	29000.00
0005435715673	27067	Economy	29000.00
0005435715606	27067	Economy	29000.00
0005432398222	27067	Economy	29000.00
0005435443467	27067	Economy	29000.00
0005435715672	27067	Economy	29000.00
0005435443472	27067	Economy	29000.00
0005433060425	2756	Economy	7700.00
0005433060420	2756	Economy	7700.00
0005434085007	2756	Economy	7700.00
0005434085008	2756	Economy	7700.00
0005434085006	2756	Economy	7700.00
0005433060424	2756	Economy	7700.00
0005433060445	2756	Economy	7700.00
0005434084964	28488	Economy	7700.00
0005434084977	28488	Economy	7700.00
0005434084950	28488	Economy	7700.00
0005433060458	28488	Economy	7700.00
0005434084963	28488	Economy	7700.00
0005434084968	28488	Economy	7700.00
0005434084962	28488	Economy	7700.00
0005434084969	28488	Economy	7700.00
0005435541158	11420	Business	20200.00
0005435518039	11420	Business	20200.00
0005435541142	11420	Business	20200.00
0005435518017	11420	Business	20200.00
0005435541164	11420	Business	20200.00
0005435541202	11420	Business	20200.00
0005435541229	11420	Business	20200.00
0005435517932	11420	Business	20200.00
0005435518112	11420	Economy	6700.00
0005435518072	11420	Economy	6700.00
0005435518092	11420	Economy	6700.00
0005435518107	11420	Economy	6700.00
0005435518091	11420	Economy	6700.00
0005435541198	11420	Economy	7400.00
0005435518084	11420	Economy	6700.00
0005435541183	11420	Economy	6700.00
0005435541160	11420	Economy	6700.00
0005435541228	11420	Economy	6700.00
0005435518040	11420	Economy	6700.00
0005435541165	11420	Economy	6700.00
0005435518147	11420	Economy	6700.00
0005435541161	11420	Economy	6700.00
0005435518028	11420	Economy	6700.00
0005435541152	11420	Economy	6700.00
0005435541254	11420	Economy	6700.00
0005435541127	11420	Economy	6700.00
0005435541001	11420	Economy	6700.00
0005435541094	11420	Economy	6700.00
0005435518058	11420	Economy	6700.00
0005435541216	11420	Economy	6700.00
0005435518148	11420	Economy	6700.00
0005435518071	11420	Economy	6700.00
0005435541241	11420	Economy	6700.00
0005435518086	11420	Economy	6700.00
0005435541143	11420	Economy	6700.00
0005435518005	11420	Economy	6700.00
0005435541141	11420	Economy	6700.00
0005435518021	11420	Economy	6700.00
0005435518149	11420	Economy	6700.00
0005435518085	11420	Economy	6700.00
0005435541171	11420	Economy	6700.00
0005435541153	11420	Economy	6700.00
0005435541172	11420	Economy	6700.00
0005435541187	11420	Economy	6700.00
0005435518038	11420	Economy	6700.00
0005435518052	11420	Economy	6700.00
0005435518068	11420	Economy	6700.00
0005435518059	11420	Economy	6700.00
0005435541255	11420	Economy	6700.00
0005435541215	11420	Economy	6700.00
0005435518057	11420	Economy	6700.00
0005435541201	11420	Economy	6700.00
0005435518042	11420	Economy	6700.00
0005435541341	22224	Business	20200.00
0005435541351	22224	Business	20200.00
0005435529591	22224	Business	20200.00
0005435541337	22224	Business	20200.00
0005435529595	22224	Business	20200.00
0005435529593	22224	Business	20200.00
0005435529601	22224	Economy	6700.00
0005435529594	22224	Economy	6700.00
0005435529602	22224	Economy	6700.00
0005435541340	22224	Economy	6700.00
0005435541344	22224	Economy	6700.00
0005435541335	22224	Economy	7400.00
0005435541348	22224	Economy	7400.00
0005435529599	22224	Economy	6700.00
0005435529607	22224	Economy	6700.00
0005435541345	22224	Economy	6700.00
0005435529977	22224	Economy	6700.00
0005435541347	22224	Economy	6700.00
0005435541353	22224	Economy	6700.00
0005435529976	22224	Economy	6700.00
0005435541332	22224	Economy	6700.00
0005435541352	22224	Economy	6700.00
0005435541343	22224	Economy	6700.00
0005435541333	22224	Economy	6700.00
0005435529600	22224	Economy	6700.00
0005435529603	22224	Economy	6700.00
0005435529597	22224	Economy	6700.00
0005435529608	22224	Economy	6700.00
0005435529598	22224	Economy	6700.00
0005435529604	22224	Economy	6700.00
0005435541346	22224	Economy	6700.00
0005435529978	22224	Economy	6700.00
0005435529609	22224	Economy	6700.00
0005435541349	22224	Economy	6700.00
0005435541338	22224	Economy	6700.00
0005435529605	22224	Economy	6700.00
0005435541339	22224	Economy	6700.00
0005432294524	22224	Economy	6700.00
0005435529596	22224	Economy	6700.00
0005435541336	22224	Economy	6700.00
0005435541350	22224	Economy	6700.00
0005435529590	22224	Economy	6700.00
0005435529588	22224	Economy	6700.00
0005432294525	22224	Economy	6700.00
0005435541334	22224	Economy	6700.00
0005435529592	22224	Economy	6700.00
0005435541342	22224	Economy	6700.00
0005435529606	22224	Economy	6700.00
0005435529589	22224	Economy	6700.00
0005433251715	2316	Business	20200.00
0005434908148	2316	Business	20200.00
0005433251859	2316	Business	20200.00
0005433251687	2316	Business	20200.00
0005434908132	2316	Business	20200.00
0005434908139	2316	Business	20200.00
0005433251812	2316	Business	20200.00
0005433251705	2316	Business	20200.00
0005433251748	2316	Business	20200.00
0005433251757	2316	Business	20200.00
0005434908156	2316	Business	20200.00
0005434908150	2316	Economy	6700.00
0005434908149	2316	Economy	6700.00
0005434908152	2316	Economy	6700.00
0005433251805	2316	Economy	6700.00
0005434908146	2316	Economy	6700.00
0005433251620	2316	Economy	6700.00
0005434908134	2316	Economy	6700.00
0005433251828	2316	Economy	6700.00
0005433251745	2316	Economy	6700.00
0005434908159	2316	Economy	6700.00
0005434908157	2316	Economy	7400.00
0005433251710	2316	Economy	7400.00
0005433401014	2316	Economy	7400.00
0005433401012	2316	Economy	7400.00
0005433251581	2316	Economy	7400.00
0005433251688	2316	Economy	6700.00
0005434908142	2316	Economy	6700.00
0005434908151	2316	Economy	6700.00
0005433251806	2316	Economy	6700.00
0005433251803	2316	Economy	6700.00
0005434908162	2316	Economy	6700.00
0005433251772	2316	Economy	6700.00
0005433251817	2316	Economy	6700.00
0005434908131	2316	Economy	6700.00
0005433251762	2316	Economy	6700.00
0005433251579	2316	Economy	6700.00
0005434908126	2316	Economy	6700.00
0005434908160	2316	Economy	6700.00
0005434908129	2316	Economy	6700.00
0005433251731	2316	Economy	6700.00
0005433251843	2316	Economy	6700.00
0005433251739	2316	Economy	6700.00
0005433251706	2316	Economy	6700.00
0005434908158	2316	Economy	6700.00
0005433251667	2316	Economy	6700.00
0005433251747	2316	Economy	6700.00
0005433251707	2316	Economy	6700.00
0005433251732	2316	Economy	6700.00
0005433401010	2316	Economy	6700.00
0005434908145	2316	Economy	6700.00
0005434908137	2316	Economy	6700.00
0005433251901	2316	Economy	6700.00
0005434908147	2316	Economy	6700.00
0005433251847	2316	Economy	6700.00
0005433251761	2316	Economy	6700.00
0005434908133	2316	Economy	6700.00
0005433251668	2316	Economy	6700.00
0005433251662	2316	Economy	6700.00
0005433251900	2316	Economy	6700.00
0005434908128	2316	Economy	6700.00
0005434908138	2316	Economy	6700.00
0005433401013	2316	Economy	6700.00
0005433251723	2316	Economy	6700.00
0005434908161	2316	Economy	6700.00
0005434908130	2316	Economy	6700.00
0005434908144	2316	Economy	6700.00
0005433251624	2316	Economy	6700.00
0005434908140	2316	Economy	6700.00
0005434908136	2316	Economy	6700.00
0005434908155	2316	Economy	6700.00
0005433251804	2316	Economy	6700.00
0005434908143	2316	Economy	6700.00
0005433251625	2316	Economy	6700.00
0005434908153	2316	Economy	6700.00
0005434908154	2316	Economy	6700.00
0005434908127	2316	Economy	6700.00
0005433401011	2316	Economy	6700.00
0005433251711	2316	Economy	6700.00
0005434908141	2316	Economy	6700.00
0005433251686	2316	Economy	6700.00
0005433251740	2316	Economy	6700.00
0005433251580	2316	Economy	6700.00
0005433251881	2316	Economy	6700.00
0005434908135	2316	Economy	6700.00
0005433251827	2316	Economy	6700.00
0005433251741	2316	Economy	6700.00
0005433251842	2316	Economy	6700.00
0005434907716	25628	Business	20200.00
0005434907645	25628	Business	20200.00
0005434907759	25628	Business	20200.00
0005434907599	25628	Business	20200.00
0005433251995	25628	Business	20200.00
0005433251988	25628	Business	20200.00
0005434907582	25628	Business	20200.00
0005433401033	25628	Business	20200.00
0005434907749	25628	Business	20200.00
0005434907533	25628	Business	20200.00
0005433252001	25628	Business	20200.00
0005434907694	25628	Economy	6700.00
0005433251997	25628	Economy	6700.00
0005434907612	25628	Economy	6700.00
0005433251980	25628	Economy	6700.00
0005434907763	25628	Economy	6700.00
0005434907553	25628	Economy	6700.00
0005434907556	25628	Economy	6700.00
0005434907747	25628	Economy	6700.00
0005434907668	25628	Economy	6700.00
0005434907673	25628	Economy	6700.00
0005434907583	25628	Economy	7400.00
0005433401034	25628	Economy	7400.00
0005433251982	25628	Economy	7400.00
0005434907764	25628	Economy	7400.00
0005433251985	25628	Economy	7400.00
0005433251990	25628	Economy	6700.00
0005434907548	25628	Economy	6700.00
0005433251977	25628	Economy	6700.00
0005434907621	25628	Economy	6700.00
0005434907456	25628	Economy	6700.00
0005434907561	25628	Economy	6700.00
0005433251993	25628	Economy	6700.00
0005433251998	25628	Economy	6700.00
0005433251972	25628	Economy	6700.00
0005434907609	25628	Economy	6700.00
0005433251976	25628	Economy	6700.00
0005434907643	25628	Economy	6700.00
0005434907511	25628	Economy	6700.00
0005433251979	25628	Economy	6700.00
0005434907623	25628	Economy	6700.00
0005434907547	25628	Economy	6700.00
0005433251996	25628	Economy	6700.00
0005434907532	25628	Economy	6700.00
0005433251987	25628	Economy	6700.00
0005434907565	25628	Economy	6700.00
0005433251989	25628	Economy	6700.00
0005434907622	25628	Economy	6700.00
0005434907542	25628	Economy	6700.00
0005434907669	25628	Economy	6700.00
0005434907695	25628	Economy	6700.00
0005434907464	25628	Economy	6700.00
0005433251984	25628	Economy	6700.00
0005434907680	25628	Economy	6700.00
0005434907738	25628	Economy	6700.00
0005433401035	25628	Economy	6700.00
0005433251978	25628	Economy	6700.00
0005433401032	25628	Economy	6700.00
0005434907765	25628	Economy	6700.00
0005433251974	25628	Economy	6700.00
0005434907638	25628	Economy	6700.00
0005433251991	25628	Economy	6700.00
0005434907538	25628	Economy	6700.00
0005434907523	25628	Economy	6700.00
0005433251975	25628	Economy	6700.00
0005434907655	25628	Economy	6700.00
0005434907642	25628	Economy	6700.00
0005433251994	25628	Economy	6700.00
0005433251971	25628	Economy	6700.00
0005433251999	25628	Economy	6700.00
0005434907751	25628	Economy	6700.00
0005434907633	25628	Economy	6700.00
0005433251992	25628	Economy	6700.00
0005433251983	25628	Economy	6700.00
0005434907478	25628	Economy	6700.00
0005434907543	25628	Economy	6700.00
0005434907691	25628	Economy	6700.00
0005434907632	25628	Economy	6700.00
0005434907646	25628	Economy	6700.00
0005434907495	25628	Economy	6700.00
0005434907552	25628	Economy	6700.00
0005434907760	25628	Economy	6700.00
0005434907554	25628	Economy	6700.00
0005433252000	25628	Economy	6700.00
0005434907491	25628	Economy	6700.00
0005434907748	25628	Economy	6700.00
0005433251973	25628	Economy	6700.00
0005433251981	25628	Economy	6700.00
0005433251986	25628	Economy	6700.00
0005432621274	2530	Economy	13600.00
0005432862398	2530	Economy	13600.00
0005432862382	2530	Economy	13600.00
0005432621272	2530	Economy	12400.00
0005432862381	2530	Economy	12400.00
0005432621269	2530	Economy	12400.00
0005432862353	2530	Economy	12400.00
0005432862347	2530	Economy	12400.00
0005432621277	2530	Economy	12400.00
0005432862372	2530	Economy	12400.00
0005432621276	2530	Economy	12400.00
0005432862348	2530	Economy	12400.00
0005432862370	2530	Economy	12400.00
0005432621270	2530	Economy	12400.00
0005432862386	2530	Economy	12400.00
0005432621275	2530	Economy	12400.00
0005432862379	2530	Economy	12400.00
0005432862399	2530	Economy	12400.00
0005432621273	2530	Economy	12400.00
0005432862380	2530	Economy	12400.00
0005432621268	2530	Economy	12400.00
0005432621266	2530	Economy	12400.00
0005432862376	2530	Economy	12400.00
0005432621265	2530	Economy	12400.00
0005432862369	2530	Economy	12400.00
0005432862400	2530	Economy	12400.00
0005432621264	2530	Economy	12400.00
0005432862375	2530	Economy	12400.00
0005432621271	2530	Economy	12400.00
0005432621267	2530	Economy	12400.00
0005432862401	2530	Economy	12400.00
0005432862428	28032	Economy	12400.00
0005432621176	28032	Economy	12400.00
0005432621191	28032	Economy	12400.00
0005432862429	28032	Economy	12400.00
0005432621175	28032	Economy	12400.00
0005432621179	28032	Economy	12400.00
0005432862430	28032	Economy	12400.00
0005432621098	28032	Economy	12400.00
0005432621164	28032	Economy	12400.00
0005432621146	28032	Economy	12400.00
0005432621162	28032	Economy	12400.00
0005432621119	28032	Economy	12400.00
0005432862433	28032	Economy	12400.00
0005432621147	28032	Economy	12400.00
0005432621167	28032	Economy	12400.00
0005432862431	28032	Economy	12400.00
0005432621076	28032	Economy	12400.00
0005432621185	28032	Economy	12400.00
0005432862432	28032	Economy	12400.00
0005432621116	28032	Economy	12400.00
0005432621131	28032	Economy	12400.00
0005432621172	28032	Economy	12400.00
0005432621120	28032	Economy	12400.00
0005432862427	28032	Economy	12400.00
0005432621145	28032	Economy	12400.00
0005432621130	28032	Economy	12400.00
0005434097490	11705	Economy	11300.00
0005434097489	11705	Economy	11300.00
0005433452773	31043	Economy	8400.00
0005433451652	31043	Economy	8400.00
0005433451651	31043	Economy	8400.00
0005433452774	31043	Economy	8400.00
0005433454898	31461	Economy	8400.00
0005433452756	31461	Economy	8400.00
0005433452757	31461	Economy	8400.00
0005434142648	11976	Economy	7200.00
0005434142631	11976	Economy	7200.00
0005433134187	11976	Economy	7200.00
0005433129304	11976	Economy	6600.00
0005434142640	11976	Economy	6600.00
0005433134169	11976	Economy	6600.00
0005433134186	11976	Economy	6600.00
0005434142632	11976	Economy	6600.00
0005433134215	29834	Economy	7200.00
0005434184699	29834	Economy	7200.00
0005433131784	29834	Economy	6600.00
0005434183612	29834	Economy	6600.00
0005434184697	29834	Economy	6600.00
0005433131783	29834	Economy	6600.00
0005434142671	29834	Economy	6600.00
0005434183613	29834	Economy	6600.00
0005433134214	29834	Economy	6600.00
0005434184698	29834	Economy	6600.00
0005433131785	29834	Economy	6600.00
0005433134213	29834	Economy	6600.00
0005433131781	29834	Economy	6600.00
0005434142672	29834	Economy	6600.00
0005434142673	29834	Economy	6600.00
0005433131782	29834	Economy	6600.00
0005433134212	29834	Economy	6600.00
0005435697768	16489	Economy	19900.00
0005435697788	16489	Economy	19900.00
0005435697790	16489	Economy	19900.00
0005435697763	16489	Economy	18100.00
0005435697765	16489	Economy	18100.00
0005435697789	16489	Economy	18100.00
0005435697780	16489	Economy	18100.00
0005435697771	16489	Economy	18100.00
0005435935066	16489	Economy	18100.00
0005435697770	16489	Economy	18100.00
0005435697784	16489	Economy	18100.00
0005435697774	16489	Economy	18100.00
0005435697775	16489	Economy	18100.00
0005435697782	16489	Economy	18100.00
0005435697783	16489	Economy	18100.00
0005435697781	16489	Economy	18100.00
0005435697766	16489	Economy	18100.00
0005435697785	16489	Economy	18100.00
0005435697767	16489	Economy	18100.00
0005435697786	16489	Economy	18100.00
0005435697776	16489	Economy	18100.00
0005435697764	16489	Economy	18100.00
0005435697777	16489	Economy	18100.00
0005435697762	16489	Economy	18100.00
0005435697769	16489	Economy	18100.00
0005435697778	16489	Economy	18100.00
0005435697787	16489	Economy	18100.00
0005435697779	16489	Economy	18100.00
0005435697772	16489	Economy	18100.00
0005435697773	16489	Economy	18100.00
0005435697556	24690	Economy	19900.00
0005435697727	24690	Economy	19900.00
0005435697470	24690	Economy	19900.00
0005435697614	24690	Economy	19900.00
0005435697653	24690	Economy	18100.00
0005435697518	24690	Economy	18100.00
0005435697506	24690	Economy	18100.00
0005435697621	24690	Economy	18100.00
0005435697590	24690	Economy	18100.00
0005435697620	24690	Economy	18100.00
0005435697517	24690	Economy	18100.00
0005435697571	24690	Economy	18100.00
0005435697619	24690	Economy	18100.00
0005435697558	24690	Economy	18100.00
0005435697618	24690	Economy	18100.00
0005435697554	24690	Economy	18100.00
0005435697641	24690	Economy	18100.00
0005435697622	24690	Economy	18100.00
0005435697609	24690	Economy	18100.00
0005435697538	24690	Economy	18100.00
0005435697570	24690	Economy	18100.00
0005435697607	24690	Economy	18100.00
0005435697623	24690	Economy	18100.00
0005435697613	24690	Economy	18100.00
0005435697507	24690	Economy	18100.00
0005435697555	24690	Economy	18100.00
0005435697499	24690	Economy	18100.00
0005435697455	24690	Economy	18100.00
0005435697589	24690	Economy	18100.00
0005435697579	24690	Economy	18100.00
0005435697608	24690	Economy	18100.00
0005435697644	24690	Economy	18100.00
0005435697533	24690	Economy	18100.00
0005435697561	24690	Economy	18100.00
0005435697505	24690	Economy	18100.00
0005435697726	24690	Economy	18100.00
0005435697520	24690	Economy	18100.00
0005435697640	24690	Economy	18100.00
0005435697519	24690	Economy	18100.00
0005435697645	24690	Economy	18100.00
0005435697551	24690	Economy	18100.00
0005435697552	24690	Economy	18100.00
0005435697582	24690	Economy	18100.00
0005433724876	18816	Economy	4400.00
0005432968863	18816	Economy	4400.00
0005432968848	18816	Economy	4400.00
0005432968858	18816	Economy	4400.00
0005433724877	18816	Economy	4400.00
0005432968862	18816	Economy	4400.00
0005432968867	18816	Economy	4400.00
0005432968859	18816	Economy	4400.00
0005433724879	18816	Economy	4400.00
0005433724878	18816	Economy	4400.00
0005433724875	18816	Economy	4400.00
0005433724837	21623	Economy	4400.00
0005432968880	21623	Economy	4400.00
0005433724817	21623	Economy	4400.00
0005433724836	21623	Economy	4400.00
0005433724853	21623	Economy	4400.00
0005432968879	21623	Economy	4400.00
0005433724831	21623	Economy	4400.00
0005434139526	7306	Business	23100.00
0005434139530	7306	Business	23100.00
0005434139497	7306	Business	23100.00
0005434139513	7306	Business	23100.00
0005434139482	7306	Business	23100.00
0005434139485	7306	Business	23100.00
0005434139510	7306	Business	23100.00
0005434139486	7306	Business	23100.00
0005434139519	7306	Business	23100.00
0005434087594	7306	Business	23100.00
0005434139505	7306	Business	23100.00
0005434087596	7306	Economy	7700.00
0005434139499	7306	Economy	7700.00
0005434139490	7306	Economy	7700.00
0005434139541	7306	Economy	7700.00
0005434139500	7306	Economy	7700.00
0005434139525	7306	Economy	7700.00
0005434139487	7306	Economy	7700.00
0005434139489	7306	Economy	7700.00
0005434139488	7306	Economy	8500.00
0005434139544	7306	Economy	8500.00
0005434139531	7306	Economy	8500.00
0005434139545	7306	Economy	8500.00
0005434139468	7306	Economy	8500.00
0005434139536	7306	Economy	7700.00
0005434139493	7306	Economy	7700.00
0005434139522	7306	Economy	7700.00
0005434139480	7306	Economy	7700.00
0005434139465	7306	Economy	7700.00
0005434139475	7306	Economy	7700.00
0005434139495	7306	Economy	7700.00
0005434139528	7306	Economy	7700.00
0005434139540	7306	Economy	7700.00
0005434139515	7306	Economy	7700.00
0005434139502	7306	Economy	7700.00
0005434139511	7306	Economy	7700.00
0005434139478	7306	Economy	7700.00
0005434139509	7306	Economy	7700.00
0005434139529	7306	Economy	7700.00
0005434139524	7306	Economy	7700.00
0005434139464	7306	Economy	7700.00
0005434139542	7306	Economy	7700.00
0005434139508	7306	Economy	7700.00
0005434139467	7306	Economy	7700.00
0005434087595	7306	Economy	7700.00
0005434139496	7306	Economy	7700.00
0005434139463	7306	Economy	7700.00
0005434139523	7306	Economy	7700.00
0005434139514	7306	Economy	7700.00
0005434139470	7306	Economy	7700.00
0005434139543	7306	Economy	7700.00
0005434139491	7306	Economy	7700.00
0005434139504	7306	Economy	7700.00
0005434139537	7306	Economy	7700.00
0005434139469	7306	Economy	7700.00
0005434139527	7306	Economy	7700.00
0005434139474	7306	Economy	7700.00
0005434139471	7306	Economy	7700.00
0005434087593	7306	Economy	7700.00
0005434139538	7306	Economy	7700.00
0005434087592	7306	Economy	7700.00
0005434139484	7306	Economy	7700.00
0005434139479	7306	Economy	7700.00
0005434139535	7306	Economy	7700.00
0005434139521	7306	Economy	7700.00
0005434139483	7306	Economy	7700.00
0005434139473	7306	Economy	7700.00
0005434139507	7306	Economy	7700.00
0005434139539	7306	Economy	7700.00
0005434139534	7306	Economy	7700.00
0005434139503	7306	Economy	7700.00
0005434139481	7306	Economy	7700.00
0005434139466	7306	Economy	7700.00
0005434139477	7306	Economy	7700.00
0005434139512	7306	Economy	7700.00
0005434139472	7306	Economy	7700.00
0005434139533	7306	Economy	7700.00
0005434139532	7306	Economy	7700.00
0005434139516	7306	Economy	7700.00
0005434139494	7306	Economy	7700.00
0005434139501	7306	Economy	7700.00
0005434139498	7306	Economy	7700.00
0005434139492	7306	Economy	7700.00
0005434139506	7306	Economy	7700.00
0005434139517	7306	Economy	7700.00
0005434139476	7306	Economy	7700.00
0005434139518	7306	Economy	7700.00
0005434139520	7306	Economy	7700.00
0005434138356	28574	Business	23100.00
0005434138551	28574	Business	23100.00
0005434138519	28574	Business	23100.00
0005434138790	28574	Business	23100.00
0005434087566	28574	Business	23100.00
0005434138586	28574	Business	23100.00
0005434138355	28574	Business	23100.00
0005434138940	28574	Business	23100.00
0005434138593	28574	Business	23100.00
0005434138862	28574	Business	23100.00
0005434138907	28574	Business	23100.00
0005434138801	28574	Economy	7700.00
0005434087545	28574	Economy	7700.00
0005434138667	28574	Economy	7700.00
0005434138948	28574	Economy	7700.00
0005434138804	28574	Economy	7700.00
0005434138647	28574	Economy	7700.00
0005434138819	28574	Economy	7700.00
0005434138616	28574	Economy	7700.00
0005434138235	28574	Economy	7700.00
0005434138928	28574	Economy	8500.00
0005434138894	28574	Economy	8500.00
0005434138484	28574	Economy	8500.00
0005434138620	28574	Economy	8500.00
0005434138594	28574	Economy	7700.00
0005434138668	28574	Economy	7700.00
0005434138762	28574	Economy	7700.00
0005434138826	28574	Economy	7700.00
0005434138744	28574	Economy	7700.00
0005434138434	28574	Economy	7700.00
0005434138398	28574	Economy	7700.00
0005434138771	28574	Economy	7700.00
0005434138820	28574	Economy	7700.00
0005434087554	28574	Economy	7700.00
0005434138788	28574	Economy	7700.00
0005434138859	28574	Economy	7700.00
0005434138754	28574	Economy	7700.00
0005434138498	28574	Economy	7700.00
0005434138625	28574	Economy	7700.00
0005434138325	28574	Economy	7700.00
0005434138930	28574	Economy	7700.00
0005434138686	28574	Economy	7700.00
0005434138827	28574	Economy	7700.00
0005434138500	28574	Economy	7700.00
0005434138791	28574	Economy	7700.00
0005434138660	28574	Economy	7700.00
0005434138614	28574	Economy	7700.00
0005434138753	28574	Economy	7700.00
0005434138929	28574	Economy	7700.00
0005434138596	28574	Economy	7700.00
0005434138802	28574	Economy	7700.00
0005434138112	28574	Economy	7700.00
0005434138592	28574	Economy	7700.00
0005434138687	28574	Economy	7700.00
0005434087546	28574	Economy	7700.00
0005434138615	28574	Economy	7700.00
0005434138715	28574	Economy	7700.00
0005434138805	28574	Economy	7700.00
0005434138895	28574	Economy	7700.00
0005434138740	28574	Economy	7700.00
0005434087576	28574	Economy	7700.00
0005434138572	28574	Economy	7700.00
0005434138789	28574	Economy	7700.00
0005434138634	28574	Economy	7700.00
0005434138559	28574	Economy	7700.00
0005434138602	28574	Economy	7700.00
0005434138497	28574	Economy	7700.00
0005434138945	28574	Economy	7700.00
0005434138627	28574	Economy	7700.00
0005434138546	28574	Economy	7700.00
0005434138564	28574	Economy	7700.00
0005434138628	28574	Economy	7700.00
0005434138800	28574	Economy	7700.00
0005434138332	28574	Economy	7700.00
0005434138706	28574	Economy	7700.00
0005434138547	28574	Economy	7700.00
0005434138685	28574	Economy	7700.00
0005434138626	28574	Economy	7700.00
0005434138400	28574	Economy	7700.00
0005434138397	28574	Economy	7700.00
0005434138851	28574	Economy	7700.00
0005434138850	28574	Economy	7700.00
0005434138331	28574	Economy	7700.00
0005434138584	28574	Economy	7700.00
0005434138939	28574	Economy	7700.00
0005434138666	28574	Economy	7700.00
0005434138568	28574	Economy	7700.00
0005434138311	28574	Economy	7700.00
0005433407582	1932	Economy	23900.00
0005435808401	1932	Economy	21700.00
0005433407603	1932	Economy	21700.00
0005433407589	1932	Economy	21700.00
0005435808404	1932	Economy	21700.00
0005434610288	1932	Economy	21700.00
0005433407604	1932	Economy	21700.00
0005434610287	1932	Economy	21700.00
0005434610290	1932	Economy	21700.00
0005433407583	1932	Economy	21700.00
0005435808403	1932	Economy	21700.00
0005434610289	1932	Economy	21700.00
0005433407588	1932	Economy	21700.00
0005433407587	1932	Economy	21700.00
0005435808402	1932	Economy	21700.00
0005435808294	23078	Economy	23900.00
0005434610265	23078	Economy	23900.00
0005435808276	23078	Economy	21700.00
0005433407647	23078	Economy	21700.00
0005435808269	23078	Economy	21700.00
0005433407638	23078	Economy	21700.00
0005434610259	23078	Economy	21700.00
0005435808215	23078	Economy	21700.00
0005435808270	23078	Economy	21700.00
0005433407640	23078	Economy	21700.00
0005433407641	23078	Economy	21700.00
0005434610261	23078	Economy	21700.00
0005435808235	23078	Economy	21700.00
0005435808277	23078	Economy	21700.00
0005435808287	23078	Economy	21700.00
0005433407642	23078	Economy	21700.00
0005435808285	23078	Economy	21700.00
0005434610255	23078	Economy	21700.00
0005433407643	23078	Economy	21700.00
0005433407644	23078	Economy	21700.00
0005434610275	23078	Economy	21700.00
0005435808311	23078	Economy	21700.00
0005433407646	23078	Economy	21700.00
0005435808284	23078	Economy	21700.00
0005435808243	23078	Economy	21700.00
0005435808268	23078	Economy	21700.00
0005435808266	23078	Economy	21700.00
0005435808289	23078	Economy	21700.00
0005434610260	23078	Economy	21700.00
0005434610264	23078	Economy	21700.00
0005433407639	23078	Economy	21700.00
0005435808275	23078	Economy	21700.00
0005433407645	23078	Economy	21700.00
0005435808236	23078	Economy	21700.00
0005435808216	23078	Economy	21700.00
0005434610256	23078	Economy	21700.00
0005435808271	23078	Economy	21700.00
0005434504290	16711	Economy	7600.00
0005434504599	16711	Economy	7600.00
0005434504270	16711	Economy	6900.00
0005434504377	16711	Economy	6900.00
0005434504499	16711	Economy	6900.00
0005434504368	16711	Economy	6900.00
0005434504600	16711	Economy	6900.00
0005434504601	16711	Economy	6900.00
0005434504500	16711	Economy	6900.00
0005434504433	16711	Economy	6900.00
0005434504443	16711	Economy	6900.00
0005434504405	16711	Economy	6900.00
0005434504488	16711	Economy	6900.00
0005434504473	16711	Economy	6900.00
0005434504556	16711	Economy	6900.00
0005434504283	16711	Economy	6900.00
0005434504528	16711	Economy	6900.00
0005434504406	16711	Economy	6900.00
0005434504343	16711	Economy	6900.00
0005434504194	16711	Economy	6900.00
0005434504515	16711	Economy	6900.00
0005434504412	16711	Economy	6900.00
0005434504367	16711	Economy	6900.00
0005434504591	16711	Economy	6900.00
0005434504444	16711	Economy	6900.00
0005434504342	16711	Economy	6900.00
0005434504206	16711	Economy	6900.00
0005434504423	16711	Economy	6900.00
0005434504407	16711	Economy	6900.00
0005434504352	16711	Economy	6900.00
0005434504282	16711	Economy	6900.00
0005434504346	16711	Economy	6900.00
0005434504485	16711	Economy	6900.00
0005434504487	16711	Economy	6900.00
0005434504529	16711	Economy	6900.00
0005434504395	16711	Economy	6900.00
0005434504516	16711	Economy	6900.00
0005434504474	16711	Economy	6900.00
0005434504279	16711	Economy	6900.00
0005434504602	16711	Economy	6900.00
0005434504771	22929	Economy	7600.00
0005434504751	22929	Economy	7600.00
0005434504760	22929	Economy	7600.00
0005434504761	22929	Economy	7600.00
0005434504747	22929	Economy	6900.00
0005434504749	22929	Economy	6900.00
0005434504763	22929	Economy	6900.00
0005434504774	22929	Economy	6900.00
0005434504755	22929	Economy	6900.00
0005434504780	22929	Economy	6900.00
0005434504773	22929	Economy	6900.00
0005434504746	22929	Economy	6900.00
0005434504785	22929	Economy	6900.00
0005434504769	22929	Economy	6900.00
0005434504756	22929	Economy	6900.00
0005434504750	22929	Economy	6900.00
0005434504759	22929	Economy	6900.00
0005434504765	22929	Economy	6900.00
0005434504762	22929	Economy	6900.00
0005434504781	22929	Economy	6900.00
0005434504786	22929	Economy	6900.00
0005434504748	22929	Economy	6900.00
0005434504754	22929	Economy	6900.00
0005434504777	22929	Economy	6900.00
0005434504784	22929	Economy	6900.00
0005434504764	22929	Economy	6900.00
0005434504766	22929	Economy	6900.00
0005434504767	22929	Economy	6900.00
0005434504757	22929	Economy	6900.00
0005434504783	22929	Economy	6900.00
0005434504753	22929	Economy	6900.00
0005434504770	22929	Economy	6900.00
0005434504745	22929	Economy	6900.00
0005434504758	22929	Economy	6900.00
0005434504752	22929	Economy	6900.00
0005434504772	22929	Economy	6900.00
0005434504778	22929	Economy	6900.00
0005434504768	22929	Economy	6900.00
0005434504776	22929	Economy	6900.00
0005434504779	22929	Economy	6900.00
0005434504775	22929	Economy	6900.00
0005434504782	22929	Economy	6900.00
0005435078603	2219	Economy	7700.00
0005435078596	2219	Economy	7700.00
0005435078602	2219	Economy	7000.00
0005435078594	2219	Economy	7000.00
0005435078599	2219	Economy	7000.00
0005433266772	2219	Economy	7000.00
0005433266815	2219	Economy	7000.00
0005433266811	2219	Economy	7000.00
0005435078604	2219	Economy	7000.00
0005433266793	2219	Economy	7000.00
0005433266817	2219	Economy	7000.00
0005433266770	2219	Economy	7000.00
0005433266785	2219	Economy	7000.00
0005433266776	2219	Economy	7000.00
0005435078595	2219	Economy	7000.00
0005433266771	2219	Economy	7000.00
0005435078600	2219	Economy	7000.00
0005435078592	2219	Economy	7000.00
0005433266777	2219	Economy	7000.00
0005435078598	2219	Economy	7000.00
0005435078597	2219	Economy	7000.00
0005433266787	2219	Economy	7000.00
0005435078601	2219	Economy	7000.00
0005435078590	2219	Economy	7000.00
0005433266816	2219	Economy	7000.00
0005435078593	2219	Economy	7000.00
0005435078589	2219	Economy	7000.00
0005433266753	2219	Economy	7000.00
0005435078591	2219	Economy	7000.00
0005433266875	24328	Economy	7000.00
0005433266874	24328	Economy	7000.00
0005435078412	24328	Economy	7000.00
0005435078470	24328	Economy	7000.00
0005433266876	24328	Economy	7000.00
0005435078484	24328	Economy	7000.00
0005435078462	24328	Economy	7000.00
0005435078447	24328	Economy	7000.00
0005435078446	24328	Economy	7000.00
0005435078473	24328	Economy	7000.00
0005435078475	24328	Economy	7000.00
0005435078388	24328	Economy	7000.00
0005435078471	24328	Economy	7000.00
0005435078461	24328	Economy	7000.00
0005435078472	24328	Economy	7000.00
0005433266880	24328	Economy	7000.00
0005435078509	24328	Economy	7000.00
0005435078413	24328	Economy	7000.00
0005433266873	24328	Economy	7000.00
0005435078519	24328	Economy	7000.00
0005435078508	24328	Economy	7000.00
0005435078430	24328	Economy	7000.00
0005433266872	24328	Economy	7000.00
0005433266877	24328	Economy	7000.00
0005433266881	24328	Economy	7000.00
0005433266878	24328	Economy	7000.00
0005435078459	24328	Economy	7000.00
0005433266879	24328	Economy	7000.00
0005435078510	24328	Economy	7000.00
0005434988916	6610	Economy	10800.00
0005434988913	6610	Economy	9800.00
0005435803309	6610	Economy	9800.00
0005435803310	6610	Economy	9800.00
0005434988919	6610	Economy	9800.00
0005434988914	6610	Economy	9800.00
0005435803308	6610	Economy	9800.00
0005434988915	6610	Economy	9800.00
0005434988912	6610	Economy	9800.00
0005434988918	6610	Economy	9800.00
0005434988920	6610	Economy	9800.00
0005434988917	6610	Economy	9800.00
0005434988778	23643	Economy	9800.00
0005434988749	23643	Economy	9800.00
0005434988777	23643	Economy	9800.00
0005432383794	30512	Business	9900.00
0005433450337	30512	Business	9900.00
0005432383806	30512	Business	9900.00
0005433450320	30512	Business	9900.00
0005432383818	30512	Business	9900.00
0005432383808	30512	Business	9900.00
0005433450328	30512	Business	9900.00
0005432383828	30512	Business	9900.00
0005432383812	30512	Business	9900.00
0005432383827	30512	Business	9900.00
0005432383823	30512	Economy	3300.00
0005432383811	30512	Economy	3300.00
0005432383822	30512	Economy	3300.00
0005432383795	30512	Economy	3300.00
0005432383815	30512	Economy	3300.00
0005432383793	30512	Economy	3600.00
0005432383802	30512	Economy	3600.00
0005432383809	30512	Economy	3600.00
0005433450321	30512	Economy	3300.00
0005433450338	30512	Economy	3300.00
0005432383800	30512	Economy	3300.00
0005432383831	30512	Economy	3300.00
0005433453794	30512	Economy	3300.00
0005433450327	30512	Economy	3300.00
0005432383798	30512	Economy	3300.00
0005432383820	30512	Economy	3300.00
0005433450325	30512	Economy	3300.00
0005432383792	30512	Economy	3300.00
0005432383807	30512	Economy	3300.00
0005433450323	30512	Economy	3300.00
0005432383829	30512	Economy	3300.00
0005432383797	30512	Economy	3300.00
0005433450336	30512	Economy	3300.00
0005433454910	30512	Economy	3300.00
0005432383814	30512	Economy	3300.00
0005433450335	30512	Economy	3300.00
0005433450341	30512	Economy	3300.00
0005432383803	30512	Economy	3300.00
0005432383825	30512	Economy	3300.00
0005432383824	30512	Economy	3300.00
0005433450331	30512	Economy	3300.00
0005432383830	30512	Economy	3300.00
0005433450322	30512	Economy	3300.00
0005432383801	30512	Economy	3300.00
0005432383819	30512	Economy	3300.00
0005433454911	30512	Economy	3300.00
0005432383796	30512	Economy	3300.00
0005433450332	30512	Economy	3300.00
0005433450330	30512	Economy	3300.00
0005433450339	30512	Economy	3300.00
0005432383810	30512	Economy	3300.00
0005433450329	30512	Economy	3300.00
0005432383799	30512	Economy	3300.00
0005433450342	30512	Economy	3300.00
0005433450319	30512	Economy	3300.00
0005433450324	30512	Economy	3300.00
0005432383804	30512	Economy	3300.00
0005432383813	30512	Economy	3300.00
0005432383821	30512	Economy	3300.00
0005432383805	30512	Economy	3300.00
0005432383817	30512	Economy	3300.00
0005433450340	30512	Economy	3300.00
0005432383816	30512	Economy	3300.00
0005432383826	30512	Economy	3300.00
0005433453795	30512	Economy	3300.00
0005433450333	30512	Economy	3300.00
0005433450326	30512	Economy	3300.00
0005433450334	30512	Economy	3300.00
0005432383356	31303	Business	9900.00
0005432383409	31303	Business	9900.00
0005432383372	31303	Business	9900.00
0005432383390	31303	Business	9900.00
0005432383391	31303	Business	9900.00
0005433450171	31303	Economy	3300.00
0005432383360	31303	Economy	3300.00
0005432383483	31303	Economy	3300.00
0005432383291	31303	Economy	3300.00
0005433450139	31303	Economy	3300.00
0005433450195	31303	Economy	3300.00
0005432383553	31303	Economy	3300.00
0005433451629	31303	Economy	3600.00
0005432383486	31303	Economy	3600.00
0005433450024	31303	Economy	3300.00
0005433451639	31303	Economy	3300.00
0005432383359	31303	Economy	3300.00
0005433450114	31303	Economy	3300.00
0005433450161	31303	Economy	3300.00
0005432383443	31303	Economy	3300.00
0005432383564	31303	Economy	3300.00
0005432383389	31303	Economy	3300.00
0005433453769	31303	Economy	3300.00
0005433450182	31303	Economy	3300.00
0005433450148	31303	Economy	3300.00
0005432383351	31303	Economy	3300.00
0005432383371	31303	Economy	3300.00
0005432383401	31303	Economy	3300.00
0005433450160	31303	Economy	3300.00
0005432383338	31303	Economy	3300.00
0005432383437	31303	Economy	3300.00
0005432383292	31303	Economy	3300.00
0005432383335	31303	Economy	3300.00
0005432383488	31303	Economy	3300.00
0005432383355	31303	Economy	3300.00
0005433453776	31303	Economy	3300.00
0005433450045	31303	Economy	3300.00
0005433450166	31303	Economy	3300.00
0005432383472	31303	Economy	3300.00
0005432383206	31303	Economy	3300.00
0005432383322	31303	Economy	3300.00
0005433450113	31303	Economy	3300.00
0005433450068	31303	Economy	3300.00
0005432383537	31303	Economy	3300.00
0005432383370	31303	Economy	3300.00
0005432383461	31303	Economy	3300.00
0005433453775	31303	Economy	3300.00
0005433450119	31303	Economy	3300.00
0005432383499	31303	Economy	3300.00
0005432383436	31303	Economy	3300.00
0005432383449	31303	Economy	3300.00
0005432383248	31303	Economy	3300.00
0005433450234	31303	Economy	3300.00
0005433450153	31303	Economy	3300.00
0005432383543	31303	Economy	3300.00
0005433450140	31303	Economy	3300.00
0005432383329	31303	Economy	3300.00
0005432383290	31303	Economy	3300.00
0005433450162	31303	Economy	3300.00
0005433131747	10801	Economy	17100.00
0005435299804	10801	Economy	17100.00
0005435299795	10801	Economy	15600.00
0005433126882	10801	Economy	15600.00
0005435299820	10801	Economy	15600.00
0005433131748	10801	Economy	15600.00
0005433131737	10801	Economy	15600.00
0005433131733	10801	Economy	15600.00
0005435299798	10801	Economy	15600.00
0005433131739	10801	Economy	15600.00
0005435299797	10801	Economy	15600.00
0005435299819	10801	Economy	15600.00
0005435299793	10801	Economy	15600.00
0005433126887	10801	Economy	15600.00
0005435299805	10801	Economy	15600.00
0005435304186	10801	Economy	15600.00
0005433126883	10801	Economy	15600.00
0005435299794	10801	Economy	15600.00
0005433126884	10801	Economy	15600.00
0005433131752	10801	Economy	15600.00
0005435299796	10801	Economy	15600.00
0005433131738	10801	Economy	15600.00
0005433129354	29741	Economy	17100.00
0005433126923	29741	Economy	15600.00
0005435299860	29741	Economy	15600.00
0005433129356	29741	Economy	15600.00
0005435302279	29741	Economy	15600.00
0005435302280	29741	Economy	15600.00
0005435299857	29741	Economy	15600.00
0005435302281	29741	Economy	15600.00
0005435299858	29741	Economy	15600.00
0005433126922	29741	Economy	15600.00
0005435302278	29741	Economy	15600.00
0005435299859	29741	Economy	15600.00
0005433129353	29741	Economy	15600.00
0005435299856	29741	Economy	15600.00
0005435302282	29741	Economy	15600.00
0005433129357	29741	Economy	15600.00
0005433129355	29741	Economy	15600.00
0005433126924	29741	Economy	15600.00
0005433126925	29741	Economy	15600.00
0005433126926	29741	Economy	15600.00
0005435299861	29741	Economy	15600.00
0005434287664	2396	Economy	17200.00
0005434287660	2396	Economy	17200.00
0005433110178	2396	Economy	15700.00
0005433110152	2396	Economy	15700.00
0005433110179	2396	Economy	15700.00
0005433110198	2396	Economy	15700.00
0005432264516	2396	Economy	15700.00
0005434287651	2396	Economy	15700.00
0005434287652	2396	Economy	15700.00
0005434287648	2396	Economy	15700.00
0005434287663	2396	Economy	15700.00
0005433110199	2396	Economy	15700.00
0005433110169	2396	Economy	15700.00
0005434287643	2396	Economy	15700.00
0005434287655	2396	Economy	15700.00
0005434287644	2396	Economy	15700.00
0005433110144	2396	Economy	15700.00
0005434287649	2396	Economy	15700.00
0005434287646	2396	Economy	15700.00
0005434287645	2396	Economy	15700.00
0005434287665	2396	Economy	15700.00
0005434287657	2396	Economy	15700.00
0005434287659	2396	Economy	15700.00
0005433110177	2396	Economy	15700.00
0005433110151	2396	Economy	15700.00
0005434287653	2396	Economy	15700.00
0005433110185	2396	Economy	15700.00
0005434287658	2396	Economy	15700.00
0005434287647	2396	Economy	15700.00
0005433110200	2396	Economy	15700.00
0005434287654	2396	Economy	15700.00
0005434287661	2396	Economy	15700.00
0005434287650	2396	Economy	15700.00
0005433110186	2396	Economy	15700.00
0005433110168	2396	Economy	15700.00
0005434287662	2396	Economy	15700.00
0005434287656	2396	Economy	15700.00
0005434287440	26831	Economy	17200.00
0005434287450	26831	Economy	17200.00
0005433110250	26831	Economy	17200.00
0005434287487	26831	Economy	15700.00
0005434287401	26831	Economy	15700.00
0005434287467	26831	Economy	15700.00
0005434287495	26831	Economy	15700.00
0005434287455	26831	Economy	15700.00
0005434287454	26831	Economy	15700.00
0005433110257	26831	Economy	15700.00
0005434287441	26831	Economy	15700.00
0005434287504	26831	Economy	15700.00
0005433110256	26831	Economy	15700.00
0005434287459	26831	Economy	15700.00
0005433110254	26831	Economy	15700.00
0005434287480	26831	Economy	15700.00
0005434287420	26831	Economy	15700.00
0005434287413	26831	Economy	15700.00
0005434287461	26831	Economy	15700.00
0005433110253	26831	Economy	15700.00
0005433110252	26831	Economy	15700.00
0005434287386	26831	Economy	15700.00
0005434287426	26831	Economy	15700.00
0005434287427	26831	Economy	15700.00
0005433110258	26831	Economy	15700.00
0005434287400	26831	Economy	15700.00
0005433110251	26831	Economy	15700.00
0005434287365	26831	Economy	15700.00
0005434287512	26831	Economy	15700.00
0005433110248	26831	Economy	15700.00
0005434287431	26831	Economy	15700.00
0005433110249	26831	Economy	15700.00
0005434287492	26831	Economy	15700.00
0005434287502	26831	Economy	15700.00
0005434287399	26831	Economy	15700.00
0005433110247	26831	Economy	15700.00
0005434287419	26831	Economy	15700.00
0005434287460	26831	Economy	15700.00
0005434287466	26831	Economy	15700.00
0005434287503	26831	Economy	15700.00
0005433110255	26831	Economy	15700.00
0005434287505	26831	Economy	15700.00
0005434287398	26831	Economy	15700.00
0005434272209	25500	Economy	22800.00
0005434269121	25500	Economy	22800.00
0005434269114	25500	Economy	22800.00
0005434269109	25500	Economy	22800.00
0005435856273	25500	Economy	22800.00
0005435856274	25500	Economy	22800.00
0005435856275	25500	Economy	22800.00
0005434269115	25500	Economy	22800.00
0005434272208	25500	Economy	22800.00
0005435856229	26672	Economy	25000.00
0005434272216	26672	Economy	22800.00
0005434273105	26672	Economy	22800.00
0005434272217	26672	Economy	22800.00
0005435854063	26672	Economy	22800.00
0005434273104	26672	Economy	22800.00
0005435263652	7158	Business	89800.00
0005433650886	7158	Business	89800.00
0005433650868	7158	Business	89800.00
0005433650885	7158	Business	89800.00
0005433650874	7158	Business	89800.00
0005433650876	7158	Business	89800.00
0005433650867	7158	Business	89800.00
0005433650877	7158	Business	89800.00
0005433650890	7158	Business	89800.00
0005433650897	7158	Business	89800.00
0005433650880	7158	Economy	29900.00
0005433650875	7158	Economy	29900.00
0005433650870	7158	Economy	29900.00
0005433650871	7158	Economy	29900.00
0005433650884	7158	Economy	29900.00
0005433650901	7158	Economy	29900.00
0005433650865	7158	Economy	32900.00
0005433650903	7158	Economy	32900.00
0005433650895	7158	Economy	32900.00
0005435263692	7158	Economy	32900.00
0005433650894	7158	Economy	32900.00
0005433650911	7158	Economy	29900.00
0005435263657	7158	Economy	29900.00
0005435263689	7158	Economy	29900.00
0005433650888	7158	Economy	29900.00
0005433650883	7158	Economy	29900.00
0005433650878	7158	Economy	29900.00
0005435263623	7158	Economy	29900.00
0005433650907	7158	Economy	29900.00
0005435263662	7158	Economy	29900.00
0005433650892	7158	Economy	29900.00
0005433650899	7158	Economy	29900.00
0005433650902	7158	Economy	29900.00
0005433650869	7158	Economy	29900.00
0005433650887	7158	Economy	29900.00
0005435263682	7158	Economy	29900.00
0005435263624	7158	Economy	29900.00
0005433650891	7158	Economy	29900.00
0005435263683	7158	Economy	29900.00
0005433650893	7158	Economy	29900.00
0005435263674	7158	Economy	29900.00
0005433650909	7158	Economy	29900.00
0005435263695	7158	Economy	29900.00
0005433650881	7158	Economy	29900.00
0005435263651	7158	Economy	29900.00
0005435263664	7158	Economy	29900.00
0005435263694	7158	Economy	29900.00
0005433650908	7158	Economy	29900.00
0005433650905	7158	Economy	29900.00
0005435263663	7158	Economy	29900.00
0005433650873	7158	Economy	29900.00
0005435263665	7158	Economy	29900.00
0005435263675	7158	Economy	29900.00
0005433650912	7158	Economy	29900.00
0005433650898	7158	Economy	29900.00
0005435263649	7158	Economy	29900.00
0005435263650	7158	Economy	29900.00
0005433650879	7158	Economy	29900.00
0005435263687	7158	Economy	29900.00
0005435263658	7158	Economy	29900.00
0005433650889	7158	Economy	29900.00
0005435263660	7158	Economy	29900.00
0005435263686	7158	Economy	29900.00
0005435263711	7158	Economy	29900.00
0005433650872	7158	Economy	29900.00
0005435263636	7158	Economy	29900.00
0005433650866	7158	Economy	29900.00
0005433650900	7158	Economy	29900.00
0005435263696	7158	Economy	29900.00
0005433650904	7158	Economy	29900.00
0005433650906	7158	Economy	29900.00
0005433650896	7158	Economy	29900.00
0005433650910	7158	Economy	29900.00
0005433650882	7158	Economy	29900.00
0005433869101	4796	Economy	19400.00
0005433869103	4796	Economy	19400.00
0005433869115	4796	Economy	19400.00
0005433869086	4796	Economy	19400.00
0005433869085	4796	Economy	17600.00
0005435860504	4796	Economy	17600.00
0005433869109	4796	Economy	17600.00
0005433869119	4796	Economy	17600.00
0005433869084	4796	Economy	17600.00
0005433869082	4796	Economy	17600.00
0005433869112	4796	Economy	17600.00
0005433869093	4796	Economy	17600.00
0005433869080	4796	Economy	17600.00
0005433869106	4796	Economy	17600.00
0005433869099	4796	Economy	17600.00
0005435860505	4796	Economy	17600.00
0005433869094	4796	Economy	17600.00
0005433869097	4796	Economy	17600.00
0005433869114	4796	Economy	17600.00
0005433869108	4796	Economy	17600.00
0005433869096	4796	Economy	17600.00
0005433869117	4796	Economy	17600.00
0005433869081	4796	Economy	17600.00
0005433869105	4796	Economy	17600.00
0005433869083	4796	Economy	17600.00
0005433869107	4796	Economy	17600.00
0005433869102	4796	Economy	17600.00
0005433869087	4796	Economy	17600.00
0005435860509	4796	Economy	17600.00
0005433869110	4796	Economy	17600.00
0005433869092	4796	Economy	17600.00
0005433869116	4796	Economy	17600.00
0005433869120	4796	Economy	17600.00
0005433869079	4796	Economy	17600.00
0005433869113	4796	Economy	17600.00
0005433869095	4796	Economy	17600.00
0005433869118	4796	Economy	17600.00
0005433869090	4796	Economy	17600.00
0005433869111	4796	Economy	17600.00
0005433869100	4796	Economy	17600.00
0005433869088	4796	Economy	17600.00
0005433869104	4796	Economy	17600.00
0005433869098	4796	Economy	17600.00
0005433869089	4796	Economy	17600.00
0005433869091	4796	Economy	17600.00
0005433868599	32620	Economy	19400.00
0005435860550	32620	Economy	19400.00
0005435860543	32620	Economy	19400.00
0005433868804	32620	Economy	19400.00
0005433868666	32620	Economy	17600.00
0005433868681	32620	Economy	17600.00
0005433868677	32620	Economy	17600.00
0005433868747	32620	Economy	17600.00
0005433868678	32620	Economy	17600.00
0005435860545	32620	Economy	17600.00
0005433868811	32620	Economy	17600.00
0005433868789	32620	Economy	17600.00
0005435860541	32620	Economy	17600.00
0005435860542	32620	Economy	17600.00
0005433868671	32620	Economy	17600.00
0005433868862	32620	Economy	17600.00
0005435860549	32620	Economy	17600.00
0005435860547	32620	Economy	17600.00
0005433868729	32620	Economy	17600.00
0005433868685	32620	Economy	17600.00
0005433868879	32620	Economy	17600.00
0005433868782	32620	Economy	17600.00
0005433868717	32620	Economy	17600.00
0005433868686	32620	Economy	17600.00
0005433868700	32620	Economy	17600.00
0005433868680	32620	Economy	17600.00
0005433868679	32620	Economy	17600.00
0005433868594	32620	Economy	17600.00
0005435860544	32620	Economy	17600.00
0005433868708	32620	Economy	17600.00
0005433868749	32620	Economy	17600.00
0005433868674	32620	Economy	17600.00
0005433868702	32620	Economy	17600.00
0005435860548	32620	Economy	17600.00
0005433868715	32620	Economy	17600.00
0005435860546	32620	Economy	17600.00
0005433868878	32620	Economy	17600.00
0005433868819	32620	Economy	17600.00
0005433868672	32620	Economy	17600.00
0005433868707	32620	Economy	17600.00
0005433868667	32620	Economy	17600.00
0005433868714	32620	Economy	17600.00
0005433868687	32620	Economy	17600.00
0005435911511	3404	Economy	24800.00
0005435911521	3404	Economy	24800.00
0005434663635	3404	Economy	22600.00
0005434460541	3404	Economy	22600.00
0005434663626	3404	Economy	22600.00
0005434663632	3404	Economy	22600.00
0005434663636	3404	Economy	22600.00
0005434461683	3404	Economy	22600.00
0005434663628	3404	Economy	22600.00
0005435911533	3404	Economy	22600.00
0005434663633	3404	Economy	22600.00
0005434461682	3404	Economy	22600.00
0005434663629	3404	Economy	22600.00
0005435911525	3404	Economy	22600.00
0005434663634	3404	Economy	22600.00
0005434663638	3404	Economy	22600.00
0005434663627	3404	Economy	22600.00
0005434663630	3404	Economy	22600.00
0005435911526	3404	Economy	22600.00
0005434460540	3404	Economy	22600.00
0005434663631	3404	Economy	22600.00
0005434663637	3404	Economy	22600.00
0005434663520	12461	Economy	22600.00
0005435911576	12461	Economy	22600.00
0005435911578	12461	Economy	22600.00
0005434663512	12461	Economy	22600.00
0005434663535	12461	Economy	22600.00
0005435911580	12461	Economy	22600.00
0005434663500	12461	Economy	22600.00
0005435911581	12461	Economy	22600.00
0005434663501	12461	Economy	22600.00
0005435911573	12461	Economy	22600.00
0005434663468	12461	Economy	22600.00
0005434663499	12461	Economy	22600.00
0005434663492	12461	Economy	22600.00
0005435911579	12461	Economy	22600.00
0005435911574	12461	Economy	22600.00
0005435911577	12461	Economy	22600.00
0005435911575	12461	Economy	22600.00
0005434663559	12461	Economy	22600.00
0005434663467	12461	Economy	22600.00
0005433868715	14520	Economy	18500.00
0005433868747	14520	Economy	18500.00
0005433868685	14520	Economy	18500.00
0005435860547	14520	Economy	16800.00
0005435860548	14520	Economy	16800.00
0005433868671	14520	Economy	16800.00
0005433868679	14520	Economy	16800.00
0005435860550	14520	Economy	16800.00
0005433868811	14520	Economy	16800.00
0005435860541	14520	Economy	16800.00
0005433868702	14520	Economy	16800.00
0005433868862	14520	Economy	16800.00
0005435860549	14520	Economy	16800.00
0005433868594	14520	Economy	16800.00
0005433868729	14520	Economy	16800.00
0005433868678	14520	Economy	16800.00
0005433868686	14520	Economy	16800.00
0005433868674	14520	Economy	16800.00
0005433868672	14520	Economy	16800.00
0005433868714	14520	Economy	16800.00
0005433868681	14520	Economy	16800.00
0005435860543	14520	Economy	16800.00
0005435860542	14520	Economy	16800.00
0005435860544	14520	Economy	16800.00
0005435860546	14520	Economy	16800.00
0005433868782	14520	Economy	16800.00
0005433868700	14520	Economy	16800.00
0005433868819	14520	Economy	16800.00
0005433868878	14520	Economy	16800.00
0005433868687	14520	Economy	16800.00
0005433868804	14520	Economy	16800.00
0005433868599	14520	Economy	16800.00
0005433868717	14520	Economy	16800.00
0005433868666	14520	Economy	16800.00
0005435860545	14520	Economy	16800.00
0005433868749	14520	Economy	16800.00
0005433868789	14520	Economy	16800.00
0005433868680	14520	Economy	16800.00
0005433868677	14520	Economy	16800.00
0005433868708	14520	Economy	16800.00
0005433868879	14520	Economy	16800.00
0005433868667	14520	Economy	16800.00
0005433868707	14520	Economy	16800.00
0005433869072	32695	Economy	18500.00
0005433869046	32695	Economy	18500.00
0005433869055	32695	Economy	18500.00
0005433869064	32695	Economy	16800.00
0005433869051	32695	Economy	16800.00
0005433869073	32695	Economy	16800.00
0005433869063	32695	Economy	16800.00
0005433869078	32695	Economy	16800.00
0005433869038	32695	Economy	16800.00
0005433869042	32695	Economy	16800.00
0005433869045	32695	Economy	16800.00
0005433869040	32695	Economy	16800.00
0005433869054	32695	Economy	16800.00
0005435860502	32695	Economy	16800.00
0005435860503	32695	Economy	16800.00
0005433869057	32695	Economy	16800.00
0005433869070	32695	Economy	16800.00
0005433869056	32695	Economy	16800.00
0005433869060	32695	Economy	16800.00
0005433869052	32695	Economy	16800.00
0005433869058	32695	Economy	16800.00
0005433869039	32695	Economy	16800.00
0005433869069	32695	Economy	16800.00
0005433869076	32695	Economy	16800.00
0005433869066	32695	Economy	16800.00
0005433869067	32695	Economy	16800.00
0005433869062	32695	Economy	16800.00
0005433869053	32695	Economy	16800.00
0005433869061	32695	Economy	16800.00
0005433869077	32695	Economy	16800.00
0005433869071	32695	Economy	16800.00
0005433869068	32695	Economy	16800.00
0005433869044	32695	Economy	16800.00
0005433869043	32695	Economy	16800.00
0005433869074	32695	Economy	16800.00
0005433869075	32695	Economy	16800.00
0005433869049	32695	Economy	16800.00
0005433869041	32695	Economy	16800.00
0005433869065	32695	Economy	16800.00
0005433869048	32695	Economy	16800.00
0005433869047	32695	Economy	16800.00
0005433869059	32695	Economy	16800.00
0005433869050	32695	Economy	16800.00
0005432799657	12121	Economy	4900.00
0005432799614	12121	Economy	4900.00
0005432799537	12121	Economy	4900.00
0005432799716	12121	Economy	4400.00
0005432799739	12121	Economy	4400.00
0005432799723	12121	Economy	4400.00
0005432799666	12121	Economy	4400.00
0005432799613	12121	Economy	4400.00
0005432799715	12121	Economy	4400.00
0005432799656	12121	Economy	4400.00
0005432799638	12121	Economy	4400.00
0005432799615	12121	Economy	4400.00
0005432799667	12121	Economy	4400.00
0005432799817	12121	Economy	4400.00
0005432799665	12121	Economy	4400.00
0005432799637	12121	Economy	4400.00
0005432799681	12121	Economy	4400.00
0005432799697	12121	Economy	4400.00
0005432799818	12121	Economy	4400.00
0005432799672	12121	Economy	4400.00
0005432799883	14803	Economy	4900.00
0005432799904	14803	Economy	4900.00
0005432799891	14803	Economy	4900.00
0005432799893	14803	Economy	4400.00
0005432799902	14803	Economy	4400.00
0005432799885	14803	Economy	4400.00
0005432799895	14803	Economy	4400.00
0005432799886	14803	Economy	4400.00
0005432799884	14803	Economy	4400.00
0005432799887	14803	Economy	4400.00
0005432799906	14803	Economy	4400.00
0005432799892	14803	Economy	4400.00
0005432799879	14803	Economy	4400.00
0005432799881	14803	Economy	4400.00
0005432799896	14803	Economy	4400.00
0005432799878	14803	Economy	4400.00
0005432799907	14803	Economy	4400.00
0005432799880	14803	Economy	4400.00
0005432799898	14803	Economy	4400.00
0005432799888	14803	Economy	4400.00
0005432799905	14803	Economy	4400.00
0005432799894	14803	Economy	4400.00
0005432799903	14803	Economy	4400.00
0005432799901	14803	Economy	4400.00
0005432799890	14803	Economy	4400.00
0005432799899	14803	Economy	4400.00
0005432799889	14803	Economy	4400.00
0005432799900	14803	Economy	4400.00
0005432799897	14803	Economy	4400.00
0005432799882	14803	Economy	4400.00
0005434408819	7074	Business	49100.00
0005434408781	7074	Business	49100.00
0005435293408	7074	Business	49100.00
0005434408792	7074	Business	49100.00
0005434299947	7074	Business	49100.00
0005435293335	7074	Business	49100.00
0005434299953	7074	Business	49100.00
0005435311129	7074	Business	49100.00
0005434408772	7074	Business	49100.00
0005432108293	7074	Business	49100.00
0005434408803	7074	Business	49100.00
0005432108292	7074	Business	49100.00
0005435293377	7074	Economy	16400.00
0005434408830	7074	Economy	16400.00
0005434299945	7074	Economy	16400.00
0005432154054	7074	Economy	16400.00
0005434408816	7074	Economy	16400.00
0005432108294	7074	Economy	16400.00
0005435293336	7074	Economy	16400.00
0005434408806	7074	Economy	16400.00
0005434408818	7074	Economy	16400.00
0005434408805	7074	Economy	16400.00
0005434299948	7074	Economy	16400.00
0005434408788	7074	Economy	16400.00
0005435311074	7074	Economy	16400.00
0005434408823	7074	Economy	16400.00
0005434299949	7074	Economy	16400.00
0005432154053	7074	Economy	16400.00
0005434408827	7074	Economy	16400.00
0005434408771	7074	Economy	16400.00
0005435311088	7074	Economy	16400.00
0005435311106	7074	Economy	16400.00
0005435293347	7074	Economy	16400.00
0005435293346	7074	Economy	16400.00
0005434299936	7074	Economy	16400.00
0005434408797	7074	Economy	16400.00
0005434299933	7074	Economy	16400.00
0005434408794	7074	Economy	16400.00
0005434408799	7074	Economy	16400.00
0005434408796	7074	Economy	16400.00
0005434408782	7074	Economy	16400.00
0005435293362	7074	Economy	16400.00
0005434408809	7074	Economy	16400.00
0005435311114	7074	Economy	16400.00
0005432154055	7074	Economy	16400.00
0005434408824	7074	Economy	16400.00
0005434299944	7074	Economy	16400.00
0005435311091	7074	Economy	16400.00
0005435293352	7074	Economy	16400.00
0005432154052	7074	Economy	16400.00
0005434408777	7074	Economy	16400.00
0005434408811	7074	Economy	16400.00
0005434408808	7074	Economy	18000.00
0005434299940	7074	Economy	18000.00
0005434408775	7074	Economy	18000.00
0005434299938	7074	Economy	18000.00
0005432154051	7074	Economy	18000.00
0005435293345	7074	Economy	18000.00
0005434408833	7074	Economy	16400.00
0005434299943	7074	Economy	16400.00
0005434408791	7074	Economy	16400.00
0005434299954	7074	Economy	16400.00
0005435293344	7074	Economy	16400.00
0005434408784	7074	Economy	16400.00
0005434408815	7074	Economy	16400.00
0005435293343	7074	Economy	16400.00
0005435311107	7074	Economy	16400.00
0005434408776	7074	Economy	16400.00
0005434408783	7074	Economy	16400.00
0005434408785	7074	Economy	16400.00
0005435311132	7074	Economy	16400.00
0005434408804	7074	Economy	16400.00
0005435311108	7074	Economy	16400.00
0005434408789	7074	Economy	16400.00
0005434299934	7074	Economy	16400.00
0005434408790	7074	Economy	16400.00
0005435293409	7074	Economy	16400.00
0005434408825	7074	Economy	16400.00
0005434408828	7074	Economy	16400.00
0005434408817	7074	Economy	16400.00
0005434408821	7074	Economy	16400.00
0005435293325	7074	Economy	16400.00
0005434299950	7074	Economy	16400.00
0005434299951	7074	Economy	16400.00
0005435293326	7074	Economy	16400.00
0005434408807	7074	Economy	16400.00
0005434299939	7074	Economy	16400.00
0005434408786	7074	Economy	16400.00
0005434408801	7074	Economy	16400.00
0005434408829	7074	Economy	16400.00
0005434408800	7074	Economy	16400.00
0005435293378	7074	Economy	16400.00
0005434299952	7074	Economy	16400.00
0005434299935	7074	Economy	16400.00
0005434408822	7074	Economy	16400.00
0005434408820	7074	Economy	16400.00
0005435311116	7074	Economy	16400.00
0005435311115	7074	Economy	16400.00
0005435311121	7074	Economy	16400.00
0005434408834	7074	Economy	16400.00
0005435293327	7074	Economy	16400.00
0005434408780	7074	Economy	16400.00
0005434408802	7074	Economy	16400.00
0005432154056	7074	Economy	16400.00
0005434408779	7074	Economy	16400.00
0005434299946	7074	Economy	16400.00
0005434408826	7074	Economy	16400.00
0005435293358	7074	Economy	16400.00
0005434408774	7074	Economy	16400.00
0005435311092	7074	Economy	16400.00
0005434408795	7074	Economy	16400.00
0005434408814	7074	Economy	16400.00
0005434299955	7074	Economy	16400.00
0005434408831	7074	Economy	16400.00
0005434299941	7074	Economy	16400.00
0005434299937	7074	Economy	16400.00
0005434408787	7074	Economy	16400.00
0005434408832	7074	Economy	16400.00
0005434299942	7074	Economy	16400.00
0005434408798	7074	Economy	16400.00
0005434408812	7074	Economy	16400.00
0005434408778	7074	Economy	16400.00
0005435293410	7074	Economy	16400.00
0005435311131	7074	Economy	16400.00
0005434408810	7074	Economy	16400.00
0005434408773	7074	Economy	16400.00
0005434408813	7074	Economy	16400.00
0005434408793	7074	Economy	16400.00
0005435293462	26882	Business	49100.00
0005434408347	26882	Business	49100.00
0005434299799	26882	Business	49100.00
0005434408171	26882	Business	49100.00
0005434407637	26882	Business	49100.00
0005434408186	26882	Business	49100.00
0005434299878	26882	Business	49100.00
0005434408082	26882	Business	49100.00
0005434299729	26882	Business	49100.00
0005434408398	26882	Business	49100.00
0005434408022	26882	Business	49100.00
0005434407936	26882	Economy	16400.00
0005434299730	26882	Economy	16400.00
0005434408123	26882	Economy	16400.00
0005435311256	26882	Economy	16400.00
0005434407911	26882	Economy	16400.00
0005435311258	26882	Economy	16400.00
0005434299866	26882	Economy	16400.00
0005432058442	26882	Economy	16400.00
0005435311252	26882	Economy	16400.00
0005435293457	26882	Economy	16400.00
0005434408154	26882	Economy	16400.00
0005435293455	26882	Economy	16400.00
0005434408192	26882	Economy	16400.00
0005434408346	26882	Economy	16400.00
0005434408310	26882	Economy	16400.00
0005434299749	26882	Economy	16400.00
0005434408323	26882	Economy	16400.00
0005434408003	26882	Economy	16400.00
0005434408125	26882	Economy	16400.00
0005434299771	26882	Economy	16400.00
0005435293453	26882	Economy	16400.00
0005434408249	26882	Economy	16400.00
0005434408416	26882	Economy	16400.00
0005434408372	26882	Economy	16400.00
0005434408463	26882	Economy	16400.00
0005434299736	26882	Economy	16400.00
0005434408340	26882	Economy	16400.00
0005434407912	26882	Economy	16400.00
0005434408151	26882	Economy	16400.00
0005434408093	26882	Economy	16400.00
0005434408127	26882	Economy	16400.00
0005434408464	26882	Economy	16400.00
0005434408121	26882	Economy	16400.00
0005434299766	26882	Economy	16400.00
0005435311257	26882	Economy	16400.00
0005434408431	26882	Economy	16400.00
0005434408285	26882	Economy	18000.00
0005434407636	26882	Economy	18000.00
0005434408444	26882	Economy	18000.00
0005434408223	26882	Economy	18000.00
0005434408074	26882	Economy	18000.00
0005434408086	26882	Economy	16400.00
0005434407916	26882	Economy	18000.00
0005434299837	26882	Economy	16400.00
0005434408443	26882	Economy	16400.00
0005434299823	26882	Economy	16400.00
0005435311250	26882	Economy	16400.00
0005434299778	26882	Economy	16400.00
0005434299763	26882	Economy	16400.00
0005434408124	26882	Economy	16400.00
0005434408311	26882	Economy	16400.00
0005432058443	26882	Economy	16400.00
0005434408064	26882	Economy	16400.00
0005435293454	26882	Economy	16400.00
0005435311255	26882	Economy	16400.00
0005434299836	26882	Economy	16400.00
0005434408075	26882	Economy	16400.00
0005435311259	26882	Economy	16400.00
0005434408110	26882	Economy	16400.00
0005434299780	26882	Economy	16400.00
0005434408094	26882	Economy	16400.00
0005435293464	26882	Economy	16400.00
0005432058444	26882	Economy	16400.00
0005435311249	26882	Economy	16400.00
0005434408111	26882	Economy	16400.00
0005434299768	26882	Economy	16400.00
0005434408150	26882	Economy	16400.00
0005434408195	26882	Economy	16400.00
0005434299748	26882	Economy	16400.00
0005434408002	26882	Economy	16400.00
0005434408085	26882	Economy	16400.00
0005434408001	26882	Economy	16400.00
0005434408071	26882	Economy	16400.00
0005434408063	26882	Economy	16400.00
0005434299822	26882	Economy	16400.00
0005435293456	26882	Economy	16400.00
0005434408021	26882	Economy	16400.00
0005434408079	26882	Economy	16400.00
0005434299877	26882	Economy	16400.00
0005435311248	26882	Economy	16400.00
0005434299821	26882	Economy	16400.00
0005434408209	26882	Economy	16400.00
0005435311254	26882	Economy	16400.00
0005434408406	26882	Economy	16400.00
0005434408371	26882	Economy	16400.00
0005434408167	26882	Economy	16400.00
0005434408258	26882	Economy	16400.00
0005434408298	26882	Economy	16400.00
0005434408405	26882	Economy	16400.00
0005435311253	26882	Economy	16400.00
0005435293458	26882	Economy	16400.00
0005435293461	26882	Economy	16400.00
0005434408137	26882	Economy	16400.00
0005434408122	26882	Economy	16400.00
0005434408322	26882	Economy	16400.00
0005435311251	26882	Economy	16400.00
0005435293460	26882	Economy	16400.00
0005435293459	26882	Economy	16400.00
0005434408218	26882	Economy	16400.00
0005434299755	26882	Economy	16400.00
0005434408178	26882	Economy	16400.00
0005434407877	26882	Economy	16400.00
0005434299779	26882	Economy	16400.00
0005435293463	26882	Economy	16400.00
0005434408341	26882	Economy	16400.00
0005434408259	26882	Economy	16400.00
0005434408131	26882	Economy	16400.00
0005432605014	6447	Economy	16500.00
0005432605015	6447	Economy	16500.00
0005432604992	6447	Economy	16500.00
0005432604986	6447	Economy	15000.00
0005432605019	6447	Economy	15000.00
0005434512194	6447	Economy	15000.00
0005432605004	6447	Economy	15000.00
0005432604998	6447	Economy	15000.00
0005434512195	6447	Economy	15000.00
0005432605013	6447	Economy	15000.00
0005432605018	6447	Economy	15000.00
0005432604993	6447	Economy	15000.00
0005432605006	6447	Economy	15000.00
0005432605012	6447	Economy	15000.00
0005432604990	6447	Economy	15000.00
0005434512190	6447	Economy	15000.00
0005432605005	6447	Economy	15000.00
0005432605016	6447	Economy	15000.00
0005432604989	6447	Economy	15000.00
0005432604982	6447	Economy	15000.00
0005432605017	6447	Economy	15000.00
0005432604996	6447	Economy	15000.00
0005434512192	6447	Economy	15000.00
0005432605008	6447	Economy	15000.00
0005432604995	6447	Economy	15000.00
0005432605010	6447	Economy	15000.00
0005432604991	6447	Economy	15000.00
0005432604983	6447	Economy	15000.00
0005432604987	6447	Economy	15000.00
0005432605009	6447	Economy	15000.00
0005432605003	6447	Economy	15000.00
0005432604985	6447	Economy	15000.00
0005432605000	6447	Economy	15000.00
0005432604984	6447	Economy	15000.00
0005432605007	6447	Economy	15000.00
0005434512191	6447	Economy	15000.00
0005432605011	6447	Economy	15000.00
0005432605002	6447	Economy	15000.00
0005432604999	6447	Economy	15000.00
0005432605001	6447	Economy	15000.00
0005432605020	6447	Economy	15000.00
0005434512193	6447	Economy	15000.00
0005432604997	6447	Economy	15000.00
0005432604981	6447	Economy	15000.00
0005432604988	6447	Economy	15000.00
0005432604994	6447	Economy	15000.00
0005432604592	21386	Economy	16500.00
0005432604753	21386	Economy	16500.00
0005432604499	21386	Economy	16500.00
0005432604595	21386	Economy	15000.00
0005432604546	21386	Economy	15000.00
0005432604788	21386	Economy	15000.00
0005432604781	21386	Economy	15000.00
0005432604609	21386	Economy	15000.00
0005435221524	21386	Economy	15000.00
0005432604645	21386	Economy	15000.00
0005432604547	21386	Economy	15000.00
0005432604600	21386	Economy	15000.00
0005432604447	21386	Economy	15000.00
0005432604376	21386	Economy	15000.00
0005432604436	21386	Economy	15000.00
0005432604375	21386	Economy	15000.00
0005432604545	21386	Economy	15000.00
0005432604512	21386	Economy	15000.00
0005432604596	21386	Economy	15000.00
0005432604601	21386	Economy	15000.00
0005432604394	21386	Economy	15000.00
0005432604606	21386	Economy	15000.00
0005432604677	21386	Economy	15000.00
0005432604542	21386	Economy	15000.00
0005432604551	21386	Economy	15000.00
0005432604682	21386	Economy	15000.00
0005432604577	21386	Economy	15000.00
0005432604567	21386	Economy	15000.00
0005432604513	21386	Economy	15000.00
0005435221525	21386	Economy	15000.00
0005432604648	21386	Economy	15000.00
0005432604568	21386	Economy	15000.00
0005432604578	21386	Economy	15000.00
0005432604498	21386	Economy	15000.00
0005432604726	21386	Economy	15000.00
0005432604590	21386	Economy	15000.00
0005435221067	21386	Economy	15000.00
0005434512165	21386	Economy	15000.00
0005432604857	21386	Economy	15000.00
0005432604559	21386	Economy	15000.00
0005432604393	21386	Economy	15000.00
0005435221066	21386	Economy	15000.00
0005432604752	21386	Economy	15000.00
0005432604496	21386	Economy	15000.00
0005435221547	21386	Economy	15000.00
0005432604593	21386	Economy	15000.00
0005434512145	21386	Economy	15000.00
0005432604448	21386	Economy	15000.00
0005433251981	14981	Business	18900.00
0005433251983	14981	Business	18900.00
0005433251974	14981	Business	18900.00
0005434907645	14981	Business	18900.00
0005433251987	14981	Business	18900.00
0005434907533	14981	Business	18900.00
0005434907478	14981	Business	18900.00
0005434907456	14981	Business	18900.00
0005434907547	14981	Business	18900.00
0005434907759	14981	Economy	6300.00
0005434907747	14981	Economy	6300.00
0005433251991	14981	Economy	6300.00
0005434907609	14981	Economy	6300.00
0005434907763	14981	Economy	6300.00
0005434907582	14981	Economy	6300.00
0005433251971	14981	Economy	6300.00
0005433251997	14981	Economy	6300.00
0005434907612	14981	Economy	6900.00
0005433251990	14981	Economy	6900.00
0005434907643	14981	Economy	6900.00
0005434907511	14981	Economy	6900.00
0005434907646	14981	Economy	6900.00
0005434907523	14981	Economy	6300.00
0005433251996	14981	Economy	6300.00
0005434907764	14981	Economy	6300.00
0005434907491	14981	Economy	6300.00
0005434907495	14981	Economy	6300.00
0005434907760	14981	Economy	6300.00
0005434907716	14981	Economy	6300.00
0005433251972	14981	Economy	6300.00
0005433251989	14981	Economy	6300.00
0005433251979	14981	Economy	6300.00
0005433251973	14981	Economy	6300.00
0005434907622	14981	Economy	6300.00
0005434907554	14981	Economy	6300.00
0005433251995	14981	Economy	6300.00
0005433251985	14981	Economy	6300.00
0005433252001	14981	Economy	6300.00
0005433251980	14981	Economy	6300.00
0005433251982	14981	Economy	6300.00
0005433251992	14981	Economy	6300.00
0005433251999	14981	Economy	6300.00
0005434907695	14981	Economy	6300.00
0005434907543	14981	Economy	6300.00
0005434907583	14981	Economy	6300.00
0005434907464	14981	Economy	6300.00
0005433251994	14981	Economy	6300.00
0005434907621	14981	Economy	6300.00
0005434907542	14981	Economy	6300.00
0005434907632	14981	Economy	6300.00
0005434907633	14981	Economy	6300.00
0005434907749	14981	Economy	6300.00
0005434907673	14981	Economy	6300.00
0005434907680	14981	Economy	6300.00
0005434907694	14981	Economy	6300.00
0005434907748	14981	Economy	6300.00
0005434907552	14981	Economy	6300.00
0005434907599	14981	Economy	6300.00
0005434907538	14981	Economy	6300.00
0005434907565	14981	Economy	6300.00
0005434907751	14981	Economy	6300.00
0005434907556	14981	Economy	6300.00
0005433251984	14981	Economy	6300.00
0005433251975	14981	Economy	6300.00
0005433251978	14981	Economy	6300.00
0005434907553	14981	Economy	6300.00
0005433251993	14981	Economy	6300.00
0005434907655	14981	Economy	6300.00
0005434907548	14981	Economy	6300.00
0005434907642	14981	Economy	6300.00
0005434907691	14981	Economy	6300.00
0005434907638	14981	Economy	6300.00
0005433251977	14981	Economy	6300.00
0005433251988	14981	Economy	6300.00
0005434907532	14981	Economy	6300.00
0005433252000	14981	Economy	6300.00
0005433251998	14981	Economy	6300.00
0005434907561	14981	Economy	6300.00
0005434907668	14981	Economy	6300.00
0005434907669	14981	Economy	6300.00
0005434907765	14981	Economy	6300.00
0005434907623	14981	Economy	6300.00
0005434907738	14981	Economy	6300.00
0005433251986	14981	Economy	6300.00
0005433251976	14981	Economy	6300.00
0005433251675	25818	Business	18900.00
0005433251700	25818	Business	18900.00
0005434908074	25818	Business	18900.00
0005434908105	25818	Business	18900.00
0005434908080	25818	Business	18900.00
0005434908095	25818	Business	18900.00
0005433251769	25818	Business	18900.00
0005434908081	25818	Business	18900.00
0005434908122	25818	Business	18900.00
0005433251571	25818	Business	18900.00
0005434908092	25818	Economy	6300.00
0005434908090	25818	Economy	6300.00
0005434908085	25818	Economy	6300.00
0005434908079	25818	Economy	6300.00
0005434908121	25818	Economy	6300.00
0005434908112	25818	Economy	6300.00
0005434908111	25818	Economy	6300.00
0005434908101	25818	Economy	6300.00
0005433251654	25818	Economy	6300.00
0005434908123	25818	Economy	6300.00
0005434908120	25818	Economy	6900.00
0005434908096	25818	Economy	6900.00
0005434908087	25818	Economy	6900.00
0005433251598	25818	Economy	6300.00
0005434908099	25818	Economy	6300.00
0005433251738	25818	Economy	6300.00
0005434908072	25818	Economy	6300.00
0005433251879	25818	Economy	6300.00
0005434908076	25818	Economy	6300.00
0005433251832	25818	Economy	6300.00
0005434908116	25818	Economy	6300.00
0005434908124	25818	Economy	6300.00
0005433251679	25818	Economy	6300.00
0005433251724	25818	Economy	6300.00
0005434908106	25818	Economy	6300.00
0005433251616	25818	Economy	6300.00
0005434908102	25818	Economy	6300.00
0005434908089	25818	Economy	6300.00
0005434908109	25818	Economy	6300.00
0005433251536	25818	Economy	6300.00
0005434908119	25818	Economy	6300.00
0005434908098	25818	Economy	6300.00
0005434908073	25818	Economy	6300.00
0005434908118	25818	Economy	6300.00
0005434908113	25818	Economy	6300.00
0005434908082	25818	Economy	6300.00
0005434908091	25818	Economy	6300.00
0005434908088	25818	Economy	6300.00
0005434908078	25818	Economy	6300.00
0005434908083	25818	Economy	6300.00
0005434908094	25818	Economy	6300.00
0005434908070	25818	Economy	6300.00
0005433251744	25818	Economy	6300.00
0005433251699	25818	Economy	6300.00
0005434908117	25818	Economy	6300.00
0005434908086	25818	Economy	6300.00
0005434908115	25818	Economy	6300.00
0005433251768	25818	Economy	6300.00
0005434908108	25818	Economy	6300.00
0005434908104	25818	Economy	6300.00
0005433251698	25818	Economy	6300.00
0005433251733	25818	Economy	6300.00
0005433251714	25818	Economy	6300.00
0005434908100	25818	Economy	6300.00
0005434908103	25818	Economy	6300.00
0005433251787	25818	Economy	6300.00
0005434908097	25818	Economy	6300.00
0005433251756	25818	Economy	6300.00
0005434908077	25818	Economy	6300.00
0005434908110	25818	Economy	6300.00
0005433251676	25818	Economy	6300.00
0005434908114	25818	Economy	6300.00
0005434908075	25818	Economy	6300.00
0005434908107	25818	Economy	6300.00
0005434908071	25818	Economy	6300.00
0005434908125	25818	Economy	6300.00
0005434908084	25818	Economy	6300.00
0005433251765	25818	Economy	6300.00
0005433251764	25818	Economy	6300.00
0005434908069	25818	Economy	6300.00
0005434908093	25818	Economy	6300.00
0005433009363	14186	Business	52300.00
0005433009389	14186	Business	52300.00
0005433009394	14186	Business	52300.00
0005433009371	14186	Business	52300.00
0005433009384	14186	Business	52300.00
0005433009396	14186	Business	52300.00
0005433009382	14186	Business	52300.00
0005433009357	14186	Business	52300.00
0005433009355	14186	Economy	17400.00
0005433009398	14186	Economy	17400.00
0005433009390	14186	Economy	17400.00
0005433810574	14186	Economy	17400.00
0005433009381	14186	Economy	19200.00
0005433009370	14186	Economy	19200.00
0005433009391	14186	Economy	19200.00
0005433009388	14186	Economy	17400.00
0005433009360	14186	Economy	17400.00
0005433009353	14186	Economy	17400.00
0005433810572	14186	Economy	17400.00
0005433009362	14186	Economy	17400.00
0005433009383	14186	Economy	17400.00
0005433009373	14186	Economy	17400.00
0005433009372	14186	Economy	17400.00
0005433009386	14186	Economy	17400.00
0005433009369	14186	Economy	17400.00
0005433009354	14186	Economy	17400.00
0005433009393	14186	Economy	17400.00
0005433009368	14186	Economy	17400.00
0005433009378	14186	Economy	17400.00
0005433810573	14186	Economy	17400.00
0005433009365	14186	Economy	17400.00
0005433009361	14186	Economy	17400.00
0005433009387	14186	Economy	17400.00
0005433009392	14186	Economy	17400.00
0005433810567	14186	Economy	17400.00
0005433009359	14186	Economy	17400.00
0005433009397	14186	Economy	17400.00
0005433009377	14186	Economy	17400.00
0005433810568	14186	Economy	17400.00
0005433009364	14186	Economy	17400.00
0005433009385	14186	Economy	17400.00
0005433009358	14186	Economy	17400.00
0005433009380	14186	Economy	17400.00
0005433009379	14186	Economy	17400.00
0005433009376	14186	Economy	17400.00
0005433009356	14186	Economy	17400.00
0005433009367	14186	Economy	17400.00
0005433009366	14186	Economy	17400.00
0005433009395	14186	Economy	17400.00
0005433009375	14186	Economy	17400.00
0005433009374	14186	Economy	17400.00
0005433008921	22875	Business	52300.00
0005433009053	22875	Business	52300.00
0005433008998	22875	Business	52300.00
0005433008888	22875	Business	52300.00
0005433008885	22875	Business	52300.00
0005433008989	22875	Business	52300.00
0005433008819	22875	Business	52300.00
0005433008772	22875	Economy	17400.00
0005433008860	22875	Economy	17400.00
0005433008855	22875	Economy	17400.00
0005433008856	22875	Economy	17400.00
0005433009052	22875	Economy	19200.00
0005433810612	22875	Economy	19200.00
0005433009018	22875	Economy	19200.00
0005433008990	22875	Economy	17400.00
0005433008876	22875	Economy	17400.00
0005433009022	22875	Economy	17400.00
0005433008733	22875	Economy	17400.00
0005433008862	22875	Economy	17400.00
0005433008920	22875	Economy	17400.00
0005433008984	22875	Economy	17400.00
0005433008912	22875	Economy	17400.00
0005433810610	22875	Economy	17400.00
0005433008831	22875	Economy	17400.00
0005433008987	22875	Economy	17400.00
0005433009019	22875	Economy	17400.00
0005433008841	22875	Economy	17400.00
0005433008867	22875	Economy	17400.00
0005433008830	22875	Economy	17400.00
0005433008993	22875	Economy	17400.00
0005433008881	22875	Economy	17400.00
0005433008796	22875	Economy	17400.00
0005433008889	22875	Economy	17400.00
0005433008832	22875	Economy	17400.00
0005433009021	22875	Economy	17400.00
0005433008884	22875	Economy	17400.00
0005433810611	22875	Economy	17400.00
0005433008710	22875	Economy	17400.00
0005433009054	22875	Economy	17400.00
0005433008732	22875	Economy	17400.00
0005433008880	22875	Economy	17400.00
0005433008857	22875	Economy	17400.00
0005433009105	22875	Economy	17400.00
0005433008992	22875	Economy	17400.00
0005433810613	22875	Economy	17400.00
0005433008795	22875	Economy	17400.00
0005433008939	22875	Economy	17400.00
0005433009020	22875	Economy	17400.00
0005433008858	22875	Economy	17400.00
0005434926038	14933	Business	22900.00
0005434926010	14933	Business	22900.00
0005434926043	14933	Business	22900.00
0005434926057	14933	Business	22900.00
0005434925996	14933	Business	22900.00
0005434926049	14933	Economy	7600.00
0005434925882	14933	Economy	7600.00
0005434926036	14933	Economy	7600.00
0005434926028	14933	Economy	7600.00
0005434925972	14933	Economy	7600.00
0005434925933	14933	Economy	7600.00
0005434925860	14933	Economy	7600.00
0005434925887	14933	Economy	8400.00
0005434926056	14933	Economy	8400.00
0005434926065	14933	Economy	7600.00
0005434926048	14933	Economy	7600.00
0005434925943	14933	Economy	7600.00
0005434925942	14933	Economy	7600.00
0005434926073	14933	Economy	7600.00
0005434926083	14933	Economy	7600.00
0005434926052	14933	Economy	7600.00
0005434926080	14933	Economy	7600.00
0005434926046	14933	Economy	7600.00
0005434926072	14933	Economy	7600.00
0005434926009	14933	Economy	7600.00
0005434926071	14933	Economy	7600.00
0005434925968	14933	Economy	7600.00
0005434926032	14933	Economy	7600.00
0005434926034	14933	Economy	7600.00
0005434926008	14933	Economy	7600.00
0005434925959	14933	Economy	7600.00
0005434925916	14933	Economy	7600.00
0005434926303	20508	Business	22900.00
0005434926294	20508	Economy	7600.00
0005434926319	20508	Economy	7600.00
0005434926308	20508	Economy	7600.00
0005434926297	20508	Economy	7600.00
0005434926314	20508	Economy	7600.00
0005434926292	20508	Economy	8400.00
0005434926311	20508	Economy	8400.00
0005434926293	20508	Economy	7600.00
0005434926300	20508	Economy	7600.00
0005434926295	20508	Economy	7600.00
0005434926291	20508	Economy	7600.00
0005434926321	20508	Economy	7600.00
0005434926298	20508	Economy	7600.00
0005434926309	20508	Economy	7600.00
0005434926301	20508	Economy	7600.00
0005434926313	20508	Economy	7600.00
0005434926304	20508	Economy	7600.00
0005434926315	20508	Economy	7600.00
0005434926320	20508	Economy	7600.00
0005434926316	20508	Economy	7600.00
0005434926286	20508	Economy	7600.00
0005434926296	20508	Economy	7600.00
0005434926290	20508	Economy	7600.00
0005434926285	20508	Economy	7600.00
0005434926318	20508	Economy	7600.00
0005434926287	20508	Economy	7600.00
0005434926306	20508	Economy	7600.00
0005434926305	20508	Economy	7600.00
0005434926289	20508	Economy	7600.00
0005434926324	20508	Economy	7600.00
0005434926323	20508	Economy	7600.00
0005434926322	20508	Economy	7600.00
0005434926312	20508	Economy	7600.00
0005434926326	20508	Economy	7600.00
0005434926317	20508	Economy	7600.00
0005434926310	20508	Economy	7600.00
0005434926288	20508	Economy	7600.00
0005434926302	20508	Economy	7600.00
0005434926325	20508	Economy	7600.00
0005434926307	20508	Economy	7600.00
0005434926299	20508	Economy	7600.00
0005435999378	15828	Economy	8900.00
0005435488189	15828	Economy	8900.00
0005435488198	15828	Economy	8900.00
0005435999344	15828	Economy	8100.00
0005435488187	15828	Economy	8100.00
0005435488200	15828	Economy	8100.00
0005435999349	15828	Economy	8100.00
0005435999291	15828	Economy	8100.00
0005435999292	15828	Economy	8100.00
0005435999347	15828	Economy	8100.00
0005435488205	15828	Economy	8100.00
0005435999384	15828	Economy	8100.00
0005435999367	15828	Economy	8100.00
0005435488206	15828	Economy	8100.00
0005435999343	15828	Economy	8100.00
0005435488199	15828	Economy	8100.00
0005435999372	15828	Economy	8100.00
0005435488201	15828	Economy	8100.00
0005435488193	15828	Economy	8100.00
0005435999290	15828	Economy	8100.00
0005435999329	15828	Economy	8100.00
0005435488188	15828	Economy	8100.00
0005435488203	15828	Economy	8100.00
0005435999350	15828	Economy	8100.00
0005435488196	15828	Economy	8100.00
0005435488204	15828	Economy	8100.00
0005435999348	15828	Economy	8100.00
0005435488186	15828	Economy	8100.00
0005435999380	15828	Economy	8100.00
0005435999369	15828	Economy	8100.00
0005435999368	15828	Economy	8100.00
0005435488191	15828	Economy	8100.00
0005435999382	15828	Economy	8100.00
0005435488194	15828	Economy	8100.00
0005435488192	15828	Economy	8100.00
0005435488197	15828	Economy	8100.00
0005435488195	15828	Economy	8100.00
0005435488202	15828	Economy	8100.00
0005435999363	15828	Economy	8100.00
0005435488190	15828	Economy	8100.00
0005435999379	15828	Economy	8100.00
0005435999524	19688	Economy	8900.00
0005435487936	19688	Economy	8900.00
0005435999527	19688	Economy	8100.00
0005435488028	19688	Economy	8100.00
0005435999523	19688	Economy	8100.00
0005435487984	19688	Economy	8100.00
0005435999525	19688	Economy	8100.00
0005435999522	19688	Economy	8100.00
0005435487994	19688	Economy	8100.00
0005435488026	19688	Economy	8100.00
0005435487868	19688	Economy	8100.00
0005435487833	19688	Economy	8100.00
0005435999512	19688	Economy	8100.00
0005435999521	19688	Economy	8100.00
0005435487934	19688	Economy	8100.00
0005435999516	19688	Economy	8100.00
0005435487983	19688	Economy	8100.00
0005435999514	19688	Economy	8100.00
0005435999519	19688	Economy	8100.00
0005435999510	19688	Economy	8100.00
0005435999511	19688	Economy	8100.00
0005435487955	19688	Economy	8100.00
0005435999520	19688	Economy	8100.00
0005435999513	19688	Economy	8100.00
0005435487995	19688	Economy	8100.00
0005435487953	19688	Economy	8100.00
0005435488063	19688	Economy	8100.00
0005435999517	19688	Economy	8100.00
0005435487956	19688	Economy	8100.00
0005435999528	19688	Economy	8100.00
0005435999515	19688	Economy	8100.00
0005435999526	19688	Economy	8100.00
0005435999529	19688	Economy	8100.00
0005435488013	19688	Economy	8100.00
0005435487967	19688	Economy	8100.00
0005435999518	19688	Economy	8100.00
0005435487915	19688	Economy	8100.00
0005435487913	19688	Economy	8100.00
0005432142305	5997	Business	199300.00
0005435472925	5997	Business	199300.00
0005432659741	5997	Business	199300.00
0005435472939	5997	Business	199300.00
0005432660854	5997	Business	199300.00
0005435472899	5997	Business	199300.00
0005435839914	5997	Business	199300.00
0005435839932	5997	Business	199300.00
0005435839923	5997	Economy	66400.00
0005432660855	5997	Economy	66400.00
0005435839931	5997	Economy	66400.00
0005435839936	5997	Economy	66400.00
0005435839910	5997	Economy	66400.00
0005435839926	5997	Economy	66400.00
0005435472832	5997	Economy	66400.00
0005435839921	5997	Economy	66400.00
0005432659742	5997	Economy	66400.00
0005432659743	5997	Economy	73100.00
0005432658628	5997	Economy	73100.00
0005435839919	5997	Economy	66400.00
0005435472897	5997	Economy	66400.00
0005435839913	5997	Economy	66400.00
0005435839912	5997	Economy	66400.00
0005432142303	5997	Economy	66400.00
0005435472874	5997	Economy	66400.00
0005435839920	5997	Economy	66400.00
0005435839909	5997	Economy	66400.00
0005435472938	5997	Economy	66400.00
0005432660853	5997	Economy	66400.00
0005432659744	5997	Economy	66400.00
0005432142306	5997	Economy	66400.00
0005435839916	5997	Economy	66400.00
0005435472944	5997	Economy	66400.00
0005435839930	5997	Economy	66400.00
0005435839915	5997	Economy	66400.00
0005435839929	5997	Economy	66400.00
0005435472917	5997	Economy	66400.00
0005435839917	5997	Economy	66400.00
0005435839927	5997	Economy	66400.00
0005435839908	5997	Economy	66400.00
0005435839918	5997	Economy	66400.00
0005435839935	5997	Economy	66400.00
0005432142304	5997	Economy	66400.00
0005435839933	5997	Economy	66400.00
0005435839922	5997	Economy	66400.00
0005435472894	5997	Economy	66400.00
0005435472893	5997	Economy	66400.00
0005435839934	5997	Economy	66400.00
0005435839937	5997	Economy	66400.00
0005435472918	5997	Economy	66400.00
0005435839928	5997	Economy	66400.00
0005435839911	5997	Economy	66400.00
0005435839924	5997	Economy	66400.00
0005435839925	5997	Economy	66400.00
0005435472991	5997	Economy	66400.00
0005435839688	18081	Business	199300.00
0005435839664	18081	Business	199300.00
0005435839733	18081	Business	199300.00
0005435839714	18081	Business	199300.00
0005435839566	18081	Business	199300.00
0005432667465	18081	Business	199300.00
0005435839717	18081	Business	199300.00
0005435839591	18081	Business	199300.00
0005435473072	18081	Business	199300.00
0005435473074	18081	Business	199300.00
0005435839716	18081	Business	199300.00
0005435473075	18081	Business	199300.00
0005435839757	18081	Business	199300.00
0005435839577	18081	Business	199300.00
0005435839734	18081	Economy	66400.00
0005435839749	18081	Economy	66400.00
0005435839723	18081	Economy	66400.00
0005435473083	18081	Economy	66400.00
0005435839750	18081	Economy	66400.00
0005432537095	18081	Economy	66400.00
0005435473071	18081	Economy	66400.00
0005435839623	18081	Economy	73100.00
0005435839632	18081	Economy	73100.00
0005432660835	18081	Economy	66400.00
0005435839646	18081	Economy	66400.00
0005435473073	18081	Economy	66400.00
0005435839593	18081	Economy	66400.00
0005435473080	18081	Economy	66400.00
0005435473070	18081	Economy	66400.00
0005435473084	18081	Economy	66400.00
0005432664152	18081	Economy	66400.00
0005435839739	18081	Economy	66400.00
0005435473076	18081	Economy	66400.00
0005432660836	18081	Economy	66400.00
0005435473079	18081	Economy	66400.00
0005435839578	18081	Economy	66400.00
0005435839758	18081	Economy	66400.00
0005435473081	18081	Economy	66400.00
0005432537096	18081	Economy	66400.00
0005432664154	18081	Economy	66400.00
0005435473077	18081	Economy	66400.00
0005435839756	18081	Economy	66400.00
0005435473078	18081	Economy	66400.00
0005435839662	18081	Economy	66400.00
0005432660825	18081	Economy	66400.00
0005435839715	18081	Economy	66400.00
0005435839627	18081	Economy	66400.00
0005435839562	18081	Economy	66400.00
0005432664151	18081	Economy	66400.00
0005435839759	18081	Economy	66400.00
0005432664150	18081	Economy	66400.00
0005435473085	18081	Economy	66400.00
0005435839587	18081	Economy	66400.00
0005432664155	18081	Economy	66400.00
0005435839586	18081	Economy	66400.00
0005435839592	18081	Economy	66400.00
0005435839696	18081	Economy	66400.00
0005435839732	18081	Economy	66400.00
0005435473082	18081	Economy	66400.00
0005435839781	18081	Economy	66400.00
0005433285381	23003	Business	15700.00
0005433285461	23003	Business	15700.00
0005433285557	23003	Business	15700.00
0005433285464	23003	Business	15700.00
0005433285571	23003	Business	15700.00
0005433285590	23003	Economy	5200.00
0005433285467	23003	Economy	5200.00
0005433285642	23003	Economy	5200.00
0005433285530	23003	Economy	5200.00
0005433285531	23003	Economy	5200.00
0005433285586	23003	Economy	5200.00
0005435104061	23003	Economy	5200.00
0005433285603	23003	Economy	5200.00
0005433285595	23003	Economy	5200.00
0005433285594	23003	Economy	5700.00
0005433285380	23003	Economy	5700.00
0005433285529	23003	Economy	5700.00
0005433285462	23003	Economy	5200.00
0005435104058	23003	Economy	5200.00
0005433285473	23003	Economy	5200.00
0005433285552	23003	Economy	5200.00
0005433285465	23003	Economy	5200.00
0005433285592	23003	Economy	5200.00
0005433285551	23003	Economy	5200.00
0005433285639	23003	Economy	5200.00
0005433285474	23003	Economy	5200.00
0005433285525	23003	Economy	5200.00
0005433285523	23003	Economy	5200.00
0005433285527	23003	Economy	5200.00
0005433285468	23003	Economy	5200.00
0005433285522	23003	Economy	5200.00
0005433285576	23003	Economy	5200.00
0005433285627	23003	Economy	5200.00
0005433285593	23003	Economy	5200.00
0005433285546	23003	Economy	5200.00
0005433285591	23003	Economy	5200.00
0005433285528	23003	Economy	5200.00
0005433285651	23003	Economy	5200.00
0005435104059	23003	Economy	5200.00
0005433285601	23003	Economy	5200.00
0005435104060	23003	Economy	5200.00
0005433285524	23003	Economy	5200.00
0005433285466	23003	Economy	5200.00
0005433285824	32044	Business	15700.00
0005433285805	32044	Business	15700.00
0005433285815	32044	Business	15700.00
0005433285821	32044	Business	15700.00
0005433285826	32044	Business	15700.00
0005433285827	32044	Economy	5200.00
0005435103971	32044	Economy	5200.00
0005433285806	32044	Economy	5200.00
0005435103976	32044	Economy	5200.00
0005435103943	32044	Economy	5200.00
0005435103970	32044	Economy	5200.00
0005433285823	32044	Economy	5200.00
0005433285831	32044	Economy	5200.00
0005433285812	32044	Economy	5200.00
0005433285825	32044	Economy	5200.00
0005433285822	32044	Economy	5200.00
0005433285819	32044	Economy	5200.00
0005435103941	32044	Economy	5200.00
0005433285830	32044	Economy	5700.00
0005433285814	32044	Economy	5200.00
0005435103974	32044	Economy	5200.00
0005433285834	32044	Economy	5200.00
0005433285818	32044	Economy	5200.00
0005433285817	32044	Economy	5200.00
0005435103942	32044	Economy	5200.00
0005433285808	32044	Economy	5200.00
0005435103947	32044	Economy	5200.00
0005435103977	32044	Economy	5200.00
0005435103975	32044	Economy	5200.00
0005433285810	32044	Economy	5200.00
0005433285809	32044	Economy	5200.00
0005433285833	32044	Economy	5200.00
0005435103973	32044	Economy	5200.00
0005435103972	32044	Economy	5200.00
0005433285835	32044	Economy	5200.00
0005435103944	32044	Economy	5200.00
0005433285832	32044	Economy	5200.00
0005433285813	32044	Economy	5200.00
0005433285811	32044	Economy	5200.00
0005435103946	32044	Economy	5200.00
0005433285807	32044	Economy	5200.00
0005433285816	32044	Economy	5200.00
0005433285820	32044	Economy	5200.00
0005433285828	32044	Economy	5200.00
0005433285829	32044	Economy	5200.00
0005433475708	23869	Economy	13500.00
0005433475709	23869	Economy	12300.00
0005433475745	23869	Economy	12300.00
0005433475738	23869	Economy	12300.00
0005433475728	23869	Economy	12300.00
0005435852620	23869	Economy	12300.00
0005433475749	23869	Economy	12300.00
0005433475750	23869	Economy	12300.00
0005435852622	23869	Economy	12300.00
0005435852623	23869	Economy	12300.00
0005433475729	23869	Economy	12300.00
0005435852621	23869	Economy	12300.00
0005435852618	23869	Economy	12300.00
0005435852619	23869	Economy	12300.00
0005433475746	23869	Economy	12300.00
0005433475739	23869	Economy	12300.00
0005433475748	23869	Economy	12300.00
0005432528836	30588	Business	42100.00
0005432528944	30588	Business	42100.00
0005434068154	30588	Business	42100.00
0005435725688	30588	Business	42100.00
0005435214704	30588	Business	42100.00
0005435725690	30588	Business	42100.00
0005434068223	30588	Business	42100.00
0005432528942	30588	Business	42100.00
0005432529156	30588	Business	42100.00
0005435214696	30588	Business	42100.00
0005434068328	30588	Business	42100.00
0005432529235	30588	Business	42100.00
0005432528791	30588	Business	42100.00
0005432529376	30588	Business	42100.00
0005432528727	30588	Business	42100.00
0005432159936	30588	Business	42100.00
0005434067898	30588	Business	42100.00
0005434067910	30588	Business	42100.00
0005434068036	30588	Business	42100.00
0005432528880	30588	Business	42100.00
0005435214730	30588	Business	42100.00
0005434068096	30588	Business	42100.00
0005434068031	30588	Business	42100.00
0005435214750	30588	Business	42100.00
0005432529236	30588	Business	42100.00
0005435214752	30588	Comfort	23900.00
0005432529018	30588	Comfort	23900.00
0005432529437	30588	Comfort	23900.00
0005432529211	30588	Comfort	23900.00
0005434068155	30588	Comfort	23900.00
0005432529128	30588	Comfort	23900.00
0005434068171	30588	Comfort	23900.00
0005432529134	30588	Comfort	23900.00
0005432529230	30588	Comfort	23900.00
0005432529176	30588	Comfort	23900.00
0005432528903	30588	Comfort	23900.00
0005432211634	30588	Comfort	23900.00
0005432529485	30588	Comfort	23900.00
0005435214694	30588	Comfort	23900.00
0005432211628	30588	Comfort	23900.00
0005432528786	30588	Comfort	23900.00
0005435214701	30588	Comfort	23900.00
0005434068084	30588	Comfort	23900.00
0005435214697	30588	Comfort	23900.00
0005432528952	30588	Comfort	23900.00
0005434067973	30588	Comfort	23900.00
0005432528591	30588	Comfort	23900.00
0005432528919	30588	Comfort	23900.00
0005432529120	30588	Comfort	23900.00
0005432528931	30588	Comfort	23900.00
0005435214713	30588	Comfort	23900.00
0005435214731	30588	Comfort	23900.00
0005434067912	30588	Comfort	23900.00
0005434068138	30588	Comfort	23900.00
0005435725685	30588	Comfort	23900.00
0005435214739	30588	Comfort	23900.00
0005434068114	30588	Comfort	23900.00
0005434068109	30588	Comfort	23900.00
0005435214725	30588	Comfort	23900.00
0005434067989	30588	Comfort	23900.00
0005432528737	30588	Comfort	23900.00
0005435214735	30588	Comfort	23900.00
0005432533310	30588	Economy	14000.00
0005435214753	30588	Economy	14000.00
0005432528987	30588	Economy	14000.00
0005435214734	30588	Economy	14000.00
0005435725687	30588	Economy	14000.00
0005435214754	30588	Economy	14000.00
0005435214748	30588	Economy	14000.00
0005432211631	30588	Economy	14000.00
0005435214692	30588	Economy	14000.00
0005432528621	30588	Economy	14000.00
0005434068179	30588	Economy	14000.00
0005432529365	30588	Economy	14000.00
0005432528555	30588	Economy	14000.00
0005432529348	30588	Economy	14000.00
0005432528792	30588	Economy	14000.00
0005432529472	30588	Economy	14000.00
0005435214690	30588	Economy	14000.00
0005435214743	30588	Economy	14000.00
0005435214688	30588	Economy	14000.00
0005432529570	30588	Economy	14000.00
0005435214729	30588	Economy	14000.00
0005434067937	30588	Economy	14000.00
0005434067955	30588	Economy	14000.00
0005435214732	30588	Economy	14000.00
0005433656730	30588	Economy	14000.00
0005432529074	30588	Economy	14000.00
0005432528775	30588	Economy	14000.00
0005432528937	30588	Economy	14000.00
0005435214717	30588	Economy	14000.00
0005434068110	30588	Economy	14000.00
0005432528872	30588	Economy	14000.00
0005435214740	30588	Economy	14000.00
0005432529370	30588	Economy	14000.00
0005432529390	30588	Economy	14000.00
0005432529357	30588	Economy	14000.00
0005432428964	30588	Economy	14000.00
0005432529541	30588	Economy	14000.00
0005432529167	30588	Economy	14000.00
0005434068180	30588	Economy	14000.00
0005434068144	30588	Economy	14000.00
0005432529129	30588	Economy	14000.00
0005434068276	30588	Economy	14000.00
0005432528870	30588	Economy	14000.00
0005435214741	30588	Economy	14000.00
0005434068314	30588	Economy	14000.00
0005432529309	30588	Economy	14000.00
0005435214712	30588	Economy	14000.00
0005432528986	30588	Economy	14000.00
0005432528793	30588	Economy	14000.00
0005434067959	30588	Economy	14000.00
0005432528943	30588	Economy	14000.00
0005435214705	30588	Economy	14000.00
0005432529281	30588	Economy	15400.00
0005434067936	30588	Economy	14000.00
0005432529368	30588	Economy	15400.00
0005432528738	30588	Economy	15400.00
0005432528316	30588	Economy	14000.00
0005434067996	30588	Economy	14000.00
0005435214742	30588	Economy	14000.00
0005432528429	30588	Economy	14000.00
0005432528776	30588	Economy	15400.00
0005432529568	30588	Economy	15400.00
0005432529064	30588	Economy	15400.00
0005432529198	30588	Economy	14000.00
0005435214711	30588	Economy	14000.00
0005432211632	30588	Economy	14000.00
0005432529007	30588	Economy	14000.00
0005435214720	30588	Economy	14000.00
0005432529456	30588	Economy	14000.00
0005432529366	30588	Economy	14000.00
0005435214710	30588	Economy	14000.00
0005432529677	30588	Economy	14000.00
0005434067846	30588	Economy	14000.00
0005432529442	30588	Economy	14000.00
0005432529195	30588	Economy	14000.00
0005432529540	30588	Economy	14000.00
0005435214747	30588	Economy	14000.00
0005435214736	30588	Economy	14000.00
0005432529107	30588	Economy	14000.00
0005432529077	30588	Economy	14000.00
0005432528664	30588	Economy	14000.00
0005435214738	30588	Economy	14000.00
0005435214695	30588	Economy	14000.00
0005432529482	30588	Economy	14000.00
0005435214715	30588	Economy	14000.00
0005434068142	30588	Economy	14000.00
0005435214737	30588	Economy	14000.00
0005432529242	30588	Economy	14000.00
0005432528696	30588	Economy	14000.00
0005432528626	30588	Economy	14000.00
0005432529127	30588	Economy	14000.00
0005432528988	30588	Economy	14000.00
0005435214706	30588	Economy	14000.00
0005434067972	30588	Economy	14000.00
0005432528984	30588	Economy	14000.00
0005434068145	30588	Economy	14000.00
0005434068280	30588	Economy	14000.00
0005432529438	30588	Economy	14000.00
0005432528430	30588	Economy	14000.00
0005434068058	30588	Economy	14000.00
0005432529378	30588	Economy	14000.00
0005435214703	30588	Economy	14000.00
0005432528930	30588	Economy	14000.00
0005432159938	30588	Economy	14000.00
0005432528932	30588	Economy	14000.00
0005434067991	30588	Economy	14000.00
0005434068059	30588	Economy	14000.00
0005434068111	30588	Economy	14000.00
0005435214733	30588	Economy	14000.00
0005435214716	30588	Economy	14000.00
0005432528871	30588	Economy	14000.00
0005433656731	30588	Economy	14000.00
0005432529259	30588	Economy	14000.00
0005432529142	30588	Economy	14000.00
0005434068027	30588	Economy	14000.00
0005432529095	30588	Economy	14000.00
0005432529041	30588	Economy	14000.00
0005435214723	30588	Economy	14000.00
0005434068037	30588	Economy	14000.00
0005435214745	30588	Economy	14000.00
0005433656729	30588	Economy	14000.00
0005432528983	30588	Economy	14000.00
0005432528600	30588	Economy	14000.00
0005432529509	30588	Economy	14000.00
0005432529063	30588	Economy	14000.00
0005432528627	30588	Economy	14000.00
0005434068313	30588	Economy	14000.00
0005432528704	30588	Economy	14000.00
0005434067988	30588	Economy	14000.00
0005435214693	30588	Economy	14000.00
0005432528997	30588	Economy	14000.00
0005435214691	30588	Economy	14000.00
0005432528953	30588	Economy	14000.00
0005432528771	30588	Economy	14000.00
0005435214727	30588	Economy	14000.00
0005434068207	30588	Economy	14000.00
0005432528784	30588	Economy	14000.00
0005435214707	30588	Economy	14000.00
0005432529763	30588	Economy	14000.00
0005434068206	30588	Economy	14000.00
0005434068017	30588	Economy	14000.00
0005432529443	30588	Economy	14000.00
0005432529194	30588	Economy	14000.00
0005432529108	30588	Economy	14000.00
0005432529193	30588	Economy	14000.00
0005432529166	30588	Economy	14000.00
0005434067990	30588	Economy	14000.00
0005435214744	30588	Economy	14000.00
0005435214708	30588	Economy	14000.00
0005432211630	30588	Economy	14000.00
0005435214751	30588	Economy	14000.00
0005434068224	30588	Economy	14000.00
0005432529486	30588	Economy	14000.00
0005434067738	30588	Economy	14000.00
0005432529057	30588	Economy	14000.00
0005434068057	30588	Economy	14000.00
0005432529282	30588	Economy	14000.00
0005432533311	30588	Economy	14000.00
0005432528736	30588	Economy	14000.00
0005432528877	30588	Economy	14000.00
0005432529089	30588	Economy	14000.00
0005435631021	30588	Economy	14000.00
0005434067978	30588	Economy	15400.00
0005432529339	30588	Economy	14000.00
0005434068157	30588	Economy	15400.00
0005435214686	30588	Economy	15400.00
0005432529369	30588	Economy	15400.00
0005435725689	30588	Economy	15400.00
0005432529042	30588	Economy	14000.00
0005432529112	30588	Economy	15400.00
0005432529137	30588	Economy	14000.00
0005434068056	30588	Economy	14000.00
0005434067928	30588	Economy	14000.00
0005435214749	30588	Economy	14000.00
0005432528783	30588	Economy	14000.00
0005435214719	30588	Economy	14000.00
0005432533313	30588	Economy	14000.00
0005435214756	30588	Economy	14000.00
0005435214689	30588	Economy	14000.00
0005435214700	30588	Economy	14000.00
0005432529571	30588	Economy	14000.00
0005432529863	30588	Economy	14000.00
0005432529180	30588	Economy	14000.00
0005432529054	30588	Economy	14000.00
0005434068141	30588	Economy	14000.00
0005432529171	30588	Economy	14000.00
0005434068329	30588	Economy	14000.00
0005432529483	30588	Economy	14000.00
0005434068033	30588	Economy	14000.00
0005432528772	30588	Economy	14000.00
0005434067941	30588	Economy	14000.00
0005434068016	30588	Economy	14000.00
0005432529231	30588	Economy	14000.00
0005432528352	30588	Economy	14000.00
0005432529356	30588	Economy	14000.00
0005435214722	30588	Economy	14000.00
0005435725686	30588	Economy	14000.00
0005432529105	30588	Economy	14000.00
0005432529340	30588	Economy	14000.00
0005434068205	30588	Economy	14000.00
0005434067911	30588	Economy	14000.00
0005435214728	30588	Economy	14000.00
0005432529375	30588	Economy	14000.00
0005432529090	30588	Economy	14000.00
0005434068032	30588	Economy	14000.00
0005432528994	30588	Economy	14000.00
0005435214698	30588	Economy	14000.00
0005435214718	30588	Economy	14000.00
0005435214709	30588	Economy	14000.00
0005432533316	30588	Economy	14000.00
0005432528705	30588	Economy	14000.00
0005432529220	30588	Economy	14000.00
0005432211627	30588	Economy	14000.00
0005433656728	30588	Economy	14000.00
0005432529626	30588	Economy	14000.00
0005434068326	30588	Economy	14000.00
0005432529444	30588	Economy	14000.00
0005432528748	30588	Economy	14000.00
0005434068190	30588	Economy	14000.00
0005434068004	30588	Economy	14000.00
0005434068082	30588	Economy	14000.00
0005432528989	30588	Economy	14000.00
0005435214702	30588	Economy	14000.00
0005432529394	30588	Economy	14000.00
0005432528878	30588	Economy	14000.00
0005435631022	30588	Economy	14000.00
0005432528909	30588	Economy	14000.00
0005432529141	30588	Economy	14000.00
0005432159939	30588	Economy	14000.00
0005434068146	30588	Economy	14000.00
0005432528785	30588	Economy	14000.00
0005432159937	30588	Economy	14000.00
0005432211629	30588	Economy	14000.00
0005432529100	30588	Economy	14000.00
0005435214746	30588	Economy	14000.00
0005434067867	30588	Economy	14000.00
0005432211633	30588	Economy	14000.00
0005432529164	30588	Economy	14000.00
0005434068196	30588	Economy	14000.00
0005434067993	30588	Economy	14000.00
0005432529338	30588	Economy	14000.00
0005435214699	30588	Economy	14000.00
0005435214726	30588	Economy	14000.00
0005432529033	30588	Economy	14000.00
0005435214724	30588	Economy	14000.00
0005435214714	30588	Economy	14000.00
0005434068277	30588	Economy	14000.00
0005435214721	30588	Economy	14000.00
0005432528310	30588	Economy	14000.00
0005432529218	30588	Economy	14000.00
0005434068357	30588	Economy	14000.00
0005432529620	30588	Economy	14000.00
0005432529019	30588	Economy	14000.00
0005435214687	30588	Economy	14000.00
0005435214755	30588	Economy	14000.00
0005434068414	30588	Economy	14000.00
0005434068055	30588	Economy	14000.00
0005432528969	30588	Economy	14000.00
0005435653443	24842	Business	9800.00
0005433368549	24842	Business	9800.00
0005433368531	24842	Business	9800.00
0005433368558	24842	Business	9800.00
0005435653462	24842	Business	9800.00
0005433368536	24842	Business	9800.00
0005435653367	24842	Business	9800.00
0005435653432	24842	Business	9800.00
0005433368538	24842	Business	9800.00
0005433368553	24842	Business	9800.00
0005435653416	24842	Business	9800.00
0005435653549	24842	Economy	3300.00
0005433368543	24842	Economy	3300.00
0005435653340	24842	Economy	3300.00
0005435653251	24842	Economy	3300.00
0005435653455	24842	Economy	3300.00
0005433368537	24842	Economy	3300.00
0005433368534	24842	Economy	3300.00
0005435653472	24842	Economy	3600.00
0005433368550	24842	Economy	3600.00
0005435653487	24842	Economy	3600.00
0005433368561	24842	Economy	3600.00
0005435653456	24842	Economy	3300.00
0005435653485	24842	Economy	3300.00
0005433368525	24842	Economy	3300.00
0005433368535	24842	Economy	3300.00
0005433368527	24842	Economy	3300.00
0005435653444	24842	Economy	3300.00
0005435653331	24842	Economy	3300.00
0005433368545	24842	Economy	3300.00
0005435653454	24842	Economy	3300.00
0005433368559	24842	Economy	3300.00
0005433368544	24842	Economy	3300.00
0005435653523	24842	Economy	3300.00
0005435653314	24842	Economy	3300.00
0005435653330	24842	Economy	3300.00
0005435653524	24842	Economy	3300.00
0005435653431	24842	Economy	3300.00
0005435653288	24842	Economy	3300.00
0005433368548	24842	Economy	3300.00
0005435653349	24842	Economy	3300.00
0005433368557	24842	Economy	3300.00
0005433368528	24842	Economy	3300.00
0005433368547	24842	Economy	3300.00
0005435653382	24842	Economy	3300.00
0005435653458	24842	Economy	3300.00
0005435653457	24842	Economy	3300.00
0005433368555	24842	Economy	3300.00
0005435653449	24842	Economy	3300.00
0005435653521	24842	Economy	3300.00
0005435653415	24842	Economy	3300.00
0005435653468	24842	Economy	3300.00
0005433368529	24842	Economy	3300.00
0005433368556	24842	Economy	3300.00
0005435653486	24842	Economy	3300.00
0005433368542	24842	Economy	3300.00
0005433368530	24842	Economy	3300.00
0005435653417	24842	Economy	3300.00
0005435653588	24842	Economy	3300.00
0005435653522	24842	Economy	3300.00
0005433368552	24842	Economy	3300.00
0005435653473	24842	Economy	3300.00
0005435653445	24842	Economy	3300.00
0005433368540	24842	Economy	3300.00
0005433368539	24842	Economy	3300.00
0005435653377	24842	Economy	3300.00
0005433368546	24842	Economy	3300.00
0005435653262	24842	Economy	3300.00
0005435653380	24842	Economy	3300.00
0005433368533	24842	Economy	3300.00
0005435653225	24842	Economy	3300.00
0005435653381	24842	Economy	3300.00
0005433368524	24842	Economy	3300.00
0005433368551	24842	Economy	3300.00
0005433368560	24842	Economy	3300.00
0005433368554	24842	Economy	3300.00
0005433368532	24842	Economy	3300.00
0005433368526	24842	Economy	3300.00
0005433368541	24842	Economy	3300.00
0005435949830	6606	Economy	18700.00
0005435949828	6606	Economy	18700.00
0005435949832	6606	Economy	18700.00
0005435949825	6606	Economy	18700.00
0005435949831	6606	Economy	18700.00
0005435949829	6606	Economy	18700.00
0005435949826	6606	Economy	18700.00
0005435949824	6606	Economy	18700.00
0005435949827	6606	Economy	18700.00
0005434980304	2021	Economy	10500.00
0005434980299	2021	Economy	10500.00
0005434980326	2021	Economy	9500.00
0005434980315	2021	Economy	9500.00
0005434980303	2021	Economy	9500.00
0005434980322	2021	Economy	9500.00
0005435801750	2021	Economy	9500.00
0005435801749	2021	Economy	9500.00
0005434980313	2021	Economy	9500.00
0005434980327	2021	Economy	9500.00
0005434980325	2021	Economy	9500.00
0005434980302	2021	Economy	9500.00
0005434980314	2021	Economy	9500.00
0005434980328	2021	Economy	9500.00
0005434980320	2021	Economy	9500.00
0005434980323	2021	Economy	9500.00
0005434980312	2021	Economy	9500.00
0005434980298	2021	Economy	9500.00
0005434980308	2021	Economy	9500.00
0005434980307	2021	Economy	9500.00
0005434980301	2021	Economy	9500.00
0005434980309	2021	Economy	9500.00
0005434980319	2021	Economy	9500.00
0005434980310	2021	Economy	9500.00
0005434980317	2021	Economy	9500.00
0005434980300	2021	Economy	9500.00
0005434980324	2021	Economy	9500.00
0005434980321	2021	Economy	9500.00
0005434980305	2021	Economy	9500.00
0005434980311	2021	Economy	9500.00
0005434980318	2021	Economy	9500.00
0005434980306	2021	Economy	9500.00
0005434980316	2021	Economy	9500.00
0005434980008	23580	Economy	10500.00
0005434980094	23580	Economy	10500.00
0005435801712	23580	Economy	9500.00
0005434979834	23580	Economy	9500.00
0005434979964	23580	Economy	9500.00
0005434980031	23580	Economy	9500.00
0005434980066	23580	Economy	9500.00
0005434980012	23580	Economy	9500.00
0005434979977	23580	Economy	9500.00
0005434979811	23580	Economy	9500.00
0005434979812	23580	Economy	9500.00
0005434980014	23580	Economy	9500.00
0005434979847	23580	Economy	9500.00
0005434979876	23580	Economy	9500.00
0005434980026	23580	Economy	9500.00
0005434979965	23580	Economy	9500.00
0005434980013	23580	Economy	9500.00
0005434979978	23580	Economy	9500.00
0005434980027	23580	Economy	9500.00
0005434980141	23580	Economy	9500.00
0005434980142	23580	Economy	9500.00
0005434980025	23580	Economy	9500.00
0005434980062	23580	Economy	9500.00
0005435801713	23580	Economy	9500.00
0005434980064	23580	Economy	9500.00
0005434980065	23580	Economy	9500.00
0005434980000	23580	Economy	9500.00
0005434979996	23580	Economy	9500.00
0005434979986	23580	Economy	9500.00
0005434980006	23580	Economy	9500.00
0005434979868	23580	Economy	9500.00
0005434979975	23580	Economy	9500.00
0005434980095	23580	Economy	9500.00
0005435801729	23580	Economy	9500.00
0005434952598	2665	Economy	5300.00
0005434952595	2665	Economy	5300.00
0005434952596	2665	Economy	5300.00
0005434952597	2665	Economy	5300.00
0005433256436	2608	Economy	5300.00
0005434952557	28199	Economy	5300.00
0005434952567	28199	Economy	5300.00
0005433256461	28199	Economy	5300.00
0005433256462	28199	Economy	5300.00
0005434952566	28199	Economy	5300.00
0005433256460	28199	Economy	5300.00
0005433111544	19769	Economy	8700.00
0005433112402	19769	Economy	8700.00
0005433112403	19769	Economy	8700.00
0005433111546	19769	Economy	8700.00
0005433111545	19769	Economy	8700.00
0005434139055	11955	Business	9700.00
0005434138733	11955	Business	9700.00
0005434138839	11955	Business	9700.00
0005434138440	11955	Business	9700.00
0005434139124	11955	Business	9700.00
0005434139021	11955	Business	9700.00
0005434138640	11955	Business	9700.00
0005434139034	11955	Business	9700.00
0005434139291	11955	Business	9700.00
0005434138921	11955	Business	9700.00
0005434138748	11955	Economy	3200.00
0005434138828	11955	Economy	3200.00
0005434138829	11955	Economy	3200.00
0005435283568	11955	Economy	3200.00
0005434138703	11955	Economy	3200.00
0005434138889	11955	Economy	3200.00
0005434139012	11955	Economy	3200.00
0005434138747	11955	Economy	3200.00
0005434138957	11955	Economy	3200.00
0005434139196	11955	Economy	3200.00
0005434138729	11955	Economy	3500.00
0005434139005	11955	Economy	3500.00
0005434139161	11955	Economy	3500.00
0005434139004	11955	Economy	3200.00
0005434138491	11955	Economy	3200.00
0005434138903	11955	Economy	3200.00
0005434138871	11955	Economy	3200.00
0005434138837	11955	Economy	3200.00
0005434139117	11955	Economy	3200.00
0005434138853	11955	Economy	3200.00
0005434139020	11955	Economy	3200.00
0005434138725	11955	Economy	3200.00
0005434138665	11955	Economy	3200.00
0005434138743	11955	Economy	3200.00
0005434138721	11955	Economy	3200.00
0005434138919	11955	Economy	3200.00
0005434138830	11955	Economy	3200.00
0005434138742	11955	Economy	3200.00
0005434139207	11955	Economy	3200.00
0005434138651	11955	Economy	3200.00
0005434138704	11955	Economy	3200.00
0005434139054	11955	Economy	3200.00
0005434138639	11955	Economy	3200.00
0005434138852	11955	Economy	3200.00
0005434138741	11955	Economy	3200.00
0005434138730	11955	Economy	3200.00
0005434139009	11955	Economy	3200.00
0005434138778	11955	Economy	3200.00
0005434138974	11955	Economy	3200.00
0005434139197	11955	Economy	3200.00
0005434138896	11955	Economy	3200.00
0005434138890	11955	Economy	3200.00
0005434138898	11955	Economy	3200.00
0005434138831	11955	Economy	3200.00
0005434139174	11955	Economy	3200.00
0005434139206	11955	Economy	3200.00
0005434139041	11955	Economy	3200.00
0005434139184	11955	Economy	3200.00
0005434138764	11955	Economy	3200.00
0005434138650	11955	Economy	3200.00
0005434138847	11955	Economy	3200.00
0005434138838	11955	Economy	3200.00
0005434138690	11955	Economy	3200.00
0005434138848	11955	Economy	3200.00
0005434138938	11955	Economy	3200.00
0005434138656	11955	Economy	3200.00
0005434139118	11955	Economy	3200.00
0005434138604	11955	Economy	3200.00
0005434138757	11955	Economy	3200.00
0005434138643	11955	Economy	3200.00
0005434138763	11955	Economy	3200.00
0005434139094	11955	Economy	3200.00
0005434139290	11955	Economy	3200.00
0005434139040	11955	Economy	3200.00
0005434138779	11955	Economy	3200.00
0005434138950	11955	Economy	3200.00
0005434138603	11955	Economy	3200.00
0005434138688	11955	Economy	3200.00
0005434138863	11955	Economy	3200.00
0005434138868	11955	Economy	3200.00
0005434138705	11955	Economy	3200.00
0005434138689	11955	Economy	3200.00
0005434138998	11955	Economy	3200.00
0005434138637	11955	Economy	3200.00
0005434139506	28731	Business	9700.00
0005434139524	28731	Business	9700.00
0005434139523	28731	Business	9700.00
0005434139515	28731	Business	9700.00
0005434139491	28731	Business	9700.00
0005434139485	28731	Business	9700.00
0005434139502	28731	Business	9700.00
0005434139465	28731	Business	9700.00
0005434139530	28731	Business	9700.00
0005434139473	28731	Economy	3200.00
0005434139545	28731	Economy	3200.00
0005434139516	28731	Economy	3200.00
0005434139541	28731	Economy	3200.00
0005434139466	28731	Economy	3200.00
0005434139531	28731	Economy	3200.00
0005434139474	28731	Economy	3200.00
0005434139498	28731	Economy	3200.00
0005434139521	28731	Economy	3200.00
0005434139526	28731	Economy	3500.00
0005434139479	28731	Economy	3500.00
0005434139539	28731	Economy	3200.00
0005434139504	28731	Economy	3200.00
0005434139469	28731	Economy	3200.00
0005434139475	28731	Economy	3200.00
0005434139527	28731	Economy	3200.00
0005434139492	28731	Economy	3200.00
0005434139472	28731	Economy	3200.00
0005434139511	28731	Economy	3200.00
0005434139495	28731	Economy	3200.00
0005434139534	28731	Economy	3200.00
0005434139470	28731	Economy	3200.00
0005434139476	28731	Economy	3200.00
0005434139477	28731	Economy	3200.00
0005434139507	28731	Economy	3200.00
0005434139505	28731	Economy	3200.00
0005434139501	28731	Economy	3200.00
0005434139508	28731	Economy	3200.00
0005434139500	28731	Economy	3200.00
0005434139480	28731	Economy	3200.00
0005434139494	28731	Economy	3200.00
0005434139487	28731	Economy	3200.00
0005434139497	28731	Economy	3200.00
0005434139484	28731	Economy	3200.00
0005434139481	28731	Economy	3200.00
0005434139467	28731	Economy	3200.00
0005434139490	28731	Economy	3200.00
0005434139544	28731	Economy	3200.00
0005434139514	28731	Economy	3200.00
0005434139538	28731	Economy	3200.00
0005434139522	28731	Economy	3200.00
0005434139535	28731	Economy	3200.00
0005434139482	28731	Economy	3200.00
0005434139464	28731	Economy	3200.00
0005434139496	28731	Economy	3200.00
0005434139528	28731	Economy	3200.00
0005434139533	28731	Economy	3200.00
0005434139542	28731	Economy	3200.00
0005434139499	28731	Economy	3200.00
0005434139489	28731	Economy	3200.00
0005434139488	28731	Economy	3200.00
0005434139478	28731	Economy	3200.00
0005434139513	28731	Economy	3200.00
0005434139543	28731	Economy	3200.00
0005434139540	28731	Economy	3200.00
0005434139525	28731	Economy	3200.00
0005434139517	28731	Economy	3200.00
0005434139510	28731	Economy	3200.00
0005434139493	28731	Economy	3200.00
0005434139532	28731	Economy	3200.00
0005434139471	28731	Economy	3200.00
0005434139468	28731	Economy	3200.00
0005434139520	28731	Economy	3200.00
0005434139503	28731	Economy	3200.00
0005434139463	28731	Economy	3200.00
0005434139512	28731	Economy	3200.00
0005434139519	28731	Economy	3200.00
0005434139509	28731	Economy	3200.00
0005434139537	28731	Economy	3200.00
0005434139536	28731	Economy	3200.00
0005434139518	28731	Economy	3200.00
0005434139486	28731	Economy	3200.00
0005434139529	28731	Economy	3200.00
0005434139483	28731	Economy	3200.00
0005434466542	6567	Economy	20900.00
0005435312826	6567	Economy	20900.00
0005434466546	6567	Economy	20900.00
0005434466547	6567	Economy	20900.00
0005434466540	6567	Economy	20900.00
0005434466541	6567	Economy	20900.00
0005434466545	6567	Economy	20900.00
0005435312817	6567	Economy	20900.00
0005435312829	6567	Economy	20900.00
0005435312820	6567	Economy	20900.00
0005435312825	6567	Economy	20900.00
0005434466544	6567	Economy	20900.00
0005434466548	6567	Economy	20900.00
0005434466543	6567	Economy	20900.00
0005435312822	6567	Economy	20900.00
0005433539024	6794	Economy	9900.00
0005433539022	6794	Economy	9900.00
0005433539019	6794	Economy	9900.00
0005433539020	6794	Economy	9900.00
0005433539016	6794	Economy	9900.00
0005433539018	6794	Economy	9900.00
0005435259783	6794	Economy	9900.00
0005435259799	6794	Economy	9900.00
0005433534536	6794	Economy	9900.00
0005433539017	6794	Economy	9900.00
0005433539025	6794	Economy	9900.00
0005435259784	6794	Economy	9900.00
0005435259797	6794	Economy	9900.00
0005435259796	6794	Economy	9900.00
0005433539023	6794	Economy	9900.00
0005433539021	6794	Economy	9900.00
0005435259834	25049	Economy	10900.00
0005433538942	25049	Economy	10900.00
0005433538947	25049	Economy	9900.00
0005433534526	25049	Economy	9900.00
0005433538941	25049	Economy	9900.00
0005435259835	25049	Economy	9900.00
0005433538972	25049	Economy	9900.00
0005435259833	25049	Economy	9900.00
0005435259832	25049	Economy	9900.00
0005433534505	25049	Economy	9900.00
0005433538968	25049	Economy	9900.00
0005433512095	846	Economy	14600.00
0005433512096	846	Economy	14600.00
0005433512098	846	Economy	14600.00
0005433512099	846	Economy	14600.00
0005432922568	846	Economy	14600.00
0005432922556	846	Economy	14600.00
0005433512102	846	Economy	14600.00
0005433512100	846	Economy	14600.00
0005432922581	846	Economy	14600.00
0005432922557	846	Economy	14600.00
0005433512101	846	Economy	14600.00
0005432922558	846	Economy	14600.00
0005433512097	846	Economy	14600.00
0005432922595	16178	Economy	16100.00
0005433512041	16178	Economy	16100.00
0005433512019	16178	Economy	16100.00
0005432922596	16178	Economy	14600.00
0005433512036	16178	Economy	14600.00
0005433512022	16178	Economy	14600.00
0005432922598	16178	Economy	14600.00
0005433512024	16178	Economy	14600.00
0005433512026	16178	Economy	14600.00
0005433512078	16178	Economy	14600.00
0005433512079	16178	Economy	14600.00
0005433512025	16178	Economy	14600.00
0005433512054	16178	Economy	14600.00
0005433512053	16178	Economy	14600.00
0005433512020	16178	Economy	14600.00
0005432922599	16178	Economy	14600.00
0005433512052	16178	Economy	14600.00
0005432922597	16178	Economy	14600.00
0005433512013	16178	Economy	14600.00
0005435916184	3701	Economy	7900.00
0005435935070	3701	Economy	7900.00
0005435697845	3701	Economy	7900.00
0005435697823	3701	Economy	7200.00
0005435697843	3701	Economy	7200.00
0005435697824	3701	Economy	7200.00
0005435697833	3701	Economy	7200.00
0005435697832	3701	Economy	7200.00
0005435697836	3701	Economy	7200.00
0005435697844	3701	Economy	7200.00
0005435697842	3701	Economy	7200.00
0005435697825	3701	Economy	7200.00
0005434950610	3701	Economy	7200.00
0005435935069	3701	Economy	7200.00
0005435697841	3701	Economy	7200.00
0005435697847	3701	Economy	7200.00
0005435916203	3701	Economy	7200.00
0005435697834	3701	Economy	7200.00
0005434950608	3701	Economy	7200.00
0005435697821	3701	Economy	7200.00
0005434950607	3701	Economy	7200.00
0005435697830	3701	Economy	7200.00
0005435697837	3701	Economy	7200.00
0005435697846	3701	Economy	7200.00
0005434950606	3701	Economy	7200.00
0005435697829	3701	Economy	7200.00
0005435935081	3701	Economy	7200.00
0005435697819	3701	Economy	7200.00
0005435697820	3701	Economy	7200.00
0005434950609	3701	Economy	7200.00
0005435697840	3701	Economy	7200.00
0005435697835	3701	Economy	7200.00
0005435697839	3701	Economy	7200.00
0005435697828	3701	Economy	7200.00
0005435697826	3701	Economy	7200.00
0005435935082	3701	Economy	7200.00
0005435697838	3701	Economy	7200.00
0005435697827	3701	Economy	7200.00
0005435697822	3701	Economy	7200.00
0005435697831	3701	Economy	7200.00
0005435697571	16287	Economy	7900.00
0005435697538	16287	Economy	7900.00
0005435697518	16287	Economy	7900.00
0005435697470	16287	Economy	7900.00
0005435697552	16287	Economy	7200.00
0005435697517	16287	Economy	7200.00
0005435697607	16287	Economy	7200.00
0005435697499	16287	Economy	7200.00
0005435697619	16287	Economy	7200.00
0005435697589	16287	Economy	7200.00
0005435697618	16287	Economy	7200.00
0005435697620	16287	Economy	7200.00
0005435697519	16287	Economy	7200.00
0005435916216	16287	Economy	7200.00
0005435697640	16287	Economy	7200.00
0005435697623	16287	Economy	7200.00
0005435697644	16287	Economy	7200.00
0005435697533	16287	Economy	7200.00
0005434950581	16287	Economy	7200.00
0005435697551	16287	Economy	7200.00
0005435697645	16287	Economy	7200.00
0005435697582	16287	Economy	7200.00
0005435697556	16287	Economy	7200.00
0005434950580	16287	Economy	7200.00
0005435697555	16287	Economy	7200.00
0005435697558	16287	Economy	7200.00
0005435697622	16287	Economy	7200.00
0005435697561	16287	Economy	7200.00
0005434950560	16287	Economy	7200.00
0005435697608	16287	Economy	7200.00
0005434950577	16287	Economy	7200.00
0005435697609	16287	Economy	7200.00
0005435697726	16287	Economy	7200.00
0005435697614	16287	Economy	7200.00
0005435697621	16287	Economy	7200.00
0005435697520	16287	Economy	7200.00
0005435697613	16287	Economy	7200.00
0005435697653	16287	Economy	7200.00
0005435697641	16287	Economy	7200.00
0005435697505	16287	Economy	7200.00
0005435697570	16287	Economy	7200.00
0005435697506	16287	Economy	7200.00
0005435697579	16287	Economy	7200.00
0005435697554	16287	Economy	7200.00
0005434950582	16287	Economy	7200.00
0005435697507	16287	Economy	7200.00
0005435916215	16287	Economy	7200.00
0005435697590	16287	Economy	7200.00
0005435697727	16287	Economy	7200.00
0005435697455	16287	Economy	7200.00
0005432607641	3943	Economy	21300.00
0005434604960	3943	Economy	21300.00
0005434606886	3943	Economy	21300.00
0005434604959	3943	Economy	19300.00
0005433519536	3943	Economy	19300.00
0005434604961	3943	Economy	19300.00
0005434606884	3943	Economy	19300.00
0005434606883	3943	Economy	19300.00
0005433519538	3943	Economy	19300.00
0005432607638	3943	Economy	19300.00
0005432607640	3943	Economy	19300.00
0005434604958	3943	Economy	19300.00
0005434604957	3943	Economy	19300.00
0005433519539	3943	Economy	19300.00
0005432609802	3943	Economy	19300.00
0005435853630	3943	Economy	19300.00
0005432609801	3943	Economy	19300.00
0005433519541	3943	Economy	19300.00
0005432607639	3943	Economy	19300.00
0005432607642	3943	Economy	19300.00
0005432609805	3943	Economy	19300.00
0005435853632	3943	Economy	19300.00
0005432609804	3943	Economy	19300.00
0005433519537	3943	Economy	19300.00
0005434606885	3943	Economy	19300.00
0005433519540	3943	Economy	19300.00
0005432609803	3943	Economy	19300.00
0005435853643	22036	Economy	21300.00
0005434606858	22036	Economy	19300.00
0005433519494	22036	Economy	19300.00
0005435853644	22036	Economy	19300.00
0005435904904	22036	Economy	19300.00
0005433519503	22036	Economy	19300.00
0005433519499	22036	Economy	19300.00
0005435904905	22036	Economy	19300.00
0005433519504	22036	Economy	19300.00
0005435628784	789	Economy	3700.00
0005433349027	789	Economy	3700.00
0005435628785	789	Economy	3700.00
0005435628786	789	Economy	3700.00
0005435628782	789	Economy	3700.00
0005433349032	789	Economy	3700.00
0005433349028	789	Economy	3700.00
0005433349039	789	Economy	3700.00
0005435628783	789	Economy	3700.00
0005435628787	789	Economy	3700.00
0005433349048	789	Economy	3700.00
0005433349092	15972	Economy	3700.00
0005433349091	15972	Economy	3700.00
0005435628749	15972	Economy	3700.00
0005435628752	15972	Economy	3700.00
0005435628740	15972	Economy	3700.00
0005435628751	15972	Economy	3700.00
0005433349090	15972	Economy	3700.00
0005435628741	15972	Economy	3700.00
0005433349094	15972	Economy	3700.00
0005435628739	15972	Economy	3700.00
0005433349093	15972	Economy	3700.00
0005433349089	15972	Economy	3700.00
0005433158149	17163	Economy	7100.00
0005434445281	17163	Economy	7100.00
0005434446555	17163	Economy	7100.00
0005434445279	17163	Economy	7100.00
0005433159325	17163	Economy	7100.00
0005434446557	17163	Economy	7100.00
0005434445280	17163	Economy	7100.00
0005434445278	17163	Economy	7100.00
0005434446556	17163	Economy	7100.00
0005433159339	17163	Economy	7100.00
0005433159353	17648	Economy	7100.00
0005433159352	17648	Economy	7100.00
0005434445259	17648	Economy	7100.00
0005435383190	7893	Economy	5900.00
0005435133068	7893	Economy	5900.00
0005435383179	7893	Economy	5400.00
0005435133071	7893	Economy	5400.00
0005435133063	7893	Economy	5400.00
0005435133069	7893	Economy	5400.00
0005435133067	7893	Economy	5400.00
0005435383225	7893	Economy	5400.00
0005435383205	7893	Economy	5400.00
0005435383178	7893	Economy	5400.00
0005435383199	7893	Economy	5400.00
0005435133072	7893	Economy	5400.00
0005435133064	7893	Economy	5400.00
0005435133070	7893	Economy	5400.00
0005435383226	7893	Economy	5400.00
0005435133073	7893	Economy	5400.00
0005435133066	7893	Economy	5400.00
0005435383180	7893	Economy	5400.00
0005435133065	7893	Economy	5400.00
0005435133016	33076	Economy	5400.00
0005435132978	33076	Economy	5400.00
0005435132944	33076	Economy	5400.00
0005435132986	33076	Economy	5400.00
0005435132961	33076	Economy	5400.00
0005435133017	33076	Economy	5400.00
0005435133005	33076	Economy	5400.00
0005435383245	33076	Economy	5400.00
0005435132973	33076	Economy	5400.00
0005435133006	33076	Economy	5400.00
0005435383244	33076	Economy	5400.00
0005435383243	33076	Economy	5400.00
0005435132950	33076	Economy	5400.00
0005435132960	33076	Economy	5400.00
0005435383247	33076	Economy	5400.00
0005435132957	33076	Economy	5400.00
0005435133018	33076	Economy	5400.00
0005435383246	33076	Economy	5400.00
0005435132959	33076	Economy	5400.00
0005435132958	33076	Economy	5400.00
0005435132992	33076	Economy	5400.00
0005435811160	4404	Business	133200.00
0005435938905	4404	Economy	44400.00
0005435938914	4404	Economy	44400.00
0005435811163	4404	Economy	44400.00
0005435811165	4404	Economy	44400.00
0005435938907	4404	Economy	44400.00
0005435811161	4404	Economy	44400.00
0005435938904	4404	Economy	44400.00
0005435811167	4404	Economy	44400.00
0005435811158	4404	Economy	44400.00
0005435811166	4404	Economy	44400.00
0005435811162	4404	Economy	44400.00
0005435811164	4404	Economy	44400.00
0005435938906	4404	Economy	44400.00
0005435811168	4404	Economy	44400.00
0005435811159	4404	Economy	44400.00
0005435938934	29438	Business	133200.00
0005435811123	29438	Business	133200.00
0005435811106	29438	Business	133200.00
0005435938935	29438	Business	133200.00
0005435938932	29438	Business	133200.00
0005435811109	29438	Economy	44400.00
0005435938931	29438	Economy	48800.00
0005435811110	29438	Economy	44400.00
0005435811127	29438	Economy	44400.00
0005435811119	29438	Economy	44400.00
0005435811100	29438	Economy	44400.00
0005435811120	29438	Economy	44400.00
0005435811108	29438	Economy	44400.00
0005435811116	29438	Economy	44400.00
0005435938930	29438	Economy	44400.00
0005435811107	29438	Economy	44400.00
0005435938933	29438	Economy	44400.00
0005435811124	29438	Economy	44400.00
0005435811111	29438	Economy	44400.00
0005435390280	7531	Economy	13800.00
0005435160493	7531	Economy	12500.00
0005435390339	7531	Economy	12500.00
0005435160498	7531	Economy	12500.00
0005435160500	7531	Economy	12500.00
0005435390278	7531	Economy	12500.00
0005435160495	7531	Economy	12500.00
0005435390283	7531	Economy	12500.00
0005435160494	7531	Economy	12500.00
0005435160496	7531	Economy	12500.00
0005435390284	7531	Economy	12500.00
0005435390277	7531	Economy	12500.00
0005435390340	7531	Economy	12500.00
0005435390316	7531	Economy	12500.00
0005435390307	7531	Economy	12500.00
0005435160497	7531	Economy	12500.00
0005435160503	7531	Economy	12500.00
0005435160501	7531	Economy	12500.00
0005435160502	7531	Economy	12500.00
0005435160499	7531	Economy	12500.00
0005435160407	29588	Economy	13800.00
0005435390361	29588	Economy	13800.00
0005435160397	29588	Economy	13800.00
0005435160413	29588	Economy	12500.00
0005435160368	29588	Economy	12500.00
0005435390359	29588	Economy	12500.00
0005435160395	29588	Economy	12500.00
0005435160430	29588	Economy	12500.00
0005435160429	29588	Economy	12500.00
0005435390360	29588	Economy	12500.00
0005435160414	29588	Economy	12500.00
0005435390363	29588	Economy	12500.00
0005435160379	29588	Economy	12500.00
0005435390366	29588	Economy	12500.00
0005435160378	29588	Economy	12500.00
0005435160452	29588	Economy	12500.00
0005435390364	29588	Economy	12500.00
0005435390362	29588	Economy	12500.00
0005435160367	29588	Economy	12500.00
0005435160406	29588	Economy	12500.00
0005435390365	29588	Economy	12500.00
0005432394158	18472	Economy	4900.00
0005432394136	18472	Economy	4900.00
0005432398216	18472	Economy	4900.00
0005432394144	18472	Economy	4900.00
0005432398228	18472	Economy	4900.00
0005432394134	18472	Economy	4900.00
0005432398235	18472	Economy	4900.00
0005432394135	18472	Economy	4900.00
0005432398230	18472	Economy	4900.00
0005432398237	18472	Economy	4900.00
0005432398227	18472	Economy	4900.00
0005432398238	18472	Economy	4900.00
0005432398260	27134	Economy	4900.00
0005435178510	27134	Economy	4900.00
0005435178505	27134	Economy	4900.00
0005432398259	27134	Economy	4900.00
0005432400185	27134	Economy	4900.00
0005432398258	27134	Economy	4900.00
0005432400186	27134	Economy	4900.00
0005432400183	27134	Economy	4900.00
0005432400187	27134	Economy	4900.00
0005432400184	27134	Economy	4900.00
0005432866079	2238	Business	87300.00
0005432639353	2238	Business	87300.00
0005432639355	2238	Business	87300.00
0005432866060	2238	Business	87300.00
0005432639345	2238	Business	87300.00
0005432866072	2238	Business	87300.00
0005432866059	2238	Business	87300.00
0005432866080	2238	Business	87300.00
0005432866075	2238	Economy	29100.00
0005432866108	2238	Economy	29100.00
0005432639336	2238	Economy	29100.00
0005432639357	2238	Economy	29100.00
0005432639347	2238	Economy	29100.00
0005432639350	2238	Economy	29100.00
0005432866083	2238	Economy	29100.00
0005432639339	2238	Economy	29100.00
0005432639344	2238	Economy	32000.00
0005432866047	2238	Economy	32000.00
0005432866091	2238	Economy	29100.00
0005432639358	2238	Economy	29100.00
0005432639340	2238	Economy	29100.00
0005432639354	2238	Economy	29100.00
0005432639351	2238	Economy	29100.00
0005432866071	2238	Economy	29100.00
0005432639356	2238	Economy	29100.00
0005432639338	2238	Economy	29100.00
0005432639342	2238	Economy	29100.00
0005432866085	2238	Economy	29100.00
0005432866107	2238	Economy	29100.00
0005432639352	2238	Economy	29100.00
0005432866092	2238	Economy	29100.00
0005432639359	2238	Economy	29100.00
0005432866078	2238	Economy	29100.00
0005432639335	2238	Economy	29100.00
0005432639341	2238	Economy	29100.00
0005432639346	2238	Economy	29100.00
0005432866084	2238	Economy	29100.00
0005432639337	2238	Economy	29100.00
0005432639349	2238	Economy	29100.00
0005432866052	2238	Economy	29100.00
0005432866068	2238	Economy	29100.00
0005432639343	2238	Economy	29100.00
0005432639334	2238	Economy	29100.00
0005432866093	2238	Economy	29100.00
0005432639348	2238	Economy	29100.00
0005432866067	2238	Economy	29100.00
0005432866073	2238	Economy	29100.00
0005433811660	24295	Business	105400.00
0005433811662	24295	Business	105400.00
0005433811665	24295	Business	105400.00
0005433811667	24295	Economy	35100.00
0005433811666	24295	Economy	35100.00
0005433811663	24295	Economy	35100.00
0005433811661	24295	Economy	35100.00
0005433811657	24295	Economy	35100.00
0005433811659	24295	Economy	35100.00
0005433811658	24295	Economy	35100.00
0005433811668	24295	Economy	35100.00
0005433811664	24295	Economy	35100.00
0005434191296	9737	Economy	4400.00
0005434191290	9737	Economy	4400.00
0005434191295	9737	Economy	4400.00
0005434191292	9737	Economy	4400.00
0005434191301	32791	Economy	4400.00
0005434191297	32791	Economy	4400.00
0005434191307	32791	Economy	4400.00
0005434191299	32791	Economy	4400.00
0005434191300	32791	Economy	4400.00
0005434191298	32791	Economy	4400.00
0005434191302	32791	Economy	4400.00
0005434191304	32791	Economy	4400.00
0005434191303	32791	Economy	4400.00
0005434191306	32791	Economy	4400.00
0005434191305	32791	Economy	4400.00
0005432665292	26493	Business	92200.00
0005432661920	26493	Business	92200.00
0005432661935	26493	Business	92200.00
0005432661913	26493	Business	92200.00
0005432658610	26493	Business	92200.00
0005432658597	26493	Business	92200.00
0005432661938	26493	Economy	30700.00
0005432661928	26493	Economy	30700.00
0005432661934	26493	Economy	30700.00
0005432658605	26493	Economy	30700.00
0005432661939	26493	Economy	30700.00
0005432665277	26493	Economy	30700.00
0005432665285	26493	Economy	30700.00
0005432661926	26493	Economy	30700.00
0005432661921	26493	Economy	33800.00
0005432658593	26493	Economy	30700.00
0005432665268	26493	Economy	30700.00
0005432658611	26493	Economy	30700.00
0005432665289	26493	Economy	30700.00
0005432658594	26493	Economy	30700.00
0005432661936	26493	Economy	30700.00
0005432658603	26493	Economy	30700.00
0005432658615	26493	Economy	30700.00
0005432661937	26493	Economy	30700.00
0005432665283	26493	Economy	30700.00
0005432665291	26493	Economy	30700.00
0005432661917	26493	Economy	30700.00
0005432658599	26493	Economy	30700.00
0005432665281	26493	Economy	30700.00
0005432665284	26493	Economy	30700.00
0005432658598	26493	Economy	30700.00
0005432665298	26493	Economy	30700.00
0005432658595	26493	Economy	30700.00
0005432661940	26493	Economy	30700.00
0005432665276	26493	Economy	30700.00
0005432665282	26493	Economy	30700.00
0005432658604	26493	Economy	30700.00
0005432661927	26493	Economy	30700.00
0005432658608	26493	Economy	30700.00
0005432665290	26493	Economy	30700.00
0005432658596	26493	Economy	30700.00
0005432658606	26493	Economy	30700.00
0005432665280	26493	Economy	30700.00
0005432658607	26493	Economy	30700.00
0005432661941	26493	Economy	30700.00
0005432661916	26493	Economy	30700.00
0005432658602	26493	Economy	30700.00
0005432661925	26493	Economy	30700.00
0005434504839	6507	Business	48400.00
0005434504854	6507	Business	48400.00
0005434504832	6507	Business	48400.00
0005434504856	6507	Business	48400.00
0005434504849	6507	Business	48400.00
0005434504831	6507	Business	48400.00
0005434504865	6507	Economy	16100.00
0005434504835	6507	Economy	16100.00
0005434504858	6507	Economy	16100.00
0005435104069	6507	Economy	16100.00
0005434504842	6507	Economy	17800.00
0005434504838	6507	Economy	17800.00
0005434504864	6507	Economy	17800.00
0005434504862	6507	Economy	17800.00
0005435104067	6507	Economy	16100.00
0005434504840	6507	Economy	16100.00
0005434504827	6507	Economy	16100.00
0005434504841	6507	Economy	16100.00
0005434504859	6507	Economy	16100.00
0005435104070	6507	Economy	16100.00
0005434504830	6507	Economy	16100.00
0005434504837	6507	Economy	16100.00
0005434504843	6507	Economy	16100.00
0005435104068	6507	Economy	16100.00
0005434504847	6507	Economy	16100.00
0005434504853	6507	Economy	16100.00
0005434504846	6507	Economy	16100.00
0005434504863	6507	Economy	16100.00
0005434504829	6507	Economy	16100.00
0005434504850	6507	Economy	16100.00
0005434504866	6507	Economy	16100.00
0005434504836	6507	Economy	16100.00
0005434504828	6507	Economy	16100.00
0005434504857	6507	Economy	16100.00
0005434504860	6507	Economy	16100.00
0005434504851	6507	Economy	16100.00
0005434504826	6507	Economy	16100.00
0005434504861	6507	Economy	16100.00
0005434504844	6507	Economy	16100.00
0005435104071	6507	Economy	16100.00
0005434504848	6507	Economy	16100.00
0005434504833	6507	Economy	16100.00
0005434504845	6507	Economy	16100.00
0005434504855	6507	Economy	16100.00
0005434504834	6507	Economy	16100.00
0005434504852	6507	Economy	16100.00
0005434504529	22675	Business	48400.00
0005435103972	22675	Business	48400.00
0005434504407	22675	Business	48400.00
0005435103970	22675	Business	48400.00
0005434504194	22675	Business	48400.00
0005434504206	22675	Economy	16100.00
0005434504282	22675	Economy	16100.00
0005434504283	22675	Economy	16100.00
0005434504601	22675	Economy	17800.00
0005434504405	22675	Economy	16100.00
0005435103976	22675	Economy	16100.00
0005435103943	22675	Economy	16100.00
0005435103973	22675	Economy	16100.00
0005434504377	22675	Economy	16100.00
0005434504591	22675	Economy	16100.00
0005435103971	22675	Economy	16100.00
0005435103977	22675	Economy	16100.00
0005434504500	22675	Economy	16100.00
0005434504270	22675	Economy	16100.00
0005434504499	22675	Economy	16100.00
0005434504433	22675	Economy	16100.00
0005435103944	22675	Economy	16100.00
0005435103947	22675	Economy	16100.00
0005434504444	22675	Economy	16100.00
0005434504487	22675	Economy	16100.00
0005435103942	22675	Economy	16100.00
0005434504406	22675	Economy	16100.00
0005434504473	22675	Economy	16100.00
0005434504488	22675	Economy	16100.00
0005434504412	22675	Economy	16100.00
0005434504352	22675	Economy	16100.00
0005434504516	22675	Economy	16100.00
0005434504485	22675	Economy	16100.00
0005434504423	22675	Economy	16100.00
0005434504367	22675	Economy	16100.00
0005434504368	22675	Economy	16100.00
0005434504515	22675	Economy	16100.00
0005434504556	22675	Economy	16100.00
0005434504343	22675	Economy	16100.00
0005434504443	22675	Economy	16100.00
0005435103946	22675	Economy	16100.00
0005434504346	22675	Economy	16100.00
0005434504602	22675	Economy	16100.00
0005434504290	22675	Economy	16100.00
0005434504395	22675	Economy	16100.00
0005434504528	22675	Economy	16100.00
0005434504279	22675	Economy	16100.00
0005435103974	22675	Economy	16100.00
0005434504342	22675	Economy	16100.00
0005434504474	22675	Economy	16100.00
0005435103975	22675	Economy	16100.00
0005434504599	22675	Economy	16100.00
0005435103941	22675	Economy	16100.00
0005434504600	22675	Economy	16100.00
0005435653831	1639	Business	50000.00
0005433368329	1639	Business	50000.00
0005433368169	1639	Business	50000.00
0005433368180	1639	Business	50000.00
0005435653822	1639	Business	50000.00
0005433368163	1639	Business	50000.00
0005433368267	1639	Business	50000.00
0005435653853	1639	Business	50000.00
0005435653813	1639	Business	50000.00
0005433368164	1639	Business	50000.00
0005435653834	1639	Business	50000.00
0005435653819	1639	Economy	16700.00
0005433368008	1639	Economy	16700.00
0005435653820	1639	Economy	16700.00
0005435653849	1639	Economy	16700.00
0005435653841	1639	Economy	16700.00
0005433368170	1639	Economy	16700.00
0005435653818	1639	Economy	16700.00
0005433368247	1639	Economy	16700.00
0005435653827	1639	Economy	16700.00
0005433368327	1639	Economy	18300.00
0005435653839	1639	Economy	18300.00
0005433368120	1639	Economy	18300.00
0005435653854	1639	Economy	16700.00
0005435653852	1639	Economy	16700.00
0005433368167	1639	Economy	16700.00
0005433368215	1639	Economy	16700.00
0005433368168	1639	Economy	16700.00
0005435653817	1639	Economy	16700.00
0005435653823	1639	Economy	16700.00
0005433368314	1639	Economy	16700.00
0005433368395	1639	Economy	16700.00
0005435653816	1639	Economy	16700.00
0005433368394	1639	Economy	16700.00
0005435653821	1639	Economy	16700.00
0005433368144	1639	Economy	16700.00
0005435653840	1639	Economy	16700.00
0005435653835	1639	Economy	16700.00
0005433368295	1639	Economy	16700.00
0005433368214	1639	Economy	16700.00
0005435653843	1639	Economy	16700.00
0005433368290	1639	Economy	16700.00
0005435653814	1639	Economy	16700.00
0005433368294	1639	Economy	16700.00
0005433368319	1639	Economy	16700.00
0005433368026	1639	Economy	16700.00
0005435653833	1639	Economy	16700.00
0005433368276	1639	Economy	16700.00
0005435653811	1639	Economy	16700.00
0005433368266	1639	Economy	16700.00
0005435653825	1639	Economy	16700.00
0005433368254	1639	Economy	16700.00
0005433368291	1639	Economy	16700.00
0005433368212	1639	Economy	16700.00
0005435653836	1639	Economy	16700.00
0005435653845	1639	Economy	16700.00
0005435653830	1639	Economy	16700.00
0005435653838	1639	Economy	16700.00
0005435653812	1639	Economy	16700.00
0005435653829	1639	Economy	16700.00
0005433368275	1639	Economy	16700.00
0005433368179	1639	Economy	16700.00
0005433368352	1639	Economy	16700.00
0005433368159	1639	Economy	16700.00
0005435653837	1639	Economy	16700.00
0005435653842	1639	Economy	16700.00
0005433368337	1639	Economy	16700.00
0005435653850	1639	Economy	16700.00
0005433368132	1639	Economy	16700.00
0005435653846	1639	Economy	16700.00
0005435653855	1639	Economy	16700.00
0005433368308	1639	Economy	16700.00
0005433368328	1639	Economy	16700.00
0005435653848	1639	Economy	16700.00
0005435653815	1639	Economy	16700.00
0005435653824	1639	Economy	16700.00
0005435653844	1639	Economy	16700.00
0005435653851	1639	Economy	16700.00
0005433368204	1639	Economy	16700.00
0005435653847	1639	Economy	16700.00
0005433368323	1639	Economy	16700.00
0005435653826	1639	Economy	16700.00
0005435653828	1639	Economy	16700.00
0005433368408	1639	Economy	16700.00
0005435653832	1639	Economy	16700.00
0005433368181	1639	Economy	16700.00
0005433368529	21690	Business	50000.00
0005433368542	21690	Business	50000.00
0005433368536	21690	Business	50000.00
0005433368534	21690	Business	50000.00
0005433368544	21690	Business	50000.00
0005435653468	21690	Business	50000.00
0005433368559	21690	Business	50000.00
0005435653314	21690	Business	50000.00
0005433368556	21690	Business	50000.00
0005433368554	21690	Business	50000.00
0005433368558	21690	Economy	16700.00
0005433368551	21690	Economy	16700.00
0005435653443	21690	Economy	16700.00
0005435653486	21690	Economy	16700.00
0005435653523	21690	Economy	16700.00
0005435653454	21690	Economy	16700.00
0005435653225	21690	Economy	16700.00
0005433368527	21690	Economy	16700.00
0005435653416	21690	Economy	18300.00
0005433368537	21690	Economy	18300.00
0005433368553	21690	Economy	18300.00
0005435653472	21690	Economy	18300.00
0005433368550	21690	Economy	18300.00
0005435653380	21690	Economy	16700.00
0005435653367	21690	Economy	16700.00
0005433368555	21690	Economy	16700.00
0005433368547	21690	Economy	16700.00
0005435653549	21690	Economy	16700.00
0005433368530	21690	Economy	16700.00
0005435653487	21690	Economy	16700.00
0005433368526	21690	Economy	16700.00
0005433368531	21690	Economy	16700.00
0005433368546	21690	Economy	16700.00
0005433368541	21690	Economy	16700.00
0005433368525	21690	Economy	16700.00
0005435653458	21690	Economy	16700.00
0005433368545	21690	Economy	16700.00
0005433368528	21690	Economy	16700.00
0005435653417	21690	Economy	16700.00
0005435653588	21690	Economy	16700.00
0005433368557	21690	Economy	16700.00
0005435653445	21690	Economy	16700.00
0005435653381	21690	Economy	16700.00
0005435653462	21690	Economy	16700.00
0005433368540	21690	Economy	16700.00
0005433368561	21690	Economy	16700.00
0005435653449	21690	Economy	16700.00
0005433368560	21690	Economy	16700.00
0005433368539	21690	Economy	16700.00
0005435653331	21690	Economy	16700.00
0005433368524	21690	Economy	16700.00
0005435653288	21690	Economy	16700.00
0005435653432	21690	Economy	16700.00
0005435653456	21690	Economy	16700.00
0005435653457	21690	Economy	16700.00
0005435653524	21690	Economy	16700.00
0005435653382	21690	Economy	16700.00
0005435653330	21690	Economy	16700.00
0005435653521	21690	Economy	16700.00
0005433368532	21690	Economy	16700.00
0005435653377	21690	Economy	16700.00
0005433368535	21690	Economy	16700.00
0005433368549	21690	Economy	16700.00
0005433368543	21690	Economy	16700.00
0005435653340	21690	Economy	16700.00
0005435653431	21690	Economy	16700.00
0005435653455	21690	Economy	16700.00
0005435653444	21690	Economy	16700.00
0005435653251	21690	Economy	16700.00
0005433368538	21690	Economy	16700.00
0005435653262	21690	Economy	16700.00
0005435653522	21690	Economy	16700.00
0005433368552	21690	Economy	16700.00
0005433368533	21690	Economy	16700.00
0005435653473	21690	Economy	16700.00
0005435653349	21690	Economy	16700.00
0005435653415	21690	Economy	16700.00
0005435653485	21690	Economy	16700.00
0005433368548	21690	Economy	16700.00
0005434466511	23221	Economy	23000.00
0005435312851	23221	Economy	23000.00
0005434466495	23221	Economy	23000.00
0005434466510	23221	Economy	20900.00
0005435312849	23221	Economy	20900.00
0005434466497	23221	Economy	20900.00
0005435312850	23221	Economy	20900.00
0005434466489	23221	Economy	20900.00
0005434466512	23221	Economy	20900.00
0005434466488	23221	Economy	20900.00
0005434466479	23221	Economy	20900.00
0005435312846	23221	Economy	20900.00
0005434466480	23221	Economy	20900.00
0005434466514	23221	Economy	20900.00
0005435312848	23221	Economy	20900.00
0005435312847	23221	Economy	20900.00
0005434466513	23221	Economy	20900.00
0005433986771	4189	Business	21500.00
0005433986766	4189	Business	21500.00
0005433986779	4189	Business	21500.00
0005433986785	4189	Business	21500.00
0005433986760	4189	Business	21500.00
0005433986791	4189	Economy	7200.00
0005433986764	4189	Economy	7200.00
0005433986799	4189	Economy	7900.00
0005433986783	4189	Economy	7900.00
0005433986758	4189	Economy	7900.00
0005433986777	4189	Economy	7200.00
0005433986755	4189	Economy	7200.00
0005435788816	4189	Economy	7200.00
0005433986757	4189	Economy	7200.00
0005433986788	4189	Economy	7200.00
0005433986790	4189	Economy	7200.00
0005433986776	4189	Economy	7200.00
0005433986781	4189	Economy	7200.00
0005433986762	4189	Economy	7200.00
0005433986793	4189	Economy	7200.00
0005433986763	4189	Economy	7200.00
0005435788815	4189	Economy	7200.00
0005433986792	4189	Economy	7200.00
0005433986761	4189	Economy	7200.00
0005433986751	4189	Economy	7200.00
0005435788817	4189	Economy	7200.00
0005433986787	4189	Economy	7200.00
0005433986796	4189	Economy	7200.00
0005433986795	4189	Economy	7200.00
0005433986794	4189	Economy	7200.00
0005433986786	4189	Economy	7200.00
0005433986753	4189	Economy	7200.00
0005433986765	4189	Economy	7200.00
0005433986759	4189	Economy	7200.00
0005433986800	4189	Economy	7200.00
0005433986782	4189	Economy	7200.00
0005433986772	4189	Economy	7200.00
0005433986770	4189	Economy	7200.00
0005433986750	4189	Economy	7200.00
0005433986767	4189	Economy	7200.00
0005433986774	4189	Economy	7200.00
0005433986780	4189	Economy	7200.00
0005433986773	4189	Economy	7200.00
0005433986778	4189	Economy	7200.00
0005433986775	4189	Economy	7200.00
0005433986756	4189	Economy	7200.00
0005433986784	4189	Economy	7200.00
0005433986798	4189	Economy	7200.00
0005433986769	4189	Economy	7200.00
0005433986768	4189	Economy	7200.00
0005433986789	4189	Economy	7200.00
0005433986754	4189	Economy	7200.00
0005433986752	4189	Economy	7200.00
0005433986797	4189	Economy	7200.00
0005433986436	25639	Business	21500.00
0005433986195	25639	Business	21500.00
0005433986582	25639	Business	21500.00
0005433986219	25639	Business	21500.00
0005433986361	25639	Business	21500.00
0005433986329	25639	Business	21500.00
0005433986380	25639	Business	21500.00
0005433986077	25639	Business	21500.00
0005433986417	25639	Business	21500.00
0005433986379	25639	Economy	7200.00
0005433986239	25639	Economy	7200.00
0005433986129	25639	Economy	7200.00
0005433986201	25639	Economy	7200.00
0005433986491	25639	Economy	7200.00
0005435788804	25639	Economy	7200.00
0005433986200	25639	Economy	7900.00
0005433986241	25639	Economy	7900.00
0005433986287	25639	Economy	7900.00
0005433986196	25639	Economy	7200.00
0005433986252	25639	Economy	7200.00
0005433986233	25639	Economy	7200.00
0005433986279	25639	Economy	7200.00
0005433986112	25639	Economy	7200.00
0005433986348	25639	Economy	7200.00
0005433986483	25639	Economy	7200.00
0005433986421	25639	Economy	7200.00
0005433986251	25639	Economy	7200.00
0005433986253	25639	Economy	7200.00
0005433986356	25639	Economy	7200.00
0005433986523	25639	Economy	7200.00
0005433986113	25639	Economy	7200.00
0005433986350	25639	Economy	7200.00
0005433986293	25639	Economy	7200.00
0005433986418	25639	Economy	7200.00
0005433986397	25639	Economy	7200.00
0005433986128	25639	Economy	7200.00
0005433986510	25639	Economy	7200.00
0005433986153	25639	Economy	7200.00
0005433986289	25639	Economy	7200.00
0005433986374	25639	Economy	7200.00
0005435788803	25639	Economy	7200.00
0005433986509	25639	Economy	7200.00
0005433986297	25639	Economy	7200.00
0005433986244	25639	Economy	7200.00
0005433986292	25639	Economy	7200.00
0005433986338	25639	Economy	7200.00
0005433986254	25639	Economy	7200.00
0005433986242	25639	Economy	7200.00
0005433986199	25639	Economy	7200.00
0005433986280	25639	Economy	7200.00
0005433986398	25639	Economy	7200.00
0005433986161	25639	Economy	7200.00
0005433986150	25639	Economy	7200.00
0005433986355	25639	Economy	7200.00
0005433986271	25639	Economy	7200.00
0005433986349	25639	Economy	7200.00
0005433986149	25639	Economy	7200.00
0005433986221	25639	Economy	7200.00
0005433986480	25639	Economy	7200.00
0005433986354	25639	Economy	7200.00
0005433986373	25639	Economy	7200.00
0005435720150	24795	Economy	9400.00
0005435719579	24795	Economy	9400.00
0005435720149	24795	Economy	9400.00
0005435719578	24795	Economy	9400.00
0005435719580	24795	Economy	9400.00
0005434509279	1621	Economy	17000.00
0005433168402	1621	Economy	17000.00
0005433168394	1621	Economy	17000.00
0005433168396	1621	Economy	15500.00
0005434509275	1621	Economy	15500.00
0005434509282	1621	Economy	15500.00
0005434509287	1621	Economy	15500.00
0005433168416	1621	Economy	15500.00
0005434509284	1621	Economy	15500.00
0005434509285	1621	Economy	15500.00
0005434509276	1621	Economy	15500.00
0005434509277	1621	Economy	15500.00
0005434509274	1621	Economy	15500.00
0005434509286	1621	Economy	15500.00
0005434509281	1621	Economy	15500.00
0005434509283	1621	Economy	15500.00
0005434509278	1621	Economy	15500.00
0005434509280	1621	Economy	15500.00
0005434190421	9031	Economy	26000.00
0005434190414	9031	Economy	23600.00
0005434516114	9031	Economy	23600.00
0005434190429	9031	Economy	23600.00
0005434190426	9031	Economy	23600.00
0005434190423	9031	Economy	23600.00
0005434516113	9031	Economy	23600.00
0005434190418	9031	Economy	23600.00
0005434516117	9031	Economy	23600.00
0005434190413	9031	Economy	23600.00
0005434516116	9031	Economy	23600.00
0005434190422	9031	Economy	23600.00
0005434190409	9031	Economy	23600.00
0005434190428	9031	Economy	23600.00
0005434516115	9031	Economy	23600.00
0005432655656	17874	Business	18000.00
0005432660837	17874	Business	18000.00
0005432666412	17874	Business	18000.00
0005432869646	17874	Business	18000.00
0005432655678	17874	Business	18000.00
0005432667473	17874	Business	18000.00
0005432655610	17874	Economy	6000.00
0005432663044	17874	Economy	6000.00
0005432667470	17874	Economy	6000.00
0005432666409	17874	Economy	6000.00
0005432661929	17874	Economy	6600.00
0005432869641	17874	Economy	6600.00
0005432661930	17874	Economy	6600.00
0005432663046	17874	Economy	6600.00
0005432655629	17874	Economy	6000.00
0005432655617	17874	Economy	6000.00
0005432657470	17874	Economy	6000.00
0005432666408	17874	Economy	6000.00
0005434151757	17874	Economy	6000.00
0005432667469	17874	Economy	6000.00
0005432655674	17874	Economy	6000.00
0005432663045	17874	Economy	6000.00
0005432655583	17874	Economy	6000.00
0005432663043	17874	Economy	6000.00
0005432655614	17874	Economy	6000.00
0005432660826	17874	Economy	6000.00
0005432869644	17874	Economy	6000.00
0005432660838	17874	Economy	6000.00
0005432869642	17874	Economy	6000.00
0005432663042	17874	Economy	6000.00
0005432869643	17874	Economy	6000.00
0005432869645	17874	Economy	6000.00
0005432658613	17874	Economy	6000.00
0005434151758	17874	Economy	6000.00
0005432657469	17874	Economy	6000.00
0005432657478	17874	Economy	6000.00
0005432657467	17874	Economy	6000.00
0005432661931	17874	Economy	6000.00
0005432655673	17874	Economy	6000.00
0005432655615	17874	Economy	6000.00
0005432660831	17874	Economy	6000.00
0005432655630	17874	Economy	6000.00
0005432667464	17874	Economy	6000.00
0005432655616	17874	Economy	6000.00
0005432655631	17874	Economy	6000.00
0005432869647	17874	Economy	6000.00
0005432655679	17874	Economy	6000.00
0005432657476	17874	Economy	6000.00
0005432869550	26320	Business	18000.00
0005432667488	26320	Business	18000.00
0005432665308	26320	Business	18000.00
0005432660851	26320	Business	18000.00
0005432655719	26320	Business	18000.00
0005434151725	26320	Business	18000.00
0005432655717	26320	Business	18000.00
0005432658624	26320	Business	18000.00
0005432869554	26320	Economy	6000.00
0005432655723	26320	Economy	6000.00
0005434151732	26320	Economy	6000.00
0005432666423	26320	Economy	6000.00
0005432658625	26320	Economy	6000.00
0005432655725	26320	Economy	6600.00
0005432655728	26320	Economy	6000.00
0005432655726	26320	Economy	6000.00
0005432657499	26320	Economy	6000.00
0005432655727	26320	Economy	6000.00
0005434151729	26320	Economy	6000.00
0005432658627	26320	Economy	6000.00
0005432655720	26320	Economy	6000.00
0005432657498	26320	Economy	6000.00
0005432655721	26320	Economy	6000.00
0005432666422	26320	Economy	6000.00
0005434151728	26320	Economy	6000.00
0005432655729	26320	Economy	6000.00
0005432665310	26320	Economy	6000.00
0005432660852	26320	Economy	6000.00
0005432655718	26320	Economy	6000.00
0005432869551	26320	Economy	6000.00
0005432658626	26320	Economy	6000.00
0005432665309	26320	Economy	6000.00
0005432655722	26320	Economy	6000.00
0005432655724	26320	Economy	6000.00
0005432869555	26320	Economy	6000.00
0005432667487	26320	Economy	6000.00
0005434151741	26320	Economy	6000.00
0005432657500	26320	Economy	6000.00
0005432866131	25054	Business	87300.00
0005432866142	25054	Business	87300.00
0005432866136	25054	Business	87300.00
0005432639234	25054	Business	87300.00
0005432639264	25054	Business	87300.00
0005432639259	25054	Business	87300.00
0005432639218	25054	Business	87300.00
0005432866143	25054	Economy	29100.00
0005432639208	25054	Economy	29100.00
0005432639210	25054	Economy	29100.00
0005432866133	25054	Economy	29100.00
0005432639211	25054	Economy	29100.00
0005432866130	25054	Economy	29100.00
0005432866137	25054	Economy	29100.00
0005432639230	25054	Economy	29100.00
0005432639235	25054	Economy	29100.00
0005432866135	25054	Economy	29100.00
0005432639195	25054	Economy	29100.00
0005432866134	25054	Economy	29100.00
0005432639209	25054	Economy	29100.00
0005432639246	25054	Economy	29100.00
0005432639253	25054	Economy	29100.00
0005432639258	25054	Economy	29100.00
0005432866140	25054	Economy	29100.00
0005432866138	25054	Economy	29100.00
0005432639244	25054	Economy	29100.00
0005432639189	25054	Economy	29100.00
0005432639236	25054	Economy	29100.00
0005432639241	25054	Economy	29100.00
0005432866132	25054	Economy	29100.00
0005432639243	25054	Economy	29100.00
0005432639190	25054	Economy	29100.00
0005432639260	25054	Economy	29100.00
0005432639269	25054	Economy	29100.00
0005432866139	25054	Economy	29100.00
0005432639231	25054	Economy	29100.00
0005432639202	25054	Economy	29100.00
0005432639219	25054	Economy	29100.00
0005432866141	25054	Economy	29100.00
0005432329488	3113	Business	16100.00
0005432905171	3113	Business	16100.00
0005432329531	3113	Business	16100.00
0005432329514	3113	Business	16100.00
0005432329498	3113	Business	16100.00
0005433438987	3113	Business	16100.00
0005432329492	3113	Economy	5400.00
0005432329502	3113	Economy	5400.00
0005432329493	3113	Economy	5400.00
0005432329504	3113	Economy	5400.00
0005432329520	3113	Economy	5400.00
0005432329533	3113	Economy	5400.00
0005432329513	3113	Economy	5400.00
0005432329501	3113	Economy	5900.00
0005433438989	3113	Economy	5900.00
0005432329508	3113	Economy	5900.00
0005432329506	3113	Economy	5900.00
0005432329518	3113	Economy	5400.00
0005432287280	3113	Economy	5400.00
0005433438983	3113	Economy	5400.00
0005432905197	3113	Economy	5400.00
0005432329515	3113	Economy	5400.00
0005432329489	3113	Economy	5400.00
0005432329505	3113	Economy	5400.00
0005432329490	3113	Economy	5400.00
0005432329509	3113	Economy	5400.00
0005432329519	3113	Economy	5400.00
0005433438991	3113	Economy	5400.00
0005432329530	3113	Economy	5400.00
0005432329499	3113	Economy	5400.00
0005432905199	3113	Economy	5400.00
0005432329507	3113	Economy	5400.00
0005432329532	3113	Economy	5400.00
0005432329500	3113	Economy	5400.00
0005433438986	3113	Economy	5400.00
0005432287281	3113	Economy	5400.00
0005432905184	3113	Economy	5400.00
0005432329521	3113	Economy	5400.00
0005433438990	3113	Economy	5400.00
0005433438985	3113	Economy	5400.00
0005432329503	3113	Economy	5400.00
0005432329524	3113	Economy	5400.00
0005432329495	3113	Economy	5400.00
0005433438984	3113	Economy	5400.00
0005432329526	3113	Economy	5400.00
0005432329529	3113	Economy	5400.00
0005432329522	3113	Economy	5400.00
0005432329512	3113	Economy	5400.00
0005432329523	3113	Economy	5400.00
0005432329517	3113	Economy	5400.00
0005432329525	3113	Economy	5400.00
0005432329510	3113	Economy	5400.00
0005433438988	3113	Economy	5400.00
0005432329528	3113	Economy	5400.00
0005432329497	3113	Economy	5400.00
0005432329496	3113	Economy	5400.00
0005432905195	3113	Economy	5400.00
0005432329491	3113	Economy	5400.00
0005432329511	3113	Economy	5400.00
0005432287278	3113	Economy	5400.00
0005432329516	3113	Economy	5400.00
0005433438992	3113	Economy	5400.00
0005432287279	3113	Economy	5400.00
0005432329494	3113	Economy	5400.00
0005432329527	3113	Economy	5400.00
0005432329153	31108	Business	16100.00
0005432329022	31108	Business	16100.00
0005432054356	31108	Business	16100.00
0005432329157	31108	Business	16100.00
0005432328950	31108	Business	16100.00
0005432328932	31108	Business	16100.00
0005432054355	31108	Business	16100.00
0005432905226	31108	Business	16100.00
0005432329079	31108	Economy	5400.00
0005432329029	31108	Economy	5400.00
0005432328957	31108	Economy	5400.00
0005432329093	31108	Economy	5400.00
0005432329362	31108	Economy	5400.00
0005432329071	31108	Economy	5400.00
0005432328979	31108	Economy	5900.00
0005432328976	31108	Economy	5900.00
0005432329072	31108	Economy	5900.00
0005432329147	31108	Economy	5900.00
0005432329042	31108	Economy	5400.00
0005432329242	31108	Economy	5400.00
0005432329135	31108	Economy	5400.00
0005432328960	31108	Economy	5400.00
0005432329064	31108	Economy	5400.00
0005432329138	31108	Economy	5400.00
0005432328975	31108	Economy	5400.00
0005432329162	31108	Economy	5400.00
0005432329173	31108	Economy	5400.00
0005432328866	31108	Economy	5400.00
0005432905224	31108	Economy	5400.00
0005432329089	31108	Economy	5400.00
0005432329025	31108	Economy	5400.00
0005432329208	31108	Economy	5400.00
0005432329062	31108	Economy	5400.00
0005432329007	31108	Economy	5400.00
0005432329023	31108	Economy	5400.00
0005432329184	31108	Economy	5400.00
0005432329180	31108	Economy	5400.00
0005432329161	31108	Economy	5400.00
0005432328930	31108	Economy	5400.00
0005432329102	31108	Economy	5400.00
0005432329030	31108	Economy	5400.00
0005432329101	31108	Economy	5400.00
0005432328929	31108	Economy	5400.00
0005432329088	31108	Economy	5400.00
0005432905225	31108	Economy	5400.00
0005432328978	31108	Economy	5400.00
0005432328911	31108	Economy	5400.00
0005432905228	31108	Economy	5400.00
0005432328977	31108	Economy	5400.00
0005432329065	31108	Economy	5400.00
0005432329066	31108	Economy	5400.00
0005432328951	31108	Economy	5400.00
0005432329043	31108	Economy	5400.00
0005432329063	31108	Economy	5400.00
0005432328912	31108	Economy	5400.00
0005432329237	31108	Economy	5400.00
0005432329067	31108	Economy	5400.00
0005432329137	31108	Economy	5400.00
0005432329058	31108	Economy	5400.00
0005432328928	31108	Economy	5400.00
0005432329113	31108	Economy	5400.00
0005432329121	31108	Economy	5400.00
0005432905227	31108	Economy	5400.00
0005432328865	31108	Economy	5400.00
0005432054357	31108	Economy	5400.00
0005432329179	31108	Economy	5400.00
0005432905223	31108	Economy	5400.00
0005432328910	31108	Economy	5400.00
0005435999569	6181	Business	124600.00
0005434309985	6181	Business	124600.00
0005435999559	6181	Business	124600.00
0005434309983	6181	Business	124600.00
0005434309988	6181	Business	124600.00
0005434309976	6181	Business	124600.00
0005435999562	6181	Business	124600.00
0005434309989	6181	Economy	41500.00
0005435999568	6181	Economy	41500.00
0005435488038	6181	Economy	41500.00
0005435487990	6181	Economy	41500.00
0005435999570	6181	Economy	41500.00
0005435297105	6181	Economy	41500.00
0005435488002	6181	Economy	41500.00
0005435488027	6181	Economy	41500.00
0005435999554	6181	Economy	41500.00
0005434309977	6181	Economy	41500.00
0005434309981	6181	Economy	41500.00
0005435999574	6181	Economy	41500.00
0005435999560	6181	Economy	41500.00
0005435999575	6181	Economy	41500.00
0005435999563	6181	Economy	41500.00
0005435488023	6181	Economy	45700.00
0005434309979	6181	Economy	45700.00
0005435487985	6181	Economy	45700.00
0005435487979	6181	Economy	45700.00
0005434309984	6181	Economy	41500.00
0005435999556	6181	Economy	41500.00
0005435999561	6181	Economy	41500.00
0005434309986	6181	Economy	41500.00
0005435999553	6181	Economy	41500.00
0005435999571	6181	Economy	41500.00
0005434309990	6181	Economy	41500.00
0005435488059	6181	Economy	41500.00
0005432146236	6181	Economy	41500.00
0005434309987	6181	Economy	41500.00
0005435487978	6181	Economy	41500.00
0005435999573	6181	Economy	41500.00
0005434309978	6181	Economy	41500.00
0005434309982	6181	Economy	41500.00
0005435999558	6181	Economy	41500.00
0005435999555	6181	Economy	41500.00
0005435999567	6181	Economy	41500.00
0005435488051	6181	Economy	41500.00
0005435488032	6181	Economy	41500.00
0005435488046	6181	Economy	41500.00
0005435297106	6181	Economy	41500.00
0005435999572	6181	Economy	41500.00
0005435999565	6181	Economy	41500.00
0005434309991	6181	Economy	41500.00
0005435999566	6181	Economy	41500.00
0005434309980	6181	Economy	41500.00
0005435999564	6181	Economy	41500.00
0005435999576	6181	Economy	41500.00
0005435487972	6181	Economy	41500.00
0005435999552	6181	Economy	41500.00
0005435999557	6181	Economy	41500.00
0005435488195	19579	Business	124600.00
0005435999343	19579	Business	124600.00
0005435488186	19579	Business	124600.00
0005435297180	19579	Business	124600.00
0005434309856	19579	Business	124600.00
0005435488190	19579	Business	124600.00
0005435488188	19579	Business	124600.00
0005435488189	19579	Economy	41500.00
0005434309872	19579	Economy	41500.00
0005435488198	19579	Economy	41500.00
0005435297179	19579	Economy	41500.00
0005435999344	19579	Economy	41500.00
0005434309866	19579	Economy	41500.00
0005435999384	19579	Economy	41500.00
0005435999379	19579	Economy	41500.00
0005435999372	19579	Economy	41500.00
0005435488199	19579	Economy	41500.00
0005434309810	19579	Economy	41500.00
0005435488202	19579	Economy	41500.00
0005435297177	19579	Economy	41500.00
0005434309886	19579	Economy	41500.00
0005435297182	19579	Economy	41500.00
0005435297178	19579	Economy	41500.00
0005435999378	19579	Economy	41500.00
0005435488204	19579	Economy	41500.00
0005435999380	19579	Economy	41500.00
0005435999382	19579	Economy	41500.00
0005435488194	19579	Economy	41500.00
0005434309865	19579	Economy	45700.00
0005434309816	19579	Economy	45700.00
0005435999367	19579	Economy	45700.00
0005435999348	19579	Economy	45700.00
0005435999290	19579	Economy	45700.00
0005434309827	19579	Economy	41500.00
0005435488192	19579	Economy	41500.00
0005435999329	19579	Economy	41500.00
0005435999292	19579	Economy	41500.00
0005434309863	19579	Economy	41500.00
0005435999347	19579	Economy	41500.00
0005435488203	19579	Economy	41500.00
0005434309809	19579	Economy	41500.00
0005435488205	19579	Economy	41500.00
0005435999363	19579	Economy	41500.00
0005435297181	19579	Economy	41500.00
0005435488201	19579	Economy	41500.00
0005435999369	19579	Economy	41500.00
0005434309815	19579	Economy	41500.00
0005435999350	19579	Economy	41500.00
0005434309847	19579	Economy	41500.00
0005435488193	19579	Economy	41500.00
0005435488196	19579	Economy	41500.00
0005434309862	19579	Economy	41500.00
0005435488206	19579	Economy	41500.00
0005435999349	19579	Economy	41500.00
0005435999291	19579	Economy	41500.00
0005435488191	19579	Economy	41500.00
0005434309888	19579	Economy	41500.00
0005434309817	19579	Economy	41500.00
0005434309871	19579	Economy	41500.00
0005434309889	19579	Economy	41500.00
0005434309825	19579	Economy	41500.00
0005435488200	19579	Economy	41500.00
0005434309864	19579	Economy	41500.00
0005434309811	19579	Economy	41500.00
0005435999368	19579	Economy	41500.00
0005435488187	19579	Economy	41500.00
0005435488197	19579	Economy	41500.00
0005434309887	19579	Economy	41500.00
0005434309861	19579	Economy	41500.00
0005435502697	1561	Business	86000.00
0005434566152	1561	Business	86000.00
0005435518237	1561	Business	86000.00
0005433186170	1561	Business	86000.00
0005434566153	1561	Business	86000.00
0005435508571	1561	Business	86000.00
0005435508579	1561	Business	86000.00
0005435508566	1561	Business	86000.00
0005435508580	1561	Business	86000.00
0005434566154	1561	Business	86000.00
0005434566156	1561	Business	86000.00
0005435518233	1561	Business	86000.00
0005435508576	1561	Economy	28700.00
0005435508582	1561	Economy	28700.00
0005435502691	1561	Economy	28700.00
0005434566157	1561	Economy	28700.00
0005434566151	1561	Economy	28700.00
0005435502700	1561	Economy	28700.00
0005435502706	1561	Economy	28700.00
0005435518228	1561	Economy	28700.00
0005435518232	1561	Economy	31500.00
0005435508570	1561	Economy	31500.00
0005435518234	1561	Economy	31500.00
0005435508569	1561	Economy	31500.00
0005435502694	1561	Economy	31500.00
0005435502687	1561	Economy	28700.00
0005435502701	1561	Economy	28700.00
0005435502695	1561	Economy	28700.00
0005435502699	1561	Economy	28700.00
0005435502703	1561	Economy	28700.00
0005434566158	1561	Economy	28700.00
0005435502689	1561	Economy	28700.00
0005435518239	1561	Economy	28700.00
0005435508581	1561	Economy	28700.00
0005434566155	1561	Economy	28700.00
0005434566149	1561	Economy	28700.00
0005435508572	1561	Economy	28700.00
0005435518245	1561	Economy	28700.00
0005433186183	1561	Economy	28700.00
0005435518229	1561	Economy	28700.00
0005435502705	1561	Economy	28700.00
0005435502692	1561	Economy	28700.00
0005435518226	1561	Economy	28700.00
0005433186171	1561	Economy	28700.00
0005435518244	1561	Economy	28700.00
0005433186237	1561	Economy	28700.00
0005435508564	1561	Economy	28700.00
0005435508574	1561	Economy	28700.00
0005435502690	1561	Economy	28700.00
0005435518243	1561	Economy	28700.00
0005435508573	1561	Economy	28700.00
0005435518224	1561	Economy	28700.00
0005434566150	1561	Economy	28700.00
0005435518240	1561	Economy	28700.00
0005435518241	1561	Economy	28700.00
0005435502693	1561	Economy	28700.00
0005434566147	1561	Economy	28700.00
0005435508568	1561	Economy	28700.00
0005435518238	1561	Economy	28700.00
0005435518227	1561	Economy	28700.00
0005435518231	1561	Economy	28700.00
0005433186199	1561	Economy	28700.00
0005434566159	1561	Economy	28700.00
0005435502688	1561	Economy	28700.00
0005435518225	1561	Economy	28700.00
0005435508577	1561	Economy	28700.00
0005435508578	1561	Economy	28700.00
0005433186236	1561	Economy	28700.00
0005435502702	1561	Economy	28700.00
0005435502696	1561	Economy	28700.00
0005435502698	1561	Economy	28700.00
0005435518236	1561	Economy	28700.00
0005435508575	1561	Economy	28700.00
0005435518235	1561	Economy	28700.00
0005434566148	1561	Economy	28700.00
0005435518242	1561	Economy	28700.00
0005435508565	1561	Economy	28700.00
0005435502704	1561	Economy	28700.00
0005435508567	1561	Economy	28700.00
0005433186163	1561	Economy	28700.00
0005435518230	1561	Economy	28700.00
0005434566012	20884	Business	86000.00
0005435502539	20884	Business	86000.00
0005435529398	20884	Business	86000.00
0005435502554	20884	Business	86000.00
0005435529310	20884	Business	86000.00
0005434566027	20884	Business	86000.00
0005435529385	20884	Business	86000.00
0005435502581	20884	Business	86000.00
0005435529283	20884	Business	86000.00
0005435502567	20884	Business	86000.00
0005435529457	20884	Business	86000.00
0005434566028	20884	Economy	28700.00
0005435502481	20884	Economy	28700.00
0005434566029	20884	Economy	28700.00
0005435502450	20884	Economy	28700.00
0005435502480	20884	Economy	28700.00
0005435529407	20884	Economy	28700.00
0005434566082	20884	Economy	28700.00
0005435502470	20884	Economy	28700.00
0005435502588	20884	Economy	28700.00
0005433186266	20884	Economy	31500.00
0005433186272	20884	Economy	31500.00
0005434566061	20884	Economy	31500.00
0005434566003	20884	Economy	31500.00
0005435529369	20884	Economy	31500.00
0005435502587	20884	Economy	28700.00
0005435502502	20884	Economy	28700.00
0005435502486	20884	Economy	28700.00
0005434566054	20884	Economy	28700.00
0005435545786	20884	Economy	28700.00
0005435529458	20884	Economy	28700.00
0005435529467	20884	Economy	28700.00
0005435502582	20884	Economy	28700.00
0005435502384	20884	Economy	28700.00
0005435529413	20884	Economy	28700.00
0005435502542	20884	Economy	28700.00
0005433186271	20884	Economy	28700.00
0005435502426	20884	Economy	28700.00
0005435529368	20884	Economy	28700.00
0005435502427	20884	Economy	28700.00
0005435502446	20884	Economy	28700.00
0005433186269	20884	Economy	28700.00
0005435502463	20884	Economy	28700.00
0005433186273	20884	Economy	28700.00
0005435529282	20884	Economy	28700.00
0005435502543	20884	Economy	28700.00
0005435502503	20884	Economy	28700.00
0005435545782	20884	Economy	28700.00
0005435502512	20884	Economy	28700.00
0005435529409	20884	Economy	28700.00
0005435502383	20884	Economy	28700.00
0005433186270	20884	Economy	28700.00
0005434566022	20884	Economy	28700.00
0005435529511	20884	Economy	28700.00
0005435529408	20884	Economy	28700.00
0005435502479	20884	Economy	28700.00
0005434566053	20884	Economy	28700.00
0005435502429	20884	Economy	28700.00
0005435502568	20884	Economy	28700.00
0005435502638	20884	Economy	28700.00
0005435529397	20884	Economy	28700.00
0005433186274	20884	Economy	28700.00
0005435529410	20884	Economy	28700.00
0005435502555	20884	Economy	28700.00
0005434566081	20884	Economy	28700.00
0005434566005	20884	Economy	28700.00
0005435502484	20884	Economy	28700.00
0005434566021	20884	Economy	28700.00
0005435529396	20884	Economy	28700.00
0005435502496	20884	Economy	28700.00
0005435529406	20884	Economy	28700.00
0005434566097	20884	Economy	28700.00
0005433186267	20884	Economy	28700.00
0005435502417	20884	Economy	28700.00
0005435545775	20884	Economy	28700.00
0005435529424	20884	Economy	28700.00
0005434566016	20884	Economy	28700.00
0005435502513	20884	Economy	28700.00
0005435502442	20884	Economy	28700.00
0005433186268	20884	Economy	28700.00
0005435529456	20884	Economy	28700.00
0005435502516	20884	Economy	28700.00
0005435545784	20884	Economy	28700.00
0005434566004	20884	Economy	28700.00
0005435502497	20884	Economy	28700.00
0005435502572	20884	Economy	28700.00
0005435153860	3923	Economy	19700.00
0005435931634	3923	Economy	19700.00
0005435153858	3923	Economy	19700.00
0005435153857	3923	Economy	19700.00
0005435153861	3923	Economy	19700.00
0005435931630	3923	Economy	19700.00
0005435931637	3923	Economy	19700.00
0005435153856	3923	Economy	19700.00
0005435153859	3923	Economy	19700.00
0005435153771	21882	Economy	21600.00
0005435931668	21882	Economy	19700.00
0005435153796	21882	Economy	19700.00
0005435153783	21882	Economy	19700.00
0005435931667	21882	Economy	19700.00
0005435153782	21882	Economy	19700.00
0005435931669	21882	Economy	19700.00
0005435225677	7222	Economy	14300.00
0005432629113	7222	Economy	14300.00
0005432629101	7222	Economy	13000.00
0005435225623	7222	Economy	13000.00
0005435225630	7222	Economy	13000.00
0005432629105	7222	Economy	13000.00
0005435225661	7222	Economy	13000.00
0005435225673	7222	Economy	13000.00
0005435225675	7222	Economy	13000.00
0005432629112	7222	Economy	13000.00
0005432629102	7222	Economy	13000.00
0005435225672	7222	Economy	13000.00
0005435225636	7222	Economy	13000.00
0005435225627	7222	Economy	13000.00
0005432629110	7222	Economy	13000.00
0005435225628	7222	Economy	13000.00
0005435225637	7222	Economy	13000.00
0005435225641	7222	Economy	13000.00
0005432629106	7222	Economy	13000.00
0005432629111	7222	Economy	13000.00
0005432629103	7222	Economy	13000.00
0005432629109	7222	Economy	13000.00
0005432629104	7222	Economy	13000.00
0005435225640	7222	Economy	13000.00
0005435225621	7222	Economy	13000.00
0005435225676	7222	Economy	13000.00
0005432629115	7222	Economy	13000.00
0005432629108	7222	Economy	13000.00
0005432629116	7222	Economy	13000.00
0005432629114	7222	Economy	13000.00
0005435225620	7222	Economy	13000.00
0005435225646	7222	Economy	13000.00
0005432629107	7222	Economy	13000.00
0005435225626	7222	Economy	13000.00
0005435225659	7222	Economy	13000.00
0005435225642	7222	Economy	13000.00
0005435225635	7222	Economy	13000.00
0005435225725	28125	Economy	13000.00
0005432629006	28125	Economy	13000.00
0005432629020	28125	Economy	13000.00
0005435225724	28125	Economy	13000.00
0005435225727	28125	Economy	13000.00
0005432628962	28125	Economy	13000.00
0005432628980	28125	Economy	13000.00
0005432629017	28125	Economy	13000.00
0005435225723	28125	Economy	13000.00
0005432628994	28125	Economy	13000.00
0005432628938	28125	Economy	13000.00
0005432628982	28125	Economy	13000.00
0005435225728	28125	Economy	13000.00
0005432629016	28125	Economy	13000.00
0005435225726	28125	Economy	13000.00
0005435225729	28125	Economy	13000.00
0005432628974	28125	Economy	13000.00
0005432629024	28125	Economy	13000.00
0005435225730	28125	Economy	13000.00
0005432629034	28125	Economy	13000.00
0005432628975	28125	Economy	13000.00
0005432629023	28125	Economy	13000.00
0005432628991	28125	Economy	13000.00
0005434267992	8761	Economy	11500.00
0005434267988	8761	Economy	10500.00
0005434268006	8761	Economy	10500.00
0005434267999	8761	Economy	10500.00
0005434267989	8761	Economy	10500.00
0005434267994	8761	Economy	10500.00
0005435960118	8761	Economy	10500.00
0005435960119	8761	Economy	10500.00
0005434268007	8761	Economy	10500.00
0005435960117	8761	Economy	10500.00
0005434267993	8761	Economy	10500.00
0005434267975	8761	Economy	10500.00
0005434267998	8761	Economy	10500.00
0005435960120	8761	Economy	10500.00
0005435960088	15225	Economy	11500.00
0005434268017	15225	Economy	10500.00
0005435960092	15225	Economy	10500.00
0005434268018	15225	Economy	10500.00
0005434268016	15225	Economy	10500.00
0005435960089	15225	Economy	10500.00
0005435960091	15225	Economy	10500.00
0005432693581	1207	Business	115000.00
0005432693592	1207	Business	115000.00
0005432873351	1207	Business	115000.00
0005432693587	1207	Business	115000.00
0005432675400	1207	Business	115000.00
0005432693596	1207	Business	115000.00
0005432675404	1207	Business	115000.00
0005432693576	1207	Business	115000.00
0005432677640	1207	Business	115000.00
0005432675393	1207	Economy	38300.00
0005432693579	1207	Economy	38300.00
0005432693585	1207	Economy	38300.00
0005432693586	1207	Economy	38300.00
0005432693571	1207	Economy	38300.00
0005432693599	1207	Economy	42200.00
0005432873378	1207	Economy	42200.00
0005432693591	1207	Economy	38300.00
0005432693584	1207	Economy	42200.00
0005432693597	1207	Economy	38300.00
0005432675401	1207	Economy	38300.00
0005432693590	1207	Economy	38300.00
0005432693577	1207	Economy	38300.00
0005432693573	1207	Economy	38300.00
0005432677639	1207	Economy	38300.00
0005432693594	1207	Economy	38300.00
0005432873379	1207	Economy	38300.00
0005432693582	1207	Economy	38300.00
0005432675407	1207	Economy	38300.00
0005432693583	1207	Economy	38300.00
0005432675405	1207	Economy	38300.00
0005432693598	1207	Economy	38300.00
0005432675394	1207	Economy	38300.00
0005432693578	1207	Economy	38300.00
0005432873377	1207	Economy	38300.00
0005432693575	1207	Economy	38300.00
0005432693593	1207	Economy	38300.00
0005432693595	1207	Economy	38300.00
0005432675396	1207	Economy	38300.00
0005432675402	1207	Economy	38300.00
0005432693589	1207	Economy	38300.00
0005432693569	1207	Economy	38300.00
0005432675399	1207	Economy	38300.00
0005432693580	1207	Economy	38300.00
0005432693572	1207	Economy	38300.00
0005432693588	1207	Economy	38300.00
0005432675395	1207	Economy	38300.00
0005432677641	1207	Economy	38300.00
0005432675398	1207	Economy	38300.00
0005432675397	1207	Economy	38300.00
0005432675406	1207	Economy	38300.00
0005432675403	1207	Economy	38300.00
0005432693574	1207	Economy	38300.00
0005432693570	1207	Economy	38300.00
0005432675305	17515	Business	115000.00
0005432675245	17515	Business	115000.00
0005432873419	17515	Business	115000.00
0005432693391	17515	Business	115000.00
0005432873416	17515	Business	115000.00
0005432693244	17515	Business	115000.00
0005432693399	17515	Business	115000.00
0005432873414	17515	Business	115000.00
0005432693285	17515	Business	115000.00
0005432675254	17515	Business	115000.00
0005432693363	17515	Economy	38300.00
0005432693367	17515	Economy	38300.00
0005432873415	17515	Economy	38300.00
0005432693338	17515	Economy	42200.00
0005432693261	17515	Economy	42200.00
0005432693366	17515	Economy	42200.00
0005432873417	17515	Economy	42200.00
0005432675308	17515	Economy	38300.00
0005432677612	17515	Economy	38300.00
0005432693238	17515	Economy	38300.00
0005432675271	17515	Economy	38300.00
0005432693413	17515	Economy	38300.00
0005432675307	17515	Economy	38300.00
0005432675257	17515	Economy	38300.00
0005432675219	17515	Economy	38300.00
0005432675272	17515	Economy	38300.00
0005432693349	17515	Economy	38300.00
0005432693286	17515	Economy	38300.00
0005432675273	17515	Economy	38300.00
0005432675246	17515	Economy	38300.00
0005432693329	17515	Economy	38300.00
0005432675262	17515	Economy	38300.00
0005432675215	17515	Economy	38300.00
0005432693330	17515	Economy	38300.00
0005432873421	17515	Economy	38300.00
0005432677611	17515	Economy	38300.00
0005432677613	17515	Economy	38300.00
0005432693322	17515	Economy	38300.00
0005432693393	17515	Economy	38300.00
0005432677581	17515	Economy	38300.00
0005432675244	17515	Economy	38300.00
0005432873420	17515	Economy	38300.00
0005432675214	17515	Economy	38300.00
0005432675213	17515	Economy	38300.00
0005432675256	17515	Economy	38300.00
0005432677580	17515	Economy	38300.00
0005432693321	17515	Economy	38300.00
0005432693245	17515	Economy	38300.00
0005432693398	17515	Economy	38300.00
0005432873418	17515	Economy	38300.00
0005432693257	17515	Economy	38300.00
0005432693211	17515	Economy	38300.00
0005433156818	1121	Economy	15200.00
0005433156817	1121	Economy	15200.00
0005434435456	1121	Economy	13900.00
0005434435447	1121	Economy	13900.00
0005433156819	1121	Economy	13900.00
0005434435459	1121	Economy	13900.00
0005434435448	1121	Economy	13900.00
0005434435454	1121	Economy	13900.00
0005434435461	1121	Economy	13900.00
0005434435458	1121	Economy	13900.00
0005434435451	1121	Economy	13900.00
0005434435460	1121	Economy	13900.00
0005434435453	1121	Economy	13900.00
0005434435450	1121	Economy	13900.00
0005434435457	1121	Economy	13900.00
0005434435455	1121	Economy	13900.00
0005434435449	1121	Economy	13900.00
0005434435452	1121	Economy	13900.00
0005434435350	17331	Economy	15200.00
0005433156900	17331	Economy	15200.00
0005433156901	17331	Economy	15200.00
0005433156902	17331	Economy	13900.00
0005434435285	17331	Economy	13900.00
0005433156899	17331	Economy	13900.00
0005433156907	17331	Economy	13900.00
0005433156906	17331	Economy	13900.00
0005434435321	17331	Economy	13900.00
0005434435331	17331	Economy	13900.00
0005434435339	17331	Economy	13900.00
0005434435273	17331	Economy	13900.00
0005433156904	17331	Economy	13900.00
0005434435258	17331	Economy	13900.00
0005433156905	17331	Economy	13900.00
0005433156903	17331	Economy	13900.00
0005434435349	17331	Economy	13900.00
0005434435373	17331	Economy	13900.00
0005434435343	17331	Economy	13900.00
0005434435325	17331	Economy	13900.00
0005434435272	17331	Economy	13900.00
0005435086966	4101	Economy	7500.00
0005435086968	4101	Economy	7500.00
0005435086971	4101	Economy	7500.00
0005435086967	4101	Economy	7500.00
0005435086970	4101	Economy	7500.00
0005435928205	4101	Economy	7500.00
0005435928183	4101	Economy	7500.00
0005435086965	4101	Economy	7500.00
0005435086964	4101	Economy	7500.00
0005435928184	4101	Economy	7500.00
0005435086969	4101	Economy	7500.00
0005435928189	4101	Economy	7500.00
0005435086877	24399	Economy	7500.00
0005435086876	24399	Economy	7500.00
0005435928227	24399	Economy	7500.00
0005435928226	24399	Economy	7500.00
0005435086890	24399	Economy	7500.00
0005435928228	24399	Economy	7500.00
0005435086847	24399	Economy	7500.00
0005435928225	24399	Economy	7500.00
0005435928229	24399	Economy	7500.00
0005435551609	11059	Business	144300.00
0005435551649	11059	Business	144300.00
0005435098561	11059	Business	144300.00
0005435551660	11059	Business	144300.00
0005435551657	11059	Business	144300.00
0005435551661	11059	Economy	48100.00
0005435098565	11059	Economy	48100.00
0005435551654	11059	Economy	48100.00
0005435551625	11059	Economy	48100.00
0005435551608	11059	Economy	48100.00
0005435098570	11059	Economy	48100.00
0005435098572	11059	Economy	48100.00
0005435551603	11059	Economy	48100.00
0005435098563	11059	Economy	48100.00
0005435551618	11059	Economy	48100.00
0005435551623	11059	Economy	48100.00
0005435551633	11059	Economy	48100.00
0005435551630	11059	Economy	48100.00
0005435551624	11059	Economy	48100.00
0005435098562	11059	Economy	48100.00
0005435098564	11059	Economy	48100.00
0005433373616	2463	Business	86800.00
0005433373617	2463	Business	86800.00
0005433373657	2463	Business	86800.00
0005433373592	2463	Business	86800.00
0005435706653	2463	Business	86800.00
0005435706665	2463	Business	86800.00
0005433373614	2463	Business	86800.00
0005435706654	2463	Economy	28900.00
0005435706664	2463	Economy	28900.00
0005435706659	2463	Economy	28900.00
0005435706675	2463	Economy	28900.00
0005433373620	2463	Economy	28900.00
0005435706669	2463	Economy	28900.00
0005435706674	2463	Economy	31800.00
0005435706655	2463	Economy	31800.00
0005435706682	2463	Economy	28900.00
0005435706657	2463	Economy	28900.00
0005433373594	2463	Economy	28900.00
0005435706676	2463	Economy	28900.00
0005435706668	2463	Economy	28900.00
0005435706661	2463	Economy	28900.00
0005435706652	2463	Economy	28900.00
0005435706681	2463	Economy	28900.00
0005433373582	2463	Economy	28900.00
0005435706660	2463	Economy	28900.00
0005435706666	2463	Economy	28900.00
0005433373593	2463	Economy	28900.00
0005435706673	2463	Economy	28900.00
0005433373604	2463	Economy	28900.00
0005435706683	2463	Economy	28900.00
0005433373591	2463	Economy	28900.00
0005435706677	2463	Economy	28900.00
0005433373606	2463	Economy	28900.00
0005435706680	2463	Economy	28900.00
0005435706679	2463	Economy	28900.00
0005435706678	2463	Economy	28900.00
0005435706670	2463	Economy	28900.00
0005435706658	2463	Economy	28900.00
0005435706662	2463	Economy	28900.00
0005433373584	2463	Economy	28900.00
0005435706656	2463	Economy	28900.00
0005433373603	2463	Economy	28900.00
0005433373590	2463	Economy	28900.00
0005435706663	2463	Economy	28900.00
0005435706671	2463	Economy	28900.00
0005435706672	2463	Economy	28900.00
0005433373615	2463	Economy	28900.00
0005435706667	2463	Economy	28900.00
0005435706539	27040	Business	86800.00
0005435706558	27040	Business	86800.00
0005435706526	27040	Business	86800.00
0005435706483	27040	Business	86800.00
0005433373689	27040	Business	86800.00
0005435706461	27040	Business	86800.00
0005435706487	27040	Economy	28900.00
0005435706516	27040	Economy	28900.00
0005435706557	27040	Economy	28900.00
0005435706459	27040	Economy	28900.00
0005433373685	27040	Economy	28900.00
0005433373687	27040	Economy	28900.00
0005435706528	27040	Economy	28900.00
0005435706504	27040	Economy	31800.00
0005433373684	27040	Economy	31800.00
0005433373690	27040	Economy	31800.00
0005435706482	27040	Economy	28900.00
0005435706460	27040	Economy	28900.00
0005433373692	27040	Economy	28900.00
0005435706611	27040	Economy	28900.00
0005433373699	27040	Economy	28900.00
0005435706513	27040	Economy	28900.00
0005433373688	27040	Economy	28900.00
0005433373697	27040	Economy	28900.00
0005435706532	27040	Economy	28900.00
0005433373686	27040	Economy	28900.00
0005433373695	27040	Economy	28900.00
0005435706610	27040	Economy	28900.00
0005433373698	27040	Economy	28900.00
0005435706486	27040	Economy	28900.00
0005435706531	27040	Economy	28900.00
0005435706508	27040	Economy	28900.00
0005433373693	27040	Economy	28900.00
0005433373694	27040	Economy	28900.00
0005435706517	27040	Economy	28900.00
0005435706497	27040	Economy	28900.00
0005435706484	27040	Economy	28900.00
0005433373691	27040	Economy	28900.00
0005435706503	27040	Economy	28900.00
0005435706553	27040	Economy	28900.00
0005435706458	27040	Economy	28900.00
0005435706564	27040	Economy	28900.00
0005435706563	27040	Economy	28900.00
0005433373700	27040	Economy	28900.00
0005433373696	27040	Economy	28900.00
0005433373701	27040	Economy	28900.00
0005434964568	1323	Business	203300.00
0005434964565	1323	Business	203300.00
0005433261635	1323	Business	203300.00
0005434964554	1323	Business	203300.00
0005434964569	1323	Business	203300.00
0005434964557	1323	Business	203300.00
0005433261656	1323	Business	203300.00
0005433261625	1323	Business	203300.00
0005433261645	1323	Business	203300.00
0005434964550	1323	Business	203300.00
0005434964570	1323	Economy	67800.00
0005434964561	1323	Economy	67800.00
0005432279309	1323	Economy	67800.00
0005434964567	1323	Economy	67800.00
0005433261647	1323	Economy	67800.00
0005434964577	1323	Economy	67800.00
0005432279312	1323	Economy	67800.00
0005434964555	1323	Economy	67800.00
0005434964548	1323	Economy	67800.00
0005434964547	1323	Economy	67800.00
0005434964562	1323	Economy	67800.00
0005434964546	1323	Economy	67800.00
0005434964563	1323	Economy	67800.00
0005434964571	1323	Economy	67800.00
0005434964559	1323	Economy	67800.00
0005434964544	1323	Economy	67800.00
0005432279311	1323	Economy	67800.00
0005434964545	1323	Economy	67800.00
0005434964556	1323	Economy	67800.00
0005433261601	1323	Economy	67800.00
0005434964542	1323	Economy	67800.00
0005433261634	1323	Economy	67800.00
0005434964575	1323	Economy	67800.00
0005433261626	1323	Economy	67800.00
0005433261621	1323	Economy	67800.00
0005433261602	1323	Economy	67800.00
0005434964553	1323	Economy	67800.00
0005434964543	1323	Economy	67800.00
0005434964558	1323	Economy	67800.00
0005432279310	1323	Economy	67800.00
0005434964574	1323	Economy	67800.00
0005434964573	1323	Economy	67800.00
0005434964564	1323	Economy	67800.00
0005434964572	1323	Economy	67800.00
0005433261655	1323	Economy	67800.00
0005434964552	1323	Economy	67800.00
0005433261622	1323	Economy	67800.00
0005434964551	1323	Economy	67800.00
0005434964549	1323	Economy	67800.00
0005434964560	1323	Economy	67800.00
0005433261643	1323	Economy	67800.00
0005434964576	1323	Economy	67800.00
0005433261636	1323	Economy	67800.00
0005434964566	1323	Economy	67800.00
0005434964348	18244	Business	203300.00
0005433261742	18244	Business	203300.00
0005434964428	18244	Business	203300.00
0005433261733	18244	Business	203300.00
0005433261744	18244	Business	203300.00
0005433261726	18244	Business	203300.00
0005434964403	18244	Business	203300.00
0005434964366	18244	Business	203300.00
0005434964367	18244	Business	203300.00
0005434964381	18244	Business	203300.00
0005433261751	18244	Business	203300.00
0005434964386	18244	Business	203300.00
0005434964313	18244	Business	203300.00
0005433261738	18244	Business	203300.00
0005434964392	18244	Business	203300.00
0005434964355	18244	Economy	74500.00
0005433261730	18244	Economy	74500.00
0005434964360	18244	Economy	74500.00
0005434964382	18244	Economy	67800.00
0005433261737	18244	Economy	67800.00
0005433261741	18244	Economy	67800.00
0005434964321	18244	Economy	67800.00
0005433261750	18244	Economy	67800.00
0005434964444	18244	Economy	67800.00
0005433261721	18244	Economy	67800.00
0005434964388	18244	Economy	67800.00
0005434964440	18244	Economy	67800.00
0005434964456	18244	Economy	67800.00
0005433261728	18244	Economy	67800.00
0005433261739	18244	Economy	67800.00
0005433261727	18244	Economy	67800.00
0005433261729	18244	Economy	67800.00
0005434964404	18244	Economy	67800.00
0005434964475	18244	Economy	67800.00
0005434964384	18244	Economy	67800.00
0005434964412	18244	Economy	67800.00
0005434964401	18244	Economy	67800.00
0005434964429	18244	Economy	67800.00
0005433261736	18244	Economy	67800.00
0005434964284	18244	Economy	67800.00
0005434964427	18244	Economy	67800.00
0005434964332	18244	Economy	67800.00
0005434964351	18244	Economy	67800.00
0005433261747	18244	Economy	67800.00
0005434964402	18244	Economy	67800.00
0005434964453	18244	Economy	67800.00
0005434964268	18244	Economy	67800.00
0005434964376	18244	Economy	67800.00
0005433261743	18244	Economy	67800.00
0005434964374	18244	Economy	67800.00
0005434964280	18244	Economy	67800.00
0005433261734	18244	Economy	67800.00
0005434964391	18244	Economy	67800.00
0005434964466	18244	Economy	67800.00
0005434964380	18244	Economy	67800.00
0005434964357	18244	Economy	67800.00
0005434964322	18244	Economy	67800.00
0005433261722	18244	Economy	67800.00
0005433261745	18244	Economy	67800.00
0005433261731	18244	Economy	67800.00
0005434964339	18244	Economy	67800.00
0005434964356	18244	Economy	67800.00
0005434964383	18244	Economy	74500.00
0005434964323	18244	Economy	67800.00
0005434964480	18244	Economy	67800.00
0005434964368	18244	Economy	74500.00
0005434964333	18244	Economy	67800.00
0005434964310	18244	Economy	67800.00
0005434964445	18244	Economy	67800.00
0005434964378	18244	Economy	67800.00
0005434964455	18244	Economy	67800.00
0005434964377	18244	Economy	67800.00
0005434964434	18244	Economy	67800.00
0005434964373	18244	Economy	67800.00
0005433261749	18244	Economy	67800.00
0005434964359	18244	Economy	67800.00
0005434964329	18244	Economy	67800.00
0005433261748	18244	Economy	67800.00
0005434964479	18244	Economy	67800.00
0005433261735	18244	Economy	67800.00
0005434964385	18244	Economy	67800.00
0005433261725	18244	Economy	67800.00
0005434964362	18244	Economy	67800.00
0005434964379	18244	Economy	67800.00
0005434964413	18244	Economy	67800.00
0005434964441	18244	Economy	67800.00
0005434964350	18244	Economy	67800.00
0005433261746	18244	Economy	67800.00
0005434964340	18244	Economy	67800.00
0005433261732	18244	Economy	67800.00
0005434964458	18244	Economy	67800.00
0005433261740	18244	Economy	67800.00
0005434964467	18244	Economy	67800.00
0005433261723	18244	Economy	67800.00
0005434964399	18244	Economy	67800.00
0005433261724	18244	Economy	67800.00
0005434964338	18244	Economy	67800.00
0005433194862	4845	Business	44200.00
0005435907568	4845	Business	44200.00
0005435907554	4845	Economy	14700.00
0005435907558	4845	Economy	14700.00
0005434626131	4845	Economy	16200.00
0005434626130	4845	Economy	16200.00
0005435907559	4845	Economy	14700.00
0005435907562	4845	Economy	14700.00
0005434626127	4845	Economy	14700.00
0005434626125	4845	Economy	14700.00
0005434626133	4845	Economy	14700.00
0005435907561	4845	Economy	14700.00
0005434626128	4845	Economy	14700.00
0005433194865	4845	Economy	14700.00
0005434626132	4845	Economy	14700.00
0005435907545	4845	Economy	14700.00
0005433194885	4845	Economy	14700.00
0005434626129	4845	Economy	14700.00
0005433194866	4845	Economy	14700.00
0005435907569	4845	Economy	14700.00
0005434626126	4845	Economy	14700.00
0005433194863	4845	Economy	14700.00
0005434626073	32914	Business	44200.00
0005433194904	32914	Economy	14700.00
0005434626072	32914	Economy	14700.00
0005434626023	32914	Economy	16200.00
0005434626046	32914	Economy	14700.00
0005435907593	32914	Economy	14700.00
0005435907594	32914	Economy	14700.00
0005434626039	32914	Economy	14700.00
0005434626024	32914	Economy	14700.00
0005434626058	32914	Economy	14700.00
0005433194900	32914	Economy	14700.00
0005434626059	32914	Economy	14700.00
0005435907590	32914	Economy	14700.00
0005433194901	32914	Economy	14700.00
0005433194903	32914	Economy	14700.00
0005435907591	32914	Economy	14700.00
0005435907592	32914	Economy	14700.00
0005434626006	32914	Economy	14700.00
0005433194902	32914	Economy	14700.00
0005435787371	13785	Economy	3400.00
0005435785601	13785	Economy	3400.00
0005435785629	13785	Economy	3400.00
0005435785547	13785	Economy	3400.00
0005435785550	13785	Economy	3100.00
0005435785739	13785	Economy	3100.00
0005435785600	13785	Economy	3100.00
0005435785602	13785	Economy	3100.00
0005435787370	13785	Economy	3100.00
0005435785553	13785	Economy	3100.00
0005432195730	13785	Economy	3100.00
0005432195732	13785	Economy	3100.00
0005435785615	13785	Economy	3100.00
0005435787375	13785	Economy	3100.00
0005435785464	13785	Economy	3100.00
0005435785626	13785	Economy	3100.00
0005435785597	13785	Economy	3100.00
0005435785545	13785	Economy	3100.00
0005435785634	13785	Economy	3100.00
0005435785708	13785	Economy	3100.00
0005435785666	13785	Economy	3100.00
0005435785610	13785	Economy	3100.00
0005435785684	13785	Economy	3100.00
0005435785768	13785	Economy	3100.00
0005435785598	13785	Economy	3100.00
0005435785582	13785	Economy	3100.00
0005435785596	13785	Economy	3100.00
0005435785628	13785	Economy	3100.00
0005435785664	13785	Economy	3100.00
0005435787369	13785	Economy	3100.00
0005435785583	13785	Economy	3100.00
0005435785711	13785	Economy	3100.00
0005435785616	13785	Economy	3100.00
0005435785524	13785	Economy	3100.00
0005435785609	13785	Economy	3100.00
0005435785614	13785	Economy	3100.00
0005435785624	13785	Economy	3100.00
0005435785622	13785	Economy	3100.00
0005432195731	13785	Economy	3100.00
0005435785595	13785	Economy	3100.00
0005435785767	13785	Economy	3100.00
0005435785585	13785	Economy	3100.00
0005435785603	13785	Economy	3100.00
0005435785586	13785	Economy	3100.00
0005435785633	13785	Economy	3100.00
0005435785552	13785	Economy	3100.00
0005435785709	13785	Economy	3100.00
0005435785625	13785	Economy	3100.00
0005435785667	13785	Economy	3100.00
0005435785929	27444	Economy	3400.00
0005435785904	27444	Economy	3400.00
0005435785920	27444	Economy	3400.00
0005435785931	27444	Economy	3100.00
0005435785912	27444	Economy	3100.00
0005435785907	27444	Economy	3100.00
0005435785914	27444	Economy	3100.00
0005435785923	27444	Economy	3100.00
0005435785901	27444	Economy	3100.00
0005435785924	27444	Economy	3100.00
0005435785899	27444	Economy	3100.00
0005432190692	27444	Economy	3100.00
0005435785910	27444	Economy	3100.00
0005432190690	27444	Economy	3100.00
0005435785900	27444	Economy	3100.00
0005435785921	27444	Economy	3100.00
0005435785925	27444	Economy	3100.00
0005435785902	27444	Economy	3100.00
0005435785927	27444	Economy	3100.00
0005435785932	27444	Economy	3100.00
0005435937417	27444	Economy	3100.00
0005435785928	27444	Economy	3100.00
0005435785905	27444	Economy	3100.00
0005435937416	27444	Economy	3100.00
0005435785908	27444	Economy	3100.00
0005432190693	27444	Economy	3100.00
0005435787390	27444	Economy	3100.00
0005435785898	27444	Economy	3100.00
0005435785930	27444	Economy	3100.00
0005435785906	27444	Economy	3100.00
0005435785915	27444	Economy	3100.00
0005435787389	27444	Economy	3100.00
0005435785909	27444	Economy	3100.00
0005432190691	27444	Economy	3100.00
0005435785917	27444	Economy	3100.00
0005435785922	27444	Economy	3100.00
0005435785926	27444	Economy	3100.00
0005435785911	27444	Economy	3100.00
0005435785903	27444	Economy	3100.00
0005435785918	27444	Economy	3100.00
0005435785913	27444	Economy	3100.00
0005435785919	27444	Economy	3100.00
0005435785916	27444	Economy	3100.00
0005434408612	20264	Business	12000.00
0005434408683	20264	Business	12000.00
0005435311287	20264	Business	12000.00
0005435311282	20264	Business	12000.00
0005434408230	20264	Business	12000.00
0005434408318	20264	Business	12000.00
0005434408147	20264	Business	12000.00
0005434408199	20264	Business	12000.00
0005434408336	20264	Business	12000.00
0005434408534	20264	Business	12000.00
0005434408193	20264	Business	12000.00
0005434408533	20264	Business	12000.00
0005434408231	20264	Economy	4000.00
0005434408320	20264	Economy	4000.00
0005434408257	20264	Economy	4000.00
0005435311277	20264	Economy	4000.00
0005434408510	20264	Economy	4000.00
0005434408136	20264	Economy	4000.00
0005435311289	20264	Economy	4000.00
0005435311275	20264	Economy	4000.00
0005434408384	20264	Economy	4000.00
0005432058449	20264	Economy	4000.00
0005434408611	20264	Economy	4400.00
0005434408338	20264	Economy	4400.00
0005435311286	20264	Economy	4400.00
0005435311288	20264	Economy	4400.00
0005434408143	20264	Economy	4400.00
0005434407823	20264	Economy	4000.00
0005434408445	20264	Economy	4000.00
0005434408148	20264	Economy	4000.00
0005434408440	20264	Economy	4000.00
0005434408329	20264	Economy	4000.00
0005434408518	20264	Economy	4000.00
0005434408494	20264	Economy	4000.00
0005434408234	20264	Economy	4000.00
0005435311281	20264	Economy	4000.00
0005435311278	20264	Economy	4000.00
0005434408232	20264	Economy	4000.00
0005434408262	20264	Economy	4000.00
0005434408496	20264	Economy	4000.00
0005434408281	20264	Economy	4000.00
0005434408391	20264	Economy	4000.00
0005434408326	20264	Economy	4000.00
0005434408302	20264	Economy	4000.00
0005434408250	20264	Economy	4000.00
0005434408243	20264	Economy	4000.00
0005434408194	20264	Economy	4000.00
0005434407822	20264	Economy	4000.00
0005434408385	20264	Economy	4000.00
0005434408142	20264	Economy	4000.00
0005434408183	20264	Economy	4000.00
0005435311280	20264	Economy	4000.00
0005434408233	20264	Economy	4000.00
0005434408264	20264	Economy	4000.00
0005434408447	20264	Economy	4000.00
0005434408256	20264	Economy	4000.00
0005434408184	20264	Economy	4000.00
0005434408146	20264	Economy	4000.00
0005434408181	20264	Economy	4000.00
0005434408439	20264	Economy	4000.00
0005432058451	20264	Economy	4000.00
0005435311276	20264	Economy	4000.00
0005434408321	20264	Economy	4000.00
0005434408378	20264	Economy	4000.00
0005434408280	20264	Economy	4000.00
0005434408448	20264	Economy	4000.00
0005435311283	20264	Economy	4000.00
0005434408244	20264	Economy	4000.00
0005434408394	20264	Economy	4000.00
0005434408436	20264	Economy	4000.00
0005435311284	20264	Economy	4000.00
0005435311285	20264	Economy	4000.00
0005434408360	20264	Economy	4000.00
0005434408482	20264	Economy	4000.00
0005434408337	20264	Economy	4000.00
0005432058452	20264	Economy	4000.00
0005434408390	20264	Economy	4000.00
0005434408273	20264	Economy	4000.00
0005435311279	20264	Economy	4000.00
0005432058450	20264	Economy	4000.00
0005434408509	20264	Economy	4000.00
0005434408519	20264	Economy	4000.00
0005434408092	20264	Economy	4000.00
0005434408325	20264	Economy	4000.00
0005434408299	20264	Economy	4000.00
0005434408535	20264	Economy	4000.00
0005434408393	20264	Economy	4000.00
0005434408210	20264	Economy	4000.00
0005434408180	20264	Economy	4000.00
0005434408263	20264	Economy	4000.00
0005434408517	20264	Economy	4000.00
0005434408330	20264	Economy	4000.00
0005434408890	27012	Business	12000.00
0005434408880	27012	Business	12000.00
0005434408884	27012	Business	12000.00
0005434408853	27012	Business	12000.00
0005435311127	27012	Business	12000.00
0005432154061	27012	Business	12000.00
0005434408900	27012	Business	12000.00
0005434408845	27012	Business	12000.00
0005434408885	27012	Business	12000.00
0005435311126	27012	Business	12000.00
0005432154059	27012	Business	12000.00
0005434408877	27012	Economy	4000.00
0005434408847	27012	Economy	4000.00
0005434408891	27012	Economy	4000.00
0005434408856	27012	Economy	4000.00
0005434408836	27012	Economy	4000.00
0005435311149	27012	Economy	4000.00
0005432154057	27012	Economy	4000.00
0005435311122	27012	Economy	4000.00
0005434408848	27012	Economy	4400.00
0005434408899	27012	Economy	4400.00
0005434408835	27012	Economy	4400.00
0005434408870	27012	Economy	4400.00
0005434408846	27012	Economy	4400.00
0005434408898	27012	Economy	4000.00
0005434408861	27012	Economy	4000.00
0005434408852	27012	Economy	4000.00
0005435311130	27012	Economy	4000.00
0005434408838	27012	Economy	4000.00
0005434408865	27012	Economy	4000.00
0005434408887	27012	Economy	4000.00
0005435311147	27012	Economy	4000.00
0005434408889	27012	Economy	4000.00
0005434408860	27012	Economy	4000.00
0005434408866	27012	Economy	4000.00
0005432154062	27012	Economy	4000.00
0005434408875	27012	Economy	4000.00
0005435311156	27012	Economy	4000.00
0005434408849	27012	Economy	4000.00
0005434408894	27012	Economy	4000.00
0005434408897	27012	Economy	4000.00
0005434408882	27012	Economy	4000.00
0005434408843	27012	Economy	4000.00
0005434408883	27012	Economy	4000.00
0005434408840	27012	Economy	4000.00
0005434408837	27012	Economy	4000.00
0005434408874	27012	Economy	4000.00
0005434408878	27012	Economy	4000.00
0005434408855	27012	Economy	4000.00
0005434408839	27012	Economy	4000.00
0005434408871	27012	Economy	4000.00
0005434408867	27012	Economy	4000.00
0005434408892	27012	Economy	4000.00
0005432154060	27012	Economy	4000.00
0005434408841	27012	Economy	4000.00
0005434408864	27012	Economy	4000.00
0005434408859	27012	Economy	4000.00
0005432154063	27012	Economy	4000.00
0005434408851	27012	Economy	4000.00
0005434408896	27012	Economy	4000.00
0005432154058	27012	Economy	4000.00
0005434408842	27012	Economy	4000.00
0005435311148	27012	Economy	4000.00
0005434408872	27012	Economy	4000.00
0005434408858	27012	Economy	4000.00
0005434408844	27012	Economy	4000.00
0005435311150	27012	Economy	4000.00
0005434408869	27012	Economy	4000.00
0005432154064	27012	Economy	4000.00
0005434408873	27012	Economy	4000.00
0005434408863	27012	Economy	4000.00
0005434408886	27012	Economy	4000.00
0005434408854	27012	Economy	4000.00
0005435311123	27012	Economy	4000.00
0005435311160	27012	Economy	4000.00
0005434408888	27012	Economy	4000.00
0005434408868	27012	Economy	4000.00
0005434408881	27012	Economy	4000.00
0005434408862	27012	Economy	4000.00
0005434408895	27012	Economy	4000.00
0005434408876	27012	Economy	4000.00
0005434408879	27012	Economy	4000.00
0005434408850	27012	Economy	4000.00
0005434408893	27012	Economy	4000.00
0005434408857	27012	Economy	4000.00
0005433124157	5700	Business	43300.00
0005434319631	5700	Business	43300.00
0005432109750	5700	Business	43300.00
0005434311254	5700	Business	43300.00
0005433124054	5700	Business	43300.00
0005432109752	5700	Economy	14400.00
0005433124072	5700	Economy	14400.00
0005433124093	5700	Economy	14400.00
0005433124086	5700	Economy	15900.00
0005432109751	5700	Economy	14400.00
0005434319634	5700	Economy	14400.00
0005433124130	5700	Economy	14400.00
0005433124184	5700	Economy	14400.00
0005433124118	5700	Economy	14400.00
0005433124111	5700	Economy	14400.00
0005433124114	5700	Economy	14400.00
0005433124182	5700	Economy	14400.00
0005433124055	5700	Economy	14400.00
0005433124006	5700	Economy	14400.00
0005434319628	5700	Economy	14400.00
0005434319632	5700	Economy	14400.00
0005433124007	5700	Economy	14400.00
0005434319633	5700	Economy	14400.00
0005434319636	5700	Economy	14400.00
0005433124113	5700	Economy	14400.00
0005433124097	5700	Economy	14400.00
0005433124109	5700	Economy	14400.00
0005433124156	5700	Economy	14400.00
0005433124117	5700	Economy	14400.00
0005433124110	5700	Economy	14400.00
0005433124136	5700	Economy	14400.00
0005434319630	5700	Economy	14400.00
0005433124155	5700	Economy	14400.00
0005434319629	5700	Economy	14400.00
0005434319635	5700	Economy	14400.00
0005433124183	5700	Economy	14400.00
0005434319488	15680	Business	43300.00
0005434319471	15680	Business	43300.00
0005433124290	15680	Business	43300.00
0005434319490	15680	Business	43300.00
0005433124288	15680	Business	43300.00
0005433124289	15680	Business	43300.00
0005434319491	15680	Economy	14400.00
0005433124301	15680	Economy	14400.00
0005434319480	15680	Economy	14400.00
0005433124296	15680	Economy	14400.00
0005434312336	15680	Economy	14400.00
0005434319492	15680	Economy	14400.00
0005434319473	15680	Economy	15900.00
0005433124295	15680	Economy	14400.00
0005433124300	15680	Economy	14400.00
0005434319472	15680	Economy	14400.00
0005433124303	15680	Economy	14400.00
0005433124291	15680	Economy	14400.00
0005433124305	15680	Economy	14400.00
0005434319470	15680	Economy	14400.00
0005433124304	15680	Economy	14400.00
0005433124287	15680	Economy	14400.00
0005433124302	15680	Economy	14400.00
0005433124293	15680	Economy	14400.00
0005433124297	15680	Economy	14400.00
0005434319481	15680	Economy	14400.00
0005433124292	15680	Economy	14400.00
0005434312329	15680	Economy	14400.00
0005434319482	15680	Economy	14400.00
0005433124286	15680	Economy	14400.00
0005434319419	15680	Economy	14400.00
0005433124307	15680	Economy	14400.00
0005434319420	15680	Economy	14400.00
0005433124299	15680	Economy	14400.00
0005434319489	15680	Economy	14400.00
0005434312339	15680	Economy	14400.00
0005434312337	15680	Economy	14400.00
0005433124306	15680	Economy	14400.00
0005433124298	15680	Economy	14400.00
0005433124285	15680	Economy	14400.00
0005434312338	15680	Economy	14400.00
0005433124294	15680	Economy	14400.00
0005434319469	15680	Economy	14400.00
0005434319500	15680	Economy	14400.00
0005435217729	24978	Economy	15500.00
0005435217730	24978	Economy	15500.00
0005435220326	24978	Economy	15500.00
0005435220332	24978	Economy	15500.00
0005435220345	24978	Economy	15500.00
0005435220327	24978	Economy	15500.00
0005435220329	24978	Economy	15500.00
0005435220331	24978	Economy	15500.00
0005435220324	24978	Economy	15500.00
0005435221523	24978	Economy	15500.00
0005435220333	24978	Economy	15500.00
0005435217728	24978	Economy	15500.00
0005434484463	8993	Economy	24900.00
0005434484461	8993	Economy	24900.00
0005434484464	8993	Economy	24900.00
0005434189230	8993	Economy	24900.00
0005434484466	8993	Economy	24900.00
0005434189231	8993	Economy	24900.00
0005434484460	8993	Economy	24900.00
0005434484462	8993	Economy	24900.00
0005434484465	8993	Economy	24900.00
0005434484431	16623	Economy	24900.00
0005434484430	16623	Economy	24900.00
0005434189280	16623	Economy	24900.00
0005434189277	16623	Economy	24900.00
0005434189281	16623	Economy	24900.00
0005434484393	16623	Economy	24900.00
0005434189282	16623	Economy	24900.00
0005434484437	16623	Economy	24900.00
0005434189279	16623	Economy	24900.00
0005434484392	16623	Economy	24900.00
0005434189278	16623	Economy	24900.00
0005434484421	16623	Economy	24900.00
0005433124287	7654	Business	11100.00
0005433124288	7654	Business	11100.00
0005433124299	7654	Business	11100.00
0005433124307	7654	Business	11100.00
0005433124291	7654	Economy	3700.00
0005433124306	7654	Economy	3700.00
0005433124292	7654	Economy	3700.00
0005433124297	7654	Economy	4100.00
0005433124295	7654	Economy	3700.00
0005433124303	7654	Economy	3700.00
0005433124304	7654	Economy	3700.00
0005433124290	7654	Economy	3700.00
0005433124289	7654	Economy	3700.00
0005433124296	7654	Economy	3700.00
0005433124286	7654	Economy	3700.00
0005433124302	7654	Economy	3700.00
0005433124298	7654	Economy	3700.00
0005433124300	7654	Economy	3700.00
0005433124293	7654	Economy	3700.00
0005433124294	7654	Economy	3700.00
0005433124305	7654	Economy	3700.00
0005433124301	7654	Economy	3700.00
0005433124285	7654	Economy	3700.00
0005432693601	7655	Business	11100.00
0005432693603	7655	Business	11100.00
0005432071627	7655	Business	11100.00
0005433450346	7655	Business	11100.00
0005432693615	7655	Business	11100.00
0005433450351	7655	Business	11100.00
0005433450350	7655	Business	11100.00
0005432071626	7655	Business	11100.00
0005433450352	7655	Business	11100.00
0005432693619	7655	Economy	3700.00
0005432721365	7655	Economy	3700.00
0005432693616	7655	Economy	3700.00
0005433450360	7655	Economy	3700.00
0005432693608	7655	Economy	3700.00
0005432693624	7655	Economy	3700.00
0005432721377	7655	Economy	3700.00
0005433450353	7655	Economy	3700.00
0005433450356	7655	Economy	3700.00
0005432721367	7655	Economy	4100.00
0005432693613	7655	Economy	4100.00
0005432693609	7655	Economy	4100.00
0005433450358	7655	Economy	4100.00
0005433450354	7655	Economy	4100.00
0005432693622	7655	Economy	3700.00
0005432071624	7655	Economy	3700.00
0005432071625	7655	Economy	3700.00
0005432693621	7655	Economy	3700.00
0005433450344	7655	Economy	3700.00
0005432693606	7655	Economy	3700.00
0005433450348	7655	Economy	3700.00
0005432693625	7655	Economy	3700.00
0005432721366	7655	Economy	3700.00
0005432721363	7655	Economy	3700.00
0005432693623	7655	Economy	3700.00
0005432721376	7655	Economy	3700.00
0005432721364	7655	Economy	3700.00
0005432693628	7655	Economy	3700.00
0005432721378	7655	Economy	3700.00
0005433450357	7655	Economy	3700.00
0005432721381	7655	Economy	3700.00
0005432721386	7655	Economy	3700.00
0005432693610	7655	Economy	3700.00
0005432721371	7655	Economy	3700.00
0005432693627	7655	Economy	3700.00
0005432693605	7655	Economy	3700.00
0005432721375	7655	Economy	3700.00
0005432721373	7655	Economy	3700.00
0005433450359	7655	Economy	3700.00
0005432721384	7655	Economy	3700.00
0005432721385	7655	Economy	3700.00
0005432693620	7655	Economy	3700.00
0005432721382	7655	Economy	3700.00
0005432721389	7655	Economy	3700.00
0005433450345	7655	Economy	3700.00
0005433450355	7655	Economy	3700.00
0005432693600	7655	Economy	3700.00
0005432693602	7655	Economy	3700.00
0005432693630	7655	Economy	3700.00
0005432721370	7655	Economy	3700.00
0005433450362	7655	Economy	3700.00
0005432693632	7655	Economy	3700.00
0005432693618	7655	Economy	3700.00
0005432693607	7655	Economy	3700.00
0005432693631	7655	Economy	3700.00
0005432693611	7655	Economy	3700.00
0005432721372	7655	Economy	3700.00
0005432721383	7655	Economy	3700.00
0005432721369	7655	Economy	3700.00
0005433450343	7655	Economy	3700.00
0005432721368	7655	Economy	3700.00
0005433450349	7655	Economy	3700.00
0005432693612	7655	Economy	3700.00
0005432693604	7655	Economy	3700.00
0005432693617	7655	Economy	3700.00
0005432721387	7655	Economy	3700.00
0005432721380	7655	Economy	3700.00
0005432721374	7655	Economy	3700.00
0005432693629	7655	Economy	3700.00
0005433450361	7655	Economy	3700.00
0005432693626	7655	Economy	3700.00
0005433450347	7655	Economy	3700.00
0005432693614	7655	Economy	3700.00
0005432721379	7655	Economy	3700.00
0005432721388	7655	Economy	3700.00
0005432693322	30395	Business	11100.00
0005433450165	30395	Business	11100.00
0005433450175	30395	Business	11100.00
0005433450060	30395	Business	11100.00
0005432693211	30395	Economy	3700.00
0005433450189	30395	Economy	3700.00
0005432693321	30395	Economy	3700.00
0005433450183	30395	Economy	3700.00
0005432693393	30395	Economy	3700.00
0005432693257	30395	Economy	3700.00
0005433450240	30395	Economy	3700.00
0005432693244	30395	Economy	4100.00
0005433450180	30395	Economy	4100.00
0005432693363	30395	Economy	4100.00
0005433450151	30395	Economy	4100.00
0005433450213	30395	Economy	3700.00
0005433450200	30395	Economy	3700.00
0005433450226	30395	Economy	3700.00
0005433450101	30395	Economy	3700.00
0005432693245	30395	Economy	3700.00
0005433450214	30395	Economy	3700.00
0005433450130	30395	Economy	3700.00
0005433450163	30395	Economy	3700.00
0005433450156	30395	Economy	3700.00
0005433450159	30395	Economy	3700.00
0005432693391	30395	Economy	3700.00
0005432693338	30395	Economy	3700.00
0005432693238	30395	Economy	3700.00
0005433450169	30395	Economy	3700.00
0005433450172	30395	Economy	3700.00
0005433450184	30395	Economy	3700.00
0005433450164	30395	Economy	3700.00
0005433450170	30395	Economy	3700.00
0005432693329	30395	Economy	3700.00
0005433450150	30395	Economy	3700.00
0005433450152	30395	Economy	3700.00
0005432693366	30395	Economy	3700.00
0005433450227	30395	Economy	3700.00
0005433450261	30395	Economy	3700.00
0005432693398	30395	Economy	3700.00
0005432693261	30395	Economy	3700.00
0005433450202	30395	Economy	3700.00
0005432693349	30395	Economy	3700.00
0005433450181	30395	Economy	3700.00
0005432693399	30395	Economy	3700.00
0005432693413	30395	Economy	3700.00
0005433450262	30395	Economy	3700.00
0005433450201	30395	Economy	3700.00
0005433450179	30395	Economy	3700.00
0005432693286	30395	Economy	3700.00
0005433450099	30395	Economy	3700.00
0005432693367	30395	Economy	3700.00
0005433450225	30395	Economy	3700.00
0005432693330	30395	Economy	3700.00
0005432693285	30395	Economy	3700.00
0005433124113	30396	Business	11100.00
0005432721173	30396	Business	11100.00
0005432721109	30396	Business	11100.00
0005433124114	30396	Business	11100.00
0005432721054	30396	Business	11100.00
0005432721113	30396	Economy	3700.00
0005433124157	30396	Economy	3700.00
0005433124054	30396	Economy	3700.00
0005433124183	30396	Economy	3700.00
0005433124110	30396	Economy	3700.00
0005432721075	30396	Economy	3700.00
0005432721110	30396	Economy	4100.00
0005433124007	30396	Economy	4100.00
0005433124182	30396	Economy	4100.00
0005432721074	30396	Economy	4100.00
0005433124155	30396	Economy	4100.00
0005432721272	30396	Economy	3700.00
0005432721160	30396	Economy	3700.00
0005433722341	30396	Economy	3700.00
0005432721139	30396	Economy	3700.00
0005433722342	30396	Economy	3700.00
0005432721048	30396	Economy	3700.00
0005433722340	30396	Economy	3700.00
0005432721273	30396	Economy	3700.00
0005433124156	30396	Economy	3700.00
0005433124184	30396	Economy	3700.00
0005432721188	30396	Economy	3700.00
0005433124117	30396	Economy	3700.00
0005432721181	30396	Economy	3700.00
0005433124111	30396	Economy	3700.00
0005433124093	30396	Economy	3700.00
0005432721182	30396	Economy	3700.00
0005433124006	30396	Economy	3700.00
0005433722338	30396	Economy	3700.00
0005432721144	30396	Economy	3700.00
0005433124086	30396	Economy	3700.00
0005432721186	30396	Economy	3700.00
0005432721134	30396	Economy	3700.00
0005432721242	30396	Economy	3700.00
0005432721195	30396	Economy	3700.00
0005433722337	30396	Economy	3700.00
0005433124055	30396	Economy	3700.00
0005432721131	30396	Economy	3700.00
0005433722339	30396	Economy	3700.00
0005433124130	30396	Economy	3700.00
0005432721205	30396	Economy	3700.00
0005432721043	30396	Economy	3700.00
0005432721194	30396	Economy	3700.00
0005432721132	30396	Economy	3700.00
0005433124072	30396	Economy	3700.00
0005432721044	30396	Economy	3700.00
0005433124109	30396	Economy	3700.00
0005433124136	30396	Economy	3700.00
0005433124097	30396	Economy	3700.00
0005433124118	30396	Economy	3700.00
0005433525235	1356	Business	70400.00
0005434513627	1356	Business	70400.00
0005433525230	1356	Business	70400.00
0005434587072	1356	Business	70400.00
0005433724888	1356	Business	70400.00
0005434587077	1356	Business	70400.00
0005434587064	1356	Business	70400.00
0005434587055	1356	Business	70400.00
0005432271057	1356	Economy	23500.00
0005433193155	1356	Economy	23500.00
0005434587061	1356	Economy	23500.00
0005432928034	1356	Economy	23500.00
0005433525227	1356	Economy	23500.00
0005432928045	1356	Economy	23500.00
0005433193156	1356	Economy	25800.00
0005433525228	1356	Economy	25800.00
0005434587059	1356	Economy	25800.00
0005433724887	1356	Economy	23500.00
0005434513626	1356	Economy	23500.00
0005434587056	1356	Economy	23500.00
0005434587073	1356	Economy	23500.00
0005433525231	1356	Economy	23500.00
0005434587070	1356	Economy	23500.00
0005432271056	1356	Economy	23500.00
0005434515014	1356	Economy	23500.00
0005434587063	1356	Economy	23500.00
0005434587060	1356	Economy	23500.00
0005433525234	1356	Economy	23500.00
0005434587058	1356	Economy	23500.00
0005434587069	1356	Economy	23500.00
0005434587075	1356	Economy	23500.00
0005433525226	1356	Economy	23500.00
0005434587052	1356	Economy	23500.00
0005432271055	1356	Economy	23500.00
0005433525232	1356	Economy	23500.00
0005433193180	1356	Economy	23500.00
0005432928056	1356	Economy	23500.00
0005434587065	1356	Economy	23500.00
0005434587054	1356	Economy	23500.00
0005434587076	1356	Economy	23500.00
0005433724889	1356	Economy	23500.00
0005432928032	1356	Economy	23500.00
0005434587057	1356	Economy	23500.00
0005434515015	1356	Economy	23500.00
0005433193273	1356	Economy	23500.00
0005432928025	1356	Economy	23500.00
0005434587067	1356	Economy	23500.00
0005433724886	1356	Economy	23500.00
0005434587071	1356	Economy	23500.00
0005434587068	1356	Economy	23500.00
0005434587074	1356	Economy	23500.00
0005433525233	1356	Economy	23500.00
0005432928063	1356	Economy	23500.00
0005433193218	1356	Economy	23500.00
0005434587062	1356	Economy	23500.00
0005434587053	1356	Economy	23500.00
0005432928030	1356	Economy	23500.00
0005433193181	1356	Economy	23500.00
0005434515013	1356	Economy	23500.00
0005433525225	1356	Economy	23500.00
0005434587066	1356	Economy	23500.00
0005433724885	1356	Economy	23500.00
0005433525229	1356	Economy	23500.00
0005432928075	18534	Business	70400.00
0005434586938	18534	Business	70400.00
0005433525147	18534	Business	70400.00
0005433193282	18534	Business	70400.00
0005433724853	18534	Business	70400.00
0005434586945	18534	Business	70400.00
0005434586873	18534	Business	70400.00
0005434586893	18534	Business	70400.00
0005434586822	18534	Business	70400.00
0005434586848	18534	Economy	23500.00
0005433193277	18534	Economy	23500.00
0005434586834	18534	Economy	23500.00
0005433525163	18534	Economy	23500.00
0005433525119	18534	Economy	23500.00
0005432928076	18534	Economy	23500.00
0005434586750	18534	Economy	23500.00
0005433525148	18534	Economy	25800.00
0005434586937	18534	Economy	25800.00
0005434586764	18534	Economy	25800.00
0005433525118	18534	Economy	25800.00
0005434586749	18534	Economy	25800.00
0005434586858	18534	Economy	23500.00
0005432968879	18534	Economy	23500.00
0005434586855	18534	Economy	23500.00
0005433193275	18534	Economy	23500.00
0005433525141	18534	Economy	23500.00
0005433193283	18534	Economy	23500.00
0005434586889	18534	Economy	23500.00
0005434586861	18534	Economy	23500.00
0005434586944	18534	Economy	23500.00
0005434586745	18534	Economy	23500.00
0005433724836	18534	Economy	23500.00
0005434586802	18534	Economy	23500.00
0005433525088	18534	Economy	23500.00
0005433193276	18534	Economy	23500.00
0005434586872	18534	Economy	23500.00
0005433193287	18534	Economy	23500.00
0005434586774	18534	Economy	23500.00
0005433193280	18534	Economy	23500.00
0005434586733	18534	Economy	23500.00
0005433525120	18534	Economy	23500.00
0005433724831	18534	Economy	23500.00
0005433193274	18534	Economy	23500.00
0005433193281	18534	Economy	23500.00
0005434586854	18534	Economy	23500.00
0005433193285	18534	Economy	23500.00
0005434586910	18534	Economy	23500.00
0005433193286	18534	Economy	23500.00
0005433193279	18534	Economy	23500.00
0005433193284	18534	Economy	23500.00
0005434586907	18534	Economy	23500.00
0005432928078	18534	Economy	23500.00
0005434586775	18534	Economy	23500.00
0005434586888	18534	Economy	23500.00
0005434586801	18534	Economy	23500.00
0005433193278	18534	Economy	23500.00
0005434586763	18534	Economy	23500.00
0005433525117	18534	Economy	23500.00
0005434586909	18534	Economy	23500.00
0005434586803	18534	Economy	23500.00
0005432928079	18534	Economy	23500.00
0005434586843	18534	Economy	23500.00
0005433724837	18534	Economy	23500.00
0005434586849	18534	Economy	23500.00
0005434586812	18534	Economy	23500.00
0005434586842	18534	Economy	23500.00
0005434586811	18534	Economy	23500.00
0005434586857	18534	Economy	23500.00
0005434586816	18534	Economy	23500.00
0005432928077	18534	Economy	23500.00
0005433724817	18534	Economy	23500.00
0005432968880	18534	Economy	23500.00
0005433193288	18534	Economy	23500.00
0005433525131	18534	Economy	23500.00
0005434586815	18534	Economy	23500.00
0005433525132	18534	Economy	23500.00
0005433525089	18534	Economy	23500.00
0005433525151	18534	Economy	23500.00
0005434344812	11449	Economy	4300.00
0005434344809	11449	Economy	4300.00
0005435305034	11449	Economy	4300.00
0005434344807	11449	Economy	4300.00
0005434344808	11449	Economy	4000.00
0005434344804	11449	Economy	4000.00
0005434344801	11449	Economy	4000.00
0005435305027	11449	Economy	4000.00
0005435302242	11449	Economy	4000.00
0005434344793	11449	Economy	4000.00
0005434344797	11449	Economy	4000.00
0005435302237	11449	Economy	4000.00
0005434344800	11449	Economy	4000.00
0005435302244	11449	Economy	4000.00
0005434344813	11449	Economy	4000.00
0005434344803	11449	Economy	4000.00
0005435302243	11449	Economy	4000.00
0005434344806	11449	Economy	4000.00
0005434344786	11449	Economy	4000.00
0005434344783	11449	Economy	4000.00
0005434344819	11449	Economy	4000.00
0005434344816	11449	Economy	4000.00
0005434344789	11449	Economy	4000.00
0005434344815	11449	Economy	4000.00
0005434344805	11449	Economy	4000.00
0005434344791	11449	Economy	4000.00
0005434344811	11449	Economy	4000.00
0005434344798	11449	Economy	4000.00
0005434344802	11449	Economy	4000.00
0005434344787	11449	Economy	4000.00
0005434344795	11449	Economy	4000.00
0005434344799	11449	Economy	4000.00
0005434344794	11449	Economy	4000.00
0005434142682	11449	Economy	4000.00
0005434344818	11449	Economy	4000.00
0005434344785	11449	Economy	4000.00
0005434344796	11449	Economy	4000.00
0005434142678	11449	Economy	4000.00
0005434344814	11449	Economy	4000.00
0005434142680	11449	Economy	4000.00
0005434344782	11449	Economy	4000.00
0005434142681	11449	Economy	4000.00
0005434344788	11449	Economy	4000.00
0005434344784	11449	Economy	4000.00
0005434344792	11449	Economy	4000.00
0005434344810	11449	Economy	4000.00
0005434142679	11449	Economy	4000.00
0005435302238	11449	Economy	4000.00
0005434344817	11449	Economy	4000.00
0005434344790	11449	Economy	4000.00
0005434344477	29756	Economy	4300.00
0005434344545	29756	Economy	4300.00
0005434344570	29756	Economy	4300.00
0005434344595	29756	Economy	4300.00
0005435304235	29756	Economy	4000.00
0005434344474	29756	Economy	4000.00
0005434344429	29756	Economy	4000.00
0005435304236	29756	Economy	4000.00
0005434344484	29756	Economy	4000.00
0005434344350	29756	Economy	4000.00
0005434344504	29756	Economy	4000.00
0005434142631	29756	Economy	4000.00
0005435304233	29756	Economy	4000.00
0005434344591	29756	Economy	4000.00
0005434344476	29756	Economy	4000.00
0005434344615	29756	Economy	4000.00
0005434142640	29756	Economy	4000.00
0005434344396	29756	Economy	4000.00
0005435304234	29756	Economy	4000.00
0005434344444	29756	Economy	4000.00
0005434344565	29756	Economy	4000.00
0005434344549	29756	Economy	4000.00
0005434142632	29756	Economy	4000.00
0005434344465	29756	Economy	4000.00
0005435304232	29756	Economy	4000.00
0005434344556	29756	Economy	4000.00
0005434344482	29756	Economy	4000.00
0005434344439	29756	Economy	4000.00
0005434344564	29756	Economy	4000.00
0005434344557	29756	Economy	4000.00
0005434344540	29756	Economy	4000.00
0005434344536	29756	Economy	4000.00
0005434344351	29756	Economy	4000.00
0005434142648	29756	Economy	4000.00
0005434344473	29756	Economy	4000.00
0005434344535	29756	Economy	4000.00
0005434344554	29756	Economy	4000.00
0005434344353	29756	Economy	4000.00
0005434344509	29756	Economy	4000.00
0005434344534	29756	Economy	4000.00
0005434344590	29756	Economy	4000.00
0005434344555	29756	Economy	4000.00
0005434344553	29756	Economy	4000.00
0005434344531	29756	Economy	4000.00
0005434344464	29756	Economy	4000.00
0005434344483	29756	Economy	4000.00
0005434344443	29756	Economy	4000.00
0005434344385	29756	Economy	4000.00
0005435305048	29756	Economy	4000.00
0005434344532	29756	Economy	4000.00
0005435825085	1283	Business	199800.00
0005435825105	1283	Business	199800.00
0005435825111	1283	Business	199800.00
0005435825102	1283	Business	199800.00
0005435825087	1283	Business	199800.00
0005433415807	1283	Business	199800.00
0005432284610	1283	Business	199800.00
0005435825099	1283	Economy	66600.00
0005433415838	1283	Economy	66600.00
0005435825104	1283	Economy	73200.00
0005435825108	1283	Economy	73200.00
0005435825101	1283	Economy	66600.00
0005433415825	1283	Economy	73200.00
0005435825097	1283	Economy	66600.00
0005435825093	1283	Economy	66600.00
0005435825106	1283	Economy	66600.00
0005435825109	1283	Economy	66600.00
0005433415818	1283	Economy	66600.00
0005433415808	1283	Economy	66600.00
0005435825098	1283	Economy	66600.00
0005435825088	1283	Economy	66600.00
0005433415809	1283	Economy	66600.00
0005435825095	1283	Economy	66600.00
0005435825107	1283	Economy	66600.00
0005435825110	1283	Economy	66600.00
0005435825103	1283	Economy	66600.00
0005435825094	1283	Economy	66600.00
0005433415859	1283	Economy	66600.00
0005435825091	1283	Economy	66600.00
0005435825100	1283	Economy	66600.00
0005435825112	1283	Economy	66600.00
0005435825086	1283	Economy	66600.00
0005435825096	1283	Economy	66600.00
0005433415839	1283	Economy	66600.00
0005433415819	1283	Economy	66600.00
0005432284611	1283	Economy	66600.00
0005435825089	1283	Economy	66600.00
0005435825090	1283	Economy	66600.00
0005435825092	1283	Economy	66600.00
0005433415936	18017	Business	199800.00
0005433415948	18017	Business	199800.00
0005433415939	18017	Business	199800.00
0005435824920	18017	Business	199800.00
0005435824913	18017	Business	199800.00
0005433415943	18017	Economy	66600.00
0005435824866	18017	Economy	66600.00
0005433415935	18017	Economy	66600.00
0005435824853	18017	Economy	66600.00
0005433415940	18017	Economy	66600.00
0005435824956	18017	Economy	66600.00
0005435824896	18017	Economy	73200.00
0005435824903	18017	Economy	73200.00
0005435824762	18017	Economy	66600.00
0005435824957	18017	Economy	66600.00
0005433415944	18017	Economy	66600.00
0005433415947	18017	Economy	66600.00
0005433415945	18017	Economy	66600.00
0005433415932	18017	Economy	66600.00
0005435824834	18017	Economy	66600.00
0005435824902	18017	Economy	66600.00
0005433415934	18017	Economy	66600.00
0005433415933	18017	Economy	66600.00
0005435824811	18017	Economy	66600.00
0005433415942	18017	Economy	66600.00
0005435824908	18017	Economy	66600.00
0005435824919	18017	Economy	66600.00
0005435824898	18017	Economy	66600.00
0005435824810	18017	Economy	66600.00
0005433415946	18017	Economy	66600.00
0005435824875	18017	Economy	66600.00
0005435824897	18017	Economy	66600.00
0005435824967	18017	Economy	66600.00
0005435824833	18017	Economy	66600.00
0005433415937	18017	Economy	66600.00
0005433415938	18017	Economy	66600.00
0005435824729	18017	Economy	66600.00
0005435824895	18017	Economy	66600.00
0005433415941	18017	Economy	66600.00
0005435824856	18017	Economy	66600.00
0005435824832	18017	Economy	66600.00
0005434460517	17523	Economy	14800.00
0005434462797	17523	Economy	13500.00
0005434462807	17523	Economy	13500.00
0005434460524	17523	Economy	13500.00
0005434460521	17523	Economy	13500.00
0005434462810	17523	Economy	13500.00
0005434462804	17523	Economy	13500.00
0005434460526	17523	Economy	13500.00
0005434462795	17523	Economy	13500.00
0005434462796	17523	Economy	13500.00
0005434460500	17523	Economy	13500.00
0005434462806	17523	Economy	13500.00
0005434460522	17523	Economy	13500.00
0005434462808	17523	Economy	13500.00
0005434462799	17523	Economy	13500.00
0005432784745	5616	Business	27800.00
0005435243040	5616	Business	27800.00
0005432144045	5616	Business	27800.00
0005432784732	5616	Business	27800.00
0005432784723	5616	Business	27800.00
0005435243042	5616	Business	27800.00
0005432784747	5616	Business	27800.00
0005432784744	5616	Business	27800.00
0005435243130	5616	Business	27800.00
0005432784722	5616	Business	27800.00
0005432784738	5616	Economy	9300.00
0005432784730	5616	Economy	9300.00
0005432784752	5616	Economy	9300.00
0005435476819	5616	Economy	9300.00
0005432784739	5616	Economy	9300.00
0005432784726	5616	Economy	9300.00
0005435476837	5616	Economy	9300.00
0005432784724	5616	Economy	9300.00
0005432784741	5616	Economy	9300.00
0005432784720	5616	Economy	9300.00
0005432784712	5616	Economy	10200.00
0005432784735	5616	Economy	10200.00
0005432784763	5616	Economy	10200.00
0005435243096	5616	Economy	10200.00
0005435243106	5616	Economy	9300.00
0005432784728	5616	Economy	9300.00
0005435243076	5616	Economy	9300.00
0005432784717	5616	Economy	9300.00
0005432784751	5616	Economy	9300.00
0005432784719	5616	Economy	9300.00
0005435243201	5616	Economy	9300.00
0005432784765	5616	Economy	9300.00
0005432784718	5616	Economy	9300.00
0005432784748	5616	Economy	9300.00
0005435243119	5616	Economy	9300.00
0005432784737	5616	Economy	9300.00
0005435243045	5616	Economy	9300.00
0005432784760	5616	Economy	9300.00
0005432784757	5616	Economy	9300.00
0005435243177	5616	Economy	9300.00
0005435243159	5616	Economy	9300.00
0005435243120	5616	Economy	9300.00
0005435243089	5616	Economy	9300.00
0005435243006	5616	Economy	9300.00
0005432784736	5616	Economy	9300.00
0005432784734	5616	Economy	9300.00
0005435243039	5616	Economy	9300.00
0005432784764	5616	Economy	9300.00
0005435476825	5616	Economy	9300.00
0005432784711	5616	Economy	9300.00
0005435243090	5616	Economy	9300.00
0005432784716	5616	Economy	9300.00
0005432144044	5616	Economy	9300.00
0005432784714	5616	Economy	9300.00
0005435243041	5616	Economy	9300.00
0005432784746	5616	Economy	9300.00
0005432784725	5616	Economy	9300.00
0005432784715	5616	Economy	9300.00
0005435476776	5616	Economy	9300.00
0005435243109	5616	Economy	9300.00
0005432784754	5616	Economy	9300.00
0005432784762	5616	Economy	9300.00
0005432784742	5616	Economy	9300.00
0005435476788	5616	Economy	9300.00
0005432784755	5616	Economy	9300.00
0005432784749	5616	Economy	9300.00
0005435476777	5616	Economy	9300.00
0005432784733	5616	Economy	9300.00
0005432784766	5616	Economy	9300.00
0005435243097	5616	Economy	9300.00
0005432784759	5616	Economy	9300.00
0005432784727	5616	Economy	9300.00
0005432784731	5616	Economy	9300.00
0005435242916	5616	Economy	9300.00
0005432784721	5616	Economy	9300.00
0005432784753	5616	Economy	9300.00
0005432784761	5616	Economy	9300.00
0005435243095	5616	Economy	9300.00
0005435243158	5616	Economy	9300.00
0005432784729	5616	Economy	9300.00
0005432784740	5616	Economy	9300.00
0005432144046	5616	Economy	9300.00
0005435243051	5616	Economy	9300.00
0005432784758	5616	Economy	9300.00
0005435476836	5616	Economy	9300.00
0005432784743	5616	Economy	9300.00
0005432784750	5616	Economy	9300.00
0005432784756	5616	Economy	9300.00
0005432784713	5616	Economy	9300.00
0005435476871	15355	Business	27800.00
0005432784017	15355	Business	27800.00
0005435243299	15355	Business	27800.00
0005432784032	15355	Business	27800.00
0005432784310	15355	Business	27800.00
0005432784348	15355	Business	27800.00
0005435476882	15355	Business	27800.00
0005435243307	15355	Business	27800.00
0005432784284	15355	Business	27800.00
0005435243305	15355	Business	27800.00
0005432784054	15355	Business	27800.00
0005432784170	15355	Economy	9300.00
0005432784033	15355	Economy	9300.00
0005435476880	15355	Economy	9300.00
0005432784108	15355	Economy	9300.00
0005432783925	15355	Economy	9300.00
0005432784082	15355	Economy	9300.00
0005432784118	15355	Economy	9300.00
0005435476875	15355	Economy	9300.00
0005432784347	15355	Economy	9300.00
0005435476872	15355	Economy	10200.00
0005435243308	15355	Economy	10200.00
0005432784321	15355	Economy	10200.00
0005432784220	15355	Economy	10200.00
0005435243316	15355	Economy	10200.00
0005435243295	15355	Economy	9300.00
0005432784237	15355	Economy	9300.00
0005432784208	15355	Economy	9300.00
0005432784311	15355	Economy	9300.00
0005435476877	15355	Economy	9300.00
0005435243315	15355	Economy	9300.00
0005435243303	15355	Economy	9300.00
0005435243309	15355	Economy	9300.00
0005435243296	15355	Economy	9300.00
0005432784201	15355	Economy	9300.00
0005432783924	15355	Economy	9300.00
0005435243291	15355	Economy	9300.00
0005432784132	15355	Economy	9300.00
0005435243313	15355	Economy	9300.00
0005435243293	15355	Economy	9300.00
0005435243314	15355	Economy	9300.00
0005435476870	15355	Economy	9300.00
0005435243297	15355	Economy	9300.00
0005435243292	15355	Economy	9300.00
0005435243317	15355	Economy	9300.00
0005435476874	15355	Economy	9300.00
0005432784136	15355	Economy	9300.00
0005435243289	15355	Economy	9300.00
0005432784106	15355	Economy	9300.00
0005435243310	15355	Economy	9300.00
0005435243302	15355	Economy	9300.00
0005435243298	15355	Economy	9300.00
0005435243304	15355	Economy	9300.00
0005435243311	15355	Economy	9300.00
0005432784194	15355	Economy	9300.00
0005432784257	15355	Economy	9300.00
0005432784251	15355	Economy	9300.00
0005432784436	15355	Economy	9300.00
0005432784253	15355	Economy	9300.00
0005432784410	15355	Economy	9300.00
0005435476879	15355	Economy	9300.00
0005432784309	15355	Economy	9300.00
0005432784218	15355	Economy	9300.00
0005432784477	15355	Economy	9300.00
0005432784370	15355	Economy	9300.00
0005435476878	15355	Economy	9300.00
0005435476876	15355	Economy	9300.00
0005435476869	15355	Economy	9300.00
0005432784016	15355	Economy	9300.00
0005435243301	15355	Economy	9300.00
0005432784488	15355	Economy	9300.00
0005435243312	15355	Economy	9300.00
0005432784083	15355	Economy	9300.00
0005432784268	15355	Economy	9300.00
0005432784285	15355	Economy	9300.00
0005435243306	15355	Economy	9300.00
0005435476873	15355	Economy	9300.00
0005432784200	15355	Economy	9300.00
0005432784131	15355	Economy	9300.00
0005435243294	15355	Economy	9300.00
0005432784478	15355	Economy	9300.00
0005432784015	15355	Economy	9300.00
0005432784199	15355	Economy	9300.00
0005432784290	15355	Economy	9300.00
0005432784196	15355	Economy	9300.00
0005432784123	15355	Economy	9300.00
0005432784207	15355	Economy	9300.00
0005432784119	15355	Economy	9300.00
0005435243300	15355	Economy	9300.00
0005435243290	15355	Economy	9300.00
0005432784219	15355	Economy	9300.00
0005435476881	15355	Economy	9300.00
0005435851008	4351	Economy	7000.00
0005435851001	4351	Economy	7000.00
0005435851053	4351	Economy	7000.00
0005435850982	4351	Economy	6300.00
0005432848571	4351	Economy	6300.00
0005435851030	4351	Economy	6300.00
0005432848563	4351	Economy	6300.00
0005435851031	4351	Economy	6300.00
0005435850993	4351	Economy	6300.00
0005435850999	4351	Economy	6300.00
0005435850967	4351	Economy	6300.00
0005435851032	4351	Economy	6300.00
0005432848564	4351	Economy	6300.00
0005432848568	4351	Economy	6300.00
0005432848572	4351	Economy	6300.00
0005434462828	4351	Economy	6300.00
0005432848561	4351	Economy	6300.00
0005434462827	4351	Economy	6300.00
0005435850989	4351	Economy	6300.00
0005435851020	4351	Economy	6300.00
0005432848573	4351	Economy	6300.00
0005435851022	4351	Economy	6300.00
0005432848566	4351	Economy	6300.00
0005432848574	4351	Economy	6300.00
0005434462829	4351	Economy	6300.00
0005432848560	4351	Economy	6300.00
0005435851007	4351	Economy	6300.00
0005435851019	4351	Economy	6300.00
0005435850977	4351	Economy	6300.00
0005435851000	4351	Economy	6300.00
0005435850987	4351	Economy	6300.00
0005432848562	4351	Economy	6300.00
0005435850986	4351	Economy	6300.00
0005432848565	4351	Economy	6300.00
0005432848567	4351	Economy	6300.00
0005435850921	4351	Economy	6300.00
0005435850983	4351	Economy	6300.00
0005432848570	4351	Economy	6300.00
0005435850978	4351	Economy	6300.00
0005432848569	4351	Economy	6300.00
0005432848472	28863	Economy	7000.00
0005432848436	28863	Economy	7000.00
0005432848448	28863	Economy	6300.00
0005432848465	28863	Economy	6300.00
0005435851074	28863	Economy	6300.00
0005435851067	28863	Economy	6300.00
0005432848466	28863	Economy	6300.00
0005435851066	28863	Economy	6300.00
0005432848477	28863	Economy	6300.00
0005435851071	28863	Economy	6300.00
0005435851072	28863	Economy	6300.00
0005435851073	28863	Economy	6300.00
0005434463946	28863	Economy	6300.00
0005435851069	28863	Economy	6300.00
0005432848473	28863	Economy	6300.00
0005434463941	28863	Economy	6300.00
0005432848425	28863	Economy	6300.00
0005434463951	28863	Economy	6300.00
0005432848476	28863	Economy	6300.00
0005435851068	28863	Economy	6300.00
0005432848454	28863	Economy	6300.00
0005432848443	28863	Economy	6300.00
0005432848437	28863	Economy	6300.00
0005434463950	28863	Economy	6300.00
0005432848442	28863	Economy	6300.00
0005432848481	28863	Economy	6300.00
0005432848444	28863	Economy	6300.00
0005435851070	28863	Economy	6300.00
0005434926366	6317	Business	11900.00
0005433497511	6317	Business	11900.00
0005433497516	6317	Business	11900.00
0005434443993	6317	Business	11900.00
0005433497527	6317	Business	11900.00
0005433497537	6317	Business	11900.00
0005433497515	6317	Business	11900.00
0005434926343	6317	Business	11900.00
0005434443989	6317	Business	11900.00
0005434444000	6317	Business	11900.00
0005434926354	6317	Economy	4000.00
0005433497536	6317	Economy	4000.00
0005434926360	6317	Economy	4000.00
0005433497523	6317	Economy	4000.00
0005433497520	6317	Economy	4000.00
0005433497519	6317	Economy	4000.00
0005434926347	6317	Economy	4000.00
0005434926346	6317	Economy	4400.00
0005434926368	6317	Economy	4400.00
0005433497530	6317	Economy	4400.00
0005434443992	6317	Economy	4000.00
0005434443996	6317	Economy	4000.00
0005433497534	6317	Economy	4000.00
0005433497532	6317	Economy	4000.00
0005434926370	6317	Economy	4000.00
0005433497518	6317	Economy	4000.00
0005433497524	6317	Economy	4000.00
0005434443997	6317	Economy	4000.00
0005434443988	6317	Economy	4000.00
0005434926358	6317	Economy	4000.00
0005434926353	6317	Economy	4000.00
0005434926355	6317	Economy	4000.00
0005434926356	6317	Economy	4000.00
0005434926367	6317	Economy	4000.00
0005434926364	6317	Economy	4000.00
0005433497525	6317	Economy	4000.00
0005434926351	6317	Economy	4000.00
0005434926361	6317	Economy	4000.00
0005433497535	6317	Economy	4000.00
0005433497517	6317	Economy	4000.00
0005434443999	6317	Economy	4000.00
0005434926344	6317	Economy	4000.00
0005433497512	6317	Economy	4000.00
0005434443998	6317	Economy	4000.00
0005434926350	6317	Economy	4000.00
0005434926359	6317	Economy	4000.00
0005434926352	6317	Economy	4000.00
0005434926365	6317	Economy	4000.00
0005433497508	6317	Economy	4000.00
0005433497531	6317	Economy	4000.00
0005434443986	6317	Economy	4000.00
0005434926362	6317	Economy	4000.00
0005433497528	6317	Economy	4000.00
0005433497538	6317	Economy	4000.00
0005434926363	6317	Economy	4000.00
0005434444003	6317	Economy	4000.00
0005434443990	6317	Economy	4000.00
0005434444002	6317	Economy	4000.00
0005434443987	6317	Economy	4000.00
0005433497513	6317	Economy	4000.00
0005434926357	6317	Economy	4000.00
0005433497510	6317	Economy	4000.00
0005433497533	6317	Economy	4000.00
0005432075292	6317	Economy	4000.00
0005434443991	6317	Economy	4000.00
0005434926348	6317	Economy	4000.00
0005433497522	6317	Economy	4000.00
0005433497509	6317	Economy	4000.00
0005434926369	6317	Economy	4000.00
0005434926345	6317	Economy	4000.00
0005434926349	6317	Economy	4000.00
0005433497529	6317	Economy	4000.00
0005434926371	6317	Economy	4000.00
0005433497514	6317	Economy	4000.00
0005434443995	6317	Economy	4000.00
0005433497521	6317	Economy	4000.00
0005434444001	6317	Economy	4000.00
0005433497526	6317	Economy	4000.00
0005434443994	6317	Economy	4000.00
0005435257398	20424	Economy	4000.00
0005435257397	20424	Economy	4000.00
0005435257394	20424	Economy	4000.00
0005435257396	20424	Economy	4000.00
0005435257395	20424	Economy	4000.00
0005434926060	20404	Business	11900.00
0005434926006	20404	Business	11900.00
0005433497280	20404	Business	11900.00
0005433497137	20404	Business	11900.00
0005434925984	20404	Business	11900.00
0005434926153	20404	Business	11900.00
0005434443740	20404	Business	11900.00
0005433497323	20404	Business	11900.00
0005434926162	20404	Business	11900.00
0005434926014	20404	Business	11900.00
0005433497443	20404	Business	11900.00
0005434443809	20404	Economy	4000.00
0005434443851	20404	Economy	4000.00
0005434443868	20404	Economy	4000.00
0005434926154	20404	Economy	4000.00
0005434926094	20404	Economy	4000.00
0005433497314	20404	Economy	4000.00
0005433497267	20404	Economy	4000.00
0005434443817	20404	Economy	4400.00
0005433497310	20404	Economy	4400.00
0005434926099	20404	Economy	4400.00
0005434443864	20404	Economy	4400.00
0005434443875	20404	Economy	4400.00
0005433497305	20404	Economy	4000.00
0005434443816	20404	Economy	4000.00
0005434926150	20404	Economy	4000.00
0005434926070	20404	Economy	4000.00
0005433497290	20404	Economy	4000.00
0005434926002	20404	Economy	4000.00
0005434926003	20404	Economy	4000.00
0005434443850	20404	Economy	4000.00
0005433497188	20404	Economy	4000.00
0005434925932	20404	Economy	4000.00
0005433497261	20404	Economy	4000.00
0005433497226	20404	Economy	4000.00
0005433497325	20404	Economy	4000.00
0005434926077	20404	Economy	4000.00
0005434443865	20404	Economy	4000.00
0005433497324	20404	Economy	4000.00
0005434443778	20404	Economy	4000.00
0005434925985	20404	Economy	4000.00
0005434926161	20404	Economy	4000.00
0005433497164	20404	Economy	4000.00
0005433497320	20404	Economy	4000.00
0005434926096	20404	Economy	4000.00
0005434926163	20404	Economy	4000.00
0005434926110	20404	Economy	4000.00
0005434926064	20404	Economy	4000.00
0005434926004	20404	Economy	4000.00
0005434925965	20404	Economy	4000.00
0005434925967	20404	Economy	4000.00
0005434926013	20404	Economy	4000.00
0005434443899	20404	Economy	4000.00
0005433497291	20404	Economy	4000.00
0005434926151	20404	Economy	4000.00
0005433497289	20404	Economy	4000.00
0005434443818	20404	Economy	4000.00
0005433497266	20404	Economy	4000.00
0005434443808	20404	Economy	4000.00
0005433497349	20404	Economy	4000.00
0005433497178	20404	Economy	4000.00
0005434926105	20404	Economy	4000.00
0005434925948	20404	Economy	4000.00
0005434926097	20404	Economy	4000.00
0005433497304	20404	Economy	4000.00
0005434926100	20404	Economy	4000.00
0005433497123	20404	Economy	4000.00
0005433497165	20404	Economy	4000.00
0005434926095	20404	Economy	4000.00
0005433497308	20404	Economy	4000.00
0005434443815	20404	Economy	4000.00
0005434925983	20404	Economy	4000.00
0005433497243	20404	Economy	4000.00
0005434926044	20404	Economy	4000.00
0005434443819	20404	Economy	4000.00
0005434925964	20404	Economy	4000.00
0005433497136	20404	Economy	4000.00
0005434443814	20404	Economy	4000.00
0005433497288	20404	Economy	4000.00
0005434443806	20404	Economy	4000.00
0005433497135	20404	Economy	4000.00
0005434926123	20404	Economy	4000.00
0005433497177	20404	Economy	4000.00
0005434443858	20404	Economy	4000.00
0005433497377	20404	Economy	4000.00
0005434443838	20404	Economy	4000.00
0005434443777	20404	Economy	4000.00
0005434443866	20404	Economy	4000.00
0005432784429	12162	Business	41200.00
0005432784294	12162	Business	41200.00
0005432784179	12162	Business	41200.00
0005432784055	12162	Business	41200.00
0005435243320	12162	Business	41200.00
0005432784358	12162	Business	41200.00
0005432784298	12162	Business	41200.00
0005432784190	12162	Business	41200.00
0005432784186	12162	Business	41200.00
0005435243319	12162	Business	41200.00
0005432784271	12162	Economy	13700.00
0005432784384	12162	Economy	13700.00
0005432784205	12162	Economy	13700.00
0005432784369	12162	Economy	13700.00
0005432784537	12162	Economy	13700.00
0005432784339	12162	Economy	13700.00
0005435243321	12162	Economy	13700.00
0005432784412	12162	Economy	13700.00
0005432784299	12162	Economy	13700.00
0005435243335	12162	Economy	15100.00
0005432784265	12162	Economy	15100.00
0005432784280	12162	Economy	15100.00
0005432784404	12162	Economy	15100.00
0005432784349	12162	Economy	15100.00
0005432784261	12162	Economy	13700.00
0005432784210	12162	Economy	13700.00
0005432784228	12162	Economy	13700.00
0005432784209	12162	Economy	13700.00
0005435243337	12162	Economy	13700.00
0005432784160	12162	Economy	13700.00
0005432784452	12162	Economy	13700.00
0005435243330	12162	Economy	13700.00
0005432784411	12162	Economy	13700.00
0005432784461	12162	Economy	13700.00
0005432784181	12162	Economy	13700.00
0005432784362	12162	Economy	13700.00
0005435243322	12162	Economy	13700.00
0005432784166	12162	Economy	13700.00
0005435243326	12162	Economy	13700.00
0005435243331	12162	Economy	13700.00
0005435243327	12162	Economy	13700.00
0005432784191	12162	Economy	13700.00
0005432784307	12162	Economy	13700.00
0005432784262	12162	Economy	13700.00
0005435243342	12162	Economy	13700.00
0005432784182	12162	Economy	13700.00
0005432784515	12162	Economy	13700.00
0005432784693	12162	Economy	13700.00
0005432784379	12162	Economy	13700.00
0005435243332	12162	Economy	13700.00
0005432784243	12162	Economy	13700.00
0005432784245	12162	Economy	13700.00
0005432784385	12162	Economy	13700.00
0005435243324	12162	Economy	13700.00
0005432784244	12162	Economy	13700.00
0005432784501	12162	Economy	13700.00
0005435243318	12162	Economy	13700.00
0005435243343	12162	Economy	13700.00
0005432784281	12162	Economy	13700.00
0005432784316	12162	Economy	13700.00
0005432784375	12162	Economy	13700.00
0005435243323	12162	Economy	13700.00
0005432784502	12162	Economy	13700.00
0005432784383	12162	Economy	13700.00
0005432784360	12162	Economy	13700.00
0005432784356	12162	Economy	13700.00
0005435243339	12162	Economy	13700.00
0005435243338	12162	Economy	13700.00
0005435243334	12162	Economy	13700.00
0005432784229	12162	Economy	13700.00
0005432784308	12162	Economy	13700.00
0005435243333	12162	Economy	13700.00
0005432784206	12162	Economy	13700.00
0005432784401	12162	Economy	13700.00
0005432784371	12162	Economy	13700.00
0005432784276	12162	Economy	13700.00
0005432784269	12162	Economy	13700.00
0005435243344	12162	Economy	13700.00
0005435243328	12162	Economy	13700.00
0005435243329	12162	Economy	13700.00
0005432784359	12162	Economy	13700.00
0005432784340	12162	Economy	13700.00
0005432784514	12162	Economy	13700.00
0005432784270	12162	Economy	13700.00
0005435243336	12162	Economy	13700.00
0005435243340	12162	Economy	13700.00
0005432784325	12162	Economy	13700.00
0005432784372	12162	Economy	13700.00
0005435243325	12162	Economy	13700.00
0005432784482	12162	Economy	13700.00
0005435243341	12162	Economy	13700.00
0005435243044	15448	Business	41200.00
0005432784695	15448	Business	41200.00
0005432784706	15448	Business	41200.00
0005432784668	15448	Business	41200.00
0005435242958	15448	Business	41200.00
0005432784684	15448	Business	41200.00
0005432784663	15448	Business	41200.00
0005432784660	15448	Business	41200.00
0005432784675	15448	Business	41200.00
0005432784674	15448	Business	41200.00
0005432784658	15448	Business	41200.00
0005432784704	15448	Economy	13700.00
0005435243122	15448	Economy	13700.00
0005432784679	15448	Economy	13700.00
0005435243071	15448	Economy	13700.00
0005432784697	15448	Economy	13700.00
0005432784656	15448	Economy	13700.00
0005435242950	15448	Economy	13700.00
0005432784691	15448	Economy	13700.00
0005432784700	15448	Economy	13700.00
0005432784694	15448	Economy	13700.00
0005432784705	15448	Economy	15100.00
0005432784659	15448	Economy	15100.00
0005432784703	15448	Economy	15100.00
0005435242992	15448	Economy	15100.00
0005435242963	15448	Economy	15100.00
0005432784665	15448	Economy	13700.00
0005432784667	15448	Economy	13700.00
0005432784693	15448	Economy	13700.00
0005435243003	15448	Economy	13700.00
0005432784683	15448	Economy	13700.00
0005432784685	15448	Economy	13700.00
0005432784666	15448	Economy	13700.00
0005435243027	15448	Economy	13700.00
0005432784673	15448	Economy	13700.00
0005435242969	15448	Economy	13700.00
0005435242993	15448	Economy	13700.00
0005435243074	15448	Economy	13700.00
0005435243144	15448	Economy	13700.00
0005435243028	15448	Economy	13700.00
0005435243026	15448	Economy	13700.00
0005432784708	15448	Economy	13700.00
0005435243019	15448	Economy	13700.00
0005432784662	15448	Economy	13700.00
0005432784688	15448	Economy	13700.00
0005435243043	15448	Economy	13700.00
0005432784680	15448	Economy	13700.00
0005432784671	15448	Economy	13700.00
0005432784686	15448	Economy	13700.00
0005432784689	15448	Economy	13700.00
0005435243064	15448	Economy	13700.00
0005432784669	15448	Economy	13700.00
0005432784672	15448	Economy	13700.00
0005432784701	15448	Economy	13700.00
0005432784661	15448	Economy	13700.00
0005435243125	15448	Economy	13700.00
0005435242970	15448	Economy	13700.00
0005432784690	15448	Economy	13700.00
0005432784710	15448	Economy	13700.00
0005435243094	15448	Economy	13700.00
0005435243063	15448	Economy	13700.00
0005432784681	15448	Economy	13700.00
0005435242986	15448	Economy	13700.00
0005432784676	15448	Economy	13700.00
0005432784707	15448	Economy	13700.00
0005435242987	15448	Economy	13700.00
0005435243004	15448	Economy	13700.00
0005432784678	15448	Economy	13700.00
0005435243178	15448	Economy	13700.00
0005432784664	15448	Economy	13700.00
0005432784699	15448	Economy	13700.00
0005435242880	15448	Economy	13700.00
0005435242997	15448	Economy	13700.00
0005435243121	15448	Economy	13700.00
0005435242998	15448	Economy	13700.00
0005432784657	15448	Economy	13700.00
0005432784702	15448	Economy	13700.00
0005435242881	15448	Economy	13700.00
0005435243070	15448	Economy	13700.00
0005432784696	15448	Economy	13700.00
0005432784709	15448	Economy	13700.00
0005432784670	15448	Economy	13700.00
0005435243162	15448	Economy	13700.00
0005432784698	15448	Economy	13700.00
0005435242971	15448	Economy	13700.00
0005432784677	15448	Economy	13700.00
0005432784682	15448	Economy	13700.00
0005435242949	15448	Economy	13700.00
0005435243100	15448	Economy	13700.00
0005432784687	15448	Economy	13700.00
0005435243179	15448	Economy	13700.00
0005432784692	15448	Economy	13700.00
0005434878694	10062	Business	49700.00
0005434910155	10062	Business	49700.00
0005434879487	10062	Business	49700.00
0005434879232	10062	Business	49700.00
0005434879243	10062	Business	49700.00
0005434879134	10062	Business	49700.00
0005434879107	10062	Business	49700.00
0005434878827	10062	Business	49700.00
0005434879008	10062	Business	49700.00
0005434879460	10062	Business	49700.00
0005434879389	10062	Business	49700.00
0005434878959	10062	Business	49700.00
0005434878890	10062	Business	49700.00
0005434878993	10062	Business	49700.00
0005434879391	10062	Business	49700.00
0005434879092	10062	Business	49700.00
0005434879204	10062	Business	49700.00
0005434879392	10062	Economy	16600.00
0005434878689	10062	Economy	16600.00
0005434878674	10062	Economy	16600.00
0005434879168	10062	Economy	16600.00
0005435914003	10062	Economy	16600.00
0005435914004	10062	Economy	16600.00
0005434878777	10062	Economy	16600.00
0005434879147	10062	Economy	16600.00
0005434879438	10062	Economy	16600.00
0005434879365	10062	Economy	16600.00
0005434878495	10062	Economy	16600.00
0005434879033	10062	Economy	16600.00
0005435913997	10062	Economy	18200.00
0005434878776	10062	Economy	18200.00
0005434878967	10062	Economy	18200.00
0005434879007	10062	Economy	16600.00
0005434879100	10062	Economy	18200.00
0005434878871	10062	Economy	16600.00
0005434879128	10062	Economy	16600.00
0005434878701	10062	Economy	16600.00
0005434878590	10062	Economy	16600.00
0005434879373	10062	Economy	16600.00
0005434879212	10062	Economy	16600.00
0005434878813	10062	Economy	16600.00
0005434879001	10062	Economy	16600.00
0005434879144	10062	Economy	16600.00
0005434878771	10062	Economy	16600.00
0005434879080	10062	Economy	16600.00
0005434879000	10062	Economy	16600.00
0005434878599	10062	Economy	16600.00
0005434910154	10062	Economy	16600.00
0005435914005	10062	Economy	16600.00
0005434879244	10062	Economy	16600.00
0005434879461	10062	Economy	16600.00
0005434879129	10062	Economy	16600.00
0005434879374	10062	Economy	16600.00
0005434878881	10062	Economy	16600.00
0005434879131	10062	Economy	16600.00
0005434758916	10062	Economy	16600.00
0005434879598	10062	Economy	16600.00
0005434878969	10062	Economy	16600.00
0005434879462	10062	Economy	16600.00
0005434879390	10062	Economy	16600.00
0005435914006	10062	Economy	16600.00
0005434879087	10062	Economy	16600.00
0005434879057	10062	Economy	16600.00
0005434879110	10062	Economy	16600.00
0005434878878	10062	Economy	16600.00
0005434878849	10062	Economy	16600.00
0005434878978	10062	Economy	16600.00
0005434878891	10062	Economy	16600.00
0005435913998	10062	Economy	16600.00
0005434878675	10062	Economy	16600.00
0005434878848	10062	Economy	16600.00
0005434879312	10062	Economy	16600.00
0005434879148	10062	Economy	16600.00
0005434879205	10062	Economy	16600.00
0005434879192	10062	Economy	16600.00
0005434878845	10062	Economy	16600.00
0005434879493	10062	Economy	16600.00
0005434879242	10062	Economy	16600.00
0005434879088	10062	Economy	16600.00
0005434878639	10062	Economy	16600.00
0005434879324	10062	Economy	16600.00
0005435913996	10062	Economy	16600.00
0005434879072	10062	Economy	16600.00
0005434878981	10062	Economy	16600.00
0005434878977	10062	Economy	16600.00
0005434878869	10062	Economy	16600.00
0005434878968	10062	Economy	16600.00
0005434878994	10062	Economy	16600.00
0005434878676	10062	Economy	16600.00
0005435914002	10062	Economy	16600.00
0005435914007	10062	Economy	16600.00
0005434878909	10062	Economy	16600.00
0005434878673	10062	Economy	16600.00
0005434879327	10062	Economy	16600.00
0005434758910	10062	Economy	16600.00
0005434878979	10062	Economy	16600.00
0005435913999	10062	Economy	16600.00
0005435914000	10062	Economy	16600.00
0005434879317	10062	Economy	16600.00
0005434878714	10062	Economy	16600.00
0005434879133	10062	Economy	16600.00
0005434878836	10062	Economy	16600.00
0005435914001	10062	Economy	16600.00
0005434879185	10062	Economy	16600.00
0005434879196	10062	Economy	16600.00
0005434879108	10062	Economy	16600.00
0005434879256	10062	Economy	16600.00
0005434879921	14635	Business	49700.00
0005434879909	14635	Business	49700.00
0005434879836	14635	Business	49700.00
0005434879892	14635	Business	49700.00
0005434879850	14635	Business	49700.00
0005434879914	14635	Business	49700.00
0005434879890	14635	Business	49700.00
0005434879856	14635	Business	49700.00
0005434879889	14635	Business	49700.00
0005434879867	14635	Business	49700.00
0005435913954	14635	Business	49700.00
0005434879846	14635	Business	49700.00
0005434879899	14635	Business	49700.00
0005434879903	14635	Business	49700.00
0005434879878	14635	Business	49700.00
0005434879857	14635	Business	49700.00
0005434879837	14635	Business	49700.00
0005434879874	14635	Economy	16600.00
0005434879895	14635	Economy	16600.00
0005434879884	14635	Economy	16600.00
0005434879865	14635	Economy	16600.00
0005434879919	14635	Economy	16600.00
0005434910124	14635	Economy	16600.00
0005434879854	14635	Economy	16600.00
0005434879845	14635	Economy	16600.00
0005435913955	14635	Economy	16600.00
0005434879842	14635	Economy	16600.00
0005434879916	14635	Economy	16600.00
0005434879848	14635	Economy	16600.00
0005434879891	14635	Economy	18200.00
0005434879887	14635	Economy	18200.00
0005434879871	14635	Economy	18200.00
0005434879868	14635	Economy	16600.00
0005434879915	14635	Economy	18200.00
0005435913960	14635	Economy	16600.00
0005434879835	14635	Economy	16600.00
0005435913957	14635	Economy	16600.00
0005434879827	14635	Economy	16600.00
0005434879911	14635	Economy	16600.00
0005434758935	14635	Economy	16600.00
0005434879872	14635	Economy	16600.00
0005434879833	14635	Economy	16600.00
0005434879847	14635	Economy	16600.00
0005434879896	14635	Economy	16600.00
0005434879862	14635	Economy	16600.00
0005434879843	14635	Economy	16600.00
0005434879912	14635	Economy	16600.00
0005434879885	14635	Economy	16600.00
0005434879908	14635	Economy	16600.00
0005434879875	14635	Economy	16600.00
0005434879907	14635	Economy	16600.00
0005434879832	14635	Economy	16600.00
0005434879861	14635	Economy	16600.00
0005434879888	14635	Economy	16600.00
0005434879877	14635	Economy	16600.00
0005434879876	14635	Economy	16600.00
0005434879828	14635	Economy	16600.00
0005434910136	14635	Economy	16600.00
0005434879905	14635	Economy	16600.00
0005434879834	14635	Economy	16600.00
0005434879883	14635	Economy	16600.00
0005434879898	14635	Economy	16600.00
0005434879866	14635	Economy	16600.00
0005434879897	14635	Economy	16600.00
0005434879879	14635	Economy	16600.00
0005434879853	14635	Economy	16600.00
0005434879920	14635	Economy	16600.00
0005434879851	14635	Economy	16600.00
0005434879841	14635	Economy	16600.00
0005434879918	14635	Economy	16600.00
0005434879900	14635	Economy	16600.00
0005434879844	14635	Economy	16600.00
0005434879840	14635	Economy	16600.00
0005434879860	14635	Economy	16600.00
0005434879855	14635	Economy	16600.00
0005434879910	14635	Economy	16600.00
0005434879873	14635	Economy	16600.00
0005434879838	14635	Economy	16600.00
0005434879852	14635	Economy	16600.00
0005434879864	14635	Economy	16600.00
0005434879904	14635	Economy	16600.00
0005434879870	14635	Economy	16600.00
0005434879913	14635	Economy	16600.00
0005434879902	14635	Economy	16600.00
0005434879863	14635	Economy	16600.00
0005434879917	14635	Economy	16600.00
0005434879880	14635	Economy	16600.00
0005434879886	14635	Economy	16600.00
0005434879893	14635	Economy	16600.00
0005434879830	14635	Economy	16600.00
0005434879881	14635	Economy	16600.00
0005434879849	14635	Economy	16600.00
0005434879894	14635	Economy	16600.00
0005434879839	14635	Economy	16600.00
0005434879882	14635	Economy	16600.00
0005434879869	14635	Economy	16600.00
0005435913950	14635	Economy	16600.00
0005434879826	14635	Economy	16600.00
0005434879901	14635	Economy	16600.00
0005435913953	14635	Economy	16600.00
0005434879906	14635	Economy	16600.00
0005434879858	14635	Economy	16600.00
0005434879829	14635	Economy	16600.00
0005435913958	14635	Economy	16600.00
0005434879859	14635	Economy	16600.00
0005434879831	14635	Economy	16600.00
0005435660339	9211	Economy	22400.00
0005435660332	9211	Economy	22400.00
0005435660331	9211	Economy	22400.00
0005434252015	9211	Economy	20300.00
0005434252067	9211	Economy	20300.00
0005434252025	9211	Economy	20300.00
0005435660330	9211	Economy	20300.00
0005435660333	9211	Economy	20300.00
0005434252049	9211	Economy	20300.00
0005434252042	9211	Economy	20300.00
0005434252024	9211	Economy	20300.00
0005435660337	9211	Economy	20300.00
0005435660335	9211	Economy	20300.00
0005435660336	9211	Economy	20300.00
0005434252044	9211	Economy	20300.00
0005435660329	9211	Economy	20300.00
0005435660334	9211	Economy	20300.00
0005435660338	9211	Economy	20300.00
0005435660237	24664	Economy	22400.00
0005435660197	24664	Economy	22400.00
0005435660196	24664	Economy	20300.00
0005434252134	24664	Economy	20300.00
0005434252128	24664	Economy	20300.00
0005435660228	24664	Economy	20300.00
0005435660226	24664	Economy	20300.00
0005435660235	24664	Economy	20300.00
0005435660227	24664	Economy	20300.00
0005434252132	24664	Economy	20300.00
0005435660214	24664	Economy	20300.00
0005434252131	24664	Economy	20300.00
0005435660195	24664	Economy	20300.00
0005434252130	24664	Economy	20300.00
0005435660245	24664	Economy	20300.00
0005434252127	24664	Economy	20300.00
0005435660215	24664	Economy	20300.00
0005435660252	24664	Economy	20300.00
0005435660270	24664	Economy	20300.00
0005434252136	24664	Economy	20300.00
0005435660223	24664	Economy	20300.00
0005434252135	24664	Economy	20300.00
0005434252133	24664	Economy	20300.00
0005434252129	24664	Economy	20300.00
0005433681417	2791	Business	33000.00
0005432967202	2791	Business	33000.00
0005432967207	2791	Business	33000.00
0005433681399	2791	Business	33000.00
0005433681375	2791	Business	33000.00
0005433681382	2791	Business	33000.00
0005432967270	2791	Business	33000.00
0005433681374	2791	Business	33000.00
0005432967156	2791	Economy	11000.00
0005433681381	2791	Economy	11000.00
0005433681411	2791	Economy	11000.00
0005433681412	2791	Economy	11000.00
0005433681385	2791	Economy	11000.00
0005433681384	2791	Economy	11000.00
0005432967134	2791	Economy	11000.00
0005433681391	2791	Economy	11000.00
0005433684456	2791	Economy	12100.00
0005432967306	2791	Economy	12100.00
0005433681396	2791	Economy	12100.00
0005432222874	2791	Economy	11000.00
0005433681416	2791	Economy	11000.00
0005432222872	2791	Economy	11000.00
0005433684454	2791	Economy	11000.00
0005433681403	2791	Economy	11000.00
0005432967201	2791	Economy	11000.00
0005433681387	2791	Economy	11000.00
0005432967149	2791	Economy	11000.00
0005432222876	2791	Economy	11000.00
0005433681407	2791	Economy	11000.00
0005433681386	2791	Economy	11000.00
0005433681394	2791	Economy	11000.00
0005432967229	2791	Economy	11000.00
0005433681395	2791	Economy	11000.00
0005432967135	2791	Economy	11000.00
0005433681373	2791	Economy	11000.00
0005432967203	2791	Economy	11000.00
0005433681376	2791	Economy	11000.00
0005432967150	2791	Economy	11000.00
0005433681400	2791	Economy	11000.00
0005433681383	2791	Economy	11000.00
0005432967133	2791	Economy	11000.00
0005432967307	2791	Economy	11000.00
0005433681397	2791	Economy	11000.00
0005433681409	2791	Economy	11000.00
0005433681419	2791	Economy	11000.00
0005433681406	2791	Economy	11000.00
0005432967040	2791	Economy	11000.00
0005433681372	2791	Economy	11000.00
0005433681408	2791	Economy	11000.00
0005432967200	2791	Economy	11000.00
0005433681389	2791	Economy	11000.00
0005432967107	2791	Economy	11000.00
0005432222875	2791	Economy	11000.00
0005433681414	2791	Economy	11000.00
0005433681388	2791	Economy	11000.00
0005432222873	2791	Economy	11000.00
0005433681402	2791	Economy	11000.00
0005433684455	2791	Economy	11000.00
0005433681410	2791	Economy	11000.00
0005433681393	2791	Economy	11000.00
0005433681415	2791	Economy	11000.00
0005432967228	2791	Economy	11000.00
0005433681379	2791	Economy	11000.00
0005433681418	2791	Economy	11000.00
0005433681398	2791	Economy	11000.00
0005433681377	2791	Economy	11000.00
0005432967146	2791	Economy	11000.00
0005432967033	2791	Economy	11000.00
0005433681371	2791	Economy	11000.00
0005433681401	2791	Economy	11000.00
0005433681405	2791	Economy	11000.00
0005433681392	2791	Economy	11000.00
0005432967141	2791	Economy	11000.00
0005433681378	2791	Economy	11000.00
0005432967157	2791	Economy	11000.00
0005433681404	2791	Economy	11000.00
0005433681380	2791	Economy	11000.00
0005433681413	2791	Economy	11000.00
0005433681390	2791	Economy	11000.00
0005432967067	2791	Economy	11000.00
0005433687721	29184	Business	33000.00
0005433681130	29184	Business	33000.00
0005433680795	29184	Business	33000.00
0005432005261	29184	Business	33000.00
0005433681137	29184	Business	33000.00
0005433687728	29184	Business	33000.00
0005432967371	29184	Business	33000.00
0005432967391	29184	Business	33000.00
0005432967383	29184	Business	33000.00
0005432967373	29184	Business	33000.00
0005432967374	29184	Business	33000.00
0005433681092	29184	Economy	11000.00
0005433680883	29184	Economy	11000.00
0005433681131	29184	Economy	11000.00
0005433681074	29184	Economy	11000.00
0005433681215	29184	Economy	11000.00
0005433680997	29184	Economy	11000.00
0005433681044	29184	Economy	11000.00
0005432967376	29184	Economy	11000.00
0005433687727	29184	Economy	11000.00
0005432967377	29184	Economy	11000.00
0005433681219	29184	Economy	12100.00
0005433681216	29184	Economy	12100.00
0005433680987	29184	Economy	12100.00
0005432967392	29184	Economy	12100.00
0005433680978	29184	Economy	12100.00
0005433681033	29184	Economy	11000.00
0005433681107	29184	Economy	11000.00
0005433681241	29184	Economy	11000.00
0005433681116	29184	Economy	11000.00
0005433690935	29184	Economy	11000.00
0005433680759	29184	Economy	11000.00
0005432967389	29184	Economy	11000.00
0005433687726	29184	Economy	11000.00
0005432967390	29184	Economy	11000.00
0005433681141	29184	Economy	11000.00
0005433680929	29184	Economy	11000.00
0005432967385	29184	Economy	11000.00
0005432967386	29184	Economy	11000.00
0005432967380	29184	Economy	11000.00
0005432967384	29184	Economy	11000.00
0005433681004	29184	Economy	11000.00
0005433681037	29184	Economy	11000.00
0005432005262	29184	Economy	11000.00
0005433681124	29184	Economy	11000.00
0005432967378	29184	Economy	11000.00
0005432967370	29184	Economy	11000.00
0005433680986	29184	Economy	11000.00
0005433687723	29184	Economy	11000.00
0005433681005	29184	Economy	11000.00
0005433684443	29184	Economy	11000.00
0005433681136	29184	Economy	11000.00
0005432005263	29184	Economy	11000.00
0005433681217	29184	Economy	11000.00
0005433681043	29184	Economy	11000.00
0005432967393	29184	Economy	11000.00
0005433680754	29184	Economy	11000.00
0005433681075	29184	Economy	11000.00
0005432967382	29184	Economy	11000.00
0005433681084	29184	Economy	11000.00
0005433680939	29184	Economy	11000.00
0005433684444	29184	Economy	11000.00
0005433680888	29184	Economy	11000.00
0005433680855	29184	Economy	11000.00
0005432967375	29184	Economy	11000.00
0005433681148	29184	Economy	11000.00
0005433680979	29184	Economy	11000.00
0005433690936	29184	Economy	11000.00
0005433680753	29184	Economy	11000.00
0005432967381	29184	Economy	11000.00
0005433681056	29184	Economy	11000.00
0005433681115	29184	Economy	11000.00
0005433687722	29184	Economy	11000.00
0005433680740	29184	Economy	11000.00
0005432967387	29184	Economy	11000.00
0005433680940	29184	Economy	11000.00
0005433681025	29184	Economy	11000.00
0005433681153	29184	Economy	11000.00
0005433681088	29184	Economy	11000.00
0005433681089	29184	Economy	11000.00
0005432967388	29184	Economy	11000.00
0005432967379	29184	Economy	11000.00
0005433681103	29184	Economy	11000.00
0005433681147	29184	Economy	11000.00
0005433687724	29184	Economy	11000.00
0005432967368	29184	Economy	11000.00
0005432967372	29184	Economy	11000.00
0005432967369	29184	Economy	11000.00
0005433681097	29184	Economy	11000.00
0005433681172	29184	Economy	11000.00
0005433681218	29184	Economy	11000.00
0005433615880	9301	Business	132900.00
0005433615878	9301	Business	132900.00
0005433615898	9301	Business	132900.00
0005433578048	9301	Business	132900.00
0005433615917	9301	Business	132900.00
0005433615877	9301	Business	132900.00
0005433615904	9301	Business	132900.00
0005433634390	9301	Business	132900.00
0005432756904	9301	Business	132900.00
0005433615887	9301	Business	132900.00
0005434269119	9301	Business	132900.00
0005433615868	9301	Business	132900.00
0005433634387	9301	Business	132900.00
0005433578041	9301	Business	132900.00
0005433615918	9301	Business	132900.00
0005433615914	9301	Business	132900.00
0005433615911	9301	Business	132900.00
0005432145145	9301	Business	132900.00
0005434163667	9301	Business	132900.00
0005433634383	9301	Business	132900.00
0005434163668	9301	Business	132900.00
0005433615906	9301	Business	132900.00
0005432756906	9301	Business	132900.00
0005433634399	9301	Business	132900.00
0005433634388	9301	Business	132900.00
0005433578037	9301	Business	132900.00
0005433578046	9301	Business	132900.00
0005434272204	9301	Business	132900.00
0005433615886	9301	Economy	48700.00
0005433615909	9301	Economy	48700.00
0005433615869	9301	Economy	48700.00
0005433634375	9301	Economy	48700.00
0005433634397	9301	Economy	48700.00
0005433634382	9301	Economy	48700.00
0005433634381	9301	Economy	44300.00
0005433634392	9301	Economy	44300.00
0005433634371	9301	Economy	44300.00
0005433578036	9301	Economy	44300.00
0005433634398	9301	Economy	44300.00
0005433615930	9301	Economy	44300.00
0005433578040	9301	Economy	44300.00
0005433615873	9301	Economy	44300.00
0005433578035	9301	Economy	44300.00
0005433615871	9301	Economy	44300.00
0005433615923	9301	Economy	44300.00
0005434272202	9301	Economy	44300.00
0005433634389	9301	Economy	44300.00
0005433634379	9301	Economy	44300.00
0005433634365	9301	Economy	44300.00
0005433634380	9301	Economy	44300.00
0005433615928	9301	Economy	44300.00
0005433615885	9301	Economy	44300.00
0005433615912	9301	Economy	44300.00
0005433615902	9301	Economy	44300.00
0005433615927	9301	Economy	44300.00
0005433615864	9301	Economy	44300.00
0005434163693	9301	Economy	44300.00
0005433634370	9301	Economy	44300.00
0005433634368	9301	Economy	44300.00
0005433615861	9301	Economy	44300.00
0005433615896	9301	Economy	44300.00
0005433634374	9301	Economy	44300.00
0005433615866	9301	Economy	44300.00
0005432756907	9301	Economy	44300.00
0005433615872	9301	Economy	44300.00
0005434272198	9301	Economy	44300.00
0005433615889	9301	Economy	44300.00
0005433615857	9301	Economy	44300.00
0005433615920	9301	Economy	44300.00
0005433578039	9301	Economy	44300.00
0005433634385	9301	Economy	44300.00
0005434163669	9301	Economy	44300.00
0005434163713	9301	Economy	44300.00
0005434272203	9301	Economy	44300.00
0005433615892	9301	Economy	44300.00
0005433634373	9301	Economy	44300.00
0005433615907	9301	Economy	44300.00
0005433615929	9301	Economy	44300.00
0005433615921	9301	Economy	44300.00
0005432756905	9301	Economy	44300.00
0005433615925	9301	Economy	44300.00
0005433615874	9301	Economy	44300.00
0005432755132	9301	Economy	44300.00
0005433634384	9301	Economy	44300.00
0005433615916	9301	Economy	44300.00
0005433615924	9301	Economy	44300.00
0005434163707	9301	Economy	44300.00
0005433615895	9301	Economy	48700.00
0005433578045	9301	Economy	48700.00
0005432755131	9301	Economy	48700.00
0005433578044	9301	Economy	44300.00
0005433634377	9301	Economy	44300.00
0005433615899	9301	Economy	44300.00
0005433615890	9301	Economy	48700.00
0005433615922	9301	Economy	44300.00
0005434163674	9301	Economy	44300.00
0005433615875	9301	Economy	44300.00
0005433615915	9301	Economy	44300.00
0005433615858	9301	Economy	44300.00
0005432145146	9301	Economy	44300.00
0005434269118	9301	Economy	44300.00
0005433634386	9301	Economy	44300.00
0005433615882	9301	Economy	44300.00
0005433578049	9301	Economy	44300.00
0005434269116	9301	Economy	44300.00
0005433615876	9301	Economy	44300.00
0005433615888	9301	Economy	44300.00
0005433634396	9301	Economy	44300.00
0005433634372	9301	Economy	44300.00
0005433615913	9301	Economy	44300.00
0005434163695	9301	Economy	44300.00
0005433615867	9301	Economy	44300.00
0005433615926	9301	Economy	44300.00
0005433634394	9301	Economy	44300.00
0005433615860	9301	Economy	44300.00
0005433578043	9301	Economy	44300.00
0005434163694	9301	Economy	44300.00
0005433615891	9301	Economy	44300.00
0005432755133	9301	Economy	44300.00
0005433615862	9301	Economy	44300.00
0005433634391	9301	Economy	44300.00
0005434163708	9301	Economy	44300.00
0005433615903	9301	Economy	44300.00
0005433634367	9301	Economy	44300.00
0005433615865	9301	Economy	44300.00
0005433615859	9301	Economy	44300.00
0005432755135	9301	Economy	44300.00
0005433634393	9301	Economy	44300.00
0005433615856	9301	Economy	44300.00
0005433615863	9301	Economy	44300.00
0005433578047	9301	Economy	44300.00
0005433615884	9301	Economy	44300.00
0005433634378	9301	Economy	44300.00
0005433615894	9301	Economy	44300.00
0005433615900	9301	Economy	44300.00
0005433615901	9301	Economy	44300.00
0005433615910	9301	Economy	44300.00
0005433615879	9301	Economy	44300.00
0005433578042	9301	Economy	44300.00
0005433615883	9301	Economy	44300.00
0005433615881	9301	Economy	44300.00
0005433615893	9301	Economy	44300.00
0005433615905	9301	Economy	44300.00
0005433634366	9301	Economy	44300.00
0005433615919	9301	Economy	44300.00
0005434269125	9301	Economy	44300.00
0005434269117	9301	Economy	44300.00
0005433615897	9301	Economy	44300.00
0005433615908	9301	Economy	44300.00
0005434269120	9301	Economy	44300.00
0005433634395	9301	Economy	44300.00
0005433634376	9301	Economy	44300.00
0005432755134	9301	Economy	44300.00
0005433578038	9301	Economy	44300.00
0005433615870	9301	Economy	44300.00
0005433634369	9301	Economy	44300.00
0005433615599	25210	Business	132900.00
0005433577947	25210	Business	132900.00
0005433614990	25210	Business	132900.00
0005433615265	25210	Business	132900.00
0005433615305	25210	Business	132900.00
0005433633954	25210	Business	132900.00
0005433615482	25210	Business	132900.00
0005433634026	25210	Business	132900.00
0005433615437	25210	Business	132900.00
0005433614989	25210	Business	132900.00
0005434163781	25210	Business	132900.00
0005433615563	25210	Business	132900.00
0005433615086	25210	Business	132900.00
0005433634060	25210	Business	132900.00
0005433615326	25210	Business	132900.00
0005433577918	25210	Business	132900.00
0005433615554	25210	Business	132900.00
0005433615087	25210	Business	132900.00
0005433634097	25210	Business	132900.00
0005433615430	25210	Business	132900.00
0005433615367	25210	Business	132900.00
0005433615396	25210	Business	132900.00
0005434273104	25210	Business	132900.00
0005433615257	25210	Business	132900.00
0005433615521	25210	Economy	48700.00
0005433577901	25210	Business	132900.00
0005433615279	25210	Economy	48700.00
0005433577892	25210	Economy	48700.00
0005433615238	25210	Economy	48700.00
0005434272216	25210	Economy	48700.00
0005433615459	25210	Economy	48700.00
0005433615531	25210	Economy	44300.00
0005433615351	25210	Economy	44300.00
0005433615283	25210	Economy	44300.00
0005433634098	25210	Economy	44300.00
0005433633955	25210	Economy	44300.00
0005433615395	25210	Economy	44300.00
0005433615284	25210	Economy	44300.00
0005434163775	25210	Economy	44300.00
0005433615239	25210	Economy	44300.00
0005433634181	25210	Economy	44300.00
0005433634183	25210	Economy	44300.00
0005433615335	25210	Economy	44300.00
0005433615306	25210	Economy	44300.00
0005433615366	25210	Economy	44300.00
0005433615097	25210	Economy	44300.00
0005433634174	25210	Economy	44300.00
0005434163782	25210	Economy	44300.00
0005433577946	25210	Economy	44300.00
0005433615270	25210	Economy	44300.00
0005433615585	25210	Economy	44300.00
0005433614977	25210	Economy	44300.00
0005433577950	25210	Economy	44300.00
0005433614873	25210	Economy	44300.00
0005433615040	25210	Economy	44300.00
0005433615365	25210	Economy	44300.00
0005433577928	25210	Economy	44300.00
0005434272217	25210	Economy	44300.00
0005434163776	25210	Economy	44300.00
0005433615357	25210	Economy	44300.00
0005433615530	25210	Economy	44300.00
0005434163785	25210	Economy	44300.00
0005433615345	25210	Economy	44300.00
0005433634081	25210	Economy	44300.00
0005433633986	25210	Economy	44300.00
0005433615307	25210	Economy	44300.00
0005433633917	25210	Economy	44300.00
0005433615428	25210	Economy	44300.00
0005433615388	25210	Economy	44300.00
0005433633980	25210	Economy	44300.00
0005433634147	25210	Economy	44300.00
0005433633916	25210	Economy	44300.00
0005433615219	25210	Economy	44300.00
0005433615185	25210	Economy	44300.00
0005433615375	25210	Economy	44300.00
0005433615221	25210	Economy	44300.00
0005433615566	25210	Economy	44300.00
0005433615100	25210	Economy	44300.00
0005433615146	25210	Economy	44300.00
0005433615139	25210	Economy	44300.00
0005433615098	25210	Economy	44300.00
0005433633956	25210	Economy	44300.00
0005433615422	25210	Economy	44300.00
0005433615242	25210	Economy	48700.00
0005434163783	25210	Economy	48700.00
0005433615411	25210	Economy	48700.00
0005433634008	25210	Economy	48700.00
0005433615387	25210	Economy	48700.00
0005433615143	25210	Economy	44300.00
0005433615215	25210	Economy	44300.00
0005433615089	25210	Economy	44300.00
0005433615286	25210	Economy	48700.00
0005433615584	25210	Economy	44300.00
0005433615140	25210	Economy	44300.00
0005433615458	25210	Economy	44300.00
0005434273105	25210	Economy	44300.00
0005433615003	25210	Economy	44300.00
0005433615532	25210	Economy	44300.00
0005433633878	25210	Economy	44300.00
0005433615041	25210	Economy	44300.00
0005433633996	25210	Economy	44300.00
0005434163780	25210	Economy	44300.00
0005433633991	25210	Economy	44300.00
0005433615259	25210	Economy	44300.00
0005433615145	25210	Economy	44300.00
0005433633981	25210	Economy	44300.00
0005433615460	25210	Economy	44300.00
0005433634080	25210	Economy	44300.00
0005433634138	25210	Economy	44300.00
0005433615354	25210	Economy	44300.00
0005433633984	25210	Economy	44300.00
0005433634182	25210	Economy	44300.00
0005433633995	25210	Economy	44300.00
0005433615088	25210	Economy	44300.00
0005433615701	25210	Economy	44300.00
0005433614987	25210	Economy	44300.00
0005433634122	25210	Economy	44300.00
0005433615583	25210	Economy	44300.00
0005433634032	25210	Economy	44300.00
0005433633985	25210	Economy	44300.00
0005433615278	25210	Economy	44300.00
0005433614958	25210	Economy	44300.00
0005433615325	25210	Economy	44300.00
0005433615096	25210	Economy	44300.00
0005433615258	25210	Economy	44300.00
0005433634079	25210	Economy	44300.00
0005434163786	25210	Economy	44300.00
0005433615004	25210	Economy	44300.00
0005433615220	25210	Economy	44300.00
0005433577891	25210	Economy	44300.00
0005433577949	25210	Economy	44300.00
0005433615436	25210	Economy	44300.00
0005433634175	25210	Economy	44300.00
0005434163777	25210	Economy	44300.00
0005433615334	25210	Economy	44300.00
0005433634146	25210	Economy	44300.00
0005433615231	25210	Economy	44300.00
0005434163779	25210	Economy	44300.00
0005433615403	25210	Economy	44300.00
0005434163784	25210	Economy	44300.00
0005433615338	25210	Economy	44300.00
0005433577959	25210	Economy	44300.00
0005433615099	25210	Economy	44300.00
0005433615222	25210	Economy	44300.00
0005433634064	25210	Economy	44300.00
0005433634065	25210	Economy	44300.00
0005433615282	25210	Economy	44300.00
0005433633997	25210	Economy	44300.00
0005433615545	25210	Economy	44300.00
0005434163778	25210	Economy	44300.00
0005433615410	25210	Economy	44300.00
0005433615216	25210	Economy	44300.00
0005435856252	4209	Business	193100.00
0005432185000	4209	Business	193100.00
0005432185001	4209	Business	193100.00
0005435947418	4209	Business	193100.00
0005435986890	4209	Business	193100.00
0005435947416	4209	Economy	64400.00
0005435986884	4209	Economy	64400.00
0005435947408	4209	Economy	64400.00
0005435986882	4209	Economy	64400.00
0005435986883	4209	Economy	64400.00
0005435947359	4209	Economy	64400.00
0005432571345	4209	Economy	64400.00
0005435986886	4209	Economy	64400.00
0005435787367	4209	Economy	64400.00
0005435986887	4209	Economy	64400.00
0005435986889	4209	Economy	64400.00
0005435947417	4209	Economy	64400.00
0005435947358	4209	Economy	64400.00
0005434271329	4209	Economy	64400.00
0005434271330	4209	Economy	64400.00
0005435986888	4209	Economy	64400.00
0005435856238	4209	Economy	64400.00
0005434271324	4209	Economy	64400.00
0005435947407	4209	Economy	64400.00
0005435787366	4209	Economy	64400.00
0005435986891	4209	Economy	64400.00
0005435856254	4209	Economy	64400.00
0005432571354	4209	Economy	64400.00
0005435947381	4209	Economy	64400.00
0005432185002	4209	Economy	64400.00
0005435947379	4209	Economy	64400.00
0005435986885	4209	Economy	64400.00
0005432571344	4209	Economy	64400.00
0005435947504	26584	Business	193100.00
0005435856280	26584	Business	193100.00
0005432571390	26584	Business	193100.00
0005435947511	26584	Business	193100.00
0005435856279	26584	Economy	70800.00
0005435856278	26584	Economy	64400.00
0005432571392	26584	Economy	64400.00
0005432571389	26584	Economy	64400.00
0005435947514	26584	Economy	64400.00
0005435856277	26584	Economy	64400.00
0005435947508	26584	Economy	64400.00
0005435947512	26584	Economy	64400.00
0005435947510	26584	Economy	64400.00
0005435947503	26584	Economy	64400.00
0005435947505	26584	Economy	64400.00
0005435856276	26584	Economy	64400.00
0005435947516	26584	Economy	64400.00
0005435986743	26584	Economy	64400.00
0005435787392	26584	Economy	70800.00
0005435947509	26584	Economy	64400.00
0005435947515	26584	Economy	64400.00
0005435947506	26584	Economy	64400.00
0005432571391	26584	Economy	64400.00
0005435947513	26584	Economy	64400.00
0005435947517	26584	Economy	64400.00
0005435947507	26584	Economy	64400.00
0005433570134	322	Business	21500.00
0005432948642	322	Business	21500.00
0005432948817	322	Business	21500.00
0005433570077	322	Business	21500.00
0005433074846	322	Business	21500.00
0005433129329	322	Business	21500.00
0005433134180	322	Business	21500.00
0005432948836	322	Business	21500.00
0005433570105	322	Business	21500.00
0005433570121	322	Business	21500.00
0005433570147	322	Business	21500.00
0005433075053	322	Business	21500.00
0005433570104	322	Business	21500.00
0005433570117	322	Business	21500.00
0005433570079	322	Business	21500.00
0005432948816	322	Business	21500.00
0005432948848	322	Business	21500.00
0005432239043	322	Business	21500.00
0005433570148	322	Business	21500.00
0005433570131	322	Business	21500.00
0005433570137	322	Business	21500.00
0005433570130	322	Business	21500.00
0005433570143	322	Business	21500.00
0005433570107	322	Business	21500.00
0005432948818	322	Business	21500.00
0005433570115	322	Economy	7900.00
0005433570110	322	Economy	7900.00
0005433570081	322	Economy	7900.00
0005432948784	322	Economy	7900.00
0005432948662	322	Economy	7900.00
0005433570116	322	Economy	7900.00
0005433074847	322	Economy	7200.00
0005433570139	322	Economy	7200.00
0005432948966	322	Economy	7200.00
0005433570136	322	Economy	7200.00
0005433074938	322	Economy	7200.00
0005433074966	322	Economy	7200.00
0005433570128	322	Economy	7200.00
0005433570083	322	Economy	7200.00
0005432948786	322	Economy	7200.00
0005433074927	322	Economy	7200.00
0005432948811	322	Economy	7200.00
0005433075008	322	Economy	7200.00
0005432239045	322	Economy	7200.00
0005433570099	322	Economy	7200.00
0005433570090	322	Economy	7200.00
0005433570080	322	Economy	7200.00
0005433570089	322	Economy	7200.00
0005432948927	322	Economy	7200.00
0005433570093	322	Economy	7200.00
0005433074939	322	Economy	7200.00
0005433075042	322	Economy	7200.00
0005433570086	322	Economy	7200.00
0005432948914	322	Economy	7200.00
0005433074955	322	Economy	7200.00
0005433074985	322	Economy	7200.00
0005432948785	322	Economy	7200.00
0005432239044	322	Economy	7200.00
0005432948922	322	Economy	7200.00
0005433570141	322	Economy	7200.00
0005433570132	322	Economy	7200.00
0005433570108	322	Economy	7200.00
0005433570111	322	Economy	7200.00
0005433570119	322	Economy	7200.00
0005433570102	322	Economy	7200.00
0005433075041	322	Economy	7200.00
0005433134188	322	Economy	7200.00
0005433570144	322	Economy	7200.00
0005433570109	322	Economy	7200.00
0005433570118	322	Economy	7200.00
0005433570088	322	Economy	7200.00
0005433570149	322	Economy	7200.00
0005433570126	322	Economy	7200.00
0005433570103	322	Economy	7200.00
0005432948965	322	Economy	7200.00
0005433570133	322	Economy	7200.00
0005432948845	322	Economy	7200.00
0005433570124	322	Economy	7200.00
0005433570095	322	Economy	7200.00
0005432948921	322	Economy	7900.00
0005433134177	322	Economy	7900.00
0005432948876	322	Economy	7900.00
0005433074917	322	Economy	7900.00
0005433129307	322	Economy	7200.00
0005433570094	322	Economy	7200.00
0005432948939	322	Economy	7200.00
0005433570127	322	Economy	7900.00
0005433570091	322	Economy	7200.00
0005433570096	322	Economy	7200.00
0005433075004	322	Economy	7200.00
0005433570092	322	Economy	7200.00
0005433129308	322	Economy	7200.00
0005433570138	322	Economy	7200.00
0005432948751	322	Economy	7200.00
0005433074900	322	Economy	7200.00
0005433075003	322	Economy	7200.00
0005432948643	322	Economy	7200.00
0005433074998	322	Economy	7200.00
0005433074863	322	Economy	7200.00
0005433570098	322	Economy	7200.00
0005433075056	322	Economy	7200.00
0005433570101	322	Economy	7200.00
0005433075069	322	Economy	7200.00
0005433074958	322	Economy	7200.00
0005433570146	322	Economy	7200.00
0005433074934	322	Economy	7200.00
0005432948950	322	Economy	7200.00
0005433570142	322	Economy	7200.00
0005433570140	322	Economy	7200.00
0005432948625	322	Economy	7200.00
0005433570078	322	Economy	7200.00
0005433570084	322	Economy	7200.00
0005433570120	322	Economy	7200.00
0005433134181	322	Economy	7200.00
0005433570125	322	Economy	7200.00
0005433570113	322	Economy	7200.00
0005433134176	322	Economy	7200.00
0005432948750	322	Economy	7200.00
0005433075009	322	Economy	7200.00
0005433570082	322	Economy	7200.00
0005433074935	322	Economy	7200.00
0005432239046	322	Economy	7200.00
0005433074862	322	Economy	7200.00
0005433570129	322	Economy	7200.00
0005432239042	322	Economy	7200.00
0005433570135	322	Economy	7200.00
0005433570106	322	Economy	7200.00
0005433074997	322	Economy	7200.00
0005433570114	322	Economy	7200.00
0005433129328	322	Economy	7200.00
0005433570097	322	Economy	7200.00
0005433074918	322	Economy	7200.00
0005433570085	322	Economy	7200.00
0005433129338	322	Economy	7200.00
0005433570112	322	Economy	7200.00
0005433074933	322	Economy	7200.00
0005433570123	322	Economy	7200.00
0005433570145	322	Economy	7200.00
0005433075043	322	Economy	7200.00
0005433570100	322	Economy	7200.00
0005433570087	322	Economy	7200.00
0005432948752	322	Economy	7200.00
0005433570122	322	Economy	7200.00
0005432948644	322	Economy	7200.00
0005433569511	11571	Business	21500.00
0005433569513	11571	Business	21500.00
0005433075211	11571	Business	21500.00
0005433569247	11571	Business	21500.00
0005432949159	11571	Business	21500.00
0005433569445	11571	Business	21500.00
0005432949174	11571	Business	21500.00
0005433134218	11571	Business	21500.00
0005433131787	11571	Business	21500.00
0005433075205	11571	Business	21500.00
0005432192373	11571	Business	21500.00
0005433569392	11571	Business	21500.00
0005433569425	11571	Business	21500.00
0005433569384	11571	Business	21500.00
0005433569460	11571	Business	21500.00
0005433569402	11571	Business	21500.00
0005433569363	11571	Business	21500.00
0005432949177	11571	Business	21500.00
0005433075199	11571	Business	21500.00
0005433075209	11571	Business	21500.00
0005433569454	11571	Business	21500.00
0005433569381	11571	Business	21500.00
0005433075201	11571	Business	21500.00
0005432949148	11571	Business	21500.00
0005432949179	11571	Economy	7900.00
0005432949172	11571	Business	21500.00
0005433569458	11571	Economy	7900.00
0005433569434	11571	Economy	7900.00
0005433075210	11571	Economy	7900.00
0005433075194	11571	Economy	7200.00
0005432949168	11571	Economy	7200.00
0005433569344	11571	Economy	7200.00
0005432949167	11571	Economy	7200.00
0005433569336	11571	Economy	7200.00
0005432949157	11571	Economy	7200.00
0005433075200	11571	Economy	7200.00
0005433134220	11571	Economy	7200.00
0005433075196	11571	Economy	7200.00
0005433075212	11571	Economy	7200.00
0005433075207	11571	Economy	7200.00
0005432949158	11571	Economy	7200.00
0005433569372	11571	Economy	7200.00
0005433075203	11571	Economy	7200.00
0005433075202	11571	Economy	7200.00
0005433569447	11571	Economy	7200.00
0005432949171	11571	Economy	7200.00
0005433075188	11571	Economy	7200.00
0005432949144	11571	Economy	7200.00
0005432949155	11571	Economy	7200.00
0005433569395	11571	Economy	7200.00
0005433569488	11571	Economy	7200.00
0005433075192	11571	Economy	7200.00
0005433569374	11571	Economy	7200.00
0005433569453	11571	Economy	7200.00
0005432949141	11571	Economy	7200.00
0005433569380	11571	Economy	7200.00
0005433131789	11571	Economy	7200.00
0005433075206	11571	Economy	7200.00
0005432949175	11571	Economy	7200.00
0005433569334	11571	Economy	7200.00
0005432949178	11571	Economy	7200.00
0005432949176	11571	Economy	7200.00
0005432949169	11571	Economy	7200.00
0005433075191	11571	Economy	7200.00
0005432949162	11571	Economy	7200.00
0005432949154	11571	Economy	7200.00
0005432949180	11571	Economy	7200.00
0005432192374	11571	Economy	7200.00
0005433075198	11571	Economy	7200.00
0005432949182	11571	Economy	7200.00
0005432949161	11571	Economy	7200.00
0005432949156	11571	Economy	7200.00
0005433569468	11571	Economy	7200.00
0005433569342	11571	Economy	7200.00
0005432949165	11571	Economy	7200.00
0005433569362	11571	Economy	7200.00
0005433569275	11571	Economy	7200.00
0005433569361	11571	Economy	7200.00
0005433569446	11571	Economy	7900.00
0005432949170	11571	Economy	7200.00
0005433569481	11571	Economy	7900.00
0005432949150	11571	Economy	7900.00
0005433569427	11571	Economy	7900.00
0005433569387	11571	Economy	7900.00
0005432949153	11571	Economy	7200.00
0005432949160	11571	Economy	7200.00
0005433075197	11571	Economy	7200.00
0005432949173	11571	Economy	7200.00
0005433075214	11571	Economy	7900.00
0005433569494	11571	Economy	7200.00
0005433569337	11571	Economy	7200.00
0005433569340	11571	Economy	7200.00
0005433569518	11571	Economy	7200.00
0005433569364	11571	Economy	7200.00
0005433569493	11571	Economy	7200.00
0005432949146	11571	Economy	7200.00
0005433569339	11571	Economy	7200.00
0005432949147	11571	Economy	7200.00
0005433569237	11571	Economy	7200.00
0005433131786	11571	Economy	7200.00
0005433569370	11571	Economy	7200.00
0005433569371	11571	Economy	7200.00
0005433075204	11571	Economy	7200.00
0005433075213	11571	Economy	7200.00
0005432949149	11571	Economy	7200.00
0005433075216	11571	Economy	7200.00
0005432949140	11571	Economy	7200.00
0005433075193	11571	Economy	7200.00
0005433569484	11571	Economy	7200.00
0005433569457	11571	Economy	7200.00
0005432949163	11571	Economy	7200.00
0005433569274	11571	Economy	7200.00
0005432949142	11571	Economy	7200.00
0005432949152	11571	Economy	7200.00
0005433134219	11571	Economy	7200.00
0005433569480	11571	Economy	7200.00
0005433569483	11571	Economy	7200.00
0005433075190	11571	Economy	7200.00
0005433075208	11571	Economy	7200.00
0005432949164	11571	Economy	7200.00
0005433075189	11571	Economy	7200.00
0005432192376	11571	Economy	7200.00
0005432949181	11571	Economy	7200.00
0005432949166	11571	Economy	7200.00
0005432949143	11571	Economy	7200.00
0005433134216	11571	Economy	7200.00
0005433569526	11571	Economy	7200.00
0005433569421	11571	Economy	7200.00
0005433134217	11571	Economy	7200.00
0005432192375	11571	Economy	7200.00
0005433569444	11571	Economy	7200.00
0005433131788	11571	Economy	7200.00
0005433075215	11571	Economy	7200.00
0005433569373	11571	Economy	7200.00
0005433569246	11571	Economy	7200.00
0005432949145	11571	Economy	7200.00
0005433569343	11571	Economy	7200.00
0005433569443	11571	Economy	7200.00
0005433569541	11571	Economy	7200.00
0005432949151	11571	Economy	7200.00
0005433075195	11571	Economy	7200.00
0005433569459	11571	Economy	7200.00
0005434733036	10006	Economy	6300.00
0005434733020	10006	Economy	6300.00
0005433817537	10006	Economy	6300.00
0005433817538	10006	Economy	6300.00
0005434733019	10006	Economy	6300.00
0005434733006	10006	Economy	6300.00
0005434733007	10006	Economy	6300.00
0005433817536	10006	Economy	6300.00
0005433817503	13918	Economy	6300.00
0005434733045	13918	Economy	6300.00
0005434733044	13918	Economy	6300.00
0005434733042	13918	Economy	6300.00
0005434733043	13918	Economy	6300.00
0005433817504	13918	Economy	6300.00
0005432985086	2357	Business	184500.00
0005435983100	2357	Business	184500.00
0005433755188	2357	Business	184500.00
0005435983063	2357	Business	184500.00
0005432655750	2357	Business	184500.00
0005433434947	2357	Business	184500.00
0005435983062	2357	Business	184500.00
0005435983056	2357	Business	184500.00
0005435983098	2357	Business	184500.00
0005432985386	2357	Business	184500.00
0005432226163	2357	Business	184500.00
0005433434841	2357	Business	184500.00
0005433755219	2357	Business	184500.00
0005433755185	2357	Business	184500.00
0005434731218	2357	Business	184500.00
0005432869575	2357	Business	184500.00
0005435983064	2357	Business	184500.00
0005433755206	2357	Business	184500.00
0005433434880	2357	Business	184500.00
0005435983067	2357	Business	184500.00
0005435983065	2357	Business	184500.00
0005433755207	2357	Business	184500.00
0005433755224	2357	Business	184500.00
0005435983086	2357	Business	184500.00
0005432869583	2357	Business	184500.00
0005432300369	2357	Business	184500.00
0005432985224	2357	Business	184500.00
0005432985344	2357	Business	184500.00
0005432655752	2357	Economy	67700.00
0005435983074	2357	Business	184500.00
0005435983082	2357	Economy	67700.00
0005433766709	2357	Economy	67700.00
0005433764716	2357	Economy	67700.00
0005433434890	2357	Economy	61500.00
0005432985452	2357	Economy	61500.00
0005432655749	2357	Economy	61500.00
0005432985444	2357	Economy	61500.00
0005432985314	2357	Economy	61500.00
0005432226166	2357	Economy	61500.00
0005433755208	2357	Economy	61500.00
0005433764715	2357	Economy	61500.00
0005432985341	2357	Economy	61500.00
0005432226168	2357	Economy	61500.00
0005432655745	2357	Economy	61500.00
0005432985387	2357	Economy	61500.00
0005433755184	2357	Economy	61500.00
0005433764717	2357	Economy	61500.00
0005433434982	2357	Economy	61500.00
0005433435034	2357	Economy	61500.00
0005434731219	2357	Economy	61500.00
0005433755213	2357	Economy	61500.00
0005433755181	2357	Economy	61500.00
0005433755204	2357	Economy	61500.00
0005433434894	2357	Economy	61500.00
0005432226169	2357	Economy	61500.00
0005435983080	2357	Economy	61500.00
0005432985363	2357	Economy	61500.00
0005432985331	2357	Economy	61500.00
0005435983076	2357	Economy	61500.00
0005435983057	2357	Economy	61500.00
0005433755217	2357	Economy	61500.00
0005433755186	2357	Economy	61500.00
0005435983066	2357	Economy	61500.00
0005435983058	2357	Economy	61500.00
0005433434913	2357	Economy	61500.00
0005433755225	2357	Economy	61500.00
0005433755197	2357	Economy	61500.00
0005433766707	2357	Economy	61500.00
0005433755205	2357	Economy	61500.00
0005433755220	2357	Economy	61500.00
0005433755212	2357	Economy	61500.00
0005434731207	2357	Economy	61500.00
0005435983094	2357	Economy	61500.00
0005435983088	2357	Economy	61500.00
0005435983097	2357	Economy	61500.00
0005433755179	2357	Economy	61500.00
0005432226167	2357	Economy	61500.00
0005433434893	2357	Economy	61500.00
0005435983061	2357	Economy	61500.00
0005433755203	2357	Economy	61500.00
0005433755232	2357	Economy	61500.00
0005435983092	2357	Economy	61500.00
0005433434911	2357	Economy	61500.00
0005435983081	2357	Economy	61500.00
0005433755216	2357	Economy	61500.00
0005432985405	2357	Economy	61500.00
0005432869563	2357	Economy	61500.00
0005432869576	2357	Economy	61500.00
0005435983096	2357	Economy	61500.00
0005433755218	2357	Economy	61500.00
0005435983072	2357	Economy	61500.00
0005433434914	2357	Economy	61500.00
0005433755223	2357	Economy	61500.00
0005433755193	2357	Economy	61500.00
0005433755190	2357	Economy	61500.00
0005433755183	2357	Economy	61500.00
0005432985339	2357	Economy	61500.00
0005432226164	2357	Economy	61500.00
0005433755234	2357	Economy	61500.00
0005435983089	2357	Economy	61500.00
0005432300365	2357	Economy	61500.00
0005432985404	2357	Economy	61500.00
0005432869562	2357	Economy	61500.00
0005433755226	2357	Economy	61500.00
0005435983091	2357	Economy	61500.00
0005433766705	2357	Economy	61500.00
0005433755201	2357	Economy	61500.00
0005435983055	2357	Economy	61500.00
0005433766708	2357	Economy	61500.00
0005433755202	2357	Economy	61500.00
0005433755187	2357	Economy	61500.00
0005433434981	2357	Economy	61500.00
0005433434980	2357	Economy	61500.00
0005433755228	2357	Economy	61500.00
0005435983077	2357	Economy	61500.00
0005435983071	2357	Economy	61500.00
0005434731211	2357	Economy	61500.00
0005432300368	2357	Economy	61500.00
0005433434918	2357	Economy	61500.00
0005433755229	2357	Economy	61500.00
0005435983078	2357	Economy	61500.00
0005433755215	2357	Economy	61500.00
0005432985427	2357	Economy	61500.00
0005435983060	2357	Economy	61500.00
0005433434976	2357	Economy	61500.00
0005432300366	2357	Economy	67700.00
0005433434959	2357	Economy	67700.00
0005433755222	2357	Economy	61500.00
0005433755200	2357	Economy	61500.00
0005435983068	2357	Economy	61500.00
0005432985382	2357	Economy	67700.00
0005432985343	2357	Economy	67700.00
0005433434922	2357	Economy	61500.00
0005433755192	2357	Economy	61500.00
0005434731212	2357	Economy	61500.00
0005433755194	2357	Economy	61500.00
0005433755231	2357	Economy	61500.00
0005432985373	2357	Economy	61500.00
0005433435015	2357	Economy	61500.00
0005433755230	2357	Economy	61500.00
0005432655751	2357	Economy	61500.00
0005433755182	2357	Economy	61500.00
0005433755235	2357	Economy	61500.00
0005435983075	2357	Economy	61500.00
0005432985403	2357	Economy	61500.00
0005432869572	2357	Economy	61500.00
0005432985366	2357	Economy	61500.00
0005433434987	2357	Economy	61500.00
0005433755195	2357	Economy	61500.00
0005432655748	2357	Economy	61500.00
0005435983099	2357	Economy	61500.00
0005435983073	2357	Economy	61500.00
0005432655744	2357	Economy	61500.00
0005433755198	2357	Economy	61500.00
0005433434891	2357	Economy	61500.00
0005435983085	2357	Economy	61500.00
0005432226165	2357	Economy	61500.00
0005433755180	2357	Economy	61500.00
0005433755196	2357	Economy	61500.00
0005433434904	2357	Economy	61500.00
0005433435054	2357	Economy	61500.00
0005435983087	2357	Economy	61500.00
0005433755211	2357	Economy	61500.00
0005433755189	2357	Economy	61500.00
0005433755178	2357	Economy	61500.00
0005432655743	2357	Economy	61500.00
0005432655747	2357	Economy	61500.00
0005433755199	2357	Economy	61500.00
0005435983083	2357	Economy	61500.00
0005433434912	2357	Economy	61500.00
0005435983090	2357	Economy	61500.00
0005435983095	2357	Economy	61500.00
0005435983069	2357	Economy	61500.00
0005435983084	2357	Economy	61500.00
0005432300363	2357	Economy	61500.00
0005432985471	2357	Economy	61500.00
0005433435033	2357	Economy	61500.00
0005435983070	2357	Economy	61500.00
0005433755227	2357	Economy	61500.00
0005433434889	2357	Economy	61500.00
0005433755209	2357	Economy	61500.00
0005433755233	2357	Economy	61500.00
0005433755210	2357	Economy	61500.00
0005433434818	2357	Economy	61500.00
0005433755214	2357	Economy	61500.00
0005433766706	2357	Economy	61500.00
0005432300364	2357	Economy	61500.00
0005432300367	2357	Economy	61500.00
0005432985183	2357	Economy	61500.00
0005435983059	2357	Economy	61500.00
0005433434762	2357	Economy	61500.00
0005433434895	2357	Economy	61500.00
0005432985342	2357	Economy	61500.00
0005432655753	2357	Economy	61500.00
0005435983079	2357	Economy	61500.00
0005435983093	2357	Economy	61500.00
0005433434840	2357	Economy	61500.00
0005433755221	2357	Economy	61500.00
0005432655746	2357	Economy	61500.00
0005433755191	2357	Economy	61500.00
0005435982613	26210	Business	184500.00
0005433754730	26210	Business	184500.00
0005433754568	26210	Business	184500.00
0005433754487	26210	Business	184500.00
0005432985642	26210	Business	184500.00
0005433754658	26210	Business	184500.00
0005433754726	26210	Business	184500.00
0005433754782	26210	Business	184500.00
0005432985645	26210	Business	184500.00
0005433435184	26210	Business	184500.00
0005433754676	26210	Business	184500.00
0005435982402	26210	Business	184500.00
0005433764699	26210	Business	184500.00
0005435982726	26210	Business	184500.00
0005435982589	26210	Business	184500.00
0005433754469	26210	Business	184500.00
0005432049526	26210	Business	184500.00
0005433754686	26210	Business	184500.00
0005432985655	26210	Business	184500.00
0005432985629	26210	Business	184500.00
0005433754742	26210	Business	184500.00
0005432051182	26210	Business	184500.00
0005434731245	26210	Business	184500.00
0005435982700	26210	Business	184500.00
0005435982642	26210	Business	184500.00
0005433754779	26210	Business	184500.00
0005435982617	26210	Economy	67700.00
0005433435169	26210	Economy	67700.00
0005435982698	26210	Economy	67700.00
0005433764700	26210	Economy	67700.00
0005433435178	26210	Economy	61500.00
0005432655599	26210	Economy	61500.00
0005433754757	26210	Economy	61500.00
0005434731246	26210	Economy	61500.00
0005435982689	26210	Economy	61500.00
0005432985650	26210	Economy	61500.00
0005432985660	26210	Economy	61500.00
0005434731244	26210	Economy	61500.00
0005433754631	26210	Economy	61500.00
0005433764695	26210	Economy	61500.00
0005435982588	26210	Economy	61500.00
0005433754684	26210	Economy	61500.00
0005432985628	26210	Economy	61500.00
0005433754593	26210	Economy	61500.00
0005435982615	26210	Economy	61500.00
0005435982401	26210	Economy	61500.00
0005433435180	26210	Economy	61500.00
0005432985640	26210	Economy	61500.00
0005432985637	26210	Economy	61500.00
0005433435160	26210	Economy	61500.00
0005433754643	26210	Economy	61500.00
0005433754692	26210	Economy	61500.00
0005433754817	26210	Economy	61500.00
0005433435174	26210	Economy	61500.00
0005433764693	26210	Economy	61500.00
0005432869635	26210	Economy	61500.00
0005433755075	26210	Economy	61500.00
0005432049528	26210	Economy	61500.00
0005432985635	26210	Economy	61500.00
0005433754588	26210	Economy	61500.00
0005433754737	26210	Economy	61500.00
0005432051184	26210	Economy	61500.00
0005435982251	26210	Economy	61500.00
0005435982616	26210	Economy	61500.00
0005433754725	26210	Economy	61500.00
0005432985647	26210	Economy	61500.00
0005432985651	26210	Economy	61500.00
0005435982610	26210	Economy	61500.00
0005432985633	26210	Economy	61500.00
0005433754681	26210	Economy	61500.00
0005432985657	26210	Economy	61500.00
0005435982692	26210	Economy	61500.00
0005433754589	26210	Economy	61500.00
0005433754732	26210	Economy	61500.00
0005433754559	26210	Economy	61500.00
0005433754736	26210	Economy	61500.00
0005433766673	26210	Economy	61500.00
0005432049527	26210	Economy	61500.00
0005435982739	26210	Economy	61500.00
0005435982638	26210	Economy	61500.00
0005435982570	26210	Economy	61500.00
0005433754549	26210	Economy	61500.00
0005435982706	26210	Economy	61500.00
0005433754890	26210	Economy	61500.00
0005433754445	26210	Economy	61500.00
0005435982727	26210	Economy	61500.00
0005435982609	26210	Economy	61500.00
0005432655625	26210	Economy	61500.00
0005433435165	26210	Economy	61500.00
0005432051183	26210	Economy	61500.00
0005433754735	26210	Economy	61500.00
0005433754683	26210	Economy	61500.00
0005432869638	26210	Economy	61500.00
0005435982630	26210	Economy	61500.00
0005433435167	26210	Economy	61500.00
0005433435170	26210	Economy	61500.00
0005433754756	26210	Economy	61500.00
0005433435158	26210	Economy	61500.00
0005433766674	26210	Economy	61500.00
0005433754796	26210	Economy	61500.00
0005432985652	26210	Economy	61500.00
0005432985656	26210	Economy	61500.00
0005435982623	26210	Economy	61500.00
0005435982747	26210	Economy	61500.00
0005432985659	26210	Economy	61500.00
0005433754488	26210	Economy	61500.00
0005432985634	26210	Economy	61500.00
0005433754514	26210	Economy	61500.00
0005435982717	26210	Economy	61500.00
0005432985638	26210	Economy	61500.00
0005435982683	26210	Economy	61500.00
0005432985643	26210	Economy	61500.00
0005432049525	26210	Economy	61500.00
0005433435186	26210	Economy	61500.00
0005433435173	26210	Economy	61500.00
0005435982699	26210	Economy	61500.00
0005433435162	26210	Economy	61500.00
0005435982252	26210	Economy	61500.00
0005432985648	26210	Economy	61500.00
0005433435161	26210	Economy	67700.00
0005432655600	26210	Economy	61500.00
0005433754760	26210	Economy	61500.00
0005432985636	26210	Economy	61500.00
0005435982632	26210	Economy	67700.00
0005433754551	26210	Economy	67700.00
0005433435187	26210	Economy	61500.00
0005433754682	26210	Economy	61500.00
0005433435181	26210	Economy	61500.00
0005435982656	26210	Economy	61500.00
0005433754606	26210	Economy	61500.00
0005435982439	26210	Economy	61500.00
0005432985641	26210	Economy	61500.00
0005433435171	26210	Economy	61500.00
0005435982738	26210	Economy	61500.00
0005432985654	26210	Economy	61500.00
0005435982657	26210	Economy	61500.00
0005433435182	26210	Economy	61500.00
0005433755114	26210	Economy	61500.00
0005433754594	26210	Economy	61500.00
0005433435185	26210	Economy	61500.00
0005433754632	26210	Economy	61500.00
0005435982740	26210	Economy	61500.00
0005432655621	26210	Economy	61500.00
0005433435166	26210	Economy	61500.00
0005433435164	26210	Economy	61500.00
0005433435176	26210	Economy	61500.00
0005433435179	26210	Economy	61500.00
0005435982550	26210	Economy	61500.00
0005435982569	26210	Economy	61500.00
0005435982662	26210	Economy	61500.00
0005432985658	26210	Economy	61500.00
0005433755113	26210	Economy	61500.00
0005435982525	26210	Economy	61500.00
0005433435172	26210	Economy	61500.00
0005432985653	26210	Economy	61500.00
0005433435159	26210	Economy	61500.00
0005435982666	26210	Economy	61500.00
0005433754607	26210	Economy	61500.00
0005435982587	26210	Economy	61500.00
0005435982723	26210	Economy	61500.00
0005433766669	26210	Economy	61500.00
0005435982663	26210	Economy	61500.00
0005432985631	26210	Economy	61500.00
0005435982542	26210	Economy	61500.00
0005435982682	26210	Economy	61500.00
0005435982697	26210	Economy	61500.00
0005432985649	26210	Economy	61500.00
0005435982631	26210	Economy	61500.00
0005432985646	26210	Economy	61500.00
0005435982737	26210	Economy	61500.00
0005433754546	26210	Economy	61500.00
0005433435177	26210	Economy	61500.00
0005433754685	26210	Economy	61500.00
0005435982688	26210	Economy	61500.00
0005432985632	26210	Economy	61500.00
0005433754733	26210	Economy	61500.00
0005432869636	26210	Economy	61500.00
0005435982644	26210	Economy	61500.00
0005433754659	26210	Economy	61500.00
0005433754691	26210	Economy	61500.00
0005433754513	26210	Economy	61500.00
0005435982724	26210	Economy	61500.00
0005432985644	26210	Economy	61500.00
0005432869640	26210	Economy	61500.00
0005432985630	26210	Economy	61500.00
0005432869639	26210	Economy	61500.00
0005433435175	26210	Economy	61500.00
0005433754889	26210	Economy	61500.00
0005435982667	26210	Economy	61500.00
0005433754776	26210	Economy	61500.00
0005433754797	26210	Economy	61500.00
0005432655620	26210	Economy	61500.00
0005433435183	26210	Economy	61500.00
0005433754818	26210	Economy	61500.00
0005433435163	26210	Economy	61500.00
0005435982693	26210	Economy	61500.00
0005435982661	26210	Economy	61500.00
0005432869637	26210	Economy	61500.00
0005433435168	26210	Economy	61500.00
0005432985639	26210	Economy	61500.00
0005433754861	26210	Economy	61500.00
0005432268011	1497	Business	38900.00
0005433151863	1497	Business	38900.00
0005434029678	1497	Business	38900.00
0005433151783	1497	Business	38900.00
0005433764696	1497	Business	38900.00
0005433931487	1497	Business	38900.00
0005434375408	1497	Business	38900.00
0005434375421	1497	Business	38900.00
0005433931482	1497	Business	38900.00
0005433764698	1497	Business	38900.00
0005434375430	1497	Business	38900.00
0005434375449	1497	Business	38900.00
0005434375435	1497	Economy	13000.00
0005434375442	1497	Economy	13000.00
0005434375444	1497	Economy	13000.00
0005433460474	1497	Economy	13000.00
0005433151757	1497	Economy	13000.00
0005433151807	1497	Economy	13000.00
0005434375443	1497	Economy	13000.00
0005434375446	1497	Economy	13000.00
0005433151811	1497	Economy	13000.00
0005433151688	1497	Economy	13000.00
0005433151808	1497	Economy	13000.00
0005433151731	1497	Economy	13000.00
0005433151771	1497	Economy	13000.00
0005433931505	1497	Economy	13000.00
0005433460473	1497	Economy	13000.00
0005433151610	1497	Economy	13000.00
0005434375433	1497	Economy	13000.00
0005434375405	1497	Economy	13000.00
0005433151582	1497	Economy	13000.00
0005433151711	1497	Economy	13000.00
0005433151834	1497	Economy	13000.00
0005433151832	1497	Economy	13000.00
0005432268012	1497	Economy	13000.00
0005434375419	1497	Economy	13000.00
0005434375422	1497	Economy	13000.00
0005434375426	1497	Economy	13000.00
0005434375404	1497	Economy	13000.00
0005432268009	1497	Economy	13000.00
0005434375438	1497	Economy	13000.00
0005434375447	1497	Economy	13000.00
0005433764692	1497	Economy	13000.00
0005433931485	1497	Economy	13000.00
0005434375440	1497	Economy	13000.00
0005432268010	1497	Economy	13000.00
0005433151847	1497	Economy	14300.00
0005434375427	1497	Economy	14300.00
0005434375423	1497	Economy	14300.00
0005433931499	1497	Economy	14300.00
0005432268014	1497	Economy	13000.00
0005433151704	1497	Economy	13000.00
0005434375432	1497	Economy	13000.00
0005434375411	1497	Economy	13000.00
0005434375434	1497	Economy	13000.00
0005434375445	1497	Economy	13000.00
0005434375407	1497	Economy	13000.00
0005433151512	1497	Economy	13000.00
0005433151826	1497	Economy	13000.00
0005434375413	1497	Economy	13000.00
0005434375417	1497	Economy	13000.00
0005434375429	1497	Economy	13000.00
0005434375403	1497	Economy	13000.00
0005433461625	1497	Economy	13000.00
0005432268015	1497	Economy	13000.00
0005434375439	1497	Economy	13000.00
0005434375428	1497	Economy	13000.00
0005434375437	1497	Economy	13000.00
0005434375415	1497	Economy	13000.00
0005434375410	1497	Economy	13000.00
0005434375441	1497	Economy	13000.00
0005433151806	1497	Economy	13000.00
0005434375400	1497	Economy	13000.00
0005434029679	1497	Economy	13000.00
0005434375431	1497	Economy	13000.00
0005433151732	1497	Economy	13000.00
0005434375448	1497	Economy	13000.00
0005433931498	1497	Economy	13000.00
0005434375418	1497	Economy	13000.00
0005434375402	1497	Economy	13000.00
0005433151701	1497	Economy	13000.00
0005433151710	1497	Economy	13000.00
0005433931483	1497	Economy	13000.00
0005433151609	1497	Economy	13000.00
0005434375414	1497	Economy	13000.00
0005434375412	1497	Economy	13000.00
0005434375399	1497	Economy	13000.00
0005433461626	1497	Economy	13000.00
0005433151746	1497	Economy	13000.00
0005434375401	1497	Economy	13000.00
0005433151608	1497	Economy	13000.00
0005433151660	1497	Economy	13000.00
0005433151644	1497	Economy	13000.00
0005434375425	1497	Economy	13000.00
0005434375406	1497	Economy	13000.00
0005432268013	1497	Economy	13000.00
0005434375416	1497	Economy	13000.00
0005434375424	1497	Economy	13000.00
0005433151831	1497	Economy	13000.00
0005434375436	1497	Economy	13000.00
0005433764697	1497	Economy	13000.00
0005433151768	1497	Economy	13000.00
0005434375420	1497	Economy	13000.00
0005433151758	1497	Economy	13000.00
0005433151730	1497	Economy	13000.00
0005433151690	1497	Economy	13000.00
0005434375409	1497	Economy	13000.00
0005434375398	1497	Economy	13000.00
0005433152015	20158	Business	38900.00
0005434375206	20158	Business	38900.00
0005434374939	20158	Business	38900.00
0005433151994	20158	Business	38900.00
0005434375217	20158	Business	38900.00
0005434375028	20158	Business	38900.00
0005434375174	20158	Business	38900.00
0005434374894	20158	Economy	13000.00
0005433152003	20158	Economy	13000.00
0005434375030	20158	Economy	13000.00
0005433151993	20158	Economy	13000.00
0005434375049	20158	Economy	13000.00
0005434375101	20158	Economy	13000.00
0005433931519	20158	Economy	13000.00
0005433152014	20158	Economy	13000.00
0005434374937	20158	Economy	13000.00
0005433152002	20158	Economy	13000.00
0005434374913	20158	Economy	13000.00
0005434374938	20158	Economy	13000.00
0005434375027	20158	Economy	13000.00
0005434375110	20158	Economy	13000.00
0005433152009	20158	Economy	13000.00
0005434375147	20158	Economy	13000.00
0005434375113	20158	Economy	13000.00
0005434374996	20158	Economy	13000.00
0005434375213	20158	Economy	13000.00
0005433152000	20158	Economy	13000.00
0005433152005	20158	Economy	13000.00
0005433152010	20158	Economy	13000.00
0005433764716	20158	Economy	13000.00
0005433152020	20158	Economy	13000.00
0005434374872	20158	Economy	13000.00
0005434375031	20158	Economy	13000.00
0005434375135	20158	Economy	13000.00
0005433152021	20158	Economy	14300.00
0005433152019	20158	Economy	14300.00
0005434374968	20158	Economy	14300.00
0005433151991	20158	Economy	14300.00
0005433152016	20158	Economy	13000.00
0005434374984	20158	Economy	13000.00
0005433152022	20158	Economy	13000.00
0005433151999	20158	Economy	13000.00
0005434375111	20158	Economy	13000.00
0005434375132	20158	Economy	13000.00
0005434374860	20158	Economy	13000.00
0005433151997	20158	Economy	13000.00
0005434375048	20158	Economy	13000.00
0005434029701	20158	Economy	13000.00
0005433152018	20158	Economy	13000.00
0005434374848	20158	Economy	13000.00
0005432056366	20158	Economy	13000.00
0005434375205	20158	Economy	13000.00
0005434375102	20158	Economy	13000.00
0005434375126	20158	Economy	13000.00
0005434375112	20158	Economy	13000.00
0005433152023	20158	Economy	13000.00
0005433152011	20158	Economy	13000.00
0005433152001	20158	Economy	13000.00
0005433152004	20158	Economy	13000.00
0005433151998	20158	Economy	13000.00
0005433151995	20158	Economy	13000.00
0005434374873	20158	Economy	13000.00
0005434375107	20158	Economy	13000.00
0005433152013	20158	Economy	13000.00
0005434375085	20158	Economy	13000.00
0005433152008	20158	Economy	13000.00
0005433151989	20158	Economy	13000.00
0005432056367	20158	Economy	13000.00
0005434375018	20158	Economy	13000.00
0005434375134	20158	Economy	13000.00
0005434375204	20158	Economy	13000.00
0005434374971	20158	Economy	13000.00
0005434375084	20158	Economy	13000.00
0005433152007	20158	Economy	13000.00
0005434375169	20158	Economy	13000.00
0005434375146	20158	Economy	13000.00
0005434374985	20158	Economy	13000.00
0005432056368	20158	Economy	13000.00
0005433151992	20158	Economy	13000.00
0005434374967	20158	Economy	13000.00
0005433152017	20158	Economy	13000.00
0005433764715	20158	Economy	13000.00
0005434029702	20158	Economy	13000.00
0005434375133	20158	Economy	13000.00
0005434374952	20158	Economy	13000.00
0005433151996	20158	Economy	13000.00
0005433152012	20158	Economy	13000.00
0005433151990	20158	Economy	13000.00
0005433152006	20158	Economy	13000.00
0005434375026	20158	Economy	13000.00
0005432056364	20158	Economy	13000.00
0005433764717	20158	Economy	13000.00
0005432056365	20158	Economy	13000.00
0005432425303	589	Business	27500.00
0005432425297	589	Business	27500.00
0005432425323	589	Business	27500.00
0005432425327	589	Business	27500.00
0005432425312	589	Business	27500.00
0005432425318	589	Business	27500.00
0005432282989	589	Business	27500.00
0005432425298	589	Economy	10100.00
0005432425329	589	Economy	10100.00
0005432425295	589	Economy	10100.00
0005432282988	589	Economy	9200.00
0005432425300	589	Economy	9200.00
0005432425314	589	Economy	9200.00
0005432425309	589	Economy	9200.00
0005432282986	589	Economy	9200.00
0005432425313	589	Economy	9200.00
0005432282990	589	Economy	9200.00
0005432425320	589	Economy	9200.00
0005432425310	589	Economy	9200.00
0005432425330	589	Economy	9200.00
0005432425296	589	Economy	9200.00
0005432425324	589	Economy	9200.00
0005432425328	589	Economy	9200.00
0005432425333	589	Economy	9200.00
0005432425335	589	Economy	9200.00
0005432425294	589	Economy	9200.00
0005432425332	589	Economy	10100.00
0005432282984	589	Economy	9200.00
0005432425334	589	Economy	10100.00
0005432425301	589	Economy	9200.00
0005432425311	589	Economy	9200.00
0005432425319	589	Economy	9200.00
0005432425315	589	Economy	9200.00
0005432425317	589	Economy	9200.00
0005432425321	589	Economy	9200.00
0005432425308	589	Economy	9200.00
0005432282985	589	Economy	9200.00
0005432425304	589	Economy	9200.00
0005432425316	589	Economy	9200.00
0005432425325	589	Economy	9200.00
0005432425326	589	Economy	9200.00
0005432425322	589	Economy	9200.00
0005432282987	589	Economy	9200.00
0005432425299	589	Economy	9200.00
0005432425302	589	Economy	9200.00
0005432425331	589	Economy	9200.00
0005432425307	589	Economy	9200.00
0005432425306	589	Economy	9200.00
0005432425305	589	Economy	9200.00
0005432302397	12841	Economy	9200.00
0005432302398	12841	Economy	9200.00
0005432302396	12841	Economy	9200.00
0005432424810	12915	Business	27500.00
0005432424809	12915	Business	27500.00
0005432424623	12915	Business	27500.00
0005432424829	12915	Business	27500.00
0005432424679	12915	Business	27500.00
0005432424770	12915	Business	27500.00
0005432424701	12915	Economy	9200.00
0005432424746	12915	Economy	9200.00
0005432424621	12915	Economy	9200.00
0005432424744	12915	Economy	9200.00
0005432424747	12915	Economy	9200.00
0005432424848	12915	Economy	9200.00
0005432424833	12915	Economy	9200.00
0005432424759	12915	Economy	9200.00
0005432424815	12915	Economy	9200.00
0005432424822	12915	Economy	9200.00
0005432424854	12915	Economy	9200.00
0005432424791	12915	Economy	9200.00
0005432424806	12915	Economy	9200.00
0005432424862	12915	Economy	9200.00
0005432424696	12915	Economy	9200.00
0005432424811	12915	Economy	9200.00
0005432424797	12915	Economy	9200.00
0005432424803	12915	Economy	10100.00
0005432424856	12915	Economy	9200.00
0005432424783	12915	Economy	9200.00
0005432424703	12915	Economy	9200.00
0005432424835	12915	Economy	9200.00
0005432424745	12915	Economy	9200.00
0005432424669	12915	Economy	9200.00
0005432424588	12915	Economy	9200.00
0005432424697	12915	Economy	9200.00
0005432424855	12915	Economy	9200.00
0005432424735	12915	Economy	9200.00
0005432424828	12915	Economy	9200.00
0005432424736	12915	Economy	9200.00
0005432424836	12915	Economy	9200.00
0005432424628	12915	Economy	9200.00
0005432424834	12915	Economy	9200.00
0005432424643	12915	Economy	9200.00
0005432424790	12915	Economy	9200.00
0005432424727	12915	Economy	9200.00
0005432424818	12915	Economy	9200.00
0005432424681	12915	Economy	9200.00
0005432424802	12915	Economy	9200.00
0005432424644	12915	Economy	9200.00
0005434735741	454	Business	24500.00
0005433058351	454	Business	24500.00
0005434024875	454	Business	24500.00
0005434024863	454	Business	24500.00
0005433684426	454	Business	24500.00
0005434024918	454	Business	24500.00
0005434024884	454	Business	24500.00
0005432235772	454	Business	24500.00
0005433058218	454	Business	24500.00
0005433929650	454	Business	24500.00
0005434024915	454	Business	24500.00
0005434024860	454	Business	24500.00
0005434028349	454	Business	24500.00
0005434024913	454	Business	24500.00
0005433058299	454	Business	24500.00
0005433058210	454	Business	24500.00
0005434024908	454	Business	24500.00
0005433058290	454	Business	24500.00
0005434029698	454	Business	24500.00
0005434024867	454	Business	24500.00
0005433058300	454	Business	24500.00
0005434024895	454	Business	24500.00
0005433684432	454	Economy	9000.00
0005434024907	454	Economy	8200.00
0005432045646	454	Economy	8200.00
0005433684425	454	Economy	8200.00
0005433058240	454	Economy	8200.00
0005434024862	454	Economy	8200.00
0005434028348	454	Economy	8200.00
0005433929649	454	Economy	8200.00
0005434024916	454	Economy	8200.00
0005434024902	454	Economy	8200.00
0005434024858	454	Economy	8200.00
0005433929646	454	Economy	8200.00
0005434024922	454	Economy	8200.00
0005433058271	454	Economy	8200.00
0005434024900	454	Economy	8200.00
0005434024920	454	Economy	8200.00
0005434024896	454	Economy	8200.00
0005433058322	454	Economy	8200.00
0005434024881	454	Economy	8200.00
0005434024921	454	Economy	8200.00
0005434028351	454	Economy	8200.00
0005433058518	454	Economy	8200.00
0005433058517	454	Economy	8200.00
0005433058288	454	Economy	8200.00
0005433058079	454	Economy	8200.00
0005434735710	454	Economy	8200.00
0005433929636	454	Economy	8200.00
0005434024885	454	Economy	8200.00
0005433058278	454	Economy	8200.00
0005434024888	454	Economy	8200.00
0005433058213	454	Economy	8200.00
0005434024873	454	Economy	8200.00
0005433058377	454	Economy	8200.00
0005434024898	454	Economy	8200.00
0005434735721	454	Economy	8200.00
0005434024859	454	Economy	8200.00
0005434024926	454	Economy	8200.00
0005433058209	454	Economy	8200.00
0005433058317	454	Economy	8200.00
0005434024876	454	Economy	8200.00
0005432235769	454	Economy	8200.00
0005434024912	454	Economy	8200.00
0005433058309	454	Economy	8200.00
0005434024890	454	Economy	8200.00
0005433058323	454	Economy	8200.00
0005432045645	454	Economy	8200.00
0005434024889	454	Economy	8200.00
0005433929655	454	Economy	8200.00
0005434032099	454	Economy	8200.00
0005433058291	454	Economy	8200.00
0005434024878	454	Economy	8200.00
0005433058394	454	Economy	8200.00
0005434024901	454	Economy	8200.00
0005434032100	454	Economy	8200.00
0005434024882	454	Economy	8200.00
0005433058301	454	Economy	8200.00
0005433058222	454	Economy	8200.00
0005434032101	454	Economy	8200.00
0005434024868	454	Economy	8200.00
0005433058304	454	Economy	8200.00
0005434024891	454	Economy	8200.00
0005433058239	454	Economy	8200.00
0005432235773	454	Economy	8200.00
0005433058221	454	Economy	8200.00
0005434024872	454	Economy	8200.00
0005433058155	454	Economy	8200.00
0005434024914	454	Economy	8200.00
0005434029699	454	Economy	8200.00
0005434024874	454	Economy	8200.00
0005433929642	454	Economy	8200.00
0005434024906	454	Economy	9000.00
0005434735709	454	Economy	8200.00
0005434024924	454	Economy	8200.00
0005432235770	454	Economy	9000.00
0005434024864	454	Economy	9000.00
0005433058101	454	Economy	8200.00
0005434028352	454	Economy	8200.00
0005434024894	454	Economy	8200.00
0005433058274	454	Economy	8200.00
0005434024909	454	Economy	8200.00
0005433058246	454	Economy	8200.00
0005433058289	454	Economy	8200.00
0005434024879	454	Economy	8200.00
0005432235774	454	Economy	8200.00
0005434028350	454	Economy	8200.00
0005434024887	454	Economy	8200.00
0005434024893	454	Economy	8200.00
0005432235771	454	Economy	8200.00
0005434024897	454	Economy	8200.00
0005434024899	454	Economy	8200.00
0005434024905	454	Economy	8200.00
0005434024925	454	Economy	8200.00
0005434024917	454	Economy	8200.00
0005434024927	454	Economy	8200.00
0005434735720	454	Economy	8200.00
0005434024866	454	Economy	8200.00
0005434024865	454	Economy	8200.00
0005433058275	454	Economy	8200.00
0005433058316	454	Economy	8200.00
0005434024886	454	Economy	8200.00
0005433058242	454	Economy	8200.00
0005433058214	454	Economy	8200.00
0005434024911	454	Economy	8200.00
0005433058376	454	Economy	8200.00
0005434029700	454	Economy	8200.00
0005434024870	454	Economy	8200.00
0005434024880	454	Economy	8200.00
0005434024869	454	Economy	8200.00
0005433058253	454	Economy	8200.00
0005433058270	454	Economy	8200.00
0005434024871	454	Economy	8200.00
0005433058219	454	Economy	8200.00
0005434024877	454	Economy	8200.00
0005434024903	454	Economy	8200.00
0005433058245	454	Economy	8200.00
0005432235767	454	Economy	8200.00
0005434024861	454	Economy	8200.00
0005434024923	454	Economy	8200.00
0005434024892	454	Economy	8200.00
0005433058211	454	Economy	8200.00
0005434024910	454	Economy	8200.00
0005432235768	454	Economy	8200.00
0005434024883	454	Economy	8200.00
0005434024919	454	Economy	8200.00
0005434032102	454	Economy	8200.00
0005434024904	454	Economy	8200.00
0005432235766	454	Economy	8200.00
0005434024211	12670	Business	24500.00
0005434024072	12670	Business	24500.00
0005434024222	12670	Business	24500.00
0005434024351	12670	Business	24500.00
0005434029679	12670	Business	24500.00
0005433684457	12670	Business	24500.00
0005434024332	12670	Business	24500.00
0005434024200	12670	Business	24500.00
0005433684458	12670	Business	24500.00
0005434024249	12670	Business	24500.00
0005434028316	12670	Business	24500.00
0005434024319	12670	Business	24500.00
0005434032037	12670	Business	24500.00
0005432156446	12670	Business	24500.00
0005434024213	12670	Business	24500.00
0005434024177	12670	Business	24500.00
0005434024034	12670	Economy	9000.00
0005434024450	12670	Economy	9000.00
0005434024182	12670	Economy	9000.00
0005434024647	12670	Economy	8200.00
0005433058576	12670	Economy	8200.00
0005434024386	12670	Economy	8200.00
0005433058574	12670	Economy	8200.00
0005434024478	12670	Economy	8200.00
0005433058590	12670	Economy	8200.00
0005433058588	12670	Economy	8200.00
0005433058592	12670	Economy	8200.00
0005434024333	12670	Economy	8200.00
0005433058601	12670	Economy	8200.00
0005432156442	12670	Economy	8200.00
0005434024417	12670	Economy	8200.00
0005434735782	12670	Economy	8200.00
0005434024292	12670	Economy	8200.00
0005433058599	12670	Economy	8200.00
0005434032036	12670	Economy	8200.00
0005434024360	12670	Economy	8200.00
0005433058578	12670	Economy	8200.00
0005434024403	12670	Economy	8200.00
0005434024275	12670	Economy	8200.00
0005434024428	12670	Economy	8200.00
0005433058567	12670	Economy	8200.00
0005434024050	12670	Economy	8200.00
0005434024477	12670	Economy	8200.00
0005433929687	12670	Economy	8200.00
0005434024283	12670	Economy	8200.00
0005434024218	12670	Economy	8200.00
0005433058586	12670	Economy	8200.00
0005434024484	12670	Economy	8200.00
0005434032047	12670	Economy	8200.00
0005434024219	12670	Economy	8200.00
0005433058603	12670	Economy	8200.00
0005432156441	12670	Economy	8200.00
0005433058577	12670	Economy	8200.00
0005434024483	12670	Economy	8200.00
0005433058597	12670	Economy	8200.00
0005433058606	12670	Economy	8200.00
0005433929684	12670	Economy	8200.00
0005434024267	12670	Economy	8200.00
0005433058581	12670	Economy	8200.00
0005433058589	12670	Economy	8200.00
0005434735780	12670	Economy	8200.00
0005434735785	12670	Economy	8200.00
0005434024390	12670	Economy	8200.00
0005434024264	12670	Economy	8200.00
0005434024439	12670	Economy	8200.00
0005434024391	12670	Economy	8200.00
0005434024523	12670	Economy	8200.00
0005433058598	12670	Economy	8200.00
0005434029678	12670	Economy	8200.00
0005433058600	12670	Economy	8200.00
0005433929685	12670	Economy	8200.00
0005434735784	12670	Economy	8200.00
0005434024223	12670	Economy	8200.00
0005434024646	12670	Economy	8200.00
0005434024384	12670	Economy	8200.00
0005434024479	12670	Economy	8200.00
0005434024385	12670	Economy	9000.00
0005433058568	12670	Economy	8200.00
0005433058585	12670	Economy	8200.00
0005433058595	12670	Economy	9000.00
0005434024504	12670	Economy	8200.00
0005433058572	12670	Economy	8200.00
0005434024073	12670	Economy	8200.00
0005433058571	12670	Economy	8200.00
0005434024509	12670	Economy	8200.00
0005434024274	12670	Economy	8200.00
0005434024037	12670	Economy	8200.00
0005433058569	12670	Economy	8200.00
0005433058584	12670	Economy	8200.00
0005434024380	12670	Economy	8200.00
0005434735783	12670	Economy	8200.00
0005433058594	12670	Economy	8200.00
0005434024398	12670	Economy	8200.00
0005434024505	12670	Economy	8200.00
0005434024449	12670	Economy	8200.00
0005433058596	12670	Economy	8200.00
0005433058591	12670	Economy	8200.00
0005433058566	12670	Economy	8200.00
0005434024212	12670	Economy	8200.00
0005434024301	12670	Economy	8200.00
0005434024429	12670	Economy	8200.00
0005434735781	12670	Economy	8200.00
0005433058593	12670	Economy	8200.00
0005433058565	12670	Economy	8200.00
0005433058575	12670	Economy	8200.00
0005434024308	12670	Economy	8200.00
0005433058587	12670	Economy	8200.00
0005434024302	12670	Economy	8200.00
0005433058582	12670	Economy	8200.00
0005434024503	12670	Economy	8200.00
0005433058604	12670	Economy	8200.00
0005434024510	12670	Economy	8200.00
0005433058579	12670	Economy	8200.00
0005434028327	12670	Economy	8200.00
0005434024266	12670	Economy	8200.00
0005434024538	12670	Economy	8200.00
0005434024413	12670	Economy	8200.00
0005434024383	12670	Economy	8200.00
0005434023895	12670	Economy	8200.00
0005433058602	12670	Economy	8200.00
0005434024248	12670	Economy	8200.00
0005434024166	12670	Economy	8200.00
0005432156444	12670	Economy	8200.00
0005434028315	12670	Economy	8200.00
0005434024238	12670	Economy	8200.00
0005433058570	12670	Economy	8200.00
0005433058580	12670	Economy	8200.00
0005433058573	12670	Economy	8200.00
0005433058583	12670	Economy	8200.00
0005434024451	12670	Economy	8200.00
0005432156445	12670	Economy	8200.00
0005432156443	12670	Economy	8200.00
0005433058605	12670	Economy	8200.00
0005432157526	12670	Economy	8200.00
0005434024356	12670	Economy	8200.00
0005433929686	12670	Economy	8200.00
0005434024300	12670	Economy	8200.00
0005434024549	12670	Economy	8200.00
0005433924946	2165	Business	34700.00
0005433036657	2165	Business	34700.00
0005433924926	2165	Business	34700.00
0005433924981	2165	Business	34700.00
0005433036756	2165	Business	34700.00
0005433036934	2165	Business	34700.00
0005433924988	2165	Business	34700.00
0005433875407	2165	Business	34700.00
0005433924966	2165	Business	34700.00
0005433036622	2165	Business	34700.00
0005433036882	2165	Business	34700.00
0005433925009	2165	Business	34700.00
0005433924998	2165	Business	34700.00
0005433036693	2165	Business	34700.00
0005433924925	2165	Business	34700.00
0005432231749	2165	Business	34700.00
0005433924956	2165	Business	34700.00
0005433036784	2165	Business	34700.00
0005433929687	2165	Business	34700.00
0005433924957	2165	Business	34700.00
0005433036874	2165	Business	34700.00
0005433924964	2165	Business	34700.00
0005433925023	2165	Business	34700.00
0005433036883	2165	Business	34700.00
0005433924953	2165	Business	34700.00
0005433925000	2165	Business	34700.00
0005433036497	2165	Business	34700.00
0005433924963	2165	Business	34700.00
0005433036785	2165	Economy	12700.00
0005433924930	2165	Economy	12700.00
0005433924937	2165	Economy	12700.00
0005433036498	2165	Economy	12700.00
0005433036581	2165	Economy	11600.00
0005433036952	2165	Economy	11600.00
0005433924967	2165	Economy	11600.00
0005433924961	2165	Economy	11600.00
0005433925004	2165	Economy	11600.00
0005432749804	2165	Economy	11600.00
0005433924948	2165	Economy	11600.00
0005433925012	2165	Economy	11600.00
0005433924935	2165	Economy	11600.00
0005433925014	2165	Economy	11600.00
0005433925011	2165	Economy	11600.00
0005433875404	2165	Economy	11600.00
0005433924997	2165	Economy	11600.00
0005433036903	2165	Economy	11600.00
0005433924936	2165	Economy	11600.00
0005433924968	2165	Economy	11600.00
0005433036771	2165	Economy	11600.00
0005433036655	2165	Economy	11600.00
0005433925020	2165	Economy	11600.00
0005433924960	2165	Economy	11600.00
0005433924979	2165	Economy	11600.00
0005433924989	2165	Economy	11600.00
0005433924983	2165	Economy	11600.00
0005433924992	2165	Economy	11600.00
0005433924980	2165	Economy	11600.00
0005433924987	2165	Economy	11600.00
0005433929861	2165	Economy	11600.00
0005433036928	2165	Economy	11600.00
0005433924927	2165	Economy	11600.00
0005433929685	2165	Economy	11600.00
0005433036660	2165	Economy	11600.00
0005433924990	2165	Economy	11600.00
0005433924929	2165	Economy	11600.00
0005433036708	2165	Economy	11600.00
0005433036656	2165	Economy	11600.00
0005433036718	2165	Economy	11600.00
0005433036575	2165	Economy	11600.00
0005433036927	2165	Economy	11600.00
0005433036464	2165	Economy	11600.00
0005433924973	2165	Economy	11600.00
0005433036762	2165	Economy	11600.00
0005433036707	2165	Economy	11600.00
0005433036761	2165	Economy	11600.00
0005434028316	2165	Economy	11600.00
0005433924970	2165	Economy	11600.00
0005433924991	2165	Economy	11600.00
0005433036637	2165	Economy	11600.00
0005433924950	2165	Economy	11600.00
0005433036544	2165	Economy	11600.00
0005433036546	2165	Economy	11600.00
0005433925019	2165	Economy	11600.00
0005433929684	2165	Economy	11600.00
0005433924975	2165	Economy	11600.00
0005433036709	2165	Economy	11600.00
0005433925010	2165	Economy	11600.00
0005432749809	2165	Economy	11600.00
0005433036839	2165	Economy	11600.00
0005433925007	2165	Economy	11600.00
0005432044573	2165	Economy	11600.00
0005433924978	2165	Economy	11600.00
0005433924939	2165	Economy	11600.00
0005433036933	2165	Economy	11600.00
0005433924934	2165	Economy	11600.00
0005432749806	2165	Economy	11600.00
0005433924974	2165	Economy	11600.00
0005433925018	2165	Economy	11600.00
0005432749808	2165	Economy	11600.00
0005433925022	2165	Economy	11600.00
0005433924982	2165	Economy	11600.00
0005433925016	2165	Economy	11600.00
0005433036499	2165	Economy	11600.00
0005434028315	2165	Economy	11600.00
0005433924944	2165	Economy	11600.00
0005433931519	2165	Economy	11600.00
0005433036673	2165	Economy	11600.00
0005433036755	2165	Economy	11600.00
0005433925013	2165	Economy	11600.00
0005433036574	2165	Economy	11600.00
0005433036786	2165	Economy	11600.00
0005433924965	2165	Economy	11600.00
0005432749805	2165	Economy	11600.00
0005433036500	2165	Economy	11600.00
0005433925008	2165	Economy	11600.00
0005433924995	2165	Economy	12700.00
0005433929862	2165	Economy	12700.00
0005433924955	2165	Economy	11600.00
0005432749807	2165	Economy	11600.00
0005433924977	2165	Economy	12700.00
0005433924943	2165	Economy	12700.00
0005433924969	2165	Economy	11600.00
0005432231745	2165	Economy	11600.00
0005432231748	2165	Economy	11600.00
0005433924942	2165	Economy	11600.00
0005433924931	2165	Economy	11600.00
0005432231747	2165	Economy	11600.00
0005433036793	2165	Economy	11600.00
0005433924959	2165	Economy	11600.00
0005432231752	2165	Economy	11600.00
0005434028327	2165	Economy	11600.00
0005433925017	2165	Economy	11600.00
0005432231751	2165	Economy	11600.00
0005433929686	2165	Economy	11600.00
0005432044574	2165	Economy	11600.00
0005433036626	2165	Economy	11600.00
0005433924972	2165	Economy	11600.00
0005433924952	2165	Economy	11600.00
0005432231753	2165	Economy	11600.00
0005433925006	2165	Economy	11600.00
0005433924985	2165	Economy	11600.00
0005433924986	2165	Economy	11600.00
0005433925005	2165	Economy	11600.00
0005433036677	2165	Economy	11600.00
0005433924949	2165	Economy	11600.00
0005433036776	2165	Economy	11600.00
0005433924940	2165	Economy	11600.00
0005432231746	2165	Economy	11600.00
0005432231754	2165	Economy	11600.00
0005433924933	2165	Economy	11600.00
0005433036675	2165	Economy	11600.00
0005433924941	2165	Economy	11600.00
0005433924984	2165	Economy	11600.00
0005433925001	2165	Economy	11600.00
0005433875406	2165	Economy	11600.00
0005433925021	2165	Economy	11600.00
0005433036545	2165	Economy	11600.00
0005433924951	2165	Economy	11600.00
0005433036625	2165	Economy	11600.00
0005433925002	2165	Economy	11600.00
0005433924962	2165	Economy	11600.00
0005433924999	2165	Economy	11600.00
0005433924945	2165	Economy	11600.00
0005433924976	2165	Economy	11600.00
0005433924971	2165	Economy	11600.00
0005433875405	2165	Economy	11600.00
0005433036854	2165	Economy	11600.00
0005433924932	2165	Economy	11600.00
0005433925015	2165	Economy	11600.00
0005433924996	2165	Economy	11600.00
0005433924994	2165	Economy	11600.00
0005433925003	2165	Economy	11600.00
0005432231750	2165	Economy	11600.00
0005433036910	2165	Economy	11600.00
0005433924947	2165	Economy	11600.00
0005433036683	2165	Economy	11600.00
0005433924993	2165	Economy	11600.00
0005433036710	2165	Economy	11600.00
0005433924958	2165	Economy	11600.00
0005433924928	2165	Economy	11600.00
0005433036775	2165	Economy	11600.00
0005433036770	2165	Economy	11600.00
0005433924938	2165	Economy	11600.00
0005432231755	2165	Economy	11600.00
0005433924954	2165	Economy	11600.00
0005433036838	2165	Economy	11600.00
0005433036719	2165	Economy	11600.00
0005433037020	2165	Economy	11600.00
0005432044572	2165	Economy	11600.00
0005433923788	24127	Business	34700.00
0005433929660	24127	Business	34700.00
0005433924415	24127	Business	34700.00
0005433037217	24127	Business	34700.00
0005433037195	24127	Business	34700.00
0005433037199	24127	Business	34700.00
0005433037198	24127	Business	34700.00
0005433924112	24127	Business	34700.00
0005433923970	24127	Business	34700.00
0005433931479	24127	Business	34700.00
0005433924137	24127	Business	34700.00
0005433037232	24127	Business	34700.00
0005433924617	24127	Business	34700.00
0005432207707	24127	Business	34700.00
0005433931478	24127	Business	34700.00
0005433923843	24127	Business	34700.00
0005433923992	24127	Business	34700.00
0005433924283	24127	Business	34700.00
0005433037223	24127	Business	34700.00
0005432207708	24127	Business	34700.00
0005433924451	24127	Business	34700.00
0005433924096	24127	Business	34700.00
0005433037234	24127	Business	34700.00
0005433037212	24127	Business	34700.00
0005433924232	24127	Business	34700.00
0005433037201	24127	Business	34700.00
0005432206300	24127	Business	34700.00
0005433924253	24127	Economy	12700.00
0005433929644	24127	Economy	12700.00
0005433037205	24127	Economy	11600.00
0005433924467	24127	Economy	11600.00
0005433929645	24127	Economy	11600.00
0005433924106	24127	Economy	11600.00
0005433924544	24127	Economy	11600.00
0005433037221	24127	Economy	11600.00
0005433929654	24127	Economy	11600.00
0005433037244	24127	Economy	11600.00
0005433923899	24127	Economy	11600.00
0005433923963	24127	Economy	11600.00
0005432206295	24127	Economy	11600.00
0005433924110	24127	Economy	11600.00
0005433924105	24127	Economy	11600.00
0005433037203	24127	Economy	11600.00
0005433924315	24127	Economy	11600.00
0005433037219	24127	Economy	11600.00
0005433924289	24127	Economy	11600.00
0005433923868	24127	Economy	11600.00
0005433037197	24127	Economy	11600.00
0005433924425	24127	Economy	11600.00
0005433924616	24127	Economy	11600.00
0005433924122	24127	Economy	11600.00
0005433924191	24127	Economy	11600.00
0005433924203	24127	Economy	11600.00
0005433037243	24127	Economy	11600.00
0005432206299	24127	Economy	11600.00
0005433924482	24127	Economy	11600.00
0005433923844	24127	Economy	11600.00
0005433924121	24127	Economy	11600.00
0005433924040	24127	Economy	11600.00
0005433924197	24127	Economy	11600.00
0005433037208	24127	Economy	11600.00
0005433924370	24127	Economy	11600.00
0005433875391	24127	Economy	11600.00
0005433037231	24127	Economy	11600.00
0005433924481	24127	Economy	11600.00
0005433037225	24127	Economy	11600.00
0005433923911	24127	Economy	11600.00
0005433037240	24127	Economy	11600.00
0005433923790	24127	Economy	11600.00
0005433931494	24127	Economy	11600.00
0005433924525	24127	Economy	11600.00
0005433924373	24127	Economy	11600.00
0005433037242	24127	Economy	11600.00
0005433924223	24127	Economy	11600.00
0005433924115	24127	Economy	11600.00
0005433923715	24127	Economy	11600.00
0005433924361	24127	Economy	11600.00
0005433924180	24127	Economy	11600.00
0005433037226	24127	Economy	11600.00
0005433931480	24127	Economy	11600.00
0005433923964	24127	Economy	11600.00
0005433923805	24127	Economy	11600.00
0005433037224	24127	Economy	11600.00
0005432749823	24127	Economy	11600.00
0005433037227	24127	Economy	11600.00
0005433924198	24127	Economy	11600.00
0005433924170	24127	Economy	11600.00
0005433924384	24127	Economy	11600.00
0005433924348	24127	Economy	11600.00
0005433924471	24127	Economy	11600.00
0005433929643	24127	Economy	11600.00
0005433924372	24127	Economy	11600.00
0005433924414	24127	Economy	11600.00
0005433924095	24127	Economy	11600.00
0005433923965	24127	Economy	11600.00
0005433037238	24127	Economy	11600.00
0005433037204	24127	Economy	11600.00
0005433924235	24127	Economy	11600.00
0005433924111	24127	Economy	11600.00
0005433923988	24127	Economy	11600.00
0005432206298	24127	Economy	11600.00
0005433037206	24127	Economy	11600.00
0005433924242	24127	Economy	11600.00
0005433923957	24127	Economy	11600.00
0005433037196	24127	Economy	11600.00
0005433037193	24127	Economy	12700.00
0005432749824	24127	Economy	11600.00
0005433924231	24127	Economy	12700.00
0005433037192	24127	Economy	11600.00
0005433037228	24127	Economy	11600.00
0005433037194	24127	Economy	12700.00
0005433924141	24127	Economy	11600.00
0005433037239	24127	Economy	12700.00
0005433037237	24127	Economy	11600.00
0005434028353	24127	Economy	11600.00
0005433037220	24127	Economy	11600.00
0005433929647	24127	Economy	11600.00
0005433924051	24127	Economy	11600.00
0005433037233	24127	Economy	11600.00
0005433037200	24127	Economy	11600.00
0005433924518	24127	Economy	11600.00
0005433923721	24127	Economy	11600.00
0005433037207	24127	Economy	11600.00
0005433924290	24127	Economy	11600.00
0005433924618	24127	Economy	11600.00
0005433924155	24127	Economy	11600.00
0005433037213	24127	Economy	11600.00
0005433924230	24127	Economy	11600.00
0005433929659	24127	Economy	11600.00
0005433924317	24127	Economy	11600.00
0005433037216	24127	Economy	11600.00
0005433037218	24127	Economy	11600.00
0005432206296	24127	Economy	11600.00
0005433875396	24127	Economy	11600.00
0005433037211	24127	Economy	11600.00
0005433923987	24127	Economy	11600.00
0005433924224	24127	Economy	11600.00
0005433037235	24127	Economy	11600.00
0005433924039	24127	Economy	11600.00
0005433875390	24127	Economy	11600.00
0005433037202	24127	Economy	11600.00
0005433923845	24127	Economy	11600.00
0005433037230	24127	Economy	11600.00
0005433924413	24127	Economy	11600.00
0005433924131	24127	Economy	11600.00
0005433923830	24127	Economy	11600.00
0005433929658	24127	Economy	11600.00
0005433037245	24127	Economy	11600.00
0005432206297	24127	Economy	11600.00
0005433037229	24127	Economy	11600.00
0005433924252	24127	Economy	11600.00
0005433037215	24127	Economy	11600.00
0005433923969	24127	Economy	11600.00
0005433924041	24127	Economy	11600.00
0005433037222	24127	Economy	11600.00
0005433037209	24127	Economy	11600.00
0005433037236	24127	Economy	11600.00
0005433924288	24127	Economy	11600.00
0005433037214	24127	Economy	11600.00
0005433924302	24127	Economy	11600.00
0005433924301	24127	Economy	11600.00
0005433923989	24127	Economy	11600.00
0005433924225	24127	Economy	11600.00
0005434028355	24127	Economy	11600.00
0005433931495	24127	Economy	11600.00
0005433923914	24127	Economy	11600.00
0005434028354	24127	Economy	11600.00
0005433924151	24127	Economy	11600.00
0005433924398	24127	Economy	11600.00
0005433924466	24127	Economy	11600.00
0005433037241	24127	Economy	11600.00
0005433923956	24127	Economy	11600.00
0005433875395	24127	Economy	11600.00
0005433037210	24127	Economy	11600.00
0005433234624	283	Business	83700.00
0005434552187	283	Business	83700.00
0005434552171	283	Business	83700.00
0005434727604	283	Business	83700.00
0005434727581	283	Business	83700.00
0005432278047	283	Business	83700.00
0005434727575	283	Business	83700.00
0005434727551	283	Business	83700.00
0005434727574	283	Business	83700.00
0005433234925	283	Business	83700.00
0005434727634	283	Business	83700.00
0005434727595	283	Business	83700.00
0005434727528	283	Business	83700.00
0005434727530	283	Business	83700.00
0005433111531	283	Business	83700.00
0005434727553	283	Business	83700.00
0005433234991	283	Business	83700.00
0005433181343	283	Business	83700.00
0005434727615	283	Business	83700.00
0005433234997	283	Business	83700.00
0005433234617	283	Business	83700.00
0005434552178	283	Business	83700.00
0005433181358	283	Business	83700.00
0005434727552	283	Business	83700.00
0005434727592	283	Business	83700.00
0005434727562	283	Comfort	47400.00
0005433234803	283	Comfort	47400.00
0005434552209	283	Comfort	47400.00
0005433234870	283	Comfort	47400.00
0005434727631	283	Comfort	47400.00
0005434727561	283	Comfort	47400.00
0005434552201	283	Comfort	47400.00
0005433181288	283	Comfort	47400.00
0005435142818	283	Comfort	47400.00
0005434552163	283	Comfort	47400.00
0005434727637	283	Comfort	47400.00
0005433234814	283	Comfort	47400.00
0005434727545	283	Comfort	47400.00
0005434552162	283	Comfort	47400.00
0005433181341	283	Comfort	47400.00
0005434727566	283	Comfort	47400.00
0005434727557	283	Comfort	47400.00
0005434727628	283	Comfort	47400.00
0005434727570	283	Comfort	47400.00
0005434727618	283	Comfort	47400.00
0005433181281	283	Comfort	47400.00
0005434727602	283	Comfort	47400.00
0005434552185	283	Comfort	47400.00
0005433181301	283	Comfort	47400.00
0005433181381	283	Comfort	47400.00
0005433234716	283	Comfort	47400.00
0005434727578	283	Comfort	47400.00
0005434727627	283	Comfort	47400.00
0005434727540	283	Comfort	47400.00
0005433181410	283	Comfort	47400.00
0005434552192	283	Comfort	47400.00
0005433766688	283	Comfort	47400.00
0005433181342	283	Comfort	47400.00
0005434552180	283	Comfort	47400.00
0005434727587	283	Comfort	47400.00
0005434727620	283	Comfort	47400.00
0005434731243	283	Comfort	47400.00
0005434302881	283	Comfort	47400.00
0005433234737	283	Comfort	47400.00
0005433234700	283	Comfort	47400.00
0005433234866	283	Comfort	47400.00
0005433181337	283	Comfort	47400.00
0005434727622	283	Economy	27900.00
0005433181317	283	Economy	27900.00
0005434552188	283	Economy	27900.00
0005433234911	283	Economy	27900.00
0005434727536	283	Economy	27900.00
0005434032062	283	Economy	27900.00
0005434727560	283	Economy	27900.00
0005434727555	283	Economy	27900.00
0005434727538	283	Economy	27900.00
0005434552172	283	Economy	27900.00
0005433234659	283	Economy	27900.00
0005434727567	283	Economy	27900.00
0005434552189	283	Economy	27900.00
0005434727535	283	Economy	27900.00
0005434727611	283	Economy	27900.00
0005434302880	283	Economy	27900.00
0005434727579	283	Economy	27900.00
0005434552181	283	Economy	27900.00
0005434552207	283	Economy	27900.00
0005434727537	283	Economy	27900.00
0005433766664	283	Economy	27900.00
0005435142814	283	Economy	27900.00
0005434727596	283	Economy	27900.00
0005433181357	283	Economy	27900.00
0005434727640	283	Economy	27900.00
0005434727546	283	Economy	27900.00
0005434727606	283	Economy	27900.00
0005435142819	283	Economy	27900.00
0005434727576	283	Economy	27900.00
0005434727621	283	Economy	27900.00
0005433234918	283	Economy	27900.00
0005434727624	283	Economy	27900.00
0005433234702	283	Economy	27900.00
0005434552199	283	Economy	27900.00
0005434552214	283	Economy	27900.00
0005434552186	283	Economy	27900.00
0005434727643	283	Economy	27900.00
0005432278041	283	Economy	27900.00
0005433234751	283	Economy	27900.00
0005434727648	283	Economy	27900.00
0005434032065	283	Economy	27900.00
0005433234718	283	Economy	27900.00
0005435142815	283	Economy	27900.00
0005434552194	283	Economy	27900.00
0005434727589	283	Economy	27900.00
0005434302536	283	Economy	27900.00
0005434727632	283	Economy	27900.00
0005434552167	283	Economy	27900.00
0005433234986	283	Economy	27900.00
0005434727559	283	Economy	27900.00
0005433111507	283	Economy	27900.00
0005433234985	283	Economy	27900.00
0005434552216	283	Economy	27900.00
0005432278048	283	Economy	27900.00
0005434552184	283	Economy	27900.00
0005433181361	283	Economy	27900.00
0005432278039	283	Economy	27900.00
0005434552196	283	Economy	27900.00
0005433234820	283	Economy	27900.00
0005433234596	283	Economy	27900.00
0005433234929	283	Economy	27900.00
0005434727644	283	Economy	30700.00
0005434032057	283	Economy	27900.00
0005433234745	283	Economy	27900.00
0005434727645	283	Economy	30700.00
0005433234867	283	Economy	27900.00
0005433234763	283	Economy	27900.00
0005433234999	283	Economy	30700.00
0005433181335	283	Economy	27900.00
0005434727584	283	Economy	30700.00
0005434727642	283	Economy	30700.00
0005434735778	283	Economy	27900.00
0005433181397	283	Economy	27900.00
0005434552206	283	Economy	27900.00
0005433234612	283	Economy	27900.00
0005434032068	283	Economy	27900.00
0005434727616	283	Economy	27900.00
0005434727600	283	Economy	27900.00
0005433234807	283	Economy	27900.00
0005433234746	283	Economy	27900.00
0005434727550	283	Economy	27900.00
0005434727633	283	Economy	27900.00
0005432278046	283	Economy	27900.00
0005434727601	283	Economy	27900.00
0005434552191	283	Economy	27900.00
0005434727598	283	Economy	27900.00
0005434552218	283	Economy	27900.00
0005433766662	283	Economy	27900.00
0005434727529	283	Economy	27900.00
0005434727549	283	Economy	27900.00
0005433181395	283	Economy	27900.00
0005433181352	283	Economy	27900.00
0005434552190	283	Economy	27900.00
0005433234996	283	Economy	27900.00
0005434552166	283	Economy	27900.00
0005434727613	283	Economy	27900.00
0005433126875	283	Economy	27900.00
0005435142813	283	Economy	27900.00
0005434302535	283	Economy	27900.00
0005434727582	283	Economy	27900.00
0005434731240	283	Economy	27900.00
0005434735774	283	Economy	27900.00
0005434727597	283	Economy	27900.00
0005434727571	283	Economy	27900.00
0005433181287	283	Economy	27900.00
0005434727599	283	Economy	27900.00
0005434727639	283	Economy	27900.00
0005433181311	283	Economy	27900.00
0005432278043	283	Economy	27900.00
0005434727625	283	Economy	27900.00
0005433181247	283	Economy	27900.00
0005434552176	283	Economy	27900.00
0005434727542	283	Economy	27900.00
0005433234809	283	Economy	27900.00
0005433113555	283	Economy	27900.00
0005434727568	283	Economy	27900.00
0005434727526	283	Economy	27900.00
0005433766689	283	Economy	27900.00
0005434552210	283	Economy	27900.00
0005434735775	283	Economy	27900.00
0005434727539	283	Economy	27900.00
0005433234492	283	Economy	27900.00
0005434552182	283	Economy	27900.00
0005434727577	283	Economy	27900.00
0005433111503	283	Economy	27900.00
0005434727626	283	Economy	27900.00
0005434727558	283	Economy	27900.00
0005433234796	283	Economy	27900.00
0005434552177	283	Economy	27900.00
0005434727641	283	Economy	27900.00
0005435142821	283	Economy	27900.00
0005434727588	283	Economy	27900.00
0005433181336	283	Economy	27900.00
0005433234795	283	Economy	27900.00
0005433289907	283	Economy	27900.00
0005434727531	283	Economy	27900.00
0005432278049	283	Economy	27900.00
0005434727623	283	Economy	27900.00
0005433181382	283	Economy	27900.00
0005433234869	283	Economy	27900.00
0005433181279	283	Economy	27900.00
0005434727572	283	Economy	27900.00
0005433181418	283	Economy	27900.00
0005435142820	283	Economy	27900.00
0005433181280	283	Economy	27900.00
0005434552217	283	Economy	27900.00
0005434727580	283	Economy	27900.00
0005434727610	283	Economy	27900.00
0005435142810	283	Economy	27900.00
0005434727629	283	Economy	27900.00
0005433234750	283	Economy	27900.00
0005432278037	283	Economy	27900.00
0005434727573	283	Economy	27900.00
0005434727607	283	Economy	27900.00
0005433234605	283	Economy	27900.00
0005434552169	283	Economy	27900.00
0005433181312	283	Economy	27900.00
0005433234821	283	Economy	27900.00
0005434727646	283	Economy	27900.00
0005434552183	283	Economy	27900.00
0005434552202	283	Economy	27900.00
0005433234755	283	Economy	27900.00
0005432278042	283	Economy	27900.00
0005433234878	283	Economy	27900.00
0005435142816	283	Economy	27900.00
0005434727543	283	Economy	27900.00
0005434552174	283	Economy	27900.00
0005433234912	283	Economy	27900.00
0005434032069	283	Economy	27900.00
0005435142809	283	Economy	27900.00
0005433289910	283	Economy	27900.00
0005432278045	283	Economy	27900.00
0005434727647	283	Economy	27900.00
0005433131761	283	Economy	27900.00
0005434552212	283	Economy	27900.00
0005434552198	283	Economy	27900.00
0005433234874	283	Economy	27900.00
0005433234606	283	Economy	27900.00
0005434552170	283	Economy	27900.00
0005434552175	283	Economy	30700.00
0005434727569	283	Economy	30700.00
0005433113554	283	Economy	30700.00
0005434727638	283	Economy	30700.00
0005433234379	283	Economy	27900.00
0005433234722	283	Economy	27900.00
0005434552208	283	Economy	27900.00
0005434727594	283	Economy	27900.00
0005433234678	283	Economy	27900.00
0005434032083	283	Economy	27900.00
0005433234607	283	Economy	27900.00
0005434727590	283	Economy	27900.00
0005433234998	283	Economy	27900.00
0005434302534	283	Economy	27900.00
0005434727554	283	Economy	27900.00
0005433181398	283	Economy	27900.00
0005434552203	283	Economy	27900.00
0005434735779	283	Economy	27900.00
0005433181414	283	Economy	27900.00
0005433181217	283	Economy	27900.00
0005433234779	283	Economy	27900.00
0005434552197	283	Economy	27900.00
0005434731239	283	Economy	27900.00
0005434727586	283	Economy	27900.00
0005433234629	283	Economy	27900.00
0005433234743	283	Economy	27900.00
0005433234792	283	Economy	27900.00
0005434727565	283	Economy	27900.00
0005433181219	283	Economy	27900.00
0005434735776	283	Economy	27900.00
0005433181310	283	Economy	27900.00
0005434552205	283	Economy	27900.00
0005434735777	283	Economy	27900.00
0005434727544	283	Economy	27900.00
0005434727614	283	Economy	27900.00
0005432278044	283	Economy	27900.00
0005433234913	283	Economy	27900.00
0005433234822	283	Economy	27900.00
0005434727532	283	Economy	27900.00
0005433181324	283	Economy	27900.00
0005434552195	283	Economy	27900.00
0005433181220	283	Economy	27900.00
0005433181415	283	Economy	27900.00
0005434727605	283	Economy	27900.00
0005435142812	283	Economy	27900.00
0005434727591	283	Economy	27900.00
0005434552168	283	Economy	27900.00
0005434727533	283	Economy	27900.00
0005434727612	283	Economy	27900.00
0005433766663	283	Economy	27900.00
0005434727556	283	Economy	27900.00
0005434552165	283	Economy	27900.00
0005433234508	283	Economy	27900.00
0005434302879	283	Economy	27900.00
0005434727583	283	Economy	27900.00
0005434727635	283	Economy	27900.00
0005433181340	283	Economy	27900.00
0005434727630	283	Economy	27900.00
0005434727609	283	Economy	27900.00
0005434727617	283	Economy	27900.00
0005433234762	283	Economy	27900.00
0005433234616	283	Economy	27900.00
0005434727585	283	Economy	27900.00
0005432278038	283	Economy	27900.00
0005434552193	283	Economy	27900.00
0005433234778	283	Economy	27900.00
0005433234630	283	Economy	27900.00
0005434727534	283	Economy	27900.00
0005434552213	283	Economy	27900.00
0005434552164	283	Economy	27900.00
0005433234810	283	Economy	27900.00
0005434302882	283	Economy	27900.00
0005434727593	283	Economy	27900.00
0005434727527	283	Economy	27900.00
0005434727548	283	Economy	27900.00
0005433234744	283	Economy	27900.00
0005433234794	283	Economy	27900.00
0005435142817	283	Economy	27900.00
0005434302533	283	Economy	27900.00
0005434727547	283	Economy	27900.00
0005433234509	283	Economy	27900.00
0005434727608	283	Economy	27900.00
0005433181218	283	Economy	27900.00
0005433234793	283	Economy	27900.00
0005434727563	283	Economy	27900.00
0005434552200	283	Economy	27900.00
0005435142811	283	Economy	27900.00
0005434731241	283	Economy	27900.00
0005434727636	283	Economy	27900.00
0005434552204	283	Economy	27900.00
0005434552179	283	Economy	27900.00
0005435142808	283	Economy	27900.00
0005433234698	283	Economy	27900.00
0005433289896	283	Economy	27900.00
0005434552211	283	Economy	27900.00
0005434727564	283	Economy	27900.00
0005434727541	283	Economy	27900.00
0005434552173	283	Economy	27900.00
0005433289909	283	Economy	27900.00
0005432278040	283	Economy	27900.00
0005434727619	283	Economy	27900.00
0005433234701	283	Economy	27900.00
0005433234889	283	Economy	27900.00
0005434727603	283	Economy	27900.00
0005434552215	283	Economy	27900.00
0005434731242	283	Economy	27900.00
0005433181248	283	Economy	27900.00
0005434551685	9854	Business	83700.00
0005435142727	9854	Business	83700.00
0005433766707	9854	Business	83700.00
0005433235291	9854	Business	83700.00
0005434725991	9854	Business	83700.00
0005434726831	9854	Business	83700.00
0005434726521	9854	Business	83700.00
0005433235280	9854	Business	83700.00
0005434725918	9854	Business	83700.00
0005434726861	9854	Business	83700.00
0005434551728	9854	Business	83700.00
0005433235298	9854	Business	83700.00
0005433181546	9854	Business	83700.00
0005433235297	9854	Business	83700.00
0005434726448	9854	Business	83700.00
0005435142666	9854	Business	83700.00
0005434551381	9854	Business	83700.00
0005433235328	9854	Business	83700.00
0005433235304	9854	Business	83700.00
0005434735739	9854	Business	83700.00
0005433235293	9854	Business	83700.00
0005434551801	9854	Business	83700.00
0005432199371	9854	Business	83700.00
0005434726377	9854	Comfort	47400.00
0005434551600	9854	Comfort	47400.00
0005432199372	9854	Comfort	47400.00
0005433235319	9854	Comfort	47400.00
0005433235333	9854	Comfort	47400.00
0005434726523	9854	Comfort	47400.00
0005434726412	9854	Comfort	47400.00
0005434551722	9854	Comfort	47400.00
0005434726666	9854	Comfort	47400.00
0005434726582	9854	Comfort	47400.00
0005434727049	9854	Comfort	47400.00
0005433289971	9854	Comfort	47400.00
0005435142725	9854	Comfort	47400.00
0005434726420	9854	Comfort	47400.00
0005434726390	9854	Comfort	47400.00
0005432199367	9854	Comfort	47400.00
0005433129355	9854	Comfort	47400.00
0005434726559	9854	Comfort	47400.00
0005434726485	9854	Comfort	47400.00
0005434726678	9854	Comfort	47400.00
0005434726389	9854	Comfort	47400.00
0005434551684	9854	Comfort	47400.00
0005433181553	9854	Comfort	47400.00
0005434726220	9854	Comfort	47400.00
0005434726762	9854	Comfort	47400.00
0005434726107	9854	Comfort	47400.00
0005434726773	9854	Comfort	47400.00
0005433289973	9854	Comfort	47400.00
0005434726970	9854	Comfort	47400.00
0005433181547	9854	Comfort	47400.00
0005434551675	9854	Comfort	47400.00
0005434726958	9854	Comfort	47400.00
0005435142668	9854	Comfort	47400.00
0005434726767	9854	Comfort	47400.00
0005434726431	9854	Comfort	47400.00
0005433235330	9854	Comfort	47400.00
0005432199366	9854	Economy	27900.00
0005434032103	9854	Economy	27900.00
0005434726443	9854	Economy	27900.00
0005434726103	9854	Economy	27900.00
0005434726405	9854	Economy	27900.00
0005434726331	9854	Economy	27900.00
0005434302482	9854	Economy	27900.00
0005434551638	9854	Economy	27900.00
0005434735735	9854	Economy	27900.00
0005434726356	9854	Economy	27900.00
0005434735712	9854	Economy	27900.00
0005434551644	9854	Economy	27900.00
0005434032106	9854	Economy	27900.00
0005434726001	9854	Economy	27900.00
0005434726598	9854	Economy	27900.00
0005434726489	9854	Economy	27900.00
0005433129357	9854	Economy	27900.00
0005434726713	9854	Economy	27900.00
0005433181538	9854	Economy	27900.00
0005432199373	9854	Economy	27900.00
0005433181543	9854	Economy	27900.00
0005433126926	9854	Economy	27900.00
0005434731218	9854	Economy	27900.00
0005434731219	9854	Economy	27900.00
0005434551726	9854	Economy	27900.00
0005434726530	9854	Economy	27900.00
0005433235292	9854	Economy	27900.00
0005434725992	9854	Economy	27900.00
0005434551674	9854	Economy	27900.00
0005433766706	9854	Economy	27900.00
0005434726655	9854	Economy	27900.00
0005434726205	9854	Economy	27900.00
0005433235301	9854	Economy	27900.00
0005433235321	9854	Economy	27900.00
0005434726867	9854	Economy	27900.00
0005435142672	9854	Economy	27900.00
0005433235303	9854	Economy	27900.00
0005433181535	9854	Economy	27900.00
0005433235299	9854	Economy	27900.00
0005433289976	9854	Economy	27900.00
0005434731207	9854	Economy	27900.00
0005434726158	9854	Economy	27900.00
0005434726373	9854	Economy	27900.00
0005433235329	9854	Economy	27900.00
0005433181539	9854	Economy	27900.00
0005434735738	9854	Economy	27900.00
0005433235325	9854	Economy	27900.00
0005434551727	9854	Economy	27900.00
0005434726577	9854	Economy	27900.00
0005433235311	9854	Economy	30700.00
0005433235316	9854	Economy	27900.00
0005434726725	9854	Economy	30700.00
0005434727055	9854	Economy	27900.00
0005433235281	9854	Economy	30700.00
0005434726516	9854	Economy	27900.00
0005432199368	9854	Economy	30700.00
0005434551743	9854	Economy	27900.00
0005433181552	9854	Economy	30700.00
0005433235312	9854	Economy	30700.00
0005434726522	9854	Economy	27900.00
0005434551758	9854	Economy	27900.00
0005433766709	9854	Economy	27900.00
0005434551596	9854	Economy	27900.00
0005433235331	9854	Economy	27900.00
0005433235276	9854	Economy	27900.00
0005433235285	9854	Economy	27900.00
0005433235334	9854	Economy	27900.00
0005434726571	9854	Economy	27900.00
0005434726435	9854	Economy	27900.00
0005433766705	9854	Economy	27900.00
0005433181542	9854	Economy	27900.00
0005435142663	9854	Economy	27900.00
0005434726854	9854	Economy	27900.00
0005434731212	9854	Economy	27900.00
0005434726438	9854	Economy	27900.00
0005433181529	9854	Economy	27900.00
0005433235271	9854	Economy	27900.00
0005434726537	9854	Economy	27900.00
0005433235300	9854	Economy	27900.00
0005434726934	9854	Economy	27900.00
0005433235277	9854	Economy	27900.00
0005433129353	9854	Economy	27900.00
0005433126925	9854	Economy	27900.00
0005434726513	9854	Economy	27900.00
0005433181541	9854	Economy	27900.00
0005434726527	9854	Economy	27900.00
0005433235327	9854	Economy	27900.00
0005434726695	9854	Economy	27900.00
0005433235305	9854	Economy	27900.00
0005433235318	9854	Economy	27900.00
0005434551852	9854	Economy	27900.00
0005433289970	9854	Economy	27900.00
0005433181534	9854	Economy	27900.00
0005433235272	9854	Economy	27900.00
0005434727082	9854	Economy	27900.00
0005434726653	9854	Economy	27900.00
0005434726200	9854	Economy	27900.00
0005434726797	9854	Economy	27900.00
0005435142654	9854	Economy	27900.00
0005434726724	9854	Economy	27900.00
0005433235309	9854	Economy	27900.00
0005434551655	9854	Economy	27900.00
0005434551382	9854	Economy	27900.00
0005433181528	9854	Economy	27900.00
0005433235294	9854	Economy	27900.00
0005434551734	9854	Economy	27900.00
0005433113573	9854	Economy	27900.00
0005435142632	9854	Economy	27900.00
0005434726442	9854	Economy	27900.00
0005434726529	9854	Economy	27900.00
0005434735713	9854	Economy	27900.00
0005434726097	9854	Economy	27900.00
0005434727081	9854	Economy	27900.00
0005433766708	9854	Economy	27900.00
0005434726496	9854	Economy	27900.00
0005433113575	9854	Economy	27900.00
0005433235270	9854	Economy	27900.00
0005434726744	9854	Economy	27900.00
0005435142694	9854	Economy	27900.00
0005434726385	9854	Economy	27900.00
0005435142657	9854	Economy	27900.00
0005433235290	9854	Economy	27900.00
0005435142660	9854	Economy	27900.00
0005433235324	9854	Economy	27900.00
0005434726206	9854	Economy	27900.00
0005434032105	9854	Economy	27900.00
0005433235313	9854	Economy	27900.00
0005433181540	9854	Economy	27900.00
0005434726181	9854	Economy	27900.00
0005434726586	9854	Economy	27900.00
0005434551809	9854	Economy	27900.00
0005434726083	9854	Economy	27900.00
0005433235322	9854	Economy	27900.00
0005433235302	9854	Economy	27900.00
0005434726677	9854	Economy	27900.00
0005433235286	9854	Economy	27900.00
0005435142631	9854	Economy	27900.00
0005434726361	9854	Economy	27900.00
0005434726641	9854	Economy	27900.00
0005435142659	9854	Economy	27900.00
0005433235306	9854	Economy	27900.00
0005434551645	9854	Economy	27900.00
0005435142726	9854	Economy	27900.00
0005433235282	9854	Economy	27900.00
0005434726791	9854	Economy	27900.00
0005434726961	9854	Economy	27900.00
0005434726042	9854	Economy	27900.00
0005433235289	9854	Economy	27900.00
0005434726903	9854	Economy	27900.00
0005434551812	9854	Economy	27900.00
0005433181531	9854	Economy	27900.00
0005433181536	9854	Economy	27900.00
0005434726403	9854	Economy	27900.00
0005432199369	9854	Economy	27900.00
0005434726644	9854	Economy	27900.00
0005434726096	9854	Economy	27900.00
0005434726536	9854	Economy	27900.00
0005434726572	9854	Economy	27900.00
0005433126924	9854	Economy	30700.00
0005433235332	9854	Economy	30700.00
0005434726870	9854	Economy	30700.00
0005434551581	9854	Economy	30700.00
0005434726568	9854	Economy	27900.00
0005434726640	9854	Economy	27900.00
0005433235283	9854	Economy	27900.00
0005434726384	9854	Economy	27900.00
0005434726102	9854	Economy	27900.00
0005433235287	9854	Economy	27900.00
0005433235279	9854	Economy	27900.00
0005433181549	9854	Economy	27900.00
0005432199370	9854	Economy	27900.00
0005433113574	9854	Economy	27900.00
0005433235273	9854	Economy	27900.00
0005434726772	9854	Economy	27900.00
0005434726943	9854	Economy	27900.00
0005433235314	9854	Economy	27900.00
0005433235320	9854	Economy	27900.00
0005434551697	9854	Economy	27900.00
0005434726195	9854	Economy	27900.00
0005434735725	9854	Economy	27900.00
0005433181544	9854	Economy	27900.00
0005434726645	9854	Economy	27900.00
0005434725863	9854	Economy	27900.00
0005433289975	9854	Economy	27900.00
0005433235296	9854	Economy	27900.00
0005433235323	9854	Economy	27900.00
0005433235310	9854	Economy	27900.00
0005434726590	9854	Economy	27900.00
0005433181532	9854	Economy	27900.00
0005434726086	9854	Economy	27900.00
0005433126923	9854	Economy	27900.00
0005434032107	9854	Economy	27900.00
0005433235278	9854	Economy	27900.00
0005434726891	9854	Economy	27900.00
0005434726599	9854	Economy	27900.00
0005434551695	9854	Economy	27900.00
0005434726156	9854	Economy	27900.00
0005433235326	9854	Economy	27900.00
0005434726986	9854	Economy	27900.00
0005435142691	9854	Economy	27900.00
0005434726211	9854	Economy	27900.00
0005433181548	9854	Economy	27900.00
0005433129356	9854	Economy	27900.00
0005434032108	9854	Economy	27900.00
0005435142714	9854	Economy	27900.00
0005433181530	9854	Economy	27900.00
0005434551979	9854	Economy	27900.00
0005433181550	9854	Economy	27900.00
0005434726722	9854	Economy	27900.00
0005433235284	9854	Economy	27900.00
0005434551788	9854	Economy	27900.00
0005433235274	9854	Economy	27900.00
0005434551626	9854	Economy	27900.00
0005434726775	9854	Economy	27900.00
0005435142732	9854	Economy	27900.00
0005433126922	9854	Economy	27900.00
0005434726404	9854	Economy	27900.00
0005434726532	9854	Economy	27900.00
0005434726225	9854	Economy	27900.00
0005434551805	9854	Economy	27900.00
0005434726665	9854	Economy	27900.00
0005434551721	9854	Economy	27900.00
0005434032104	9854	Economy	27900.00
0005433235288	9854	Economy	27900.00
0005434725986	9854	Economy	27900.00
0005434726085	9854	Economy	27900.00
0005433235307	9854	Economy	27900.00
0005434726712	9854	Economy	27900.00
0005433235317	9854	Economy	27900.00
0005433129354	9854	Economy	27900.00
0005434726624	9854	Economy	27900.00
0005434551622	9854	Economy	27900.00
0005433181551	9854	Economy	27900.00
0005434726558	9854	Economy	27900.00
0005433289974	9854	Economy	27900.00
0005434726157	9854	Economy	27900.00
0005433235308	9854	Economy	27900.00
0005434731211	9854	Economy	27900.00
0005434726720	9854	Economy	27900.00
0005433181537	9854	Economy	27900.00
0005433235275	9854	Economy	27900.00
0005434551637	9854	Economy	27900.00
0005434726962	9854	Economy	27900.00
0005433235315	9854	Economy	27900.00
0005434302485	9854	Economy	27900.00
0005434727080	9854	Economy	27900.00
0005433181533	9854	Economy	27900.00
0005434726022	9854	Economy	27900.00
0005433289972	9854	Economy	27900.00
0005434726495	9854	Economy	27900.00
0005433235295	9854	Economy	27900.00
0005434551505	9854	Economy	27900.00
0005434726679	9854	Economy	27900.00
0005434726514	9854	Economy	27900.00
0005433181545	9854	Economy	27900.00
0005434726578	9854	Economy	27900.00
0005435214199	7777	Business	42100.00
0005435213928	7777	Business	42100.00
0005435214336	7777	Business	42100.00
0005432069915	7777	Business	42100.00
0005432530289	7777	Business	42100.00
0005432530277	7777	Business	42100.00
0005435214368	7777	Business	42100.00
0005432530247	7777	Business	42100.00
0005434068819	7777	Business	42100.00
0005432535919	7777	Business	42100.00
0005432530223	7777	Business	42100.00
0005435214354	7777	Business	42100.00
0005432530278	7777	Business	42100.00
0005432530293	7777	Business	42100.00
0005434068795	7777	Business	42100.00
0005432530291	7777	Business	42100.00
0005432150334	7777	Business	42100.00
0005435214085	7777	Business	42100.00
0005432069908	7777	Business	42100.00
0005435214035	7777	Business	42100.00
0005432530262	7777	Business	42100.00
0005432069911	7777	Business	42100.00
0005432533341	7777	Comfort	23900.00
0005432530324	7777	Comfort	23900.00
0005432530295	7777	Comfort	23900.00
0005435725634	7777	Comfort	23900.00
0005432530228	7777	Comfort	23900.00
0005432530246	7777	Comfort	23900.00
0005432530266	7777	Comfort	23900.00
0005434068766	7777	Comfort	23900.00
0005434068769	7777	Comfort	23900.00
0005432530303	7777	Comfort	23900.00
0005432069903	7777	Comfort	23900.00
0005434068823	7777	Comfort	23900.00
0005432530240	7777	Comfort	23900.00
0005432530302	7777	Comfort	23900.00
0005435213804	7777	Comfort	23900.00
0005432530206	7777	Comfort	23900.00
0005434068814	7777	Comfort	23900.00
0005432530238	7777	Comfort	23900.00
0005432530288	7777	Comfort	23900.00
0005432530320	7777	Comfort	23900.00
0005432069914	7777	Comfort	23900.00
0005432530225	7777	Comfort	23900.00
0005435214160	7777	Comfort	23900.00
0005434068830	7777	Comfort	23900.00
0005432530202	7777	Comfort	23900.00
0005434068826	7777	Comfort	23900.00
0005432535917	7777	Comfort	23900.00
0005435214390	7777	Comfort	23900.00
0005435213924	7777	Comfort	23900.00
0005434068834	7777	Comfort	23900.00
0005432530306	7777	Comfort	23900.00
0005432150332	7777	Comfort	23900.00
0005434068812	7777	Comfort	23900.00
0005432530301	7777	Comfort	23900.00
0005432069910	7777	Comfort	23900.00
0005435213849	7777	Comfort	23900.00
0005432428988	7777	Comfort	23900.00
0005432530207	7777	Comfort	23900.00
0005432530217	7777	Economy	14000.00
0005434068776	7777	Comfort	23900.00
0005432150335	7777	Economy	14000.00
0005434068774	7777	Economy	14000.00
0005434068810	7777	Economy	14000.00
0005434068771	7777	Economy	14000.00
0005432530313	7777	Economy	14000.00
0005434068822	7777	Economy	14000.00
0005432530326	7777	Economy	14000.00
0005432530252	7777	Economy	14000.00
0005435214159	7777	Economy	14000.00
0005432530283	7777	Economy	14000.00
0005435214161	7777	Economy	14000.00
0005435214346	7777	Economy	14000.00
0005432530215	7777	Economy	14000.00
0005432530226	7777	Economy	14000.00
0005432530269	7777	Economy	14000.00
0005434068796	7777	Economy	14000.00
0005435214317	7777	Economy	14000.00
0005432530210	7777	Economy	14000.00
0005432069912	7777	Economy	14000.00
0005434068775	7777	Economy	14000.00
0005434068797	7777	Economy	14000.00
0005435214185	7777	Economy	14000.00
0005432530224	7777	Economy	14000.00
0005432530308	7777	Economy	14000.00
0005432530314	7777	Economy	14000.00
0005432530241	7777	Economy	14000.00
0005432530249	7777	Economy	14000.00
0005432530294	7777	Economy	14000.00
0005432530317	7777	Economy	14000.00
0005435725650	7777	Economy	14000.00
0005432530298	7777	Economy	14000.00
0005432530287	7777	Economy	14000.00
0005435214074	7777	Economy	14000.00
0005434068815	7777	Economy	14000.00
0005432533342	7777	Economy	14000.00
0005435214020	7777	Economy	14000.00
0005432530292	7777	Economy	14000.00
0005432530279	7777	Economy	14000.00
0005434068800	7777	Economy	14000.00
0005434068777	7777	Economy	14000.00
0005432530230	7777	Economy	14000.00
0005432530232	7777	Economy	14000.00
0005434068808	7777	Economy	14000.00
0005435630993	7777	Economy	14000.00
0005434068789	7777	Economy	14000.00
0005432530239	7777	Economy	14000.00
0005432530311	7777	Economy	14000.00
0005434068833	7777	Economy	14000.00
0005432530323	7777	Economy	14000.00
0005435213884	7777	Economy	14000.00
0005435213803	7777	Economy	14000.00
0005432530216	7777	Economy	14000.00
0005435214192	7777	Economy	14000.00
0005434068820	7777	Economy	14000.00
0005435213925	7777	Economy	14000.00
0005432530304	7777	Economy	14000.00
0005434068768	7777	Economy	14000.00
0005435725637	7777	Economy	14000.00
0005432530290	7777	Economy	14000.00
0005432069904	7777	Economy	14000.00
0005432530328	7777	Economy	15400.00
0005432530248	7777	Economy	14000.00
0005432530205	7777	Economy	15400.00
0005432530256	7777	Economy	14000.00
0005435214289	7777	Economy	14000.00
0005435214006	7777	Economy	14000.00
0005432530231	7777	Economy	15400.00
0005435214391	7777	Economy	14000.00
0005434068802	7777	Economy	15400.00
0005432530227	7777	Economy	14000.00
0005435214131	7777	Economy	14000.00
0005434068782	7777	Economy	14000.00
0005432530229	7777	Economy	14000.00
0005434068807	7777	Economy	14000.00
0005432530271	7777	Economy	14000.00
0005434068798	7777	Economy	14000.00
0005432530243	7777	Economy	14000.00
0005435213955	7777	Economy	14000.00
0005432530242	7777	Economy	14000.00
0005432530327	7777	Economy	14000.00
0005432428987	7777	Economy	14000.00
0005432069906	7777	Economy	14000.00
0005432530297	7777	Economy	14000.00
0005435630990	7777	Economy	14000.00
0005432530213	7777	Economy	14000.00
0005434068791	7777	Economy	14000.00
0005435214073	7777	Economy	14000.00
0005432530322	7777	Economy	14000.00
0005432530265	7777	Economy	14000.00
0005432150333	7777	Economy	14000.00
0005434068809	7777	Economy	14000.00
0005435214036	7777	Economy	14000.00
0005434068824	7777	Economy	14000.00
0005432535916	7777	Economy	14000.00
0005435214331	7777	Economy	14000.00
0005432530307	7777	Economy	14000.00
0005435214222	7777	Economy	14000.00
0005435214200	7777	Economy	14000.00
0005432530299	7777	Economy	14000.00
0005435213892	7777	Economy	14000.00
0005432530258	7777	Economy	14000.00
0005432530259	7777	Economy	14000.00
0005434068770	7777	Economy	14000.00
0005435213916	7777	Economy	14000.00
0005435214426	7777	Economy	14000.00
0005434068767	7777	Economy	14000.00
0005432069909	7777	Economy	14000.00
0005434068793	7777	Economy	14000.00
0005434068801	7777	Economy	14000.00
0005434068835	7777	Economy	14000.00
0005432069905	7777	Economy	14000.00
0005432069902	7777	Economy	14000.00
0005434068806	7777	Economy	14000.00
0005432530286	7777	Economy	14000.00
0005432530251	7777	Economy	14000.00
0005435214198	7777	Economy	14000.00
0005434068817	7777	Economy	14000.00
0005435213896	7777	Economy	14000.00
0005432150328	7777	Economy	14000.00
0005432530209	7777	Economy	14000.00
0005434068781	7777	Economy	14000.00
0005435214157	7777	Economy	14000.00
0005434068825	7777	Economy	14000.00
0005432530211	7777	Economy	14000.00
0005432530316	7777	Economy	14000.00
0005434068831	7777	Economy	14000.00
0005434068779	7777	Economy	14000.00
0005435214005	7777	Economy	14000.00
0005432530272	7777	Economy	14000.00
0005435214237	7777	Economy	14000.00
0005432069913	7777	Economy	14000.00
0005432530305	7777	Economy	14000.00
0005432535918	7777	Economy	14000.00
0005432530310	7777	Economy	14000.00
0005434068803	7777	Economy	14000.00
0005435214100	7777	Economy	14000.00
0005435214170	7777	Economy	14000.00
0005432530250	7777	Economy	14000.00
0005432150331	7777	Economy	14000.00
0005432530273	7777	Economy	14000.00
0005435214330	7777	Economy	14000.00
0005435213974	7777	Economy	14000.00
0005435214446	7777	Economy	14000.00
0005432530200	7777	Economy	14000.00
0005432530235	7777	Economy	14000.00
0005435214230	7777	Economy	14000.00
0005432530234	7777	Economy	14000.00
0005434068787	7777	Economy	14000.00
0005434068829	7777	Economy	14000.00
0005435214140	7777	Economy	14000.00
0005432428989	7777	Economy	14000.00
0005432530245	7777	Economy	14000.00
0005434068828	7777	Economy	14000.00
0005432535920	7777	Economy	14000.00
0005435214316	7777	Economy	14000.00
0005435214024	7777	Economy	14000.00
0005435214229	7777	Economy	14000.00
0005432150329	7777	Economy	14000.00
0005432530296	7777	Economy	14000.00
0005432530280	7777	Economy	14000.00
0005432530312	7777	Economy	14000.00
0005434068780	7777	Economy	15400.00
0005432530257	7777	Economy	15400.00
0005432530268	7777	Economy	15400.00
0005432530244	7777	Economy	15400.00
0005432530275	7777	Economy	15400.00
0005434068805	7777	Economy	15400.00
0005435214427	7777	Economy	14000.00
0005432530321	7777	Economy	14000.00
0005434068813	7777	Economy	14000.00
0005435214335	7777	Economy	14000.00
0005434068765	7777	Economy	14000.00
0005432530276	7777	Economy	14000.00
0005433656706	7777	Economy	14000.00
0005432530263	7777	Economy	14000.00
0005434068790	7777	Economy	14000.00
0005432530219	7777	Economy	14000.00
0005432530253	7777	Economy	14000.00
0005432530204	7777	Economy	14000.00
0005434068794	7777	Economy	14000.00
0005434068832	7777	Economy	14000.00
0005432069907	7777	Economy	14000.00
0005434068816	7777	Economy	14000.00
0005434068804	7777	Economy	14000.00
0005432530218	7777	Economy	14000.00
0005434068792	7777	Economy	14000.00
0005432530233	7777	Economy	14000.00
0005432530196	7777	Economy	14000.00
0005435214092	7777	Economy	14000.00
0005435214196	7777	Economy	14000.00
0005434068788	7777	Economy	14000.00
0005432530300	7777	Economy	14000.00
0005432530274	7777	Economy	14000.00
0005434068786	7777	Economy	14000.00
0005432530261	7777	Economy	14000.00
0005435213975	7777	Economy	14000.00
0005435214108	7777	Economy	14000.00
0005435214249	7777	Economy	14000.00
0005434068818	7777	Economy	14000.00
0005432530212	7777	Economy	14000.00
0005432530264	7777	Economy	14000.00
0005432530220	7777	Economy	14000.00
0005432530197	7777	Economy	14000.00
0005432530260	7777	Economy	14000.00
0005432150330	7777	Economy	14000.00
0005432530208	7777	Economy	14000.00
0005435214191	7777	Economy	14000.00
0005434068811	7777	Economy	14000.00
0005432530254	7777	Economy	14000.00
0005432530199	7777	Economy	14000.00
0005432530281	7777	Economy	14000.00
0005432530319	7777	Economy	14000.00
0005434068799	7777	Economy	14000.00
0005434068785	7777	Economy	14000.00
0005432530318	7777	Economy	14000.00
0005434068821	7777	Economy	14000.00
0005434068764	7777	Economy	14000.00
0005432530203	7777	Economy	14000.00
0005432537095	7777	Economy	14000.00
0005432530236	7777	Economy	14000.00
0005432530214	7777	Economy	14000.00
0005432530282	7777	Economy	14000.00
0005435214064	7777	Economy	14000.00
0005435214466	7777	Economy	14000.00
0005432537096	7777	Economy	14000.00
0005434068773	7777	Economy	14000.00
0005432530255	7777	Economy	14000.00
0005432530325	7777	Economy	14000.00
0005432530237	7777	Economy	14000.00
0005432530201	7777	Economy	14000.00
0005434068783	7777	Economy	14000.00
0005432530221	7777	Economy	14000.00
0005435725635	7777	Economy	14000.00
0005435214031	7777	Economy	14000.00
0005435214388	7777	Economy	14000.00
0005432530309	7777	Economy	14000.00
0005434068778	7777	Economy	14000.00
0005432530198	7777	Economy	14000.00
0005434068827	7777	Economy	14000.00
0005432530267	7777	Economy	14000.00
0005434068836	7777	Economy	14000.00
0005435213954	7777	Economy	14000.00
0005434068784	7777	Economy	14000.00
0005432530222	7777	Economy	14000.00
0005432530315	7777	Economy	14000.00
0005432530270	7777	Economy	14000.00
0005435214072	7777	Economy	14000.00
0005432530284	7777	Economy	14000.00
0005435214158	7777	Economy	14000.00
0005432530285	7777	Economy	14000.00
0005435214004	7777	Economy	14000.00
0005435214284	7777	Economy	14000.00
0005434068772	7777	Economy	14000.00
0005435425558	5322	Business	43100.00
0005435615636	5322	Business	43100.00
0005435615619	5322	Business	43100.00
0005435425296	5322	Business	43100.00
0005434573604	5322	Business	43100.00
0005432363448	5322	Business	43100.00
0005435319665	5322	Business	43100.00
0005432047618	5322	Business	43100.00
0005434573597	5322	Business	43100.00
0005432363432	5322	Business	43100.00
0005435615603	5322	Business	43100.00
0005435491475	5322	Business	43100.00
0005435380352	5322	Business	43100.00
0005435425628	5322	Business	43100.00
0005434344830	5322	Business	43100.00
0005435319662	5322	Business	43100.00
0005435425782	5322	Business	43100.00
0005435615573	5322	Business	43100.00
0005435615618	5322	Business	43100.00
0005434245374	5322	Business	43100.00
0005432363446	5322	Business	43100.00
0005434344832	5322	Business	43100.00
0005435380331	5322	Business	43100.00
0005435615645	5322	Business	43100.00
0005435615575	5322	Comfort	24400.00
0005435615646	5322	Business	43100.00
0005435425511	5322	Comfort	24400.00
0005435042876	5322	Comfort	24400.00
0005435615598	5322	Comfort	24400.00
0005434344821	5322	Comfort	24400.00
0005434573602	5322	Comfort	24400.00
0005435615616	5322	Comfort	24400.00
0005435615635	5322	Comfort	24400.00
0005435097378	5322	Comfort	24400.00
0005435424990	5322	Comfort	24400.00
0005435615588	5322	Comfort	24400.00
0005432841028	5322	Comfort	24400.00
0005434344823	5322	Comfort	24400.00
0005435615624	5322	Comfort	24400.00
0005435097377	5322	Comfort	24400.00
0005435615605	5322	Comfort	24400.00
0005435615594	5322	Comfort	24400.00
0005434245231	5322	Comfort	24400.00
0005435425521	5322	Comfort	24400.00
0005435615597	5322	Comfort	24400.00
0005432841029	5322	Comfort	24400.00
0005435425599	5322	Comfort	24400.00
0005435615580	5322	Comfort	24400.00
0005434344854	5322	Comfort	24400.00
0005435615562	5322	Comfort	24400.00
0005435425520	5322	Comfort	24400.00
0005435615566	5322	Comfort	24400.00
0005435615585	5322	Comfort	24400.00
0005434245189	5322	Comfort	24400.00
0005435615643	5322	Comfort	24400.00
0005435425564	5322	Comfort	24400.00
0005435615613	5322	Comfort	24400.00
0005435615642	5322	Comfort	24400.00
0005435302245	5322	Comfort	24400.00
0005435615621	5322	Comfort	24400.00
0005432133470	5322	Comfort	24400.00
0005434245268	5322	Comfort	24400.00
0005432841035	5322	Comfort	24400.00
0005434344845	5322	Comfort	24400.00
0005434344835	5322	Economy	14400.00
0005435425522	5322	Economy	14400.00
0005434573599	5322	Economy	14400.00
0005435615607	5322	Economy	14400.00
0005434344839	5322	Economy	14400.00
0005434573598	5322	Economy	14400.00
0005432363447	5322	Economy	14400.00
0005434573596	5322	Economy	14400.00
0005434344852	5322	Economy	14400.00
0005435615601	5322	Economy	14400.00
0005435425288	5322	Economy	14400.00
0005434245182	5322	Economy	14400.00
0005434344834	5322	Economy	14400.00
0005435425715	5322	Economy	14400.00
0005434344824	5322	Economy	14400.00
0005435615560	5322	Economy	14400.00
0005434245168	5322	Economy	14400.00
0005435425282	5322	Economy	14400.00
0005435615622	5322	Economy	14400.00
0005435615641	5322	Economy	14400.00
0005435615612	5322	Economy	14400.00
0005434245146	5322	Economy	14400.00
0005435425487	5322	Economy	14400.00
0005435615602	5322	Economy	14400.00
0005435425563	5322	Economy	14400.00
0005434245183	5322	Economy	14400.00
0005435319633	5322	Economy	14400.00
0005435319640	5322	Economy	14400.00
0005434344846	5322	Economy	14400.00
0005435302230	5322	Economy	14400.00
0005435425671	5322	Economy	14400.00
0005432841030	5322	Economy	14400.00
0005434344825	5322	Economy	14400.00
0005435319660	5322	Economy	14400.00
0005435615638	5322	Economy	14400.00
0005435615561	5322	Economy	14400.00
0005435425352	5322	Economy	14400.00
0005435425289	5322	Economy	14400.00
0005435425640	5322	Economy	14400.00
0005434344853	5322	Economy	14400.00
0005435425767	5322	Economy	14400.00
0005435615570	5322	Economy	14400.00
0005434344851	5322	Economy	14400.00
0005435615583	5322	Economy	14400.00
0005434344848	5322	Economy	14400.00
0005434573601	5322	Economy	14400.00
0005435097383	5322	Economy	14400.00
0005434344826	5322	Economy	14400.00
0005432047619	5322	Economy	14400.00
0005435615590	5322	Economy	14400.00
0005434245075	5322	Economy	14400.00
0005435319654	5322	Economy	14400.00
0005435425142	5322	Economy	14400.00
0005435425263	5322	Economy	14400.00
0005435615609	5322	Economy	14400.00
0005435097376	5322	Economy	14400.00
0005435425505	5322	Economy	14400.00
0005435319663	5322	Economy	15800.00
0005435380335	5322	Economy	15800.00
0005435615633	5322	Economy	15800.00
0005434344844	5322	Economy	14400.00
0005432133471	5322	Economy	14400.00
0005434573595	5322	Economy	14400.00
0005435615634	5322	Economy	15800.00
0005435615610	5322	Economy	15800.00
0005435555404	5322	Economy	14400.00
0005434573606	5322	Economy	14400.00
0005435425620	5322	Economy	14400.00
0005435425595	5322	Economy	14400.00
0005434573603	5322	Economy	14400.00
0005434344838	5322	Economy	14400.00
0005435305028	5322	Economy	14400.00
0005435615640	5322	Economy	14400.00
0005432363433	5322	Economy	14400.00
0005435380337	5322	Economy	14400.00
0005435425367	5322	Economy	14400.00
0005432133472	5322	Economy	14400.00
0005435319641	5322	Economy	14400.00
0005435615639	5322	Economy	14400.00
0005435615586	5322	Economy	14400.00
0005434573607	5322	Economy	14400.00
0005432363445	5322	Economy	14400.00
0005434573600	5322	Economy	14400.00
0005434344836	5322	Economy	14400.00
0005432133479	5322	Economy	14400.00
0005435425415	5322	Economy	14400.00
0005434245161	5322	Economy	14400.00
0005435425353	5322	Economy	14400.00
0005435097380	5322	Economy	14400.00
0005435615565	5322	Economy	14400.00
0005435615589	5322	Economy	14400.00
0005432133476	5322	Economy	14400.00
0005432133473	5322	Economy	14400.00
0005435425519	5322	Economy	14400.00
0005434344828	5322	Economy	14400.00
0005435615571	5322	Economy	14400.00
0005432133469	5322	Economy	14400.00
0005435425510	5322	Economy	14400.00
0005435097382	5322	Economy	14400.00
0005434245209	5322	Economy	14400.00
0005435319632	5322	Economy	14400.00
0005435425477	5322	Economy	14400.00
0005434573594	5322	Economy	14400.00
0005435615614	5322	Economy	14400.00
0005435615579	5322	Economy	14400.00
0005435425362	5322	Economy	14400.00
0005435319630	5322	Economy	14400.00
0005434245233	5322	Economy	14400.00
0005435425512	5322	Economy	14400.00
0005435615625	5322	Economy	14400.00
0005435490291	5322	Economy	14400.00
0005435615604	5322	Economy	14400.00
0005435615648	5322	Economy	14400.00
0005435425502	5322	Economy	14400.00
0005435380340	5322	Economy	14400.00
0005435425684	5322	Economy	14400.00
0005435425619	5322	Economy	14400.00
0005432047616	5322	Economy	14400.00
0005435425869	5322	Economy	14400.00
0005434344840	5322	Economy	14400.00
0005435615620	5322	Economy	14400.00
0005435380336	5322	Economy	14400.00
0005435425092	5322	Economy	14400.00
0005435490292	5322	Economy	14400.00
0005435425393	5322	Economy	14400.00
0005434245317	5322	Economy	14400.00
0005435615593	5322	Economy	14400.00
0005435097374	5322	Economy	14400.00
0005434344841	5322	Economy	14400.00
0005435615623	5322	Economy	14400.00
0005435615595	5322	Economy	14400.00
0005435425488	5322	Economy	14400.00
0005435615572	5322	Economy	14400.00
0005435302248	5322	Economy	14400.00
0005435615611	5322	Economy	14400.00
0005435425459	5322	Economy	14400.00
0005435615606	5322	Economy	14400.00
0005435615649	5322	Economy	14400.00
0005435615574	5322	Economy	14400.00
0005434245228	5322	Economy	14400.00
0005435615567	5322	Economy	14400.00
0005434245297	5322	Economy	14400.00
0005435615569	5322	Economy	14400.00
0005435097381	5322	Economy	14400.00
0005434344822	5322	Economy	14400.00
0005435615644	5322	Economy	14400.00
0005435319661	5322	Economy	14400.00
0005434245169	5322	Economy	14400.00
0005435425513	5322	Economy	14400.00
0005434245232	5322	Economy	14400.00
0005435305019	5322	Economy	14400.00
0005435615637	5322	Economy	14400.00
0005435425281	5322	Economy	14400.00
0005435615630	5322	Economy	14400.00
0005435425236	5322	Economy	14400.00
0005435425364	5322	Economy	14400.00
0005435615626	5322	Economy	14400.00
0005435615578	5322	Economy	14400.00
0005435097375	5322	Economy	14400.00
0005435425683	5322	Economy	14400.00
0005435425247	5322	Economy	14400.00
0005434245319	5322	Economy	14400.00
0005435615568	5322	Economy	14400.00
0005435425492	5322	Economy	15800.00
0005435425504	5322	Economy	14400.00
0005435425491	5322	Economy	15800.00
0005435615592	5322	Economy	15800.00
0005434573593	5322	Economy	15800.00
0005434245076	5322	Economy	15800.00
0005435615563	5322	Economy	15800.00
0005435425547	5322	Economy	14400.00
0005435555405	5322	Economy	14400.00
0005434245303	5322	Economy	14400.00
0005434245322	5322	Economy	14400.00
0005435097385	5322	Economy	14400.00
0005435380330	5322	Economy	14400.00
0005435615650	5322	Economy	14400.00
0005435319634	5322	Economy	14400.00
0005434245188	5322	Economy	14400.00
0005435615564	5322	Economy	14400.00
0005435319642	5322	Economy	14400.00
0005434344837	5322	Economy	14400.00
0005434344833	5322	Economy	14400.00
0005434573592	5322	Economy	14400.00
0005434245302	5322	Economy	14400.00
0005434245267	5322	Economy	14400.00
0005434344850	5322	Economy	14400.00
0005435302229	5322	Economy	14400.00
0005434245294	5322	Economy	14400.00
0005434344831	5322	Economy	14400.00
0005435615627	5322	Economy	14400.00
0005432133480	5322	Economy	14400.00
0005432133475	5322	Economy	14400.00
0005435425407	5322	Economy	14400.00
0005434245193	5322	Economy	14400.00
0005435042860	5322	Economy	14400.00
0005432133482	5322	Economy	14400.00
0005435615581	5322	Economy	14400.00
0005435319607	5322	Economy	14400.00
0005432133477	5322	Economy	14400.00
0005435425284	5322	Economy	14400.00
0005435615559	5322	Economy	14400.00
0005435615591	5322	Economy	14400.00
0005435425486	5322	Economy	14400.00
0005435319639	5322	Economy	14400.00
0005435615587	5322	Economy	14400.00
0005434344842	5322	Economy	14400.00
0005434344849	5322	Economy	14400.00
0005435425239	5322	Economy	14400.00
0005435305016	5322	Economy	14400.00
0005435425562	5322	Economy	14400.00
0005434344843	5322	Economy	14400.00
0005434245212	5322	Economy	14400.00
0005435615600	5322	Economy	14400.00
0005432841034	5322	Economy	14400.00
0005435097379	5322	Economy	14400.00
0005435425175	5322	Economy	14400.00
0005435425290	5322	Economy	14400.00
0005435615577	5322	Economy	14400.00
0005435615582	5322	Economy	14400.00
0005435615632	5322	Economy	14400.00
0005435615628	5322	Economy	14400.00
0005434344827	5322	Economy	14400.00
0005435425470	5322	Economy	14400.00
0005432047615	5322	Economy	14400.00
0005432133481	5322	Economy	14400.00
0005434656575	5322	Economy	14400.00
0005434245318	5322	Economy	14400.00
0005432133474	5322	Economy	14400.00
0005435425476	5322	Economy	14400.00
0005435425682	5322	Economy	14400.00
0005435425827	5322	Economy	14400.00
0005434344847	5322	Economy	14400.00
0005435425202	5322	Economy	14400.00
0005435615584	5322	Economy	14400.00
0005435491477	5322	Economy	14400.00
0005434245213	5322	Economy	14400.00
0005434344829	5322	Economy	14400.00
0005435097384	5322	Economy	14400.00
0005435615608	5322	Economy	14400.00
0005435425484	5322	Economy	14400.00
0005435425826	5322	Economy	14400.00
0005435425616	5322	Economy	14400.00
0005434245145	5322	Economy	14400.00
0005435425617	5322	Economy	14400.00
0005432047617	5322	Economy	14400.00
0005434344820	5322	Economy	14400.00
0005435615631	5322	Economy	14400.00
0005435425259	5322	Economy	14400.00
0005435425506	5322	Economy	14400.00
0005435425392	5322	Economy	14400.00
0005435425295	5322	Economy	14400.00
0005435615599	5322	Economy	14400.00
0005435615617	5322	Economy	14400.00
0005435491476	5322	Economy	14400.00
0005435425596	5322	Economy	14400.00
0005435425541	5322	Economy	14400.00
0005434245194	5322	Economy	14400.00
0005435425394	5322	Economy	14400.00
0005433719167	5322	Economy	14400.00
0005435425235	5322	Economy	14400.00
0005432133478	5322	Economy	14400.00
0005435615647	5322	Economy	14400.00
0005435615576	5322	Economy	14400.00
0005434573605	5322	Economy	14400.00
0005434245371	5322	Economy	14400.00
0005435302217	5322	Economy	14400.00
0005435425411	5322	Economy	14400.00
0005432133483	5322	Economy	14400.00
0005435425365	5322	Economy	14400.00
0005435615596	5322	Economy	14400.00
0005435615629	5322	Economy	14400.00
0005435615615	5322	Economy	14400.00
0005435042891	10878	Business	43100.00
0005435614765	10878	Business	43100.00
0005435425988	10878	Business	43100.00
0005435304229	10878	Business	43100.00
0005435490255	10878	Business	43100.00
0005435426003	10878	Business	43100.00
0005432165170	10878	Business	43100.00
0005435614926	10878	Business	43100.00
0005435425993	10878	Business	43100.00
0005435615213	10878	Business	43100.00
0005435426017	10878	Business	43100.00
0005435614946	10878	Business	43100.00
0005435304230	10878	Business	43100.00
0005435614484	10878	Business	43100.00
0005435614509	10878	Business	43100.00
0005435426036	10878	Business	43100.00
0005435425982	10878	Business	43100.00
0005435614408	10878	Business	43100.00
0005434245490	10878	Business	43100.00
0005434245500	10878	Business	43100.00
0005434245498	10878	Business	43100.00
0005435426018	10878	Business	43100.00
0005435614846	10878	Comfort	24400.00
0005432165168	10878	Business	43100.00
0005435614955	10878	Comfort	24400.00
0005435426023	10878	Comfort	24400.00
0005435614179	10878	Comfort	24400.00
0005435614459	10878	Comfort	24400.00
0005435426019	10878	Comfort	24400.00
0005435615021	10878	Comfort	24400.00
0005435614663	10878	Comfort	24400.00
0005435614483	10878	Comfort	24400.00
0005435426030	10878	Comfort	24400.00
0005435490257	10878	Comfort	24400.00
0005434245507	10878	Comfort	24400.00
0005435614590	10878	Comfort	24400.00
0005435380377	10878	Comfort	24400.00
0005435425976	10878	Comfort	24400.00
0005435380374	10878	Comfort	24400.00
0005432165173	10878	Comfort	24400.00
0005434344533	10878	Comfort	24400.00
0005435097291	10878	Comfort	24400.00
0005435319729	10878	Comfort	24400.00
0005434344495	10878	Comfort	24400.00
0005434245486	10878	Comfort	24400.00
0005434573380	10878	Comfort	24400.00
0005435614026	10878	Comfort	24400.00
0005434573411	10878	Comfort	24400.00
0005434573460	10878	Comfort	24400.00
0005435614582	10878	Comfort	24400.00
0005435614686	10878	Comfort	24400.00
0005435614969	10878	Comfort	24400.00
0005435614763	10878	Comfort	24400.00
0005435425997	10878	Comfort	24400.00
0005435614583	10878	Comfort	24400.00
0005435614601	10878	Comfort	24400.00
0005435097282	10878	Comfort	24400.00
0005435426041	10878	Comfort	24400.00
0005432363472	10878	Comfort	24400.00
0005435426014	10878	Comfort	24400.00
0005435614457	10878	Comfort	24400.00
0005435614971	10878	Comfort	24400.00
0005435426012	10878	Comfort	24400.00
0005435426021	10878	Economy	14400.00
0005435426034	10878	Economy	14400.00
0005434344461	10878	Economy	14400.00
0005435425990	10878	Economy	14400.00
0005435426022	10878	Economy	14400.00
0005434245505	10878	Economy	14400.00
0005435304228	10878	Economy	14400.00
0005435614655	10878	Economy	14400.00
0005435614968	10878	Economy	14400.00
0005432841050	10878	Economy	14400.00
0005434245484	10878	Economy	14400.00
0005433719202	10878	Economy	14400.00
0005435613962	10878	Economy	14400.00
0005434245503	10878	Economy	14400.00
0005435614957	10878	Economy	14400.00
0005435614486	10878	Economy	14400.00
0005435614787	10878	Economy	14400.00
0005435614251	10878	Economy	14400.00
0005435614729	10878	Economy	14400.00
0005435614777	10878	Economy	14400.00
0005435614365	10878	Economy	14400.00
0005432363474	10878	Economy	14400.00
0005435490256	10878	Economy	14400.00
0005434344506	10878	Economy	14400.00
0005434573381	10878	Economy	14400.00
0005435614295	10878	Economy	14400.00
0005435614706	10878	Economy	14400.00
0005435097270	10878	Economy	14400.00
0005434344452	10878	Economy	14400.00
0005432363473	10878	Economy	14400.00
0005435614949	10878	Economy	14400.00
0005435614564	10878	Economy	14400.00
0005435319724	10878	Economy	14400.00
0005435555392	10878	Economy	14400.00
0005435425983	10878	Economy	14400.00
0005435380376	10878	Economy	14400.00
0005435305044	10878	Economy	14400.00
0005435614192	10878	Economy	14400.00
0005434245487	10878	Economy	14400.00
0005435614738	10878	Economy	14400.00
0005435614294	10878	Economy	14400.00
0005435426029	10878	Economy	14400.00
0005434344455	10878	Economy	14400.00
0005435425996	10878	Economy	14400.00
0005434344502	10878	Economy	14400.00
0005435426027	10878	Economy	14400.00
0005435097272	10878	Economy	14400.00
0005435425978	10878	Economy	14400.00
0005435490252	10878	Economy	14400.00
0005434344451	10878	Economy	14400.00
0005435614177	10878	Economy	14400.00
0005435425994	10878	Economy	14400.00
0005435426044	10878	Economy	14400.00
0005435614566	10878	Economy	14400.00
0005435097268	10878	Economy	14400.00
0005435425985	10878	Economy	14400.00
0005435426015	10878	Economy	14400.00
0005435097250	10878	Economy	15800.00
0005434573443	10878	Economy	14400.00
0005434344402	10878	Economy	15800.00
0005435426035	10878	Economy	15800.00
0005435426013	10878	Economy	14400.00
0005435490251	10878	Economy	14400.00
0005434344390	10878	Economy	15800.00
0005435425973	10878	Economy	14400.00
0005435304231	10878	Economy	15800.00
0005434245479	10878	Economy	14400.00
0005435425979	10878	Economy	15800.00
0005435305045	10878	Economy	14400.00
0005435425991	10878	Economy	14400.00
0005434573487	10878	Economy	14400.00
0005435614887	10878	Economy	14400.00
0005435614054	10878	Economy	14400.00
0005435425999	10878	Economy	14400.00
0005435555393	10878	Economy	14400.00
0005435615395	10878	Economy	14400.00
0005432165174	10878	Economy	14400.00
0005435613964	10878	Economy	14400.00
0005434245489	10878	Economy	14400.00
0005435614565	10878	Economy	14400.00
0005435614533	10878	Economy	14400.00
0005435617173	10878	Economy	14400.00
0005435097280	10878	Economy	14400.00
0005435614013	10878	Economy	14400.00
0005435425981	10878	Economy	14400.00
0005434245478	10878	Economy	14400.00
0005435614741	10878	Economy	14400.00
0005435319726	10878	Economy	14400.00
0005435614180	10878	Economy	14400.00
0005435614689	10878	Economy	14400.00
0005434573453	10878	Economy	14400.00
0005435615056	10878	Economy	14400.00
0005434245506	10878	Economy	14400.00
0005435319728	10878	Economy	14400.00
0005435614941	10878	Economy	14400.00
0005435615020	10878	Economy	14400.00
0005435614970	10878	Economy	14400.00
0005434344462	10878	Economy	14400.00
0005434573517	10878	Economy	14400.00
0005433719199	10878	Economy	14400.00
0005435614323	10878	Economy	14400.00
0005434245499	10878	Economy	14400.00
0005434245491	10878	Economy	14400.00
0005435097261	10878	Economy	14400.00
0005435614845	10878	Economy	14400.00
0005435426043	10878	Economy	14400.00
0005435615019	10878	Economy	14400.00
0005434344454	10878	Economy	14400.00
0005435614437	10878	Economy	14400.00
0005435614581	10878	Economy	14400.00
0005435426001	10878	Economy	14400.00
0005435426005	10878	Economy	14400.00
0005435614874	10878	Economy	14400.00
0005435425986	10878	Economy	14400.00
0005435097292	10878	Economy	14400.00
0005435614954	10878	Economy	14400.00
0005435614786	10878	Economy	14400.00
0005435097296	10878	Economy	14400.00
0005434573494	10878	Economy	14400.00
0005434245482	10878	Economy	14400.00
0005435319723	10878	Economy	14400.00
0005434656591	10878	Economy	14400.00
0005434344499	10878	Economy	14400.00
0005435426025	10878	Economy	14400.00
0005435614865	10878	Economy	14400.00
0005435425980	10878	Economy	14400.00
0005434344490	10878	Economy	14400.00
0005435614921	10878	Economy	14400.00
0005435614740	10878	Economy	14400.00
0005435426002	10878	Economy	14400.00
0005435614622	10878	Economy	14400.00
0005434344589	10878	Economy	14400.00
0005435614880	10878	Economy	14400.00
0005435614602	10878	Economy	14400.00
0005435426038	10878	Economy	14400.00
0005435425975	10878	Economy	14400.00
0005435614296	10878	Economy	14400.00
0005435614464	10878	Economy	14400.00
0005435425995	10878	Economy	14400.00
0005434344493	10878	Economy	14400.00
0005435097271	10878	Economy	14400.00
0005435426020	10878	Economy	14400.00
0005435614438	10878	Economy	14400.00
0005435426016	10878	Economy	14400.00
0005435380375	10878	Economy	14400.00
0005434573461	10878	Economy	14400.00
0005435614836	10878	Economy	14400.00
0005435490263	10878	Economy	14400.00
0005434245496	10878	Economy	14400.00
0005435614942	10878	Economy	14400.00
0005435614415	10878	Economy	14400.00
0005435426008	10878	Economy	14400.00
0005435614785	10878	Economy	14400.00
0005435614812	10878	Economy	14400.00
0005432165169	10878	Economy	14400.00
0005432165172	10878	Economy	14400.00
0005434573479	10878	Economy	14400.00
0005434344494	10878	Economy	14400.00
0005435426007	10878	Economy	14400.00
0005432363475	10878	Economy	14400.00
0005435426010	10878	Economy	14400.00
0005435614025	10878	Economy	14400.00
0005435614753	10878	Economy	14400.00
0005432166958	10878	Economy	14400.00
0005434344450	10878	Economy	14400.00
0005435491457	10878	Economy	14400.00
0005434245483	10878	Economy	14400.00
0005434245494	10878	Economy	15800.00
0005432165171	10878	Economy	14400.00
0005435380379	10878	Economy	15800.00
0005434245501	10878	Economy	15800.00
0005435614847	10878	Economy	15800.00
0005434245504	10878	Economy	14400.00
0005435614314	10878	Economy	15800.00
0005435614549	10878	Economy	14400.00
0005435555390	10878	Economy	14400.00
0005435490260	10878	Economy	14400.00
0005434344403	10878	Economy	14400.00
0005435614778	10878	Economy	14400.00
0005434573444	10878	Economy	14400.00
0005434245492	10878	Economy	14400.00
0005434573404	10878	Economy	14400.00
0005435426004	10878	Economy	14400.00
0005435613935	10878	Economy	14400.00
0005435555391	10878	Economy	14400.00
0005435614557	10878	Economy	14400.00
0005435319725	10878	Economy	14400.00
0005435426028	10878	Economy	14400.00
0005435614808	10878	Economy	14400.00
0005435426000	10878	Economy	14400.00
0005435319731	10878	Economy	14400.00
0005434245493	10878	Economy	14400.00
0005435614692	10878	Economy	14400.00
0005434344496	10878	Economy	14400.00
0005434344330	10878	Economy	14400.00
0005435614813	10878	Economy	14400.00
0005434344331	10878	Economy	14400.00
0005435614947	10878	Economy	14400.00
0005435319730	10878	Economy	14400.00
0005434245495	10878	Economy	14400.00
0005435614490	10878	Economy	14400.00
0005435614585	10878	Economy	14400.00
0005435614315	10878	Economy	14400.00
0005435614443	10878	Economy	14400.00
0005435490261	10878	Economy	14400.00
0005434573410	10878	Economy	14400.00
0005435042890	10878	Economy	14400.00
0005435426024	10878	Economy	14400.00
0005435426026	10878	Economy	14400.00
0005435425984	10878	Economy	14400.00
0005433719201	10878	Economy	14400.00
0005435426032	10878	Economy	14400.00
0005435425977	10878	Economy	14400.00
0005435614776	10878	Economy	14400.00
0005434245481	10878	Economy	14400.00
0005435614463	10878	Economy	14400.00
0005432166959	10878	Economy	14400.00
0005434344588	10878	Economy	14400.00
0005434344467	10878	Economy	14400.00
0005434573495	10878	Economy	14400.00
0005435305046	10878	Economy	14400.00
0005435614835	10878	Economy	14400.00
0005435426040	10878	Economy	14400.00
0005435614800	10878	Economy	14400.00
0005434245488	10878	Economy	14400.00
0005434344587	10878	Economy	14400.00
0005435425972	10878	Economy	14400.00
0005434245497	10878	Economy	14400.00
0005435426042	10878	Economy	14400.00
0005435614458	10878	Economy	14400.00
0005435425987	10878	Economy	14400.00
0005435615078	10878	Economy	14400.00
0005435425998	10878	Economy	14400.00
0005435614807	10878	Economy	14400.00
0005435613963	10878	Economy	14400.00
0005435097258	10878	Economy	14400.00
0005435426009	10878	Economy	14400.00
0005435614992	10878	Economy	14400.00
0005435615057	10878	Economy	14400.00
0005433719200	10878	Economy	14400.00
0005435614584	10878	Economy	14400.00
0005435304227	10878	Economy	14400.00
0005432841049	10878	Economy	14400.00
0005435614037	10878	Economy	14400.00
0005432165167	10878	Economy	14400.00
0005435614742	10878	Economy	14400.00
0005435614956	10878	Economy	14400.00
0005435380378	10878	Economy	14400.00
0005435426039	10878	Economy	14400.00
0005435426006	10878	Economy	14400.00
0005435614817	10878	Economy	14400.00
0005435614844	10878	Economy	14400.00
0005435425974	10878	Economy	14400.00
0005435426033	10878	Economy	14400.00
0005435426037	10878	Economy	14400.00
0005435426011	10878	Economy	14400.00
0005434245502	10878	Economy	14400.00
0005435614485	10878	Economy	14400.00
0005435614532	10878	Economy	14400.00
0005435425992	10878	Economy	14400.00
0005435097297	10878	Economy	14400.00
0005434344332	10878	Economy	14400.00
0005435097281	10878	Economy	14400.00
0005434245480	10878	Economy	14400.00
0005435490262	10878	Economy	14400.00
0005435305047	10878	Economy	14400.00
0005435319727	10878	Economy	14400.00
0005434344500	10878	Economy	14400.00
0005435491458	10878	Economy	14400.00
0005435614569	10878	Economy	14400.00
0005435426031	10878	Economy	14400.00
0005434245485	10878	Economy	14400.00
0005435425989	10878	Economy	14400.00
0005435614391	10878	Economy	14400.00
0005433507485	3353	Business	18800.00
0005433634427	3353	Business	18800.00
0005432460415	3353	Business	18800.00
0005433507489	3353	Business	18800.00
0005433634407	3353	Business	18800.00
0005433805985	3353	Business	18800.00
0005432182111	3353	Business	18800.00
0005433805957	3353	Business	18800.00
0005433634434	3353	Business	18800.00
0005433805974	3353	Business	18800.00
0005432182100	3353	Business	18800.00
0005432182112	3353	Business	18800.00
0005433634416	3353	Business	18800.00
0005433805958	3353	Business	18800.00
0005433507476	3353	Business	18800.00
0005433634415	3353	Business	18800.00
0005433805991	3353	Business	18800.00
0005434143748	3353	Business	18800.00
0005433634410	3353	Business	18800.00
0005432460109	3353	Business	18800.00
0005432460299	3353	Business	18800.00
0005433634411	3353	Business	18800.00
0005432460504	3353	Business	18800.00
0005433507486	3353	Business	18800.00
0005433805992	3353	Business	18800.00
0005433634400	3353	Business	18800.00
0005432460466	3353	Business	18800.00
0005433634421	3353	Business	18800.00
0005433805973	3353	Economy	6900.00
0005433805989	3353	Economy	6900.00
0005433507478	3353	Economy	6900.00
0005432460278	3353	Economy	6900.00
0005433634430	3353	Economy	6900.00
0005432460325	3353	Economy	6900.00
0005433805978	3353	Economy	6300.00
0005433507472	3353	Economy	6300.00
0005433805963	3353	Economy	6300.00
0005432460340	3353	Economy	6300.00
0005433634417	3353	Economy	6300.00
0005432460397	3353	Economy	6300.00
0005433634420	3353	Economy	6300.00
0005432182114	3353	Economy	6300.00
0005432182101	3353	Economy	6300.00
0005432460426	3353	Economy	6300.00
0005432182099	3353	Economy	6300.00
0005432460503	3353	Economy	6300.00
0005433805967	3353	Economy	6300.00
0005433634429	3353	Economy	6300.00
0005433507487	3353	Economy	6300.00
0005432182095	3353	Economy	6300.00
0005433805993	3353	Economy	6300.00
0005432460221	3353	Economy	6300.00
0005432460241	3353	Economy	6300.00
0005433805975	3353	Economy	6300.00
0005433805966	3353	Economy	6300.00
0005432460427	3353	Economy	6300.00
0005433805984	3353	Economy	6300.00
0005433507477	3353	Economy	6300.00
0005432460386	3353	Economy	6300.00
0005433634418	3353	Economy	6300.00
0005433805971	3353	Economy	6300.00
0005433507481	3353	Economy	6300.00
0005433805959	3353	Economy	6300.00
0005432182116	3353	Economy	6300.00
0005433634405	3353	Economy	6300.00
0005432460460	3353	Economy	6300.00
0005432460251	3353	Economy	6300.00
0005433805961	3353	Economy	6300.00
0005433634402	3353	Economy	6300.00
0005433634414	3353	Economy	6300.00
0005433507473	3353	Economy	6300.00
0005433805987	3353	Economy	6300.00
0005432460356	3353	Economy	6300.00
0005432460393	3353	Economy	6300.00
0005432460446	3353	Economy	6300.00
0005432459979	3353	Economy	6300.00
0005433805970	3353	Economy	6300.00
0005433634435	3353	Economy	6300.00
0005432460303	3353	Economy	6300.00
0005433805964	3353	Economy	6300.00
0005432460341	3353	Economy	6300.00
0005433634425	3353	Economy	6300.00
0005434143747	3353	Economy	6300.00
0005433805986	3353	Economy	6300.00
0005432182110	3353	Economy	6300.00
0005432460348	3353	Economy	6300.00
0005433507480	3353	Economy	6300.00
0005432460360	3353	Economy	6300.00
0005433805980	3353	Economy	6300.00
0005432182103	3353	Economy	6300.00
0005434143745	3353	Economy	6300.00
0005433634412	3353	Economy	6300.00
0005433634419	3353	Economy	6300.00
0005433634409	3353	Economy	6300.00
0005433805983	3353	Economy	6900.00
0005432182097	3353	Economy	6900.00
0005432460312	3353	Economy	6900.00
0005432182098	3353	Economy	6900.00
0005433805997	3353	Economy	6900.00
0005434143746	3353	Economy	6300.00
0005433805994	3353	Economy	6300.00
0005433634408	3353	Economy	6300.00
0005433805981	3353	Economy	6300.00
0005433507484	3353	Economy	6900.00
0005432460219	3353	Economy	6300.00
0005432460459	3353	Economy	6300.00
0005433507474	3353	Economy	6300.00
0005432460333	3353	Economy	6300.00
0005432460313	3353	Economy	6300.00
0005432182113	3353	Economy	6300.00
0005433634404	3353	Economy	6300.00
0005434143749	3353	Economy	6300.00
0005432182115	3353	Economy	6300.00
0005432182104	3353	Economy	6300.00
0005432460326	3353	Economy	6300.00
0005433634423	3353	Economy	6300.00
0005433634413	3353	Economy	6300.00
0005433507492	3353	Economy	6300.00
0005433805996	3353	Economy	6300.00
0005433805956	3353	Economy	6300.00
0005433805995	3353	Economy	6300.00
0005433507475	3353	Economy	6300.00
0005433634422	3353	Economy	6300.00
0005433634431	3353	Economy	6300.00
0005432182105	3353	Economy	6300.00
0005433805960	3353	Economy	6300.00
0005433507479	3353	Economy	6300.00
0005433805990	3353	Economy	6300.00
0005433634401	3353	Economy	6300.00
0005433634428	3353	Economy	6300.00
0005432182107	3353	Economy	6300.00
0005432460456	3353	Economy	6300.00
0005432460311	3353	Economy	6300.00
0005433634406	3353	Economy	6300.00
0005432459934	3353	Economy	6300.00
0005433634403	3353	Economy	6300.00
0005432460461	3353	Economy	6300.00
0005433634433	3353	Economy	6300.00
0005433805969	3353	Economy	6300.00
0005432460359	3353	Economy	6300.00
0005432460110	3353	Economy	6300.00
0005433507488	3353	Economy	6300.00
0005433805962	3353	Economy	6300.00
0005433805977	3353	Economy	6300.00
0005433507482	3353	Economy	6300.00
0005433805972	3353	Economy	6300.00
0005433507490	3353	Economy	6300.00
0005432182106	3353	Economy	6300.00
0005433805965	3353	Economy	6300.00
0005433634424	3353	Economy	6300.00
0005432182108	3353	Economy	6300.00
0005434143744	3353	Economy	6300.00
0005433507483	3353	Economy	6300.00
0005433805982	3353	Economy	6300.00
0005432460465	3353	Economy	6300.00
0005433634426	3353	Economy	6300.00
0005432182109	3353	Economy	6300.00
0005432460412	3353	Economy	6300.00
0005433507491	3353	Economy	6300.00
0005432182102	3353	Economy	6300.00
0005433805979	3353	Economy	6300.00
0005433805976	3353	Economy	6300.00
0005433507471	3353	Economy	6300.00
0005432182096	3353	Economy	6300.00
0005432460339	3353	Economy	6300.00
0005433805988	3353	Economy	6300.00
0005433805968	3353	Economy	6300.00
0005434143750	3353	Economy	6300.00
0005433634432	3353	Economy	6300.00
0005432460392	3353	Economy	6300.00
0005435885819	3354	Business	18800.00
0005435885883	3354	Business	18800.00
0005435885648	3354	Business	18800.00
0005435885797	3354	Business	18800.00
0005435885725	3354	Business	18800.00
0005435885687	3354	Business	18800.00
0005435885820	3354	Business	18800.00
0005435885814	3354	Business	18800.00
0005435885662	3354	Business	18800.00
0005435885940	3354	Business	18800.00
0005435885634	3354	Economy	6900.00
0005435885469	3354	Economy	6300.00
0005435885736	3354	Economy	6300.00
0005435885672	3354	Economy	6300.00
0005435885749	3354	Economy	6300.00
0005435885667	3354	Economy	6300.00
0005435885792	3354	Economy	6300.00
0005435885788	3354	Economy	6300.00
0005435885884	3354	Economy	6300.00
0005435885791	3354	Economy	6300.00
0005435885671	3354	Economy	6300.00
0005435885674	3354	Economy	6300.00
0005435885587	3354	Economy	6300.00
0005435885640	3354	Economy	6300.00
0005435885810	3354	Economy	6300.00
0005435885712	3354	Economy	6300.00
0005435885793	3354	Economy	6300.00
0005435885615	3354	Economy	6300.00
0005435885842	3354	Economy	6900.00
0005435885836	3354	Economy	6900.00
0005435885755	3354	Economy	6300.00
0005435885802	3354	Economy	6300.00
0005435885521	3354	Economy	6300.00
0005435885681	3354	Economy	6300.00
0005435885713	3354	Economy	6300.00
0005435885638	3354	Economy	6300.00
0005435885867	3354	Economy	6300.00
0005435885633	3354	Economy	6300.00
0005435885821	3354	Economy	6300.00
0005435885815	3354	Economy	6300.00
0005435885666	3354	Economy	6300.00
0005435885496	3354	Economy	6300.00
0005435885777	3354	Economy	6300.00
0005435885737	3354	Economy	6300.00
0005435885866	3354	Economy	6300.00
0005435885880	3354	Economy	6300.00
0005435885826	3354	Economy	6300.00
0005435885879	3354	Economy	6300.00
0005435885796	3354	Economy	6300.00
0005435885779	3354	Economy	6300.00
0005435885827	3354	Economy	6300.00
0005435885843	3354	Economy	6300.00
0005432042962	8233	Business	18800.00
0005432460822	8233	Business	18800.00
0005432460808	8233	Business	18800.00
0005435886119	8233	Business	18800.00
0005433507351	8233	Business	18800.00
0005432460815	8233	Business	18800.00
0005435886091	8233	Business	18800.00
0005434326279	8233	Business	18800.00
0005432460821	8233	Business	18800.00
0005432042960	8233	Business	18800.00
0005432460807	8233	Business	18800.00
0005435886106	8233	Business	18800.00
0005435886095	8233	Business	18800.00
0005432460789	8233	Business	18800.00
0005435886088	8233	Business	18800.00
0005435886090	8233	Business	18800.00
0005432460824	8233	Business	18800.00
0005432460790	8233	Business	18800.00
0005433507347	8233	Business	18800.00
0005432460814	8233	Business	18800.00
0005432460780	8233	Economy	6900.00
0005432460787	8233	Economy	6900.00
0005435886125	8233	Economy	6900.00
0005432460797	8233	Economy	6900.00
0005435886105	8233	Economy	6900.00
0005433507306	8233	Economy	6300.00
0005433507346	8233	Economy	6300.00
0005432460796	8233	Economy	6300.00
0005435886082	8233	Economy	6300.00
0005435886114	8233	Economy	6300.00
0005435886113	8233	Economy	6300.00
0005432460776	8233	Economy	6300.00
0005435886101	8233	Economy	6300.00
0005432460819	8233	Economy	6300.00
0005432042965	8233	Economy	6300.00
0005435142971	8233	Economy	6300.00
0005435886122	8233	Economy	6300.00
0005432460816	8233	Economy	6300.00
0005432460788	8233	Economy	6300.00
0005432042961	8233	Economy	6300.00
0005435886083	8233	Economy	6300.00
0005435886118	8233	Economy	6300.00
0005432460799	8233	Economy	6300.00
0005432460825	8233	Economy	6300.00
0005433507350	8233	Economy	6300.00
0005435886104	8233	Economy	6300.00
0005435886100	8233	Economy	6300.00
0005435886096	8233	Economy	6300.00
0005433507229	8233	Economy	6300.00
0005432460811	8233	Economy	6300.00
0005433507326	8233	Economy	6300.00
0005432460793	8233	Economy	6300.00
0005432460823	8233	Economy	6300.00
0005432460795	8233	Economy	6300.00
0005432460782	8233	Economy	6300.00
0005432460817	8233	Economy	6300.00
0005434326278	8233	Economy	6300.00
0005433507291	8233	Economy	6300.00
0005432042957	8233	Economy	6300.00
0005432460792	8233	Economy	6300.00
0005435886086	8233	Economy	6300.00
0005432042959	8233	Economy	6300.00
0005435886097	8233	Economy	6300.00
0005433507305	8233	Economy	6300.00
0005432460794	8233	Economy	6300.00
0005433507331	8233	Economy	6300.00
0005432460801	8233	Economy	6300.00
0005432460810	8233	Economy	6300.00
0005432460785	8233	Economy	6300.00
0005435886120	8233	Economy	6300.00
0005435886094	8233	Economy	6300.00
0005435886108	8233	Economy	6300.00
0005432042958	8233	Economy	6300.00
0005432460806	8233	Economy	6300.00
0005434312356	8233	Economy	6300.00
0005435886085	8233	Economy	6300.00
0005435886109	8233	Economy	6900.00
0005435886121	8233	Economy	6900.00
0005435886111	8233	Economy	6300.00
0005432042964	8233	Economy	6300.00
0005432460779	8233	Economy	6300.00
0005432460781	8233	Economy	6900.00
0005435886102	8233	Economy	6300.00
0005432042953	8233	Economy	6300.00
0005432460784	8233	Economy	6300.00
0005432460773	8233	Economy	6300.00
0005432460805	8233	Economy	6300.00
0005435886093	8233	Economy	6300.00
0005435886081	8233	Economy	6300.00
0005435886099	8233	Economy	6300.00
0005432460800	8233	Economy	6300.00
0005432460802	8233	Economy	6300.00
0005435886087	8233	Economy	6300.00
0005432460777	8233	Economy	6300.00
0005432460818	8233	Economy	6300.00
0005435886123	8233	Economy	6300.00
0005433507307	8233	Economy	6300.00
0005432460783	8233	Economy	6300.00
0005432042952	8233	Economy	6300.00
0005432042963	8233	Economy	6300.00
0005435886124	8233	Economy	6300.00
0005432460804	8233	Economy	6300.00
0005432460812	8233	Economy	6300.00
0005433507341	8233	Economy	6300.00
0005433507349	8233	Economy	6300.00
0005435886092	8233	Economy	6300.00
0005432042954	8233	Economy	6300.00
0005432460803	8233	Economy	6300.00
0005435886116	8233	Economy	6300.00
0005435886117	8233	Economy	6300.00
0005432042956	8233	Economy	6300.00
0005435886084	8233	Economy	6300.00
0005432460820	8233	Economy	6300.00
0005432460774	8233	Economy	6300.00
0005432460809	8233	Economy	6300.00
0005435886110	8233	Economy	6300.00
0005432460813	8233	Economy	6300.00
0005435886107	8233	Economy	6300.00
0005433507327	8233	Economy	6300.00
0005432460778	8233	Economy	6300.00
0005432460786	8233	Economy	6300.00
0005433507328	8233	Economy	6300.00
0005432460791	8233	Economy	6300.00
0005433507303	8233	Economy	6300.00
0005432460826	8233	Economy	6300.00
0005435886089	8233	Economy	6300.00
0005435886098	8233	Economy	6300.00
0005432042955	8233	Economy	6300.00
0005435886112	8233	Economy	6300.00
0005432460775	8233	Economy	6300.00
0005432460798	8233	Economy	6300.00
0005435886115	8233	Economy	6300.00
0005434312357	8233	Economy	6300.00
0005433507345	8233	Economy	6300.00
0005435886103	8233	Economy	6300.00
0005433634064	8189	Business	18800.00
0005433633955	8189	Business	18800.00
0005433805761	8189	Business	18800.00
0005433805589	8189	Business	18800.00
0005433805693	8189	Business	18800.00
0005433805878	8189	Business	18800.00
0005433805694	8189	Business	18800.00
0005433805717	8189	Business	18800.00
0005433634032	8189	Business	18800.00
0005433805721	8189	Business	18800.00
0005433634079	8189	Economy	6900.00
0005433805536	8189	Economy	6300.00
0005434143742	8189	Economy	6300.00
0005433633980	8189	Economy	6300.00
0005433634175	8189	Economy	6300.00
0005433805701	8189	Economy	6300.00
0005433634097	8189	Economy	6300.00
0005433634008	8189	Economy	6300.00
0005433634147	8189	Economy	6300.00
0005433805583	8189	Economy	6300.00
0005433805567	8189	Economy	6300.00
0005433634026	8189	Economy	6300.00
0005433805742	8189	Economy	6300.00
0005433634122	8189	Economy	6300.00
0005433634060	8189	Economy	6300.00
0005433805609	8189	Economy	6300.00
0005433805791	8189	Economy	6300.00
0005433805703	8189	Economy	6300.00
0005433633954	8189	Economy	6300.00
0005433805720	8189	Economy	6300.00
0005433805765	8189	Economy	6300.00
0005433633878	8189	Economy	6300.00
0005433805597	8189	Economy	6300.00
0005434143741	8189	Economy	6300.00
0005433634081	8189	Economy	6300.00
0005433633916	8189	Economy	6300.00
0005433633996	8189	Economy	6900.00
0005433805716	8189	Economy	6900.00
0005433805608	8189	Economy	6300.00
0005433805692	8189	Economy	6300.00
0005433633981	8189	Economy	6900.00
0005433805777	8189	Economy	6300.00
0005433805510	8189	Economy	6300.00
0005433633995	8189	Economy	6300.00
0005433634098	8189	Economy	6300.00
0005433633997	8189	Economy	6300.00
0005433634146	8189	Economy	6300.00
0005433805722	8189	Economy	6300.00
0005433805690	8189	Economy	6300.00
0005433805741	8189	Economy	6300.00
0005433805719	8189	Economy	6300.00
0005433633956	8189	Economy	6300.00
0005433634138	8189	Economy	6300.00
0005433805702	8189	Economy	6300.00
0005433634182	8189	Economy	6300.00
0005433805715	8189	Economy	6300.00
0005433633985	8189	Economy	6300.00
0005433805711	8189	Economy	6300.00
0005433805602	8189	Economy	6300.00
0005433634065	8189	Economy	6300.00
0005433634181	8189	Economy	6300.00
0005433633986	8189	Economy	6300.00
0005433634174	8189	Economy	6300.00
0005433633984	8189	Economy	6300.00
0005433634080	8189	Economy	6300.00
0005433805572	8189	Economy	6300.00
0005433633917	8189	Economy	6300.00
0005433633991	8189	Economy	6300.00
0005433805590	8189	Economy	6300.00
0005433805712	8189	Economy	6300.00
0005433634183	8189	Economy	6300.00
0005433805568	8189	Economy	6300.00
0005434183596	8207	Business	18800.00
0005432383855	4532	Business	9900.00
0005432383834	4532	Business	9900.00
0005432383847	4532	Business	9900.00
0005432383844	4532	Business	9900.00
0005432383869	4532	Business	9900.00
0005432728162	4532	Business	9900.00
0005432383833	4532	Business	9900.00
0005432728159	4532	Business	9900.00
0005432383867	4532	Business	9900.00
0005432728160	4532	Business	9900.00
0005432728152	4532	Economy	3300.00
0005433454913	4532	Economy	3300.00
0005432728163	4532	Economy	3300.00
0005432383865	4532	Economy	3300.00
0005432383862	4532	Economy	3300.00
0005433722339	4532	Economy	3300.00
0005433722341	4532	Economy	3600.00
0005433454912	4532	Economy	3600.00
0005432728155	4532	Economy	3600.00
0005433722337	4532	Economy	3300.00
0005432728158	4532	Economy	3300.00
0005432383835	4532	Economy	3300.00
0005432383874	4532	Economy	3300.00
0005433722342	4532	Economy	3300.00
0005432383842	4532	Economy	3300.00
0005432383858	4532	Economy	3300.00
0005432728153	4532	Economy	3300.00
0005432383853	4532	Economy	3300.00
0005432383845	4532	Economy	3300.00
0005432383868	4532	Economy	3300.00
0005432383860	4532	Economy	3300.00
0005432383840	4532	Economy	3300.00
0005432728157	4532	Economy	3300.00
0005432383873	4532	Economy	3300.00
0005432383870	4532	Economy	3300.00
0005432383850	4532	Economy	3300.00
0005432728156	4532	Economy	3300.00
0005433722340	4532	Economy	3300.00
0005432383839	4532	Economy	3300.00
0005432383852	4532	Economy	3300.00
0005432383843	4532	Economy	3300.00
0005432383872	4532	Economy	3300.00
0005432383864	4532	Economy	3300.00
0005432383837	4532	Economy	3300.00
0005433453796	4532	Economy	3300.00
0005432383836	4532	Economy	3300.00
0005432383861	4532	Economy	3300.00
0005432383859	4532	Economy	3300.00
0005432383851	4532	Economy	3300.00
0005432383838	4532	Economy	3300.00
0005433722338	4532	Economy	3300.00
0005432383866	4532	Economy	3300.00
0005432383857	4532	Economy	3300.00
0005432383848	4532	Economy	3300.00
0005432728164	4532	Economy	3300.00
0005432728151	4532	Economy	3300.00
0005432728154	4532	Economy	3300.00
0005432728161	4532	Economy	3300.00
0005432383871	4532	Economy	3300.00
0005432383863	4532	Economy	3300.00
0005432383832	4532	Economy	3300.00
0005432383856	4532	Economy	3300.00
0005432383846	4532	Economy	3300.00
0005432383841	4532	Economy	3300.00
0005432383849	4532	Economy	3300.00
0005433454914	4532	Economy	3300.00
0005432383854	4532	Economy	3300.00
0005432383355	30111	Business	9900.00
0005433722267	30111	Business	9900.00
0005432383461	30111	Business	9900.00
0005432383291	30111	Business	9900.00
0005432383472	30111	Business	9900.00
0005432383499	30111	Business	9900.00
0005432383351	30111	Business	9900.00
0005432383488	30111	Economy	3300.00
0005433453775	30111	Economy	3300.00
0005433722273	30111	Economy	3300.00
0005433722251	30111	Economy	3300.00
0005432383389	30111	Economy	3300.00
0005432383553	30111	Economy	3300.00
0005433451639	30111	Economy	3300.00
0005433722245	30111	Economy	3300.00
0005432383322	30111	Economy	3600.00
0005433194885	30111	Economy	3600.00
0005432728044	30111	Economy	3600.00
0005432728029	30111	Economy	3600.00
0005432383206	30111	Economy	3300.00
0005432383356	30111	Economy	3300.00
0005432383292	30111	Economy	3300.00
0005432728098	30111	Economy	3300.00
0005433722258	30111	Economy	3300.00
0005432383359	30111	Economy	3300.00
0005432383391	30111	Economy	3300.00
0005432383537	30111	Economy	3300.00
0005433194862	30111	Economy	3300.00
0005433722234	30111	Economy	3300.00
0005432383437	30111	Economy	3300.00
0005432728076	30111	Economy	3300.00
0005432383443	30111	Economy	3300.00
0005432728050	30111	Economy	3300.00
0005432383338	30111	Economy	3300.00
0005433722264	30111	Economy	3300.00
0005433194863	30111	Economy	3300.00
0005433722253	30111	Economy	3300.00
0005432383370	30111	Economy	3300.00
0005432383329	30111	Economy	3300.00
0005432383372	30111	Economy	3300.00
0005432728006	30111	Economy	3300.00
0005433722263	30111	Economy	3300.00
0005433722266	30111	Economy	3300.00
0005432383371	30111	Economy	3300.00
0005432383390	30111	Economy	3300.00
0005432727987	30111	Economy	3300.00
0005433451629	30111	Economy	3300.00
0005432383486	30111	Economy	3300.00
0005433194865	30111	Economy	3300.00
0005432383483	30111	Economy	3300.00
0005433453769	30111	Economy	3300.00
0005432728099	30111	Economy	3300.00
0005432383248	30111	Economy	3300.00
0005432383564	30111	Economy	3300.00
0005432383360	30111	Economy	3300.00
0005433722257	30111	Economy	3300.00
0005432383543	30111	Economy	3300.00
0005432728049	30111	Economy	3300.00
0005433722236	30111	Economy	3300.00
0005433722270	30111	Economy	3300.00
0005432383449	30111	Economy	3300.00
0005432383335	30111	Economy	3300.00
0005432728028	30111	Economy	3300.00
0005432383401	30111	Economy	3300.00
0005432383409	30111	Economy	3300.00
0005433194866	30111	Economy	3300.00
0005433722235	30111	Economy	3300.00
0005432383290	30111	Economy	3300.00
0005433453776	30111	Economy	3300.00
0005432383436	30111	Economy	3300.00
0005435529639	1742	Business	57200.00
0005433517053	1742	Business	57200.00
0005435541380	1742	Business	57200.00
0005435529633	1742	Business	57200.00
0005435541383	1742	Business	57200.00
0005435529992	1742	Business	57200.00
0005435529991	1742	Business	57200.00
0005435541388	1742	Business	57200.00
0005435529638	1742	Business	57200.00
0005435529650	1742	Economy	19100.00
0005435529643	1742	Economy	19100.00
0005435529645	1742	Economy	19100.00
0005435541378	1742	Economy	19100.00
0005435529636	1742	Economy	19100.00
0005435529632	1742	Economy	19100.00
0005432294529	1742	Economy	21000.00
0005433517048	1742	Economy	21000.00
0005435529990	1742	Economy	21000.00
0005433517057	1742	Economy	21000.00
0005435541396	1742	Economy	19100.00
0005432294530	1742	Economy	19100.00
0005433517050	1742	Economy	19100.00
0005435529994	1742	Economy	19100.00
0005435541393	1742	Economy	19100.00
0005433517055	1742	Economy	19100.00
0005433517054	1742	Economy	19100.00
0005432925059	1742	Economy	19100.00
0005435541389	1742	Economy	19100.00
0005435541381	1742	Economy	19100.00
0005435529641	1742	Economy	19100.00
0005435529648	1742	Economy	19100.00
0005435541379	1742	Economy	19100.00
0005435541392	1742	Economy	19100.00
0005435529646	1742	Economy	19100.00
0005435541387	1742	Economy	19100.00
0005433517051	1742	Economy	19100.00
0005435529647	1742	Economy	19100.00
0005433517052	1742	Economy	19100.00
0005435529642	1742	Economy	19100.00
0005435541385	1742	Economy	19100.00
0005435541391	1742	Economy	19100.00
0005435541384	1742	Economy	19100.00
0005432925087	1742	Economy	19100.00
0005435529652	1742	Economy	19100.00
0005435529640	1742	Economy	19100.00
0005435541390	1742	Economy	19100.00
0005435541397	1742	Economy	19100.00
0005432925084	1742	Economy	19100.00
0005432925057	1742	Economy	19100.00
0005435541386	1742	Economy	19100.00
0005435529635	1742	Economy	19100.00
0005435541394	1742	Economy	19100.00
0005432925064	1742	Economy	19100.00
0005435529644	1742	Economy	19100.00
0005432925058	1742	Economy	19100.00
0005435529634	1742	Economy	19100.00
0005435529649	1742	Economy	19100.00
0005435529653	1742	Economy	19100.00
0005435529651	1742	Economy	19100.00
0005435529993	1742	Economy	19100.00
0005433517047	1742	Economy	19100.00
0005435541395	1742	Economy	19100.00
0005435541377	1742	Economy	19100.00
0005432925063	1742	Economy	19100.00
0005435541382	1742	Economy	19100.00
0005433517056	1742	Economy	19100.00
0005435529637	1742	Economy	19100.00
0005433517049	1742	Economy	19100.00
0005435518017	22020	Business	57200.00
0005433516989	22020	Business	57200.00
0005432925119	22020	Business	57200.00
0005435517932	22020	Business	57200.00
0005435518038	22020	Business	57200.00
0005435518092	22020	Business	57200.00
0005435518085	22020	Business	57200.00
0005435518084	22020	Business	57200.00
0005432925123	22020	Business	57200.00
0005435518147	22020	Economy	19100.00
0005435541241	22020	Economy	19100.00
0005435541183	22020	Economy	19100.00
0005435518059	22020	Economy	19100.00
0005432925121	22020	Economy	19100.00
0005435518052	22020	Economy	19100.00
0005432925120	22020	Economy	19100.00
0005435541143	22020	Economy	21000.00
0005435541255	22020	Economy	21000.00
0005435518058	22020	Economy	21000.00
0005435541161	22020	Economy	21000.00
0005435541215	22020	Economy	21000.00
0005435541229	22020	Economy	19100.00
0005435541187	22020	Economy	19100.00
0005435518021	22020	Economy	19100.00
0005435541172	22020	Economy	19100.00
0005435518086	22020	Economy	19100.00
0005435518028	22020	Economy	19100.00
0005435518057	22020	Economy	19100.00
0005435518068	22020	Economy	19100.00
0005435541094	22020	Economy	19100.00
0005435541254	22020	Economy	19100.00
0005435518148	22020	Economy	19100.00
0005435518042	22020	Economy	19100.00
0005435541198	22020	Economy	19100.00
0005435518040	22020	Economy	19100.00
0005432925124	22020	Economy	19100.00
0005433516990	22020	Economy	19100.00
0005435518112	22020	Economy	19100.00
0005433516962	22020	Economy	19100.00
0005435518039	22020	Economy	19100.00
0005435541141	22020	Economy	19100.00
0005435541216	22020	Economy	19100.00
0005435541001	22020	Economy	19100.00
0005435541202	22020	Economy	19100.00
0005435541165	22020	Economy	19100.00
0005435541228	22020	Economy	19100.00
0005435541152	22020	Economy	19100.00
0005433517009	22020	Economy	19100.00
0005435518091	22020	Economy	19100.00
0005435518107	22020	Economy	19100.00
0005435541158	22020	Economy	19100.00
0005432925122	22020	Economy	19100.00
0005433516981	22020	Economy	19100.00
0005435541201	22020	Economy	19100.00
0005435541171	22020	Economy	19100.00
0005435541153	22020	Economy	19100.00
0005435541142	22020	Economy	19100.00
0005435518149	22020	Economy	19100.00
0005435518005	22020	Economy	19100.00
0005435541127	22020	Economy	19100.00
0005435518071	22020	Economy	19100.00
0005435541160	22020	Economy	19100.00
0005435518072	22020	Economy	19100.00
0005435541164	22020	Economy	19100.00
0005432839590	7360	Business	18500.00
0005432839576	7360	Business	18500.00
0005434459174	7360	Business	18500.00
0005435491446	7360	Business	18500.00
0005435252865	7360	Business	18500.00
0005432839589	7360	Business	18500.00
0005432839572	7360	Business	18500.00
0005435491459	7360	Business	18500.00
0005432839588	7360	Business	18500.00
0005432839574	7360	Business	18500.00
0005434664985	7360	Business	18500.00
0005435252876	7360	Economy	6200.00
0005434459166	7360	Economy	6200.00
0005432839582	7360	Economy	6200.00
0005435252833	7360	Economy	6200.00
0005434459168	7360	Economy	6200.00
0005435491455	7360	Economy	6200.00
0005435252864	7360	Economy	6200.00
0005435252904	7360	Economy	6200.00
0005435252873	7360	Economy	6800.00
0005432823483	7360	Economy	6800.00
0005435252837	7360	Economy	6800.00
0005432073451	7360	Economy	6800.00
0005434459176	7360	Economy	6200.00
0005434664978	7360	Economy	6200.00
0005432839568	7360	Economy	6200.00
0005432839567	7360	Economy	6200.00
0005435491443	7360	Economy	6200.00
0005432839587	7360	Economy	6200.00
0005432839577	7360	Economy	6200.00
0005434664975	7360	Economy	6200.00
0005434459167	7360	Economy	6200.00
0005432823484	7360	Economy	6200.00
0005432839586	7360	Economy	6200.00
0005435252803	7360	Economy	6200.00
0005432839565	7360	Economy	6200.00
0005434664986	7360	Economy	6200.00
0005432073450	7360	Economy	6200.00
0005434459164	7360	Economy	6200.00
0005435252838	7360	Economy	6200.00
0005432839573	7360	Economy	6200.00
0005432839579	7360	Economy	6200.00
0005432839570	7360	Economy	6200.00
0005435252875	7360	Economy	6200.00
0005434459173	7360	Economy	6200.00
0005435252913	7360	Economy	6200.00
0005432839578	7360	Economy	6200.00
0005432839585	7360	Economy	6200.00
0005434459169	7360	Economy	6200.00
0005434459170	7360	Economy	6200.00
0005434664974	7360	Economy	6200.00
0005435252941	7360	Economy	6200.00
0005432839593	7360	Economy	6200.00
0005432839594	7360	Economy	6200.00
0005432839566	7360	Economy	6200.00
0005434459160	7360	Economy	6200.00
0005432839580	7360	Economy	6200.00
0005435252878	7360	Economy	6200.00
0005432073452	7360	Economy	6200.00
0005432839583	7360	Economy	6200.00
0005432073449	7360	Economy	6200.00
0005432839569	7360	Economy	6200.00
0005432839575	7360	Economy	6200.00
0005434459171	7360	Economy	6200.00
0005432839571	7360	Economy	6200.00
0005434459177	7360	Economy	6200.00
0005432839564	7360	Economy	6200.00
0005432839563	7360	Economy	6200.00
0005434459163	7360	Economy	6200.00
0005432839584	7360	Economy	6200.00
0005435252821	7360	Economy	6200.00
0005432839592	7360	Economy	6200.00
0005434459165	7360	Economy	6200.00
0005434459159	7360	Economy	6200.00
0005432841047	7360	Economy	6200.00
0005434459178	7360	Economy	6200.00
0005434459172	7360	Economy	6200.00
0005434459161	7360	Economy	6200.00
0005434459158	7360	Economy	6200.00
0005432839581	7360	Economy	6200.00
0005432839591	7360	Economy	6200.00
0005432841048	7360	Economy	6200.00
0005434459162	7360	Economy	6200.00
0005434664977	7360	Economy	6200.00
0005434459175	7360	Economy	6200.00
0005432839248	28944	Business	18500.00
0005434665001	28944	Business	18500.00
0005432839214	28944	Business	18500.00
0005435253005	28944	Business	18500.00
0005432839433	28944	Business	18500.00
0005435253022	28944	Business	18500.00
0005434459067	28944	Business	18500.00
0005432839295	28944	Business	18500.00
0005434459030	28944	Business	18500.00
0005432839405	28944	Business	18500.00
0005434459014	28944	Business	18500.00
0005434459015	28944	Business	18500.00
0005432839394	28944	Economy	6200.00
0005434458981	28944	Economy	6200.00
0005434459020	28944	Economy	6200.00
0005434458928	28944	Economy	6200.00
0005434458955	28944	Economy	6200.00
0005432839329	28944	Economy	6200.00
0005435253009	28944	Economy	6200.00
0005435253018	28944	Economy	6200.00
0005432839224	28944	Economy	6200.00
0005434459053	28944	Economy	6800.00
0005432839388	28944	Economy	6800.00
0005434459010	28944	Economy	6800.00
0005432839349	28944	Economy	6800.00
0005435253019	28944	Economy	6200.00
0005434665002	28944	Economy	6200.00
0005434459096	28944	Economy	6200.00
0005432839406	28944	Economy	6200.00
0005432841038	28944	Economy	6200.00
0005434459068	28944	Economy	6200.00
0005434459028	28944	Economy	6200.00
0005432839381	28944	Economy	6200.00
0005434459029	28944	Economy	6200.00
0005432839393	28944	Economy	6200.00
0005432839299	28944	Economy	6200.00
0005432839246	28944	Economy	6200.00
0005432839313	28944	Economy	6200.00
0005432839286	28944	Economy	6200.00
0005432823468	28944	Economy	6200.00
0005435491478	28944	Economy	6200.00
0005434458983	28944	Economy	6200.00
0005435253006	28944	Economy	6200.00
0005435253015	28944	Economy	6200.00
0005434459052	28944	Economy	6200.00
0005435253007	28944	Economy	6200.00
0005434459061	28944	Economy	6200.00
0005432839382	28944	Economy	6200.00
0005435253012	28944	Economy	6200.00
0005435253021	28944	Economy	6200.00
0005434458948	28944	Economy	6200.00
0005432839383	28944	Economy	6200.00
0005432839300	28944	Economy	6200.00
0005434458933	28944	Economy	6200.00
0005435253023	28944	Economy	6200.00
0005432839376	28944	Economy	6200.00
0005432839344	28944	Economy	6200.00
0005432839377	28944	Economy	6200.00
0005432839498	28944	Economy	6200.00
0005432839276	28944	Economy	6200.00
0005435491479	28944	Economy	6200.00
0005432839277	28944	Economy	6200.00
0005432839362	28944	Economy	6200.00
0005434458982	28944	Economy	6200.00
0005432839445	28944	Economy	6200.00
0005432839247	28944	Economy	6200.00
0005435253011	28944	Economy	6200.00
0005434458927	28944	Economy	6200.00
0005432001059	28944	Economy	6200.00
0005432823473	28944	Economy	6200.00
0005434458996	28944	Economy	6200.00
0005435253014	28944	Economy	6200.00
0005434458931	28944	Economy	6200.00
0005432839389	28944	Economy	6200.00
0005432839434	28944	Economy	6200.00
0005432839328	28944	Economy	6200.00
0005435253008	28944	Economy	6200.00
0005435253016	28944	Economy	6200.00
0005432839378	28944	Economy	6200.00
0005435253020	28944	Economy	6200.00
0005432839432	28944	Economy	6200.00
0005434459019	28944	Economy	6200.00
0005435253010	28944	Economy	6200.00
0005435253017	28944	Economy	6200.00
0005435253013	28944	Economy	6200.00
0005434458975	28944	Economy	6200.00
0005432841037	28944	Economy	6200.00
0005434459040	28944	Economy	6200.00
0005434458932	28944	Economy	6200.00
0005435990748	8808	Business	145300.00
0005435990749	8808	Economy	48400.00
0005435990746	8808	Economy	48400.00
0005434276088	8808	Economy	48400.00
0005434276082	8808	Economy	48400.00
0005435990751	8808	Economy	48400.00
0005435990752	8808	Economy	48400.00
0005435990747	8808	Economy	48400.00
0005435990745	8808	Economy	48400.00
0005435990750	8808	Economy	48400.00
0005434276131	15738	Business	145300.00
0005434276127	15738	Business	145300.00
0005434276130	15738	Business	145300.00
0005435990665	15738	Economy	48400.00
0005434276125	15738	Economy	48400.00
0005434276129	15738	Economy	48400.00
0005434276128	15738	Economy	48400.00
0005434276126	15738	Economy	48400.00
0005432427181	20640	Economy	15900.00
0005432427180	20640	Economy	14500.00
0005432427175	20640	Economy	14500.00
0005433476907	20640	Economy	14500.00
0005433476912	20640	Economy	14500.00
0005432427179	20640	Economy	14500.00
0005433476909	20640	Economy	14500.00
0005433476911	20640	Economy	14500.00
0005433476910	20640	Economy	14500.00
0005432427177	20640	Economy	14500.00
0005432427178	20640	Economy	14500.00
0005433476908	20640	Economy	14500.00
0005432427176	20640	Economy	14500.00
0005433476930	30853	Economy	14500.00
0005432427165	30853	Economy	14500.00
0005432427158	30853	Economy	14500.00
0005433476928	30853	Economy	14500.00
0005433476927	30853	Economy	14500.00
0005432427166	30853	Economy	14500.00
0005433476929	30853	Economy	14500.00
0005433476931	30853	Economy	14500.00
0005432909378	23847	Economy	13300.00
0005432909372	23847	Economy	13300.00
0005433468394	23847	Economy	13300.00
0005433468406	23847	Economy	12100.00
0005433468419	23847	Economy	12100.00
0005433468387	23847	Economy	12100.00
0005433468421	23847	Economy	12100.00
0005433468415	23847	Economy	12100.00
0005433468423	23847	Economy	12100.00
0005433468395	23847	Economy	12100.00
0005432909380	23847	Economy	12100.00
0005433468399	23847	Economy	12100.00
0005433468420	23847	Economy	12100.00
0005433468458	23847	Economy	12100.00
0005432909373	23847	Economy	12100.00
0005433468400	23847	Economy	12100.00
0005432909377	23847	Economy	12100.00
0005433468416	23847	Economy	12100.00
0005432909370	23847	Economy	12100.00
0005432909374	23847	Economy	12100.00
0005433468412	23847	Economy	12100.00
0005432909376	23847	Economy	12100.00
0005433468402	23847	Economy	12100.00
0005432909375	23847	Economy	12100.00
0005433468386	23847	Economy	12100.00
0005432909379	23847	Economy	12100.00
0005433468403	23847	Economy	12100.00
0005433468461	23847	Economy	12100.00
0005433468383	23847	Economy	12100.00
0005433468418	23847	Economy	12100.00
0005432909371	23847	Economy	12100.00
0005433468404	23847	Economy	12100.00
0005432361193	6366	Business	36600.00
0005432062322	6366	Business	36600.00
0005432336240	6366	Business	36600.00
0005435490252	6366	Business	36600.00
0005432361226	6366	Business	36600.00
0005432336236	6366	Business	36600.00
0005434149814	6366	Business	36600.00
0005432336237	6366	Business	36600.00
0005432361198	6366	Business	36600.00
0005432336245	6366	Business	36600.00
0005435490262	6366	Business	36600.00
0005435177421	6366	Business	36600.00
0005435177348	6366	Economy	12200.00
0005432361210	6366	Economy	12200.00
0005432361214	6366	Economy	12200.00
0005435177427	6366	Economy	12200.00
0005435177368	6366	Economy	12200.00
0005434149805	6366	Economy	12200.00
0005432361183	6366	Economy	12200.00
0005432336246	6366	Economy	12200.00
0005432336242	6366	Economy	12200.00
0005435177231	6366	Economy	12200.00
0005432062320	6366	Economy	12200.00
0005432062324	6366	Economy	12200.00
0005432361196	6366	Economy	12200.00
0005432361188	6366	Economy	12200.00
0005432361181	6366	Economy	12200.00
0005432361203	6366	Economy	12200.00
0005435177261	6366	Economy	12200.00
0005432336248	6366	Economy	12200.00
0005432361201	6366	Economy	12200.00
0005432361200	6366	Economy	12200.00
0005432361190	6366	Economy	12200.00
0005434149845	6366	Economy	12200.00
0005432361189	6366	Economy	12200.00
0005435490261	6366	Economy	12200.00
0005432361204	6366	Economy	12200.00
0005435177395	6366	Economy	12200.00
0005432361215	6366	Economy	12200.00
0005435177424	6366	Economy	12200.00
0005435177338	6366	Economy	12200.00
0005432361182	6366	Economy	12200.00
0005432361217	6366	Economy	12200.00
0005432361209	6366	Economy	12200.00
0005435177391	6366	Economy	12200.00
0005435177319	6366	Economy	12200.00
0005432361207	6366	Economy	12200.00
0005432361199	6366	Economy	12200.00
0005432361218	6366	Economy	12200.00
0005435723064	6366	Economy	13400.00
0005432336239	6366	Economy	13400.00
0005432336243	6366	Economy	13400.00
0005435177299	6366	Economy	13400.00
0005432336241	6366	Economy	13400.00
0005432062323	6366	Economy	13400.00
0005435177285	6366	Economy	12200.00
0005435490257	6366	Economy	12200.00
0005432361208	6366	Economy	12200.00
0005432363475	6366	Economy	12200.00
0005435723063	6366	Economy	12200.00
0005432361225	6366	Economy	12200.00
0005432361205	6366	Economy	12200.00
0005435490251	6366	Economy	12200.00
0005432361191	6366	Economy	12200.00
0005435177229	6366	Economy	12200.00
0005432361219	6366	Economy	12200.00
0005432361227	6366	Economy	12200.00
0005435490255	6366	Economy	12200.00
0005435177396	6366	Economy	12200.00
0005432361223	6366	Economy	12200.00
0005432361224	6366	Economy	12200.00
0005432361185	6366	Economy	12200.00
0005432361222	6366	Economy	12200.00
0005434149859	6366	Economy	12200.00
0005432062321	6366	Economy	12200.00
0005435177361	6366	Economy	12200.00
0005432361179	6366	Economy	12200.00
0005432363474	6366	Economy	12200.00
0005434149863	6366	Economy	12200.00
0005432361213	6366	Economy	12200.00
0005432363472	6366	Economy	12200.00
0005435177392	6366	Economy	12200.00
0005435490260	6366	Economy	12200.00
0005432062319	6366	Economy	12200.00
0005432361212	6366	Economy	12200.00
0005435723065	6366	Economy	12200.00
0005435723054	6366	Economy	12200.00
0005435177383	6366	Economy	12200.00
0005432361184	6366	Economy	12200.00
0005432361187	6366	Economy	12200.00
0005432336244	6366	Economy	12200.00
0005435177371	6366	Economy	12200.00
0005435177373	6366	Economy	12200.00
0005435490263	6366	Economy	12200.00
0005434149782	6366	Economy	12200.00
0005435723059	6366	Economy	12200.00
0005435177327	6366	Economy	12200.00
0005432361194	6366	Economy	12200.00
0005435490256	6366	Economy	12200.00
0005432361202	6366	Economy	12200.00
0005432336247	6366	Economy	12200.00
0005432361197	6366	Economy	12200.00
0005435177468	6366	Economy	12200.00
0005434149867	6366	Economy	12200.00
0005432361220	6366	Economy	12200.00
0005432361186	6366	Economy	12200.00
0005432361195	6366	Economy	12200.00
0005432361206	6366	Economy	12200.00
0005432361180	6366	Economy	12200.00
0005432361211	6366	Economy	12200.00
0005435723058	6366	Economy	12200.00
0005432361192	6366	Economy	12200.00
0005435177397	6366	Economy	12200.00
0005435177306	6366	Economy	12200.00
0005432361216	6366	Economy	12200.00
0005432361221	6366	Economy	12200.00
0005435177230	6366	Economy	12200.00
0005435177232	6366	Economy	12200.00
0005432336238	6366	Economy	12200.00
0005435177274	6366	Economy	12200.00
0005432363473	6366	Economy	12200.00
0005435177553	20989	Business	36600.00
0005432336176	20989	Business	36600.00
0005432052799	20989	Business	36600.00
0005432360812	20989	Business	36600.00
0005435177557	20989	Business	36600.00
0005432360916	20989	Business	36600.00
0005435177558	20989	Business	36600.00
0005434149930	20989	Economy	12200.00
0005435723079	20989	Economy	12200.00
0005432336132	20989	Economy	12200.00
0005435177554	20989	Economy	12200.00
0005432052800	20989	Economy	12200.00
0005435177567	20989	Economy	12200.00
0005434149938	20989	Economy	12200.00
0005435177551	20989	Economy	12200.00
0005432360686	20989	Economy	12200.00
0005432360736	20989	Economy	12200.00
0005435177544	20989	Economy	12200.00
0005435177555	20989	Economy	12200.00
0005435490294	20989	Economy	12200.00
0005435177566	20989	Economy	12200.00
0005432360924	20989	Economy	12200.00
0005435177562	20989	Economy	12200.00
0005432360664	20989	Economy	12200.00
0005432360923	20989	Economy	12200.00
0005434149940	20989	Economy	12200.00
0005432336162	20989	Economy	12200.00
0005434149936	20989	Economy	12200.00
0005432360640	20989	Economy	12200.00
0005435177559	20989	Economy	12200.00
0005435177552	20989	Economy	12200.00
0005432336164	20989	Economy	12200.00
0005432360663	20989	Economy	12200.00
0005432360748	20989	Economy	12200.00
0005432336155	20989	Economy	12200.00
0005432360835	20989	Economy	12200.00
0005432360583	20989	Economy	13400.00
0005435177561	20989	Economy	13400.00
0005434149934	20989	Economy	13400.00
0005432360945	20989	Economy	12200.00
0005434149941	20989	Economy	12200.00
0005435177547	20989	Economy	12200.00
0005432336146	20989	Economy	12200.00
0005432363444	20989	Economy	12200.00
0005432360922	20989	Economy	12200.00
0005432360944	20989	Economy	12200.00
0005434149937	20989	Economy	12200.00
0005432360724	20989	Economy	12200.00
0005434149935	20989	Economy	12200.00
0005435490293	20989	Economy	12200.00
0005432336148	20989	Economy	12200.00
0005435177550	20989	Economy	12200.00
0005432360781	20989	Economy	12200.00
0005432360871	20989	Economy	12200.00
0005435177571	20989	Economy	12200.00
0005432360714	20989	Economy	12200.00
0005432360735	20989	Economy	12200.00
0005432360688	20989	Economy	12200.00
0005434149933	20989	Economy	12200.00
0005432336136	20989	Economy	12200.00
0005435490295	20989	Economy	12200.00
0005432360886	20989	Economy	12200.00
0005432360792	20989	Economy	12200.00
0005432360739	20989	Economy	12200.00
0005435177568	20989	Economy	12200.00
0005435177546	20989	Economy	12200.00
0005435490296	20989	Economy	12200.00
0005432052798	20989	Economy	12200.00
0005435177560	20989	Economy	12200.00
0005432360747	20989	Economy	12200.00
0005432336147	20989	Economy	12200.00
0005435177548	20989	Economy	12200.00
0005432360713	20989	Economy	12200.00
0005435177556	20989	Economy	12200.00
0005435177549	20989	Economy	12200.00
0005432360877	20989	Economy	12200.00
0005435177569	20989	Economy	12200.00
0005435177545	20989	Economy	12200.00
0005432360864	20989	Economy	12200.00
0005434149931	20989	Economy	12200.00
0005432360618	20989	Economy	12200.00
0005432360617	20989	Economy	12200.00
0005432360904	20989	Economy	12200.00
0005432360708	20989	Economy	12200.00
0005432360863	20989	Economy	12200.00
0005435177563	20989	Economy	12200.00
0005432360639	20989	Economy	12200.00
0005434149939	20989	Economy	12200.00
0005434149932	20989	Economy	12200.00
0005435177570	20989	Economy	12200.00
0005435177565	20989	Economy	12200.00
0005432360731	20989	Economy	12200.00
0005435177564	20989	Economy	12200.00
0005432360651	20989	Economy	12200.00
0005435723080	20989	Economy	12200.00
0005432360885	20989	Economy	12200.00
0005432360925	20989	Economy	12200.00
0005432360884	20989	Economy	12200.00
0005434458987	17689	Economy	3400.00
0005434463944	17689	Economy	3100.00
0005434448344	17689	Economy	3100.00
0005434459002	17689	Economy	3100.00
0005434186250	17689	Economy	3100.00
0005434458999	17689	Economy	3100.00
0005434459049	17689	Economy	3100.00
0005434448345	17689	Economy	3100.00
0005434448353	17689	Economy	3100.00
0005434461665	17689	Economy	3100.00
0005434186251	17689	Economy	3100.00
0005434448352	17689	Economy	3100.00
0005434459050	17689	Economy	3100.00
0005434463943	17689	Economy	3100.00
0005434448337	17689	Economy	3100.00
0005434448343	17689	Economy	3100.00
0005434461658	17689	Economy	3100.00
0005434461664	17689	Economy	3100.00
0005434458913	17689	Economy	3100.00
0005434458990	17689	Economy	3100.00
0005434458914	17689	Economy	3100.00
0005434463945	17689	Economy	3100.00
0005434186252	17689	Economy	3100.00
0005434461659	17689	Economy	3100.00
0005434186249	17689	Economy	3100.00
0005434463954	17689	Economy	3100.00
0005434459162	29102	Economy	3400.00
0005434459174	29102	Economy	3400.00
0005434459170	29102	Economy	3100.00
0005434459169	29102	Economy	3100.00
0005434459164	29102	Economy	3100.00
0005434459160	29102	Economy	3100.00
0005434459173	29102	Economy	3100.00
0005434459168	29102	Economy	3100.00
0005434459167	29102	Economy	3100.00
0005434459161	29102	Economy	3100.00
0005434448371	29102	Economy	3100.00
0005434459178	29102	Economy	3100.00
0005434186223	29102	Economy	3100.00
0005434459177	29102	Economy	3100.00
0005434459176	29102	Economy	3100.00
0005434463965	29102	Economy	3100.00
0005434186213	29102	Economy	3100.00
0005434463967	29102	Economy	3100.00
0005434448374	29102	Economy	3100.00
0005434459172	29102	Economy	3100.00
0005434186212	29102	Economy	3100.00
0005434186225	29102	Economy	3100.00
0005434462825	29102	Economy	3100.00
0005434448372	29102	Economy	3100.00
0005434186229	29102	Economy	3100.00
0005434463966	29102	Economy	3100.00
0005434459166	29102	Economy	3100.00
0005434459171	29102	Economy	3100.00
0005434448373	29102	Economy	3100.00
0005434459159	29102	Economy	3100.00
0005434186224	29102	Economy	3100.00
0005434459163	29102	Economy	3100.00
0005434459158	29102	Economy	3100.00
0005434459165	29102	Economy	3100.00
0005434462826	29102	Economy	3100.00
0005434459175	29102	Economy	3100.00
0005432664180	6489	Business	185300.00
0005432661961	6489	Business	185300.00
0005432661970	6489	Business	185300.00
0005432663073	6489	Business	185300.00
0005432663072	6489	Business	185300.00
0005432661965	6489	Business	185300.00
0005432663074	6489	Business	185300.00
0005432661974	6489	Economy	61800.00
0005432661966	6489	Economy	61800.00
0005432661971	6489	Economy	61800.00
0005432661973	6489	Economy	61800.00
0005432663075	6489	Economy	61800.00
0005432661964	6489	Economy	67900.00
0005432663079	6489	Economy	67900.00
0005432661967	6489	Economy	61800.00
0005432664186	6489	Economy	61800.00
0005432664179	6489	Economy	61800.00
0005432664183	6489	Economy	61800.00
0005432663085	6489	Economy	61800.00
0005432661960	6489	Economy	61800.00
0005432664182	6489	Economy	61800.00
0005432664181	6489	Economy	61800.00
0005432664177	6489	Economy	61800.00
0005432664187	6489	Economy	61800.00
0005432664184	6489	Economy	61800.00
0005432661962	6489	Economy	61800.00
0005432661972	6489	Economy	61800.00
0005432661969	6489	Economy	61800.00
0005432663078	6489	Economy	61800.00
0005432661963	6489	Economy	61800.00
0005432664174	6489	Economy	61800.00
0005432664178	6489	Economy	61800.00
0005432663082	6489	Economy	61800.00
0005432663080	6489	Economy	61800.00
0005432663076	6489	Economy	61800.00
0005432663071	6489	Economy	61800.00
0005432663081	6489	Economy	61800.00
0005432663077	6489	Economy	61800.00
0005432664175	6489	Economy	61800.00
0005432663084	6489	Economy	61800.00
0005432663083	6489	Economy	61800.00
0005432661968	6489	Economy	61800.00
0005432664176	6489	Economy	61800.00
0005432664173	6489	Economy	61800.00
0005432664185	6489	Economy	61800.00
0005432604981	21413	Economy	7300.00
0005432605008	21413	Economy	7300.00
0005432604996	21413	Economy	7300.00
0005432605018	21413	Economy	7300.00
0005432604998	21413	Economy	6600.00
0005432604985	21413	Economy	6600.00
0005432605007	21413	Economy	6600.00
0005432604988	21413	Economy	6600.00
0005432605006	21413	Economy	6600.00
0005432605011	21413	Economy	6600.00
0005432604993	21413	Economy	6600.00
0005432604987	21413	Economy	6600.00
0005432605014	21413	Economy	6600.00
0005432605009	21413	Economy	6600.00
0005432605003	21413	Economy	6600.00
0005432605004	21413	Economy	6600.00
0005432605020	21413	Economy	6600.00
0005432604997	21413	Economy	6600.00
0005432604994	21413	Economy	6600.00
0005432605005	21413	Economy	6600.00
0005432605013	21413	Economy	6600.00
0005432605015	21413	Economy	6600.00
0005432604990	21413	Economy	6600.00
0005432604983	21413	Economy	6600.00
0005432604982	21413	Economy	6600.00
0005432604984	21413	Economy	6600.00
0005432604999	21413	Economy	6600.00
0005432605017	21413	Economy	6600.00
0005432605016	21413	Economy	6600.00
0005432605010	21413	Economy	6600.00
0005432604991	21413	Economy	6600.00
0005432605019	21413	Economy	6600.00
0005432604992	21413	Economy	6600.00
0005432605000	21413	Economy	6600.00
0005432605012	21413	Economy	6600.00
0005432604995	21413	Economy	6600.00
0005432604986	21413	Economy	6600.00
0005432605001	21413	Economy	6600.00
0005432605002	21413	Economy	6600.00
0005432604989	21413	Economy	6600.00
0005432604712	31707	Economy	7300.00
0005432604585	31707	Economy	7300.00
0005432604635	31707	Economy	7300.00
0005432604647	31707	Economy	6600.00
0005432604673	31707	Economy	6600.00
0005432604823	31707	Economy	6600.00
0005432604767	31707	Economy	6600.00
0005432604516	31707	Economy	6600.00
0005432604681	31707	Economy	6600.00
0005432604537	31707	Economy	6600.00
0005432604646	31707	Economy	6600.00
0005432604772	31707	Economy	6600.00
0005435221526	31707	Economy	6600.00
0005432604761	31707	Economy	6600.00
0005432604566	31707	Economy	6600.00
0005432604450	31707	Economy	6600.00
0005435221068	31707	Economy	6600.00
0005432604719	31707	Economy	6600.00
0005432604718	31707	Economy	6600.00
0005432604665	31707	Economy	6600.00
0005432604451	31707	Economy	6600.00
0005432604565	31707	Economy	6600.00
0005432604519	31707	Economy	6600.00
0005432604623	31707	Economy	6600.00
0005435221069	31707	Economy	6600.00
0005432604631	31707	Economy	6600.00
0005432604760	31707	Economy	6600.00
0005432604584	31707	Economy	6600.00
0005432604766	31707	Economy	6600.00
0005432604683	31707	Economy	6600.00
0005432604622	31707	Economy	6600.00
0005432604624	31707	Economy	6600.00
0005432604637	31707	Economy	6600.00
0005432604632	31707	Economy	6600.00
0005432604639	31707	Economy	6600.00
0005432604612	31707	Economy	6600.00
0005432604636	31707	Economy	6600.00
0005435221527	31707	Economy	6600.00
0005435221070	31707	Economy	6600.00
0005433293283	12316	Economy	19500.00
0005433293266	12316	Economy	17800.00
0005435154625	12316	Economy	17800.00
0005433293256	12316	Economy	17800.00
0005435154627	12316	Economy	17800.00
0005433293284	12316	Economy	17800.00
0005433293299	12316	Economy	17800.00
0005435154628	12316	Economy	17800.00
0005433293293	12316	Economy	17800.00
0005435154624	12316	Economy	17800.00
0005433293268	12316	Economy	17800.00
0005433293285	12316	Economy	17800.00
0005435154626	12316	Economy	17800.00
0005433293244	12316	Economy	17800.00
0005433293306	12316	Economy	17800.00
0005433293290	12316	Economy	17800.00
0005433293289	12316	Economy	17800.00
0005433293294	12316	Economy	17800.00
0005435154622	12316	Economy	17800.00
0005435154623	12316	Economy	17800.00
0005433293300	12316	Economy	17800.00
0005433293297	12316	Economy	17800.00
0005435154621	12316	Economy	17800.00
0005433293267	12316	Economy	17800.00
0005433293269	12316	Economy	17800.00
0005433293298	12316	Economy	17800.00
0005433473337	23891	Economy	14000.00
0005433473355	23891	Economy	14000.00
0005435257319	23891	Economy	12700.00
0005433473316	23891	Economy	12700.00
0005435257328	23891	Economy	12700.00
0005433473359	23891	Economy	12700.00
0005433473319	23891	Economy	12700.00
0005433473329	23891	Economy	12700.00
0005435257324	23891	Economy	12700.00
0005433473333	23891	Economy	12700.00
0005435257327	23891	Economy	12700.00
0005435257323	23891	Economy	12700.00
0005433473315	23891	Economy	12700.00
0005435257318	23891	Economy	12700.00
0005433473330	23891	Economy	12700.00
0005435257321	23891	Economy	12700.00
0005433473332	23891	Economy	12700.00
0005435257322	23891	Economy	12700.00
0005435257320	23891	Economy	12700.00
0005435257329	23891	Economy	12700.00
0005435257326	23891	Economy	12700.00
0005435257325	23891	Economy	12700.00
0005434606863	18852	Economy	6600.00
0005434606840	18852	Economy	6600.00
0005434606841	18852	Economy	6600.00
0005434606839	18852	Economy	6600.00
0005434606849	18852	Economy	6600.00
0005434606850	18852	Economy	6600.00
0005434606848	18852	Economy	6600.00
0005434604956	22295	Economy	6600.00
0005434606881	22295	Economy	6600.00
0005434606882	22295	Economy	6600.00
0005434604954	22295	Economy	6600.00
0005435904708	22295	Economy	6600.00
0005434604955	22295	Economy	6600.00
0005434604953	22295	Economy	6600.00
0005434522508	3847	Economy	24900.00
0005434522511	3847	Economy	24900.00
0005434602941	3847	Economy	24900.00
0005435904426	3847	Economy	24900.00
0005435904428	3847	Economy	22600.00
0005434522509	3847	Economy	22600.00
0005434522512	3847	Economy	22600.00
0005434602946	3847	Economy	22600.00
0005434602945	3847	Economy	22600.00
0005435904432	3847	Economy	22600.00
0005434602947	3847	Economy	22600.00
0005434522507	3847	Economy	22600.00
0005435904407	3847	Economy	22600.00
0005434522510	3847	Economy	22600.00
0005435904430	3847	Economy	22600.00
0005435904431	3847	Economy	22600.00
0005434602943	3847	Economy	22600.00
0005434602944	3847	Economy	22600.00
0005434602940	3847	Economy	22600.00
0005434602942	3847	Economy	22600.00
0005435904421	3847	Economy	22600.00
0005435904422	3847	Economy	22600.00
0005434522513	3847	Economy	22600.00
0005434602918	19065	Economy	24900.00
0005434604933	19065	Economy	24900.00
0005434522480	19065	Economy	24900.00
0005434602922	19065	Economy	22600.00
0005434602916	19065	Economy	22600.00
0005434604934	19065	Economy	22600.00
0005434602921	19065	Economy	22600.00
0005434522474	19065	Economy	22600.00
0005435904447	19065	Economy	22600.00
0005434604925	19065	Economy	22600.00
0005434602915	19065	Economy	22600.00
0005435904448	19065	Economy	22600.00
0005434522488	19065	Economy	22600.00
0005434522471	19065	Economy	22600.00
0005434602914	19065	Economy	22600.00
0005434602920	19065	Economy	22600.00
0005434522479	19065	Economy	22600.00
0005434522486	19065	Economy	22600.00
0005434602912	19065	Economy	22600.00
0005434602928	19065	Economy	22600.00
0005434602919	19065	Economy	22600.00
0005434522475	19065	Economy	22600.00
0005434522487	19065	Economy	22600.00
0005435904449	19065	Economy	22600.00
0005435904450	19065	Economy	22600.00
0005435904714	19065	Economy	22600.00
0005434522482	19065	Economy	22600.00
0005434604926	19065	Economy	22600.00
0005435904446	19065	Economy	22600.00
0005434522501	19065	Economy	22600.00
0005434522485	19065	Economy	22600.00
0005434522481	19065	Economy	22600.00
0005432748208	415	Business	44500.00
0005432751585	415	Business	44500.00
0005432748228	415	Business	44500.00
0005432751582	415	Business	44500.00
0005432748217	415	Business	44500.00
0005432891309	415	Business	44500.00
0005432891198	415	Business	44500.00
0005432891252	415	Business	44500.00
0005432748216	415	Business	44500.00
0005432891229	415	Business	44500.00
0005432891239	415	Business	44500.00
0005432753357	415	Business	44500.00
0005432748242	415	Economy	14800.00
0005433293292	415	Economy	14800.00
0005432748227	415	Economy	14800.00
0005433293305	415	Economy	14800.00
0005432748245	415	Economy	14800.00
0005432748241	415	Economy	14800.00
0005432751581	415	Economy	14800.00
0005432891202	415	Economy	14800.00
0005432891207	415	Economy	14800.00
0005432748230	415	Economy	14800.00
0005432748221	415	Economy	16300.00
0005432220078	415	Economy	16300.00
0005432891152	415	Economy	16300.00
0005432748222	415	Economy	16300.00
0005432748229	415	Economy	16300.00
0005432891310	415	Economy	14800.00
0005432891138	415	Economy	14800.00
0005432891205	415	Economy	14800.00
0005432891230	415	Economy	14800.00
0005432748212	415	Economy	14800.00
0005432748232	415	Economy	14800.00
0005432748219	415	Economy	14800.00
0005432751583	415	Economy	14800.00
0005432748210	415	Economy	14800.00
0005432891200	415	Economy	14800.00
0005432891137	415	Economy	14800.00
0005432748234	415	Economy	14800.00
0005432891238	415	Economy	14800.00
0005432753356	415	Economy	14800.00
0005432748218	415	Economy	14800.00
0005432891208	415	Economy	14800.00
0005433293291	415	Economy	14800.00
0005433293303	415	Economy	14800.00
0005432891172	415	Economy	14800.00
0005433293302	415	Economy	14800.00
0005432748207	415	Economy	14800.00
0005432891199	415	Economy	14800.00
0005432748244	415	Economy	14800.00
0005432749821	415	Economy	14800.00
0005432220077	415	Economy	14800.00
0005432748226	415	Economy	14800.00
0005432891293	415	Economy	14800.00
0005432748224	415	Economy	14800.00
0005432748237	415	Economy	14800.00
0005432891151	415	Economy	14800.00
0005432891214	415	Economy	14800.00
0005432891136	415	Economy	14800.00
0005432748225	415	Economy	14800.00
0005432748211	415	Economy	14800.00
0005432748233	415	Economy	14800.00
0005432220075	415	Economy	14800.00
0005432891206	415	Economy	14800.00
0005433293304	415	Economy	14800.00
0005432748240	415	Economy	14800.00
0005432749822	415	Economy	14800.00
0005432753355	415	Economy	14800.00
0005432748223	415	Economy	14800.00
0005432753358	415	Economy	14800.00
0005432751584	415	Economy	14800.00
0005432891253	415	Economy	14800.00
0005432748214	415	Economy	14800.00
0005432748243	415	Economy	14800.00
0005432748231	415	Economy	14800.00
0005432748206	415	Economy	14800.00
0005432748236	415	Economy	14800.00
0005432891231	415	Economy	14800.00
0005432891294	415	Economy	14800.00
0005432748220	415	Economy	14800.00
0005432748235	415	Economy	14800.00
0005432220076	415	Economy	14800.00
0005432748238	415	Economy	14800.00
0005432748213	415	Economy	14800.00
0005432891135	415	Economy	14800.00
0005432891249	415	Economy	14800.00
0005432891218	415	Economy	14800.00
0005432748215	415	Economy	14800.00
0005433293301	415	Economy	14800.00
0005432749820	415	Economy	14800.00
0005432891237	415	Economy	14800.00
0005432891112	415	Economy	14800.00
0005432751580	415	Economy	14800.00
0005432891160	415	Economy	14800.00
0005432748239	415	Economy	14800.00
0005432748209	415	Economy	14800.00
0005432891178	415	Economy	14800.00
0005432747916	12038	Business	44500.00
0005432753328	12038	Business	44500.00
0005432891355	12038	Business	44500.00
0005432747949	12038	Business	44500.00
0005432747887	12038	Business	44500.00
0005432891356	12038	Business	44500.00
0005432747983	12038	Business	44500.00
0005432748005	12038	Economy	14800.00
0005432891365	12038	Economy	14800.00
0005432747959	12038	Economy	14800.00
0005432891360	12038	Economy	14800.00
0005432753342	12038	Economy	14800.00
0005432891354	12038	Economy	14800.00
0005432891363	12038	Economy	14800.00
0005432747886	12038	Economy	16300.00
0005432756867	12038	Economy	16300.00
0005432747965	12038	Economy	16300.00
0005432747857	12038	Economy	14800.00
0005432753343	12038	Economy	14800.00
0005432747786	12038	Economy	14800.00
0005432747896	12038	Economy	14800.00
0005432891367	12038	Economy	14800.00
0005432747855	12038	Economy	14800.00
0005432747866	12038	Economy	14800.00
0005432891351	12038	Economy	14800.00
0005432747882	12038	Economy	14800.00
0005432747854	12038	Economy	14800.00
0005432891370	12038	Economy	14800.00
0005432748020	12038	Economy	14800.00
0005432891359	12038	Economy	14800.00
0005432891361	12038	Economy	14800.00
0005432891353	12038	Economy	14800.00
0005432747941	12038	Economy	14800.00
0005432756866	12038	Economy	14800.00
0005432748057	12038	Economy	14800.00
0005432748122	12038	Economy	14800.00
0005432747852	12038	Economy	14800.00
0005432747853	12038	Economy	14800.00
0005432891364	12038	Economy	14800.00
0005432891366	12038	Economy	14800.00
0005432214842	12038	Economy	14800.00
0005432747734	12038	Economy	14800.00
0005432214840	12038	Economy	14800.00
0005432747868	12038	Economy	14800.00
0005432753329	12038	Economy	14800.00
0005432891357	12038	Economy	14800.00
0005432891368	12038	Economy	14800.00
0005432748004	12038	Economy	14800.00
0005432748073	12038	Economy	14800.00
0005432891369	12038	Economy	14800.00
0005432214841	12038	Economy	14800.00
0005432747744	12038	Economy	14800.00
0005432747901	12038	Economy	14800.00
0005432753317	12038	Economy	14800.00
0005432891358	12038	Economy	14800.00
0005432747733	12038	Economy	14800.00
0005432747895	12038	Economy	14800.00
0005432748097	12038	Economy	14800.00
0005432891362	12038	Economy	14800.00
0005432747785	12038	Economy	14800.00
0005432747856	12038	Economy	14800.00
0005432747984	12038	Economy	14800.00
0005432747827	12038	Economy	14800.00
0005432747919	12038	Economy	14800.00
0005432747873	12038	Economy	14800.00
0005432747944	12038	Economy	14800.00
0005432747964	12038	Economy	14800.00
0005432747990	12038	Economy	14800.00
0005432891352	12038	Economy	14800.00
0005433525223	18943	Economy	28200.00
0005432928021	18943	Economy	28200.00
0005433525217	18943	Economy	25700.00
0005433531354	18943	Economy	25700.00
0005432928048	18943	Economy	25700.00
0005432928019	18943	Economy	25700.00
0005433531355	18943	Economy	25700.00
0005432928047	18943	Economy	25700.00
0005432928027	18943	Economy	25700.00
0005433533372	18943	Economy	25700.00
0005432928028	18943	Economy	25700.00
0005433525216	18943	Economy	25700.00
0005432928026	18943	Economy	25700.00
0005433525220	18943	Economy	25700.00
0005433531356	18943	Economy	25700.00
0005433525215	18943	Economy	25700.00
0005433525218	18943	Economy	25700.00
0005433531357	18943	Economy	25700.00
0005433525219	18943	Economy	25700.00
0005433533371	18943	Economy	25700.00
0005433533370	18943	Economy	25700.00
0005432928020	18943	Economy	25700.00
0005433525221	18943	Economy	25700.00
0005433525222	18943	Economy	25700.00
0005433525224	18943	Economy	25700.00
0005433527298	32507	Economy	28200.00
0005432928086	32507	Economy	28200.00
0005433525145	32507	Economy	25700.00
0005432928083	32507	Economy	25700.00
0005433525115	32507	Economy	25700.00
0005433527291	32507	Economy	25700.00
0005433531319	32507	Economy	25700.00
0005432928084	32507	Economy	25700.00
0005432928081	32507	Economy	25700.00
0005432928085	32507	Economy	25700.00
0005433531320	32507	Economy	25700.00
0005433525112	32507	Economy	25700.00
0005433527290	32507	Economy	25700.00
0005432928080	32507	Economy	25700.00
0005433531328	32507	Economy	25700.00
0005433531326	32507	Economy	25700.00
0005433531330	32507	Economy	25700.00
0005433531321	32507	Economy	25700.00
0005433531329	32507	Economy	25700.00
0005433527289	32507	Economy	25700.00
0005433525144	32507	Economy	25700.00
0005433531318	32507	Economy	25700.00
0005432928082	32507	Economy	25700.00
0005435373838	5255	Business	84000.00
0005434825772	5255	Business	84000.00
0005432121582	5255	Business	84000.00
0005435373877	5255	Business	84000.00
0005434825791	5255	Business	84000.00
0005434825770	5255	Business	84000.00
0005435373701	5255	Business	84000.00
0005435374020	5255	Business	84000.00
0005434825780	5255	Business	84000.00
0005435735186	5255	Business	84000.00
0005434825840	5255	Business	84000.00
0005434825814	5255	Business	84000.00
0005434825812	5255	Business	84000.00
0005435373893	5255	Business	84000.00
0005435386636	5255	Business	84000.00
0005435150267	5255	Business	84000.00
0005434825835	5255	Business	84000.00
0005434825842	5255	Business	84000.00
0005434825805	5255	Business	84000.00
0005435373712	5255	Business	84000.00
0005435374076	5255	Business	84000.00
0005434825776	5255	Business	84000.00
0005434825799	5255	Comfort	47600.00
0005435373758	5255	Comfort	47600.00
0005434825836	5255	Comfort	47600.00
0005435373892	5255	Comfort	47600.00
0005435373722	5255	Comfort	47600.00
0005434825793	5255	Comfort	47600.00
0005434825828	5255	Comfort	47600.00
0005435735185	5255	Comfort	47600.00
0005434825818	5255	Comfort	47600.00
0005434825837	5255	Comfort	47600.00
0005435373976	5255	Comfort	47600.00
0005434825784	5255	Comfort	47600.00
0005435373759	5255	Comfort	47600.00
0005434825804	5255	Comfort	47600.00
0005432823476	5255	Comfort	47600.00
0005435374219	5255	Comfort	47600.00
0005434825853	5255	Comfort	47600.00
0005434825734	5255	Comfort	47600.00
0005435373705	5255	Comfort	47600.00
0005434825817	5255	Comfort	47600.00
0005434825764	5255	Comfort	47600.00
0005434825743	5255	Comfort	47600.00
0005435735156	5255	Comfort	47600.00
0005434825831	5255	Comfort	47600.00
0005434825728	5255	Comfort	47600.00
0005435150275	5255	Comfort	47600.00
0005435373673	5255	Comfort	47600.00
0005435386640	5255	Comfort	47600.00
0005434825741	5255	Comfort	47600.00
0005434825785	5255	Comfort	47600.00
0005435373847	5255	Comfort	47600.00
0005434825729	5255	Comfort	47600.00
0005434825749	5255	Comfort	47600.00
0005435373841	5255	Comfort	47600.00
0005434825762	5255	Economy	28000.00
0005434825844	5255	Economy	28000.00
0005434664999	5255	Economy	28000.00
0005434825730	5255	Economy	28000.00
0005435386649	5255	Economy	28000.00
0005435373790	5255	Economy	28000.00
0005434825781	5255	Economy	28000.00
0005435150270	5255	Economy	28000.00
0005435374075	5255	Economy	28000.00
0005432121574	5255	Economy	28000.00
0005434825774	5255	Economy	28000.00
0005434825838	5255	Economy	28000.00
0005434825788	5255	Economy	28000.00
0005435373476	5255	Economy	28000.00
0005435374217	5255	Economy	28000.00
0005434664997	5255	Economy	28000.00
0005435150277	5255	Economy	28000.00
0005434825738	5255	Economy	28000.00
0005435373789	5255	Economy	28000.00
0005434825744	5255	Economy	28000.00
0005434825740	5255	Economy	28000.00
0005432121576	5255	Economy	28000.00
0005434825757	5255	Economy	28000.00
0005434831229	5255	Economy	28000.00
0005435150276	5255	Economy	28000.00
0005435150271	5255	Economy	28000.00
0005435661955	5255	Economy	28000.00
0005434825753	5255	Economy	28000.00
0005434825733	5255	Economy	28000.00
0005434825815	5255	Economy	28000.00
0005434825732	5255	Economy	28000.00
0005435373871	5255	Economy	28000.00
0005434825823	5255	Economy	28000.00
0005435661948	5255	Economy	28000.00
0005432121578	5255	Economy	28000.00
0005435373475	5255	Economy	28000.00
0005434825813	5255	Economy	28000.00
0005434825777	5255	Economy	28000.00
0005432121579	5255	Economy	28000.00
0005435373878	5255	Economy	28000.00
0005434831231	5255	Economy	28000.00
0005434825847	5255	Economy	30800.00
0005434825841	5255	Economy	30800.00
0005434828743	5255	Economy	28000.00
0005434825735	5255	Economy	28000.00
0005435373742	5255	Economy	28000.00
0005434825746	5255	Economy	28000.00
0005434825795	5255	Economy	30800.00
0005434825760	5255	Economy	30800.00
0005434828742	5255	Economy	30800.00
0005434825798	5255	Economy	28000.00
0005435373606	5255	Economy	28000.00
0005435386622	5255	Economy	28000.00
0005432121575	5255	Economy	28000.00
0005432121587	5255	Economy	28000.00
0005434828745	5255	Economy	28000.00
0005434825806	5255	Economy	28000.00
0005435374071	5255	Economy	28000.00
0005434825786	5255	Economy	28000.00
0005434825801	5255	Economy	28000.00
0005435150266	5255	Economy	28000.00
0005434825769	5255	Economy	28000.00
0005434831230	5255	Economy	28000.00
0005434825766	5255	Economy	28000.00
0005435299812	5255	Economy	28000.00
0005434825794	5255	Economy	28000.00
0005432394177	5255	Economy	28000.00
0005435373819	5255	Economy	28000.00
0005435150274	5255	Economy	28000.00
0005434831228	5255	Economy	28000.00
0005434825809	5255	Economy	28000.00
0005432121577	5255	Economy	28000.00
0005434825820	5255	Economy	28000.00
0005434825775	5255	Economy	28000.00
0005434825839	5255	Economy	28000.00
0005434825745	5255	Economy	28000.00
0005435374216	5255	Economy	28000.00
0005435661954	5255	Economy	28000.00
0005435373932	5255	Economy	28000.00
0005434825819	5255	Economy	28000.00
0005435373907	5255	Economy	28000.00
0005435373720	5255	Economy	28000.00
0005435304193	5255	Economy	28000.00
0005435150272	5255	Economy	28000.00
0005434825822	5255	Economy	28000.00
0005435373934	5255	Economy	28000.00
0005434825779	5255	Economy	28000.00
0005435373894	5255	Economy	28000.00
0005434825737	5255	Economy	28000.00
0005432121586	5255	Economy	28000.00
0005435373978	5255	Economy	28000.00
0005434825811	5255	Economy	28000.00
0005434825752	5255	Economy	28000.00
0005435373717	5255	Economy	28000.00
0005434825754	5255	Economy	28000.00
0005434825739	5255	Economy	28000.00
0005434825768	5255	Economy	28000.00
0005435373930	5255	Economy	28000.00
0005434825821	5255	Economy	28000.00
0005432394175	5255	Economy	28000.00
0005435373652	5255	Economy	28000.00
0005434825852	5255	Economy	28000.00
0005434825802	5255	Economy	28000.00
0005435373895	5255	Economy	28000.00
0005432396311	5255	Economy	28000.00
0005435373745	5255	Economy	28000.00
0005434825763	5255	Economy	28000.00
0005434825761	5255	Economy	28000.00
0005435373713	5255	Economy	28000.00
0005434825750	5255	Economy	28000.00
0005434825797	5255	Economy	28000.00
0005435299816	5255	Economy	28000.00
0005435661950	5255	Economy	28000.00
0005434825756	5255	Economy	28000.00
0005434825765	5255	Economy	28000.00
0005435374074	5255	Economy	28000.00
0005434825851	5255	Economy	28000.00
0005434825807	5255	Economy	28000.00
0005434825816	5255	Economy	28000.00
0005432121580	5255	Economy	28000.00
0005435373960	5255	Economy	28000.00
0005435373832	5255	Economy	28000.00
0005435661951	5255	Economy	28000.00
0005432394174	5255	Economy	28000.00
0005435374093	5255	Economy	28000.00
0005434825773	5255	Economy	28000.00
0005434825751	5255	Economy	28000.00
0005435373955	5255	Economy	28000.00
0005434825825	5255	Economy	28000.00
0005434825783	5255	Economy	28000.00
0005432121581	5255	Economy	30800.00
0005435373653	5255	Economy	28000.00
0005432394176	5255	Economy	30800.00
0005434825834	5255	Economy	30800.00
0005434664998	5255	Economy	30800.00
0005435150268	5255	Economy	28000.00
0005434825759	5255	Economy	30800.00
0005435373741	5255	Economy	28000.00
0005434825824	5255	Economy	28000.00
0005434825800	5255	Economy	28000.00
0005432396312	5255	Economy	28000.00
0005434825767	5255	Economy	28000.00
0005434825736	5255	Economy	28000.00
0005435735158	5255	Economy	28000.00
0005435386642	5255	Economy	28000.00
0005435373831	5255	Economy	28000.00
0005435150265	5255	Economy	28000.00
0005435373582	5255	Economy	28000.00
0005434825803	5255	Economy	28000.00
0005435373961	5255	Economy	28000.00
0005434825843	5255	Economy	28000.00
0005434825830	5255	Economy	28000.00
0005434825792	5255	Economy	28000.00
0005434825771	5255	Economy	28000.00
0005434825846	5255	Economy	28000.00
0005435374077	5255	Economy	28000.00
0005435299827	5255	Economy	28000.00
0005435373906	5255	Economy	28000.00
0005434825845	5255	Economy	28000.00
0005434825748	5255	Economy	28000.00
0005435373891	5255	Economy	28000.00
0005435373581	5255	Economy	28000.00
0005435373837	5255	Economy	28000.00
0005434825758	5255	Economy	28000.00
0005434825826	5255	Economy	28000.00
0005435150269	5255	Economy	28000.00
0005432121573	5255	Economy	28000.00
0005434825829	5255	Economy	28000.00
0005435373644	5255	Economy	28000.00
0005435373559	5255	Economy	28000.00
0005434825747	5255	Economy	28000.00
0005432121585	5255	Economy	28000.00
0005434825855	5255	Economy	28000.00
0005435373721	5255	Economy	28000.00
0005434825755	5255	Economy	28000.00
0005434825808	5255	Economy	28000.00
0005434825810	5255	Economy	28000.00
0005435299811	5255	Economy	28000.00
0005432121583	5255	Economy	28000.00
0005435373499	5255	Economy	28000.00
0005432121584	5255	Economy	28000.00
0005435373711	5255	Economy	28000.00
0005435304198	5255	Economy	28000.00
0005435373925	5255	Economy	28000.00
0005434825850	5255	Economy	28000.00
0005434825854	5255	Economy	28000.00
0005435735157	5255	Economy	28000.00
0005434825778	5255	Economy	28000.00
0005435374218	5255	Economy	28000.00
0005434665000	5255	Economy	28000.00
0005434831227	5255	Economy	28000.00
0005434825849	5255	Economy	28000.00
0005434828744	5255	Economy	28000.00
0005435373698	5255	Economy	28000.00
0005435373977	5255	Economy	28000.00
0005435735166	5255	Economy	28000.00
0005434825832	5255	Economy	28000.00
0005434825731	5255	Economy	28000.00
0005434825782	5255	Economy	28000.00
0005435150278	5255	Economy	28000.00
0005435373924	5255	Economy	28000.00
0005434825848	5255	Economy	28000.00
0005434825833	5255	Economy	28000.00
0005435150279	5255	Economy	28000.00
0005435299828	5255	Economy	28000.00
0005434825790	5255	Economy	28000.00
0005434825787	5255	Economy	28000.00
0005434825796	5255	Economy	28000.00
0005434825742	5255	Economy	28000.00
0005435373800	5255	Economy	28000.00
0005434825827	5255	Economy	28000.00
0005435150273	5255	Economy	28000.00
0005435373674	5255	Economy	28000.00
0005434825789	5255	Economy	28000.00
0005435150119	9937	Business	84000.00
0005434824004	9937	Business	84000.00
0005434824540	9937	Business	84000.00
0005434824761	9937	Business	84000.00
0005435374364	9937	Business	84000.00
0005434824735	9937	Business	84000.00
0005435314959	9937	Business	84000.00
0005435374429	9937	Business	84000.00
0005435299860	9937	Business	84000.00
0005435150125	9937	Business	84000.00
0005435374399	9937	Business	84000.00
0005434824201	9937	Business	84000.00
0005434824895	9937	Business	84000.00
0005435150127	9937	Business	84000.00
0005434824107	9937	Business	84000.00
0005435386681	9937	Business	84000.00
0005434824542	9937	Business	84000.00
0005434824967	9937	Business	84000.00
0005435179409	9937	Business	84000.00
0005434824894	9937	Business	84000.00
0005435374417	9937	Business	84000.00
0005435374430	9937	Business	84000.00
0005435299858	9937	Business	84000.00
0005435299857	9937	Business	84000.00
0005435386684	9937	Comfort	47600.00
0005435386683	9937	Comfort	47600.00
0005434831201	9937	Comfort	47600.00
0005435374421	9937	Comfort	47600.00
0005434558286	9937	Comfort	47600.00
0005434824479	9937	Comfort	47600.00
0005435374384	9937	Comfort	47600.00
0005434824999	9937	Comfort	47600.00
0005434824579	9937	Comfort	47600.00
0005435386688	9937	Comfort	47600.00
0005434823737	9937	Comfort	47600.00
0005432203187	9937	Comfort	47600.00
0005434823922	9937	Comfort	47600.00
0005435374428	9937	Comfort	47600.00
0005432400166	9937	Comfort	47600.00
0005435374411	9937	Comfort	47600.00
0005435150136	9937	Comfort	47600.00
0005435374407	9937	Comfort	47600.00
0005434824056	9937	Comfort	47600.00
0005434824473	9937	Comfort	47600.00
0005435150092	9937	Comfort	47600.00
0005434558310	9937	Comfort	47600.00
0005434558344	9937	Comfort	47600.00
0005434824474	9937	Comfort	47600.00
0005434824454	9937	Comfort	47600.00
0005435150093	9937	Comfort	47600.00
0005434825263	9937	Comfort	47600.00
0005434824626	9937	Comfort	47600.00
0005435150138	9937	Comfort	47600.00
0005434824911	9937	Comfort	47600.00
0005435374397	9937	Comfort	47600.00
0005434824811	9937	Comfort	47600.00
0005435374404	9937	Comfort	47600.00
0005435735219	9937	Comfort	47600.00
0005434824567	9937	Comfort	47600.00
0005434828714	9937	Economy	28000.00
0005435302278	9937	Economy	28000.00
0005434824444	9937	Economy	28000.00
0005434824528	9937	Economy	28000.00
0005434825000	9937	Economy	28000.00
0005435374420	9937	Economy	28000.00
0005435374422	9937	Economy	28000.00
0005434824789	9937	Economy	28000.00
0005435386682	9937	Economy	28000.00
0005434824235	9937	Economy	28000.00
0005434824661	9937	Economy	28000.00
0005434824578	9937	Economy	28000.00
0005435374396	9937	Economy	28000.00
0005434824067	9937	Economy	28000.00
0005435374385	9937	Economy	28000.00
0005434824639	9937	Economy	28000.00
0005434824810	9937	Economy	28000.00
0005434824801	9937	Economy	28000.00
0005434824802	9937	Economy	28000.00
0005435150168	9937	Economy	28000.00
0005434558342	9937	Economy	28000.00
0005434824527	9937	Economy	28000.00
0005435374424	9937	Economy	28000.00
0005434824952	9937	Economy	28000.00
0005435374388	9937	Economy	28000.00
0005435374409	9937	Economy	28000.00
0005434824878	9937	Economy	28000.00
0005435374366	9937	Economy	28000.00
0005434824757	9937	Economy	28000.00
0005435374365	9937	Economy	28000.00
0005434825053	9937	Economy	28000.00
0005434831202	9937	Economy	28000.00
0005435374377	9937	Economy	28000.00
0005434824464	9937	Economy	28000.00
0005434824576	9937	Economy	28000.00
0005432203190	9937	Economy	28000.00
0005434824529	9937	Economy	28000.00
0005435299861	9937	Economy	28000.00
0005435374376	9937	Economy	28000.00
0005434824709	9937	Economy	28000.00
0005435299859	9937	Economy	28000.00
0005435374398	9937	Economy	28000.00
0005435374380	9937	Economy	28000.00
0005434824696	9937	Economy	28000.00
0005434824606	9937	Economy	28000.00
0005434824094	9937	Economy	28000.00
0005434824627	9937	Economy	28000.00
0005435374406	9937	Economy	28000.00
0005435386686	9937	Economy	30800.00
0005435374367	9937	Economy	28000.00
0005435314960	9937	Economy	30800.00
0005435661983	9937	Economy	28000.00
0005434823927	9937	Economy	30800.00
0005435661982	9937	Economy	28000.00
0005434824399	9937	Economy	28000.00
0005435314958	9937	Economy	30800.00
0005434558311	9937	Economy	28000.00
0005435150096	9937	Economy	30800.00
0005434824653	9937	Economy	30800.00
0005432396279	9937	Economy	28000.00
0005432400164	9937	Economy	28000.00
0005434825188	9937	Economy	28000.00
0005435374426	9937	Economy	28000.00
0005432400167	9937	Economy	28000.00
0005434824955	9937	Economy	28000.00
0005434825114	9937	Economy	28000.00
0005435374373	9937	Economy	28000.00
0005434824975	9937	Economy	28000.00
0005434824654	9937	Economy	28000.00
0005434831189	9937	Economy	28000.00
0005435386687	9937	Economy	28000.00
0005434824317	9937	Economy	28000.00
0005434825173	9937	Economy	28000.00
0005434825186	9937	Economy	28000.00
0005434825052	9937	Economy	28000.00
0005434824093	9937	Economy	28000.00
0005434824734	9937	Economy	28000.00
0005435150135	9937	Economy	28000.00
0005434824354	9937	Economy	28000.00
0005434824686	9937	Economy	28000.00
0005434824340	9937	Economy	28000.00
0005435302281	9937	Economy	28000.00
0005434823926	9937	Economy	28000.00
0005435735220	9937	Economy	28000.00
0005435150157	9937	Economy	28000.00
0005435374415	9937	Economy	28000.00
0005435374368	9937	Economy	28000.00
0005434824415	9937	Economy	28000.00
0005434825250	9937	Economy	28000.00
0005434824795	9937	Economy	28000.00
0005432400163	9937	Economy	28000.00
0005434824951	9937	Economy	28000.00
0005434824353	9937	Economy	28000.00
0005435374390	9937	Economy	28000.00
0005434824803	9937	Economy	28000.00
0005434824435	9937	Economy	28000.00
0005434825152	9937	Economy	28000.00
0005435374386	9937	Economy	28000.00
0005434824760	9937	Economy	28000.00
0005435374375	9937	Economy	28000.00
0005435374416	9937	Economy	28000.00
0005434824836	9937	Economy	28000.00
0005434824520	9937	Economy	28000.00
0005435735222	9937	Economy	28000.00
0005432823486	9937	Economy	28000.00
0005435374374	9937	Economy	28000.00
0005434824697	9937	Economy	28000.00
0005432823487	9937	Economy	28000.00
0005435374402	9937	Economy	28000.00
0005434824355	9937	Economy	28000.00
0005435314956	9937	Economy	28000.00
0005434824954	9937	Economy	28000.00
0005434824629	9937	Economy	28000.00
0005434824705	9937	Economy	28000.00
0005434558353	9937	Economy	28000.00
0005434824910	9937	Economy	28000.00
0005434824199	9937	Economy	28000.00
0005434828729	9937	Economy	28000.00
0005435374414	9937	Economy	28000.00
0005435314955	9937	Economy	28000.00
0005434824953	9937	Economy	28000.00
0005434824539	9937	Economy	28000.00
0005435374379	9937	Economy	28000.00
0005434824652	9937	Economy	28000.00
0005434831200	9937	Economy	28000.00
0005434825051	9937	Economy	28000.00
0005434824758	9937	Economy	28000.00
0005435302282	9937	Economy	28000.00
0005435374389	9937	Economy	28000.00
0005435150169	9937	Economy	28000.00
0005434824234	9937	Economy	28000.00
0005435374419	9937	Economy	28000.00
0005434825318	9937	Economy	28000.00
0005434824526	9937	Economy	28000.00
0005434824455	9937	Economy	28000.00
0005435374418	9937	Economy	28000.00
0005435302280	9937	Economy	28000.00
0005432203189	9937	Economy	28000.00
0005435374372	9937	Economy	28000.00
0005435735218	9937	Economy	28000.00
0005435374378	9937	Economy	30800.00
0005435374371	9937	Economy	30800.00
0005435374392	9937	Economy	30800.00
0005435374413	9937	Economy	30800.00
0005435179701	9937	Economy	30800.00
0005435374405	9937	Economy	28000.00
0005435374427	9937	Economy	28000.00
0005434831192	9937	Economy	28000.00
0005434664971	9937	Economy	28000.00
0005435374408	9937	Economy	28000.00
0005434824563	9937	Economy	28000.00
0005435374394	9937	Economy	28000.00
0005435302279	9937	Economy	28000.00
0005434824280	9937	Economy	28000.00
0005434664983	9937	Economy	28000.00
0005434824341	9937	Economy	28000.00
0005434825017	9937	Economy	28000.00
0005435314957	9937	Economy	28000.00
0005435150137	9937	Economy	28000.00
0005434825165	9937	Economy	28000.00
0005434824881	9937	Economy	28000.00
0005432396280	9937	Economy	28000.00
0005435661981	9937	Economy	28000.00
0005432203192	9937	Economy	28000.00
0005434664984	9937	Economy	28000.00
0005434824719	9937	Economy	28000.00
0005435374381	9937	Economy	28000.00
0005434825187	9937	Economy	28000.00
0005435374393	9937	Economy	28000.00
0005435374370	9937	Economy	28000.00
0005435374412	9937	Economy	28000.00
0005435374363	9937	Economy	28000.00
0005435374383	9937	Economy	28000.00
0005434824361	9937	Economy	28000.00
0005435150139	9937	Economy	28000.00
0005435374387	9937	Economy	28000.00
0005435374391	9937	Economy	28000.00
0005434824577	9937	Economy	28000.00
0005435374369	9937	Economy	28000.00
0005434831212	9937	Economy	28000.00
0005434824812	9937	Economy	28000.00
0005432823485	9937	Economy	28000.00
0005435374410	9937	Economy	28000.00
0005435374403	9937	Economy	28000.00
0005435374382	9937	Economy	28000.00
0005432203191	9937	Economy	28000.00
0005435299856	9937	Economy	28000.00
0005434824882	9937	Economy	28000.00
0005434825166	9937	Economy	28000.00
0005434824200	9937	Economy	28000.00
0005434824499	9937	Economy	28000.00
0005434824482	9937	Economy	28000.00
0005435374423	9937	Economy	28000.00
0005435374425	9937	Economy	28000.00
0005435374400	9937	Economy	28000.00
0005434825016	9937	Economy	28000.00
0005434558346	9937	Economy	28000.00
0005434558298	9937	Economy	28000.00
0005434558325	9937	Economy	28000.00
0005434824756	9937	Economy	28000.00
0005435386685	9937	Economy	28000.00
0005434824915	9937	Economy	28000.00
0005435374401	9937	Economy	28000.00
0005434558349	9937	Economy	28000.00
0005434824706	9937	Economy	28000.00
0005432400165	9937	Economy	28000.00
0005434828733	9937	Economy	28000.00
0005435374395	9937	Economy	28000.00
0005434824745	9937	Economy	28000.00
0005434824453	9937	Economy	28000.00
0005434824316	9937	Economy	28000.00
0005435735221	9937	Economy	28000.00
0005434824379	9937	Economy	28000.00
0005435179700	9937	Economy	28000.00
0005434824790	9937	Economy	28000.00
0005432203188	9937	Economy	28000.00
0005434824851	9937	Economy	28000.00
0005434824956	9937	Economy	28000.00
0005435150140	9937	Economy	28000.00
0005435082930	7023	Economy	8200.00
0005435082933	7023	Economy	7400.00
0005435082935	7023	Economy	7400.00
0005435082929	7023	Economy	7400.00
0005435082934	7023	Economy	7400.00
0005435082931	7023	Economy	7400.00
0005435082932	7023	Economy	7400.00
0005435082928	7023	Economy	7400.00
0005435790357	7023	Economy	7400.00
0005435082927	7023	Economy	7400.00
0005435790358	7023	Economy	7400.00
0005435082936	7023	Economy	7400.00
0005435790356	7023	Economy	7400.00
0005435082843	25970	Economy	8200.00
0005435082853	25970	Economy	7400.00
0005435082844	25970	Economy	7400.00
0005435790338	25970	Economy	7400.00
0005435082849	25970	Economy	7400.00
0005435082859	25970	Economy	7400.00
0005435082862	25970	Economy	7400.00
0005435790324	25970	Economy	7400.00
0005435790323	25970	Economy	7400.00
0005435790337	25970	Economy	7400.00
0005435082861	25970	Economy	7400.00
0005434214931	9530	Business	32800.00
0005434757150	9530	Business	32800.00
0005434215012	9530	Business	32800.00
0005434214863	9530	Business	32800.00
0005434214697	9530	Business	32800.00
0005434214995	9530	Business	32800.00
0005434214870	9530	Business	32800.00
0005434214679	9530	Business	32800.00
0005434214950	9530	Business	32800.00
0005434757152	9530	Business	32800.00
0005434757153	9530	Business	32800.00
0005434214752	9530	Business	32800.00
0005434214814	9530	Economy	10900.00
0005434757157	9530	Economy	10900.00
0005434757144	9530	Economy	10900.00
0005434757154	9530	Economy	10900.00
0005434215009	9530	Economy	10900.00
0005434757133	9530	Economy	10900.00
0005434214913	9530	Economy	10900.00
0005434214846	9530	Economy	10900.00
0005434214964	9530	Economy	10900.00
0005434214739	9530	Economy	10900.00
0005434757142	9530	Economy	12000.00
0005434214852	9530	Economy	12000.00
0005434757131	9530	Economy	12000.00
0005434214818	9530	Economy	12000.00
0005434215017	9530	Economy	12000.00
0005434757138	9530	Economy	10900.00
0005434757151	9530	Economy	10900.00
0005434214869	9530	Economy	10900.00
0005434757143	9530	Economy	10900.00
0005434214992	9530	Economy	10900.00
0005434214901	9530	Economy	10900.00
0005434214696	9530	Economy	10900.00
0005434214952	9530	Economy	10900.00
0005434214902	9530	Economy	10900.00
0005434214933	9530	Economy	10900.00
0005434757134	9530	Economy	10900.00
0005434214663	9530	Economy	10900.00
0005434214839	9530	Economy	10900.00
0005434215071	9530	Economy	10900.00
0005434215015	9530	Economy	10900.00
0005434757141	9530	Economy	10900.00
0005434757130	9530	Economy	10900.00
0005434757146	9530	Economy	10900.00
0005434214840	9530	Economy	10900.00
0005434214678	9530	Economy	10900.00
0005434214702	9530	Economy	10900.00
0005434757155	9530	Economy	10900.00
0005434757137	9530	Economy	10900.00
0005434214994	9530	Economy	10900.00
0005434757158	9530	Economy	10900.00
0005434214845	9530	Economy	10900.00
0005434214921	9530	Economy	10900.00
0005434214770	9530	Economy	10900.00
0005434757132	9530	Economy	10900.00
0005434214851	9530	Economy	10900.00
0005434214858	9530	Economy	10900.00
0005434214831	9530	Economy	10900.00
0005434214817	9530	Economy	10900.00
0005434215078	9530	Economy	10900.00
0005434757139	9530	Economy	10900.00
0005434757149	9530	Economy	10900.00
0005434214928	9530	Economy	10900.00
0005434214868	9530	Economy	10900.00
0005434757147	9530	Economy	10900.00
0005434757135	9530	Economy	10900.00
0005434757145	9530	Economy	10900.00
0005434757148	9530	Economy	10900.00
0005434215003	9530	Economy	10900.00
0005434214879	9530	Economy	10900.00
0005434215024	9530	Economy	10900.00
0005434214677	9530	Economy	10900.00
0005434214914	9530	Economy	10900.00
0005434214799	9530	Economy	10900.00
0005434215069	9530	Economy	10900.00
0005434214860	9530	Economy	10900.00
0005434214875	9530	Economy	10900.00
0005434215038	9530	Economy	10900.00
0005434214951	9530	Economy	10900.00
0005434215022	9530	Economy	10900.00
0005434214694	9530	Economy	10900.00
0005434215080	9530	Economy	10900.00
0005434215014	9530	Economy	10900.00
0005434215079	9530	Economy	10900.00
0005434214859	9530	Economy	10900.00
0005434214878	9530	Economy	10900.00
0005434214695	9530	Economy	10900.00
0005434214843	9530	Economy	10900.00
0005434214962	9530	Economy	10900.00
0005434757136	9530	Economy	10900.00
0005434757156	9530	Economy	10900.00
0005434757140	9530	Economy	10900.00
0005434214932	9530	Economy	10900.00
0005434215315	28637	Business	32800.00
0005434215268	28637	Business	32800.00
0005434215291	28637	Business	32800.00
0005434215293	28637	Business	32800.00
0005434215272	28637	Business	32800.00
0005434215277	28637	Business	32800.00
0005434215288	28637	Business	32800.00
0005434215280	28637	Business	32800.00
0005434756603	28637	Business	32800.00
0005434215301	28637	Business	32800.00
0005434215311	28637	Economy	10900.00
0005434756709	28637	Economy	10900.00
0005434756714	28637	Economy	10900.00
0005434215312	28637	Economy	10900.00
0005434215289	28637	Economy	10900.00
0005434756826	28637	Economy	10900.00
0005434215286	28637	Economy	10900.00
0005434215313	28637	Economy	10900.00
0005434215279	28637	Economy	10900.00
0005434756647	28637	Economy	12000.00
0005434756710	28637	Economy	12000.00
0005434215274	28637	Economy	12000.00
0005434215269	28637	Economy	12000.00
0005434215307	28637	Economy	12000.00
0005434215273	28637	Economy	10900.00
0005434756827	28637	Economy	10900.00
0005434215303	28637	Economy	10900.00
0005434756774	28637	Economy	10900.00
0005434756738	28637	Economy	10900.00
0005434756615	28637	Economy	10900.00
0005434756869	28637	Economy	10900.00
0005434756659	28637	Economy	10900.00
0005434756832	28637	Economy	10900.00
0005434756595	28637	Economy	10900.00
0005434756870	28637	Economy	10900.00
0005434215281	28637	Economy	10900.00
0005434756631	28637	Economy	10900.00
0005434756768	28637	Economy	10900.00
0005434215304	28637	Economy	10900.00
0005434215309	28637	Economy	10900.00
0005434215294	28637	Economy	10900.00
0005434215270	28637	Economy	10900.00
0005434215300	28637	Economy	10900.00
0005434215298	28637	Economy	10900.00
0005434215292	28637	Economy	10900.00
0005434756692	28637	Economy	10900.00
0005434215305	28637	Economy	10900.00
0005434756808	28637	Economy	10900.00
0005434215308	28637	Economy	10900.00
0005434215290	28637	Economy	10900.00
0005434215276	28637	Economy	10900.00
0005434756701	28637	Economy	10900.00
0005434215282	28637	Economy	10900.00
0005434756836	28637	Economy	10900.00
0005434215310	28637	Economy	10900.00
0005434756643	28637	Economy	10900.00
0005434215283	28637	Economy	10900.00
0005434756698	28637	Economy	10900.00
0005434215314	28637	Economy	10900.00
0005434756846	28637	Economy	10900.00
0005434756715	28637	Economy	10900.00
0005434756634	28637	Economy	10900.00
0005434215299	28637	Economy	10900.00
0005434756773	28637	Economy	10900.00
0005434215296	28637	Economy	10900.00
0005434756594	28637	Economy	10900.00
0005434756719	28637	Economy	10900.00
0005434215287	28637	Economy	10900.00
0005434756616	28637	Economy	10900.00
0005434756739	28637	Economy	10900.00
0005434215275	28637	Economy	10900.00
0005434215284	28637	Economy	10900.00
0005434215295	28637	Economy	10900.00
0005434756672	28637	Economy	10900.00
0005434756602	28637	Economy	10900.00
0005434756699	28637	Economy	10900.00
0005434215297	28637	Economy	10900.00
0005434756763	28637	Economy	10900.00
0005434215302	28637	Economy	10900.00
0005434215278	28637	Economy	10900.00
0005434756736	28637	Economy	10900.00
0005434756711	28637	Economy	10900.00
0005434756646	28637	Economy	10900.00
0005434215271	28637	Economy	10900.00
0005434215306	28637	Economy	10900.00
0005434756557	28637	Economy	10900.00
0005434215285	28637	Economy	10900.00
0005434760221	10816	Economy	9800.00
0005435100175	10816	Economy	8900.00
0005435100174	10816	Economy	8900.00
0005435100176	10816	Economy	8900.00
0005434760206	10816	Economy	8900.00
0005435100177	10816	Economy	8900.00
0005435100158	31812	Economy	9800.00
0005435100151	31812	Economy	8900.00
0005435100147	31812	Economy	8900.00
0005434760239	31812	Economy	8900.00
0005435100146	31812	Economy	8900.00
0005434760240	31812	Economy	8900.00
0005434639766	1961	Economy	20900.00
0005434639770	1961	Economy	20900.00
0005434639773	1961	Economy	20900.00
0005434639762	1961	Economy	20900.00
0005434639775	1961	Economy	19000.00
0005433202525	1961	Economy	19000.00
0005434639760	1961	Economy	19000.00
0005432290688	1961	Economy	19000.00
0005434639778	1961	Economy	19000.00
0005435948344	1961	Economy	19000.00
0005432290690	1961	Economy	19000.00
0005434639759	1961	Economy	19000.00
0005433202524	1961	Economy	19000.00
0005434639781	1961	Economy	19000.00
0005434639777	1961	Economy	19000.00
0005434639782	1961	Economy	19000.00
0005434639771	1961	Economy	19000.00
0005434639764	1961	Economy	19000.00
0005434639785	1961	Economy	19000.00
0005433202426	1961	Economy	19000.00
0005433202465	1961	Economy	19000.00
0005433202456	1961	Economy	19000.00
0005434639784	1961	Economy	19000.00
0005434639763	1961	Economy	19000.00
0005434639761	1961	Economy	19000.00
0005434639772	1961	Economy	19000.00
0005434639776	1961	Economy	19000.00
0005435948346	1961	Economy	19000.00
0005432290687	1961	Economy	19000.00
0005432290689	1961	Economy	19000.00
0005433202466	1961	Economy	19000.00
0005434639783	1961	Economy	19000.00
0005433202438	1961	Economy	19000.00
0005434639768	1961	Economy	19000.00
0005434639767	1961	Economy	19000.00
0005434639779	1961	Economy	19000.00
0005434639774	1961	Economy	19000.00
0005435948345	1961	Economy	19000.00
0005434639765	1961	Economy	19000.00
0005434639769	1961	Economy	19000.00
0005433202512	1961	Economy	19000.00
0005434639780	1961	Economy	19000.00
0005432290686	1961	Economy	19000.00
0005433202422	1961	Economy	19000.00
0005434639596	23299	Economy	20900.00
0005434639563	23299	Economy	20900.00
0005433202603	23299	Economy	20900.00
0005433202612	23299	Economy	20900.00
0005434639488	23299	Economy	19000.00
0005433202606	23299	Economy	19000.00
0005434639541	23299	Economy	19000.00
0005433202613	23299	Economy	19000.00
0005434639540	23299	Economy	19000.00
0005433202602	23299	Economy	19000.00
0005433202599	23299	Economy	19000.00
0005434639562	23299	Economy	19000.00
0005433202610	23299	Economy	19000.00
0005433202607	23299	Economy	19000.00
0005433202601	23299	Economy	19000.00
0005434639592	23299	Economy	19000.00
0005434639424	23299	Economy	19000.00
0005434639520	23299	Economy	19000.00
0005434639497	23299	Economy	19000.00
0005434639561	23299	Economy	19000.00
0005434639529	23299	Economy	19000.00
0005434639527	23299	Economy	19000.00
0005433202605	23299	Economy	19000.00
0005434639521	23299	Economy	19000.00
0005434639400	23299	Economy	19000.00
0005435948336	23299	Economy	19000.00
0005434639496	23299	Economy	19000.00
0005434639525	23299	Economy	19000.00
0005434639487	23299	Economy	19000.00
0005435948331	23299	Economy	19000.00
0005435948332	23299	Economy	19000.00
0005434639526	23299	Economy	19000.00
0005433202611	23299	Economy	19000.00
0005434639560	23299	Economy	19000.00
0005434639466	23299	Economy	19000.00
0005434639564	23299	Economy	19000.00
0005433202608	23299	Economy	19000.00
0005434639516	23299	Economy	19000.00
0005433202614	23299	Economy	19000.00
0005434639597	23299	Economy	19000.00
0005434639515	23299	Economy	19000.00
0005433202600	23299	Economy	19000.00
0005434639530	23299	Economy	19000.00
0005433202604	23299	Economy	19000.00
0005434639401	23299	Economy	19000.00
0005433202609	23299	Economy	19000.00
0005434601277	6038	Business	69700.00
0005434601291	6038	Business	69700.00
0005433533374	6038	Business	69700.00
0005435326920	6038	Business	69700.00
0005434601281	6038	Business	69700.00
0005434601287	6038	Business	69700.00
0005435326847	6038	Business	69700.00
0005435326841	6038	Economy	23200.00
0005435326813	6038	Economy	23200.00
0005435326861	6038	Economy	23200.00
0005434601290	6038	Economy	23200.00
0005435326868	6038	Economy	23200.00
0005434601280	6038	Economy	23200.00
0005434601268	6038	Economy	25600.00
0005434601278	6038	Economy	25600.00
0005433531360	6038	Economy	25600.00
0005433533373	6038	Economy	23200.00
0005435326824	6038	Economy	23200.00
0005434601286	6038	Economy	23200.00
0005435326812	6038	Economy	23200.00
0005435326887	6038	Economy	23200.00
0005432111330	6038	Economy	23200.00
0005434601269	6038	Economy	23200.00
0005433531362	6038	Economy	23200.00
0005434601292	6038	Economy	23200.00
0005434601270	6038	Economy	23200.00
0005434601271	6038	Economy	23200.00
0005434601283	6038	Economy	23200.00
0005435326888	6038	Economy	23200.00
0005434601279	6038	Economy	23200.00
0005433531361	6038	Economy	23200.00
0005435326903	6038	Economy	23200.00
0005433533377	6038	Economy	23200.00
0005434601274	6038	Economy	23200.00
0005435326907	6038	Economy	23200.00
0005434601289	6038	Economy	23200.00
0005434601284	6038	Economy	23200.00
0005434601267	6038	Economy	23200.00
0005434601288	6038	Economy	23200.00
0005435326864	6038	Economy	23200.00
0005434601285	6038	Economy	23200.00
0005435326814	6038	Economy	23200.00
0005433531359	6038	Economy	23200.00
0005433533376	6038	Economy	23200.00
0005435326875	6038	Economy	23200.00
0005433531358	6038	Economy	23200.00
0005432111331	6038	Economy	23200.00
0005435326867	6038	Economy	23200.00
0005434601276	6038	Economy	23200.00
0005434601266	6038	Economy	23200.00
0005434601265	6038	Economy	23200.00
0005434601273	6038	Economy	23200.00
0005434601275	6038	Economy	23200.00
0005434601272	6038	Economy	23200.00
0005435326840	6038	Economy	23200.00
0005432111329	6038	Economy	23200.00
0005435326902	6038	Economy	23200.00
0005434601282	6038	Economy	23200.00
0005435326876	6038	Economy	23200.00
0005433533375	6038	Economy	23200.00
0005434601122	18597	Business	69700.00
0005434601201	18597	Business	69700.00
0005434601054	18597	Business	69700.00
0005435326981	18597	Business	69700.00
0005433531324	18597	Business	69700.00
0005435326980	18597	Economy	23200.00
0005434601064	18597	Economy	23200.00
0005434601088	18597	Economy	23200.00
0005434601157	18597	Economy	23200.00
0005433531325	18597	Economy	23200.00
0005435326991	18597	Economy	25600.00
0005433527267	18597	Economy	25600.00
0005435326987	18597	Economy	25600.00
0005434601057	18597	Economy	23200.00
0005435326985	18597	Economy	23200.00
0005434600972	18597	Economy	23200.00
0005434601011	18597	Economy	23200.00
0005435326986	18597	Economy	23200.00
0005434601056	18597	Economy	23200.00
0005434601013	18597	Economy	23200.00
0005435326984	18597	Economy	23200.00
0005434600912	18597	Economy	23200.00
0005434601035	18597	Economy	23200.00
0005435326989	18597	Economy	23200.00
0005435326983	18597	Economy	23200.00
0005434601090	18597	Economy	23200.00
0005435326990	18597	Economy	23200.00
0005435326979	18597	Economy	23200.00
0005434601065	18597	Economy	23200.00
0005434601104	18597	Economy	23200.00
0005433531315	18597	Economy	23200.00
0005434601097	18597	Economy	23200.00
0005434601020	18597	Economy	23200.00
0005434601121	18597	Economy	23200.00
0005434601089	18597	Economy	23200.00
0005434601146	18597	Economy	23200.00
0005434601063	18597	Economy	23200.00
0005434601045	18597	Economy	23200.00
0005434601158	18597	Economy	23200.00
0005433531313	18597	Economy	23200.00
0005435326992	18597	Economy	23200.00
0005434601055	18597	Economy	23200.00
0005434601087	18597	Economy	23200.00
0005434600973	18597	Economy	23200.00
0005435326982	18597	Economy	23200.00
0005434601145	18597	Economy	23200.00
0005435326988	18597	Economy	23200.00
0005434552153	10597	Business	9100.00
0005434558426	10597	Business	9100.00
0005434552158	10597	Business	9100.00
0005434552117	10597	Business	9100.00
0005433181327	10597	Business	9100.00
0005434552118	10597	Business	9100.00
0005434552113	10597	Business	9100.00
0005434552141	10597	Business	9100.00
0005434552159	10597	Business	9100.00
0005434552121	10597	Business	9100.00
0005434552155	10597	Business	9100.00
0005434552126	10597	Economy	3000.00
0005434552156	10597	Economy	3000.00
0005434558425	10597	Economy	3000.00
0005433181190	10597	Economy	3000.00
0005434558422	10597	Economy	3000.00
0005433181240	10597	Economy	3000.00
0005434552150	10597	Economy	3000.00
0005434554099	10597	Economy	3000.00
0005434552137	10597	Economy	3000.00
0005433181338	10597	Economy	3300.00
0005433181392	10597	Economy	3300.00
0005434552145	10597	Economy	3300.00
0005434552110	10597	Economy	3300.00
0005433181393	10597	Economy	3300.00
0005434552123	10597	Economy	3000.00
0005433181339	10597	Economy	3000.00
0005434552131	10597	Economy	3000.00
0005434552147	10597	Economy	3000.00
0005433181366	10597	Economy	3000.00
0005434552112	10597	Economy	3000.00
0005434558421	10597	Economy	3000.00
0005434552115	10597	Economy	3000.00
0005433181296	10597	Economy	3000.00
0005434558423	10597	Economy	3000.00
0005434552146	10597	Economy	3000.00
0005434552136	10597	Economy	3000.00
0005433181254	10597	Economy	3000.00
0005434552107	10597	Economy	3000.00
0005434552128	10597	Economy	3000.00
0005433181159	10597	Economy	3000.00
0005433181313	10597	Economy	3000.00
0005434552108	10597	Economy	3000.00
0005434558419	10597	Economy	3000.00
0005434552161	10597	Economy	3000.00
0005434552151	10597	Economy	3000.00
0005434552134	10597	Economy	3000.00
0005434552111	10597	Economy	3000.00
0005433181192	10597	Economy	3000.00
0005434552132	10597	Economy	3000.00
0005434552135	10597	Economy	3000.00
0005433181309	10597	Economy	3000.00
0005434552139	10597	Economy	3000.00
0005434552149	10597	Economy	3000.00
0005434552124	10597	Economy	3000.00
0005433181314	10597	Economy	3000.00
0005434552142	10597	Economy	3000.00
0005434554100	10597	Economy	3000.00
0005434552127	10597	Economy	3000.00
0005434552122	10597	Economy	3000.00
0005434552129	10597	Economy	3000.00
0005434552105	10597	Economy	3000.00
0005434552133	10597	Economy	3000.00
0005434552109	10597	Economy	3000.00
0005434552116	10597	Economy	3000.00
0005434552125	10597	Economy	3000.00
0005434552140	10597	Economy	3000.00
0005434552114	10597	Economy	3000.00
0005434552138	10597	Economy	3000.00
0005434552130	10597	Economy	3000.00
0005434552152	10597	Economy	3000.00
0005433181302	10597	Economy	3000.00
0005434552148	10597	Economy	3000.00
0005433181328	10597	Economy	3000.00
0005434558427	10597	Economy	3000.00
0005434558420	10597	Economy	3000.00
0005434558424	10597	Economy	3000.00
0005434552120	10597	Economy	3000.00
0005434552143	10597	Economy	3000.00
0005434552157	10597	Economy	3000.00
0005434552160	10597	Economy	3000.00
0005434552144	10597	Economy	3000.00
0005434552119	10597	Economy	3000.00
0005434552154	10597	Economy	3000.00
0005434552106	10597	Economy	3000.00
0005433181367	10597	Economy	3000.00
0005433181253	10597	Economy	3000.00
0005433181546	27784	Business	9100.00
0005435314957	27784	Business	9100.00
0005433181537	27784	Business	9100.00
0005433181531	27784	Business	9100.00
0005433181532	27784	Business	9100.00
0005433181542	27784	Economy	3000.00
0005433181528	27784	Economy	3300.00
0005433181552	27784	Economy	3300.00
0005433181547	27784	Economy	3000.00
0005433181536	27784	Economy	3000.00
0005433181545	27784	Economy	3000.00
0005433181548	27784	Economy	3000.00
0005433181541	27784	Economy	3000.00
0005435314958	27784	Economy	3000.00
0005435314956	27784	Economy	3000.00
0005433181533	27784	Economy	3000.00
0005433181539	27784	Economy	3000.00
0005435314959	27784	Economy	3000.00
0005433181530	27784	Economy	3000.00
0005433181529	27784	Economy	3000.00
0005433181549	27784	Economy	3000.00
0005433181540	27784	Economy	3000.00
0005433181553	27784	Economy	3000.00
0005433181550	27784	Economy	3000.00
0005433181544	27784	Economy	3000.00
0005435314955	27784	Economy	3000.00
0005435314960	27784	Economy	3000.00
0005433181535	27784	Economy	3000.00
0005433181551	27784	Economy	3000.00
0005433181534	27784	Economy	3000.00
0005433181543	27784	Economy	3000.00
0005433181538	27784	Economy	3000.00
0005434551771	27781	Business	9100.00
0005434551741	27781	Business	9100.00
0005434551752	27781	Business	9100.00
0005434551932	27781	Business	9100.00
0005434551744	27781	Business	9100.00
0005434551933	27781	Business	9100.00
0005434551739	27781	Business	9100.00
0005434551826	27781	Economy	3000.00
0005434558350	27781	Economy	3000.00
0005434551585	27781	Economy	3000.00
0005434551778	27781	Economy	3000.00
0005434551767	27781	Economy	3000.00
0005434551747	27781	Economy	3000.00
0005434552011	27781	Economy	3000.00
0005434551663	27781	Economy	3300.00
0005434551757	27781	Economy	3300.00
0005434558345	27781	Economy	3300.00
0005434551909	27781	Economy	3300.00
0005434551782	27781	Economy	3300.00
0005434551691	27781	Economy	3000.00
0005434558340	27781	Economy	3000.00
0005434551513	27781	Economy	3000.00
0005434551921	27781	Economy	3000.00
0005434551825	27781	Economy	3000.00
0005434551510	27781	Economy	3000.00
0005434551855	27781	Economy	3000.00
0005434551803	27781	Economy	3000.00
0005434551692	27781	Economy	3000.00
0005434551604	27781	Economy	3000.00
0005434551824	27781	Economy	3000.00
0005434551664	27781	Economy	3000.00
0005434551643	27781	Economy	3000.00
0005434551651	27781	Economy	3000.00
0005434558343	27781	Economy	3000.00
0005434551750	27781	Economy	3000.00
0005434551746	27781	Economy	3000.00
0005434551701	27781	Economy	3000.00
0005434551804	27781	Economy	3000.00
0005434551908	27781	Economy	3000.00
0005434551603	27781	Economy	3000.00
0005434551792	27781	Economy	3000.00
0005434551772	27781	Economy	3000.00
0005434551330	27781	Economy	3000.00
0005434551854	27781	Economy	3000.00
0005434551702	27781	Economy	3000.00
0005434551914	27781	Economy	3000.00
0005434551715	27781	Economy	3000.00
0005434551670	27781	Economy	3000.00
0005434551773	27781	Economy	3000.00
0005434551780	27781	Economy	3000.00
0005434558322	27781	Economy	3000.00
0005434558338	27781	Economy	3000.00
0005434551668	27781	Economy	3000.00
0005434551669	27781	Economy	3000.00
0005434551568	27781	Economy	3000.00
0005434551502	27781	Economy	3000.00
0005434551751	27781	Economy	3000.00
0005434551694	27781	Economy	3000.00
0005434551779	27781	Economy	3000.00
0005434551569	27781	Economy	3000.00
0005434551686	27781	Economy	3000.00
0005434551863	27781	Economy	3000.00
0005434551753	27781	Economy	3000.00
0005434551665	27781	Economy	3000.00
0005433459293	6165	Economy	11700.00
0005435254484	6165	Economy	11700.00
0005433459295	6165	Economy	11700.00
0005435254492	6165	Economy	11700.00
0005433459294	6165	Economy	11700.00
0005433459292	6165	Economy	11700.00
0005433459291	6165	Economy	11700.00
0005435254491	6165	Economy	11700.00
0005433459296	6165	Economy	11700.00
0005433459256	19318	Economy	11700.00
0005433459263	19318	Economy	11700.00
0005433459254	19318	Economy	11700.00
0005435254515	19318	Economy	11700.00
0005433459257	19318	Economy	11700.00
0005433459253	19318	Economy	11700.00
0005435254517	19318	Economy	11700.00
0005433459255	19318	Economy	11700.00
0005435254516	19318	Economy	11700.00
0005435682851	6724	Business	51100.00
0005435438208	6724	Business	51100.00
0005435682818	6724	Business	51100.00
0005435631019	6724	Business	51100.00
0005435720152	6724	Business	51100.00
0005435682814	6724	Business	51100.00
0005432136258	6724	Business	51100.00
0005432136256	6724	Business	51100.00
0005435682854	6724	Business	51100.00
0005435682844	6724	Business	51100.00
0005435682845	6724	Business	51100.00
0005435682856	6724	Economy	17000.00
0005435682846	6724	Economy	17000.00
0005432136257	6724	Economy	17000.00
0005435682823	6724	Economy	17000.00
0005435682819	6724	Economy	17000.00
0005435682817	6724	Economy	17000.00
0005434828719	6724	Economy	17000.00
0005434828722	6724	Economy	17000.00
0005435682859	6724	Economy	18700.00
0005435682827	6724	Economy	18700.00
0005435682847	6724	Economy	18700.00
0005435682824	6724	Economy	18700.00
0005432533324	6724	Economy	18700.00
0005435682848	6724	Economy	17000.00
0005435682850	6724	Economy	17000.00
0005432533317	6724	Economy	17000.00
0005434828704	6724	Economy	17000.00
0005435438131	6724	Economy	17000.00
0005435682820	6724	Economy	17000.00
0005435682855	6724	Economy	17000.00
0005435682839	6724	Economy	17000.00
0005434828718	6724	Economy	17000.00
0005435682842	6724	Economy	17000.00
0005435682835	6724	Economy	17000.00
0005435682849	6724	Economy	17000.00
0005435438183	6724	Economy	17000.00
0005435682838	6724	Economy	17000.00
0005432533318	6724	Economy	17000.00
0005435682852	6724	Economy	17000.00
0005435682826	6724	Economy	17000.00
0005435438180	6724	Economy	17000.00
0005435438132	6724	Economy	17000.00
0005434828720	6724	Economy	17000.00
0005435682816	6724	Economy	17000.00
0005435682840	6724	Economy	17000.00
0005435720151	6724	Economy	17000.00
0005435631017	6724	Economy	17000.00
0005435682853	6724	Economy	17000.00
0005435682833	6724	Economy	17000.00
0005435217732	6724	Economy	17000.00
0005435682821	6724	Economy	17000.00
0005432136254	6724	Economy	17000.00
0005435220325	6724	Economy	17000.00
0005435682858	6724	Economy	17000.00
0005435719582	6724	Economy	17000.00
0005435682815	6724	Economy	17000.00
0005435682828	6724	Economy	17000.00
0005435438080	6724	Economy	17000.00
0005435438109	6724	Economy	17000.00
0005435438249	6724	Economy	17000.00
0005435682857	6724	Economy	17000.00
0005435719581	6724	Economy	17000.00
0005435438212	6724	Economy	17000.00
0005435631016	6724	Economy	17000.00
0005435682834	6724	Economy	17000.00
0005435438110	6724	Economy	17000.00
0005435682831	6724	Economy	17000.00
0005435217733	6724	Economy	17000.00
0005435682830	6724	Economy	17000.00
0005435438201	6724	Economy	17000.00
0005435682843	6724	Economy	17000.00
0005432533308	6724	Economy	17000.00
0005435682822	6724	Economy	17000.00
0005432533309	6724	Economy	17000.00
0005435221522	6724	Economy	17000.00
0005435720153	6724	Economy	17000.00
0005432136255	6724	Economy	17000.00
0005435682836	6724	Economy	17000.00
0005435661980	6724	Economy	17000.00
0005435438228	6724	Economy	17000.00
0005435682841	6724	Economy	17000.00
0005435682837	6724	Economy	17000.00
0005435682825	6724	Economy	17000.00
0005435682829	6724	Economy	17000.00
0005435631020	6724	Economy	17000.00
0005435438187	6724	Economy	17000.00
0005435631018	6724	Economy	17000.00
0005435682832	6724	Economy	17000.00
0005435630990	24581	Business	51100.00
0005435682650	24581	Business	51100.00
0005435682404	24581	Business	51100.00
0005435720829	24581	Business	51100.00
0005435682554	24581	Business	51100.00
0005435682465	24581	Business	51100.00
0005435682529	24581	Business	51100.00
0005435438342	24581	Business	51100.00
0005435438334	24581	Economy	17000.00
0005435682609	24581	Economy	17000.00
0005435682555	24581	Economy	17000.00
0005435682653	24581	Economy	17000.00
0005435682639	24581	Economy	17000.00
0005435682468	24581	Economy	17000.00
0005435438338	24581	Economy	17000.00
0005435438336	24581	Economy	17000.00
0005434828747	24581	Economy	18700.00
0005435682536	24581	Economy	18700.00
0005435682430	24581	Economy	18700.00
0005435720830	24581	Economy	18700.00
0005435438332	24581	Economy	17000.00
0005435438335	24581	Economy	17000.00
0005435720831	24581	Economy	17000.00
0005435682640	24581	Economy	17000.00
0005435438340	24581	Economy	17000.00
0005435682302	24581	Economy	17000.00
0005435682414	24581	Economy	17000.00
0005435630993	24581	Economy	17000.00
0005435438327	24581	Economy	17000.00
0005435682422	24581	Economy	17000.00
0005435720835	24581	Economy	17000.00
0005435682423	24581	Economy	17000.00
0005434828746	24581	Economy	17000.00
0005435682441	24581	Economy	17000.00
0005435682567	24581	Economy	17000.00
0005435438337	24581	Economy	17000.00
0005432305791	24581	Economy	17000.00
0005435682424	24581	Economy	17000.00
0005435438331	24581	Economy	17000.00
0005435438344	24581	Economy	17000.00
0005435682366	24581	Economy	17000.00
0005435682466	24581	Economy	17000.00
0005435661953	24581	Economy	17000.00
0005435682553	24581	Economy	17000.00
0005435682576	24581	Economy	17000.00
0005432533342	24581	Economy	17000.00
0005435438346	24581	Economy	17000.00
0005435682405	24581	Economy	17000.00
0005435661968	24581	Economy	17000.00
0005435438343	24581	Economy	17000.00
0005435682502	24581	Economy	17000.00
0005435682528	24581	Economy	17000.00
0005435682370	24581	Economy	17000.00
0005432533341	24581	Economy	17000.00
0005435661969	24581	Economy	17000.00
0005435682461	24581	Economy	17000.00
0005435682651	24581	Economy	17000.00
0005435682500	24581	Economy	17000.00
0005435438330	24581	Economy	17000.00
0005435438326	24581	Economy	17000.00
0005435438328	24581	Economy	17000.00
0005435682585	24581	Economy	17000.00
0005435682575	24581	Economy	17000.00
0005435438339	24581	Economy	17000.00
0005432305792	24581	Economy	17000.00
0005435682556	24581	Economy	17000.00
0005435682303	24581	Economy	17000.00
0005435682535	24581	Economy	17000.00
0005435438329	24581	Economy	17000.00
0005435682437	24581	Economy	17000.00
0005435682501	24581	Economy	17000.00
0005435438333	24581	Economy	17000.00
0005435438341	24581	Economy	17000.00
0005435438345	24581	Economy	17000.00
0005435127056	11515	Business	26400.00
0005435127058	11515	Business	26400.00
0005435127035	11515	Business	26400.00
0005435127030	11515	Business	26400.00
0005435127054	11515	Business	26400.00
0005435127022	11515	Business	26400.00
0005435106035	11515	Business	26400.00
0005435127043	11515	Business	26400.00
0005435127057	11515	Economy	8800.00
0005435127031	11515	Economy	8800.00
0005435127021	11515	Economy	8800.00
0005435106037	11515	Economy	8800.00
0005435127028	11515	Economy	8800.00
0005435127060	11515	Economy	9700.00
0005435127045	11515	Economy	9700.00
0005435127032	11515	Economy	9700.00
0005435127049	11515	Economy	9700.00
0005435106034	11515	Economy	8800.00
0005435106036	11515	Economy	8800.00
0005435127040	11515	Economy	8800.00
0005435558103	11515	Economy	8800.00
0005435127024	11515	Economy	8800.00
0005435127048	11515	Economy	8800.00
0005435127052	11515	Economy	8800.00
0005435127051	11515	Economy	8800.00
0005435127023	11515	Economy	8800.00
0005435127062	11515	Economy	8800.00
0005435127053	11515	Economy	8800.00
0005435127034	11515	Economy	8800.00
0005435127037	11515	Economy	8800.00
0005435127033	11515	Economy	8800.00
0005435127059	11515	Economy	8800.00
0005435127039	11515	Economy	8800.00
0005435127027	11515	Economy	8800.00
0005435127061	11515	Economy	8800.00
0005435127047	11515	Economy	8800.00
0005435127050	11515	Economy	8800.00
0005435127055	11515	Economy	8800.00
0005435127038	11515	Economy	8800.00
0005435127041	11515	Economy	8800.00
0005435127029	11515	Economy	8800.00
0005435127026	11515	Economy	8800.00
0005435127042	11515	Economy	8800.00
0005435127044	11515	Economy	8800.00
0005435127046	11515	Economy	8800.00
0005435127036	11515	Economy	8800.00
0005435127025	11515	Economy	8800.00
0005435558133	31879	Business	26400.00
0005435126580	31879	Business	26400.00
0005435126809	31879	Business	26400.00
0005435126640	31879	Business	26400.00
0005435126822	31879	Business	26400.00
0005435126712	31879	Business	26400.00
0005435126476	31879	Business	26400.00
0005435126653	31879	Business	26400.00
0005435558131	31879	Economy	8800.00
0005435098578	31879	Economy	8800.00
0005435126711	31879	Economy	8800.00
0005435126443	31879	Economy	8800.00
0005435126764	31879	Economy	9700.00
0005435106027	31879	Economy	9700.00
0005435126821	31879	Economy	9700.00
0005435106004	31879	Economy	8800.00
0005435126576	31879	Economy	8800.00
0005435126540	31879	Economy	8800.00
0005435126701	31879	Economy	8800.00
0005435126823	31879	Economy	8800.00
0005435126717	31879	Economy	8800.00
0005435126779	31879	Economy	8800.00
0005435126581	31879	Economy	8800.00
0005435126896	31879	Economy	8800.00
0005435126735	31879	Economy	8800.00
0005435126879	31879	Economy	8800.00
0005435106014	31879	Economy	8800.00
0005435126654	31879	Economy	8800.00
0005435126582	31879	Economy	8800.00
0005435126720	31879	Economy	8800.00
0005435126830	31879	Economy	8800.00
0005435126819	31879	Economy	8800.00
0005435126810	31879	Economy	8800.00
0005435106025	31879	Economy	8800.00
0005435126721	31879	Economy	8800.00
0005435126541	31879	Economy	8800.00
0005435126895	31879	Economy	8800.00
0005435126733	31879	Economy	8800.00
0005435126734	31879	Economy	8800.00
0005435126477	31879	Economy	8800.00
0005435558132	31879	Economy	8800.00
0005435106026	31879	Economy	8800.00
0005435126818	31879	Economy	8800.00
0005435126808	31879	Economy	8800.00
0005435106005	31879	Economy	8800.00
0005433398877	13513	Business	36600.00
0005433398872	13513	Business	36600.00
0005433398894	13513	Business	36600.00
0005433398897	13513	Business	36600.00
0005433398879	13513	Business	36600.00
0005435732443	13513	Business	36600.00
0005433398893	13513	Business	36600.00
0005433398880	13513	Business	36600.00
0005433398914	13513	Economy	12200.00
0005435732465	13513	Economy	12200.00
0005433398898	13513	Economy	12200.00
0005433398912	13513	Economy	12200.00
0005433398902	13513	Economy	13400.00
0005435732440	13513	Economy	13400.00
0005433398916	13513	Economy	13400.00
0005435732459	13513	Economy	12200.00
0005435732445	13513	Economy	12200.00
0005433398907	13513	Economy	12200.00
0005433398869	13513	Economy	12200.00
0005433398885	13513	Economy	12200.00
0005433398896	13513	Economy	12200.00
0005433398878	13513	Economy	12200.00
0005433398881	13513	Economy	12200.00
0005433398901	13513	Economy	12200.00
0005435732404	13513	Economy	12200.00
0005433398883	13513	Economy	12200.00
0005433398892	13513	Economy	12200.00
0005433398882	13513	Economy	12200.00
0005433398905	13513	Economy	12200.00
0005435732406	13513	Economy	12200.00
0005433398889	13513	Economy	12200.00
0005433398910	13513	Economy	12200.00
0005433398888	13513	Economy	12200.00
0005433398915	13513	Economy	12200.00
0005435732405	13513	Economy	12200.00
0005433398887	13513	Economy	12200.00
0005433398886	13513	Economy	12200.00
0005435732444	13513	Economy	12200.00
0005433398903	13513	Economy	12200.00
0005433398873	13513	Economy	12200.00
0005435732418	13513	Economy	12200.00
0005433398911	13513	Economy	12200.00
0005433398909	13513	Economy	12200.00
0005435732409	13513	Economy	12200.00
0005435732508	13513	Economy	12200.00
0005435732497	13513	Economy	12200.00
0005435732464	13513	Economy	12200.00
0005435732435	13513	Economy	12200.00
0005435732498	13513	Economy	12200.00
0005433398891	13513	Economy	12200.00
0005433398874	13513	Economy	12200.00
0005433398917	13513	Economy	12200.00
0005433398884	13513	Economy	12200.00
0005433398870	13513	Economy	12200.00
0005433398890	13513	Economy	12200.00
0005433398904	13513	Economy	12200.00
0005435732458	13513	Economy	12200.00
0005433398876	13513	Economy	12200.00
0005433398871	13513	Economy	12200.00
0005435732395	13513	Economy	12200.00
0005435732460	13513	Economy	12200.00
0005435732463	13513	Economy	12200.00
0005433398875	13513	Economy	12200.00
0005433398908	13513	Economy	12200.00
0005433398895	13513	Economy	12200.00
0005433398918	13513	Economy	12200.00
0005433398913	13513	Economy	12200.00
0005433398900	13513	Economy	12200.00
0005433398906	13513	Economy	12200.00
0005433398899	13513	Economy	12200.00
0005433398516	19367	Business	36600.00
0005433398307	19367	Business	36600.00
0005435732550	19367	Business	36600.00
0005433398498	19367	Business	36600.00
0005433398656	19367	Business	36600.00
0005433398535	19367	Business	36600.00
0005432297324	19367	Business	36600.00
0005432297322	19367	Business	36600.00
0005433398655	19367	Economy	12200.00
0005433398330	19367	Economy	12200.00
0005433398551	19367	Economy	12200.00
0005433398588	19367	Economy	12200.00
0005433398517	19367	Economy	12200.00
0005433398340	19367	Economy	12200.00
0005433398514	19367	Economy	12200.00
0005433398570	19367	Economy	12200.00
0005433398491	19367	Economy	12200.00
0005433398492	19367	Economy	12200.00
0005433398564	19367	Economy	13400.00
0005435732546	19367	Economy	13400.00
0005433398447	19367	Economy	13400.00
0005433398192	19367	Economy	12200.00
0005433398500	19367	Economy	12200.00
0005433398351	19367	Economy	12200.00
0005433398550	19367	Economy	12200.00
0005433398490	19367	Economy	12200.00
0005435732549	19367	Economy	12200.00
0005433398654	19367	Economy	12200.00
0005433398322	19367	Economy	12200.00
0005433398549	19367	Economy	12200.00
0005433398525	19367	Economy	12200.00
0005433398474	19367	Economy	12200.00
0005433398488	19367	Economy	12200.00
0005433398493	19367	Economy	12200.00
0005435732548	19367	Economy	12200.00
0005433398472	19367	Economy	12200.00
0005432297325	19367	Economy	12200.00
0005433398049	19367	Economy	12200.00
0005433398515	19367	Economy	12200.00
0005433398216	19367	Economy	12200.00
0005433398341	19367	Economy	12200.00
0005433398526	19367	Economy	12200.00
0005433398647	19367	Economy	12200.00
0005433398305	19367	Economy	12200.00
0005435732551	19367	Economy	12200.00
0005433398543	19367	Economy	12200.00
0005435732552	19367	Economy	12200.00
0005432297323	19367	Economy	12200.00
0005433398502	19367	Economy	12200.00
0005433398568	19367	Economy	12200.00
0005435732547	19367	Economy	12200.00
0005433398455	19367	Economy	12200.00
0005433398001	19367	Economy	12200.00
0005433398000	19367	Economy	12200.00
0005433398582	19367	Economy	12200.00
0005433398589	19367	Economy	12200.00
0005433398501	19367	Economy	12200.00
0005433398347	19367	Economy	12200.00
0005433398179	19367	Economy	12200.00
0005433398600	19367	Economy	12200.00
0005433398599	19367	Economy	12200.00
0005433398439	19367	Economy	12200.00
0005433398489	19367	Economy	12200.00
0005433398534	19367	Economy	12200.00
0005432297326	19367	Economy	12200.00
0005433398377	19367	Economy	12200.00
0005435069574	13152	Business	11300.00
0005435069445	13152	Business	11300.00
0005435069455	13152	Business	11300.00
0005435069471	13152	Business	11300.00
0005435925534	13152	Business	11300.00
0005435069465	13152	Business	11300.00
0005435069439	13152	Business	11300.00
0005435069428	13152	Business	11300.00
0005435069423	13152	Business	11300.00
0005435925536	13152	Economy	3800.00
0005435069332	13152	Economy	3800.00
0005435069607	13152	Economy	3800.00
0005435069580	13152	Economy	3800.00
0005435069579	13152	Economy	3800.00
0005435069406	13152	Economy	3800.00
0005435069256	13152	Economy	4100.00
0005435069635	13152	Economy	4100.00
0005435069610	13152	Economy	4100.00
0005435925531	13152	Economy	4100.00
0005435069507	13152	Economy	3800.00
0005435069630	13152	Economy	3800.00
0005435925528	13152	Economy	3800.00
0005435069612	13152	Economy	3800.00
0005435069446	13152	Economy	3800.00
0005435925533	13152	Economy	3800.00
0005435069333	13152	Economy	3800.00
0005435069512	13152	Economy	3800.00
0005435069407	13152	Economy	3800.00
0005435069654	13152	Economy	3800.00
0005435069582	13152	Economy	3800.00
0005435069711	13152	Economy	3800.00
0005435069273	13152	Economy	3800.00
0005435069464	13152	Economy	3800.00
0005435069463	13152	Economy	3800.00
0005435069614	13152	Economy	3800.00
0005435069801	13152	Economy	3800.00
0005435069497	13152	Economy	3800.00
0005435925530	13152	Economy	3800.00
0005435069451	13152	Economy	3800.00
0005435069203	13152	Economy	3800.00
0005435069510	13152	Economy	3800.00
0005435925529	13152	Economy	3800.00
0005435069470	13152	Economy	3800.00
0005435069316	13152	Economy	3800.00
0005435069418	13152	Economy	3800.00
0005435069603	13152	Economy	3800.00
0005435069673	13152	Economy	3800.00
0005435069604	13152	Economy	3800.00
0005435069424	13152	Economy	3800.00
0005435069509	13152	Economy	3800.00
0005435069583	13152	Economy	3800.00
0005435069437	13152	Economy	3800.00
0005435925532	13152	Economy	3800.00
0005435069686	13152	Economy	3800.00
0005435069324	13152	Economy	3800.00
0005435069634	13152	Economy	3800.00
0005435069511	13152	Economy	3800.00
0005435069482	13152	Economy	3800.00
0005435069276	13152	Economy	3800.00
0005435069355	13152	Economy	3800.00
0005435069397	13152	Economy	3800.00
0005435069613	13152	Economy	3800.00
0005435069315	13152	Economy	3800.00
0005435069653	13152	Economy	3800.00
0005435069204	13152	Economy	3800.00
0005435069257	13152	Economy	3800.00
0005435925535	13152	Economy	3800.00
0005435069908	15488	Business	11300.00
0005435069957	15488	Business	11300.00
0005435069954	15488	Business	11300.00
0005435069923	15488	Business	11300.00
0005435069929	15488	Business	11300.00
0005435925406	15488	Business	11300.00
0005435069955	15488	Business	11300.00
0005435069934	15488	Economy	3800.00
0005435069932	15488	Economy	3800.00
0005435069946	15488	Economy	3800.00
0005435069922	15488	Economy	3800.00
0005435069950	15488	Economy	3800.00
0005435069914	15488	Economy	4100.00
0005435069906	15488	Economy	4100.00
0005435069944	15488	Economy	4100.00
0005435069943	15488	Economy	4100.00
0005435069952	15488	Economy	4100.00
0005435925374	15488	Economy	3800.00
0005435069933	15488	Economy	3800.00
0005435069938	15488	Economy	3800.00
0005435069937	15488	Economy	3800.00
0005435069917	15488	Economy	3800.00
0005435925356	15488	Economy	3800.00
0005435069953	15488	Economy	3800.00
0005435069907	15488	Economy	3800.00
0005435069948	15488	Economy	3800.00
0005435069912	15488	Economy	3800.00
0005435069910	15488	Economy	3800.00
0005435069939	15488	Economy	3800.00
0005435069926	15488	Economy	3800.00
0005435069927	15488	Economy	3800.00
0005435069911	15488	Economy	3800.00
0005435069925	15488	Economy	3800.00
0005435069945	15488	Economy	3800.00
0005435069951	15488	Economy	3800.00
0005435069931	15488	Economy	3800.00
0005435069915	15488	Economy	3800.00
0005435925363	15488	Economy	3800.00
0005435069921	15488	Economy	3800.00
0005435069956	15488	Economy	3800.00
0005435925390	15488	Economy	3800.00
0005435069928	15488	Economy	3800.00
0005435925391	15488	Economy	3800.00
0005435925394	15488	Economy	3800.00
0005435925392	15488	Economy	3800.00
0005435069919	15488	Economy	3800.00
0005435069940	15488	Economy	3800.00
0005435069930	15488	Economy	3800.00
0005435925373	15488	Economy	3800.00
0005435069947	15488	Economy	3800.00
0005435069916	15488	Economy	3800.00
0005435069918	15488	Economy	3800.00
0005435069958	15488	Economy	3800.00
0005435069941	15488	Economy	3800.00
0005435069936	15488	Economy	3800.00
0005435069920	15488	Economy	3800.00
0005435925355	15488	Economy	3800.00
0005435925411	15488	Economy	3800.00
0005435069909	15488	Economy	3800.00
0005435925409	15488	Economy	3800.00
0005435069942	15488	Economy	3800.00
0005435069935	15488	Economy	3800.00
0005435925405	15488	Economy	3800.00
0005435069924	15488	Economy	3800.00
0005435069913	15488	Economy	3800.00
0005435069949	15488	Economy	3800.00
0005435925395	15488	Economy	3800.00
0005433407596	23183	Economy	27100.00
0005435808400	23183	Economy	27100.00
0005435808403	23183	Economy	24700.00
0005435808394	23183	Economy	24700.00
0005433407588	23183	Economy	24700.00
0005435808396	23183	Economy	24700.00
0005435808386	23183	Economy	24700.00
0005433407590	23183	Economy	24700.00
0005435808404	23183	Economy	24700.00
0005433407598	23183	Economy	24700.00
0005435808382	23183	Economy	24700.00
0005435808401	23183	Economy	24700.00
0005435808399	23183	Economy	24700.00
0005433407566	23183	Economy	24700.00
0005435808387	23183	Economy	24700.00
0005433407600	23183	Economy	24700.00
0005435808391	23183	Economy	24700.00
0005435808397	23183	Economy	24700.00
0005435808390	23183	Economy	24700.00
0005433407587	23183	Economy	24700.00
0005433407582	23183	Economy	24700.00
0005435808389	23183	Economy	24700.00
0005433407571	23183	Economy	24700.00
0005435808393	23183	Economy	24700.00
0005435808395	23183	Economy	24700.00
0005433407604	23183	Economy	24700.00
0005435808384	23183	Economy	24700.00
0005433407595	23183	Economy	24700.00
0005435808388	23183	Economy	24700.00
0005433407608	23183	Economy	24700.00
0005435808383	23183	Economy	24700.00
0005433407591	23183	Economy	24700.00
0005435808402	23183	Economy	24700.00
0005435808398	23183	Economy	24700.00
0005433407589	23183	Economy	24700.00
0005435808392	23183	Economy	24700.00
0005433407597	23183	Economy	24700.00
0005433407583	23183	Economy	24700.00
0005435808385	23183	Economy	24700.00
0005433407603	23183	Economy	24700.00
0005434756737	10719	Business	61300.00
0005434215326	10719	Business	61300.00
0005434756474	10719	Business	61300.00
0005434756611	10719	Business	61300.00
0005434756805	10719	Business	61300.00
0005434756785	10719	Business	61300.00
0005434756476	10719	Business	61300.00
0005434756542	10719	Business	61300.00
0005434215335	10719	Business	61300.00
0005434756728	10719	Business	61300.00
0005434215329	10719	Business	61300.00
0005434215334	10719	Business	61300.00
0005434756783	10719	Economy	20400.00
0005434215349	10719	Economy	20400.00
0005434756685	10719	Economy	20400.00
0005434215352	10719	Economy	20400.00
0005434215362	10719	Economy	20400.00
0005434215346	10719	Economy	20400.00
0005434756770	10719	Economy	20400.00
0005434756814	10719	Economy	20400.00
0005434215347	10719	Economy	22500.00
0005434215322	10719	Economy	22500.00
0005434756812	10719	Economy	22500.00
0005434756744	10719	Economy	22500.00
0005434215325	10719	Economy	22500.00
0005434756815	10719	Economy	20400.00
0005434215316	10719	Economy	20400.00
0005434756782	10719	Economy	20400.00
0005434756648	10719	Economy	20400.00
0005434215330	10719	Economy	20400.00
0005434215333	10719	Economy	20400.00
0005434756769	10719	Economy	20400.00
0005434215350	10719	Economy	20400.00
0005434215338	10719	Economy	20400.00
0005434215359	10719	Economy	20400.00
0005434756686	10719	Economy	20400.00
0005434215351	10719	Economy	20400.00
0005434215361	10719	Economy	20400.00
0005434215332	10719	Economy	20400.00
0005434215327	10719	Economy	20400.00
0005434215317	10719	Economy	20400.00
0005434215319	10719	Economy	20400.00
0005434756784	10719	Economy	20400.00
0005434756828	10719	Economy	20400.00
0005434756607	10719	Economy	20400.00
0005434215324	10719	Economy	20400.00
0005434756633	10719	Economy	20400.00
0005434215354	10719	Economy	20400.00
0005434215331	10719	Economy	20400.00
0005434215323	10719	Economy	20400.00
0005434215348	10719	Economy	20400.00
0005434215357	10719	Economy	20400.00
0005434756612	10719	Economy	20400.00
0005434756813	10719	Economy	20400.00
0005434756531	10719	Economy	20400.00
0005434756786	10719	Economy	20400.00
0005434756459	10719	Economy	20400.00
0005434756528	10719	Economy	20400.00
0005434215360	10719	Economy	20400.00
0005434756532	10719	Economy	20400.00
0005434215341	10719	Economy	20400.00
0005434756729	10719	Economy	20400.00
0005434756654	10719	Economy	20400.00
0005434215355	10719	Economy	20400.00
0005434215344	10719	Economy	20400.00
0005434215337	10719	Economy	20400.00
0005434215328	10719	Economy	20400.00
0005434756548	10719	Economy	20400.00
0005434215340	10719	Economy	20400.00
0005434756678	10719	Economy	20400.00
0005434215321	10719	Economy	20400.00
0005434215342	10719	Economy	20400.00
0005434756743	10719	Economy	20400.00
0005434215339	10719	Economy	20400.00
0005434215358	10719	Economy	20400.00
0005434215353	10719	Economy	20400.00
0005434756880	10719	Economy	20400.00
0005434215320	10719	Economy	20400.00
0005434756804	10719	Economy	20400.00
0005434215318	10719	Economy	20400.00
0005434215336	10719	Economy	20400.00
0005434215345	10719	Economy	20400.00
0005434756761	10719	Economy	20400.00
0005434215343	10719	Economy	20400.00
0005434756677	10719	Economy	20400.00
0005434215356	10719	Economy	20400.00
0005434757107	28699	Business	61300.00
0005434757126	28699	Business	61300.00
0005434214735	28699	Business	61300.00
0005434757114	28699	Business	61300.00
0005434214738	28699	Business	61300.00
0005434214874	28699	Business	61300.00
0005434214991	28699	Business	61300.00
0005434214728	28699	Business	61300.00
0005434214662	28699	Business	61300.00
0005434214784	28699	Business	61300.00
0005434214774	28699	Economy	20400.00
0005434757124	28699	Economy	20400.00
0005434757122	28699	Economy	20400.00
0005434214953	28699	Economy	20400.00
0005434214815	28699	Economy	20400.00
0005434214927	28699	Economy	20400.00
0005434214873	28699	Economy	20400.00
0005434757115	28699	Economy	20400.00
0005434757116	28699	Economy	20400.00
0005434215044	28699	Economy	20400.00
0005434214906	28699	Economy	22500.00
0005434214771	28699	Economy	22500.00
0005434214658	28699	Economy	22500.00
0005434214708	28699	Economy	22500.00
0005434214849	28699	Economy	22500.00
0005434757117	28699	Economy	20400.00
0005434757103	28699	Economy	20400.00
0005434757118	28699	Economy	20400.00
0005434757125	28699	Economy	20400.00
0005434214954	28699	Economy	20400.00
0005434757113	28699	Economy	20400.00
0005434757112	28699	Economy	20400.00
0005434214824	28699	Economy	20400.00
0005434214776	28699	Economy	20400.00
0005434214978	28699	Economy	20400.00
0005434214905	28699	Economy	20400.00
0005434214871	28699	Economy	20400.00
0005434214805	28699	Economy	20400.00
0005434214876	28699	Economy	20400.00
0005434215035	28699	Economy	20400.00
0005434757108	28699	Economy	20400.00
0005434214746	28699	Economy	20400.00
0005434757123	28699	Economy	20400.00
0005434757127	28699	Economy	20400.00
0005434214657	28699	Economy	20400.00
0005434214727	28699	Economy	20400.00
0005434214850	28699	Economy	20400.00
0005434214725	28699	Economy	20400.00
0005434214707	28699	Economy	20400.00
0005434214690	28699	Economy	20400.00
0005434757106	28699	Economy	20400.00
0005434214920	28699	Economy	20400.00
0005434757119	28699	Economy	20400.00
0005434757120	28699	Economy	20400.00
0005434757101	28699	Economy	20400.00
0005434214979	28699	Economy	20400.00
0005434214701	28699	Economy	20400.00
0005434214803	28699	Economy	20400.00
0005434214919	28699	Economy	20400.00
0005434214794	28699	Economy	20400.00
0005434214773	28699	Economy	20400.00
0005434214872	28699	Economy	20400.00
0005434215106	28699	Economy	20400.00
0005434757109	28699	Economy	20400.00
0005434757102	28699	Economy	20400.00
0005434757100	28699	Economy	20400.00
0005434757105	28699	Economy	20400.00
0005434214762	28699	Economy	20400.00
0005434214955	28699	Economy	20400.00
0005434757110	28699	Economy	20400.00
0005434214785	28699	Economy	20400.00
0005434214689	28699	Economy	20400.00
0005434214892	28699	Economy	20400.00
0005434214957	28699	Economy	20400.00
0005434214857	28699	Economy	20400.00
0005434214907	28699	Economy	20400.00
0005434214786	28699	Economy	20400.00
0005434757121	28699	Economy	20400.00
0005434214881	28699	Economy	20400.00
0005434757128	28699	Economy	20400.00
0005434214889	28699	Economy	20400.00
0005434214990	28699	Economy	20400.00
0005434214620	28699	Economy	20400.00
0005434757104	28699	Economy	20400.00
0005434214804	28699	Economy	20400.00
0005434214688	28699	Economy	20400.00
0005434214893	28699	Economy	20400.00
0005434214821	28699	Economy	20400.00
0005434757111	28699	Economy	20400.00
0005434214989	28699	Economy	20400.00
0005434214842	28699	Economy	20400.00
0005434757129	28699	Economy	20400.00
0005434214956	28699	Economy	20400.00
0005434214772	28699	Economy	20400.00
0005434214795	28699	Economy	20400.00
0005435040902	5485	Business	29500.00
0005435007418	5485	Business	29500.00
0005434229583	5485	Business	29500.00
0005432125579	5485	Business	29500.00
0005434229545	5485	Business	29500.00
0005434229671	5485	Business	29500.00
0005435040860	5485	Business	29500.00
0005435040906	5485	Business	29500.00
0005435040889	5485	Business	29500.00
0005435040878	5485	Business	29500.00
0005435043296	5485	Business	29500.00
0005432125582	5485	Business	29500.00
0005434229578	5485	Economy	9800.00
0005432125578	5485	Economy	9800.00
0005435042890	5485	Economy	9800.00
0005435007434	5485	Economy	9800.00
0005435007432	5485	Economy	9800.00
0005435007429	5485	Economy	9800.00
0005434229612	5485	Economy	9800.00
0005435040900	5485	Economy	9800.00
0005435043295	5485	Economy	9800.00
0005434229577	5485	Economy	9800.00
0005435007422	5485	Economy	9800.00
0005435007436	5485	Economy	9800.00
0005434229547	5485	Economy	9800.00
0005435040882	5485	Economy	9800.00
0005435042891	5485	Economy	9800.00
0005435040872	5485	Economy	9800.00
0005435007438	5485	Economy	9800.00
0005435040884	5485	Economy	9800.00
0005435040866	5485	Economy	9800.00
0005435040881	5485	Economy	9800.00
0005435040874	5485	Economy	9800.00
0005435040855	5485	Economy	9800.00
0005435040909	5485	Economy	9800.00
0005435040898	5485	Economy	9800.00
0005435040858	5485	Economy	9800.00
0005435040854	5485	Economy	9800.00
0005435040871	5485	Economy	9800.00
0005435040911	5485	Economy	9800.00
0005434229595	5485	Economy	9800.00
0005435040913	5485	Economy	9800.00
0005435040851	5485	Economy	9800.00
0005434229485	5485	Economy	9800.00
0005435040891	5485	Economy	9800.00
0005435007440	5485	Economy	9800.00
0005435040886	5485	Economy	9800.00
0005434229556	5485	Economy	9800.00
0005435007439	5485	Economy	9800.00
0005434229564	5485	Economy	9800.00
0005434229511	5485	Economy	9800.00
0005435040890	5485	Economy	10800.00
0005435007421	5485	Economy	10800.00
0005434229546	5485	Economy	10800.00
0005432125580	5485	Economy	10800.00
0005434229582	5485	Economy	10800.00
0005435040865	5485	Economy	10800.00
0005435040861	5485	Economy	9800.00
0005435007428	5485	Economy	9800.00
0005434229594	5485	Economy	9800.00
0005435040917	5485	Economy	9800.00
0005435040868	5485	Economy	9800.00
0005434229502	5485	Economy	9800.00
0005434229542	5485	Economy	9800.00
0005434229531	5485	Economy	9800.00
0005435040896	5485	Economy	9800.00
0005435040918	5485	Economy	9800.00
0005435007417	5485	Economy	9800.00
0005435007423	5485	Economy	9800.00
0005435007435	5485	Economy	9800.00
0005435040914	5485	Economy	9800.00
0005435040853	5485	Economy	9800.00
0005435040876	5485	Economy	9800.00
0005435040873	5485	Economy	9800.00
0005434229674	5485	Economy	9800.00
0005435040863	5485	Economy	9800.00
0005435040870	5485	Economy	9800.00
0005435007431	5485	Economy	9800.00
0005435040915	5485	Economy	9800.00
0005435040856	5485	Economy	9800.00
0005435040880	5485	Economy	9800.00
0005434229513	5485	Economy	9800.00
0005435007420	5485	Economy	9800.00
0005435040892	5485	Economy	9800.00
0005435007426	5485	Economy	9800.00
0005435040857	5485	Economy	9800.00
0005435040903	5485	Economy	9800.00
0005435040875	5485	Economy	9800.00
0005435040908	5485	Economy	9800.00
0005435040895	5485	Economy	9800.00
0005435007430	5485	Economy	9800.00
0005435007437	5485	Economy	9800.00
0005435007424	5485	Economy	9800.00
0005435007433	5485	Economy	9800.00
0005435040904	5485	Economy	9800.00
0005435007425	5485	Economy	9800.00
0005435007441	5485	Economy	9800.00
0005435040862	5485	Economy	9800.00
0005435040879	5485	Economy	9800.00
0005434229523	5485	Economy	9800.00
0005435040887	5485	Economy	9800.00
0005435040899	5485	Economy	9800.00
0005435040864	5485	Economy	9800.00
0005435040852	5485	Economy	9800.00
0005435040901	5485	Economy	9800.00
0005432125581	5485	Economy	9800.00
0005432125577	5485	Economy	9800.00
0005435040912	5485	Economy	9800.00
0005435040869	5485	Economy	9800.00
0005435040885	5485	Economy	9800.00
0005434229530	5485	Economy	9800.00
0005435040897	5485	Economy	9800.00
0005435040883	5485	Economy	9800.00
0005435040916	5485	Economy	9800.00
0005434229534	5485	Economy	9800.00
0005435040894	5485	Economy	9800.00
0005434229548	5485	Economy	9800.00
0005435040910	5485	Economy	9800.00
0005435040893	5485	Economy	9800.00
0005435040877	5485	Economy	9800.00
0005435007427	5485	Economy	9800.00
0005435040905	5485	Economy	9800.00
0005434229639	5485	Economy	9800.00
0005435007419	5485	Economy	9800.00
0005435040859	5485	Economy	9800.00
0005435040907	5485	Economy	9800.00
0005435040888	5485	Economy	9800.00
0005435040867	5485	Economy	9800.00
0005432304467	12964	Business	29500.00
0005435040532	12964	Business	29500.00
0005435007312	12964	Business	29500.00
0005434229755	12964	Business	29500.00
0005435040207	12964	Business	29500.00
0005435040455	12964	Business	29500.00
0005435040461	12964	Business	29500.00
0005435040497	12964	Business	29500.00
0005435040268	12964	Business	29500.00
0005435007309	12964	Business	29500.00
0005435007271	12964	Business	29500.00
0005434229757	12964	Business	29500.00
0005435040222	12964	Economy	9800.00
0005435040422	12964	Economy	9800.00
0005432304465	12964	Economy	9800.00
0005435040580	12964	Economy	9800.00
0005434229774	12964	Economy	9800.00
0005435040349	12964	Economy	9800.00
0005434229768	12964	Economy	9800.00
0005435040578	12964	Economy	9800.00
0005434229760	12964	Economy	9800.00
0005435007242	12964	Economy	9800.00
0005435040221	12964	Economy	9800.00
0005434229762	12964	Economy	9800.00
0005435040442	12964	Economy	9800.00
0005435007269	12964	Economy	9800.00
0005435007178	12964	Economy	9800.00
0005435040436	12964	Economy	9800.00
0005435007355	12964	Economy	9800.00
0005435040323	12964	Economy	9800.00
0005435040060	12964	Economy	9800.00
0005435040208	12964	Economy	9800.00
0005435039798	12964	Economy	9800.00
0005435040454	12964	Economy	9800.00
0005434229756	12964	Economy	9800.00
0005435007173	12964	Economy	9800.00
0005435040246	12964	Economy	9800.00
0005435040482	12964	Economy	9800.00
0005435040258	12964	Economy	9800.00
0005435040407	12964	Economy	9800.00
0005432304464	12964	Economy	9800.00
0005435007311	12964	Economy	9800.00
0005435007251	12964	Economy	9800.00
0005435040373	12964	Economy	9800.00
0005434229773	12964	Economy	9800.00
0005435040453	12964	Economy	9800.00
0005435007281	12964	Economy	10800.00
0005435040406	12964	Economy	10800.00
0005432304466	12964	Economy	10800.00
0005435007280	12964	Economy	10800.00
0005435040067	12964	Economy	10800.00
0005435007211	12964	Economy	10800.00
0005434229767	12964	Economy	9800.00
0005435040501	12964	Economy	9800.00
0005435040402	12964	Economy	9800.00
0005434229763	12964	Economy	9800.00
0005435040169	12964	Economy	9800.00
0005435040259	12964	Economy	9800.00
0005435040324	12964	Economy	9800.00
0005435040354	12964	Economy	9800.00
0005434229754	12964	Economy	9800.00
0005435007202	12964	Economy	9800.00
0005435040195	12964	Economy	9800.00
0005435040401	12964	Economy	9800.00
0005434229758	12964	Economy	9800.00
0005435040444	12964	Economy	9800.00
0005435040235	12964	Economy	9800.00
0005435007356	12964	Economy	9800.00
0005435377913	12964	Economy	9800.00
0005435007308	12964	Economy	9800.00
0005435040350	12964	Economy	9800.00
0005435007138	12964	Economy	9800.00
0005435039917	12964	Economy	9800.00
0005435040144	12964	Economy	9800.00
0005435040162	12964	Economy	9800.00
0005435040443	12964	Economy	9800.00
0005435040490	12964	Economy	9800.00
0005434229759	12964	Economy	9800.00
0005435007172	12964	Economy	9800.00
0005435007243	12964	Economy	9800.00
0005434229770	12964	Economy	9800.00
0005435040421	12964	Economy	9800.00
0005435040327	12964	Economy	9800.00
0005435040452	12964	Economy	9800.00
0005435007337	12964	Economy	9800.00
0005434229753	12964	Economy	9800.00
0005435040374	12964	Economy	9800.00
0005434229761	12964	Economy	9800.00
0005434229765	12964	Economy	9800.00
0005435040398	12964	Economy	9800.00
0005435007270	12964	Economy	9800.00
0005435040380	12964	Economy	9800.00
0005435040416	12964	Economy	9800.00
0005435040489	12964	Economy	9800.00
0005434229766	12964	Economy	9800.00
0005435007310	12964	Economy	9800.00
0005434229764	12964	Economy	9800.00
0005435040308	12964	Economy	9800.00
0005435007184	12964	Economy	9800.00
0005435007179	12964	Economy	9800.00
0005435040500	12964	Economy	9800.00
0005434229752	12964	Economy	9800.00
0005435040579	12964	Economy	9800.00
0005435007233	12964	Economy	9800.00
0005434229771	12964	Economy	9800.00
0005435040091	12964	Economy	9800.00
0005435042878	12964	Economy	9800.00
0005434229769	12964	Economy	9800.00
0005435007174	12964	Economy	9800.00
0005435040170	12964	Economy	9800.00
0005434229772	12964	Economy	9800.00
0005435040273	12964	Economy	9800.00
0005435042884	12964	Economy	9800.00
0005434411849	14898	Business	52900.00
0005434427105	14898	Business	52900.00
0005434411848	14898	Business	52900.00
0005434427099	14898	Business	52900.00
0005434427104	14898	Business	52900.00
0005434427096	14898	Business	52900.00
0005432188662	14898	Business	52900.00
0005434427101	14898	Business	52900.00
0005435902794	14898	Economy	17600.00
0005434427100	14898	Economy	17600.00
0005435902868	14898	Economy	17600.00
0005434427087	14898	Economy	17600.00
0005435902820	14898	Economy	17600.00
0005434427085	14898	Economy	17600.00
0005434427090	14898	Economy	19400.00
0005432188661	14898	Economy	19400.00
0005434427094	14898	Economy	19400.00
0005435902841	14898	Economy	19400.00
0005434427081	14898	Economy	17600.00
0005434427083	14898	Economy	17600.00
0005435902769	14898	Economy	17600.00
0005434427093	14898	Economy	17600.00
0005435902842	14898	Economy	17600.00
0005435554221	14898	Economy	17600.00
0005434427102	14898	Economy	17600.00
0005434427098	14898	Economy	17600.00
0005434427103	14898	Economy	17600.00
0005434427082	14898	Economy	17600.00
0005434427092	14898	Economy	17600.00
0005434427106	14898	Economy	17600.00
0005435902768	14898	Economy	17600.00
0005434427089	14898	Economy	17600.00
0005435554220	14898	Economy	17600.00
0005434411850	14898	Economy	17600.00
0005435902911	14898	Economy	17600.00
0005434427084	14898	Economy	17600.00
0005435902846	14898	Economy	17600.00
0005435902789	14898	Economy	17600.00
0005434427097	14898	Economy	17600.00
0005434411847	14898	Economy	17600.00
0005435554225	14898	Economy	17600.00
0005435902801	14898	Economy	17600.00
0005434411851	14898	Economy	17600.00
0005432188663	14898	Economy	17600.00
0005435902881	14898	Economy	17600.00
0005435902869	14898	Economy	17600.00
0005434427095	14898	Economy	17600.00
0005435902908	14898	Economy	17600.00
0005435902845	14898	Economy	17600.00
0005435902910	14898	Economy	17600.00
0005434427086	14898	Economy	17600.00
0005435902880	14898	Economy	17600.00
0005435902909	14898	Economy	17600.00
0005434427108	14898	Economy	17600.00
0005434427088	14898	Economy	17600.00
0005435554226	14898	Economy	17600.00
0005434427109	14898	Economy	17600.00
0005434427107	14898	Economy	17600.00
0005434427091	14898	Economy	17600.00
0005435902843	14898	Economy	17600.00
0005435902838	14898	Economy	17600.00
0005435903015	20179	Business	52900.00
0005434426745	20179	Business	52900.00
0005435903009	20179	Business	52900.00
0005435903012	20179	Business	52900.00
0005434426799	20179	Business	52900.00
0005435903018	20179	Business	52900.00
0005435903004	20179	Business	52900.00
0005435903010	20179	Business	52900.00
0005434411820	20179	Economy	17600.00
0005434426719	20179	Economy	17600.00
0005434426917	20179	Economy	17600.00
0005434426636	20179	Economy	19400.00
0005434426867	20179	Economy	19400.00
0005435903017	20179	Economy	17600.00
0005435903005	20179	Economy	17600.00
0005434426695	20179	Economy	17600.00
0005434426918	20179	Economy	17600.00
0005434426901	20179	Economy	17600.00
0005435554275	20179	Economy	17600.00
0005435554273	20179	Economy	17600.00
0005435903019	20179	Economy	17600.00
0005434426900	20179	Economy	17600.00
0005434426939	20179	Economy	17600.00
0005435903013	20179	Economy	17600.00
0005434426747	20179	Economy	17600.00
0005434426932	20179	Economy	17600.00
0005434426916	20179	Economy	17600.00
0005434426919	20179	Economy	17600.00
0005435903020	20179	Economy	17600.00
0005434411818	20179	Economy	17600.00
0005435903022	20179	Economy	17600.00
0005434426915	20179	Economy	17600.00
0005435903011	20179	Economy	17600.00
0005435903007	20179	Economy	17600.00
0005434426798	20179	Economy	17600.00
0005434426883	20179	Economy	17600.00
0005434426758	20179	Economy	17600.00
0005435903006	20179	Economy	17600.00
0005435903014	20179	Economy	17600.00
0005435903008	20179	Economy	17600.00
0005435554272	20179	Economy	17600.00
0005434426893	20179	Economy	17600.00
0005434426759	20179	Economy	17600.00
0005434426794	20179	Economy	17600.00
0005434426776	20179	Economy	17600.00
0005434426741	20179	Economy	17600.00
0005434426864	20179	Economy	17600.00
0005435903016	20179	Economy	17600.00
0005435554274	20179	Economy	17600.00
0005435903021	20179	Economy	17600.00
0005434426800	20179	Economy	17600.00
0005434523798	28012	Business	106800.00
0005432462548	28012	Business	106800.00
0005434523799	28012	Economy	35600.00
0005434523790	28012	Economy	35600.00
0005434523788	28012	Economy	35600.00
0005434523796	28012	Economy	35600.00
0005432462550	28012	Economy	35600.00
0005434523783	28012	Economy	35600.00
0005434523800	28012	Economy	35600.00
0005432462547	28012	Economy	35600.00
0005434523779	28012	Economy	35600.00
0005434523786	28012	Economy	35600.00
0005432462545	28012	Economy	35600.00
0005434523789	28012	Economy	35600.00
0005432462549	28012	Economy	35600.00
0005432462546	28012	Economy	35600.00
0005434523784	28012	Economy	35600.00
0005432462544	28012	Economy	35600.00
0005434523787	28012	Economy	35600.00
0005432462551	28012	Economy	35600.00
0005432462552	28012	Economy	35600.00
0005434523785	28012	Economy	35600.00
0005434523812	30884	Business	106800.00
0005432462526	30884	Economy	35600.00
0005434523817	30884	Economy	35600.00
0005434559106	30884	Economy	35600.00
0005432462539	30884	Economy	39200.00
0005434523815	30884	Economy	35600.00
0005434523816	30884	Economy	35600.00
0005434523813	30884	Economy	35600.00
0005434559105	30884	Economy	35600.00
0005432462533	30884	Economy	35600.00
0005432462525	30884	Economy	35600.00
0005434523814	30884	Economy	35600.00
0005434523811	30884	Economy	35600.00
0005433726132	30863	Business	91700.00
0005433726127	30863	Economy	30600.00
0005433726129	30863	Economy	30600.00
0005433726142	30863	Economy	30600.00
0005433726138	30863	Economy	30600.00
0005433726126	30863	Economy	30600.00
0005433726130	30863	Economy	33600.00
0005433726133	30863	Economy	30600.00
0005433726141	30863	Economy	30600.00
0005433726131	30863	Economy	30600.00
0005433726135	30863	Economy	30600.00
0005433726139	30863	Economy	30600.00
0005433726137	30863	Economy	30600.00
0005433726136	30863	Economy	30600.00
0005433726134	30863	Economy	30600.00
0005433726128	30863	Economy	30600.00
0005433726140	30863	Economy	30600.00
0005433434799	26520	Business	18500.00
0005434273087	26520	Business	18500.00
0005433434854	26520	Business	18500.00
0005435983043	26520	Business	18500.00
0005435983019	26520	Business	18500.00
0005435983047	26520	Business	18500.00
0005435983034	26520	Business	18500.00
0005435983024	26520	Business	18500.00
0005435983046	26520	Business	18500.00
0005433434864	26520	Economy	6200.00
0005435983042	26520	Economy	6200.00
0005433434919	26520	Economy	6200.00
0005435983053	26520	Economy	6200.00
0005435983028	26520	Economy	6200.00
0005435983025	26520	Economy	6200.00
0005433434798	26520	Economy	6200.00
0005435983045	26520	Economy	6200.00
0005434270218	26520	Economy	6800.00
0005435983036	26520	Economy	6800.00
0005435983023	26520	Economy	6200.00
0005433434962	26520	Economy	6200.00
0005432300361	26520	Economy	6200.00
0005435983029	26520	Economy	6200.00
0005435983044	26520	Economy	6200.00
0005435983050	26520	Economy	6200.00
0005433434923	26520	Economy	6200.00
0005433434963	26520	Economy	6200.00
0005433434951	26520	Economy	6200.00
0005435983026	26520	Economy	6200.00
0005432300358	26520	Economy	6200.00
0005433434865	26520	Economy	6200.00
0005433434936	26520	Economy	6200.00
0005432300362	26520	Economy	6200.00
0005435983030	26520	Economy	6200.00
0005435983017	26520	Economy	6200.00
0005433434984	26520	Economy	6200.00
0005433434964	26520	Economy	6200.00
0005433434952	26520	Economy	6200.00
0005435983052	26520	Economy	6200.00
0005433434860	26520	Economy	6200.00
0005433434906	26520	Economy	6200.00
0005435983048	26520	Economy	6200.00
0005433434966	26520	Economy	6200.00
0005433434931	26520	Economy	6200.00
0005433434953	26520	Economy	6200.00
0005435983032	26520	Economy	6200.00
0005432300359	26520	Economy	6200.00
0005432300360	26520	Economy	6200.00
0005435983035	26520	Economy	6200.00
0005433434925	26520	Economy	6200.00
0005435983021	26520	Economy	6200.00
0005433434866	26520	Economy	6200.00
0005433434938	26520	Economy	6200.00
0005435983033	26520	Economy	6200.00
0005435983039	26520	Economy	6200.00
0005435983051	26520	Economy	6200.00
0005435983038	26520	Economy	6200.00
0005433434983	26520	Economy	6200.00
0005435983054	26520	Economy	6200.00
0005435983037	26520	Economy	6200.00
0005433434768	26520	Economy	6200.00
0005435983040	26520	Economy	6200.00
0005433434924	26520	Economy	6200.00
0005435983020	26520	Economy	6200.00
0005435983031	26520	Economy	6200.00
0005435983022	26520	Economy	6200.00
0005435983027	26520	Economy	6200.00
0005435983018	26520	Economy	6200.00
0005435983041	26520	Economy	6200.00
0005435983049	26520	Economy	6200.00
0005435982662	26735	Business	18500.00
0005433435179	26735	Business	18500.00
0005435982632	26735	Business	18500.00
0005435982252	26735	Business	18500.00
0005435982550	26735	Business	18500.00
0005435982747	26735	Business	18500.00
0005435982727	26735	Business	18500.00
0005433435174	26735	Business	18500.00
0005433435160	26735	Business	18500.00
0005435982706	26735	Business	18500.00
0005435982724	26735	Business	18500.00
0005435982525	26735	Business	18500.00
0005435982569	26735	Economy	6200.00
0005433435170	26735	Economy	6200.00
0005435982630	26735	Economy	6200.00
0005435982737	26735	Economy	6200.00
0005435982688	26735	Economy	6200.00
0005433435178	26735	Economy	6200.00
0005433435159	26735	Economy	6200.00
0005435982698	26735	Economy	6200.00
0005435982700	26735	Economy	6200.00
0005435982589	26735	Economy	6200.00
0005435982657	26735	Economy	6800.00
0005433435177	26735	Economy	6800.00
0005435982644	26735	Economy	6800.00
0005434269140	26735	Economy	6800.00
0005433435173	26735	Economy	6800.00
0005433435162	26735	Economy	6200.00
0005435982401	26735	Economy	6200.00
0005435982697	26735	Economy	6200.00
0005433435184	26735	Economy	6200.00
0005433435185	26735	Economy	6200.00
0005435982739	26735	Economy	6200.00
0005434271348	26735	Economy	6200.00
0005433435168	26735	Economy	6200.00
0005435982638	26735	Economy	6200.00
0005434271349	26735	Economy	6200.00
0005433435183	26735	Economy	6200.00
0005435982610	26735	Economy	6200.00
0005435982682	26735	Economy	6200.00
0005433435169	26735	Economy	6200.00
0005435982617	26735	Economy	6200.00
0005433435165	26735	Economy	6200.00
0005435982693	26735	Economy	6200.00
0005433435186	26735	Economy	6200.00
0005433435175	26735	Economy	6200.00
0005433435163	26735	Economy	6200.00
0005435982623	26735	Economy	6200.00
0005433435167	26735	Economy	6200.00
0005434270243	26735	Economy	6200.00
0005435982642	26735	Economy	6200.00
0005433435187	26735	Economy	6200.00
0005435982699	26735	Economy	6200.00
0005435982666	26735	Economy	6200.00
0005435982631	26735	Economy	6200.00
0005434270244	26735	Economy	6200.00
0005435982689	26735	Economy	6200.00
0005433435181	26735	Economy	6200.00
0005433435172	26735	Economy	6200.00
0005433435182	26735	Economy	6200.00
0005435982740	26735	Economy	6200.00
0005432051182	26735	Economy	6200.00
0005435982717	26735	Economy	6200.00
0005435982587	26735	Economy	6200.00
0005435982656	26735	Economy	6200.00
0005433435176	26735	Economy	6200.00
0005435982588	26735	Economy	6200.00
0005435982402	26735	Economy	6200.00
0005434271347	26735	Economy	6200.00
0005433435158	26735	Economy	6200.00
0005435982613	26735	Economy	6200.00
0005432051184	26735	Economy	6200.00
0005432051183	26735	Economy	6200.00
0005435982609	26735	Economy	6200.00
0005435982570	26735	Economy	6200.00
0005435982439	26735	Economy	6200.00
0005435982616	26735	Economy	6200.00
0005435982726	26735	Economy	6200.00
0005434269139	26735	Economy	6200.00
0005435982692	26735	Economy	6200.00
0005435982542	26735	Economy	6200.00
0005435982738	26735	Economy	6200.00
0005435982661	26735	Economy	6200.00
0005435982723	26735	Economy	6200.00
0005433435161	26735	Economy	6200.00
0005435982251	26735	Economy	6200.00
0005435982615	26735	Economy	6200.00
0005433435164	26735	Economy	6200.00
0005433435171	26735	Economy	6200.00
0005435982663	26735	Economy	6200.00
0005435982667	26735	Economy	6200.00
0005433435180	26735	Economy	6200.00
0005433435166	26735	Economy	6200.00
0005435982683	26735	Economy	6200.00
0005433689926	29269	Economy	21000.00
0005433686648	29269	Economy	19100.00
0005433689930	29269	Economy	19100.00
0005433689922	29269	Economy	19100.00
0005433689927	29269	Economy	19100.00
0005433686661	29269	Economy	19100.00
0005433686647	29269	Economy	19100.00
0005433689928	29269	Economy	19100.00
0005432584484	3164	Economy	11100.00
0005432858164	3164	Economy	11100.00
0005432584483	3164	Economy	11100.00
0005432584463	3164	Economy	10100.00
0005432858200	3164	Economy	10100.00
0005432584476	3164	Economy	10100.00
0005432584475	3164	Economy	10100.00
0005432858189	3164	Economy	10100.00
0005432858172	3164	Economy	10100.00
0005432216320	3164	Economy	10100.00
0005432584478	3164	Economy	10100.00
0005432584482	3164	Economy	10100.00
0005432858193	3164	Economy	10100.00
0005432858171	3164	Economy	10100.00
0005432858194	3164	Economy	10100.00
0005432858221	3164	Economy	10100.00
0005432858178	3164	Economy	10100.00
0005432216321	3164	Economy	10100.00
0005432584474	3164	Economy	10100.00
0005432584464	3164	Economy	10100.00
0005432584470	3164	Economy	10100.00
0005432858203	3164	Economy	10100.00
0005432584485	3164	Economy	10100.00
0005432584481	3164	Economy	10100.00
0005432584473	3164	Economy	10100.00
0005432584462	3164	Economy	10100.00
0005432858190	3164	Economy	10100.00
0005432858163	3164	Economy	10100.00
0005432584469	3164	Economy	10100.00
0005432858179	3164	Economy	10100.00
0005432584466	3164	Economy	10100.00
0005432584461	3164	Economy	10100.00
0005432858158	3164	Economy	10100.00
0005432584480	3164	Economy	10100.00
0005432858180	3164	Economy	10100.00
0005432858198	3164	Economy	10100.00
0005432584479	3164	Economy	10100.00
0005432858166	3164	Economy	10100.00
0005432584467	3164	Economy	10100.00
0005432858197	3164	Economy	10100.00
0005432584471	3164	Economy	10100.00
0005432584465	3164	Economy	10100.00
0005432584472	3164	Economy	10100.00
0005432584477	3164	Economy	10100.00
0005432584468	3164	Economy	10100.00
0005432858283	31464	Economy	10100.00
0005432584290	31464	Economy	10100.00
0005432584350	31464	Economy	10100.00
0005432584352	31464	Economy	10100.00
0005432584194	31464	Economy	10100.00
0005432858274	31464	Economy	10100.00
0005432584317	31464	Economy	10100.00
0005432858282	31464	Economy	10100.00
0005432858279	31464	Economy	10100.00
0005432858277	31464	Economy	10100.00
0005432858278	31464	Economy	10100.00
0005432584267	31464	Economy	10100.00
0005432584358	31464	Economy	10100.00
0005432584271	31464	Economy	10100.00
0005432584280	31464	Economy	10100.00
0005432858272	31464	Economy	10100.00
0005432858275	31464	Economy	10100.00
0005432858273	31464	Economy	10100.00
0005432584281	31464	Economy	10100.00
0005432584316	31464	Economy	10100.00
0005432584266	31464	Economy	10100.00
0005432584348	31464	Economy	10100.00
0005432584283	31464	Economy	10100.00
0005432584351	31464	Economy	10100.00
0005432584193	31464	Economy	10100.00
0005432584270	31464	Economy	10100.00
0005432858280	31464	Economy	10100.00
0005432584192	31464	Economy	10100.00
0005432584259	31464	Economy	10100.00
0005432858276	31464	Economy	10100.00
0005432584233	31464	Economy	10100.00
0005432858281	31464	Economy	10100.00
0005434943514	857	Economy	8300.00
0005433255185	857	Economy	7500.00
0005434943508	857	Economy	7500.00
0005433255187	857	Economy	7500.00
0005434943515	857	Economy	7500.00
0005433255167	857	Economy	7500.00
0005433255158	857	Economy	7500.00
0005434943513	857	Economy	7500.00
0005434943511	857	Economy	7500.00
0005433255186	857	Economy	7500.00
0005434943510	857	Economy	7500.00
0005433255169	857	Economy	7500.00
0005434943512	857	Economy	7500.00
0005434943516	857	Economy	7500.00
0005433255188	857	Economy	7500.00
0005433255170	857	Economy	7500.00
0005434943509	857	Economy	7500.00
0005433255159	857	Economy	7500.00
0005433255212	16210	Economy	8300.00
0005433255216	16210	Economy	7500.00
0005433255211	16210	Economy	7500.00
0005434943467	16210	Economy	7500.00
0005434943445	16210	Economy	7500.00
0005434943415	16210	Economy	7500.00
0005433255214	16210	Economy	7500.00
0005434943471	16210	Economy	7500.00
0005433255215	16210	Economy	7500.00
0005433255213	16210	Economy	7500.00
0005435858631	27607	Business	90500.00
0005435858634	27607	Business	90500.00
0005433654832	27607	Business	90500.00
0005433654837	27607	Business	90500.00
0005435858629	27607	Business	90500.00
0005433654851	27607	Business	90500.00
0005435858628	27607	Business	90500.00
0005433654835	27607	Economy	30200.00
0005433654853	27607	Economy	30200.00
0005433654826	27607	Economy	30200.00
0005433654829	27607	Economy	30200.00
0005433654824	27607	Economy	30200.00
0005433654841	27607	Economy	30200.00
0005433654852	27607	Economy	30200.00
0005435858636	27607	Economy	33200.00
0005433654834	27607	Economy	30200.00
0005435858633	27607	Economy	30200.00
0005433654857	27607	Economy	30200.00
0005433654820	27607	Economy	30200.00
0005435858639	27607	Economy	30200.00
0005435858630	27607	Economy	30200.00
0005433654858	27607	Economy	30200.00
0005433654854	27607	Economy	30200.00
0005433654823	27607	Economy	30200.00
0005433654831	27607	Economy	30200.00
0005435858626	27607	Economy	30200.00
0005433654864	27607	Economy	30200.00
0005433654810	27607	Economy	30200.00
0005433654794	27607	Economy	30200.00
0005435858627	27607	Economy	30200.00
0005433654840	27607	Economy	30200.00
0005433654830	27607	Economy	30200.00
0005433654825	27607	Economy	30200.00
0005433654811	27607	Economy	30200.00
0005435858632	27607	Economy	30200.00
0005435858635	27607	Economy	30200.00
0005435858637	27607	Economy	30200.00
0005435858638	27607	Economy	30200.00
0005433654822	27607	Economy	30200.00
0005433811652	14372	Economy	4400.00
0005435653781	21771	Business	9800.00
0005433368304	21771	Business	9800.00
0005435653805	21771	Business	9800.00
0005433368117	21771	Business	9800.00
0005435653797	21771	Business	9800.00
0005433368059	21771	Business	9800.00
0005435653762	21771	Business	9800.00
0005433368367	21771	Business	9800.00
0005435653764	21771	Business	9800.00
0005433368206	21771	Business	9800.00
0005435653782	21771	Business	9800.00
0005435653778	21771	Business	9800.00
0005435653804	21771	Economy	3300.00
0005433368065	21771	Economy	3300.00
0005435653790	21771	Economy	3300.00
0005435653801	21771	Economy	3300.00
0005435653761	21771	Economy	3300.00
0005435653787	21771	Economy	3300.00
0005433368186	21771	Economy	3300.00
0005433368199	21771	Economy	3300.00
0005435653757	21771	Economy	3300.00
0005433368116	21771	Economy	3300.00
0005435653799	21771	Economy	3600.00
0005433368246	21771	Economy	3600.00
0005433368130	21771	Economy	3600.00
0005435653791	21771	Economy	3600.00
0005435653789	21771	Economy	3600.00
0005435653758	21771	Economy	3300.00
0005433368070	21771	Economy	3300.00
0005435653803	21771	Economy	3300.00
0005433368274	21771	Economy	3300.00
0005433368075	21771	Economy	3300.00
0005435653766	21771	Economy	3300.00
0005435653810	21771	Economy	3300.00
0005433368237	21771	Economy	3300.00
0005435653795	21771	Economy	3300.00
0005435653798	21771	Economy	3300.00
0005435653788	21771	Economy	3300.00
0005435653769	21771	Economy	3300.00
0005435653800	21771	Economy	3300.00
0005435653806	21771	Economy	3300.00
0005435653773	21771	Economy	3300.00
0005435653775	21771	Economy	3300.00
0005435653802	21771	Economy	3300.00
0005435653770	21771	Economy	3300.00
0005435653771	21771	Economy	3300.00
0005435653763	21771	Economy	3300.00
0005435653783	21771	Economy	3300.00
0005433368143	21771	Economy	3300.00
0005433368149	21771	Economy	3300.00
0005433368103	21771	Economy	3300.00
0005433368064	21771	Economy	3300.00
0005433368264	21771	Economy	3300.00
0005435653793	21771	Economy	3300.00
0005435653809	21771	Economy	3300.00
0005435653772	21771	Economy	3300.00
0005433368118	21771	Economy	3300.00
0005435653807	21771	Economy	3300.00
0005435653759	21771	Economy	3300.00
0005435653776	21771	Economy	3300.00
0005433368194	21771	Economy	3300.00
0005433368110	21771	Economy	3300.00
0005435653808	21771	Economy	3300.00
0005433368273	21771	Economy	3300.00
0005433368172	21771	Economy	3300.00
0005433368265	21771	Economy	3300.00
0005433368017	21771	Economy	3300.00
0005433368205	21771	Economy	3300.00
0005433368207	21771	Economy	3300.00
0005435653774	21771	Economy	3300.00
0005435653767	21771	Economy	3300.00
0005435653792	21771	Economy	3300.00
0005433368310	21771	Economy	3300.00
0005433368245	21771	Economy	3300.00
0005435653785	21771	Economy	3300.00
0005435653796	21771	Economy	3300.00
0005435653777	21771	Economy	3300.00
0005433368060	21771	Economy	3300.00
0005433368069	21771	Economy	3300.00
0005433368208	21771	Economy	3300.00
0005435653794	21771	Economy	3300.00
0005435653786	21771	Economy	3300.00
0005433368317	21771	Economy	3300.00
0005433368366	21771	Economy	3300.00
0005433368302	21771	Economy	3300.00
0005435653784	21771	Economy	3300.00
0005433368303	21771	Economy	3300.00
0005435653768	21771	Economy	3300.00
0005435653760	21771	Economy	3300.00
0005435653780	21771	Economy	3300.00
0005435653765	21771	Economy	3300.00
0005435653779	21771	Economy	3300.00
0005433785570	9342	Business	186200.00
0005435269826	9342	Business	186200.00
0005435269810	9342	Business	186200.00
0005432667490	9342	Business	186200.00
0005433785559	9342	Business	186200.00
0005433805968	9342	Business	186200.00
0005433785579	9342	Business	186200.00
0005433785583	9342	Business	186200.00
0005433805994	9342	Business	186200.00
0005432667489	9342	Business	186200.00
0005433805983	9342	Business	186200.00
0005433805978	9342	Business	186200.00
0005434171154	9342	Business	186200.00
0005433785585	9342	Business	186200.00
0005433805995	9342	Economy	68300.00
0005433805992	9342	Business	186200.00
0005435269759	9342	Economy	68300.00
0005433805979	9342	Economy	68300.00
0005432666426	9342	Economy	68300.00
0005433785569	9342	Economy	62100.00
0005433805985	9342	Economy	62100.00
0005433785589	9342	Economy	62100.00
0005433785580	9342	Economy	62100.00
0005433805996	9342	Economy	62100.00
0005433763460	9342	Economy	62100.00
0005434171187	9342	Economy	62100.00
0005433805988	9342	Economy	62100.00
0005433785571	9342	Economy	62100.00
0005433785591	9342	Economy	62100.00
0005433805976	9342	Economy	62100.00
0005433785564	9342	Economy	62100.00
0005433805990	9342	Economy	62100.00
0005433763452	9342	Economy	62100.00
0005434171183	9342	Economy	62100.00
0005433785586	9342	Economy	62100.00
0005433763461	9342	Economy	62100.00
0005433763454	9342	Economy	62100.00
0005433763456	9342	Economy	62100.00
0005434171221	9342	Economy	62100.00
0005433805961	9342	Economy	62100.00
0005435269817	9342	Economy	62100.00
0005433785575	9342	Economy	62100.00
0005434171145	9342	Economy	62100.00
0005433785590	9342	Economy	62100.00
0005434171220	9342	Economy	62100.00
0005433805957	9342	Economy	62100.00
0005433805960	9342	Economy	62100.00
0005434171230	9342	Economy	62100.00
0005433785578	9342	Economy	62100.00
0005433805958	9342	Economy	62100.00
0005433805991	9342	Economy	62100.00
0005433805987	9342	Economy	62100.00
0005433805972	9342	Economy	62100.00
0005433785593	9342	Economy	62100.00
0005435269801	9342	Economy	62100.00
0005433763463	9342	Economy	62100.00
0005433763458	9342	Economy	62100.00
0005434171216	9342	Economy	62100.00
0005432666424	9342	Economy	62100.00
0005434171178	9342	Economy	62100.00
0005433785560	9342	Economy	62100.00
0005433805974	9342	Economy	62100.00
0005433805973	9342	Economy	62100.00
0005433785594	9342	Economy	62100.00
0005433805956	9342	Economy	62100.00
0005433785587	9342	Economy	62100.00
0005433763462	9342	Economy	62100.00
0005435269802	9342	Economy	62100.00
0005435269808	9342	Economy	62100.00
0005433805975	9342	Economy	62100.00
0005433785563	9342	Economy	62100.00
0005433785572	9342	Economy	62100.00
0005434171165	9342	Economy	62100.00
0005433785592	9342	Economy	62100.00
0005433785566	9342	Economy	62100.00
0005433805989	9342	Economy	62100.00
0005433785565	9342	Economy	62100.00
0005434171153	9342	Economy	62100.00
0005433763465	9342	Economy	62100.00
0005433805993	9342	Economy	62100.00
0005435269799	9342	Economy	62100.00
0005433805962	9342	Economy	62100.00
0005433785568	9342	Economy	62100.00
0005433763466	9342	Economy	62100.00
0005433785576	9342	Economy	68300.00
0005435269795	9342	Economy	62100.00
0005435269803	9342	Economy	68300.00
0005432666425	9342	Economy	62100.00
0005433805986	9342	Economy	62100.00
0005433763457	9342	Economy	62100.00
0005434171215	9342	Economy	62100.00
0005434171189	9342	Economy	62100.00
0005432657503	9342	Economy	62100.00
0005434171193	9342	Economy	62100.00
0005433785588	9342	Economy	62100.00
0005433805967	9342	Economy	62100.00
0005433785581	9342	Economy	62100.00
0005434270234	9342	Economy	62100.00
0005433785584	9342	Economy	62100.00
0005433805977	9342	Economy	62100.00
0005433785558	9342	Economy	62100.00
0005435269788	9342	Economy	62100.00
0005433805964	9342	Economy	62100.00
0005433805980	9342	Economy	62100.00
0005433805971	9342	Economy	62100.00
0005434270233	9342	Economy	62100.00
0005433785596	9342	Economy	62100.00
0005433785562	9342	Economy	62100.00
0005433763459	9342	Economy	62100.00
0005434171197	9342	Economy	62100.00
0005432657502	9342	Economy	62100.00
0005433805984	9342	Economy	62100.00
0005433785577	9342	Economy	62100.00
0005433805997	9342	Economy	62100.00
0005433785582	9342	Economy	62100.00
0005434171169	9342	Economy	62100.00
0005433805981	9342	Economy	62100.00
0005433805969	9342	Economy	62100.00
0005433805970	9342	Economy	62100.00
0005433763464	9342	Economy	62100.00
0005433785595	9342	Economy	62100.00
0005433763455	9342	Economy	62100.00
0005434171170	9342	Economy	62100.00
0005433805959	9342	Economy	62100.00
0005433805963	9342	Economy	62100.00
0005432657501	9342	Economy	62100.00
0005433785574	9342	Economy	62100.00
0005433805966	9342	Economy	62100.00
0005434171144	9342	Economy	62100.00
0005433805982	9342	Economy	62100.00
0005435269809	9342	Economy	62100.00
0005434171184	9342	Economy	62100.00
0005433763453	9342	Economy	62100.00
0005434171198	9342	Economy	62100.00
0005434171203	9342	Economy	62100.00
0005433805965	9342	Economy	62100.00
0005435269811	9342	Economy	62100.00
0005435269779	9342	Economy	62100.00
0005433785567	9342	Economy	62100.00
0005435269789	9342	Economy	62100.00
0005432665311	9342	Economy	62100.00
0005433785573	9342	Economy	62100.00
0005433785561	9342	Economy	62100.00
0005435269800	9342	Economy	62100.00
0005434171303	26257	Business	186200.00
0005433805878	26257	Business	186200.00
0005433805722	26257	Business	186200.00
0005433763287	26257	Business	186200.00
0005433785067	26257	Business	186200.00
0005434151754	26257	Business	186200.00
0005433785246	26257	Business	186200.00
0005433763306	26257	Business	186200.00
0005434171308	26257	Business	186200.00
0005433785265	26257	Business	186200.00
0005433763339	26257	Business	186200.00
0005433785295	26257	Business	186200.00
0005433805583	26257	Business	186200.00
0005434171300	26257	Business	186200.00
0005433785248	26257	Business	186200.00
0005433805703	26257	Business	186200.00
0005433785070	26257	Business	186200.00
0005432659712	26257	Business	186200.00
0005433805765	26257	Economy	68300.00
0005433785329	26257	Economy	68300.00
0005433785293	26257	Economy	62100.00
0005433785286	26257	Economy	62100.00
0005435269884	26257	Economy	62100.00
0005433805590	26257	Economy	62100.00
0005434269138	26257	Economy	62100.00
0005433785276	26257	Economy	62100.00
0005433785142	26257	Economy	62100.00
0005433785037	26257	Economy	62100.00
0005433805609	26257	Economy	62100.00
0005435269883	26257	Economy	62100.00
0005433805510	26257	Economy	62100.00
0005433785236	26257	Economy	62100.00
0005433805711	26257	Economy	62100.00
0005433785235	26257	Economy	62100.00
0005433785323	26257	Economy	62100.00
0005434151756	26257	Economy	62100.00
0005433785404	26257	Economy	62100.00
0005434171305	26257	Economy	62100.00
0005433785330	26257	Economy	62100.00
0005433763229	26257	Economy	62100.00
0005433805777	26257	Economy	62100.00
0005432657481	26257	Economy	62100.00
0005433785256	26257	Economy	62100.00
0005433763375	26257	Economy	62100.00
0005433785336	26257	Economy	62100.00
0005434270241	26257	Economy	62100.00
0005433785304	26257	Economy	62100.00
0005433763284	26257	Economy	62100.00
0005433785245	26257	Economy	62100.00
0005432659728	26257	Economy	62100.00
0005433805742	26257	Economy	62100.00
0005433785209	26257	Economy	62100.00
0005433785327	26257	Economy	62100.00
0005432659711	26257	Economy	62100.00
0005433763313	26257	Economy	62100.00
0005433805690	26257	Economy	62100.00
0005434271346	26257	Economy	62100.00
0005433785279	26257	Economy	62100.00
0005433785247	26257	Economy	62100.00
0005433805568	26257	Economy	62100.00
0005434270242	26257	Economy	62100.00
0005433763257	26257	Economy	62100.00
0005433785339	26257	Economy	62100.00
0005434171310	26257	Economy	62100.00
0005433763336	26257	Economy	62100.00
0005433763258	26257	Economy	62100.00
0005434171299	26257	Economy	62100.00
0005433805602	26257	Economy	62100.00
0005433785190	26257	Economy	62100.00
0005434269137	26257	Economy	62100.00
0005433805701	26257	Economy	62100.00
0005433805712	26257	Economy	62100.00
0005434171301	26257	Economy	62100.00
0005433763318	26257	Economy	62100.00
0005433805692	26257	Economy	62100.00
0005433805536	26257	Economy	62100.00
0005433805741	26257	Economy	62100.00
0005433805761	26257	Economy	62100.00
0005433785272	26257	Economy	62100.00
0005434171302	26257	Economy	62100.00
0005433805608	26257	Economy	62100.00
0005433805791	26257	Economy	62100.00
0005433763297	26257	Economy	62100.00
0005433785291	26257	Economy	68300.00
0005433805694	26257	Economy	68300.00
0005433785036	26257	Economy	62100.00
0005433785366	26257	Economy	62100.00
0005433785307	26257	Economy	62100.00
0005433763352	26257	Economy	68300.00
0005433763341	26257	Economy	62100.00
0005433785195	26257	Economy	62100.00
0005433805721	26257	Economy	62100.00
0005433785157	26257	Economy	62100.00
0005433785226	26257	Economy	62100.00
0005433785405	26257	Economy	62100.00
0005433763340	26257	Economy	62100.00
0005434171304	26257	Economy	62100.00
0005433763374	26257	Economy	62100.00
0005433805720	26257	Economy	62100.00
0005433805693	26257	Economy	62100.00
0005435269886	26257	Economy	62100.00
0005435269885	26257	Economy	62100.00
0005433785083	26257	Economy	62100.00
0005433763373	26257	Economy	62100.00
0005433785232	26257	Economy	62100.00
0005433805717	26257	Economy	62100.00
0005433785251	26257	Economy	62100.00
0005434171307	26257	Economy	62100.00
0005434171298	26257	Economy	62100.00
0005433785063	26257	Economy	62100.00
0005433805572	26257	Economy	62100.00
0005433785260	26257	Economy	62100.00
0005433763338	26257	Economy	62100.00
0005433785035	26257	Economy	62100.00
0005433785275	26257	Economy	62100.00
0005433763353	26257	Economy	62100.00
0005433763342	26257	Economy	62100.00
0005433805716	26257	Economy	62100.00
0005433805589	26257	Economy	62100.00
0005433805719	26257	Economy	62100.00
0005433805702	26257	Economy	62100.00
0005434171306	26257	Economy	62100.00
0005433785362	26257	Economy	62100.00
0005433785261	26257	Economy	62100.00
0005433785278	26257	Economy	62100.00
0005434171297	26257	Economy	62100.00
0005434151755	26257	Economy	62100.00
0005433763299	26257	Economy	62100.00
0005433805597	26257	Economy	62100.00
0005433763230	26257	Economy	62100.00
0005433785255	26257	Economy	62100.00
0005433785264	26257	Economy	62100.00
0005433785194	26257	Economy	62100.00
0005433805715	26257	Economy	62100.00
0005433805567	26257	Economy	62100.00
0005434171309	26257	Economy	62100.00
0005433785271	26257	Economy	62100.00
0005433785158	26257	Economy	62100.00
0005435135756	4898	Economy	5300.00
0005435135754	4898	Economy	5300.00
0005435135757	4898	Economy	5300.00
0005435929666	4898	Economy	5300.00
0005435135755	4898	Economy	5300.00
0005435135717	33033	Economy	5300.00
0005435929690	33033	Economy	5300.00
0005435929689	33033	Economy	5300.00
0005435929692	33033	Economy	5300.00
0005435929691	33033	Economy	5300.00
0005434983377	9455	Economy	17900.00
0005434217998	9455	Economy	17900.00
0005434218020	9455	Economy	17900.00
0005434983378	9455	Economy	17900.00
0005434218000	9455	Economy	17900.00
0005434218006	9455	Economy	17900.00
0005434217999	9455	Economy	17900.00
0005434217993	9455	Economy	17900.00
0005434218019	9455	Economy	17900.00
0005434983379	9455	Economy	17900.00
0005434983375	9455	Economy	17900.00
0005434217992	9455	Economy	17900.00
0005434983376	9455	Economy	17900.00
0005434218041	27352	Economy	19700.00
0005434218037	27352	Economy	17900.00
0005434983348	27352	Economy	17900.00
0005434218039	27352	Economy	17900.00
0005434218038	27352	Economy	17900.00
0005434983362	27352	Economy	17900.00
0005434983344	27352	Economy	17900.00
0005434983337	27352	Economy	17900.00
0005434983363	27352	Economy	17900.00
0005434218040	27352	Economy	17900.00
0005433986199	24258	Business	36400.00
0005433961269	24258	Business	36400.00
0005433961126	24258	Business	36400.00
0005433986128	24258	Business	36400.00
0005433961179	24258	Business	36400.00
0005433961285	24258	Business	36400.00
0005433961351	24258	Business	36400.00
0005433960998	24258	Business	36400.00
0005433986196	24258	Business	36400.00
0005433986356	24258	Business	36400.00
0005433986253	24258	Business	36400.00
0005433986374	24258	Business	36400.00
0005433986195	24258	Business	36400.00
0005433986480	24258	Business	36400.00
0005433986244	24258	Business	36400.00
0005433961113	24258	Economy	13400.00
0005433986254	24258	Economy	13400.00
0005433986289	24258	Economy	12100.00
0005433961298	24258	Economy	12100.00
0005433986077	24258	Economy	12100.00
0005433961061	24258	Economy	12100.00
0005433961319	24258	Economy	12100.00
0005433986373	24258	Economy	12100.00
0005433961071	24258	Economy	12100.00
0005433961294	24258	Economy	12100.00
0005433961072	24258	Economy	12100.00
0005433961100	24258	Economy	12100.00
0005433986523	24258	Economy	12100.00
0005433961373	24258	Economy	12100.00
0005433986279	24258	Economy	12100.00
0005433961263	24258	Economy	12100.00
0005433961345	24258	Economy	12100.00
0005433986252	24258	Economy	12100.00
0005433986509	24258	Economy	12100.00
0005433961305	24258	Economy	12100.00
0005433986354	24258	Economy	12100.00
0005433986379	24258	Economy	12100.00
0005433986153	24258	Economy	12100.00
0005433986421	24258	Economy	12100.00
0005433986380	24258	Economy	12100.00
0005433961218	24258	Economy	12100.00
0005433986338	24258	Economy	12100.00
0005433961226	24258	Economy	12100.00
0005433961112	24258	Economy	12100.00
0005433986200	24258	Economy	12100.00
0005433986219	24258	Economy	12100.00
0005433986201	24258	Economy	12100.00
0005433986233	24258	Economy	12100.00
0005433961183	24258	Economy	12100.00
0005433986293	24258	Economy	12100.00
0005433961366	24258	Economy	12100.00
0005433986582	24258	Economy	12100.00
0005433960912	24258	Economy	12100.00
0005433986221	24258	Economy	12100.00
0005433961342	24258	Economy	12100.00
0005433961131	24258	Economy	12100.00
0005433961217	24258	Economy	12100.00
0005433961307	24258	Economy	12100.00
0005433961247	24258	Economy	12100.00
0005433986150	24258	Economy	12100.00
0005433986436	24258	Economy	12100.00
0005433986292	24258	Economy	12100.00
0005433961176	24258	Economy	12100.00
0005433961320	24258	Economy	12100.00
0005433986149	24258	Economy	12100.00
0005433986112	24258	Economy	12100.00
0005433961357	24258	Economy	12100.00
0005433986297	24258	Economy	12100.00
0005433961083	24258	Economy	12100.00
0005433961270	24258	Economy	13400.00
0005433961344	24258	Economy	12100.00
0005433961163	24258	Economy	12100.00
0005433986417	24258	Economy	13400.00
0005433986329	24258	Economy	12100.00
0005433986418	24258	Economy	12100.00
0005433986355	24258	Economy	12100.00
0005433961204	24258	Economy	12100.00
0005433961228	24258	Economy	12100.00
0005433961288	24258	Economy	12100.00
0005433961245	24258	Economy	12100.00
0005433986398	24258	Economy	12100.00
0005433961316	24258	Economy	12100.00
0005433961242	24258	Economy	12100.00
0005433961234	24258	Economy	12100.00
0005433986241	24258	Economy	12100.00
0005433986510	24258	Economy	12100.00
0005433986239	24258	Economy	12100.00
0005433986397	24258	Economy	12100.00
0005433961101	24258	Economy	12100.00
0005433986287	24258	Economy	12100.00
0005433986280	24258	Economy	12100.00
0005433986271	24258	Economy	12100.00
0005433961254	24258	Economy	12100.00
0005433986350	24258	Economy	12100.00
0005433961215	24258	Economy	12100.00
0005433961308	24258	Economy	12100.00
0005433986348	24258	Economy	12100.00
0005433986161	24258	Economy	12100.00
0005433986242	24258	Economy	12100.00
0005433961374	24258	Economy	12100.00
0005433961323	24258	Economy	12100.00
0005433986361	24258	Economy	12100.00
0005433961341	24258	Economy	12100.00
0005433961306	24258	Economy	12100.00
0005433986129	24258	Economy	12100.00
0005433961127	24258	Economy	12100.00
0005433986491	24258	Economy	12100.00
0005433961376	24258	Economy	12100.00
0005433986251	24258	Economy	12100.00
0005433986113	24258	Economy	12100.00
0005433961343	24258	Economy	12100.00
0005433986349	24258	Economy	12100.00
0005433961248	24258	Economy	12100.00
0005433986483	24258	Economy	12100.00
0005433961166	24258	Economy	12100.00
0005433961797	25923	Business	36400.00
0005433986725	25923	Business	36400.00
0005433986693	25923	Business	36400.00
0005433961807	25923	Business	36400.00
0005433986735	25923	Business	36400.00
0005433961800	25923	Business	36400.00
0005433961812	25923	Business	36400.00
0005433961828	25923	Business	36400.00
0005433961849	25923	Business	36400.00
0005433986742	25923	Business	36400.00
0005433961787	25923	Business	36400.00
0005433986743	25923	Business	36400.00
0005433961791	25923	Business	36400.00
0005433986741	25923	Business	36400.00
0005433961840	25923	Business	36400.00
0005433961794	25923	Business	36400.00
0005433986718	25923	Business	36400.00
0005433961784	25923	Economy	13400.00
0005433986737	25923	Economy	13400.00
0005433961778	25923	Economy	13400.00
0005433986721	25923	Economy	12100.00
0005433961823	25923	Economy	12100.00
0005433961850	25923	Economy	12100.00
0005433986697	25923	Economy	12100.00
0005433961788	25923	Economy	12100.00
0005433986732	25923	Economy	12100.00
0005433961837	25923	Economy	12100.00
0005433961831	25923	Economy	12100.00
0005433961790	25923	Economy	12100.00
0005433986726	25923	Economy	12100.00
0005433961785	25923	Economy	12100.00
0005433986722	25923	Economy	12100.00
0005433961792	25923	Economy	12100.00
0005433961832	25923	Economy	12100.00
0005433961829	25923	Economy	12100.00
0005433986707	25923	Economy	12100.00
0005433986731	25923	Economy	12100.00
0005433986749	25923	Economy	12100.00
0005433986729	25923	Economy	12100.00
0005433986733	25923	Economy	12100.00
0005433961779	25923	Economy	12100.00
0005433986702	25923	Economy	12100.00
0005433986739	25923	Economy	12100.00
0005433986716	25923	Economy	12100.00
0005433986738	25923	Economy	12100.00
0005433961793	25923	Economy	12100.00
0005433961820	25923	Economy	12100.00
0005433986711	25923	Economy	12100.00
0005433961836	25923	Economy	12100.00
0005433961803	25923	Economy	12100.00
0005433961825	25923	Economy	12100.00
0005433961819	25923	Economy	12100.00
0005433986734	25923	Economy	12100.00
0005433961786	25923	Economy	12100.00
0005433961811	25923	Economy	12100.00
0005433986748	25923	Economy	12100.00
0005433961801	25923	Economy	12100.00
0005433986746	25923	Economy	12100.00
0005433961783	25923	Economy	12100.00
0005433961830	25923	Economy	12100.00
0005433986717	25923	Economy	12100.00
0005433961804	25923	Economy	12100.00
0005433961839	25923	Economy	12100.00
0005433986747	25923	Economy	12100.00
0005433961809	25923	Economy	12100.00
0005433986723	25923	Economy	12100.00
0005433986708	25923	Economy	12100.00
0005433986709	25923	Economy	12100.00
0005433986728	25923	Economy	12100.00
0005433961841	25923	Economy	12100.00
0005433986724	25923	Economy	12100.00
0005433961842	25923	Economy	12100.00
0005433961848	25923	Economy	12100.00
0005433961814	25923	Economy	12100.00
0005433961802	25923	Economy	12100.00
0005433986705	25923	Economy	12100.00
0005433961818	25923	Economy	12100.00
0005433961845	25923	Economy	12100.00
0005433986695	25923	Economy	12100.00
0005433986714	25923	Economy	13400.00
0005433961799	25923	Economy	12100.00
0005433961835	25923	Economy	13400.00
0005433961780	25923	Economy	12100.00
0005433986698	25923	Economy	13400.00
0005433961847	25923	Economy	12100.00
0005433961852	25923	Economy	13400.00
0005433961827	25923	Economy	12100.00
0005433961813	25923	Economy	12100.00
0005433986715	25923	Economy	12100.00
0005433986704	25923	Economy	12100.00
0005433961844	25923	Economy	12100.00
0005433961796	25923	Economy	12100.00
0005433986745	25923	Economy	12100.00
0005433961789	25923	Economy	12100.00
0005433986710	25923	Economy	12100.00
0005433961843	25923	Economy	12100.00
0005433961782	25923	Economy	12100.00
0005433986701	25923	Economy	12100.00
0005433986703	25923	Economy	12100.00
0005433986713	25923	Economy	12100.00
0005433961824	25923	Economy	12100.00
0005433986706	25923	Economy	12100.00
0005433961815	25923	Economy	12100.00
0005433986736	25923	Economy	12100.00
0005433961826	25923	Economy	12100.00
0005433986730	25923	Economy	12100.00
0005433986720	25923	Economy	12100.00
0005433986694	25923	Economy	12100.00
0005433961798	25923	Economy	12100.00
0005433961805	25923	Economy	12100.00
0005433961795	25923	Economy	12100.00
0005433961833	25923	Economy	12100.00
0005433986727	25923	Economy	12100.00
0005433961851	25923	Economy	12100.00
0005433961810	25923	Economy	12100.00
0005433986696	25923	Economy	12100.00
0005433986699	25923	Economy	12100.00
0005433961838	25923	Economy	12100.00
0005433986700	25923	Economy	12100.00
0005433961816	25923	Economy	12100.00
0005433986744	25923	Economy	12100.00
0005433961817	25923	Economy	12100.00
0005433961822	25923	Economy	12100.00
0005433986740	25923	Economy	12100.00
0005433961781	25923	Economy	12100.00
0005433961821	25923	Economy	12100.00
0005433961846	25923	Economy	12100.00
0005433986712	25923	Economy	12100.00
0005433961806	25923	Economy	12100.00
0005433961808	25923	Economy	12100.00
0005433961834	25923	Economy	12100.00
0005433986719	25923	Economy	12100.00
0005432269544	959	Economy	25400.00
0005434480763	959	Economy	25400.00
0005432269546	959	Economy	25400.00
0005434480752	959	Economy	23100.00
0005434480768	959	Economy	23100.00
0005434480754	959	Economy	23100.00
0005434480749	959	Economy	23100.00
0005433166062	959	Economy	23100.00
0005434480750	959	Economy	23100.00
0005434480755	959	Economy	23100.00
0005434480757	959	Economy	23100.00
0005433166013	959	Economy	23100.00
0005434480760	959	Economy	23100.00
0005434480765	959	Economy	23100.00
0005433166032	959	Economy	23100.00
0005434480751	959	Economy	23100.00
0005434480758	959	Economy	23100.00
0005434480762	959	Economy	23100.00
0005434480756	959	Economy	23100.00
0005432269543	959	Economy	23100.00
0005433166094	959	Economy	23100.00
0005434480767	959	Economy	23100.00
0005434480747	959	Economy	23100.00
0005434480766	959	Economy	23100.00
0005433165992	959	Economy	23100.00
0005434480769	959	Economy	23100.00
0005434480764	959	Economy	23100.00
0005432269545	959	Economy	23100.00
0005434480748	959	Economy	23100.00
0005434480770	959	Economy	23100.00
0005434480753	959	Economy	23100.00
0005433166033	959	Economy	23100.00
0005434480759	959	Economy	23100.00
0005434480761	959	Economy	23100.00
0005434480771	959	Economy	23100.00
0005434480537	16552	Economy	25400.00
0005433166137	16552	Economy	23100.00
0005434480511	16552	Economy	23100.00
0005433166133	16552	Economy	23100.00
0005434480488	16552	Economy	23100.00
0005433166128	16552	Economy	23100.00
0005433166130	16552	Economy	23100.00
0005433166125	16552	Economy	23100.00
0005433166132	16552	Economy	23100.00
0005434480517	16552	Economy	23100.00
0005433166127	16552	Economy	23100.00
0005434480525	16552	Economy	23100.00
0005434480576	16552	Economy	23100.00
0005434480566	16552	Economy	23100.00
0005434480509	16552	Economy	23100.00
0005434480516	16552	Economy	23100.00
0005433166129	16552	Economy	23100.00
0005433166134	16552	Economy	23100.00
0005434480510	16552	Economy	23100.00
0005433166135	16552	Economy	23100.00
0005433166131	16552	Economy	23100.00
0005433166136	16552	Economy	23100.00
0005433166126	16552	Economy	23100.00
0005433289901	10370	Economy	17000.00
0005435142793	10370	Economy	17000.00
0005435142795	10370	Economy	17000.00
0005435142794	10370	Economy	15400.00
0005433289884	10370	Economy	15400.00
0005435150257	10370	Economy	15400.00
0005435142802	10370	Economy	15400.00
0005433289904	10370	Economy	15400.00
0005435150254	10370	Economy	15400.00
0005435142799	10370	Economy	15400.00
0005435150255	10370	Economy	15400.00
0005435142796	10370	Economy	15400.00
0005435150262	10370	Economy	15400.00
0005435142801	10370	Economy	15400.00
0005435150258	10370	Economy	15400.00
0005435386601	10370	Economy	15400.00
0005435386607	10370	Economy	15400.00
0005435142804	10370	Economy	15400.00
0005435386611	10370	Economy	15400.00
0005435150251	10370	Economy	15400.00
0005435142803	10370	Economy	15400.00
0005435386608	10370	Economy	15400.00
0005435142806	10370	Economy	15400.00
0005435150252	10370	Economy	15400.00
0005435150259	10370	Economy	15400.00
0005435150253	10370	Economy	15400.00
0005435150261	10370	Economy	15400.00
0005435150256	10370	Economy	15400.00
0005435386594	10370	Economy	15400.00
0005433289881	10370	Economy	15400.00
0005435142805	10370	Economy	15400.00
0005433289895	10370	Economy	15400.00
0005435150263	10370	Economy	15400.00
0005435142800	10370	Economy	15400.00
0005435142807	10370	Economy	15400.00
0005435142797	10370	Economy	15400.00
0005435150264	10370	Economy	15400.00
0005435386612	10370	Economy	15400.00
0005435386641	10370	Economy	15400.00
0005435142798	10370	Economy	15400.00
0005435150260	10370	Economy	15400.00
0005433289905	10370	Economy	15400.00
0005433289885	10370	Economy	15400.00
0005435142695	21927	Economy	17000.00
0005433289978	21927	Economy	17000.00
0005435142665	21927	Economy	17000.00
0005435142733	21927	Economy	17000.00
0005433289982	21927	Economy	15400.00
0005435150140	21927	Economy	15400.00
0005435386684	21927	Economy	15400.00
0005435150135	21927	Economy	15400.00
0005435150137	21927	Economy	15400.00
0005435386683	21927	Economy	15400.00
0005433289983	21927	Economy	15400.00
0005435386688	21927	Economy	15400.00
0005435386681	21927	Economy	15400.00
0005435150138	21927	Economy	15400.00
0005435150139	21927	Economy	15400.00
0005435150092	21927	Economy	15400.00
0005435142640	21927	Economy	15400.00
0005435150169	21927	Economy	15400.00
0005435142730	21927	Economy	15400.00
0005435150119	21927	Economy	15400.00
0005435142636	21927	Economy	15400.00
0005435142709	21927	Economy	15400.00
0005435386686	21927	Economy	15400.00
0005435386687	21927	Economy	15400.00
0005433289980	21927	Economy	15400.00
0005435142637	21927	Economy	15400.00
0005435150127	21927	Economy	15400.00
0005435142677	21927	Economy	15400.00
0005435150093	21927	Economy	15400.00
0005435150096	21927	Economy	15400.00
0005435142708	21927	Economy	15400.00
0005435150157	21927	Economy	15400.00
0005435386685	21927	Economy	15400.00
0005435142701	21927	Economy	15400.00
0005435150125	21927	Economy	15400.00
0005433289979	21927	Economy	15400.00
0005435150168	21927	Economy	15400.00
0005435150136	21927	Economy	15400.00
0005435386682	21927	Economy	15400.00
0005435142641	21927	Economy	15400.00
0005433289984	21927	Economy	15400.00
0005433289977	21927	Economy	15400.00
0005433289981	21927	Economy	15400.00
0005435529496	11228	Business	57200.00
0005434573584	11228	Business	57200.00
0005435545778	11228	Business	57200.00
0005435502449	11228	Business	57200.00
0005435529447	11228	Business	57200.00
0005435529489	11228	Economy	19100.00
0005435502521	11228	Economy	19100.00
0005435319659	11228	Economy	19100.00
0005434573588	11228	Economy	19100.00
0005435545805	11228	Economy	19100.00
0005435529335	11228	Economy	19100.00
0005435545810	11228	Economy	19100.00
0005435545827	11228	Economy	21000.00
0005434573578	11228	Economy	21000.00
0005435502519	11228	Economy	21000.00
0005435529356	11228	Economy	19100.00
0005435529427	11228	Economy	19100.00
0005434573585	11228	Economy	19100.00
0005435545804	11228	Economy	19100.00
0005435545809	11228	Economy	19100.00
0005435502478	11228	Economy	19100.00
0005434573582	11228	Economy	19100.00
0005435502518	11228	Economy	19100.00
0005435502448	11228	Economy	19100.00
0005435319629	11228	Economy	19100.00
0005434573581	11228	Economy	19100.00
0005435502538	11228	Economy	19100.00
0005435545808	11228	Economy	19100.00
0005435529357	11228	Economy	19100.00
0005435502535	11228	Economy	19100.00
0005435529422	11228	Economy	19100.00
0005434573591	11228	Economy	19100.00
0005435502541	11228	Economy	19100.00
0005434573590	11228	Economy	19100.00
0005435319637	11228	Economy	19100.00
0005435319644	11228	Economy	19100.00
0005435319645	11228	Economy	19100.00
0005435529495	11228	Economy	19100.00
0005435319658	11228	Economy	19100.00
0005435529488	11228	Economy	19100.00
0005435545826	11228	Economy	19100.00
0005435529423	11228	Economy	19100.00
0005434573586	11228	Economy	19100.00
0005434573583	11228	Economy	19100.00
0005435319643	11228	Economy	19100.00
0005435502520	11228	Economy	19100.00
0005435502489	11228	Economy	19100.00
0005435529494	11228	Economy	19100.00
0005435502536	11228	Economy	19100.00
0005435545832	11228	Economy	19100.00
0005435502422	11228	Economy	19100.00
0005435502522	11228	Economy	19100.00
0005435319635	11228	Economy	19100.00
0005435502471	11228	Economy	19100.00
0005435529334	11228	Economy	19100.00
0005435319595	11228	Economy	19100.00
0005434573579	11228	Economy	19100.00
0005435502537	11228	Economy	19100.00
0005434573587	11228	Economy	19100.00
0005434573589	11228	Economy	19100.00
0005435545817	11228	Economy	19100.00
0005434573580	11228	Economy	19100.00
0005435319636	11228	Economy	19100.00
0005435319737	20912	Business	57200.00
0005432291971	20912	Business	57200.00
0005432291969	20912	Business	57200.00
0005435502669	20912	Business	57200.00
0005435508563	20912	Business	57200.00
0005434573427	20912	Business	57200.00
0005434573500	20912	Business	57200.00
0005435508561	20912	Economy	19100.00
0005435518223	20912	Economy	19100.00
0005435502686	20912	Economy	19100.00
0005435319738	20912	Economy	19100.00
0005435518222	20912	Economy	19100.00
0005435508558	20912	Economy	19100.00
0005435518221	20912	Economy	19100.00
0005435502682	20912	Economy	19100.00
0005435518219	20912	Economy	21000.00
0005435319732	20912	Economy	21000.00
0005435502664	20912	Economy	21000.00
0005434573452	20912	Economy	21000.00
0005435518218	20912	Economy	19100.00
0005435502684	20912	Economy	19100.00
0005435502681	20912	Economy	19100.00
0005432291973	20912	Economy	19100.00
0005435319735	20912	Economy	19100.00
0005435502674	20912	Economy	19100.00
0005432291970	20912	Economy	19100.00
0005434573417	20912	Economy	19100.00
0005434573418	20912	Economy	19100.00
0005434573426	20912	Economy	19100.00
0005435508559	20912	Economy	19100.00
0005435502673	20912	Economy	19100.00
0005432291972	20912	Economy	19100.00
0005435502677	20912	Economy	19100.00
0005435319733	20912	Economy	19100.00
0005434573442	20912	Economy	19100.00
0005435502678	20912	Economy	19100.00
0005435508553	20912	Economy	19100.00
0005435508552	20912	Economy	19100.00
0005435502668	20912	Economy	19100.00
0005435502663	20912	Economy	19100.00
0005435502680	20912	Economy	19100.00
0005432291974	20912	Economy	19100.00
0005435508557	20912	Economy	19100.00
0005434573441	20912	Economy	19100.00
0005434573436	20912	Economy	19100.00
0005435319740	20912	Economy	19100.00
0005435502683	20912	Economy	19100.00
0005435508555	20912	Economy	19100.00
0005435319736	20912	Economy	19100.00
0005435502670	20912	Economy	19100.00
0005435502666	20912	Economy	19100.00
0005435502672	20912	Economy	19100.00
0005435502676	20912	Economy	19100.00
0005434573514	20912	Economy	19100.00
0005435508554	20912	Economy	19100.00
0005435502675	20912	Economy	19100.00
0005435508562	20912	Economy	19100.00
0005435319734	20912	Economy	19100.00
0005435502685	20912	Economy	19100.00
0005435518220	20912	Economy	19100.00
0005435508560	20912	Economy	19100.00
0005435502667	20912	Economy	19100.00
0005435508550	20912	Economy	19100.00
0005434573491	20912	Economy	19100.00
0005434573464	20912	Economy	19100.00
0005434573490	20912	Economy	19100.00
0005435502679	20912	Economy	19100.00
0005435319739	20912	Economy	19100.00
0005435508556	20912	Economy	19100.00
0005435502665	20912	Economy	19100.00
0005435502671	20912	Economy	19100.00
0005435508551	20912	Economy	19100.00
0005432693211	2949	Business	10300.00
0005432693398	2949	Business	10300.00
0005432693330	2949	Business	10300.00
0005432693321	2949	Economy	3400.00
0005432693238	2949	Economy	3400.00
0005432693338	2949	Economy	3400.00
0005432693261	2949	Economy	3400.00
0005432693367	2949	Economy	3400.00
0005432693285	2949	Economy	3400.00
0005432693329	2949	Economy	3400.00
0005432693244	2949	Economy	3400.00
0005432693257	2949	Economy	3400.00
0005432693413	2949	Economy	3400.00
0005432693366	2949	Economy	3400.00
0005432693363	2949	Economy	3400.00
0005432693393	2949	Economy	3400.00
0005432693391	2949	Economy	3400.00
0005432693286	2949	Economy	3400.00
0005432693349	2949	Economy	3400.00
0005432693399	2949	Economy	3400.00
0005432693245	2949	Economy	3400.00
0005432693322	2949	Economy	3400.00
0005432880931	3000	Business	10300.00
0005432707202	3000	Business	10300.00
0005432707211	3000	Business	10300.00
0005432707208	3000	Business	10300.00
0005432707218	3000	Business	10300.00
0005432707209	3000	Business	10300.00
0005432707223	3000	Business	10300.00
0005433194882	3000	Business	10300.00
0005432880980	3000	Business	10300.00
0005432707222	3000	Economy	3400.00
0005433124110	3000	Economy	3400.00
0005433124054	3000	Economy	3400.00
0005433124109	3000	Economy	3400.00
0005432707215	3000	Economy	3400.00
0005432217824	3000	Economy	3400.00
0005433124130	3000	Economy	3400.00
0005432880890	3000	Economy	3800.00
0005432707207	3000	Economy	3800.00
0005432707204	3000	Economy	3800.00
0005432707201	3000	Economy	3800.00
0005433124155	3000	Economy	3400.00
0005433124184	3000	Economy	3400.00
0005432707206	3000	Economy	3400.00
0005433194878	3000	Economy	3400.00
0005433194884	3000	Economy	3400.00
0005432707224	3000	Economy	3400.00
0005432707219	3000	Economy	3400.00
0005433124114	3000	Economy	3400.00
0005432880951	3000	Economy	3400.00
0005432707212	3000	Economy	3400.00
0005433124117	3000	Economy	3400.00
0005433124006	3000	Economy	3400.00
0005432880917	3000	Economy	3400.00
0005432707200	3000	Economy	3400.00
0005432880915	3000	Economy	3400.00
0005432707213	3000	Economy	3400.00
0005432880933	3000	Economy	3400.00
0005433124072	3000	Economy	3400.00
0005432880979	3000	Economy	3400.00
0005432217826	3000	Economy	3400.00
0005432880999	3000	Economy	3400.00
0005432707203	3000	Economy	3400.00
0005433124111	3000	Economy	3400.00
0005433124086	3000	Economy	3400.00
0005432707216	3000	Economy	3400.00
0005433124136	3000	Economy	3400.00
0005432880889	3000	Economy	3400.00
0005432707214	3000	Economy	3400.00
0005433124055	3000	Economy	3400.00
0005432707217	3000	Economy	3400.00
0005432880911	3000	Economy	3400.00
0005432707210	3000	Economy	3400.00
0005433194883	3000	Economy	3400.00
0005433124183	3000	Economy	3400.00
0005432707205	3000	Economy	3400.00
0005433124118	3000	Economy	3400.00
0005433124113	3000	Economy	3400.00
0005432217825	3000	Economy	3400.00
0005433124097	3000	Economy	3400.00
0005433124182	3000	Economy	3400.00
0005433124093	3000	Economy	3400.00
0005432707220	3000	Economy	3400.00
0005433124007	3000	Economy	3400.00
0005432707221	3000	Economy	3400.00
0005433124157	3000	Economy	3400.00
0005433124156	3000	Economy	3400.00
0005432706932	29936	Business	10300.00
0005432881069	29936	Business	10300.00
0005433124268	29936	Business	10300.00
0005433124275	29936	Business	10300.00
0005432693632	29936	Business	10300.00
0005432693613	29936	Business	10300.00
0005433124280	29936	Business	10300.00
0005432693604	29936	Business	10300.00
0005432707071	29936	Business	10300.00
0005432707072	29936	Business	10300.00
0005432693608	29936	Business	10300.00
0005432707073	29936	Business	10300.00
0005433124277	29936	Economy	3400.00
0005432881074	29936	Economy	3400.00
0005432693606	29936	Economy	3400.00
0005432707030	29936	Economy	3400.00
0005432881065	29936	Economy	3400.00
0005432693618	29936	Economy	3400.00
0005433124279	29936	Economy	3400.00
0005432693627	29936	Economy	3400.00
0005433124273	29936	Economy	3400.00
0005432706940	29936	Economy	3400.00
0005432707131	29936	Economy	3800.00
0005433124284	29936	Economy	3800.00
0005432707014	29936	Economy	3800.00
0005432706931	29936	Economy	3800.00
0005432881072	29936	Economy	3800.00
0005432707013	29936	Economy	3400.00
0005432693621	29936	Economy	3400.00
0005432693620	29936	Economy	3400.00
0005432693630	29936	Economy	3400.00
0005433124265	29936	Economy	3400.00
0005433124266	29936	Economy	3400.00
0005432881066	29936	Economy	3400.00
0005432706834	29936	Economy	3400.00
0005433124278	29936	Economy	3400.00
0005432881064	29936	Economy	3400.00
0005432693607	29936	Economy	3400.00
0005432881071	29936	Economy	3400.00
0005433124267	29936	Economy	3400.00
0005432707069	29936	Economy	3400.00
0005432693614	29936	Economy	3400.00
0005432707070	29936	Economy	3400.00
0005432707012	29936	Economy	3400.00
0005432706833	29936	Economy	3400.00
0005432693628	29936	Economy	3400.00
0005432706895	29936	Economy	3400.00
0005432881061	29936	Economy	3400.00
0005432706958	29936	Economy	3400.00
0005432707015	29936	Economy	3400.00
0005432693611	29936	Economy	3400.00
0005432693619	29936	Economy	3400.00
0005432881067	29936	Economy	3400.00
0005433124272	29936	Economy	3400.00
0005432693617	29936	Economy	3400.00
0005432693625	29936	Economy	3400.00
0005432881063	29936	Economy	3400.00
0005432706841	29936	Economy	3400.00
0005432693605	29936	Economy	3400.00
0005432881068	29936	Economy	3400.00
0005432693609	29936	Economy	3400.00
0005432707090	29936	Economy	3400.00
0005433124283	29936	Economy	3400.00
0005433124270	29936	Economy	3400.00
0005432693622	29936	Economy	3400.00
0005432693623	29936	Economy	3400.00
0005433124276	29936	Economy	3400.00
0005432693616	29936	Economy	3400.00
0005433124281	29936	Economy	3400.00
0005433124282	29936	Economy	3400.00
0005432707091	29936	Economy	3400.00
0005432693603	29936	Economy	3400.00
0005432693600	29936	Economy	3400.00
0005432693629	29936	Economy	3400.00
0005432881075	29936	Economy	3400.00
0005432693610	29936	Economy	3400.00
0005433124274	29936	Economy	3400.00
0005433124271	29936	Economy	3400.00
0005432881070	29936	Economy	3400.00
0005433124269	29936	Economy	3400.00
0005433124264	29936	Economy	3400.00
0005432693624	29936	Economy	3400.00
0005432706949	29936	Economy	3400.00
0005432693626	29936	Economy	3400.00
0005432707089	29936	Economy	3400.00
0005432707066	29936	Economy	3400.00
0005432881073	29936	Economy	3400.00
0005432693631	29936	Economy	3400.00
0005432693601	29936	Economy	3400.00
0005432707132	29936	Economy	3400.00
0005432706941	29936	Economy	3400.00
0005432693612	29936	Economy	3400.00
0005432693615	29936	Economy	3400.00
0005432693602	29936	Economy	3400.00
0005432881062	29936	Economy	3400.00
0005432706959	29936	Economy	3400.00
0005432707088	29936	Economy	3400.00
0005434980273	23685	Economy	4000.00
0005434988912	23685	Economy	4000.00
0005434980274	23685	Economy	3600.00
0005434980275	23685	Economy	3600.00
0005434980291	23685	Economy	3600.00
0005434980267	23685	Economy	3600.00
0005434988915	23685	Economy	3600.00
0005434980295	23685	Economy	3600.00
0005434980286	23685	Economy	3600.00
0005434980276	23685	Economy	3600.00
0005434988913	23685	Economy	3600.00
0005434980287	23685	Economy	3600.00
0005434980289	23685	Economy	3600.00
0005434980279	23685	Economy	3600.00
0005434980280	23685	Economy	3600.00
0005434980268	23685	Economy	3600.00
0005434980296	23685	Economy	3600.00
0005434980284	23685	Economy	3600.00
0005434980269	23685	Economy	3600.00
0005434980294	23685	Economy	3600.00
0005434980293	23685	Economy	3600.00
0005434988917	23685	Economy	3600.00
0005434980290	23685	Economy	3600.00
0005434980285	23685	Economy	3600.00
0005434980270	23685	Economy	3600.00
0005434980297	23685	Economy	3600.00
0005434988919	23685	Economy	3600.00
0005434980281	23685	Economy	3600.00
0005434980288	23685	Economy	3600.00
0005434988918	23685	Economy	3600.00
0005434980272	23685	Economy	3600.00
0005434988920	23685	Economy	3600.00
0005434988914	23685	Economy	3600.00
0005434980292	23685	Economy	3600.00
0005434980271	23685	Economy	3600.00
0005434980277	23685	Economy	3600.00
0005434980283	23685	Economy	3600.00
0005434980282	23685	Economy	3600.00
0005434988916	23685	Economy	3600.00
0005434980278	23685	Economy	3600.00
0005434980168	27564	Economy	4000.00
0005434988805	27564	Economy	4000.00
0005434980122	27564	Economy	3600.00
0005434988787	27564	Economy	3600.00
0005434988842	27564	Economy	3600.00
0005434988862	27564	Economy	3600.00
0005434979962	27564	Economy	3600.00
0005434988794	27564	Economy	3600.00
0005434979941	27564	Economy	3600.00
0005434988828	27564	Economy	3600.00
0005434988801	27564	Economy	3600.00
0005434988835	27564	Economy	3600.00
0005434979939	27564	Economy	3600.00
0005434979949	27564	Economy	3600.00
0005434988802	27564	Economy	3600.00
0005434979982	27564	Economy	3600.00
0005434979987	27564	Economy	3600.00
0005434979906	27564	Economy	3600.00
0005434980114	27564	Economy	3600.00
0005434988814	27564	Economy	3600.00
0005434980067	27564	Economy	3600.00
0005434988786	27564	Economy	3600.00
0005434979995	27564	Economy	3600.00
0005434979940	27564	Economy	3600.00
0005434988863	27564	Economy	3600.00
0005434988861	27564	Economy	3600.00
0005434979905	27564	Economy	3600.00
0005434979849	27564	Economy	3600.00
0005434988795	27564	Economy	3600.00
0005434988869	27564	Economy	3600.00
0005434979951	27564	Economy	3600.00
0005434979950	27564	Economy	3600.00
0005434980158	27564	Economy	3600.00
0005434979851	27564	Economy	3600.00
0005434979850	27564	Economy	3600.00
0005434988849	27564	Economy	3600.00
0005434980059	27564	Economy	3600.00
0005434302532	10271	Economy	21600.00
0005434302531	10271	Economy	19700.00
0005433113546	10271	Economy	19700.00
0005433111520	10271	Economy	19700.00
0005434302529	10271	Economy	19700.00
0005433113556	10271	Economy	19700.00
0005434302530	10271	Economy	19700.00
0005433113574	19590	Economy	19700.00
0005433113575	19590	Economy	19700.00
0005434302485	19590	Economy	19700.00
0005434302482	19590	Economy	19700.00
0005433113573	19590	Economy	19700.00
0005435070010	3547	Business	26900.00
0005435719036	3547	Business	26900.00
0005435925381	3547	Business	26900.00
0005435925423	3547	Business	26900.00
0005435069961	3547	Business	26900.00
0005435069981	3547	Business	26900.00
0005435719037	3547	Business	26900.00
0005435069968	3547	Business	26900.00
0005435069970	3547	Economy	9000.00
0005435925415	3547	Economy	9000.00
0005435925366	3547	Economy	9000.00
0005435070001	3547	Economy	9000.00
0005435069994	3547	Economy	9000.00
0005435925360	3547	Economy	9000.00
0005435925388	3547	Economy	9900.00
0005435069998	3547	Economy	9900.00
0005435069991	3547	Economy	9900.00
0005435069962	3547	Economy	9900.00
0005435069985	3547	Economy	9000.00
0005435719039	3547	Economy	9000.00
0005435070000	3547	Economy	9000.00
0005435069964	3547	Economy	9000.00
0005435925376	3547	Economy	9000.00
0005435070002	3547	Economy	9000.00
0005435069966	3547	Economy	9000.00
0005435069976	3547	Economy	9000.00
0005435069969	3547	Economy	9000.00
0005435069992	3547	Economy	9000.00
0005435925361	3547	Economy	9000.00
0005435069999	3547	Economy	9000.00
0005435069965	3547	Economy	9000.00
0005435070008	3547	Economy	9000.00
0005435070011	3547	Economy	9000.00
0005435925402	3547	Economy	9000.00
0005435069959	3547	Economy	9000.00
0005435719040	3547	Economy	9000.00
0005435069974	3547	Economy	9000.00
0005435069997	3547	Economy	9000.00
0005435069971	3547	Economy	9000.00
0005435925304	3547	Economy	9000.00
0005435069982	3547	Economy	9000.00
0005435069967	3547	Economy	9000.00
0005435069990	3547	Economy	9000.00
0005435925422	3547	Economy	9000.00
0005435069972	3547	Economy	9000.00
0005435925396	3547	Economy	9000.00
0005435070007	3547	Economy	9000.00
0005435069979	3547	Economy	9000.00
0005435925421	3547	Economy	9000.00
0005435070009	3547	Economy	9000.00
0005435069978	3547	Economy	9000.00
0005435069989	3547	Economy	9000.00
0005435069975	3547	Economy	9000.00
0005435069987	3547	Economy	9000.00
0005435069960	3547	Economy	9000.00
0005435925387	3547	Economy	9000.00
0005435070005	3547	Economy	9000.00
0005435069986	3547	Economy	9000.00
0005435069995	3547	Economy	9000.00
0005435070003	3547	Economy	9000.00
0005435069983	3547	Economy	9000.00
0005435069973	3547	Economy	9000.00
0005435719038	3547	Economy	9000.00
0005435069963	3547	Economy	9000.00
0005435069996	3547	Economy	9000.00
0005435069993	3547	Economy	9000.00
0005435069984	3547	Economy	9000.00
0005435070004	3547	Economy	9000.00
0005435069988	3547	Economy	9000.00
0005435069980	3547	Economy	9000.00
0005435069977	3547	Economy	9000.00
0005435070006	3547	Economy	9000.00
0005435069582	15325	Business	26900.00
0005435069613	15325	Business	26900.00
0005435069653	15325	Business	26900.00
0005435069332	15325	Business	26900.00
0005435069509	15325	Business	26900.00
0005435925535	15325	Business	26900.00
0005435069583	15325	Business	26900.00
0005435069634	15325	Business	26900.00
0005435069203	15325	Business	26900.00
0005435069510	15325	Business	26900.00
0005435069451	15325	Business	26900.00
0005435069204	15325	Economy	9000.00
0005435925532	15325	Economy	9000.00
0005435925530	15325	Economy	9000.00
0005435069686	15325	Economy	9000.00
0005435069428	15325	Economy	9000.00
0005435069437	15325	Economy	9000.00
0005435069424	15325	Economy	9000.00
0005435069574	15325	Economy	9000.00
0005435069470	15325	Economy	9000.00
0005435069316	15325	Economy	9900.00
0005435069273	15325	Economy	9900.00
0005435069635	15325	Economy	9900.00
0005435069471	15325	Economy	9900.00
0005435069256	15325	Economy	9000.00
0005435069614	15325	Economy	9000.00
0005435069610	15325	Economy	9000.00
0005435069455	15325	Economy	9000.00
0005435069465	15325	Economy	9000.00
0005435069397	15325	Economy	9000.00
0005435069445	15325	Economy	9000.00
0005435069607	15325	Economy	9000.00
0005435069630	15325	Economy	9000.00
0005435069507	15325	Economy	9000.00
0005435069418	15325	Economy	9000.00
0005435069315	15325	Economy	9000.00
0005435069464	15325	Economy	9000.00
0005435939911	15325	Economy	9000.00
0005435069603	15325	Economy	9000.00
0005435069579	15325	Economy	9000.00
0005435069711	15325	Economy	9000.00
0005435069257	15325	Economy	9000.00
0005435069446	15325	Economy	9000.00
0005435069439	15325	Economy	9000.00
0005435069482	15325	Economy	9000.00
0005435939914	15325	Economy	9000.00
0005435069333	15325	Economy	9000.00
0005435069276	15325	Economy	9000.00
0005435939913	15325	Economy	9000.00
0005435069580	15325	Economy	9000.00
0005435069512	15325	Economy	9000.00
0005435069497	15325	Economy	9000.00
0005435069612	15325	Economy	9000.00
0005435069423	15325	Economy	9000.00
0005435925534	15325	Economy	9000.00
0005435925533	15325	Economy	9000.00
0005435925536	15325	Economy	9000.00
0005435925531	15325	Economy	9000.00
0005435069673	15325	Economy	9000.00
0005435069355	15325	Economy	9000.00
0005435925528	15325	Economy	9000.00
0005435069604	15325	Economy	9000.00
0005435069801	15325	Economy	9000.00
0005435069463	15325	Economy	9000.00
0005435069324	15325	Economy	9000.00
0005435925529	15325	Economy	9000.00
0005435069407	15325	Economy	9000.00
0005435939912	15325	Economy	9000.00
0005435069654	15325	Economy	9000.00
0005435069511	15325	Economy	9000.00
0005435069406	15325	Economy	9000.00
0005432659741	18123	Economy	5900.00
0005432660853	18123	Economy	5900.00
0005432658628	18123	Economy	5900.00
0005432660855	18123	Economy	5900.00
0005432660854	18123	Economy	5900.00
0005432659743	18123	Economy	5900.00
0005432659742	18123	Economy	5900.00
0005432659744	18123	Economy	5900.00
0005432667463	26461	Economy	5900.00
0005432667466	26461	Economy	5900.00
0005432664147	26461	Economy	5900.00
0005432667474	26461	Economy	5900.00
0005432667477	26461	Economy	5900.00
0005432667462	26461	Economy	5900.00
0005432667475	26461	Economy	5900.00
0005432664153	26461	Economy	5900.00
0005433102539	134	Business	20000.00
0005433102514	134	Business	20000.00
0005433102581	134	Business	20000.00
0005433102505	134	Business	20000.00
0005433102583	134	Business	20000.00
0005432901728	134	Business	20000.00
0005433102582	134	Business	20000.00
0005433102451	134	Business	20000.00
0005432677612	134	Business	20000.00
0005432920056	134	Business	20000.00
0005433102525	134	Business	20000.00
0005432901753	134	Business	20000.00
0005433102644	134	Business	20000.00
0005433102564	134	Business	20000.00
0005433102661	134	Economy	7300.00
0005433102622	134	Economy	7300.00
0005432901751	134	Economy	7300.00
0005433102654	134	Economy	7300.00
0005432677611	134	Economy	7300.00
0005432920030	134	Economy	6700.00
0005432920184	134	Economy	6700.00
0005432901806	134	Economy	6700.00
0005432901791	134	Economy	6700.00
0005433102541	134	Economy	6700.00
0005433102588	134	Economy	6700.00
0005433102587	134	Economy	6700.00
0005432920083	134	Economy	6700.00
0005432901735	134	Economy	6700.00
0005432901800	134	Economy	6700.00
0005433102660	134	Economy	6700.00
0005433102655	134	Economy	6700.00
0005433102361	134	Economy	6700.00
0005433102522	134	Economy	6700.00
0005433102466	134	Economy	6700.00
0005433102632	134	Economy	6700.00
0005432901701	134	Economy	6700.00
0005432901702	134	Economy	6700.00
0005433102633	134	Economy	6700.00
0005433102542	134	Economy	6700.00
0005433102537	134	Economy	6700.00
0005433102613	134	Economy	6700.00
0005433102573	134	Economy	6700.00
0005433102615	134	Economy	6700.00
0005432157526	134	Economy	6700.00
0005433102625	134	Economy	6700.00
0005433102558	134	Economy	6700.00
0005432901810	134	Economy	6700.00
0005433102623	134	Economy	6700.00
0005433102500	134	Economy	6700.00
0005433102467	134	Economy	6700.00
0005433102372	134	Economy	6700.00
0005432901768	134	Economy	6700.00
0005433102450	134	Economy	6700.00
0005433102567	134	Economy	6700.00
0005433102496	134	Economy	6700.00
0005433102641	134	Economy	7300.00
0005433102589	134	Economy	7300.00
0005433102662	134	Economy	7300.00
0005432901712	134	Economy	7300.00
0005433102624	134	Economy	6700.00
0005432901752	134	Economy	6700.00
0005433102569	134	Economy	6700.00
0005433102653	134	Economy	7300.00
0005432901746	134	Economy	6700.00
0005432901761	134	Economy	6700.00
0005433102511	134	Economy	6700.00
0005433102618	134	Economy	6700.00
0005433102643	134	Economy	6700.00
0005433102536	134	Economy	6700.00
0005432677580	134	Economy	6700.00
0005432901737	134	Economy	6700.00
0005433102619	134	Economy	6700.00
0005432901799	134	Economy	6700.00
0005433102645	134	Economy	6700.00
0005432919990	134	Economy	6700.00
0005433102474	134	Economy	6700.00
0005433102420	134	Economy	6700.00
0005433102650	134	Economy	6700.00
0005433102371	134	Economy	6700.00
0005433102498	134	Economy	6700.00
0005432920044	134	Economy	6700.00
0005432677613	134	Economy	6700.00
0005433102590	134	Economy	6700.00
0005432920054	134	Economy	6700.00
0005433102649	134	Economy	6700.00
0005433102620	134	Economy	6700.00
0005432901787	134	Economy	6700.00
0005433102490	134	Economy	6700.00
0005433102530	134	Economy	6700.00
0005432901747	134	Economy	6700.00
0005432677581	134	Economy	6700.00
0005433102614	134	Economy	6700.00
0005432920055	134	Economy	6700.00
0005433102563	134	Economy	6700.00
0005433102521	134	Economy	6700.00
0005433102520	134	Economy	6700.00
0005433102552	134	Economy	6700.00
0005432901711	134	Economy	6700.00
0005432920017	134	Economy	6700.00
0005433102621	134	Economy	6700.00
0005432901801	134	Economy	6700.00
0005432920029	134	Economy	6700.00
0005432901684	134	Economy	6700.00
0005432817979	133	Business	20000.00
0005432262708	133	Business	20000.00
0005432262686	133	Business	20000.00
0005432262685	133	Business	20000.00
0005432262678	133	Business	20000.00
0005432756874	133	Business	20000.00
0005432817990	133	Business	20000.00
0005432262683	133	Business	20000.00
0005432262710	133	Business	20000.00
0005433476968	133	Business	20000.00
0005432818000	133	Business	20000.00
0005432262709	133	Business	20000.00
0005433476970	133	Business	20000.00
0005432817984	133	Business	20000.00
0005432817971	133	Business	20000.00
0005433476967	133	Business	20000.00
0005432817987	133	Business	20000.00
0005432756862	133	Business	20000.00
0005432756873	133	Business	20000.00
0005432262694	133	Business	20000.00
0005432262716	133	Economy	7300.00
0005433476958	133	Economy	7300.00
0005432817982	133	Economy	7300.00
0005432262689	133	Economy	6700.00
0005432207706	133	Economy	6700.00
0005432817993	133	Economy	6700.00
0005432262697	133	Economy	6700.00
0005432262692	133	Economy	6700.00
0005432817986	133	Economy	6700.00
0005432262723	133	Economy	6700.00
0005432817972	133	Economy	6700.00
0005432262687	133	Economy	6700.00
0005432817981	133	Economy	6700.00
0005432262705	133	Economy	6700.00
0005432262713	133	Economy	6700.00
0005432289044	133	Economy	6700.00
0005432817997	133	Economy	6700.00
0005432817973	133	Economy	6700.00
0005432817996	133	Economy	6700.00
0005432262704	133	Economy	6700.00
0005433476964	133	Economy	6700.00
0005432207703	133	Economy	6700.00
0005432817999	133	Economy	6700.00
0005432262700	133	Economy	6700.00
0005433476966	133	Economy	6700.00
0005432817985	133	Economy	6700.00
0005432262680	133	Economy	6700.00
0005433476959	133	Economy	6700.00
0005432262677	133	Economy	6700.00
0005432262696	133	Economy	6700.00
0005433476960	133	Economy	6700.00
0005432262702	133	Economy	6700.00
0005433476962	133	Economy	6700.00
0005432262688	133	Economy	6700.00
0005432262712	133	Economy	6700.00
0005432817998	133	Economy	6700.00
0005433476963	133	Economy	6700.00
0005432262721	133	Economy	6700.00
0005432262711	133	Economy	6700.00
0005432262693	133	Economy	6700.00
0005432262720	133	Economy	6700.00
0005432262703	133	Economy	6700.00
0005432262718	133	Economy	6700.00
0005432262684	133	Economy	7300.00
0005432817980	133	Economy	7300.00
0005432207704	133	Economy	7300.00
0005432753336	133	Economy	7300.00
0005432289045	133	Economy	6700.00
0005432817995	133	Economy	6700.00
0005432262679	133	Economy	6700.00
0005432817976	133	Economy	6700.00
0005432817975	133	Economy	6700.00
0005432262701	133	Economy	6700.00
0005432817992	133	Economy	6700.00
0005433476969	133	Economy	6700.00
0005432207705	133	Economy	6700.00
0005432817988	133	Economy	6700.00
0005432262719	133	Economy	6700.00
0005432262695	133	Economy	6700.00
0005432817978	133	Economy	6700.00
0005432262698	133	Economy	6700.00
0005432817994	133	Economy	6700.00
0005432756861	133	Economy	6700.00
0005432262690	133	Economy	6700.00
0005432262682	133	Economy	6700.00
0005432817977	133	Economy	6700.00
0005432753327	133	Economy	6700.00
0005432262691	133	Economy	6700.00
0005432753321	133	Economy	6700.00
0005432262681	133	Economy	6700.00
0005432262722	133	Economy	6700.00
0005433476965	133	Economy	6700.00
0005432262699	133	Economy	6700.00
0005433476961	133	Economy	6700.00
0005434153554	133	Economy	6700.00
0005432817991	133	Economy	6700.00
0005432817989	133	Economy	6700.00
0005432817974	133	Economy	6700.00
0005432818001	133	Economy	6700.00
0005432262714	133	Economy	6700.00
0005432262707	133	Economy	6700.00
0005432262715	133	Economy	6700.00
0005432262717	133	Economy	6700.00
0005432817983	133	Economy	6700.00
0005432262706	133	Economy	6700.00
0005432020738	8037	Business	20000.00
0005433103072	8037	Business	20000.00
0005433103081	8037	Business	20000.00
0005432753361	8037	Business	20000.00
0005432020730	8037	Business	20000.00
0005432020721	8037	Business	20000.00
0005432751586	8037	Business	20000.00
0005433103067	8037	Business	20000.00
0005433103049	8037	Business	20000.00
0005433103038	8037	Business	20000.00
0005433103083	8037	Business	20000.00
0005432920227	8037	Business	20000.00
0005432020728	8037	Business	20000.00
0005432020719	8037	Business	20000.00
0005433103055	8037	Business	20000.00
0005433103088	8037	Business	20000.00
0005432044574	8037	Business	20000.00
0005432677644	8037	Business	20000.00
0005432920222	8037	Business	20000.00
0005433103071	8037	Business	20000.00
0005433103063	8037	Business	20000.00
0005433103058	8037	Business	20000.00
0005433103064	8037	Business	20000.00
0005432753359	8037	Economy	7300.00
0005433103057	8037	Business	20000.00
0005432020716	8037	Economy	7300.00
0005433103097	8037	Economy	7300.00
0005433103048	8037	Economy	7300.00
0005432920218	8037	Economy	7300.00
0005432020713	8037	Economy	6700.00
0005433103070	8037	Economy	6700.00
0005432920226	8037	Economy	6700.00
0005432920224	8037	Economy	6700.00
0005433103037	8037	Economy	6700.00
0005433103050	8037	Economy	6700.00
0005432020736	8037	Economy	6700.00
0005433103082	8037	Economy	6700.00
0005433103053	8037	Economy	6700.00
0005433103062	8037	Economy	6700.00
0005432920217	8037	Economy	6700.00
0005433103060	8037	Economy	6700.00
0005433103069	8037	Economy	6700.00
0005433103061	8037	Economy	6700.00
0005433103043	8037	Economy	6700.00
0005433103087	8037	Economy	6700.00
0005432920219	8037	Economy	6700.00
0005433103077	8037	Economy	6700.00
0005433103052	8037	Economy	6700.00
0005432020726	8037	Economy	6700.00
0005433103080	8037	Economy	6700.00
0005432020733	8037	Economy	6700.00
0005433103091	8037	Economy	6700.00
0005432920213	8037	Economy	6700.00
0005432020735	8037	Economy	6700.00
0005433103099	8037	Economy	6700.00
0005432392052	8037	Economy	6700.00
0005432020717	8037	Economy	6700.00
0005433103102	8037	Economy	6700.00
0005432020722	8037	Economy	6700.00
0005433103101	8037	Economy	6700.00
0005432020723	8037	Economy	6700.00
0005433103042	8037	Economy	6700.00
0005432392053	8037	Economy	6700.00
0005433103047	8037	Economy	6700.00
0005433103079	8037	Economy	6700.00
0005433103040	8037	Economy	6700.00
0005432920212	8037	Economy	6700.00
0005432920214	8037	Economy	6700.00
0005432020734	8037	Economy	6700.00
0005432045648	8037	Economy	6700.00
0005433103092	8037	Economy	6700.00
0005432020732	8037	Economy	6700.00
0005432020714	8037	Economy	6700.00
0005432020725	8037	Economy	6700.00
0005433103046	8037	Economy	6700.00
0005432920215	8037	Economy	6700.00
0005433103051	8037	Economy	6700.00
0005432920225	8037	Economy	7300.00
0005433103103	8037	Economy	7300.00
0005433103054	8037	Economy	7300.00
0005432044572	8037	Economy	7300.00
0005433103076	8037	Economy	6700.00
0005433103066	8037	Economy	6700.00
0005433103073	8037	Economy	6700.00
0005432020731	8037	Economy	7300.00
0005432677643	8037	Economy	6700.00
0005433103078	8037	Economy	6700.00
0005433103085	8037	Economy	6700.00
0005432045647	8037	Economy	6700.00
0005433103045	8037	Economy	6700.00
0005432920228	8037	Economy	6700.00
0005433103095	8037	Economy	6700.00
0005432677642	8037	Economy	6700.00
0005432044573	8037	Economy	6700.00
0005433103075	8037	Economy	6700.00
0005433103096	8037	Economy	6700.00
0005432020718	8037	Economy	6700.00
0005433103074	8037	Economy	6700.00
0005432677645	8037	Economy	6700.00
0005432020729	8037	Economy	6700.00
0005433103090	8037	Economy	6700.00
0005433103056	8037	Economy	6700.00
0005432020739	8037	Economy	6700.00
0005433103098	8037	Economy	6700.00
0005433103086	8037	Economy	6700.00
0005432020720	8037	Economy	6700.00
0005432920216	8037	Economy	6700.00
0005432920221	8037	Economy	6700.00
0005433103100	8037	Economy	6700.00
0005432920223	8037	Economy	6700.00
0005433103059	8037	Economy	6700.00
0005432020737	8037	Economy	6700.00
0005433103065	8037	Economy	6700.00
0005433103068	8037	Economy	6700.00
0005433103039	8037	Economy	6700.00
0005433103093	8037	Economy	6700.00
0005432920210	8037	Economy	6700.00
0005433103084	8037	Economy	6700.00
0005433103089	8037	Economy	6700.00
0005432920209	8037	Economy	6700.00
0005432020727	8037	Economy	6700.00
0005432753360	8037	Economy	6700.00
0005433103094	8037	Economy	6700.00
0005432920229	8037	Economy	6700.00
0005432045649	8037	Economy	6700.00
0005432020715	8037	Economy	6700.00
0005433103041	8037	Economy	6700.00
0005432920211	8037	Economy	6700.00
0005432020724	8037	Economy	6700.00
0005433103044	8037	Economy	6700.00
0005432920220	8037	Economy	6700.00
0005432817811	8038	Business	20000.00
0005432901917	8038	Business	20000.00
0005432901906	8038	Business	20000.00
0005432817605	8038	Business	20000.00
0005432817720	8038	Business	20000.00
0005432817721	8038	Business	20000.00
0005432817647	8038	Business	20000.00
0005432901911	8038	Economy	7300.00
0005432901922	8038	Economy	7300.00
0005432817775	8038	Economy	7300.00
0005432901913	8038	Economy	6700.00
0005432817746	8038	Economy	6700.00
0005432817744	8038	Economy	6700.00
0005432901910	8038	Economy	6700.00
0005432901918	8038	Economy	6700.00
0005432817736	8038	Economy	6700.00
0005432901919	8038	Economy	6700.00
0005432901909	8038	Economy	6700.00
0005432901914	8038	Economy	6700.00
0005432817584	8038	Economy	6700.00
0005432817674	8038	Economy	6700.00
0005432901912	8038	Economy	6700.00
0005432817700	8038	Economy	7300.00
0005432901920	8038	Economy	7300.00
0005432901921	8038	Economy	6700.00
0005432817743	8038	Economy	6700.00
0005432817875	8038	Economy	7300.00
0005432817701	8038	Economy	6700.00
0005432901915	8038	Economy	6700.00
0005432817745	8038	Economy	6700.00
0005432817782	8038	Economy	6700.00
0005432817772	8038	Economy	6700.00
0005432901908	8038	Economy	6700.00
0005432817604	8038	Economy	6700.00
0005432002112	8038	Economy	6700.00
0005432817722	8038	Economy	6700.00
0005432817783	8038	Economy	6700.00
0005432901907	8038	Economy	6700.00
0005432817675	8038	Economy	6700.00
0005432817810	8038	Economy	6700.00
0005432002113	8038	Economy	6700.00
0005432901905	8038	Economy	6700.00
0005432901916	8038	Economy	6700.00
0005433870769	9692	Economy	6900.00
0005433870768	9692	Economy	6900.00
0005433870770	9692	Economy	6900.00
0005434175802	9692	Economy	6900.00
0005434175828	32376	Economy	6900.00
0005434175825	32376	Economy	6900.00
0005433870755	32376	Economy	6900.00
0005434175827	32376	Economy	6900.00
0005434175824	32376	Economy	6900.00
0005433870756	32376	Economy	6900.00
0005434175826	32376	Economy	6900.00
0005434879871	3488	Business	35000.00
0005434879841	3488	Business	35000.00
0005435902865	3488	Business	35000.00
0005432799958	3488	Business	35000.00
0005435127070	3488	Business	35000.00
0005434879880	3488	Business	35000.00
0005434879895	3488	Business	35000.00
0005435127069	3488	Business	35000.00
0005432799957	3488	Business	35000.00
0005434879851	3488	Business	35000.00
0005434938491	3488	Business	35000.00
0005435902931	3488	Business	35000.00
0005434879884	3488	Business	35000.00
0005434938493	3488	Business	35000.00
0005435902921	3488	Business	35000.00
0005434938475	3488	Business	35000.00
0005435127098	3488	Business	35000.00
0005434879908	3488	Business	35000.00
0005434879916	3488	Business	35000.00
0005435626506	3488	Business	35000.00
0005434427133	3488	Business	35000.00
0005435127063	3488	Business	35000.00
0005434879901	3488	Business	35000.00
0005434879839	3488	Business	35000.00
0005434938486	3488	Comfort	19900.00
0005435127065	3488	Comfort	19900.00
0005434879900	3488	Comfort	19900.00
0005432799948	3488	Comfort	19900.00
0005435127068	3488	Comfort	19900.00
0005435913950	3488	Comfort	19900.00
0005434879873	3488	Comfort	19900.00
0005434938476	3488	Comfort	19900.00
0005434879899	3488	Comfort	19900.00
0005432799950	3488	Comfort	19900.00
0005434427121	3488	Comfort	19900.00
0005432183505	3488	Comfort	19900.00
0005434879912	3488	Comfort	19900.00
0005432613932	3488	Comfort	19900.00
0005434879870	3488	Comfort	19900.00
0005435626491	3488	Comfort	19900.00
0005434879868	3488	Comfort	19900.00
0005434879840	3488	Comfort	19900.00
0005434427138	3488	Comfort	19900.00
0005435127095	3488	Comfort	19900.00
0005435127085	3488	Comfort	19900.00
0005434879876	3488	Comfort	19900.00
0005434879878	3488	Comfort	19900.00
0005435902852	3488	Comfort	19900.00
0005435626504	3488	Comfort	19900.00
0005434427125	3488	Comfort	19900.00
0005435626497	3488	Comfort	19900.00
0005434879903	3488	Comfort	19900.00
0005435127094	3488	Comfort	19900.00
0005434879836	3488	Comfort	19900.00
0005434879846	3488	Comfort	19900.00
0005435913955	3488	Economy	11700.00
0005435127077	3488	Economy	11700.00
0005432799959	3488	Economy	11700.00
0005435127097	3488	Economy	11700.00
0005434879848	3488	Economy	11700.00
0005434427114	3488	Economy	11700.00
0005435902893	3488	Economy	11700.00
0005432799955	3488	Economy	11700.00
0005434427131	3488	Economy	11700.00
0005435127088	3488	Economy	11700.00
0005435127080	3488	Economy	11700.00
0005434879904	3488	Economy	11700.00
0005434879828	3488	Economy	11700.00
0005434427132	3488	Economy	11700.00
0005432799964	3488	Economy	11700.00
0005434427111	3488	Economy	11700.00
0005434879842	3488	Economy	11700.00
0005435127090	3488	Economy	11700.00
0005434879892	3488	Economy	11700.00
0005432613934	3488	Economy	11700.00
0005435626500	3488	Economy	11700.00
0005434427126	3488	Economy	11700.00
0005434427130	3488	Economy	11700.00
0005434427119	3488	Economy	11700.00
0005435127066	3488	Economy	11700.00
0005434879863	3488	Economy	11700.00
0005432188666	3488	Economy	11700.00
0005434879877	3488	Economy	11700.00
0005434427124	3488	Economy	11700.00
0005435626493	3488	Economy	11700.00
0005435902965	3488	Economy	11700.00
0005435127102	3488	Economy	11700.00
0005434427117	3488	Economy	11700.00
0005435626494	3488	Economy	11700.00
0005435127089	3488	Economy	11700.00
0005434879850	3488	Economy	11700.00
0005435913954	3488	Economy	11700.00
0005434879874	3488	Economy	11700.00
0005434427129	3488	Economy	11700.00
0005435626488	3488	Economy	11700.00
0005435626496	3488	Economy	11700.00
0005435127081	3488	Economy	11700.00
0005435626490	3488	Economy	11700.00
0005435902894	3488	Economy	11700.00
0005434879918	3488	Economy	11700.00
0005432799940	3488	Economy	11700.00
0005432183504	3488	Economy	11700.00
0005434879914	3488	Economy	11700.00
0005434879832	3488	Economy	12800.00
0005435127099	3488	Economy	11700.00
0005435902791	3488	Economy	12800.00
0005434879902	3488	Economy	11700.00
0005434879862	3488	Economy	11700.00
0005434879881	3488	Economy	11700.00
0005435127073	3488	Economy	12800.00
0005434879894	3488	Economy	11700.00
0005434879834	3488	Economy	11700.00
0005432799962	3488	Economy	11700.00
0005434879855	3488	Economy	11700.00
0005435127079	3488	Economy	11700.00
0005434879919	3488	Economy	11700.00
0005434879845	3488	Economy	11700.00
0005434427115	3488	Economy	11700.00
0005434879852	3488	Economy	11700.00
0005432799941	3488	Economy	11700.00
0005434938480	3488	Economy	11700.00
0005434427137	3488	Economy	11700.00
0005434879831	3488	Economy	11700.00
0005435902930	3488	Economy	11700.00
0005435127103	3488	Economy	11700.00
0005434938492	3488	Economy	11700.00
0005435626505	3488	Economy	11700.00
0005435902772	3488	Economy	11700.00
0005434879859	3488	Economy	11700.00
0005434427112	3488	Economy	11700.00
0005432799961	3488	Economy	11700.00
0005434879915	3488	Economy	11700.00
0005432799942	3488	Economy	11700.00
0005435626502	3488	Economy	11700.00
0005434879827	3488	Economy	11700.00
0005434879909	3488	Economy	11700.00
0005434879879	3488	Economy	11700.00
0005432799946	3488	Economy	11700.00
0005434879847	3488	Economy	11700.00
0005434879896	3488	Economy	11700.00
0005432799960	3488	Economy	11700.00
0005432799939	3488	Economy	11700.00
0005435902864	3488	Economy	11700.00
0005434879887	3488	Economy	11700.00
0005432611774	3488	Economy	11700.00
0005435902821	3488	Economy	11700.00
0005434879910	3488	Economy	11700.00
0005432611773	3488	Economy	11700.00
0005432799953	3488	Economy	11700.00
0005435127083	3488	Economy	11700.00
0005434879864	3488	Economy	11700.00
0005434879869	3488	Economy	11700.00
0005435626503	3488	Economy	11700.00
0005435127067	3488	Economy	11700.00
0005432799949	3488	Economy	11700.00
0005432799944	3488	Economy	11700.00
0005435902854	3488	Economy	11700.00
0005434879857	3488	Economy	11700.00
0005434879906	3488	Economy	11700.00
0005435127072	3488	Economy	11700.00
0005435902853	3488	Economy	11700.00
0005434879854	3488	Economy	11700.00
0005434427118	3488	Economy	11700.00
0005435127076	3488	Economy	11700.00
0005434879866	3488	Economy	11700.00
0005434879829	3488	Economy	11700.00
0005434938483	3488	Economy	11700.00
0005432799956	3488	Economy	11700.00
0005435626492	3488	Economy	11700.00
0005435902795	3488	Economy	11700.00
0005435127082	3488	Economy	11700.00
0005434879844	3488	Economy	11700.00
0005435913958	3488	Economy	11700.00
0005434879843	3488	Economy	11700.00
0005434427120	3488	Economy	11700.00
0005434879856	3488	Economy	11700.00
0005434879913	3488	Economy	11700.00
0005435127075	3488	Economy	11700.00
0005434879920	3488	Economy	11700.00
0005435626489	3488	Economy	11700.00
0005434879888	3488	Economy	11700.00
0005434938482	3488	Economy	11700.00
0005434938473	3488	Economy	11700.00
0005432799952	3488	Economy	11700.00
0005434879830	3488	Economy	11700.00
0005434879853	3488	Economy	11700.00
0005434879883	3488	Economy	11700.00
0005435902966	3488	Economy	11700.00
0005435127093	3488	Economy	11700.00
0005435127096	3488	Economy	11700.00
0005432188664	3488	Economy	11700.00
0005434427135	3488	Economy	11700.00
0005434427128	3488	Economy	11700.00
0005434879886	3488	Economy	11700.00
0005435902851	3488	Economy	11700.00
0005434879907	3488	Economy	11700.00
0005434879893	3488	Economy	11700.00
0005432799938	3488	Economy	12800.00
0005434879921	3488	Economy	12800.00
0005435127101	3488	Economy	11700.00
0005434879917	3488	Economy	11700.00
0005435913960	3488	Economy	11700.00
0005434879838	3488	Economy	11700.00
0005434938488	3488	Economy	11700.00
0005432799943	3488	Economy	11700.00
0005434427127	3488	Economy	11700.00
0005435127091	3488	Economy	11700.00
0005435127100	3488	Economy	11700.00
0005435127104	3488	Economy	11700.00
0005434938481	3488	Economy	11700.00
0005434938489	3488	Economy	11700.00
0005434879875	3488	Economy	11700.00
0005434938477	3488	Economy	11700.00
0005434938484	3488	Economy	11700.00
0005434879872	3488	Economy	11700.00
0005434879858	3488	Economy	11700.00
0005434938490	3488	Economy	11700.00
0005434879897	3488	Economy	11700.00
0005435127064	3488	Economy	11700.00
0005435902796	3488	Economy	11700.00
0005432799951	3488	Economy	11700.00
0005432799937	3488	Economy	11700.00
0005434879911	3488	Economy	11700.00
0005435127086	3488	Economy	11700.00
0005435127071	3488	Economy	11700.00
0005434879833	3488	Economy	11700.00
0005434879905	3488	Economy	11700.00
0005435626495	3488	Economy	11700.00
0005434879860	3488	Economy	11700.00
0005434879891	3488	Economy	11700.00
0005434427136	3488	Economy	11700.00
0005434938487	3488	Economy	11700.00
0005432799963	3488	Economy	11700.00
0005435902892	3488	Economy	11700.00
0005435626501	3488	Economy	11700.00
0005435626498	3488	Economy	11700.00
0005434938474	3488	Economy	11700.00
0005434879885	3488	Economy	11700.00
0005432613933	3488	Economy	11700.00
0005435127074	3488	Economy	11700.00
0005434938478	3488	Economy	11700.00
0005434427116	3488	Economy	11700.00
0005434427139	3488	Economy	11700.00
0005434879867	3488	Economy	11700.00
0005434427113	3488	Economy	11700.00
0005435626499	3488	Economy	11700.00
0005435913953	3488	Economy	11700.00
0005434427122	3488	Economy	11700.00
0005434879882	3488	Economy	11700.00
0005435913957	3488	Economy	11700.00
0005435902790	3488	Economy	11700.00
0005432799945	3488	Economy	11700.00
0005434879861	3488	Economy	11700.00
0005435902812	3488	Economy	11700.00
0005435902863	3488	Economy	11700.00
0005434938485	3488	Economy	11700.00
0005434879826	3488	Economy	11700.00
0005434879889	3488	Economy	11700.00
0005434879835	3488	Economy	11700.00
0005434879837	3488	Economy	11700.00
0005435127084	3488	Economy	11700.00
0005434427110	3488	Economy	11700.00
0005435127078	3488	Economy	11700.00
0005432613931	3488	Economy	11700.00
0005434879865	3488	Economy	11700.00
0005435902833	3488	Economy	11700.00
0005434427123	3488	Economy	11700.00
0005434938479	3488	Economy	11700.00
0005434879849	3488	Economy	11700.00
0005434427134	3488	Economy	11700.00
0005432188665	3488	Economy	11700.00
0005435127092	3488	Economy	11700.00
0005435626487	3488	Economy	11700.00
0005435127087	3488	Economy	11700.00
0005432799954	3488	Economy	11700.00
0005432799947	3488	Economy	11700.00
0005434879890	3488	Economy	11700.00
0005435902822	3488	Economy	11700.00
0005434879898	3488	Economy	11700.00
0005434878978	14562	Business	35000.00
0005434879100	14562	Business	35000.00
0005434426798	14562	Business	35000.00
0005435913996	14562	Business	35000.00
0005435126777	14562	Business	35000.00
0005434878849	14562	Business	35000.00
0005434878967	14562	Business	35000.00
0005434879033	14562	Business	35000.00
0005434878590	14562	Business	35000.00
0005434878891	14562	Business	35000.00
0005434879460	14562	Business	35000.00
0005435626360	14562	Business	35000.00
0005435126860	14562	Business	35000.00
0005435914007	14562	Business	35000.00
0005434879107	14562	Business	35000.00
0005434879232	14562	Business	35000.00
0005434878776	14562	Business	35000.00
0005434938279	14562	Business	35000.00
0005434878869	14562	Business	35000.00
0005435914000	14562	Business	35000.00
0005432799653	14562	Comfort	19900.00
0005435126606	14562	Comfort	19900.00
0005435903020	14562	Comfort	19900.00
0005434878968	14562	Comfort	19900.00
0005435126894	14562	Comfort	19900.00
0005435903011	14562	Comfort	19900.00
0005434879373	14562	Comfort	19900.00
0005434938390	14562	Comfort	19900.00
0005434879008	14562	Comfort	19900.00
0005435126737	14562	Comfort	19900.00
0005435126848	14562	Comfort	19900.00
0005435903006	14562	Comfort	19900.00
0005435626359	14562	Comfort	19900.00
0005434878827	14562	Comfort	19900.00
0005434879317	14562	Comfort	19900.00
0005435626352	14562	Comfort	19900.00
0005434879256	14562	Comfort	19900.00
0005434878777	14562	Comfort	19900.00
0005434938334	14562	Comfort	19900.00
0005434426759	14562	Comfort	19900.00
0005434426741	14562	Comfort	19900.00
0005435126729	14562	Comfort	19900.00
0005434878599	14562	Comfort	19900.00
0005434426747	14562	Comfort	19900.00
0005435126849	14562	Comfort	19900.00
0005434879392	14562	Comfort	19900.00
0005432799727	14562	Economy	11700.00
0005435626342	14562	Economy	11700.00
0005434878848	14562	Economy	11700.00
0005434878674	14562	Economy	11700.00
0005434879168	14562	Economy	11700.00
0005435913997	14562	Economy	11700.00
0005434938355	14562	Economy	11700.00
0005435126730	14562	Economy	11700.00
0005434879133	14562	Economy	11700.00
0005432799769	14562	Economy	11700.00
0005434878878	14562	Economy	11700.00
0005435914002	14562	Economy	11700.00
0005435903021	14562	Economy	11700.00
0005435626292	14562	Economy	11700.00
0005432799711	14562	Economy	11700.00
0005434426719	14562	Economy	11700.00
0005434879205	14562	Economy	11700.00
0005434938368	14562	Economy	11700.00
0005434878994	14562	Economy	11700.00
0005434879092	14562	Economy	11700.00
0005435126594	14562	Economy	11700.00
0005435626299	14562	Economy	11700.00
0005435626326	14562	Economy	11700.00
0005435626301	14562	Economy	11700.00
0005434426919	14562	Economy	11700.00
0005435126798	14562	Economy	11700.00
0005434426800	14562	Economy	11700.00
0005434938369	14562	Economy	11700.00
0005434879493	14562	Economy	11700.00
0005434879007	14562	Economy	11700.00
0005435626296	14562	Economy	11700.00
0005434879088	14562	Economy	11700.00
0005435626344	14562	Economy	11700.00
0005435914006	14562	Economy	11700.00
0005435626291	14562	Economy	11700.00
0005435126616	14562	Economy	11700.00
0005434938256	14562	Economy	11700.00
0005435842342	14562	Economy	11700.00
0005435126770	14562	Economy	11700.00
0005434879148	14562	Economy	11700.00
0005434938242	14562	Economy	11700.00
0005434426794	14562	Economy	11700.00
0005435903013	14562	Economy	11700.00
0005434938303	14562	Economy	11700.00
0005435914004	14562	Economy	11700.00
0005435126859	14562	Economy	11700.00
0005434878673	14562	Economy	11700.00
0005434426864	14562	Economy	11700.00
0005434426901	14562	Economy	11700.00
0005434878871	14562	Economy	11700.00
0005434938255	14562	Economy	12800.00
0005435913999	14562	Economy	11700.00
0005432799709	14562	Economy	12800.00
0005434878979	14562	Economy	12800.00
0005434938404	14562	Economy	11700.00
0005432799760	14562	Economy	11700.00
0005434879365	14562	Economy	12800.00
0005434879390	14562	Economy	12800.00
0005434938344	14562	Economy	11700.00
0005434879389	14562	Economy	11700.00
0005435626295	14562	Economy	11700.00
0005432611750	14562	Economy	11700.00
0005434879110	14562	Economy	11700.00
0005434878909	14562	Economy	11700.00
0005435126728	14562	Economy	11700.00
0005434878836	14562	Economy	11700.00
0005435126605	14562	Economy	11700.00
0005434879144	14562	Economy	11700.00
0005434879487	14562	Economy	11700.00
0005434426799	14562	Economy	11700.00
0005434878977	14562	Economy	11700.00
0005435841838	14562	Economy	11700.00
0005435126618	14562	Economy	11700.00
0005434879080	14562	Economy	11700.00
0005434878714	14562	Economy	11700.00
0005434878890	14562	Economy	11700.00
0005434426636	14562	Economy	11700.00
0005435841837	14562	Economy	11700.00
0005434426776	14562	Economy	11700.00
0005432799779	14562	Economy	11700.00
0005435626289	14562	Economy	11700.00
0005434879327	14562	Economy	11700.00
0005434878969	14562	Economy	11700.00
0005435126633	14562	Economy	11700.00
0005435126718	14562	Economy	11700.00
0005435126559	14562	Economy	11700.00
0005435126617	14562	Economy	11700.00
0005435903007	14562	Economy	11700.00
0005434879438	14562	Economy	11700.00
0005435913998	14562	Economy	11700.00
0005434426745	14562	Economy	11700.00
0005432799647	14562	Economy	11700.00
0005435903016	14562	Economy	11700.00
0005435903010	14562	Economy	11700.00
0005434879461	14562	Economy	11700.00
0005432799761	14562	Economy	11700.00
0005434879598	14562	Economy	11700.00
0005435126585	14562	Economy	11700.00
0005434426915	14562	Economy	11700.00
0005435126638	14562	Economy	11700.00
0005435914005	14562	Economy	11700.00
0005435903009	14562	Economy	11700.00
0005435626300	14562	Economy	11700.00
0005434938241	14562	Economy	11700.00
0005434938403	14562	Economy	11700.00
0005434938285	14562	Economy	11700.00
0005435914001	14562	Economy	11700.00
0005432799796	14562	Economy	11700.00
0005435626311	14562	Economy	11700.00
0005435626290	14562	Economy	11700.00
0005434878694	14562	Economy	11700.00
0005434938367	14562	Economy	11700.00
0005432799685	14562	Economy	11700.00
0005432799707	14562	Economy	11700.00
0005432799708	14562	Economy	11700.00
0005434879134	14562	Economy	11700.00
0005434938286	14562	Economy	11700.00
0005435626329	14562	Economy	11700.00
0005432799770	14562	Economy	11700.00
0005432611749	14562	Economy	11700.00
0005435903017	14562	Economy	11700.00
0005434878771	14562	Economy	11700.00
0005434879057	14562	Economy	11700.00
0005434879108	14562	Economy	11700.00
0005434879391	14562	Economy	11700.00
0005432799732	14562	Economy	11700.00
0005435126607	14562	Economy	11700.00
0005432799777	14562	Economy	11700.00
0005432799609	14562	Economy	11700.00
0005434878495	14562	Economy	11700.00
0005435126727	14562	Economy	11700.00
0005434879462	14562	Economy	11700.00
0005434879196	14562	Economy	11700.00
0005434879129	14562	Economy	11700.00
0005432799755	14562	Economy	11700.00
0005435126639	14562	Economy	11700.00
0005434879000	14562	Economy	11700.00
0005434426916	14562	Economy	11700.00
0005434938375	14562	Economy	11700.00
0005435626294	14562	Economy	11700.00
0005435126534	14562	Economy	11700.00
0005434938318	14562	Economy	11700.00
0005434879374	14562	Economy	11700.00
0005435626353	14562	Economy	11700.00
0005435626278	14562	Economy	11700.00
0005435126584	14562	Economy	11700.00
0005432799776	14562	Economy	11700.00
0005435126560	14562	Economy	11700.00
0005432799754	14562	Economy	11700.00
0005432611740	14562	Economy	11700.00
0005432799756	14562	Economy	11700.00
0005434879131	14562	Economy	11700.00
0005432799686	14562	Economy	11700.00
0005434938353	14562	Economy	12800.00
0005434878676	14562	Economy	12800.00
0005432799627	14562	Economy	12800.00
0005432799795	14562	Economy	12800.00
0005432799640	14562	Economy	11700.00
0005434879212	14562	Economy	11700.00
0005432799791	14562	Economy	11700.00
0005434426932	14562	Economy	11700.00
0005435126681	14562	Economy	11700.00
0005435126731	14562	Economy	11700.00
0005435903004	14562	Economy	11700.00
0005434879147	14562	Economy	11700.00
0005434938298	14562	Economy	11700.00
0005435126556	14562	Economy	11700.00
0005435126702	14562	Economy	11700.00
0005434878675	14562	Economy	11700.00
0005435903018	14562	Economy	11700.00
0005434879087	14562	Economy	11700.00
0005435626328	14562	Economy	11700.00
0005435903005	14562	Economy	11700.00
0005432799693	14562	Economy	11700.00
0005434879244	14562	Economy	11700.00
0005432799790	14562	Economy	11700.00
0005435626343	14562	Economy	11700.00
0005432799757	14562	Economy	11700.00
0005434878689	14562	Economy	11700.00
0005435126651	14562	Economy	11700.00
0005434879185	14562	Economy	11700.00
0005435903014	14562	Economy	11700.00
0005434426939	14562	Economy	11700.00
0005435126533	14562	Economy	11700.00
0005434878993	14562	Economy	11700.00
0005434879243	14562	Economy	11700.00
0005435126738	14562	Economy	11700.00
0005434938424	14562	Economy	11700.00
0005435903022	14562	Economy	11700.00
0005435626302	14562	Economy	11700.00
0005434426900	14562	Economy	11700.00
0005434878981	14562	Economy	11700.00
0005435626293	14562	Economy	11700.00
0005432799677	14562	Economy	11700.00
0005434878813	14562	Economy	11700.00
0005434938370	14562	Economy	11700.00
0005434879128	14562	Economy	11700.00
0005434426918	14562	Economy	11700.00
0005432611739	14562	Economy	11700.00
0005435903015	14562	Economy	11700.00
0005434879242	14562	Economy	11700.00
0005434938302	14562	Economy	11700.00
0005434878845	14562	Economy	11700.00
0005434878701	14562	Economy	11700.00
0005434879072	14562	Economy	11700.00
0005435126719	14562	Economy	11700.00
0005434938372	14562	Economy	11700.00
0005435626285	14562	Economy	11700.00
0005434938376	14562	Economy	11700.00
0005432799717	14562	Economy	11700.00
0005432799768	14562	Economy	11700.00
0005432799608	14562	Economy	11700.00
0005434426917	14562	Economy	11700.00
0005432799753	14562	Economy	11700.00
0005435903012	14562	Economy	11700.00
0005432799635	14562	Economy	11700.00
0005434426883	14562	Economy	11700.00
0005434426893	14562	Economy	11700.00
0005434426867	14562	Economy	11700.00
0005435903019	14562	Economy	11700.00
0005434938299	14562	Economy	11700.00
0005434879312	14562	Economy	11700.00
0005432799626	14562	Economy	11700.00
0005432799771	14562	Economy	11700.00
0005434879204	14562	Economy	11700.00
0005435126591	14562	Economy	11700.00
0005435126796	14562	Economy	11700.00
0005434879001	14562	Economy	11700.00
0005434938341	14562	Economy	11700.00
0005435626327	14562	Economy	11700.00
0005432799724	14562	Economy	11700.00
0005435126756	14562	Economy	11700.00
0005435914003	14562	Economy	11700.00
0005432611741	14562	Economy	11700.00
0005434879192	14562	Economy	11700.00
0005434426758	14562	Economy	11700.00
0005435903008	14562	Economy	11700.00
0005434878881	14562	Economy	11700.00
0005434878639	14562	Economy	11700.00
0005435126641	14562	Economy	11700.00
0005432799733	14562	Economy	11700.00
0005434878959	14562	Economy	11700.00
0005434879324	14562	Economy	11700.00
0005434426695	14562	Economy	11700.00
0005434312354	3644	Economy	16300.00
0005434325853	3644	Economy	14800.00
0005434325849	3644	Economy	14800.00
0005434325854	3644	Economy	14800.00
0005434325847	3644	Economy	14800.00
0005434325855	3644	Economy	14800.00
0005435889964	3644	Economy	14800.00
0005434325856	3644	Economy	14800.00
0005435889957	3644	Economy	14800.00
0005434325848	3644	Economy	14800.00
0005434325850	3644	Economy	14800.00
0005434325851	3644	Economy	14800.00
0005434312355	3644	Economy	14800.00
0005434325852	3644	Economy	14800.00
0005434325846	3644	Economy	14800.00
0005435889963	3644	Economy	14800.00
0005434325742	15637	Economy	16300.00
0005434325774	15637	Economy	14800.00
0005435890000	15637	Economy	14800.00
0005435890004	15637	Economy	14800.00
0005435890003	15637	Economy	14800.00
0005435890002	15637	Economy	14800.00
0005434325739	15637	Economy	14800.00
0005435889999	15637	Economy	14800.00
0005434325740	15637	Economy	14800.00
0005435890001	15637	Economy	14800.00
0005434325765	15637	Economy	14800.00
0005435890005	15637	Economy	14800.00
0005435957954	613	Economy	4500.00
0005435957966	613	Economy	4100.00
0005433420463	613	Economy	4100.00
0005435957961	613	Economy	4100.00
0005435957965	613	Economy	4100.00
0005435957964	613	Economy	4100.00
0005435957963	613	Economy	4100.00
0005435957960	613	Economy	4100.00
0005433420456	613	Economy	4100.00
0005435957957	613	Economy	4100.00
0005435957953	613	Economy	4100.00
0005435957955	613	Economy	4100.00
0005435957958	613	Economy	4100.00
0005435957956	613	Economy	4100.00
0005435957952	613	Economy	4100.00
0005435957962	613	Economy	4100.00
0005433420455	613	Economy	4100.00
0005435957959	613	Economy	4100.00
0005433420460	613	Economy	4100.00
0005435957877	15174	Economy	4500.00
0005435957830	15174	Economy	4500.00
0005435957871	15174	Economy	4100.00
0005435957759	15174	Economy	4100.00
0005433420553	15174	Economy	4100.00
0005435957849	15174	Economy	4100.00
0005435957812	15174	Economy	4100.00
0005435957883	15174	Economy	4100.00
0005435957846	15174	Economy	4100.00
0005435957819	15174	Economy	4100.00
0005433420550	15174	Economy	4100.00
0005435957873	15174	Economy	4100.00
0005433420552	15174	Economy	4100.00
0005435957847	15174	Economy	4100.00
0005433420551	15174	Economy	4100.00
0005435957751	15174	Economy	4100.00
0005435957832	15174	Economy	4100.00
0005435957870	15174	Economy	4100.00
0005433420554	15174	Economy	4100.00
0005433420548	15174	Economy	4100.00
0005435957831	15174	Economy	4100.00
0005433420549	15174	Economy	4100.00
0005435957845	15174	Economy	4100.00
0005433420547	15174	Economy	4100.00
0005435629425	8935	Economy	10400.00
0005434247159	8935	Economy	10400.00
0005434247173	8935	Economy	10400.00
0005434247164	8935	Economy	10400.00
0005435629411	16023	Economy	10400.00
0005434247193	16023	Economy	10400.00
0005435629412	16023	Economy	10400.00
0005435629410	16023	Economy	10400.00
0005434247192	16023	Economy	10400.00
0005434247194	16023	Economy	10400.00
0005434247191	16023	Economy	10400.00
0005434096753	11821	Economy	14700.00
0005434096752	11821	Economy	13400.00
0005434096764	11821	Economy	13400.00
0005434096751	11821	Economy	13400.00
0005434096754	11821	Economy	13400.00
0005434096750	11821	Economy	13400.00
0005434096775	20166	Economy	13400.00
0005434096778	20166	Economy	13400.00
0005434096777	20166	Economy	13400.00
0005434096776	20166	Economy	13400.00
0005434096773	20166	Economy	13400.00
0005434096774	20166	Economy	13400.00
0005435229539	25114	Business	87700.00
0005432645997	25114	Business	87700.00
0005435229541	25114	Business	87700.00
0005435229557	25114	Business	87700.00
0005432646006	25114	Business	87700.00
0005432646126	25114	Business	87700.00
0005435229550	25114	Economy	29200.00
0005432645999	25114	Economy	29200.00
0005432646086	25114	Economy	29200.00
0005432646142	25114	Economy	29200.00
0005435229556	25114	Economy	29200.00
0005435229546	25114	Economy	29200.00
0005432646033	25114	Economy	29200.00
0005432646075	25114	Economy	29200.00
0005432646024	25114	Economy	32200.00
0005432646081	25114	Economy	32200.00
0005432646141	25114	Economy	32200.00
0005432646036	25114	Economy	29200.00
0005435229536	25114	Economy	29200.00
0005432646084	25114	Economy	29200.00
0005432645988	25114	Economy	29200.00
0005432646127	25114	Economy	29200.00
0005432646021	25114	Economy	29200.00
0005432646128	25114	Economy	29200.00
0005435229553	25114	Economy	29200.00
0005435229548	25114	Economy	29200.00
0005435229538	25114	Economy	29200.00
0005432646082	25114	Economy	29200.00
0005432646012	25114	Economy	29200.00
0005435229542	25114	Economy	29200.00
0005435229544	25114	Economy	29200.00
0005435229555	25114	Economy	29200.00
0005432646073	25114	Economy	29200.00
0005435229540	25114	Economy	29200.00
0005432646091	25114	Economy	29200.00
0005432646079	25114	Economy	29200.00
0005432646089	25114	Economy	29200.00
0005432646110	25114	Economy	29200.00
0005435229551	25114	Economy	29200.00
0005435229547	25114	Economy	29200.00
0005432646122	25114	Economy	29200.00
0005432646007	25114	Economy	29200.00
0005432646077	25114	Economy	29200.00
0005432646000	25114	Economy	29200.00
0005432646123	25114	Economy	29200.00
0005435229537	25114	Economy	29200.00
0005432645987	25114	Economy	29200.00
0005432646106	25114	Economy	29200.00
0005435229545	25114	Economy	29200.00
0005435229549	25114	Economy	29200.00
0005432646083	25114	Economy	29200.00
0005432646078	25114	Economy	29200.00
0005432645989	25114	Economy	29200.00
0005435229552	25114	Economy	29200.00
0005435229543	25114	Economy	29200.00
0005432646061	25114	Economy	29200.00
0005432646070	25114	Economy	29200.00
0005432646076	25114	Economy	29200.00
0005432646060	25114	Economy	29200.00
0005432646088	25114	Economy	29200.00
0005435229554	25114	Economy	29200.00
0005435797715	2830	Business	12600.00
0005435797719	2830	Business	12600.00
0005435797714	2830	Business	12600.00
0005435797723	2830	Business	12600.00
0005435797718	2830	Economy	4200.00
0005433404871	2830	Economy	4200.00
0005435797716	2830	Economy	4200.00
0005433404890	2830	Economy	4200.00
0005435797724	2830	Economy	4200.00
0005435797728	2830	Economy	4200.00
0005435797725	2830	Economy	4200.00
0005435797720	2830	Economy	4200.00
0005435797722	2830	Economy	4200.00
0005435797727	2830	Economy	4200.00
0005433404872	2830	Economy	4200.00
0005435797721	2830	Economy	4200.00
0005435797726	2830	Economy	4200.00
0005435797717	2830	Economy	4200.00
0005435797616	29321	Business	12600.00
0005435797611	29321	Business	12600.00
0005433404944	29321	Business	12600.00
0005435797637	29321	Business	12600.00
0005433404942	29321	Business	12600.00
0005435797586	29321	Business	12600.00
0005433404943	29321	Economy	4200.00
0005435797636	29321	Economy	4600.00
0005435797588	29321	Economy	4200.00
0005435797617	29321	Economy	4200.00
0005435797647	29321	Economy	4200.00
0005435797659	29321	Economy	4200.00
0005433404939	29321	Economy	4200.00
0005435797589	29321	Economy	4200.00
0005433404938	29321	Economy	4200.00
0005435797672	29321	Economy	4200.00
0005435797591	29321	Economy	4200.00
0005435797569	29321	Economy	4200.00
0005435797600	29321	Economy	4200.00
0005433404941	29321	Economy	4200.00
0005435797628	29321	Economy	4200.00
0005433404940	29321	Economy	4200.00
0005435797660	29321	Economy	4200.00
0005435797599	29321	Economy	4200.00
0005435797620	29321	Economy	4200.00
0005435797645	29321	Economy	4200.00
0005435797572	29321	Economy	4200.00
0005435797629	29321	Economy	4200.00
0005433404937	29321	Economy	4200.00
0005435376372	5789	Economy	6800.00
0005435376389	5789	Economy	6800.00
0005435376375	5789	Economy	6800.00
0005435376388	5789	Economy	6800.00
0005434948165	5793	Economy	6800.00
0005434948166	5793	Economy	6800.00
0005434948162	5793	Economy	6800.00
0005434948161	5793	Economy	6800.00
0005434948168	5793	Economy	6800.00
0005434948167	5793	Economy	6800.00
0005434948163	5793	Economy	6800.00
0005434948164	5793	Economy	6800.00
0005435376398	16374	Economy	6800.00
0005434948097	16374	Economy	6800.00
0005434948112	16374	Economy	6800.00
0005434948096	16374	Economy	6800.00
0005435376400	16374	Economy	6800.00
0005435376401	16374	Economy	6800.00
0005434948074	16374	Economy	6800.00
0005434948113	16374	Economy	6800.00
0005434948114	16374	Economy	6800.00
0005435376399	16374	Economy	6800.00
0005433961900	6943	Business	21400.00
0005433961886	6943	Business	21400.00
0005433961896	6943	Business	21400.00
0005433961874	6943	Business	21400.00
0005433961855	6943	Business	21400.00
0005433961885	6943	Business	21400.00
0005433961893	6943	Economy	7100.00
0005433961872	6943	Economy	7100.00
0005433961857	6943	Economy	7100.00
0005433961877	6943	Economy	7100.00
0005433961901	6943	Economy	7100.00
0005433961898	6943	Economy	7800.00
0005433961859	6943	Economy	7800.00
0005433961873	6943	Economy	7800.00
0005433961870	6943	Economy	7100.00
0005433961875	6943	Economy	7100.00
0005433961868	6943	Economy	7100.00
0005433961869	6943	Economy	7100.00
0005433961878	6943	Economy	7100.00
0005433961888	6943	Economy	7100.00
0005433961860	6943	Economy	7100.00
0005433961897	6943	Economy	7100.00
0005433961906	6943	Economy	7100.00
0005433961864	6943	Economy	7100.00
0005433961865	6943	Economy	7100.00
0005433961884	6943	Economy	7100.00
0005433961881	6943	Economy	7100.00
0005433961856	6943	Economy	7100.00
0005433961863	6943	Economy	7100.00
0005433961905	6943	Economy	7100.00
0005433961899	6943	Economy	7100.00
0005433961876	6943	Economy	7100.00
0005433961889	6943	Economy	7100.00
0005433961879	6943	Economy	7100.00
0005433961883	6943	Economy	7100.00
0005433961866	6943	Economy	7100.00
0005433961894	6943	Economy	7100.00
0005433961853	6943	Economy	7100.00
0005433961854	6943	Economy	7100.00
0005433961882	6943	Economy	7100.00
0005433961880	6943	Economy	7100.00
0005433961903	6943	Economy	7100.00
0005433961895	6943	Economy	7100.00
0005433961861	6943	Economy	7100.00
0005433961867	6943	Economy	7100.00
0005433961887	6943	Economy	7100.00
0005433961904	6943	Economy	7100.00
0005433961891	6943	Economy	7100.00
0005433961862	6943	Economy	7100.00
0005433961902	6943	Economy	7100.00
0005433961890	6943	Economy	7100.00
0005433961871	6943	Economy	7100.00
0005433961858	6943	Economy	7100.00
0005433961892	6943	Economy	7100.00
0005433961301	25704	Business	21400.00
0005433961231	25704	Business	21400.00
0005433961213	25704	Business	21400.00
0005433961275	25704	Business	21400.00
0005433961260	25704	Business	21400.00
0005433961317	25704	Business	21400.00
0005433961295	25704	Business	21400.00
0005433961177	25704	Business	21400.00
0005433961266	25704	Business	21400.00
0005433961235	25704	Economy	7100.00
0005433961290	25704	Economy	7100.00
0005433961274	25704	Economy	7100.00
0005433961087	25704	Economy	7100.00
0005433961313	25704	Economy	7100.00
0005433961296	25704	Economy	7100.00
0005433960981	25704	Economy	7100.00
0005433961299	25704	Economy	7800.00
0005433961302	25704	Economy	7800.00
0005433961139	25704	Economy	7800.00
0005433961109	25704	Economy	7100.00
0005433961209	25704	Economy	7100.00
0005433961314	25704	Economy	7100.00
0005433961251	25704	Economy	7100.00
0005433961236	25704	Economy	7100.00
0005433961223	25704	Economy	7100.00
0005433961020	25704	Economy	7100.00
0005433961289	25704	Economy	7100.00
0005433961045	25704	Economy	7100.00
0005433961138	25704	Economy	7100.00
0005433961095	25704	Economy	7100.00
0005433961185	25704	Economy	7100.00
0005433961267	25704	Economy	7100.00
0005433961279	25704	Economy	7100.00
0005433961198	25704	Economy	7100.00
0005433961232	25704	Economy	7100.00
0005433961312	25704	Economy	7100.00
0005433961132	25704	Economy	7100.00
0005433961216	25704	Economy	7100.00
0005433961210	25704	Economy	7100.00
0005433961074	25704	Economy	7100.00
0005433961190	25704	Economy	7100.00
0005433961191	25704	Economy	7100.00
0005433961051	25704	Economy	7100.00
0005433961318	25704	Economy	7100.00
0005433961201	25704	Economy	7100.00
0005433961135	25704	Economy	7100.00
0005433961140	25704	Economy	7100.00
0005433961205	25704	Economy	7100.00
0005433961265	25704	Economy	7100.00
0005433961178	25704	Economy	7100.00
0005433961134	25704	Economy	7100.00
0005433961264	25704	Economy	7100.00
0005433961077	25704	Economy	7100.00
0005433961250	25704	Economy	7100.00
0005433960906	25704	Economy	7100.00
0005433961303	25704	Economy	7100.00
0005433961133	25704	Economy	7100.00
0005433961212	25704	Economy	7100.00
0005433961076	25704	Economy	7100.00
0005433961224	25704	Economy	7100.00
0005433961046	25704	Economy	7100.00
0005433961145	25704	Economy	7100.00
0005433961007	25704	Economy	7100.00
0005435082861	24444	Economy	3900.00
0005435082849	24444	Economy	3900.00
0005435082844	24444	Economy	3900.00
0005435082862	24444	Economy	3900.00
0005435082859	24444	Economy	3900.00
0005435082853	24444	Economy	3900.00
0005435082843	24444	Economy	3900.00
0005435082919	26053	Economy	3900.00
0005435082924	26053	Economy	3900.00
0005435082916	26053	Economy	3900.00
0005435082918	26053	Economy	3900.00
0005435082921	26053	Economy	3900.00
0005435082925	26053	Economy	3900.00
0005435082917	26053	Economy	3900.00
0005435082922	26053	Economy	3900.00
0005435082926	26053	Economy	3900.00
0005435082923	26053	Economy	3900.00
0005435082920	26053	Economy	3900.00
0005434245481	4995	Business	18000.00
0005434245490	4995	Business	18000.00
0005434245489	4995	Business	18000.00
0005434245484	4995	Business	18000.00
0005434245506	4995	Business	18000.00
0005435286659	4995	Economy	6600.00
0005434245494	4995	Economy	6000.00
0005433534505	4995	Economy	6000.00
0005434245504	4995	Economy	6000.00
0005434245486	4995	Economy	6000.00
0005434245503	4995	Economy	6000.00
0005434245496	4995	Economy	6000.00
0005434245478	4995	Economy	6000.00
0005435286675	4995	Economy	6000.00
0005434245497	4995	Economy	6000.00
0005434245499	4995	Economy	6000.00
0005434245485	4995	Economy	6000.00
0005434245488	4995	Economy	6000.00
0005434245487	4995	Economy	6000.00
0005432166958	4995	Economy	6000.00
0005435286663	4995	Economy	6000.00
0005435286664	4995	Economy	6000.00
0005434245491	4995	Economy	6600.00
0005434245502	4995	Economy	6000.00
0005434245480	4995	Economy	6000.00
0005434245501	4995	Economy	6000.00
0005434245492	4995	Economy	6000.00
0005432166959	4995	Economy	6000.00
0005434245483	4995	Economy	6000.00
0005434245505	4995	Economy	6000.00
0005434245493	4995	Economy	6000.00
0005434245495	4995	Economy	6000.00
0005434245498	4995	Economy	6000.00
0005434245479	4995	Economy	6000.00
0005435286669	4995	Economy	6000.00
0005435286673	4995	Economy	6000.00
0005435286668	4995	Economy	6000.00
0005435286660	4995	Economy	6000.00
0005433534526	4995	Economy	6000.00
0005434245482	4995	Economy	6000.00
0005434245500	4995	Economy	6000.00
0005434245507	4995	Economy	6000.00
0005432106409	4996	Business	18000.00
0005433615972	4996	Business	18000.00
0005433615937	4996	Business	18000.00
0005432106379	4996	Business	18000.00
0005433615995	4996	Business	18000.00
0005432106382	4996	Business	18000.00
0005433616004	4996	Business	18000.00
0005432106384	4996	Business	18000.00
0005432106404	4996	Business	18000.00
0005433785596	4996	Business	18000.00
0005433615985	4996	Business	18000.00
0005433616005	4996	Business	18000.00
0005433615974	4996	Business	18000.00
0005432106408	4996	Business	18000.00
0005432106407	4996	Business	18000.00
0005433616002	4996	Business	18000.00
0005433785563	4996	Business	18000.00
0005432106395	4996	Business	18000.00
0005433785575	4996	Business	18000.00
0005432106419	4996	Business	18000.00
0005433616003	4996	Business	18000.00
0005433785562	4996	Business	18000.00
0005433615986	4996	Business	18000.00
0005432106423	4996	Business	18000.00
0005433615964	4996	Business	18000.00
0005433615950	4996	Business	18000.00
0005433785586	4996	Business	18000.00
0005433785591	4996	Business	18000.00
0005432106380	4996	Economy	6600.00
0005433785579	4996	Economy	6600.00
0005432106390	4996	Economy	6600.00
0005433785582	4996	Economy	6600.00
0005433615953	4996	Economy	6600.00
0005433615939	4996	Economy	6600.00
0005432666425	4996	Economy	6000.00
0005433615948	4996	Economy	6000.00
0005432106391	4996	Economy	6000.00
0005433615989	4996	Economy	6000.00
0005433615997	4996	Economy	6000.00
0005433615942	4996	Economy	6000.00
0005433615936	4996	Economy	6000.00
0005432106415	4996	Economy	6000.00
0005433785588	4996	Economy	6000.00
0005433785561	4996	Economy	6000.00
0005433785566	4996	Economy	6000.00
0005432106406	4996	Economy	6000.00
0005433615931	4996	Economy	6000.00
0005433615934	4996	Economy	6000.00
0005433615957	4996	Economy	6000.00
0005432106401	4996	Economy	6000.00
0005432106424	4996	Economy	6000.00
0005433615992	4996	Economy	6000.00
0005433785560	4996	Economy	6000.00
0005433615978	4996	Economy	6000.00
0005433785574	4996	Economy	6000.00
0005432106386	4996	Economy	6000.00
0005433615993	4996	Economy	6000.00
0005433615968	4996	Economy	6000.00
0005433615962	4996	Economy	6000.00
0005433785577	4996	Economy	6000.00
0005433785567	4996	Economy	6000.00
0005433615961	4996	Economy	6000.00
0005433785592	4996	Economy	6000.00
0005432106422	4996	Economy	6000.00
0005433615958	4996	Economy	6000.00
0005432145147	4996	Economy	6000.00
0005433785565	4996	Economy	6000.00
0005433615965	4996	Economy	6000.00
0005433785572	4996	Economy	6000.00
0005432106414	4996	Economy	6000.00
0005432667490	4996	Economy	6000.00
0005433615947	4996	Economy	6000.00
0005433785573	4996	Economy	6000.00
0005432106405	4996	Economy	6000.00
0005433615977	4996	Economy	6000.00
0005433615970	4996	Economy	6000.00
0005433616001	4996	Economy	6000.00
0005433785589	4996	Economy	6000.00
0005433615946	4996	Economy	6000.00
0005433785558	4996	Economy	6000.00
0005432106396	4996	Economy	6000.00
0005433616000	4996	Economy	6000.00
0005432106417	4996	Economy	6000.00
0005433785590	4996	Economy	6000.00
0005433785569	4996	Economy	6000.00
0005433615954	4996	Economy	6000.00
0005433615996	4996	Economy	6000.00
0005433785594	4996	Economy	6000.00
0005432106412	4996	Economy	6000.00
0005433615994	4996	Economy	6000.00
0005433785584	4996	Economy	6000.00
0005433785570	4996	Economy	6000.00
0005433615944	4996	Economy	6000.00
0005432106402	4996	Economy	6000.00
0005432665311	4996	Economy	6600.00
0005433615988	4996	Economy	6600.00
0005432106381	4996	Economy	6600.00
0005433615980	4996	Economy	6600.00
0005432106385	4996	Economy	6600.00
0005433785580	4996	Economy	6000.00
0005433615981	4996	Economy	6000.00
0005433615982	4996	Economy	6000.00
0005432106410	4996	Economy	6000.00
0005432106388	4996	Economy	6600.00
0005433615983	4996	Economy	6000.00
0005433615949	4996	Economy	6000.00
0005433785578	4996	Economy	6000.00
0005433615960	4996	Economy	6000.00
0005432106418	4996	Economy	6000.00
0005433615941	4996	Economy	6000.00
0005433615955	4996	Economy	6000.00
0005433615951	4996	Economy	6000.00
0005432106420	4996	Economy	6000.00
0005432666426	4996	Economy	6000.00
0005433615967	4996	Economy	6000.00
0005433615991	4996	Economy	6000.00
0005432106393	4996	Economy	6000.00
0005433615940	4996	Economy	6000.00
0005433615952	4996	Economy	6000.00
0005432106403	4996	Economy	6000.00
0005433615975	4996	Economy	6000.00
0005432666424	4996	Economy	6000.00
0005433615979	4996	Economy	6000.00
0005433785583	4996	Economy	6000.00
0005432106392	4996	Economy	6000.00
0005432106398	4996	Economy	6000.00
0005432106421	4996	Economy	6000.00
0005432667489	4996	Economy	6000.00
0005433615943	4996	Economy	6000.00
0005433785571	4996	Economy	6000.00
0005433615999	4996	Economy	6000.00
0005433785595	4996	Economy	6000.00
0005433785585	4996	Economy	6000.00
0005432106411	4996	Economy	6000.00
0005433615973	4996	Economy	6000.00
0005433615971	4996	Economy	6000.00
0005433785581	4996	Economy	6000.00
0005432106387	4996	Economy	6000.00
0005432106425	4996	Economy	6000.00
0005432106400	4996	Economy	6000.00
0005433615987	4996	Economy	6000.00
0005433785576	4996	Economy	6000.00
0005432106378	4996	Economy	6000.00
0005433785593	4996	Economy	6000.00
0005433615984	4996	Economy	6000.00
0005433615933	4996	Economy	6000.00
0005433615945	4996	Economy	6000.00
0005433615963	4996	Economy	6000.00
0005432106397	4996	Economy	6000.00
0005433615935	4996	Economy	6000.00
0005433615998	4996	Economy	6000.00
0005432106416	4996	Economy	6000.00
0005433615966	4996	Economy	6000.00
0005432145148	4996	Economy	6000.00
0005432106413	4996	Economy	6000.00
0005433615990	4996	Economy	6000.00
0005433615976	4996	Economy	6000.00
0005433615938	4996	Economy	6000.00
0005433785587	4996	Economy	6000.00
0005433615969	4996	Economy	6000.00
0005433785564	4996	Economy	6000.00
0005432106394	4996	Economy	6000.00
0005432106389	4996	Economy	6000.00
0005433785559	4996	Economy	6000.00
0005433615932	4996	Economy	6000.00
0005433615956	4996	Economy	6000.00
0005433785568	4996	Economy	6000.00
0005432106383	4996	Economy	6000.00
0005433615959	4996	Economy	6000.00
0005432106399	4996	Economy	6000.00
0005434149941	4998	Business	18000.00
0005434312337	4998	Business	18000.00
0005434265576	4998	Business	18000.00
0005433688837	4998	Business	18000.00
0005434229764	4998	Business	18000.00
0005435007233	4998	Business	18000.00
0005434265596	4998	Business	18000.00
0005435007173	4998	Business	18000.00
0005434265583	4998	Business	18000.00
0005434173589	4998	Business	18000.00
0005434229766	4998	Business	18000.00
0005433815429	4998	Business	18000.00
0005434229765	4998	Business	18000.00
0005434265591	4998	Business	18000.00
0005434265600	4998	Business	18000.00
0005433815417	4998	Business	18000.00
0005435269776	4998	Business	18000.00
0005435007251	4998	Business	18000.00
0005434229755	4998	Business	18000.00
0005434149931	4998	Business	18000.00
0005434265595	4998	Economy	6600.00
0005435007202	4998	Economy	6600.00
0005434229770	4998	Economy	6600.00
0005434265592	4998	Economy	6600.00
0005434229762	4998	Economy	6000.00
0005435007271	4998	Economy	6000.00
0005434149940	4998	Economy	6000.00
0005432336164	4998	Economy	6000.00
0005435007211	4998	Economy	6000.00
0005434229768	4998	Economy	6000.00
0005435007178	4998	Economy	6000.00
0005434312329	4998	Economy	6000.00
0005434149936	4998	Economy	6000.00
0005432336136	4998	Economy	6000.00
0005434173588	4998	Economy	6000.00
0005434265599	4998	Economy	6000.00
0005434312336	4998	Economy	6000.00
0005435007355	4998	Economy	6000.00
0005434265587	4998	Economy	6000.00
0005434265597	4998	Economy	6000.00
0005434265598	4998	Economy	6000.00
0005435007184	4998	Economy	6000.00
0005435007172	4998	Economy	6000.00
0005432336148	4998	Economy	6000.00
0005433815421	4998	Economy	6000.00
0005433688836	4998	Economy	6000.00
0005432336132	4998	Economy	6000.00
0005435007281	4998	Economy	6000.00
0005433685543	4998	Economy	6000.00
0005432336162	4998	Economy	6000.00
0005434229754	4998	Economy	6000.00
0005434149937	4998	Economy	6000.00
0005434265586	4998	Economy	6000.00
0005434149938	4998	Economy	6000.00
0005434265579	4998	Economy	6000.00
0005434229769	4998	Economy	6000.00
0005434229761	4998	Economy	6000.00
0005434229771	4998	Economy	6000.00
0005434265581	4998	Economy	6000.00
0005434229772	4998	Economy	6000.00
0005434229767	4998	Economy	6000.00
0005434149932	4998	Economy	6000.00
0005434265580	4998	Economy	6000.00
0005434229763	4998	Economy	6000.00
0005434149934	4998	Economy	6000.00
0005434149939	4998	Economy	6000.00
0005434229757	4998	Economy	6600.00
0005435007310	4998	Economy	6600.00
0005435007337	4998	Economy	6600.00
0005434312339	4998	Economy	6600.00
0005435007311	4998	Economy	6000.00
0005432336155	4998	Economy	6000.00
0005434229759	4998	Economy	6000.00
0005434265588	4998	Economy	6000.00
0005435007270	4998	Economy	6000.00
0005434312338	4998	Economy	6000.00
0005432336176	4998	Economy	6000.00
0005435269767	4998	Economy	6000.00
0005432336147	4998	Economy	6000.00
0005434265577	4998	Economy	6000.00
0005435007269	4998	Economy	6000.00
0005433815413	4998	Economy	6000.00
0005434149933	4998	Economy	6000.00
0005434229760	4998	Economy	6000.00
0005434229752	4998	Economy	6000.00
0005434265575	4998	Economy	6000.00
0005432336146	4998	Economy	6000.00
0005434149930	4998	Economy	6000.00
0005434265582	4998	Economy	6000.00
0005434265594	4998	Economy	6000.00
0005435007179	4998	Economy	6000.00
0005434149935	4998	Economy	6000.00
0005435269769	4998	Economy	6000.00
0005434229774	4998	Economy	6000.00
0005434265584	4998	Economy	6000.00
0005434229753	4998	Economy	6000.00
0005435007174	4998	Economy	6000.00
0005434173591	4998	Economy	6000.00
0005434265578	4998	Economy	6000.00
0005435007243	4998	Economy	6000.00
0005435007312	4998	Economy	6000.00
0005435007242	4998	Economy	6000.00
0005434265589	4998	Economy	6000.00
0005435269768	4998	Economy	6000.00
0005435007308	4998	Economy	6000.00
0005435007309	4998	Economy	6000.00
0005434173590	4998	Economy	6000.00
0005434229773	4998	Economy	6000.00
0005434229758	4998	Economy	6000.00
0005434265585	4998	Economy	6000.00
0005435007280	4998	Economy	6000.00
0005434229756	4998	Economy	6000.00
0005434265593	4998	Economy	6000.00
0005435007138	4998	Economy	6000.00
0005435007356	4998	Economy	6000.00
0005433815416	4998	Economy	6000.00
0005434265590	4998	Economy	6000.00
0005433785366	8395	Business	18000.00
0005434245225	8395	Business	18000.00
0005433785362	8395	Business	18000.00
0005433785323	8395	Business	18000.00
0005434245382	8395	Business	18000.00
0005433785236	8395	Business	18000.00
0005434245227	8395	Business	18000.00
0005433785158	8395	Business	18000.00
0005434245335	8395	Business	18000.00
0005433785329	8395	Business	18000.00
0005433785083	8395	Business	18000.00
0005433785142	8395	Business	18000.00
0005434245377	8395	Business	18000.00
0005433785272	8395	Business	18000.00
0005434245226	8395	Business	18000.00
0005434245133	8395	Economy	6600.00
0005433785248	8395	Economy	6600.00
0005433785291	8395	Economy	6600.00
0005435269885	8395	Economy	6000.00
0005434245332	8395	Economy	6000.00
0005434245323	8395	Economy	6000.00
0005434245275	8395	Economy	6000.00
0005433785276	8395	Economy	6000.00
0005434245173	8395	Economy	6000.00
0005433785336	8395	Economy	6000.00
0005433785330	8395	Economy	6000.00
0005433785063	8395	Economy	6000.00
0005434245210	8395	Economy	6000.00
0005434245258	8395	Economy	6000.00
0005433785226	8395	Economy	6000.00
0005434245257	8395	Economy	6000.00
0005434245324	8395	Economy	6000.00
0005433785209	8395	Economy	6000.00
0005433785286	8395	Economy	6000.00
0005434245262	8395	Economy	6000.00
0005433785245	8395	Economy	6000.00
0005432659728	8395	Economy	6000.00
0005433785264	8395	Economy	6000.00
0005433785070	8395	Economy	6000.00
0005433785327	8395	Economy	6000.00
0005433785035	8395	Economy	6000.00
0005433785195	8395	Economy	6000.00
0005434245204	8395	Economy	6000.00
0005433785304	8395	Economy	6000.00
0005433785260	8395	Economy	6000.00
0005434245134	8395	Economy	6000.00
0005433785295	8395	Economy	6000.00
0005433785293	8395	Economy	6000.00
0005434245261	8395	Economy	6000.00
0005435269884	8395	Economy	6000.00
0005433785278	8395	Economy	6000.00
0005432659712	8395	Economy	6000.00
0005433785232	8395	Economy	6000.00
0005434245172	8395	Economy	6600.00
0005434245331	8395	Economy	6600.00
0005433785339	8395	Economy	6600.00
0005433785036	8395	Economy	6600.00
0005433785255	8395	Economy	6000.00
0005433785275	8395	Economy	6600.00
0005434245211	8395	Economy	6000.00
0005433785405	8395	Economy	6000.00
0005433785251	8395	Economy	6000.00
0005433785307	8395	Economy	6000.00
0005433785404	8395	Economy	6000.00
0005433785256	8395	Economy	6000.00
0005434245369	8395	Economy	6000.00
0005433785190	8395	Economy	6000.00
0005434245328	8395	Economy	6000.00
0005435269883	8395	Economy	6000.00
0005433785157	8395	Economy	6000.00
0005434245171	8395	Economy	6000.00
0005434245356	8395	Economy	6000.00
0005433785261	8395	Economy	6000.00
0005433785246	8395	Economy	6000.00
0005432659711	8395	Economy	6000.00
0005433785279	8395	Economy	6000.00
0005433785037	8395	Economy	6000.00
0005434245304	8395	Economy	6000.00
0005433785265	8395	Economy	6000.00
0005433785235	8395	Economy	6000.00
0005434245383	8395	Economy	6000.00
0005434245259	8395	Economy	6000.00
0005433785247	8395	Economy	6000.00
0005433785271	8395	Economy	6000.00
0005434245184	8395	Economy	6000.00
0005435269886	8395	Economy	6000.00
0005433785067	8395	Economy	6000.00
0005434245339	8395	Economy	6000.00
0005434245260	8395	Economy	6000.00
0005433785194	8395	Economy	6000.00
0005433615282	8394	Business	18000.00
0005433615566	8394	Business	18000.00
0005433615279	8394	Business	18000.00
0005433615365	8394	Business	18000.00
0005433614873	8394	Business	18000.00
0005433615387	8394	Business	18000.00
0005433615215	8394	Business	18000.00
0005433615554	8394	Business	18000.00
0005433615270	8394	Business	18000.00
0005433615325	8394	Business	18000.00
0005433615219	8394	Business	18000.00
0005433615430	8394	Business	18000.00
0005433615366	8394	Economy	6600.00
0005433615583	8394	Economy	6600.00
0005433615459	8394	Economy	6600.00
0005433615265	8394	Economy	6600.00
0005433615403	8394	Economy	6000.00
0005433615220	8394	Economy	6000.00
0005433615041	8394	Economy	6000.00
0005433614958	8394	Economy	6000.00
0005433615097	8394	Economy	6000.00
0005433615345	8394	Economy	6000.00
0005433615375	8394	Economy	6000.00
0005433615222	8394	Economy	6000.00
0005433615545	8394	Economy	6000.00
0005433615521	8394	Economy	6000.00
0005433615563	8394	Economy	6000.00
0005433615701	8394	Economy	6000.00
0005433614989	8394	Economy	6000.00
0005433615396	8394	Economy	6000.00
0005433615599	8394	Economy	6000.00
0005433615410	8394	Economy	6000.00
0005433615422	8394	Economy	6000.00
0005433615436	8394	Economy	6000.00
0005433615306	8394	Economy	6000.00
0005433615338	8394	Economy	6000.00
0005433615089	8394	Economy	6000.00
0005433615242	8394	Economy	6000.00
0005433615238	8394	Economy	6000.00
0005433615334	8394	Economy	6000.00
0005433615326	8394	Economy	6000.00
0005433615388	8394	Economy	6000.00
0005433615357	8394	Economy	6000.00
0005433615040	8394	Economy	6000.00
0005433615482	8394	Economy	6000.00
0005433615087	8394	Economy	6000.00
0005433615411	8394	Economy	6000.00
0005433615335	8394	Economy	6000.00
0005433615351	8394	Economy	6000.00
0005433615221	8394	Economy	6000.00
0005433615100	8394	Economy	6000.00
0005433615460	8394	Economy	6600.00
0005433615259	8394	Economy	6600.00
0005433615004	8394	Economy	6600.00
0005433615584	8394	Economy	6600.00
0005433615099	8394	Economy	6000.00
0005433615531	8394	Economy	6000.00
0005433614977	8394	Economy	6000.00
0005433615096	8394	Economy	6000.00
0005433615239	8394	Economy	6000.00
0005433615258	8394	Economy	6000.00
0005433615145	8394	Economy	6000.00
0005433615532	8394	Economy	6000.00
0005433615216	8394	Economy	6000.00
0005433615143	8394	Economy	6000.00
0005433615088	8394	Economy	6000.00
0005433615354	8394	Economy	6000.00
0005433615395	8394	Economy	6000.00
0005433615140	8394	Economy	6000.00
0005433615146	8394	Economy	6000.00
0005433615428	8394	Economy	6000.00
0005433615231	8394	Economy	6000.00
0005433614990	8394	Economy	6000.00
0005433615284	8394	Economy	6000.00
0005433615530	8394	Economy	6000.00
0005433615278	8394	Economy	6000.00
0005433615003	8394	Economy	6000.00
0005433615305	8394	Economy	6000.00
0005433615585	8394	Economy	6000.00
0005433615185	8394	Economy	6000.00
0005433615458	8394	Economy	6000.00
0005433615437	8394	Economy	6000.00
0005433615139	8394	Economy	6000.00
0005433615257	8394	Economy	6000.00
0005433615367	8394	Economy	6000.00
0005433615307	8394	Economy	6000.00
0005433615286	8394	Economy	6000.00
0005433615283	8394	Economy	6000.00
0005433615098	8394	Economy	6000.00
0005433615086	8394	Economy	6000.00
0005433614987	8394	Economy	6000.00
0005435007432	8392	Business	18000.00
0005434149805	8392	Business	18000.00
0005435286722	8392	Business	18000.00
0005434149845	8392	Business	18000.00
0005435286717	8392	Business	18000.00
0005432035431	8392	Business	18000.00
0005434265368	8392	Business	18000.00
0005435286718	8392	Business	18000.00
0005435007428	8392	Business	18000.00
0005432047616	8392	Business	18000.00
0005433690960	8392	Business	18000.00
0005434265320	8392	Business	18000.00
0005435007434	8392	Business	18000.00
0005435007417	8392	Business	18000.00
0005434229594	8392	Business	18000.00
0005435286715	8392	Business	18000.00
0005432035428	8392	Business	18000.00
0005433815471	8392	Business	18000.00
0005434265370	8392	Business	18000.00
0005434265384	8392	Business	18000.00
0005432035426	8392	Business	18000.00
0005432035434	8392	Business	18000.00
0005435286720	8392	Business	18000.00
0005434229502	8392	Business	18000.00
0005432336237	8392	Business	18000.00
0005434265383	8392	Economy	6600.00
0005434149814	8392	Economy	6600.00
0005435007421	8392	Economy	6600.00
0005435007441	8392	Economy	6600.00
0005432336242	8392	Economy	6600.00
0005435286712	8392	Economy	6600.00
0005434229577	8392	Economy	6000.00
0005433690961	8392	Economy	6000.00
0005433688847	8392	Economy	6000.00
0005433534536	8392	Economy	6000.00
0005434229534	8392	Economy	6000.00
0005435007427	8392	Economy	6000.00
0005432047619	8392	Economy	6000.00
0005434265315	8392	Economy	6000.00
0005432336245	8392	Economy	6000.00
0005432035432	8392	Economy	6000.00
0005432047618	8392	Economy	6000.00
0005434149863	8392	Economy	6000.00
0005435007420	8392	Economy	6000.00
0005432035438	8392	Economy	6000.00
0005432336240	8392	Economy	6000.00
0005434229671	8392	Economy	6000.00
0005432047615	8392	Economy	6000.00
0005432035435	8392	Economy	6000.00
0005434229531	8392	Economy	6000.00
0005435007433	8392	Economy	6000.00
0005432336241	8392	Economy	6000.00
0005433815473	8392	Economy	6000.00
0005434229511	8392	Economy	6000.00
0005434229639	8392	Economy	6000.00
0005434265397	8392	Economy	6000.00
0005434149782	8392	Economy	6000.00
0005432047617	8392	Economy	6000.00
0005435286721	8392	Economy	6000.00
0005434265307	8392	Economy	6000.00
0005432035437	8392	Economy	6000.00
0005435286714	8392	Economy	6000.00
0005435007418	8392	Economy	6000.00
0005432336246	8392	Economy	6000.00
0005434229523	8392	Economy	6000.00
0005435007435	8392	Economy	6000.00
0005433689949	8392	Economy	6000.00
0005432336236	8392	Economy	6000.00
0005432035433	8392	Economy	6000.00
0005433815472	8392	Economy	6000.00
0005434229513	8392	Economy	6000.00
0005435007429	8392	Economy	6000.00
0005432035442	8392	Economy	6000.00
0005432035440	8392	Economy	6000.00
0005434229674	8392	Economy	6000.00
0005434265331	8392	Economy	6000.00
0005434229595	8392	Economy	6000.00
0005434265345	8392	Economy	6000.00
0005434229485	8392	Economy	6000.00
0005434265445	8392	Economy	6000.00
0005432035425	8392	Economy	6000.00
0005432035444	8392	Economy	6000.00
0005434265377	8392	Economy	6000.00
0005432336238	8392	Economy	6000.00
0005434149867	8392	Economy	6000.00
0005432035445	8392	Economy	6600.00
0005435007440	8392	Economy	6600.00
0005433689948	8392	Economy	6600.00
0005432035430	8392	Economy	6600.00
0005432035418	8392	Economy	6600.00
0005435007423	8392	Economy	6000.00
0005435007425	8392	Economy	6000.00
0005432035439	8392	Economy	6000.00
0005435286713	8392	Economy	6000.00
0005434265371	8392	Economy	6000.00
0005435286719	8392	Economy	6000.00
0005434265411	8392	Economy	6000.00
0005433688846	8392	Economy	6000.00
0005432035420	8392	Economy	6000.00
0005434265428	8392	Economy	6000.00
0005434265353	8392	Economy	6000.00
0005432336248	8392	Economy	6000.00
0005434229542	8392	Economy	6000.00
0005432336239	8392	Economy	6000.00
0005432035422	8392	Economy	6000.00
0005435007430	8392	Economy	6000.00
0005435007419	8392	Economy	6000.00
0005435007426	8392	Economy	6000.00
0005434229547	8392	Economy	6000.00
0005434229583	8392	Economy	6000.00
0005435007439	8392	Economy	6000.00
0005432035441	8392	Economy	6000.00
0005432035424	8392	Economy	6000.00
0005432336244	8392	Economy	6000.00
0005432336243	8392	Economy	6000.00
0005434229582	8392	Economy	6000.00
0005432035419	8392	Economy	6000.00
0005434265264	8392	Economy	6000.00
0005432035427	8392	Economy	6000.00
0005434229556	8392	Economy	6000.00
0005435007422	8392	Economy	6000.00
0005435007437	8392	Economy	6000.00
0005434265438	8392	Economy	6000.00
0005435007431	8392	Economy	6000.00
0005434265318	8392	Economy	6000.00
0005434265382	8392	Economy	6000.00
0005432336247	8392	Economy	6000.00
0005435007436	8392	Economy	6000.00
0005435007424	8392	Economy	6000.00
0005434229578	8392	Economy	6000.00
0005434229564	8392	Economy	6000.00
0005435286716	8392	Economy	6000.00
0005434229545	8392	Economy	6000.00
0005434229548	8392	Economy	6000.00
0005434265316	8392	Economy	6000.00
0005434265372	8392	Economy	6000.00
0005434311254	8392	Economy	6000.00
0005434265317	8392	Economy	6000.00
0005434229530	8392	Economy	6000.00
0005432035436	8392	Economy	6000.00
0005434229612	8392	Economy	6000.00
0005432035421	8392	Economy	6000.00
0005435007438	8392	Economy	6000.00
0005434265446	8392	Economy	6000.00
0005432035423	8392	Economy	6000.00
0005434265449	8392	Economy	6000.00
0005434229546	8392	Economy	6000.00
0005432035429	8392	Economy	6000.00
0005432035443	8392	Economy	6000.00
0005434149859	8392	Economy	6000.00
0005434639479	12638	Economy	16200.00
0005433202625	12638	Economy	14800.00
0005434639600	12638	Economy	14800.00
0005434639503	12638	Economy	14800.00
0005433202628	12638	Economy	14800.00
0005434639504	12638	Economy	14800.00
0005433202629	12638	Economy	14800.00
0005433202624	12638	Economy	14800.00
0005433202617	12638	Economy	14800.00
0005434639595	12638	Economy	14800.00
0005434639409	12638	Economy	14800.00
0005433202626	12638	Economy	14800.00
0005433202621	12638	Economy	14800.00
0005433202618	12638	Economy	14800.00
0005433202619	12638	Economy	14800.00
0005434639548	12638	Economy	14800.00
0005434639505	12638	Economy	14800.00
0005434639546	12638	Economy	14800.00
0005434639523	12638	Economy	14800.00
0005434639571	12638	Economy	14800.00
0005434639506	12638	Economy	14800.00
0005433202622	12638	Economy	14800.00
0005433202627	12638	Economy	14800.00
0005433202623	12638	Economy	14800.00
0005433202620	12638	Economy	14800.00
0005433202616	12638	Economy	14800.00
0005434639522	12638	Economy	14800.00
0005433202615	12638	Economy	14800.00
0005433202480	23386	Economy	16200.00
0005434639758	23386	Economy	16200.00
0005433202486	23386	Economy	16200.00
0005434639733	23386	Economy	14800.00
0005434639738	23386	Economy	14800.00
0005434639737	23386	Economy	14800.00
0005434639742	23386	Economy	14800.00
0005434639751	23386	Economy	14800.00
0005433202475	23386	Economy	14800.00
0005433202503	23386	Economy	14800.00
0005434639736	23386	Economy	14800.00
0005433202478	23386	Economy	14800.00
0005434639740	23386	Economy	14800.00
0005434639746	23386	Economy	14800.00
0005434639752	23386	Economy	14800.00
0005434639749	23386	Economy	14800.00
0005433202519	23386	Economy	14800.00
0005433202433	23386	Economy	14800.00
0005433202479	23386	Economy	14800.00
0005434639743	23386	Economy	14800.00
0005434639739	23386	Economy	14800.00
0005433202453	23386	Economy	14800.00
0005433202445	23386	Economy	14800.00
0005434639741	23386	Economy	14800.00
0005434639754	23386	Economy	14800.00
0005433202434	23386	Economy	14800.00
0005434639732	23386	Economy	14800.00
0005434639757	23386	Economy	14800.00
0005434639735	23386	Economy	14800.00
0005434639755	23386	Economy	14800.00
0005433202484	23386	Economy	14800.00
0005434639745	23386	Economy	14800.00
0005433202409	23386	Economy	14800.00
0005434639744	23386	Economy	14800.00
0005434639747	23386	Economy	14800.00
0005434639748	23386	Economy	14800.00
0005433202476	23386	Economy	14800.00
0005433202485	23386	Economy	14800.00
0005434639750	23386	Economy	14800.00
0005434639734	23386	Economy	14800.00
0005434639756	23386	Economy	14800.00
0005434639753	23386	Economy	14800.00
0005432383463	21056	Business	18900.00
0005432329102	21056	Business	18900.00
0005432329121	21056	Business	18900.00
0005432328957	21056	Business	18900.00
0005432329023	21056	Business	18900.00
0005432329066	21056	Business	18900.00
0005432383349	21056	Business	18900.00
0005432383464	21056	Business	18900.00
0005432328911	21056	Business	18900.00
0005432329025	21056	Business	18900.00
0005432328976	21056	Business	18900.00
0005432383337	21056	Business	18900.00
0005432328932	21056	Economy	6300.00
0005432383431	21056	Economy	6300.00
0005432329237	21056	Economy	6300.00
0005432329063	21056	Economy	6300.00
0005432383415	21056	Economy	6300.00
0005432383467	21056	Economy	6300.00
0005432383348	21056	Economy	6300.00
0005432383491	21056	Economy	6300.00
0005432329042	21056	Economy	6300.00
0005432329093	21056	Economy	6300.00
0005432328928	21056	Economy	6900.00
0005432383452	21056	Economy	6900.00
0005432329079	21056	Economy	6900.00
0005432329088	21056	Economy	6900.00
0005432054355	21056	Economy	6900.00
0005432329113	21056	Economy	6300.00
0005432329058	21056	Economy	6300.00
0005432383541	21056	Economy	6300.00
0005432329362	21056	Economy	6300.00
0005432329147	21056	Economy	6300.00
0005432383453	21056	Economy	6300.00
0005432383542	21056	Economy	6300.00
0005432383507	21056	Economy	6300.00
0005432329208	21056	Economy	6300.00
0005432329065	21056	Economy	6300.00
0005432383318	21056	Economy	6300.00
0005432329242	21056	Economy	6300.00
0005432328960	21056	Economy	6300.00
0005432383454	21056	Economy	6300.00
0005432383502	21056	Economy	6300.00
0005432383354	21056	Economy	6300.00
0005432383432	21056	Economy	6300.00
0005432329180	21056	Economy	6300.00
0005432383476	21056	Economy	6300.00
0005432329030	21056	Economy	6300.00
0005432329153	21056	Economy	6300.00
0005432329179	21056	Economy	6300.00
0005432383508	21056	Economy	6300.00
0005432328978	21056	Economy	6300.00
0005432054357	21056	Economy	6300.00
0005432329162	21056	Economy	6300.00
0005432383506	21056	Economy	6300.00
0005432329135	21056	Economy	6300.00
0005432329137	21056	Economy	6300.00
0005432383367	21056	Economy	6300.00
0005432383364	21056	Economy	6300.00
0005432329071	21056	Economy	6300.00
0005432054356	21056	Economy	6300.00
0005432329022	21056	Economy	6300.00
0005432328912	21056	Economy	6300.00
0005432383524	21056	Economy	6300.00
0005432329101	21056	Economy	6300.00
0005432328950	21056	Economy	6300.00
0005432383414	21056	Economy	6300.00
0005432329029	21056	Economy	6300.00
0005432328866	21056	Economy	6300.00
0005432329064	21056	Economy	6300.00
0005432329043	21056	Economy	6300.00
0005432383366	21056	Economy	6300.00
0005432383133	21056	Economy	6300.00
0005432328975	21056	Economy	6300.00
0005432329007	21056	Economy	6300.00
0005432328930	21056	Economy	6300.00
0005432328929	21056	Economy	6300.00
0005432329173	21056	Economy	6300.00
0005432329138	21056	Economy	6300.00
0005432328977	21056	Economy	6300.00
0005432328910	21056	Economy	6300.00
0005432329072	21056	Economy	6300.00
0005432329067	21056	Economy	6300.00
0005432329161	21056	Economy	6300.00
0005432383525	21056	Economy	6300.00
0005432383416	21056	Economy	6300.00
0005432329184	21056	Economy	6300.00
0005432328979	21056	Economy	6300.00
0005432329157	21056	Economy	6300.00
0005432383430	21056	Economy	6300.00
0005432383134	21056	Economy	6300.00
0005432329089	21056	Economy	6300.00
0005432383340	21056	Economy	6300.00
0005432328951	21056	Economy	6300.00
0005432329062	21056	Economy	6300.00
0005432383462	21056	Economy	6300.00
0005432328865	21056	Economy	6300.00
0005432383365	21056	Economy	6300.00
0005432383808	31243	Business	18900.00
0005432329442	31243	Business	18900.00
0005432329462	31243	Business	18900.00
0005432329446	31243	Business	18900.00
0005432329480	31243	Business	18900.00
0005432383798	31243	Business	18900.00
0005432329474	31243	Business	18900.00
0005432329450	31243	Business	18900.00
0005432329456	31243	Business	18900.00
0005432329485	31243	Business	18900.00
0005432329464	31243	Business	18900.00
0005432383799	31243	Economy	6300.00
0005432383803	31243	Economy	6300.00
0005432287271	31243	Economy	6300.00
0005432383830	31243	Economy	6300.00
0005432383820	31243	Economy	6300.00
0005432383809	31243	Economy	6300.00
0005432329470	31243	Economy	6300.00
0005432329451	31243	Economy	6300.00
0005432329466	31243	Economy	6300.00
0005432287277	31243	Economy	6300.00
0005432383827	31243	Economy	6900.00
0005432383825	31243	Economy	6900.00
0005432383824	31243	Economy	6900.00
0005432329465	31243	Economy	6900.00
0005432383831	31243	Economy	6900.00
0005432329449	31243	Economy	6300.00
0005432383823	31243	Economy	6300.00
0005432329478	31243	Economy	6300.00
0005432287275	31243	Economy	6300.00
0005432329469	31243	Economy	6300.00
0005432329471	31243	Economy	6300.00
0005432383821	31243	Economy	6300.00
0005432329443	31243	Economy	6300.00
0005432329475	31243	Economy	6300.00
0005432329448	31243	Economy	6300.00
0005432383828	31243	Economy	6300.00
0005432383817	31243	Economy	6300.00
0005432329479	31243	Economy	6300.00
0005432383813	31243	Economy	6300.00
0005432329477	31243	Economy	6300.00
0005432329467	31243	Economy	6300.00
0005432383800	31243	Economy	6300.00
0005432383805	31243	Economy	6300.00
0005432383807	31243	Economy	6300.00
0005432329458	31243	Economy	6300.00
0005432383795	31243	Economy	6300.00
0005432329482	31243	Economy	6300.00
0005432329463	31243	Economy	6300.00
0005432383819	31243	Economy	6300.00
0005432329468	31243	Economy	6300.00
0005432383812	31243	Economy	6300.00
0005432383797	31243	Economy	6300.00
0005432383816	31243	Economy	6300.00
0005432329476	31243	Economy	6300.00
0005432329486	31243	Economy	6300.00
0005432329460	31243	Economy	6300.00
0005432383806	31243	Economy	6300.00
0005432383792	31243	Economy	6300.00
0005432383826	31243	Economy	6300.00
0005432383793	31243	Economy	6300.00
0005432329454	31243	Economy	6300.00
0005432329453	31243	Economy	6300.00
0005432383796	31243	Economy	6300.00
0005432383794	31243	Economy	6300.00
0005432383811	31243	Economy	6300.00
0005432329455	31243	Economy	6300.00
0005432383814	31243	Economy	6300.00
0005432329473	31243	Economy	6300.00
0005432329487	31243	Economy	6300.00
0005432329459	31243	Economy	6300.00
0005432287274	31243	Economy	6300.00
0005432383810	31243	Economy	6300.00
0005432287272	31243	Economy	6300.00
0005432329452	31243	Economy	6300.00
0005432383818	31243	Economy	6300.00
0005432329481	31243	Economy	6300.00
0005432329444	31243	Economy	6300.00
0005432329461	31243	Economy	6300.00
0005432329483	31243	Economy	6300.00
0005432287273	31243	Economy	6300.00
0005432329445	31243	Economy	6300.00
0005432329484	31243	Economy	6300.00
0005432383815	31243	Economy	6300.00
0005432383801	31243	Economy	6300.00
0005432329440	31243	Economy	6300.00
0005432287276	31243	Economy	6300.00
0005432329447	31243	Economy	6300.00
0005432329441	31243	Economy	6300.00
0005432383829	31243	Economy	6300.00
0005432383802	31243	Economy	6300.00
0005432329472	31243	Economy	6300.00
0005432383804	31243	Economy	6300.00
0005432383822	31243	Economy	6300.00
0005432329457	31243	Economy	6300.00
0005432954079	27598	Business	89600.00
0005432954084	27598	Business	89600.00
0005432954081	27598	Business	89600.00
0005433642466	27598	Business	89600.00
0005433642409	27598	Business	89600.00
0005433642469	27598	Business	89600.00
0005432954074	27598	Economy	29900.00
0005433642465	27598	Economy	29900.00
0005432954077	27598	Economy	29900.00
0005433642423	27598	Economy	32800.00
0005432954078	27598	Economy	32800.00
0005433642430	27598	Economy	29900.00
0005433642456	27598	Economy	29900.00
0005433642368	27598	Economy	29900.00
0005432954076	27598	Economy	29900.00
0005433642447	27598	Economy	29900.00
0005433642497	27598	Economy	29900.00
0005432954073	27598	Economy	29900.00
0005432954087	27598	Economy	29900.00
0005432954082	27598	Economy	29900.00
0005433642512	27598	Economy	29900.00
0005433642384	27598	Economy	29900.00
0005432954075	27598	Economy	29900.00
0005432954086	27598	Economy	29900.00
0005433642508	27598	Economy	29900.00
0005433642455	27598	Economy	29900.00
0005433642509	27598	Economy	29900.00
0005432954085	27598	Economy	29900.00
0005433642496	27598	Economy	29900.00
0005432954080	27598	Economy	29900.00
0005433642503	27598	Economy	29900.00
0005433642483	27598	Economy	29900.00
0005433642459	27598	Economy	29900.00
0005433642471	27598	Economy	29900.00
0005433642464	27598	Economy	29900.00
0005433642367	27598	Economy	29900.00
0005432954083	27598	Economy	29900.00
0005433642379	27598	Economy	29900.00
0005433642484	27598	Economy	29900.00
0005433642385	27598	Economy	29900.00
0005432954088	27598	Economy	29900.00
0005432954089	27598	Economy	29900.00
0005433642394	27598	Economy	29900.00
0005432425253	13329	Business	12700.00
0005432425277	13329	Business	12700.00
0005432425266	13329	Business	12700.00
0005432425274	13329	Business	12700.00
0005432425265	13329	Business	12700.00
0005432425260	13329	Business	12700.00
0005432425263	13329	Business	12700.00
0005432425293	13329	Economy	4200.00
0005432425282	13329	Economy	4200.00
0005432425257	13329	Economy	4700.00
0005432425262	13329	Economy	4700.00
0005432425273	13329	Economy	4700.00
0005432425279	13329	Economy	4700.00
0005432425287	13329	Economy	4200.00
0005432425237	13329	Economy	4200.00
0005432425256	13329	Economy	4200.00
0005432425271	13329	Economy	4200.00
0005432425290	13329	Economy	4200.00
0005432425285	13329	Economy	4200.00
0005432425259	13329	Economy	4200.00
0005432425242	13329	Economy	4200.00
0005432425258	13329	Economy	4200.00
0005432425267	13329	Economy	4200.00
0005432425275	13329	Economy	4200.00
0005432425249	13329	Economy	4200.00
0005432425241	13329	Economy	4200.00
0005432425239	13329	Economy	4200.00
0005432425278	13329	Economy	4200.00
0005432425246	13329	Economy	4200.00
0005432425252	13329	Economy	4200.00
0005432425286	13329	Economy	4200.00
0005432425270	13329	Economy	4200.00
0005432425276	13329	Economy	4200.00
0005432425251	13329	Economy	4200.00
0005432425248	13329	Economy	4200.00
0005432425272	13329	Economy	4200.00
0005432425291	13329	Economy	4200.00
0005432425236	13329	Economy	4200.00
0005432425268	13329	Economy	4200.00
0005432425261	13329	Economy	4200.00
0005432425292	13329	Economy	4200.00
0005432425244	13329	Economy	4200.00
0005432425264	13329	Economy	4200.00
0005432425247	13329	Economy	4200.00
0005432425255	13329	Economy	4200.00
0005432425283	13329	Economy	4200.00
0005432425289	13329	Economy	4200.00
0005432425281	13329	Economy	4200.00
0005432425245	13329	Economy	4200.00
0005432425288	13329	Economy	4200.00
0005432425280	13329	Economy	4200.00
0005432425269	13329	Economy	4200.00
0005432425238	13329	Economy	4200.00
0005432425254	13329	Economy	4200.00
0005432425240	13329	Economy	4200.00
0005432425243	13329	Economy	4200.00
0005432425284	13329	Economy	4200.00
0005432425250	13329	Economy	4200.00
0005432424681	30715	Business	12700.00
0005432424679	30715	Business	12700.00
0005432424834	30715	Business	12700.00
0005432424862	30715	Business	12700.00
0005432424644	30715	Business	12700.00
0005432424759	30715	Economy	4200.00
0005432424621	30715	Economy	4200.00
0005432424735	30715	Economy	4200.00
0005432424797	30715	Economy	4200.00
0005432424783	30715	Economy	4200.00
0005432424818	30715	Economy	4200.00
0005432424835	30715	Economy	4200.00
0005432424829	30715	Economy	4700.00
0005432424828	30715	Economy	4700.00
0005432424588	30715	Economy	4700.00
0005432424643	30715	Economy	4200.00
0005432424746	30715	Economy	4200.00
0005432424809	30715	Economy	4200.00
0005432424745	30715	Economy	4200.00
0005432424623	30715	Economy	4200.00
0005432424747	30715	Economy	4200.00
0005432424701	30715	Economy	4200.00
0005432424822	30715	Economy	4200.00
0005432424811	30715	Economy	4200.00
0005432424628	30715	Economy	4200.00
0005432424744	30715	Economy	4200.00
0005432424802	30715	Economy	4200.00
0005432424855	30715	Economy	4200.00
0005432424810	30715	Economy	4200.00
0005432424848	30715	Economy	4200.00
0005432424856	30715	Economy	4200.00
0005432424697	30715	Economy	4200.00
0005432424836	30715	Economy	4200.00
0005432424854	30715	Economy	4200.00
0005432424770	30715	Economy	4200.00
0005432424833	30715	Economy	4200.00
0005432424727	30715	Economy	4200.00
0005432424790	30715	Economy	4200.00
0005432424803	30715	Economy	4200.00
0005432424669	30715	Economy	4200.00
0005432424806	30715	Economy	4200.00
0005432424736	30715	Economy	4200.00
0005432424791	30715	Economy	4200.00
0005432424815	30715	Economy	4200.00
0005432424703	30715	Economy	4200.00
0005432424696	30715	Economy	4200.00
0005432822340	9593	Business	32600.00
0005432818001	9593	Business	32600.00
0005434186228	9593	Business	32600.00
0005432901780	9593	Business	32600.00
0005432817975	9593	Business	32600.00
0005432817998	9593	Business	32600.00
0005432817997	9593	Business	32600.00
0005434157560	9593	Business	32600.00
0005432822334	9593	Business	32600.00
0005432817979	9593	Business	32600.00
0005432817973	9593	Economy	10900.00
0005432901726	9593	Economy	10900.00
0005432901776	9593	Economy	10900.00
0005434448376	9593	Economy	10900.00
0005432289044	9593	Economy	10900.00
0005432817971	9593	Economy	10900.00
0005432901756	9593	Economy	10900.00
0005432817982	9593	Economy	11900.00
0005432901713	9593	Economy	11900.00
0005434186230	9593	Economy	11900.00
0005432901760	9593	Economy	11900.00
0005434186226	9593	Economy	10900.00
0005432817978	9593	Economy	10900.00
0005432817977	9593	Economy	10900.00
0005434157562	9593	Economy	10900.00
0005432818000	9593	Economy	10900.00
0005432901725	9593	Economy	10900.00
0005432901740	9593	Economy	10900.00
0005432822339	9593	Economy	10900.00
0005432817995	9593	Economy	10900.00
0005434186231	9593	Economy	10900.00
0005432817991	9593	Economy	10900.00
0005432817992	9593	Economy	10900.00
0005432901782	9593	Economy	10900.00
0005432817983	9593	Economy	10900.00
0005432901699	9593	Economy	10900.00
0005432817987	9593	Economy	10900.00
0005432289045	9593	Economy	10900.00
0005432822335	9593	Economy	10900.00
0005434448375	9593	Economy	10900.00
0005432822337	9593	Economy	10900.00
0005432817985	9593	Economy	10900.00
0005432817994	9593	Economy	10900.00
0005432901823	9593	Economy	10900.00
0005432901815	9593	Economy	10900.00
0005432901814	9593	Economy	10900.00
0005432817989	9593	Economy	10900.00
0005432901783	9593	Economy	10900.00
0005432817986	9593	Economy	10900.00
0005432817976	9593	Economy	10900.00
0005432822336	9593	Economy	10900.00
0005434157556	9593	Economy	10900.00
0005432817993	9593	Economy	10900.00
0005432817999	9593	Economy	10900.00
0005434186219	9593	Economy	10900.00
0005432817972	9593	Economy	10900.00
0005432822338	9593	Economy	10900.00
0005434157512	9593	Economy	10900.00
0005432901781	9593	Economy	10900.00
0005434186227	9593	Economy	10900.00
0005432817984	9593	Economy	10900.00
0005432901779	9593	Economy	10900.00
0005432817996	9593	Economy	10900.00
0005434186233	9593	Economy	10900.00
0005434448378	9593	Economy	10900.00
0005432901771	9593	Economy	10900.00
0005434448377	9593	Economy	10900.00
0005432817980	9593	Economy	10900.00
0005432817981	9593	Economy	10900.00
0005432901708	9593	Economy	10900.00
0005432901762	9593	Economy	10900.00
0005432817990	9593	Economy	10900.00
0005432817988	9593	Economy	10900.00
0005432901798	9593	Economy	10900.00
0005434186222	9593	Economy	10900.00
0005432817974	9593	Economy	10900.00
0005434157513	9593	Economy	10900.00
0005432901770	9593	Economy	10900.00
0005432901908	28983	Business	32600.00
0005432817721	28983	Business	32600.00
0005432822249	28983	Business	32600.00
0005432901917	28983	Business	32600.00
0005432817775	28983	Business	32600.00
0005432901911	28983	Business	32600.00
0005432817744	28983	Business	32600.00
0005432817675	28983	Economy	10900.00
0005432822282	28983	Economy	10900.00
0005432817647	28983	Economy	10900.00
0005432817720	28983	Economy	10900.00
0005432822272	28983	Economy	10900.00
0005434157617	28983	Economy	10900.00
0005432901912	28983	Economy	10900.00
0005432002112	28983	Economy	10900.00
0005432817674	28983	Economy	10900.00
0005434157618	28983	Economy	10900.00
0005434448342	28983	Economy	10900.00
0005432817782	28983	Economy	10900.00
0005434157614	28983	Economy	10900.00
0005432901919	28983	Economy	10900.00
0005432817783	28983	Economy	10900.00
0005432817736	28983	Economy	10900.00
0005432901918	28983	Economy	10900.00
0005432817604	28983	Economy	10900.00
0005432901922	28983	Economy	10900.00
0005432822275	28983	Economy	10900.00
0005432901905	28983	Economy	10900.00
0005432822286	28983	Economy	10900.00
0005432817605	28983	Economy	10900.00
0005432901906	28983	Economy	10900.00
0005434157619	28983	Economy	10900.00
0005434157615	28983	Economy	10900.00
0005432822246	28983	Economy	10900.00
0005432901913	28983	Economy	10900.00
0005432901916	28983	Economy	10900.00
0005432901915	28983	Economy	10900.00
0005432822270	28983	Economy	10900.00
0005432817875	28983	Economy	10900.00
0005434448336	28983	Economy	10900.00
0005432817810	28983	Economy	10900.00
0005434157612	28983	Economy	10900.00
0005434186248	28983	Economy	10900.00
0005432822274	28983	Economy	10900.00
0005432817745	28983	Economy	10900.00
0005432822281	28983	Economy	10900.00
0005432901907	28983	Economy	10900.00
0005432817584	28983	Economy	10900.00
0005432002113	28983	Economy	10900.00
0005432817700	28983	Economy	10900.00
0005432817772	28983	Economy	10900.00
0005432901920	28983	Economy	10900.00
0005432817722	28983	Economy	10900.00
0005432817811	28983	Economy	10900.00
0005432901914	28983	Economy	10900.00
0005434448341	28983	Economy	10900.00
0005432817701	28983	Economy	10900.00
0005432817743	28983	Economy	10900.00
0005432817746	28983	Economy	10900.00
0005432901909	28983	Economy	10900.00
0005432901910	28983	Economy	10900.00
0005434157613	28983	Economy	10900.00
0005434157616	28983	Economy	10900.00
0005432901921	28983	Economy	10900.00
0005432613932	15118	Economy	11000.00
0005432613931	15118	Economy	11000.00
0005432611773	15118	Economy	11000.00
0005432613933	15118	Economy	11000.00
0005432613934	15118	Economy	11000.00
0005432611774	15118	Economy	11000.00
0005435841838	31591	Economy	11000.00
0005432611741	31591	Economy	11000.00
0005432611740	31591	Economy	11000.00
0005435841837	31591	Economy	11000.00
0005432611739	31591	Economy	11000.00
0005435842342	31591	Economy	11000.00
0005432611750	31591	Economy	11000.00
0005432611749	31591	Economy	11000.00
0005432948890	11859	Business	105900.00
0005433570038	11859	Business	105900.00
0005432948518	11859	Business	105900.00
0005432948734	11859	Business	105900.00
0005433570063	11859	Business	105900.00
0005433570030	11859	Business	105900.00
0005432948840	11859	Business	105900.00
0005433570042	11859	Business	105900.00
0005433570064	11859	Business	105900.00
0005432948821	11859	Business	105900.00
0005432948656	11859	Business	105900.00
0005432948771	11859	Business	105900.00
0005432948791	11859	Business	105900.00
0005432948770	11859	Business	105900.00
0005432948993	11859	Business	105900.00
0005432948829	11859	Business	105900.00
0005432948719	11859	Business	105900.00
0005432948792	11859	Business	105900.00
0005432948604	11859	Economy	35300.00
0005432948847	11859	Economy	35300.00
0005433570075	11859	Economy	35300.00
0005432948578	11859	Economy	35300.00
0005432948699	11859	Economy	35300.00
0005432948793	11859	Economy	35300.00
0005433570065	11859	Economy	35300.00
0005433570041	11859	Economy	35300.00
0005432948830	11859	Economy	35300.00
0005432948614	11859	Economy	35300.00
0005432948647	11859	Economy	35300.00
0005432948741	11859	Economy	38800.00
0005433570074	11859	Economy	38800.00
0005432948897	11859	Economy	38800.00
0005433570037	11859	Economy	38800.00
0005432948994	11859	Economy	35300.00
0005433570076	11859	Economy	35300.00
0005433570044	11859	Economy	35300.00
0005433570055	11859	Economy	35300.00
0005433570056	11859	Economy	35300.00
0005433570036	11859	Economy	35300.00
0005433570045	11859	Economy	35300.00
0005433570072	11859	Economy	35300.00
0005432948777	11859	Economy	35300.00
0005433570029	11859	Economy	35300.00
0005432948688	11859	Economy	35300.00
0005432948911	11859	Economy	35300.00
0005432948861	11859	Economy	35300.00
0005433570061	11859	Economy	35300.00
0005433570054	11859	Economy	35300.00
0005432948833	11859	Economy	35300.00
0005433570073	11859	Economy	35300.00
0005433570059	11859	Economy	35300.00
0005433570052	11859	Economy	35300.00
0005432948888	11859	Economy	35300.00
0005433570034	11859	Economy	35300.00
0005432948603	11859	Economy	35300.00
0005433570051	11859	Economy	35300.00
0005433570067	11859	Economy	35300.00
0005433570047	11859	Economy	35300.00
0005433570039	11859	Economy	35300.00
0005433570050	11859	Economy	35300.00
0005433570071	11859	Economy	35300.00
0005433570031	11859	Economy	35300.00
0005432948841	11859	Economy	35300.00
0005433570032	11859	Economy	35300.00
0005433570068	11859	Economy	35300.00
0005433570062	11859	Economy	35300.00
0005433570048	11859	Economy	35300.00
0005433570057	11859	Economy	35300.00
0005432948735	11859	Economy	35300.00
0005433570066	11859	Economy	35300.00
0005432948896	11859	Economy	35300.00
0005432948772	11859	Economy	35300.00
0005433570046	11859	Economy	35300.00
0005433570058	11859	Economy	35300.00
0005433570033	11859	Economy	35300.00
0005432948781	11859	Economy	35300.00
0005432948787	11859	Economy	35300.00
0005432948720	11859	Economy	35300.00
0005432948744	11859	Economy	35300.00
0005432948689	11859	Economy	35300.00
0005433570069	11859	Economy	35300.00
0005432948635	11859	Economy	35300.00
0005432948756	11859	Economy	35300.00
0005432948877	11859	Economy	35300.00
0005433570049	11859	Economy	35300.00
0005432948577	11859	Economy	35300.00
0005432948755	11859	Economy	35300.00
0005433570053	11859	Economy	35300.00
0005433570035	11859	Economy	35300.00
0005432948696	11859	Economy	35300.00
0005433570060	11859	Economy	35300.00
0005432948776	11859	Economy	35300.00
0005432948889	11859	Economy	35300.00
0005432948822	11859	Economy	35300.00
0005433570040	11859	Economy	35300.00
0005432948757	11859	Economy	35300.00
0005433570070	11859	Economy	35300.00
0005432948646	11859	Economy	35300.00
0005432948773	11859	Economy	35300.00
0005432948695	11859	Economy	35300.00
0005433570043	11859	Economy	35300.00
0005432948667	11859	Economy	35300.00
0005432948887	11859	Economy	35300.00
0005432948653	11859	Economy	35300.00
0005432948782	11859	Economy	35300.00
0005432949213	25317	Business	105900.00
0005432949200	25317	Business	105900.00
0005433569502	25317	Business	105900.00
0005432949186	25317	Business	105900.00
0005432949218	25317	Business	105900.00
0005432949184	25317	Business	105900.00
0005433569474	25317	Business	105900.00
0005432949221	25317	Business	105900.00
0005433569475	25317	Business	105900.00
0005432949194	25317	Business	105900.00
0005433569505	25317	Business	105900.00
0005433569548	25317	Business	105900.00
0005433569623	25317	Business	105900.00
0005432949211	25317	Business	105900.00
0005432949191	25317	Business	105900.00
0005432949220	25317	Business	105900.00
0005433569360	25317	Business	105900.00
0005432949202	25317	Economy	35300.00
0005432949206	25317	Economy	35300.00
0005433569498	25317	Economy	35300.00
0005433569476	25317	Economy	35300.00
0005432949217	25317	Economy	35300.00
0005433569477	25317	Economy	35300.00
0005433569324	25317	Economy	35300.00
0005432949188	25317	Economy	35300.00
0005433569563	25317	Economy	35300.00
0005433569574	25317	Economy	35300.00
0005433569438	25317	Economy	35300.00
0005433569320	25317	Economy	38800.00
0005433569580	25317	Economy	38800.00
0005433569490	25317	Economy	38800.00
0005433569405	25317	Economy	38800.00
0005432949185	25317	Economy	35300.00
0005433569407	25317	Economy	35300.00
0005433569717	25317	Economy	35300.00
0005432949201	25317	Economy	35300.00
0005432949193	25317	Economy	35300.00
0005432949209	25317	Economy	35300.00
0005433569345	25317	Economy	35300.00
0005433569472	25317	Economy	35300.00
0005432949210	25317	Economy	35300.00
0005433569491	25317	Economy	35300.00
0005433569636	25317	Economy	35300.00
0005433569258	25317	Economy	35300.00
0005433569435	25317	Economy	35300.00
0005433569681	25317	Economy	35300.00
0005433569321	25317	Economy	35300.00
0005433569755	25317	Economy	35300.00
0005432949214	25317	Economy	35300.00
0005432949222	25317	Economy	35300.00
0005433569504	25317	Economy	35300.00
0005432949204	25317	Economy	35300.00
0005432949207	25317	Economy	35300.00
0005432949197	25317	Economy	35300.00
0005433569535	25317	Economy	35300.00
0005433569632	25317	Economy	35300.00
0005433569499	25317	Economy	35300.00
0005432949198	25317	Economy	35300.00
0005433569546	25317	Economy	35300.00
0005433569492	25317	Economy	35300.00
0005433569581	25317	Economy	35300.00
0005432949212	25317	Economy	35300.00
0005432949205	25317	Economy	35300.00
0005433569564	25317	Economy	35300.00
0005432949187	25317	Economy	35300.00
0005433569500	25317	Economy	35300.00
0005433569440	25317	Economy	35300.00
0005432949199	25317	Economy	35300.00
0005433569341	25317	Economy	35300.00
0005432949215	25317	Economy	35300.00
0005432949195	25317	Economy	35300.00
0005433569620	25317	Economy	35300.00
0005433569442	25317	Economy	35300.00
0005432949216	25317	Economy	35300.00
0005433569437	25317	Economy	35300.00
0005432949223	25317	Economy	35300.00
0005432949219	25317	Economy	35300.00
0005433569408	25317	Economy	35300.00
0005433569501	25317	Economy	35300.00
0005433569356	25317	Economy	35300.00
0005433569436	25317	Economy	35300.00
0005432949196	25317	Economy	35300.00
0005433569550	25317	Economy	35300.00
0005433569566	25317	Economy	35300.00
0005433569441	25317	Economy	35300.00
0005433569641	25317	Economy	35300.00
0005433569579	25317	Economy	35300.00
0005433569575	25317	Economy	35300.00
0005433569503	25317	Economy	35300.00
0005432949190	25317	Economy	35300.00
0005432949189	25317	Economy	35300.00
0005432949183	25317	Economy	35300.00
0005433569346	25317	Economy	35300.00
0005432949208	25317	Economy	35300.00
0005432949203	25317	Economy	35300.00
0005433569635	25317	Economy	35300.00
0005433569578	25317	Economy	35300.00
0005433569682	25317	Economy	35300.00
0005433569705	25317	Economy	35300.00
0005432949192	25317	Economy	35300.00
0005433569760	25317	Economy	35300.00
0005433569557	25317	Economy	35300.00
0005433569565	25317	Economy	35300.00
0005434655202	5399	Business	67200.00
0005434655181	5399	Business	67200.00
0005434655200	5399	Business	67200.00
0005435555392	5399	Business	67200.00
0005435340405	5399	Business	67200.00
0005434655188	5399	Business	67200.00
0005435340388	5399	Business	67200.00
0005434655189	5399	Business	67200.00
0005434655180	5399	Economy	22400.00
0005434655199	5399	Economy	22400.00
0005435555391	5399	Economy	22400.00
0005435340421	5399	Economy	22400.00
0005434655205	5399	Economy	22400.00
0005435555393	5399	Economy	22400.00
0005434655194	5399	Economy	24600.00
0005432114260	5399	Economy	24600.00
0005432114259	5399	Economy	22400.00
0005434655185	5399	Economy	22400.00
0005434655179	5399	Economy	22400.00
0005434655178	5399	Economy	22400.00
0005435340409	5399	Economy	22400.00
0005435340424	5399	Economy	22400.00
0005434655187	5399	Economy	22400.00
0005435340419	5399	Economy	22400.00
0005434655192	5399	Economy	22400.00
0005434655198	5399	Economy	22400.00
0005435340404	5399	Economy	22400.00
0005434655186	5399	Economy	22400.00
0005434655193	5399	Economy	22400.00
0005435340420	5399	Economy	22400.00
0005435340373	5399	Economy	22400.00
0005435340376	5399	Economy	22400.00
0005434656591	5399	Economy	22400.00
0005434655191	5399	Economy	22400.00
0005435340369	5399	Economy	22400.00
0005435340372	5399	Economy	22400.00
0005435340423	5399	Economy	22400.00
0005434655184	5399	Economy	22400.00
0005434655190	5399	Economy	22400.00
0005434655196	5399	Economy	22400.00
0005435340375	5399	Economy	22400.00
0005435340400	5399	Economy	22400.00
0005435555390	5399	Economy	22400.00
0005435340368	5399	Economy	22400.00
0005435340363	5399	Economy	22400.00
0005434655203	5399	Economy	22400.00
0005434655195	5399	Economy	22400.00
0005435340401	5399	Economy	22400.00
0005434655197	5399	Economy	22400.00
0005434655201	5399	Economy	22400.00
0005434655183	5399	Economy	22400.00
0005434655177	5399	Economy	22400.00
0005434655204	5399	Economy	22400.00
0005435340380	5399	Economy	22400.00
0005432114258	5399	Economy	22400.00
0005435340371	5399	Economy	22400.00
0005434655182	5399	Economy	22400.00
0005435340534	12537	Business	67200.00
0005435555407	12537	Business	67200.00
0005435340523	12537	Business	67200.00
0005434654932	12537	Business	67200.00
0005434654961	12537	Business	67200.00
0005435340520	12537	Business	67200.00
0005435340532	12537	Business	67200.00
0005435340521	12537	Business	67200.00
0005434654990	12537	Economy	22400.00
0005434654931	12537	Economy	22400.00
0005435340529	12537	Economy	22400.00
0005434654991	12537	Economy	22400.00
0005435340531	12537	Economy	22400.00
0005434655020	12537	Economy	22400.00
0005434654960	12537	Economy	22400.00
0005434654974	12537	Economy	22400.00
0005434654828	12537	Economy	24600.00
0005435340522	12537	Economy	22400.00
0005434656572	12537	Economy	22400.00
0005435340530	12537	Economy	22400.00
0005434655033	12537	Economy	22400.00
0005434654923	12537	Economy	22400.00
0005434654921	12537	Economy	22400.00
0005435340519	12537	Economy	22400.00
0005434655024	12537	Economy	22400.00
0005435340524	12537	Economy	22400.00
0005435555406	12537	Economy	22400.00
0005435340528	12537	Economy	22400.00
0005434655016	12537	Economy	22400.00
0005434654908	12537	Economy	22400.00
0005434655043	12537	Economy	22400.00
0005435340526	12537	Economy	22400.00
0005434654827	12537	Economy	22400.00
0005434654889	12537	Economy	22400.00
0005435340525	12537	Economy	22400.00
0005435340527	12537	Economy	22400.00
0005434655041	12537	Economy	22400.00
0005434655019	12537	Economy	22400.00
0005435340533	12537	Economy	22400.00
0005434654826	12537	Economy	22400.00
0005434654924	12537	Economy	22400.00
0005434655017	12537	Economy	22400.00
0005434654920	12537	Economy	22400.00
0005433716837	7454	Business	32000.00
0005435266178	7454	Business	32000.00
0005433716815	7454	Business	32000.00
0005433689945	7454	Business	32000.00
0005433716850	7454	Business	32000.00
0005433722331	7454	Business	32000.00
0005433716820	7454	Economy	10700.00
0005433716844	7454	Business	32000.00
0005432428947	7454	Economy	10700.00
0005433716836	7454	Economy	10700.00
0005433716847	7454	Economy	10700.00
0005433722334	7454	Economy	10700.00
0005433716807	7454	Economy	10700.00
0005433716817	7454	Economy	10700.00
0005433716822	7454	Economy	10700.00
0005433716809	7454	Economy	10700.00
0005433716843	7454	Economy	10700.00
0005433716838	7454	Economy	10700.00
0005433716833	7454	Economy	10700.00
0005432078202	7454	Economy	10700.00
0005433722336	7454	Economy	10700.00
0005433688843	7454	Economy	10700.00
0005433722332	7454	Economy	10700.00
0005433722330	7454	Economy	10700.00
0005433716814	7454	Economy	10700.00
0005433716841	7454	Economy	10700.00
0005433716852	7454	Economy	10700.00
0005433716848	7454	Economy	10700.00
0005432428956	7454	Economy	10700.00
0005433716823	7454	Economy	10700.00
0005433716824	7454	Economy	10700.00
0005433716813	7454	Economy	10700.00
0005433716821	7454	Economy	10700.00
0005433716825	7454	Economy	10700.00
0005432078204	7454	Economy	10700.00
0005433716842	7454	Economy	11700.00
0005433716818	7454	Economy	11700.00
0005432078206	7454	Economy	11700.00
0005433716839	7454	Economy	11700.00
0005433716849	7454	Economy	10700.00
0005433716832	7454	Economy	10700.00
0005433716851	7454	Economy	10700.00
0005433656726	7454	Economy	10700.00
0005435266179	7454	Economy	10700.00
0005433716816	7454	Economy	10700.00
0005433716830	7454	Economy	10700.00
0005433716855	7454	Economy	10700.00
0005432078203	7454	Economy	10700.00
0005433716827	7454	Economy	10700.00
0005433716846	7454	Economy	10700.00
0005433716854	7454	Economy	10700.00
0005433722333	7454	Economy	10700.00
0005433716845	7454	Economy	10700.00
0005433716826	7454	Economy	10700.00
0005433690958	7454	Economy	10700.00
0005433716856	7454	Economy	10700.00
0005433719198	7454	Economy	10700.00
0005433716812	7454	Economy	10700.00
0005433719196	7454	Economy	10700.00
0005432078205	7454	Economy	10700.00
0005433716819	7454	Economy	10700.00
0005433656727	7454	Economy	10700.00
0005433716831	7454	Economy	10700.00
0005433716853	7454	Economy	10700.00
0005433688845	7454	Economy	10700.00
0005433716810	7454	Economy	10700.00
0005433716835	7454	Economy	10700.00
0005433716834	7454	Economy	10700.00
0005433716806	7454	Economy	10700.00
0005433716829	7454	Economy	10700.00
0005433688844	7454	Economy	10700.00
0005433716811	7454	Economy	10700.00
0005433716857	7454	Economy	10700.00
0005433690959	7454	Economy	10700.00
0005433719197	7454	Economy	10700.00
0005433716840	7454	Economy	10700.00
0005433722335	7454	Economy	10700.00
0005433656725	7454	Economy	10700.00
0005433689946	7454	Economy	10700.00
0005433689947	7454	Economy	10700.00
0005433716808	7454	Economy	10700.00
0005433716828	7454	Economy	10700.00
0005432428955	7454	Economy	10700.00
0005433716493	29252	Business	32000.00
0005432006815	29252	Business	32000.00
0005433716582	29252	Business	32000.00
0005433716590	29252	Business	32000.00
0005433716197	29252	Business	32000.00
0005432006812	29252	Business	32000.00
0005432428987	29252	Business	32000.00
0005433716680	29252	Economy	10700.00
0005433716581	29252	Economy	10700.00
0005433716379	29252	Economy	10700.00
0005433716507	29252	Economy	10700.00
0005433716488	29252	Economy	10700.00
0005433716404	29252	Economy	10700.00
0005433716489	29252	Economy	10700.00
0005433716484	29252	Economy	10700.00
0005433716390	29252	Economy	10700.00
0005433716394	29252	Economy	10700.00
0005433716492	29252	Economy	10700.00
0005433716486	29252	Economy	10700.00
0005433716550	29252	Economy	10700.00
0005433716483	29252	Economy	10700.00
0005433716305	29252	Economy	10700.00
0005433716601	29252	Economy	10700.00
0005433716506	29252	Economy	10700.00
0005433716286	29252	Economy	10700.00
0005433716549	29252	Economy	10700.00
0005432006814	29252	Economy	10700.00
0005433716679	29252	Economy	10700.00
0005433716397	29252	Economy	10700.00
0005433716306	29252	Economy	10700.00
0005433716405	29252	Economy	10700.00
0005433716466	29252	Economy	10700.00
0005433716299	29252	Economy	10700.00
0005432006811	29252	Economy	10700.00
0005433688837	29252	Economy	10700.00
0005433716431	29252	Economy	10700.00
0005433716274	29252	Economy	10700.00
0005433716497	29252	Economy	10700.00
0005433716442	29252	Economy	10700.00
0005433656706	29252	Economy	10700.00
0005433716646	29252	Economy	10700.00
0005433716196	29252	Economy	10700.00
0005433719162	29252	Economy	10700.00
0005433716380	29252	Economy	10700.00
0005433716437	29252	Economy	10700.00
0005433716393	29252	Economy	10700.00
0005433716502	29252	Economy	10700.00
0005433716396	29252	Economy	10700.00
0005433716600	29252	Economy	10700.00
0005433716398	29252	Economy	10700.00
0005433716470	29252	Economy	10700.00
0005433716198	29252	Economy	10700.00
0005433716551	29252	Economy	10700.00
0005433716348	29252	Economy	10700.00
0005433716482	29252	Economy	10700.00
0005433716552	29252	Economy	10700.00
0005433716647	29252	Economy	10700.00
0005432006813	29252	Economy	10700.00
0005433716528	29252	Economy	10700.00
0005433716399	29252	Economy	10700.00
0005433716583	29252	Economy	10700.00
0005432428989	29252	Economy	10700.00
0005433685543	29252	Economy	10700.00
0005433716297	29252	Economy	10700.00
0005432428988	29252	Economy	10700.00
0005433716190	29252	Economy	10700.00
0005433688836	29252	Economy	10700.00
0005434182253	8701	Business	36500.00
0005434182308	8701	Business	36500.00
0005434095519	8701	Business	36500.00
0005434095525	8701	Business	36500.00
0005434143746	8701	Business	36500.00
0005434095523	8701	Business	36500.00
0005434182309	8701	Business	36500.00
0005434182284	8701	Business	36500.00
0005434095524	8701	Economy	12200.00
0005434184684	8701	Economy	12200.00
0005434095529	8701	Economy	12200.00
0005434095522	8701	Economy	12200.00
0005434143749	8701	Economy	13400.00
0005434182275	8701	Economy	13400.00
0005434143747	8701	Economy	12200.00
0005434182298	8701	Economy	12200.00
0005434182325	8701	Economy	12200.00
0005434095530	8701	Economy	12200.00
0005434095527	8701	Economy	12200.00
0005434143744	8701	Economy	12200.00
0005434095528	8701	Economy	12200.00
0005434182297	8701	Economy	12200.00
0005434182249	8701	Economy	12200.00
0005434143748	8701	Economy	12200.00
0005434182320	8701	Economy	12200.00
0005434182273	8701	Economy	12200.00
0005434143745	8701	Economy	12200.00
0005434182350	8701	Economy	12200.00
0005434095526	8701	Economy	12200.00
0005434182329	8701	Economy	12200.00
0005434095521	8701	Economy	12200.00
0005434182337	8701	Economy	12200.00
0005434182336	8701	Economy	12200.00
0005434182248	8701	Economy	12200.00
0005434182348	8701	Economy	12200.00
0005434182276	8701	Economy	12200.00
0005434184683	8701	Economy	12200.00
0005434184688	8701	Economy	12200.00
0005434182330	8701	Economy	12200.00
0005434095531	8701	Economy	12200.00
0005434143750	8701	Economy	12200.00
0005434184675	8701	Economy	12200.00
0005434182319	8701	Economy	12200.00
0005434095520	8701	Economy	12200.00
0005434095532	8701	Economy	12200.00
0005434182285	8701	Economy	12200.00
0005434184698	11657	Business	36500.00
0005434095503	11657	Business	36500.00
0005434182402	11657	Business	36500.00
0005434182401	11657	Business	36500.00
0005434182404	11657	Business	36500.00
0005434182406	11657	Business	36500.00
0005434095404	11657	Business	36500.00
0005434095375	11657	Business	36500.00
0005434182407	11657	Economy	12200.00
0005434183612	11657	Economy	12200.00
0005434095427	11657	Economy	13400.00
0005434095377	11657	Economy	12200.00
0005434184699	11657	Economy	12200.00
0005434095371	11657	Economy	12200.00
0005434182405	11657	Economy	12200.00
0005434143742	11657	Economy	12200.00
0005434095471	11657	Economy	12200.00
0005434095302	11657	Economy	12200.00
0005434182400	11657	Economy	12200.00
0005434182395	11657	Economy	12200.00
0005434095399	11657	Economy	12200.00
0005434183613	11657	Economy	12200.00
0005434182403	11657	Economy	12200.00
0005434095382	11657	Economy	12200.00
0005434095432	11657	Economy	12200.00
0005434182396	11657	Economy	12200.00
0005434184697	11657	Economy	12200.00
0005434095372	11657	Economy	12200.00
0005434095410	11657	Economy	12200.00
0005434095501	11657	Economy	12200.00
0005434095433	11657	Economy	12200.00
0005434095502	11657	Economy	12200.00
0005434095416	11657	Economy	12200.00
0005434095354	11657	Economy	12200.00
0005434095355	11657	Economy	12200.00
0005434143741	11657	Economy	12200.00
0005434182397	11657	Economy	12200.00
0005434095389	11657	Economy	12200.00
0005434095301	11657	Economy	12200.00
0005434095431	11657	Economy	12200.00
0005434095374	11657	Economy	12200.00
0005434095470	11657	Economy	12200.00
0005434182398	11657	Economy	12200.00
0005434182399	11657	Economy	12200.00
0005434095356	11657	Economy	12200.00
0005434095469	11657	Economy	12200.00
0005433398474	1457	Business	33000.00
0005433457039	1457	Business	33000.00
0005433398439	1457	Business	33000.00
0005433398000	1457	Business	33000.00
0005433398490	1457	Business	33000.00
0005435732548	1457	Business	33000.00
0005433398543	1457	Business	33000.00
0005433398570	1457	Business	33000.00
0005433457040	1457	Economy	11000.00
0005433398001	1457	Economy	11000.00
0005433398377	1457	Economy	11000.00
0005433457041	1457	Economy	11000.00
0005433398517	1457	Economy	11000.00
0005433398455	1457	Economy	11000.00
0005433398492	1457	Economy	11000.00
0005433398526	1457	Economy	12100.00
0005433398535	1457	Economy	12100.00
0005435732550	1457	Economy	12100.00
0005435732549	1457	Economy	12100.00
0005435732546	1457	Economy	11000.00
0005433398049	1457	Economy	11000.00
0005433398599	1457	Economy	11000.00
0005433457038	1457	Economy	11000.00
0005433398179	1457	Economy	11000.00
0005433398322	1457	Economy	11000.00
0005433398341	1457	Economy	11000.00
0005435732551	1457	Economy	11000.00
0005432297323	1457	Economy	11000.00
0005433398340	1457	Economy	11000.00
0005432297326	1457	Economy	11000.00
0005433398525	1457	Economy	11000.00
0005433398582	1457	Economy	11000.00
0005433398192	1457	Economy	11000.00
0005433398549	1457	Economy	11000.00
0005433398307	1457	Economy	11000.00
0005433398347	1457	Economy	11000.00
0005433398647	1457	Economy	11000.00
0005433398330	1457	Economy	11000.00
0005433398589	1457	Economy	11000.00
0005433398600	1457	Economy	11000.00
0005433398588	1457	Economy	11000.00
0005432906559	1457	Economy	11000.00
0005433398656	1457	Economy	11000.00
0005433398498	1457	Economy	11000.00
0005433398502	1457	Economy	11000.00
0005432297324	1457	Economy	11000.00
0005433398655	1457	Economy	11000.00
0005433398491	1457	Economy	11000.00
0005432297325	1457	Economy	11000.00
0005433398488	1457	Economy	11000.00
0005433398305	1457	Economy	11000.00
0005433398654	1457	Economy	11000.00
0005433398216	1457	Economy	11000.00
0005433398515	1457	Economy	11000.00
0005433398493	1457	Economy	11000.00
0005433398500	1457	Economy	11000.00
0005433398514	1457	Economy	11000.00
0005435732552	1457	Economy	11000.00
0005433398351	1457	Economy	11000.00
0005433398472	1457	Economy	11000.00
0005433398447	1457	Economy	11000.00
0005433398489	1457	Economy	11000.00
0005435732547	1457	Economy	11000.00
0005433398551	1457	Economy	11000.00
0005433398501	1457	Economy	11000.00
0005432906555	1457	Economy	11000.00
0005433398534	1457	Economy	11000.00
0005433398550	1457	Economy	11000.00
0005433398516	1457	Economy	11000.00
0005432297322	1457	Economy	11000.00
0005433398564	1457	Economy	11000.00
0005432906556	1457	Economy	11000.00
0005433398568	1457	Economy	11000.00
0005433398897	19232	Business	33000.00
0005433398884	19232	Business	33000.00
0005433398908	19232	Business	33000.00
0005435732465	19232	Business	33000.00
0005435732404	19232	Business	33000.00
0005435732409	19232	Business	33000.00
0005435732445	19232	Business	33000.00
0005435732405	19232	Business	33000.00
0005433398881	19232	Business	33000.00
0005433398869	19232	Business	33000.00
0005435732464	19232	Business	33000.00
0005433457009	19232	Business	33000.00
0005433398907	19232	Economy	11000.00
0005433398882	19232	Economy	11000.00
0005435732444	19232	Economy	11000.00
0005433398876	19232	Economy	11000.00
0005433398887	19232	Economy	11000.00
0005433456998	19232	Economy	11000.00
0005435732508	19232	Economy	11000.00
0005433398910	19232	Economy	11000.00
0005435732459	19232	Economy	11000.00
0005433398871	19232	Economy	12100.00
0005433398879	19232	Economy	12100.00
0005433398875	19232	Economy	12100.00
0005435732458	19232	Economy	11000.00
0005433398916	19232	Economy	11000.00
0005433456997	19232	Economy	11000.00
0005435732443	19232	Economy	11000.00
0005433398906	19232	Economy	11000.00
0005433398892	19232	Economy	11000.00
0005433398870	19232	Economy	11000.00
0005432906578	19232	Economy	11000.00
0005433398894	19232	Economy	11000.00
0005433398885	19232	Economy	11000.00
0005433398874	19232	Economy	11000.00
0005433398914	19232	Economy	11000.00
0005433398880	19232	Economy	11000.00
0005433398912	19232	Economy	11000.00
0005435732498	19232	Economy	11000.00
0005433398877	19232	Economy	11000.00
0005435732463	19232	Economy	11000.00
0005433457006	19232	Economy	11000.00
0005433398915	19232	Economy	11000.00
0005435732497	19232	Economy	11000.00
0005433398872	19232	Economy	11000.00
0005433398896	19232	Economy	11000.00
0005433398893	19232	Economy	11000.00
0005433398899	19232	Economy	11000.00
0005432906579	19232	Economy	11000.00
0005433398903	19232	Economy	11000.00
0005433398883	19232	Economy	11000.00
0005433398911	19232	Economy	11000.00
0005435732406	19232	Economy	11000.00
0005433398895	19232	Economy	11000.00
0005433398901	19232	Economy	11000.00
0005433398904	19232	Economy	11000.00
0005433398890	19232	Economy	11000.00
0005433398913	19232	Economy	11000.00
0005433398889	19232	Economy	11000.00
0005433457000	19232	Economy	11000.00
0005435732460	19232	Economy	11000.00
0005433456994	19232	Economy	11000.00
0005433398918	19232	Economy	11000.00
0005433398898	19232	Economy	11000.00
0005435732418	19232	Economy	11000.00
0005433457003	19232	Economy	11000.00
0005433398900	19232	Economy	11000.00
0005433457010	19232	Economy	11000.00
0005435732440	19232	Economy	11000.00
0005432906577	19232	Economy	11000.00
0005433398886	19232	Economy	11000.00
0005433398891	19232	Economy	11000.00
0005433398905	19232	Economy	11000.00
0005433457018	19232	Economy	11000.00
0005433398878	19232	Economy	11000.00
0005433457019	19232	Economy	11000.00
0005433398873	19232	Economy	11000.00
0005433398917	19232	Economy	11000.00
0005433398888	19232	Economy	11000.00
0005433398902	19232	Economy	11000.00
0005433457024	19232	Economy	11000.00
0005433398909	19232	Economy	11000.00
0005433456999	19232	Economy	11000.00
0005435732435	19232	Economy	11000.00
0005433457001	19232	Economy	11000.00
0005435732395	19232	Economy	11000.00
0005433457002	19232	Economy	11000.00
0005434443838	17345	Economy	15600.00
0005434443868	17345	Economy	14100.00
0005434443850	17345	Economy	14100.00
0005434443777	17345	Economy	14100.00
0005434443808	17345	Economy	14100.00
0005434443864	17345	Economy	14100.00
0005434443899	17345	Economy	14100.00
0005434443809	17345	Economy	14100.00
0005434443858	17345	Economy	14100.00
0005434443818	17345	Economy	14100.00
0005434443817	17345	Economy	14100.00
0005434443816	17345	Economy	14100.00
0005434443851	17345	Economy	14100.00
0005434443819	17345	Economy	14100.00
0005434443815	17345	Economy	14100.00
0005434443875	17345	Economy	14100.00
0005434443778	17345	Economy	14100.00
0005434443814	17345	Economy	14100.00
0005434443866	17345	Economy	14100.00
0005434443806	17345	Economy	14100.00
0005434443740	17345	Economy	14100.00
0005434443865	17345	Economy	14100.00
0005434443985	20584	Economy	15600.00
0005434443984	20584	Economy	15600.00
0005434443979	20584	Economy	14100.00
0005434443970	20584	Economy	14100.00
0005434443971	20584	Economy	14100.00
0005434443973	20584	Economy	14100.00
0005434443981	20584	Economy	14100.00
0005434443978	20584	Economy	14100.00
0005434443982	20584	Economy	14100.00
0005434443972	20584	Economy	14100.00
0005434443976	20584	Economy	14100.00
0005434443969	20584	Economy	14100.00
0005434443977	20584	Economy	14100.00
0005434443983	20584	Economy	14100.00
0005434443975	20584	Economy	14100.00
0005434443974	20584	Economy	14100.00
0005434443980	20584	Economy	14100.00
0005434954678	7286	Economy	5800.00
0005435377609	7286	Economy	5800.00
0005434954677	7286	Economy	5800.00
0005435377599	7286	Economy	5800.00
0005435377610	7286	Economy	5800.00
0005435377602	7286	Economy	5800.00
0005434954679	7286	Economy	5800.00
0005434954676	7286	Economy	5800.00
0005434954675	7286	Economy	5800.00
0005435377600	7286	Economy	5800.00
0005434954636	28308	Economy	5800.00
0005434954649	28308	Economy	5800.00
0005435377620	28308	Economy	5800.00
0005434954665	28308	Economy	5800.00
0005434954646	28308	Economy	5800.00
0005434954664	28308	Economy	5800.00
0005434954637	28308	Economy	5800.00
0005434954635	28308	Economy	5800.00
0005434954644	28308	Economy	5800.00
0005435377621	28308	Economy	5800.00
0005434351920	4484	Economy	15400.00
0005434326278	4484	Economy	15400.00
0005434351921	4484	Economy	15400.00
0005434351916	4484	Economy	14000.00
0005434351912	4484	Economy	14000.00
0005434351913	4484	Economy	14000.00
0005434351917	4484	Economy	14000.00
0005434351915	4484	Economy	14000.00
0005434351919	4484	Economy	14000.00
0005435893727	4484	Economy	14000.00
0005434351918	4484	Economy	14000.00
0005434351914	4484	Economy	14000.00
0005434351910	4484	Economy	14000.00
0005435893709	4484	Economy	14000.00
0005435893728	4484	Economy	14000.00
0005435893731	4484	Economy	14000.00
0005434351922	4484	Economy	14000.00
0005434326279	4484	Economy	14000.00
0005435893719	4484	Economy	14000.00
0005435893732	4484	Economy	14000.00
0005435893718	4484	Economy	14000.00
0005434351911	4484	Economy	14000.00
0005434351742	29683	Economy	15400.00
0005434351848	29683	Economy	15400.00
0005435893751	29683	Economy	14000.00
0005435893754	29683	Economy	14000.00
0005434351818	29683	Economy	14000.00
0005434351806	29683	Economy	14000.00
0005434351743	29683	Economy	14000.00
0005434351775	29683	Economy	14000.00
0005434351828	29683	Economy	14000.00
0005435893752	29683	Economy	14000.00
0005434351829	29683	Economy	14000.00
0005434351815	29683	Economy	14000.00
0005434351864	29683	Economy	14000.00
0005435893755	29683	Economy	14000.00
0005435893753	29683	Economy	14000.00
0005434351835	29683	Economy	14000.00
0005434351740	29683	Economy	14000.00
0005434351753	29683	Economy	14000.00
0005435893758	29683	Economy	14000.00
0005434351749	29683	Economy	14000.00
0005434351882	29683	Economy	14000.00
0005435893757	29683	Economy	14000.00
0005435893756	29683	Economy	14000.00
0005434351883	29683	Economy	14000.00
0005434351752	29683	Economy	14000.00
0005433343969	1085	Business	30600.00
0005435092251	1085	Business	30600.00
0005433344176	1085	Business	30600.00
0005433343952	1085	Business	30600.00
0005433269768	1085	Business	30600.00
0005434445285	1085	Business	30600.00
0005435545870	1085	Business	30600.00
0005433343873	1085	Business	30600.00
0005433344383	1085	Business	30600.00
0005433343881	1085	Business	30600.00
0005433343525	1085	Business	30600.00
0005433343929	1085	Business	30600.00
0005433344000	1085	Business	30600.00
0005433343993	1085	Business	30600.00
0005434445286	1085	Business	30600.00
0005433343676	1085	Business	30600.00
0005433343950	1085	Business	30600.00
0005433343830	1085	Business	30600.00
0005433343370	1085	Business	30600.00
0005433344044	1085	Economy	11200.00
0005433343796	1085	Economy	11200.00
0005432293251	1085	Economy	10200.00
0005433343992	1085	Economy	10200.00
0005433159335	1085	Economy	10200.00
0005433343954	1085	Economy	10200.00
0005433343951	1085	Economy	10200.00
0005433343657	1085	Economy	10200.00
0005434445282	1085	Economy	10200.00
0005434446559	1085	Economy	10200.00
0005433344066	1085	Economy	10200.00
0005435092245	1085	Economy	10200.00
0005433343693	1085	Economy	10200.00
0005433344330	1085	Economy	10200.00
0005433343956	1085	Economy	10200.00
0005433343602	1085	Economy	10200.00
0005433344121	1085	Economy	10200.00
0005433344327	1085	Economy	10200.00
0005433343776	1085	Economy	10200.00
0005433344040	1085	Economy	10200.00
0005433343754	1085	Economy	10200.00
0005433344103	1085	Economy	10200.00
0005435092248	1085	Economy	10200.00
0005433343540	1085	Economy	10200.00
0005433343797	1085	Economy	10200.00
0005433344094	1085	Economy	10200.00
0005433343770	1085	Economy	10200.00
0005433343949	1085	Economy	10200.00
0005435092244	1085	Economy	10200.00
0005433158147	1085	Economy	10200.00
0005433343729	1085	Economy	10200.00
0005435545867	1085	Economy	10200.00
0005433343526	1085	Economy	10200.00
0005433344175	1085	Economy	10200.00
0005432293250	1085	Economy	10200.00
0005435545869	1085	Economy	10200.00
0005433343371	1085	Economy	10200.00
0005433343650	1085	Economy	10200.00
0005435092250	1085	Economy	10200.00
0005433343827	1085	Economy	10200.00
0005433343880	1085	Economy	10200.00
0005433343655	1085	Economy	10200.00
0005435545871	1085	Economy	10200.00
0005435092241	1085	Economy	10200.00
0005433269726	1085	Economy	10200.00
0005433344296	1085	Economy	10200.00
0005434445284	1085	Economy	10200.00
0005434445283	1085	Economy	10200.00
0005435092246	1085	Economy	10200.00
0005433344102	1085	Economy	10200.00
0005433343986	1085	Economy	10200.00
0005433344081	1085	Economy	10200.00
0005433343673	1085	Economy	10200.00
0005433344148	1085	Economy	10200.00
0005433343930	1085	Economy	10200.00
0005433269748	1085	Economy	10200.00
0005433344191	1085	Economy	10200.00
0005433344400	1085	Economy	10200.00
0005433343775	1085	Economy	10200.00
0005433343558	1085	Economy	10200.00
0005433343649	1085	Economy	10200.00
0005433344468	1085	Economy	10200.00
0005433343955	1085	Economy	10200.00
0005434446558	1085	Economy	10200.00
0005433343933	1085	Economy	10200.00
0005435092249	1085	Economy	10200.00
0005433343728	1085	Economy	10200.00
0005433462784	1085	Economy	10200.00
0005433344127	1085	Economy	10200.00
0005433158148	1085	Economy	10200.00
0005433343753	1085	Economy	10200.00
0005433462783	1085	Economy	11200.00
0005432293249	1085	Economy	10200.00
0005433344111	1085	Economy	10200.00
0005435092247	1085	Economy	11200.00
0005433343879	1085	Economy	11200.00
0005433343897	1085	Economy	10200.00
0005433343744	1085	Economy	10200.00
0005433343369	1085	Economy	10200.00
0005433344011	1085	Economy	10200.00
0005433343961	1085	Economy	10200.00
0005433344150	1085	Economy	10200.00
0005433344348	1085	Economy	10200.00
0005433343899	1085	Economy	10200.00
0005433343960	1085	Economy	10200.00
0005433343905	1085	Economy	10200.00
0005435092242	1085	Economy	10200.00
0005433343959	1085	Economy	10200.00
0005433158152	1085	Economy	10200.00
0005433344043	1085	Economy	10200.00
0005435092243	1085	Economy	10200.00
0005433343560	1085	Economy	10200.00
0005435545868	1085	Economy	10200.00
0005433344149	1085	Economy	10200.00
0005433344181	1085	Economy	10200.00
0005433343692	1085	Economy	10200.00
0005433343752	1085	Economy	10200.00
0005433344122	1085	Economy	10200.00
0005433343896	1085	Economy	10200.00
0005433344174	1085	Economy	10200.00
0005433343804	1085	Economy	10200.00
0005433343831	1085	Economy	10200.00
0005433159336	1085	Economy	10200.00
0005433344266	1085	Economy	10200.00
0005433344012	1085	Economy	10200.00
0005433343877	1085	Economy	10200.00
0005433344130	1085	Economy	10200.00
0005433344125	1085	Economy	10200.00
0005433269761	1085	Economy	10200.00
0005433463938	1085	Economy	10200.00
0005433343450	1085	Economy	10200.00
0005433343895	1085	Economy	10200.00
0005433344328	1085	Economy	10200.00
0005433343529	1085	Economy	10200.00
0005433344197	1085	Economy	10200.00
0005433343953	1085	Economy	10200.00
0005433343968	1085	Economy	10200.00
0005433343892	1085	Economy	10200.00
0005433343874	1085	Economy	10200.00
0005433343559	1085	Economy	10200.00
0005433343740	1085	Economy	10200.00
0005433343948	1085	Economy	10200.00
0005435545866	1085	Economy	10200.00
0005433344772	17072	Business	30600.00
0005435092163	17072	Business	30600.00
0005433344791	17072	Business	30600.00
0005433344750	17072	Business	30600.00
0005433344756	17072	Business	30600.00
0005433344814	17072	Business	30600.00
0005433344819	17072	Business	30600.00
0005433269813	17072	Business	30600.00
0005433344770	17072	Business	30600.00
0005433344823	17072	Business	30600.00
0005433269811	17072	Business	30600.00
0005433344805	17072	Business	30600.00
0005433269809	17072	Business	30600.00
0005433344746	17072	Business	30600.00
0005433344771	17072	Business	30600.00
0005435092197	17072	Business	30600.00
0005435508426	17072	Business	30600.00
0005433344745	17072	Business	30600.00
0005435508409	17072	Business	30600.00
0005433344824	17072	Business	30600.00
0005433344781	17072	Business	30600.00
0005433344786	17072	Business	30600.00
0005433344803	17072	Economy	11200.00
0005433344780	17072	Business	30600.00
0005433344815	17072	Economy	11200.00
0005433344817	17072	Economy	10200.00
0005433344752	17072	Economy	10200.00
0005435508439	17072	Economy	10200.00
0005433344798	17072	Economy	10200.00
0005433344740	17072	Economy	10200.00
0005433344801	17072	Economy	10200.00
0005433344804	17072	Economy	10200.00
0005433344809	17072	Economy	10200.00
0005433344747	17072	Economy	10200.00
0005433344825	17072	Economy	10200.00
0005433344802	17072	Economy	10200.00
0005433344831	17072	Economy	10200.00
0005433344821	17072	Economy	10200.00
0005435508432	17072	Economy	10200.00
0005433344757	17072	Economy	10200.00
0005433344796	17072	Economy	10200.00
0005433159351	17072	Economy	10200.00
0005435092147	17072	Economy	10200.00
0005435508412	17072	Economy	10200.00
0005435092164	17072	Economy	10200.00
0005433344774	17072	Economy	10200.00
0005433344785	17072	Economy	10200.00
0005433344833	17072	Economy	10200.00
0005435092142	17072	Economy	10200.00
0005433344835	17072	Economy	10200.00
0005435092190	17072	Economy	10200.00
0005433344764	17072	Economy	10200.00
0005433344808	17072	Economy	10200.00
0005433269810	17072	Economy	10200.00
0005433344760	17072	Economy	10200.00
0005433269812	17072	Economy	10200.00
0005433344761	17072	Economy	10200.00
0005433344773	17072	Economy	10200.00
0005433344755	17072	Economy	10200.00
0005435508438	17072	Economy	10200.00
0005433344769	17072	Economy	10200.00
0005433344784	17072	Economy	10200.00
0005433344768	17072	Economy	10200.00
0005433344822	17072	Economy	10200.00
0005433344778	17072	Economy	10200.00
0005433344767	17072	Economy	10200.00
0005433344837	17072	Economy	10200.00
0005435508425	17072	Economy	10200.00
0005435508410	17072	Economy	10200.00
0005433344834	17072	Economy	10200.00
0005433344776	17072	Economy	10200.00
0005435092148	17072	Economy	10200.00
0005433344820	17072	Economy	10200.00
0005433344792	17072	Economy	10200.00
0005433344795	17072	Economy	10200.00
0005433344754	17072	Economy	10200.00
0005433344800	17072	Economy	10200.00
0005433344766	17072	Economy	10200.00
0005433344782	17072	Economy	10200.00
0005433344762	17072	Economy	10200.00
0005433344830	17072	Economy	10200.00
0005433344790	17072	Economy	11200.00
0005433344806	17072	Economy	10200.00
0005433344818	17072	Economy	10200.00
0005433344742	17072	Economy	11200.00
0005433344748	17072	Economy	10200.00
0005433344838	17072	Economy	10200.00
0005433344789	17072	Economy	10200.00
0005433344738	17072	Economy	10200.00
0005433344777	17072	Economy	10200.00
0005433269814	17072	Economy	10200.00
0005433344743	17072	Economy	10200.00
0005433344783	17072	Economy	10200.00
0005433344839	17072	Economy	10200.00
0005433344826	17072	Economy	10200.00
0005435508411	17072	Economy	10200.00
0005433344794	17072	Economy	10200.00
0005433344799	17072	Economy	10200.00
0005433344811	17072	Economy	10200.00
0005435092189	17072	Economy	10200.00
0005433344741	17072	Economy	10200.00
0005433344832	17072	Economy	10200.00
0005435092177	17072	Economy	10200.00
0005433344744	17072	Economy	10200.00
0005433344753	17072	Economy	10200.00
0005433344816	17072	Economy	10200.00
0005433344797	17072	Economy	10200.00
0005433344749	17072	Economy	10200.00
0005433344812	17072	Economy	10200.00
0005433344793	17072	Economy	10200.00
0005435508443	17072	Economy	10200.00
0005433159350	17072	Economy	10200.00
0005433344775	17072	Economy	10200.00
0005433344765	17072	Economy	10200.00
0005433344827	17072	Economy	10200.00
0005433344807	17072	Economy	10200.00
0005433344829	17072	Economy	10200.00
0005433344763	17072	Economy	10200.00
0005433344810	17072	Economy	10200.00
0005433344787	17072	Economy	10200.00
0005433344813	17072	Economy	10200.00
0005433344759	17072	Economy	10200.00
0005433344836	17072	Economy	10200.00
0005435092205	17072	Economy	10200.00
0005433344828	17072	Economy	10200.00
0005433344779	17072	Economy	10200.00
0005433344739	17072	Economy	10200.00
0005433344758	17072	Economy	10200.00
0005433344751	17072	Economy	10200.00
0005433344788	17072	Economy	10200.00
0005432851982	1337	Business	101000.00
0005432390334	1337	Business	101000.00
0005432390324	1337	Business	101000.00
0005432392041	1337	Business	101000.00
0005432390313	1337	Business	101000.00
0005432392047	1337	Business	101000.00
0005432390342	1337	Business	101000.00
0005432390338	1337	Business	101000.00
0005432851967	1337	Business	101000.00
0005432390333	1337	Business	101000.00
0005432851965	1337	Business	101000.00
0005432851984	1337	Business	101000.00
0005432392044	1337	Business	101000.00
0005432390317	1337	Business	101000.00
0005432851985	1337	Business	101000.00
0005432390332	1337	Business	101000.00
0005432390311	1337	Economy	33700.00
0005432851928	1337	Economy	33700.00
0005432390326	1337	Economy	33700.00
0005432851937	1337	Economy	33700.00
0005432851964	1337	Economy	33700.00
0005432390319	1337	Economy	33700.00
0005432390315	1337	Economy	33700.00
0005432390323	1337	Economy	33700.00
0005432390301	1337	Economy	33700.00
0005432851959	1337	Economy	37000.00
0005432390305	1337	Economy	37000.00
0005432851954	1337	Economy	37000.00
0005432390330	1337	Economy	37000.00
0005432390346	1337	Economy	33700.00
0005432390307	1337	Economy	33700.00
0005432390302	1337	Economy	33700.00
0005432390320	1337	Economy	33700.00
0005432392048	1337	Economy	33700.00
0005432390325	1337	Economy	33700.00
0005432851958	1337	Economy	33700.00
0005432390306	1337	Economy	33700.00
0005432390341	1337	Economy	33700.00
0005432390312	1337	Economy	33700.00
0005432851952	1337	Economy	33700.00
0005432390303	1337	Economy	33700.00
0005432851917	1337	Economy	33700.00
0005432390345	1337	Economy	33700.00
0005432851970	1337	Economy	33700.00
0005432390321	1337	Economy	33700.00
0005432390339	1337	Economy	33700.00
0005432390328	1337	Economy	33700.00
0005432851936	1337	Economy	33700.00
0005432390304	1337	Economy	33700.00
0005432851926	1337	Economy	33700.00
0005432392050	1337	Economy	33700.00
0005432390310	1337	Economy	33700.00
0005432392042	1337	Economy	33700.00
0005432390316	1337	Economy	33700.00
0005432851960	1337	Economy	33700.00
0005432392051	1337	Economy	33700.00
0005432851962	1337	Economy	33700.00
0005432390337	1337	Economy	33700.00
0005432390327	1337	Economy	33700.00
0005432390340	1337	Economy	33700.00
0005432390322	1337	Economy	33700.00
0005432392040	1337	Economy	33700.00
0005432851953	1337	Economy	33700.00
0005432392049	1337	Economy	33700.00
0005432390347	1337	Economy	33700.00
0005432390314	1337	Economy	33700.00
0005432390344	1337	Economy	33700.00
0005432390309	1337	Economy	33700.00
0005432390349	1337	Economy	33700.00
0005432390335	1337	Economy	33700.00
0005432390308	1337	Economy	33700.00
0005432851950	1337	Economy	33700.00
0005432392038	1337	Economy	33700.00
0005432390331	1337	Economy	33700.00
0005432852008	1337	Economy	33700.00
0005432392043	1337	Economy	33700.00
0005432851961	1337	Economy	33700.00
0005432851956	1337	Economy	33700.00
0005432390329	1337	Economy	33700.00
0005432390336	1337	Economy	33700.00
0005432851963	1337	Economy	33700.00
0005432390348	1337	Economy	33700.00
0005432851971	1337	Economy	33700.00
0005432392045	1337	Economy	33700.00
0005432392046	1337	Economy	33700.00
0005432851951	1337	Economy	33700.00
0005432392039	1337	Economy	33700.00
0005432390343	1337	Economy	33700.00
0005432390318	1337	Economy	33700.00
0005434026716	12772	Business	40300.00
0005434068037	12772	Business	40300.00
0005434068016	12772	Business	40300.00
0005434082034	12772	Business	40300.00
0005434068027	12772	Business	40300.00
0005434067988	12772	Business	40300.00
0005434067989	12772	Business	40300.00
0005434068171	12772	Business	40300.00
0005434068144	12772	Business	40300.00
0005434068190	12772	Business	40300.00
0005434068357	12772	Business	40300.00
0005434082050	12772	Economy	13400.00
0005434067955	12772	Economy	13400.00
0005434068329	12772	Economy	13400.00
0005432159938	12772	Economy	13400.00
0005432433774	12772	Economy	13400.00
0005434068280	12772	Economy	13400.00
0005434068058	12772	Economy	13400.00
0005433989820	12772	Economy	13400.00
0005433812942	12772	Economy	13400.00
0005432433771	12772	Economy	13400.00
0005434068033	12772	Economy	13400.00
0005434068004	12772	Economy	13400.00
0005434068036	12772	Economy	13400.00
0005434068110	12772	Economy	13400.00
0005434068326	12772	Economy	13400.00
0005434067991	12772	Economy	13400.00
0005434068157	12772	Economy	13400.00
0005432159939	12772	Economy	13400.00
0005434068207	12772	Economy	13400.00
0005434082083	12772	Economy	13400.00
0005434082060	12772	Economy	13400.00
0005434067738	12772	Economy	13400.00
0005434068205	12772	Economy	13400.00
0005434068109	12772	Economy	13400.00
0005434068155	12772	Economy	13400.00
0005434067846	12772	Economy	13400.00
0005433989806	12772	Economy	13400.00
0005434067993	12772	Economy	13400.00
0005432161192	12772	Economy	13400.00
0005434068082	12772	Economy	13400.00
0005433812943	12772	Economy	13400.00
0005434068114	12772	Economy	13400.00
0005434068055	12772	Economy	13400.00
0005434067912	12772	Economy	13400.00
0005434068096	12772	Economy	13400.00
0005434068084	12772	Economy	13400.00
0005434068414	12772	Economy	13400.00
0005434067898	12772	Economy	14800.00
0005434082055	12772	Economy	14800.00
0005434067990	12772	Economy	14800.00
0005434068146	12772	Economy	14800.00
0005434067910	12772	Economy	14800.00
0005434068141	12772	Economy	14800.00
0005434068032	12772	Economy	13400.00
0005434067936	12772	Economy	13400.00
0005432433770	12772	Economy	13400.00
0005434067972	12772	Economy	13400.00
0005434067996	12772	Economy	13400.00
0005434068314	12772	Economy	13400.00
0005434068180	12772	Economy	13400.00
0005434068277	12772	Economy	13400.00
0005434082104	12772	Economy	13400.00
0005433989783	12772	Economy	13400.00
0005434082061	12772	Economy	13400.00
0005434068111	12772	Economy	13400.00
0005433989807	12772	Economy	13400.00
0005434067937	12772	Economy	13400.00
0005434068196	12772	Economy	13400.00
0005434068056	12772	Economy	13400.00
0005434082059	12772	Economy	13400.00
0005434068179	12772	Economy	13400.00
0005434082097	12772	Economy	13400.00
0005433989819	12772	Economy	13400.00
0005434068154	12772	Economy	13400.00
0005434082043	12772	Economy	13400.00
0005434082074	12772	Economy	13400.00
0005434068276	12772	Economy	13400.00
0005434082036	12772	Economy	13400.00
0005434082072	12772	Economy	13400.00
0005434068328	12772	Economy	13400.00
0005434067928	12772	Economy	13400.00
0005434068206	12772	Economy	13400.00
0005434082044	12772	Economy	13400.00
0005434067978	12772	Economy	13400.00
0005434082035	12772	Economy	13400.00
0005434068059	12772	Economy	13400.00
0005433989795	12772	Economy	13400.00
0005434082047	12772	Economy	13400.00
0005434081996	12772	Economy	13400.00
0005434067911	12772	Economy	13400.00
0005434082086	12772	Economy	13400.00
0005432161191	12772	Economy	13400.00
0005434082095	12772	Economy	13400.00
0005434068142	12772	Economy	13400.00
0005432159937	12772	Economy	13400.00
0005434082046	12772	Economy	13400.00
0005434082120	12772	Economy	13400.00
0005434068017	12772	Economy	13400.00
0005434067867	12772	Economy	13400.00
0005432433776	12772	Economy	13400.00
0005432433772	12772	Economy	13400.00
0005432159936	12772	Economy	13400.00
0005434082045	12772	Economy	13400.00
0005434068138	12772	Economy	13400.00
0005434068313	12772	Economy	13400.00
0005434068223	12772	Economy	13400.00
0005432433773	12772	Economy	13400.00
0005434082051	12772	Economy	13400.00
0005434082098	12772	Economy	13400.00
0005434068145	12772	Economy	13400.00
0005434082085	12772	Economy	13400.00
0005434082037	12772	Economy	13400.00
0005434067941	12772	Economy	13400.00
0005432433775	12772	Economy	13400.00
0005434067959	12772	Economy	13400.00
0005434082048	12772	Economy	13400.00
0005434068224	12772	Economy	13400.00
0005434067973	12772	Economy	13400.00
0005434068031	12772	Economy	13400.00
0005433812941	12772	Economy	13400.00
0005434082077	12772	Economy	13400.00
0005434082096	12772	Economy	13400.00
0005434068057	12772	Economy	13400.00
0005434068691	30665	Business	40300.00
0005434082282	30665	Business	40300.00
0005434068751	30665	Business	40300.00
0005434068761	30665	Business	40300.00
0005434082268	30665	Business	40300.00
0005434068739	30665	Business	40300.00
0005434068729	30665	Business	40300.00
0005434068730	30665	Business	40300.00
0005434068742	30665	Business	40300.00
0005434068753	30665	Business	40300.00
0005434068694	30665	Business	40300.00
0005434082273	30665	Business	40300.00
0005434082262	30665	Economy	13400.00
0005434068716	30665	Economy	13400.00
0005434082274	30665	Economy	13400.00
0005432186928	30665	Economy	13400.00
0005434082280	30665	Economy	13400.00
0005432150327	30665	Economy	13400.00
0005432433715	30665	Economy	13400.00
0005434068715	30665	Economy	13400.00
0005434068703	30665	Economy	13400.00
0005433989849	30665	Economy	13400.00
0005434068699	30665	Economy	13400.00
0005434068763	30665	Economy	13400.00
0005434068732	30665	Economy	13400.00
0005434068734	30665	Economy	13400.00
0005434068710	30665	Economy	13400.00
0005432186927	30665	Economy	13400.00
0005434068755	30665	Economy	13400.00
0005434068705	30665	Economy	13400.00
0005434068759	30665	Economy	13400.00
0005432186930	30665	Economy	13400.00
0005433989851	30665	Economy	13400.00
0005434068752	30665	Economy	13400.00
0005434068740	30665	Economy	13400.00
0005434068737	30665	Economy	13400.00
0005434068695	30665	Economy	13400.00
0005432150325	30665	Economy	13400.00
0005432150321	30665	Economy	13400.00
0005434068746	30665	Economy	13400.00
0005434068712	30665	Economy	13400.00
0005434068733	30665	Economy	13400.00
0005434068708	30665	Economy	13400.00
0005434068702	30665	Economy	13400.00
0005432433726	30665	Economy	13400.00
0005434082266	30665	Economy	13400.00
0005434068701	30665	Economy	14800.00
0005434068723	30665	Economy	14800.00
0005434082278	30665	Economy	14800.00
0005434068717	30665	Economy	14800.00
0005434068713	30665	Economy	14800.00
0005434068762	30665	Economy	13400.00
0005434068743	30665	Economy	13400.00
0005434068741	30665	Economy	13400.00
0005433989850	30665	Economy	13400.00
0005434068758	30665	Economy	13400.00
0005434068735	30665	Economy	13400.00
0005434068727	30665	Economy	13400.00
0005434068698	30665	Economy	13400.00
0005434082265	30665	Economy	13400.00
0005434082279	30665	Economy	13400.00
0005434068756	30665	Economy	13400.00
0005435283409	30665	Economy	13400.00
0005434068707	30665	Economy	13400.00
0005432150320	30665	Economy	13400.00
0005434068738	30665	Economy	13400.00
0005434068706	30665	Economy	13400.00
0005434082283	30665	Economy	13400.00
0005434068749	30665	Economy	13400.00
0005434068745	30665	Economy	13400.00
0005434068744	30665	Economy	13400.00
0005434068731	30665	Economy	13400.00
0005433989847	30665	Economy	13400.00
0005434068728	30665	Economy	13400.00
0005434068748	30665	Economy	13400.00
0005434082271	30665	Economy	13400.00
0005434068709	30665	Economy	13400.00
0005434068693	30665	Economy	13400.00
0005434082264	30665	Economy	13400.00
0005434068704	30665	Economy	13400.00
0005432150324	30665	Economy	13400.00
0005434068726	30665	Economy	13400.00
0005434068714	30665	Economy	13400.00
0005434082267	30665	Economy	13400.00
0005434082270	30665	Economy	13400.00
0005434068719	30665	Economy	13400.00
0005434068697	30665	Economy	13400.00
0005435283410	30665	Economy	13400.00
0005434082276	30665	Economy	13400.00
0005433989848	30665	Economy	13400.00
0005434068736	30665	Economy	13400.00
0005434082284	30665	Economy	13400.00
0005432150323	30665	Economy	13400.00
0005434068718	30665	Economy	13400.00
0005434068692	30665	Economy	13400.00
0005434068725	30665	Economy	13400.00
0005434082272	30665	Economy	13400.00
0005434068747	30665	Economy	13400.00
0005434068721	30665	Economy	13400.00
0005434068700	30665	Economy	13400.00
0005434068750	30665	Economy	13400.00
0005434068760	30665	Economy	13400.00
0005434068696	30665	Economy	13400.00
0005434082277	30665	Economy	13400.00
0005432150326	30665	Economy	13400.00
0005434082263	30665	Economy	13400.00
0005434068720	30665	Economy	13400.00
0005434082275	30665	Economy	13400.00
0005434068722	30665	Economy	13400.00
0005434068711	30665	Economy	13400.00
0005432186929	30665	Economy	13400.00
0005434068754	30665	Economy	13400.00
0005432150322	30665	Economy	13400.00
0005434082281	30665	Economy	13400.00
0005434068724	30665	Economy	13400.00
0005434082269	30665	Economy	13400.00
0005434068757	30665	Economy	13400.00
0005433686673	9038	Economy	19300.00
0005433687747	9038	Economy	17600.00
0005433685565	9038	Economy	17600.00
0005433687745	9038	Economy	17600.00
0005433687744	9038	Economy	17600.00
0005433687742	9038	Economy	17600.00
0005433687743	9038	Economy	17600.00
0005433686671	9038	Economy	17600.00
0005433687746	9038	Economy	17600.00
0005433685562	9038	Economy	17600.00
0005433686676	9038	Economy	17600.00
0005433685560	9038	Economy	17600.00
0005433686672	9038	Economy	17600.00
0005433686674	9038	Economy	17600.00
0005433685561	9038	Economy	17600.00
0005433685564	9038	Economy	17600.00
0005433685563	9038	Economy	17600.00
0005433686677	9038	Economy	17600.00
0005433686675	9038	Economy	17600.00
0005432535865	5529	Business	35300.00
0005434265292	5529	Business	35300.00
0005435462772	5529	Business	35300.00
0005434265342	5529	Business	35300.00
0005432140586	5529	Business	35300.00
0005435767270	5529	Business	35300.00
0005432140589	5529	Business	35300.00
0005435462704	5529	Business	35300.00
0005435462827	5529	Business	35300.00
0005435767276	5529	Business	35300.00
0005435767252	5529	Business	35300.00
0005435462731	5529	Business	35300.00
0005435462649	5529	Business	35300.00
0005435462630	5529	Business	35300.00
0005435462799	5529	Business	35300.00
0005435462675	5529	Business	35300.00
0005435767242	5529	Business	35300.00
0005435722095	5529	Business	35300.00
0005435767254	5529	Business	35300.00
0005434265321	5529	Business	35300.00
0005435462828	5529	Business	35300.00
0005435767255	5529	Business	35300.00
0005434265417	5529	Business	35300.00
0005432140593	5529	Business	35300.00
0005434265413	5529	Business	35300.00
0005432140587	5529	Business	35300.00
0005434265332	5529	Economy	12900.00
0005435767286	5529	Economy	12900.00
0005435767288	5529	Economy	12900.00
0005432140591	5529	Economy	11800.00
0005435462547	5529	Economy	11800.00
0005435767229	5529	Economy	11800.00
0005435462685	5529	Economy	11800.00
0005432140588	5529	Economy	11800.00
0005434265422	5529	Economy	11800.00
0005435462664	5529	Economy	11800.00
0005435767283	5529	Economy	11800.00
0005434831179	5529	Economy	11800.00
0005435767249	5529	Economy	11800.00
0005435767260	5529	Economy	11800.00
0005435767281	5529	Economy	11800.00
0005433527335	5529	Economy	11800.00
0005435735215	5529	Economy	11800.00
0005435735213	5529	Economy	11800.00
0005434265340	5529	Economy	11800.00
0005435767228	5529	Economy	11800.00
0005432535877	5529	Economy	11800.00
0005435462743	5529	Economy	11800.00
0005433527333	5529	Economy	11800.00
0005435767280	5529	Economy	11800.00
0005435462784	5529	Economy	11800.00
0005434265301	5529	Economy	11800.00
0005435735217	5529	Economy	11800.00
0005435767253	5529	Economy	11800.00
0005435767256	5529	Economy	11800.00
0005435462712	5529	Economy	11800.00
0005435722097	5529	Economy	11800.00
0005435767236	5529	Economy	11800.00
0005435725683	5529	Economy	11800.00
0005435767246	5529	Economy	11800.00
0005435725684	5529	Economy	11800.00
0005435767231	5529	Economy	11800.00
0005435767261	5529	Economy	11800.00
0005435462909	5529	Economy	11800.00
0005435767234	5529	Economy	11800.00
0005435767240	5529	Economy	11800.00
0005435462807	5529	Economy	11800.00
0005435462636	5529	Economy	11800.00
0005434265352	5529	Economy	11800.00
0005435725682	5529	Economy	11800.00
0005435767287	5529	Economy	11800.00
0005435767241	5529	Economy	11800.00
0005434265276	5529	Economy	11800.00
0005435767225	5529	Economy	11800.00
0005435767273	5529	Economy	11800.00
0005435462742	5529	Economy	11800.00
0005435735212	5529	Economy	11800.00
0005435767238	5529	Economy	11800.00
0005435767279	5529	Economy	11800.00
0005434265271	5529	Economy	11800.00
0005435767278	5529	Economy	11800.00
0005435462733	5529	Economy	11800.00
0005434265386	5529	Economy	11800.00
0005435767237	5529	Economy	11800.00
0005432535876	5529	Economy	11800.00
0005435462734	5529	Economy	11800.00
0005432535867	5529	Economy	11800.00
0005434265388	5529	Economy	11800.00
0005435462762	5529	Economy	11800.00
0005435462783	5529	Economy	11800.00
0005434265351	5529	Economy	11800.00
0005435767230	5529	Economy	11800.00
0005435767233	5529	Economy	11800.00
0005434265357	5529	Economy	11800.00
0005434265354	5529	Economy	11800.00
0005435462900	5529	Economy	11800.00
0005435767243	5529	Economy	11800.00
0005435767239	5529	Economy	11800.00
0005435462910	5529	Economy	11800.00
0005435767258	5529	Economy	11800.00
0005434831174	5529	Economy	11800.00
0005435462651	5529	Economy	11800.00
0005435725681	5529	Economy	11800.00
0005435767262	5529	Economy	11800.00
0005435767284	5529	Economy	11800.00
0005435462740	5529	Economy	12900.00
0005435462648	5529	Economy	12900.00
0005435462663	5529	Economy	11800.00
0005434265302	5529	Economy	11800.00
0005434265414	5529	Economy	11800.00
0005435767248	5529	Economy	12900.00
0005435462755	5529	Economy	11800.00
0005432140590	5529	Economy	11800.00
0005434265434	5529	Economy	11800.00
0005435767263	5529	Economy	11800.00
0005434265478	5529	Economy	11800.00
0005435462650	5529	Economy	11800.00
0005435462813	5529	Economy	11800.00
0005435735214	5529	Economy	11800.00
0005434265348	5529	Economy	11800.00
0005435767265	5529	Economy	11800.00
0005435722096	5529	Economy	11800.00
0005434265290	5529	Economy	11800.00
0005435767235	5529	Economy	11800.00
0005435767285	5529	Economy	11800.00
0005435735216	5529	Economy	11800.00
0005435767227	5529	Economy	11800.00
0005435462794	5529	Economy	11800.00
0005434265356	5529	Economy	11800.00
0005435767268	5529	Economy	11800.00
0005435462778	5529	Economy	11800.00
0005432535872	5529	Economy	11800.00
0005435722098	5529	Economy	11800.00
0005435767271	5529	Economy	11800.00
0005435767269	5529	Economy	11800.00
0005434265333	5529	Economy	11800.00
0005435462814	5529	Economy	11800.00
0005435462782	5529	Economy	11800.00
0005434265236	5529	Economy	11800.00
0005434265326	5529	Economy	11800.00
0005435767232	5529	Economy	11800.00
0005432140592	5529	Economy	11800.00
0005433529345	5529	Economy	11800.00
0005435767264	5529	Economy	11800.00
0005435462773	5529	Economy	11800.00
0005435767250	5529	Economy	11800.00
0005435462779	5529	Economy	11800.00
0005434265237	5529	Economy	11800.00
0005434265341	5529	Economy	11800.00
0005435767266	5529	Economy	11800.00
0005435767244	5529	Economy	11800.00
0005435462652	5529	Economy	11800.00
0005435767257	5529	Economy	11800.00
0005435767277	5529	Economy	11800.00
0005434265358	5529	Economy	11800.00
0005435767275	5529	Economy	11800.00
0005435767274	5529	Economy	11800.00
0005432535873	5529	Economy	11800.00
0005435767251	5529	Economy	11800.00
0005434265291	5529	Economy	11800.00
0005434265418	5529	Economy	11800.00
0005435767289	5529	Economy	11800.00
0005433529346	5529	Economy	11800.00
0005435767247	5529	Economy	11800.00
0005435462833	5529	Economy	11800.00
0005434265385	5529	Economy	11800.00
0005435767272	5529	Economy	11800.00
0005435767259	5529	Economy	11800.00
0005434265275	5529	Economy	11800.00
0005434265410	5529	Economy	11800.00
0005433527334	5529	Economy	11800.00
0005435767226	5529	Economy	11800.00
0005435767282	5529	Economy	11800.00
0005435767267	5529	Economy	11800.00
0005435767245	5529	Economy	11800.00
0005435043295	13460	Business	35300.00
0005435463087	13460	Business	35300.00
0005434265593	13460	Business	35300.00
0005435766671	13460	Business	35300.00
0005435766909	13460	Business	35300.00
0005435766972	13460	Business	35300.00
0005435725635	13460	Business	35300.00
0005435766819	13460	Business	35300.00
0005434265583	13460	Business	35300.00
0005435766777	13460	Business	35300.00
0005435463107	13460	Business	35300.00
0005435723058	13460	Business	35300.00
0005435766498	13460	Business	35300.00
0005435766711	13460	Business	35300.00
0005435766908	13460	Business	35300.00
0005435766778	13460	Business	35300.00
0005434831235	13460	Business	35300.00
0005434265585	13460	Business	35300.00
0005432535919	13460	Business	35300.00
0005435463090	13460	Business	35300.00
0005435463082	13460	Business	35300.00
0005435043296	13460	Business	35300.00
0005434265598	13460	Economy	12900.00
0005435463086	13460	Economy	12900.00
0005435463076	13460	Economy	11800.00
0005435766985	13460	Economy	12900.00
0005434265588	13460	Economy	11800.00
0005435463102	13460	Economy	11800.00
0005435766491	13460	Economy	11800.00
0005435463070	13460	Economy	11800.00
0005435766582	13460	Economy	11800.00
0005435766528	13460	Economy	11800.00
0005432535917	13460	Economy	11800.00
0005435766765	13460	Economy	11800.00
0005435766907	13460	Economy	11800.00
0005434265581	13460	Economy	11800.00
0005435766572	13460	Economy	11800.00
0005432535916	13460	Economy	11800.00
0005435766564	13460	Economy	11800.00
0005435722058	13460	Economy	11800.00
0005435766767	13460	Economy	11800.00
0005435766837	13460	Economy	11800.00
0005435766672	13460	Economy	11800.00
0005435735182	13460	Economy	11800.00
0005435766887	13460	Economy	11800.00
0005435766434	13460	Economy	11800.00
0005435766675	13460	Economy	11800.00
0005435766827	13460	Economy	11800.00
0005435463072	13460	Economy	11800.00
0005435463073	13460	Economy	11800.00
0005435766818	13460	Economy	11800.00
0005435463101	13460	Economy	11800.00
0005435463088	13460	Economy	11800.00
0005435766859	13460	Economy	11800.00
0005435463097	13460	Economy	11800.00
0005435463095	13460	Economy	11800.00
0005435766665	13460	Economy	11800.00
0005435463085	13460	Economy	11800.00
0005435723065	13460	Economy	11800.00
0005435766712	13460	Economy	11800.00
0005432194585	13460	Economy	11800.00
0005434831232	13460	Economy	11800.00
0005435725650	13460	Economy	11800.00
0005435766965	13460	Economy	11800.00
0005434265575	13460	Economy	11800.00
0005435766490	13460	Economy	11800.00
0005435766829	13460	Economy	11800.00
0005435735165	13460	Economy	11800.00
0005434265596	13460	Economy	11800.00
0005435766885	13460	Economy	11800.00
0005434265587	13460	Economy	11800.00
0005435463084	13460	Economy	11800.00
0005434831234	13460	Economy	11800.00
0005435766865	13460	Economy	11800.00
0005435766781	13460	Economy	11800.00
0005435767060	13460	Economy	11800.00
0005432535920	13460	Economy	11800.00
0005434265599	13460	Economy	11800.00
0005435766826	13460	Economy	11800.00
0005434265582	13460	Economy	11800.00
0005435766684	13460	Economy	11800.00
0005435766779	13460	Economy	11800.00
0005435722069	13460	Economy	11800.00
0005434265594	13460	Economy	11800.00
0005435766780	13460	Economy	11800.00
0005435766882	13460	Economy	11800.00
0005435725637	13460	Economy	11800.00
0005435463079	13460	Economy	11800.00
0005435766719	13460	Economy	11800.00
0005435766830	13460	Economy	11800.00
0005435766630	13460	Economy	11800.00
0005435723054	13460	Economy	11800.00
0005435463077	13460	Economy	11800.00
0005434265577	13460	Economy	11800.00
0005435766660	13460	Economy	11800.00
0005435766949	13460	Economy	11800.00
0005435463074	13460	Economy	11800.00
0005435463105	13460	Economy	11800.00
0005434265589	13460	Economy	11800.00
0005435766846	13460	Economy	11800.00
0005435463071	13460	Economy	11800.00
0005434265600	13460	Economy	11800.00
0005435463078	13460	Economy	11800.00
0005435766904	13460	Economy	11800.00
0005435766714	13460	Economy	11800.00
0005432194582	13460	Economy	11800.00
0005435766850	13460	Economy	11800.00
0005435463094	13460	Economy	11800.00
0005435766844	13460	Economy	11800.00
0005434265584	13460	Economy	11800.00
0005435463089	13460	Economy	12900.00
0005435766581	13460	Economy	12900.00
0005435463081	13460	Economy	11800.00
0005435463098	13460	Economy	11800.00
0005434265597	13460	Economy	12900.00
0005435766948	13460	Economy	11800.00
0005435766643	13460	Economy	12900.00
0005435766699	13460	Economy	11800.00
0005435766785	13460	Economy	11800.00
0005435766720	13460	Economy	11800.00
0005435766884	13460	Economy	11800.00
0005435766854	13460	Economy	11800.00
0005435463092	13460	Economy	11800.00
0005435463106	13460	Economy	11800.00
0005435463099	13460	Economy	11800.00
0005435723064	13460	Economy	11800.00
0005435766652	13460	Economy	11800.00
0005435766685	13460	Economy	11800.00
0005435766565	13460	Economy	11800.00
0005435723059	13460	Economy	11800.00
0005435766733	13460	Economy	11800.00
0005435463093	13460	Economy	11800.00
0005435766649	13460	Economy	11800.00
0005432194583	13460	Economy	11800.00
0005434265586	13460	Economy	11800.00
0005434265578	13460	Economy	11800.00
0005435723063	13460	Economy	11800.00
0005435766615	13460	Economy	11800.00
0005435766687	13460	Economy	11800.00
0005435766563	13460	Economy	11800.00
0005434265579	13460	Economy	11800.00
0005435735167	13460	Economy	11800.00
0005435463103	13460	Economy	11800.00
0005435463091	13460	Economy	11800.00
0005434265576	13460	Economy	11800.00
0005435766881	13460	Economy	11800.00
0005434265580	13460	Economy	11800.00
0005435766731	13460	Economy	11800.00
0005432194581	13460	Economy	11800.00
0005435463075	13460	Economy	11800.00
0005435766883	13460	Economy	11800.00
0005434265591	13460	Economy	11800.00
0005435463083	13460	Economy	11800.00
0005435463080	13460	Economy	11800.00
0005435766843	13460	Economy	11800.00
0005435463096	13460	Economy	11800.00
0005435725634	13460	Economy	11800.00
0005435766984	13460	Economy	11800.00
0005432194584	13460	Economy	11800.00
0005435766661	13460	Economy	11800.00
0005434831233	13460	Economy	11800.00
0005435766947	13460	Economy	11800.00
0005435722068	13460	Economy	11800.00
0005432535918	13460	Economy	11800.00
0005434265590	13460	Economy	11800.00
0005435766433	13460	Economy	11800.00
0005435766766	13460	Economy	11800.00
0005434265595	13460	Economy	11800.00
0005435766616	13460	Economy	11800.00
0005435463108	13460	Economy	11800.00
0005435463104	13460	Economy	11800.00
0005435766626	13460	Economy	11800.00
0005435766414	13460	Economy	11800.00
0005435766584	13460	Economy	11800.00
0005434265592	13460	Economy	11800.00
0005435766642	13460	Economy	11800.00
0005435463100	13460	Economy	11800.00
0005434602913	18658	Economy	3300.00
0005434604926	18634	Economy	3300.00
0005434604925	18634	Economy	3300.00
0005434515011	18634	Economy	3300.00
0005434513624	18634	Economy	3300.00
0005434515012	18634	Economy	3300.00
0005434513625	18634	Economy	3300.00
0005434513622	18634	Economy	3300.00
0005434513623	18634	Economy	3300.00
0005434514989	19133	Economy	3300.00
0005434514981	19133	Economy	3300.00
0005434514990	19133	Economy	3300.00
0005432649504	4129	Business	88300.00
0005432632860	4129	Business	88300.00
0005432632855	4129	Business	88300.00
0005432649503	4129	Business	88300.00
0005432649510	4129	Business	88300.00
0005432632857	4129	Economy	29400.00
0005432632865	4129	Economy	29400.00
0005432649512	4129	Economy	29400.00
0005435846293	4129	Economy	29400.00
0005432649502	4129	Economy	29400.00
0005432632862	4129	Economy	32400.00
0005435844348	4129	Economy	29400.00
0005432632854	4129	Economy	29400.00
0005432632867	4129	Economy	29400.00
0005432649509	4129	Economy	29400.00
0005435846276	4129	Economy	29400.00
0005432632861	4129	Economy	29400.00
0005432632859	4129	Economy	29400.00
0005432649505	4129	Economy	29400.00
0005432632856	4129	Economy	29400.00
0005432632863	4129	Economy	29400.00
0005432649511	4129	Economy	29400.00
0005432649506	4129	Economy	29400.00
0005432632864	4129	Economy	29400.00
0005432649508	4129	Economy	29400.00
0005435846256	4129	Economy	29400.00
0005435846272	4129	Economy	29400.00
0005432632866	4129	Economy	29400.00
0005432649507	4129	Economy	29400.00
0005432649501	4129	Economy	29400.00
0005435844349	4129	Economy	29400.00
0005435846285	4129	Economy	29400.00
0005435844347	4129	Economy	29400.00
0005435844356	4129	Economy	29400.00
0005432632858	4129	Economy	29400.00
0005435844346	4129	Economy	29400.00
0005433285670	1830	Business	48700.00
0005433009077	1830	Business	48700.00
0005433810614	1830	Business	48700.00
0005432295927	1830	Business	48700.00
0005433008910	1830	Business	48700.00
0005433008962	1830	Business	48700.00
0005433285661	1830	Business	48700.00
0005433285699	1830	Business	48700.00
0005433008961	1830	Business	48700.00
0005433008963	1830	Business	48700.00
0005433009063	1830	Business	48700.00
0005433009017	1830	Economy	16200.00
0005433009096	1830	Economy	16200.00
0005433008919	1830	Economy	16200.00
0005433009132	1830	Economy	16200.00
0005433009007	1830	Economy	16200.00
0005433008979	1830	Economy	16200.00
0005433285520	1830	Economy	16200.00
0005433009008	1830	Economy	16200.00
0005433009059	1830	Economy	16200.00
0005433285587	1830	Economy	16200.00
0005433285487	1830	Economy	17900.00
0005433009110	1830	Economy	17900.00
0005433009067	1830	Economy	17900.00
0005433008960	1830	Economy	17900.00
0005433009010	1830	Economy	17900.00
0005433285485	1830	Economy	16200.00
0005433285674	1830	Economy	16200.00
0005432295925	1830	Economy	16200.00
0005433008981	1830	Economy	16200.00
0005433008970	1830	Economy	16200.00
0005433009026	1830	Economy	16200.00
0005433008931	1830	Economy	16200.00
0005433285575	1830	Economy	16200.00
0005433285764	1830	Economy	16200.00
0005433285628	1830	Economy	16200.00
0005433285513	1830	Economy	16200.00
0005433008932	1830	Economy	16200.00
0005433008977	1830	Economy	16200.00
0005433009149	1830	Economy	16200.00
0005433285479	1830	Economy	16200.00
0005433285411	1830	Economy	16200.00
0005433285626	1830	Economy	16200.00
0005433285600	1830	Economy	16200.00
0005432295926	1830	Economy	16200.00
0005433285602	1830	Economy	16200.00
0005433285582	1830	Economy	16200.00
0005433810615	1830	Economy	16200.00
0005433009009	1830	Economy	16200.00
0005433285583	1830	Economy	16200.00
0005433285499	1830	Economy	16200.00
0005433009080	1830	Economy	16200.00
0005433285664	1830	Economy	16200.00
0005433285550	1830	Economy	16200.00
0005433008846	1830	Economy	16200.00
0005433285486	1830	Economy	16200.00
0005433285543	1830	Economy	16200.00
0005433009062	1830	Economy	16200.00
0005433285498	1830	Economy	16200.00
0005433285549	1830	Economy	16200.00
0005433285625	1830	Economy	16200.00
0005433009058	1830	Economy	16200.00
0005433008983	1830	Economy	16200.00
0005433285412	1830	Economy	16200.00
0005433285700	1830	Economy	16200.00
0005433009148	1830	Economy	16200.00
0005433285545	1830	Economy	16200.00
0005433009081	1830	Economy	16200.00
0005433285463	1830	Economy	16200.00
0005433009111	1830	Economy	16200.00
0005433008918	1830	Economy	16200.00
0005433285629	1830	Economy	16200.00
0005433008982	1830	Economy	16200.00
0005433009138	1830	Economy	16200.00
0005433285410	1830	Economy	16200.00
0005433008980	1830	Economy	16200.00
0005433285599	1830	Economy	16200.00
0005433009024	1830	Economy	16200.00
0005433008976	1830	Economy	16200.00
0005433285519	1830	Economy	16200.00
0005433285604	1830	Economy	16200.00
0005433008997	1830	Economy	16200.00
0005433009047	1830	Economy	16200.00
0005433008907	1830	Economy	16200.00
0005433285478	1830	Economy	16200.00
0005433009051	1830	Economy	16200.00
0005433009131	1830	Economy	16200.00
0005433285565	1830	Economy	16200.00
0005433008971	1830	Economy	16200.00
0005433009360	22515	Business	48700.00
0005433009356	22515	Business	48700.00
0005433810574	22515	Business	48700.00
0005433009375	22515	Business	48700.00
0005433009391	22515	Business	48700.00
0005433009382	22515	Business	48700.00
0005433009368	22515	Business	48700.00
0005433810567	22515	Business	48700.00
0005433285817	22515	Business	48700.00
0005433285831	22515	Business	48700.00
0005433009377	22515	Economy	16200.00
0005433009381	22515	Economy	16200.00
0005433285809	22515	Economy	16200.00
0005433285818	22515	Economy	16200.00
0005433009389	22515	Economy	16200.00
0005433009393	22515	Economy	16200.00
0005433009379	22515	Economy	16200.00
0005433009384	22515	Economy	16200.00
0005433810568	22515	Economy	16200.00
0005433285829	22515	Economy	16200.00
0005433009392	22515	Economy	17900.00
0005433285822	22515	Economy	17900.00
0005433009358	22515	Economy	17900.00
0005433009369	22515	Economy	17900.00
0005433009354	22515	Economy	16200.00
0005433285830	22515	Economy	16200.00
0005433285833	22515	Economy	16200.00
0005433009359	22515	Economy	16200.00
0005433009374	22515	Economy	16200.00
0005433285812	22515	Economy	16200.00
0005433810573	22515	Economy	16200.00
0005433285820	22515	Economy	16200.00
0005433009388	22515	Economy	16200.00
0005433285827	22515	Economy	16200.00
0005433285805	22515	Economy	16200.00
0005433009386	22515	Economy	16200.00
0005433009353	22515	Economy	16200.00
0005433009376	22515	Economy	16200.00
0005433009367	22515	Economy	16200.00
0005433285834	22515	Economy	16200.00
0005433009371	22515	Economy	16200.00
0005433009370	22515	Economy	16200.00
0005433009395	22515	Economy	16200.00
0005433009387	22515	Economy	16200.00
0005433009396	22515	Economy	16200.00
0005433285807	22515	Economy	16200.00
0005433285814	22515	Economy	16200.00
0005433285835	22515	Economy	16200.00
0005433009364	22515	Economy	16200.00
0005433009372	22515	Economy	16200.00
0005433009398	22515	Economy	16200.00
0005433285810	22515	Economy	16200.00
0005433285816	22515	Economy	16200.00
0005433285826	22515	Economy	16200.00
0005433285832	22515	Economy	16200.00
0005433285813	22515	Economy	16200.00
0005433009365	22515	Economy	16200.00
0005433009357	22515	Economy	16200.00
0005433009385	22515	Economy	16200.00
0005433285823	22515	Economy	16200.00
0005433009355	22515	Economy	16200.00
0005433009394	22515	Economy	16200.00
0005433810572	22515	Economy	16200.00
0005433009373	22515	Economy	16200.00
0005433285824	22515	Economy	16200.00
0005433009383	22515	Economy	16200.00
0005433009397	22515	Economy	16200.00
0005433009380	22515	Economy	16200.00
0005433009361	22515	Economy	16200.00
0005433009363	22515	Economy	16200.00
0005433009366	22515	Economy	16200.00
0005433285806	22515	Economy	16200.00
0005433285825	22515	Economy	16200.00
0005433285808	22515	Economy	16200.00
0005433285828	22515	Economy	16200.00
0005433285821	22515	Economy	16200.00
0005433009362	22515	Economy	16200.00
0005433009378	22515	Economy	16200.00
0005433009390	22515	Economy	16200.00
0005433285815	22515	Economy	16200.00
0005433285811	22515	Economy	16200.00
0005433285819	22515	Economy	16200.00
0005432755111	12291	Business	83800.00
0005432751545	12291	Business	83800.00
0005432751558	12291	Business	83800.00
0005432755087	12291	Economy	27900.00
0005432751539	12291	Economy	30700.00
0005432751534	12291	Economy	30700.00
0005432751554	12291	Economy	30700.00
0005432755073	12291	Economy	27900.00
0005432751535	12291	Economy	27900.00
0005432751536	12291	Economy	27900.00
0005432755090	12291	Economy	27900.00
0005432751549	12291	Economy	27900.00
0005432755097	12291	Economy	27900.00
0005432755095	12291	Economy	27900.00
0005432755094	12291	Economy	27900.00
0005432755104	12291	Economy	27900.00
0005432751546	12291	Economy	27900.00
0005432755089	12291	Economy	27900.00
0005432755110	12291	Economy	27900.00
0005432755075	12291	Economy	27900.00
0005434152824	12291	Economy	27900.00
0005432755088	12291	Economy	27900.00
0005432751555	12291	Economy	27900.00
0005432751551	12291	Economy	27900.00
0005432755100	12291	Economy	27900.00
0005432755103	12291	Economy	27900.00
0005432751550	12291	Economy	27900.00
0005432751547	12291	Economy	27900.00
0005432751541	12291	Economy	27900.00
0005432751553	12291	Economy	27900.00
0005432755091	12291	Economy	27900.00
0005432755074	12291	Economy	27900.00
0005433847731	5602	Business	99800.00
0005433815465	5602	Business	99800.00
0005433847709	5602	Business	99800.00
0005433847747	5602	Business	99800.00
0005433847745	5602	Business	99800.00
0005435282731	5602	Business	99800.00
0005435282645	5602	Business	99800.00
0005435282648	5602	Business	99800.00
0005434173563	5602	Business	99800.00
0005434173560	5602	Business	99800.00
0005433847729	5602	Business	99800.00
0005433847749	5602	Business	99800.00
0005435282709	5602	Business	99800.00
0005433847722	5602	Business	99800.00
0005433847723	5602	Business	99800.00
0005433847746	5602	Economy	33300.00
0005432081623	5602	Economy	33300.00
0005433847696	5602	Economy	33300.00
0005433847706	5602	Economy	33300.00
0005433847727	5602	Economy	33300.00
0005432081624	5602	Economy	33300.00
0005433847712	5602	Economy	33300.00
0005433847754	5602	Economy	33300.00
0005435282668	5602	Economy	33300.00
0005435282647	5602	Economy	33300.00
0005433847751	5602	Economy	36600.00
0005433847702	5602	Economy	33300.00
0005435282669	5602	Economy	36600.00
0005433847697	5602	Economy	36600.00
0005435282717	5602	Economy	33300.00
0005433847701	5602	Economy	33300.00
0005435282729	5602	Economy	33300.00
0005433847715	5602	Economy	33300.00
0005434173553	5602	Economy	33300.00
0005435282546	5602	Economy	33300.00
0005433847750	5602	Economy	33300.00
0005433847714	5602	Economy	33300.00
0005433847703	5602	Economy	33300.00
0005435282727	5602	Economy	33300.00
0005433847708	5602	Economy	33300.00
0005432081621	5602	Economy	33300.00
0005433847713	5602	Economy	33300.00
0005433847724	5602	Economy	33300.00
0005433847720	5602	Economy	33300.00
0005433847737	5602	Economy	33300.00
0005433847704	5602	Economy	33300.00
0005435282673	5602	Economy	33300.00
0005433847710	5602	Economy	33300.00
0005433847717	5602	Economy	33300.00
0005435282676	5602	Economy	33300.00
0005433847705	5602	Economy	33300.00
0005433815470	5602	Economy	33300.00
0005433847741	5602	Economy	33300.00
0005433847740	5602	Economy	33300.00
0005433847707	5602	Economy	33300.00
0005435282630	5602	Economy	33300.00
0005435282728	5602	Economy	33300.00
0005434173557	5602	Economy	33300.00
0005433847719	5602	Economy	33300.00
0005433847736	5602	Economy	33300.00
0005433847733	5602	Economy	33300.00
0005434173549	5602	Economy	33300.00
0005435282674	5602	Economy	33300.00
0005433847716	5602	Economy	33300.00
0005433847728	5602	Economy	33300.00
0005435282658	5602	Economy	33300.00
0005433847752	5602	Economy	33300.00
0005434173561	5602	Economy	33300.00
0005433847698	5602	Economy	33300.00
0005434173562	5602	Economy	33300.00
0005433847718	5602	Economy	33300.00
0005433847721	5602	Economy	33300.00
0005433847743	5602	Economy	33300.00
0005433815469	5602	Economy	33300.00
0005433847738	5602	Economy	33300.00
0005433815464	5602	Economy	33300.00
0005432081622	5602	Economy	33300.00
0005433847699	5602	Economy	33300.00
0005433847742	5602	Economy	33300.00
0005435282578	5602	Economy	33300.00
0005433847725	5602	Economy	33300.00
0005433815466	5602	Economy	33300.00
0005435282577	5602	Economy	33300.00
0005433847744	5602	Economy	33300.00
0005433847739	5602	Economy	33300.00
0005433847730	5602	Economy	33300.00
0005433847726	5602	Economy	33300.00
0005433847700	5602	Economy	33300.00
0005435282675	5602	Economy	33300.00
0005435282730	5602	Economy	33300.00
0005433847748	5602	Economy	33300.00
0005435282651	5602	Economy	33300.00
0005435282710	5602	Economy	33300.00
0005433815467	5602	Economy	33300.00
0005433847732	5602	Economy	33300.00
0005433815468	5602	Economy	33300.00
0005433847711	5602	Economy	33300.00
0005433847695	5602	Economy	33300.00
0005434173554	5602	Economy	33300.00
0005433847735	5602	Economy	33300.00
0005433847753	5602	Economy	33300.00
0005433847734	5602	Economy	33300.00
0005435282629	5602	Economy	33300.00
0005435282646	5602	Economy	33300.00
0005432003755	13826	Business	99800.00
0005435282924	13826	Business	99800.00
0005433846926	13826	Business	99800.00
0005433847342	13826	Business	99800.00
0005434173588	13826	Business	99800.00
0005433847113	13826	Business	99800.00
0005435282931	13826	Business	99800.00
0005433846919	13826	Business	99800.00
0005433847495	13826	Business	99800.00
0005433847328	13826	Business	99800.00
0005435282916	13826	Business	99800.00
0005433847163	13826	Business	99800.00
0005435282923	13826	Business	99800.00
0005433815416	13826	Business	99800.00
0005433847134	13826	Business	99800.00
0005433847196	13826	Business	99800.00
0005435282934	13826	Economy	33300.00
0005434173589	13826	Business	99800.00
0005433847088	13826	Economy	33300.00
0005433846927	13826	Economy	33300.00
0005433847180	13826	Economy	33300.00
0005433847384	13826	Economy	33300.00
0005433847177	13826	Economy	33300.00
0005433847270	13826	Economy	33300.00
0005433847245	13826	Economy	33300.00
0005435282921	13826	Economy	33300.00
0005435282915	13826	Economy	33300.00
0005435282920	13826	Economy	33300.00
0005435282914	13826	Economy	33300.00
0005433847179	13826	Economy	36600.00
0005433847494	13826	Economy	36600.00
0005433847164	13826	Economy	36600.00
0005435282911	13826	Economy	33300.00
0005435282927	13826	Economy	33300.00
0005434173590	13826	Economy	33300.00
0005433847200	13826	Economy	33300.00
0005435282913	13826	Economy	33300.00
0005433847301	13826	Economy	33300.00
0005435282938	13826	Economy	33300.00
0005433847285	13826	Economy	33300.00
0005433847325	13826	Economy	33300.00
0005433847048	13826	Economy	33300.00
0005433847382	13826	Economy	33300.00
0005435282918	13826	Economy	33300.00
0005433847098	13826	Economy	33300.00
0005435282928	13826	Economy	33300.00
0005434173591	13826	Economy	33300.00
0005435282925	13826	Economy	33300.00
0005433846984	13826	Economy	33300.00
0005435282930	13826	Economy	33300.00
0005435282935	13826	Economy	33300.00
0005433847291	13826	Economy	33300.00
0005433847185	13826	Economy	33300.00
0005433847231	13826	Economy	33300.00
0005433847183	13826	Economy	33300.00
0005435282936	13826	Economy	33300.00
0005433847357	13826	Economy	33300.00
0005433847258	13826	Economy	33300.00
0005435282933	13826	Economy	33300.00
0005433815413	13826	Economy	33300.00
0005433847197	13826	Economy	33300.00
0005433815429	13826	Economy	33300.00
0005433847239	13826	Economy	33300.00
0005433847449	13826	Economy	33300.00
0005433847255	13826	Economy	33300.00
0005435282919	13826	Economy	33300.00
0005433847178	13826	Economy	33300.00
0005433847152	13826	Economy	33300.00
0005435282926	13826	Economy	33300.00
0005433847206	13826	Economy	33300.00
0005433847121	13826	Economy	33300.00
0005433847230	13826	Economy	33300.00
0005433847244	13826	Economy	33300.00
0005435282932	13826	Economy	33300.00
0005433847277	13826	Economy	33300.00
0005433847003	13826	Economy	33300.00
0005433847240	13826	Economy	33300.00
0005433847252	13826	Economy	33300.00
0005433847359	13826	Economy	33300.00
0005433847256	13826	Economy	33300.00
0005433815417	13826	Economy	33300.00
0005433847151	13826	Economy	33300.00
0005435282922	13826	Economy	33300.00
0005433847243	13826	Economy	33300.00
0005435282937	13826	Economy	33300.00
0005435282912	13826	Economy	33300.00
0005435282929	13826	Economy	33300.00
0005433847424	13826	Economy	33300.00
0005433847195	13826	Economy	33300.00
0005433846925	13826	Economy	33300.00
0005433847381	13826	Economy	33300.00
0005433815421	13826	Economy	33300.00
0005433847207	13826	Economy	33300.00
0005432003756	13826	Economy	33300.00
0005433847450	13826	Economy	33300.00
0005435282917	13826	Economy	33300.00
0005433847329	13826	Economy	33300.00
0005433847454	13826	Economy	33300.00
0005434620938	7796	Economy	16600.00
0005434620951	7796	Economy	16600.00
0005435332486	7796	Economy	15100.00
0005435332409	7796	Economy	15100.00
0005434620948	7796	Economy	15100.00
0005434620950	7796	Economy	15100.00
0005432112555	7796	Economy	15100.00
0005434620943	7796	Economy	15100.00
0005434620940	7796	Economy	15100.00
0005435332465	7796	Economy	15100.00
0005434620957	7796	Economy	15100.00
0005434620947	7796	Economy	15100.00
0005432112554	7796	Economy	15100.00
0005435332425	7796	Economy	15100.00
0005434620939	7796	Economy	15100.00
0005434620942	7796	Economy	15100.00
0005434620937	7796	Economy	15100.00
0005434620946	7796	Economy	15100.00
0005434620941	7796	Economy	15100.00
0005434620945	7796	Economy	15100.00
0005434620952	7796	Economy	15100.00
0005435332429	7796	Economy	15100.00
0005435332439	7796	Economy	15100.00
0005435332428	7796	Economy	15100.00
0005434620944	7796	Economy	15100.00
0005434620956	7796	Economy	15100.00
0005435332437	7796	Economy	15100.00
0005434620953	7796	Economy	15100.00
0005435332467	7796	Economy	15100.00
0005434620949	7796	Economy	15100.00
0005434620954	7796	Economy	15100.00
0005434620955	7796	Economy	15100.00
0005435332436	7796	Economy	15100.00
0005435332512	32951	Economy	16600.00
0005434620604	32951	Economy	16600.00
0005434620704	32951	Economy	15100.00
0005435332509	32951	Economy	15100.00
0005434620758	32951	Economy	15100.00
0005435332518	32951	Economy	15100.00
0005434620705	32951	Economy	15100.00
0005434620851	32951	Economy	15100.00
0005434620764	32951	Economy	15100.00
0005434620603	32951	Economy	15100.00
0005434620711	32951	Economy	15100.00
0005435332510	32951	Economy	15100.00
0005434620660	32951	Economy	15100.00
0005434620602	32951	Economy	15100.00
0005435332516	32951	Economy	15100.00
0005434620820	32951	Economy	15100.00
0005434620666	32951	Economy	15100.00
0005435332515	32951	Economy	15100.00
0005434620776	32951	Economy	15100.00
0005435332514	32951	Economy	15100.00
0005435332508	32951	Economy	15100.00
0005434620814	32951	Economy	15100.00
0005434620763	32951	Economy	15100.00
0005434620872	32951	Economy	15100.00
0005434620755	32951	Economy	15100.00
0005435332511	32951	Economy	15100.00
0005435332513	32951	Economy	15100.00
0005434620806	32951	Economy	15100.00
0005434620782	32951	Economy	15100.00
0005435332517	32951	Economy	15100.00
0005434620661	32951	Economy	15100.00
0005434620873	32951	Economy	15100.00
0005434620759	32951	Economy	15100.00
0005434620757	32951	Economy	15100.00
0005434620771	32951	Economy	15100.00
0005435785957	4288	Business	38000.00
0005435918706	4288	Business	38000.00
0005435785954	4288	Business	38000.00
0005435785935	4288	Business	38000.00
0005434994193	4288	Economy	12700.00
0005435785953	4288	Economy	12700.00
0005435785961	4288	Economy	12700.00
0005435785940	4288	Economy	12700.00
0005434994189	4288	Economy	12700.00
0005435785937	4288	Economy	12700.00
0005435785941	4288	Economy	12700.00
0005435785962	4288	Economy	13900.00
0005435785951	4288	Economy	13900.00
0005435785958	4288	Economy	12700.00
0005435785939	4288	Economy	12700.00
0005434994194	4288	Economy	12700.00
0005435785950	4288	Economy	12700.00
0005435918725	4288	Economy	12700.00
0005435785968	4288	Economy	12700.00
0005435785964	4288	Economy	12700.00
0005432190694	4288	Economy	12700.00
0005435785949	4288	Economy	12700.00
0005435785936	4288	Economy	12700.00
0005434994186	4288	Economy	12700.00
0005432190696	4288	Economy	12700.00
0005435785945	4288	Economy	12700.00
0005435787391	4288	Economy	12700.00
0005432190697	4288	Economy	12700.00
0005435785942	4288	Economy	12700.00
0005435937408	4288	Economy	12700.00
0005435785955	4288	Economy	12700.00
0005435785948	4288	Economy	12700.00
0005435785967	4288	Economy	12700.00
0005434994192	4288	Economy	12700.00
0005435785956	4288	Economy	12700.00
0005435785963	4288	Economy	12700.00
0005435785960	4288	Economy	12700.00
0005435785933	4288	Economy	12700.00
0005435918735	4288	Economy	12700.00
0005435785952	4288	Economy	12700.00
0005435785934	4288	Economy	12700.00
0005435918703	4288	Economy	12700.00
0005435785947	4288	Economy	12700.00
0005435918704	4288	Economy	12700.00
0005435785965	4288	Economy	12700.00
0005435918697	4288	Economy	12700.00
0005435785959	4288	Economy	12700.00
0005434994191	4288	Economy	12700.00
0005435785944	4288	Economy	12700.00
0005432190695	4288	Economy	12700.00
0005435785938	4288	Economy	12700.00
0005434994187	4288	Economy	12700.00
0005434994190	4288	Economy	12700.00
0005435785966	4288	Economy	12700.00
0005435785946	4288	Economy	12700.00
0005434994195	4288	Economy	12700.00
0005434994188	4288	Economy	12700.00
0005435785943	4288	Economy	12700.00
0005435785587	27287	Business	38000.00
0005435785555	27287	Business	38000.00
0005435785649	27287	Business	38000.00
0005435785577	27287	Business	38000.00
0005435918738	27287	Business	38000.00
0005435787367	27287	Business	38000.00
0005435918741	27287	Business	38000.00
0005435937460	27287	Business	38000.00
0005435785382	27287	Economy	12700.00
0005435918740	27287	Economy	12700.00
0005435785627	27287	Economy	12700.00
0005435785510	27287	Economy	13900.00
0005435918736	27287	Economy	13900.00
0005435785612	27287	Economy	12700.00
0005435937459	27287	Economy	12700.00
0005435785446	27287	Economy	12700.00
0005435785509	27287	Economy	12700.00
0005435785599	27287	Economy	12700.00
0005435785636	27287	Economy	12700.00
0005434994041	27287	Economy	12700.00
0005435937457	27287	Economy	12700.00
0005435785557	27287	Economy	12700.00
0005435785477	27287	Economy	12700.00
0005434994117	27287	Economy	12700.00
0005435785565	27287	Economy	12700.00
0005435785588	27287	Economy	12700.00
0005434994146	27287	Economy	12700.00
0005435785491	27287	Economy	12700.00
0005435785537	27287	Economy	12700.00
0005434994109	27287	Economy	12700.00
0005434994067	27287	Economy	12700.00
0005435785619	27287	Economy	12700.00
0005435785429	27287	Economy	12700.00
0005435785613	27287	Economy	12700.00
0005435787366	27287	Economy	12700.00
0005434994134	27287	Economy	12700.00
0005435918739	27287	Economy	12700.00
0005435785618	27287	Economy	12700.00
0005434994113	27287	Economy	12700.00
0005434994077	27287	Economy	12700.00
0005435918737	27287	Economy	12700.00
0005435785589	27287	Economy	12700.00
0005435785473	27287	Economy	12700.00
0005435785716	27287	Economy	12700.00
0005435785451	27287	Economy	12700.00
0005435937458	27287	Economy	12700.00
0005435785487	27287	Economy	12700.00
0005435785635	27287	Economy	12700.00
0005435785490	27287	Economy	12700.00
0005434994145	27287	Economy	12700.00
0005434994124	27287	Economy	12700.00
0005435785478	27287	Economy	12700.00
0005435785556	27287	Economy	12700.00
0005435785564	27287	Economy	12700.00
0005435785507	27287	Economy	12700.00
0005432146233	19876	Economy	14000.00
0005432146235	19876	Economy	12800.00
0005432146234	19876	Economy	12800.00
0005434082290	4700	Business	40900.00
0005432460731	4700	Business	40900.00
0005434082292	4700	Business	40900.00
0005432568676	4700	Business	40900.00
0005432568702	4700	Business	40900.00
0005432186931	4700	Business	40900.00
0005432568694	4700	Business	40900.00
0005432460749	4700	Business	40900.00
0005432568703	4700	Business	40900.00
0005432568700	4700	Business	40900.00
0005432460738	4700	Business	40900.00
0005432170505	4700	Business	40900.00
0005432170501	4700	Business	40900.00
0005434082296	4700	Business	40900.00
0005432568684	4700	Business	40900.00
0005432460764	4700	Business	40900.00
0005432568710	4700	Business	40900.00
0005432568693	4700	Business	40900.00
0005432568659	4700	Economy	15000.00
0005432568678	4700	Economy	15000.00
0005432568686	4700	Economy	15000.00
0005432568683	4700	Economy	13600.00
0005434082303	4700	Economy	13600.00
0005432568681	4700	Economy	13600.00
0005434082285	4700	Economy	13600.00
0005432568680	4700	Economy	13600.00
0005432460762	4700	Economy	13600.00
0005433452777	4700	Economy	13600.00
0005432568691	4700	Economy	13600.00
0005434082288	4700	Economy	13600.00
0005432568695	4700	Economy	13600.00
0005432568708	4700	Economy	13600.00
0005432170503	4700	Economy	13600.00
0005432568697	4700	Economy	13600.00
0005434082305	4700	Economy	13600.00
0005432460748	4700	Economy	13600.00
0005434082298	4700	Economy	13600.00
0005432568663	4700	Economy	13600.00
0005432568711	4700	Economy	13600.00
0005432460760	4700	Economy	13600.00
0005432460743	4700	Economy	13600.00
0005432460758	4700	Economy	13600.00
0005432460733	4700	Economy	13600.00
0005432460754	4700	Economy	13600.00
0005432568699	4700	Economy	13600.00
0005432568655	4700	Economy	13600.00
0005432460736	4700	Economy	13600.00
0005432460720	4700	Economy	13600.00
0005432460726	4700	Economy	13600.00
0005432568679	4700	Economy	13600.00
0005434082301	4700	Economy	13600.00
0005432170506	4700	Economy	13600.00
0005432460761	4700	Economy	13600.00
0005434082287	4700	Economy	13600.00
0005432568689	4700	Economy	13600.00
0005432571386	4700	Economy	13600.00
0005432460742	4700	Economy	13600.00
0005432568675	4700	Economy	13600.00
0005432568696	4700	Economy	13600.00
0005434082293	4700	Economy	13600.00
0005432460769	4700	Economy	13600.00
0005432568688	4700	Economy	13600.00
0005432460727	4700	Economy	13600.00
0005432568674	4700	Economy	13600.00
0005432568656	4700	Economy	13600.00
0005432460755	4700	Economy	13600.00
0005432568660	4700	Economy	13600.00
0005432568677	4700	Economy	13600.00
0005432460759	4700	Economy	13600.00
0005432568671	4700	Economy	13600.00
0005432460737	4700	Economy	13600.00
0005432460729	4700	Economy	13600.00
0005434082286	4700	Economy	13600.00
0005433451653	4700	Economy	13600.00
0005432568669	4700	Economy	13600.00
0005432170504	4700	Economy	13600.00
0005432460772	4700	Economy	13600.00
0005432568707	4700	Economy	13600.00
0005432186932	4700	Economy	13600.00
0005432460745	4700	Economy	13600.00
0005432460767	4700	Economy	13600.00
0005432460746	4700	Economy	13600.00
0005432571387	4700	Economy	13600.00
0005432460752	4700	Economy	13600.00
0005432460723	4700	Economy	13600.00
0005432460741	4700	Economy	13600.00
0005434082294	4700	Economy	13600.00
0005432460750	4700	Economy	13600.00
0005434082289	4700	Economy	13600.00
0005432460771	4700	Economy	13600.00
0005434082295	4700	Economy	13600.00
0005434082302	4700	Economy	13600.00
0005433451654	4700	Economy	13600.00
0005432568668	4700	Economy	13600.00
0005432460730	4700	Economy	13600.00
0005432460728	4700	Economy	15000.00
0005433726144	4700	Economy	13600.00
0005432460747	4700	Economy	13600.00
0005432460757	4700	Economy	13600.00
0005432568713	4700	Economy	15000.00
0005432460763	4700	Economy	13600.00
0005432568690	4700	Economy	13600.00
0005432568670	4700	Economy	13600.00
0005433451655	4700	Economy	13600.00
0005432460725	4700	Economy	13600.00
0005432568652	4700	Economy	13600.00
0005432568687	4700	Economy	13600.00
0005433452776	4700	Economy	13600.00
0005432568704	4700	Economy	13600.00
0005432568661	4700	Economy	13600.00
0005434082306	4700	Economy	13600.00
0005432568701	4700	Economy	13600.00
0005434082297	4700	Economy	13600.00
0005432460722	4700	Economy	13600.00
0005434082291	4700	Economy	13600.00
0005432460739	4700	Economy	13600.00
0005434082299	4700	Economy	13600.00
0005432460744	4700	Economy	13600.00
0005432460765	4700	Economy	13600.00
0005432568653	4700	Economy	13600.00
0005432460732	4700	Economy	13600.00
0005432568664	4700	Economy	13600.00
0005432186934	4700	Economy	13600.00
0005432460751	4700	Economy	13600.00
0005432568709	4700	Economy	13600.00
0005432460734	4700	Economy	13600.00
0005432568692	4700	Economy	13600.00
0005432568673	4700	Economy	13600.00
0005432568666	4700	Economy	13600.00
0005432460735	4700	Economy	13600.00
0005432460756	4700	Economy	13600.00
0005434082304	4700	Economy	13600.00
0005432568698	4700	Economy	13600.00
0005432568712	4700	Economy	13600.00
0005432460768	4700	Economy	13600.00
0005432568667	4700	Economy	13600.00
0005432460724	4700	Economy	13600.00
0005432186933	4700	Economy	13600.00
0005433726143	4700	Economy	13600.00
0005432568705	4700	Economy	13600.00
0005432460753	4700	Economy	13600.00
0005434082307	4700	Economy	13600.00
0005432568665	4700	Economy	13600.00
0005432568658	4700	Economy	13600.00
0005432170502	4700	Economy	13600.00
0005432568714	4700	Economy	13600.00
0005432170507	4700	Economy	13600.00
0005432568682	4700	Economy	13600.00
0005432568672	4700	Economy	13600.00
0005433452775	4700	Economy	13600.00
0005432460740	4700	Economy	13600.00
0005432460766	4700	Economy	13600.00
0005432460719	4700	Economy	13600.00
0005432571388	4700	Economy	13600.00
0005432568657	4700	Economy	13600.00
0005432460721	4700	Economy	13600.00
0005432568685	4700	Economy	13600.00
0005432460770	4700	Economy	13600.00
0005434082300	4700	Economy	13600.00
0005432568662	4700	Economy	13600.00
0005432568706	4700	Economy	13600.00
0005432568654	4700	Economy	13600.00
0005434082060	30573	Business	40900.00
0005432568184	30573	Business	40900.00
0005432571356	30573	Business	40900.00
0005434082046	30573	Business	40900.00
0005432460181	30573	Business	40900.00
0005432460258	30573	Business	40900.00
0005432568187	30573	Business	40900.00
0005434082051	30573	Business	40900.00
0005432460616	30573	Business	40900.00
0005434082055	30573	Business	40900.00
0005432460259	30573	Business	40900.00
0005432571339	30573	Business	40900.00
0005432571340	30573	Business	40900.00
0005432460195	30573	Business	40900.00
0005432571367	30573	Business	40900.00
0005432571365	30573	Business	40900.00
0005432571361	30573	Business	40900.00
0005434082044	30573	Business	40900.00
0005432161192	30573	Business	40900.00
0005432460424	30573	Business	40900.00
0005432568077	30573	Business	40900.00
0005432460338	30573	Business	40900.00
0005432568223	30573	Business	40900.00
0005432460182	30573	Business	40900.00
0005432460205	30573	Economy	15000.00
0005432460323	30573	Economy	15000.00
0005432460444	30573	Economy	13600.00
0005432568219	30573	Economy	15000.00
0005432213669	30573	Economy	13600.00
0005432460355	30573	Economy	13600.00
0005432460200	30573	Economy	13600.00
0005432213670	30573	Economy	13600.00
0005432568024	30573	Economy	13600.00
0005432460202	30573	Economy	13600.00
0005432460337	30573	Economy	13600.00
0005432568100	30573	Economy	13600.00
0005432568145	30573	Economy	13600.00
0005432568146	30573	Economy	13600.00
0005432571355	30573	Economy	13600.00
0005432568252	30573	Economy	13600.00
0005432568076	30573	Economy	13600.00
0005434082045	30573	Economy	13600.00
0005432568301	30573	Economy	13600.00
0005432460143	30573	Economy	13600.00
0005432568264	30573	Economy	13600.00
0005432460188	30573	Economy	13600.00
0005432568183	30573	Economy	13600.00
0005434082034	30573	Economy	13600.00
0005432568163	30573	Economy	13600.00
0005434082074	30573	Economy	13600.00
0005434081996	30573	Economy	13600.00
0005434082036	30573	Economy	13600.00
0005432568220	30573	Economy	13600.00
0005432571368	30573	Economy	13600.00
0005432460262	30573	Economy	13600.00
0005432568274	30573	Economy	13600.00
0005432213671	30573	Economy	13600.00
0005432568154	30573	Economy	13600.00
0005434082095	30573	Economy	13600.00
0005432460199	30573	Economy	13600.00
0005432568291	30573	Economy	13600.00
0005432571338	30573	Economy	13600.00
0005433452755	30573	Economy	13600.00
0005434082050	30573	Economy	13600.00
0005432568405	30573	Economy	13600.00
0005432460353	30573	Economy	13600.00
0005432460354	30573	Economy	13600.00
0005432568404	30573	Economy	13600.00
0005432568225	30573	Economy	13600.00
0005434082037	30573	Economy	13600.00
0005432568263	30573	Economy	13600.00
0005432568339	30573	Economy	13600.00
0005432460194	30573	Economy	13600.00
0005434082043	30573	Economy	13600.00
0005432568164	30573	Economy	13600.00
0005434082120	30573	Economy	13600.00
0005432460574	30573	Economy	13600.00
0005432460357	30573	Economy	13600.00
0005432568212	30573	Economy	13600.00
0005432460290	30573	Economy	13600.00
0005432460261	30573	Economy	13600.00
0005434082072	30573	Economy	13600.00
0005432460534	30573	Economy	13600.00
0005432568432	30573	Economy	13600.00
0005434082035	30573	Economy	13600.00
0005432460367	30573	Economy	13600.00
0005432460497	30573	Economy	13600.00
0005434082059	30573	Economy	13600.00
0005432460197	30573	Economy	13600.00
0005434082097	30573	Economy	13600.00
0005434082096	30573	Economy	13600.00
0005434082083	30573	Economy	13600.00
0005432460189	30573	Economy	13600.00
0005432568342	30573	Economy	15000.00
0005432460183	30573	Economy	15000.00
0005432460457	30573	Economy	13600.00
0005432571364	30573	Economy	13600.00
0005432568097	30573	Economy	15000.00
0005432568141	30573	Economy	15000.00
0005432568470	30573	Economy	13600.00
0005432213672	30573	Economy	13600.00
0005432460211	30573	Economy	13600.00
0005434082077	30573	Economy	13600.00
0005432460425	30573	Economy	13600.00
0005432568343	30573	Economy	13600.00
0005432568384	30573	Economy	13600.00
0005432460382	30573	Economy	13600.00
0005434082085	30573	Economy	13600.00
0005432568188	30573	Economy	13600.00
0005434082104	30573	Economy	13600.00
0005434082061	30573	Economy	13600.00
0005432568247	30573	Economy	13600.00
0005432568161	30573	Economy	13600.00
0005432460365	30573	Economy	13600.00
0005434082086	30573	Economy	13600.00
0005432568471	30573	Economy	13600.00
0005432568125	30573	Economy	13600.00
0005432568337	30573	Economy	13600.00
0005432460206	30573	Economy	13600.00
0005432568383	30573	Economy	13600.00
0005432568185	30573	Economy	13600.00
0005432460196	30573	Economy	13600.00
0005432568199	30573	Economy	13600.00
0005432460208	30573	Economy	13600.00
0005432460295	30573	Economy	13600.00
0005432568202	30573	Economy	13600.00
0005432568338	30573	Economy	13600.00
0005434082098	30573	Economy	13600.00
0005432568327	30573	Economy	13600.00
0005432568433	30573	Economy	13600.00
0005432460142	30573	Economy	13600.00
0005432460203	30573	Economy	13600.00
0005432460187	30573	Economy	13600.00
0005432568258	30573	Economy	13600.00
0005432460225	30573	Economy	13600.00
0005432568025	30573	Economy	13600.00
0005432568192	30573	Economy	13600.00
0005432568364	30573	Economy	13600.00
0005432460401	30573	Economy	13600.00
0005432460345	30573	Economy	13600.00
0005432568039	30573	Economy	13600.00
0005432460509	30573	Economy	13600.00
0005434082048	30573	Economy	13600.00
0005432568162	30573	Economy	13600.00
0005432568190	30573	Economy	13600.00
0005432568173	30573	Economy	13600.00
0005432460615	30573	Economy	13600.00
0005432568308	30573	Economy	13600.00
0005432571360	30573	Economy	13600.00
0005434082047	30573	Economy	13600.00
0005432161191	30573	Economy	13600.00
0005432568147	30573	Economy	13600.00
0005432460291	30573	Economy	13600.00
0005432460344	30573	Economy	13600.00
0005435722095	13564	Economy	9900.00
0005435722096	13564	Economy	9900.00
0005435722097	13564	Economy	9900.00
0005435722098	13564	Economy	9900.00
0005435722077	21139	Economy	9900.00
0005435722076	21139	Economy	9900.00
0005432295926	22800	Economy	8800.00
0005432295925	22800	Economy	8800.00
0005432295927	22800	Economy	8800.00
0005435097372	11109	Business	23600.00
0005433344893	11109	Business	23600.00
0005433344935	11109	Business	23600.00
0005433344854	11109	Business	23600.00
0005433344895	11109	Business	23600.00
0005433344844	11109	Business	23600.00
0005433344861	11109	Business	23600.00
0005435508461	11109	Business	23600.00
0005433344849	11109	Business	23600.00
0005433344848	11109	Business	23600.00
0005435508459	11109	Business	23600.00
0005433344889	11109	Economy	7900.00
0005435097370	11109	Economy	7900.00
0005433344917	11109	Economy	7900.00
0005433344874	11109	Economy	7900.00
0005433344851	11109	Economy	7900.00
0005433344896	11109	Economy	7900.00
0005433344930	11109	Economy	7900.00
0005433344883	11109	Economy	7900.00
0005433344928	11109	Economy	7900.00
0005435097366	11109	Economy	7900.00
0005433344868	11109	Economy	7900.00
0005433344941	11109	Economy	7900.00
0005433344902	11109	Economy	7900.00
0005433344887	11109	Economy	7900.00
0005433344866	11109	Economy	7900.00
0005435508431	11109	Economy	7900.00
0005433344885	11109	Economy	7900.00
0005435097367	11109	Economy	7900.00
0005433344873	11109	Economy	7900.00
0005435508430	11109	Economy	7900.00
0005433344863	11109	Economy	7900.00
0005433344892	11109	Economy	7900.00
0005433344921	11109	Economy	7900.00
0005433344898	11109	Economy	7900.00
0005435508462	11109	Economy	7900.00
0005433344840	11109	Economy	7900.00
0005433344886	11109	Economy	7900.00
0005435097369	11109	Economy	7900.00
0005433344850	11109	Economy	7900.00
0005435097365	11109	Economy	7900.00
0005433344903	11109	Economy	7900.00
0005433344852	11109	Economy	7900.00
0005433344862	11109	Economy	7900.00
0005433344924	11109	Economy	7900.00
0005433344867	11109	Economy	7900.00
0005435508465	11109	Economy	7900.00
0005433344891	11109	Economy	7900.00
0005433344908	11109	Economy	7900.00
0005433344857	11109	Economy	7900.00
0005433344932	11109	Economy	7900.00
0005435508463	11109	Economy	8600.00
0005433344939	11109	Economy	8600.00
0005433344934	11109	Economy	8600.00
0005435097371	11109	Economy	8600.00
0005435380333	11109	Economy	8600.00
0005435508413	11109	Economy	8600.00
0005433344931	11109	Economy	7900.00
0005433344940	11109	Economy	7900.00
0005433344845	11109	Economy	7900.00
0005435508464	11109	Economy	7900.00
0005433344905	11109	Economy	7900.00
0005433344929	11109	Economy	7900.00
0005433344855	11109	Economy	7900.00
0005433344925	11109	Economy	7900.00
0005433344864	11109	Economy	7900.00
0005433344894	11109	Economy	7900.00
0005433344920	11109	Economy	7900.00
0005433344843	11109	Economy	7900.00
0005435508447	11109	Economy	7900.00
0005433344901	11109	Economy	7900.00
0005433344884	11109	Economy	7900.00
0005433344890	11109	Economy	7900.00
0005435508460	11109	Economy	7900.00
0005433344907	11109	Economy	7900.00
0005433344936	11109	Economy	7900.00
0005433344869	11109	Economy	7900.00
0005433344938	11109	Economy	7900.00
0005433344919	11109	Economy	7900.00
0005433344870	11109	Economy	7900.00
0005433344910	11109	Economy	7900.00
0005433344859	11109	Economy	7900.00
0005433344916	11109	Economy	7900.00
0005433344913	11109	Economy	7900.00
0005433344900	11109	Economy	7900.00
0005433344841	11109	Economy	7900.00
0005433344875	11109	Economy	7900.00
0005433344923	11109	Economy	7900.00
0005433344881	11109	Economy	7900.00
0005435097368	11109	Economy	7900.00
0005435508414	11109	Economy	7900.00
0005433344933	11109	Economy	7900.00
0005433344897	11109	Economy	7900.00
0005433344922	11109	Economy	7900.00
0005433344842	11109	Economy	7900.00
0005433344927	11109	Economy	7900.00
0005435380329	11109	Economy	7900.00
0005433344899	11109	Economy	7900.00
0005433344937	11109	Economy	7900.00
0005433344882	11109	Economy	7900.00
0005433344860	11109	Economy	7900.00
0005433344847	11109	Economy	7900.00
0005433344918	11109	Economy	7900.00
0005433344906	11109	Economy	7900.00
0005433344876	11109	Economy	7900.00
0005433344914	11109	Economy	7900.00
0005433344846	11109	Economy	7900.00
0005433344858	11109	Economy	7900.00
0005433344909	11109	Economy	7900.00
0005435508417	11109	Economy	7900.00
0005433344912	11109	Economy	7900.00
0005435097373	11109	Economy	7900.00
0005433344865	11109	Economy	7900.00
0005435508448	11109	Economy	7900.00
0005433344872	11109	Economy	7900.00
0005433344879	11109	Economy	7900.00
0005433344880	11109	Economy	7900.00
0005433344871	11109	Economy	7900.00
0005433344853	11109	Economy	7900.00
0005433344904	11109	Economy	7900.00
0005433344877	11109	Economy	7900.00
0005433344911	11109	Economy	7900.00
0005433344856	11109	Economy	7900.00
0005433344915	11109	Economy	7900.00
0005433344926	11109	Economy	7900.00
0005433344888	11109	Economy	7900.00
0005433344878	11109	Economy	7900.00
0005433343968	17085	Business	23600.00
0005433343827	17085	Business	23600.00
0005433344174	17085	Business	23600.00
0005435097333	17085	Business	23600.00
0005433344066	17085	Business	23600.00
0005433343692	17085	Business	23600.00
0005433344296	17085	Business	23600.00
0005435097274	17085	Business	23600.00
0005433344012	17085	Business	23600.00
0005433343740	17085	Business	23600.00
0005433343370	17085	Business	23600.00
0005433343950	17085	Economy	7900.00
0005433343728	17085	Economy	7900.00
0005433343796	17085	Economy	7900.00
0005433343775	17085	Economy	7900.00
0005435545866	17085	Economy	7900.00
0005433344011	17085	Economy	7900.00
0005433343930	17085	Economy	7900.00
0005433344149	17085	Economy	7900.00
0005433343905	17085	Economy	7900.00
0005433343873	17085	Economy	7900.00
0005433343881	17085	Economy	7900.00
0005433343602	17085	Economy	7900.00
0005433344102	17085	Economy	7900.00
0005435380383	17085	Economy	7900.00
0005435545867	17085	Economy	7900.00
0005433344383	17085	Economy	7900.00
0005433343754	17085	Economy	7900.00
0005433344400	17085	Economy	7900.00
0005435380382	17085	Economy	7900.00
0005433344148	17085	Economy	7900.00
0005433343770	17085	Economy	7900.00
0005433344197	17085	Economy	7900.00
0005432293250	17085	Economy	7900.00
0005433343959	17085	Economy	7900.00
0005433343559	17085	Economy	7900.00
0005433343830	17085	Economy	7900.00
0005433343879	17085	Economy	7900.00
0005433344043	17085	Economy	7900.00
0005433343948	17085	Economy	7900.00
0005433344127	17085	Economy	7900.00
0005433344150	17085	Economy	7900.00
0005433343992	17085	Economy	7900.00
0005433343729	17085	Economy	7900.00
0005433344176	17085	Economy	7900.00
0005433343953	17085	Economy	7900.00
0005433343899	17085	Economy	7900.00
0005435545868	17085	Economy	7900.00
0005433343752	17085	Economy	7900.00
0005433343880	17085	Economy	7900.00
0005433343986	17085	Economy	7900.00
0005433344121	17085	Economy	8600.00
0005433344094	17085	Economy	8600.00
0005433344330	17085	Economy	8600.00
0005433344181	17085	Economy	8600.00
0005433343655	17085	Economy	8600.00
0005433343797	17085	Economy	8600.00
0005435380385	17085	Economy	7900.00
0005433344111	17085	Economy	7900.00
0005433343450	17085	Economy	7900.00
0005433343804	17085	Economy	7900.00
0005433344125	17085	Economy	7900.00
0005435097240	17085	Economy	7900.00
0005433343831	17085	Economy	7900.00
0005433343956	17085	Economy	7900.00
0005433344000	17085	Economy	7900.00
0005433343933	17085	Economy	7900.00
0005435380380	17085	Economy	7900.00
0005433343776	17085	Economy	7900.00
0005433344175	17085	Economy	7900.00
0005433343895	17085	Economy	7900.00
0005433343896	17085	Economy	7900.00
0005433344266	17085	Economy	7900.00
0005433343929	17085	Economy	7900.00
0005433343744	17085	Economy	7900.00
0005433343693	17085	Economy	7900.00
0005433343753	17085	Economy	7900.00
0005433343371	17085	Economy	7900.00
0005435380384	17085	Economy	7900.00
0005433343897	17085	Economy	7900.00
0005435097286	17085	Economy	7900.00
0005433344327	17085	Economy	7900.00
0005433343877	17085	Economy	7900.00
0005433343993	17085	Economy	7900.00
0005435097267	17085	Economy	7900.00
0005433343529	17085	Economy	7900.00
0005433343960	17085	Economy	7900.00
0005435380381	17085	Economy	7900.00
0005433343874	17085	Economy	7900.00
0005433343955	17085	Economy	7900.00
0005433343525	17085	Economy	7900.00
0005433344122	17085	Economy	7900.00
0005433343949	17085	Economy	7900.00
0005433344044	17085	Economy	7900.00
0005433343673	17085	Economy	7900.00
0005435545870	17085	Economy	7900.00
0005433344191	17085	Economy	7900.00
0005433343657	17085	Economy	7900.00
0005435097332	17085	Economy	7900.00
0005433344468	17085	Economy	7900.00
0005433343961	17085	Economy	7900.00
0005432293249	17085	Economy	7900.00
0005433344130	17085	Economy	7900.00
0005433343676	17085	Economy	7900.00
0005433344040	17085	Economy	7900.00
0005432293251	17085	Economy	7900.00
0005433343560	17085	Economy	7900.00
0005433343969	17085	Economy	7900.00
0005435545871	17085	Economy	7900.00
0005435097269	17085	Economy	7900.00
0005433343952	17085	Economy	7900.00
0005433343892	17085	Economy	7900.00
0005435545869	17085	Economy	7900.00
0005433344328	17085	Economy	7900.00
0005433343951	17085	Economy	7900.00
0005433343369	17085	Economy	7900.00
0005433343954	17085	Economy	7900.00
0005433344103	17085	Economy	7900.00
0005433343649	17085	Economy	7900.00
0005433343540	17085	Economy	7900.00
0005433344081	17085	Economy	7900.00
0005435097237	17085	Economy	7900.00
0005433344348	17085	Economy	7900.00
0005433343650	17085	Economy	7900.00
0005433343558	17085	Economy	7900.00
0005435097300	17085	Economy	7900.00
0005433343526	17085	Economy	7900.00
0005433481301	9059	Business	26600.00
0005433476965	9059	Business	26600.00
0005433507472	9059	Business	26600.00
0005433507485	9059	Business	26600.00
0005433476968	9059	Business	26600.00
0005432920073	9059	Business	26600.00
0005433507488	9059	Business	26600.00
0005432920079	9059	Business	26600.00
0005434158987	9059	Business	26600.00
0005432920040	9059	Economy	8900.00
0005433476960	9059	Economy	8900.00
0005433507480	9059	Economy	8900.00
0005433481303	9059	Economy	8900.00
0005433476966	9059	Economy	8900.00
0005433476967	9059	Economy	8900.00
0005432920041	9059	Economy	8900.00
0005433507491	9059	Economy	9800.00
0005432920038	9059	Economy	8900.00
0005433507484	9059	Economy	8900.00
0005432919980	9059	Economy	8900.00
0005433476963	9059	Economy	8900.00
0005433481305	9059	Economy	8900.00
0005433507482	9059	Economy	8900.00
0005433507478	9059	Economy	8900.00
0005433481304	9059	Economy	8900.00
0005433507476	9059	Economy	8900.00
0005433507473	9059	Economy	8900.00
0005433507481	9059	Economy	8900.00
0005433507475	9059	Economy	8900.00
0005433476958	9059	Economy	8900.00
0005433507483	9059	Economy	8900.00
0005432920010	9059	Economy	8900.00
0005433507471	9059	Economy	8900.00
0005432920074	9059	Economy	8900.00
0005432920007	9059	Economy	8900.00
0005432919969	9059	Economy	8900.00
0005433476961	9059	Economy	8900.00
0005433476959	9059	Economy	8900.00
0005433507489	9059	Economy	8900.00
0005433507479	9059	Economy	8900.00
0005433476969	9059	Economy	8900.00
0005433481299	9059	Economy	8900.00
0005432920072	9059	Economy	8900.00
0005433507474	9059	Economy	8900.00
0005433507477	9059	Economy	8900.00
0005432920022	9059	Economy	8900.00
0005432920108	9059	Economy	8900.00
0005432920046	9059	Economy	8900.00
0005432920011	9059	Economy	8900.00
0005433481300	9059	Economy	8900.00
0005433507486	9059	Economy	8900.00
0005432920047	9059	Economy	8900.00
0005432920039	9059	Economy	8900.00
0005433476962	9059	Economy	8900.00
0005432920008	9059	Economy	8900.00
0005433481302	9059	Economy	8900.00
0005433507492	9059	Economy	8900.00
0005434158993	9059	Economy	8900.00
0005433507490	9059	Economy	8900.00
0005432920127	9059	Economy	8900.00
0005433476964	9059	Economy	8900.00
0005432920021	9059	Economy	8900.00
0005433476970	9059	Economy	8900.00
0005433507487	9059	Economy	8900.00
0005434159002	9059	Economy	8900.00
0005432920244	20448	Business	26600.00
0005432920231	20448	Business	26600.00
0005433507312	20448	Business	26600.00
0005433507323	20448	Business	26600.00
0005433507359	20448	Business	26600.00
0005432920232	20448	Business	26600.00
0005433507387	20448	Business	26600.00
0005432920247	20448	Business	26600.00
0005433507381	20448	Economy	8900.00
0005432920246	20448	Economy	8900.00
0005433481244	20448	Economy	8900.00
0005432920245	20448	Economy	8900.00
0005433507333	20448	Economy	9800.00
0005433507309	20448	Economy	9800.00
0005433481265	20448	Economy	8900.00
0005432920243	20448	Economy	8900.00
0005433507332	20448	Economy	8900.00
0005432920236	20448	Economy	8900.00
0005433507348	20448	Economy	8900.00
0005432920239	20448	Economy	8900.00
0005432920234	20448	Economy	8900.00
0005433507334	20448	Economy	8900.00
0005432920233	20448	Economy	8900.00
0005433507310	20448	Economy	8900.00
0005433507354	20448	Economy	8900.00
0005432920240	20448	Economy	8900.00
0005433507297	20448	Economy	8900.00
0005433481236	20448	Economy	8900.00
0005432920249	20448	Economy	8900.00
0005433507335	20448	Economy	8900.00
0005432920250	20448	Economy	8900.00
0005433507322	20448	Economy	8900.00
0005432920230	20448	Economy	8900.00
0005432920242	20448	Economy	8900.00
0005433481266	20448	Economy	8900.00
0005433507315	20448	Economy	8900.00
0005433507372	20448	Economy	8900.00
0005433507355	20448	Economy	8900.00
0005432920251	20448	Economy	8900.00
0005433507360	20448	Economy	8900.00
0005432920238	20448	Economy	8900.00
0005432920248	20448	Economy	8900.00
0005433507356	20448	Economy	8900.00
0005432920235	20448	Economy	8900.00
0005433507371	20448	Economy	8900.00
0005432920237	20448	Economy	8900.00
0005433507288	20448	Economy	8900.00
0005432920241	20448	Economy	8900.00
0005433481237	20448	Economy	8900.00
0005433507343	20448	Economy	8900.00
0005433481245	20448	Economy	8900.00
0005433481225	20448	Economy	8900.00
0005433507298	20448	Economy	8900.00
0005432394171	10214	Economy	5800.00
0005432396310	10214	Economy	5800.00
0005432394172	10214	Economy	5800.00
0005432394168	10214	Economy	5800.00
0005432394173	10214	Economy	5800.00
0005432394170	10214	Economy	5800.00
0005432396309	10214	Economy	5800.00
0005432396308	10214	Economy	5800.00
0005432396307	10214	Economy	5800.00
0005432394169	10214	Economy	5800.00
0005432400166	18319	Economy	5800.00
0005432400167	18319	Economy	5800.00
0005435179700	18319	Economy	5800.00
0005432400163	18319	Economy	5800.00
0005432396279	18319	Economy	5800.00
0005435179701	18319	Economy	5800.00
0005432396280	18319	Economy	5800.00
0005432400165	18319	Economy	5800.00
0005435179409	18319	Economy	5800.00
0005432400164	18319	Economy	5800.00
0005435626360	11005	Business	9500.00
0005435626328	11005	Business	9500.00
0005435126585	11005	Business	9500.00
0005435626343	11005	Business	9500.00
0005435626311	11005	Business	9500.00
0005435626327	11005	Business	9500.00
0005435126728	11005	Business	9500.00
0005434411852	11005	Business	9500.00
0005435126681	11005	Economy	3200.00
0005435554210	11005	Economy	3200.00
0005435126618	11005	Economy	3200.00
0005435126796	11005	Economy	3200.00
0005435626302	11005	Economy	3200.00
0005435126702	11005	Economy	3200.00
0005435126606	11005	Economy	3200.00
0005435626342	11005	Economy	3200.00
0005435126719	11005	Economy	3500.00
0005435626353	11005	Economy	3500.00
0005435126594	11005	Economy	3500.00
0005435556712	11005	Economy	3500.00
0005435126848	11005	Economy	3500.00
0005435126730	11005	Economy	3200.00
0005435126770	11005	Economy	3200.00
0005435126638	11005	Economy	3200.00
0005435626300	11005	Economy	3200.00
0005435126607	11005	Economy	3200.00
0005435626299	11005	Economy	3200.00
0005435626292	11005	Economy	3200.00
0005434411854	11005	Economy	3200.00
0005435126756	11005	Economy	3200.00
0005435626294	11005	Economy	3200.00
0005435126605	11005	Economy	3200.00
0005435126633	11005	Economy	3200.00
0005435126533	11005	Economy	3200.00
0005435126718	11005	Economy	3200.00
0005435626291	11005	Economy	3200.00
0005434928349	11005	Economy	3200.00
0005435626278	11005	Economy	3200.00
0005435626301	11005	Economy	3200.00
0005435126894	11005	Economy	3200.00
0005435126729	11005	Economy	3200.00
0005435126560	11005	Economy	3200.00
0005435126731	11005	Economy	3200.00
0005435126737	11005	Economy	3200.00
0005435554235	11005	Economy	3200.00
0005435126559	11005	Economy	3200.00
0005435126651	11005	Economy	3200.00
0005435126616	11005	Economy	3200.00
0005435626326	11005	Economy	3200.00
0005435126591	11005	Economy	3200.00
0005435126534	11005	Economy	3200.00
0005435126849	11005	Economy	3200.00
0005435626329	11005	Economy	3200.00
0005435126738	11005	Economy	3200.00
0005435126860	11005	Economy	3200.00
0005435126639	11005	Economy	3200.00
0005435626293	11005	Economy	3200.00
0005435126859	11005	Economy	3200.00
0005435626290	11005	Economy	3200.00
0005435626296	11005	Economy	3200.00
0005435554211	11005	Economy	3200.00
0005435626289	11005	Economy	3200.00
0005435126798	11005	Economy	3200.00
0005435626352	11005	Economy	3200.00
0005435554214	11005	Economy	3200.00
0005435126617	11005	Economy	3200.00
0005435126556	11005	Economy	3200.00
0005435626295	11005	Economy	3200.00
0005435126641	11005	Economy	3200.00
0005435126777	11005	Economy	3200.00
0005434411853	11005	Economy	3200.00
0005434411855	11005	Economy	3200.00
0005435626344	11005	Economy	3200.00
0005435626359	11005	Economy	3200.00
0005435126584	11005	Economy	3200.00
0005434928350	11005	Economy	3200.00
0005435126727	11005	Economy	3200.00
0005435626285	11005	Economy	3200.00
0005435127064	14757	Business	9500.00
0005435626498	14757	Business	9500.00
0005435127080	14757	Business	9500.00
0005434411816	14757	Business	9500.00
0005435556735	14757	Business	9500.00
0005435127097	14757	Business	9500.00
0005435626492	14757	Business	9500.00
0005435626488	14757	Business	9500.00
0005435127085	14757	Business	9500.00
0005435626489	14757	Economy	3200.00
0005434928332	14757	Economy	3200.00
0005435127093	14757	Economy	3200.00
0005435127067	14757	Economy	3200.00
0005434411821	14757	Economy	3200.00
0005435127075	14757	Economy	3200.00
0005435127073	14757	Economy	3200.00
0005434928335	14757	Economy	3200.00
0005435127096	14757	Economy	3200.00
0005435626500	14757	Economy	3500.00
0005435626491	14757	Economy	3500.00
0005435626490	14757	Economy	3500.00
0005435127082	14757	Economy	3500.00
0005435626497	14757	Economy	3200.00
0005434411811	14757	Economy	3200.00
0005435127087	14757	Economy	3200.00
0005435127074	14757	Economy	3200.00
0005435626503	14757	Economy	3200.00
0005435626496	14757	Economy	3200.00
0005435127098	14757	Economy	3200.00
0005435127091	14757	Economy	3200.00
0005435127092	14757	Economy	3200.00
0005435127095	14757	Economy	3200.00
0005435626487	14757	Economy	3200.00
0005435127101	14757	Economy	3200.00
0005435626493	14757	Economy	3200.00
0005435554270	14757	Economy	3200.00
0005435626494	14757	Economy	3200.00
0005435127094	14757	Economy	3200.00
0005434411815	14757	Economy	3200.00
0005435626505	14757	Economy	3200.00
0005435626495	14757	Economy	3200.00
0005435127083	14757	Economy	3200.00
0005435127079	14757	Economy	3200.00
0005435127072	14757	Economy	3200.00
0005435127066	14757	Economy	3200.00
0005435127099	14757	Economy	3200.00
0005435127089	14757	Economy	3200.00
0005434411836	14757	Economy	3200.00
0005434411801	14757	Economy	3200.00
0005435626502	14757	Economy	3200.00
0005435127070	14757	Economy	3200.00
0005435127084	14757	Economy	3200.00
0005435127088	14757	Economy	3200.00
0005435127100	14757	Economy	3200.00
0005435554269	14757	Economy	3200.00
0005435127069	14757	Economy	3200.00
0005435127065	14757	Economy	3200.00
0005435127063	14757	Economy	3200.00
0005435127081	14757	Economy	3200.00
0005435127078	14757	Economy	3200.00
0005435127090	14757	Economy	3200.00
0005435626506	14757	Economy	3200.00
0005435626501	14757	Economy	3200.00
0005435127104	14757	Economy	3200.00
0005435127086	14757	Economy	3200.00
0005435556736	14757	Economy	3200.00
0005434411817	14757	Economy	3200.00
0005435127102	14757	Economy	3200.00
0005435127103	14757	Economy	3200.00
0005434411794	14757	Economy	3200.00
0005434928333	14757	Economy	3200.00
0005435127077	14757	Economy	3200.00
0005435554267	14757	Economy	3200.00
0005435127071	14757	Economy	3200.00
0005434928325	14757	Economy	3200.00
0005435626504	14757	Economy	3200.00
0005435554271	14757	Economy	3200.00
0005435626499	14757	Economy	3200.00
0005435127068	14757	Economy	3200.00
0005435554268	14757	Economy	3200.00
0005435127076	14757	Economy	3200.00
0005435715774	7100	Business	86900.00
0005435443382	7100	Business	86900.00
0005435715763	7100	Business	86900.00
0005435715773	7100	Economy	29000.00
0005432400190	7100	Economy	29000.00
0005435715767	7100	Economy	29000.00
0005435715765	7100	Economy	29000.00
0005435715761	7100	Economy	29000.00
0005432400188	7100	Economy	31900.00
0005435715775	7100	Economy	31900.00
0005435443370	7100	Economy	31900.00
0005435178507	7100	Economy	29000.00
0005435715764	7100	Economy	29000.00
0005435443360	7100	Economy	29000.00
0005432398261	7100	Economy	29000.00
0005435715768	7100	Economy	29000.00
0005435219225	7100	Economy	29000.00
0005432398262	7100	Economy	29000.00
0005435179402	7100	Economy	29000.00
0005435715762	7100	Economy	29000.00
0005435715759	7100	Economy	29000.00
0005432400189	7100	Economy	29000.00
0005435219220	7100	Economy	29000.00
0005432398263	7100	Economy	29000.00
0005435219219	7100	Economy	29000.00
0005435443369	7100	Economy	29000.00
0005435443422	7100	Economy	29000.00
0005435715771	7100	Economy	29000.00
0005435715760	7100	Economy	29000.00
0005435443381	7100	Economy	29000.00
0005432398264	7100	Economy	29000.00
0005432400191	7100	Economy	29000.00
0005435219226	7100	Economy	29000.00
0005435715770	7100	Economy	29000.00
0005435715769	7100	Economy	29000.00
0005435715766	7100	Economy	29000.00
0005435715772	7100	Economy	29000.00
0005435715554	27061	Business	86900.00
0005435715557	27061	Business	86900.00
0005435715602	27061	Business	86900.00
0005435715579	27061	Business	86900.00
0005432398234	27061	Business	86900.00
0005435715603	27061	Economy	29000.00
0005435715631	27061	Economy	29000.00
0005435715572	27061	Economy	29000.00
0005435443481	27061	Economy	29000.00
0005435178521	27061	Economy	29000.00
0005435443475	27061	Economy	29000.00
0005435715643	27061	Economy	31900.00
0005432398233	27061	Economy	31900.00
0005435443478	27061	Economy	29000.00
0005435715644	27061	Economy	29000.00
0005432398220	27061	Economy	29000.00
0005435715639	27061	Economy	29000.00
0005432394153	27061	Economy	29000.00
0005435715530	27061	Economy	29000.00
0005435715665	27061	Economy	29000.00
0005435715608	27061	Economy	29000.00
0005435443477	27061	Economy	29000.00
0005435443479	27061	Economy	29000.00
0005435715697	27061	Economy	29000.00
0005432394154	27061	Economy	29000.00
0005435715655	27061	Economy	29000.00
0005435179007	27061	Economy	29000.00
0005435715654	27061	Economy	29000.00
0005435715640	27061	Economy	29000.00
0005435178520	27061	Economy	29000.00
0005435715698	27061	Economy	29000.00
0005435443476	27061	Economy	29000.00
0005435715621	27061	Economy	29000.00
0005435179008	27061	Economy	29000.00
0005435443480	27061	Economy	29000.00
0005433060440	2744	Economy	7700.00
0005434085012	2744	Economy	7700.00
0005434085011	2744	Economy	7700.00
0005434085009	2744	Economy	7700.00
0005433060441	2744	Economy	7700.00
0005434085010	2744	Economy	7700.00
0005434085013	2744	Economy	7700.00
0005433060459	28493	Economy	7700.00
0005433060461	28493	Economy	7700.00
0005434084972	28493	Economy	7700.00
0005433060460	28493	Economy	7700.00
0005434084959	28493	Economy	7700.00
0005432632833	25205	Economy	29000.00
0005435844315	25205	Economy	29000.00
0005432632845	25205	Economy	26400.00
0005432632849	25205	Economy	26400.00
0005432632842	25205	Economy	26400.00
0005432632846	25205	Economy	26400.00
0005435844345	25205	Economy	26400.00
0005432632847	25205	Economy	26400.00
0005432632836	25205	Economy	26400.00
0005432632835	25205	Economy	26400.00
0005432632838	25205	Economy	26400.00
0005432632839	25205	Economy	26400.00
0005432632841	25205	Economy	26400.00
0005435844329	25205	Economy	26400.00
0005432632834	25205	Economy	26400.00
0005432632848	25205	Economy	26400.00
0005435844313	25205	Economy	26400.00
0005435844343	25205	Economy	26400.00
0005432632840	25205	Economy	26400.00
0005432632850	25205	Economy	26400.00
0005432632851	25205	Economy	26400.00
0005432632843	25205	Economy	26400.00
0005432632852	25205	Economy	26400.00
0005432632832	25205	Economy	26400.00
0005432632844	25205	Economy	26400.00
0005432632853	25205	Economy	26400.00
0005432632837	25205	Economy	26400.00
0005435844327	25205	Economy	26400.00
0005432632781	28169	Economy	29000.00
0005432632783	28169	Economy	29000.00
0005432632782	28169	Economy	29000.00
0005435844384	28169	Economy	26400.00
0005435844380	28169	Economy	26400.00
0005432632764	28169	Economy	26400.00
0005435844391	28169	Economy	26400.00
0005435844386	28169	Economy	26400.00
0005432632776	28169	Economy	26400.00
0005435844385	28169	Economy	26400.00
0005432632762	28169	Economy	26400.00
0005432632784	28169	Economy	26400.00
0005432632773	28169	Economy	26400.00
0005432632795	28169	Economy	26400.00
0005432632779	28169	Economy	26400.00
0005432632792	28169	Economy	26400.00
0005432632780	28169	Economy	26400.00
0005432632759	28169	Economy	26400.00
0005432632761	28169	Economy	26400.00
0005435844387	28169	Economy	26400.00
0005432632794	28169	Economy	26400.00
0005432632786	28169	Economy	26400.00
0005435844383	28169	Economy	26400.00
0005432632798	28169	Economy	26400.00
0005432632769	28169	Economy	26400.00
0005435844388	28169	Economy	26400.00
0005435844389	28169	Economy	26400.00
0005432632758	28169	Economy	26400.00
0005432632763	28169	Economy	26400.00
0005432632772	28169	Economy	26400.00
0005432632775	28169	Economy	26400.00
0005432632787	28169	Economy	26400.00
0005432632803	28169	Economy	26400.00
0005435844392	28169	Economy	26400.00
0005435844390	28169	Economy	26400.00
0005432632778	28169	Economy	26400.00
0005435844381	28169	Economy	26400.00
0005432632790	28169	Economy	26400.00
0005432632765	28169	Economy	26400.00
0005435844382	28169	Economy	26400.00
0005435844379	28169	Economy	26400.00
0005432632770	28169	Economy	26400.00
0005432632799	28169	Economy	26400.00
0005432632777	28169	Economy	26400.00
0005432632804	28169	Economy	26400.00
0005435518104	11390	Business	20200.00
0005435518061	11390	Business	20200.00
0005435518098	11390	Business	20200.00
0005435541098	11390	Business	20200.00
0005435518087	11390	Economy	6700.00
0005435541156	11390	Economy	6700.00
0005435541264	11390	Economy	6700.00
0005435541263	11390	Economy	7400.00
0005435518134	11390	Economy	6700.00
0005435541239	11390	Economy	6700.00
0005435541242	11390	Economy	6700.00
0005435518088	11390	Economy	6700.00
0005435518117	11390	Economy	6700.00
0005435541185	11390	Economy	6700.00
0005435541247	11390	Economy	6700.00
0005435518045	11390	Economy	6700.00
0005435541177	11390	Economy	6700.00
0005435518055	11390	Economy	6700.00
0005435518046	11390	Economy	6700.00
0005435541200	11390	Economy	6700.00
0005435518069	11390	Economy	6700.00
0005435541186	11390	Economy	6700.00
0005435541199	11390	Economy	6700.00
0005435518056	11390	Economy	6700.00
0005435541128	11390	Economy	6700.00
0005435541260	11390	Economy	6700.00
0005435541193	11390	Economy	6700.00
0005435541210	11390	Economy	6700.00
0005435518103	11390	Economy	6700.00
0005435541205	11390	Economy	6700.00
0005435541178	11390	Economy	6700.00
0005435541261	11390	Economy	6700.00
0005435541211	11390	Economy	6700.00
0005435529628	22249	Business	20200.00
0005435529623	22249	Business	20200.00
0005435529615	22249	Business	20200.00
0005435529630	22249	Business	20200.00
0005435541367	22249	Business	20200.00
0005435529620	22249	Business	20200.00
0005435529610	22249	Economy	6700.00
0005435529612	22249	Economy	6700.00
0005432294526	22249	Economy	6700.00
0005435541355	22249	Economy	6700.00
0005435529631	22249	Economy	6700.00
0005435541361	22249	Economy	7400.00
0005435541372	22249	Economy	7400.00
0005435541368	22249	Economy	7400.00
0005435529987	22249	Economy	6700.00
0005435529979	22249	Economy	6700.00
0005435529629	22249	Economy	6700.00
0005435541366	22249	Economy	6700.00
0005435541374	22249	Economy	6700.00
0005435529985	22249	Economy	6700.00
0005435541375	22249	Economy	6700.00
0005435529989	22249	Economy	6700.00
0005435529625	22249	Economy	6700.00
0005435541360	22249	Economy	6700.00
0005435529611	22249	Economy	6700.00
0005435529621	22249	Economy	6700.00
0005435529988	22249	Economy	6700.00
0005435529983	22249	Economy	6700.00
0005435529616	22249	Economy	6700.00
0005435541369	22249	Economy	6700.00
0005435541362	22249	Economy	6700.00
0005435529982	22249	Economy	6700.00
0005432294528	22249	Economy	6700.00
0005435541370	22249	Economy	6700.00
0005435529618	22249	Economy	6700.00
0005435529981	22249	Economy	6700.00
0005435541359	22249	Economy	6700.00
0005435529984	22249	Economy	6700.00
0005435541373	22249	Economy	6700.00
0005435541365	22249	Economy	6700.00
0005435529980	22249	Economy	6700.00
0005435541363	22249	Economy	6700.00
0005435541376	22249	Economy	6700.00
0005432294527	22249	Economy	6700.00
0005435541357	22249	Economy	6700.00
0005435529619	22249	Economy	6700.00
0005435529614	22249	Economy	6700.00
0005435529626	22249	Economy	6700.00
0005435529613	22249	Economy	6700.00
0005435529617	22249	Economy	6700.00
0005435541356	22249	Economy	6700.00
0005435541358	22249	Economy	6700.00
0005435529622	22249	Economy	6700.00
0005435541354	22249	Economy	6700.00
0005435529624	22249	Economy	6700.00
0005435529627	22249	Economy	6700.00
0005435529986	22249	Economy	6700.00
0005435541371	22249	Economy	6700.00
0005435541364	22249	Economy	6700.00
0005434908217	2296	Business	20200.00
0005434908198	2296	Business	20200.00
0005434908181	2296	Business	20200.00
0005433251822	2296	Business	20200.00
0005434908187	2296	Business	20200.00
0005434908208	2296	Business	20200.00
0005434908178	2296	Business	20200.00
0005434908213	2296	Business	20200.00
0005434908172	2296	Business	20200.00
0005434908182	2296	Business	20200.00
0005433401027	2296	Economy	6700.00
0005434908203	2296	Economy	6700.00
0005433251829	2296	Economy	6700.00
0005433251891	2296	Economy	6700.00
0005433251755	2296	Economy	6700.00
0005433251823	2296	Economy	6700.00
0005434908196	2296	Economy	6700.00
0005434908201	2296	Economy	7400.00
0005433251810	2296	Economy	7400.00
0005433251792	2296	Economy	7400.00
0005433251777	2296	Economy	7400.00
0005434908211	2296	Economy	7400.00
0005434908163	2296	Economy	6700.00
0005434908167	2296	Economy	6700.00
0005434908183	2296	Economy	6700.00
0005433251774	2296	Economy	6700.00
0005434908177	2296	Economy	6700.00
0005433251892	2296	Economy	6700.00
0005434908179	2296	Economy	6700.00
0005434908205	2296	Economy	6700.00
0005434908209	2296	Economy	6700.00
0005434908184	2296	Economy	6700.00
0005434908192	2296	Economy	6700.00
0005434908171	2296	Economy	6700.00
0005433251873	2296	Economy	6700.00
0005434908204	2296	Economy	6700.00
0005433401015	2296	Economy	6700.00
0005434908166	2296	Economy	6700.00
0005433401004	2296	Economy	6700.00
0005434908202	2296	Economy	6700.00
0005433251835	2296	Economy	6700.00
0005434908191	2296	Economy	6700.00
0005434908188	2296	Economy	6700.00
0005433251893	2296	Economy	6700.00
0005434908173	2296	Economy	6700.00
0005434908190	2296	Economy	6700.00
0005434908214	2296	Economy	6700.00
0005434908199	2296	Economy	6700.00
0005434908176	2296	Economy	6700.00
0005434908207	2296	Economy	6700.00
0005434908169	2296	Economy	6700.00
0005433251751	2296	Economy	6700.00
0005433251871	2296	Economy	6700.00
0005434908195	2296	Economy	6700.00
0005434908216	2296	Economy	6700.00
0005433251785	2296	Economy	6700.00
0005434908210	2296	Economy	6700.00
0005434908189	2296	Economy	6700.00
0005434908212	2296	Economy	6700.00
0005433251612	2296	Economy	6700.00
0005433401003	2296	Economy	6700.00
0005434908175	2296	Economy	6700.00
0005433251831	2296	Economy	6700.00
0005433251876	2296	Economy	6700.00
0005434908174	2296	Economy	6700.00
0005434908200	2296	Economy	6700.00
0005434908186	2296	Economy	6700.00
0005433251877	2296	Economy	6700.00
0005433251872	2296	Economy	6700.00
0005434908180	2296	Economy	6700.00
0005433251836	2296	Economy	6700.00
0005433251770	2296	Economy	6700.00
0005434908185	2296	Economy	6700.00
0005434908197	2296	Economy	6700.00
0005433251750	2296	Economy	6700.00
0005434908215	2296	Economy	6700.00
0005433251771	2296	Economy	6700.00
0005434908165	2296	Economy	6700.00
0005433251784	2296	Economy	6700.00
0005434908193	2296	Economy	6700.00
0005433251935	2296	Economy	6700.00
0005434908218	2296	Economy	6700.00
0005433251786	2296	Economy	6700.00
0005434908168	2296	Economy	6700.00
0005434908170	2296	Economy	6700.00
0005434908194	2296	Economy	6700.00
0005434908206	2296	Economy	6700.00
0005434908164	2296	Economy	6700.00
0005433252007	25580	Business	20200.00
0005434907507	25580	Business	20200.00
0005434907579	25580	Business	20200.00
0005434907685	25580	Business	20200.00
0005434907423	25580	Business	20200.00
0005434907603	25580	Business	20200.00
0005434907728	25580	Business	20200.00
0005434907675	25580	Business	20200.00
0005433252033	25580	Business	20200.00
0005433252017	25580	Economy	6700.00
0005434907706	25580	Economy	6700.00
0005434907752	25580	Economy	6700.00
0005433252031	25580	Economy	6700.00
0005433252013	25580	Economy	6700.00
0005433252016	25580	Economy	6700.00
0005434907676	25580	Economy	6700.00
0005434907745	25580	Economy	6700.00
0005434907550	25580	Economy	6700.00
0005434907439	25580	Economy	7400.00
0005434907753	25580	Economy	7400.00
0005434907722	25580	Economy	7400.00
0005434907725	25580	Economy	7400.00
0005434907733	25580	Economy	6700.00
0005434907690	25580	Economy	6700.00
0005433252029	25580	Economy	6700.00
0005434907659	25580	Economy	6700.00
0005433252027	25580	Economy	6700.00
0005434907704	25580	Economy	6700.00
0005434907598	25580	Economy	6700.00
0005433252020	25580	Economy	6700.00
0005433252018	25580	Economy	6700.00
0005434907654	25580	Economy	6700.00
0005434907475	25580	Economy	6700.00
0005434907721	25580	Economy	6700.00
0005433252021	25580	Economy	6700.00
0005434907585	25580	Economy	6700.00
0005433252006	25580	Economy	6700.00
0005433252009	25580	Economy	6700.00
0005434907534	25580	Economy	6700.00
0005433252022	25580	Economy	6700.00
0005433252005	25580	Economy	6700.00
0005434907705	25580	Economy	6700.00
0005433252023	25580	Economy	6700.00
0005433401037	25580	Economy	6700.00
0005434907549	25580	Economy	6700.00
0005434907734	25580	Economy	6700.00
0005433252028	25580	Economy	6700.00
0005434907727	25580	Economy	6700.00
0005433252014	25580	Economy	6700.00
0005433252026	25580	Economy	6700.00
0005434907656	25580	Economy	6700.00
0005434907397	25580	Economy	6700.00
0005434907726	25580	Economy	6700.00
0005434907607	25580	Economy	6700.00
0005434907741	25580	Economy	6700.00
0005434907487	25580	Economy	6700.00
0005434907658	25580	Economy	6700.00
0005433252004	25580	Economy	6700.00
0005434907616	25580	Economy	6700.00
0005434907617	25580	Economy	6700.00
0005433252015	25580	Economy	6700.00
0005433252008	25580	Economy	6700.00
0005433252030	25580	Economy	6700.00
0005434907422	25580	Economy	6700.00
0005433252012	25580	Economy	6700.00
0005434907587	25580	Economy	6700.00
0005433252024	25580	Economy	6700.00
0005433401036	25580	Economy	6700.00
0005433252025	25580	Economy	6700.00
0005434907778	25580	Economy	6700.00
0005433252011	25580	Economy	6700.00
0005434907657	25580	Economy	6700.00
0005434907720	25580	Economy	6700.00
0005434907602	25580	Economy	6700.00
0005434907724	25580	Economy	6700.00
0005433252010	25580	Economy	6700.00
0005433252019	25580	Economy	6700.00
0005434907723	25580	Economy	6700.00
0005433252032	25580	Economy	6700.00
0005434907689	25580	Economy	6700.00
0005434907732	25580	Economy	6700.00
0005433252003	25580	Economy	6700.00
0005433252002	25580	Economy	6700.00
0005434907568	25580	Economy	6700.00
0005432621287	2518	Economy	13600.00
0005432621281	2518	Economy	12400.00
0005432621280	2518	Economy	12400.00
0005432621288	2518	Economy	12400.00
0005432862407	2518	Economy	12400.00
0005432621286	2518	Economy	12400.00
0005432621279	2518	Economy	12400.00
0005432621285	2518	Economy	12400.00
0005432621284	2518	Economy	12400.00
0005432862361	2518	Economy	12400.00
0005432621278	2518	Economy	12400.00
0005432621290	2518	Economy	12400.00
0005432862362	2518	Economy	12400.00
0005432621291	2518	Economy	12400.00
0005432862377	2518	Economy	12400.00
0005432862395	2518	Economy	12400.00
0005432862406	2518	Economy	12400.00
0005432621282	2518	Economy	12400.00
0005432862367	2518	Economy	12400.00
0005432862363	2518	Economy	12400.00
0005432621289	2518	Economy	12400.00
0005432621283	2518	Economy	12400.00
0005432862438	28041	Economy	13600.00
0005432621125	28041	Economy	12400.00
0005432862440	28041	Economy	12400.00
0005432621109	28041	Economy	12400.00
0005432862436	28041	Economy	12400.00
0005432621140	28041	Economy	12400.00
0005432621186	28041	Economy	12400.00
0005432621111	28041	Economy	12400.00
0005432621124	28041	Economy	12400.00
0005432862437	28041	Economy	12400.00
0005432621207	28041	Economy	12400.00
0005432621232	28041	Economy	12400.00
0005432621189	28041	Economy	12400.00
0005432862439	28041	Economy	12400.00
0005432621187	28041	Economy	12400.00
0005432621184	28041	Economy	12400.00
0005432621183	28041	Economy	12400.00
0005432862434	28041	Economy	12400.00
0005432621231	28041	Economy	12400.00
0005432621160	28041	Economy	12400.00
0005432621214	28041	Economy	12400.00
0005432621161	28041	Economy	12400.00
0005432862435	28041	Economy	12400.00
0005432621110	28041	Economy	12400.00
0005432862441	28041	Economy	12400.00
0005434097488	11701	Economy	11300.00
0005434097487	11701	Economy	11300.00
0005434191297	28025	Economy	29900.00
0005434191304	28025	Economy	29900.00
0005434191303	28025	Economy	29900.00
0005434191301	28025	Economy	29900.00
0005434191302	28025	Economy	29900.00
0005434191306	28025	Economy	29900.00
0005434191298	28025	Economy	29900.00
0005434191299	28025	Economy	29900.00
0005434191300	28025	Economy	29900.00
0005434191305	28025	Economy	29900.00
0005434191307	28025	Economy	29900.00
0005433452775	31056	Economy	8400.00
0005433452777	31056	Economy	8400.00
0005433452776	31056	Economy	8400.00
0005433451653	31056	Economy	8400.00
0005433451655	31056	Economy	8400.00
0005433451654	31056	Economy	8400.00
0005433452755	31445	Economy	8400.00
0005433134188	11984	Economy	7200.00
0005433129307	11984	Economy	6600.00
0005433129329	11984	Economy	6600.00
0005433129328	11984	Economy	6600.00
0005434142644	11984	Economy	6600.00
0005433134180	11984	Economy	6600.00
0005433134181	11984	Economy	6600.00
0005434142645	11984	Economy	6600.00
0005433134177	11984	Economy	6600.00
0005433134176	11984	Economy	6600.00
0005433129308	11984	Economy	6600.00
0005433129338	11984	Economy	6600.00
0005434142635	11984	Economy	6600.00
0005434184702	29839	Economy	6600.00
0005433134220	29839	Economy	6600.00
0005433131789	29839	Economy	6600.00
0005434142675	29839	Economy	6600.00
0005433134219	29839	Economy	6600.00
0005433134216	29839	Economy	6600.00
0005433134218	29839	Economy	6600.00
0005434184701	29839	Economy	6600.00
0005434183615	29839	Economy	6600.00
0005434142676	29839	Economy	6600.00
0005434142677	29839	Economy	6600.00
0005434142674	29839	Economy	6600.00
0005433131787	29839	Economy	6600.00
0005433131788	29839	Economy	6600.00
0005433134217	29839	Economy	6600.00
0005434184700	29839	Economy	6600.00
0005433131786	29839	Economy	6600.00
0005434183614	29839	Economy	6600.00
0005435697801	16454	Economy	19900.00
0005435697808	16454	Economy	18100.00
0005435697792	16454	Economy	18100.00
0005435697806	16454	Economy	18100.00
0005435697800	16454	Economy	18100.00
0005435697791	16454	Economy	18100.00
0005435697803	16454	Economy	18100.00
0005435697795	16454	Economy	18100.00
0005435697815	16454	Economy	18100.00
0005435697814	16454	Economy	18100.00
0005435697807	16454	Economy	18100.00
0005435697802	16454	Economy	18100.00
0005435697793	16454	Economy	18100.00
0005435697794	16454	Economy	18100.00
0005435697797	16454	Economy	18100.00
0005435697813	16454	Economy	18100.00
0005435697812	16454	Economy	18100.00
0005435697805	16454	Economy	18100.00
0005435697811	16454	Economy	18100.00
0005435697817	16454	Economy	18100.00
0005435697809	16454	Economy	18100.00
0005435697810	16454	Economy	18100.00
0005435697796	16454	Economy	18100.00
0005435697804	16454	Economy	18100.00
0005435697818	16454	Economy	18100.00
0005435697816	16454	Economy	18100.00
0005435697798	16454	Economy	18100.00
0005435697799	16454	Economy	18100.00
0005435697612	24744	Economy	19900.00
0005435697490	24744	Economy	18100.00
0005435697626	24744	Economy	18100.00
0005435935097	24744	Economy	18100.00
0005435697596	24744	Economy	18100.00
0005435697669	24744	Economy	18100.00
0005435697625	24744	Economy	18100.00
0005435697716	24744	Economy	18100.00
0005435697630	24744	Economy	18100.00
0005435697491	24744	Economy	18100.00
0005435697671	24744	Economy	18100.00
0005435697610	24744	Economy	18100.00
0005435697668	24744	Economy	18100.00
0005435697629	24744	Economy	18100.00
0005435935095	24744	Economy	18100.00
0005435697564	24744	Economy	18100.00
0005435697562	24744	Economy	18100.00
0005435697565	24744	Economy	18100.00
0005435697591	24744	Economy	18100.00
0005435697586	24744	Economy	18100.00
0005435935096	24744	Economy	18100.00
0005435697611	24744	Economy	18100.00
0005435935098	24744	Economy	18100.00
0005435697563	24744	Economy	18100.00
0005433724884	18811	Economy	4400.00
0005433724880	18811	Economy	4400.00
0005433724882	18811	Economy	4400.00
0005432968854	18811	Economy	4400.00
0005433724881	18811	Economy	4400.00
0005432968860	18811	Economy	4400.00
0005433724883	18811	Economy	4400.00
0005432968853	18811	Economy	4400.00
0005433724834	21633	Economy	4400.00
0005433724828	21633	Economy	4400.00
0005432968883	21633	Economy	4400.00
0005432968882	21633	Economy	4400.00
0005432968884	21633	Economy	4400.00
0005433724857	21633	Economy	4400.00
0005432968881	21633	Economy	4400.00
0005433724848	21633	Economy	4400.00
0005434139583	7315	Business	23100.00
0005434139612	7315	Business	23100.00
0005434139597	7315	Business	23100.00
0005434139568	7315	Business	23100.00
0005434139613	7315	Business	23100.00
0005434139564	7315	Business	23100.00
0005434139614	7315	Business	23100.00
0005434139598	7315	Business	23100.00
0005434139578	7315	Business	23100.00
0005434139575	7315	Business	23100.00
0005434139558	7315	Economy	7700.00
0005434139601	7315	Economy	7700.00
0005434087599	7315	Economy	7700.00
0005434139608	7315	Economy	7700.00
0005434139571	7315	Economy	7700.00
0005434139602	7315	Economy	7700.00
0005434139581	7315	Economy	7700.00
0005434139621	7315	Economy	7700.00
0005434087600	7315	Economy	7700.00
0005434139589	7315	Economy	8500.00
0005434139562	7315	Economy	8500.00
0005434139566	7315	Economy	8500.00
0005434139573	7315	Economy	8500.00
0005434087598	7315	Economy	8500.00
0005434139548	7315	Economy	7700.00
0005434139547	7315	Economy	7700.00
0005434139593	7315	Economy	7700.00
0005434139588	7315	Economy	7700.00
0005434139615	7315	Economy	7700.00
0005434139569	7315	Economy	7700.00
0005434139559	7315	Economy	7700.00
0005434139553	7315	Economy	7700.00
0005434139579	7315	Economy	7700.00
0005434087601	7315	Economy	7700.00
0005434087597	7315	Economy	7700.00
0005434087602	7315	Economy	7700.00
0005434139563	7315	Economy	7700.00
0005434139560	7315	Economy	7700.00
0005434139576	7315	Economy	7700.00
0005434139555	7315	Economy	7700.00
0005434139609	7315	Economy	7700.00
0005434139580	7315	Economy	7700.00
0005434139565	7315	Economy	7700.00
0005434139582	7315	Economy	7700.00
0005434139552	7315	Economy	7700.00
0005434139556	7315	Economy	7700.00
0005434139596	7315	Economy	7700.00
0005434139618	7315	Economy	7700.00
0005434139587	7315	Economy	7700.00
0005434139620	7315	Economy	7700.00
0005434139574	7315	Economy	7700.00
0005434139619	7315	Economy	7700.00
0005434139546	7315	Economy	7700.00
0005434139600	7315	Economy	7700.00
0005434139616	7315	Economy	7700.00
0005434139606	7315	Economy	7700.00
0005434139592	7315	Economy	7700.00
0005434139570	7315	Economy	7700.00
0005434139604	7315	Economy	7700.00
0005434139594	7315	Economy	7700.00
0005434139611	7315	Economy	7700.00
0005434139561	7315	Economy	7700.00
0005434139599	7315	Economy	7700.00
0005434139551	7315	Economy	7700.00
0005434139549	7315	Economy	7700.00
0005434139610	7315	Economy	7700.00
0005434139595	7315	Economy	7700.00
0005434139550	7315	Economy	7700.00
0005434139584	7315	Economy	7700.00
0005434139603	7315	Economy	7700.00
0005434139586	7315	Economy	7700.00
0005434139572	7315	Economy	7700.00
0005434139554	7315	Economy	7700.00
0005434139605	7315	Economy	7700.00
0005434139617	7315	Economy	7700.00
0005434139557	7315	Economy	7700.00
0005434139577	7315	Economy	7700.00
0005434139591	7315	Economy	7700.00
0005434139607	7315	Economy	7700.00
0005434139590	7315	Economy	7700.00
0005434139585	7315	Economy	7700.00
0005434139567	7315	Economy	7700.00
0005434138797	28567	Business	23100.00
0005434138526	28567	Business	23100.00
0005434138692	28567	Business	23100.00
0005434138679	28567	Business	23100.00
0005434138691	28567	Business	23100.00
0005434138812	28567	Business	23100.00
0005434138470	28567	Business	23100.00
0005434138684	28567	Business	23100.00
0005434138552	28567	Economy	7700.00
0005434138944	28567	Economy	7700.00
0005434138045	28567	Economy	7700.00
0005434138532	28567	Economy	7700.00
0005434138964	28567	Economy	7700.00
0005434138978	28567	Economy	7700.00
0005434138918	28567	Economy	7700.00
0005434138611	28567	Economy	7700.00
0005434138376	28567	Economy	7700.00
0005434138886	28567	Economy	8500.00
0005434138533	28567	Economy	8500.00
0005434138631	28567	Economy	8500.00
0005434138942	28567	Economy	8500.00
0005434138796	28567	Economy	8500.00
0005434138570	28567	Economy	7700.00
0005434138636	28567	Economy	7700.00
0005434138648	28567	Economy	7700.00
0005434138857	28567	Economy	7700.00
0005434138881	28567	Economy	7700.00
0005434138879	28567	Economy	7700.00
0005434138375	28567	Economy	7700.00
0005434138635	28567	Economy	7700.00
0005434138813	28567	Economy	7700.00
0005434138250	28567	Economy	7700.00
0005434138917	28567	Economy	7700.00
0005434138424	28567	Economy	7700.00
0005434138645	28567	Economy	7700.00
0005434138599	28567	Economy	7700.00
0005434138646	28567	Economy	7700.00
0005434138934	28567	Economy	7700.00
0005434138846	28567	Economy	7700.00
0005434138756	28567	Economy	7700.00
0005434138783	28567	Economy	7700.00
0005434138963	28567	Economy	7700.00
0005434138773	28567	Economy	7700.00
0005434138821	28567	Economy	7700.00
0005434138571	28567	Economy	7700.00
0005434138738	28567	Economy	7700.00
0005434138882	28567	Economy	7700.00
0005434138681	28567	Economy	7700.00
0005434138554	28567	Economy	7700.00
0005434138892	28567	Economy	7700.00
0005434138607	28567	Economy	7700.00
0005434138867	28567	Economy	7700.00
0005434138856	28567	Economy	7700.00
0005434138680	28567	Economy	7700.00
0005434138513	28567	Economy	7700.00
0005434138767	28567	Economy	7700.00
0005434138737	28567	Economy	7700.00
0005434138887	28567	Economy	7700.00
0005434138210	28567	Economy	7700.00
0005434138969	28567	Economy	7700.00
0005434138933	28567	Economy	7700.00
0005434138565	28567	Economy	7700.00
0005434138553	28567	Economy	7700.00
0005434138810	28567	Economy	7700.00
0005434138916	28567	Economy	7700.00
0005434138609	28567	Economy	7700.00
0005434138608	28567	Economy	7700.00
0005434138739	28567	Economy	7700.00
0005434138840	28567	Economy	7700.00
0005434138971	28567	Economy	7700.00
0005434138211	28567	Economy	7700.00
0005434138629	28567	Economy	7700.00
0005434138941	28567	Economy	7700.00
0005434138811	28567	Economy	7700.00
0005434138716	28567	Economy	7700.00
0005434138630	28567	Economy	7700.00
0005434087577	28567	Economy	7700.00
0005434138612	28567	Economy	7700.00
0005434138858	28567	Economy	7700.00
0005434138527	28567	Economy	7700.00
0005434138649	28567	Economy	7700.00
0005434138600	28567	Economy	7700.00
0005434138759	28567	Economy	7700.00
0005434138610	28567	Economy	7700.00
0005434138700	28567	Economy	7700.00
0005434138046	28567	Economy	7700.00
0005434138755	28567	Economy	7700.00
0005434610292	1894	Economy	23900.00
0005435808407	1894	Economy	21700.00
0005435808409	1894	Economy	21700.00
0005433407633	1894	Economy	21700.00
0005434610293	1894	Economy	21700.00
0005434610291	1894	Economy	21700.00
0005435808405	1894	Economy	21700.00
0005433407605	1894	Economy	21700.00
0005435808406	1894	Economy	21700.00
0005435808411	1894	Economy	21700.00
0005433407606	1894	Economy	21700.00
0005435808408	1894	Economy	21700.00
0005435808412	1894	Economy	21700.00
0005435808410	1894	Economy	21700.00
0005434610294	1894	Economy	21700.00
0005434610262	23111	Economy	21700.00
0005434504375	16695	Economy	7600.00
0005434504386	16695	Economy	7600.00
0005434504401	16695	Economy	7600.00
0005434504497	16695	Economy	7600.00
0005434504472	16695	Economy	6900.00
0005434504411	16695	Economy	6900.00
0005434504553	16695	Economy	6900.00
0005434504505	16695	Economy	6900.00
0005434504328	16695	Economy	6900.00
0005434504296	16695	Economy	6900.00
0005434504295	16695	Economy	6900.00
0005434504508	16695	Economy	6900.00
0005434504385	16695	Economy	6900.00
0005434504468	16695	Economy	6900.00
0005434504511	16695	Economy	6900.00
0005434504467	16695	Economy	6900.00
0005434504537	16695	Economy	6900.00
0005434504466	16695	Economy	6900.00
0005434504471	16695	Economy	6900.00
0005434504496	16695	Economy	6900.00
0005434504464	16695	Economy	6900.00
0005434504509	16695	Economy	6900.00
0005434504477	16695	Economy	6900.00
0005434504410	16695	Economy	6900.00
0005434504451	16695	Economy	6900.00
0005434504374	16695	Economy	6900.00
0005434504510	16695	Economy	6900.00
0005434504465	16695	Economy	6900.00
0005434504301	16695	Economy	6900.00
0005434504387	16695	Economy	6900.00
0005434504552	16695	Economy	6900.00
0005434504294	16695	Economy	6900.00
0005434504298	16695	Economy	6900.00
0005434504340	16695	Economy	6900.00
0005434504812	22913	Economy	7600.00
0005434504805	22913	Economy	7600.00
0005434504824	22913	Economy	7600.00
0005434504817	22913	Economy	7600.00
0005434504798	22913	Economy	6900.00
0005434504813	22913	Economy	6900.00
0005434504807	22913	Economy	6900.00
0005434504806	22913	Economy	6900.00
0005434504796	22913	Economy	6900.00
0005434504801	22913	Economy	6900.00
0005434504791	22913	Economy	6900.00
0005434504793	22913	Economy	6900.00
0005434504808	22913	Economy	6900.00
0005434504825	22913	Economy	6900.00
0005434504800	22913	Economy	6900.00
0005434504821	22913	Economy	6900.00
0005434504803	22913	Economy	6900.00
0005434504823	22913	Economy	6900.00
0005434504822	22913	Economy	6900.00
0005434504789	22913	Economy	6900.00
0005434504816	22913	Economy	6900.00
0005434504815	22913	Economy	6900.00
0005434504809	22913	Economy	6900.00
0005434504790	22913	Economy	6900.00
0005434504804	22913	Economy	6900.00
0005434504802	22913	Economy	6900.00
0005434504788	22913	Economy	6900.00
0005434504795	22913	Economy	6900.00
0005434504811	22913	Economy	6900.00
0005434504787	22913	Economy	6900.00
0005434504818	22913	Economy	6900.00
0005434504814	22913	Economy	6900.00
0005434504799	22913	Economy	6900.00
0005434504819	22913	Economy	6900.00
0005434504820	22913	Economy	6900.00
0005434504792	22913	Economy	6900.00
0005434504797	22913	Economy	6900.00
0005434504794	22913	Economy	6900.00
0005434504810	22913	Economy	6900.00
0005435078613	2190	Economy	7700.00
0005435078605	2190	Economy	7700.00
0005435078616	2190	Economy	7700.00
0005435078610	2190	Economy	7000.00
0005433266789	2190	Economy	7000.00
0005435078612	2190	Economy	7000.00
0005435078617	2190	Economy	7000.00
0005433266822	2190	Economy	7000.00
0005435078608	2190	Economy	7000.00
0005433266821	2190	Economy	7000.00
0005435078620	2190	Economy	7000.00
0005435078611	2190	Economy	7000.00
0005433266823	2190	Economy	7000.00
0005433266790	2190	Economy	7000.00
0005433266820	2190	Economy	7000.00
0005435078614	2190	Economy	7000.00
0005433266825	2190	Economy	7000.00
0005435078615	2190	Economy	7000.00
0005433266808	2190	Economy	7000.00
0005433266807	2190	Economy	7000.00
0005435078609	2190	Economy	7000.00
0005433266774	2190	Economy	7000.00
0005435078618	2190	Economy	7000.00
0005435078607	2190	Economy	7000.00
0005435078619	2190	Economy	7000.00
0005433266826	2190	Economy	7000.00
0005433266788	2190	Economy	7000.00
0005435078606	2190	Economy	7000.00
0005435078524	24378	Economy	7700.00
0005433266883	24378	Economy	7000.00
0005433266888	24378	Economy	7000.00
0005435078504	24378	Economy	7000.00
0005433266890	24378	Economy	7000.00
0005435078479	24378	Economy	7000.00
0005433266887	24378	Economy	7000.00
0005435078482	24378	Economy	7000.00
0005435078522	24378	Economy	7000.00
0005435078403	24378	Economy	7000.00
0005435078442	24378	Economy	7000.00
0005433266884	24378	Economy	7000.00
0005435078477	24378	Economy	7000.00
0005435078478	24378	Economy	7000.00
0005435078495	24378	Economy	7000.00
0005433266889	24378	Economy	7000.00
0005435078523	24378	Economy	7000.00
0005433266891	24378	Economy	7000.00
0005435078415	24378	Economy	7000.00
0005433266882	24378	Economy	7000.00
0005435078525	24378	Economy	7000.00
0005433266886	24378	Economy	7000.00
0005435078404	24378	Economy	7000.00
0005435078483	24378	Economy	7000.00
0005433266885	24378	Economy	7000.00
0005435078414	24378	Economy	7000.00
0005434988921	6657	Economy	10800.00
0005434988923	6657	Economy	9800.00
0005434988922	6657	Economy	9800.00
0005435803312	6657	Economy	9800.00
0005434988924	6657	Economy	9800.00
0005435464525	6657	Economy	9800.00
0005435803314	6657	Economy	9800.00
0005435803311	6657	Economy	9800.00
0005435803313	6657	Economy	9800.00
0005435464524	6657	Economy	9800.00
0005434988792	23634	Economy	10800.00
0005434988791	23634	Economy	9800.00
0005434988812	23634	Economy	9800.00
0005434988788	23634	Economy	9800.00
0005435803296	23634	Economy	9800.00
0005434988813	23634	Economy	9800.00
0005434988815	23634	Economy	9800.00
0005434988811	23634	Economy	9800.00
0005435464542	23634	Economy	9800.00
0005434988810	23634	Economy	9800.00
0005435803284	23634	Economy	9800.00
0005435464543	23634	Economy	9800.00
0005433450350	30469	Business	9900.00
0005432383869	30469	Business	9900.00
0005432383846	30469	Business	9900.00
0005432383872	30469	Business	9900.00
0005433450362	30469	Business	9900.00
0005433450358	30469	Business	9900.00
0005433450343	30469	Business	9900.00
0005432383853	30469	Business	9900.00
0005432383868	30469	Business	9900.00
0005432383841	30469	Business	9900.00
0005433450345	30469	Business	9900.00
0005432383874	30469	Economy	3300.00
0005432383847	30469	Economy	3300.00
0005432383860	30469	Economy	3300.00
0005433450353	30469	Economy	3300.00
0005432383864	30469	Economy	3300.00
0005432383833	30469	Economy	3300.00
0005433450355	30469	Economy	3300.00
0005432383856	30469	Economy	3600.00
0005432383844	30469	Economy	3600.00
0005433454912	30469	Economy	3300.00
0005432383862	30469	Economy	3300.00
0005433450349	30469	Economy	3300.00
0005432383843	30469	Economy	3300.00
0005432383840	30469	Economy	3300.00
0005432383871	30469	Economy	3300.00
0005432383866	30469	Economy	3300.00
0005432383863	30469	Economy	3300.00
0005432383837	30469	Economy	3300.00
0005432383859	30469	Economy	3300.00
0005432383873	30469	Economy	3300.00
0005433450357	30469	Economy	3300.00
0005432383851	30469	Economy	3300.00
0005432383838	30469	Economy	3300.00
0005432383854	30469	Economy	3300.00
0005432383848	30469	Economy	3300.00
0005433450359	30469	Economy	3300.00
0005432383836	30469	Economy	3300.00
0005433450347	30469	Economy	3300.00
0005432383870	30469	Economy	3300.00
0005433453796	30469	Economy	3300.00
0005432383849	30469	Economy	3300.00
0005433450354	30469	Economy	3300.00
0005432383857	30469	Economy	3300.00
0005433450346	30469	Economy	3300.00
0005432383855	30469	Economy	3300.00
0005432383832	30469	Economy	3300.00
0005432383834	30469	Economy	3300.00
0005433450360	30469	Economy	3300.00
0005433450351	30469	Economy	3300.00
0005432383839	30469	Economy	3300.00
0005432383867	30469	Economy	3300.00
0005433450361	30469	Economy	3300.00
0005433450356	30469	Economy	3300.00
0005433450348	30469	Economy	3300.00
0005432383842	30469	Economy	3300.00
0005432383861	30469	Economy	3300.00
0005432383852	30469	Economy	3300.00
0005433450344	30469	Economy	3300.00
0005432383845	30469	Economy	3300.00
0005433454914	30469	Economy	3300.00
0005432383865	30469	Economy	3300.00
0005433454913	30469	Economy	3300.00
0005432383835	30469	Economy	3300.00
0005433450352	30469	Economy	3300.00
0005432383850	30469	Economy	3300.00
0005432383858	30469	Economy	3300.00
0005432383478	31330	Business	9900.00
0005432383451	31330	Business	9900.00
0005432383435	31330	Business	9900.00
0005432383422	31330	Business	9900.00
0005432383498	31330	Business	9900.00
0005433450169	31330	Business	9900.00
0005432383546	31330	Business	9900.00
0005433450159	31330	Business	9900.00
0005432383353	31330	Business	9900.00
0005432383526	31330	Business	9900.00
0005433450200	31330	Economy	3300.00
0005432383460	31330	Economy	3300.00
0005432383386	31330	Economy	3300.00
0005432383423	31330	Economy	3300.00
0005432383388	31330	Economy	3300.00
0005433450060	31330	Economy	3300.00
0005432383361	31330	Economy	3300.00
0005432383325	31330	Economy	3600.00
0005433450179	31330	Economy	3600.00
0005433450150	31330	Economy	3600.00
0005432383496	31330	Economy	3600.00
0005432383424	31330	Economy	3300.00
0005432383484	31330	Economy	3300.00
0005433450175	31330	Economy	3300.00
0005432383385	31330	Economy	3300.00
0005433450130	31330	Economy	3300.00
0005432383357	31330	Economy	3300.00
0005432383487	31330	Economy	3300.00
0005433450151	31330	Economy	3300.00
0005433450227	31330	Economy	3300.00
0005432383298	31330	Economy	3300.00
0005433450180	31330	Economy	3300.00
0005433450172	31330	Economy	3300.00
0005432383330	31330	Economy	3300.00
0005433450261	31330	Economy	3300.00
0005432383396	31330	Economy	3300.00
0005433450181	31330	Economy	3300.00
0005433450201	31330	Economy	3300.00
0005432383324	31330	Economy	3300.00
0005433450262	31330	Economy	3300.00
0005432383485	31330	Economy	3300.00
0005433450183	31330	Economy	3300.00
0005433450202	31330	Economy	3300.00
0005433450152	31330	Economy	3300.00
0005432383362	31330	Economy	3300.00
0005433450226	31330	Economy	3300.00
0005432383384	31330	Economy	3300.00
0005432383503	31330	Economy	3300.00
0005432383490	31330	Economy	3300.00
0005432383477	31330	Economy	3300.00
0005432383489	31330	Economy	3300.00
0005433450240	31330	Economy	3300.00
0005433450170	31330	Economy	3300.00
0005433450184	31330	Economy	3300.00
0005432383433	31330	Economy	3300.00
0005433450213	31330	Economy	3300.00
0005433450165	31330	Economy	3300.00
0005433450101	31330	Economy	3300.00
0005432383377	31330	Economy	3300.00
0005432383395	31330	Economy	3300.00
0005433450214	31330	Economy	3300.00
0005433450163	31330	Economy	3300.00
0005432383438	31330	Economy	3300.00
0005432383417	31330	Economy	3300.00
0005432383392	31330	Economy	3300.00
0005432383284	31330	Economy	3300.00
0005432383393	31330	Economy	3300.00
0005433450164	31330	Economy	3300.00
0005432383509	31330	Economy	3300.00
0005432383434	31330	Economy	3300.00
0005432383497	31330	Economy	3300.00
0005432383387	31330	Economy	3300.00
0005432383418	31330	Economy	3300.00
0005432383285	31330	Economy	3300.00
0005433450099	31330	Economy	3300.00
0005432383545	31330	Economy	3300.00
0005433450189	31330	Economy	3300.00
0005432383358	31330	Economy	3300.00
0005433450156	31330	Economy	3300.00
0005432383510	31330	Economy	3300.00
0005433450225	31330	Economy	3300.00
0005433788220	26471	Economy	23800.00
0005433788226	26471	Economy	23800.00
0005435548579	26471	Economy	23800.00
0005433788227	26471	Economy	23800.00
0005433788219	26471	Economy	23800.00
0005433788243	26471	Economy	23800.00
0005435548571	26471	Economy	23800.00
0005433788221	26471	Economy	23800.00
0005435548574	26471	Economy	23800.00
0005435548578	26471	Economy	23800.00
0005435548573	26471	Economy	23800.00
0005433788224	26471	Economy	23800.00
0005435548576	26471	Economy	23800.00
0005435548577	26471	Economy	23800.00
0005435548575	26471	Economy	23800.00
0005433788218	26471	Economy	23800.00
0005435548572	26471	Economy	23800.00
0005433788240	26471	Economy	23800.00
0005433788244	26471	Economy	23800.00
0005435304196	10766	Economy	17100.00
0005435304205	10766	Economy	17100.00
0005435299826	10766	Economy	17100.00
0005435304202	10766	Economy	15600.00
0005433131719	10766	Economy	15600.00
0005435304203	10766	Economy	15600.00
0005435299832	10766	Economy	15600.00
0005435304188	10766	Economy	15600.00
0005435299833	10766	Economy	15600.00
0005433131751	10766	Economy	15600.00
0005435304201	10766	Economy	15600.00
0005435299809	10766	Economy	15600.00
0005433131743	10766	Economy	15600.00
0005433131741	10766	Economy	15600.00
0005433131740	10766	Economy	15600.00
0005435304197	10766	Economy	15600.00
0005435304200	10766	Economy	15600.00
0005433131742	10766	Economy	15600.00
0005433131717	10766	Economy	15600.00
0005433126880	10766	Economy	15600.00
0005433126881	10766	Economy	15600.00
0005435299822	10766	Economy	15600.00
0005435304189	10766	Economy	15600.00
0005433131718	10766	Economy	15600.00
0005435304204	10766	Economy	15600.00
0005435299810	10766	Economy	15600.00
0005433126873	10766	Economy	15600.00
0005435299865	29730	Economy	17100.00
0005433126930	29730	Economy	17100.00
0005435302287	29730	Economy	15600.00
0005435302286	29730	Economy	15600.00
0005435302284	29730	Economy	15600.00
0005433129359	29730	Economy	15600.00
0005435302283	29730	Economy	15600.00
0005435299862	29730	Economy	15600.00
0005435302285	29730	Economy	15600.00
0005433129361	29730	Economy	15600.00
0005433126927	29730	Economy	15600.00
0005433126928	29730	Economy	15600.00
0005433126929	29730	Economy	15600.00
0005433129360	29730	Economy	15600.00
0005433129358	29730	Economy	15600.00
0005435299864	29730	Economy	15600.00
0005435299866	29730	Economy	15600.00
0005435299863	29730	Economy	15600.00
0005434287686	2392	Economy	17200.00
0005434287669	2392	Economy	17200.00
0005433110123	2392	Economy	15700.00
0005432264518	2392	Economy	15700.00
0005434287668	2392	Economy	15700.00
0005434287688	2392	Economy	15700.00
0005433110146	2392	Economy	15700.00
0005433110187	2392	Economy	15700.00
0005434287678	2392	Economy	15700.00
0005432264519	2392	Economy	15700.00
0005434287672	2392	Economy	15700.00
0005433110188	2392	Economy	15700.00
0005434287681	2392	Economy	15700.00
0005434287670	2392	Economy	15700.00
0005434287680	2392	Economy	15700.00
0005434287673	2392	Economy	15700.00
0005434287683	2392	Economy	15700.00
0005434287667	2392	Economy	15700.00
0005434287677	2392	Economy	15700.00
0005433110171	2392	Economy	15700.00
0005434287671	2392	Economy	15700.00
0005434287674	2392	Economy	15700.00
0005433110172	2392	Economy	15700.00
0005434287687	2392	Economy	15700.00
0005433110173	2392	Economy	15700.00
0005434287679	2392	Economy	15700.00
0005433110182	2392	Economy	15700.00
0005434287676	2392	Economy	15700.00
0005434287666	2392	Economy	15700.00
0005434287684	2392	Economy	15700.00
0005434287682	2392	Economy	15700.00
0005434287685	2392	Economy	15700.00
0005433110183	2392	Economy	15700.00
0005434287675	2392	Economy	15700.00
0005432264517	2392	Economy	15700.00
0005433110159	2392	Economy	15700.00
0005434287506	26848	Economy	17200.00
0005434287571	26848	Economy	15700.00
0005434287429	26848	Economy	15700.00
0005434287507	26848	Economy	15700.00
0005434287574	26848	Economy	15700.00
0005433110264	26848	Economy	15700.00
0005434287464	26848	Economy	15700.00
0005433110267	26848	Economy	15700.00
0005434287405	26848	Economy	15700.00
0005433110262	26848	Economy	15700.00
0005434287436	26848	Economy	15700.00
0005433110265	26848	Economy	15700.00
0005434287474	26848	Economy	15700.00
0005434287489	26848	Economy	15700.00
0005434287575	26848	Economy	15700.00
0005434287488	26848	Economy	15700.00
0005433110263	26848	Economy	15700.00
0005433110268	26848	Economy	15700.00
0005434287414	26848	Economy	15700.00
0005434287572	26848	Economy	15700.00
0005433110270	26848	Economy	15700.00
0005433110261	26848	Economy	15700.00
0005433110266	26848	Economy	15700.00
0005433110260	26848	Economy	15700.00
0005433110259	26848	Economy	15700.00
0005433110269	26848	Economy	15700.00
0005434272199	25459	Economy	22800.00
0005435856279	25459	Economy	22800.00
0005435856277	25459	Economy	22800.00
0005435856276	25459	Economy	22800.00
0005434272201	25459	Economy	22800.00
0005435856280	25459	Economy	22800.00
0005434269111	25459	Economy	22800.00
0005435856278	25459	Economy	22800.00
0005434269112	25459	Economy	22800.00
0005434269113	25459	Economy	22800.00
0005435314843	6096	Economy	24600.00
0005434520397	6096	Economy	24600.00
0005434520390	6096	Economy	24600.00
0005434520403	6096	Economy	24600.00
0005434520406	6096	Economy	22300.00
0005435314869	6096	Economy	22300.00
0005435314848	6096	Economy	22300.00
0005434520391	6096	Economy	22300.00
0005435314864	6096	Economy	22300.00
0005435314865	6096	Economy	22300.00
0005434520393	6096	Economy	22300.00
0005435314866	6096	Economy	22300.00
0005434520410	6096	Economy	22300.00
0005434520413	6096	Economy	22300.00
0005435314853	6096	Economy	22300.00
0005434520415	6096	Economy	22300.00
0005434520412	6096	Economy	22300.00
0005435314870	6096	Economy	22300.00
0005434520404	6096	Economy	22300.00
0005435314863	6096	Economy	22300.00
0005434520399	6096	Economy	22300.00
0005435314847	6096	Economy	22300.00
0005434520394	6096	Economy	22300.00
0005434520414	6096	Economy	22300.00
0005434520401	6096	Economy	22300.00
0005435314868	6096	Economy	22300.00
0005434520409	6096	Economy	22300.00
0005434520422	6096	Economy	22300.00
0005434520418	6096	Economy	22300.00
0005434520407	6096	Economy	22300.00
0005435314872	6096	Economy	22300.00
0005434520417	6096	Economy	22300.00
0005435314871	6096	Economy	22300.00
0005434520421	6096	Economy	22300.00
0005434520408	6096	Economy	22300.00
0005434520411	6096	Economy	22300.00
0005435314852	6096	Economy	22300.00
0005434520405	6096	Economy	22300.00
0005434520389	6096	Economy	22300.00
0005434520419	6096	Economy	22300.00
0005434520392	6096	Economy	22300.00
0005434520402	6096	Economy	22300.00
0005434520420	6096	Economy	22300.00
0005434520400	6096	Economy	22300.00
0005434520395	6096	Economy	22300.00
0005435314859	6096	Economy	22300.00
0005434520396	6096	Economy	22300.00
0005434520416	6096	Economy	22300.00
0005434520398	6096	Economy	22300.00
0005433650705	27621	Business	89800.00
0005433650691	27621	Business	89800.00
0005433650791	27621	Business	89800.00
0005433650713	27621	Business	89800.00
0005433650740	27621	Business	89800.00
0005433650742	27621	Business	89800.00
0005433650711	27621	Business	89800.00
0005433650785	27621	Business	89800.00
0005435263735	27621	Business	89800.00
0005433650695	27621	Business	89800.00
0005435263752	27621	Business	89800.00
0005433650784	27621	Economy	29900.00
0005433650770	27621	Economy	29900.00
0005435263726	27621	Economy	29900.00
0005433650659	27621	Economy	29900.00
0005433650763	27621	Economy	29900.00
0005433650700	27621	Economy	29900.00
0005433650701	27621	Economy	29900.00
0005435263729	27621	Economy	29900.00
0005433650758	27621	Economy	29900.00
0005435263737	27621	Economy	29900.00
0005435263753	27621	Economy	32900.00
0005435263727	27621	Economy	32900.00
0005435263746	27621	Economy	32900.00
0005435263734	27621	Economy	32900.00
0005433650709	27621	Economy	32900.00
0005433650741	27621	Economy	29900.00
0005435263749	27621	Economy	29900.00
0005435263725	27621	Economy	29900.00
0005433650734	27621	Economy	29900.00
0005435263743	27621	Economy	29900.00
0005433650782	27621	Economy	29900.00
0005433650732	27621	Economy	29900.00
0005433650685	27621	Economy	29900.00
0005433650778	27621	Economy	29900.00
0005433650733	27621	Economy	29900.00
0005433650838	27621	Economy	29900.00
0005433650762	27621	Economy	29900.00
0005433650767	27621	Economy	29900.00
0005433650777	27621	Economy	29900.00
0005433650771	27621	Economy	29900.00
0005435263739	27621	Economy	29900.00
0005433650723	27621	Economy	29900.00
0005435263732	27621	Economy	29900.00
0005433650768	27621	Economy	29900.00
0005435263733	27621	Economy	29900.00
0005433650719	27621	Economy	29900.00
0005433650696	27621	Economy	29900.00
0005433650686	27621	Economy	29900.00
0005433650677	27621	Economy	29900.00
0005433650744	27621	Economy	29900.00
0005435263744	27621	Economy	29900.00
0005435263724	27621	Economy	29900.00
0005433650860	27621	Economy	29900.00
0005433650837	27621	Economy	29900.00
0005433650706	27621	Economy	29900.00
0005435263741	27621	Economy	29900.00
0005435263730	27621	Economy	29900.00
0005435263736	27621	Economy	29900.00
0005435263745	27621	Economy	29900.00
0005433650690	27621	Economy	29900.00
0005433650749	27621	Economy	29900.00
0005435263747	27621	Economy	29900.00
0005433650788	27621	Economy	29900.00
0005433650769	27621	Economy	29900.00
0005433650783	27621	Economy	29900.00
0005433650738	27621	Economy	29900.00
0005433650735	27621	Economy	29900.00
0005435263748	27621	Economy	29900.00
0005435263738	27621	Economy	29900.00
0005433650710	27621	Economy	29900.00
0005433650715	27621	Economy	29900.00
0005435263751	27621	Economy	29900.00
0005433650772	27621	Economy	29900.00
0005433650728	27621	Economy	29900.00
0005433650714	27621	Economy	29900.00
0005433650797	27621	Economy	29900.00
0005433650656	27621	Economy	29900.00
0005435263742	27621	Economy	29900.00
0005435263731	27621	Economy	29900.00
0005433650745	27621	Economy	29900.00
0005433650737	27621	Economy	29900.00
0005433650720	27621	Economy	29900.00
0005433650755	27621	Economy	29900.00
0005433650660	27621	Economy	29900.00
0005433650799	27621	Economy	29900.00
0005433650765	27621	Economy	29900.00
0005435263728	27621	Economy	29900.00
0005433650786	27621	Economy	29900.00
0005433650743	27621	Economy	29900.00
0005435263740	27621	Economy	29900.00
0005433650721	27621	Economy	29900.00
0005435263750	27621	Economy	29900.00
0005433650722	27621	Economy	29900.00
0005433650716	27621	Economy	29900.00
0005433650764	27621	Economy	29900.00
0005433869148	4756	Economy	19400.00
0005433869151	4756	Economy	19400.00
0005433869122	4756	Economy	19400.00
0005433869157	4756	Economy	19400.00
0005433869135	4756	Economy	17600.00
0005433869141	4756	Economy	17600.00
0005433869133	4756	Economy	17600.00
0005433869126	4756	Economy	17600.00
0005433869124	4756	Economy	17600.00
0005433869127	4756	Economy	17600.00
0005433869129	4756	Economy	17600.00
0005433869132	4756	Economy	17600.00
0005433869144	4756	Economy	17600.00
0005435860513	4756	Economy	17600.00
0005433869142	4756	Economy	17600.00
0005433869128	4756	Economy	17600.00
0005433869147	4756	Economy	17600.00
0005433869136	4756	Economy	17600.00
0005433869134	4756	Economy	17600.00
0005433869140	4756	Economy	17600.00
0005433869146	4756	Economy	17600.00
0005435860506	4756	Economy	17600.00
0005433869131	4756	Economy	17600.00
0005433869143	4756	Economy	17600.00
0005433869139	4756	Economy	17600.00
0005433869145	4756	Economy	17600.00
0005435860510	4756	Economy	17600.00
0005433869137	4756	Economy	17600.00
0005433869155	4756	Economy	17600.00
0005433869152	4756	Economy	17600.00
0005433869125	4756	Economy	17600.00
0005433869158	4756	Economy	17600.00
0005433869153	4756	Economy	17600.00
0005433869159	4756	Economy	17600.00
0005433869121	4756	Economy	17600.00
0005433869149	4756	Economy	17600.00
0005433869150	4756	Economy	17600.00
0005433869156	4756	Economy	17600.00
0005433869123	4756	Economy	17600.00
0005433869138	4756	Economy	17600.00
0005433869130	4756	Economy	17600.00
0005433869154	4756	Economy	17600.00
0005433868847	32619	Economy	19400.00
0005433868781	32619	Economy	19400.00
0005433868896	32619	Economy	19400.00
0005433868624	32619	Economy	19400.00
0005433868779	32619	Economy	17600.00
0005433868597	32619	Economy	17600.00
0005433868928	32619	Economy	17600.00
0005435860552	32619	Economy	17600.00
0005433868815	32619	Economy	17600.00
0005433868768	32619	Economy	17600.00
0005435860553	32619	Economy	17600.00
0005433868929	32619	Economy	17600.00
0005433868688	32619	Economy	17600.00
0005435860559	32619	Economy	17600.00
0005433868746	32619	Economy	17600.00
0005435860554	32619	Economy	17600.00
0005433868763	32619	Economy	17600.00
0005435860558	32619	Economy	17600.00
0005433868625	32619	Economy	17600.00
0005433868757	32619	Economy	17600.00
0005435860557	32619	Economy	17600.00
0005433868752	32619	Economy	17600.00
0005433868745	32619	Economy	17600.00
0005433868724	32619	Economy	17600.00
0005433868844	32619	Economy	17600.00
0005433868814	32619	Economy	17600.00
0005433868771	32619	Economy	17600.00
0005433868835	32619	Economy	17600.00
0005435860556	32619	Economy	17600.00
0005433868726	32619	Economy	17600.00
0005433868756	32619	Economy	17600.00
0005433868845	32619	Economy	17600.00
0005435860555	32619	Economy	17600.00
0005433868689	32619	Economy	17600.00
0005433868649	32619	Economy	17600.00
0005435860551	32619	Economy	17600.00
0005433868877	32619	Economy	17600.00
0005433868725	32619	Economy	17600.00
0005433868767	32619	Economy	17600.00
0005433868899	32619	Economy	17600.00
0005433868792	32619	Economy	17600.00
0005433868902	32619	Economy	17600.00
0005433868778	32619	Economy	17600.00
0005435911546	3428	Economy	22600.00
0005434663639	3428	Economy	22600.00
0005434663647	3428	Economy	22600.00
0005434663640	3428	Economy	22600.00
0005434460544	3428	Economy	22600.00
0005435911519	3428	Economy	22600.00
0005434663653	3428	Economy	22600.00
0005434663650	3428	Economy	22600.00
0005434461686	3428	Economy	22600.00
0005434663643	3428	Economy	22600.00
0005434663645	3428	Economy	22600.00
0005435911534	3428	Economy	22600.00
0005434663649	3428	Economy	22600.00
0005434663644	3428	Economy	22600.00
0005435911532	3428	Economy	22600.00
0005434461684	3428	Economy	22600.00
0005434460542	3428	Economy	22600.00
0005434663642	3428	Economy	22600.00
0005434461685	3428	Economy	22600.00
0005434663646	3428	Economy	22600.00
0005434663652	3428	Economy	22600.00
0005435911518	3428	Economy	22600.00
0005434460543	3428	Economy	22600.00
0005434663641	3428	Economy	22600.00
0005435911548	3428	Economy	22600.00
0005434663651	3428	Economy	22600.00
0005434663648	3428	Economy	22600.00
0005435911517	3428	Economy	22600.00
0005435911585	12442	Economy	24800.00
0005434663541	12442	Economy	24800.00
0005434663485	12442	Economy	24800.00
0005434663521	12442	Economy	22600.00
0005434663503	12442	Economy	22600.00
0005434663497	12442	Economy	22600.00
0005435911584	12442	Economy	22600.00
0005435911583	12442	Economy	22600.00
0005435911589	12442	Economy	22600.00
0005435911582	12442	Economy	22600.00
0005434663498	12442	Economy	22600.00
0005434663542	12442	Economy	22600.00
0005434663505	12442	Economy	22600.00
0005434663504	12442	Economy	22600.00
0005435911586	12442	Economy	22600.00
0005435911587	12442	Economy	22600.00
0005434663527	12442	Economy	22600.00
0005434663496	12442	Economy	22600.00
0005435911588	12442	Economy	22600.00
0005434663549	12442	Economy	22600.00
0005434663484	12442	Economy	22600.00
0005434663532	12442	Economy	22600.00
0005433868688	14526	Economy	18500.00
0005433868778	14526	Economy	18500.00
0005433868902	14526	Economy	18500.00
0005433868815	14526	Economy	18500.00
0005433868768	14526	Economy	16800.00
0005433868689	14526	Economy	16800.00
0005433868725	14526	Economy	16800.00
0005433868929	14526	Economy	16800.00
0005433868745	14526	Economy	16800.00
0005435860559	14526	Economy	16800.00
0005433868624	14526	Economy	16800.00
0005433868781	14526	Economy	16800.00
0005435860551	14526	Economy	16800.00
0005435860553	14526	Economy	16800.00
0005435860558	14526	Economy	16800.00
0005433868597	14526	Economy	16800.00
0005435860554	14526	Economy	16800.00
0005433868928	14526	Economy	16800.00
0005433868847	14526	Economy	16800.00
0005433868844	14526	Economy	16800.00
0005433868746	14526	Economy	16800.00
0005433868752	14526	Economy	16800.00
0005435860556	14526	Economy	16800.00
0005433868757	14526	Economy	16800.00
0005433868726	14526	Economy	16800.00
0005435860555	14526	Economy	16800.00
0005433868724	14526	Economy	16800.00
0005433868896	14526	Economy	16800.00
0005433868625	14526	Economy	16800.00
0005433868779	14526	Economy	16800.00
0005433868845	14526	Economy	16800.00
0005433868763	14526	Economy	16800.00
0005433868899	14526	Economy	16800.00
0005433868756	14526	Economy	16800.00
0005433868814	14526	Economy	16800.00
0005433868767	14526	Economy	16800.00
0005433868792	14526	Economy	16800.00
0005435860552	14526	Economy	16800.00
0005433868877	14526	Economy	16800.00
0005433868771	14526	Economy	16800.00
0005433868649	14526	Economy	16800.00
0005433868835	14526	Economy	16800.00
0005435860557	14526	Economy	16800.00
0005433869084	32658	Economy	18500.00
0005433869097	32658	Economy	18500.00
0005433869095	32658	Economy	18500.00
0005435860509	32658	Economy	18500.00
0005433869080	32658	Economy	16800.00
0005433869120	32658	Economy	16800.00
0005433869098	32658	Economy	16800.00
0005433869114	32658	Economy	16800.00
0005435860505	32658	Economy	16800.00
0005433869082	32658	Economy	16800.00
0005435860504	32658	Economy	16800.00
0005433869113	32658	Economy	16800.00
0005433869115	32658	Economy	16800.00
0005433869107	32658	Economy	16800.00
0005433869119	32658	Economy	16800.00
0005433869116	32658	Economy	16800.00
0005433869093	32658	Economy	16800.00
0005433869108	32658	Economy	16800.00
0005433869081	32658	Economy	16800.00
0005433869085	32658	Economy	16800.00
0005433869111	32658	Economy	16800.00
0005433869118	32658	Economy	16800.00
0005433869117	32658	Economy	16800.00
0005433869100	32658	Economy	16800.00
0005433869087	32658	Economy	16800.00
0005433869099	32658	Economy	16800.00
0005433869110	32658	Economy	16800.00
0005433869086	32658	Economy	16800.00
0005433869101	32658	Economy	16800.00
0005433869103	32658	Economy	16800.00
0005433869088	32658	Economy	16800.00
0005433869092	32658	Economy	16800.00
0005433869109	32658	Economy	16800.00
0005433869105	32658	Economy	16800.00
0005433869083	32658	Economy	16800.00
0005433869079	32658	Economy	16800.00
0005433869091	32658	Economy	16800.00
0005433869090	32658	Economy	16800.00
0005433869104	32658	Economy	16800.00
0005433869096	32658	Economy	16800.00
0005433869106	32658	Economy	16800.00
0005433869094	32658	Economy	16800.00
0005433869112	32658	Economy	16800.00
0005433869089	32658	Economy	16800.00
0005433869102	32658	Economy	16800.00
0005432799732	12142	Economy	4900.00
0005432799761	12142	Economy	4900.00
0005432799693	12142	Economy	4900.00
0005432799640	12142	Economy	4900.00
0005432799790	12142	Economy	4400.00
0005432799685	12142	Economy	4400.00
0005432799791	12142	Economy	4400.00
0005432799724	12142	Economy	4400.00
0005432799677	12142	Economy	4400.00
0005432799635	12142	Economy	4400.00
0005432799707	12142	Economy	4400.00
0005432799795	12142	Economy	4400.00
0005432799760	12142	Economy	4400.00
0005432799768	12142	Economy	4400.00
0005432799777	12142	Economy	4400.00
0005432799756	12142	Economy	4400.00
0005432799755	12142	Economy	4400.00
0005432799733	12142	Economy	4400.00
0005432799627	12142	Economy	4400.00
0005432799653	12142	Economy	4400.00
0005432799776	12142	Economy	4400.00
0005432799647	12142	Economy	4400.00
0005432799769	12142	Economy	4400.00
0005432799709	12142	Economy	4400.00
0005432799711	12142	Economy	4400.00
0005432799717	12142	Economy	4400.00
0005432799754	12142	Economy	4400.00
0005432799609	12142	Economy	4400.00
0005432799753	12142	Economy	4400.00
0005432799708	12142	Economy	4400.00
0005432799779	12142	Economy	4400.00
0005432799770	12142	Economy	4400.00
0005432799771	12142	Economy	4400.00
0005432799727	12142	Economy	4400.00
0005432799796	12142	Economy	4400.00
0005432799686	12142	Economy	4400.00
0005432799626	12142	Economy	4400.00
0005432799608	12142	Economy	4400.00
0005432799757	12142	Economy	4400.00
0005432799931	14782	Economy	4900.00
0005432799919	14782	Economy	4900.00
0005432799935	14782	Economy	4400.00
0005432799911	14782	Economy	4400.00
0005432799909	14782	Economy	4400.00
0005432799924	14782	Economy	4400.00
0005432799921	14782	Economy	4400.00
0005432799913	14782	Economy	4400.00
0005432799936	14782	Economy	4400.00
0005432799933	14782	Economy	4400.00
0005432799926	14782	Economy	4400.00
0005432799928	14782	Economy	4400.00
0005432799932	14782	Economy	4400.00
0005432799910	14782	Economy	4400.00
0005432799923	14782	Economy	4400.00
0005432799915	14782	Economy	4400.00
0005432799914	14782	Economy	4400.00
0005432799917	14782	Economy	4400.00
0005432799918	14782	Economy	4400.00
0005432799912	14782	Economy	4400.00
0005432799934	14782	Economy	4400.00
0005432799908	14782	Economy	4400.00
0005432799925	14782	Economy	4400.00
0005432799930	14782	Economy	4400.00
0005432799920	14782	Economy	4400.00
0005432799929	14782	Economy	4400.00
0005432799916	14782	Economy	4400.00
0005432799922	14782	Economy	4400.00
0005432799927	14782	Economy	4400.00
0005434408868	7088	Business	49100.00
0005435293426	7088	Business	49100.00
0005434408846	7088	Business	49100.00
0005434408851	7088	Business	49100.00
0005432108295	7088	Business	49100.00
0005435311130	7088	Business	49100.00
0005434408845	7088	Business	49100.00
0005434408858	7088	Business	49100.00
0005434299976	7088	Business	49100.00
0005434408841	7088	Business	49100.00
0005434408840	7088	Business	49100.00
0005435311122	7088	Business	49100.00
0005434299959	7088	Economy	16400.00
0005434408878	7088	Economy	16400.00
0005434299967	7088	Economy	16400.00
0005434408869	7088	Economy	16400.00
0005434408861	7088	Economy	16400.00
0005434408836	7088	Economy	16400.00
0005434299972	7088	Economy	16400.00
0005434408879	7088	Economy	16400.00
0005434408883	7088	Economy	16400.00
0005434408896	7088	Economy	16400.00
0005435293395	7088	Economy	16400.00
0005434299966	7088	Economy	16400.00
0005432154063	7088	Economy	16400.00
0005435311126	7088	Economy	16400.00
0005434408855	7088	Economy	16400.00
0005434408842	7088	Economy	16400.00
0005434408843	7088	Economy	16400.00
0005434408887	7088	Economy	16400.00
0005434408881	7088	Economy	16400.00
0005434408886	7088	Economy	16400.00
0005434408885	7088	Economy	16400.00
0005435311147	7088	Economy	16400.00
0005434408874	7088	Economy	16400.00
0005434408891	7088	Economy	16400.00
0005434299970	7088	Economy	16400.00
0005435311149	7088	Economy	16400.00
0005434299963	7088	Economy	16400.00
0005434408837	7088	Economy	16400.00
0005434408859	7088	Economy	16400.00
0005432108296	7088	Economy	16400.00
0005434408856	7088	Economy	16400.00
0005435293316	7088	Economy	16400.00
0005434408857	7088	Economy	16400.00
0005435293394	7088	Economy	16400.00
0005434408892	7088	Economy	16400.00
0005434408882	7088	Economy	16400.00
0005435293388	7088	Economy	16400.00
0005434408867	7088	Economy	16400.00
0005434408880	7088	Economy	18000.00
0005435293309	7088	Economy	18000.00
0005435293364	7088	Economy	18000.00
0005434408893	7088	Economy	18000.00
0005434408849	7088	Economy	18000.00
0005434408852	7088	Economy	18000.00
0005434408862	7088	Economy	16400.00
0005432154060	7088	Economy	16400.00
0005434408877	7088	Economy	16400.00
0005432154057	7088	Economy	16400.00
0005434299978	7088	Economy	16400.00
0005434408889	7088	Economy	16400.00
0005434299956	7088	Economy	16400.00
0005434408897	7088	Economy	16400.00
0005434408871	7088	Economy	16400.00
0005434299971	7088	Economy	16400.00
0005434408899	7088	Economy	16400.00
0005432154062	7088	Economy	16400.00
0005434408884	7088	Economy	16400.00
0005434299960	7088	Economy	16400.00
0005434408888	7088	Economy	16400.00
0005434408872	7088	Economy	16400.00
0005432154058	7088	Economy	16400.00
0005434408876	7088	Economy	16400.00
0005434408850	7088	Economy	16400.00
0005434299968	7088	Economy	16400.00
0005435311150	7088	Economy	16400.00
0005434408864	7088	Economy	16400.00
0005434408838	7088	Economy	16400.00
0005434299974	7088	Economy	16400.00
0005434299977	7088	Economy	16400.00
0005434408900	7088	Economy	16400.00
0005432154059	7088	Economy	16400.00
0005434408890	7088	Economy	16400.00
0005434408854	7088	Economy	16400.00
0005434408839	7088	Economy	16400.00
0005434299962	7088	Economy	16400.00
0005434408894	7088	Economy	16400.00
0005434299975	7088	Economy	16400.00
0005434299965	7088	Economy	16400.00
0005434299969	7088	Economy	16400.00
0005434408860	7088	Economy	16400.00
0005434408866	7088	Economy	16400.00
0005434299958	7088	Economy	16400.00
0005434408853	7088	Economy	16400.00
0005435293371	7088	Economy	16400.00
0005434408835	7088	Economy	16400.00
0005434408875	7088	Economy	16400.00
0005434408898	7088	Economy	16400.00
0005435293379	7088	Economy	16400.00
0005434408847	7088	Economy	16400.00
0005434408870	7088	Economy	16400.00
0005434299957	7088	Economy	16400.00
0005435293381	7088	Economy	16400.00
0005434408895	7088	Economy	16400.00
0005432154061	7088	Economy	16400.00
0005434408865	7088	Economy	16400.00
0005434299961	7088	Economy	16400.00
0005435311148	7088	Economy	16400.00
0005434299979	7088	Economy	16400.00
0005434408844	7088	Economy	16400.00
0005435311156	7088	Economy	16400.00
0005434408873	7088	Economy	16400.00
0005434299973	7088	Economy	16400.00
0005435293370	7088	Economy	16400.00
0005434299964	7088	Economy	16400.00
0005435311160	7088	Economy	16400.00
0005432154064	7088	Economy	16400.00
0005435293315	7088	Economy	16400.00
0005434408848	7088	Economy	16400.00
0005435311123	7088	Economy	16400.00
0005434408863	7088	Economy	16400.00
0005435311127	7088	Economy	16400.00
0005435293469	26938	Business	49100.00
0005434408219	26938	Business	49100.00
0005434408307	26938	Business	49100.00
0005434408349	26938	Business	49100.00
0005434408187	26938	Business	49100.00
0005434408504	26938	Business	49100.00
0005434408308	26938	Business	49100.00
0005434408402	26938	Business	49100.00
0005434407931	26938	Business	49100.00
0005434299723	26938	Business	49100.00
0005435293465	26938	Business	49100.00
0005434299746	26938	Business	49100.00
0005435293466	26938	Economy	16400.00
0005435293475	26938	Economy	16400.00
0005434408361	26938	Economy	16400.00
0005434408375	26938	Economy	16400.00
0005434408352	26938	Economy	16400.00
0005435293476	26938	Economy	16400.00
0005432058445	26938	Economy	16400.00
0005434408241	26938	Economy	16400.00
0005434408109	26938	Economy	16400.00
0005434408353	26938	Economy	16400.00
0005434299805	26938	Economy	16400.00
0005434408376	26938	Economy	16400.00
0005434408532	26938	Economy	16400.00
0005434299783	26938	Economy	16400.00
0005435311260	26938	Economy	16400.00
0005434408304	26938	Economy	16400.00
0005434299776	26938	Economy	16400.00
0005434408305	26938	Economy	16400.00
0005434299829	26938	Economy	16400.00
0005434408400	26938	Economy	16400.00
0005435293473	26938	Economy	16400.00
0005434408441	26938	Economy	16400.00
0005434299769	26938	Economy	16400.00
0005434408639	26938	Economy	16400.00
0005434408362	26938	Economy	16400.00
0005434299789	26938	Economy	16400.00
0005435293474	26938	Economy	16400.00
0005434299791	26938	Economy	16400.00
0005435293477	26938	Economy	16400.00
0005434407834	26938	Economy	16400.00
0005434408289	26938	Economy	16400.00
0005434299838	26938	Economy	16400.00
0005434408155	26938	Economy	16400.00
0005434408261	26938	Economy	16400.00
0005434299788	26938	Economy	16400.00
0005434408348	26938	Economy	16400.00
0005434299770	26938	Economy	16400.00
0005435311268	26938	Economy	16400.00
0005434408401	26938	Economy	18000.00
0005435311263	26938	Economy	18000.00
0005435311267	26938	Economy	18000.00
0005434408247	26938	Economy	18000.00
0005434408536	26938	Economy	18000.00
0005435293467	26938	Economy	16400.00
0005434408170	26938	Economy	16400.00
0005434299691	26938	Economy	16400.00
0005435293472	26938	Economy	16400.00
0005435311272	26938	Economy	16400.00
0005434408144	26938	Economy	16400.00
0005432058448	26938	Economy	16400.00
0005434408169	26938	Economy	16400.00
0005434408116	26938	Economy	16400.00
0005434408284	26938	Economy	16400.00
0005434408484	26938	Economy	16400.00
0005432058447	26938	Economy	16400.00
0005434408051	26938	Economy	16400.00
0005434408101	26938	Economy	16400.00
0005434408303	26938	Economy	16400.00
0005434408156	26938	Economy	16400.00
0005434299824	26938	Economy	16400.00
0005434299704	26938	Economy	16400.00
0005434299790	26938	Economy	16400.00
0005434407944	26938	Economy	16400.00
0005434408397	26938	Economy	16400.00
0005434408388	26938	Economy	16400.00
0005435311269	26938	Economy	16400.00
0005434408423	26938	Economy	16400.00
0005434408500	26938	Economy	16400.00
0005434408339	26938	Economy	16400.00
0005435311270	26938	Economy	16400.00
0005435311266	26938	Economy	16400.00
0005434408559	26938	Economy	16400.00
0005434408242	26938	Economy	16400.00
0005434408239	26938	Economy	16400.00
0005434408238	26938	Economy	16400.00
0005434408128	26938	Economy	16400.00
0005435311264	26938	Economy	16400.00
0005435311261	26938	Economy	16400.00
0005434408297	26938	Economy	16400.00
0005434408168	26938	Economy	16400.00
0005434408499	26938	Economy	16400.00
0005434408129	26938	Economy	16400.00
0005434408350	26938	Economy	16400.00
0005434408191	26938	Economy	16400.00
0005435311271	26938	Economy	16400.00
0005435311273	26938	Economy	16400.00
0005434408222	26938	Economy	16400.00
0005434408319	26938	Economy	16400.00
0005434408188	26938	Economy	16400.00
0005434408069	26938	Economy	16400.00
0005434408327	26938	Economy	16400.00
0005434408377	26938	Economy	16400.00
0005434408364	26938	Economy	16400.00
0005434407895	26938	Economy	16400.00
0005434299705	26938	Economy	16400.00
0005434299757	26938	Economy	16400.00
0005434407872	26938	Economy	16400.00
0005434408422	26938	Economy	16400.00
0005435311274	26938	Economy	16400.00
0005435293468	26938	Economy	16400.00
0005434299756	26938	Economy	16400.00
0005434299870	26938	Economy	16400.00
0005435293471	26938	Economy	16400.00
0005434299742	26938	Economy	16400.00
0005435311265	26938	Economy	16400.00
0005434408314	26938	Economy	16400.00
0005432058446	26938	Economy	16400.00
0005434299835	26938	Economy	16400.00
0005434408309	26938	Economy	16400.00
0005435311262	26938	Economy	16400.00
0005435293470	26938	Economy	16400.00
0005434408457	26938	Economy	16400.00
0005435218121	6430	Economy	16500.00
0005432605058	6430	Economy	16500.00
0005432605038	6430	Economy	16500.00
0005432605044	6430	Economy	16500.00
0005432605042	6430	Economy	15000.00
0005432605031	6430	Economy	15000.00
0005432605043	6430	Economy	15000.00
0005432605049	6430	Economy	15000.00
0005432605059	6430	Economy	15000.00
0005432605027	6430	Economy	15000.00
0005432605061	6430	Economy	15000.00
0005432605029	6430	Economy	15000.00
0005434512198	6430	Economy	15000.00
0005432605033	6430	Economy	15000.00
0005432605041	6430	Economy	15000.00
0005432605048	6430	Economy	15000.00
0005434512202	6430	Economy	15000.00
0005432605057	6430	Economy	15000.00
0005432605028	6430	Economy	15000.00
0005434512200	6430	Economy	15000.00
0005432605050	6430	Economy	15000.00
0005432605021	6430	Economy	15000.00
0005432605022	6430	Economy	15000.00
0005432605032	6430	Economy	15000.00
0005432605026	6430	Economy	15000.00
0005432605035	6430	Economy	15000.00
0005432605023	6430	Economy	15000.00
0005432605039	6430	Economy	15000.00
0005434512199	6430	Economy	15000.00
0005432605054	6430	Economy	15000.00
0005432605051	6430	Economy	15000.00
0005432605056	6430	Economy	15000.00
0005432605055	6430	Economy	15000.00
0005432605025	6430	Economy	15000.00
0005432605040	6430	Economy	15000.00
0005432605045	6430	Economy	15000.00
0005432605046	6430	Economy	15000.00
0005434512203	6430	Economy	15000.00
0005432605060	6430	Economy	15000.00
0005432605034	6430	Economy	15000.00
0005432605030	6430	Economy	15000.00
0005432605037	6430	Economy	15000.00
0005434512201	6430	Economy	15000.00
0005432605047	6430	Economy	15000.00
0005432605024	6430	Economy	15000.00
0005434512197	6430	Economy	15000.00
0005432605053	6430	Economy	15000.00
0005434512196	6430	Economy	15000.00
0005432605052	6430	Economy	15000.00
0005432605036	6430	Economy	15000.00
0005434512174	21373	Economy	16500.00
0005432604622	21373	Economy	16500.00
0005434512153	21373	Economy	16500.00
0005432604612	21373	Economy	16500.00
0005434512160	21373	Economy	15000.00
0005432604823	21373	Economy	15000.00
0005432604635	21373	Economy	15000.00
0005432604665	21373	Economy	15000.00
0005434512132	21373	Economy	15000.00
0005432604632	21373	Economy	15000.00
0005432604673	21373	Economy	15000.00
0005435221068	21373	Economy	15000.00
0005432604639	21373	Economy	15000.00
0005432604450	21373	Economy	15000.00
0005432604565	21373	Economy	15000.00
0005432604647	21373	Economy	15000.00
0005432604767	21373	Economy	15000.00
0005434512158	21373	Economy	15000.00
0005434512130	21373	Economy	15000.00
0005434512152	21373	Economy	15000.00
0005432604624	21373	Economy	15000.00
0005432604623	21373	Economy	15000.00
0005434512151	21373	Economy	15000.00
0005435221527	21373	Economy	15000.00
0005432604772	21373	Economy	15000.00
0005434512159	21373	Economy	15000.00
0005432604516	21373	Economy	15000.00
0005435221069	21373	Economy	15000.00
0005432604766	21373	Economy	15000.00
0005432604537	21373	Economy	15000.00
0005432604683	21373	Economy	15000.00
0005432604681	21373	Economy	15000.00
0005432604760	21373	Economy	15000.00
0005434512131	21373	Economy	15000.00
0005432604584	21373	Economy	15000.00
0005432604646	21373	Economy	15000.00
0005435221070	21373	Economy	15000.00
0005432604637	21373	Economy	15000.00
0005435221526	21373	Economy	15000.00
0005432604451	21373	Economy	15000.00
0005432604566	21373	Economy	15000.00
0005432604719	21373	Economy	15000.00
0005432604636	21373	Economy	15000.00
0005432604585	21373	Economy	15000.00
0005432604712	21373	Economy	15000.00
0005432604631	21373	Economy	15000.00
0005432604718	21373	Economy	15000.00
0005432604519	21373	Economy	15000.00
0005432604761	21373	Economy	15000.00
0005434907657	15021	Business	18900.00
0005434907617	15021	Business	18900.00
0005433252031	15021	Business	18900.00
0005434907585	15021	Business	18900.00
0005433252004	15021	Business	18900.00
0005434907587	15021	Business	18900.00
0005434907705	15021	Business	18900.00
0005434907397	15021	Business	18900.00
0005433252023	15021	Business	18900.00
0005433252006	15021	Business	18900.00
0005434907704	15021	Business	18900.00
0005434907676	15021	Economy	6300.00
0005434907598	15021	Economy	6300.00
0005434907752	15021	Economy	6300.00
0005433252010	15021	Economy	6300.00
0005434907745	15021	Economy	6300.00
0005433252024	15021	Economy	6300.00
0005433252003	15021	Economy	6300.00
0005434907507	15021	Economy	6300.00
0005434907616	15021	Economy	6900.00
0005433252013	15021	Economy	6900.00
0005434907659	15021	Economy	6900.00
0005434907689	15021	Economy	6900.00
0005434907568	15021	Economy	6300.00
0005434907607	15021	Economy	6300.00
0005433252032	15021	Economy	6300.00
0005433252008	15021	Economy	6300.00
0005434907658	15021	Economy	6300.00
0005433252018	15021	Economy	6300.00
0005434907778	15021	Economy	6300.00
0005434907534	15021	Economy	6300.00
0005433252009	15021	Economy	6300.00
0005434907685	15021	Economy	6300.00
0005434907706	15021	Economy	6300.00
0005433252014	15021	Economy	6300.00
0005433252022	15021	Economy	6300.00
0005433252020	15021	Economy	6300.00
0005433252005	15021	Economy	6300.00
0005433252028	15021	Economy	6300.00
0005434907602	15021	Economy	6300.00
0005433252016	15021	Economy	6300.00
0005433252025	15021	Economy	6300.00
0005434907753	15021	Economy	6300.00
0005434907579	15021	Economy	6300.00
0005434907725	15021	Economy	6300.00
0005434907675	15021	Economy	6300.00
0005433252015	15021	Economy	6300.00
0005434907439	15021	Economy	6300.00
0005434907549	15021	Economy	6300.00
0005434907724	15021	Economy	6300.00
0005433252019	15021	Economy	6300.00
0005434907732	15021	Economy	6300.00
0005434907722	15021	Economy	6300.00
0005434907726	15021	Economy	6300.00
0005434907654	15021	Economy	6300.00
0005434907733	15021	Economy	6300.00
0005433252002	15021	Economy	6300.00
0005434907603	15021	Economy	6300.00
0005434907741	15021	Economy	6300.00
0005434907475	15021	Economy	6300.00
0005433252007	15021	Economy	6300.00
0005433252011	15021	Economy	6300.00
0005433252026	15021	Economy	6300.00
0005434907728	15021	Economy	6300.00
0005434907723	15021	Economy	6300.00
0005434907734	15021	Economy	6300.00
0005433252012	15021	Economy	6300.00
0005433252033	15021	Economy	6300.00
0005433252021	15021	Economy	6300.00
0005434907720	15021	Economy	6300.00
0005434907423	15021	Economy	6300.00
0005434907727	15021	Economy	6300.00
0005433252030	15021	Economy	6300.00
0005434907690	15021	Economy	6300.00
0005433252029	15021	Economy	6300.00
0005434907721	15021	Economy	6300.00
0005433252017	15021	Economy	6300.00
0005434907550	15021	Economy	6300.00
0005433252027	15021	Economy	6300.00
0005434907656	15021	Economy	6300.00
0005434907422	15021	Economy	6300.00
0005434907487	15021	Economy	6300.00
0005433251731	25849	Business	18900.00
0005433251747	25849	Business	18900.00
0005433251827	25849	Business	18900.00
0005434908128	25849	Business	18900.00
0005434908158	25849	Business	18900.00
0005434908149	25849	Business	18900.00
0005433251687	25849	Business	18900.00
0005434908140	25849	Business	18900.00
0005433251901	25849	Economy	6300.00
0005434908136	25849	Economy	6300.00
0005433251732	25849	Economy	6300.00
0005434908161	25849	Economy	6300.00
0005434908159	25849	Economy	6300.00
0005434908138	25849	Economy	6300.00
0005433251806	25849	Economy	6300.00
0005433251881	25849	Economy	6300.00
0005433251710	25849	Economy	6300.00
0005434908127	25849	Economy	6300.00
0005433251761	25849	Economy	6900.00
0005433251581	25849	Economy	6900.00
0005434908154	25849	Economy	6900.00
0005433251705	25849	Economy	6900.00
0005433251859	25849	Economy	6900.00
0005433251748	25849	Economy	6300.00
0005433251812	25849	Economy	6300.00
0005433251772	25849	Economy	6300.00
0005433251715	25849	Economy	6300.00
0005433251668	25849	Economy	6300.00
0005434908133	25849	Economy	6300.00
0005433251707	25849	Economy	6300.00
0005434908162	25849	Economy	6300.00
0005433251711	25849	Economy	6300.00
0005433251900	25849	Economy	6300.00
0005434908139	25849	Economy	6300.00
0005434908157	25849	Economy	6300.00
0005434908130	25849	Economy	6300.00
0005434908152	25849	Economy	6300.00
0005434908126	25849	Economy	6300.00
0005433251739	25849	Economy	6300.00
0005433251741	25849	Economy	6300.00
0005433251843	25849	Economy	6300.00
0005433251580	25849	Economy	6300.00
0005434908160	25849	Economy	6300.00
0005433251804	25849	Economy	6300.00
0005434908129	25849	Economy	6300.00
0005434908148	25849	Economy	6300.00
0005434908137	25849	Economy	6300.00
0005433251686	25849	Economy	6300.00
0005433251847	25849	Economy	6300.00
0005434908156	25849	Economy	6300.00
0005433251803	25849	Economy	6300.00
0005433251723	25849	Economy	6300.00
0005433251842	25849	Economy	6300.00
0005434908134	25849	Economy	6300.00
0005433251624	25849	Economy	6300.00
0005434908151	25849	Economy	6300.00
0005434908150	25849	Economy	6300.00
0005433251828	25849	Economy	6300.00
0005434908145	25849	Economy	6300.00
0005433251579	25849	Economy	6300.00
0005433251762	25849	Economy	6300.00
0005433251740	25849	Economy	6300.00
0005433251805	25849	Economy	6300.00
0005434908131	25849	Economy	6300.00
0005434908153	25849	Economy	6300.00
0005434908143	25849	Economy	6300.00
0005433251625	25849	Economy	6300.00
0005434908135	25849	Economy	6300.00
0005433251662	25849	Economy	6300.00
0005434908144	25849	Economy	6300.00
0005433251688	25849	Economy	6300.00
0005434908132	25849	Economy	6300.00
0005433251706	25849	Economy	6300.00
0005434908147	25849	Economy	6300.00
0005434908142	25849	Economy	6300.00
0005434908146	25849	Economy	6300.00
0005433251745	25849	Economy	6300.00
0005433251667	25849	Economy	6300.00
0005433251817	25849	Economy	6300.00
0005434908155	25849	Economy	6300.00
0005433251757	25849	Economy	6300.00
0005433251620	25849	Economy	6300.00
0005434908141	25849	Economy	6300.00
0005433810575	14176	Business	52300.00
0005433009444	14176	Business	52300.00
0005433810576	14176	Business	52300.00
0005433009413	14176	Business	52300.00
0005433810566	14176	Business	52300.00
0005433009423	14176	Business	52300.00
0005433009433	14176	Economy	17400.00
0005433009415	14176	Economy	17400.00
0005433009424	14176	Economy	17400.00
0005433009403	14176	Economy	17400.00
0005433009400	14176	Economy	17400.00
0005433009402	14176	Economy	19200.00
0005433009434	14176	Economy	17400.00
0005433009437	14176	Economy	17400.00
0005433009427	14176	Economy	17400.00
0005433009422	14176	Economy	17400.00
0005433009421	14176	Economy	17400.00
0005433009425	14176	Economy	17400.00
0005433009432	14176	Economy	17400.00
0005433009399	14176	Economy	17400.00
0005433009414	14176	Economy	17400.00
0005433009429	14176	Economy	17400.00
0005433009436	14176	Economy	17400.00
0005433009401	14176	Economy	17400.00
0005433009416	14176	Economy	17400.00
0005433009412	14176	Economy	17400.00
0005433009410	14176	Economy	17400.00
0005433009418	14176	Economy	17400.00
0005433009430	14176	Economy	17400.00
0005433009439	14176	Economy	17400.00
0005433009431	14176	Economy	17400.00
0005433009420	14176	Economy	17400.00
0005433009407	14176	Economy	17400.00
0005433009435	14176	Economy	17400.00
0005433009440	14176	Economy	17400.00
0005433009438	14176	Economy	17400.00
0005433009408	14176	Economy	17400.00
0005433009409	14176	Economy	17400.00
0005433009404	14176	Economy	17400.00
0005433009442	14176	Economy	17400.00
0005433009428	14176	Economy	17400.00
0005433009445	14176	Economy	17400.00
0005433009405	14176	Economy	17400.00
0005433810577	14176	Economy	17400.00
0005433009419	14176	Economy	17400.00
0005433009441	14176	Economy	17400.00
0005433009443	14176	Economy	17400.00
0005433009406	14176	Economy	17400.00
0005433009417	14176	Economy	17400.00
0005433009411	14176	Economy	17400.00
0005433009426	14176	Economy	17400.00
0005433009198	22872	Business	52300.00
0005433008816	22872	Business	52300.00
0005433009293	22872	Business	52300.00
0005433009034	22872	Business	52300.00
0005433009073	22872	Business	52300.00
0005433008923	22872	Business	52300.00
0005433009087	22872	Business	52300.00
0005433009035	22872	Economy	17400.00
0005433009160	22872	Economy	17400.00
0005433009072	22872	Economy	17400.00
0005433009158	22872	Economy	19200.00
0005433009159	22872	Economy	19200.00
0005433008944	22872	Economy	19200.00
0005433008817	22872	Economy	17400.00
0005433008877	22872	Economy	17400.00
0005433008890	22872	Economy	17400.00
0005433009033	22872	Economy	17400.00
0005433009294	22872	Economy	17400.00
0005433009091	22872	Economy	17400.00
0005433009071	22872	Economy	17400.00
0005433008991	22872	Economy	17400.00
0005433009045	22872	Economy	17400.00
0005433008790	22872	Economy	17400.00
0005433008896	22872	Economy	17400.00
0005433009050	22872	Economy	17400.00
0005433009049	22872	Economy	17400.00
0005433009088	22872	Economy	17400.00
0005433008968	22872	Economy	17400.00
0005433009161	22872	Economy	17400.00
0005433009090	22872	Economy	17400.00
0005433008914	22872	Economy	17400.00
0005433008915	22872	Economy	17400.00
0005433008969	22872	Economy	17400.00
0005433008894	22872	Economy	17400.00
0005433009089	22872	Economy	17400.00
0005433008654	22872	Economy	17400.00
0005433008891	22872	Economy	17400.00
0005433009139	22872	Economy	17400.00
0005433008879	22872	Economy	17400.00
0005433008967	22872	Economy	17400.00
0005433009003	22872	Economy	17400.00
0005433008906	22872	Economy	17400.00
0005433008897	22872	Economy	17400.00
0005433009162	22872	Economy	17400.00
0005433008938	22872	Economy	17400.00
0005433009012	22872	Economy	17400.00
0005433008905	22872	Economy	17400.00
0005433008903	22872	Economy	17400.00
0005433009044	22872	Economy	17400.00
0005433009004	22872	Economy	17400.00
0005433009140	22872	Economy	17400.00
0005433009141	22872	Economy	17400.00
0005433008878	22872	Economy	17400.00
0005434926013	14962	Business	22900.00
0005434926004	14962	Business	22900.00
0005434926077	14962	Business	22900.00
0005434926064	14962	Business	22900.00
0005434926123	14962	Business	22900.00
0005434926151	14962	Business	22900.00
0005434926161	14962	Economy	7600.00
0005434926014	14962	Economy	7600.00
0005434926060	14962	Economy	7600.00
0005434925964	14962	Economy	7600.00
0005434926097	14962	Economy	7600.00
0005434926099	14962	Economy	8400.00
0005434926110	14962	Economy	8400.00
0005434926162	14962	Economy	7600.00
0005434926163	14962	Economy	7600.00
0005434925984	14962	Economy	7600.00
0005434926100	14962	Economy	7600.00
0005434925965	14962	Economy	7600.00
0005434926070	14962	Economy	7600.00
0005434925967	14962	Economy	7600.00
0005434926002	14962	Economy	7600.00
0005434925932	14962	Economy	7600.00
0005434926094	14962	Economy	7600.00
0005434926006	14962	Economy	7600.00
0005434926150	14962	Economy	7600.00
0005434926154	14962	Economy	7600.00
0005434925983	14962	Economy	7600.00
0005434925948	14962	Economy	7600.00
0005434926003	14962	Economy	7600.00
0005434926095	14962	Economy	7600.00
0005434925985	14962	Economy	7600.00
0005434926044	14962	Economy	7600.00
0005434926105	14962	Economy	7600.00
0005434926153	14962	Economy	7600.00
0005434926096	14962	Economy	7600.00
0005434926327	20540	Business	22900.00
0005434926342	20540	Business	22900.00
0005434926339	20540	Business	22900.00
0005434926340	20540	Economy	7600.00
0005434926331	20540	Economy	7600.00
0005434926337	20540	Economy	7600.00
0005434926335	20540	Economy	7600.00
0005434926330	20540	Economy	7600.00
0005434926333	20540	Economy	7600.00
0005434926334	20540	Economy	7600.00
0005434926332	20540	Economy	7600.00
0005434926336	20540	Economy	7600.00
0005434926328	20540	Economy	7600.00
0005434926341	20540	Economy	7600.00
0005434926338	20540	Economy	7600.00
0005434926329	20540	Economy	7600.00
0005435999387	15821	Economy	8900.00
0005435999393	15821	Economy	8900.00
0005435488222	15821	Economy	8900.00
0005435488211	15821	Economy	8100.00
0005435999420	15821	Economy	8100.00
0005435488218	15821	Economy	8100.00
0005435488208	15821	Economy	8100.00
0005435488224	15821	Economy	8100.00
0005435488210	15821	Economy	8100.00
0005435999421	15821	Economy	8100.00
0005435488207	15821	Economy	8100.00
0005435488215	15821	Economy	8100.00
0005435488214	15821	Economy	8100.00
0005435488213	15821	Economy	8100.00
0005435488219	15821	Economy	8100.00
0005435999390	15821	Economy	8100.00
0005435999422	15821	Economy	8100.00
0005435488209	15821	Economy	8100.00
0005435999354	15821	Economy	8100.00
0005435488212	15821	Economy	8100.00
0005435999398	15821	Economy	8100.00
0005435488228	15821	Economy	8100.00
0005435488216	15821	Economy	8100.00
0005435488221	15821	Economy	8100.00
0005435999391	15821	Economy	8100.00
0005435999355	15821	Economy	8100.00
0005435999370	15821	Economy	8100.00
0005435488223	15821	Economy	8100.00
0005435488226	15821	Economy	8100.00
0005435999392	15821	Economy	8100.00
0005435999373	15821	Economy	8100.00
0005435488227	15821	Economy	8100.00
0005435488220	15821	Economy	8100.00
0005435488217	15821	Economy	8100.00
0005435488225	15821	Economy	8100.00
0005435999394	15821	Economy	8100.00
0005435999545	19672	Economy	8900.00
0005435487996	19672	Economy	8900.00
0005435488050	19672	Economy	8900.00
0005435487976	19672	Economy	8100.00
0005435999533	19672	Economy	8100.00
0005435999536	19672	Economy	8100.00
0005435487968	19672	Economy	8100.00
0005435999530	19672	Economy	8100.00
0005435999532	19672	Economy	8100.00
0005435999540	19672	Economy	8100.00
0005435487944	19672	Economy	8100.00
0005435999543	19672	Economy	8100.00
0005435999531	19672	Economy	8100.00
0005435999538	19672	Economy	8100.00
0005435999546	19672	Economy	8100.00
0005435487962	19672	Economy	8100.00
0005435487981	19672	Economy	8100.00
0005435999548	19672	Economy	8100.00
0005435487926	19672	Economy	8100.00
0005435487937	19672	Economy	8100.00
0005435999541	19672	Economy	8100.00
0005435488007	19672	Economy	8100.00
0005435999542	19672	Economy	8100.00
0005435999549	19672	Economy	8100.00
0005435488000	19672	Economy	8100.00
0005435999537	19672	Economy	8100.00
0005435999534	19672	Economy	8100.00
0005435487945	19672	Economy	8100.00
0005435488001	19672	Economy	8100.00
0005435487963	19672	Economy	8100.00
0005435487952	19672	Economy	8100.00
0005435999535	19672	Economy	8100.00
0005435999544	19672	Economy	8100.00
0005435487859	19672	Economy	8100.00
0005435999551	19672	Economy	8100.00
0005435487969	19672	Economy	8100.00
0005435487858	19672	Economy	8100.00
0005435487999	19672	Economy	8100.00
0005435487975	19672	Economy	8100.00
0005435999547	19672	Economy	8100.00
0005435487943	19672	Economy	8100.00
0005435999550	19672	Economy	8100.00
0005435999539	19672	Economy	8100.00
0005435839957	6002	Business	199300.00
0005432142308	6002	Business	199300.00
0005432658630	6002	Business	199300.00
0005435472987	6002	Business	199300.00
0005432537071	6002	Business	199300.00
0005435839964	6002	Business	199300.00
0005435472929	6002	Business	199300.00
0005435839955	6002	Business	199300.00
0005435839941	6002	Economy	66400.00
0005435839952	6002	Economy	66400.00
0005432142307	6002	Economy	66400.00
0005435839939	6002	Economy	66400.00
0005435472983	6002	Economy	66400.00
0005435839958	6002	Economy	66400.00
0005435472984	6002	Economy	66400.00
0005432537075	6002	Economy	73100.00
0005432537074	6002	Economy	73100.00
0005435839944	6002	Economy	66400.00
0005435839953	6002	Economy	73100.00
0005435472967	6002	Economy	66400.00
0005435472978	6002	Economy	66400.00
0005435839940	6002	Economy	66400.00
0005435839947	6002	Economy	66400.00
0005432660856	6002	Economy	66400.00
0005435839948	6002	Economy	66400.00
0005435839949	6002	Economy	66400.00
0005432658629	6002	Economy	66400.00
0005435472961	6002	Economy	66400.00
0005435839960	6002	Economy	66400.00
0005435839963	6002	Economy	66400.00
0005435839945	6002	Economy	66400.00
0005435839946	6002	Economy	66400.00
0005435839951	6002	Economy	66400.00
0005435472957	6002	Economy	66400.00
0005435472923	6002	Economy	66400.00
0005435839961	6002	Economy	66400.00
0005435839950	6002	Economy	66400.00
0005432537080	6002	Economy	66400.00
0005432142309	6002	Economy	66400.00
0005435473006	6002	Economy	66400.00
0005432537076	6002	Economy	66400.00
0005435839962	6002	Economy	66400.00
0005435472958	6002	Economy	66400.00
0005435839938	6002	Economy	66400.00
0005435839959	6002	Economy	66400.00
0005435839942	6002	Economy	66400.00
0005435472922	6002	Economy	66400.00
0005435839943	6002	Economy	66400.00
0005435839956	6002	Economy	66400.00
0005432659745	6002	Economy	66400.00
0005435839954	6002	Economy	66400.00
0005432664130	18061	Business	199300.00
0005432537097	18061	Business	199300.00
0005435473086	18061	Business	199300.00
0005435839673	18061	Business	199300.00
0005435473094	18061	Business	199300.00
0005432667468	18061	Business	199300.00
0005432667457	18061	Business	199300.00
0005432664143	18061	Business	199300.00
0005435839654	18061	Business	199300.00
0005435473098	18061	Business	199300.00
0005435839634	18061	Business	199300.00
0005435839639	18061	Business	199300.00
0005435839679	18061	Business	199300.00
0005432660832	18061	Business	199300.00
0005435839669	18061	Economy	66400.00
0005432660829	18061	Economy	66400.00
0005435473100	18061	Economy	66400.00
0005432667467	18061	Economy	66400.00
0005435473088	18061	Economy	73100.00
0005435839638	18061	Economy	73100.00
0005435839653	18061	Economy	66400.00
0005432664129	18061	Economy	66400.00
0005435473099	18061	Economy	66400.00
0005435839635	18061	Economy	66400.00
0005435839843	18061	Economy	66400.00
0005435839731	18061	Economy	66400.00
0005435839569	18061	Economy	66400.00
0005435473087	18061	Economy	66400.00
0005432664148	18061	Economy	66400.00
0005435839605	18061	Economy	66400.00
0005435839652	18061	Economy	66400.00
0005435473090	18061	Economy	66400.00
0005435839729	18061	Economy	66400.00
0005435473089	18061	Economy	66400.00
0005435839684	18061	Economy	66400.00
0005435839710	18061	Economy	66400.00
0005435839656	18061	Economy	66400.00
0005435473095	18061	Economy	66400.00
0005435839752	18061	Economy	66400.00
0005435839672	18061	Economy	66400.00
0005435839718	18061	Economy	66400.00
0005432664144	18061	Economy	66400.00
0005435839730	18061	Economy	66400.00
0005435839748	18061	Economy	66400.00
0005435839571	18061	Economy	66400.00
0005435839655	18061	Economy	66400.00
0005435473091	18061	Economy	66400.00
0005432660830	18061	Economy	66400.00
0005435473097	18061	Economy	66400.00
0005435473092	18061	Economy	66400.00
0005432664145	18061	Economy	66400.00
0005435839698	18061	Economy	66400.00
0005435839660	18061	Economy	66400.00
0005435839697	18061	Economy	66400.00
0005435473096	18061	Economy	66400.00
0005435839722	18061	Economy	66400.00
0005435839570	18061	Economy	66400.00
0005435839685	18061	Economy	66400.00
0005435839687	18061	Economy	66400.00
0005435473102	18061	Economy	66400.00
0005435473101	18061	Economy	66400.00
0005435473093	18061	Economy	66400.00
0005433285499	23039	Business	15700.00
0005433285629	23039	Business	15700.00
0005433285699	23039	Business	15700.00
0005433285498	23039	Business	15700.00
0005433285664	23039	Business	15700.00
0005433285550	23039	Business	15700.00
0005433285599	23039	Economy	5200.00
0005433285411	23039	Economy	5200.00
0005433285582	23039	Economy	5200.00
0005433285670	23039	Economy	5200.00
0005433285764	23039	Economy	5200.00
0005433285661	23039	Economy	5200.00
0005435104066	23039	Economy	5200.00
0005435104064	23039	Economy	5200.00
0005433285463	23039	Economy	5200.00
0005433285545	23039	Economy	5700.00
0005433285587	23039	Economy	5700.00
0005435104063	23039	Economy	5200.00
0005433285604	23039	Economy	5200.00
0005433285520	23039	Economy	5200.00
0005433285519	23039	Economy	5200.00
0005433285674	23039	Economy	5200.00
0005433285513	23039	Economy	5200.00
0005433285549	23039	Economy	5200.00
0005433285543	23039	Economy	5200.00
0005433285410	23039	Economy	5200.00
0005435104065	23039	Economy	5200.00
0005433285487	23039	Economy	5200.00
0005433285628	23039	Economy	5200.00
0005433285700	23039	Economy	5200.00
0005433285485	23039	Economy	5200.00
0005433285626	23039	Economy	5200.00
0005433285486	23039	Economy	5200.00
0005433285625	23039	Economy	5200.00
0005433285600	23039	Economy	5200.00
0005433285565	23039	Economy	5200.00
0005433285479	23039	Economy	5200.00
0005433285412	23039	Economy	5200.00
0005433285583	23039	Economy	5200.00
0005433285575	23039	Economy	5200.00
0005435104062	23039	Economy	5200.00
0005433285478	23039	Economy	5200.00
0005433285602	23039	Economy	5200.00
0005433285840	32045	Business	15700.00
0005433285866	32045	Business	15700.00
0005433285858	32045	Business	15700.00
0005435103962	32045	Business	15700.00
0005433285848	32045	Economy	5200.00
0005433285843	32045	Economy	5200.00
0005433285837	32045	Economy	5200.00
0005433285846	32045	Economy	5200.00
0005433285856	32045	Economy	5200.00
0005433285854	32045	Economy	5200.00
0005433285855	32045	Economy	5200.00
0005433285861	32045	Economy	5200.00
0005433285863	32045	Economy	5200.00
0005433285865	32045	Economy	5200.00
0005433285836	32045	Economy	5200.00
0005433285859	32045	Economy	5200.00
0005433285857	32045	Economy	5700.00
0005433285845	32045	Economy	5700.00
0005433285849	32045	Economy	5200.00
0005433285839	32045	Economy	5200.00
0005433285850	32045	Economy	5200.00
0005433285842	32045	Economy	5200.00
0005433285862	32045	Economy	5200.00
0005433285838	32045	Economy	5200.00
0005433285860	32045	Economy	5200.00
0005433285864	32045	Economy	5200.00
0005433285847	32045	Economy	5200.00
0005433285841	32045	Economy	5200.00
0005433285851	32045	Economy	5200.00
0005435103960	32045	Economy	5200.00
0005433285867	32045	Economy	5200.00
0005435103961	32045	Economy	5200.00
0005433285844	32045	Economy	5200.00
0005433285852	32045	Economy	5200.00
0005433285853	32045	Economy	5200.00
0005434068222	30583	Business	42100.00
0005435214763	30583	Business	42100.00
0005432528965	30583	Business	42100.00
0005432528964	30583	Business	42100.00
0005432428948	30583	Business	42100.00
0005434068358	30583	Business	42100.00
0005433656734	30583	Business	42100.00
0005432529463	30583	Business	42100.00
0005432529504	30583	Business	42100.00
0005432528853	30583	Business	42100.00
0005434068078	30583	Business	42100.00
0005434068199	30583	Business	42100.00
0005432529361	30583	Business	42100.00
0005432535892	30583	Business	42100.00
0005435214798	30583	Business	42100.00
0005434068312	30583	Business	42100.00
0005435214799	30583	Business	42100.00
0005432529272	30583	Business	42100.00
0005435214783	30583	Business	42100.00
0005432528766	30583	Business	42100.00
0005435214797	30583	Comfort	23900.00
0005432528916	30583	Comfort	23900.00
0005435214806	30583	Comfort	23900.00
0005434068317	30583	Comfort	23900.00
0005435214822	30583	Comfort	23900.00
0005435214816	30583	Comfort	23900.00
0005433656733	30583	Comfort	23900.00
0005434068198	30583	Comfort	23900.00
0005432529162	30583	Comfort	23900.00
0005434068369	30583	Comfort	23900.00
0005435214765	30583	Comfort	23900.00
0005432428965	30583	Comfort	23900.00
0005434068240	30583	Comfort	23900.00
0005432528608	30583	Comfort	23900.00
0005435214793	30583	Comfort	23900.00
0005435214777	30583	Comfort	23900.00
0005432528596	30583	Comfort	23900.00
0005434068152	30583	Comfort	23900.00
0005434068249	30583	Comfort	23900.00
0005432529652	30583	Comfort	23900.00
0005432529021	30583	Comfort	23900.00
0005435214817	30583	Comfort	23900.00
0005432529116	30583	Comfort	23900.00
0005435283421	30583	Comfort	23900.00
0005432529480	30583	Comfort	23900.00
0005435214810	30583	Comfort	23900.00
0005435214813	30583	Comfort	23900.00
0005435214785	30583	Comfort	23900.00
0005432529653	30583	Comfort	23900.00
0005434067823	30583	Comfort	23900.00
0005435214794	30583	Comfort	23900.00
0005432528713	30583	Comfort	23900.00
0005432428966	30583	Comfort	23900.00
0005435214824	30583	Comfort	23900.00
0005435631023	30583	Comfort	23900.00
0005434068083	30583	Economy	14000.00
0005434068133	30583	Comfort	23900.00
0005434068340	30583	Economy	14000.00
0005432211638	30583	Economy	14000.00
0005435214791	30583	Economy	14000.00
0005435214796	30583	Economy	14000.00
0005435214759	30583	Economy	14000.00
0005434068467	30583	Economy	14000.00
0005435725693	30583	Economy	14000.00
0005434068238	30583	Economy	14000.00
0005432529441	30583	Economy	14000.00
0005432529213	30583	Economy	14000.00
0005435283423	30583	Economy	14000.00
0005432528974	30583	Economy	14000.00
0005432529053	30583	Economy	14000.00
0005434068135	30583	Economy	14000.00
0005435283420	30583	Economy	14000.00
0005432529711	30583	Economy	14000.00
0005434068445	30583	Economy	14000.00
0005434068028	30583	Economy	14000.00
0005432529449	30583	Economy	14000.00
0005435214779	30583	Economy	14000.00
0005432533319	30583	Economy	14000.00
0005432529111	30583	Economy	14000.00
0005432529132	30583	Economy	14000.00
0005435214771	30583	Economy	14000.00
0005432529321	30583	Economy	14000.00
0005435214811	30583	Economy	14000.00
0005432529436	30583	Economy	14000.00
0005435214815	30583	Economy	14000.00
0005434068073	30583	Economy	14000.00
0005432537078	30583	Economy	14000.00
0005435214809	30583	Economy	14000.00
0005435214780	30583	Economy	14000.00
0005435214808	30583	Economy	14000.00
0005432529445	30583	Economy	14000.00
0005432529878	30583	Economy	14000.00
0005432529506	30583	Economy	14000.00
0005435214782	30583	Economy	14000.00
0005434068061	30583	Economy	14000.00
0005432528856	30583	Economy	14000.00
0005435214768	30583	Economy	14000.00
0005432528968	30583	Economy	14000.00
0005432529203	30583	Economy	14000.00
0005432529044	30583	Economy	14000.00
0005432537072	30583	Economy	14000.00
0005432528598	30583	Economy	14000.00
0005432528714	30583	Economy	14000.00
0005432529993	30583	Economy	14000.00
0005435214786	30583	Economy	14000.00
0005432529106	30583	Economy	14000.00
0005432529133	30583	Economy	14000.00
0005434068074	30583	Economy	14000.00
0005432529155	30583	Economy	14000.00
0005434068014	30583	Economy	14000.00
0005432529150	30583	Economy	14000.00
0005432529295	30583	Economy	14000.00
0005432529367	30583	Economy	14000.00
0005432529850	30583	Economy	15400.00
0005434068047	30583	Economy	14000.00
0005435214803	30583	Economy	15400.00
0005432211641	30583	Economy	14000.00
0005432529215	30583	Economy	14000.00
0005434068015	30583	Economy	14000.00
0005432529539	30583	Economy	14000.00
0005434068048	30583	Economy	15400.00
0005434068169	30583	Economy	15400.00
0005432528975	30583	Economy	15400.00
0005435214772	30583	Economy	14000.00
0005432529102	30583	Economy	14000.00
0005432537077	30583	Economy	14000.00
0005432529979	30583	Economy	14000.00
0005435283426	30583	Economy	14000.00
0005435725695	30583	Economy	14000.00
0005432529642	30583	Economy	14000.00
0005434068204	30583	Economy	14000.00
0005434068248	30583	Economy	14000.00
0005435631025	30583	Economy	14000.00
0005432529262	30583	Economy	14000.00
0005434068366	30583	Economy	14000.00
0005432529297	30583	Economy	14000.00
0005432529025	30583	Economy	14000.00
0005432529498	30583	Economy	14000.00
0005434068185	30583	Economy	14000.00
0005432211639	30583	Economy	14000.00
0005432529103	30583	Economy	14000.00
0005432529560	30583	Economy	14000.00
0005432211637	30583	Economy	14000.00
0005432428971	30583	Economy	14000.00
0005435214812	30583	Economy	14000.00
0005432535891	30583	Economy	14000.00
0005432528597	30583	Economy	14000.00
0005432528612	30583	Economy	14000.00
0005432529320	30583	Economy	14000.00
0005435214762	30583	Economy	14000.00
0005435214787	30583	Economy	14000.00
0005432529465	30583	Economy	14000.00
0005432529043	30583	Economy	14000.00
0005435214823	30583	Economy	14000.00
0005432529149	30583	Economy	14000.00
0005434068374	30583	Economy	14000.00
0005435214778	30583	Economy	14000.00
0005432529260	30583	Economy	14000.00
0005435214760	30583	Economy	14000.00
0005432529464	30583	Economy	14000.00
0005434067824	30583	Economy	14000.00
0005432528717	30583	Economy	14000.00
0005435214770	30583	Economy	14000.00
0005432428969	30583	Economy	14000.00
0005434068316	30583	Economy	14000.00
0005432529440	30583	Economy	14000.00
0005435214761	30583	Economy	14000.00
0005432529446	30583	Economy	14000.00
0005432529841	30583	Economy	14000.00
0005432159943	30583	Economy	14000.00
0005433656732	30583	Economy	14000.00
0005432528855	30583	Economy	14000.00
0005435214789	30583	Economy	14000.00
0005435214781	30583	Economy	14000.00
0005432529022	30583	Economy	14000.00
0005435214773	30583	Economy	14000.00
0005432529076	30583	Economy	14000.00
0005432528940	30583	Economy	14000.00
0005432529115	30583	Economy	14000.00
0005432529427	30583	Economy	14000.00
0005432529032	30583	Economy	14000.00
0005432529505	30583	Economy	14000.00
0005432529052	30583	Economy	14000.00
0005432529877	30583	Economy	14000.00
0005435214758	30583	Economy	14000.00
0005432528405	30583	Economy	14000.00
0005434068579	30583	Economy	14000.00
0005434068367	30583	Economy	14000.00
0005434068068	30583	Economy	14000.00
0005435725694	30583	Economy	14000.00
0005432529298	30583	Economy	14000.00
0005432529371	30583	Economy	14000.00
0005432528753	30583	Economy	14000.00
0005432528861	30583	Economy	14000.00
0005434068113	30583	Economy	14000.00
0005434068396	30583	Economy	14000.00
0005435214802	30583	Economy	14000.00
0005435214807	30583	Economy	14000.00
0005432428967	30583	Economy	14000.00
0005432159940	30583	Economy	14000.00
0005435214774	30583	Economy	14000.00
0005432529342	30583	Economy	14000.00
0005432428970	30583	Economy	14000.00
0005432537082	30583	Economy	14000.00
0005432529641	30583	Economy	14000.00
0005432537081	30583	Economy	14000.00
0005432211636	30583	Economy	14000.00
0005435214805	30583	Economy	14000.00
0005434068341	30583	Economy	14000.00
0005435214769	30583	Economy	14000.00
0005435283424	30583	Economy	14000.00
0005432428962	30583	Economy	15400.00
0005434068132	30583	Economy	15400.00
0005435214820	30583	Economy	15400.00
0005434068106	30583	Economy	15400.00
0005432528915	30583	Economy	14000.00
0005432528917	30583	Economy	14000.00
0005435283425	30583	Economy	14000.00
0005434067950	30583	Economy	14000.00
0005435214775	30583	Economy	14000.00
0005435214821	30583	Economy	14000.00
0005432529196	30583	Economy	14000.00
0005432428968	30583	Economy	14000.00
0005435214757	30583	Economy	14000.00
0005435214819	30583	Economy	14000.00
0005435214804	30583	Economy	14000.00
0005432529842	30583	Economy	14000.00
0005432529241	30583	Economy	14000.00
0005434068298	30583	Economy	14000.00
0005432529157	30583	Economy	14000.00
0005432529182	30583	Economy	14000.00
0005432529075	30583	Economy	14000.00
0005432529110	30583	Economy	14000.00
0005432159941	30583	Economy	14000.00
0005435725691	30583	Economy	14000.00
0005432529332	30583	Economy	14000.00
0005432529066	30583	Economy	14000.00
0005435214776	30583	Economy	14000.00
0005435214801	30583	Economy	14000.00
0005432528929	30583	Economy	14000.00
0005432529473	30583	Economy	14000.00
0005435214792	30583	Economy	14000.00
0005434068234	30583	Economy	14000.00
0005432529416	30583	Economy	14000.00
0005432529070	30583	Economy	14000.00
0005432529245	30583	Economy	14000.00
0005432529574	30583	Economy	14000.00
0005432529104	30583	Economy	14000.00
0005434068001	30583	Economy	14000.00
0005432529457	30583	Economy	14000.00
0005432537073	30583	Economy	14000.00
0005435214764	30583	Economy	14000.00
0005434068122	30583	Economy	14000.00
0005432529047	30583	Economy	14000.00
0005432529405	30583	Economy	14000.00
0005435725696	30583	Economy	14000.00
0005434068098	30583	Economy	14000.00
0005432529020	30583	Economy	14000.00
0005435214784	30583	Economy	14000.00
0005432529565	30583	Economy	14000.00
0005434068202	30583	Economy	14000.00
0005432528789	30583	Economy	14000.00
0005432529627	30583	Economy	14000.00
0005435631024	30583	Economy	14000.00
0005432211640	30583	Economy	14000.00
0005432211635	30583	Economy	14000.00
0005432529178	30583	Economy	14000.00
0005432528788	30583	Economy	14000.00
0005432528718	30583	Economy	14000.00
0005435283422	30583	Economy	14000.00
0005432528967	30583	Economy	14000.00
0005434068075	30583	Economy	14000.00
0005432529341	30583	Economy	14000.00
0005432535868	30583	Economy	14000.00
0005432528845	30583	Economy	14000.00
0005435214790	30583	Economy	14000.00
0005435214766	30583	Economy	14000.00
0005432529261	30583	Economy	14000.00
0005432159942	30583	Economy	14000.00
0005434068112	30583	Economy	14000.00
0005432529204	30583	Economy	14000.00
0005435214814	30583	Economy	14000.00
0005435214788	30583	Economy	14000.00
0005434068478	30583	Economy	14000.00
0005432529411	30583	Economy	14000.00
0005432529333	30583	Economy	14000.00
0005435214818	30583	Economy	14000.00
0005434068099	30583	Economy	14000.00
0005435725692	30583	Economy	14000.00
0005432211642	30583	Economy	14000.00
0005435214767	30583	Economy	14000.00
0005435214800	30583	Economy	14000.00
0005434068347	30583	Economy	14000.00
0005435214795	30583	Economy	14000.00
0005432528947	30583	Economy	14000.00
0005432529181	30583	Economy	14000.00
0005434068221	30583	Economy	14000.00
0005432529573	30583	Economy	14000.00
0005433368592	24834	Business	9800.00
0005433368572	24834	Business	9800.00
0005435653475	24834	Business	9800.00
0005435653270	24834	Business	9800.00
0005433368582	24834	Business	9800.00
0005433368598	24834	Business	9800.00
0005433368568	24834	Business	9800.00
0005433368597	24834	Business	9800.00
0005435653489	24834	Business	9800.00
0005435653258	24834	Business	9800.00
0005435653436	24834	Business	9800.00
0005433368579	24834	Business	9800.00
0005433368594	24834	Economy	3300.00
0005433368574	24834	Economy	3300.00
0005435653505	24834	Economy	3300.00
0005433368564	24834	Economy	3300.00
0005435653423	24834	Economy	3300.00
0005433368589	24834	Economy	3300.00
0005435653369	24834	Economy	3300.00
0005435653412	24834	Economy	3600.00
0005435653477	24834	Economy	3600.00
0005433368575	24834	Economy	3600.00
0005433368587	24834	Economy	3600.00
0005433368591	24834	Economy	3600.00
0005433368585	24834	Economy	3300.00
0005433368563	24834	Economy	3300.00
0005435653429	24834	Economy	3300.00
0005435653483	24834	Economy	3300.00
0005435653390	24834	Economy	3300.00
0005435653389	24834	Economy	3300.00
0005433368577	24834	Economy	3300.00
0005433368567	24834	Economy	3300.00
0005435653309	24834	Economy	3300.00
0005433368590	24834	Economy	3300.00
0005433368588	24834	Economy	3300.00
0005433368562	24834	Economy	3300.00
0005435653287	24834	Economy	3300.00
0005433368566	24834	Economy	3300.00
0005435653428	24834	Economy	3300.00
0005433368565	24834	Economy	3300.00
0005435653440	24834	Economy	3300.00
0005435653520	24834	Economy	3300.00
0005435653323	24834	Economy	3300.00
0005433368580	24834	Economy	3300.00
0005435653271	24834	Economy	3300.00
0005435653418	24834	Economy	3300.00
0005435653542	24834	Economy	3300.00
0005433368573	24834	Economy	3300.00
0005433368576	24834	Economy	3300.00
0005435653325	24834	Economy	3300.00
0005435653529	24834	Economy	3300.00
0005435653386	24834	Economy	3300.00
0005435653310	24834	Economy	3300.00
0005435653506	24834	Economy	3300.00
0005435653530	24834	Economy	3300.00
0005435653303	24834	Economy	3300.00
0005435653413	24834	Economy	3300.00
0005433368583	24834	Economy	3300.00
0005433368569	24834	Economy	3300.00
0005433368595	24834	Economy	3300.00
0005435653424	24834	Economy	3300.00
0005433368599	24834	Economy	3300.00
0005435653361	24834	Economy	3300.00
0005433368600	24834	Economy	3300.00
0005435653543	24834	Economy	3300.00
0005433368571	24834	Economy	3300.00
0005433368581	24834	Economy	3300.00
0005433368586	24834	Economy	3300.00
0005435653360	24834	Economy	3300.00
0005435653528	24834	Economy	3300.00
0005435653410	24834	Economy	3300.00
0005435653326	24834	Economy	3300.00
0005435653365	24834	Economy	3300.00
0005433368570	24834	Economy	3300.00
0005433368584	24834	Economy	3300.00
0005433368596	24834	Economy	3300.00
0005435653490	24834	Economy	3300.00
0005435653422	24834	Economy	3300.00
0005435653482	24834	Economy	3300.00
0005435653446	24834	Economy	3300.00
0005433368593	24834	Economy	3300.00
0005435653362	24834	Economy	3300.00
0005433368578	24834	Economy	3300.00
0005435653409	24834	Economy	3300.00
0005435653461	24834	Economy	3300.00
0005435949803	23306	Economy	18700.00
0005435949804	23306	Economy	18700.00
0005435949793	23306	Economy	18700.00
0005435949800	23306	Economy	18700.00
0005435949796	23306	Economy	18700.00
0005435949797	23306	Economy	18700.00
0005435949795	23306	Economy	18700.00
0005435949794	23306	Economy	18700.00
0005435949811	23306	Economy	18700.00
0005435949809	23306	Economy	18700.00
0005435949812	23306	Economy	18700.00
0005435949790	23306	Economy	18700.00
0005435949822	23306	Economy	18700.00
0005434980335	2061	Economy	10500.00
0005434980353	2061	Economy	10500.00
0005434980336	2061	Economy	10500.00
0005434980354	2061	Economy	9500.00
0005434980346	2061	Economy	9500.00
0005434980338	2061	Economy	9500.00
0005434980350	2061	Economy	9500.00
0005434980347	2061	Economy	9500.00
0005434980343	2061	Economy	9500.00
0005434980334	2061	Economy	9500.00
0005435801753	2061	Economy	9500.00
0005434980356	2061	Economy	9500.00
0005434980342	2061	Economy	9500.00
0005434980341	2061	Economy	9500.00
0005434980357	2061	Economy	9500.00
0005434980333	2061	Economy	9500.00
0005434980348	2061	Economy	9500.00
0005434980340	2061	Economy	9500.00
0005434980330	2061	Economy	9500.00
0005434980331	2061	Economy	9500.00
0005434980332	2061	Economy	9500.00
0005434980358	2061	Economy	9500.00
0005434980351	2061	Economy	9500.00
0005434980339	2061	Economy	9500.00
0005435801752	2061	Economy	9500.00
0005434980355	2061	Economy	9500.00
0005434980337	2061	Economy	9500.00
0005434980352	2061	Economy	9500.00
0005434980329	2061	Economy	9500.00
0005434980345	2061	Economy	9500.00
0005434980359	2061	Economy	9500.00
0005434980349	2061	Economy	9500.00
0005434980344	2061	Economy	9500.00
0005435801751	2061	Economy	9500.00
0005434979950	23547	Economy	10500.00
0005434979995	23547	Economy	9500.00
0005434980158	23547	Economy	9500.00
0005434979850	23547	Economy	9500.00
0005434979940	23547	Economy	9500.00
0005434979905	23547	Economy	9500.00
0005434979941	23547	Economy	9500.00
0005434980059	23547	Economy	9500.00
0005435801728	23547	Economy	9500.00
0005434979987	23547	Economy	9500.00
0005434980168	23547	Economy	9500.00
0005434979906	23547	Economy	9500.00
0005434980114	23547	Economy	9500.00
0005434979949	23547	Economy	9500.00
0005434979939	23547	Economy	9500.00
0005434979851	23547	Economy	9500.00
0005434979982	23547	Economy	9500.00
0005434980122	23547	Economy	9500.00
0005434980067	23547	Economy	9500.00
0005434979951	23547	Economy	9500.00
0005434979962	23547	Economy	9500.00
0005434979849	23547	Economy	9500.00
0005434952599	2626	Economy	5300.00
0005434952601	2626	Economy	5300.00
0005434952600	2626	Economy	5300.00
0005433256446	2640	Economy	5300.00
0005433256447	2640	Economy	5300.00
0005433256437	2640	Economy	5300.00
0005433256445	2640	Economy	5300.00
0005433256464	28235	Economy	5300.00
0005434952578	28235	Economy	5300.00
0005434952577	28235	Economy	5300.00
0005434952584	28235	Economy	5300.00
0005433256463	28235	Economy	5300.00
0005433112404	19781	Economy	8700.00
0005433111548	19781	Economy	8700.00
0005433112405	19781	Economy	8700.00
0005433111547	19781	Economy	8700.00
0005434138633	11969	Business	9700.00
0005434138787	11969	Business	9700.00
0005434138956	11969	Business	9700.00
0005434138701	11969	Business	9700.00
0005434138780	11969	Business	9700.00
0005434139138	11969	Business	9700.00
0005434139107	11969	Business	9700.00
0005434138872	11969	Business	9700.00
0005434138854	11969	Business	9700.00
0005434139002	11969	Business	9700.00
0005434138904	11969	Economy	3200.00
0005434138702	11969	Economy	3200.00
0005434138508	11969	Economy	3200.00
0005434138745	11969	Economy	3200.00
0005434139110	11969	Economy	3200.00
0005434138815	11969	Economy	3200.00
0005434138736	11969	Economy	3200.00
0005434139127	11969	Economy	3500.00
0005434138734	11969	Economy	3500.00
0005434138707	11969	Economy	3500.00
0005434138735	11969	Economy	3500.00
0005434138760	11969	Economy	3500.00
0005434138914	11969	Economy	3200.00
0005434139039	11969	Economy	3200.00
0005434139026	11969	Economy	3200.00
0005434138661	11969	Economy	3200.00
0005434138786	11969	Economy	3200.00
0005434139000	11969	Economy	3200.00
0005434138695	11969	Economy	3200.00
0005434138902	11969	Economy	3200.00
0005434138883	11969	Economy	3200.00
0005434139101	11969	Economy	3200.00
0005434139134	11969	Economy	3200.00
0005434138901	11969	Economy	3200.00
0005434138806	11969	Economy	3200.00
0005434138993	11969	Economy	3200.00
0005434139191	11969	Economy	3200.00
0005434138992	11969	Economy	3200.00
0005434139148	11969	Economy	3200.00
0005434139038	11969	Economy	3200.00
0005434139042	11969	Economy	3200.00
0005434138583	11969	Economy	3200.00
0005434138873	11969	Economy	3200.00
0005434138908	11969	Economy	3200.00
0005434138909	11969	Economy	3200.00
0005434139085	11969	Economy	3200.00
0005434138749	11969	Economy	3200.00
0005434139014	11969	Economy	3200.00
0005434138696	11969	Economy	3200.00
0005434139166	11969	Economy	3200.00
0005434138731	11969	Economy	3200.00
0005434138770	11969	Economy	3200.00
0005434138817	11969	Economy	3200.00
0005434138798	11969	Economy	3200.00
0005434138911	11969	Economy	3200.00
0005434139032	11969	Economy	3200.00
0005434138967	11969	Economy	3200.00
0005434138931	11969	Economy	3200.00
0005434138818	11969	Economy	3200.00
0005434138632	11969	Economy	3200.00
0005434139018	11969	Economy	3200.00
0005434138910	11969	Economy	3200.00
0005434138758	11969	Economy	3200.00
0005434138726	11969	Economy	3200.00
0005434139079	11969	Economy	3200.00
0005434138915	11969	Economy	3200.00
0005434138698	11969	Economy	3200.00
0005434138991	11969	Economy	3200.00
0005434139165	11969	Economy	3200.00
0005434138937	11969	Economy	3200.00
0005434139116	11969	Economy	3200.00
0005434139109	11969	Economy	3200.00
0005434138663	11969	Economy	3200.00
0005434139102	11969	Economy	3200.00
0005434139103	11969	Economy	3200.00
0005434139086	11969	Economy	3200.00
0005434138849	11969	Economy	3200.00
0005434138946	11969	Economy	3200.00
0005434139087	11969	Economy	3200.00
0005434138769	11969	Economy	3200.00
0005434139033	11969	Economy	3200.00
0005434139613	28768	Business	9700.00
0005434139610	28768	Business	9700.00
0005434139603	28768	Business	9700.00
0005434139619	28768	Business	9700.00
0005434139584	28768	Business	9700.00
0005434139586	28768	Business	9700.00
0005434139565	28768	Business	9700.00
0005434139615	28768	Business	9700.00
0005434139611	28768	Business	9700.00
0005434139596	28768	Business	9700.00
0005434139572	28768	Business	9700.00
0005434139595	28768	Economy	3200.00
0005434139563	28768	Economy	3200.00
0005434139564	28768	Economy	3200.00
0005434139594	28768	Economy	3200.00
0005434139559	28768	Economy	3200.00
0005434139550	28768	Economy	3200.00
0005434139591	28768	Economy	3200.00
0005434139573	28768	Economy	3200.00
0005434139612	28768	Economy	3500.00
0005434139592	28768	Economy	3500.00
0005434139558	28768	Economy	3500.00
0005434139587	28768	Economy	3500.00
0005434139605	28768	Economy	3500.00
0005434139571	28768	Economy	3200.00
0005434139602	28768	Economy	3200.00
0005434139556	28768	Economy	3200.00
0005434139581	28768	Economy	3200.00
0005434139553	28768	Economy	3200.00
0005434139590	28768	Economy	3200.00
0005434139555	28768	Economy	3200.00
0005434139585	28768	Economy	3200.00
0005434139593	28768	Economy	3200.00
0005434139568	28768	Economy	3200.00
0005434139548	28768	Economy	3200.00
0005434139601	28768	Economy	3200.00
0005434139560	28768	Economy	3200.00
0005434139621	28768	Economy	3200.00
0005434139570	28768	Economy	3200.00
0005434139569	28768	Economy	3200.00
0005434139599	28768	Economy	3200.00
0005434139547	28768	Economy	3200.00
0005434139606	28768	Economy	3200.00
0005434139575	28768	Economy	3200.00
0005434139579	28768	Economy	3200.00
0005434139566	28768	Economy	3200.00
0005434139551	28768	Economy	3200.00
0005434139614	28768	Economy	3200.00
0005434139561	28768	Economy	3200.00
0005434139608	28768	Economy	3200.00
0005434139557	28768	Economy	3200.00
0005434139617	28768	Economy	3200.00
0005434139567	28768	Economy	3200.00
0005434139597	28768	Economy	3200.00
0005434139546	28768	Economy	3200.00
0005434139578	28768	Economy	3200.00
0005434139580	28768	Economy	3200.00
0005434139618	28768	Economy	3200.00
0005434139552	28768	Economy	3200.00
0005434139583	28768	Economy	3200.00
0005434139607	28768	Economy	3200.00
0005434139589	28768	Economy	3200.00
0005434139582	28768	Economy	3200.00
0005434139616	28768	Economy	3200.00
0005434139554	28768	Economy	3200.00
0005434139549	28768	Economy	3200.00
0005434139574	28768	Economy	3200.00
0005434139609	28768	Economy	3200.00
0005434139600	28768	Economy	3200.00
0005434139576	28768	Economy	3200.00
0005434139598	28768	Economy	3200.00
0005434139620	28768	Economy	3200.00
0005434139604	28768	Economy	3200.00
0005434139588	28768	Economy	3200.00
0005434139562	28768	Economy	3200.00
0005434139577	28768	Economy	3200.00
0005434516098	19093	Economy	23600.00
0005434190443	19093	Economy	23600.00
0005434190440	19093	Economy	23600.00
0005434190445	19093	Economy	23600.00
0005434516095	19093	Economy	23600.00
0005434516089	19093	Economy	23600.00
0005434513602	19093	Economy	23600.00
0005434516091	19093	Economy	23600.00
0005434516096	19093	Economy	23600.00
0005434190442	19093	Economy	23600.00
0005434513600	19093	Economy	23600.00
0005434190441	19093	Economy	23600.00
0005434516094	19093	Economy	23600.00
0005434513601	19093	Economy	23600.00
0005434516101	19093	Economy	23600.00
0005434516097	19093	Economy	23600.00
0005434513610	19093	Economy	23600.00
0005434190444	19093	Economy	23600.00
0005434516090	19093	Economy	23600.00
0005433539032	6825	Economy	10900.00
0005433539027	6825	Economy	10900.00
0005433539029	6825	Economy	9900.00
0005433539028	6825	Economy	9900.00
0005433539030	6825	Economy	9900.00
0005435259801	6825	Economy	9900.00
0005435259794	6825	Economy	9900.00
0005435259798	6825	Economy	9900.00
0005433534538	6825	Economy	9900.00
0005435259813	6825	Economy	9900.00
0005435259804	6825	Economy	9900.00
0005433539031	6825	Economy	9900.00
0005433539033	6825	Economy	9900.00
0005435259805	6825	Economy	9900.00
0005435259800	6825	Economy	9900.00
0005433534537	6825	Economy	9900.00
0005433539026	6825	Economy	9900.00
0005433538950	25021	Economy	10900.00
0005433538952	25021	Economy	10900.00
0005433538954	25021	Economy	10900.00
0005433538958	25021	Economy	9900.00
0005433534518	25021	Economy	9900.00
0005435259836	25021	Economy	9900.00
0005433538955	25021	Economy	9900.00
0005433538949	25021	Economy	9900.00
0005435259837	25021	Economy	9900.00
0005433538951	25021	Economy	9900.00
0005433538948	25021	Economy	9900.00
0005433538957	25021	Economy	9900.00
0005433538931	25021	Economy	9900.00
0005435259838	25021	Economy	9900.00
0005433538956	25021	Economy	9900.00
0005435259840	25021	Economy	9900.00
0005433538976	25021	Economy	9900.00
0005433538953	25021	Economy	9900.00
0005433538917	25021	Economy	9900.00
0005435259839	25021	Economy	9900.00
0005433538977	25021	Economy	9900.00
0005432922569	794	Economy	16100.00
0005433512111	794	Economy	14600.00
0005433512106	794	Economy	14600.00
0005433512110	794	Economy	14600.00
0005433512109	794	Economy	14600.00
0005433512107	794	Economy	14600.00
0005433512104	794	Economy	14600.00
0005433512108	794	Economy	14600.00
0005432922566	794	Economy	14600.00
0005433512105	794	Economy	14600.00
0005432922570	794	Economy	14600.00
0005433512103	794	Economy	14600.00
0005433512083	16138	Economy	16100.00
0005433512065	16138	Economy	14600.00
0005433512066	16138	Economy	14600.00
0005433512031	16138	Economy	14600.00
0005432922601	16138	Economy	14600.00
0005432922602	16138	Economy	14600.00
0005433512082	16138	Economy	14600.00
0005433512034	16138	Economy	14600.00
0005433512035	16138	Economy	14600.00
0005432922600	16138	Economy	14600.00
0005433512081	16138	Economy	14600.00
0005435852601	4035	Economy	13500.00
0005435852602	4035	Economy	12300.00
0005433475783	4035	Economy	12300.00
0005435852604	4035	Economy	12300.00
0005433475787	4035	Economy	12300.00
0005433475788	4035	Economy	12300.00
0005433475781	4035	Economy	12300.00
0005433475789	4035	Economy	12300.00
0005433475784	4035	Economy	12300.00
0005433475782	4035	Economy	12300.00
0005433475785	4035	Economy	12300.00
0005433475786	4035	Economy	12300.00
0005435697856	3681	Economy	7900.00
0005435697875	3681	Economy	7900.00
0005435697851	3681	Economy	7900.00
0005435697857	3681	Economy	7200.00
0005435697848	3681	Economy	7200.00
0005435697873	3681	Economy	7200.00
0005434950612	3681	Economy	7200.00
0005434950615	3681	Economy	7200.00
0005435916192	3681	Economy	7200.00
0005434950613	3681	Economy	7200.00
0005435697872	3681	Economy	7200.00
0005435697859	3681	Economy	7200.00
0005435916198	3681	Economy	7200.00
0005435935062	3681	Economy	7200.00
0005435697849	3681	Economy	7200.00
0005435697866	3681	Economy	7200.00
0005435697876	3681	Economy	7200.00
0005435697870	3681	Economy	7200.00
0005435697871	3681	Economy	7200.00
0005435697854	3681	Economy	7200.00
0005435697850	3681	Economy	7200.00
0005435697863	3681	Economy	7200.00
0005435697868	3681	Economy	7200.00
0005435916199	3681	Economy	7200.00
0005435916200	3681	Economy	7200.00
0005435916201	3681	Economy	7200.00
0005435697874	3681	Economy	7200.00
0005435697864	3681	Economy	7200.00
0005435697852	3681	Economy	7200.00
0005435697861	3681	Economy	7200.00
0005434950614	3681	Economy	7200.00
0005435697862	3681	Economy	7200.00
0005435916197	3681	Economy	7200.00
0005435697858	3681	Economy	7200.00
0005435697865	3681	Economy	7200.00
0005435697867	3681	Economy	7200.00
0005435697869	3681	Economy	7200.00
0005435697877	3681	Economy	7200.00
0005435697860	3681	Economy	7200.00
0005435697855	3681	Economy	7200.00
0005434950611	3681	Economy	7200.00
0005435697853	3681	Economy	7200.00
0005435935075	3681	Economy	7200.00
0005435935098	16303	Economy	7900.00
0005435697564	16303	Economy	7200.00
0005435697491	16303	Economy	7200.00
0005435697610	16303	Economy	7200.00
0005435916220	16303	Economy	7200.00
0005434950588	16303	Economy	7200.00
0005435697586	16303	Economy	7200.00
0005435916218	16303	Economy	7200.00
0005435697671	16303	Economy	7200.00
0005435916217	16303	Economy	7200.00
0005434950578	16303	Economy	7200.00
0005435697611	16303	Economy	7200.00
0005434950565	16303	Economy	7200.00
0005435697625	16303	Economy	7200.00
0005435697716	16303	Economy	7200.00
0005435697630	16303	Economy	7200.00
0005435697668	16303	Economy	7200.00
0005435697562	16303	Economy	7200.00
0005435697591	16303	Economy	7200.00
0005435697629	16303	Economy	7200.00
0005435935095	16303	Economy	7200.00
0005434950573	16303	Economy	7200.00
0005435935096	16303	Economy	7200.00
0005435916219	16303	Economy	7200.00
0005435935097	16303	Economy	7200.00
0005435697596	16303	Economy	7200.00
0005435697563	16303	Economy	7200.00
0005435697669	16303	Economy	7200.00
0005435697612	16303	Economy	7200.00
0005434950579	16303	Economy	7200.00
0005435697626	16303	Economy	7200.00
0005435697565	16303	Economy	7200.00
0005435697490	16303	Economy	7200.00
0005432609808	3940	Economy	21300.00
0005434604962	3940	Economy	21300.00
0005433519544	3940	Economy	21300.00
0005432609810	3940	Economy	19300.00
0005434604963	3940	Economy	19300.00
0005433519543	3940	Economy	19300.00
0005432609806	3940	Economy	19300.00
0005432607644	3940	Economy	19300.00
0005435853631	3940	Economy	19300.00
0005432609807	3940	Economy	19300.00
0005434604964	3940	Economy	19300.00
0005434606887	3940	Economy	19300.00
0005434606889	3940	Economy	19300.00
0005432609809	3940	Economy	19300.00
0005433519542	3940	Economy	19300.00
0005434606888	3940	Economy	19300.00
0005432607645	3940	Economy	19300.00
0005435841482	3940	Economy	19300.00
0005435853628	3940	Economy	19300.00
0005434604965	3940	Economy	19300.00
0005432607643	3940	Economy	19300.00
0005434606890	3940	Economy	19300.00
0005435853647	22046	Economy	21300.00
0005434606839	22046	Economy	21300.00
0005434606841	22046	Economy	19300.00
0005433519516	22046	Economy	19300.00
0005434606850	22046	Economy	19300.00
0005433519492	22046	Economy	19300.00
0005434606848	22046	Economy	19300.00
0005435853645	22046	Economy	19300.00
0005433519525	22046	Economy	19300.00
0005433519493	22046	Economy	19300.00
0005435853646	22046	Economy	19300.00
0005434606863	22046	Economy	19300.00
0005433519519	22046	Economy	19300.00
0005434606849	22046	Economy	19300.00
0005434606840	22046	Economy	19300.00
0005433519498	22046	Economy	19300.00
0005433519505	22046	Economy	19300.00
0005433519506	22046	Economy	19300.00
0005433349049	679	Economy	3700.00
0005435628790	679	Economy	3700.00
0005433349036	679	Economy	3700.00
0005433349014	679	Economy	3700.00
0005435628789	679	Economy	3700.00
0005433349067	679	Economy	3700.00
0005433349044	679	Economy	3700.00
0005435628791	679	Economy	3700.00
0005433349037	679	Economy	3700.00
0005433349066	679	Economy	3700.00
0005433349045	679	Economy	3700.00
0005435628788	679	Economy	3700.00
0005433349098	15881	Economy	3700.00
0005433349099	15881	Economy	3700.00
0005435628760	15881	Economy	3700.00
0005433349097	15881	Economy	3700.00
0005433349100	15881	Economy	3700.00
0005435628756	15881	Economy	3700.00
0005435628757	15881	Economy	3700.00
0005433349095	15881	Economy	3700.00
0005433349096	15881	Economy	3700.00
0005435628759	15881	Economy	3700.00
0005433158148	17261	Economy	7100.00
0005434445282	17261	Economy	7100.00
0005434445285	17261	Economy	7100.00
0005434446558	17261	Economy	7100.00
0005433159335	17261	Economy	7100.00
0005434445284	17261	Economy	7100.00
0005433158152	17261	Economy	7100.00
0005434445283	17261	Economy	7100.00
0005434445286	17261	Economy	7100.00
0005433158147	17261	Economy	7100.00
0005434446559	17261	Economy	7100.00
0005433159336	17261	Economy	7100.00
0005434445272	17619	Economy	7100.00
0005433159356	17619	Economy	7100.00
0005434445267	17619	Economy	7100.00
0005433159355	17619	Economy	7100.00
0005434445257	17619	Economy	7100.00
0005434445268	17619	Economy	7100.00
0005433159354	17619	Economy	7100.00
0005433158196	17619	Economy	7100.00
0005434445266	17619	Economy	7100.00
0005435383184	7896	Economy	5900.00
0005435133085	7896	Economy	5900.00
0005435383227	7896	Economy	5900.00
0005435133074	7896	Economy	5400.00
0005435383198	7896	Economy	5400.00
0005435133075	7896	Economy	5400.00
0005435383185	7896	Economy	5400.00
0005435133081	7896	Economy	5400.00
0005435133079	7896	Economy	5400.00
0005435133078	7896	Economy	5400.00
0005435133083	7896	Economy	5400.00
0005435133076	7896	Economy	5400.00
0005435383197	7896	Economy	5400.00
0005435383183	7896	Economy	5400.00
0005435133077	7896	Economy	5400.00
0005435133082	7896	Economy	5400.00
0005435133084	7896	Economy	5400.00
0005435133080	7896	Economy	5400.00
0005435383252	33087	Economy	5400.00
0005435383254	33087	Economy	5400.00
0005435383249	33087	Economy	5400.00
0005435133033	33087	Economy	5400.00
0005435132982	33087	Economy	5400.00
0005435132948	33087	Economy	5400.00
0005435132967	33087	Economy	5400.00
0005435133008	33087	Economy	5400.00
0005435133007	33087	Economy	5400.00
0005435383251	33087	Economy	5400.00
0005435133022	33087	Economy	5400.00
0005435383250	33087	Economy	5400.00
0005435132999	33087	Economy	5400.00
0005435383253	33087	Economy	5400.00
0005435132981	33087	Economy	5400.00
0005435133000	33087	Economy	5400.00
0005435383248	33087	Economy	5400.00
0005435160511	7508	Economy	13800.00
0005435160507	7508	Economy	13800.00
0005435390327	7508	Economy	12500.00
0005435390297	7508	Economy	12500.00
0005435160509	7508	Economy	12500.00
0005435160506	7508	Economy	12500.00
0005435390302	7508	Economy	12500.00
0005435390281	7508	Economy	12500.00
0005435160508	7508	Economy	12500.00
0005435160504	7508	Economy	12500.00
0005435390309	7508	Economy	12500.00
0005435160512	7508	Economy	12500.00
0005435390303	7508	Economy	12500.00
0005435160513	7508	Economy	12500.00
0005435160515	7508	Economy	12500.00
0005435160505	7508	Economy	12500.00
0005435390308	7508	Economy	12500.00
0005435390328	7508	Economy	12500.00
0005435390304	7508	Economy	12500.00
0005435390334	7508	Economy	12500.00
0005435390329	7508	Economy	12500.00
0005435160514	7508	Economy	12500.00
0005435390294	7508	Economy	12500.00
0005435160510	7508	Economy	12500.00
0005435160418	29557	Economy	13800.00
0005435390367	29557	Economy	12500.00
0005435160458	29557	Economy	12500.00
0005435390369	29557	Economy	12500.00
0005435160453	29557	Economy	12500.00
0005435160427	29557	Economy	12500.00
0005435160426	29557	Economy	12500.00
0005435160421	29557	Economy	12500.00
0005435160425	29557	Economy	12500.00
0005435160420	29557	Economy	12500.00
0005435390372	29557	Economy	12500.00
0005435390370	29557	Economy	12500.00
0005435390368	29557	Economy	12500.00
0005435160396	29557	Economy	12500.00
0005435160419	29557	Economy	12500.00
0005435160370	29557	Economy	12500.00
0005435390371	29557	Economy	12500.00
0005435160424	29557	Economy	12500.00
0005432394152	18479	Economy	4900.00
0005432394150	18479	Economy	4900.00
0005432394151	18479	Economy	4900.00
0005432394141	18479	Economy	4900.00
0005435178523	18479	Economy	4900.00
0005432394137	18479	Economy	4900.00
0005435178524	18479	Economy	4900.00
0005432394138	18479	Economy	4900.00
0005432398225	18479	Economy	4900.00
0005435178522	18479	Economy	4900.00
0005432394156	18479	Economy	4900.00
0005432394143	18479	Economy	4900.00
0005432398263	27132	Economy	4900.00
0005432400191	27132	Economy	4900.00
0005432398261	27132	Economy	4900.00
0005435178507	27132	Economy	4900.00
0005435179402	27132	Economy	4900.00
0005432398262	27132	Economy	4900.00
0005432400190	27132	Economy	4900.00
0005432400188	27132	Economy	4900.00
0005432398264	27132	Economy	4900.00
0005432400189	27132	Economy	4900.00
0005434191287	9698	Economy	4400.00
0005434552869	9698	Economy	4400.00
0005434552870	9698	Economy	4400.00
0005434552871	9698	Economy	4400.00
0005434552874	9698	Economy	4400.00
0005434552873	9698	Economy	4400.00
0005434552872	9698	Economy	4400.00
0005435104084	6551	Business	48400.00
0005435104081	6551	Business	48400.00
0005435104073	6551	Business	48400.00
0005434504903	6551	Business	48400.00
0005434504889	6551	Business	48400.00
0005435104091	6551	Business	48400.00
0005434504907	6551	Business	48400.00
0005435104076	6551	Business	48400.00
0005434504877	6551	Economy	16100.00
0005434504892	6551	Economy	16100.00
0005435104085	6551	Economy	16100.00
0005434504870	6551	Economy	16100.00
0005434504897	6551	Economy	16100.00
0005435104090	6551	Economy	17800.00
0005434504868	6551	Economy	17800.00
0005435104088	6551	Economy	17800.00
0005434504891	6551	Economy	17800.00
0005434504905	6551	Economy	17800.00
0005435104078	6551	Economy	16100.00
0005434504879	6551	Economy	16100.00
0005435104072	6551	Economy	16100.00
0005434504900	6551	Economy	16100.00
0005435104080	6551	Economy	16100.00
0005434504871	6551	Economy	16100.00
0005434504869	6551	Economy	16100.00
0005435104075	6551	Economy	16100.00
0005434504867	6551	Economy	16100.00
0005435104089	6551	Economy	16100.00
0005434504902	6551	Economy	16100.00
0005434504896	6551	Economy	16100.00
0005434504895	6551	Economy	16100.00
0005434504890	6551	Economy	16100.00
0005434504884	6551	Economy	16100.00
0005434504898	6551	Economy	16100.00
0005434504872	6551	Economy	16100.00
0005434504874	6551	Economy	16100.00
0005435104077	6551	Economy	16100.00
0005434504885	6551	Economy	16100.00
0005434504881	6551	Economy	16100.00
0005435104086	6551	Economy	16100.00
0005434504878	6551	Economy	16100.00
0005434504886	6551	Economy	16100.00
0005434504904	6551	Economy	16100.00
0005434504873	6551	Economy	16100.00
0005435104074	6551	Economy	16100.00
0005434504883	6551	Economy	16100.00
0005434504893	6551	Economy	16100.00
0005434504899	6551	Economy	16100.00
0005435104082	6551	Economy	16100.00
0005434504894	6551	Economy	16100.00
0005434504880	6551	Economy	16100.00
0005434504875	6551	Economy	16100.00
0005435104087	6551	Economy	16100.00
0005434504876	6551	Economy	16100.00
0005434504901	6551	Economy	16100.00
0005435104083	6551	Economy	16100.00
0005435104079	6551	Economy	16100.00
0005434504882	6551	Economy	16100.00
0005434504888	6551	Economy	16100.00
0005434504887	6551	Economy	16100.00
0005434504906	6551	Economy	16100.00
0005434504471	22661	Business	48400.00
0005434504374	22661	Business	48400.00
0005434504496	22661	Business	48400.00
0005434504387	22661	Business	48400.00
0005434504472	22661	Economy	16100.00
0005434504466	22661	Economy	16100.00
0005434504505	22661	Economy	16100.00
0005434504375	22661	Economy	17800.00
0005434504328	22661	Economy	17800.00
0005434504298	22661	Economy	16100.00
0005434504295	22661	Economy	16100.00
0005434504385	22661	Economy	16100.00
0005435103962	22661	Economy	16100.00
0005434504509	22661	Economy	16100.00
0005434504477	22661	Economy	16100.00
0005434504497	22661	Economy	16100.00
0005434504537	22661	Economy	16100.00
0005434504340	22661	Economy	16100.00
0005434504301	22661	Economy	16100.00
0005435103960	22661	Economy	16100.00
0005434504410	22661	Economy	16100.00
0005434504467	22661	Economy	16100.00
0005434504464	22661	Economy	16100.00
0005435103961	22661	Economy	16100.00
0005434504552	22661	Economy	16100.00
0005434504468	22661	Economy	16100.00
0005434504401	22661	Economy	16100.00
0005434504511	22661	Economy	16100.00
0005434504294	22661	Economy	16100.00
0005434504508	22661	Economy	16100.00
0005434504465	22661	Economy	16100.00
0005434504296	22661	Economy	16100.00
0005434504411	22661	Economy	16100.00
0005434504510	22661	Economy	16100.00
0005434504451	22661	Economy	16100.00
0005434504386	22661	Economy	16100.00
0005434504553	22661	Economy	16100.00
0005433368378	1668	Business	50000.00
0005435653895	1668	Business	50000.00
0005435653891	1668	Business	50000.00
0005433368260	1668	Business	50000.00
0005435653900	1668	Business	50000.00
0005435653882	1668	Business	50000.00
0005435653901	1668	Business	50000.00
0005433368257	1668	Business	50000.00
0005433368404	1668	Business	50000.00
0005433368248	1668	Business	50000.00
0005435653873	1668	Economy	16700.00
0005435653870	1668	Economy	16700.00
0005435653876	1668	Economy	16700.00
0005433368053	1668	Economy	16700.00
0005433368298	1668	Economy	16700.00
0005433368347	1668	Economy	16700.00
0005433368398	1668	Economy	16700.00
0005433368258	1668	Economy	16700.00
0005435653903	1668	Economy	16700.00
0005433368219	1668	Economy	16700.00
0005433368313	1668	Economy	18300.00
0005435653879	1668	Economy	18300.00
0005435653902	1668	Economy	18300.00
0005435653871	1668	Economy	18300.00
0005433368147	1668	Economy	18300.00
0005433368096	1668	Economy	16700.00
0005435653863	1668	Economy	16700.00
0005435653862	1668	Economy	16700.00
0005433368501	1668	Economy	16700.00
0005433368297	1668	Economy	16700.00
0005435653899	1668	Economy	16700.00
0005435653878	1668	Economy	16700.00
0005435653892	1668	Economy	16700.00
0005433368261	1668	Economy	16700.00
0005433368252	1668	Economy	16700.00
0005433368203	1668	Economy	16700.00
0005435653897	1668	Economy	16700.00
0005433368306	1668	Economy	16700.00
0005433368098	1668	Economy	16700.00
0005433368324	1668	Economy	16700.00
0005435653889	1668	Economy	16700.00
0005435653859	1668	Economy	16700.00
0005435653885	1668	Economy	16700.00
0005435653865	1668	Economy	16700.00
0005435653866	1668	Economy	16700.00
0005435653890	1668	Economy	16700.00
0005435653877	1668	Economy	16700.00
0005433368312	1668	Economy	16700.00
0005433368148	1668	Economy	16700.00
0005435653894	1668	Economy	16700.00
0005435653898	1668	Economy	16700.00
0005433368217	1668	Economy	16700.00
0005433368251	1668	Economy	16700.00
0005433368387	1668	Economy	16700.00
0005435653881	1668	Economy	16700.00
0005433368227	1668	Economy	16700.00
0005435653883	1668	Economy	16700.00
0005433368097	1668	Economy	16700.00
0005435653860	1668	Economy	16700.00
0005435653905	1668	Economy	16700.00
0005435653869	1668	Economy	16700.00
0005435653864	1668	Economy	16700.00
0005435653884	1668	Economy	16700.00
0005433368386	1668	Economy	16700.00
0005435653893	1668	Economy	16700.00
0005435653858	1668	Economy	16700.00
0005435653874	1668	Economy	16700.00
0005435653856	1668	Economy	16700.00
0005435653875	1668	Economy	16700.00
0005433368305	1668	Economy	16700.00
0005435653867	1668	Economy	16700.00
0005433368388	1668	Economy	16700.00
0005435653868	1668	Economy	16700.00
0005433368502	1668	Economy	16700.00
0005435653886	1668	Economy	16700.00
0005433368339	1668	Economy	16700.00
0005433368379	1668	Economy	16700.00
0005433368052	1668	Economy	16700.00
0005433368259	1668	Economy	16700.00
0005435653887	1668	Economy	16700.00
0005433368241	1668	Economy	16700.00
0005435653872	1668	Economy	16700.00
0005435653888	1668	Economy	16700.00
0005435653880	1668	Economy	16700.00
0005433368082	1668	Economy	16700.00
0005435653904	1668	Economy	16700.00
0005435653861	1668	Economy	16700.00
0005435653896	1668	Economy	16700.00
0005435653857	1668	Economy	16700.00
0005433368155	1668	Economy	16700.00
0005435653365	21674	Business	50000.00
0005433368569	21674	Business	50000.00
0005433368562	21674	Business	50000.00
0005435653412	21674	Business	50000.00
0005435653490	21674	Business	50000.00
0005435653361	21674	Business	50000.00
0005435653258	21674	Business	50000.00
0005435653271	21674	Business	50000.00
0005435653326	21674	Business	50000.00
0005433368575	21674	Business	50000.00
0005435653413	21674	Business	50000.00
0005435653323	21674	Business	50000.00
0005435653440	21674	Economy	16700.00
0005435653389	21674	Economy	16700.00
0005433368596	21674	Economy	16700.00
0005435653424	21674	Economy	16700.00
0005433368572	21674	Economy	16700.00
0005435653529	21674	Economy	16700.00
0005435653489	21674	Economy	16700.00
0005435653418	21674	Economy	16700.00
0005435653386	21674	Economy	16700.00
0005433368593	21674	Economy	16700.00
0005433368578	21674	Economy	18300.00
0005433368568	21674	Economy	18300.00
0005433368597	21674	Economy	18300.00
0005435653325	21674	Economy	18300.00
0005433368586	21674	Economy	18300.00
0005435653422	21674	Economy	16700.00
0005435653310	21674	Economy	16700.00
0005433368599	21674	Economy	16700.00
0005435653482	21674	Economy	16700.00
0005433368581	21674	Economy	16700.00
0005433368566	21674	Economy	16700.00
0005435653309	21674	Economy	16700.00
0005435653506	21674	Economy	16700.00
0005435653477	21674	Economy	16700.00
0005435653461	21674	Economy	16700.00
0005433368585	21674	Economy	16700.00
0005433368600	21674	Economy	16700.00
0005435653543	21674	Economy	16700.00
0005433368580	21674	Economy	16700.00
0005433368587	21674	Economy	16700.00
0005433368565	21674	Economy	16700.00
0005435653303	21674	Economy	16700.00
0005433368563	21674	Economy	16700.00
0005435653428	21674	Economy	16700.00
0005435653542	21674	Economy	16700.00
0005433368582	21674	Economy	16700.00
0005433368595	21674	Economy	16700.00
0005435653528	21674	Economy	16700.00
0005433368592	21674	Economy	16700.00
0005435653429	21674	Economy	16700.00
0005435653362	21674	Economy	16700.00
0005435653369	21674	Economy	16700.00
0005433368574	21674	Economy	16700.00
0005435653483	21674	Economy	16700.00
0005433368589	21674	Economy	16700.00
0005433368571	21674	Economy	16700.00
0005433368588	21674	Economy	16700.00
0005433368594	21674	Economy	16700.00
0005433368576	21674	Economy	16700.00
0005433368564	21674	Economy	16700.00
0005433368570	21674	Economy	16700.00
0005435653423	21674	Economy	16700.00
0005433368598	21674	Economy	16700.00
0005435653530	21674	Economy	16700.00
0005435653505	21674	Economy	16700.00
0005435653287	21674	Economy	16700.00
0005435653270	21674	Economy	16700.00
0005433368590	21674	Economy	16700.00
0005435653409	21674	Economy	16700.00
0005433368591	21674	Economy	16700.00
0005435653520	21674	Economy	16700.00
0005435653446	21674	Economy	16700.00
0005435653390	21674	Economy	16700.00
0005433368577	21674	Economy	16700.00
0005433368573	21674	Economy	16700.00
0005433368584	21674	Economy	16700.00
0005435653410	21674	Economy	16700.00
0005433368579	21674	Economy	16700.00
0005435653436	21674	Economy	16700.00
0005435653475	21674	Economy	16700.00
0005435653360	21674	Economy	16700.00
0005433368567	21674	Economy	16700.00
0005433368583	21674	Economy	16700.00
0005435788818	4181	Business	21500.00
0005433986838	4181	Business	21500.00
0005433986844	4181	Business	21500.00
0005433986825	4181	Business	21500.00
0005433986809	4181	Business	21500.00
0005433986805	4181	Business	21500.00
0005433986839	4181	Economy	7200.00
0005433986831	4181	Economy	7200.00
0005433986830	4181	Economy	7200.00
0005433986834	4181	Economy	7200.00
0005433986829	4181	Economy	7900.00
0005433986820	4181	Economy	7900.00
0005433986813	4181	Economy	7900.00
0005433986817	4181	Economy	7900.00
0005433986826	4181	Economy	7200.00
0005433986832	4181	Economy	7200.00
0005433986822	4181	Economy	7200.00
0005433986835	4181	Economy	7200.00
0005433986843	4181	Economy	7200.00
0005433986833	4181	Economy	7200.00
0005433986816	4181	Economy	7200.00
0005433986802	4181	Economy	7200.00
0005433986808	4181	Economy	7200.00
0005433986842	4181	Economy	7200.00
0005433986804	4181	Economy	7200.00
0005433986801	4181	Economy	7200.00
0005433986811	4181	Economy	7200.00
0005433986812	4181	Economy	7200.00
0005433986837	4181	Economy	7200.00
0005433986806	4181	Economy	7200.00
0005433986836	4181	Economy	7200.00
0005433986823	4181	Economy	7200.00
0005433986828	4181	Economy	7200.00
0005433986815	4181	Economy	7200.00
0005433986807	4181	Economy	7200.00
0005433986810	4181	Economy	7200.00
0005435788819	4181	Economy	7200.00
0005433986814	4181	Economy	7200.00
0005433986821	4181	Economy	7200.00
0005433986840	4181	Economy	7200.00
0005433986824	4181	Economy	7200.00
0005433986827	4181	Economy	7200.00
0005433986803	4181	Economy	7200.00
0005433986841	4181	Economy	7200.00
0005433986818	4181	Economy	7200.00
0005433986819	4181	Economy	7200.00
0005433986082	25673	Business	21500.00
0005433986255	25673	Business	21500.00
0005433986440	25673	Business	21500.00
0005433986393	25673	Business	21500.00
0005433986447	25673	Business	21500.00
0005435788798	25673	Business	21500.00
0005433986416	25673	Economy	7200.00
0005435788802	25673	Economy	7200.00
0005433986202	25673	Economy	7200.00
0005433986137	25673	Economy	7200.00
0005433986203	25673	Economy	7200.00
0005433986363	25673	Economy	7200.00
0005433986256	25673	Economy	7200.00
0005433986391	25673	Economy	7200.00
0005433986290	25673	Economy	7200.00
0005433986390	25673	Economy	7900.00
0005433986392	25673	Economy	7200.00
0005433986389	25673	Economy	7200.00
0005433986045	25673	Economy	7200.00
0005433986455	25673	Economy	7200.00
0005433986396	25673	Economy	7200.00
0005433986369	25673	Economy	7200.00
0005433986429	25673	Economy	7200.00
0005433986046	25673	Economy	7200.00
0005433986364	25673	Economy	7200.00
0005433986318	25673	Economy	7200.00
0005433986136	25673	Economy	7200.00
0005433986395	25673	Economy	7200.00
0005433986446	25673	Economy	7200.00
0005435788797	25673	Economy	7200.00
0005433986358	25673	Economy	7200.00
0005433986427	25673	Economy	7200.00
0005433986144	25673	Economy	7200.00
0005433986415	25673	Economy	7200.00
0005433986204	25673	Economy	7200.00
0005433986302	25673	Economy	7200.00
0005433986449	25673	Economy	7200.00
0005433986257	25673	Economy	7200.00
0005435788801	25673	Economy	7200.00
0005433986410	25673	Economy	7200.00
0005433986425	25673	Economy	7200.00
0005433986399	25673	Economy	7200.00
0005433986316	25673	Economy	7200.00
0005433986420	25673	Economy	7200.00
0005433986439	25673	Economy	7200.00
0005433986445	25673	Economy	7200.00
0005433986419	25673	Economy	7200.00
0005433986448	25673	Economy	7200.00
0005433986377	25673	Economy	7200.00
0005433986317	25673	Economy	7200.00
0005433986342	25673	Economy	7200.00
0005433460473	20241	Business	201300.00
0005433461613	20241	Business	201300.00
0005433461625	20241	Business	201300.00
0005433461624	20241	Business	201300.00
0005433461615	20241	Business	201300.00
0005433461617	20241	Business	201300.00
0005433461620	20241	Business	201300.00
0005433460463	20241	Business	201300.00
0005433460472	20241	Business	201300.00
0005433460460	20241	Business	201300.00
0005433460470	20241	Economy	67100.00
0005433460467	20241	Economy	67100.00
0005433461618	20241	Economy	67100.00
0005433460469	20241	Economy	67100.00
0005433461626	20241	Economy	67100.00
0005433461612	20241	Economy	67100.00
0005433461614	20241	Economy	67100.00
0005433461622	20241	Economy	67100.00
0005433461616	20241	Economy	67100.00
0005433460466	20241	Economy	67100.00
0005433460465	20241	Economy	67100.00
0005433461621	20241	Economy	67100.00
0005433460462	20241	Economy	67100.00
0005433460474	20241	Economy	67100.00
0005433461623	20241	Economy	67100.00
0005433460471	20241	Economy	67100.00
0005433460468	20241	Economy	67100.00
0005433461619	20241	Economy	67100.00
0005433460464	20241	Economy	67100.00
0005433460461	20241	Economy	67100.00
0005435719582	24780	Economy	10400.00
0005435719581	24780	Economy	9400.00
0005435720152	24780	Economy	9400.00
0005435720151	24780	Economy	9400.00
0005435720153	24780	Economy	9400.00
0005434509195	21314	Economy	17000.00
0005433168445	21314	Economy	17000.00
0005433168449	21314	Economy	15500.00
0005434509217	21314	Economy	15500.00
0005434509228	21314	Economy	15500.00
0005434509242	21314	Economy	15500.00
0005434509202	21314	Economy	15500.00
0005433168450	21314	Economy	15500.00
0005434509218	21314	Economy	15500.00
0005434509229	21314	Economy	15500.00
0005434509220	21314	Economy	15500.00
0005433168448	21314	Economy	15500.00
0005434509241	21314	Economy	15500.00
0005434509240	21314	Economy	15500.00
0005433168451	21314	Economy	15500.00
0005434509221	21314	Economy	15500.00
0005433168447	21314	Economy	15500.00
0005434509194	21314	Economy	15500.00
0005434509219	21314	Economy	15500.00
0005434509246	21314	Economy	15500.00
0005434509226	21314	Economy	15500.00
0005433168446	21314	Economy	15500.00
0005434509227	21314	Economy	15500.00
0005433168452	21314	Economy	15500.00
0005432665286	17814	Business	18000.00
0005432655661	17814	Business	18000.00
0005432655624	17814	Business	18000.00
0005432869654	17814	Business	18000.00
0005432869649	17814	Business	18000.00
0005432655653	17814	Business	18000.00
0005432655643	17814	Business	18000.00
0005432869650	17814	Economy	6000.00
0005432657479	17814	Economy	6000.00
0005432655634	17814	Economy	6000.00
0005432655671	17814	Economy	6000.00
0005432655635	17814	Economy	6000.00
0005432665301	17814	Economy	6000.00
0005434151760	17814	Economy	6600.00
0005432663068	17814	Economy	6000.00
0005432655626	17814	Economy	6000.00
0005432661942	17814	Economy	6000.00
0005432655700	17814	Economy	6000.00
0005432655672	17814	Economy	6000.00
0005432655662	17814	Economy	6000.00
0005434151759	17814	Economy	6000.00
0005432869651	17814	Economy	6000.00
0005432655633	17814	Economy	6000.00
0005432665294	17814	Economy	6000.00
0005432665293	17814	Economy	6000.00
0005432869648	17814	Economy	6000.00
0005432665287	17814	Economy	6000.00
0005432661943	17814	Economy	6000.00
0005432665300	17814	Economy	6000.00
0005432655644	17814	Economy	6000.00
0005432663048	17814	Economy	6000.00
0005432659725	17814	Economy	6000.00
0005432869652	17814	Economy	6000.00
0005434151761	17814	Economy	6000.00
0005432663058	17814	Economy	6000.00
0005432869653	17814	Economy	6000.00
0005432666423	17814	Economy	6000.00
0005432869569	26296	Business	18000.00
0005432665311	26296	Business	18000.00
0005432655731	26296	Business	18000.00
0005432660855	26296	Business	18000.00
0005432655735	26296	Economy	6000.00
0005432655740	26296	Economy	6000.00
0005432660854	26296	Economy	6000.00
0005432655739	26296	Economy	6600.00
0005432655741	26296	Economy	6600.00
0005432655733	26296	Economy	6000.00
0005432657501	26296	Economy	6000.00
0005432655734	26296	Economy	6000.00
0005432667490	26296	Economy	6000.00
0005432655730	26296	Economy	6000.00
0005432659743	26296	Economy	6000.00
0005432655736	26296	Economy	6000.00
0005432659744	26296	Economy	6000.00
0005432659741	26296	Economy	6000.00
0005432658628	26296	Economy	6000.00
0005432667489	26296	Economy	6000.00
0005432666426	26296	Economy	6000.00
0005432666424	26296	Economy	6000.00
0005432869585	26296	Economy	6000.00
0005432666425	26296	Economy	6000.00
0005432660853	26296	Economy	6000.00
0005432657502	26296	Economy	6000.00
0005432655732	26296	Economy	6000.00
0005432869584	26296	Economy	6000.00
0005432655737	26296	Economy	6000.00
0005432869570	26296	Economy	6000.00
0005432659742	26296	Economy	6000.00
0005432655742	26296	Economy	6000.00
0005432655738	26296	Economy	6000.00
0005432657503	26296	Economy	6000.00
0005432329552	3116	Business	16100.00
0005432329537	3116	Business	16100.00
0005432329580	3116	Business	16100.00
0005432329578	3116	Business	16100.00
0005432329559	3116	Business	16100.00
0005432329572	3116	Business	16100.00
0005432329550	3116	Business	16100.00
0005433439002	3116	Business	16100.00
0005432287284	3116	Business	16100.00
0005432329557	3116	Business	16100.00
0005432329534	3116	Economy	5400.00
0005432905210	3116	Economy	5400.00
0005433438993	3116	Economy	5400.00
0005432329548	3116	Economy	5400.00
0005432329561	3116	Economy	5400.00
0005432329566	3116	Economy	5400.00
0005432329535	3116	Economy	5400.00
0005433438995	3116	Economy	5400.00
0005432287286	3116	Economy	5400.00
0005433438998	3116	Economy	5400.00
0005432329565	3116	Economy	5400.00
0005432329567	3116	Economy	5400.00
0005433439001	3116	Economy	5400.00
0005432329571	3116	Economy	5400.00
0005432905177	3116	Economy	5400.00
0005432329569	3116	Economy	5400.00
0005432329570	3116	Economy	5400.00
0005432287285	3116	Economy	5400.00
0005432329560	3116	Economy	5400.00
0005432329551	3116	Economy	5400.00
0005432329558	3116	Economy	5400.00
0005432329541	3116	Economy	5400.00
0005432329545	3116	Economy	5400.00
0005432329575	3116	Economy	5400.00
0005432329562	3116	Economy	5400.00
0005433438994	3116	Economy	5400.00
0005432329577	3116	Economy	5400.00
0005432329540	3116	Economy	5400.00
0005432329553	3116	Economy	5400.00
0005432329563	3116	Economy	5400.00
0005432287282	3116	Economy	5400.00
0005432329555	3116	Economy	5400.00
0005432905211	3116	Economy	5400.00
0005432329536	3116	Economy	5400.00
0005432329556	3116	Economy	5400.00
0005432329573	3116	Economy	5400.00
0005433438999	3116	Economy	5400.00
0005432329564	3116	Economy	5400.00
0005432329579	3116	Economy	5400.00
0005432287283	3116	Economy	5400.00
0005433438997	3116	Economy	5400.00
0005432329549	3116	Economy	5400.00
0005432329546	3116	Economy	5400.00
0005432329574	3116	Economy	5400.00
0005432329543	3116	Economy	5400.00
0005432329544	3116	Economy	5400.00
0005432287287	3116	Economy	5400.00
0005432905178	3116	Economy	5400.00
0005432329547	3116	Economy	5400.00
0005432329538	3116	Economy	5400.00
0005432329568	3116	Economy	5400.00
0005432329542	3116	Economy	5400.00
0005432329539	3116	Economy	5400.00
0005433439000	3116	Economy	5400.00
0005432329576	3116	Economy	5400.00
0005432329554	3116	Economy	5400.00
0005433438996	3116	Economy	5400.00
0005432329020	31129	Business	16100.00
0005433438934	31129	Business	16100.00
0005432329152	31129	Business	16100.00
0005432328974	31129	Business	16100.00
0005432329296	31129	Economy	5400.00
0005432329004	31129	Economy	5400.00
0005432328996	31129	Economy	5400.00
0005432328972	31129	Economy	5400.00
0005432329132	31129	Economy	5400.00
0005432905229	31129	Economy	5900.00
0005432329124	31129	Economy	5900.00
0005432328938	31129	Economy	5900.00
0005432329119	31129	Economy	5900.00
0005432328988	31129	Economy	5400.00
0005432905234	31129	Economy	5400.00
0005432905230	31129	Economy	5400.00
0005432905231	31129	Economy	5400.00
0005432329005	31129	Economy	5400.00
0005432329295	31129	Economy	5400.00
0005432329178	31129	Economy	5400.00
0005432329108	31129	Economy	5400.00
0005432328973	31129	Economy	5400.00
0005432054360	31129	Economy	5400.00
0005432329123	31129	Economy	5400.00
0005432054359	31129	Economy	5400.00
0005432329106	31129	Economy	5400.00
0005432329075	31129	Economy	5400.00
0005432905235	31129	Economy	5400.00
0005432329206	31129	Economy	5400.00
0005432848860	31129	Economy	5400.00
0005432329203	31129	Economy	5400.00
0005433438953	31129	Economy	5400.00
0005432329128	31129	Economy	5400.00
0005432329002	31129	Economy	5400.00
0005433438954	31129	Economy	5400.00
0005432329127	31129	Economy	5400.00
0005432329109	31129	Economy	5400.00
0005432329092	31129	Economy	5400.00
0005432329294	31129	Economy	5400.00
0005432329021	31129	Economy	5400.00
0005432329293	31129	Economy	5400.00
0005432848858	31129	Economy	5400.00
0005433438948	31129	Economy	5400.00
0005433438917	31129	Economy	5400.00
0005432329186	31129	Economy	5400.00
0005432905233	31129	Economy	5400.00
0005432905232	31129	Economy	5400.00
0005432329131	31129	Economy	5400.00
0005432329074	31129	Economy	5400.00
0005432329018	31129	Economy	5400.00
0005433438949	31129	Economy	5400.00
0005432329298	31129	Economy	5400.00
0005432329120	31129	Economy	5400.00
0005432329056	31129	Economy	5400.00
0005432329111	31129	Economy	5400.00
0005433438935	31129	Economy	5400.00
0005432848859	31129	Economy	5400.00
0005432328987	31129	Economy	5400.00
0005432329212	31129	Economy	5400.00
0005432328939	31129	Economy	5400.00
0005432329003	31129	Economy	5400.00
0005432054358	31129	Economy	5400.00
0005432329281	31129	Economy	5400.00
0005432848861	31129	Economy	5400.00
0005432329185	31129	Economy	5400.00
0005432329183	31129	Economy	5400.00
0005432848857	31129	Economy	5400.00
0005432329078	31129	Economy	5400.00
0005433438916	31129	Economy	5400.00
0005433438955	31129	Economy	5400.00
0005432329300	31129	Economy	5400.00
0005432905236	31129	Economy	5400.00
0005435488006	6231	Business	124600.00
0005435999589	6231	Business	124600.00
0005434309996	6231	Business	124600.00
0005434310003	6231	Business	124600.00
0005434310004	6231	Business	124600.00
0005435488022	6231	Business	124600.00
0005435488072	6231	Economy	41500.00
0005435999584	6231	Economy	41500.00
0005435999582	6231	Economy	41500.00
0005435999588	6231	Economy	41500.00
0005432146237	6231	Economy	41500.00
0005435488018	6231	Economy	41500.00
0005435488048	6231	Economy	41500.00
0005435297125	6231	Economy	41500.00
0005435488035	6231	Economy	41500.00
0005435488055	6231	Economy	41500.00
0005435488044	6231	Economy	41500.00
0005435488088	6231	Economy	41500.00
0005434309994	6231	Economy	41500.00
0005435999579	6231	Economy	41500.00
0005435487992	6231	Economy	41500.00
0005435488073	6231	Economy	41500.00
0005435999587	6231	Economy	41500.00
0005435488093	6231	Economy	41500.00
0005434309998	6231	Economy	45700.00
0005435999585	6231	Economy	45700.00
0005434310001	6231	Economy	45700.00
0005434309997	6231	Economy	45700.00
0005434309993	6231	Economy	45700.00
0005435488049	6231	Economy	41500.00
0005435488034	6231	Economy	41500.00
0005435488086	6231	Economy	41500.00
0005435297126	6231	Economy	41500.00
0005435999581	6231	Economy	41500.00
0005435488019	6231	Economy	41500.00
0005435999580	6231	Economy	41500.00
0005435488021	6231	Economy	41500.00
0005434309999	6231	Economy	41500.00
0005435488079	6231	Economy	41500.00
0005435297130	6231	Economy	41500.00
0005435297132	6231	Economy	41500.00
0005435999577	6231	Economy	41500.00
0005435488033	6231	Economy	41500.00
0005435487993	6231	Economy	41500.00
0005435999578	6231	Economy	41500.00
0005435488080	6231	Economy	41500.00
0005434309995	6231	Economy	41500.00
0005434309992	6231	Economy	41500.00
0005435488092	6231	Economy	41500.00
0005435488043	6231	Economy	41500.00
0005432146238	6231	Economy	41500.00
0005435488085	6231	Economy	41500.00
0005435999583	6231	Economy	41500.00
0005434310000	6231	Economy	41500.00
0005434310002	6231	Economy	41500.00
0005435297128	6231	Economy	41500.00
0005435297131	6231	Economy	41500.00
0005435999586	6231	Economy	41500.00
0005435488042	6231	Economy	41500.00
0005435297187	19532	Business	124600.00
0005435488221	19532	Business	124600.00
0005435488225	19532	Business	124600.00
0005435488216	19532	Business	124600.00
0005435297184	19532	Business	124600.00
0005435297188	19532	Business	124600.00
0005435488209	19532	Economy	41500.00
0005434309874	19532	Economy	41500.00
0005435488212	19532	Economy	41500.00
0005435999398	19532	Economy	41500.00
0005435488217	19532	Economy	41500.00
0005435999394	19532	Economy	41500.00
0005434309850	19532	Economy	41500.00
0005435999392	19532	Economy	41500.00
0005434309883	19532	Economy	41500.00
0005435999373	19532	Economy	41500.00
0005435488228	19532	Economy	41500.00
0005434309919	19532	Economy	41500.00
0005435488227	19532	Economy	41500.00
0005435297189	19532	Economy	41500.00
0005435488219	19532	Economy	41500.00
0005435488224	19532	Economy	41500.00
0005435488218	19532	Economy	45700.00
0005434309884	19532	Economy	41500.00
0005434309790	19532	Economy	41500.00
0005435297186	19532	Economy	41500.00
0005434309840	19532	Economy	41500.00
0005435999354	19532	Economy	41500.00
0005435999370	19532	Economy	41500.00
0005435488220	19532	Economy	41500.00
0005435999355	19532	Economy	41500.00
0005435488207	19532	Economy	41500.00
0005435488211	19532	Economy	41500.00
0005435999420	19532	Economy	41500.00
0005435488215	19532	Economy	41500.00
0005435488226	19532	Economy	41500.00
0005435488210	19532	Economy	41500.00
0005434309851	19532	Economy	41500.00
0005435999422	19532	Economy	41500.00
0005435297183	19532	Economy	41500.00
0005435999421	19532	Economy	41500.00
0005435297185	19532	Economy	41500.00
0005435488214	19532	Economy	41500.00
0005435999390	19532	Economy	41500.00
0005435488213	19532	Economy	41500.00
0005435999387	19532	Economy	41500.00
0005435488222	19532	Economy	41500.00
0005435999391	19532	Economy	41500.00
0005435488223	19532	Economy	41500.00
0005435999393	19532	Economy	41500.00
0005435488208	19532	Economy	41500.00
0005433158171	17544	Economy	13600.00
0005433158168	17544	Economy	12300.00
0005433158174	17544	Economy	12300.00
0005433158169	17544	Economy	12300.00
0005434446532	17544	Economy	12300.00
0005433158170	17544	Economy	12300.00
0005434446531	17544	Economy	12300.00
0005433158172	17544	Economy	12300.00
0005433158173	17544	Economy	12300.00
0005433158175	17544	Economy	12300.00
0005435518250	1603	Business	86000.00
0005434566165	1603	Business	86000.00
0005433186206	1603	Business	86000.00
0005435518259	1603	Business	86000.00
0005435502727	1603	Business	86000.00
0005434566167	1603	Business	86000.00
0005435518260	1603	Business	86000.00
0005435502708	1603	Business	86000.00
0005434566163	1603	Business	86000.00
0005435502714	1603	Business	86000.00
0005433186197	1603	Business	86000.00
0005433186178	1603	Economy	28700.00
0005435502707	1603	Economy	28700.00
0005435502722	1603	Economy	28700.00
0005435508585	1603	Economy	28700.00
0005435518257	1603	Economy	28700.00
0005435508589	1603	Economy	28700.00
0005434566166	1603	Economy	28700.00
0005435518248	1603	Economy	28700.00
0005435518247	1603	Economy	28700.00
0005434566161	1603	Economy	31500.00
0005435502725	1603	Economy	31500.00
0005435518251	1603	Economy	31500.00
0005435508586	1603	Economy	31500.00
0005435502718	1603	Economy	31500.00
0005432291977	1603	Economy	28700.00
0005433186196	1603	Economy	28700.00
0005435518255	1603	Economy	28700.00
0005435502716	1603	Economy	28700.00
0005435502726	1603	Economy	28700.00
0005434566172	1603	Economy	28700.00
0005433186203	1603	Economy	28700.00
0005435508597	1603	Economy	28700.00
0005435508599	1603	Economy	28700.00
0005432291975	1603	Economy	28700.00
0005434566171	1603	Economy	28700.00
0005433186211	1603	Economy	28700.00
0005432291976	1603	Economy	28700.00
0005433186212	1603	Economy	28700.00
0005434566160	1603	Economy	28700.00
0005435502709	1603	Economy	28700.00
0005433186192	1603	Economy	28700.00
0005434566168	1603	Economy	28700.00
0005435518258	1603	Economy	28700.00
0005435508584	1603	Economy	28700.00
0005435508594	1603	Economy	28700.00
0005435518246	1603	Economy	28700.00
0005435508591	1603	Economy	28700.00
0005435508596	1603	Economy	28700.00
0005433186202	1603	Economy	28700.00
0005434566162	1603	Economy	28700.00
0005434566164	1603	Economy	28700.00
0005435518252	1603	Economy	28700.00
0005434566170	1603	Economy	28700.00
0005433186231	1603	Economy	28700.00
0005435518253	1603	Economy	28700.00
0005435508587	1603	Economy	28700.00
0005435502724	1603	Economy	28700.00
0005435518261	1603	Economy	28700.00
0005435502715	1603	Economy	28700.00
0005434566169	1603	Economy	28700.00
0005435502711	1603	Economy	28700.00
0005435502728	1603	Economy	28700.00
0005435508588	1603	Economy	28700.00
0005435508583	1603	Economy	28700.00
0005435518254	1603	Economy	28700.00
0005433186200	1603	Economy	28700.00
0005435508592	1603	Economy	28700.00
0005435502721	1603	Economy	28700.00
0005435502712	1603	Economy	28700.00
0005435508593	1603	Economy	28700.00
0005435502719	1603	Economy	28700.00
0005435518249	1603	Economy	28700.00
0005435508598	1603	Economy	28700.00
0005435502717	1603	Economy	28700.00
0005433186207	1603	Economy	28700.00
0005435502723	1603	Economy	28700.00
0005435518256	1603	Economy	28700.00
0005435508595	1603	Economy	28700.00
0005435502710	1603	Economy	28700.00
0005433186201	1603	Economy	28700.00
0005433186187	1603	Economy	28700.00
0005435502720	1603	Economy	28700.00
0005435508590	1603	Economy	28700.00
0005435502713	1603	Economy	28700.00
0005433186281	20880	Business	86000.00
0005435529496	20880	Business	86000.00
0005435545827	20880	Business	86000.00
0005435529357	20880	Business	86000.00
0005435529356	20880	Business	86000.00
0005435529494	20880	Economy	28700.00
0005434566037	20880	Economy	28700.00
0005434565985	20880	Economy	28700.00
0005433186279	20880	Economy	28700.00
0005434566024	20880	Economy	28700.00
0005434566045	20880	Economy	28700.00
0005435529495	20880	Economy	28700.00
0005435529423	20880	Economy	28700.00
0005434566059	20880	Economy	28700.00
0005435502518	20880	Economy	31500.00
0005435502535	20880	Economy	31500.00
0005435502520	20880	Economy	31500.00
0005433186280	20880	Economy	28700.00
0005435529422	20880	Economy	28700.00
0005434566085	20880	Economy	28700.00
0005434565991	20880	Economy	28700.00
0005435502522	20880	Economy	28700.00
0005435529488	20880	Economy	28700.00
0005434566038	20880	Economy	28700.00
0005435502422	20880	Economy	28700.00
0005435545778	20880	Economy	28700.00
0005435529489	20880	Economy	28700.00
0005435545809	20880	Economy	28700.00
0005434566058	20880	Economy	28700.00
0005435545817	20880	Economy	28700.00
0005435502448	20880	Economy	28700.00
0005434565990	20880	Economy	28700.00
0005434566073	20880	Economy	28700.00
0005434565961	20880	Economy	28700.00
0005434566060	20880	Economy	28700.00
0005435502471	20880	Economy	28700.00
0005434566046	20880	Economy	28700.00
0005434566047	20880	Economy	28700.00
0005433186277	20880	Economy	28700.00
0005433186275	20880	Economy	28700.00
0005434566068	20880	Economy	28700.00
0005433186282	20880	Economy	28700.00
0005434566039	20880	Economy	28700.00
0005435502538	20880	Economy	28700.00
0005435502541	20880	Economy	28700.00
0005435545804	20880	Economy	28700.00
0005435502521	20880	Economy	28700.00
0005435502489	20880	Economy	28700.00
0005435529427	20880	Economy	28700.00
0005435502449	20880	Economy	28700.00
0005433186276	20880	Economy	28700.00
0005435545805	20880	Economy	28700.00
0005435545810	20880	Economy	28700.00
0005435529447	20880	Economy	28700.00
0005435502478	20880	Economy	28700.00
0005433186278	20880	Economy	28700.00
0005435502519	20880	Economy	28700.00
0005435502537	20880	Economy	28700.00
0005435545808	20880	Economy	28700.00
0005435529334	20880	Economy	28700.00
0005435502536	20880	Economy	28700.00
0005435529335	20880	Economy	28700.00
0005434566086	20880	Economy	28700.00
0005435545826	20880	Economy	28700.00
0005435545832	20880	Economy	28700.00
0005435153866	3899	Economy	19700.00
0005435153862	3899	Economy	19700.00
0005435153867	3899	Economy	19700.00
0005435153868	3899	Economy	19700.00
0005435153864	3899	Economy	19700.00
0005435142971	3899	Economy	19700.00
0005435153865	3899	Economy	19700.00
0005435153863	3899	Economy	19700.00
0005435931647	3899	Economy	19700.00
0005435931650	3899	Economy	19700.00
0005435931648	3899	Economy	19700.00
0005435153781	21883	Economy	19700.00
0005435931673	21883	Economy	19700.00
0005435931672	21883	Economy	19700.00
0005435153815	21883	Economy	19700.00
0005435153803	21883	Economy	19700.00
0005435153824	21883	Economy	19700.00
0005435153808	21883	Economy	19700.00
0005435153797	21883	Economy	19700.00
0005435931670	21883	Economy	19700.00
0005435153810	21883	Economy	19700.00
0005435153804	21883	Economy	19700.00
0005435153814	21883	Economy	19700.00
0005435153813	21883	Economy	19700.00
0005435931671	21883	Economy	19700.00
0005435931674	21883	Economy	19700.00
0005435153829	21883	Economy	19700.00
0005435153802	21883	Economy	19700.00
0005432629125	7168	Economy	14300.00
0005432629128	7168	Economy	13000.00
0005432629124	7168	Economy	13000.00
0005432629117	7168	Economy	13000.00
0005435225658	7168	Economy	13000.00
0005432629126	7168	Economy	13000.00
0005432629129	7168	Economy	13000.00
0005432629130	7168	Economy	13000.00
0005432629123	7168	Economy	13000.00
0005435225652	7168	Economy	13000.00
0005432629120	7168	Economy	13000.00
0005432629121	7168	Economy	13000.00
0005435225670	7168	Economy	13000.00
0005432629118	7168	Economy	13000.00
0005432629131	7168	Economy	13000.00
0005432629122	7168	Economy	13000.00
0005435225669	7168	Economy	13000.00
0005432629127	7168	Economy	13000.00
0005432629119	7168	Economy	13000.00
0005432629015	28147	Economy	14300.00
0005432628943	28147	Economy	14300.00
0005432629029	28147	Economy	14300.00
0005435225737	28147	Economy	13000.00
0005432628952	28147	Economy	13000.00
0005432629014	28147	Economy	13000.00
0005432628992	28147	Economy	13000.00
0005432629038	28147	Economy	13000.00
0005435225734	28147	Economy	13000.00
0005435225735	28147	Economy	13000.00
0005432629063	28147	Economy	13000.00
0005432629055	28147	Economy	13000.00
0005435225732	28147	Economy	13000.00
0005435225731	28147	Economy	13000.00
0005432628999	28147	Economy	13000.00
0005432629079	28147	Economy	13000.00
0005435225739	28147	Economy	13000.00
0005435225733	28147	Economy	13000.00
0005432628965	28147	Economy	13000.00
0005432629013	28147	Economy	13000.00
0005432628958	28147	Economy	13000.00
0005432629045	28147	Economy	13000.00
0005432629078	28147	Economy	13000.00
0005435225738	28147	Economy	13000.00
0005432629054	28147	Economy	13000.00
0005432628979	28147	Economy	13000.00
0005432629031	28147	Economy	13000.00
0005432629030	28147	Economy	13000.00
0005432629062	28147	Economy	13000.00
0005435225736	28147	Economy	13000.00
0005434267972	8736	Economy	11500.00
0005435960122	8736	Economy	11500.00
0005434267973	8736	Economy	10500.00
0005435960121	8736	Economy	10500.00
0005434267971	8736	Economy	10500.00
0005435960123	8736	Economy	10500.00
0005435960102	15223	Economy	11500.00
0005435960087	15223	Economy	11500.00
0005435960086	15223	Economy	10500.00
0005434268019	15223	Economy	10500.00
0005434268021	15223	Economy	10500.00
0005435960101	15223	Economy	10500.00
0005435960081	15223	Economy	10500.00
0005435960099	15223	Economy	10500.00
0005435960096	15223	Economy	10500.00
0005434268022	15223	Economy	10500.00
0005434268020	15223	Economy	10500.00
0005432675419	1189	Business	115000.00
0005432693610	1189	Business	115000.00
0005432873367	1189	Business	115000.00
0005432693632	1189	Business	115000.00
0005432873366	1189	Business	115000.00
0005432693621	1189	Business	115000.00
0005432873350	1189	Business	115000.00
0005432693622	1189	Business	115000.00
0005432677644	1189	Business	115000.00
0005432675424	1189	Economy	38300.00
0005432693602	1189	Business	115000.00
0005432693601	1189	Economy	38300.00
0005432675413	1189	Economy	38300.00
0005432693611	1189	Economy	38300.00
0005432675414	1189	Economy	38300.00
0005432693618	1189	Economy	38300.00
0005432873343	1189	Economy	38300.00
0005432675415	1189	Economy	38300.00
0005432693628	1189	Economy	42200.00
0005432677643	1189	Economy	42200.00
0005432873358	1189	Economy	42200.00
0005432675418	1189	Economy	38300.00
0005432873344	1189	Economy	38300.00
0005432693619	1189	Economy	38300.00
0005432693625	1189	Economy	38300.00
0005432693606	1189	Economy	38300.00
0005432693624	1189	Economy	38300.00
0005432693629	1189	Economy	38300.00
0005432873359	1189	Economy	38300.00
0005432873368	1189	Economy	38300.00
0005432675412	1189	Economy	38300.00
0005432693614	1189	Economy	38300.00
0005432693627	1189	Economy	38300.00
0005432873349	1189	Economy	38300.00
0005432693608	1189	Economy	38300.00
0005432693604	1189	Economy	38300.00
0005432693626	1189	Economy	38300.00
0005432675422	1189	Economy	38300.00
0005432693612	1189	Economy	38300.00
0005432693609	1189	Economy	38300.00
0005432675411	1189	Economy	38300.00
0005432675420	1189	Economy	38300.00
0005432675408	1189	Economy	38300.00
0005432873329	1189	Economy	38300.00
0005432693620	1189	Economy	38300.00
0005432693623	1189	Economy	38300.00
0005432873357	1189	Economy	38300.00
0005432693616	1189	Economy	38300.00
0005432693630	1189	Economy	38300.00
0005432873376	1189	Economy	38300.00
0005432675417	1189	Economy	38300.00
0005432675409	1189	Economy	38300.00
0005432693607	1189	Economy	38300.00
0005432677645	1189	Economy	38300.00
0005432693617	1189	Economy	38300.00
0005432693613	1189	Economy	38300.00
0005432693615	1189	Economy	38300.00
0005432693631	1189	Economy	38300.00
0005432693605	1189	Economy	38300.00
0005432677642	1189	Economy	38300.00
0005432693603	1189	Economy	38300.00
0005432675421	1189	Economy	38300.00
0005432675423	1189	Economy	38300.00
0005432675416	1189	Economy	38300.00
0005432675410	1189	Economy	38300.00
0005432693600	1189	Economy	38300.00
0005432873369	1189	Economy	38300.00
0005432693406	17460	Business	115000.00
0005432693303	17460	Business	115000.00
0005432693426	17460	Business	115000.00
0005432693301	17460	Business	115000.00
0005432873424	17460	Business	115000.00
0005432677608	17460	Economy	38300.00
0005432677619	17460	Economy	38300.00
0005432693497	17460	Economy	38300.00
0005432693258	17460	Economy	38300.00
0005432693292	17460	Economy	38300.00
0005432675298	17460	Economy	42200.00
0005432693233	17460	Economy	42200.00
0005432675306	17460	Economy	38300.00
0005432675217	17460	Economy	38300.00
0005432693334	17460	Economy	38300.00
0005432693310	17460	Economy	38300.00
0005432693308	17460	Economy	38300.00
0005432693323	17460	Economy	38300.00
0005432675288	17460	Economy	38300.00
0005432675294	17460	Economy	38300.00
0005432693279	17460	Economy	38300.00
0005432873426	17460	Economy	38300.00
0005432873427	17460	Economy	38300.00
0005432873422	17460	Economy	38300.00
0005432675302	17460	Economy	38300.00
0005432693356	17460	Economy	38300.00
0005432693307	17460	Economy	38300.00
0005432675184	17460	Economy	38300.00
0005432693423	17460	Economy	38300.00
0005432693296	17460	Economy	38300.00
0005432675185	17460	Economy	38300.00
0005432693278	17460	Economy	38300.00
0005432693441	17460	Economy	38300.00
0005432693232	17460	Economy	38300.00
0005432693302	17460	Economy	38300.00
0005432675238	17460	Economy	38300.00
0005432693236	17460	Economy	38300.00
0005432693253	17460	Economy	38300.00
0005432873429	17460	Economy	38300.00
0005432693473	17460	Economy	38300.00
0005432873425	17460	Economy	38300.00
0005432693295	17460	Economy	38300.00
0005432675301	17460	Economy	38300.00
0005432693362	17460	Economy	38300.00
0005432693435	17460	Economy	38300.00
0005432693397	17460	Economy	38300.00
0005432693231	17460	Economy	38300.00
0005432693343	17460	Economy	38300.00
0005432873423	17460	Economy	38300.00
0005432693498	17460	Economy	38300.00
0005432693425	17460	Economy	38300.00
0005432693499	17460	Economy	38300.00
0005432873428	17460	Economy	38300.00
0005432693324	17460	Economy	38300.00
0005434435468	1129	Economy	15200.00
0005434435463	1129	Economy	15200.00
0005434435473	1129	Economy	13900.00
0005434435466	1129	Economy	13900.00
0005434435471	1129	Economy	13900.00
0005434435476	1129	Economy	13900.00
0005434435474	1129	Economy	13900.00
0005434435465	1129	Economy	13900.00
0005433156846	1129	Economy	13900.00
0005433156877	1129	Economy	13900.00
0005433156815	1129	Economy	13900.00
0005434435472	1129	Economy	13900.00
0005433156833	1129	Economy	13900.00
0005434435464	1129	Economy	13900.00
0005433156804	1129	Economy	13900.00
0005433156875	1129	Economy	13900.00
0005433156839	1129	Economy	13900.00
0005433156834	1129	Economy	13900.00
0005433156811	1129	Economy	13900.00
0005433156840	1129	Economy	13900.00
0005433156812	1129	Economy	13900.00
0005433156851	1129	Economy	13900.00
0005434435462	1129	Economy	13900.00
0005433156814	1129	Economy	13900.00
0005434435475	1129	Economy	13900.00
0005433156876	1129	Economy	13900.00
0005433156845	1129	Economy	13900.00
0005433156809	1129	Economy	13900.00
0005434435469	1129	Economy	13900.00
0005433156810	1129	Economy	13900.00
0005433156874	1129	Economy	13900.00
0005434435467	1129	Economy	13900.00
0005434435470	1129	Economy	13900.00
0005434435324	17314	Economy	15200.00
0005434435377	17314	Economy	15200.00
0005434435300	17314	Economy	15200.00
0005434435326	17314	Economy	13900.00
0005433156911	17314	Economy	13900.00
0005434435367	17314	Economy	13900.00
0005434435355	17314	Economy	13900.00
0005433156914	17314	Economy	13900.00
0005434435327	17314	Economy	13900.00
0005434435356	17314	Economy	13900.00
0005434435323	17314	Economy	13900.00
0005433156915	17314	Economy	13900.00
0005433156913	17314	Economy	13900.00
0005434435383	17314	Economy	13900.00
0005434435354	17314	Economy	13900.00
0005434435310	17314	Economy	13900.00
0005433156912	17314	Economy	13900.00
0005433156909	17314	Economy	13900.00
0005434435264	17314	Economy	13900.00
0005433156908	17314	Economy	13900.00
0005434435396	17314	Economy	13900.00
0005434435309	17314	Economy	13900.00
0005434435312	17314	Economy	13900.00
0005434435410	17314	Economy	13900.00
0005433156910	17314	Economy	13900.00
0005434435301	17314	Economy	13900.00
0005435928181	4095	Economy	7500.00
0005435928198	4095	Economy	7500.00
0005435086975	4095	Economy	7500.00
0005435086973	4095	Economy	7500.00
0005435086977	4095	Economy	7500.00
0005435928199	4095	Economy	7500.00
0005435928192	4095	Economy	7500.00
0005435086972	4095	Economy	7500.00
0005435928180	4095	Economy	7500.00
0005435086976	4095	Economy	7500.00
0005435086978	4095	Economy	7500.00
0005435086974	4095	Economy	7500.00
0005435086979	4095	Economy	7500.00
0005435086947	24411	Economy	8200.00
0005435928231	24411	Economy	8200.00
0005435928233	24411	Economy	7500.00
0005435928230	24411	Economy	7500.00
0005435086915	24411	Economy	7500.00
0005435086948	24411	Economy	7500.00
0005435086906	24411	Economy	7500.00
0005435086927	24411	Economy	7500.00
0005435086891	24411	Economy	7500.00
0005435086939	24411	Economy	7500.00
0005435928232	24411	Economy	7500.00
0005435086931	24411	Economy	7500.00
0005435928234	24411	Economy	7500.00
0005435086909	24411	Economy	7500.00
0005435086928	24411	Economy	7500.00
0005435098593	17012	Business	144300.00
0005435551697	17012	Business	144300.00
0005435551704	17012	Business	144300.00
0005435551683	17012	Economy	48100.00
0005435551702	17012	Economy	48100.00
0005435551690	17012	Economy	48100.00
0005435551684	17012	Economy	48100.00
0005435551692	17012	Economy	48100.00
0005435098592	17012	Economy	48100.00
0005435551700	17012	Economy	48100.00
0005435551688	17012	Economy	48100.00
0005435551693	17012	Economy	48100.00
0005435098590	17012	Economy	48100.00
0005435551689	17012	Economy	48100.00
0005435551703	17012	Economy	48100.00
0005435551705	17012	Economy	48100.00
0005435098591	17012	Economy	48100.00
0005435551695	17012	Economy	48100.00
0005435551698	17012	Economy	48100.00
0005435551687	17012	Economy	48100.00
0005435551694	17012	Economy	48100.00
0005435551691	17012	Economy	48100.00
0005435551696	17012	Economy	48100.00
0005435551686	17012	Economy	48100.00
0005435098596	17012	Economy	48100.00
0005435551706	17012	Economy	48100.00
0005435098595	17012	Economy	48100.00
0005435551701	17012	Economy	48100.00
0005435098594	17012	Economy	48100.00
0005435551699	17012	Economy	48100.00
0005435098589	17012	Economy	48100.00
0005435098597	17012	Economy	48100.00
0005435551685	17012	Economy	48100.00
0005434626134	4844	Business	44200.00
0005434626140	4844	Business	44200.00
0005435907548	4844	Economy	14700.00
0005434626135	4844	Economy	14700.00
0005433194884	4844	Economy	14700.00
0005434626139	4844	Economy	14700.00
0005434626143	4844	Economy	14700.00
0005433194882	4844	Economy	14700.00
0005434626142	4844	Economy	14700.00
0005433194878	4844	Economy	14700.00
0005434626137	4844	Economy	14700.00
0005434626141	4844	Economy	14700.00
0005434626138	4844	Economy	14700.00
0005434626136	4844	Economy	14700.00
0005433194883	4844	Economy	14700.00
0005435907598	32880	Business	44200.00
0005433194905	32880	Business	44200.00
0005433194913	32880	Business	44200.00
0005435907596	32880	Business	44200.00
0005434626067	32880	Economy	14700.00
0005433194908	32880	Economy	14700.00
0005435907597	32880	Economy	14700.00
0005434626105	32880	Economy	16200.00
0005434626065	32880	Economy	14700.00
0005434626021	32880	Economy	14700.00
0005433194912	32880	Economy	14700.00
0005433194911	32880	Economy	14700.00
0005434626022	32880	Economy	14700.00
0005435907595	32880	Economy	14700.00
0005434626071	32880	Economy	14700.00
0005434626103	32880	Economy	14700.00
0005433194909	32880	Economy	14700.00
0005434626102	32880	Economy	14700.00
0005433194907	32880	Economy	14700.00
0005433194910	32880	Economy	14700.00
0005434626104	32880	Economy	14700.00
0005433194906	32880	Economy	14700.00
0005434626084	32880	Economy	14700.00
0005434626027	32880	Economy	14700.00
0005434626070	32880	Economy	14700.00
0005435907599	32880	Economy	14700.00
0005435785749	13760	Economy	3400.00
0005435785751	13760	Economy	3400.00
0005435937461	13760	Economy	3400.00
0005435785410	13760	Economy	3100.00
0005435785735	13760	Economy	3100.00
0005435937464	13760	Economy	3100.00
0005435937465	13760	Economy	3100.00
0005435785645	13760	Economy	3100.00
0005435785805	13760	Economy	3100.00
0005435785651	13760	Economy	3100.00
0005435785591	13760	Economy	3100.00
0005435937462	13760	Economy	3100.00
0005435785590	13760	Economy	3100.00
0005435785668	13760	Economy	3100.00
0005435785661	13760	Economy	3100.00
0005435785573	13760	Economy	3100.00
0005435785705	13760	Economy	3100.00
0005435785562	13760	Economy	3100.00
0005435785717	13760	Economy	3100.00
0005435785728	13760	Economy	3100.00
0005435785669	13760	Economy	3100.00
0005435785542	13760	Economy	3100.00
0005435785701	13760	Economy	3100.00
0005435785561	13760	Economy	3100.00
0005435785650	13760	Economy	3100.00
0005435937466	13760	Economy	3100.00
0005435785793	13760	Economy	3100.00
0005432195733	13760	Economy	3100.00
0005435785750	13760	Economy	3100.00
0005435937463	13760	Economy	3100.00
0005435785632	13760	Economy	3100.00
0005432195734	13760	Economy	3100.00
0005435785652	13760	Economy	3100.00
0005435785813	13760	Economy	3100.00
0005435785644	13760	Economy	3100.00
0005435785442	13760	Economy	3100.00
0005435785570	13760	Economy	3100.00
0005435785576	13760	Economy	3100.00
0005435785449	13760	Economy	3100.00
0005435785748	13760	Economy	3100.00
0005435785736	13760	Economy	3100.00
0005435785685	13760	Economy	3100.00
0005435785571	13760	Economy	3100.00
0005435785675	13760	Economy	3100.00
0005435785965	27399	Economy	3400.00
0005435785940	27399	Economy	3400.00
0005435785946	27399	Economy	3400.00
0005435785962	27399	Economy	3400.00
0005435785952	27399	Economy	3100.00
0005435785947	27399	Economy	3100.00
0005435785966	27399	Economy	3100.00
0005432190695	27399	Economy	3100.00
0005435785937	27399	Economy	3100.00
0005432190697	27399	Economy	3100.00
0005435785963	27399	Economy	3100.00
0005435937408	27399	Economy	3100.00
0005435785950	27399	Economy	3100.00
0005435785953	27399	Economy	3100.00
0005435785935	27399	Economy	3100.00
0005435785933	27399	Economy	3100.00
0005435785944	27399	Economy	3100.00
0005435785957	27399	Economy	3100.00
0005435785960	27399	Economy	3100.00
0005435785967	27399	Economy	3100.00
0005435785936	27399	Economy	3100.00
0005435785941	27399	Economy	3100.00
0005435785956	27399	Economy	3100.00
0005435785961	27399	Economy	3100.00
0005435785955	27399	Economy	3100.00
0005435785951	27399	Economy	3100.00
0005435785943	27399	Economy	3100.00
0005435785964	27399	Economy	3100.00
0005435785945	27399	Economy	3100.00
0005435785939	27399	Economy	3100.00
0005435785958	27399	Economy	3100.00
0005435785968	27399	Economy	3100.00
0005435785942	27399	Economy	3100.00
0005435785954	27399	Economy	3100.00
0005435787391	27399	Economy	3100.00
0005432190696	27399	Economy	3100.00
0005432190694	27399	Economy	3100.00
0005435785959	27399	Economy	3100.00
0005435785949	27399	Economy	3100.00
0005435785948	27399	Economy	3100.00
0005435785934	27399	Economy	3100.00
0005435785938	27399	Economy	3100.00
0005434408334	20271	Business	12000.00
0005434408255	20271	Business	12000.00
0005432058457	20271	Business	12000.00
0005434408356	20271	Business	12000.00
0005434408597	20271	Business	12000.00
0005434408539	20271	Business	12000.00
0005434408542	20271	Business	12000.00
0005434408576	20271	Business	12000.00
0005434408382	20271	Business	12000.00
0005434408549	20271	Business	12000.00
0005432058458	20271	Economy	4000.00
0005434407996	20271	Economy	4000.00
0005434408333	20271	Economy	4000.00
0005434408237	20271	Economy	4000.00
0005434408291	20271	Economy	4000.00
0005432058455	20271	Economy	4000.00
0005434408274	20271	Economy	4000.00
0005434408552	20271	Economy	4000.00
0005434408587	20271	Economy	4000.00
0005434408190	20271	Economy	4400.00
0005434408419	20271	Economy	4400.00
0005434408417	20271	Economy	4400.00
0005435311290	20271	Economy	4400.00
0005434408424	20271	Economy	4000.00
0005434408491	20271	Economy	4000.00
0005434408442	20271	Economy	4000.00
0005434408392	20271	Economy	4000.00
0005434408365	20271	Economy	4000.00
0005434408528	20271	Economy	4000.00
0005434408105	20271	Economy	4000.00
0005434408315	20271	Economy	4000.00
0005434408497	20271	Economy	4000.00
0005434408420	20271	Economy	4000.00
0005434408283	20271	Economy	4000.00
0005434408047	20271	Economy	4000.00
0005434408351	20271	Economy	4000.00
0005434408282	20271	Economy	4000.00
0005432058453	20271	Economy	4000.00
0005434408573	20271	Economy	4000.00
0005434408316	20271	Economy	4000.00
0005434408292	20271	Economy	4000.00
0005434408290	20271	Economy	4000.00
0005434408511	20271	Economy	4000.00
0005434408414	20271	Economy	4000.00
0005435311292	20271	Economy	4000.00
0005434408236	20271	Economy	4000.00
0005434408548	20271	Economy	4000.00
0005435311291	20271	Economy	4000.00
0005435311294	20271	Economy	4000.00
0005434408383	20271	Economy	4000.00
0005434408277	20271	Economy	4000.00
0005434408553	20271	Economy	4000.00
0005434408486	20271	Economy	4000.00
0005434408415	20271	Economy	4000.00
0005434407988	20271	Economy	4000.00
0005434408335	20271	Economy	4000.00
0005434408502	20271	Economy	4000.00
0005434408254	20271	Economy	4000.00
0005434408572	20271	Economy	4000.00
0005434408189	20271	Economy	4000.00
0005434408465	20271	Economy	4000.00
0005434408421	20271	Economy	4000.00
0005434407803	20271	Economy	4000.00
0005435311295	20271	Economy	4000.00
0005434407827	20271	Economy	4000.00
0005434408296	20271	Economy	4000.00
0005434408295	20271	Economy	4000.00
0005434408040	20271	Economy	4000.00
0005435311296	20271	Economy	4000.00
0005434408522	20271	Economy	4000.00
0005432058454	20271	Economy	4000.00
0005434408526	20271	Economy	4000.00
0005434408149	20271	Economy	4000.00
0005434408575	20271	Economy	4000.00
0005434408501	20271	Economy	4000.00
0005434408106	20271	Economy	4000.00
0005434408456	20271	Economy	4000.00
0005434408581	20271	Economy	4000.00
0005432058456	20271	Economy	4000.00
0005434408538	20271	Economy	4000.00
0005434408395	20271	Economy	4000.00
0005434408425	20271	Economy	4000.00
0005434408332	20271	Economy	4000.00
0005434408490	20271	Economy	4000.00
0005434408485	20271	Economy	4000.00
0005434408354	20271	Economy	4000.00
0005434408331	20271	Economy	4000.00
0005435311293	20271	Economy	4000.00
0005434408932	27011	Business	12000.00
0005434408962	27011	Business	12000.00
0005432154067	27011	Business	12000.00
0005432154065	27011	Business	12000.00
0005434408940	27011	Business	12000.00
0005434408947	27011	Business	12000.00
0005434408961	27011	Business	12000.00
0005434408955	27011	Business	12000.00
0005434408912	27011	Business	12000.00
0005434408902	27011	Business	12000.00
0005434408958	27011	Business	12000.00
0005434408933	27011	Economy	4000.00
0005434408941	27011	Economy	4000.00
0005434408943	27011	Economy	4000.00
0005434408915	27011	Economy	4000.00
0005435311158	27011	Economy	4000.00
0005434408922	27011	Economy	4000.00
0005434408938	27011	Economy	4000.00
0005434408925	27011	Economy	4000.00
0005434408948	27011	Economy	4000.00
0005434408951	27011	Economy	4400.00
0005435311162	27011	Economy	4400.00
0005434408937	27011	Economy	4400.00
0005434408931	27011	Economy	4000.00
0005434408945	27011	Economy	4000.00
0005432154066	27011	Economy	4000.00
0005434408908	27011	Economy	4000.00
0005434408920	27011	Economy	4000.00
0005434408944	27011	Economy	4000.00
0005434408954	27011	Economy	4000.00
0005435311087	27011	Economy	4000.00
0005434408935	27011	Economy	4000.00
0005434408946	27011	Economy	4000.00
0005434408957	27011	Economy	4000.00
0005434408953	27011	Economy	4000.00
0005434408906	27011	Economy	4000.00
0005434408914	27011	Economy	4000.00
0005435311151	27011	Economy	4000.00
0005434408926	27011	Economy	4000.00
0005434408934	27011	Economy	4000.00
0005434408959	27011	Economy	4000.00
0005434408921	27011	Economy	4000.00
0005434408923	27011	Economy	4000.00
0005434408952	27011	Economy	4000.00
0005434408956	27011	Economy	4000.00
0005434408910	27011	Economy	4000.00
0005434408942	27011	Economy	4000.00
0005434408950	27011	Economy	4000.00
0005434408939	27011	Economy	4000.00
0005432154070	27011	Economy	4000.00
0005434408949	27011	Economy	4000.00
0005434408913	27011	Economy	4000.00
0005434408917	27011	Economy	4000.00
0005434408905	27011	Economy	4000.00
0005434408903	27011	Economy	4000.00
0005435311139	27011	Economy	4000.00
0005434408901	27011	Economy	4000.00
0005434408936	27011	Economy	4000.00
0005434408963	27011	Economy	4000.00
0005434408909	27011	Economy	4000.00
0005434408928	27011	Economy	4000.00
0005434408924	27011	Economy	4000.00
0005435311157	27011	Economy	4000.00
0005434408929	27011	Economy	4000.00
0005434408907	27011	Economy	4000.00
0005435311140	27011	Economy	4000.00
0005434408918	27011	Economy	4000.00
0005432154069	27011	Economy	4000.00
0005434408930	27011	Economy	4000.00
0005432154071	27011	Economy	4000.00
0005434408960	27011	Economy	4000.00
0005432154068	27011	Economy	4000.00
0005434408927	27011	Economy	4000.00
0005434408919	27011	Economy	4000.00
0005434408904	27011	Economy	4000.00
0005434408911	27011	Economy	4000.00
0005434408964	27011	Economy	4000.00
0005434408916	27011	Economy	4000.00
0005434319656	5696	Business	43300.00
0005434319642	5696	Business	43300.00
0005434311256	5696	Business	43300.00
0005433124164	5696	Business	43300.00
0005432109755	5696	Business	43300.00
0005434319653	5696	Economy	14400.00
0005433124059	5696	Economy	14400.00
0005433124096	5696	Economy	14400.00
0005434319644	5696	Economy	14400.00
0005434319651	5696	Economy	15900.00
0005433124142	5696	Economy	15900.00
0005433124053	5696	Economy	14400.00
0005434319639	5696	Economy	14400.00
0005434319655	5696	Economy	14400.00
0005434319640	5696	Economy	14400.00
0005434319637	5696	Economy	14400.00
0005432109754	5696	Economy	14400.00
0005434319654	5696	Economy	14400.00
0005433124119	5696	Economy	14400.00
0005434319647	5696	Economy	14400.00
0005432109753	5696	Economy	14400.00
0005434319649	5696	Economy	14400.00
0005434319648	5696	Economy	14400.00
0005434319652	5696	Economy	14400.00
0005434319650	5696	Economy	14400.00
0005433124163	5696	Economy	14400.00
0005434319638	5696	Economy	14400.00
0005433124162	5696	Economy	14400.00
0005434319641	5696	Economy	14400.00
0005433124143	5696	Economy	14400.00
0005433124218	5696	Economy	14400.00
0005434319645	5696	Economy	14400.00
0005434311255	5696	Economy	14400.00
0005433124161	5696	Economy	14400.00
0005434319643	5696	Economy	14400.00
0005433124089	5696	Economy	14400.00
0005434319646	5696	Economy	14400.00
0005434311245	15673	Business	43300.00
0005433124308	15673	Business	43300.00
0005433124316	15673	Business	43300.00
0005434311246	15673	Business	43300.00
0005433124329	15673	Economy	14400.00
0005434312340	15673	Economy	14400.00
0005433124323	15673	Economy	14400.00
0005434319557	15673	Economy	14400.00
0005434319577	15673	Economy	15900.00
0005433124320	15673	Economy	15900.00
0005434319551	15673	Economy	15900.00
0005433124312	15673	Economy	15900.00
0005433124326	15673	Economy	14400.00
0005435297350	15673	Economy	14400.00
0005434319518	15673	Economy	14400.00
0005433124315	15673	Economy	14400.00
0005433124330	15673	Economy	14400.00
0005433124318	15673	Economy	14400.00
0005433124321	15673	Economy	14400.00
0005434311244	15673	Economy	14400.00
0005433124327	15673	Economy	14400.00
0005433124311	15673	Economy	14400.00
0005433124322	15673	Economy	14400.00
0005435297351	15673	Economy	14400.00
0005433124314	15673	Economy	14400.00
0005433124325	15673	Economy	14400.00
0005434319523	15673	Economy	14400.00
0005434319483	15673	Economy	14400.00
0005434319519	15673	Economy	14400.00
0005433124310	15673	Economy	14400.00
0005434319521	15673	Economy	14400.00
0005434311237	15673	Economy	14400.00
0005433124309	15673	Economy	14400.00
0005433124317	15673	Economy	14400.00
0005434319552	15673	Economy	14400.00
0005434319556	15673	Economy	14400.00
0005433124313	15673	Economy	14400.00
0005433124328	15673	Economy	14400.00
0005433124319	15673	Economy	14400.00
0005433124324	15673	Economy	14400.00
0005435220356	31737	Economy	17100.00
0005435219242	31737	Economy	15500.00
0005435219237	31737	Economy	15500.00
0005435220499	31737	Economy	15500.00
0005435220361	31737	Economy	15500.00
0005435220355	31737	Economy	15500.00
0005435220500	31737	Economy	15500.00
0005435220360	31737	Economy	15500.00
0005435220498	31737	Economy	15500.00
0005435220357	31737	Economy	15500.00
0005435219240	31737	Economy	15500.00
0005435220497	31737	Economy	15500.00
0005435220359	31737	Economy	15500.00
0005435220502	31737	Economy	15500.00
0005435219241	31737	Economy	15500.00
0005435220354	31737	Economy	15500.00
0005435220362	31737	Economy	15500.00
0005435220358	31737	Economy	15500.00
0005435220501	31737	Economy	15500.00
0005435219236	31737	Economy	15500.00
0005435219243	31737	Economy	15500.00
0005435219238	31737	Economy	15500.00
0005435219239	31737	Economy	15500.00
0005434484473	8982	Economy	27400.00
0005434484469	8982	Economy	24900.00
0005434484472	8982	Economy	24900.00
0005434189239	8982	Economy	24900.00
0005434484467	8982	Economy	24900.00
0005434189241	8982	Economy	24900.00
0005434484470	8982	Economy	24900.00
0005434189257	8982	Economy	24900.00
0005434189245	8982	Economy	24900.00
0005434484468	8982	Economy	24900.00
0005434484471	8982	Economy	24900.00
0005434484398	16650	Economy	27400.00
0005434189285	16650	Economy	27400.00
0005434484417	16650	Economy	24900.00
0005434189286	16650	Economy	24900.00
0005434484400	16650	Economy	24900.00
0005434189283	16650	Economy	24900.00
0005434189287	16650	Economy	24900.00
0005434484409	16650	Economy	24900.00
0005434484422	16650	Economy	24900.00
0005434189284	16650	Economy	24900.00
0005434189288	16650	Economy	24900.00
0005434484413	16650	Economy	24900.00
0005434484401	16650	Economy	24900.00
0005433124309	7662	Business	11100.00
0005433124320	7662	Economy	3700.00
0005433124312	7662	Economy	3700.00
0005433124326	7662	Economy	3700.00
0005433124310	7662	Economy	3700.00
0005433124321	7662	Economy	4100.00
0005433124318	7662	Economy	4100.00
0005433124325	7662	Economy	4100.00
0005433124330	7662	Economy	3700.00
0005433124314	7662	Economy	3700.00
0005433124323	7662	Economy	3700.00
0005433124328	7662	Economy	3700.00
0005433124317	7662	Economy	3700.00
0005433124327	7662	Economy	3700.00
0005433722262	7662	Economy	3700.00
0005433124315	7662	Economy	3700.00
0005433722271	7662	Economy	3700.00
0005433124316	7662	Economy	3700.00
0005433124308	7662	Economy	3700.00
0005433124311	7662	Economy	3700.00
0005433124324	7662	Economy	3700.00
0005433124322	7662	Economy	3700.00
0005433722261	7662	Economy	3700.00
0005433124313	7662	Economy	3700.00
0005433124319	7662	Economy	3700.00
0005433124329	7662	Economy	3700.00
0005432693657	7663	Business	11100.00
0005433450369	7663	Business	11100.00
0005432693649	7663	Business	11100.00
0005432721393	7663	Business	11100.00
0005433450371	7663	Business	11100.00
0005433450380	7663	Business	11100.00
0005432693638	7663	Business	11100.00
0005433450368	7663	Business	11100.00
0005432071629	7663	Business	11100.00
0005433450366	7663	Economy	3700.00
0005432721416	7663	Economy	3700.00
0005432721395	7663	Economy	3700.00
0005432693652	7663	Economy	3700.00
0005432693656	7663	Economy	3700.00
0005432721406	7663	Economy	3700.00
0005432721412	7663	Economy	3700.00
0005432693647	7663	Economy	3700.00
0005433450379	7663	Economy	4100.00
0005433450367	7663	Economy	4100.00
0005433450363	7663	Economy	4100.00
0005432721400	7663	Economy	4100.00
0005432693634	7663	Economy	3700.00
0005433450364	7663	Economy	3700.00
0005432693646	7663	Economy	3700.00
0005432693636	7663	Economy	3700.00
0005432693662	7663	Economy	3700.00
0005432693654	7663	Economy	3700.00
0005432693637	7663	Economy	3700.00
0005433450375	7663	Economy	3700.00
0005432693650	7663	Economy	3700.00
0005432721398	7663	Economy	3700.00
0005432721413	7663	Economy	3700.00
0005433450373	7663	Economy	3700.00
0005433450370	7663	Economy	3700.00
0005433450365	7663	Economy	3700.00
0005432693643	7663	Economy	3700.00
0005432693635	7663	Economy	3700.00
0005432721391	7663	Economy	3700.00
0005432693640	7663	Economy	3700.00
0005432721402	7663	Economy	3700.00
0005432721405	7663	Economy	3700.00
0005432693661	7663	Economy	3700.00
0005432693639	7663	Economy	3700.00
0005433450378	7663	Economy	3700.00
0005432721397	7663	Economy	3700.00
0005433450384	7663	Economy	3700.00
0005432693641	7663	Economy	3700.00
0005433450381	7663	Economy	3700.00
0005432721410	7663	Economy	3700.00
0005433450372	7663	Economy	3700.00
0005432721394	7663	Economy	3700.00
0005432693660	7663	Economy	3700.00
0005432721392	7663	Economy	3700.00
0005432721411	7663	Economy	3700.00
0005432721414	7663	Economy	3700.00
0005433450383	7663	Economy	3700.00
0005433450377	7663	Economy	3700.00
0005432693648	7663	Economy	3700.00
0005432721417	7663	Economy	3700.00
0005432071628	7663	Economy	3700.00
0005432721401	7663	Economy	3700.00
0005432721403	7663	Economy	3700.00
0005433450376	7663	Economy	3700.00
0005433450374	7663	Economy	3700.00
0005432721407	7663	Economy	3700.00
0005433450382	7663	Economy	3700.00
0005432693659	7663	Economy	3700.00
0005432693642	7663	Economy	3700.00
0005432721409	7663	Economy	3700.00
0005432721404	7663	Economy	3700.00
0005432693655	7663	Economy	3700.00
0005432693645	7663	Economy	3700.00
0005432693644	7663	Economy	3700.00
0005432693633	7663	Economy	3700.00
0005432721408	7663	Economy	3700.00
0005432721399	7663	Economy	3700.00
0005432693653	7663	Economy	3700.00
0005432693651	7663	Economy	3700.00
0005432721396	7663	Economy	3700.00
0005432721390	7663	Economy	3700.00
0005432721415	7663	Economy	3700.00
0005432693658	7663	Economy	3700.00
0005433450264	30404	Business	11100.00
0005432693292	30404	Business	11100.00
0005432693231	30404	Business	11100.00
0005432693499	30404	Business	11100.00
0005432693233	30404	Business	11100.00
0005432693425	30404	Business	11100.00
0005432693279	30404	Economy	3700.00
0005433450144	30404	Economy	3700.00
0005433450267	30404	Economy	3700.00
0005432693356	30404	Economy	3700.00
0005432693323	30404	Economy	3700.00
0005432693435	30404	Economy	3700.00
0005433450167	30404	Economy	3700.00
0005432693302	30404	Economy	4100.00
0005432693310	30404	Economy	3700.00
0005433450206	30404	Economy	3700.00
0005433450265	30404	Economy	3700.00
0005433450120	30404	Economy	3700.00
0005432693308	30404	Economy	3700.00
0005432693307	30404	Economy	3700.00
0005433450219	30404	Economy	3700.00
0005432693301	30404	Economy	3700.00
0005432693497	30404	Economy	3700.00
0005433450102	30404	Economy	3700.00
0005432693334	30404	Economy	3700.00
0005433450098	30404	Economy	3700.00
0005432693498	30404	Economy	3700.00
0005432693423	30404	Economy	3700.00
0005432693295	30404	Economy	3700.00
0005433450125	30404	Economy	3700.00
0005433450220	30404	Economy	3700.00
0005432693296	30404	Economy	3700.00
0005433450122	30404	Economy	3700.00
0005432693473	30404	Economy	3700.00
0005433450205	30404	Economy	3700.00
0005433450133	30404	Economy	3700.00
0005432693303	30404	Economy	3700.00
0005432693324	30404	Economy	3700.00
0005432693441	30404	Economy	3700.00
0005433450168	30404	Economy	3700.00
0005432693406	30404	Economy	3700.00
0005432693362	30404	Economy	3700.00
0005432693253	30404	Economy	3700.00
0005433450245	30404	Economy	3700.00
0005432693426	30404	Economy	3700.00
0005432693258	30404	Economy	3700.00
0005432693397	30404	Economy	3700.00
0005432693343	30404	Economy	3700.00
0005432693232	30404	Economy	3700.00
0005432693236	30404	Economy	3700.00
0005432693278	30404	Economy	3700.00
0005433124163	30405	Business	11100.00
0005432721256	30405	Business	11100.00
0005433124143	30405	Business	11100.00
0005433124059	30405	Business	11100.00
0005432721077	30405	Business	11100.00
0005432721209	30405	Economy	3700.00
0005432721079	30405	Economy	3700.00
0005433722345	30405	Economy	3700.00
0005432721202	30405	Economy	3700.00
0005432721210	30405	Economy	3700.00
0005432721189	30405	Economy	3700.00
0005432721078	30405	Economy	3700.00
0005433124089	30405	Economy	4100.00
0005432721255	30405	Economy	4100.00
0005432721248	30405	Economy	3700.00
0005433124218	30405	Economy	3700.00
0005432721169	30405	Economy	3700.00
0005432721232	30405	Economy	3700.00
0005433124053	30405	Economy	3700.00
0005433722346	30405	Economy	3700.00
0005432721200	30405	Economy	3700.00
0005432721297	30405	Economy	3700.00
0005433124164	30405	Economy	3700.00
0005433124096	30405	Economy	3700.00
0005432721249	30405	Economy	3700.00
0005432721333	30405	Economy	3700.00
0005432721170	30405	Economy	3700.00
0005432721171	30405	Economy	3700.00
0005432721253	30405	Economy	3700.00
0005432721223	30405	Economy	3700.00
0005432721175	30405	Economy	3700.00
0005432721174	30405	Economy	3700.00
0005432721141	30405	Economy	3700.00
0005433124119	30405	Economy	3700.00
0005432721163	30405	Economy	3700.00
0005433722343	30405	Economy	3700.00
0005433124142	30405	Economy	3700.00
0005433124162	30405	Economy	3700.00
0005432721225	30405	Economy	3700.00
0005432721332	30405	Economy	3700.00
0005432721201	30405	Economy	3700.00
0005432721254	30405	Economy	3700.00
0005433124161	30405	Economy	3700.00
0005432721142	30405	Economy	3700.00
0005432721000	30405	Economy	3700.00
0005432721164	30405	Economy	3700.00
0005432721224	30405	Economy	3700.00
0005433722344	30405	Economy	3700.00
0005433193216	1370	Business	70400.00
0005433724892	1370	Business	70400.00
0005434587095	1370	Business	70400.00
0005433525240	1370	Business	70400.00
0005434587087	1370	Business	70400.00
0005432928051	1370	Business	70400.00
0005434587101	1370	Business	70400.00
0005433193206	1370	Business	70400.00
0005433525238	1370	Business	70400.00
0005432968864	1370	Economy	23500.00
0005432271058	1370	Economy	23500.00
0005432928035	1370	Economy	23500.00
0005434587078	1370	Economy	23500.00
0005433525246	1370	Economy	23500.00
0005434587103	1370	Economy	23500.00
0005434513629	1370	Economy	23500.00
0005434587088	1370	Economy	25800.00
0005433193197	1370	Economy	25800.00
0005434513631	1370	Economy	25800.00
0005434513628	1370	Economy	25800.00
0005434587082	1370	Economy	23500.00
0005434587081	1370	Economy	23500.00
0005434513630	1370	Economy	23500.00
0005434587100	1370	Economy	23500.00
0005434587084	1370	Economy	23500.00
0005433724890	1370	Economy	23500.00
0005434587091	1370	Economy	23500.00
0005433525245	1370	Economy	23500.00
0005434515017	1370	Economy	23500.00
0005433525243	1370	Economy	23500.00
0005433193217	1370	Economy	23500.00
0005434587094	1370	Economy	23500.00
0005432928033	1370	Economy	23500.00
0005433525248	1370	Economy	23500.00
0005433525247	1370	Economy	23500.00
0005434587092	1370	Economy	23500.00
0005434587098	1370	Economy	23500.00
0005434587097	1370	Economy	23500.00
0005434587089	1370	Economy	23500.00
0005433193194	1370	Economy	23500.00
0005434587085	1370	Economy	23500.00
0005433525236	1370	Economy	23500.00
0005434515016	1370	Economy	23500.00
0005434587093	1370	Economy	23500.00
0005434587079	1370	Economy	23500.00
0005434587090	1370	Economy	23500.00
0005433193174	1370	Economy	23500.00
0005433525244	1370	Economy	23500.00
0005434587096	1370	Economy	23500.00
0005433724891	1370	Economy	23500.00
0005433525241	1370	Economy	23500.00
0005432928046	1370	Economy	23500.00
0005434587086	1370	Economy	23500.00
0005433193195	1370	Economy	23500.00
0005433193191	1370	Economy	23500.00
0005433724893	1370	Economy	23500.00
0005433193202	1370	Economy	23500.00
0005434587099	1370	Economy	23500.00
0005433193173	1370	Economy	23500.00
0005433193187	1370	Economy	23500.00
0005433193128	1370	Economy	23500.00
0005434587083	1370	Economy	23500.00
0005434587102	1370	Economy	23500.00
0005433525242	1370	Economy	23500.00
0005433525237	1370	Economy	23500.00
0005432968869	1370	Economy	23500.00
0005433525239	1370	Economy	23500.00
0005434587080	1370	Economy	23500.00
0005434586869	18553	Business	70400.00
0005434586818	18553	Business	70400.00
0005433193301	18553	Business	70400.00
0005432928081	18553	Business	70400.00
0005434586744	18553	Business	70400.00
0005433525112	18553	Business	70400.00
0005432928082	18553	Business	70400.00
0005433193295	18553	Economy	23500.00
0005434586875	18553	Economy	23500.00
0005434514989	18553	Economy	23500.00
0005432968883	18553	Economy	23500.00
0005433525145	18553	Economy	23500.00
0005432968882	18553	Economy	23500.00
0005434514990	18553	Economy	23500.00
0005434586820	18553	Economy	23500.00
0005433193291	18553	Economy	23500.00
0005433193299	18553	Economy	23500.00
0005434586890	18553	Economy	23500.00
0005432928084	18553	Economy	23500.00
0005434586817	18553	Economy	23500.00
0005433193300	18553	Economy	23500.00
0005433193293	18553	Economy	23500.00
0005433525144	18553	Economy	23500.00
0005433193289	18553	Economy	23500.00
0005433724857	18553	Economy	23500.00
0005434514981	18553	Economy	23500.00
0005432928080	18553	Economy	23500.00
0005433193298	18553	Economy	23500.00
0005434586824	18553	Economy	23500.00
0005434586881	18553	Economy	23500.00
0005433724828	18553	Economy	23500.00
0005432928083	18553	Economy	23500.00
0005434586868	18553	Economy	23500.00
0005432928086	18553	Economy	23500.00
0005433193290	18553	Economy	23500.00
0005434586867	18553	Economy	23500.00
0005433193297	18553	Economy	23500.00
0005432968881	18553	Economy	23500.00
0005433193296	18553	Economy	23500.00
0005433525115	18553	Economy	23500.00
0005434586819	18553	Economy	23500.00
0005433724834	18553	Economy	23500.00
0005433193294	18553	Economy	23500.00
0005434586823	18553	Economy	23500.00
0005433193292	18553	Economy	23500.00
0005434586882	18553	Economy	23500.00
0005433724848	18553	Economy	23500.00
0005432928085	18553	Economy	23500.00
0005434586870	18553	Economy	23500.00
0005434586874	18553	Economy	23500.00
0005432968884	18553	Economy	23500.00
0005434344842	11471	Economy	4300.00
0005434344822	11471	Economy	4300.00
0005434344833	11471	Economy	4300.00
0005435305016	11471	Economy	4300.00
0005434344830	11471	Economy	4000.00
0005435305028	11471	Economy	4000.00
0005434142684	11471	Economy	4000.00
0005434344831	11471	Economy	4000.00
0005434344846	11471	Economy	4000.00
0005434344853	11471	Economy	4000.00
0005434344827	11471	Economy	4000.00
0005434344851	11471	Economy	4000.00
0005434344847	11471	Economy	4000.00
0005434344823	11471	Economy	4000.00
0005434344843	11471	Economy	4000.00
0005434344848	11471	Economy	4000.00
0005434142683	11471	Economy	4000.00
0005434344837	11471	Economy	4000.00
0005434344825	11471	Economy	4000.00
0005434344845	11471	Economy	4000.00
0005434344821	11471	Economy	4000.00
0005435302245	11471	Economy	4000.00
0005435302230	11471	Economy	4000.00
0005435302229	11471	Economy	4000.00
0005434344844	11471	Economy	4000.00
0005434344838	11471	Economy	4000.00
0005434344836	11471	Economy	4000.00
0005434344840	11471	Economy	4000.00
0005435302248	11471	Economy	4000.00
0005434344852	11471	Economy	4000.00
0005434344820	11471	Economy	4000.00
0005434142686	11471	Economy	4000.00
0005434344850	11471	Economy	4000.00
0005434344824	11471	Economy	4000.00
0005434344828	11471	Economy	4000.00
0005434344841	11471	Economy	4000.00
0005434344829	11471	Economy	4000.00
0005434344834	11471	Economy	4000.00
0005434344839	11471	Economy	4000.00
0005434344849	11471	Economy	4000.00
0005434344835	11471	Economy	4000.00
0005435302217	11471	Economy	4000.00
0005434344826	11471	Economy	4000.00
0005434344854	11471	Economy	4000.00
0005434142685	11471	Economy	4000.00
0005435305019	11471	Economy	4000.00
0005434344832	11471	Economy	4000.00
0005434344491	29778	Economy	4300.00
0005434344694	29778	Economy	4300.00
0005434344675	29778	Economy	4300.00
0005434344575	29778	Economy	4300.00
0005434344510	29778	Economy	4000.00
0005434344438	29778	Economy	4000.00
0005434344492	29778	Economy	4000.00
0005434344524	29778	Economy	4000.00
0005434344528	29778	Economy	4000.00
0005434344625	29778	Economy	4000.00
0005434344676	29778	Economy	4000.00
0005434344497	29778	Economy	4000.00
0005434142645	29778	Economy	4000.00
0005434344513	29778	Economy	4000.00
0005434344525	29778	Economy	4000.00
0005434344505	29778	Economy	4000.00
0005434344638	29778	Economy	4000.00
0005434344599	29778	Economy	4000.00
0005434344543	29778	Economy	4000.00
0005434344598	29778	Economy	4000.00
0005434344693	29778	Economy	4000.00
0005434344515	29778	Economy	4000.00
0005434344419	29778	Economy	4000.00
0005434344577	29778	Economy	4000.00
0005434344448	29778	Economy	4000.00
0005434344489	29778	Economy	4000.00
0005434344552	29778	Economy	4000.00
0005434344387	29778	Economy	4000.00
0005434344468	29778	Economy	4000.00
0005434142644	29778	Economy	4000.00
0005434344434	29778	Economy	4000.00
0005434344512	29778	Economy	4000.00
0005434344560	29778	Economy	4000.00
0005434344518	29778	Economy	4000.00
0005434344626	29778	Economy	4000.00
0005434344544	29778	Economy	4000.00
0005434344487	29778	Economy	4000.00
0005434344433	29778	Economy	4000.00
0005434344432	29778	Economy	4000.00
0005434344463	29778	Economy	4000.00
0005434344526	29778	Economy	4000.00
0005434344437	29778	Economy	4000.00
0005434344636	29778	Economy	4000.00
0005434344516	29778	Economy	4000.00
0005434344634	29778	Economy	4000.00
0005434344527	29778	Economy	4000.00
0005434142635	29778	Economy	4000.00
0005434344635	29778	Economy	4000.00
0005434344431	29778	Economy	4000.00
0005435825136	1276	Business	199800.00
0005433415867	1276	Business	199800.00
0005433415820	1276	Business	199800.00
0005432284614	1276	Business	199800.00
0005433415826	1276	Business	199800.00
0005435825125	1276	Business	199800.00
0005433415779	1276	Business	199800.00
0005435825122	1276	Business	199800.00
0005435825138	1276	Economy	66600.00
0005433415821	1276	Economy	66600.00
0005435825118	1276	Economy	66600.00
0005433415781	1276	Economy	66600.00
0005433415795	1276	Economy	73200.00
0005435825139	1276	Economy	73200.00
0005432284612	1276	Economy	73200.00
0005432284613	1276	Economy	66600.00
0005433415831	1276	Economy	66600.00
0005435825132	1276	Economy	66600.00
0005435825131	1276	Economy	66600.00
0005435825129	1276	Economy	66600.00
0005435825121	1276	Economy	66600.00
0005435825120	1276	Economy	66600.00
0005435825127	1276	Economy	66600.00
0005435825116	1276	Economy	66600.00
0005435825115	1276	Economy	66600.00
0005435825124	1276	Economy	66600.00
0005433415810	1276	Economy	66600.00
0005435825141	1276	Economy	66600.00
0005433415806	1276	Economy	66600.00
0005435825126	1276	Economy	66600.00
0005435825134	1276	Economy	66600.00
0005435825123	1276	Economy	66600.00
0005433415780	1276	Economy	66600.00
0005435825133	1276	Economy	66600.00
0005433415912	1276	Economy	66600.00
0005435825117	1276	Economy	66600.00
0005435825130	1276	Economy	66600.00
0005435825135	1276	Economy	66600.00
0005435825140	1276	Economy	66600.00
0005433415824	1276	Economy	66600.00
0005435825128	1276	Economy	66600.00
0005435825137	1276	Economy	66600.00
0005433415866	1276	Economy	66600.00
0005435825113	1276	Economy	66600.00
0005433415845	1276	Economy	66600.00
0005433415868	1276	Economy	66600.00
0005435825119	1276	Economy	66600.00
0005435825114	1276	Economy	66600.00
0005433415754	1276	Economy	66600.00
0005435824989	18022	Business	199800.00
0005433415961	18022	Business	199800.00
0005435824900	18022	Business	199800.00
0005435824865	18022	Business	199800.00
0005433415953	18022	Business	199800.00
0005435824972	18022	Business	199800.00
0005435824722	18022	Economy	66600.00
0005433415955	18022	Economy	66600.00
0005435824882	18022	Economy	66600.00
0005433415957	18022	Economy	73200.00
0005433415952	18022	Economy	66600.00
0005435824823	18022	Economy	66600.00
0005435825004	18022	Economy	66600.00
0005435824843	18022	Economy	66600.00
0005435824862	18022	Economy	66600.00
0005433415963	18022	Economy	66600.00
0005435824901	18022	Economy	66600.00
0005433415964	18022	Economy	66600.00
0005435824941	18022	Economy	66600.00
0005435824861	18022	Economy	66600.00
0005435824854	18022	Economy	66600.00
0005435824883	18022	Economy	66600.00
0005435824755	18022	Economy	66600.00
0005433415960	18022	Economy	66600.00
0005435824974	18022	Economy	66600.00
0005433415956	18022	Economy	66600.00
0005435824984	18022	Economy	66600.00
0005433415958	18022	Economy	66600.00
0005433415950	18022	Economy	66600.00
0005435824928	18022	Economy	66600.00
0005433415949	18022	Economy	66600.00
0005433415962	18022	Economy	66600.00
0005435824995	18022	Economy	66600.00
0005435824847	18022	Economy	66600.00
0005435824927	18022	Economy	66600.00
0005435824975	18022	Economy	66600.00
0005435824936	18022	Economy	66600.00
0005433415959	18022	Economy	66600.00
0005435824971	18022	Economy	66600.00
0005435824899	18022	Economy	66600.00
0005433415954	18022	Economy	66600.00
0005433415951	18022	Economy	66600.00
0005435825038	18022	Economy	66600.00
0005435824996	18022	Economy	66600.00
0005432784792	5653	Business	27800.00
0005435243008	5653	Business	27800.00
0005432784778	5653	Business	27800.00
0005432144050	5653	Business	27800.00
0005435476829	5653	Business	27800.00
0005435476823	5653	Business	27800.00
0005435243055	5653	Business	27800.00
0005432784819	5653	Business	27800.00
0005435476812	5653	Business	27800.00
0005432784806	5653	Business	27800.00
0005432784770	5653	Business	27800.00
0005435243190	5653	Economy	9300.00
0005432784783	5653	Economy	9300.00
0005435476828	5653	Economy	9300.00
0005435243133	5653	Economy	9300.00
0005432784797	5653	Economy	9300.00
0005435243099	5653	Economy	9300.00
0005432784771	5653	Economy	9300.00
0005432784810	5653	Economy	9300.00
0005432784790	5653	Economy	9300.00
0005432784787	5653	Economy	9300.00
0005432784798	5653	Economy	10200.00
0005432784800	5653	Economy	10200.00
0005432784773	5653	Economy	10200.00
0005432784805	5653	Economy	10200.00
0005432784807	5653	Economy	10200.00
0005435243082	5653	Economy	9300.00
0005432784775	5653	Economy	9300.00
0005435243025	5653	Economy	9300.00
0005432784784	5653	Economy	9300.00
0005432784794	5653	Economy	9300.00
0005435243136	5653	Economy	9300.00
0005435243174	5653	Economy	9300.00
0005432784799	5653	Economy	9300.00
0005435243110	5653	Economy	9300.00
0005435476811	5653	Economy	9300.00
0005435476817	5653	Economy	9300.00
0005435243084	5653	Economy	9300.00
0005432784779	5653	Economy	9300.00
0005432784772	5653	Economy	9300.00
0005432784803	5653	Economy	9300.00
0005432784769	5653	Economy	9300.00
0005435243087	5653	Economy	9300.00
0005432784780	5653	Economy	9300.00
0005432784789	5653	Economy	9300.00
0005432784777	5653	Economy	9300.00
0005435243081	5653	Economy	9300.00
0005432784801	5653	Economy	9300.00
0005432144049	5653	Economy	9300.00
0005432784813	5653	Economy	9300.00
0005432784768	5653	Economy	9300.00
0005432784818	5653	Economy	9300.00
0005435476818	5653	Economy	9300.00
0005432784795	5653	Economy	9300.00
0005432784821	5653	Economy	9300.00
0005432784804	5653	Economy	9300.00
0005432144048	5653	Economy	9300.00
0005435243091	5653	Economy	9300.00
0005432144047	5653	Economy	9300.00
0005435243056	5653	Economy	9300.00
0005432784811	5653	Economy	9300.00
0005435242968	5653	Economy	9300.00
0005435243117	5653	Economy	9300.00
0005432784796	5653	Economy	9300.00
0005432784802	5653	Economy	9300.00
0005432784781	5653	Economy	9300.00
0005432784786	5653	Economy	9300.00
0005432784774	5653	Economy	9300.00
0005432784785	5653	Economy	9300.00
0005432784812	5653	Economy	9300.00
0005435243024	5653	Economy	9300.00
0005435243023	5653	Economy	9300.00
0005432784817	5653	Economy	9300.00
0005432784809	5653	Economy	9300.00
0005435243007	5653	Economy	9300.00
0005432784776	5653	Economy	9300.00
0005435243077	5653	Economy	9300.00
0005432784791	5653	Economy	9300.00
0005432784782	5653	Economy	9300.00
0005435243068	5653	Economy	9300.00
0005432784788	5653	Economy	9300.00
0005432784816	5653	Economy	9300.00
0005435243067	5653	Economy	9300.00
0005432784815	5653	Economy	9300.00
0005435243046	5653	Economy	9300.00
0005432784814	5653	Economy	9300.00
0005432784808	5653	Economy	9300.00
0005435476816	5653	Economy	9300.00
0005435243108	5653	Economy	9300.00
0005435243118	5653	Economy	9300.00
0005432784820	5653	Economy	9300.00
0005432784793	5653	Economy	9300.00
0005435243135	5653	Economy	9300.00
0005435243086	5653	Economy	9300.00
0005432784767	5653	Economy	9300.00
0005435243088	5653	Economy	9300.00
0005432784182	15380	Business	27800.00
0005435476886	15380	Business	27800.00
0005432784501	15380	Business	27800.00
0005432784411	15380	Business	27800.00
0005432784245	15380	Business	27800.00
0005432784369	15380	Business	27800.00
0005435243339	15380	Business	27800.00
0005432784243	15380	Business	27800.00
0005432784515	15380	Business	27800.00
0005435243338	15380	Business	27800.00
0005432784537	15380	Business	27800.00
0005432784316	15380	Business	27800.00
0005432784228	15380	Economy	9300.00
0005432784360	15380	Economy	9300.00
0005432784271	15380	Economy	9300.00
0005432784055	15380	Economy	9300.00
0005435243332	15380	Economy	9300.00
0005432784514	15380	Economy	9300.00
0005432784356	15380	Economy	9300.00
0005432784482	15380	Economy	9300.00
0005432784281	15380	Economy	9300.00
0005435243342	15380	Economy	9300.00
0005432784379	15380	Economy	10200.00
0005435243325	15380	Economy	10200.00
0005432784362	15380	Economy	10200.00
0005435243334	15380	Economy	10200.00
0005435243318	15380	Economy	10200.00
0005432784294	15380	Economy	9300.00
0005432784404	15380	Economy	9300.00
0005432784262	15380	Economy	9300.00
0005432784461	15380	Economy	9300.00
0005432784299	15380	Economy	9300.00
0005432784371	15380	Economy	9300.00
0005432784205	15380	Economy	9300.00
0005435243341	15380	Economy	9300.00
0005435243328	15380	Economy	9300.00
0005432784325	15380	Economy	9300.00
0005432784265	15380	Economy	9300.00
0005432784452	15380	Economy	9300.00
0005435243343	15380	Economy	9300.00
0005432784358	15380	Economy	9300.00
0005432784186	15380	Economy	9300.00
0005432784340	15380	Economy	9300.00
0005435243324	15380	Economy	9300.00
0005432784210	15380	Economy	9300.00
0005435476885	15380	Economy	9300.00
0005432784209	15380	Economy	9300.00
0005432784229	15380	Economy	9300.00
0005432784383	15380	Economy	9300.00
0005432784206	15380	Economy	9300.00
0005432784384	15380	Economy	9300.00
0005432784280	15380	Economy	9300.00
0005435476883	15380	Economy	9300.00
0005432784244	15380	Economy	9300.00
0005432784375	15380	Economy	9300.00
0005435243326	15380	Economy	9300.00
0005432784181	15380	Economy	9300.00
0005432784191	15380	Economy	9300.00
0005435243331	15380	Economy	9300.00
0005435243322	15380	Economy	9300.00
0005432784298	15380	Economy	9300.00
0005435243330	15380	Economy	9300.00
0005432784339	15380	Economy	9300.00
0005432784270	15380	Economy	9300.00
0005435243323	15380	Economy	9300.00
0005432784359	15380	Economy	9300.00
0005435243340	15380	Economy	9300.00
0005432784693	15380	Economy	9300.00
0005435243327	15380	Economy	9300.00
0005432784502	15380	Economy	9300.00
0005435243336	15380	Economy	9300.00
0005432784349	15380	Economy	9300.00
0005432784269	15380	Economy	9300.00
0005435243320	15380	Economy	9300.00
0005432784385	15380	Economy	9300.00
0005432784372	15380	Economy	9300.00
0005435243344	15380	Economy	9300.00
0005432784190	15380	Economy	9300.00
0005435476884	15380	Economy	9300.00
0005435243335	15380	Economy	9300.00
0005432784276	15380	Economy	9300.00
0005432784307	15380	Economy	9300.00
0005432784401	15380	Economy	9300.00
0005432784412	15380	Economy	9300.00
0005432784261	15380	Economy	9300.00
0005432784429	15380	Economy	9300.00
0005432784166	15380	Economy	9300.00
0005435243333	15380	Economy	9300.00
0005432784160	15380	Economy	9300.00
0005432784179	15380	Economy	9300.00
0005435243321	15380	Economy	9300.00
0005435243329	15380	Economy	9300.00
0005435243319	15380	Economy	9300.00
0005432784308	15380	Economy	9300.00
0005435243337	15380	Economy	9300.00
0005432848589	4383	Economy	7000.00
0005432848590	4383	Economy	7000.00
0005435851037	4383	Economy	7000.00
0005434463970	4383	Economy	7000.00
0005432848583	4383	Economy	6300.00
0005432848579	4383	Economy	6300.00
0005434463971	4383	Economy	6300.00
0005432848578	4383	Economy	6300.00
0005432848576	4383	Economy	6300.00
0005435851024	4383	Economy	6300.00
0005432848577	4383	Economy	6300.00
0005435851026	4383	Economy	6300.00
0005434462830	4383	Economy	6300.00
0005435851045	4383	Economy	6300.00
0005434462831	4383	Economy	6300.00
0005432848584	4383	Economy	6300.00
0005432848575	4383	Economy	6300.00
0005432848581	4383	Economy	6300.00
0005435851013	4383	Economy	6300.00
0005435851012	4383	Economy	6300.00
0005435851034	4383	Economy	6300.00
0005434463969	4383	Economy	6300.00
0005432848580	4383	Economy	6300.00
0005432848582	4383	Economy	6300.00
0005435851014	4383	Economy	6300.00
0005435851027	4383	Economy	6300.00
0005435851011	4383	Economy	6300.00
0005432848585	4383	Economy	6300.00
0005435851025	4383	Economy	6300.00
0005434463968	4383	Economy	6300.00
0005432848586	4383	Economy	6300.00
0005432848587	4383	Economy	6300.00
0005432848588	4383	Economy	6300.00
0005432848457	28841	Economy	7000.00
0005435851081	28841	Economy	7000.00
0005434461659	28841	Economy	6300.00
0005434461665	28841	Economy	6300.00
0005434463954	28841	Economy	6300.00
0005432848467	28841	Economy	6300.00
0005435851082	28841	Economy	6300.00
0005432848451	28841	Economy	6300.00
0005432848399	28841	Economy	6300.00
0005435851079	28841	Economy	6300.00
0005432848463	28841	Economy	6300.00
0005432848484	28841	Economy	6300.00
0005434463943	28841	Economy	6300.00
0005435851075	28841	Economy	6300.00
0005432848458	28841	Economy	6300.00
0005432848464	28841	Economy	6300.00
0005434463945	28841	Economy	6300.00
0005435851083	28841	Economy	6300.00
0005432848482	28841	Economy	6300.00
0005432848483	28841	Economy	6300.00
0005432848462	28841	Economy	6300.00
0005435851078	28841	Economy	6300.00
0005435851080	28841	Economy	6300.00
0005434463944	28841	Economy	6300.00
0005432848475	28841	Economy	6300.00
0005432848419	28841	Economy	6300.00
0005432848450	28841	Economy	6300.00
0005435851077	28841	Economy	6300.00
0005432848494	28841	Economy	6300.00
0005434461658	28841	Economy	6300.00
0005432848459	28841	Economy	6300.00
0005434461664	28841	Economy	6300.00
0005432848489	28841	Economy	6300.00
0005435851076	28841	Economy	6300.00
0005432848400	28841	Economy	6300.00
0005435851084	28841	Economy	6300.00
0005434926397	6325	Business	11900.00
0005434926393	6325	Business	11900.00
0005434926404	6325	Business	11900.00
0005434926376	6325	Business	11900.00
0005432075296	6325	Business	11900.00
0005434444009	6325	Business	11900.00
0005434926378	6325	Business	11900.00
0005433497546	6325	Business	11900.00
0005433497540	6325	Business	11900.00
0005434444007	6325	Business	11900.00
0005434444006	6325	Business	11900.00
0005434444004	6325	Economy	4000.00
0005434926383	6325	Economy	4000.00
0005433497550	6325	Economy	4000.00
0005433497547	6325	Economy	4000.00
0005434926394	6325	Economy	4000.00
0005434444008	6325	Economy	4000.00
0005433497545	6325	Economy	4000.00
0005434926400	6325	Economy	4400.00
0005434926375	6325	Economy	4400.00
0005433497560	6325	Economy	4400.00
0005433497553	6325	Economy	4400.00
0005433497548	6325	Economy	4000.00
0005433497557	6325	Economy	4000.00
0005433497549	6325	Economy	4000.00
0005434444017	6325	Economy	4000.00
0005433497551	6325	Economy	4000.00
0005433497565	6325	Economy	4000.00
0005433497543	6325	Economy	4000.00
0005433497552	6325	Economy	4000.00
0005434444012	6325	Economy	4000.00
0005434444015	6325	Economy	4000.00
0005434926377	6325	Economy	4000.00
0005434926373	6325	Economy	4000.00
0005434926398	6325	Economy	4000.00
0005434926379	6325	Economy	4000.00
0005434926401	6325	Economy	4000.00
0005434444016	6325	Economy	4000.00
0005433497558	6325	Economy	4000.00
0005433497559	6325	Economy	4000.00
0005433497562	6325	Economy	4000.00
0005434444013	6325	Economy	4000.00
0005434926402	6325	Economy	4000.00
0005434926388	6325	Economy	4000.00
0005434926396	6325	Economy	4000.00
0005434926387	6325	Economy	4000.00
0005434926380	6325	Economy	4000.00
0005434926390	6325	Economy	4000.00
0005433497568	6325	Economy	4000.00
0005433497544	6325	Economy	4000.00
0005434926389	6325	Economy	4000.00
0005433497556	6325	Economy	4000.00
0005434926399	6325	Economy	4000.00
0005432075295	6325	Economy	4000.00
0005433497539	6325	Economy	4000.00
0005432075294	6325	Economy	4000.00
0005433497542	6325	Economy	4000.00
0005433497564	6325	Economy	4000.00
0005434444018	6325	Economy	4000.00
0005434926374	6325	Economy	4000.00
0005434926392	6325	Economy	4000.00
0005434444014	6325	Economy	4000.00
0005434926372	6325	Economy	4000.00
0005434444010	6325	Economy	4000.00
0005433497541	6325	Economy	4000.00
0005434926403	6325	Economy	4000.00
0005434444011	6325	Economy	4000.00
0005432075293	6325	Economy	4000.00
0005434926382	6325	Economy	4000.00
0005433497555	6325	Economy	4000.00
0005434926395	6325	Economy	4000.00
0005434926381	6325	Economy	4000.00
0005433497554	6325	Economy	4000.00
0005434444005	6325	Economy	4000.00
0005434926386	6325	Economy	4000.00
0005434926391	6325	Economy	4000.00
0005433497567	6325	Economy	4000.00
0005433497561	6325	Economy	4000.00
0005434926385	6325	Economy	4000.00
0005434926384	6325	Economy	4000.00
0005433497563	6325	Economy	4000.00
0005433497566	6325	Economy	4000.00
0005435257399	20347	Business	11900.00
0005435257402	20347	Economy	4000.00
0005435257401	20347	Economy	4000.00
0005435257404	20347	Economy	4000.00
0005435257400	20347	Economy	4000.00
0005435257406	20347	Economy	4000.00
0005435257405	20347	Economy	4000.00
0005435257403	20347	Economy	4000.00
0005433497309	20350	Business	11900.00
0005433497297	20350	Business	11900.00
0005433497292	20350	Business	11900.00
0005433497285	20350	Business	11900.00
0005433497234	20350	Business	11900.00
0005433497235	20350	Business	11900.00
0005434926169	20350	Business	11900.00
0005434926134	20350	Business	11900.00
0005433497255	20350	Business	11900.00
0005434926101	20350	Business	11900.00
0005433497341	20350	Business	11900.00
0005434926061	20350	Economy	4000.00
0005434926195	20350	Economy	4000.00
0005434443879	20350	Economy	4000.00
0005434926160	20350	Economy	4000.00
0005433497391	20350	Economy	4000.00
0005434443793	20350	Economy	4000.00
0005433497276	20350	Economy	4400.00
0005434926164	20350	Economy	4400.00
0005433497248	20350	Economy	4400.00
0005434926081	20350	Economy	4400.00
0005434926069	20350	Economy	4400.00
0005433497156	20350	Economy	4000.00
0005433497302	20350	Economy	4000.00
0005434925896	20350	Economy	4000.00
0005434926118	20350	Economy	4000.00
0005434443880	20350	Economy	4000.00
0005434443796	20350	Economy	4000.00
0005433497312	20350	Economy	4000.00
0005433497268	20350	Economy	4000.00
0005433497436	20350	Economy	4000.00
0005434443876	20350	Economy	4000.00
0005434926102	20350	Economy	4000.00
0005434926041	20350	Economy	4000.00
0005433497253	20350	Economy	4000.00
0005433497313	20350	Economy	4000.00
0005434926145	20350	Economy	4000.00
0005433497296	20350	Economy	4000.00
0005434925986	20350	Economy	4000.00
0005433497192	20350	Economy	4000.00
0005433497273	20350	Economy	4000.00
0005434443895	20350	Economy	4000.00
0005434443844	20350	Economy	4000.00
0005433497342	20350	Economy	4000.00
0005433497307	20350	Economy	4000.00
0005433497262	20350	Economy	4000.00
0005434926026	20350	Economy	4000.00
0005434926027	20350	Economy	4000.00
0005433497221	20350	Economy	4000.00
0005434926109	20350	Economy	4000.00
0005434443896	20350	Economy	4000.00
0005433497416	20350	Economy	4000.00
0005434443881	20350	Economy	4000.00
0005434926168	20350	Economy	4000.00
0005434926018	20350	Economy	4000.00
0005433497405	20350	Economy	4000.00
0005434926133	20350	Economy	4000.00
0005433497208	20350	Economy	4000.00
0005434443893	20350	Economy	4000.00
0005433497417	20350	Economy	4000.00
0005434926039	20350	Economy	4000.00
0005433497252	20350	Economy	4000.00
0005434926040	20350	Economy	4000.00
0005433497194	20350	Economy	4000.00
0005434926074	20350	Economy	4000.00
0005434926076	20350	Economy	4000.00
0005433497301	20350	Economy	4000.00
0005434443897	20350	Economy	4000.00
0005434926131	20350	Economy	4000.00
0005433497275	20350	Economy	4000.00
0005433497311	20350	Economy	4000.00
0005433497193	20350	Economy	4000.00
0005434926194	20350	Economy	4000.00
0005434443792	20350	Economy	4000.00
0005434443892	20350	Economy	4000.00
0005434926015	20350	Economy	4000.00
0005435243348	12177	Business	41200.00
0005432784247	12177	Business	41200.00
0005432784500	12177	Business	41200.00
0005432784302	12177	Business	41200.00
0005435243362	12177	Business	41200.00
0005432784364	12177	Business	41200.00
0005435243358	12177	Business	41200.00
0005432784590	12177	Business	41200.00
0005432784197	12177	Business	41200.00
0005432784263	12177	Economy	13700.00
0005435243365	12177	Economy	13700.00
0005432784416	12177	Economy	13700.00
0005432784313	12177	Economy	13700.00
0005432784434	12177	Economy	13700.00
0005432784376	12177	Economy	13700.00
0005432784345	12177	Economy	13700.00
0005432784382	12177	Economy	13700.00
0005432784462	12177	Economy	13700.00
0005435243371	12177	Economy	15100.00
0005435243360	12177	Economy	15100.00
0005432784259	12177	Economy	15100.00
0005435243352	12177	Economy	15100.00
0005432784063	12177	Economy	13700.00
0005432784405	12177	Economy	13700.00
0005435243356	12177	Economy	13700.00
0005432784246	12177	Economy	13700.00
0005432784238	12177	Economy	13700.00
0005432784141	12177	Economy	13700.00
0005432784531	12177	Economy	13700.00
0005432784337	12177	Economy	13700.00
0005432784498	12177	Economy	13700.00
0005432784317	12177	Economy	13700.00
0005435243367	12177	Economy	13700.00
0005435243346	12177	Economy	13700.00
0005432784499	12177	Economy	13700.00
0005435243359	12177	Economy	13700.00
0005432784497	12177	Economy	13700.00
0005432784198	12177	Economy	13700.00
0005435243363	12177	Economy	13700.00
0005435243347	12177	Economy	13700.00
0005432784368	12177	Economy	13700.00
0005432784111	12177	Economy	13700.00
0005432784346	12177	Economy	13700.00
0005435243353	12177	Economy	13700.00
0005432784377	12177	Economy	13700.00
0005432784338	12177	Economy	13700.00
0005435243368	12177	Economy	13700.00
0005435243373	12177	Economy	13700.00
0005435243372	12177	Economy	13700.00
0005432784451	12177	Economy	13700.00
0005435243361	12177	Economy	13700.00
0005432784312	12177	Economy	13700.00
0005435243369	12177	Economy	13700.00
0005432784393	12177	Economy	13700.00
0005432784588	12177	Economy	13700.00
0005432784329	12177	Economy	13700.00
0005435243370	12177	Economy	13700.00
0005432784541	12177	Economy	13700.00
0005435243345	12177	Economy	13700.00
0005432784343	12177	Economy	13700.00
0005435243354	12177	Economy	13700.00
0005432784417	12177	Economy	13700.00
0005435243364	12177	Economy	13700.00
0005435243350	12177	Economy	13700.00
0005432784344	12177	Economy	13700.00
0005432784433	12177	Economy	13700.00
0005432784589	12177	Economy	13700.00
0005432784221	12177	Economy	13700.00
0005432784293	12177	Economy	13700.00
0005432784450	12177	Economy	13700.00
0005432784395	12177	Economy	13700.00
0005432784274	12177	Economy	13700.00
0005432784062	12177	Economy	13700.00
0005435243355	12177	Economy	13700.00
0005435243351	12177	Economy	13700.00
0005435243357	12177	Economy	13700.00
0005432784394	12177	Economy	13700.00
0005432784414	12177	Economy	13700.00
0005435243366	12177	Economy	13700.00
0005432784489	12177	Economy	13700.00
0005432784213	12177	Economy	13700.00
0005435243349	12177	Economy	13700.00
0005432784301	12177	Economy	13700.00
0005435243089	15396	Business	41200.00
0005435243041	15396	Business	41200.00
0005432784759	15396	Business	41200.00
0005432784714	15396	Business	41200.00
0005432784766	15396	Business	41200.00
0005432784744	15396	Business	41200.00
0005432784721	15396	Business	41200.00
0005432784717	15396	Business	41200.00
0005432784746	15396	Business	41200.00
0005435243095	15396	Economy	13700.00
0005432784734	15396	Economy	13700.00
0005432784753	15396	Economy	13700.00
0005432784731	15396	Economy	13700.00
0005435243159	15396	Economy	13700.00
0005435243090	15396	Economy	13700.00
0005432784758	15396	Economy	13700.00
0005435243120	15396	Economy	13700.00
0005432784754	15396	Economy	15100.00
0005432784719	15396	Economy	15100.00
0005435243006	15396	Economy	13700.00
0005432784733	15396	Economy	13700.00
0005432784736	15396	Economy	13700.00
0005432784720	15396	Economy	13700.00
0005435243039	15396	Economy	13700.00
0005432784756	15396	Economy	13700.00
0005432784755	15396	Economy	13700.00
0005432784725	15396	Economy	13700.00
0005432784718	15396	Economy	13700.00
0005432784763	15396	Economy	13700.00
0005432784712	15396	Economy	13700.00
0005432784739	15396	Economy	13700.00
0005432784747	15396	Economy	13700.00
0005432784751	15396	Economy	13700.00
0005435243051	15396	Economy	13700.00
0005432784730	15396	Economy	13700.00
0005432784711	15396	Economy	13700.00
0005435243096	15396	Economy	13700.00
0005432784760	15396	Economy	13700.00
0005432784743	15396	Economy	13700.00
0005435243042	15396	Economy	13700.00
0005435243109	15396	Economy	13700.00
0005435243201	15396	Economy	13700.00
0005435243158	15396	Economy	13700.00
0005432784737	15396	Economy	13700.00
0005432784735	15396	Economy	13700.00
0005432784729	15396	Economy	13700.00
0005435243045	15396	Economy	13700.00
0005432784762	15396	Economy	13700.00
0005435243119	15396	Economy	13700.00
0005435242916	15396	Economy	13700.00
0005432784765	15396	Economy	13700.00
0005432784713	15396	Economy	13700.00
0005432784724	15396	Economy	13700.00
0005432784715	15396	Economy	13700.00
0005432784732	15396	Economy	13700.00
0005432784761	15396	Economy	13700.00
0005432784750	15396	Economy	13700.00
0005435243130	15396	Economy	13700.00
0005432784764	15396	Economy	13700.00
0005432784716	15396	Economy	13700.00
0005432784723	15396	Economy	13700.00
0005432784738	15396	Economy	13700.00
0005435243040	15396	Economy	13700.00
0005432784741	15396	Economy	13700.00
0005432784728	15396	Economy	13700.00
0005435243076	15396	Economy	13700.00
0005435243097	15396	Economy	13700.00
0005432784740	15396	Economy	13700.00
0005432784757	15396	Economy	13700.00
0005432784752	15396	Economy	13700.00
0005432784727	15396	Economy	13700.00
0005432784748	15396	Economy	13700.00
0005432784749	15396	Economy	13700.00
0005432784722	15396	Economy	13700.00
0005435243106	15396	Economy	13700.00
0005435243177	15396	Economy	13700.00
0005432784742	15396	Economy	13700.00
0005432784745	15396	Economy	13700.00
0005432784726	15396	Economy	13700.00
0005434878995	10089	Business	49700.00
0005434878946	10089	Business	49700.00
0005434879223	10089	Business	49700.00
0005434879056	10089	Business	49700.00
0005434879245	10089	Business	49700.00
0005434879030	10089	Business	49700.00
0005434879191	10089	Business	49700.00
0005434879031	10089	Business	49700.00
0005434879281	10089	Business	49700.00
0005434879005	10089	Business	49700.00
0005434879079	10089	Business	49700.00
0005434879305	10089	Business	49700.00
0005434879486	10089	Business	49700.00
0005434879040	10089	Business	49700.00
0005434879172	10089	Business	49700.00
0005434879006	10089	Business	49700.00
0005434879448	10089	Business	49700.00
0005434878942	10089	Business	49700.00
0005434878876	10089	Business	49700.00
0005434879397	10089	Business	49700.00
0005434879225	10089	Economy	16600.00
0005434878638	10089	Economy	16600.00
0005434878892	10089	Economy	16600.00
0005434879065	10089	Economy	16600.00
0005434878996	10089	Economy	16600.00
0005434879228	10089	Economy	16600.00
0005434879229	10089	Economy	16600.00
0005434878937	10089	Economy	16600.00
0005434879394	10089	Economy	16600.00
0005434879199	10089	Economy	16600.00
0005434879047	10089	Economy	16600.00
0005434879089	10089	Economy	16600.00
0005434879345	10089	Economy	18200.00
0005434879226	10089	Economy	16600.00
0005434879485	10089	Economy	18200.00
0005434879490	10089	Economy	18200.00
0005434879208	10089	Economy	16600.00
0005434879505	10089	Economy	18200.00
0005434878943	10089	Economy	16600.00
0005434879154	10089	Economy	16600.00
0005434879097	10089	Economy	16600.00
0005434879319	10089	Economy	16600.00
0005434878931	10089	Economy	16600.00
0005434879121	10089	Economy	16600.00
0005434879295	10089	Economy	16600.00
0005434878893	10089	Economy	16600.00
0005434879344	10089	Economy	16600.00
0005434879206	10089	Economy	16600.00
0005434879194	10089	Economy	16600.00
0005434758915	10089	Economy	16600.00
0005434879120	10089	Economy	16600.00
0005434878930	10089	Economy	16600.00
0005434879411	10089	Economy	16600.00
0005434879119	10089	Economy	16600.00
0005434879161	10089	Economy	16600.00
0005434879175	10089	Economy	16600.00
0005434879298	10089	Economy	16600.00
0005434878945	10089	Economy	16600.00
0005434879489	10089	Economy	16600.00
0005434879066	10089	Economy	16600.00
0005434879456	10089	Economy	16600.00
0005434879283	10089	Economy	16600.00
0005434879193	10089	Economy	16600.00
0005434879297	10089	Economy	16600.00
0005434879173	10089	Economy	16600.00
0005434879182	10089	Economy	16600.00
0005434879122	10089	Economy	16600.00
0005434879335	10089	Economy	16600.00
0005434879495	10089	Economy	16600.00
0005434878693	10089	Economy	16600.00
0005434758920	10089	Economy	16600.00
0005434879200	10089	Economy	16600.00
0005434879039	10089	Economy	16600.00
0005434879063	10089	Economy	16600.00
0005434878944	10089	Economy	16600.00
0005434879265	10089	Economy	16600.00
0005434879398	10089	Economy	16600.00
0005434879224	10089	Economy	16600.00
0005434879014	10089	Economy	16600.00
0005434879179	10089	Economy	16600.00
0005434879085	10089	Economy	16600.00
0005434879095	10089	Economy	16600.00
0005434879153	10089	Economy	16600.00
0005434879165	10089	Economy	16600.00
0005434879272	10089	Economy	16600.00
0005434879091	10089	Economy	16600.00
0005434879393	10089	Economy	16600.00
0005434758921	10089	Economy	16600.00
0005434879296	10089	Economy	16600.00
0005434879336	10089	Economy	16600.00
0005434879320	10089	Economy	16600.00
0005434879207	10089	Economy	16600.00
0005434879469	10089	Economy	16600.00
0005434879077	10089	Economy	16600.00
0005434879103	10089	Economy	16600.00
0005434879038	10089	Economy	16600.00
0005434879078	10089	Economy	16600.00
0005434879086	10089	Economy	16600.00
0005434879468	10089	Economy	16600.00
0005434879382	10089	Economy	16600.00
0005434878873	10089	Economy	16600.00
0005434879271	10089	Economy	16600.00
0005434879174	10089	Economy	16600.00
0005434879004	10089	Economy	16600.00
0005434879306	10089	Economy	16600.00
0005434879351	10089	Economy	16600.00
0005434879090	10089	Economy	16600.00
0005434879201	10089	Economy	16600.00
0005434879060	10089	Economy	16600.00
0005434879264	10089	Economy	16600.00
0005434878868	10089	Economy	16600.00
0005434879350	10089	Economy	16600.00
0005434879282	10089	Economy	16600.00
0005434879045	10089	Economy	16600.00
0005434878950	10089	Economy	16600.00
0005434879261	10089	Economy	16600.00
0005434879997	14654	Business	49700.00
0005434879956	14654	Business	49700.00
0005434879954	14654	Business	49700.00
0005434880011	14654	Business	49700.00
0005434879980	14654	Business	49700.00
0005435913945	14654	Business	49700.00
0005434879922	14654	Business	49700.00
0005434910144	14654	Business	49700.00
0005434879939	14654	Business	49700.00
0005434879977	14654	Business	49700.00
0005434879933	14654	Business	49700.00
0005434879965	14654	Business	49700.00
0005434880006	14654	Business	49700.00
0005434758937	14654	Business	49700.00
0005434880007	14654	Business	49700.00
0005434880018	14654	Business	49700.00
0005434880003	14654	Business	49700.00
0005434879962	14654	Business	49700.00
0005434879952	14654	Economy	16600.00
0005434879996	14654	Economy	16600.00
0005434879995	14654	Economy	16600.00
0005434879957	14654	Economy	16600.00
0005434879961	14654	Economy	16600.00
0005434879937	14654	Economy	16600.00
0005434879978	14654	Economy	16600.00
0005434880004	14654	Economy	16600.00
0005434879972	14654	Economy	16600.00
0005434879955	14654	Economy	18200.00
0005434879974	14654	Economy	18200.00
0005434880014	14654	Economy	18200.00
0005434879924	14654	Economy	16600.00
0005434879930	14654	Economy	18200.00
0005434879958	14654	Economy	16600.00
0005434879943	14654	Economy	16600.00
0005434880016	14654	Economy	16600.00
0005434879976	14654	Economy	16600.00
0005434879942	14654	Economy	16600.00
0005434879963	14654	Economy	16600.00
0005434880005	14654	Economy	16600.00
0005434880009	14654	Economy	16600.00
0005434879953	14654	Economy	16600.00
0005434879945	14654	Economy	16600.00
0005434879923	14654	Economy	16600.00
0005434879929	14654	Economy	16600.00
0005434879981	14654	Economy	16600.00
0005434879940	14654	Economy	16600.00
0005434879973	14654	Economy	16600.00
0005434880008	14654	Economy	16600.00
0005434879979	14654	Economy	16600.00
0005434879931	14654	Economy	16600.00
0005434879999	14654	Economy	16600.00
0005434879967	14654	Economy	16600.00
0005434879947	14654	Economy	16600.00
0005434879964	14654	Economy	16600.00
0005434879936	14654	Economy	16600.00
0005434879969	14654	Economy	16600.00
0005434879925	14654	Economy	16600.00
0005434879984	14654	Economy	16600.00
0005434879959	14654	Economy	16600.00
0005434880015	14654	Economy	16600.00
0005434879992	14654	Economy	16600.00
0005434879941	14654	Economy	16600.00
0005434879998	14654	Economy	16600.00
0005435913959	14654	Economy	16600.00
0005434879951	14654	Economy	16600.00
0005434879990	14654	Economy	16600.00
0005434879991	14654	Economy	16600.00
0005434879968	14654	Economy	16600.00
0005434880002	14654	Economy	16600.00
0005434879988	14654	Economy	16600.00
0005434879993	14654	Economy	16600.00
0005434879987	14654	Economy	16600.00
0005434880000	14654	Economy	16600.00
0005434879926	14654	Economy	16600.00
0005434879970	14654	Economy	16600.00
0005434879949	14654	Economy	16600.00
0005434879960	14654	Economy	16600.00
0005434879975	14654	Economy	16600.00
0005434879927	14654	Economy	16600.00
0005434879946	14654	Economy	16600.00
0005434879982	14654	Economy	16600.00
0005434879994	14654	Economy	16600.00
0005434879986	14654	Economy	16600.00
0005434879935	14654	Economy	16600.00
0005434879985	14654	Economy	16600.00
0005434879989	14654	Economy	16600.00
0005434879928	14654	Economy	16600.00
0005434879966	14654	Economy	16600.00
0005434880013	14654	Economy	16600.00
0005434879948	14654	Economy	16600.00
0005434880017	14654	Economy	16600.00
0005434879971	14654	Economy	16600.00
0005434758936	14654	Economy	16600.00
0005434879950	14654	Economy	16600.00
0005434879932	14654	Economy	16600.00
0005434879938	14654	Economy	16600.00
0005434879934	14654	Economy	16600.00
0005434879944	14654	Economy	16600.00
0005434880010	14654	Economy	16600.00
0005434880012	14654	Economy	16600.00
0005434879983	14654	Economy	16600.00
0005434880001	14654	Economy	16600.00
0005435913944	14654	Economy	16600.00
0005435660343	9234	Economy	22400.00
0005435660350	9234	Economy	22400.00
0005435660349	9234	Economy	20300.00
0005434252038	9234	Economy	20300.00
0005435660345	9234	Economy	20300.00
0005434252041	9234	Economy	20300.00
0005434252039	9234	Economy	20300.00
0005435660344	9234	Economy	20300.00
0005434252070	9234	Economy	20300.00
0005435660347	9234	Economy	20300.00
0005434252059	9234	Economy	20300.00
0005435660348	9234	Economy	20300.00
0005435660346	9234	Economy	20300.00
0005434252048	9234	Economy	20300.00
0005435660341	9234	Economy	20300.00
0005434252040	9234	Economy	20300.00
0005434252060	9234	Economy	20300.00
0005435660342	9234	Economy	20300.00
0005434252030	9234	Economy	20300.00
0005435660340	9234	Economy	20300.00
0005435660266	24675	Economy	22400.00
0005434252143	24675	Economy	22400.00
0005435660244	24675	Economy	22400.00
0005434252144	24675	Economy	20300.00
0005434252140	24675	Economy	20300.00
0005435660260	24675	Economy	20300.00
0005435660263	24675	Economy	20300.00
0005435660219	24675	Economy	20300.00
0005435660250	24675	Economy	20300.00
0005435660265	24675	Economy	20300.00
0005435660220	24675	Economy	20300.00
0005434252137	24675	Economy	20300.00
0005435660246	24675	Economy	20300.00
0005435660185	24675	Economy	20300.00
0005435660243	24675	Economy	20300.00
0005434252139	24675	Economy	20300.00
0005434252141	24675	Economy	20300.00
0005435660277	24675	Economy	20300.00
0005435660255	24675	Economy	20300.00
0005435660269	24675	Economy	20300.00
0005434252138	24675	Economy	20300.00
0005435660271	24675	Economy	20300.00
0005435660264	24675	Economy	20300.00
0005434252142	24675	Economy	20300.00
0005435660225	24675	Economy	20300.00
0005432967237	2782	Business	33000.00
0005433681454	2782	Business	33000.00
0005432222880	2782	Business	33000.00
0005433681466	2782	Business	33000.00
0005433681435	2782	Business	33000.00
0005432967254	2782	Business	33000.00
0005433681445	2782	Business	33000.00
0005432967210	2782	Business	33000.00
0005432967261	2782	Economy	11000.00
0005433684458	2782	Economy	11000.00
0005433681455	2782	Economy	11000.00
0005433681465	2782	Economy	11000.00
0005433681446	2782	Economy	11000.00
0005433681438	2782	Economy	11000.00
0005433681469	2782	Economy	11000.00
0005433681457	2782	Economy	12100.00
0005433681460	2782	Economy	12100.00
0005433681437	2782	Economy	12100.00
0005432967208	2782	Economy	12100.00
0005433681447	2782	Economy	11000.00
0005433681421	2782	Economy	11000.00
0005433681431	2782	Economy	11000.00
0005433681442	2782	Economy	11000.00
0005432967218	2782	Economy	11000.00
0005432222878	2782	Economy	11000.00
0005432222882	2782	Economy	11000.00
0005432967310	2782	Economy	11000.00
0005432222879	2782	Economy	11000.00
0005432967255	2782	Economy	11000.00
0005433681461	2782	Economy	11000.00
0005432967052	2782	Economy	11000.00
0005433681458	2782	Economy	11000.00
0005433681462	2782	Economy	11000.00
0005433681444	2782	Economy	11000.00
0005433681425	2782	Economy	11000.00
0005432967252	2782	Economy	11000.00
0005433681456	2782	Economy	11000.00
0005433681436	2782	Economy	11000.00
0005432967153	2782	Economy	11000.00
0005433681423	2782	Economy	11000.00
0005433681468	2782	Economy	11000.00
0005432967152	2782	Economy	11000.00
0005432967161	2782	Economy	11000.00
0005432222881	2782	Economy	11000.00
0005433681451	2782	Economy	11000.00
0005432222877	2782	Economy	11000.00
0005433681443	2782	Economy	11000.00
0005433681420	2782	Economy	11000.00
0005433681452	2782	Economy	11000.00
0005433681467	2782	Economy	11000.00
0005432967311	2782	Economy	11000.00
0005432967238	2782	Economy	11000.00
0005433681448	2782	Economy	11000.00
0005432967211	2782	Economy	11000.00
0005433681428	2782	Economy	11000.00
0005433681463	2782	Economy	11000.00
0005433681439	2782	Economy	11000.00
0005432967096	2782	Economy	11000.00
0005433681453	2782	Economy	11000.00
0005433681464	2782	Economy	11000.00
0005433681432	2782	Economy	11000.00
0005433681440	2782	Economy	11000.00
0005433681429	2782	Economy	11000.00
0005432967212	2782	Economy	11000.00
0005433681449	2782	Economy	11000.00
0005433681426	2782	Economy	11000.00
0005433681433	2782	Economy	11000.00
0005432967162	2782	Economy	11000.00
0005432967262	2782	Economy	11000.00
0005433681430	2782	Economy	11000.00
0005433681459	2782	Economy	11000.00
0005433684457	2782	Economy	11000.00
0005433681422	2782	Economy	11000.00
0005432967151	2782	Economy	11000.00
0005432967167	2782	Economy	11000.00
0005433681434	2782	Economy	11000.00
0005433681427	2782	Economy	11000.00
0005433681424	2782	Economy	11000.00
0005433681450	2782	Economy	11000.00
0005433681441	2782	Economy	11000.00
0005432967419	29194	Business	33000.00
0005433681024	29194	Business	33000.00
0005432967398	29194	Business	33000.00
0005433681069	29194	Business	33000.00
0005432967417	29194	Business	33000.00
0005433681305	29194	Business	33000.00
0005432967412	29194	Business	33000.00
0005432967415	29194	Economy	11000.00
0005433687730	29194	Economy	11000.00
0005432967416	29194	Economy	11000.00
0005432967418	29194	Economy	11000.00
0005433681051	29194	Economy	11000.00
0005432967397	29194	Economy	11000.00
0005432005265	29194	Economy	11000.00
0005433680944	29194	Economy	11000.00
0005433681165	29194	Economy	12100.00
0005432967403	29194	Economy	12100.00
0005433681070	29194	Economy	12100.00
0005433681023	29194	Economy	11000.00
0005432967411	29194	Economy	11000.00
0005432967413	29194	Economy	11000.00
0005432967400	29194	Economy	11000.00
0005433680945	29194	Economy	11000.00
0005433680973	29194	Economy	11000.00
0005432967402	29194	Economy	11000.00
0005433684440	29194	Economy	11000.00
0005433681243	29194	Economy	11000.00
0005433681196	29194	Economy	11000.00
0005432967399	29194	Economy	11000.00
0005433680910	29194	Economy	11000.00
0005432967408	29194	Economy	11000.00
0005433681054	29194	Economy	11000.00
0005433681132	29194	Economy	11000.00
0005433687732	29194	Economy	11000.00
0005433681270	29194	Economy	11000.00
0005432967401	29194	Economy	11000.00
0005433681255	29194	Economy	11000.00
0005433681156	29194	Economy	11000.00
0005433681242	29194	Economy	11000.00
0005432967394	29194	Economy	11000.00
0005433681114	29194	Economy	11000.00
0005432005264	29194	Economy	11000.00
0005432967414	29194	Economy	11000.00
0005433681109	29194	Economy	11000.00
0005432967396	29194	Economy	11000.00
0005433681038	29194	Economy	11000.00
0005433681076	29194	Economy	11000.00
0005432005266	29194	Economy	11000.00
0005433684451	29194	Economy	11000.00
0005432967407	29194	Economy	11000.00
0005433681052	29194	Economy	11000.00
0005432967410	29194	Economy	11000.00
0005433690950	29194	Economy	11000.00
0005433681271	29194	Economy	11000.00
0005433687733	29194	Economy	11000.00
0005432967409	29194	Economy	11000.00
0005433681195	29194	Economy	11000.00
0005433681108	29194	Economy	11000.00
0005433680972	29194	Economy	11000.00
0005433681194	29194	Economy	11000.00
0005433681099	29194	Economy	11000.00
0005433681157	29194	Economy	11000.00
0005432967406	29194	Economy	11000.00
0005432967395	29194	Economy	11000.00
0005432967404	29194	Economy	11000.00
0005432967405	29194	Economy	11000.00
0005433681304	29194	Economy	11000.00
0005433681189	29194	Economy	11000.00
0005433681100	29194	Economy	11000.00
0005432756910	9323	Business	132900.00
0005434163706	9323	Business	132900.00
0005433615967	9323	Business	132900.00
0005433615960	9323	Business	132900.00
0005433615951	9323	Business	132900.00
0005432145147	9323	Business	132900.00
0005433615968	9323	Business	132900.00
0005432755137	9323	Business	132900.00
0005433615972	9323	Business	132900.00
0005433578054	9323	Business	132900.00
0005433578051	9323	Business	132900.00
0005433578056	9323	Business	132900.00
0005433615975	9323	Business	132900.00
0005433634422	9323	Business	132900.00
0005434153543	9323	Business	132900.00
0005433615946	9323	Business	132900.00
0005433615959	9323	Business	132900.00
0005434272205	9323	Business	132900.00
0005433615990	9323	Business	132900.00
0005433615938	9323	Business	132900.00
0005433615970	9323	Business	132900.00
0005433615971	9323	Business	132900.00
0005434153540	9323	Business	132900.00
0005434163719	9323	Business	132900.00
0005433615966	9323	Business	132900.00
0005432756909	9323	Business	132900.00
0005433634414	9323	Economy	48700.00
0005434163698	9323	Economy	48700.00
0005432755136	9323	Economy	48700.00
0005433634400	9323	Economy	48700.00
0005433615981	9323	Economy	44300.00
0005433615931	9323	Economy	44300.00
0005433634423	9323	Economy	44300.00
0005433615982	9323	Economy	44300.00
0005433615949	9323	Economy	44300.00
0005433634402	9323	Economy	44300.00
0005433615997	9323	Economy	44300.00
0005433578055	9323	Economy	44300.00
0005434163709	9323	Economy	44300.00
0005433616001	9323	Economy	44300.00
0005434163683	9323	Economy	44300.00
0005433615987	9323	Economy	44300.00
0005433615988	9323	Economy	44300.00
0005433615932	9323	Economy	44300.00
0005433634409	9323	Economy	44300.00
0005433615994	9323	Economy	44300.00
0005433634426	9323	Economy	44300.00
0005432756908	9323	Economy	44300.00
0005433634413	9323	Economy	44300.00
0005433615945	9323	Economy	44300.00
0005433615957	9323	Economy	44300.00
0005433616000	9323	Economy	44300.00
0005433634407	9323	Economy	44300.00
0005433615953	9323	Economy	44300.00
0005433615943	9323	Economy	44300.00
0005433615934	9323	Economy	44300.00
0005433615956	9323	Economy	44300.00
0005433634434	9323	Economy	44300.00
0005433615995	9323	Economy	44300.00
0005433615964	9323	Economy	44300.00
0005433634433	9323	Economy	44300.00
0005434163704	9323	Economy	44300.00
0005433615993	9323	Economy	44300.00
0005433634412	9323	Economy	44300.00
0005433615952	9323	Economy	44300.00
0005433634404	9323	Economy	44300.00
0005433634415	9323	Economy	44300.00
0005433634416	9323	Economy	44300.00
0005433634410	9323	Economy	44300.00
0005433615977	9323	Economy	44300.00
0005433634418	9323	Economy	44300.00
0005433615976	9323	Economy	44300.00
0005433615940	9323	Economy	44300.00
0005433615998	9323	Economy	44300.00
0005433616005	9323	Economy	44300.00
0005433578061	9323	Economy	44300.00
0005433634429	9323	Economy	44300.00
0005433634425	9323	Economy	44300.00
0005433615961	9323	Economy	44300.00
0005433615947	9323	Economy	44300.00
0005433615991	9323	Economy	44300.00
0005433634405	9323	Economy	44300.00
0005433615983	9323	Economy	48700.00
0005433634403	9323	Economy	48700.00
0005433578059	9323	Economy	48700.00
0005433615992	9323	Economy	44300.00
0005433615933	9323	Economy	44300.00
0005433578050	9323	Economy	44300.00
0005433615948	9323	Economy	44300.00
0005433616003	9323	Economy	48700.00
0005433616004	9323	Economy	44300.00
0005433615973	9323	Economy	44300.00
0005433615999	9323	Economy	44300.00
0005433615941	9323	Economy	44300.00
0005433615980	9323	Economy	44300.00
0005433615963	9323	Economy	44300.00
0005433578052	9323	Economy	44300.00
0005433634427	9323	Economy	44300.00
0005434163737	9323	Economy	44300.00
0005433634401	9323	Economy	44300.00
0005433634421	9323	Economy	44300.00
0005433578062	9323	Economy	44300.00
0005433634428	9323	Economy	44300.00
0005433615986	9323	Economy	44300.00
0005434152813	9323	Economy	44300.00
0005433615942	9323	Economy	44300.00
0005433615958	9323	Economy	44300.00
0005434153541	9323	Economy	44300.00
0005433615989	9323	Economy	44300.00
0005433634432	9323	Economy	44300.00
0005433578060	9323	Economy	44300.00
0005433615979	9323	Economy	44300.00
0005433634420	9323	Economy	44300.00
0005433615937	9323	Economy	44300.00
0005432145148	9323	Economy	44300.00
0005433615974	9323	Economy	44300.00
0005433578057	9323	Economy	44300.00
0005433634419	9323	Economy	44300.00
0005433634411	9323	Economy	44300.00
0005433615939	9323	Economy	44300.00
0005433615969	9323	Economy	44300.00
0005433615944	9323	Economy	44300.00
0005433615978	9323	Economy	44300.00
0005433634406	9323	Economy	44300.00
0005433616002	9323	Economy	44300.00
0005433634408	9323	Economy	44300.00
0005433615954	9323	Economy	44300.00
0005433615965	9323	Economy	44300.00
0005433615950	9323	Economy	44300.00
0005434163697	9323	Economy	44300.00
0005433615984	9323	Economy	44300.00
0005433634430	9323	Economy	44300.00
0005433615935	9323	Economy	44300.00
0005433578053	9323	Economy	44300.00
0005433578058	9323	Economy	44300.00
0005434163738	9323	Economy	44300.00
0005434163705	9323	Economy	44300.00
0005433615962	9323	Economy	44300.00
0005433615996	9323	Economy	44300.00
0005433634424	9323	Economy	44300.00
0005433615936	9323	Economy	44300.00
0005433634435	9323	Economy	44300.00
0005433615955	9323	Economy	44300.00
0005433634431	9323	Economy	44300.00
0005433615985	9323	Economy	44300.00
0005433634417	9323	Economy	44300.00
0005433615361	25232	Business	132900.00
0005433615407	25232	Business	132900.00
0005433577957	25232	Business	132900.00
0005433615689	25232	Business	132900.00
0005433615439	25232	Business	132900.00
0005433577913	25232	Business	132900.00
0005433615440	25232	Business	132900.00
0005433615360	25232	Business	132900.00
0005432755074	25232	Business	132900.00
0005432755087	25232	Business	132900.00
0005433634051	25232	Business	132900.00
0005433615385	25232	Business	132900.00
0005433615409	25232	Business	132900.00
0005433615091	25232	Business	132900.00
0005433634323	25232	Business	132900.00
0005433615275	25232	Business	132900.00
0005433634021	25232	Business	132900.00
0005433615474	25232	Business	132900.00
0005433615475	25232	Business	132900.00
0005432751536	25232	Business	132900.00
0005433615363	25232	Business	132900.00
0005433615068	25232	Business	132900.00
0005432751546	25232	Business	132900.00
0005433615276	25232	Business	132900.00
0005433615553	25232	Business	132900.00
0005432755094	25232	Business	132900.00
0005433615401	25232	Economy	48700.00
0005433615702	25232	Economy	48700.00
0005433615478	25232	Economy	48700.00
0005433634168	25232	Economy	48700.00
0005433634193	25232	Economy	48700.00
0005432751539	25232	Economy	48700.00
0005433634231	25232	Economy	44300.00
0005433615381	25232	Economy	44300.00
0005433634324	25232	Economy	44300.00
0005432755091	25232	Economy	44300.00
0005432751553	25232	Economy	44300.00
0005432751541	25232	Economy	44300.00
0005433634137	25232	Economy	44300.00
0005433615508	25232	Economy	44300.00
0005433615362	25232	Economy	44300.00
0005433615154	25232	Economy	44300.00
0005432751550	25232	Economy	44300.00
0005433615227	25232	Economy	44300.00
0005433615378	25232	Economy	44300.00
0005433615092	25232	Economy	44300.00
0005433634100	25232	Economy	44300.00
0005432755073	25232	Economy	44300.00
0005433577973	25232	Economy	44300.00
0005433615552	25232	Economy	44300.00
0005433634006	25232	Economy	44300.00
0005433615576	25232	Economy	44300.00
0005433634129	25232	Economy	44300.00
0005433615417	25232	Economy	44300.00
0005433615575	25232	Economy	44300.00
0005433615453	25232	Economy	44300.00
0005433615441	25232	Economy	44300.00
0005433615171	25232	Economy	44300.00
0005433633952	25232	Economy	44300.00
0005433634267	25232	Economy	44300.00
0005433615191	25232	Economy	44300.00
0005433634167	25232	Economy	44300.00
0005434152824	25232	Economy	44300.00
0005433577930	25232	Economy	44300.00
0005433615246	25232	Economy	44300.00
0005433577974	25232	Economy	44300.00
0005433615090	25232	Economy	44300.00
0005433615264	25232	Economy	44300.00
0005433615423	25232	Economy	44300.00
0005433577975	25232	Economy	44300.00
0005433615389	25232	Economy	44300.00
0005433615204	25232	Economy	44300.00
0005433615452	25232	Economy	44300.00
0005433634219	25232	Economy	44300.00
0005433615373	25232	Economy	44300.00
0005433615217	25232	Economy	44300.00
0005433577934	25232	Economy	44300.00
0005432755095	25232	Economy	44300.00
0005433615290	25232	Economy	44300.00
0005433615368	25232	Economy	44300.00
0005433615640	25232	Economy	44300.00
0005433615274	25232	Economy	44300.00
0005433615543	25232	Economy	44300.00
0005433634131	25232	Economy	44300.00
0005433615400	25232	Economy	44300.00
0005432755097	25232	Economy	44300.00
0005432751554	25232	Economy	44300.00
0005432751558	25232	Economy	44300.00
0005433634139	25232	Economy	48700.00
0005433577958	25232	Economy	48700.00
0005433634230	25232	Economy	48700.00
0005433634189	25232	Economy	48700.00
0005433577955	25232	Economy	48700.00
0005433577971	25232	Economy	44300.00
0005433634160	25232	Economy	44300.00
0005433615120	25232	Economy	44300.00
0005433615358	25232	Economy	44300.00
0005433615190	25232	Economy	48700.00
0005432751535	25232	Economy	44300.00
0005433615289	25232	Economy	44300.00
0005433634103	25232	Economy	44300.00
0005433615067	25232	Economy	44300.00
0005433615175	25232	Economy	44300.00
0005433615399	25232	Economy	44300.00
0005433615450	25232	Economy	44300.00
0005433577954	25232	Economy	44300.00
0005433577924	25232	Economy	44300.00
0005433615570	25232	Economy	44300.00
0005433634071	25232	Economy	44300.00
0005433634101	25232	Economy	44300.00
0005433615169	25232	Economy	44300.00
0005433634132	25232	Economy	44300.00
0005433615446	25232	Economy	44300.00
0005432751534	25232	Economy	44300.00
0005433634056	25232	Economy	44300.00
0005433577923	25232	Economy	44300.00
0005433634036	25232	Economy	44300.00
0005433634128	25232	Economy	44300.00
0005432755103	25232	Economy	44300.00
0005433634113	25232	Economy	44300.00
0005433577914	25232	Economy	44300.00
0005433615454	25232	Economy	44300.00
0005433634143	25232	Economy	44300.00
0005433634144	25232	Economy	44300.00
0005432755089	25232	Economy	44300.00
0005433615374	25232	Economy	44300.00
0005432755090	25232	Economy	44300.00
0005433615121	25232	Economy	44300.00
0005433634072	25232	Economy	44300.00
0005433634224	25232	Economy	44300.00
0005433615240	25232	Economy	44300.00
0005433577912	25232	Economy	44300.00
0005433634014	25232	Economy	44300.00
0005432755088	25232	Economy	44300.00
0005432751545	25232	Economy	44300.00
0005432751547	25232	Economy	44300.00
0005433633989	25232	Economy	44300.00
0005432755110	25232	Economy	44300.00
0005433615245	25232	Economy	44300.00
0005433634074	25232	Economy	44300.00
0005432751551	25232	Economy	44300.00
0005433615155	25232	Economy	44300.00
0005432751549	25232	Economy	44300.00
0005433634073	25232	Economy	44300.00
0005432751555	25232	Economy	44300.00
0005433615247	25232	Economy	44300.00
0005432755075	25232	Economy	44300.00
0005433634218	25232	Economy	44300.00
0005433615182	25232	Economy	44300.00
0005432755100	25232	Economy	44300.00
0005433633953	25232	Economy	44300.00
0005433634223	25232	Economy	44300.00
0005432755104	25232	Economy	44300.00
0005433577956	25232	Economy	44300.00
0005432755111	25232	Economy	44300.00
0005433615294	25232	Economy	44300.00
0005433633992	25232	Economy	44300.00
0005433615205	25232	Economy	44300.00
0005435947468	4208	Business	193100.00
0005435856228	4208	Business	193100.00
0005435947373	4208	Business	193100.00
0005435787370	4208	Business	193100.00
0005435856226	4208	Economy	64400.00
0005432571364	4208	Economy	64400.00
0005432571368	4208	Economy	64400.00
0005432571338	4208	Economy	64400.00
0005432571361	4208	Economy	64400.00
0005435947410	4208	Economy	64400.00
0005435787371	4208	Economy	64400.00
0005435856227	4208	Economy	64400.00
0005432571339	4208	Economy	64400.00
0005435947375	4208	Economy	64400.00
0005435856237	4208	Economy	64400.00
0005432571360	4208	Economy	64400.00
0005435947386	4208	Economy	64400.00
0005435947376	4208	Economy	64400.00
0005432185003	4208	Economy	64400.00
0005435856233	4208	Economy	64400.00
0005432571367	4208	Economy	64400.00
0005435787375	4208	Economy	64400.00
0005432571365	4208	Economy	64400.00
0005432571355	4208	Economy	64400.00
0005432185005	4208	Economy	64400.00
0005435787369	4208	Economy	64400.00
0005435947400	4208	Economy	64400.00
0005432571340	4208	Economy	64400.00
0005435947401	4208	Economy	64400.00
0005435856249	4208	Economy	64400.00
0005435856234	4208	Economy	64400.00
0005432571356	4208	Economy	64400.00
0005435947467	4208	Economy	64400.00
0005435947377	4208	Economy	64400.00
0005435947427	4208	Economy	64400.00
0005432185004	4208	Economy	64400.00
0005435947525	26609	Business	193100.00
0005435787395	26609	Business	193100.00
0005432571395	26609	Business	193100.00
0005435986816	26609	Business	193100.00
0005435947523	26609	Business	193100.00
0005435986850	26609	Business	193100.00
0005435986831	26609	Business	193100.00
0005435947519	26609	Economy	64400.00
0005432571396	26609	Economy	64400.00
0005435947520	26609	Economy	64400.00
0005435986832	26609	Economy	64400.00
0005435947532	26609	Economy	64400.00
0005435986827	26609	Economy	64400.00
0005435856284	26609	Economy	64400.00
0005435947526	26609	Economy	64400.00
0005435947533	26609	Economy	64400.00
0005432571393	26609	Economy	64400.00
0005435947524	26609	Economy	64400.00
0005435986819	26609	Economy	64400.00
0005432571394	26609	Economy	64400.00
0005435986809	26609	Economy	64400.00
0005435947518	26609	Economy	64400.00
0005435947522	26609	Economy	64400.00
0005435856281	26609	Economy	64400.00
0005435787393	26609	Economy	64400.00
0005435947530	26609	Economy	64400.00
0005435986828	26609	Economy	70800.00
0005435947527	26609	Economy	64400.00
0005435986847	26609	Economy	64400.00
0005435947531	26609	Economy	64400.00
0005435986801	26609	Economy	64400.00
0005435947529	26609	Economy	64400.00
0005435787394	26609	Economy	64400.00
0005435947521	26609	Economy	64400.00
0005435947528	26609	Economy	64400.00
0005435856283	26609	Economy	64400.00
0005435986844	26609	Economy	64400.00
0005435856282	26609	Economy	64400.00
0005433570151	311	Business	21500.00
0005433570167	311	Business	21500.00
0005433570160	311	Business	21500.00
0005433570164	311	Business	21500.00
0005432948805	311	Business	21500.00
0005432948891	311	Business	21500.00
0005433570212	311	Business	21500.00
0005433075026	311	Business	21500.00
0005432239051	311	Business	21500.00
0005433570204	311	Business	21500.00
0005433570211	311	Business	21500.00
0005433075115	311	Business	21500.00
0005433075040	311	Business	21500.00
0005433570157	311	Business	21500.00
0005433570184	311	Business	21500.00
0005432948820	311	Business	21500.00
0005432948789	311	Business	21500.00
0005432948623	311	Business	21500.00
0005432948860	311	Business	21500.00
0005433075016	311	Business	21500.00
0005433074964	311	Business	21500.00
0005433570190	311	Business	21500.00
0005433570161	311	Business	21500.00
0005433570181	311	Business	21500.00
0005433074990	311	Business	21500.00
0005433134179	311	Business	21500.00
0005433570191	311	Business	21500.00
0005432948929	311	Economy	7900.00
0005433570150	311	Business	21500.00
0005433570152	311	Economy	7900.00
0005432239050	311	Economy	7900.00
0005432948862	311	Economy	7900.00
0005432948687	311	Economy	7900.00
0005433570188	311	Economy	7900.00
0005432948693	311	Economy	7200.00
0005432239053	311	Economy	7200.00
0005433570159	311	Economy	7200.00
0005433074873	311	Economy	7200.00
0005432948878	311	Economy	7200.00
0005433074949	311	Economy	7200.00
0005433570174	311	Economy	7200.00
0005433074947	311	Economy	7200.00
0005432948886	311	Economy	7200.00
0005432239047	311	Economy	7200.00
0005433570192	311	Economy	7200.00
0005433074960	311	Economy	7200.00
0005432948928	311	Economy	7200.00
0005433074883	311	Economy	7200.00
0005432239048	311	Economy	7200.00
0005433570210	311	Economy	7200.00
0005433134184	311	Economy	7200.00
0005433075017	311	Economy	7200.00
0005433570162	311	Economy	7200.00
0005433570195	311	Economy	7200.00
0005433570179	311	Economy	7200.00
0005432948908	311	Economy	7200.00
0005433570209	311	Economy	7200.00
0005433074993	311	Economy	7200.00
0005433570163	311	Economy	7200.00
0005433570178	311	Economy	7200.00
0005433074963	311	Economy	7200.00
0005433075030	311	Economy	7200.00
0005432948946	311	Economy	7200.00
0005433570213	311	Economy	7200.00
0005433570203	311	Economy	7200.00
0005432948779	311	Economy	7200.00
0005433570215	311	Economy	7200.00
0005433570173	311	Economy	7200.00
0005433074948	311	Economy	7200.00
0005433570169	311	Economy	7200.00
0005433570202	311	Economy	7200.00
0005432948832	311	Economy	7200.00
0005433074882	311	Economy	7200.00
0005433570194	311	Economy	7200.00
0005433074968	311	Economy	7200.00
0005433075105	311	Economy	7200.00
0005433074881	311	Economy	7200.00
0005433570193	311	Economy	7200.00
0005433570186	311	Economy	7200.00
0005432948783	311	Economy	7200.00
0005433074982	311	Economy	7200.00
0005433570201	311	Economy	7200.00
0005433570155	311	Economy	7200.00
0005433570177	311	Economy	7200.00
0005433075045	311	Economy	7200.00
0005432948898	311	Economy	7200.00
0005433129321	311	Economy	7200.00
0005433570198	311	Economy	7200.00
0005433074872	311	Economy	7200.00
0005432948885	311	Economy	7200.00
0005433570172	311	Economy	7200.00
0005433075007	311	Economy	7200.00
0005433074984	311	Economy	7200.00
0005432948906	311	Economy	7900.00
0005433075046	311	Economy	7900.00
0005432948715	311	Economy	7900.00
0005433134178	311	Economy	7900.00
0005432239049	311	Economy	7900.00
0005432239054	311	Economy	7200.00
0005433570199	311	Economy	7200.00
0005433570180	311	Economy	7200.00
0005432239052	311	Economy	7200.00
0005432948996	311	Economy	7900.00
0005433570166	311	Economy	7200.00
0005432948725	311	Economy	7200.00
0005433075094	311	Economy	7200.00
0005432948839	311	Economy	7200.00
0005433074819	311	Economy	7200.00
0005433074976	311	Economy	7200.00
0005432948726	311	Economy	7200.00
0005432948798	311	Economy	7200.00
0005433570208	311	Economy	7200.00
0005433570168	311	Economy	7200.00
0005433570170	311	Economy	7200.00
0005433570200	311	Economy	7200.00
0005432948762	311	Economy	7200.00
0005432948850	311	Economy	7200.00
0005433570185	311	Economy	7200.00
0005432948716	311	Economy	7200.00
0005432948837	311	Economy	7200.00
0005433075065	311	Economy	7200.00
0005432948809	311	Economy	7200.00
0005433570176	311	Economy	7200.00
0005433570171	311	Economy	7200.00
0005432948834	311	Economy	7200.00
0005432948835	311	Economy	7200.00
0005433570197	311	Economy	7200.00
0005432948692	311	Economy	7200.00
0005432949049	311	Economy	7200.00
0005433570205	311	Economy	7200.00
0005432948718	311	Economy	7200.00
0005433570189	311	Economy	7200.00
0005433570183	311	Economy	7200.00
0005433075027	311	Economy	7200.00
0005432948838	311	Economy	7200.00
0005433570154	311	Economy	7200.00
0005433570207	311	Economy	7200.00
0005432948884	311	Economy	7200.00
0005433570175	311	Economy	7200.00
0005433075031	311	Economy	7200.00
0005433570158	311	Economy	7200.00
0005432948883	311	Economy	7200.00
0005432948774	311	Economy	7200.00
0005432948997	311	Economy	7200.00
0005432948804	311	Economy	7200.00
0005432948899	311	Economy	7200.00
0005433074980	311	Economy	7200.00
0005433570182	311	Economy	7200.00
0005433074989	311	Economy	7200.00
0005433570165	311	Economy	7200.00
0005433570153	311	Economy	7200.00
0005432948863	311	Economy	7200.00
0005433075106	311	Economy	7200.00
0005432948831	311	Economy	7200.00
0005432948844	311	Economy	7200.00
0005433570156	311	Economy	7200.00
0005432948758	311	Economy	7200.00
0005433074928	311	Economy	7200.00
0005433074971	311	Economy	7200.00
0005433570187	311	Economy	7200.00
0005432948775	311	Economy	7200.00
0005433074981	311	Economy	7200.00
0005433570196	311	Economy	7200.00
0005433075028	311	Economy	7200.00
0005433570206	311	Economy	7200.00
0005433074975	311	Economy	7200.00
0005432948843	311	Economy	7200.00
0005433570214	311	Economy	7200.00
0005433929863	11569	Business	21500.00
0005432949207	11569	Business	21500.00
0005433569578	11569	Business	21500.00
0005433569623	11569	Business	21500.00
0005433075221	11569	Business	21500.00
0005433929865	11569	Business	21500.00
0005433569755	11569	Business	21500.00
0005433569477	11569	Business	21500.00
0005433569345	11569	Business	21500.00
0005433134222	11569	Business	21500.00
0005432192377	11569	Business	21500.00
0005433569324	11569	Business	21500.00
0005432949210	11569	Business	21500.00
0005433569550	11569	Business	21500.00
0005432949206	11569	Business	21500.00
0005432949184	11569	Business	21500.00
0005432949213	11569	Business	21500.00
0005433569566	11569	Business	21500.00
0005433569632	11569	Business	21500.00
0005433075226	11569	Business	21500.00
0005433569641	11569	Business	21500.00
0005433569341	11569	Business	21500.00
0005432949214	11569	Business	21500.00
0005433569475	11569	Business	21500.00
0005433569360	11569	Business	21500.00
0005433075217	11569	Business	21500.00
0005433075233	11569	Economy	7900.00
0005433075237	11569	Economy	7900.00
0005433569500	11569	Economy	7900.00
0005433569356	11569	Economy	7900.00
0005433569548	11569	Economy	7900.00
0005433569491	11569	Economy	7200.00
0005433929864	11569	Economy	7200.00
0005433131794	11569	Economy	7200.00
0005433075224	11569	Economy	7200.00
0005433569682	11569	Economy	7200.00
0005432949188	11569	Economy	7200.00
0005432192379	11569	Economy	7200.00
0005433569574	11569	Economy	7200.00
0005432949195	11569	Economy	7200.00
0005432949209	11569	Economy	7200.00
0005433075218	11569	Economy	7200.00
0005432949212	11569	Economy	7200.00
0005433075236	11569	Economy	7200.00
0005433569565	11569	Economy	7200.00
0005432949198	11569	Economy	7200.00
0005433075219	11569	Economy	7200.00
0005433569440	11569	Economy	7200.00
0005432949208	11569	Economy	7200.00
0005433929866	11569	Economy	7200.00
0005433075220	11569	Economy	7200.00
0005432949187	11569	Economy	7200.00
0005433569564	11569	Economy	7200.00
0005432949199	11569	Economy	7200.00
0005432949211	11569	Economy	7200.00
0005433569581	11569	Economy	7200.00
0005433569557	11569	Economy	7200.00
0005433569504	11569	Economy	7200.00
0005432949216	11569	Economy	7200.00
0005433569437	11569	Economy	7200.00
0005433075239	11569	Economy	7200.00
0005432949222	11569	Economy	7200.00
0005433075244	11569	Economy	7200.00
0005433569501	11569	Economy	7200.00
0005432949183	11569	Economy	7200.00
0005433075240	11569	Economy	7200.00
0005433569436	11569	Economy	7200.00
0005433569405	11569	Economy	7200.00
0005433569503	11569	Economy	7200.00
0005432949191	11569	Economy	7200.00
0005433569717	11569	Economy	7200.00
0005432949217	11569	Economy	7200.00
0005433075228	11569	Economy	7200.00
0005433569563	11569	Economy	7200.00
0005432949202	11569	Economy	7200.00
0005433075231	11569	Economy	7200.00
0005432949192	11569	Economy	7200.00
0005433075230	11569	Economy	7200.00
0005433569258	11569	Economy	7200.00
0005433075222	11569	Economy	7200.00
0005433569435	11569	Economy	7200.00
0005433569499	11569	Economy	7200.00
0005433131790	11569	Economy	7900.00
0005433075245	11569	Economy	7900.00
0005433075235	11569	Economy	7900.00
0005432949203	11569	Economy	7200.00
0005433569476	11569	Economy	7200.00
0005433075227	11569	Economy	7200.00
0005433569760	11569	Economy	7200.00
0005432949215	11569	Economy	7900.00
0005432949194	11569	Economy	7200.00
0005432949221	11569	Economy	7200.00
0005433569346	11569	Economy	7200.00
0005433075225	11569	Economy	7200.00
0005433569502	11569	Economy	7200.00
0005433569580	11569	Economy	7200.00
0005433569546	11569	Economy	7200.00
0005432949196	11569	Economy	7200.00
0005433569635	11569	Economy	7200.00
0005432949204	11569	Economy	7200.00
0005433075243	11569	Economy	7200.00
0005432949185	11569	Economy	7200.00
0005433075223	11569	Economy	7200.00
0005433134221	11569	Economy	7200.00
0005433134224	11569	Economy	7200.00
0005433569705	11569	Economy	7200.00
0005433569579	11569	Economy	7200.00
0005432949200	11569	Economy	7200.00
0005433569438	11569	Economy	7200.00
0005433569474	11569	Economy	7200.00
0005432949189	11569	Economy	7200.00
0005433134223	11569	Economy	7200.00
0005432949205	11569	Economy	7200.00
0005433569407	11569	Economy	7200.00
0005433569321	11569	Economy	7200.00
0005433075232	11569	Economy	7200.00
0005432949201	11569	Economy	7200.00
0005433569535	11569	Economy	7200.00
0005433569320	11569	Economy	7200.00
0005433075242	11569	Economy	7200.00
0005433569575	11569	Economy	7200.00
0005433131791	11569	Economy	7200.00
0005433569681	11569	Economy	7200.00
0005433075238	11569	Economy	7200.00
0005433131793	11569	Economy	7200.00
0005432949193	11569	Economy	7200.00
0005433075234	11569	Economy	7200.00
0005433569441	11569	Economy	7200.00
0005432949223	11569	Economy	7200.00
0005433569498	11569	Economy	7200.00
0005432192378	11569	Economy	7200.00
0005433131792	11569	Economy	7200.00
0005433569408	11569	Economy	7200.00
0005433569505	11569	Economy	7200.00
0005433569472	11569	Economy	7200.00
0005432949197	11569	Economy	7200.00
0005432949218	11569	Economy	7200.00
0005433569442	11569	Economy	7200.00
0005432949190	11569	Economy	7200.00
0005433075229	11569	Economy	7200.00
0005432949186	11569	Economy	7200.00
0005433569490	11569	Economy	7200.00
0005433075241	11569	Economy	7200.00
0005433569620	11569	Economy	7200.00
0005432949219	11569	Economy	7200.00
0005433569492	11569	Economy	7200.00
0005433569636	11569	Economy	7200.00
0005432949220	11569	Economy	7200.00
0005433817539	9965	Economy	6300.00
0005434733023	9965	Economy	6300.00
0005433817541	9965	Economy	6300.00
0005433817542	9965	Economy	6300.00
0005434733009	9965	Economy	6300.00
0005434733014	9965	Economy	6300.00
0005434733024	9965	Economy	6300.00
0005434733011	9965	Economy	6300.00
0005434733015	9965	Economy	6300.00
0005434733010	9965	Economy	6300.00
0005433817540	9965	Economy	6300.00
0005433817512	13914	Economy	6300.00
0005433817511	13914	Economy	6300.00
0005434733049	13914	Economy	6300.00
0005433817492	13914	Economy	6300.00
0005434733048	13914	Economy	6300.00
0005433817522	13914	Economy	6300.00
0005434733047	13914	Economy	6300.00
0005434733046	13914	Economy	6300.00
0005435983149	2363	Business	184500.00
0005434731205	2363	Business	184500.00
0005433755290	2363	Business	184500.00
0005432985354	2363	Business	184500.00
0005433434892	2363	Business	184500.00
0005432226174	2363	Business	184500.00
0005433766710	2363	Business	184500.00
0005433434909	2363	Business	184500.00
0005433435040	2363	Business	184500.00
0005433755243	2363	Business	184500.00
0005432226171	2363	Business	184500.00
0005432869593	2363	Business	184500.00
0005434731203	2363	Business	184500.00
0005433755251	2363	Business	184500.00
0005432985429	2363	Business	184500.00
0005435983119	2363	Business	184500.00
0005432655757	2363	Business	184500.00
0005433755239	2363	Business	184500.00
0005433755258	2363	Business	184500.00
0005435983146	2363	Business	184500.00
0005433755285	2363	Business	184500.00
0005432226173	2363	Business	184500.00
0005433434986	2363	Business	184500.00
0005433755263	2363	Business	184500.00
0005433755245	2363	Business	184500.00
0005435983125	2363	Business	184500.00
0005433434824	2363	Business	184500.00
0005432985378	2363	Economy	67700.00
0005435983106	2363	Economy	67700.00
0005432869592	2363	Economy	67700.00
0005432985557	2363	Economy	67700.00
0005433755244	2363	Economy	61500.00
0005433755266	2363	Economy	61500.00
0005435983150	2363	Economy	61500.00
0005433435021	2363	Economy	61500.00
0005433435012	2363	Economy	61500.00
0005433755242	2363	Economy	61500.00
0005432985409	2363	Economy	61500.00
0005435983137	2363	Economy	61500.00
0005432655764	2363	Economy	61500.00
0005432226175	2363	Economy	61500.00
0005435983126	2363	Economy	61500.00
0005432655763	2363	Economy	61500.00
0005433755241	2363	Economy	61500.00
0005435983139	2363	Economy	61500.00
0005435983103	2363	Economy	61500.00
0005432300373	2363	Economy	61500.00
0005432655761	2363	Economy	61500.00
0005433755281	2363	Economy	61500.00
0005432985309	2363	Economy	61500.00
0005432985464	2363	Economy	61500.00
0005435983123	2363	Economy	61500.00
0005433755289	2363	Economy	61500.00
0005435983105	2363	Economy	61500.00
0005435983128	2363	Economy	61500.00
0005433435067	2363	Economy	61500.00
0005432985535	2363	Economy	61500.00
0005433755268	2363	Economy	61500.00
0005435983121	2363	Economy	61500.00
0005433766712	2363	Economy	61500.00
0005432985556	2363	Economy	61500.00
0005432985434	2363	Economy	61500.00
0005435983142	2363	Economy	61500.00
0005433755291	2363	Economy	61500.00
0005435983116	2363	Economy	61500.00
0005433435108	2363	Economy	61500.00
0005435983147	2363	Economy	61500.00
0005435983124	2363	Economy	61500.00
0005433435036	2363	Economy	61500.00
0005435983148	2363	Economy	61500.00
0005433755236	2363	Economy	61500.00
0005432655759	2363	Economy	61500.00
0005433435011	2363	Economy	61500.00
0005435983101	2363	Economy	61500.00
0005435983117	2363	Economy	61500.00
0005433755269	2363	Economy	61500.00
0005433755275	2363	Economy	61500.00
0005432655754	2363	Economy	61500.00
0005433435107	2363	Economy	61500.00
0005433755249	2363	Economy	61500.00
0005433435058	2363	Economy	61500.00
0005433755278	2363	Economy	61500.00
0005433435068	2363	Economy	61500.00
0005433434903	2363	Economy	61500.00
0005435983120	2363	Economy	61500.00
0005435983107	2363	Economy	61500.00
0005433755286	2363	Economy	61500.00
0005434731208	2363	Economy	61500.00
0005432985301	2363	Economy	61500.00
0005433755257	2363	Economy	61500.00
0005433434965	2363	Economy	61500.00
0005435983115	2363	Economy	61500.00
0005433755256	2363	Economy	61500.00
0005432985308	2363	Economy	61500.00
0005435983143	2363	Economy	61500.00
0005432985369	2363	Economy	61500.00
0005433755287	2363	Economy	61500.00
0005432300372	2363	Economy	61500.00
0005432655755	2363	Economy	61500.00
0005432300374	2363	Economy	61500.00
0005432985212	2363	Economy	61500.00
0005432226172	2363	Economy	61500.00
0005432300370	2363	Economy	61500.00
0005435983102	2363	Economy	61500.00
0005435983131	2363	Economy	61500.00
0005432869595	2363	Economy	61500.00
0005433435059	2363	Economy	61500.00
0005432985414	2363	Economy	61500.00
0005432300371	2363	Economy	61500.00
0005432869599	2363	Economy	61500.00
0005433755277	2363	Economy	61500.00
0005433755292	2363	Economy	61500.00
0005435983113	2363	Economy	61500.00
0005432226176	2363	Economy	61500.00
0005433755259	2363	Economy	61500.00
0005432655765	2363	Economy	61500.00
0005433755288	2363	Economy	61500.00
0005433755271	2363	Economy	61500.00
0005435983108	2363	Economy	61500.00
0005435983114	2363	Economy	61500.00
0005433755261	2363	Economy	61500.00
0005432985348	2363	Economy	61500.00
0005433755250	2363	Economy	67700.00
0005432655756	2363	Economy	61500.00
0005433434825	2363	Economy	67700.00
0005435983138	2363	Economy	61500.00
0005433755267	2363	Economy	61500.00
0005433434910	2363	Economy	61500.00
0005435983130	2363	Economy	67700.00
0005433755237	2363	Economy	67700.00
0005433755252	2363	Economy	61500.00
0005435983133	2363	Economy	61500.00
0005435983132	2363	Economy	61500.00
0005432985370	2363	Economy	61500.00
0005433755270	2363	Economy	61500.00
0005433435117	2363	Economy	61500.00
0005433755282	2363	Economy	61500.00
0005433434948	2363	Economy	61500.00
0005433755283	2363	Economy	61500.00
0005432655760	2363	Economy	61500.00
0005434731204	2363	Economy	61500.00
0005435983136	2363	Economy	61500.00
0005433435008	2363	Economy	61500.00
0005435983122	2363	Economy	61500.00
0005433755240	2363	Economy	61500.00
0005433755264	2363	Economy	61500.00
0005433435009	2363	Economy	61500.00
0005433755247	2363	Economy	61500.00
0005434731210	2363	Economy	61500.00
0005433755280	2363	Economy	61500.00
0005433755284	2363	Economy	61500.00
0005435983141	2363	Economy	61500.00
0005432985362	2363	Economy	61500.00
0005433435004	2363	Economy	61500.00
0005432985482	2363	Economy	61500.00
0005435983145	2363	Economy	61500.00
0005435983109	2363	Economy	61500.00
0005435983140	2363	Economy	61500.00
0005433766711	2363	Economy	61500.00
0005435983104	2363	Economy	61500.00
0005433755279	2363	Economy	61500.00
0005435983127	2363	Economy	61500.00
0005432985371	2363	Economy	61500.00
0005433755260	2363	Economy	61500.00
0005432869600	2363	Economy	61500.00
0005435983134	2363	Economy	61500.00
0005433764718	2363	Economy	61500.00
0005435983110	2363	Economy	61500.00
0005433755262	2363	Economy	61500.00
0005432985307	2363	Economy	61500.00
0005433755238	2363	Economy	61500.00
0005433755248	2363	Economy	61500.00
0005432655758	2363	Economy	61500.00
0005432226170	2363	Economy	61500.00
0005433755246	2363	Economy	61500.00
0005433755276	2363	Economy	61500.00
0005432869571	2363	Economy	61500.00
0005433755254	2363	Economy	61500.00
0005435983144	2363	Economy	61500.00
0005432985313	2363	Economy	61500.00
0005432655762	2363	Economy	61500.00
0005435983118	2363	Economy	61500.00
0005433755255	2363	Economy	61500.00
0005433755265	2363	Economy	61500.00
0005433755273	2363	Economy	61500.00
0005435983111	2363	Economy	61500.00
0005433755253	2363	Economy	61500.00
0005432985534	2363	Economy	61500.00
0005433434934	2363	Economy	61500.00
0005435983135	2363	Economy	61500.00
0005433755274	2363	Economy	61500.00
0005435983112	2363	Economy	61500.00
0005433435116	2363	Economy	61500.00
0005433755272	2363	Economy	61500.00
0005435983129	2363	Economy	61500.00
0005434731209	2363	Economy	61500.00
0005432985484	2363	Economy	61500.00
0005432655631	26177	Business	184500.00
0005433754663	26177	Business	184500.00
0005435982731	26177	Business	184500.00
0005432869642	26177	Business	184500.00
0005432985676	26177	Business	184500.00
0005435982748	26177	Business	184500.00
0005432655610	26177	Business	184500.00
0005433754669	26177	Business	184500.00
0005435982845	26177	Business	184500.00
0005435982900	26177	Business	184500.00
0005432655674	26177	Business	184500.00
0005433754915	26177	Business	184500.00
0005432049529	26177	Business	184500.00
0005432985692	26177	Business	184500.00
0005435982680	26177	Business	184500.00
0005433754898	26177	Business	184500.00
0005433754769	26177	Business	184500.00
0005435982840	26177	Business	184500.00
0005433754882	26177	Business	184500.00
0005435982679	26177	Business	184500.00
0005432985686	26177	Business	184500.00
0005433754883	26177	Business	184500.00
0005433435198	26177	Business	184500.00
0005435982675	26177	Business	184500.00
0005432655656	26177	Business	184500.00
0005433766679	26177	Business	184500.00
0005433754675	26177	Business	184500.00
0005435982745	26177	Business	184500.00
0005433754678	26177	Economy	67700.00
0005433754721	26177	Economy	67700.00
0005433754603	26177	Economy	67700.00
0005433435208	26177	Economy	67700.00
0005433435202	26177	Economy	61500.00
0005433435206	26177	Economy	61500.00
0005432985680	26177	Economy	61500.00
0005432051185	26177	Economy	61500.00
0005433754857	26177	Economy	61500.00
0005432985671	26177	Economy	61500.00
0005433754727	26177	Economy	61500.00
0005432869646	26177	Economy	61500.00
0005432655679	26177	Economy	61500.00
0005435982954	26177	Economy	61500.00
0005432985684	26177	Economy	61500.00
0005432655583	26177	Economy	61500.00
0005432985662	26177	Economy	61500.00
0005433754900	26177	Economy	61500.00
0005434731250	26177	Economy	61500.00
0005435982841	26177	Economy	61500.00
0005433435201	26177	Economy	61500.00
0005432655629	26177	Economy	61500.00
0005433754657	26177	Economy	61500.00
0005433435199	26177	Economy	61500.00
0005433435210	26177	Economy	61500.00
0005435982694	26177	Economy	61500.00
0005432985661	26177	Economy	61500.00
0005434731248	26177	Economy	61500.00
0005432985674	26177	Economy	61500.00
0005432985687	26177	Economy	61500.00
0005433754688	26177	Economy	61500.00
0005433754835	26177	Economy	61500.00
0005432985678	26177	Economy	61500.00
0005433764702	26177	Economy	61500.00
0005435982822	26177	Economy	61500.00
0005432985672	26177	Economy	61500.00
0005435982672	26177	Economy	61500.00
0005432985663	26177	Economy	61500.00
0005435982707	26177	Economy	61500.00
0005432655673	26177	Economy	61500.00
0005433754850	26177	Economy	61500.00
0005433754743	26177	Economy	61500.00
0005435982649	26177	Economy	61500.00
0005432985679	26177	Economy	61500.00
0005432985670	26177	Economy	61500.00
0005435982758	26177	Economy	61500.00
0005435982600	26177	Economy	61500.00
0005432051186	26177	Economy	61500.00
0005432985668	26177	Economy	61500.00
0005432985690	26177	Economy	61500.00
0005433754904	26177	Economy	61500.00
0005435982834	26177	Economy	61500.00
0005433435192	26177	Economy	61500.00
0005434731247	26177	Economy	61500.00
0005433754698	26177	Economy	61500.00
0005433754660	26177	Economy	61500.00
0005432049530	26177	Economy	61500.00
0005432655678	26177	Economy	61500.00
0005433435204	26177	Economy	61500.00
0005433754746	26177	Economy	61500.00
0005433754635	26177	Economy	61500.00
0005433435205	26177	Economy	61500.00
0005433754661	26177	Economy	61500.00
0005433435191	26177	Economy	61500.00
0005432985689	26177	Economy	61500.00
0005435982541	26177	Economy	61500.00
0005434731249	26177	Economy	61500.00
0005432985669	26177	Economy	61500.00
0005433754811	26177	Economy	61500.00
0005432869641	26177	Economy	61500.00
0005432985667	26177	Economy	61500.00
0005432655614	26177	Economy	61500.00
0005433754932	26177	Economy	61500.00
0005432869647	26177	Economy	61500.00
0005432869645	26177	Economy	61500.00
0005433435216	26177	Economy	61500.00
0005433754520	26177	Economy	61500.00
0005433754838	26177	Economy	61500.00
0005435982732	26177	Economy	61500.00
0005432985693	26177	Economy	61500.00
0005435982450	26177	Economy	61500.00
0005433435188	26177	Economy	61500.00
0005435982351	26177	Economy	61500.00
0005433435195	26177	Economy	61500.00
0005432985688	26177	Economy	61500.00
0005433766686	26177	Economy	61500.00
0005432051188	26177	Economy	61500.00
0005433435190	26177	Economy	61500.00
0005433754744	26177	Economy	61500.00
0005435982641	26177	Economy	61500.00
0005433754768	26177	Economy	61500.00
0005433766680	26177	Economy	61500.00
0005432985677	26177	Economy	67700.00
0005433754795	26177	Economy	67700.00
0005432869644	26177	Economy	61500.00
0005435982795	26177	Economy	61500.00
0005435982599	26177	Economy	67700.00
0005435982611	26177	Economy	61500.00
0005435982674	26177	Economy	67700.00
0005435982540	26177	Economy	61500.00
0005435982681	26177	Economy	61500.00
0005433764701	26177	Economy	61500.00
0005435982544	26177	Economy	61500.00
0005433754690	26177	Economy	61500.00
0005435982749	26177	Economy	61500.00
0005432655615	26177	Economy	61500.00
0005433754662	26177	Economy	61500.00
0005433754794	26177	Economy	61500.00
0005435982789	26177	Economy	61500.00
0005432985675	26177	Economy	61500.00
0005435982746	26177	Economy	61500.00
0005432985673	26177	Economy	61500.00
0005433435214	26177	Economy	61500.00
0005432655616	26177	Economy	61500.00
0005435982650	26177	Economy	61500.00
0005435982846	26177	Economy	61500.00
0005433754636	26177	Economy	61500.00
0005433754700	26177	Economy	61500.00
0005433754521	26177	Economy	61500.00
0005432049531	26177	Economy	61500.00
0005433754639	26177	Economy	61500.00
0005434731251	26177	Economy	61500.00
0005435982671	26177	Economy	61500.00
0005433766683	26177	Economy	61500.00
0005433754870	26177	Economy	61500.00
0005433754638	26177	Economy	61500.00
0005433754647	26177	Economy	61500.00
0005435982759	26177	Economy	61500.00
0005433435209	26177	Economy	61500.00
0005432985683	26177	Economy	61500.00
0005433435212	26177	Economy	61500.00
0005433435215	26177	Economy	61500.00
0005433754793	26177	Economy	61500.00
0005432985664	26177	Economy	61500.00
0005435982695	26177	Economy	61500.00
0005433754858	26177	Economy	61500.00
0005433435200	26177	Economy	61500.00
0005432985685	26177	Economy	61500.00
0005433435189	26177	Economy	61500.00
0005433754563	26177	Economy	61500.00
0005433754851	26177	Economy	61500.00
0005433435211	26177	Economy	61500.00
0005433435197	26177	Economy	61500.00
0005432985691	26177	Economy	61500.00
0005433435207	26177	Economy	61500.00
0005433754699	26177	Economy	61500.00
0005432985681	26177	Economy	61500.00
0005433754929	26177	Economy	61500.00
0005433754602	26177	Economy	61500.00
0005432869643	26177	Economy	61500.00
0005432985665	26177	Economy	61500.00
0005435982788	26177	Economy	61500.00
0005432655617	26177	Economy	61500.00
0005432051187	26177	Economy	61500.00
0005433435213	26177	Economy	61500.00
0005432655630	26177	Economy	61500.00
0005432985694	26177	Economy	61500.00
0005435982507	26177	Economy	61500.00
0005433766668	26177	Economy	61500.00
0005432985666	26177	Economy	61500.00
0005434731252	26177	Economy	61500.00
0005433435193	26177	Economy	61500.00
0005433435194	26177	Economy	61500.00
0005435982772	26177	Economy	61500.00
0005435982612	26177	Economy	61500.00
0005433435203	26177	Economy	61500.00
0005433754909	26177	Economy	61500.00
0005432985682	26177	Economy	61500.00
0005433435196	26177	Economy	61500.00
0005434375470	1517	Business	38900.00
0005434029677	1517	Business	38900.00
0005434375456	1517	Business	38900.00
0005434375469	1517	Business	38900.00
0005434375451	1517	Business	38900.00
0005434375497	1517	Business	38900.00
0005433151766	1517	Business	38900.00
0005434375501	1517	Business	38900.00
0005433151693	1517	Business	38900.00
0005433931479	1517	Business	38900.00
0005434375475	1517	Business	38900.00
0005433764693	1517	Business	38900.00
0005433151899	1517	Economy	13000.00
0005434375459	1517	Economy	13000.00
0005433461629	1517	Economy	13000.00
0005434375457	1517	Economy	13000.00
0005434375471	1517	Economy	13000.00
0005432268020	1517	Economy	13000.00
0005433151802	1517	Economy	13000.00
0005433151786	1517	Economy	13000.00
0005433151767	1517	Economy	13000.00
0005434375498	1517	Economy	13000.00
0005434375464	1517	Economy	13000.00
0005433151801	1517	Economy	13000.00
0005434375504	1517	Economy	13000.00
0005433151743	1517	Economy	13000.00
0005434375460	1517	Economy	13000.00
0005433460477	1517	Economy	13000.00
0005433151739	1517	Economy	13000.00
0005434375463	1517	Economy	13000.00
0005433460476	1517	Economy	13000.00
0005434375468	1517	Economy	13000.00
0005433151759	1517	Economy	13000.00
0005434375484	1517	Economy	13000.00
0005434375492	1517	Economy	13000.00
0005434375480	1517	Economy	13000.00
0005433151796	1517	Economy	13000.00
0005434375450	1517	Economy	13000.00
0005433764699	1517	Economy	13000.00
0005434375453	1517	Economy	13000.00
0005433764695	1517	Economy	13000.00
0005433151760	1517	Economy	13000.00
0005434375486	1517	Economy	13000.00
0005434375494	1517	Economy	13000.00
0005433151745	1517	Economy	13000.00
0005434375465	1517	Economy	13000.00
0005433461627	1517	Economy	13000.00
0005434375489	1517	Economy	13000.00
0005434375493	1517	Economy	14300.00
0005432268019	1517	Economy	14300.00
0005433931480	1517	Economy	14300.00
0005434029681	1517	Economy	14300.00
0005434375491	1517	Economy	14300.00
0005433151694	1517	Economy	13000.00
0005434375482	1517	Economy	13000.00
0005434375487	1517	Economy	13000.00
0005434375454	1517	Economy	13000.00
0005433151737	1517	Economy	13000.00
0005434375503	1517	Economy	13000.00
0005434375477	1517	Economy	13000.00
0005434029680	1517	Economy	13000.00
0005434375481	1517	Economy	13000.00
0005434375490	1517	Economy	13000.00
0005434375499	1517	Economy	13000.00
0005433151742	1517	Economy	13000.00
0005434375474	1517	Economy	13000.00
0005434375479	1517	Economy	13000.00
0005434375485	1517	Economy	13000.00
0005433151712	1517	Economy	13000.00
0005433931478	1517	Economy	13000.00
0005433151628	1517	Economy	13000.00
0005434375496	1517	Economy	13000.00
0005434375488	1517	Economy	13000.00
0005433151719	1517	Economy	13000.00
0005433151974	1517	Economy	13000.00
0005434375467	1517	Economy	13000.00
0005433151751	1517	Economy	13000.00
0005434375452	1517	Economy	13000.00
0005434375461	1517	Economy	13000.00
0005433460475	1517	Economy	13000.00
0005433151744	1517	Economy	13000.00
0005434375455	1517	Economy	13000.00
0005434375478	1517	Economy	13000.00
0005433151830	1517	Economy	13000.00
0005432268022	1517	Economy	13000.00
0005432268017	1517	Economy	13000.00
0005433151723	1517	Economy	13000.00
0005434375462	1517	Economy	13000.00
0005433151692	1517	Economy	13000.00
0005433151733	1517	Economy	13000.00
0005434375500	1517	Economy	13000.00
0005434375495	1517	Economy	13000.00
0005434375466	1517	Economy	13000.00
0005432268021	1517	Economy	13000.00
0005434375483	1517	Economy	13000.00
0005434375473	1517	Economy	13000.00
0005434375502	1517	Economy	13000.00
0005433151738	1517	Economy	13000.00
0005433931494	1517	Economy	13000.00
0005433151629	1517	Economy	13000.00
0005433151844	1517	Economy	13000.00
0005434375472	1517	Economy	13000.00
0005434375476	1517	Economy	13000.00
0005433931495	1517	Economy	13000.00
0005433461628	1517	Economy	13000.00
0005434375458	1517	Economy	13000.00
0005433151735	1517	Economy	13000.00
0005433151691	1517	Economy	13000.00
0005433151785	1517	Economy	13000.00
0005432268018	1517	Economy	13000.00
0005433764700	1517	Economy	13000.00
0005432268016	1517	Economy	13000.00
0005434375091	20134	Business	38900.00
0005433152029	20134	Business	38900.00
0005432056369	20134	Business	38900.00
0005434375007	20134	Business	38900.00
0005434375089	20134	Business	38900.00
0005434375222	20134	Business	38900.00
0005434374989	20134	Business	38900.00
0005434375197	20134	Business	38900.00
0005434375024	20134	Business	38900.00
0005434375178	20134	Business	38900.00
0005433152035	20134	Business	38900.00
0005433152055	20134	Economy	13000.00
0005433152032	20134	Economy	13000.00
0005434375176	20134	Economy	13000.00
0005433152041	20134	Economy	13000.00
0005433152026	20134	Economy	13000.00
0005433152056	20134	Economy	13000.00
0005433152048	20134	Economy	13000.00
0005433152033	20134	Economy	13000.00
0005434374900	20134	Economy	13000.00
0005434375086	20134	Economy	13000.00
0005433152030	20134	Economy	13000.00
0005433931520	20134	Economy	13000.00
0005433152050	20134	Economy	13000.00
0005433152053	20134	Economy	13000.00
0005434375037	20134	Economy	13000.00
0005434375159	20134	Economy	13000.00
0005433152039	20134	Economy	13000.00
0005433152034	20134	Economy	13000.00
0005434375175	20134	Economy	13000.00
0005433152052	20134	Economy	13000.00
0005434375151	20134	Economy	13000.00
0005434375064	20134	Economy	13000.00
0005434029703	20134	Economy	13000.00
0005434375013	20134	Economy	13000.00
0005434375051	20134	Economy	13000.00
0005434375036	20134	Economy	13000.00
0005434374899	20134	Economy	14300.00
0005433931521	20134	Economy	14300.00
0005433764718	20134	Economy	14300.00
0005434375131	20134	Economy	14300.00
0005434375080	20134	Economy	14300.00
0005434374980	20134	Economy	13000.00
0005433152045	20134	Economy	13000.00
0005433152044	20134	Economy	13000.00
0005434375163	20134	Economy	13000.00
0005433152058	20134	Economy	13000.00
0005433152049	20134	Economy	13000.00
0005434375196	20134	Economy	13000.00
0005433152037	20134	Economy	13000.00
0005434375090	20134	Economy	13000.00
0005433152024	20134	Economy	13000.00
0005434375150	20134	Economy	13000.00
0005433152047	20134	Economy	13000.00
0005433152046	20134	Economy	13000.00
0005433152042	20134	Economy	13000.00
0005434375098	20134	Economy	13000.00
0005433152043	20134	Economy	13000.00
0005433152038	20134	Economy	13000.00
0005434029704	20134	Economy	13000.00
0005434375177	20134	Economy	13000.00
0005434374973	20134	Economy	13000.00
0005434375125	20134	Economy	13000.00
0005434375099	20134	Economy	13000.00
0005434375223	20134	Economy	13000.00
0005434375014	20134	Economy	13000.00
0005434375162	20134	Economy	13000.00
0005434375023	20134	Economy	13000.00
0005433152031	20134	Economy	13000.00
0005434374914	20134	Economy	13000.00
0005432056370	20134	Economy	13000.00
0005434375012	20134	Economy	13000.00
0005433152027	20134	Economy	13000.00
0005432056371	20134	Economy	13000.00
0005434375068	20134	Economy	13000.00
0005433152054	20134	Economy	13000.00
0005434375128	20134	Economy	13000.00
0005434375202	20134	Economy	13000.00
0005434375104	20134	Economy	13000.00
0005434374925	20134	Economy	13000.00
0005434375219	20134	Economy	13000.00
0005433152036	20134	Economy	13000.00
0005433152057	20134	Economy	13000.00
0005434375119	20134	Economy	13000.00
0005434375038	20134	Economy	13000.00
0005434375183	20134	Economy	13000.00
0005434375069	20134	Economy	13000.00
0005434375095	20134	Economy	13000.00
0005434375122	20134	Economy	13000.00
0005434375073	20134	Economy	13000.00
0005434375158	20134	Economy	13000.00
0005434375139	20134	Economy	13000.00
0005434375065	20134	Economy	13000.00
0005433152051	20134	Economy	13000.00
0005434375157	20134	Economy	13000.00
0005433152040	20134	Economy	13000.00
0005433152028	20134	Economy	13000.00
0005433152025	20134	Economy	13000.00
0005434375079	20134	Economy	13000.00
0005432425359	561	Business	27500.00
0005432425365	561	Business	27500.00
0005432425374	561	Business	27500.00
0005432425347	561	Business	27500.00
0005432425356	561	Business	27500.00
0005432282995	561	Business	27500.00
0005432282994	561	Business	27500.00
0005432425337	561	Business	27500.00
0005432425343	561	Business	27500.00
0005432425340	561	Business	27500.00
0005432425353	561	Economy	10100.00
0005432425377	561	Economy	10100.00
0005432425366	561	Economy	10100.00
0005432282993	561	Economy	9200.00
0005432425345	561	Economy	9200.00
0005432282997	561	Economy	9200.00
0005432425346	561	Economy	9200.00
0005432425342	561	Economy	9200.00
0005432425372	561	Economy	9200.00
0005432425336	561	Economy	9200.00
0005432425350	561	Economy	9200.00
0005432282991	561	Economy	9200.00
0005432425351	561	Economy	9200.00
0005432425348	561	Economy	9200.00
0005432425358	561	Economy	9200.00
0005432425339	561	Economy	9200.00
0005432425354	561	Economy	9200.00
0005432425370	561	Economy	9200.00
0005432425368	561	Economy	9200.00
0005432425367	561	Economy	9200.00
0005432425355	561	Economy	9200.00
0005432425364	561	Economy	10100.00
0005432425338	561	Economy	9200.00
0005432425369	561	Economy	10100.00
0005432425349	561	Economy	9200.00
0005432282998	561	Economy	9200.00
0005432425341	561	Economy	9200.00
0005432425371	561	Economy	9200.00
0005432425375	561	Economy	9200.00
0005432282996	561	Economy	9200.00
0005432425363	561	Economy	9200.00
0005432425362	561	Economy	9200.00
0005432425361	561	Economy	9200.00
0005432425360	561	Economy	9200.00
0005432425352	561	Economy	9200.00
0005432425373	561	Economy	9200.00
0005432425357	561	Economy	9200.00
0005432425376	561	Economy	9200.00
0005432282992	561	Economy	9200.00
0005432425344	561	Economy	9200.00
0005433158172	12836	Business	27500.00
0005432302399	12836	Business	27500.00
0005433158173	12836	Business	27500.00
0005433261873	12836	Economy	10100.00
0005434446532	12836	Economy	9200.00
0005433158171	12836	Economy	9200.00
0005433158174	12836	Economy	9200.00
0005433158168	12836	Economy	9200.00
0005432302401	12836	Economy	9200.00
0005433158175	12836	Economy	9200.00
0005434446531	12836	Economy	9200.00
0005433261872	12836	Economy	9200.00
0005433158169	12836	Economy	9200.00
0005433158170	12836	Economy	9200.00
0005432302400	12836	Economy	9200.00
0005433261871	12836	Economy	9200.00
0005432302402	12836	Economy	9200.00
0005432424749	12856	Business	27500.00
0005432424716	12856	Business	27500.00
0005432424846	12856	Business	27500.00
0005432424645	12856	Business	27500.00
0005432424786	12856	Business	27500.00
0005432424808	12856	Business	27500.00
0005432424903	12856	Business	27500.00
0005432424906	12856	Business	27500.00
0005432424754	12856	Economy	10100.00
0005432424849	12856	Economy	10100.00
0005432424708	12856	Economy	9200.00
0005432424889	12856	Economy	9200.00
0005432424750	12856	Economy	9200.00
0005432424881	12856	Economy	9200.00
0005432424824	12856	Economy	9200.00
0005432424807	12856	Economy	9200.00
0005432424901	12856	Economy	9200.00
0005432424880	12856	Economy	9200.00
0005432424902	12856	Economy	9200.00
0005432424798	12856	Economy	9200.00
0005432424646	12856	Economy	9200.00
0005432424900	12856	Economy	9200.00
0005432424707	12856	Economy	9200.00
0005432424785	12856	Economy	9200.00
0005432424896	12856	Economy	9200.00
0005432424897	12856	Economy	9200.00
0005432424748	12856	Economy	9200.00
0005432424863	12856	Economy	9200.00
0005432424847	12856	Economy	9200.00
0005432424909	12856	Economy	10100.00
0005432424800	12856	Economy	9200.00
0005432424825	12856	Economy	9200.00
0005432424753	12856	Economy	9200.00
0005432424799	12856	Economy	9200.00
0005432424702	12856	Economy	9200.00
0005432424761	12856	Economy	9200.00
0005432424914	12856	Economy	9200.00
0005432424912	12856	Economy	9200.00
0005432424796	12856	Economy	9200.00
0005432424908	12856	Economy	9200.00
0005432424827	12856	Economy	9200.00
0005432424853	12856	Economy	9200.00
0005432424823	12856	Economy	9200.00
0005432424850	12856	Economy	9200.00
0005432424876	12856	Economy	9200.00
0005432424674	12856	Economy	9200.00
0005432424742	12856	Economy	9200.00
0005432424794	12856	Economy	9200.00
0005432424860	12856	Economy	9200.00
0005432424762	12856	Economy	9200.00
0005432424826	12856	Economy	9200.00
0005432424875	12856	Economy	9200.00
0005434024994	452	Business	24500.00
0005433058282	452	Business	24500.00
0005434024987	452	Business	24500.00
0005433058462	452	Business	24500.00
0005434024934	452	Business	24500.00
0005433058233	452	Business	24500.00
0005434024963	452	Business	24500.00
0005434024966	452	Business	24500.00
0005433058435	452	Business	24500.00
0005434024995	452	Business	24500.00
0005433058329	452	Business	24500.00
0005433058559	452	Business	24500.00
0005434024978	452	Business	24500.00
0005433058482	452	Business	24500.00
0005433058399	452	Business	24500.00
0005434024939	452	Business	24500.00
0005433929658	452	Business	24500.00
0005434024930	452	Business	24500.00
0005433929644	452	Business	24500.00
0005434024962	452	Economy	9000.00
0005434024951	452	Economy	9000.00
0005433058360	452	Economy	9000.00
0005434029701	452	Economy	9000.00
0005433058352	452	Economy	8200.00
0005434028354	452	Economy	8200.00
0005434024993	452	Economy	8200.00
0005434024935	452	Economy	8200.00
0005434024959	452	Economy	8200.00
0005433058321	452	Economy	8200.00
0005434024936	452	Economy	8200.00
0005434024986	452	Economy	8200.00
0005433058330	452	Economy	8200.00
0005434024976	452	Economy	8200.00
0005434024973	452	Economy	8200.00
0005434024961	452	Economy	8200.00
0005434032104	452	Economy	8200.00
0005434024950	452	Economy	8200.00
0005434024955	452	Economy	8200.00
0005434024942	452	Economy	8200.00
0005434029702	452	Economy	8200.00
0005434024970	452	Economy	8200.00
0005434024957	452	Economy	8200.00
0005434024932	452	Economy	8200.00
0005433058223	452	Economy	8200.00
0005434024967	452	Economy	8200.00
0005433929643	452	Economy	8200.00
0005432235779	452	Economy	8200.00
0005434024943	452	Economy	8200.00
0005433058447	452	Economy	8200.00
0005433058331	452	Economy	8200.00
0005432235778	452	Economy	8200.00
0005433058483	452	Economy	8200.00
0005434024965	452	Economy	8200.00
0005432235775	452	Economy	8200.00
0005433684444	452	Economy	8200.00
0005434024984	452	Economy	8200.00
0005433058262	452	Economy	8200.00
0005434024972	452	Economy	8200.00
0005433058408	452	Economy	8200.00
0005434024933	452	Economy	8200.00
0005432235776	452	Economy	8200.00
0005434735739	452	Economy	8200.00
0005434032108	452	Economy	8200.00
0005432045647	452	Economy	8200.00
0005434735738	452	Economy	8200.00
0005434024979	452	Economy	8200.00
0005434028355	452	Economy	8200.00
0005434735725	452	Economy	8200.00
0005434024968	452	Economy	8200.00
0005433929647	452	Economy	8200.00
0005434024928	452	Economy	8200.00
0005434024964	452	Economy	8200.00
0005432045649	452	Economy	8200.00
0005434024945	452	Economy	8200.00
0005434024980	452	Economy	8200.00
0005433058255	452	Economy	8200.00
0005433929654	452	Economy	8200.00
0005433058424	452	Economy	8200.00
0005434024982	452	Economy	8200.00
0005434024971	452	Economy	8200.00
0005434024975	452	Economy	8200.00
0005432045648	452	Economy	8200.00
0005434735735	452	Economy	8200.00
0005434032106	452	Economy	8200.00
0005434024946	452	Economy	8200.00
0005433058284	452	Economy	8200.00
0005434032105	452	Economy	8200.00
0005434024947	452	Economy	8200.00
0005433929659	452	Economy	8200.00
0005434024981	452	Economy	8200.00
0005433058356	452	Economy	8200.00
0005434024958	452	Economy	8200.00
0005434024983	452	Economy	9000.00
0005433058355	452	Economy	8200.00
0005433058283	452	Economy	9000.00
0005434024991	452	Economy	9000.00
0005434024953	452	Economy	8200.00
0005434735713	452	Economy	8200.00
0005432235780	452	Economy	8200.00
0005433058401	452	Economy	8200.00
0005433058413	452	Economy	8200.00
0005433058434	452	Economy	8200.00
0005433058481	452	Economy	8200.00
0005434024985	452	Economy	8200.00
0005433058324	452	Economy	8200.00
0005434032107	452	Economy	8200.00
0005433929645	452	Economy	8200.00
0005433058353	452	Economy	8200.00
0005434024929	452	Economy	8200.00
0005433058347	452	Economy	8200.00
0005434024988	452	Economy	8200.00
0005433058407	452	Economy	8200.00
0005434024944	452	Economy	8200.00
0005433929660	452	Economy	8200.00
0005432235777	452	Economy	8200.00
0005434024990	452	Economy	8200.00
0005434024996	452	Economy	8200.00
0005433058426	452	Economy	8200.00
0005434024940	452	Economy	8200.00
0005433058400	452	Economy	8200.00
0005433058333	452	Economy	8200.00
0005434024969	452	Economy	8200.00
0005434024938	452	Economy	8200.00
0005434735712	452	Economy	8200.00
0005434028353	452	Economy	8200.00
0005433058244	452	Economy	8200.00
0005434024977	452	Economy	8200.00
0005434024954	452	Economy	8200.00
0005434024931	452	Economy	8200.00
0005434024937	452	Economy	8200.00
0005434032103	452	Economy	8200.00
0005433058463	452	Economy	8200.00
0005433058320	452	Economy	8200.00
0005434024992	452	Economy	8200.00
0005434024941	452	Economy	8200.00
0005434024952	452	Economy	8200.00
0005433058425	452	Economy	8200.00
0005433058516	452	Economy	8200.00
0005434024948	452	Economy	8200.00
0005433058168	452	Economy	8200.00
0005433058319	452	Economy	8200.00
0005434024949	452	Economy	8200.00
0005434024956	452	Economy	8200.00
0005434024974	452	Economy	8200.00
0005433058254	452	Economy	8200.00
0005433684443	452	Economy	8200.00
0005434024989	452	Economy	8200.00
0005434024960	452	Economy	8200.00
0005433058359	452	Economy	8200.00
0005434032067	12648	Business	24500.00
0005433058628	12648	Business	24500.00
0005433058636	12648	Business	24500.00
0005434024576	12648	Business	24500.00
0005434024458	12648	Business	24500.00
0005433058640	12648	Business	24500.00
0005434024141	12648	Business	24500.00
0005434024387	12648	Business	24500.00
0005434032060	12648	Business	24500.00
0005433058620	12648	Business	24500.00
0005434029677	12648	Business	24500.00
0005434024453	12648	Business	24500.00
0005433058624	12648	Business	24500.00
0005434024254	12648	Business	24500.00
0005434735787	12648	Business	24500.00
0005434032066	12648	Business	24500.00
0005434024444	12648	Business	24500.00
0005434024443	12648	Business	24500.00
0005434024577	12648	Business	24500.00
0005432156447	12648	Business	24500.00
0005433058611	12648	Economy	9000.00
0005434024578	12648	Economy	8200.00
0005434024140	12648	Economy	8200.00
0005434024440	12648	Economy	8200.00
0005434024689	12648	Economy	8200.00
0005434024497	12648	Economy	8200.00
0005434032053	12648	Economy	8200.00
0005434024424	12648	Economy	8200.00
0005434032076	12648	Economy	8200.00
0005433684459	12648	Economy	8200.00
0005434024372	12648	Economy	8200.00
0005433058632	12648	Economy	8200.00
0005434024441	12648	Economy	8200.00
0005433058631	12648	Economy	8200.00
0005433058639	12648	Economy	8200.00
0005434023990	12648	Economy	8200.00
0005433058635	12648	Economy	8200.00
0005434032075	12648	Economy	8200.00
0005434024488	12648	Economy	8200.00
0005434028321	12648	Economy	8200.00
0005434024171	12648	Economy	8200.00
0005433929691	12648	Economy	8200.00
0005433058643	12648	Economy	8200.00
0005433058641	12648	Economy	8200.00
0005434023900	12648	Economy	8200.00
0005434024331	12648	Economy	8200.00
0005434024280	12648	Economy	8200.00
0005433058621	12648	Economy	8200.00
0005433929690	12648	Economy	8200.00
0005434024303	12648	Economy	8200.00
0005434024357	12648	Economy	8200.00
0005434024501	12648	Economy	8200.00
0005434029680	12648	Economy	8200.00
0005434024321	12648	Economy	8200.00
0005433058622	12648	Economy	8200.00
0005433058644	12648	Economy	8200.00
0005432157529	12648	Economy	8200.00
0005433058616	12648	Economy	8200.00
0005434024388	12648	Economy	8200.00
0005433058610	12648	Economy	8200.00
0005433058623	12648	Economy	8200.00
0005433058608	12648	Economy	8200.00
0005434024170	12648	Economy	8200.00
0005434029681	12648	Economy	8200.00
0005433929689	12648	Economy	8200.00
0005434024408	12648	Economy	8200.00
0005433058626	12648	Economy	8200.00
0005433058634	12648	Economy	8200.00
0005434024500	12648	Economy	8200.00
0005434024228	12648	Economy	8200.00
0005433058619	12648	Economy	8200.00
0005434024136	12648	Economy	8200.00
0005434023901	12648	Economy	8200.00
0005434735786	12648	Economy	8200.00
0005434024169	12648	Economy	8200.00
0005434024334	12648	Economy	8200.00
0005434023989	12648	Economy	8200.00
0005434024299	12648	Economy	8200.00
0005433929688	12648	Economy	8200.00
0005434024255	12648	Economy	8200.00
0005433058629	12648	Economy	8200.00
0005433058615	12648	Economy	8200.00
0005434024470	12648	Economy	8200.00
0005434024414	12648	Economy	8200.00
0005433058642	12648	Economy	9000.00
0005434024716	12648	Economy	9000.00
0005433058638	12648	Economy	8200.00
0005433058627	12648	Economy	8200.00
0005434024389	12648	Economy	8200.00
0005434024286	12648	Economy	8200.00
0005432157528	12648	Economy	8200.00
0005434024245	12648	Economy	8200.00
0005434024338	12648	Economy	8200.00
0005434028311	12648	Economy	8200.00
0005433058612	12648	Economy	8200.00
0005432156448	12648	Economy	8200.00
0005433058646	12648	Economy	8200.00
0005434024324	12648	Economy	8200.00
0005433058647	12648	Economy	8200.00
0005432156449	12648	Economy	8200.00
0005433058609	12648	Economy	8200.00
0005433058633	12648	Economy	8200.00
0005434024350	12648	Economy	8200.00
0005434024246	12648	Economy	8200.00
0005433058630	12648	Economy	8200.00
0005433058625	12648	Economy	8200.00
0005434032059	12648	Economy	8200.00
0005434024217	12648	Economy	8200.00
0005433058637	12648	Economy	8200.00
0005434735788	12648	Economy	8200.00
0005434024553	12648	Economy	8200.00
0005433058645	12648	Economy	8200.00
0005433684460	12648	Economy	8200.00
0005434735789	12648	Economy	8200.00
0005434024137	12648	Economy	8200.00
0005434024496	12648	Economy	8200.00
0005432157527	12648	Economy	8200.00
0005434024330	12648	Economy	8200.00
0005434028325	12648	Economy	8200.00
0005434024119	12648	Economy	8200.00
0005434024495	12648	Economy	8200.00
0005433058613	12648	Economy	8200.00
0005434024296	12648	Economy	8200.00
0005433684461	12648	Economy	8200.00
0005433058607	12648	Economy	8200.00
0005434024373	12648	Economy	8200.00
0005433058618	12648	Economy	8200.00
0005434024265	12648	Economy	8200.00
0005433058614	12648	Economy	8200.00
0005434024554	12648	Economy	8200.00
0005433058617	12648	Economy	8200.00
0005434024455	12648	Economy	8200.00
0005433529340	13810	Business	111600.00
0005433529332	13810	Business	111600.00
0005433529342	13810	Business	111600.00
0005433527328	13810	Business	111600.00
0005433527327	13810	Business	111600.00
0005433527323	13810	Business	111600.00
0005433527331	13810	Business	111600.00
0005433527330	13810	Business	111600.00
0005433529335	13810	Economy	37200.00
0005433529341	13810	Economy	40900.00
0005433527333	13810	Economy	37200.00
0005433529334	13810	Economy	37200.00
0005433527321	13810	Economy	37200.00
0005433527326	13810	Economy	37200.00
0005433527335	13810	Economy	37200.00
0005433529345	13810	Economy	37200.00
0005433529338	13810	Economy	37200.00
0005433527332	13810	Economy	37200.00
0005433529337	13810	Economy	37200.00
0005433527324	13810	Economy	37200.00
0005433529343	13810	Economy	37200.00
0005433529346	13810	Economy	37200.00
0005433529333	13810	Economy	37200.00
0005433527320	13810	Economy	37200.00
0005433529344	13810	Economy	37200.00
0005433527334	13810	Economy	37200.00
0005433529336	13810	Economy	37200.00
0005433529339	13810	Economy	37200.00
0005433527325	13810	Economy	37200.00
0005433527329	13810	Economy	37200.00
0005433527322	13810	Economy	37200.00
0005433529287	32457	Business	111600.00
0005433533348	32457	Business	111600.00
0005433529288	32457	Business	111600.00
0005433529279	32457	Business	111600.00
0005433533356	32457	Economy	37200.00
0005433529297	32457	Economy	37200.00
0005433529305	32457	Economy	37200.00
0005433529293	32457	Economy	40900.00
0005433533338	32457	Economy	40900.00
0005433529295	32457	Economy	37200.00
0005433533321	32457	Economy	37200.00
0005433533342	32457	Economy	37200.00
0005433529290	32457	Economy	37200.00
0005433529286	32457	Economy	37200.00
0005433533337	32457	Economy	37200.00
0005433529298	32457	Economy	37200.00
0005433529289	32457	Economy	37200.00
0005433533351	32457	Economy	37200.00
0005433529307	32457	Economy	37200.00
0005433529311	32457	Economy	37200.00
0005433529294	32457	Economy	37200.00
0005433529317	32457	Economy	37200.00
0005433533355	32457	Economy	37200.00
0005433533347	32457	Economy	37200.00
0005433533336	32457	Economy	37200.00
0005433533343	32457	Economy	37200.00
0005433529309	32457	Economy	37200.00
0005433533346	32457	Economy	37200.00
0005433533339	32457	Economy	37200.00
0005433533322	32457	Economy	37200.00
0005433533344	32457	Economy	37200.00
0005433533345	32457	Economy	37200.00
0005433529299	32457	Economy	37200.00
0005433529306	32457	Economy	37200.00
0005433529285	32457	Economy	37200.00
0005433533341	32457	Economy	37200.00
0005433529310	32457	Economy	37200.00
0005433533350	32457	Economy	37200.00
0005433533340	32457	Economy	37200.00
0005433931521	2143	Business	34700.00
0005433036674	2143	Business	34700.00
0005433036908	2143	Business	34700.00
0005433036792	2143	Business	34700.00
0005433037021	2143	Business	34700.00
0005433036807	2143	Business	34700.00
0005432231765	2143	Business	34700.00
0005433036955	2143	Business	34700.00
0005433925050	2143	Business	34700.00
0005433036753	2143	Business	34700.00
0005433925042	2143	Business	34700.00
0005432231766	2143	Business	34700.00
0005433036739	2143	Business	34700.00
0005433036918	2143	Business	34700.00
0005433036828	2143	Business	34700.00
0005433036972	2143	Business	34700.00
0005433036895	2143	Business	34700.00
0005432231764	2143	Business	34700.00
0005433925108	2143	Business	34700.00
0005433925070	2143	Business	34700.00
0005433925033	2143	Business	34700.00
0005433925084	2143	Economy	12700.00
0005433925086	2143	Economy	12700.00
0005433036823	2143	Economy	12700.00
0005434028325	2143	Economy	12700.00
0005433036841	2143	Economy	11600.00
0005433036889	2143	Economy	11600.00
0005433925098	2143	Economy	11600.00
0005433925091	2143	Economy	11600.00
0005433925043	2143	Economy	11600.00
0005433036576	2143	Economy	11600.00
0005433925089	2143	Economy	11600.00
0005433036809	2143	Economy	11600.00
0005433036781	2143	Economy	11600.00
0005433925044	2143	Economy	11600.00
0005433925058	2143	Economy	11600.00
0005433036610	2143	Economy	11600.00
0005433925049	2143	Economy	11600.00
0005433925103	2143	Economy	11600.00
0005433036691	2143	Economy	11600.00
0005433925074	2143	Economy	11600.00
0005433925027	2143	Economy	11600.00
0005433036887	2143	Economy	11600.00
0005433925096	2143	Economy	11600.00
0005433925092	2143	Economy	11600.00
0005433036919	2143	Economy	11600.00
0005433036982	2143	Economy	11600.00
0005432044575	2143	Economy	11600.00
0005433925099	2143	Economy	11600.00
0005433929691	2143	Economy	11600.00
0005433925116	2143	Economy	11600.00
0005433925076	2143	Economy	11600.00
0005433037048	2143	Economy	11600.00
0005433925081	2143	Economy	11600.00
0005433925085	2143	Economy	11600.00
0005433036865	2143	Economy	11600.00
0005433925118	2143	Economy	11600.00
0005433036877	2143	Economy	11600.00
0005433037032	2143	Economy	11600.00
0005433037047	2143	Economy	11600.00
0005433925037	2143	Economy	11600.00
0005433925075	2143	Economy	11600.00
0005432231758	2143	Economy	11600.00
0005433036862	2143	Economy	11600.00
0005433925097	2143	Economy	11600.00
0005433036990	2143	Economy	11600.00
0005433036772	2143	Economy	11600.00
0005433931520	2143	Economy	11600.00
0005432231763	2143	Economy	11600.00
0005433925107	2143	Economy	11600.00
0005433925100	2143	Economy	11600.00
0005432231761	2143	Economy	11600.00
0005433925102	2143	Economy	11600.00
0005433036842	2143	Economy	11600.00
0005433925064	2143	Economy	11600.00
0005433036817	2143	Economy	11600.00
0005433925034	2143	Economy	11600.00
0005433925111	2143	Economy	11600.00
0005433925036	2143	Economy	11600.00
0005433925030	2143	Economy	11600.00
0005433925066	2143	Economy	11600.00
0005433925055	2143	Economy	11600.00
0005433925031	2143	Economy	11600.00
0005433036676	2143	Economy	11600.00
0005433036746	2143	Economy	11600.00
0005433925047	2143	Economy	11600.00
0005433036907	2143	Economy	11600.00
0005433036754	2143	Economy	11600.00
0005432231757	2143	Economy	11600.00
0005433925087	2143	Economy	11600.00
0005433925072	2143	Economy	11600.00
0005433036791	2143	Economy	11600.00
0005433925032	2143	Economy	11600.00
0005433925115	2143	Economy	11600.00
0005433036787	2143	Economy	11600.00
0005433036926	2143	Economy	11600.00
0005433925056	2143	Economy	11600.00
0005433925112	2143	Economy	11600.00
0005433036888	2143	Economy	11600.00
0005433036827	2143	Economy	11600.00
0005433925045	2143	Economy	11600.00
0005432231760	2143	Economy	11600.00
0005433925079	2143	Economy	11600.00
0005432044576	2143	Economy	11600.00
0005433036875	2143	Economy	11600.00
0005433036799	2143	Economy	11600.00
0005433037050	2143	Economy	11600.00
0005433925094	2143	Economy	11600.00
0005433925109	2143	Economy	11600.00
0005433925065	2143	Economy	11600.00
0005433925119	2143	Economy	11600.00
0005433036821	2143	Economy	11600.00
0005433929689	2143	Economy	12700.00
0005433036899	2143	Economy	11600.00
0005433036798	2143	Economy	11600.00
0005433037010	2143	Economy	11600.00
0005433925071	2143	Economy	12700.00
0005433925083	2143	Economy	12700.00
0005433925057	2143	Economy	11600.00
0005433925106	2143	Economy	11600.00
0005433036819	2143	Economy	11600.00
0005433925077	2143	Economy	11600.00
0005433925024	2143	Economy	11600.00
0005433925038	2143	Economy	11600.00
0005433925113	2143	Economy	11600.00
0005433925039	2143	Economy	11600.00
0005433925069	2143	Economy	11600.00
0005433925046	2143	Economy	11600.00
0005433925026	2143	Economy	11600.00
0005433925093	2143	Economy	11600.00
0005433929690	2143	Economy	11600.00
0005433036779	2143	Economy	11600.00
0005433925117	2143	Economy	11600.00
0005433925053	2143	Economy	11600.00
0005433925121	2143	Economy	11600.00
0005433925090	2143	Economy	11600.00
0005433925054	2143	Economy	11600.00
0005433036900	2143	Economy	11600.00
0005433036957	2143	Economy	11600.00
0005433036611	2143	Economy	11600.00
0005433925025	2143	Economy	11600.00
0005432231756	2143	Economy	11600.00
0005434028311	2143	Economy	11600.00
0005433925080	2143	Economy	11600.00
0005433925101	2143	Economy	11600.00
0005433036855	2143	Economy	11600.00
0005433925035	2143	Economy	11600.00
0005434028321	2143	Economy	11600.00
0005433929688	2143	Economy	11600.00
0005433925095	2143	Economy	11600.00
0005433925041	2143	Economy	11600.00
0005433036846	2143	Economy	11600.00
0005433925062	2143	Economy	11600.00
0005433925104	2143	Economy	11600.00
0005433925029	2143	Economy	11600.00
0005433925088	2143	Economy	11600.00
0005433036768	2143	Economy	11600.00
0005433925028	2143	Economy	11600.00
0005433036511	2143	Economy	11600.00
0005433925048	2143	Economy	11600.00
0005433925114	2143	Economy	11600.00
0005433037041	2143	Economy	11600.00
0005433036884	2143	Economy	11600.00
0005433925105	2143	Economy	11600.00
0005433925051	2143	Economy	11600.00
0005432231759	2143	Economy	11600.00
0005433036780	2143	Economy	11600.00
0005433925078	2143	Economy	11600.00
0005433925082	2143	Economy	11600.00
0005433925073	2143	Economy	11600.00
0005433925067	2143	Economy	11600.00
0005432231762	2143	Economy	11600.00
0005433036816	2143	Economy	11600.00
0005433036767	2143	Economy	11600.00
0005433036954	2143	Economy	11600.00
0005433925040	2143	Economy	11600.00
0005433925068	2143	Economy	11600.00
0005433036716	2143	Economy	11600.00
0005433036983	2143	Economy	11600.00
0005433925061	2143	Economy	11600.00
0005433925059	2143	Economy	11600.00
0005433925120	2143	Economy	11600.00
0005433925110	2143	Economy	11600.00
0005433925060	2143	Economy	11600.00
0005433925063	2143	Economy	11600.00
0005433036840	2143	Economy	11600.00
0005433925052	2143	Economy	11600.00
0005433037296	24136	Business	34700.00
0005433924130	24136	Business	34700.00
0005433924487	24136	Business	34700.00
0005432206302	24136	Business	34700.00
0005433924655	24136	Business	34700.00
0005433924493	24136	Business	34700.00
0005433037255	24136	Business	34700.00
0005433037294	24136	Business	34700.00
0005433923801	24136	Business	34700.00
0005433923900	24136	Business	34700.00
0005433923836	24136	Business	34700.00
0005433931493	24136	Business	34700.00
0005433924329	24136	Business	34700.00
0005433924237	24136	Business	34700.00
0005433037270	24136	Business	34700.00
0005433037246	24136	Business	34700.00
0005433924175	24136	Business	34700.00
0005433037268	24136	Business	34700.00
0005433924512	24136	Business	34700.00
0005433037247	24136	Business	34700.00
0005432749826	24136	Business	34700.00
0005432206303	24136	Business	34700.00
0005433924445	24136	Business	34700.00
0005433924280	24136	Business	34700.00
0005433924187	24136	Business	34700.00
0005433037291	24136	Business	34700.00
0005433037253	24136	Economy	12700.00
0005433924228	24136	Economy	12700.00
0005433929652	24136	Economy	11600.00
0005433923898	24136	Economy	11600.00
0005433924274	24136	Economy	11600.00
0005433037248	24136	Economy	11600.00
0005433924355	24136	Economy	11600.00
0005433924243	24136	Economy	11600.00
0005433875389	24136	Economy	11600.00
0005433037276	24136	Economy	11600.00
0005432207711	24136	Economy	11600.00
0005433037256	24136	Economy	11600.00
0005433037262	24136	Economy	11600.00
0005433037275	24136	Economy	11600.00
0005433037295	24136	Economy	11600.00
0005433037298	24136	Economy	11600.00
0005433924382	24136	Economy	11600.00
0005434028357	24136	Economy	11600.00
0005433924308	24136	Economy	11600.00
0005433037269	24136	Economy	11600.00
0005432207709	24136	Economy	11600.00
0005433924520	24136	Economy	11600.00
0005433037279	24136	Economy	11600.00
0005433924186	24136	Economy	11600.00
0005433923993	24136	Economy	11600.00
0005433924281	24136	Economy	11600.00
0005432207710	24136	Economy	11600.00
0005433924444	24136	Economy	11600.00
0005433037260	24136	Economy	11600.00
0005433924249	24136	Economy	11600.00
0005433923968	24136	Economy	11600.00
0005433924504	24136	Economy	11600.00
0005433037288	24136	Economy	11600.00
0005433924307	24136	Economy	11600.00
0005432206301	24136	Economy	11600.00
0005433037282	24136	Economy	11600.00
0005433037252	24136	Economy	11600.00
0005434028359	24136	Economy	11600.00
0005433037257	24136	Economy	11600.00
0005433037273	24136	Economy	11600.00
0005433924387	24136	Economy	11600.00
0005433037278	24136	Economy	11600.00
0005433924654	24136	Economy	11600.00
0005433037285	24136	Economy	11600.00
0005433924176	24136	Economy	11600.00
0005433924374	24136	Economy	11600.00
0005433037254	24136	Economy	11600.00
0005433037250	24136	Economy	11600.00
0005433924741	24136	Economy	11600.00
0005433924196	24136	Economy	11600.00
0005433924440	24136	Economy	11600.00
0005433923837	24136	Economy	11600.00
0005433037259	24136	Economy	11600.00
0005433924216	24136	Economy	11600.00
0005433037258	24136	Economy	11600.00
0005433924076	24136	Economy	11600.00
0005433924331	24136	Economy	11600.00
0005433923945	24136	Economy	11600.00
0005433037293	24136	Economy	11600.00
0005433924287	24136	Economy	11600.00
0005433037286	24136	Economy	11600.00
0005433037267	24136	Economy	11600.00
0005433923953	24136	Economy	11600.00
0005433923680	24136	Economy	11600.00
0005433923990	24136	Economy	11600.00
0005433037287	24136	Economy	11600.00
0005432749825	24136	Economy	11600.00
0005433924479	24136	Economy	11600.00
0005433924077	24136	Economy	11600.00
0005433037271	24136	Economy	11600.00
0005434028358	24136	Economy	11600.00
0005433037297	24136	Economy	11600.00
0005433037289	24136	Economy	11600.00
0005433923787	24136	Economy	11600.00
0005433037251	24136	Economy	11600.00
0005433924356	24136	Economy	11600.00
0005433924189	24136	Economy	12700.00
0005433923944	24136	Economy	11600.00
0005433924539	24136	Economy	12700.00
0005433924259	24136	Economy	11600.00
0005433924164	24136	Economy	11600.00
0005433924082	24136	Economy	11600.00
0005433924510	24136	Economy	11600.00
0005433924138	24136	Economy	11600.00
0005433924190	24136	Economy	11600.00
0005433924279	24136	Economy	11600.00
0005433924201	24136	Economy	11600.00
0005433037263	24136	Economy	11600.00
0005433924139	24136	Economy	11600.00
0005433924511	24136	Economy	11600.00
0005433924311	24136	Economy	11600.00
0005433924513	24136	Economy	11600.00
0005433923897	24136	Economy	11600.00
0005433037290	24136	Economy	11600.00
0005433924330	24136	Economy	11600.00
0005433037283	24136	Economy	11600.00
0005433931501	24136	Economy	11600.00
0005433924419	24136	Economy	11600.00
0005433924310	24136	Economy	11600.00
0005433923890	24136	Economy	11600.00
0005433923896	24136	Economy	11600.00
0005433924140	24136	Economy	11600.00
0005433929653	24136	Economy	11600.00
0005433037265	24136	Economy	11600.00
0005433924353	24136	Economy	11600.00
0005433037281	24136	Economy	11600.00
0005433037272	24136	Economy	11600.00
0005433924238	24136	Economy	11600.00
0005433037261	24136	Economy	11600.00
0005433924443	24136	Economy	11600.00
0005433924402	24136	Economy	11600.00
0005433924312	24136	Economy	11600.00
0005433037266	24136	Economy	11600.00
0005433924025	24136	Economy	11600.00
0005433929651	24136	Economy	11600.00
0005433923802	24136	Economy	11600.00
0005433924200	24136	Economy	11600.00
0005433037264	24136	Economy	11600.00
0005433924229	24136	Economy	11600.00
0005433924309	24136	Economy	11600.00
0005433924620	24136	Economy	11600.00
0005432206304	24136	Economy	11600.00
0005433924395	24136	Economy	11600.00
0005433037280	24136	Economy	11600.00
0005433037292	24136	Economy	11600.00
0005433037284	24136	Economy	11600.00
0005432206305	24136	Economy	11600.00
0005433924275	24136	Economy	11600.00
0005433923835	24136	Economy	11600.00
0005433924215	24136	Economy	11600.00
0005434028356	24136	Economy	11600.00
0005433037274	24136	Economy	11600.00
0005433037249	24136	Economy	11600.00
0005433924366	24136	Economy	11600.00
0005433924087	24136	Economy	11600.00
0005433924383	24136	Economy	11600.00
0005433924193	24136	Economy	11600.00
0005433924360	24136	Economy	11600.00
0005433037277	24136	Economy	11600.00
0005433924063	24136	Economy	11600.00
0005433924403	24136	Economy	11600.00
0005434727755	267	Business	83700.00
0005433181297	267	Business	83700.00
0005433234982	267	Business	83700.00
0005434727705	267	Business	83700.00
0005434727748	267	Business	83700.00
0005434552245	267	Business	83700.00
0005433181387	267	Business	83700.00
0005433181295	267	Business	83700.00
0005434552241	267	Business	83700.00
0005434727717	267	Business	83700.00
0005432278060	267	Business	83700.00
0005434727666	267	Business	83700.00
0005433289917	267	Business	83700.00
0005434727672	267	Business	83700.00
0005433181332	267	Business	83700.00
0005434727716	267	Business	83700.00
0005434727708	267	Business	83700.00
0005434727656	267	Business	83700.00
0005434552223	267	Business	83700.00
0005433181421	267	Business	83700.00
0005433234587	267	Business	83700.00
0005433289931	267	Business	83700.00
0005433766669	267	Business	83700.00
0005434727678	267	Business	83700.00
0005433181294	267	Business	83700.00
0005434727684	267	Business	83700.00
0005433234707	267	Business	83700.00
0005434727763	267	Business	83700.00
0005434552225	267	Comfort	47400.00
0005433234798	267	Comfort	47400.00
0005433181388	267	Comfort	47400.00
0005433234730	267	Comfort	47400.00
0005433234756	267	Comfort	47400.00
0005434727721	267	Comfort	47400.00
0005434552254	267	Comfort	47400.00
0005433131735	267	Comfort	47400.00
0005433181318	267	Comfort	47400.00
0005433234725	267	Comfort	47400.00
0005433181270	267	Comfort	47400.00
0005434727753	267	Comfort	47400.00
0005433181384	267	Comfort	47400.00
0005434727751	267	Comfort	47400.00
0005434727711	267	Comfort	47400.00
0005433289911	267	Comfort	47400.00
0005434727650	267	Comfort	47400.00
0005433235053	267	Comfort	47400.00
0005435142834	267	Comfort	47400.00
0005433234595	267	Comfort	47400.00
0005434727731	267	Comfort	47400.00
0005434552246	267	Comfort	47400.00
0005433234735	267	Comfort	47400.00
0005434552244	267	Comfort	47400.00
0005434731245	267	Comfort	47400.00
0005433126898	267	Comfort	47400.00
0005433131757	267	Comfort	47400.00
0005433234940	267	Comfort	47400.00
0005434727703	267	Comfort	47400.00
0005434727771	267	Comfort	47400.00
0005434735781	267	Comfort	47400.00
0005434727718	267	Comfort	47400.00
0005434727761	267	Comfort	47400.00
0005433235004	267	Comfort	47400.00
0005434727696	267	Comfort	47400.00
0005434727694	267	Comfort	47400.00
0005434727697	267	Comfort	47400.00
0005435142826	267	Comfort	47400.00
0005434552239	267	Comfort	47400.00
0005433181268	267	Comfort	47400.00
0005432278057	267	Comfort	47400.00
0005432278052	267	Economy	27900.00
0005434727682	267	Comfort	47400.00
0005434552242	267	Economy	27900.00
0005434552231	267	Economy	27900.00
0005434735782	267	Economy	27900.00
0005434552267	267	Economy	27900.00
0005434727739	267	Economy	27900.00
0005433181293	267	Economy	27900.00
0005433234784	267	Economy	27900.00
0005434727669	267	Economy	27900.00
0005433234797	267	Economy	27900.00
0005434727695	267	Economy	27900.00
0005433234583	267	Economy	27900.00
0005434727732	267	Economy	27900.00
0005435142830	267	Economy	27900.00
0005434727653	267	Economy	27900.00
0005433235055	267	Economy	27900.00
0005433234915	267	Economy	27900.00
0005433234923	267	Economy	27900.00
0005434552224	267	Economy	27900.00
0005434727670	267	Economy	27900.00
0005434727699	267	Economy	27900.00
0005434727724	267	Economy	27900.00
0005434552249	267	Economy	27900.00
0005433289882	267	Economy	27900.00
0005433234609	267	Economy	27900.00
0005434552263	267	Economy	27900.00
0005433289938	267	Economy	27900.00
0005434727677	267	Economy	27900.00
0005434727725	267	Economy	27900.00
0005433289883	267	Economy	27900.00
0005434727698	267	Economy	27900.00
0005434727743	267	Economy	27900.00
0005434727744	267	Economy	27900.00
0005434552240	267	Economy	27900.00
0005434727676	267	Economy	27900.00
0005433126874	267	Economy	27900.00
0005435142823	267	Economy	27900.00
0005433235062	267	Economy	27900.00
0005434727727	267	Economy	27900.00
0005434727712	267	Economy	27900.00
0005434727764	267	Economy	27900.00
0005434727667	267	Economy	27900.00
0005434735783	267	Economy	27900.00
0005432278054	267	Economy	27900.00
0005434552252	267	Economy	27900.00
0005433235067	267	Economy	27900.00
0005434552247	267	Economy	27900.00
0005433234668	267	Economy	27900.00
0005433234663	267	Economy	27900.00
0005433181303	267	Economy	27900.00
0005433181331	267	Economy	27900.00
0005434552221	267	Economy	27900.00
0005433234739	267	Economy	27900.00
0005434727651	267	Economy	27900.00
0005434552232	267	Economy	27900.00
0005433289912	267	Economy	27900.00
0005433234864	267	Economy	30700.00
0005433181413	267	Economy	27900.00
0005434727706	267	Economy	30700.00
0005434727745	267	Economy	30700.00
0005433111519	267	Economy	27900.00
0005435142828	267	Economy	27900.00
0005432278056	267	Economy	27900.00
0005434552235	267	Economy	30700.00
0005433234916	267	Economy	27900.00
0005434727773	267	Economy	30700.00
0005434727680	267	Economy	27900.00
0005434727674	267	Economy	30700.00
0005434552219	267	Economy	27900.00
0005434552251	267	Economy	27900.00
0005434727710	267	Economy	27900.00
0005434552243	267	Economy	27900.00
0005435142832	267	Economy	27900.00
0005433181404	267	Economy	27900.00
0005433113557	267	Economy	27900.00
0005434727701	267	Economy	27900.00
0005434552227	267	Economy	27900.00
0005434552260	267	Economy	27900.00
0005435142833	267	Economy	27900.00
0005433234872	267	Economy	27900.00
0005434302539	267	Economy	27900.00
0005434735780	267	Economy	27900.00
0005433126897	267	Economy	27900.00
0005433181452	267	Economy	27900.00
0005433235063	267	Economy	27900.00
0005433126889	267	Economy	27900.00
0005433234734	267	Economy	27900.00
0005434727654	267	Economy	27900.00
0005433111518	267	Economy	27900.00
0005434552256	267	Economy	27900.00
0005433126896	267	Economy	27900.00
0005434727719	267	Economy	27900.00
0005434731246	267	Economy	27900.00
0005434552228	267	Economy	27900.00
0005434731244	267	Economy	27900.00
0005433289914	267	Economy	27900.00
0005434727664	267	Economy	27900.00
0005433111525	267	Economy	27900.00
0005434735784	267	Economy	27900.00
0005435142831	267	Economy	27900.00
0005434727758	267	Economy	27900.00
0005433234885	267	Economy	27900.00
0005433234863	267	Economy	27900.00
0005434727752	267	Economy	27900.00
0005433234830	267	Economy	27900.00
0005433181422	267	Economy	27900.00
0005432278050	267	Economy	27900.00
0005434552238	267	Economy	27900.00
0005433234854	267	Economy	27900.00
0005432278059	267	Economy	27900.00
0005433234537	267	Economy	27900.00
0005433126872	267	Economy	27900.00
0005433181316	267	Economy	27900.00
0005433234742	267	Economy	27900.00
0005434727769	267	Economy	27900.00
0005434727772	267	Economy	27900.00
0005434552261	267	Economy	27900.00
0005434727749	267	Economy	27900.00
0005434727715	267	Economy	27900.00
0005434727652	267	Economy	27900.00
0005433766674	267	Economy	27900.00
0005434727742	267	Economy	27900.00
0005433181292	267	Economy	27900.00
0005432278064	267	Economy	27900.00
0005434727660	267	Economy	27900.00
0005434727691	267	Economy	27900.00
0005433234321	267	Economy	27900.00
0005433234726	267	Economy	27900.00
0005434552222	267	Economy	27900.00
0005434727668	267	Economy	27900.00
0005433289916	267	Economy	27900.00
0005433126885	267	Economy	27900.00
0005434552266	267	Economy	27900.00
0005433181406	267	Economy	27900.00
0005433234845	267	Economy	27900.00
0005433234594	267	Economy	27900.00
0005435142829	267	Economy	27900.00
0005434552259	267	Economy	27900.00
0005434727693	267	Economy	27900.00
0005434552230	267	Economy	27900.00
0005434727661	267	Economy	27900.00
0005433181407	267	Economy	27900.00
0005434552250	267	Economy	27900.00
0005433234855	267	Economy	27900.00
0005434727722	267	Economy	27900.00
0005434727741	267	Economy	27900.00
0005433289930	267	Economy	27900.00
0005433234711	267	Economy	27900.00
0005434727658	267	Economy	27900.00
0005434302538	267	Economy	27900.00
0005434552234	267	Economy	27900.00
0005434727657	267	Economy	27900.00
0005434727709	267	Economy	27900.00
0005434727728	267	Economy	27900.00
0005433234586	267	Economy	27900.00
0005434727756	267	Economy	27900.00
0005434727774	267	Economy	27900.00
0005433234914	267	Economy	27900.00
0005433181447	267	Economy	27900.00
0005434727649	267	Economy	27900.00
0005434727759	267	Economy	27900.00
0005433289919	267	Economy	27900.00
0005434727738	267	Economy	27900.00
0005433111532	267	Economy	27900.00
0005434727720	267	Economy	27900.00
0005432278062	267	Economy	27900.00
0005434727760	267	Economy	27900.00
0005434727766	267	Economy	27900.00
0005434032037	267	Economy	27900.00
0005434552272	267	Economy	27900.00
0005434727714	267	Economy	27900.00
0005434727730	267	Economy	27900.00
0005432278053	267	Economy	27900.00
0005433234757	267	Economy	27900.00
0005433235056	267	Economy	27900.00
0005434727707	267	Economy	27900.00
0005434552264	267	Economy	30700.00
0005434727688	267	Economy	27900.00
0005434552270	267	Economy	30700.00
0005434552271	267	Economy	30700.00
0005433234941	267	Economy	30700.00
0005434727662	267	Economy	30700.00
0005434727675	267	Economy	27900.00
0005432278055	267	Economy	27900.00
0005434727685	267	Economy	27900.00
0005434552248	267	Economy	27900.00
0005433234934	267	Economy	27900.00
0005434727767	267	Economy	27900.00
0005434727689	267	Economy	27900.00
0005434727733	267	Economy	27900.00
0005434727754	267	Economy	27900.00
0005434727740	267	Economy	27900.00
0005434727687	267	Economy	27900.00
0005434727736	267	Economy	27900.00
0005434552255	267	Economy	27900.00
0005434552258	267	Economy	27900.00
0005433181409	267	Economy	27900.00
0005433289913	267	Economy	27900.00
0005434727737	267	Economy	27900.00
0005433234981	267	Economy	27900.00
0005433234525	267	Economy	27900.00
0005434727686	267	Economy	27900.00
0005434727700	267	Economy	27900.00
0005433234935	267	Economy	27900.00
0005433234705	267	Economy	27900.00
0005434552273	267	Economy	27900.00
0005433126871	267	Economy	27900.00
0005434727765	267	Economy	27900.00
0005434552229	267	Economy	27900.00
0005434727726	267	Economy	27900.00
0005434302541	267	Economy	27900.00
0005433289929	267	Economy	27900.00
0005434727734	267	Economy	27900.00
0005434552236	267	Economy	27900.00
0005432278063	267	Economy	27900.00
0005434727671	267	Economy	27900.00
0005434727704	267	Economy	27900.00
0005433126902	267	Economy	27900.00
0005434727757	267	Economy	27900.00
0005432278058	267	Economy	27900.00
0005435142825	267	Economy	27900.00
0005434032036	267	Economy	27900.00
0005433181315	267	Economy	27900.00
0005433181289	267	Economy	27900.00
0005433289918	267	Economy	27900.00
0005434727692	267	Economy	27900.00
0005433234729	267	Economy	27900.00
0005435142824	267	Economy	27900.00
0005434552257	267	Economy	27900.00
0005434727768	267	Economy	27900.00
0005434727681	267	Economy	27900.00
0005434727683	267	Economy	27900.00
0005434727655	267	Economy	27900.00
0005435142822	267	Economy	27900.00
0005433234740	267	Economy	27900.00
0005434727770	267	Economy	27900.00
0005434727659	267	Economy	27900.00
0005434552269	267	Economy	27900.00
0005432278061	267	Economy	27900.00
0005433181330	267	Economy	27900.00
0005434552220	267	Economy	27900.00
0005435142827	267	Economy	27900.00
0005434727729	267	Economy	27900.00
0005434552268	267	Economy	27900.00
0005433234708	267	Economy	27900.00
0005434032047	267	Economy	27900.00
0005433234728	267	Economy	27900.00
0005433234736	267	Economy	27900.00
0005433234664	267	Economy	27900.00
0005434727723	267	Economy	27900.00
0005434727702	267	Economy	27900.00
0005434552265	267	Economy	27900.00
0005433181269	267	Economy	27900.00
0005434727735	267	Economy	27900.00
0005434727746	267	Economy	27900.00
0005434727663	267	Economy	27900.00
0005433234584	267	Economy	27900.00
0005433234959	267	Economy	27900.00
0005434552233	267	Economy	27900.00
0005434727673	267	Economy	27900.00
0005433235068	267	Economy	27900.00
0005434302537	267	Economy	27900.00
0005434552226	267	Economy	27900.00
0005433131736	267	Economy	27900.00
0005433181251	267	Economy	27900.00
0005433235154	267	Economy	27900.00
0005434727750	267	Economy	27900.00
0005434727665	267	Economy	27900.00
0005434727679	267	Economy	27900.00
0005433766673	267	Economy	27900.00
0005433234871	267	Economy	27900.00
0005433234808	267	Economy	27900.00
0005433234781	267	Economy	27900.00
0005434727690	267	Economy	27900.00
0005434552253	267	Economy	27900.00
0005433289915	267	Economy	27900.00
0005433234875	267	Economy	27900.00
0005433181405	267	Economy	27900.00
0005434302540	267	Economy	27900.00
0005433181412	267	Economy	27900.00
0005433234524	267	Economy	27900.00
0005434727762	267	Economy	27900.00
0005434727713	267	Economy	27900.00
0005434727747	267	Economy	27900.00
0005432278051	267	Economy	27900.00
0005434552262	267	Economy	27900.00
0005434552237	267	Economy	27900.00
0005434735785	267	Economy	27900.00
0005434726500	9851	Business	83700.00
0005433235346	9851	Business	83700.00
0005434551747	9851	Business	83700.00
0005434726787	9851	Business	83700.00
0005434551757	9851	Business	83700.00
0005434726975	9851	Business	83700.00
0005434726414	9851	Business	83700.00
0005434726019	9851	Business	83700.00
0005434551921	9851	Business	83700.00
0005435142640	9851	Business	83700.00
0005434726761	9851	Business	83700.00
0005434735749	9851	Business	83700.00
0005434302497	9851	Business	83700.00
0005434726311	9851	Business	83700.00
0005434726753	9851	Business	83700.00
0005434551604	9851	Business	83700.00
0005434726477	9851	Business	83700.00
0005434727105	9851	Business	83700.00
0005433181578	9851	Business	83700.00
0005433235395	9851	Business	83700.00
0005433235357	9851	Business	83700.00
0005434551908	9851	Business	83700.00
0005434726423	9851	Business	83700.00
0005434726538	9851	Business	83700.00
0005434726413	9851	Business	83700.00
0005434551771	9851	Business	83700.00
0005434726464	9851	Comfort	47400.00
0005434302499	9851	Comfort	47400.00
0005433181558	9851	Comfort	47400.00
0005433235354	9851	Comfort	47400.00
0005433181577	9851	Comfort	47400.00
0005434726671	9851	Comfort	47400.00
0005433126927	9851	Comfort	47400.00
0005433235378	9851	Comfort	47400.00
0005433235396	9851	Comfort	47400.00
0005433235385	9851	Comfort	47400.00
0005434551782	9851	Comfort	47400.00
0005434726703	9851	Comfort	47400.00
0005434726461	9851	Comfort	47400.00
0005434551863	9851	Comfort	47400.00
0005433181554	9851	Comfort	47400.00
0005434726619	9851	Comfort	47400.00
0005434726705	9851	Comfort	47400.00
0005434727005	9851	Comfort	47400.00
0005434726938	9851	Comfort	47400.00
0005433289978	9851	Comfort	47400.00
0005434726251	9851	Comfort	47400.00
0005434032109	9851	Comfort	47400.00
0005433235368	9851	Comfort	47400.00
0005433235386	9851	Comfort	47400.00
0005434551568	9851	Comfort	47400.00
0005433235370	9851	Comfort	47400.00
0005433235384	9851	Comfort	47400.00
0005434551668	9851	Comfort	47400.00
0005434727124	9851	Comfort	47400.00
0005434726539	9851	Comfort	47400.00
0005434726603	9851	Comfort	47400.00
0005434032113	9851	Comfort	47400.00
0005434726328	9851	Comfort	47400.00
0005433235350	9851	Comfort	47400.00
0005433235394	9851	Comfort	47400.00
0005434731210	9851	Comfort	47400.00
0005433235352	9851	Comfort	47400.00
0005434726850	9851	Comfort	47400.00
0005433235376	9851	Comfort	47400.00
0005434726847	9851	Comfort	47400.00
0005434727006	9851	Comfort	47400.00
0005434726937	9851	Comfort	47400.00
0005434727132	9851	Comfort	47400.00
0005435142709	9851	Comfort	47400.00
0005434726876	9851	Economy	27900.00
0005433235358	9851	Economy	27900.00
0005433289982	9851	Economy	27900.00
0005434726618	9851	Economy	27900.00
0005434552011	9851	Economy	27900.00
0005434726562	9851	Economy	27900.00
0005433126928	9851	Economy	27900.00
0005433289980	9851	Economy	27900.00
0005434551854	9851	Economy	27900.00
0005434726976	9851	Economy	27900.00
0005433181567	9851	Economy	27900.00
0005434726303	9851	Economy	27900.00
0005433235388	9851	Economy	27900.00
0005433289977	9851	Economy	27900.00
0005434727054	9851	Economy	27900.00
0005434727100	9851	Economy	27900.00
0005433113576	9851	Economy	27900.00
0005434726877	9851	Economy	27900.00
0005434551643	9851	Economy	27900.00
0005434726895	9851	Economy	27900.00
0005434726941	9851	Economy	27900.00
0005433289983	9851	Economy	27900.00
0005434725790	9851	Economy	27900.00
0005434727121	9851	Economy	27900.00
0005433766711	9851	Economy	27900.00
0005434726560	9851	Economy	27900.00
0005434726046	9851	Economy	27900.00
0005434727268	9851	Economy	27900.00
0005433129358	9851	Economy	27900.00
0005433235353	9851	Economy	27900.00
0005434551772	9851	Economy	27900.00
0005433181579	9851	Economy	27900.00
0005433235344	9851	Economy	27900.00
0005433181556	9851	Economy	27900.00
0005434726288	9851	Economy	27900.00
0005433235380	9851	Economy	27900.00
0005434726669	9851	Economy	27900.00
0005434032112	9851	Economy	27900.00
0005433766712	9851	Economy	27900.00
0005434726878	9851	Economy	27900.00
0005434726896	9851	Economy	27900.00
0005434726766	9851	Economy	27900.00
0005434551665	9851	Economy	27900.00
0005433235375	9851	Economy	27900.00
0005434726215	9851	Economy	27900.00
0005434726433	9851	Economy	27900.00
0005434302494	9851	Economy	27900.00
0005434726675	9851	Economy	27900.00
0005434551750	9851	Economy	27900.00
0005433235363	9851	Economy	27900.00
0005434726670	9851	Economy	27900.00
0005434726250	9851	Economy	27900.00
0005434726317	9851	Economy	27900.00
0005433181571	9851	Economy	27900.00
0005433235361	9851	Economy	27900.00
0005434726809	9851	Economy	27900.00
0005433126929	9851	Economy	27900.00
0005434726020	9851	Economy	27900.00
0005434726594	9851	Economy	27900.00
0005434726881	9851	Economy	27900.00
0005434726686	9851	Economy	27900.00
0005434551773	9851	Economy	27900.00
0005433235367	9851	Economy	27900.00
0005433235356	9851	Economy	27900.00
0005434551825	9851	Economy	27900.00
0005433181560	9851	Economy	27900.00
0005434726942	9851	Economy	30700.00
0005433235387	9851	Economy	30700.00
0005434551933	9851	Economy	27900.00
0005434551744	9851	Economy	30700.00
0005434726424	9851	Economy	27900.00
0005434727243	9851	Economy	27900.00
0005433181569	9851	Economy	30700.00
0005434726475	9851	Economy	30700.00
0005434727108	9851	Economy	27900.00
0005433289984	9851	Economy	27900.00
0005434726875	9851	Economy	27900.00
0005434726583	9851	Economy	27900.00
0005434727013	9851	Economy	27900.00
0005434551753	9851	Economy	27900.00
0005434726778	9851	Economy	27900.00
0005434551826	9851	Economy	27900.00
0005434726710	9851	Economy	27900.00
0005433181574	9851	Economy	27900.00
0005433181568	9851	Economy	27900.00
0005434551692	9851	Economy	27900.00
0005434302518	9851	Economy	27900.00
0005434731208	9851	Economy	27900.00
0005434726316	9851	Economy	27900.00
0005432199377	9851	Economy	27900.00
0005434551780	9851	Economy	27900.00
0005434735761	9851	Economy	27900.00
0005434735760	9851	Economy	27900.00
0005434551715	9851	Economy	27900.00
0005434551824	9851	Economy	27900.00
0005434551651	9851	Economy	27900.00
0005433181576	9851	Economy	27900.00
0005434726241	9851	Economy	27900.00
0005434727437	9851	Economy	27900.00
0005434551513	9851	Economy	27900.00
0005433235379	9851	Economy	27900.00
0005434726620	9851	Economy	27900.00
0005434735750	9851	Economy	27900.00
0005433235337	9851	Economy	27900.00
0005434726936	9851	Economy	27900.00
0005433235347	9851	Economy	27900.00
0005433235348	9851	Economy	27900.00
0005434551603	9851	Economy	27900.00
0005433181564	9851	Economy	27900.00
0005433181562	9851	Economy	27900.00
0005434551752	9851	Economy	27900.00
0005435142636	9851	Economy	27900.00
0005434551670	9851	Economy	27900.00
0005433289979	9851	Economy	27900.00
0005434551330	9851	Economy	27900.00
0005433235393	9851	Economy	27900.00
0005433235339	9851	Economy	27900.00
0005433235359	9851	Economy	27900.00
0005434731204	9851	Economy	27900.00
0005433235338	9851	Economy	27900.00
0005433235365	9851	Economy	27900.00
0005434726425	9851	Economy	27900.00
0005434551701	9851	Economy	27900.00
0005434726593	9851	Economy	27900.00
0005434726685	9851	Economy	27900.00
0005433235372	9851	Economy	27900.00
0005433235364	9851	Economy	27900.00
0005434735731	9851	Economy	27900.00
0005434726777	9851	Economy	27900.00
0005433235362	9851	Economy	27900.00
0005434726706	9851	Economy	27900.00
0005434726444	9851	Economy	27900.00
0005435142677	9851	Economy	27900.00
0005434727131	9851	Economy	27900.00
0005434726923	9851	Economy	27900.00
0005433235391	9851	Economy	27900.00
0005434302496	9851	Economy	27900.00
0005433126930	9851	Economy	27900.00
0005434726848	9851	Economy	27900.00
0005433235360	9851	Economy	27900.00
0005432199380	9851	Economy	27900.00
0005434726985	9851	Economy	27900.00
0005434551746	9851	Economy	27900.00
0005434551932	9851	Economy	27900.00
0005433235373	9851	Economy	27900.00
0005433235374	9851	Economy	27900.00
0005433235342	9851	Economy	27900.00
0005434551663	9851	Economy	27900.00
0005435142733	9851	Economy	27900.00
0005433235371	9851	Economy	27900.00
0005434726474	9851	Economy	27900.00
0005433235351	9851	Economy	27900.00
0005433235398	9851	Economy	27900.00
0005432199378	9851	Economy	27900.00
0005434726788	9851	Economy	27900.00
0005434551855	9851	Economy	27900.00
0005434726622	9851	Economy	27900.00
0005434726613	9851	Economy	27900.00
0005434726786	9851	Economy	27900.00
0005433129359	9851	Economy	27900.00
0005434726585	9851	Economy	27900.00
0005433766710	9851	Economy	27900.00
0005433235341	9851	Economy	27900.00
0005434726472	9851	Economy	27900.00
0005433235392	9851	Economy	27900.00
0005433235397	9851	Economy	27900.00
0005433235340	9851	Economy	27900.00
0005434726465	9851	Economy	27900.00
0005434727099	9851	Economy	27900.00
0005434551914	9851	Economy	27900.00
0005434551664	9851	Economy	30700.00
0005434551569	9851	Economy	30700.00
0005434727004	9851	Economy	30700.00
0005434726966	9851	Economy	30700.00
0005434727073	9851	Economy	27900.00
0005434727053	9851	Economy	30700.00
0005434726596	9851	Economy	27900.00
0005434726699	9851	Economy	27900.00
0005433235377	9851	Economy	27900.00
0005434551702	9851	Economy	27900.00
0005434726604	9851	Economy	27900.00
0005434551778	9851	Economy	27900.00
0005434551585	9851	Economy	27900.00
0005433181570	9851	Economy	27900.00
0005434726188	9851	Economy	27900.00
0005434551751	9851	Economy	27900.00
0005433235381	9851	Economy	27900.00
0005434726707	9851	Economy	27900.00
0005434726445	9851	Economy	27900.00
0005433235335	9851	Economy	27900.00
0005434726309	9851	Economy	27900.00
0005433235366	9851	Economy	27900.00
0005434726587	9851	Economy	27900.00
0005434551502	9851	Economy	27900.00
0005435142708	9851	Economy	27900.00
0005434726634	9851	Economy	27900.00
0005434726920	9851	Economy	27900.00
0005433181572	9851	Economy	27900.00
0005433235349	9851	Economy	27900.00
0005435142701	9851	Economy	27900.00
0005433181573	9851	Economy	27900.00
0005434726760	9851	Economy	27900.00
0005434727120	9851	Economy	27900.00
0005434551694	9851	Economy	27900.00
0005433289981	9851	Economy	27900.00
0005434032110	9851	Economy	27900.00
0005432199376	9851	Economy	27900.00
0005435142641	9851	Economy	27900.00
0005434551739	9851	Economy	27900.00
0005435142730	9851	Economy	27900.00
0005433181559	9851	Economy	27900.00
0005432199375	9851	Economy	27900.00
0005434551804	9851	Economy	27900.00
0005433235383	9851	Economy	27900.00
0005433235369	9851	Economy	27900.00
0005434551792	9851	Economy	27900.00
0005434726897	9851	Economy	27900.00
0005434302517	9851	Economy	27900.00
0005435142695	9851	Economy	27900.00
0005434551691	9851	Economy	27900.00
0005434731203	9851	Economy	27900.00
0005434731205	9851	Economy	27900.00
0005433181557	9851	Economy	27900.00
0005434726816	9851	Economy	27900.00
0005434726880	9851	Economy	27900.00
0005434726752	9851	Economy	27900.00
0005434551779	9851	Economy	27900.00
0005434726757	9851	Economy	27900.00
0005434551803	9851	Economy	27900.00
0005435142637	9851	Economy	27900.00
0005434551510	9851	Economy	27900.00
0005434726803	9851	Economy	27900.00
0005433129360	9851	Economy	27900.00
0005433235355	9851	Economy	27900.00
0005432199374	9851	Economy	27900.00
0005433235336	9851	Economy	27900.00
0005434726473	9851	Economy	27900.00
0005434735740	9851	Economy	27900.00
0005434726224	9851	Economy	27900.00
0005433129361	9851	Economy	27900.00
0005434726908	9851	Economy	27900.00
0005434727173	9851	Economy	27900.00
0005433113577	9851	Economy	27900.00
0005434726476	9851	Economy	27900.00
0005433181575	9851	Economy	27900.00
0005434726621	9851	Economy	27900.00
0005434302498	9851	Economy	27900.00
0005432199379	9851	Economy	27900.00
0005434551669	9851	Economy	27900.00
0005433235343	9851	Economy	27900.00
0005434726704	9851	Economy	27900.00
0005434551741	9851	Economy	27900.00
0005433235390	9851	Economy	27900.00
0005433181555	9851	Economy	27900.00
0005434726863	9851	Economy	27900.00
0005434032111	9851	Economy	27900.00
0005433235389	9851	Economy	27900.00
0005435142665	9851	Economy	27900.00
0005434726737	9851	Economy	27900.00
0005434726700	9851	Economy	27900.00
0005434731209	9851	Economy	27900.00
0005434726702	9851	Economy	27900.00
0005433235382	9851	Economy	27900.00
0005434551686	9851	Economy	27900.00
0005433181563	9851	Economy	27900.00
0005433235345	9851	Economy	27900.00
0005434726919	9851	Economy	27900.00
0005433181565	9851	Economy	27900.00
0005434551767	9851	Economy	27900.00
0005433181566	9851	Economy	27900.00
0005434551909	9851	Economy	27900.00
0005433181561	9851	Economy	27900.00
0005432530426	7761	Business	42100.00
0005432530452	7761	Business	42100.00
0005432530439	7761	Business	42100.00
0005432530422	7761	Business	42100.00
0005432530375	7761	Business	42100.00
0005434068858	7761	Business	42100.00
0005432530370	7761	Business	42100.00
0005434068905	7761	Business	42100.00
0005432069927	7761	Business	42100.00
0005432530336	7761	Business	42100.00
0005434068880	7761	Business	42100.00
0005435214209	7761	Business	42100.00
0005432428990	7761	Business	42100.00
0005434068852	7761	Business	42100.00
0005432530416	7761	Business	42100.00
0005432530368	7761	Business	42100.00
0005435214107	7761	Business	42100.00
0005434068901	7761	Business	42100.00
0005434068843	7761	Business	42100.00
0005432530402	7761	Business	42100.00
0005434068904	7761	Business	42100.00
0005432530329	7761	Comfort	23900.00
0005432530359	7761	Comfort	23900.00
0005434068898	7761	Comfort	23900.00
0005435214513	7761	Comfort	23900.00
0005432069930	7761	Comfort	23900.00
0005435214319	7761	Comfort	23900.00
0005432530393	7761	Comfort	23900.00
0005435214213	7761	Comfort	23900.00
0005433656689	7761	Comfort	23900.00
0005432530353	7761	Comfort	23900.00
0005432530379	7761	Comfort	23900.00
0005432530431	7761	Comfort	23900.00
0005434068840	7761	Comfort	23900.00
0005432069921	7761	Comfort	23900.00
0005432530428	7761	Comfort	23900.00
0005432530367	7761	Comfort	23900.00
0005432530415	7761	Comfort	23900.00
0005432530366	7761	Comfort	23900.00
0005432530456	7761	Comfort	23900.00
0005435214014	7761	Comfort	23900.00
0005434068873	7761	Comfort	23900.00
0005432069922	7761	Comfort	23900.00
0005432530340	7761	Comfort	23900.00
0005432069916	7761	Comfort	23900.00
0005432530339	7761	Comfort	23900.00
0005432530420	7761	Comfort	23900.00
0005432069919	7761	Comfort	23900.00
0005433656690	7761	Comfort	23900.00
0005434068870	7761	Comfort	23900.00
0005434068889	7761	Comfort	23900.00
0005432530412	7761	Comfort	23900.00
0005432530462	7761	Comfort	23900.00
0005432530354	7761	Comfort	23900.00
0005432530407	7761	Comfort	23900.00
0005432530429	7761	Economy	14000.00
0005434068887	7761	Economy	14000.00
0005432530386	7761	Economy	14000.00
0005435214292	7761	Economy	14000.00
0005432530387	7761	Economy	14000.00
0005432530421	7761	Economy	14000.00
0005435214226	7761	Economy	14000.00
0005433656697	7761	Economy	14000.00
0005434068897	7761	Economy	14000.00
0005432530350	7761	Economy	14000.00
0005435214051	7761	Economy	14000.00
0005435214269	7761	Economy	14000.00
0005434068894	7761	Economy	14000.00
0005432530343	7761	Economy	14000.00
0005435214141	7761	Economy	14000.00
0005434068841	7761	Economy	14000.00
0005432530365	7761	Economy	14000.00
0005432530451	7761	Economy	14000.00
0005435213858	7761	Economy	14000.00
0005432530392	7761	Economy	14000.00
0005434068876	7761	Economy	14000.00
0005432150341	7761	Economy	14000.00
0005432530345	7761	Economy	14000.00
0005434068846	7761	Economy	14000.00
0005434068845	7761	Economy	14000.00
0005433656687	7761	Economy	14000.00
0005434068861	7761	Economy	14000.00
0005432530443	7761	Economy	14000.00
0005432530363	7761	Economy	14000.00
0005434068908	7761	Economy	14000.00
0005432530384	7761	Economy	14000.00
0005434068902	7761	Economy	14000.00
0005434068842	7761	Economy	14000.00
0005432530445	7761	Economy	14000.00
0005432530358	7761	Economy	14000.00
0005435214373	7761	Economy	14000.00
0005432530430	7761	Economy	14000.00
0005435631006	7761	Economy	14000.00
0005432530377	7761	Economy	14000.00
0005432428994	7761	Economy	14000.00
0005432069917	7761	Economy	14000.00
0005432530333	7761	Economy	14000.00
0005434068906	7761	Economy	14000.00
0005432530341	7761	Economy	14000.00
0005434068862	7761	Economy	14000.00
0005432530432	7761	Economy	14000.00
0005434068881	7761	Economy	14000.00
0005435214171	7761	Economy	14000.00
0005432530352	7761	Economy	14000.00
0005434068907	7761	Economy	14000.00
0005432530391	7761	Economy	14000.00
0005432530441	7761	Economy	14000.00
0005432530442	7761	Economy	15400.00
0005435214298	7761	Economy	14000.00
0005432428993	7761	Economy	15400.00
0005434068886	7761	Economy	15400.00
0005432530453	7761	Economy	14000.00
0005432530374	7761	Economy	15400.00
0005432530438	7761	Economy	14000.00
0005432530383	7761	Economy	15400.00
0005432535921	7761	Economy	15400.00
0005432530364	7761	Economy	14000.00
0005435725665	7761	Economy	14000.00
0005434068891	7761	Economy	14000.00
0005432530335	7761	Economy	14000.00
0005432530351	7761	Economy	14000.00
0005432533345	7761	Economy	14000.00
0005432530378	7761	Economy	14000.00
0005434068872	7761	Economy	14000.00
0005434068859	7761	Economy	14000.00
0005432530447	7761	Economy	14000.00
0005432530338	7761	Economy	14000.00
0005432428991	7761	Economy	14000.00
0005435214227	7761	Economy	14000.00
0005435214299	7761	Economy	14000.00
0005432530444	7761	Economy	14000.00
0005435214370	7761	Economy	14000.00
0005432530455	7761	Economy	14000.00
0005434068850	7761	Economy	14000.00
0005432530372	7761	Economy	14000.00
0005432530440	7761	Economy	14000.00
0005432530396	7761	Economy	14000.00
0005432530406	7761	Economy	14000.00
0005432530418	7761	Economy	14000.00
0005432530427	7761	Economy	14000.00
0005434068909	7761	Economy	14000.00
0005432535924	7761	Economy	14000.00
0005435631008	7761	Economy	14000.00
0005432530349	7761	Economy	14000.00
0005432069923	7761	Economy	14000.00
0005432530398	7761	Economy	14000.00
0005435214293	7761	Economy	14000.00
0005432530425	7761	Economy	14000.00
0005435213956	7761	Economy	14000.00
0005435630999	7761	Economy	14000.00
0005434068864	7761	Economy	14000.00
0005432428992	7761	Economy	14000.00
0005435214318	7761	Economy	14000.00
0005432069926	7761	Economy	14000.00
0005432530413	7761	Economy	14000.00
0005432530404	7761	Economy	14000.00
0005432530423	7761	Economy	14000.00
0005432530399	7761	Economy	14000.00
0005432530330	7761	Economy	14000.00
0005435214201	7761	Economy	14000.00
0005432150336	7761	Economy	14000.00
0005432530390	7761	Economy	14000.00
0005433656698	7761	Economy	14000.00
0005434068838	7761	Economy	14000.00
0005432150338	7761	Economy	14000.00
0005435214029	7761	Economy	14000.00
0005435213929	7761	Economy	14000.00
0005434068884	7761	Economy	14000.00
0005434068878	7761	Economy	14000.00
0005432530461	7761	Economy	14000.00
0005432069918	7761	Economy	14000.00
0005432150337	7761	Economy	14000.00
0005434068869	7761	Economy	14000.00
0005432530395	7761	Economy	14000.00
0005434068868	7761	Economy	14000.00
0005432530346	7761	Economy	14000.00
0005435214224	7761	Economy	14000.00
0005432530414	7761	Economy	14000.00
0005432530362	7761	Economy	14000.00
0005432530410	7761	Economy	14000.00
0005434068857	7761	Economy	14000.00
0005432530434	7761	Economy	14000.00
0005432530369	7761	Economy	14000.00
0005434068866	7761	Economy	14000.00
0005432150340	7761	Economy	14000.00
0005432530459	7761	Economy	14000.00
0005434068877	7761	Economy	14000.00
0005432530435	7761	Economy	14000.00
0005435214212	7761	Economy	14000.00
0005432069928	7761	Economy	14000.00
0005435214307	7761	Economy	14000.00
0005432150342	7761	Economy	14000.00
0005432530417	7761	Economy	14000.00
0005432530436	7761	Economy	14000.00
0005432530449	7761	Economy	14000.00
0005435213859	7761	Economy	14000.00
0005432535923	7761	Economy	14000.00
0005432530380	7761	Economy	14000.00
0005434068892	7761	Economy	14000.00
0005435213993	7761	Economy	14000.00
0005432530348	7761	Economy	14000.00
0005432533343	7761	Economy	14000.00
0005435214366	7761	Economy	14000.00
0005432530397	7761	Economy	14000.00
0005435214312	7761	Economy	14000.00
0005432530385	7761	Economy	14000.00
0005435725636	7761	Economy	14000.00
0005435214188	7761	Economy	14000.00
0005432530373	7761	Economy	14000.00
0005432530371	7761	Economy	14000.00
0005432069929	7761	Economy	14000.00
0005434068885	7761	Economy	14000.00
0005435214268	7761	Economy	15400.00
0005434068903	7761	Economy	15400.00
0005434068848	7761	Economy	15400.00
0005432530454	7761	Economy	14000.00
0005432530403	7761	Economy	15400.00
0005432069924	7761	Economy	14000.00
0005435214219	7761	Economy	14000.00
0005432533344	7761	Economy	14000.00
0005434068890	7761	Economy	14000.00
0005432530361	7761	Economy	14000.00
0005434068851	7761	Economy	14000.00
0005434068855	7761	Economy	14000.00
0005434068893	7761	Economy	14000.00
0005432530357	7761	Economy	14000.00
0005432530347	7761	Economy	14000.00
0005432530419	7761	Economy	14000.00
0005432530424	7761	Economy	14000.00
0005432535925	7761	Economy	14000.00
0005432530344	7761	Economy	14000.00
0005432530356	7761	Economy	14000.00
0005432150339	7761	Economy	14000.00
0005432530409	7761	Economy	14000.00
0005435214197	7761	Economy	14000.00
0005432530448	7761	Economy	14000.00
0005434068871	7761	Economy	14000.00
0005432530408	7761	Economy	14000.00
0005435214380	7761	Economy	14000.00
0005434068888	7761	Economy	14000.00
0005435213809	7761	Economy	14000.00
0005432530388	7761	Economy	14000.00
0005435214253	7761	Economy	14000.00
0005432530334	7761	Economy	14000.00
0005432530376	7761	Economy	14000.00
0005434068874	7761	Economy	14000.00
0005435214117	7761	Economy	14000.00
0005432069925	7761	Economy	14000.00
0005432530331	7761	Economy	14000.00
0005434068837	7761	Economy	14000.00
0005435630998	7761	Economy	14000.00
0005434068863	7761	Economy	14000.00
0005435214214	7761	Economy	14000.00
0005432530360	7761	Economy	14000.00
0005434068882	7761	Economy	14000.00
0005432530401	7761	Economy	14000.00
0005434068844	7761	Economy	14000.00
0005434068879	7761	Economy	14000.00
0005433656701	7761	Economy	14000.00
0005434068860	7761	Economy	14000.00
0005432530437	7761	Economy	14000.00
0005432530411	7761	Economy	14000.00
0005434068875	7761	Economy	14000.00
0005435631007	7761	Economy	14000.00
0005434068853	7761	Economy	14000.00
0005432530457	7761	Economy	14000.00
0005434068839	7761	Economy	14000.00
0005435214021	7761	Economy	14000.00
0005434068849	7761	Economy	14000.00
0005432150343	7761	Economy	14000.00
0005434068883	7761	Economy	14000.00
0005432530405	7761	Economy	14000.00
0005432530460	7761	Economy	14000.00
0005432537097	7761	Economy	14000.00
0005434068895	7761	Economy	14000.00
0005435214239	7761	Economy	14000.00
0005432530389	7761	Economy	14000.00
0005434068896	7761	Economy	14000.00
0005435214030	7761	Economy	14000.00
0005432530332	7761	Economy	14000.00
0005432530382	7761	Economy	14000.00
0005432530337	7761	Economy	14000.00
0005432530400	7761	Economy	14000.00
0005432530394	7761	Economy	14000.00
0005434068899	7761	Economy	14000.00
0005432530433	7761	Economy	14000.00
0005432530458	7761	Economy	14000.00
0005435214264	7761	Economy	14000.00
0005434068867	7761	Economy	14000.00
0005435214022	7761	Economy	14000.00
0005432530446	7761	Economy	14000.00
0005432069920	7761	Economy	14000.00
0005435214218	7761	Economy	14000.00
0005434068847	7761	Economy	14000.00
0005432530355	7761	Economy	14000.00
0005434068854	7761	Economy	14000.00
0005434068900	7761	Economy	14000.00
0005432530450	7761	Economy	14000.00
0005435214313	7761	Economy	14000.00
0005432535922	7761	Economy	14000.00
0005432530381	7761	Economy	14000.00
0005435213841	7761	Economy	14000.00
0005434068856	7761	Economy	14000.00
0005432530342	7761	Economy	14000.00
0005434068865	7761	Economy	14000.00
0005435615742	5342	Business	43100.00
0005435615740	5342	Business	43100.00
0005435615702	5342	Business	43100.00
0005435615653	5342	Business	43100.00
0005435097391	5342	Business	43100.00
0005435615700	5342	Business	43100.00
0005435615714	5342	Business	43100.00
0005434344859	5342	Business	43100.00
0005434245377	5342	Business	43100.00
0005435615732	5342	Business	43100.00
0005435615748	5342	Business	43100.00
0005434245133	5342	Business	43100.00
0005435615703	5342	Business	43100.00
0005435042878	5342	Business	43100.00
0005435425627	5342	Business	43100.00
0005435425331	5342	Business	43100.00
0005435615681	5342	Business	43100.00
0005435615737	5342	Business	43100.00
0005434344888	5342	Business	43100.00
0005434245173	5342	Business	43100.00
0005434245324	5342	Business	43100.00
0005435615682	5342	Comfort	24400.00
0005435615736	5342	Business	43100.00
0005435425354	5342	Comfort	24400.00
0005435425565	5342	Comfort	24400.00
0005435615692	5342	Comfort	24400.00
0005435302260	5342	Comfort	24400.00
0005435615698	5342	Comfort	24400.00
0005435097392	5342	Comfort	24400.00
0005435615762	5342	Comfort	24400.00
0005435615690	5342	Comfort	24400.00
0005435425216	5342	Comfort	24400.00
0005435425656	5342	Comfort	24400.00
0005434344882	5342	Comfort	24400.00
0005435615718	5342	Comfort	24400.00
0005435615661	5342	Comfort	24400.00
0005434245382	5342	Comfort	24400.00
0005435425567	5342	Comfort	24400.00
0005434245259	5342	Comfort	24400.00
0005434344889	5342	Comfort	24400.00
0005435615709	5342	Comfort	24400.00
0005434344860	5342	Comfort	24400.00
0005435425868	5342	Comfort	24400.00
0005435615701	5342	Comfort	24400.00
0005435425657	5342	Comfort	24400.00
0005434245323	5342	Comfort	24400.00
0005435302252	5342	Comfort	24400.00
0005435615716	5342	Comfort	24400.00
0005435615717	5342	Comfort	24400.00
0005435425614	5342	Comfort	24400.00
0005434245204	5342	Comfort	24400.00
0005435615664	5342	Comfort	24400.00
0005435615660	5342	Comfort	24400.00
0005434245227	5342	Comfort	24400.00
0005435615763	5342	Comfort	24400.00
0005435425432	5342	Comfort	24400.00
0005435425423	5342	Comfort	24400.00
0005434245275	5342	Comfort	24400.00
0005434344887	5342	Comfort	24400.00
0005435305026	5342	Comfort	24400.00
0005435615704	5342	Comfort	24400.00
0005435615729	5342	Comfort	24400.00
0005435615658	5342	Comfort	24400.00
0005434573612	5342	Comfort	24400.00
0005435425458	5342	Comfort	24400.00
0005435615687	5342	Economy	14400.00
0005432133487	5342	Economy	14400.00
0005434344874	5342	Economy	14400.00
0005434344865	5342	Economy	14400.00
0005435425503	5342	Economy	14400.00
0005434344872	5342	Economy	14400.00
0005435425344	5342	Economy	14400.00
0005432133493	5342	Economy	14400.00
0005435615672	5342	Economy	14400.00
0005435425543	5342	Economy	14400.00
0005434245184	5342	Economy	14400.00
0005435425406	5342	Economy	14400.00
0005435555407	5342	Economy	14400.00
0005435425626	5342	Economy	14400.00
0005435615667	5342	Economy	14400.00
0005434245335	5342	Economy	14400.00
0005435615708	5342	Economy	14400.00
0005434344863	5342	Economy	14400.00
0005434344884	5342	Economy	14400.00
0005432133491	5342	Economy	14400.00
0005435615719	5342	Economy	14400.00
0005435615744	5342	Economy	14400.00
0005435425579	5342	Economy	14400.00
0005435425804	5342	Economy	14400.00
0005435615668	5342	Economy	14400.00
0005434344868	5342	Economy	14400.00
0005432133484	5342	Economy	14400.00
0005435425568	5342	Economy	14400.00
0005435097393	5342	Economy	14400.00
0005435615680	5342	Economy	14400.00
0005435490296	5342	Economy	14400.00
0005432841038	5342	Economy	14400.00
0005435425373	5342	Economy	14400.00
0005434245331	5342	Economy	14400.00
0005434344892	5342	Economy	14400.00
0005435425678	5342	Economy	14400.00
0005435042884	5342	Economy	14400.00
0005434344877	5342	Economy	14400.00
0005435615685	5342	Economy	14400.00
0005435615678	5342	Economy	14400.00
0005435615666	5342	Economy	14400.00
0005435425433	5342	Economy	14400.00
0005435615741	5342	Economy	14400.00
0005435615764	5342	Economy	14400.00
0005435615760	5342	Economy	14400.00
0005435425594	5342	Economy	14400.00
0005435491479	5342	Economy	14400.00
0005435425557	5342	Economy	14400.00
0005435615689	5342	Economy	14400.00
0005434656572	5342	Economy	14400.00
0005435425705	5342	Economy	14400.00
0005435615686	5342	Economy	14400.00
0005432133488	5342	Economy	14400.00
0005435615688	5342	Economy	14400.00
0005435615677	5342	Economy	14400.00
0005435615745	5342	Economy	14400.00
0005435615705	5342	Economy	14400.00
0005435615707	5342	Economy	14400.00
0005435425368	5342	Economy	14400.00
0005434344876	5342	Economy	14400.00
0005435615670	5342	Economy	14400.00
0005435615752	5342	Economy	14400.00
0005434245383	5342	Economy	14400.00
0005434344869	5342	Economy	14400.00
0005435425805	5342	Economy	15800.00
0005434245226	5342	Economy	14400.00
0005435615738	5342	Economy	15800.00
0005434245257	5342	Economy	14400.00
0005434344862	5342	Economy	14400.00
0005434573609	5342	Economy	15800.00
0005435615723	5342	Economy	14400.00
0005435615711	5342	Economy	14400.00
0005435425602	5342	Economy	14400.00
0005435425507	5342	Economy	14400.00
0005435615697	5342	Economy	14400.00
0005432133494	5342	Economy	14400.00
0005432133497	5342	Economy	14400.00
0005435425358	5342	Economy	14400.00
0005435097388	5342	Economy	14400.00
0005435425741	5342	Economy	14400.00
0005435425217	5342	Economy	14400.00
0005435615747	5342	Economy	14400.00
0005435319689	5342	Economy	14400.00
0005435425711	5342	Economy	14400.00
0005435615665	5342	Economy	14400.00
0005435615726	5342	Economy	14400.00
0005434573615	5342	Economy	14400.00
0005435615761	5342	Economy	14400.00
0005435615727	5342	Economy	14400.00
0005435615662	5342	Economy	14400.00
0005435615751	5342	Economy	14400.00
0005435615713	5342	Economy	14400.00
0005432363444	5342	Economy	14400.00
0005435490293	5342	Economy	14400.00
0005435425137	5342	Economy	14400.00
0005434344881	5342	Economy	14400.00
0005432841037	5342	Economy	14400.00
0005435425693	5342	Economy	14400.00
0005434573619	5342	Economy	14400.00
0005434344867	5342	Economy	14400.00
0005435425580	5342	Economy	14400.00
0005434245304	5342	Economy	14400.00
0005435425677	5342	Economy	14400.00
0005433719162	5342	Economy	14400.00
0005435615710	5342	Economy	14400.00
0005435425636	5342	Economy	14400.00
0005434573614	5342	Economy	14400.00
0005435425867	5342	Economy	14400.00
0005435615696	5342	Economy	14400.00
0005435425692	5342	Economy	14400.00
0005434245261	5342	Economy	14400.00
0005435425480	5342	Economy	14400.00
0005434245260	5342	Economy	14400.00
0005434344879	5342	Economy	14400.00
0005432133489	5342	Economy	14400.00
0005435615652	5342	Economy	14400.00
0005434245134	5342	Economy	14400.00
0005435319672	5342	Economy	14400.00
0005435615730	5342	Economy	14400.00
0005435615728	5342	Economy	14400.00
0005435425719	5342	Economy	14400.00
0005435425479	5342	Economy	14400.00
0005435425417	5342	Economy	14400.00
0005435425604	5342	Economy	14400.00
0005435319684	5342	Economy	14400.00
0005435615673	5342	Economy	14400.00
0005435319690	5342	Economy	14400.00
0005435380318	5342	Economy	14400.00
0005435425498	5342	Economy	14400.00
0005435490294	5342	Economy	14400.00
0005434245210	5342	Economy	14400.00
0005435615754	5342	Economy	14400.00
0005435425478	5342	Economy	14400.00
0005434344883	5342	Economy	14400.00
0005435425724	5342	Economy	14400.00
0005434245225	5342	Economy	14400.00
0005434344855	5342	Economy	14400.00
0005435615669	5342	Economy	14400.00
0005435615734	5342	Economy	14400.00
0005435425679	5342	Economy	14400.00
0005435615758	5342	Economy	14400.00
0005435491478	5342	Economy	14400.00
0005432133486	5342	Economy	14400.00
0005435097394	5342	Economy	14400.00
0005434344890	5342	Economy	14400.00
0005435425710	5342	Economy	14400.00
0005435302240	5342	Economy	14400.00
0005435615715	5342	Economy	14400.00
0005435615735	5342	Economy	14400.00
0005435615654	5342	Economy	14400.00
0005434245332	5342	Economy	14400.00
0005434573620	5342	Economy	14400.00
0005435302250	5342	Economy	14400.00
0005434344871	5342	Economy	14400.00
0005435426012	5342	Economy	14400.00
0005435319685	5342	Economy	14400.00
0005434573613	5342	Economy	14400.00
0005435615655	5342	Economy	14400.00
0005435380342	5342	Economy	14400.00
0005434573611	5342	Economy	14400.00
0005435425138	5342	Economy	14400.00
0005435615753	5342	Economy	14400.00
0005434245211	5342	Economy	14400.00
0005435425357	5342	Economy	14400.00
0005435615746	5342	Economy	14400.00
0005435097390	5342	Economy	14400.00
0005435425318	5342	Economy	14400.00
0005434573621	5342	Economy	14400.00
0005435615720	5342	Economy	14400.00
0005434344858	5342	Economy	14400.00
0005435615691	5342	Economy	14400.00
0005434344864	5342	Economy	15800.00
0005434344866	5342	Economy	15800.00
0005434344857	5342	Economy	15800.00
0005435615675	5342	Economy	15800.00
0005435319628	5342	Economy	15800.00
0005435615674	5342	Economy	14400.00
0005434573616	5342	Economy	14400.00
0005432133490	5342	Economy	14400.00
0005434344880	5342	Economy	14400.00
0005434245171	5342	Economy	14400.00
0005435319627	5342	Economy	14400.00
0005435425576	5342	Economy	14400.00
0005434245172	5342	Economy	14400.00
0005435425655	5342	Economy	14400.00
0005435425606	5342	Economy	14400.00
0005435615731	5342	Economy	14400.00
0005435615699	5342	Economy	14400.00
0005435615679	5342	Economy	14400.00
0005435490295	5342	Economy	14400.00
0005435615657	5342	Economy	14400.00
0005435425603	5342	Economy	14400.00
0005434344873	5342	Economy	14400.00
0005435615651	5342	Economy	14400.00
0005435615724	5342	Economy	14400.00
0005435615684	5342	Economy	14400.00
0005435425493	5342	Economy	14400.00
0005435555406	5342	Economy	14400.00
0005435615659	5342	Economy	14400.00
0005432133492	5342	Economy	14400.00
0005435615712	5342	Economy	14400.00
0005434344870	5342	Economy	14400.00
0005435319683	5342	Economy	14400.00
0005434344875	5342	Economy	14400.00
0005435615739	5342	Economy	14400.00
0005435425664	5342	Economy	14400.00
0005434245258	5342	Economy	14400.00
0005434344856	5342	Economy	14400.00
0005435425343	5342	Economy	14400.00
0005435615733	5342	Economy	14400.00
0005435615722	5342	Economy	14400.00
0005435615695	5342	Economy	14400.00
0005435615706	5342	Economy	14400.00
0005435425457	5342	Economy	14400.00
0005435425356	5342	Economy	14400.00
0005434573610	5342	Economy	14400.00
0005435615693	5342	Economy	14400.00
0005435097387	5342	Economy	14400.00
0005435425716	5342	Economy	14400.00
0005435615683	5342	Economy	14400.00
0005434344878	5342	Economy	14400.00
0005435319664	5342	Economy	14400.00
0005432047620	5342	Economy	14400.00
0005435319671	5342	Economy	14400.00
0005435615749	5342	Economy	14400.00
0005434573608	5342	Economy	14400.00
0005435425746	5342	Economy	14400.00
0005432047621	5342	Economy	14400.00
0005434344861	5342	Economy	14400.00
0005434344891	5342	Economy	14400.00
0005435097386	5342	Economy	14400.00
0005435425742	5342	Economy	14400.00
0005434573618	5342	Economy	14400.00
0005435615694	5342	Economy	14400.00
0005435425718	5342	Economy	14400.00
0005435425534	5342	Economy	14400.00
0005435425615	5342	Economy	14400.00
0005435302251	5342	Economy	14400.00
0005435425278	5342	Economy	14400.00
0005434245339	5342	Economy	14400.00
0005435425369	5342	Economy	14400.00
0005432047622	5342	Economy	14400.00
0005435425515	5342	Economy	14400.00
0005432133485	5342	Economy	14400.00
0005435615755	5342	Economy	14400.00
0005435425581	5342	Economy	14400.00
0005435615721	5342	Economy	14400.00
0005435615757	5342	Economy	14400.00
0005434245328	5342	Economy	14400.00
0005434245356	5342	Economy	14400.00
0005435615756	5342	Economy	14400.00
0005435615725	5342	Economy	14400.00
0005435615676	5342	Economy	14400.00
0005434573617	5342	Economy	14400.00
0005432133496	5342	Economy	14400.00
0005435615743	5342	Economy	14400.00
0005435615656	5342	Economy	14400.00
0005435097389	5342	Economy	14400.00
0005435425355	5342	Economy	14400.00
0005434245369	5342	Economy	14400.00
0005435425858	5342	Economy	14400.00
0005435615663	5342	Economy	14400.00
0005434344886	5342	Economy	14400.00
0005434245262	5342	Economy	14400.00
0005434344885	5342	Economy	14400.00
0005432133495	5342	Economy	14400.00
0005435302239	5342	Economy	14400.00
0005435615759	5342	Economy	14400.00
0005435615750	5342	Economy	14400.00
0005435615671	5342	Economy	14400.00
0005435425665	5342	Economy	14400.00
0005435425578	5342	Economy	14400.00
0005435425566	5342	Economy	14400.00
0005435614907	10923	Business	43100.00
0005435426055	10923	Business	43100.00
0005435614186	10923	Business	43100.00
0005435426105	10923	Business	43100.00
0005435614993	10923	Business	43100.00
0005434245526	10923	Business	43100.00
0005435613986	10923	Business	43100.00
0005435319739	10923	Business	43100.00
0005435304236	10923	Business	43100.00
0005435614849	10923	Business	43100.00
0005435097237	10923	Business	43100.00
0005435426064	10923	Business	43100.00
0005434245514	10923	Business	43100.00
0005435614628	10923	Business	43100.00
0005435426045	10923	Business	43100.00
0005435614804	10923	Business	43100.00
0005435426109	10923	Business	43100.00
0005432165177	10923	Business	43100.00
0005434344564	10923	Business	43100.00
0005435426046	10923	Business	43100.00
0005435491460	10923	Business	43100.00
0005435614936	10923	Business	43100.00
0005435614642	10923	Comfort	24400.00
0005435426080	10923	Comfort	24400.00
0005434573490	10923	Comfort	24400.00
0005435426062	10923	Comfort	24400.00
0005435614636	10923	Comfort	24400.00
0005435426058	10923	Comfort	24400.00
0005435426071	10923	Comfort	24400.00
0005434245523	10923	Comfort	24400.00
0005435490282	10923	Comfort	24400.00
0005435614304	10923	Comfort	24400.00
0005435426068	10923	Comfort	24400.00
0005435614998	10923	Comfort	24400.00
0005435614710	10923	Comfort	24400.00
0005434245524	10923	Comfort	24400.00
0005433719204	10923	Comfort	24400.00
0005435426094	10923	Comfort	24400.00
0005434344484	10923	Comfort	24400.00
0005434573491	10923	Comfort	24400.00
0005434344483	10923	Comfort	24400.00
0005434573441	10923	Comfort	24400.00
0005435613985	10923	Comfort	24400.00
0005432165181	10923	Comfort	24400.00
0005435426052	10923	Comfort	24400.00
0005435614858	10923	Comfort	24400.00
0005435614675	10923	Comfort	24400.00
0005435614587	10923	Comfort	24400.00
0005435614848	10923	Comfort	24400.00
0005435380385	10923	Comfort	24400.00
0005434344591	10923	Comfort	24400.00
0005435426076	10923	Comfort	24400.00
0005435380383	10923	Comfort	24400.00
0005435426103	10923	Comfort	24400.00
0005435614908	10923	Comfort	24400.00
0005432165182	10923	Comfort	24400.00
0005434245527	10923	Comfort	24400.00
0005435614371	10923	Economy	14400.00
0005435615047	10923	Comfort	24400.00
0005435319733	10923	Economy	14400.00
0005434344555	10923	Economy	14400.00
0005435614563	10923	Economy	14400.00
0005434245518	10923	Economy	14400.00
0005434573427	10923	Economy	14400.00
0005435614758	10923	Economy	14400.00
0005435305048	10923	Economy	14400.00
0005435614999	10923	Economy	14400.00
0005435614985	10923	Economy	14400.00
0005435426100	10923	Economy	14400.00
0005435426051	10923	Economy	14400.00
0005434344477	10923	Economy	14400.00
0005435426074	10923	Economy	14400.00
0005435426095	10923	Economy	14400.00
0005435614568	10923	Economy	14400.00
0005435614721	10923	Economy	14400.00
0005435615026	10923	Economy	14400.00
0005435380384	10923	Economy	14400.00
0005435614736	10923	Economy	14400.00
0005435614940	10923	Economy	14400.00
0005435426107	10923	Economy	14400.00
0005435097286	10923	Economy	14400.00
0005435614995	10923	Economy	14400.00
0005434344557	10923	Economy	14400.00
0005435614989	10923	Economy	14400.00
0005435614803	10923	Economy	14400.00
0005435614440	10923	Economy	14400.00
0005435614988	10923	Economy	14400.00
0005435042893	10923	Economy	14400.00
0005432841052	10923	Economy	14400.00
0005435097300	10923	Economy	14400.00
0005434245534	10923	Economy	14400.00
0005434344615	10923	Economy	14400.00
0005434344556	10923	Economy	14400.00
0005435614891	10923	Economy	14400.00
0005435426060	10923	Economy	14400.00
0005434344396	10923	Economy	14400.00
0005432166962	10923	Economy	14400.00
0005435614386	10923	Economy	14400.00
0005435614843	10923	Economy	14400.00
0005434245508	10923	Economy	14400.00
0005435614789	10923	Economy	14400.00
0005434573464	10923	Economy	14400.00
0005434344444	10923	Economy	14400.00
0005434344590	10923	Economy	14400.00
0005434245509	10923	Economy	14400.00
0005434344536	10923	Economy	14400.00
0005433719205	10923	Economy	14400.00
0005432841053	10923	Economy	14400.00
0005435426101	10923	Economy	14400.00
0005435426067	10923	Economy	14400.00
0005434573426	10923	Economy	14400.00
0005435426087	10923	Economy	14400.00
0005435319740	10923	Economy	14400.00
0005434573514	10923	Economy	14400.00
0005435614722	10923	Economy	14400.00
0005435426054	10923	Economy	14400.00
0005435614659	10923	Economy	14400.00
0005434344351	10923	Economy	14400.00
0005435097267	10923	Economy	15800.00
0005435097240	10923	Economy	15800.00
0005435614066	10923	Economy	14400.00
0005435614930	10923	Economy	15800.00
0005435614479	10923	Economy	15800.00
0005435614974	10923	Economy	14400.00
0005434245535	10923	Economy	15800.00
0005434344595	10923	Economy	14400.00
0005434344532	10923	Economy	14400.00
0005435614539	10923	Economy	14400.00
0005434344534	10923	Economy	14400.00
0005432363477	10923	Economy	14400.00
0005434344429	10923	Economy	14400.00
0005435380381	10923	Economy	14400.00
0005435426098	10923	Economy	14400.00
0005434245515	10923	Economy	14400.00
0005434245512	10923	Economy	14400.00
0005435097274	10923	Economy	14400.00
0005434344473	10923	Economy	14400.00
0005434344476	10923	Economy	14400.00
0005435615161	10923	Economy	14400.00
0005435304232	10923	Economy	14400.00
0005435319734	10923	Economy	14400.00
0005433719203	10923	Economy	14400.00
0005435426081	10923	Economy	14400.00
0005434245533	10923	Economy	14400.00
0005435614625	10923	Economy	14400.00
0005435426102	10923	Economy	14400.00
0005435614680	10923	Economy	14400.00
0005435614996	10923	Economy	14400.00
0005435614932	10923	Economy	14400.00
0005434245522	10923	Economy	14400.00
0005435614662	10923	Economy	14400.00
0005434344545	10923	Economy	14400.00
0005434344509	10923	Economy	14400.00
0005435380382	10923	Economy	14400.00
0005434344443	10923	Economy	14400.00
0005435614500	10923	Economy	14400.00
0005435615214	10923	Economy	14400.00
0005434344565	10923	Economy	14400.00
0005434573417	10923	Economy	14400.00
0005434344554	10923	Economy	14400.00
0005435614806	10923	Economy	14400.00
0005435614687	10923	Economy	14400.00
0005435319732	10923	Economy	14400.00
0005435426053	10923	Economy	14400.00
0005434245510	10923	Economy	14400.00
0005435614837	10923	Economy	14400.00
0005435614705	10923	Economy	14400.00
0005434245530	10923	Economy	14400.00
0005435614746	10923	Economy	14400.00
0005435426065	10923	Economy	14400.00
0005435426072	10923	Economy	14400.00
0005435615133	10923	Economy	14400.00
0005434344353	10923	Economy	14400.00
0005432165178	10923	Economy	14400.00
0005435426061	10923	Economy	14400.00
0005435614676	10923	Economy	14400.00
0005435614679	10923	Economy	14400.00
0005435426110	10923	Economy	14400.00
0005435426097	10923	Economy	14400.00
0005435614667	10923	Economy	14400.00
0005435614666	10923	Economy	14400.00
0005435426073	10923	Economy	14400.00
0005435097332	10923	Economy	14400.00
0005435615028	10923	Economy	14400.00
0005432165179	10923	Economy	14400.00
0005435426108	10923	Economy	14400.00
0005432165175	10923	Economy	14400.00
0005435614986	10923	Economy	14400.00
0005435319738	10923	Economy	14400.00
0005432165176	10923	Economy	14400.00
0005435614850	10923	Economy	14400.00
0005432166961	10923	Economy	14400.00
0005434344570	10923	Economy	14400.00
0005435614931	10923	Economy	14400.00
0005434245531	10923	Economy	14400.00
0005434344482	10923	Economy	14400.00
0005434245513	10923	Economy	14400.00
0005435490258	10923	Economy	14400.00
0005435426066	10923	Economy	14400.00
0005435426111	10923	Economy	14400.00
0005435426059	10923	Economy	14400.00
0005435426096	10923	Economy	14400.00
0005434573442	10923	Economy	14400.00
0005435426079	10923	Economy	14400.00
0005432166960	10923	Economy	14400.00
0005435615046	10923	Economy	14400.00
0005434245528	10923	Economy	14400.00
0005435319735	10923	Economy	14400.00
0005434344504	10923	Economy	14400.00
0005435097333	10923	Economy	14400.00
0005435426082	10923	Economy	14400.00
0005435614838	10923	Economy	14400.00
0005435490265	10923	Economy	14400.00
0005435380380	10923	Economy	14400.00
0005435614816	10923	Economy	14400.00
0005435614935	10923	Economy	14400.00
0005434573418	10923	Economy	14400.00
0005435426089	10923	Economy	14400.00
0005435426112	10923	Economy	14400.00
0005435614461	10923	Economy	14400.00
0005435426075	10923	Economy	14400.00
0005435426056	10923	Economy	14400.00
0005435615101	10923	Economy	14400.00
0005432363476	10923	Economy	14400.00
0005435319736	10923	Economy	14400.00
0005435491461	10923	Economy	14400.00
0005435615014	10923	Economy	15800.00
0005432165180	10923	Economy	15800.00
0005434245521	10923	Economy	15800.00
0005435615311	10923	Economy	15800.00
0005435426104	10923	Economy	15800.00
0005434245529	10923	Economy	15800.00
0005435042894	10923	Economy	14400.00
0005435614674	10923	Economy	14400.00
0005434344465	10923	Economy	14400.00
0005434656593	10923	Economy	14400.00
0005435426049	10923	Economy	14400.00
0005435615053	10923	Economy	14400.00
0005435615152	10923	Economy	14400.00
0005435614724	10923	Economy	14400.00
0005434245519	10923	Economy	14400.00
0005435614067	10923	Economy	14400.00
0005434344549	10923	Economy	14400.00
0005434245517	10923	Economy	14400.00
0005435614657	10923	Economy	14400.00
0005435614867	10923	Economy	14400.00
0005435614973	10923	Economy	14400.00
0005435614488	10923	Economy	14400.00
0005435614473	10923	Economy	14400.00
0005435615054	10923	Economy	14400.00
0005435426083	10923	Economy	14400.00
0005434573452	10923	Economy	14400.00
0005434344385	10923	Economy	14400.00
0005435614809	10923	Economy	14400.00
0005435614305	10923	Economy	14400.00
0005435426086	10923	Economy	14400.00
0005435614764	10923	Economy	14400.00
0005435304234	10923	Economy	14400.00
0005435614343	10923	Economy	14400.00
0005435614472	10923	Economy	14400.00
0005435614745	10923	Economy	14400.00
0005434344439	10923	Economy	14400.00
0005435426047	10923	Economy	14400.00
0005434344474	10923	Economy	14400.00
0005434245516	10923	Economy	14400.00
0005435426057	10923	Economy	14400.00
0005435426088	10923	Economy	14400.00
0005435426077	10923	Economy	14400.00
0005435614538	10923	Economy	14400.00
0005435426091	10923	Economy	14400.00
0005435614990	10923	Economy	14400.00
0005435614698	10923	Economy	14400.00
0005435614976	10923	Economy	14400.00
0005435614727	10923	Economy	14400.00
0005435426070	10923	Economy	14400.00
0005434245511	10923	Economy	14400.00
0005435426093	10923	Economy	14400.00
0005435097269	10923	Economy	14400.00
0005435614502	10923	Economy	14400.00
0005435614842	10923	Economy	14400.00
0005435614579	10923	Economy	14400.00
0005432841051	10923	Economy	14400.00
0005435426099	10923	Economy	14400.00
0005434245520	10923	Economy	14400.00
0005435426085	10923	Economy	14400.00
0005435426106	10923	Economy	14400.00
0005435614482	10923	Economy	14400.00
0005435319737	10923	Economy	14400.00
0005435490254	10923	Economy	14400.00
0005435614788	10923	Economy	14400.00
0005435614567	10923	Economy	14400.00
0005434245525	10923	Economy	14400.00
0005435426078	10923	Economy	14400.00
0005434344535	10923	Economy	14400.00
0005435614501	10923	Economy	14400.00
0005434245532	10923	Economy	14400.00
0005434344553	10923	Economy	14400.00
0005435614991	10923	Economy	14400.00
0005435615068	10923	Economy	14400.00
0005435614499	10923	Economy	14400.00
0005435614560	10923	Economy	14400.00
0005435304235	10923	Economy	14400.00
0005435042892	10923	Economy	14400.00
0005435426069	10923	Economy	14400.00
0005435614839	10923	Economy	14400.00
0005435614950	10923	Economy	14400.00
0005435615180	10923	Economy	14400.00
0005434344531	10923	Economy	14400.00
0005435304233	10923	Economy	14400.00
0005435426048	10923	Economy	14400.00
0005434344540	10923	Economy	14400.00
0005434344350	10923	Economy	14400.00
0005434344464	10923	Economy	14400.00
0005434245537	10923	Economy	14400.00
0005435615134	10923	Economy	14400.00
0005435614578	10923	Economy	14400.00
0005434573500	10923	Economy	14400.00
0005434656592	10923	Economy	14400.00
0005434245536	10923	Economy	14400.00
0005435426090	10923	Economy	14400.00
0005435614830	10923	Economy	14400.00
0005435614529	10923	Economy	14400.00
0005435426092	10923	Economy	14400.00
0005435614626	10923	Economy	14400.00
0005435614487	10923	Economy	14400.00
0005434573436	10923	Economy	14400.00
0005435426063	10923	Economy	14400.00
0005435426084	10923	Economy	14400.00
0005435426050	10923	Economy	14400.00
0005435614810	10923	Economy	14400.00
0005432460425	3387	Business	18800.00
0005432182125	3387	Business	18800.00
0005432460197	3387	Business	18800.00
0005433634444	3387	Business	18800.00
0005433507509	3387	Business	18800.00
0005433634458	3387	Business	18800.00
0005433634445	3387	Business	18800.00
0005433634440	3387	Business	18800.00
0005433507496	3387	Business	18800.00
0005433806027	3387	Business	18800.00
0005433634438	3387	Business	18800.00
0005432182137	3387	Business	18800.00
0005432182130	3387	Business	18800.00
0005432182138	3387	Business	18800.00
0005433507508	3387	Business	18800.00
0005433806003	3387	Business	18800.00
0005433806007	3387	Business	18800.00
0005433806000	3387	Business	18800.00
0005433634439	3387	Business	18800.00
0005432182124	3387	Business	18800.00
0005432460401	3387	Business	18800.00
0005432460199	3387	Business	18800.00
0005433806023	3387	Business	18800.00
0005433634437	3387	Business	18800.00
0005432182136	3387	Business	18800.00
0005433634466	3387	Business	18800.00
0005433507500	3387	Business	18800.00
0005432460355	3387	Business	18800.00
0005432460509	3387	Economy	6900.00
0005432460367	3387	Economy	6900.00
0005433806020	3387	Economy	6900.00
0005432460497	3387	Economy	6900.00
0005433507503	3387	Economy	6900.00
0005432182126	3387	Economy	6900.00
0005432460143	3387	Economy	6300.00
0005433806004	3387	Economy	6300.00
0005432460211	3387	Economy	6300.00
0005432460205	3387	Economy	6300.00
0005433634465	3387	Economy	6300.00
0005433806013	3387	Economy	6300.00
0005433806036	3387	Economy	6300.00
0005432460187	3387	Economy	6300.00
0005433634453	3387	Economy	6300.00
0005433507512	3387	Economy	6300.00
0005433507511	3387	Economy	6300.00
0005433806008	3387	Economy	6300.00
0005432460200	3387	Economy	6300.00
0005433806012	3387	Economy	6300.00
0005432460202	3387	Economy	6300.00
0005433806030	3387	Economy	6300.00
0005432460189	3387	Economy	6300.00
0005432182118	3387	Economy	6300.00
0005433806018	3387	Economy	6300.00
0005433634462	3387	Economy	6300.00
0005433806032	3387	Economy	6300.00
0005433806026	3387	Economy	6300.00
0005433806010	3387	Economy	6300.00
0005432460188	3387	Economy	6300.00
0005433806015	3387	Economy	6300.00
0005432182120	3387	Economy	6300.00
0005432460457	3387	Economy	6300.00
0005433806011	3387	Economy	6300.00
0005433507498	3387	Economy	6300.00
0005432182131	3387	Economy	6300.00
0005433507493	3387	Economy	6300.00
0005432182128	3387	Economy	6300.00
0005433806016	3387	Economy	6300.00
0005433634454	3387	Economy	6300.00
0005432460262	3387	Economy	6300.00
0005432460182	3387	Economy	6300.00
0005432460574	3387	Economy	6300.00
0005432182117	3387	Economy	6300.00
0005433634468	3387	Economy	6300.00
0005433806021	3387	Economy	6300.00
0005432460424	3387	Economy	6300.00
0005433805999	3387	Economy	6300.00
0005432460258	3387	Economy	6300.00
0005432460291	3387	Economy	6300.00
0005433806033	3387	Economy	6300.00
0005432460194	3387	Economy	6300.00
0005433634464	3387	Economy	6300.00
0005433806034	3387	Economy	6300.00
0005433806006	3387	Economy	6300.00
0005433806028	3387	Economy	6300.00
0005432182139	3387	Economy	6300.00
0005432460337	3387	Economy	6300.00
0005432460354	3387	Economy	6300.00
0005432460203	3387	Economy	6300.00
0005433634436	3387	Economy	6300.00
0005432182134	3387	Economy	6300.00
0005433806037	3387	Economy	6300.00
0005432182122	3387	Economy	6300.00
0005432460444	3387	Economy	6900.00
0005433806019	3387	Economy	6900.00
0005432182121	3387	Economy	6900.00
0005433806024	3387	Economy	6900.00
0005433806002	3387	Economy	6900.00
0005433634469	3387	Economy	6300.00
0005432460615	3387	Economy	6300.00
0005432460295	3387	Economy	6300.00
0005432460196	3387	Economy	6300.00
0005433507502	3387	Economy	6900.00
0005433507504	3387	Economy	6300.00
0005433634448	3387	Economy	6300.00
0005433634441	3387	Economy	6300.00
0005433634467	3387	Economy	6300.00
0005433806025	3387	Economy	6300.00
0005433806001	3387	Economy	6300.00
0005433806035	3387	Economy	6300.00
0005433634456	3387	Economy	6300.00
0005433634443	3387	Economy	6300.00
0005432460259	3387	Economy	6300.00
0005433806029	3387	Economy	6300.00
0005432460195	3387	Economy	6300.00
0005433634449	3387	Economy	6300.00
0005432460345	3387	Economy	6300.00
0005432460616	3387	Economy	6300.00
0005432460181	3387	Economy	6300.00
0005432460261	3387	Economy	6300.00
0005432460534	3387	Economy	6300.00
0005433634459	3387	Economy	6300.00
0005433507506	3387	Economy	6300.00
0005433507494	3387	Economy	6300.00
0005432182133	3387	Economy	6300.00
0005432460225	3387	Economy	6300.00
0005433806017	3387	Economy	6300.00
0005433806014	3387	Economy	6300.00
0005433806022	3387	Economy	6300.00
0005432460344	3387	Economy	6300.00
0005432460357	3387	Economy	6300.00
0005433634442	3387	Economy	6300.00
0005433634457	3387	Economy	6300.00
0005432460365	3387	Economy	6300.00
0005432460142	3387	Economy	6300.00
0005432460206	3387	Economy	6300.00
0005432182119	3387	Economy	6300.00
0005433634451	3387	Economy	6300.00
0005432182123	3387	Economy	6300.00
0005432460208	3387	Economy	6300.00
0005433634460	3387	Economy	6300.00
0005433806009	3387	Economy	6300.00
0005433507501	3387	Economy	6300.00
0005433507505	3387	Economy	6300.00
0005433507507	3387	Economy	6300.00
0005432460183	3387	Economy	6300.00
0005433806031	3387	Economy	6300.00
0005433805998	3387	Economy	6300.00
0005432460353	3387	Economy	6300.00
0005433634463	3387	Economy	6300.00
0005432182135	3387	Economy	6300.00
0005433507499	3387	Economy	6300.00
0005433634447	3387	Economy	6300.00
0005433507497	3387	Economy	6300.00
0005432182127	3387	Economy	6300.00
0005433634455	3387	Economy	6300.00
0005433634446	3387	Economy	6300.00
0005433634452	3387	Economy	6300.00
0005433507495	3387	Economy	6300.00
0005432460338	3387	Economy	6300.00
0005433507510	3387	Economy	6300.00
0005433634450	3387	Economy	6300.00
0005433634461	3387	Economy	6300.00
0005432182132	3387	Economy	6300.00
0005432460323	3387	Economy	6300.00
0005432182129	3387	Economy	6300.00
0005432460382	3387	Economy	6300.00
0005432460290	3387	Economy	6300.00
0005433806005	3387	Economy	6300.00
0005435885756	3388	Business	18800.00
0005435885895	3388	Business	18800.00
0005435885585	3388	Business	18800.00
0005435885370	3388	Business	18800.00
0005435885887	3388	Economy	6900.00
0005435885832	3388	Economy	6900.00
0005435885774	3388	Economy	6300.00
0005435885800	3388	Economy	6300.00
0005435885628	3388	Economy	6300.00
0005435885724	3388	Economy	6300.00
0005435885731	3388	Economy	6300.00
0005435885818	3388	Economy	6300.00
0005435885714	3388	Economy	6300.00
0005435885878	3388	Economy	6300.00
0005435885829	3388	Economy	6300.00
0005435885799	3388	Economy	6300.00
0005435885717	3388	Economy	6900.00
0005435885543	3388	Economy	6300.00
0005435885542	3388	Economy	6300.00
0005435885584	3388	Economy	6300.00
0005435885833	3388	Economy	6300.00
0005435885728	3388	Economy	6300.00
0005435885591	3388	Economy	6300.00
0005435885661	3388	Economy	6300.00
0005435885896	3388	Economy	6300.00
0005435885625	3388	Economy	6300.00
0005435885773	3388	Economy	6300.00
0005435885877	3388	Economy	6300.00
0005435885897	3388	Economy	6300.00
0005435885910	3388	Economy	6300.00
0005435885371	3388	Economy	6300.00
0005435885888	3388	Economy	6300.00
0005435885876	3388	Economy	6300.00
0005435885624	3388	Economy	6300.00
0005435885629	3388	Economy	6300.00
0005432460861	8277	Business	18800.00
0005433507387	8277	Business	18800.00
0005433507348	8277	Business	18800.00
0005435886152	8277	Business	18800.00
0005433507333	8277	Business	18800.00
0005432042967	8277	Business	18800.00
0005432460836	8277	Business	18800.00
0005432460848	8277	Business	18800.00
0005435886153	8277	Business	18800.00
0005435886163	8277	Business	18800.00
0005432460865	8277	Business	18800.00
0005433507356	8277	Business	18800.00
0005432460857	8277	Business	18800.00
0005435886129	8277	Business	18800.00
0005432460858	8277	Business	18800.00
0005432460862	8277	Business	18800.00
0005432460845	8277	Business	18800.00
0005432460834	8277	Business	18800.00
0005432460879	8277	Business	18800.00
0005435886138	8277	Business	18800.00
0005435886126	8277	Economy	6900.00
0005432042979	8277	Economy	6900.00
0005435886157	8277	Economy	6300.00
0005435886150	8277	Economy	6300.00
0005432042976	8277	Economy	6300.00
0005432460833	8277	Economy	6300.00
0005435886161	8277	Economy	6300.00
0005432460832	8277	Economy	6300.00
0005433507312	8277	Economy	6300.00
0005432042969	8277	Economy	6300.00
0005433507323	8277	Economy	6300.00
0005432460867	8277	Economy	6300.00
0005435886162	8277	Economy	6300.00
0005432460841	8277	Economy	6300.00
0005432460839	8277	Economy	6300.00
0005435886130	8277	Economy	6300.00
0005435886140	8277	Economy	6300.00
0005433507343	8277	Economy	6300.00
0005433507355	8277	Economy	6300.00
0005433507381	8277	Economy	6300.00
0005435886136	8277	Economy	6300.00
0005433507359	8277	Economy	6300.00
0005432042978	8277	Economy	6300.00
0005435886131	8277	Economy	6300.00
0005432460872	8277	Economy	6300.00
0005432460829	8277	Economy	6300.00
0005433507371	8277	Economy	6300.00
0005433507309	8277	Economy	6300.00
0005432460859	8277	Economy	6300.00
0005432042971	8277	Economy	6300.00
0005435886160	8277	Economy	6300.00
0005434326281	8277	Economy	6300.00
0005432460854	8277	Economy	6300.00
0005433507315	8277	Economy	6300.00
0005434326280	8277	Economy	6300.00
0005432460846	8277	Economy	6300.00
0005435886135	8277	Economy	6300.00
0005432042973	8277	Economy	6300.00
0005432460851	8277	Economy	6300.00
0005432460855	8277	Economy	6300.00
0005432460842	8277	Economy	6300.00
0005435886133	8277	Economy	6300.00
0005432460840	8277	Economy	6300.00
0005432460860	8277	Economy	6300.00
0005432460838	8277	Economy	6300.00
0005432460856	8277	Economy	6300.00
0005433507310	8277	Economy	6300.00
0005432042972	8277	Economy	6300.00
0005432460876	8277	Economy	6300.00
0005435886154	8277	Economy	6300.00
0005433507332	8277	Economy	6300.00
0005435886139	8277	Economy	6300.00
0005433507297	8277	Economy	6300.00
0005435886159	8277	Economy	6900.00
0005432460852	8277	Economy	6900.00
0005432460869	8277	Economy	6900.00
0005432460843	8277	Economy	6300.00
0005432460831	8277	Economy	6300.00
0005432460849	8277	Economy	6300.00
0005435886156	8277	Economy	6300.00
0005432460830	8277	Economy	6900.00
0005433507335	8277	Economy	6300.00
0005432460863	8277	Economy	6300.00
0005432460877	8277	Economy	6300.00
0005432460875	8277	Economy	6300.00
0005435886134	8277	Economy	6300.00
0005435886128	8277	Economy	6300.00
0005432460874	8277	Economy	6300.00
0005435886158	8277	Economy	6300.00
0005432460835	8277	Economy	6300.00
0005433507334	8277	Economy	6300.00
0005432042974	8277	Economy	6300.00
0005435886144	8277	Economy	6300.00
0005432042966	8277	Economy	6300.00
0005435886143	8277	Economy	6300.00
0005435886155	8277	Economy	6300.00
0005435886147	8277	Economy	6300.00
0005432460868	8277	Economy	6300.00
0005435886132	8277	Economy	6300.00
0005435886141	8277	Economy	6300.00
0005433507288	8277	Economy	6300.00
0005434312359	8277	Economy	6300.00
0005432460837	8277	Economy	6300.00
0005435886149	8277	Economy	6300.00
0005432460870	8277	Economy	6300.00
0005432460827	8277	Economy	6300.00
0005432460866	8277	Economy	6300.00
0005432042968	8277	Economy	6300.00
0005432460850	8277	Economy	6300.00
0005435886145	8277	Economy	6300.00
0005432460847	8277	Economy	6300.00
0005435886164	8277	Economy	6300.00
0005433507354	8277	Economy	6300.00
0005433507372	8277	Economy	6300.00
0005433507360	8277	Economy	6300.00
0005435886146	8277	Economy	6300.00
0005432460844	8277	Economy	6300.00
0005432460853	8277	Economy	6300.00
0005432042970	8277	Economy	6300.00
0005432460871	8277	Economy	6300.00
0005435886151	8277	Economy	6300.00
0005432460878	8277	Economy	6300.00
0005435886148	8277	Economy	6300.00
0005432460828	8277	Economy	6300.00
0005434312358	8277	Economy	6300.00
0005433507322	8277	Economy	6300.00
0005433507298	8277	Economy	6300.00
0005432042975	8277	Economy	6300.00
0005435886142	8277	Economy	6300.00
0005435886127	8277	Economy	6300.00
0005432042977	8277	Economy	6300.00
0005435886137	8277	Economy	6300.00
0005432460873	8277	Economy	6300.00
0005432460864	8277	Economy	6300.00
0005433805751	8290	Business	18800.00
0005433805714	8290	Business	18800.00
0005433805675	8290	Business	18800.00
0005433805897	8290	Business	18800.00
0005433805790	8290	Business	18800.00
0005433805789	8290	Business	18800.00
0005433634131	8290	Business	18800.00
0005433805748	8290	Business	18800.00
0005433634193	8290	Business	18800.00
0005433634100	8290	Business	18800.00
0005433805724	8290	Business	18800.00
0005433805725	8290	Business	18800.00
0005433805793	8290	Business	18800.00
0005433805821	8290	Business	18800.00
0005433805616	8290	Business	18800.00
0005434143737	8290	Business	18800.00
0005433634128	8290	Economy	6900.00
0005433634167	8290	Economy	6300.00
0005433634051	8290	Economy	6300.00
0005433634230	8290	Economy	6300.00
0005433634219	8290	Economy	6300.00
0005433805745	8290	Economy	6300.00
0005433634071	8290	Economy	6300.00
0005433805816	8290	Economy	6300.00
0005433805770	8290	Economy	6300.00
0005433805723	8290	Economy	6300.00
0005433805713	8290	Economy	6300.00
0005433634103	8290	Economy	6300.00
0005433805785	8290	Economy	6300.00
0005433634218	8290	Economy	6300.00
0005433805896	8290	Economy	6300.00
0005433634139	8290	Economy	6300.00
0005433634021	8290	Economy	6300.00
0005433634073	8290	Economy	6300.00
0005433634267	8290	Economy	6300.00
0005433805627	8290	Economy	6300.00
0005433805895	8290	Economy	6300.00
0005433633953	8290	Economy	6300.00
0005434271342	8290	Economy	6300.00
0005433805646	8290	Economy	6300.00
0005433805625	8290	Economy	6300.00
0005433634014	8290	Economy	6300.00
0005433633992	8290	Economy	6300.00
0005433634072	8290	Economy	6300.00
0005433634056	8290	Economy	6300.00
0005433805670	8290	Economy	6900.00
0005433805771	8290	Economy	6900.00
0005433634074	8290	Economy	6900.00
0005433634144	8290	Economy	6300.00
0005433634006	8290	Economy	6900.00
0005433634036	8290	Economy	6300.00
0005433634143	8290	Economy	6300.00
0005433634132	8290	Economy	6300.00
0005433634231	8290	Economy	6300.00
0005433633989	8290	Economy	6300.00
0005433805649	8290	Economy	6300.00
0005433805436	8290	Economy	6300.00
0005433805617	8290	Economy	6300.00
0005433634137	8290	Economy	6300.00
0005433805738	8290	Economy	6300.00
0005433633952	8290	Economy	6300.00
0005433634101	8290	Economy	6300.00
0005433634223	8290	Economy	6300.00
0005433634323	8290	Economy	6300.00
0005433805709	8290	Economy	6300.00
0005433634224	8290	Economy	6300.00
0005433805710	8290	Economy	6300.00
0005433805676	8290	Economy	6300.00
0005433634113	8290	Economy	6300.00
0005433634189	8290	Economy	6300.00
0005434271336	8290	Economy	6300.00
0005433805630	8290	Economy	6300.00
0005433805638	8290	Economy	6300.00
0005433634324	8290	Economy	6300.00
0005433805750	8290	Economy	6300.00
0005433634160	8290	Economy	6300.00
0005433805631	8290	Economy	6300.00
0005433805726	8290	Economy	6300.00
0005433634168	8290	Economy	6300.00
0005433634129	8290	Economy	6300.00
0005434183593	8332	Economy	6300.00
0005434183599	8332	Economy	6300.00
0005434183597	8332	Economy	6300.00
0005434183598	8332	Economy	6300.00
0005432383878	4531	Business	9900.00
0005433194901	4531	Business	9900.00
0005432383888	4531	Business	9900.00
0005432728174	4531	Business	9900.00
0005432383880	4531	Business	9900.00
0005432383911	4531	Business	9900.00
0005432383905	4531	Business	9900.00
0005432383896	4531	Business	9900.00
0005432728176	4531	Business	9900.00
0005433194903	4531	Business	9900.00
0005432728167	4531	Business	9900.00
0005432728168	4531	Economy	3300.00
0005432383897	4531	Economy	3300.00
0005432728171	4531	Economy	3300.00
0005432383883	4531	Economy	3300.00
0005432383901	4531	Economy	3300.00
0005433722345	4531	Economy	3600.00
0005432728165	4531	Economy	3600.00
0005432383882	4531	Economy	3300.00
0005432728169	4531	Economy	3300.00
0005432383881	4531	Economy	3300.00
0005433453797	4531	Economy	3300.00
0005433194902	4531	Economy	3300.00
0005433194904	4531	Economy	3300.00
0005432383898	4531	Economy	3300.00
0005432728173	4531	Economy	3300.00
0005432383877	4531	Economy	3300.00
0005433722343	4531	Economy	3300.00
0005432383876	4531	Economy	3300.00
0005432383890	4531	Economy	3300.00
0005432728177	4531	Economy	3300.00
0005432383904	4531	Economy	3300.00
0005432383875	4531	Economy	3300.00
0005433453799	4531	Economy	3300.00
0005433194900	4531	Economy	3300.00
0005432383906	4531	Economy	3300.00
0005432383913	4531	Economy	3300.00
0005432728172	4531	Economy	3300.00
0005432383895	4531	Economy	3300.00
0005432383910	4531	Economy	3300.00
0005432383912	4531	Economy	3300.00
0005432383909	4531	Economy	3300.00
0005433722346	4531	Economy	3300.00
0005433454915	4531	Economy	3300.00
0005432383894	4531	Economy	3300.00
0005432383900	4531	Economy	3300.00
0005432383886	4531	Economy	3300.00
0005432383908	4531	Economy	3300.00
0005432383914	4531	Economy	3300.00
0005433722344	4531	Economy	3300.00
0005432728175	4531	Economy	3300.00
0005433453798	4531	Economy	3300.00
0005432383892	4531	Economy	3300.00
0005432728166	4531	Economy	3300.00
0005432383907	4531	Economy	3300.00
0005432383899	4531	Economy	3300.00
0005432383903	4531	Economy	3300.00
0005432383893	4531	Economy	3300.00
0005433453800	4531	Economy	3300.00
0005432383902	4531	Economy	3300.00
0005432383884	4531	Economy	3300.00
0005432383889	4531	Economy	3300.00
0005432383887	4531	Economy	3300.00
0005432383891	4531	Economy	3300.00
0005432728170	4531	Economy	3300.00
0005432383885	4531	Economy	3300.00
0005432383879	4531	Economy	3300.00
0005432383510	30107	Business	9900.00
0005432383478	30107	Business	9900.00
0005432383526	30107	Business	9900.00
0005432728038	30107	Business	9900.00
0005432728043	30107	Business	9900.00
0005432383433	30107	Business	9900.00
0005432728094	30107	Business	9900.00
0005433194883	30107	Business	9900.00
0005432383377	30107	Economy	3300.00
0005432383388	30107	Economy	3300.00
0005432383497	30107	Economy	3300.00
0005432383423	30107	Economy	3300.00
0005432728055	30107	Economy	3300.00
0005432728064	30107	Economy	3300.00
0005432383387	30107	Economy	3300.00
0005432383422	30107	Economy	3600.00
0005432383424	30107	Economy	3600.00
0005433194882	30107	Economy	3600.00
0005432383285	30107	Economy	3600.00
0005432383451	30107	Economy	3300.00
0005432383477	30107	Economy	3300.00
0005432383393	30107	Economy	3300.00
0005432728110	30107	Economy	3300.00
0005432383498	30107	Economy	3300.00
0005432383385	30107	Economy	3300.00
0005432383434	30107	Economy	3300.00
0005432728071	30107	Economy	3300.00
0005432728018	30107	Economy	3300.00
0005432383489	30107	Economy	3300.00
0005432383353	30107	Economy	3300.00
0005432728051	30107	Economy	3300.00
0005432383324	30107	Economy	3300.00
0005432383386	30107	Economy	3300.00
0005432383460	30107	Economy	3300.00
0005432728042	30107	Economy	3300.00
0005432383357	30107	Economy	3300.00
0005432728026	30107	Economy	3300.00
0005432383490	30107	Economy	3300.00
0005432728112	30107	Economy	3300.00
0005432728072	30107	Economy	3300.00
0005432383392	30107	Economy	3300.00
0005432728025	30107	Economy	3300.00
0005432383362	30107	Economy	3300.00
0005432383545	30107	Economy	3300.00
0005432728111	30107	Economy	3300.00
0005432383325	30107	Economy	3300.00
0005432383418	30107	Economy	3300.00
0005432383384	30107	Economy	3300.00
0005432728073	30107	Economy	3300.00
0005432383435	30107	Economy	3300.00
0005432383484	30107	Economy	3300.00
0005432383487	30107	Economy	3300.00
0005432383509	30107	Economy	3300.00
0005432728057	30107	Economy	3300.00
0005432383298	30107	Economy	3300.00
0005432383395	30107	Economy	3300.00
0005432383496	30107	Economy	3300.00
0005432728075	30107	Economy	3300.00
0005432383503	30107	Economy	3300.00
0005432383330	30107	Economy	3300.00
0005432383417	30107	Economy	3300.00
0005432728056	30107	Economy	3300.00
0005432383485	30107	Economy	3300.00
0005433194878	30107	Economy	3300.00
0005433194884	30107	Economy	3300.00
0005432383358	30107	Economy	3300.00
0005432383396	30107	Economy	3300.00
0005432383284	30107	Economy	3300.00
0005432383438	30107	Economy	3300.00
0005432383361	30107	Economy	3300.00
0005432383546	30107	Economy	3300.00
0005435541410	1718	Business	57200.00
0005432294532	1718	Business	57200.00
0005435529999	1718	Business	57200.00
0005435529672	1718	Business	57200.00
0005435529675	1718	Business	57200.00
0005435530000	1718	Business	57200.00
0005435529659	1718	Business	57200.00
0005433517064	1718	Business	57200.00
0005432925094	1718	Business	57200.00
0005435529655	1718	Economy	19100.00
0005435529660	1718	Economy	19100.00
0005435541408	1718	Economy	19100.00
0005435529671	1718	Economy	19100.00
0005435529657	1718	Economy	19100.00
0005435529661	1718	Economy	19100.00
0005435529666	1718	Economy	21000.00
0005435541405	1718	Economy	21000.00
0005433517062	1718	Economy	21000.00
0005435529995	1718	Economy	19100.00
0005433517061	1718	Economy	19100.00
0005432925096	1718	Economy	19100.00
0005435529667	1718	Economy	19100.00
0005435529664	1718	Economy	19100.00
0005435529674	1718	Economy	19100.00
0005432294531	1718	Economy	19100.00
0005435541409	1718	Economy	19100.00
0005432925089	1718	Economy	19100.00
0005435541412	1718	Economy	19100.00
0005435541411	1718	Economy	19100.00
0005435541402	1718	Economy	19100.00
0005435541419	1718	Economy	19100.00
0005432925088	1718	Economy	19100.00
0005435541417	1718	Economy	19100.00
0005435541401	1718	Economy	19100.00
0005435541407	1718	Economy	19100.00
0005435541398	1718	Economy	19100.00
0005433517063	1718	Economy	19100.00
0005435529673	1718	Economy	19100.00
0005435541400	1718	Economy	19100.00
0005435529658	1718	Economy	19100.00
0005435541399	1718	Economy	19100.00
0005432925095	1718	Economy	19100.00
0005435529654	1718	Economy	19100.00
0005435529668	1718	Economy	19100.00
0005435541415	1718	Economy	19100.00
0005432294534	1718	Economy	19100.00
0005435541403	1718	Economy	19100.00
0005435529665	1718	Economy	19100.00
0005435529662	1718	Economy	19100.00
0005435529996	1718	Economy	19100.00
0005435541418	1718	Economy	19100.00
0005433517059	1718	Economy	19100.00
0005432925068	1718	Economy	19100.00
0005435529656	1718	Economy	19100.00
0005435541414	1718	Economy	19100.00
0005435529670	1718	Economy	19100.00
0005435541406	1718	Economy	19100.00
0005433517058	1718	Economy	19100.00
0005435541416	1718	Economy	19100.00
0005432294533	1718	Economy	19100.00
0005435529998	1718	Economy	19100.00
0005435529997	1718	Economy	19100.00
0005433517066	1718	Economy	19100.00
0005435541413	1718	Economy	19100.00
0005433517060	1718	Economy	19100.00
0005435541404	1718	Economy	19100.00
0005435529663	1718	Economy	19100.00
0005435529669	1718	Economy	19100.00
0005433517065	1718	Economy	19100.00
0005435541178	21997	Business	57200.00
0005433516985	21997	Business	57200.00
0005435541247	21997	Business	57200.00
0005435541199	21997	Business	57200.00
0005435541128	21997	Business	57200.00
0005435518134	21997	Economy	19100.00
0005432925127	21997	Economy	19100.00
0005435541205	21997	Economy	19100.00
0005433517023	21997	Economy	19100.00
0005435518098	21997	Economy	19100.00
0005435541193	21997	Economy	21000.00
0005432925126	21997	Economy	21000.00
0005435541186	21997	Economy	19100.00
0005435518069	21997	Economy	19100.00
0005435541098	21997	Economy	19100.00
0005435541211	21997	Economy	19100.00
0005435541264	21997	Economy	19100.00
0005435518103	21997	Economy	19100.00
0005435541263	21997	Economy	19100.00
0005435541210	21997	Economy	19100.00
0005435518087	21997	Economy	19100.00
0005435541185	21997	Economy	19100.00
0005435518088	21997	Economy	19100.00
0005435541177	21997	Economy	19100.00
0005435518117	21997	Economy	19100.00
0005433516986	21997	Economy	19100.00
0005435518104	21997	Economy	19100.00
0005435541260	21997	Economy	19100.00
0005433516994	21997	Economy	19100.00
0005435541156	21997	Economy	19100.00
0005433516982	21997	Economy	19100.00
0005435518056	21997	Economy	19100.00
0005435518046	21997	Economy	19100.00
0005435541239	21997	Economy	19100.00
0005435518045	21997	Economy	19100.00
0005432925125	21997	Economy	19100.00
0005435541242	21997	Economy	19100.00
0005435541200	21997	Economy	19100.00
0005435518055	21997	Economy	19100.00
0005435518061	21997	Economy	19100.00
0005433516995	21997	Economy	19100.00
0005433516993	21997	Economy	19100.00
0005435541261	21997	Economy	19100.00
0005432841050	7381	Business	18500.00
0005434664984	7381	Business	18500.00
0005435252887	7381	Business	18500.00
0005435252850	7381	Business	18500.00
0005434459184	7381	Business	18500.00
0005432839617	7381	Business	18500.00
0005432839598	7381	Business	18500.00
0005435491458	7381	Business	18500.00
0005432839625	7381	Business	18500.00
0005432839597	7381	Business	18500.00
0005432839616	7381	Business	18500.00
0005435252889	7381	Business	18500.00
0005435252868	7381	Economy	6200.00
0005434459189	7381	Economy	6200.00
0005432073454	7381	Economy	6200.00
0005432823485	7381	Economy	6200.00
0005435252841	7381	Economy	6200.00
0005435252851	7381	Economy	6200.00
0005432823486	7381	Economy	6200.00
0005435252933	7381	Economy	6200.00
0005432839604	7381	Economy	6800.00
0005434459188	7381	Economy	6800.00
0005435252844	7381	Economy	6800.00
0005432823487	7381	Economy	6800.00
0005435252812	7381	Economy	6800.00
0005435252863	7381	Economy	6200.00
0005435252901	7381	Economy	6200.00
0005435252937	7381	Economy	6200.00
0005432839622	7381	Economy	6200.00
0005434459185	7381	Economy	6200.00
0005434459181	7381	Economy	6200.00
0005435252831	7381	Economy	6200.00
0005434459195	7381	Economy	6200.00
0005435252877	7381	Economy	6200.00
0005435252900	7381	Economy	6200.00
0005432839595	7381	Economy	6200.00
0005432839618	7381	Economy	6200.00
0005432839613	7381	Economy	6200.00
0005434459192	7381	Economy	6200.00
0005432839606	7381	Economy	6200.00
0005432839626	7381	Economy	6200.00
0005432839614	7381	Economy	6200.00
0005432839609	7381	Economy	6200.00
0005432839610	7381	Economy	6200.00
0005434459194	7381	Economy	6200.00
0005432839608	7381	Economy	6200.00
0005435252840	7381	Economy	6200.00
0005435252881	7381	Economy	6200.00
0005435252846	7381	Economy	6200.00
0005434459179	7381	Economy	6200.00
0005434459197	7381	Economy	6200.00
0005432839624	7381	Economy	6200.00
0005434459191	7381	Economy	6200.00
0005434459199	7381	Economy	6200.00
0005432839602	7381	Economy	6200.00
0005434459193	7381	Economy	6200.00
0005432841049	7381	Economy	6200.00
0005434459187	7381	Economy	6200.00
0005432839620	7381	Economy	6200.00
0005435252902	7381	Economy	6200.00
0005434459180	7381	Economy	6200.00
0005434459198	7381	Economy	6200.00
0005435252869	7381	Economy	6200.00
0005432839603	7381	Economy	6200.00
0005432839612	7381	Economy	6200.00
0005432839596	7381	Economy	6200.00
0005434459190	7381	Economy	6200.00
0005432839615	7381	Economy	6200.00
0005435252862	7381	Economy	6200.00
0005432839623	7381	Economy	6200.00
0005434459183	7381	Economy	6200.00
0005432839599	7381	Economy	6200.00
0005432839600	7381	Economy	6200.00
0005432073453	7381	Economy	6200.00
0005434459186	7381	Economy	6200.00
0005435491457	7381	Economy	6200.00
0005434459182	7381	Economy	6200.00
0005432839601	7381	Economy	6200.00
0005432839621	7381	Economy	6200.00
0005434664971	7381	Economy	6200.00
0005432839605	7381	Economy	6200.00
0005434459196	7381	Economy	6200.00
0005432839607	7381	Economy	6200.00
0005435252882	7381	Economy	6200.00
0005432073455	7381	Economy	6200.00
0005432839611	7381	Economy	6200.00
0005435252888	7381	Economy	6200.00
0005434664983	7381	Economy	6200.00
0005432839619	7381	Economy	6200.00
0005435252843	7381	Economy	6200.00
0005432839451	28918	Business	18500.00
0005435253030	28918	Business	18500.00
0005435253026	28918	Business	18500.00
0005434458990	28918	Business	18500.00
0005435253029	28918	Business	18500.00
0005432839341	28918	Business	18500.00
0005432839284	28918	Business	18500.00
0005435253032	28918	Business	18500.00
0005432839463	28918	Economy	6200.00
0005435253034	28918	Economy	6200.00
0005432839326	28918	Economy	6200.00
0005432839404	28918	Economy	6200.00
0005432839342	28918	Economy	6200.00
0005434458999	28918	Economy	6800.00
0005432839347	28918	Economy	6800.00
0005432823472	28918	Economy	6800.00
0005432839352	28918	Economy	6800.00
0005432841033	28918	Economy	6800.00
0005432839340	28918	Economy	6200.00
0005435253028	28918	Economy	6200.00
0005432839464	28918	Economy	6200.00
0005435253033	28918	Economy	6200.00
0005434458914	28918	Economy	6200.00
0005432839292	28918	Economy	6200.00
0005432839361	28918	Economy	6200.00
0005435491480	28918	Economy	6200.00
0005432839421	28918	Economy	6200.00
0005432839420	28918	Economy	6200.00
0005434458987	28918	Economy	6200.00
0005432839418	28918	Economy	6200.00
0005434459049	28918	Economy	6200.00
0005432839466	28918	Economy	6200.00
0005432841032	28918	Economy	6200.00
0005432839353	28918	Economy	6200.00
0005432839465	28918	Economy	6200.00
0005432001062	28918	Economy	6200.00
0005432839317	28918	Economy	6200.00
0005432839291	28918	Economy	6200.00
0005432839417	28918	Economy	6200.00
0005432839298	28918	Economy	6200.00
0005435253025	28918	Economy	6200.00
0005435491481	28918	Economy	6200.00
0005435253041	28918	Economy	6200.00
0005435253039	28918	Economy	6200.00
0005432839348	28918	Economy	6200.00
0005434459050	28918	Economy	6200.00
0005435253027	28918	Economy	6200.00
0005435253031	28918	Economy	6200.00
0005432839372	28918	Economy	6200.00
0005432001061	28918	Economy	6200.00
0005435253037	28918	Economy	6200.00
0005434459002	28918	Economy	6200.00
0005435491482	28918	Economy	6200.00
0005434458913	28918	Economy	6200.00
0005435253024	28918	Economy	6200.00
0005432839330	28918	Economy	6200.00
0005432839402	28918	Economy	6200.00
0005435253038	28918	Economy	6200.00
0005435253035	28918	Economy	6200.00
0005432839491	28918	Economy	6200.00
0005432001060	28918	Economy	6200.00
0005434665003	28918	Economy	6200.00
0005435253040	28918	Economy	6200.00
0005435253036	28918	Economy	6200.00
0005432839371	28918	Economy	6200.00
0005432839229	28918	Economy	6200.00
0005432839419	28918	Economy	6200.00
0005432823471	28918	Economy	6200.00
0005432839413	28918	Economy	6200.00
0005435990758	8825	Business	145300.00
0005435990756	8825	Economy	48400.00
0005434276061	8825	Economy	48400.00
0005435990753	8825	Economy	48400.00
0005435990755	8825	Economy	48400.00
0005434276080	8825	Economy	48400.00
0005435990757	8825	Economy	48400.00
0005434276094	8825	Economy	48400.00
0005435990759	8825	Economy	48400.00
0005434276095	8825	Economy	48400.00
0005434276079	8825	Economy	48400.00
0005435990754	8825	Economy	48400.00
0005434276060	8825	Economy	48400.00
0005434276136	15727	Business	145300.00
0005435990675	15727	Business	145300.00
0005435990687	15727	Business	145300.00
0005434276134	15727	Business	145300.00
0005435990655	15727	Economy	48400.00
0005435990685	15727	Economy	48400.00
0005434276135	15727	Economy	48400.00
0005434276133	15727	Economy	48400.00
0005434276137	15727	Economy	48400.00
0005435990674	15727	Economy	48400.00
0005435990699	15727	Economy	48400.00
0005434276132	15727	Economy	48400.00
0005435990700	15727	Economy	48400.00
0005435990688	15727	Economy	48400.00
0005433468489	2081	Economy	13300.00
0005432909350	2081	Economy	13300.00
0005432909321	2081	Economy	13300.00
0005432909338	2081	Economy	12100.00
0005433468491	2081	Economy	12100.00
0005432909307	2081	Economy	12100.00
0005433468494	2081	Economy	12100.00
0005433468497	2081	Economy	12100.00
0005433468488	2081	Economy	12100.00
0005433468506	2081	Economy	12100.00
0005433468504	2081	Economy	12100.00
0005432909337	2081	Economy	12100.00
0005432909358	2081	Economy	12100.00
0005433468490	2081	Economy	12100.00
0005433468495	2081	Economy	12100.00
0005433468496	2081	Economy	12100.00
0005433468501	2081	Economy	12100.00
0005433468498	2081	Economy	12100.00
0005432909341	2081	Economy	12100.00
0005433468499	2081	Economy	12100.00
0005433468502	2081	Economy	12100.00
0005433468505	2081	Economy	12100.00
0005433468492	2081	Economy	12100.00
0005432909336	2081	Economy	12100.00
0005433468503	2081	Economy	12100.00
0005433468493	2081	Economy	12100.00
0005433468500	2081	Economy	12100.00
0005432909340	2081	Economy	12100.00
0005435177449	6414	Business	36600.00
0005432062331	6414	Business	36600.00
0005432062328	6414	Business	36600.00
0005434149840	6414	Business	36600.00
0005435177434	6414	Business	36600.00
0005432336251	6414	Business	36600.00
0005432336255	6414	Business	36600.00
0005435177435	6414	Business	36600.00
0005432361230	6414	Business	36600.00
0005432361245	6414	Business	36600.00
0005432062329	6414	Business	36600.00
0005432361265	6414	Business	36600.00
0005435490282	6414	Economy	12200.00
0005432361274	6414	Economy	12200.00
0005432062330	6414	Economy	12200.00
0005435490265	6414	Economy	12200.00
0005434149866	6414	Economy	12200.00
0005435177433	6414	Economy	12200.00
0005432361234	6414	Economy	12200.00
0005434149865	6414	Economy	12200.00
0005432361271	6414	Economy	12200.00
0005432336258	6414	Economy	12200.00
0005432361256	6414	Economy	12200.00
0005432361253	6414	Economy	12200.00
0005432336250	6414	Economy	12200.00
0005432361260	6414	Economy	12200.00
0005432361261	6414	Economy	12200.00
0005435723070	6414	Economy	12200.00
0005432361276	6414	Economy	12200.00
0005434149854	6414	Economy	12200.00
0005435177180	6414	Economy	12200.00
0005432361228	6414	Economy	12200.00
0005432361250	6414	Economy	12200.00
0005432361239	6414	Economy	12200.00
0005432361267	6414	Economy	12200.00
0005432361231	6414	Economy	12200.00
0005432361259	6414	Economy	12200.00
0005435177353	6414	Economy	12200.00
0005432062325	6414	Economy	12200.00
0005434149873	6414	Economy	12200.00
0005435177326	6414	Economy	12200.00
0005432361268	6414	Economy	12200.00
0005432361272	6414	Economy	12200.00
0005432361275	6414	Economy	12200.00
0005434149835	6414	Economy	12200.00
0005435177488	6414	Economy	13400.00
0005435177322	6414	Economy	13400.00
0005435177367	6414	Economy	13400.00
0005432361247	6414	Economy	13400.00
0005432361241	6414	Economy	12200.00
0005432336252	6414	Economy	12200.00
0005432361236	6414	Economy	12200.00
0005432361252	6414	Economy	12200.00
0005432062326	6414	Economy	12200.00
0005432361254	6414	Economy	12200.00
0005434149843	6414	Economy	12200.00
0005432361262	6414	Economy	12200.00
0005435177417	6414	Economy	12200.00
0005432361273	6414	Economy	12200.00
0005432361235	6414	Economy	12200.00
0005435177422	6414	Economy	12200.00
0005432336259	6414	Economy	12200.00
0005434149889	6414	Economy	12200.00
0005435177448	6414	Economy	12200.00
0005432361232	6414	Economy	12200.00
0005432336249	6414	Economy	12200.00
0005434149868	6414	Economy	12200.00
0005435177414	6414	Economy	12200.00
0005432361242	6414	Economy	12200.00
0005432361257	6414	Economy	12200.00
0005432361246	6414	Economy	12200.00
0005435177447	6414	Economy	12200.00
0005432361258	6414	Economy	12200.00
0005434149876	6414	Economy	12200.00
0005432363477	6414	Economy	12200.00
0005432361249	6414	Economy	12200.00
0005435723069	6414	Economy	12200.00
0005432361248	6414	Economy	12200.00
0005432361251	6414	Economy	12200.00
0005435177331	6414	Economy	12200.00
0005432363476	6414	Economy	12200.00
0005432361264	6414	Economy	12200.00
0005435177450	6414	Economy	12200.00
0005432361237	6414	Economy	12200.00
0005432336257	6414	Economy	12200.00
0005432361255	6414	Economy	12200.00
0005434149838	6414	Economy	12200.00
0005432361240	6414	Economy	12200.00
0005432361263	6414	Economy	12200.00
0005435177416	6414	Economy	12200.00
0005432361238	6414	Economy	12200.00
0005432336253	6414	Economy	12200.00
0005435490258	6414	Economy	12200.00
0005435723068	6414	Economy	12200.00
0005435177343	6414	Economy	12200.00
0005432361229	6414	Economy	12200.00
0005432361266	6414	Economy	12200.00
0005432361243	6414	Economy	12200.00
0005432361233	6414	Economy	12200.00
0005432336260	6414	Economy	12200.00
0005435177425	6414	Economy	12200.00
0005432361270	6414	Economy	12200.00
0005432336254	6414	Economy	12200.00
0005432361269	6414	Economy	12200.00
0005432361244	6414	Economy	12200.00
0005435177423	6414	Economy	12200.00
0005435490254	6414	Economy	12200.00
0005432062327	6414	Economy	12200.00
0005432336256	6414	Economy	12200.00
0005435177415	6414	Economy	12200.00
0005432360600	20990	Business	36600.00
0005432052801	20990	Business	36600.00
0005432360842	20990	Business	36600.00
0005434149954	20990	Business	36600.00
0005432360687	20990	Business	36600.00
0005434149953	20990	Business	36600.00
0005435490299	20990	Business	36600.00
0005432360968	20990	Business	36600.00
0005432360790	20990	Business	36600.00
0005432360773	20990	Business	36600.00
0005432336182	20990	Business	36600.00
0005435177573	20990	Economy	12200.00
0005435177588	20990	Economy	12200.00
0005432360899	20990	Economy	12200.00
0005435177592	20990	Economy	12200.00
0005435177594	20990	Economy	12200.00
0005435177574	20990	Economy	12200.00
0005432360770	20990	Economy	12200.00
0005434149943	20990	Economy	12200.00
0005434149942	20990	Economy	12200.00
0005435177596	20990	Economy	12200.00
0005432360751	20990	Economy	12200.00
0005432360774	20990	Economy	12200.00
0005432360750	20990	Economy	12200.00
0005432360737	20990	Economy	12200.00
0005434149952	20990	Economy	12200.00
0005432052802	20990	Economy	12200.00
0005435177579	20990	Economy	12200.00
0005432360854	20990	Economy	12200.00
0005435177582	20990	Economy	12200.00
0005435177597	20990	Economy	12200.00
0005435177577	20990	Economy	12200.00
0005432360726	20990	Economy	12200.00
0005432336183	20990	Economy	12200.00
0005435490297	20990	Economy	12200.00
0005435177578	20990	Economy	12200.00
0005432361220	20990	Economy	12200.00
0005435177576	20990	Economy	12200.00
0005432360771	20990	Economy	13400.00
0005432360816	20990	Economy	13400.00
0005432360879	20990	Economy	13400.00
0005432360874	20990	Economy	12200.00
0005432360833	20990	Economy	12200.00
0005432360817	20990	Economy	12200.00
0005435177572	20990	Economy	12200.00
0005434149950	20990	Economy	12200.00
0005432360897	20990	Economy	12200.00
0005432360798	20990	Economy	12200.00
0005432360840	20990	Economy	12200.00
0005435177581	20990	Economy	12200.00
0005432360597	20990	Economy	12200.00
0005432360895	20990	Economy	12200.00
0005435177593	20990	Economy	12200.00
0005432052803	20990	Economy	12200.00
0005435177587	20990	Economy	12200.00
0005432360975	20990	Economy	12200.00
0005434149948	20990	Economy	12200.00
0005432336178	20990	Economy	12200.00
0005435177575	20990	Economy	12200.00
0005432361037	20990	Economy	12200.00
0005432360857	20990	Economy	12200.00
0005432360880	20990	Economy	12200.00
0005435177591	20990	Economy	12200.00
0005435177583	20990	Economy	12200.00
0005434149945	20990	Economy	12200.00
0005432360557	20990	Economy	12200.00
0005432360745	20990	Economy	12200.00
0005435723081	20990	Economy	12200.00
0005435177580	20990	Economy	12200.00
0005435177585	20990	Economy	12200.00
0005432336172	20990	Economy	12200.00
0005432336153	20990	Economy	12200.00
0005432360556	20990	Economy	12200.00
0005432361221	20990	Economy	12200.00
0005435177598	20990	Economy	12200.00
0005432360974	20990	Economy	12200.00
0005432360891	20990	Economy	12200.00
0005432360757	20990	Economy	12200.00
0005432360661	20990	Economy	12200.00
0005432360878	20990	Economy	12200.00
0005432360799	20990	Economy	12200.00
0005432336154	20990	Economy	12200.00
0005432336087	20990	Economy	12200.00
0005435177586	20990	Economy	12200.00
0005434149947	20990	Economy	12200.00
0005434149949	20990	Economy	12200.00
0005432336166	20990	Economy	12200.00
0005432360826	20990	Economy	12200.00
0005432360601	20990	Economy	12200.00
0005432360775	20990	Economy	12200.00
0005435177584	20990	Economy	12200.00
0005434149944	20990	Economy	12200.00
0005434149951	20990	Economy	12200.00
0005435177590	20990	Economy	12200.00
0005435177589	20990	Economy	12200.00
0005432360800	20990	Economy	12200.00
0005432360772	20990	Economy	12200.00
0005434149946	20990	Economy	12200.00
0005435490300	20990	Economy	12200.00
0005432360873	20990	Economy	12200.00
0005435177595	20990	Economy	12200.00
0005432360746	20990	Economy	12200.00
0005432360892	20990	Economy	12200.00
0005432360881	20990	Economy	12200.00
0005432336135	20990	Economy	12200.00
0005432360738	20990	Economy	12200.00
0005435490298	20990	Economy	12200.00
0005434448360	17727	Economy	3400.00
0005434458969	17727	Economy	3400.00
0005434459046	17727	Economy	3400.00
0005434459024	17727	Economy	3100.00
0005434459047	17727	Economy	3100.00
0005434461663	17727	Economy	3100.00
0005434461662	17727	Economy	3100.00
0005434459080	17727	Economy	3100.00
0005434459120	17727	Economy	3100.00
0005434186254	17727	Economy	3100.00
0005434186253	17727	Economy	3100.00
0005434459051	17727	Economy	3100.00
0005434459001	17727	Economy	3100.00
0005434459004	17727	Economy	3100.00
0005434458939	17727	Economy	3100.00
0005434463947	17727	Economy	3100.00
0005434186255	17727	Economy	3100.00
0005434448338	17727	Economy	3100.00
0005434448348	17727	Economy	3100.00
0005434459000	17727	Economy	3100.00
0005434458940	17727	Economy	3100.00
0005434459005	17727	Economy	3100.00
0005434448339	17727	Economy	3100.00
0005434458924	17727	Economy	3100.00
0005434459121	17727	Economy	3100.00
0005434459098	17727	Economy	3100.00
0005434459039	17727	Economy	3100.00
0005434459017	17727	Economy	3100.00
0005434461657	17727	Economy	3100.00
0005434463948	17727	Economy	3100.00
0005434459048	17727	Economy	3100.00
0005434458925	17727	Economy	3100.00
0005434459099	17727	Economy	3100.00
0005434463940	17727	Economy	3100.00
0005434459079	17727	Economy	3100.00
0005434459003	17727	Economy	3100.00
0005434448349	17727	Economy	3100.00
0005434448340	17727	Economy	3100.00
0005434459112	17727	Economy	3100.00
0005434459191	29110	Economy	3400.00
0005434459184	29110	Economy	3400.00
0005434462829	29110	Economy	3100.00
0005434459179	29110	Economy	3100.00
0005434459182	29110	Economy	3100.00
0005434459197	29110	Economy	3100.00
0005434459195	29110	Economy	3100.00
0005434459199	29110	Economy	3100.00
0005434459180	29110	Economy	3100.00
0005434186228	29110	Economy	3100.00
0005434462828	29110	Economy	3100.00
0005434448376	29110	Economy	3100.00
0005434186231	29110	Economy	3100.00
0005434186226	29110	Economy	3100.00
0005434459185	29110	Economy	3100.00
0005434462827	29110	Economy	3100.00
0005434448375	29110	Economy	3100.00
0005434448378	29110	Economy	3100.00
0005434186222	29110	Economy	3100.00
0005434448377	29110	Economy	3100.00
0005434186219	29110	Economy	3100.00
0005434459183	29110	Economy	3100.00
0005434186230	29110	Economy	3100.00
0005434459193	29110	Economy	3100.00
0005434459186	29110	Economy	3100.00
0005434459194	29110	Economy	3100.00
0005434459196	29110	Economy	3100.00
0005434459187	29110	Economy	3100.00
0005434459192	29110	Economy	3100.00
0005434186233	29110	Economy	3100.00
0005434459188	29110	Economy	3100.00
0005434459190	29110	Economy	3100.00
0005434459181	29110	Economy	3100.00
0005434459189	29110	Economy	3100.00
0005434186227	29110	Economy	3100.00
0005434459198	29110	Economy	3100.00
0005432605025	21454	Economy	7300.00
0005432605056	21454	Economy	7300.00
0005432605047	21454	Economy	7300.00
0005432605052	21454	Economy	7300.00
0005432605060	21454	Economy	6600.00
0005432605061	21454	Economy	6600.00
0005432605044	21454	Economy	6600.00
0005432605041	21454	Economy	6600.00
0005432605022	21454	Economy	6600.00
0005432605054	21454	Economy	6600.00
0005432605048	21454	Economy	6600.00
0005432605027	21454	Economy	6600.00
0005432605034	21454	Economy	6600.00
0005432605058	21454	Economy	6600.00
0005432605033	21454	Economy	6600.00
0005432605045	21454	Economy	6600.00
0005435218121	21454	Economy	6600.00
0005432605037	21454	Economy	6600.00
0005432605023	21454	Economy	6600.00
0005432605059	21454	Economy	6600.00
0005432605038	21454	Economy	6600.00
0005432605024	21454	Economy	6600.00
0005432605035	21454	Economy	6600.00
0005432605029	21454	Economy	6600.00
0005432605031	21454	Economy	6600.00
0005432605040	21454	Economy	6600.00
0005432605043	21454	Economy	6600.00
0005432605026	21454	Economy	6600.00
0005432605039	21454	Economy	6600.00
0005432605042	21454	Economy	6600.00
0005432605028	21454	Economy	6600.00
0005432605030	21454	Economy	6600.00
0005432605049	21454	Economy	6600.00
0005432605057	21454	Economy	6600.00
0005432605021	21454	Economy	6600.00
0005432605051	21454	Economy	6600.00
0005432605055	21454	Economy	6600.00
0005432605053	21454	Economy	6600.00
0005432605036	21454	Economy	6600.00
0005432605046	21454	Economy	6600.00
0005432605050	21454	Economy	6600.00
0005432605032	21454	Economy	6600.00
0005432604618	31713	Economy	7300.00
0005432604617	31713	Economy	7300.00
0005432604616	31713	Economy	7300.00
0005432604894	31713	Economy	7300.00
0005432604895	31713	Economy	6600.00
0005432604756	31713	Economy	6600.00
0005432604808	31713	Economy	6600.00
0005432604660	31713	Economy	6600.00
0005432604708	31713	Economy	6600.00
0005435221548	31713	Economy	6600.00
0005432604675	31713	Economy	6600.00
0005432604556	31713	Economy	6600.00
0005432604591	31713	Economy	6600.00
0005432604889	31713	Economy	6600.00
0005432604655	31713	Economy	6600.00
0005432604543	31713	Economy	6600.00
0005432604544	31713	Economy	6600.00
0005435221071	31713	Economy	6600.00
0005432604778	31713	Economy	6600.00
0005432604638	31713	Economy	6600.00
0005432604692	31713	Economy	6600.00
0005432604668	31713	Economy	6600.00
0005432604674	31713	Economy	6600.00
0005435221549	31713	Economy	6600.00
0005432604777	31713	Economy	6600.00
0005432604785	31713	Economy	6600.00
0005432604849	31713	Economy	6600.00
0005435221529	31713	Economy	6600.00
0005435221528	31713	Economy	6600.00
0005432604541	31713	Economy	6600.00
0005432604520	31713	Economy	6600.00
0005432604765	31713	Economy	6600.00
0005432604826	31713	Economy	6600.00
0005432604746	31713	Economy	6600.00
0005432604728	31713	Economy	6600.00
0005433293364	29603	Economy	19500.00
0005433293359	29603	Economy	19500.00
0005435154600	29603	Economy	17800.00
0005433293358	29603	Economy	17800.00
0005433293352	29603	Economy	17800.00
0005433293365	29603	Economy	17800.00
0005433293354	29603	Economy	17800.00
0005435154601	29603	Economy	17800.00
0005433293367	29603	Economy	17800.00
0005433293366	29603	Economy	17800.00
0005433293368	29603	Economy	17800.00
0005435154598	29603	Economy	17800.00
0005433293362	29603	Economy	17800.00
0005433293370	29603	Economy	17800.00
0005433293369	29603	Economy	17800.00
0005433293360	29603	Economy	17800.00
0005435154599	29603	Economy	17800.00
0005433293361	29603	Economy	17800.00
0005433293355	29603	Economy	17800.00
0005433293353	29603	Economy	17800.00
0005433293357	29603	Economy	17800.00
0005433293363	29603	Economy	17800.00
0005433293356	29603	Economy	17800.00
0005435257258	6671	Economy	14000.00
0005433473421	6671	Economy	14000.00
0005433473414	6671	Economy	14000.00
0005433473440	6671	Economy	14000.00
0005435257289	6671	Economy	12700.00
0005433473435	6671	Economy	12700.00
0005435257297	6671	Economy	12700.00
0005433473422	6671	Economy	12700.00
0005435257275	6671	Economy	12700.00
0005435257261	6671	Economy	12700.00
0005435257277	6671	Economy	12700.00
0005433473433	6671	Economy	12700.00
0005433473431	6671	Economy	12700.00
0005433473434	6671	Economy	12700.00
0005433473417	6671	Economy	12700.00
0005433473438	6671	Economy	12700.00
0005433473426	6671	Economy	12700.00
0005433473419	6671	Economy	12700.00
0005433473429	6671	Economy	12700.00
0005435257271	6671	Economy	12700.00
0005435257265	6671	Economy	12700.00
0005433473418	6671	Economy	12700.00
0005433473436	6671	Economy	12700.00
0005435257292	6671	Economy	12700.00
0005433473420	6671	Economy	12700.00
0005433473439	6671	Economy	12700.00
0005433473423	6671	Economy	12700.00
0005435257260	6671	Economy	12700.00
0005433473441	6671	Economy	12700.00
0005433473415	6671	Economy	12700.00
0005435257267	6671	Economy	12700.00
0005435257295	6671	Economy	12700.00
0005433473427	6671	Economy	12700.00
0005433473430	6671	Economy	12700.00
0005435257262	6671	Economy	12700.00
0005435257306	6671	Economy	12700.00
0005433473443	6671	Economy	12700.00
0005433473428	6671	Economy	12700.00
0005435257288	6671	Economy	12700.00
0005435257278	6671	Economy	12700.00
0005433473424	6671	Economy	12700.00
0005433473416	6671	Economy	12700.00
0005435257290	6671	Economy	12700.00
0005433473442	6671	Economy	12700.00
0005435257264	6671	Economy	12700.00
0005433473437	6671	Economy	12700.00
0005433473425	6671	Economy	12700.00
0005433473432	6671	Economy	12700.00
0005434606855	18834	Economy	6600.00
0005434606883	22306	Economy	6600.00
0005434604958	22306	Economy	6600.00
0005434604957	22306	Economy	6600.00
0005434606884	22306	Economy	6600.00
0005434604960	22306	Economy	6600.00
0005434604961	22306	Economy	6600.00
0005434604959	22306	Economy	6600.00
0005434606886	22306	Economy	6600.00
0005434606885	22306	Economy	6600.00
0005432748261	424	Business	44500.00
0005433293307	424	Business	44500.00
0005432748277	424	Business	44500.00
0005432749824	424	Business	44500.00
0005432891184	424	Business	44500.00
0005432748264	424	Business	44500.00
0005432748248	424	Business	44500.00
0005432748247	424	Business	44500.00
0005432748265	424	Business	44500.00
0005432891216	424	Economy	14800.00
0005433875395	424	Economy	14800.00
0005432220082	424	Economy	14800.00
0005435154632	424	Economy	14800.00
0005432891262	424	Economy	14800.00
0005432748246	424	Economy	14800.00
0005432748258	424	Economy	14800.00
0005432748253	424	Economy	14800.00
0005432748255	424	Economy	14800.00
0005432220080	424	Economy	16300.00
0005432891164	424	Economy	16300.00
0005435154631	424	Economy	16300.00
0005433293311	424	Economy	16300.00
0005432891204	424	Economy	14800.00
0005432748271	424	Economy	14800.00
0005432748280	424	Economy	14800.00
0005435154629	424	Economy	14800.00
0005432753361	424	Economy	14800.00
0005432748250	424	Economy	14800.00
0005432748283	424	Economy	14800.00
0005432748276	424	Economy	14800.00
0005435154634	424	Economy	14800.00
0005432748259	424	Economy	14800.00
0005432748268	424	Economy	14800.00
0005432748275	424	Economy	14800.00
0005432751586	424	Economy	14800.00
0005433875396	424	Economy	14800.00
0005432748254	424	Economy	14800.00
0005435154630	424	Economy	14800.00
0005432891321	424	Economy	14800.00
0005432753359	424	Economy	14800.00
0005432748272	424	Economy	14800.00
0005432891173	424	Economy	14800.00
0005432748267	424	Economy	14800.00
0005432748251	424	Economy	14800.00
0005433293310	424	Economy	14800.00
0005432748282	424	Economy	14800.00
0005432748278	424	Economy	14800.00
0005435154636	424	Economy	14800.00
0005433875391	424	Economy	14800.00
0005432748257	424	Economy	14800.00
0005435627122	424	Economy	14800.00
0005435154635	424	Economy	14800.00
0005435154633	424	Economy	14800.00
0005433293309	424	Economy	14800.00
0005432748270	424	Economy	14800.00
0005432749823	424	Economy	14800.00
0005432220079	424	Economy	14800.00
0005432891146	424	Economy	14800.00
0005432220081	424	Economy	14800.00
0005432748269	424	Economy	14800.00
0005432748262	424	Economy	14800.00
0005432748252	424	Economy	14800.00
0005432748249	424	Economy	14800.00
0005432748284	424	Economy	14800.00
0005432748274	424	Economy	14800.00
0005432748279	424	Economy	14800.00
0005432748256	424	Economy	14800.00
0005432748285	424	Economy	14800.00
0005433875390	424	Economy	14800.00
0005432748273	424	Economy	14800.00
0005432748266	424	Economy	14800.00
0005432748281	424	Economy	14800.00
0005432748260	424	Economy	14800.00
0005432753360	424	Economy	14800.00
0005432748263	424	Economy	14800.00
0005432747927	12048	Business	44500.00
0005432891371	12048	Business	44500.00
0005432747921	12048	Business	44500.00
0005432747869	12048	Business	44500.00
0005432753345	12048	Business	44500.00
0005432747870	12048	Business	44500.00
0005432747905	12048	Business	44500.00
0005432747796	12048	Business	44500.00
0005432891390	12048	Business	44500.00
0005432748044	12048	Economy	14800.00
0005432747902	12048	Economy	14800.00
0005432891389	12048	Economy	14800.00
0005432891386	12048	Economy	14800.00
0005432747860	12048	Economy	14800.00
0005432747939	12048	Economy	14800.00
0005432747874	12048	Economy	14800.00
0005432747812	12048	Economy	14800.00
0005432748105	12048	Economy	14800.00
0005432891388	12048	Economy	16300.00
0005432747988	12048	Economy	16300.00
0005432748119	12048	Economy	16300.00
0005432214844	12048	Economy	16300.00
0005432756881	12048	Economy	16300.00
0005432891373	12048	Economy	14800.00
0005432891381	12048	Economy	14800.00
0005433875410	12048	Economy	14800.00
0005432891380	12048	Economy	14800.00
0005432891387	12048	Economy	14800.00
0005432747924	12048	Economy	14800.00
0005432891374	12048	Economy	14800.00
0005432748107	12048	Economy	14800.00
0005432748047	12048	Economy	14800.00
0005432747920	12048	Economy	14800.00
0005433875408	12048	Economy	14800.00
0005432891383	12048	Economy	14800.00
0005432891377	12048	Economy	14800.00
0005432748064	12048	Economy	14800.00
0005432891375	12048	Economy	14800.00
0005432748084	12048	Economy	14800.00
0005432891392	12048	Economy	14800.00
0005432747987	12048	Economy	14800.00
0005432891391	12048	Economy	14800.00
0005432891372	12048	Economy	14800.00
0005432748079	12048	Economy	14800.00
0005432748093	12048	Economy	14800.00
0005432756882	12048	Economy	14800.00
0005433875409	12048	Economy	14800.00
0005434153556	12048	Economy	14800.00
0005432891379	12048	Economy	14800.00
0005434153555	12048	Economy	14800.00
0005432748078	12048	Economy	14800.00
0005432747975	12048	Economy	14800.00
0005432891384	12048	Economy	14800.00
0005432747986	12048	Economy	14800.00
0005432747930	12048	Economy	14800.00
0005432747952	12048	Economy	14800.00
0005432891385	12048	Economy	14800.00
0005432748034	12048	Economy	14800.00
0005432214843	12048	Economy	14800.00
0005432756880	12048	Economy	14800.00
0005432747925	12048	Economy	14800.00
0005432748023	12048	Economy	14800.00
0005432891378	12048	Economy	14800.00
0005432747948	12048	Economy	14800.00
0005432753344	12048	Economy	14800.00
0005432748115	12048	Economy	14800.00
0005432891382	12048	Economy	14800.00
0005434153557	12048	Economy	14800.00
0005432747950	12048	Economy	14800.00
0005432747903	12048	Economy	14800.00
0005432748039	12048	Economy	14800.00
0005432891376	12048	Economy	14800.00
0005432753339	12048	Economy	14800.00
0005432747976	12048	Economy	14800.00
0005432747931	12048	Economy	14800.00
0005432747929	12048	Economy	14800.00
0005432928030	18955	Economy	28200.00
0005433533377	18955	Economy	25700.00
0005433525225	18955	Economy	25700.00
0005432928025	18955	Economy	25700.00
0005433533374	18955	Economy	25700.00
0005432928034	18955	Economy	25700.00
0005433525235	18955	Economy	25700.00
0005433533373	18955	Economy	25700.00
0005433525230	18955	Economy	25700.00
0005433525231	18955	Economy	25700.00
0005433533375	18955	Economy	25700.00
0005433525232	18955	Economy	25700.00
0005433533376	18955	Economy	25700.00
0005432928063	18955	Economy	25700.00
0005433525234	18955	Economy	25700.00
0005433525233	18955	Economy	25700.00
0005432928056	18955	Economy	25700.00
0005433525227	18955	Economy	25700.00
0005433531360	18955	Economy	25700.00
0005433531361	18955	Economy	25700.00
0005433525228	18955	Economy	25700.00
0005433525229	18955	Economy	25700.00
0005432928032	18955	Economy	25700.00
0005433531362	18955	Economy	25700.00
0005433531358	18955	Economy	25700.00
0005433525226	18955	Economy	25700.00
0005433531359	18955	Economy	25700.00
0005432928045	18955	Economy	25700.00
0005433525106	32518	Economy	28200.00
0005432928091	32518	Economy	28200.00
0005433525138	32518	Economy	25700.00
0005433531346	32518	Economy	25700.00
0005432928087	32518	Economy	25700.00
0005433525114	32518	Economy	25700.00
0005432928089	32518	Economy	25700.00
0005433525113	32518	Economy	25700.00
0005433527285	32518	Economy	25700.00
0005433525193	32518	Economy	25700.00
0005433525159	32518	Economy	25700.00
0005433525137	32518	Economy	25700.00
0005433525178	32518	Economy	25700.00
0005433525166	32518	Economy	25700.00
0005433525143	32518	Economy	25700.00
0005432928088	32518	Economy	25700.00
0005433525186	32518	Economy	25700.00
0005432928090	32518	Economy	25700.00
0005433527300	32518	Economy	25700.00
0005433525173	32518	Economy	25700.00
0005433531345	32518	Economy	25700.00
0005433527286	32518	Economy	25700.00
0005433525177	32518	Economy	25700.00
0005433525139	32518	Economy	25700.00
0005433525171	32518	Economy	25700.00
0005434825890	5266	Business	84000.00
0005434825922	5266	Business	84000.00
0005434825928	5266	Business	84000.00
0005434825959	5266	Business	84000.00
0005434825941	5266	Business	84000.00
0005434831234	5266	Business	84000.00
0005435299814	5266	Business	84000.00
0005435374070	5266	Business	84000.00
0005435374019	5266	Business	84000.00
0005435374006	5266	Business	84000.00
0005435373918	5266	Business	84000.00
0005435735165	5266	Business	84000.00
0005435374017	5266	Business	84000.00
0005434825948	5266	Business	84000.00
0005434558429	5266	Business	84000.00
0005434825933	5266	Business	84000.00
0005434825937	5266	Comfort	47600.00
0005435373816	5266	Comfort	47600.00
0005434825862	5266	Comfort	47600.00
0005434825881	5266	Comfort	47600.00
0005435374114	5266	Comfort	47600.00
0005434665001	5266	Comfort	47600.00
0005435373788	5266	Comfort	47600.00
0005434825951	5266	Comfort	47600.00
0005434825942	5266	Comfort	47600.00
0005435150283	5266	Comfort	47600.00
0005435374150	5266	Comfort	47600.00
0005434825926	5266	Comfort	47600.00
0005435373913	5266	Comfort	47600.00
0005434825956	5266	Comfort	47600.00
0005434825860	5266	Comfort	47600.00
0005435373783	5266	Comfort	47600.00
0005435373782	5266	Comfort	47600.00
0005435373608	5266	Comfort	47600.00
0005435373857	5266	Comfort	47600.00
0005435150290	5266	Comfort	47600.00
0005435735167	5266	Comfort	47600.00
0005435373884	5266	Comfort	47600.00
0005434825954	5266	Comfort	47600.00
0005434831232	5266	Comfort	47600.00
0005434825939	5266	Comfort	47600.00
0005434825884	5266	Comfort	47600.00
0005435661953	5266	Comfort	47600.00
0005435150293	5266	Comfort	47600.00
0005434831235	5266	Economy	28000.00
0005434825925	5266	Economy	28000.00
0005434825980	5266	Economy	28000.00
0005434825879	5266	Economy	28000.00
0005434825927	5266	Economy	28000.00
0005434825982	5266	Economy	28000.00
0005435373602	5266	Economy	28000.00
0005435299815	5266	Economy	28000.00
0005434825883	5266	Economy	28000.00
0005434825899	5266	Economy	28000.00
0005435299829	5266	Economy	28000.00
0005432121600	5266	Economy	28000.00
0005434825929	5266	Economy	28000.00
0005435374094	5266	Economy	28000.00
0005434825931	5266	Economy	28000.00
0005434828747	5266	Economy	28000.00
0005434825892	5266	Economy	28000.00
0005434825861	5266	Economy	28000.00
0005434825894	5266	Economy	28000.00
0005434825924	5266	Economy	28000.00
0005434825919	5266	Economy	28000.00
0005434825949	5266	Economy	28000.00
0005434825886	5266	Economy	28000.00
0005432121589	5266	Economy	28000.00
0005435386616	5266	Economy	28000.00
0005434825909	5266	Economy	28000.00
0005434825981	5266	Economy	28000.00
0005435304199	5266	Economy	28000.00
0005435373814	5266	Economy	28000.00
0005432121593	5266	Economy	28000.00
0005434825945	5266	Economy	28000.00
0005435661968	5266	Economy	28000.00
0005432121596	5266	Economy	28000.00
0005435374069	5266	Economy	28000.00
0005434825898	5266	Economy	28000.00
0005435373650	5266	Economy	28000.00
0005434825920	5266	Economy	28000.00
0005434825970	5266	Economy	28000.00
0005434825857	5266	Economy	28000.00
0005435304206	5266	Economy	28000.00
0005434825971	5266	Economy	28000.00
0005432121595	5266	Economy	28000.00
0005434825969	5266	Economy	28000.00
0005434825958	5266	Economy	28000.00
0005434825910	5266	Economy	28000.00
0005434828746	5266	Economy	28000.00
0005434825978	5266	Economy	28000.00
0005434825944	5266	Economy	28000.00
0005434825880	5266	Economy	28000.00
0005434825868	5266	Economy	30800.00
0005434825902	5266	Economy	30800.00
0005434825932	5266	Economy	28000.00
0005434558430	5266	Economy	28000.00
0005435150285	5266	Economy	28000.00
0005435373601	5266	Economy	30800.00
0005434825972	5266	Economy	30800.00
0005434825976	5266	Economy	28000.00
0005435373856	5266	Economy	28000.00
0005432121591	5266	Economy	28000.00
0005434825867	5266	Economy	28000.00
0005434558432	5266	Economy	28000.00
0005434825903	5266	Economy	28000.00
0005435150288	5266	Economy	28000.00
0005434665002	5266	Economy	28000.00
0005434825878	5266	Economy	28000.00
0005434825858	5266	Economy	28000.00
0005434825875	5266	Economy	28000.00
0005435374128	5266	Economy	28000.00
0005434825917	5266	Economy	28000.00
0005434825863	5266	Economy	28000.00
0005434825943	5266	Economy	28000.00
0005434825876	5266	Economy	28000.00
0005435373662	5266	Economy	28000.00
0005435373865	5266	Economy	28000.00
0005434825918	5266	Economy	28000.00
0005434825889	5266	Economy	28000.00
0005434825955	5266	Economy	28000.00
0005435373607	5266	Economy	28000.00
0005435373773	5266	Economy	28000.00
0005434825893	5266	Economy	28000.00
0005435373981	5266	Economy	28000.00
0005435373709	5266	Economy	28000.00
0005435299807	5266	Economy	28000.00
0005434825891	5266	Economy	28000.00
0005434825906	5266	Economy	28000.00
0005434825934	5266	Economy	28000.00
0005435299813	5266	Economy	28000.00
0005435386639	5266	Economy	28000.00
0005432394179	5266	Economy	28000.00
0005432121597	5266	Economy	28000.00
0005432396315	5266	Economy	28000.00
0005435373849	5266	Economy	28000.00
0005435373638	5266	Economy	28000.00
0005434825912	5266	Economy	28000.00
0005432396313	5266	Economy	28000.00
0005435373843	5266	Economy	28000.00
0005434831233	5266	Economy	28000.00
0005434825983	5266	Economy	28000.00
0005434825962	5266	Economy	28000.00
0005434825968	5266	Economy	28000.00
0005434825908	5266	Economy	28000.00
0005434558431	5266	Economy	28000.00
0005434825870	5266	Economy	28000.00
0005435374037	5266	Economy	28000.00
0005434825913	5266	Economy	28000.00
0005434825953	5266	Economy	28000.00
0005432396314	5266	Economy	28000.00
0005435299808	5266	Economy	28000.00
0005435373734	5266	Economy	28000.00
0005434825888	5266	Economy	28000.00
0005434825859	5266	Economy	28000.00
0005435661969	5266	Economy	28000.00
0005434825940	5266	Economy	28000.00
0005432396316	5266	Economy	28000.00
0005434825901	5266	Economy	28000.00
0005434825897	5266	Economy	28000.00
0005434825904	5266	Economy	28000.00
0005435374038	5266	Economy	28000.00
0005434825960	5266	Economy	28000.00
0005434825947	5266	Economy	28000.00
0005434825935	5266	Economy	28000.00
0005435373636	5266	Economy	28000.00
0005435373778	5266	Economy	28000.00
0005434825975	5266	Economy	28000.00
0005434825874	5266	Economy	28000.00
0005434825885	5266	Economy	28000.00
0005434825974	5266	Economy	28000.00
0005434825915	5266	Economy	28000.00
0005434825923	5266	Economy	28000.00
0005434825964	5266	Economy	30800.00
0005435374005	5266	Economy	30800.00
0005435386644	5266	Economy	30800.00
0005435150281	5266	Economy	28000.00
0005435373866	5266	Economy	28000.00
0005434825946	5266	Economy	28000.00
0005434825896	5266	Economy	28000.00
0005432823473	5266	Economy	28000.00
0005435150286	5266	Economy	28000.00
0005435373912	5266	Economy	28000.00
0005432394178	5266	Economy	28000.00
0005435150291	5266	Economy	28000.00
0005434825950	5266	Economy	28000.00
0005435374147	5266	Economy	28000.00
0005434558433	5266	Economy	28000.00
0005435373610	5266	Economy	28000.00
0005435373564	5266	Economy	28000.00
0005432121598	5266	Economy	28000.00
0005435150280	5266	Economy	28000.00
0005434825871	5266	Economy	28000.00
0005435373998	5266	Economy	28000.00
0005434825973	5266	Economy	28000.00
0005434825877	5266	Economy	28000.00
0005434825900	5266	Economy	28000.00
0005435735182	5266	Economy	28000.00
0005434825984	5266	Economy	28000.00
0005432823468	5266	Economy	28000.00
0005435373657	5266	Economy	28000.00
0005434825921	5266	Economy	28000.00
0005432394180	5266	Economy	28000.00
0005434558428	5266	Economy	28000.00
0005432121599	5266	Economy	28000.00
0005434825872	5266	Economy	28000.00
0005435373665	5266	Economy	28000.00
0005434825977	5266	Economy	28000.00
0005434825864	5266	Economy	28000.00
0005435150289	5266	Economy	28000.00
0005434825967	5266	Economy	28000.00
0005434825911	5266	Economy	28000.00
0005435150292	5266	Economy	28000.00
0005434825866	5266	Economy	28000.00
0005435150287	5266	Economy	28000.00
0005435373661	5266	Economy	28000.00
0005432121590	5266	Economy	28000.00
0005435374022	5266	Economy	28000.00
0005435373851	5266	Economy	28000.00
0005434825907	5266	Economy	28000.00
0005432121594	5266	Economy	28000.00
0005435373958	5266	Economy	28000.00
0005435373997	5266	Economy	28000.00
0005435374054	5266	Economy	28000.00
0005435373899	5266	Economy	28000.00
0005432121588	5266	Economy	28000.00
0005434825966	5266	Economy	28000.00
0005434825961	5266	Economy	28000.00
0005434825914	5266	Economy	28000.00
0005434825965	5266	Economy	28000.00
0005435150284	5266	Economy	28000.00
0005435373852	5266	Economy	28000.00
0005434825865	5266	Economy	28000.00
0005435374151	5266	Economy	28000.00
0005434825936	5266	Economy	28000.00
0005434825938	5266	Economy	28000.00
0005435373848	5266	Economy	28000.00
0005435373697	5266	Economy	28000.00
0005435374113	5266	Economy	28000.00
0005434825963	5266	Economy	28000.00
0005434825905	5266	Economy	28000.00
0005434825873	5266	Economy	28000.00
0005434825952	5266	Economy	28000.00
0005434825869	5266	Economy	28000.00
0005435150282	5266	Economy	28000.00
0005432121592	5266	Economy	28000.00
0005434825887	5266	Economy	28000.00
0005434825985	5266	Economy	28000.00
0005434825979	5266	Economy	28000.00
0005434825930	5266	Economy	28000.00
0005434825895	5266	Economy	28000.00
0005435373875	5266	Economy	28000.00
0005434825957	5266	Economy	28000.00
0005434825882	5266	Economy	28000.00
0005435373898	5266	Economy	28000.00
0005434825916	5266	Economy	28000.00
0005434825856	5266	Economy	28000.00
0005435374039	5266	Economy	28000.00
0005434824095	9924	Business	84000.00
0005434825038	9924	Business	84000.00
0005434825249	9924	Business	84000.00
0005434825029	9924	Business	84000.00
0005435374479	9924	Business	84000.00
0005434824856	9924	Business	84000.00
0005434825258	9924	Business	84000.00
0005434824918	9924	Business	84000.00
0005435374443	9924	Business	84000.00
0005435374474	9924	Business	84000.00
0005434824356	9924	Business	84000.00
0005434824762	9924	Business	84000.00
0005434825267	9924	Business	84000.00
0005434558350	9924	Business	84000.00
0005435374459	9924	Business	84000.00
0005434825095	9924	Business	84000.00
0005432203195	9924	Business	84000.00
0005434558345	9924	Business	84000.00
0005435374492	9924	Business	84000.00
0005432203194	9924	Business	84000.00
0005435374481	9924	Business	84000.00
0005434828742	9924	Business	84000.00
0005435374434	9924	Business	84000.00
0005432400158	9924	Comfort	47600.00
0005434824693	9924	Comfort	47600.00
0005435314968	9924	Comfort	47600.00
0005434825279	9924	Comfort	47600.00
0005434824717	9924	Comfort	47600.00
0005434825321	9924	Comfort	47600.00
0005434824926	9924	Comfort	47600.00
0005435374478	9924	Comfort	47600.00
0005435374461	9924	Comfort	47600.00
0005435179703	9924	Comfort	47600.00
0005434824909	9924	Comfort	47600.00
0005434824750	9924	Comfort	47600.00
0005434824432	9924	Comfort	47600.00
0005434823958	9924	Comfort	47600.00
0005435374444	9924	Comfort	47600.00
0005435374439	9924	Comfort	47600.00
0005434824930	9924	Comfort	47600.00
0005435374437	9924	Comfort	47600.00
0005435150148	9924	Comfort	47600.00
0005434824919	9924	Comfort	47600.00
0005434824688	9924	Comfort	47600.00
0005434825158	9924	Comfort	47600.00
0005434824561	9924	Comfort	47600.00
0005435374465	9924	Comfort	47600.00
0005434824945	9924	Comfort	47600.00
0005434825147	9924	Comfort	47600.00
0005435386689	9924	Comfort	47600.00
0005435374480	9924	Comfort	47600.00
0005434831195	9924	Comfort	47600.00
0005434831216	9924	Comfort	47600.00
0005435374458	9924	Comfort	47600.00
0005435374469	9924	Comfort	47600.00
0005434824347	9924	Comfort	47600.00
0005435374431	9924	Comfort	47600.00
0005434558338	9924	Comfort	47600.00
0005434824816	9924	Comfort	47600.00
0005435374457	9924	Economy	28000.00
0005434824486	9924	Economy	28000.00
0005435374460	9924	Economy	28000.00
0005434824888	9924	Economy	28000.00
0005435299866	9924	Economy	28000.00
0005435374486	9924	Economy	28000.00
0005435374432	9924	Economy	28000.00
0005434823913	9924	Economy	28000.00
0005434824151	9924	Economy	28000.00
0005434558322	9924	Economy	28000.00
0005434824968	9924	Economy	28000.00
0005434824644	9924	Economy	28000.00
0005435374435	9924	Economy	28000.00
0005434824617	9924	Economy	28000.00
0005434824913	9924	Economy	28000.00
0005434824904	9924	Economy	28000.00
0005435374487	9924	Economy	28000.00
0005434824689	9924	Economy	28000.00
0005435374440	9924	Economy	28000.00
0005435314962	9924	Economy	28000.00
0005435386691	9924	Economy	28000.00
0005435735226	9924	Economy	28000.00
0005434825106	9924	Economy	28000.00
0005434823912	9924	Economy	28000.00
0005434825273	9924	Economy	28000.00
0005435299863	9924	Economy	28000.00
0005434824300	9924	Economy	28000.00
0005434824504	9924	Economy	28000.00
0005434824853	9924	Economy	28000.00
0005434824484	9924	Economy	28000.00
0005435374441	9924	Economy	28000.00
0005435314963	9924	Economy	28000.00
0005434824854	9924	Economy	28000.00
0005432396297	9924	Economy	28000.00
0005434558343	9924	Economy	28000.00
0005435150121	9924	Economy	28000.00
0005434824651	9924	Economy	28000.00
0005435735224	9924	Economy	28000.00
0005434824541	9924	Economy	28000.00
0005435374446	9924	Economy	28000.00
0005434824988	9924	Economy	28000.00
0005434824782	9924	Economy	28000.00
0005434824643	9924	Economy	28000.00
0005434824860	9924	Economy	28000.00
0005435374438	9924	Economy	28000.00
0005434825044	9924	Economy	28000.00
0005434825111	9924	Economy	28000.00
0005434824948	9924	Economy	28000.00
0005434825036	9924	Economy	28000.00
0005435374475	9924	Economy	30800.00
0005434825058	9924	Economy	30800.00
0005434825611	9924	Economy	28000.00
0005435374451	9924	Economy	28000.00
0005435374454	9924	Economy	28000.00
0005434824152	9924	Economy	28000.00
0005435374433	9924	Economy	30800.00
0005435374491	9924	Economy	30800.00
0005434828727	9924	Economy	28000.00
0005434824204	9924	Economy	28000.00
0005435299865	9924	Economy	28000.00
0005435302283	9924	Economy	28000.00
0005434825067	9924	Economy	28000.00
0005434824890	9924	Economy	28000.00
0005434825094	9924	Economy	28000.00
0005434824753	9924	Economy	28000.00
0005434825043	9924	Economy	28000.00
0005432203193	9924	Economy	28000.00
0005435302287	9924	Economy	28000.00
0005435150112	9924	Economy	28000.00
0005434824505	9924	Economy	28000.00
0005434558340	9924	Economy	28000.00
0005434824989	9924	Economy	28000.00
0005434831217	9924	Economy	28000.00
0005435314964	9924	Economy	28000.00
0005435314965	9924	Economy	28000.00
0005432203199	9924	Economy	28000.00
0005432823489	9924	Economy	28000.00
0005435661985	9924	Economy	28000.00
0005434824876	9924	Economy	28000.00
0005435179411	9924	Economy	28000.00
0005434824691	9924	Economy	28000.00
0005434825048	9924	Economy	28000.00
0005434824912	9924	Economy	28000.00
0005435374467	9924	Economy	28000.00
0005434824701	9924	Economy	28000.00
0005435374456	9924	Economy	28000.00
0005434824764	9924	Economy	28000.00
0005435735223	9924	Economy	28000.00
0005434824420	9924	Economy	28000.00
0005434825064	9924	Economy	28000.00
0005435314961	9924	Economy	28000.00
0005434831187	9924	Economy	28000.00
0005434824460	9924	Economy	28000.00
0005432396275	9924	Economy	28000.00
0005435386690	9924	Economy	28000.00
0005434823959	9924	Economy	28000.00
0005434824839	9924	Economy	28000.00
0005435374468	9924	Economy	28000.00
0005435314967	9924	Economy	28000.00
0005434825275	9924	Economy	28000.00
0005434824570	9924	Economy	28000.00
0005435374488	9924	Economy	28000.00
0005434825093	9924	Economy	28000.00
0005432203196	9924	Economy	28000.00
0005434824927	9924	Economy	28000.00
0005434824635	9924	Economy	28000.00
0005434825047	9924	Economy	28000.00
0005434824819	9924	Economy	28000.00
0005434824805	9924	Economy	28000.00
0005435374484	9924	Economy	28000.00
0005434824845	9924	Economy	28000.00
0005434825037	9924	Economy	28000.00
0005434824929	9924	Economy	28000.00
0005434825526	9924	Economy	28000.00
0005434824899	9924	Economy	28000.00
0005435299864	9924	Economy	28000.00
0005434824872	9924	Economy	28000.00
0005435374471	9924	Economy	28000.00
0005434824466	9924	Economy	28000.00
0005434824700	9924	Economy	28000.00
0005432396266	9924	Economy	28000.00
0005434824751	9924	Economy	28000.00
0005434664982	9924	Economy	28000.00
0005434824569	9924	Economy	28000.00
0005434825364	9924	Economy	28000.00
0005434824902	9924	Economy	28000.00
0005434824907	9924	Economy	28000.00
0005434824620	9924	Economy	28000.00
0005434824485	9924	Economy	28000.00
0005434825107	9924	Economy	28000.00
0005434824562	9924	Economy	28000.00
0005434824754	9924	Economy	28000.00
0005434824459	9924	Economy	28000.00
0005434824786	9924	Economy	28000.00
0005434824677	9924	Economy	28000.00
0005435314966	9924	Economy	28000.00
0005434825040	9924	Economy	28000.00
0005435386695	9924	Economy	28000.00
0005434825487	9924	Economy	28000.00
0005434825205	9924	Economy	28000.00
0005434825001	9924	Economy	28000.00
0005434824781	9924	Economy	28000.00
0005435386692	9924	Economy	28000.00
0005434824838	9924	Economy	28000.00
0005435374493	9924	Economy	28000.00
0005434824636	9924	Economy	28000.00
0005432203198	9924	Economy	28000.00
0005435374464	9924	Economy	28000.00
0005435374466	9924	Economy	28000.00
0005435374482	9924	Economy	28000.00
0005435735225	9924	Economy	28000.00
0005434825277	9924	Economy	28000.00
0005432823488	9924	Economy	28000.00
0005435179410	9924	Economy	30800.00
0005434824897	9924	Economy	28000.00
0005435374489	9924	Economy	30800.00
0005434824947	9924	Economy	30800.00
0005435374495	9924	Economy	28000.00
0005435386694	9924	Economy	28000.00
0005434824516	9924	Economy	28000.00
0005434824299	9924	Economy	28000.00
0005434824806	9924	Economy	28000.00
0005435302286	9924	Economy	28000.00
0005434825046	9924	Economy	28000.00
0005434825235	9924	Economy	28000.00
0005432396267	9924	Economy	28000.00
0005435374447	9924	Economy	28000.00
0005434824429	9924	Economy	28000.00
0005435374472	9924	Economy	28000.00
0005434824859	9924	Economy	28000.00
0005434825522	9924	Economy	28000.00
0005434825274	9924	Economy	28000.00
0005434824650	9924	Economy	28000.00
0005435374452	9924	Economy	28000.00
0005434824935	9924	Economy	28000.00
0005434825281	9924	Economy	28000.00
0005434824920	9924	Economy	28000.00
0005434824875	9924	Economy	28000.00
0005434824914	9924	Economy	28000.00
0005435374455	9924	Economy	28000.00
0005434824784	9924	Economy	28000.00
0005435374442	9924	Economy	28000.00
0005435374450	9924	Economy	28000.00
0005434825049	9924	Economy	28000.00
0005434825525	9924	Economy	28000.00
0005432396296	9924	Economy	28000.00
0005434825110	9924	Economy	28000.00
0005434824820	9924	Economy	28000.00
0005435374449	9924	Economy	28000.00
0005434825280	9924	Economy	28000.00
0005435374485	9924	Economy	28000.00
0005435302285	9924	Economy	28000.00
0005434824616	9924	Economy	28000.00
0005434824763	9924	Economy	28000.00
0005434824973	9924	Economy	28000.00
0005434824483	9924	Economy	28000.00
0005434824670	9924	Economy	28000.00
0005435299862	9924	Economy	28000.00
0005434824815	9924	Economy	28000.00
0005434824896	9924	Economy	28000.00
0005434823947	9924	Economy	28000.00
0005434825327	9924	Economy	28000.00
0005435374477	9924	Economy	28000.00
0005434825259	9924	Economy	28000.00
0005432203197	9924	Economy	28000.00
0005434824357	9924	Economy	28000.00
0005434824864	9924	Economy	28000.00
0005435374463	9924	Economy	28000.00
0005435374483	9924	Economy	28000.00
0005434824887	9924	Economy	28000.00
0005435374436	9924	Economy	28000.00
0005434824346	9924	Economy	28000.00
0005434824695	9924	Economy	28000.00
0005434824877	9924	Economy	28000.00
0005435374445	9924	Economy	28000.00
0005434824785	9924	Economy	28000.00
0005434824506	9924	Economy	28000.00
0005434824551	9924	Economy	28000.00
0005434825002	9924	Economy	28000.00
0005435374476	9924	Economy	28000.00
0005435661984	9924	Economy	28000.00
0005434824905	9924	Economy	28000.00
0005435374453	9924	Economy	28000.00
0005435374473	9924	Economy	28000.00
0005435150117	9924	Economy	28000.00
0005435374494	9924	Economy	28000.00
0005434825266	9924	Economy	28000.00
0005434825204	9924	Economy	28000.00
0005434824889	9924	Economy	28000.00
0005434825056	9924	Economy	28000.00
0005435374462	9924	Economy	28000.00
0005435179702	9924	Economy	28000.00
0005432396265	9924	Economy	28000.00
0005435374470	9924	Economy	28000.00
0005435150156	9924	Economy	28000.00
0005434824622	9924	Economy	28000.00
0005435302284	9924	Economy	28000.00
0005435374490	9924	Economy	28000.00
0005434824707	9924	Economy	28000.00
0005435150144	9924	Economy	28000.00
0005435386693	9924	Economy	28000.00
0005434824934	9924	Economy	28000.00
0005435661986	9924	Economy	28000.00
0005434825057	9924	Economy	28000.00
0005434824752	9924	Economy	28000.00
0005435374448	9924	Economy	28000.00
0005434824676	9924	Economy	28000.00
0005435082947	6990	Economy	8200.00
0005435082938	6990	Economy	8200.00
0005435790359	6990	Economy	7400.00
0005435082942	6990	Economy	7400.00
0005435790360	6990	Economy	7400.00
0005435790361	6990	Economy	7400.00
0005435082945	6990	Economy	7400.00
0005435082946	6990	Economy	7400.00
0005435082941	6990	Economy	7400.00
0005435082944	6990	Economy	7400.00
0005435082937	6990	Economy	7400.00
0005435082940	6990	Economy	7400.00
0005435082939	6990	Economy	7400.00
0005435082943	6990	Economy	7400.00
0005435790342	25996	Economy	8200.00
0005435790332	25996	Economy	7400.00
0005435082856	25996	Economy	7400.00
0005435082871	25996	Economy	7400.00
0005435082872	25996	Economy	7400.00
0005435082870	25996	Economy	7400.00
0005435790330	25996	Economy	7400.00
0005435082839	25996	Economy	7400.00
0005435082868	25996	Economy	7400.00
0005435790331	25996	Economy	7400.00
0005435790343	25996	Economy	7400.00
0005435790341	25996	Economy	7400.00
0005435082887	25996	Economy	7400.00
0005434214969	9513	Business	32800.00
0005434214856	9513	Business	32800.00
0005434757184	9513	Business	32800.00
0005434214960	9513	Business	32800.00
0005434757187	9513	Business	32800.00
0005434214885	9513	Business	32800.00
0005434215056	9513	Business	32800.00
0005434215034	9513	Business	32800.00
0005434757190	9513	Business	32800.00
0005434757191	9513	Business	32800.00
0005434215005	9513	Business	32800.00
0005434215099	9513	Business	32800.00
0005434214841	9513	Economy	10900.00
0005434215075	9513	Economy	10900.00
0005434757174	9513	Economy	10900.00
0005434214996	9513	Economy	10900.00
0005434214970	9513	Economy	10900.00
0005434214997	9513	Economy	10900.00
0005434214834	9513	Economy	10900.00
0005434215007	9513	Economy	10900.00
0005434215013	9513	Economy	10900.00
0005434757164	9513	Economy	10900.00
0005434757189	9513	Economy	12000.00
0005434215018	9513	Economy	12000.00
0005434757159	9513	Economy	12000.00
0005434757167	9513	Economy	12000.00
0005434215109	9513	Economy	10900.00
0005434214943	9513	Economy	10900.00
0005434214761	9513	Economy	10900.00
0005434757176	9513	Economy	10900.00
0005434757178	9513	Economy	10900.00
0005434214890	9513	Economy	10900.00
0005434214900	9513	Economy	10900.00
0005434757175	9513	Economy	10900.00
0005434214891	9513	Economy	10900.00
0005434215199	9513	Economy	10900.00
0005434757179	9513	Economy	10900.00
0005434214884	9513	Economy	10900.00
0005434757172	9513	Economy	10900.00
0005434214942	9513	Economy	10900.00
0005434214848	9513	Economy	10900.00
0005434215055	9513	Economy	10900.00
0005434757160	9513	Economy	10900.00
0005434757192	9513	Economy	10900.00
0005434757163	9513	Economy	10900.00
0005434214922	9513	Economy	10900.00
0005434214751	9513	Economy	10900.00
0005434757180	9513	Economy	10900.00
0005434214654	9513	Economy	10900.00
0005434215047	9513	Economy	10900.00
0005434757186	9513	Economy	10900.00
0005434214855	9513	Economy	10900.00
0005434757169	9513	Economy	10900.00
0005434215061	9513	Economy	10900.00
0005434215046	9513	Economy	10900.00
0005434757162	9513	Economy	10900.00
0005434757183	9513	Economy	10900.00
0005434757161	9513	Economy	10900.00
0005434214653	9513	Economy	10900.00
0005434757168	9513	Economy	10900.00
0005434214729	9513	Economy	10900.00
0005434757170	9513	Economy	10900.00
0005434214908	9513	Economy	10900.00
0005434215027	9513	Economy	10900.00
0005434757185	9513	Economy	10900.00
0005434757194	9513	Economy	10900.00
0005434215137	9513	Economy	10900.00
0005434757193	9513	Economy	10900.00
0005434757165	9513	Economy	10900.00
0005434757181	9513	Economy	10900.00
0005434215139	9513	Economy	10900.00
0005434757182	9513	Economy	10900.00
0005434215089	9513	Economy	10900.00
0005434214961	9513	Economy	10900.00
0005434215138	9513	Economy	10900.00
0005434757188	9513	Economy	10900.00
0005434214925	9513	Economy	10900.00
0005434215048	9513	Economy	10900.00
0005434757171	9513	Economy	10900.00
0005434214822	9513	Economy	10900.00
0005434214823	9513	Economy	10900.00
0005434215006	9513	Economy	10900.00
0005434757195	9513	Economy	10900.00
0005434757177	9513	Economy	10900.00
0005434757173	9513	Economy	10900.00
0005434214923	9513	Economy	10900.00
0005434757196	9513	Economy	10900.00
0005434757166	9513	Economy	10900.00
0005434215060	9513	Economy	10900.00
0005434214958	9513	Economy	10900.00
0005434756785	28607	Business	32800.00
0005434215348	28607	Business	32800.00
0005434756814	28607	Business	32800.00
0005434756612	28607	Business	32800.00
0005434756805	28607	Business	32800.00
0005434756812	28607	Business	32800.00
0005434215359	28607	Business	32800.00
0005434756678	28607	Business	32800.00
0005434756686	28607	Business	32800.00
0005434756677	28607	Business	32800.00
0005434756654	28607	Business	32800.00
0005434215360	28607	Economy	10900.00
0005434215318	28607	Economy	10900.00
0005434756815	28607	Economy	10900.00
0005434215319	28607	Economy	10900.00
0005434215345	28607	Economy	10900.00
0005434215358	28607	Economy	10900.00
0005434756459	28607	Economy	10900.00
0005434756804	28607	Economy	10900.00
0005434215347	28607	Economy	12000.00
0005434215357	28607	Economy	12000.00
0005434756729	28607	Economy	10900.00
0005434756685	28607	Economy	10900.00
0005434215355	28607	Economy	10900.00
0005434215349	28607	Economy	10900.00
0005434215336	28607	Economy	10900.00
0005434215327	28607	Economy	10900.00
0005434756783	28607	Economy	10900.00
0005434756476	28607	Economy	10900.00
0005434215334	28607	Economy	10900.00
0005434215343	28607	Economy	10900.00
0005434215322	28607	Economy	10900.00
0005434215341	28607	Economy	10900.00
0005434215329	28607	Economy	10900.00
0005434215351	28607	Economy	10900.00
0005434215342	28607	Economy	10900.00
0005434215356	28607	Economy	10900.00
0005434215340	28607	Economy	10900.00
0005434756782	28607	Economy	10900.00
0005434756648	28607	Economy	10900.00
0005434215335	28607	Economy	10900.00
0005434215361	28607	Economy	10900.00
0005434215317	28607	Economy	10900.00
0005434756728	28607	Economy	10900.00
0005434756531	28607	Economy	10900.00
0005434215337	28607	Economy	10900.00
0005434215332	28607	Economy	10900.00
0005434215331	28607	Economy	10900.00
0005434756770	28607	Economy	10900.00
0005434756607	28607	Economy	10900.00
0005434756828	28607	Economy	10900.00
0005434215323	28607	Economy	10900.00
0005434756633	28607	Economy	10900.00
0005434756761	28607	Economy	10900.00
0005434756880	28607	Economy	10900.00
0005434215346	28607	Economy	10900.00
0005434215324	28607	Economy	10900.00
0005434215321	28607	Economy	10900.00
0005434215352	28607	Economy	10900.00
0005434756542	28607	Economy	10900.00
0005434215344	28607	Economy	10900.00
0005434756548	28607	Economy	10900.00
0005434756813	28607	Economy	10900.00
0005434215354	28607	Economy	10900.00
0005434215326	28607	Economy	10900.00
0005434215325	28607	Economy	10900.00
0005434756528	28607	Economy	10900.00
0005434215362	28607	Economy	10900.00
0005434756784	28607	Economy	10900.00
0005434756532	28607	Economy	10900.00
0005434215339	28607	Economy	10900.00
0005434756474	28607	Economy	10900.00
0005434215353	28607	Economy	10900.00
0005434756737	28607	Economy	10900.00
0005434215338	28607	Economy	10900.00
0005434756786	28607	Economy	10900.00
0005434756769	28607	Economy	10900.00
0005434215316	28607	Economy	10900.00
0005434756744	28607	Economy	10900.00
0005434756743	28607	Economy	10900.00
0005434215333	28607	Economy	10900.00
0005434215330	28607	Economy	10900.00
0005434756611	28607	Economy	10900.00
0005434215320	28607	Economy	10900.00
0005434215328	28607	Economy	10900.00
0005434215350	28607	Economy	10900.00
0005434760227	10831	Economy	8900.00
0005434760225	10831	Economy	8900.00
0005435100178	10831	Economy	8900.00
0005435100179	10831	Economy	8900.00
0005434760228	10831	Economy	8900.00
0005434760243	31825	Economy	9800.00
0005435100162	31825	Economy	8900.00
0005434760242	31825	Economy	8900.00
0005435100163	31825	Economy	8900.00
0005434760241	31825	Economy	8900.00
0005434639798	1988	Economy	20900.00
0005434639815	1988	Economy	20900.00
0005435948349	1988	Economy	20900.00
0005434639786	1988	Economy	20900.00
0005433202451	1988	Economy	19000.00
0005434639803	1988	Economy	19000.00
0005435948347	1988	Economy	19000.00
0005434639794	1988	Economy	19000.00
0005434639807	1988	Economy	19000.00
0005434639793	1988	Economy	19000.00
0005434639797	1988	Economy	19000.00
0005433202443	1988	Economy	19000.00
0005434639801	1988	Economy	19000.00
0005434639804	1988	Economy	19000.00
0005434639802	1988	Economy	19000.00
0005434639814	1988	Economy	19000.00
0005435948348	1988	Economy	19000.00
0005433202492	1988	Economy	19000.00
0005434639809	1988	Economy	19000.00
0005434639810	1988	Economy	19000.00
0005434639791	1988	Economy	19000.00
0005434639790	1988	Economy	19000.00
0005434639788	1988	Economy	19000.00
0005434639805	1988	Economy	19000.00
0005434639813	1988	Economy	19000.00
0005433202506	1988	Economy	19000.00
0005433202460	1988	Economy	19000.00
0005434639796	1988	Economy	19000.00
0005434639787	1988	Economy	19000.00
0005434639800	1988	Economy	19000.00
0005432290692	1988	Economy	19000.00
0005434639812	1988	Economy	19000.00
0005433202444	1988	Economy	19000.00
0005434639806	1988	Economy	19000.00
0005434639795	1988	Economy	19000.00
0005433202494	1988	Economy	19000.00
0005434639808	1988	Economy	19000.00
0005434639811	1988	Economy	19000.00
0005433202461	1988	Economy	19000.00
0005433202521	1988	Economy	19000.00
0005434639789	1988	Economy	19000.00
0005432290691	1988	Economy	19000.00
0005435948350	1988	Economy	19000.00
0005434639792	1988	Economy	19000.00
0005433202507	1988	Economy	19000.00
0005433202495	1988	Economy	19000.00
0005434639799	1988	Economy	19000.00
0005433202496	1988	Economy	19000.00
0005433202493	1988	Economy	19000.00
0005433202625	23292	Economy	20900.00
0005434639503	23292	Economy	20900.00
0005433202623	23292	Economy	20900.00
0005434639504	23292	Economy	20900.00
0005433202615	23292	Economy	19000.00
0005434639595	23292	Economy	19000.00
0005434639522	23292	Economy	19000.00
0005433202624	23292	Economy	19000.00
0005433202627	23292	Economy	19000.00
0005433202616	23292	Economy	19000.00
0005434639548	23292	Economy	19000.00
0005433202619	23292	Economy	19000.00
0005433202629	23292	Economy	19000.00
0005433202621	23292	Economy	19000.00
0005434639479	23292	Economy	19000.00
0005434639523	23292	Economy	19000.00
0005433202628	23292	Economy	19000.00
0005434639600	23292	Economy	19000.00
0005434639546	23292	Economy	19000.00
0005434639409	23292	Economy	19000.00
0005434639505	23292	Economy	19000.00
0005433202618	23292	Economy	19000.00
0005433202622	23292	Economy	19000.00
0005433202626	23292	Economy	19000.00
0005434639571	23292	Economy	19000.00
0005433202617	23292	Economy	19000.00
0005434639506	23292	Economy	19000.00
0005433202620	23292	Economy	19000.00
0005434601308	6088	Business	69700.00
0005432111332	6088	Business	69700.00
0005434601309	6088	Business	69700.00
0005432111334	6088	Business	69700.00
0005434601307	6088	Business	69700.00
0005433531364	6088	Business	69700.00
0005433531363	6088	Business	69700.00
0005434601299	6088	Economy	23200.00
0005435326905	6088	Economy	23200.00
0005434601311	6088	Economy	23200.00
0005434601315	6088	Economy	23200.00
0005434601310	6088	Economy	23200.00
0005435326879	6088	Economy	25600.00
0005435326878	6088	Economy	25600.00
0005434601293	6088	Economy	23200.00
0005435326874	6088	Economy	23200.00
0005434601319	6088	Economy	23200.00
0005434601305	6088	Economy	23200.00
0005434601304	6088	Economy	23200.00
0005434601306	6088	Economy	23200.00
0005433533378	6088	Economy	23200.00
0005435326893	6088	Economy	23200.00
0005434601297	6088	Economy	23200.00
0005434601313	6088	Economy	23200.00
0005434601312	6088	Economy	23200.00
0005435326860	6088	Economy	23200.00
0005435326819	6088	Economy	23200.00
0005434601301	6088	Economy	23200.00
0005434601294	6088	Economy	23200.00
0005434601300	6088	Economy	23200.00
0005434601295	6088	Economy	23200.00
0005433533379	6088	Economy	23200.00
0005434601302	6088	Economy	23200.00
0005434601317	6088	Economy	23200.00
0005432111333	6088	Economy	23200.00
0005435326914	6088	Economy	23200.00
0005434601314	6088	Economy	23200.00
0005434601318	6088	Economy	23200.00
0005434601298	6088	Economy	23200.00
0005434601296	6088	Economy	23200.00
0005435326965	6088	Economy	23200.00
0005435326892	6088	Economy	23200.00
0005433531365	6088	Economy	23200.00
0005435326960	6088	Economy	23200.00
0005435326877	6088	Economy	23200.00
0005434601303	6088	Economy	23200.00
0005435326904	6088	Economy	23200.00
0005434601316	6088	Economy	23200.00
0005435326917	6088	Economy	23200.00
0005435326994	18607	Business	69700.00
0005434601125	18607	Business	69700.00
0005435327008	18607	Business	69700.00
0005433531328	18607	Business	69700.00
0005434601109	18607	Business	69700.00
0005434600913	18607	Economy	23200.00
0005435327006	18607	Economy	23200.00
0005435326996	18607	Economy	23200.00
0005434601069	18607	Economy	23200.00
0005434600992	18607	Economy	23200.00
0005434601092	18607	Economy	23200.00
0005434601091	18607	Economy	23200.00
0005434601098	18607	Economy	25600.00
0005435326993	18607	Economy	25600.00
0005435327001	18607	Economy	23200.00
0005434601099	18607	Economy	23200.00
0005435327003	18607	Economy	23200.00
0005433531319	18607	Economy	23200.00
0005434600963	18607	Economy	23200.00
0005433531326	18607	Economy	23200.00
0005435327000	18607	Economy	23200.00
0005433527298	18607	Economy	23200.00
0005434601068	18607	Economy	23200.00
0005433531320	18607	Economy	23200.00
0005434601086	18607	Economy	23200.00
0005434601066	18607	Economy	23200.00
0005435327004	18607	Economy	23200.00
0005435326999	18607	Economy	23200.00
0005435326998	18607	Economy	23200.00
0005434601119	18607	Economy	23200.00
0005435326995	18607	Economy	23200.00
0005433527289	18607	Economy	23200.00
0005434601026	18607	Economy	23200.00
0005433531321	18607	Economy	23200.00
0005434600994	18607	Economy	23200.00
0005434601116	18607	Economy	23200.00
0005434601153	18607	Economy	23200.00
0005434601170	18607	Economy	23200.00
0005434601008	18607	Economy	23200.00
0005434601003	18607	Economy	23200.00
0005435326997	18607	Economy	23200.00
0005433531330	18607	Economy	23200.00
0005434601095	18607	Economy	23200.00
0005435327007	18607	Economy	23200.00
0005434601096	18607	Economy	23200.00
0005435327002	18607	Economy	23200.00
0005433527290	18607	Economy	23200.00
0005434601152	18607	Economy	23200.00
0005434601093	18607	Economy	23200.00
0005433527291	18607	Economy	23200.00
0005434601117	18607	Economy	23200.00
0005433531329	18607	Economy	23200.00
0005434601002	18607	Economy	23200.00
0005433531318	18607	Economy	23200.00
0005435327005	18607	Economy	23200.00
0005434601059	18607	Economy	23200.00
0005434601120	18607	Economy	23200.00
0005433181219	10619	Business	9100.00
0005433181324	10619	Business	9100.00
0005434552207	10619	Business	9100.00
0005434552182	10619	Business	9100.00
0005434552164	10619	Business	9100.00
0005434552203	10619	Business	9100.00
0005434552172	10619	Business	9100.00
0005434552218	10619	Business	9100.00
0005434552194	10619	Business	9100.00
0005433181312	10619	Business	9100.00
0005433181343	10619	Business	9100.00
0005434552185	10619	Business	9100.00
0005433181415	10619	Economy	3000.00
0005433181358	10619	Economy	3000.00
0005433181311	10619	Economy	3000.00
0005434552171	10619	Economy	3000.00
0005434552198	10619	Economy	3000.00
0005433181287	10619	Economy	3000.00
0005434552191	10619	Economy	3000.00
0005433181217	10619	Economy	3000.00
0005433181336	10619	Economy	3000.00
0005434552188	10619	Economy	3000.00
0005434552206	10619	Economy	3300.00
0005434552184	10619	Economy	3300.00
0005434552165	10619	Economy	3300.00
0005434552192	10619	Economy	3300.00
0005434552197	10619	Economy	3000.00
0005434554102	10619	Economy	3000.00
0005434552214	10619	Economy	3000.00
0005433181395	10619	Economy	3000.00
0005433181281	10619	Economy	3000.00
0005434552181	10619	Economy	3000.00
0005433181398	10619	Economy	3000.00
0005433181352	10619	Economy	3000.00
0005433181342	10619	Economy	3000.00
0005434552211	10619	Economy	3000.00
0005434552199	10619	Economy	3000.00
0005434552216	10619	Economy	3000.00
0005433181337	10619	Economy	3000.00
0005433181247	10619	Economy	3000.00
0005434552204	10619	Economy	3000.00
0005434554101	10619	Economy	3000.00
0005434552210	10619	Economy	3000.00
0005434552202	10619	Economy	3000.00
0005434552212	10619	Economy	3000.00
0005433181418	10619	Economy	3000.00
0005434552201	10619	Economy	3000.00
0005434552187	10619	Economy	3000.00
0005433181248	10619	Economy	3000.00
0005434552193	10619	Economy	3000.00
0005434552217	10619	Economy	3000.00
0005434552200	10619	Economy	3000.00
0005434552174	10619	Economy	3000.00
0005434552168	10619	Economy	3000.00
0005433181335	10619	Economy	3000.00
0005434552196	10619	Economy	3000.00
0005433181414	10619	Economy	3000.00
0005433181220	10619	Economy	3000.00
0005434552208	10619	Economy	3000.00
0005433181288	10619	Economy	3000.00
0005434552183	10619	Economy	3000.00
0005433181279	10619	Economy	3000.00
0005433181301	10619	Economy	3000.00
0005433181382	10619	Economy	3000.00
0005434552213	10619	Economy	3000.00
0005433181397	10619	Economy	3000.00
0005433181340	10619	Economy	3000.00
0005433181381	10619	Economy	3000.00
0005434552215	10619	Economy	3000.00
0005434552173	10619	Economy	3000.00
0005434552170	10619	Economy	3000.00
0005434552169	10619	Economy	3000.00
0005433181280	10619	Economy	3000.00
0005434552177	10619	Economy	3000.00
0005434552186	10619	Economy	3000.00
0005434552167	10619	Economy	3000.00
0005433181410	10619	Economy	3000.00
0005434552189	10619	Economy	3000.00
0005434552205	10619	Economy	3000.00
0005433181341	10619	Economy	3000.00
0005433181317	10619	Economy	3000.00
0005433181357	10619	Economy	3000.00
0005433181310	10619	Economy	3000.00
0005434552178	10619	Economy	3000.00
0005434552209	10619	Economy	3000.00
0005434552166	10619	Economy	3000.00
0005434552179	10619	Economy	3000.00
0005434552163	10619	Economy	3000.00
0005433181218	10619	Economy	3000.00
0005433181361	10619	Economy	3000.00
0005434552195	10619	Economy	3000.00
0005434552162	10619	Economy	3000.00
0005434552190	10619	Economy	3000.00
0005434552176	10619	Economy	3000.00
0005434552175	10619	Economy	3000.00
0005434552180	10619	Economy	3000.00
0005435314967	27739	Business	9100.00
0005433181575	27739	Business	9100.00
0005433181571	27739	Business	9100.00
0005435314968	27739	Economy	3000.00
0005433181578	27739	Economy	3000.00
0005433181574	27739	Economy	3000.00
0005433181561	27739	Economy	3300.00
0005433181556	27739	Economy	3300.00
0005433181566	27739	Economy	3000.00
0005435314963	27739	Economy	3000.00
0005435314966	27739	Economy	3000.00
0005435314962	27739	Economy	3000.00
0005433181555	27739	Economy	3000.00
0005435314961	27739	Economy	3000.00
0005433181579	27739	Economy	3000.00
0005433181577	27739	Economy	3000.00
0005433181560	27739	Economy	3000.00
0005433181562	27739	Economy	3000.00
0005435314965	27739	Economy	3000.00
0005433181572	27739	Economy	3000.00
0005433181558	27739	Economy	3000.00
0005433181563	27739	Economy	3000.00
0005433181576	27739	Economy	3000.00
0005433181568	27739	Economy	3000.00
0005433181554	27739	Economy	3000.00
0005433181567	27739	Economy	3000.00
0005433181570	27739	Economy	3000.00
0005433181557	27739	Economy	3000.00
0005433181573	27739	Economy	3000.00
0005433181564	27739	Economy	3000.00
0005433181569	27739	Economy	3000.00
0005433181559	27739	Economy	3000.00
0005435314964	27739	Economy	3000.00
0005433181565	27739	Economy	3000.00
0005434551483	27737	Business	9100.00
0005434558363	27737	Business	9100.00
0005434551628	27737	Business	9100.00
0005434558395	27737	Business	9100.00
0005434551839	27737	Business	9100.00
0005434558405	27737	Business	9100.00
0005434551816	27737	Economy	3000.00
0005434558335	27737	Economy	3000.00
0005434551911	27737	Economy	3000.00
0005434551544	27737	Economy	3000.00
0005434551662	27737	Economy	3000.00
0005434551910	27737	Economy	3300.00
0005434551846	27737	Economy	3300.00
0005434551629	27737	Economy	3300.00
0005434558312	27737	Economy	3000.00
0005434551706	27737	Economy	3000.00
0005434551654	27737	Economy	3000.00
0005434558347	27737	Economy	3000.00
0005434551912	27737	Economy	3000.00
0005434551866	27737	Economy	3000.00
0005434558374	27737	Economy	3000.00
0005434558336	27737	Economy	3000.00
0005434558383	27737	Economy	3000.00
0005434551867	27737	Economy	3000.00
0005434551862	27737	Economy	3000.00
0005434558382	27737	Economy	3000.00
0005434551533	27737	Economy	3000.00
0005434551899	27737	Economy	3000.00
0005434558348	27737	Economy	3000.00
0005434551660	27737	Economy	3000.00
0005434551795	27737	Economy	3000.00
0005434551861	27737	Economy	3000.00
0005434551817	27737	Economy	3000.00
0005434551827	27737	Economy	3000.00
0005434551736	27737	Economy	3000.00
0005434551468	27737	Economy	3000.00
0005434558351	27737	Economy	3000.00
0005434558364	27737	Economy	3000.00
0005434551656	27737	Economy	3000.00
0005434558329	27737	Economy	3000.00
0005434552027	27737	Economy	3000.00
0005434552026	27737	Economy	3000.00
0005434554088	27737	Economy	3000.00
0005434551624	27737	Economy	3000.00
0005434551994	27737	Economy	3000.00
0005434551745	27737	Economy	3000.00
0005434558385	27737	Economy	3000.00
0005434551883	27737	Economy	3000.00
0005434558398	27737	Economy	3000.00
0005434558355	27737	Economy	3000.00
0005434551661	27737	Economy	3000.00
0005434554082	27737	Economy	3000.00
0005433459297	6126	Economy	11700.00
0005435254498	6126	Economy	11700.00
0005433459298	6126	Economy	11700.00
0005435254502	6126	Economy	11700.00
0005435254497	6126	Economy	11700.00
0005433459299	6126	Economy	11700.00
0005433459269	19304	Economy	11700.00
0005433459270	19304	Economy	11700.00
0005435254518	19304	Economy	11700.00
0005435254519	19304	Economy	11700.00
0005435682887	6745	Business	51100.00
0005435682895	6745	Business	51100.00
0005435438152	6745	Business	51100.00
0005435682903	6745	Business	51100.00
0005435682905	6745	Business	51100.00
0005435217735	6745	Business	51100.00
0005435438214	6745	Business	51100.00
0005435719583	6745	Business	51100.00
0005435438179	6745	Business	51100.00
0005435682870	6745	Business	51100.00
0005435217719	6745	Business	51100.00
0005434828733	6745	Business	51100.00
0005432136260	6745	Economy	17000.00
0005432136262	6745	Economy	17000.00
0005435682885	6745	Economy	17000.00
0005435682860	6745	Economy	17000.00
0005432533310	6745	Economy	17000.00
0005435719584	6745	Economy	17000.00
0005435438229	6745	Economy	17000.00
0005434828729	6745	Economy	17000.00
0005435682889	6745	Economy	17000.00
0005435631021	6745	Economy	17000.00
0005435438100	6745	Economy	18700.00
0005435682864	6745	Economy	18700.00
0005435438226	6745	Economy	18700.00
0005435682865	6745	Economy	18700.00
0005435682886	6745	Economy	18700.00
0005435682896	6745	Economy	17000.00
0005435682862	6745	Economy	17000.00
0005435682900	6745	Economy	17000.00
0005435682888	6745	Economy	17000.00
0005432533311	6745	Economy	17000.00
0005435682877	6745	Economy	17000.00
0005435438225	6745	Economy	17000.00
0005435682880	6745	Economy	17000.00
0005435682882	6745	Economy	17000.00
0005435438101	6745	Economy	17000.00
0005435682891	6745	Economy	17000.00
0005435682872	6745	Economy	17000.00
0005435682861	6745	Economy	17000.00
0005435661983	6745	Economy	17000.00
0005432533316	6745	Economy	17000.00
0005435682897	6745	Economy	17000.00
0005435682869	6745	Economy	17000.00
0005435682879	6745	Economy	17000.00
0005435438234	6745	Economy	17000.00
0005435438247	6745	Economy	17000.00
0005435438230	6745	Economy	17000.00
0005435682894	6745	Economy	17000.00
0005435438177	6745	Economy	17000.00
0005435217734	6745	Economy	17000.00
0005435438220	6745	Economy	17000.00
0005435682884	6745	Economy	17000.00
0005435438188	6745	Economy	17000.00
0005435682873	6745	Economy	17000.00
0005435682890	6745	Economy	17000.00
0005435682868	6745	Economy	17000.00
0005435217736	6745	Economy	17000.00
0005435661981	6745	Economy	17000.00
0005435682883	6745	Economy	17000.00
0005435438231	6745	Economy	17000.00
0005435438227	6745	Economy	17000.00
0005435682898	6745	Economy	17000.00
0005435682901	6745	Economy	17000.00
0005435217720	6745	Economy	17000.00
0005435682874	6745	Economy	17000.00
0005435438248	6745	Economy	17000.00
0005435438121	6745	Economy	17000.00
0005435682893	6745	Economy	17000.00
0005435661982	6745	Economy	17000.00
0005435682881	6745	Economy	17000.00
0005435438274	6745	Economy	17000.00
0005435631022	6745	Economy	17000.00
0005435682878	6745	Economy	17000.00
0005435682876	6745	Economy	17000.00
0005435682867	6745	Economy	17000.00
0005435438258	6745	Economy	17000.00
0005435220336	6745	Economy	17000.00
0005435438153	6745	Economy	17000.00
0005435438232	6745	Economy	17000.00
0005432136261	6745	Economy	17000.00
0005435438221	6745	Economy	17000.00
0005435682871	6745	Economy	17000.00
0005435438178	6745	Economy	17000.00
0005435682875	6745	Economy	17000.00
0005432533313	6745	Economy	17000.00
0005435682863	6745	Economy	17000.00
0005435682866	6745	Economy	17000.00
0005435682902	6745	Economy	17000.00
0005435682892	6745	Economy	17000.00
0005432136259	6745	Economy	17000.00
0005435682904	6745	Economy	17000.00
0005434828714	6745	Economy	17000.00
0005435220341	6745	Economy	17000.00
0005435682899	6745	Economy	17000.00
0005435438269	6745	Economy	17000.00
0005434828748	24596	Business	51100.00
0005435682622	24596	Business	51100.00
0005435631007	24596	Business	51100.00
0005435438352	24596	Business	51100.00
0005435438359	24596	Business	51100.00
0005435682525	24596	Business	51100.00
0005435682506	24596	Business	51100.00
0005435682510	24596	Business	51100.00
0005435682471	24596	Business	51100.00
0005435682550	24596	Business	51100.00
0005435438351	24596	Business	51100.00
0005435682515	24596	Business	51100.00
0005435438364	24596	Economy	17000.00
0005435438361	24596	Economy	17000.00
0005435438348	24596	Economy	17000.00
0005435438362	24596	Economy	17000.00
0005435682447	24596	Economy	17000.00
0005435438355	24596	Economy	17000.00
0005435682472	24596	Economy	17000.00
0005432305794	24596	Economy	17000.00
0005435682415	24596	Economy	17000.00
0005435682608	24596	Economy	17000.00
0005435682335	24596	Economy	18700.00
0005435631006	24596	Economy	18700.00
0005435682564	24596	Economy	18700.00
0005435682442	24596	Economy	18700.00
0005435682687	24596	Economy	17000.00
0005432533343	24596	Economy	17000.00
0005435630999	24596	Economy	17000.00
0005435438358	24596	Economy	17000.00
0005435661964	24596	Economy	17000.00
0005435438356	24596	Economy	17000.00
0005435438369	24596	Economy	17000.00
0005435438368	24596	Economy	17000.00
0005435682559	24596	Economy	17000.00
0005435682607	24596	Economy	17000.00
0005435682518	24596	Economy	17000.00
0005435682561	24596	Economy	17000.00
0005435438366	24596	Economy	17000.00
0005435682519	24596	Economy	17000.00
0005435682566	24596	Economy	17000.00
0005435682514	24596	Economy	17000.00
0005435682517	24596	Economy	17000.00
0005435631008	24596	Economy	17000.00
0005435438357	24596	Economy	17000.00
0005435438360	24596	Economy	17000.00
0005435438363	24596	Economy	17000.00
0005432533344	24596	Economy	17000.00
0005435682596	24596	Economy	17000.00
0005435682499	24596	Economy	17000.00
0005435682326	24596	Economy	17000.00
0005435438353	24596	Economy	17000.00
0005435682334	24596	Economy	17000.00
0005435438347	24596	Economy	17000.00
0005435682568	24596	Economy	17000.00
0005434828750	24596	Economy	17000.00
0005435661943	24596	Economy	17000.00
0005435630998	24596	Economy	17000.00
0005434828749	24596	Economy	17000.00
0005435682410	24596	Economy	17000.00
0005435682686	24596	Economy	17000.00
0005435682505	24596	Economy	17000.00
0005435438349	24596	Economy	17000.00
0005435682483	24596	Economy	17000.00
0005435682494	24596	Economy	17000.00
0005435682526	24596	Economy	17000.00
0005435661942	24596	Economy	17000.00
0005435438367	24596	Economy	17000.00
0005435682545	24596	Economy	17000.00
0005435682493	24596	Economy	17000.00
0005435682632	24596	Economy	17000.00
0005435682470	24596	Economy	17000.00
0005435682530	24596	Economy	17000.00
0005435682692	24596	Economy	17000.00
0005435682580	24596	Economy	17000.00
0005435682431	24596	Economy	17000.00
0005435682448	24596	Economy	17000.00
0005435682527	24596	Economy	17000.00
0005435438365	24596	Economy	17000.00
0005435682443	24596	Economy	17000.00
0005435438354	24596	Economy	17000.00
0005435682343	24596	Economy	17000.00
0005435682691	24596	Economy	17000.00
0005432305793	24596	Economy	17000.00
0005432533345	24596	Economy	17000.00
0005435682392	24596	Economy	17000.00
0005435438350	24596	Economy	17000.00
0005435682543	24596	Economy	17000.00
0005435127096	11541	Business	26400.00
0005435127067	11541	Business	26400.00
0005435127063	11541	Business	26400.00
0005435127079	11541	Business	26400.00
0005435127103	11541	Economy	8800.00
0005435127093	11541	Economy	8800.00
0005435127100	11541	Economy	8800.00
0005435127092	11541	Economy	8800.00
0005435127087	11541	Economy	8800.00
0005435558114	11541	Economy	9700.00
0005435127070	11541	Economy	9700.00
0005435127095	11541	Economy	9700.00
0005435127066	11541	Economy	9700.00
0005435127076	11541	Economy	8800.00
0005435106039	11541	Economy	8800.00
0005435106038	11541	Economy	8800.00
0005435127104	11541	Economy	8800.00
0005435127082	11541	Economy	8800.00
0005435127074	11541	Economy	8800.00
0005435127099	11541	Economy	8800.00
0005435127069	11541	Economy	8800.00
0005435127089	11541	Economy	8800.00
0005435127094	11541	Economy	8800.00
0005435127090	11541	Economy	8800.00
0005435127068	11541	Economy	8800.00
0005435127072	11541	Economy	8800.00
0005435127085	11541	Economy	8800.00
0005435127084	11541	Economy	8800.00
0005435127081	11541	Economy	8800.00
0005435127075	11541	Economy	8800.00
0005435127101	11541	Economy	8800.00
0005435127065	11541	Economy	8800.00
0005435127102	11541	Economy	8800.00
0005435127080	11541	Economy	8800.00
0005435127098	11541	Economy	8800.00
0005435127071	11541	Economy	8800.00
0005435127086	11541	Economy	8800.00
0005435127091	11541	Economy	8800.00
0005435127064	11541	Economy	8800.00
0005435127083	11541	Economy	8800.00
0005435127073	11541	Economy	8800.00
0005435127097	11541	Economy	8800.00
0005435127077	11541	Economy	8800.00
0005435127078	11541	Economy	8800.00
0005435127088	11541	Economy	8800.00
0005435558136	31852	Business	26400.00
0005435558135	31852	Business	26400.00
0005435126567	31852	Business	26400.00
0005435126620	31852	Business	26400.00
0005435126793	31852	Business	26400.00
0005435098582	31852	Economy	8800.00
0005435106018	31852	Economy	8800.00
0005435126742	31852	Economy	8800.00
0005435126812	31852	Economy	8800.00
0005435106015	31852	Economy	9700.00
0005435126754	31852	Economy	8800.00
0005435106016	31852	Economy	8800.00
0005435126820	31852	Economy	8800.00
0005435126710	31852	Economy	8800.00
0005435126815	31852	Economy	8800.00
0005435106019	31852	Economy	8800.00
0005435126937	31852	Economy	8800.00
0005435126800	31852	Economy	8800.00
0005435126825	31852	Economy	8800.00
0005435126811	31852	Economy	8800.00
0005435126688	31852	Economy	8800.00
0005435558134	31852	Economy	8800.00
0005435126621	31852	Economy	8800.00
0005435098571	31852	Economy	8800.00
0005435126739	31852	Economy	8800.00
0005435126704	31852	Economy	8800.00
0005435126622	31852	Economy	8800.00
0005435126741	31852	Economy	8800.00
0005435126697	31852	Economy	8800.00
0005435126892	31852	Economy	8800.00
0005435106021	31852	Economy	8800.00
0005435106020	31852	Economy	8800.00
0005435098581	31852	Economy	8800.00
0005435098573	31852	Economy	8800.00
0005435126705	31852	Economy	8800.00
0005435126700	31852	Economy	8800.00
0005435106000	31852	Economy	8800.00
0005435106001	31852	Economy	8800.00
0005435106017	31852	Economy	8800.00
0005433398941	13551	Business	36600.00
0005433398960	13551	Business	36600.00
0005433398946	13551	Business	36600.00
0005433398920	13551	Business	36600.00
0005433398949	13551	Business	36600.00
0005433398962	13551	Business	36600.00
0005433398955	13551	Business	36600.00
0005435732441	13551	Business	36600.00
0005433398954	13551	Business	36600.00
0005433398923	13551	Economy	12200.00
0005433398948	13551	Economy	12200.00
0005433398943	13551	Economy	12200.00
0005435732410	13551	Economy	12200.00
0005435732449	13551	Economy	12200.00
0005433398935	13551	Economy	13400.00
0005433398959	13551	Economy	13400.00
0005435732485	13551	Economy	13400.00
0005433398961	13551	Economy	13400.00
0005433398931	13551	Economy	12200.00
0005433398927	13551	Economy	12200.00
0005433398947	13551	Economy	12200.00
0005433398924	13551	Economy	12200.00
0005433398928	13551	Economy	12200.00
0005433398944	13551	Economy	12200.00
0005435732428	13551	Economy	12200.00
0005435732504	13551	Economy	12200.00
0005433398956	13551	Economy	12200.00
0005433398926	13551	Economy	12200.00
0005433398933	13551	Economy	12200.00
0005433398932	13551	Economy	12200.00
0005433398957	13551	Economy	12200.00
0005435732433	13551	Economy	12200.00
0005435732424	13551	Economy	12200.00
0005433398951	13551	Economy	12200.00
0005433398930	13551	Economy	12200.00
0005433398953	13551	Economy	12200.00
0005433398938	13551	Economy	12200.00
0005435732430	13551	Economy	12200.00
0005433398966	13551	Economy	12200.00
0005433398967	13551	Economy	12200.00
0005433398950	13551	Economy	12200.00
0005433398939	13551	Economy	12200.00
0005433398958	13551	Economy	12200.00
0005433398937	13551	Economy	12200.00
0005433398940	13551	Economy	12200.00
0005433398929	13551	Economy	12200.00
0005433398963	13551	Economy	12200.00
0005435732411	13551	Economy	12200.00
0005433398934	13551	Economy	12200.00
0005433398921	13551	Economy	12200.00
0005433398964	13551	Economy	12200.00
0005433398922	13551	Economy	12200.00
0005433398936	13551	Economy	12200.00
0005433398952	13551	Economy	12200.00
0005433398945	13551	Economy	12200.00
0005435732429	13551	Economy	12200.00
0005433398925	13551	Economy	12200.00
0005435732448	13551	Economy	12200.00
0005433398942	13551	Economy	12200.00
0005435732431	13551	Economy	12200.00
0005433398919	13551	Economy	12200.00
0005433398965	13551	Economy	12200.00
0005433398528	19368	Business	36600.00
0005433398314	19368	Business	36600.00
0005433398406	19368	Business	36600.00
0005433398505	19368	Business	36600.00
0005433398555	19368	Business	36600.00
0005435732556	19368	Business	36600.00
0005433398676	19368	Business	36600.00
0005433398290	19368	Business	36600.00
0005433398578	19368	Business	36600.00
0005435732554	19368	Business	36600.00
0005433398645	19368	Business	36600.00
0005433398485	19368	Economy	12200.00
0005433398610	19368	Economy	12200.00
0005433398620	19368	Economy	12200.00
0005433398367	19368	Economy	12200.00
0005435732557	19368	Economy	13400.00
0005433398311	19368	Economy	13400.00
0005433398442	19368	Economy	13400.00
0005433398443	19368	Economy	13400.00
0005435732566	19368	Economy	13400.00
0005435732563	19368	Economy	12200.00
0005433398675	19368	Economy	12200.00
0005433398449	19368	Economy	12200.00
0005433398461	19368	Economy	12200.00
0005433398710	19368	Economy	12200.00
0005433398646	19368	Economy	12200.00
0005433398465	19368	Economy	12200.00
0005433398407	19368	Economy	12200.00
0005433398495	19368	Economy	12200.00
0005435732565	19368	Economy	12200.00
0005433398577	19368	Economy	12200.00
0005433398473	19368	Economy	12200.00
0005435732559	19368	Economy	12200.00
0005433398450	19368	Economy	12200.00
0005433398512	19368	Economy	12200.00
0005433398416	19368	Economy	12200.00
0005433398408	19368	Economy	12200.00
0005433398496	19368	Economy	12200.00
0005433398343	19368	Economy	12200.00
0005433398458	19368	Economy	12200.00
0005433398527	19368	Economy	12200.00
0005435732555	19368	Economy	12200.00
0005433398619	19368	Economy	12200.00
0005433398523	19368	Economy	12200.00
0005433398487	19368	Economy	12200.00
0005433398457	19368	Economy	12200.00
0005435732553	19368	Economy	12200.00
0005433398650	19368	Economy	12200.00
0005435732562	19368	Economy	12200.00
0005433398486	19368	Economy	12200.00
0005433398466	19368	Economy	12200.00
0005435732564	19368	Economy	12200.00
0005433398699	19368	Economy	12200.00
0005433398709	19368	Economy	12200.00
0005433398481	19368	Economy	12200.00
0005433398511	19368	Economy	12200.00
0005433398612	19368	Economy	12200.00
0005433398677	19368	Economy	12200.00
0005435732561	19368	Economy	12200.00
0005433398405	19368	Economy	12200.00
0005435732560	19368	Economy	12200.00
0005433398480	19368	Economy	12200.00
0005433398700	19368	Economy	12200.00
0005433398621	19368	Economy	12200.00
0005433398591	19368	Economy	12200.00
0005433398609	19368	Economy	12200.00
0005433398327	19368	Economy	12200.00
0005435732558	19368	Economy	12200.00
0005435069460	13143	Business	11300.00
0005435925552	13143	Business	11300.00
0005435069593	13143	Business	11300.00
0005435925538	13143	Business	11300.00
0005435069555	13143	Business	11300.00
0005435069551	13143	Business	11300.00
0005435069461	13143	Business	11300.00
0005435925539	13143	Business	11300.00
0005435925555	13143	Business	11300.00
0005435069309	13143	Economy	3800.00
0005435069660	13143	Economy	3800.00
0005435069456	13143	Economy	3800.00
0005435069688	13143	Economy	3800.00
0005435069550	13143	Economy	3800.00
0005435925553	13143	Economy	3800.00
0005435925546	13143	Economy	3800.00
0005435069572	13143	Economy	3800.00
0005435069310	13143	Economy	4100.00
0005435069556	13143	Economy	4100.00
0005435069585	13143	Economy	4100.00
0005435069795	13143	Economy	3800.00
0005435069523	13143	Economy	3800.00
0005435069557	13143	Economy	3800.00
0005435925560	13143	Economy	3800.00
0005435069505	13143	Economy	3800.00
0005435069586	13143	Economy	3800.00
0005435925559	13143	Economy	3800.00
0005435925537	13143	Economy	3800.00
0005435069762	13143	Economy	3800.00
0005435069459	13143	Economy	3800.00
0005435069431	13143	Economy	3800.00
0005435925551	13143	Economy	3800.00
0005435069595	13143	Economy	3800.00
0005435069689	13143	Economy	3800.00
0005435925542	13143	Economy	3800.00
0005435069275	13143	Economy	3800.00
0005435069577	13143	Economy	3800.00
0005435069594	13143	Economy	3800.00
0005435069742	13143	Economy	3800.00
0005435069552	13143	Economy	3800.00
0005435069475	13143	Economy	3800.00
0005435069474	13143	Economy	3800.00
0005435069488	13143	Economy	3800.00
0005435925547	13143	Economy	3800.00
0005435925544	13143	Economy	3800.00
0005435069338	13143	Economy	3800.00
0005435925541	13143	Economy	3800.00
0005435925540	13143	Economy	3800.00
0005435925548	13143	Economy	3800.00
0005435925557	13143	Economy	3800.00
0005435925545	13143	Economy	3800.00
0005435925543	13143	Economy	3800.00
0005435069578	13143	Economy	3800.00
0005435925558	13143	Economy	3800.00
0005435925554	13143	Economy	3800.00
0005435069778	13143	Economy	3800.00
0005435069504	13143	Economy	3800.00
0005435069481	13143	Economy	3800.00
0005435069494	13143	Economy	3800.00
0005435069592	13143	Economy	3800.00
0005435069539	13143	Economy	3800.00
0005435925549	13143	Economy	3800.00
0005435069543	13143	Economy	3800.00
0005435925550	13143	Economy	3800.00
0005435925556	13143	Economy	3800.00
0005435069975	15483	Business	11300.00
0005435069997	15483	Business	11300.00
0005435069976	15483	Business	11300.00
0005435925415	15483	Business	11300.00
0005435069977	15483	Business	11300.00
0005435069970	15483	Business	11300.00
0005435070003	15483	Business	11300.00
0005435925421	15483	Economy	3800.00
0005435069966	15483	Economy	3800.00
0005435070008	15483	Economy	3800.00
0005435070006	15483	Economy	3800.00
0005435070009	15483	Economy	3800.00
0005435069967	15483	Economy	3800.00
0005435069962	15483	Economy	4100.00
0005435069991	15483	Economy	4100.00
0005435925423	15483	Economy	4100.00
0005435069984	15483	Economy	4100.00
0005435070001	15483	Economy	3800.00
0005435069983	15483	Economy	3800.00
0005435925361	15483	Economy	3800.00
0005435069986	15483	Economy	3800.00
0005435925304	15483	Economy	3800.00
0005435069989	15483	Economy	3800.00
0005435069982	15483	Economy	3800.00
0005435069968	15483	Economy	3800.00
0005435925376	15483	Economy	3800.00
0005435069973	15483	Economy	3800.00
0005435069974	15483	Economy	3800.00
0005435069960	15483	Economy	3800.00
0005435925388	15483	Economy	3800.00
0005435925422	15483	Economy	3800.00
0005435069959	15483	Economy	3800.00
0005435069993	15483	Economy	3800.00
0005435925402	15483	Economy	3800.00
0005435070000	15483	Economy	3800.00
0005435069969	15483	Economy	3800.00
0005435069964	15483	Economy	3800.00
0005435070002	15483	Economy	3800.00
0005435069998	15483	Economy	3800.00
0005435925396	15483	Economy	3800.00
0005435925381	15483	Economy	3800.00
0005435069992	15483	Economy	3800.00
0005435069980	15483	Economy	3800.00
0005435070011	15483	Economy	3800.00
0005435069979	15483	Economy	3800.00
0005435069965	15483	Economy	3800.00
0005435069996	15483	Economy	3800.00
0005435069995	15483	Economy	3800.00
0005435070004	15483	Economy	3800.00
0005435069961	15483	Economy	3800.00
0005435069985	15483	Economy	3800.00
0005435070010	15483	Economy	3800.00
0005435069988	15483	Economy	3800.00
0005435070007	15483	Economy	3800.00
0005435069987	15483	Economy	3800.00
0005435925387	15483	Economy	3800.00
0005435925360	15483	Economy	3800.00
0005435069994	15483	Economy	3800.00
0005435069972	15483	Economy	3800.00
0005435069981	15483	Economy	3800.00
0005435069963	15483	Economy	3800.00
0005435069990	15483	Economy	3800.00
0005435069999	15483	Economy	3800.00
0005435925366	15483	Economy	3800.00
0005435070005	15483	Economy	3800.00
0005435069971	15483	Economy	3800.00
0005435069978	15483	Economy	3800.00
0005433407664	29481	Economy	27100.00
0005433407663	29481	Economy	27100.00
0005433407651	29481	Economy	27100.00
0005435808273	29481	Economy	27100.00
0005433407657	29481	Economy	24700.00
0005433407660	29481	Economy	24700.00
0005435808245	29481	Economy	24700.00
0005433407652	29481	Economy	24700.00
0005435808336	29481	Economy	24700.00
0005435808304	29481	Economy	24700.00
0005433407653	29481	Economy	24700.00
0005435808320	29481	Economy	24700.00
0005435808302	29481	Economy	24700.00
0005435808312	29481	Economy	24700.00
0005433407649	29481	Economy	24700.00
0005435808301	29481	Economy	24700.00
0005435808286	29481	Economy	24700.00
0005435808303	29481	Economy	24700.00
0005435808353	29481	Economy	24700.00
0005433407661	29481	Economy	24700.00
0005433407648	29481	Economy	24700.00
0005435808282	29481	Economy	24700.00
0005435808307	29481	Economy	24700.00
0005435808332	29481	Economy	24700.00
0005435808318	29481	Economy	24700.00
0005433407659	29481	Economy	24700.00
0005433407656	29481	Economy	24700.00
0005435808297	29481	Economy	24700.00
0005435808272	29481	Economy	24700.00
0005435808328	29481	Economy	24700.00
0005435808339	29481	Economy	24700.00
0005435808298	29481	Economy	24700.00
0005435808281	29481	Economy	24700.00
0005433407655	29481	Economy	24700.00
0005433407662	29481	Economy	24700.00
0005435808342	29481	Economy	24700.00
0005435808321	29481	Economy	24700.00
0005433407658	29481	Economy	24700.00
0005433407654	29481	Economy	24700.00
0005433407650	29481	Economy	24700.00
0005435808317	29481	Economy	24700.00
0005435808322	29481	Economy	24700.00
0005435808333	29481	Economy	24700.00
0005434756478	10688	Business	61300.00
0005434215385	10688	Business	61300.00
0005434756752	10688	Business	61300.00
0005434756809	10688	Business	61300.00
0005434756717	10688	Business	61300.00
0005434756509	10688	Business	61300.00
0005434757003	10688	Business	61300.00
0005434756849	10688	Business	61300.00
0005434756718	10688	Business	61300.00
0005434215389	10688	Business	61300.00
0005434756741	10688	Business	61300.00
0005434215407	10688	Business	61300.00
0005434215372	10688	Economy	20400.00
0005434215397	10688	Economy	20400.00
0005434215391	10688	Economy	20400.00
0005434756843	10688	Economy	20400.00
0005434215363	10688	Economy	20400.00
0005434756842	10688	Economy	20400.00
0005434756667	10688	Economy	20400.00
0005434756730	10688	Economy	20400.00
0005434756753	10688	Economy	20400.00
0005434756764	10688	Economy	20400.00
0005434215381	10688	Economy	22500.00
0005434756881	10688	Economy	22500.00
0005434756821	10688	Economy	22500.00
0005434215375	10688	Economy	22500.00
0005434215394	10688	Economy	22500.00
0005434215377	10688	Economy	20400.00
0005434756887	10688	Economy	20400.00
0005434215396	10688	Economy	20400.00
0005434756669	10688	Economy	20400.00
0005434756582	10688	Economy	20400.00
0005434215410	10688	Economy	20400.00
0005434215368	10688	Economy	20400.00
0005434215403	10688	Economy	20400.00
0005434215388	10688	Economy	20400.00
0005434756830	10688	Economy	20400.00
0005434215393	10688	Economy	20400.00
0005434756691	10688	Economy	20400.00
0005434756650	10688	Economy	20400.00
0005434215378	10688	Economy	20400.00
0005434215405	10688	Economy	20400.00
0005434756895	10688	Economy	20400.00
0005434756625	10688	Economy	20400.00
0005434215400	10688	Economy	20400.00
0005434215399	10688	Economy	20400.00
0005434756767	10688	Economy	20400.00
0005434215373	10688	Economy	20400.00
0005434215370	10688	Economy	20400.00
0005434215374	10688	Economy	20400.00
0005434215380	10688	Economy	20400.00
0005434756762	10688	Economy	20400.00
0005434215392	10688	Economy	20400.00
0005434756746	10688	Economy	20400.00
0005434215379	10688	Economy	20400.00
0005434756649	10688	Economy	20400.00
0005434215364	10688	Economy	20400.00
0005434215367	10688	Economy	20400.00
0005434215376	10688	Economy	20400.00
0005434756754	10688	Economy	20400.00
0005434756759	10688	Economy	20400.00
0005434215365	10688	Economy	20400.00
0005434215398	10688	Economy	20400.00
0005434756640	10688	Economy	20400.00
0005434215408	10688	Economy	20400.00
0005434215402	10688	Economy	20400.00
0005434215387	10688	Economy	20400.00
0005434756624	10688	Economy	20400.00
0005434215386	10688	Economy	20400.00
0005434215401	10688	Economy	20400.00
0005434215382	10688	Economy	20400.00
0005434756848	10688	Economy	20400.00
0005434756642	10688	Economy	20400.00
0005434215366	10688	Economy	20400.00
0005434215406	10688	Economy	20400.00
0005434215395	10688	Economy	20400.00
0005434215383	10688	Economy	20400.00
0005434215409	10688	Economy	20400.00
0005434215369	10688	Economy	20400.00
0005434756793	10688	Economy	20400.00
0005434756726	10688	Economy	20400.00
0005434757050	10688	Economy	20400.00
0005434756886	10688	Economy	20400.00
0005434756910	10688	Economy	20400.00
0005434756716	10688	Economy	20400.00
0005434215390	10688	Economy	20400.00
0005434215404	10688	Economy	20400.00
0005434756690	10688	Economy	20400.00
0005434756829	10688	Economy	20400.00
0005434756765	10688	Economy	20400.00
0005434756668	10688	Economy	20400.00
0005434756779	10688	Economy	20400.00
0005434215371	10688	Economy	20400.00
0005434215384	10688	Economy	20400.00
0005434756947	10688	Economy	20400.00
0005434214921	28666	Business	61300.00
0005434214695	28666	Business	61300.00
0005434214928	28666	Business	61300.00
0005434757143	28666	Business	61300.00
0005434214702	28666	Business	61300.00
0005434215024	28666	Business	61300.00
0005434215015	28666	Business	61300.00
0005434757152	28666	Business	61300.00
0005434214995	28666	Business	61300.00
0005434757149	28666	Business	61300.00
0005434214962	28666	Business	61300.00
0005434214678	28666	Business	61300.00
0005434215012	28666	Economy	20400.00
0005434214694	28666	Economy	20400.00
0005434757145	28666	Economy	20400.00
0005434214696	28666	Economy	20400.00
0005434214843	28666	Economy	20400.00
0005434214901	28666	Economy	20400.00
0005434214879	28666	Economy	20400.00
0005434214851	28666	Economy	20400.00
0005434757154	28666	Economy	20400.00
0005434214950	28666	Economy	20400.00
0005434214697	28666	Economy	22500.00
0005434757151	28666	Economy	22500.00
0005434214870	28666	Economy	22500.00
0005434757153	28666	Economy	22500.00
0005434214869	28666	Economy	22500.00
0005434757148	28666	Economy	20400.00
0005434214677	28666	Economy	20400.00
0005434214818	28666	Economy	20400.00
0005434215069	28666	Economy	20400.00
0005434214817	28666	Economy	20400.00
0005434214846	28666	Economy	20400.00
0005434214839	28666	Economy	20400.00
0005434757141	28666	Economy	20400.00
0005434214840	28666	Economy	20400.00
0005434214875	28666	Economy	20400.00
0005434215022	28666	Economy	20400.00
0005434757133	28666	Economy	20400.00
0005434214799	28666	Economy	20400.00
0005434214933	28666	Economy	20400.00
0005434214859	28666	Economy	20400.00
0005434214913	28666	Economy	20400.00
0005434214914	28666	Economy	20400.00
0005434757134	28666	Economy	20400.00
0005434214860	28666	Economy	20400.00
0005434215078	28666	Economy	20400.00
0005434214845	28666	Economy	20400.00
0005434214770	28666	Economy	20400.00
0005434757132	28666	Economy	20400.00
0005434214878	28666	Economy	20400.00
0005434757158	28666	Economy	20400.00
0005434214868	28666	Economy	20400.00
0005434214952	28666	Economy	20400.00
0005434214663	28666	Economy	20400.00
0005434215003	28666	Economy	20400.00
0005434757138	28666	Economy	20400.00
0005434757156	28666	Economy	20400.00
0005434757139	28666	Economy	20400.00
0005434757135	28666	Economy	20400.00
0005434757150	28666	Economy	20400.00
0005434214964	28666	Economy	20400.00
0005434214679	28666	Economy	20400.00
0005434215014	28666	Economy	20400.00
0005434214994	28666	Economy	20400.00
0005434757136	28666	Economy	20400.00
0005434214951	28666	Economy	20400.00
0005434757137	28666	Economy	20400.00
0005434214932	28666	Economy	20400.00
0005434757144	28666	Economy	20400.00
0005434214992	28666	Economy	20400.00
0005434215071	28666	Economy	20400.00
0005434757131	28666	Economy	20400.00
0005434757140	28666	Economy	20400.00
0005434757157	28666	Economy	20400.00
0005434214852	28666	Economy	20400.00
0005434214831	28666	Economy	20400.00
0005434214931	28666	Economy	20400.00
0005434215079	28666	Economy	20400.00
0005434214814	28666	Economy	20400.00
0005434215009	28666	Economy	20400.00
0005434757155	28666	Economy	20400.00
0005434215017	28666	Economy	20400.00
0005434757146	28666	Economy	20400.00
0005434757142	28666	Economy	20400.00
0005434757147	28666	Economy	20400.00
0005434757130	28666	Economy	20400.00
0005434214902	28666	Economy	20400.00
0005434214739	28666	Economy	20400.00
0005434214863	28666	Economy	20400.00
0005434214858	28666	Economy	20400.00
0005434215038	28666	Economy	20400.00
0005434214752	28666	Economy	20400.00
0005434215080	28666	Economy	20400.00
0005435040957	5447	Business	29500.00
0005434229471	5447	Business	29500.00
0005435040959	5447	Business	29500.00
0005435007452	5447	Business	29500.00
0005435040943	5447	Business	29500.00
0005435040961	5447	Business	29500.00
0005434229593	5447	Business	29500.00
0005434229654	5447	Business	29500.00
0005434229625	5447	Business	29500.00
0005435040934	5447	Business	29500.00
0005435040972	5447	Business	29500.00
0005434229627	5447	Business	29500.00
0005435040935	5447	Economy	9800.00
0005434229622	5447	Economy	9800.00
0005435040931	5447	Economy	9800.00
0005432125583	5447	Economy	9800.00
0005435007466	5447	Economy	9800.00
0005435040984	5447	Economy	9800.00
0005435040974	5447	Economy	9800.00
0005435040952	5447	Economy	9800.00
0005435040919	5447	Economy	9800.00
0005435040940	5447	Economy	9800.00
0005435007465	5447	Economy	9800.00
0005435040929	5447	Economy	9800.00
0005435040925	5447	Economy	9800.00
0005435040951	5447	Economy	9800.00
0005432125590	5447	Economy	9800.00
0005435040926	5447	Economy	9800.00
0005435040964	5447	Economy	9800.00
0005435007462	5447	Economy	9800.00
0005435040963	5447	Economy	9800.00
0005432125588	5447	Economy	9800.00
0005435040965	5447	Economy	9800.00
0005435007453	5447	Economy	9800.00
0005435040955	5447	Economy	9800.00
0005434229653	5447	Economy	9800.00
0005435040971	5447	Economy	9800.00
0005435043297	5447	Economy	9800.00
0005434229532	5447	Economy	9800.00
0005434229554	5447	Economy	9800.00
0005435040966	5447	Economy	9800.00
0005434229555	5447	Economy	9800.00
0005435040976	5447	Economy	9800.00
0005434229587	5447	Economy	9800.00
0005435040936	5447	Economy	9800.00
0005434229626	5447	Economy	9800.00
0005435007444	5447	Economy	9800.00
0005435040921	5447	Economy	9800.00
0005435007448	5447	Economy	9800.00
0005435042893	5447	Economy	9800.00
0005435040949	5447	Economy	9800.00
0005435040977	5447	Economy	9800.00
0005435040962	5447	Economy	10800.00
0005434229599	5447	Economy	10800.00
0005435040953	5447	Economy	10800.00
0005435007455	5447	Economy	10800.00
0005435007446	5447	Economy	10800.00
0005434229647	5447	Economy	9800.00
0005435007460	5447	Economy	9800.00
0005435007454	5447	Economy	9800.00
0005435040973	5447	Economy	9800.00
0005435040941	5447	Economy	9800.00
0005435040945	5447	Economy	9800.00
0005435007459	5447	Economy	9800.00
0005435007443	5447	Economy	9800.00
0005435040923	5447	Economy	9800.00
0005435040928	5447	Economy	9800.00
0005435007463	5447	Economy	9800.00
0005434229632	5447	Economy	9800.00
0005435040933	5447	Economy	9800.00
0005435040950	5447	Economy	9800.00
0005434229616	5447	Economy	9800.00
0005435040958	5447	Economy	9800.00
0005434229553	5447	Economy	9800.00
0005435040939	5447	Economy	9800.00
0005432125587	5447	Economy	9800.00
0005435040927	5447	Economy	9800.00
0005435040954	5447	Economy	9800.00
0005432125586	5447	Economy	9800.00
0005435040920	5447	Economy	9800.00
0005435040970	5447	Economy	9800.00
0005435040948	5447	Economy	9800.00
0005434229633	5447	Economy	9800.00
0005435007445	5447	Economy	9800.00
0005435040978	5447	Economy	9800.00
0005435040942	5447	Economy	9800.00
0005434229558	5447	Economy	9800.00
0005435007450	5447	Economy	9800.00
0005435007456	5447	Economy	9800.00
0005435042892	5447	Economy	9800.00
0005435007451	5447	Economy	9800.00
0005435040924	5447	Economy	9800.00
0005435040982	5447	Economy	9800.00
0005435040956	5447	Economy	9800.00
0005435007449	5447	Economy	9800.00
0005432125584	5447	Economy	9800.00
0005435040969	5447	Economy	9800.00
0005435040960	5447	Economy	9800.00
0005435040944	5447	Economy	9800.00
0005434229611	5447	Economy	9800.00
0005435007447	5447	Economy	9800.00
0005435040938	5447	Economy	9800.00
0005434229617	5447	Economy	9800.00
0005435040975	5447	Economy	9800.00
0005435040983	5447	Economy	9800.00
0005435042894	5447	Economy	9800.00
0005435040946	5447	Economy	9800.00
0005432125589	5447	Economy	9800.00
0005435007461	5447	Economy	9800.00
0005435040932	5447	Economy	9800.00
0005435040937	5447	Economy	9800.00
0005435007457	5447	Economy	9800.00
0005435040980	5447	Economy	9800.00
0005435040979	5447	Economy	9800.00
0005435040947	5447	Economy	9800.00
0005435007442	5447	Economy	9800.00
0005435040968	5447	Economy	9800.00
0005435040922	5447	Economy	9800.00
0005434229598	5447	Economy	9800.00
0005435040981	5447	Economy	9800.00
0005435007464	5447	Economy	9800.00
0005435040967	5447	Economy	9800.00
0005435007458	5447	Economy	9800.00
0005435040930	5447	Economy	9800.00
0005432125585	5447	Economy	9800.00
0005434229522	5447	Economy	9800.00
0005435007322	12947	Business	29500.00
0005435040387	12947	Business	29500.00
0005435007165	12947	Business	29500.00
0005435007210	12947	Business	29500.00
0005435007226	12947	Business	29500.00
0005435007209	12947	Business	29500.00
0005432304471	12947	Business	29500.00
0005435007164	12947	Business	29500.00
0005435040471	12947	Business	29500.00
0005435007182	12947	Business	29500.00
0005435040365	12947	Business	29500.00
0005434229788	12947	Business	29500.00
0005435040507	12947	Economy	9800.00
0005435007225	12947	Economy	9800.00
0005435040434	12947	Economy	9800.00
0005435040389	12947	Economy	9800.00
0005435040320	12947	Economy	9800.00
0005434229797	12947	Economy	9800.00
0005435040479	12947	Economy	9800.00
0005435040538	12947	Economy	9800.00
0005435040464	12947	Economy	9800.00
0005435040554	12947	Economy	9800.00
0005435040341	12947	Economy	9800.00
0005435040266	12947	Economy	9800.00
0005434229796	12947	Economy	9800.00
0005434229780	12947	Economy	9800.00
0005434229776	12947	Economy	9800.00
0005432304472	12947	Economy	9800.00
0005435042868	12947	Economy	9800.00
0005435007286	12947	Economy	9800.00
0005434229787	12947	Economy	9800.00
0005435040375	12947	Economy	9800.00
0005435040435	12947	Economy	9800.00
0005435040565	12947	Economy	9800.00
0005434229784	12947	Economy	9800.00
0005435040411	12947	Economy	9800.00
0005435040515	12947	Economy	9800.00
0005434229781	12947	Economy	9800.00
0005434229790	12947	Economy	9800.00
0005435040470	12947	Economy	9800.00
0005435377914	12947	Economy	9800.00
0005434229789	12947	Economy	9800.00
0005435040304	12947	Economy	9800.00
0005435040491	12947	Economy	9800.00
0005434229791	12947	Economy	9800.00
0005435007284	12947	Economy	9800.00
0005434229777	12947	Economy	9800.00
0005435040516	12947	Economy	9800.00
0005435040556	12947	Economy	9800.00
0005435042885	12947	Economy	10800.00
0005434229785	12947	Economy	10800.00
0005435040555	12947	Economy	10800.00
0005435040312	12947	Economy	10800.00
0005435007232	12947	Economy	9800.00
0005435040321	12947	Economy	9800.00
0005434229794	12947	Economy	9800.00
0005435040399	12947	Economy	9800.00
0005435040151	12947	Economy	9800.00
0005435040362	12947	Economy	9800.00
0005435007196	12947	Economy	9800.00
0005435040397	12947	Economy	9800.00
0005432304468	12947	Economy	9800.00
0005435007235	12947	Economy	9800.00
0005435040390	12947	Economy	9800.00
0005435040475	12947	Economy	9800.00
0005434229795	12947	Economy	9800.00
0005435040451	12947	Economy	9800.00
0005434229782	12947	Economy	9800.00
0005435042875	12947	Economy	9800.00
0005435040269	12947	Economy	9800.00
0005435040335	12947	Economy	9800.00
0005435007207	12947	Economy	9800.00
0005435040566	12947	Economy	9800.00
0005434229786	12947	Economy	9800.00
0005435007321	12947	Economy	9800.00
0005435007245	12947	Economy	9800.00
0005432304470	12947	Economy	9800.00
0005435007166	12947	Economy	9800.00
0005435040238	12947	Economy	9800.00
0005434229793	12947	Economy	9800.00
0005435040146	12947	Economy	9800.00
0005434229778	12947	Economy	9800.00
0005435040467	12947	Economy	9800.00
0005435040225	12947	Economy	9800.00
0005435040366	12947	Economy	9800.00
0005435040328	12947	Economy	9800.00
0005435040543	12947	Economy	9800.00
0005434229775	12947	Economy	9800.00
0005435040334	12947	Economy	9800.00
0005435007320	12947	Economy	9800.00
0005434229792	12947	Economy	9800.00
0005435040424	12947	Economy	9800.00
0005435040493	12947	Economy	9800.00
0005435377916	12947	Economy	9800.00
0005435040363	12947	Economy	9800.00
0005435040325	12947	Economy	9800.00
0005435040480	12947	Economy	9800.00
0005435040386	12947	Economy	9800.00
0005432304469	12947	Economy	9800.00
0005435377915	12947	Economy	9800.00
0005435040340	12947	Economy	9800.00
0005435007285	12947	Economy	9800.00
0005435040481	12947	Economy	9800.00
0005435040145	12947	Economy	9800.00
0005435040460	12947	Economy	9800.00
0005435007222	12947	Economy	9800.00
0005435040425	12947	Economy	9800.00
0005435040410	12947	Economy	9800.00
0005435007326	12947	Economy	9800.00
0005434229779	12947	Economy	9800.00
0005435007244	12947	Economy	9800.00
0005435007221	12947	Economy	9800.00
0005434229783	12947	Economy	9800.00
0005435040478	12947	Economy	9800.00
0005435007263	12947	Economy	9800.00
0005435040226	12947	Economy	9800.00
0005434411855	14875	Business	52900.00
0005434427134	14875	Business	52900.00
0005435902865	14875	Business	52900.00
0005435902821	14875	Business	52900.00
0005435902796	14875	Business	52900.00
0005434427121	14875	Business	52900.00
0005432188666	14875	Business	52900.00
0005434427110	14875	Business	52900.00
0005435902930	14875	Economy	17600.00
0005434427124	14875	Economy	17600.00
0005435902931	14875	Economy	17600.00
0005435902893	14875	Economy	17600.00
0005432188665	14875	Economy	17600.00
0005435902833	14875	Economy	17600.00
0005435902892	14875	Economy	17600.00
0005434427139	14875	Economy	19400.00
0005435902852	14875	Economy	19400.00
0005435902822	14875	Economy	17600.00
0005435902772	14875	Economy	17600.00
0005434427135	14875	Economy	17600.00
0005435554214	14875	Economy	17600.00
0005434427128	14875	Economy	17600.00
0005435554210	14875	Economy	17600.00
0005435902921	14875	Economy	17600.00
0005435902966	14875	Economy	17600.00
0005434427118	14875	Economy	17600.00
0005434427112	14875	Economy	17600.00
0005435902791	14875	Economy	17600.00
0005434427137	14875	Economy	17600.00
0005435902853	14875	Economy	17600.00
0005434427138	14875	Economy	17600.00
0005435902965	14875	Economy	17600.00
0005434427136	14875	Economy	17600.00
0005435902864	14875	Economy	17600.00
0005434427125	14875	Economy	17600.00
0005434427113	14875	Economy	17600.00
0005434411854	14875	Economy	17600.00
0005434427120	14875	Economy	17600.00
0005434427119	14875	Economy	17600.00
0005434427117	14875	Economy	17600.00
0005435554235	14875	Economy	17600.00
0005434411853	14875	Economy	17600.00
0005435902795	14875	Economy	17600.00
0005434427129	14875	Economy	17600.00
0005432188664	14875	Economy	17600.00
0005434427123	14875	Economy	17600.00
0005434427111	14875	Economy	17600.00
0005435902863	14875	Economy	17600.00
0005434427132	14875	Economy	17600.00
0005434427126	14875	Economy	17600.00
0005435902851	14875	Economy	17600.00
0005434427127	14875	Economy	17600.00
0005435902854	14875	Economy	17600.00
0005435902812	14875	Economy	17600.00
0005435902894	14875	Economy	17600.00
0005434427114	14875	Economy	17600.00
0005434427130	14875	Economy	17600.00
0005434427133	14875	Economy	17600.00
0005434427122	14875	Economy	17600.00
0005434411852	14875	Economy	17600.00
0005434427116	14875	Economy	17600.00
0005435902790	14875	Economy	17600.00
0005434427115	14875	Economy	17600.00
0005434427131	14875	Economy	17600.00
0005435554211	14875	Economy	17600.00
0005434411808	20195	Business	52900.00
0005435903024	20195	Business	52900.00
0005435903025	20195	Business	52900.00
0005434426815	20195	Business	52900.00
0005435903027	20195	Business	52900.00
0005434426948	20195	Business	52900.00
0005434426882	20195	Business	52900.00
0005434426964	20195	Business	52900.00
0005435903030	20195	Business	52900.00
0005432059540	20195	Business	52900.00
0005435903032	20195	Economy	17600.00
0005435903033	20195	Economy	17600.00
0005434426858	20195	Economy	17600.00
0005434411812	20195	Economy	17600.00
0005435554279	20195	Economy	17600.00
0005432059541	20195	Economy	19400.00
0005434426941	20195	Economy	19400.00
0005434426884	20195	Economy	19400.00
0005435903035	20195	Economy	17600.00
0005434427039	20195	Economy	17600.00
0005434426920	20195	Economy	17600.00
0005434426942	20195	Economy	17600.00
0005434426857	20195	Economy	17600.00
0005432059542	20195	Economy	17600.00
0005434426965	20195	Economy	17600.00
0005434426910	20195	Economy	17600.00
0005435903039	20195	Economy	17600.00
0005434426836	20195	Economy	17600.00
0005434426841	20195	Economy	17600.00
0005434426947	20195	Economy	17600.00
0005434426909	20195	Economy	17600.00
0005432059543	20195	Economy	17600.00
0005435903028	20195	Economy	17600.00
0005434411809	20195	Economy	17600.00
0005434426912	20195	Economy	17600.00
0005434411813	20195	Economy	17600.00
0005434426934	20195	Economy	17600.00
0005435903037	20195	Economy	17600.00
0005435903034	20195	Economy	17600.00
0005434426953	20195	Economy	17600.00
0005434426785	20195	Economy	17600.00
0005435554276	20195	Economy	17600.00
0005434426873	20195	Economy	17600.00
0005435903036	20195	Economy	17600.00
0005435903023	20195	Economy	17600.00
0005434426845	20195	Economy	17600.00
0005435903026	20195	Economy	17600.00
0005435554277	20195	Economy	17600.00
0005434426933	20195	Economy	17600.00
0005434426881	20195	Economy	17600.00
0005434411810	20195	Economy	17600.00
0005435903038	20195	Economy	17600.00
0005435903031	20195	Economy	17600.00
0005434426946	20195	Economy	17600.00
0005434411807	20195	Economy	17600.00
0005435554278	20195	Economy	17600.00
0005434426866	20195	Economy	17600.00
0005434426938	20195	Economy	17600.00
0005434426982	20195	Economy	17600.00
0005434426983	20195	Economy	17600.00
0005435554280	20195	Economy	17600.00
0005435903029	20195	Economy	17600.00
0005435983065	26536	Business	18500.00
0005435983078	26536	Business	18500.00
0005435983058	26536	Business	18500.00
0005435983090	26536	Business	18500.00
0005433434840	26536	Business	18500.00
0005435983056	26536	Business	18500.00
0005435983071	26536	Business	18500.00
0005435983076	26536	Business	18500.00
0005435983079	26536	Business	18500.00
0005433434922	26536	Business	18500.00
0005435983061	26536	Business	18500.00
0005432300364	26536	Business	18500.00
0005433434959	26536	Economy	6200.00
0005435983070	26536	Economy	6200.00
0005433434841	26536	Economy	6200.00
0005433434911	26536	Economy	6200.00
0005435983098	26536	Economy	6200.00
0005433434914	26536	Economy	6200.00
0005435983097	26536	Economy	6200.00
0005432300365	26536	Economy	6800.00
0005433434980	26536	Economy	6800.00
0005435983073	26536	Economy	6800.00
0005435983085	26536	Economy	6800.00
0005433435033	26536	Economy	6200.00
0005435983074	26536	Economy	6200.00
0005435983066	26536	Economy	6200.00
0005435983055	26536	Economy	6200.00
0005435983062	26536	Economy	6200.00
0005435983060	26536	Economy	6200.00
0005433434982	26536	Economy	6200.00
0005434270234	26536	Economy	6200.00
0005434270233	26536	Economy	6200.00
0005435983057	26536	Economy	6200.00
0005435983093	26536	Economy	6200.00
0005435983068	26536	Economy	6200.00
0005433435015	26536	Economy	6200.00
0005435983099	26536	Economy	6200.00
0005435983063	26536	Economy	6200.00
0005435983095	26536	Economy	6200.00
0005435983094	26536	Economy	6200.00
0005433434913	26536	Economy	6200.00
0005433435034	26536	Economy	6200.00
0005435983077	26536	Economy	6200.00
0005433434893	26536	Economy	6200.00
0005432300368	26536	Economy	6200.00
0005435983100	26536	Economy	6200.00
0005433434762	26536	Economy	6200.00
0005435983075	26536	Economy	6200.00
0005433434889	26536	Economy	6200.00
0005435983091	26536	Economy	6200.00
0005435983084	26536	Economy	6200.00
0005433434904	26536	Economy	6200.00
0005435983086	26536	Economy	6200.00
0005433435054	26536	Economy	6200.00
0005435983092	26536	Economy	6200.00
0005433434818	26536	Economy	6200.00
0005435983083	26536	Economy	6200.00
0005435983081	26536	Economy	6200.00
0005433434987	26536	Economy	6200.00
0005435983087	26536	Economy	6200.00
0005433434891	26536	Economy	6200.00
0005432300366	26536	Economy	6200.00
0005435983089	26536	Economy	6200.00
0005433434912	26536	Economy	6200.00
0005433434880	26536	Economy	6200.00
0005435983088	26536	Economy	6200.00
0005432300363	26536	Economy	6200.00
0005435983064	26536	Economy	6200.00
0005435983080	26536	Economy	6200.00
0005433434895	26536	Economy	6200.00
0005433434918	26536	Economy	6200.00
0005435983082	26536	Economy	6200.00
0005432300369	26536	Economy	6200.00
0005433434981	26536	Economy	6200.00
0005435983096	26536	Economy	6200.00
0005433434894	26536	Economy	6200.00
0005435983059	26536	Economy	6200.00
0005433434890	26536	Economy	6200.00
0005435983069	26536	Economy	6200.00
0005432300367	26536	Economy	6200.00
0005435983067	26536	Economy	6200.00
0005433434947	26536	Economy	6200.00
0005435983072	26536	Economy	6200.00
0005433434976	26536	Economy	6200.00
0005433435195	26709	Business	18500.00
0005435982671	26709	Business	18500.00
0005435982674	26709	Business	18500.00
0005433435189	26709	Business	18500.00
0005433435212	26709	Business	18500.00
0005435982599	26709	Business	18500.00
0005435982731	26709	Business	18500.00
0005435982544	26709	Business	18500.00
0005433435207	26709	Business	18500.00
0005434270245	26709	Business	18500.00
0005434271350	26709	Economy	6200.00
0005435982841	26709	Economy	6200.00
0005433435202	26709	Economy	6200.00
0005435982650	26709	Economy	6200.00
0005433435196	26709	Economy	6200.00
0005435982672	26709	Economy	6200.00
0005433435193	26709	Economy	6200.00
0005433435215	26709	Economy	6200.00
0005435982649	26709	Economy	6200.00
0005433435204	26709	Economy	6800.00
0005433435211	26709	Economy	6800.00
0005434271352	26709	Economy	6800.00
0005435982680	26709	Economy	6200.00
0005433435209	26709	Economy	6200.00
0005435982695	26709	Economy	6200.00
0005433435203	26709	Economy	6200.00
0005433435213	26709	Economy	6200.00
0005433435190	26709	Economy	6200.00
0005433435191	26709	Economy	6200.00
0005435982840	26709	Economy	6200.00
0005433435200	26709	Economy	6200.00
0005435982600	26709	Economy	6200.00
0005433435201	26709	Economy	6200.00
0005435982507	26709	Economy	6200.00
0005433435208	26709	Economy	6200.00
0005435982789	26709	Economy	6200.00
0005433435199	26709	Economy	6200.00
0005435982679	26709	Economy	6200.00
0005435982351	26709	Economy	6200.00
0005435982748	26709	Economy	6200.00
0005433435192	26709	Economy	6200.00
0005435982745	26709	Economy	6200.00
0005434271351	26709	Economy	6200.00
0005433435210	26709	Economy	6200.00
0005435982900	26709	Economy	6200.00
0005435982611	26709	Economy	6200.00
0005432051186	26709	Economy	6200.00
0005435982749	26709	Economy	6200.00
0005433435197	26709	Economy	6200.00
0005435982746	26709	Economy	6200.00
0005433435188	26709	Economy	6200.00
0005435982758	26709	Economy	6200.00
0005433435205	26709	Economy	6200.00
0005435982772	26709	Economy	6200.00
0005432051187	26709	Economy	6200.00
0005435982795	26709	Economy	6200.00
0005435982641	26709	Economy	6200.00
0005435982675	26709	Economy	6200.00
0005435982450	26709	Economy	6200.00
0005435982954	26709	Economy	6200.00
0005435982612	26709	Economy	6200.00
0005433435194	26709	Economy	6200.00
0005435982788	26709	Economy	6200.00
0005432051188	26709	Economy	6200.00
0005435982681	26709	Economy	6200.00
0005433435216	26709	Economy	6200.00
0005434269142	26709	Economy	6200.00
0005434269141	26709	Economy	6200.00
0005432051185	26709	Economy	6200.00
0005435982759	26709	Economy	6200.00
0005435982822	26709	Economy	6200.00
0005433435214	26709	Economy	6200.00
0005435982541	26709	Economy	6200.00
0005435982834	26709	Economy	6200.00
0005433435198	26709	Economy	6200.00
0005435982732	26709	Economy	6200.00
0005433435206	26709	Economy	6200.00
0005435982707	26709	Economy	6200.00
0005435982845	26709	Economy	6200.00
0005435982540	26709	Economy	6200.00
0005434270246	26709	Economy	6200.00
0005435982694	26709	Economy	6200.00
0005435982846	26709	Economy	6200.00
0005433686670	19508	Economy	21000.00
0005433685553	19508	Economy	21000.00
0005433686664	19508	Economy	21000.00
0005433687742	19508	Economy	21000.00
0005433685558	19508	Economy	19100.00
0005433686669	19508	Economy	19100.00
0005433687737	19508	Economy	19100.00
0005433685564	19508	Economy	19100.00
0005433685554	19508	Economy	19100.00
0005433687745	19508	Economy	19100.00
0005433685559	19508	Economy	19100.00
0005433687738	19508	Economy	19100.00
0005433686674	19508	Economy	19100.00
0005433687743	19508	Economy	19100.00
0005433686672	19508	Economy	19100.00
0005433687746	19508	Economy	19100.00
0005433686671	19508	Economy	19100.00
0005433687739	19508	Economy	19100.00
0005433685556	19508	Economy	19100.00
0005433686668	19508	Economy	19100.00
0005433686677	19508	Economy	19100.00
0005433686673	19508	Economy	19100.00
0005433685565	19508	Economy	19100.00
0005433687736	19508	Economy	19100.00
0005433687741	19508	Economy	19100.00
0005433686666	19508	Economy	19100.00
0005433685552	19508	Economy	19100.00
0005433687744	19508	Economy	19100.00
0005433686663	19508	Economy	19100.00
0005433685562	19508	Economy	19100.00
0005433687747	19508	Economy	19100.00
0005433687735	19508	Economy	19100.00
0005433687740	19508	Economy	19100.00
0005433685560	19508	Economy	19100.00
0005433685555	19508	Economy	19100.00
0005433685563	19508	Economy	19100.00
0005433685561	19508	Economy	19100.00
0005433686676	19508	Economy	19100.00
0005433686665	19508	Economy	19100.00
0005433687734	19508	Economy	19100.00
0005433686667	19508	Economy	19100.00
0005433685557	19508	Economy	19100.00
0005433686675	19508	Economy	19100.00
0005432858196	3185	Economy	11100.00
0005432584497	3185	Economy	11100.00
0005432216325	3185	Economy	11100.00
0005432584509	3185	Economy	10100.00
0005432584498	3185	Economy	10100.00
0005432584495	3185	Economy	10100.00
0005432584499	3185	Economy	10100.00
0005432584507	3185	Economy	10100.00
0005432584508	3185	Economy	10100.00
0005432584504	3185	Economy	10100.00
0005432216324	3185	Economy	10100.00
0005432584501	3185	Economy	10100.00
0005432584493	3185	Economy	10100.00
0005432584489	3185	Economy	10100.00
0005432584491	3185	Economy	10100.00
0005432584488	3185	Economy	10100.00
0005432584494	3185	Economy	10100.00
0005432584506	3185	Economy	10100.00
0005432584510	3185	Economy	10100.00
0005432858159	3185	Economy	10100.00
0005432584505	3185	Economy	10100.00
0005432584492	3185	Economy	10100.00
0005432858199	3185	Economy	10100.00
0005432584487	3185	Economy	10100.00
0005432216323	3185	Economy	10100.00
0005432584490	3185	Economy	10100.00
0005432216322	3185	Economy	10100.00
0005432584496	3185	Economy	10100.00
0005432858191	3185	Economy	10100.00
0005432858212	3185	Economy	10100.00
0005432584502	3185	Economy	10100.00
0005432584486	3185	Economy	10100.00
0005432584503	3185	Economy	10100.00
0005432858195	3185	Economy	10100.00
0005432584500	3185	Economy	10100.00
0005432584342	31523	Economy	11100.00
0005432584303	31523	Economy	11100.00
0005432858286	31523	Economy	11100.00
0005432858288	31523	Economy	10100.00
0005432858290	31523	Economy	10100.00
0005432584201	31523	Economy	10100.00
0005432584289	31523	Economy	10100.00
0005432584244	31523	Economy	10100.00
0005432858292	31523	Economy	10100.00
0005432858291	31523	Economy	10100.00
0005432858284	31523	Economy	10100.00
0005432584423	31523	Economy	10100.00
0005432584229	31523	Economy	10100.00
0005432584219	31523	Economy	10100.00
0005432584298	31523	Economy	10100.00
0005432584230	31523	Economy	10100.00
0005432584332	31523	Economy	10100.00
0005432584331	31523	Economy	10100.00
0005432584304	31523	Economy	10100.00
0005432858293	31523	Economy	10100.00
0005432584354	31523	Economy	10100.00
0005432584349	31523	Economy	10100.00
0005432858287	31523	Economy	10100.00
0005432858285	31523	Economy	10100.00
0005432858296	31523	Economy	10100.00
0005432584401	31523	Economy	10100.00
0005432858295	31523	Economy	10100.00
0005432584419	31523	Economy	10100.00
0005432584305	31523	Economy	10100.00
0005432858297	31523	Economy	10100.00
0005432858289	31523	Economy	10100.00
0005432584333	31523	Economy	10100.00
0005432584299	31523	Economy	10100.00
0005432858294	31523	Economy	10100.00
0005432584369	31523	Economy	10100.00
0005433255184	877	Economy	8300.00
0005434943524	877	Economy	7500.00
0005434943520	877	Economy	7500.00
0005434943518	877	Economy	7500.00
0005433255150	877	Economy	7500.00
0005434943519	877	Economy	7500.00
0005434943517	877	Economy	7500.00
0005433255168	877	Economy	7500.00
0005434943523	877	Economy	7500.00
0005433255177	877	Economy	7500.00
0005434943525	877	Economy	7500.00
0005433255154	877	Economy	7500.00
0005434943522	877	Economy	7500.00
0005434943521	877	Economy	7500.00
0005434943453	16246	Economy	8300.00
0005434943441	16246	Economy	7500.00
0005433255218	16246	Economy	7500.00
0005433255221	16246	Economy	7500.00
0005434943448	16246	Economy	7500.00
0005434943468	16246	Economy	7500.00
0005433255217	16246	Economy	7500.00
0005434943422	16246	Economy	7500.00
0005434943456	16246	Economy	7500.00
0005434943484	16246	Economy	7500.00
0005433255219	16246	Economy	7500.00
0005434943455	16246	Economy	7500.00
0005433255220	16246	Economy	7500.00
0005434943421	16246	Economy	7500.00
0005434943474	16246	Economy	7500.00
0005434943442	16246	Economy	7500.00
0005435858617	4325	Business	90500.00
0005435858606	4325	Business	90500.00
0005435858592	4325	Business	90500.00
0005433654906	4325	Business	90500.00
0005433654899	4325	Business	90500.00
0005433654915	4325	Business	90500.00
0005433654917	4325	Economy	30200.00
0005435858579	4325	Economy	30200.00
0005435858589	4325	Economy	30200.00
0005435858594	4325	Economy	30200.00
0005433654907	4325	Economy	30200.00
0005435858590	4325	Economy	30200.00
0005435858587	4325	Economy	30200.00
0005433654904	4325	Economy	30200.00
0005433654910	4325	Economy	30200.00
0005433654913	4325	Economy	30200.00
0005435858584	4325	Economy	30200.00
0005433654905	4325	Economy	30200.00
0005433654903	4325	Economy	30200.00
0005435858607	4325	Economy	30200.00
0005433654908	4325	Economy	30200.00
0005435858572	4325	Economy	30200.00
0005433654914	4325	Economy	30200.00
0005435858580	4325	Economy	30200.00
0005435858591	4325	Economy	30200.00
0005435858571	4325	Economy	30200.00
0005433654911	4325	Economy	30200.00
0005435858586	4325	Economy	30200.00
0005433654912	4325	Economy	30200.00
0005433654901	4325	Economy	30200.00
0005433654897	4325	Economy	30200.00
0005433654902	4325	Economy	30200.00
0005435858605	4325	Economy	30200.00
0005433654900	4325	Economy	30200.00
0005433654916	4325	Economy	30200.00
0005435858570	4325	Economy	30200.00
0005433654909	4325	Economy	30200.00
0005433654898	4325	Economy	30200.00
0005433811656	14409	Economy	4400.00
0005433811648	14409	Economy	4400.00
0005433811663	27883	Economy	4400.00
0005433811660	27883	Economy	4400.00
0005433811666	27883	Economy	4400.00
0005433811665	27883	Economy	4400.00
0005433811667	27883	Economy	4400.00
0005433811657	27883	Economy	4400.00
0005433811664	27883	Economy	4400.00
0005433811668	27883	Economy	4400.00
0005433811662	27883	Economy	4400.00
0005433811661	27883	Economy	4400.00
0005433811659	27883	Economy	4400.00
0005433811658	27883	Economy	4400.00
0005435653831	21737	Business	9800.00
0005435653815	21737	Business	9800.00
0005433368008	21737	Business	9800.00
0005433368319	21737	Business	9800.00
0005435653823	21737	Business	9800.00
0005433368169	21737	Business	9800.00
0005433368329	21737	Business	9800.00
0005433368120	21737	Business	9800.00
0005435653826	21737	Business	9800.00
0005433368180	21737	Business	9800.00
0005435653838	21737	Business	9800.00
0005435653853	21737	Economy	3300.00
0005435653827	21737	Economy	3300.00
0005433368132	21737	Economy	3300.00
0005435653822	21737	Economy	3300.00
0005433368408	21737	Economy	3300.00
0005433368204	21737	Economy	3300.00
0005435653819	21737	Economy	3300.00
0005433368168	21737	Economy	3300.00
0005433368308	21737	Economy	3300.00
0005435653847	21737	Economy	3600.00
0005433368212	21737	Economy	3600.00
0005435653836	21737	Economy	3600.00
0005433368328	21737	Economy	3300.00
0005433368327	21737	Economy	3300.00
0005435653814	21737	Economy	3300.00
0005435653844	21737	Economy	3300.00
0005433368181	21737	Economy	3300.00
0005433368291	21737	Economy	3300.00
0005435653854	21737	Economy	3300.00
0005433368352	21737	Economy	3300.00
0005433368163	21737	Economy	3300.00
0005433368295	21737	Economy	3300.00
0005435653835	21737	Economy	3300.00
0005435653834	21737	Economy	3300.00
0005435653852	21737	Economy	3300.00
0005435653845	21737	Economy	3300.00
0005435653830	21737	Economy	3300.00
0005435653818	21737	Economy	3300.00
0005433368164	21737	Economy	3300.00
0005435653817	21737	Economy	3300.00
0005433368170	21737	Economy	3300.00
0005433368276	21737	Economy	3300.00
0005435653848	21737	Economy	3300.00
0005433368179	21737	Economy	3300.00
0005435653840	21737	Economy	3300.00
0005433368167	21737	Economy	3300.00
0005435653837	21737	Economy	3300.00
0005435653813	21737	Economy	3300.00
0005435653825	21737	Economy	3300.00
0005435653849	21737	Economy	3300.00
0005433368266	21737	Economy	3300.00
0005435653832	21737	Economy	3300.00
0005435653812	21737	Economy	3300.00
0005435653839	21737	Economy	3300.00
0005435653843	21737	Economy	3300.00
0005435653828	21737	Economy	3300.00
0005433368214	21737	Economy	3300.00
0005433368290	21737	Economy	3300.00
0005433368337	21737	Economy	3300.00
0005433368394	21737	Economy	3300.00
0005433368247	21737	Economy	3300.00
0005435653821	21737	Economy	3300.00
0005433368323	21737	Economy	3300.00
0005435653851	21737	Economy	3300.00
0005435653829	21737	Economy	3300.00
0005435653855	21737	Economy	3300.00
0005435653846	21737	Economy	3300.00
0005433368144	21737	Economy	3300.00
0005435653842	21737	Economy	3300.00
0005435653850	21737	Economy	3300.00
0005433368254	21737	Economy	3300.00
0005433368395	21737	Economy	3300.00
0005433368314	21737	Economy	3300.00
0005435653816	21737	Economy	3300.00
0005433368294	21737	Economy	3300.00
0005433368215	21737	Economy	3300.00
0005433368267	21737	Economy	3300.00
0005435653820	21737	Economy	3300.00
0005433368275	21737	Economy	3300.00
0005435653824	21737	Economy	3300.00
0005435653811	21737	Economy	3300.00
0005435653841	21737	Economy	3300.00
0005433368026	21737	Economy	3300.00
0005433368159	21737	Economy	3300.00
0005435653833	21737	Economy	3300.00
0005432666427	9372	Business	186200.00
0005434270224	9372	Business	186200.00
0005432667493	9372	Business	186200.00
0005433763469	9372	Business	186200.00
0005433806022	9372	Business	186200.00
0005434171232	9372	Business	186200.00
0005433806037	9372	Business	186200.00
0005433785602	9372	Business	186200.00
0005433806016	9372	Business	186200.00
0005433785601	9372	Business	186200.00
0005433806009	9372	Business	186200.00
0005433785610	9372	Business	186200.00
0005434171225	9372	Business	186200.00
0005432657505	9372	Business	186200.00
0005433785621	9372	Business	186200.00
0005433763478	9372	Economy	68300.00
0005433785625	9372	Economy	62100.00
0005433806011	9372	Economy	62100.00
0005433806033	9372	Economy	62100.00
0005433806032	9372	Economy	62100.00
0005432657508	9372	Economy	62100.00
0005433785614	9372	Economy	62100.00
0005433785597	9372	Economy	62100.00
0005432667491	9372	Economy	62100.00
0005433806000	9372	Economy	62100.00
0005433785609	9372	Economy	62100.00
0005433806010	9372	Economy	62100.00
0005433806001	9372	Economy	62100.00
0005433763468	9372	Economy	62100.00
0005433806031	9372	Economy	62100.00
0005433785626	9372	Economy	62100.00
0005433785616	9372	Economy	62100.00
0005435269769	9372	Economy	62100.00
0005433785619	9372	Economy	62100.00
0005433785608	9372	Economy	62100.00
0005433785605	9372	Economy	62100.00
0005433806029	9372	Economy	62100.00
0005433785613	9372	Economy	62100.00
0005433806006	9372	Economy	62100.00
0005432666428	9372	Economy	62100.00
0005433806019	9372	Economy	62100.00
0005433785600	9372	Economy	62100.00
0005435269767	9372	Economy	62100.00
0005433785618	9372	Economy	62100.00
0005433806021	9372	Economy	62100.00
0005433806036	9372	Economy	62100.00
0005433763480	9372	Economy	62100.00
0005433806002	9372	Economy	62100.00
0005432657506	9372	Economy	62100.00
0005434270220	9372	Economy	62100.00
0005434171182	9372	Economy	62100.00
0005433785617	9372	Economy	62100.00
0005434171231	9372	Economy	62100.00
0005433806028	9372	Economy	62100.00
0005433806035	9372	Economy	62100.00
0005434270223	9372	Economy	62100.00
0005433763472	9372	Economy	62100.00
0005433785615	9372	Economy	62100.00
0005435269776	9372	Economy	62100.00
0005434171188	9372	Economy	62100.00
0005433806007	9372	Economy	62100.00
0005433785612	9372	Economy	62100.00
0005433763481	9372	Economy	62100.00
0005433763479	9372	Economy	62100.00
0005433806026	9372	Economy	62100.00
0005433806015	9372	Economy	62100.00
0005433806017	9372	Economy	62100.00
0005433785607	9372	Economy	62100.00
0005435269768	9372	Economy	62100.00
0005434171181	9372	Economy	62100.00
0005433806014	9372	Economy	62100.00
0005434273091	9372	Economy	62100.00
0005433806018	9372	Economy	62100.00
0005433806025	9372	Economy	68300.00
0005432657507	9372	Economy	68300.00
0005433785603	9372	Economy	62100.00
0005433763471	9372	Economy	62100.00
0005433806034	9372	Economy	62100.00
0005434270228	9372	Economy	62100.00
0005433785606	9372	Economy	62100.00
0005433763467	9372	Economy	62100.00
0005433806020	9372	Economy	62100.00
0005433763476	9372	Economy	62100.00
0005434171157	9372	Economy	62100.00
0005433806005	9372	Economy	62100.00
0005432665312	9372	Economy	62100.00
0005433806012	9372	Economy	62100.00
0005433806030	9372	Economy	62100.00
0005433785611	9372	Economy	62100.00
0005433785628	9372	Economy	62100.00
0005433785629	9372	Economy	62100.00
0005433785627	9372	Economy	62100.00
0005433806027	9372	Economy	62100.00
0005433785631	9372	Economy	62100.00
0005433785598	9372	Economy	62100.00
0005433806023	9372	Economy	62100.00
0005433785622	9372	Economy	62100.00
0005433785624	9372	Economy	62100.00
0005433785620	9372	Economy	62100.00
0005433806008	9372	Economy	62100.00
0005433785599	9372	Economy	62100.00
0005432665313	9372	Economy	62100.00
0005434171191	9372	Economy	62100.00
0005433785623	9372	Economy	62100.00
0005433763470	9372	Economy	62100.00
0005433806013	9372	Economy	62100.00
0005433806004	9372	Economy	62100.00
0005434273098	9372	Economy	62100.00
0005433785630	9372	Economy	62100.00
0005432657504	9372	Economy	62100.00
0005433763473	9372	Economy	62100.00
0005433806003	9372	Economy	62100.00
0005433806024	9372	Economy	62100.00
0005434171195	9372	Economy	62100.00
0005432667494	9372	Economy	62100.00
0005432667492	9372	Economy	62100.00
0005433805998	9372	Economy	62100.00
0005434171194	9372	Economy	62100.00
0005433763474	9372	Economy	62100.00
0005434273092	9372	Economy	62100.00
0005433805999	9372	Economy	62100.00
0005433763477	9372	Economy	62100.00
0005433763475	9372	Economy	62100.00
0005433785604	9372	Economy	62100.00
0005434171206	9372	Economy	62100.00
0005433805625	26263	Business	186200.00
0005435269894	26263	Business	186200.00
0005433763404	26263	Business	186200.00
0005433785267	26263	Business	186200.00
0005433785303	26263	Business	186200.00
0005433785099	26263	Business	186200.00
0005434269139	26263	Business	186200.00
0005433763349	26263	Business	186200.00
0005433805793	26263	Business	186200.00
0005434171326	26263	Business	186200.00
0005432663044	26263	Business	186200.00
0005433785315	26263	Business	186200.00
0005433805638	26263	Business	186200.00
0005433785266	26263	Business	186200.00
0005433805616	26263	Business	186200.00
0005433785389	26263	Business	186200.00
0005433805745	26263	Business	186200.00
0005435269889	26263	Business	186200.00
0005433805771	26263	Business	186200.00
0005434270243	26263	Business	186200.00
0005433805676	26263	Economy	62100.00
0005434171313	26263	Economy	62100.00
0005434270244	26263	Economy	62100.00
0005433785314	26263	Economy	62100.00
0005433805785	26263	Economy	62100.00
0005434171316	26263	Economy	62100.00
0005433805751	26263	Economy	62100.00
0005433785317	26263	Economy	62100.00
0005435269890	26263	Economy	62100.00
0005433785390	26263	Economy	62100.00
0005433785219	26263	Economy	62100.00
0005433805710	26263	Economy	62100.00
0005433763405	26263	Economy	62100.00
0005433805896	26263	Economy	62100.00
0005435269896	26263	Economy	62100.00
0005433785191	26263	Economy	62100.00
0005433785296	26263	Economy	62100.00
0005433785183	26263	Economy	62100.00
0005432657470	26263	Economy	62100.00
0005433785367	26263	Economy	62100.00
0005433763302	26263	Economy	62100.00
0005435269900	26263	Economy	62100.00
0005433805675	26263	Economy	62100.00
0005433805738	26263	Economy	62100.00
0005435269891	26263	Economy	62100.00
0005434171319	26263	Economy	62100.00
0005434271349	26263	Economy	62100.00
0005432666412	26263	Economy	62100.00
0005433805770	26263	Economy	62100.00
0005433805821	26263	Economy	62100.00
0005434151758	26263	Economy	62100.00
0005434171322	26263	Economy	62100.00
0005432657476	26263	Economy	62100.00
0005433805897	26263	Economy	62100.00
0005433805714	26263	Economy	62100.00
0005433805789	26263	Economy	62100.00
0005433785292	26263	Economy	62100.00
0005435269892	26263	Economy	62100.00
0005433785281	26263	Economy	62100.00
0005433805726	26263	Economy	62100.00
0005433785363	26263	Economy	62100.00
0005435269897	26263	Economy	62100.00
0005433763350	26263	Economy	62100.00
0005433805724	26263	Economy	62100.00
0005432663043	26263	Economy	62100.00
0005433785337	26263	Economy	62100.00
0005434171323	26263	Economy	62100.00
0005433763312	26263	Economy	62100.00
0005434271348	26263	Economy	62100.00
0005433785401	26263	Economy	62100.00
0005434171311	26263	Economy	62100.00
0005433805617	26263	Economy	62100.00
0005434171327	26263	Economy	62100.00
0005433805436	26263	Economy	62100.00
0005434171321	26263	Economy	62100.00
0005434171324	26263	Economy	62100.00
0005433805895	26263	Economy	62100.00
0005433805646	26263	Economy	62100.00
0005433763398	26263	Economy	62100.00
0005433805631	26263	Economy	68300.00
0005433785277	26263	Economy	62100.00
0005433805709	26263	Economy	62100.00
0005434171325	26263	Economy	62100.00
0005433805790	26263	Economy	68300.00
0005434171314	26263	Economy	68300.00
0005434171320	26263	Economy	62100.00
0005434171317	26263	Economy	62100.00
0005432663046	26263	Economy	62100.00
0005433805723	26263	Economy	62100.00
0005433785297	26263	Economy	62100.00
0005433763362	26263	Economy	62100.00
0005435269887	26263	Economy	62100.00
0005434269140	26263	Economy	62100.00
0005433763304	26263	Economy	62100.00
0005433785280	26263	Economy	62100.00
0005433763388	26263	Economy	62100.00
0005433805649	26263	Economy	62100.00
0005433805725	26263	Economy	62100.00
0005433805750	26263	Economy	62100.00
0005434171312	26263	Economy	62100.00
0005432666409	26263	Economy	62100.00
0005433763351	26263	Economy	62100.00
0005432666408	26263	Economy	62100.00
0005433805670	26263	Economy	62100.00
0005433805713	26263	Economy	62100.00
0005433805630	26263	Economy	62100.00
0005434171328	26263	Economy	62100.00
0005435269895	26263	Economy	62100.00
0005432663045	26263	Economy	62100.00
0005432663042	26263	Economy	62100.00
0005435269898	26263	Economy	62100.00
0005433763370	26263	Economy	62100.00
0005433785403	26263	Economy	62100.00
0005432657478	26263	Economy	62100.00
0005434171315	26263	Economy	62100.00
0005435269893	26263	Economy	62100.00
0005433805627	26263	Economy	62100.00
0005435269888	26263	Economy	62100.00
0005432657469	26263	Economy	62100.00
0005434171318	26263	Economy	62100.00
0005434151757	26263	Economy	62100.00
0005435269899	26263	Economy	62100.00
0005433785100	26263	Economy	62100.00
0005433805748	26263	Economy	62100.00
0005434271347	26263	Economy	62100.00
0005433763406	26263	Economy	62100.00
0005433785241	26263	Economy	62100.00
0005433805816	26263	Economy	62100.00
0005432657467	26263	Economy	62100.00
0005433785220	26263	Economy	62100.00
0005435929670	4883	Economy	5900.00
0005435135760	4883	Economy	5900.00
0005435135759	4883	Economy	5300.00
0005435929683	4883	Economy	5300.00
0005435135762	4883	Economy	5300.00
0005435135761	4883	Economy	5300.00
0005435135758	4883	Economy	5300.00
0005435929684	4883	Economy	5300.00
0005435135709	33059	Economy	5300.00
0005435929694	33059	Economy	5300.00
0005435135714	33059	Economy	5300.00
0005435929693	33059	Economy	5300.00
0005435135715	33059	Economy	5300.00
0005435135735	33059	Economy	5300.00
0005434983384	9488	Economy	19700.00
0005434983385	9488	Economy	19700.00
0005434983382	9488	Economy	17900.00
0005434983381	9488	Economy	17900.00
0005434983380	9488	Economy	17900.00
0005434218002	9488	Economy	17900.00
0005434218007	9488	Economy	17900.00
0005434983383	9488	Economy	17900.00
0005434218018	9488	Economy	17900.00
0005434218017	9488	Economy	17900.00
0005434218043	27341	Economy	17900.00
0005434983345	27341	Economy	17900.00
0005434983350	27341	Economy	17900.00
0005434218044	27341	Economy	17900.00
0005434983351	27341	Economy	17900.00
0005434983365	27341	Economy	17900.00
0005434218042	27341	Economy	17900.00
0005434983346	27341	Economy	17900.00
0005434218045	27341	Economy	17900.00
0005433961280	24255	Business	36400.00
0005433986455	24255	Business	36400.00
0005433986317	24255	Business	36400.00
0005433961240	24255	Business	36400.00
0005433961414	24255	Business	36400.00
0005433986204	24255	Business	36400.00
0005433986439	24255	Business	36400.00
0005433986046	24255	Business	36400.00
0005433961184	24255	Business	36400.00
0005433961188	24255	Business	36400.00
0005433961380	24255	Business	36400.00
0005433961413	24255	Business	36400.00
0005433986425	24255	Economy	13400.00
0005433986377	24255	Economy	13400.00
0005433961393	24255	Economy	12100.00
0005433986318	24255	Economy	13400.00
0005433986358	24255	Economy	12100.00
0005433986447	24255	Economy	12100.00
0005433961282	24255	Economy	12100.00
0005433961404	24255	Economy	12100.00
0005433986440	24255	Economy	12100.00
0005433986399	24255	Economy	12100.00
0005433986255	24255	Economy	12100.00
0005433986415	24255	Economy	12100.00
0005433961181	24255	Economy	12100.00
0005433986410	24255	Economy	12100.00
0005433961195	24255	Economy	12100.00
0005433961349	24255	Economy	12100.00
0005433961403	24255	Economy	12100.00
0005433961116	24255	Economy	12100.00
0005433986393	24255	Economy	12100.00
0005433961142	24255	Economy	12100.00
0005433961327	24255	Economy	12100.00
0005433961233	24255	Economy	12100.00
0005433961194	24255	Economy	12100.00
0005433986389	24255	Economy	12100.00
0005433961379	24255	Economy	12100.00
0005433961304	24255	Economy	12100.00
0005433961392	24255	Economy	12100.00
0005433986342	24255	Economy	12100.00
0005433961358	24255	Economy	12100.00
0005433961114	24255	Economy	12100.00
0005433961335	24255	Economy	12100.00
0005433961196	24255	Economy	12100.00
0005433961322	24255	Economy	12100.00
0005433961197	24255	Economy	12100.00
0005433961324	24255	Economy	12100.00
0005433961394	24255	Economy	12100.00
0005433961187	24255	Economy	12100.00
0005433961237	24255	Economy	12100.00
0005433961154	24255	Economy	12100.00
0005433961238	24255	Economy	12100.00
0005433986364	24255	Economy	12100.00
0005433960990	24255	Economy	12100.00
0005433986136	24255	Economy	12100.00
0005433961321	24255	Economy	12100.00
0005433961371	24255	Economy	12100.00
0005433986256	24255	Economy	12100.00
0005433961402	24255	Economy	12100.00
0005433961336	24255	Economy	12100.00
0005433961225	24255	Economy	12100.00
0005433986420	24255	Economy	12100.00
0005433961115	24255	Economy	13400.00
0005433961144	24255	Economy	12100.00
0005433961227	24255	Economy	12100.00
0005433986257	24255	Economy	12100.00
0005433961375	24255	Economy	13400.00
0005433986445	24255	Economy	13400.00
0005433986446	24255	Economy	12100.00
0005433961202	24255	Economy	12100.00
0005433986302	24255	Economy	12100.00
0005433961286	24255	Economy	12100.00
0005433986392	24255	Economy	12100.00
0005433961332	24255	Economy	12100.00
0005433986396	24255	Economy	12100.00
0005433961340	24255	Economy	12100.00
0005433961391	24255	Economy	12100.00
0005433986390	24255	Economy	12100.00
0005433960924	24255	Economy	12100.00
0005433986395	24255	Economy	12100.00
0005433986369	24255	Economy	12100.00
0005433986144	24255	Economy	12100.00
0005433961339	24255	Economy	12100.00
0005433961326	24255	Economy	12100.00
0005433961211	24255	Economy	12100.00
0005433986316	24255	Economy	12100.00
0005433961405	24255	Economy	12100.00
0005433986391	24255	Economy	12100.00
0005433986419	24255	Economy	12100.00
0005433986429	24255	Economy	12100.00
0005433986363	24255	Economy	12100.00
0005433961193	24255	Economy	12100.00
0005433961287	24255	Economy	12100.00
0005433986449	24255	Economy	12100.00
0005433961385	24255	Economy	12100.00
0005433986137	24255	Economy	12100.00
0005433961409	24255	Economy	12100.00
0005433986082	24255	Economy	12100.00
0005433986045	24255	Economy	12100.00
0005433961189	24255	Economy	12100.00
0005433961300	24255	Economy	12100.00
0005433961222	24255	Economy	12100.00
0005433961354	24255	Economy	12100.00
0005433986203	24255	Economy	12100.00
0005433986290	24255	Economy	12100.00
0005433986202	24255	Economy	12100.00
0005433986448	24255	Economy	12100.00
0005433986416	24255	Economy	12100.00
0005433961239	24255	Economy	12100.00
0005433961325	24255	Economy	12100.00
0005433986427	24255	Economy	12100.00
0005433961281	24255	Economy	12100.00
0005433961333	24255	Economy	12100.00
0005433961871	25936	Business	36400.00
0005433986791	25936	Business	36400.00
0005433986773	25936	Business	36400.00
0005433961887	25936	Business	36400.00
0005433961876	25936	Business	36400.00
0005433986755	25936	Business	36400.00
0005433961904	25936	Business	36400.00
0005433986766	25936	Business	36400.00
0005433961883	25936	Business	36400.00
0005433986770	25936	Business	36400.00
0005433961856	25936	Business	36400.00
0005433986769	25936	Business	36400.00
0005433986779	25936	Business	36400.00
0005433961879	25936	Business	36400.00
0005433961872	25936	Economy	13400.00
0005433961896	25936	Economy	13400.00
0005433986788	25936	Economy	13400.00
0005433986787	25936	Economy	13400.00
0005433986778	25936	Economy	12100.00
0005433961861	25936	Economy	12100.00
0005433961885	25936	Economy	12100.00
0005433986789	25936	Economy	12100.00
0005433986752	25936	Economy	12100.00
0005433961891	25936	Economy	12100.00
0005433986783	25936	Economy	12100.00
0005433961864	25936	Economy	12100.00
0005433961888	25936	Economy	12100.00
0005433961853	25936	Economy	12100.00
0005433961880	25936	Economy	12100.00
0005433961874	25936	Economy	12100.00
0005433986763	25936	Economy	12100.00
0005433986790	25936	Economy	12100.00
0005433961894	25936	Economy	12100.00
0005433961863	25936	Economy	12100.00
0005433986761	25936	Economy	12100.00
0005433986750	25936	Economy	12100.00
0005433986771	25936	Economy	12100.00
0005433961902	25936	Economy	12100.00
0005433961855	25936	Economy	12100.00
0005433986762	25936	Economy	12100.00
0005433986768	25936	Economy	12100.00
0005433961901	25936	Economy	12100.00
0005433986797	25936	Economy	12100.00
0005433986794	25936	Economy	12100.00
0005433961906	25936	Economy	12100.00
0005433961858	25936	Economy	12100.00
0005433961899	25936	Economy	12100.00
0005433961859	25936	Economy	12100.00
0005433961878	25936	Economy	12100.00
0005433961905	25936	Economy	12100.00
0005433986786	25936	Economy	12100.00
0005433986765	25936	Economy	12100.00
0005433986760	25936	Economy	12100.00
0005433961889	25936	Economy	12100.00
0005433986772	25936	Economy	12100.00
0005433986782	25936	Economy	12100.00
0005433961892	25936	Economy	12100.00
0005433986774	25936	Economy	12100.00
0005433986754	25936	Economy	12100.00
0005433986799	25936	Economy	12100.00
0005433986780	25936	Economy	13400.00
0005433961867	25936	Economy	13400.00
0005433961881	25936	Economy	12100.00
0005433986764	25936	Economy	12100.00
0005433986792	25936	Economy	12100.00
0005433986753	25936	Economy	12100.00
0005433961868	25936	Economy	12100.00
0005433961895	25936	Economy	12100.00
0005433961897	25936	Economy	12100.00
0005433961873	25936	Economy	12100.00
0005433986758	25936	Economy	12100.00
0005433986785	25936	Economy	12100.00
0005433986759	25936	Economy	12100.00
0005433986796	25936	Economy	12100.00
0005433961865	25936	Economy	12100.00
0005433961857	25936	Economy	12100.00
0005433986757	25936	Economy	12100.00
0005433961893	25936	Economy	12100.00
0005433986775	25936	Economy	12100.00
0005433986767	25936	Economy	12100.00
0005433961890	25936	Economy	12100.00
0005433961884	25936	Economy	12100.00
0005433986777	25936	Economy	12100.00
0005433961862	25936	Economy	12100.00
0005433961866	25936	Economy	12100.00
0005433986795	25936	Economy	12100.00
0005433961869	25936	Economy	12100.00
0005433986793	25936	Economy	12100.00
0005433986784	25936	Economy	12100.00
0005433961903	25936	Economy	12100.00
0005433961870	25936	Economy	12100.00
0005433961854	25936	Economy	12100.00
0005433986751	25936	Economy	12100.00
0005433961860	25936	Economy	12100.00
0005433961882	25936	Economy	12100.00
0005433961900	25936	Economy	12100.00
0005433986800	25936	Economy	12100.00
0005433986756	25936	Economy	12100.00
0005433986776	25936	Economy	12100.00
0005433986781	25936	Economy	12100.00
0005433961877	25936	Economy	12100.00
0005433986798	25936	Economy	12100.00
0005433961898	25936	Economy	12100.00
0005433961886	25936	Economy	12100.00
0005433961875	25936	Economy	12100.00
0005433166026	952	Economy	25400.00
0005434480792	952	Economy	25400.00
0005434480775	952	Economy	23100.00
0005434480791	952	Economy	23100.00
0005433165968	952	Economy	23100.00
0005434480780	952	Economy	23100.00
0005434480779	952	Economy	23100.00
0005434480774	952	Economy	23100.00
0005434480772	952	Economy	23100.00
0005434480782	952	Economy	23100.00
0005434480773	952	Economy	23100.00
0005434480784	952	Economy	23100.00
0005434480787	952	Economy	23100.00
0005434480778	952	Economy	23100.00
0005434480776	952	Economy	23100.00
0005433166051	952	Economy	23100.00
0005433166025	952	Economy	23100.00
0005434480793	952	Economy	23100.00
0005432269548	952	Economy	23100.00
0005434480794	952	Economy	23100.00
0005434480795	952	Economy	23100.00
0005434480777	952	Economy	23100.00
0005433166022	952	Economy	23100.00
0005434480786	952	Economy	23100.00
0005434480781	952	Economy	23100.00
0005433166066	952	Economy	23100.00
0005433166067	952	Economy	23100.00
0005434480785	952	Economy	23100.00
0005433166005	952	Economy	23100.00
0005432269547	952	Economy	23100.00
0005433166050	952	Economy	23100.00
0005433165985	952	Economy	23100.00
0005434480789	952	Economy	23100.00
0005434480783	952	Economy	23100.00
0005434480790	952	Economy	23100.00
0005434480788	952	Economy	23100.00
0005434480588	16569	Economy	25400.00
0005434480534	16569	Economy	25400.00
0005434480471	16569	Economy	25400.00
0005434480621	16569	Economy	25400.00
0005434480590	16569	Economy	23100.00
0005433166141	16569	Economy	23100.00
0005434480483	16569	Economy	23100.00
0005434480535	16569	Economy	23100.00
0005434480564	16569	Economy	23100.00
0005434480671	16569	Economy	23100.00
0005433166145	16569	Economy	23100.00
0005433166138	16569	Economy	23100.00
0005434480584	16569	Economy	23100.00
0005434480587	16569	Economy	23100.00
0005433166142	16569	Economy	23100.00
0005434480589	16569	Economy	23100.00
0005434480523	16569	Economy	23100.00
0005434480640	16569	Economy	23100.00
0005434480526	16569	Economy	23100.00
0005433166144	16569	Economy	23100.00
0005434480500	16569	Economy	23100.00
0005434480614	16569	Economy	23100.00
0005434480527	16569	Economy	23100.00
0005434480572	16569	Economy	23100.00
0005434480482	16569	Economy	23100.00
0005434480501	16569	Economy	23100.00
0005434480561	16569	Economy	23100.00
0005433166146	16569	Economy	23100.00
0005434480528	16569	Economy	23100.00
0005434480612	16569	Economy	23100.00
0005434480639	16569	Economy	23100.00
0005434480546	16569	Economy	23100.00
0005434480669	16569	Economy	23100.00
0005433166139	16569	Economy	23100.00
0005434480502	16569	Economy	23100.00
0005434480565	16569	Economy	23100.00
0005433166147	16569	Economy	23100.00
0005434480622	16569	Economy	23100.00
0005434480450	16569	Economy	23100.00
0005434480571	16569	Economy	23100.00
0005434480563	16569	Economy	23100.00
0005433166148	16569	Economy	23100.00
0005434480470	16569	Economy	23100.00
0005434480573	16569	Economy	23100.00
0005433166149	16569	Economy	23100.00
0005433166143	16569	Economy	23100.00
0005434480562	16569	Economy	23100.00
0005434480449	16569	Economy	23100.00
0005433166140	16569	Economy	23100.00
0005433872542	3206	Economy	19000.00
0005433872541	3206	Economy	17200.00
0005433872543	3206	Economy	17200.00
0005433872545	3206	Economy	17200.00
0005433872544	3206	Economy	17200.00
0005433872548	3206	Economy	17200.00
0005433872549	3206	Economy	17200.00
0005433872540	3206	Economy	17200.00
0005433872546	3206	Economy	17200.00
0005433872547	3206	Economy	17200.00
0005433872530	32537	Economy	17200.00
0005433872508	32537	Economy	17200.00
0005433872517	32537	Economy	17200.00
0005433872505	32537	Economy	17200.00
0005433872513	32537	Economy	17200.00
0005433872504	32537	Economy	17200.00
0005433872514	32537	Economy	17200.00
0005433872494	32537	Economy	17200.00
0005433872509	32537	Economy	17200.00
0005433872531	32537	Economy	17200.00
0005433872524	32537	Economy	17200.00
0005433872510	32537	Economy	17200.00
0005435142809	10323	Economy	17000.00
0005435142818	10323	Economy	17000.00
0005435142812	10323	Economy	17000.00
0005435386640	10323	Economy	15400.00
0005433289907	10323	Economy	15400.00
0005435150278	10323	Economy	15400.00
0005433289909	10323	Economy	15400.00
0005435150269	10323	Economy	15400.00
0005435150279	10323	Economy	15400.00
0005435150270	10323	Economy	15400.00
0005435142817	10323	Economy	15400.00
0005435386622	10323	Economy	15400.00
0005435150268	10323	Economy	15400.00
0005435150273	10323	Economy	15400.00
0005435142821	10323	Economy	15400.00
0005433289910	10323	Economy	15400.00
0005435150265	10323	Economy	15400.00
0005435142808	10323	Economy	15400.00
0005435150272	10323	Economy	15400.00
0005433289896	10323	Economy	15400.00
0005435386636	10323	Economy	15400.00
0005435142814	10323	Economy	15400.00
0005435150275	10323	Economy	15400.00
0005435142819	10323	Economy	15400.00
0005435142816	10323	Economy	15400.00
0005435150271	10323	Economy	15400.00
0005435150274	10323	Economy	15400.00
0005435150276	10323	Economy	15400.00
0005435142820	10323	Economy	15400.00
0005435150266	10323	Economy	15400.00
0005435142813	10323	Economy	15400.00
0005435142811	10323	Economy	15400.00
0005435150267	10323	Economy	15400.00
0005435150277	10323	Economy	15400.00
0005435386649	10323	Economy	15400.00
0005435386642	10323	Economy	15400.00
0005435142810	10323	Economy	15400.00
0005435142815	10323	Economy	15400.00
0005433289985	21954	Economy	17000.00
0005435386691	21954	Economy	17000.00
0005435386690	21954	Economy	15400.00
0005435386695	21954	Economy	15400.00
0005435142776	21954	Economy	15400.00
0005435142697	21954	Economy	15400.00
0005435142675	21954	Economy	15400.00
0005435142617	21954	Economy	15400.00
0005435150121	21954	Economy	15400.00
0005435386693	21954	Economy	15400.00
0005435142748	21954	Economy	15400.00
0005435142698	21954	Economy	15400.00
0005435150112	21954	Economy	15400.00
0005435386694	21954	Economy	15400.00
0005435150156	21954	Economy	15400.00
0005435386689	21954	Economy	15400.00
0005435142680	21954	Economy	15400.00
0005435386692	21954	Economy	15400.00
0005435142616	21954	Economy	15400.00
0005433289987	21954	Economy	15400.00
0005435142749	21954	Economy	15400.00
0005433289990	21954	Economy	15400.00
0005433289989	21954	Economy	15400.00
0005435150117	21954	Economy	15400.00
0005435150144	21954	Economy	15400.00
0005435150148	21954	Economy	15400.00
0005435142736	21954	Economy	15400.00
0005433289988	21954	Economy	15400.00
0005433289986	21954	Economy	15400.00
0005435502510	11181	Business	57200.00
0005435529436	11181	Business	57200.00
0005435502501	11181	Business	57200.00
0005434573597	11181	Business	57200.00
0005435545789	11181	Business	57200.00
0005435545777	11181	Business	57200.00
0005435529451	11181	Business	57200.00
0005435529352	11181	Business	57200.00
0005434573592	11181	Business	57200.00
0005435545796	11181	Business	57200.00
0005435545774	11181	Business	57200.00
0005435502531	11181	Business	57200.00
0005434573604	11181	Economy	19100.00
0005435529446	11181	Economy	19100.00
0005435502511	11181	Economy	19100.00
0005435545823	11181	Economy	19100.00
0005435502647	11181	Economy	19100.00
0005435502546	11181	Economy	19100.00
0005435529465	11181	Economy	19100.00
0005435502574	11181	Economy	19100.00
0005435529373	11181	Economy	19100.00
0005435545773	11181	Economy	19100.00
0005435319634	11181	Economy	21000.00
0005435529513	11181	Economy	21000.00
0005435319662	11181	Economy	21000.00
0005435319641	11181	Economy	21000.00
0005435529462	11181	Economy	21000.00
0005435529466	11181	Economy	19100.00
0005435319633	11181	Economy	19100.00
0005435502530	11181	Economy	19100.00
0005435529471	11181	Economy	19100.00
0005435502580	11181	Economy	19100.00
0005434573595	11181	Economy	19100.00
0005434573596	11181	Economy	19100.00
0005435529492	11181	Economy	19100.00
0005435319642	11181	Economy	19100.00
0005435319639	11181	Economy	19100.00
0005434573598	11181	Economy	19100.00
0005435502523	11181	Economy	19100.00
0005435502482	11181	Economy	19100.00
0005435545822	11181	Economy	19100.00
0005435319640	11181	Economy	19100.00
0005434573593	11181	Economy	19100.00
0005434573599	11181	Economy	19100.00
0005435545795	11181	Economy	19100.00
0005435529479	11181	Economy	19100.00
0005435529487	11181	Economy	19100.00
0005434573606	11181	Economy	19100.00
0005435529421	11181	Economy	19100.00
0005435529493	11181	Economy	19100.00
0005435529463	11181	Economy	19100.00
0005435529437	11181	Economy	19100.00
0005434573607	11181	Economy	19100.00
0005435545790	11181	Economy	19100.00
0005435502559	11181	Economy	19100.00
0005435529464	11181	Economy	19100.00
0005435502438	11181	Economy	19100.00
0005435319607	11181	Economy	19100.00
0005435502474	11181	Economy	19100.00
0005435502540	11181	Economy	19100.00
0005435529432	11181	Economy	19100.00
0005435502547	11181	Economy	19100.00
0005434573602	11181	Economy	19100.00
0005435545799	11181	Economy	19100.00
0005435502545	11181	Economy	19100.00
0005435319654	11181	Economy	19100.00
0005434573601	11181	Economy	19100.00
0005435319665	11181	Economy	19100.00
0005435545755	11181	Economy	19100.00
0005435502397	11181	Economy	19100.00
0005434573594	11181	Economy	19100.00
0005435319661	11181	Economy	19100.00
0005435529532	11181	Economy	19100.00
0005435319660	11181	Economy	19100.00
0005434573605	11181	Economy	19100.00
0005435502483	11181	Economy	19100.00
0005434573600	11181	Economy	19100.00
0005435545820	11181	Economy	19100.00
0005435529486	11181	Economy	19100.00
0005434573603	11181	Economy	19100.00
0005435529531	11181	Economy	19100.00
0005435529478	11181	Economy	19100.00
0005435529485	11181	Economy	19100.00
0005435545821	11181	Economy	19100.00
0005435545788	11181	Economy	19100.00
0005435529542	11181	Economy	19100.00
0005435502509	11181	Economy	19100.00
0005435502534	11181	Economy	19100.00
0005435319663	11181	Economy	19100.00
0005435529445	11181	Economy	19100.00
0005435529470	11181	Economy	19100.00
0005435319630	11181	Economy	19100.00
0005435529533	11181	Economy	19100.00
0005435529480	11181	Economy	19100.00
0005435319632	11181	Economy	19100.00
0005435508572	20904	Business	57200.00
0005435502693	20904	Business	57200.00
0005434573438	20904	Business	57200.00
0005435319741	20904	Business	57200.00
0005435508573	20904	Business	57200.00
0005435518232	20904	Business	57200.00
0005435502705	20904	Business	57200.00
0005435502696	20904	Business	57200.00
0005435502694	20904	Economy	19100.00
0005435508575	20904	Economy	19100.00
0005435518236	20904	Economy	19100.00
0005434573449	20904	Economy	19100.00
0005434573451	20904	Economy	19100.00
0005435508580	20904	Economy	19100.00
0005434573439	20904	Economy	19100.00
0005435319743	20904	Economy	19100.00
0005435518241	20904	Economy	19100.00
0005435508570	20904	Economy	21000.00
0005435508579	20904	Economy	21000.00
0005434573488	20904	Economy	21000.00
0005435508581	20904	Economy	21000.00
0005435502698	20904	Economy	19100.00
0005435319742	20904	Economy	19100.00
0005435518234	20904	Economy	19100.00
0005435319749	20904	Economy	19100.00
0005435518235	20904	Economy	19100.00
0005435319747	20904	Economy	19100.00
0005435518244	20904	Economy	19100.00
0005435518228	20904	Economy	19100.00
0005435508568	20904	Economy	19100.00
0005435518243	20904	Economy	19100.00
0005435518225	20904	Economy	19100.00
0005435518242	20904	Economy	19100.00
0005435319746	20904	Economy	19100.00
0005435518237	20904	Economy	19100.00
0005435502695	20904	Economy	19100.00
0005434573477	20904	Economy	19100.00
0005435502692	20904	Economy	19100.00
0005435518240	20904	Economy	19100.00
0005435319745	20904	Economy	19100.00
0005434573437	20904	Economy	19100.00
0005435518227	20904	Economy	19100.00
0005435508576	20904	Economy	19100.00
0005434573422	20904	Economy	19100.00
0005435508567	20904	Economy	19100.00
0005435502700	20904	Economy	19100.00
0005435508574	20904	Economy	19100.00
0005435319744	20904	Economy	19100.00
0005435502688	20904	Economy	19100.00
0005435502702	20904	Economy	19100.00
0005435502701	20904	Economy	19100.00
0005435502690	20904	Economy	19100.00
0005435502703	20904	Economy	19100.00
0005435518226	20904	Economy	19100.00
0005435508578	20904	Economy	19100.00
0005435518233	20904	Economy	19100.00
0005435508565	20904	Economy	19100.00
0005435508571	20904	Economy	19100.00
0005435518230	20904	Economy	19100.00
0005435508582	20904	Economy	19100.00
0005435502697	20904	Economy	19100.00
0005434573468	20904	Economy	19100.00
0005435518229	20904	Economy	19100.00
0005435508577	20904	Economy	19100.00
0005435502691	20904	Economy	19100.00
0005434573394	20904	Economy	19100.00
0005435502706	20904	Economy	19100.00
0005435518224	20904	Economy	19100.00
0005435319748	20904	Economy	19100.00
0005435518238	20904	Economy	19100.00
0005435518231	20904	Economy	19100.00
0005435502704	20904	Economy	19100.00
0005434573508	20904	Economy	19100.00
0005435508566	20904	Economy	19100.00
0005434573469	20904	Economy	19100.00
0005435508569	20904	Economy	19100.00
0005435518239	20904	Economy	19100.00
0005434573509	20904	Economy	19100.00
0005435502689	20904	Economy	19100.00
0005435508564	20904	Economy	19100.00
0005435502687	20904	Economy	19100.00
0005435502699	20904	Economy	19100.00
0005435518245	20904	Economy	19100.00
0005433683386	24315	Economy	18800.00
0005433683383	24315	Economy	18800.00
0005433927450	24315	Economy	17100.00
0005433927451	24315	Economy	17100.00
0005433683380	24315	Economy	17100.00
0005433927457	24315	Economy	17100.00
0005433927469	24315	Economy	17100.00
0005433927460	24315	Economy	17100.00
0005433683382	24315	Economy	17100.00
0005433927471	24315	Economy	17100.00
0005433927461	24315	Economy	17100.00
0005433683387	24315	Economy	17100.00
0005433683390	24315	Economy	17100.00
0005433683379	24315	Economy	17100.00
0005433927456	24315	Economy	17100.00
0005433683385	24315	Economy	17100.00
0005433683381	24315	Economy	17100.00
0005433683384	24315	Economy	17100.00
0005433683388	24315	Economy	17100.00
0005433927449	24315	Economy	17100.00
0005433683389	24315	Economy	17100.00
0005433927482	29291	Economy	18800.00
0005433927491	29291	Economy	17100.00
0005433683362	29291	Economy	17100.00
0005433683349	29291	Economy	17100.00
0005433927485	29291	Economy	17100.00
0005433683352	29291	Economy	17100.00
0005433927488	29291	Economy	17100.00
0005433683363	29291	Economy	17100.00
0005433927483	29291	Economy	17100.00
0005433683347	29291	Economy	17100.00
0005433683367	29291	Economy	17100.00
0005433683361	29291	Economy	17100.00
0005433927486	29291	Economy	17100.00
0005433683359	29291	Economy	17100.00
0005433683366	29291	Economy	17100.00
0005433927490	29291	Economy	17100.00
0005433927484	29291	Economy	17100.00
0005433927489	29291	Economy	17100.00
0005433683346	29291	Economy	17100.00
0005433927481	29291	Economy	17100.00
0005433927487	29291	Economy	17100.00
0005432693498	2891	Business	10300.00
0005432693236	2891	Business	10300.00
0005432693323	2891	Economy	3400.00
0005432693232	2891	Economy	3400.00
0005432693279	2891	Economy	3400.00
0005432693425	2891	Economy	3400.00
0005432693334	2891	Economy	3800.00
0005432693258	2891	Economy	3800.00
0005432693497	2891	Economy	3800.00
0005432693292	2891	Economy	3800.00
0005432693499	2891	Economy	3400.00
0005432693296	2891	Economy	3400.00
0005432693307	2891	Economy	3400.00
0005432693278	2891	Economy	3400.00
0005432693473	2891	Economy	3400.00
0005432693231	2891	Economy	3400.00
0005432693397	2891	Economy	3400.00
0005432693362	2891	Economy	3400.00
0005432693441	2891	Economy	3400.00
0005432693356	2891	Economy	3400.00
0005432693301	2891	Economy	3400.00
0005432693303	2891	Economy	3400.00
0005432693295	2891	Economy	3400.00
0005432693308	2891	Economy	3400.00
0005432693426	2891	Economy	3400.00
0005432693324	2891	Economy	3400.00
0005432693233	2891	Economy	3400.00
0005432693310	2891	Economy	3400.00
0005432693435	2891	Economy	3400.00
0005432693423	2891	Economy	3400.00
0005432693253	2891	Economy	3400.00
0005432693343	2891	Economy	3400.00
0005432693406	2891	Economy	3400.00
0005432693302	2891	Economy	3400.00
0005432707240	2892	Business	10300.00
0005432707235	2892	Business	10300.00
0005433194875	2892	Business	10300.00
0005432880976	2892	Business	10300.00
0005432217827	2892	Business	10300.00
0005432880937	2892	Business	10300.00
0005433124059	2892	Business	10300.00
0005433194868	2892	Business	10300.00
0005432707243	2892	Economy	3400.00
0005432707237	2892	Economy	3400.00
0005432880943	2892	Economy	3400.00
0005432707242	2892	Economy	3400.00
0005433124096	2892	Economy	3800.00
0005432880947	2892	Economy	3800.00
0005432707246	2892	Economy	3800.00
0005432707238	2892	Economy	3400.00
0005432707241	2892	Economy	3400.00
0005432217830	2892	Economy	3400.00
0005432707248	2892	Economy	3400.00
0005432707234	2892	Economy	3400.00
0005433124161	2892	Economy	3400.00
0005432707250	2892	Economy	3400.00
0005432880936	2892	Economy	3400.00
0005432707228	2892	Economy	3400.00
0005433124218	2892	Economy	3400.00
0005432707233	2892	Economy	3400.00
0005433194874	2892	Economy	3400.00
0005433124143	2892	Economy	3400.00
0005433124089	2892	Economy	3400.00
0005433124053	2892	Economy	3400.00
0005432707231	2892	Economy	3400.00
0005433124142	2892	Economy	3400.00
0005433124163	2892	Economy	3400.00
0005433194869	2892	Economy	3400.00
0005432217828	2892	Economy	3400.00
0005432707227	2892	Economy	3400.00
0005432707230	2892	Economy	3400.00
0005433124164	2892	Economy	3400.00
0005433194873	2892	Economy	3400.00
0005432880952	2892	Economy	3400.00
0005432217829	2892	Economy	3400.00
0005432880955	2892	Economy	3400.00
0005432880948	2892	Economy	3400.00
0005432707247	2892	Economy	3400.00
0005432881012	2892	Economy	3400.00
0005432880942	2892	Economy	3400.00
0005432707232	2892	Economy	3400.00
0005432707244	2892	Economy	3400.00
0005433194877	2892	Economy	3400.00
0005432707245	2892	Economy	3400.00
0005432707229	2892	Economy	3400.00
0005432707226	2892	Economy	3400.00
0005432707236	2892	Economy	3400.00
0005432707239	2892	Economy	3400.00
0005432880995	2892	Economy	3400.00
0005433124162	2892	Economy	3400.00
0005432707249	2892	Economy	3400.00
0005432880900	2892	Economy	3400.00
0005432707225	2892	Economy	3400.00
0005433124119	2892	Economy	3400.00
0005432693647	29982	Business	10300.00
0005433194903	29982	Business	10300.00
0005432693655	29982	Business	10300.00
0005432706976	29982	Business	10300.00
0005432881084	29982	Business	10300.00
0005432707031	29982	Business	10300.00
0005433124295	29982	Business	10300.00
0005432881088	29982	Business	10300.00
0005432881083	29982	Business	10300.00
0005432693659	29982	Business	10300.00
0005432881077	29982	Business	10300.00
0005432707075	29982	Business	10300.00
0005432881090	29982	Economy	3400.00
0005432693649	29982	Economy	3400.00
0005432707006	29982	Economy	3400.00
0005432693648	29982	Economy	3400.00
0005432707040	29982	Economy	3400.00
0005433124298	29982	Economy	3400.00
0005432706995	29982	Economy	3400.00
0005433124304	29982	Economy	3400.00
0005432693654	29982	Economy	3400.00
0005432693658	29982	Economy	3400.00
0005432693651	29982	Economy	3800.00
0005432707032	29982	Economy	3800.00
0005432693640	29982	Economy	3800.00
0005433194904	29982	Economy	3800.00
0005432707084	29982	Economy	3800.00
0005432707001	29982	Economy	3400.00
0005432881078	29982	Economy	3400.00
0005433124285	29982	Economy	3400.00
0005432693634	29982	Economy	3400.00
0005433124294	29982	Economy	3400.00
0005433124299	29982	Economy	3400.00
0005433124303	29982	Economy	3400.00
0005433124289	29982	Economy	3400.00
0005432706939	29982	Economy	3400.00
0005433124293	29982	Economy	3400.00
0005432707000	29982	Economy	3400.00
0005432693661	29982	Economy	3400.00
0005432707007	29982	Economy	3400.00
0005432693639	29982	Economy	3400.00
0005433124297	29982	Economy	3400.00
0005432707062	29982	Economy	3400.00
0005432693660	29982	Economy	3400.00
0005433124292	29982	Economy	3400.00
0005432707010	29982	Economy	3400.00
0005433124300	29982	Economy	3400.00
0005432706999	29982	Economy	3400.00
0005432693646	29982	Economy	3400.00
0005433124306	29982	Economy	3400.00
0005432693635	29982	Economy	3400.00
0005432693638	29982	Economy	3400.00
0005432881091	29982	Economy	3400.00
0005432693641	29982	Economy	3400.00
0005433124302	29982	Economy	3400.00
0005433124290	29982	Economy	3400.00
0005432693650	29982	Economy	3400.00
0005432693645	29982	Economy	3400.00
0005432881082	29982	Economy	3400.00
0005432693644	29982	Economy	3400.00
0005433124301	29982	Economy	3400.00
0005432706971	29982	Economy	3400.00
0005432881076	29982	Economy	3400.00
0005432881087	29982	Economy	3400.00
0005433124286	29982	Economy	3400.00
0005432693657	29982	Economy	3400.00
0005432693643	29982	Economy	3400.00
0005432693662	29982	Economy	3400.00
0005432881081	29982	Economy	3400.00
0005432693636	29982	Economy	3400.00
0005433194901	29982	Economy	3400.00
0005432693637	29982	Economy	3400.00
0005432707059	29982	Economy	3400.00
0005433124307	29982	Economy	3400.00
0005432693656	29982	Economy	3400.00
0005433124296	29982	Economy	3400.00
0005433194902	29982	Economy	3400.00
0005433194900	29982	Economy	3400.00
0005432693652	29982	Economy	3400.00
0005432881089	29982	Economy	3400.00
0005432707011	29982	Economy	3400.00
0005432693633	29982	Economy	3400.00
0005433124291	29982	Economy	3400.00
0005432707094	29982	Economy	3400.00
0005432693642	29982	Economy	3400.00
0005432707085	29982	Economy	3400.00
0005433124287	29982	Economy	3400.00
0005432693653	29982	Economy	3400.00
0005432881079	29982	Economy	3400.00
0005432881086	29982	Economy	3400.00
0005432881085	29982	Economy	3400.00
0005432706994	29982	Economy	3400.00
0005432706975	29982	Economy	3400.00
0005433124305	29982	Economy	3400.00
0005432706938	29982	Economy	3400.00
0005433124288	29982	Economy	3400.00
0005432881080	29982	Economy	3400.00
0005434980314	23691	Economy	4000.00
0005434980305	23691	Economy	4000.00
0005434980327	23691	Economy	4000.00
0005434980319	23691	Economy	3600.00
0005434988922	23691	Economy	3600.00
0005434980321	23691	Economy	3600.00
0005434980324	23691	Economy	3600.00
0005434980322	23691	Economy	3600.00
0005434980307	23691	Economy	3600.00
0005434980311	23691	Economy	3600.00
0005434988924	23691	Economy	3600.00
0005434980312	23691	Economy	3600.00
0005434980306	23691	Economy	3600.00
0005434980302	23691	Economy	3600.00
0005434980320	23691	Economy	3600.00
0005434980317	23691	Economy	3600.00
0005434980315	23691	Economy	3600.00
0005434980323	23691	Economy	3600.00
0005434980298	23691	Economy	3600.00
0005434980304	23691	Economy	3600.00
0005434980316	23691	Economy	3600.00
0005434980326	23691	Economy	3600.00
0005434980325	23691	Economy	3600.00
0005434980313	23691	Economy	3600.00
0005434980308	23691	Economy	3600.00
0005434980299	23691	Economy	3600.00
0005434988923	23691	Economy	3600.00
0005434980310	23691	Economy	3600.00
0005434980328	23691	Economy	3600.00
0005434980303	23691	Economy	3600.00
0005434980300	23691	Economy	3600.00
0005434980318	23691	Economy	3600.00
0005434980309	23691	Economy	3600.00
0005434988921	23691	Economy	3600.00
0005434980301	23691	Economy	3600.00
0005434980183	27566	Economy	4000.00
0005434980076	27566	Economy	4000.00
0005434988827	27566	Economy	4000.00
0005434980096	27566	Economy	3600.00
0005434988817	27566	Economy	3600.00
0005434980091	27566	Economy	3600.00
0005434988822	27566	Economy	3600.00
0005434979947	27566	Economy	3600.00
0005434980049	27566	Economy	3600.00
0005434980103	27566	Economy	3600.00
0005434988807	27566	Economy	3600.00
0005434980140	27566	Economy	3600.00
0005434980017	27566	Economy	3600.00
0005434980171	27566	Economy	3600.00
0005434980029	27566	Economy	3600.00
0005434980112	27566	Economy	3600.00
0005434979969	27566	Economy	3600.00
0005434988821	27566	Economy	3600.00
0005434979983	27566	Economy	3600.00
0005434980038	27566	Economy	3600.00
0005434988820	27566	Economy	3600.00
0005434988825	27566	Economy	3600.00
0005434980090	27566	Economy	3600.00
0005434980032	27566	Economy	3600.00
0005434979992	27566	Economy	3600.00
0005434979966	27566	Economy	3600.00
0005434980127	27566	Economy	3600.00
0005434980018	27566	Economy	3600.00
0005434980182	27566	Economy	3600.00
0005434979970	27566	Economy	3600.00
0005434988808	27566	Economy	3600.00
0005434988824	27566	Economy	3600.00
0005434980086	27566	Economy	3600.00
0005434988803	27566	Economy	3600.00
0005434979971	27566	Economy	3600.00
0005434980119	27566	Economy	3600.00
0005434988823	27566	Economy	3600.00
0005434980092	27566	Economy	3600.00
0005434988830	27566	Economy	3600.00
0005434988829	27566	Economy	3600.00
0005434979991	27566	Economy	3600.00
0005434980126	27566	Economy	3600.00
0005434980060	27566	Economy	3600.00
0005434980104	27566	Economy	3600.00
0005434980130	27566	Economy	3600.00
0005434980087	27566	Economy	3600.00
0005434302882	10275	Economy	21600.00
0005434302535	10275	Economy	19700.00
0005434302536	10275	Economy	19700.00
0005433113555	10275	Economy	19700.00
0005434302881	10275	Economy	19700.00
0005433111507	10275	Economy	19700.00
0005434302534	10275	Economy	19700.00
0005433111503	10275	Economy	19700.00
0005434302880	10275	Economy	19700.00
0005434302533	10275	Economy	19700.00
0005434302879	10275	Economy	19700.00
0005433113554	10275	Economy	19700.00
0005433111531	10275	Economy	19700.00
0005434302494	19611	Economy	19700.00
0005434302498	19611	Economy	19700.00
0005434302497	19611	Economy	19700.00
0005434302499	19611	Economy	19700.00
0005433113576	19611	Economy	19700.00
0005433113577	19611	Economy	19700.00
0005434302517	19611	Economy	19700.00
0005434302496	19611	Economy	19700.00
0005434302518	19611	Economy	19700.00
0005435070034	3562	Business	26900.00
0005435070040	3562	Business	26900.00
0005435925429	3562	Business	26900.00
0005435070041	3562	Business	26900.00
0005435070021	3562	Business	26900.00
0005435070043	3562	Business	26900.00
0005435925372	3562	Business	26900.00
0005435070059	3562	Business	26900.00
0005435925397	3562	Business	26900.00
0005435070047	3562	Economy	9000.00
0005435070061	3562	Economy	9000.00
0005435070022	3562	Economy	9000.00
0005435070042	3562	Economy	9000.00
0005435070030	3562	Economy	9000.00
0005435070037	3562	Economy	9000.00
0005435925431	3562	Economy	9000.00
0005435070053	3562	Economy	9000.00
0005435925419	3562	Economy	9900.00
0005435070025	3562	Economy	9900.00
0005435070024	3562	Economy	9900.00
0005435070033	3562	Economy	9000.00
0005435925428	3562	Economy	9000.00
0005435925382	3562	Economy	9000.00
0005435070065	3562	Economy	9000.00
0005435070045	3562	Economy	9000.00
0005435939895	3562	Economy	9000.00
0005435070044	3562	Economy	9000.00
0005435070049	3562	Economy	9000.00
0005435070028	3562	Economy	9000.00
0005435070063	3562	Economy	9000.00
0005435070048	3562	Economy	9000.00
0005435925407	3562	Economy	9000.00
0005435070012	3562	Economy	9000.00
0005435070052	3562	Economy	9000.00
0005435925434	3562	Economy	9000.00
0005435925420	3562	Economy	9000.00
0005435925393	3562	Economy	9000.00
0005435070055	3562	Economy	9000.00
0005435070015	3562	Economy	9000.00
0005435070013	3562	Economy	9000.00
0005435925432	3562	Economy	9000.00
0005435925370	3562	Economy	9000.00
0005435070036	3562	Economy	9000.00
0005435925386	3562	Economy	9000.00
0005435070017	3562	Economy	9000.00
0005435070020	3562	Economy	9000.00
0005435070019	3562	Economy	9000.00
0005435070062	3562	Economy	9000.00
0005435070039	3562	Economy	9000.00
0005435070050	3562	Economy	9000.00
0005435070057	3562	Economy	9000.00
0005435070026	3562	Economy	9000.00
0005435070032	3562	Economy	9000.00
0005435070023	3562	Economy	9000.00
0005435070051	3562	Economy	9000.00
0005435925408	3562	Economy	9000.00
0005435070014	3562	Economy	9000.00
0005435925410	3562	Economy	9000.00
0005435070018	3562	Economy	9000.00
0005435925383	3562	Economy	9000.00
0005435070031	3562	Economy	9000.00
0005435070029	3562	Economy	9000.00
0005435070046	3562	Economy	9000.00
0005435070060	3562	Economy	9000.00
0005435070016	3562	Economy	9000.00
0005435070056	3562	Economy	9000.00
0005435925398	3562	Economy	9000.00
0005435070054	3562	Economy	9000.00
0005435719041	3562	Economy	9000.00
0005435070038	3562	Economy	9000.00
0005435070035	3562	Economy	9000.00
0005435070027	3562	Economy	9000.00
0005435070064	3562	Economy	9000.00
0005435070058	3562	Economy	9000.00
0005435069309	15299	Business	26900.00
0005435925542	15299	Business	26900.00
0005435069778	15299	Business	26900.00
0005435069474	15299	Business	26900.00
0005435069475	15299	Business	26900.00
0005435069592	15299	Business	26900.00
0005435069481	15299	Business	26900.00
0005435069494	15299	Business	26900.00
0005435925555	15299	Business	26900.00
0005435069505	15299	Economy	9000.00
0005435925547	15299	Economy	9000.00
0005435925546	15299	Economy	9000.00
0005435925540	15299	Economy	9000.00
0005435069578	15299	Economy	9000.00
0005435069551	15299	Economy	9000.00
0005435925560	15299	Economy	9000.00
0005435069552	15299	Economy	9900.00
0005435069762	15299	Economy	9900.00
0005435069688	15299	Economy	9000.00
0005435925541	15299	Economy	9000.00
0005435069431	15299	Economy	9000.00
0005435069338	15299	Economy	9000.00
0005435925537	15299	Economy	9000.00
0005435069488	15299	Economy	9000.00
0005435939916	15299	Economy	9000.00
0005435069742	15299	Economy	9000.00
0005435069456	15299	Economy	9000.00
0005435925559	15299	Economy	9000.00
0005435925549	15299	Economy	9000.00
0005435939918	15299	Economy	9000.00
0005435069275	15299	Economy	9000.00
0005435925545	15299	Economy	9000.00
0005435069586	15299	Economy	9000.00
0005435069577	15299	Economy	9000.00
0005435069595	15299	Economy	9000.00
0005435939915	15299	Economy	9000.00
0005435069523	15299	Economy	9000.00
0005435069539	15299	Economy	9000.00
0005435925552	15299	Economy	9000.00
0005435925544	15299	Economy	9000.00
0005435069556	15299	Economy	9000.00
0005435069459	15299	Economy	9000.00
0005435069543	15299	Economy	9000.00
0005435069461	15299	Economy	9000.00
0005435069504	15299	Economy	9000.00
0005435939917	15299	Economy	9000.00
0005435069310	15299	Economy	9000.00
0005435925550	15299	Economy	9000.00
0005435069585	15299	Economy	9000.00
0005435069795	15299	Economy	9000.00
0005435925553	15299	Economy	9000.00
0005435925543	15299	Economy	9000.00
0005435069550	15299	Economy	9000.00
0005435069460	15299	Economy	9000.00
0005435925554	15299	Economy	9000.00
0005435069572	15299	Economy	9000.00
0005435069555	15299	Economy	9000.00
0005435069594	15299	Economy	9000.00
0005435925538	15299	Economy	9000.00
0005435925539	15299	Economy	9000.00
0005435925556	15299	Economy	9000.00
0005435069660	15299	Economy	9000.00
0005435925548	15299	Economy	9000.00
0005435069689	15299	Economy	9000.00
0005435069557	15299	Economy	9000.00
0005435925558	15299	Economy	9000.00
0005435925557	15299	Economy	9000.00
0005435925551	15299	Economy	9000.00
0005435069593	15299	Economy	9000.00
0005432659745	18178	Economy	5900.00
0005432658629	18178	Economy	5900.00
0005432660856	18178	Economy	5900.00
0005432658630	18178	Economy	5900.00
0005432667473	26400	Economy	5900.00
0005432667470	26400	Economy	5900.00
0005432660838	26400	Economy	5900.00
0005432667469	26400	Economy	5900.00
0005432667464	26400	Economy	5900.00
0005432660831	26400	Economy	5900.00
0005432660826	26400	Economy	5900.00
0005432660837	26400	Economy	5900.00
0005433102679	156	Business	20000.00
0005433102706	156	Business	20000.00
0005432920027	156	Business	20000.00
0005433102700	156	Business	20000.00
0005432901854	156	Business	20000.00
0005433102707	156	Business	20000.00
0005432677608	156	Business	20000.00
0005432901794	156	Business	20000.00
0005433102478	156	Business	20000.00
0005432392014	156	Business	20000.00
0005433102709	156	Business	20000.00
0005433102691	156	Business	20000.00
0005433102631	156	Business	20000.00
0005433102323	156	Business	20000.00
0005432901786	156	Business	20000.00
0005433102506	156	Business	20000.00
0005432157527	156	Economy	7300.00
0005432392023	156	Economy	7300.00
0005433102693	156	Economy	7300.00
0005432920028	156	Economy	7300.00
0005432392016	156	Economy	6700.00
0005433102494	156	Economy	6700.00
0005433102586	156	Economy	6700.00
0005432920052	156	Economy	6700.00
0005432919972	156	Economy	6700.00
0005433102315	156	Economy	6700.00
0005432920062	156	Economy	6700.00
0005433102717	156	Economy	6700.00
0005433102607	156	Economy	6700.00
0005432901847	156	Economy	6700.00
0005432920103	156	Economy	6700.00
0005432901852	156	Economy	6700.00
0005433102684	156	Economy	6700.00
0005433102617	156	Economy	6700.00
0005433102681	156	Economy	6700.00
0005433102718	156	Economy	6700.00
0005433102626	156	Economy	6700.00
0005432392006	156	Economy	6700.00
0005432920114	156	Economy	6700.00
0005433102713	156	Economy	6700.00
0005432920102	156	Economy	6700.00
0005433102609	156	Economy	6700.00
0005433102446	156	Economy	6700.00
0005433102568	156	Economy	6700.00
0005432392036	156	Economy	6700.00
0005432919998	156	Economy	6700.00
0005433102682	156	Economy	6700.00
0005432901836	156	Economy	6700.00
0005432901805	156	Economy	6700.00
0005433102685	156	Economy	6700.00
0005433102314	156	Economy	6700.00
0005433102692	156	Economy	6700.00
0005432901850	156	Economy	6700.00
0005433102495	156	Economy	6700.00
0005432901885	156	Economy	6700.00
0005432392027	156	Economy	6700.00
0005432919997	156	Economy	6700.00
0005432920085	156	Economy	6700.00
0005432920063	156	Economy	6700.00
0005433102517	156	Economy	6700.00
0005433102447	156	Economy	7300.00
0005432392005	156	Economy	7300.00
0005432901820	156	Economy	7300.00
0005433102701	156	Economy	7300.00
0005433102666	156	Economy	7300.00
0005432920015	156	Economy	6700.00
0005432901849	156	Economy	6700.00
0005432920053	156	Economy	6700.00
0005433102515	156	Economy	6700.00
0005432157529	156	Economy	7300.00
0005432157528	156	Economy	6700.00
0005432901789	156	Economy	6700.00
0005433102324	156	Economy	6700.00
0005432901802	156	Economy	6700.00
0005432392007	156	Economy	6700.00
0005432677619	156	Economy	6700.00
0005433102708	156	Economy	6700.00
0005433102637	156	Economy	6700.00
0005432920065	156	Economy	6700.00
0005432920092	156	Economy	6700.00
0005433102518	156	Economy	6700.00
0005433102627	156	Economy	6700.00
0005433102456	156	Economy	6700.00
0005432901792	156	Economy	6700.00
0005432920143	156	Economy	6700.00
0005432920115	156	Economy	6700.00
0005432920142	156	Economy	6700.00
0005433102460	156	Economy	6700.00
0005432901848	156	Economy	6700.00
0005432920042	156	Economy	6700.00
0005433102719	156	Economy	6700.00
0005433102680	156	Economy	6700.00
0005432901804	156	Economy	6700.00
0005433102629	156	Economy	6700.00
0005432920101	156	Economy	6700.00
0005432901777	156	Economy	6700.00
0005432392017	156	Economy	6700.00
0005433102674	156	Economy	6700.00
0005432392015	156	Economy	6700.00
0005433102461	156	Economy	6700.00
0005432901828	156	Economy	6700.00
0005432901877	156	Economy	6700.00
0005432392024	156	Economy	6700.00
0005433102683	156	Economy	6700.00
0005432920086	156	Economy	6700.00
0005432919996	156	Economy	6700.00
0005432920016	156	Economy	6700.00
0005432392008	156	Economy	6700.00
0005432901785	156	Economy	6700.00
0005432920180	156	Economy	6700.00
0005432392035	156	Economy	6700.00
0005433102642	156	Economy	6700.00
0005432901803	156	Economy	6700.00
0005432392010	156	Economy	6700.00
0005433102606	156	Economy	6700.00
0005433102608	156	Economy	6700.00
0005433102409	156	Economy	6700.00
0005432818018	151	Business	20000.00
0005432818030	151	Business	20000.00
0005432262726	151	Business	20000.00
0005432262750	151	Business	20000.00
0005432262746	151	Business	20000.00
0005432289047	151	Business	20000.00
0005432818004	151	Business	20000.00
0005432262745	151	Business	20000.00
0005433687727	151	Business	20000.00
0005432818024	151	Business	20000.00
0005433687728	151	Business	20000.00
0005432262735	151	Business	20000.00
0005432818019	151	Business	20000.00
0005432818012	151	Business	20000.00
0005432262739	151	Business	20000.00
0005432262764	151	Business	20000.00
0005433687724	151	Business	20000.00
0005432262756	151	Business	20000.00
0005433476979	151	Business	20000.00
0005433690936	151	Business	20000.00
0005432262728	151	Business	20000.00
0005432262740	151	Economy	7300.00
0005432262752	151	Economy	7300.00
0005432262731	151	Economy	7300.00
0005432818021	151	Economy	7300.00
0005432262760	151	Economy	6700.00
0005433476975	151	Economy	6700.00
0005433476981	151	Economy	6700.00
0005433476980	151	Economy	6700.00
0005432262769	151	Economy	6700.00
0005432262751	151	Economy	6700.00
0005432818007	151	Economy	6700.00
0005433476973	151	Economy	6700.00
0005432262749	151	Economy	6700.00
0005432818003	151	Economy	6700.00
0005432753342	151	Economy	6700.00
0005432818014	151	Economy	6700.00
0005432289046	151	Economy	6700.00
0005432818020	151	Economy	6700.00
0005432262738	151	Economy	6700.00
0005432289048	151	Economy	6700.00
0005433690935	151	Economy	6700.00
0005433687721	151	Economy	6700.00
0005432262747	151	Economy	6700.00
0005432207707	151	Economy	6700.00
0005432756867	151	Economy	6700.00
0005432262758	151	Economy	6700.00
0005432753317	151	Economy	6700.00
0005432262765	151	Economy	6700.00
0005432262744	151	Economy	6700.00
0005432262732	151	Economy	6700.00
0005432207708	151	Economy	6700.00
0005432818013	151	Economy	6700.00
0005432753329	151	Economy	6700.00
0005432818025	151	Economy	6700.00
0005432262759	151	Economy	6700.00
0005432262725	151	Economy	6700.00
0005432262741	151	Economy	6700.00
0005432262767	151	Economy	6700.00
0005432262763	151	Economy	7300.00
0005432818022	151	Economy	7300.00
0005432262748	151	Economy	7300.00
0005432262727	151	Economy	7300.00
0005433476976	151	Economy	6700.00
0005432262768	151	Economy	6700.00
0005432262742	151	Economy	6700.00
0005433476974	151	Economy	7300.00
0005432818016	151	Economy	6700.00
0005432818009	151	Economy	6700.00
0005433687726	151	Economy	6700.00
0005432818031	151	Economy	6700.00
0005432818028	151	Economy	6700.00
0005432262724	151	Economy	6700.00
0005432262766	151	Economy	6700.00
0005432262730	151	Economy	6700.00
0005433687723	151	Economy	6700.00
0005432818027	151	Economy	6700.00
0005432818026	151	Economy	6700.00
0005432262733	151	Economy	6700.00
0005432262761	151	Economy	6700.00
0005433476978	151	Economy	6700.00
0005432262762	151	Economy	6700.00
0005433476971	151	Economy	6700.00
0005433476977	151	Economy	6700.00
0005432818006	151	Economy	6700.00
0005432818005	151	Economy	6700.00
0005432756866	151	Economy	6700.00
0005432262755	151	Economy	6700.00
0005432753343	151	Economy	6700.00
0005432818017	151	Economy	6700.00
0005433687722	151	Economy	6700.00
0005432818029	151	Economy	6700.00
0005432262753	151	Economy	6700.00
0005432262737	151	Economy	6700.00
0005432262757	151	Economy	6700.00
0005433476972	151	Economy	6700.00
0005432262743	151	Economy	6700.00
0005432262734	151	Economy	6700.00
0005432262736	151	Economy	6700.00
0005432818010	151	Economy	6700.00
0005432818023	151	Economy	6700.00
0005432262729	151	Economy	6700.00
0005432818015	151	Economy	6700.00
0005432753328	151	Economy	6700.00
0005432818008	151	Economy	6700.00
0005432818002	151	Economy	6700.00
0005432262754	151	Economy	6700.00
0005432818011	151	Economy	6700.00
0005432920237	7979	Business	20000.00
0005432020742	7979	Business	20000.00
0005433103139	7979	Business	20000.00
0005432045650	7979	Business	20000.00
0005432020749	7979	Business	20000.00
0005432020754	7979	Business	20000.00
0005433103126	7979	Business	20000.00
0005433103140	7979	Business	20000.00
0005432920232	7979	Business	20000.00
0005433103148	7979	Business	20000.00
0005432044576	7979	Business	20000.00
0005432020753	7979	Business	20000.00
0005432753363	7979	Business	20000.00
0005432753362	7979	Business	20000.00
0005432920236	7979	Business	20000.00
0005432920234	7979	Business	20000.00
0005432392056	7979	Business	20000.00
0005432920251	7979	Business	20000.00
0005432920235	7979	Business	20000.00
0005432020760	7979	Economy	7300.00
0005432677648	7979	Economy	7300.00
0005432920246	7979	Economy	7300.00
0005433103129	7979	Economy	7300.00
0005433103135	7979	Economy	6700.00
0005433103133	7979	Economy	6700.00
0005433103108	7979	Economy	6700.00
0005432920242	7979	Economy	6700.00
0005433103105	7979	Economy	6700.00
0005433103114	7979	Economy	6700.00
0005432751589	7979	Economy	6700.00
0005432392055	7979	Economy	6700.00
0005432920249	7979	Economy	6700.00
0005432920230	7979	Economy	6700.00
0005432020758	7979	Economy	6700.00
0005432020768	7979	Economy	6700.00
0005432020761	7979	Economy	6700.00
0005433103123	7979	Economy	6700.00
0005433103125	7979	Economy	6700.00
0005432020747	7979	Economy	6700.00
0005432677650	7979	Economy	6700.00
0005432020743	7979	Economy	6700.00
0005432920248	7979	Economy	6700.00
0005432920243	7979	Economy	6700.00
0005433103146	7979	Economy	6700.00
0005432020766	7979	Economy	6700.00
0005432020765	7979	Economy	6700.00
0005432020744	7979	Economy	6700.00
0005432753366	7979	Economy	6700.00
0005433103151	7979	Economy	6700.00
0005433103138	7979	Economy	6700.00
0005433103121	7979	Economy	6700.00
0005432020740	7979	Economy	6700.00
0005432751587	7979	Economy	6700.00
0005433103145	7979	Economy	6700.00
0005432020759	7979	Economy	6700.00
0005432020755	7979	Economy	6700.00
0005432020746	7979	Economy	6700.00
0005433103116	7979	Economy	6700.00
0005433103134	7979	Economy	6700.00
0005433103150	7979	Economy	6700.00
0005433103115	7979	Economy	6700.00
0005432020752	7979	Economy	6700.00
0005433103112	7979	Economy	6700.00
0005432920241	7979	Economy	6700.00
0005433103137	7979	Economy	7300.00
0005432753365	7979	Economy	7300.00
0005433103149	7979	Economy	7300.00
0005432020757	7979	Economy	7300.00
0005432020750	7979	Economy	6700.00
0005433103128	7979	Economy	6700.00
0005433103130	7979	Economy	6700.00
0005433103127	7979	Economy	6700.00
0005433103111	7979	Economy	6700.00
0005433103122	7979	Economy	6700.00
0005432920245	7979	Economy	6700.00
0005433103144	7979	Economy	6700.00
0005433103124	7979	Economy	6700.00
0005432020767	7979	Economy	6700.00
0005432392054	7979	Economy	6700.00
0005432920247	7979	Economy	6700.00
0005433103141	7979	Economy	6700.00
0005433103104	7979	Economy	6700.00
0005433103110	7979	Economy	6700.00
0005432920231	7979	Economy	6700.00
0005433103106	7979	Economy	6700.00
0005432020763	7979	Economy	6700.00
0005433103107	7979	Economy	6700.00
0005432020748	7979	Economy	6700.00
0005433103117	7979	Economy	6700.00
0005432920240	7979	Economy	6700.00
0005432044575	7979	Economy	6700.00
0005433103131	7979	Economy	6700.00
0005432677649	7979	Economy	6700.00
0005433103109	7979	Economy	6700.00
0005432751588	7979	Economy	6700.00
0005432020741	7979	Economy	6700.00
0005432020764	7979	Economy	6700.00
0005433103120	7979	Economy	6700.00
0005432677646	7979	Economy	6700.00
0005432920233	7979	Economy	6700.00
0005433103143	7979	Economy	6700.00
0005433103132	7979	Economy	6700.00
0005432920238	7979	Economy	6700.00
0005432677647	7979	Economy	6700.00
0005433103119	7979	Economy	6700.00
0005432920244	7979	Economy	6700.00
0005432020762	7979	Economy	6700.00
0005433103118	7979	Economy	6700.00
0005433103142	7979	Economy	6700.00
0005432920239	7979	Economy	6700.00
0005432920250	7979	Economy	6700.00
0005433103113	7979	Economy	6700.00
0005432753364	7979	Economy	6700.00
0005432020756	7979	Economy	6700.00
0005433103147	7979	Economy	6700.00
0005432020751	7979	Economy	6700.00
0005433103136	7979	Economy	6700.00
0005432020745	7979	Economy	6700.00
0005432901939	7992	Business	20000.00
0005432817896	7992	Business	20000.00
0005432817687	7992	Business	20000.00
0005432901934	7992	Business	20000.00
0005432901928	7992	Business	20000.00
0005432817947	7992	Business	20000.00
0005432817672	7992	Business	20000.00
0005434513601	7992	Business	20000.00
0005434513602	7992	Business	20000.00
0005434513600	7992	Business	20000.00
0005432901932	7992	Business	20000.00
0005432817561	7992	Economy	7300.00
0005434513610	7992	Economy	7300.00
0005432002115	7992	Economy	6700.00
0005432817688	7992	Economy	6700.00
0005432901927	7992	Economy	6700.00
0005432901937	7992	Economy	6700.00
0005432817778	7992	Economy	6700.00
0005432901926	7992	Economy	6700.00
0005432901931	7992	Economy	6700.00
0005432817717	7992	Economy	6700.00
0005432817804	7992	Economy	6700.00
0005432817841	7992	Economy	6700.00
0005432817815	7992	Economy	6700.00
0005432817606	7992	Economy	6700.00
0005432817673	7992	Economy	6700.00
0005432817683	7992	Economy	6700.00
0005432817787	7992	Economy	6700.00
0005432817892	7992	Economy	6700.00
0005432817607	7992	Economy	6700.00
0005432817884	7992	Economy	6700.00
0005432817795	7992	Economy	6700.00
0005432817885	7992	Economy	6700.00
0005432901940	7992	Economy	6700.00
0005432817682	7992	Economy	7300.00
0005432901938	7992	Economy	6700.00
0005432901925	7992	Economy	6700.00
0005432817562	7992	Economy	6700.00
0005432817779	7992	Economy	6700.00
0005432901930	7992	Economy	6700.00
0005432817786	7992	Economy	6700.00
0005432901924	7992	Economy	6700.00
0005432817753	7992	Economy	6700.00
0005432817620	7992	Economy	6700.00
0005432901929	7992	Economy	6700.00
0005432002114	7992	Economy	6700.00
0005432817814	7992	Economy	6700.00
0005432817708	7992	Economy	6700.00
0005432901936	7992	Economy	6700.00
0005432817608	7992	Economy	6700.00
0005432901935	7992	Economy	6700.00
0005432817806	7992	Economy	6700.00
0005432901923	7992	Economy	6700.00
0005432817948	7992	Economy	6700.00
0005432901933	7992	Economy	6700.00
0005434175800	9663	Economy	6900.00
0005434175801	9663	Economy	6900.00
0005433870772	9663	Economy	6900.00
0005434175776	9663	Economy	6900.00
0005434175775	9663	Economy	6900.00
0005433870771	9663	Economy	6900.00
0005433870750	32335	Economy	6900.00
0005433870746	32335	Economy	6900.00
0005433870748	32335	Economy	6900.00
0005434175831	32335	Economy	6900.00
0005434175829	32335	Economy	6900.00
0005434175832	32335	Economy	6900.00
0005434175830	32335	Economy	6900.00
0005434879970	3516	Business	35000.00
0005434879924	3516	Business	35000.00
0005435626511	3516	Business	35000.00
0005434879936	3516	Business	35000.00
0005435913945	3516	Business	35000.00
0005434879962	3516	Business	35000.00
0005435626520	3516	Business	35000.00
0005432799989	3516	Business	35000.00
0005434879981	3516	Business	35000.00
0005435626524	3516	Business	35000.00
0005435902915	3516	Business	35000.00
0005435626529	3516	Business	35000.00
0005434938510	3516	Business	35000.00
0005435127132	3516	Business	35000.00
0005434879984	3516	Business	35000.00
0005434938499	3516	Business	35000.00
0005435127142	3516	Business	35000.00
0005434879925	3516	Business	35000.00
0005435626508	3516	Business	35000.00
0005435626519	3516	Business	35000.00
0005434427150	3516	Comfort	19900.00
0005434879949	3516	Comfort	19900.00
0005434879961	3516	Comfort	19900.00
0005434879987	3516	Comfort	19900.00
0005434880010	3516	Comfort	19900.00
0005432188668	3516	Comfort	19900.00
0005435626522	3516	Comfort	19900.00
0005435902907	3516	Comfort	19900.00
0005434938498	3516	Comfort	19900.00
0005434938504	3516	Comfort	19900.00
0005434427140	3516	Comfort	19900.00
0005435127111	3516	Comfort	19900.00
0005434427168	3516	Comfort	19900.00
0005434879956	3516	Comfort	19900.00
0005432188669	3516	Comfort	19900.00
0005432611776	3516	Comfort	19900.00
0005434938502	3516	Comfort	19900.00
0005434879967	3516	Comfort	19900.00
0005432611775	3516	Comfort	19900.00
0005434938505	3516	Comfort	19900.00
0005432799992	3516	Comfort	19900.00
0005434879943	3516	Comfort	19900.00
0005434879922	3516	Comfort	19900.00
0005434879975	3516	Comfort	19900.00
0005434879985	3516	Comfort	19900.00
0005434938509	3516	Comfort	19900.00
0005434879998	3516	Comfort	19900.00
0005435626521	3516	Comfort	19900.00
0005435626509	3516	Comfort	19900.00
0005434880017	3516	Comfort	19900.00
0005434879977	3516	Comfort	19900.00
0005432799965	3516	Comfort	19900.00
0005434427143	3516	Comfort	19900.00
0005434879988	3516	Economy	11700.00
0005435127121	3516	Comfort	19900.00
0005434880000	3516	Economy	11700.00
0005435127136	3516	Economy	11700.00
0005434879974	3516	Economy	11700.00
0005434427147	3516	Economy	11700.00
0005435626510	3516	Economy	11700.00
0005435127115	3516	Economy	11700.00
0005432613939	3516	Economy	11700.00
0005435902862	3516	Economy	11700.00
0005432188667	3516	Economy	11700.00
0005435626518	3516	Economy	11700.00
0005432799983	3516	Economy	11700.00
0005434879959	3516	Economy	11700.00
0005434938512	3516	Economy	11700.00
0005435127105	3516	Economy	11700.00
0005435626507	3516	Economy	11700.00
0005434880015	3516	Economy	11700.00
0005434879923	3516	Economy	11700.00
0005434880001	3516	Economy	11700.00
0005434879995	3516	Economy	11700.00
0005432799971	3516	Economy	11700.00
0005435626516	3516	Economy	11700.00
0005432799986	3516	Economy	11700.00
0005434879993	3516	Economy	11700.00
0005434879933	3516	Economy	11700.00
0005434427144	3516	Economy	11700.00
0005432613935	3516	Economy	11700.00
0005432799968	3516	Economy	11700.00
0005434938506	3516	Economy	11700.00
0005432799966	3516	Economy	11700.00
0005432799970	3516	Economy	11700.00
0005434879927	3516	Economy	11700.00
0005435127131	3516	Economy	11700.00
0005434879979	3516	Economy	11700.00
0005432613938	3516	Economy	11700.00
0005435626513	3516	Economy	11700.00
0005434427169	3516	Economy	11700.00
0005435127108	3516	Economy	11700.00
0005434880003	3516	Economy	11700.00
0005434427158	3516	Economy	11700.00
0005434879944	3516	Economy	11700.00
0005434938511	3516	Economy	11700.00
0005434880014	3516	Economy	11700.00
0005435127119	3516	Economy	12800.00
0005434938501	3516	Economy	11700.00
0005435127140	3516	Economy	11700.00
0005434880007	3516	Economy	11700.00
0005434879992	3516	Economy	12800.00
0005434427141	3516	Economy	12800.00
0005435626512	3516	Economy	12800.00
0005432799969	3516	Economy	11700.00
0005434879942	3516	Economy	11700.00
0005434879969	3516	Economy	11700.00
0005432799985	3516	Economy	11700.00
0005432799984	3516	Economy	11700.00
0005434879928	3516	Economy	11700.00
0005434880006	3516	Economy	11700.00
0005435902826	3516	Economy	11700.00
0005435127143	3516	Economy	11700.00
0005434880004	3516	Economy	11700.00
0005434879999	3516	Economy	11700.00
0005435127114	3516	Economy	11700.00
0005435127130	3516	Economy	11700.00
0005434879965	3516	Economy	11700.00
0005434879954	3516	Economy	11700.00
0005435841829	3516	Economy	11700.00
0005434879960	3516	Economy	11700.00
0005434427142	3516	Economy	11700.00
0005432799967	3516	Economy	11700.00
0005434879971	3516	Economy	11700.00
0005434879937	3516	Economy	11700.00
0005432799990	3516	Economy	11700.00
0005435902942	3516	Economy	11700.00
0005434879945	3516	Economy	11700.00
0005434938503	3516	Economy	11700.00
0005434427146	3516	Economy	11700.00
0005432183506	3516	Economy	11700.00
0005434879983	3516	Economy	11700.00
0005432799988	3516	Economy	11700.00
0005435127126	3516	Economy	11700.00
0005435127147	3516	Economy	11700.00
0005432799981	3516	Economy	11700.00
0005434880011	3516	Economy	11700.00
0005434879950	3516	Economy	11700.00
0005434427149	3516	Economy	11700.00
0005435626526	3516	Economy	11700.00
0005434879934	3516	Economy	11700.00
0005432799977	3516	Economy	11700.00
0005434879957	3516	Economy	11700.00
0005434879953	3516	Economy	11700.00
0005434427160	3516	Economy	11700.00
0005432183507	3516	Economy	11700.00
0005435902906	3516	Economy	11700.00
0005434880009	3516	Economy	11700.00
0005434879938	3516	Economy	11700.00
0005435902867	3516	Economy	11700.00
0005434879976	3516	Economy	11700.00
0005434879978	3516	Economy	11700.00
0005434879940	3516	Economy	11700.00
0005435127125	3516	Economy	11700.00
0005435127120	3516	Economy	11700.00
0005432799972	3516	Economy	11700.00
0005434427155	3516	Economy	11700.00
0005435626528	3516	Economy	11700.00
0005434880002	3516	Economy	11700.00
0005435127128	3516	Economy	11700.00
0005434880013	3516	Economy	11700.00
0005434879963	3516	Economy	11700.00
0005434879932	3516	Economy	11700.00
0005435626527	3516	Economy	11700.00
0005434427164	3516	Economy	11700.00
0005434879955	3516	Economy	11700.00
0005435127133	3516	Economy	11700.00
0005435626517	3516	Economy	11700.00
0005434938508	3516	Economy	11700.00
0005434880016	3516	Economy	11700.00
0005435626523	3516	Economy	11700.00
0005434427157	3516	Economy	11700.00
0005432799975	3516	Economy	11700.00
0005434879929	3516	Economy	11700.00
0005434427167	3516	Economy	11700.00
0005434879939	3516	Economy	11700.00
0005432613937	3516	Economy	11700.00
0005434879966	3516	Economy	11700.00
0005434879990	3516	Economy	11700.00
0005434879926	3516	Economy	11700.00
0005434879952	3516	Economy	11700.00
0005432799974	3516	Economy	11700.00
0005435626525	3516	Economy	12800.00
0005434879946	3516	Economy	12800.00
0005434427156	3516	Economy	12800.00
0005434879986	3516	Economy	12800.00
0005435127118	3516	Economy	11700.00
0005434879935	3516	Economy	11700.00
0005434879941	3516	Economy	11700.00
0005435127107	3516	Economy	11700.00
0005434879931	3516	Economy	11700.00
0005434427145	3516	Economy	11700.00
0005435127139	3516	Economy	11700.00
0005434879980	3516	Economy	11700.00
0005435127135	3516	Economy	11700.00
0005435127138	3516	Economy	11700.00
0005432613936	3516	Economy	11700.00
0005435902884	3516	Economy	11700.00
0005434879982	3516	Economy	11700.00
0005434879947	3516	Economy	11700.00
0005435127116	3516	Economy	11700.00
0005435127106	3516	Economy	11700.00
0005434427148	3516	Economy	11700.00
0005434427165	3516	Economy	11700.00
0005434880018	3516	Economy	11700.00
0005432799991	3516	Economy	11700.00
0005434938500	3516	Economy	11700.00
0005435127113	3516	Economy	11700.00
0005434879972	3516	Economy	11700.00
0005432799987	3516	Economy	11700.00
0005434938495	3516	Economy	11700.00
0005434879996	3516	Economy	11700.00
0005435127109	3516	Economy	11700.00
0005434427152	3516	Economy	11700.00
0005434938496	3516	Economy	11700.00
0005434879964	3516	Economy	11700.00
0005434880005	3516	Economy	11700.00
0005434427151	3516	Economy	11700.00
0005432611777	3516	Economy	11700.00
0005434879930	3516	Economy	11700.00
0005435127141	3516	Economy	11700.00
0005435626515	3516	Economy	11700.00
0005435127134	3516	Economy	11700.00
0005435913944	3516	Economy	11700.00
0005432799976	3516	Economy	11700.00
0005434938497	3516	Economy	11700.00
0005435127137	3516	Economy	11700.00
0005434879994	3516	Economy	11700.00
0005432799980	3516	Economy	11700.00
0005434879989	3516	Economy	11700.00
0005435127127	3516	Economy	11700.00
0005432799993	3516	Economy	11700.00
0005434879973	3516	Economy	11700.00
0005434427154	3516	Economy	11700.00
0005435902919	3516	Economy	11700.00
0005435127129	3516	Economy	11700.00
0005434938507	3516	Economy	11700.00
0005435127145	3516	Economy	11700.00
0005435127146	3516	Economy	11700.00
0005435127117	3516	Economy	11700.00
0005434427166	3516	Economy	11700.00
0005435127110	3516	Economy	11700.00
0005434427162	3516	Economy	11700.00
0005432799982	3516	Economy	11700.00
0005434880008	3516	Economy	11700.00
0005435127144	3516	Economy	11700.00
0005435127122	3516	Economy	11700.00
0005432799978	3516	Economy	11700.00
0005434427159	3516	Economy	11700.00
0005434879948	3516	Economy	11700.00
0005435902872	3516	Economy	11700.00
0005435902871	3516	Economy	11700.00
0005435127112	3516	Economy	11700.00
0005434879951	3516	Economy	11700.00
0005432799979	3516	Economy	11700.00
0005434938494	3516	Economy	11700.00
0005435902799	3516	Economy	11700.00
0005434427163	3516	Economy	11700.00
0005435902902	3516	Economy	11700.00
0005434427153	3516	Economy	11700.00
0005435127124	3516	Economy	11700.00
0005434427161	3516	Economy	11700.00
0005434880012	3516	Economy	11700.00
0005434879991	3516	Economy	11700.00
0005435127123	3516	Economy	11700.00
0005435913959	3516	Economy	11700.00
0005434879997	3516	Economy	11700.00
0005435626514	3516	Economy	11700.00
0005432799973	3516	Economy	11700.00
0005435902885	3516	Economy	11700.00
0005434879958	3516	Economy	11700.00
0005434879968	3516	Economy	11700.00
0005432799730	14567	Business	35000.00
0005434879090	14567	Business	35000.00
0005434879226	14567	Business	35000.00
0005434879200	14567	Business	35000.00
0005434878995	14567	Business	35000.00
0005432799785	14567	Business	35000.00
0005434879271	14567	Business	35000.00
0005434879085	14567	Business	35000.00
0005434938345	14567	Business	35000.00
0005435626332	14567	Business	35000.00
0005435626358	14567	Business	35000.00
0005434879264	14567	Business	35000.00
0005434879201	14567	Business	35000.00
0005434879448	14567	Business	35000.00
0005432607596	14567	Business	35000.00
0005435126541	14567	Business	35000.00
0005434878873	14567	Business	35000.00
0005432607599	14567	Business	35000.00
0005434938398	14567	Business	35000.00
0005432799719	14567	Business	35000.00
0005432799764	14567	Comfort	19900.00
0005434879077	14567	Comfort	19900.00
0005434938412	14567	Comfort	19900.00
0005434879306	14567	Comfort	19900.00
0005434879154	14567	Comfort	19900.00
0005434879182	14567	Comfort	19900.00
0005434879272	14567	Comfort	19900.00
0005432799692	14567	Comfort	19900.00
0005435126540	14567	Comfort	19900.00
0005434426785	14567	Comfort	19900.00
0005435126735	14567	Comfort	19900.00
0005435126818	14567	Comfort	19900.00
0005434878944	14567	Comfort	19900.00
0005434878942	14567	Comfort	19900.00
0005435626312	14567	Comfort	19900.00
0005434938418	14567	Comfort	19900.00
0005434879382	14567	Comfort	19900.00
0005434879175	14567	Comfort	19900.00
0005434879174	14567	Comfort	19900.00
0005434426884	14567	Comfort	19900.00
0005435626279	14567	Comfort	19900.00
0005434879060	14567	Comfort	19900.00
0005434879261	14567	Comfort	19900.00
0005435903028	14567	Comfort	19900.00
0005434879485	14567	Comfort	19900.00
0005435126830	14567	Comfort	19900.00
0005432799645	14567	Comfort	19900.00
0005434426934	14567	Comfort	19900.00
0005434879228	14567	Comfort	19900.00
0005434426881	14567	Comfort	19900.00
0005434879120	14567	Comfort	19900.00
0005435626308	14567	Comfort	19900.00
0005435126717	14567	Comfort	19900.00
0005432799688	14567	Comfort	19900.00
0005435126477	14567	Comfort	19900.00
0005434879489	14567	Economy	11700.00
0005435126653	14567	Economy	11700.00
0005435126476	14567	Economy	11700.00
0005435126443	14567	Economy	11700.00
0005432799740	14567	Economy	11700.00
0005434426941	14567	Economy	11700.00
0005432799783	14567	Economy	11700.00
0005432799748	14567	Economy	11700.00
0005432799797	14567	Economy	11700.00
0005434879199	14567	Economy	11700.00
0005432799738	14567	Economy	11700.00
0005435126896	14567	Economy	11700.00
0005432799751	14567	Economy	11700.00
0005435126764	14567	Economy	11700.00
0005435126701	14567	Economy	11700.00
0005432611751	14567	Economy	11700.00
0005434879319	14567	Economy	11700.00
0005432607617	14567	Economy	11700.00
0005435903034	14567	Economy	11700.00
0005434938316	14567	Economy	11700.00
0005434879335	14567	Economy	11700.00
0005434938250	14567	Economy	11700.00
0005435626315	14567	Economy	11700.00
0005434938352	14567	Economy	11700.00
0005434938384	14567	Economy	11700.00
0005434426920	14567	Economy	11700.00
0005434879397	14567	Economy	11700.00
0005434879351	14567	Economy	11700.00
0005434879172	14567	Economy	11700.00
0005432611760	14567	Economy	11700.00
0005435903036	14567	Economy	11700.00
0005432799646	14567	Economy	11700.00
0005434879063	14567	Economy	11700.00
0005434938317	14567	Economy	11700.00
0005435903023	14567	Economy	11700.00
0005435126734	14567	Economy	11700.00
0005434426873	14567	Economy	11700.00
0005434878892	14567	Economy	11700.00
0005432607595	14567	Economy	11700.00
0005434879193	14567	Economy	11700.00
0005434879004	14567	Economy	11700.00
0005434879486	14567	Economy	11700.00
0005435126822	14567	Economy	11700.00
0005432799734	14567	Economy	11700.00
0005434879006	14567	Economy	11700.00
0005432799744	14567	Economy	11700.00
0005434879206	14567	Economy	11700.00
0005435903039	14567	Economy	11700.00
0005434879191	14567	Economy	11700.00
0005434879456	14567	Economy	11700.00
0005432611737	14567	Economy	11700.00
0005432799778	14567	Economy	11700.00
0005434878931	14567	Economy	11700.00
0005434879297	14567	Economy	12800.00
0005434879207	14567	Economy	12800.00
0005434938347	14567	Economy	11700.00
0005434879014	14567	Economy	11700.00
0005434878945	14567	Economy	11700.00
0005434879505	14567	Economy	11700.00
0005434879245	14567	Economy	11700.00
0005434426912	14567	Economy	12800.00
0005434879153	14567	Economy	11700.00
0005434426858	14567	Economy	11700.00
0005434879097	14567	Economy	11700.00
0005435626283	14567	Economy	11700.00
0005435626310	14567	Economy	11700.00
0005432799742	14567	Economy	11700.00
0005434879030	14567	Economy	11700.00
0005435126576	14567	Economy	11700.00
0005434879393	14567	Economy	11700.00
0005435126809	14567	Economy	11700.00
0005434878893	14567	Economy	11700.00
0005434878638	14567	Economy	11700.00
0005435626314	14567	Economy	11700.00
0005435903033	14567	Economy	11700.00
0005435626336	14567	Economy	11700.00
0005434938331	14567	Economy	11700.00
0005434427039	14567	Economy	11700.00
0005434938428	14567	Economy	11700.00
0005435126733	14567	Economy	11700.00
0005434426983	14567	Economy	11700.00
0005432607602	14567	Economy	11700.00
0005434426946	14567	Economy	11700.00
0005432799765	14567	Economy	11700.00
0005434426948	14567	Economy	11700.00
0005432799670	14567	Economy	11700.00
0005434426866	14567	Economy	11700.00
0005432799801	14567	Economy	11700.00
0005434879038	14567	Economy	11700.00
0005432059540	14567	Economy	11700.00
0005434879208	14567	Economy	11700.00
0005434938371	14567	Economy	11700.00
0005434426938	14567	Economy	11700.00
0005434879350	14567	Economy	11700.00
0005432799680	14567	Economy	11700.00
0005435626346	14567	Economy	11700.00
0005434938408	14567	Economy	11700.00
0005432799741	14567	Economy	11700.00
0005434879065	14567	Economy	11700.00
0005434879265	14567	Economy	11700.00
0005434938315	14567	Economy	11700.00
0005435626318	14567	Economy	11700.00
0005434938348	14567	Economy	11700.00
0005435126895	14567	Economy	11700.00
0005435903031	14567	Economy	11700.00
0005435126779	14567	Economy	11700.00
0005434938399	14567	Economy	11700.00
0005434879121	14567	Economy	11700.00
0005435903038	14567	Economy	11700.00
0005432059542	14567	Economy	11700.00
0005432607598	14567	Economy	11700.00
0005435903030	14567	Economy	11700.00
0005434879345	14567	Economy	11700.00
0005434878937	14567	Economy	11700.00
0005435903035	14567	Economy	11700.00
0005435126654	14567	Economy	11700.00
0005434879320	14567	Economy	11700.00
0005435626366	14567	Economy	11700.00
0005434878693	14567	Economy	11700.00
0005435626345	14567	Economy	11700.00
0005434879103	14567	Economy	11700.00
0005432799735	14567	Economy	11700.00
0005434879336	14567	Economy	11700.00
0005435626331	14567	Economy	11700.00
0005434426910	14567	Economy	11700.00
0005432799731	14567	Economy	11700.00
0005435126721	14567	Economy	11700.00
0005435126582	14567	Economy	11700.00
0005434426953	14567	Economy	11700.00
0005434879066	14567	Economy	11700.00
0005435903025	14567	Economy	11700.00
0005434879165	14567	Economy	11700.00
0005435126810	14567	Economy	11700.00
0005435126821	14567	Economy	11700.00
0005435626309	14567	Economy	11700.00
0005432059541	14567	Economy	11700.00
0005434879344	14567	Economy	11700.00
0005434938351	14567	Economy	11700.00
0005434879056	14567	Economy	11700.00
0005434879089	14567	Economy	11700.00
0005434879091	14567	Economy	11700.00
0005434879040	14567	Economy	11700.00
0005434938320	14567	Economy	11700.00
0005434426909	14567	Economy	11700.00
0005432059543	14567	Economy	11700.00
0005434879298	14567	Economy	11700.00
0005434879173	14567	Economy	11700.00
0005435126879	14567	Economy	11700.00
0005434879398	14567	Economy	11700.00
0005434938335	14567	Economy	11700.00
0005434879122	14567	Economy	12800.00
0005434879296	14567	Economy	12800.00
0005434878868	14567	Economy	12800.00
0005434879223	14567	Economy	12800.00
0005434426964	14567	Economy	11700.00
0005435626324	14567	Economy	12800.00
0005434879224	14567	Economy	11700.00
0005435903032	14567	Economy	11700.00
0005432799802	14567	Economy	11700.00
0005434879095	14567	Economy	11700.00
0005435903027	14567	Economy	11700.00
0005434879079	14567	Economy	11700.00
0005434879225	14567	Economy	11700.00
0005434426982	14567	Economy	11700.00
0005434938452	14567	Economy	11700.00
0005434879281	14567	Economy	11700.00
0005434426841	14567	Economy	11700.00
0005434878930	14567	Economy	11700.00
0005434879295	14567	Economy	11700.00
0005434426933	14567	Economy	11700.00
0005434938330	14567	Economy	11700.00
0005432607594	14567	Economy	11700.00
0005435126711	14567	Economy	11700.00
0005434426836	14567	Economy	11700.00
0005435626284	14567	Economy	11700.00
0005434878943	14567	Economy	11700.00
0005435126640	14567	Economy	11700.00
0005434426965	14567	Economy	11700.00
0005435626325	14567	Economy	11700.00
0005435903037	14567	Economy	11700.00
0005434879119	14567	Economy	11700.00
0005432799729	14567	Economy	11700.00
0005432799811	14567	Economy	11700.00
0005434879490	14567	Economy	11700.00
0005434426942	14567	Economy	11700.00
0005434879282	14567	Economy	11700.00
0005434878996	14567	Economy	11700.00
0005434878950	14567	Economy	11700.00
0005434938319	14567	Economy	11700.00
0005434879039	14567	Economy	11700.00
0005432799743	14567	Economy	11700.00
0005434426845	14567	Economy	11700.00
0005434878946	14567	Economy	11700.00
0005435626347	14567	Economy	11700.00
0005435626355	14567	Economy	11700.00
0005435626356	14567	Economy	11700.00
0005432799679	14567	Economy	11700.00
0005435126819	14567	Economy	11700.00
0005432799758	14567	Economy	11700.00
0005434879161	14567	Economy	11700.00
0005434879283	14567	Economy	11700.00
0005434879305	14567	Economy	11700.00
0005435126580	14567	Economy	11700.00
0005435903029	14567	Economy	11700.00
0005434938235	14567	Economy	11700.00
0005434938261	14567	Economy	11700.00
0005435126808	14567	Economy	11700.00
0005432799794	14567	Economy	11700.00
0005434879394	14567	Economy	11700.00
0005434879468	14567	Economy	11700.00
0005434938289	14567	Economy	11700.00
0005432799662	14567	Economy	11700.00
0005434938391	14567	Economy	11700.00
0005432607597	14567	Economy	11700.00
0005434879229	14567	Economy	11700.00
0005435903026	14567	Economy	11700.00
0005434879045	14567	Economy	11700.00
0005434879031	14567	Economy	11700.00
0005432799661	14567	Economy	11700.00
0005434426947	14567	Economy	11700.00
0005434879194	14567	Economy	11700.00
0005434879495	14567	Economy	11700.00
0005434879086	14567	Economy	11700.00
0005435126823	14567	Economy	11700.00
0005434879047	14567	Economy	11700.00
0005434879469	14567	Economy	11700.00
0005435126581	14567	Economy	11700.00
0005435126720	14567	Economy	11700.00
0005434879078	14567	Economy	11700.00
0005434878876	14567	Economy	11700.00
0005435126712	14567	Economy	11700.00
0005432799784	14567	Economy	11700.00
0005434426815	14567	Economy	11700.00
0005434879411	14567	Economy	11700.00
0005435903024	14567	Economy	11700.00
0005434879005	14567	Economy	11700.00
0005434426857	14567	Economy	11700.00
0005434426882	14567	Economy	11700.00
0005434879179	14567	Economy	11700.00
0005434325859	3612	Economy	16300.00
0005434325868	3612	Economy	16300.00
0005434325858	3612	Economy	14800.00
0005435889958	3612	Economy	14800.00
0005434325857	3612	Economy	14800.00
0005434325860	3612	Economy	14800.00
0005434325865	3612	Economy	14800.00
0005435889959	3612	Economy	14800.00
0005434325863	3612	Economy	14800.00
0005434325861	3612	Economy	14800.00
0005434325867	3612	Economy	14800.00
0005434312356	3612	Economy	14800.00
0005435889968	3612	Economy	14800.00
0005434325866	3612	Economy	14800.00
0005434312357	3612	Economy	14800.00
0005435889967	3612	Economy	14800.00
0005434325862	3612	Economy	14800.00
0005434325864	3612	Economy	14800.00
0005435889960	3612	Economy	14800.00
0005434325743	15648	Economy	16300.00
0005435890006	15648	Economy	14800.00
0005434325812	15648	Economy	14800.00
0005434325778	15648	Economy	14800.00
0005434325748	15648	Economy	14800.00
0005435890010	15648	Economy	14800.00
0005434325756	15648	Economy	14800.00
0005434325772	15648	Economy	14800.00
0005434325779	15648	Economy	14800.00
0005434325749	15648	Economy	14800.00
0005434325800	15648	Economy	14800.00
0005434325757	15648	Economy	14800.00
0005434325810	15648	Economy	14800.00
0005434325801	15648	Economy	14800.00
0005435890009	15648	Economy	14800.00
0005434325771	15648	Economy	14800.00
0005434325766	15648	Economy	14800.00
0005434325809	15648	Economy	14800.00
0005435890007	15648	Economy	14800.00
0005434325798	15648	Economy	14800.00
0005434325808	15648	Economy	14800.00
0005435890008	15648	Economy	14800.00
0005435957967	631	Economy	4500.00
0005435957974	631	Economy	4100.00
0005433420464	631	Economy	4100.00
0005435957973	631	Economy	4100.00
0005433420516	631	Economy	4100.00
0005433420431	631	Economy	4100.00
0005433420490	631	Economy	4100.00
0005433420491	631	Economy	4100.00
0005433420461	631	Economy	4100.00
0005435957972	631	Economy	4100.00
0005435957968	631	Economy	4100.00
0005435957981	631	Economy	4100.00
0005435957970	631	Economy	4100.00
0005433420476	631	Economy	4100.00
0005433420469	631	Economy	4100.00
0005435957979	631	Economy	4100.00
0005433420497	631	Economy	4100.00
0005435957971	631	Economy	4100.00
0005433420489	631	Economy	4100.00
0005435957978	631	Economy	4100.00
0005433420457	631	Economy	4100.00
0005433420501	631	Economy	4100.00
0005435957975	631	Economy	4100.00
0005433420475	631	Economy	4100.00
0005435957977	631	Economy	4100.00
0005435957980	631	Economy	4100.00
0005435957976	631	Economy	4100.00
0005435957969	631	Economy	4100.00
0005433420477	631	Economy	4100.00
0005433420424	631	Economy	4100.00
0005433420558	15203	Economy	4500.00
0005435957794	15203	Economy	4500.00
0005435957817	15203	Economy	4500.00
0005435957825	15203	Economy	4100.00
0005435957836	15203	Economy	4100.00
0005433420563	15203	Economy	4100.00
0005433420560	15203	Economy	4100.00
0005433420561	15203	Economy	4100.00
0005435957839	15203	Economy	4100.00
0005433420559	15203	Economy	4100.00
0005433420556	15203	Economy	4100.00
0005435957818	15203	Economy	4100.00
0005435957865	15203	Economy	4100.00
0005433420557	15203	Economy	4100.00
0005433420562	15203	Economy	4100.00
0005435957893	15203	Economy	4100.00
0005433420555	15203	Economy	4100.00
0005435957829	15203	Economy	4100.00
0005435957864	15203	Economy	4100.00
0005435957826	15203	Economy	4100.00
0005435957795	15203	Economy	4100.00
0005435219218	27268	Economy	28100.00
0005435216600	27268	Economy	28100.00
0005435221063	27268	Economy	25500.00
0005435219220	27268	Economy	25500.00
0005435219210	27268	Economy	25500.00
0005435221062	27268	Economy	25500.00
0005435216611	27268	Economy	25500.00
0005435216595	27268	Economy	25500.00
0005435219226	27268	Economy	25500.00
0005435219205	27268	Economy	25500.00
0005435219225	27268	Economy	25500.00
0005435219212	27268	Economy	25500.00
0005435219213	27268	Economy	25500.00
0005435219216	27268	Economy	25500.00
0005435219219	27268	Economy	25500.00
0005435219209	27268	Economy	25500.00
0005435216601	27268	Economy	25500.00
0005435216629	31780	Economy	28100.00
0005435217747	31780	Economy	28100.00
0005435216625	31780	Economy	28100.00
0005435218128	31780	Economy	28100.00
0005435216626	31780	Economy	25500.00
0005435218126	31780	Economy	25500.00
0005435216630	31780	Economy	25500.00
0005435218124	31780	Economy	25500.00
0005435217751	31780	Economy	25500.00
0005435216623	31780	Economy	25500.00
0005435216627	31780	Economy	25500.00
0005435217749	31780	Economy	25500.00
0005435216621	31780	Economy	25500.00
0005435217753	31780	Economy	25500.00
0005435217750	31780	Economy	25500.00
0005435218125	31780	Economy	25500.00
0005435217752	31780	Economy	25500.00
0005435216628	31780	Economy	25500.00
0005435216622	31780	Economy	25500.00
0005435216624	31780	Economy	25500.00
0005435218123	31780	Economy	25500.00
0005435218127	31780	Economy	25500.00
0005435217748	31780	Economy	25500.00
0005434247174	8856	Economy	10400.00
0005434247176	8856	Economy	10400.00
0005435629426	8856	Economy	10400.00
0005434247175	8856	Economy	10400.00
0005434247184	8856	Economy	10400.00
0005435629427	8856	Economy	10400.00
0005434247195	16000	Economy	10400.00
0005434247196	16000	Economy	10400.00
0005434467802	4003	Economy	23400.00
0005434467800	4003	Economy	21200.00
0005434467807	4003	Economy	21200.00
0005434467803	4003	Economy	21200.00
0005434467808	4003	Economy	21200.00
0005434467799	4003	Economy	21200.00
0005434467798	4003	Economy	21200.00
0005434467801	4003	Economy	21200.00
0005434467805	4003	Economy	21200.00
0005434467806	4003	Economy	21200.00
0005434467804	4003	Economy	21200.00
0005434467783	23213	Economy	23400.00
0005434467780	23213	Economy	21200.00
0005434467777	23213	Economy	21200.00
0005434467788	23213	Economy	21200.00
0005434467760	23213	Economy	21200.00
0005434467786	23213	Economy	21200.00
0005434467782	23213	Economy	21200.00
0005434467787	23213	Economy	21200.00
0005434467759	23213	Economy	21200.00
0005435163330	4442	Economy	13400.00
0005435163324	4442	Economy	13400.00
0005435933483	4442	Economy	12200.00
0005435163331	4442	Economy	12200.00
0005435933480	4442	Economy	12200.00
0005435163328	4442	Economy	12200.00
0005435163329	4442	Economy	12200.00
0005435163326	4442	Economy	12200.00
0005435933482	4442	Economy	12200.00
0005435933496	4442	Economy	12200.00
0005435163320	4442	Economy	12200.00
0005435163317	4442	Economy	12200.00
0005435933490	4442	Economy	12200.00
0005435933478	4442	Economy	12200.00
0005435933479	4442	Economy	12200.00
0005435933481	4442	Economy	12200.00
0005435933486	4442	Economy	12200.00
0005435163332	4442	Economy	12200.00
0005435163323	4442	Economy	12200.00
0005435933485	4442	Economy	12200.00
0005435163319	4442	Economy	12200.00
0005435163321	4442	Economy	12200.00
0005435163318	4442	Economy	12200.00
0005435163322	4442	Economy	12200.00
0005435163325	4442	Economy	12200.00
0005435933484	4442	Economy	12200.00
0005435933475	4442	Economy	12200.00
0005435163327	4442	Economy	12200.00
0005435163289	29505	Economy	13400.00
0005435163260	29505	Economy	12200.00
0005435933517	29505	Economy	12200.00
0005435933520	29505	Economy	12200.00
0005435163243	29505	Economy	12200.00
0005435163302	29505	Economy	12200.00
0005435933514	29505	Economy	12200.00
0005435163282	29505	Economy	12200.00
0005435163274	29505	Economy	12200.00
0005435163291	29505	Economy	12200.00
0005435163283	29505	Economy	12200.00
0005435163290	29505	Economy	12200.00
0005435163293	29505	Economy	12200.00
0005435163271	29505	Economy	12200.00
0005435933521	29505	Economy	12200.00
0005435933518	29505	Economy	12200.00
0005435933519	29505	Economy	12200.00
0005435933516	29505	Economy	12200.00
0005435933515	29505	Economy	12200.00
0005435163269	29505	Economy	12200.00
0005435229502	6834	Business	87700.00
0005435229496	6834	Business	87700.00
0005432646230	6834	Business	87700.00
0005432646203	6834	Business	87700.00
0005432646209	6834	Business	87700.00
0005432646213	6834	Business	87700.00
0005432646229	6834	Business	87700.00
0005432646211	6834	Business	87700.00
0005435229519	6834	Business	87700.00
0005432646196	6834	Business	87700.00
0005432646228	6834	Business	87700.00
0005432646193	6834	Economy	29200.00
0005432646210	6834	Economy	29200.00
0005435229459	6834	Economy	29200.00
0005432646200	6834	Economy	29200.00
0005432646195	6834	Economy	29200.00
0005432646236	6834	Economy	29200.00
0005432646224	6834	Economy	29200.00
0005432646227	6834	Economy	29200.00
0005432646215	6834	Economy	29200.00
0005432646221	6834	Economy	32200.00
0005435229462	6834	Economy	32200.00
0005432646218	6834	Economy	32200.00
0005435229463	6834	Economy	32200.00
0005435229494	6834	Economy	29200.00
0005435229471	6834	Economy	29200.00
0005432646207	6834	Economy	29200.00
0005432646235	6834	Economy	29200.00
0005435229470	6834	Economy	29200.00
0005432646240	6834	Economy	29200.00
0005432646187	6834	Economy	29200.00
0005432646214	6834	Economy	29200.00
0005432646237	6834	Economy	29200.00
0005435229489	6834	Economy	29200.00
0005435229501	6834	Economy	29200.00
0005435229458	6834	Economy	29200.00
0005432646194	6834	Economy	29200.00
0005432646208	6834	Economy	29200.00
0005432646234	6834	Economy	29200.00
0005432646225	6834	Economy	29200.00
0005432646239	6834	Economy	29200.00
0005432646238	6834	Economy	29200.00
0005435229441	6834	Economy	29200.00
0005435229488	6834	Economy	29200.00
0005432646188	6834	Economy	29200.00
0005432646231	6834	Economy	29200.00
0005432646205	6834	Economy	29200.00
0005435229506	6834	Economy	29200.00
0005435229487	6834	Economy	29200.00
0005435229491	6834	Economy	29200.00
0005435229472	6834	Economy	29200.00
0005432646212	6834	Economy	29200.00
0005432646197	6834	Economy	29200.00
0005435229435	6834	Economy	29200.00
0005432646198	6834	Economy	29200.00
0005432646216	6834	Economy	29200.00
0005435229503	6834	Economy	29200.00
0005432646192	6834	Economy	29200.00
0005435229460	6834	Economy	29200.00
0005435229507	6834	Economy	29200.00
0005435229495	6834	Economy	29200.00
0005435229490	6834	Economy	29200.00
0005432646223	6834	Economy	29200.00
0005432646220	6834	Economy	29200.00
0005435229461	6834	Economy	29200.00
0005435229473	6834	Economy	29200.00
0005435229516	6834	Economy	29200.00
0005432646202	6834	Economy	29200.00
0005432646232	6834	Economy	29200.00
0005432646222	6834	Economy	29200.00
0005432646201	6834	Economy	29200.00
0005435229442	6834	Economy	29200.00
0005435229468	6834	Economy	29200.00
0005432646206	6834	Economy	29200.00
0005435229508	6834	Economy	29200.00
0005435229440	6834	Economy	29200.00
0005435229443	6834	Economy	29200.00
0005432646185	6834	Economy	29200.00
0005432646186	6834	Economy	29200.00
0005432646189	6834	Economy	29200.00
0005432646217	6834	Economy	29200.00
0005432646190	6834	Economy	29200.00
0005435229469	6834	Economy	29200.00
0005432646226	6834	Economy	29200.00
0005432646191	6834	Economy	29200.00
0005432646199	6834	Economy	29200.00
0005435229504	6834	Economy	29200.00
0005435229450	6834	Economy	29200.00
0005432646233	6834	Economy	29200.00
0005432646219	6834	Economy	29200.00
0005432646204	6834	Economy	29200.00
0005435797737	2825	Business	12600.00
0005433404861	2825	Business	12600.00
0005435797742	2825	Business	12600.00
0005433404868	2825	Economy	4200.00
0005433404850	2825	Economy	4200.00
0005435797739	2825	Economy	4200.00
0005433404901	2825	Economy	4200.00
0005435797738	2825	Economy	4200.00
0005433404898	2825	Economy	4200.00
0005435797731	2825	Economy	4200.00
0005435797740	2825	Economy	4200.00
0005435797733	2825	Economy	4200.00
0005433404880	2825	Economy	4200.00
0005433404879	2825	Economy	4200.00
0005435797732	2825	Economy	4200.00
0005433404874	2825	Economy	4200.00
0005435797730	2825	Economy	4200.00
0005435797741	2825	Economy	4200.00
0005433404863	2825	Economy	4200.00
0005433404867	2825	Economy	4200.00
0005433404888	2825	Economy	4200.00
0005435797735	2825	Economy	4200.00
0005435797734	2825	Economy	4200.00
0005435797736	2825	Economy	4200.00
0005433404862	2825	Economy	4200.00
0005435797729	2825	Economy	4200.00
0005435797608	29311	Business	12600.00
0005435797571	29311	Business	12600.00
0005435797658	29311	Economy	4200.00
0005433404946	29311	Economy	4600.00
0005435797657	29311	Economy	4600.00
0005433404947	29311	Economy	4600.00
0005435797555	29311	Economy	4200.00
0005435797655	29311	Economy	4200.00
0005435797619	29311	Economy	4200.00
0005435797643	29311	Economy	4200.00
0005433404949	29311	Economy	4200.00
0005433404950	29311	Economy	4200.00
0005435797656	29311	Economy	4200.00
0005433404945	29311	Economy	4200.00
0005435797570	29311	Economy	4200.00
0005435797612	29311	Economy	4200.00
0005433404951	29311	Economy	4200.00
0005435797679	29311	Economy	4200.00
0005435797640	29311	Economy	4200.00
0005435797575	29311	Economy	4200.00
0005435797644	29311	Economy	4200.00
0005435797621	29311	Economy	4200.00
0005433404948	29311	Economy	4200.00
0005435376382	5815	Economy	6800.00
0005435376370	5815	Economy	6800.00
0005435376381	5815	Economy	6800.00
0005435376376	5815	Economy	6800.00
0005435376377	5815	Economy	6800.00
0005434948177	5820	Economy	6800.00
0005434948176	5820	Economy	6800.00
0005434948173	5820	Economy	6800.00
0005434948169	5820	Economy	6800.00
0005434948170	5820	Economy	6800.00
0005434948172	5820	Economy	6800.00
0005434948178	5820	Economy	6800.00
0005434948171	5820	Economy	6800.00
0005434948174	5820	Economy	6800.00
0005434948175	5820	Economy	6800.00
0005435376402	16384	Economy	6800.00
0005434948100	16384	Economy	6800.00
0005434948139	16384	Economy	6800.00
0005434948140	16384	Economy	6800.00
0005435376406	16384	Economy	6800.00
0005434948107	16384	Economy	6800.00
0005434948102	16384	Economy	6800.00
0005435376405	16384	Economy	6800.00
0005434948106	16384	Economy	6800.00
0005435376404	16384	Economy	6800.00
0005434948101	16384	Economy	6800.00
0005435376403	16384	Economy	6800.00
0005433961949	6866	Business	21400.00
0005433961972	6866	Business	21400.00
0005433961909	6866	Business	21400.00
0005433961965	6866	Business	21400.00
0005433961937	6866	Business	21400.00
0005433961923	6866	Business	21400.00
0005433961963	6866	Business	21400.00
0005433961934	6866	Business	21400.00
0005433961944	6866	Business	21400.00
0005433961921	6866	Business	21400.00
0005433961956	6866	Economy	7100.00
0005433961926	6866	Economy	7100.00
0005433961971	6866	Economy	7100.00
0005433961927	6866	Economy	7100.00
0005433961929	6866	Economy	7100.00
0005433961911	6866	Economy	7100.00
0005433961970	6866	Economy	7100.00
0005433961946	6866	Economy	7100.00
0005433961935	6866	Economy	7100.00
0005433961964	6866	Economy	7100.00
0005433961928	6866	Economy	7800.00
0005433961917	6866	Economy	7800.00
0005433961930	6866	Economy	7800.00
0005433961931	6866	Economy	7800.00
0005433961932	6866	Economy	7100.00
0005433961907	6866	Economy	7100.00
0005433961952	6866	Economy	7100.00
0005433961947	6866	Economy	7100.00
0005433961953	6866	Economy	7100.00
0005433961962	6866	Economy	7100.00
0005433961938	6866	Economy	7100.00
0005433961950	6866	Economy	7100.00
0005433961920	6866	Economy	7100.00
0005433961957	6866	Economy	7100.00
0005433961955	6866	Economy	7100.00
0005433961969	6866	Economy	7100.00
0005433961915	6866	Economy	7100.00
0005433961951	6866	Economy	7100.00
0005433961924	6866	Economy	7100.00
0005433961922	6866	Economy	7100.00
0005433961943	6866	Economy	7100.00
0005433961941	6866	Economy	7100.00
0005433961912	6866	Economy	7100.00
0005433961954	6866	Economy	7100.00
0005433961966	6866	Economy	7100.00
0005433961958	6866	Economy	7100.00
0005433961936	6866	Economy	7100.00
0005433961940	6866	Economy	7100.00
0005433961916	6866	Economy	7100.00
0005433961942	6866	Economy	7100.00
0005433961925	6866	Economy	7100.00
0005433961967	6866	Economy	7100.00
0005433961948	6866	Economy	7100.00
0005433961960	6866	Economy	7100.00
0005433961973	6866	Economy	7100.00
0005433961933	6866	Economy	7100.00
0005433961908	6866	Economy	7100.00
0005433961961	6866	Economy	7100.00
0005433961959	6866	Economy	7100.00
0005433961914	6866	Economy	7100.00
0005433961913	6866	Economy	7100.00
0005433961968	6866	Economy	7100.00
0005433961939	6866	Economy	7100.00
0005433961945	6866	Economy	7100.00
0005433961919	6866	Economy	7100.00
0005433961910	6866	Economy	7100.00
0005433961918	6866	Economy	7100.00
0005433960998	25793	Business	21400.00
0005433961126	25793	Business	21400.00
0005433961351	25793	Business	21400.00
0005433961298	25793	Business	21400.00
0005433961316	25793	Business	21400.00
0005433961228	25793	Business	21400.00
0005433961083	25793	Business	21400.00
0005433961345	25793	Business	21400.00
0005433961307	25793	Business	21400.00
0005433960912	25793	Economy	7100.00
0005433961288	25793	Economy	7100.00
0005433961248	25793	Economy	7100.00
0005433961269	25793	Economy	7100.00
0005433961242	25793	Economy	7100.00
0005433961342	25793	Economy	7800.00
0005433961319	25793	Economy	7800.00
0005433961061	25793	Economy	7800.00
0005433961176	25793	Economy	7100.00
0005433961131	25793	Economy	7100.00
0005433961343	25793	Economy	7100.00
0005433961113	25793	Economy	7100.00
0005433961376	25793	Economy	7100.00
0005433961218	25793	Economy	7100.00
0005433961341	25793	Economy	7100.00
0005433961366	25793	Economy	7100.00
0005433961308	25793	Economy	7100.00
0005433961112	25793	Economy	7100.00
0005433961306	25793	Economy	7100.00
0005433961254	25793	Economy	7100.00
0005433961127	25793	Economy	7100.00
0005433961179	25793	Economy	7100.00
0005433961215	25793	Economy	7100.00
0005433961344	25793	Economy	7100.00
0005433961166	25793	Economy	7100.00
0005433961270	25793	Economy	7100.00
0005433961234	25793	Economy	7100.00
0005433961247	25793	Economy	7100.00
0005433961357	25793	Economy	7100.00
0005433961263	25793	Economy	7100.00
0005433961183	25793	Economy	7100.00
0005433961294	25793	Economy	7100.00
0005433961101	25793	Economy	7100.00
0005433961245	25793	Economy	7100.00
0005433961072	25793	Economy	7100.00
0005433961071	25793	Economy	7100.00
0005433961305	25793	Economy	7100.00
0005433961100	25793	Economy	7100.00
0005433961323	25793	Economy	7100.00
0005433961373	25793	Economy	7100.00
0005433961163	25793	Economy	7100.00
0005433961374	25793	Economy	7100.00
0005433961217	25793	Economy	7100.00
0005433961285	25793	Economy	7100.00
0005433961320	25793	Economy	7100.00
0005433961204	25793	Economy	7100.00
0005433961226	25793	Economy	7100.00
0005435082870	24477	Economy	3900.00
0005435082839	24477	Economy	3900.00
0005435082887	24477	Economy	3900.00
0005435082856	24477	Economy	3900.00
0005435082868	24477	Economy	3900.00
0005435082872	24477	Economy	3900.00
0005435082871	24477	Economy	3900.00
0005435082932	26063	Economy	3900.00
0005435082934	26063	Economy	3900.00
0005435082935	26063	Economy	3900.00
0005435082933	26063	Economy	3900.00
0005435082927	26063	Economy	3900.00
0005435082930	26063	Economy	3900.00
0005435082929	26063	Economy	3900.00
0005435082928	26063	Economy	3900.00
0005435082936	26063	Economy	3900.00
0005435082931	26063	Economy	3900.00
0005434245512	5215	Business	18000.00
0005434245532	5215	Business	18000.00
0005434245508	5215	Business	18000.00
0005434245525	5215	Business	18000.00
0005435286674	5215	Business	18000.00
0005434245522	5215	Business	18000.00
0005434245530	5215	Business	18000.00
0005434245521	5215	Economy	6600.00
0005434245519	5215	Economy	6000.00
0005434245531	5215	Economy	6000.00
0005434245527	5215	Economy	6000.00
0005434245511	5215	Economy	6000.00
0005432166961	5215	Economy	6000.00
0005434245528	5215	Economy	6000.00
0005434245515	5215	Economy	6000.00
0005434245516	5215	Economy	6000.00
0005434245514	5215	Economy	6000.00
0005432166962	5215	Economy	6000.00
0005434245529	5215	Economy	6600.00
0005434245518	5215	Economy	6000.00
0005434245523	5215	Economy	6000.00
0005434245526	5215	Economy	6000.00
0005433534518	5215	Economy	6000.00
0005434245537	5215	Economy	6000.00
0005434245535	5215	Economy	6000.00
0005434245533	5215	Economy	6000.00
0005432166960	5215	Economy	6000.00
0005434245534	5215	Economy	6000.00
0005434245536	5215	Economy	6000.00
0005435286672	5215	Economy	6000.00
0005434245524	5215	Economy	6000.00
0005434245520	5215	Economy	6000.00
0005434245513	5215	Economy	6000.00
0005434245510	5215	Economy	6000.00
0005434245509	5215	Economy	6000.00
0005434245517	5215	Economy	6000.00
0005433616067	5217	Business	18000.00
0005433616019	5217	Business	18000.00
0005433616075	5217	Business	18000.00
0005432106443	5217	Business	18000.00
0005432106470	5217	Business	18000.00
0005432106438	5217	Business	18000.00
0005433785611	5217	Business	18000.00
0005433785616	5217	Business	18000.00
0005433785614	5217	Business	18000.00
0005433616051	5217	Business	18000.00
0005433785626	5217	Business	18000.00
0005432106463	5217	Business	18000.00
0005433785603	5217	Business	18000.00
0005432106460	5217	Business	18000.00
0005433616013	5217	Business	18000.00
0005432665312	5217	Business	18000.00
0005433616022	5217	Business	18000.00
0005432106459	5217	Business	18000.00
0005433785629	5217	Business	18000.00
0005432106436	5217	Business	18000.00
0005433616053	5217	Business	18000.00
0005432106441	5217	Business	18000.00
0005432106448	5217	Business	18000.00
0005433616048	5217	Business	18000.00
0005432667493	5217	Business	18000.00
0005432106432	5217	Business	18000.00
0005433616055	5217	Business	18000.00
0005432106456	5217	Business	18000.00
0005433785628	5217	Economy	6600.00
0005433616027	5217	Economy	6600.00
0005432106445	5217	Economy	6600.00
0005433785602	5217	Economy	6600.00
0005432667494	5217	Economy	6600.00
0005433616009	5217	Economy	6600.00
0005432106458	5217	Economy	6000.00
0005432106473	5217	Economy	6000.00
0005433616070	5217	Economy	6000.00
0005433616041	5217	Economy	6000.00
0005432106462	5217	Economy	6000.00
0005432106457	5217	Economy	6000.00
0005433616028	5217	Economy	6000.00
0005433785612	5217	Economy	6000.00
0005433616068	5217	Economy	6000.00
0005433785597	5217	Economy	6000.00
0005433785624	5217	Economy	6000.00
0005433616046	5217	Economy	6000.00
0005433785618	5217	Economy	6000.00
0005433616047	5217	Economy	6000.00
0005433616016	5217	Economy	6000.00
0005432106472	5217	Economy	6000.00
0005433785607	5217	Economy	6000.00
0005432106461	5217	Economy	6000.00
0005433785627	5217	Economy	6000.00
0005432106469	5217	Economy	6000.00
0005432106451	5217	Economy	6000.00
0005433785599	5217	Economy	6000.00
0005432106442	5217	Economy	6000.00
0005433785615	5217	Economy	6000.00
0005433785606	5217	Economy	6000.00
0005433616006	5217	Economy	6000.00
0005433616038	5217	Economy	6000.00
0005433785610	5217	Economy	6000.00
0005433616032	5217	Economy	6000.00
0005433616044	5217	Economy	6000.00
0005433785613	5217	Economy	6000.00
0005432106431	5217	Economy	6000.00
0005432106471	5217	Economy	6000.00
0005432106453	5217	Economy	6000.00
0005432666428	5217	Economy	6000.00
0005432106468	5217	Economy	6000.00
0005433616058	5217	Economy	6000.00
0005433616035	5217	Economy	6000.00
0005432106447	5217	Economy	6000.00
0005433616039	5217	Economy	6000.00
0005432106467	5217	Economy	6000.00
0005433616076	5217	Economy	6000.00
0005433785609	5217	Economy	6000.00
0005432106475	5217	Economy	6000.00
0005433616008	5217	Economy	6000.00
0005432665313	5217	Economy	6000.00
0005433785630	5217	Economy	6000.00
0005433616030	5217	Economy	6000.00
0005433785601	5217	Economy	6000.00
0005432666427	5217	Economy	6000.00
0005433616078	5217	Economy	6000.00
0005432106449	5217	Economy	6000.00
0005432106464	5217	Economy	6000.00
0005432106466	5217	Economy	6000.00
0005432106433	5217	Economy	6000.00
0005433616061	5217	Economy	6000.00
0005432106439	5217	Economy	6000.00
0005432106465	5217	Economy	6000.00
0005433616052	5217	Economy	6000.00
0005433616045	5217	Economy	6000.00
0005433616072	5217	Economy	6600.00
0005433785600	5217	Economy	6600.00
0005433616014	5217	Economy	6600.00
0005433616049	5217	Economy	6600.00
0005433616057	5217	Economy	6000.00
0005433616043	5217	Economy	6600.00
0005433785604	5217	Economy	6000.00
0005433616064	5217	Economy	6000.00
0005433616042	5217	Economy	6000.00
0005433616054	5217	Economy	6600.00
0005433785617	5217	Economy	6000.00
0005433616018	5217	Economy	6000.00
0005432145150	5217	Economy	6000.00
0005433616050	5217	Economy	6000.00
0005433616015	5217	Economy	6000.00
0005433616069	5217	Economy	6000.00
0005433785608	5217	Economy	6000.00
0005433616033	5217	Economy	6000.00
0005433616074	5217	Economy	6000.00
0005433616024	5217	Economy	6000.00
0005432106450	5217	Economy	6000.00
0005433785621	5217	Economy	6000.00
0005432106430	5217	Economy	6000.00
0005433616021	5217	Economy	6000.00
0005433616029	5217	Economy	6000.00
0005433616080	5217	Economy	6000.00
0005433785625	5217	Economy	6000.00
0005433785620	5217	Economy	6000.00
0005433785598	5217	Economy	6000.00
0005433616023	5217	Economy	6000.00
0005433616062	5217	Economy	6000.00
0005432106429	5217	Economy	6000.00
0005433616020	5217	Economy	6000.00
0005433616010	5217	Economy	6000.00
0005432106454	5217	Economy	6000.00
0005432106452	5217	Economy	6000.00
0005433616071	5217	Economy	6000.00
0005432667491	5217	Economy	6000.00
0005433616012	5217	Economy	6000.00
0005433616063	5217	Economy	6000.00
0005432106474	5217	Economy	6000.00
0005433616059	5217	Economy	6000.00
0005433616060	5217	Economy	6000.00
0005433616079	5217	Economy	6000.00
0005433616036	5217	Economy	6000.00
0005433616077	5217	Economy	6000.00
0005433616037	5217	Economy	6000.00
0005433785622	5217	Economy	6000.00
0005433785619	5217	Economy	6000.00
0005433616025	5217	Economy	6000.00
0005433785605	5217	Economy	6000.00
0005433785631	5217	Economy	6000.00
0005432106440	5217	Economy	6000.00
0005433616017	5217	Economy	6000.00
0005433616007	5217	Economy	6000.00
0005432106444	5217	Economy	6000.00
0005433785623	5217	Economy	6000.00
0005433616011	5217	Economy	6000.00
0005432106455	5217	Economy	6000.00
0005433616056	5217	Economy	6000.00
0005432106434	5217	Economy	6000.00
0005433616065	5217	Economy	6000.00
0005432106446	5217	Economy	6000.00
0005432106435	5217	Economy	6000.00
0005433616031	5217	Economy	6000.00
0005432106427	5217	Economy	6000.00
0005432145149	5217	Economy	6000.00
0005433616026	5217	Economy	6000.00
0005432106428	5217	Economy	6000.00
0005432106426	5217	Economy	6000.00
0005433616034	5217	Economy	6000.00
0005433616040	5217	Economy	6000.00
0005433616066	5217	Economy	6000.00
0005433616073	5217	Economy	6000.00
0005432667492	5217	Economy	6000.00
0005432106437	5217	Economy	6000.00
0005433688825	5219	Business	18000.00
0005434229778	5219	Business	18000.00
0005433815445	5219	Business	18000.00
0005434149950	5219	Business	18000.00
0005434265624	5219	Business	18000.00
0005434229781	5219	Business	18000.00
0005434265609	5219	Business	18000.00
0005435007284	5219	Business	18000.00
0005432336182	5219	Business	18000.00
0005435269786	5219	Business	18000.00
0005435007235	5219	Business	18000.00
0005434229796	5219	Business	18000.00
0005434149943	5219	Business	18000.00
0005435007164	5219	Business	18000.00
0005434229777	5219	Business	18000.00
0005434229780	5219	Business	18000.00
0005434149952	5219	Business	18000.00
0005434265622	5219	Business	18000.00
0005435269794	5219	Business	18000.00
0005435007182	5219	Business	18000.00
0005434229790	5219	Business	18000.00
0005434265602	5219	Economy	6600.00
0005432336172	5219	Economy	6600.00
0005434229785	5219	Economy	6600.00
0005435007326	5219	Economy	6000.00
0005434311246	5219	Economy	6600.00
0005434229784	5219	Economy	6000.00
0005434229788	5219	Economy	6000.00
0005435007222	5219	Economy	6000.00
0005432336178	5219	Economy	6000.00
0005434265607	5219	Economy	6000.00
0005432336153	5219	Economy	6000.00
0005434229791	5219	Economy	6000.00
0005435007232	5219	Economy	6000.00
0005434229779	5219	Economy	6000.00
0005434265606	5219	Economy	6000.00
0005434149948	5219	Economy	6000.00
0005434265617	5219	Economy	6000.00
0005434265626	5219	Economy	6000.00
0005435007166	5219	Economy	6000.00
0005434265610	5219	Economy	6000.00
0005434265613	5219	Economy	6000.00
0005434229789	5219	Economy	6000.00
0005434229792	5219	Economy	6000.00
0005435269796	5219	Economy	6000.00
0005433688826	5219	Economy	6000.00
0005432336183	5219	Economy	6000.00
0005435269772	5219	Economy	6000.00
0005435007321	5219	Economy	6000.00
0005434229795	5219	Economy	6000.00
0005433815432	5219	Economy	6000.00
0005434265619	5219	Economy	6000.00
0005434265614	5219	Economy	6000.00
0005435007286	5219	Economy	6000.00
0005434149944	5219	Economy	6000.00
0005434229797	5219	Economy	6000.00
0005434149954	5219	Economy	6000.00
0005435269797	5219	Economy	6000.00
0005434265620	5219	Economy	6000.00
0005434265623	5219	Economy	6000.00
0005434265603	5219	Economy	6000.00
0005435007165	5219	Economy	6000.00
0005434312340	5219	Economy	6000.00
0005434149953	5219	Economy	6000.00
0005435007263	5219	Economy	6000.00
0005434149949	5219	Economy	6000.00
0005435007226	5219	Economy	6000.00
0005434229787	5219	Economy	6600.00
0005432336154	5219	Economy	6600.00
0005434229783	5219	Economy	6600.00
0005434265618	5219	Economy	6600.00
0005434173592	5219	Economy	6600.00
0005434173596	5219	Economy	6000.00
0005435007221	5219	Economy	6000.00
0005433815431	5219	Economy	6000.00
0005435007244	5219	Economy	6000.00
0005434311237	5219	Economy	6000.00
0005434229793	5219	Economy	6000.00
0005435269798	5219	Economy	6000.00
0005434265621	5219	Economy	6000.00
0005433815428	5219	Economy	6000.00
0005434229782	5219	Economy	6000.00
0005434265616	5219	Economy	6000.00
0005435269793	5219	Economy	6000.00
0005432336166	5219	Economy	6000.00
0005434149946	5219	Economy	6000.00
0005434265608	5219	Economy	6000.00
0005434265612	5219	Economy	6000.00
0005434173595	5219	Economy	6000.00
0005435007209	5219	Economy	6000.00
0005435269771	5219	Economy	6000.00
0005434265611	5219	Economy	6000.00
0005435007210	5219	Economy	6000.00
0005434229786	5219	Economy	6000.00
0005434229776	5219	Economy	6000.00
0005435269787	5219	Economy	6000.00
0005434149945	5219	Economy	6000.00
0005434173594	5219	Economy	6000.00
0005434311244	5219	Economy	6000.00
0005435007320	5219	Economy	6000.00
0005435007207	5219	Economy	6000.00
0005435007285	5219	Economy	6000.00
0005435007196	5219	Economy	6000.00
0005434229775	5219	Economy	6000.00
0005435007225	5219	Economy	6000.00
0005434265601	5219	Economy	6000.00
0005434229794	5219	Economy	6000.00
0005432336087	5219	Economy	6000.00
0005434311245	5219	Economy	6000.00
0005434173593	5219	Economy	6000.00
0005434265625	5219	Economy	6000.00
0005434265605	5219	Economy	6000.00
0005434149947	5219	Economy	6000.00
0005434149942	5219	Economy	6000.00
0005435007245	5219	Economy	6000.00
0005432336135	5219	Economy	6000.00
0005434149951	5219	Economy	6000.00
0005434265615	5219	Economy	6000.00
0005434265604	5219	Economy	6000.00
0005435007322	5219	Economy	6000.00
0005434245093	8362	Business	18000.00
0005434245276	8362	Business	18000.00
0005433785219	8362	Business	18000.00
0005434245306	8362	Business	18000.00
0005433785401	8362	Business	18000.00
0005435269895	8362	Business	18000.00
0005433785191	8362	Economy	6600.00
0005434245346	8362	Business	18000.00
0005434245354	8362	Economy	6600.00
0005432663042	8362	Economy	6600.00
0005434245238	8362	Economy	6600.00
0005433785403	8362	Economy	6600.00
0005433785367	8362	Economy	6000.00
0005433785266	8362	Economy	6000.00
0005433785303	8362	Economy	6000.00
0005432666409	8362	Economy	6000.00
0005433785267	8362	Economy	6000.00
0005434245224	8362	Economy	6000.00
0005434245270	8362	Economy	6000.00
0005434245096	8362	Economy	6000.00
0005434245223	8362	Economy	6000.00
0005433785280	8362	Economy	6000.00
0005433785337	8362	Economy	6000.00
0005432663044	8362	Economy	6000.00
0005433785297	8362	Economy	6000.00
0005433785183	8362	Economy	6000.00
0005434245347	8362	Economy	6000.00
0005435269889	8362	Economy	6000.00
0005432663045	8362	Economy	6000.00
0005435269887	8362	Economy	6000.00
0005432663046	8362	Economy	6000.00
0005434245214	8362	Economy	6000.00
0005433785363	8362	Economy	6000.00
0005433785296	8362	Economy	6600.00
0005432666412	8362	Economy	6000.00
0005433785281	8362	Economy	6600.00
0005435269897	8362	Economy	6000.00
0005434245345	8362	Economy	6000.00
0005435269891	8362	Economy	6600.00
0005435269892	8362	Economy	6000.00
0005435269900	8362	Economy	6000.00
0005433785315	8362	Economy	6000.00
0005435269896	8362	Economy	6000.00
0005435269898	8362	Economy	6000.00
0005434245343	8362	Economy	6000.00
0005432663043	8362	Economy	6000.00
0005435269894	8362	Economy	6000.00
0005434245355	8362	Economy	6000.00
0005434245309	8362	Economy	6000.00
0005434245269	8362	Economy	6000.00
0005433785317	8362	Economy	6000.00
0005432666408	8362	Economy	6000.00
0005433785390	8362	Economy	6000.00
0005434245353	8362	Economy	6000.00
0005433785100	8362	Economy	6000.00
0005433785277	8362	Economy	6000.00
0005434245305	8362	Economy	6000.00
0005434245266	8362	Economy	6000.00
0005433785220	8362	Economy	6000.00
0005435269899	8362	Economy	6000.00
0005435269888	8362	Economy	6000.00
0005434245256	8362	Economy	6000.00
0005435269890	8362	Economy	6000.00
0005433785292	8362	Economy	6000.00
0005434245344	8362	Economy	6000.00
0005433785389	8362	Economy	6000.00
0005435269893	8362	Economy	6000.00
0005433785241	8362	Economy	6000.00
0005433785099	8362	Economy	6000.00
0005433785314	8362	Economy	6000.00
0005434245298	8362	Economy	6000.00
0005433615264	8361	Business	18000.00
0005433615246	8361	Business	18000.00
0005433615446	8361	Business	18000.00
0005433615358	8361	Business	18000.00
0005433615552	8361	Business	18000.00
0005433615575	8361	Business	18000.00
0005433615508	8361	Business	18000.00
0005433615289	8361	Business	18000.00
0005433615543	8361	Business	18000.00
0005433615290	8361	Business	18000.00
0005433615155	8361	Business	18000.00
0005433615381	8361	Business	18000.00
0005433615689	8361	Business	18000.00
0005433615204	8361	Economy	6600.00
0005433615171	8361	Economy	6600.00
0005433615205	8361	Economy	6600.00
0005433615478	8361	Economy	6600.00
0005433615702	8361	Economy	6000.00
0005433615368	8361	Economy	6000.00
0005433615453	8361	Economy	6000.00
0005433615441	8361	Economy	6000.00
0005433615121	8361	Economy	6000.00
0005433615245	8361	Economy	6000.00
0005433615276	8361	Economy	6000.00
0005433615191	8361	Economy	6000.00
0005433615389	8361	Economy	6000.00
0005433615154	8361	Economy	6000.00
0005433615067	8361	Economy	6000.00
0005433615294	8361	Economy	6000.00
0005433615175	8361	Economy	6000.00
0005433615068	8361	Economy	6000.00
0005433615400	8361	Economy	6000.00
0005433615092	8361	Economy	6000.00
0005433615275	8361	Economy	6000.00
0005433615439	8361	Economy	6000.00
0005433615440	8361	Economy	6000.00
0005433615217	8361	Economy	6000.00
0005433615240	8361	Economy	6000.00
0005433615454	8361	Economy	6000.00
0005433615360	8361	Economy	6000.00
0005433615374	8361	Economy	6000.00
0005433615450	8361	Economy	6000.00
0005433615576	8361	Economy	6600.00
0005433615247	8361	Economy	6600.00
0005433615190	8361	Economy	6600.00
0005433615227	8361	Economy	6000.00
0005433615570	8361	Economy	6000.00
0005433615091	8361	Economy	6000.00
0005433615475	8361	Economy	6000.00
0005433615417	8361	Economy	6000.00
0005433615409	8361	Economy	6000.00
0005433615452	8361	Economy	6000.00
0005433615401	8361	Economy	6000.00
0005433615407	8361	Economy	6000.00
0005433615362	8361	Economy	6000.00
0005433615399	8361	Economy	6000.00
0005433615361	8361	Economy	6000.00
0005433615274	8361	Economy	6000.00
0005433615378	8361	Economy	6000.00
0005433615553	8361	Economy	6000.00
0005433615373	8361	Economy	6000.00
0005433615182	8361	Economy	6000.00
0005433615423	8361	Economy	6000.00
0005433615640	8361	Economy	6000.00
0005433615120	8361	Economy	6000.00
0005433615474	8361	Economy	6000.00
0005433615090	8361	Economy	6000.00
0005433615169	8361	Economy	6000.00
0005433615385	8361	Economy	6000.00
0005433615363	8361	Economy	6000.00
0005434265287	8360	Business	18000.00
0005435286724	8360	Business	18000.00
0005435007447	8360	Business	18000.00
0005434265373	8360	Business	18000.00
0005432035467	8360	Business	18000.00
0005432035460	8360	Business	18000.00
0005432035457	8360	Business	18000.00
0005432035451	8360	Business	18000.00
0005432047620	8360	Business	18000.00
0005432035448	8360	Business	18000.00
0005434149838	8360	Business	18000.00
0005433690964	8360	Business	18000.00
0005434265440	8360	Business	18000.00
0005434265389	8360	Business	18000.00
0005435007450	8360	Business	18000.00
0005432035463	8360	Business	18000.00
0005434149843	8360	Business	18000.00
0005434173555	8360	Business	18000.00
0005432035456	8360	Business	18000.00
0005434229625	8360	Business	18000.00
0005433815475	8360	Business	18000.00
0005435007449	8360	Business	18000.00
0005435007442	8360	Business	18000.00
0005433534537	8360	Business	18000.00
0005434229532	8360	Business	18000.00
0005433688848	8360	Business	18000.00
0005433688850	8360	Business	18000.00
0005433690962	8360	Economy	6600.00
0005432336255	8360	Economy	6600.00
0005433688849	8360	Economy	6600.00
0005435007463	8360	Economy	6600.00
0005434149854	8360	Economy	6600.00
0005434265517	8360	Economy	6600.00
0005434265400	8360	Economy	6000.00
0005434265325	8360	Economy	6000.00
0005432047621	8360	Economy	6000.00
0005434229471	8360	Economy	6000.00
0005435007456	8360	Economy	6000.00
0005434265392	8360	Economy	6000.00
0005434229599	8360	Economy	6000.00
0005434265402	8360	Economy	6000.00
0005435286726	8360	Economy	6000.00
0005435007454	8360	Economy	6000.00
0005432336256	8360	Economy	6000.00
0005434229622	8360	Economy	6000.00
0005434149865	8360	Economy	6000.00
0005435007448	8360	Economy	6000.00
0005432035461	8360	Economy	6000.00
0005434265391	8360	Economy	6000.00
0005435007445	8360	Economy	6000.00
0005434265483	8360	Economy	6000.00
0005434229554	8360	Economy	6000.00
0005435007446	8360	Economy	6000.00
0005435007443	8360	Economy	6000.00
0005434265336	8360	Economy	6000.00
0005434229553	8360	Economy	6000.00
0005434265399	8360	Economy	6000.00
0005435007458	8360	Economy	6000.00
0005434265273	8360	Economy	6000.00
0005432035469	8360	Economy	6000.00
0005432035473	8360	Economy	6000.00
0005434265435	8360	Economy	6000.00
0005432035464	8360	Economy	6000.00
0005434229558	8360	Economy	6000.00
0005432336251	8360	Economy	6000.00
0005434265306	8360	Economy	6000.00
0005432336253	8360	Economy	6000.00
0005435007461	8360	Economy	6000.00
0005432336249	8360	Economy	6000.00
0005434149876	8360	Economy	6000.00
0005434229626	8360	Economy	6000.00
0005432336259	8360	Economy	6000.00
0005433690963	8360	Economy	6000.00
0005432035470	8360	Economy	6000.00
0005434229653	8360	Economy	6000.00
0005433815476	8360	Economy	6000.00
0005435286729	8360	Economy	6000.00
0005434265441	8360	Economy	6000.00
0005432035453	8360	Economy	6000.00
0005434173556	8360	Economy	6000.00
0005434149866	8360	Economy	6000.00
0005434265286	8360	Economy	6000.00
0005432035450	8360	Economy	6000.00
0005434149868	8360	Economy	6000.00
0005435007455	8360	Economy	6000.00
0005434265482	8360	Economy	6000.00
0005432336254	8360	Economy	6000.00
0005435007452	8360	Economy	6600.00
0005434229632	8360	Economy	6600.00
0005432035458	8360	Economy	6600.00
0005434229587	8360	Economy	6600.00
0005435286730	8360	Economy	6000.00
0005435007457	8360	Economy	6600.00
0005434229647	8360	Economy	6000.00
0005432035474	8360	Economy	6000.00
0005432336257	8360	Economy	6600.00
0005434265329	8360	Economy	6000.00
0005432035446	8360	Economy	6000.00
0005435007465	8360	Economy	6000.00
0005433689950	8360	Economy	6000.00
0005434265409	8360	Economy	6000.00
0005434265369	8360	Economy	6000.00
0005435286728	8360	Economy	6000.00
0005434265436	8360	Economy	6000.00
0005432035462	8360	Economy	6000.00
0005435286723	8360	Economy	6000.00
0005434149873	8360	Economy	6000.00
0005433534538	8360	Economy	6000.00
0005434229654	8360	Economy	6000.00
0005435007453	8360	Economy	6000.00
0005435007451	8360	Economy	6000.00
0005435007460	8360	Economy	6000.00
0005434311255	8360	Economy	6000.00
0005434149889	8360	Economy	6000.00
0005432336252	8360	Economy	6000.00
0005434311256	8360	Economy	6000.00
0005432035449	8360	Economy	6000.00
0005434265355	8360	Economy	6000.00
0005432035471	8360	Economy	6000.00
0005434265335	8360	Economy	6000.00
0005432035452	8360	Economy	6000.00
0005434265324	8360	Economy	6000.00
0005434265405	8360	Economy	6000.00
0005432035455	8360	Economy	6000.00
0005434265521	8360	Economy	6000.00
0005435007462	8360	Economy	6000.00
0005432035466	8360	Economy	6000.00
0005432035472	8360	Economy	6000.00
0005432047622	8360	Economy	6000.00
0005434265305	8360	Economy	6000.00
0005435007466	8360	Economy	6000.00
0005434265480	8360	Economy	6000.00
0005434229616	8360	Economy	6000.00
0005435286725	8360	Economy	6000.00
0005433815474	8360	Economy	6000.00
0005434149835	8360	Economy	6000.00
0005432035465	8360	Economy	6000.00
0005434265274	8360	Economy	6000.00
0005434149840	8360	Economy	6000.00
0005432336260	8360	Economy	6000.00
0005432035447	8360	Economy	6000.00
0005435007459	8360	Economy	6000.00
0005434229611	8360	Economy	6000.00
0005432035468	8360	Economy	6000.00
0005434229593	8360	Economy	6000.00
0005434229555	8360	Economy	6000.00
0005432035459	8360	Economy	6000.00
0005434265390	8360	Economy	6000.00
0005432035454	8360	Economy	6000.00
0005435286727	8360	Economy	6000.00
0005432336250	8360	Economy	6000.00
0005433815477	8360	Economy	6000.00
0005435007444	8360	Economy	6000.00
0005435007464	8360	Economy	6000.00
0005432336258	8360	Economy	6000.00
0005434229627	8360	Economy	6000.00
0005434229633	8360	Economy	6000.00
0005434229617	8360	Economy	6000.00
0005434229598	8360	Economy	6000.00
0005434229522	8360	Economy	6000.00
0005434639454	12596	Economy	16200.00
0005434639574	12596	Economy	16200.00
0005434639472	12596	Economy	16200.00
0005433202639	12596	Economy	14800.00
0005433202632	12596	Economy	14800.00
0005433202631	12596	Economy	14800.00
0005434639498	12596	Economy	14800.00
0005433202630	12596	Economy	14800.00
0005434639528	12596	Economy	14800.00
0005434639573	12596	Economy	14800.00
0005434639621	12596	Economy	14800.00
0005433202641	12596	Economy	14800.00
0005434639456	12596	Economy	14800.00
0005434639508	12596	Economy	14800.00
0005434639455	12596	Economy	14800.00
0005433202640	12596	Economy	14800.00
0005434639514	12596	Economy	14800.00
0005433202635	12596	Economy	14800.00
0005433202642	12596	Economy	14800.00
0005433202637	12596	Economy	14800.00
0005434639601	12596	Economy	14800.00
0005433202634	12596	Economy	14800.00
0005433202633	12596	Economy	14800.00
0005434639556	12596	Economy	14800.00
0005433202636	12596	Economy	14800.00
0005433202644	12596	Economy	14800.00
0005434639622	12596	Economy	14800.00
0005434639702	12596	Economy	14800.00
0005434639598	12596	Economy	14800.00
0005433202638	12596	Economy	14800.00
0005433202643	12596	Economy	14800.00
0005434639507	12596	Economy	14800.00
0005434639585	12596	Economy	14800.00
0005434639759	23376	Economy	16200.00
0005434639766	23376	Economy	16200.00
0005433202465	23376	Economy	16200.00
0005434639777	23376	Economy	16200.00
0005433202438	23376	Economy	14800.00
0005432290690	23376	Economy	14800.00
0005434639773	23376	Economy	14800.00
0005434639763	23376	Economy	14800.00
0005433202525	23376	Economy	14800.00
0005432290687	23376	Economy	14800.00
0005432290686	23376	Economy	14800.00
0005434639774	23376	Economy	14800.00
0005434639778	23376	Economy	14800.00
0005434639760	23376	Economy	14800.00
0005434639784	23376	Economy	14800.00
0005434639772	23376	Economy	14800.00
0005433202512	23376	Economy	14800.00
0005434639785	23376	Economy	14800.00
0005434639769	23376	Economy	14800.00
0005432290688	23376	Economy	14800.00
0005433202422	23376	Economy	14800.00
0005434639762	23376	Economy	14800.00
0005434639776	23376	Economy	14800.00
0005433202456	23376	Economy	14800.00
0005434639780	23376	Economy	14800.00
0005434639770	23376	Economy	14800.00
0005434639775	23376	Economy	14800.00
0005434639761	23376	Economy	14800.00
0005434639768	23376	Economy	14800.00
0005434639782	23376	Economy	14800.00
0005434639767	23376	Economy	14800.00
0005434639783	23376	Economy	14800.00
0005432290689	23376	Economy	14800.00
0005434639765	23376	Economy	14800.00
0005434639771	23376	Economy	14800.00
0005434639779	23376	Economy	14800.00
0005434639764	23376	Economy	14800.00
0005433202524	23376	Economy	14800.00
0005433202466	23376	Economy	14800.00
0005434639781	23376	Economy	14800.00
0005433202426	23376	Economy	14800.00
0005432329203	21087	Business	18900.00
0005432054359	21087	Business	18900.00
0005432383552	21087	Business	18900.00
0005432329074	21087	Business	18900.00
0005432329296	21087	Business	18900.00
0005432329075	21087	Business	18900.00
0005432329021	21087	Business	18900.00
0005432383289	21087	Business	18900.00
0005432383683	21087	Business	18900.00
0005432329212	21087	Business	18900.00
0005432329300	21087	Business	18900.00
0005432383410	21087	Economy	6300.00
0005432848859	21087	Economy	6300.00
0005432329293	21087	Economy	6300.00
0005432383634	21087	Economy	6300.00
0005432383550	21087	Economy	6300.00
0005432383481	21087	Economy	6300.00
0005432329294	21087	Economy	6300.00
0005432328996	21087	Economy	6300.00
0005432329127	21087	Economy	6300.00
0005432328938	21087	Economy	6900.00
0005432329185	21087	Economy	6900.00
0005432848861	21087	Economy	6900.00
0005432054360	21087	Economy	6900.00
0005432383547	21087	Economy	6900.00
0005432383307	21087	Economy	6300.00
0005432848860	21087	Economy	6300.00
0005432329178	21087	Economy	6300.00
0005432383606	21087	Economy	6300.00
0005432383682	21087	Economy	6300.00
0005432383482	21087	Economy	6300.00
0005432329018	21087	Economy	6300.00
0005432329003	21087	Economy	6300.00
0005432328987	21087	Economy	6300.00
0005432329004	21087	Economy	6300.00
0005432383407	21087	Economy	6300.00
0005432383323	21087	Economy	6300.00
0005432848858	21087	Economy	6300.00
0005432383551	21087	Economy	6300.00
0005432328988	21087	Economy	6300.00
0005432329108	21087	Economy	6300.00
0005432383672	21087	Economy	6300.00
0005432383519	21087	Economy	6300.00
0005432329124	21087	Economy	6300.00
0005432329119	21087	Economy	6300.00
0005432329152	21087	Economy	6300.00
0005432328939	21087	Economy	6300.00
0005432383575	21087	Economy	6300.00
0005432383578	21087	Economy	6300.00
0005432383560	21087	Economy	6300.00
0005432328972	21087	Economy	6300.00
0005432383494	21087	Economy	6300.00
0005432383475	21087	Economy	6300.00
0005432329056	21087	Economy	6300.00
0005432329128	21087	Economy	6300.00
0005432329109	21087	Economy	6300.00
0005432329281	21087	Economy	6300.00
0005432329078	21087	Economy	6300.00
0005432383633	21087	Economy	6300.00
0005432328974	21087	Economy	6300.00
0005432383520	21087	Economy	6300.00
0005432329131	21087	Economy	6300.00
0005432329186	21087	Economy	6300.00
0005432329206	21087	Economy	6300.00
0005432329295	21087	Economy	6300.00
0005432054358	21087	Economy	6300.00
0005432329092	21087	Economy	6300.00
0005432329002	21087	Economy	6300.00
0005432329020	21087	Economy	6300.00
0005432383638	21087	Economy	6300.00
0005432329123	21087	Economy	6300.00
0005432383448	21087	Economy	6300.00
0005432329132	21087	Economy	6300.00
0005432383411	21087	Economy	6300.00
0005432329183	21087	Economy	6300.00
0005432328973	21087	Economy	6300.00
0005432329120	21087	Economy	6300.00
0005432329005	21087	Economy	6300.00
0005432383474	21087	Economy	6300.00
0005432383577	21087	Economy	6300.00
0005432848857	21087	Economy	6300.00
0005432329106	21087	Economy	6300.00
0005432329111	21087	Economy	6300.00
0005432383495	21087	Economy	6300.00
0005432383607	21087	Economy	6300.00
0005432329298	21087	Economy	6300.00
0005432383445	21087	Economy	6300.00
0005432383870	31278	Business	18900.00
0005432383867	31278	Business	18900.00
0005432329501	31278	Business	18900.00
0005432329516	31278	Business	18900.00
0005432329498	31278	Business	18900.00
0005432329511	31278	Business	18900.00
0005432383850	31278	Business	18900.00
0005432383866	31278	Business	18900.00
0005432329499	31278	Business	18900.00
0005432383835	31278	Business	18900.00
0005432383861	31278	Business	18900.00
0005432383873	31278	Economy	6300.00
0005432329505	31278	Economy	6300.00
0005432329520	31278	Economy	6300.00
0005432329527	31278	Economy	6300.00
0005432329529	31278	Economy	6300.00
0005432329522	31278	Economy	6300.00
0005432383841	31278	Economy	6300.00
0005432329523	31278	Economy	6300.00
0005432329494	31278	Economy	6300.00
0005432329502	31278	Economy	6300.00
0005432329510	31278	Economy	6900.00
0005432329513	31278	Economy	6900.00
0005432383863	31278	Economy	6900.00
0005432329504	31278	Economy	6900.00
0005432329489	31278	Economy	6900.00
0005432383864	31278	Economy	6300.00
0005432287278	31278	Economy	6300.00
0005432383874	31278	Economy	6300.00
0005432287279	31278	Economy	6300.00
0005432383849	31278	Economy	6300.00
0005432329519	31278	Economy	6300.00
0005432329521	31278	Economy	6300.00
0005432383865	31278	Economy	6300.00
0005432329503	31278	Economy	6300.00
0005432383862	31278	Economy	6300.00
0005432329497	31278	Economy	6300.00
0005432329524	31278	Economy	6300.00
0005432383851	31278	Economy	6300.00
0005432383872	31278	Economy	6300.00
0005432383857	31278	Economy	6300.00
0005432383853	31278	Economy	6300.00
0005432329525	31278	Economy	6300.00
0005432383845	31278	Economy	6300.00
0005432383860	31278	Economy	6300.00
0005432383871	31278	Economy	6300.00
0005432383833	31278	Economy	6300.00
0005432383846	31278	Economy	6300.00
0005432383832	31278	Economy	6300.00
0005432329514	31278	Economy	6300.00
0005432329490	31278	Economy	6300.00
0005432329493	31278	Economy	6300.00
0005432329515	31278	Economy	6300.00
0005432383843	31278	Economy	6300.00
0005432287281	31278	Economy	6300.00
0005432329518	31278	Economy	6300.00
0005432329488	31278	Economy	6300.00
0005432329496	31278	Economy	6300.00
0005432329508	31278	Economy	6300.00
0005432383858	31278	Economy	6300.00
0005432383836	31278	Economy	6300.00
0005432329491	31278	Economy	6300.00
0005432383844	31278	Economy	6300.00
0005432383838	31278	Economy	6300.00
0005432383859	31278	Economy	6300.00
0005432383855	31278	Economy	6300.00
0005432329500	31278	Economy	6300.00
0005432329526	31278	Economy	6300.00
0005432383847	31278	Economy	6300.00
0005432329530	31278	Economy	6300.00
0005432329506	31278	Economy	6300.00
0005432383852	31278	Economy	6300.00
0005432329492	31278	Economy	6300.00
0005432329509	31278	Economy	6300.00
0005432383848	31278	Economy	6300.00
0005432287280	31278	Economy	6300.00
0005432329495	31278	Economy	6300.00
0005432329533	31278	Economy	6300.00
0005432383869	31278	Economy	6300.00
0005432329507	31278	Economy	6300.00
0005432329517	31278	Economy	6300.00
0005432329532	31278	Economy	6300.00
0005432329512	31278	Economy	6300.00
0005432383840	31278	Economy	6300.00
0005432383837	31278	Economy	6300.00
0005432383842	31278	Economy	6300.00
0005432329528	31278	Economy	6300.00
0005432329531	31278	Economy	6300.00
0005432383868	31278	Economy	6300.00
0005432383856	31278	Economy	6300.00
0005432383834	31278	Economy	6300.00
0005432383839	31278	Economy	6300.00
0005432383854	31278	Economy	6300.00
0005432953989	2492	Business	89600.00
0005433642587	2492	Business	89600.00
0005432954003	2492	Business	89600.00
0005432953990	2492	Business	89600.00
0005432954026	2492	Business	89600.00
0005433642607	2492	Business	89600.00
0005433642601	2492	Business	89600.00
0005433642616	2492	Business	89600.00
0005432954053	2492	Economy	29900.00
0005433642614	2492	Economy	29900.00
0005433642615	2492	Economy	29900.00
0005433642591	2492	Economy	29900.00
0005433642585	2492	Economy	29900.00
0005433642606	2492	Economy	32800.00
0005433642612	2492	Economy	32800.00
0005433642599	2492	Economy	32800.00
0005433642586	2492	Economy	32800.00
0005433642581	2492	Economy	29900.00
0005432953974	2492	Economy	29900.00
0005433642594	2492	Economy	29900.00
0005433642602	2492	Economy	29900.00
0005432954006	2492	Economy	29900.00
0005433642626	2492	Economy	29900.00
0005433642621	2492	Economy	29900.00
0005433642609	2492	Economy	29900.00
0005433642588	2492	Economy	29900.00
0005432953999	2492	Economy	29900.00
0005433642595	2492	Economy	29900.00
0005433642625	2492	Economy	29900.00
0005433642589	2492	Economy	29900.00
0005432954000	2492	Economy	29900.00
0005433642597	2492	Economy	29900.00
0005433642590	2492	Economy	29900.00
0005433642584	2492	Economy	29900.00
0005432954016	2492	Economy	29900.00
0005432953995	2492	Economy	29900.00
0005433642618	2492	Economy	29900.00
0005433642624	2492	Economy	29900.00
0005433642582	2492	Economy	29900.00
0005433642611	2492	Economy	29900.00
0005433642604	2492	Economy	29900.00
0005432954009	2492	Economy	29900.00
0005433642613	2492	Economy	29900.00
0005433642610	2492	Economy	29900.00
0005433642617	2492	Economy	29900.00
0005432953975	2492	Economy	29900.00
0005433642623	2492	Economy	29900.00
0005432953972	2492	Economy	29900.00
0005433642600	2492	Economy	29900.00
0005433642603	2492	Economy	29900.00
0005432954027	2492	Economy	29900.00
0005432954022	2492	Economy	29900.00
0005433642596	2492	Economy	29900.00
0005433642593	2492	Economy	29900.00
0005433642605	2492	Economy	29900.00
0005433642583	2492	Economy	29900.00
0005433642622	2492	Economy	29900.00
0005433642620	2492	Economy	29900.00
0005432953954	2492	Economy	29900.00
0005433642619	2492	Economy	29900.00
0005433642627	2492	Economy	29900.00
0005432953991	2492	Economy	29900.00
0005433642592	2492	Economy	29900.00
0005432954054	2492	Economy	29900.00
0005433642608	2492	Economy	29900.00
0005432953994	2492	Economy	29900.00
0005433642598	2492	Economy	29900.00
0005432425320	13330	Business	12700.00
0005432425305	13330	Business	12700.00
0005432425321	13330	Business	12700.00
0005432425323	13330	Business	12700.00
0005432425326	13330	Economy	4200.00
0005432425301	13330	Economy	4200.00
0005432425313	13330	Economy	4200.00
0005432425299	13330	Economy	4200.00
0005432425311	13330	Economy	4700.00
0005432425335	13330	Economy	4200.00
0005432425297	13330	Economy	4200.00
0005432425312	13330	Economy	4200.00
0005432425300	13330	Economy	4200.00
0005432425318	13330	Economy	4200.00
0005432425316	13330	Economy	4200.00
0005432425325	13330	Economy	4200.00
0005432425302	13330	Economy	4200.00
0005432425295	13330	Economy	4200.00
0005432425294	13330	Economy	4200.00
0005432425317	13330	Economy	4200.00
0005432425308	13330	Economy	4200.00
0005432425304	13330	Economy	4200.00
0005432425314	13330	Economy	4200.00
0005432425329	13330	Economy	4200.00
0005432425327	13330	Economy	4200.00
0005432425334	13330	Economy	4200.00
0005432425319	13330	Economy	4200.00
0005432425310	13330	Economy	4200.00
0005432425296	13330	Economy	4200.00
0005432425298	13330	Economy	4200.00
0005432425307	13330	Economy	4200.00
0005432425332	13330	Economy	4200.00
0005432425315	13330	Economy	4200.00
0005432425322	13330	Economy	4200.00
0005432425309	13330	Economy	4200.00
0005432425331	13330	Economy	4200.00
0005432425333	13330	Economy	4200.00
0005432425328	13330	Economy	4200.00
0005432425303	13330	Economy	4200.00
0005432425324	13330	Economy	4200.00
0005432425306	13330	Economy	4200.00
0005432425330	13330	Economy	4200.00
0005432424702	30797	Business	12700.00
0005432424850	30797	Business	12700.00
0005432424853	30797	Business	12700.00
0005432424876	30797	Business	12700.00
0005432424794	30797	Business	12700.00
0005432424785	30797	Economy	4200.00
0005432424825	30797	Economy	4200.00
0005432424716	30797	Economy	4200.00
0005432424762	30797	Economy	4200.00
0005432424903	30797	Economy	4200.00
0005432424761	30797	Economy	4700.00
0005432424708	30797	Economy	4700.00
0005432424875	30797	Economy	4200.00
0005432424750	30797	Economy	4200.00
0005432424646	30797	Economy	4200.00
0005432424824	30797	Economy	4200.00
0005432424849	30797	Economy	4200.00
0005432424742	30797	Economy	4200.00
0005432424863	30797	Economy	4200.00
0005432424798	30797	Economy	4200.00
0005432424826	30797	Economy	4200.00
0005432424847	30797	Economy	4200.00
0005432424753	30797	Economy	4200.00
0005432424914	30797	Economy	4200.00
0005432424807	30797	Economy	4200.00
0005432424799	30797	Economy	4200.00
0005432424707	30797	Economy	4200.00
0005432424900	30797	Economy	4200.00
0005432424754	30797	Economy	4200.00
0005432424749	30797	Economy	4200.00
0005432424908	30797	Economy	4200.00
0005432424823	30797	Economy	4200.00
0005432424880	30797	Economy	4200.00
0005432424901	30797	Economy	4200.00
0005432424786	30797	Economy	4200.00
0005432424674	30797	Economy	4200.00
0005432424897	30797	Economy	4200.00
0005432424748	30797	Economy	4200.00
0005432424846	30797	Economy	4200.00
0005432424909	30797	Economy	4200.00
0005432424860	30797	Economy	4200.00
0005432424827	30797	Economy	4200.00
0005432424645	30797	Economy	4200.00
0005432424906	30797	Economy	4200.00
0005432424902	30797	Economy	4200.00
0005432424881	30797	Economy	4200.00
0005432424808	30797	Economy	4200.00
0005432424912	30797	Economy	4200.00
0005432424800	30797	Economy	4200.00
0005432424889	30797	Economy	4200.00
0005432424796	30797	Economy	4200.00
0005432424896	30797	Economy	4200.00
0005434448380	9624	Business	32600.00
0005432818030	9624	Business	32600.00
0005434157572	9624	Business	32600.00
0005432901799	9624	Business	32600.00
0005432901728	9624	Business	32600.00
0005432818029	9624	Business	32600.00
0005432289048	9624	Business	32600.00
0005434448379	9624	Business	32600.00
0005432289046	9624	Economy	10900.00
0005432901712	9624	Economy	10900.00
0005432818007	9624	Economy	10900.00
0005432289047	9624	Economy	10900.00
0005434157543	9624	Economy	10900.00
0005432818023	9624	Economy	10900.00
0005434448381	9624	Economy	11900.00
0005434157566	9624	Economy	11900.00
0005432818003	9624	Economy	11900.00
0005432901747	9624	Economy	11900.00
0005432901735	9624	Economy	11900.00
0005432818014	9624	Economy	10900.00
0005432818011	9624	Economy	10900.00
0005432818017	9624	Economy	10900.00
0005432818013	9624	Economy	10900.00
0005432901753	9624	Economy	10900.00
0005434157527	9624	Economy	10900.00
0005432818020	9624	Economy	10900.00
0005432901746	9624	Economy	10900.00
0005432901711	9624	Economy	10900.00
0005432822347	9624	Economy	10900.00
0005432818028	9624	Economy	10900.00
0005432818024	9624	Economy	10900.00
0005432822348	9624	Economy	10900.00
0005432818031	9624	Economy	10900.00
0005432818027	9624	Economy	10900.00
0005432901684	9624	Economy	10900.00
0005432822343	9624	Economy	10900.00
0005432818019	9624	Economy	10900.00
0005432901701	9624	Economy	10900.00
0005432822344	9624	Economy	10900.00
0005432901787	9624	Economy	10900.00
0005432818026	9624	Economy	10900.00
0005432818025	9624	Economy	10900.00
0005432822346	9624	Economy	10900.00
0005432822342	9624	Economy	10900.00
0005432818002	9624	Economy	10900.00
0005434157528	9624	Economy	10900.00
0005434157558	9624	Economy	10900.00
0005432901791	9624	Economy	10900.00
0005432901751	9624	Economy	10900.00
0005432901801	9624	Economy	10900.00
0005432818005	9624	Economy	10900.00
0005432901806	9624	Economy	10900.00
0005432818004	9624	Economy	10900.00
0005432818016	9624	Economy	10900.00
0005432901702	9624	Economy	10900.00
0005432901768	9624	Economy	10900.00
0005432901737	9624	Economy	10900.00
0005432818008	9624	Economy	10900.00
0005432901752	9624	Economy	10900.00
0005432822341	9624	Economy	10900.00
0005432818015	9624	Economy	10900.00
0005434157559	9624	Economy	10900.00
0005432901761	9624	Economy	10900.00
0005432818009	9624	Economy	10900.00
0005434157532	9624	Economy	10900.00
0005432822345	9624	Economy	10900.00
0005434157573	9624	Economy	10900.00
0005432818018	9624	Economy	10900.00
0005434157578	9624	Economy	10900.00
0005432818021	9624	Economy	10900.00
0005432818022	9624	Economy	10900.00
0005434157544	9624	Economy	10900.00
0005432901800	9624	Economy	10900.00
0005432818006	9624	Economy	10900.00
0005432818012	9624	Economy	10900.00
0005432818010	9624	Economy	10900.00
0005432901810	9624	Economy	10900.00
0005432817717	28970	Business	32600.00
0005432822278	28970	Business	32600.00
0005432817687	28970	Business	32600.00
0005432817672	28970	Business	32600.00
0005432817806	28970	Business	32600.00
0005434157622	28970	Business	32600.00
0005432817814	28970	Business	32600.00
0005432817815	28970	Business	32600.00
0005432817948	28970	Business	32600.00
0005432817885	28970	Economy	10900.00
0005434157624	28970	Economy	10900.00
0005432817753	28970	Economy	10900.00
0005432817708	28970	Economy	10900.00
0005432002115	28970	Economy	10900.00
0005432901940	28970	Economy	10900.00
0005434186249	28970	Economy	10900.00
0005432817620	28970	Economy	10900.00
0005432901928	28970	Economy	11900.00
0005432817779	28970	Economy	11900.00
0005432817688	28970	Economy	11900.00
0005432901930	28970	Economy	11900.00
0005432817682	28970	Economy	11900.00
0005432822280	28970	Economy	10900.00
0005432817947	28970	Economy	10900.00
0005432002114	28970	Economy	10900.00
0005434448345	28970	Economy	10900.00
0005432817673	28970	Economy	10900.00
0005432901923	28970	Economy	10900.00
0005432817804	28970	Economy	10900.00
0005434448352	28970	Economy	10900.00
0005432901931	28970	Economy	10900.00
0005432817787	28970	Economy	10900.00
0005434157621	28970	Economy	10900.00
0005432817561	28970	Economy	10900.00
0005432817896	28970	Economy	10900.00
0005434157625	28970	Economy	10900.00
0005434448337	28970	Economy	10900.00
0005434448353	28970	Economy	10900.00
0005432817884	28970	Economy	10900.00
0005432901925	28970	Economy	10900.00
0005434157623	28970	Economy	10900.00
0005432822260	28970	Economy	10900.00
0005434157626	28970	Economy	10900.00
0005432901927	28970	Economy	10900.00
0005432901924	28970	Economy	10900.00
0005432817778	28970	Economy	10900.00
0005432817841	28970	Economy	10900.00
0005432901926	28970	Economy	10900.00
0005432901935	28970	Economy	10900.00
0005434186250	28970	Economy	10900.00
0005432817606	28970	Economy	10900.00
0005432901934	28970	Economy	10900.00
0005434186251	28970	Economy	10900.00
0005432817607	28970	Economy	10900.00
0005434186252	28970	Economy	10900.00
0005432817786	28970	Economy	10900.00
0005432901936	28970	Economy	10900.00
0005432901929	28970	Economy	10900.00
0005432901937	28970	Economy	10900.00
0005432901938	28970	Economy	10900.00
0005434448344	28970	Economy	10900.00
0005432901933	28970	Economy	10900.00
0005434448343	28970	Economy	10900.00
0005432901932	28970	Economy	10900.00
0005432817795	28970	Economy	10900.00
0005432901939	28970	Economy	10900.00
0005434157620	28970	Economy	10900.00
0005432817683	28970	Economy	10900.00
0005432817892	28970	Economy	10900.00
0005432817562	28970	Economy	10900.00
0005432817608	28970	Economy	10900.00
0005435841829	15141	Economy	11000.00
0005432613935	15141	Economy	11000.00
0005432613938	15141	Economy	11000.00
0005432613939	15141	Economy	11000.00
0005432611777	15141	Economy	11000.00
0005432613936	15141	Economy	11000.00
0005432611775	15141	Economy	11000.00
0005432611776	15141	Economy	11000.00
0005432613937	15141	Economy	11000.00
0005432607617	31632	Economy	11000.00
0005432607595	31632	Economy	11000.00
0005432611751	31632	Economy	11000.00
0005432611760	31632	Economy	11000.00
0005432607596	31632	Economy	11000.00
0005432607594	31632	Economy	11000.00
0005432607602	31632	Economy	11000.00
0005432607597	31632	Economy	11000.00
0005432607599	31632	Economy	11000.00
0005432611737	31632	Economy	11000.00
0005432607598	31632	Economy	11000.00
0005432948786	11873	Business	105900.00
0005433570112	11873	Business	105900.00
0005433570087	11873	Business	105900.00
0005432948644	11873	Business	105900.00
0005432948921	11873	Business	105900.00
0005432948966	11873	Business	105900.00
0005433570094	11873	Business	105900.00
0005433570096	11873	Business	105900.00
0005433570078	11873	Business	105900.00
0005432948816	11873	Business	105900.00
0005433570135	11873	Business	105900.00
0005433570119	11873	Business	105900.00
0005433570144	11873	Business	105900.00
0005432948752	11873	Business	105900.00
0005433570139	11873	Business	105900.00
0005432948845	11873	Business	105900.00
0005433570147	11873	Economy	35300.00
0005433570105	11873	Business	105900.00
0005432948950	11873	Economy	35300.00
0005433570091	11873	Economy	35300.00
0005433570083	11873	Economy	35300.00
0005432948876	11873	Economy	35300.00
0005433570109	11873	Economy	35300.00
0005433570111	11873	Economy	35300.00
0005433570142	11873	Economy	35300.00
0005433570140	11873	Economy	35300.00
0005433570148	11873	Economy	35300.00
0005433570103	11873	Economy	35300.00
0005433570126	11873	Economy	38800.00
0005433570113	11873	Economy	38800.00
0005433570149	11873	Economy	35300.00
0005433570122	11873	Economy	38800.00
0005433570095	11873	Economy	35300.00
0005433570080	11873	Economy	35300.00
0005433570121	11873	Economy	35300.00
0005433570129	11873	Economy	35300.00
0005433570108	11873	Economy	35300.00
0005433570106	11873	Economy	35300.00
0005433570082	11873	Economy	35300.00
0005433570114	11873	Economy	35300.00
0005432948818	11873	Economy	35300.00
0005432948836	11873	Economy	35300.00
0005432948927	11873	Economy	35300.00
0005433570081	11873	Economy	35300.00
0005433570137	11873	Economy	35300.00
0005433570124	11873	Economy	35300.00
0005433570132	11873	Economy	35300.00
0005433570131	11873	Economy	35300.00
0005432948785	11873	Economy	35300.00
0005432948817	11873	Economy	35300.00
0005433570115	11873	Economy	35300.00
0005433570084	11873	Economy	35300.00
0005433570099	11873	Economy	35300.00
0005432948848	11873	Economy	35300.00
0005433570141	11873	Economy	35300.00
0005433570085	11873	Economy	35300.00
0005433570098	11873	Economy	35300.00
0005433570093	11873	Economy	35300.00
0005433570092	11873	Economy	35300.00
0005433570143	11873	Economy	35300.00
0005433570107	11873	Economy	35300.00
0005432948642	11873	Economy	35300.00
0005432948811	11873	Economy	35300.00
0005433570133	11873	Economy	35300.00
0005432948939	11873	Economy	35300.00
0005432948914	11873	Economy	35300.00
0005433570146	11873	Economy	35300.00
0005433570088	11873	Economy	35300.00
0005433570145	11873	Economy	35300.00
0005432948922	11873	Economy	35300.00
0005433570100	11873	Economy	35300.00
0005433570116	11873	Economy	35300.00
0005432948643	11873	Economy	35300.00
0005433570118	11873	Economy	35300.00
0005433570086	11873	Economy	35300.00
0005432948784	11873	Economy	35300.00
0005433570090	11873	Economy	35300.00
0005433570138	11873	Economy	35300.00
0005433570079	11873	Economy	35300.00
0005433570104	11873	Economy	35300.00
0005433570120	11873	Economy	35300.00
0005432948751	11873	Economy	35300.00
0005433570110	11873	Economy	35300.00
0005433570117	11873	Economy	35300.00
0005433570123	11873	Economy	35300.00
0005433570127	11873	Economy	35300.00
0005432948662	11873	Economy	35300.00
0005433570136	11873	Economy	35300.00
0005433570101	11873	Economy	35300.00
0005433570134	11873	Economy	35300.00
0005433570128	11873	Economy	35300.00
0005433570077	11873	Economy	35300.00
0005432948625	11873	Economy	35300.00
0005433570130	11873	Economy	35300.00
0005432948750	11873	Economy	35300.00
0005433570125	11873	Economy	35300.00
0005433570089	11873	Economy	35300.00
0005432948965	11873	Economy	35300.00
0005433570097	11873	Economy	35300.00
0005433570102	11873	Economy	35300.00
0005433569539	25278	Business	105900.00
0005432949243	25278	Business	105900.00
0005432949253	25278	Business	105900.00
0005433569525	25278	Business	105900.00
0005433569359	25278	Business	105900.00
0005433569651	25278	Business	105900.00
0005432949254	25278	Business	105900.00
0005432949250	25278	Business	105900.00
0005432949265	25278	Business	105900.00
0005433569572	25278	Business	105900.00
0005433569536	25278	Business	105900.00
0005432949244	25278	Business	105900.00
0005433569648	25278	Business	105900.00
0005432949256	25278	Business	105900.00
0005433569652	25278	Business	105900.00
0005432949263	25278	Business	105900.00
0005432949224	25278	Business	105900.00
0005433569621	25278	Business	105900.00
0005432949235	25278	Business	105900.00
0005433569569	25278	Economy	35300.00
0005433569431	25278	Economy	35300.00
0005432949233	25278	Economy	35300.00
0005433569555	25278	Economy	35300.00
0005432949245	25278	Economy	35300.00
0005432949246	25278	Economy	35300.00
0005433569647	25278	Economy	35300.00
0005433569607	25278	Economy	35300.00
0005433569366	25278	Economy	35300.00
0005433569471	25278	Economy	35300.00
0005432949232	25278	Economy	35300.00
0005433569615	25278	Economy	35300.00
0005432949248	25278	Economy	35300.00
0005433569538	25278	Economy	38800.00
0005433569583	25278	Economy	38800.00
0005433569571	25278	Economy	38800.00
0005433569716	25278	Economy	38800.00
0005432949230	25278	Economy	35300.00
0005433569606	25278	Economy	35300.00
0005432949228	25278	Economy	35300.00
0005433569553	25278	Economy	35300.00
0005433569721	25278	Economy	35300.00
0005432949241	25278	Economy	35300.00
0005433569640	25278	Economy	35300.00
0005433569469	25278	Economy	35300.00
0005433569582	25278	Economy	35300.00
0005433569524	25278	Economy	35300.00
0005433569558	25278	Economy	35300.00
0005432949242	25278	Economy	35300.00
0005432949262	25278	Economy	35300.00
0005432949257	25278	Economy	35300.00
0005432949261	25278	Economy	35300.00
0005433569697	25278	Economy	35300.00
0005432949255	25278	Economy	35300.00
0005433569102	25278	Economy	35300.00
0005433569633	25278	Economy	35300.00
0005433569365	25278	Economy	35300.00
0005433569649	25278	Economy	35300.00
0005433569534	25278	Economy	35300.00
0005433569719	25278	Economy	35300.00
0005432949251	25278	Economy	35300.00
0005433569470	25278	Economy	35300.00
0005432949259	25278	Economy	35300.00
0005433569186	25278	Economy	35300.00
0005433569589	25278	Economy	35300.00
0005433569567	25278	Economy	35300.00
0005432949252	25278	Economy	35300.00
0005433569614	25278	Economy	35300.00
0005433569612	25278	Economy	35300.00
0005432949238	25278	Economy	35300.00
0005432949260	25278	Economy	35300.00
0005433569695	25278	Economy	35300.00
0005433569696	25278	Economy	35300.00
0005432949225	25278	Economy	35300.00
0005433569597	25278	Economy	35300.00
0005433569650	25278	Economy	35300.00
0005433569485	25278	Economy	35300.00
0005433569624	25278	Economy	35300.00
0005432949236	25278	Economy	35300.00
0005433569639	25278	Economy	35300.00
0005432949227	25278	Economy	35300.00
0005432949237	25278	Economy	35300.00
0005432949229	25278	Economy	35300.00
0005433569540	25278	Economy	35300.00
0005432949234	25278	Economy	35300.00
0005433569617	25278	Economy	35300.00
0005433569570	25278	Economy	35300.00
0005432949247	25278	Economy	35300.00
0005433569646	25278	Economy	35300.00
0005432949258	25278	Economy	35300.00
0005433569103	25278	Economy	35300.00
0005433569702	25278	Economy	35300.00
0005433569674	25278	Economy	35300.00
0005433569598	25278	Economy	35300.00
0005433569729	25278	Economy	35300.00
0005432949239	25278	Economy	35300.00
0005432949264	25278	Economy	35300.00
0005433569608	25278	Economy	35300.00
0005433569568	25278	Economy	35300.00
0005432949249	25278	Economy	35300.00
0005432949226	25278	Economy	35300.00
0005432949231	25278	Economy	35300.00
0005433569562	25278	Economy	35300.00
0005433569629	25278	Economy	35300.00
0005432949240	25278	Economy	35300.00
0005433569634	25278	Economy	35300.00
0005433569529	25278	Economy	35300.00
0005433812922	14468	Business	117400.00
0005433808390	14468	Business	117400.00
0005434026740	14468	Business	117400.00
0005433808388	14468	Business	117400.00
0005433808393	14468	Economy	39100.00
0005432430929	14468	Economy	39100.00
0005432430933	14468	Economy	39100.00
0005432430930	14468	Economy	43000.00
0005433812918	14468	Economy	39100.00
0005432430934	14468	Economy	39100.00
0005432430925	14468	Economy	39100.00
0005432430936	14468	Economy	39100.00
0005433812916	14468	Economy	39100.00
0005433808398	14468	Economy	39100.00
0005434026742	14468	Economy	39100.00
0005433808415	14468	Economy	39100.00
0005433808407	14468	Economy	39100.00
0005433812920	14468	Economy	39100.00
0005432430927	14468	Economy	39100.00
0005433812924	14468	Economy	39100.00
0005433808389	14468	Economy	39100.00
0005432430937	14468	Economy	39100.00
0005433808404	14468	Economy	39100.00
0005432430926	14468	Economy	39100.00
0005433808406	14468	Economy	39100.00
0005434026739	14468	Economy	39100.00
0005433808408	14468	Economy	39100.00
0005432430932	14468	Economy	39100.00
0005432430935	14468	Economy	39100.00
0005433808403	14468	Economy	39100.00
0005433808397	14468	Economy	39100.00
0005432430931	14468	Economy	39100.00
0005432430928	14468	Economy	39100.00
0005434026741	14468	Economy	39100.00
0005433812914	14468	Economy	39100.00
0005434026737	14468	Economy	39100.00
0005434026738	14468	Economy	39100.00
0005433812917	14468	Economy	39100.00
0005433812936	30835	Business	117400.00
0005432430881	30835	Business	117400.00
0005433808447	30835	Business	117400.00
0005432430892	30835	Business	117400.00
0005433808435	30835	Business	117400.00
0005434026701	30835	Business	117400.00
0005433808445	30835	Economy	39100.00
0005432430903	30835	Economy	39100.00
0005433808444	30835	Economy	39100.00
0005432430893	30835	Economy	39100.00
0005432430884	30835	Economy	43000.00
0005433808441	30835	Economy	39100.00
0005433812937	30835	Economy	39100.00
0005433808442	30835	Economy	39100.00
0005433808434	30835	Economy	39100.00
0005433812934	30835	Economy	39100.00
0005433812938	30835	Economy	39100.00
0005433808436	30835	Economy	39100.00
0005432430894	30835	Economy	39100.00
0005433808448	30835	Economy	39100.00
0005433812941	30835	Economy	39100.00
0005433808437	30835	Economy	39100.00
0005432430896	30835	Economy	39100.00
0005433808438	30835	Economy	39100.00
0005434026716	30835	Economy	39100.00
0005434026715	30835	Economy	39100.00
0005433812939	30835	Economy	39100.00
0005433808439	30835	Economy	39100.00
0005434026702	30835	Economy	39100.00
0005432430882	30835	Economy	39100.00
0005434026723	30835	Economy	39100.00
0005433808446	30835	Economy	39100.00
0005433808449	30835	Economy	39100.00
0005432430895	30835	Economy	39100.00
0005433812940	30835	Economy	39100.00
0005434026722	30835	Economy	39100.00
0005433812942	30835	Economy	39100.00
0005432430885	30835	Economy	39100.00
0005433808440	30835	Economy	39100.00
0005433808433	30835	Economy	39100.00
0005432430883	30835	Economy	39100.00
0005433812943	30835	Economy	39100.00
0005433808443	30835	Economy	39100.00
0005432430897	30835	Economy	39100.00
0005433812935	30835	Economy	39100.00
0005434655234	5373	Business	67200.00
0005434656592	5373	Business	67200.00
0005434655236	5373	Business	67200.00
0005435340414	5373	Business	67200.00
0005435340427	5373	Business	67200.00
0005434655210	5373	Economy	22400.00
0005435340327	5373	Economy	22400.00
0005435340426	5373	Economy	22400.00
0005434655209	5373	Economy	22400.00
0005434655233	5373	Economy	22400.00
0005435340510	5373	Economy	22400.00
0005434655219	5373	Economy	24600.00
0005434655214	5373	Economy	24600.00
0005434655207	5373	Economy	24600.00
0005434655232	5373	Economy	24600.00
0005434655220	5373	Economy	22400.00
0005434655218	5373	Economy	22400.00
0005434655217	5373	Economy	22400.00
0005434655206	5373	Economy	22400.00
0005435340413	5373	Economy	22400.00
0005434655221	5373	Economy	22400.00
0005435340396	5373	Economy	22400.00
0005435340467	5373	Economy	22400.00
0005434655213	5373	Economy	22400.00
0005434655225	5373	Economy	22400.00
0005434655227	5373	Economy	22400.00
0005435340456	5373	Economy	22400.00
0005435340348	5373	Economy	22400.00
0005434655231	5373	Economy	22400.00
0005434655228	5373	Economy	22400.00
0005434655215	5373	Economy	22400.00
0005435340397	5373	Economy	22400.00
0005434655216	5373	Economy	22400.00
0005435340452	5373	Economy	22400.00
0005434655212	5373	Economy	22400.00
0005434655223	5373	Economy	22400.00
0005434655229	5373	Economy	22400.00
0005432114261	5373	Economy	22400.00
0005435340328	5373	Economy	22400.00
0005435340443	5373	Economy	22400.00
0005434655211	5373	Economy	22400.00
0005432114262	5373	Economy	22400.00
0005434655226	5373	Economy	22400.00
0005435340483	5373	Economy	22400.00
0005434656593	5373	Economy	22400.00
0005434655222	5373	Economy	22400.00
0005432114263	5373	Economy	22400.00
0005434655235	5373	Economy	22400.00
0005434655224	5373	Economy	22400.00
0005434655230	5373	Economy	22400.00
0005434655208	5373	Economy	22400.00
0005435340543	12563	Business	67200.00
0005434654834	12563	Business	67200.00
0005435340549	12563	Business	67200.00
0005434654944	12563	Business	67200.00
0005434654909	12563	Business	67200.00
0005434654933	12563	Business	67200.00
0005435555409	12563	Business	67200.00
0005434654845	12563	Business	67200.00
0005434655021	12563	Economy	22400.00
0005434654996	12563	Economy	22400.00
0005434655055	12563	Economy	22400.00
0005435340542	12563	Economy	22400.00
0005435340537	12563	Economy	22400.00
0005435340540	12563	Economy	24600.00
0005434654906	12563	Economy	24600.00
0005434654950	12563	Economy	24600.00
0005434655053	12563	Economy	24600.00
0005435340541	12563	Economy	24600.00
0005435340546	12563	Economy	22400.00
0005435555410	12563	Economy	22400.00
0005435340538	12563	Economy	22400.00
0005434654844	12563	Economy	22400.00
0005434655009	12563	Economy	22400.00
0005435340544	12563	Economy	22400.00
0005435340547	12563	Economy	22400.00
0005434654979	12563	Economy	22400.00
0005434655054	12563	Economy	22400.00
0005434654995	12563	Economy	22400.00
0005434655052	12563	Economy	22400.00
0005434654938	12563	Economy	22400.00
0005434654851	12563	Economy	22400.00
0005434654843	12563	Economy	22400.00
0005434654955	12563	Economy	22400.00
0005435340545	12563	Economy	22400.00
0005435340535	12563	Economy	22400.00
0005434654868	12563	Economy	22400.00
0005434654947	12563	Economy	22400.00
0005434654945	12563	Economy	22400.00
0005435340539	12563	Economy	22400.00
0005434654954	12563	Economy	22400.00
0005434654936	12563	Economy	22400.00
0005434654894	12563	Economy	22400.00
0005434654852	12563	Economy	22400.00
0005434654943	12563	Economy	22400.00
0005434654904	12563	Economy	22400.00
0005435555408	12563	Economy	22400.00
0005435340536	12563	Economy	22400.00
0005434655025	12563	Economy	22400.00
0005434654890	12563	Economy	22400.00
0005434654934	12563	Economy	22400.00
0005434654903	12563	Economy	22400.00
0005435340550	12563	Economy	22400.00
0005435340548	12563	Economy	22400.00
0005434654980	12563	Economy	22400.00
0005434655034	12563	Economy	22400.00
0005434654997	12563	Economy	22400.00
0005434655063	12563	Economy	22400.00
0005433716886	7448	Business	32000.00
0005433719201	7448	Business	32000.00
0005433716864	7448	Business	32000.00
0005433690961	7448	Business	32000.00
0005433656728	7448	Business	32000.00
0005433716892	7448	Economy	10700.00
0005433716871	7448	Economy	10700.00
0005433716904	7448	Economy	10700.00
0005433719200	7448	Economy	10700.00
0005433722338	7448	Economy	10700.00
0005433716898	7448	Economy	10700.00
0005433688847	7448	Economy	10700.00
0005433722342	7448	Economy	10700.00
0005433656731	7448	Economy	10700.00
0005433716875	7448	Economy	10700.00
0005433716885	7448	Economy	10700.00
0005435266195	7448	Economy	10700.00
0005435266186	7448	Economy	10700.00
0005435266176	7448	Economy	10700.00
0005433722340	7448	Economy	10700.00
0005435266192	7448	Economy	10700.00
0005433689948	7448	Economy	10700.00
0005433716909	7448	Economy	10700.00
0005433716903	7448	Economy	10700.00
0005433716883	7448	Economy	10700.00
0005433716876	7448	Economy	10700.00
0005433722337	7448	Economy	10700.00
0005433690960	7448	Economy	10700.00
0005433716907	7448	Economy	10700.00
0005433716865	7448	Economy	10700.00
0005433722341	7448	Economy	10700.00
0005433719202	7448	Economy	10700.00
0005433722339	7448	Economy	10700.00
0005433716870	7448	Economy	11700.00
0005433716863	7448	Economy	10700.00
0005433716899	7448	Economy	11700.00
0005432078208	7448	Economy	11700.00
0005433716868	7448	Economy	11700.00
0005433716860	7448	Economy	11700.00
0005435266169	7448	Economy	10700.00
0005435266193	7448	Economy	10700.00
0005432078207	7448	Economy	10700.00
0005433716878	7448	Economy	10700.00
0005433716874	7448	Economy	10700.00
0005433716880	7448	Economy	10700.00
0005433716881	7448	Economy	10700.00
0005433716908	7448	Economy	10700.00
0005433716895	7448	Economy	10700.00
0005435266175	7448	Economy	10700.00
0005433719199	7448	Economy	10700.00
0005433656729	7448	Economy	10700.00
0005433716873	7448	Economy	10700.00
0005433716902	7448	Economy	10700.00
0005433716906	7448	Economy	10700.00
0005432078209	7448	Economy	10700.00
0005432078212	7448	Economy	10700.00
0005433716882	7448	Economy	10700.00
0005433716872	7448	Economy	10700.00
0005433716869	7448	Economy	10700.00
0005435266170	7448	Economy	10700.00
0005433716862	7448	Economy	10700.00
0005433656730	7448	Economy	10700.00
0005433716897	7448	Economy	10700.00
0005433716890	7448	Economy	10700.00
0005433716866	7448	Economy	10700.00
0005433716893	7448	Economy	10700.00
0005433716905	7448	Economy	10700.00
0005433689949	7448	Economy	10700.00
0005433716894	7448	Economy	10700.00
0005433716887	7448	Economy	10700.00
0005435266200	7448	Economy	10700.00
0005433716879	7448	Economy	10700.00
0005433716867	7448	Economy	10700.00
0005433716861	7448	Economy	10700.00
0005433716877	7448	Economy	10700.00
0005433688846	7448	Economy	10700.00
0005432428964	7448	Economy	10700.00
0005433716900	7448	Economy	10700.00
0005433716889	7448	Economy	10700.00
0005432078210	7448	Economy	10700.00
0005433716884	7448	Economy	10700.00
0005433716891	7448	Economy	10700.00
0005433716888	7448	Economy	10700.00
0005433716896	7448	Economy	10700.00
0005432078211	7448	Economy	10700.00
0005433716901	7448	Economy	10700.00
0005433716859	7448	Economy	10700.00
0005433716858	7448	Economy	10700.00
0005433656690	29223	Business	32000.00
0005435266230	29223	Business	32000.00
0005433716401	29223	Business	32000.00
0005433716545	29223	Business	32000.00
0005433688826	29223	Business	32000.00
0005433719169	29223	Business	32000.00
0005433719177	29223	Business	32000.00
0005433716512	29223	Business	32000.00
0005433716566	29223	Business	32000.00
0005432428990	29223	Business	32000.00
0005435266222	29223	Economy	10700.00
0005433656689	29223	Economy	10700.00
0005433716511	29223	Economy	10700.00
0005433716565	29223	Economy	10700.00
0005435266221	29223	Economy	10700.00
0005433716414	29223	Economy	10700.00
0005433716400	29223	Economy	10700.00
0005433719172	29223	Economy	10700.00
0005433716357	29223	Economy	10700.00
0005435266232	29223	Economy	10700.00
0005433716536	29223	Economy	10700.00
0005433716464	29223	Economy	10700.00
0005433722261	29223	Economy	10700.00
0005433716083	29223	Economy	10700.00
0005433716485	29223	Economy	10700.00
0005433716459	29223	Economy	10700.00
0005433719178	29223	Economy	10700.00
0005433716593	29223	Economy	10700.00
0005435266226	29223	Economy	10700.00
0005432428991	29223	Economy	10700.00
0005433716672	29223	Economy	10700.00
0005432428992	29223	Economy	10700.00
0005433716524	29223	Economy	10700.00
0005433716557	29223	Economy	10700.00
0005435266229	29223	Economy	10700.00
0005433656701	29223	Economy	11700.00
0005435266220	29223	Economy	11700.00
0005433716316	29223	Economy	11700.00
0005433716571	29223	Economy	11700.00
0005433716409	29223	Economy	11700.00
0005433716594	29223	Economy	10700.00
0005432006816	29223	Economy	10700.00
0005433716383	29223	Economy	10700.00
0005432428993	29223	Economy	10700.00
0005433716444	29223	Economy	10700.00
0005433722271	29223	Economy	10700.00
0005433716384	29223	Economy	10700.00
0005433716589	29223	Economy	10700.00
0005433716271	29223	Economy	10700.00
0005435266225	29223	Economy	10700.00
0005433716154	29223	Economy	10700.00
0005433716558	29223	Economy	10700.00
0005433716358	29223	Economy	10700.00
0005432428994	29223	Economy	10700.00
0005435266219	29223	Economy	10700.00
0005435266227	29223	Economy	10700.00
0005433719171	29223	Economy	10700.00
0005433716448	29223	Economy	10700.00
0005433656698	29223	Economy	10700.00
0005433716532	29223	Economy	10700.00
0005433716443	29223	Economy	10700.00
0005433716659	29223	Economy	10700.00
0005433716424	29223	Economy	10700.00
0005433716388	29223	Economy	10700.00
0005435266228	29223	Economy	10700.00
0005433688825	29223	Economy	10700.00
0005433656697	29223	Economy	10700.00
0005433656687	29223	Economy	10700.00
0005433716426	29223	Economy	10700.00
0005433716487	29223	Economy	10700.00
0005433716304	29223	Economy	10700.00
0005433719170	29223	Economy	10700.00
0005433716387	29223	Economy	10700.00
0005433716455	29223	Economy	10700.00
0005433716525	29223	Economy	10700.00
0005435266231	29223	Economy	10700.00
0005435266224	29223	Economy	10700.00
0005433716155	29223	Economy	10700.00
0005433716544	29223	Economy	10700.00
0005433716425	29223	Economy	10700.00
0005433716555	29223	Economy	10700.00
0005433722262	29223	Economy	10700.00
0005433716406	29223	Economy	10700.00
0005435266223	29223	Economy	10700.00
0005433716362	29223	Economy	10700.00
0005434095540	8652	Business	36500.00
0005434182292	8652	Business	36500.00
0005434182302	8652	Business	36500.00
0005434182327	8652	Economy	12200.00
0005434095536	8652	Economy	12200.00
0005434182326	8652	Economy	12200.00
0005434095542	8652	Economy	12200.00
0005434182301	8652	Economy	12200.00
0005434182375	8652	Economy	13400.00
0005434095541	8652	Economy	13400.00
0005434095535	8652	Economy	13400.00
0005434182343	8652	Economy	12200.00
0005434182328	8652	Economy	12200.00
0005434182293	8652	Economy	12200.00
0005434182344	8652	Economy	12200.00
0005434182304	8652	Economy	12200.00
0005434095537	8652	Economy	12200.00
0005434182295	8652	Economy	12200.00
0005434182374	8652	Economy	12200.00
0005434184685	8652	Economy	12200.00
0005434095544	8652	Economy	12200.00
0005434182296	8652	Economy	12200.00
0005434095533	8652	Economy	12200.00
0005434095543	8652	Economy	12200.00
0005434095539	8652	Economy	12200.00
0005434095545	8652	Economy	12200.00
0005434182283	8652	Economy	12200.00
0005434182274	8652	Economy	12200.00
0005434095538	8652	Economy	12200.00
0005434095546	8652	Economy	12200.00
0005434184679	8652	Economy	12200.00
0005434095534	8652	Economy	12200.00
0005434182371	8652	Economy	12200.00
0005434095419	11643	Business	36500.00
0005434182416	11643	Business	36500.00
0005434182417	11643	Business	36500.00
0005434182408	11643	Economy	12200.00
0005434095441	11643	Economy	12200.00
0005434182418	11643	Economy	12200.00
0005434184701	11643	Economy	12200.00
0005434095402	11643	Economy	12200.00
0005434095443	11643	Economy	13400.00
0005434182409	11643	Economy	13400.00
0005434095398	11643	Economy	13400.00
0005434095396	11643	Economy	12200.00
0005434182421	11643	Economy	12200.00
0005434095391	11643	Economy	12200.00
0005434095440	11643	Economy	12200.00
0005434182419	11643	Economy	12200.00
0005434183614	11643	Economy	12200.00
0005434182411	11643	Economy	12200.00
0005434095463	11643	Economy	12200.00
0005434184702	11643	Economy	12200.00
0005434095462	11643	Economy	12200.00
0005434095397	11643	Economy	12200.00
0005434182410	11643	Economy	12200.00
0005434095444	11643	Economy	12200.00
0005434184700	11643	Economy	12200.00
0005434143737	11643	Economy	12200.00
0005434095390	11643	Economy	12200.00
0005434182420	11643	Economy	12200.00
0005434183615	11643	Economy	12200.00
0005434182413	11643	Economy	12200.00
0005434182412	11643	Economy	12200.00
0005434182414	11643	Economy	12200.00
0005434182415	11643	Economy	12200.00
0005433398512	1464	Business	33000.00
0005433398700	1464	Business	33000.00
0005435732553	1464	Business	33000.00
0005433398675	1464	Business	33000.00
0005433398645	1464	Business	33000.00
0005433398699	1464	Business	33000.00
0005433398577	1464	Business	33000.00
0005433398290	1464	Business	33000.00
0005433398591	1464	Business	33000.00
0005433457046	1464	Business	33000.00
0005433398555	1464	Business	33000.00
0005433398408	1464	Economy	11000.00
0005433398511	1464	Economy	11000.00
0005433398485	1464	Economy	11000.00
0005433398466	1464	Economy	11000.00
0005433398676	1464	Economy	11000.00
0005433398473	1464	Economy	11000.00
0005433398609	1464	Economy	11000.00
0005433398610	1464	Economy	12100.00
0005435732564	1464	Economy	12100.00
0005433398406	1464	Economy	12100.00
0005433398405	1464	Economy	11000.00
0005433398327	1464	Economy	11000.00
0005433398528	1464	Economy	11000.00
0005435732555	1464	Economy	11000.00
0005433398481	1464	Economy	11000.00
0005433398407	1464	Economy	11000.00
0005433398314	1464	Economy	11000.00
0005433457042	1464	Economy	11000.00
0005435732562	1464	Economy	11000.00
0005433398450	1464	Economy	11000.00
0005433398495	1464	Economy	11000.00
0005433398650	1464	Economy	11000.00
0005433457045	1464	Economy	11000.00
0005435732561	1464	Economy	11000.00
0005433398461	1464	Economy	11000.00
0005435732558	1464	Economy	11000.00
0005435732560	1464	Economy	11000.00
0005433398486	1464	Economy	11000.00
0005433398343	1464	Economy	11000.00
0005433398449	1464	Economy	11000.00
0005433398443	1464	Economy	11000.00
0005435732563	1464	Economy	11000.00
0005435732554	1464	Economy	11000.00
0005433398578	1464	Economy	11000.00
0005435732559	1464	Economy	11000.00
0005435732566	1464	Economy	11000.00
0005435732556	1464	Economy	11000.00
0005433398505	1464	Economy	11000.00
0005433457044	1464	Economy	11000.00
0005433398487	1464	Economy	11000.00
0005433398620	1464	Economy	11000.00
0005433398621	1464	Economy	11000.00
0005433398646	1464	Economy	11000.00
0005432906572	1464	Economy	11000.00
0005433398619	1464	Economy	11000.00
0005433398416	1464	Economy	11000.00
0005433398465	1464	Economy	11000.00
0005433398523	1464	Economy	11000.00
0005433398612	1464	Economy	11000.00
0005433457043	1464	Economy	11000.00
0005433398367	1464	Economy	11000.00
0005433398677	1464	Economy	11000.00
0005433398480	1464	Economy	11000.00
0005433398496	1464	Economy	11000.00
0005433398709	1464	Economy	11000.00
0005433398458	1464	Economy	11000.00
0005433398311	1464	Economy	11000.00
0005435732565	1464	Economy	11000.00
0005433398527	1464	Economy	11000.00
0005433398442	1464	Economy	11000.00
0005433398710	1464	Economy	11000.00
0005435732557	1464	Economy	11000.00
0005433398457	1464	Economy	11000.00
0005433398957	19284	Business	33000.00
0005435732431	19284	Business	33000.00
0005435732441	19284	Business	33000.00
0005433398961	19284	Business	33000.00
0005435732485	19284	Business	33000.00
0005435732504	19284	Business	33000.00
0005433398943	19284	Economy	11000.00
0005433398954	19284	Economy	11000.00
0005433398962	19284	Economy	11000.00
0005433398940	19284	Economy	11000.00
0005433398950	19284	Economy	11000.00
0005433398926	19284	Economy	12100.00
0005433398959	19284	Economy	12100.00
0005433398938	19284	Economy	12100.00
0005435732410	19284	Economy	11000.00
0005433398920	19284	Economy	11000.00
0005433398946	19284	Economy	11000.00
0005435732449	19284	Economy	11000.00
0005433398963	19284	Economy	11000.00
0005433398947	19284	Economy	11000.00
0005433398931	19284	Economy	11000.00
0005433398929	19284	Economy	11000.00
0005433398939	19284	Economy	11000.00
0005433398932	19284	Economy	11000.00
0005433398965	19284	Economy	11000.00
0005435732429	19284	Economy	11000.00
0005433398967	19284	Economy	11000.00
0005433398956	19284	Economy	11000.00
0005435732448	19284	Economy	11000.00
0005433457004	19284	Economy	11000.00
0005433398925	19284	Economy	11000.00
0005433398955	19284	Economy	11000.00
0005433398960	19284	Economy	11000.00
0005435732428	19284	Economy	11000.00
0005433398951	19284	Economy	11000.00
0005433398921	19284	Economy	11000.00
0005433398948	19284	Economy	11000.00
0005433457021	19284	Economy	11000.00
0005433398945	19284	Economy	11000.00
0005433398930	19284	Economy	11000.00
0005433398966	19284	Economy	11000.00
0005433398953	19284	Economy	11000.00
0005435732433	19284	Economy	11000.00
0005435732411	19284	Economy	11000.00
0005435732430	19284	Economy	11000.00
0005433398964	19284	Economy	11000.00
0005433398941	19284	Economy	11000.00
0005432906580	19284	Economy	11000.00
0005433398923	19284	Economy	11000.00
0005433398922	19284	Economy	11000.00
0005433398937	19284	Economy	11000.00
0005435732424	19284	Economy	11000.00
0005433398924	19284	Economy	11000.00
0005433398936	19284	Economy	11000.00
0005433457007	19284	Economy	11000.00
0005433398933	19284	Economy	11000.00
0005433398935	19284	Economy	11000.00
0005433398952	19284	Economy	11000.00
0005433398934	19284	Economy	11000.00
0005433398944	19284	Economy	11000.00
0005432906581	19284	Economy	11000.00
0005433457008	19284	Economy	11000.00
0005433398927	19284	Economy	11000.00
0005433398942	19284	Economy	11000.00
0005433398949	19284	Economy	11000.00
0005433457022	19284	Economy	11000.00
0005433457020	19284	Economy	11000.00
0005433398928	19284	Economy	11000.00
0005433398919	19284	Economy	11000.00
0005433398958	19284	Economy	11000.00
0005434443792	17339	Economy	15600.00
0005434443895	17339	Economy	14100.00
0005434443793	17339	Economy	14100.00
0005434443881	17339	Economy	14100.00
0005434443880	17339	Economy	14100.00
0005434443892	17339	Economy	14100.00
0005434443796	17339	Economy	14100.00
0005434443897	17339	Economy	14100.00
0005434443879	17339	Economy	14100.00
0005434443844	17339	Economy	14100.00
0005434443896	17339	Economy	14100.00
0005434443893	17339	Economy	14100.00
0005434443876	17339	Economy	14100.00
0005434444003	20589	Economy	15600.00
0005434443997	20589	Economy	15600.00
0005434443995	20589	Economy	14100.00
0005434443991	20589	Economy	14100.00
0005434443999	20589	Economy	14100.00
0005434444001	20589	Economy	14100.00
0005434443987	20589	Economy	14100.00
0005434444002	20589	Economy	14100.00
0005434443990	20589	Economy	14100.00
0005434443992	20589	Economy	14100.00
0005434443989	20589	Economy	14100.00
0005434443988	20589	Economy	14100.00
0005434443996	20589	Economy	14100.00
0005434443998	20589	Economy	14100.00
0005434443994	20589	Economy	14100.00
0005434443993	20589	Economy	14100.00
0005434443986	20589	Economy	14100.00
0005434444000	20589	Economy	14100.00
0005434954681	7269	Economy	5800.00
0005434954680	7269	Economy	5800.00
0005434954682	7269	Economy	5800.00
0005434954631	28337	Economy	5800.00
0005434954648	28337	Economy	5800.00
0005434954632	28337	Economy	5800.00
0005435377623	28337	Economy	5800.00
0005435377622	28337	Economy	5800.00
0005434954633	28337	Economy	5800.00
0005434954650	28337	Economy	5800.00
0005434954647	28337	Economy	5800.00
0005434351923	4504	Economy	14000.00
0005435893711	4504	Economy	14000.00
0005434351926	4504	Economy	14000.00
0005434351931	4504	Economy	14000.00
0005434351927	4504	Economy	14000.00
0005434351925	4504	Economy	14000.00
0005435893702	4504	Economy	14000.00
0005435893706	4504	Economy	14000.00
0005434351924	4504	Economy	14000.00
0005434351934	4504	Economy	14000.00
0005434351929	4504	Economy	14000.00
0005434351935	4504	Economy	14000.00
0005435893677	4504	Economy	14000.00
0005434351928	4504	Economy	14000.00
0005434326280	4504	Economy	14000.00
0005434351933	4504	Economy	14000.00
0005435893676	4504	Economy	14000.00
0005435893705	4504	Economy	14000.00
0005434351930	4504	Economy	14000.00
0005434351932	4504	Economy	14000.00
0005435893712	4504	Economy	14000.00
0005434326281	4504	Economy	14000.00
0005435893691	4504	Economy	14000.00
0005434183596	4504	Economy	14000.00
0005434351777	29660	Economy	14000.00
0005435893761	29660	Economy	14000.00
0005434351811	29660	Economy	14000.00
0005434351791	29660	Economy	14000.00
0005434351832	29660	Economy	14000.00
0005434351858	29660	Economy	14000.00
0005435893762	29660	Economy	14000.00
0005434351850	29660	Economy	14000.00
0005434351849	29660	Economy	14000.00
0005434351805	29660	Economy	14000.00
0005435893760	29660	Economy	14000.00
0005434351812	29660	Economy	14000.00
0005434351847	29660	Economy	14000.00
0005435893759	29660	Economy	14000.00
0005435893764	29660	Economy	14000.00
0005434351851	29660	Economy	14000.00
0005434351819	29660	Economy	14000.00
0005434351790	29660	Economy	14000.00
0005435893765	29660	Economy	14000.00
0005434351833	29660	Economy	14000.00
0005434351857	29660	Economy	14000.00
0005435893763	29660	Economy	14000.00
0005434351778	29660	Economy	14000.00
0005435092255	1069	Business	30600.00
0005433463941	1069	Business	30600.00
0005435545872	1069	Business	30600.00
0005435092252	1069	Business	30600.00
0005433344059	1069	Business	30600.00
0005433344038	1069	Business	30600.00
0005433343998	1069	Business	30600.00
0005433343619	1069	Business	30600.00
0005433343989	1069	Business	30600.00
0005433343981	1069	Business	30600.00
0005433344058	1069	Business	30600.00
0005433344206	1069	Business	30600.00
0005433343867	1069	Business	30600.00
0005433269742	1069	Business	30600.00
0005433344289	1069	Business	30600.00
0005433344113	1069	Business	30600.00
0005433343624	1069	Business	30600.00
0005433343591	1069	Economy	11200.00
0005433159329	1069	Business	30600.00
0005433159330	1069	Economy	11200.00
0005433343868	1069	Economy	10200.00
0005433343999	1069	Economy	10200.00
0005433343853	1069	Economy	10200.00
0005433462787	1069	Economy	10200.00
0005433463940	1069	Economy	10200.00
0005433343894	1069	Economy	10200.00
0005433344070	1069	Economy	10200.00
0005434445289	1069	Economy	10200.00
0005433344072	1069	Economy	10200.00
0005433463939	1069	Economy	10200.00
0005433343919	1069	Economy	10200.00
0005433343833	1069	Economy	10200.00
0005433344545	1069	Economy	10200.00
0005433344160	1069	Economy	10200.00
0005433343646	1069	Economy	10200.00
0005433344074	1069	Economy	10200.00
0005433269781	1069	Economy	10200.00
0005433344183	1069	Economy	10200.00
0005434445287	1069	Economy	10200.00
0005433344036	1069	Economy	10200.00
0005433344008	1069	Economy	10200.00
0005433462786	1069	Economy	10200.00
0005433343742	1069	Economy	10200.00
0005433343741	1069	Economy	10200.00
0005433343850	1069	Economy	10200.00
0005435092254	1069	Economy	10200.00
0005433344090	1069	Economy	10200.00
0005433343849	1069	Economy	10200.00
0005433343622	1069	Economy	10200.00
0005433344182	1069	Economy	10200.00
0005433344034	1069	Economy	10200.00
0005433343971	1069	Economy	10200.00
0005433344131	1069	Economy	10200.00
0005432293254	1069	Economy	10200.00
0005434445288	1069	Economy	10200.00
0005433269743	1069	Economy	10200.00
0005433343645	1069	Economy	10200.00
0005433343990	1069	Economy	10200.00
0005433343869	1069	Economy	10200.00
0005433344272	1069	Economy	10200.00
0005433344010	1069	Economy	10200.00
0005435092258	1069	Economy	10200.00
0005433343935	1069	Economy	10200.00
0005433344504	1069	Economy	10200.00
0005433343920	1069	Economy	10200.00
0005433344124	1069	Economy	10200.00
0005433269774	1069	Economy	10200.00
0005433344506	1069	Economy	10200.00
0005433343810	1069	Economy	10200.00
0005433344159	1069	Economy	10200.00
0005433344199	1069	Economy	10200.00
0005433343931	1069	Economy	10200.00
0005433344544	1069	Economy	10200.00
0005433344157	1069	Economy	10200.00
0005433344161	1069	Economy	10200.00
0005433343893	1069	Economy	10200.00
0005433344151	1069	Economy	10200.00
0005433343808	1069	Economy	10200.00
0005433344290	1069	Economy	10200.00
0005433159337	1069	Economy	11200.00
0005433343639	1069	Economy	10200.00
0005435092257	1069	Economy	11200.00
0005433344147	1069	Economy	10200.00
0005435092259	1069	Economy	10200.00
0005433269790	1069	Economy	10200.00
0005433269756	1069	Economy	10200.00
0005433343832	1069	Economy	10200.00
0005435092260	1069	Economy	10200.00
0005433344171	1069	Economy	10200.00
0005435092256	1069	Economy	10200.00
0005433343988	1069	Economy	10200.00
0005433344172	1069	Economy	10200.00
0005433344156	1069	Economy	10200.00
0005433343702	1069	Economy	10200.00
0005433344114	1069	Economy	10200.00
0005433343942	1069	Economy	10200.00
0005435092253	1069	Economy	10200.00
0005433269783	1069	Economy	10200.00
0005433343459	1069	Economy	10200.00
0005433344035	1069	Economy	10200.00
0005432293252	1069	Economy	10200.00
0005433344271	1069	Economy	10200.00
0005433343460	1069	Economy	10200.00
0005434446561	1069	Economy	10200.00
0005433269775	1069	Economy	10200.00
0005433343716	1069	Economy	10200.00
0005435092261	1069	Economy	10200.00
0005432293253	1069	Economy	10200.00
0005433343900	1069	Economy	10200.00
0005434446560	1069	Economy	10200.00
0005433344270	1069	Economy	10200.00
0005433344007	1069	Economy	10200.00
0005433343918	1069	Economy	10200.00
0005433344123	1069	Economy	10200.00
0005433343854	1069	Economy	10200.00
0005433343871	1069	Economy	10200.00
0005433343701	1069	Economy	10200.00
0005433462785	1069	Economy	10200.00
0005433159331	1069	Economy	10200.00
0005433344255	1069	Economy	10200.00
0005433269767	1069	Economy	10200.00
0005433269782	1069	Economy	10200.00
0005433159332	1069	Economy	10200.00
0005433344071	1069	Economy	10200.00
0005433343632	1069	Economy	10200.00
0005433343980	1069	Economy	10200.00
0005433343819	1069	Economy	10200.00
0005433343277	1069	Economy	10200.00
0005433344009	1069	Economy	10200.00
0005433344505	1069	Economy	10200.00
0005433344200	1069	Economy	10200.00
0005433343983	1069	Economy	10200.00
0005433344085	1069	Economy	10200.00
0005433344284	1069	Economy	10200.00
0005433344099	1069	Economy	10200.00
0005433343623	1069	Economy	10200.00
0005433343633	1069	Economy	10200.00
0005433344045	1069	Economy	10200.00
0005433344158	1069	Economy	10200.00
0005433344014	1069	Economy	10200.00
0005433344923	17077	Business	30600.00
0005433344890	17077	Business	30600.00
0005433344904	17077	Business	30600.00
0005433344877	17077	Business	30600.00
0005433344873	17077	Business	30600.00
0005433344908	17077	Business	30600.00
0005433344843	17077	Business	30600.00
0005435508464	17077	Business	30600.00
0005433344892	17077	Business	30600.00
0005433344871	17077	Business	30600.00
0005433344907	17077	Business	30600.00
0005435508463	17077	Business	30600.00
0005433344939	17077	Business	30600.00
0005433344876	17077	Business	30600.00
0005433344899	17077	Business	30600.00
0005433344888	17077	Business	30600.00
0005435508414	17077	Economy	11200.00
0005433344885	17077	Economy	10200.00
0005433269815	17077	Economy	10200.00
0005433344847	17077	Economy	10200.00
0005433344886	17077	Economy	10200.00
0005433344931	17077	Economy	10200.00
0005433344910	17077	Economy	10200.00
0005433344902	17077	Economy	10200.00
0005433344936	17077	Economy	10200.00
0005433344883	17077	Economy	10200.00
0005433344941	17077	Economy	10200.00
0005433344915	17077	Economy	10200.00
0005433344853	17077	Economy	10200.00
0005433344893	17077	Economy	10200.00
0005433344896	17077	Economy	10200.00
0005433344855	17077	Economy	10200.00
0005433344846	17077	Economy	10200.00
0005435508413	17077	Economy	10200.00
0005433344850	17077	Economy	10200.00
0005435508447	17077	Economy	10200.00
0005433344842	17077	Economy	10200.00
0005433344854	17077	Economy	10200.00
0005433344927	17077	Economy	10200.00
0005433344937	17077	Economy	10200.00
0005433344930	17077	Economy	10200.00
0005433344920	17077	Economy	10200.00
0005433344932	17077	Economy	10200.00
0005433344895	17077	Economy	10200.00
0005433344862	17077	Economy	10200.00
0005433344935	17077	Economy	10200.00
0005433159353	17077	Economy	10200.00
0005433344861	17077	Economy	10200.00
0005433344848	17077	Economy	10200.00
0005433344906	17077	Economy	10200.00
0005435508430	17077	Economy	10200.00
0005433344865	17077	Economy	10200.00
0005433344872	17077	Economy	10200.00
0005433344914	17077	Economy	10200.00
0005433344840	17077	Economy	10200.00
0005433344912	17077	Economy	10200.00
0005433344916	17077	Economy	10200.00
0005433344938	17077	Economy	10200.00
0005435092170	17077	Economy	10200.00
0005435508417	17077	Economy	10200.00
0005433159352	17077	Economy	10200.00
0005433344863	17077	Economy	10200.00
0005433344894	17077	Economy	10200.00
0005433344887	17077	Economy	10200.00
0005435508465	17077	Economy	10200.00
0005433344933	17077	Economy	10200.00
0005433344884	17077	Economy	10200.00
0005433344882	17077	Economy	10200.00
0005433344913	17077	Economy	10200.00
0005435508462	17077	Economy	10200.00
0005433344924	17077	Economy	10200.00
0005435508431	17077	Economy	10200.00
0005433344844	17077	Economy	10200.00
0005433344859	17077	Economy	10200.00
0005433344911	17077	Economy	10200.00
0005433344879	17077	Economy	10200.00
0005435508461	17077	Economy	10200.00
0005433344857	17077	Economy	10200.00
0005433344934	17077	Economy	11200.00
0005433344878	17077	Economy	10200.00
0005433344841	17077	Economy	10200.00
0005433344881	17077	Economy	10200.00
0005434445259	17077	Economy	10200.00
0005433269821	17077	Economy	10200.00
0005433344926	17077	Economy	10200.00
0005433344860	17077	Economy	10200.00
0005435092180	17077	Economy	10200.00
0005433344918	17077	Economy	10200.00
0005433344921	17077	Economy	10200.00
0005435092229	17077	Economy	10200.00
0005435092171	17077	Economy	10200.00
0005433344925	17077	Economy	10200.00
0005435508460	17077	Economy	10200.00
0005433344851	17077	Economy	10200.00
0005433344858	17077	Economy	10200.00
0005433344866	17077	Economy	10200.00
0005433269820	17077	Economy	10200.00
0005433344917	17077	Economy	10200.00
0005433344864	17077	Economy	10200.00
0005435092182	17077	Economy	10200.00
0005433344919	17077	Economy	10200.00
0005433344849	17077	Economy	10200.00
0005435508448	17077	Economy	10200.00
0005433344897	17077	Economy	10200.00
0005433344856	17077	Economy	10200.00
0005433344901	17077	Economy	10200.00
0005433344845	17077	Economy	10200.00
0005433269819	17077	Economy	10200.00
0005433344867	17077	Economy	10200.00
0005433269818	17077	Economy	10200.00
0005433344929	17077	Economy	10200.00
0005433344870	17077	Economy	10200.00
0005433344889	17077	Economy	10200.00
0005435092202	17077	Economy	10200.00
0005433344928	17077	Economy	10200.00
0005433344922	17077	Economy	10200.00
0005433344940	17077	Economy	10200.00
0005435508459	17077	Economy	10200.00
0005433344852	17077	Economy	10200.00
0005433344903	17077	Economy	10200.00
0005433344900	17077	Economy	10200.00
0005433344909	17077	Economy	10200.00
0005433269816	17077	Economy	10200.00
0005433344880	17077	Economy	10200.00
0005433269817	17077	Economy	10200.00
0005433344868	17077	Economy	10200.00
0005433344905	17077	Economy	10200.00
0005433344869	17077	Economy	10200.00
0005433344898	17077	Economy	10200.00
0005435092181	17077	Economy	10200.00
0005433344874	17077	Economy	10200.00
0005433344875	17077	Economy	10200.00
0005433344891	17077	Economy	10200.00
0005432852021	18268	Business	101000.00
0005432390227	18268	Business	101000.00
0005432852034	18268	Business	101000.00
0005432392016	18268	Business	101000.00
0005432852026	18268	Business	101000.00
0005432392024	18268	Business	101000.00
0005432392005	18268	Business	101000.00
0005432390220	18268	Business	101000.00
0005432852020	18268	Business	101000.00
0005432390264	18268	Business	101000.00
0005432852035	18268	Business	101000.00
0005432392023	18268	Business	101000.00
0005432852017	18268	Economy	33700.00
0005432390136	18268	Economy	33700.00
0005432390198	18268	Economy	33700.00
0005432390266	18268	Economy	33700.00
0005432390196	18268	Economy	33700.00
0005432852023	18268	Economy	33700.00
0005432390183	18268	Economy	33700.00
0005432390186	18268	Economy	37000.00
0005432390215	18268	Economy	33700.00
0005432392027	18268	Economy	33700.00
0005432852025	18268	Economy	33700.00
0005432852033	18268	Economy	33700.00
0005432390210	18268	Economy	33700.00
0005432392008	18268	Economy	33700.00
0005432390265	18268	Economy	33700.00
0005432390211	18268	Economy	33700.00
0005432390188	18268	Economy	33700.00
0005432390261	18268	Economy	33700.00
0005432392017	18268	Economy	33700.00
0005432852016	18268	Economy	33700.00
0005432390212	18268	Economy	33700.00
0005432390175	18268	Economy	33700.00
0005432390194	18268	Economy	33700.00
0005432392035	18268	Economy	33700.00
0005432852024	18268	Economy	33700.00
0005432390197	18268	Economy	33700.00
0005432390238	18268	Economy	33700.00
0005432852015	18268	Economy	33700.00
0005432852032	18268	Economy	33700.00
0005432852027	18268	Economy	33700.00
0005432390202	18268	Economy	33700.00
0005432392015	18268	Economy	33700.00
0005432390226	18268	Economy	33700.00
0005432390260	18268	Economy	33700.00
0005432852030	18268	Economy	33700.00
0005432852029	18268	Economy	33700.00
0005432390249	18268	Economy	33700.00
0005432390217	18268	Economy	33700.00
0005432852031	18268	Economy	33700.00
0005432390216	18268	Economy	33700.00
0005432390248	18268	Economy	33700.00
0005432852028	18268	Economy	33700.00
0005432392014	18268	Economy	33700.00
0005432852019	18268	Economy	33700.00
0005432390203	18268	Economy	33700.00
0005432390239	18268	Economy	33700.00
0005432392007	18268	Economy	33700.00
0005432392006	18268	Economy	33700.00
0005432392036	18268	Economy	33700.00
0005432852018	18268	Economy	33700.00
0005432852022	18268	Economy	33700.00
0005432392010	18268	Economy	33700.00
0005432390195	18268	Economy	33700.00
0005432390214	18268	Economy	33700.00
0005432390259	18268	Economy	33700.00
0005432852014	18268	Economy	33700.00
0005432390262	18268	Economy	33700.00
0005434082089	12784	Business	40300.00
0005434082142	12784	Business	40300.00
0005434082064	12784	Business	40300.00
0005435283420	12784	Business	40300.00
0005432433779	12784	Business	40300.00
0005434068347	12784	Business	40300.00
0005433989802	12784	Business	40300.00
0005432159943	12784	Business	40300.00
0005432433778	12784	Economy	13400.00
0005432161193	12784	Economy	13400.00
0005434068467	12784	Economy	13400.00
0005434068073	12784	Economy	13400.00
0005434082136	12784	Economy	13400.00
0005434067824	12784	Economy	13400.00
0005434068340	12784	Economy	13400.00
0005434026720	12784	Economy	13400.00
0005434068198	12784	Economy	13400.00
0005434068106	12784	Economy	13400.00
0005434068396	12784	Economy	13400.00
0005434068445	12784	Economy	13400.00
0005434068199	12784	Economy	13400.00
0005434068478	12784	Economy	13400.00
0005434068317	12784	Economy	13400.00
0005434068341	12784	Economy	13400.00
0005434068238	12784	Economy	13400.00
0005435283425	12784	Economy	13400.00
0005434068369	12784	Economy	13400.00
0005434068099	12784	Economy	13400.00
0005434068222	12784	Economy	13400.00
0005434068240	12784	Economy	13400.00
0005434068078	12784	Economy	13400.00
0005434068358	12784	Economy	13400.00
0005434068113	12784	Economy	13400.00
0005434068068	12784	Economy	13400.00
0005434068367	12784	Economy	13400.00
0005432161195	12784	Economy	13400.00
0005434068048	12784	Economy	13400.00
0005434068366	12784	Economy	13400.00
0005432159940	12784	Economy	13400.00
0005434068132	12784	Economy	13400.00
0005434082111	12784	Economy	13400.00
0005433989794	12784	Economy	14800.00
0005434068169	12784	Economy	14800.00
0005434068248	12784	Economy	14800.00
0005434068298	12784	Economy	14800.00
0005434068014	12784	Economy	14800.00
0005434068234	12784	Economy	14800.00
0005434068047	12784	Economy	13400.00
0005435283424	12784	Economy	13400.00
0005434026721	12784	Economy	13400.00
0005433812944	12784	Economy	13400.00
0005434082040	12784	Economy	13400.00
0005434082135	12784	Economy	13400.00
0005433989808	12784	Economy	13400.00
0005432159941	12784	Economy	13400.00
0005434068316	12784	Economy	13400.00
0005434082109	12784	Economy	13400.00
0005434082146	12784	Economy	13400.00
0005434082180	12784	Economy	13400.00
0005432433777	12784	Economy	13400.00
0005434068122	12784	Economy	13400.00
0005432161194	12784	Economy	13400.00
0005433989809	12784	Economy	13400.00
0005432433781	12784	Economy	13400.00
0005434068202	12784	Economy	13400.00
0005434068112	12784	Economy	13400.00
0005434082108	12784	Economy	13400.00
0005432433780	12784	Economy	13400.00
0005434082181	12784	Economy	13400.00
0005434068374	12784	Economy	13400.00
0005434068074	12784	Economy	13400.00
0005434067950	12784	Economy	13400.00
0005434026731	12784	Economy	13400.00
0005434082107	12784	Economy	13400.00
0005434082065	12784	Economy	13400.00
0005434082211	12784	Economy	13400.00
0005434082116	12784	Economy	13400.00
0005434068001	12784	Economy	13400.00
0005432161196	12784	Economy	13400.00
0005434068579	12784	Economy	13400.00
0005435283421	12784	Economy	13400.00
0005434068133	12784	Economy	13400.00
0005434068135	12784	Economy	13400.00
0005434068028	12784	Economy	13400.00
0005434068185	12784	Economy	13400.00
0005435283422	12784	Economy	13400.00
0005432159942	12784	Economy	13400.00
0005434082110	12784	Economy	13400.00
0005434082057	12784	Economy	13400.00
0005434082039	12784	Economy	13400.00
0005434068249	12784	Economy	13400.00
0005432433782	12784	Economy	13400.00
0005434082063	12784	Economy	13400.00
0005434082070	12784	Economy	13400.00
0005435283426	12784	Economy	13400.00
0005434068015	12784	Economy	13400.00
0005434082189	12784	Economy	13400.00
0005434082128	12784	Economy	13400.00
0005434082149	12784	Economy	13400.00
0005435283423	12784	Economy	13400.00
0005433989810	12784	Economy	13400.00
0005434082088	12784	Economy	13400.00
0005434068204	12784	Economy	13400.00
0005434068312	12784	Economy	13400.00
0005434068221	12784	Economy	13400.00
0005434067823	12784	Economy	13400.00
0005434068098	12784	Economy	13400.00
0005433812945	12784	Economy	13400.00
0005434068083	12784	Economy	13400.00
0005434068152	12784	Economy	13400.00
0005434068075	12784	Economy	13400.00
0005434068061	12784	Economy	13400.00
0005434068829	30640	Business	40300.00
0005434068804	30640	Business	40300.00
0005434082299	30640	Business	40300.00
0005434068777	30640	Business	40300.00
0005432150328	30640	Business	40300.00
0005434082307	30640	Business	40300.00
0005432150332	30640	Business	40300.00
0005434068798	30640	Business	40300.00
0005434082289	30640	Business	40300.00
0005434082293	30640	Business	40300.00
0005434082287	30640	Economy	13400.00
0005434068828	30640	Economy	13400.00
0005434082288	30640	Economy	13400.00
0005434068765	30640	Economy	13400.00
0005432433719	30640	Economy	13400.00
0005432433744	30640	Economy	13400.00
0005434082306	30640	Economy	13400.00
0005434068792	30640	Economy	13400.00
0005434082297	30640	Economy	13400.00
0005434068797	30640	Economy	13400.00
0005434068768	30640	Economy	13400.00
0005434068822	30640	Economy	13400.00
0005432150331	30640	Economy	13400.00
0005434068807	30640	Economy	13400.00
0005434068809	30640	Economy	13400.00
0005434082301	30640	Economy	13400.00
0005434068793	30640	Economy	13400.00
0005434082304	30640	Economy	13400.00
0005434068774	30640	Economy	13400.00
0005434082305	30640	Economy	13400.00
0005434082290	30640	Economy	13400.00
0005434068835	30640	Economy	13400.00
0005432433745	30640	Economy	13400.00
0005434082291	30640	Economy	13400.00
0005434068802	30640	Economy	13400.00
0005434068830	30640	Economy	13400.00
0005434082302	30640	Economy	13400.00
0005432186932	30640	Economy	13400.00
0005434068799	30640	Economy	13400.00
0005434068790	30640	Economy	13400.00
0005434068812	30640	Economy	13400.00
0005434068814	30640	Economy	13400.00
0005432186933	30640	Economy	13400.00
0005432433758	30640	Economy	13400.00
0005434068786	30640	Economy	13400.00
0005432150330	30640	Economy	13400.00
0005432186934	30640	Economy	13400.00
0005434068813	30640	Economy	13400.00
0005434068783	30640	Economy	14800.00
0005434068789	30640	Economy	14800.00
0005434068823	30640	Economy	14800.00
0005434068788	30640	Economy	14800.00
0005434068771	30640	Economy	14800.00
0005434068816	30640	Economy	14800.00
0005433989856	30640	Economy	13400.00
0005434082285	30640	Economy	13400.00
0005434068796	30640	Economy	13400.00
0005434068769	30640	Economy	13400.00
0005434068817	30640	Economy	13400.00
0005434068806	30640	Economy	13400.00
0005434068833	30640	Economy	13400.00
0005434068827	30640	Economy	13400.00
0005434068775	30640	Economy	13400.00
0005433989855	30640	Economy	13400.00
0005434068784	30640	Economy	13400.00
0005434068836	30640	Economy	13400.00
0005434068808	30640	Economy	13400.00
0005434068787	30640	Economy	13400.00
0005434068821	30640	Economy	13400.00
0005432150335	30640	Economy	13400.00
0005434082295	30640	Economy	13400.00
0005434068781	30640	Economy	13400.00
0005434082286	30640	Economy	13400.00
0005434068826	30640	Economy	13400.00
0005434068800	30640	Economy	13400.00
0005434082298	30640	Economy	13400.00
0005434068815	30640	Economy	13400.00
0005434068772	30640	Economy	13400.00
0005432433759	30640	Economy	13400.00
0005433989854	30640	Economy	13400.00
0005434068770	30640	Economy	13400.00
0005434068794	30640	Economy	13400.00
0005434068764	30640	Economy	13400.00
0005434068785	30640	Economy	13400.00
0005434068805	30640	Economy	13400.00
0005432150334	30640	Economy	13400.00
0005432433728	30640	Economy	13400.00
0005432150333	30640	Economy	13400.00
0005434068824	30640	Economy	13400.00
0005434068818	30640	Economy	13400.00
0005434082296	30640	Economy	13400.00
0005434068803	30640	Economy	13400.00
0005434068776	30640	Economy	13400.00
0005434068767	30640	Economy	13400.00
0005434068834	30640	Economy	13400.00
0005434082300	30640	Economy	13400.00
0005434068832	30640	Economy	13400.00
0005432186931	30640	Economy	13400.00
0005434068779	30640	Economy	13400.00
0005434068810	30640	Economy	13400.00
0005434068780	30640	Economy	13400.00
0005434082294	30640	Economy	13400.00
0005434082292	30640	Economy	13400.00
0005434068825	30640	Economy	13400.00
0005434068801	30640	Economy	13400.00
0005434068791	30640	Economy	13400.00
0005434082303	30640	Economy	13400.00
0005434068820	30640	Economy	13400.00
0005434068778	30640	Economy	13400.00
0005434068831	30640	Economy	13400.00
0005434068782	30640	Economy	13400.00
0005434068773	30640	Economy	13400.00
0005432150329	30640	Economy	13400.00
0005434068766	30640	Economy	13400.00
0005434068819	30640	Economy	13400.00
0005433989853	30640	Economy	13400.00
0005434068811	30640	Economy	13400.00
0005432433723	30640	Economy	13400.00
0005433989852	30640	Economy	13400.00
0005434068795	30640	Economy	13400.00
0005433689922	19364	Economy	19300.00
0005433686648	19364	Economy	17600.00
0005433689930	19364	Economy	17600.00
0005433689928	19364	Economy	17600.00
0005433686647	19364	Economy	17600.00
0005433686661	19364	Economy	17600.00
0005433689927	19364	Economy	17600.00
0005433689926	19364	Economy	17600.00
0005435735221	5534	Business	35300.00
0005435767348	5534	Business	35300.00
0005435767324	5534	Business	35300.00
0005435767302	5534	Business	35300.00
0005435767361	5534	Business	35300.00
0005433529348	5534	Business	35300.00
0005434265318	5534	Business	35300.00
0005435735220	5534	Business	35300.00
0005434265345	5534	Business	35300.00
0005435462805	5534	Business	35300.00
0005434831189	5534	Business	35300.00
0005435767306	5534	Business	35300.00
0005433529349	5534	Business	35300.00
0005435767349	5534	Business	35300.00
0005435720846	5534	Business	35300.00
0005432140597	5534	Business	35300.00
0005435725686	5534	Business	35300.00
0005435720843	5534	Business	35300.00
0005434265331	5534	Business	35300.00
0005435767325	5534	Business	35300.00
0005435767290	5534	Business	35300.00
0005435720844	5534	Business	35300.00
0005433529347	5534	Economy	12900.00
0005435462764	5534	Economy	12900.00
0005435767357	5534	Economy	12900.00
0005435767330	5534	Economy	11800.00
0005435767331	5534	Economy	11800.00
0005435767347	5534	Economy	11800.00
0005434265372	5534	Economy	11800.00
0005435767313	5534	Economy	11800.00
0005435767345	5534	Economy	11800.00
0005434831200	5534	Economy	11800.00
0005434265449	5534	Economy	11800.00
0005435462819	5534	Economy	11800.00
0005434265383	5534	Economy	11800.00
0005434265264	5534	Economy	11800.00
0005435767360	5534	Economy	11800.00
0005435767334	5534	Economy	11800.00
0005434265411	5534	Economy	11800.00
0005435767353	5534	Economy	11800.00
0005434265377	5534	Economy	11800.00
0005435767354	5534	Economy	11800.00
0005434265446	5534	Economy	11800.00
0005435735218	5534	Economy	11800.00
0005435462953	5534	Economy	11800.00
0005435767322	5534	Economy	11800.00
0005434265382	5534	Economy	11800.00
0005434831212	5534	Economy	11800.00
0005435767314	5534	Economy	11800.00
0005435767339	5534	Economy	11800.00
0005435767292	5534	Economy	11800.00
0005435767291	5534	Economy	11800.00
0005434831201	5534	Economy	11800.00
0005432140596	5534	Economy	11800.00
0005435767328	5534	Economy	11800.00
0005435462872	5534	Economy	11800.00
0005435462653	5534	Economy	11800.00
0005434265371	5534	Economy	11800.00
0005435767352	5534	Economy	11800.00
0005435767297	5534	Economy	11800.00
0005435767307	5534	Economy	11800.00
0005435767327	5534	Economy	11800.00
0005432140594	5534	Economy	11800.00
0005435767316	5534	Economy	11800.00
0005435735219	5534	Economy	11800.00
0005434265315	5534	Economy	11800.00
0005434831202	5534	Economy	11800.00
0005435462917	5534	Economy	11800.00
0005434265316	5534	Economy	11800.00
0005435462884	5534	Economy	11800.00
0005435462916	5534	Economy	11800.00
0005432140602	5534	Economy	11800.00
0005435767363	5534	Economy	11800.00
0005432140598	5534	Economy	11800.00
0005435767305	5534	Economy	11800.00
0005435462658	5534	Economy	11800.00
0005435767309	5534	Economy	11800.00
0005435767362	5534	Economy	11800.00
0005435767337	5534	Economy	11800.00
0005435462760	5534	Economy	11800.00
0005433527336	5534	Economy	11800.00
0005435462804	5534	Economy	11800.00
0005435767296	5534	Economy	11800.00
0005432140601	5534	Economy	11800.00
0005435767310	5534	Economy	11800.00
0005435767342	5534	Economy	11800.00
0005433529350	5534	Economy	11800.00
0005435462873	5534	Economy	11800.00
0005435725685	5534	Economy	11800.00
0005435767359	5534	Economy	11800.00
0005434265353	5534	Economy	11800.00
0005435462915	5534	Economy	11800.00
0005435462728	5534	Economy	11800.00
0005435767308	5534	Economy	11800.00
0005435767332	5534	Economy	11800.00
0005435462659	5534	Economy	11800.00
0005435722100	5534	Economy	11800.00
0005435767344	5534	Economy	11800.00
0005435767312	5534	Economy	11800.00
0005433527338	5534	Economy	12900.00
0005434265445	5534	Economy	12900.00
0005435767300	5534	Economy	11800.00
0005435767295	5534	Economy	11800.00
0005435767350	5534	Economy	11800.00
0005435767340	5534	Economy	11800.00
0005435462926	5534	Economy	11800.00
0005435725688	5534	Economy	11800.00
0005435767335	5534	Economy	11800.00
0005434265428	5534	Economy	11800.00
0005435767320	5534	Economy	11800.00
0005435462724	5534	Economy	11800.00
0005435462723	5534	Economy	11800.00
0005435767338	5534	Economy	11800.00
0005435767304	5534	Economy	11800.00
0005435617173	5534	Economy	11800.00
0005435767298	5534	Economy	11800.00
0005435725690	5534	Economy	11800.00
0005432140599	5534	Economy	11800.00
0005435767315	5534	Economy	11800.00
0005434265384	5534	Economy	11800.00
0005435723080	5534	Economy	11800.00
0005435767293	5534	Economy	11800.00
0005435462700	5534	Economy	11800.00
0005435462862	5534	Economy	11800.00
0005435767301	5534	Economy	11800.00
0005435767351	5534	Economy	11800.00
0005435767294	5534	Economy	11800.00
0005435462820	5534	Economy	11800.00
0005432140600	5534	Economy	11800.00
0005435767317	5534	Economy	11800.00
0005435725687	5534	Economy	11800.00
0005435767356	5534	Economy	11800.00
0005435735222	5534	Economy	11800.00
0005433527337	5534	Economy	11800.00
0005435720845	5534	Economy	11800.00
0005434831192	5534	Economy	11800.00
0005435767299	5534	Economy	11800.00
0005435767319	5534	Economy	11800.00
0005435767326	5534	Economy	11800.00
0005434265438	5534	Economy	11800.00
0005434265307	5534	Economy	11800.00
0005435767343	5534	Economy	11800.00
0005435767355	5534	Economy	11800.00
0005435767329	5534	Economy	11800.00
0005432140595	5534	Economy	11800.00
0005435767321	5534	Economy	11800.00
0005434265368	5534	Economy	11800.00
0005435767358	5534	Economy	11800.00
0005435767341	5534	Economy	11800.00
0005434265397	5534	Economy	11800.00
0005434265320	5534	Economy	11800.00
0005435767333	5534	Economy	11800.00
0005435462699	5534	Economy	11800.00
0005435462761	5534	Economy	11800.00
0005435767323	5534	Economy	11800.00
0005434265370	5534	Economy	11800.00
0005434265317	5534	Economy	11800.00
0005435767303	5534	Economy	11800.00
0005435767336	5534	Economy	11800.00
0005435767318	5534	Economy	11800.00
0005435725689	5534	Economy	11800.00
0005435767311	5534	Economy	11800.00
0005435722099	5534	Economy	11800.00
0005435767346	5534	Economy	11800.00
0005435723079	5534	Economy	11800.00
0005435463131	13457	Business	35300.00
0005434265624	13457	Business	35300.00
0005435766465	13457	Business	35300.00
0005435766686	13457	Business	35300.00
0005435463116	13457	Business	35300.00
0005435766654	13457	Business	35300.00
0005432535923	13457	Business	35300.00
0005434265611	13457	Business	35300.00
0005434265614	13457	Business	35300.00
0005435766807	13457	Business	35300.00
0005435723069	13457	Business	35300.00
0005435766635	13457	Business	35300.00
0005435766634	13457	Business	35300.00
0005434265621	13457	Business	35300.00
0005435766508	13457	Business	35300.00
0005435766653	13457	Business	35300.00
0005435766832	13457	Business	35300.00
0005434265625	13457	Business	35300.00
0005434831238	13457	Business	35300.00
0005435766815	13457	Business	35300.00
0005435463119	13457	Business	35300.00
0005435766639	13457	Business	35300.00
0005434831241	13457	Business	35300.00
0005435463125	13457	Business	35300.00
0005435463133	13457	Economy	12900.00
0005435766670	13457	Economy	12900.00
0005435735177	13457	Economy	12900.00
0005435463145	13457	Economy	11800.00
0005435725665	13457	Economy	11800.00
0005435766707	13457	Economy	11800.00
0005435463137	13457	Economy	11800.00
0005432194588	13457	Economy	11800.00
0005434265602	13457	Economy	11800.00
0005435766700	13457	Economy	11800.00
0005435766502	13457	Economy	11800.00
0005434265603	13457	Economy	11800.00
0005435723070	13457	Economy	11800.00
0005435766566	13457	Economy	11800.00
0005435766783	13457	Economy	11800.00
0005434265619	13457	Economy	11800.00
0005435766808	13457	Economy	11800.00
0005434265605	13457	Economy	11800.00
0005434265620	13457	Economy	11800.00
0005435463134	13457	Economy	11800.00
0005435463117	13457	Economy	11800.00
0005435766698	13457	Economy	11800.00
0005435766656	13457	Economy	11800.00
0005435766726	13457	Economy	11800.00
0005435463113	13457	Economy	11800.00
0005435766760	13457	Economy	11800.00
0005434831240	13457	Economy	11800.00
0005435463143	13457	Economy	11800.00
0005435463118	13457	Economy	11800.00
0005434265618	13457	Economy	11800.00
0005432194589	13457	Economy	11800.00
0005434265616	13457	Economy	11800.00
0005435766801	13457	Economy	11800.00
0005432535922	13457	Economy	11800.00
0005435766503	13457	Economy	11800.00
0005435766821	13457	Economy	11800.00
0005435463146	13457	Economy	11800.00
0005435722077	13457	Economy	11800.00
0005435463130	13457	Economy	11800.00
0005435463138	13457	Economy	11800.00
0005435766625	13457	Economy	11800.00
0005432194586	13457	Economy	11800.00
0005434265626	13457	Economy	11800.00
0005435766836	13457	Economy	11800.00
0005432535925	13457	Economy	11800.00
0005435463140	13457	Economy	11800.00
0005435766683	13457	Economy	11800.00
0005435463127	13457	Economy	11800.00
0005435766655	13457	Economy	11800.00
0005435463141	13457	Economy	11800.00
0005435617178	13457	Economy	11800.00
0005435766722	13457	Economy	11800.00
0005435766466	13457	Economy	11800.00
0005435463147	13457	Economy	11800.00
0005435463136	13457	Economy	11800.00
0005435766618	13457	Economy	11800.00
0005435722076	13457	Economy	11800.00
0005435766925	13457	Economy	11800.00
0005435463135	13457	Economy	11800.00
0005435766860	13457	Economy	11800.00
0005435766915	13457	Economy	11800.00
0005435735195	13457	Economy	11800.00
0005435766723	13457	Economy	11800.00
0005435463128	13457	Economy	11800.00
0005435766745	13457	Economy	11800.00
0005432535921	13457	Economy	11800.00
0005434831239	13457	Economy	11800.00
0005434265606	13457	Economy	11800.00
0005435766835	13457	Economy	11800.00
0005435735175	13457	Economy	11800.00
0005435766718	13457	Economy	11800.00
0005435766585	13457	Economy	11800.00
0005435735178	13457	Economy	11800.00
0005435766467	13457	Economy	11800.00
0005435766831	13457	Economy	11800.00
0005435766751	13457	Economy	11800.00
0005435766800	13457	Economy	11800.00
0005435766746	13457	Economy	11800.00
0005435463132	13457	Economy	11800.00
0005434265610	13457	Economy	11800.00
0005435463115	13457	Economy	11800.00
0005435463129	13457	Economy	11800.00
0005435766806	13457	Economy	12900.00
0005432194587	13457	Economy	11800.00
0005435766803	13457	Economy	12900.00
0005435766752	13457	Economy	11800.00
0005435735174	13457	Economy	11800.00
0005435617179	13457	Economy	12900.00
0005435766897	13457	Economy	11800.00
0005434265601	13457	Economy	11800.00
0005435766708	13457	Economy	11800.00
0005434265604	13457	Economy	11800.00
0005435463121	13457	Economy	11800.00
0005435463124	13457	Economy	11800.00
0005434265613	13457	Economy	11800.00
0005435463123	13457	Economy	11800.00
0005435463114	13457	Economy	11800.00
0005435766814	13457	Economy	11800.00
0005435766805	13457	Economy	11800.00
0005435766784	13457	Economy	11800.00
0005435463142	13457	Economy	11800.00
0005435766759	13457	Economy	11800.00
0005434265608	13457	Economy	11800.00
0005434265622	13457	Economy	11800.00
0005435463122	13457	Economy	11800.00
0005435735155	13457	Economy	11800.00
0005435766804	13457	Economy	11800.00
0005434265615	13457	Economy	11800.00
0005435766633	13457	Economy	11800.00
0005435463111	13457	Economy	11800.00
0005435735173	13457	Economy	11800.00
0005435766727	13457	Economy	11800.00
0005435766916	13457	Economy	11800.00
0005435766868	13457	Economy	11800.00
0005435723068	13457	Economy	11800.00
0005434831237	13457	Economy	11800.00
0005435766896	13457	Economy	11800.00
0005435766599	13457	Economy	11800.00
0005435617177	13457	Economy	11800.00
0005434265612	13457	Economy	11800.00
0005435463139	13457	Economy	11800.00
0005435463144	13457	Economy	11800.00
0005435766782	13457	Economy	11800.00
0005434265623	13457	Economy	11800.00
0005435043297	13457	Economy	11800.00
0005435766619	13457	Economy	11800.00
0005435766725	13457	Economy	11800.00
0005435463112	13457	Economy	11800.00
0005435766721	13457	Economy	11800.00
0005435766501	13457	Economy	11800.00
0005434265607	13457	Economy	11800.00
0005432535924	13457	Economy	11800.00
0005435766912	13457	Economy	11800.00
0005435766676	13457	Economy	11800.00
0005434265609	13457	Economy	11800.00
0005435617176	13457	Economy	11800.00
0005435463109	13457	Economy	11800.00
0005435725636	13457	Economy	11800.00
0005435766574	13457	Economy	11800.00
0005435766666	13457	Economy	11800.00
0005434265617	13457	Economy	11800.00
0005434831236	13457	Economy	11800.00
0005435463110	13457	Economy	11800.00
0005435463126	13457	Economy	11800.00
0005435463120	13457	Economy	11800.00
0005434513626	18648	Economy	3300.00
0005434513627	18648	Economy	3300.00
0005434604909	18648	Economy	3300.00
0005434515015	18648	Economy	3300.00
0005434515013	18648	Economy	3300.00
0005434604927	18648	Economy	3300.00
0005434515014	18648	Economy	3300.00
0005434604911	18648	Economy	3300.00
0005434604910	18648	Economy	3300.00
0005434604912	18648	Economy	3300.00
0005434602945	19196	Economy	3300.00
0005434514995	19196	Economy	3300.00
0005434602947	19196	Economy	3300.00
0005434602944	19196	Economy	3300.00
0005434602940	19196	Economy	3300.00
0005434602943	19196	Economy	3300.00
0005434514993	19196	Economy	3300.00
0005434602946	19196	Economy	3300.00
0005434602941	19196	Economy	3300.00
0005434602942	19196	Economy	3300.00
0005432632763	25097	Business	88300.00
0005432632780	25097	Business	88300.00
0005435846319	25097	Business	88300.00
0005435844380	25097	Business	88300.00
0005435844390	25097	Business	88300.00
0005432632775	25097	Business	88300.00
0005432632784	25097	Economy	29400.00
0005435844384	25097	Economy	29400.00
0005432632777	25097	Economy	29400.00
0005432632762	25097	Economy	29400.00
0005432649466	25097	Economy	29400.00
0005432632795	25097	Economy	29400.00
0005432649492	25097	Economy	32400.00
0005432632790	25097	Economy	32400.00
0005432632772	25097	Economy	29400.00
0005435844386	25097	Economy	29400.00
0005435846315	25097	Economy	29400.00
0005435844383	25097	Economy	29400.00
0005435844391	25097	Economy	29400.00
0005432649455	25097	Economy	29400.00
0005435844387	25097	Economy	29400.00
0005435846320	25097	Economy	29400.00
0005432649465	25097	Economy	29400.00
0005435846316	25097	Economy	29400.00
0005435846321	25097	Economy	29400.00
0005435846318	25097	Economy	29400.00
0005432649438	25097	Economy	29400.00
0005432632779	25097	Economy	29400.00
0005435844389	25097	Economy	29400.00
0005432632799	25097	Economy	29400.00
0005432632770	25097	Economy	29400.00
0005432649444	25097	Economy	29400.00
0005435844382	25097	Economy	29400.00
0005432632764	25097	Economy	29400.00
0005432632786	25097	Economy	29400.00
0005432632803	25097	Economy	29400.00
0005432632792	25097	Economy	29400.00
0005432632759	25097	Economy	29400.00
0005432632773	25097	Economy	29400.00
0005432632783	25097	Economy	29400.00
0005435844379	25097	Economy	29400.00
0005432632787	25097	Economy	29400.00
0005432649467	25097	Economy	29400.00
0005432649462	25097	Economy	29400.00
0005432632794	25097	Economy	29400.00
0005432632776	25097	Economy	29400.00
0005435846314	25097	Economy	29400.00
0005432632798	25097	Economy	29400.00
0005432632758	25097	Economy	29400.00
0005432649470	25097	Economy	29400.00
0005435844385	25097	Economy	29400.00
0005432632804	25097	Economy	29400.00
0005432632761	25097	Economy	29400.00
0005432632781	25097	Economy	29400.00
0005435844381	25097	Economy	29400.00
0005432649439	25097	Economy	29400.00
0005432649456	25097	Economy	29400.00
0005432649468	25097	Economy	29400.00
0005432632778	25097	Economy	29400.00
0005432632765	25097	Economy	29400.00
0005435844388	25097	Economy	29400.00
0005435844392	25097	Economy	29400.00
0005432632769	25097	Economy	29400.00
0005432632782	25097	Economy	29400.00
0005435846317	25097	Economy	29400.00
0005433009113	1875	Business	48700.00
0005433285577	1875	Business	48700.00
0005433285567	1875	Business	48700.00
0005433009094	1875	Business	48700.00
0005433285619	1875	Business	48700.00
0005433009040	1875	Business	48700.00
0005433009078	1875	Business	48700.00
0005433285645	1875	Business	48700.00
0005433008995	1875	Business	48700.00
0005433285585	1875	Business	48700.00
0005433009112	1875	Economy	16200.00
0005433009055	1875	Economy	16200.00
0005433285437	1875	Economy	16200.00
0005433285635	1875	Economy	16200.00
0005433285735	1875	Economy	16200.00
0005433008956	1875	Economy	16200.00
0005433009164	1875	Economy	16200.00
0005433009002	1875	Economy	16200.00
0005433009114	1875	Economy	16200.00
0005433285500	1875	Economy	17900.00
0005433285654	1875	Economy	17900.00
0005433810620	1875	Economy	17900.00
0005433285616	1875	Economy	17900.00
0005433810622	1875	Economy	16200.00
0005433285581	1875	Economy	16200.00
0005433285566	1875	Economy	16200.00
0005433009133	1875	Economy	16200.00
0005433285676	1875	Economy	16200.00
0005433285644	1875	Economy	16200.00
0005433009232	1875	Economy	16200.00
0005433009150	1875	Economy	16200.00
0005433009095	1875	Economy	16200.00
0005433009056	1875	Economy	16200.00
0005432295929	1875	Economy	16200.00
0005433009001	1875	Economy	16200.00
0005433285536	1875	Economy	16200.00
0005433285578	1875	Economy	16200.00
0005433810621	1875	Economy	16200.00
0005433008950	1875	Economy	16200.00
0005433009254	1875	Economy	16200.00
0005433009104	1875	Economy	16200.00
0005433285704	1875	Economy	16200.00
0005433285548	1875	Economy	16200.00
0005433810619	1875	Economy	16200.00
0005433008994	1875	Economy	16200.00
0005433285568	1875	Economy	16200.00
0005433285736	1875	Economy	16200.00
0005433285613	1875	Economy	16200.00
0005433008916	1875	Economy	16200.00
0005433009037	1875	Economy	16200.00
0005433009108	1875	Economy	16200.00
0005433285636	1875	Economy	16200.00
0005433285622	1875	Economy	16200.00
0005433009147	1875	Economy	16200.00
0005433009005	1875	Economy	16200.00
0005433008951	1875	Economy	16200.00
0005433285572	1875	Economy	16200.00
0005433008949	1875	Economy	16200.00
0005433009231	1875	Economy	16200.00
0005433285643	1875	Economy	16200.00
0005433009109	1875	Economy	16200.00
0005433810618	1875	Economy	16200.00
0005433008996	1875	Economy	16200.00
0005433009136	1875	Economy	16200.00
0005433009032	1875	Economy	16200.00
0005433008988	1875	Economy	16200.00
0005433285624	1875	Economy	16200.00
0005433009119	1875	Economy	16200.00
0005433285579	1875	Economy	16200.00
0005433285560	1875	Economy	16200.00
0005433008933	1875	Economy	16200.00
0005433285667	1875	Economy	16200.00
0005432295928	1875	Economy	16200.00
0005433285623	1875	Economy	16200.00
0005433008815	1875	Economy	16200.00
0005433009064	1875	Economy	16200.00
0005433009194	1875	Economy	16200.00
0005433810616	1875	Economy	16200.00
0005433285720	1875	Economy	16200.00
0005433285535	1875	Economy	16200.00
0005433009107	1875	Economy	16200.00
0005433285534	1875	Economy	16200.00
0005433009151	1875	Economy	16200.00
0005433009230	1875	Economy	16200.00
0005433009144	1875	Economy	16200.00
0005433009163	1875	Economy	16200.00
0005433810617	1875	Economy	16200.00
0005433009115	1875	Economy	16200.00
0005433009424	22616	Business	48700.00
0005433009438	22616	Business	48700.00
0005433285864	22616	Business	48700.00
0005433285845	22616	Business	48700.00
0005433009409	22616	Business	48700.00
0005433285861	22616	Business	48700.00
0005433285843	22616	Business	48700.00
0005433285860	22616	Business	48700.00
0005433285859	22616	Economy	16200.00
0005433810577	22616	Economy	16200.00
0005433810575	22616	Economy	16200.00
0005433009425	22616	Economy	16200.00
0005433285846	22616	Economy	16200.00
0005433009442	22616	Economy	16200.00
0005433285857	22616	Economy	16200.00
0005433009408	22616	Economy	16200.00
0005433009412	22616	Economy	16200.00
0005433009416	22616	Economy	17900.00
0005433009400	22616	Economy	17900.00
0005433009429	22616	Economy	17900.00
0005433009437	22616	Economy	17900.00
0005433009407	22616	Economy	16200.00
0005433009404	22616	Economy	16200.00
0005433009430	22616	Economy	16200.00
0005433285856	22616	Economy	16200.00
0005433009420	22616	Economy	16200.00
0005433285863	22616	Economy	16200.00
0005433009421	22616	Economy	16200.00
0005433009423	22616	Economy	16200.00
0005433009435	22616	Economy	16200.00
0005433285855	22616	Economy	16200.00
0005433009428	22616	Economy	16200.00
0005433810566	22616	Economy	16200.00
0005433285854	22616	Economy	16200.00
0005433810576	22616	Economy	16200.00
0005433285850	22616	Economy	16200.00
0005433009406	22616	Economy	16200.00
0005433009414	22616	Economy	16200.00
0005433285842	22616	Economy	16200.00
0005433009441	22616	Economy	16200.00
0005433009436	22616	Economy	16200.00
0005433285852	22616	Economy	16200.00
0005433009418	22616	Economy	16200.00
0005433009444	22616	Economy	16200.00
0005433009401	22616	Economy	16200.00
0005433285847	22616	Economy	16200.00
0005433285838	22616	Economy	16200.00
0005433285867	22616	Economy	16200.00
0005433009399	22616	Economy	16200.00
0005433009411	22616	Economy	16200.00
0005433285839	22616	Economy	16200.00
0005433009434	22616	Economy	16200.00
0005433009440	22616	Economy	16200.00
0005433009405	22616	Economy	16200.00
0005433285866	22616	Economy	16200.00
0005433009419	22616	Economy	16200.00
0005433009439	22616	Economy	16200.00
0005433009413	22616	Economy	16200.00
0005433009433	22616	Economy	16200.00
0005433009432	22616	Economy	16200.00
0005433285844	22616	Economy	16200.00
0005433285836	22616	Economy	16200.00
0005433009426	22616	Economy	16200.00
0005433009417	22616	Economy	16200.00
0005433285837	22616	Economy	16200.00
0005433285841	22616	Economy	16200.00
0005433009427	22616	Economy	16200.00
0005433285840	22616	Economy	16200.00
0005433009445	22616	Economy	16200.00
0005433009431	22616	Economy	16200.00
0005433285865	22616	Economy	16200.00
0005433009422	22616	Economy	16200.00
0005433009443	22616	Economy	16200.00
0005433009415	22616	Economy	16200.00
0005433285848	22616	Economy	16200.00
0005433285851	22616	Economy	16200.00
0005433009403	22616	Economy	16200.00
0005433009410	22616	Economy	16200.00
0005433009402	22616	Economy	16200.00
0005433285858	22616	Economy	16200.00
0005433285862	22616	Economy	16200.00
0005433285853	22616	Economy	16200.00
0005433285849	22616	Economy	16200.00
0005434152799	25344	Business	83800.00
0005432756894	25344	Business	83800.00
0005432756900	25344	Business	83800.00
0005432755129	25344	Business	83800.00
0005432755122	25344	Economy	27900.00
0005434152782	25344	Economy	27900.00
0005434153546	25344	Economy	27900.00
0005434152797	25344	Economy	30700.00
0005432756899	25344	Economy	27900.00
0005432756902	25344	Economy	27900.00
0005434152791	25344	Economy	27900.00
0005432755121	25344	Economy	27900.00
0005432755125	25344	Economy	27900.00
0005432755132	25344	Economy	27900.00
0005432756901	25344	Economy	27900.00
0005434152784	25344	Economy	27900.00
0005432756897	25344	Economy	27900.00
0005432755124	25344	Economy	27900.00
0005432755128	25344	Economy	27900.00
0005432755123	25344	Economy	27900.00
0005432756896	25344	Economy	27900.00
0005434153539	25344	Economy	27900.00
0005432755127	25344	Economy	27900.00
0005432756898	25344	Economy	27900.00
0005434152798	25344	Economy	27900.00
0005432755134	25344	Economy	27900.00
0005432755131	25344	Economy	27900.00
0005432756907	25344	Economy	27900.00
0005432756895	25344	Economy	27900.00
0005434153536	25344	Economy	27900.00
0005432756905	25344	Economy	27900.00
0005432755135	25344	Economy	27900.00
0005434152792	25344	Economy	27900.00
0005432755133	25344	Economy	27900.00
0005434152800	25344	Economy	27900.00
0005432755130	25344	Economy	27900.00
0005432756904	25344	Economy	27900.00
0005432756906	25344	Economy	27900.00
0005432755126	25344	Economy	27900.00
0005432756903	25344	Economy	27900.00
0005433847802	5567	Business	99800.00
0005435282786	5567	Business	99800.00
0005433847795	5567	Business	99800.00
0005433847766	5567	Business	99800.00
0005433847775	5567	Business	99800.00
0005433847811	5567	Business	99800.00
0005433847773	5567	Business	99800.00
0005433847781	5567	Business	99800.00
0005433847803	5567	Business	99800.00
0005432081628	5567	Business	99800.00
0005433847764	5567	Business	99800.00
0005433847804	5567	Business	99800.00
0005433847787	5567	Business	99800.00
0005433847778	5567	Business	99800.00
0005433847763	5567	Business	99800.00
0005433847771	5567	Business	99800.00
0005433847800	5567	Business	99800.00
0005433847812	5567	Business	99800.00
0005433847805	5567	Economy	33300.00
0005433847767	5567	Economy	33300.00
0005433847783	5567	Economy	33300.00
0005435282777	5567	Economy	33300.00
0005435282749	5567	Economy	33300.00
0005433847801	5567	Economy	33300.00
0005432081627	5567	Economy	33300.00
0005435282665	5567	Economy	33300.00
0005433815472	5567	Economy	36600.00
0005433847757	5567	Economy	36600.00
0005433847760	5567	Economy	36600.00
0005433847758	5567	Economy	36600.00
0005433847762	5567	Economy	33300.00
0005435282706	5567	Economy	33300.00
0005433847794	5567	Economy	33300.00
0005432081630	5567	Economy	33300.00
0005433847785	5567	Economy	33300.00
0005433847779	5567	Economy	33300.00
0005433847768	5567	Economy	33300.00
0005435282758	5567	Economy	33300.00
0005435282664	5567	Economy	33300.00
0005435282652	5567	Economy	33300.00
0005433847784	5567	Economy	33300.00
0005433847759	5567	Economy	33300.00
0005433847798	5567	Economy	33300.00
0005432081631	5567	Economy	33300.00
0005433847770	5567	Economy	33300.00
0005435282750	5567	Economy	33300.00
0005433847810	5567	Economy	33300.00
0005435282760	5567	Economy	33300.00
0005432081629	5567	Economy	33300.00
0005433847777	5567	Economy	33300.00
0005433847788	5567	Economy	33300.00
0005433847782	5567	Economy	33300.00
0005433847791	5567	Economy	33300.00
0005435282705	5567	Economy	33300.00
0005432081625	5567	Economy	33300.00
0005433847769	5567	Economy	33300.00
0005433847796	5567	Economy	33300.00
0005435282770	5567	Economy	33300.00
0005433847792	5567	Economy	33300.00
0005435282644	5567	Economy	33300.00
0005433847793	5567	Economy	33300.00
0005433815473	5567	Economy	33300.00
0005433847815	5567	Economy	33300.00
0005435282796	5567	Economy	33300.00
0005433847772	5567	Economy	33300.00
0005435282751	5567	Economy	33300.00
0005433847809	5567	Economy	33300.00
0005435282746	5567	Economy	33300.00
0005433847806	5567	Economy	33300.00
0005435282670	5567	Economy	33300.00
0005433847813	5567	Economy	33300.00
0005433847765	5567	Economy	33300.00
0005433815471	5567	Economy	33300.00
0005435282753	5567	Economy	33300.00
0005433847761	5567	Economy	33300.00
0005435282691	5567	Economy	33300.00
0005433847786	5567	Economy	33300.00
0005433847756	5567	Economy	33300.00
0005435282834	5567	Economy	33300.00
0005435282735	5567	Economy	33300.00
0005435282707	5567	Economy	33300.00
0005433847807	5567	Economy	33300.00
0005433847789	5567	Economy	33300.00
0005433847790	5567	Economy	33300.00
0005435282736	5567	Economy	33300.00
0005435282659	5567	Economy	33300.00
0005433847755	5567	Economy	33300.00
0005435282759	5567	Economy	33300.00
0005435282822	5567	Economy	33300.00
0005433847780	5567	Economy	33300.00
0005432081626	5567	Economy	33300.00
0005433847799	5567	Economy	33300.00
0005433847797	5567	Economy	33300.00
0005433847774	5567	Economy	33300.00
0005433847776	5567	Economy	33300.00
0005435282873	5567	Economy	33300.00
0005433847814	5567	Economy	33300.00
0005435282795	5567	Economy	33300.00
0005433847808	5567	Economy	33300.00
0005435282944	13839	Business	99800.00
0005433847447	13839	Business	99800.00
0005435282964	13839	Business	99800.00
0005435282945	13839	Business	99800.00
0005433847165	13839	Business	99800.00
0005435282956	13839	Business	99800.00
0005433847118	13839	Business	99800.00
0005433847361	13839	Business	99800.00
0005434173592	13839	Business	99800.00
0005433847378	13839	Business	99800.00
0005433815431	13839	Business	99800.00
0005433847292	13839	Business	99800.00
0005433847221	13839	Business	99800.00
0005433847192	13839	Business	99800.00
0005435282939	13839	Business	99800.00
0005433847462	13839	Business	99800.00
0005433847365	13839	Business	99800.00
0005434173595	13839	Economy	33300.00
0005435282955	13839	Economy	33300.00
0005433847191	13839	Economy	33300.00
0005435282940	13839	Economy	33300.00
0005433847461	13839	Economy	33300.00
0005434173593	13839	Economy	33300.00
0005434173594	13839	Economy	33300.00
0005433815428	13839	Economy	33300.00
0005433847452	13839	Economy	33300.00
0005435282947	13839	Economy	36600.00
0005433847366	13839	Economy	36600.00
0005433847105	13839	Economy	36600.00
0005433847374	13839	Economy	33300.00
0005433847090	13839	Economy	33300.00
0005433847426	13839	Economy	33300.00
0005433847478	13839	Economy	33300.00
0005435282951	13839	Economy	33300.00
0005435282960	13839	Economy	33300.00
0005433847362	13839	Economy	33300.00
0005433847119	13839	Economy	33300.00
0005432003758	13839	Economy	33300.00
0005433847451	13839	Economy	33300.00
0005432003757	13839	Economy	33300.00
0005433847377	13839	Economy	33300.00
0005433847074	13839	Economy	33300.00
0005433847155	13839	Economy	33300.00
0005433847437	13839	Economy	33300.00
0005433847479	13839	Economy	33300.00
0005433847304	13839	Economy	33300.00
0005432003759	13839	Economy	33300.00
0005433847315	13839	Economy	33300.00
0005435282959	13839	Economy	33300.00
0005433815432	13839	Economy	33300.00
0005433847445	13839	Economy	33300.00
0005435282961	13839	Economy	33300.00
0005433847319	13839	Economy	33300.00
0005433847480	13839	Economy	33300.00
0005433847600	13839	Economy	33300.00
0005433847220	13839	Economy	33300.00
0005434173596	13839	Economy	33300.00
0005433847293	13839	Economy	33300.00
0005433847512	13839	Economy	33300.00
0005435282953	13839	Economy	33300.00
0005435282954	13839	Economy	33300.00
0005435282957	13839	Economy	33300.00
0005433847543	13839	Economy	33300.00
0005435282952	13839	Economy	33300.00
0005433847463	13839	Economy	33300.00
0005433847513	13839	Economy	33300.00
0005433847212	13839	Economy	33300.00
0005433847427	13839	Economy	33300.00
0005433815445	13839	Economy	33300.00
0005433847089	13839	Economy	33300.00
0005435282950	13839	Economy	33300.00
0005435282958	13839	Economy	33300.00
0005435282965	13839	Economy	33300.00
0005433847446	13839	Economy	33300.00
0005435282942	13839	Economy	33300.00
0005433847373	13839	Economy	33300.00
0005433847229	13839	Economy	33300.00
0005433847213	13839	Economy	33300.00
0005435282966	13839	Economy	33300.00
0005435282949	13839	Economy	33300.00
0005435282943	13839	Economy	33300.00
0005433847320	13839	Economy	33300.00
0005432003760	13839	Economy	33300.00
0005433847438	13839	Economy	33300.00
0005433847364	13839	Economy	33300.00
0005433847433	13839	Economy	33300.00
0005435282946	13839	Economy	33300.00
0005435282962	13839	Economy	33300.00
0005433847302	13839	Economy	33300.00
0005433847434	13839	Economy	33300.00
0005433847492	13839	Economy	33300.00
0005433847303	13839	Economy	33300.00
0005435282948	13839	Economy	33300.00
0005433847439	13839	Economy	33300.00
0005435282963	13839	Economy	33300.00
0005435282941	13839	Economy	33300.00
0005433847358	13839	Economy	33300.00
0005435332427	7850	Economy	16600.00
0005434620966	7850	Economy	16600.00
0005435332454	7850	Economy	16600.00
0005435332403	7850	Economy	16600.00
0005434620977	7850	Economy	15100.00
0005434620962	7850	Economy	15100.00
0005435332453	7850	Economy	15100.00
0005435332441	7850	Economy	15100.00
0005434620969	7850	Economy	15100.00
0005435332379	7850	Economy	15100.00
0005434620968	7850	Economy	15100.00
0005432112558	7850	Economy	15100.00
0005434620972	7850	Economy	15100.00
0005434620965	7850	Economy	15100.00
0005435332438	7850	Economy	15100.00
0005435332471	7850	Economy	15100.00
0005434620964	7850	Economy	15100.00
0005434620974	7850	Economy	15100.00
0005435332444	7850	Economy	15100.00
0005432112557	7850	Economy	15100.00
0005434620959	7850	Economy	15100.00
0005434620963	7850	Economy	15100.00
0005434620970	7850	Economy	15100.00
0005434620960	7850	Economy	15100.00
0005434620971	7850	Economy	15100.00
0005435332470	7850	Economy	15100.00
0005435332443	7850	Economy	15100.00
0005434620961	7850	Economy	15100.00
0005435332378	7850	Economy	15100.00
0005435332380	7850	Economy	15100.00
0005434620975	7850	Economy	15100.00
0005434620973	7850	Economy	15100.00
0005434620978	7850	Economy	15100.00
0005434620976	7850	Economy	15100.00
0005434620958	7850	Economy	15100.00
0005432112556	7850	Economy	15100.00
0005434620967	7850	Economy	15100.00
0005435332523	32992	Economy	16600.00
0005435332528	32992	Economy	16600.00
0005434620781	32992	Economy	16600.00
0005434620812	32992	Economy	15100.00
0005435332524	32992	Economy	15100.00
0005434620792	32992	Economy	15100.00
0005434620810	32992	Economy	15100.00
0005435332521	32992	Economy	15100.00
0005434620855	32992	Economy	15100.00
0005435332522	32992	Economy	15100.00
0005434620775	32992	Economy	15100.00
0005434620811	32992	Economy	15100.00
0005434620807	32992	Economy	15100.00
0005434620790	32992	Economy	15100.00
0005434620825	32992	Economy	15100.00
0005434620833	32992	Economy	15100.00
0005434620802	32992	Economy	15100.00
0005434620783	32992	Economy	15100.00
0005434620841	32992	Economy	15100.00
0005434620784	32992	Economy	15100.00
0005435332526	32992	Economy	15100.00
0005435332519	32992	Economy	15100.00
0005434620852	32992	Economy	15100.00
0005435332527	32992	Economy	15100.00
0005434620791	32992	Economy	15100.00
0005435332520	32992	Economy	15100.00
0005434620853	32992	Economy	15100.00
0005434620862	32992	Economy	15100.00
0005434620789	32992	Economy	15100.00
0005435332525	32992	Economy	15100.00
0005434620670	32992	Economy	15100.00
0005434620854	32992	Economy	15100.00
0005434620770	32992	Economy	15100.00
0005435785971	4263	Business	38000.00
0005435937404	4263	Business	38000.00
0005435918708	4263	Business	38000.00
0005434994203	4263	Business	38000.00
0005435785994	4263	Business	38000.00
0005435785991	4263	Business	38000.00
0005435786000	4263	Economy	12700.00
0005435937413	4263	Economy	12700.00
0005435937406	4263	Economy	12700.00
0005434994197	4263	Economy	12700.00
0005435786003	4263	Economy	13900.00
0005435785973	4263	Economy	13900.00
0005435785987	4263	Economy	13900.00
0005435937400	4263	Economy	13900.00
0005435785984	4263	Economy	13900.00
0005435785981	4263	Economy	12700.00
0005435785999	4263	Economy	12700.00
0005435785986	4263	Economy	12700.00
0005435786004	4263	Economy	12700.00
0005435785972	4263	Economy	12700.00
0005435785993	4263	Economy	12700.00
0005435785995	4263	Economy	12700.00
0005432190699	4263	Economy	12700.00
0005435918695	4263	Economy	12700.00
0005435785969	4263	Economy	12700.00
0005435785970	4263	Economy	12700.00
0005435785998	4263	Economy	12700.00
0005435937414	4263	Economy	12700.00
0005435787392	4263	Economy	12700.00
0005435785978	4263	Economy	12700.00
0005435786002	4263	Economy	12700.00
0005435785975	4263	Economy	12700.00
0005432190701	4263	Economy	12700.00
0005435785974	4263	Economy	12700.00
0005434994201	4263	Economy	12700.00
0005434994200	4263	Economy	12700.00
0005435785983	4263	Economy	12700.00
0005432190700	4263	Economy	12700.00
0005435785980	4263	Economy	12700.00
0005435785992	4263	Economy	12700.00
0005435785985	4263	Economy	12700.00
0005434994205	4263	Economy	12700.00
0005435785988	4263	Economy	12700.00
0005435918707	4263	Economy	12700.00
0005435918713	4263	Economy	12700.00
0005434994204	4263	Economy	12700.00
0005435937405	4263	Economy	12700.00
0005434994202	4263	Economy	12700.00
0005434994196	4263	Economy	12700.00
0005434994198	4263	Economy	12700.00
0005435785979	4263	Economy	12700.00
0005435785990	4263	Economy	12700.00
0005432190698	4263	Economy	12700.00
0005435785989	4263	Economy	12700.00
0005435786001	4263	Economy	12700.00
0005435785982	4263	Economy	12700.00
0005435785997	4263	Economy	12700.00
0005435785977	4263	Economy	12700.00
0005435918709	4263	Economy	12700.00
0005434994199	4263	Economy	12700.00
0005435785976	4263	Economy	12700.00
0005435785996	4263	Economy	12700.00
0005434994090	27328	Business	38000.00
0005435785624	27328	Business	38000.00
0005435785614	27328	Business	38000.00
0005434994094	27328	Business	38000.00
0005435785600	27328	Business	38000.00
0005435785596	27328	Business	38000.00
0005435787371	27328	Business	38000.00
0005435787369	27328	Business	38000.00
0005435785634	27328	Business	38000.00
0005434994120	27328	Economy	12700.00
0005435785768	27328	Economy	12700.00
0005435785616	27328	Economy	12700.00
0005435785664	27328	Economy	12700.00
0005435785629	27328	Economy	12700.00
0005435918745	27328	Economy	12700.00
0005435785610	27328	Economy	13900.00
0005435785582	27328	Economy	13900.00
0005435785597	27328	Economy	13900.00
0005435785464	27328	Economy	12700.00
0005434994119	27328	Economy	12700.00
0005435785547	27328	Economy	12700.00
0005435785595	27328	Economy	12700.00
0005435787370	27328	Economy	12700.00
0005435785583	27328	Economy	12700.00
0005435785586	27328	Economy	12700.00
0005435785598	27328	Economy	12700.00
0005435785708	27328	Economy	12700.00
0005435918743	27328	Economy	12700.00
0005435785550	27328	Economy	12700.00
0005435785553	27328	Economy	12700.00
0005435785552	27328	Economy	12700.00
0005434994095	27328	Economy	12700.00
0005435785585	27328	Economy	12700.00
0005435785666	27328	Economy	12700.00
0005435785667	27328	Economy	12700.00
0005435785633	27328	Economy	12700.00
0005435785609	27328	Economy	12700.00
0005435918744	27328	Economy	12700.00
0005435785626	27328	Economy	12700.00
0005434994063	27328	Economy	12700.00
0005432195732	27328	Economy	12700.00
0005435785622	27328	Economy	12700.00
0005435785625	27328	Economy	12700.00
0005435785739	27328	Economy	12700.00
0005432195730	27328	Economy	12700.00
0005435785603	27328	Economy	12700.00
0005435787375	27328	Economy	12700.00
0005435785684	27328	Economy	12700.00
0005435785601	27328	Economy	12700.00
0005435785524	27328	Economy	12700.00
0005435785545	27328	Economy	12700.00
0005435785602	27328	Economy	12700.00
0005435785628	27328	Economy	12700.00
0005435918742	27328	Economy	12700.00
0005435785767	27328	Economy	12700.00
0005435785615	27328	Economy	12700.00
0005435785711	27328	Economy	12700.00
0005435785709	27328	Economy	12700.00
0005432195731	27328	Economy	12700.00
0005432146236	19860	Economy	12800.00
0005432460775	4699	Business	40900.00
0005432568733	4699	Business	40900.00
0005432568755	4699	Business	40900.00
0005432568749	4699	Business	40900.00
0005432460784	4699	Business	40900.00
0005434082308	4699	Business	40900.00
0005432460810	4699	Business	40900.00
0005434082316	4699	Business	40900.00
0005432460791	4699	Business	40900.00
0005432460780	4699	Business	40900.00
0005432568717	4699	Business	40900.00
0005432568767	4699	Business	40900.00
0005433726147	4699	Business	40900.00
0005434082318	4699	Business	40900.00
0005432568729	4699	Business	40900.00
0005432568716	4699	Business	40900.00
0005432460782	4699	Business	40900.00
0005432568760	4699	Business	40900.00
0005432568771	4699	Business	40900.00
0005433452779	4699	Business	40900.00
0005432571392	4699	Economy	15000.00
0005432460802	4699	Business	40900.00
0005432460811	4699	Economy	15000.00
0005432568740	4699	Economy	15000.00
0005432568769	4699	Economy	13600.00
0005432460818	4699	Economy	13600.00
0005432460774	4699	Economy	13600.00
0005434082325	4699	Economy	13600.00
0005432460815	4699	Economy	13600.00
0005432568757	4699	Economy	13600.00
0005432460793	4699	Economy	13600.00
0005432460796	4699	Economy	13600.00
0005432460777	4699	Economy	13600.00
0005432568765	4699	Economy	13600.00
0005432460781	4699	Economy	13600.00
0005432460817	4699	Economy	13600.00
0005432568776	4699	Economy	13600.00
0005432460816	4699	Economy	13600.00
0005432568763	4699	Economy	13600.00
0005432568732	4699	Economy	13600.00
0005432460786	4699	Economy	13600.00
0005432568743	4699	Economy	13600.00
0005432571389	4699	Economy	13600.00
0005432568739	4699	Economy	13600.00
0005432568723	4699	Economy	13600.00
0005434082315	4699	Economy	13600.00
0005432568768	4699	Economy	13600.00
0005432568770	4699	Economy	13600.00
0005434082314	4699	Economy	13600.00
0005432568759	4699	Economy	13600.00
0005432460806	4699	Economy	13600.00
0005432170509	4699	Economy	13600.00
0005432568753	4699	Economy	13600.00
0005432186935	4699	Economy	13600.00
0005434082321	4699	Economy	13600.00
0005432460809	4699	Economy	13600.00
0005432460790	4699	Economy	13600.00
0005432568772	4699	Economy	13600.00
0005432170508	4699	Economy	13600.00
0005432460795	4699	Economy	13600.00
0005432460814	4699	Economy	13600.00
0005432460808	4699	Economy	13600.00
0005432460800	4699	Economy	13600.00
0005433452778	4699	Economy	13600.00
0005432568724	4699	Economy	13600.00
0005432170510	4699	Economy	13600.00
0005432460803	4699	Economy	13600.00
0005432568742	4699	Economy	13600.00
0005432568731	4699	Economy	13600.00
0005432460785	4699	Economy	13600.00
0005432568746	4699	Economy	13600.00
0005433726146	4699	Economy	13600.00
0005434082309	4699	Economy	13600.00
0005432568715	4699	Economy	13600.00
0005432460825	4699	Economy	13600.00
0005432460779	4699	Economy	13600.00
0005432568738	4699	Economy	13600.00
0005432460805	4699	Economy	13600.00
0005434082312	4699	Economy	13600.00
0005433451656	4699	Economy	13600.00
0005432460820	4699	Economy	13600.00
0005432568726	4699	Economy	13600.00
0005432568725	4699	Economy	13600.00
0005432170513	4699	Economy	13600.00
0005434082322	4699	Economy	13600.00
0005432568748	4699	Economy	13600.00
0005432568741	4699	Economy	13600.00
0005432568751	4699	Economy	13600.00
0005432460826	4699	Economy	13600.00
0005432460799	4699	Economy	13600.00
0005432460823	4699	Economy	13600.00
0005432186938	4699	Economy	13600.00
0005432568736	4699	Economy	13600.00
0005433451657	4699	Economy	13600.00
0005432460824	4699	Economy	13600.00
0005432460776	4699	Economy	13600.00
0005433451658	4699	Economy	13600.00
0005432571390	4699	Economy	13600.00
0005432568721	4699	Economy	13600.00
0005432568747	4699	Economy	15000.00
0005432568775	4699	Economy	13600.00
0005434082324	4699	Economy	13600.00
0005434082319	4699	Economy	13600.00
0005432568728	4699	Economy	15000.00
0005432568754	4699	Economy	15000.00
0005432460807	4699	Economy	13600.00
0005432568774	4699	Economy	13600.00
0005432568722	4699	Economy	13600.00
0005432460787	4699	Economy	13600.00
0005432568737	4699	Economy	13600.00
0005434082317	4699	Economy	13600.00
0005434082326	4699	Economy	13600.00
0005432460804	4699	Economy	13600.00
0005432568719	4699	Economy	13600.00
0005434082320	4699	Economy	13600.00
0005432460773	4699	Economy	13600.00
0005433726145	4699	Economy	13600.00
0005434082323	4699	Economy	13600.00
0005432568745	4699	Economy	13600.00
0005434082313	4699	Economy	13600.00
0005432568758	4699	Economy	13600.00
0005432460821	4699	Economy	13600.00
0005432568764	4699	Economy	13600.00
0005432460778	4699	Economy	13600.00
0005434082310	4699	Economy	13600.00
0005432170511	4699	Economy	13600.00
0005432460789	4699	Economy	13600.00
0005432568720	4699	Economy	13600.00
0005432460822	4699	Economy	13600.00
0005432568766	4699	Economy	13600.00
0005432568744	4699	Economy	13600.00
0005432460794	4699	Economy	13600.00
0005432460797	4699	Economy	13600.00
0005432568734	4699	Economy	13600.00
0005432460813	4699	Economy	13600.00
0005432460801	4699	Economy	13600.00
0005432460812	4699	Economy	13600.00
0005432460798	4699	Economy	13600.00
0005432186937	4699	Economy	13600.00
0005432568718	4699	Economy	13600.00
0005432170512	4699	Economy	13600.00
0005432460788	4699	Economy	13600.00
0005432568752	4699	Economy	13600.00
0005432568762	4699	Economy	13600.00
0005432186939	4699	Economy	13600.00
0005432568761	4699	Economy	13600.00
0005432460792	4699	Economy	13600.00
0005432568773	4699	Economy	13600.00
0005432460783	4699	Economy	13600.00
0005434082311	4699	Economy	13600.00
0005432568750	4699	Economy	13600.00
0005432568730	4699	Economy	13600.00
0005432568735	4699	Economy	13600.00
0005432568727	4699	Economy	13600.00
0005432460819	4699	Economy	13600.00
0005432571391	4699	Economy	13600.00
0005432568756	4699	Economy	13600.00
0005432186936	4699	Economy	13600.00
0005432460521	30523	Business	40900.00
0005432460403	30523	Business	40900.00
0005432460464	30523	Business	40900.00
0005432460292	30523	Business	40900.00
0005432568429	30523	Business	40900.00
0005432568268	30523	Business	40900.00
0005432460106	30523	Business	40900.00
0005432567787	30523	Business	40900.00
0005435840376	30523	Business	40900.00
0005432213676	30523	Business	40900.00
0005434082142	30523	Business	40900.00
0005432460502	30523	Business	40900.00
0005432460139	30523	Business	40900.00
0005432568310	30523	Business	40900.00
0005432460432	30523	Business	40900.00
0005432460664	30523	Business	40900.00
0005432460385	30523	Business	40900.00
0005434082063	30523	Business	40900.00
0005434082040	30523	Business	40900.00
0005432567888	30523	Business	40900.00
0005432568134	30523	Business	40900.00
0005432568241	30523	Business	40900.00
0005432568428	30523	Business	40900.00
0005435840388	30523	Business	40900.00
0005435840380	30523	Economy	15000.00
0005432460411	30523	Economy	15000.00
0005432460536	30523	Economy	15000.00
0005434082065	30523	Economy	13600.00
0005432568106	30523	Economy	13600.00
0005432568328	30523	Economy	13600.00
0005432568399	30523	Economy	13600.00
0005432460402	30523	Economy	13600.00
0005435840379	30523	Economy	13600.00
0005434082057	30523	Economy	13600.00
0005432460496	30523	Economy	13600.00
0005432460215	30523	Economy	13600.00
0005434082189	30523	Economy	13600.00
0005434082128	30523	Economy	13600.00
0005432213675	30523	Economy	13600.00
0005432568135	30523	Economy	13600.00
0005432161194	30523	Economy	13600.00
0005432460476	30523	Economy	13600.00
0005434082107	30523	Economy	13600.00
0005432568359	30523	Economy	13600.00
0005435840383	30523	Economy	13600.00
0005432460307	30523	Economy	13600.00
0005432460535	30523	Economy	13600.00
0005432460657	30523	Economy	13600.00
0005432460431	30523	Economy	13600.00
0005432568279	30523	Economy	13600.00
0005434082146	30523	Economy	13600.00
0005432460588	30523	Economy	13600.00
0005434082089	30523	Economy	13600.00
0005432460429	30523	Economy	13600.00
0005432568430	30523	Economy	13600.00
0005435840385	30523	Economy	13600.00
0005434082149	30523	Economy	13600.00
0005432460364	30523	Economy	13600.00
0005432460276	30523	Economy	13600.00
0005432568255	30523	Economy	13600.00
0005432460552	30523	Economy	13600.00
0005432460414	30523	Economy	13600.00
0005432213673	30523	Economy	13600.00
0005432568360	30523	Economy	13600.00
0005432568316	30523	Economy	13600.00
0005432460407	30523	Economy	13600.00
0005432568248	30523	Economy	13600.00
0005432568160	30523	Economy	13600.00
0005434082088	30523	Economy	13600.00
0005432460477	30523	Economy	13600.00
0005432568400	30523	Economy	13600.00
0005435840386	30523	Economy	13600.00
0005432460371	30523	Economy	13600.00
0005432460363	30523	Economy	13600.00
0005432460522	30523	Economy	13600.00
0005432568157	30523	Economy	13600.00
0005432568224	30523	Economy	13600.00
0005432460248	30523	Economy	13600.00
0005432460404	30523	Economy	13600.00
0005434082211	30523	Economy	13600.00
0005432460379	30523	Economy	13600.00
0005434082109	30523	Economy	13600.00
0005434082180	30523	Economy	13600.00
0005432568167	30523	Economy	13600.00
0005432460192	30523	Economy	13600.00
0005432568278	30523	Economy	13600.00
0005432460378	30523	Economy	13600.00
0005432568276	30523	Economy	13600.00
0005435840387	30523	Economy	13600.00
0005432568168	30523	Economy	13600.00
0005433452759	30523	Economy	13600.00
0005432460433	30523	Economy	13600.00
0005432460463	30523	Economy	13600.00
0005432460501	30523	Economy	13600.00
0005432567887	30523	Economy	13600.00
0005432161195	30523	Economy	13600.00
0005432568075	30523	Economy	13600.00
0005432460589	30523	Economy	15000.00
0005432568426	30523	Economy	13600.00
0005432568251	30523	Economy	13600.00
0005432460665	30523	Economy	15000.00
0005433452753	30523	Economy	15000.00
0005434082108	30523	Economy	13600.00
0005432460324	30523	Economy	13600.00
0005432568427	30523	Economy	13600.00
0005432568127	30523	Economy	13600.00
0005432568105	30523	Economy	13600.00
0005432568329	30523	Economy	13600.00
0005432460281	30523	Economy	13600.00
0005432460234	30523	Economy	13600.00
0005434082136	30523	Economy	13600.00
0005432567932	30523	Economy	13600.00
0005432568030	30523	Economy	13600.00
0005432213674	30523	Economy	13600.00
0005432568465	30523	Economy	13600.00
0005434082181	30523	Economy	13600.00
0005432568317	30523	Economy	13600.00
0005432568354	30523	Economy	13600.00
0005432460233	30523	Economy	13600.00
0005434082064	30523	Economy	13600.00
0005435840384	30523	Economy	13600.00
0005432460380	30523	Economy	13600.00
0005432568319	30523	Economy	13600.00
0005435840378	30523	Economy	13600.00
0005432460098	30523	Economy	13600.00
0005432460413	30523	Economy	13600.00
0005432568315	30523	Economy	13600.00
0005435840377	30523	Economy	13600.00
0005432568398	30523	Economy	13600.00
0005434082110	30523	Economy	13600.00
0005432568235	30523	Economy	13600.00
0005432460434	30523	Economy	13600.00
0005432213677	30523	Economy	13600.00
0005434082135	30523	Economy	13600.00
0005432460428	30523	Economy	13600.00
0005435840381	30523	Economy	13600.00
0005432460247	30523	Economy	13600.00
0005433452758	30523	Economy	13600.00
0005434082039	30523	Economy	13600.00
0005432460478	30523	Economy	13600.00
0005432460384	30523	Economy	13600.00
0005432460470	30523	Economy	13600.00
0005432568333	30523	Economy	13600.00
0005434082116	30523	Economy	13600.00
0005432568375	30523	Economy	13600.00
0005432161193	30523	Economy	13600.00
0005435840382	30523	Economy	13600.00
0005432161196	30523	Economy	13600.00
0005432460253	30523	Economy	13600.00
0005432568313	30523	Economy	13600.00
0005434082111	30523	Economy	13600.00
0005434082070	30523	Economy	13600.00
0005432460408	30523	Economy	13600.00
0005432568229	30523	Economy	13600.00
0005432460370	30523	Economy	13600.00
0005432568228	30523	Economy	13600.00
0005432460469	30523	Economy	13600.00
0005432568275	30523	Economy	13600.00
0005432460316	30523	Economy	13600.00
0005435722099	13655	Economy	9900.00
0005435720845	13655	Economy	9900.00
0005435720844	13655	Economy	9900.00
0005435720846	13655	Economy	9900.00
0005435722100	13655	Economy	9900.00
0005435720843	13655	Economy	9900.00
0005435720140	21229	Economy	9900.00
0005435722073	21229	Economy	9900.00
0005432295929	22775	Economy	8800.00
0005432295928	22775	Economy	8800.00
0005433344975	11094	Business	23600.00
0005433344960	11094	Business	23600.00
0005433344980	11094	Business	23600.00
0005433344951	11094	Business	23600.00
0005433344984	11094	Business	23600.00
0005435508435	11094	Business	23600.00
0005433345036	11094	Business	23600.00
0005433345041	11094	Business	23600.00
0005433344956	11094	Business	23600.00
0005433345037	11094	Business	23600.00
0005435097376	11094	Business	23600.00
0005433344990	11094	Business	23600.00
0005433344969	11094	Economy	7900.00
0005433344964	11094	Economy	7900.00
0005433344983	11094	Economy	7900.00
0005433344944	11094	Economy	7900.00
0005433345033	11094	Economy	7900.00
0005433345031	11094	Economy	7900.00
0005435508454	11094	Economy	7900.00
0005433345032	11094	Economy	7900.00
0005435380352	11094	Economy	7900.00
0005433344954	11094	Economy	7900.00
0005433345014	11094	Economy	7900.00
0005433345009	11094	Economy	7900.00
0005433345001	11094	Economy	7900.00
0005433345024	11094	Economy	7900.00
0005433345017	11094	Economy	7900.00
0005435097384	11094	Economy	7900.00
0005435508455	11094	Economy	7900.00
0005435097379	11094	Economy	7900.00
0005435097377	11094	Economy	7900.00
0005435097380	11094	Economy	7900.00
0005433344976	11094	Economy	7900.00
0005433345035	11094	Economy	7900.00
0005433345043	11094	Economy	7900.00
0005433345008	11094	Economy	7900.00
0005433345027	11094	Economy	7900.00
0005433345006	11094	Economy	7900.00
0005433345023	11094	Economy	7900.00
0005433344974	11094	Economy	7900.00
0005433344966	11094	Economy	7900.00
0005433344997	11094	Economy	7900.00
0005435508476	11094	Economy	7900.00
0005433344947	11094	Economy	7900.00
0005433344943	11094	Economy	7900.00
0005433344942	11094	Economy	7900.00
0005433345016	11094	Economy	7900.00
0005433345025	11094	Economy	7900.00
0005433344945	11094	Economy	7900.00
0005433344985	11094	Economy	7900.00
0005433345029	11094	Economy	7900.00
0005433345003	11094	Economy	7900.00
0005435097383	11094	Economy	8600.00
0005433344950	11094	Economy	8600.00
0005435380330	11094	Economy	8600.00
0005435097382	11094	Economy	8600.00
0005435097378	11094	Economy	8600.00
0005433345034	11094	Economy	8600.00
0005433344953	11094	Economy	7900.00
0005435380331	11094	Economy	7900.00
0005435508458	11094	Economy	7900.00
0005433345005	11094	Economy	7900.00
0005433345020	11094	Economy	7900.00
0005433345028	11094	Economy	7900.00
0005433345040	11094	Economy	7900.00
0005433344994	11094	Economy	7900.00
0005433345013	11094	Economy	7900.00
0005433344991	11094	Economy	7900.00
0005433344946	11094	Economy	7900.00
0005433344949	11094	Economy	7900.00
0005433344982	11094	Economy	7900.00
0005433344979	11094	Economy	7900.00
0005433344986	11094	Economy	7900.00
0005433345012	11094	Economy	7900.00
0005433345018	11094	Economy	7900.00
0005433344993	11094	Economy	7900.00
0005435380340	11094	Economy	7900.00
0005433344967	11094	Economy	7900.00
0005435380335	11094	Economy	7900.00
0005435508473	11094	Economy	7900.00
0005433344977	11094	Economy	7900.00
0005433345022	11094	Economy	7900.00
0005433344957	11094	Economy	7900.00
0005433344999	11094	Economy	7900.00
0005433344958	11094	Economy	7900.00
0005433344998	11094	Economy	7900.00
0005435097375	11094	Economy	7900.00
0005433345007	11094	Economy	7900.00
0005433344978	11094	Economy	7900.00
0005433344971	11094	Economy	7900.00
0005433344996	11094	Economy	7900.00
0005433345010	11094	Economy	7900.00
0005435508433	11094	Economy	7900.00
0005433344995	11094	Economy	7900.00
0005433344988	11094	Economy	7900.00
0005433344981	11094	Economy	7900.00
0005433344970	11094	Economy	7900.00
0005433345042	11094	Economy	7900.00
0005435508453	11094	Economy	7900.00
0005435380337	11094	Economy	7900.00
0005433345000	11094	Economy	7900.00
0005433344965	11094	Economy	7900.00
0005433344948	11094	Economy	7900.00
0005435097385	11094	Economy	7900.00
0005433344987	11094	Economy	7900.00
0005433345030	11094	Economy	7900.00
0005433344973	11094	Economy	7900.00
0005433344992	11094	Economy	7900.00
0005433344959	11094	Economy	7900.00
0005435508457	11094	Economy	7900.00
0005435097374	11094	Economy	7900.00
0005433345026	11094	Economy	7900.00
0005433345004	11094	Economy	7900.00
0005433345039	11094	Economy	7900.00
0005433345019	11094	Economy	7900.00
0005433344963	11094	Economy	7900.00
0005433344968	11094	Economy	7900.00
0005433344972	11094	Economy	7900.00
0005433344961	11094	Economy	7900.00
0005433345021	11094	Economy	7900.00
0005435380336	11094	Economy	7900.00
0005433345038	11094	Economy	7900.00
0005435097381	11094	Economy	7900.00
0005433345002	11094	Economy	7900.00
0005433345011	11094	Economy	7900.00
0005433344955	11094	Economy	7900.00
0005433345015	11094	Economy	7900.00
0005433344962	11094	Economy	7900.00
0005433344989	11094	Economy	7900.00
0005433344952	11094	Economy	7900.00
0005433343850	17124	Business	23600.00
0005433344014	17124	Business	23600.00
0005433344289	17124	Business	23600.00
0005433344171	17124	Business	23600.00
0005433343918	17124	Business	23600.00
0005433343931	17124	Business	23600.00
0005433344074	17124	Business	23600.00
0005433344160	17124	Business	23600.00
0005433344182	17124	Business	23600.00
0005433344008	17124	Business	23600.00
0005433343716	17124	Business	23600.00
0005433343920	17124	Economy	7900.00
0005432293254	17124	Economy	7900.00
0005433343988	17124	Economy	7900.00
0005435097344	17124	Economy	7900.00
0005433344124	17124	Economy	7900.00
0005433343460	17124	Economy	7900.00
0005433343459	17124	Economy	7900.00
0005435097304	17124	Economy	7900.00
0005432293253	17124	Economy	7900.00
0005433343983	17124	Economy	7900.00
0005435097295	17124	Economy	7900.00
0005433344290	17124	Economy	7900.00
0005433344506	17124	Economy	7900.00
0005433343810	17124	Economy	7900.00
0005435097288	17124	Economy	7900.00
0005433344156	17124	Economy	7900.00
0005433344010	17124	Economy	7900.00
0005433343990	17124	Economy	7900.00
0005433343591	17124	Economy	7900.00
0005433344114	17124	Economy	7900.00
0005433343819	17124	Economy	7900.00
0005433343832	17124	Economy	7900.00
0005433343935	17124	Economy	7900.00
0005435097315	17124	Economy	7900.00
0005433343900	17124	Economy	7900.00
0005433344131	17124	Economy	7900.00
0005433344099	17124	Economy	7900.00
0005435097278	17124	Economy	7900.00
0005435380388	17124	Economy	7900.00
0005433344271	17124	Economy	7900.00
0005433343854	17124	Economy	7900.00
0005433343999	17124	Economy	7900.00
0005433344035	17124	Economy	7900.00
0005433344161	17124	Economy	7900.00
0005433344272	17124	Economy	7900.00
0005433343919	17124	Economy	7900.00
0005433344270	17124	Economy	7900.00
0005433344045	17124	Economy	7900.00
0005433344284	17124	Economy	8600.00
0005435097257	17124	Economy	7900.00
0005433343869	17124	Economy	8600.00
0005433344038	17124	Economy	8600.00
0005435097287	17124	Economy	8600.00
0005433343893	17124	Economy	8600.00
0005433343833	17124	Economy	7900.00
0005433343867	17124	Economy	7900.00
0005433344505	17124	Economy	7900.00
0005435097279	17124	Economy	7900.00
0005433343639	17124	Economy	7900.00
0005435097285	17124	Economy	7900.00
0005433343971	17124	Economy	7900.00
0005433343853	17124	Economy	7900.00
0005433344009	17124	Economy	7900.00
0005433344090	17124	Economy	7900.00
0005433344158	17124	Economy	7900.00
0005435097343	17124	Economy	7900.00
0005433343619	17124	Economy	7900.00
0005433344151	17124	Economy	7900.00
0005433344157	17124	Economy	7900.00
0005433343871	17124	Economy	7900.00
0005433343633	17124	Economy	7900.00
0005433343645	17124	Economy	7900.00
0005433343646	17124	Economy	7900.00
0005433344058	17124	Economy	7900.00
0005433343742	17124	Economy	7900.00
0005433343632	17124	Economy	7900.00
0005433343808	17124	Economy	7900.00
0005433344113	17124	Economy	7900.00
0005435097289	17124	Economy	7900.00
0005433343277	17124	Economy	7900.00
0005433344147	17124	Economy	7900.00
0005433344071	17124	Economy	7900.00
0005435380389	17124	Economy	7900.00
0005433344255	17124	Economy	7900.00
0005433343894	17124	Economy	7900.00
0005433344036	17124	Economy	7900.00
0005433343989	17124	Economy	7900.00
0005433344159	17124	Economy	7900.00
0005433343702	17124	Economy	7900.00
0005433343980	17124	Economy	7900.00
0005433343942	17124	Economy	7900.00
0005435380390	17124	Economy	7900.00
0005432293252	17124	Economy	7900.00
0005435545872	17124	Economy	7900.00
0005433343868	17124	Economy	7900.00
0005435380391	17124	Economy	7900.00
0005435097293	17124	Economy	7900.00
0005435097294	17124	Economy	7900.00
0005433343981	17124	Economy	7900.00
0005433344072	17124	Economy	7900.00
0005433344034	17124	Economy	7900.00
0005435097303	17124	Economy	7900.00
0005433344059	17124	Economy	7900.00
0005433343998	17124	Economy	7900.00
0005433343849	17124	Economy	7900.00
0005433344545	17124	Economy	7900.00
0005433344504	17124	Economy	7900.00
0005433344070	17124	Economy	7900.00
0005433343624	17124	Economy	7900.00
0005433343701	17124	Economy	7900.00
0005435380386	17124	Economy	7900.00
0005433344206	17124	Economy	7900.00
0005433343741	17124	Economy	7900.00
0005435380387	17124	Economy	7900.00
0005433344172	17124	Economy	7900.00
0005433343622	17124	Economy	7900.00
0005433344123	17124	Economy	7900.00
0005433343623	17124	Economy	7900.00
0005433344007	17124	Economy	7900.00
0005433344200	17124	Economy	7900.00
0005433344085	17124	Economy	7900.00
0005433344183	17124	Economy	7900.00
0005433344199	17124	Economy	7900.00
0005433344544	17124	Economy	7900.00
0005433507502	9109	Business	26600.00
0005432919990	9109	Business	26600.00
0005433481312	9109	Business	26600.00
0005433507509	9109	Business	26600.00
0005433507506	9109	Business	26600.00
0005433507505	9109	Business	26600.00
0005433476980	9109	Business	26600.00
0005433481308	9109	Business	26600.00
0005432920030	9109	Business	26600.00
0005433476976	9109	Economy	8900.00
0005433476975	9109	Economy	8900.00
0005433476974	9109	Economy	8900.00
0005433507512	9109	Economy	8900.00
0005434159003	9109	Economy	8900.00
0005433481307	9109	Economy	8900.00
0005433507499	9109	Economy	8900.00
0005432920083	9109	Economy	9800.00
0005433507497	9109	Economy	9800.00
0005434158995	9109	Economy	8900.00
0005433507494	9109	Economy	8900.00
0005432920054	9109	Economy	8900.00
0005434159008	9109	Economy	8900.00
0005433507501	9109	Economy	8900.00
0005434158994	9109	Economy	8900.00
0005433507498	9109	Economy	8900.00
0005433507504	9109	Economy	8900.00
0005433507503	9109	Economy	8900.00
0005433476971	9109	Economy	8900.00
0005432920056	9109	Economy	8900.00
0005432920184	9109	Economy	8900.00
0005432920017	9109	Economy	8900.00
0005433507495	9109	Economy	8900.00
0005433481311	9109	Economy	8900.00
0005432920044	9109	Economy	8900.00
0005433481306	9109	Economy	8900.00
0005432920029	9109	Economy	8900.00
0005433481310	9109	Economy	8900.00
0005433476979	9109	Economy	8900.00
0005434159009	9109	Economy	8900.00
0005433476973	9109	Economy	8900.00
0005432920055	9109	Economy	8900.00
0005433476972	9109	Economy	8900.00
0005433507511	9109	Economy	8900.00
0005433476978	9109	Economy	8900.00
0005433507510	9109	Economy	8900.00
0005434158997	9109	Economy	8900.00
0005433507500	9109	Economy	8900.00
0005433507507	9109	Economy	8900.00
0005434158999	9109	Economy	8900.00
0005433476977	9109	Economy	8900.00
0005433476981	9109	Economy	8900.00
0005433481313	9109	Economy	8900.00
0005433481309	9109	Economy	8900.00
0005433507508	9109	Economy	8900.00
0005433507493	9109	Economy	8900.00
0005433507496	9109	Economy	8900.00
0005432920269	20438	Business	26600.00
0005433507429	20438	Business	26600.00
0005432920256	20438	Business	26600.00
0005432920253	20438	Economy	8900.00
0005433481250	20438	Economy	8900.00
0005432920265	20438	Economy	8900.00
0005433481228	20438	Economy	8900.00
0005432920263	20438	Economy	8900.00
0005433481251	20438	Economy	9800.00
0005433507382	20438	Economy	9800.00
0005432920259	20438	Economy	9800.00
0005433481229	20438	Economy	9800.00
0005433507410	20438	Economy	8900.00
0005432920262	20438	Economy	8900.00
0005433481267	20438	Economy	8900.00
0005432920266	20438	Economy	8900.00
0005433481227	20438	Economy	8900.00
0005432920270	20438	Economy	8900.00
0005433481226	20438	Economy	8900.00
0005433481257	20438	Economy	8900.00
0005432920254	20438	Economy	8900.00
0005433507383	20438	Economy	8900.00
0005432920261	20438	Economy	8900.00
0005433481264	20438	Economy	8900.00
0005433481252	20438	Economy	8900.00
0005433481263	20438	Economy	8900.00
0005433507369	20438	Economy	8900.00
0005433507406	20438	Economy	8900.00
0005432920271	20438	Economy	8900.00
0005432920264	20438	Economy	8900.00
0005433507388	20438	Economy	8900.00
0005433507409	20438	Economy	8900.00
0005433481256	20438	Economy	8900.00
0005433507375	20438	Economy	8900.00
0005433507373	20438	Economy	8900.00
0005432920272	20438	Economy	8900.00
0005432920255	20438	Economy	8900.00
0005432920260	20438	Economy	8900.00
0005432920268	20438	Economy	8900.00
0005433507367	20438	Economy	8900.00
0005433481269	20438	Economy	8900.00
0005433481268	20438	Economy	8900.00
0005432920258	20438	Economy	8900.00
0005433507368	20438	Economy	8900.00
0005432920252	20438	Economy	8900.00
0005432920257	20438	Economy	8900.00
0005433481249	20438	Economy	8900.00
0005433507376	20438	Economy	8900.00
0005433507325	20438	Economy	8900.00
0005432920267	20438	Economy	8900.00
0005432396311	10183	Economy	5800.00
0005432394177	10183	Economy	5800.00
0005432394176	10183	Economy	5800.00
0005432394174	10183	Economy	5800.00
0005432394175	10183	Economy	5800.00
0005432396312	10183	Economy	5800.00
0005432396265	18352	Economy	5800.00
0005432396296	18352	Economy	5800.00
0005432400158	18352	Economy	5800.00
0005432396267	18352	Economy	5800.00
0005432396266	18352	Economy	5800.00
0005435179703	18352	Economy	5800.00
0005435179411	18352	Economy	5800.00
0005432396275	18352	Economy	5800.00
0005432396297	18352	Economy	5800.00
0005435179410	18352	Economy	5800.00
0005435179702	18352	Economy	5800.00
0005435626358	11012	Business	9500.00
0005435126779	11012	Business	9500.00
0005435556718	11012	Business	9500.00
0005435626308	11012	Business	9500.00
0005435626325	11012	Business	9500.00
0005435626366	11012	Business	9500.00
0005435626324	11012	Business	9500.00
0005435626284	11012	Economy	3200.00
0005435126476	11012	Economy	3200.00
0005435626312	11012	Economy	3200.00
0005435554238	11012	Economy	3200.00
0005435626356	11012	Economy	3200.00
0005435126808	11012	Economy	3200.00
0005435626355	11012	Economy	3200.00
0005435626309	11012	Economy	3200.00
0005435126810	11012	Economy	3200.00
0005435126809	11012	Economy	3200.00
0005435126477	11012	Economy	3500.00
0005435626310	11012	Economy	3500.00
0005435626331	11012	Economy	3500.00
0005435556721	11012	Economy	3200.00
0005435126879	11012	Economy	3200.00
0005435126830	11012	Economy	3200.00
0005435554240	11012	Economy	3200.00
0005435626345	11012	Economy	3200.00
0005435556722	11012	Economy	3200.00
0005435626279	11012	Economy	3200.00
0005435126733	11012	Economy	3200.00
0005435126764	11012	Economy	3200.00
0005435126823	11012	Economy	3200.00
0005435126711	11012	Economy	3200.00
0005435626283	11012	Economy	3200.00
0005435626315	11012	Economy	3200.00
0005435126717	11012	Economy	3200.00
0005435626347	11012	Economy	3200.00
0005434411857	11012	Economy	3200.00
0005435126721	11012	Economy	3200.00
0005435126581	11012	Economy	3200.00
0005434411856	11012	Economy	3200.00
0005435556715	11012	Economy	3200.00
0005435126541	11012	Economy	3200.00
0005435126734	11012	Economy	3200.00
0005435126580	11012	Economy	3200.00
0005435126822	11012	Economy	3200.00
0005435126712	11012	Economy	3200.00
0005435126654	11012	Economy	3200.00
0005435126819	11012	Economy	3200.00
0005435626346	11012	Economy	3200.00
0005435126895	11012	Economy	3200.00
0005434411858	11012	Economy	3200.00
0005435126640	11012	Economy	3200.00
0005435126653	11012	Economy	3200.00
0005435626336	11012	Economy	3200.00
0005435126896	11012	Economy	3200.00
0005435126582	11012	Economy	3200.00
0005435626332	11012	Economy	3200.00
0005435126540	11012	Economy	3200.00
0005435126818	11012	Economy	3200.00
0005435126821	11012	Economy	3200.00
0005434928351	11012	Economy	3200.00
0005434411859	11012	Economy	3200.00
0005434928353	11012	Economy	3200.00
0005435626314	11012	Economy	3200.00
0005435126701	11012	Economy	3200.00
0005435626318	11012	Economy	3200.00
0005435126720	11012	Economy	3200.00
0005435554239	11012	Economy	3200.00
0005435554207	11012	Economy	3200.00
0005435126443	11012	Economy	3200.00
0005435126735	11012	Economy	3200.00
0005435554208	11012	Economy	3200.00
0005435126576	11012	Economy	3200.00
0005434928352	11012	Economy	3200.00
0005435556740	14768	Business	9500.00
0005435554272	14768	Business	9500.00
0005435626524	14768	Business	9500.00
0005435626521	14768	Business	9500.00
0005435127141	14768	Business	9500.00
0005435626518	14768	Business	9500.00
0005435556738	14768	Business	9500.00
0005435554274	14768	Business	9500.00
0005435626517	14768	Business	9500.00
0005435556737	14768	Business	9500.00
0005435127134	14768	Business	9500.00
0005435626523	14768	Business	9500.00
0005434928340	14768	Economy	3200.00
0005435626511	14768	Economy	3200.00
0005435127144	14768	Economy	3200.00
0005435626507	14768	Economy	3200.00
0005435127136	14768	Economy	3200.00
0005435127119	14768	Economy	3200.00
0005435626528	14768	Economy	3200.00
0005435127108	14768	Economy	3500.00
0005435127138	14768	Economy	3500.00
0005435127114	14768	Economy	3500.00
0005435127139	14768	Economy	3500.00
0005435127107	14768	Economy	3500.00
0005435127112	14768	Economy	3200.00
0005435127109	14768	Economy	3200.00
0005435626525	14768	Economy	3200.00
0005435626508	14768	Economy	3200.00
0005435626515	14768	Economy	3200.00
0005435127127	14768	Economy	3200.00
0005435127113	14768	Economy	3200.00
0005435626512	14768	Economy	3200.00
0005435127106	14768	Economy	3200.00
0005435127146	14768	Economy	3200.00
0005434411820	14768	Economy	3200.00
0005435127133	14768	Economy	3200.00
0005435127147	14768	Economy	3200.00
0005435127129	14768	Economy	3200.00
0005435626510	14768	Economy	3200.00
0005435127126	14768	Economy	3200.00
0005435127131	14768	Economy	3200.00
0005435127128	14768	Economy	3200.00
0005435127130	14768	Economy	3200.00
0005435127110	14768	Economy	3200.00
0005435554275	14768	Economy	3200.00
0005435127125	14768	Economy	3200.00
0005435554273	14768	Economy	3200.00
0005435127111	14768	Economy	3200.00
0005435127140	14768	Economy	3200.00
0005435127121	14768	Economy	3200.00
0005435127145	14768	Economy	3200.00
0005435626514	14768	Economy	3200.00
0005435127143	14768	Economy	3200.00
0005435127115	14768	Economy	3200.00
0005435127118	14768	Economy	3200.00
0005435626513	14768	Economy	3200.00
0005435127117	14768	Economy	3200.00
0005435127132	14768	Economy	3200.00
0005435626516	14768	Economy	3200.00
0005435626526	14768	Economy	3200.00
0005435127120	14768	Economy	3200.00
0005435626529	14768	Economy	3200.00
0005435626509	14768	Economy	3200.00
0005435127135	14768	Economy	3200.00
0005435626522	14768	Economy	3200.00
0005434928341	14768	Economy	3200.00
0005434928336	14768	Economy	3200.00
0005435127122	14768	Economy	3200.00
0005435626520	14768	Economy	3200.00
0005435127124	14768	Economy	3200.00
0005434928337	14768	Economy	3200.00
0005435626527	14768	Economy	3200.00
0005435127123	14768	Economy	3200.00
0005435556739	14768	Economy	3200.00
0005434411818	14768	Economy	3200.00
0005435127142	14768	Economy	3200.00
0005435127105	14768	Economy	3200.00
0005435127137	14768	Economy	3200.00
0005435127116	14768	Economy	3200.00
0005435626519	14768	Economy	3200.00
0005435179404	7128	Business	86900.00
0005435715790	7128	Business	86900.00
0005435715776	7128	Business	86900.00
0005435443420	7128	Business	86900.00
0005432398266	7128	Business	86900.00
0005435443411	7128	Business	86900.00
0005435715782	7128	Business	86900.00
0005435443414	7128	Economy	29000.00
0005432398265	7128	Economy	29000.00
0005435443413	7128	Economy	29000.00
0005435443458	7128	Economy	29000.00
0005435715781	7128	Economy	29000.00
0005435178506	7128	Economy	29000.00
0005435715788	7128	Economy	29000.00
0005432400192	7128	Economy	29000.00
0005435216595	7128	Economy	29000.00
0005435715793	7128	Economy	29000.00
0005435216611	7128	Economy	29000.00
0005432400193	7128	Economy	29000.00
0005435715792	7128	Economy	29000.00
0005432400196	7128	Economy	29000.00
0005435715789	7128	Economy	29000.00
0005435219216	7128	Economy	29000.00
0005435715791	7128	Economy	29000.00
0005435443416	7128	Economy	29000.00
0005435715783	7128	Economy	29000.00
0005435715780	7128	Economy	29000.00
0005435715786	7128	Economy	29000.00
0005435219218	7128	Economy	29000.00
0005435178509	7128	Economy	29000.00
0005435715779	7128	Economy	29000.00
0005435715784	7128	Economy	29000.00
0005435443457	7128	Economy	29000.00
0005435443419	7128	Economy	29000.00
0005435715778	7128	Economy	29000.00
0005435443424	7128	Economy	29000.00
0005435219213	7128	Economy	29000.00
0005432398267	7128	Economy	29000.00
0005435715777	7128	Economy	29000.00
0005432400194	7128	Economy	29000.00
0005432400195	7128	Economy	29000.00
0005435715785	7128	Economy	29000.00
0005435715787	7128	Economy	29000.00
0005435443412	7128	Economy	29000.00
0005435715577	27057	Business	86900.00
0005435715624	27057	Business	86900.00
0005435715700	27057	Business	86900.00
0005435715575	27057	Business	86900.00
0005435443483	27057	Business	86900.00
0005435443484	27057	Economy	29000.00
0005435715576	27057	Economy	29000.00
0005435443486	27057	Economy	29000.00
0005432398216	27057	Economy	29000.00
0005435443489	27057	Economy	31900.00
0005435715647	27057	Economy	31900.00
0005435715629	27057	Economy	29000.00
0005432394158	27057	Economy	29000.00
0005435715683	27057	Economy	29000.00
0005432394134	27057	Economy	29000.00
0005432394135	27057	Economy	29000.00
0005435443487	27057	Economy	29000.00
0005435715666	27057	Economy	29000.00
0005435443488	27057	Economy	29000.00
0005432394136	27057	Economy	29000.00
0005435715625	27057	Economy	29000.00
0005432398227	27057	Economy	29000.00
0005435715636	27057	Economy	29000.00
0005435715630	27057	Economy	29000.00
0005435443491	27057	Economy	29000.00
0005432394144	27057	Economy	29000.00
0005435443482	27057	Economy	29000.00
0005435715628	27057	Economy	29000.00
0005432398228	27057	Economy	29000.00
0005435443490	27057	Economy	29000.00
0005435443485	27057	Economy	29000.00
0005432398230	27057	Economy	29000.00
0005432398237	27057	Economy	29000.00
0005435715693	27057	Economy	29000.00
0005435443492	27057	Economy	29000.00
0005432398238	27057	Economy	29000.00
0005432398235	27057	Economy	29000.00
0005434085017	2742	Economy	7700.00
0005434085014	2742	Economy	7700.00
0005433060435	2742	Economy	7700.00
0005433060449	2742	Economy	7700.00
0005433060434	2742	Economy	7700.00
0005434085015	2742	Economy	7700.00
0005434085018	2742	Economy	7700.00
0005434085016	2742	Economy	7700.00
0005433060436	2742	Economy	7700.00
0005434084976	28518	Economy	7700.00
0005433060463	28518	Economy	7700.00
0005434084974	28518	Economy	7700.00
0005434084980	28518	Economy	7700.00
0005434084975	28518	Economy	7700.00
0005433060462	28518	Economy	7700.00
0005434084990	28518	Economy	7700.00
0005434084970	28518	Economy	7700.00
0005433060464	28518	Economy	7700.00
0005435541238	11393	Business	20200.00
0005435541272	11393	Business	20200.00
0005435518049	11393	Business	20200.00
0005435541276	11393	Business	20200.00
0005435541217	11393	Business	20200.00
0005435518141	11393	Economy	6700.00
0005435541168	11393	Economy	6700.00
0005435518079	11393	Economy	6700.00
0005435541249	11393	Economy	7400.00
0005435518105	11393	Economy	7400.00
0005435518089	11393	Economy	7400.00
0005435518153	11393	Economy	6700.00
0005435518050	11393	Economy	6700.00
0005435541206	11393	Economy	6700.00
0005435518152	11393	Economy	6700.00
0005435541283	11393	Economy	6700.00
0005435541257	11393	Economy	6700.00
0005435518106	11393	Economy	6700.00
0005435518132	11393	Economy	6700.00
0005435518136	11393	Economy	6700.00
0005435518142	11393	Economy	6700.00
0005435541250	11393	Economy	6700.00
0005435541269	11393	Economy	6700.00
0005435518073	11393	Economy	6700.00
0005435541218	11393	Economy	6700.00
0005435541227	11393	Economy	6700.00
0005435541194	11393	Economy	6700.00
0005435541180	11393	Economy	6700.00
0005435541373	11393	Economy	6700.00
0005435541176	11393	Economy	6700.00
0005435541207	11393	Economy	6700.00
0005435541179	11393	Economy	6700.00
0005435518126	11393	Economy	6700.00
0005435518053	11393	Economy	6700.00
0005435541192	11393	Economy	6700.00
0005435541248	11393	Economy	6700.00
0005435541282	11393	Economy	6700.00
0005435541107	11393	Economy	6700.00
0005435518127	11393	Economy	6700.00
0005435541386	22226	Business	20200.00
0005435529641	22226	Business	20200.00
0005435529639	22226	Business	20200.00
0005435529992	22226	Business	20200.00
0005435529991	22226	Business	20200.00
0005435529651	22226	Economy	6700.00
0005435529646	22226	Economy	6700.00
0005435541392	22226	Economy	6700.00
0005435541391	22226	Economy	6700.00
0005435541378	22226	Economy	6700.00
0005435541380	22226	Economy	7400.00
0005435541382	22226	Economy	7400.00
0005435541393	22226	Economy	7400.00
0005435541397	22226	Economy	6700.00
0005435541379	22226	Economy	6700.00
0005435529644	22226	Economy	6700.00
0005435529640	22226	Economy	6700.00
0005435529632	22226	Economy	6700.00
0005435529650	22226	Economy	6700.00
0005435541390	22226	Economy	6700.00
0005435529994	22226	Economy	6700.00
0005435529652	22226	Economy	6700.00
0005435541384	22226	Economy	6700.00
0005432294529	22226	Economy	6700.00
0005435541395	22226	Economy	6700.00
0005432294530	22226	Economy	6700.00
0005435529633	22226	Economy	6700.00
0005435529637	22226	Economy	6700.00
0005435541396	22226	Economy	6700.00
0005435529638	22226	Economy	6700.00
0005435529653	22226	Economy	6700.00
0005435541381	22226	Economy	6700.00
0005435541385	22226	Economy	6700.00
0005435541389	22226	Economy	6700.00
0005435529647	22226	Economy	6700.00
0005435541394	22226	Economy	6700.00
0005435529993	22226	Economy	6700.00
0005435529649	22226	Economy	6700.00
0005435529648	22226	Economy	6700.00
0005435529643	22226	Economy	6700.00
0005435541377	22226	Economy	6700.00
0005435541383	22226	Economy	6700.00
0005435529634	22226	Economy	6700.00
0005435529990	22226	Economy	6700.00
0005435529635	22226	Economy	6700.00
0005435541388	22226	Economy	6700.00
0005435529636	22226	Economy	6700.00
0005435541387	22226	Economy	6700.00
0005435529645	22226	Economy	6700.00
0005435529642	22226	Economy	6700.00
0005434908265	2315	Business	20200.00
0005434908272	2315	Business	20200.00
0005434908234	2315	Business	20200.00
0005434908268	2315	Business	20200.00
0005434908231	2315	Business	20200.00
0005433251796	2315	Business	20200.00
0005433251797	2315	Business	20200.00
0005434908259	2315	Business	20200.00
0005433251888	2315	Business	20200.00
0005434908270	2315	Business	20200.00
0005434908220	2315	Business	20200.00
0005434908225	2315	Economy	6700.00
0005434908252	2315	Economy	6700.00
0005434908264	2315	Economy	6700.00
0005434908235	2315	Economy	6700.00
0005434908262	2315	Economy	6700.00
0005434908224	2315	Economy	6700.00
0005433251752	2315	Economy	6700.00
0005433251818	2315	Economy	7400.00
0005433251722	2315	Economy	7400.00
0005433251813	2315	Economy	7400.00
0005434908229	2315	Economy	7400.00
0005433251754	2315	Economy	7400.00
0005433251729	2315	Economy	6700.00
0005434908266	2315	Economy	6700.00
0005434908242	2315	Economy	6700.00
0005434908278	2315	Economy	6700.00
0005434908230	2315	Economy	6700.00
0005434908227	2315	Economy	6700.00
0005434908247	2315	Economy	6700.00
0005433251905	2315	Economy	6700.00
0005433251746	2315	Economy	6700.00
0005434908243	2315	Economy	6700.00
0005434908274	2315	Economy	6700.00
0005434908219	2315	Economy	6700.00
0005434908233	2315	Economy	6700.00
0005434908238	2315	Economy	6700.00
0005434908258	2315	Economy	6700.00
0005434908222	2315	Economy	6700.00
0005434908263	2315	Economy	6700.00
0005433251801	2315	Economy	6700.00
0005434908244	2315	Economy	6700.00
0005433401019	2315	Economy	6700.00
0005434908223	2315	Economy	6700.00
0005433251906	2315	Economy	6700.00
0005433251802	2315	Economy	6700.00
0005434908250	2315	Economy	6700.00
0005433251868	2315	Economy	6700.00
0005433251753	2315	Economy	6700.00
0005434908256	2315	Economy	6700.00
0005434908271	2315	Economy	6700.00
0005433251866	2315	Economy	6700.00
0005433251867	2315	Economy	6700.00
0005433251819	2315	Economy	6700.00
0005434908257	2315	Economy	6700.00
0005434908273	2315	Economy	6700.00
0005434908228	2315	Economy	6700.00
0005433251855	2315	Economy	6700.00
0005434908260	2315	Economy	6700.00
0005434908251	2315	Economy	6700.00
0005434908246	2315	Economy	6700.00
0005434908276	2315	Economy	6700.00
0005434908226	2315	Economy	6700.00
0005434908275	2315	Economy	6700.00
0005434908261	2315	Economy	6700.00
0005433251826	2315	Economy	6700.00
0005434908240	2315	Economy	6700.00
0005434908221	2315	Economy	6700.00
0005433251896	2315	Economy	6700.00
0005433401016	2315	Economy	6700.00
0005433251759	2315	Economy	6700.00
0005433251763	2315	Economy	6700.00
0005434908241	2315	Economy	6700.00
0005434908254	2315	Economy	6700.00
0005434908269	2315	Economy	6700.00
0005434908239	2315	Economy	6700.00
0005433251760	2315	Economy	6700.00
0005434908277	2315	Economy	6700.00
0005433251841	2315	Economy	6700.00
0005434908236	2315	Economy	6700.00
0005434908232	2315	Economy	6700.00
0005434908245	2315	Economy	6700.00
0005434908267	2315	Economy	6700.00
0005433251758	2315	Economy	6700.00
0005434908255	2315	Economy	6700.00
0005434908253	2315	Economy	6700.00
0005434908248	2315	Economy	6700.00
0005434908249	2315	Economy	6700.00
0005433251887	2315	Economy	6700.00
0005434908237	2315	Economy	6700.00
0005434907615	25598	Business	20200.00
0005433252046	25598	Business	20200.00
0005434907687	25598	Business	20200.00
0005434907930	25598	Business	20200.00
0005433252045	25598	Business	20200.00
0005434907867	25598	Business	20200.00
0005433252044	25598	Business	20200.00
0005434907886	25598	Business	20200.00
0005433252053	25598	Business	20200.00
0005434907651	25598	Business	20200.00
0005434907787	25598	Business	20200.00
0005434907845	25598	Business	20200.00
0005433252050	25598	Economy	6700.00
0005433252051	25598	Economy	6700.00
0005434907544	25598	Economy	6700.00
0005433252040	25598	Economy	6700.00
0005433252039	25598	Economy	6700.00
0005434907857	25598	Economy	6700.00
0005434907844	25598	Economy	6700.00
0005434907774	25598	Economy	6700.00
0005433401041	25598	Economy	6700.00
0005433252048	25598	Economy	6700.00
0005433252043	25598	Economy	7400.00
0005434907581	25598	Economy	7400.00
0005434907492	25598	Economy	7400.00
0005434907614	25598	Economy	7400.00
0005434907887	25598	Economy	6700.00
0005434907750	25598	Economy	6700.00
0005434907712	25598	Economy	6700.00
0005434907866	25598	Economy	6700.00
0005433252059	25598	Economy	6700.00
0005433252036	25598	Economy	6700.00
0005434907731	25598	Economy	6700.00
0005434907677	25598	Economy	6700.00
0005434907628	25598	Economy	6700.00
0005433252064	25598	Economy	6700.00
0005434907758	25598	Economy	6700.00
0005434907924	25598	Economy	6700.00
0005434907798	25598	Economy	6700.00
0005433252047	25598	Economy	6700.00
0005434907903	25598	Economy	6700.00
0005434907860	25598	Economy	6700.00
0005433252062	25598	Economy	6700.00
0005434907699	25598	Economy	6700.00
0005434907788	25598	Economy	6700.00
0005433252049	25598	Economy	6700.00
0005433252060	25598	Economy	6700.00
0005433401038	25598	Economy	6700.00
0005433252055	25598	Economy	6700.00
0005433252034	25598	Economy	6700.00
0005433252056	25598	Economy	6700.00
0005434907818	25598	Economy	6700.00
0005434907794	25598	Economy	6700.00
0005434907686	25598	Economy	6700.00
0005433252035	25598	Economy	6700.00
0005434907613	25598	Economy	6700.00
0005434907663	25598	Economy	6700.00
0005434907729	25598	Economy	6700.00
0005434907929	25598	Economy	6700.00
0005434907821	25598	Economy	6700.00
0005434907596	25598	Economy	6700.00
0005433252038	25598	Economy	6700.00
0005433252063	25598	Economy	6700.00
0005434907666	25598	Economy	6700.00
0005434907822	25598	Economy	6700.00
0005434907871	25598	Economy	6700.00
0005434907918	25598	Economy	6700.00
0005434907790	25598	Economy	6700.00
0005434907546	25598	Economy	6700.00
0005433252052	25598	Economy	6700.00
0005434907545	25598	Economy	6700.00
0005434907701	25598	Economy	6700.00
0005433252065	25598	Economy	6700.00
0005434907772	25598	Economy	6700.00
0005434907665	25598	Economy	6700.00
0005433252061	25598	Economy	6700.00
0005434907870	25598	Economy	6700.00
0005434907713	25598	Economy	6700.00
0005433401040	25598	Economy	6700.00
0005433252041	25598	Economy	6700.00
0005433252042	25598	Economy	6700.00
0005434907711	25598	Economy	6700.00
0005433252037	25598	Economy	6700.00
0005434907757	25598	Economy	6700.00
0005433252058	25598	Economy	6700.00
0005433401039	25598	Economy	6700.00
0005434907700	25598	Economy	6700.00
0005434907919	25598	Economy	6700.00
0005434907551	25598	Economy	6700.00
0005433252057	25598	Economy	6700.00
0005433252054	25598	Economy	6700.00
0005432621295	2511	Economy	13600.00
0005432621293	2511	Economy	13600.00
0005432862334	2511	Economy	13600.00
0005432621297	2511	Economy	13600.00
0005432862355	2511	Economy	12400.00
0005432621305	2511	Economy	12400.00
0005432621303	2511	Economy	12400.00
0005432621301	2511	Economy	12400.00
0005432621296	2511	Economy	12400.00
0005432621294	2511	Economy	12400.00
0005432621292	2511	Economy	12400.00
0005432862357	2511	Economy	12400.00
0005432621302	2511	Economy	12400.00
0005432862397	2511	Economy	12400.00
0005432621298	2511	Economy	12400.00
0005432862356	2511	Economy	12400.00
0005432862392	2511	Economy	12400.00
0005432621307	2511	Economy	12400.00
0005432621304	2511	Economy	12400.00
0005432862396	2511	Economy	12400.00
0005432621299	2511	Economy	12400.00
0005432621306	2511	Economy	12400.00
0005432862333	2511	Economy	12400.00
0005432862335	2511	Economy	12400.00
0005432621300	2511	Economy	12400.00
0005432862448	28073	Economy	13600.00
0005432862447	28073	Economy	13600.00
0005432862444	28073	Economy	12400.00
0005432621123	28073	Economy	12400.00
0005432621136	28073	Economy	12400.00
0005432621158	28073	Economy	12400.00
0005432862442	28073	Economy	12400.00
0005432862446	28073	Economy	12400.00
0005432862450	28073	Economy	12400.00
0005432862443	28073	Economy	12400.00
0005432621135	28073	Economy	12400.00
0005432621134	28073	Economy	12400.00
0005432621168	28073	Economy	12400.00
0005432862449	28073	Economy	12400.00
0005432862445	28073	Economy	12400.00
0005432621169	28073	Economy	12400.00
0005432621211	28073	Economy	12400.00
0005432621212	28073	Economy	12400.00
0005432621159	28073	Economy	12400.00
0005432621198	28073	Economy	12400.00
0005432621218	28073	Economy	12400.00
0005434097498	13038	Economy	11300.00
0005434097497	13038	Economy	11300.00
0005434191293	32873	Business	89600.00
0005434191280	32873	Economy	29900.00
0005434191295	32873	Economy	29900.00
0005434191296	32873	Economy	29900.00
0005434191290	32873	Economy	29900.00
0005434191281	32873	Economy	29900.00
0005434191292	32873	Economy	29900.00
0005433452778	31039	Economy	8400.00
0005433451656	31039	Economy	8400.00
0005433451657	31039	Economy	8400.00
0005433452779	31039	Economy	8400.00
0005433451658	31039	Economy	8400.00
0005433452758	31462	Economy	8400.00
0005433452753	31462	Economy	8400.00
0005433452759	31462	Economy	8400.00
0005434142652	12022	Economy	7200.00
0005434142634	12022	Economy	6600.00
0005434184675	12022	Economy	6600.00
0005434184684	12022	Economy	6600.00
0005433129321	12022	Economy	6600.00
0005433134178	12022	Economy	6600.00
0005434142671	12022	Economy	6600.00
0005433134184	12022	Economy	6600.00
0005434184683	12022	Economy	6600.00
0005434142657	12022	Economy	6600.00
0005434142633	12022	Economy	6600.00
0005433134179	12022	Economy	6600.00
0005434142651	12022	Economy	6600.00
0005434184688	12022	Economy	6600.00
0005433134224	29817	Economy	7200.00
0005433131794	29817	Economy	7200.00
0005433131790	29817	Economy	6600.00
0005434184705	29817	Economy	6600.00
0005434142681	29817	Economy	6600.00
0005434183617	29817	Economy	6600.00
0005434142680	29817	Economy	6600.00
0005433131792	29817	Economy	6600.00
0005433131791	29817	Economy	6600.00
0005434183618	29817	Economy	6600.00
0005434142678	29817	Economy	6600.00
0005434183616	29817	Economy	6600.00
0005433134222	29817	Economy	6600.00
0005433134223	29817	Economy	6600.00
0005433131793	29817	Economy	6600.00
0005433134221	29817	Economy	6600.00
0005434184704	29817	Economy	6600.00
0005434142682	29817	Economy	6600.00
0005434184703	29817	Economy	6600.00
0005434142679	29817	Economy	6600.00
0005435798978	1606	Economy	17200.00
0005435798986	1606	Economy	17200.00
0005435798983	1606	Economy	15700.00
0005435798984	1606	Economy	15700.00
0005435798985	1606	Economy	15700.00
0005435798982	1606	Economy	15700.00
0005435798979	1606	Economy	15700.00
0005435798981	1606	Economy	15700.00
0005435798988	1606	Economy	15700.00
0005435798989	1606	Economy	15700.00
0005435798987	1606	Economy	15700.00
0005435798980	1606	Economy	15700.00
0005435798990	1606	Economy	15700.00
0005435798991	1606	Economy	15700.00
0005435697843	16449	Economy	19900.00
0005435697835	16449	Economy	19900.00
0005435697839	16449	Economy	18100.00
0005435935070	16449	Economy	18100.00
0005435935082	16449	Economy	18100.00
0005435697845	16449	Economy	18100.00
0005435697822	16449	Economy	18100.00
0005435697832	16449	Economy	18100.00
0005435697840	16449	Economy	18100.00
0005435697826	16449	Economy	18100.00
0005435697837	16449	Economy	18100.00
0005435697829	16449	Economy	18100.00
0005435697836	16449	Economy	18100.00
0005435697841	16449	Economy	18100.00
0005435697844	16449	Economy	18100.00
0005435697824	16449	Economy	18100.00
0005435697833	16449	Economy	18100.00
0005435697831	16449	Economy	18100.00
0005435697828	16449	Economy	18100.00
0005435697842	16449	Economy	18100.00
0005435697825	16449	Economy	18100.00
0005435935069	16449	Economy	18100.00
0005435697819	16449	Economy	18100.00
0005435697847	16449	Economy	18100.00
0005435697820	16449	Economy	18100.00
0005435697846	16449	Economy	18100.00
0005435935081	16449	Economy	18100.00
0005435697823	16449	Economy	18100.00
0005435697827	16449	Economy	18100.00
0005435697821	16449	Economy	18100.00
0005435697830	16449	Economy	18100.00
0005435697838	16449	Economy	18100.00
0005435697834	16449	Economy	18100.00
0005435935101	24745	Economy	19900.00
0005435697676	24745	Economy	19900.00
0005435697537	24745	Economy	19900.00
0005435697673	24745	Economy	18100.00
0005435697698	24745	Economy	18100.00
0005435697485	24745	Economy	18100.00
0005435697604	24745	Economy	18100.00
0005435697659	24745	Economy	18100.00
0005435697660	24745	Economy	18100.00
0005435697568	24745	Economy	18100.00
0005435935102	24745	Economy	18100.00
0005435697658	24745	Economy	18100.00
0005435697595	24745	Economy	18100.00
0005435697540	24745	Economy	18100.00
0005435697628	24745	Economy	18100.00
0005435697627	24745	Economy	18100.00
0005435697536	24745	Economy	18100.00
0005435697539	24745	Economy	18100.00
0005435697603	24745	Economy	18100.00
0005435935100	24745	Economy	18100.00
0005435697576	24745	Economy	18100.00
0005435697569	24745	Economy	18100.00
0005435697674	24745	Economy	18100.00
0005435697657	24745	Economy	18100.00
0005435697783	24745	Economy	18100.00
0005435935099	24745	Economy	18100.00
0005435697631	24745	Economy	18100.00
0005433724886	18760	Economy	4400.00
0005433724889	18760	Economy	4400.00
0005433724887	18760	Economy	4400.00
0005433724885	18760	Economy	4400.00
0005433724888	18760	Economy	4400.00
0005433724850	21621	Economy	4400.00
0005433724843	21621	Economy	4400.00
0005433724842	21621	Economy	4400.00
0005433724863	21621	Economy	4400.00
0005432968885	21621	Economy	4400.00
0005433724849	21621	Economy	4400.00
0005434139623	7347	Business	23100.00
0005434139684	7347	Business	23100.00
0005434139682	7347	Business	23100.00
0005434139624	7347	Business	23100.00
0005434139676	7347	Business	23100.00
0005434139673	7347	Business	23100.00
0005434087605	7347	Business	23100.00
0005434139689	7347	Business	23100.00
0005434139648	7347	Business	23100.00
0005434139658	7347	Economy	7700.00
0005434139633	7347	Economy	7700.00
0005434139651	7347	Economy	7700.00
0005434139671	7347	Economy	7700.00
0005434139631	7347	Economy	7700.00
0005434139622	7347	Economy	7700.00
0005434087604	7347	Economy	7700.00
0005434139664	7347	Economy	8500.00
0005434139662	7347	Economy	8500.00
0005434139627	7347	Economy	8500.00
0005434139643	7347	Economy	8500.00
0005434139654	7347	Economy	8500.00
0005434139652	7347	Economy	7700.00
0005434139659	7347	Economy	7700.00
0005434139639	7347	Economy	7700.00
0005434139636	7347	Economy	7700.00
0005434139635	7347	Economy	7700.00
0005434139637	7347	Economy	7700.00
0005434139665	7347	Economy	7700.00
0005434087603	7347	Economy	7700.00
0005434139683	7347	Economy	7700.00
0005434139642	7347	Economy	7700.00
0005434087606	7347	Economy	7700.00
0005434139677	7347	Economy	7700.00
0005434139680	7347	Economy	7700.00
0005434139657	7347	Economy	7700.00
0005434139672	7347	Economy	7700.00
0005434139661	7347	Economy	7700.00
0005434139660	7347	Economy	7700.00
0005434139679	7347	Economy	7700.00
0005434139666	7347	Economy	7700.00
0005434139649	7347	Economy	7700.00
0005434139625	7347	Economy	7700.00
0005434139691	7347	Economy	7700.00
0005434139640	7347	Economy	7700.00
0005434139646	7347	Economy	7700.00
0005434139656	7347	Economy	7700.00
0005434139641	7347	Economy	7700.00
0005434139669	7347	Economy	7700.00
0005434139686	7347	Economy	7700.00
0005434139628	7347	Economy	7700.00
0005434139638	7347	Economy	7700.00
0005434139688	7347	Economy	7700.00
0005434139678	7347	Economy	7700.00
0005434139653	7347	Economy	7700.00
0005434139675	7347	Economy	7700.00
0005434139629	7347	Economy	7700.00
0005434139630	7347	Economy	7700.00
0005434139647	7347	Economy	7700.00
0005434139634	7347	Economy	7700.00
0005434139650	7347	Economy	7700.00
0005434139644	7347	Economy	7700.00
0005434139626	7347	Economy	7700.00
0005434139668	7347	Economy	7700.00
0005434139690	7347	Economy	7700.00
0005434139667	7347	Economy	7700.00
0005434139685	7347	Economy	7700.00
0005434139681	7347	Economy	7700.00
0005434139663	7347	Economy	7700.00
0005434139632	7347	Economy	7700.00
0005434139674	7347	Economy	7700.00
0005434139655	7347	Economy	7700.00
0005434139645	7347	Economy	7700.00
0005434139687	7347	Economy	7700.00
0005434139670	7347	Economy	7700.00
0005434138651	28559	Business	23100.00
0005434138757	28559	Business	23100.00
0005434139161	28559	Business	23100.00
0005434138604	28559	Business	23100.00
0005435283557	28559	Business	23100.00
0005434138779	28559	Business	23100.00
0005434139207	28559	Business	23100.00
0005434138440	28559	Business	23100.00
0005434138871	28559	Business	23100.00
0005435283568	28559	Business	23100.00
0005434139184	28559	Business	23100.00
0005434139004	28559	Economy	7700.00
0005434138919	28559	Economy	7700.00
0005434138831	28559	Economy	7700.00
0005434139118	28559	Economy	7700.00
0005434138688	28559	Economy	7700.00
0005434138950	28559	Economy	7700.00
0005434139290	28559	Economy	7700.00
0005434139054	28559	Economy	7700.00
0005434138957	28559	Economy	7700.00
0005434138778	28559	Economy	8500.00
0005434138998	28559	Economy	8500.00
0005434138705	28559	Economy	8500.00
0005434138639	28559	Economy	7700.00
0005434138733	28559	Economy	7700.00
0005434139291	28559	Economy	7700.00
0005434138830	28559	Economy	7700.00
0005434139040	28559	Economy	7700.00
0005434138921	28559	Economy	7700.00
0005434138603	28559	Economy	7700.00
0005434138689	28559	Economy	7700.00
0005434139005	28559	Economy	7700.00
0005434138848	28559	Economy	7700.00
0005434139021	28559	Economy	7700.00
0005434138637	28559	Economy	7700.00
0005434138748	28559	Economy	7700.00
0005434139012	28559	Economy	7700.00
0005434138656	28559	Economy	7700.00
0005434138838	28559	Economy	7700.00
0005434138853	28559	Economy	7700.00
0005434138828	28559	Economy	7700.00
0005434138650	28559	Economy	7700.00
0005434138868	28559	Economy	7700.00
0005434138896	28559	Economy	7700.00
0005434138763	28559	Economy	7700.00
0005434138721	28559	Economy	7700.00
0005434139055	28559	Economy	7700.00
0005434138643	28559	Economy	7700.00
0005434138725	28559	Economy	7700.00
0005434138974	28559	Economy	7700.00
0005434139197	28559	Economy	7700.00
0005434139124	28559	Economy	7700.00
0005434138847	28559	Economy	7700.00
0005434138665	28559	Economy	7700.00
0005434139041	28559	Economy	7700.00
0005434138938	28559	Economy	7700.00
0005434138829	28559	Economy	7700.00
0005434138640	28559	Economy	7700.00
0005434138690	28559	Economy	7700.00
0005434139020	28559	Economy	7700.00
0005434139196	28559	Economy	7700.00
0005434139094	28559	Economy	7700.00
0005434138898	28559	Economy	7700.00
0005434139174	28559	Economy	7700.00
0005435283556	28559	Economy	7700.00
0005434138889	28559	Economy	7700.00
0005434138729	28559	Economy	7700.00
0005434139034	28559	Economy	7700.00
0005434087547	28559	Economy	7700.00
0005434138852	28559	Economy	7700.00
0005434138839	28559	Economy	7700.00
0005434138704	28559	Economy	7700.00
0005434139117	28559	Economy	7700.00
0005434138903	28559	Economy	7700.00
0005434138741	28559	Economy	7700.00
0005434138743	28559	Economy	7700.00
0005434138747	28559	Economy	7700.00
0005434139009	28559	Economy	7700.00
0005434138837	28559	Economy	7700.00
0005434138890	28559	Economy	7700.00
0005434138730	28559	Economy	7700.00
0005434087579	28559	Economy	7700.00
0005434139206	28559	Economy	7700.00
0005434138863	28559	Economy	7700.00
0005434138742	28559	Economy	7700.00
0005434138764	28559	Economy	7700.00
0005434138491	28559	Economy	7700.00
0005434138703	28559	Economy	7700.00
0005433407610	1951	Economy	23900.00
0005433407617	1951	Economy	23900.00
0005435808419	1951	Economy	21700.00
0005435808418	1951	Economy	21700.00
0005434610295	1951	Economy	21700.00
0005435808416	1951	Economy	21700.00
0005433407623	1951	Economy	21700.00
0005434610297	1951	Economy	21700.00
0005435808415	1951	Economy	21700.00
0005435808414	1951	Economy	21700.00
0005433407602	1951	Economy	21700.00
0005434610296	1951	Economy	21700.00
0005433407611	1951	Economy	21700.00
0005435808417	1951	Economy	21700.00
0005433407618	1951	Economy	21700.00
0005435808413	1951	Economy	21700.00
0005433407620	1951	Economy	21700.00
0005433407609	1951	Economy	21700.00
0005434610263	23065	Economy	21700.00
0005434504383	16678	Economy	7600.00
0005434504425	16678	Economy	7600.00
0005434504495	16678	Economy	6900.00
0005434504543	16678	Economy	6900.00
0005434504653	16678	Economy	6900.00
0005434504539	16678	Economy	6900.00
0005434504445	16678	Economy	6900.00
0005434504518	16678	Economy	6900.00
0005434504416	16678	Economy	6900.00
0005434504517	16678	Economy	6900.00
0005434504449	16678	Economy	6900.00
0005434504492	16678	Economy	6900.00
0005434504612	16678	Economy	6900.00
0005434504578	16678	Economy	6900.00
0005434504390	16678	Economy	6900.00
0005434504551	16678	Economy	6900.00
0005434504457	16678	Economy	6900.00
0005434504534	16678	Economy	6900.00
0005434504408	16678	Economy	6900.00
0005434504506	16678	Economy	6900.00
0005434504652	16678	Economy	6900.00
0005434504446	16678	Economy	6900.00
0005434504540	16678	Economy	6900.00
0005434504564	16678	Economy	6900.00
0005434504614	16678	Economy	6900.00
0005434504613	16678	Economy	6900.00
0005434504577	16678	Economy	6900.00
0005434504678	16678	Economy	6900.00
0005434504192	16678	Economy	6900.00
0005434504455	16678	Economy	6900.00
0005434504494	16678	Economy	6900.00
0005434504389	16678	Economy	6900.00
0005434504454	16678	Economy	6900.00
0005434504456	16678	Economy	6900.00
0005434504450	16678	Economy	6900.00
0005434504382	16678	Economy	6900.00
0005434504502	16678	Economy	6900.00
0005434504507	16678	Economy	6900.00
0005434504646	16678	Economy	6900.00
0005434504847	22898	Economy	7600.00
0005434504850	22898	Economy	7600.00
0005434504843	22898	Economy	7600.00
0005434504840	22898	Economy	6900.00
0005434504827	22898	Economy	6900.00
0005434504852	22898	Economy	6900.00
0005434504844	22898	Economy	6900.00
0005434504841	22898	Economy	6900.00
0005434504865	22898	Economy	6900.00
0005434504830	22898	Economy	6900.00
0005434504849	22898	Economy	6900.00
0005434504828	22898	Economy	6900.00
0005434504832	22898	Economy	6900.00
0005434504838	22898	Economy	6900.00
0005434504862	22898	Economy	6900.00
0005434504845	22898	Economy	6900.00
0005434504857	22898	Economy	6900.00
0005434504834	22898	Economy	6900.00
0005434504856	22898	Economy	6900.00
0005434504846	22898	Economy	6900.00
0005434504842	22898	Economy	6900.00
0005434504853	22898	Economy	6900.00
0005434504854	22898	Economy	6900.00
0005434504855	22898	Economy	6900.00
0005434504863	22898	Economy	6900.00
0005434504861	22898	Economy	6900.00
0005434504836	22898	Economy	6900.00
0005434504837	22898	Economy	6900.00
0005434504839	22898	Economy	6900.00
0005434504851	22898	Economy	6900.00
0005434504860	22898	Economy	6900.00
0005434504864	22898	Economy	6900.00
0005434504859	22898	Economy	6900.00
0005434504831	22898	Economy	6900.00
0005434504826	22898	Economy	6900.00
0005434504866	22898	Economy	6900.00
0005434504833	22898	Economy	6900.00
0005434504835	22898	Economy	6900.00
0005434504848	22898	Economy	6900.00
0005434504858	22898	Economy	6900.00
0005434504829	22898	Economy	6900.00
0005434608366	6503	Economy	19100.00
0005434608373	6503	Economy	19100.00
0005434608364	6503	Economy	17300.00
0005434608368	6503	Economy	17300.00
0005434608358	6503	Economy	17300.00
0005434608377	6503	Economy	17300.00
0005434608367	6503	Economy	17300.00
0005434608360	6503	Economy	17300.00
0005434608372	6503	Economy	17300.00
0005434608365	6503	Economy	17300.00
0005434608362	6503	Economy	17300.00
0005434608375	6503	Economy	17300.00
0005434608376	6503	Economy	17300.00
0005434608363	6503	Economy	17300.00
0005434608361	6503	Economy	17300.00
0005434608370	6503	Economy	17300.00
0005434608371	6503	Economy	17300.00
0005434608374	6503	Economy	17300.00
0005434608369	6503	Economy	17300.00
0005434608359	6503	Economy	17300.00
0005434608341	22497	Economy	19100.00
0005434608337	22497	Economy	17300.00
0005434608324	22497	Economy	17300.00
0005434608357	22497	Economy	17300.00
0005434608326	22497	Economy	17300.00
0005434608340	22497	Economy	17300.00
0005434608319	22497	Economy	17300.00
0005434608318	22497	Economy	17300.00
0005434608327	22497	Economy	17300.00
0005434608325	22497	Economy	17300.00
0005434608343	22497	Economy	17300.00
0005434608350	22497	Economy	17300.00
0005434608334	22497	Economy	17300.00
0005434608332	22497	Economy	17300.00
0005434608344	22497	Economy	17300.00
0005434608352	22497	Economy	17300.00
0005434608338	22497	Economy	17300.00
0005434608342	22497	Economy	17300.00
0005434608330	22497	Economy	17300.00
0005434608328	22497	Economy	17300.00
0005433266813	2216	Economy	7700.00
0005433266834	2216	Economy	7700.00
0005435078637	2216	Economy	7000.00
0005435078632	2216	Economy	7000.00
0005433266814	2216	Economy	7000.00
0005435078635	2216	Economy	7000.00
0005435078627	2216	Economy	7000.00
0005435078628	2216	Economy	7000.00
0005433266796	2216	Economy	7000.00
0005433266819	2216	Economy	7000.00
0005435078622	2216	Economy	7000.00
0005435078636	2216	Economy	7000.00
0005435078626	2216	Economy	7000.00
0005435078631	2216	Economy	7000.00
0005435078623	2216	Economy	7000.00
0005433266800	2216	Economy	7000.00
0005433266792	2216	Economy	7000.00
0005433266833	2216	Economy	7000.00
0005435078624	2216	Economy	7000.00
0005435078625	2216	Economy	7000.00
0005433266801	2216	Economy	7000.00
0005435078634	2216	Economy	7000.00
0005435078633	2216	Economy	7000.00
0005435078629	2216	Economy	7000.00
0005435078621	2216	Economy	7000.00
0005433266818	2216	Economy	7000.00
0005435078630	2216	Economy	7000.00
0005433266897	24356	Economy	7700.00
0005435078490	24356	Economy	7000.00
0005433266899	24356	Economy	7000.00
0005433266894	24356	Economy	7000.00
0005433266895	24356	Economy	7000.00
0005435078476	24356	Economy	7000.00
0005433266898	24356	Economy	7000.00
0005435078512	24356	Economy	7000.00
0005433266893	24356	Economy	7000.00
0005433266892	24356	Economy	7000.00
0005435078496	24356	Economy	7000.00
0005433266896	24356	Economy	7000.00
0005434988933	6625	Economy	9800.00
0005434988927	6625	Economy	9800.00
0005435803317	6625	Economy	9800.00
0005434988928	6625	Economy	9800.00
0005434988937	6625	Economy	9800.00
0005435803315	6625	Economy	9800.00
0005434988930	6625	Economy	9800.00
0005434988934	6625	Economy	9800.00
0005435803316	6625	Economy	9800.00
0005434988931	6625	Economy	9800.00
0005434988926	6625	Economy	9800.00
0005435803318	6625	Economy	9800.00
0005434988925	6625	Economy	9800.00
0005434988929	6625	Economy	9800.00
0005434988936	6625	Economy	9800.00
0005434988935	6625	Economy	9800.00
0005434988932	6625	Economy	9800.00
0005434988787	23627	Economy	9800.00
0005434988794	23627	Economy	9800.00
0005434988814	23627	Economy	9800.00
0005434988801	23627	Economy	9800.00
0005434988802	23627	Economy	9800.00
0005434988862	23627	Economy	9800.00
0005434988828	23627	Economy	9800.00
0005434988869	23627	Economy	9800.00
0005434988863	23627	Economy	9800.00
0005434988805	23627	Economy	9800.00
0005434988795	23627	Economy	9800.00
0005434988835	23627	Economy	9800.00
0005434988861	23627	Economy	9800.00
0005435464544	23627	Economy	9800.00
0005434988842	23627	Economy	9800.00
0005435803286	23627	Economy	9800.00
0005435464545	23627	Economy	9800.00
0005434988786	23627	Economy	9800.00
0005434988849	23627	Economy	9800.00
0005432383909	30474	Business	9900.00
0005432383908	30474	Business	9900.00
0005432383879	30474	Business	9900.00
0005433450374	30474	Business	9900.00
0005432383899	30474	Business	9900.00
0005432383888	30474	Business	9900.00
0005432383884	30474	Business	9900.00
0005433450363	30474	Business	9900.00
0005432383903	30474	Business	9900.00
0005433450382	30474	Economy	3300.00
0005433453798	30474	Economy	3300.00
0005433450379	30474	Economy	3300.00
0005432383889	30474	Economy	3300.00
0005433450380	30474	Economy	3300.00
0005432383896	30474	Economy	3300.00
0005432383887	30474	Economy	3300.00
0005432383876	30474	Economy	3300.00
0005432383890	30474	Economy	3600.00
0005433450367	30474	Economy	3600.00
0005432383910	30474	Economy	3300.00
0005433450370	30474	Economy	3300.00
0005432383891	30474	Economy	3300.00
0005433453800	30474	Economy	3300.00
0005433453797	30474	Economy	3300.00
0005432383881	30474	Economy	3300.00
0005432383902	30474	Economy	3300.00
0005432383883	30474	Economy	3300.00
0005432383880	30474	Economy	3300.00
0005432383907	30474	Economy	3300.00
0005433450381	30474	Economy	3300.00
0005433450378	30474	Economy	3300.00
0005432383904	30474	Economy	3300.00
0005432383875	30474	Economy	3300.00
0005433450373	30474	Economy	3300.00
0005432383913	30474	Economy	3300.00
0005432383886	30474	Economy	3300.00
0005432383877	30474	Economy	3300.00
0005432383898	30474	Economy	3300.00
0005432383912	30474	Economy	3300.00
0005433450371	30474	Economy	3300.00
0005432383892	30474	Economy	3300.00
0005432383878	30474	Economy	3300.00
0005433450377	30474	Economy	3300.00
0005433454915	30474	Economy	3300.00
0005433450369	30474	Economy	3300.00
0005433450365	30474	Economy	3300.00
0005433450366	30474	Economy	3300.00
0005433450383	30474	Economy	3300.00
0005433450372	30474	Economy	3300.00
0005432383894	30474	Economy	3300.00
0005432383906	30474	Economy	3300.00
0005432383895	30474	Economy	3300.00
0005432383885	30474	Economy	3300.00
0005433453799	30474	Economy	3300.00
0005432383882	30474	Economy	3300.00
0005432383901	30474	Economy	3300.00
0005432383893	30474	Economy	3300.00
0005432383911	30474	Economy	3300.00
0005432383905	30474	Economy	3300.00
0005433450375	30474	Economy	3300.00
0005433450384	30474	Economy	3300.00
0005432383900	30474	Economy	3300.00
0005433450368	30474	Economy	3300.00
0005433450376	30474	Economy	3300.00
0005432383897	30474	Economy	3300.00
0005433450364	30474	Economy	3300.00
0005432383914	30474	Economy	3300.00
0005433450167	31305	Business	9900.00
0005432383463	31305	Business	9900.00
0005432383318	31305	Business	9900.00
0005432383508	31305	Business	9900.00
0005433453779	31305	Business	9900.00
0005433450102	31305	Business	9900.00
0005433450267	31305	Business	9900.00
0005432383452	31305	Business	9900.00
0005432383506	31305	Economy	3300.00
0005432383354	31305	Economy	3300.00
0005432383464	31305	Economy	3300.00
0005433451641	31305	Economy	3300.00
0005432383467	31305	Economy	3300.00
0005432383366	31305	Economy	3600.00
0005432383133	31305	Economy	3600.00
0005432383454	31305	Economy	3600.00
0005432383476	31305	Economy	3300.00
0005433450265	31305	Economy	3300.00
0005432383491	31305	Economy	3300.00
0005433450120	31305	Economy	3300.00
0005432383340	31305	Economy	3300.00
0005433450219	31305	Economy	3300.00
0005432383414	31305	Economy	3300.00
0005433450205	31305	Economy	3300.00
0005432383431	31305	Economy	3300.00
0005432383542	31305	Economy	3300.00
0005432383415	31305	Economy	3300.00
0005432383337	31305	Economy	3300.00
0005432383364	31305	Economy	3300.00
0005432383432	31305	Economy	3300.00
0005433450168	31305	Economy	3300.00
0005432383453	31305	Economy	3300.00
0005432383507	31305	Economy	3300.00
0005433450206	31305	Economy	3300.00
0005432383348	31305	Economy	3300.00
0005432383502	31305	Economy	3300.00
0005433450122	31305	Economy	3300.00
0005432383416	31305	Economy	3300.00
0005432383365	31305	Economy	3300.00
0005433450098	31305	Economy	3300.00
0005432383541	31305	Economy	3300.00
0005432383367	31305	Economy	3300.00
0005433450144	31305	Economy	3300.00
0005433450125	31305	Economy	3300.00
0005433450133	31305	Economy	3300.00
0005433450245	31305	Economy	3300.00
0005432383462	31305	Economy	3300.00
0005433450220	31305	Economy	3300.00
0005432383430	31305	Economy	3300.00
0005432383134	31305	Economy	3300.00
0005432383524	31305	Economy	3300.00
0005432383525	31305	Economy	3300.00
0005433450264	31305	Economy	3300.00
0005432383349	31305	Economy	3300.00
0005435548524	20830	Economy	26200.00
0005433788265	20830	Economy	26200.00
0005435548512	20830	Economy	26200.00
0005433788267	20830	Economy	26200.00
0005435548498	20830	Economy	23800.00
0005433788264	20830	Economy	23800.00
0005435548513	20830	Economy	23800.00
0005435548526	20830	Economy	23800.00
0005435548527	20830	Economy	23800.00
0005433788274	20830	Economy	23800.00
0005433788269	20830	Economy	23800.00
0005433788266	20830	Economy	23800.00
0005433788273	20830	Economy	23800.00
0005433788272	20830	Economy	23800.00
0005433788270	20830	Economy	23800.00
0005435548528	20830	Economy	23800.00
0005435548506	20830	Economy	23800.00
0005435548505	20830	Economy	23800.00
0005435548509	20830	Economy	23800.00
0005435548500	20830	Economy	23800.00
0005435548525	20830	Economy	23800.00
0005435548523	20830	Economy	23800.00
0005433788275	20830	Economy	23800.00
0005433788276	20830	Economy	23800.00
0005433788268	20830	Economy	23800.00
0005433788271	20830	Economy	23800.00
0005435548510	20830	Economy	23800.00
0005435548531	20830	Economy	23800.00
0005435299828	10743	Economy	15600.00
0005435299811	10743	Economy	15600.00
0005435299812	10743	Economy	15600.00
0005433126875	10743	Economy	15600.00
0005433131761	10743	Economy	15600.00
0005435304198	10743	Economy	15600.00
0005435299827	10743	Economy	15600.00
0005435304193	10743	Economy	15600.00
0005435299816	10743	Economy	15600.00
0005435299867	29689	Economy	17100.00
0005433126932	29689	Economy	15600.00
0005435299869	29689	Economy	15600.00
0005435302291	29689	Economy	15600.00
0005435302292	29689	Economy	15600.00
0005433129362	29689	Economy	15600.00
0005435299870	29689	Economy	15600.00
0005435302289	29689	Economy	15600.00
0005433126935	29689	Economy	15600.00
0005433126931	29689	Economy	15600.00
0005433129366	29689	Economy	15600.00
0005435299868	29689	Economy	15600.00
0005433129364	29689	Economy	15600.00
0005433129363	29689	Economy	15600.00
0005433126934	29689	Economy	15600.00
0005433126933	29689	Economy	15600.00
0005435302290	29689	Economy	15600.00
0005435302288	29689	Economy	15600.00
0005433129365	29689	Economy	15600.00
0005433110161	2397	Economy	17200.00
0005434287704	2397	Economy	17200.00
0005434287709	2397	Economy	17200.00
0005434287689	2397	Economy	15700.00
0005433110202	2397	Economy	15700.00
0005434287694	2397	Economy	15700.00
0005434287696	2397	Economy	15700.00
0005434287695	2397	Economy	15700.00
0005434287705	2397	Economy	15700.00
0005432264520	2397	Economy	15700.00
0005434287707	2397	Economy	15700.00
0005434287699	2397	Economy	15700.00
0005434287698	2397	Economy	15700.00
0005434287697	2397	Economy	15700.00
0005433110140	2397	Economy	15700.00
0005434287701	2397	Economy	15700.00
0005434287693	2397	Economy	15700.00
0005434287700	2397	Economy	15700.00
0005433110226	2397	Economy	15700.00
0005433110224	2397	Economy	15700.00
0005433110249	2397	Economy	15700.00
0005434287708	2397	Economy	15700.00
0005433110195	2397	Economy	15700.00
0005434287703	2397	Economy	15700.00
0005434287692	2397	Economy	15700.00
0005434287710	2397	Economy	15700.00
0005433110223	2397	Economy	15700.00
0005433110141	2397	Economy	15700.00
0005434287691	2397	Economy	15700.00
0005432264521	2397	Economy	15700.00
0005433110201	2397	Economy	15700.00
0005433110225	2397	Economy	15700.00
0005434287702	2397	Economy	15700.00
0005433110191	2397	Economy	15700.00
0005433110164	2397	Economy	15700.00
0005433110218	2397	Economy	15700.00
0005434287706	2397	Economy	15700.00
0005434287690	2397	Economy	15700.00
0005433110274	26843	Economy	17200.00
0005434287519	26843	Economy	17200.00
0005434287494	26843	Economy	17200.00
0005433110280	26843	Economy	15700.00
0005434287470	26843	Economy	15700.00
0005434287528	26843	Economy	15700.00
0005434287471	26843	Economy	15700.00
0005434287530	26843	Economy	15700.00
0005433110282	26843	Economy	15700.00
0005433110273	26843	Economy	15700.00
0005434287472	26843	Economy	15700.00
0005433110277	26843	Economy	15700.00
0005434287573	26843	Economy	15700.00
0005433110281	26843	Economy	15700.00
0005433110278	26843	Economy	15700.00
0005434287493	26843	Economy	15700.00
0005433110275	26843	Economy	15700.00
0005434287446	26843	Economy	15700.00
0005433110271	26843	Economy	15700.00
0005433110272	26843	Economy	15700.00
0005434287525	26843	Economy	15700.00
0005433110276	26843	Economy	15700.00
0005434287490	26843	Economy	15700.00
0005434287545	26843	Economy	15700.00
0005434287481	26843	Economy	15700.00
0005434287524	26843	Economy	15700.00
0005433110279	26843	Economy	15700.00
0005434287435	26843	Economy	15700.00
0005434269119	25461	Economy	25000.00
0005435856281	25461	Economy	25000.00
0005434272203	25461	Economy	22800.00
0005435856283	25461	Economy	22800.00
0005435856284	25461	Economy	22800.00
0005434272198	25461	Economy	22800.00
0005434269117	25461	Economy	22800.00
0005435856282	25461	Economy	22800.00
0005434269116	25461	Economy	22800.00
0005434272202	25461	Economy	22800.00
0005434269118	25461	Economy	22800.00
0005434269120	25461	Economy	22800.00
0005434272204	25461	Economy	22800.00
0005434269125	25461	Economy	22800.00
0005434272220	26655	Economy	25000.00
0005435856242	26655	Economy	22800.00
0005434272219	26655	Economy	22800.00
0005434273106	26655	Economy	22800.00
0005435856240	26655	Economy	22800.00
0005435856241	26655	Economy	22800.00
0005435856245	26655	Economy	22800.00
0005435856244	26655	Economy	22800.00
0005434272218	26655	Economy	22800.00
0005434273107	26655	Economy	22800.00
0005435856243	26655	Economy	22800.00
0005434520310	19074	Economy	24600.00
0005434520361	19074	Economy	24600.00
0005434520386	19074	Economy	24600.00
0005434520360	19074	Economy	24600.00
0005434520311	19074	Economy	22300.00
0005434520321	19074	Economy	22300.00
0005434520307	19074	Economy	22300.00
0005434520319	19074	Economy	22300.00
0005434520347	19074	Economy	22300.00
0005435314903	19074	Economy	22300.00
0005435314912	19074	Economy	22300.00
0005435314907	19074	Economy	22300.00
0005434520313	19074	Economy	22300.00
0005435314908	19074	Economy	22300.00
0005434520322	19074	Economy	22300.00
0005434520283	19074	Economy	22300.00
0005435314906	19074	Economy	22300.00
0005434520382	19074	Economy	22300.00
0005434520333	19074	Economy	22300.00
0005434520318	19074	Economy	22300.00
0005435314902	19074	Economy	22300.00
0005434520356	19074	Economy	22300.00
0005435314904	19074	Economy	22300.00
0005434520339	19074	Economy	22300.00
0005434520338	19074	Economy	22300.00
0005434520342	19074	Economy	22300.00
0005434520355	19074	Economy	22300.00
0005434520335	19074	Economy	22300.00
0005434520325	19074	Economy	22300.00
0005434520357	19074	Economy	22300.00
0005435314909	19074	Economy	22300.00
0005434520317	19074	Economy	22300.00
0005435314905	19074	Economy	22300.00
0005434520341	19074	Economy	22300.00
0005435314900	19074	Economy	22300.00
0005435314911	19074	Economy	22300.00
0005435314910	19074	Economy	22300.00
0005434520340	19074	Economy	22300.00
0005434520348	19074	Economy	22300.00
0005435314901	19074	Economy	22300.00
0005434520346	19074	Economy	22300.00
0005434520337	19074	Economy	22300.00
0005434520332	19074	Economy	22300.00
0005434520282	19074	Economy	22300.00
0005433874417	7791	Economy	17400.00
0005433874418	7791	Economy	17400.00
0005433874419	7791	Economy	17400.00
0005433874411	7791	Economy	17400.00
0005433874413	7791	Economy	17400.00
0005433874415	7791	Economy	17400.00
0005433874414	7791	Economy	17400.00
0005433874416	7791	Economy	17400.00
0005433874412	7791	Economy	17400.00
0005433874394	32627	Economy	19200.00
0005433874395	32627	Economy	17400.00
0005433874385	32627	Economy	17400.00
0005433874386	32627	Economy	17400.00
0005433869195	4799	Economy	19400.00
0005433869179	4799	Economy	19400.00
0005433869188	4799	Economy	19400.00
0005433869199	4799	Economy	19400.00
0005433869186	4799	Economy	17600.00
0005433869171	4799	Economy	17600.00
0005433869167	4799	Economy	17600.00
0005433869190	4799	Economy	17600.00
0005433869177	4799	Economy	17600.00
0005435860508	4799	Economy	17600.00
0005433869198	4799	Economy	17600.00
0005433869173	4799	Economy	17600.00
0005433869172	4799	Economy	17600.00
0005433869180	4799	Economy	17600.00
0005433869161	4799	Economy	17600.00
0005433869183	4799	Economy	17600.00
0005433869163	4799	Economy	17600.00
0005433869176	4799	Economy	17600.00
0005433869168	4799	Economy	17600.00
0005433869170	4799	Economy	17600.00
0005433869185	4799	Economy	17600.00
0005433869169	4799	Economy	17600.00
0005433869189	4799	Economy	17600.00
0005433869164	4799	Economy	17600.00
0005433869162	4799	Economy	17600.00
0005433869178	4799	Economy	17600.00
0005433869196	4799	Economy	17600.00
0005433869174	4799	Economy	17600.00
0005433869160	4799	Economy	17600.00
0005433869193	4799	Economy	17600.00
0005433869200	4799	Economy	17600.00
0005433869166	4799	Economy	17600.00
0005433869182	4799	Economy	17600.00
0005433869181	4799	Economy	17600.00
0005433869184	4799	Economy	17600.00
0005433869187	4799	Economy	17600.00
0005433869191	4799	Economy	17600.00
0005433869194	4799	Economy	17600.00
0005435860512	4799	Economy	17600.00
0005433869165	4799	Economy	17600.00
0005433869192	4799	Economy	17600.00
0005433869197	4799	Economy	17600.00
0005433869201	4799	Economy	17600.00
0005433869175	4799	Economy	17600.00
0005433868760	32601	Economy	19400.00
0005433868825	32601	Economy	19400.00
0005433868774	32601	Economy	19400.00
0005433868820	32601	Economy	19400.00
0005433868769	32601	Economy	17600.00
0005433868640	32601	Economy	17600.00
0005433868740	32601	Economy	17600.00
0005433868639	32601	Economy	17600.00
0005433868691	32601	Economy	17600.00
0005433868709	32601	Economy	17600.00
0005433868743	32601	Economy	17600.00
0005433868851	32601	Economy	17600.00
0005433868807	32601	Economy	17600.00
0005433868872	32601	Economy	17600.00
0005433868850	32601	Economy	17600.00
0005433868828	32601	Economy	17600.00
0005433868829	32601	Economy	17600.00
0005433868610	32601	Economy	17600.00
0005433868824	32601	Economy	17600.00
0005433868634	32601	Economy	17600.00
0005433868821	32601	Economy	17600.00
0005433868748	32601	Economy	17600.00
0005433868838	32601	Economy	17600.00
0005433868891	32601	Economy	17600.00
0005433868802	32601	Economy	17600.00
0005433868823	32601	Economy	17600.00
0005433868600	32601	Economy	17600.00
0005433868718	32601	Economy	17600.00
0005433868801	32601	Economy	17600.00
0005433868852	32601	Economy	17600.00
0005433868761	32601	Economy	17600.00
0005433868827	32601	Economy	17600.00
0005433868806	32601	Economy	17600.00
0005433868633	32601	Economy	17600.00
0005433868783	32601	Economy	17600.00
0005433868711	32601	Economy	17600.00
0005433868692	32601	Economy	17600.00
0005433868849	32601	Economy	17600.00
0005433868762	32601	Economy	17600.00
0005433868784	32601	Economy	17600.00
0005433868848	32601	Economy	17600.00
0005433868803	32601	Economy	17600.00
0005433868764	32601	Economy	17600.00
0005433868873	32601	Economy	17600.00
0005433868822	32601	Economy	17600.00
0005433868710	32601	Economy	17600.00
0005433868810	32601	Economy	17600.00
0005433868635	32601	Economy	17600.00
0005433868741	32601	Economy	17600.00
0005434461688	3431	Economy	24800.00
0005434663661	3431	Economy	24800.00
0005434663659	3431	Economy	22600.00
0005434663657	3431	Economy	22600.00
0005434663663	3431	Economy	22600.00
0005435911524	3431	Economy	22600.00
0005434663665	3431	Economy	22600.00
0005434663662	3431	Economy	22600.00
0005435911552	3431	Economy	22600.00
0005435911503	3431	Economy	22600.00
0005434663655	3431	Economy	22600.00
0005434663664	3431	Economy	22600.00
0005435911543	3431	Economy	22600.00
0005434663666	3431	Economy	22600.00
0005434663660	3431	Economy	22600.00
0005434663654	3431	Economy	22600.00
0005434460545	3431	Economy	22600.00
0005434461687	3431	Economy	22600.00
0005434663656	3431	Economy	22600.00
0005435911509	3431	Economy	22600.00
0005434663658	3431	Economy	22600.00
0005434460546	3431	Economy	22600.00
0005434663536	12443	Economy	24800.00
0005434663564	12443	Economy	24800.00
0005434663518	12443	Economy	24800.00
0005434663555	12443	Economy	24800.00
0005434663610	12443	Economy	22600.00
0005434663544	12443	Economy	22600.00
0005434462806	12443	Economy	22600.00
0005434462807	12443	Economy	22600.00
0005434462799	12443	Economy	22600.00
0005434462796	12443	Economy	22600.00
0005434663585	12443	Economy	22600.00
0005434460526	12443	Economy	22600.00
0005434663608	12443	Economy	22600.00
0005434460521	12443	Economy	22600.00
0005435911591	12443	Economy	22600.00
0005434663543	12443	Economy	22600.00
0005435911596	12443	Economy	22600.00
0005434663553	12443	Economy	22600.00
0005434663578	12443	Economy	22600.00
0005435911595	12443	Economy	22600.00
0005434462795	12443	Economy	22600.00
0005435911590	12443	Economy	22600.00
0005434663609	12443	Economy	22600.00
0005434663524	12443	Economy	22600.00
0005434462797	12443	Economy	22600.00
0005435911593	12443	Economy	22600.00
0005435911597	12443	Economy	22600.00
0005434663519	12443	Economy	22600.00
0005434663579	12443	Economy	22600.00
0005434460517	12443	Economy	22600.00
0005434663607	12443	Economy	22600.00
0005434462810	12443	Economy	22600.00
0005435911594	12443	Economy	22600.00
0005434460524	12443	Economy	22600.00
0005434663580	12443	Economy	22600.00
0005434663548	12443	Economy	22600.00
0005434663554	12443	Economy	22600.00
0005434663534	12443	Economy	22600.00
0005435911592	12443	Economy	22600.00
0005434462804	12443	Economy	22600.00
0005434460522	12443	Economy	22600.00
0005434460500	12443	Economy	22600.00
0005434462808	12443	Economy	22600.00
0005433868820	14492	Economy	18500.00
0005433868849	14492	Economy	18500.00
0005433868600	14492	Economy	18500.00
0005433868803	14492	Economy	18500.00
0005433868828	14492	Economy	16800.00
0005433868801	14492	Economy	16800.00
0005433868691	14492	Economy	16800.00
0005433868825	14492	Economy	16800.00
0005433868810	14492	Economy	16800.00
0005433868711	14492	Economy	16800.00
0005433868806	14492	Economy	16800.00
0005433868634	14492	Economy	16800.00
0005433868873	14492	Economy	16800.00
0005433868891	14492	Economy	16800.00
0005433868709	14492	Economy	16800.00
0005433868838	14492	Economy	16800.00
0005433868822	14492	Economy	16800.00
0005433868761	14492	Economy	16800.00
0005433868851	14492	Economy	16800.00
0005433868769	14492	Economy	16800.00
0005433868807	14492	Economy	16800.00
0005433868640	14492	Economy	16800.00
0005433868821	14492	Economy	16800.00
0005433868710	14492	Economy	16800.00
0005433868774	14492	Economy	16800.00
0005433868784	14492	Economy	16800.00
0005433868633	14492	Economy	16800.00
0005433868802	14492	Economy	16800.00
0005433868762	14492	Economy	16800.00
0005433868824	14492	Economy	16800.00
0005433868692	14492	Economy	16800.00
0005433868610	14492	Economy	16800.00
0005433868850	14492	Economy	16800.00
0005433868743	14492	Economy	16800.00
0005433868748	14492	Economy	16800.00
0005433868872	14492	Economy	16800.00
0005433868635	14492	Economy	16800.00
0005433868852	14492	Economy	16800.00
0005433868741	14492	Economy	16800.00
0005433868760	14492	Economy	16800.00
0005433868783	14492	Economy	16800.00
0005433868827	14492	Economy	16800.00
0005433868764	14492	Economy	16800.00
0005433868639	14492	Economy	16800.00
0005433868740	14492	Economy	16800.00
0005433868823	14492	Economy	16800.00
0005433868718	14492	Economy	16800.00
0005433868829	14492	Economy	16800.00
0005433868848	14492	Economy	16800.00
0005433869154	32701	Economy	18500.00
0005433869155	32701	Economy	18500.00
0005433869135	32701	Economy	18500.00
0005433869132	32701	Economy	18500.00
0005433869121	32701	Economy	16800.00
0005433869138	32701	Economy	16800.00
0005433869125	32701	Economy	16800.00
0005433869141	32701	Economy	16800.00
0005435860513	32701	Economy	16800.00
0005435860510	32701	Economy	16800.00
0005435860506	32701	Economy	16800.00
0005433869152	32701	Economy	16800.00
0005433869129	32701	Economy	16800.00
0005433869126	32701	Economy	16800.00
0005433869156	32701	Economy	16800.00
0005433869137	32701	Economy	16800.00
0005433869122	32701	Economy	16800.00
0005433869159	32701	Economy	16800.00
0005433869158	32701	Economy	16800.00
0005433869146	32701	Economy	16800.00
0005433869145	32701	Economy	16800.00
0005433869124	32701	Economy	16800.00
0005433869140	32701	Economy	16800.00
0005433869134	32701	Economy	16800.00
0005433869130	32701	Economy	16800.00
0005433869123	32701	Economy	16800.00
0005433869149	32701	Economy	16800.00
0005433869139	32701	Economy	16800.00
0005433869144	32701	Economy	16800.00
0005433869150	32701	Economy	16800.00
0005433869142	32701	Economy	16800.00
0005433869128	32701	Economy	16800.00
0005433869136	32701	Economy	16800.00
0005433869143	32701	Economy	16800.00
0005433869133	32701	Economy	16800.00
0005433869147	32701	Economy	16800.00
0005433869148	32701	Economy	16800.00
0005433869131	32701	Economy	16800.00
0005433869157	32701	Economy	16800.00
0005433869153	32701	Economy	16800.00
0005433869151	32701	Economy	16800.00
0005433869127	32701	Economy	16800.00
0005432799801	12149	Economy	4900.00
0005432799811	12149	Economy	4900.00
0005432799785	12149	Economy	4900.00
0005432799692	12149	Economy	4900.00
0005432799741	12149	Economy	4400.00
0005432799738	12149	Economy	4400.00
0005432799751	12149	Economy	4400.00
0005432799731	12149	Economy	4400.00
0005432799748	12149	Economy	4400.00
0005432799740	12149	Economy	4400.00
0005432799794	12149	Economy	4400.00
0005432799758	12149	Economy	4400.00
0005432799719	12149	Economy	4400.00
0005432799661	12149	Economy	4400.00
0005432799744	12149	Economy	4400.00
0005432799680	12149	Economy	4400.00
0005432799729	12149	Economy	4400.00
0005432799645	12149	Economy	4400.00
0005432799765	12149	Economy	4400.00
0005432799797	12149	Economy	4400.00
0005432799783	12149	Economy	4400.00
0005432799742	12149	Economy	4400.00
0005432799734	12149	Economy	4400.00
0005432799730	12149	Economy	4400.00
0005432799670	12149	Economy	4400.00
0005432799764	12149	Economy	4400.00
0005432799784	12149	Economy	4400.00
0005432799688	12149	Economy	4400.00
0005432799646	12149	Economy	4400.00
0005432799743	12149	Economy	4400.00
0005432799679	12149	Economy	4400.00
0005432799778	12149	Economy	4400.00
0005432799802	12149	Economy	4400.00
0005432799662	12149	Economy	4400.00
0005432799735	12149	Economy	4400.00
0005432799957	14784	Economy	4900.00
0005432799950	14784	Economy	4900.00
0005432799963	14784	Economy	4900.00
0005432799938	14784	Economy	4400.00
0005432799960	14784	Economy	4400.00
0005432799956	14784	Economy	4400.00
0005432799946	14784	Economy	4400.00
0005432799937	14784	Economy	4400.00
0005432799958	14784	Economy	4400.00
0005432799964	14784	Economy	4400.00
0005432799945	14784	Economy	4400.00
0005432799959	14784	Economy	4400.00
0005432799961	14784	Economy	4400.00
0005432799953	14784	Economy	4400.00
0005432799943	14784	Economy	4400.00
0005432799955	14784	Economy	4400.00
0005432799940	14784	Economy	4400.00
0005432799944	14784	Economy	4400.00
0005432799962	14784	Economy	4400.00
0005432799942	14784	Economy	4400.00
0005432799948	14784	Economy	4400.00
0005432799949	14784	Economy	4400.00
0005432799951	14784	Economy	4400.00
0005432799954	14784	Economy	4400.00
0005432799939	14784	Economy	4400.00
0005432799941	14784	Economy	4400.00
0005432799952	14784	Economy	4400.00
0005432799947	14784	Economy	4400.00
0005435293367	7084	Business	49100.00
0005434300004	7084	Business	49100.00
0005434408961	7084	Business	49100.00
0005434408932	7084	Business	49100.00
0005434408917	7084	Business	49100.00
0005434408933	7084	Business	49100.00
0005434408907	7084	Business	49100.00
0005434408944	7084	Business	49100.00
0005434408959	7084	Business	49100.00
0005434299998	7084	Business	49100.00
0005434299981	7084	Business	49100.00
0005432108297	7084	Economy	16400.00
0005434299992	7084	Economy	16400.00
0005434408930	7084	Economy	16400.00
0005434408913	7084	Economy	16400.00
0005434408960	7084	Economy	16400.00
0005435293359	7084	Economy	16400.00
0005434299989	7084	Economy	16400.00
0005434299993	7084	Economy	16400.00
0005434408946	7084	Economy	16400.00
0005432154065	7084	Economy	16400.00
0005435293356	7084	Economy	16400.00
0005434299980	7084	Economy	16400.00
0005435293397	7084	Economy	16400.00
0005435311158	7084	Economy	16400.00
0005434299982	7084	Economy	16400.00
0005434408943	7084	Economy	16400.00
0005434408905	7084	Economy	16400.00
0005435293387	7084	Economy	16400.00
0005434408962	7084	Economy	16400.00
0005434408947	7084	Economy	16400.00
0005434408952	7084	Economy	16400.00
0005435311139	7084	Economy	16400.00
0005434408903	7084	Economy	16400.00
0005434299983	7084	Economy	16400.00
0005434299991	7084	Economy	16400.00
0005434408948	7084	Economy	16400.00
0005434408904	7084	Economy	16400.00
0005434408919	7084	Economy	16400.00
0005434408935	7084	Economy	16400.00
0005432108299	7084	Economy	16400.00
0005432154069	7084	Economy	16400.00
0005432154070	7084	Economy	16400.00
0005434299997	7084	Economy	16400.00
0005434408937	7084	Economy	16400.00
0005435293357	7084	Economy	16400.00
0005432154066	7084	Economy	16400.00
0005434408963	7084	Economy	16400.00
0005434299987	7084	Economy	18000.00
0005434299990	7084	Economy	16400.00
0005434408938	7084	Economy	18000.00
0005434408949	7084	Economy	18000.00
0005435293407	7084	Economy	18000.00
0005434300002	7084	Economy	18000.00
0005434408921	7084	Economy	18000.00
0005434408911	7084	Economy	16400.00
0005434408902	7084	Economy	16400.00
0005435293369	7084	Economy	16400.00
0005434299995	7084	Economy	16400.00
0005434299996	7084	Economy	16400.00
0005434408927	7084	Economy	16400.00
0005434408914	7084	Economy	16400.00
0005434408945	7084	Economy	16400.00
0005434408929	7084	Economy	16400.00
0005434299994	7084	Economy	16400.00
0005434300001	7084	Economy	16400.00
0005435311162	7084	Economy	16400.00
0005435293366	7084	Economy	16400.00
0005434408931	7084	Economy	16400.00
0005434408922	7084	Economy	16400.00
0005432108298	7084	Economy	16400.00
0005434299999	7084	Economy	16400.00
0005434408926	7084	Economy	16400.00
0005432154068	7084	Economy	16400.00
0005434408955	7084	Economy	16400.00
0005434408901	7084	Economy	16400.00
0005434408951	7084	Economy	16400.00
0005435293392	7084	Economy	16400.00
0005434408940	7084	Economy	16400.00
0005434408912	7084	Economy	16400.00
0005434299988	7084	Economy	16400.00
0005434408950	7084	Economy	16400.00
0005434408958	7084	Economy	16400.00
0005435311157	7084	Economy	16400.00
0005434408915	7084	Economy	16400.00
0005434408918	7084	Economy	16400.00
0005432154071	7084	Economy	16400.00
0005434408942	7084	Economy	16400.00
0005435311151	7084	Economy	16400.00
0005434408953	7084	Economy	16400.00
0005434408910	7084	Economy	16400.00
0005435311140	7084	Economy	16400.00
0005434408934	7084	Economy	16400.00
0005432154067	7084	Economy	16400.00
0005434408925	7084	Economy	16400.00
0005434408923	7084	Economy	16400.00
0005434299984	7084	Economy	16400.00
0005434408908	7084	Economy	16400.00
0005434300003	7084	Economy	16400.00
0005434408939	7084	Economy	16400.00
0005434299986	7084	Economy	16400.00
0005434408957	7084	Economy	16400.00
0005434300000	7084	Economy	16400.00
0005434408920	7084	Economy	16400.00
0005434408941	7084	Economy	16400.00
0005435293406	7084	Economy	16400.00
0005435311087	7084	Economy	16400.00
0005434408954	7084	Economy	16400.00
0005434408909	7084	Economy	16400.00
0005434408924	7084	Economy	16400.00
0005434408936	7084	Economy	16400.00
0005434408964	7084	Economy	16400.00
0005434408956	7084	Economy	16400.00
0005434408928	7084	Economy	16400.00
0005435293368	7084	Economy	16400.00
0005434408906	7084	Economy	16400.00
0005434299985	7084	Economy	16400.00
0005434408916	7084	Economy	16400.00
0005434408230	26911	Business	49100.00
0005435311280	26911	Business	49100.00
0005435311278	26911	Business	49100.00
0005434408232	26911	Business	49100.00
0005434299806	26911	Business	49100.00
0005434408281	26911	Business	49100.00
0005434408263	26911	Business	49100.00
0005434299794	26911	Business	49100.00
0005434299786	26911	Business	49100.00
0005432058450	26911	Business	49100.00
0005434407822	26911	Business	49100.00
0005434408611	26911	Business	49100.00
0005434299819	26911	Economy	16400.00
0005434408510	26911	Economy	16400.00
0005434408440	26911	Economy	16400.00
0005434299787	26911	Economy	16400.00
0005434408143	26911	Economy	16400.00
0005435311288	26911	Economy	16400.00
0005434408533	26911	Economy	16400.00
0005434408280	26911	Economy	16400.00
0005432058451	26911	Economy	16400.00
0005434408330	26911	Economy	16400.00
0005434408257	26911	Economy	16400.00
0005435293485	26911	Economy	16400.00
0005435293483	26911	Economy	16400.00
0005434408233	26911	Economy	16400.00
0005434408321	26911	Economy	16400.00
0005434408146	26911	Economy	16400.00
0005434408496	26911	Economy	16400.00
0005434408210	26911	Economy	16400.00
0005434408337	26911	Economy	16400.00
0005435311282	26911	Economy	16400.00
0005434299792	26911	Economy	16400.00
0005434408194	26911	Economy	16400.00
0005434408535	26911	Economy	16400.00
0005434299688	26911	Economy	16400.00
0005434408231	26911	Economy	16400.00
0005434408136	26911	Economy	16400.00
0005435293478	26911	Economy	16400.00
0005434408234	26911	Economy	16400.00
0005434408320	26911	Economy	16400.00
0005434408385	26911	Economy	16400.00
0005434408378	26911	Economy	16400.00
0005434408448	26911	Economy	16400.00
0005435293486	26911	Economy	16400.00
0005434299798	26911	Economy	16400.00
0005435293481	26911	Economy	16400.00
0005435311279	26911	Economy	16400.00
0005434408264	26911	Economy	16400.00
0005434408142	26911	Economy	16400.00
0005432058452	26911	Economy	16400.00
0005434299847	26911	Economy	16400.00
0005434408509	26911	Economy	18000.00
0005434299848	26911	Economy	18000.00
0005434299879	26911	Economy	18000.00
0005434408148	26911	Economy	18000.00
0005434408360	26911	Economy	18000.00
0005435311287	26911	Economy	18000.00
0005434408250	26911	Economy	16400.00
0005434299977	26911	Economy	16400.00
0005434408326	26911	Economy	16400.00
0005434299777	26911	Economy	16400.00
0005434408180	26911	Economy	16400.00
0005434408329	26911	Economy	16400.00
0005434408244	26911	Economy	16400.00
0005434299743	26911	Economy	16400.00
0005435311286	26911	Economy	16400.00
0005434299816	26911	Economy	16400.00
0005434408199	26911	Economy	16400.00
0005434408683	26911	Economy	16400.00
0005434408517	26911	Economy	16400.00
0005434299808	26911	Economy	16400.00
0005435293490	26911	Economy	16400.00
0005434408445	26911	Economy	16400.00
0005434408181	26911	Economy	16400.00
0005435311276	26911	Economy	16400.00
0005434407823	26911	Economy	16400.00
0005434408519	26911	Economy	16400.00
0005435293480	26911	Economy	16400.00
0005434408184	26911	Economy	16400.00
0005434408391	26911	Economy	16400.00
0005434299818	26911	Economy	16400.00
0005434408302	26911	Economy	16400.00
0005435293484	26911	Economy	16400.00
0005435311289	26911	Economy	16400.00
0005434299793	26911	Economy	16400.00
0005434408390	26911	Economy	16400.00
0005435311275	26911	Economy	16400.00
0005434408436	26911	Economy	16400.00
0005435293488	26911	Economy	16400.00
0005434408394	26911	Economy	16400.00
0005435311277	26911	Economy	16400.00
0005434408193	26911	Economy	16400.00
0005434299767	26911	Economy	16400.00
0005434408494	26911	Economy	16400.00
0005435293482	26911	Economy	16400.00
0005434299747	26911	Economy	16400.00
0005435293489	26911	Economy	16400.00
0005435311285	26911	Economy	16400.00
0005434408256	26911	Economy	16400.00
0005434408262	26911	Economy	16400.00
0005434408336	26911	Economy	16400.00
0005434408384	26911	Economy	16400.00
0005434408092	26911	Economy	16400.00
0005434408299	26911	Economy	16400.00
0005434408534	26911	Economy	16400.00
0005434299849	26911	Economy	16400.00
0005435311284	26911	Economy	16400.00
0005435311283	26911	Economy	16400.00
0005432058449	26911	Economy	16400.00
0005434408183	26911	Economy	16400.00
0005434408318	26911	Economy	16400.00
0005434408243	26911	Economy	16400.00
0005434408482	26911	Economy	16400.00
0005434408612	26911	Economy	16400.00
0005434408447	26911	Economy	16400.00
0005434408393	26911	Economy	16400.00
0005434408439	26911	Economy	16400.00
0005434408518	26911	Economy	16400.00
0005434408338	26911	Economy	16400.00
0005434408325	26911	Economy	16400.00
0005434408147	26911	Economy	16400.00
0005435311281	26911	Economy	16400.00
0005434299852	26911	Economy	16400.00
0005435293479	26911	Economy	16400.00
0005435293487	26911	Economy	16400.00
0005434299797	26911	Economy	16400.00
0005434408273	26911	Economy	16400.00
0005432605081	6439	Economy	16500.00
0005432605071	6439	Economy	16500.00
0005432605079	6439	Economy	16500.00
0005432605074	6439	Economy	16500.00
0005432605080	6439	Economy	15000.00
0005432605073	6439	Economy	15000.00
0005432605069	6439	Economy	15000.00
0005432605076	6439	Economy	15000.00
0005432605083	6439	Economy	15000.00
0005435218122	6439	Economy	15000.00
0005432605064	6439	Economy	15000.00
0005432605068	6439	Economy	15000.00
0005432605089	6439	Economy	15000.00
0005432605070	6439	Economy	15000.00
0005432605085	6439	Economy	15000.00
0005432605093	6439	Economy	15000.00
0005434512204	6439	Economy	15000.00
0005432605078	6439	Economy	15000.00
0005432605082	6439	Economy	15000.00
0005432605067	6439	Economy	15000.00
0005432605091	6439	Economy	15000.00
0005432605092	6439	Economy	15000.00
0005434512205	6439	Economy	15000.00
0005432605086	6439	Economy	15000.00
0005432605066	6439	Economy	15000.00
0005434512206	6439	Economy	15000.00
0005432605087	6439	Economy	15000.00
0005432605075	6439	Economy	15000.00
0005432605101	6439	Economy	15000.00
0005432605095	6439	Economy	15000.00
0005432605063	6439	Economy	15000.00
0005434512208	6439	Economy	15000.00
0005434512209	6439	Economy	15000.00
0005432605096	6439	Economy	15000.00
0005432605065	6439	Economy	15000.00
0005432605090	6439	Economy	15000.00
0005432605100	6439	Economy	15000.00
0005432605088	6439	Economy	15000.00
0005432605084	6439	Economy	15000.00
0005432605099	6439	Economy	15000.00
0005432605097	6439	Economy	15000.00
0005432605072	6439	Economy	15000.00
0005434512207	6439	Economy	15000.00
0005432605077	6439	Economy	15000.00
0005432605098	6439	Economy	15000.00
0005432605062	6439	Economy	15000.00
0005435220492	6439	Economy	15000.00
0005432605094	6439	Economy	15000.00
0005432604660	21377	Economy	16500.00
0005432604826	21377	Economy	16500.00
0005432604638	21377	Economy	16500.00
0005432604889	21377	Economy	16500.00
0005435221548	21377	Economy	15000.00
0005435221529	21377	Economy	15000.00
0005434512179	21377	Economy	15000.00
0005434512157	21377	Economy	15000.00
0005432604675	21377	Economy	15000.00
0005434512147	21377	Economy	15000.00
0005432604765	21377	Economy	15000.00
0005432604520	21377	Economy	15000.00
0005432604756	21377	Economy	15000.00
0005432604849	21377	Economy	15000.00
0005434512154	21377	Economy	15000.00
0005432604808	21377	Economy	15000.00
0005432604556	21377	Economy	15000.00
0005432604674	21377	Economy	15000.00
0005435312895	21377	Economy	15000.00
0005432604541	21377	Economy	15000.00
0005432604544	21377	Economy	15000.00
0005432604778	21377	Economy	15000.00
0005435221528	21377	Economy	15000.00
0005432604894	21377	Economy	15000.00
0005432604618	21377	Economy	15000.00
0005432604616	21377	Economy	15000.00
0005434512163	21377	Economy	15000.00
0005435312896	21377	Economy	15000.00
0005432604708	21377	Economy	15000.00
0005434512170	21377	Economy	15000.00
0005432604591	21377	Economy	15000.00
0005435221549	21377	Economy	15000.00
0005432604617	21377	Economy	15000.00
0005432604692	21377	Economy	15000.00
0005434512155	21377	Economy	15000.00
0005432604777	21377	Economy	15000.00
0005432604746	21377	Economy	15000.00
0005432604668	21377	Economy	15000.00
0005434512133	21377	Economy	15000.00
0005435312898	21377	Economy	15000.00
0005432604728	21377	Economy	15000.00
0005432604785	21377	Economy	15000.00
0005435221071	21377	Economy	15000.00
0005432604655	21377	Economy	15000.00
0005434512180	21377	Economy	15000.00
0005432604895	21377	Economy	15000.00
0005432604543	21377	Economy	15000.00
0005435312897	21377	Economy	15000.00
0005434907903	15013	Business	18900.00
0005433252060	15013	Business	18900.00
0005434907772	15013	Business	18900.00
0005434907787	15013	Business	18900.00
0005433252034	15013	Business	18900.00
0005434907857	15013	Business	18900.00
0005434907729	15013	Business	18900.00
0005434907750	15013	Business	18900.00
0005433252038	15013	Business	18900.00
0005434907871	15013	Economy	6300.00
0005434907867	15013	Economy	6300.00
0005434907758	15013	Economy	6300.00
0005434907918	15013	Economy	6300.00
0005433252041	15013	Economy	6300.00
0005434907551	15013	Economy	6300.00
0005434907919	15013	Economy	6300.00
0005433252035	15013	Economy	6300.00
0005434907544	15013	Economy	6300.00
0005434907665	15013	Economy	6300.00
0005434907790	15013	Economy	6900.00
0005433252048	15013	Economy	6900.00
0005433252056	15013	Economy	6900.00
0005433252054	15013	Economy	6900.00
0005433252044	15013	Economy	6900.00
0005433252065	15013	Economy	6300.00
0005434907686	15013	Economy	6300.00
0005434907860	15013	Economy	6300.00
0005434907757	15013	Economy	6300.00
0005434907614	15013	Economy	6300.00
0005434907887	15013	Economy	6300.00
0005434907794	15013	Economy	6300.00
0005433252058	15013	Economy	6300.00
0005434907546	15013	Economy	6300.00
0005433252043	15013	Economy	6300.00
0005434907651	15013	Economy	6300.00
0005433252039	15013	Economy	6300.00
0005434907866	15013	Economy	6300.00
0005434907596	15013	Economy	6300.00
0005434907818	15013	Economy	6300.00
0005433252059	15013	Economy	6300.00
0005433252064	15013	Economy	6300.00
0005433252047	15013	Economy	6300.00
0005434907924	15013	Economy	6300.00
0005434907713	15013	Economy	6300.00
0005433252040	15013	Economy	6300.00
0005434907821	15013	Economy	6300.00
0005434907930	15013	Economy	6300.00
0005433252053	15013	Economy	6300.00
0005434907731	15013	Economy	6300.00
0005433252051	15013	Economy	6300.00
0005433252057	15013	Economy	6300.00
0005434907929	15013	Economy	6300.00
0005434907774	15013	Economy	6300.00
0005434907666	15013	Economy	6300.00
0005433252042	15013	Economy	6300.00
0005434907788	15013	Economy	6300.00
0005433252049	15013	Economy	6300.00
0005434907845	15013	Economy	6300.00
0005434907700	15013	Economy	6300.00
0005434907615	15013	Economy	6300.00
0005434907886	15013	Economy	6300.00
0005433252050	15013	Economy	6300.00
0005434907844	15013	Economy	6300.00
0005434907711	15013	Economy	6300.00
0005433252055	15013	Economy	6300.00
0005434907699	15013	Economy	6300.00
0005434907613	15013	Economy	6300.00
0005434907822	15013	Economy	6300.00
0005434907677	15013	Economy	6300.00
0005433252052	15013	Economy	6300.00
0005433252063	15013	Economy	6300.00
0005434907492	15013	Economy	6300.00
0005434907628	15013	Economy	6300.00
0005434907798	15013	Economy	6300.00
0005433252046	15013	Economy	6300.00
0005433252062	15013	Economy	6300.00
0005434907712	15013	Economy	6300.00
0005434907663	15013	Economy	6300.00
0005434907701	15013	Economy	6300.00
0005433252037	15013	Economy	6300.00
0005433252061	15013	Economy	6300.00
0005434907545	15013	Economy	6300.00
0005434907581	15013	Economy	6300.00
0005433252036	15013	Economy	6300.00
0005434907870	15013	Economy	6300.00
0005434907687	15013	Economy	6300.00
0005433252045	15013	Economy	6300.00
0005434908179	25844	Business	18900.00
0005433251871	25844	Business	18900.00
0005434908218	25844	Business	18900.00
0005433251836	25844	Business	18900.00
0005433251774	25844	Business	18900.00
0005433251770	25844	Business	18900.00
0005434908205	25844	Business	18900.00
0005433251777	25844	Business	18900.00
0005434908196	25844	Business	18900.00
0005433251751	25844	Business	18900.00
0005434908195	25844	Economy	6300.00
0005434908214	25844	Economy	6300.00
0005434908211	25844	Economy	6300.00
0005434908202	25844	Economy	6300.00
0005433251835	25844	Economy	6300.00
0005434908204	25844	Economy	6300.00
0005434908198	25844	Economy	6300.00
0005434908174	25844	Economy	6300.00
0005433251612	25844	Economy	6300.00
0005433251823	25844	Economy	6300.00
0005434908184	25844	Economy	6900.00
0005434908168	25844	Economy	6900.00
0005434908178	25844	Economy	6900.00
0005434908212	25844	Economy	6900.00
0005434908176	25844	Economy	6900.00
0005433251755	25844	Economy	6300.00
0005433251786	25844	Economy	6300.00
0005434908166	25844	Economy	6300.00
0005433251829	25844	Economy	6300.00
0005433251831	25844	Economy	6300.00
0005434908165	25844	Economy	6300.00
0005434908167	25844	Economy	6300.00
0005434908192	25844	Economy	6300.00
0005434908213	25844	Economy	6300.00
0005433251935	25844	Economy	6300.00
0005434908164	25844	Economy	6300.00
0005434908216	25844	Economy	6300.00
0005434908206	25844	Economy	6300.00
0005434908209	25844	Economy	6300.00
0005434908173	25844	Economy	6300.00
0005433251785	25844	Economy	6300.00
0005434908217	25844	Economy	6300.00
0005433251872	25844	Economy	6300.00
0005434908194	25844	Economy	6300.00
0005434908182	25844	Economy	6300.00
0005433251784	25844	Economy	6300.00
0005433251893	25844	Economy	6300.00
0005434908193	25844	Economy	6300.00
0005434908187	25844	Economy	6300.00
0005434908197	25844	Economy	6300.00
0005434908189	25844	Economy	6300.00
0005433251876	25844	Economy	6300.00
0005434908207	25844	Economy	6300.00
0005434908191	25844	Economy	6300.00
0005434908200	25844	Economy	6300.00
0005434908210	25844	Economy	6300.00
0005433251891	25844	Economy	6300.00
0005434908186	25844	Economy	6300.00
0005433251750	25844	Economy	6300.00
0005434908201	25844	Economy	6300.00
0005433251810	25844	Economy	6300.00
0005433251822	25844	Economy	6300.00
0005433251873	25844	Economy	6300.00
0005434908185	25844	Economy	6300.00
0005434908188	25844	Economy	6300.00
0005434908203	25844	Economy	6300.00
0005434908180	25844	Economy	6300.00
0005433251877	25844	Economy	6300.00
0005434908170	25844	Economy	6300.00
0005434908208	25844	Economy	6300.00
0005433251771	25844	Economy	6300.00
0005434908169	25844	Economy	6300.00
0005434908175	25844	Economy	6300.00
0005434908172	25844	Economy	6300.00
0005434908171	25844	Economy	6300.00
0005434908163	25844	Economy	6300.00
0005434908181	25844	Economy	6300.00
0005434908199	25844	Economy	6300.00
0005433251792	25844	Economy	6300.00
0005434908183	25844	Economy	6300.00
0005433251892	25844	Economy	6300.00
0005434908190	25844	Economy	6300.00
0005434908215	25844	Economy	6300.00
0005434908177	25844	Economy	6300.00
0005432607632	22466	Economy	16400.00
0005432609791	22466	Economy	14900.00
0005432607630	22466	Economy	14900.00
0005432607638	22466	Economy	14900.00
0005432609803	22466	Economy	14900.00
0005432609798	22466	Economy	14900.00
0005432607629	22466	Economy	14900.00
0005435842336	22466	Economy	14900.00
0005432607625	22466	Economy	14900.00
0005432609794	22466	Economy	14900.00
0005432609804	22466	Economy	14900.00
0005432607634	22466	Economy	14900.00
0005432609795	22466	Economy	14900.00
0005432609792	22466	Economy	14900.00
0005432609805	22466	Economy	14900.00
0005432609801	22466	Economy	14900.00
0005432607639	22466	Economy	14900.00
0005432607637	22466	Economy	14900.00
0005432609789	22466	Economy	14900.00
0005432609796	22466	Economy	14900.00
0005432609800	22466	Economy	14900.00
0005432609802	22466	Economy	14900.00
0005432607640	22466	Economy	14900.00
0005432607631	22466	Economy	14900.00
0005432607642	22466	Economy	14900.00
0005432607633	22466	Economy	14900.00
0005432607636	22466	Economy	14900.00
0005432609790	22466	Economy	14900.00
0005432607628	22466	Economy	14900.00
0005432609797	22466	Economy	14900.00
0005432607641	22466	Economy	14900.00
0005432609793	22466	Economy	14900.00
0005432609799	22466	Economy	14900.00
0005432607626	22466	Economy	14900.00
0005432607624	22466	Economy	14900.00
0005432607635	22466	Economy	14900.00
0005435842335	22466	Economy	14900.00
0005432607627	22466	Economy	14900.00
0005432613911	31723	Economy	16400.00
0005432609752	31723	Economy	16400.00
0005432609760	31723	Economy	16400.00
0005435841117	31723	Economy	14900.00
0005432609763	31723	Economy	14900.00
0005432609766	31723	Economy	14900.00
0005432613904	31723	Economy	14900.00
0005435841486	31723	Economy	14900.00
0005435841485	31723	Economy	14900.00
0005432609771	31723	Economy	14900.00
0005435841112	31723	Economy	14900.00
0005435841483	31723	Economy	14900.00
0005435841118	31723	Economy	14900.00
0005432609748	31723	Economy	14900.00
0005432609747	31723	Economy	14900.00
0005435841116	31723	Economy	14900.00
0005435841487	31723	Economy	14900.00
0005432613898	31723	Economy	14900.00
0005435841114	31723	Economy	14900.00
0005432609753	31723	Economy	14900.00
0005432609770	31723	Economy	14900.00
0005432609751	31723	Economy	14900.00
0005432613910	31723	Economy	14900.00
0005432613882	31723	Economy	14900.00
0005432609750	31723	Economy	14900.00
0005432613886	31723	Economy	14900.00
0005432609764	31723	Economy	14900.00
0005432613887	31723	Economy	14900.00
0005432613890	31723	Economy	14900.00
0005432609754	31723	Economy	14900.00
0005432613907	31723	Economy	14900.00
0005435841111	31723	Economy	14900.00
0005435841113	31723	Economy	14900.00
0005432613905	31723	Economy	14900.00
0005432613897	31723	Economy	14900.00
0005432609765	31723	Economy	14900.00
0005435841115	31723	Economy	14900.00
0005435841484	31723	Economy	14900.00
0005432609761	31723	Economy	14900.00
0005433810570	14164	Business	52300.00
0005433009488	14164	Business	52300.00
0005433009476	14164	Business	52300.00
0005433810571	14164	Business	52300.00
0005433009456	14164	Business	52300.00
0005433009452	14164	Economy	17400.00
0005433009447	14164	Economy	17400.00
0005433009465	14164	Economy	17400.00
0005433009484	14164	Economy	17400.00
0005433009455	14164	Economy	17400.00
0005433009453	14164	Economy	19200.00
0005433009459	14164	Economy	19200.00
0005433009458	14164	Economy	19200.00
0005433009487	14164	Economy	17400.00
0005433009460	14164	Economy	17400.00
0005433009457	14164	Economy	17400.00
0005433009462	14164	Economy	17400.00
0005433009483	14164	Economy	17400.00
0005433009454	14164	Economy	17400.00
0005433009480	14164	Economy	17400.00
0005433009469	14164	Economy	17400.00
0005433009471	14164	Economy	17400.00
0005433009470	14164	Economy	17400.00
0005433009463	14164	Economy	17400.00
0005433009474	14164	Economy	17400.00
0005433009461	14164	Economy	17400.00
0005433009482	14164	Economy	17400.00
0005433009481	14164	Economy	17400.00
0005433009489	14164	Economy	17400.00
0005433009451	14164	Economy	17400.00
0005433009467	14164	Economy	17400.00
0005433009475	14164	Economy	17400.00
0005433009448	14164	Economy	17400.00
0005433009485	14164	Economy	17400.00
0005433009466	14164	Economy	17400.00
0005433009473	14164	Economy	17400.00
0005433810579	14164	Economy	17400.00
0005433009477	14164	Economy	17400.00
0005433009478	14164	Economy	17400.00
0005433009449	14164	Economy	17400.00
0005433009468	14164	Economy	17400.00
0005433009450	14164	Economy	17400.00
0005433009472	14164	Economy	17400.00
0005433009486	14164	Economy	17400.00
0005433009446	14164	Economy	17400.00
0005433009464	14164	Economy	17400.00
0005433009490	14164	Economy	17400.00
0005433009479	14164	Economy	17400.00
0005433009491	14164	Economy	17400.00
0005433810614	22822	Business	52300.00
0005433009111	22822	Business	52300.00
0005433009008	22822	Business	52300.00
0005433810615	22822	Business	52300.00
0005433009080	22822	Business	52300.00
0005433009059	22822	Business	52300.00
0005433009063	22822	Economy	17400.00
0005433009081	22822	Economy	17400.00
0005433008977	22822	Economy	17400.00
0005433008931	22822	Economy	17400.00
0005433009026	22822	Economy	17400.00
0005433009051	22822	Economy	17400.00
0005433009138	22822	Economy	17400.00
0005433008918	22822	Economy	19200.00
0005433008976	22822	Economy	19200.00
0005433009062	22822	Economy	19200.00
0005433009067	22822	Economy	17400.00
0005433008907	22822	Economy	17400.00
0005433008997	22822	Economy	17400.00
0005433008970	22822	Economy	17400.00
0005433009017	22822	Economy	17400.00
0005433008981	22822	Economy	17400.00
0005433009131	22822	Economy	17400.00
0005433008919	22822	Economy	17400.00
0005433009024	22822	Economy	17400.00
0005433008982	22822	Economy	17400.00
0005433008980	22822	Economy	17400.00
0005433008960	22822	Economy	17400.00
0005433009007	22822	Economy	17400.00
0005433009132	22822	Economy	17400.00
0005433008983	22822	Economy	17400.00
0005433009110	22822	Economy	17400.00
0005433009047	22822	Economy	17400.00
0005433008971	22822	Economy	17400.00
0005433008962	22822	Economy	17400.00
0005433009096	22822	Economy	17400.00
0005433008979	22822	Economy	17400.00
0005433008961	22822	Economy	17400.00
0005433009149	22822	Economy	17400.00
0005433009010	22822	Economy	17400.00
0005433008932	22822	Economy	17400.00
0005433009058	22822	Economy	17400.00
0005433008963	22822	Economy	17400.00
0005433008846	22822	Economy	17400.00
0005433008910	22822	Economy	17400.00
0005433009148	22822	Economy	17400.00
0005433009077	22822	Economy	17400.00
0005433009009	22822	Economy	17400.00
0005434926118	14965	Business	22900.00
0005434926018	14965	Business	22900.00
0005434926133	14965	Business	22900.00
0005434926041	14965	Business	22900.00
0005434926061	14965	Business	22900.00
0005434926074	14965	Economy	7600.00
0005434926194	14965	Economy	7600.00
0005434925986	14965	Economy	7600.00
0005434926081	14965	Economy	7600.00
0005434926160	14965	Economy	8400.00
0005434926164	14965	Economy	8400.00
0005434926169	14965	Economy	7600.00
0005434926027	14965	Economy	7600.00
0005434926040	14965	Economy	7600.00
0005434926195	14965	Economy	7600.00
0005434926131	14965	Economy	7600.00
0005434926145	14965	Economy	7600.00
0005434926102	14965	Economy	7600.00
0005434926109	14965	Economy	7600.00
0005434926069	14965	Economy	7600.00
0005434926168	14965	Economy	7600.00
0005434925896	14965	Economy	7600.00
0005434926076	14965	Economy	7600.00
0005434926039	14965	Economy	7600.00
0005434926015	14965	Economy	7600.00
0005434926134	14965	Economy	7600.00
0005434926026	14965	Economy	7600.00
0005434926101	14965	Economy	7600.00
0005434926357	20533	Business	22900.00
0005434926354	20533	Business	22900.00
0005434926371	20533	Economy	7600.00
0005434926356	20533	Economy	7600.00
0005434926349	20533	Economy	7600.00
0005434926368	20533	Economy	7600.00
0005434926366	20533	Economy	7600.00
0005434926362	20533	Economy	7600.00
0005434926352	20533	Economy	7600.00
0005434926365	20533	Economy	7600.00
0005434926364	20533	Economy	7600.00
0005434926348	20533	Economy	7600.00
0005434926359	20533	Economy	7600.00
0005434926346	20533	Economy	7600.00
0005434926363	20533	Economy	7600.00
0005434926344	20533	Economy	7600.00
0005434926343	20533	Economy	7600.00
0005434926347	20533	Economy	7600.00
0005434926360	20533	Economy	7600.00
0005434926370	20533	Economy	7600.00
0005434926355	20533	Economy	7600.00
0005434926345	20533	Economy	7600.00
0005434926369	20533	Economy	7600.00
0005434926358	20533	Economy	7600.00
0005434926367	20533	Economy	7600.00
0005434926350	20533	Economy	7600.00
0005434926351	20533	Economy	7600.00
0005434926361	20533	Economy	7600.00
0005434926353	20533	Economy	7600.00
0005435488232	15816	Economy	8900.00
0005435488247	15816	Economy	8900.00
0005435488240	15816	Economy	8900.00
0005435999416	15816	Economy	8100.00
0005435999417	15816	Economy	8100.00
0005435999383	15816	Economy	8100.00
0005435488244	15816	Economy	8100.00
0005435999400	15816	Economy	8100.00
0005435488239	15816	Economy	8100.00
0005435488241	15816	Economy	8100.00
0005435999408	15816	Economy	8100.00
0005435999427	15816	Economy	8100.00
0005435488245	15816	Economy	8100.00
0005435488231	15816	Economy	8100.00
0005435999411	15816	Economy	8100.00
0005435999415	15816	Economy	8100.00
0005435488246	15816	Economy	8100.00
0005435488251	15816	Economy	8100.00
0005435488250	15816	Economy	8100.00
0005435999402	15816	Economy	8100.00
0005435999364	15816	Economy	8100.00
0005435488233	15816	Economy	8100.00
0005435488234	15816	Economy	8100.00
0005435488249	15816	Economy	8100.00
0005435999401	15816	Economy	8100.00
0005435999409	15816	Economy	8100.00
0005435488237	15816	Economy	8100.00
0005435488230	15816	Economy	8100.00
0005435488243	15816	Economy	8100.00
0005435488238	15816	Economy	8100.00
0005435488242	15816	Economy	8100.00
0005435488236	15816	Economy	8100.00
0005435488229	15816	Economy	8100.00
0005435999403	15816	Economy	8100.00
0005435999423	15816	Economy	8100.00
0005435999399	15816	Economy	8100.00
0005435999418	15816	Economy	8100.00
0005435999388	15816	Economy	8100.00
0005435488248	15816	Economy	8100.00
0005435488235	15816	Economy	8100.00
0005435999389	15816	Economy	8100.00
0005435487978	19711	Economy	8900.00
0005435488046	19711	Economy	8900.00
0005435488023	19711	Economy	8900.00
0005435999562	19711	Economy	8100.00
0005435488038	19711	Economy	8100.00
0005435999553	19711	Economy	8100.00
0005435999556	19711	Economy	8100.00
0005435488032	19711	Economy	8100.00
0005435999574	19711	Economy	8100.00
0005435487985	19711	Economy	8100.00
0005435999567	19711	Economy	8100.00
0005435487972	19711	Economy	8100.00
0005435488059	19711	Economy	8100.00
0005435999552	19711	Economy	8100.00
0005435488027	19711	Economy	8100.00
0005435999575	19711	Economy	8100.00
0005435999571	19711	Economy	8100.00
0005435999570	19711	Economy	8100.00
0005435999559	19711	Economy	8100.00
0005435999576	19711	Economy	8100.00
0005435488051	19711	Economy	8100.00
0005435999557	19711	Economy	8100.00
0005435488002	19711	Economy	8100.00
0005435487990	19711	Economy	8100.00
0005435999564	19711	Economy	8100.00
0005435999560	19711	Economy	8100.00
0005435999563	19711	Economy	8100.00
0005435999554	19711	Economy	8100.00
0005435999558	19711	Economy	8100.00
0005435999573	19711	Economy	8100.00
0005435999555	19711	Economy	8100.00
0005435999565	19711	Economy	8100.00
0005435487979	19711	Economy	8100.00
0005435999566	19711	Economy	8100.00
0005435999568	19711	Economy	8100.00
0005435999572	19711	Economy	8100.00
0005435999569	19711	Economy	8100.00
0005435999561	19711	Economy	8100.00
0005435839991	6008	Business	199300.00
0005432142310	6008	Business	199300.00
0005435472962	6008	Business	199300.00
0005435839979	6008	Business	199300.00
0005435839992	6008	Business	199300.00
0005435839986	6008	Business	199300.00
0005435839975	6008	Business	199300.00
0005435839990	6008	Economy	66400.00
0005432658631	6008	Economy	66400.00
0005435839985	6008	Economy	66400.00
0005435839982	6008	Economy	66400.00
0005435839966	6008	Economy	66400.00
0005435839974	6008	Economy	66400.00
0005432660858	6008	Economy	73100.00
0005435839987	6008	Economy	66400.00
0005435839972	6008	Economy	73100.00
0005432658632	6008	Economy	66400.00
0005435839984	6008	Economy	66400.00
0005435839994	6008	Economy	66400.00
0005435472850	6008	Economy	66400.00
0005432659746	6008	Economy	66400.00
0005435839971	6008	Economy	66400.00
0005435472969	6008	Economy	66400.00
0005435839981	6008	Economy	66400.00
0005435472963	6008	Economy	66400.00
0005435473002	6008	Economy	66400.00
0005432659747	6008	Economy	66400.00
0005435472952	6008	Economy	66400.00
0005435472982	6008	Economy	66400.00
0005435839980	6008	Economy	66400.00
0005435839969	6008	Economy	66400.00
0005435472964	6008	Economy	66400.00
0005435839983	6008	Economy	66400.00
0005435839989	6008	Economy	66400.00
0005435472974	6008	Economy	66400.00
0005432660857	6008	Economy	66400.00
0005435472968	6008	Economy	66400.00
0005432142311	6008	Economy	66400.00
0005435839993	6008	Economy	66400.00
0005435839968	6008	Economy	66400.00
0005435472959	6008	Economy	66400.00
0005435472999	6008	Economy	66400.00
0005435839988	6008	Economy	66400.00
0005435472977	6008	Economy	66400.00
0005435839976	6008	Economy	66400.00
0005435472973	6008	Economy	66400.00
0005435839970	6008	Economy	66400.00
0005435472927	6008	Economy	66400.00
0005435839967	6008	Economy	66400.00
0005435839977	6008	Economy	66400.00
0005435839978	6008	Economy	66400.00
0005435839965	6008	Economy	66400.00
0005435839995	6008	Economy	66400.00
0005435839973	6008	Economy	66400.00
0005435472921	6008	Economy	66400.00
0005435473109	18091	Business	199300.00
0005435473112	18091	Business	199300.00
0005435839761	18091	Business	199300.00
0005435839812	18091	Business	199300.00
0005435839743	18091	Business	199300.00
0005435839747	18091	Business	199300.00
0005432667474	18091	Business	199300.00
0005432667466	18091	Business	199300.00
0005432667463	18091	Business	199300.00
0005435839670	18091	Business	199300.00
0005435473105	18091	Economy	66400.00
0005435839764	18091	Economy	66400.00
0005435839755	18091	Economy	66400.00
0005435839762	18091	Economy	66400.00
0005432667477	18091	Economy	66400.00
0005435839763	18091	Economy	66400.00
0005435839738	18091	Economy	66400.00
0005435839760	18091	Economy	73100.00
0005435839661	18091	Economy	73100.00
0005435839712	18091	Economy	73100.00
0005432537099	18091	Economy	66400.00
0005435839775	18091	Economy	66400.00
0005435473118	18091	Economy	66400.00
0005435473115	18091	Economy	66400.00
0005435839806	18091	Economy	66400.00
0005435839737	18091	Economy	66400.00
0005432664153	18091	Economy	66400.00
0005432537098	18091	Economy	66400.00
0005435839789	18091	Economy	66400.00
0005432667475	18091	Economy	66400.00
0005435839774	18091	Economy	66400.00
0005435473107	18091	Economy	66400.00
0005435473110	18091	Economy	66400.00
0005435839706	18091	Economy	66400.00
0005432664147	18091	Economy	66400.00
0005432667462	18091	Economy	66400.00
0005435839744	18091	Economy	66400.00
0005435839769	18091	Economy	66400.00
0005435473108	18091	Economy	66400.00
0005435473111	18091	Economy	66400.00
0005435839783	18091	Economy	66400.00
0005435617238	18091	Economy	66400.00
0005435839616	18091	Economy	66400.00
0005435473117	18091	Economy	66400.00
0005435839742	18091	Economy	66400.00
0005435839782	18091	Economy	66400.00
0005435473119	18091	Economy	66400.00
0005435473114	18091	Economy	66400.00
0005435473116	18091	Economy	66400.00
0005435473106	18091	Economy	66400.00
0005435473104	18091	Economy	66400.00
0005435839807	18091	Economy	66400.00
0005435839790	18091	Economy	66400.00
0005435473103	18091	Economy	66400.00
0005435473113	18091	Economy	66400.00
0005433462777	17267	Business	146400.00
0005433463927	17267	Business	146400.00
0005433462776	17267	Business	146400.00
0005433463933	17267	Business	146400.00
0005433462781	17267	Economy	53700.00
0005433463930	17267	Economy	53700.00
0005433462779	17267	Economy	48800.00
0005433463941	17267	Economy	48800.00
0005433462784	17267	Economy	48800.00
0005433462782	17267	Economy	48800.00
0005433463934	17267	Economy	48800.00
0005433462783	17267	Economy	48800.00
0005433462785	17267	Economy	48800.00
0005433463939	17267	Economy	48800.00
0005433463935	17267	Economy	48800.00
0005433462786	17267	Economy	48800.00
0005433462773	17267	Economy	48800.00
0005433462772	17267	Economy	48800.00
0005433463932	17267	Economy	48800.00
0005433463940	17267	Economy	48800.00
0005433463936	17267	Economy	48800.00
0005433463931	17267	Economy	48800.00
0005433462775	17267	Economy	48800.00
0005433463928	17267	Economy	48800.00
0005433463926	17267	Economy	48800.00
0005433462778	17267	Economy	48800.00
0005433463938	17267	Economy	48800.00
0005433462774	17267	Economy	48800.00
0005433462787	17267	Economy	48800.00
0005433462780	17267	Economy	48800.00
0005433463937	17267	Economy	48800.00
0005433463929	17267	Economy	48800.00
0005435104069	23043	Business	15700.00
0005433285622	23043	Business	15700.00
0005433285676	23043	Economy	5200.00
0005433285644	23043	Economy	5200.00
0005433285535	23043	Economy	5200.00
0005433285567	23043	Economy	5200.00
0005435104067	23043	Economy	5200.00
0005433285585	23043	Economy	5200.00
0005433285437	23043	Economy	5200.00
0005433285645	23043	Economy	5200.00
0005435104070	23043	Economy	5200.00
0005433285566	23043	Economy	5200.00
0005433285616	23043	Economy	5200.00
0005433285623	23043	Economy	5200.00
0005433285643	23043	Economy	5200.00
0005433285735	23043	Economy	5200.00
0005433285654	23043	Economy	5200.00
0005433285572	23043	Economy	5700.00
0005433285619	23043	Economy	5200.00
0005433285613	23043	Economy	5200.00
0005433285704	23043	Economy	5200.00
0005433285624	23043	Economy	5200.00
0005433285579	23043	Economy	5200.00
0005435104068	23043	Economy	5200.00
0005433285560	23043	Economy	5200.00
0005433285500	23043	Economy	5200.00
0005433285534	23043	Economy	5200.00
0005433285577	23043	Economy	5200.00
0005433285667	23043	Economy	5200.00
0005433285548	23043	Economy	5200.00
0005433285578	23043	Economy	5200.00
0005433285636	23043	Economy	5200.00
0005433285536	23043	Economy	5200.00
0005433285736	23043	Economy	5200.00
0005433285581	23043	Economy	5200.00
0005433285635	23043	Economy	5200.00
0005433285720	23043	Economy	5200.00
0005433285568	23043	Economy	5200.00
0005435104071	23043	Economy	5200.00
0005433285876	32059	Business	15700.00
0005433285881	32059	Business	15700.00
0005433285875	32059	Business	15700.00
0005433285899	32059	Economy	5200.00
0005433285877	32059	Economy	5200.00
0005433285879	32059	Economy	5200.00
0005433285880	32059	Economy	5200.00
0005433285887	32059	Economy	5200.00
0005433285897	32059	Economy	5200.00
0005433285894	32059	Economy	5200.00
0005435103979	32059	Economy	5200.00
0005433285898	32059	Economy	5200.00
0005433285896	32059	Economy	5200.00
0005433285873	32059	Economy	5200.00
0005435103968	32059	Economy	5700.00
0005435103978	32059	Economy	5700.00
0005433285878	32059	Economy	5700.00
0005433285888	32059	Economy	5700.00
0005433285883	32059	Economy	5200.00
0005433285891	32059	Economy	5200.00
0005433285869	32059	Economy	5200.00
0005433285872	32059	Economy	5200.00
0005433285892	32059	Economy	5200.00
0005433285886	32059	Economy	5200.00
0005433285882	32059	Economy	5200.00
0005433285868	32059	Economy	5200.00
0005435103969	32059	Economy	5200.00
0005433285885	32059	Economy	5200.00
0005433285871	32059	Economy	5200.00
0005433285874	32059	Economy	5200.00
0005433285890	32059	Economy	5200.00
0005433285870	32059	Economy	5200.00
0005433285895	32059	Economy	5200.00
0005433285889	32059	Economy	5200.00
0005433285884	32059	Economy	5200.00
0005433285893	32059	Economy	5200.00
0005435214829	30591	Business	42100.00
0005432529431	30591	Business	42100.00
0005435214850	30591	Business	42100.00
0005432529188	30591	Business	42100.00
0005432529039	30591	Business	42100.00
0005432529221	30591	Business	42100.00
0005435214837	30591	Business	42100.00
0005432529088	30591	Business	42100.00
0005434068477	30591	Business	42100.00
0005435214826	30591	Business	42100.00
0005435214888	30591	Business	42100.00
0005432529244	30591	Business	42100.00
0005432529583	30591	Business	42100.00
0005432529337	30591	Business	42100.00
0005435214871	30591	Business	42100.00
0005432529243	30591	Business	42100.00
0005434068282	30591	Business	42100.00
0005434068332	30591	Business	42100.00
0005434068410	30591	Business	42100.00
0005432211647	30591	Business	42100.00
0005435214833	30591	Business	42100.00
0005435214893	30591	Business	42100.00
0005434068300	30591	Business	42100.00
0005432529557	30591	Business	42100.00
0005435214831	30591	Business	42100.00
0005435631026	30591	Comfort	23900.00
0005434067834	30591	Comfort	23900.00
0005434068080	30591	Comfort	23900.00
0005435214880	30591	Comfort	23900.00
0005435214868	30591	Comfort	23900.00
0005432529359	30591	Comfort	23900.00
0005434068172	30591	Comfort	23900.00
0005435214859	30591	Comfort	23900.00
0005434068319	30591	Comfort	23900.00
0005435214865	30591	Comfort	23900.00
0005435214886	30591	Comfort	23900.00
0005432529594	30591	Comfort	23900.00
0005435725697	30591	Comfort	23900.00
0005432528899	30591	Comfort	23900.00
0005435214841	30591	Comfort	23900.00
0005432529526	30591	Comfort	23900.00
0005435214847	30591	Comfort	23900.00
0005432529208	30591	Comfort	23900.00
0005435214855	30591	Comfort	23900.00
0005434068460	30591	Comfort	23900.00
0005432529265	30591	Comfort	23900.00
0005432529343	30591	Comfort	23900.00
0005432159947	30591	Comfort	23900.00
0005432529428	30591	Comfort	23900.00
0005434068128	30591	Comfort	23900.00
0005435214827	30591	Comfort	23900.00
0005435214849	30591	Comfort	23900.00
0005434068201	30591	Comfort	23900.00
0005433656736	30591	Comfort	23900.00
0005432529396	30591	Comfort	23900.00
0005432529607	30591	Comfort	23900.00
0005434068209	30591	Comfort	23900.00
0005432535893	30591	Comfort	23900.00
0005434068283	30591	Comfort	23900.00
0005434068371	30591	Comfort	23900.00
0005432529209	30591	Comfort	23900.00
0005434068403	30591	Economy	14000.00
0005434068427	30591	Economy	14000.00
0005432529467	30591	Economy	14000.00
0005432529554	30591	Economy	14000.00
0005432529312	30591	Economy	14000.00
0005435214828	30591	Economy	14000.00
0005432529270	30591	Economy	14000.00
0005434068309	30591	Economy	14000.00
0005432529232	30591	Economy	14000.00
0005432529742	30591	Economy	14000.00
0005435214870	30591	Economy	14000.00
0005432159948	30591	Economy	14000.00
0005434068315	30591	Economy	14000.00
0005435214883	30591	Economy	14000.00
0005432211645	30591	Economy	14000.00
0005432529353	30591	Economy	14000.00
0005435214894	30591	Economy	14000.00
0005432529561	30591	Economy	14000.00
0005432428957	30591	Economy	14000.00
0005432529264	30591	Economy	14000.00
0005432529759	30591	Economy	14000.00
0005434068370	30591	Economy	14000.00
0005432529234	30591	Economy	14000.00
0005432211651	30591	Economy	14000.00
0005435214843	30591	Economy	14000.00
0005432528950	30591	Economy	14000.00
0005435214854	30591	Economy	14000.00
0005432529399	30591	Economy	14000.00
0005434067987	30591	Economy	14000.00
0005432211643	30591	Economy	14000.00
0005432528583	30591	Economy	14000.00
0005434068394	30591	Economy	14000.00
0005432529146	30591	Economy	14000.00
0005432529336	30591	Economy	14000.00
0005432529479	30591	Economy	14000.00
0005435214860	30591	Economy	14000.00
0005434068320	30591	Economy	14000.00
0005434068416	30591	Economy	14000.00
0005434067968	30591	Economy	14000.00
0005432528874	30591	Economy	14000.00
0005432529618	30591	Economy	14000.00
0005432529419	30591	Economy	14000.00
0005432529586	30591	Economy	14000.00
0005432529916	30591	Economy	14000.00
0005432529275	30591	Economy	14000.00
0005434068287	30591	Economy	14000.00
0005435214869	30591	Economy	14000.00
0005432529917	30591	Economy	14000.00
0005435631028	30591	Economy	14000.00
0005434068450	30591	Economy	14000.00
0005432529525	30591	Economy	14000.00
0005432529327	30591	Economy	14000.00
0005435725698	30591	Economy	14000.00
0005434068035	30591	Economy	14000.00
0005432529384	30591	Economy	14000.00
0005432529256	30591	Economy	14000.00
0005432529418	30591	Economy	14000.00
0005432529170	30591	Economy	14000.00
0005435214877	30591	Economy	14000.00
0005432528823	30591	Economy	15400.00
0005432529430	30591	Economy	14000.00
0005435214825	30591	Economy	15400.00
0005435214891	30591	Economy	14000.00
0005434068020	30591	Economy	14000.00
0005434067833	30591	Economy	14000.00
0005432529344	30591	Economy	15400.00
0005435214836	30591	Economy	14000.00
0005435214882	30591	Economy	15400.00
0005432159946	30591	Economy	14000.00
0005435214830	30591	Economy	14000.00
0005432529736	30591	Economy	14000.00
0005434068065	30591	Economy	14000.00
0005434068147	30591	Economy	14000.00
0005432529172	30591	Economy	14000.00
0005432528584	30591	Economy	14000.00
0005432529160	30591	Economy	14000.00
0005434068197	30591	Economy	14000.00
0005434068463	30591	Economy	14000.00
0005433656738	30591	Economy	14000.00
0005434068299	30591	Economy	14000.00
0005432428959	30591	Economy	14000.00
0005434068124	30591	Economy	14000.00
0005432529882	30591	Economy	14000.00
0005434068079	30591	Economy	14000.00
0005434068200	30591	Economy	14000.00
0005434068409	30591	Economy	14000.00
0005435725700	30591	Economy	14000.00
0005432529346	30591	Economy	14000.00
0005432529173	30591	Economy	14000.00
0005432529087	30591	Economy	14000.00
0005435214851	30591	Economy	14000.00
0005435214839	30591	Economy	14000.00
0005432529393	30591	Economy	14000.00
0005434068426	30591	Economy	14000.00
0005434068262	30591	Economy	14000.00
0005435725699	30591	Economy	14000.00
0005432529772	30591	Economy	14000.00
0005432428946	30591	Economy	14000.00
0005432537083	30591	Economy	14000.00
0005435214873	30591	Economy	14000.00
0005432529059	30591	Economy	14000.00
0005434068070	30591	Economy	14000.00
0005433656737	30591	Economy	14000.00
0005434068195	30591	Economy	14000.00
0005432529233	30591	Economy	14000.00
0005432529514	30591	Economy	14000.00
0005434067967	30591	Economy	14000.00
0005432529487	30591	Economy	14000.00
0005432529315	30591	Economy	14000.00
0005432529307	30591	Economy	14000.00
0005432529358	30591	Economy	14000.00
0005432211649	30591	Economy	14000.00
0005435214852	30591	Economy	14000.00
0005435214856	30591	Economy	14000.00
0005432529398	30591	Economy	14000.00
0005432529031	30591	Economy	14000.00
0005435214889	30591	Economy	14000.00
0005434068310	30591	Economy	14000.00
0005432529065	30591	Economy	14000.00
0005435214840	30591	Economy	14000.00
0005432529197	30591	Economy	14000.00
0005432529466	30591	Economy	14000.00
0005432529515	30591	Economy	14000.00
0005432159944	30591	Economy	14000.00
0005432529269	30591	Economy	14000.00
0005435631027	30591	Economy	14000.00
0005434068449	30591	Economy	14000.00
0005434068429	30591	Economy	14000.00
0005435214872	30591	Economy	14000.00
0005432159945	30591	Economy	14000.00
0005435214834	30591	Economy	14000.00
0005432529743	30591	Economy	14000.00
0005435214842	30591	Economy	14000.00
0005435214874	30591	Economy	14000.00
0005435214835	30591	Economy	14000.00
0005434068349	30591	Economy	14000.00
0005432428961	30591	Economy	14000.00
0005435214853	30591	Economy	14000.00
0005432529397	30591	Economy	14000.00
0005432529385	30591	Economy	14000.00
0005432529517	30591	Economy	14000.00
0005432529360	30591	Economy	14000.00
0005432529673	30591	Economy	14000.00
0005435214881	30591	Economy	14000.00
0005434068034	30591	Economy	14000.00
0005432537084	30591	Economy	14000.00
0005432529608	30591	Economy	14000.00
0005432529968	30591	Economy	14000.00
0005435214845	30591	Economy	14000.00
0005434068428	30591	Economy	14000.00
0005432529593	30591	Economy	14000.00
0005434068225	30591	Economy	14000.00
0005432528595	30591	Economy	14000.00
0005432529347	30591	Economy	14000.00
0005435214867	30591	Economy	14000.00
0005432529527	30591	Economy	14000.00
0005432528920	30591	Economy	14000.00
0005432529038	30591	Economy	14000.00
0005434068375	30591	Economy	14000.00
0005432529165	30591	Economy	14000.00
0005435214885	30591	Economy	14000.00
0005432529301	30591	Economy	14000.00
0005432529216	30591	Economy	14000.00
0005432211650	30591	Economy	14000.00
0005432529548	30591	Economy	15400.00
0005435214887	30591	Economy	14000.00
0005435214832	30591	Economy	14000.00
0005432529672	30591	Economy	14000.00
0005432529584	30591	Economy	14000.00
0005432530074	30591	Economy	14000.00
0005434068102	30591	Economy	14000.00
0005432529145	30591	Economy	14000.00
0005435214848	30591	Economy	14000.00
0005434068123	30591	Economy	14000.00
0005432528996	30591	Economy	14000.00
0005434068435	30591	Economy	14000.00
0005432529317	30591	Economy	14000.00
0005432529316	30591	Economy	14000.00
0005432529224	30591	Economy	14000.00
0005435214890	30591	Economy	14000.00
0005432529553	30591	Economy	14000.00
0005432528653	30591	Economy	14000.00
0005432529306	30591	Economy	14000.00
0005432529046	30591	Economy	14000.00
0005432529395	30591	Economy	14000.00
0005432530047	30591	Economy	14000.00
0005434068103	30591	Economy	14000.00
0005434068116	30591	Economy	14000.00
0005435214862	30591	Economy	14000.00
0005435214884	30591	Economy	14000.00
0005434067986	30591	Economy	14000.00
0005435214858	30591	Economy	14000.00
0005432529322	30591	Economy	14000.00
0005435214861	30591	Economy	14000.00
0005434068459	30591	Economy	14000.00
0005434068178	30591	Economy	14000.00
0005434068125	30591	Economy	14000.00
0005432529496	30591	Economy	14000.00
0005432428960	30591	Economy	14000.00
0005434068117	30591	Economy	14000.00
0005432529420	30591	Economy	14000.00
0005434068348	30591	Economy	14000.00
0005432529494	30591	Economy	14000.00
0005435214844	30591	Economy	14000.00
0005434068289	30591	Economy	14000.00
0005432529304	30591	Economy	14000.00
0005432529201	30591	Economy	14000.00
0005435214876	30591	Economy	14000.00
0005432529516	30591	Economy	14000.00
0005434068350	30591	Economy	14000.00
0005432529034	30591	Economy	14000.00
0005432533314	30591	Economy	14000.00
0005432533315	30591	Economy	14000.00
0005434068239	30591	Economy	14000.00
0005435214866	30591	Economy	14000.00
0005434068164	30591	Economy	14000.00
0005434067992	30591	Economy	14000.00
0005435214864	30591	Economy	14000.00
0005432529474	30591	Economy	14000.00
0005433656735	30591	Economy	14000.00
0005432529302	30591	Economy	14000.00
0005435214892	30591	Economy	14000.00
0005432529279	30591	Economy	14000.00
0005432528854	30591	Economy	14000.00
0005435214878	30591	Economy	14000.00
0005434068464	30591	Economy	14000.00
0005432529756	30591	Economy	14000.00
0005434068448	30591	Economy	14000.00
0005435214838	30591	Economy	14000.00
0005434068318	30591	Economy	14000.00
0005432535866	30591	Economy	14000.00
0005435214846	30591	Economy	14000.00
0005432529093	30591	Economy	14000.00
0005432529645	30591	Economy	14000.00
0005432529495	30591	Economy	14000.00
0005432529478	30591	Economy	14000.00
0005432211646	30591	Economy	14000.00
0005435214857	30591	Economy	14000.00
0005432529293	30591	Economy	14000.00
0005435214875	30591	Economy	14000.00
0005432529448	30591	Economy	14000.00
0005432428958	30591	Economy	14000.00
0005432529585	30591	Economy	14000.00
0005432211644	30591	Economy	14000.00
0005432529294	30591	Economy	14000.00
0005434068163	30591	Economy	14000.00
0005432529200	30591	Economy	14000.00
0005432211648	30591	Economy	14000.00
0005435214879	30591	Economy	14000.00
0005434068451	30591	Economy	14000.00
0005434068069	30591	Economy	14000.00
0005432528981	30591	Economy	14000.00
0005435214863	30591	Economy	14000.00
0005432537079	30591	Economy	14000.00
0005434068118	30591	Economy	14000.00
0005432535887	30591	Economy	14000.00
0005435653295	24832	Business	9800.00
0005433368611	24832	Business	9800.00
0005433368620	24832	Business	9800.00
0005435653558	24832	Business	9800.00
0005433368617	24832	Business	9800.00
0005433368604	24832	Business	9800.00
0005433368637	24832	Business	9800.00
0005435653467	24832	Business	9800.00
0005435653451	24832	Business	9800.00
0005435653426	24832	Business	9800.00
0005435653464	24832	Business	9800.00
0005433368629	24832	Economy	3300.00
0005435653463	24832	Economy	3300.00
0005435653384	24832	Economy	3300.00
0005433368606	24832	Economy	3300.00
0005435653518	24832	Economy	3300.00
0005433368633	24832	Economy	3300.00
0005435653559	24832	Economy	3300.00
0005433368603	24832	Economy	3300.00
0005433368636	24832	Economy	3300.00
0005433368630	24832	Economy	3600.00
0005435653564	24832	Economy	3600.00
0005433368618	24832	Economy	3600.00
0005435653515	24832	Economy	3600.00
0005433368638	24832	Economy	3300.00
0005433368605	24832	Economy	3300.00
0005435653570	24832	Economy	3300.00
0005435653318	24832	Economy	3300.00
0005433368621	24832	Economy	3300.00
0005433368608	24832	Economy	3300.00
0005433368601	24832	Economy	3300.00
0005433368632	24832	Economy	3300.00
0005433368631	24832	Economy	3300.00
0005435653556	24832	Economy	3300.00
0005435653497	24832	Economy	3300.00
0005435653551	24832	Economy	3300.00
0005435653411	24832	Economy	3300.00
0005435653481	24832	Economy	3300.00
0005433368625	24832	Economy	3300.00
0005435653571	24832	Economy	3300.00
0005435653533	24832	Economy	3300.00
0005435653484	24832	Economy	3300.00
0005433368602	24832	Economy	3300.00
0005433368616	24832	Economy	3300.00
0005435653383	24832	Economy	3300.00
0005433368634	24832	Economy	3300.00
0005433368613	24832	Economy	3300.00
0005435653421	24832	Economy	3300.00
0005435653503	24832	Economy	3300.00
0005435653419	24832	Economy	3300.00
0005435653572	24832	Economy	3300.00
0005433368614	24832	Economy	3300.00
0005435653317	24832	Economy	3300.00
0005435653450	24832	Economy	3300.00
0005435653531	24832	Economy	3300.00
0005435653555	24832	Economy	3300.00
0005435653401	24832	Economy	3300.00
0005433368626	24832	Economy	3300.00
0005433368610	24832	Economy	3300.00
0005433368609	24832	Economy	3300.00
0005435653420	24832	Economy	3300.00
0005435653498	24832	Economy	3300.00
0005433368627	24832	Economy	3300.00
0005435653480	24832	Economy	3300.00
0005433368624	24832	Economy	3300.00
0005433368612	24832	Economy	3300.00
0005433368615	24832	Economy	3300.00
0005433368622	24832	Economy	3300.00
0005433368628	24832	Economy	3300.00
0005435653532	24832	Economy	3300.00
0005435653459	24832	Economy	3300.00
0005433368635	24832	Economy	3300.00
0005435653504	24832	Economy	3300.00
0005435653466	24832	Economy	3300.00
0005435653400	24832	Economy	3300.00
0005435653563	24832	Economy	3300.00
0005433368623	24832	Economy	3300.00
0005433368607	24832	Economy	3300.00
0005435653315	24832	Economy	3300.00
0005435653478	24832	Economy	3300.00
0005435653534	24832	Economy	3300.00
0005435653324	24832	Economy	3300.00
0005435653550	24832	Economy	3300.00
0005435653474	24832	Economy	3300.00
0005433368619	24832	Economy	3300.00
0005434980368	2036	Economy	10500.00
0005434980370	2036	Economy	10500.00
0005434980382	2036	Economy	10500.00
0005434980373	2036	Economy	9500.00
0005434980384	2036	Economy	9500.00
0005435801756	2036	Economy	9500.00
0005434980389	2036	Economy	9500.00
0005434980383	2036	Economy	9500.00
0005434980374	2036	Economy	9500.00
0005434980390	2036	Economy	9500.00
0005435801755	2036	Economy	9500.00
0005434980371	2036	Economy	9500.00
0005434980365	2036	Economy	9500.00
0005434980372	2036	Economy	9500.00
0005434980375	2036	Economy	9500.00
0005434980381	2036	Economy	9500.00
0005434980387	2036	Economy	9500.00
0005434980363	2036	Economy	9500.00
0005434980386	2036	Economy	9500.00
0005434980366	2036	Economy	9500.00
0005434980388	2036	Economy	9500.00
0005434980380	2036	Economy	9500.00
0005434980364	2036	Economy	9500.00
0005434980376	2036	Economy	9500.00
0005435801754	2036	Economy	9500.00
0005434980377	2036	Economy	9500.00
0005434980369	2036	Economy	9500.00
0005434980379	2036	Economy	9500.00
0005434980361	2036	Economy	9500.00
0005434980378	2036	Economy	9500.00
0005434980362	2036	Economy	9500.00
0005434980367	2036	Economy	9500.00
0005434980360	2036	Economy	9500.00
0005434980385	2036	Economy	9500.00
0005434980182	23551	Economy	10500.00
0005434980112	23551	Economy	10500.00
0005434979970	23551	Economy	10500.00
0005434980029	23551	Economy	10500.00
0005434979947	23551	Economy	9500.00
0005434980038	23551	Economy	9500.00
0005435801735	23551	Economy	9500.00
0005434980126	23551	Economy	9500.00
0005434980140	23551	Economy	9500.00
0005434979992	23551	Economy	9500.00
0005435801727	23551	Economy	9500.00
0005434980104	23551	Economy	9500.00
0005434979983	23551	Economy	9500.00
0005434980076	23551	Economy	9500.00
0005434980127	23551	Economy	9500.00
0005434980119	23551	Economy	9500.00
0005434980171	23551	Economy	9500.00
0005434980092	23551	Economy	9500.00
0005434980103	23551	Economy	9500.00
0005434979966	23551	Economy	9500.00
0005434980017	23551	Economy	9500.00
0005434980032	23551	Economy	9500.00
0005434980183	23551	Economy	9500.00
0005434979969	23551	Economy	9500.00
0005434980130	23551	Economy	9500.00
0005434979991	23551	Economy	9500.00
0005434980086	23551	Economy	9500.00
0005434980087	23551	Economy	9500.00
0005434980091	23551	Economy	9500.00
0005434980096	23551	Economy	9500.00
0005434980049	23551	Economy	9500.00
0005434979971	23551	Economy	9500.00
0005434980060	23551	Economy	9500.00
0005434980090	23551	Economy	9500.00
0005434980018	23551	Economy	9500.00
0005434952602	2632	Economy	5300.00
0005434952603	2632	Economy	5300.00
0005434952604	2632	Economy	5300.00
0005434952605	2632	Economy	5300.00
0005433256452	2634	Economy	5300.00
0005434952564	28284	Economy	5300.00
0005434952573	28284	Economy	5300.00
0005434952568	28284	Economy	5300.00
0005433256466	28284	Economy	5300.00
0005433256465	28284	Economy	5300.00
0005433112407	19793	Economy	8700.00
0005433111550	19793	Economy	8700.00
0005433111549	19793	Economy	8700.00
0005433112406	19793	Economy	8700.00
0005434139122	11929	Business	9700.00
0005434138723	11929	Business	9700.00
0005434139060	11929	Business	9700.00
0005434139173	11929	Business	9700.00
0005434139126	11929	Business	9700.00
0005434139068	11929	Business	9700.00
0005434138947	11929	Business	9700.00
0005434139007	11929	Business	9700.00
0005434138984	11929	Business	9700.00
0005434139162	11929	Business	9700.00
0005434138975	11929	Economy	3200.00
0005434139121	11929	Economy	3200.00
0005434139091	11929	Economy	3200.00
0005434139136	11929	Economy	3200.00
0005434138943	11929	Economy	3200.00
0005434139022	11929	Economy	3200.00
0005434139057	11929	Economy	3200.00
0005434139050	11929	Economy	3200.00
0005434139178	11929	Economy	3200.00
0005434139106	11929	Economy	3200.00
0005434138981	11929	Economy	3500.00
0005434139199	11929	Economy	3500.00
0005434139003	11929	Economy	3500.00
0005434139221	11929	Economy	3500.00
0005434138962	11929	Economy	3500.00
0005434139205	11929	Economy	3200.00
0005434139078	11929	Economy	3200.00
0005434138913	11929	Economy	3200.00
0005434139084	11929	Economy	3200.00
0005434138724	11929	Economy	3200.00
0005434138961	11929	Economy	3200.00
0005434138989	11929	Economy	3200.00
0005434139056	11929	Economy	3200.00
0005434139175	11929	Economy	3200.00
0005434139015	11929	Economy	3200.00
0005434138833	11929	Economy	3200.00
0005434139046	11929	Economy	3200.00
0005434138983	11929	Economy	3200.00
0005434138994	11929	Economy	3200.00
0005434139182	11929	Economy	3200.00
0005434138900	11929	Economy	3200.00
0005434139029	11929	Economy	3200.00
0005434139062	11929	Economy	3200.00
0005434138678	11929	Economy	3200.00
0005434139047	11929	Economy	3200.00
0005434138897	11929	Economy	3200.00
0005434139090	11929	Economy	3200.00
0005434139204	11929	Economy	3200.00
0005434139198	11929	Economy	3200.00
0005434138955	11929	Economy	3200.00
0005434139044	11929	Economy	3200.00
0005434139096	11929	Economy	3200.00
0005434138809	11929	Economy	3200.00
0005434139177	11929	Economy	3200.00
0005434139092	11929	Economy	3200.00
0005434139059	11929	Economy	3200.00
0005434139016	11929	Economy	3200.00
0005434139172	11929	Economy	3200.00
0005434139008	11929	Economy	3200.00
0005434138988	11929	Economy	3200.00
0005434139013	11929	Economy	3200.00
0005434139183	11929	Economy	3200.00
0005434139181	11929	Economy	3200.00
0005434139065	11929	Economy	3200.00
0005434138920	11929	Economy	3200.00
0005434138912	11929	Economy	3200.00
0005434139146	11929	Economy	3200.00
0005434139011	11929	Economy	3200.00
0005434139100	11929	Economy	3200.00
0005434138976	11929	Economy	3200.00
0005434138709	11929	Economy	3200.00
0005434139245	11929	Economy	3200.00
0005434138722	11929	Economy	3200.00
0005434139135	11929	Economy	3200.00
0005434139066	11929	Economy	3200.00
0005434139114	11929	Economy	3200.00
0005434139123	11929	Economy	3200.00
0005434138673	11929	Economy	3200.00
0005434138927	11929	Economy	3200.00
0005434139067	11929	Economy	3200.00
0005434139049	11929	Economy	3200.00
0005434139061	11929	Economy	3200.00
0005434138926	11929	Economy	3200.00
0005434139045	11929	Economy	3200.00
0005434138977	11929	Economy	3200.00
0005434139632	28723	Business	9700.00
0005434139678	28723	Business	9700.00
0005434139642	28723	Business	9700.00
0005434139672	28723	Business	9700.00
0005434139634	28723	Business	9700.00
0005434139639	28723	Business	9700.00
0005434139644	28723	Business	9700.00
0005434139687	28723	Business	9700.00
0005434139657	28723	Economy	3200.00
0005434139631	28723	Economy	3200.00
0005434139629	28723	Economy	3200.00
0005434139627	28723	Economy	3200.00
0005434139662	28723	Economy	3200.00
0005434139691	28723	Economy	3200.00
0005434139688	28723	Economy	3200.00
0005434139664	28723	Economy	3200.00
0005434139628	28723	Economy	3500.00
0005434139690	28723	Economy	3500.00
0005434139641	28723	Economy	3500.00
0005434139670	28723	Economy	3200.00
0005434139635	28723	Economy	3200.00
0005434139684	28723	Economy	3200.00
0005434139658	28723	Economy	3200.00
0005434139665	28723	Economy	3200.00
0005434139630	28723	Economy	3200.00
0005434139659	28723	Economy	3200.00
0005434139649	28723	Economy	3200.00
0005434139661	28723	Economy	3200.00
0005434139625	28723	Economy	3200.00
0005434139648	28723	Economy	3200.00
0005434139655	28723	Economy	3200.00
0005434139637	28723	Economy	3200.00
0005434139677	28723	Economy	3200.00
0005434139656	28723	Economy	3200.00
0005434139683	28723	Economy	3200.00
0005434139623	28723	Economy	3200.00
0005434139680	28723	Economy	3200.00
0005434139685	28723	Economy	3200.00
0005434139636	28723	Economy	3200.00
0005434139654	28723	Economy	3200.00
0005434139673	28723	Economy	3200.00
0005434139676	28723	Economy	3200.00
0005434139663	28723	Economy	3200.00
0005434139650	28723	Economy	3200.00
0005434139638	28723	Economy	3200.00
0005434139669	28723	Economy	3200.00
0005434139647	28723	Economy	3200.00
0005434139671	28723	Economy	3200.00
0005434139651	28723	Economy	3200.00
0005434139666	28723	Economy	3200.00
0005434139640	28723	Economy	3200.00
0005434139686	28723	Economy	3200.00
0005434139652	28723	Economy	3200.00
0005434139675	28723	Economy	3200.00
0005434139660	28723	Economy	3200.00
0005434139626	28723	Economy	3200.00
0005434139667	28723	Economy	3200.00
0005434139645	28723	Economy	3200.00
0005434139622	28723	Economy	3200.00
0005434139679	28723	Economy	3200.00
0005434139643	28723	Economy	3200.00
0005434139674	28723	Economy	3200.00
0005434139646	28723	Economy	3200.00
0005434139682	28723	Economy	3200.00
0005434139681	28723	Economy	3200.00
0005434139689	28723	Economy	3200.00
0005434139633	28723	Economy	3200.00
0005434139668	28723	Economy	3200.00
0005434139624	28723	Economy	3200.00
0005434139653	28723	Economy	3200.00
0005433539036	6807	Economy	10900.00
0005435259807	6807	Economy	10900.00
0005433539038	6807	Economy	9900.00
0005435259829	6807	Economy	9900.00
0005435259828	6807	Economy	9900.00
0005433539041	6807	Economy	9900.00
0005433539035	6807	Economy	9900.00
0005433534540	6807	Economy	9900.00
0005435259827	6807	Economy	9900.00
0005435259812	6807	Economy	9900.00
0005435259818	6807	Economy	9900.00
0005433534539	6807	Economy	9900.00
0005433539037	6807	Economy	9900.00
0005435259792	6807	Economy	9900.00
0005435259791	6807	Economy	9900.00
0005433539034	6807	Economy	9900.00
0005435259806	6807	Economy	9900.00
0005433539040	6807	Economy	9900.00
0005435259814	6807	Economy	9900.00
0005435259811	6807	Economy	9900.00
0005433539042	6807	Economy	9900.00
0005433539039	6807	Economy	9900.00
0005433534514	25008	Economy	10900.00
0005433534519	25008	Economy	9900.00
0005435259842	25008	Economy	9900.00
0005433538981	25008	Economy	9900.00
0005433534523	25008	Economy	9900.00
0005435259843	25008	Economy	9900.00
0005435259841	25008	Economy	9900.00
0005433538983	25008	Economy	9900.00
0005435259844	25008	Economy	9900.00
0005433538967	25008	Economy	9900.00
0005433534513	25008	Economy	9900.00
0005433538971	25008	Economy	9900.00
0005433538970	25008	Economy	9900.00
0005433538980	25008	Economy	9900.00
0005433512113	815	Economy	16100.00
0005433512119	815	Economy	14600.00
0005433512116	815	Economy	14600.00
0005432922564	815	Economy	14600.00
0005432922572	815	Economy	14600.00
0005433512118	815	Economy	14600.00
0005432922563	815	Economy	14600.00
0005433512115	815	Economy	14600.00
0005433512114	815	Economy	14600.00
0005433512112	815	Economy	14600.00
0005433512117	815	Economy	14600.00
0005432922606	16135	Economy	16100.00
0005432922603	16135	Economy	14600.00
0005433512070	16135	Economy	14600.00
0005433512071	16135	Economy	14600.00
0005432922604	16135	Economy	14600.00
0005433512050	16135	Economy	14600.00
0005433512046	16135	Economy	14600.00
0005432922605	16135	Economy	14600.00
0005433512048	16135	Economy	14600.00
0005433512045	16135	Economy	14600.00
0005435697900	3652	Economy	7900.00
0005435697882	3652	Economy	7900.00
0005435697906	3652	Economy	7900.00
0005435697887	3652	Economy	7200.00
0005435697879	3652	Economy	7200.00
0005435935079	3652	Economy	7200.00
0005435697905	3652	Economy	7200.00
0005435916196	3652	Economy	7200.00
0005435697897	3652	Economy	7200.00
0005435916190	3652	Economy	7200.00
0005435935074	3652	Economy	7200.00
0005435697901	3652	Economy	7200.00
0005435697891	3652	Economy	7200.00
0005435697899	3652	Economy	7200.00
0005434950617	3652	Economy	7200.00
0005435697881	3652	Economy	7200.00
0005435697895	3652	Economy	7200.00
0005435697896	3652	Economy	7200.00
0005435697885	3652	Economy	7200.00
0005435697894	3652	Economy	7200.00
0005435697890	3652	Economy	7200.00
0005435935078	3652	Economy	7200.00
0005434950618	3652	Economy	7200.00
0005435697907	3652	Economy	7200.00
0005435697898	3652	Economy	7200.00
0005435697878	3652	Economy	7200.00
0005435697903	3652	Economy	7200.00
0005435697902	3652	Economy	7200.00
0005435916191	3652	Economy	7200.00
0005435697886	3652	Economy	7200.00
0005435697888	3652	Economy	7200.00
0005435697893	3652	Economy	7200.00
0005434950619	3652	Economy	7200.00
0005435697889	3652	Economy	7200.00
0005435697884	3652	Economy	7200.00
0005435935076	3652	Economy	7200.00
0005435697904	3652	Economy	7200.00
0005435697883	3652	Economy	7200.00
0005435697892	3652	Economy	7200.00
0005434950616	3652	Economy	7200.00
0005435697880	3652	Economy	7200.00
0005435697657	16260	Economy	7900.00
0005435697674	16260	Economy	7900.00
0005434950583	16260	Economy	7900.00
0005435916223	16260	Economy	7200.00
0005435916222	16260	Economy	7200.00
0005435697676	16260	Economy	7200.00
0005434950593	16260	Economy	7200.00
0005435935100	16260	Economy	7200.00
0005435697631	16260	Economy	7200.00
0005435697539	16260	Economy	7200.00
0005435697576	16260	Economy	7200.00
0005435697595	16260	Economy	7200.00
0005435935101	16260	Economy	7200.00
0005435697659	16260	Economy	7200.00
0005435935102	16260	Economy	7200.00
0005435697540	16260	Economy	7200.00
0005435697603	16260	Economy	7200.00
0005435697698	16260	Economy	7200.00
0005435935099	16260	Economy	7200.00
0005434950594	16260	Economy	7200.00
0005435916221	16260	Economy	7200.00
0005435697628	16260	Economy	7200.00
0005435697568	16260	Economy	7200.00
0005435697485	16260	Economy	7200.00
0005435697783	16260	Economy	7200.00
0005435697537	16260	Economy	7200.00
0005435697660	16260	Economy	7200.00
0005435697658	16260	Economy	7200.00
0005435697604	16260	Economy	7200.00
0005435697569	16260	Economy	7200.00
0005434950584	16260	Economy	7200.00
0005435697627	16260	Economy	7200.00
0005435697536	16260	Economy	7200.00
0005435697673	16260	Economy	7200.00
0005435853639	3992	Economy	21300.00
0005433519545	3992	Economy	21300.00
0005432607648	3992	Economy	19300.00
0005434606891	3992	Economy	19300.00
0005434604967	3992	Economy	19300.00
0005433519546	3992	Economy	19300.00
0005434604966	3992	Economy	19300.00
0005434606892	3992	Economy	19300.00
0005432609812	3992	Economy	19300.00
0005435853634	3992	Economy	19300.00
0005432609813	3992	Economy	19300.00
0005434604968	3992	Economy	19300.00
0005433519548	3992	Economy	19300.00
0005432607649	3992	Economy	19300.00
0005434606893	3992	Economy	19300.00
0005434606894	3992	Economy	19300.00
0005433519549	3992	Economy	19300.00
0005435853633	3992	Economy	19300.00
0005432607646	3992	Economy	19300.00
0005432607647	3992	Economy	19300.00
0005432609811	3992	Economy	19300.00
0005434604969	3992	Economy	19300.00
0005434604970	3992	Economy	19300.00
0005433519547	3992	Economy	19300.00
0005434604971	3992	Economy	19300.00
0005435841118	22083	Economy	21300.00
0005432613897	22083	Economy	21300.00
0005432609766	22083	Economy	21300.00
0005432613890	22083	Economy	21300.00
0005435841116	22083	Economy	19300.00
0005432613904	22083	Economy	19300.00
0005432609750	22083	Economy	19300.00
0005433519520	22083	Economy	19300.00
0005432613910	22083	Economy	19300.00
0005435841115	22083	Economy	19300.00
0005433519507	22083	Economy	19300.00
0005433519509	22083	Economy	19300.00
0005432613887	22083	Economy	19300.00
0005435841486	22083	Economy	19300.00
0005432609765	22083	Economy	19300.00
0005432609752	22083	Economy	19300.00
0005432609770	22083	Economy	19300.00
0005435841114	22083	Economy	19300.00
0005432609763	22083	Economy	19300.00
0005432609771	22083	Economy	19300.00
0005433519508	22083	Economy	19300.00
0005432609753	22083	Economy	19300.00
0005433519523	22083	Economy	19300.00
0005432609761	22083	Economy	19300.00
0005432613907	22083	Economy	19300.00
0005432609760	22083	Economy	19300.00
0005432609751	22083	Economy	19300.00
0005433519501	22083	Economy	19300.00
0005434606855	22083	Economy	19300.00
0005432613911	22083	Economy	19300.00
0005435841113	22083	Economy	19300.00
0005432609747	22083	Economy	19300.00
0005435841112	22083	Economy	19300.00
0005432609748	22083	Economy	19300.00
0005435841111	22083	Economy	19300.00
0005435841487	22083	Economy	19300.00
0005435841117	22083	Economy	19300.00
0005435841483	22083	Economy	19300.00
0005432613905	22083	Economy	19300.00
0005435841484	22083	Economy	19300.00
0005432609764	22083	Economy	19300.00
0005432609754	22083	Economy	19300.00
0005435841485	22083	Economy	19300.00
0005432613886	22083	Economy	19300.00
0005432613882	22083	Economy	19300.00
0005432613898	22083	Economy	19300.00
0005433349068	719	Economy	3700.00
0005435628794	719	Economy	3700.00
0005435628793	719	Economy	3700.00
0005435628795	719	Economy	3700.00
0005433349070	719	Economy	3700.00
0005433349053	719	Economy	3700.00
0005433349069	719	Economy	3700.00
0005435628796	719	Economy	3700.00
0005433349064	719	Economy	3700.00
0005433349065	719	Economy	3700.00
0005435628792	719	Economy	3700.00
0005433349101	15927	Economy	3700.00
0005435628764	15927	Economy	3700.00
0005433349103	15927	Economy	3700.00
0005435628750	15927	Economy	3700.00
0005433349102	15927	Economy	3700.00
0005433349106	15927	Economy	3700.00
0005433349104	15927	Economy	3700.00
0005433349105	15927	Economy	3700.00
0005433159329	17167	Economy	7100.00
0005434446561	17167	Economy	7100.00
0005433159331	17167	Economy	7100.00
0005434445288	17167	Economy	7100.00
0005434445287	17167	Economy	7100.00
0005433159332	17167	Economy	7100.00
0005433159330	17167	Economy	7100.00
0005434446560	17167	Economy	7100.00
0005433159337	17167	Economy	7100.00
0005434445289	17167	Economy	7100.00
0005433159358	17630	Economy	7100.00
0005433159357	17630	Economy	7100.00
0005434445265	17630	Economy	7100.00
0005434445262	17630	Economy	7100.00
0005434445264	17630	Economy	7100.00
0005434445270	17630	Economy	7100.00
0005434445263	17630	Economy	7100.00
0005435133092	7907	Economy	5400.00
0005435133088	7907	Economy	5400.00
0005435133093	7907	Economy	5400.00
0005435133086	7907	Economy	5400.00
0005435383220	7907	Economy	5400.00
0005435383223	7907	Economy	5400.00
0005435133090	7907	Economy	5400.00
0005435133087	7907	Economy	5400.00
0005435133089	7907	Economy	5400.00
0005435383203	7907	Economy	5400.00
0005435383202	7907	Economy	5400.00
0005435133091	7907	Economy	5400.00
0005435133094	7907	Economy	5400.00
0005435133002	33111	Economy	5900.00
0005435132969	33111	Economy	5900.00
0005435133011	33111	Economy	5400.00
0005435132968	33111	Economy	5400.00
0005435383257	33111	Economy	5400.00
0005435133067	33111	Economy	5400.00
0005435383256	33111	Economy	5400.00
0005435383258	33111	Economy	5400.00
0005435383255	33111	Economy	5400.00
0005435133001	33111	Economy	5400.00
0005435132994	33111	Economy	5400.00
0005435133012	33111	Economy	5400.00
0005435132998	33111	Economy	5400.00
0005435133029	33111	Economy	5400.00
0005435811172	4397	Business	133200.00
0005435811177	4397	Economy	44400.00
0005435811176	4397	Economy	48800.00
0005435938919	4397	Economy	48800.00
0005435938911	4397	Economy	44400.00
0005435938901	4397	Economy	44400.00
0005435811175	4397	Economy	44400.00
0005435811173	4397	Economy	44400.00
0005435811170	4397	Economy	44400.00
0005435811178	4397	Economy	44400.00
0005435811174	4397	Economy	44400.00
0005435811169	4397	Economy	44400.00
0005435938913	4397	Economy	44400.00
0005435811171	4397	Economy	44400.00
0005435938915	4397	Economy	44400.00
0005435938912	4397	Economy	44400.00
0005435811130	29453	Business	133200.00
0005435811126	29453	Business	133200.00
0005435811139	29453	Business	133200.00
0005435938936	29453	Business	133200.00
0005435811114	29453	Economy	44400.00
0005435938938	29453	Economy	44400.00
0005435938937	29453	Economy	48800.00
0005435938940	29453	Economy	44400.00
0005435938939	29453	Economy	44400.00
0005435811133	29453	Economy	44400.00
0005435811115	29453	Economy	44400.00
0005435811125	29453	Economy	44400.00
0005435811138	29453	Economy	44400.00
0005435811121	29453	Economy	44400.00
0005435811129	29453	Economy	44400.00
0005435390323	7502	Economy	13800.00
0005435160521	7502	Economy	12500.00
0005435160523	7502	Economy	12500.00
0005435160526	7502	Economy	12500.00
0005435160517	7502	Economy	12500.00
0005435160525	7502	Economy	12500.00
0005435160519	7502	Economy	12500.00
0005435160518	7502	Economy	12500.00
0005435160522	7502	Economy	12500.00
0005435160524	7502	Economy	12500.00
0005435160516	7502	Economy	12500.00
0005435390289	7502	Economy	12500.00
0005435160520	7502	Economy	12500.00
0005435160459	29579	Economy	13800.00
0005435390378	29579	Economy	13800.00
0005435160442	29579	Economy	13800.00
0005435160434	29579	Economy	13800.00
0005435390380	29579	Economy	12500.00
0005435390373	29579	Economy	12500.00
0005435390379	29579	Economy	12500.00
0005435390377	29579	Economy	12500.00
0005435160464	29579	Economy	12500.00
0005435160465	29579	Economy	12500.00
0005435160443	29579	Economy	12500.00
0005435390376	29579	Economy	12500.00
0005435160435	29579	Economy	12500.00
0005435160431	29579	Economy	12500.00
0005435160445	29579	Economy	12500.00
0005435160451	29579	Economy	12500.00
0005435390374	29579	Economy	12500.00
0005435390375	29579	Economy	12500.00
0005435160441	29579	Economy	12500.00
0005435179009	18465	Economy	4900.00
0005435178525	18465	Economy	4900.00
0005432398239	18465	Economy	4900.00
0005432398246	18465	Economy	4900.00
0005432398236	18465	Economy	4900.00
0005432398241	18465	Economy	4900.00
0005435178526	18465	Economy	4900.00
0005432398232	18465	Economy	4900.00
0005432398231	18465	Economy	4900.00
0005432398247	18465	Economy	4900.00
0005432398242	18465	Economy	4900.00
0005435178509	27131	Economy	4900.00
0005432400193	27131	Economy	4900.00
0005435178506	27131	Economy	4900.00
0005432400195	27131	Economy	4900.00
0005432400194	27131	Economy	4900.00
0005432398267	27131	Economy	4900.00
0005435179404	27131	Economy	4900.00
0005432400196	27131	Economy	4900.00
0005432398265	27131	Economy	4900.00
0005432400192	27131	Economy	4900.00
0005432398266	27131	Economy	4900.00
0005434191285	9730	Economy	4400.00
0005434191286	9730	Economy	4400.00
0005434191289	9730	Economy	4400.00
0005434191294	9730	Economy	4400.00
0005434504912	6554	Business	48400.00
0005434504919	6554	Business	48400.00
0005434504927	6554	Business	48400.00
0005434504916	6554	Business	48400.00
0005435104100	6554	Business	48400.00
0005435104107	6554	Business	48400.00
0005435104098	6554	Business	48400.00
0005434504920	6554	Business	48400.00
0005434504909	6554	Economy	16100.00
0005434504922	6554	Economy	16100.00
0005434504933	6554	Economy	16100.00
0005434504942	6554	Economy	16100.00
0005435104094	6554	Economy	16100.00
0005434504921	6554	Economy	17800.00
0005435104096	6554	Economy	16100.00
0005434504924	6554	Economy	16100.00
0005435104104	6554	Economy	16100.00
0005434504948	6554	Economy	16100.00
0005435104103	6554	Economy	16100.00
0005434504945	6554	Economy	16100.00
0005435104099	6554	Economy	16100.00
0005434504914	6554	Economy	16100.00
0005434504911	6554	Economy	16100.00
0005434504937	6554	Economy	16100.00
0005434504910	6554	Economy	16100.00
0005434504932	6554	Economy	16100.00
0005435104093	6554	Economy	16100.00
0005434504939	6554	Economy	16100.00
0005435104105	6554	Economy	16100.00
0005434504918	6554	Economy	16100.00
0005434504928	6554	Economy	16100.00
0005434504929	6554	Economy	16100.00
0005434504931	6554	Economy	16100.00
0005435104101	6554	Economy	16100.00
0005435104102	6554	Economy	16100.00
0005434504936	6554	Economy	16100.00
0005434504947	6554	Economy	16100.00
0005434504938	6554	Economy	16100.00
0005434504940	6554	Economy	16100.00
0005434504943	6554	Economy	16100.00
0005434504917	6554	Economy	16100.00
0005435104097	6554	Economy	16100.00
0005434504944	6554	Economy	16100.00
0005435104095	6554	Economy	16100.00
0005434504941	6554	Economy	16100.00
0005434504934	6554	Economy	16100.00
0005435104106	6554	Economy	16100.00
0005434504908	6554	Economy	16100.00
0005434504923	6554	Economy	16100.00
0005435104092	6554	Economy	16100.00
0005434504913	6554	Economy	16100.00
0005434504915	6554	Economy	16100.00
0005434504930	6554	Economy	16100.00
0005434504935	6554	Economy	16100.00
0005434504926	6554	Economy	16100.00
0005434504946	6554	Economy	16100.00
0005434504925	6554	Economy	16100.00
0005434504540	22657	Business	48400.00
0005434504455	22657	Business	48400.00
0005434504551	22657	Business	48400.00
0005434504445	22657	Economy	16100.00
0005434504416	22657	Economy	16100.00
0005434504506	22657	Economy	16100.00
0005434504534	22657	Economy	16100.00
0005434504456	22657	Economy	17800.00
0005434504449	22657	Economy	17800.00
0005434504678	22657	Economy	16100.00
0005435103969	22657	Economy	16100.00
0005434504502	22657	Economy	16100.00
0005434504578	22657	Economy	16100.00
0005434504492	22657	Economy	16100.00
0005434504446	22657	Economy	16100.00
0005434504390	22657	Economy	16100.00
0005435103979	22657	Economy	16100.00
0005434504518	22657	Economy	16100.00
0005434504577	22657	Economy	16100.00
0005434504612	22657	Economy	16100.00
0005434504517	22657	Economy	16100.00
0005434504457	22657	Economy	16100.00
0005434504543	22657	Economy	16100.00
0005434504613	22657	Economy	16100.00
0005434504192	22657	Economy	16100.00
0005434504652	22657	Economy	16100.00
0005434504408	22657	Economy	16100.00
0005435103968	22657	Economy	16100.00
0005434504564	22657	Economy	16100.00
0005434504450	22657	Economy	16100.00
0005434504614	22657	Economy	16100.00
0005434504383	22657	Economy	16100.00
0005434504646	22657	Economy	16100.00
0005434504539	22657	Economy	16100.00
0005434504507	22657	Economy	16100.00
0005434504653	22657	Economy	16100.00
0005434504494	22657	Economy	16100.00
0005434504454	22657	Economy	16100.00
0005434504382	22657	Economy	16100.00
0005434504495	22657	Economy	16100.00
0005434504389	22657	Economy	16100.00
0005434504425	22657	Economy	16100.00
0005435103978	22657	Economy	16100.00
0005435800123	21304	Economy	16800.00
0005435800118	21304	Economy	15300.00
0005435800130	21304	Economy	15300.00
0005435800114	21304	Economy	15300.00
0005435800113	21304	Economy	15300.00
0005435800138	21304	Economy	15300.00
0005435800128	21304	Economy	15300.00
0005435800126	21304	Economy	15300.00
0005435800119	21304	Economy	15300.00
0005435800122	21304	Economy	15300.00
0005435800127	21304	Economy	15300.00
0005435800139	21304	Economy	15300.00
0005435653920	1692	Business	50000.00
0005435653935	1692	Business	50000.00
0005435653924	1692	Business	50000.00
0005435653940	1692	Business	50000.00
0005435653907	1692	Business	50000.00
0005433368190	1692	Business	50000.00
0005435653937	1692	Business	50000.00
0005433368301	1692	Business	50000.00
0005433368363	1692	Business	50000.00
0005435653948	1692	Business	50000.00
0005435653912	1692	Business	50000.00
0005433368189	1692	Economy	16700.00
0005433368283	1692	Economy	16700.00
0005433368262	1692	Economy	16700.00
0005433368399	1692	Economy	16700.00
0005435653946	1692	Economy	16700.00
0005435653925	1692	Economy	16700.00
0005435653936	1692	Economy	16700.00
0005433368230	1692	Economy	16700.00
0005433368351	1692	Economy	16700.00
0005435653923	1692	Economy	16700.00
0005433368460	1692	Economy	18300.00
0005435653931	1692	Economy	18300.00
0005435653926	1692	Economy	18300.00
0005435653929	1692	Economy	18300.00
0005435653917	1692	Economy	16700.00
0005435653921	1692	Economy	16700.00
0005435653952	1692	Economy	16700.00
0005435653938	1692	Economy	16700.00
0005435653950	1692	Economy	16700.00
0005435653910	1692	Economy	16700.00
0005435653955	1692	Economy	16700.00
0005435653949	1692	Economy	16700.00
0005433368198	1692	Economy	16700.00
0005433368372	1692	Economy	16700.00
0005433368133	1692	Economy	16700.00
0005435653939	1692	Economy	16700.00
0005435653927	1692	Economy	16700.00
0005435653913	1692	Economy	16700.00
0005435653941	1692	Economy	16700.00
0005435653928	1692	Economy	16700.00
0005435653906	1692	Economy	16700.00
0005435653947	1692	Economy	16700.00
0005435653956	1692	Economy	16700.00
0005433368362	1692	Economy	16700.00
0005435653930	1692	Economy	16700.00
0005433368375	1692	Economy	16700.00
0005433368228	1692	Economy	16700.00
0005433368300	1692	Economy	16700.00
0005433368119	1692	Economy	16700.00
0005435653918	1692	Economy	16700.00
0005435653914	1692	Economy	16700.00
0005435653916	1692	Economy	16700.00
0005433368231	1692	Economy	16700.00
0005433368200	1692	Economy	16700.00
0005433368373	1692	Economy	16700.00
0005433368080	1692	Economy	16700.00
0005433368197	1692	Economy	16700.00
0005433367998	1692	Economy	16700.00
0005435653959	1692	Economy	16700.00
0005435653944	1692	Economy	16700.00
0005433368385	1692	Economy	16700.00
0005435653909	1692	Economy	16700.00
0005435653915	1692	Economy	16700.00
0005435653922	1692	Economy	16700.00
0005435653942	1692	Economy	16700.00
0005435653954	1692	Economy	16700.00
0005433368224	1692	Economy	16700.00
0005433368263	1692	Economy	16700.00
0005435653943	1692	Economy	16700.00
0005433368334	1692	Economy	16700.00
0005435653951	1692	Economy	16700.00
0005435653934	1692	Economy	16700.00
0005433368229	1692	Economy	16700.00
0005435653945	1692	Economy	16700.00
0005433368421	1692	Economy	16700.00
0005433367997	1692	Economy	16700.00
0005435653911	1692	Economy	16700.00
0005435653932	1692	Economy	16700.00
0005433368282	1692	Economy	16700.00
0005435653908	1692	Economy	16700.00
0005435653957	1692	Economy	16700.00
0005435653953	1692	Economy	16700.00
0005435653919	1692	Economy	16700.00
0005435653933	1692	Economy	16700.00
0005433368332	1692	Economy	16700.00
0005435653958	1692	Economy	16700.00
0005435653401	21682	Business	50000.00
0005433368617	21682	Business	50000.00
0005435653464	21682	Business	50000.00
0005433368637	21682	Business	50000.00
0005433368614	21682	Business	50000.00
0005435653421	21682	Business	50000.00
0005433368618	21682	Business	50000.00
0005435653478	21682	Business	50000.00
0005435653317	21682	Business	50000.00
0005433368603	21682	Business	50000.00
0005435653555	21682	Business	50000.00
0005435653383	21682	Economy	16700.00
0005435653563	21682	Economy	16700.00
0005433368620	21682	Economy	16700.00
0005433368610	21682	Economy	16700.00
0005435653533	21682	Economy	16700.00
0005435653411	21682	Economy	16700.00
0005435653467	21682	Economy	16700.00
0005435653450	21682	Economy	16700.00
0005433368627	21682	Economy	18300.00
0005435653384	21682	Economy	18300.00
0005433368630	21682	Economy	18300.00
0005435653419	21682	Economy	18300.00
0005435653503	21682	Economy	16700.00
0005435653484	21682	Economy	16700.00
0005433368613	21682	Economy	16700.00
0005435653518	21682	Economy	16700.00
0005433368629	21682	Economy	16700.00
0005433368628	21682	Economy	16700.00
0005433368631	21682	Economy	16700.00
0005435653531	21682	Economy	16700.00
0005433368623	21682	Economy	16700.00
0005435653459	21682	Economy	16700.00
0005435653532	21682	Economy	16700.00
0005435653564	21682	Economy	16700.00
0005433368633	21682	Economy	16700.00
0005433368602	21682	Economy	16700.00
0005433368634	21682	Economy	16700.00
0005433368624	21682	Economy	16700.00
0005433368625	21682	Economy	16700.00
0005435653400	21682	Economy	16700.00
0005433368609	21682	Economy	16700.00
0005435653570	21682	Economy	16700.00
0005435653466	21682	Economy	16700.00
0005435653315	21682	Economy	16700.00
0005433368635	21682	Economy	16700.00
0005433368601	21682	Economy	16700.00
0005435653474	21682	Economy	16700.00
0005435653480	21682	Economy	16700.00
0005435653534	21682	Economy	16700.00
0005435653571	21682	Economy	16700.00
0005435653556	21682	Economy	16700.00
0005433368611	21682	Economy	16700.00
0005435653318	21682	Economy	16700.00
0005433368621	21682	Economy	16700.00
0005433368626	21682	Economy	16700.00
0005435653558	21682	Economy	16700.00
0005435653515	21682	Economy	16700.00
0005435653481	21682	Economy	16700.00
0005435653559	21682	Economy	16700.00
0005435653504	21682	Economy	16700.00
0005435653451	21682	Economy	16700.00
0005433368605	21682	Economy	16700.00
0005435653420	21682	Economy	16700.00
0005433368615	21682	Economy	16700.00
0005435653498	21682	Economy	16700.00
0005433368607	21682	Economy	16700.00
0005433368622	21682	Economy	16700.00
0005435653551	21682	Economy	16700.00
0005435653324	21682	Economy	16700.00
0005433368612	21682	Economy	16700.00
0005435653572	21682	Economy	16700.00
0005433368616	21682	Economy	16700.00
0005435653295	21682	Economy	16700.00
0005433368638	21682	Economy	16700.00
0005435653497	21682	Economy	16700.00
0005433368619	21682	Economy	16700.00
0005435653550	21682	Economy	16700.00
0005433368606	21682	Economy	16700.00
0005435653426	21682	Economy	16700.00
0005433368604	21682	Economy	16700.00
0005433368608	21682	Economy	16700.00
0005433368636	21682	Economy	16700.00
0005435653463	21682	Economy	16700.00
0005433368632	21682	Economy	16700.00
0005435627122	12241	Economy	11200.00
0005433986859	4162	Business	21500.00
0005433986863	4162	Business	21500.00
0005433986875	4162	Business	21500.00
0005433986853	4162	Business	21500.00
0005433986873	4162	Business	21500.00
0005433986874	4162	Economy	7200.00
0005433986862	4162	Economy	7200.00
0005433986877	4162	Economy	7200.00
0005433986864	4162	Economy	7200.00
0005433986850	4162	Economy	7200.00
0005433986848	4162	Economy	7200.00
0005433986868	4162	Economy	7200.00
0005433986865	4162	Economy	7200.00
0005433986855	4162	Economy	7200.00
0005433986852	4162	Economy	7200.00
0005433986854	4162	Economy	7200.00
0005435788821	4162	Economy	7200.00
0005433986872	4162	Economy	7200.00
0005433986851	4162	Economy	7200.00
0005433986866	4162	Economy	7200.00
0005433986845	4162	Economy	7200.00
0005435788820	4162	Economy	7200.00
0005433986860	4162	Economy	7200.00
0005433986876	4162	Economy	7200.00
0005433986857	4162	Economy	7200.00
0005433986867	4162	Economy	7200.00
0005433986869	4162	Economy	7200.00
0005433986847	4162	Economy	7200.00
0005433986856	4162	Economy	7200.00
0005433986861	4162	Economy	7200.00
0005433986849	4162	Economy	7200.00
0005433986858	4162	Economy	7200.00
0005433986870	4162	Economy	7200.00
0005435788822	4162	Economy	7200.00
0005433986871	4162	Economy	7200.00
0005433986846	4162	Economy	7200.00
0005433986367	25656	Business	21500.00
0005433986326	25656	Business	21500.00
0005433986454	25656	Economy	7200.00
0005433986229	25656	Economy	7200.00
0005433986234	25656	Economy	7200.00
0005433986475	25656	Economy	7900.00
0005433986330	25656	Economy	7900.00
0005435788800	25656	Economy	7900.00
0005433986438	25656	Economy	7200.00
0005433986434	25656	Economy	7200.00
0005433986304	25656	Economy	7200.00
0005433986388	25656	Economy	7200.00
0005433986156	25656	Economy	7200.00
0005433986339	25656	Economy	7200.00
0005433986301	25656	Economy	7200.00
0005433986474	25656	Economy	7200.00
0005433986340	25656	Economy	7200.00
0005433986208	25656	Economy	7200.00
0005433986209	25656	Economy	7200.00
0005433986413	25656	Economy	7200.00
0005433986394	25656	Economy	7200.00
0005433986453	25656	Economy	7200.00
0005433986283	25656	Economy	7200.00
0005435788799	25656	Economy	7200.00
0005433986435	25656	Economy	7200.00
0005433986315	25656	Economy	7200.00
0005433986264	25656	Economy	7200.00
0005433986387	25656	Economy	7200.00
0005433986265	25656	Economy	7200.00
0005433986193	25656	Economy	7200.00
0005433986294	25656	Economy	7200.00
0005433986341	25656	Economy	7200.00
0005433986284	25656	Economy	7200.00
0005433986437	25656	Economy	7200.00
0005433986414	25656	Economy	7200.00
0005433986258	25656	Economy	7200.00
0005433986243	25656	Economy	7200.00
0005433986422	25656	Economy	7200.00
0005435719584	24781	Economy	9400.00
0005435719583	24781	Economy	9400.00
0005433168424	1636	Economy	17000.00
0005434509293	1636	Economy	17000.00
0005434509303	1636	Economy	15500.00
0005434509294	1636	Economy	15500.00
0005433168409	1636	Economy	15500.00
0005433168412	1636	Economy	15500.00
0005434509292	1636	Economy	15500.00
0005433168410	1636	Economy	15500.00
0005434509295	1636	Economy	15500.00
0005433168414	1636	Economy	15500.00
0005434509302	1636	Economy	15500.00
0005434509301	1636	Economy	15500.00
0005434509297	1636	Economy	15500.00
0005433168413	1636	Economy	15500.00
0005434509300	1636	Economy	15500.00
0005434509290	1636	Economy	15500.00
0005434509291	1636	Economy	15500.00
0005434509289	1636	Economy	15500.00
0005433168403	1636	Economy	15500.00
0005434509288	1636	Economy	15500.00
0005433168418	1636	Economy	15500.00
0005433168408	1636	Economy	15500.00
0005434509299	1636	Economy	15500.00
0005434509298	1636	Economy	15500.00
0005433168411	1636	Economy	15500.00
0005434509296	1636	Economy	15500.00
0005432663053	17821	Business	18000.00
0005432657489	17821	Business	18000.00
0005432659726	17821	Business	18000.00
0005432661932	17821	Business	18000.00
0005432869660	17821	Business	18000.00
0005432869657	17821	Business	18000.00
0005432667476	17821	Economy	6000.00
0005432869659	17821	Economy	6000.00
0005432657485	17821	Economy	6000.00
0005432659722	17821	Economy	6600.00
0005432659732	17821	Economy	6600.00
0005434151763	17821	Economy	6600.00
0005432659729	17821	Economy	6600.00
0005432661933	17821	Economy	6000.00
0005432657486	17821	Economy	6000.00
0005432659724	17821	Economy	6000.00
0005432659731	17821	Economy	6000.00
0005432655664	17821	Economy	6000.00
0005432655651	17821	Economy	6000.00
0005432655654	17821	Economy	6000.00
0005434151762	17821	Economy	6000.00
0005432869656	17821	Economy	6000.00
0005432869655	17821	Economy	6000.00
0005432655665	17821	Economy	6000.00
0005432655642	17821	Economy	6000.00
0005432869662	17821	Economy	6000.00
0005432659730	17821	Economy	6000.00
0005432869661	17821	Economy	6000.00
0005432657473	17821	Economy	6000.00
0005432658609	17821	Economy	6000.00
0005432657488	17821	Economy	6000.00
0005432655655	17821	Economy	6000.00
0005434151765	17821	Economy	6000.00
0005432658614	17821	Economy	6000.00
0005432655628	17821	Economy	6000.00
0005432666419	17821	Economy	6000.00
0005432655613	17821	Economy	6000.00
0005432667479	17821	Economy	6000.00
0005432869658	17821	Economy	6000.00
0005432659723	17821	Economy	6000.00
0005432655641	17821	Economy	6000.00
0005432666414	17821	Economy	6000.00
0005432663065	17821	Economy	6000.00
0005432657484	17821	Economy	6000.00
0005434151764	17821	Economy	6000.00
0005432657487	17821	Economy	6000.00
0005432666411	17821	Economy	6000.00
0005432657474	17821	Economy	6000.00
0005432655650	17821	Economy	6000.00
0005432869576	26298	Business	18000.00
0005432655752	26298	Business	18000.00
0005432655753	26298	Business	18000.00
0005432666428	26298	Business	18000.00
0005432657505	26298	Business	18000.00
0005432665312	26298	Economy	6000.00
0005432659745	26298	Economy	6000.00
0005432655749	26298	Economy	6000.00
0005432660856	26298	Economy	6600.00
0005432667493	26298	Economy	6600.00
0005432657504	26298	Economy	6000.00
0005432665313	26298	Economy	6000.00
0005432655751	26298	Economy	6000.00
0005432869575	26298	Economy	6000.00
0005432869563	26298	Economy	6000.00
0005432655743	26298	Economy	6000.00
0005432658629	26298	Economy	6000.00
0005432869583	26298	Economy	6000.00
0005432655747	26298	Economy	6000.00
0005432667494	26298	Economy	6000.00
0005432657508	26298	Economy	6000.00
0005432667491	26298	Economy	6000.00
0005432657507	26298	Economy	6000.00
0005432655746	26298	Economy	6000.00
0005432869572	26298	Economy	6000.00
0005432869562	26298	Economy	6000.00
0005432658630	26298	Economy	6000.00
0005432655745	26298	Economy	6000.00
0005432655744	26298	Economy	6000.00
0005432655748	26298	Economy	6000.00
0005432655750	26298	Economy	6000.00
0005432657506	26298	Economy	6000.00
0005432666427	26298	Economy	6000.00
0005432667492	26298	Economy	6000.00
0005432639280	25067	Business	87300.00
0005432866156	25067	Business	87300.00
0005432639249	25067	Business	87300.00
0005432866155	25067	Business	87300.00
0005432866144	25067	Business	87300.00
0005432639197	25067	Business	87300.00
0005432639229	25067	Economy	29100.00
0005432639288	25067	Economy	29100.00
0005432639228	25067	Economy	29100.00
0005432866146	25067	Economy	29100.00
0005432866145	25067	Economy	32000.00
0005432639293	25067	Economy	32000.00
0005432639247	25067	Economy	29100.00
0005432866151	25067	Economy	29100.00
0005432639216	25067	Economy	29100.00
0005432639294	25067	Economy	29100.00
0005432639215	25067	Economy	29100.00
0005432866148	25067	Economy	29100.00
0005432639285	25067	Economy	29100.00
0005432866152	25067	Economy	29100.00
0005432639217	25067	Economy	29100.00
0005432639196	25067	Economy	29100.00
0005432639227	25067	Economy	29100.00
0005432866157	25067	Economy	29100.00
0005432639248	25067	Economy	29100.00
0005432639286	25067	Economy	29100.00
0005432866149	25067	Economy	29100.00
0005432639289	25067	Economy	29100.00
0005432639250	25067	Economy	29100.00
0005432639290	25067	Economy	29100.00
0005432639255	25067	Economy	29100.00
0005432639238	25067	Economy	29100.00
0005432866150	25067	Economy	29100.00
0005432639254	25067	Economy	29100.00
0005432639220	25067	Economy	29100.00
0005432866154	25067	Economy	29100.00
0005432639279	25067	Economy	29100.00
0005432639237	25067	Economy	29100.00
0005432866153	25067	Economy	29100.00
0005432866147	25067	Economy	29100.00
0005432329612	3127	Business	16100.00
0005432905187	3127	Business	16100.00
0005432287291	3127	Business	16100.00
0005432329596	3127	Business	16100.00
0005432287290	3127	Business	16100.00
0005432329592	3127	Business	16100.00
0005432329588	3127	Business	16100.00
0005432329620	3127	Economy	5400.00
0005432329582	3127	Economy	5400.00
0005432329617	3127	Economy	5400.00
0005432329598	3127	Economy	5400.00
0005432329597	3127	Economy	5400.00
0005432287293	3127	Economy	5400.00
0005432329594	3127	Economy	5400.00
0005432329608	3127	Economy	5400.00
0005432329609	3127	Economy	5900.00
0005432329623	3127	Economy	5900.00
0005432329627	3127	Economy	5900.00
0005432287288	3127	Economy	5900.00
0005432287292	3127	Economy	5400.00
0005432329590	3127	Economy	5400.00
0005432905201	3127	Economy	5400.00
0005432329625	3127	Economy	5400.00
0005432329611	3127	Economy	5400.00
0005432329601	3127	Economy	5400.00
0005432329604	3127	Economy	5400.00
0005432329606	3127	Economy	5400.00
0005432329603	3127	Economy	5400.00
0005432329613	3127	Economy	5400.00
0005432329622	3127	Economy	5400.00
0005432329586	3127	Economy	5400.00
0005432329587	3127	Economy	5400.00
0005432329605	3127	Economy	5400.00
0005432905202	3127	Economy	5400.00
0005432329589	3127	Economy	5400.00
0005432329614	3127	Economy	5400.00
0005433439004	3127	Economy	5400.00
0005432329581	3127	Economy	5400.00
0005432905200	3127	Economy	5400.00
0005432905186	3127	Economy	5400.00
0005432287289	3127	Economy	5400.00
0005432329591	3127	Economy	5400.00
0005432329616	3127	Economy	5400.00
0005432329599	3127	Economy	5400.00
0005432329583	3127	Economy	5400.00
0005432905203	3127	Economy	5400.00
0005432329595	3127	Economy	5400.00
0005432329600	3127	Economy	5400.00
0005432329615	3127	Economy	5400.00
0005432329624	3127	Economy	5400.00
0005433439003	3127	Economy	5400.00
0005432329602	3127	Economy	5400.00
0005432329610	3127	Economy	5400.00
0005432329618	3127	Economy	5400.00
0005432329585	3127	Economy	5400.00
0005432329626	3127	Economy	5400.00
0005432905213	3127	Economy	5400.00
0005432329619	3127	Economy	5400.00
0005432329621	3127	Economy	5400.00
0005432329607	3127	Economy	5400.00
0005432329584	3127	Economy	5400.00
0005432329593	3127	Economy	5400.00
0005432329284	31122	Business	16100.00
0005432329230	31122	Business	16100.00
0005432329245	31122	Business	16100.00
0005432328971	31122	Business	16100.00
0005432329144	31122	Business	16100.00
0005432054361	31122	Business	16100.00
0005432848864	31122	Business	16100.00
0005432329164	31122	Economy	5400.00
0005432329215	31122	Economy	5400.00
0005432328983	31122	Economy	5400.00
0005432905239	31122	Economy	5400.00
0005432848867	31122	Economy	5400.00
0005432054362	31122	Economy	5400.00
0005432329292	31122	Economy	5400.00
0005432329229	31122	Economy	5900.00
0005432905237	31122	Economy	5900.00
0005432329233	31122	Economy	5900.00
0005433438970	31122	Economy	5900.00
0005432329214	31122	Economy	5400.00
0005432328986	31122	Economy	5400.00
0005432329330	31122	Economy	5400.00
0005432848865	31122	Economy	5400.00
0005433438932	31122	Economy	5400.00
0005432905238	31122	Economy	5400.00
0005432329166	31122	Economy	5400.00
0005432329129	31122	Economy	5400.00
0005432848862	31122	Economy	5400.00
0005432329291	31122	Economy	5400.00
0005432329146	31122	Economy	5400.00
0005432329227	31122	Economy	5400.00
0005432329228	31122	Economy	5400.00
0005432905242	31122	Economy	5400.00
0005432848863	31122	Economy	5400.00
0005432848866	31122	Economy	5400.00
0005432905241	31122	Economy	5400.00
0005432329261	31122	Economy	5400.00
0005432329265	31122	Economy	5400.00
0005432329145	31122	Economy	5400.00
0005432329192	31122	Economy	5400.00
0005432329181	31122	Economy	5400.00
0005432329163	31122	Economy	5400.00
0005433438960	31122	Economy	5400.00
0005432905240	31122	Economy	5400.00
0005432328985	31122	Economy	5400.00
0005433438959	31122	Economy	5400.00
0005433438947	31122	Economy	5400.00
0005433438968	31122	Economy	5400.00
0005433438964	31122	Economy	5400.00
0005432329246	31122	Economy	5400.00
0005433438933	31122	Economy	5400.00
0005432054364	31122	Economy	5400.00
0005433438962	31122	Economy	5400.00
0005432329331	31122	Economy	5400.00
0005433438961	31122	Economy	5400.00
0005432329015	31122	Economy	5400.00
0005432329234	31122	Economy	5400.00
0005432054363	31122	Economy	5400.00
0005432329209	31122	Economy	5400.00
0005432328982	31122	Economy	5400.00
0005432328784	31122	Economy	5400.00
0005432329122	31122	Economy	5400.00
0005432329285	31122	Economy	5400.00
0005435488030	6215	Business	124600.00
0005435488126	6215	Business	124600.00
0005435488025	6215	Business	124600.00
0005434310006	6215	Business	124600.00
0005434310013	6215	Business	124600.00
0005435297141	6215	Economy	41500.00
0005435487988	6215	Economy	41500.00
0005435488069	6215	Economy	41500.00
0005435488031	6215	Economy	41500.00
0005435487980	6215	Economy	41500.00
0005435488158	6215	Economy	41500.00
0005435999596	6215	Economy	41500.00
0005435488036	6215	Economy	41500.00
0005435488029	6215	Economy	41500.00
0005435999594	6215	Economy	41500.00
0005432146239	6215	Economy	41500.00
0005435297113	6215	Economy	41500.00
0005435487960	6215	Economy	41500.00
0005434310007	6215	Economy	41500.00
0005434310017	6215	Economy	41500.00
0005435297114	6215	Economy	41500.00
0005435488136	6215	Economy	41500.00
0005435488094	6215	Economy	41500.00
0005435487991	6215	Economy	41500.00
0005434310011	6215	Economy	45700.00
0005435488005	6215	Economy	45700.00
0005432146241	6215	Economy	45700.00
0005434310016	6215	Economy	41500.00
0005435297123	6215	Economy	41500.00
0005435999593	6215	Economy	41500.00
0005435487997	6215	Economy	41500.00
0005435488089	6215	Economy	41500.00
0005435488070	6215	Economy	41500.00
0005434310005	6215	Economy	41500.00
0005434310015	6215	Economy	41500.00
0005434310010	6215	Economy	41500.00
0005435999592	6215	Economy	41500.00
0005434310009	6215	Economy	41500.00
0005435488127	6215	Economy	41500.00
0005435488114	6215	Economy	41500.00
0005435999591	6215	Economy	41500.00
0005434310014	6215	Economy	41500.00
0005435488095	6215	Economy	41500.00
0005435488128	6215	Economy	41500.00
0005434310018	6215	Economy	41500.00
0005435488014	6215	Economy	41500.00
0005435488037	6215	Economy	41500.00
0005435488159	6215	Economy	41500.00
0005435488024	6215	Economy	41500.00
0005435999595	6215	Economy	41500.00
0005435487986	6215	Economy	41500.00
0005434310012	6215	Economy	41500.00
0005435488003	6215	Economy	41500.00
0005435488004	6215	Economy	41500.00
0005435297158	6215	Economy	41500.00
0005435297138	6215	Economy	41500.00
0005435488015	6215	Economy	41500.00
0005435487998	6215	Economy	41500.00
0005434310008	6215	Economy	41500.00
0005435999590	6215	Economy	41500.00
0005435297137	6215	Economy	41500.00
0005435297122	6215	Economy	41500.00
0005432146240	6215	Economy	41500.00
0005435297191	19569	Business	124600.00
0005435999409	19569	Business	124600.00
0005435488245	19569	Business	124600.00
0005434309890	19569	Business	124600.00
0005435488231	19569	Business	124600.00
0005434309877	19569	Economy	41500.00
0005435488246	19569	Economy	41500.00
0005435488251	19569	Economy	41500.00
0005435488248	19569	Economy	41500.00
0005435488230	19569	Economy	41500.00
0005435999418	19569	Economy	41500.00
0005435488243	19569	Economy	41500.00
0005435297194	19569	Economy	41500.00
0005435999423	19569	Economy	41500.00
0005435999364	19569	Economy	41500.00
0005435297193	19569	Economy	41500.00
0005435488249	19569	Economy	41500.00
0005435488247	19569	Economy	41500.00
0005435999402	19569	Economy	41500.00
0005435488240	19569	Economy	41500.00
0005435999403	19569	Economy	41500.00
0005434309939	19569	Economy	41500.00
0005434309947	19569	Economy	45700.00
0005435488241	19569	Economy	45700.00
0005435999417	19569	Economy	45700.00
0005435999416	19569	Economy	45700.00
0005435297196	19569	Economy	41500.00
0005434309948	19569	Economy	41500.00
0005435999389	19569	Economy	41500.00
0005435488244	19569	Economy	41500.00
0005435999411	19569	Economy	41500.00
0005435999399	19569	Economy	41500.00
0005434309873	19569	Economy	41500.00
0005435488233	19569	Economy	41500.00
0005435488250	19569	Economy	41500.00
0005435297195	19569	Economy	41500.00
0005435488242	19569	Economy	41500.00
0005435297197	19569	Economy	41500.00
0005435488232	19569	Economy	41500.00
0005435999400	19569	Economy	41500.00
0005435999401	19569	Economy	41500.00
0005435488234	19569	Economy	41500.00
0005435999383	19569	Economy	41500.00
0005435297190	19569	Economy	41500.00
0005435488235	19569	Economy	41500.00
0005435488229	19569	Economy	41500.00
0005435488237	19569	Economy	41500.00
0005435999388	19569	Economy	41500.00
0005435488238	19569	Economy	41500.00
0005435297192	19569	Economy	41500.00
0005435999415	19569	Economy	41500.00
0005435999427	19569	Economy	41500.00
0005435999408	19569	Economy	41500.00
0005435488239	19569	Economy	41500.00
0005435488236	19569	Economy	41500.00
0005435508600	1556	Business	86000.00
0005435502745	1556	Business	86000.00
0005435508604	1556	Business	86000.00
0005435518270	1556	Business	86000.00
0005435508611	1556	Business	86000.00
0005435508610	1556	Business	86000.00
0005435502740	1556	Business	86000.00
0005434566185	1556	Business	86000.00
0005435502747	1556	Business	86000.00
0005435518274	1556	Business	86000.00
0005435518278	1556	Economy	28700.00
0005435508605	1556	Economy	28700.00
0005435508609	1556	Economy	28700.00
0005435502732	1556	Economy	28700.00
0005435518266	1556	Economy	28700.00
0005433186184	1556	Economy	28700.00
0005435518272	1556	Economy	28700.00
0005435502744	1556	Economy	28700.00
0005435502739	1556	Economy	28700.00
0005435502737	1556	Economy	31500.00
0005435518268	1556	Economy	31500.00
0005433186179	1556	Economy	31500.00
0005433186259	1556	Economy	31500.00
0005435508607	1556	Economy	28700.00
0005434566180	1556	Economy	28700.00
0005435508614	1556	Economy	28700.00
0005433186239	1556	Economy	28700.00
0005435502735	1556	Economy	28700.00
0005435508615	1556	Economy	28700.00
0005435502738	1556	Economy	28700.00
0005435508603	1556	Economy	28700.00
0005435518264	1556	Economy	28700.00
0005435518263	1556	Economy	28700.00
0005435502734	1556	Economy	28700.00
0005435508608	1556	Economy	28700.00
0005434566183	1556	Economy	28700.00
0005434566186	1556	Economy	28700.00
0005433186180	1556	Economy	28700.00
0005435502746	1556	Economy	28700.00
0005434566184	1556	Economy	28700.00
0005435518273	1556	Economy	28700.00
0005434566174	1556	Economy	28700.00
0005435508613	1556	Economy	28700.00
0005432291978	1556	Economy	28700.00
0005435502730	1556	Economy	28700.00
0005435518275	1556	Economy	28700.00
0005432291980	1556	Economy	28700.00
0005435518267	1556	Economy	28700.00
0005435502729	1556	Economy	28700.00
0005435508612	1556	Economy	28700.00
0005433186189	1556	Economy	28700.00
0005434566175	1556	Economy	28700.00
0005435502733	1556	Economy	28700.00
0005434566173	1556	Economy	28700.00
0005433186258	1556	Economy	28700.00
0005435518269	1556	Economy	28700.00
0005435502741	1556	Economy	28700.00
0005435508602	1556	Economy	28700.00
0005435518276	1556	Economy	28700.00
0005434566178	1556	Economy	28700.00
0005433186218	1556	Economy	28700.00
0005434566182	1556	Economy	28700.00
0005435502748	1556	Economy	28700.00
0005435518265	1556	Economy	28700.00
0005435508601	1556	Economy	28700.00
0005432291979	1556	Economy	28700.00
0005435502736	1556	Economy	28700.00
0005434566177	1556	Economy	28700.00
0005435508606	1556	Economy	28700.00
0005433186208	1556	Economy	28700.00
0005435502749	1556	Economy	28700.00
0005434566176	1556	Economy	28700.00
0005435502731	1556	Economy	28700.00
0005435518271	1556	Economy	28700.00
0005433186205	1556	Economy	28700.00
0005433186188	1556	Economy	28700.00
0005435518262	1556	Economy	28700.00
0005435502742	1556	Economy	28700.00
0005434566181	1556	Economy	28700.00
0005435502743	1556	Economy	28700.00
0005435502750	1556	Economy	28700.00
0005435518277	1556	Economy	28700.00
0005433186172	1556	Economy	28700.00
0005434566179	1556	Economy	28700.00
0005434566018	20863	Business	86000.00
0005435545823	20863	Business	86000.00
0005435529421	20863	Business	86000.00
0005435502530	20863	Business	86000.00
0005435529486	20863	Business	86000.00
0005434566057	20863	Business	86000.00
0005433186287	20863	Business	86000.00
0005434566049	20863	Business	86000.00
0005434566017	20863	Business	86000.00
0005435502474	20863	Business	86000.00
0005435545777	20863	Business	86000.00
0005433186283	20863	Business	86000.00
0005435529492	20863	Economy	28700.00
0005435529533	20863	Economy	28700.00
0005435502545	20863	Economy	28700.00
0005435502531	20863	Economy	28700.00
0005433186286	20863	Economy	28700.00
0005435502482	20863	Economy	28700.00
0005433186284	20863	Economy	28700.00
0005434566013	20863	Economy	28700.00
0005435529493	20863	Economy	31500.00
0005435545820	20863	Economy	31500.00
0005433186285	20863	Economy	31500.00
0005435529478	20863	Economy	31500.00
0005435529532	20863	Economy	31500.00
0005435529464	20863	Economy	28700.00
0005435502534	20863	Economy	28700.00
0005435529462	20863	Economy	28700.00
0005435529436	20863	Economy	28700.00
0005435545755	20863	Economy	28700.00
0005433186289	20863	Economy	28700.00
0005434566109	20863	Economy	28700.00
0005434566048	20863	Economy	28700.00
0005434566111	20863	Economy	28700.00
0005435545822	20863	Economy	28700.00
0005435545790	20863	Economy	28700.00
0005434566122	20863	Economy	28700.00
0005435502546	20863	Economy	28700.00
0005435502501	20863	Economy	28700.00
0005435502509	20863	Economy	28700.00
0005435529445	20863	Economy	28700.00
0005435502547	20863	Economy	28700.00
0005435502397	20863	Economy	28700.00
0005435545821	20863	Economy	28700.00
0005435529373	20863	Economy	28700.00
0005435502580	20863	Economy	28700.00
0005434566123	20863	Economy	28700.00
0005435529485	20863	Economy	28700.00
0005435529466	20863	Economy	28700.00
0005435529531	20863	Economy	28700.00
0005435545789	20863	Economy	28700.00
0005434566069	20863	Economy	28700.00
0005435502647	20863	Economy	28700.00
0005435529437	20863	Economy	28700.00
0005435529479	20863	Economy	28700.00
0005435529542	20863	Economy	28700.00
0005435545796	20863	Economy	28700.00
0005435545774	20863	Economy	28700.00
0005435502574	20863	Economy	28700.00
0005435529471	20863	Economy	28700.00
0005435529446	20863	Economy	28700.00
0005435545795	20863	Economy	28700.00
0005433186288	20863	Economy	28700.00
0005435502483	20863	Economy	28700.00
0005435529432	20863	Economy	28700.00
0005435529470	20863	Economy	28700.00
0005435502559	20863	Economy	28700.00
0005434566025	20863	Economy	28700.00
0005435529487	20863	Economy	28700.00
0005435529480	20863	Economy	28700.00
0005435529513	20863	Economy	28700.00
0005435529463	20863	Economy	28700.00
0005435529352	20863	Economy	28700.00
0005434566070	20863	Economy	28700.00
0005435502511	20863	Economy	28700.00
0005435545799	20863	Economy	28700.00
0005433186290	20863	Economy	28700.00
0005433186291	20863	Economy	28700.00
0005435529451	20863	Economy	28700.00
0005435545788	20863	Economy	28700.00
0005435502510	20863	Economy	28700.00
0005434566056	20863	Economy	28700.00
0005435502523	20863	Economy	28700.00
0005435502540	20863	Economy	28700.00
0005434566055	20863	Economy	28700.00
0005435545773	20863	Economy	28700.00
0005435529465	20863	Economy	28700.00
0005435502438	20863	Economy	28700.00
0005435931653	3886	Economy	21600.00
0005435153869	3886	Economy	19700.00
0005435153875	3886	Economy	19700.00
0005435153872	3886	Economy	19700.00
0005435931632	3886	Economy	19700.00
0005435153874	3886	Economy	19700.00
0005435931629	3886	Economy	19700.00
0005435931633	3886	Economy	19700.00
0005435153873	3886	Economy	19700.00
0005435931638	3886	Economy	19700.00
0005435931649	3886	Economy	19700.00
0005435153870	3886	Economy	19700.00
0005435153871	3886	Economy	19700.00
0005435931628	3886	Economy	19700.00
0005435153830	21884	Economy	21600.00
0005435153816	21884	Economy	19700.00
0005435153825	21884	Economy	19700.00
0005435931675	21884	Economy	19700.00
0005435153833	21884	Economy	19700.00
0005435931677	21884	Economy	19700.00
0005435153826	21884	Economy	19700.00
0005435931676	21884	Economy	19700.00
0005435153835	21884	Economy	19700.00
0005435153834	21884	Economy	19700.00
0005435153821	21884	Economy	19700.00
0005432629134	7181	Economy	14300.00
0005432629145	7181	Economy	13000.00
0005432629143	7181	Economy	13000.00
0005432629136	7181	Economy	13000.00
0005432629133	7181	Economy	13000.00
0005432629138	7181	Economy	13000.00
0005432629144	7181	Economy	13000.00
0005432629139	7181	Economy	13000.00
0005435225689	7181	Economy	13000.00
0005432629141	7181	Economy	13000.00
0005432629140	7181	Economy	13000.00
0005432629137	7181	Economy	13000.00
0005432629142	7181	Economy	13000.00
0005432629135	7181	Economy	13000.00
0005432629132	7181	Economy	13000.00
0005432629065	28095	Economy	13000.00
0005432629064	28095	Economy	13000.00
0005432629025	28095	Economy	13000.00
0005435225741	28095	Economy	13000.00
0005432629028	28095	Economy	13000.00
0005435225747	28095	Economy	13000.00
0005435225740	28095	Economy	13000.00
0005435225742	28095	Economy	13000.00
0005435225743	28095	Economy	13000.00
0005435225745	28095	Economy	13000.00
0005435225746	28095	Economy	13000.00
0005435225744	28095	Economy	13000.00
0005432629035	28095	Economy	13000.00
0005432628921	28095	Economy	13000.00
0005434267986	8758	Economy	11500.00
0005434267997	8758	Economy	11500.00
0005435960126	8758	Economy	10500.00
0005435960124	8758	Economy	10500.00
0005435960127	8758	Economy	10500.00
0005434267996	8758	Economy	10500.00
0005435960125	8758	Economy	10500.00
0005435960128	8758	Economy	10500.00
0005434267990	8758	Economy	10500.00
0005434268025	15245	Economy	10500.00
0005434268024	15245	Economy	10500.00
0005434268026	15245	Economy	10500.00
0005434268023	15245	Economy	10500.00
0005432675427	1180	Business	115000.00
0005432873375	1180	Business	115000.00
0005432675437	1180	Business	115000.00
0005432693650	1180	Business	115000.00
0005432677646	1180	Business	115000.00
0005432693657	1180	Business	115000.00
0005432873345	1180	Business	115000.00
0005432693661	1180	Business	115000.00
0005432693633	1180	Business	115000.00
0005432675435	1180	Economy	38300.00
0005432693637	1180	Business	115000.00
0005432675425	1180	Economy	38300.00
0005432693648	1180	Economy	38300.00
0005432693634	1180	Economy	38300.00
0005432693651	1180	Economy	38300.00
0005432693638	1180	Economy	38300.00
0005432675428	1180	Economy	42200.00
0005432675436	1180	Economy	42200.00
0005432693652	1180	Economy	38300.00
0005432693654	1180	Economy	38300.00
0005432693642	1180	Economy	38300.00
0005432873374	1180	Economy	38300.00
0005432677648	1180	Economy	38300.00
0005432693647	1180	Economy	38300.00
0005432677650	1180	Economy	38300.00
0005432693662	1180	Economy	38300.00
0005432693643	1180	Economy	38300.00
0005432693644	1180	Economy	38300.00
0005432693641	1180	Economy	38300.00
0005432873380	1180	Economy	38300.00
0005432675426	1180	Economy	38300.00
0005432693658	1180	Economy	38300.00
0005432675438	1180	Economy	38300.00
0005432693639	1180	Economy	38300.00
0005432693649	1180	Economy	38300.00
0005432873381	1180	Economy	38300.00
0005432693660	1180	Economy	38300.00
0005432873335	1180	Economy	38300.00
0005432675431	1180	Economy	38300.00
0005432677649	1180	Economy	38300.00
0005432675432	1180	Economy	38300.00
0005432675430	1180	Economy	38300.00
0005432677647	1180	Economy	38300.00
0005432675429	1180	Economy	38300.00
0005432693635	1180	Economy	38300.00
0005432873346	1180	Economy	38300.00
0005432693640	1180	Economy	38300.00
0005432873385	1180	Economy	38300.00
0005432693646	1180	Economy	38300.00
0005432693656	1180	Economy	38300.00
0005432873334	1180	Economy	38300.00
0005432675434	1180	Economy	38300.00
0005432693655	1180	Economy	38300.00
0005432675433	1180	Economy	38300.00
0005432693645	1180	Economy	38300.00
0005432693659	1180	Economy	38300.00
0005432693636	1180	Economy	38300.00
0005432693653	1180	Economy	38300.00
0005432693268	17510	Business	115000.00
0005432693466	17510	Business	115000.00
0005432675258	17510	Business	115000.00
0005432873430	17510	Business	115000.00
0005432693355	17510	Business	115000.00
0005432693418	17510	Business	115000.00
0005432693249	17510	Business	115000.00
0005432693419	17510	Business	115000.00
0005432675330	17510	Business	115000.00
0005432693332	17510	Business	115000.00
0005432675260	17510	Business	115000.00
0005432693297	17510	Business	115000.00
0005432873432	17510	Business	115000.00
0005432693359	17510	Business	115000.00
0005432693273	17510	Economy	38300.00
0005432693438	17510	Economy	38300.00
0005432677591	17510	Economy	38300.00
0005432873433	17510	Economy	38300.00
0005432693486	17510	Economy	38300.00
0005432693331	17510	Economy	42200.00
0005432693431	17510	Economy	42200.00
0005432675376	17510	Economy	42200.00
0005432675290	17510	Economy	38300.00
0005432675274	17510	Economy	38300.00
0005432693514	17510	Economy	38300.00
0005432873431	17510	Economy	38300.00
0005432677609	17510	Economy	38300.00
0005432693313	17510	Economy	38300.00
0005432693364	17510	Economy	38300.00
0005432693403	17510	Economy	38300.00
0005432677606	17510	Economy	38300.00
0005432693361	17510	Economy	38300.00
0005432693430	17510	Economy	38300.00
0005432675259	17510	Economy	38300.00
0005432693248	17510	Economy	38300.00
0005432675275	17510	Economy	38300.00
0005432675314	17510	Economy	38300.00
0005432873434	17510	Economy	38300.00
0005432693376	17510	Economy	38300.00
0005432677607	17510	Economy	38300.00
0005432675377	17510	Economy	38300.00
0005432693267	17510	Economy	38300.00
0005432693370	17510	Economy	38300.00
0005432693405	17510	Economy	38300.00
0005432873435	17510	Economy	38300.00
0005432693404	17510	Economy	38300.00
0005432675348	17510	Economy	38300.00
0005432675280	17510	Economy	38300.00
0005432693360	17510	Economy	38300.00
0005432693422	17510	Economy	38300.00
0005432693326	17510	Economy	38300.00
0005432675264	17510	Economy	38300.00
0005432693439	17510	Economy	38300.00
0005432675243	17510	Economy	38300.00
0005432693298	17510	Economy	38300.00
0005432677605	17510	Economy	38300.00
0005432693437	17510	Economy	38300.00
0005432675313	17510	Economy	38300.00
0005432693458	17510	Economy	38300.00
0005433156822	1145	Economy	15200.00
0005434435485	1145	Economy	15200.00
0005433156849	1145	Economy	13900.00
0005434435483	1145	Economy	13900.00
0005434435477	1145	Economy	13900.00
0005434435488	1145	Economy	13900.00
0005433156900	1145	Economy	13900.00
0005434435492	1145	Economy	13900.00
0005434435486	1145	Economy	13900.00
0005434435491	1145	Economy	13900.00
0005433156823	1145	Economy	13900.00
0005434435481	1145	Economy	13900.00
0005434435487	1145	Economy	13900.00
0005434435480	1145	Economy	13900.00
0005434435482	1145	Economy	13900.00
0005434435479	1145	Economy	13900.00
0005434435489	1145	Economy	13900.00
0005434435484	1145	Economy	13900.00
0005433156844	1145	Economy	13900.00
0005434435478	1145	Economy	13900.00
0005434435490	1145	Economy	13900.00
0005433156867	1145	Economy	13900.00
0005434435334	17277	Economy	15200.00
0005434435364	17277	Economy	13900.00
0005434435299	17277	Economy	13900.00
0005434435291	17277	Economy	13900.00
0005434435304	17277	Economy	13900.00
0005433156922	17277	Economy	13900.00
0005433156916	17277	Economy	13900.00
0005433156920	17277	Economy	13900.00
0005433156923	17277	Economy	13900.00
0005434435394	17277	Economy	13900.00
0005434435361	17277	Economy	13900.00
0005434435388	17277	Economy	13900.00
0005434435322	17277	Economy	13900.00
0005434435371	17277	Economy	13900.00
0005433156918	17277	Economy	13900.00
0005434435408	17277	Economy	13900.00
0005434435389	17277	Economy	13900.00
0005434435428	17277	Economy	13900.00
0005434435362	17277	Economy	13900.00
0005434435276	17277	Economy	13900.00
0005433156919	17277	Economy	13900.00
0005433156921	17277	Economy	13900.00
0005433156917	17277	Economy	13900.00
0005434435370	17277	Economy	13900.00
0005434435289	17277	Economy	13900.00
0005434435429	17277	Economy	13900.00
0005435928190	4106	Economy	8200.00
0005435086987	4106	Economy	7500.00
0005435928196	4106	Economy	7500.00
0005435086982	4106	Economy	7500.00
0005435928194	4106	Economy	7500.00
0005435086986	4106	Economy	7500.00
0005435928193	4106	Economy	7500.00
0005435928206	4106	Economy	7500.00
0005435928182	4106	Economy	7500.00
0005435086984	4106	Economy	7500.00
0005435086985	4106	Economy	7500.00
0005435086981	4106	Economy	7500.00
0005435086980	4106	Economy	7500.00
0005435086983	4106	Economy	7500.00
0005435928239	24387	Economy	8200.00
0005435928240	24387	Economy	7500.00
0005435928235	24387	Economy	7500.00
0005435086908	24387	Economy	7500.00
0005435086899	24387	Economy	7500.00
0005435928236	24387	Economy	7500.00
0005435086903	24387	Economy	7500.00
0005435928238	24387	Economy	7500.00
0005435086907	24387	Economy	7500.00
0005435928237	24387	Economy	7500.00
0005433261638	1333	Business	203300.00
0005433261715	1333	Business	203300.00
0005434964586	1333	Business	203300.00
0005434964590	1333	Business	203300.00
0005434964579	1333	Business	203300.00
0005434964616	1333	Business	203300.00
0005434964595	1333	Business	203300.00
0005432279313	1333	Business	203300.00
0005434964608	1333	Business	203300.00
0005433261665	1333	Business	203300.00
0005434964598	1333	Economy	67800.00
0005433261652	1333	Economy	67800.00
0005433261696	1333	Economy	67800.00
0005434964592	1333	Economy	67800.00
0005433261674	1333	Economy	67800.00
0005434964600	1333	Economy	67800.00
0005434964593	1333	Economy	67800.00
0005434964601	1333	Economy	67800.00
0005434964609	1333	Economy	67800.00
0005434964582	1333	Economy	67800.00
0005433261716	1333	Economy	67800.00
0005433261660	1333	Economy	67800.00
0005432279317	1333	Economy	67800.00
0005434964602	1333	Economy	67800.00
0005434964591	1333	Economy	67800.00
0005433261694	1333	Economy	67800.00
0005434964606	1333	Economy	67800.00
0005434964583	1333	Economy	67800.00
0005434964603	1333	Economy	67800.00
0005433261658	1333	Economy	67800.00
0005434964589	1333	Economy	67800.00
0005434964607	1333	Economy	67800.00
0005434964580	1333	Economy	67800.00
0005434964614	1333	Economy	67800.00
0005433261644	1333	Economy	67800.00
0005434964599	1333	Economy	67800.00
0005434964587	1333	Economy	67800.00
0005433261659	1333	Economy	67800.00
0005433261633	1333	Economy	67800.00
0005434964597	1333	Economy	67800.00
0005433261641	1333	Economy	67800.00
0005434964578	1333	Economy	67800.00
0005433261640	1333	Economy	67800.00
0005434964588	1333	Economy	74500.00
0005433261664	1333	Economy	74500.00
0005433261653	1333	Economy	67800.00
0005434964611	1333	Economy	67800.00
0005434964585	1333	Economy	67800.00
0005434964596	1333	Economy	67800.00
0005433261666	1333	Economy	67800.00
0005432279315	1333	Economy	67800.00
0005433261689	1333	Economy	67800.00
0005434964613	1333	Economy	67800.00
0005433261654	1333	Economy	67800.00
0005434964615	1333	Economy	67800.00
0005434964581	1333	Economy	67800.00
0005434964584	1333	Economy	67800.00
0005434964594	1333	Economy	67800.00
0005433261714	1333	Economy	67800.00
0005434964604	1333	Economy	67800.00
0005433261678	1333	Economy	67800.00
0005434964612	1333	Economy	67800.00
0005434964605	1333	Economy	67800.00
0005432279316	1333	Economy	67800.00
0005434964610	1333	Economy	67800.00
0005433261673	1333	Economy	67800.00
0005432279314	1333	Economy	67800.00
0005433261651	1333	Economy	67800.00
0005434964400	18237	Business	203300.00
0005433261765	18237	Business	203300.00
0005433261768	18237	Business	203300.00
0005433261771	18237	Business	203300.00
0005434964358	18237	Business	203300.00
0005434964317	18237	Business	203300.00
0005434964320	18237	Business	203300.00
0005434964476	18237	Business	203300.00
0005433261752	18237	Business	203300.00
0005433261762	18237	Business	203300.00
0005434964346	18237	Business	203300.00
0005433261754	18237	Business	203300.00
0005434964435	18237	Business	203300.00
0005434964396	18237	Economy	74500.00
0005434964437	18237	Economy	67800.00
0005433261767	18237	Economy	67800.00
0005434964409	18237	Economy	67800.00
0005434964473	18237	Economy	67800.00
0005433261770	18237	Economy	67800.00
0005433261769	18237	Economy	67800.00
0005434964425	18237	Economy	67800.00
0005434964449	18237	Economy	67800.00
0005434964352	18237	Economy	67800.00
0005434964436	18237	Economy	67800.00
0005433261755	18237	Economy	67800.00
0005434964365	18237	Economy	67800.00
0005433261753	18237	Economy	67800.00
0005433261756	18237	Economy	67800.00
0005434964345	18237	Economy	67800.00
0005434964394	18237	Economy	67800.00
0005434964426	18237	Economy	67800.00
0005434964442	18237	Economy	67800.00
0005434964417	18237	Economy	67800.00
0005434964419	18237	Economy	67800.00
0005434964347	18237	Economy	67800.00
0005434964353	18237	Economy	67800.00
0005434964370	18237	Economy	67800.00
0005433261758	18237	Economy	67800.00
0005434964411	18237	Economy	67800.00
0005434964443	18237	Economy	74500.00
0005434964450	18237	Economy	67800.00
0005434964393	18237	Economy	67800.00
0005434964424	18237	Economy	67800.00
0005434964344	18237	Economy	67800.00
0005433261760	18237	Economy	67800.00
0005434964395	18237	Economy	67800.00
0005434964432	18237	Economy	67800.00
0005433261772	18237	Economy	67800.00
0005434964410	18237	Economy	67800.00
0005434964372	18237	Economy	67800.00
0005434964463	18237	Economy	67800.00
0005434964371	18237	Economy	67800.00
0005434964420	18237	Economy	67800.00
0005433261759	18237	Economy	67800.00
0005434964405	18237	Economy	67800.00
0005434964474	18237	Economy	67800.00
0005433261766	18237	Economy	67800.00
0005433261757	18237	Economy	67800.00
0005433261763	18237	Economy	67800.00
0005434964406	18237	Economy	67800.00
0005434964318	18237	Economy	67800.00
0005433261761	18237	Economy	67800.00
0005434964423	18237	Economy	67800.00
0005433261764	18237	Economy	67800.00
0005434626144	4846	Business	44200.00
0005433194869	4846	Economy	14700.00
0005435907547	4846	Economy	14700.00
0005433194875	4846	Economy	16200.00
0005434626150	4846	Economy	14700.00
0005433194874	4846	Economy	14700.00
0005434626153	4846	Economy	14700.00
0005433194877	4846	Economy	14700.00
0005434626146	4846	Economy	14700.00
0005434626149	4846	Economy	14700.00
0005434626145	4846	Economy	14700.00
0005435907560	4846	Economy	14700.00
0005433194873	4846	Economy	14700.00
0005435907546	4846	Economy	14700.00
0005434626151	4846	Economy	14700.00
0005434626148	4846	Economy	14700.00
0005435907577	4846	Economy	14700.00
0005433194868	4846	Economy	14700.00
0005434626152	4846	Economy	14700.00
0005434626147	4846	Economy	14700.00
0005435907603	32902	Business	44200.00
0005434626080	32902	Economy	14700.00
0005435907601	32902	Economy	16200.00
0005434626076	32902	Economy	16200.00
0005434626054	32902	Economy	16200.00
0005435907600	32902	Economy	14700.00
0005434626053	32902	Economy	14700.00
0005434626075	32902	Economy	14700.00
0005434626068	32902	Economy	14700.00
0005434626077	32902	Economy	14700.00
0005434626069	32902	Economy	14700.00
0005434626089	32902	Economy	14700.00
0005434626108	32902	Economy	14700.00
0005435907605	32902	Economy	14700.00
0005434626088	32902	Economy	14700.00
0005434626055	32902	Economy	14700.00
0005435907602	32902	Economy	14700.00
0005434626090	32902	Economy	14700.00
0005434626064	32902	Economy	14700.00
0005434626078	32902	Economy	14700.00
0005434626091	32902	Economy	14700.00
0005434626121	32902	Economy	14700.00
0005435907604	32902	Economy	14700.00
0005434626074	32902	Economy	14700.00
0005434626107	32902	Economy	14700.00
0005435907606	32902	Economy	14700.00
0005434626060	32902	Economy	14700.00
0005434626086	32902	Economy	14700.00
0005435785810	13794	Economy	3400.00
0005435785697	13794	Economy	3400.00
0005435785647	13794	Economy	3400.00
0005432195736	13794	Economy	3400.00
0005435785713	13794	Economy	3100.00
0005435785873	13794	Economy	3100.00
0005435785679	13794	Economy	3100.00
0005432195737	13794	Economy	3100.00
0005435785687	13794	Economy	3100.00
0005435785639	13794	Economy	3100.00
0005435785734	13794	Economy	3100.00
0005435785702	13794	Economy	3100.00
0005435785757	13794	Economy	3100.00
0005435785605	13794	Economy	3100.00
0005435785674	13794	Economy	3100.00
0005435785654	13794	Economy	3100.00
0005435785620	13794	Economy	3100.00
0005435785686	13794	Economy	3100.00
0005435785838	13794	Economy	3100.00
0005435785671	13794	Economy	3100.00
0005435785690	13794	Economy	3100.00
0005435785621	13794	Economy	3100.00
0005435785594	13794	Economy	3100.00
0005435785703	13794	Economy	3100.00
0005435937468	13794	Economy	3100.00
0005435785872	13794	Economy	3100.00
0005435785606	13794	Economy	3100.00
0005435785640	13794	Economy	3100.00
0005435785693	13794	Economy	3100.00
0005435785839	13794	Economy	3100.00
0005432195735	13794	Economy	3100.00
0005435785676	13794	Economy	3100.00
0005435785688	13794	Economy	3100.00
0005435785715	13794	Economy	3100.00
0005435785776	13794	Economy	3100.00
0005435785683	13794	Economy	3100.00
0005435937470	13794	Economy	3100.00
0005435785840	13794	Economy	3100.00
0005435785787	13794	Economy	3100.00
0005435785692	13794	Economy	3100.00
0005435785754	13794	Economy	3100.00
0005435785646	13794	Economy	3100.00
0005435785696	13794	Economy	3100.00
0005435937467	13794	Economy	3100.00
0005435785655	13794	Economy	3100.00
0005435785691	13794	Economy	3100.00
0005435785630	13794	Economy	3100.00
0005435785486	13794	Economy	3100.00
0005435937469	13794	Economy	3100.00
0005435785689	13794	Economy	3100.00
0005432190701	27403	Economy	3400.00
0005432190699	27403	Economy	3400.00
0005435785998	27403	Economy	3400.00
0005435785985	27403	Economy	3100.00
0005435785973	27403	Economy	3100.00
0005435785971	27403	Economy	3100.00
0005435785978	27403	Economy	3100.00
0005435787392	27403	Economy	3100.00
0005432190698	27403	Economy	3100.00
0005435786003	27403	Economy	3100.00
0005435785977	27403	Economy	3100.00
0005435785986	27403	Economy	3100.00
0005435937405	27403	Economy	3100.00
0005435786001	27403	Economy	3100.00
0005435785996	27403	Economy	3100.00
0005435937414	27403	Economy	3100.00
0005435785991	27403	Economy	3100.00
0005435785992	27403	Economy	3100.00
0005435785969	27403	Economy	3100.00
0005435785980	27403	Economy	3100.00
0005435785990	27403	Economy	3100.00
0005435785994	27403	Economy	3100.00
0005435785995	27403	Economy	3100.00
0005435785984	27403	Economy	3100.00
0005435785970	27403	Economy	3100.00
0005435785975	27403	Economy	3100.00
0005435785979	27403	Economy	3100.00
0005435785981	27403	Economy	3100.00
0005435785976	27403	Economy	3100.00
0005435786004	27403	Economy	3100.00
0005435785974	27403	Economy	3100.00
0005435785972	27403	Economy	3100.00
0005435785988	27403	Economy	3100.00
0005435785997	27403	Economy	3100.00
0005435785989	27403	Economy	3100.00
0005435937404	27403	Economy	3100.00
0005435785993	27403	Economy	3100.00
0005435785987	27403	Economy	3100.00
0005435785983	27403	Economy	3100.00
0005435937400	27403	Economy	3100.00
0005435937413	27403	Economy	3100.00
0005435785999	27403	Economy	3100.00
0005435785982	27403	Economy	3100.00
0005432190700	27403	Economy	3100.00
0005435786002	27403	Economy	3100.00
0005435786000	27403	Economy	3100.00
0005435937406	27403	Economy	3100.00
0005434408432	20294	Business	12000.00
0005434408503	20294	Business	12000.00
0005434408427	20294	Business	12000.00
0005434408688	20294	Business	12000.00
0005434408577	20294	Business	12000.00
0005435311307	20294	Business	12000.00
0005434408523	20294	Business	12000.00
0005434408588	20294	Business	12000.00
0005434408637	20294	Business	12000.00
0005434408483	20294	Business	12000.00
0005435311310	20294	Business	12000.00
0005435311306	20294	Economy	4000.00
0005434408580	20294	Economy	4000.00
0005434408654	20294	Economy	4000.00
0005434408426	20294	Economy	4000.00
0005434408603	20294	Economy	4000.00
0005434408476	20294	Economy	4000.00
0005434408759	20294	Economy	4000.00
0005435311317	20294	Economy	4000.00
0005435311299	20294	Economy	4000.00
0005435311301	20294	Economy	4400.00
0005434408158	20294	Economy	4400.00
0005435311303	20294	Economy	4400.00
0005435311309	20294	Economy	4400.00
0005434408260	20294	Economy	4400.00
0005434408379	20294	Economy	4000.00
0005434408475	20294	Economy	4000.00
0005434408089	20294	Economy	4000.00
0005434408050	20294	Economy	4000.00
0005434408744	20294	Economy	4000.00
0005432058461	20294	Economy	4000.00
0005434408505	20294	Economy	4000.00
0005434408579	20294	Economy	4000.00
0005432058460	20294	Economy	4000.00
0005434408403	20294	Economy	4000.00
0005434408687	20294	Economy	4000.00
0005434408478	20294	Economy	4000.00
0005435311300	20294	Economy	4000.00
0005435311316	20294	Economy	4000.00
0005434408679	20294	Economy	4000.00
0005434408389	20294	Economy	4000.00
0005435311315	20294	Economy	4000.00
0005434408601	20294	Economy	4000.00
0005435311305	20294	Economy	4000.00
0005434408745	20294	Economy	4000.00
0005434408343	20294	Economy	4000.00
0005435311311	20294	Economy	4000.00
0005434408506	20294	Economy	4000.00
0005435311308	20294	Economy	4000.00
0005434408317	20294	Economy	4000.00
0005434408342	20294	Economy	4000.00
0005434408508	20294	Economy	4000.00
0005434408386	20294	Economy	4000.00
0005434408370	20294	Economy	4000.00
0005434408455	20294	Economy	4000.00
0005434408418	20294	Economy	4000.00
0005434408551	20294	Economy	4000.00
0005434408728	20294	Economy	4000.00
0005434408638	20294	Economy	4000.00
0005434408596	20294	Economy	4000.00
0005435311302	20294	Economy	4000.00
0005434408410	20294	Economy	4000.00
0005435311312	20294	Economy	4000.00
0005434408602	20294	Economy	4000.00
0005435311313	20294	Economy	4000.00
0005435311314	20294	Economy	4000.00
0005435311298	20294	Economy	4000.00
0005435311304	20294	Economy	4000.00
0005434408524	20294	Economy	4000.00
0005434408380	20294	Economy	4000.00
0005434408515	20294	Economy	4000.00
0005434408594	20294	Economy	4000.00
0005434408373	20294	Economy	4000.00
0005434408344	20294	Economy	4000.00
0005434408525	20294	Economy	4000.00
0005432058459	20294	Economy	4000.00
0005434408454	20294	Economy	4000.00
0005434408404	20294	Economy	4000.00
0005434408540	20294	Economy	4000.00
0005434408374	20294	Economy	4000.00
0005434408215	20294	Economy	4000.00
0005434408735	20294	Economy	4000.00
0005434408369	20294	Economy	4000.00
0005434408197	20294	Economy	4000.00
0005434408479	20294	Economy	4000.00
0005434408428	20294	Economy	4000.00
0005434408622	20294	Economy	4000.00
0005434408368	20294	Economy	4000.00
0005434408363	20294	Economy	4000.00
0005435311297	20294	Economy	4000.00
0005435311179	26974	Business	12000.00
0005434409019	26974	Business	12000.00
0005434409029	26974	Business	12000.00
0005434408985	26974	Business	12000.00
0005434408997	26974	Business	12000.00
0005434409016	26974	Business	12000.00
0005435311193	26974	Business	12000.00
0005432154072	26974	Business	12000.00
0005432154078	26974	Business	12000.00
0005434408981	26974	Business	12000.00
0005434409010	26974	Business	12000.00
0005434409002	26974	Economy	4000.00
0005432154076	26974	Economy	4000.00
0005434409001	26974	Economy	4000.00
0005434408989	26974	Economy	4000.00
0005434409005	26974	Economy	4000.00
0005434408996	26974	Economy	4000.00
0005435311154	26974	Economy	4000.00
0005434409006	26974	Economy	4000.00
0005434408998	26974	Economy	4400.00
0005435311166	26974	Economy	4400.00
0005432154077	26974	Economy	4400.00
0005434408966	26974	Economy	4400.00
0005434409028	26974	Economy	4000.00
0005434408995	26974	Economy	4000.00
0005434408988	26974	Economy	4000.00
0005435311172	26974	Economy	4000.00
0005434409009	26974	Economy	4000.00
0005434408986	26974	Economy	4000.00
0005435311173	26974	Economy	4000.00
0005434408970	26974	Economy	4000.00
0005434409024	26974	Economy	4000.00
0005435311146	26974	Economy	4000.00
0005434408977	26974	Economy	4000.00
0005434408993	26974	Economy	4000.00
0005435311178	26974	Economy	4000.00
0005434408999	26974	Economy	4000.00
0005435311168	26974	Economy	4000.00
0005432154073	26974	Economy	4000.00
0005435311169	26974	Economy	4000.00
0005434408980	26974	Economy	4000.00
0005434408965	26974	Economy	4000.00
0005434408972	26974	Economy	4000.00
0005434409023	26974	Economy	4000.00
0005434408982	26974	Economy	4000.00
0005435311167	26974	Economy	4000.00
0005434408969	26974	Economy	4000.00
0005434408992	26974	Economy	4000.00
0005434409025	26974	Economy	4000.00
0005435311155	26974	Economy	4000.00
0005434408979	26974	Economy	4000.00
0005435311145	26974	Economy	4000.00
0005434408978	26974	Economy	4000.00
0005434408991	26974	Economy	4000.00
0005434409011	26974	Economy	4000.00
0005435311159	26974	Economy	4000.00
0005434409007	26974	Economy	4000.00
0005434409017	26974	Economy	4000.00
0005434409012	26974	Economy	4000.00
0005434409027	26974	Economy	4000.00
0005434408994	26974	Economy	4000.00
0005434408984	26974	Economy	4000.00
0005434408971	26974	Economy	4000.00
0005434409003	26974	Economy	4000.00
0005434409018	26974	Economy	4000.00
0005432154075	26974	Economy	4000.00
0005435311144	26974	Economy	4000.00
0005432154074	26974	Economy	4000.00
0005434409008	26974	Economy	4000.00
0005434409026	26974	Economy	4000.00
0005434408983	26974	Economy	4000.00
0005434408973	26974	Economy	4000.00
0005435311181	26974	Economy	4000.00
0005434408987	26974	Economy	4000.00
0005434408990	26974	Economy	4000.00
0005434408974	26974	Economy	4000.00
0005434409021	26974	Economy	4000.00
0005434409020	26974	Economy	4000.00
0005434409014	26974	Economy	4000.00
0005434409000	26974	Economy	4000.00
0005434408975	26974	Economy	4000.00
0005434408968	26974	Economy	4000.00
0005435311174	26974	Economy	4000.00
0005434409022	26974	Economy	4000.00
0005435311138	26974	Economy	4000.00
0005434408967	26974	Economy	4000.00
0005434409015	26974	Economy	4000.00
0005434408976	26974	Economy	4000.00
0005434409004	26974	Economy	4000.00
0005434409013	26974	Economy	4000.00
0005434319671	5691	Business	43300.00
0005433124138	5691	Business	43300.00
0005433124127	5691	Business	43300.00
0005433124194	5691	Business	43300.00
0005434319666	5691	Economy	14400.00
0005434319659	5691	Economy	14400.00
0005434319668	5691	Economy	14400.00
0005433124137	5691	Economy	14400.00
0005434311258	5691	Economy	14400.00
0005433124125	5691	Economy	14400.00
0005434319664	5691	Economy	14400.00
0005432109757	5691	Economy	14400.00
0005433124141	5691	Economy	15900.00
0005433124151	5691	Economy	15900.00
0005433124140	5691	Economy	15900.00
0005433124145	5691	Economy	14400.00
0005433124126	5691	Economy	14400.00
0005433124191	5691	Economy	14400.00
0005433124153	5691	Economy	14400.00
0005433124146	5691	Economy	14400.00
0005432109756	5691	Economy	14400.00
0005433124213	5691	Economy	14400.00
0005434311257	5691	Economy	14400.00
0005434319657	5691	Economy	14400.00
0005434319670	5691	Economy	14400.00
0005433124139	5691	Economy	14400.00
0005434319658	5691	Economy	14400.00
0005433124132	5691	Economy	14400.00
0005434319667	5691	Economy	14400.00
0005433124195	5691	Economy	14400.00
0005434319663	5691	Economy	14400.00
0005433124102	5691	Economy	14400.00
0005433124134	5691	Economy	14400.00
0005434319662	5691	Economy	14400.00
0005433124152	5691	Economy	14400.00
0005434319669	5691	Economy	14400.00
0005433124192	5691	Economy	14400.00
0005433124133	5691	Economy	14400.00
0005434319660	5691	Economy	14400.00
0005434319661	5691	Economy	14400.00
0005432109758	5691	Economy	14400.00
0005434319665	5691	Economy	14400.00
0005433124337	15655	Business	43300.00
0005434319550	15655	Business	43300.00
0005434319544	15655	Business	43300.00
0005434319582	15655	Business	43300.00
0005433124336	15655	Business	43300.00
0005433124341	15655	Business	43300.00
0005434319549	15655	Business	43300.00
0005433124342	15655	Economy	14400.00
0005434319498	15655	Economy	14400.00
0005434319533	15655	Economy	14400.00
0005434319616	15655	Economy	14400.00
0005434319547	15655	Economy	15900.00
0005434319516	15655	Economy	15900.00
0005433124331	15655	Economy	14400.00
0005433124345	15655	Economy	14400.00
0005434319543	15655	Economy	14400.00
0005433124335	15655	Economy	14400.00
0005433124338	15655	Economy	14400.00
0005433124347	15655	Economy	14400.00
0005434319517	15655	Economy	14400.00
0005434319581	15655	Economy	14400.00
0005434319522	15655	Economy	14400.00
0005433124344	15655	Economy	14400.00
0005433124346	15655	Economy	14400.00
0005434319504	15655	Economy	14400.00
0005433124343	15655	Economy	14400.00
0005434319560	15655	Economy	14400.00
0005434319580	15655	Economy	14400.00
0005433124339	15655	Economy	14400.00
0005433124334	15655	Economy	14400.00
0005435297353	15655	Economy	14400.00
0005434319602	15655	Economy	14400.00
0005434319605	15655	Economy	14400.00
0005433124332	15655	Economy	14400.00
0005434319586	15655	Economy	14400.00
0005434319511	15655	Economy	14400.00
0005434319534	15655	Economy	14400.00
0005433124340	15655	Economy	14400.00
0005433124333	15655	Economy	14400.00
0005434319545	15655	Economy	14400.00
0005435297352	15655	Economy	14400.00
0005434319542	15655	Economy	14400.00
0005435217733	24987	Economy	17100.00
0005435217735	24987	Economy	15500.00
0005435220341	24987	Economy	15500.00
0005435217719	24987	Economy	15500.00
0005435217734	24987	Economy	15500.00
0005435220336	24987	Economy	15500.00
0005435220325	24987	Economy	15500.00
0005435217736	24987	Economy	15500.00
0005435221522	24987	Economy	15500.00
0005435217732	24987	Economy	15500.00
0005435217720	24987	Economy	15500.00
0005434484481	9005	Economy	27400.00
0005434484480	9005	Economy	24900.00
0005434484478	9005	Economy	24900.00
0005434484476	9005	Economy	24900.00
0005434484477	9005	Economy	24900.00
0005434189268	9005	Economy	24900.00
0005434189246	9005	Economy	24900.00
0005434189256	9005	Economy	24900.00
0005434484474	9005	Economy	24900.00
0005434484479	9005	Economy	24900.00
0005434189269	9005	Economy	24900.00
0005434484475	9005	Economy	24900.00
0005434189289	16649	Economy	27400.00
0005434189291	16649	Economy	27400.00
0005434189293	16649	Economy	24900.00
0005434189294	16649	Economy	24900.00
0005434484435	16649	Economy	24900.00
0005434484434	16649	Economy	24900.00
0005434484433	16649	Economy	24900.00
0005434189292	16649	Economy	24900.00
0005434189290	16649	Economy	24900.00
0005434484414	16649	Economy	24900.00
0005434484425	16649	Economy	24900.00
0005434484438	16649	Economy	24900.00
0005433124347	7707	Business	11100.00
0005433124336	7707	Economy	3700.00
0005433722292	7707	Economy	3700.00
0005433124338	7707	Economy	3700.00
0005433124333	7707	Economy	3700.00
0005433722272	7707	Economy	3700.00
0005433124334	7707	Economy	3700.00
0005433124346	7707	Economy	3700.00
0005433124337	7707	Economy	3700.00
0005433124343	7707	Economy	3700.00
0005433124345	7707	Economy	3700.00
0005433722300	7707	Economy	3700.00
0005433124339	7707	Economy	3700.00
0005433124331	7707	Economy	3700.00
0005433124342	7707	Economy	3700.00
0005433124335	7707	Economy	3700.00
0005433124332	7707	Economy	3700.00
0005433124341	7707	Economy	3700.00
0005433722268	7707	Economy	3700.00
0005433722265	7707	Economy	3700.00
0005433722280	7707	Economy	3700.00
0005433124344	7707	Economy	3700.00
0005433124340	7707	Economy	3700.00
0005432693664	7708	Business	11100.00
0005432693685	7708	Business	11100.00
0005432721420	7708	Business	11100.00
0005433450399	7708	Business	11100.00
0005433450397	7708	Business	11100.00
0005432693676	7708	Business	11100.00
0005432721421	7708	Business	11100.00
0005432721435	7708	Business	11100.00
0005433450405	7708	Business	11100.00
0005432693671	7708	Business	11100.00
0005432721430	7708	Business	11100.00
0005432693677	7708	Economy	3700.00
0005432721441	7708	Economy	3700.00
0005432721443	7708	Economy	3700.00
0005432721432	7708	Economy	3700.00
0005433450398	7708	Economy	3700.00
0005432693672	7708	Economy	3700.00
0005433450394	7708	Economy	3700.00
0005432721444	7708	Economy	3700.00
0005433450392	7708	Economy	4100.00
0005432071630	7708	Economy	4100.00
0005432693675	7708	Economy	4100.00
0005432693688	7708	Economy	3700.00
0005432693681	7708	Economy	3700.00
0005433450404	7708	Economy	3700.00
0005432721422	7708	Economy	3700.00
0005433450403	7708	Economy	3700.00
0005432693668	7708	Economy	3700.00
0005432693694	7708	Economy	3700.00
0005432721442	7708	Economy	3700.00
0005433450395	7708	Economy	3700.00
0005432693665	7708	Economy	3700.00
0005432693682	7708	Economy	3700.00
0005432721439	7708	Economy	3700.00
0005432693692	7708	Economy	3700.00
0005433450388	7708	Economy	3700.00
0005432693684	7708	Economy	3700.00
0005432693680	7708	Economy	3700.00
0005433450393	7708	Economy	3700.00
0005432071631	7708	Economy	3700.00
0005432693678	7708	Economy	3700.00
0005433450396	7708	Economy	3700.00
0005433450406	7708	Economy	3700.00
0005432071632	7708	Economy	3700.00
0005433450400	7708	Economy	3700.00
0005432721436	7708	Economy	3700.00
0005432693679	7708	Economy	3700.00
0005432721440	7708	Economy	3700.00
0005432693690	7708	Economy	3700.00
0005432721426	7708	Economy	3700.00
0005432721438	7708	Economy	3700.00
0005432721429	7708	Economy	3700.00
0005433450386	7708	Economy	3700.00
0005432721445	7708	Economy	3700.00
0005432721419	7708	Economy	3700.00
0005432721427	7708	Economy	3700.00
0005433450387	7708	Economy	3700.00
0005432693683	7708	Economy	3700.00
0005433450391	7708	Economy	3700.00
0005433450402	7708	Economy	3700.00
0005432721434	7708	Economy	3700.00
0005432693686	7708	Economy	3700.00
0005432693693	7708	Economy	3700.00
0005432693689	7708	Economy	3700.00
0005432721428	7708	Economy	3700.00
0005432721433	7708	Economy	3700.00
0005432721425	7708	Economy	3700.00
0005433450401	7708	Economy	3700.00
0005432693673	7708	Economy	3700.00
0005432693666	7708	Economy	3700.00
0005432721423	7708	Economy	3700.00
0005432693691	7708	Economy	3700.00
0005432721437	7708	Economy	3700.00
0005432693669	7708	Economy	3700.00
0005432693687	7708	Economy	3700.00
0005432693663	7708	Economy	3700.00
0005432693670	7708	Economy	3700.00
0005432721418	7708	Economy	3700.00
0005432721431	7708	Economy	3700.00
0005433450390	7708	Economy	3700.00
0005432693667	7708	Economy	3700.00
0005432693674	7708	Economy	3700.00
0005433450385	7708	Economy	3700.00
0005432721424	7708	Economy	3700.00
0005433450389	7708	Economy	3700.00
0005432693370	30413	Business	11100.00
0005433450222	30413	Business	11100.00
0005432693430	30413	Business	11100.00
0005433450105	30413	Economy	3700.00
0005432693268	30413	Economy	3700.00
0005432693248	30413	Economy	3700.00
0005432693273	30413	Economy	3700.00
0005432693439	30413	Economy	3700.00
0005432693267	30413	Economy	3700.00
0005432693404	30413	Economy	3700.00
0005433450272	30413	Economy	4100.00
0005433450138	30413	Economy	4100.00
0005433450273	30413	Economy	4100.00
0005432693486	30413	Economy	4100.00
0005433450257	30413	Economy	3700.00
0005433450259	30413	Economy	3700.00
0005432693355	30413	Economy	3700.00
0005432693422	30413	Economy	3700.00
0005432693438	30413	Economy	3700.00
0005432693431	30413	Economy	3700.00
0005432693419	30413	Economy	3700.00
0005432693326	30413	Economy	3700.00
0005432693418	30413	Economy	3700.00
0005433450123	30413	Economy	3700.00
0005432693514	30413	Economy	3700.00
0005432693361	30413	Economy	3700.00
0005432693376	30413	Economy	3700.00
0005432693331	30413	Economy	3700.00
0005433450238	30413	Economy	3700.00
0005432693359	30413	Economy	3700.00
0005432693360	30413	Economy	3700.00
0005432693437	30413	Economy	3700.00
0005432693405	30413	Economy	3700.00
0005432693458	30413	Economy	3700.00
0005432693332	30413	Economy	3700.00
0005433450190	30413	Economy	3700.00
0005433450221	30413	Economy	3700.00
0005432693298	30413	Economy	3700.00
0005433450204	30413	Economy	3700.00
0005432693403	30413	Economy	3700.00
0005433450229	30413	Economy	3700.00
0005433450124	30413	Economy	3700.00
0005432693313	30413	Economy	3700.00
0005432693364	30413	Economy	3700.00
0005432693249	30413	Economy	3700.00
0005432693466	30413	Economy	3700.00
0005432693297	30413	Economy	3700.00
0005433124191	30414	Business	11100.00
0005433124194	30414	Business	11100.00
0005432721313	30414	Business	11100.00
0005432721315	30414	Business	11100.00
0005432721121	30414	Business	11100.00
0005432721318	30414	Business	11100.00
0005433124146	30414	Business	11100.00
0005433124132	30414	Business	11100.00
0005432721193	30414	Business	11100.00
0005433722347	30414	Economy	3700.00
0005432721211	30414	Economy	3700.00
0005432721259	30414	Economy	3700.00
0005432721322	30414	Economy	3700.00
0005433124125	30414	Economy	3700.00
0005432721192	30414	Economy	4100.00
0005432721355	30414	Economy	4100.00
0005433722351	30414	Economy	4100.00
0005432721314	30414	Economy	4100.00
0005433124145	30414	Economy	3700.00
0005432721263	30414	Economy	3700.00
0005432721233	30414	Economy	3700.00
0005432721234	30414	Economy	3700.00
0005433124151	30414	Economy	3700.00
0005433124141	30414	Economy	3700.00
0005433124102	30414	Economy	3700.00
0005432721191	30414	Economy	3700.00
0005433124133	30414	Economy	3700.00
0005432721218	30414	Economy	3700.00
0005432721176	30414	Economy	3700.00
0005432721262	30414	Economy	3700.00
0005433722348	30414	Economy	3700.00
0005433124127	30414	Economy	3700.00
0005433722350	30414	Economy	3700.00
0005432721230	30414	Economy	3700.00
0005432721118	30414	Economy	3700.00
0005432721301	30414	Economy	3700.00
0005432721275	30414	Economy	3700.00
0005433124192	30414	Economy	3700.00
0005433124139	30414	Economy	3700.00
0005433124213	30414	Economy	3700.00
0005433124153	30414	Economy	3700.00
0005432721172	30414	Economy	3700.00
0005433124140	30414	Economy	3700.00
0005432721177	30414	Economy	3700.00
0005432721203	30414	Economy	3700.00
0005433722349	30414	Economy	3700.00
0005433124152	30414	Economy	3700.00
0005433124195	30414	Economy	3700.00
0005432721204	30414	Economy	3700.00
0005432721212	30414	Economy	3700.00
0005432721356	30414	Economy	3700.00
0005432721138	30414	Economy	3700.00
0005433124137	30414	Economy	3700.00
0005433124138	30414	Economy	3700.00
0005432721229	30414	Economy	3700.00
0005432721258	30414	Economy	3700.00
0005433124126	30414	Economy	3700.00
0005432721243	30414	Economy	3700.00
0005433124134	30414	Economy	3700.00
0005433193244	1405	Business	70400.00
0005434515020	1405	Business	70400.00
0005433525260	1405	Business	70400.00
0005434587104	1405	Business	70400.00
0005432928006	1405	Business	70400.00
0005434587117	1405	Business	70400.00
0005434587114	1405	Business	70400.00
0005433724895	1405	Business	70400.00
0005434587118	1405	Economy	23500.00
0005434587119	1405	Economy	23500.00
0005432928050	1405	Economy	23500.00
0005433724898	1405	Economy	23500.00
0005433724896	1405	Economy	23500.00
0005433525259	1405	Economy	23500.00
0005434587126	1405	Economy	25800.00
0005433525252	1405	Economy	25800.00
0005433525249	1405	Economy	25800.00
0005434587106	1405	Economy	25800.00
0005434587130	1405	Economy	23500.00
0005433193231	1405	Economy	23500.00
0005433525256	1405	Economy	23500.00
0005434587113	1405	Economy	23500.00
0005433525251	1405	Economy	23500.00
0005434587124	1405	Economy	23500.00
0005432928043	1405	Economy	23500.00
0005432928044	1405	Economy	23500.00
0005434587108	1405	Economy	23500.00
0005433724897	1405	Economy	23500.00
0005433193243	1405	Economy	23500.00
0005433525257	1405	Economy	23500.00
0005434587107	1405	Economy	23500.00
0005433525250	1405	Economy	23500.00
0005433193168	1405	Economy	23500.00
0005434587128	1405	Economy	23500.00
0005434587105	1405	Economy	23500.00
0005434587123	1405	Economy	23500.00
0005433193221	1405	Economy	23500.00
0005433193151	1405	Economy	23500.00
0005433525253	1405	Economy	23500.00
0005433525254	1405	Economy	23500.00
0005434587115	1405	Economy	23500.00
0005434587121	1405	Economy	23500.00
0005434587112	1405	Economy	23500.00
0005432928005	1405	Economy	23500.00
0005433193179	1405	Economy	23500.00
0005433193245	1405	Economy	23500.00
0005434587127	1405	Economy	23500.00
0005434587129	1405	Economy	23500.00
0005433525255	1405	Economy	23500.00
0005434587125	1405	Economy	23500.00
0005434587110	1405	Economy	23500.00
0005433193220	1405	Economy	23500.00
0005434587122	1405	Economy	23500.00
0005434515019	1405	Economy	23500.00
0005432928049	1405	Economy	23500.00
0005434513632	1405	Economy	23500.00
0005432271059	1405	Economy	23500.00
0005434515018	1405	Economy	23500.00
0005432271061	1405	Economy	23500.00
0005434587109	1405	Economy	23500.00
0005433193158	1405	Economy	23500.00
0005434587120	1405	Economy	23500.00
0005434587111	1405	Economy	23500.00
0005433525258	1405	Economy	23500.00
0005434587116	1405	Economy	23500.00
0005433724894	1405	Economy	23500.00
0005433193214	1405	Economy	23500.00
0005432271060	1405	Economy	23500.00
0005434586871	18536	Business	70400.00
0005434586878	18536	Business	70400.00
0005433724850	18536	Business	70400.00
0005433193305	18536	Business	70400.00
0005433193303	18536	Business	70400.00
0005432928090	18536	Business	70400.00
0005433724843	18536	Business	70400.00
0005434586928	18536	Economy	23500.00
0005433525138	18536	Economy	23500.00
0005432928089	18536	Economy	23500.00
0005433525173	18536	Economy	23500.00
0005434514995	18536	Economy	23500.00
0005434586880	18536	Economy	23500.00
0005433525114	18536	Economy	23500.00
0005433193310	18536	Economy	23500.00
0005433525166	18536	Economy	23500.00
0005434586879	18536	Economy	23500.00
0005433525186	18536	Economy	25800.00
0005432968885	18536	Economy	25800.00
0005433193314	18536	Economy	25800.00
0005432928091	18536	Economy	25800.00
0005434586902	18536	Economy	25800.00
0005433724863	18536	Economy	23500.00
0005434586901	18536	Economy	23500.00
0005433525193	18536	Economy	23500.00
0005432928088	18536	Economy	23500.00
0005433193311	18536	Economy	23500.00
0005433525178	18536	Economy	23500.00
0005433525171	18536	Economy	23500.00
0005434586866	18536	Economy	23500.00
0005434586885	18536	Economy	23500.00
0005434586963	18536	Economy	23500.00
0005434586962	18536	Economy	23500.00
0005433193309	18536	Economy	23500.00
0005434586886	18536	Economy	23500.00
0005434586835	18536	Economy	23500.00
0005434586856	18536	Economy	23500.00
0005433525113	18536	Economy	23500.00
0005432928087	18536	Economy	23500.00
0005433193307	18536	Economy	23500.00
0005433193313	18536	Economy	23500.00
0005433525159	18536	Economy	23500.00
0005434586887	18536	Economy	23500.00
0005433193304	18536	Economy	23500.00
0005434586905	18536	Economy	23500.00
0005433525139	18536	Economy	23500.00
0005434586952	18536	Economy	23500.00
0005434586949	18536	Economy	23500.00
0005433193308	18536	Economy	23500.00
0005433193302	18536	Economy	23500.00
0005433525177	18536	Economy	23500.00
0005434586827	18536	Economy	23500.00
0005434586953	18536	Economy	23500.00
0005433724842	18536	Economy	23500.00
0005433724849	18536	Economy	23500.00
0005434514993	18536	Economy	23500.00
0005434586776	18536	Economy	23500.00
0005433193306	18536	Economy	23500.00
0005434586908	18536	Economy	23500.00
0005433193312	18536	Economy	23500.00
0005434587020	18536	Economy	23500.00
0005434586934	18536	Economy	23500.00
0005433525106	18536	Economy	23500.00
0005433525143	18536	Economy	23500.00
0005434586967	18536	Economy	23500.00
0005434586828	18536	Economy	23500.00
0005433525137	18536	Economy	23500.00
0005434344867	11479	Economy	4300.00
0005434344862	11479	Economy	4300.00
0005434142690	11479	Economy	4300.00
0005434142687	11479	Economy	4300.00
0005435302250	11479	Economy	4000.00
0005434344892	11479	Economy	4000.00
0005434344864	11479	Economy	4000.00
0005434344890	11479	Economy	4000.00
0005434142689	11479	Economy	4000.00
0005434344874	11479	Economy	4000.00
0005434344880	11479	Economy	4000.00
0005435302260	11479	Economy	4000.00
0005434344878	11479	Economy	4000.00
0005434344870	11479	Economy	4000.00
0005434344868	11479	Economy	4000.00
0005434344879	11479	Economy	4000.00
0005434344873	11479	Economy	4000.00
0005434344860	11479	Economy	4000.00
0005434344871	11479	Economy	4000.00
0005434344855	11479	Economy	4000.00
0005434344875	11479	Economy	4000.00
0005434344859	11479	Economy	4000.00
0005434344881	11479	Economy	4000.00
0005434344866	11479	Economy	4000.00
0005435302240	11479	Economy	4000.00
0005434344889	11479	Economy	4000.00
0005434344888	11479	Economy	4000.00
0005434142691	11479	Economy	4000.00
0005434344858	11479	Economy	4000.00
0005434344863	11479	Economy	4000.00
0005434344886	11479	Economy	4000.00
0005434344883	11479	Economy	4000.00
0005434142688	11479	Economy	4000.00
0005434344872	11479	Economy	4000.00
0005434344882	11479	Economy	4000.00
0005435302239	11479	Economy	4000.00
0005434344884	11479	Economy	4000.00
0005434344887	11479	Economy	4000.00
0005435302252	11479	Economy	4000.00
0005434344857	11479	Economy	4000.00
0005434344876	11479	Economy	4000.00
0005434344885	11479	Economy	4000.00
0005434344865	11479	Economy	4000.00
0005434344891	11479	Economy	4000.00
0005434344856	11479	Economy	4000.00
0005435305026	11479	Economy	4000.00
0005434344861	11479	Economy	4000.00
0005434344877	11479	Economy	4000.00
0005434344869	11479	Economy	4000.00
0005435302251	11479	Economy	4000.00
0005434344418	29807	Economy	4300.00
0005434344651	29807	Economy	4300.00
0005435305051	29807	Economy	4300.00
0005434344582	29807	Economy	4300.00
0005434344446	29807	Economy	4000.00
0005434344470	29807	Economy	4000.00
0005434344593	29807	Economy	4000.00
0005434344501	29807	Economy	4000.00
0005434344562	29807	Economy	4000.00
0005434344642	29807	Economy	4000.00
0005434344401	29807	Economy	4000.00
0005435305053	29807	Economy	4000.00
0005434344641	29807	Economy	4000.00
0005435305049	29807	Economy	4000.00
0005434344537	29807	Economy	4000.00
0005435305052	29807	Economy	4000.00
0005434344573	29807	Economy	4000.00
0005434142634	29807	Economy	4000.00
0005435305050	29807	Economy	4000.00
0005434344609	29807	Economy	4000.00
0005434344563	29807	Economy	4000.00
0005434344631	29807	Economy	4000.00
0005435304239	29807	Economy	4000.00
0005434344594	29807	Economy	4000.00
0005434344567	29807	Economy	4000.00
0005434142633	29807	Economy	4000.00
0005434142652	29807	Economy	4000.00
0005434344584	29807	Economy	4000.00
0005434344449	29807	Economy	4000.00
0005434142671	29807	Economy	4000.00
0005435304237	29807	Economy	4000.00
0005434142651	29807	Economy	4000.00
0005434344485	29807	Economy	4000.00
0005434344445	29807	Economy	4000.00
0005434344632	29807	Economy	4000.00
0005435304240	29807	Economy	4000.00
0005434142657	29807	Economy	4000.00
0005434344471	29807	Economy	4000.00
0005435304238	29807	Economy	4000.00
0005434344574	29807	Economy	4000.00
0005435304241	29807	Economy	4000.00
0005434344538	29807	Economy	4000.00
0005434344517	29807	Economy	4000.00
0005433415928	1268	Business	199800.00
0005435825162	1268	Business	199800.00
0005435825165	1268	Business	199800.00
0005433415932	1268	Business	199800.00
0005435825155	1268	Business	199800.00
0005433415857	1268	Business	199800.00
0005433415834	1268	Business	199800.00
0005435825142	1268	Business	199800.00
0005435825161	1268	Business	199800.00
0005435825154	1268	Business	199800.00
0005433415871	1268	Economy	66600.00
0005435825149	1268	Economy	66600.00
0005435825164	1268	Economy	66600.00
0005433415835	1268	Economy	66600.00
0005435825148	1268	Economy	66600.00
0005433415812	1268	Economy	66600.00
0005433415850	1268	Economy	73200.00
0005433415863	1268	Economy	73200.00
0005433415902	1268	Economy	66600.00
0005435825153	1268	Economy	66600.00
0005432284615	1268	Economy	66600.00
0005433415933	1268	Economy	66600.00
0005433415873	1268	Economy	66600.00
0005433415829	1268	Economy	66600.00
0005435825156	1268	Economy	66600.00
0005433415876	1268	Economy	66600.00
0005435825158	1268	Economy	66600.00
0005433415853	1268	Economy	66600.00
0005435825152	1268	Economy	66600.00
0005435825168	1268	Economy	66600.00
0005433415874	1268	Economy	66600.00
0005432284616	1268	Economy	66600.00
0005433415790	1268	Economy	66600.00
0005435825144	1268	Economy	66600.00
0005433415833	1268	Economy	66600.00
0005432284617	1268	Economy	66600.00
0005433415720	1268	Economy	66600.00
0005433415767	1268	Economy	66600.00
0005435825157	1268	Economy	66600.00
0005435825167	1268	Economy	66600.00
0005435825145	1268	Economy	66600.00
0005433415864	1268	Economy	66600.00
0005433415923	1268	Economy	66600.00
0005435825150	1268	Economy	66600.00
0005433415854	1268	Economy	66600.00
0005433415802	1268	Economy	66600.00
0005433415786	1268	Economy	66600.00
0005435825143	1268	Economy	66600.00
0005433415799	1268	Economy	66600.00
0005433415872	1268	Economy	66600.00
0005433415875	1268	Economy	66600.00
0005433415929	1268	Economy	66600.00
0005435825160	1268	Economy	66600.00
0005435825147	1268	Economy	66600.00
0005435825146	1268	Economy	66600.00
0005433415791	1268	Economy	66600.00
0005435825166	1268	Economy	66600.00
0005433415830	1268	Economy	66600.00
0005435825163	1268	Economy	66600.00
0005433415849	1268	Economy	66600.00
0005433415852	1268	Economy	66600.00
0005435825159	1268	Economy	66600.00
0005433415851	1268	Economy	66600.00
0005435825151	1268	Economy	66600.00
0005435824964	18012	Business	199800.00
0005433415971	18012	Business	199800.00
0005435824932	18012	Business	199800.00
0005435825002	18012	Business	199800.00
0005433415980	18012	Business	199800.00
0005435825003	18012	Economy	66600.00
0005433415967	18012	Economy	66600.00
0005435824945	18012	Economy	73200.00
0005433415969	18012	Economy	73200.00
0005435824940	18012	Economy	66600.00
0005435824968	18012	Economy	66600.00
0005435824933	18012	Economy	66600.00
0005433415970	18012	Economy	66600.00
0005435825022	18012	Economy	66600.00
0005433415977	18012	Economy	66600.00
0005435824874	18012	Economy	66600.00
0005433415972	18012	Economy	66600.00
0005433415973	18012	Economy	66600.00
0005435824892	18012	Economy	66600.00
0005435824934	18012	Economy	66600.00
0005433415976	18012	Economy	66600.00
0005433415966	18012	Economy	66600.00
0005435824822	18012	Economy	66600.00
0005433415978	18012	Economy	66600.00
0005433415975	18012	Economy	66600.00
0005435824812	18012	Economy	66600.00
0005435824891	18012	Economy	66600.00
0005435824973	18012	Economy	66600.00
0005433415981	18012	Economy	66600.00
0005433415979	18012	Economy	66600.00
0005435824864	18012	Economy	66600.00
0005435824870	18012	Economy	66600.00
0005435824925	18012	Economy	66600.00
0005435824924	18012	Economy	66600.00
0005433415974	18012	Economy	66600.00
0005433415965	18012	Economy	66600.00
0005433415968	18012	Economy	66600.00
0005434461683	12570	Economy	13500.00
0005434461682	12570	Economy	13500.00
0005434460541	12570	Economy	13500.00
0005434460546	12570	Economy	13500.00
0005434460544	12570	Economy	13500.00
0005434461685	12570	Economy	13500.00
0005434460545	12570	Economy	13500.00
0005434461686	12570	Economy	13500.00
0005434461687	12570	Economy	13500.00
0005434460542	12570	Economy	13500.00
0005434461688	12570	Economy	13500.00
0005434460543	12570	Economy	13500.00
0005434460540	12570	Economy	13500.00
0005434461684	12570	Economy	13500.00
0005435476827	5668	Business	27800.00
0005432784859	5668	Business	27800.00
0005435243111	5668	Business	27800.00
0005432784847	5668	Business	27800.00
0005435476847	5668	Business	27800.00
0005435243059	5668	Business	27800.00
0005432784866	5668	Business	27800.00
0005435243103	5668	Business	27800.00
0005435476804	5668	Business	27800.00
0005432784851	5668	Business	27800.00
0005432784873	5668	Business	27800.00
0005432784825	5668	Economy	9300.00
0005432784849	5668	Economy	9300.00
0005432784842	5668	Economy	9300.00
0005435243032	5668	Economy	9300.00
0005432784823	5668	Economy	9300.00
0005432784843	5668	Economy	9300.00
0005432784868	5668	Economy	9300.00
0005435243060	5668	Economy	9300.00
0005435243131	5668	Economy	10200.00
0005435243228	5668	Economy	10200.00
0005432784827	5668	Economy	10200.00
0005432784829	5668	Economy	10200.00
0005432144053	5668	Economy	10200.00
0005432784872	5668	Economy	9300.00
0005432784854	5668	Economy	9300.00
0005432784876	5668	Economy	9300.00
0005432784839	5668	Economy	9300.00
0005432784860	5668	Economy	9300.00
0005432784875	5668	Economy	9300.00
0005432784845	5668	Economy	9300.00
0005432784838	5668	Economy	9300.00
0005432784862	5668	Economy	9300.00
0005432784865	5668	Economy	9300.00
0005435243165	5668	Economy	9300.00
0005435476849	5668	Economy	9300.00
0005435243104	5668	Economy	9300.00
0005432784840	5668	Economy	9300.00
0005432784848	5668	Economy	9300.00
0005432784830	5668	Economy	9300.00
0005435243116	5668	Economy	9300.00
0005432784874	5668	Economy	9300.00
0005432784853	5668	Economy	9300.00
0005432784852	5668	Economy	9300.00
0005432784836	5668	Economy	9300.00
0005435243105	5668	Economy	9300.00
0005432784871	5668	Economy	9300.00
0005432784858	5668	Economy	9300.00
0005432784831	5668	Economy	9300.00
0005432784828	5668	Economy	9300.00
0005432784835	5668	Economy	9300.00
0005432784826	5668	Economy	9300.00
0005432784863	5668	Economy	9300.00
0005432784833	5668	Economy	9300.00
0005432784870	5668	Economy	9300.00
0005432784869	5668	Economy	9300.00
0005432784857	5668	Economy	9300.00
0005432784837	5668	Economy	9300.00
0005432784832	5668	Economy	9300.00
0005432784841	5668	Economy	9300.00
0005435476803	5668	Economy	9300.00
0005432144052	5668	Economy	9300.00
0005435243080	5668	Economy	9300.00
0005432784822	5668	Economy	9300.00
0005432784867	5668	Economy	9300.00
0005435949979	5668	Economy	9300.00
0005432784834	5668	Economy	9300.00
0005435243227	5668	Economy	9300.00
0005432784855	5668	Economy	9300.00
0005435243150	5668	Economy	9300.00
0005435949978	5668	Economy	9300.00
0005432144051	5668	Economy	9300.00
0005432784856	5668	Economy	9300.00
0005435243112	5668	Economy	9300.00
0005435243061	5668	Economy	9300.00
0005432784824	5668	Economy	9300.00
0005432784844	5668	Economy	9300.00
0005432784850	5668	Economy	9300.00
0005432784861	5668	Economy	9300.00
0005435476848	5668	Economy	9300.00
0005432784846	5668	Economy	9300.00
0005435243073	5668	Economy	9300.00
0005432784864	5668	Economy	9300.00
0005435243352	15347	Business	27800.00
0005432784274	15347	Business	27800.00
0005435243369	15347	Business	27800.00
0005432784589	15347	Business	27800.00
0005435243358	15347	Business	27800.00
0005432784376	15347	Business	27800.00
0005435476890	15347	Business	27800.00
0005435243367	15347	Business	27800.00
0005432784531	15347	Business	27800.00
0005432784433	15347	Business	27800.00
0005432784213	15347	Business	27800.00
0005432784500	15347	Economy	9300.00
0005435243350	15347	Economy	9300.00
0005432784489	15347	Economy	9300.00
0005435476889	15347	Economy	9300.00
0005432784302	15347	Economy	9300.00
0005432784221	15347	Economy	9300.00
0005432784313	15347	Economy	9300.00
0005432784414	15347	Economy	9300.00
0005435243372	15347	Economy	9300.00
0005435243349	15347	Economy	10200.00
0005432784247	15347	Economy	10200.00
0005435243365	15347	Economy	10200.00
0005435476887	15347	Economy	10200.00
0005435243355	15347	Economy	10200.00
0005435243373	15347	Economy	9300.00
0005432784394	15347	Economy	9300.00
0005432784063	15347	Economy	9300.00
0005435243362	15347	Economy	9300.00
0005435243371	15347	Economy	9300.00
0005432784263	15347	Economy	9300.00
0005435476891	15347	Economy	9300.00
0005432784417	15347	Economy	9300.00
0005432784111	15347	Economy	9300.00
0005435476892	15347	Economy	9300.00
0005432784246	15347	Economy	9300.00
0005432784197	15347	Economy	9300.00
0005432784364	15347	Economy	9300.00
0005432784405	15347	Economy	9300.00
0005432784259	15347	Economy	9300.00
0005432784141	15347	Economy	9300.00
0005432784198	15347	Economy	9300.00
0005432784588	15347	Economy	9300.00
0005432784451	15347	Economy	9300.00
0005432784393	15347	Economy	9300.00
0005432784346	15347	Economy	9300.00
0005432784395	15347	Economy	9300.00
0005432784499	15347	Economy	9300.00
0005432784337	15347	Economy	9300.00
0005432784329	15347	Economy	9300.00
0005435243347	15347	Economy	9300.00
0005432784434	15347	Economy	9300.00
0005435476888	15347	Economy	9300.00
0005432784382	15347	Economy	9300.00
0005432784590	15347	Economy	9300.00
0005432784498	15347	Economy	9300.00
0005432784344	15347	Economy	9300.00
0005435243346	15347	Economy	9300.00
0005432784238	15347	Economy	9300.00
0005432784541	15347	Economy	9300.00
0005435243357	15347	Economy	9300.00
0005435243363	15347	Economy	9300.00
0005432784377	15347	Economy	9300.00
0005435243370	15347	Economy	9300.00
0005435243348	15347	Economy	9300.00
0005432784312	15347	Economy	9300.00
0005435243345	15347	Economy	9300.00
0005432784416	15347	Economy	9300.00
0005432784345	15347	Economy	9300.00
0005435476894	15347	Economy	9300.00
0005435476893	15347	Economy	9300.00
0005432784343	15347	Economy	9300.00
0005432784497	15347	Economy	9300.00
0005432784450	15347	Economy	9300.00
0005432784368	15347	Economy	9300.00
0005435243364	15347	Economy	9300.00
0005435243366	15347	Economy	9300.00
0005435243353	15347	Economy	9300.00
0005435476895	15347	Economy	9300.00
0005432784462	15347	Economy	9300.00
0005432784317	15347	Economy	9300.00
0005432784062	15347	Economy	9300.00
0005435243356	15347	Economy	9300.00
0005432784293	15347	Economy	9300.00
0005435243368	15347	Economy	9300.00
0005432784338	15347	Economy	9300.00
0005432784301	15347	Economy	9300.00
0005435243354	15347	Economy	9300.00
0005435243359	15347	Economy	9300.00
0005435243351	15347	Economy	9300.00
0005435243361	15347	Economy	9300.00
0005435243360	15347	Economy	9300.00
0005435851018	4365	Economy	7000.00
0005435851042	4365	Economy	7000.00
0005434463973	4365	Economy	7000.00
0005435851040	4365	Economy	6300.00
0005434462832	4365	Economy	6300.00
0005434463972	4365	Economy	6300.00
0005432848595	4365	Economy	6300.00
0005435851005	4365	Economy	6300.00
0005435850988	4365	Economy	6300.00
0005435851041	4365	Economy	6300.00
0005432848604	4365	Economy	6300.00
0005435851010	4365	Economy	6300.00
0005432848593	4365	Economy	6300.00
0005432848599	4365	Economy	6300.00
0005435851016	4365	Economy	6300.00
0005432848600	4365	Economy	6300.00
0005435851029	4365	Economy	6300.00
0005432848601	4365	Economy	6300.00
0005435851063	4365	Economy	6300.00
0005435851017	4365	Economy	6300.00
0005432848597	4365	Economy	6300.00
0005432848592	4365	Economy	6300.00
0005432848596	4365	Economy	6300.00
0005434462833	4365	Economy	6300.00
0005432848603	4365	Economy	6300.00
0005432848594	4365	Economy	6300.00
0005432848598	4365	Economy	6300.00
0005435851009	4365	Economy	6300.00
0005432848602	4365	Economy	6300.00
0005435851015	4365	Economy	6300.00
0005432848591	4365	Economy	6300.00
0005432848507	28879	Economy	7000.00
0005434461663	28879	Economy	7000.00
0005432848416	28879	Economy	7000.00
0005435851086	28879	Economy	6300.00
0005432848415	28879	Economy	6300.00
0005432848497	28879	Economy	6300.00
0005434463948	28879	Economy	6300.00
0005432848558	28879	Economy	6300.00
0005432848446	28879	Economy	6300.00
0005435851092	28879	Economy	6300.00
0005435851085	28879	Economy	6300.00
0005432848447	28879	Economy	6300.00
0005435851089	28879	Economy	6300.00
0005435851093	28879	Economy	6300.00
0005435851091	28879	Economy	6300.00
0005435851090	28879	Economy	6300.00
0005435851087	28879	Economy	6300.00
0005435851088	28879	Economy	6300.00
0005432848491	28879	Economy	6300.00
0005432848493	28879	Economy	6300.00
0005434463947	28879	Economy	6300.00
0005434461657	28879	Economy	6300.00
0005432848445	28879	Economy	6300.00
0005434461662	28879	Economy	6300.00
0005432848479	28879	Economy	6300.00
0005432848480	28879	Economy	6300.00
0005434463940	28879	Economy	6300.00
0005432075299	6353	Business	11900.00
0005433497578	6353	Business	11900.00
0005433497580	6353	Business	11900.00
0005434926407	6353	Business	11900.00
0005433497596	6353	Business	11900.00
0005434926437	6353	Business	11900.00
0005434926421	6353	Business	11900.00
0005434444023	6353	Business	11900.00
0005434444027	6353	Business	11900.00
0005434444019	6353	Business	11900.00
0005434926410	6353	Economy	4000.00
0005434926423	6353	Economy	4000.00
0005433497588	6353	Economy	4000.00
0005433497584	6353	Economy	4000.00
0005434926428	6353	Economy	4000.00
0005433497587	6353	Economy	4000.00
0005433497576	6353	Economy	4000.00
0005434926424	6353	Economy	4000.00
0005434926417	6353	Economy	4000.00
0005433497600	6353	Economy	4400.00
0005432075297	6353	Economy	4400.00
0005433497574	6353	Economy	4400.00
0005433497581	6353	Economy	4400.00
0005434926427	6353	Economy	4400.00
0005433497599	6353	Economy	4000.00
0005432075298	6353	Economy	4000.00
0005433497597	6353	Economy	4000.00
0005434926412	6353	Economy	4000.00
0005433497583	6353	Economy	4000.00
0005434926435	6353	Economy	4000.00
0005434926416	6353	Economy	4000.00
0005434926408	6353	Economy	4000.00
0005434926413	6353	Economy	4000.00
0005434444031	6353	Economy	4000.00
0005434444028	6353	Economy	4000.00
0005434444029	6353	Economy	4000.00
0005434444022	6353	Economy	4000.00
0005434926425	6353	Economy	4000.00
0005434926414	6353	Economy	4000.00
0005433497582	6353	Economy	4000.00
0005433497598	6353	Economy	4000.00
0005433497570	6353	Economy	4000.00
0005434444024	6353	Economy	4000.00
0005433497591	6353	Economy	4000.00
0005434444032	6353	Economy	4000.00
0005434926431	6353	Economy	4000.00
0005433497593	6353	Economy	4000.00
0005433497571	6353	Economy	4000.00
0005434926420	6353	Economy	4000.00
0005434444033	6353	Economy	4000.00
0005434926426	6353	Economy	4000.00
0005434926422	6353	Economy	4000.00
0005433497573	6353	Economy	4000.00
0005434926429	6353	Economy	4000.00
0005434926436	6353	Economy	4000.00
0005433497572	6353	Economy	4000.00
0005434926433	6353	Economy	4000.00
0005433497589	6353	Economy	4000.00
0005434926439	6353	Economy	4000.00
0005434444026	6353	Economy	4000.00
0005434444034	6353	Economy	4000.00
0005434926409	6353	Economy	4000.00
0005433497577	6353	Economy	4000.00
0005433497592	6353	Economy	4000.00
0005434926418	6353	Economy	4000.00
0005433497590	6353	Economy	4000.00
0005434444021	6353	Economy	4000.00
0005433497569	6353	Economy	4000.00
0005434926411	6353	Economy	4000.00
0005434926415	6353	Economy	4000.00
0005433497585	6353	Economy	4000.00
0005433497586	6353	Economy	4000.00
0005434926405	6353	Economy	4000.00
0005433497575	6353	Economy	4000.00
0005434444025	6353	Economy	4000.00
0005434926438	6353	Economy	4000.00
0005434926430	6353	Economy	4000.00
0005433497595	6353	Economy	4000.00
0005434444020	6353	Economy	4000.00
0005433497594	6353	Economy	4000.00
0005434926406	6353	Economy	4000.00
0005434926434	6353	Economy	4000.00
0005434926419	6353	Economy	4000.00
0005434926432	6353	Economy	4000.00
0005434444035	6353	Economy	4000.00
0005433497579	6353	Economy	4000.00
0005434444030	6353	Economy	4000.00
0005435257413	20374	Economy	4000.00
0005435257410	20374	Economy	4000.00
0005435257412	20374	Economy	4000.00
0005435257408	20374	Economy	4000.00
0005435257407	20374	Economy	4000.00
0005435257411	20374	Economy	4000.00
0005435257409	20374	Economy	4000.00
0005433497463	20375	Business	11900.00
0005433497317	20375	Business	11900.00
0005433497353	20375	Business	11900.00
0005434443847	20375	Business	11900.00
0005433497265	20375	Business	11900.00
0005434926085	20375	Business	11900.00
0005433497355	20375	Business	11900.00
0005434443867	20375	Business	11900.00
0005433497413	20375	Business	11900.00
0005433497354	20375	Business	11900.00
0005433497399	20375	Economy	4000.00
0005434926138	20375	Economy	4000.00
0005434926159	20375	Economy	4000.00
0005433497492	20375	Economy	4000.00
0005434926047	20375	Economy	4000.00
0005434926111	20375	Economy	4000.00
0005433497299	20375	Economy	4000.00
0005433497504	20375	Economy	4000.00
0005433497378	20375	Economy	4000.00
0005433497368	20375	Economy	4400.00
0005434926066	20375	Economy	4400.00
0005433497348	20375	Economy	4400.00
0005434926165	20375	Economy	4400.00
0005434926143	20375	Economy	4000.00
0005434926126	20375	Economy	4000.00
0005434925974	20375	Economy	4000.00
0005434925976	20375	Economy	4000.00
0005434926051	20375	Economy	4000.00
0005434926078	20375	Economy	4000.00
0005433497259	20375	Economy	4000.00
0005434443840	20375	Economy	4000.00
0005434925975	20375	Economy	4000.00
0005433497316	20375	Economy	4000.00
0005434926093	20375	Economy	4000.00
0005433497257	20375	Economy	4000.00
0005434926084	20375	Economy	4000.00
0005433497379	20375	Economy	4000.00
0005434926062	20375	Economy	4000.00
0005434926050	20375	Economy	4000.00
0005434926067	20375	Economy	4000.00
0005433497347	20375	Economy	4000.00
0005433497204	20375	Economy	4000.00
0005433497315	20375	Economy	4000.00
0005434926030	20375	Economy	4000.00
0005433497202	20375	Economy	4000.00
0005434926029	20375	Economy	4000.00
0005434926139	20375	Economy	4000.00
0005434926079	20375	Economy	4000.00
0005434443887	20375	Economy	4000.00
0005433497332	20375	Economy	4000.00
0005433497318	20375	Economy	4000.00
0005434926114	20375	Economy	4000.00
0005434443824	20375	Economy	4000.00
0005434926122	20375	Economy	4000.00
0005434926115	20375	Economy	4000.00
0005434443846	20375	Economy	4000.00
0005433497180	20375	Economy	4000.00
0005434926121	20375	Economy	4000.00
0005433497367	20375	Economy	4000.00
0005434926146	20375	Economy	4000.00
0005434443902	20375	Economy	4000.00
0005434926117	20375	Economy	4000.00
0005433497258	20375	Economy	4000.00
0005434925973	20375	Economy	4000.00
0005433497358	20375	Economy	4000.00
0005434443856	20375	Economy	4000.00
0005434926021	20375	Economy	4000.00
0005433497327	20375	Economy	4000.00
0005433497503	20375	Economy	4000.00
0005433497264	20375	Economy	4000.00
0005434443843	20375	Economy	4000.00
0005433497326	20375	Economy	4000.00
0005433497398	20375	Economy	4000.00
0005433497256	20375	Economy	4000.00
0005433497203	20375	Economy	4000.00
0005433497103	20375	Economy	4000.00
0005433497319	20375	Economy	4000.00
0005433497300	20375	Economy	4000.00
0005433497331	20375	Economy	4000.00
0005434926127	20375	Economy	4000.00
0005432784415	12163	Business	41200.00
0005432784399	12163	Business	41200.00
0005432784277	12163	Business	41200.00
0005435243381	12163	Business	41200.00
0005432784544	12163	Business	41200.00
0005435243396	12163	Business	41200.00
0005432784361	12163	Business	41200.00
0005432784366	12163	Business	41200.00
0005435243379	12163	Business	41200.00
0005435243389	12163	Economy	13700.00
0005432784352	12163	Economy	13700.00
0005435243391	12163	Economy	13700.00
0005432784260	12163	Economy	13700.00
0005432784476	12163	Economy	13700.00
0005435243383	12163	Economy	13700.00
0005432784272	12163	Economy	13700.00
0005432784373	12163	Economy	13700.00
0005432784625	12163	Economy	13700.00
0005435243386	12163	Economy	15100.00
0005432784354	12163	Economy	15100.00
0005432784455	12163	Economy	15100.00
0005432784435	12163	Economy	15100.00
0005432784355	12163	Economy	13700.00
0005432784626	12163	Economy	13700.00
0005435243385	12163	Economy	13700.00
0005432784351	12163	Economy	13700.00
0005432784264	12163	Economy	13700.00
0005432784134	12163	Economy	13700.00
0005435243398	12163	Economy	13700.00
0005435243384	12163	Economy	13700.00
0005435243378	12163	Economy	13700.00
0005432784282	12163	Economy	13700.00
0005432784322	12163	Economy	13700.00
0005432784252	12163	Economy	13700.00
0005435243382	12163	Economy	13700.00
0005435243376	12163	Economy	13700.00
0005432784350	12163	Economy	13700.00
0005435243377	12163	Economy	13700.00
0005435243374	12163	Economy	13700.00
0005432784222	12163	Economy	13700.00
0005435243395	12163	Economy	13700.00
0005432784185	12163	Economy	13700.00
0005432784468	12163	Economy	13700.00
0005432784424	12163	Economy	13700.00
0005435243392	12163	Economy	13700.00
0005435243393	12163	Economy	13700.00
0005432784479	12163	Economy	13700.00
0005432784353	12163	Economy	13700.00
0005432784423	12163	Economy	13700.00
0005432784493	12163	Economy	13700.00
0005435243388	12163	Economy	13700.00
0005432784446	12163	Economy	13700.00
0005435243387	12163	Economy	13700.00
0005432784357	12163	Economy	13700.00
0005435243394	12163	Economy	13700.00
0005432784510	12163	Economy	13700.00
0005432784365	12163	Economy	13700.00
0005432784318	12163	Economy	13700.00
0005432784492	12163	Economy	13700.00
0005435243397	12163	Economy	13700.00
0005432784480	12163	Economy	13700.00
0005432784511	12163	Economy	13700.00
0005432784491	12163	Economy	13700.00
0005435243390	12163	Economy	13700.00
0005432784431	12163	Economy	13700.00
0005432784223	12163	Economy	13700.00
0005435243375	12163	Economy	13700.00
0005432784532	12163	Economy	13700.00
0005432784418	12163	Economy	13700.00
0005432784467	12163	Economy	13700.00
0005432784324	12163	Economy	13700.00
0005432784273	12163	Economy	13700.00
0005435243399	12163	Economy	13700.00
0005432784398	12163	Economy	13700.00
0005432784430	12163	Economy	13700.00
0005435243380	12163	Economy	13700.00
0005432784315	12163	Economy	13700.00
0005432784796	15450	Business	41200.00
0005432784788	15450	Business	41200.00
0005432784803	15450	Business	41200.00
0005432784808	15450	Business	41200.00
0005435243024	15450	Business	41200.00
0005435243108	15450	Business	41200.00
0005432784789	15450	Business	41200.00
0005432784821	15450	Business	41200.00
0005432784793	15450	Business	41200.00
0005432784769	15450	Business	41200.00
0005435243190	15450	Economy	13700.00
0005432784772	15450	Economy	13700.00
0005432784816	15450	Economy	13700.00
0005432784767	15450	Economy	13700.00
0005435243133	15450	Economy	13700.00
0005432784782	15450	Economy	13700.00
0005432784805	15450	Economy	13700.00
0005435243067	15450	Economy	13700.00
0005432784797	15450	Economy	15100.00
0005432784799	15450	Economy	15100.00
0005435243091	15450	Economy	15100.00
0005432784795	15450	Economy	15100.00
0005432784768	15450	Economy	15100.00
0005432784801	15450	Economy	13700.00
0005432784820	15450	Economy	13700.00
0005435243136	15450	Economy	13700.00
0005432784775	15450	Economy	13700.00
0005435243023	15450	Economy	13700.00
0005432784792	15450	Economy	13700.00
0005432784817	15450	Economy	13700.00
0005435243068	15450	Economy	13700.00
0005432784780	15450	Economy	13700.00
0005432784784	15450	Economy	13700.00
0005432784776	15450	Economy	13700.00
0005435243007	15450	Economy	13700.00
0005432784778	15450	Economy	13700.00
0005432784815	15450	Economy	13700.00
0005432784787	15450	Economy	13700.00
0005432784771	15450	Economy	13700.00
0005432784819	15450	Economy	13700.00
0005432784781	15450	Economy	13700.00
0005432784809	15450	Economy	13700.00
0005432784812	15450	Economy	13700.00
0005432784807	15450	Economy	13700.00
0005432784814	15450	Economy	13700.00
0005435243087	15450	Economy	13700.00
0005435243110	15450	Economy	13700.00
0005432784785	15450	Economy	13700.00
0005432784773	15450	Economy	13700.00
0005435243084	15450	Economy	13700.00
0005432784794	15450	Economy	13700.00
0005435243025	15450	Economy	13700.00
0005435243086	15450	Economy	13700.00
0005432784818	15450	Economy	13700.00
0005435243077	15450	Economy	13700.00
0005432784783	15450	Economy	13700.00
0005432784790	15450	Economy	13700.00
0005435242968	15450	Economy	13700.00
0005435243117	15450	Economy	13700.00
0005432784810	15450	Economy	13700.00
0005435243174	15450	Economy	13700.00
0005435243008	15450	Economy	13700.00
0005432784800	15450	Economy	13700.00
0005432784811	15450	Economy	13700.00
0005432784802	15450	Economy	13700.00
0005435243082	15450	Economy	13700.00
0005432784813	15450	Economy	13700.00
0005432784786	15450	Economy	13700.00
0005432784804	15450	Economy	13700.00
0005432784779	15450	Economy	13700.00
0005432784777	15450	Economy	13700.00
0005435243055	15450	Economy	13700.00
0005432784798	15450	Economy	13700.00
0005435243081	15450	Economy	13700.00
0005432784791	15450	Economy	13700.00
0005435243135	15450	Economy	13700.00
0005432784806	15450	Economy	13700.00
0005435243118	15450	Economy	13700.00
0005432784774	15450	Economy	13700.00
0005435243046	15450	Economy	13700.00
0005432784770	15450	Economy	13700.00
0005435243088	15450	Economy	13700.00
0005435243099	15450	Economy	13700.00
0005435243056	15450	Economy	13700.00
0005434879578	10121	Business	49700.00
0005434879216	10121	Business	49700.00
0005434879259	10121	Business	49700.00
0005434879145	10121	Business	49700.00
0005434879219	10121	Business	49700.00
0005434879081	10121	Business	49700.00
0005434879278	10121	Business	49700.00
0005434879190	10121	Business	49700.00
0005434879579	10121	Business	49700.00
0005434879537	10121	Business	49700.00
0005435914016	10121	Business	49700.00
0005435914022	10121	Business	49700.00
0005434879273	10121	Business	49700.00
0005434879127	10121	Business	49700.00
0005434879055	10121	Business	49700.00
0005434910158	10121	Business	49700.00
0005434910156	10121	Business	49700.00
0005435914017	10121	Business	49700.00
0005435914014	10121	Business	49700.00
0005434879009	10121	Business	49700.00
0005434758929	10121	Economy	16600.00
0005434879202	10121	Economy	16600.00
0005434879458	10121	Economy	16600.00
0005434879277	10121	Economy	16600.00
0005434879538	10121	Economy	16600.00
0005434879302	10121	Economy	16600.00
0005434879480	10121	Economy	16600.00
0005434879158	10121	Economy	16600.00
0005434879550	10121	Economy	16600.00
0005434879189	10121	Economy	16600.00
0005434879294	10121	Economy	16600.00
0005434878846	10121	Economy	16600.00
0005434879481	10121	Economy	16600.00
0005435914023	10121	Economy	18200.00
0005434879415	10121	Economy	18200.00
0005434879539	10121	Economy	18200.00
0005434758914	10121	Economy	18200.00
0005434879293	10121	Economy	16600.00
0005435914012	10121	Economy	16600.00
0005434879235	10121	Economy	16600.00
0005435914009	10121	Economy	16600.00
0005434879338	10121	Economy	16600.00
0005434758911	10121	Economy	16600.00
0005434879421	10121	Economy	16600.00
0005434758924	10121	Economy	16600.00
0005434879241	10121	Economy	16600.00
0005434878898	10121	Economy	16600.00
0005435914010	10121	Economy	16600.00
0005435914019	10121	Economy	16600.00
0005434879601	10121	Economy	16600.00
0005434879509	10121	Economy	16600.00
0005434879720	10121	Economy	16600.00
0005435914008	10121	Economy	16600.00
0005434879236	10121	Economy	16600.00
0005434879188	10121	Economy	16600.00
0005434879220	10121	Economy	16600.00
0005434879266	10121	Economy	16600.00
0005434878939	10121	Economy	16600.00
0005434879644	10121	Economy	16600.00
0005435914025	10121	Economy	16600.00
0005434879428	10121	Economy	16600.00
0005434879381	10121	Economy	16600.00
0005434879383	10121	Economy	16600.00
0005435914011	10121	Economy	16600.00
0005434879279	10121	Economy	16600.00
0005434879511	10121	Economy	16600.00
0005434879263	10121	Economy	16600.00
0005434879357	10121	Economy	16600.00
0005434879395	10121	Economy	16600.00
0005434879396	10121	Economy	16600.00
0005434879540	10121	Economy	16600.00
0005434879203	10121	Economy	16600.00
0005434879262	10121	Economy	16600.00
0005434879157	10121	Economy	16600.00
0005434878905	10121	Economy	16600.00
0005434758925	10121	Economy	16600.00
0005434879276	10121	Economy	16600.00
0005434878874	10121	Economy	16600.00
0005434758930	10121	Economy	16600.00
0005434879627	10121	Economy	16600.00
0005434879159	10121	Economy	16600.00
0005435914013	10121	Economy	16600.00
0005434879562	10121	Economy	16600.00
0005434879019	10121	Economy	16600.00
0005434879104	10121	Economy	16600.00
0005434758919	10121	Economy	16600.00
0005434879492	10121	Economy	16600.00
0005434879083	10121	Economy	16600.00
0005435914015	10121	Economy	16600.00
0005434879602	10121	Economy	16600.00
0005434910157	10121	Economy	16600.00
0005434879699	10121	Economy	16600.00
0005434879412	10121	Economy	16600.00
0005434878897	10121	Economy	16600.00
0005435914021	10121	Economy	16600.00
0005435914018	10121	Economy	16600.00
0005435914026	10121	Economy	16600.00
0005434879331	10121	Economy	16600.00
0005434878938	10121	Economy	16600.00
0005435914024	10121	Economy	16600.00
0005434879425	10121	Economy	16600.00
0005434879167	10121	Economy	16600.00
0005434879352	10121	Economy	16600.00
0005434879082	10121	Economy	16600.00
0005434879217	10121	Economy	16600.00
0005434879301	10121	Economy	16600.00
0005434879114	10121	Economy	16600.00
0005434879597	10121	Economy	16600.00
0005434879413	10121	Economy	16600.00
0005434879561	10121	Economy	16600.00
0005434878875	10121	Economy	16600.00
0005435914020	10121	Economy	16600.00
0005434879457	10121	Economy	16600.00
0005434880061	14604	Business	49700.00
0005434880028	14604	Business	49700.00
0005434880076	14604	Business	49700.00
0005434758939	14604	Business	49700.00
0005434880065	14604	Business	49700.00
0005434880112	14604	Business	49700.00
0005434880057	14604	Business	49700.00
0005434880093	14604	Business	49700.00
0005434880042	14604	Business	49700.00
0005434880082	14604	Business	49700.00
0005434880098	14604	Business	49700.00
0005434880081	14604	Business	49700.00
0005435913956	14604	Business	49700.00
0005434880109	14604	Business	49700.00
0005434880050	14604	Business	49700.00
0005434880059	14604	Business	49700.00
0005434880099	14604	Business	49700.00
0005434880023	14604	Business	49700.00
0005434880047	14604	Economy	16600.00
0005434880022	14604	Business	49700.00
0005434880030	14604	Economy	16600.00
0005434880062	14604	Economy	16600.00
0005434880079	14604	Economy	16600.00
0005434880071	14604	Economy	16600.00
0005434880102	14604	Economy	16600.00
0005434880052	14604	Economy	16600.00
0005434880066	14604	Economy	16600.00
0005434880032	14604	Economy	16600.00
0005434880044	14604	Economy	16600.00
0005434880043	14604	Economy	18200.00
0005434880074	14604	Economy	18200.00
0005434880058	14604	Economy	18200.00
0005434880113	14604	Economy	18200.00
0005434880100	14604	Economy	16600.00
0005434880056	14604	Economy	16600.00
0005434880027	14604	Economy	16600.00
0005434880060	14604	Economy	16600.00
0005434880088	14604	Economy	16600.00
0005434880096	14604	Economy	16600.00
0005434880091	14604	Economy	16600.00
0005434880031	14604	Economy	16600.00
0005434880107	14604	Economy	16600.00
0005434880094	14604	Economy	16600.00
0005434880036	14604	Economy	16600.00
0005434880070	14604	Economy	16600.00
0005434880020	14604	Economy	16600.00
0005434880029	14604	Economy	16600.00
0005434880055	14604	Economy	16600.00
0005434880073	14604	Economy	16600.00
0005434880040	14604	Economy	16600.00
0005434880111	14604	Economy	16600.00
0005434880041	14604	Economy	16600.00
0005434880080	14604	Economy	16600.00
0005434880037	14604	Economy	16600.00
0005434880045	14604	Economy	16600.00
0005434880085	14604	Economy	16600.00
0005434880115	14604	Economy	16600.00
0005434880021	14604	Economy	16600.00
0005434880039	14604	Economy	16600.00
0005434880046	14604	Economy	16600.00
0005434880038	14604	Economy	16600.00
0005434880033	14604	Economy	16600.00
0005434880114	14604	Economy	16600.00
0005434880068	14604	Economy	16600.00
0005434880105	14604	Economy	16600.00
0005434880083	14604	Economy	16600.00
0005434880026	14604	Economy	16600.00
0005434880035	14604	Economy	16600.00
0005434880051	14604	Economy	16600.00
0005434880053	14604	Economy	16600.00
0005434880101	14604	Economy	16600.00
0005434758938	14604	Economy	16600.00
0005434880095	14604	Economy	16600.00
0005434880072	14604	Economy	16600.00
0005434880110	14604	Economy	16600.00
0005434880054	14604	Economy	16600.00
0005434880090	14604	Economy	16600.00
0005434880034	14604	Economy	16600.00
0005434910137	14604	Economy	16600.00
0005434880087	14604	Economy	16600.00
0005434880104	14604	Economy	16600.00
0005434880075	14604	Economy	16600.00
0005434880086	14604	Economy	16600.00
0005434880069	14604	Economy	16600.00
0005434880063	14604	Economy	16600.00
0005434880025	14604	Economy	16600.00
0005434880108	14604	Economy	16600.00
0005434880078	14604	Economy	16600.00
0005434880067	14604	Economy	16600.00
0005434758940	14604	Economy	16600.00
0005434880048	14604	Economy	16600.00
0005434880024	14604	Economy	16600.00
0005434880103	14604	Economy	16600.00
0005434880064	14604	Economy	16600.00
0005434880089	14604	Economy	16600.00
0005434880092	14604	Economy	16600.00
0005434880106	14604	Economy	16600.00
0005434880097	14604	Economy	16600.00
0005434880084	14604	Economy	16600.00
0005434880077	14604	Economy	16600.00
0005434880019	14604	Economy	16600.00
0005434880049	14604	Economy	16600.00
0005434252088	9248	Economy	22400.00
0005435660352	9248	Economy	22400.00
0005435660361	9248	Economy	20300.00
0005434252047	9248	Economy	20300.00
0005434252093	9248	Economy	20300.00
0005435660357	9248	Economy	20300.00
0005434252087	9248	Economy	20300.00
0005435660354	9248	Economy	20300.00
0005434252094	9248	Economy	20300.00
0005435660360	9248	Economy	20300.00
0005434252081	9248	Economy	20300.00
0005435660362	9248	Economy	20300.00
0005435660359	9248	Economy	20300.00
0005435660355	9248	Economy	20300.00
0005434252045	9248	Economy	20300.00
0005434252112	9248	Economy	20300.00
0005435660356	9248	Economy	20300.00
0005434252046	9248	Economy	20300.00
0005434252028	9248	Economy	20300.00
0005435660358	9248	Economy	20300.00
0005435660353	9248	Economy	20300.00
0005435660351	9248	Economy	20300.00
0005435660217	24632	Economy	20300.00
0005434252148	24632	Economy	20300.00
0005434252151	24632	Economy	20300.00
0005435660261	24632	Economy	20300.00
0005434252150	24632	Economy	20300.00
0005435660216	24632	Economy	20300.00
0005435660248	24632	Economy	20300.00
0005435660253	24632	Economy	20300.00
0005434252145	24632	Economy	20300.00
0005434252153	24632	Economy	20300.00
0005435660254	24632	Economy	20300.00
0005434252154	24632	Economy	20300.00
0005434252152	24632	Economy	20300.00
0005434252149	24632	Economy	20300.00
0005434252155	24632	Economy	20300.00
0005434252147	24632	Economy	20300.00
0005434252146	24632	Economy	20300.00
0005433681470	2787	Business	33000.00
0005433681483	2787	Business	33000.00
0005433681502	2787	Business	33000.00
0005432967199	2787	Business	33000.00
0005433681504	2787	Business	33000.00
0005433681495	2787	Business	33000.00
0005432967232	2787	Business	33000.00
0005433681509	2787	Business	33000.00
0005433684459	2787	Business	33000.00
0005433681475	2787	Business	33000.00
0005433681505	2787	Business	33000.00
0005432967284	2787	Business	33000.00
0005432967187	2787	Economy	11000.00
0005433681517	2787	Economy	11000.00
0005432967257	2787	Economy	11000.00
0005433681507	2787	Economy	11000.00
0005433684460	2787	Economy	11000.00
0005433681499	2787	Economy	11000.00
0005433681503	2787	Economy	11000.00
0005433681485	2787	Economy	11000.00
0005432967176	2787	Economy	11000.00
0005432967363	2787	Economy	12100.00
0005432967258	2787	Economy	12100.00
0005432967085	2787	Economy	12100.00
0005433681498	2787	Economy	12100.00
0005433681500	2787	Economy	12100.00
0005433681478	2787	Economy	11000.00
0005432967316	2787	Economy	11000.00
0005433681480	2787	Economy	11000.00
0005433681486	2787	Economy	11000.00
0005432222886	2787	Economy	11000.00
0005432967186	2787	Economy	11000.00
0005433681510	2787	Economy	11000.00
0005432967227	2787	Economy	11000.00
0005432967235	2787	Economy	11000.00
0005432967074	2787	Economy	11000.00
0005433681492	2787	Economy	11000.00
0005432967073	2787	Economy	11000.00
0005433681497	2787	Economy	11000.00
0005432967108	2787	Economy	11000.00
0005433681489	2787	Economy	11000.00
0005432222884	2787	Economy	11000.00
0005432967315	2787	Economy	11000.00
0005433684461	2787	Economy	11000.00
0005433681493	2787	Economy	11000.00
0005432967288	2787	Economy	11000.00
0005432967111	2787	Economy	11000.00
0005432967177	2787	Economy	11000.00
0005433681479	2787	Economy	11000.00
0005433681491	2787	Economy	11000.00
0005433681501	2787	Economy	11000.00
0005432967222	2787	Economy	11000.00
0005432967217	2787	Economy	11000.00
0005433681494	2787	Economy	11000.00
0005432967221	2787	Economy	11000.00
0005432967109	2787	Economy	11000.00
0005433681477	2787	Economy	11000.00
0005433681487	2787	Economy	11000.00
0005433681488	2787	Economy	11000.00
0005432222887	2787	Economy	11000.00
0005432967362	2787	Economy	11000.00
0005432967158	2787	Economy	11000.00
0005432967170	2787	Economy	11000.00
0005433681472	2787	Economy	11000.00
0005432967226	2787	Economy	11000.00
0005432967223	2787	Economy	11000.00
0005432967236	2787	Economy	11000.00
0005433681511	2787	Economy	11000.00
0005433681506	2787	Economy	11000.00
0005433681484	2787	Economy	11000.00
0005433681482	2787	Economy	11000.00
0005432967110	2787	Economy	11000.00
0005433681515	2787	Economy	11000.00
0005432222885	2787	Economy	11000.00
0005433681474	2787	Economy	11000.00
0005432967206	2787	Economy	11000.00
0005433681513	2787	Economy	11000.00
0005432967086	2787	Economy	11000.00
0005433681514	2787	Economy	11000.00
0005432967289	2787	Economy	11000.00
0005433681473	2787	Economy	11000.00
0005433681471	2787	Economy	11000.00
0005433681512	2787	Economy	11000.00
0005432222883	2787	Economy	11000.00
0005433681490	2787	Economy	11000.00
0005433681476	2787	Economy	11000.00
0005432967185	2787	Economy	11000.00
0005433681496	2787	Economy	11000.00
0005433681516	2787	Economy	11000.00
0005432967184	2787	Economy	11000.00
0005433681508	2787	Economy	11000.00
0005432967215	2787	Economy	11000.00
0005433681481	2787	Economy	11000.00
0005433680974	29192	Business	33000.00
0005433681186	29192	Business	33000.00
0005433681036	29192	Business	33000.00
0005432967427	29192	Business	33000.00
0005432967422	29192	Business	33000.00
0005433681096	29192	Business	33000.00
0005433681205	29192	Business	33000.00
0005432967435	29192	Business	33000.00
0005433681286	29192	Business	33000.00
0005432967421	29192	Business	33000.00
0005433680959	29192	Business	33000.00
0005432967424	29192	Economy	11000.00
0005432967441	29192	Economy	11000.00
0005433680951	29192	Economy	11000.00
0005433681150	29192	Economy	11000.00
0005433681080	29192	Economy	11000.00
0005433681146	29192	Economy	11000.00
0005432967437	29192	Economy	12100.00
0005433681282	29192	Economy	12100.00
0005433681104	29192	Economy	12100.00
0005432967438	29192	Economy	12100.00
0005433681155	29192	Economy	11000.00
0005433681028	29192	Economy	11000.00
0005433680950	29192	Economy	11000.00
0005432005267	29192	Economy	11000.00
0005433681002	29192	Economy	11000.00
0005433681187	29192	Economy	11000.00
0005432967434	29192	Economy	11000.00
0005433681166	29192	Economy	11000.00
0005432005268	29192	Economy	11000.00
0005433681095	29192	Economy	11000.00
0005433681264	29192	Economy	11000.00
0005433681062	29192	Economy	11000.00
0005433681098	29192	Economy	11000.00
0005433681145	29192	Economy	11000.00
0005433681231	29192	Economy	11000.00
0005432967445	29192	Economy	11000.00
0005433687731	29192	Economy	11000.00
0005432967428	29192	Economy	11000.00
0005432967431	29192	Economy	11000.00
0005433681003	29192	Economy	11000.00
0005432967436	29192	Economy	11000.00
0005433681167	29192	Economy	11000.00
0005432005269	29192	Economy	11000.00
0005433681154	29192	Economy	11000.00
0005433681046	29192	Economy	11000.00
0005433681135	29192	Economy	11000.00
0005432967439	29192	Economy	11000.00
0005433681263	29192	Economy	11000.00
0005432967443	29192	Economy	11000.00
0005433680990	29192	Economy	11000.00
0005433681144	29192	Economy	11000.00
0005432967426	29192	Economy	11000.00
0005433690946	29192	Economy	11000.00
0005433681055	29192	Economy	11000.00
0005433681073	29192	Economy	11000.00
0005432967440	29192	Economy	11000.00
0005433680989	29192	Economy	11000.00
0005433681001	29192	Economy	11000.00
0005432967420	29192	Economy	11000.00
0005433690945	29192	Economy	11000.00
0005432967444	29192	Economy	11000.00
0005432967433	29192	Economy	11000.00
0005433690952	29192	Economy	11000.00
0005433681368	29192	Economy	11000.00
0005432967430	29192	Economy	11000.00
0005432967423	29192	Economy	11000.00
0005433680952	29192	Economy	11000.00
0005433681079	29192	Economy	11000.00
0005432967429	29192	Economy	11000.00
0005432967442	29192	Economy	11000.00
0005432967432	29192	Economy	11000.00
0005432967425	29192	Economy	11000.00
0005433681061	29192	Economy	11000.00
0005433681250	29192	Economy	11000.00
0005433681149	29192	Economy	11000.00
0005433681292	29192	Economy	11000.00
0005433616013	9327	Business	132900.00
0005434152804	9327	Business	132900.00
0005433616009	9327	Business	132900.00
0005434152810	9327	Business	132900.00
0005433578076	9327	Business	132900.00
0005433634462	9327	Business	132900.00
0005433616045	9327	Business	132900.00
0005433616027	9327	Business	132900.00
0005433616058	9327	Business	132900.00
0005433616072	9327	Business	132900.00
0005433616033	9327	Business	132900.00
0005432755138	9327	Business	132900.00
0005433616066	9327	Business	132900.00
0005433578075	9327	Business	132900.00
0005432145150	9327	Business	132900.00
0005433616077	9327	Business	132900.00
0005433616012	9327	Business	132900.00
0005434163720	9327	Business	132900.00
0005433616026	9327	Business	132900.00
0005433616030	9327	Business	132900.00
0005433634436	9327	Business	132900.00
0005433616024	9327	Business	132900.00
0005433578073	9327	Business	132900.00
0005433616070	9327	Business	132900.00
0005433616014	9327	Business	132900.00
0005433616035	9327	Economy	48700.00
0005433616079	9327	Economy	48700.00
0005433616031	9327	Economy	48700.00
0005433616076	9327	Economy	48700.00
0005433634449	9327	Economy	44300.00
0005433578066	9327	Economy	44300.00
0005433634439	9327	Economy	44300.00
0005433634459	9327	Economy	44300.00
0005434152805	9327	Economy	44300.00
0005433616015	9327	Economy	44300.00
0005433616019	9327	Economy	44300.00
0005433616039	9327	Economy	44300.00
0005434152809	9327	Economy	44300.00
0005434152808	9327	Economy	44300.00
0005433634453	9327	Economy	44300.00
0005434163724	9327	Economy	44300.00
0005433578071	9327	Economy	44300.00
0005434152807	9327	Economy	44300.00
0005433616041	9327	Economy	44300.00
0005433616074	9327	Economy	44300.00
0005433634466	9327	Economy	44300.00
0005433616075	9327	Economy	44300.00
0005433616080	9327	Economy	44300.00
0005433616048	9327	Economy	44300.00
0005432145149	9327	Economy	44300.00
0005433616049	9327	Economy	44300.00
0005433634458	9327	Economy	44300.00
0005433616011	9327	Economy	44300.00
0005433616055	9327	Economy	44300.00
0005433634450	9327	Economy	44300.00
0005433616032	9327	Economy	44300.00
0005433634455	9327	Economy	44300.00
0005433634440	9327	Economy	44300.00
0005433616063	9327	Economy	44300.00
0005433634461	9327	Economy	44300.00
0005433616016	9327	Economy	44300.00
0005433616042	9327	Economy	44300.00
0005433616068	9327	Economy	44300.00
0005433634463	9327	Economy	44300.00
0005433616010	9327	Economy	44300.00
0005433616008	9327	Economy	44300.00
0005433616061	9327	Economy	44300.00
0005433616044	9327	Economy	44300.00
0005433616043	9327	Economy	44300.00
0005433616023	9327	Economy	44300.00
0005433616052	9327	Economy	44300.00
0005433616034	9327	Economy	44300.00
0005433616028	9327	Economy	44300.00
0005433616060	9327	Economy	44300.00
0005433616037	9327	Economy	44300.00
0005433616069	9327	Economy	44300.00
0005432756912	9327	Economy	44300.00
0005433634438	9327	Economy	44300.00
0005432756913	9327	Economy	44300.00
0005432755140	9327	Economy	44300.00
0005433616040	9327	Economy	44300.00
0005433634465	9327	Economy	44300.00
0005434163702	9327	Economy	48700.00
0005433578074	9327	Economy	48700.00
0005433616038	9327	Economy	48700.00
0005433578070	9327	Economy	48700.00
0005433634448	9327	Economy	44300.00
0005433616021	9327	Economy	44300.00
0005433578067	9327	Economy	44300.00
0005433616017	9327	Economy	48700.00
0005433578072	9327	Economy	44300.00
0005434163682	9327	Economy	44300.00
0005433634469	9327	Economy	44300.00
0005433634447	9327	Economy	44300.00
0005433634457	9327	Economy	44300.00
0005433616029	9327	Economy	44300.00
0005433634468	9327	Economy	44300.00
0005433616022	9327	Economy	44300.00
0005432755141	9327	Economy	44300.00
0005433616071	9327	Economy	44300.00
0005432756911	9327	Economy	44300.00
0005433634456	9327	Economy	44300.00
0005433634437	9327	Economy	44300.00
0005433616007	9327	Economy	44300.00
0005433616057	9327	Economy	44300.00
0005433616006	9327	Economy	44300.00
0005433634441	9327	Economy	44300.00
0005434163701	9327	Economy	44300.00
0005433616020	9327	Economy	44300.00
0005433616056	9327	Economy	44300.00
0005433634443	9327	Economy	44300.00
0005433634451	9327	Economy	44300.00
0005433616053	9327	Economy	44300.00
0005433616064	9327	Economy	44300.00
0005433616047	9327	Economy	44300.00
0005433578068	9327	Economy	44300.00
0005433616067	9327	Economy	44300.00
0005433616059	9327	Economy	44300.00
0005433578064	9327	Economy	44300.00
0005433634467	9327	Economy	44300.00
0005433634464	9327	Economy	44300.00
0005433634454	9327	Economy	44300.00
0005433616018	9327	Economy	44300.00
0005433634446	9327	Economy	44300.00
0005433634460	9327	Economy	44300.00
0005433616036	9327	Economy	44300.00
0005433578069	9327	Economy	44300.00
0005433616025	9327	Economy	44300.00
0005434163715	9327	Economy	44300.00
0005433616046	9327	Economy	44300.00
0005433616051	9327	Economy	44300.00
0005433578063	9327	Economy	44300.00
0005433616054	9327	Economy	44300.00
0005432755139	9327	Economy	44300.00
0005433634444	9327	Economy	44300.00
0005433616078	9327	Economy	44300.00
0005433634442	9327	Economy	44300.00
0005433634452	9327	Economy	44300.00
0005433616073	9327	Economy	44300.00
0005433578065	9327	Economy	44300.00
0005433616065	9327	Economy	44300.00
0005433616062	9327	Economy	44300.00
0005433634445	9327	Economy	44300.00
0005433616050	9327	Economy	44300.00
0005433615309	25216	Business	132900.00
0005433615609	25216	Business	132900.00
0005433634222	25216	Business	132900.00
0005433615364	25216	Business	132900.00
0005434272220	25216	Business	132900.00
0005433634090	25216	Business	132900.00
0005433577967	25216	Business	132900.00
0005433615308	25216	Business	132900.00
0005433615548	25216	Business	132900.00
0005433634184	25216	Business	132900.00
0005433615355	25216	Business	132900.00
0005433615213	25216	Business	132900.00
0005433615425	25216	Business	132900.00
0005433615523	25216	Business	132900.00
0005433615352	25216	Business	132900.00
0005433634121	25216	Business	132900.00
0005433615421	25216	Business	132900.00
0005434163787	25216	Business	132900.00
0005433615595	25216	Business	132900.00
0005433577982	25216	Business	132900.00
0005433615624	25216	Business	132900.00
0005433615562	25216	Business	132900.00
0005435854068	25216	Business	132900.00
0005433615115	25216	Economy	48700.00
0005433615336	25216	Economy	48700.00
0005433615415	25216	Economy	48700.00
0005434163792	25216	Economy	48700.00
0005433615591	25216	Economy	48700.00
0005433615386	25216	Economy	44300.00
0005433634114	25216	Economy	44300.00
0005435854066	25216	Economy	44300.00
0005433615310	25216	Economy	44300.00
0005433615499	25216	Economy	44300.00
0005433615462	25216	Economy	44300.00
0005433615255	25216	Economy	44300.00
0005433614954	25216	Economy	44300.00
0005433615512	25216	Economy	44300.00
0005433615281	25216	Economy	44300.00
0005433634099	25216	Economy	44300.00
0005433634198	25216	Economy	44300.00
0005434163791	25216	Economy	44300.00
0005433615547	25216	Economy	44300.00
0005433615382	25216	Economy	44300.00
0005434163795	25216	Economy	44300.00
0005433615183	25216	Economy	44300.00
0005433615371	25216	Economy	44300.00
0005433634016	25216	Economy	44300.00
0005433578011	25216	Economy	44300.00
0005433615612	25216	Economy	44300.00
0005433577978	25216	Economy	44300.00
0005433615408	25216	Economy	44300.00
0005433634106	25216	Economy	44300.00
0005433615655	25216	Economy	44300.00
0005433615481	25216	Economy	44300.00
0005433615504	25216	Economy	44300.00
0005433577937	25216	Economy	44300.00
0005433633977	25216	Economy	44300.00
0005434272218	25216	Economy	44300.00
0005433615280	25216	Economy	44300.00
0005433615498	25216	Economy	44300.00
0005433615637	25216	Economy	44300.00
0005433634256	25216	Economy	44300.00
0005433634126	25216	Economy	44300.00
0005433615250	25216	Economy	44300.00
0005434163793	25216	Economy	44300.00
0005433634204	25216	Economy	44300.00
0005433634203	25216	Economy	44300.00
0005433615295	25216	Economy	44300.00
0005433615507	25216	Economy	44300.00
0005433615266	25216	Economy	44300.00
0005433634089	25216	Economy	44300.00
0005433615604	25216	Economy	44300.00
0005433615254	25216	Economy	48700.00
0005433615249	25216	Economy	48700.00
0005433615461	25216	Economy	44300.00
0005434273106	25216	Economy	44300.00
0005433615527	25216	Economy	44300.00
0005433615602	25216	Economy	44300.00
0005433615431	25216	Economy	44300.00
0005434163794	25216	Economy	48700.00
0005434163789	25216	Economy	44300.00
0005434163790	25216	Economy	44300.00
0005433615377	25216	Economy	44300.00
0005433615484	25216	Economy	44300.00
0005433634255	25216	Economy	44300.00
0005433615524	25216	Economy	44300.00
0005433634163	25216	Economy	44300.00
0005433634017	25216	Economy	44300.00
0005433634119	25216	Economy	44300.00
0005435854067	25216	Economy	44300.00
0005433615477	25216	Economy	44300.00
0005433615333	25216	Economy	44300.00
0005434163788	25216	Economy	44300.00
0005434273107	25216	Economy	44300.00
0005433615471	25216	Economy	44300.00
0005433634025	25216	Economy	44300.00
0005435854069	25216	Economy	44300.00
0005433577933	25216	Economy	44300.00
0005433577968	25216	Economy	44300.00
0005433615596	25216	Economy	44300.00
0005433615522	25216	Economy	44300.00
0005433634210	25216	Economy	44300.00
0005433615608	25216	Economy	44300.00
0005434163797	25216	Economy	44300.00
0005433615528	25216	Economy	44300.00
0005433615506	25216	Economy	44300.00
0005433634148	25216	Economy	44300.00
0005433634217	25216	Economy	44300.00
0005433615485	25216	Economy	44300.00
0005433615455	25216	Economy	44300.00
0005433615241	25216	Economy	44300.00
0005433614960	25216	Economy	44300.00
0005433634124	25216	Economy	44300.00
0005433615296	25216	Economy	44300.00
0005433615605	25216	Economy	44300.00
0005433615414	25216	Economy	44300.00
0005434163796	25216	Economy	44300.00
0005433634086	25216	Economy	44300.00
0005433615561	25216	Economy	44300.00
0005433634153	25216	Economy	44300.00
0005433615580	25216	Economy	44300.00
0005433615634	25216	Economy	44300.00
0005433615479	25216	Economy	44300.00
0005433615633	25216	Economy	44300.00
0005433634123	25216	Economy	44300.00
0005435854070	25216	Economy	44300.00
0005433634125	25216	Economy	44300.00
0005433615519	25216	Economy	44300.00
0005433615520	25216	Economy	44300.00
0005434272219	25216	Economy	44300.00
0005433634188	25216	Economy	44300.00
0005435986893	4251	Business	193100.00
0005435947426	4251	Business	193100.00
0005435854065	4251	Business	193100.00
0005435854064	4251	Business	193100.00
0005435986894	4251	Business	193100.00
0005435947403	4251	Business	193100.00
0005435986903	4251	Business	193100.00
0005435986899	4251	Economy	64400.00
0005435986901	4251	Economy	64400.00
0005435986896	4251	Economy	64400.00
0005434271342	4251	Economy	64400.00
0005435986898	4251	Economy	64400.00
0005435856250	4251	Economy	64400.00
0005435947402	4251	Economy	64400.00
0005435947409	4251	Economy	64400.00
0005435986904	4251	Economy	64400.00
0005432185007	4251	Economy	64400.00
0005435986895	4251	Economy	64400.00
0005435986892	4251	Economy	64400.00
0005432185008	4251	Economy	64400.00
0005432185006	4251	Economy	64400.00
0005435947387	4251	Economy	64400.00
0005435947425	4251	Economy	64400.00
0005434271336	4251	Economy	64400.00
0005435986900	4251	Economy	64400.00
0005435947430	4251	Economy	64400.00
0005435947419	4251	Economy	64400.00
0005435947411	4251	Economy	64400.00
0005435947431	4251	Economy	64400.00
0005435986897	4251	Economy	64400.00
0005435947424	4251	Economy	64400.00
0005435986902	4251	Economy	64400.00
0005435947448	4251	Economy	64400.00
0005435986818	26574	Business	193100.00
0005435947540	26574	Business	193100.00
0005435986798	26574	Business	193100.00
0005432571398	26574	Business	193100.00
0005435947544	26574	Business	193100.00
0005435856286	26574	Economy	70800.00
0005435986830	26574	Economy	64400.00
0005435787397	26574	Economy	64400.00
0005432571397	26574	Economy	64400.00
0005435947535	26574	Economy	64400.00
0005435947536	26574	Economy	64400.00
0005435986800	26574	Economy	64400.00
0005435947547	26574	Economy	64400.00
0005435856285	26574	Economy	64400.00
0005435947548	26574	Economy	64400.00
0005435986814	26574	Economy	64400.00
0005435986805	26574	Economy	64400.00
0005435947546	26574	Economy	64400.00
0005435947534	26574	Economy	64400.00
0005432571399	26574	Economy	64400.00
0005435947545	26574	Economy	70800.00
0005435947537	26574	Economy	64400.00
0005435947543	26574	Economy	64400.00
0005435986817	26574	Economy	64400.00
0005435856287	26574	Economy	64400.00
0005435986815	26574	Economy	64400.00
0005435947539	26574	Economy	64400.00
0005435986829	26574	Economy	64400.00
0005435947538	26574	Economy	64400.00
0005435947542	26574	Economy	64400.00
0005435947541	26574	Economy	64400.00
0005435986823	26574	Economy	64400.00
0005435787396	26574	Economy	64400.00
0005435986824	26574	Economy	64400.00
0005435856288	26574	Economy	64400.00
0005433570246	310	Business	21500.00
0005433570289	310	Business	21500.00
0005432948815	310	Business	21500.00
0005432949067	310	Business	21500.00
0005433570251	310	Business	21500.00
0005432948947	310	Business	21500.00
0005433570268	310	Business	21500.00
0005433074995	310	Business	21500.00
0005433570217	310	Business	21500.00
0005434087924	310	Business	21500.00
0005432948723	310	Business	21500.00
0005433129336	310	Business	21500.00
0005432948794	310	Business	21500.00
0005432948948	310	Business	21500.00
0005433075036	310	Business	21500.00
0005433570254	310	Business	21500.00
0005433570265	310	Business	21500.00
0005433570220	310	Business	21500.00
0005433570242	310	Business	21500.00
0005433074944	310	Business	21500.00
0005433570255	310	Business	21500.00
0005433570259	310	Business	21500.00
0005433129322	310	Business	21500.00
0005432948936	310	Business	21500.00
0005433134191	310	Business	21500.00
0005432948754	310	Business	21500.00
0005433075002	310	Economy	7900.00
0005433074965	310	Economy	7900.00
0005433570284	310	Economy	7900.00
0005433570276	310	Economy	7900.00
0005433570226	310	Economy	7900.00
0005433075022	310	Economy	7200.00
0005433074916	310	Economy	7200.00
0005433075083	310	Economy	7200.00
0005432948934	310	Economy	7200.00
0005433134200	310	Economy	7200.00
0005433570271	310	Economy	7200.00
0005433075074	310	Economy	7200.00
0005434087922	310	Economy	7200.00
0005433134204	310	Economy	7200.00
0005433570269	310	Economy	7200.00
0005432948865	310	Economy	7200.00
0005432948856	310	Economy	7200.00
0005433570229	310	Economy	7200.00
0005433570274	310	Economy	7200.00
0005432949068	310	Economy	7200.00
0005433570222	310	Economy	7200.00
0005433075039	310	Economy	7200.00
0005432948935	310	Economy	7200.00
0005434087923	310	Economy	7200.00
0005433570241	310	Economy	7200.00
0005433075082	310	Economy	7200.00
0005433570277	310	Economy	7200.00
0005433075011	310	Economy	7200.00
0005433570279	310	Economy	7200.00
0005433570261	310	Economy	7200.00
0005433570216	310	Economy	7200.00
0005433570263	310	Economy	7200.00
0005432948944	310	Economy	7200.00
0005433570260	310	Economy	7200.00
0005432239055	310	Economy	7200.00
0005432948645	310	Economy	7200.00
0005433075038	310	Economy	7200.00
0005433570247	310	Economy	7200.00
0005432948894	310	Economy	7200.00
0005433570266	310	Economy	7200.00
0005433570237	310	Economy	7200.00
0005432948738	310	Economy	7200.00
0005433570278	310	Economy	7200.00
0005433570230	310	Economy	7200.00
0005433570239	310	Economy	7200.00
0005432949097	310	Economy	7200.00
0005432948857	310	Economy	7200.00
0005433074996	310	Economy	7200.00
0005433570244	310	Economy	7200.00
0005433129341	310	Economy	7200.00
0005433134203	310	Economy	7200.00
0005433570253	310	Economy	7200.00
0005433075081	310	Economy	7200.00
0005433074945	310	Economy	7200.00
0005432948864	310	Economy	7200.00
0005432949065	310	Economy	7200.00
0005433075123	310	Economy	7200.00
0005433570223	310	Economy	7900.00
0005434087925	310	Economy	7900.00
0005433570219	310	Economy	7900.00
0005432948870	310	Economy	7900.00
0005432948795	310	Economy	7900.00
0005433075018	310	Economy	7200.00
0005433570273	310	Economy	7200.00
0005433570252	310	Economy	7200.00
0005433570290	310	Economy	7200.00
0005432239056	310	Economy	7200.00
0005433570286	310	Economy	7900.00
0005432948871	310	Economy	7200.00
0005432949019	310	Economy	7200.00
0005432948658	310	Economy	7200.00
0005433074926	310	Economy	7200.00
0005432239059	310	Economy	7200.00
0005433570287	310	Economy	7200.00
0005433570235	310	Economy	7200.00
0005433570234	310	Economy	7200.00
0005432948990	310	Economy	7200.00
0005433075097	310	Economy	7200.00
0005432948842	310	Economy	7200.00
0005433570272	310	Economy	7200.00
0005432948945	310	Economy	7200.00
0005433074946	310	Economy	7200.00
0005433570232	310	Economy	7200.00
0005433570231	310	Economy	7200.00
0005433570281	310	Economy	7200.00
0005433570270	310	Economy	7200.00
0005432948806	310	Economy	7200.00
0005433570236	310	Economy	7200.00
0005433570258	310	Economy	7200.00
0005433134201	310	Economy	7200.00
0005432949038	310	Economy	7200.00
0005432948867	310	Economy	7200.00
0005433074957	310	Economy	7200.00
0005433570249	310	Economy	7200.00
0005433570218	310	Economy	7200.00
0005432949066	310	Economy	7200.00
0005433570250	310	Economy	7200.00
0005433570264	310	Economy	7200.00
0005433570262	310	Economy	7200.00
0005433570225	310	Economy	7200.00
0005433075037	310	Economy	7200.00
0005433570228	310	Economy	7200.00
0005433570248	310	Economy	7200.00
0005432948866	310	Economy	7200.00
0005433570282	310	Economy	7200.00
0005433570245	310	Economy	7200.00
0005433570238	310	Economy	7200.00
0005433570224	310	Economy	7200.00
0005433570283	310	Economy	7200.00
0005433570243	310	Economy	7200.00
0005433570267	310	Economy	7200.00
0005433570256	310	Economy	7200.00
0005432948686	310	Economy	7200.00
0005432948895	310	Economy	7200.00
0005433570280	310	Economy	7200.00
0005433570275	310	Economy	7200.00
0005433570288	310	Economy	7200.00
0005433570240	310	Economy	7200.00
0005433570227	310	Economy	7200.00
0005432239058	310	Economy	7200.00
0005432239057	310	Economy	7200.00
0005433570233	310	Economy	7200.00
0005433570285	310	Economy	7200.00
0005433129335	310	Economy	7200.00
0005433570257	310	Economy	7200.00
0005433570221	310	Economy	7200.00
0005432949239	11567	Business	21500.00
0005432949242	11567	Business	21500.00
0005433569729	11567	Business	21500.00
0005433569359	11567	Business	21500.00
0005433569650	11567	Business	21500.00
0005433569695	11567	Business	21500.00
0005433075246	11567	Business	21500.00
0005433075273	11567	Business	21500.00
0005432949258	11567	Business	21500.00
0005433569696	11567	Business	21500.00
0005433569640	11567	Business	21500.00
0005433569606	11567	Business	21500.00
0005433075247	11567	Business	21500.00
0005432949254	11567	Business	21500.00
0005433075274	11567	Business	21500.00
0005433569431	11567	Business	21500.00
0005433569539	11567	Business	21500.00
0005432949241	11567	Business	21500.00
0005433075265	11567	Business	21500.00
0005433569558	11567	Business	21500.00
0005432949259	11567	Business	21500.00
0005432949237	11567	Business	21500.00
0005432949251	11567	Business	21500.00
0005433569366	11567	Business	21500.00
0005433075263	11567	Economy	7900.00
0005433569617	11567	Economy	7900.00
0005433569583	11567	Economy	7900.00
0005433569469	11567	Economy	7900.00
0005433569607	11567	Economy	7900.00
0005432949234	11567	Economy	7900.00
0005433569524	11567	Economy	7200.00
0005433075253	11567	Economy	7200.00
0005433569553	11567	Economy	7200.00
0005433075269	11567	Economy	7200.00
0005433134228	11567	Economy	7200.00
0005432949226	11567	Economy	7200.00
0005433569555	11567	Economy	7200.00
0005433075266	11567	Economy	7200.00
0005433569571	11567	Economy	7200.00
0005433569614	11567	Economy	7200.00
0005433075258	11567	Economy	7200.00
0005432949225	11567	Economy	7200.00
0005433569652	11567	Economy	7200.00
0005433569572	11567	Economy	7200.00
0005433569485	11567	Economy	7200.00
0005433075270	11567	Economy	7200.00
0005433569674	11567	Economy	7200.00
0005433075264	11567	Economy	7200.00
0005432949249	11567	Economy	7200.00
0005433075267	11567	Economy	7200.00
0005432949244	11567	Economy	7200.00
0005433569648	11567	Economy	7200.00
0005432949230	11567	Economy	7200.00
0005433569646	11567	Economy	7200.00
0005432949240	11567	Economy	7200.00
0005433131795	11567	Economy	7200.00
0005433131796	11567	Economy	7200.00
0005432949255	11567	Economy	7200.00
0005433569639	11567	Economy	7200.00
0005433075257	11567	Economy	7200.00
0005433569597	11567	Economy	7200.00
0005433569634	11567	Economy	7200.00
0005433569568	11567	Economy	7200.00
0005432949265	11567	Economy	7200.00
0005432192383	11567	Economy	7200.00
0005433569719	11567	Economy	7200.00
0005433569569	11567	Economy	7200.00
0005433569365	11567	Economy	7200.00
0005432949238	11567	Economy	7200.00
0005433569589	11567	Economy	7200.00
0005433075272	11567	Economy	7200.00
0005432949262	11567	Economy	7200.00
0005433075261	11567	Economy	7200.00
0005433569534	11567	Economy	7200.00
0005433569186	11567	Economy	7200.00
0005433569629	11567	Economy	7200.00
0005432949227	11567	Economy	7200.00
0005432949257	11567	Economy	7200.00
0005432949246	11567	Economy	7200.00
0005433131798	11567	Economy	7200.00
0005433569536	11567	Economy	7200.00
0005433569567	11567	Economy	7200.00
0005433134226	11567	Economy	7200.00
0005432949260	11567	Economy	7200.00
0005433569716	11567	Economy	7200.00
0005433569525	11567	Economy	7900.00
0005433569697	11567	Economy	7900.00
0005432949247	11567	Economy	7900.00
0005433075250	11567	Economy	7200.00
0005433569540	11567	Economy	7900.00
0005433569529	11567	Economy	7200.00
0005433075259	11567	Economy	7200.00
0005433569470	11567	Economy	7200.00
0005433569633	11567	Economy	7900.00
0005433075256	11567	Economy	7200.00
0005433569721	11567	Economy	7200.00
0005433131799	11567	Economy	7200.00
0005433075248	11567	Economy	7200.00
0005432949229	11567	Economy	7200.00
0005433075251	11567	Economy	7200.00
0005433569649	11567	Economy	7200.00
0005432949233	11567	Economy	7200.00
0005433569612	11567	Economy	7200.00
0005432949263	11567	Economy	7200.00
0005433075268	11567	Economy	7200.00
0005433075252	11567	Economy	7200.00
0005433569624	11567	Economy	7200.00
0005432949224	11567	Economy	7200.00
0005432949231	11567	Economy	7200.00
0005433134229	11567	Economy	7200.00
0005433569608	11567	Economy	7200.00
0005433569621	11567	Economy	7200.00
0005432949253	11567	Economy	7200.00
0005432949243	11567	Economy	7200.00
0005433134227	11567	Economy	7200.00
0005432949250	11567	Economy	7200.00
0005433569103	11567	Economy	7200.00
0005432192381	11567	Economy	7200.00
0005433569582	11567	Economy	7200.00
0005433569651	11567	Economy	7200.00
0005433075254	11567	Economy	7200.00
0005432949252	11567	Economy	7200.00
0005432949235	11567	Economy	7200.00
0005433569702	11567	Economy	7200.00
0005433569471	11567	Economy	7200.00
0005433134225	11567	Economy	7200.00
0005433075249	11567	Economy	7200.00
0005433075260	11567	Economy	7200.00
0005432192380	11567	Economy	7200.00
0005433569102	11567	Economy	7200.00
0005433569562	11567	Economy	7200.00
0005432949228	11567	Economy	7200.00
0005433131797	11567	Economy	7200.00
0005433569615	11567	Economy	7200.00
0005433075271	11567	Economy	7200.00
0005433569598	11567	Economy	7200.00
0005433075275	11567	Economy	7200.00
0005432949245	11567	Economy	7200.00
0005433569538	11567	Economy	7200.00
0005433569647	11567	Economy	7200.00
0005433569570	11567	Economy	7200.00
0005432949236	11567	Economy	7200.00
0005432949264	11567	Economy	7200.00
0005432949256	11567	Economy	7200.00
0005432949232	11567	Economy	7200.00
0005432949248	11567	Economy	7200.00
0005432949261	11567	Economy	7200.00
0005432192382	11567	Economy	7200.00
0005433075262	11567	Economy	7200.00
0005433075255	11567	Economy	7200.00
0005434733025	10050	Economy	6300.00
0005434733027	10050	Economy	6300.00
0005433817546	10050	Economy	6300.00
0005433817544	10050	Economy	6300.00
0005433817543	10050	Economy	6300.00
0005433817545	10050	Economy	6300.00
0005434733050	13930	Economy	6300.00
0005433817517	13930	Economy	6300.00
0005434733051	13930	Economy	6300.00
0005433817515	13930	Economy	6300.00
0005433817506	13930	Economy	6300.00
0005435983155	2366	Business	184500.00
0005432655777	2366	Business	184500.00
0005432655766	2366	Business	184500.00
0005432226183	2366	Business	184500.00
0005433434852	2366	Business	184500.00
0005433434900	2366	Business	184500.00
0005434731200	2366	Business	184500.00
0005435983172	2366	Business	184500.00
0005433755302	2366	Business	184500.00
0005435983168	2366	Business	184500.00
0005433755338	2366	Business	184500.00
0005433435020	2366	Business	184500.00
0005435983156	2366	Business	184500.00
0005433755334	2366	Business	184500.00
0005432985439	2366	Business	184500.00
0005432226181	2366	Business	184500.00
0005435983175	2366	Business	184500.00
0005435983181	2366	Business	184500.00
0005433755345	2366	Business	184500.00
0005433755319	2366	Business	184500.00
0005432300378	2366	Business	184500.00
0005435983190	2366	Business	184500.00
0005434731202	2366	Business	184500.00
0005433766715	2366	Business	184500.00
0005433435025	2366	Business	184500.00
0005435983163	2366	Business	184500.00
0005435983174	2366	Business	184500.00
0005433755294	2366	Economy	67700.00
0005433435043	2366	Economy	67700.00
0005432655768	2366	Economy	67700.00
0005432985430	2366	Economy	67700.00
0005433755352	2366	Economy	61500.00
0005433755306	2366	Economy	61500.00
0005432985372	2366	Economy	61500.00
0005435983153	2366	Economy	61500.00
0005433755348	2366	Economy	61500.00
0005432655767	2366	Economy	61500.00
0005432869556	2366	Economy	61500.00
0005432985438	2366	Economy	61500.00
0005434731228	2366	Economy	61500.00
0005433755316	2366	Economy	61500.00
0005433755346	2366	Economy	61500.00
0005433435026	2366	Economy	61500.00
0005433755347	2366	Economy	61500.00
0005433755330	2366	Economy	61500.00
0005435983187	2366	Economy	61500.00
0005435983165	2366	Economy	61500.00
0005433755295	2366	Economy	61500.00
0005433755311	2366	Economy	61500.00
0005432869606	2366	Economy	61500.00
0005435983151	2366	Economy	61500.00
0005435983177	2366	Economy	61500.00
0005435983192	2366	Economy	61500.00
0005433434999	2366	Economy	61500.00
0005435983161	2366	Economy	61500.00
0005435983185	2366	Economy	61500.00
0005432869586	2366	Economy	61500.00
0005433764720	2366	Economy	61500.00
0005434731201	2366	Economy	61500.00
0005432985285	2366	Economy	61500.00
0005432985466	2366	Economy	61500.00
0005432655773	2366	Economy	61500.00
0005433435019	2366	Economy	61500.00
0005435983157	2366	Economy	61500.00
0005432985467	2366	Economy	61500.00
0005433434929	2366	Economy	61500.00
0005432985336	2366	Economy	61500.00
0005435983183	2366	Economy	61500.00
0005432985563	2366	Economy	61500.00
0005435983184	2366	Economy	61500.00
0005435983178	2366	Economy	61500.00
0005432985450	2366	Economy	61500.00
0005432985349	2366	Economy	61500.00
0005435983154	2366	Economy	61500.00
0005433755325	2366	Economy	61500.00
0005433435076	2366	Economy	61500.00
0005435983169	2366	Economy	61500.00
0005435983166	2366	Economy	61500.00
0005432226182	2366	Economy	61500.00
0005433755323	2366	Economy	61500.00
0005433755331	2366	Economy	61500.00
0005433755326	2366	Economy	61500.00
0005432226178	2366	Economy	61500.00
0005433755317	2366	Economy	61500.00
0005435983162	2366	Economy	61500.00
0005433755342	2366	Economy	61500.00
0005435983152	2366	Economy	61500.00
0005432985480	2366	Economy	61500.00
0005433434969	2366	Economy	61500.00
0005432300376	2366	Economy	61500.00
0005434731221	2366	Economy	61500.00
0005432300377	2366	Economy	61500.00
0005433755322	2366	Economy	61500.00
0005433434957	2366	Economy	61500.00
0005433755351	2366	Economy	61500.00
0005433755310	2366	Economy	61500.00
0005433766713	2366	Economy	61500.00
0005432985436	2366	Economy	61500.00
0005433435077	2366	Economy	61500.00
0005433755309	2366	Economy	61500.00
0005435983167	2366	Economy	61500.00
0005432985412	2366	Economy	61500.00
0005433755318	2366	Economy	61500.00
0005433755340	2366	Economy	61500.00
0005433434956	2366	Economy	61500.00
0005435983179	2366	Economy	61500.00
0005433434873	2366	Economy	61500.00
0005433435000	2366	Economy	61500.00
0005432985375	2366	Economy	61500.00
0005433434933	2366	Economy	61500.00
0005435983171	2366	Economy	61500.00
0005433755299	2366	Economy	61500.00
0005432655776	2366	Economy	61500.00
0005433755320	2366	Economy	61500.00
0005432869590	2366	Economy	61500.00
0005432300380	2366	Economy	61500.00
0005433755308	2366	Economy	61500.00
0005432655775	2366	Economy	61500.00
0005432869588	2366	Economy	61500.00
0005432985517	2366	Economy	61500.00
0005432869605	2366	Economy	61500.00
0005435983160	2366	Economy	61500.00
0005432869582	2366	Economy	61500.00
0005433435051	2366	Economy	61500.00
0005435983191	2366	Economy	61500.00
0005432985413	2366	Economy	61500.00
0005433755341	2366	Economy	61500.00
0005435983170	2366	Economy	67700.00
0005432985406	2366	Economy	67700.00
0005433755337	2366	Economy	61500.00
0005433755344	2366	Economy	61500.00
0005435983188	2366	Economy	61500.00
0005433434930	2366	Economy	67700.00
0005433755327	2366	Economy	67700.00
0005432985374	2366	Economy	61500.00
0005433755335	2366	Economy	61500.00
0005435983158	2366	Economy	61500.00
0005433755296	2366	Economy	61500.00
0005433434915	2366	Economy	61500.00
0005435983182	2366	Economy	61500.00
0005433434946	2366	Economy	61500.00
0005433434874	2366	Economy	61500.00
0005433755298	2366	Economy	61500.00
0005432655778	2366	Economy	61500.00
0005432226177	2366	Economy	61500.00
0005432655770	2366	Economy	61500.00
0005433766716	2366	Economy	61500.00
0005433434932	2366	Economy	61500.00
0005433755350	2366	Economy	61500.00
0005435983189	2366	Economy	61500.00
0005432869587	2366	Economy	61500.00
0005433755315	2366	Economy	61500.00
0005433766714	2366	Economy	61500.00
0005432985340	2366	Economy	61500.00
0005433434955	2366	Economy	61500.00
0005433755304	2366	Economy	61500.00
0005432300379	2366	Economy	61500.00
0005433755312	2366	Economy	61500.00
0005432655772	2366	Economy	61500.00
0005433755333	2366	Economy	61500.00
0005433755307	2366	Economy	61500.00
0005433435007	2366	Economy	61500.00
0005432655774	2366	Economy	61500.00
0005432655771	2366	Economy	61500.00
0005435983159	2366	Economy	61500.00
0005432869617	2366	Economy	61500.00
0005435983193	2366	Economy	61500.00
0005432985435	2366	Economy	61500.00
0005432869616	2366	Economy	61500.00
0005433755301	2366	Economy	61500.00
0005432300375	2366	Economy	61500.00
0005435983186	2366	Economy	61500.00
0005432985395	2366	Economy	61500.00
0005433434899	2366	Economy	61500.00
0005433755324	2366	Economy	61500.00
0005432300381	2366	Economy	61500.00
0005433755293	2366	Economy	61500.00
0005433755313	2366	Economy	61500.00
0005433755343	2366	Economy	61500.00
0005433755321	2366	Economy	61500.00
0005433755300	2366	Economy	61500.00
0005432226180	2366	Economy	61500.00
0005432869557	2366	Economy	61500.00
0005433755332	2366	Economy	61500.00
0005433755349	2366	Economy	61500.00
0005434731213	2366	Economy	61500.00
0005433435041	2366	Economy	61500.00
0005433755314	2366	Economy	61500.00
0005433435052	2366	Economy	61500.00
0005433435042	2366	Economy	61500.00
0005433434954	2366	Economy	61500.00
0005433435027	2366	Economy	61500.00
0005435983173	2366	Economy	61500.00
0005433755303	2366	Economy	61500.00
0005433764719	2366	Economy	61500.00
0005432869558	2366	Economy	61500.00
0005433434901	2366	Economy	61500.00
0005433755339	2366	Economy	61500.00
0005433434872	2366	Economy	61500.00
0005432655769	2366	Economy	61500.00
0005435983164	2366	Economy	61500.00
0005434731220	2366	Economy	61500.00
0005433755328	2366	Economy	61500.00
0005432226179	2366	Economy	61500.00
0005433434960	2366	Economy	61500.00
0005433755336	2366	Economy	61500.00
0005433434975	2366	Economy	61500.00
0005435983180	2366	Economy	61500.00
0005433435018	2366	Economy	61500.00
0005433755305	2366	Economy	61500.00
0005433755297	2366	Economy	61500.00
0005433755329	2366	Economy	61500.00
0005435983176	2366	Economy	61500.00
0005435982687	26187	Business	184500.00
0005433435242	26187	Business	184500.00
0005433755011	26187	Business	184500.00
0005433754741	26187	Business	184500.00
0005432985713	26187	Business	184500.00
0005435982786	26187	Business	184500.00
0005435982878	26187	Business	184500.00
0005435982835	26187	Business	184500.00
0005435982643	26187	Business	184500.00
0005432655653	26187	Business	184500.00
0005433754946	26187	Business	184500.00
0005433754845	26187	Business	184500.00
0005432049534	26187	Business	184500.00
0005433754847	26187	Business	184500.00
0005435982912	26187	Business	184500.00
0005435982760	26187	Business	184500.00
0005432985724	26187	Business	184500.00
0005435982877	26187	Business	184500.00
0005435982718	26187	Business	184500.00
0005433754671	26187	Business	184500.00
0005432655671	26187	Business	184500.00
0005433754729	26187	Business	184500.00
0005435982784	26187	Business	184500.00
0005435982815	26187	Business	184500.00
0005433754844	26187	Business	184500.00
0005432985698	26187	Economy	67700.00
0005433754962	26187	Economy	67700.00
0005433754809	26187	Economy	67700.00
0005433435235	26187	Economy	67700.00
0005432655700	26187	Economy	61500.00
0005435982725	26187	Economy	61500.00
0005433754869	26187	Economy	61500.00
0005433435244	26187	Economy	61500.00
0005433754798	26187	Economy	61500.00
0005432985726	26187	Economy	61500.00
0005432049532	26187	Economy	61500.00
0005432655633	26187	Economy	61500.00
0005433754819	26187	Economy	61500.00
0005435982685	26187	Economy	61500.00
0005432049535	26187	Economy	61500.00
0005433754597	26187	Economy	61500.00
0005433754913	26187	Economy	61500.00
0005435982792	26187	Economy	61500.00
0005433766693	26187	Economy	61500.00
0005432985710	26187	Economy	61500.00
0005435982594	26187	Economy	61500.00
0005432985712	26187	Economy	61500.00
0005433754960	26187	Economy	61500.00
0005432985703	26187	Economy	61500.00
0005433435232	26187	Economy	61500.00
0005433754723	26187	Economy	61500.00
0005435982750	26187	Economy	61500.00
0005432655634	26187	Economy	61500.00
0005432869654	26187	Economy	61500.00
0005435982836	26187	Economy	61500.00
0005433754623	26187	Economy	61500.00
0005433435219	26187	Economy	61500.00
0005433755006	26187	Economy	61500.00
0005434731254	26187	Economy	61500.00
0005433754972	26187	Economy	61500.00
0005433435226	26187	Economy	61500.00
0005433754605	26187	Economy	61500.00
0005432985725	26187	Economy	61500.00
0005432655644	26187	Economy	61500.00
0005432985704	26187	Economy	61500.00
0005433754824	26187	Economy	61500.00
0005433754831	26187	Economy	61500.00
0005432985695	26187	Economy	61500.00
0005432985722	26187	Economy	61500.00
0005432869651	26187	Economy	61500.00
0005433435223	26187	Economy	61500.00
0005433754825	26187	Economy	61500.00
0005432985696	26187	Economy	61500.00
0005433755012	26187	Economy	61500.00
0005433754961	26187	Economy	61500.00
0005433754920	26187	Economy	61500.00
0005433754860	26187	Economy	61500.00
0005432985714	26187	Economy	61500.00
0005433754982	26187	Economy	61500.00
0005433754836	26187	Economy	61500.00
0005433754868	26187	Economy	61500.00
0005435982676	26187	Economy	61500.00
0005432985699	26187	Economy	61500.00
0005433435241	26187	Economy	61500.00
0005433754820	26187	Economy	61500.00
0005432985715	26187	Economy	61500.00
0005433754670	26187	Economy	61500.00
0005433435229	26187	Economy	61500.00
0005432869652	26187	Economy	61500.00
0005433754848	26187	Economy	61500.00
0005433435231	26187	Economy	61500.00
0005432985697	26187	Economy	61500.00
0005432869649	26187	Economy	61500.00
0005432985708	26187	Economy	61500.00
0005432985701	26187	Economy	61500.00
0005433754612	26187	Economy	61500.00
0005433435239	26187	Economy	61500.00
0005433754807	26187	Economy	61500.00
0005433754633	26187	Economy	61500.00
0005433435237	26187	Economy	61500.00
0005433755046	26187	Economy	61500.00
0005432985718	26187	Economy	61500.00
0005433755080	26187	Economy	61500.00
0005433755045	26187	Economy	61500.00
0005432051190	26187	Economy	61500.00
0005433754774	26187	Economy	61500.00
0005433754906	26187	Economy	61500.00
0005435982939	26187	Economy	61500.00
0005432655661	26187	Economy	61500.00
0005433754936	26187	Economy	61500.00
0005432985702	26187	Economy	61500.00
0005432049533	26187	Economy	61500.00
0005432985700	26187	Economy	61500.00
0005433754846	26187	Economy	61500.00
0005432985705	26187	Economy	61500.00
0005435982766	26187	Economy	61500.00
0005433754634	26187	Economy	61500.00
0005433754653	26187	Economy	61500.00
0005433754667	26187	Economy	61500.00
0005433435224	26187	Economy	61500.00
0005432985717	26187	Economy	67700.00
0005433435233	26187	Economy	67700.00
0005433435221	26187	Economy	61500.00
0005432985711	26187	Economy	67700.00
0005433766692	26187	Economy	61500.00
0005432655662	26187	Economy	61500.00
0005432985721	26187	Economy	61500.00
0005433435225	26187	Economy	61500.00
0005435982765	26187	Economy	61500.00
0005432869650	26187	Economy	61500.00
0005432985716	26187	Economy	61500.00
0005433754948	26187	Economy	61500.00
0005435982686	26187	Economy	61500.00
0005435982802	26187	Economy	61500.00
0005432985723	26187	Economy	61500.00
0005433754891	26187	Economy	61500.00
0005435982583	26187	Economy	61500.00
0005432985720	26187	Economy	61500.00
0005433435240	26187	Economy	61500.00
0005432655626	26187	Economy	61500.00
0005433435220	26187	Economy	61500.00
0005432051192	26187	Economy	61500.00
0005433754808	26187	Economy	61500.00
0005432869653	26187	Economy	61500.00
0005433435238	26187	Economy	61500.00
0005432985706	26187	Economy	61500.00
0005433754750	26187	Economy	61500.00
0005432985709	26187	Economy	61500.00
0005433754947	26187	Economy	61500.00
0005435982828	26187	Economy	61500.00
0005432051189	26187	Economy	61500.00
0005433754707	26187	Economy	61500.00
0005433764694	26187	Economy	61500.00
0005435982719	26187	Economy	61500.00
0005433754773	26187	Economy	61500.00
0005433435234	26187	Economy	61500.00
0005435982782	26187	Economy	61500.00
0005433435222	26187	Economy	61500.00
0005432985707	26187	Economy	61500.00
0005433435217	26187	Economy	61500.00
0005433435218	26187	Economy	61500.00
0005433764707	26187	Economy	61500.00
0005433754953	26187	Economy	61500.00
0005435982597	26187	Economy	61500.00
0005433435227	26187	Economy	61500.00
0005435982940	26187	Economy	61500.00
0005433754945	26187	Economy	61500.00
0005432051191	26187	Economy	61500.00
0005432869648	26187	Economy	61500.00
0005432985719	26187	Economy	61500.00
0005435982848	26187	Economy	61500.00
0005433754666	26187	Economy	61500.00
0005433754767	26187	Economy	61500.00
0005432655624	26187	Economy	61500.00
0005435982825	26187	Economy	61500.00
0005432655672	26187	Economy	61500.00
0005433754749	26187	Economy	61500.00
0005433754918	26187	Economy	61500.00
0005433435228	26187	Economy	61500.00
0005435982751	26187	Economy	61500.00
0005435982826	26187	Economy	61500.00
0005434731255	26187	Economy	61500.00
0005433754973	26187	Economy	61500.00
0005433754935	26187	Economy	61500.00
0005433754892	26187	Economy	61500.00
0005433435230	26187	Economy	61500.00
0005433435243	26187	Economy	61500.00
0005433435236	26187	Economy	61500.00
0005434731253	26187	Economy	61500.00
0005432655635	26187	Economy	61500.00
0005435982720	26187	Economy	61500.00
0005433754672	26187	Economy	61500.00
0005435982821	26187	Economy	61500.00
0005435982684	26187	Economy	61500.00
0005432655643	26187	Economy	61500.00
0005433754790	26187	Economy	61500.00
0005433754867	26187	Economy	61500.00
0005434375543	1532	Business	38900.00
0005434375506	1532	Business	38900.00
0005433461632	1532	Business	38900.00
0005434375519	1532	Business	38900.00
0005434375521	1532	Business	38900.00
0005434375553	1532	Business	38900.00
0005433461630	1532	Economy	13000.00
0005433764701	1532	Economy	13000.00
0005433151675	1532	Economy	13000.00
0005434375505	1532	Economy	13000.00
0005434375512	1532	Economy	13000.00
0005434375548	1532	Economy	13000.00
0005433151870	1532	Economy	13000.00
0005433151914	1532	Economy	13000.00
0005434375513	1532	Economy	13000.00
0005433151720	1532	Economy	13000.00
0005433151888	1532	Economy	13000.00
0005434375538	1532	Economy	13000.00
0005433151872	1532	Economy	13000.00
0005434375546	1532	Economy	13000.00
0005434375544	1532	Economy	13000.00
0005434375535	1532	Economy	13000.00
0005434375533	1532	Economy	13000.00
0005433151838	1532	Economy	13000.00
0005433151855	1532	Economy	13000.00
0005434375507	1532	Economy	13000.00
0005434375556	1532	Economy	13000.00
0005434375549	1532	Economy	13000.00
0005432268024	1532	Economy	13000.00
0005434375518	1532	Economy	13000.00
0005434375551	1532	Economy	13000.00
0005433151904	1532	Economy	13000.00
0005434375524	1532	Economy	13000.00
0005434375528	1532	Economy	13000.00
0005433151676	1532	Economy	13000.00
0005434375540	1532	Economy	13000.00
0005434375523	1532	Economy	13000.00
0005433460479	1532	Economy	13000.00
0005434029669	1532	Economy	14300.00
0005434375534	1532	Economy	14300.00
0005433151761	1532	Economy	14300.00
0005433460478	1532	Economy	14300.00
0005434375539	1532	Economy	14300.00
0005433151703	1532	Economy	13000.00
0005433151810	1532	Economy	13000.00
0005433151891	1532	Economy	13000.00
0005434375542	1532	Economy	13000.00
0005433461631	1532	Economy	13000.00
0005434375532	1532	Economy	13000.00
0005434375525	1532	Economy	13000.00
0005434375547	1532	Economy	13000.00
0005433151683	1532	Economy	13000.00
0005433151727	1532	Economy	13000.00
0005434375555	1532	Economy	13000.00
0005434375537	1532	Economy	13000.00
0005433151747	1532	Economy	13000.00
0005433151713	1532	Economy	13000.00
0005433151736	1532	Economy	13000.00
0005432268023	1532	Economy	13000.00
0005433151854	1532	Economy	13000.00
0005433151752	1532	Economy	13000.00
0005434375552	1532	Economy	13000.00
0005433151950	1532	Economy	13000.00
0005433151821	1532	Economy	13000.00
0005432268029	1532	Economy	13000.00
0005433151971	1532	Economy	13000.00
0005432268027	1532	Economy	13000.00
0005434375550	1532	Economy	13000.00
0005433151778	1532	Economy	13000.00
0005432268025	1532	Economy	13000.00
0005434375520	1532	Economy	13000.00
0005432268026	1532	Economy	13000.00
0005434375557	1532	Economy	13000.00
0005433151890	1532	Economy	13000.00
0005434375526	1532	Economy	13000.00
0005434375516	1532	Economy	13000.00
0005434375545	1532	Economy	13000.00
0005433151539	1532	Economy	13000.00
0005434375527	1532	Economy	13000.00
0005433151954	1532	Economy	13000.00
0005434375511	1532	Economy	13000.00
0005434375510	1532	Economy	13000.00
0005433764702	1532	Economy	13000.00
0005433151721	1532	Economy	13000.00
0005434375530	1532	Economy	13000.00
0005432268028	1532	Economy	13000.00
0005433151836	1532	Economy	13000.00
0005433151781	1532	Economy	13000.00
0005434375529	1532	Economy	13000.00
0005434375517	1532	Economy	13000.00
0005433931493	1532	Economy	13000.00
0005434375536	1532	Economy	13000.00
0005434375531	1532	Economy	13000.00
0005434375515	1532	Economy	13000.00
0005434375514	1532	Economy	13000.00
0005434375508	1532	Economy	13000.00
0005433151820	1532	Economy	13000.00
0005433151960	1532	Economy	13000.00
0005434375554	1532	Economy	13000.00
0005433151861	1532	Economy	13000.00
0005434375509	1532	Economy	13000.00
0005434375522	1532	Economy	13000.00
0005434375541	1532	Economy	13000.00
0005433931501	1532	Economy	13000.00
0005433151782	1532	Economy	13000.00
0005433764719	20152	Business	38900.00
0005434375020	20152	Business	38900.00
0005434374921	20152	Business	38900.00
0005433152093	20152	Business	38900.00
0005434375138	20152	Business	38900.00
0005434375033	20152	Business	38900.00
0005433152086	20152	Business	38900.00
0005433152077	20152	Economy	13000.00
0005434374936	20152	Business	38900.00
0005433152069	20152	Economy	13000.00
0005433152080	20152	Economy	13000.00
0005433152062	20152	Economy	13000.00
0005434375074	20152	Economy	13000.00
0005433152074	20152	Economy	13000.00
0005433152067	20152	Economy	13000.00
0005433152064	20152	Economy	13000.00
0005434375076	20152	Economy	13000.00
0005434375143	20152	Economy	13000.00
0005433931525	20152	Economy	13000.00
0005434375108	20152	Economy	13000.00
0005434375081	20152	Economy	13000.00
0005434375199	20152	Economy	13000.00
0005433152070	20152	Economy	13000.00
0005434375075	20152	Economy	13000.00
0005434375021	20152	Economy	13000.00
0005434029705	20152	Economy	13000.00
0005433764720	20152	Economy	13000.00
0005433152066	20152	Economy	13000.00
0005434375071	20152	Economy	13000.00
0005434029706	20152	Economy	13000.00
0005433152075	20152	Economy	13000.00
0005434375148	20152	Economy	13000.00
0005433152060	20152	Economy	13000.00
0005434375275	20152	Economy	13000.00
0005432056373	20152	Economy	13000.00
0005434375118	20152	Economy	13000.00
0005433152072	20152	Economy	13000.00
0005433152091	20152	Economy	13000.00
0005433931524	20152	Economy	13000.00
0005434375097	20152	Economy	14300.00
0005434375189	20152	Economy	14300.00
0005434375130	20152	Economy	14300.00
0005434375156	20152	Economy	14300.00
0005434375188	20152	Economy	13000.00
0005434375274	20152	Economy	14300.00
0005433152073	20152	Economy	13000.00
0005434374765	20152	Economy	13000.00
0005434375240	20152	Economy	13000.00
0005433152082	20152	Economy	13000.00
0005433152061	20152	Economy	13000.00
0005434375185	20152	Economy	13000.00
0005434375117	20152	Economy	13000.00
0005434375200	20152	Economy	13000.00
0005434375034	20152	Economy	13000.00
0005433152085	20152	Economy	13000.00
0005434375124	20152	Economy	13000.00
0005434375144	20152	Economy	13000.00
0005434375106	20152	Economy	13000.00
0005434375129	20152	Economy	13000.00
0005434374920	20152	Economy	13000.00
0005434375077	20152	Economy	13000.00
0005434375078	20152	Economy	13000.00
0005434375002	20152	Economy	13000.00
0005434375224	20152	Economy	13000.00
0005433152078	20152	Economy	13000.00
0005434375070	20152	Economy	13000.00
0005433152092	20152	Economy	13000.00
0005434375145	20152	Economy	13000.00
0005434375035	20152	Economy	13000.00
0005434375208	20152	Economy	13000.00
0005434375123	20152	Economy	13000.00
0005433152068	20152	Economy	13000.00
0005434375182	20152	Economy	13000.00
0005433152089	20152	Economy	13000.00
0005434375001	20152	Economy	13000.00
0005433152079	20152	Economy	13000.00
0005432056374	20152	Economy	13000.00
0005433931526	20152	Economy	13000.00
0005433152065	20152	Economy	13000.00
0005433152076	20152	Economy	13000.00
0005433152084	20152	Economy	13000.00
0005434375109	20152	Economy	13000.00
0005434029707	20152	Economy	13000.00
0005433152063	20152	Economy	13000.00
0005434375088	20152	Economy	13000.00
0005434375015	20152	Economy	13000.00
0005434375004	20152	Economy	13000.00
0005432056372	20152	Economy	13000.00
0005433152059	20152	Economy	13000.00
0005433152090	20152	Economy	13000.00
0005434375276	20152	Economy	13000.00
0005433931522	20152	Economy	13000.00
0005433152088	20152	Economy	13000.00
0005433152083	20152	Economy	13000.00
0005434375149	20152	Economy	13000.00
0005434375072	20152	Economy	13000.00
0005433152087	20152	Economy	13000.00
0005434375155	20152	Economy	13000.00
0005434375207	20152	Economy	13000.00
0005434375241	20152	Economy	13000.00
0005433152071	20152	Economy	13000.00
0005433152081	20152	Economy	13000.00
0005433931523	20152	Economy	13000.00
0005432425409	541	Business	27500.00
0005432425396	541	Business	27500.00
0005432283006	541	Business	27500.00
0005432283005	541	Business	27500.00
0005432425395	541	Business	27500.00
0005432425386	541	Business	27500.00
0005432425392	541	Business	27500.00
0005432425402	541	Business	27500.00
0005432425397	541	Business	27500.00
0005432425417	541	Business	27500.00
0005432425426	541	Business	27500.00
0005432425383	541	Economy	10100.00
0005432425416	541	Economy	10100.00
0005432425387	541	Economy	10100.00
0005432283000	541	Economy	10100.00
0005432425418	541	Economy	9200.00
0005432425421	541	Economy	9200.00
0005432425394	541	Economy	9200.00
0005432425405	541	Economy	9200.00
0005432425406	541	Economy	9200.00
0005432425399	541	Economy	9200.00
0005432425398	541	Economy	9200.00
0005432425412	541	Economy	9200.00
0005432425413	541	Economy	9200.00
0005432425382	541	Economy	9200.00
0005432425401	541	Economy	9200.00
0005432425385	541	Economy	9200.00
0005432425400	541	Economy	9200.00
0005432283001	541	Economy	9200.00
0005432425422	541	Economy	9200.00
0005432283003	541	Economy	9200.00
0005432425404	541	Economy	9200.00
0005432425403	541	Economy	9200.00
0005432283004	541	Economy	9200.00
0005432425393	541	Economy	9200.00
0005432425390	541	Economy	9200.00
0005432425408	541	Economy	10100.00
0005432283002	541	Economy	10100.00
0005432425381	541	Economy	9200.00
0005432425379	541	Economy	9200.00
0005432425391	541	Economy	9200.00
0005432425410	541	Economy	9200.00
0005432425414	541	Economy	9200.00
0005432425407	541	Economy	9200.00
0005432425423	541	Economy	9200.00
0005432425415	541	Economy	9200.00
0005432425384	541	Economy	9200.00
0005432282999	541	Economy	9200.00
0005432425419	541	Economy	9200.00
0005432425425	541	Economy	9200.00
0005432425420	541	Economy	9200.00
0005432425411	541	Economy	9200.00
0005432425424	541	Economy	9200.00
0005432425380	541	Economy	9200.00
0005432425388	541	Economy	9200.00
0005432425378	541	Economy	9200.00
0005432425389	541	Economy	9200.00
0005433261874	12929	Business	27500.00
0005433261875	12929	Economy	10100.00
0005432302406	12929	Economy	10100.00
0005432302407	12929	Economy	9200.00
0005432302405	12929	Economy	9200.00
0005432302403	12929	Economy	9200.00
0005432302404	12929	Economy	9200.00
0005432424956	12927	Business	27500.00
0005432424949	12927	Business	27500.00
0005432424950	12927	Business	27500.00
0005432424941	12927	Business	27500.00
0005432424765	12927	Business	27500.00
0005432424840	12927	Business	27500.00
0005432424948	12927	Business	27500.00
0005432424879	12927	Economy	10100.00
0005432424873	12927	Economy	9200.00
0005432424899	12927	Economy	9200.00
0005432424932	12927	Economy	9200.00
0005432424594	12927	Economy	9200.00
0005432424887	12927	Economy	9200.00
0005432424852	12927	Economy	9200.00
0005432424732	12927	Economy	9200.00
0005432424871	12927	Economy	9200.00
0005432424926	12927	Economy	9200.00
0005432424841	12927	Economy	9200.00
0005432424927	12927	Economy	9200.00
0005432424784	12927	Economy	9200.00
0005432424910	12927	Economy	9200.00
0005432424813	12927	Economy	9200.00
0005432424878	12927	Economy	9200.00
0005432424593	12927	Economy	10100.00
0005432424942	12927	Economy	10100.00
0005432424838	12927	Economy	10100.00
0005432424888	12927	Economy	9200.00
0005432424907	12927	Economy	9200.00
0005432424636	12927	Economy	9200.00
0005432424788	12927	Economy	9200.00
0005432424830	12927	Economy	9200.00
0005432424851	12927	Economy	9200.00
0005432424885	12927	Economy	9200.00
0005432424789	12927	Economy	9200.00
0005432424913	12927	Economy	9200.00
0005432424933	12927	Economy	9200.00
0005432424877	12927	Economy	9200.00
0005432424839	12927	Economy	9200.00
0005432424737	12927	Economy	9200.00
0005432424961	12927	Economy	9200.00
0005432424795	12927	Economy	9200.00
0005432424955	12927	Economy	9200.00
0005432424842	12927	Economy	9200.00
0005432424898	12927	Economy	9200.00
0005432424870	12927	Economy	9200.00
0005432424772	12927	Economy	9200.00
0005432424874	12927	Economy	9200.00
0005432424884	12927	Economy	9200.00
0005434025026	432	Business	24500.00
0005434025011	432	Business	24500.00
0005434025056	432	Business	24500.00
0005434025053	432	Business	24500.00
0005434735760	432	Business	24500.00
0005432235788	432	Business	24500.00
0005433058486	432	Business	24500.00
0005434025046	432	Business	24500.00
0005434025002	432	Business	24500.00
0005433058472	432	Business	24500.00
0005434025045	432	Business	24500.00
0005434032113	432	Business	24500.00
0005433684451	432	Business	24500.00
0005433058436	432	Business	24500.00
0005433058369	432	Business	24500.00
0005434032109	432	Business	24500.00
0005433058186	432	Economy	9000.00
0005434025022	432	Economy	9000.00
0005433058287	432	Economy	9000.00
0005434025031	432	Economy	9000.00
0005434025013	432	Economy	8200.00
0005434025012	432	Economy	8200.00
0005434025023	432	Economy	8200.00
0005434025035	432	Economy	8200.00
0005434025005	432	Economy	8200.00
0005434029704	432	Economy	8200.00
0005434028356	432	Economy	8200.00
0005433058433	432	Economy	8200.00
0005433058505	432	Economy	8200.00
0005433058318	432	Economy	8200.00
0005434028358	432	Economy	8200.00
0005434025021	432	Economy	8200.00
0005434028359	432	Economy	8200.00
0005433929653	432	Economy	8200.00
0005433058415	432	Economy	8200.00
0005432045650	432	Economy	8200.00
0005433058229	432	Economy	8200.00
0005434025032	432	Economy	8200.00
0005434025004	432	Economy	8200.00
0005434025018	432	Economy	8200.00
0005434025010	432	Economy	8200.00
0005432235781	432	Economy	8200.00
0005433929652	432	Economy	8200.00
0005434025042	432	Economy	8200.00
0005433058091	432	Economy	8200.00
0005433058228	432	Economy	8200.00
0005432235786	432	Economy	8200.00
0005434025060	432	Economy	8200.00
0005434025063	432	Economy	8200.00
0005433058182	432	Economy	8200.00
0005434025000	432	Economy	8200.00
0005434025041	432	Economy	8200.00
0005434025028	432	Economy	8200.00
0005434735761	432	Economy	8200.00
0005434025003	432	Economy	8200.00
0005433058296	432	Economy	8200.00
0005432235784	432	Economy	8200.00
0005434032112	432	Economy	8200.00
0005434025061	432	Economy	8200.00
0005433058373	432	Economy	8200.00
0005433058487	432	Economy	8200.00
0005433929651	432	Economy	8200.00
0005433058090	432	Economy	8200.00
0005434025016	432	Economy	8200.00
0005434025039	432	Economy	8200.00
0005434029703	432	Economy	8200.00
0005432235783	432	Economy	8200.00
0005434025019	432	Economy	8200.00
0005434025044	432	Economy	8200.00
0005433058166	432	Economy	8200.00
0005434024997	432	Economy	8200.00
0005434735749	432	Economy	8200.00
0005434735731	432	Economy	8200.00
0005434025034	432	Economy	8200.00
0005433058343	432	Economy	8200.00
0005434024998	432	Economy	8200.00
0005434025027	432	Economy	8200.00
0005434024999	432	Economy	8200.00
0005434025040	432	Economy	8200.00
0005434025009	432	Economy	8200.00
0005432235785	432	Economy	8200.00
0005433058372	432	Economy	8200.00
0005434025062	432	Economy	8200.00
0005434025025	432	Economy	8200.00
0005433058344	432	Economy	9000.00
0005433058402	432	Economy	8200.00
0005434025030	432	Economy	8200.00
0005434025048	432	Economy	9000.00
0005434025052	432	Economy	8200.00
0005434025059	432	Economy	8200.00
0005434025065	432	Economy	8200.00
0005434028357	432	Economy	8200.00
0005433058185	432	Economy	8200.00
0005434025008	432	Economy	8200.00
0005434025050	432	Economy	8200.00
0005434025064	432	Economy	8200.00
0005433058405	432	Economy	8200.00
0005433058387	432	Economy	8200.00
0005434025033	432	Economy	8200.00
0005432235782	432	Economy	8200.00
0005433058362	432	Economy	8200.00
0005434025037	432	Economy	8200.00
0005434025001	432	Economy	8200.00
0005433058232	432	Economy	8200.00
0005434025051	432	Economy	8200.00
0005434025055	432	Economy	8200.00
0005433058410	432	Economy	8200.00
0005433058380	432	Economy	8200.00
0005434025043	432	Economy	8200.00
0005433058350	432	Economy	8200.00
0005434025020	432	Economy	8200.00
0005433058423	432	Economy	8200.00
0005432235787	432	Economy	8200.00
0005434025058	432	Economy	8200.00
0005434025038	432	Economy	8200.00
0005434025017	432	Economy	8200.00
0005434025057	432	Economy	8200.00
0005434025054	432	Economy	8200.00
0005434032110	432	Economy	8200.00
0005434025036	432	Economy	8200.00
0005433058409	432	Economy	8200.00
0005433058440	432	Economy	8200.00
0005434025029	432	Economy	8200.00
0005434025047	432	Economy	8200.00
0005434025014	432	Economy	8200.00
0005434735740	432	Economy	8200.00
0005433684440	432	Economy	8200.00
0005433058167	432	Economy	8200.00
0005434032111	432	Economy	8200.00
0005434025007	432	Economy	8200.00
0005433058297	432	Economy	8200.00
0005434025006	432	Economy	8200.00
0005434025015	432	Economy	8200.00
0005434025049	432	Economy	8200.00
0005434735750	432	Economy	8200.00
0005434025024	432	Economy	8200.00
0005434024828	12689	Business	24500.00
0005434032070	12689	Business	24500.00
0005434024241	12689	Business	24500.00
0005434024519	12689	Business	24500.00
0005434024590	12689	Business	24500.00
0005434024176	12689	Business	24500.00
0005434024466	12689	Business	24500.00
0005434735791	12689	Business	24500.00
0005433058667	12689	Business	24500.00
0005434735792	12689	Business	24500.00
0005434024410	12689	Business	24500.00
0005434024482	12689	Business	24500.00
0005434024175	12689	Business	24500.00
0005433058648	12689	Business	24500.00
0005433058683	12689	Business	24500.00
0005433058681	12689	Business	24500.00
0005433058669	12689	Business	24500.00
0005433058650	12689	Business	24500.00
0005434024506	12689	Economy	9000.00
0005434024541	12689	Economy	8200.00
0005433058662	12689	Economy	8200.00
0005434024250	12689	Economy	8200.00
0005433929695	12689	Economy	8200.00
0005434028318	12689	Economy	8200.00
0005434024560	12689	Economy	8200.00
0005434029669	12689	Economy	8200.00
0005433929692	12689	Economy	8200.00
0005434028323	12689	Economy	8200.00
0005434024638	12689	Economy	8200.00
0005433058665	12689	Economy	8200.00
0005434024571	12689	Economy	8200.00
0005434032072	12689	Economy	8200.00
0005433058654	12689	Economy	8200.00
0005434024434	12689	Economy	8200.00
0005432156451	12689	Economy	8200.00
0005434024240	12689	Economy	8200.00
0005434024527	12689	Economy	8200.00
0005434024574	12689	Economy	8200.00
0005434024377	12689	Economy	8200.00
0005434024258	12689	Economy	8200.00
0005434024616	12689	Economy	8200.00
0005433058676	12689	Economy	8200.00
0005434028333	12689	Economy	8200.00
0005433058656	12689	Economy	8200.00
0005433058668	12689	Economy	8200.00
0005434024407	12689	Economy	8200.00
0005433058678	12689	Economy	8200.00
0005434024164	12689	Economy	8200.00
0005434024507	12689	Economy	8200.00
0005434032082	12689	Economy	8200.00
0005434032071	12689	Economy	8200.00
0005433058664	12689	Economy	8200.00
0005434023890	12689	Economy	8200.00
0005433058652	12689	Economy	8200.00
0005433058672	12689	Economy	8200.00
0005434024401	12689	Economy	8200.00
0005434024644	12689	Economy	8200.00
0005434024402	12689	Economy	8200.00
0005434024467	12689	Economy	8200.00
0005433058684	12689	Economy	8200.00
0005433058661	12689	Economy	8200.00
0005433058657	12689	Economy	8200.00
0005433058679	12689	Economy	8200.00
0005434024174	12689	Economy	8200.00
0005434024423	12689	Economy	8200.00
0005433058663	12689	Economy	8200.00
0005433058675	12689	Economy	8200.00
0005434735790	12689	Economy	8200.00
0005434024621	12689	Economy	8200.00
0005433929693	12689	Economy	8200.00
0005432156454	12689	Economy	8200.00
0005434024518	12689	Economy	8200.00
0005433058649	12689	Economy	8200.00
0005433929694	12689	Economy	8200.00
0005433058651	12689	Economy	9000.00
0005434024573	12689	Economy	9000.00
0005434023984	12689	Economy	8200.00
0005434024435	12689	Economy	9000.00
0005433058671	12689	Economy	9000.00
0005433058666	12689	Economy	8200.00
0005434024406	12689	Economy	8200.00
0005434024259	12689	Economy	8200.00
0005433058686	12689	Economy	8200.00
0005434024247	12689	Economy	8200.00
0005433058660	12689	Economy	8200.00
0005433058680	12689	Economy	8200.00
0005433684462	12689	Economy	8200.00
0005432156450	12689	Economy	8200.00
0005433058658	12689	Economy	8200.00
0005433058655	12689	Economy	8200.00
0005434024485	12689	Economy	8200.00
0005434024634	12689	Economy	8200.00
0005434024639	12689	Economy	8200.00
0005433058653	12689	Economy	8200.00
0005433058659	12689	Economy	8200.00
0005434024516	12689	Economy	8200.00
0005433058682	12689	Economy	8200.00
0005434024542	12689	Economy	8200.00
0005433058687	12689	Economy	8200.00
0005434735794	12689	Economy	8200.00
0005434024528	12689	Economy	8200.00
0005434024418	12689	Economy	8200.00
0005434024611	12689	Economy	8200.00
0005433058685	12689	Economy	8200.00
0005434024471	12689	Economy	8200.00
0005433929696	12689	Economy	8200.00
0005434735793	12689	Economy	8200.00
0005434028329	12689	Economy	8200.00
0005433058670	12689	Economy	8200.00
0005434024412	12689	Economy	8200.00
0005434024461	12689	Economy	8200.00
0005434024559	12689	Economy	8200.00
0005434024643	12689	Economy	8200.00
0005434024486	12689	Economy	8200.00
0005434024411	12689	Economy	8200.00
0005433058673	12689	Economy	8200.00
0005434024257	12689	Economy	8200.00
0005432156453	12689	Economy	8200.00
0005434024315	12689	Economy	8200.00
0005433058677	12689	Economy	8200.00
0005432156452	12689	Economy	8200.00
0005434024481	12689	Economy	8200.00
0005434024251	12689	Economy	8200.00
0005434024239	12689	Economy	8200.00
0005434023983	12689	Economy	8200.00
0005433058674	12689	Economy	8200.00
0005434024575	12689	Economy	8200.00
0005432157530	12689	Economy	8200.00
0005433036769	2129	Business	34700.00
0005433036940	2129	Business	34700.00
0005433925195	2129	Business	34700.00
0005433036881	2129	Business	34700.00
0005433925194	2129	Business	34700.00
0005433925219	2129	Business	34700.00
0005432231768	2129	Business	34700.00
0005433036834	2129	Business	34700.00
0005433925156	2129	Business	34700.00
0005433925146	2129	Business	34700.00
0005433925128	2129	Business	34700.00
0005433036729	2129	Business	34700.00
0005433925143	2129	Business	34700.00
0005433925129	2129	Business	34700.00
0005433037025	2129	Business	34700.00
0005434028323	2129	Business	34700.00
0005433925163	2129	Business	34700.00
0005433925150	2129	Business	34700.00
0005433925216	2129	Business	34700.00
0005433036774	2129	Business	34700.00
0005433925214	2129	Business	34700.00
0005433925159	2129	Business	34700.00
0005433925186	2129	Economy	12700.00
0005433925133	2129	Economy	12700.00
0005433925178	2129	Economy	12700.00
0005433925174	2129	Economy	11600.00
0005433925211	2129	Economy	11600.00
0005433925176	2129	Economy	11600.00
0005433925187	2129	Economy	11600.00
0005433925207	2129	Economy	11600.00
0005433036999	2129	Economy	11600.00
0005433929694	2129	Economy	11600.00
0005432231773	2129	Economy	11600.00
0005433929693	2129	Economy	11600.00
0005433037000	2129	Economy	11600.00
0005433925212	2129	Economy	11600.00
0005433036824	2129	Economy	11600.00
0005433037013	2129	Economy	11600.00
0005433037055	2129	Economy	11600.00
0005433925191	2129	Economy	11600.00
0005433925172	2129	Economy	11600.00
0005433925141	2129	Economy	11600.00
0005433925217	2129	Economy	11600.00
0005433037024	2129	Economy	11600.00
0005433925170	2129	Economy	11600.00
0005433925134	2129	Economy	11600.00
0005433925122	2129	Economy	11600.00
0005433925153	2129	Economy	11600.00
0005433925145	2129	Economy	11600.00
0005433925164	2129	Economy	11600.00
0005433925171	2129	Economy	11600.00
0005433036730	2129	Economy	11600.00
0005433925161	2129	Economy	11600.00
0005432044579	2129	Economy	11600.00
0005433036995	2129	Economy	11600.00
0005433929696	2129	Economy	11600.00
0005433925180	2129	Economy	11600.00
0005433925140	2129	Economy	11600.00
0005433036826	2129	Economy	11600.00
0005433925165	2129	Economy	11600.00
0005433931524	2129	Economy	11600.00
0005433925158	2129	Economy	11600.00
0005433037002	2129	Economy	11600.00
0005433925173	2129	Economy	11600.00
0005433036924	2129	Economy	11600.00
0005433925142	2129	Economy	11600.00
0005433925184	2129	Economy	11600.00
0005433925167	2129	Economy	11600.00
0005433925132	2129	Economy	11600.00
0005433925181	2129	Economy	11600.00
0005433925135	2129	Economy	11600.00
0005433929695	2129	Economy	11600.00
0005433925188	2129	Economy	11600.00
0005433875409	2129	Economy	11600.00
0005433925206	2129	Economy	11600.00
0005433925201	2129	Economy	11600.00
0005433931525	2129	Economy	11600.00
0005432231767	2129	Economy	11600.00
0005433925130	2129	Economy	11600.00
0005432231774	2129	Economy	11600.00
0005433036825	2129	Economy	11600.00
0005433037017	2129	Economy	11600.00
0005434028329	2129	Economy	11600.00
0005433925202	2129	Economy	11600.00
0005433036802	2129	Economy	11600.00
0005433925137	2129	Economy	11600.00
0005433925131	2129	Economy	11600.00
0005433925210	2129	Economy	11600.00
0005433036971	2129	Economy	11600.00
0005433925177	2129	Economy	11600.00
0005433037019	2129	Economy	11600.00
0005433036941	2129	Economy	11600.00
0005433925197	2129	Economy	11600.00
0005433037054	2129	Economy	11600.00
0005433925182	2129	Economy	11600.00
0005433925136	2129	Economy	11600.00
0005432231775	2129	Economy	11600.00
0005433925124	2129	Economy	11600.00
0005433925183	2129	Economy	11600.00
0005433036988	2129	Economy	11600.00
0005433036835	2129	Economy	11600.00
0005433037001	2129	Economy	11600.00
0005433925126	2129	Economy	11600.00
0005433925193	2129	Economy	11600.00
0005433925149	2129	Economy	11600.00
0005433037044	2129	Economy	11600.00
0005433929864	2129	Economy	11600.00
0005432044578	2129	Economy	12700.00
0005433036967	2129	Economy	11600.00
0005433925147	2129	Economy	11600.00
0005433925125	2129	Economy	12700.00
0005433925215	2129	Economy	11600.00
0005432231776	2129	Economy	11600.00
0005433925139	2129	Economy	11600.00
0005433036923	2129	Economy	11600.00
0005433036994	2129	Economy	11600.00
0005433925151	2129	Economy	11600.00
0005433931526	2129	Economy	11600.00
0005433036641	2129	Economy	11600.00
0005433925152	2129	Economy	11600.00
0005433929866	2129	Economy	11600.00
0005433929865	2129	Economy	11600.00
0005433925169	2129	Economy	11600.00
0005433925196	2129	Economy	11600.00
0005434028333	2129	Economy	11600.00
0005433925127	2129	Economy	11600.00
0005433925157	2129	Economy	11600.00
0005433929863	2129	Economy	11600.00
0005433875408	2129	Economy	11600.00
0005433925155	2129	Economy	11600.00
0005433931523	2129	Economy	11600.00
0005433036880	2129	Economy	11600.00
0005433925192	2129	Economy	11600.00
0005433036966	2129	Economy	11600.00
0005433925190	2129	Economy	11600.00
0005433036897	2129	Economy	11600.00
0005433925213	2129	Economy	11600.00
0005433037045	2129	Economy	11600.00
0005433925166	2129	Economy	11600.00
0005432231769	2129	Economy	11600.00
0005433925148	2129	Economy	11600.00
0005433931522	2129	Economy	11600.00
0005433925204	2129	Economy	11600.00
0005433925209	2129	Economy	11600.00
0005433925198	2129	Economy	11600.00
0005432044577	2129	Economy	11600.00
0005433925123	2129	Economy	11600.00
0005433036975	2129	Economy	11600.00
0005433925189	2129	Economy	11600.00
0005433925199	2129	Economy	11600.00
0005433925203	2129	Economy	11600.00
0005434028318	2129	Economy	11600.00
0005433925205	2129	Economy	11600.00
0005433036944	2129	Economy	11600.00
0005433925179	2129	Economy	11600.00
0005433925185	2129	Economy	11600.00
0005433925160	2129	Economy	11600.00
0005433925175	2129	Economy	11600.00
0005433925154	2129	Economy	11600.00
0005433925138	2129	Economy	11600.00
0005433036898	2129	Economy	11600.00
0005433925200	2129	Economy	11600.00
0005432231771	2129	Economy	11600.00
0005433037018	2129	Economy	11600.00
0005433925168	2129	Economy	11600.00
0005432044580	2129	Economy	11600.00
0005433875410	2129	Economy	11600.00
0005432231772	2129	Economy	11600.00
0005433036801	2129	Economy	11600.00
0005433036980	2129	Economy	11600.00
0005433925162	2129	Economy	11600.00
0005433925218	2129	Economy	11600.00
0005433036965	2129	Economy	11600.00
0005433925208	2129	Economy	11600.00
0005433036896	2129	Economy	11600.00
0005433929692	2129	Economy	11600.00
0005433925144	2129	Economy	11600.00
0005432231770	2129	Economy	11600.00
0005433924378	24108	Business	34700.00
0005433875399	24108	Business	34700.00
0005433037332	24108	Business	34700.00
0005433037338	24108	Business	34700.00
0005433037322	24108	Business	34700.00
0005433924720	24108	Business	34700.00
0005433924432	24108	Business	34700.00
0005433924485	24108	Business	34700.00
0005433924514	24108	Business	34700.00
0005433924679	24108	Business	34700.00
0005433929640	24108	Business	34700.00
0005433037307	24108	Business	34700.00
0005433924556	24108	Business	34700.00
0005433037309	24108	Business	34700.00
0005433924404	24108	Business	34700.00
0005433924314	24108	Business	34700.00
0005433924338	24108	Business	34700.00
0005432749827	24108	Business	34700.00
0005433037329	24108	Business	34700.00
0005433929665	24108	Business	34700.00
0005433037325	24108	Business	34700.00
0005433037327	24108	Business	34700.00
0005433924523	24108	Business	34700.00
0005433924247	24108	Economy	12700.00
0005433924335	24108	Economy	12700.00
0005433924219	24108	Economy	12700.00
0005433924631	24108	Economy	11600.00
0005433923707	24108	Economy	11600.00
0005433924367	24108	Economy	11600.00
0005433924622	24108	Economy	11600.00
0005433924421	24108	Economy	11600.00
0005434028364	24108	Economy	11600.00
0005433924522	24108	Economy	11600.00
0005433037323	24108	Economy	11600.00
0005433924486	24108	Economy	11600.00
0005433924491	24108	Economy	11600.00
0005433924496	24108	Economy	11600.00
0005432206308	24108	Economy	11600.00
0005433924346	24108	Economy	11600.00
0005432206309	24108	Economy	11600.00
0005433924233	24108	Economy	11600.00
0005433924047	24108	Economy	11600.00
0005433037336	24108	Economy	11600.00
0005433924334	24108	Economy	11600.00
0005433924217	24108	Economy	11600.00
0005433924152	24108	Economy	11600.00
0005433924273	24108	Economy	11600.00
0005433924276	24108	Economy	11600.00
0005433037305	24108	Economy	11600.00
0005433924135	24108	Economy	11600.00
0005433924439	24108	Economy	11600.00
0005433924094	24108	Economy	11600.00
0005433924698	24108	Economy	11600.00
0005433924344	24108	Economy	11600.00
0005433924142	24108	Economy	11600.00
0005433924364	24108	Economy	11600.00
0005433924297	24108	Economy	11600.00
0005433924174	24108	Economy	11600.00
0005433929666	24108	Economy	11600.00
0005433037353	24108	Economy	11600.00
0005433924347	24108	Economy	11600.00
0005433037310	24108	Economy	11600.00
0005433037321	24108	Economy	11600.00
0005433924354	24108	Economy	11600.00
0005433037301	24108	Economy	11600.00
0005433037351	24108	Economy	11600.00
0005433924450	24108	Economy	11600.00
0005433924422	24108	Economy	11600.00
0005433037334	24108	Economy	11600.00
0005433924205	24108	Economy	11600.00
0005433929670	24108	Economy	11600.00
0005433924693	24108	Economy	11600.00
0005433923872	24108	Economy	11600.00
0005433924277	24108	Economy	11600.00
0005434028363	24108	Economy	11600.00
0005433924250	24108	Economy	11600.00
0005433929669	24108	Economy	11600.00
0005433929672	24108	Economy	11600.00
0005433037314	24108	Economy	11600.00
0005433037326	24108	Economy	11600.00
0005433037306	24108	Economy	11600.00
0005433037299	24108	Economy	11600.00
0005433037328	24108	Economy	11600.00
0005433875398	24108	Economy	11600.00
0005433924182	24108	Economy	11600.00
0005433037304	24108	Economy	11600.00
0005433929641	24108	Economy	11600.00
0005433924114	24108	Economy	11600.00
0005433924048	24108	Economy	11600.00
0005433924365	24108	Economy	11600.00
0005433924272	24108	Economy	11600.00
0005433037346	24108	Economy	11600.00
0005433924692	24108	Economy	11600.00
0005432207712	24108	Economy	11600.00
0005433037330	24108	Economy	11600.00
0005433037319	24108	Economy	11600.00
0005434028362	24108	Economy	11600.00
0005433037331	24108	Economy	11600.00
0005433924362	24108	Economy	11600.00
0005433924313	24108	Economy	11600.00
0005433037324	24108	Economy	11600.00
0005433037337	24108	Economy	11600.00
0005433037347	24108	Economy	11600.00
0005433924509	24108	Economy	11600.00
0005433037316	24108	Economy	11600.00
0005433037313	24108	Economy	11600.00
0005433923880	24108	Economy	11600.00
0005433037344	24108	Economy	11600.00
0005433924339	24108	Economy	12700.00
0005433923750	24108	Economy	12700.00
0005433924363	24108	Economy	11600.00
0005432206311	24108	Economy	11600.00
0005433924505	24108	Economy	11600.00
0005433037312	24108	Economy	11600.00
0005433924412	24108	Economy	11600.00
0005433924494	24108	Economy	11600.00
0005433924411	24108	Economy	11600.00
0005433924343	24108	Economy	11600.00
0005433924183	24108	Economy	11600.00
0005433923881	24108	Economy	11600.00
0005433924248	24108	Economy	11600.00
0005433924101	24108	Economy	11600.00
0005433037308	24108	Economy	11600.00
0005433924497	24108	Economy	11600.00
0005433924508	24108	Economy	11600.00
0005433924278	24108	Economy	11600.00
0005433037317	24108	Economy	11600.00
0005434028361	24108	Economy	11600.00
0005433924377	24108	Economy	11600.00
0005433924202	24108	Economy	11600.00
0005433924375	24108	Economy	11600.00
0005433037335	24108	Economy	11600.00
0005433037311	24108	Economy	11600.00
0005433037320	24108	Economy	11600.00
0005433037349	24108	Economy	11600.00
0005433924438	24108	Economy	11600.00
0005433037352	24108	Economy	11600.00
0005433924102	24108	Economy	11600.00
0005433037300	24108	Economy	11600.00
0005433924236	24108	Economy	11600.00
0005433037345	24108	Economy	11600.00
0005432749829	24108	Economy	11600.00
0005432206307	24108	Economy	11600.00
0005433924535	24108	Economy	11600.00
0005432206306	24108	Economy	11600.00
0005433924574	24108	Economy	11600.00
0005433037303	24108	Economy	11600.00
0005433924562	24108	Economy	11600.00
0005433924206	24108	Economy	11600.00
0005433037340	24108	Economy	11600.00
0005432206310	24108	Economy	11600.00
0005433931500	24108	Economy	11600.00
0005433037342	24108	Economy	11600.00
0005433924630	24108	Economy	11600.00
0005433037348	24108	Economy	11600.00
0005433037333	24108	Economy	11600.00
0005433924261	24108	Economy	11600.00
0005433037318	24108	Economy	11600.00
0005433923710	24108	Economy	11600.00
0005433924303	24108	Economy	11600.00
0005433037341	24108	Economy	11600.00
0005433924868	24108	Economy	11600.00
0005433924316	24108	Economy	11600.00
0005433037339	24108	Economy	11600.00
0005433923941	24108	Economy	11600.00
0005433924699	24108	Economy	11600.00
0005433037350	24108	Economy	11600.00
0005433924143	24108	Economy	11600.00
0005433924262	24108	Economy	11600.00
0005433924010	24108	Economy	11600.00
0005433924495	24108	Economy	11600.00
0005433929667	24108	Economy	11600.00
0005433924519	24108	Economy	11600.00
0005433924700	24108	Economy	11600.00
0005433037343	24108	Economy	11600.00
0005433924345	24108	Economy	11600.00
0005434028360	24108	Economy	11600.00
0005432749828	24108	Economy	11600.00
0005433924117	24108	Economy	11600.00
0005433037315	24108	Economy	11600.00
0005433924100	24108	Economy	11600.00
0005433924405	24108	Economy	11600.00
0005432207713	24108	Economy	11600.00
0005433037302	24108	Economy	11600.00
0005433234937	284	Business	83700.00
0005435142840	284	Business	83700.00
0005433234897	284	Business	83700.00
0005435142845	284	Business	83700.00
0005433235009	284	Business	83700.00
0005434727807	284	Business	83700.00
0005434552293	284	Business	83700.00
0005434552307	284	Business	83700.00
0005433289928	284	Business	83700.00
0005432278072	284	Business	83700.00
0005434727846	284	Business	83700.00
0005434727875	284	Business	83700.00
0005434727860	284	Business	83700.00
0005434727890	284	Business	83700.00
0005434727888	284	Business	83700.00
0005434032075	284	Business	83700.00
0005433234868	284	Business	83700.00
0005433234852	284	Business	83700.00
0005434552311	284	Business	83700.00
0005433766686	284	Business	83700.00
0005433234641	284	Business	83700.00
0005434727836	284	Business	83700.00
0005433234910	284	Business	83700.00
0005434727823	284	Business	83700.00
0005434552313	284	Business	83700.00
0005434552321	284	Business	83700.00
0005434302546	284	Comfort	47400.00
0005434552294	284	Comfort	47400.00
0005434727856	284	Comfort	47400.00
0005434302545	284	Comfort	47400.00
0005433111524	284	Comfort	47400.00
0005434727829	284	Comfort	47400.00
0005434731247	284	Comfort	47400.00
0005434727834	284	Comfort	47400.00
0005434727815	284	Comfort	47400.00
0005434552279	284	Comfort	47400.00
0005434552319	284	Comfort	47400.00
0005434552283	284	Comfort	47400.00
0005433234713	284	Comfort	47400.00
0005434552301	284	Comfort	47400.00
0005434552309	284	Comfort	47400.00
0005434727894	284	Comfort	47400.00
0005434727813	284	Comfort	47400.00
0005434727820	284	Comfort	47400.00
0005434727825	284	Comfort	47400.00
0005433181441	284	Comfort	47400.00
0005433234812	284	Comfort	47400.00
0005434552295	284	Comfort	47400.00
0005433235109	284	Comfort	47400.00
0005434727896	284	Comfort	47400.00
0005433234563	284	Comfort	47400.00
0005433234611	284	Comfort	47400.00
0005432278076	284	Comfort	47400.00
0005434727816	284	Comfort	47400.00
0005434727886	284	Comfort	47400.00
0005434552297	284	Comfort	47400.00
0005433181326	284	Comfort	47400.00
0005434727785	284	Comfort	47400.00
0005434552287	284	Comfort	47400.00
0005432278074	284	Comfort	47400.00
0005434727838	284	Comfort	47400.00
0005434727863	284	Comfort	47400.00
0005434727781	284	Comfort	47400.00
0005434552292	284	Comfort	47400.00
0005432278070	284	Comfort	47400.00
0005432278067	284	Comfort	47400.00
0005434727870	284	Economy	27900.00
0005434727787	284	Economy	27900.00
0005433181429	284	Economy	27900.00
0005434727777	284	Economy	27900.00
0005434552324	284	Economy	27900.00
0005434727827	284	Economy	27900.00
0005433234642	284	Economy	27900.00
0005434727783	284	Economy	27900.00
0005434727891	284	Economy	27900.00
0005433235115	284	Economy	27900.00
0005434552303	284	Economy	27900.00
0005433234919	284	Economy	27900.00
0005434552291	284	Economy	27900.00
0005434727884	284	Economy	27900.00
0005434727880	284	Economy	27900.00
0005433234576	284	Economy	27900.00
0005434727802	284	Economy	27900.00
0005433234848	284	Economy	27900.00
0005433234840	284	Economy	27900.00
0005434727850	284	Economy	27900.00
0005434727828	284	Economy	27900.00
0005433181202	284	Economy	27900.00
0005434727792	284	Economy	27900.00
0005433181391	284	Economy	27900.00
0005434727799	284	Economy	27900.00
0005433289937	284	Economy	27900.00
0005434727889	284	Economy	27900.00
0005434735788	284	Economy	27900.00
0005433234723	284	Economy	27900.00
0005433234727	284	Economy	27900.00
0005433235010	284	Economy	27900.00
0005434727796	284	Economy	27900.00
0005433234836	284	Economy	27900.00
0005433289906	284	Economy	27900.00
0005432278075	284	Economy	27900.00
0005434727806	284	Economy	27900.00
0005434727818	284	Economy	27900.00
0005434727793	284	Economy	27900.00
0005433234920	284	Economy	27900.00
0005433126888	284	Economy	27900.00
0005433235029	284	Economy	27900.00
0005433766683	284	Economy	27900.00
0005434727782	284	Economy	27900.00
0005434727882	284	Economy	27900.00
0005433234690	284	Economy	27900.00
0005434727857	284	Economy	27900.00
0005433234832	284	Economy	27900.00
0005434727812	284	Economy	27900.00
0005434727780	284	Economy	27900.00
0005434727789	284	Economy	27900.00
0005434552302	284	Economy	27900.00
0005433181505	284	Economy	27900.00
0005433234648	284	Economy	27900.00
0005433181305	284	Economy	27900.00
0005434731251	284	Economy	27900.00
0005434727824	284	Economy	27900.00
0005435142837	284	Economy	27900.00
0005434727831	284	Economy	27900.00
0005434552329	284	Economy	27900.00
0005434727821	284	Economy	30700.00
0005434731248	284	Economy	27900.00
0005433234924	284	Economy	30700.00
0005435142838	284	Economy	27900.00
0005433181386	284	Economy	30700.00
0005433181350	284	Economy	27900.00
0005434727893	284	Economy	27900.00
0005433131749	284	Economy	27900.00
0005434552275	284	Economy	27900.00
0005433181408	284	Economy	27900.00
0005433234839	284	Economy	27900.00
0005434032059	284	Economy	27900.00
0005434727895	284	Economy	27900.00
0005435142848	284	Economy	27900.00
0005433234930	284	Economy	27900.00
0005434552326	284	Economy	27900.00
0005434032067	284	Economy	27900.00
0005433289936	284	Economy	27900.00
0005434302883	284	Economy	27900.00
0005433126886	284	Economy	27900.00
0005433181360	284	Economy	27900.00
0005434727809	284	Economy	27900.00
0005434727832	284	Economy	27900.00
0005434727872	284	Economy	27900.00
0005433235044	284	Economy	27900.00
0005433766668	284	Economy	27900.00
0005434727877	284	Economy	27900.00
0005434735789	284	Economy	27900.00
0005434727803	284	Economy	27900.00
0005433234770	284	Economy	27900.00
0005434552284	284	Economy	27900.00
0005433126899	284	Economy	27900.00
0005433234800	284	Economy	27900.00
0005433113562	284	Economy	27900.00
0005434552277	284	Economy	27900.00
0005434552317	284	Economy	27900.00
0005434552290	284	Economy	27900.00
0005434727881	284	Economy	27900.00
0005434735786	284	Economy	27900.00
0005432278071	284	Economy	27900.00
0005435142846	284	Economy	27900.00
0005434727795	284	Economy	27900.00
0005433131768	284	Economy	27900.00
0005434727868	284	Economy	27900.00
0005434727864	284	Economy	27900.00
0005433126866	284	Economy	27900.00
0005434552280	284	Economy	27900.00
0005433131729	284	Economy	27900.00
0005433181325	284	Economy	27900.00
0005434727826	284	Economy	27900.00
0005433181373	284	Economy	27900.00
0005434552299	284	Economy	27900.00
0005434552328	284	Economy	27900.00
0005434302543	284	Economy	27900.00
0005434727801	284	Economy	27900.00
0005434727874	284	Economy	27900.00
0005434727798	284	Economy	27900.00
0005433181385	284	Economy	27900.00
0005435142842	284	Economy	27900.00
0005433113559	284	Economy	27900.00
0005434727788	284	Economy	27900.00
0005434727879	284	Economy	27900.00
0005433289943	284	Economy	27900.00
0005432278068	284	Economy	27900.00
0005434727784	284	Economy	27900.00
0005432278065	284	Economy	27900.00
0005433235078	284	Economy	27900.00
0005434552274	284	Economy	27900.00
0005433131769	284	Economy	27900.00
0005434727845	284	Economy	27900.00
0005434552278	284	Economy	27900.00
0005434727805	284	Economy	27900.00
0005434727892	284	Economy	27900.00
0005434552310	284	Economy	27900.00
0005434727837	284	Economy	27900.00
0005434727873	284	Economy	27900.00
0005434552300	284	Economy	27900.00
0005434552296	284	Economy	27900.00
0005434727822	284	Economy	27900.00
0005434552322	284	Economy	27900.00
0005434727885	284	Economy	27900.00
0005433234699	284	Economy	27900.00
0005434727814	284	Economy	27900.00
0005433181430	284	Economy	27900.00
0005434552282	284	Economy	27900.00
0005433113561	284	Economy	27900.00
0005434727786	284	Economy	27900.00
0005434727779	284	Economy	27900.00
0005433113558	284	Economy	27900.00
0005433766679	284	Economy	27900.00
0005432278066	284	Economy	27900.00
0005434727887	284	Economy	27900.00
0005434552306	284	Economy	27900.00
0005435142841	284	Economy	27900.00
0005433234973	284	Economy	27900.00
0005433234573	284	Economy	27900.00
0005435142839	284	Economy	27900.00
0005434731252	284	Economy	27900.00
0005433234689	284	Economy	27900.00
0005434552289	284	Economy	27900.00
0005433766680	284	Economy	27900.00
0005433181304	284	Economy	27900.00
0005433181351	284	Economy	27900.00
0005434552323	284	Economy	27900.00
0005434727869	284	Economy	30700.00
0005434552308	284	Economy	30700.00
0005434727883	284	Economy	30700.00
0005434727800	284	Economy	30700.00
0005433234650	284	Economy	30700.00
0005434727867	284	Economy	30700.00
0005433181403	284	Economy	27900.00
0005434727854	284	Economy	27900.00
0005434727840	284	Economy	27900.00
0005434552298	284	Economy	27900.00
0005434552305	284	Economy	27900.00
0005433235001	284	Economy	27900.00
0005434731249	284	Economy	27900.00
0005434552312	284	Economy	27900.00
0005433235110	284	Economy	27900.00
0005434727847	284	Economy	27900.00
0005432278077	284	Economy	27900.00
0005434727865	284	Economy	27900.00
0005434727844	284	Economy	27900.00
0005433181390	284	Economy	27900.00
0005434727871	284	Economy	27900.00
0005434032076	284	Economy	27900.00
0005434727835	284	Economy	27900.00
0005434032053	284	Economy	27900.00
0005433234927	284	Economy	27900.00
0005434302544	284	Economy	27900.00
0005433234851	284	Economy	27900.00
0005434727811	284	Economy	27900.00
0005432278073	284	Economy	27900.00
0005433234873	284	Economy	27900.00
0005434727852	284	Economy	27900.00
0005434735787	284	Economy	27900.00
0005434727842	284	Economy	27900.00
0005434552320	284	Economy	27900.00
0005434552327	284	Economy	27900.00
0005434727841	284	Economy	27900.00
0005433234704	284	Economy	27900.00
0005434727791	284	Economy	27900.00
0005434727794	284	Economy	27900.00
0005434552285	284	Economy	27900.00
0005433126864	284	Economy	27900.00
0005433234888	284	Economy	27900.00
0005434727843	284	Economy	27900.00
0005434552315	284	Economy	27900.00
0005433234813	284	Economy	27900.00
0005433289920	284	Economy	27900.00
0005434727853	284	Economy	27900.00
0005434727776	284	Economy	27900.00
0005433234909	284	Economy	27900.00
0005434552304	284	Economy	27900.00
0005433234976	284	Economy	27900.00
0005434727817	284	Economy	27900.00
0005434552276	284	Economy	27900.00
0005433234703	284	Economy	27900.00
0005433234938	284	Economy	27900.00
0005434727790	284	Economy	27900.00
0005434727851	284	Economy	27900.00
0005434727833	284	Economy	27900.00
0005434727866	284	Economy	27900.00
0005434727830	284	Economy	27900.00
0005434727855	284	Economy	27900.00
0005433181359	284	Economy	27900.00
0005433113560	284	Economy	27900.00
0005434727810	284	Economy	27900.00
0005435142836	284	Economy	27900.00
0005435142835	284	Economy	27900.00
0005433234691	284	Economy	27900.00
0005434552314	284	Economy	27900.00
0005434727778	284	Economy	27900.00
0005434552281	284	Economy	27900.00
0005434552288	284	Economy	27900.00
0005434727861	284	Economy	27900.00
0005433235200	284	Economy	27900.00
0005434727839	284	Economy	27900.00
0005433235204	284	Economy	27900.00
0005434727878	284	Economy	27900.00
0005435142843	284	Economy	27900.00
0005434552316	284	Economy	27900.00
0005433234610	284	Economy	27900.00
0005434727797	284	Economy	27900.00
0005433235028	284	Economy	27900.00
0005434727804	284	Economy	27900.00
0005435142844	284	Economy	27900.00
0005434727808	284	Economy	27900.00
0005433181431	284	Economy	27900.00
0005434552325	284	Economy	27900.00
0005433235066	284	Economy	27900.00
0005434727819	284	Economy	27900.00
0005434302542	284	Economy	27900.00
0005434727848	284	Economy	27900.00
0005434727849	284	Economy	27900.00
0005434032060	284	Economy	27900.00
0005434727775	284	Economy	27900.00
0005434032066	284	Economy	27900.00
0005435142847	284	Economy	27900.00
0005432278069	284	Economy	27900.00
0005434727859	284	Economy	27900.00
0005434731250	284	Economy	27900.00
0005434727862	284	Economy	27900.00
0005434727876	284	Economy	27900.00
0005433234649	284	Economy	27900.00
0005433235190	284	Economy	27900.00
0005434727858	284	Economy	27900.00
0005434552286	284	Economy	27900.00
0005434552318	284	Economy	27900.00
0005433126892	284	Economy	27900.00
0005433181602	9863	Business	83700.00
0005434726223	9863	Business	83700.00
0005433126932	9863	Business	83700.00
0005434726662	9863	Business	83700.00
0005434551706	9863	Business	83700.00
0005433235400	9863	Business	83700.00
0005434727260	9863	Business	83700.00
0005434726756	9863	Business	83700.00
0005434302508	9863	Business	83700.00
0005434726004	9863	Business	83700.00
0005433235416	9863	Business	83700.00
0005433235446	9863	Business	83700.00
0005434726616	9863	Business	83700.00
0005433235455	9863	Business	83700.00
0005434727374	9863	Business	83700.00
0005434726781	9863	Business	83700.00
0005433235451	9863	Business	83700.00
0005433235461	9863	Business	83700.00
0005434726393	9863	Business	83700.00
0005433181581	9863	Business	83700.00
0005433181588	9863	Business	83700.00
0005433181589	9863	Business	83700.00
0005434032114	9863	Business	83700.00
0005433235430	9863	Business	83700.00
0005433181600	9863	Business	83700.00
0005434727188	9863	Comfort	47400.00
0005434726687	9863	Comfort	47400.00
0005434727122	9863	Comfort	47400.00
0005434726612	9863	Comfort	47400.00
0005433181590	9863	Comfort	47400.00
0005434726769	9863	Comfort	47400.00
0005434727037	9863	Comfort	47400.00
0005434726868	9863	Comfort	47400.00
0005434727119	9863	Comfort	47400.00
0005434726996	9863	Comfort	47400.00
0005433181597	9863	Comfort	47400.00
0005434551624	9863	Comfort	47400.00
0005433235453	9863	Comfort	47400.00
0005434727095	9863	Comfort	47400.00
0005433235435	9863	Comfort	47400.00
0005434726455	9863	Comfort	47400.00
0005434551483	9863	Comfort	47400.00
0005434727017	9863	Comfort	47400.00
0005434551468	9863	Comfort	47400.00
0005434727110	9863	Comfort	47400.00
0005433235459	9863	Comfort	47400.00
0005434552027	9863	Comfort	47400.00
0005433235437	9863	Comfort	47400.00
0005433235415	9863	Comfort	47400.00
0005433129363	9863	Comfort	47400.00
0005433181604	9863	Comfort	47400.00
0005434551866	9863	Comfort	47400.00
0005434726905	9863	Comfort	47400.00
0005433235421	9863	Comfort	47400.00
0005435142749	9863	Comfort	47400.00
0005434735743	9863	Comfort	47400.00
0005434727096	9863	Comfort	47400.00
0005433235442	9863	Comfort	47400.00
0005433235399	9863	Comfort	47400.00
0005434726782	9863	Comfort	47400.00
0005432199387	9863	Comfort	47400.00
0005433235408	9863	Comfort	47400.00
0005435142748	9863	Comfort	47400.00
0005434551629	9863	Comfort	47400.00
0005434551827	9863	Comfort	47400.00
0005433181580	9863	Comfort	47400.00
0005434735730	9863	Economy	27900.00
0005433235444	9863	Comfort	47400.00
0005434727375	9863	Economy	27900.00
0005434731213	9863	Economy	27900.00
0005433235454	9863	Economy	27900.00
0005434726751	9863	Economy	27900.00
0005435142617	9863	Economy	27900.00
0005434726832	9863	Economy	27900.00
0005433113579	9863	Economy	27900.00
0005434726668	9863	Economy	27900.00
0005432199386	9863	Economy	27900.00
0005434551736	9863	Economy	27900.00
0005434551839	9863	Economy	27900.00
0005433235406	9863	Economy	27900.00
0005434551910	9863	Economy	27900.00
0005433235413	9863	Economy	27900.00
0005433235447	9863	Economy	27900.00
0005434726667	9863	Economy	27900.00
0005434551795	9863	Economy	27900.00
0005434726723	9863	Economy	27900.00
0005434726650	9863	Economy	27900.00
0005433766715	9863	Economy	27900.00
0005433235405	9863	Economy	27900.00
0005434551656	9863	Economy	27900.00
0005434032116	9863	Economy	27900.00
0005434551654	9863	Economy	27900.00
0005435142698	9863	Economy	27900.00
0005434727387	9863	Economy	27900.00
0005433235443	9863	Economy	27900.00
0005434726486	9863	Economy	27900.00
0005433235433	9863	Economy	27900.00
0005434726322	9863	Economy	27900.00
0005433235427	9863	Economy	27900.00
0005434726682	9863	Economy	27900.00
0005434726357	9863	Economy	27900.00
0005435142616	9863	Economy	27900.00
0005432199383	9863	Economy	27900.00
0005433181595	9863	Economy	27900.00
0005434726922	9863	Economy	27900.00
0005434731220	9863	Economy	27900.00
0005434727162	9863	Economy	27900.00
0005433235422	9863	Economy	27900.00
0005435142675	9863	Economy	27900.00
0005434727369	9863	Economy	27900.00
0005433181582	9863	Economy	27900.00
0005434726893	9863	Economy	27900.00
0005433126934	9863	Economy	27900.00
0005433289985	9863	Economy	27900.00
0005434551911	9863	Economy	27900.00
0005434032115	9863	Economy	27900.00
0005433235424	9863	Economy	27900.00
0005434726969	9863	Economy	27900.00
0005434726997	9863	Economy	27900.00
0005435142776	9863	Economy	27900.00
0005434726830	9863	Economy	27900.00
0005433181585	9863	Economy	27900.00
0005433235414	9863	Economy	27900.00
0005434735726	9863	Economy	30700.00
0005434727042	9863	Economy	30700.00
0005434726869	9863	Economy	27900.00
0005434725974	9863	Economy	27900.00
0005433126933	9863	Economy	30700.00
0005434726967	9863	Economy	27900.00
0005433235423	9863	Economy	30700.00
0005434727052	9863	Economy	27900.00
0005433235404	9863	Economy	27900.00
0005433235458	9863	Economy	27900.00
0005434551867	9863	Economy	27900.00
0005433235419	9863	Economy	27900.00
0005434727265	9863	Economy	27900.00
0005433235434	9863	Economy	27900.00
0005434726812	9863	Economy	27900.00
0005434727367	9863	Economy	27900.00
0005434726935	9863	Economy	27900.00
0005434726738	9863	Economy	27900.00
0005433235409	9863	Economy	27900.00
0005435142680	9863	Economy	27900.00
0005434726591	9863	Economy	27900.00
0005434726749	9863	Economy	27900.00
0005433181587	9863	Economy	27900.00
0005434726765	9863	Economy	27900.00
0005434726770	9863	Economy	27900.00
0005434727050	9863	Economy	27900.00
0005434727210	9863	Economy	27900.00
0005433126935	9863	Economy	27900.00
0005433181584	9863	Economy	27900.00
0005434725976	9863	Economy	27900.00
0005434727123	9863	Economy	27900.00
0005434726463	9863	Economy	27900.00
0005433289987	9863	Economy	27900.00
0005434726452	9863	Economy	27900.00
0005433113578	9863	Economy	27900.00
0005434735729	9863	Economy	27900.00
0005434727331	9863	Economy	27900.00
0005433181592	9863	Economy	27900.00
0005434726547	9863	Economy	27900.00
0005434726884	9863	Economy	27900.00
0005433235402	9863	Economy	27900.00
0005434726711	9863	Economy	27900.00
0005434726733	9863	Economy	27900.00
0005433235420	9863	Economy	27900.00
0005434726774	9863	Economy	27900.00
0005434726478	9863	Economy	27900.00
0005434726906	9863	Economy	27900.00
0005434551899	9863	Economy	27900.00
0005434726745	9863	Economy	27900.00
0005433235449	9863	Economy	27900.00
0005433235440	9863	Economy	27900.00
0005434727157	9863	Economy	27900.00
0005433235441	9863	Economy	27900.00
0005435142697	9863	Economy	27900.00
0005433766714	9863	Economy	27900.00
0005434726892	9863	Economy	27900.00
0005434551662	9863	Economy	27900.00
0005434551660	9863	Economy	27900.00
0005433129362	9863	Economy	27900.00
0005434551533	9863	Economy	27900.00
0005433181583	9863	Economy	27900.00
0005434726499	9863	Economy	27900.00
0005433235411	9863	Economy	27900.00
0005434726735	9863	Economy	27900.00
0005434726630	9863	Economy	27900.00
0005433235425	9863	Economy	27900.00
0005434726885	9863	Economy	27900.00
0005434551661	9863	Economy	27900.00
0005432199381	9863	Economy	27900.00
0005434731228	9863	Economy	27900.00
0005434735727	9863	Economy	27900.00
0005434726940	9863	Economy	27900.00
0005433235436	9863	Economy	27900.00
0005434726862	9863	Economy	27900.00
0005433235456	9863	Economy	27900.00
0005434551628	9863	Economy	27900.00
0005434727046	9863	Economy	27900.00
0005434727499	9863	Economy	27900.00
0005434726697	9863	Economy	27900.00
0005434726325	9863	Economy	27900.00
0005434726698	9863	Economy	27900.00
0005433181591	9863	Economy	27900.00
0005433289986	9863	Economy	27900.00
0005433181594	9863	Economy	27900.00
0005433289988	9863	Economy	27900.00
0005434726792	9863	Economy	27900.00
0005435142736	9863	Economy	27900.00
0005434727189	9863	Economy	27900.00
0005432199385	9863	Economy	27900.00
0005433235452	9863	Economy	27900.00
0005434727166	9863	Economy	27900.00
0005432199384	9863	Economy	27900.00
0005433235460	9863	Economy	27900.00
0005434726873	9863	Economy	27900.00
0005434726734	9863	Economy	27900.00
0005434726886	9863	Economy	27900.00
0005434727503	9863	Economy	27900.00
0005434726813	9863	Economy	27900.00
0005433235438	9863	Economy	27900.00
0005433235457	9863	Economy	27900.00
0005434551846	9863	Economy	27900.00
0005434727388	9863	Economy	27900.00
0005434726639	9863	Economy	27900.00
0005433181586	9863	Economy	27900.00
0005434726779	9863	Economy	27900.00
0005433289989	9863	Economy	27900.00
0005434551994	9863	Economy	27900.00
0005433181598	9863	Economy	30700.00
0005433235418	9863	Economy	30700.00
0005434726939	9863	Economy	30700.00
0005433235432	9863	Economy	30700.00
0005433235417	9863	Economy	27900.00
0005434731202	9863	Economy	27900.00
0005433181593	9863	Economy	27900.00
0005433181601	9863	Economy	27900.00
0005434727151	9863	Economy	27900.00
0005434731221	9863	Economy	27900.00
0005434551912	9863	Economy	27900.00
0005433235412	9863	Economy	27900.00
0005433766713	9863	Economy	27900.00
0005434726802	9863	Economy	27900.00
0005434727158	9863	Economy	27900.00
0005433235439	9863	Economy	27900.00
0005434727211	9863	Economy	27900.00
0005434726768	9863	Economy	27900.00
0005433235431	9863	Economy	27900.00
0005433235429	9863	Economy	27900.00
0005434551861	9863	Economy	27900.00
0005434727174	9863	Economy	27900.00
0005434726544	9863	Economy	27900.00
0005434726297	9863	Economy	27900.00
0005433235428	9863	Economy	27900.00
0005434726819	9863	Economy	27900.00
0005434726512	9863	Economy	27900.00
0005434731200	9863	Economy	27900.00
0005434726462	9863	Economy	27900.00
0005434726701	9863	Economy	27900.00
0005434727084	9863	Economy	27900.00
0005434726236	9863	Economy	27900.00
0005434302509	9863	Economy	27900.00
0005434726394	9863	Economy	27900.00
0005434726968	9863	Economy	27900.00
0005433235462	9863	Economy	27900.00
0005434727164	9863	Economy	27900.00
0005434725975	9863	Economy	27900.00
0005433235401	9863	Economy	27900.00
0005434551816	9863	Economy	27900.00
0005434726721	9863	Economy	27900.00
0005433181596	9863	Economy	27900.00
0005434726628	9863	Economy	27900.00
0005433235403	9863	Economy	27900.00
0005434726337	9863	Economy	27900.00
0005434726629	9863	Economy	27900.00
0005434726750	9863	Economy	27900.00
0005433766716	9863	Economy	27900.00
0005433235426	9863	Economy	27900.00
0005434726327	9863	Economy	27900.00
0005434726739	9863	Economy	27900.00
0005433181599	9863	Economy	27900.00
0005434551883	9863	Economy	27900.00
0005434551544	9863	Economy	27900.00
0005434727165	9863	Economy	27900.00
0005434726545	9863	Economy	27900.00
0005432199382	9863	Economy	27900.00
0005434726003	9863	Economy	27900.00
0005433235445	9863	Economy	27900.00
0005434726569	9863	Economy	27900.00
0005434735742	9863	Economy	27900.00
0005434726492	9863	Economy	27900.00
0005434726326	9863	Economy	27900.00
0005433235407	9863	Economy	27900.00
0005433129364	9863	Economy	27900.00
0005434727085	9863	Economy	27900.00
0005434726696	9863	Economy	27900.00
0005433289990	9863	Economy	27900.00
0005434735728	9863	Economy	27900.00
0005434727154	9863	Economy	27900.00
0005434726561	9863	Economy	27900.00
0005434726780	9863	Economy	27900.00
0005434727204	9863	Economy	27900.00
0005433181603	9863	Economy	27900.00
0005434726362	9863	Economy	27900.00
0005434727168	9863	Economy	27900.00
0005433235410	9863	Economy	27900.00
0005434551745	9863	Economy	27900.00
0005434731201	9863	Economy	27900.00
0005434726771	9863	Economy	27900.00
0005433181605	9863	Economy	27900.00
0005434551862	9863	Economy	27900.00
0005433235448	9863	Economy	27900.00
0005433126931	9863	Economy	27900.00
0005434726683	9863	Economy	27900.00
0005434726548	9863	Economy	27900.00
0005433235450	9863	Economy	27900.00
0005433129365	9863	Economy	27900.00
0005434726904	9863	Economy	27900.00
0005434551817	9863	Economy	27900.00
0005433129366	9863	Economy	27900.00
0005434552026	9863	Economy	27900.00
0005435214062	7725	Business	42100.00
0005432530465	7725	Business	42100.00
0005434068910	7725	Business	42100.00
0005435214367	7725	Business	42100.00
0005432530481	7725	Business	42100.00
0005432530538	7725	Business	42100.00
0005432530498	7725	Business	42100.00
0005432530596	7725	Business	42100.00
0005435214206	7725	Business	42100.00
0005432535926	7725	Business	42100.00
0005432530565	7725	Business	42100.00
0005435214304	7725	Business	42100.00
0005432530470	7725	Business	42100.00
0005435214116	7725	Business	42100.00
0005432069935	7725	Business	42100.00
0005435214046	7725	Business	42100.00
0005435213973	7725	Business	42100.00
0005432530560	7725	Business	42100.00
0005432530512	7725	Business	42100.00
0005434068931	7725	Business	42100.00
0005434068978	7725	Business	42100.00
0005435214439	7725	Business	42100.00
0005432530533	7725	Comfort	23900.00
0005435213927	7725	Comfort	23900.00
0005434068945	7725	Comfort	23900.00
0005434068922	7725	Comfort	23900.00
0005434068961	7725	Comfort	23900.00
0005432530510	7725	Comfort	23900.00
0005432530493	7725	Comfort	23900.00
0005434068968	7725	Comfort	23900.00
0005432428997	7725	Comfort	23900.00
0005432530569	7725	Comfort	23900.00
0005432530550	7725	Comfort	23900.00
0005435214091	7725	Comfort	23900.00
0005434068936	7725	Comfort	23900.00
0005432530540	7725	Comfort	23900.00
0005435214238	7725	Comfort	23900.00
0005435214358	7725	Comfort	23900.00
0005435214267	7725	Comfort	23900.00
0005432530485	7725	Comfort	23900.00
0005435214228	7725	Comfort	23900.00
0005434068928	7725	Comfort	23900.00
0005434068911	7725	Comfort	23900.00
0005432530466	7725	Comfort	23900.00
0005432530527	7725	Comfort	23900.00
0005434068937	7725	Comfort	23900.00
0005432533346	7725	Comfort	23900.00
0005434068953	7725	Comfort	23900.00
0005432530551	7725	Comfort	23900.00
0005435214296	7725	Comfort	23900.00
0005435214266	7725	Comfort	23900.00
0005432530581	7725	Comfort	23900.00
0005432530594	7725	Comfort	23900.00
0005432530530	7725	Comfort	23900.00
0005432530535	7725	Comfort	23900.00
0005434068933	7725	Comfort	23900.00
0005435214369	7725	Comfort	23900.00
0005434068963	7725	Economy	14000.00
0005432530592	7725	Comfort	23900.00
0005434068980	7725	Economy	14000.00
0005435214282	7725	Economy	14000.00
0005435214195	7725	Economy	14000.00
0005432530492	7725	Economy	14000.00
0005434068977	7725	Economy	14000.00
0005432069942	7725	Economy	14000.00
0005432530584	7725	Economy	14000.00
0005432530549	7725	Economy	14000.00
0005432530567	7725	Economy	14000.00
0005432530572	7725	Economy	14000.00
0005434068924	7725	Economy	14000.00
0005435214152	7725	Economy	14000.00
0005435214245	7725	Economy	14000.00
0005432530543	7725	Economy	14000.00
0005434068943	7725	Economy	14000.00
0005434068919	7725	Economy	14000.00
0005434068920	7725	Economy	14000.00
0005432530537	7725	Economy	14000.00
0005432530506	7725	Economy	14000.00
0005435214143	7725	Economy	14000.00
0005435214145	7725	Economy	14000.00
0005435214476	7725	Economy	14000.00
0005435214233	7725	Economy	14000.00
0005432530464	7725	Economy	14000.00
0005434068965	7725	Economy	14000.00
0005435725639	7725	Economy	14000.00
0005432069941	7725	Economy	14000.00
0005435214314	7725	Economy	14000.00
0005434068912	7725	Economy	14000.00
0005434068951	7725	Economy	14000.00
0005435214297	7725	Economy	14000.00
0005432069943	7725	Economy	14000.00
0005434068935	7725	Economy	14000.00
0005432530473	7725	Economy	14000.00
0005432530478	7725	Economy	14000.00
0005432069940	7725	Economy	14000.00
0005432530505	7725	Economy	14000.00
0005432530524	7725	Economy	14000.00
0005432530525	7725	Economy	14000.00
0005435214070	7725	Economy	14000.00
0005432530487	7725	Economy	14000.00
0005435213972	7725	Economy	14000.00
0005432069939	7725	Economy	14000.00
0005432530475	7725	Economy	14000.00
0005435214359	7725	Economy	14000.00
0005432530534	7725	Economy	14000.00
0005434068946	7725	Economy	14000.00
0005432069944	7725	Economy	14000.00
0005432069936	7725	Economy	14000.00
0005432150348	7725	Economy	14000.00
0005432530583	7725	Economy	14000.00
0005432537098	7725	Economy	14000.00
0005434068918	7725	Economy	14000.00
0005432530554	7725	Economy	14000.00
0005432530494	7725	Economy	14000.00
0005435214265	7725	Economy	15400.00
0005434068913	7725	Economy	14000.00
0005434068940	7725	Economy	15400.00
0005432530515	7725	Economy	14000.00
0005434068950	7725	Economy	14000.00
0005432069933	7725	Economy	14000.00
0005435214079	7725	Economy	15400.00
0005432530587	7725	Economy	14000.00
0005432530593	7725	Economy	15400.00
0005434068974	7725	Economy	14000.00
0005435214305	7725	Economy	14000.00
0005435214444	7725	Economy	14000.00
0005432530521	7725	Economy	14000.00
0005432530562	7725	Economy	14000.00
0005432530480	7725	Economy	14000.00
0005434068954	7725	Economy	14000.00
0005435214013	7725	Economy	14000.00
0005432150345	7725	Economy	14000.00
0005435214456	7725	Economy	14000.00
0005432530580	7725	Economy	14000.00
0005434068914	7725	Economy	14000.00
0005432530488	7725	Economy	14000.00
0005435214003	7725	Economy	14000.00
0005435214150	7725	Economy	14000.00
0005434068942	7725	Economy	14000.00
0005432150344	7725	Economy	14000.00
0005435214409	7725	Economy	14000.00
0005432530499	7725	Economy	14000.00
0005432530491	7725	Economy	14000.00
0005432530496	7725	Economy	14000.00
0005432530582	7725	Economy	14000.00
0005432530479	7725	Economy	14000.00
0005435214012	7725	Economy	14000.00
0005432530556	7725	Economy	14000.00
0005432530500	7725	Economy	14000.00
0005434068939	7725	Economy	14000.00
0005434068960	7725	Economy	14000.00
0005435214283	7725	Economy	14000.00
0005435214275	7725	Economy	14000.00
0005434068934	7725	Economy	14000.00
0005434068917	7725	Economy	14000.00
0005435214121	7725	Economy	14000.00
0005432530463	7725	Economy	14000.00
0005432530591	7725	Economy	14000.00
0005435214246	7725	Economy	14000.00
0005432530514	7725	Economy	14000.00
0005435214445	7725	Economy	14000.00
0005432530541	7725	Economy	14000.00
0005432530570	7725	Economy	14000.00
0005432530483	7725	Economy	14000.00
0005432530511	7725	Economy	14000.00
0005435214577	7725	Economy	14000.00
0005434068932	7725	Economy	14000.00
0005435214323	7725	Economy	14000.00
0005435214559	7725	Economy	14000.00
0005432530523	7725	Economy	14000.00
0005432530509	7725	Economy	14000.00
0005435214144	7725	Economy	14000.00
0005435214193	7725	Economy	14000.00
0005435214225	7725	Economy	14000.00
0005435214393	7725	Economy	14000.00
0005432069934	7725	Economy	14000.00
0005432530548	7725	Economy	14000.00
0005432530542	7725	Economy	14000.00
0005432530578	7725	Economy	14000.00
0005434068970	7725	Economy	14000.00
0005433656702	7725	Economy	14000.00
0005432530495	7725	Economy	14000.00
0005432069937	7725	Economy	14000.00
0005432530585	7725	Economy	14000.00
0005432530476	7725	Economy	14000.00
0005432530536	7725	Economy	14000.00
0005435214357	7725	Economy	14000.00
0005435214122	7725	Economy	14000.00
0005434068972	7725	Economy	14000.00
0005432530507	7725	Economy	14000.00
0005434068982	7725	Economy	14000.00
0005432530513	7725	Economy	14000.00
0005434068926	7725	Economy	14000.00
0005435214601	7725	Economy	14000.00
0005434068923	7725	Economy	14000.00
0005434068975	7725	Economy	14000.00
0005434068976	7725	Economy	14000.00
0005434068916	7725	Economy	14000.00
0005434068921	7725	Economy	14000.00
0005434068952	7725	Economy	14000.00
0005432428995	7725	Economy	14000.00
0005433656710	7725	Economy	14000.00
0005434068929	7725	Economy	14000.00
0005432530557	7725	Economy	14000.00
0005432530503	7725	Economy	14000.00
0005432530555	7725	Economy	14000.00
0005434068949	7725	Economy	14000.00
0005432530563	7725	Economy	14000.00
0005432530468	7725	Economy	14000.00
0005432530571	7725	Economy	14000.00
0005434068971	7725	Economy	14000.00
0005432530576	7725	Economy	14000.00
0005432530532	7725	Economy	14000.00
0005434068962	7725	Economy	14000.00
0005432530489	7725	Economy	14000.00
0005432530520	7725	Economy	14000.00
0005434068966	7725	Economy	14000.00
0005432530586	7725	Economy	14000.00
0005434068948	7725	Economy	14000.00
0005432069931	7725	Economy	14000.00
0005434068979	7725	Economy	14000.00
0005432533348	7725	Economy	14000.00
0005434068957	7725	Economy	14000.00
0005432530595	7725	Economy	15400.00
0005435214441	7725	Economy	15400.00
0005432530471	7725	Economy	15400.00
0005432530531	7725	Economy	15400.00
0005435214583	7725	Economy	14000.00
0005432530564	7725	Economy	14000.00
0005432530517	7725	Economy	14000.00
0005434068973	7725	Economy	14000.00
0005432530558	7725	Economy	14000.00
0005432530526	7725	Economy	14000.00
0005432530573	7725	Economy	14000.00
0005432530508	7725	Economy	14000.00
0005432535930	7725	Economy	14000.00
0005432530504	7725	Economy	14000.00
0005432150351	7725	Economy	14000.00
0005432530559	7725	Economy	14000.00
0005434068959	7725	Economy	14000.00
0005435725633	7725	Economy	14000.00
0005434068967	7725	Economy	14000.00
0005434068915	7725	Economy	14000.00
0005432535928	7725	Economy	14000.00
0005432428996	7725	Economy	14000.00
0005434068925	7725	Economy	14000.00
0005432530588	7725	Economy	14000.00
0005432530568	7725	Economy	14000.00
0005432530490	7725	Economy	14000.00
0005435214176	7725	Economy	14000.00
0005432069938	7725	Economy	14000.00
0005434068938	7725	Economy	14000.00
0005432530553	7725	Economy	14000.00
0005432530579	7725	Economy	14000.00
0005432530516	7725	Economy	14000.00
0005434068927	7725	Economy	14000.00
0005435214288	7725	Economy	14000.00
0005432535929	7725	Economy	14000.00
0005432530482	7725	Economy	14000.00
0005432530472	7725	Economy	14000.00
0005435214301	7725	Economy	14000.00
0005432530469	7725	Economy	14000.00
0005432533347	7725	Economy	14000.00
0005432530552	7725	Economy	14000.00
0005432530522	7725	Economy	14000.00
0005433656711	7725	Economy	14000.00
0005432530547	7725	Economy	14000.00
0005432150350	7725	Economy	14000.00
0005435214410	7725	Economy	14000.00
0005432530528	7725	Economy	14000.00
0005432530539	7725	Economy	14000.00
0005432530575	7725	Economy	14000.00
0005432530577	7725	Economy	14000.00
0005432530544	7725	Economy	14000.00
0005433656700	7725	Economy	14000.00
0005434068944	7725	Economy	14000.00
0005432530502	7725	Economy	14000.00
0005432530477	7725	Economy	14000.00
0005432530590	7725	Economy	14000.00
0005435214576	7725	Economy	14000.00
0005435214477	7725	Economy	14000.00
0005432530486	7725	Economy	14000.00
0005434068958	7725	Economy	14000.00
0005435214324	7725	Economy	14000.00
0005435214078	7725	Economy	14000.00
0005435214377	7725	Economy	14000.00
0005435214232	7725	Economy	14000.00
0005434068964	7725	Economy	14000.00
0005435214554	7725	Economy	14000.00
0005432530467	7725	Economy	14000.00
0005434068956	7725	Economy	14000.00
0005432530529	7725	Economy	14000.00
0005432530589	7725	Economy	14000.00
0005432069932	7725	Economy	14000.00
0005435213926	7725	Economy	14000.00
0005432530561	7725	Economy	14000.00
0005432530497	7725	Economy	14000.00
0005432150349	7725	Economy	14000.00
0005432530519	7725	Economy	14000.00
0005435214438	7725	Economy	14000.00
0005432530501	7725	Economy	14000.00
0005435214527	7725	Economy	14000.00
0005434068930	7725	Economy	14000.00
0005434068947	7725	Economy	14000.00
0005432530545	7725	Economy	14000.00
0005432530518	7725	Economy	14000.00
0005432535927	7725	Economy	14000.00
0005435214348	7725	Economy	14000.00
0005432530474	7725	Economy	14000.00
0005434068955	7725	Economy	14000.00
0005434068981	7725	Economy	14000.00
0005432150346	7725	Economy	14000.00
0005432537099	7725	Economy	14000.00
0005432150347	7725	Economy	14000.00
0005434068969	7725	Economy	14000.00
0005433656699	7725	Economy	14000.00
0005435214468	7725	Economy	14000.00
0005432530546	7725	Economy	14000.00
0005434068941	7725	Economy	14000.00
0005435214248	7725	Economy	14000.00
0005432530566	7725	Economy	14000.00
0005432530484	7725	Economy	14000.00
0005432530574	7725	Economy	14000.00
0005434245343	5325	Business	43100.00
0005434344929	5325	Business	43100.00
0005434245269	5325	Business	43100.00
0005435319655	5325	Business	43100.00
0005435615803	5325	Business	43100.00
0005435615802	5325	Business	43100.00
0005434245354	5325	Business	43100.00
0005434573623	5325	Business	43100.00
0005434344912	5325	Business	43100.00
0005435615860	5325	Business	43100.00
0005435615883	5325	Business	43100.00
0005435615801	5325	Business	43100.00
0005435425819	5325	Business	43100.00
0005435615872	5325	Business	43100.00
0005435615893	5325	Business	43100.00
0005435425672	5325	Business	43100.00
0005435615900	5325	Business	43100.00
0005435425472	5325	Business	43100.00
0005435615867	5325	Business	43100.00
0005435615770	5325	Business	43100.00
0005435615834	5325	Business	43100.00
0005435615807	5325	Business	43100.00
0005435615897	5325	Business	43100.00
0005435615768	5325	Business	43100.00
0005435615813	5325	Business	43100.00
0005435425591	5325	Business	43100.00
0005435615819	5325	Business	43100.00
0005434245238	5325	Comfort	24400.00
0005435617238	5325	Comfort	24400.00
0005435425895	5325	Comfort	24400.00
0005432133508	5325	Comfort	24400.00
0005435615772	5325	Comfort	24400.00
0005435042885	5325	Comfort	24400.00
0005435615805	5325	Comfort	24400.00
0005432133511	5325	Comfort	24400.00
0005432133512	5325	Comfort	24400.00
0005434245344	5325	Comfort	24400.00
0005435615894	5325	Comfort	24400.00
0005435425812	5325	Comfort	24400.00
0005435425588	5325	Comfort	24400.00
0005434573629	5325	Comfort	24400.00
0005435615895	5325	Comfort	24400.00
0005435615869	5325	Comfort	24400.00
0005434245270	5325	Comfort	24400.00
0005435555410	5325	Comfort	24400.00
0005435097401	5325	Comfort	24400.00
0005435615843	5325	Comfort	24400.00
0005435425446	5325	Comfort	24400.00
0005435615848	5325	Comfort	24400.00
0005435491480	5325	Comfort	24400.00
0005435617178	5325	Comfort	24400.00
0005435425551	5325	Comfort	24400.00
0005435615891	5325	Comfort	24400.00
0005435615832	5325	Comfort	24400.00
0005435615776	5325	Comfort	24400.00
0005435319670	5325	Comfort	24400.00
0005435615800	5325	Comfort	24400.00
0005435425326	5325	Comfort	24400.00
0005434344924	5325	Comfort	24400.00
0005435617176	5325	Comfort	24400.00
0005435302233	5325	Comfort	24400.00
0005434344903	5325	Comfort	24400.00
0005435425590	5325	Comfort	24400.00
0005435615780	5325	Comfort	24400.00
0005435425646	5325	Comfort	24400.00
0005435425466	5325	Comfort	24400.00
0005435425738	5325	Comfort	24400.00
0005435615810	5325	Comfort	24400.00
0005432133507	5325	Comfort	24400.00
0005435615829	5325	Comfort	24400.00
0005435615825	5325	Economy	14400.00
0005435615773	5325	Economy	14400.00
0005432133500	5325	Economy	14400.00
0005434344918	5325	Economy	14400.00
0005434573627	5325	Economy	14400.00
0005435615850	5325	Economy	14400.00
0005434245346	5325	Economy	14400.00
0005435615896	5325	Economy	14400.00
0005435615784	5325	Economy	14400.00
0005435425418	5325	Economy	14400.00
0005435425896	5325	Economy	14400.00
0005434344920	5325	Economy	14400.00
0005435615783	5325	Economy	14400.00
0005434344919	5325	Economy	14400.00
0005435615854	5325	Economy	14400.00
0005435425402	5325	Economy	14400.00
0005435615868	5325	Economy	14400.00
0005435615816	5325	Economy	14400.00
0005434344905	5325	Economy	14400.00
0005432133504	5325	Economy	14400.00
0005435615889	5325	Economy	14400.00
0005435615774	5325	Economy	14400.00
0005433719171	5325	Economy	14400.00
0005434344911	5325	Economy	14400.00
0005435319649	5325	Economy	14400.00
0005435615797	5325	Economy	14400.00
0005435490298	5325	Economy	14400.00
0005435615877	5325	Economy	14400.00
0005435490300	5325	Economy	14400.00
0005435615769	5325	Economy	14400.00
0005434573622	5325	Economy	14400.00
0005435425709	5325	Economy	14400.00
0005435615852	5325	Economy	14400.00
0005434245276	5325	Economy	14400.00
0005435425938	5325	Economy	14400.00
0005435615886	5325	Economy	14400.00
0005435615788	5325	Economy	14400.00
0005434344896	5325	Economy	14400.00
0005435615859	5325	Economy	14400.00
0005432133502	5325	Economy	14400.00
0005435319669	5325	Economy	14400.00
0005432133509	5325	Economy	14400.00
0005434245353	5325	Economy	14400.00
0005434344902	5325	Economy	14400.00
0005434245096	5325	Economy	14400.00
0005435302253	5325	Economy	14400.00
0005435615870	5325	Economy	14400.00
0005435425327	5325	Economy	14400.00
0005435305035	5325	Economy	14400.00
0005434344907	5325	Economy	14400.00
0005435425539	5325	Economy	14400.00
0005434344900	5325	Economy	14400.00
0005435097397	5325	Economy	14400.00
0005434344909	5325	Economy	14400.00
0005435615820	5325	Economy	14400.00
0005434344923	5325	Economy	14400.00
0005435615824	5325	Economy	14400.00
0005435097403	5325	Economy	14400.00
0005435425401	5325	Economy	14400.00
0005435319674	5325	Economy	15800.00
0005435425659	5325	Economy	14400.00
0005435425540	5325	Economy	15800.00
0005435615888	5325	Economy	15800.00
0005435097396	5325	Economy	14400.00
0005434245347	5325	Economy	14400.00
0005434344908	5325	Economy	15800.00
0005432841033	5325	Economy	15800.00
0005435425730	5325	Economy	15800.00
0005435425750	5325	Economy	14400.00
0005435615871	5325	Economy	14400.00
0005434245355	5325	Economy	14400.00
0005435615855	5325	Economy	14400.00
0005435615836	5325	Economy	14400.00
0005435615881	5325	Economy	14400.00
0005435380325	5325	Economy	14400.00
0005433719178	5325	Economy	14400.00
0005435319711	5325	Economy	14400.00
0005434245214	5325	Economy	14400.00
0005435555408	5325	Economy	14400.00
0005435490299	5325	Economy	14400.00
0005435615786	5325	Economy	14400.00
0005434245305	5325	Economy	14400.00
0005435615781	5325	Economy	14400.00
0005435615828	5325	Economy	14400.00
0005432133503	5325	Economy	14400.00
0005434344922	5325	Economy	14400.00
0005435491481	5325	Economy	14400.00
0005435425528	5325	Economy	14400.00
0005435615835	5325	Economy	14400.00
0005434344927	5325	Economy	14400.00
0005435615876	5325	Economy	14400.00
0005435615880	5325	Economy	14400.00
0005434573633	5325	Economy	14400.00
0005435615858	5325	Economy	14400.00
0005435425267	5325	Economy	14400.00
0005435615862	5325	Economy	14400.00
0005432133505	5325	Economy	14400.00
0005435425760	5325	Economy	14400.00
0005435097395	5325	Economy	14400.00
0005435615887	5325	Economy	14400.00
0005434573630	5325	Economy	14400.00
0005435615799	5325	Economy	14400.00
0005435615790	5325	Economy	14400.00
0005435615873	5325	Economy	14400.00
0005435425381	5325	Economy	14400.00
0005434245093	5325	Economy	14400.00
0005435425556	5325	Economy	14400.00
0005435615892	5325	Economy	14400.00
0005435305033	5325	Economy	14400.00
0005435615798	5325	Economy	14400.00
0005435615874	5325	Economy	14400.00
0005432133506	5325	Economy	14400.00
0005435097400	5325	Economy	14400.00
0005434344895	5325	Economy	14400.00
0005435615826	5325	Economy	14400.00
0005434245224	5325	Economy	14400.00
0005435425740	5325	Economy	14400.00
0005435615865	5325	Economy	14400.00
0005435425890	5325	Economy	14400.00
0005435425420	5325	Economy	14400.00
0005435615823	5325	Economy	14400.00
0005435425852	5325	Economy	14400.00
0005435425309	5325	Economy	14400.00
0005435305040	5325	Economy	14400.00
0005435615861	5325	Economy	14400.00
0005435615839	5325	Economy	14400.00
0005434245266	5325	Economy	14400.00
0005435425473	5325	Economy	14400.00
0005435615830	5325	Economy	14400.00
0005435615818	5325	Economy	14400.00
0005435615766	5325	Economy	14400.00
0005435425474	5325	Economy	14400.00
0005435615879	5325	Economy	14400.00
0005435490297	5325	Economy	14400.00
0005435617177	5325	Economy	14400.00
0005435615890	5325	Economy	14400.00
0005435615811	5325	Economy	14400.00
0005434344928	5325	Economy	14400.00
0005435425592	5325	Economy	14400.00
0005435615812	5325	Economy	14400.00
0005435302232	5325	Economy	14400.00
0005435615771	5325	Economy	14400.00
0005435615785	5325	Economy	14400.00
0005435615864	5325	Economy	14400.00
0005435425759	5325	Economy	14400.00
0005434245306	5325	Economy	14400.00
0005435615778	5325	Economy	14400.00
0005434344897	5325	Economy	14400.00
0005432133513	5325	Economy	14400.00
0005435097399	5325	Economy	14400.00
0005434573631	5325	Economy	14400.00
0005435425833	5325	Economy	14400.00
0005434344894	5325	Economy	14400.00
0005434245298	5325	Economy	14400.00
0005435615782	5325	Economy	14400.00
0005435615856	5325	Economy	14400.00
0005435425838	5325	Economy	14400.00
0005435305031	5325	Economy	14400.00
0005435380345	5325	Economy	14400.00
0005435615792	5325	Economy	14400.00
0005434344925	5325	Economy	14400.00
0005435615831	5325	Economy	14400.00
0005435097402	5325	Economy	14400.00
0005435615796	5325	Economy	14400.00
0005434573624	5325	Economy	14400.00
0005435425569	5325	Economy	14400.00
0005435615821	5325	Economy	14400.00
0005434573625	5325	Economy	14400.00
0005435615817	5325	Economy	14400.00
0005435615857	5325	Economy	14400.00
0005434245223	5325	Economy	15800.00
0005434344898	5325	Economy	15800.00
0005432133498	5325	Economy	15800.00
0005434573628	5325	Economy	15800.00
0005434344910	5325	Economy	15800.00
0005435425649	5325	Economy	15800.00
0005435615815	5325	Economy	14400.00
0005435615777	5325	Economy	14400.00
0005435615866	5325	Economy	14400.00
0005434573632	5325	Economy	14400.00
0005435615878	5325	Economy	14400.00
0005434344906	5325	Economy	14400.00
0005435302234	5325	Economy	14400.00
0005434344916	5325	Economy	14400.00
0005435615827	5325	Economy	14400.00
0005435615814	5325	Economy	14400.00
0005432047623	5325	Economy	14400.00
0005432047624	5325	Economy	14400.00
0005435615875	5325	Economy	14400.00
0005434344915	5325	Economy	14400.00
0005435615884	5325	Economy	14400.00
0005435425739	5325	Economy	14400.00
0005435491482	5325	Economy	14400.00
0005435425708	5325	Economy	14400.00
0005435425410	5325	Economy	14400.00
0005435615804	5325	Economy	14400.00
0005434245256	5325	Economy	14400.00
0005434344917	5325	Economy	14400.00
0005435615806	5325	Economy	14400.00
0005432841032	5325	Economy	14400.00
0005432133499	5325	Economy	14400.00
0005434573626	5325	Economy	14400.00
0005435319657	5325	Economy	14400.00
0005435380343	5325	Economy	14400.00
0005435042868	5325	Economy	14400.00
0005434344921	5325	Economy	14400.00
0005435319710	5325	Economy	14400.00
0005435425729	5325	Economy	14400.00
0005435615849	5325	Economy	14400.00
0005435615863	5325	Economy	14400.00
0005434344901	5325	Economy	14400.00
0005435615767	5325	Economy	14400.00
0005435615898	5325	Economy	14400.00
0005435615794	5325	Economy	14400.00
0005435615838	5325	Economy	14400.00
0005435615837	5325	Economy	14400.00
0005435615853	5325	Economy	14400.00
0005435425583	5325	Economy	14400.00
0005435615795	5325	Economy	14400.00
0005435615847	5325	Economy	14400.00
0005435615842	5325	Economy	14400.00
0005435615899	5325	Economy	14400.00
0005435615789	5325	Economy	14400.00
0005435615882	5325	Economy	14400.00
0005434344899	5325	Economy	14400.00
0005434344913	5325	Economy	14400.00
0005435425485	5325	Economy	14400.00
0005434245309	5325	Economy	14400.00
0005435425570	5325	Economy	14400.00
0005433719170	5325	Economy	14400.00
0005432133501	5325	Economy	14400.00
0005435380355	5325	Economy	14400.00
0005434344904	5325	Economy	14400.00
0005435615851	5325	Economy	14400.00
0005435097404	5325	Economy	14400.00
0005434573634	5325	Economy	14400.00
0005435615841	5325	Economy	14400.00
0005435425409	5325	Economy	14400.00
0005435615775	5325	Economy	14400.00
0005435615845	5325	Economy	14400.00
0005435425749	5325	Economy	14400.00
0005435615844	5325	Economy	14400.00
0005435615885	5325	Economy	14400.00
0005433719172	5325	Economy	14400.00
0005434344926	5325	Economy	14400.00
0005435615809	5325	Economy	14400.00
0005435555409	5325	Economy	14400.00
0005435615787	5325	Economy	14400.00
0005435425408	5325	Economy	14400.00
0005435380344	5325	Economy	14400.00
0005435425465	5325	Economy	14400.00
0005433719169	5325	Economy	14400.00
0005433719177	5325	Economy	14400.00
0005435615791	5325	Economy	14400.00
0005435319680	5325	Economy	14400.00
0005435615822	5325	Economy	14400.00
0005434245345	5325	Economy	14400.00
0005435425775	5325	Economy	14400.00
0005435615793	5325	Economy	14400.00
0005435615840	5325	Economy	14400.00
0005435319700	5325	Economy	14400.00
0005435615808	5325	Economy	14400.00
0005435380341	5325	Economy	14400.00
0005435097398	5325	Economy	14400.00
0005432133510	5325	Economy	14400.00
0005435425447	5325	Economy	14400.00
0005434344914	5325	Economy	14400.00
0005435615846	5325	Economy	14400.00
0005435042875	5325	Economy	14400.00
0005435617179	5325	Economy	14400.00
0005435615833	5325	Economy	14400.00
0005435425891	5325	Economy	14400.00
0005435615765	5325	Economy	14400.00
0005435425527	5325	Economy	14400.00
0005434344893	5325	Economy	14400.00
0005435615779	5325	Economy	14400.00
0005435426157	10908	Business	43100.00
0005435426151	10908	Business	43100.00
0005434245548	10908	Business	43100.00
0005434344625	10908	Business	43100.00
0005434573468	10908	Business	43100.00
0005435426115	10908	Business	43100.00
0005432841055	10908	Business	43100.00
0005435426178	10908	Business	43100.00
0005435615031	10908	Business	43100.00
0005435097295	10908	Business	43100.00
0005434245550	10908	Business	43100.00
0005435615091	10908	Business	43100.00
0005434344577	10908	Business	43100.00
0005435614512	10908	Business	43100.00
0005434344505	10908	Business	43100.00
0005434344510	10908	Business	43100.00
0005433719208	10908	Business	43100.00
0005435380388	10908	Business	43100.00
0005435426141	10908	Business	43100.00
0005435614340	10908	Business	43100.00
0005435614898	10908	Business	43100.00
0005435426181	10908	Business	43100.00
0005434344431	10908	Business	43100.00
0005435426123	10908	Business	43100.00
0005435426136	10908	Business	43100.00
0005435426165	10908	Business	43100.00
0005434344527	10908	Business	43100.00
0005435319744	10908	Comfort	24400.00
0005434573438	10908	Business	43100.00
0005435614707	10908	Comfort	24400.00
0005435614922	10908	Comfort	24400.00
0005435426172	10908	Comfort	24400.00
0005435614819	10908	Comfort	24400.00
0005434573422	10908	Comfort	24400.00
0005435319747	10908	Comfort	24400.00
0005435614861	10908	Comfort	24400.00
0005434344676	10908	Comfort	24400.00
0005434245542	10908	Comfort	24400.00
0005435614645	10908	Comfort	24400.00
0005435614879	10908	Comfort	24400.00
0005435426137	10908	Comfort	24400.00
0005432363478	10908	Comfort	24400.00
0005435491467	10908	Comfort	24400.00
0005435615006	10908	Comfort	24400.00
0005435426154	10908	Comfort	24400.00
0005435614647	10908	Comfort	24400.00
0005435614864	10908	Comfort	24400.00
0005434344432	10908	Comfort	24400.00
0005435426129	10908	Comfort	24400.00
0005435615108	10908	Comfort	24400.00
0005432363480	10908	Comfort	24400.00
0005435426149	10908	Comfort	24400.00
0005435615072	10908	Comfort	24400.00
0005435614617	10908	Comfort	24400.00
0005435614888	10908	Comfort	24400.00
0005435614604	10908	Comfort	24400.00
0005435614646	10908	Comfort	24400.00
0005435615055	10908	Comfort	24400.00
0005434573469	10908	Comfort	24400.00
0005434344675	10908	Comfort	24400.00
0005434344694	10908	Comfort	24400.00
0005434656594	10908	Comfort	24400.00
0005434245562	10908	Comfort	24400.00
0005434573488	10908	Comfort	24400.00
0005434344387	10908	Comfort	24400.00
0005435426174	10908	Comfort	24400.00
0005435426161	10908	Comfort	24400.00
0005435614869	10908	Comfort	24400.00
0005434245560	10908	Comfort	24400.00
0005434245556	10908	Economy	14400.00
0005435426143	10908	Economy	14400.00
0005435615029	10908	Economy	14400.00
0005434344492	10908	Economy	14400.00
0005435426162	10908	Economy	14400.00
0005435426114	10908	Economy	14400.00
0005435614719	10908	Economy	14400.00
0005434344463	10908	Economy	14400.00
0005435614967	10908	Economy	14400.00
0005435614805	10908	Economy	14400.00
0005435615109	10908	Economy	14400.00
0005435380386	10908	Economy	14400.00
0005435614708	10908	Economy	14400.00
0005435319748	10908	Economy	14400.00
0005435615027	10908	Economy	14400.00
0005435614737	10908	Economy	14400.00
0005435614406	10908	Economy	14400.00
0005435491451	10908	Economy	14400.00
0005435614963	10908	Economy	14400.00
0005434245558	10908	Economy	14400.00
0005432165190	10908	Economy	14400.00
0005434245539	10908	Economy	14400.00
0005435615103	10908	Economy	14400.00
0005432841054	10908	Economy	14400.00
0005435426155	10908	Economy	14400.00
0005435426169	10908	Economy	14400.00
0005435426134	10908	Economy	14400.00
0005435614833	10908	Economy	14400.00
0005432363479	10908	Economy	14400.00
0005435614455	10908	Economy	14400.00
0005434344528	10908	Economy	14400.00
0005435097289	10908	Economy	14400.00
0005435042897	10908	Economy	14400.00
0005434344468	10908	Economy	14400.00
0005435614910	10908	Economy	14400.00
0005435097288	10908	Economy	14400.00
0005435097293	10908	Economy	14400.00
0005435426125	10908	Economy	14400.00
0005434344552	10908	Economy	14400.00
0005434573509	10908	Economy	14400.00
0005435097257	10908	Economy	14400.00
0005435380389	10908	Economy	14400.00
0005435426150	10908	Economy	14400.00
0005432165186	10908	Economy	14400.00
0005432363481	10908	Economy	14400.00
0005435614924	10908	Economy	14400.00
0005435614339	10908	Economy	14400.00
0005433719209	10908	Economy	14400.00
0005434344512	10908	Economy	14400.00
0005434344635	10908	Economy	14400.00
0005435614730	10908	Economy	14400.00
0005435614554	10908	Economy	14400.00
0005434245555	10908	Economy	14400.00
0005435426167	10908	Economy	14400.00
0005435614964	10908	Economy	14400.00
0005432165191	10908	Economy	14400.00
0005435614796	10908	Economy	14400.00
0005435426117	10908	Economy	14400.00
0005434344518	10908	Economy	14400.00
0005434245552	10908	Economy	14400.00
0005435614755	10908	Economy	14400.00
0005435615119	10908	Economy	14400.00
0005435614860	10908	Economy	14400.00
0005435614650	10908	Economy	15800.00
0005435614820	10908	Economy	15800.00
0005434245543	10908	Economy	14400.00
0005435615067	10908	Economy	15800.00
0005435426177	10908	Economy	14400.00
0005435319742	10908	Economy	14400.00
0005435615227	10908	Economy	15800.00
0005432165184	10908	Economy	14400.00
0005434344448	10908	Economy	15800.00
0005435614682	10908	Economy	14400.00
0005435042895	10908	Economy	15800.00
0005434573451	10908	Economy	14400.00
0005435614605	10908	Economy	14400.00
0005435614773	10908	Economy	14400.00
0005435614766	10908	Economy	14400.00
0005435614781	10908	Economy	14400.00
0005435615131	10908	Economy	14400.00
0005435097303	10908	Economy	14400.00
0005435426140	10908	Economy	14400.00
0005435615240	10908	Economy	14400.00
0005434344636	10908	Economy	14400.00
0005435614616	10908	Economy	14400.00
0005432165185	10908	Economy	14400.00
0005435426118	10908	Economy	14400.00
0005435614444	10908	Economy	14400.00
0005435426126	10908	Economy	14400.00
0005434344438	10908	Economy	14400.00
0005434245547	10908	Economy	14400.00
0005435426133	10908	Economy	14400.00
0005434344516	10908	Economy	14400.00
0005434573477	10908	Economy	14400.00
0005434245549	10908	Economy	14400.00
0005434344419	10908	Economy	14400.00
0005435426173	10908	Economy	14400.00
0005435615239	10908	Economy	14400.00
0005434245563	10908	Economy	14400.00
0005435614665	10908	Economy	14400.00
0005435614447	10908	Economy	14400.00
0005435614885	10908	Economy	14400.00
0005435097304	10908	Economy	14400.00
0005434344599	10908	Economy	14400.00
0005435614445	10908	Economy	14400.00
0005435426146	10908	Economy	14400.00
0005435426176	10908	Economy	14400.00
0005435426166	10908	Economy	14400.00
0005435426138	10908	Economy	14400.00
0005435380390	10908	Economy	14400.00
0005435426152	10908	Economy	14400.00
0005435614937	10908	Economy	14400.00
0005435426145	10908	Economy	14400.00
0005435426182	10908	Economy	14400.00
0005435615094	10908	Economy	14400.00
0005435426158	10908	Economy	14400.00
0005435615003	10908	Economy	14400.00
0005435614782	10908	Economy	14400.00
0005434245554	10908	Economy	14400.00
0005435614797	10908	Economy	14400.00
0005435615155	10908	Economy	14400.00
0005435426183	10908	Economy	14400.00
0005435097343	10908	Economy	14400.00
0005435614299	10908	Economy	14400.00
0005435426113	10908	Economy	14400.00
0005435426147	10908	Economy	14400.00
0005435426121	10908	Economy	14400.00
0005435426119	10908	Economy	14400.00
0005435614923	10908	Economy	14400.00
0005434245567	10908	Economy	14400.00
0005435614994	10908	Economy	14400.00
0005435615156	10908	Economy	14400.00
0005434344526	10908	Economy	14400.00
0005435614446	10908	Economy	14400.00
0005432166964	10908	Economy	14400.00
0005435097344	10908	Economy	14400.00
0005434245564	10908	Economy	14400.00
0005435614756	10908	Economy	14400.00
0005435490270	10908	Economy	14400.00
0005435614948	10908	Economy	14400.00
0005434245538	10908	Economy	14400.00
0005434245551	10908	Economy	14400.00
0005435426142	10908	Economy	14400.00
0005434573449	10908	Economy	14400.00
0005435614944	10908	Economy	14400.00
0005435426168	10908	Economy	14400.00
0005435426175	10908	Economy	14400.00
0005434573394	10908	Economy	14400.00
0005435426124	10908	Economy	14400.00
0005434344497	10908	Economy	14400.00
0005435614531	10908	Economy	14400.00
0005435614252	10908	Economy	14400.00
0005435614637	10908	Economy	14400.00
0005435614875	10908	Economy	14400.00
0005435614952	10908	Economy	14400.00
0005435615064	10908	Economy	14400.00
0005434344525	10908	Economy	14400.00
0005434344513	10908	Economy	14400.00
0005434344560	10908	Economy	14400.00
0005434344487	10908	Economy	14400.00
0005434344433	10908	Economy	14400.00
0005434245544	10908	Economy	14400.00
0005434245565	10908	Economy	14400.00
0005435614735	10908	Economy	14400.00
0005435614774	10908	Economy	14400.00
0005435614456	10908	Economy	14400.00
0005435426153	10908	Economy	14400.00
0005435615030	10908	Economy	14400.00
0005434245540	10908	Economy	14400.00
0005434245546	10908	Economy	14400.00
0005435319746	10908	Economy	14400.00
0005434656595	10908	Economy	15800.00
0005435426122	10908	Economy	15800.00
0005435426132	10908	Economy	15800.00
0005435426139	10908	Economy	15800.00
0005435614997	10908	Economy	15800.00
0005435097315	10908	Economy	15800.00
0005435614975	10908	Economy	14400.00
0005434344598	10908	Economy	14400.00
0005435614558	10908	Economy	14400.00
0005435426127	10908	Economy	14400.00
0005435097294	10908	Economy	14400.00
0005434573508	10908	Economy	14400.00
0005434245566	10908	Economy	14400.00
0005435614300	10908	Economy	14400.00
0005435614980	10908	Economy	14400.00
0005435426170	10908	Economy	14400.00
0005435097278	10908	Economy	14400.00
0005435615102	10908	Economy	14400.00
0005435614881	10908	Economy	14400.00
0005435614951	10908	Economy	14400.00
0005435614978	10908	Economy	14400.00
0005433719207	10908	Economy	14400.00
0005435614798	10908	Economy	14400.00
0005435614654	10908	Economy	14400.00
0005433719206	10908	Economy	14400.00
0005435614718	10908	Economy	14400.00
0005434344626	10908	Economy	14400.00
0005435426116	10908	Economy	14400.00
0005435614945	10908	Economy	14400.00
0005435614775	10908	Economy	14400.00
0005435614253	10908	Economy	14400.00
0005434344437	10908	Economy	14400.00
0005435097279	10908	Economy	14400.00
0005434245561	10908	Economy	14400.00
0005435614513	10908	Economy	14400.00
0005435615120	10908	Economy	14400.00
0005434344638	10908	Economy	14400.00
0005435614877	10908	Economy	14400.00
0005434573437	10908	Economy	14400.00
0005435614749	10908	Economy	14400.00
0005432165183	10908	Economy	14400.00
0005435615092	10908	Economy	14400.00
0005435426163	10908	Economy	14400.00
0005432166966	10908	Economy	14400.00
0005435426144	10908	Economy	14400.00
0005435614821	10908	Economy	14400.00
0005435042896	10908	Economy	14400.00
0005434344515	10908	Economy	14400.00
0005435319749	10908	Economy	14400.00
0005432165188	10908	Economy	14400.00
0005435615130	10908	Economy	14400.00
0005435380391	10908	Economy	14400.00
0005435426160	10908	Economy	14400.00
0005435614979	10908	Economy	14400.00
0005435615074	10908	Economy	14400.00
0005434344543	10908	Economy	14400.00
0005434245557	10908	Economy	14400.00
0005435319745	10908	Economy	14400.00
0005434344491	10908	Economy	14400.00
0005435614767	10908	Economy	14400.00
0005435615112	10908	Economy	14400.00
0005434344634	10908	Economy	14400.00
0005435426159	10908	Economy	14400.00
0005435615113	10908	Economy	14400.00
0005432165189	10908	Economy	14400.00
0005435614571	10908	Economy	14400.00
0005435614653	10908	Economy	14400.00
0005434344575	10908	Economy	14400.00
0005435491452	10908	Economy	14400.00
0005434344434	10908	Economy	14400.00
0005435319741	10908	Economy	14400.00
0005434344489	10908	Economy	14400.00
0005435614553	10908	Economy	14400.00
0005435614720	10908	Economy	14400.00
0005434344544	10908	Economy	14400.00
0005435426131	10908	Economy	14400.00
0005435615073	10908	Economy	14400.00
0005435426179	10908	Economy	14400.00
0005435426171	10908	Economy	14400.00
0005435614915	10908	Economy	14400.00
0005434245553	10908	Economy	14400.00
0005435426164	10908	Economy	14400.00
0005435097287	10908	Economy	14400.00
0005435426128	10908	Economy	14400.00
0005435614527	10908	Economy	14400.00
0005432166963	10908	Economy	14400.00
0005435097285	10908	Economy	14400.00
0005435426135	10908	Economy	14400.00
0005434245559	10908	Economy	14400.00
0005434245541	10908	Economy	14400.00
0005432165187	10908	Economy	14400.00
0005435426156	10908	Economy	14400.00
0005434344693	10908	Economy	14400.00
0005435319743	10908	Economy	14400.00
0005435426130	10908	Economy	14400.00
0005434573439	10908	Economy	14400.00
0005434245545	10908	Economy	14400.00
0005435426148	10908	Economy	14400.00
0005435380387	10908	Economy	14400.00
0005434344524	10908	Economy	14400.00
0005435614603	10908	Economy	14400.00
0005435614899	10908	Economy	14400.00
0005435426180	10908	Economy	14400.00
0005435615090	10908	Economy	14400.00
0005432166965	10908	Economy	14400.00
0005435614943	10908	Economy	14400.00
0005435614734	10908	Economy	14400.00
0005435426120	10908	Economy	14400.00
0005432460247	3385	Business	18800.00
0005432460403	3385	Business	18800.00
0005432182154	3385	Business	18800.00
0005432460470	3385	Business	18800.00
0005433634483	3385	Business	18800.00
0005433806051	3385	Business	18800.00
0005433507528	3385	Business	18800.00
0005433507533	3385	Business	18800.00
0005432182140	3385	Business	18800.00
0005432182146	3385	Business	18800.00
0005433507532	3385	Business	18800.00
0005432460433	3385	Business	18800.00
0005432182148	3385	Business	18800.00
0005432460477	3385	Business	18800.00
0005433634499	3385	Business	18800.00
0005432460588	3385	Business	18800.00
0005433806048	3385	Business	18800.00
0005433507525	3385	Business	18800.00
0005433806049	3385	Business	18800.00
0005433634478	3385	Business	18800.00
0005432460478	3385	Business	18800.00
0005432460234	3385	Business	18800.00
0005432460384	3385	Business	18800.00
0005433634486	3385	Business	18800.00
0005433806057	3385	Business	18800.00
0005433507515	3385	Business	18800.00
0005432182144	3385	Business	18800.00
0005432460411	3385	Business	18800.00
0005433634472	3385	Economy	6900.00
0005432460378	3385	Economy	6900.00
0005432460380	3385	Economy	6900.00
0005433634500	3385	Economy	6900.00
0005432460469	3385	Economy	6900.00
0005432460281	3385	Economy	6900.00
0005432460379	3385	Economy	6300.00
0005433507520	3385	Economy	6300.00
0005433806041	3385	Economy	6300.00
0005432460476	3385	Economy	6300.00
0005433634477	3385	Economy	6300.00
0005432460434	3385	Economy	6300.00
0005432460253	3385	Economy	6300.00
0005433806054	3385	Economy	6300.00
0005432182150	3385	Economy	6300.00
0005433507523	3385	Economy	6300.00
0005433634473	3385	Economy	6300.00
0005432182151	3385	Economy	6300.00
0005433806055	3385	Economy	6300.00
0005433806045	3385	Economy	6300.00
0005433634487	3385	Economy	6300.00
0005433806065	3385	Economy	6300.00
0005433634491	3385	Economy	6300.00
0005433806066	3385	Economy	6300.00
0005432460098	3385	Economy	6300.00
0005432182149	3385	Economy	6300.00
0005432460364	3385	Economy	6300.00
0005432460432	3385	Economy	6300.00
0005433806063	3385	Economy	6300.00
0005433634481	3385	Economy	6300.00
0005432460248	3385	Economy	6300.00
0005433634490	3385	Economy	6300.00
0005433634475	3385	Economy	6300.00
0005433634493	3385	Economy	6300.00
0005433634470	3385	Economy	6300.00
0005433806053	3385	Economy	6300.00
0005432182161	3385	Economy	6300.00
0005433634482	3385	Economy	6300.00
0005432182147	3385	Economy	6300.00
0005432460589	3385	Economy	6300.00
0005433634494	3385	Economy	6300.00
0005432460496	3385	Economy	6300.00
0005432182156	3385	Economy	6300.00
0005433634495	3385	Economy	6300.00
0005432460428	3385	Economy	6300.00
0005432182152	3385	Economy	6300.00
0005433507527	3385	Economy	6300.00
0005432460215	3385	Economy	6300.00
0005432460385	3385	Economy	6300.00
0005432182162	3385	Economy	6300.00
0005433507526	3385	Economy	6300.00
0005432460429	3385	Economy	6300.00
0005432460324	3385	Economy	6300.00
0005433806047	3385	Economy	6300.00
0005432460536	3385	Economy	6300.00
0005433806058	3385	Economy	6300.00
0005433634498	3385	Economy	6300.00
0005432460106	3385	Economy	6300.00
0005432460370	3385	Economy	6300.00
0005433806052	3385	Economy	6300.00
0005432460657	3385	Economy	6300.00
0005432460408	3385	Economy	6300.00
0005433806038	3385	Economy	6300.00
0005433507530	3385	Economy	6300.00
0005433507514	3385	Economy	6900.00
0005432460413	3385	Economy	6300.00
0005432182160	3385	Economy	6900.00
0005432182158	3385	Economy	6900.00
0005433507531	3385	Economy	6900.00
0005432182153	3385	Economy	6900.00
0005433806046	3385	Economy	6300.00
0005433806043	3385	Economy	6300.00
0005433806060	3385	Economy	6300.00
0005432182141	3385	Economy	6300.00
0005433634501	3385	Economy	6900.00
0005433507529	3385	Economy	6300.00
0005432460407	3385	Economy	6300.00
0005432460307	3385	Economy	6300.00
0005432460139	3385	Economy	6300.00
0005433634489	3385	Economy	6300.00
0005432460664	3385	Economy	6300.00
0005433806044	3385	Economy	6300.00
0005433806042	3385	Economy	6300.00
0005432460535	3385	Economy	6300.00
0005432460233	3385	Economy	6300.00
0005433634471	3385	Economy	6300.00
0005433507522	3385	Economy	6300.00
0005432460502	3385	Economy	6300.00
0005432460665	3385	Economy	6300.00
0005433507513	3385	Economy	6300.00
0005432182145	3385	Economy	6300.00
0005433806040	3385	Economy	6300.00
0005433634474	3385	Economy	6300.00
0005432460521	3385	Economy	6300.00
0005433507516	3385	Economy	6300.00
0005433634485	3385	Economy	6300.00
0005433634480	3385	Economy	6300.00
0005433507524	3385	Economy	6300.00
0005432182143	3385	Economy	6300.00
0005432182159	3385	Economy	6300.00
0005433806061	3385	Economy	6300.00
0005433634492	3385	Economy	6300.00
0005433507518	3385	Economy	6300.00
0005432460501	3385	Economy	6300.00
0005433806056	3385	Economy	6300.00
0005432460552	3385	Economy	6300.00
0005432182157	3385	Economy	6300.00
0005433634488	3385	Economy	6300.00
0005432182155	3385	Economy	6300.00
0005433806059	3385	Economy	6300.00
0005433806039	3385	Economy	6300.00
0005433634484	3385	Economy	6300.00
0005433634496	3385	Economy	6300.00
0005433806062	3385	Economy	6300.00
0005433806050	3385	Economy	6300.00
0005432460192	3385	Economy	6300.00
0005433634502	3385	Economy	6300.00
0005432182142	3385	Economy	6300.00
0005432460414	3385	Economy	6300.00
0005432182163	3385	Economy	6300.00
0005432460431	3385	Economy	6300.00
0005432460402	3385	Economy	6300.00
0005433634497	3385	Economy	6300.00
0005432460292	3385	Economy	6300.00
0005433806064	3385	Economy	6300.00
0005433507534	3385	Economy	6300.00
0005433634503	3385	Economy	6300.00
0005433634479	3385	Economy	6300.00
0005432460316	3385	Economy	6300.00
0005432460464	3385	Economy	6300.00
0005433507519	3385	Economy	6300.00
0005433507521	3385	Economy	6300.00
0005432460522	3385	Economy	6300.00
0005433634476	3385	Economy	6300.00
0005433507517	3385	Economy	6300.00
0005432460404	3385	Economy	6300.00
0005432460276	3385	Economy	6300.00
0005432460363	3385	Economy	6300.00
0005432460371	3385	Economy	6300.00
0005432460463	3385	Economy	6300.00
0005435885822	3384	Business	18800.00
0005435885997	3384	Business	18800.00
0005435885689	3384	Business	18800.00
0005435885858	3384	Business	18800.00
0005435885762	3384	Business	18800.00
0005435885718	3384	Business	18800.00
0005435885670	3384	Business	18800.00
0005435885719	3384	Business	18800.00
0005435885914	3384	Economy	6900.00
0005435885865	3384	Economy	6900.00
0005435885763	3384	Economy	6900.00
0005435885816	3384	Economy	6300.00
0005435885669	3384	Economy	6300.00
0005435885874	3384	Economy	6300.00
0005435885601	3384	Economy	6300.00
0005435885864	3384	Economy	6300.00
0005435885906	3384	Economy	6300.00
0005435885668	3384	Economy	6300.00
0005435885727	3384	Economy	6300.00
0005435885908	3384	Economy	6300.00
0005435885885	3384	Economy	6300.00
0005435885823	3384	Economy	6300.00
0005435885682	3384	Economy	6300.00
0005435885976	3384	Economy	6300.00
0005435885932	3384	Economy	6300.00
0005435885770	3384	Economy	6300.00
0005435885808	3384	Economy	6300.00
0005435885920	3384	Economy	6300.00
0005435885830	3384	Economy	6300.00
0005435885849	3384	Economy	6300.00
0005435885699	3384	Economy	6300.00
0005435885996	3384	Economy	6300.00
0005435885850	3384	Economy	6300.00
0005435885663	3384	Economy	6300.00
0005435885907	3384	Economy	6300.00
0005435885757	3384	Economy	6300.00
0005435885834	3384	Economy	6300.00
0005435885973	3384	Economy	6300.00
0005435885875	3384	Economy	6300.00
0005435885688	3384	Economy	6300.00
0005435885817	3384	Economy	6300.00
0005435885627	3384	Economy	6300.00
0005435885798	3384	Economy	6300.00
0005435885751	3384	Economy	6300.00
0005435885841	3384	Economy	6300.00
0005435885975	3384	Economy	6300.00
0005435885966	3384	Economy	6300.00
0005435885801	3384	Economy	6300.00
0005435885704	3384	Economy	6300.00
0005435885626	3384	Economy	6300.00
0005432460880	8195	Business	18800.00
0005432042985	8195	Business	18800.00
0005432460930	8195	Business	18800.00
0005432460896	8195	Business	18800.00
0005432460931	8195	Business	18800.00
0005433507382	8195	Business	18800.00
0005435886197	8195	Business	18800.00
0005432460882	8195	Business	18800.00
0005432042986	8195	Business	18800.00
0005432042981	8195	Business	18800.00
0005435886195	8195	Business	18800.00
0005435886174	8195	Business	18800.00
0005432460928	8195	Business	18800.00
0005435886220	8195	Business	18800.00
0005432460895	8195	Business	18800.00
0005435886198	8195	Business	18800.00
0005433507376	8195	Business	18800.00
0005432460915	8195	Business	18800.00
0005435886196	8195	Business	18800.00
0005435886189	8195	Business	18800.00
0005435886208	8195	Business	18800.00
0005435886216	8195	Business	18800.00
0005432460925	8195	Business	18800.00
0005432042988	8195	Business	18800.00
0005435886218	8195	Economy	6900.00
0005432460901	8195	Economy	6900.00
0005435886184	8195	Economy	6900.00
0005435886185	8195	Economy	6900.00
0005432460892	8195	Economy	6900.00
0005435886180	8195	Economy	6900.00
0005432460890	8195	Economy	6300.00
0005433507369	8195	Economy	6300.00
0005432460905	8195	Economy	6300.00
0005435886217	8195	Economy	6300.00
0005432460886	8195	Economy	6300.00
0005432042984	8195	Economy	6300.00
0005432460891	8195	Economy	6300.00
0005432460929	8195	Economy	6300.00
0005432460907	8195	Economy	6300.00
0005433507388	8195	Economy	6300.00
0005435886171	8195	Economy	6300.00
0005432460900	8195	Economy	6300.00
0005432460887	8195	Economy	6300.00
0005435142973	8195	Economy	6300.00
0005433507367	8195	Economy	6300.00
0005435886206	8195	Economy	6300.00
0005435886210	8195	Economy	6300.00
0005435886167	8195	Economy	6300.00
0005432460918	8195	Economy	6300.00
0005432460923	8195	Economy	6300.00
0005432460899	8195	Economy	6300.00
0005432460910	8195	Economy	6300.00
0005432042990	8195	Economy	6300.00
0005435886214	8195	Economy	6300.00
0005432460911	8195	Economy	6300.00
0005432042980	8195	Economy	6300.00
0005435886170	8195	Economy	6300.00
0005432460898	8195	Economy	6300.00
0005435886199	8195	Economy	6300.00
0005435886204	8195	Economy	6300.00
0005435886211	8195	Economy	6300.00
0005432460912	8195	Economy	6300.00
0005435886223	8195	Economy	6300.00
0005435886203	8195	Economy	6300.00
0005432460924	8195	Economy	6300.00
0005435886205	8195	Economy	6300.00
0005432042992	8195	Economy	6300.00
0005435886207	8195	Economy	6300.00
0005432460932	8195	Economy	6300.00
0005432460902	8195	Economy	6300.00
0005432460889	8195	Economy	6300.00
0005432042983	8195	Economy	6300.00
0005432460913	8195	Economy	6300.00
0005433507325	8195	Economy	6300.00
0005435886183	8195	Economy	6300.00
0005432042993	8195	Economy	6300.00
0005435886187	8195	Economy	6300.00
0005432460883	8195	Economy	6300.00
0005435142972	8195	Economy	6300.00
0005432460903	8195	Economy	6300.00
0005432460914	8195	Economy	6300.00
0005432460885	8195	Economy	6300.00
0005432460908	8195	Economy	6900.00
0005432460909	8195	Economy	6900.00
0005432460922	8195	Economy	6900.00
0005435886212	8195	Economy	6900.00
0005435886215	8195	Economy	6300.00
0005432460904	8195	Economy	6300.00
0005435886176	8195	Economy	6300.00
0005435886192	8195	Economy	6900.00
0005435886173	8195	Economy	6300.00
0005435886178	8195	Economy	6300.00
0005432042994	8195	Economy	6300.00
0005434312361	8195	Economy	6300.00
0005435886168	8195	Economy	6300.00
0005435142974	8195	Economy	6300.00
0005435886209	8195	Economy	6300.00
0005435886191	8195	Economy	6300.00
0005433507410	8195	Economy	6300.00
0005433507383	8195	Economy	6300.00
0005434312360	8195	Economy	6300.00
0005435886172	8195	Economy	6300.00
0005435886221	8195	Economy	6300.00
0005435886166	8195	Economy	6300.00
0005432460926	8195	Economy	6300.00
0005432460919	8195	Economy	6300.00
0005435886181	8195	Economy	6300.00
0005433507373	8195	Economy	6300.00
0005432460893	8195	Economy	6300.00
0005432460881	8195	Economy	6300.00
0005433507368	8195	Economy	6300.00
0005432042982	8195	Economy	6300.00
0005433507375	8195	Economy	6300.00
0005435886165	8195	Economy	6300.00
0005435886188	8195	Economy	6300.00
0005435886175	8195	Economy	6300.00
0005432460884	8195	Economy	6300.00
0005435886186	8195	Economy	6300.00
0005435886193	8195	Economy	6300.00
0005435886194	8195	Economy	6300.00
0005432042987	8195	Economy	6300.00
0005433507429	8195	Economy	6300.00
0005433507406	8195	Economy	6300.00
0005432460888	8195	Economy	6300.00
0005432460906	8195	Economy	6300.00
0005435886202	8195	Economy	6300.00
0005435886200	8195	Economy	6300.00
0005435886190	8195	Economy	6300.00
0005432042991	8195	Economy	6300.00
0005432460917	8195	Economy	6300.00
0005435886169	8195	Economy	6300.00
0005432460927	8195	Economy	6300.00
0005435886219	8195	Economy	6300.00
0005432042989	8195	Economy	6300.00
0005435886222	8195	Economy	6300.00
0005432460894	8195	Economy	6300.00
0005432460921	8195	Economy	6300.00
0005432460920	8195	Economy	6300.00
0005435886213	8195	Economy	6300.00
0005435886177	8195	Economy	6300.00
0005435886201	8195	Economy	6300.00
0005433507409	8195	Economy	6300.00
0005435886179	8195	Economy	6300.00
0005435886182	8195	Economy	6300.00
0005432460916	8195	Economy	6300.00
0005432460897	8195	Economy	6300.00
0005435854067	8196	Business	18800.00
0005433805813	8196	Business	18800.00
0005433805664	8196	Business	18800.00
0005433805707	8196	Business	18800.00
0005433634114	8196	Business	18800.00
0005433634210	8196	Business	18800.00
0005433805773	8196	Business	18800.00
0005433634090	8196	Business	18800.00
0005433805883	8196	Business	18800.00
0005433634203	8196	Business	18800.00
0005433633977	8196	Business	18800.00
0005433805774	8196	Business	18800.00
0005433634153	8196	Business	18800.00
0005433805673	8196	Economy	6900.00
0005433805529	8196	Economy	6900.00
0005433805663	8196	Economy	6900.00
0005433634255	8196	Economy	6900.00
0005433805731	8196	Economy	6300.00
0005433634089	8196	Economy	6300.00
0005433805815	8196	Economy	6300.00
0005433805662	8196	Economy	6300.00
0005433805732	8196	Economy	6300.00
0005435854068	8196	Economy	6300.00
0005433805658	8196	Economy	6300.00
0005435854070	8196	Economy	6300.00
0005433634148	8196	Economy	6300.00
0005433805780	8196	Economy	6300.00
0005433805689	8196	Economy	6300.00
0005433805775	8196	Economy	6300.00
0005433805754	8196	Economy	6300.00
0005433634256	8196	Economy	6300.00
0005433805708	8196	Economy	6300.00
0005434271334	8196	Economy	6300.00
0005433805595	8196	Economy	6300.00
0005433805814	8196	Economy	6300.00
0005433634204	8196	Economy	6300.00
0005433634119	8196	Economy	6300.00
0005433634163	8196	Economy	6900.00
0005433805661	8196	Economy	6900.00
0005433634124	8196	Economy	6900.00
0005433634217	8196	Economy	6300.00
0005433805671	8196	Economy	6300.00
0005433634106	8196	Economy	6300.00
0005433805637	8196	Economy	6300.00
0005433805788	8196	Economy	6300.00
0005433805633	8196	Economy	6300.00
0005433634017	8196	Economy	6300.00
0005433634121	8196	Economy	6300.00
0005433805812	8196	Economy	6300.00
0005433634184	8196	Economy	6300.00
0005433805755	8196	Economy	6300.00
0005433805838	8196	Economy	6300.00
0005433634198	8196	Economy	6300.00
0005433634016	8196	Economy	6300.00
0005433634188	8196	Economy	6300.00
0005433634025	8196	Economy	6300.00
0005433634125	8196	Economy	6300.00
0005433634126	8196	Economy	6300.00
0005433634123	8196	Economy	6300.00
0005433805596	8196	Economy	6300.00
0005433634222	8196	Economy	6300.00
0005433805672	8196	Economy	6300.00
0005433805884	8196	Economy	6300.00
0005433634086	8196	Economy	6300.00
0005433634099	8196	Economy	6300.00
0005433805756	8196	Economy	6300.00
0005435854066	8196	Economy	6300.00
0005435854069	8196	Economy	6300.00
0005433805762	8196	Economy	6300.00
0005434183601	8197	Economy	6300.00
0005434183600	8197	Economy	6300.00
0005433194911	4677	Business	9900.00
0005433454916	4677	Business	9900.00
0005432383954	4677	Business	9900.00
0005433722348	4677	Business	9900.00
0005433454917	4677	Business	9900.00
0005432383924	4677	Business	9900.00
0005432383949	4677	Business	9900.00
0005432728190	4677	Business	9900.00
0005432383930	4677	Business	9900.00
0005433194910	4677	Business	9900.00
0005433194907	4677	Economy	3300.00
0005432383936	4677	Economy	3300.00
0005432383941	4677	Economy	3300.00
0005432383942	4677	Economy	3300.00
0005432383953	4677	Economy	3300.00
0005432383952	4677	Economy	3300.00
0005432383938	4677	Economy	3300.00
0005432383951	4677	Economy	3600.00
0005433722351	4677	Economy	3600.00
0005432383937	4677	Economy	3600.00
0005432728179	4677	Economy	3600.00
0005432383917	4677	Economy	3600.00
0005433194913	4677	Economy	3300.00
0005432383927	4677	Economy	3300.00
0005432383933	4677	Economy	3300.00
0005432383929	4677	Economy	3300.00
0005432383923	4677	Economy	3300.00
0005432383926	4677	Economy	3300.00
0005432383948	4677	Economy	3300.00
0005432383944	4677	Economy	3300.00
0005432383947	4677	Economy	3300.00
0005432383918	4677	Economy	3300.00
0005432383945	4677	Economy	3300.00
0005432383940	4677	Economy	3300.00
0005432383915	4677	Economy	3300.00
0005432728187	4677	Economy	3300.00
0005432383950	4677	Economy	3300.00
0005432383946	4677	Economy	3300.00
0005432383920	4677	Economy	3300.00
0005432728186	4677	Economy	3300.00
0005432383921	4677	Economy	3300.00
0005433722347	4677	Economy	3300.00
0005432728184	4677	Economy	3300.00
0005432728181	4677	Economy	3300.00
0005432728185	4677	Economy	3300.00
0005433722349	4677	Economy	3300.00
0005432383925	4677	Economy	3300.00
0005433194909	4677	Economy	3300.00
0005432728188	4677	Economy	3300.00
0005432383931	4677	Economy	3300.00
0005433722350	4677	Economy	3300.00
0005432383932	4677	Economy	3300.00
0005432383943	4677	Economy	3300.00
0005432728189	4677	Economy	3300.00
0005432728178	4677	Economy	3300.00
0005432728180	4677	Economy	3300.00
0005432383934	4677	Economy	3300.00
0005433194906	4677	Economy	3300.00
0005432728182	4677	Economy	3300.00
0005432383919	4677	Economy	3300.00
0005432383955	4677	Economy	3300.00
0005432383928	4677	Economy	3300.00
0005432383922	4677	Economy	3300.00
0005432728183	4677	Economy	3300.00
0005432383939	4677	Economy	3300.00
0005433194908	4677	Economy	3300.00
0005432383916	4677	Economy	3300.00
0005432383935	4677	Economy	3300.00
0005433194912	4677	Economy	3300.00
0005433194905	4677	Economy	3300.00
0005432728062	30190	Business	9900.00
0005432728063	30190	Business	9900.00
0005432383507	30190	Business	9900.00
0005432383476	30190	Business	9900.00
0005433194873	30190	Business	9900.00
0005432383463	30190	Business	9900.00
0005432383454	30190	Economy	3300.00
0005432728039	30190	Economy	3300.00
0005432383416	30190	Economy	3300.00
0005432383508	30190	Economy	3300.00
0005432728045	30190	Economy	3300.00
0005432728069	30190	Economy	3300.00
0005432383367	30190	Economy	3300.00
0005432383364	30190	Economy	3600.00
0005432728084	30190	Economy	3600.00
0005432383365	30190	Economy	3600.00
0005432383464	30190	Economy	3600.00
0005432383414	30190	Economy	3600.00
0005432383318	30190	Economy	3300.00
0005432728074	30190	Economy	3300.00
0005432383541	30190	Economy	3300.00
0005432383462	30190	Economy	3300.00
0005432383432	30190	Economy	3300.00
0005432383415	30190	Economy	3300.00
0005432383467	30190	Economy	3300.00
0005432728046	30190	Economy	3300.00
0005433194868	30190	Economy	3300.00
0005432383354	30190	Economy	3300.00
0005432383506	30190	Economy	3300.00
0005432383348	30190	Economy	3300.00
0005432383431	30190	Economy	3300.00
0005432383349	30190	Economy	3300.00
0005432383337	30190	Economy	3300.00
0005432728004	30190	Economy	3300.00
0005433722271	30190	Economy	3300.00
0005432728015	30190	Economy	3300.00
0005432383524	30190	Economy	3300.00
0005432383542	30190	Economy	3300.00
0005433194877	30190	Economy	3300.00
0005433194874	30190	Economy	3300.00
0005432728014	30190	Economy	3300.00
0005432383525	30190	Economy	3300.00
0005432383340	30190	Economy	3300.00
0005432383430	30190	Economy	3300.00
0005432383491	30190	Economy	3300.00
0005433453779	30190	Economy	3300.00
0005433194875	30190	Economy	3300.00
0005432383133	30190	Economy	3300.00
0005433194869	30190	Economy	3300.00
0005432383453	30190	Economy	3300.00
0005433722261	30190	Economy	3300.00
0005432383366	30190	Economy	3300.00
0005432728089	30190	Economy	3300.00
0005433722262	30190	Economy	3300.00
0005432383502	30190	Economy	3300.00
0005432383452	30190	Economy	3300.00
0005432383134	30190	Economy	3300.00
0005432728047	30190	Economy	3300.00
0005432728093	30190	Economy	3300.00
0005433451641	30190	Economy	3300.00
0005435541426	1724	Business	57200.00
0005432925090	1724	Business	57200.00
0005432925091	1724	Business	57200.00
0005435529676	1724	Business	57200.00
0005435529677	1724	Business	57200.00
0005435529685	1724	Business	57200.00
0005435529691	1724	Business	57200.00
0005432925086	1724	Business	57200.00
0005432294535	1724	Business	57200.00
0005435530011	1724	Business	57200.00
0005435529683	1724	Economy	19100.00
0005435541428	1724	Economy	19100.00
0005435529684	1724	Economy	19100.00
0005435541439	1724	Economy	19100.00
0005435541422	1724	Economy	19100.00
0005435530001	1724	Economy	19100.00
0005435541420	1724	Economy	19100.00
0005435541435	1724	Economy	19100.00
0005435541430	1724	Economy	21000.00
0005432925099	1724	Economy	21000.00
0005435530007	1724	Economy	19100.00
0005435530008	1724	Economy	19100.00
0005433517069	1724	Economy	19100.00
0005435529692	1724	Economy	19100.00
0005433517067	1724	Economy	19100.00
0005435541440	1724	Economy	19100.00
0005435529689	1724	Economy	19100.00
0005435529679	1724	Economy	19100.00
0005433517074	1724	Economy	19100.00
0005435541434	1724	Economy	19100.00
0005435541421	1724	Economy	19100.00
0005435541432	1724	Economy	19100.00
0005435529695	1724	Economy	19100.00
0005435529680	1724	Economy	19100.00
0005435541431	1724	Economy	19100.00
0005433517071	1724	Economy	19100.00
0005435541427	1724	Economy	19100.00
0005435530009	1724	Economy	19100.00
0005432925100	1724	Economy	19100.00
0005435541429	1724	Economy	19100.00
0005435529693	1724	Economy	19100.00
0005435530010	1724	Economy	19100.00
0005435529690	1724	Economy	19100.00
0005435530002	1724	Economy	19100.00
0005433517072	1724	Economy	19100.00
0005432925085	1724	Economy	19100.00
0005435541433	1724	Economy	19100.00
0005435541423	1724	Economy	19100.00
0005435541441	1724	Economy	19100.00
0005435529687	1724	Economy	19100.00
0005435541438	1724	Economy	19100.00
0005433517075	1724	Economy	19100.00
0005435529686	1724	Economy	19100.00
0005435529694	1724	Economy	19100.00
0005435541437	1724	Economy	19100.00
0005435541424	1724	Economy	19100.00
0005435530004	1724	Economy	19100.00
0005435529697	1724	Economy	19100.00
0005435529678	1724	Economy	19100.00
0005435530005	1724	Economy	19100.00
0005433517073	1724	Economy	19100.00
0005435529682	1724	Economy	19100.00
0005432925073	1724	Economy	19100.00
0005435529681	1724	Economy	19100.00
0005435529688	1724	Economy	19100.00
0005435529696	1724	Economy	19100.00
0005433517068	1724	Economy	19100.00
0005435541436	1724	Economy	19100.00
0005435530003	1724	Economy	19100.00
0005435530006	1724	Economy	19100.00
0005433517070	1724	Economy	19100.00
0005435541425	1724	Economy	19100.00
0005433517008	22016	Business	57200.00
0005435541373	22016	Business	57200.00
0005432925131	22016	Business	57200.00
0005435541107	22016	Business	57200.00
0005435541168	22016	Business	57200.00
0005435541257	22016	Business	57200.00
0005435541282	22016	Economy	19100.00
0005435541283	22016	Economy	19100.00
0005435541217	22016	Economy	19100.00
0005435518089	22016	Economy	19100.00
0005433516977	22016	Economy	19100.00
0005433516996	22016	Economy	19100.00
0005435518053	22016	Economy	21000.00
0005433516984	22016	Economy	21000.00
0005435518050	22016	Economy	19100.00
0005435518132	22016	Economy	19100.00
0005433516976	22016	Economy	19100.00
0005433517004	22016	Economy	19100.00
0005435518079	22016	Economy	19100.00
0005432925132	22016	Economy	19100.00
0005432925128	22016	Economy	19100.00
0005435541206	22016	Economy	19100.00
0005433516973	22016	Economy	19100.00
0005435541269	22016	Economy	19100.00
0005435518073	22016	Economy	19100.00
0005435541227	22016	Economy	19100.00
0005435518153	22016	Economy	19100.00
0005435541192	22016	Economy	19100.00
0005435518105	22016	Economy	19100.00
0005433516974	22016	Economy	19100.00
0005435541248	22016	Economy	19100.00
0005433516975	22016	Economy	19100.00
0005432925129	22016	Economy	19100.00
0005435518127	22016	Economy	19100.00
0005433516991	22016	Economy	19100.00
0005435518106	22016	Economy	19100.00
0005435541276	22016	Economy	19100.00
0005435541180	22016	Economy	19100.00
0005435541176	22016	Economy	19100.00
0005433516983	22016	Economy	19100.00
0005432925130	22016	Economy	19100.00
0005435541207	22016	Economy	19100.00
0005435541250	22016	Economy	19100.00
0005435518142	22016	Economy	19100.00
0005435541238	22016	Economy	19100.00
0005435541218	22016	Economy	19100.00
0005433517007	22016	Economy	19100.00
0005435541272	22016	Economy	19100.00
0005435518141	22016	Economy	19100.00
0005435518152	22016	Economy	19100.00
0005435541194	22016	Economy	19100.00
0005435541249	22016	Economy	19100.00
0005433516951	22016	Economy	19100.00
0005435541179	22016	Economy	19100.00
0005435518136	22016	Economy	19100.00
0005435518049	22016	Economy	19100.00
0005435518126	22016	Economy	19100.00
0005432839651	7356	Business	18500.00
0005432823488	7356	Business	18500.00
0005435252885	7356	Business	18500.00
0005434459221	7356	Business	18500.00
0005432839634	7356	Business	18500.00
0005435252870	7356	Business	18500.00
0005432839627	7356	Business	18500.00
0005435491461	7356	Business	18500.00
0005434459207	7356	Business	18500.00
0005435252961	7356	Economy	6200.00
0005432839646	7356	Economy	6200.00
0005434459220	7356	Economy	6200.00
0005434459214	7356	Economy	6200.00
0005432839650	7356	Economy	6200.00
0005432839656	7356	Economy	6200.00
0005434459209	7356	Economy	6200.00
0005434459219	7356	Economy	6200.00
0005435252921	7356	Economy	6800.00
0005432839653	7356	Economy	6800.00
0005435252892	7356	Economy	6800.00
0005435252848	7356	Economy	6800.00
0005432839630	7356	Economy	6800.00
0005432839632	7356	Economy	6200.00
0005432839635	7356	Economy	6200.00
0005432839640	7356	Economy	6200.00
0005432839645	7356	Economy	6200.00
0005434664982	7356	Economy	6200.00
0005435252954	7356	Economy	6200.00
0005435252955	7356	Economy	6200.00
0005432073458	7356	Economy	6200.00
0005432839657	7356	Economy	6200.00
0005432839649	7356	Economy	6200.00
0005434459200	7356	Economy	6200.00
0005435252916	7356	Economy	6200.00
0005434459217	7356	Economy	6200.00
0005434459201	7356	Economy	6200.00
0005432839629	7356	Economy	6200.00
0005434459211	7356	Economy	6200.00
0005434459212	7356	Economy	6200.00
0005432839647	7356	Economy	6200.00
0005435252891	7356	Economy	6200.00
0005432839633	7356	Economy	6200.00
0005432839652	7356	Economy	6200.00
0005432841052	7356	Economy	6200.00
0005434459205	7356	Economy	6200.00
0005434459208	7356	Economy	6200.00
0005432823489	7356	Economy	6200.00
0005434459206	7356	Economy	6200.00
0005432839639	7356	Economy	6200.00
0005432839636	7356	Economy	6200.00
0005432839655	7356	Economy	6200.00
0005432073456	7356	Economy	6200.00
0005434459204	7356	Economy	6200.00
0005432839654	7356	Economy	6200.00
0005432073457	7356	Economy	6200.00
0005435252890	7356	Economy	6200.00
0005434459202	7356	Economy	6200.00
0005432839642	7356	Economy	6200.00
0005432839644	7356	Economy	6200.00
0005435252922	7356	Economy	6200.00
0005432841051	7356	Economy	6200.00
0005432839631	7356	Economy	6200.00
0005432839637	7356	Economy	6200.00
0005432839643	7356	Economy	6200.00
0005435252879	7356	Economy	6200.00
0005434459215	7356	Economy	6200.00
0005432073459	7356	Economy	6200.00
0005432839641	7356	Economy	6200.00
0005434459210	7356	Economy	6200.00
0005435491460	7356	Economy	6200.00
0005434459213	7356	Economy	6200.00
0005434459218	7356	Economy	6200.00
0005432841053	7356	Economy	6200.00
0005434459216	7356	Economy	6200.00
0005432839628	7356	Economy	6200.00
0005432839648	7356	Economy	6200.00
0005435252849	7356	Economy	6200.00
0005435252950	7356	Economy	6200.00
0005432839638	7356	Economy	6200.00
0005434459203	7356	Economy	6200.00
0005432839324	28927	Business	18500.00
0005435253060	28927	Business	18500.00
0005434458925	28927	Business	18500.00
0005434665006	28927	Business	18500.00
0005435253056	28927	Business	18500.00
0005435253051	28927	Business	18500.00
0005435253048	28927	Business	18500.00
0005434459047	28927	Business	18500.00
0005435253044	28927	Business	18500.00
0005435491483	28927	Business	18500.00
0005435253054	28927	Business	18500.00
0005432841039	28927	Economy	6200.00
0005432839532	28927	Economy	6200.00
0005435491485	28927	Economy	6200.00
0005432839410	28927	Economy	6200.00
0005435253061	28927	Economy	6200.00
0005432823465	28927	Economy	6200.00
0005434459080	28927	Economy	6200.00
0005435253059	28927	Economy	6200.00
0005432839307	28927	Economy	6800.00
0005432839358	28927	Economy	6800.00
0005435253057	28927	Economy	6800.00
0005434459051	28927	Economy	6800.00
0005435253055	28927	Economy	6800.00
0005432839461	28927	Economy	6200.00
0005432839335	28927	Economy	6200.00
0005435253053	28927	Economy	6200.00
0005432839460	28927	Economy	6200.00
0005432839350	28927	Economy	6200.00
0005432839496	28927	Economy	6200.00
0005432839379	28927	Economy	6200.00
0005432823466	28927	Economy	6200.00
0005432839407	28927	Economy	6200.00
0005434459017	28927	Economy	6200.00
0005435253049	28927	Economy	6200.00
0005434459079	28927	Economy	6200.00
0005434459000	28927	Economy	6200.00
0005432839399	28927	Economy	6200.00
0005434459001	28927	Economy	6200.00
0005432839365	28927	Economy	6200.00
0005434458939	28927	Economy	6200.00
0005432839316	28927	Economy	6200.00
0005435491484	28927	Economy	6200.00
0005432839260	28927	Economy	6200.00
0005434459046	28927	Economy	6200.00
0005434665004	28927	Economy	6200.00
0005434459003	28927	Economy	6200.00
0005434459099	28927	Economy	6200.00
0005432839380	28927	Economy	6200.00
0005432839452	28927	Economy	6200.00
0005432839401	28927	Economy	6200.00
0005432839296	28927	Economy	6200.00
0005432839400	28927	Economy	6200.00
0005434665005	28927	Economy	6200.00
0005435253042	28927	Economy	6200.00
0005432839409	28927	Economy	6200.00
0005432839306	28927	Economy	6200.00
0005432839336	28927	Economy	6200.00
0005432839297	28927	Economy	6200.00
0005434459112	28927	Economy	6200.00
0005434458969	28927	Economy	6200.00
0005435253052	28927	Economy	6200.00
0005432839351	28927	Economy	6200.00
0005434459048	28927	Economy	6200.00
0005432839258	28927	Economy	6200.00
0005434459005	28927	Economy	6200.00
0005434459004	28927	Economy	6200.00
0005435253046	28927	Economy	6200.00
0005435253058	28927	Economy	6200.00
0005434458924	28927	Economy	6200.00
0005432839495	28927	Economy	6200.00
0005434458940	28927	Economy	6200.00
0005432839325	28927	Economy	6200.00
0005434459024	28927	Economy	6200.00
0005435253050	28927	Economy	6200.00
0005434459121	28927	Economy	6200.00
0005432839357	28927	Economy	6200.00
0005432839531	28927	Economy	6200.00
0005432839334	28927	Economy	6200.00
0005434459039	28927	Economy	6200.00
0005432839356	28927	Economy	6200.00
0005434459098	28927	Economy	6200.00
0005435253047	28927	Economy	6200.00
0005432839259	28927	Economy	6200.00
0005432839408	28927	Economy	6200.00
0005434459120	28927	Economy	6200.00
0005432001063	28927	Economy	6200.00
0005435253045	28927	Economy	6200.00
0005435253043	28927	Economy	6200.00
0005435990762	8830	Economy	48400.00
0005434276090	8830	Economy	48400.00
0005435990760	8830	Economy	48400.00
0005435990765	8830	Economy	48400.00
0005435990764	8830	Economy	48400.00
0005435990761	8830	Economy	48400.00
0005435990763	8830	Economy	48400.00
0005434276089	8830	Economy	48400.00
0005435990766	8830	Economy	48400.00
0005435990691	15755	Business	145300.00
0005435990669	15755	Business	145300.00
0005435990702	15755	Business	145300.00
0005434276140	15755	Business	145300.00
0005434276142	15755	Economy	48400.00
0005434276139	15755	Economy	48400.00
0005435990692	15755	Economy	48400.00
0005435990694	15755	Economy	48400.00
0005435990721	15755	Economy	48400.00
0005435990701	15755	Economy	48400.00
0005434276138	15755	Economy	48400.00
0005435990693	15755	Economy	48400.00
0005435990722	15755	Economy	48400.00
0005434276141	15755	Economy	48400.00
0005435990695	15755	Economy	48400.00
0005435990720	15755	Economy	48400.00
0005433476914	20634	Economy	14500.00
0005433476919	20634	Economy	14500.00
0005433476916	20634	Economy	14500.00
0005432427185	20634	Economy	14500.00
0005432427186	20634	Economy	14500.00
0005433476913	20634	Economy	14500.00
0005433476920	20634	Economy	14500.00
0005432427182	20634	Economy	14500.00
0005433476915	20634	Economy	14500.00
0005432427183	20634	Economy	14500.00
0005432427184	20634	Economy	14500.00
0005432427157	30858	Economy	15900.00
0005433476933	30858	Economy	14500.00
0005433476935	30858	Economy	14500.00
0005432427164	30858	Economy	14500.00
0005432427151	30858	Economy	14500.00
0005433476932	30858	Economy	14500.00
0005432427167	30858	Economy	14500.00
0005432427153	30858	Economy	14500.00
0005432427170	30858	Economy	14500.00
0005432427156	30858	Economy	14500.00
0005432427152	30858	Economy	14500.00
0005433476934	30858	Economy	14500.00
0005435177402	6412	Business	36600.00
0005432062333	6412	Business	36600.00
0005432361282	6412	Business	36600.00
0005432062335	6412	Business	36600.00
0005434149857	6412	Business	36600.00
0005435177307	6412	Business	36600.00
0005434149824	6412	Business	36600.00
0005432361294	6412	Business	36600.00
0005435177384	6412	Business	36600.00
0005434149864	6412	Business	36600.00
0005432062336	6412	Business	36600.00
0005434149860	6412	Economy	12200.00
0005432361310	6412	Economy	12200.00
0005435177332	6412	Economy	12200.00
0005432361298	6412	Economy	12200.00
0005435177349	6412	Economy	12200.00
0005432361308	6412	Economy	12200.00
0005434149822	6412	Economy	12200.00
0005435177473	6412	Economy	12200.00
0005435177374	6412	Economy	12200.00
0005435177385	6412	Economy	12200.00
0005432336262	6412	Economy	12200.00
0005432361290	6412	Economy	12200.00
0005435490270	6412	Economy	12200.00
0005432361278	6412	Economy	12200.00
0005432361318	6412	Economy	12200.00
0005432363478	6412	Economy	12200.00
0005432361293	6412	Economy	12200.00
0005432336269	6412	Economy	12200.00
0005435177375	6412	Economy	12200.00
0005432363480	6412	Economy	12200.00
0005435177501	6412	Economy	12200.00
0005432361316	6412	Economy	12200.00
0005432336265	6412	Economy	12200.00
0005432361292	6412	Economy	12200.00
0005435177445	6412	Economy	12200.00
0005434149850	6412	Economy	12200.00
0005432361315	6412	Economy	12200.00
0005432361306	6412	Economy	12200.00
0005432336264	6412	Economy	12200.00
0005435177387	6412	Economy	12200.00
0005432361286	6412	Economy	12200.00
0005432361277	6412	Economy	12200.00
0005435177432	6412	Economy	12200.00
0005435177457	6412	Economy	12200.00
0005435177323	6412	Economy	12200.00
0005432361324	6412	Economy	12200.00
0005434149834	6412	Economy	13400.00
0005432361304	6412	Economy	13400.00
0005432361303	6412	Economy	13400.00
0005432361319	6412	Economy	13400.00
0005432361307	6412	Economy	13400.00
0005432062334	6412	Economy	12200.00
0005434149862	6412	Economy	13400.00
0005432336267	6412	Economy	12200.00
0005432361301	6412	Economy	12200.00
0005432336261	6412	Economy	12200.00
0005432361311	6412	Economy	12200.00
0005435177278	6412	Economy	12200.00
0005432361305	6412	Economy	12200.00
0005432361309	6412	Economy	12200.00
0005434149849	6412	Economy	12200.00
0005432361288	6412	Economy	12200.00
0005432361287	6412	Economy	12200.00
0005434149891	6412	Economy	12200.00
0005432361289	6412	Economy	12200.00
0005432062332	6412	Economy	12200.00
0005434149816	6412	Economy	12200.00
0005434149861	6412	Economy	12200.00
0005432361320	6412	Economy	12200.00
0005432361300	6412	Economy	12200.00
0005432361312	6412	Economy	12200.00
0005435177382	6412	Economy	12200.00
0005432361297	6412	Economy	12200.00
0005432361285	6412	Economy	12200.00
0005432361321	6412	Economy	12200.00
0005434149848	6412	Economy	12200.00
0005434149823	6412	Economy	12200.00
0005432363481	6412	Economy	12200.00
0005432361281	6412	Economy	12200.00
0005435177325	6412	Economy	12200.00
0005432336270	6412	Economy	12200.00
0005432361299	6412	Economy	12200.00
0005435177458	6412	Economy	12200.00
0005432363479	6412	Economy	12200.00
0005435177324	6412	Economy	12200.00
0005432361291	6412	Economy	12200.00
0005435177446	6412	Economy	12200.00
0005432361280	6412	Economy	12200.00
0005432361296	6412	Economy	12200.00
0005432361326	6412	Economy	12200.00
0005434149817	6412	Economy	12200.00
0005435177542	6412	Economy	12200.00
0005432361284	6412	Economy	12200.00
0005432336268	6412	Economy	12200.00
0005432361314	6412	Economy	12200.00
0005432361323	6412	Economy	12200.00
0005432361283	6412	Economy	12200.00
0005432361313	6412	Economy	12200.00
0005435177543	6412	Economy	12200.00
0005435177472	6412	Economy	12200.00
0005435177386	6412	Economy	12200.00
0005435177403	6412	Economy	12200.00
0005432361302	6412	Economy	12200.00
0005432361279	6412	Economy	12200.00
0005432361295	6412	Economy	12200.00
0005432336266	6412	Economy	12200.00
0005432336273	6412	Economy	12200.00
0005434149893	6412	Economy	12200.00
0005432361317	6412	Economy	12200.00
0005432336272	6412	Economy	12200.00
0005434149833	6412	Economy	12200.00
0005434149892	6412	Economy	12200.00
0005435177388	6412	Economy	12200.00
0005434149894	6412	Economy	12200.00
0005432336271	6412	Economy	12200.00
0005432336263	6412	Economy	12200.00
0005432361325	6412	Economy	12200.00
0005432361322	6412	Economy	12200.00
0005435177381	6412	Economy	12200.00
0005432363449	21023	Business	36600.00
0005435177616	21023	Business	36600.00
0005432360920	21023	Business	36600.00
0005435177603	21023	Business	36600.00
0005432336191	21023	Business	36600.00
0005432360926	21023	Business	36600.00
0005432360928	21023	Business	36600.00
0005435490301	21023	Business	36600.00
0005434149961	21023	Business	36600.00
0005435177600	21023	Economy	12200.00
0005432360896	21023	Economy	12200.00
0005432360921	21023	Economy	12200.00
0005435177617	21023	Economy	12200.00
0005432336194	21023	Economy	12200.00
0005435177611	21023	Economy	12200.00
0005432360704	21023	Economy	12200.00
0005432360985	21023	Economy	12200.00
0005432361117	21023	Economy	12200.00
0005435490302	21023	Economy	12200.00
0005435177612	21023	Economy	12200.00
0005432361045	21023	Economy	12200.00
0005432363451	21023	Economy	12200.00
0005435177608	21023	Economy	12200.00
0005432360909	21023	Economy	12200.00
0005435177624	21023	Economy	12200.00
0005432360703	21023	Economy	12200.00
0005435177607	21023	Economy	12200.00
0005432360788	21023	Economy	12200.00
0005435177618	21023	Economy	12200.00
0005432336099	21023	Economy	12200.00
0005432360760	21023	Economy	12200.00
0005432360901	21023	Economy	12200.00
0005435177614	21023	Economy	12200.00
0005432361004	21023	Economy	12200.00
0005432361175	21023	Economy	12200.00
0005435177606	21023	Economy	12200.00
0005432360869	21023	Economy	12200.00
0005434149965	21023	Economy	12200.00
0005432360592	21023	Economy	13400.00
0005435723083	21023	Economy	13400.00
0005434149964	21023	Economy	13400.00
0005435177604	21023	Economy	12200.00
0005432360905	21023	Economy	12200.00
0005432360938	21023	Economy	12200.00
0005432361021	21023	Economy	12200.00
0005432336193	21023	Economy	12200.00
0005432052806	21023	Economy	12200.00
0005432363453	21023	Economy	12200.00
0005435490304	21023	Economy	12200.00
0005435177599	21023	Economy	12200.00
0005435177609	21023	Economy	12200.00
0005432361024	21023	Economy	12200.00
0005432360900	21023	Economy	12200.00
0005432360825	21023	Economy	12200.00
0005434149955	21023	Economy	12200.00
0005432336100	21023	Economy	12200.00
0005434149957	21023	Economy	12200.00
0005432360931	21023	Economy	12200.00
0005432360721	21023	Economy	12200.00
0005435177622	21023	Economy	12200.00
0005435177605	21023	Economy	12200.00
0005432360941	21023	Economy	12200.00
0005435177621	21023	Economy	12200.00
0005432052805	21023	Economy	12200.00
0005435177623	21023	Economy	12200.00
0005432361005	21023	Economy	12200.00
0005434149956	21023	Economy	12200.00
0005435177619	21023	Economy	12200.00
0005434149963	21023	Economy	12200.00
0005432360789	21023	Economy	12200.00
0005432363450	21023	Economy	12200.00
0005434149958	21023	Economy	12200.00
0005435490303	21023	Economy	12200.00
0005432360791	21023	Economy	12200.00
0005435177626	21023	Economy	12200.00
0005432052807	21023	Economy	12200.00
0005435177613	21023	Economy	12200.00
0005432336248	21023	Economy	12200.00
0005432360868	21023	Economy	12200.00
0005432360906	21023	Economy	12200.00
0005432052804	21023	Economy	12200.00
0005432363454	21023	Economy	12200.00
0005432360932	21023	Economy	12200.00
0005434149960	21023	Economy	12200.00
0005432360870	21023	Economy	12200.00
0005432361020	21023	Economy	12200.00
0005435177627	21023	Economy	12200.00
0005432361118	21023	Economy	12200.00
0005432360937	21023	Economy	12200.00
0005432336192	21023	Economy	12200.00
0005435177620	21023	Economy	12200.00
0005435177601	21023	Economy	12200.00
0005434149959	21023	Economy	12200.00
0005435177610	21023	Economy	12200.00
0005435177615	21023	Economy	12200.00
0005432336149	21023	Economy	12200.00
0005435723082	21023	Economy	12200.00
0005432336157	21023	Economy	12200.00
0005435177602	21023	Economy	12200.00
0005432360652	21023	Economy	12200.00
0005435177625	21023	Economy	12200.00
0005432360734	21023	Economy	12200.00
0005434149962	21023	Economy	12200.00
0005434459042	17686	Economy	3400.00
0005434459056	17686	Economy	3400.00
0005434459069	17686	Economy	3100.00
0005434459031	17686	Economy	3100.00
0005434448356	17686	Economy	3100.00
0005434458998	17686	Economy	3100.00
0005434459026	17686	Economy	3100.00
0005434459013	17686	Economy	3100.00
0005434186258	17686	Economy	3100.00
0005434461668	17686	Economy	3100.00
0005434186257	17686	Economy	3100.00
0005434459027	17686	Economy	3100.00
0005434461670	17686	Economy	3100.00
0005434459022	17686	Economy	3100.00
0005434459033	17686	Economy	3100.00
0005434458993	17686	Economy	3100.00
0005434461671	17686	Economy	3100.00
0005434458992	17686	Economy	3100.00
0005434186256	17686	Economy	3100.00
0005434459081	17686	Economy	3100.00
0005434459070	17686	Economy	3100.00
0005434459041	17686	Economy	3100.00
0005434459057	17686	Economy	3100.00
0005434459054	17686	Economy	3100.00
0005434461669	17686	Economy	3100.00
0005434458997	17686	Economy	3100.00
0005434459032	17686	Economy	3100.00
0005434459021	17686	Economy	3100.00
0005434459169	17686	Economy	3100.00
0005434461676	17686	Economy	3100.00
0005434459023	17686	Economy	3100.00
0005434459212	29106	Economy	3400.00
0005434459213	29106	Economy	3400.00
0005434459200	29106	Economy	3100.00
0005434459215	29106	Economy	3100.00
0005434459211	29106	Economy	3100.00
0005434463970	29106	Economy	3100.00
0005434459205	29106	Economy	3100.00
0005434463968	29106	Economy	3100.00
0005434459221	29106	Economy	3100.00
0005434463971	29106	Economy	3100.00
0005434459208	29106	Economy	3100.00
0005434459207	29106	Economy	3100.00
0005434448379	29106	Economy	3100.00
0005434459216	29106	Economy	3100.00
0005434459206	29106	Economy	3100.00
0005434459209	29106	Economy	3100.00
0005434459214	29106	Economy	3100.00
0005434462830	29106	Economy	3100.00
0005434459217	29106	Economy	3100.00
0005434459218	29106	Economy	3100.00
0005434459220	29106	Economy	3100.00
0005434459203	29106	Economy	3100.00
0005434463969	29106	Economy	3100.00
0005434462831	29106	Economy	3100.00
0005434459219	29106	Economy	3100.00
0005434459204	29106	Economy	3100.00
0005434448380	29106	Economy	3100.00
0005434459202	29106	Economy	3100.00
0005434448381	29106	Economy	3100.00
0005434459210	29106	Economy	3100.00
0005434459201	29106	Economy	3100.00
0005432605084	21449	Economy	7300.00
0005432605068	21449	Economy	7300.00
0005432605076	21449	Economy	7300.00
0005432605086	21449	Economy	6600.00
0005432605064	21449	Economy	6600.00
0005432605088	21449	Economy	6600.00
0005432605083	21449	Economy	6600.00
0005432605097	21449	Economy	6600.00
0005432605071	21449	Economy	6600.00
0005435218122	21449	Economy	6600.00
0005432605069	21449	Economy	6600.00
0005432605087	21449	Economy	6600.00
0005432605082	21449	Economy	6600.00
0005432605066	21449	Economy	6600.00
0005432605090	21449	Economy	6600.00
0005432605063	21449	Economy	6600.00
0005432605094	21449	Economy	6600.00
0005432605085	21449	Economy	6600.00
0005432605067	21449	Economy	6600.00
0005432605096	21449	Economy	6600.00
0005432605101	21449	Economy	6600.00
0005432605075	21449	Economy	6600.00
0005435220492	21449	Economy	6600.00
0005432605070	21449	Economy	6600.00
0005432605074	21449	Economy	6600.00
0005432605098	21449	Economy	6600.00
0005432605100	21449	Economy	6600.00
0005432605077	21449	Economy	6600.00
0005432605081	21449	Economy	6600.00
0005432605080	21449	Economy	6600.00
0005432605091	21449	Economy	6600.00
0005432605095	21449	Economy	6600.00
0005432605099	21449	Economy	6600.00
0005432605089	21449	Economy	6600.00
0005432605093	21449	Economy	6600.00
0005432605062	21449	Economy	6600.00
0005432605065	21449	Economy	6600.00
0005432605078	21449	Economy	6600.00
0005432605072	21449	Economy	6600.00
0005432605073	21449	Economy	6600.00
0005432605079	21449	Economy	6600.00
0005432605092	21449	Economy	6600.00
0005432604658	31715	Economy	7300.00
0005432604716	31715	Economy	7300.00
0005432604717	31715	Economy	7300.00
0005432604764	31715	Economy	7300.00
0005432604813	31715	Economy	6600.00
0005432604779	31715	Economy	6600.00
0005432604725	31715	Economy	6600.00
0005432604689	31715	Economy	6600.00
0005432604687	31715	Economy	6600.00
0005432604707	31715	Economy	6600.00
0005432604700	31715	Economy	6600.00
0005432604918	31715	Economy	6600.00
0005432604699	31715	Economy	6600.00
0005432604571	31715	Economy	6600.00
0005432604877	31715	Economy	6600.00
0005432604702	31715	Economy	6600.00
0005432604713	31715	Economy	6600.00
0005432604664	31715	Economy	6600.00
0005432604809	31715	Economy	6600.00
0005432604701	31715	Economy	6600.00
0005432604854	31715	Economy	6600.00
0005432604878	31715	Economy	6600.00
0005432604704	31715	Economy	6600.00
0005432604819	31715	Economy	6600.00
0005432604640	31715	Economy	6600.00
0005432604688	31715	Economy	6600.00
0005432604705	31715	Economy	6600.00
0005432604703	31715	Economy	6600.00
0005432604608	31715	Economy	6600.00
0005432604827	31715	Economy	6600.00
0005432604686	31715	Economy	6600.00
0005432604850	31715	Economy	6600.00
0005432604945	31715	Economy	6600.00
0005432604812	31715	Economy	6600.00
0005432604724	31715	Economy	6600.00
0005432604884	31715	Economy	6600.00
0005432604903	31715	Economy	6600.00
0005432604706	31715	Economy	6600.00
0005432604695	31715	Economy	6600.00
0005432604904	31715	Economy	6600.00
0005432604714	31715	Economy	6600.00
0005432604580	31715	Economy	6600.00
0005432604641	31715	Economy	6600.00
0005432604611	31715	Economy	6600.00
0005432604715	31715	Economy	6600.00
0005432604669	31715	Economy	6600.00
0005432604822	31715	Economy	6600.00
0005432604919	31715	Economy	6600.00
0005433293303	12313	Economy	19500.00
0005433293302	12313	Economy	19500.00
0005433293292	12313	Economy	17800.00
0005433293304	12313	Economy	17800.00
0005435154636	12313	Economy	17800.00
0005433293310	12313	Economy	17800.00
0005433293291	12313	Economy	17800.00
0005435154631	12313	Economy	17800.00
0005433293305	12313	Economy	17800.00
0005435154635	12313	Economy	17800.00
0005433293311	12313	Economy	17800.00
0005435154632	12313	Economy	17800.00
0005433293309	12313	Economy	17800.00
0005435154633	12313	Economy	17800.00
0005433293301	12313	Economy	17800.00
0005435154629	12313	Economy	17800.00
0005435154634	12313	Economy	17800.00
0005433293307	12313	Economy	17800.00
0005435154630	12313	Economy	17800.00
0005434606870	18818	Economy	6600.00
0005434606871	18818	Economy	6600.00
0005434606864	18818	Economy	6600.00
0005434606865	18818	Economy	6600.00
0005434604964	22348	Economy	6600.00
0005434606888	22348	Economy	6600.00
0005434606889	22348	Economy	6600.00
0005434604963	22348	Economy	6600.00
0005434604965	22348	Economy	6600.00
0005434606890	22348	Economy	6600.00
0005434606887	22348	Economy	6600.00
0005434604962	22348	Economy	6600.00
0005432891220	421	Business	44500.00
0005432748313	421	Business	44500.00
0005432748310	421	Business	44500.00
0005432748320	421	Business	44500.00
0005432891235	421	Business	44500.00
0005432891228	421	Business	44500.00
0005432891255	421	Business	44500.00
0005432748304	421	Business	44500.00
0005432891171	421	Business	44500.00
0005432748305	421	Business	44500.00
0005432891188	421	Business	44500.00
0005432220087	421	Economy	14800.00
0005432748286	421	Economy	14800.00
0005433875389	421	Economy	14800.00
0005432748317	421	Economy	14800.00
0005432891246	421	Economy	14800.00
0005432748302	421	Economy	14800.00
0005432748290	421	Economy	14800.00
0005432753364	421	Economy	14800.00
0005432748296	421	Economy	14800.00
0005432891247	421	Economy	16300.00
0005432748295	421	Economy	16300.00
0005432748316	421	Economy	16300.00
0005432748315	421	Economy	16300.00
0005433293265	421	Economy	16300.00
0005432753366	421	Economy	14800.00
0005432891233	421	Economy	14800.00
0005432748318	421	Economy	14800.00
0005432220083	421	Economy	14800.00
0005432753362	421	Economy	14800.00
0005432748299	421	Economy	14800.00
0005433293286	421	Economy	14800.00
0005432891266	421	Economy	14800.00
0005433293312	421	Economy	14800.00
0005432748301	421	Economy	14800.00
0005432891180	421	Economy	14800.00
0005432891261	421	Economy	14800.00
0005432749825	421	Economy	14800.00
0005432748309	421	Economy	14800.00
0005432753363	421	Economy	14800.00
0005432748300	421	Economy	14800.00
0005432891192	421	Economy	14800.00
0005432891193	421	Economy	14800.00
0005435154637	421	Economy	14800.00
0005432748322	421	Economy	14800.00
0005432891267	421	Economy	14800.00
0005432220084	421	Economy	14800.00
0005432749826	421	Economy	14800.00
0005432751588	421	Economy	14800.00
0005432220086	421	Economy	14800.00
0005432748288	421	Economy	14800.00
0005432748323	421	Economy	14800.00
0005432748308	421	Economy	14800.00
0005432748306	421	Economy	14800.00
0005432891187	421	Economy	14800.00
0005432748292	421	Economy	14800.00
0005432891258	421	Economy	14800.00
0005432751587	421	Economy	14800.00
0005432220088	421	Economy	14800.00
0005432748311	421	Economy	14800.00
0005432891232	421	Economy	14800.00
0005432748297	421	Economy	14800.00
0005432748293	421	Economy	14800.00
0005432891227	421	Economy	14800.00
0005433293313	421	Economy	14800.00
0005432748303	421	Economy	14800.00
0005432748291	421	Economy	14800.00
0005432748321	421	Economy	14800.00
0005432748287	421	Economy	14800.00
0005432891245	421	Economy	14800.00
0005432891256	421	Economy	14800.00
0005432891257	421	Economy	14800.00
0005432751589	421	Economy	14800.00
0005432891234	421	Economy	14800.00
0005432748294	421	Economy	14800.00
0005432748289	421	Economy	14800.00
0005432891179	421	Economy	14800.00
0005432891236	421	Economy	14800.00
0005432748314	421	Economy	14800.00
0005432753365	421	Economy	14800.00
0005432748312	421	Economy	14800.00
0005432220085	421	Economy	14800.00
0005432748307	421	Economy	14800.00
0005432748319	421	Economy	14800.00
0005432891226	421	Economy	14800.00
0005432891194	421	Economy	14800.00
0005432891189	421	Economy	14800.00
0005432891154	421	Economy	14800.00
0005432748298	421	Economy	14800.00
0005432748010	12040	Business	44500.00
0005432748123	12040	Business	44500.00
0005432753346	12040	Business	44500.00
0005433293363	12040	Business	44500.00
0005432214846	12040	Business	44500.00
0005432747978	12040	Business	44500.00
0005432891404	12040	Business	44500.00
0005432891399	12040	Business	44500.00
0005433875412	12040	Business	44500.00
0005432891402	12040	Business	44500.00
0005434153559	12040	Business	44500.00
0005432747775	12040	Business	44500.00
0005432747969	12040	Economy	14800.00
0005432753341	12040	Economy	14800.00
0005435154600	12040	Economy	14800.00
0005432748022	12040	Economy	14800.00
0005432747934	12040	Economy	14800.00
0005434152853	12040	Economy	14800.00
0005432748054	12040	Economy	14800.00
0005432747841	12040	Economy	14800.00
0005432748113	12040	Economy	14800.00
0005434153560	12040	Economy	14800.00
0005433293364	12040	Economy	16300.00
0005432891406	12040	Economy	16300.00
0005432747938	12040	Economy	16300.00
0005432747997	12040	Economy	16300.00
0005432747829	12040	Economy	16300.00
0005432891409	12040	Economy	14800.00
0005432747936	12040	Economy	14800.00
0005432748027	12040	Economy	14800.00
0005432747961	12040	Economy	14800.00
0005433293354	12040	Economy	14800.00
0005432748040	12040	Economy	14800.00
0005432747897	12040	Economy	14800.00
0005432891403	12040	Economy	14800.00
0005433293359	12040	Economy	14800.00
0005432747875	12040	Economy	14800.00
0005432891397	12040	Economy	14800.00
0005433875411	12040	Economy	14800.00
0005432891396	12040	Economy	14800.00
0005433293362	12040	Economy	14800.00
0005432747828	12040	Economy	14800.00
0005432891395	12040	Economy	14800.00
0005432891405	12040	Economy	14800.00
0005432891398	12040	Economy	14800.00
0005432891393	12040	Economy	14800.00
0005433293367	12040	Economy	14800.00
0005432756869	12040	Economy	14800.00
0005432748026	12040	Economy	14800.00
0005432748025	12040	Economy	14800.00
0005433293369	12040	Economy	14800.00
0005432891407	12040	Economy	14800.00
0005434153558	12040	Economy	14800.00
0005432747993	12040	Economy	14800.00
0005433293368	12040	Economy	14800.00
0005432747937	12040	Economy	14800.00
0005433293355	12040	Economy	14800.00
0005433293356	12040	Economy	14800.00
0005432891410	12040	Economy	14800.00
0005435154598	12040	Economy	14800.00
0005432891408	12040	Economy	14800.00
0005435154599	12040	Economy	14800.00
0005433293353	12040	Economy	14800.00
0005433293357	12040	Economy	14800.00
0005432747808	12040	Economy	14800.00
0005432753338	12040	Economy	14800.00
0005432747953	12040	Economy	14800.00
0005432747899	12040	Economy	14800.00
0005432748076	12040	Economy	14800.00
0005433293352	12040	Economy	14800.00
0005433293361	12040	Economy	14800.00
0005432891394	12040	Economy	14800.00
0005435154601	12040	Economy	14800.00
0005432747891	12040	Economy	14800.00
0005432748043	12040	Economy	14800.00
0005433293360	12040	Economy	14800.00
0005432747968	12040	Economy	14800.00
0005432891401	12040	Economy	14800.00
0005432756872	12040	Economy	14800.00
0005432756871	12040	Economy	14800.00
0005432749800	12040	Economy	14800.00
0005433293370	12040	Economy	14800.00
0005432748041	12040	Economy	14800.00
0005433293366	12040	Economy	14800.00
0005432748042	12040	Economy	14800.00
0005434152852	12040	Economy	14800.00
0005432891400	12040	Economy	14800.00
0005432747954	12040	Economy	14800.00
0005433293358	12040	Economy	14800.00
0005432747960	12040	Economy	14800.00
0005432747898	12040	Economy	14800.00
0005432748077	12040	Economy	14800.00
0005433293365	12040	Economy	14800.00
0005432747970	12040	Economy	14800.00
0005432214845	12040	Economy	14800.00
0005433525237	18990	Economy	28200.00
0005433525248	18990	Economy	28200.00
0005432928033	18990	Economy	28200.00
0005433525245	18990	Economy	28200.00
0005433525242	18990	Economy	25700.00
0005433525244	18990	Economy	25700.00
0005433531363	18990	Economy	25700.00
0005433525241	18990	Economy	25700.00
0005433531364	18990	Economy	25700.00
0005433533378	18990	Economy	25700.00
0005433525236	18990	Economy	25700.00
0005433525238	18990	Economy	25700.00
0005433531365	18990	Economy	25700.00
0005433525240	18990	Economy	25700.00
0005432928035	18990	Economy	25700.00
0005433533379	18990	Economy	25700.00
0005432928051	18990	Economy	25700.00
0005433525239	18990	Economy	25700.00
0005432928046	18990	Economy	25700.00
0005433525243	18990	Economy	25700.00
0005433525246	18990	Economy	25700.00
0005433525247	18990	Economy	25700.00
0005433527296	32491	Economy	28200.00
0005432928096	32491	Economy	28200.00
0005433531340	32491	Economy	28200.00
0005433531333	32491	Economy	28200.00
0005433525126	32491	Economy	25700.00
0005432928094	32491	Economy	25700.00
0005432928093	32491	Economy	25700.00
0005433525172	32491	Economy	25700.00
0005433527294	32491	Economy	25700.00
0005433525189	32491	Economy	25700.00
0005432928095	32491	Economy	25700.00
0005433527297	32491	Economy	25700.00
0005433531334	32491	Economy	25700.00
0005432928097	32491	Economy	25700.00
0005433525168	32491	Economy	25700.00
0005433525135	32491	Economy	25700.00
0005433527295	32491	Economy	25700.00
0005433525133	32491	Economy	25700.00
0005433531339	32491	Economy	25700.00
0005433525149	32491	Economy	25700.00
0005433531335	32491	Economy	25700.00
0005433525142	32491	Economy	25700.00
0005433525134	32491	Economy	25700.00
0005433525153	32491	Economy	25700.00
0005433525174	32491	Economy	25700.00
0005433525154	32491	Economy	25700.00
0005433527306	32491	Economy	25700.00
0005433525107	32491	Economy	25700.00
0005432928092	32491	Economy	25700.00
0005434826066	5291	Business	84000.00
0005435373914	5291	Business	84000.00
0005435304184	5291	Business	84000.00
0005435373937	5291	Business	84000.00
0005434826063	5291	Business	84000.00
0005434826011	5291	Business	84000.00
0005435304216	5291	Business	84000.00
0005432121601	5291	Business	84000.00
0005434826103	5291	Business	84000.00
0005434826086	5291	Business	84000.00
0005434825994	5291	Business	84000.00
0005434826010	5291	Business	84000.00
0005434831236	5291	Business	84000.00
0005435373622	5291	Business	84000.00
0005434826102	5291	Business	84000.00
0005434826005	5291	Business	84000.00
0005434826075	5291	Business	84000.00
0005435374096	5291	Business	84000.00
0005435374073	5291	Business	84000.00
0005435373765	5291	Business	84000.00
0005435373786	5291	Business	84000.00
0005435150303	5291	Business	84000.00
0005434828748	5291	Business	84000.00
0005435304215	5291	Business	84000.00
0005435178999	5291	Business	84000.00
0005434826071	5291	Comfort	47600.00
0005434825992	5291	Comfort	47600.00
0005434826109	5291	Comfort	47600.00
0005432121607	5291	Comfort	47600.00
0005434826081	5291	Comfort	47600.00
0005434826018	5291	Comfort	47600.00
0005435386646	5291	Comfort	47600.00
0005435374013	5291	Comfort	47600.00
0005435373885	5291	Comfort	47600.00
0005435373992	5291	Comfort	47600.00
0005435374090	5291	Comfort	47600.00
0005434826056	5291	Comfort	47600.00
0005435374228	5291	Comfort	47600.00
0005434826039	5291	Comfort	47600.00
0005434826072	5291	Comfort	47600.00
0005434825988	5291	Comfort	47600.00
0005434826059	5291	Comfort	47600.00
0005435178998	5291	Comfort	47600.00
0005432394183	5291	Comfort	47600.00
0005434558440	5291	Comfort	47600.00
0005434826101	5291	Comfort	47600.00
0005434826073	5291	Comfort	47600.00
0005434826085	5291	Comfort	47600.00
0005434826114	5291	Comfort	47600.00
0005435373985	5291	Comfort	47600.00
0005434826076	5291	Comfort	47600.00
0005435735177	5291	Comfort	47600.00
0005435373916	5291	Comfort	47600.00
0005435299851	5291	Comfort	47600.00
0005435373738	5291	Comfort	47600.00
0005432394181	5291	Comfort	47600.00
0005434826108	5291	Comfort	47600.00
0005435150306	5291	Comfort	47600.00
0005432394184	5291	Economy	28000.00
0005435735174	5291	Economy	28000.00
0005434826021	5291	Economy	28000.00
0005434831239	5291	Economy	28000.00
0005435373846	5291	Economy	28000.00
0005434825986	5291	Economy	28000.00
0005434826087	5291	Economy	28000.00
0005434826112	5291	Economy	28000.00
0005434828749	5291	Economy	28000.00
0005435373879	5291	Economy	28000.00
0005432121611	5291	Economy	28000.00
0005434826040	5291	Economy	28000.00
0005435374153	5291	Economy	28000.00
0005435374012	5291	Economy	28000.00
0005434558442	5291	Economy	28000.00
0005435299843	5291	Economy	28000.00
0005434826051	5291	Economy	28000.00
0005434826052	5291	Economy	28000.00
0005434826064	5291	Economy	28000.00
0005434826047	5291	Economy	28000.00
0005434826015	5291	Economy	28000.00
0005434826027	5291	Economy	28000.00
0005434826022	5291	Economy	28000.00
0005434826093	5291	Economy	28000.00
0005434558445	5291	Economy	28000.00
0005434826000	5291	Economy	28000.00
0005434826091	5291	Economy	28000.00
0005434665003	5291	Economy	28000.00
0005432121614	5291	Economy	28000.00
0005434826048	5291	Economy	28000.00
0005434826097	5291	Economy	28000.00
0005432823472	5291	Economy	28000.00
0005434826098	5291	Economy	28000.00
0005435374199	5291	Economy	28000.00
0005434826004	5291	Economy	28000.00
0005435374277	5291	Economy	28000.00
0005434826033	5291	Economy	28000.00
0005435735175	5291	Economy	28000.00
0005434826054	5291	Economy	28000.00
0005432396320	5291	Economy	28000.00
0005434558436	5291	Economy	28000.00
0005435373764	5291	Economy	28000.00
0005434826099	5291	Economy	28000.00
0005434826003	5291	Economy	30800.00
0005435150307	5291	Economy	30800.00
0005434558446	5291	Economy	28000.00
0005435373817	5291	Economy	28000.00
0005434825999	5291	Economy	28000.00
0005435735178	5291	Economy	28000.00
0005432394182	5291	Economy	30800.00
0005435373909	5291	Economy	28000.00
0005435150295	5291	Economy	30800.00
0005434826079	5291	Economy	28000.00
0005434826092	5291	Economy	28000.00
0005435374000	5291	Economy	28000.00
0005435373654	5291	Economy	28000.00
0005434826089	5291	Economy	28000.00
0005435386633	5291	Economy	28000.00
0005435373797	5291	Economy	28000.00
0005434826035	5291	Economy	28000.00
0005435735195	5291	Economy	28000.00
0005435374001	5291	Economy	28000.00
0005435304219	5291	Economy	28000.00
0005432121610	5291	Economy	28000.00
0005435373880	5291	Economy	28000.00
0005434825990	5291	Economy	28000.00
0005434826029	5291	Economy	28000.00
0005434825989	5291	Economy	28000.00
0005435150296	5291	Economy	28000.00
0005434825987	5291	Economy	28000.00
0005435150297	5291	Economy	28000.00
0005434558435	5291	Economy	28000.00
0005434826034	5291	Economy	28000.00
0005434826049	5291	Economy	28000.00
0005435373995	5291	Economy	28000.00
0005435735173	5291	Economy	28000.00
0005434826068	5291	Economy	28000.00
0005434558443	5291	Economy	28000.00
0005435373886	5291	Economy	28000.00
0005435374276	5291	Economy	28000.00
0005434826088	5291	Economy	28000.00
0005434826100	5291	Economy	28000.00
0005434826096	5291	Economy	28000.00
0005432121603	5291	Economy	28000.00
0005435373694	5291	Economy	28000.00
0005434826007	5291	Economy	28000.00
0005434826070	5291	Economy	28000.00
0005432121608	5291	Economy	28000.00
0005434825998	5291	Economy	28000.00
0005435374002	5291	Economy	28000.00
0005435373818	5291	Economy	28000.00
0005435373988	5291	Economy	28000.00
0005434826008	5291	Economy	28000.00
0005435373957	5291	Economy	28000.00
0005432121604	5291	Economy	28000.00
0005435373911	5291	Economy	28000.00
0005434826050	5291	Economy	28000.00
0005435374014	5291	Economy	28000.00
0005432121609	5291	Economy	28000.00
0005434558434	5291	Economy	28000.00
0005434826023	5291	Economy	28000.00
0005435386643	5291	Economy	28000.00
0005434826082	5291	Economy	28000.00
0005434826037	5291	Economy	28000.00
0005432121605	5291	Economy	28000.00
0005435299823	5291	Economy	28000.00
0005435150304	5291	Economy	28000.00
0005435374064	5291	Economy	28000.00
0005435150305	5291	Economy	28000.00
0005434826062	5291	Economy	28000.00
0005435373910	5291	Economy	28000.00
0005434831237	5291	Economy	28000.00
0005435304190	5291	Economy	28000.00
0005434826057	5291	Economy	28000.00
0005434826110	5291	Economy	28000.00
0005434826014	5291	Economy	28000.00
0005434826106	5291	Economy	28000.00
0005432823471	5291	Economy	28000.00
0005435150294	5291	Economy	28000.00
0005432396319	5291	Economy	28000.00
0005435661943	5291	Economy	28000.00
0005435374095	5291	Economy	28000.00
0005432121602	5291	Economy	28000.00
0005434826046	5291	Economy	28000.00
0005434826030	5291	Economy	28000.00
0005434826053	5291	Economy	28000.00
0005434826032	5291	Economy	28000.00
0005434826036	5291	Economy	28000.00
0005435373833	5291	Economy	28000.00
0005434826095	5291	Economy	28000.00
0005435299825	5291	Economy	28000.00
0005435374062	5291	Economy	28000.00
0005434826020	5291	Economy	28000.00
0005434826080	5291	Economy	28000.00
0005434826044	5291	Economy	28000.00
0005434825991	5291	Economy	28000.00
0005434825996	5291	Economy	28000.00
0005432121612	5291	Economy	28000.00
0005434826041	5291	Economy	28000.00
0005434825995	5291	Economy	28000.00
0005434826113	5291	Economy	30800.00
0005434826045	5291	Economy	28000.00
0005434826115	5291	Economy	30800.00
0005435374063	5291	Economy	30800.00
0005435299845	5291	Economy	30800.00
0005434826038	5291	Economy	30800.00
0005434826067	5291	Economy	28000.00
0005435373798	5291	Economy	28000.00
0005435374097	5291	Economy	28000.00
0005434558444	5291	Economy	28000.00
0005435304222	5291	Economy	28000.00
0005434826061	5291	Economy	28000.00
0005434826078	5291	Economy	28000.00
0005434831238	5291	Economy	28000.00
0005435373751	5291	Economy	28000.00
0005434826016	5291	Economy	28000.00
0005434826069	5291	Economy	28000.00
0005435299844	5291	Economy	28000.00
0005434826019	5291	Economy	28000.00
0005435735155	5291	Economy	28000.00
0005434826060	5291	Economy	28000.00
0005435374078	5291	Economy	28000.00
0005434826105	5291	Economy	28000.00
0005434826042	5291	Economy	28000.00
0005435386624	5291	Economy	28000.00
0005434826009	5291	Economy	28000.00
0005434826084	5291	Economy	28000.00
0005434826043	5291	Economy	28000.00
0005434558439	5291	Economy	28000.00
0005434826001	5291	Economy	28000.00
0005434826074	5291	Economy	28000.00
0005434826006	5291	Economy	28000.00
0005435150308	5291	Economy	28000.00
0005435373834	5291	Economy	28000.00
0005434825997	5291	Economy	28000.00
0005435150302	5291	Economy	28000.00
0005434826028	5291	Economy	28000.00
0005435661942	5291	Economy	28000.00
0005435150300	5291	Economy	28000.00
0005435299817	5291	Economy	28000.00
0005434826104	5291	Economy	28000.00
0005435374230	5291	Economy	28000.00
0005435374227	5291	Economy	28000.00
0005434831241	5291	Economy	28000.00
0005435373915	5291	Economy	28000.00
0005435373887	5291	Economy	28000.00
0005434825993	5291	Economy	28000.00
0005435373890	5291	Economy	28000.00
0005434831240	5291	Economy	28000.00
0005432121606	5291	Economy	28000.00
0005435374194	5291	Economy	28000.00
0005434826065	5291	Economy	28000.00
0005434558438	5291	Economy	28000.00
0005435373974	5291	Economy	28000.00
0005434826083	5291	Economy	28000.00
0005435373956	5291	Economy	28000.00
0005434826077	5291	Economy	28000.00
0005435386625	5291	Economy	28000.00
0005434826002	5291	Economy	28000.00
0005432121615	5291	Economy	28000.00
0005434558437	5291	Economy	28000.00
0005434826107	5291	Economy	28000.00
0005432396317	5291	Economy	28000.00
0005432121613	5291	Economy	28000.00
0005435150298	5291	Economy	28000.00
0005434826013	5291	Economy	28000.00
0005435386610	5291	Economy	28000.00
0005434826026	5291	Economy	28000.00
0005434828750	5291	Economy	28000.00
0005434826024	5291	Economy	28000.00
0005435150299	5291	Economy	28000.00
0005434558441	5291	Economy	28000.00
0005434826025	5291	Economy	28000.00
0005435374229	5291	Economy	28000.00
0005435374125	5291	Economy	28000.00
0005434826031	5291	Economy	28000.00
0005434826017	5291	Economy	28000.00
0005435374043	5291	Economy	28000.00
0005434826094	5291	Economy	28000.00
0005434826055	5291	Economy	28000.00
0005435374089	5291	Economy	28000.00
0005435374015	5291	Economy	28000.00
0005434826090	5291	Economy	28000.00
0005434826012	5291	Economy	28000.00
0005435304218	5291	Economy	28000.00
0005435373746	5291	Economy	28000.00
0005434826111	5291	Economy	28000.00
0005435661964	5291	Economy	28000.00
0005435150301	5291	Economy	28000.00
0005434826058	5291	Economy	28000.00
0005432396318	5291	Economy	28000.00
0005435299824	5291	Economy	28000.00
0005435374531	9885	Business	84000.00
0005434825161	9885	Business	84000.00
0005434825589	9885	Business	84000.00
0005434825156	9885	Business	84000.00
0005434825041	9885	Business	84000.00
0005435374556	9885	Business	84000.00
0005434825351	9885	Business	84000.00
0005434824846	9885	Business	84000.00
0005435374549	9885	Business	84000.00
0005435314969	9885	Business	84000.00
0005435374519	9885	Business	84000.00
0005435374552	9885	Business	84000.00
0005434824594	9885	Business	84000.00
0005435374544	9885	Business	84000.00
0005432396298	9885	Business	84000.00
0005435386698	9885	Business	84000.00
0005434824959	9885	Business	84000.00
0005435374511	9885	Business	84000.00
0005435374559	9885	Business	84000.00
0005434824508	9885	Business	84000.00
0005434824716	9885	Business	84000.00
0005435374510	9885	Business	84000.00
0005434825033	9885	Business	84000.00
0005434824848	9885	Business	84000.00
0005435374527	9885	Business	84000.00
0005435179413	9885	Comfort	47600.00
0005434558364	9885	Comfort	47600.00
0005435374514	9885	Comfort	47600.00
0005434824898	9885	Comfort	47600.00
0005434825077	9885	Comfort	47600.00
0005435299869	9885	Comfort	47600.00
0005435374518	9885	Comfort	47600.00
0005435299870	9885	Comfort	47600.00
0005434825398	9885	Comfort	47600.00
0005435386703	9885	Comfort	47600.00
0005434825174	9885	Comfort	47600.00
0005435150122	9885	Comfort	47600.00
0005434824746	9885	Comfort	47600.00
0005434825155	9885	Comfort	47600.00
0005435374523	9885	Comfort	47600.00
0005434824990	9885	Comfort	47600.00
0005432396285	9885	Comfort	47600.00
0005434824715	9885	Comfort	47600.00
0005435314973	9885	Comfort	47600.00
0005434558405	9885	Comfort	47600.00
0005434824718	9885	Comfort	47600.00
0005432203201	9885	Comfort	47600.00
0005434824589	9885	Comfort	47600.00
0005435374530	9885	Comfort	47600.00
0005435374505	9885	Comfort	47600.00
0005435735227	9885	Comfort	47600.00
0005434558355	9885	Comfort	47600.00
0005434825510	9885	Comfort	47600.00
0005434824868	9885	Comfort	47600.00
0005435374528	9885	Comfort	47600.00
0005434825124	9885	Comfort	47600.00
0005434824664	9885	Comfort	47600.00
0005434824808	9885	Economy	28000.00
0005435150183	9885	Economy	28000.00
0005434558348	9885	Economy	28000.00
0005434825026	9885	Economy	28000.00
0005434824433	9885	Economy	28000.00
0005435374506	9885	Economy	28000.00
0005434824847	9885	Economy	28000.00
0005435374515	9885	Economy	28000.00
0005434824663	9885	Economy	28000.00
0005434824982	9885	Economy	28000.00
0005435374522	9885	Economy	28000.00
0005435374560	9885	Economy	28000.00
0005435374554	9885	Economy	28000.00
0005434824965	9885	Economy	28000.00
0005434825588	9885	Economy	28000.00
0005434558336	9885	Economy	28000.00
0005432203207	9885	Economy	28000.00
0005435374538	9885	Economy	28000.00
0005434824736	9885	Economy	28000.00
0005434824804	9885	Economy	28000.00
0005434824556	9885	Economy	28000.00
0005435374535	9885	Economy	28000.00
0005434825157	9885	Economy	28000.00
0005434558329	9885	Economy	28000.00
0005435374529	9885	Economy	28000.00
0005435386704	9885	Economy	28000.00
0005434558385	9885	Economy	28000.00
0005435386701	9885	Economy	28000.00
0005432203205	9885	Economy	28000.00
0005434558382	9885	Economy	28000.00
0005435302288	9885	Economy	28000.00
0005435374517	9885	Economy	28000.00
0005432400161	9885	Economy	28000.00
0005435374561	9885	Economy	28000.00
0005434824903	9885	Economy	28000.00
0005435150164	9885	Economy	28000.00
0005434824723	9885	Economy	28000.00
0005434825385	9885	Economy	28000.00
0005434824976	9885	Economy	28000.00
0005434825403	9885	Economy	28000.00
0005434825373	9885	Economy	30800.00
0005435314974	9885	Economy	28000.00
0005435386697	9885	Economy	30800.00
0005434558347	9885	Economy	28000.00
0005434824634	9885	Economy	30800.00
0005434824730	9885	Economy	28000.00
0005434824633	9885	Economy	28000.00
0005432396299	9885	Economy	30800.00
0005435374520	9885	Economy	28000.00
0005435661988	9885	Economy	28000.00
0005435374497	9885	Economy	28000.00
0005435374542	9885	Economy	28000.00
0005434825278	9885	Economy	28000.00
0005434824465	9885	Economy	28000.00
0005435299867	9885	Economy	28000.00
0005435374553	9885	Economy	28000.00
0005435374539	9885	Economy	28000.00
0005435374500	9885	Economy	28000.00
0005434824744	9885	Economy	28000.00
0005434825233	9885	Economy	28000.00
0005434825160	9885	Economy	28000.00
0005435735229	9885	Economy	28000.00
0005435374524	9885	Economy	28000.00
0005435374525	9885	Economy	28000.00
0005434824892	9885	Economy	28000.00
0005434831188	9885	Economy	28000.00
0005435179704	9885	Economy	28000.00
0005435374501	9885	Economy	28000.00
0005434558383	9885	Economy	28000.00
0005434825080	9885	Economy	28000.00
0005435374562	9885	Economy	28000.00
0005435374550	9885	Economy	28000.00
0005434831197	9885	Economy	28000.00
0005434825336	9885	Economy	28000.00
0005435374536	9885	Economy	28000.00
0005435374558	9885	Economy	28000.00
0005434558312	9885	Economy	28000.00
0005435374540	9885	Economy	28000.00
0005432203200	9885	Economy	28000.00
0005434558351	9885	Economy	28000.00
0005435302291	9885	Economy	28000.00
0005435386696	9885	Economy	28000.00
0005434824507	9885	Economy	28000.00
0005434825254	9885	Economy	28000.00
0005434825135	9885	Economy	28000.00
0005435374509	9885	Economy	28000.00
0005435661989	9885	Economy	28000.00
0005435374507	9885	Economy	28000.00
0005432203202	9885	Economy	28000.00
0005434824946	9885	Economy	28000.00
0005435374504	9885	Economy	28000.00
0005435374541	9885	Economy	28000.00
0005432396300	9885	Economy	28000.00
0005435374503	9885	Economy	28000.00
0005435374512	9885	Economy	28000.00
0005435374543	9885	Economy	28000.00
0005434825350	9885	Economy	28000.00
0005435386702	9885	Economy	28000.00
0005434825027	9885	Economy	28000.00
0005435374496	9885	Economy	28000.00
0005434558374	9885	Economy	28000.00
0005434824501	9885	Economy	28000.00
0005432823490	9885	Economy	28000.00
0005435179412	9885	Economy	28000.00
0005434824307	9885	Economy	28000.00
0005435735230	9885	Economy	28000.00
0005434825317	9885	Economy	28000.00
0005434828713	9885	Economy	28000.00
0005435374551	9885	Economy	28000.00
0005435374516	9885	Economy	28000.00
0005435374545	9885	Economy	28000.00
0005435314972	9885	Economy	28000.00
0005434825092	9885	Economy	28000.00
0005434824788	9885	Economy	28000.00
0005435661987	9885	Economy	28000.00
0005435302290	9885	Economy	28000.00
0005435374534	9885	Economy	28000.00
0005432400156	9885	Economy	28000.00
0005434824906	9885	Economy	28000.00
0005434558398	9885	Economy	28000.00
0005435386700	9885	Economy	28000.00
0005434825402	9885	Economy	28000.00
0005435735228	9885	Economy	30800.00
0005435374498	9885	Economy	30800.00
0005435374533	9885	Economy	30800.00
0005434825481	9885	Economy	30800.00
0005435374532	9885	Economy	30800.00
0005432203203	9885	Economy	28000.00
0005434824729	9885	Economy	28000.00
0005432400159	9885	Economy	28000.00
0005432400160	9885	Economy	28000.00
0005434825075	9885	Economy	28000.00
0005435302289	9885	Economy	28000.00
0005434824852	9885	Economy	28000.00
0005434825701	9885	Economy	28000.00
0005434824638	9885	Economy	28000.00
0005434825126	9885	Economy	28000.00
0005435374546	9885	Economy	28000.00
0005434824471	9885	Economy	28000.00
0005435314970	9885	Economy	28000.00
0005435374508	9885	Economy	28000.00
0005435374521	9885	Economy	28000.00
0005434824621	9885	Economy	28000.00
0005434825108	9885	Economy	28000.00
0005435735231	9885	Economy	28000.00
0005435302292	9885	Economy	28000.00
0005434825134	9885	Economy	28000.00
0005435374547	9885	Economy	28000.00
0005432203206	9885	Economy	28000.00
0005434824765	9885	Economy	28000.00
0005435150190	9885	Economy	28000.00
0005434824807	9885	Economy	28000.00
0005434824983	9885	Economy	28000.00
0005435374555	9885	Economy	28000.00
0005434825184	9885	Economy	28000.00
0005434825337	9885	Economy	28000.00
0005434824834	9885	Economy	28000.00
0005435299868	9885	Economy	28000.00
0005434824799	9885	Economy	28000.00
0005434831183	9885	Economy	28000.00
0005434824964	9885	Economy	28000.00
0005434824797	9885	Economy	28000.00
0005434558363	9885	Economy	28000.00
0005434831196	9885	Economy	28000.00
0005435374537	9885	Economy	28000.00
0005434825065	9885	Economy	28000.00
0005434824867	9885	Economy	28000.00
0005434824994	9885	Economy	28000.00
0005434824708	9885	Economy	28000.00
0005435374526	9885	Economy	28000.00
0005434824502	9885	Economy	28000.00
0005434558395	9885	Economy	28000.00
0005434825386	9885	Economy	28000.00
0005434825192	9885	Economy	28000.00
0005434825122	9885	Economy	28000.00
0005435314971	9885	Economy	28000.00
0005434825169	9885	Economy	28000.00
0005435374499	9885	Economy	28000.00
0005435150163	9885	Economy	28000.00
0005435374513	9885	Economy	28000.00
0005434825361	9885	Economy	28000.00
0005434824835	9885	Economy	28000.00
0005435179705	9885	Economy	28000.00
0005435386699	9885	Economy	28000.00
0005434558335	9885	Economy	28000.00
0005435374557	9885	Economy	28000.00
0005434824886	9885	Economy	28000.00
0005435374502	9885	Economy	28000.00
0005435374548	9885	Economy	28000.00
0005432203204	9885	Economy	28000.00
0005434825683	9885	Economy	28000.00
0005435150123	9885	Economy	28000.00
0005434825022	9885	Economy	28000.00
0005434825538	9885	Economy	28000.00
0005435790364	7000	Economy	7400.00
0005435082951	7000	Economy	7400.00
0005435082950	7000	Economy	7400.00
0005435790363	7000	Economy	7400.00
0005435082949	7000	Economy	7400.00
0005435790362	7000	Economy	7400.00
0005435790365	7000	Economy	7400.00
0005435082948	7000	Economy	7400.00
0005435082867	26022	Economy	8200.00
0005435082854	26022	Economy	7400.00
0005435082863	26022	Economy	7400.00
0005435790350	26022	Economy	7400.00
0005435082860	26022	Economy	7400.00
0005435082865	26022	Economy	7400.00
0005435082855	26022	Economy	7400.00
0005435082873	26022	Economy	7400.00
0005435082866	26022	Economy	7400.00
0005434214736	9540	Business	32800.00
0005434215036	9540	Business	32800.00
0005434757206	9540	Business	32800.00
0005434214974	9540	Business	32800.00
0005434215000	9540	Business	32800.00
0005434214965	9540	Business	32800.00
0005434757199	9540	Business	32800.00
0005434214826	9540	Business	32800.00
0005434214934	9540	Business	32800.00
0005434757211	9540	Business	32800.00
0005434757204	9540	Business	32800.00
0005434214971	9540	Business	32800.00
0005434214833	9540	Economy	10900.00
0005434757216	9540	Economy	10900.00
0005434757231	9540	Economy	10900.00
0005434214959	9540	Economy	10900.00
0005434214975	9540	Economy	10900.00
0005434214844	9540	Economy	10900.00
0005434215200	9540	Economy	10900.00
0005434757215	9540	Economy	10900.00
0005434757200	9540	Economy	10900.00
0005434215043	9540	Economy	10900.00
0005434757243	9540	Economy	12000.00
0005434757246	9540	Economy	12000.00
0005434757214	9540	Economy	12000.00
0005434757239	9540	Economy	12000.00
0005434214918	9540	Economy	12000.00
0005434214866	9540	Economy	10900.00
0005434215001	9540	Economy	10900.00
0005434757233	9540	Economy	10900.00
0005434757236	9540	Economy	10900.00
0005434757213	9540	Economy	10900.00
0005434757198	9540	Economy	10900.00
0005434757220	9540	Economy	10900.00
0005434757244	9540	Economy	10900.00
0005434757223	9540	Economy	10900.00
0005434215201	9540	Economy	10900.00
0005434757209	9540	Economy	10900.00
0005434214864	9540	Economy	10900.00
0005434757205	9540	Economy	10900.00
0005434214936	9540	Economy	10900.00
0005434214982	9540	Economy	10900.00
0005434757221	9540	Economy	10900.00
0005434757225	9540	Economy	10900.00
0005434757237	9540	Economy	10900.00
0005434757234	9540	Economy	10900.00
0005434757229	9540	Economy	10900.00
0005434757212	9540	Economy	10900.00
0005434757240	9540	Economy	10900.00
0005434757207	9540	Economy	10900.00
0005434757228	9540	Economy	10900.00
0005434757201	9540	Economy	10900.00
0005434214827	9540	Economy	10900.00
0005434215088	9540	Economy	10900.00
0005434214986	9540	Economy	10900.00
0005434757218	9540	Economy	10900.00
0005434214939	9540	Economy	10900.00
0005434214792	9540	Economy	10900.00
0005434214903	9540	Economy	10900.00
0005434215126	9540	Economy	10900.00
0005434757227	9540	Economy	10900.00
0005434757226	9540	Economy	10900.00
0005434757232	9540	Economy	10900.00
0005434757241	9540	Economy	10900.00
0005434757202	9540	Economy	10900.00
0005434214963	9540	Economy	10900.00
0005434215205	9540	Economy	10900.00
0005434757238	9540	Economy	10900.00
0005434757224	9540	Economy	10900.00
0005434214935	9540	Economy	10900.00
0005434757242	9540	Economy	10900.00
0005434757245	9540	Economy	10900.00
0005434757222	9540	Economy	10900.00
0005434214949	9540	Economy	10900.00
0005434215127	9540	Economy	10900.00
0005434757210	9540	Economy	10900.00
0005434214915	9540	Economy	10900.00
0005434214998	9540	Economy	10900.00
0005434215143	9540	Economy	10900.00
0005434757217	9540	Economy	10900.00
0005434757208	9540	Economy	10900.00
0005434215067	9540	Economy	10900.00
0005434757235	9540	Economy	10900.00
0005434215051	9540	Economy	10900.00
0005434214791	9540	Economy	10900.00
0005434757230	9540	Economy	10900.00
0005434214877	9540	Economy	10900.00
0005434757219	9540	Economy	10900.00
0005434214937	9540	Economy	10900.00
0005434214904	9540	Economy	10900.00
0005434757203	9540	Economy	10900.00
0005434214790	9540	Economy	10900.00
0005434757197	9540	Economy	10900.00
0005434215068	9540	Economy	10900.00
0005434214865	9540	Economy	10900.00
0005434214861	9540	Economy	10900.00
0005434757050	28630	Business	32800.00
0005434215409	28630	Business	32800.00
0005434215365	28630	Business	32800.00
0005434215399	28630	Business	32800.00
0005434215397	28630	Business	32800.00
0005434756764	28630	Business	32800.00
0005434756762	28630	Business	32800.00
0005434215400	28630	Business	32800.00
0005434756881	28630	Business	32800.00
0005434756582	28630	Business	32800.00
0005434215389	28630	Business	32800.00
0005434756726	28630	Business	32800.00
0005434215404	28630	Economy	10900.00
0005434756717	28630	Economy	10900.00
0005434215372	28630	Economy	10900.00
0005434756478	28630	Economy	10900.00
0005434215408	28630	Economy	10900.00
0005434756895	28630	Economy	10900.00
0005434756947	28630	Economy	10900.00
0005434215407	28630	Economy	10900.00
0005434756669	28630	Economy	10900.00
0005434215375	28630	Economy	10900.00
0005434215382	28630	Economy	12000.00
0005434215364	28630	Economy	12000.00
0005434215405	28630	Economy	12000.00
0005434215390	28630	Economy	12000.00
0005434756910	28630	Economy	12000.00
0005434756754	28630	Economy	10900.00
0005434215378	28630	Economy	10900.00
0005434756642	28630	Economy	10900.00
0005434756829	28630	Economy	10900.00
0005434756887	28630	Economy	10900.00
0005434215373	28630	Economy	10900.00
0005434756759	28630	Economy	10900.00
0005434215368	28630	Economy	10900.00
0005434215402	28630	Economy	10900.00
0005434756668	28630	Economy	10900.00
0005434215385	28630	Economy	10900.00
0005434756509	28630	Economy	10900.00
0005434756625	28630	Economy	10900.00
0005434756667	28630	Economy	10900.00
0005434756849	28630	Economy	10900.00
0005434215387	28630	Economy	10900.00
0005434215370	28630	Economy	10900.00
0005434215377	28630	Economy	10900.00
0005434215367	28630	Economy	10900.00
0005434215401	28630	Economy	10900.00
0005434757003	28630	Economy	10900.00
0005434756765	28630	Economy	10900.00
0005434215376	28630	Economy	10900.00
0005434756842	28630	Economy	10900.00
0005434756752	28630	Economy	10900.00
0005434756843	28630	Economy	10900.00
0005434215396	28630	Economy	10900.00
0005434215380	28630	Economy	10900.00
0005434215406	28630	Economy	10900.00
0005434756767	28630	Economy	10900.00
0005434756649	28630	Economy	10900.00
0005434215379	28630	Economy	10900.00
0005434215393	28630	Economy	10900.00
0005434756746	28630	Economy	10900.00
0005434756690	28630	Economy	10900.00
0005434215395	28630	Economy	10900.00
0005434215391	28630	Economy	10900.00
0005434756809	28630	Economy	10900.00
0005434756821	28630	Economy	10900.00
0005434756779	28630	Economy	10900.00
0005434756741	28630	Economy	10900.00
0005434756793	28630	Economy	10900.00
0005434215366	28630	Economy	10900.00
0005434756718	28630	Economy	10900.00
0005434215386	28630	Economy	10900.00
0005434215410	28630	Economy	10900.00
0005434756886	28630	Economy	10900.00
0005434215383	28630	Economy	10900.00
0005434215369	28630	Economy	10900.00
0005434756848	28630	Economy	10900.00
0005434215381	28630	Economy	10900.00
0005434756753	28630	Economy	10900.00
0005434756716	28630	Economy	10900.00
0005434756650	28630	Economy	10900.00
0005434756640	28630	Economy	10900.00
0005434756624	28630	Economy	10900.00
0005434215388	28630	Economy	10900.00
0005434215384	28630	Economy	10900.00
0005434756691	28630	Economy	10900.00
0005434215371	28630	Economy	10900.00
0005434756730	28630	Economy	10900.00
0005434215363	28630	Economy	10900.00
0005434215392	28630	Economy	10900.00
0005434215394	28630	Economy	10900.00
0005434215403	28630	Economy	10900.00
0005434756830	28630	Economy	10900.00
0005434215374	28630	Economy	10900.00
0005434215398	28630	Economy	10900.00
0005435100182	10821	Economy	8900.00
0005435100180	10821	Economy	8900.00
0005434760214	10821	Economy	8900.00
0005435100181	10821	Economy	8900.00
0005434760213	10821	Economy	8900.00
0005434760244	31844	Economy	9800.00
0005435100170	31844	Economy	8900.00
0005435100154	31844	Economy	8900.00
0005434760245	31844	Economy	8900.00
0005434639818	1953	Economy	20900.00
0005434639827	1953	Economy	20900.00
0005433202523	1953	Economy	20900.00
0005434639832	1953	Economy	20900.00
0005434639839	1953	Economy	19000.00
0005433202472	1953	Economy	19000.00
0005434639820	1953	Economy	19000.00
0005434639833	1953	Economy	19000.00
0005434639821	1953	Economy	19000.00
0005434639837	1953	Economy	19000.00
0005434639842	1953	Economy	19000.00
0005434639822	1953	Economy	19000.00
0005433202502	1953	Economy	19000.00
0005433202437	1953	Economy	19000.00
0005433202537	1953	Economy	19000.00
0005434639824	1953	Economy	19000.00
0005432290693	1953	Economy	19000.00
0005434639836	1953	Economy	19000.00
0005434639838	1953	Economy	19000.00
0005433202522	1953	Economy	19000.00
0005434639825	1953	Economy	19000.00
0005434639817	1953	Economy	19000.00
0005434639829	1953	Economy	19000.00
0005433202539	1953	Economy	19000.00
0005432290694	1953	Economy	19000.00
0005433202464	1953	Economy	19000.00
0005434639835	1953	Economy	19000.00
0005434639831	1953	Economy	19000.00
0005433202538	1953	Economy	19000.00
0005433202441	1953	Economy	19000.00
0005433202529	1953	Economy	19000.00
0005434639816	1953	Economy	19000.00
0005433202516	1953	Economy	19000.00
0005434639840	1953	Economy	19000.00
0005433202510	1953	Economy	19000.00
0005432290695	1953	Economy	19000.00
0005434639828	1953	Economy	19000.00
0005433202563	1953	Economy	19000.00
0005432290696	1953	Economy	19000.00
0005433202553	1953	Economy	19000.00
0005434639841	1953	Economy	19000.00
0005434639823	1953	Economy	19000.00
0005433202440	1953	Economy	19000.00
0005434639826	1953	Economy	19000.00
0005434639830	1953	Economy	19000.00
0005433202508	1953	Economy	19000.00
0005434639834	1953	Economy	19000.00
0005433202501	1953	Economy	19000.00
0005433202564	1953	Economy	19000.00
0005434639819	1953	Economy	19000.00
0005433202638	23272	Economy	20900.00
0005433202633	23272	Economy	20900.00
0005433202630	23272	Economy	19000.00
0005433202632	23272	Economy	19000.00
0005433202635	23272	Economy	19000.00
0005433202639	23272	Economy	19000.00
0005434639508	23272	Economy	19000.00
0005435948337	23272	Economy	19000.00
0005433202637	23272	Economy	19000.00
0005434639456	23272	Economy	19000.00
0005433202634	23272	Economy	19000.00
0005434639574	23272	Economy	19000.00
0005433202636	23272	Economy	19000.00
0005434639455	23272	Economy	19000.00
0005434639498	23272	Economy	19000.00
0005434639598	23272	Economy	19000.00
0005433202642	23272	Economy	19000.00
0005434639702	23272	Economy	19000.00
0005433202644	23272	Economy	19000.00
0005434639601	23272	Economy	19000.00
0005434639621	23272	Economy	19000.00
0005434639573	23272	Economy	19000.00
0005434639556	23272	Economy	19000.00
0005434639514	23272	Economy	19000.00
0005433202641	23272	Economy	19000.00
0005434639528	23272	Economy	19000.00
0005433202643	23272	Economy	19000.00
0005434639454	23272	Economy	19000.00
0005433202631	23272	Economy	19000.00
0005434639472	23272	Economy	19000.00
0005434639507	23272	Economy	19000.00
0005434639622	23272	Economy	19000.00
0005433202640	23272	Economy	19000.00
0005434639585	23272	Economy	19000.00
0005432111337	6080	Business	69700.00
0005434601336	6080	Business	69700.00
0005435326948	6080	Business	69700.00
0005433533381	6080	Business	69700.00
0005432111338	6080	Business	69700.00
0005433531367	6080	Economy	23200.00
0005434601325	6080	Economy	23200.00
0005434601320	6080	Economy	23200.00
0005433533382	6080	Economy	23200.00
0005435326882	6080	Economy	23200.00
0005434601333	6080	Economy	25600.00
0005434601321	6080	Economy	25600.00
0005434601338	6080	Economy	23200.00
0005434601334	6080	Economy	23200.00
0005435326870	6080	Economy	23200.00
0005434601323	6080	Economy	23200.00
0005435326885	6080	Economy	23200.00
0005434601339	6080	Economy	23200.00
0005433531368	6080	Economy	23200.00
0005434601347	6080	Economy	23200.00
0005434601332	6080	Economy	23200.00
0005434601340	6080	Economy	23200.00
0005434601337	6080	Economy	23200.00
0005434601343	6080	Economy	23200.00
0005435326883	6080	Economy	23200.00
0005434601324	6080	Economy	23200.00
0005435326906	6080	Economy	23200.00
0005434601326	6080	Economy	23200.00
0005434601335	6080	Economy	23200.00
0005434601327	6080	Economy	23200.00
0005433533383	6080	Economy	23200.00
0005434601330	6080	Economy	23200.00
0005434601328	6080	Economy	23200.00
0005434601331	6080	Economy	23200.00
0005434601346	6080	Economy	23200.00
0005434601322	6080	Economy	23200.00
0005433533380	6080	Economy	23200.00
0005434601342	6080	Economy	23200.00
0005433531366	6080	Economy	23200.00
0005435326886	6080	Economy	23200.00
0005435326863	6080	Economy	23200.00
0005432111336	6080	Economy	23200.00
0005434601344	6080	Economy	23200.00
0005434601329	6080	Economy	23200.00
0005434601341	6080	Economy	23200.00
0005432111335	6080	Economy	23200.00
0005434601345	6080	Economy	23200.00
0005434601179	18556	Business	69700.00
0005433531346	18556	Business	69700.00
0005434601111	18556	Business	69700.00
0005435327019	18556	Economy	23200.00
0005434600999	18556	Economy	23200.00
0005434600996	18556	Economy	23200.00
0005435327011	18556	Economy	23200.00
0005435327017	18556	Economy	23200.00
0005434601180	18556	Economy	23200.00
0005434601181	18556	Economy	25600.00
0005434601215	18556	Economy	25600.00
0005435327009	18556	Economy	23200.00
0005435327010	18556	Economy	23200.00
0005434601077	18556	Economy	23200.00
0005433531345	18556	Economy	23200.00
0005433527300	18556	Economy	23200.00
0005434601149	18556	Economy	23200.00
0005434601223	18556	Economy	23200.00
0005434601166	18556	Economy	23200.00
0005434601160	18556	Economy	23200.00
0005435327012	18556	Economy	23200.00
0005433527285	18556	Economy	23200.00
0005434601060	18556	Economy	23200.00
0005435327020	18556	Economy	23200.00
0005435327016	18556	Economy	23200.00
0005434601124	18556	Economy	23200.00
0005434601118	18556	Economy	23200.00
0005434601081	18556	Economy	23200.00
0005435327013	18556	Economy	23200.00
0005435327015	18556	Economy	23200.00
0005434601049	18556	Economy	23200.00
0005434601100	18556	Economy	23200.00
0005434601135	18556	Economy	23200.00
0005434601123	18556	Economy	23200.00
0005434601048	18556	Economy	23200.00
0005433527286	18556	Economy	23200.00
0005435327021	18556	Economy	23200.00
0005435327014	18556	Economy	23200.00
0005435327018	18556	Economy	23200.00
0005434552246	10674	Business	9100.00
0005434552242	10674	Business	9100.00
0005434552272	10674	Business	9100.00
0005434558432	10674	Business	9100.00
0005434554104	10674	Business	9100.00
0005433181331	10674	Business	9100.00
0005433181452	10674	Business	9100.00
0005433181407	10674	Business	9100.00
0005433181251	10674	Business	9100.00
0005433181421	10674	Business	9100.00
0005434552228	10674	Business	9100.00
0005434552231	10674	Economy	3000.00
0005434552220	10674	Economy	3000.00
0005434558431	10674	Economy	3000.00
0005433181384	10674	Economy	3000.00
0005434552273	10674	Economy	3000.00
0005434552241	10674	Economy	3000.00
0005434552226	10674	Economy	3000.00
0005434552266	10674	Economy	3000.00
0005434552222	10674	Economy	3000.00
0005434558433	10674	Economy	3000.00
0005433181330	10674	Economy	3300.00
0005434552235	10674	Economy	3300.00
0005434552249	10674	Economy	3300.00
0005433181412	10674	Economy	3300.00
0005434552225	10674	Economy	3300.00
0005433181387	10674	Economy	3000.00
0005434552230	10674	Economy	3000.00
0005433181293	10674	Economy	3000.00
0005434552254	10674	Economy	3000.00
0005434552237	10674	Economy	3000.00
0005434552257	10674	Economy	3000.00
0005433181295	10674	Economy	3000.00
0005433181405	10674	Economy	3000.00
0005434552238	10674	Economy	3000.00
0005434552252	10674	Economy	3000.00
0005434552255	10674	Economy	3000.00
0005433181388	10674	Economy	3000.00
0005434552256	10674	Economy	3000.00
0005433181303	10674	Economy	3000.00
0005434552239	10674	Economy	3000.00
0005433181292	10674	Economy	3000.00
0005434552271	10674	Economy	3000.00
0005433181297	10674	Economy	3000.00
0005433181268	10674	Economy	3000.00
0005434552264	10674	Economy	3000.00
0005434552245	10674	Economy	3000.00
0005433181413	10674	Economy	3000.00
0005433181332	10674	Economy	3000.00
0005434552250	10674	Economy	3000.00
0005434552233	10674	Economy	3000.00
0005434552260	10674	Economy	3000.00
0005434552259	10674	Economy	3000.00
0005434558428	10674	Economy	3000.00
0005434552269	10674	Economy	3000.00
0005434558430	10674	Economy	3000.00
0005433181409	10674	Economy	3000.00
0005434552248	10674	Economy	3000.00
0005434558429	10674	Economy	3000.00
0005433181269	10674	Economy	3000.00
0005434552219	10674	Economy	3000.00
0005434552268	10674	Economy	3000.00
0005434554103	10674	Economy	3000.00
0005434552243	10674	Economy	3000.00
0005433181318	10674	Economy	3000.00
0005434552253	10674	Economy	3000.00
0005434552234	10674	Economy	3000.00
0005434552232	10674	Economy	3000.00
0005433181315	10674	Economy	3000.00
0005434552270	10674	Economy	3000.00
0005434552244	10674	Economy	3000.00
0005434552240	10674	Economy	3000.00
0005434552229	10674	Economy	3000.00
0005433181316	10674	Economy	3000.00
0005434552224	10674	Economy	3000.00
0005433181294	10674	Economy	3000.00
0005433181422	10674	Economy	3000.00
0005434552263	10674	Economy	3000.00
0005433181406	10674	Economy	3000.00
0005434552227	10674	Economy	3000.00
0005434552236	10674	Economy	3000.00
0005434552223	10674	Economy	3000.00
0005434552247	10674	Economy	3000.00
0005433181289	10674	Economy	3000.00
0005434552221	10674	Economy	3000.00
0005434552265	10674	Economy	3000.00
0005434552258	10674	Economy	3000.00
0005433181447	10674	Economy	3000.00
0005434552261	10674	Economy	3000.00
0005434552251	10674	Economy	3000.00
0005433181270	10674	Economy	3000.00
0005434552262	10674	Economy	3000.00
0005434552267	10674	Economy	3000.00
0005433181404	10674	Economy	3000.00
0005433181604	27680	Business	9100.00
0005433181590	27680	Business	9100.00
0005435314970	27680	Business	9100.00
0005435314969	27680	Business	9100.00
0005433181581	27680	Economy	3000.00
0005433181597	27680	Economy	3000.00
0005435314971	27680	Economy	3300.00
0005433181582	27680	Economy	3000.00
0005433181601	27680	Economy	3000.00
0005433181603	27680	Economy	3000.00
0005433181595	27680	Economy	3000.00
0005433181605	27680	Economy	3000.00
0005433181586	27680	Economy	3000.00
0005433181589	27680	Economy	3000.00
0005433181599	27680	Economy	3000.00
0005433181594	27680	Economy	3000.00
0005433181584	27680	Economy	3000.00
0005435314972	27680	Economy	3000.00
0005435314974	27680	Economy	3000.00
0005433181583	27680	Economy	3000.00
0005433181588	27680	Economy	3000.00
0005433181598	27680	Economy	3000.00
0005433181587	27680	Economy	3000.00
0005433181596	27680	Economy	3000.00
0005433181600	27680	Economy	3000.00
0005433181593	27680	Economy	3000.00
0005433181591	27680	Economy	3000.00
0005435314973	27680	Economy	3000.00
0005433181592	27680	Economy	3000.00
0005433181580	27680	Economy	3000.00
0005433181585	27680	Economy	3000.00
0005433181602	27680	Economy	3000.00
0005434551784	27696	Business	9100.00
0005434551781	27696	Business	9100.00
0005434554087	27696	Business	9100.00
0005434552089	27696	Business	9100.00
0005434551719	27696	Business	9100.00
0005434551881	27696	Business	9100.00
0005434551783	27696	Economy	3000.00
0005434551729	27696	Economy	3000.00
0005434554075	27696	Economy	3000.00
0005434558376	27696	Economy	3300.00
0005434551929	27696	Economy	3300.00
0005434551948	27696	Economy	3300.00
0005434551517	27696	Economy	3000.00
0005434558365	27696	Economy	3000.00
0005434551925	27696	Economy	3000.00
0005434551985	27696	Economy	3000.00
0005434551924	27696	Economy	3000.00
0005434551630	27696	Economy	3000.00
0005434551955	27696	Economy	3000.00
0005434551882	27696	Economy	3000.00
0005434551573	27696	Economy	3000.00
0005434551659	27696	Economy	3000.00
0005434551986	27696	Economy	3000.00
0005434551799	27696	Economy	3000.00
0005434551821	27696	Economy	3000.00
0005434551666	27696	Economy	3000.00
0005434551988	27696	Economy	3000.00
0005434551930	27696	Economy	3000.00
0005434551949	27696	Economy	3000.00
0005434551720	27696	Economy	3000.00
0005434551725	27696	Economy	3000.00
0005434551906	27696	Economy	3000.00
0005434551922	27696	Economy	3000.00
0005434558375	27696	Economy	3000.00
0005434551786	27696	Economy	3000.00
0005434551954	27696	Economy	3000.00
0005434551646	27696	Economy	3000.00
0005434552088	27696	Economy	3000.00
0005434551667	27696	Economy	3000.00
0005434551574	27696	Economy	3000.00
0005434551713	27696	Economy	3000.00
0005434558341	27696	Economy	3000.00
0005434551928	27696	Economy	3000.00
0005434551766	27696	Economy	3000.00
0005434551785	27696	Economy	3000.00
0005434551953	27696	Economy	3000.00
0005434552100	27696	Economy	3000.00
0005434551802	27696	Economy	3000.00
0005433459302	6163	Economy	11700.00
0005433459301	6163	Economy	11700.00
0005435254499	6163	Economy	11700.00
0005433459303	6163	Economy	11700.00
0005433459300	6163	Economy	11700.00
0005435254504	6163	Economy	11700.00
0005433459260	19334	Economy	11700.00
0005435254520	19334	Economy	11700.00
0005433459261	19334	Economy	11700.00
0005433459276	19334	Economy	11700.00
0005433459265	19334	Economy	11700.00
0005433459262	19334	Economy	11700.00
0005433459252	19334	Economy	11700.00
0005433459259	19334	Economy	11700.00
0005433459273	19334	Economy	11700.00
0005433459258	19334	Economy	11700.00
0005435438251	6752	Business	51100.00
0005435661984	6752	Business	51100.00
0005432136265	6752	Business	51100.00
0005435682917	6752	Business	51100.00
0005435631023	6752	Business	51100.00
0005435661985	6752	Business	51100.00
0005435682931	6752	Business	51100.00
0005435682924	6752	Business	51100.00
0005435682928	6752	Business	51100.00
0005435217717	6752	Economy	17000.00
0005435438168	6752	Economy	17000.00
0005432533319	6752	Economy	17000.00
0005435682920	6752	Economy	17000.00
0005435682912	6752	Economy	17000.00
0005435438279	6752	Economy	17000.00
0005435682935	6752	Economy	17000.00
0005435438277	6752	Economy	17000.00
0005435438167	6752	Economy	17000.00
0005435438244	6752	Economy	17000.00
0005435682906	6752	Economy	18700.00
0005435438268	6752	Economy	18700.00
0005435682911	6752	Economy	18700.00
0005435220340	6752	Economy	18700.00
0005435438195	6752	Economy	18700.00
0005435682929	6752	Economy	17000.00
0005434828727	6752	Economy	17000.00
0005435438203	6752	Economy	17000.00
0005435438238	6752	Economy	17000.00
0005432136263	6752	Economy	17000.00
0005435682907	6752	Economy	17000.00
0005435438142	6752	Economy	17000.00
0005435682914	6752	Economy	17000.00
0005435438211	6752	Economy	17000.00
0005435438151	6752	Economy	17000.00
0005435438217	6752	Economy	17000.00
0005435438191	6752	Economy	17000.00
0005435220334	6752	Economy	17000.00
0005434828742	6752	Economy	17000.00
0005435438176	6752	Economy	17000.00
0005435220337	6752	Economy	17000.00
0005435438190	6752	Economy	17000.00
0005435438252	6752	Economy	17000.00
0005435438286	6752	Economy	17000.00
0005435682925	6752	Economy	17000.00
0005435682923	6752	Economy	17000.00
0005435438182	6752	Economy	17000.00
0005435438250	6752	Economy	17000.00
0005435682926	6752	Economy	17000.00
0005435682910	6752	Economy	17000.00
0005435438202	6752	Economy	17000.00
0005435438196	6752	Economy	17000.00
0005432136266	6752	Economy	17000.00
0005435438198	6752	Economy	17000.00
0005435682916	6752	Economy	17000.00
0005432136264	6752	Economy	17000.00
0005435682922	6752	Economy	17000.00
0005435220339	6752	Economy	17000.00
0005435438278	6752	Economy	17000.00
0005435438288	6752	Economy	17000.00
0005435682918	6752	Economy	17000.00
0005435438099	6752	Economy	17000.00
0005435682932	6752	Economy	17000.00
0005435631024	6752	Economy	17000.00
0005435682930	6752	Economy	17000.00
0005435682919	6752	Economy	17000.00
0005435682933	6752	Economy	17000.00
0005435631025	6752	Economy	17000.00
0005435682913	6752	Economy	17000.00
0005435682921	6752	Economy	17000.00
0005435217716	6752	Economy	17000.00
0005435682908	6752	Economy	17000.00
0005435682927	6752	Economy	17000.00
0005435438210	6752	Economy	17000.00
0005435661986	6752	Economy	17000.00
0005435682915	6752	Economy	17000.00
0005435438144	6752	Economy	17000.00
0005435220338	6752	Economy	17000.00
0005435682934	6752	Economy	17000.00
0005435438223	6752	Economy	17000.00
0005432136267	6752	Economy	17000.00
0005435438216	6752	Economy	17000.00
0005435682909	6752	Economy	17000.00
0005435682582	24606	Business	51100.00
0005435661946	24606	Business	51100.00
0005434828752	24606	Business	51100.00
0005435682657	24606	Business	51100.00
0005435219237	24606	Business	51100.00
0005432533346	24606	Business	51100.00
0005435219241	24606	Business	51100.00
0005435682333	24606	Business	51100.00
0005435682652	24606	Business	51100.00
0005435438375	24606	Business	51100.00
0005435438373	24606	Business	51100.00
0005435661959	24606	Economy	17000.00
0005435219239	24606	Economy	17000.00
0005435682521	24606	Economy	17000.00
0005435220500	24606	Economy	17000.00
0005435220359	24606	Economy	17000.00
0005435682616	24606	Economy	17000.00
0005435682383	24606	Economy	17000.00
0005434828751	24606	Economy	17000.00
0005435682487	24606	Economy	17000.00
0005435438391	24606	Economy	18700.00
0005435220357	24606	Economy	18700.00
0005435438376	24606	Economy	18700.00
0005435220358	24606	Economy	18700.00
0005432305795	24606	Economy	17000.00
0005435219238	24606	Economy	17000.00
0005435438378	24606	Economy	17000.00
0005435682642	24606	Economy	17000.00
0005435438374	24606	Economy	17000.00
0005435438389	24606	Economy	17000.00
0005435220499	24606	Economy	17000.00
0005435682617	24606	Economy	17000.00
0005435682544	24606	Economy	17000.00
0005435438382	24606	Economy	17000.00
0005435438380	24606	Economy	17000.00
0005435438386	24606	Economy	17000.00
0005435220502	24606	Economy	17000.00
0005435438383	24606	Economy	17000.00
0005435438377	24606	Economy	17000.00
0005432305797	24606	Economy	17000.00
0005435682620	24606	Economy	17000.00
0005435438385	24606	Economy	17000.00
0005435220356	24606	Economy	17000.00
0005435438381	24606	Economy	17000.00
0005435438379	24606	Economy	17000.00
0005435438384	24606	Economy	17000.00
0005434828753	24606	Economy	17000.00
0005435219240	24606	Economy	17000.00
0005435682581	24606	Economy	17000.00
0005435220354	24606	Economy	17000.00
0005435682520	24606	Economy	17000.00
0005435438392	24606	Economy	17000.00
0005435661960	24606	Economy	17000.00
0005435682583	24606	Economy	17000.00
0005435682546	24606	Economy	17000.00
0005432533348	24606	Economy	17000.00
0005435682479	24606	Economy	17000.00
0005435438370	24606	Economy	17000.00
0005435220362	24606	Economy	17000.00
0005435682490	24606	Economy	17000.00
0005435682637	24606	Economy	17000.00
0005435682488	24606	Economy	17000.00
0005435438388	24606	Economy	17000.00
0005435682480	24606	Economy	17000.00
0005435220360	24606	Economy	17000.00
0005435661947	24606	Economy	17000.00
0005435220497	24606	Economy	17000.00
0005435682587	24606	Economy	17000.00
0005435220501	24606	Economy	17000.00
0005435682584	24606	Economy	17000.00
0005435682638	24606	Economy	17000.00
0005435219242	24606	Economy	17000.00
0005435219243	24606	Economy	17000.00
0005432533347	24606	Economy	17000.00
0005435220498	24606	Economy	17000.00
0005435682551	24606	Economy	17000.00
0005435438371	24606	Economy	17000.00
0005435661952	24606	Economy	17000.00
0005435219236	24606	Economy	17000.00
0005432305796	24606	Economy	17000.00
0005435438393	24606	Economy	17000.00
0005435220355	24606	Economy	17000.00
0005435438390	24606	Economy	17000.00
0005435438372	24606	Economy	17000.00
0005435682672	24606	Economy	17000.00
0005434828754	24606	Economy	17000.00
0005435682427	24606	Economy	17000.00
0005435220361	24606	Economy	17000.00
0005435438387	24606	Economy	17000.00
0005435558116	11517	Business	26400.00
0005435127144	11517	Business	26400.00
0005435127140	11517	Business	26400.00
0005435098589	11517	Business	26400.00
0005435127116	11517	Business	26400.00
0005435127132	11517	Business	26400.00
0005435127145	11517	Business	26400.00
0005435127123	11517	Business	26400.00
0005435127113	11517	Economy	8800.00
0005435127129	11517	Economy	8800.00
0005435127120	11517	Economy	8800.00
0005435127138	11517	Economy	8800.00
0005435098595	11517	Economy	9700.00
0005435127110	11517	Economy	9700.00
0005435127108	11517	Economy	9700.00
0005435127147	11517	Economy	8800.00
0005435558117	11517	Economy	8800.00
0005435127119	11517	Economy	8800.00
0005435127143	11517	Economy	8800.00
0005435127124	11517	Economy	8800.00
0005435098593	11517	Economy	8800.00
0005435098594	11517	Economy	8800.00
0005435127139	11517	Economy	8800.00
0005435127133	11517	Economy	8800.00
0005435127112	11517	Economy	8800.00
0005435127131	11517	Economy	8800.00
0005435127141	11517	Economy	8800.00
0005435127137	11517	Economy	8800.00
0005435127106	11517	Economy	8800.00
0005435127114	11517	Economy	8800.00
0005435127128	11517	Economy	8800.00
0005435127134	11517	Economy	8800.00
0005435127107	11517	Economy	8800.00
0005435127118	11517	Economy	8800.00
0005435106042	11517	Economy	8800.00
0005435098597	11517	Economy	8800.00
0005435127117	11517	Economy	8800.00
0005435106041	11517	Economy	8800.00
0005435127130	11517	Economy	8800.00
0005435098591	11517	Economy	8800.00
0005435098590	11517	Economy	8800.00
0005435127121	11517	Economy	8800.00
0005435127146	11517	Economy	8800.00
0005435127135	11517	Economy	8800.00
0005435106043	11517	Economy	8800.00
0005435098592	11517	Economy	8800.00
0005435127111	11517	Economy	8800.00
0005435127126	11517	Economy	8800.00
0005435127125	11517	Economy	8800.00
0005435127127	11517	Economy	8800.00
0005435106040	11517	Economy	8800.00
0005435127142	11517	Economy	8800.00
0005435098596	11517	Economy	8800.00
0005435127105	11517	Economy	8800.00
0005435127122	11517	Economy	8800.00
0005435127115	11517	Economy	8800.00
0005435127136	11517	Economy	8800.00
0005435127109	11517	Economy	8800.00
0005435126868	31851	Business	26400.00
0005435126755	31851	Business	26400.00
0005435126847	31851	Business	26400.00
0005435126762	31851	Business	26400.00
0005435126758	31851	Business	26400.00
0005435126990	31851	Economy	8800.00
0005435126973	31851	Economy	8800.00
0005435126864	31851	Economy	8800.00
0005435126786	31851	Economy	8800.00
0005435126691	31851	Economy	8800.00
0005435106013	31851	Economy	9700.00
0005435126866	31851	Economy	8800.00
0005435126836	31851	Economy	8800.00
0005435126772	31851	Economy	8800.00
0005435126933	31851	Economy	8800.00
0005435126649	31851	Economy	8800.00
0005435126744	31851	Economy	8800.00
0005435126797	31851	Economy	8800.00
0005435126724	31851	Economy	8800.00
0005435126761	31851	Economy	8800.00
0005435126773	31851	Economy	8800.00
0005435126765	31851	Economy	8800.00
0005435126852	31851	Economy	8800.00
0005435126827	31851	Economy	8800.00
0005435126878	31851	Economy	8800.00
0005435126807	31851	Economy	8800.00
0005435126743	31851	Economy	8800.00
0005435126991	31851	Economy	8800.00
0005435126790	31851	Economy	8800.00
0005435126694	31851	Economy	8800.00
0005435126757	31851	Economy	8800.00
0005435126843	31851	Economy	8800.00
0005435126835	31851	Economy	8800.00
0005435127013	31851	Economy	8800.00
0005435126893	31851	Economy	8800.00
0005435126766	31851	Economy	8800.00
0005435558137	31851	Economy	8800.00
0005435126834	31851	Economy	8800.00
0005435126844	31851	Economy	8800.00
0005435558138	31851	Economy	8800.00
0005435126689	31851	Economy	8800.00
0005435126972	31851	Economy	8800.00
0005435126785	31851	Economy	8800.00
0005435126789	31851	Economy	8800.00
0005435126692	31851	Economy	8800.00
0005435126867	31851	Economy	8800.00
0005435126869	31851	Economy	8800.00
0005435126791	31851	Economy	8800.00
0005435126725	31851	Economy	8800.00
0005433398976	13554	Business	36600.00
0005435732468	13554	Business	36600.00
0005433398994	13554	Business	36600.00
0005433399016	13554	Business	36600.00
0005433399002	13554	Business	36600.00
0005433399014	13554	Business	36600.00
0005435732477	13554	Business	36600.00
0005433399003	13554	Economy	12200.00
0005433399013	13554	Economy	12200.00
0005433398995	13554	Economy	12200.00
0005435732466	13554	Economy	12200.00
0005435732499	13554	Economy	12200.00
0005433399010	13554	Economy	12200.00
0005433398973	13554	Economy	12200.00
0005435732511	13554	Economy	12200.00
0005435732520	13554	Economy	12200.00
0005435732471	13554	Economy	13400.00
0005435732476	13554	Economy	12200.00
0005435732454	13554	Economy	12200.00
0005435732539	13554	Economy	12200.00
0005433399008	13554	Economy	12200.00
0005433398980	13554	Economy	12200.00
0005433399004	13554	Economy	12200.00
0005435732415	13554	Economy	12200.00
0005433399001	13554	Economy	12200.00
0005433398997	13554	Economy	12200.00
0005433398978	13554	Economy	12200.00
0005433399017	13554	Economy	12200.00
0005433398983	13554	Economy	12200.00
0005433398987	13554	Economy	12200.00
0005435732402	13554	Economy	12200.00
0005435732414	13554	Economy	12200.00
0005433398971	13554	Economy	12200.00
0005433398992	13554	Economy	12200.00
0005433398988	13554	Economy	12200.00
0005433398993	13554	Economy	12200.00
0005433398999	13554	Economy	12200.00
0005433398991	13554	Economy	12200.00
0005433399005	13554	Economy	12200.00
0005433399000	13554	Economy	12200.00
0005433398998	13554	Economy	12200.00
0005433398979	13554	Economy	12200.00
0005433398990	13554	Economy	12200.00
0005433398972	13554	Economy	12200.00
0005433398977	13554	Economy	12200.00
0005433398986	13554	Economy	12200.00
0005433398985	13554	Economy	12200.00
0005433398969	13554	Economy	12200.00
0005433398984	13554	Economy	12200.00
0005433398982	13554	Economy	12200.00
0005433399007	13554	Economy	12200.00
0005433398968	13554	Economy	12200.00
0005435732483	13554	Economy	12200.00
0005435732493	13554	Economy	12200.00
0005433399018	13554	Economy	12200.00
0005433398989	13554	Economy	12200.00
0005433398996	13554	Economy	12200.00
0005433399006	13554	Economy	12200.00
0005435732494	13554	Economy	12200.00
0005435732472	13554	Economy	12200.00
0005433398970	13554	Economy	12200.00
0005433399009	13554	Economy	12200.00
0005435732484	13554	Economy	12200.00
0005433398974	13554	Economy	12200.00
0005433398975	13554	Economy	12200.00
0005433398981	13554	Economy	12200.00
0005433399012	13554	Economy	12200.00
0005433399011	13554	Economy	12200.00
0005435732503	13554	Economy	12200.00
0005435732467	13554	Economy	12200.00
0005433399015	13554	Economy	12200.00
0005433398522	19415	Business	36600.00
0005433398659	19415	Business	36600.00
0005433398438	19415	Business	36600.00
0005435732582	19415	Business	36600.00
0005433398440	19415	Business	36600.00
0005433398392	19415	Business	36600.00
0005433398431	19415	Economy	12200.00
0005433398552	19415	Economy	12200.00
0005433398497	19415	Economy	12200.00
0005435732567	19415	Economy	12200.00
0005435732569	19415	Economy	12200.00
0005433398451	19415	Economy	12200.00
0005435732586	19415	Economy	12200.00
0005435732578	19415	Economy	12200.00
0005433398499	19415	Economy	13400.00
0005435732579	19415	Economy	13400.00
0005435732581	19415	Economy	13400.00
0005433398575	19415	Economy	13400.00
0005433398566	19415	Economy	12200.00
0005433398547	19415	Economy	12200.00
0005433398520	19415	Economy	12200.00
0005433398274	19415	Economy	12200.00
0005435732576	19415	Economy	12200.00
0005433398596	19415	Economy	12200.00
0005432297328	19415	Economy	12200.00
0005433398618	19415	Economy	12200.00
0005433398562	19415	Economy	12200.00
0005435732583	19415	Economy	12200.00
0005433398381	19415	Economy	12200.00
0005433398651	19415	Economy	12200.00
0005433398617	19415	Economy	12200.00
0005432297327	19415	Economy	12200.00
0005433398378	19415	Economy	12200.00
0005435732577	19415	Economy	12200.00
0005435732584	19415	Economy	12200.00
0005435732573	19415	Economy	12200.00
0005433398669	19415	Economy	12200.00
0005435732585	19415	Economy	12200.00
0005435732572	19415	Economy	12200.00
0005435732571	19415	Economy	12200.00
0005435732588	19415	Economy	12200.00
0005433398648	19415	Economy	12200.00
0005433398391	19415	Economy	12200.00
0005433398544	19415	Economy	12200.00
0005433398719	19415	Economy	12200.00
0005432297329	19415	Economy	12200.00
0005435732570	19415	Economy	12200.00
0005435732589	19415	Economy	12200.00
0005435732587	19415	Economy	12200.00
0005433398775	19415	Economy	12200.00
0005435732580	19415	Economy	12200.00
0005435732568	19415	Economy	12200.00
0005433398273	19415	Economy	12200.00
0005433398521	19415	Economy	12200.00
0005433398563	19415	Economy	12200.00
0005433398652	19415	Economy	12200.00
0005433398649	19415	Economy	12200.00
0005435732575	19415	Economy	12200.00
0005433398545	19415	Economy	12200.00
0005435732574	19415	Economy	12200.00
0005435732590	19415	Economy	12200.00
0005435069541	13162	Business	11300.00
0005435069620	13162	Business	11300.00
0005435069675	13162	Business	11300.00
0005435069415	13162	Business	11300.00
0005435069414	13162	Business	11300.00
0005435069805	13162	Business	11300.00
0005435925562	13162	Business	11300.00
0005435069739	13162	Business	11300.00
0005435069623	13162	Economy	3800.00
0005435069384	13162	Economy	3800.00
0005435069621	13162	Economy	3800.00
0005435925566	13162	Economy	3800.00
0005435069302	13162	Economy	3800.00
0005435069538	13162	Economy	3800.00
0005435069676	13162	Economy	3800.00
0005435069661	13162	Economy	3800.00
0005435069780	13162	Economy	3800.00
0005435069518	13162	Economy	4100.00
0005435069738	13162	Economy	4100.00
0005435069643	13162	Economy	3800.00
0005435069493	13162	Economy	3800.00
0005435069644	13162	Economy	3800.00
0005435069662	13162	Economy	3800.00
0005435069588	13162	Economy	3800.00
0005435069581	13162	Economy	3800.00
0005435069597	13162	Economy	3800.00
0005435925563	13162	Economy	3800.00
0005435069609	13162	Economy	3800.00
0005435069590	13162	Economy	3800.00
0005435069553	13162	Economy	3800.00
0005435069489	13162	Economy	3800.00
0005435069779	13162	Economy	3800.00
0005435069508	13162	Economy	3800.00
0005435069721	13162	Economy	3800.00
0005435069487	13162	Economy	3800.00
0005435069640	13162	Economy	3800.00
0005435069632	13162	Economy	3800.00
0005435069674	13162	Economy	3800.00
0005435925561	13162	Economy	3800.00
0005435069615	13162	Economy	3800.00
0005435069645	13162	Economy	3800.00
0005435069650	13162	Economy	3800.00
0005435069540	13162	Economy	3800.00
0005435069722	13162	Economy	3800.00
0005435069608	13162	Economy	3800.00
0005435069385	13162	Economy	3800.00
0005435069492	13162	Economy	3800.00
0005435069480	13162	Economy	3800.00
0005435069430	13162	Economy	3800.00
0005435069874	13162	Economy	3800.00
0005435069519	13162	Economy	3800.00
0005435069697	13162	Economy	3800.00
0005435069596	13162	Economy	3800.00
0005435925565	13162	Economy	3800.00
0005435069479	13162	Economy	3800.00
0005435069449	13162	Economy	3800.00
0005435069639	13162	Economy	3800.00
0005435069485	13162	Economy	3800.00
0005435069576	13162	Economy	3800.00
0005435069554	13162	Economy	3800.00
0005435069486	13162	Economy	3800.00
0005435069638	13162	Economy	3800.00
0005435925564	13162	Economy	3800.00
0005435069624	13162	Economy	3800.00
0005435069442	13162	Economy	3800.00
0005435069535	13162	Economy	3800.00
0005435070037	15465	Business	11300.00
0005435070038	15465	Business	11300.00
0005435925393	15465	Business	11300.00
0005435925383	15465	Business	11300.00
0005435070055	15465	Business	11300.00
0005435070045	15465	Business	11300.00
0005435070052	15465	Business	11300.00
0005435070036	15465	Business	11300.00
0005435070029	15465	Economy	3800.00
0005435925397	15465	Economy	3800.00
0005435070026	15465	Economy	3800.00
0005435070023	15465	Economy	3800.00
0005435925428	15465	Economy	3800.00
0005435925431	15465	Economy	3800.00
0005435070065	15465	Economy	3800.00
0005435070012	15465	Economy	4100.00
0005435070018	15465	Economy	4100.00
0005435070054	15465	Economy	4100.00
0005435070051	15465	Economy	3800.00
0005435070060	15465	Economy	3800.00
0005435070027	15465	Economy	3800.00
0005435070056	15465	Economy	3800.00
0005435925429	15465	Economy	3800.00
0005435925410	15465	Economy	3800.00
0005435070059	15465	Economy	3800.00
0005435070046	15465	Economy	3800.00
0005435070031	15465	Economy	3800.00
0005435070042	15465	Economy	3800.00
0005435925432	15465	Economy	3800.00
0005435070048	15465	Economy	3800.00
0005435070044	15465	Economy	3800.00
0005435070014	15465	Economy	3800.00
0005435070034	15465	Economy	3800.00
0005435070040	15465	Economy	3800.00
0005435070058	15465	Economy	3800.00
0005435070016	15465	Economy	3800.00
0005435070039	15465	Economy	3800.00
0005435925372	15465	Economy	3800.00
0005435925408	15465	Economy	3800.00
0005435070061	15465	Economy	3800.00
0005435070032	15465	Economy	3800.00
0005435070062	15465	Economy	3800.00
0005435925398	15465	Economy	3800.00
0005435070063	15465	Economy	3800.00
0005435925382	15465	Economy	3800.00
0005435070064	15465	Economy	3800.00
0005435070028	15465	Economy	3800.00
0005435070021	15465	Economy	3800.00
0005435070047	15465	Economy	3800.00
0005435070020	15465	Economy	3800.00
0005435070035	15465	Economy	3800.00
0005435925386	15465	Economy	3800.00
0005435925407	15465	Economy	3800.00
0005435925434	15465	Economy	3800.00
0005435070019	15465	Economy	3800.00
0005435070017	15465	Economy	3800.00
0005435070057	15465	Economy	3800.00
0005435070015	15465	Economy	3800.00
0005435070049	15465	Economy	3800.00
0005435070033	15465	Economy	3800.00
0005435925419	15465	Economy	3800.00
0005435070024	15465	Economy	3800.00
0005435070050	15465	Economy	3800.00
0005435070022	15465	Economy	3800.00
0005435070043	15465	Economy	3800.00
0005435070013	15465	Economy	3800.00
0005435070025	15465	Economy	3800.00
0005435070041	15465	Economy	3800.00
0005435070053	15465	Economy	3800.00
0005435070030	15465	Economy	3800.00
0005435925370	15465	Economy	3800.00
0005435925420	15465	Economy	3800.00
0005433407617	23181	Economy	27100.00
0005433407633	23181	Economy	24700.00
0005433407605	23181	Economy	24700.00
0005433407609	23181	Economy	24700.00
0005433407623	23181	Economy	24700.00
0005433407606	23181	Economy	24700.00
0005435808405	23181	Economy	24700.00
0005433407618	23181	Economy	24700.00
0005435808408	23181	Economy	24700.00
0005435808413	23181	Economy	24700.00
0005433407610	23181	Economy	24700.00
0005435808412	23181	Economy	24700.00
0005435808410	23181	Economy	24700.00
0005435808416	23181	Economy	24700.00
0005435808406	23181	Economy	24700.00
0005435808414	23181	Economy	24700.00
0005435808415	23181	Economy	24700.00
0005435808419	23181	Economy	24700.00
0005435808411	23181	Economy	24700.00
0005435808407	23181	Economy	24700.00
0005433407620	23181	Economy	24700.00
0005433407602	23181	Economy	24700.00
0005435808418	23181	Economy	24700.00
0005435808409	23181	Economy	24700.00
0005435808417	23181	Economy	24700.00
0005433407611	23181	Economy	24700.00
0005434756670	10731	Business	61300.00
0005434215414	10731	Business	61300.00
0005434215441	10731	Business	61300.00
0005434215440	10731	Business	61300.00
0005434756837	10731	Business	61300.00
0005434756745	10731	Business	61300.00
0005434215451	10731	Business	61300.00
0005434215412	10731	Business	61300.00
0005434756700	10731	Business	61300.00
0005434756750	10731	Business	61300.00
0005434215422	10731	Economy	20400.00
0005434756839	10731	Economy	20400.00
0005434756860	10731	Economy	20400.00
0005434756790	10731	Economy	20400.00
0005434215432	10731	Economy	20400.00
0005434215431	10731	Economy	20400.00
0005434756725	10731	Economy	20400.00
0005434756901	10731	Economy	20400.00
0005434215425	10731	Economy	20400.00
0005434215458	10731	Economy	20400.00
0005434215455	10731	Economy	22500.00
0005434756878	10731	Economy	22500.00
0005434215424	10731	Economy	22500.00
0005434756697	10731	Economy	22500.00
0005434215436	10731	Economy	22500.00
0005434756896	10731	Economy	20400.00
0005434215453	10731	Economy	20400.00
0005434215426	10731	Economy	20400.00
0005434756858	10731	Economy	20400.00
0005434215419	10731	Economy	20400.00
0005434215435	10731	Economy	20400.00
0005434756902	10731	Economy	20400.00
0005434756861	10731	Economy	20400.00
0005434756810	10731	Economy	20400.00
0005434215428	10731	Economy	20400.00
0005434756909	10731	Economy	20400.00
0005434756834	10731	Economy	20400.00
0005434756838	10731	Economy	20400.00
0005434756748	10731	Economy	20400.00
0005434215457	10731	Economy	20400.00
0005434215447	10731	Economy	20400.00
0005434215454	10731	Economy	20400.00
0005434756713	10731	Economy	20400.00
0005434215438	10731	Economy	20400.00
0005434756897	10731	Economy	20400.00
0005434756867	10731	Economy	20400.00
0005434215418	10731	Economy	20400.00
0005434756751	10731	Economy	20400.00
0005434756879	10731	Economy	20400.00
0005434215449	10731	Economy	20400.00
0005434756855	10731	Economy	20400.00
0005434215437	10731	Economy	20400.00
0005434215417	10731	Economy	20400.00
0005434756859	10731	Economy	20400.00
0005434215442	10731	Economy	20400.00
0005434756742	10731	Economy	20400.00
0005434756835	10731	Economy	20400.00
0005434756908	10731	Economy	20400.00
0005434215427	10731	Economy	20400.00
0005434756937	10731	Economy	20400.00
0005434215416	10731	Economy	20400.00
0005434215450	10731	Economy	20400.00
0005434756724	10731	Economy	20400.00
0005434756799	10731	Economy	20400.00
0005434756787	10731	Economy	20400.00
0005434215415	10731	Economy	20400.00
0005434215434	10731	Economy	20400.00
0005434215411	10731	Economy	20400.00
0005434215456	10731	Economy	20400.00
0005434215448	10731	Economy	20400.00
0005434756862	10731	Economy	20400.00
0005434215433	10731	Economy	20400.00
0005434756824	10731	Economy	20400.00
0005434215446	10731	Economy	20400.00
0005434756889	10731	Economy	20400.00
0005434215444	10731	Economy	20400.00
0005434215420	10731	Economy	20400.00
0005434215413	10731	Economy	20400.00
0005434756833	10731	Economy	20400.00
0005434215439	10731	Economy	20400.00
0005434756663	10731	Economy	20400.00
0005434756856	10731	Economy	20400.00
0005434215430	10731	Economy	20400.00
0005434215445	10731	Economy	20400.00
0005434215429	10731	Economy	20400.00
0005434215423	10731	Economy	20400.00
0005434215452	10731	Economy	20400.00
0005434756903	10731	Economy	20400.00
0005434215421	10731	Economy	20400.00
0005434215443	10731	Economy	20400.00
0005434215139	28676	Business	61300.00
0005434757166	28676	Business	61300.00
0005434757174	28676	Business	61300.00
0005434757160	28676	Business	61300.00
0005434214958	28676	Business	61300.00
0005434757184	28676	Business	61300.00
0005434214761	28676	Business	61300.00
0005434215006	28676	Business	61300.00
0005434215027	28676	Business	61300.00
0005434757185	28676	Business	61300.00
0005434214970	28676	Business	61300.00
0005434215005	28676	Business	61300.00
0005434757177	28676	Economy	20400.00
0005434214960	28676	Economy	20400.00
0005434215089	28676	Economy	20400.00
0005434214848	28676	Economy	20400.00
0005434215056	28676	Economy	20400.00
0005434757181	28676	Economy	20400.00
0005434215046	28676	Economy	20400.00
0005434214890	28676	Economy	20400.00
0005434757165	28676	Economy	20400.00
0005434215034	28676	Economy	22500.00
0005434757188	28676	Economy	22500.00
0005434214856	28676	Economy	22500.00
0005434215048	28676	Economy	22500.00
0005434757190	28676	Economy	20400.00
0005434757191	28676	Economy	20400.00
0005434214996	28676	Economy	20400.00
0005434757171	28676	Economy	20400.00
0005434214729	28676	Economy	20400.00
0005434215138	28676	Economy	20400.00
0005434214925	28676	Economy	20400.00
0005434214900	28676	Economy	20400.00
0005434757159	28676	Economy	20400.00
0005434214751	28676	Economy	20400.00
0005434214943	28676	Economy	20400.00
0005434214822	28676	Economy	20400.00
0005434214997	28676	Economy	20400.00
0005434757164	28676	Economy	20400.00
0005434757173	28676	Economy	20400.00
0005434215075	28676	Economy	20400.00
0005434757168	28676	Economy	20400.00
0005434757182	28676	Economy	20400.00
0005434757193	28676	Economy	20400.00
0005434757192	28676	Economy	20400.00
0005434215018	28676	Economy	20400.00
0005434757179	28676	Economy	20400.00
0005434757189	28676	Economy	20400.00
0005434215055	28676	Economy	20400.00
0005434215047	28676	Economy	20400.00
0005434214653	28676	Economy	20400.00
0005434215007	28676	Economy	20400.00
0005434757169	28676	Economy	20400.00
0005434214891	28676	Economy	20400.00
0005434215061	28676	Economy	20400.00
0005434757172	28676	Economy	20400.00
0005434757187	28676	Economy	20400.00
0005434757176	28676	Economy	20400.00
0005434214969	28676	Economy	20400.00
0005434215060	28676	Economy	20400.00
0005434215109	28676	Economy	20400.00
0005434215137	28676	Economy	20400.00
0005434757162	28676	Economy	20400.00
0005434214922	28676	Economy	20400.00
0005434214855	28676	Economy	20400.00
0005434215099	28676	Economy	20400.00
0005434214923	28676	Economy	20400.00
0005434757167	28676	Economy	20400.00
0005434757196	28676	Economy	20400.00
0005434214961	28676	Economy	20400.00
0005434757195	28676	Economy	20400.00
0005434757161	28676	Economy	20400.00
0005434757175	28676	Economy	20400.00
0005434214884	28676	Economy	20400.00
0005434214885	28676	Economy	20400.00
0005434215013	28676	Economy	20400.00
0005434757163	28676	Economy	20400.00
0005434757178	28676	Economy	20400.00
0005434214823	28676	Economy	20400.00
0005434757180	28676	Economy	20400.00
0005434214841	28676	Economy	20400.00
0005434214654	28676	Economy	20400.00
0005434214908	28676	Economy	20400.00
0005434214942	28676	Economy	20400.00
0005434757170	28676	Economy	20400.00
0005434757186	28676	Economy	20400.00
0005434757183	28676	Economy	20400.00
0005434757194	28676	Economy	20400.00
0005434214834	28676	Economy	20400.00
0005434215199	28676	Economy	20400.00
0005435040996	5455	Business	29500.00
0005435007492	5455	Business	29500.00
0005434229543	5455	Business	29500.00
0005435007468	5455	Business	29500.00
0005432125591	5455	Business	29500.00
0005432125597	5455	Business	29500.00
0005435041017	5455	Business	29500.00
0005435041007	5455	Business	29500.00
0005435041035	5455	Business	29500.00
0005435040994	5455	Business	29500.00
0005435007471	5455	Business	29500.00
0005435041041	5455	Economy	9800.00
0005435041012	5455	Economy	9800.00
0005435007476	5455	Economy	9800.00
0005435007478	5455	Economy	9800.00
0005435040992	5455	Economy	9800.00
0005435041020	5455	Economy	9800.00
0005434229624	5455	Economy	9800.00
0005434229544	5455	Economy	9800.00
0005435007475	5455	Economy	9800.00
0005435040989	5455	Economy	9800.00
0005435041000	5455	Economy	9800.00
0005435040986	5455	Economy	9800.00
0005435041051	5455	Economy	9800.00
0005435041003	5455	Economy	9800.00
0005434229613	5455	Economy	9800.00
0005435041010	5455	Economy	9800.00
0005435041040	5455	Economy	9800.00
0005435041039	5455	Economy	9800.00
0005435007473	5455	Economy	9800.00
0005435041036	5455	Economy	9800.00
0005435041037	5455	Economy	9800.00
0005435041029	5455	Economy	9800.00
0005435041045	5455	Economy	9800.00
0005435040995	5455	Economy	9800.00
0005434229573	5455	Economy	9800.00
0005435041052	5455	Economy	9800.00
0005435040987	5455	Economy	9800.00
0005435041001	5455	Economy	9800.00
0005435041043	5455	Economy	9800.00
0005434229635	5455	Economy	9800.00
0005435007482	5455	Economy	9800.00
0005435041032	5455	Economy	9800.00
0005435007484	5455	Economy	9800.00
0005435040993	5455	Economy	9800.00
0005435041044	5455	Economy	9800.00
0005434229641	5455	Economy	9800.00
0005435041013	5455	Economy	9800.00
0005435042895	5455	Economy	9800.00
0005435041005	5455	Economy	9800.00
0005434229637	5455	Economy	10800.00
0005435041004	5455	Economy	10800.00
0005435041030	5455	Economy	10800.00
0005435007474	5455	Economy	10800.00
0005435041024	5455	Economy	10800.00
0005435040997	5455	Economy	10800.00
0005435007469	5455	Economy	9800.00
0005435041011	5455	Economy	9800.00
0005434229638	5455	Economy	9800.00
0005435041034	5455	Economy	9800.00
0005434229651	5455	Economy	9800.00
0005435007490	5455	Economy	9800.00
0005435041027	5455	Economy	9800.00
0005434229618	5455	Economy	9800.00
0005434229636	5455	Economy	9800.00
0005435041046	5455	Economy	9800.00
0005435007481	5455	Economy	9800.00
0005434229572	5455	Economy	9800.00
0005435041026	5455	Economy	9800.00
0005435041002	5455	Economy	9800.00
0005432125592	5455	Economy	9800.00
0005435040998	5455	Economy	9800.00
0005435042897	5455	Economy	9800.00
0005435007477	5455	Economy	9800.00
0005435041021	5455	Economy	9800.00
0005435041042	5455	Economy	9800.00
0005435007491	5455	Economy	9800.00
0005435007485	5455	Economy	9800.00
0005432125596	5455	Economy	9800.00
0005435007472	5455	Economy	9800.00
0005434229541	5455	Economy	9800.00
0005435007480	5455	Economy	9800.00
0005435040991	5455	Economy	9800.00
0005434229614	5455	Economy	9800.00
0005435041031	5455	Economy	9800.00
0005435041006	5455	Economy	9800.00
0005435041028	5455	Economy	9800.00
0005435041018	5455	Economy	9800.00
0005435041016	5455	Economy	9800.00
0005435041015	5455	Economy	9800.00
0005434229630	5455	Economy	9800.00
0005435040999	5455	Economy	9800.00
0005435007488	5455	Economy	9800.00
0005435007487	5455	Economy	9800.00
0005435041033	5455	Economy	9800.00
0005435041008	5455	Economy	9800.00
0005435007467	5455	Economy	9800.00
0005435041023	5455	Economy	9800.00
0005432125594	5455	Economy	9800.00
0005435041025	5455	Economy	9800.00
0005435040988	5455	Economy	9800.00
0005432125598	5455	Economy	9800.00
0005434229642	5455	Economy	9800.00
0005435041022	5455	Economy	9800.00
0005435041038	5455	Economy	9800.00
0005435040990	5455	Economy	9800.00
0005435007489	5455	Economy	9800.00
0005435041014	5455	Economy	9800.00
0005432125593	5455	Economy	9800.00
0005435007483	5455	Economy	9800.00
0005435007470	5455	Economy	9800.00
0005435041047	5455	Economy	9800.00
0005435041009	5455	Economy	9800.00
0005435041050	5455	Economy	9800.00
0005434229650	5455	Economy	9800.00
0005434229631	5455	Economy	9800.00
0005435041019	5455	Economy	9800.00
0005435041053	5455	Economy	9800.00
0005434229615	5455	Economy	9800.00
0005435007479	5455	Economy	9800.00
0005434229592	5455	Economy	9800.00
0005435041048	5455	Economy	9800.00
0005434229640	5455	Economy	9800.00
0005435041049	5455	Economy	9800.00
0005432125595	5455	Economy	9800.00
0005435007486	5455	Economy	9800.00
0005435040985	5455	Economy	9800.00
0005435042896	5455	Economy	9800.00
0005435040527	12987	Business	29500.00
0005435040594	12987	Business	29500.00
0005434229817	12987	Business	29500.00
0005434229804	12987	Business	29500.00
0005435040589	12987	Business	29500.00
0005435040609	12987	Business	29500.00
0005435040242	12987	Business	29500.00
0005435377918	12987	Business	29500.00
0005435040681	12987	Business	29500.00
0005435040680	12987	Business	29500.00
0005435007213	12987	Business	29500.00
0005435040383	12987	Economy	9800.00
0005435040588	12987	Economy	9800.00
0005432304474	12987	Economy	9800.00
0005434229803	12987	Economy	9800.00
0005435040164	12987	Economy	9800.00
0005435040536	12987	Economy	9800.00
0005435007324	12987	Economy	9800.00
0005435007297	12987	Economy	9800.00
0005435040358	12987	Economy	9800.00
0005434229810	12987	Economy	9800.00
0005435040702	12987	Economy	9800.00
0005435040518	12987	Economy	9800.00
0005432304475	12987	Economy	9800.00
0005435007279	12987	Economy	9800.00
0005434229812	12987	Economy	9800.00
0005435040494	12987	Economy	9800.00
0005435040414	12987	Economy	9800.00
0005435040077	12987	Economy	9800.00
0005434229815	12987	Economy	9800.00
0005435040582	12987	Economy	9800.00
0005435377917	12987	Economy	9800.00
0005435040290	12987	Economy	9800.00
0005435040445	12987	Economy	9800.00
0005435007201	12987	Economy	9800.00
0005434229802	12987	Economy	9800.00
0005435043292	12987	Economy	9800.00
0005435040250	12987	Economy	9800.00
0005435007214	12987	Economy	9800.00
0005435040392	12987	Economy	9800.00
0005435040371	12987	Economy	9800.00
0005435040458	12987	Economy	9800.00
0005435377919	12987	Economy	9800.00
0005435040800	12987	Economy	9800.00
0005435007377	12987	Economy	9800.00
0005435007206	12987	Economy	9800.00
0005435042882	12987	Economy	9800.00
0005434229811	12987	Economy	9800.00
0005435040396	12987	Economy	10800.00
0005435377920	12987	Economy	10800.00
0005435040488	12987	Economy	10800.00
0005435007267	12987	Economy	10800.00
0005435007278	12987	Economy	10800.00
0005435040567	12987	Economy	10800.00
0005435040388	12987	Economy	9800.00
0005434229813	12987	Economy	9800.00
0005435007266	12987	Economy	9800.00
0005434229798	12987	Economy	9800.00
0005435040642	12987	Economy	9800.00
0005434229818	12987	Economy	9800.00
0005435040175	12987	Economy	9800.00
0005435040439	12987	Economy	9800.00
0005434229806	12987	Economy	9800.00
0005435040345	12987	Economy	9800.00
0005435040385	12987	Economy	9800.00
0005435040584	12987	Economy	9800.00
0005435007277	12987	Economy	9800.00
0005435007227	12987	Economy	9800.00
0005435040597	12987	Economy	9800.00
0005435040408	12987	Economy	9800.00
0005434229821	12987	Economy	9800.00
0005435040163	12987	Economy	9800.00
0005434229807	12987	Economy	9800.00
0005435040537	12987	Economy	9800.00
0005435007265	12987	Economy	9800.00
0005434229816	12987	Economy	9800.00
0005434229814	12987	Economy	9800.00
0005435042883	12987	Economy	9800.00
0005434229800	12987	Economy	9800.00
0005435040519	12987	Economy	9800.00
0005435043294	12987	Economy	9800.00
0005435040287	12987	Economy	9800.00
0005435040331	12987	Economy	9800.00
0005435042877	12987	Economy	9800.00
0005432304473	12987	Economy	9800.00
0005435040583	12987	Economy	9800.00
0005435042881	12987	Economy	9800.00
0005435043293	12987	Economy	9800.00
0005435040495	12987	Economy	9800.00
0005435007301	12987	Economy	9800.00
0005435040446	12987	Economy	9800.00
0005434229820	12987	Economy	9800.00
0005435040595	12987	Economy	9800.00
0005434229799	12987	Economy	9800.00
0005435040384	12987	Economy	9800.00
0005435040581	12987	Economy	9800.00
0005434229805	12987	Economy	9800.00
0005435040391	12987	Economy	9800.00
0005435040598	12987	Economy	9800.00
0005434229819	12987	Economy	9800.00
0005435040643	12987	Economy	9800.00
0005435007353	12987	Economy	9800.00
0005435007262	12987	Economy	9800.00
0005435040078	12987	Economy	9800.00
0005435040568	12987	Economy	9800.00
0005434229808	12987	Economy	9800.00
0005435007264	12987	Economy	9800.00
0005435040423	12987	Economy	9800.00
0005434229809	12987	Economy	9800.00
0005435040412	12987	Economy	9800.00
0005435007276	12987	Economy	9800.00
0005435007352	12987	Economy	9800.00
0005435040249	12987	Economy	9800.00
0005435040068	12987	Economy	9800.00
0005434229801	12987	Economy	9800.00
0005435007376	12987	Economy	9800.00
0005434427169	14891	Business	52900.00
0005435554207	14891	Business	52900.00
0005434427141	14891	Business	52900.00
0005434427147	14891	Business	52900.00
0005435902871	14891	Business	52900.00
0005435902907	14891	Business	52900.00
0005434427156	14891	Business	52900.00
0005434427160	14891	Business	52900.00
0005434427155	14891	Business	52900.00
0005434411858	14891	Economy	17600.00
0005435902799	14891	Economy	17600.00
0005434427163	14891	Economy	17600.00
0005434427168	14891	Economy	17600.00
0005434411857	14891	Economy	17600.00
0005434411859	14891	Economy	19400.00
0005432188667	14891	Economy	19400.00
0005435902885	14891	Economy	19400.00
0005434411856	14891	Economy	17600.00
0005434427159	14891	Economy	17600.00
0005434427149	14891	Economy	17600.00
0005435902915	14891	Economy	17600.00
0005434427143	14891	Economy	17600.00
0005435902862	14891	Economy	17600.00
0005435902902	14891	Economy	17600.00
0005434427146	14891	Economy	17600.00
0005434427162	14891	Economy	17600.00
0005434427158	14891	Economy	17600.00
0005434427164	14891	Economy	17600.00
0005434427152	14891	Economy	17600.00
0005435554239	14891	Economy	17600.00
0005434427145	14891	Economy	17600.00
0005435902906	14891	Economy	17600.00
0005432188668	14891	Economy	17600.00
0005434427148	14891	Economy	17600.00
0005435902942	14891	Economy	17600.00
0005434427165	14891	Economy	17600.00
0005434427150	14891	Economy	17600.00
0005434427166	14891	Economy	17600.00
0005432188669	14891	Economy	17600.00
0005435554238	14891	Economy	17600.00
0005434427151	14891	Economy	17600.00
0005434427154	14891	Economy	17600.00
0005434427161	14891	Economy	17600.00
0005435902826	14891	Economy	17600.00
0005434427157	14891	Economy	17600.00
0005435902919	14891	Economy	17600.00
0005434427140	14891	Economy	17600.00
0005435554240	14891	Economy	17600.00
0005435902867	14891	Economy	17600.00
0005435902884	14891	Economy	17600.00
0005435902872	14891	Economy	17600.00
0005434427144	14891	Economy	17600.00
0005435554208	14891	Economy	17600.00
0005434427142	14891	Economy	17600.00
0005434427167	14891	Economy	17600.00
0005434427153	14891	Economy	17600.00
0005435903040	20181	Business	52900.00
0005435903053	20181	Business	52900.00
0005435903041	20181	Business	52900.00
0005434426985	20181	Business	52900.00
0005435903051	20181	Business	52900.00
0005434411832	20181	Business	52900.00
0005435903049	20181	Business	52900.00
0005434427037	20181	Business	52900.00
0005435903048	20181	Business	52900.00
0005434427067	20181	Economy	17600.00
0005435903043	20181	Economy	17600.00
0005435903052	20181	Economy	17600.00
0005434426997	20181	Economy	17600.00
0005434426998	20181	Economy	17600.00
0005434426842	20181	Economy	17600.00
0005435554281	20181	Economy	17600.00
0005435903047	20181	Economy	17600.00
0005434426986	20181	Economy	19400.00
0005434426764	20181	Economy	19400.00
0005434426803	20181	Economy	17600.00
0005434427068	20181	Economy	17600.00
0005435903045	20181	Economy	17600.00
0005435903044	20181	Economy	17600.00
0005434426958	20181	Economy	17600.00
0005434427066	20181	Economy	17600.00
0005435554285	20181	Economy	17600.00
0005434426984	20181	Economy	17600.00
0005434411824	20181	Economy	17600.00
0005432059545	20181	Economy	17600.00
0005434426959	20181	Economy	17600.00
0005435554284	20181	Economy	17600.00
0005435903050	20181	Economy	17600.00
0005434427045	20181	Economy	17600.00
0005434427017	20181	Economy	17600.00
0005434426765	20181	Economy	17600.00
0005434411825	20181	Economy	17600.00
0005434426987	20181	Economy	17600.00
0005435903057	20181	Economy	17600.00
0005434426880	20181	Economy	17600.00
0005434427046	20181	Economy	17600.00
0005434411805	20181	Economy	17600.00
0005435903056	20181	Economy	17600.00
0005434427036	20181	Economy	17600.00
0005434426849	20181	Economy	17600.00
0005435554282	20181	Economy	17600.00
0005435903055	20181	Economy	17600.00
0005434426753	20181	Economy	17600.00
0005434426926	20181	Economy	17600.00
0005432059544	20181	Economy	17600.00
0005434426949	20181	Economy	17600.00
0005434426874	20181	Economy	17600.00
0005434427005	20181	Economy	17600.00
0005434411806	20181	Economy	17600.00
0005434426804	20181	Economy	17600.00
0005435903058	20181	Economy	17600.00
0005435554283	20181	Economy	17600.00
0005434426972	20181	Economy	17600.00
0005435903046	20181	Economy	17600.00
0005435903042	20181	Economy	17600.00
0005434426802	20181	Economy	17600.00
0005434426879	20181	Economy	17600.00
0005435903054	20181	Economy	17600.00
0005434426957	20181	Economy	17600.00
0005434426844	20181	Economy	17600.00
0005433726115	21660	Business	91700.00
0005433726120	21660	Economy	30600.00
0005433726119	21660	Economy	30600.00
0005433726094	21660	Economy	30600.00
0005433726102	21660	Economy	30600.00
0005433726100	21660	Economy	30600.00
0005433726098	21660	Economy	30600.00
0005433726099	21660	Economy	30600.00
0005433726121	21660	Economy	30600.00
0005433726107	21660	Economy	30600.00
0005433726111	21660	Economy	30600.00
0005433726114	21660	Economy	30600.00
0005433435012	26516	Business	18500.00
0005435983135	26516	Business	18500.00
0005433435009	26516	Business	18500.00
0005435983121	26516	Business	18500.00
0005433435036	26516	Business	18500.00
0005435983107	26516	Business	18500.00
0005435983150	26516	Business	18500.00
0005435983102	26516	Business	18500.00
0005433435008	26516	Business	18500.00
0005435983124	26516	Business	18500.00
0005435983149	26516	Business	18500.00
0005435983137	26516	Economy	6200.00
0005435983113	26516	Economy	6200.00
0005434273092	26516	Economy	6200.00
0005435983147	26516	Economy	6200.00
0005435983106	26516	Economy	6200.00
0005433435040	26516	Economy	6200.00
0005435983119	26516	Economy	6200.00
0005435983134	26516	Economy	6200.00
0005435983126	26516	Economy	6800.00
0005435983131	26516	Economy	6800.00
0005435983146	26516	Economy	6800.00
0005432300373	26516	Economy	6800.00
0005433434903	26516	Economy	6800.00
0005435983118	26516	Economy	6200.00
0005435983123	26516	Economy	6200.00
0005433434986	26516	Economy	6200.00
0005435983143	26516	Economy	6200.00
0005435983128	26516	Economy	6200.00
0005435983117	26516	Economy	6200.00
0005435983109	26516	Economy	6200.00
0005432300374	26516	Economy	6200.00
0005435983115	26516	Economy	6200.00
0005432300370	26516	Economy	6200.00
0005435983125	26516	Economy	6200.00
0005435983105	26516	Economy	6200.00
0005435983122	26516	Economy	6200.00
0005433434909	26516	Economy	6200.00
0005435983112	26516	Economy	6200.00
0005435983145	26516	Economy	6200.00
0005435983130	26516	Economy	6200.00
0005435983129	26516	Economy	6200.00
0005435983116	26516	Economy	6200.00
0005433435004	26516	Economy	6200.00
0005433434892	26516	Economy	6200.00
0005434270228	26516	Economy	6200.00
0005433435117	26516	Economy	6200.00
0005433435021	26516	Economy	6200.00
0005435983136	26516	Economy	6200.00
0005435983108	26516	Economy	6200.00
0005435983110	26516	Economy	6200.00
0005435983103	26516	Economy	6200.00
0005435983142	26516	Economy	6200.00
0005435983101	26516	Economy	6200.00
0005434270220	26516	Economy	6200.00
0005434273098	26516	Economy	6200.00
0005435983144	26516	Economy	6200.00
0005433434948	26516	Economy	6200.00
0005433434824	26516	Economy	6200.00
0005433435058	26516	Economy	6200.00
0005433435108	26516	Economy	6200.00
0005435983141	26516	Economy	6200.00
0005435983111	26516	Economy	6200.00
0005433434965	26516	Economy	6200.00
0005435983138	26516	Economy	6200.00
0005435983133	26516	Economy	6200.00
0005435983139	26516	Economy	6200.00
0005433434910	26516	Economy	6200.00
0005435983132	26516	Economy	6200.00
0005433435116	26516	Economy	6200.00
0005434270224	26516	Economy	6200.00
0005433435011	26516	Economy	6200.00
0005435983148	26516	Economy	6200.00
0005434273091	26516	Economy	6200.00
0005435983140	26516	Economy	6200.00
0005435983127	26516	Economy	6200.00
0005432300371	26516	Economy	6200.00
0005434270223	26516	Economy	6200.00
0005432300372	26516	Economy	6200.00
0005433435067	26516	Economy	6200.00
0005433434934	26516	Economy	6200.00
0005433435059	26516	Economy	6200.00
0005433435107	26516	Economy	6200.00
0005435983104	26516	Economy	6200.00
0005435983114	26516	Economy	6200.00
0005433434825	26516	Economy	6200.00
0005435983120	26516	Economy	6200.00
0005433435068	26516	Economy	6200.00
0005435982684	26698	Business	18500.00
0005433435234	26698	Business	18500.00
0005434269145	26698	Business	18500.00
0005435982848	26698	Business	18500.00
0005435982725	26698	Business	18500.00
0005433435228	26698	Business	18500.00
0005433435240	26698	Business	18500.00
0005435982815	26698	Business	18500.00
0005435982835	26698	Business	18500.00
0005435982760	26698	Business	18500.00
0005434269144	26698	Economy	6200.00
0005435982784	26698	Economy	6200.00
0005433435223	26698	Economy	6200.00
0005435982750	26698	Economy	6200.00
0005435982765	26698	Economy	6200.00
0005433435239	26698	Economy	6200.00
0005435982720	26698	Economy	6200.00
0005435982719	26698	Economy	6200.00
0005435982686	26698	Economy	6800.00
0005433435224	26698	Economy	6800.00
0005433435238	26698	Economy	6200.00
0005433435225	26698	Economy	6200.00
0005434270247	26698	Economy	6200.00
0005432051192	26698	Economy	6200.00
0005434269143	26698	Economy	6200.00
0005433435242	26698	Economy	6200.00
0005433435222	26698	Economy	6200.00
0005434271354	26698	Economy	6200.00
0005433435243	26698	Economy	6200.00
0005435982825	26698	Economy	6200.00
0005433435226	26698	Economy	6200.00
0005433435227	26698	Economy	6200.00
0005435982687	26698	Economy	6200.00
0005435982676	26698	Economy	6200.00
0005433435230	26698	Economy	6200.00
0005435982912	26698	Economy	6200.00
0005435982786	26698	Economy	6200.00
0005435982836	26698	Economy	6200.00
0005435982828	26698	Economy	6200.00
0005433435220	26698	Economy	6200.00
0005433435221	26698	Economy	6200.00
0005433435217	26698	Economy	6200.00
0005435982939	26698	Economy	6200.00
0005435982826	26698	Economy	6200.00
0005433435218	26698	Economy	6200.00
0005435982718	26698	Economy	6200.00
0005435982751	26698	Economy	6200.00
0005435982802	26698	Economy	6200.00
0005435982643	26698	Economy	6200.00
0005432051190	26698	Economy	6200.00
0005435982782	26698	Economy	6200.00
0005435982821	26698	Economy	6200.00
0005435982594	26698	Economy	6200.00
0005433435233	26698	Economy	6200.00
0005435982583	26698	Economy	6200.00
0005435982685	26698	Economy	6200.00
0005435982766	26698	Economy	6200.00
0005434270248	26698	Economy	6200.00
0005433435219	26698	Economy	6200.00
0005432051191	26698	Economy	6200.00
0005433435235	26698	Economy	6200.00
0005433435232	26698	Economy	6200.00
0005434271353	26698	Economy	6200.00
0005433435236	26698	Economy	6200.00
0005433435229	26698	Economy	6200.00
0005435982878	26698	Economy	6200.00
0005435982877	26698	Economy	6200.00
0005432051189	26698	Economy	6200.00
0005433435237	26698	Economy	6200.00
0005433435241	26698	Economy	6200.00
0005435982940	26698	Economy	6200.00
0005433435231	26698	Economy	6200.00
0005435982597	26698	Economy	6200.00
0005433435244	26698	Economy	6200.00
0005435982792	26698	Economy	6200.00
0005432584526	3147	Economy	11100.00
0005432584517	3147	Economy	11100.00
0005432584534	3147	Economy	10100.00
0005432584532	3147	Economy	10100.00
0005432584520	3147	Economy	10100.00
0005432584522	3147	Economy	10100.00
0005432858192	3147	Economy	10100.00
0005432584533	3147	Economy	10100.00
0005432216327	3147	Economy	10100.00
0005432858229	3147	Economy	10100.00
0005432216326	3147	Economy	10100.00
0005432858223	3147	Economy	10100.00
0005432584513	3147	Economy	10100.00
0005432584531	3147	Economy	10100.00
0005432584515	3147	Economy	10100.00
0005432584523	3147	Economy	10100.00
0005432584536	3147	Economy	10100.00
0005432584516	3147	Economy	10100.00
0005432858188	3147	Economy	10100.00
0005432584525	3147	Economy	10100.00
0005432584512	3147	Economy	10100.00
0005432858150	3147	Economy	10100.00
0005432858244	3147	Economy	10100.00
0005432858224	3147	Economy	10100.00
0005432584527	3147	Economy	10100.00
0005432584524	3147	Economy	10100.00
0005432584530	3147	Economy	10100.00
0005432584518	3147	Economy	10100.00
0005432858151	3147	Economy	10100.00
0005432584535	3147	Economy	10100.00
0005432584529	3147	Economy	10100.00
0005432584528	3147	Economy	10100.00
0005432858204	3147	Economy	10100.00
0005432858209	3147	Economy	10100.00
0005432858187	3147	Economy	10100.00
0005432584519	3147	Economy	10100.00
0005432858202	3147	Economy	10100.00
0005432584521	3147	Economy	10100.00
0005432858208	3147	Economy	10100.00
0005432858230	3147	Economy	10100.00
0005432858205	3147	Economy	10100.00
0005432216328	3147	Economy	10100.00
0005432584514	3147	Economy	10100.00
0005432584511	3147	Economy	10100.00
0005432584359	31516	Economy	11100.00
0005432584375	31516	Economy	11100.00
0005432584324	31516	Economy	11100.00
0005432858307	31516	Economy	10100.00
0005432858305	31516	Economy	10100.00
0005432858306	31516	Economy	10100.00
0005432858300	31516	Economy	10100.00
0005432858299	31516	Economy	10100.00
0005432584287	31516	Economy	10100.00
0005432584284	31516	Economy	10100.00
0005432584372	31516	Economy	10100.00
0005432584366	31516	Economy	10100.00
0005432584302	31516	Economy	10100.00
0005432858298	31516	Economy	10100.00
0005432584320	31516	Economy	10100.00
0005432584236	31516	Economy	10100.00
0005432584329	31516	Economy	10100.00
0005432858301	31516	Economy	10100.00
0005432584301	31516	Economy	10100.00
0005432584327	31516	Economy	10100.00
0005432858303	31516	Economy	10100.00
0005432584326	31516	Economy	10100.00
0005432584321	31516	Economy	10100.00
0005432584288	31516	Economy	10100.00
0005432584399	31516	Economy	10100.00
0005432858302	31516	Economy	10100.00
0005432584322	31516	Economy	10100.00
0005432584365	31516	Economy	10100.00
0005432584325	31516	Economy	10100.00
0005432584392	31516	Economy	10100.00
0005432584367	31516	Economy	10100.00
0005432858304	31516	Economy	10100.00
0005432584285	31516	Economy	10100.00
0005432584328	31516	Economy	10100.00
0005432584300	31516	Economy	10100.00
0005432584261	31516	Economy	10100.00
0005432858308	31516	Economy	10100.00
0005432584286	31516	Economy	10100.00
0005434943526	896	Economy	8300.00
0005433255178	896	Economy	8300.00
0005434943530	896	Economy	7500.00
0005433255175	896	Economy	7500.00
0005434943529	896	Economy	7500.00
0005433255166	896	Economy	7500.00
0005434943533	896	Economy	7500.00
0005434943534	896	Economy	7500.00
0005434943531	896	Economy	7500.00
0005434943535	896	Economy	7500.00
0005434943532	896	Economy	7500.00
0005434943527	896	Economy	7500.00
0005434943528	896	Economy	7500.00
0005434943469	16194	Economy	8300.00
0005434943460	16194	Economy	7500.00
0005433255226	16194	Economy	7500.00
0005433255227	16194	Economy	7500.00
0005434943438	16194	Economy	7500.00
0005433255223	16194	Economy	7500.00
0005434943432	16194	Economy	7500.00
0005433255222	16194	Economy	7500.00
0005433255225	16194	Economy	7500.00
0005434943487	16194	Economy	7500.00
0005434943489	16194	Economy	7500.00
0005434943472	16194	Economy	7500.00
0005433255224	16194	Economy	7500.00
0005434943462	16194	Economy	7500.00
0005434943473	16194	Economy	7500.00
0005434943434	16194	Economy	7500.00
0005434943433	16194	Economy	7500.00
0005433811644	14349	Economy	4400.00
0005433811654	14349	Economy	4400.00
0005433811647	14349	Economy	4400.00
0005433811655	14349	Economy	4400.00
0005433368082	21748	Business	9800.00
0005435653890	21748	Business	9800.00
0005435653887	21748	Business	9800.00
0005433368217	21748	Business	9800.00
0005435653882	21748	Business	9800.00
0005433368404	21748	Business	9800.00
0005435653894	21748	Business	9800.00
0005433368053	21748	Business	9800.00
0005433368148	21748	Business	9800.00
0005435653898	21748	Business	9800.00
0005433368258	21748	Economy	3300.00
0005435653858	21748	Economy	3300.00
0005435653864	21748	Economy	3300.00
0005435653878	21748	Economy	3300.00
0005435653902	21748	Economy	3300.00
0005435653903	21748	Economy	3300.00
0005433368227	21748	Economy	3300.00
0005433368261	21748	Economy	3300.00
0005433368313	21748	Economy	3300.00
0005433368324	21748	Economy	3300.00
0005433368260	21748	Economy	3600.00
0005435653892	21748	Economy	3600.00
0005433368203	21748	Economy	3600.00
0005433368378	21748	Economy	3600.00
0005435653880	21748	Economy	3600.00
0005433368297	21748	Economy	3300.00
0005435653865	21748	Economy	3300.00
0005435653856	21748	Economy	3300.00
0005435653888	21748	Economy	3300.00
0005435653893	21748	Economy	3300.00
0005433368251	21748	Economy	3300.00
0005435653881	21748	Economy	3300.00
0005435653863	21748	Economy	3300.00
0005433368379	21748	Economy	3300.00
0005433368096	21748	Economy	3300.00
0005433368098	21748	Economy	3300.00
0005433368219	21748	Economy	3300.00
0005435653872	21748	Economy	3300.00
0005433368501	21748	Economy	3300.00
0005433368259	21748	Economy	3300.00
0005435653867	21748	Economy	3300.00
0005435653877	21748	Economy	3300.00
0005435653861	21748	Economy	3300.00
0005433368097	21748	Economy	3300.00
0005435653875	21748	Economy	3300.00
0005435653900	21748	Economy	3300.00
0005435653899	21748	Economy	3300.00
0005435653866	21748	Economy	3300.00
0005433368052	21748	Economy	3300.00
0005435653884	21748	Economy	3300.00
0005435653895	21748	Economy	3300.00
0005433368387	21748	Economy	3300.00
0005435653868	21748	Economy	3300.00
0005433368147	21748	Economy	3300.00
0005435653901	21748	Economy	3300.00
0005435653891	21748	Economy	3300.00
0005433368155	21748	Economy	3300.00
0005435653874	21748	Economy	3300.00
0005435653873	21748	Economy	3300.00
0005435653857	21748	Economy	3300.00
0005433368252	21748	Economy	3300.00
0005435653869	21748	Economy	3300.00
0005435653859	21748	Economy	3300.00
0005433368339	21748	Economy	3300.00
0005433368306	21748	Economy	3300.00
0005433368257	21748	Economy	3300.00
0005433368347	21748	Economy	3300.00
0005435653886	21748	Economy	3300.00
0005435653883	21748	Economy	3300.00
0005433368298	21748	Economy	3300.00
0005435653905	21748	Economy	3300.00
0005433368248	21748	Economy	3300.00
0005435653889	21748	Economy	3300.00
0005433368312	21748	Economy	3300.00
0005435653871	21748	Economy	3300.00
0005435653862	21748	Economy	3300.00
0005433368305	21748	Economy	3300.00
0005433368398	21748	Economy	3300.00
0005435653885	21748	Economy	3300.00
0005433368388	21748	Economy	3300.00
0005435653870	21748	Economy	3300.00
0005435653860	21748	Economy	3300.00
0005433368241	21748	Economy	3300.00
0005433368502	21748	Economy	3300.00
0005435653897	21748	Economy	3300.00
0005435653896	21748	Economy	3300.00
0005433368386	21748	Economy	3300.00
0005435653876	21748	Economy	3300.00
0005435653879	21748	Economy	3300.00
0005435653904	21748	Economy	3300.00
0005434171252	9349	Business	186200.00
0005433785651	9349	Business	186200.00
0005433806065	9349	Business	186200.00
0005434171196	9349	Business	186200.00
0005433785661	9349	Business	186200.00
0005433785671	9349	Business	186200.00
0005433763495	9349	Business	186200.00
0005433763494	9349	Business	186200.00
0005433763487	9349	Business	186200.00
0005432657510	9349	Business	186200.00
0005433785656	9349	Business	186200.00
0005433785670	9349	Business	186200.00
0005434270231	9349	Business	186200.00
0005433785667	9349	Business	186200.00
0005434171214	9349	Business	186200.00
0005433785673	9349	Business	186200.00
0005433806060	9349	Economy	68300.00
0005433785636	9349	Economy	68300.00
0005434171175	9349	Economy	68300.00
0005433785642	9349	Economy	68300.00
0005433785633	9349	Economy	62100.00
0005433806048	9349	Economy	62100.00
0005433785648	9349	Economy	62100.00
0005433785665	9349	Economy	62100.00
0005433785658	9349	Economy	62100.00
0005433785634	9349	Economy	62100.00
0005433806051	9349	Economy	62100.00
0005433763486	9349	Economy	62100.00
0005433763488	9349	Economy	62100.00
0005434171250	9349	Economy	62100.00
0005433785644	9349	Economy	62100.00
0005434171190	9349	Economy	62100.00
0005433785635	9349	Economy	62100.00
0005433806062	9349	Economy	62100.00
0005433785632	9349	Economy	62100.00
0005435269787	9349	Economy	62100.00
0005434171219	9349	Economy	62100.00
0005433806055	9349	Economy	62100.00
0005433806044	9349	Economy	62100.00
0005434273093	9349	Economy	62100.00
0005434171277	9349	Economy	62100.00
0005433785655	9349	Economy	62100.00
0005433806064	9349	Economy	62100.00
0005434171244	9349	Economy	62100.00
0005434151733	9349	Economy	62100.00
0005433763493	9349	Economy	62100.00
0005435269796	9349	Economy	62100.00
0005433785645	9349	Economy	62100.00
0005433763491	9349	Economy	62100.00
0005433763492	9349	Economy	62100.00
0005433763485	9349	Economy	62100.00
0005433785664	9349	Economy	62100.00
0005433785637	9349	Economy	62100.00
0005433806056	9349	Economy	62100.00
0005433785669	9349	Economy	62100.00
0005433806040	9349	Economy	62100.00
0005433785650	9349	Economy	62100.00
0005432665314	9349	Economy	62100.00
0005433806058	9349	Economy	62100.00
0005435269798	9349	Economy	62100.00
0005433785649	9349	Economy	62100.00
0005433806039	9349	Economy	62100.00
0005433763484	9349	Economy	62100.00
0005434171222	9349	Economy	62100.00
0005435269771	9349	Economy	62100.00
0005433785666	9349	Economy	62100.00
0005433806046	9349	Economy	62100.00
0005433806066	9349	Economy	62100.00
0005433806063	9349	Economy	62100.00
0005433806038	9349	Economy	62100.00
0005435269786	9349	Economy	62100.00
0005433806047	9349	Economy	62100.00
0005433806053	9349	Economy	62100.00
0005433806057	9349	Economy	62100.00
0005432657509	9349	Economy	62100.00
0005433806054	9349	Economy	62100.00
0005434270232	9349	Economy	62100.00
0005432665315	9349	Economy	68300.00
0005434171218	9349	Economy	62100.00
0005433763482	9349	Economy	68300.00
0005433785660	9349	Economy	68300.00
0005433806052	9349	Economy	62100.00
0005435269797	9349	Economy	62100.00
0005433785638	9349	Economy	62100.00
0005434171251	9349	Economy	62100.00
0005433806045	9349	Economy	62100.00
0005433763496	9349	Economy	62100.00
0005433806061	9349	Economy	62100.00
0005433763489	9349	Economy	62100.00
0005433806050	9349	Economy	62100.00
0005435269793	9349	Economy	62100.00
0005432666429	9349	Economy	62100.00
0005434171172	9349	Economy	62100.00
0005433785657	9349	Economy	62100.00
0005433806042	9349	Economy	62100.00
0005435269794	9349	Economy	62100.00
0005433785662	9349	Economy	62100.00
0005433806043	9349	Economy	62100.00
0005434171276	9349	Economy	62100.00
0005433785639	9349	Economy	62100.00
0005433785659	9349	Economy	62100.00
0005434171177	9349	Economy	62100.00
0005433785663	9349	Economy	62100.00
0005433763490	9349	Economy	62100.00
0005433785654	9349	Economy	62100.00
0005433785652	9349	Economy	62100.00
0005434171213	9349	Economy	62100.00
0005434171265	9349	Economy	62100.00
0005433785646	9349	Economy	62100.00
0005433785643	9349	Economy	62100.00
0005434151734	9349	Economy	62100.00
0005434171217	9349	Economy	62100.00
0005435269772	9349	Economy	62100.00
0005434273094	9349	Economy	62100.00
0005434171160	9349	Economy	62100.00
0005433785672	9349	Economy	62100.00
0005433785653	9349	Economy	62100.00
0005433806049	9349	Economy	62100.00
0005433806041	9349	Economy	62100.00
0005433806059	9349	Economy	62100.00
0005433785668	9349	Economy	62100.00
0005433763483	9349	Economy	62100.00
0005433785641	9349	Economy	62100.00
0005433785647	9349	Economy	62100.00
0005433785640	9349	Economy	62100.00
0005434171336	26260	Business	186200.00
0005433785350	26260	Business	186200.00
0005433763333	26260	Business	186200.00
0005433805838	26260	Business	186200.00
0005433785294	26260	Business	186200.00
0005433785370	26260	Business	186200.00
0005433805731	26260	Business	186200.00
0005433805762	26260	Business	186200.00
0005433763382	26260	Business	186200.00
0005433785452	26260	Business	186200.00
0005433785270	26260	Business	186200.00
0005433805673	26260	Business	186200.00
0005433785088	26260	Business	186200.00
0005433785269	26260	Business	186200.00
0005433805780	26260	Business	186200.00
0005433785309	26260	Business	186200.00
0005435269904	26260	Business	186200.00
0005435269910	26260	Business	186200.00
0005435269901	26260	Business	186200.00
0005433763411	26260	Business	186200.00
0005434151760	26260	Economy	68300.00
0005434171333	26260	Economy	62100.00
0005433785196	26260	Economy	62100.00
0005432666423	26260	Economy	62100.00
0005433763367	26260	Economy	62100.00
0005433805663	26260	Economy	62100.00
0005435269906	26260	Economy	62100.00
0005433785494	26260	Economy	62100.00
0005435269903	26260	Economy	62100.00
0005433785425	26260	Economy	62100.00
0005433805637	26260	Economy	62100.00
0005433805775	26260	Economy	62100.00
0005433805633	26260	Economy	62100.00
0005434171338	26260	Economy	62100.00
0005433785439	26260	Economy	62100.00
0005433805813	26260	Economy	62100.00
0005433785438	26260	Economy	62100.00
0005433763327	26260	Economy	62100.00
0005433805672	26260	Economy	62100.00
0005433785213	26260	Economy	62100.00
0005433805755	26260	Economy	62100.00
0005433805773	26260	Economy	62100.00
0005433785331	26260	Economy	62100.00
0005434171335	26260	Economy	62100.00
0005433785299	26260	Economy	62100.00
0005433785332	26260	Economy	62100.00
0005435269905	26260	Economy	62100.00
0005434271352	26260	Economy	62100.00
0005433785372	26260	Economy	62100.00
0005433805788	26260	Economy	62100.00
0005435269911	26260	Economy	62100.00
0005433785089	26260	Economy	62100.00
0005433785310	26260	Economy	62100.00
0005433785374	26260	Economy	62100.00
0005432663058	26260	Economy	62100.00
0005433805689	26260	Economy	62100.00
0005433785373	26260	Economy	62100.00
0005433763359	26260	Economy	62100.00
0005432657479	26260	Economy	62100.00
0005433763358	26260	Economy	62100.00
0005433805529	26260	Economy	62100.00
0005433805756	26260	Economy	62100.00
0005434171330	26260	Economy	62100.00
0005433785318	26260	Economy	62100.00
0005435269907	26260	Economy	62100.00
0005433763328	26260	Economy	62100.00
0005433805815	26260	Economy	62100.00
0005433805883	26260	Economy	62100.00
0005433805596	26260	Economy	62100.00
0005433785127	26260	Economy	62100.00
0005433763360	26260	Economy	62100.00
0005435269902	26260	Economy	62100.00
0005434151761	26260	Economy	62100.00
0005433785453	26260	Economy	62100.00
0005435269912	26260	Economy	62100.00
0005433763305	26260	Economy	62100.00
0005434269141	26260	Economy	62100.00
0005434151759	26260	Economy	62100.00
0005433805774	26260	Economy	62100.00
0005433785268	26260	Economy	62100.00
0005433805884	26260	Economy	62100.00
0005433785192	26260	Economy	62100.00
0005433785175	26260	Economy	62100.00
0005433763368	26260	Economy	62100.00
0005433785384	26260	Economy	62100.00
0005433805732	26260	Economy	62100.00
0005434171337	26260	Economy	62100.00
0005433785300	26260	Economy	62100.00
0005433805671	26260	Economy	62100.00
0005433785298	26260	Economy	62100.00
0005433805658	26260	Economy	62100.00
0005432659725	26260	Economy	62100.00
0005434271351	26260	Economy	62100.00
0005434171329	26260	Economy	62100.00
0005433785489	26260	Economy	62100.00
0005433785311	26260	Economy	62100.00
0005432663048	26260	Economy	62100.00
0005433763410	26260	Economy	62100.00
0005434171339	26260	Economy	62100.00
0005433805661	26260	Economy	62100.00
0005434171331	26260	Economy	62100.00
0005434271350	26260	Economy	62100.00
0005433805662	26260	Economy	62100.00
0005434270246	26260	Economy	62100.00
0005433805754	26260	Economy	62100.00
0005433785357	26260	Economy	62100.00
0005433785173	26260	Economy	62100.00
0005435269908	26260	Economy	62100.00
0005433785441	26260	Economy	62100.00
0005433763369	26260	Economy	62100.00
0005433785512	26260	Economy	62100.00
0005433763376	26260	Economy	62100.00
0005434171332	26260	Economy	62100.00
0005433785446	26260	Economy	62100.00
0005433805812	26260	Economy	62100.00
0005433763332	26260	Economy	62100.00
0005433785354	26260	Economy	62100.00
0005433805664	26260	Economy	62100.00
0005433805814	26260	Economy	62100.00
0005434171334	26260	Economy	62100.00
0005433785479	26260	Economy	62100.00
0005432663068	26260	Economy	62100.00
0005433805707	26260	Economy	62100.00
0005433785383	26260	Economy	62100.00
0005433805708	26260	Economy	62100.00
0005433785214	26260	Economy	62100.00
0005434269142	26260	Economy	62100.00
0005433785371	26260	Economy	62100.00
0005433763347	26260	Economy	62100.00
0005433763346	26260	Economy	62100.00
0005433785442	26260	Economy	62100.00
0005433785249	26260	Economy	62100.00
0005435269909	26260	Economy	62100.00
0005434270245	26260	Economy	62100.00
0005433805595	26260	Economy	62100.00
0005435135766	4922	Economy	5300.00
0005435929671	4922	Economy	5300.00
0005435135765	4922	Economy	5300.00
0005435135764	4922	Economy	5300.00
0005435135763	4922	Economy	5300.00
0005435929672	4922	Economy	5300.00
0005435135767	4922	Economy	5300.00
0005435135707	33049	Economy	5900.00
0005435135722	33049	Economy	5900.00
0005435929695	33049	Economy	5300.00
0005435135730	33049	Economy	5300.00
0005435135708	33049	Economy	5300.00
0005435929696	33049	Economy	5300.00
0005435135710	33049	Economy	5300.00
0005435135736	33049	Economy	5300.00
0005435135737	33049	Economy	5300.00
0005435929697	33049	Economy	5300.00
0005434983386	9491	Economy	19700.00
0005434983387	9491	Economy	17900.00
0005434217996	9491	Economy	17900.00
0005434218023	9491	Economy	17900.00
0005434983389	9491	Economy	17900.00
0005434218010	9491	Economy	17900.00
0005434983388	9491	Economy	17900.00
0005434983390	9491	Economy	17900.00
0005434218047	27373	Economy	19700.00
0005434983341	27373	Economy	17900.00
0005434983347	27373	Economy	17900.00
0005434218048	27373	Economy	17900.00
0005434983336	27373	Economy	17900.00
0005434218049	27373	Economy	17900.00
0005434218046	27373	Economy	17900.00
0005434983335	27373	Economy	17900.00
0005433961347	24232	Business	36400.00
0005433986437	24232	Business	36400.00
0005433986294	24232	Business	36400.00
0005433961355	24232	Business	36400.00
0005433986434	24232	Business	36400.00
0005433961469	24232	Business	36400.00
0005433961440	24232	Business	36400.00
0005433961330	24232	Business	36400.00
0005433961432	24232	Economy	13400.00
0005433986326	24232	Economy	13400.00
0005433961386	24232	Economy	12100.00
0005433961429	24232	Economy	13400.00
0005433986453	24232	Economy	12100.00
0005433961297	24232	Economy	12100.00
0005433961427	24232	Economy	12100.00
0005433986229	24232	Economy	12100.00
0005433961367	24232	Economy	12100.00
0005433986265	24232	Economy	12100.00
0005433961257	24232	Economy	12100.00
0005433986367	24232	Economy	12100.00
0005433986474	24232	Economy	12100.00
0005433961382	24232	Economy	12100.00
0005433961368	24232	Economy	12100.00
0005433986413	24232	Economy	12100.00
0005433961369	24232	Economy	12100.00
0005433986414	24232	Economy	12100.00
0005433961462	24232	Economy	12100.00
0005433986234	24232	Economy	12100.00
0005433986387	24232	Economy	12100.00
0005433986208	24232	Economy	12100.00
0005433986156	24232	Economy	12100.00
0005433961256	24232	Economy	12100.00
0005433986243	24232	Economy	12100.00
0005433961258	24232	Economy	12100.00
0005433986330	24232	Economy	12100.00
0005433986209	24232	Economy	12100.00
0005433961268	24232	Economy	12100.00
0005433961421	24232	Economy	12100.00
0005433961459	24232	Economy	12100.00
0005433961291	24232	Economy	12100.00
0005433986454	24232	Economy	12100.00
0005433961359	24232	Economy	12100.00
0005433961259	24232	Economy	12100.00
0005433961399	24232	Economy	12100.00
0005433986264	24232	Economy	12100.00
0005433961293	24232	Economy	12100.00
0005433961346	24232	Economy	13400.00
0005433961348	24232	Economy	13400.00
0005433961230	24232	Economy	12100.00
0005433961463	24232	Economy	12100.00
0005433986394	24232	Economy	12100.00
0005433961337	24232	Economy	12100.00
0005433986388	24232	Economy	12100.00
0005433986284	24232	Economy	12100.00
0005433961249	24232	Economy	12100.00
0005433961381	24232	Economy	12100.00
0005433986340	24232	Economy	12100.00
0005433986339	24232	Economy	12100.00
0005433961400	24232	Economy	12100.00
0005433986258	24232	Economy	12100.00
0005433986435	24232	Economy	12100.00
0005433986283	24232	Economy	12100.00
0005433961401	24232	Economy	12100.00
0005433961410	24232	Economy	12100.00
0005433961292	24232	Economy	12100.00
0005433961229	24232	Economy	12100.00
0005433986301	24232	Economy	12100.00
0005433986422	24232	Economy	12100.00
0005433986475	24232	Economy	12100.00
0005433961468	24232	Economy	12100.00
0005433986315	24232	Economy	12100.00
0005433986304	24232	Economy	12100.00
0005433961329	24232	Economy	12100.00
0005433961450	24232	Economy	12100.00
0005433961460	24232	Economy	12100.00
0005433986193	24232	Economy	12100.00
0005433961461	24232	Economy	12100.00
0005433961192	24232	Economy	12100.00
0005433986438	24232	Economy	12100.00
0005433986341	24232	Economy	12100.00
0005433986823	25947	Business	36400.00
0005433961946	25947	Business	36400.00
0005433986824	25947	Business	36400.00
0005433961929	25947	Business	36400.00
0005433986825	25947	Business	36400.00
0005433961930	25947	Business	36400.00
0005433986836	25947	Business	36400.00
0005433961940	25947	Business	36400.00
0005433961934	25947	Business	36400.00
0005433961924	25947	Business	36400.00
0005433986832	25947	Business	36400.00
0005433961923	25947	Business	36400.00
0005433961964	25947	Business	36400.00
0005433986801	25947	Business	36400.00
0005433961925	25947	Business	36400.00
0005433961915	25947	Business	36400.00
0005433961958	25947	Business	36400.00
0005433986840	25947	Business	36400.00
0005433986841	25947	Business	36400.00
0005433986802	25947	Business	36400.00
0005433986831	25947	Economy	13400.00
0005433986833	25947	Economy	12100.00
0005433986838	25947	Economy	12100.00
0005433986834	25947	Economy	12100.00
0005433986828	25947	Economy	12100.00
0005433961957	25947	Economy	12100.00
0005433986814	25947	Economy	12100.00
0005433986844	25947	Economy	12100.00
0005433986805	25947	Economy	12100.00
0005433961935	25947	Economy	12100.00
0005433986822	25947	Economy	12100.00
0005433961927	25947	Economy	12100.00
0005433961943	25947	Economy	12100.00
0005433986817	25947	Economy	12100.00
0005433961928	25947	Economy	12100.00
0005433961959	25947	Economy	12100.00
0005433961965	25947	Economy	12100.00
0005433986842	25947	Economy	12100.00
0005433961916	25947	Economy	12100.00
0005433961968	25947	Economy	12100.00
0005433961955	25947	Economy	12100.00
0005433961962	25947	Economy	12100.00
0005433961912	25947	Economy	12100.00
0005433961956	25947	Economy	12100.00
0005433961960	25947	Economy	12100.00
0005433961942	25947	Economy	12100.00
0005433961941	25947	Economy	12100.00
0005433961922	25947	Economy	12100.00
0005433986843	25947	Economy	12100.00
0005433961936	25947	Economy	12100.00
0005433986827	25947	Economy	12100.00
0005433986826	25947	Economy	12100.00
0005433961947	25947	Economy	12100.00
0005433961913	25947	Economy	12100.00
0005433986830	25947	Economy	12100.00
0005433986806	25947	Economy	12100.00
0005433986821	25947	Economy	12100.00
0005433961932	25947	Economy	12100.00
0005433961910	25947	Economy	12100.00
0005433961914	25947	Economy	12100.00
0005433961938	25947	Economy	12100.00
0005433986829	25947	Economy	12100.00
0005433986819	25947	Economy	12100.00
0005433986815	25947	Economy	12100.00
0005433986820	25947	Economy	12100.00
0005433961939	25947	Economy	12100.00
0005433986809	25947	Economy	12100.00
0005433961963	25947	Economy	12100.00
0005433986837	25947	Economy	12100.00
0005433961954	25947	Economy	12100.00
0005433986808	25947	Economy	12100.00
0005433986811	25947	Economy	12100.00
0005433961917	25947	Economy	12100.00
0005433961949	25947	Economy	13400.00
0005433961921	25947	Economy	13400.00
0005433961969	25947	Economy	12100.00
0005433961945	25947	Economy	12100.00
0005433961948	25947	Economy	12100.00
0005433986816	25947	Economy	12100.00
0005433961971	25947	Economy	12100.00
0005433961953	25947	Economy	12100.00
0005433986804	25947	Economy	12100.00
0005433961966	25947	Economy	12100.00
0005433986813	25947	Economy	12100.00
0005433961926	25947	Economy	12100.00
0005433986807	25947	Economy	12100.00
0005433961973	25947	Economy	12100.00
0005433961967	25947	Economy	12100.00
0005433986812	25947	Economy	12100.00
0005433961911	25947	Economy	12100.00
0005433961972	25947	Economy	12100.00
0005433961937	25947	Economy	12100.00
0005433986810	25947	Economy	12100.00
0005433986818	25947	Economy	12100.00
0005433961931	25947	Economy	12100.00
0005433961918	25947	Economy	12100.00
0005433961933	25947	Economy	12100.00
0005433961952	25947	Economy	12100.00
0005433986839	25947	Economy	12100.00
0005433961970	25947	Economy	12100.00
0005433961950	25947	Economy	12100.00
0005433986803	25947	Economy	12100.00
0005433961909	25947	Economy	12100.00
0005433961908	25947	Economy	12100.00
0005433961919	25947	Economy	12100.00
0005433986835	25947	Economy	12100.00
0005433961961	25947	Economy	12100.00
0005433961920	25947	Economy	12100.00
0005433961951	25947	Economy	12100.00
0005433961907	25947	Economy	12100.00
0005433961944	25947	Economy	12100.00
0005434480796	961	Economy	25400.00
0005433166008	961	Economy	25400.00
0005434480803	961	Economy	25400.00
0005434480813	961	Economy	23100.00
0005434480815	961	Economy	23100.00
0005433166007	961	Economy	23100.00
0005434480800	961	Economy	23100.00
0005434480810	961	Economy	23100.00
0005434480816	961	Economy	23100.00
0005434480821	961	Economy	23100.00
0005434480804	961	Economy	23100.00
0005434480801	961	Economy	23100.00
0005434480818	961	Economy	23100.00
0005434480811	961	Economy	23100.00
0005434480809	961	Economy	23100.00
0005434480806	961	Economy	23100.00
0005434480805	961	Economy	23100.00
0005434480812	961	Economy	23100.00
0005433166080	961	Economy	23100.00
0005434480820	961	Economy	23100.00
0005433166004	961	Economy	23100.00
0005434480808	961	Economy	23100.00
0005432269551	961	Economy	23100.00
0005434480802	961	Economy	23100.00
0005434480799	961	Economy	23100.00
0005434480822	961	Economy	23100.00
0005434480814	961	Economy	23100.00
0005434480819	961	Economy	23100.00
0005434480797	961	Economy	23100.00
0005434480798	961	Economy	23100.00
0005433166042	961	Economy	23100.00
0005433166079	961	Economy	23100.00
0005432269549	961	Economy	23100.00
0005432269550	961	Economy	23100.00
0005434480807	961	Economy	23100.00
0005434480817	961	Economy	23100.00
0005434480610	16593	Economy	25400.00
0005433166164	16593	Economy	25400.00
0005434480593	16593	Economy	23100.00
0005434480611	16593	Economy	23100.00
0005433166163	16593	Economy	23100.00
0005434480648	16593	Economy	23100.00
0005434480560	16593	Economy	23100.00
0005434480696	16593	Economy	23100.00
0005434480580	16593	Economy	23100.00
0005433166152	16593	Economy	23100.00
0005433166160	16593	Economy	23100.00
0005434480520	16593	Economy	23100.00
0005433166155	16593	Economy	23100.00
0005434480697	16593	Economy	23100.00
0005433166153	16593	Economy	23100.00
0005433166157	16593	Economy	23100.00
0005434480583	16593	Economy	23100.00
0005434480521	16593	Economy	23100.00
0005434480594	16593	Economy	23100.00
0005433166159	16593	Economy	23100.00
0005434480633	16593	Economy	23100.00
0005434480660	16593	Economy	23100.00
0005433166156	16593	Economy	23100.00
0005434480673	16593	Economy	23100.00
0005434480522	16593	Economy	23100.00
0005433166151	16593	Economy	23100.00
0005433166161	16593	Economy	23100.00
0005434480661	16593	Economy	23100.00
0005434480627	16593	Economy	23100.00
0005434480615	16593	Economy	23100.00
0005433166158	16593	Economy	23100.00
0005434480624	16593	Economy	23100.00
0005434480519	16593	Economy	23100.00
0005434480559	16593	Economy	23100.00
0005434480582	16593	Economy	23100.00
0005434480581	16593	Economy	23100.00
0005433166162	16593	Economy	23100.00
0005433166150	16593	Economy	23100.00
0005433166154	16593	Economy	23100.00
0005434480676	16593	Economy	23100.00
0005435150291	10325	Economy	17000.00
0005435150281	10325	Economy	17000.00
0005435150285	10325	Economy	17000.00
0005435142830	10325	Economy	17000.00
0005435386644	10325	Economy	15400.00
0005433289915	10325	Economy	15400.00
0005435150283	10325	Economy	15400.00
0005433289911	10325	Economy	15400.00
0005435150290	10325	Economy	15400.00
0005433289913	10325	Economy	15400.00
0005433289938	10325	Economy	15400.00
0005435142824	10325	Economy	15400.00
0005433289917	10325	Economy	15400.00
0005433289882	10325	Economy	15400.00
0005435150286	10325	Economy	15400.00
0005433289931	10325	Economy	15400.00
0005435142829	10325	Economy	15400.00
0005435142828	10325	Economy	15400.00
0005433289919	10325	Economy	15400.00
0005435142825	10325	Economy	15400.00
0005433289916	10325	Economy	15400.00
0005435150287	10325	Economy	15400.00
0005435150284	10325	Economy	15400.00
0005435142831	10325	Economy	15400.00
0005433289914	10325	Economy	15400.00
0005435142823	10325	Economy	15400.00
0005435150288	10325	Economy	15400.00
0005435142822	10325	Economy	15400.00
0005435150282	10325	Economy	15400.00
0005435150292	10325	Economy	15400.00
0005435386616	10325	Economy	15400.00
0005435142834	10325	Economy	15400.00
0005433289883	10325	Economy	15400.00
0005433289912	10325	Economy	15400.00
0005435142833	10325	Economy	15400.00
0005435142827	10325	Economy	15400.00
0005435150293	10325	Economy	15400.00
0005433289929	10325	Economy	15400.00
0005435142826	10325	Economy	15400.00
0005435142832	10325	Economy	15400.00
0005433289930	10325	Economy	15400.00
0005433289918	10325	Economy	15400.00
0005435150289	10325	Economy	15400.00
0005435386639	10325	Economy	15400.00
0005435150280	10325	Economy	15400.00
0005435142674	21934	Economy	17000.00
0005433289998	21934	Economy	17000.00
0005435142653	21934	Economy	17000.00
0005435386697	21934	Economy	15400.00
0005433289993	21934	Economy	15400.00
0005435386701	21934	Economy	15400.00
0005435142652	21934	Economy	15400.00
0005433289996	21934	Economy	15400.00
0005435386698	21934	Economy	15400.00
0005435142704	21934	Economy	15400.00
0005435142649	21934	Economy	15400.00
0005433289991	21934	Economy	15400.00
0005435142696	21934	Economy	15400.00
0005435142764	21934	Economy	15400.00
0005433289995	21934	Economy	15400.00
0005435386704	21934	Economy	15400.00
0005435142705	21934	Economy	15400.00
0005435142735	21934	Economy	15400.00
0005435142707	21934	Economy	15400.00
0005435142706	21934	Economy	15400.00
0005435142713	21934	Economy	15400.00
0005435386700	21934	Economy	15400.00
0005433289997	21934	Economy	15400.00
0005435150122	21934	Economy	15400.00
0005435150164	21934	Economy	15400.00
0005435386702	21934	Economy	15400.00
0005435386696	21934	Economy	15400.00
0005433289994	21934	Economy	15400.00
0005435142690	21934	Economy	15400.00
0005435386703	21934	Economy	15400.00
0005435150183	21934	Economy	15400.00
0005435142759	21934	Economy	15400.00
0005435150163	21934	Economy	15400.00
0005435142702	21934	Economy	15400.00
0005433289992	21934	Economy	15400.00
0005435150190	21934	Economy	15400.00
0005435142712	21934	Economy	15400.00
0005435150123	21934	Economy	15400.00
0005435386699	21934	Economy	15400.00
0005434573610	11227	Business	57200.00
0005435545819	11227	Business	57200.00
0005434573611	11227	Business	57200.00
0005435529548	11227	Business	57200.00
0005435502570	11227	Business	57200.00
0005435502633	11227	Business	57200.00
0005435502514	11227	Business	57200.00
0005434573608	11227	Business	57200.00
0005434573617	11227	Economy	19100.00
0005435529455	11227	Economy	19100.00
0005435545845	11227	Economy	19100.00
0005435502569	11227	Economy	19100.00
0005435545830	11227	Economy	19100.00
0005435319684	11227	Economy	19100.00
0005435529430	11227	Economy	19100.00
0005435502597	11227	Economy	19100.00
0005435319685	11227	Economy	21000.00
0005435529482	11227	Economy	21000.00
0005435319683	11227	Economy	21000.00
0005435319671	11227	Economy	21000.00
0005435319628	11227	Economy	19100.00
0005435529499	11227	Economy	19100.00
0005435529431	11227	Economy	19100.00
0005435545818	11227	Economy	19100.00
0005434573621	11227	Economy	19100.00
0005435529498	11227	Economy	19100.00
0005435502604	11227	Economy	19100.00
0005435529395	11227	Economy	19100.00
0005435502563	11227	Economy	19100.00
0005434573615	11227	Economy	19100.00
0005435502586	11227	Economy	19100.00
0005435545794	11227	Economy	19100.00
0005435529387	11227	Economy	19100.00
0005435529391	11227	Economy	19100.00
0005434573613	11227	Economy	19100.00
0005435529454	11227	Economy	19100.00
0005435502632	11227	Economy	19100.00
0005435319690	11227	Economy	19100.00
0005435545816	11227	Economy	19100.00
0005435502605	11227	Economy	19100.00
0005435545793	11227	Economy	19100.00
0005435529519	11227	Economy	19100.00
0005435545837	11227	Economy	19100.00
0005434573620	11227	Economy	19100.00
0005434573616	11227	Economy	19100.00
0005435545842	11227	Economy	19100.00
0005435545806	11227	Economy	19100.00
0005435502515	11227	Economy	19100.00
0005435529474	11227	Economy	19100.00
0005435319664	11227	Economy	19100.00
0005434573612	11227	Economy	19100.00
0005435529448	11227	Economy	19100.00
0005435319672	11227	Economy	19100.00
0005435319627	11227	Economy	19100.00
0005434573614	11227	Economy	19100.00
0005435502561	11227	Economy	19100.00
0005435319689	11227	Economy	19100.00
0005435529475	11227	Economy	19100.00
0005435502608	11227	Economy	19100.00
0005435529507	11227	Economy	19100.00
0005435545829	11227	Economy	19100.00
0005435545815	11227	Economy	19100.00
0005435502594	11227	Economy	19100.00
0005435502400	11227	Economy	19100.00
0005435502562	11227	Economy	19100.00
0005435529549	11227	Economy	19100.00
0005434573609	11227	Economy	19100.00
0005435545831	11227	Economy	19100.00
0005434573618	11227	Economy	19100.00
0005435545843	11227	Economy	19100.00
0005435545838	11227	Economy	19100.00
0005435529461	11227	Economy	19100.00
0005434573619	11227	Economy	19100.00
0005435502596	11227	Economy	19100.00
0005435529476	11227	Economy	19100.00
0005434573507	20958	Business	57200.00
0005435518257	20958	Business	57200.00
0005435518258	20958	Business	57200.00
0005435502709	20958	Business	57200.00
0005435319758	20958	Business	57200.00
0005435319757	20958	Business	57200.00
0005435502716	20958	Business	57200.00
0005432291975	20958	Business	57200.00
0005435319751	20958	Business	57200.00
0005435502718	20958	Business	57200.00
0005435319750	20958	Economy	19100.00
0005435502712	20958	Economy	19100.00
0005435502708	20958	Economy	19100.00
0005434573516	20958	Economy	19100.00
0005435502713	20958	Economy	19100.00
0005434573527	20958	Economy	19100.00
0005435502723	20958	Economy	19100.00
0005435319752	20958	Economy	21000.00
0005435502727	20958	Economy	21000.00
0005435518254	20958	Economy	21000.00
0005435319756	20958	Economy	21000.00
0005435518261	20958	Economy	21000.00
0005435518249	20958	Economy	19100.00
0005434573489	20958	Economy	19100.00
0005435508595	20958	Economy	19100.00
0005434573526	20958	Economy	19100.00
0005434573520	20958	Economy	19100.00
0005435518248	20958	Economy	19100.00
0005435508584	20958	Economy	19100.00
0005435508594	20958	Economy	19100.00
0005435502722	20958	Economy	19100.00
0005435502714	20958	Economy	19100.00
0005435502715	20958	Economy	19100.00
0005435518259	20958	Economy	19100.00
0005435508597	20958	Economy	19100.00
0005435502710	20958	Economy	19100.00
0005435518246	20958	Economy	19100.00
0005434573498	20958	Economy	19100.00
0005435508589	20958	Economy	19100.00
0005435502719	20958	Economy	19100.00
0005435502707	20958	Economy	19100.00
0005435518256	20958	Economy	19100.00
0005434573462	20958	Economy	19100.00
0005435502720	20958	Economy	19100.00
0005435502726	20958	Economy	19100.00
0005435508592	20958	Economy	19100.00
0005435508591	20958	Economy	19100.00
0005435508585	20958	Economy	19100.00
0005434573497	20958	Economy	19100.00
0005435518251	20958	Economy	19100.00
0005434573502	20958	Economy	19100.00
0005432291976	20958	Economy	19100.00
0005435508599	20958	Economy	19100.00
0005435319754	20958	Economy	19100.00
0005435502724	20958	Economy	19100.00
0005435319753	20958	Economy	19100.00
0005435502711	20958	Economy	19100.00
0005435508586	20958	Economy	19100.00
0005435319755	20958	Economy	19100.00
0005432291977	20958	Economy	19100.00
0005435518250	20958	Economy	19100.00
0005435508596	20958	Economy	19100.00
0005435518252	20958	Economy	19100.00
0005435502728	20958	Economy	19100.00
0005435502717	20958	Economy	19100.00
0005435502725	20958	Economy	19100.00
0005435502721	20958	Economy	19100.00
0005435508587	20958	Economy	19100.00
0005435518247	20958	Economy	19100.00
0005435508593	20958	Economy	19100.00
0005434573504	20958	Economy	19100.00
0005435518260	20958	Economy	19100.00
0005434573541	20958	Economy	19100.00
0005435508598	20958	Economy	19100.00
0005435518253	20958	Economy	19100.00
0005434573501	20958	Economy	19100.00
0005435508583	20958	Economy	19100.00
0005435508588	20958	Economy	19100.00
0005435518255	20958	Economy	19100.00
0005435508590	20958	Economy	19100.00
0005432693360	2941	Business	10300.00
0005432693422	2941	Business	10300.00
0005432693514	2941	Business	10300.00
0005432693370	2941	Business	10300.00
0005432693458	2941	Business	10300.00
0005432693439	2941	Economy	3400.00
0005432693248	2941	Economy	3400.00
0005432693431	2941	Economy	3400.00
0005432693332	2941	Economy	3800.00
0005432693268	2941	Economy	3800.00
0005432693376	2941	Economy	3400.00
0005432693437	2941	Economy	3400.00
0005432693364	2941	Economy	3400.00
0005432693298	2941	Economy	3400.00
0005432693486	2941	Economy	3400.00
0005432693297	2941	Economy	3400.00
0005432693313	2941	Economy	3400.00
0005432693273	2941	Economy	3400.00
0005432693466	2941	Economy	3400.00
0005432693355	2941	Economy	3400.00
0005432693438	2941	Economy	3400.00
0005432693326	2941	Economy	3400.00
0005432693403	2941	Economy	3400.00
0005432693361	2941	Economy	3400.00
0005432693405	2941	Economy	3400.00
0005432693418	2941	Economy	3400.00
0005432693404	2941	Economy	3400.00
0005432693430	2941	Economy	3400.00
0005432693331	2941	Economy	3400.00
0005432693359	2941	Economy	3400.00
0005432693267	2941	Economy	3400.00
0005432693249	2941	Economy	3400.00
0005432693419	2941	Economy	3400.00
0005433124126	2940	Business	10300.00
0005433124102	2940	Business	10300.00
0005432880985	2940	Business	10300.00
0005432880939	2940	Business	10300.00
0005432707253	2940	Business	10300.00
0005432880930	2940	Business	10300.00
0005432707263	2940	Business	10300.00
0005432707273	2940	Business	10300.00
0005432707264	2940	Economy	3400.00
0005433124138	2940	Economy	3400.00
0005433124153	2940	Economy	3400.00
0005432707277	2940	Economy	3400.00
0005432880966	2940	Economy	3400.00
0005433124132	2940	Economy	3400.00
0005432880975	2940	Economy	3400.00
0005432707262	2940	Economy	3400.00
0005432707252	2940	Economy	3800.00
0005432707257	2940	Economy	3800.00
0005432217831	2940	Economy	3800.00
0005432707270	2940	Economy	3400.00
0005432880941	2940	Economy	3400.00
0005433124146	2940	Economy	3400.00
0005433124191	2940	Economy	3400.00
0005433124194	2940	Economy	3400.00
0005433124134	2940	Economy	3400.00
0005432880971	2940	Economy	3400.00
0005433124195	2940	Economy	3400.00
0005433124192	2940	Economy	3400.00
0005433124152	2940	Economy	3400.00
0005433124151	2940	Economy	3400.00
0005433124133	2940	Economy	3400.00
0005432707260	2940	Economy	3400.00
0005432707256	2940	Economy	3400.00
0005433194881	2940	Economy	3400.00
0005432707259	2940	Economy	3400.00
0005432880970	2940	Economy	3400.00
0005433124125	2940	Economy	3400.00
0005432707272	2940	Economy	3400.00
0005433124213	2940	Economy	3400.00
0005432707255	2940	Economy	3400.00
0005432880984	2940	Economy	3400.00
0005432707268	2940	Economy	3400.00
0005432880935	2940	Economy	3400.00
0005432707265	2940	Economy	3400.00
0005433124127	2940	Economy	3400.00
0005433194891	2940	Economy	3400.00
0005432880938	2940	Economy	3400.00
0005432707258	2940	Economy	3400.00
0005432707269	2940	Economy	3400.00
0005432707251	2940	Economy	3400.00
0005432880940	2940	Economy	3400.00
0005432707275	2940	Economy	3400.00
0005432880987	2940	Economy	3400.00
0005433124137	2940	Economy	3400.00
0005432707271	2940	Economy	3400.00
0005432707276	2940	Economy	3400.00
0005432707266	2940	Economy	3400.00
0005433124141	2940	Economy	3400.00
0005432707254	2940	Economy	3400.00
0005433124145	2940	Economy	3400.00
0005432881021	2940	Economy	3400.00
0005432880934	2940	Economy	3400.00
0005433124139	2940	Economy	3400.00
0005432707261	2940	Economy	3400.00
0005432707267	2940	Economy	3400.00
0005432881034	2940	Economy	3400.00
0005432880969	2940	Economy	3400.00
0005433124140	2940	Economy	3400.00
0005432707274	2940	Economy	3400.00
0005432881027	2940	Economy	3400.00
0005433194867	2940	Economy	3400.00
0005432707086	30032	Business	10300.00
0005433124315	30032	Business	10300.00
0005433124325	30032	Business	10300.00
0005432881105	30032	Business	10300.00
0005432693669	30032	Business	10300.00
0005432693665	30032	Business	10300.00
0005432707035	30032	Business	10300.00
0005432707130	30032	Business	10300.00
0005432881104	30032	Business	10300.00
0005432881101	30032	Business	10300.00
0005433124327	30032	Business	10300.00
0005432707120	30032	Business	10300.00
0005432693681	30032	Economy	3400.00
0005433124317	30032	Economy	3400.00
0005432693664	30032	Economy	3400.00
0005433124329	30032	Economy	3400.00
0005432706981	30032	Economy	3400.00
0005433124311	30032	Economy	3400.00
0005433124308	30032	Economy	3400.00
0005432881095	30032	Economy	3400.00
0005432707081	30032	Economy	3400.00
0005432693663	30032	Economy	3400.00
0005432881096	30032	Economy	3800.00
0005433124326	30032	Economy	3800.00
0005432881093	30032	Economy	3800.00
0005433194910	30032	Economy	3800.00
0005433194908	30032	Economy	3800.00
0005433124314	30032	Economy	3400.00
0005432693691	30032	Economy	3400.00
0005433124310	30032	Economy	3400.00
0005433124320	30032	Economy	3400.00
0005432881102	30032	Economy	3400.00
0005433124318	30032	Economy	3400.00
0005432693694	30032	Economy	3400.00
0005433124323	30032	Economy	3400.00
0005432693680	30032	Economy	3400.00
0005432693684	30032	Economy	3400.00
0005432693693	30032	Economy	3400.00
0005432693678	30032	Economy	3400.00
0005432881098	30032	Economy	3400.00
0005432693672	30032	Economy	3400.00
0005432693687	30032	Economy	3400.00
0005432693668	30032	Economy	3400.00
0005432706980	30032	Economy	3400.00
0005432881100	30032	Economy	3400.00
0005433124322	30032	Economy	3400.00
0005432707106	30032	Economy	3400.00
0005433124319	30032	Economy	3400.00
0005432693682	30032	Economy	3400.00
0005432881099	30032	Economy	3400.00
0005433124313	30032	Economy	3400.00
0005432707111	30032	Economy	3400.00
0005433124330	30032	Economy	3400.00
0005432707079	30032	Economy	3400.00
0005432707025	30032	Economy	3400.00
0005433194912	30032	Economy	3400.00
0005432881097	30032	Economy	3400.00
0005433194906	30032	Economy	3400.00
0005432693692	30032	Economy	3400.00
0005432707129	30032	Economy	3400.00
0005432693671	30032	Economy	3400.00
0005432693670	30032	Economy	3400.00
0005433124324	30032	Economy	3400.00
0005433194911	30032	Economy	3400.00
0005432693688	30032	Economy	3400.00
0005433194913	30032	Economy	3400.00
0005432693683	30032	Economy	3400.00
0005432881103	30032	Economy	3400.00
0005433124321	30032	Economy	3400.00
0005432707107	30032	Economy	3400.00
0005432707024	30032	Economy	3400.00
0005432693673	30032	Economy	3400.00
0005433124328	30032	Economy	3400.00
0005432707058	30032	Economy	3400.00
0005432706968	30032	Economy	3400.00
0005432693667	30032	Economy	3400.00
0005433124316	30032	Economy	3400.00
0005432707121	30032	Economy	3400.00
0005432693686	30032	Economy	3400.00
0005433194907	30032	Economy	3400.00
0005433124309	30032	Economy	3400.00
0005432707080	30032	Economy	3400.00
0005432693674	30032	Economy	3400.00
0005433124312	30032	Economy	3400.00
0005432693666	30032	Economy	3400.00
0005433194905	30032	Economy	3400.00
0005432693679	30032	Economy	3400.00
0005432693690	30032	Economy	3400.00
0005432881092	30032	Economy	3400.00
0005432707119	30032	Economy	3400.00
0005432693676	30032	Economy	3400.00
0005433194909	30032	Economy	3400.00
0005432881094	30032	Economy	3400.00
0005432693689	30032	Economy	3400.00
0005432693677	30032	Economy	3400.00
0005432693675	30032	Economy	3400.00
0005432693685	30032	Economy	3400.00
0005434980343	23676	Economy	4000.00
0005434988929	23676	Economy	4000.00
0005434980332	23676	Economy	4000.00
0005434980344	23676	Economy	4000.00
0005434988928	23676	Economy	3600.00
0005434980333	23676	Economy	3600.00
0005434980341	23676	Economy	3600.00
0005434988937	23676	Economy	3600.00
0005434988931	23676	Economy	3600.00
0005434988933	23676	Economy	3600.00
0005434980339	23676	Economy	3600.00
0005434980353	23676	Economy	3600.00
0005434980330	23676	Economy	3600.00
0005434988932	23676	Economy	3600.00
0005434980351	23676	Economy	3600.00
0005434980329	23676	Economy	3600.00
0005434980346	23676	Economy	3600.00
0005434980338	23676	Economy	3600.00
0005434988926	23676	Economy	3600.00
0005434980350	23676	Economy	3600.00
0005434988930	23676	Economy	3600.00
0005434980358	23676	Economy	3600.00
0005434980334	23676	Economy	3600.00
0005434988934	23676	Economy	3600.00
0005434980336	23676	Economy	3600.00
0005434988925	23676	Economy	3600.00
0005434980352	23676	Economy	3600.00
0005434980347	23676	Economy	3600.00
0005434980345	23676	Economy	3600.00
0005434980355	23676	Economy	3600.00
0005434980331	23676	Economy	3600.00
0005434980357	23676	Economy	3600.00
0005434988927	23676	Economy	3600.00
0005434988936	23676	Economy	3600.00
0005434980342	23676	Economy	3600.00
0005434980335	23676	Economy	3600.00
0005434980356	23676	Economy	3600.00
0005434980354	23676	Economy	3600.00
0005434980359	23676	Economy	3600.00
0005434980340	23676	Economy	3600.00
0005434980348	23676	Economy	3600.00
0005434980337	23676	Economy	3600.00
0005434988935	23676	Economy	3600.00
0005434980349	23676	Economy	3600.00
0005434980007	27575	Economy	4000.00
0005434988834	27575	Economy	4000.00
0005434980077	27575	Economy	4000.00
0005434980098	27575	Economy	4000.00
0005434980070	27575	Economy	3600.00
0005434980232	27575	Economy	3600.00
0005434980073	27575	Economy	3600.00
0005434979974	27575	Economy	3600.00
0005434980229	27575	Economy	3600.00
0005434980150	27575	Economy	3600.00
0005434979955	27575	Economy	3600.00
0005434980053	27575	Economy	3600.00
0005434988804	27575	Economy	3600.00
0005434980128	27575	Economy	3600.00
0005434980033	27575	Economy	3600.00
0005434988840	27575	Economy	3600.00
0005434980063	27575	Economy	3600.00
0005434980227	27575	Economy	3600.00
0005434980123	27575	Economy	3600.00
0005434980010	27575	Economy	3600.00
0005434988841	27575	Economy	3600.00
0005434988819	27575	Economy	3600.00
0005434980072	27575	Economy	3600.00
0005434980035	27575	Economy	3600.00
0005434988818	27575	Economy	3600.00
0005434988843	27575	Economy	3600.00
0005434988831	27575	Economy	3600.00
0005434980124	27575	Economy	3600.00
0005434980228	27575	Economy	3600.00
0005434980101	27575	Economy	3600.00
0005434980052	27575	Economy	3600.00
0005434980192	27575	Economy	3600.00
0005434979972	27575	Economy	3600.00
0005434980034	27575	Economy	3600.00
0005434980172	27575	Economy	3600.00
0005434980102	27575	Economy	3600.00
0005434980097	27575	Economy	3600.00
0005434988838	27575	Economy	3600.00
0005434980100	27575	Economy	3600.00
0005434980189	27575	Economy	3600.00
0005434980068	27575	Economy	3600.00
0005434980036	27575	Economy	3600.00
0005434980113	27575	Economy	3600.00
0005434980120	27575	Economy	3600.00
0005434988833	27575	Economy	3600.00
0005434979973	27575	Economy	3600.00
0005434302541	10277	Economy	21600.00
0005434302539	10277	Economy	19700.00
0005433111532	10277	Economy	19700.00
0005434302540	10277	Economy	19700.00
0005434302537	10277	Economy	19700.00
0005434302538	10277	Economy	19700.00
0005433111525	10277	Economy	19700.00
0005433111518	10277	Economy	19700.00
0005433113557	10277	Economy	19700.00
0005433111519	10277	Economy	19700.00
0005434302508	19622	Economy	19700.00
0005433113578	19622	Economy	19700.00
0005434302509	19622	Economy	19700.00
0005433113579	19622	Economy	19700.00
0005435925400	3556	Business	26900.00
0005435070112	3556	Business	26900.00
0005435070089	3556	Business	26900.00
0005435070092	3556	Business	26900.00
0005435070117	3556	Business	26900.00
0005435070099	3556	Business	26900.00
0005435070086	3556	Business	26900.00
0005435070067	3556	Business	26900.00
0005435070082	3556	Business	26900.00
0005435070104	3556	Economy	9000.00
0005435070106	3556	Economy	9000.00
0005435070074	3556	Economy	9000.00
0005435070083	3556	Economy	9000.00
0005435070100	3556	Economy	9000.00
0005435719046	3556	Economy	9000.00
0005435070068	3556	Economy	9000.00
0005435070091	3556	Economy	9000.00
0005435070103	3556	Economy	9900.00
0005435070066	3556	Economy	9900.00
0005435070079	3556	Economy	9900.00
0005435719047	3556	Economy	9900.00
0005435070075	3556	Economy	9000.00
0005435070090	3556	Economy	9000.00
0005435070111	3556	Economy	9000.00
0005435070115	3556	Economy	9000.00
0005435070105	3556	Economy	9000.00
0005435719048	3556	Economy	9000.00
0005435925362	3556	Economy	9000.00
0005435070093	3556	Economy	9000.00
0005435925450	3556	Economy	9000.00
0005435070101	3556	Economy	9000.00
0005435719049	3556	Economy	9000.00
0005435070076	3556	Economy	9000.00
0005435719043	3556	Economy	9000.00
0005435070102	3556	Economy	9000.00
0005435719045	3556	Economy	9000.00
0005435925425	3556	Economy	9000.00
0005435925413	3556	Economy	9000.00
0005435070071	3556	Economy	9000.00
0005435070080	3556	Economy	9000.00
0005435070072	3556	Economy	9000.00
0005435925424	3556	Economy	9000.00
0005435070113	3556	Economy	9000.00
0005435070078	3556	Economy	9000.00
0005435070088	3556	Economy	9000.00
0005435070073	3556	Economy	9000.00
0005435925430	3556	Economy	9000.00
0005435925399	3556	Economy	9000.00
0005435070098	3556	Economy	9000.00
0005435925456	3556	Economy	9000.00
0005435070084	3556	Economy	9000.00
0005435070087	3556	Economy	9000.00
0005435925436	3556	Economy	9000.00
0005435070077	3556	Economy	9000.00
0005435070107	3556	Economy	9000.00
0005435070085	3556	Economy	9000.00
0005435070096	3556	Economy	9000.00
0005435719044	3556	Economy	9000.00
0005435070109	3556	Economy	9000.00
0005435070097	3556	Economy	9000.00
0005435070108	3556	Economy	9000.00
0005435925443	3556	Economy	9000.00
0005435925449	3556	Economy	9000.00
0005435070070	3556	Economy	9000.00
0005435070081	3556	Economy	9000.00
0005435070094	3556	Economy	9000.00
0005435925380	3556	Economy	9000.00
0005435070118	3556	Economy	9000.00
0005435070110	3556	Economy	9000.00
0005435925442	3556	Economy	9000.00
0005435925459	3556	Economy	9000.00
0005435925305	3556	Economy	9000.00
0005435719042	3556	Economy	9000.00
0005435070114	3556	Economy	9000.00
0005435070116	3556	Economy	9000.00
0005435070069	3556	Economy	9000.00
0005435070095	3556	Economy	9000.00
0005435069554	15308	Business	26900.00
0005435939924	15308	Business	26900.00
0005435069538	15308	Business	26900.00
0005435069540	15308	Business	26900.00
0005435939919	15308	Business	26900.00
0005435069643	15308	Business	26900.00
0005435069674	15308	Business	26900.00
0005435069588	15308	Business	26900.00
0005435925562	15308	Business	26900.00
0005435069519	15308	Business	26900.00
0005435925561	15308	Business	26900.00
0005435069414	15308	Economy	9000.00
0005435069662	15308	Economy	9000.00
0005435069442	15308	Economy	9000.00
0005435069780	15308	Economy	9000.00
0005435069805	15308	Economy	9000.00
0005435069874	15308	Economy	9000.00
0005435069639	15308	Economy	9000.00
0005435069721	15308	Economy	9000.00
0005435069489	15308	Economy	9900.00
0005435925563	15308	Economy	9900.00
0005435939922	15308	Economy	9900.00
0005435069518	15308	Economy	9000.00
0005435069697	15308	Economy	9000.00
0005435069590	15308	Economy	9000.00
0005435069722	15308	Economy	9000.00
0005435069615	15308	Economy	9000.00
0005435069302	15308	Economy	9000.00
0005435069485	15308	Economy	9000.00
0005435069541	15308	Economy	9000.00
0005435069624	15308	Economy	9000.00
0005435069449	15308	Economy	9000.00
0005435069492	15308	Economy	9000.00
0005435069535	15308	Economy	9000.00
0005435069645	15308	Economy	9000.00
0005435069621	15308	Economy	9000.00
0005435069739	15308	Economy	9000.00
0005435069486	15308	Economy	9000.00
0005435069480	15308	Economy	9000.00
0005435069644	15308	Economy	9000.00
0005435069623	15308	Economy	9000.00
0005435069609	15308	Economy	9000.00
0005435069675	15308	Economy	9000.00
0005435069415	15308	Economy	9000.00
0005435069487	15308	Economy	9000.00
0005435069430	15308	Economy	9000.00
0005435925565	15308	Economy	9000.00
0005435069638	15308	Economy	9000.00
0005435069632	15308	Economy	9000.00
0005435069553	15308	Economy	9000.00
0005435069620	15308	Economy	9000.00
0005435069738	15308	Economy	9000.00
0005435925564	15308	Economy	9000.00
0005435069508	15308	Economy	9000.00
0005435069779	15308	Economy	9000.00
0005435069597	15308	Economy	9000.00
0005435069661	15308	Economy	9000.00
0005435939920	15308	Economy	9000.00
0005435069676	15308	Economy	9000.00
0005435069640	15308	Economy	9000.00
0005435939921	15308	Economy	9000.00
0005435069650	15308	Economy	9000.00
0005435069493	15308	Economy	9000.00
0005435069384	15308	Economy	9000.00
0005435069596	15308	Economy	9000.00
0005435069576	15308	Economy	9000.00
0005435925566	15308	Economy	9000.00
0005435069385	15308	Economy	9000.00
0005435069581	15308	Economy	9000.00
0005435069608	15308	Economy	9000.00
0005435069479	15308	Economy	9000.00
0005435939923	15308	Economy	9000.00
0005432658631	18201	Economy	5900.00
0005432660858	18201	Economy	5900.00
0005432659747	18201	Economy	5900.00
0005432659746	18201	Economy	5900.00
0005432658632	18201	Economy	5900.00
0005432660857	18201	Economy	5900.00
0005433102689	118	Business	20000.00
0005433102779	118	Business	20000.00
0005433102574	118	Business	20000.00
0005432920179	118	Business	20000.00
0005433102688	118	Business	20000.00
0005433102671	118	Business	20000.00
0005433102551	118	Business	20000.00
0005433102595	118	Business	20000.00
0005433102556	118	Business	20000.00
0005432920096	118	Business	20000.00
0005432901857	118	Business	20000.00
0005432920157	118	Economy	7300.00
0005433102773	118	Economy	7300.00
0005433102711	118	Economy	6700.00
0005432901807	118	Economy	6700.00
0005432920100	118	Economy	6700.00
0005432920097	118	Economy	6700.00
0005433102524	118	Economy	6700.00
0005433102710	118	Economy	6700.00
0005432920152	118	Economy	6700.00
0005433102628	118	Economy	6700.00
0005433102699	118	Economy	6700.00
0005432677607	118	Economy	6700.00
0005432901919	118	Economy	6700.00
0005433102686	118	Economy	6700.00
0005432677605	118	Economy	6700.00
0005433102550	118	Economy	6700.00
0005433102672	118	Economy	6700.00
0005432919967	118	Economy	6700.00
0005433102657	118	Economy	6700.00
0005432901825	118	Economy	6700.00
0005432901795	118	Economy	6700.00
0005433102575	118	Economy	6700.00
0005433102778	118	Economy	6700.00
0005432901873	118	Economy	6700.00
0005433102735	118	Economy	6700.00
0005432901817	118	Economy	6700.00
0005432901841	118	Economy	6700.00
0005433102670	118	Economy	6700.00
0005432920045	118	Economy	6700.00
0005433102690	118	Economy	6700.00
0005433102758	118	Economy	6700.00
0005432920099	118	Economy	6700.00
0005433102599	118	Economy	6700.00
0005432920058	118	Economy	6700.00
0005433102742	118	Economy	6700.00
0005433102726	118	Economy	6700.00
0005433102485	118	Economy	6700.00
0005432920048	118	Economy	6700.00
0005433102543	118	Economy	6700.00
0005433102772	118	Economy	6700.00
0005432919968	118	Economy	6700.00
0005433102749	118	Economy	6700.00
0005432901858	118	Economy	7300.00
0005433102714	118	Economy	7300.00
0005432677606	118	Economy	7300.00
0005432677591	118	Economy	6700.00
0005432901773	118	Economy	6700.00
0005433102510	118	Economy	6700.00
0005433102775	118	Economy	6700.00
0005433102760	118	Economy	6700.00
0005432920057	118	Economy	6700.00
0005433102705	118	Economy	6700.00
0005433102741	118	Economy	6700.00
0005433102523	118	Economy	6700.00
0005433102748	118	Economy	6700.00
0005432920105	118	Economy	6700.00
0005432901816	118	Economy	6700.00
0005432920098	118	Economy	6700.00
0005432920107	118	Economy	6700.00
0005432920104	118	Economy	6700.00
0005432901918	118	Economy	6700.00
0005432901774	118	Economy	6700.00
0005433102716	118	Economy	6700.00
0005433102544	118	Economy	6700.00
0005433102725	118	Economy	6700.00
0005432677609	118	Economy	6700.00
0005433102759	118	Economy	6700.00
0005433102497	118	Economy	6700.00
0005433102698	118	Economy	6700.00
0005433102616	118	Economy	6700.00
0005432901808	118	Economy	6700.00
0005433102694	118	Economy	6700.00
0005432157530	118	Economy	6700.00
0005433102519	118	Economy	6700.00
0005432901784	118	Economy	6700.00
0005433102695	118	Economy	6700.00
0005433102425	118	Economy	6700.00
0005433102673	118	Economy	6700.00
0005433102424	118	Economy	6700.00
0005433102484	118	Economy	6700.00
0005433102665	118	Economy	6700.00
0005432901775	118	Economy	6700.00
0005433102598	118	Economy	6700.00
0005432818061	122	Business	20000.00
0005432262789	122	Business	20000.00
0005432818047	122	Business	20000.00
0005432753345	122	Business	20000.00
0005432262797	122	Business	20000.00
0005433687730	122	Business	20000.00
0005432818032	122	Business	20000.00
0005432818033	122	Business	20000.00
0005433476982	122	Business	20000.00
0005432262802	122	Business	20000.00
0005432818039	122	Business	20000.00
0005432262788	122	Business	20000.00
0005432818042	122	Business	20000.00
0005432818060	122	Business	20000.00
0005432207710	122	Business	20000.00
0005432818059	122	Business	20000.00
0005433476989	122	Business	20000.00
0005432262778	122	Business	20000.00
0005432262806	122	Economy	7300.00
0005432289050	122	Economy	7300.00
0005432262814	122	Economy	7300.00
0005432818053	122	Economy	6700.00
0005432262776	122	Economy	6700.00
0005432262796	122	Economy	6700.00
0005434153557	122	Economy	6700.00
0005432262803	122	Economy	6700.00
0005432262785	122	Economy	6700.00
0005432262792	122	Economy	6700.00
0005433476985	122	Economy	6700.00
0005433687733	122	Economy	6700.00
0005432818051	122	Economy	6700.00
0005432262813	122	Economy	6700.00
0005432262816	122	Economy	6700.00
0005432262800	122	Economy	6700.00
0005432756880	122	Economy	6700.00
0005432262793	122	Economy	6700.00
0005432262795	122	Economy	6700.00
0005432756881	122	Economy	6700.00
0005432262811	122	Economy	6700.00
0005432262787	122	Economy	6700.00
0005433476987	122	Economy	6700.00
0005434153556	122	Economy	6700.00
0005432262810	122	Economy	6700.00
0005432289049	122	Economy	6700.00
0005432753339	122	Economy	6700.00
0005432262804	122	Economy	6700.00
0005432207711	122	Economy	6700.00
0005432262808	122	Economy	6700.00
0005432818034	122	Economy	6700.00
0005432818056	122	Economy	6700.00
0005432262780	122	Economy	6700.00
0005432262772	122	Economy	6700.00
0005432818049	122	Economy	6700.00
0005432262773	122	Economy	6700.00
0005432262786	122	Economy	6700.00
0005433476984	122	Economy	7300.00
0005433476988	122	Economy	6700.00
0005432818044	122	Economy	6700.00
0005432289051	122	Economy	6700.00
0005432262798	122	Economy	6700.00
0005432262815	122	Economy	6700.00
0005432262807	122	Economy	7300.00
0005433476986	122	Economy	6700.00
0005432262774	122	Economy	6700.00
0005432262812	122	Economy	6700.00
0005432207709	122	Economy	6700.00
0005432262799	122	Economy	6700.00
0005432262770	122	Economy	6700.00
0005432262784	122	Economy	6700.00
0005432756882	122	Economy	6700.00
0005432262783	122	Economy	6700.00
0005432818046	122	Economy	6700.00
0005432262779	122	Economy	6700.00
0005432818057	122	Economy	6700.00
0005432818037	122	Economy	6700.00
0005432818058	122	Economy	6700.00
0005433476983	122	Economy	6700.00
0005432262777	122	Economy	6700.00
0005432753344	122	Economy	6700.00
0005432818040	122	Economy	6700.00
0005432818052	122	Economy	6700.00
0005432818055	122	Economy	6700.00
0005432262805	122	Economy	6700.00
0005432818054	122	Economy	6700.00
0005433687732	122	Economy	6700.00
0005432818035	122	Economy	6700.00
0005432818048	122	Economy	6700.00
0005432818043	122	Economy	6700.00
0005432818045	122	Economy	6700.00
0005433690950	122	Economy	6700.00
0005434153555	122	Economy	6700.00
0005432262775	122	Economy	6700.00
0005432262817	122	Economy	6700.00
0005432262791	122	Economy	6700.00
0005432262801	122	Economy	6700.00
0005432262794	122	Economy	6700.00
0005432262781	122	Economy	6700.00
0005432262809	122	Economy	6700.00
0005432818038	122	Economy	6700.00
0005432262782	122	Economy	6700.00
0005432262771	122	Economy	6700.00
0005432818050	122	Economy	6700.00
0005432262790	122	Economy	6700.00
0005432818041	122	Economy	6700.00
0005432818036	122	Economy	6700.00
0005432920255	8057	Business	20000.00
0005433103206	8057	Business	20000.00
0005432020770	8057	Business	20000.00
0005432753368	8057	Business	20000.00
0005432020779	8057	Business	20000.00
0005432020785	8057	Business	20000.00
0005432020773	8057	Business	20000.00
0005433103172	8057	Business	20000.00
0005432020778	8057	Business	20000.00
0005432044579	8057	Business	20000.00
0005432920257	8057	Business	20000.00
0005433103191	8057	Business	20000.00
0005432920268	8057	Business	20000.00
0005433103213	8057	Business	20000.00
0005433103204	8057	Business	20000.00
0005432751593	8057	Business	20000.00
0005433103173	8057	Business	20000.00
0005432020786	8057	Business	20000.00
0005432044577	8057	Business	20000.00
0005433103189	8057	Business	20000.00
0005433103158	8057	Business	20000.00
0005433103183	8057	Economy	7300.00
0005433103169	8057	Economy	7300.00
0005433103159	8057	Economy	7300.00
0005432020769	8057	Economy	7300.00
0005433103178	8057	Economy	7300.00
0005433103211	8057	Economy	6700.00
0005433103187	8057	Economy	6700.00
0005432920261	8057	Economy	6700.00
0005433103197	8057	Economy	6700.00
0005432751592	8057	Economy	6700.00
0005433103154	8057	Economy	6700.00
0005433103164	8057	Economy	6700.00
0005432392057	8057	Economy	6700.00
0005433103207	8057	Economy	6700.00
0005432920252	8057	Economy	6700.00
0005433103199	8057	Economy	6700.00
0005432920263	8057	Economy	6700.00
0005433103162	8057	Economy	6700.00
0005433103167	8057	Economy	6700.00
0005433103170	8057	Economy	6700.00
0005433103166	8057	Economy	6700.00
0005432677652	8057	Economy	6700.00
0005432392059	8057	Economy	6700.00
0005432020772	8057	Economy	6700.00
0005433103196	8057	Economy	6700.00
0005433103171	8057	Economy	6700.00
0005433103214	8057	Economy	6700.00
0005432020790	8057	Economy	6700.00
0005433103155	8057	Economy	6700.00
0005433103203	8057	Economy	6700.00
0005432920253	8057	Economy	6700.00
0005432920267	8057	Economy	6700.00
0005432677651	8057	Economy	6700.00
0005433103188	8057	Economy	6700.00
0005432020793	8057	Economy	6700.00
0005432920264	8057	Economy	6700.00
0005432020783	8057	Economy	6700.00
0005433103201	8057	Economy	6700.00
0005432020789	8057	Economy	6700.00
0005433103175	8057	Economy	6700.00
0005432920262	8057	Economy	6700.00
0005432044580	8057	Economy	6700.00
0005432020776	8057	Economy	6700.00
0005433103212	8057	Economy	6700.00
0005432751591	8057	Economy	6700.00
0005433103184	8057	Economy	6700.00
0005432020792	8057	Economy	6700.00
0005432920266	8057	Economy	6700.00
0005433103186	8057	Economy	7300.00
0005432392058	8057	Economy	6700.00
0005433103177	8057	Economy	7300.00
0005433103195	8057	Economy	7300.00
0005432920271	8057	Economy	7300.00
0005432020777	8057	Economy	6700.00
0005433103182	8057	Economy	6700.00
0005432677653	8057	Economy	6700.00
0005433103194	8057	Economy	6700.00
0005433103156	8057	Economy	7300.00
0005432020781	8057	Economy	6700.00
0005433103181	8057	Economy	6700.00
0005432753367	8057	Economy	6700.00
0005432020782	8057	Economy	6700.00
0005432751594	8057	Economy	6700.00
0005433103152	8057	Economy	6700.00
0005432020794	8057	Economy	6700.00
0005433103209	8057	Economy	6700.00
0005432020780	8057	Economy	6700.00
0005432920259	8057	Economy	6700.00
0005432045651	8057	Economy	6700.00
0005433103165	8057	Economy	6700.00
0005432751590	8057	Economy	6700.00
0005432020788	8057	Economy	6700.00
0005432020775	8057	Economy	6700.00
0005433103192	8057	Economy	6700.00
0005432753369	8057	Economy	6700.00
0005433103202	8057	Economy	6700.00
0005433103153	8057	Economy	6700.00
0005432920260	8057	Economy	6700.00
0005432920269	8057	Economy	6700.00
0005432920254	8057	Economy	6700.00
0005433103160	8057	Economy	6700.00
0005433103163	8057	Economy	6700.00
0005433103168	8057	Economy	6700.00
0005432044578	8057	Economy	6700.00
0005433103190	8057	Economy	6700.00
0005432920258	8057	Economy	6700.00
0005433103161	8057	Economy	6700.00
0005433103157	8057	Economy	6700.00
0005432020787	8057	Economy	6700.00
0005432920265	8057	Economy	6700.00
0005432920272	8057	Economy	6700.00
0005432920256	8057	Economy	6700.00
0005433103176	8057	Economy	6700.00
0005432020791	8057	Economy	6700.00
0005432920270	8057	Economy	6700.00
0005433103200	8057	Economy	6700.00
0005432045652	8057	Economy	6700.00
0005433103198	8057	Economy	6700.00
0005432020774	8057	Economy	6700.00
0005433103205	8057	Economy	6700.00
0005433103180	8057	Economy	6700.00
0005432020771	8057	Economy	6700.00
0005433103179	8057	Economy	6700.00
0005432020784	8057	Economy	6700.00
0005433103193	8057	Economy	6700.00
0005433103174	8057	Economy	6700.00
0005433103208	8057	Economy	6700.00
0005433103210	8057	Economy	6700.00
0005433103185	8057	Economy	6700.00
0005432901954	8103	Business	20000.00
0005432817699	8103	Business	20000.00
0005432817866	8103	Business	20000.00
0005432817837	8103	Business	20000.00
0005432817802	8103	Business	20000.00
0005432817836	8103	Business	20000.00
0005432901941	8103	Business	20000.00
0005432817937	8103	Business	20000.00
0005432901952	8103	Business	20000.00
0005432817796	8103	Business	20000.00
0005432817829	8103	Economy	6700.00
0005432817617	8103	Economy	6700.00
0005432901956	8103	Economy	6700.00
0005432901942	8103	Economy	6700.00
0005432901947	8103	Economy	6700.00
0005432817830	8103	Economy	6700.00
0005432817776	8103	Economy	6700.00
0005432817777	8103	Economy	6700.00
0005432901957	8103	Economy	6700.00
0005432817789	8103	Economy	6700.00
0005432901950	8103	Economy	6700.00
0005432817873	8103	Economy	6700.00
0005432817763	8103	Economy	6700.00
0005432817936	8103	Economy	6700.00
0005432817780	8103	Economy	6700.00
0005432817760	8103	Economy	6700.00
0005432901946	8103	Economy	6700.00
0005432817794	8103	Economy	6700.00
0005432817618	8103	Economy	6700.00
0005432817800	8103	Economy	7300.00
0005432901951	8103	Economy	7300.00
0005432817819	8103	Economy	6700.00
0005432817764	8103	Economy	6700.00
0005432901943	8103	Economy	6700.00
0005432901953	8103	Economy	7300.00
0005432002116	8103	Economy	6700.00
0005432901958	8103	Economy	6700.00
0005432817801	8103	Economy	6700.00
0005432817968	8103	Economy	6700.00
0005432817857	8103	Economy	6700.00
0005432817718	8103	Economy	6700.00
0005432901945	8103	Economy	6700.00
0005432817698	8103	Economy	6700.00
0005432901955	8103	Economy	6700.00
0005432901949	8103	Economy	6700.00
0005432002117	8103	Economy	6700.00
0005432817803	8103	Economy	6700.00
0005432901944	8103	Economy	6700.00
0005432817719	8103	Economy	6700.00
0005432817867	8103	Economy	6700.00
0005432817790	8103	Economy	6700.00
0005432817797	8103	Economy	6700.00
0005432817919	8103	Economy	6700.00
0005432901948	8103	Economy	6700.00
0005434175807	9648	Economy	6900.00
0005434175794	9648	Economy	6900.00
0005434175808	9648	Economy	6900.00
0005434175774	9648	Economy	6900.00
0005434175788	9648	Economy	6900.00
0005434175809	9648	Economy	6900.00
0005434175789	9648	Economy	6900.00
0005434175795	9648	Economy	6900.00
0005433870773	9648	Economy	6900.00
0005433870775	9648	Economy	6900.00
0005434175806	9648	Economy	6900.00
0005433870774	9648	Economy	6900.00
0005433870744	32325	Economy	6900.00
0005434175836	32325	Economy	6900.00
0005434175834	32325	Economy	6900.00
0005434175833	32325	Economy	6900.00
0005434175835	32325	Economy	6900.00
0005433870765	32325	Economy	6900.00
0005434175837	32325	Economy	6900.00
0005434880107	3514	Business	35000.00
0005434880096	3514	Business	35000.00
0005432800019	3514	Business	35000.00
0005432611778	3514	Business	35000.00
0005434427192	3514	Business	35000.00
0005435902938	3514	Business	35000.00
0005434880114	3514	Business	35000.00
0005434880088	3514	Business	35000.00
0005434880072	3514	Business	35000.00
0005434880034	3514	Business	35000.00
0005434938518	3514	Business	35000.00
0005434880020	3514	Business	35000.00
0005434880036	3514	Business	35000.00
0005434427172	3514	Business	35000.00
0005435127173	3514	Business	35000.00
0005435127175	3514	Business	35000.00
0005434880110	3514	Business	35000.00
0005432800012	3514	Business	35000.00
0005435913956	3514	Business	35000.00
0005432613940	3514	Business	35000.00
0005432800018	3514	Comfort	19900.00
0005435127151	3514	Comfort	19900.00
0005432800020	3514	Comfort	19900.00
0005434938529	3514	Comfort	19900.00
0005435127184	3514	Comfort	19900.00
0005434880044	3514	Comfort	19900.00
0005434880067	3514	Comfort	19900.00
0005434880057	3514	Comfort	19900.00
0005434880087	3514	Comfort	19900.00
0005434880035	3514	Comfort	19900.00
0005435902905	3514	Comfort	19900.00
0005432800021	3514	Comfort	19900.00
0005434427194	3514	Comfort	19900.00
0005432800023	3514	Comfort	19900.00
0005435127155	3514	Comfort	19900.00
0005434938527	3514	Comfort	19900.00
0005432188673	3514	Comfort	19900.00
0005432800000	3514	Comfort	19900.00
0005435127188	3514	Comfort	19900.00
0005434427180	3514	Comfort	19900.00
0005434880086	3514	Comfort	19900.00
0005435902993	3514	Comfort	19900.00
0005434427175	3514	Comfort	19900.00
0005432799998	3514	Comfort	19900.00
0005435626542	3514	Comfort	19900.00
0005432800013	3514	Comfort	19900.00
0005434938523	3514	Comfort	19900.00
0005435626530	3514	Comfort	19900.00
0005434880103	3514	Comfort	19900.00
0005434938517	3514	Comfort	19900.00
0005434880076	3514	Comfort	19900.00
0005434880080	3514	Economy	11700.00
0005434427185	3514	Economy	11700.00
0005434880063	3514	Economy	11700.00
0005434880025	3514	Economy	11700.00
0005435127165	3514	Economy	11700.00
0005434880037	3514	Economy	11700.00
0005434427171	3514	Economy	11700.00
0005434938520	3514	Economy	11700.00
0005434880021	3514	Economy	11700.00
0005434427191	3514	Economy	11700.00
0005435127182	3514	Economy	11700.00
0005434880091	3514	Economy	11700.00
0005435127148	3514	Economy	11700.00
0005434880069	3514	Economy	11700.00
0005434880071	3514	Economy	11700.00
0005435127154	3514	Economy	11700.00
0005434938526	3514	Economy	11700.00
0005434880047	3514	Economy	11700.00
0005434880041	3514	Economy	11700.00
0005432799996	3514	Economy	11700.00
0005435626541	3514	Economy	11700.00
0005432188671	3514	Economy	11700.00
0005434938516	3514	Economy	11700.00
0005432800014	3514	Economy	11700.00
0005434938515	3514	Economy	11700.00
0005434427193	3514	Economy	11700.00
0005434938532	3514	Economy	11700.00
0005435127187	3514	Economy	11700.00
0005434880062	3514	Economy	11700.00
0005435127171	3514	Economy	11700.00
0005434880059	3514	Economy	11700.00
0005434880073	3514	Economy	11700.00
0005432613944	3514	Economy	11700.00
0005434880083	3514	Economy	11700.00
0005432800005	3514	Economy	11700.00
0005435127167	3514	Economy	11700.00
0005432800009	3514	Economy	11700.00
0005434880089	3514	Economy	11700.00
0005434880023	3514	Economy	11700.00
0005434880098	3514	Economy	11700.00
0005432799994	3514	Economy	11700.00
0005434880050	3514	Economy	11700.00
0005434938519	3514	Economy	11700.00
0005434880111	3514	Economy	11700.00
0005435902891	3514	Economy	11700.00
0005435127178	3514	Economy	11700.00
0005434880026	3514	Economy	11700.00
0005435902875	3514	Economy	12800.00
0005434880027	3514	Economy	12800.00
0005434880077	3514	Economy	11700.00
0005434938530	3514	Economy	12800.00
0005434880105	3514	Economy	11700.00
0005435902877	3514	Economy	11700.00
0005434938513	3514	Economy	11700.00
0005434938531	3514	Economy	11700.00
0005434880081	3514	Economy	11700.00
0005435127174	3514	Economy	11700.00
0005435127152	3514	Economy	11700.00
0005434938522	3514	Economy	11700.00
0005435127176	3514	Economy	11700.00
0005434880113	3514	Economy	11700.00
0005434427177	3514	Economy	11700.00
0005434880093	3514	Economy	11700.00
0005432800008	3514	Economy	11700.00
0005434880046	3514	Economy	11700.00
0005434880106	3514	Economy	11700.00
0005434880058	3514	Economy	11700.00
0005434880061	3514	Economy	11700.00
0005435127158	3514	Economy	11700.00
0005434427170	3514	Economy	11700.00
0005435902878	3514	Economy	11700.00
0005434427186	3514	Economy	11700.00
0005435626532	3514	Economy	11700.00
0005432800007	3514	Economy	11700.00
0005434880095	3514	Economy	11700.00
0005434880038	3514	Economy	11700.00
0005435902936	3514	Economy	11700.00
0005435626540	3514	Economy	11700.00
0005434880045	3514	Economy	11700.00
0005434938524	3514	Economy	11700.00
0005434880053	3514	Economy	11700.00
0005434427181	3514	Economy	11700.00
0005434880028	3514	Economy	11700.00
0005434880033	3514	Economy	11700.00
0005434880055	3514	Economy	11700.00
0005435902904	3514	Economy	11700.00
0005432800017	3514	Economy	11700.00
0005434880042	3514	Economy	11700.00
0005434427187	3514	Economy	11700.00
0005434880070	3514	Economy	11700.00
0005434880104	3514	Economy	11700.00
0005434880100	3514	Economy	11700.00
0005432800006	3514	Economy	11700.00
0005435127189	3514	Economy	11700.00
0005435127150	3514	Economy	11700.00
0005435902883	3514	Economy	11700.00
0005435127168	3514	Economy	11700.00
0005434880108	3514	Economy	11700.00
0005434427174	3514	Economy	11700.00
0005432611780	3514	Economy	11700.00
0005434880040	3514	Economy	11700.00
0005435127161	3514	Economy	11700.00
0005432799999	3514	Economy	11700.00
0005432183509	3514	Economy	11700.00
0005435127186	3514	Economy	11700.00
0005435127169	3514	Economy	11700.00
0005432183510	3514	Economy	11700.00
0005435902901	3514	Economy	11700.00
0005434880019	3514	Economy	11700.00
0005435902992	3514	Economy	11700.00
0005434938521	3514	Economy	11700.00
0005435626533	3514	Economy	11700.00
0005434880051	3514	Economy	11700.00
0005432183511	3514	Economy	11700.00
0005432613943	3514	Economy	11700.00
0005435127162	3514	Economy	11700.00
0005434880084	3514	Economy	11700.00
0005434427190	3514	Economy	11700.00
0005434880032	3514	Economy	11700.00
0005434880048	3514	Economy	11700.00
0005434880029	3514	Economy	11700.00
0005435626531	3514	Economy	11700.00
0005434880043	3514	Economy	11700.00
0005434880039	3514	Economy	11700.00
0005435127164	3514	Economy	11700.00
0005434880022	3514	Economy	11700.00
0005434880085	3514	Economy	11700.00
0005435127160	3514	Economy	11700.00
0005432800011	3514	Economy	12800.00
0005434880115	3514	Economy	11700.00
0005434880064	3514	Economy	12800.00
0005435626536	3514	Economy	12800.00
0005435127185	3514	Economy	12800.00
0005434880065	3514	Economy	11700.00
0005434880090	3514	Economy	11700.00
0005434427173	3514	Economy	11700.00
0005435127170	3514	Economy	11700.00
0005432613941	3514	Economy	11700.00
0005434880099	3514	Economy	11700.00
0005435626535	3514	Economy	11700.00
0005435902876	3514	Economy	11700.00
0005434880078	3514	Economy	11700.00
0005432613942	3514	Economy	11700.00
0005434880052	3514	Economy	11700.00
0005434427184	3514	Economy	11700.00
0005434427178	3514	Economy	11700.00
0005432800003	3514	Economy	11700.00
0005434427189	3514	Economy	11700.00
0005435127157	3514	Economy	11700.00
0005434880074	3514	Economy	11700.00
0005434427195	3514	Economy	11700.00
0005432800004	3514	Economy	11700.00
0005434880102	3514	Economy	11700.00
0005434427197	3514	Economy	11700.00
0005432800002	3514	Economy	11700.00
0005434880101	3514	Economy	11700.00
0005434880079	3514	Economy	11700.00
0005432800016	3514	Economy	11700.00
0005435127156	3514	Economy	11700.00
0005435127172	3514	Economy	11700.00
0005434427196	3514	Economy	11700.00
0005434427182	3514	Economy	11700.00
0005434880092	3514	Economy	11700.00
0005432800015	3514	Economy	11700.00
0005432183508	3514	Economy	11700.00
0005434938528	3514	Economy	11700.00
0005435127183	3514	Economy	11700.00
0005434880066	3514	Economy	11700.00
0005435626538	3514	Economy	11700.00
0005434880024	3514	Economy	11700.00
0005432800001	3514	Economy	11700.00
0005435127180	3514	Economy	11700.00
0005434938514	3514	Economy	11700.00
0005434880056	3514	Economy	11700.00
0005434938525	3514	Economy	11700.00
0005435626537	3514	Economy	11700.00
0005434880112	3514	Economy	11700.00
0005435902937	3514	Economy	11700.00
0005435902882	3514	Economy	11700.00
0005434880109	3514	Economy	11700.00
0005432611779	3514	Economy	11700.00
0005434427199	3514	Economy	11700.00
0005432188672	3514	Economy	11700.00
0005434880068	3514	Economy	11700.00
0005434880082	3514	Economy	11700.00
0005434427179	3514	Economy	11700.00
0005434880031	3514	Economy	11700.00
0005434880060	3514	Economy	11700.00
0005434880054	3514	Economy	11700.00
0005434427176	3514	Economy	11700.00
0005435127159	3514	Economy	11700.00
0005435626534	3514	Economy	11700.00
0005434880094	3514	Economy	11700.00
0005435127181	3514	Economy	11700.00
0005435127163	3514	Economy	11700.00
0005434880097	3514	Economy	11700.00
0005432800010	3514	Economy	11700.00
0005434427188	3514	Economy	11700.00
0005434880030	3514	Economy	11700.00
0005435626539	3514	Economy	11700.00
0005432800022	3514	Economy	11700.00
0005435902900	3514	Economy	11700.00
0005435127149	3514	Economy	11700.00
0005435127179	3514	Economy	11700.00
0005432799995	3514	Economy	11700.00
0005434880049	3514	Economy	11700.00
0005432799997	3514	Economy	11700.00
0005435127166	3514	Economy	11700.00
0005434427198	3514	Economy	11700.00
0005435127177	3514	Economy	11700.00
0005432188670	3514	Economy	11700.00
0005434880075	3514	Economy	11700.00
0005435127153	3514	Economy	11700.00
0005435902899	3514	Economy	11700.00
0005434427183	3514	Economy	11700.00
0005435902870	3514	Economy	11700.00
0005435902922	3514	Economy	11700.00
0005432799814	14549	Business	35000.00
0005435626305	14549	Business	35000.00
0005434879699	14549	Business	35000.00
0005432607609	14549	Business	35000.00
0005434879540	14549	Business	35000.00
0005434938338	14549	Business	35000.00
0005434879293	14549	Business	35000.00
0005432607600	14549	Business	35000.00
0005434879396	14549	Business	35000.00
0005434879425	14549	Business	35000.00
0005434879301	14549	Business	35000.00
0005435903042	14549	Business	35000.00
0005434879158	14549	Business	35000.00
0005434879294	14549	Business	35000.00
0005432607622	14549	Business	35000.00
0005435626364	14549	Business	35000.00
0005434879412	14549	Business	35000.00
0005434879562	14549	Business	35000.00
0005435914722	14549	Business	35000.00
0005434427046	14549	Business	35000.00
0005432799706	14549	Business	35000.00
0005432799728	14549	Business	35000.00
0005435626380	14549	Comfort	19900.00
0005435903051	14549	Business	35000.00
0005432607601	14549	Comfort	19900.00
0005434879602	14549	Comfort	19900.00
0005435126811	14549	Comfort	19900.00
0005434879511	14549	Comfort	19900.00
0005434426958	14549	Comfort	19900.00
0005435914009	14549	Comfort	19900.00
0005434426959	14549	Comfort	19900.00
0005435903047	14549	Comfort	19900.00
0005434879413	14549	Comfort	19900.00
0005434426998	14549	Comfort	19900.00
0005434879538	14549	Comfort	19900.00
0005435914721	14549	Comfort	19900.00
0005435914025	14549	Comfort	19900.00
0005432799705	14549	Comfort	19900.00
0005435903052	14549	Comfort	19900.00
0005432799815	14549	Comfort	19900.00
0005434879219	14549	Comfort	19900.00
0005434879216	14549	Comfort	19900.00
0005435626363	14549	Comfort	19900.00
0005434879262	14549	Comfort	19900.00
0005435126742	14549	Comfort	19900.00
0005434879276	14549	Comfort	19900.00
0005434879537	14549	Comfort	19900.00
0005434879278	14549	Comfort	19900.00
0005432059545	14549	Comfort	19900.00
0005435914019	14549	Comfort	19900.00
0005435626307	14549	Comfort	19900.00
0005432607605	14549	Comfort	19900.00
0005434879273	14549	Comfort	19900.00
0005435914020	14549	Economy	11700.00
0005434938340	14549	Comfort	19900.00
0005434426849	14549	Economy	11700.00
0005434879145	14549	Economy	11700.00
0005434426844	14549	Economy	11700.00
0005434426802	14549	Economy	11700.00
0005434879279	14549	Economy	11700.00
0005434879381	14549	Economy	11700.00
0005432799747	14549	Economy	11700.00
0005434879338	14549	Economy	11700.00
0005435626373	14549	Economy	11700.00
0005435626379	14549	Economy	11700.00
0005434878897	14549	Economy	11700.00
0005435126620	14549	Economy	11700.00
0005435126739	14549	Economy	11700.00
0005434426957	14549	Economy	11700.00
0005434938446	14549	Economy	11700.00
0005434879352	14549	Economy	11700.00
0005434427017	14549	Economy	11700.00
0005435126800	14549	Economy	11700.00
0005435914719	14549	Economy	11700.00
0005435126622	14549	Economy	11700.00
0005432611742	14549	Economy	11700.00
0005434426986	14549	Economy	11700.00
0005435914023	14549	Economy	11700.00
0005435914024	14549	Economy	11700.00
0005434879127	14549	Economy	11700.00
0005434879220	14549	Economy	11700.00
0005434879492	14549	Economy	11700.00
0005435126892	14549	Economy	11700.00
0005435914015	14549	Economy	11700.00
0005435126688	14549	Economy	11700.00
0005434879083	14549	Economy	11700.00
0005432799839	14549	Economy	11700.00
0005434879236	14549	Economy	11700.00
0005435903056	14549	Economy	11700.00
0005432799833	14549	Economy	11700.00
0005435626306	14549	Economy	11700.00
0005435626365	14549	Economy	11700.00
0005434879217	14549	Economy	11700.00
0005435914021	14549	Economy	11700.00
0005434938394	14549	Economy	11700.00
0005435914011	14549	Economy	11700.00
0005434879167	14549	Economy	11700.00
0005435126710	14549	Economy	11700.00
0005434938377	14549	Economy	11700.00
0005434878874	14549	Economy	11700.00
0005432799682	14549	Economy	12800.00
0005435903055	14549	Economy	11700.00
0005434426987	14549	Economy	12800.00
0005434879357	14549	Economy	11700.00
0005435626335	14549	Economy	11700.00
0005435126815	14549	Economy	12800.00
0005435126741	14549	Economy	11700.00
0005434878938	14549	Economy	12800.00
0005434427005	14549	Economy	11700.00
0005435914014	14549	Economy	11700.00
0005434879266	14549	Economy	11700.00
0005435626340	14549	Economy	11700.00
0005434879235	14549	Economy	11700.00
0005434426949	14549	Economy	11700.00
0005432799800	14549	Economy	11700.00
0005434879241	14549	Economy	11700.00
0005434879104	14549	Economy	11700.00
0005434426880	14549	Economy	11700.00
0005434938395	14549	Economy	11700.00
0005434427066	14549	Economy	11700.00
0005434427037	14549	Economy	11700.00
0005435903054	14549	Economy	11700.00
0005434879480	14549	Economy	11700.00
0005435126697	14549	Economy	11700.00
0005435626338	14549	Economy	11700.00
0005435626303	14549	Economy	11700.00
0005432799810	14549	Economy	11700.00
0005435903057	14549	Economy	11700.00
0005432607604	14549	Economy	11700.00
0005434427036	14549	Economy	11700.00
0005434879189	14549	Economy	11700.00
0005434879259	14549	Economy	11700.00
0005434879644	14549	Economy	11700.00
0005434426842	14549	Economy	11700.00
0005434879082	14549	Economy	11700.00
0005434878846	14549	Economy	11700.00
0005434938337	14549	Economy	11700.00
0005432799849	14549	Economy	11700.00
0005435903058	14549	Economy	11700.00
0005435126704	14549	Economy	11700.00
0005432607581	14549	Economy	11700.00
0005434938379	14549	Economy	11700.00
0005435903048	14549	Economy	11700.00
0005434879081	14549	Economy	11700.00
0005435626382	14549	Economy	11700.00
0005432607582	14549	Economy	11700.00
0005435903045	14549	Economy	11700.00
0005435626348	14549	Economy	11700.00
0005435914724	14549	Economy	11700.00
0005434879720	14549	Economy	11700.00
0005434879627	14549	Economy	11700.00
0005432799759	14549	Economy	11700.00
0005435626377	14549	Economy	11700.00
0005434427068	14549	Economy	11700.00
0005434426997	14549	Economy	11700.00
0005434878898	14549	Economy	11700.00
0005434427067	14549	Economy	11700.00
0005435626349	14549	Economy	11700.00
0005435914012	14549	Economy	11700.00
0005434879383	14549	Economy	11700.00
0005435126621	14549	Economy	11700.00
0005435626313	14549	Economy	11700.00
0005435126793	14549	Economy	11700.00
0005434879302	14549	Economy	11700.00
0005435626323	14549	Economy	11700.00
0005434938438	14549	Economy	11700.00
0005434879202	14549	Economy	11700.00
0005434879597	14549	Economy	11700.00
0005434879190	14549	Economy	11700.00
0005434938448	14549	Economy	11700.00
0005435903049	14549	Economy	11700.00
0005434938300	14549	Economy	11700.00
0005434879157	14549	Economy	11700.00
0005434879203	14549	Economy	11700.00
0005435903043	14549	Economy	11700.00
0005435914013	14549	Economy	11700.00
0005432607603	14549	Economy	11700.00
0005435126937	14549	Economy	11700.00
0005434938301	14549	Economy	11700.00
0005434879009	14549	Economy	11700.00
0005434426879	14549	Economy	11700.00
0005432799659	14549	Economy	11700.00
0005435626304	14549	Economy	11700.00
0005432799710	14549	Economy	11700.00
0005432799868	14549	Economy	12800.00
0005434426765	14549	Economy	12800.00
0005434426972	14549	Economy	12800.00
0005434879550	14549	Economy	12800.00
0005435903040	14549	Economy	12800.00
0005435903053	14549	Economy	11700.00
0005434879277	14549	Economy	11700.00
0005435914008	14549	Economy	11700.00
0005435126754	14549	Economy	11700.00
0005434879114	14549	Economy	11700.00
0005434879509	14549	Economy	11700.00
0005434938441	14549	Economy	11700.00
0005434879578	14549	Economy	11700.00
0005434879561	14549	Economy	11700.00
0005435903041	14549	Economy	11700.00
0005434427045	14549	Economy	11700.00
0005435914010	14549	Economy	11700.00
0005434879428	14549	Economy	11700.00
0005434426753	14549	Economy	11700.00
0005432799832	14549	Economy	11700.00
0005435626322	14549	Economy	11700.00
0005432799658	14549	Economy	11700.00
0005434426804	14549	Economy	11700.00
0005435903050	14549	Economy	11700.00
0005434879481	14549	Economy	11700.00
0005434879539	14549	Economy	11700.00
0005435914016	14549	Economy	11700.00
0005435914018	14549	Economy	11700.00
0005434938378	14549	Economy	11700.00
0005435914017	14549	Economy	11700.00
0005434938246	14549	Economy	11700.00
0005434879458	14549	Economy	11700.00
0005434938439	14549	Economy	11700.00
0005434879415	14549	Economy	11700.00
0005434879579	14549	Economy	11700.00
0005434879395	14549	Economy	11700.00
0005434938397	14549	Economy	11700.00
0005434878905	14549	Economy	11700.00
0005434938402	14549	Economy	11700.00
0005432059544	14549	Economy	11700.00
0005434879159	14549	Economy	11700.00
0005434426874	14549	Economy	11700.00
0005435626383	14549	Economy	11700.00
0005434879457	14549	Economy	11700.00
0005432799834	14549	Economy	11700.00
0005432799876	14549	Economy	11700.00
0005435914026	14549	Economy	11700.00
0005434879601	14549	Economy	11700.00
0005434878939	14549	Economy	11700.00
0005435126812	14549	Economy	11700.00
0005434879331	14549	Economy	11700.00
0005434938440	14549	Economy	11700.00
0005435626372	14549	Economy	11700.00
0005435914718	14549	Economy	11700.00
0005434938247	14549	Economy	11700.00
0005432799641	14549	Economy	11700.00
0005434878875	14549	Economy	11700.00
0005435903044	14549	Economy	11700.00
0005432799824	14549	Economy	11700.00
0005434938411	14549	Economy	11700.00
0005434879421	14549	Economy	11700.00
0005434879055	14549	Economy	11700.00
0005435914022	14549	Economy	11700.00
0005435626341	14549	Economy	11700.00
0005435626288	14549	Economy	11700.00
0005435914723	14549	Economy	11700.00
0005435126705	14549	Economy	11700.00
0005432799890	14549	Economy	11700.00
0005434426926	14549	Economy	11700.00
0005432607608	14549	Economy	11700.00
0005434879263	14549	Economy	11700.00
0005432799848	14549	Economy	11700.00
0005434426803	14549	Economy	11700.00
0005434879188	14549	Economy	11700.00
0005435126820	14549	Economy	11700.00
0005435903046	14549	Economy	11700.00
0005435126700	14549	Economy	11700.00
0005435126825	14549	Economy	11700.00
0005432799704	14549	Economy	11700.00
0005434426985	14549	Economy	11700.00
0005434879019	14549	Economy	11700.00
0005434938396	14549	Economy	11700.00
0005435914720	14549	Economy	11700.00
0005435126567	14549	Economy	11700.00
0005434426764	14549	Economy	11700.00
0005434426984	14549	Economy	11700.00
0005434325870	3629	Economy	16300.00
0005434325871	3629	Economy	14800.00
0005434325876	3629	Economy	14800.00
0005434325879	3629	Economy	14800.00
0005434312359	3629	Economy	14800.00
0005434325869	3629	Economy	14800.00
0005435889936	3629	Economy	14800.00
0005435889953	3629	Economy	14800.00
0005434325880	3629	Economy	14800.00
0005434312358	3629	Economy	14800.00
0005435889944	3629	Economy	14800.00
0005434325877	3629	Economy	14800.00
0005434325873	3629	Economy	14800.00
0005434325875	3629	Economy	14800.00
0005434325878	3629	Economy	14800.00
0005434325874	3629	Economy	14800.00
0005434325872	3629	Economy	14800.00
0005434325782	15644	Economy	14800.00
0005435890015	15644	Economy	14800.00
0005435890014	15644	Economy	14800.00
0005435890013	15644	Economy	14800.00
0005435890012	15644	Economy	14800.00
0005435890016	15644	Economy	14800.00
0005434325736	15644	Economy	14800.00
0005434325737	15644	Economy	14800.00
0005434325787	15644	Economy	14800.00
0005435890011	15644	Economy	14800.00
0005434325813	15644	Economy	14800.00
0005434325775	15644	Economy	14800.00
0005434325805	15644	Economy	14800.00
0005434325786	15644	Economy	14800.00
0005434325799	15644	Economy	14800.00
0005435957993	627	Economy	4100.00
0005435957984	627	Economy	4100.00
0005435957988	627	Economy	4100.00
0005433420500	627	Economy	4100.00
0005433420478	627	Economy	4100.00
0005435957996	627	Economy	4100.00
0005435957983	627	Economy	4100.00
0005433420494	627	Economy	4100.00
0005433420526	627	Economy	4100.00
0005433420470	627	Economy	4100.00
0005433420479	627	Economy	4100.00
0005435957992	627	Economy	4100.00
0005435957985	627	Economy	4100.00
0005433420499	627	Economy	4100.00
0005435957986	627	Economy	4100.00
0005433420525	627	Economy	4100.00
0005433420495	627	Economy	4100.00
0005433420513	627	Economy	4100.00
0005435957987	627	Economy	4100.00
0005433420459	627	Economy	4100.00
0005433420510	627	Economy	4100.00
0005435957991	627	Economy	4100.00
0005435957994	627	Economy	4100.00
0005435957995	627	Economy	4100.00
0005433420458	627	Economy	4100.00
0005435957990	627	Economy	4100.00
0005435957989	627	Economy	4100.00
0005433420514	627	Economy	4100.00
0005435957982	627	Economy	4100.00
0005435957844	15207	Economy	4500.00
0005433420570	15207	Economy	4100.00
0005435957866	15207	Economy	4100.00
0005433420564	15207	Economy	4100.00
0005433420568	15207	Economy	4100.00
0005433420573	15207	Economy	4100.00
0005435957874	15207	Economy	4100.00
0005433420574	15207	Economy	4100.00
0005435957858	15207	Economy	4100.00
0005433420566	15207	Economy	4100.00
0005435957884	15207	Economy	4100.00
0005435957869	15207	Economy	4100.00
0005435957927	15207	Economy	4100.00
0005433420565	15207	Economy	4100.00
0005435957885	15207	Economy	4100.00
0005433420569	15207	Economy	4100.00
0005435957857	15207	Economy	4100.00
0005433420572	15207	Economy	4100.00
0005433420567	15207	Economy	4100.00
0005433420571	15207	Economy	4100.00
0005434995315	24002	Business	94000.00
0005434995314	24002	Business	94000.00
0005434995311	24002	Economy	31300.00
0005434995324	24002	Economy	31300.00
0005434995310	24002	Economy	31300.00
0005434995312	24002	Economy	31300.00
0005434995313	24002	Economy	31300.00
0005434995325	24002	Economy	31300.00
0005434995336	24002	Economy	31300.00
0005434995322	24002	Economy	31300.00
0005434995323	24002	Economy	31300.00
0005434995337	24002	Economy	31300.00
0005434995318	24002	Economy	31300.00
0005434995317	24002	Economy	31300.00
0005434995316	24002	Economy	31300.00
0005434247170	8835	Economy	10400.00
0005434247166	8835	Economy	10400.00
0005434247169	8835	Economy	10400.00
0005434247167	8835	Economy	10400.00
0005434247171	8835	Economy	10400.00
0005434247187	8835	Economy	10400.00
0005434247188	8835	Economy	10400.00
0005435629413	16009	Economy	10400.00
0005435629415	16009	Economy	10400.00
0005434247197	16009	Economy	10400.00
0005435629417	16009	Economy	10400.00
0005434247198	16009	Economy	10400.00
0005435629416	16009	Economy	10400.00
0005433404875	2874	Business	12600.00
0005433404886	2874	Economy	4200.00
0005435797745	2874	Economy	4600.00
0005435797747	2874	Economy	4200.00
0005435797746	2874	Economy	4200.00
0005435797754	2874	Economy	4200.00
0005433404908	2874	Economy	4200.00
0005435797748	2874	Economy	4200.00
0005435797752	2874	Economy	4200.00
0005433404887	2874	Economy	4200.00
0005435797744	2874	Economy	4200.00
0005435797750	2874	Economy	4200.00
0005433404894	2874	Economy	4200.00
0005433404895	2874	Economy	4200.00
0005435797743	2874	Economy	4200.00
0005435797751	2874	Economy	4200.00
0005435797749	2874	Economy	4200.00
0005435797756	2874	Economy	4200.00
0005435797753	2874	Economy	4200.00
0005435797757	2874	Economy	4200.00
0005435797755	2874	Economy	4200.00
0005435797627	29300	Business	12600.00
0005433404953	29300	Economy	4200.00
0005435797613	29300	Economy	4200.00
0005433404956	29300	Economy	4200.00
0005435797610	29300	Economy	4200.00
0005435797638	29300	Economy	4200.00
0005435797609	29300	Economy	4200.00
0005435797669	29300	Economy	4200.00
0005435797615	29300	Economy	4200.00
0005435797632	29300	Economy	4200.00
0005435797614	29300	Economy	4200.00
0005435797574	29300	Economy	4200.00
0005433404955	29300	Economy	4200.00
0005433404954	29300	Economy	4200.00
0005435797633	29300	Economy	4200.00
0005435797602	29300	Economy	4200.00
0005433404952	29300	Economy	4200.00
0005433404957	29300	Economy	4200.00
0005433404958	29300	Economy	4200.00
0005435797652	29300	Economy	4200.00
0005435797639	29300	Economy	4200.00
0005435797682	29300	Economy	4200.00
0005435376380	5822	Economy	6800.00
0005435376373	5822	Economy	6800.00
0005435376400	5822	Economy	6800.00
0005435376378	5822	Economy	6800.00
0005435376379	5822	Economy	6800.00
0005435376401	5822	Economy	6800.00
0005434948184	5805	Economy	6800.00
0005434948183	5805	Economy	6800.00
0005434948187	5805	Economy	6800.00
0005434948180	5805	Economy	6800.00
0005434948181	5805	Economy	6800.00
0005434948179	5805	Economy	6800.00
0005434948186	5805	Economy	6800.00
0005434948185	5805	Economy	6800.00
0005434948182	5805	Economy	6800.00
0005434948148	16397	Economy	6800.00
0005435376408	16397	Economy	6800.00
0005434948151	16397	Economy	6800.00
0005434948105	16397	Economy	6800.00
0005434948138	16397	Economy	6800.00
0005434948104	16397	Economy	6800.00
0005434948063	16397	Economy	6800.00
0005435376409	16397	Economy	6800.00
0005435376410	16397	Economy	6800.00
0005434948121	16397	Economy	6800.00
0005435376407	16397	Economy	6800.00
0005433961997	6946	Business	21400.00
0005433962023	6946	Business	21400.00
0005433962017	6946	Business	21400.00
0005433962027	6946	Business	21400.00
0005433961979	6946	Business	21400.00
0005433962024	6946	Business	21400.00
0005433962000	6946	Business	21400.00
0005433962026	6946	Business	21400.00
0005433961984	6946	Business	21400.00
0005433962006	6946	Economy	7100.00
0005433962002	6946	Economy	7100.00
0005433962019	6946	Economy	7100.00
0005433961982	6946	Economy	7100.00
0005433962016	6946	Economy	7800.00
0005433961993	6946	Economy	7100.00
0005433961985	6946	Economy	7100.00
0005433962030	6946	Economy	7100.00
0005433962003	6946	Economy	7100.00
0005433961978	6946	Economy	7100.00
0005433961986	6946	Economy	7100.00
0005433961974	6946	Economy	7100.00
0005433961990	6946	Economy	7100.00
0005433961988	6946	Economy	7100.00
0005433961996	6946	Economy	7100.00
0005433962020	6946	Economy	7100.00
0005433962018	6946	Economy	7100.00
0005433962022	6946	Economy	7100.00
0005433962004	6946	Economy	7100.00
0005433962013	6946	Economy	7100.00
0005433962014	6946	Economy	7100.00
0005433962009	6946	Economy	7100.00
0005433961989	6946	Economy	7100.00
0005433962029	6946	Economy	7100.00
0005433961994	6946	Economy	7100.00
0005433961981	6946	Economy	7100.00
0005433962028	6946	Economy	7100.00
0005433962031	6946	Economy	7100.00
0005433962001	6946	Economy	7100.00
0005433961980	6946	Economy	7100.00
0005433961995	6946	Economy	7100.00
0005433961987	6946	Economy	7100.00
0005433962007	6946	Economy	7100.00
0005433962005	6946	Economy	7100.00
0005433961976	6946	Economy	7100.00
0005433962012	6946	Economy	7100.00
0005433961975	6946	Economy	7100.00
0005433961992	6946	Economy	7100.00
0005433961998	6946	Economy	7100.00
0005433961991	6946	Economy	7100.00
0005433961983	6946	Economy	7100.00
0005433961999	6946	Economy	7100.00
0005433962025	6946	Economy	7100.00
0005433962011	6946	Economy	7100.00
0005433962015	6946	Economy	7100.00
0005433962021	6946	Economy	7100.00
0005433962010	6946	Economy	7100.00
0005433961977	6946	Economy	7100.00
0005433962008	6946	Economy	7100.00
0005433961239	25768	Business	21400.00
0005433961195	25768	Business	21400.00
0005433961187	25768	Business	21400.00
0005433961393	25768	Business	21400.00
0005433961144	25768	Business	21400.00
0005433961332	25768	Business	21400.00
0005433961281	25768	Business	21400.00
0005433960924	25768	Business	21400.00
0005433961402	25768	Economy	7100.00
0005433961413	25768	Economy	7100.00
0005433961240	25768	Economy	7100.00
0005433961188	25768	Economy	7100.00
0005433961371	25768	Economy	7100.00
0005433961227	25768	Economy	7100.00
0005433961336	25768	Economy	7800.00
0005433961394	25768	Economy	7800.00
0005433961197	25768	Economy	7800.00
0005433961222	25768	Economy	7100.00
0005433961115	25768	Economy	7100.00
0005433961194	25768	Economy	7100.00
0005433961379	25768	Economy	7100.00
0005433961142	25768	Economy	7100.00
0005433961286	25768	Economy	7100.00
0005433961238	25768	Economy	7100.00
0005433961405	25768	Economy	7100.00
0005433961225	25768	Economy	7100.00
0005433961335	25768	Economy	7100.00
0005433961375	25768	Economy	7100.00
0005433961304	25768	Economy	7100.00
0005433961391	25768	Economy	7100.00
0005433961321	25768	Economy	7100.00
0005433961404	25768	Economy	7100.00
0005433961237	25768	Economy	7100.00
0005433961354	25768	Economy	7100.00
0005433961358	25768	Economy	7100.00
0005433961349	25768	Economy	7100.00
0005433961196	25768	Economy	7100.00
0005433961414	25768	Economy	7100.00
0005433961325	25768	Economy	7100.00
0005433961385	25768	Economy	7100.00
0005433961326	25768	Economy	7100.00
0005433961193	25768	Economy	7100.00
0005433961340	25768	Economy	7100.00
0005433961327	25768	Economy	7100.00
0005433961282	25768	Economy	7100.00
0005433961233	25768	Economy	7100.00
0005433961300	25768	Economy	7100.00
0005433961202	25768	Economy	7100.00
0005433961154	25768	Economy	7100.00
0005433961287	25768	Economy	7100.00
0005433961211	25768	Economy	7100.00
0005433961409	25768	Economy	7100.00
0005433961189	25768	Economy	7100.00
0005433960990	25768	Economy	7100.00
0005433961181	25768	Economy	7100.00
0005433961116	25768	Economy	7100.00
0005433961324	25768	Economy	7100.00
0005433961184	25768	Economy	7100.00
0005433961403	25768	Economy	7100.00
0005433961322	25768	Economy	7100.00
0005433961339	25768	Economy	7100.00
0005433961333	25768	Economy	7100.00
0005433961114	25768	Economy	7100.00
0005433961280	25768	Economy	7100.00
0005433961380	25768	Economy	7100.00
0005433961392	25768	Economy	7100.00
0005435082866	24510	Economy	3900.00
0005435082855	24510	Economy	3900.00
0005435082865	24510	Economy	3900.00
0005435082854	24510	Economy	3900.00
0005435082863	24510	Economy	3900.00
0005435082873	24510	Economy	3900.00
0005435082867	24510	Economy	3900.00
0005435082860	24510	Economy	3900.00
0005435082941	26106	Economy	3900.00
0005435082944	26106	Economy	3900.00
0005435082945	26106	Economy	3900.00
0005435082947	26106	Economy	3900.00
0005435082942	26106	Economy	3900.00
0005435082946	26106	Economy	3900.00
0005435082940	26106	Economy	3900.00
0005435082943	26106	Economy	3900.00
0005435082937	26106	Economy	3900.00
0005435082938	26106	Economy	3900.00
0005435082939	26106	Economy	3900.00
0005434245566	4973	Business	18000.00
0005434245567	4973	Business	18000.00
0005434245556	4973	Business	18000.00
0005434245539	4973	Business	18000.00
0005435286676	4973	Business	18000.00
0005434245546	4973	Business	18000.00
0005434245541	4973	Business	18000.00
0005434245552	4973	Business	18000.00
0005432166966	4973	Economy	6600.00
0005434245554	4973	Economy	6600.00
0005432166963	4973	Economy	6000.00
0005433534519	4973	Economy	6000.00
0005432166964	4973	Economy	6000.00
0005434245543	4973	Economy	6000.00
0005435286661	4973	Economy	6000.00
0005434245557	4973	Economy	6000.00
0005434245551	4973	Economy	6000.00
0005434245562	4973	Economy	6000.00
0005434245550	4973	Economy	6000.00
0005434245563	4973	Economy	6000.00
0005434245560	4973	Economy	6000.00
0005434245545	4973	Economy	6000.00
0005434245555	4973	Economy	6000.00
0005434245544	4973	Economy	6000.00
0005434245561	4973	Economy	6000.00
0005434245559	4973	Economy	6000.00
0005434245564	4973	Economy	6000.00
0005433534514	4973	Economy	6000.00
0005434245549	4973	Economy	6000.00
0005435286670	4973	Economy	6000.00
0005433534523	4973	Economy	6000.00
0005432166965	4973	Economy	6000.00
0005434245553	4973	Economy	6000.00
0005434245538	4973	Economy	6000.00
0005434245548	4973	Economy	6000.00
0005433534513	4973	Economy	6000.00
0005434245565	4973	Economy	6000.00
0005435286690	4973	Economy	6000.00
0005434245547	4973	Economy	6000.00
0005434245540	4973	Economy	6000.00
0005435286680	4973	Economy	6000.00
0005435286678	4973	Economy	6000.00
0005434245542	4973	Economy	6000.00
0005434245558	4973	Economy	6000.00
0005432106494	4972	Business	18000.00
0005433616149	4972	Business	18000.00
0005432106522	4972	Business	18000.00
0005433616140	4972	Business	18000.00
0005433616082	4972	Business	18000.00
0005432106506	4972	Business	18000.00
0005433785642	4972	Business	18000.00
0005432106520	4972	Business	18000.00
0005433616136	4972	Business	18000.00
0005433616114	4972	Business	18000.00
0005433785666	4972	Business	18000.00
0005432106493	4972	Business	18000.00
0005433616134	4972	Business	18000.00
0005432106484	4972	Business	18000.00
0005432106513	4972	Business	18000.00
0005433785636	4972	Business	18000.00
0005432106499	4972	Business	18000.00
0005433616121	4972	Business	18000.00
0005432106479	4972	Business	18000.00
0005433616099	4972	Business	18000.00
0005432106478	4972	Business	18000.00
0005433616154	4972	Business	18000.00
0005433616110	4972	Business	18000.00
0005432106501	4972	Business	18000.00
0005433616148	4972	Business	18000.00
0005433616104	4972	Business	18000.00
0005433616108	4972	Business	18000.00
0005433616085	4972	Economy	6600.00
0005433785665	4972	Economy	6600.00
0005433785656	4972	Economy	6600.00
0005433616138	4972	Economy	6600.00
0005433785668	4972	Economy	6600.00
0005433616118	4972	Economy	6600.00
0005432665315	4972	Economy	6000.00
0005433616155	4972	Economy	6000.00
0005432665314	4972	Economy	6000.00
0005432145151	4972	Economy	6000.00
0005433785649	4972	Economy	6000.00
0005433616130	4972	Economy	6000.00
0005433785667	4972	Economy	6000.00
0005432106496	4972	Economy	6000.00
0005433616116	4972	Economy	6000.00
0005432106516	4972	Economy	6000.00
0005432106476	4972	Economy	6000.00
0005432106480	4972	Economy	6000.00
0005433785637	4972	Economy	6000.00
0005433616109	4972	Economy	6000.00
0005433616111	4972	Economy	6000.00
0005433616139	4972	Economy	6000.00
0005433785640	4972	Economy	6000.00
0005432106509	4972	Economy	6000.00
0005432106518	4972	Economy	6000.00
0005433616093	4972	Economy	6000.00
0005433616117	4972	Economy	6000.00
0005433616095	4972	Economy	6000.00
0005433616131	4972	Economy	6000.00
0005433785643	4972	Economy	6000.00
0005433785653	4972	Economy	6000.00
0005433785644	4972	Economy	6000.00
0005433785654	4972	Economy	6000.00
0005433616106	4972	Economy	6000.00
0005432106492	4972	Economy	6000.00
0005433785659	4972	Economy	6000.00
0005433616133	4972	Economy	6000.00
0005433616090	4972	Economy	6000.00
0005433616142	4972	Economy	6000.00
0005433616105	4972	Economy	6000.00
0005432106505	4972	Economy	6000.00
0005432106510	4972	Economy	6000.00
0005433616152	4972	Economy	6000.00
0005433616146	4972	Economy	6000.00
0005433616115	4972	Economy	6000.00
0005433616125	4972	Economy	6000.00
0005432106477	4972	Economy	6000.00
0005433785632	4972	Economy	6000.00
0005433785655	4972	Economy	6000.00
0005433785670	4972	Economy	6000.00
0005433616092	4972	Economy	6000.00
0005433785664	4972	Economy	6000.00
0005433616129	4972	Economy	6000.00
0005433785673	4972	Economy	6000.00
0005432106488	4972	Economy	6000.00
0005433616101	4972	Economy	6000.00
0005433616120	4972	Economy	6000.00
0005433616112	4972	Economy	6000.00
0005432106483	4972	Economy	6000.00
0005433616103	4972	Economy	6000.00
0005432106512	4972	Economy	6000.00
0005433616147	4972	Economy	6000.00
0005433785645	4972	Economy	6000.00
0005433616089	4972	Economy	6000.00
0005433785650	4972	Economy	6000.00
0005432106485	4972	Economy	6000.00
0005432106521	4972	Economy	6600.00
0005433785646	4972	Economy	6600.00
0005433616081	4972	Economy	6600.00
0005432106486	4972	Economy	6600.00
0005432666429	4972	Economy	6000.00
0005433616098	4972	Economy	6600.00
0005432106481	4972	Economy	6000.00
0005433616096	4972	Economy	6000.00
0005433616132	4972	Economy	6000.00
0005433616091	4972	Economy	6600.00
0005432106482	4972	Economy	6000.00
0005433616086	4972	Economy	6000.00
0005433616084	4972	Economy	6000.00
0005433616122	4972	Economy	6000.00
0005433616107	4972	Economy	6000.00
0005433616144	4972	Economy	6000.00
0005433616126	4972	Economy	6000.00
0005432106489	4972	Economy	6000.00
0005432106491	4972	Economy	6000.00
0005433785672	4972	Economy	6000.00
0005433616145	4972	Economy	6000.00
0005433785671	4972	Economy	6000.00
0005433785647	4972	Economy	6000.00
0005433616143	4972	Economy	6000.00
0005433616123	4972	Economy	6000.00
0005433616151	4972	Economy	6000.00
0005432106500	4972	Economy	6000.00
0005433616097	4972	Economy	6000.00
0005433785660	4972	Economy	6000.00
0005433785651	4972	Economy	6000.00
0005433616083	4972	Economy	6000.00
0005433785661	4972	Economy	6000.00
0005433785662	4972	Economy	6000.00
0005433616119	4972	Economy	6000.00
0005432106495	4972	Economy	6000.00
0005433616135	4972	Economy	6000.00
0005432106503	4972	Economy	6000.00
0005433785658	4972	Economy	6000.00
0005432106511	4972	Economy	6000.00
0005433616124	4972	Economy	6000.00
0005432145152	4972	Economy	6000.00
0005433785648	4972	Economy	6000.00
0005433785639	4972	Economy	6000.00
0005433785638	4972	Economy	6000.00
0005433616113	4972	Economy	6000.00
0005432106507	4972	Economy	6000.00
0005433616137	4972	Economy	6000.00
0005432106498	4972	Economy	6000.00
0005433616094	4972	Economy	6000.00
0005433616141	4972	Economy	6000.00
0005432106508	4972	Economy	6000.00
0005433616153	4972	Economy	6000.00
0005432106490	4972	Economy	6000.00
0005433785641	4972	Economy	6000.00
0005432106515	4972	Economy	6000.00
0005432106487	4972	Economy	6000.00
0005433616088	4972	Economy	6000.00
0005432106514	4972	Economy	6000.00
0005432106497	4972	Economy	6000.00
0005433616102	4972	Economy	6000.00
0005433616087	4972	Economy	6000.00
0005433616127	4972	Economy	6000.00
0005433785657	4972	Economy	6000.00
0005433785635	4972	Economy	6000.00
0005432106519	4972	Economy	6000.00
0005433616150	4972	Economy	6000.00
0005433785634	4972	Economy	6000.00
0005432106504	4972	Economy	6000.00
0005432106502	4972	Economy	6000.00
0005433616128	4972	Economy	6000.00
0005433785633	4972	Economy	6000.00
0005433785663	4972	Economy	6000.00
0005433785652	4972	Economy	6000.00
0005433616100	4972	Economy	6000.00
0005433785669	4972	Economy	6000.00
0005432106517	4972	Economy	6000.00
0005434229798	4970	Business	18000.00
0005434149956	4970	Business	18000.00
0005434265636	4970	Business	18000.00
0005434149965	4970	Business	18000.00
0005434149957	4970	Business	18000.00
0005432336192	4970	Business	18000.00
0005434265648	4970	Business	18000.00
0005435007297	4970	Business	18000.00
0005435007206	4970	Business	18000.00
0005434265640	4970	Business	18000.00
0005435269821	4970	Business	18000.00
0005434229806	4970	Business	18000.00
0005435007301	4970	Business	18000.00
0005434229814	4970	Business	18000.00
0005434265627	4970	Business	18000.00
0005434149960	4970	Business	18000.00
0005434265645	4970	Business	18000.00
0005434229813	4970	Business	18000.00
0005434265634	4970	Business	18000.00
0005434229799	4970	Business	18000.00
0005433685538	4970	Business	18000.00
0005434265651	4970	Economy	6600.00
0005435007201	4970	Economy	6600.00
0005434173599	4970	Economy	6000.00
0005434149963	4970	Economy	6000.00
0005433688829	4970	Economy	6000.00
0005435007324	4970	Economy	6000.00
0005435269791	4970	Economy	6000.00
0005435007376	4970	Economy	6000.00
0005433815443	4970	Economy	6000.00
0005434173597	4970	Economy	6000.00
0005434229821	4970	Economy	6000.00
0005434149964	4970	Economy	6000.00
0005434265628	4970	Economy	6000.00
0005434229807	4970	Economy	6000.00
0005434229808	4970	Economy	6000.00
0005434265637	4970	Economy	6000.00
0005435269790	4970	Economy	6000.00
0005434265652	4970	Economy	6000.00
0005435007262	4970	Economy	6000.00
0005435007279	4970	Economy	6000.00
0005435007214	4970	Economy	6000.00
0005434265653	4970	Economy	6000.00
0005434229810	4970	Economy	6000.00
0005432336194	4970	Economy	6000.00
0005435269820	4970	Economy	6000.00
0005434265631	4970	Economy	6000.00
0005435007265	4970	Economy	6000.00
0005435269792	4970	Economy	6000.00
0005434265638	4970	Economy	6000.00
0005434229816	4970	Economy	6000.00
0005434229819	4970	Economy	6000.00
0005434265642	4970	Economy	6000.00
0005435269822	4970	Economy	6000.00
0005434265643	4970	Economy	6000.00
0005432336191	4970	Economy	6000.00
0005434229804	4970	Economy	6000.00
0005434265633	4970	Economy	6000.00
0005434265644	4970	Economy	6000.00
0005435007266	4970	Economy	6000.00
0005433815437	4970	Economy	6000.00
0005435007213	4970	Economy	6000.00
0005432336193	4970	Economy	6000.00
0005434229817	4970	Economy	6000.00
0005435269824	4970	Economy	6000.00
0005435007264	4970	Economy	6600.00
0005434149955	4970	Economy	6600.00
0005434149961	4970	Economy	6600.00
0005435269833	4970	Economy	6600.00
0005434229811	4970	Economy	6000.00
0005432336248	4970	Economy	6000.00
0005433815410	4970	Economy	6000.00
0005434265632	4970	Economy	6000.00
0005435007278	4970	Economy	6600.00
0005434265649	4970	Economy	6000.00
0005433688830	4970	Economy	6000.00
0005434265630	4970	Economy	6000.00
0005434265641	4970	Economy	6000.00
0005434149959	4970	Economy	6000.00
0005434265647	4970	Economy	6000.00
0005434149958	4970	Economy	6000.00
0005434265639	4970	Economy	6000.00
0005432336157	4970	Economy	6000.00
0005432336100	4970	Economy	6000.00
0005433815409	4970	Economy	6000.00
0005435007227	4970	Economy	6000.00
0005435007377	4970	Economy	6000.00
0005434149962	4970	Economy	6000.00
0005434229809	4970	Economy	6000.00
0005432336149	4970	Economy	6000.00
0005433685545	4970	Economy	6000.00
0005434229818	4970	Economy	6000.00
0005434229815	4970	Economy	6000.00
0005434265650	4970	Economy	6000.00
0005434229802	4970	Economy	6000.00
0005434229800	4970	Economy	6000.00
0005434173598	4970	Economy	6000.00
0005432336099	4970	Economy	6000.00
0005435269807	4970	Economy	6000.00
0005435007276	4970	Economy	6000.00
0005434229805	4970	Economy	6000.00
0005434265646	4970	Economy	6000.00
0005435269834	4970	Economy	6000.00
0005435007352	4970	Economy	6000.00
0005435269832	4970	Economy	6000.00
0005434229820	4970	Economy	6000.00
0005435269835	4970	Economy	6000.00
0005434229801	4970	Economy	6000.00
0005434229803	4970	Economy	6000.00
0005435269825	4970	Economy	6000.00
0005435007277	4970	Economy	6000.00
0005434265635	4970	Economy	6000.00
0005433815430	4970	Economy	6000.00
0005434265629	4970	Economy	6000.00
0005434229812	4970	Economy	6000.00
0005435007353	4970	Economy	6000.00
0005435007267	4970	Economy	6000.00
0005433785331	8405	Business	18000.00
0005433785298	8405	Business	18000.00
0005434245357	8405	Business	18000.00
0005433785441	8405	Business	18000.00
0005434245254	8405	Business	18000.00
0005434245437	8405	Business	18000.00
0005434245253	8405	Business	18000.00
0005433785370	8405	Business	18000.00
0005434245443	8405	Business	18000.00
0005433785127	8405	Business	18000.00
0005433785374	8405	Business	18000.00
0005433785268	8405	Business	18000.00
0005433785270	8405	Business	18000.00
0005432663048	8405	Business	18000.00
0005433785350	8405	Business	18000.00
0005434245283	8405	Economy	6600.00
0005435269911	8405	Economy	6600.00
0005433785332	8405	Economy	6600.00
0005434245250	8405	Economy	6600.00
0005432659725	8405	Economy	6000.00
0005433785354	8405	Economy	6000.00
0005434245126	8405	Economy	6000.00
0005434245352	8405	Economy	6000.00
0005434245314	8405	Economy	6000.00
0005434245358	8405	Economy	6000.00
0005433785371	8405	Economy	6000.00
0005435269910	8405	Economy	6000.00
0005433785311	8405	Economy	6000.00
0005433785300	8405	Economy	6000.00
0005435269909	8405	Economy	6000.00
0005434245157	8405	Economy	6000.00
0005434245208	8405	Economy	6000.00
0005433785425	8405	Economy	6000.00
0005435269901	8405	Economy	6000.00
0005434245249	8405	Economy	6000.00
0005433785310	8405	Economy	6000.00
0005435269912	8405	Economy	6000.00
0005435269906	8405	Economy	6000.00
0005434245320	8405	Economy	6000.00
0005433785213	8405	Economy	6000.00
0005435269902	8405	Economy	6000.00
0005433785512	8405	Economy	6000.00
0005433785192	8405	Economy	6000.00
0005434245397	8405	Economy	6000.00
0005435269904	8405	Economy	6000.00
0005434245396	8405	Economy	6000.00
0005433785372	8405	Economy	6600.00
0005433785299	8405	Economy	6600.00
0005434245392	8405	Economy	6600.00
0005434245284	8405	Economy	6000.00
0005434245315	8405	Economy	6000.00
0005433785442	8405	Economy	6600.00
0005433785196	8405	Economy	6000.00
0005434245436	8405	Economy	6000.00
0005433785173	8405	Economy	6000.00
0005433785494	8405	Economy	6000.00
0005433785357	8405	Economy	6000.00
0005435269903	8405	Economy	6000.00
0005432663058	8405	Economy	6000.00
0005433785479	8405	Economy	6000.00
0005434245285	8405	Economy	6000.00
0005434245321	8405	Economy	6000.00
0005433785452	8405	Economy	6000.00
0005434245351	8405	Economy	6000.00
0005433785373	8405	Economy	6000.00
0005433785088	8405	Economy	6000.00
0005433785383	8405	Economy	6000.00
0005433785384	8405	Economy	6000.00
0005433785438	8405	Economy	6000.00
0005432666423	8405	Economy	6000.00
0005433785439	8405	Economy	6000.00
0005435269908	8405	Economy	6000.00
0005433785269	8405	Economy	6000.00
0005433785175	8405	Economy	6000.00
0005435269907	8405	Economy	6000.00
0005434245449	8405	Economy	6000.00
0005434245350	8405	Economy	6000.00
0005433785214	8405	Economy	6000.00
0005433785489	8405	Economy	6000.00
0005435269905	8405	Economy	6000.00
0005433785249	8405	Economy	6000.00
0005433785453	8405	Economy	6000.00
0005433785309	8405	Economy	6000.00
0005432663068	8405	Economy	6000.00
0005433785446	8405	Economy	6000.00
0005433785318	8405	Economy	6000.00
0005433785089	8405	Economy	6000.00
0005434245313	8405	Economy	6000.00
0005433785294	8405	Economy	6000.00
0005433615254	8406	Business	18000.00
0005433615310	8406	Business	18000.00
0005433615498	8406	Business	18000.00
0005433615455	8406	Business	18000.00
0005433615562	8406	Business	18000.00
0005433615499	8406	Business	18000.00
0005433615633	8406	Business	18000.00
0005433615504	8406	Business	18000.00
0005433615485	8406	Business	18000.00
0005433615484	8406	Business	18000.00
0005433615431	8406	Business	18000.00
0005433615183	8406	Business	18000.00
0005433615295	8406	Business	18000.00
0005433615364	8406	Economy	6600.00
0005433615249	8406	Economy	6000.00
0005433615605	8406	Economy	6000.00
0005433615415	8406	Economy	6000.00
0005433615655	8406	Economy	6000.00
0005433615512	8406	Economy	6000.00
0005433615624	8406	Economy	6000.00
0005433615523	8406	Economy	6000.00
0005433615595	8406	Economy	6000.00
0005433615462	8406	Economy	6000.00
0005433615522	8406	Economy	6000.00
0005433615382	8406	Economy	6000.00
0005433615333	8406	Economy	6000.00
0005433615507	8406	Economy	6000.00
0005433615634	8406	Economy	6000.00
0005433615371	8406	Economy	6000.00
0005433615309	8406	Economy	6000.00
0005433615280	8406	Economy	6000.00
0005433615477	8406	Economy	6000.00
0005433614954	8406	Economy	6000.00
0005433615425	8406	Economy	6000.00
0005433615355	8406	Economy	6000.00
0005433615421	8406	Economy	6000.00
0005433615296	8406	Economy	6000.00
0005433615602	8406	Economy	6000.00
0005433615479	8406	Economy	6000.00
0005433615281	8406	Economy	6000.00
0005433615519	8406	Economy	6000.00
0005433615386	8406	Economy	6600.00
0005433615481	8406	Economy	6000.00
0005433615377	8406	Economy	6000.00
0005433615527	8406	Economy	6000.00
0005433614960	8406	Economy	6000.00
0005433615637	8406	Economy	6000.00
0005433615548	8406	Economy	6000.00
0005433615520	8406	Economy	6000.00
0005433615547	8406	Economy	6000.00
0005433615241	8406	Economy	6000.00
0005433615528	8406	Economy	6000.00
0005433615506	8406	Economy	6000.00
0005433615461	8406	Economy	6000.00
0005433615604	8406	Economy	6000.00
0005433615266	8406	Economy	6000.00
0005433615591	8406	Economy	6000.00
0005433615608	8406	Economy	6000.00
0005433615255	8406	Economy	6000.00
0005433615414	8406	Economy	6000.00
0005433615308	8406	Economy	6000.00
0005433615612	8406	Economy	6000.00
0005433615580	8406	Economy	6000.00
0005433615524	8406	Economy	6000.00
0005433615115	8406	Economy	6000.00
0005433615352	8406	Economy	6000.00
0005433615609	8406	Economy	6000.00
0005433615596	8406	Economy	6000.00
0005433615408	8406	Economy	6000.00
0005433615336	8406	Economy	6000.00
0005433615471	8406	Economy	6000.00
0005433615561	8406	Economy	6000.00
0005433615250	8406	Economy	6000.00
0005433615213	8406	Economy	6000.00
0005433815536	8407	Business	18000.00
0005434229636	8407	Business	18000.00
0005435007481	8407	Business	18000.00
0005434229651	8407	Business	18000.00
0005434265362	8407	Business	18000.00
0005434229543	8407	Business	18000.00
0005433689951	8407	Business	18000.00
0005434149850	8407	Business	18000.00
0005434173552	8407	Business	18000.00
0005434229615	8407	Business	18000.00
0005432035483	8407	Business	18000.00
0005435007487	8407	Business	18000.00
0005434173559	8407	Business	18000.00
0005432336269	8407	Business	18000.00
0005432035475	8407	Business	18000.00
0005434229635	8407	Business	18000.00
0005434229642	8407	Business	18000.00
0005432336262	8407	Business	18000.00
0005435007480	8407	Business	18000.00
0005434149892	8407	Business	18000.00
0005432035487	8407	Business	18000.00
0005432035494	8407	Business	18000.00
0005433815482	8407	Business	18000.00
0005432035484	8407	Business	18000.00
0005434149862	8407	Business	18000.00
0005434149893	8407	Business	18000.00
0005435007476	8407	Economy	6600.00
0005432035502	8407	Economy	6600.00
0005432035482	8407	Economy	6600.00
0005432336272	8407	Economy	6600.00
0005434173558	8407	Economy	6000.00
0005432035481	8407	Economy	6000.00
0005432035498	8407	Economy	6000.00
0005434265328	8407	Economy	6000.00
0005434229650	8407	Economy	6000.00
0005432035488	8407	Economy	6000.00
0005432047624	8407	Economy	6000.00
0005435007486	8407	Economy	6000.00
0005434229541	8407	Economy	6000.00
0005435007492	8407	Economy	6000.00
0005435286731	8407	Economy	6000.00
0005434265424	8407	Economy	6000.00
0005435007467	8407	Economy	6000.00
0005434265461	8407	Economy	6000.00
0005435007473	8407	Economy	6000.00
0005433815480	8407	Economy	6000.00
0005434265423	8407	Economy	6000.00
0005434229637	8407	Economy	6000.00
0005434149824	8407	Economy	6000.00
0005435007471	8407	Economy	6000.00
0005434149849	8407	Economy	6000.00
0005435007488	8407	Economy	6000.00
0005432035479	8407	Economy	6000.00
0005434229544	8407	Economy	6000.00
0005435007478	8407	Economy	6000.00
0005432035499	8407	Economy	6000.00
0005432035485	8407	Economy	6000.00
0005434149816	8407	Economy	6000.00
0005433534539	8407	Economy	6000.00
0005434229572	8407	Economy	6000.00
0005434265363	8407	Economy	6000.00
0005435286732	8407	Economy	6000.00
0005433689953	8407	Economy	6000.00
0005434149894	8407	Economy	6000.00
0005432035497	8407	Economy	6000.00
0005432035495	8407	Economy	6000.00
0005434149891	8407	Economy	6000.00
0005434265361	8407	Economy	6000.00
0005435007489	8407	Economy	6000.00
0005432035478	8407	Economy	6000.00
0005432336261	8407	Economy	6000.00
0005434265367	8407	Economy	6000.00
0005432035493	8407	Economy	6000.00
0005434229640	8407	Economy	6000.00
0005434149857	8407	Economy	6000.00
0005435007485	8407	Economy	6000.00
0005435007477	8407	Economy	6000.00
0005434265322	8407	Economy	6000.00
0005432035489	8407	Economy	6000.00
0005434229630	8407	Economy	6000.00
0005432336270	8407	Economy	6000.00
0005434149864	8407	Economy	6000.00
0005433690965	8407	Economy	6000.00
0005434229631	8407	Economy	6000.00
0005434265412	8407	Economy	6000.00
0005434229613	8407	Economy	6000.00
0005434149860	8407	Economy	6000.00
0005434265365	8407	Economy	6000.00
0005434265425	8407	Economy	6600.00
0005435007470	8407	Economy	6600.00
0005433815478	8407	Economy	6600.00
0005434149861	8407	Economy	6600.00
0005435007475	8407	Economy	6600.00
0005434149823	8407	Economy	6000.00
0005434229624	8407	Economy	6000.00
0005434229638	8407	Economy	6000.00
0005434149834	8407	Economy	6600.00
0005432035476	8407	Economy	6000.00
0005434265448	8407	Economy	6000.00
0005434229592	8407	Economy	6000.00
0005434265552	8407	Economy	6000.00
0005434149833	8407	Economy	6000.00
0005435007484	8407	Economy	6000.00
0005435007472	8407	Economy	6000.00
0005433534540	8407	Economy	6000.00
0005434265346	8407	Economy	6000.00
0005432336264	8407	Economy	6000.00
0005432336265	8407	Economy	6000.00
0005432035490	8407	Economy	6000.00
0005434265459	8407	Economy	6000.00
0005432035501	8407	Economy	6000.00
0005435007482	8407	Economy	6000.00
0005434265366	8407	Economy	6000.00
0005434265401	8407	Economy	6000.00
0005432336273	8407	Economy	6000.00
0005434311258	8407	Economy	6000.00
0005434229618	8407	Economy	6000.00
0005435007469	8407	Economy	6000.00
0005434265327	8407	Economy	6000.00
0005434149817	8407	Economy	6000.00
0005434229641	8407	Economy	6000.00
0005434265430	8407	Economy	6000.00
0005434265484	8407	Economy	6000.00
0005432336271	8407	Economy	6000.00
0005434265460	8407	Economy	6000.00
0005432047623	8407	Economy	6000.00
0005432035500	8407	Economy	6000.00
0005433815481	8407	Economy	6000.00
0005432035492	8407	Economy	6000.00
0005432035491	8407	Economy	6000.00
0005434265439	8407	Economy	6000.00
0005435286733	8407	Economy	6000.00
0005432336268	8407	Economy	6000.00
0005432035480	8407	Economy	6000.00
0005434149848	8407	Economy	6000.00
0005435007490	8407	Economy	6000.00
0005432336266	8407	Economy	6000.00
0005434229573	8407	Economy	6000.00
0005434311257	8407	Economy	6000.00
0005434265313	8407	Economy	6000.00
0005433689952	8407	Economy	6000.00
0005434173569	8407	Economy	6000.00
0005435007474	8407	Economy	6000.00
0005435007483	8407	Economy	6000.00
0005435007491	8407	Economy	6000.00
0005433815479	8407	Economy	6000.00
0005434229614	8407	Economy	6000.00
0005432336267	8407	Economy	6000.00
0005434149822	8407	Economy	6000.00
0005435286734	8407	Economy	6000.00
0005432035477	8407	Economy	6000.00
0005435007468	8407	Economy	6000.00
0005435007479	8407	Economy	6000.00
0005432336263	8407	Economy	6000.00
0005432035496	8407	Economy	6000.00
0005432035486	8407	Economy	6000.00
0005434639578	12605	Economy	16200.00
0005433202657	12605	Economy	16200.00
0005434639584	12605	Economy	16200.00
0005433202653	12605	Economy	14800.00
0005434639566	12605	Economy	14800.00
0005433202654	12605	Economy	14800.00
0005433202659	12605	Economy	14800.00
0005433202651	12605	Economy	14800.00
0005434639616	12605	Economy	14800.00
0005434639658	12605	Economy	14800.00
0005434639683	12605	Economy	14800.00
0005433202656	12605	Economy	14800.00
0005433202658	12605	Economy	14800.00
0005434639586	12605	Economy	14800.00
0005433202645	12605	Economy	14800.00
0005433202655	12605	Economy	14800.00
0005434639572	12605	Economy	14800.00
0005433202647	12605	Economy	14800.00
0005434639606	12605	Economy	14800.00
0005433202649	12605	Economy	14800.00
0005433202650	12605	Economy	14800.00
0005434639657	12605	Economy	14800.00
0005434639579	12605	Economy	14800.00
0005434639675	12605	Economy	14800.00
0005433202648	12605	Economy	14800.00
0005433202646	12605	Economy	14800.00
0005434639656	12605	Economy	14800.00
0005433202652	12605	Economy	14800.00
0005434639681	12605	Economy	14800.00
0005434639565	12605	Economy	14800.00
0005434639589	12605	Economy	14800.00
0005434639590	12605	Economy	14800.00
0005434639569	12605	Economy	14800.00
0005434639558	12605	Economy	14800.00
0005434639694	12605	Economy	14800.00
0005434639517	12605	Economy	14800.00
0005434639620	12605	Economy	14800.00
0005434639811	23401	Economy	16200.00
0005434639798	23401	Economy	16200.00
0005434639804	23401	Economy	14800.00
0005434639799	23401	Economy	14800.00
0005433202492	23401	Economy	14800.00
0005434639812	23401	Economy	14800.00
0005434639786	23401	Economy	14800.00
0005434639802	23401	Economy	14800.00
0005434639809	23401	Economy	14800.00
0005433202506	23401	Economy	14800.00
0005434639810	23401	Economy	14800.00
0005434639792	23401	Economy	14800.00
0005434639796	23401	Economy	14800.00
0005434639793	23401	Economy	14800.00
0005434639807	23401	Economy	14800.00
0005433202521	23401	Economy	14800.00
0005434639797	23401	Economy	14800.00
0005433202460	23401	Economy	14800.00
0005433202451	23401	Economy	14800.00
0005433202444	23401	Economy	14800.00
0005434639789	23401	Economy	14800.00
0005434639813	23401	Economy	14800.00
0005432290691	23401	Economy	14800.00
0005434639800	23401	Economy	14800.00
0005432290692	23401	Economy	14800.00
0005434639803	23401	Economy	14800.00
0005433202494	23401	Economy	14800.00
0005434639808	23401	Economy	14800.00
0005433202443	23401	Economy	14800.00
0005434639790	23401	Economy	14800.00
0005433202493	23401	Economy	14800.00
0005434639805	23401	Economy	14800.00
0005434639801	23401	Economy	14800.00
0005433202507	23401	Economy	14800.00
0005434639806	23401	Economy	14800.00
0005434639788	23401	Economy	14800.00
0005434639795	23401	Economy	14800.00
0005433202495	23401	Economy	14800.00
0005434639791	23401	Economy	14800.00
0005433202461	23401	Economy	14800.00
0005433202496	23401	Economy	14800.00
0005434639787	23401	Economy	14800.00
0005434639815	23401	Economy	14800.00
0005434639814	23401	Economy	14800.00
0005434639794	23401	Economy	14800.00
0005432329261	21105	Business	18900.00
0005432329291	21105	Business	18900.00
0005432329234	21105	Business	18900.00
0005432383473	21105	Business	18900.00
0005432848865	21105	Business	18900.00
0005432383504	21105	Business	18900.00
0005432383621	21105	Business	18900.00
0005432383640	21105	Business	18900.00
0005432848864	21105	Business	18900.00
0005432329144	21105	Business	18900.00
0005432383512	21105	Business	18900.00
0005432848862	21105	Business	18900.00
0005432383350	21105	Economy	6300.00
0005432329163	21105	Economy	6300.00
0005432383561	21105	Economy	6300.00
0005432328982	21105	Economy	6300.00
0005432383596	21105	Economy	6300.00
0005432383513	21105	Economy	6300.00
0005432383608	21105	Economy	6300.00
0005432328983	21105	Economy	6300.00
0005432383531	21105	Economy	6300.00
0005432329284	21105	Economy	6900.00
0005432329285	21105	Economy	6900.00
0005432383574	21105	Economy	6900.00
0005432054363	21105	Economy	6900.00
0005432329330	21105	Economy	6900.00
0005432329246	21105	Economy	6300.00
0005432848866	21105	Economy	6300.00
0005432328985	21105	Economy	6300.00
0005432054361	21105	Economy	6300.00
0005432329164	21105	Economy	6300.00
0005432329209	21105	Economy	6300.00
0005432329227	21105	Economy	6300.00
0005432383602	21105	Economy	6300.00
0005432383625	21105	Economy	6300.00
0005432383515	21105	Economy	6300.00
0005432383442	21105	Economy	6300.00
0005432383637	21105	Economy	6300.00
0005432329146	21105	Economy	6300.00
0005432329331	21105	Economy	6300.00
0005432329166	21105	Economy	6300.00
0005432329192	21105	Economy	6300.00
0005432383425	21105	Economy	6300.00
0005432383492	21105	Economy	6300.00
0005432329129	21105	Economy	6300.00
0005432383639	21105	Economy	6300.00
0005432383581	21105	Economy	6300.00
0005432383755	21105	Economy	6300.00
0005432329015	21105	Economy	6300.00
0005432329228	21105	Economy	6300.00
0005432383532	21105	Economy	6300.00
0005432054364	21105	Economy	6300.00
0005432383429	21105	Economy	6300.00
0005432329145	21105	Economy	6300.00
0005432383530	21105	Economy	6300.00
0005432329233	21105	Economy	6300.00
0005432383586	21105	Economy	6300.00
0005432329265	21105	Economy	6300.00
0005432383754	21105	Economy	6300.00
0005432383756	21105	Economy	6300.00
0005432329122	21105	Economy	6300.00
0005432329245	21105	Economy	6300.00
0005432383529	21105	Economy	6300.00
0005432383582	21105	Economy	6300.00
0005432328986	21105	Economy	6300.00
0005432848867	21105	Economy	6300.00
0005432383458	21105	Economy	6300.00
0005432383518	21105	Economy	6300.00
0005432383521	21105	Economy	6300.00
0005432848863	21105	Economy	6300.00
0005432054362	21105	Economy	6300.00
0005432383665	21105	Economy	6300.00
0005432329230	21105	Economy	6300.00
0005432383540	21105	Economy	6300.00
0005432383649	21105	Economy	6300.00
0005432383493	21105	Economy	6300.00
0005432329215	21105	Economy	6300.00
0005432383450	21105	Economy	6300.00
0005432383459	21105	Economy	6300.00
0005432383544	21105	Economy	6300.00
0005432328784	21105	Economy	6300.00
0005432329214	21105	Economy	6300.00
0005432383603	21105	Economy	6300.00
0005432329292	21105	Economy	6300.00
0005432383587	21105	Economy	6300.00
0005432383619	21105	Economy	6300.00
0005432328971	21105	Economy	6300.00
0005432383676	21105	Economy	6300.00
0005432383590	21105	Economy	6300.00
0005432329181	21105	Economy	6300.00
0005432329229	21105	Economy	6300.00
0005432287282	31266	Business	18900.00
0005432329578	31266	Business	18900.00
0005432329560	31266	Business	18900.00
0005432329555	31266	Business	18900.00
0005432383883	31266	Business	18900.00
0005432329567	31266	Business	18900.00
0005432287284	31266	Business	18900.00
0005432329562	31266	Business	18900.00
0005432383880	31266	Business	18900.00
0005432329540	31266	Business	18900.00
0005432383884	31266	Business	18900.00
0005432383898	31266	Economy	6300.00
0005432383901	31266	Economy	6300.00
0005432383882	31266	Economy	6300.00
0005432383875	31266	Economy	6300.00
0005432329572	31266	Economy	6300.00
0005432383913	31266	Economy	6300.00
0005432383914	31266	Economy	6300.00
0005432329568	31266	Economy	6300.00
0005432383911	31266	Economy	6300.00
0005432383888	31266	Economy	6300.00
0005432383902	31266	Economy	6900.00
0005432383903	31266	Economy	6900.00
0005432329546	31266	Economy	6900.00
0005432287285	31266	Economy	6900.00
0005432329556	31266	Economy	6900.00
0005432329571	31266	Economy	6300.00
0005432329544	31266	Economy	6300.00
0005432287287	31266	Economy	6300.00
0005432329563	31266	Economy	6300.00
0005432287286	31266	Economy	6300.00
0005432329577	31266	Economy	6300.00
0005432329558	31266	Economy	6300.00
0005432329552	31266	Economy	6300.00
0005432383910	31266	Economy	6300.00
0005432329547	31266	Economy	6300.00
0005432329541	31266	Economy	6300.00
0005432329539	31266	Economy	6300.00
0005432383899	31266	Economy	6300.00
0005432329542	31266	Economy	6300.00
0005432329549	31266	Economy	6300.00
0005432329565	31266	Economy	6300.00
0005432329564	31266	Economy	6300.00
0005432329580	31266	Economy	6300.00
0005432383889	31266	Economy	6300.00
0005432383881	31266	Economy	6300.00
0005432383895	31266	Economy	6300.00
0005432329559	31266	Economy	6300.00
0005432329566	31266	Economy	6300.00
0005432329551	31266	Economy	6300.00
0005432329536	31266	Economy	6300.00
0005432329543	31266	Economy	6300.00
0005432383897	31266	Economy	6300.00
0005432329550	31266	Economy	6300.00
0005432329569	31266	Economy	6300.00
0005432383892	31266	Economy	6300.00
0005432383890	31266	Economy	6300.00
0005432383909	31266	Economy	6300.00
0005432383891	31266	Economy	6300.00
0005432383879	31266	Economy	6300.00
0005432383907	31266	Economy	6300.00
0005432329537	31266	Economy	6300.00
0005432383876	31266	Economy	6300.00
0005432329534	31266	Economy	6300.00
0005432329574	31266	Economy	6300.00
0005432383886	31266	Economy	6300.00
0005432383894	31266	Economy	6300.00
0005432329553	31266	Economy	6300.00
0005432383877	31266	Economy	6300.00
0005432329554	31266	Economy	6300.00
0005432329576	31266	Economy	6300.00
0005432383905	31266	Economy	6300.00
0005432383900	31266	Economy	6300.00
0005432329538	31266	Economy	6300.00
0005432329535	31266	Economy	6300.00
0005432383893	31266	Economy	6300.00
0005432329579	31266	Economy	6300.00
0005432383906	31266	Economy	6300.00
0005432329561	31266	Economy	6300.00
0005432329548	31266	Economy	6300.00
0005432329545	31266	Economy	6300.00
0005432287283	31266	Economy	6300.00
0005432383908	31266	Economy	6300.00
0005432383887	31266	Economy	6300.00
0005432329570	31266	Economy	6300.00
0005432383885	31266	Economy	6300.00
0005432383912	31266	Economy	6300.00
0005432383878	31266	Economy	6300.00
0005432329557	31266	Economy	6300.00
0005432383896	31266	Economy	6300.00
0005432329575	31266	Economy	6300.00
0005432329573	31266	Economy	6300.00
0005432383904	31266	Economy	6300.00
0005432425369	13268	Business	12700.00
0005432425341	13268	Business	12700.00
0005432425349	13268	Business	12700.00
0005432425359	13268	Business	12700.00
0005432425346	13268	Economy	4200.00
0005432425371	13268	Economy	4200.00
0005432425364	13268	Economy	4700.00
0005432425368	13268	Economy	4700.00
0005432425338	13268	Economy	4700.00
0005432425352	13268	Economy	4200.00
0005432425375	13268	Economy	4200.00
0005432425339	13268	Economy	4200.00
0005432425347	13268	Economy	4200.00
0005432425354	13268	Economy	4200.00
0005432425373	13268	Economy	4200.00
0005432425372	13268	Economy	4200.00
0005432425358	13268	Economy	4200.00
0005432425365	13268	Economy	4200.00
0005432425337	13268	Economy	4200.00
0005432425355	13268	Economy	4200.00
0005432425361	13268	Economy	4200.00
0005432425370	13268	Economy	4200.00
0005432425340	13268	Economy	4200.00
0005432425357	13268	Economy	4200.00
0005432425344	13268	Economy	4200.00
0005432425336	13268	Economy	4200.00
0005432425345	13268	Economy	4200.00
0005432425366	13268	Economy	4200.00
0005432425376	13268	Economy	4200.00
0005432425353	13268	Economy	4200.00
0005432425360	13268	Economy	4200.00
0005432425350	13268	Economy	4200.00
0005432425367	13268	Economy	4200.00
0005432425348	13268	Economy	4200.00
0005432425351	13268	Economy	4200.00
0005432425356	13268	Economy	4200.00
0005432425343	13268	Economy	4200.00
0005432425362	13268	Economy	4200.00
0005432425342	13268	Economy	4200.00
0005432425377	13268	Economy	4200.00
0005432425363	13268	Economy	4200.00
0005432425374	13268	Economy	4200.00
0005432424948	30714	Business	12700.00
0005432424949	30714	Business	12700.00
0005432424593	30714	Business	12700.00
0005432424795	30714	Business	12700.00
0005432424942	30714	Business	12700.00
0005432424878	30714	Business	12700.00
0005432424842	30714	Economy	4200.00
0005432424873	30714	Economy	4200.00
0005432424813	30714	Economy	4200.00
0005432424898	30714	Economy	4200.00
0005432424594	30714	Economy	4200.00
0005432424852	30714	Economy	4200.00
0005432424772	30714	Economy	4700.00
0005432424871	30714	Economy	4700.00
0005432424884	30714	Economy	4200.00
0005432424961	30714	Economy	4200.00
0005432424840	30714	Economy	4200.00
0005432424732	30714	Economy	4200.00
0005432424885	30714	Economy	4200.00
0005432424926	30714	Economy	4200.00
0005432424877	30714	Economy	4200.00
0005432424907	30714	Economy	4200.00
0005432424784	30714	Economy	4200.00
0005432424927	30714	Economy	4200.00
0005432424874	30714	Economy	4200.00
0005432424910	30714	Economy	4200.00
0005432424932	30714	Economy	4200.00
0005432424887	30714	Economy	4200.00
0005432424870	30714	Economy	4200.00
0005432424737	30714	Economy	4200.00
0005432424765	30714	Economy	4200.00
0005432424888	30714	Economy	4200.00
0005432424838	30714	Economy	4200.00
0005432424830	30714	Economy	4200.00
0005432424851	30714	Economy	4200.00
0005432424899	30714	Economy	4200.00
0005432424839	30714	Economy	4200.00
0005432424933	30714	Economy	4200.00
0005432424955	30714	Economy	4200.00
0005432424950	30714	Economy	4200.00
0005432424879	30714	Economy	4200.00
0005432424636	30714	Economy	4200.00
0005432424913	30714	Economy	4200.00
0005432424789	30714	Economy	4200.00
0005432424788	30714	Economy	4200.00
0005432424956	30714	Economy	4200.00
0005432424841	30714	Economy	4200.00
0005432424941	30714	Economy	4200.00
0005432818060	9600	Business	32600.00
0005432818032	9600	Business	32600.00
0005432901805	9600	Business	32600.00
0005432818059	9600	Business	32600.00
0005432818044	9600	Business	32600.00
0005432818056	9600	Business	32600.00
0005432822354	9600	Business	32600.00
0005432901847	9600	Business	32600.00
0005434157585	9600	Business	32600.00
0005432901792	9600	Economy	10900.00
0005432822350	9600	Economy	10900.00
0005434157584	9600	Economy	10900.00
0005434157583	9600	Economy	10900.00
0005432901785	9600	Economy	10900.00
0005432901828	9600	Economy	10900.00
0005432818036	9600	Economy	10900.00
0005432901836	9600	Economy	11900.00
0005434448383	9600	Economy	11900.00
0005432818055	9600	Economy	11900.00
0005432818052	9600	Economy	11900.00
0005432818037	9600	Economy	10900.00
0005432818046	9600	Economy	10900.00
0005432818045	9600	Economy	10900.00
0005432901854	9600	Economy	10900.00
0005432818033	9600	Economy	10900.00
0005432901850	9600	Economy	10900.00
0005432818039	9600	Economy	10900.00
0005432818035	9600	Economy	10900.00
0005432901885	9600	Economy	10900.00
0005432818049	9600	Economy	10900.00
0005432901789	9600	Economy	10900.00
0005432822351	9600	Economy	10900.00
0005432822349	9600	Economy	10900.00
0005434157582	9600	Economy	10900.00
0005432818041	9600	Economy	10900.00
0005432901802	9600	Economy	10900.00
0005432818053	9600	Economy	10900.00
0005432818051	9600	Economy	10900.00
0005434448382	9600	Economy	10900.00
0005432818058	9600	Economy	10900.00
0005432822353	9600	Economy	10900.00
0005432901786	9600	Economy	10900.00
0005432818047	9600	Economy	10900.00
0005432818050	9600	Economy	10900.00
0005432822352	9600	Economy	10900.00
0005432818048	9600	Economy	10900.00
0005432818038	9600	Economy	10900.00
0005432818043	9600	Economy	10900.00
0005432818061	9600	Economy	10900.00
0005432289049	9600	Economy	10900.00
0005432289051	9600	Economy	10900.00
0005434157591	9600	Economy	10900.00
0005432822356	9600	Economy	10900.00
0005432901803	9600	Economy	10900.00
0005432818034	9600	Economy	10900.00
0005432901804	9600	Economy	10900.00
0005432901794	9600	Economy	10900.00
0005432901877	9600	Economy	10900.00
0005434186234	9600	Economy	10900.00
0005432901849	9600	Economy	10900.00
0005432289050	9600	Economy	10900.00
0005432818040	9600	Economy	10900.00
0005432818057	9600	Economy	10900.00
0005432818042	9600	Economy	10900.00
0005432901777	9600	Economy	10900.00
0005432818054	9600	Economy	10900.00
0005434157553	9600	Economy	10900.00
0005432901848	9600	Economy	10900.00
0005432822355	9600	Economy	10900.00
0005434157592	9600	Economy	10900.00
0005432901820	9600	Economy	10900.00
0005432901852	9600	Economy	10900.00
0005432817617	28997	Business	32600.00
0005434157630	28997	Business	32600.00
0005434448338	28997	Business	32600.00
0005432901954	28997	Business	32600.00
0005432817867	28997	Business	32600.00
0005432822293	28997	Business	32600.00
0005434448349	28997	Business	32600.00
0005432817777	28997	Business	32600.00
0005432817857	28997	Business	32600.00
0005432901947	28997	Business	32600.00
0005432817819	28997	Business	32600.00
0005434157627	28997	Economy	10900.00
0005432901955	28997	Economy	10900.00
0005432817830	28997	Economy	10900.00
0005432822287	28997	Economy	10900.00
0005432901956	28997	Economy	10900.00
0005432901945	28997	Economy	10900.00
0005432822322	28997	Economy	10900.00
0005432822301	28997	Economy	10900.00
0005432822300	28997	Economy	10900.00
0005432817698	28997	Economy	10900.00
0005432901942	28997	Economy	11900.00
0005432901944	28997	Economy	11900.00
0005432901948	28997	Economy	11900.00
0005432822268	28997	Economy	11900.00
0005434186254	28997	Economy	10900.00
0005432817699	28997	Economy	10900.00
0005432817936	28997	Economy	10900.00
0005432817937	28997	Economy	10900.00
0005434448360	28997	Economy	10900.00
0005432817866	28997	Economy	10900.00
0005432817800	28997	Economy	10900.00
0005432822299	28997	Economy	10900.00
0005434157631	28997	Economy	10900.00
0005432817873	28997	Economy	10900.00
0005432817789	28997	Economy	10900.00
0005432817760	28997	Economy	10900.00
0005432901951	28997	Economy	10900.00
0005434448348	28997	Economy	10900.00
0005432817718	28997	Economy	10900.00
0005432817968	28997	Economy	10900.00
0005432822266	28997	Economy	10900.00
0005432817797	28997	Economy	10900.00
0005432901943	28997	Economy	10900.00
0005432817794	28997	Economy	10900.00
0005434157628	28997	Economy	10900.00
0005434157633	28997	Economy	10900.00
0005432817803	28997	Economy	10900.00
0005432817764	28997	Economy	10900.00
0005432817776	28997	Economy	10900.00
0005432901952	28997	Economy	10900.00
0005432822279	28997	Economy	10900.00
0005432901957	28997	Economy	10900.00
0005434186253	28997	Economy	10900.00
0005432822267	28997	Economy	10900.00
0005432901941	28997	Economy	10900.00
0005434448339	28997	Economy	10900.00
0005432822321	28997	Economy	10900.00
0005434157632	28997	Economy	10900.00
0005432901953	28997	Economy	10900.00
0005432817801	28997	Economy	10900.00
0005432901946	28997	Economy	10900.00
0005432817836	28997	Economy	10900.00
0005432817802	28997	Economy	10900.00
0005432817790	28997	Economy	10900.00
0005434157629	28997	Economy	10900.00
0005432817763	28997	Economy	10900.00
0005432817919	28997	Economy	10900.00
0005434448340	28997	Economy	10900.00
0005432817780	28997	Economy	10900.00
0005432817837	28997	Economy	10900.00
0005434186255	28997	Economy	10900.00
0005432901949	28997	Economy	10900.00
0005432817618	28997	Economy	10900.00
0005434157634	28997	Economy	10900.00
0005432822294	28997	Economy	10900.00
0005432002116	28997	Economy	10900.00
0005432817719	28997	Economy	10900.00
0005432002117	28997	Economy	10900.00
0005432901958	28997	Economy	10900.00
0005432817829	28997	Economy	10900.00
0005432822295	28997	Economy	10900.00
0005432901950	28997	Economy	10900.00
0005432817796	28997	Economy	10900.00
0005432613943	15086	Economy	11000.00
0005432613942	15086	Economy	11000.00
0005432611780	15086	Economy	11000.00
0005432613940	15086	Economy	11000.00
0005432613944	15086	Economy	11000.00
0005432611778	15086	Economy	11000.00
0005432611779	15086	Economy	11000.00
0005432613941	15086	Economy	11000.00
0005432607609	31587	Economy	11000.00
0005432607581	31587	Economy	11000.00
0005432607601	31587	Economy	11000.00
0005432607605	31587	Economy	11000.00
0005432611742	31587	Economy	11000.00
0005432607608	31587	Economy	11000.00
0005432607582	31587	Economy	11000.00
0005432607600	31587	Economy	11000.00
0005432607604	31587	Economy	11000.00
0005432607622	31587	Economy	11000.00
0005432607603	31587	Economy	11000.00
0005433570157	11861	Business	105900.00
0005432948997	11861	Business	105900.00
0005432948860	11861	Business	105900.00
0005432948844	11861	Business	105900.00
0005433570200	11861	Business	105900.00
0005433570153	11861	Business	105900.00
0005432948758	11861	Business	105900.00
0005432948687	11861	Business	105900.00
0005432948805	11861	Business	105900.00
0005433570174	11861	Business	105900.00
0005432948996	11861	Business	105900.00
0005433570175	11861	Business	105900.00
0005433570195	11861	Business	105900.00
0005432948798	11861	Business	105900.00
0005433570171	11861	Business	105900.00
0005433570166	11861	Business	105900.00
0005433570164	11861	Business	105900.00
0005432948693	11861	Business	105900.00
0005433570152	11861	Business	105900.00
0005432948831	11861	Economy	35300.00
0005432948774	11861	Business	105900.00
0005433570186	11861	Economy	35300.00
0005433570188	11861	Economy	35300.00
0005432948718	11861	Economy	35300.00
0005432948891	11861	Economy	35300.00
0005432948838	11861	Economy	35300.00
0005432948725	11861	Economy	35300.00
0005433570170	11861	Economy	35300.00
0005432948946	11861	Economy	35300.00
0005432948837	11861	Economy	35300.00
0005432948715	11861	Economy	35300.00
0005433570182	11861	Economy	35300.00
0005432948820	11861	Economy	35300.00
0005433570172	11861	Economy	38800.00
0005433570197	11861	Economy	38800.00
0005432948862	11861	Economy	38800.00
0005433570173	11861	Economy	38800.00
0005433570161	11861	Economy	35300.00
0005432948839	11861	Economy	35300.00
0005433570163	11861	Economy	35300.00
0005433570183	11861	Economy	35300.00
0005433570191	11861	Economy	35300.00
0005432948716	11861	Economy	35300.00
0005432948906	11861	Economy	35300.00
0005432948885	11861	Economy	35300.00
0005433570155	11861	Economy	35300.00
0005433570208	11861	Economy	35300.00
0005432948623	11861	Economy	35300.00
0005432948908	11861	Economy	35300.00
0005433570180	11861	Economy	35300.00
0005433570176	11861	Economy	35300.00
0005433570190	11861	Economy	35300.00
0005432948804	11861	Economy	35300.00
0005433570151	11861	Economy	35300.00
0005432948692	11861	Economy	35300.00
0005432948809	11861	Economy	35300.00
0005433570202	11861	Economy	35300.00
0005433570187	11861	Economy	35300.00
0005433570192	11861	Economy	35300.00
0005433570207	11861	Economy	35300.00
0005432948928	11861	Economy	35300.00
0005432948783	11861	Economy	35300.00
0005433570204	11861	Economy	35300.00
0005433570168	11861	Economy	35300.00
0005433570205	11861	Economy	35300.00
0005432948834	11861	Economy	35300.00
0005432948899	11861	Economy	35300.00
0005433570213	11861	Economy	35300.00
0005433570211	11861	Economy	35300.00
0005432948789	11861	Economy	35300.00
0005432948886	11861	Economy	35300.00
0005432948779	11861	Economy	35300.00
0005432948775	11861	Economy	35300.00
0005433570214	11861	Economy	35300.00
0005432948929	11861	Economy	35300.00
0005433570196	11861	Economy	35300.00
0005433570189	11861	Economy	35300.00
0005433570215	11861	Economy	35300.00
0005433570185	11861	Economy	35300.00
0005432948878	11861	Economy	35300.00
0005432948843	11861	Economy	35300.00
0005432948835	11861	Economy	35300.00
0005433570201	11861	Economy	35300.00
0005433570167	11861	Economy	35300.00
0005432948726	11861	Economy	35300.00
0005432949049	11861	Economy	35300.00
0005433570159	11861	Economy	35300.00
0005432948884	11861	Economy	35300.00
0005433570150	11861	Economy	35300.00
0005433570169	11861	Economy	35300.00
0005433570181	11861	Economy	35300.00
0005432948898	11861	Economy	35300.00
0005433570178	11861	Economy	35300.00
0005432948762	11861	Economy	35300.00
0005433570177	11861	Economy	35300.00
0005433570198	11861	Economy	35300.00
0005433570209	11861	Economy	35300.00
0005433570179	11861	Economy	35300.00
0005433570156	11861	Economy	35300.00
0005433570210	11861	Economy	35300.00
0005433570162	11861	Economy	35300.00
0005433570154	11861	Economy	35300.00
0005433570184	11861	Economy	35300.00
0005433570203	11861	Economy	35300.00
0005432948863	11861	Economy	35300.00
0005433570193	11861	Economy	35300.00
0005433570212	11861	Economy	35300.00
0005433570165	11861	Economy	35300.00
0005432948850	11861	Economy	35300.00
0005433570206	11861	Economy	35300.00
0005432948832	11861	Economy	35300.00
0005432948883	11861	Economy	35300.00
0005433570160	11861	Economy	35300.00
0005433570199	11861	Economy	35300.00
0005433570158	11861	Economy	35300.00
0005433570194	11861	Economy	35300.00
0005432949279	25300	Business	105900.00
0005433569586	25300	Business	105900.00
0005433569478	25300	Business	105900.00
0005433569720	25300	Business	105900.00
0005432949290	25300	Business	105900.00
0005432949275	25300	Business	105900.00
0005432949282	25300	Business	105900.00
0005432949278	25300	Business	105900.00
0005433569691	25300	Business	105900.00
0005432949283	25300	Business	105900.00
0005433569302	25300	Business	105900.00
0005432949286	25300	Business	105900.00
0005432949269	25300	Business	105900.00
0005433569742	25300	Business	105900.00
0005433569243	25300	Business	105900.00
0005433569737	25300	Business	105900.00
0005432949298	25300	Business	105900.00
0005433569825	25300	Business	105900.00
0005433569510	25300	Economy	35300.00
0005433569718	25300	Economy	35300.00
0005432949297	25300	Economy	35300.00
0005433569604	25300	Economy	35300.00
0005432949304	25300	Economy	35300.00
0005433569756	25300	Economy	35300.00
0005433569714	25300	Economy	35300.00
0005433569611	25300	Economy	35300.00
0005433569622	25300	Economy	35300.00
0005433569383	25300	Economy	35300.00
0005432949295	25300	Economy	35300.00
0005432949270	25300	Economy	35300.00
0005433569667	25300	Economy	38800.00
0005432949302	25300	Economy	38800.00
0005433569757	25300	Economy	38800.00
0005432949288	25300	Economy	35300.00
0005433569743	25300	Economy	38800.00
0005433569631	25300	Economy	35300.00
0005433569713	25300	Economy	35300.00
0005433569836	25300	Economy	35300.00
0005432949277	25300	Economy	35300.00
0005432949287	25300	Economy	35300.00
0005433569551	25300	Economy	35300.00
0005433569355	25300	Economy	35300.00
0005433569668	25300	Economy	35300.00
0005432949281	25300	Economy	35300.00
0005433569547	25300	Economy	35300.00
0005433569861	25300	Economy	35300.00
0005432949299	25300	Economy	35300.00
0005433569683	25300	Economy	35300.00
0005432949268	25300	Economy	35300.00
0005433569739	25300	Economy	35300.00
0005432949306	25300	Economy	35300.00
0005432949307	25300	Economy	35300.00
0005433569605	25300	Economy	35300.00
0005433569394	25300	Economy	35300.00
0005433569462	25300	Economy	35300.00
0005433569660	25300	Economy	35300.00
0005433569645	25300	Economy	35300.00
0005432949274	25300	Economy	35300.00
0005432949293	25300	Economy	35300.00
0005432949276	25300	Economy	35300.00
0005433569661	25300	Economy	35300.00
0005433569862	25300	Economy	35300.00
0005433569479	25300	Economy	35300.00
0005432949296	25300	Economy	35300.00
0005433569613	25300	Economy	35300.00
0005433569242	25300	Economy	35300.00
0005433569741	25300	Economy	35300.00
0005433569658	25300	Economy	35300.00
0005432949289	25300	Economy	35300.00
0005433569618	25300	Economy	35300.00
0005432949284	25300	Economy	35300.00
0005432949292	25300	Economy	35300.00
0005432949301	25300	Economy	35300.00
0005433569738	25300	Economy	35300.00
0005432949271	25300	Economy	35300.00
0005433569542	25300	Economy	35300.00
0005433569758	25300	Economy	35300.00
0005433569543	25300	Economy	35300.00
0005432949305	25300	Economy	35300.00
0005433569599	25300	Economy	35300.00
0005433569532	25300	Economy	35300.00
0005433569450	25300	Economy	35300.00
0005433569449	25300	Economy	35300.00
0005433569559	25300	Economy	35300.00
0005433569638	25300	Economy	35300.00
0005432949303	25300	Economy	35300.00
0005433569644	25300	Economy	35300.00
0005433569657	25300	Economy	35300.00
0005433569637	25300	Economy	35300.00
0005433569740	25300	Economy	35300.00
0005433569585	25300	Economy	35300.00
0005432949280	25300	Economy	35300.00
0005433569461	25300	Economy	35300.00
0005433569643	25300	Economy	35300.00
0005432949273	25300	Economy	35300.00
0005432949272	25300	Economy	35300.00
0005432949300	25300	Economy	35300.00
0005433569684	25300	Economy	35300.00
0005432949285	25300	Economy	35300.00
0005432949266	25300	Economy	35300.00
0005432949267	25300	Economy	35300.00
0005433569690	25300	Economy	35300.00
0005432949291	25300	Economy	35300.00
0005433569735	25300	Economy	35300.00
0005432949294	25300	Economy	35300.00
0005433569666	25300	Economy	35300.00
0005433811647	27940	Business	105400.00
0005433811644	27940	Business	105400.00
0005433811655	27940	Economy	35100.00
0005433811643	27940	Economy	35100.00
0005433811652	27940	Economy	35100.00
0005433927517	27940	Economy	35100.00
0005433811646	27940	Economy	38600.00
0005433811634	27940	Economy	35100.00
0005433811654	27940	Economy	35100.00
0005433811639	27940	Economy	35100.00
0005433811648	27940	Economy	35100.00
0005433811656	27940	Economy	35100.00
0005433811638	27940	Economy	35100.00
0005434655253	5392	Business	67200.00
0005434655255	5392	Business	67200.00
0005434655252	5392	Business	67200.00
0005434656594	5392	Business	67200.00
0005434655259	5392	Economy	22400.00
0005434655241	5392	Economy	22400.00
0005434655264	5392	Economy	22400.00
0005435340488	5392	Economy	22400.00
0005434655237	5392	Economy	22400.00
0005434655239	5392	Economy	22400.00
0005432114265	5392	Economy	22400.00
0005434655267	5392	Economy	22400.00
0005434655247	5392	Economy	24600.00
0005434655266	5392	Economy	24600.00
0005434655261	5392	Economy	24600.00
0005434655258	5392	Economy	22400.00
0005434655262	5392	Economy	22400.00
0005434655260	5392	Economy	22400.00
0005434655240	5392	Economy	22400.00
0005434655256	5392	Economy	22400.00
0005434655243	5392	Economy	22400.00
0005434655254	5392	Economy	22400.00
0005434655246	5392	Economy	22400.00
0005434655245	5392	Economy	22400.00
0005434655257	5392	Economy	22400.00
0005435340474	5392	Economy	22400.00
0005434655265	5392	Economy	22400.00
0005434655242	5392	Economy	22400.00
0005434655249	5392	Economy	22400.00
0005434655251	5392	Economy	22400.00
0005435340461	5392	Economy	22400.00
0005432114264	5392	Economy	22400.00
0005435340479	5392	Economy	22400.00
0005434655263	5392	Economy	22400.00
0005434655244	5392	Economy	22400.00
0005434656595	5392	Economy	22400.00
0005434655248	5392	Economy	22400.00
0005435340408	5392	Economy	22400.00
0005432114266	5392	Economy	22400.00
0005435340433	5392	Economy	22400.00
0005434655250	5392	Economy	22400.00
0005435340435	5392	Economy	22400.00
0005435340399	5392	Economy	22400.00
0005434655238	5392	Economy	22400.00
0005435340436	5392	Economy	22400.00
0005432114267	5392	Economy	22400.00
0005434654912	12541	Business	67200.00
0005434655026	12541	Business	67200.00
0005434655027	12541	Business	67200.00
0005434655018	12541	Business	67200.00
0005434655028	12541	Business	67200.00
0005434654949	12541	Business	67200.00
0005435340554	12541	Business	67200.00
0005435340561	12541	Business	67200.00
0005434654953	12541	Business	67200.00
0005434656579	12541	Economy	22400.00
0005434655022	12541	Economy	22400.00
0005435340551	12541	Economy	22400.00
0005434655050	12541	Economy	22400.00
0005434654987	12541	Economy	22400.00
0005434655040	12541	Economy	22400.00
0005434654992	12541	Economy	24600.00
0005434654911	12541	Economy	24600.00
0005435555411	12541	Economy	22400.00
0005434654952	12541	Economy	22400.00
0005434655110	12541	Economy	22400.00
0005434654929	12541	Economy	22400.00
0005435340556	12541	Economy	22400.00
0005434654876	12541	Economy	22400.00
0005435340559	12541	Economy	22400.00
0005435340562	12541	Economy	22400.00
0005435340565	12541	Economy	22400.00
0005434655109	12541	Economy	22400.00
0005434654877	12541	Economy	22400.00
0005434654975	12541	Economy	22400.00
0005434655039	12541	Economy	22400.00
0005435340558	12541	Economy	22400.00
0005435340557	12541	Economy	22400.00
0005435555412	12541	Economy	22400.00
0005435340555	12541	Economy	22400.00
0005434656573	12541	Economy	22400.00
0005435340564	12541	Economy	22400.00
0005434654986	12541	Economy	22400.00
0005435340560	12541	Economy	22400.00
0005435340563	12541	Economy	22400.00
0005434656574	12541	Economy	22400.00
0005435340553	12541	Economy	22400.00
0005435340552	12541	Economy	22400.00
0005434655023	12541	Economy	22400.00
0005434656580	12541	Economy	22400.00
0005434654882	12541	Economy	22400.00
0005433716940	7424	Business	32000.00
0005433716939	7424	Business	32000.00
0005433716913	7424	Business	32000.00
0005435266163	7424	Business	32000.00
0005433656732	7424	Business	32000.00
0005433716957	7424	Business	32000.00
0005433716952	7424	Economy	10700.00
0005433716927	7424	Business	32000.00
0005432078213	7424	Economy	10700.00
0005433688850	7424	Economy	10700.00
0005435266182	7424	Economy	10700.00
0005433719203	7424	Economy	10700.00
0005433716914	7424	Economy	10700.00
0005433688848	7424	Economy	10700.00
0005433716924	7424	Economy	10700.00
0005433716956	7424	Economy	10700.00
0005433719205	7424	Economy	10700.00
0005433719204	7424	Economy	10700.00
0005433716929	7424	Economy	10700.00
0005435266162	7424	Economy	10700.00
0005433716958	7424	Economy	10700.00
0005433716941	7424	Economy	10700.00
0005433722344	7424	Economy	10700.00
0005433716943	7424	Economy	10700.00
0005433722346	7424	Economy	10700.00
0005433689950	7424	Economy	10700.00
0005432428970	7424	Economy	10700.00
0005433690964	7424	Economy	10700.00
0005432078215	7424	Economy	10700.00
0005432428971	7424	Economy	10700.00
0005432078218	7424	Economy	10700.00
0005433716916	7424	Economy	10700.00
0005433690962	7424	Economy	10700.00
0005433716925	7424	Economy	11700.00
0005433716935	7424	Economy	11700.00
0005433722343	7424	Economy	11700.00
0005433690963	7424	Economy	10700.00
0005433716926	7424	Economy	10700.00
0005432428962	7424	Economy	10700.00
0005433716915	7424	Economy	10700.00
0005433716949	7424	Economy	10700.00
0005432428965	7424	Economy	10700.00
0005433716937	7424	Economy	10700.00
0005433716911	7424	Economy	10700.00
0005433716921	7424	Economy	10700.00
0005433716928	7424	Economy	10700.00
0005433716946	7424	Economy	10700.00
0005433716932	7424	Economy	10700.00
0005433716959	7424	Economy	10700.00
0005433716955	7424	Economy	10700.00
0005433656734	7424	Economy	10700.00
0005433716950	7424	Economy	10700.00
0005433716936	7424	Economy	10700.00
0005432078217	7424	Economy	10700.00
0005432078214	7424	Economy	10700.00
0005432428969	7424	Economy	10700.00
0005433716922	7424	Economy	10700.00
0005433688849	7424	Economy	10700.00
0005433716953	7424	Economy	10700.00
0005433716944	7424	Economy	10700.00
0005433716919	7424	Economy	10700.00
0005433716960	7424	Economy	10700.00
0005433656733	7424	Economy	10700.00
0005433716938	7424	Economy	10700.00
0005433722345	7424	Economy	10700.00
0005433716917	7424	Economy	10700.00
0005433716920	7424	Economy	10700.00
0005433716930	7424	Economy	10700.00
0005433716948	7424	Economy	10700.00
0005432428966	7424	Economy	10700.00
0005432078216	7424	Economy	10700.00
0005433716954	7424	Economy	10700.00
0005433716947	7424	Economy	10700.00
0005432428968	7424	Economy	10700.00
0005433716923	7424	Economy	10700.00
0005433716951	7424	Economy	10700.00
0005432428948	7424	Economy	10700.00
0005433716945	7424	Economy	10700.00
0005433716912	7424	Economy	10700.00
0005433716931	7424	Economy	10700.00
0005433716910	7424	Economy	10700.00
0005432428967	7424	Economy	10700.00
0005433716942	7424	Economy	10700.00
0005433716933	7424	Economy	10700.00
0005433716934	7424	Economy	10700.00
0005433716918	7424	Economy	10700.00
0005433716423	29251	Business	32000.00
0005433716343	29251	Business	32000.00
0005433716586	29251	Business	32000.00
0005433688829	29251	Business	32000.00
0005433656710	29251	Business	32000.00
0005433716320	29251	Economy	10700.00
0005433685545	29251	Economy	10700.00
0005432428997	29251	Economy	10700.00
0005433716626	29251	Economy	10700.00
0005433722300	29251	Economy	10700.00
0005433722272	29251	Economy	10700.00
0005433716534	29251	Economy	10700.00
0005435266252	29251	Economy	10700.00
0005433716321	29251	Economy	10700.00
0005433716678	29251	Economy	10700.00
0005433722265	29251	Economy	10700.00
0005433656700	29251	Economy	10700.00
0005435266233	29251	Economy	10700.00
0005433716377	29251	Economy	10700.00
0005432006817	29251	Economy	10700.00
0005432006818	29251	Economy	10700.00
0005433716535	29251	Economy	10700.00
0005435266246	29251	Economy	10700.00
0005433716349	29251	Economy	10700.00
0005435546234	29251	Economy	10700.00
0005432006819	29251	Economy	10700.00
0005433716356	29251	Economy	10700.00
0005435266235	29251	Economy	10700.00
0005435266238	29251	Economy	10700.00
0005435266236	29251	Economy	10700.00
0005433716283	29251	Economy	10700.00
0005435266242	29251	Economy	10700.00
0005433716692	29251	Economy	10700.00
0005433716355	29251	Economy	10700.00
0005433716556	29251	Economy	10700.00
0005433716518	29251	Economy	10700.00
0005433716282	29251	Economy	10700.00
0005435266244	29251	Economy	10700.00
0005433656702	29251	Economy	10700.00
0005433716580	29251	Economy	11700.00
0005433722292	29251	Economy	10700.00
0005433716674	29251	Economy	10700.00
0005433716519	29251	Economy	10700.00
0005435266249	29251	Economy	10700.00
0005435266237	29251	Economy	10700.00
0005435266239	29251	Economy	10700.00
0005435546236	29251	Economy	10700.00
0005433716517	29251	Economy	10700.00
0005433716675	29251	Economy	10700.00
0005435266251	29251	Economy	10700.00
0005433716585	29251	Economy	10700.00
0005435266247	29251	Economy	10700.00
0005433716596	29251	Economy	10700.00
0005433716744	29251	Economy	10700.00
0005435266255	29251	Economy	10700.00
0005435266254	29251	Economy	10700.00
0005435266240	29251	Economy	10700.00
0005435266241	29251	Economy	10700.00
0005433716619	29251	Economy	10700.00
0005433716322	29251	Economy	10700.00
0005433722280	29251	Economy	10700.00
0005433685538	29251	Economy	10700.00
0005435266245	29251	Economy	10700.00
0005435266250	29251	Economy	10700.00
0005433716576	29251	Economy	10700.00
0005432428996	29251	Economy	10700.00
0005433716378	29251	Economy	10700.00
0005433716696	29251	Economy	10700.00
0005433656711	29251	Economy	10700.00
0005433716354	29251	Economy	10700.00
0005433716575	29251	Economy	10700.00
0005435266253	29251	Economy	10700.00
0005432006820	29251	Economy	10700.00
0005433716617	29251	Economy	10700.00
0005433722268	29251	Economy	10700.00
0005435266248	29251	Economy	10700.00
0005432428995	29251	Economy	10700.00
0005433656699	29251	Economy	10700.00
0005435266243	29251	Economy	10700.00
0005435546235	29251	Economy	10700.00
0005433716618	29251	Economy	10700.00
0005435266234	29251	Economy	10700.00
0005433688830	29251	Economy	10700.00
0005434095554	8710	Business	36500.00
0005434095561	8710	Business	36500.00
0005434095551	8710	Business	36500.00
0005434182351	8710	Business	36500.00
0005434182345	8710	Business	36500.00
0005434182272	8710	Economy	12200.00
0005434182385	8710	Economy	12200.00
0005434095549	8710	Economy	12200.00
0005434095553	8710	Economy	12200.00
0005434182368	8710	Economy	12200.00
0005434095550	8710	Economy	12200.00
0005434095559	8710	Economy	12200.00
0005434095552	8710	Economy	12200.00
0005434182352	8710	Economy	12200.00
0005434182321	8710	Economy	12200.00
0005434095555	8710	Economy	12200.00
0005434095547	8710	Economy	12200.00
0005434182315	8710	Economy	12200.00
0005434182303	8710	Economy	12200.00
0005434095548	8710	Economy	12200.00
0005434095560	8710	Economy	12200.00
0005434182341	8710	Economy	12200.00
0005434182346	8710	Economy	12200.00
0005434182318	8710	Economy	12200.00
0005434182353	8710	Economy	12200.00
0005434182384	8710	Economy	12200.00
0005434182332	8710	Economy	12200.00
0005434095558	8710	Economy	12200.00
0005434182340	8710	Economy	12200.00
0005434095556	8710	Economy	12200.00
0005434182354	8710	Economy	12200.00
0005434182314	8710	Economy	12200.00
0005434095557	8710	Economy	12200.00
0005434183618	11659	Business	36500.00
0005434095445	11659	Business	36500.00
0005434184703	11659	Business	36500.00
0005434182424	11659	Business	36500.00
0005434184704	11659	Business	36500.00
0005434182427	11659	Economy	12200.00
0005434182432	11659	Economy	12200.00
0005434182425	11659	Economy	12200.00
0005434182434	11659	Economy	12200.00
0005434182430	11659	Economy	13400.00
0005434095424	11659	Economy	12200.00
0005434183616	11659	Economy	12200.00
0005434095448	11659	Economy	12200.00
0005434184705	11659	Economy	12200.00
0005434182423	11659	Economy	12200.00
0005434095450	11659	Economy	12200.00
0005434095447	11659	Economy	12200.00
0005434095394	11659	Economy	12200.00
0005434182433	11659	Economy	12200.00
0005434182429	11659	Economy	12200.00
0005434183617	11659	Economy	12200.00
0005434095425	11659	Economy	12200.00
0005434182428	11659	Economy	12200.00
0005434182422	11659	Economy	12200.00
0005434095395	11659	Economy	12200.00
0005434095409	11659	Economy	12200.00
0005434182431	11659	Economy	12200.00
0005434095449	11659	Economy	12200.00
0005434182426	11659	Economy	12200.00
0005433398521	1417	Business	33000.00
0005435732567	1417	Business	33000.00
0005433398547	1417	Business	33000.00
0005433398274	1417	Business	33000.00
0005433398669	1417	Business	33000.00
0005433398497	1417	Business	33000.00
0005435732589	1417	Economy	11000.00
0005433457047	1417	Economy	11000.00
0005435732571	1417	Economy	11000.00
0005435732583	1417	Economy	11000.00
0005435732575	1417	Economy	11000.00
0005435732576	1417	Economy	11000.00
0005433398392	1417	Economy	11000.00
0005433457049	1417	Economy	12100.00
0005433398545	1417	Economy	12100.00
0005433398438	1417	Economy	12100.00
0005435732579	1417	Economy	12100.00
0005433398499	1417	Economy	11000.00
0005433398651	1417	Economy	11000.00
0005435732590	1417	Economy	11000.00
0005433457050	1417	Economy	11000.00
0005432297329	1417	Economy	11000.00
0005433398520	1417	Economy	11000.00
0005433398596	1417	Economy	11000.00
0005433398378	1417	Economy	11000.00
0005433398391	1417	Economy	11000.00
0005432906551	1417	Economy	11000.00
0005435732573	1417	Economy	11000.00
0005433398648	1417	Economy	11000.00
0005433398431	1417	Economy	11000.00
0005435732572	1417	Economy	11000.00
0005435732577	1417	Economy	11000.00
0005433398552	1417	Economy	11000.00
0005433398562	1417	Economy	11000.00
0005433398618	1417	Economy	11000.00
0005435732574	1417	Economy	11000.00
0005433398451	1417	Economy	11000.00
0005435732586	1417	Economy	11000.00
0005435732584	1417	Economy	11000.00
0005433398652	1417	Economy	11000.00
0005433398659	1417	Economy	11000.00
0005433398522	1417	Economy	11000.00
0005435732585	1417	Economy	11000.00
0005432297327	1417	Economy	11000.00
0005433398775	1417	Economy	11000.00
0005433398381	1417	Economy	11000.00
0005433398440	1417	Economy	11000.00
0005435732582	1417	Economy	11000.00
0005435732568	1417	Economy	11000.00
0005433398719	1417	Economy	11000.00
0005433398617	1417	Economy	11000.00
0005435732581	1417	Economy	11000.00
0005433398544	1417	Economy	11000.00
0005433457048	1417	Economy	11000.00
0005433398649	1417	Economy	11000.00
0005435732580	1417	Economy	11000.00
0005435732569	1417	Economy	11000.00
0005435732570	1417	Economy	11000.00
0005432906563	1417	Economy	11000.00
0005435732578	1417	Economy	11000.00
0005433398575	1417	Economy	11000.00
0005432297328	1417	Economy	11000.00
0005433398273	1417	Economy	11000.00
0005435732588	1417	Economy	11000.00
0005435732587	1417	Economy	11000.00
0005433398563	1417	Economy	11000.00
0005433398566	1417	Economy	11000.00
0005433398972	19252	Business	33000.00
0005435732467	19252	Business	33000.00
0005433399005	19252	Business	33000.00
0005433398978	19252	Business	33000.00
0005433398990	19252	Business	33000.00
0005435732454	19252	Business	33000.00
0005433398997	19252	Business	33000.00
0005435732472	19252	Business	33000.00
0005435732471	19252	Business	33000.00
0005433398980	19252	Business	33000.00
0005433399002	19252	Economy	11000.00
0005435732493	19252	Economy	11000.00
0005433399017	19252	Economy	11000.00
0005435732494	19252	Economy	11000.00
0005433398985	19252	Economy	11000.00
0005433399010	19252	Economy	11000.00
0005433399016	19252	Economy	11000.00
0005433398999	19252	Economy	12100.00
0005433398994	19252	Economy	12100.00
0005432906582	19252	Economy	12100.00
0005433398998	19252	Economy	12100.00
0005433399013	19252	Economy	12100.00
0005433398984	19252	Economy	11000.00
0005433398993	19252	Economy	11000.00
0005435732539	19252	Economy	11000.00
0005435732511	19252	Economy	11000.00
0005433398996	19252	Economy	11000.00
0005433399004	19252	Economy	11000.00
0005433399009	19252	Economy	11000.00
0005435732499	19252	Economy	11000.00
0005433398983	19252	Economy	11000.00
0005433398995	19252	Economy	11000.00
0005433399006	19252	Economy	11000.00
0005433398992	19252	Economy	11000.00
0005435732466	19252	Economy	11000.00
0005435732402	19252	Economy	11000.00
0005432906584	19252	Economy	11000.00
0005433398982	19252	Economy	11000.00
0005435732476	19252	Economy	11000.00
0005433398988	19252	Economy	11000.00
0005435732520	19252	Economy	11000.00
0005433399012	19252	Economy	11000.00
0005433398976	19252	Economy	11000.00
0005435732468	19252	Economy	11000.00
0005433398971	19252	Economy	11000.00
0005433398974	19252	Economy	11000.00
0005433398981	19252	Economy	11000.00
0005432906583	19252	Economy	11000.00
0005435732484	19252	Economy	11000.00
0005433398987	19252	Economy	11000.00
0005433398979	19252	Economy	11000.00
0005433398975	19252	Economy	11000.00
0005433399014	19252	Economy	11000.00
0005433399018	19252	Economy	11000.00
0005435732503	19252	Economy	11000.00
0005432906585	19252	Economy	11000.00
0005433399000	19252	Economy	11000.00
0005433398986	19252	Economy	11000.00
0005435732415	19252	Economy	11000.00
0005433398970	19252	Economy	11000.00
0005433398973	19252	Economy	11000.00
0005435732414	19252	Economy	11000.00
0005433398991	19252	Economy	11000.00
0005433399011	19252	Economy	11000.00
0005433398977	19252	Economy	11000.00
0005433399001	19252	Economy	11000.00
0005433399003	19252	Economy	11000.00
0005435732477	19252	Economy	11000.00
0005433398969	19252	Economy	11000.00
0005433399007	19252	Economy	11000.00
0005433398989	19252	Economy	11000.00
0005433399008	19252	Economy	11000.00
0005433398968	19252	Economy	11000.00
0005433399015	19252	Economy	11000.00
0005435732483	19252	Economy	11000.00
0005434443867	17344	Economy	14100.00
0005434443840	17344	Economy	14100.00
0005434443887	17344	Economy	14100.00
0005434443847	17344	Economy	14100.00
0005434443824	17344	Economy	14100.00
0005434443843	17344	Economy	14100.00
0005434443902	17344	Economy	14100.00
0005434443856	17344	Economy	14100.00
0005434443846	17344	Economy	14100.00
0005434444012	20596	Economy	15600.00
0005434444017	20596	Economy	15600.00
0005434444006	20596	Economy	14100.00
0005434444018	20596	Economy	14100.00
0005434444014	20596	Economy	14100.00
0005434444013	20596	Economy	14100.00
0005434444008	20596	Economy	14100.00
0005434444005	20596	Economy	14100.00
0005434444015	20596	Economy	14100.00
0005434444009	20596	Economy	14100.00
0005434444007	20596	Economy	14100.00
0005434444016	20596	Economy	14100.00
0005434444010	20596	Economy	14100.00
0005434444011	20596	Economy	14100.00
0005434444004	20596	Economy	14100.00
0005434954683	7256	Economy	5800.00
0005435377604	7256	Economy	5800.00
0005434954684	7256	Economy	5800.00
0005435377606	7256	Economy	5800.00
0005434954686	7256	Economy	5800.00
0005434954685	7256	Economy	5800.00
0005435377605	7256	Economy	5800.00
0005435377603	7256	Economy	5800.00
0005435377624	28304	Economy	5800.00
0005434954653	28304	Economy	5800.00
0005435377626	28304	Economy	5800.00
0005435377625	28304	Economy	5800.00
0005434954662	28304	Economy	5800.00
0005434351947	4478	Economy	15400.00
0005434351946	4478	Economy	15400.00
0005434351940	4478	Economy	15400.00
0005434351942	4478	Economy	14000.00
0005434351936	4478	Economy	14000.00
0005434351944	4478	Economy	14000.00
0005434351938	4478	Economy	14000.00
0005435893717	4478	Economy	14000.00
0005435893704	4478	Economy	14000.00
0005435893703	4478	Economy	14000.00
0005434183593	4478	Economy	14000.00
0005434351948	4478	Economy	14000.00
0005434351937	4478	Economy	14000.00
0005434351943	4478	Economy	14000.00
0005435893716	4478	Economy	14000.00
0005435893710	4478	Economy	14000.00
0005434351939	4478	Economy	14000.00
0005434183597	4478	Economy	14000.00
0005435893715	4478	Economy	14000.00
0005434183599	4478	Economy	14000.00
0005434183598	4478	Economy	14000.00
0005434351945	4478	Economy	14000.00
0005434351941	4478	Economy	14000.00
0005434351808	29631	Economy	15400.00
0005435893766	29631	Economy	15400.00
0005434351802	29631	Economy	14000.00
0005435893771	29631	Economy	14000.00
0005434351807	29631	Economy	14000.00
0005434351809	29631	Economy	14000.00
0005435893772	29631	Economy	14000.00
0005434351840	29631	Economy	14000.00
0005434351841	29631	Economy	14000.00
0005435893770	29631	Economy	14000.00
0005434351780	29631	Economy	14000.00
0005434351803	29631	Economy	14000.00
0005435893768	29631	Economy	14000.00
0005435893773	29631	Economy	14000.00
0005435893769	29631	Economy	14000.00
0005435893767	29631	Economy	14000.00
0005434446565	1059	Business	30600.00
0005433344408	1059	Business	30600.00
0005435092270	1059	Business	30600.00
0005435092265	1059	Business	30600.00
0005433344239	1059	Business	30600.00
0005433343762	1059	Business	30600.00
0005433344032	1059	Business	30600.00
0005433344304	1059	Business	30600.00
0005433344153	1059	Business	30600.00
0005433344407	1059	Business	30600.00
0005433343973	1059	Business	30600.00
0005433462788	1059	Business	30600.00
0005434446564	1059	Business	30600.00
0005433344082	1059	Business	30600.00
0005433344134	1059	Business	30600.00
0005435545879	1059	Business	30600.00
0005433343761	1059	Business	30600.00
0005433344549	1059	Business	30600.00
0005433343755	1059	Business	30600.00
0005435092263	1059	Business	30600.00
0005435545875	1059	Business	30600.00
0005433344100	1059	Business	30600.00
0005433343791	1059	Economy	11200.00
0005433344228	1059	Business	30600.00
0005433343982	1059	Economy	11200.00
0005434446566	1059	Economy	11200.00
0005433344240	1059	Economy	10200.00
0005433344419	1059	Economy	10200.00
0005435545874	1059	Economy	10200.00
0005433343941	1059	Economy	10200.00
0005433343938	1059	Economy	10200.00
0005433343839	1059	Economy	10200.00
0005435092268	1059	Economy	10200.00
0005433344101	1059	Economy	10200.00
0005433344211	1059	Economy	10200.00
0005433343987	1059	Economy	10200.00
0005433343852	1059	Economy	10200.00
0005433343972	1059	Economy	10200.00
0005433344388	1059	Economy	10200.00
0005433343846	1059	Economy	10200.00
0005435545883	1059	Economy	10200.00
0005433344080	1059	Economy	10200.00
0005433462790	1059	Economy	10200.00
0005433344144	1059	Economy	10200.00
0005433343447	1059	Economy	10200.00
0005433344501	1059	Economy	10200.00
0005433344312	1059	Economy	10200.00
0005433463943	1059	Economy	10200.00
0005433343962	1059	Economy	10200.00
0005433462789	1059	Economy	10200.00
0005433343607	1059	Economy	10200.00
0005433344079	1059	Economy	10200.00
0005433344392	1059	Economy	10200.00
0005433344389	1059	Economy	10200.00
0005433343939	1059	Economy	10200.00
0005435092266	1059	Economy	10200.00
0005433344409	1059	Economy	10200.00
0005433344324	1059	Economy	10200.00
0005435545873	1059	Economy	10200.00
0005433344307	1059	Economy	10200.00
0005433344521	1059	Economy	10200.00
0005433343712	1059	Economy	10200.00
0005434445291	1059	Economy	10200.00
0005432293255	1059	Economy	10200.00
0005435545881	1059	Economy	10200.00
0005433344013	1059	Economy	10200.00
0005433344229	1059	Economy	10200.00
0005433343750	1059	Economy	10200.00
0005433344168	1059	Economy	10200.00
0005435545880	1059	Economy	10200.00
0005433344097	1059	Economy	10200.00
0005433344306	1059	Economy	10200.00
0005433344073	1059	Economy	10200.00
0005433344249	1059	Economy	10200.00
0005433343482	1059	Economy	10200.00
0005433344030	1059	Economy	10200.00
0005433343890	1059	Economy	10200.00
0005433344198	1059	Economy	10200.00
0005433463942	1059	Economy	10200.00
0005433344402	1059	Economy	10200.00
0005433344029	1059	Economy	10200.00
0005435545876	1059	Economy	10200.00
0005433344282	1059	Economy	10200.00
0005435092267	1059	Economy	10200.00
0005433344167	1059	Economy	10200.00
0005433344098	1059	Economy	10200.00
0005433344227	1059	Economy	10200.00
0005433344033	1059	Economy	10200.00
0005433343749	1059	Economy	10200.00
0005435092264	1059	Economy	10200.00
0005433269788	1059	Economy	10200.00
0005433343790	1059	Economy	10200.00
0005433344406	1059	Economy	11200.00
0005433344060	1059	Economy	10200.00
0005435545878	1059	Economy	10200.00
0005433344647	1059	Economy	11200.00
0005433343970	1059	Economy	10200.00
0005435092269	1059	Economy	10200.00
0005433344152	1059	Economy	10200.00
0005433343836	1059	Economy	10200.00
0005433269789	1059	Economy	10200.00
0005435545877	1059	Economy	10200.00
0005432293257	1059	Economy	10200.00
0005433269777	1059	Economy	10200.00
0005434445293	1059	Economy	10200.00
0005435092262	1059	Economy	10200.00
0005433344305	1059	Economy	10200.00
0005433344416	1059	Economy	10200.00
0005433344335	1059	Economy	10200.00
0005435092272	1059	Economy	10200.00
0005433344143	1059	Economy	10200.00
0005433344112	1059	Economy	10200.00
0005433344250	1059	Economy	10200.00
0005433269784	1059	Economy	10200.00
0005432293256	1059	Economy	10200.00
0005433269754	1059	Economy	10200.00
0005433344145	1059	Economy	10200.00
0005433269763	1059	Economy	10200.00
0005433344139	1059	Economy	10200.00
0005435545882	1059	Economy	10200.00
0005433344169	1059	Economy	10200.00
0005433343940	1059	Economy	10200.00
0005435092271	1059	Economy	10200.00
0005433344075	1059	Economy	10200.00
0005434446563	1059	Economy	10200.00
0005433343481	1059	Economy	10200.00
0005433344023	1059	Economy	10200.00
0005433344531	1059	Economy	10200.00
0005434446562	1059	Economy	10200.00
0005433344001	1059	Economy	10200.00
0005433344421	1059	Economy	10200.00
0005433343845	1059	Economy	10200.00
0005433269755	1059	Economy	10200.00
0005433158150	1059	Economy	10200.00
0005433343963	1059	Economy	10200.00
0005433344311	1059	Economy	10200.00
0005433343889	1059	Economy	10200.00
0005433343812	1059	Economy	10200.00
0005433269749	1059	Economy	10200.00
0005433344670	1059	Economy	10200.00
0005433344422	1059	Economy	10200.00
0005433344467	1059	Economy	10200.00
0005434445292	1059	Economy	10200.00
0005433343903	1059	Economy	10200.00
0005434445290	1059	Economy	10200.00
0005433344084	1059	Economy	10200.00
0005433158196	17029	Business	30600.00
0005433344977	17029	Business	30600.00
0005433345016	17029	Business	30600.00
0005435092220	17029	Business	30600.00
0005433345025	17029	Business	30600.00
0005433344962	17029	Business	30600.00
0005433344989	17029	Business	30600.00
0005433344992	17029	Business	30600.00
0005435508453	17029	Business	30600.00
0005433344981	17029	Business	30600.00
0005433344942	17029	Business	30600.00
0005433345017	17029	Business	30600.00
0005434445272	17029	Business	30600.00
0005435092193	17029	Business	30600.00
0005433344961	17029	Business	30600.00
0005433345005	17029	Business	30600.00
0005434445268	17029	Business	30600.00
0005433344987	17029	Business	30600.00
0005433345011	17029	Economy	11200.00
0005434445266	17029	Economy	11200.00
0005435508476	17029	Economy	11200.00
0005435508458	17029	Economy	10200.00
0005433345008	17029	Economy	10200.00
0005433345038	17029	Economy	10200.00
0005433344975	17029	Economy	10200.00
0005433344980	17029	Economy	10200.00
0005435508435	17029	Economy	10200.00
0005433345015	17029	Economy	10200.00
0005433344970	17029	Economy	10200.00
0005433344979	17029	Economy	10200.00
0005433345020	17029	Economy	10200.00
0005433344968	17029	Economy	10200.00
0005435508454	17029	Economy	10200.00
0005433344963	17029	Economy	10200.00
0005433269824	17029	Economy	10200.00
0005433345033	17029	Economy	10200.00
0005433345003	17029	Economy	10200.00
0005433345024	17029	Economy	10200.00
0005433345001	17029	Economy	10200.00
0005435092194	17029	Economy	10200.00
0005433344996	17029	Economy	10200.00
0005433344993	17029	Economy	10200.00
0005433345041	17029	Economy	10200.00
0005433344952	17029	Economy	10200.00
0005433345026	17029	Economy	10200.00
0005433344972	17029	Economy	10200.00
0005433344988	17029	Economy	10200.00
0005433344943	17029	Economy	10200.00
0005433344951	17029	Economy	10200.00
0005435508433	17029	Economy	10200.00
0005435508455	17029	Economy	10200.00
0005433344984	17029	Economy	10200.00
0005433344971	17029	Economy	10200.00
0005433269822	17029	Economy	10200.00
0005435508473	17029	Economy	10200.00
0005433345037	17029	Economy	10200.00
0005433159354	17029	Economy	10200.00
0005433344955	17029	Economy	10200.00
0005435092141	17029	Economy	10200.00
0005433345009	17029	Economy	10200.00
0005433345022	17029	Economy	10200.00
0005433345029	17029	Economy	10200.00
0005433345036	17029	Economy	10200.00
0005433344991	17029	Economy	10200.00
0005433345006	17029	Economy	10200.00
0005433345019	17029	Economy	10200.00
0005435092155	17029	Economy	10200.00
0005433345021	17029	Economy	10200.00
0005433344969	17029	Economy	10200.00
0005433344958	17029	Economy	10200.00
0005433344950	17029	Economy	10200.00
0005433345042	17029	Economy	10200.00
0005433345012	17029	Economy	10200.00
0005433345030	17029	Economy	10200.00
0005433345040	17029	Economy	11200.00
0005433344946	17029	Economy	10200.00
0005433344954	17029	Economy	10200.00
0005433344960	17029	Economy	11200.00
0005433344965	17029	Economy	11200.00
0005433344997	17029	Economy	10200.00
0005433344982	17029	Economy	10200.00
0005433269823	17029	Economy	10200.00
0005434445267	17029	Economy	10200.00
0005433345010	17029	Economy	10200.00
0005435092140	17029	Economy	10200.00
0005433344944	17029	Economy	10200.00
0005433345028	17029	Economy	10200.00
0005433344949	17029	Economy	10200.00
0005433269825	17029	Economy	10200.00
0005433344978	17029	Economy	10200.00
0005433345032	17029	Economy	10200.00
0005433344974	17029	Economy	10200.00
0005433345039	17029	Economy	10200.00
0005435092206	17029	Economy	10200.00
0005433159355	17029	Economy	10200.00
0005433345002	17029	Economy	10200.00
0005433345031	17029	Economy	10200.00
0005433344998	17029	Economy	10200.00
0005435092154	17029	Economy	10200.00
0005435092219	17029	Economy	10200.00
0005433344956	17029	Economy	10200.00
0005433344985	17029	Economy	10200.00
0005433345000	17029	Economy	10200.00
0005433344953	17029	Economy	10200.00
0005433344966	17029	Economy	10200.00
0005433344990	17029	Economy	10200.00
0005433344994	17029	Economy	10200.00
0005433344973	17029	Economy	10200.00
0005433344947	17029	Economy	10200.00
0005433344957	17029	Economy	10200.00
0005433159356	17029	Economy	10200.00
0005433344976	17029	Economy	10200.00
0005433345027	17029	Economy	10200.00
0005433344967	17029	Economy	10200.00
0005433345043	17029	Economy	10200.00
0005433345034	17029	Economy	10200.00
0005433344948	17029	Economy	10200.00
0005434445257	17029	Economy	10200.00
0005433344986	17029	Economy	10200.00
0005435508457	17029	Economy	10200.00
0005433345004	17029	Economy	10200.00
0005433344983	17029	Economy	10200.00
0005435092179	17029	Economy	10200.00
0005433344995	17029	Economy	10200.00
0005433345013	17029	Economy	10200.00
0005433344964	17029	Economy	10200.00
0005433345014	17029	Economy	10200.00
0005433345007	17029	Economy	10200.00
0005433345018	17029	Economy	10200.00
0005433344945	17029	Economy	10200.00
0005433345035	17029	Economy	10200.00
0005433344999	17029	Economy	10200.00
0005433345023	17029	Economy	10200.00
0005433344959	17029	Economy	10200.00
0005434082154	12775	Business	40300.00
0005434026735	12775	Business	40300.00
0005434026717	12775	Business	40300.00
0005434067967	12775	Business	40300.00
0005432159947	12775	Business	40300.00
0005434068451	12775	Business	40300.00
0005434082054	12775	Business	40300.00
0005434068195	12775	Business	40300.00
0005434068309	12775	Business	40300.00
0005434068103	12775	Business	40300.00
0005434082137	12775	Business	40300.00
0005434068079	12775	Economy	13400.00
0005434026719	12775	Economy	13400.00
0005434068450	12775	Economy	13400.00
0005434068116	12775	Economy	13400.00
0005434068197	12775	Economy	13400.00
0005434068371	12775	Economy	13400.00
0005434082113	12775	Economy	13400.00
0005432433785	12775	Economy	13400.00
0005434068403	12775	Economy	13400.00
0005434082150	12775	Economy	13400.00
0005434068163	12775	Economy	13400.00
0005434068375	12775	Economy	13400.00
0005434068315	12775	Economy	13400.00
0005434068282	12775	Economy	13400.00
0005434068102	12775	Economy	13400.00
0005434068035	12775	Economy	13400.00
0005434068065	12775	Economy	13400.00
0005434026736	12775	Economy	13400.00
0005434082151	12775	Economy	13400.00
0005434068020	12775	Economy	13400.00
0005434068318	12775	Economy	13400.00
0005434067968	12775	Economy	13400.00
0005434068320	12775	Economy	13400.00
0005434068459	12775	Economy	13400.00
0005434068123	12775	Economy	13400.00
0005434082127	12775	Economy	13400.00
0005434068427	12775	Economy	13400.00
0005434082069	12775	Economy	13400.00
0005434082171	12775	Economy	13400.00
0005433989822	12775	Economy	13400.00
0005432159946	12775	Economy	13400.00
0005434067833	12775	Economy	13400.00
0005433989799	12775	Economy	13400.00
0005434068310	12775	Economy	13400.00
0005434068394	12775	Economy	13400.00
0005433989800	12775	Economy	13400.00
0005434068201	12775	Economy	13400.00
0005434082012	12775	Economy	14800.00
0005433812947	12775	Economy	14800.00
0005432433783	12775	Economy	14800.00
0005434082143	12775	Economy	14800.00
0005432159945	12775	Economy	14800.00
0005434068164	12775	Economy	14800.00
0005434068080	12775	Economy	13400.00
0005434082172	12775	Economy	13400.00
0005432159944	12775	Economy	13400.00
0005434068332	12775	Economy	13400.00
0005432161198	12775	Economy	13400.00
0005434068448	12775	Economy	13400.00
0005433989812	12775	Economy	13400.00
0005434068034	12775	Economy	13400.00
0005434068410	12775	Economy	13400.00
0005434068147	12775	Economy	13400.00
0005434068117	12775	Economy	13400.00
0005434068239	12775	Economy	13400.00
0005434068128	12775	Economy	13400.00
0005434068460	12775	Economy	13400.00
0005434082099	12775	Economy	13400.00
0005434068409	12775	Economy	13400.00
0005434068124	12775	Economy	13400.00
0005434068178	12775	Economy	13400.00
0005434082015	12775	Economy	13400.00
0005434067986	12775	Economy	13400.00
0005434068225	12775	Economy	13400.00
0005434082158	12775	Economy	13400.00
0005434082101	12775	Economy	13400.00
0005434068429	12775	Economy	13400.00
0005434068370	12775	Economy	13400.00
0005432159948	12775	Economy	13400.00
0005434082131	12775	Economy	13400.00
0005434026718	12775	Economy	13400.00
0005434082016	12775	Economy	13400.00
0005434067834	12775	Economy	13400.00
0005434068350	12775	Economy	13400.00
0005434068416	12775	Economy	13400.00
0005433989818	12775	Economy	13400.00
0005434068449	12775	Economy	13400.00
0005434068287	12775	Economy	13400.00
0005434068262	12775	Economy	13400.00
0005433989821	12775	Economy	13400.00
0005434068319	12775	Economy	13400.00
0005434068426	12775	Economy	13400.00
0005434068477	12775	Economy	13400.00
0005432433784	12775	Economy	13400.00
0005434067992	12775	Economy	13400.00
0005434068118	12775	Economy	13400.00
0005434067987	12775	Economy	13400.00
0005434068069	12775	Economy	13400.00
0005434082134	12775	Economy	13400.00
0005434068435	12775	Economy	13400.00
0005434082133	12775	Economy	13400.00
0005434068464	12775	Economy	13400.00
0005432161197	12775	Economy	13400.00
0005434068349	12775	Economy	13400.00
0005434082102	12775	Economy	13400.00
0005432433786	12775	Economy	13400.00
0005434068348	12775	Economy	13400.00
0005434068200	12775	Economy	13400.00
0005434068289	12775	Economy	13400.00
0005434068209	12775	Economy	13400.00
0005434068283	12775	Economy	13400.00
0005434068428	12775	Economy	13400.00
0005434068463	12775	Economy	13400.00
0005434068125	12775	Economy	13400.00
0005434068172	12775	Economy	13400.00
0005434068300	12775	Economy	13400.00
0005433989817	12775	Economy	13400.00
0005434068070	12775	Economy	13400.00
0005434068299	12775	Economy	13400.00
0005434026728	12775	Economy	13400.00
0005434082112	12775	Economy	13400.00
0005433812946	12775	Economy	13400.00
0005434082316	30671	Business	40300.00
0005434068837	30671	Business	40300.00
0005434068902	30671	Business	40300.00
0005433812916	30671	Business	40300.00
0005434068901	30671	Business	40300.00
0005432186938	30671	Business	40300.00
0005432186936	30671	Business	40300.00
0005434068842	30671	Business	40300.00
0005434026737	30671	Business	40300.00
0005434068907	30671	Business	40300.00
0005432433736	30671	Business	40300.00
0005434026741	30671	Business	40300.00
0005434082317	30671	Economy	13400.00
0005434068906	30671	Economy	13400.00
0005434068897	30671	Economy	13400.00
0005432150341	30671	Economy	13400.00
0005434082321	30671	Economy	13400.00
0005432433735	30671	Economy	13400.00
0005434068865	30671	Economy	13400.00
0005434068873	30671	Economy	13400.00
0005432150338	30671	Economy	13400.00
0005434068847	30671	Economy	13400.00
0005432150342	30671	Economy	13400.00
0005434068863	30671	Economy	13400.00
0005434068878	30671	Economy	13400.00
0005434068904	30671	Economy	13400.00
0005434068882	30671	Economy	13400.00
0005434068853	30671	Economy	13400.00
0005434068877	30671	Economy	13400.00
0005433989857	30671	Economy	13400.00
0005434068858	30671	Economy	13400.00
0005434068888	30671	Economy	13400.00
0005434026738	30671	Economy	13400.00
0005434068848	30671	Economy	13400.00
0005432150339	30671	Economy	13400.00
0005432186937	30671	Economy	13400.00
0005434026742	30671	Economy	13400.00
0005432433751	30671	Economy	13400.00
0005434068841	30671	Economy	13400.00
0005434082312	30671	Economy	13400.00
0005433812917	30671	Economy	13400.00
0005432150343	30671	Economy	13400.00
0005434068868	30671	Economy	13400.00
0005434068846	30671	Economy	13400.00
0005433989859	30671	Economy	13400.00
0005434068856	30671	Economy	13400.00
0005434068844	30671	Economy	13400.00
0005434068869	30671	Economy	13400.00
0005434068864	30671	Economy	13400.00
0005434068881	30671	Economy	13400.00
0005434068903	30671	Economy	13400.00
0005434068845	30671	Economy	13400.00
0005434068879	30671	Economy	14800.00
0005434068900	30671	Economy	14800.00
0005434068895	30671	Economy	14800.00
0005432186939	30671	Economy	14800.00
0005434068859	30671	Economy	14800.00
0005434068890	30671	Economy	14800.00
0005434068851	30671	Economy	13400.00
0005434068870	30671	Economy	13400.00
0005434068852	30671	Economy	13400.00
0005434068861	30671	Economy	13400.00
0005434026740	30671	Economy	13400.00
0005434026739	30671	Economy	13400.00
0005434068896	30671	Economy	13400.00
0005432433742	30671	Economy	13400.00
0005434068840	30671	Economy	13400.00
0005434068843	30671	Economy	13400.00
0005434068855	30671	Economy	13400.00
0005434068899	30671	Economy	13400.00
0005434068883	30671	Economy	13400.00
0005434082322	30671	Economy	13400.00
0005434068885	30671	Economy	13400.00
0005434068909	30671	Economy	13400.00
0005434082318	30671	Economy	13400.00
0005433812922	30671	Economy	13400.00
0005432150336	30671	Economy	13400.00
0005434068893	30671	Economy	13400.00
0005434082313	30671	Economy	13400.00
0005434068880	30671	Economy	13400.00
0005434068857	30671	Economy	13400.00
0005434082308	30671	Economy	13400.00
0005434068867	30671	Economy	13400.00
0005434068838	30671	Economy	13400.00
0005433812918	30671	Economy	13400.00
0005432150340	30671	Economy	13400.00
0005434068871	30671	Economy	13400.00
0005434068886	30671	Economy	13400.00
0005434082319	30671	Economy	13400.00
0005432150337	30671	Economy	13400.00
0005434082325	30671	Economy	13400.00
0005434082320	30671	Economy	13400.00
0005434068889	30671	Economy	13400.00
0005434068892	30671	Economy	13400.00
0005433812920	30671	Economy	13400.00
0005434068876	30671	Economy	13400.00
0005434082310	30671	Economy	13400.00
0005434082314	30671	Economy	13400.00
0005434068872	30671	Economy	13400.00
0005434068850	30671	Economy	13400.00
0005434082326	30671	Economy	13400.00
0005434082323	30671	Economy	13400.00
0005434068905	30671	Economy	13400.00
0005434082324	30671	Economy	13400.00
0005434082311	30671	Economy	13400.00
0005432433734	30671	Economy	13400.00
0005434082315	30671	Economy	13400.00
0005434068839	30671	Economy	13400.00
0005434068898	30671	Economy	13400.00
0005434068875	30671	Economy	13400.00
0005433989860	30671	Economy	13400.00
0005434068854	30671	Economy	13400.00
0005434068849	30671	Economy	13400.00
0005434082309	30671	Economy	13400.00
0005433812914	30671	Economy	13400.00
0005434068884	30671	Economy	13400.00
0005432433764	30671	Economy	13400.00
0005434068862	30671	Economy	13400.00
0005434068894	30671	Economy	13400.00
0005433812924	30671	Economy	13400.00
0005434068860	30671	Economy	13400.00
0005434068866	30671	Economy	13400.00
0005432186935	30671	Economy	13400.00
0005434068908	30671	Economy	13400.00
0005433989858	30671	Economy	13400.00
0005434068874	30671	Economy	13400.00
0005434068887	30671	Economy	13400.00
0005432433743	30671	Economy	13400.00
0005434068891	30671	Economy	13400.00
0005432140611	5539	Business	35300.00
0005435462790	5539	Business	35300.00
0005434265391	5539	Business	35300.00
0005434265409	5539	Business	35300.00
0005435767395	5539	Business	35300.00
0005435767389	5539	Business	35300.00
0005435462899	5539	Business	35300.00
0005432140607	5539	Business	35300.00
0005435725693	5539	Business	35300.00
0005435767381	5539	Business	35300.00
0005432535892	5539	Business	35300.00
0005435462806	5539	Business	35300.00
0005435767431	5539	Business	35300.00
0005433527341	5539	Business	35300.00
0005435767370	5539	Business	35300.00
0005434265305	5539	Business	35300.00
0005435735226	5539	Business	35300.00
0005434265392	5539	Business	35300.00
0005435735225	5539	Business	35300.00
0005435767392	5539	Business	35300.00
0005435767429	5539	Business	35300.00
0005435462837	5539	Business	35300.00
0005434265480	5539	Business	35300.00
0005434265436	5539	Business	35300.00
0005435767415	5539	Business	35300.00
0005434265440	5539	Business	35300.00
0005435462803	5539	Business	35300.00
0005435767402	5539	Economy	12900.00
0005435462776	5539	Economy	12900.00
0005435462758	5539	Economy	12900.00
0005432140612	5539	Economy	12900.00
0005435722101	5539	Economy	11800.00
0005435767375	5539	Economy	11800.00
0005435767373	5539	Economy	11800.00
0005435462886	5539	Economy	11800.00
0005435462785	5539	Economy	11800.00
0005435767379	5539	Economy	11800.00
0005435767367	5539	Economy	11800.00
0005435767430	5539	Economy	11800.00
0005434265274	5539	Economy	11800.00
0005435767424	5539	Economy	11800.00
0005435767406	5539	Economy	11800.00
0005433527342	5539	Economy	11800.00
0005434265521	5539	Economy	11800.00
0005434265389	5539	Economy	11800.00
0005435767364	5539	Economy	11800.00
0005435462881	5539	Economy	11800.00
0005432140610	5539	Economy	11800.00
0005435767405	5539	Economy	11800.00
0005435767371	5539	Economy	11800.00
0005435462891	5539	Economy	11800.00
0005435767385	5539	Economy	11800.00
0005434265324	5539	Economy	11800.00
0005435767404	5539	Economy	11800.00
0005435767397	5539	Economy	11800.00
0005435767386	5539	Economy	11800.00
0005435767423	5539	Economy	11800.00
0005434265369	5539	Economy	11800.00
0005432140605	5539	Economy	11800.00
0005434265400	5539	Economy	11800.00
0005435725694	5539	Economy	11800.00
0005435767398	5539	Economy	11800.00
0005435735224	5539	Economy	11800.00
0005435767407	5539	Economy	11800.00
0005435767376	5539	Economy	11800.00
0005435462972	5539	Economy	11800.00
0005434831195	5539	Economy	11800.00
0005435462955	5539	Economy	11800.00
0005434265483	5539	Economy	11800.00
0005435767394	5539	Economy	11800.00
0005435767412	5539	Economy	11800.00
0005435767369	5539	Economy	11800.00
0005435462769	5539	Economy	11800.00
0005435462823	5539	Economy	11800.00
0005434265287	5539	Economy	11800.00
0005435723081	5539	Economy	11800.00
0005434265402	5539	Economy	11800.00
0005435767427	5539	Economy	11800.00
0005435767368	5539	Economy	11800.00
0005435725692	5539	Economy	11800.00
0005432140608	5539	Economy	11800.00
0005435767419	5539	Economy	11800.00
0005435462768	5539	Economy	11800.00
0005435462759	5539	Economy	11800.00
0005435767378	5539	Economy	11800.00
0005435767365	5539	Economy	11800.00
0005435722102	5539	Economy	11800.00
0005434831187	5539	Economy	11800.00
0005435462848	5539	Economy	11800.00
0005433529353	5539	Economy	11800.00
0005435735223	5539	Economy	11800.00
0005435767380	5539	Economy	11800.00
0005435462753	5539	Economy	11800.00
0005434265435	5539	Economy	11800.00
0005435767408	5539	Economy	11800.00
0005435462990	5539	Economy	11800.00
0005434265335	5539	Economy	11800.00
0005435462791	5539	Economy	11800.00
0005432140603	5539	Economy	11800.00
0005435767393	5539	Economy	11800.00
0005433529351	5539	Economy	11800.00
0005432535891	5539	Economy	11800.00
0005435767416	5539	Economy	11800.00
0005434265325	5539	Economy	11800.00
0005435462767	5539	Economy	11800.00
0005434265517	5539	Economy	11800.00
0005434831217	5539	Economy	11800.00
0005432140606	5539	Economy	11800.00
0005434265373	5539	Economy	11800.00
0005435462907	5539	Economy	11800.00
0005434265306	5539	Economy	11800.00
0005435767421	5539	Economy	11800.00
0005435462865	5539	Economy	11800.00
0005435767413	5539	Economy	11800.00
0005435767396	5539	Economy	11800.00
0005433527339	5539	Economy	11800.00
0005435767410	5539	Economy	12900.00
0005435767399	5539	Economy	11800.00
0005435767411	5539	Economy	12900.00
0005435767372	5539	Economy	11800.00
0005435767374	5539	Economy	11800.00
0005434265441	5539	Economy	11800.00
0005435767417	5539	Economy	12900.00
0005434265399	5539	Economy	12900.00
0005435462939	5539	Economy	11800.00
0005435767377	5539	Economy	11800.00
0005434265405	5539	Economy	11800.00
0005435462871	5539	Economy	11800.00
0005435767400	5539	Economy	11800.00
0005435767428	5539	Economy	11800.00
0005435767383	5539	Economy	11800.00
0005435462674	5539	Economy	11800.00
0005435725691	5539	Economy	11800.00
0005435462751	5539	Economy	11800.00
0005435767384	5539	Economy	11800.00
0005434265273	5539	Economy	11800.00
0005434265336	5539	Economy	11800.00
0005435767432	5539	Economy	11800.00
0005435462810	5539	Economy	11800.00
0005435462815	5539	Economy	11800.00
0005435462885	5539	Economy	11800.00
0005435462876	5539	Economy	11800.00
0005435462752	5539	Economy	11800.00
0005433529352	5539	Economy	11800.00
0005435767403	5539	Economy	11800.00
0005435767390	5539	Economy	11800.00
0005435767426	5539	Economy	11800.00
0005434265355	5539	Economy	11800.00
0005435462846	5539	Economy	11800.00
0005434265390	5539	Economy	11800.00
0005435725696	5539	Economy	11800.00
0005435767409	5539	Economy	11800.00
0005432140609	5539	Economy	11800.00
0005432140604	5539	Economy	11800.00
0005435462847	5539	Economy	11800.00
0005434831216	5539	Economy	11800.00
0005433527340	5539	Economy	11800.00
0005435767422	5539	Economy	11800.00
0005435462781	5539	Economy	11800.00
0005435767387	5539	Economy	11800.00
0005435767382	5539	Economy	11800.00
0005435462971	5539	Economy	11800.00
0005435767366	5539	Economy	11800.00
0005435462849	5539	Economy	11800.00
0005435462737	5539	Economy	11800.00
0005435462894	5539	Economy	11800.00
0005435462890	5539	Economy	11800.00
0005434265286	5539	Economy	11800.00
0005435462892	5539	Economy	11800.00
0005435462786	5539	Economy	11800.00
0005434265482	5539	Economy	11800.00
0005435462809	5539	Economy	11800.00
0005435767414	5539	Economy	11800.00
0005435767420	5539	Economy	11800.00
0005432535868	5539	Economy	11800.00
0005435725695	5539	Economy	11800.00
0005435767401	5539	Economy	11800.00
0005435463028	5539	Economy	11800.00
0005435767391	5539	Economy	11800.00
0005435767418	5539	Economy	11800.00
0005435767425	5539	Economy	11800.00
0005434265329	5539	Economy	11800.00
0005435462954	5539	Economy	11800.00
0005435767388	5539	Economy	11800.00
0005435462816	5539	Economy	11800.00
0005432194593	13449	Business	35300.00
0005433529310	13449	Business	35300.00
0005435766648	13449	Business	35300.00
0005435463168	13449	Business	35300.00
0005433529289	13449	Business	35300.00
0005434265641	13449	Business	35300.00
0005435766788	13449	Business	35300.00
0005435463184	13449	Business	35300.00
0005435766770	13449	Business	35300.00
0005435463158	13449	Business	35300.00
0005435766592	13449	Business	35300.00
0005434265632	13449	Business	35300.00
0005433533348	13449	Business	35300.00
0005432194592	13449	Business	35300.00
0005435766874	13449	Business	35300.00
0005435766918	13449	Business	35300.00
0005432194591	13449	Business	35300.00
0005435766739	13449	Business	35300.00
0005435463172	13449	Business	35300.00
0005434265648	13449	Business	35300.00
0005433533345	13449	Business	35300.00
0005435766876	13449	Business	35300.00
0005433533344	13449	Business	35300.00
0005435766798	13449	Economy	12900.00
0005435766390	13449	Economy	12900.00
0005435722073	13449	Economy	11800.00
0005435766484	13449	Economy	11800.00
0005434265637	13449	Economy	11800.00
0005435463162	13449	Economy	11800.00
0005435766852	13449	Economy	11800.00
0005435766851	13449	Economy	11800.00
0005434265651	13449	Economy	11800.00
0005434265633	13449	Economy	11800.00
0005433529298	13449	Economy	11800.00
0005434831243	13449	Economy	11800.00
0005435725633	13449	Economy	11800.00
0005435735168	13449	Economy	11800.00
0005435463155	13449	Economy	11800.00
0005435463166	13449	Economy	11800.00
0005435463149	13449	Economy	11800.00
0005435766880	13449	Economy	11800.00
0005435463174	13449	Economy	11800.00
0005435766810	13449	Economy	11800.00
0005435766799	13449	Economy	11800.00
0005435463178	13449	Economy	11800.00
0005435735172	13449	Economy	11800.00
0005433533341	13449	Economy	11800.00
0005435766790	13449	Economy	11800.00
0005433533347	13449	Economy	11800.00
0005434831244	13449	Economy	11800.00
0005434265635	13449	Economy	11800.00
0005435463176	13449	Economy	11800.00
0005435766732	13449	Economy	11800.00
0005434265627	13449	Economy	11800.00
0005435766773	13449	Economy	11800.00
0005435463151	13449	Economy	11800.00
0005433533355	13449	Economy	11800.00
0005433533356	13449	Economy	11800.00
0005434265640	13449	Economy	11800.00
0005435463170	13449	Economy	11800.00
0005435463157	13449	Economy	11800.00
0005435766610	13449	Economy	11800.00
0005435766903	13449	Economy	11800.00
0005435766840	13449	Economy	11800.00
0005435463156	13449	Economy	11800.00
0005435463171	13449	Economy	11800.00
0005434265636	13449	Economy	11800.00
0005433533343	13449	Economy	11800.00
0005435463165	13449	Economy	11800.00
0005433529299	13449	Economy	11800.00
0005433529288	13449	Economy	11800.00
0005435735202	13449	Economy	11800.00
0005435766769	13449	Economy	11800.00
0005435463173	13449	Economy	11800.00
0005435766879	13449	Economy	11800.00
0005435463177	13449	Economy	11800.00
0005434265647	13449	Economy	11800.00
0005435766906	13449	Economy	11800.00
0005435766697	13449	Economy	11800.00
0005432535927	13449	Economy	11800.00
0005434265630	13449	Economy	11800.00
0005432535926	13449	Economy	11800.00
0005435766812	13449	Economy	11800.00
0005434265642	13449	Economy	11800.00
0005435463169	13449	Economy	11800.00
0005433529317	13449	Economy	11800.00
0005435463152	13449	Economy	11800.00
0005433529294	13449	Economy	11800.00
0005435463163	13449	Economy	11800.00
0005435463167	13449	Economy	11800.00
0005433529295	13449	Economy	11800.00
0005432194590	13449	Economy	11800.00
0005434265649	13449	Economy	11800.00
0005435463182	13449	Economy	11800.00
0005433533321	13449	Economy	11800.00
0005435766695	13449	Economy	11800.00
0005435766591	13449	Economy	11800.00
0005434265638	13449	Economy	11800.00
0005433533339	13449	Economy	11800.00
0005435766877	13449	Economy	11800.00
0005433529290	13449	Economy	11800.00
0005433533342	13449	Economy	11800.00
0005434265650	13449	Economy	11800.00
0005434265628	13449	Economy	11800.00
0005433529305	13449	Economy	11800.00
0005435766789	13449	Economy	12900.00
0005433533336	13449	Economy	12900.00
0005432535929	13449	Economy	11800.00
0005435463183	13449	Economy	11800.00
0005435766768	13449	Economy	11800.00
0005435463154	13449	Economy	12900.00
0005434265643	13449	Economy	11800.00
0005433529293	13449	Economy	11800.00
0005435735180	13449	Economy	11800.00
0005435766869	13449	Economy	11800.00
0005433533338	13449	Economy	11800.00
0005435463153	13449	Economy	11800.00
0005433529297	13449	Economy	11800.00
0005435463148	13449	Economy	11800.00
0005433529309	13449	Economy	11800.00
0005433529307	13449	Economy	11800.00
0005435463150	13449	Economy	11800.00
0005435766811	13449	Economy	11800.00
0005435766886	13449	Economy	11800.00
0005433529287	13449	Economy	11800.00
0005433533350	13449	Economy	11800.00
0005435463186	13449	Economy	11800.00
0005435725639	13449	Economy	11800.00
0005433529286	13449	Economy	11800.00
0005435766791	13449	Economy	11800.00
0005435463179	13449	Economy	11800.00
0005434265653	13449	Economy	11800.00
0005434831245	13449	Economy	11800.00
0005435463185	13449	Economy	11800.00
0005435463180	13449	Economy	11800.00
0005432535928	13449	Economy	11800.00
0005433529306	13449	Economy	11800.00
0005435463159	13449	Economy	11800.00
0005434265645	13449	Economy	11800.00
0005434265652	13449	Economy	11800.00
0005433533337	13449	Economy	11800.00
0005435766917	13449	Economy	11800.00
0005435766758	13449	Economy	11800.00
0005433533322	13449	Economy	11800.00
0005433529279	13449	Economy	11800.00
0005433529311	13449	Economy	11800.00
0005434265639	13449	Economy	11800.00
0005435463175	13449	Economy	11800.00
0005435735179	13449	Economy	11800.00
0005435463160	13449	Economy	11800.00
0005435463161	13449	Economy	11800.00
0005435735176	13449	Economy	11800.00
0005435766924	13449	Economy	11800.00
0005434265644	13449	Economy	11800.00
0005433529285	13449	Economy	11800.00
0005434265634	13449	Economy	11800.00
0005433533351	13449	Economy	11800.00
0005435766696	13449	Economy	11800.00
0005434265629	13449	Economy	11800.00
0005435720140	13449	Economy	11800.00
0005435463164	13449	Economy	11800.00
0005433533340	13449	Economy	11800.00
0005434265646	13449	Economy	11800.00
0005432535930	13449	Economy	11800.00
0005434831242	13449	Economy	11800.00
0005434265631	13449	Economy	11800.00
0005435463181	13449	Economy	11800.00
0005435766842	13449	Economy	11800.00
0005435766772	13449	Economy	11800.00
0005435766740	13449	Economy	11800.00
0005435766663	13449	Economy	11800.00
0005433533346	13449	Economy	11800.00
0005434602927	18667	Economy	3300.00
0005434602926	18667	Economy	3300.00
0005434515017	18668	Economy	3300.00
0005435904716	18668	Economy	3300.00
0005434604931	18668	Economy	3300.00
0005434513628	18668	Economy	3300.00
0005434515016	18668	Economy	3300.00
0005435904715	18668	Economy	3300.00
0005434513630	18668	Economy	3300.00
0005434513629	18668	Economy	3300.00
0005434604944	18668	Economy	3300.00
0005434513631	18668	Economy	3300.00
0005434514988	19219	Economy	3300.00
0005434514987	19219	Economy	3300.00
0005434515002	19219	Economy	3300.00
0005434515003	19219	Economy	3300.00
0005434514992	19219	Economy	3300.00
0005432632876	4124	Business	88300.00
0005432632869	4124	Business	88300.00
0005432632879	4124	Business	88300.00
0005435846289	4124	Business	88300.00
0005432649519	4124	Business	88300.00
0005435846286	4124	Business	88300.00
0005435844358	4124	Business	88300.00
0005435844360	4124	Economy	29400.00
0005432632871	4124	Economy	29400.00
0005432649513	4124	Economy	29400.00
0005432632873	4124	Economy	32400.00
0005435846266	4124	Economy	29400.00
0005435844341	4124	Economy	29400.00
0005435846291	4124	Economy	29400.00
0005435846287	4124	Economy	29400.00
0005432649520	4124	Economy	29400.00
0005432632868	4124	Economy	29400.00
0005435846297	4124	Economy	29400.00
0005435844344	4124	Economy	29400.00
0005432632875	4124	Economy	29400.00
0005432649524	4124	Economy	29400.00
0005432649526	4124	Economy	29400.00
0005435846265	4124	Economy	29400.00
0005435844359	4124	Economy	29400.00
0005432649517	4124	Economy	29400.00
0005432649516	4124	Economy	29400.00
0005432632880	4124	Economy	29400.00
0005432632874	4124	Economy	29400.00
0005432632878	4124	Economy	29400.00
0005435846300	4124	Economy	29400.00
0005435844352	4124	Economy	29400.00
0005435844361	4124	Economy	29400.00
0005435846283	4124	Economy	29400.00
0005435846282	4124	Economy	29400.00
0005432632877	4124	Economy	29400.00
0005435844339	4124	Economy	29400.00
0005432649515	4124	Economy	29400.00
0005432632870	4124	Economy	29400.00
0005432649522	4124	Economy	29400.00
0005432649514	4124	Economy	29400.00
0005432649523	4124	Economy	29400.00
0005435844340	4124	Economy	29400.00
0005435844351	4124	Economy	29400.00
0005435844350	4124	Economy	29400.00
0005432649521	4124	Economy	29400.00
0005435846290	4124	Economy	29400.00
0005432632872	4124	Economy	29400.00
0005432649525	4124	Economy	29400.00
0005435844353	4124	Economy	29400.00
0005435846284	4124	Economy	29400.00
0005435846281	4124	Economy	29400.00
0005432649518	4124	Economy	29400.00
0005433810628	1866	Business	48700.00
0005433810645	1866	Business	48700.00
0005433008843	1866	Business	48700.00
0005433810641	1866	Business	48700.00
0005433810646	1866	Business	48700.00
0005433810643	1866	Business	48700.00
0005432295932	1866	Business	48700.00
0005433810629	1866	Business	48700.00
0005433009099	1866	Economy	16200.00
0005433810639	1866	Economy	16200.00
0005433009292	1866	Economy	16200.00
0005433285521	1866	Economy	16200.00
0005433009176	1866	Economy	16200.00
0005433285681	1866	Economy	16200.00
0005433285596	1866	Economy	16200.00
0005433285680	1866	Economy	17900.00
0005433810644	1866	Economy	17900.00
0005433009042	1866	Economy	17900.00
0005433810640	1866	Economy	17900.00
0005433810626	1866	Economy	17900.00
0005433285554	1866	Economy	16200.00
0005433009252	1866	Economy	16200.00
0005433009013	1866	Economy	16200.00
0005433009118	1866	Economy	16200.00
0005433810630	1866	Economy	16200.00
0005433009184	1866	Economy	16200.00
0005433810623	1866	Economy	16200.00
0005433285665	1866	Economy	16200.00
0005433285780	1866	Economy	16200.00
0005433810635	1866	Economy	16200.00
0005433009011	1866	Economy	16200.00
0005433009203	1866	Economy	16200.00
0005433810633	1866	Economy	16200.00
0005433009014	1866	Economy	16200.00
0005433810632	1866	Economy	16200.00
0005433285662	1866	Economy	16200.00
0005433810638	1866	Economy	16200.00
0005433810642	1866	Economy	16200.00
0005433285669	1866	Economy	16200.00
0005433008964	1866	Economy	16200.00
0005433009041	1866	Economy	16200.00
0005433285598	1866	Economy	16200.00
0005433009255	1866	Economy	16200.00
0005433285630	1866	Economy	16200.00
0005433810625	1866	Economy	16200.00
0005433285561	1866	Economy	16200.00
0005433009057	1866	Economy	16200.00
0005433810634	1866	Economy	16200.00
0005433285562	1866	Economy	16200.00
0005433285509	1866	Economy	16200.00
0005433009237	1866	Economy	16200.00
0005433009079	1866	Economy	16200.00
0005433810627	1866	Economy	16200.00
0005433009134	1866	Economy	16200.00
0005433810631	1866	Economy	16200.00
0005433285697	1866	Economy	16200.00
0005433810624	1866	Economy	16200.00
0005432295930	1866	Economy	16200.00
0005432295931	1866	Economy	16200.00
0005433285767	1866	Economy	16200.00
0005433810636	1866	Economy	16200.00
0005433008842	1866	Economy	16200.00
0005433009100	1866	Economy	16200.00
0005433009213	1866	Economy	16200.00
0005433285597	1866	Economy	16200.00
0005433009097	1866	Economy	16200.00
0005433285547	1866	Economy	16200.00
0005433285763	1866	Economy	16200.00
0005433285584	1866	Economy	16200.00
0005433009183	1866	Economy	16200.00
0005433009098	1866	Economy	16200.00
0005433009175	1866	Economy	16200.00
0005433285663	1866	Economy	16200.00
0005433810637	1866	Economy	16200.00
0005433008797	1866	Economy	16200.00
0005433009214	1866	Economy	16200.00
0005433009276	1866	Economy	16200.00
0005433009469	22598	Business	48700.00
0005433009477	22598	Business	48700.00
0005433285894	22598	Business	48700.00
0005433009447	22598	Business	48700.00
0005433285868	22598	Business	48700.00
0005433285892	22598	Business	48700.00
0005433009450	22598	Business	48700.00
0005433009482	22598	Business	48700.00
0005433285885	22598	Business	48700.00
0005433009454	22598	Business	48700.00
0005433285870	22598	Business	48700.00
0005433285896	22598	Economy	16200.00
0005433009470	22598	Economy	16200.00
0005433285898	22598	Economy	16200.00
0005433009464	22598	Economy	16200.00
0005433285873	22598	Economy	16200.00
0005433009459	22598	Economy	16200.00
0005433285876	22598	Economy	16200.00
0005433009465	22598	Economy	16200.00
0005433009475	22598	Economy	17900.00
0005433009456	22598	Economy	17900.00
0005433009457	22598	Economy	17900.00
0005433009476	22598	Economy	17900.00
0005433009468	22598	Economy	16200.00
0005433009487	22598	Economy	16200.00
0005433009458	22598	Economy	16200.00
0005433285899	22598	Economy	16200.00
0005433009478	22598	Economy	16200.00
0005433285878	22598	Economy	16200.00
0005433285881	22598	Economy	16200.00
0005433009461	22598	Economy	16200.00
0005433009460	22598	Economy	16200.00
0005433285890	22598	Economy	16200.00
0005433810570	22598	Economy	16200.00
0005433009446	22598	Economy	16200.00
0005433285883	22598	Economy	16200.00
0005433810579	22598	Economy	16200.00
0005433009471	22598	Economy	16200.00
0005433009463	22598	Economy	16200.00
0005433009449	22598	Economy	16200.00
0005433009455	22598	Economy	16200.00
0005433009479	22598	Economy	16200.00
0005433009491	22598	Economy	16200.00
0005433009483	22598	Economy	16200.00
0005433009484	22598	Economy	16200.00
0005433009488	22598	Economy	16200.00
0005433009453	22598	Economy	16200.00
0005433285872	22598	Economy	16200.00
0005433810571	22598	Economy	16200.00
0005433009467	22598	Economy	16200.00
0005433009480	22598	Economy	16200.00
0005433285869	22598	Economy	16200.00
0005433285886	22598	Economy	16200.00
0005433009462	22598	Economy	16200.00
0005433009481	22598	Economy	16200.00
0005433009490	22598	Economy	16200.00
0005433009473	22598	Economy	16200.00
0005433285889	22598	Economy	16200.00
0005433009489	22598	Economy	16200.00
0005433285880	22598	Economy	16200.00
0005433285874	22598	Economy	16200.00
0005433009451	22598	Economy	16200.00
0005433009452	22598	Economy	16200.00
0005433285871	22598	Economy	16200.00
0005433009448	22598	Economy	16200.00
0005433285879	22598	Economy	16200.00
0005433285877	22598	Economy	16200.00
0005433009485	22598	Economy	16200.00
0005433009466	22598	Economy	16200.00
0005433285887	22598	Economy	16200.00
0005433285895	22598	Economy	16200.00
0005433285893	22598	Economy	16200.00
0005433285875	22598	Economy	16200.00
0005433009486	22598	Economy	16200.00
0005433285888	22598	Economy	16200.00
0005433285884	22598	Economy	16200.00
0005433009472	22598	Economy	16200.00
0005433285897	22598	Economy	16200.00
0005433285891	22598	Economy	16200.00
0005433285882	22598	Economy	16200.00
0005433009474	22598	Economy	16200.00
0005433847859	5547	Business	99800.00
0005433847851	5547	Business	99800.00
0005433847845	5547	Business	99800.00
0005435282748	5547	Business	99800.00
0005435282752	5547	Business	99800.00
0005433847869	5547	Business	99800.00
0005433847853	5547	Business	99800.00
0005435282794	5547	Business	99800.00
0005433847822	5547	Business	99800.00
0005433847837	5547	Business	99800.00
0005433847829	5547	Business	99800.00
0005433847872	5547	Business	99800.00
0005433815474	5547	Business	99800.00
0005433847831	5547	Business	99800.00
0005435282773	5547	Business	99800.00
0005432081639	5547	Business	99800.00
0005433847830	5547	Business	99800.00
0005433847846	5547	Business	99800.00
0005435282821	5547	Economy	33300.00
0005433847817	5547	Economy	33300.00
0005435282858	5547	Economy	33300.00
0005433847850	5547	Economy	33300.00
0005433847835	5547	Economy	33300.00
0005433847863	5547	Economy	33300.00
0005435282764	5547	Economy	33300.00
0005433847838	5547	Economy	33300.00
0005433847864	5547	Economy	33300.00
0005433847823	5547	Economy	33300.00
0005433847843	5547	Economy	36600.00
0005433815475	5547	Economy	36600.00
0005435282859	5547	Economy	36600.00
0005433847844	5547	Economy	33300.00
0005433847862	5547	Economy	36600.00
0005432081632	5547	Economy	33300.00
0005433847842	5547	Economy	33300.00
0005433847833	5547	Economy	33300.00
0005433847841	5547	Economy	33300.00
0005435282819	5547	Economy	33300.00
0005435282811	5547	Economy	33300.00
0005432081634	5547	Economy	33300.00
0005433847857	5547	Economy	33300.00
0005433847854	5547	Economy	33300.00
0005433847825	5547	Economy	33300.00
0005433847865	5547	Economy	33300.00
0005433847827	5547	Economy	33300.00
0005433847839	5547	Economy	33300.00
0005432081635	5547	Economy	33300.00
0005433847818	5547	Economy	33300.00
0005433847852	5547	Economy	33300.00
0005433847868	5547	Economy	33300.00
0005435282818	5547	Economy	33300.00
0005433847861	5547	Economy	33300.00
0005435282826	5547	Economy	33300.00
0005434173555	5547	Economy	33300.00
0005433847836	5547	Economy	33300.00
0005433847870	5547	Economy	33300.00
0005432081638	5547	Economy	33300.00
0005433847873	5547	Economy	33300.00
0005433815477	5547	Economy	33300.00
0005433847819	5547	Economy	33300.00
0005432081636	5547	Economy	33300.00
0005433847840	5547	Economy	33300.00
0005434173556	5547	Economy	33300.00
0005433847858	5547	Economy	33300.00
0005433815476	5547	Economy	33300.00
0005433847832	5547	Economy	33300.00
0005435282766	5547	Economy	33300.00
0005433847826	5547	Economy	33300.00
0005433847866	5547	Economy	33300.00
0005433847828	5547	Economy	33300.00
0005435282799	5547	Economy	33300.00
0005433847855	5547	Economy	33300.00
0005433847871	5547	Economy	33300.00
0005433847821	5547	Economy	33300.00
0005433847834	5547	Economy	33300.00
0005435282755	5547	Economy	33300.00
0005435282747	5547	Economy	33300.00
0005432081637	5547	Economy	33300.00
0005435282716	5547	Economy	33300.00
0005433847820	5547	Economy	33300.00
0005433847867	5547	Economy	33300.00
0005435282721	5547	Economy	33300.00
0005433847824	5547	Economy	33300.00
0005433847847	5547	Economy	33300.00
0005435282790	5547	Economy	33300.00
0005433847848	5547	Economy	33300.00
0005433847849	5547	Economy	33300.00
0005435282763	5547	Economy	33300.00
0005433847816	5547	Economy	33300.00
0005435282782	5547	Economy	33300.00
0005433847860	5547	Economy	33300.00
0005435282800	5547	Economy	33300.00
0005432081633	5547	Economy	33300.00
0005433847856	5547	Economy	33300.00
0005435282972	13886	Business	99800.00
0005432003762	13886	Business	99800.00
0005433847414	13886	Business	99800.00
0005432003761	13886	Business	99800.00
0005433847321	13886	Business	99800.00
0005435282974	13886	Business	99800.00
0005433847169	13886	Business	99800.00
0005435282990	13886	Business	99800.00
0005435282982	13886	Business	99800.00
0005433847544	13886	Business	99800.00
0005433847344	13886	Business	99800.00
0005433847430	13886	Business	99800.00
0005433847274	13886	Business	99800.00
0005435282977	13886	Business	99800.00
0005434173599	13886	Business	99800.00
0005433847410	13886	Business	99800.00
0005433847474	13886	Business	99800.00
0005433815443	13886	Business	99800.00
0005433815430	13886	Business	99800.00
0005433847554	13886	Business	99800.00
0005433815437	13886	Economy	33300.00
0005433847259	13886	Economy	33300.00
0005435282981	13886	Economy	33300.00
0005433847168	13886	Economy	33300.00
0005435282969	13886	Economy	33300.00
0005433847227	13886	Economy	33300.00
0005433847553	13886	Economy	33300.00
0005433847425	13886	Economy	33300.00
0005433815409	13886	Economy	33300.00
0005433847496	13886	Economy	33300.00
0005433847335	13886	Economy	33300.00
0005433847395	13886	Economy	33300.00
0005433847298	13886	Economy	33300.00
0005433847353	13886	Economy	36600.00
0005435282970	13886	Economy	36600.00
0005433847537	13886	Economy	36600.00
0005434173597	13886	Economy	33300.00
0005433847507	13886	Economy	33300.00
0005433847061	13886	Economy	33300.00
0005433847411	13886	Economy	33300.00
0005433847393	13886	Economy	33300.00
0005433847352	13886	Economy	33300.00
0005435282985	13886	Economy	33300.00
0005435282991	13886	Economy	33300.00
0005433847209	13886	Economy	33300.00
0005433847171	13886	Economy	33300.00
0005435282988	13886	Economy	33300.00
0005433847334	13886	Economy	33300.00
0005435282967	13886	Economy	33300.00
0005433847307	13886	Economy	33300.00
0005434173598	13886	Economy	33300.00
0005435282983	13886	Economy	33300.00
0005433847159	13886	Economy	33300.00
0005435282987	13886	Economy	33300.00
0005433847435	13886	Economy	33300.00
0005433847203	13886	Economy	33300.00
0005433847316	13886	Economy	33300.00
0005433847306	13886	Economy	33300.00
0005435282971	13886	Economy	33300.00
0005435282968	13886	Economy	33300.00
0005433847158	13886	Economy	33300.00
0005433847409	13886	Economy	33300.00
0005433847289	13886	Economy	33300.00
0005435282986	13886	Economy	33300.00
0005433847428	13886	Economy	33300.00
0005435282973	13886	Economy	33300.00
0005433847184	13886	Economy	33300.00
0005432003763	13886	Economy	33300.00
0005435282984	13886	Economy	33300.00
0005433847441	13886	Economy	33300.00
0005433847546	13886	Economy	33300.00
0005435282976	13886	Economy	33300.00
0005433847561	13886	Economy	33300.00
0005433847228	13886	Economy	33300.00
0005433847136	13886	Economy	33300.00
0005433847336	13886	Economy	33300.00
0005433847283	13886	Economy	33300.00
0005432003764	13886	Economy	33300.00
0005433847266	13886	Economy	33300.00
0005433847372	13886	Economy	33300.00
0005435282978	13886	Economy	33300.00
0005433847337	13886	Economy	33300.00
0005433847356	13886	Economy	33300.00
0005433847260	13886	Economy	33300.00
0005433847278	13886	Economy	33300.00
0005433847429	13886	Economy	33300.00
0005433847167	13886	Economy	33300.00
0005435282980	13886	Economy	33300.00
0005433847284	13886	Economy	33300.00
0005433847371	13886	Economy	33300.00
0005433847545	13886	Economy	33300.00
0005435282975	13886	Economy	33300.00
0005433847294	13886	Economy	33300.00
0005433847522	13886	Economy	33300.00
0005433815410	13886	Economy	33300.00
0005433846985	13886	Economy	33300.00
0005435282989	13886	Economy	33300.00
0005435282992	13886	Economy	33300.00
0005433847313	13886	Economy	33300.00
0005435282979	13886	Economy	33300.00
0005433847343	13886	Economy	33300.00
0005435332474	7821	Economy	16600.00
0005435332456	7821	Economy	16600.00
0005435332499	7821	Economy	16600.00
0005435332473	7821	Economy	16600.00
0005434620989	7821	Economy	15100.00
0005435332458	7821	Economy	15100.00
0005434620982	7821	Economy	15100.00
0005435332511	7821	Economy	15100.00
0005435332457	7821	Economy	15100.00
0005435332475	7821	Economy	15100.00
0005434620983	7821	Economy	15100.00
0005434620996	7821	Economy	15100.00
0005434620999	7821	Economy	15100.00
0005434620987	7821	Economy	15100.00
0005434620984	7821	Economy	15100.00
0005434620993	7821	Economy	15100.00
0005434620992	7821	Economy	15100.00
0005434620994	7821	Economy	15100.00
0005432112559	7821	Economy	15100.00
0005434620995	7821	Economy	15100.00
0005434620997	7821	Economy	15100.00
0005435332433	7821	Economy	15100.00
0005434620998	7821	Economy	15100.00
0005432112560	7821	Economy	15100.00
0005432112561	7821	Economy	15100.00
0005434620981	7821	Economy	15100.00
0005434620991	7821	Economy	15100.00
0005435332417	7821	Economy	15100.00
0005434620979	7821	Economy	15100.00
0005434620986	7821	Economy	15100.00
0005435332434	7821	Economy	15100.00
0005434620988	7821	Economy	15100.00
0005434620990	7821	Economy	15100.00
0005434620985	7821	Economy	15100.00
0005434620980	7821	Economy	15100.00
0005435332416	7821	Economy	15100.00
0005435332442	7821	Economy	15100.00
0005434620832	32967	Economy	16600.00
0005434620800	32967	Economy	16600.00
0005435332529	32967	Economy	16600.00
0005434620797	32967	Economy	15100.00
0005434620788	32967	Economy	15100.00
0005435332536	32967	Economy	15100.00
0005434620842	32967	Economy	15100.00
0005434620871	32967	Economy	15100.00
0005435332532	32967	Economy	15100.00
0005434620909	32967	Economy	15100.00
0005435332540	32967	Economy	15100.00
0005435332530	32967	Economy	15100.00
0005435332537	32967	Economy	15100.00
0005434620801	32967	Economy	15100.00
0005434620843	32967	Economy	15100.00
0005434620831	32967	Economy	15100.00
0005434620907	32967	Economy	15100.00
0005434620803	32967	Economy	15100.00
0005435332535	32967	Economy	15100.00
0005435332533	32967	Economy	15100.00
0005434620723	32967	Economy	15100.00
0005434620900	32967	Economy	15100.00
0005435332539	32967	Economy	15100.00
0005434620805	32967	Economy	15100.00
0005434620908	32967	Economy	15100.00
0005434620760	32967	Economy	15100.00
0005434620787	32967	Economy	15100.00
0005434620836	32967	Economy	15100.00
0005434620899	32967	Economy	15100.00
0005434620774	32967	Economy	15100.00
0005434620804	32967	Economy	15100.00
0005434620722	32967	Economy	15100.00
0005435332538	32967	Economy	15100.00
0005435332531	32967	Economy	15100.00
0005434620870	32967	Economy	15100.00
0005434620798	32967	Economy	15100.00
0005435332534	32967	Economy	15100.00
0005434620819	32967	Economy	15100.00
0005434994208	4312	Business	38000.00
0005435937418	4312	Business	38000.00
0005435786008	4312	Business	38000.00
0005435786030	4312	Business	38000.00
0005435786032	4312	Business	38000.00
0005435786006	4312	Business	38000.00
0005435786012	4312	Business	38000.00
0005435918722	4312	Business	38000.00
0005434994212	4312	Business	38000.00
0005434994211	4312	Economy	12700.00
0005435786016	4312	Economy	12700.00
0005435787395	4312	Economy	12700.00
0005435786028	4312	Economy	12700.00
0005435786019	4312	Economy	13900.00
0005435937432	4312	Economy	13900.00
0005434994206	4312	Economy	12700.00
0005435786031	4312	Economy	12700.00
0005435918696	4312	Economy	12700.00
0005435937419	4312	Economy	12700.00
0005435786033	4312	Economy	12700.00
0005435937436	4312	Economy	12700.00
0005434994213	4312	Economy	12700.00
0005435786021	4312	Economy	12700.00
0005435786018	4312	Economy	12700.00
0005435786023	4312	Economy	12700.00
0005435786020	4312	Economy	12700.00
0005435786026	4312	Economy	12700.00
0005435937427	4312	Economy	12700.00
0005434994207	4312	Economy	12700.00
0005435937435	4312	Economy	12700.00
0005435937429	4312	Economy	12700.00
0005434994214	4312	Economy	12700.00
0005435787394	4312	Economy	12700.00
0005435918693	4312	Economy	12700.00
0005435786009	4312	Economy	12700.00
0005435786013	4312	Economy	12700.00
0005435786037	4312	Economy	12700.00
0005432190705	4312	Economy	12700.00
0005435786035	4312	Economy	12700.00
0005435786034	4312	Economy	12700.00
0005435786007	4312	Economy	12700.00
0005435786025	4312	Economy	12700.00
0005434994209	4312	Economy	12700.00
0005435786038	4312	Economy	12700.00
0005432190704	4312	Economy	12700.00
0005435786005	4312	Economy	12700.00
0005435786015	4312	Economy	12700.00
0005434994210	4312	Economy	12700.00
0005435786010	4312	Economy	12700.00
0005435918705	4312	Economy	12700.00
0005435937426	4312	Economy	12700.00
0005435786029	4312	Economy	12700.00
0005434994215	4312	Economy	12700.00
0005435787393	4312	Economy	12700.00
0005435786027	4312	Economy	12700.00
0005432190703	4312	Economy	12700.00
0005435786014	4312	Economy	12700.00
0005435786036	4312	Economy	12700.00
0005432190702	4312	Economy	12700.00
0005435786011	4312	Economy	12700.00
0005435786017	4312	Economy	12700.00
0005435786022	4312	Economy	12700.00
0005435786024	4312	Economy	12700.00
0005435786039	4312	Economy	12700.00
0005435918749	27304	Business	38000.00
0005435785749	27304	Business	38000.00
0005435785576	27304	Business	38000.00
0005435785661	27304	Business	38000.00
0005434994082	27304	Business	38000.00
0005435785561	27304	Business	38000.00
0005435785573	27304	Business	38000.00
0005435785562	27304	Business	38000.00
0005435937466	27304	Economy	12700.00
0005435785542	27304	Economy	12700.00
0005435785736	27304	Economy	12700.00
0005435918750	27304	Economy	12700.00
0005435785751	27304	Economy	12700.00
0005435785813	27304	Economy	12700.00
0005435785735	27304	Economy	12700.00
0005435785748	27304	Economy	12700.00
0005434994149	27304	Economy	13900.00
0005435785645	27304	Economy	13900.00
0005434994150	27304	Economy	13900.00
0005435937465	27304	Economy	13900.00
0005435785750	27304	Economy	12700.00
0005435918746	27304	Economy	12700.00
0005435785591	27304	Economy	12700.00
0005435785669	27304	Economy	12700.00
0005434994087	27304	Economy	12700.00
0005435785651	27304	Economy	12700.00
0005435785705	27304	Economy	12700.00
0005435785650	27304	Economy	12700.00
0005435785590	27304	Economy	12700.00
0005435785571	27304	Economy	12700.00
0005434994106	27304	Economy	12700.00
0005434994070	27304	Economy	12700.00
0005435785717	27304	Economy	12700.00
0005435918748	27304	Economy	12700.00
0005434994078	27304	Economy	12700.00
0005434994100	27304	Economy	12700.00
0005435785410	27304	Economy	12700.00
0005434994088	27304	Economy	12700.00
0005435785701	27304	Economy	12700.00
0005435785805	27304	Economy	12700.00
0005435785652	27304	Economy	12700.00
0005435937461	27304	Economy	12700.00
0005435785632	27304	Economy	12700.00
0005435785675	27304	Economy	12700.00
0005435785442	27304	Economy	12700.00
0005435785644	27304	Economy	12700.00
0005435785570	27304	Economy	12700.00
0005435918747	27304	Economy	12700.00
0005435937462	27304	Economy	12700.00
0005435937463	27304	Economy	12700.00
0005432195733	27304	Economy	12700.00
0005435785449	27304	Economy	12700.00
0005435785728	27304	Economy	12700.00
0005432195734	27304	Economy	12700.00
0005435785685	27304	Economy	12700.00
0005435937464	27304	Economy	12700.00
0005435785793	27304	Economy	12700.00
0005435785668	27304	Economy	12700.00
0005432146237	19886	Economy	12800.00
0005432146238	19886	Economy	12800.00
0005434082348	4708	Business	40900.00
0005434082351	4708	Business	40900.00
0005432568837	4708	Business	40900.00
0005432170517	4708	Business	40900.00
0005432568788	4708	Business	40900.00
0005432568781	4708	Business	40900.00
0005432568815	4708	Business	40900.00
0005432460865	4708	Business	40900.00
0005432568789	4708	Business	40900.00
0005432568804	4708	Business	40900.00
0005432568793	4708	Business	40900.00
0005432460833	4708	Business	40900.00
0005432170516	4708	Business	40900.00
0005432568782	4708	Business	40900.00
0005432460878	4708	Business	40900.00
0005434082332	4708	Business	40900.00
0005434559110	4708	Business	40900.00
0005434082343	4708	Business	40900.00
0005434082353	4708	Business	40900.00
0005432460868	4708	Business	40900.00
0005432460828	4708	Business	40900.00
0005432568792	4708	Business	40900.00
0005432460839	4708	Business	40900.00
0005432460844	4708	Business	40900.00
0005434082358	4708	Business	40900.00
0005432568795	4708	Business	40900.00
0005432460834	4708	Economy	15000.00
0005432568824	4708	Economy	15000.00
0005432568814	4708	Economy	15000.00
0005432568808	4708	Economy	15000.00
0005433726148	4708	Economy	13600.00
0005434082354	4708	Economy	13600.00
0005434082338	4708	Economy	13600.00
0005432568835	4708	Economy	13600.00
0005432460873	4708	Economy	13600.00
0005432568818	4708	Economy	13600.00
0005432568834	4708	Economy	13600.00
0005432568777	4708	Economy	13600.00
0005434559113	4708	Economy	13600.00
0005432571394	4708	Economy	13600.00
0005432568798	4708	Economy	13600.00
0005432460838	4708	Economy	13600.00
0005432460843	4708	Economy	13600.00
0005434082327	4708	Economy	13600.00
0005432460858	4708	Economy	13600.00
0005432460871	4708	Economy	13600.00
0005434082345	4708	Economy	13600.00
0005432460870	4708	Economy	13600.00
0005432460848	4708	Economy	13600.00
0005432170518	4708	Economy	13600.00
0005432571396	4708	Economy	13600.00
0005434082339	4708	Economy	13600.00
0005432568796	4708	Economy	13600.00
0005432568780	4708	Economy	13600.00
0005432568839	4708	Economy	13600.00
0005432460851	4708	Economy	13600.00
0005432568827	4708	Economy	13600.00
0005432568822	4708	Economy	13600.00
0005434082340	4708	Economy	13600.00
0005432460876	4708	Economy	13600.00
0005432568787	4708	Economy	13600.00
0005432460862	4708	Economy	13600.00
0005432460864	4708	Economy	13600.00
0005434559107	4708	Economy	13600.00
0005432186940	4708	Economy	13600.00
0005432568784	4708	Economy	13600.00
0005432568817	4708	Economy	13600.00
0005432571393	4708	Economy	13600.00
0005432568790	4708	Economy	13600.00
0005432460855	4708	Economy	13600.00
0005432460852	4708	Economy	13600.00
0005434082330	4708	Economy	13600.00
0005432568811	4708	Economy	13600.00
0005432460874	4708	Economy	13600.00
0005432460831	4708	Economy	13600.00
0005432568791	4708	Economy	13600.00
0005432460875	4708	Economy	13600.00
0005432460835	4708	Economy	13600.00
0005432170514	4708	Economy	13600.00
0005434082341	4708	Economy	13600.00
0005432568830	4708	Economy	13600.00
0005434559109	4708	Economy	13600.00
0005434082347	4708	Economy	13600.00
0005432568831	4708	Economy	13600.00
0005432460827	4708	Economy	13600.00
0005432460846	4708	Economy	13600.00
0005432460849	4708	Economy	13600.00
0005432460837	4708	Economy	13600.00
0005432170520	4708	Economy	13600.00
0005432568812	4708	Economy	13600.00
0005432568809	4708	Economy	13600.00
0005434082333	4708	Economy	13600.00
0005432460872	4708	Economy	13600.00
0005434082329	4708	Economy	13600.00
0005434082335	4708	Economy	13600.00
0005432568794	4708	Economy	13600.00
0005434082352	4708	Economy	13600.00
0005432460856	4708	Economy	13600.00
0005432460863	4708	Economy	13600.00
0005432170521	4708	Economy	13600.00
0005432460832	4708	Economy	13600.00
0005433726149	4708	Economy	13600.00
0005434082337	4708	Economy	13600.00
0005432568783	4708	Economy	13600.00
0005432568836	4708	Economy	13600.00
0005434082334	4708	Economy	13600.00
0005432568829	4708	Economy	13600.00
0005434082355	4708	Economy	13600.00
0005432460854	4708	Economy	13600.00
0005432568810	4708	Economy	13600.00
0005434082350	4708	Economy	15000.00
0005432568825	4708	Economy	15000.00
0005432568816	4708	Economy	13600.00
0005432460829	4708	Economy	13600.00
0005432568826	4708	Economy	13600.00
0005434082349	4708	Economy	13600.00
0005432460836	4708	Economy	13600.00
0005432568805	4708	Economy	13600.00
0005432460845	4708	Economy	13600.00
0005432460867	4708	Economy	13600.00
0005432568806	4708	Economy	13600.00
0005434082342	4708	Economy	13600.00
0005432568800	4708	Economy	13600.00
0005432460859	4708	Economy	13600.00
0005433451659	4708	Economy	13600.00
0005432460850	4708	Economy	13600.00
0005432568802	4708	Economy	13600.00
0005432460830	4708	Economy	13600.00
0005432460877	4708	Economy	13600.00
0005432568813	4708	Economy	13600.00
0005432568832	4708	Economy	13600.00
0005432460866	4708	Economy	13600.00
0005432568838	4708	Economy	13600.00
0005432186941	4708	Economy	13600.00
0005434082357	4708	Economy	13600.00
0005432460860	4708	Economy	13600.00
0005432568821	4708	Economy	13600.00
0005432568785	4708	Economy	13600.00
0005432568820	4708	Economy	13600.00
0005432568803	4708	Economy	13600.00
0005434082356	4708	Economy	13600.00
0005432460840	4708	Economy	13600.00
0005432460847	4708	Economy	13600.00
0005432568779	4708	Economy	13600.00
0005432460861	4708	Economy	13600.00
0005434082331	4708	Economy	13600.00
0005432460869	4708	Economy	13600.00
0005434082344	4708	Economy	13600.00
0005432170519	4708	Economy	13600.00
0005433452780	4708	Economy	13600.00
0005432568797	4708	Economy	13600.00
0005432568823	4708	Economy	13600.00
0005434559108	4708	Economy	13600.00
0005432568807	4708	Economy	13600.00
0005434082336	4708	Economy	13600.00
0005432460841	4708	Economy	13600.00
0005432460842	4708	Economy	13600.00
0005432568833	4708	Economy	13600.00
0005432568786	4708	Economy	13600.00
0005433451660	4708	Economy	13600.00
0005432568828	4708	Economy	13600.00
0005432568799	4708	Economy	13600.00
0005432460853	4708	Economy	13600.00
0005434082346	4708	Economy	13600.00
0005434082328	4708	Economy	13600.00
0005432568819	4708	Economy	13600.00
0005434559111	4708	Economy	13600.00
0005432571395	4708	Economy	13600.00
0005432460879	4708	Economy	13600.00
0005432460857	4708	Economy	13600.00
0005432568801	4708	Economy	13600.00
0005432568778	4708	Economy	13600.00
0005432170515	4708	Economy	13600.00
0005434559112	4708	Economy	13600.00
0005432568493	30515	Business	40900.00
0005432568579	30515	Business	40900.00
0005434082158	30515	Business	40900.00
0005432571357	30515	Business	40900.00
0005432568299	30515	Business	40900.00
0005432460264	30515	Business	40900.00
0005434082131	30515	Business	40900.00
0005432161197	30515	Business	40900.00
0005432213679	30515	Business	40900.00
0005432568348	30515	Business	40900.00
0005432213678	30515	Business	40900.00
0005432460449	30515	Business	40900.00
0005432460437	30515	Business	40900.00
0005432460369	30515	Business	40900.00
0005432568497	30515	Business	40900.00
0005432460578	30515	Business	40900.00
0005432460368	30515	Business	40900.00
0005432460329	30515	Business	40900.00
0005432568533	30515	Business	40900.00
0005432568196	30515	Business	40900.00
0005432568407	30515	Business	40900.00
0005432460372	30515	Economy	15000.00
0005432460230	30515	Economy	13600.00
0005434082143	30515	Economy	13600.00
0005432460532	30515	Economy	13600.00
0005432568391	30515	Economy	13600.00
0005434082101	30515	Economy	13600.00
0005432568461	30515	Economy	13600.00
0005432460576	30515	Economy	13600.00
0005432568152	30515	Economy	13600.00
0005432568417	30515	Economy	13600.00
0005434082133	30515	Economy	13600.00
0005434082069	30515	Economy	13600.00
0005432460366	30515	Economy	13600.00
0005432460575	30515	Economy	13600.00
0005432213680	30515	Economy	13600.00
0005432460485	30515	Economy	13600.00
0005432571359	30515	Economy	13600.00
0005434082151	30515	Economy	13600.00
0005432568495	30515	Economy	13600.00
0005432571372	30515	Economy	13600.00
0005432568307	30515	Economy	13600.00
0005432460373	30515	Economy	13600.00
0005432568373	30515	Economy	13600.00
0005432460249	30515	Economy	13600.00
0005432568474	30515	Economy	13600.00
0005432460448	30515	Economy	13600.00
0005432568557	30515	Economy	13600.00
0005433454904	30515	Economy	13600.00
0005432568515	30515	Economy	13600.00
0005432568453	30515	Economy	13600.00
0005432568511	30515	Economy	13600.00
0005432460468	30515	Economy	13600.00
0005432568341	30515	Economy	13600.00
0005432568464	30515	Economy	13600.00
0005432568292	30515	Economy	13600.00
0005432460450	30515	Economy	13600.00
0005434082134	30515	Economy	13600.00
0005432460331	30515	Economy	13600.00
0005432568365	30515	Economy	13600.00
0005432568122	30515	Economy	13600.00
0005432568600	30515	Economy	13600.00
0005434082171	30515	Economy	13600.00
0005432460486	30515	Economy	13600.00
0005432460318	30515	Economy	13600.00
0005434082015	30515	Economy	13600.00
0005432568363	30515	Economy	13600.00
0005432568000	30515	Economy	13600.00
0005432568330	30515	Economy	13600.00
0005432568443	30515	Economy	13600.00
0005432460696	30515	Economy	13600.00
0005432460494	30515	Economy	13600.00
0005432460319	30515	Economy	13600.00
0005432567988	30515	Economy	13600.00
0005432568170	30515	Economy	13600.00
0005432460559	30515	Economy	13600.00
0005432460217	30515	Economy	13600.00
0005432568108	30515	Economy	13600.00
0005432568350	30515	Economy	13600.00
0005432460507	30515	Economy	13600.00
0005432568494	30515	Economy	13600.00
0005432568324	30515	Economy	13600.00
0005432460531	30515	Economy	13600.00
0005432568331	30515	Economy	13600.00
0005432460648	30515	Economy	13600.00
0005432460342	30515	Economy	13600.00
0005432460445	30515	Economy	13600.00
0005432568109	30515	Economy	13600.00
0005432568487	30515	Economy	13600.00
0005432568246	30515	Economy	13600.00
0005432568139	30515	Economy	13600.00
0005432568390	30515	Economy	13600.00
0005432568394	30515	Economy	13600.00
0005432571358	30515	Economy	13600.00
0005432460451	30515	Economy	13600.00
0005434082137	30515	Economy	13600.00
0005432568349	30515	Economy	13600.00
0005432460420	30515	Economy	13600.00
0005432460661	30515	Economy	13600.00
0005434082154	30515	Economy	13600.00
0005432460452	30515	Economy	13600.00
0005432460438	30515	Economy	13600.00
0005432460492	30515	Economy	15000.00
0005432460515	30515	Economy	15000.00
0005432460506	30515	Economy	13600.00
0005432460358	30515	Economy	13600.00
0005434082150	30515	Economy	15000.00
0005432568403	30515	Economy	15000.00
0005432460280	30515	Economy	13600.00
0005432460530	30515	Economy	13600.00
0005432568463	30515	Economy	13600.00
0005432568475	30515	Economy	13600.00
0005432567922	30515	Economy	13600.00
0005432568203	30515	Economy	13600.00
0005432460265	30515	Economy	13600.00
0005432460330	30515	Economy	13600.00
0005432568439	30515	Economy	13600.00
0005432568273	30515	Economy	13600.00
0005432460399	30515	Economy	13600.00
0005434082102	30515	Economy	13600.00
0005432568362	30515	Economy	13600.00
0005432568395	30515	Economy	13600.00
0005432568374	30515	Economy	13600.00
0005432460691	30515	Economy	13600.00
0005434082113	30515	Economy	13600.00
0005432568412	30515	Economy	13600.00
0005432460582	30515	Economy	13600.00
0005432568392	30515	Economy	13600.00
0005432460690	30515	Economy	13600.00
0005434082054	30515	Economy	13600.00
0005432460335	30515	Economy	13600.00
0005432460508	30515	Economy	13600.00
0005434082127	30515	Economy	13600.00
0005432568306	30515	Economy	13600.00
0005432568418	30515	Economy	13600.00
0005432568567	30515	Economy	13600.00
0005432460558	30515	Economy	13600.00
0005432460400	30515	Economy	13600.00
0005432568510	30515	Economy	13600.00
0005432568512	30515	Economy	13600.00
0005432567946	30515	Economy	13600.00
0005434082112	30515	Economy	13600.00
0005434082172	30515	Economy	13600.00
0005433454903	30515	Economy	13600.00
0005432568436	30515	Economy	13600.00
0005432460447	30515	Economy	13600.00
0005432568178	30515	Economy	13600.00
0005432568137	30515	Economy	13600.00
0005432460317	30515	Economy	13600.00
0005432568462	30515	Economy	13600.00
0005432568504	30515	Economy	13600.00
0005434082099	30515	Economy	13600.00
0005432568314	30515	Economy	13600.00
0005432568496	30515	Economy	13600.00
0005432161198	30515	Economy	13600.00
0005432460254	30515	Economy	13600.00
0005432460557	30515	Economy	13600.00
0005432568534	30515	Economy	13600.00
0005432568334	30515	Economy	13600.00
0005432568335	30515	Economy	13600.00
0005432568201	30515	Economy	13600.00
0005432568389	30515	Economy	13600.00
0005434082016	30515	Economy	13600.00
0005432568321	30515	Economy	13600.00
0005432460543	30515	Economy	13600.00
0005432460533	30515	Economy	13600.00
0005434082012	30515	Economy	13600.00
0005432568488	30515	Economy	13600.00
0005432460343	30515	Economy	13600.00
0005432460349	30515	Economy	13600.00
0005432568396	30515	Economy	13600.00
0005432568599	30515	Economy	13600.00
0005435722101	13600	Economy	9900.00
0005435722102	13600	Economy	9900.00
0005435722079	21165	Economy	9900.00
0005435722088	21165	Economy	9900.00
0005435722086	21165	Economy	9900.00
0005435722080	21165	Economy	9900.00
0005435722087	21165	Economy	9900.00
0005432295932	22807	Economy	8800.00
0005432295931	22807	Economy	8800.00
0005432295930	22807	Economy	8800.00
0005433345066	11075	Business	23600.00
0005433345064	11075	Business	23600.00
0005433345083	11075	Business	23600.00
0005435508486	11075	Business	23600.00
0005433345070	11075	Business	23600.00
0005433345047	11075	Business	23600.00
0005433345103	11075	Business	23600.00
0005433345044	11075	Business	23600.00
0005433345062	11075	Business	23600.00
0005433345137	11075	Business	23600.00
0005433345115	11075	Business	23600.00
0005433345075	11075	Business	23600.00
0005433345053	11075	Economy	7900.00
0005433345058	11075	Economy	7900.00
0005435508467	11075	Economy	7900.00
0005433345145	11075	Economy	7900.00
0005435508469	11075	Economy	7900.00
0005433345110	11075	Economy	7900.00
0005435508484	11075	Economy	7900.00
0005435097386	11075	Economy	7900.00
0005433345146	11075	Economy	7900.00
0005433345087	11075	Economy	7900.00
0005435508451	11075	Economy	7900.00
0005433345099	11075	Economy	7900.00
0005435097391	11075	Economy	7900.00
0005433345073	11075	Economy	7900.00
0005433345131	11075	Economy	7900.00
0005433345130	11075	Economy	7900.00
0005433345082	11075	Economy	7900.00
0005433345127	11075	Economy	7900.00
0005433345105	11075	Economy	7900.00
0005435508500	11075	Economy	7900.00
0005433345056	11075	Economy	7900.00
0005433345078	11075	Economy	7900.00
0005433345054	11075	Economy	7900.00
0005433345072	11075	Economy	7900.00
0005433345139	11075	Economy	7900.00
0005435508475	11075	Economy	7900.00
0005433345092	11075	Economy	7900.00
0005435097387	11075	Economy	7900.00
0005433345084	11075	Economy	7900.00
0005433345060	11075	Economy	7900.00
0005435508437	11075	Economy	7900.00
0005435508450	11075	Economy	7900.00
0005433345123	11075	Economy	7900.00
0005433345134	11075	Economy	7900.00
0005433345111	11075	Economy	7900.00
0005435097394	11075	Economy	7900.00
0005433345142	11075	Economy	7900.00
0005433345119	11075	Economy	7900.00
0005433345125	11075	Economy	7900.00
0005433345057	11075	Economy	8600.00
0005433345093	11075	Economy	8600.00
0005433345088	11075	Economy	8600.00
0005433345046	11075	Economy	8600.00
0005433345107	11075	Economy	8600.00
0005433345118	11075	Economy	8600.00
0005433345055	11075	Economy	7900.00
0005435508489	11075	Economy	7900.00
0005435508468	11075	Economy	7900.00
0005435097388	11075	Economy	7900.00
0005433345077	11075	Economy	7900.00
0005433345143	11075	Economy	7900.00
0005435508449	11075	Economy	7900.00
0005433345074	11075	Economy	7900.00
0005433345114	11075	Economy	7900.00
0005433345089	11075	Economy	7900.00
0005435380342	11075	Economy	7900.00
0005433345052	11075	Economy	7900.00
0005433345050	11075	Economy	7900.00
0005433345112	11075	Economy	7900.00
0005433345116	11075	Economy	7900.00
0005433345126	11075	Economy	7900.00
0005433345071	11075	Economy	7900.00
0005433345117	11075	Economy	7900.00
0005433345080	11075	Economy	7900.00
0005433345120	11075	Economy	7900.00
0005433345059	11075	Economy	7900.00
0005433345106	11075	Economy	7900.00
0005433345068	11075	Economy	7900.00
0005433345076	11075	Economy	7900.00
0005433345108	11075	Economy	7900.00
0005433345132	11075	Economy	7900.00
0005433345121	11075	Economy	7900.00
0005433345138	11075	Economy	7900.00
0005433345097	11075	Economy	7900.00
0005433345090	11075	Economy	7900.00
0005433345133	11075	Economy	7900.00
0005433345091	11075	Economy	7900.00
0005433345109	11075	Economy	7900.00
0005433345136	11075	Economy	7900.00
0005433345094	11075	Economy	7900.00
0005433345128	11075	Economy	7900.00
0005433345048	11075	Economy	7900.00
0005433345096	11075	Economy	7900.00
0005433345045	11075	Economy	7900.00
0005433345069	11075	Economy	7900.00
0005433345086	11075	Economy	7900.00
0005435380318	11075	Economy	7900.00
0005435508436	11075	Economy	7900.00
0005433345049	11075	Economy	7900.00
0005435508505	11075	Economy	7900.00
0005433345081	11075	Economy	7900.00
0005433345098	11075	Economy	7900.00
0005435097393	11075	Economy	7900.00
0005433345113	11075	Economy	7900.00
0005433345104	11075	Economy	7900.00
0005433345122	11075	Economy	7900.00
0005433345063	11075	Economy	7900.00
0005433345051	11075	Economy	7900.00
0005433345129	11075	Economy	7900.00
0005433345065	11075	Economy	7900.00
0005435097390	11075	Economy	7900.00
0005433345140	11075	Economy	7900.00
0005433345135	11075	Economy	7900.00
0005433345102	11075	Economy	7900.00
0005433345141	11075	Economy	7900.00
0005433345061	11075	Economy	7900.00
0005433345100	11075	Economy	7900.00
0005433345085	11075	Economy	7900.00
0005433345124	11075	Economy	7900.00
0005435508456	11075	Economy	7900.00
0005433345101	11075	Economy	7900.00
0005433345095	11075	Economy	7900.00
0005433345079	11075	Economy	7900.00
0005435097392	11075	Economy	7900.00
0005433345067	11075	Economy	7900.00
0005435097389	11075	Economy	7900.00
0005433345144	11075	Economy	7900.00
0005433344023	17091	Business	23600.00
0005433344306	17091	Business	23600.00
0005433344250	17091	Business	23600.00
0005433344307	17091	Business	23600.00
0005433344670	17091	Business	23600.00
0005433344211	17091	Business	23600.00
0005433344153	17091	Business	23600.00
0005433344029	17091	Business	23600.00
0005433343941	17091	Business	23600.00
0005433344112	17091	Business	23600.00
0005435097322	17091	Business	23600.00
0005433344531	17091	Business	23600.00
0005433344419	17091	Economy	7900.00
0005435545879	17091	Economy	7900.00
0005435380393	17091	Economy	7900.00
0005435545876	17091	Economy	7900.00
0005433344421	17091	Economy	7900.00
0005433344249	17091	Economy	7900.00
0005433344073	17091	Economy	7900.00
0005433344521	17091	Economy	7900.00
0005433344101	17091	Economy	7900.00
0005433344033	17091	Economy	7900.00
0005435097318	17091	Economy	7900.00
0005433344501	17091	Economy	7900.00
0005433344082	17091	Economy	7900.00
0005433343852	17091	Economy	7900.00
0005433343712	17091	Economy	7900.00
0005433344416	17091	Economy	7900.00
0005433343939	17091	Economy	7900.00
0005435545877	17091	Economy	7900.00
0005432293256	17091	Economy	7900.00
0005433344030	17091	Economy	7900.00
0005433344080	17091	Economy	7900.00
0005433344100	17091	Economy	7900.00
0005433343962	17091	Economy	7900.00
0005433343889	17091	Economy	7900.00
0005435380396	17091	Economy	7900.00
0005433343982	17091	Economy	7900.00
0005433344549	17091	Economy	7900.00
0005435545878	17091	Economy	7900.00
0005433343970	17091	Economy	7900.00
0005433344402	17091	Economy	7900.00
0005433344143	17091	Economy	7900.00
0005433344167	17091	Economy	7900.00
0005435097308	17091	Economy	7900.00
0005435380394	17091	Economy	7900.00
0005435545881	17091	Economy	7900.00
0005433344467	17091	Economy	7900.00
0005433344075	17091	Economy	7900.00
0005435545882	17091	Economy	7900.00
0005433344406	17091	Economy	7900.00
0005435545874	17091	Economy	8600.00
0005433343791	17091	Economy	8600.00
0005433344304	17091	Economy	8600.00
0005433344013	17091	Economy	8600.00
0005435545880	17091	Economy	8600.00
0005432293257	17091	Economy	7900.00
0005433344311	17091	Economy	7900.00
0005433343845	17091	Economy	7900.00
0005433344407	17091	Economy	7900.00
0005433343607	17091	Economy	7900.00
0005433343973	17091	Economy	7900.00
0005433344229	17091	Economy	7900.00
0005433343762	17091	Economy	7900.00
0005433343482	17091	Economy	7900.00
0005435097307	17091	Economy	7900.00
0005435545873	17091	Economy	7900.00
0005433343481	17091	Economy	7900.00
0005433344422	17091	Economy	7900.00
0005433344408	17091	Economy	7900.00
0005433344312	17091	Economy	7900.00
0005433343938	17091	Economy	7900.00
0005433343755	17091	Economy	7900.00
0005433343972	17091	Economy	7900.00
0005433344198	17091	Economy	7900.00
0005435097312	17091	Economy	7900.00
0005433343447	17091	Economy	7900.00
0005433343790	17091	Economy	7900.00
0005433344282	17091	Economy	7900.00
0005433343903	17091	Economy	7900.00
0005433344409	17091	Economy	7900.00
0005435097314	17091	Economy	7900.00
0005435097313	17091	Economy	7900.00
0005433344001	17091	Economy	7900.00
0005433344647	17091	Economy	7900.00
0005433344079	17091	Economy	7900.00
0005433343987	17091	Economy	7900.00
0005433343940	17091	Economy	7900.00
0005433343750	17091	Economy	7900.00
0005432293255	17091	Economy	7900.00
0005433344060	17091	Economy	7900.00
0005433344227	17091	Economy	7900.00
0005435545875	17091	Economy	7900.00
0005433343963	17091	Economy	7900.00
0005433343839	17091	Economy	7900.00
0005435097302	17091	Economy	7900.00
0005433344139	17091	Economy	7900.00
0005433343890	17091	Economy	7900.00
0005433344134	17091	Economy	7900.00
0005433344152	17091	Economy	7900.00
0005433344392	17091	Economy	7900.00
0005433343836	17091	Economy	7900.00
0005435380395	17091	Economy	7900.00
0005433343846	17091	Economy	7900.00
0005433344389	17091	Economy	7900.00
0005433344239	17091	Economy	7900.00
0005433344169	17091	Economy	7900.00
0005435380392	17091	Economy	7900.00
0005435097306	17091	Economy	7900.00
0005433344388	17091	Economy	7900.00
0005433344335	17091	Economy	7900.00
0005433344324	17091	Economy	7900.00
0005433344084	17091	Economy	7900.00
0005433344228	17091	Economy	7900.00
0005433344168	17091	Economy	7900.00
0005433343761	17091	Economy	7900.00
0005433344032	17091	Economy	7900.00
0005435545883	17091	Economy	7900.00
0005433344145	17091	Economy	7900.00
0005433344098	17091	Economy	7900.00
0005433343812	17091	Economy	7900.00
0005433343749	17091	Economy	7900.00
0005433344240	17091	Economy	7900.00
0005433344097	17091	Economy	7900.00
0005433344305	17091	Economy	7900.00
0005433344144	17091	Economy	7900.00
0005433476983	9112	Business	26600.00
0005433476986	9112	Business	26600.00
0005433507513	9112	Business	26600.00
0005432920180	9112	Business	26600.00
0005432920085	9112	Business	26600.00
0005432919997	9112	Business	26600.00
0005433507533	9112	Business	26600.00
0005433507525	9112	Economy	8900.00
0005432920102	9112	Economy	8900.00
0005433481319	9112	Economy	8900.00
0005432920027	9112	Economy	8900.00
0005432920063	9112	Economy	8900.00
0005432919998	9112	Economy	8900.00
0005432920103	9112	Economy	8900.00
0005433507517	9112	Economy	9800.00
0005433476985	9112	Economy	9800.00
0005433507530	9112	Economy	9800.00
0005433507532	9112	Economy	9800.00
0005433507519	9112	Economy	8900.00
0005433481314	9112	Economy	8900.00
0005433507516	9112	Economy	8900.00
0005432920028	9112	Economy	8900.00
0005433507534	9112	Economy	8900.00
0005433476988	9112	Economy	8900.00
0005433507514	9112	Economy	8900.00
0005432920065	9112	Economy	8900.00
0005433507531	9112	Economy	8900.00
0005433476987	9112	Economy	8900.00
0005433481318	9112	Economy	8900.00
0005433476982	9112	Economy	8900.00
0005433481315	9112	Economy	8900.00
0005433507529	9112	Economy	8900.00
0005433476989	9112	Economy	8900.00
0005432919996	9112	Economy	8900.00
0005433507526	9112	Economy	8900.00
0005433481316	9112	Economy	8900.00
0005432920053	9112	Economy	8900.00
0005433507518	9112	Economy	8900.00
0005432920101	9112	Economy	8900.00
0005432920086	9112	Economy	8900.00
0005432920052	9112	Economy	8900.00
0005433507522	9112	Economy	8900.00
0005432920114	9112	Economy	8900.00
0005433507515	9112	Economy	8900.00
0005432919972	9112	Economy	8900.00
0005433476984	9112	Economy	8900.00
0005433481317	9112	Economy	8900.00
0005433507521	9112	Economy	8900.00
0005432920092	9112	Economy	8900.00
0005432920015	9112	Economy	8900.00
0005432920042	9112	Economy	8900.00
0005433507524	9112	Economy	8900.00
0005432920115	9112	Economy	8900.00
0005433481320	9112	Economy	8900.00
0005433481321	9112	Economy	8900.00
0005432920142	9112	Economy	8900.00
0005433507520	9112	Economy	8900.00
0005432920062	9112	Economy	8900.00
0005433507523	9112	Economy	8900.00
0005432920016	9112	Economy	8900.00
0005433507528	9112	Economy	8900.00
0005433507527	9112	Economy	8900.00
0005432920143	9112	Economy	8900.00
0005433507353	20435	Business	26600.00
0005432920286	20435	Business	26600.00
0005432920283	20435	Business	26600.00
0005432920289	20435	Business	26600.00
0005433481305	20435	Business	26600.00
0005433507364	20435	Business	26600.00
0005433507401	20435	Business	26600.00
0005432920275	20435	Business	26600.00
0005433507424	20435	Economy	8900.00
0005433481258	20435	Economy	8900.00
0005433507363	20435	Economy	8900.00
0005433481242	20435	Economy	8900.00
0005433481293	20435	Economy	8900.00
0005432920285	20435	Economy	8900.00
0005432920293	20435	Economy	8900.00
0005432920284	20435	Economy	8900.00
0005433507362	20435	Economy	8900.00
0005433481261	20435	Economy	8900.00
0005433507374	20435	Economy	8900.00
0005432920288	20435	Economy	8900.00
0005433481304	20435	Economy	8900.00
0005433507425	20435	Economy	8900.00
0005433481272	20435	Economy	8900.00
0005433481247	20435	Economy	8900.00
0005432920274	20435	Economy	8900.00
0005433507393	20435	Economy	8900.00
0005432920281	20435	Economy	8900.00
0005433507352	20435	Economy	8900.00
0005433481281	20435	Economy	8900.00
0005432920292	20435	Economy	8900.00
0005432920287	20435	Economy	8900.00
0005432920282	20435	Economy	8900.00
0005433481260	20435	Economy	8900.00
0005433507426	20435	Economy	8900.00
0005433507405	20435	Economy	8900.00
0005432920277	20435	Economy	8900.00
0005432920290	20435	Economy	8900.00
0005432920273	20435	Economy	8900.00
0005432920278	20435	Economy	8900.00
0005432920280	20435	Economy	8900.00
0005433507404	20435	Economy	8900.00
0005432920276	20435	Economy	8900.00
0005432920291	20435	Economy	8900.00
0005433481248	20435	Economy	8900.00
0005433507403	20435	Economy	8900.00
0005433481243	20435	Economy	8900.00
0005432920279	20435	Economy	8900.00
0005432920294	20435	Economy	8900.00
0005433507389	20435	Economy	8900.00
0005433507402	20435	Economy	8900.00
0005432396316	10155	Economy	5800.00
0005432394178	10155	Economy	5800.00
0005432396314	10155	Economy	5800.00
0005432394179	10155	Economy	5800.00
0005432396313	10155	Economy	5800.00
0005432396315	10155	Economy	5800.00
0005432394180	10155	Economy	5800.00
0005432396285	18376	Economy	5800.00
0005432400156	18376	Economy	5800.00
0005432396298	18376	Economy	5800.00
0005435179413	18376	Economy	5800.00
0005432400160	18376	Economy	5800.00
0005435179705	18376	Economy	5800.00
0005432396299	18376	Economy	5800.00
0005435179704	18376	Economy	5800.00
0005432400159	18376	Economy	5800.00
0005432396300	18376	Economy	5800.00
0005432400161	18376	Economy	5800.00
0005435179412	18376	Economy	5800.00
0005435554249	10985	Business	9500.00
0005435626307	10985	Business	9500.00
0005435126741	10985	Business	9500.00
0005435556724	10985	Business	9500.00
0005435554252	10985	Business	9500.00
0005435556725	10985	Business	9500.00
0005435626313	10985	Business	9500.00
0005435554236	10985	Business	9500.00
0005435126800	10985	Business	9500.00
0005435626288	10985	Economy	3200.00
0005435126621	10985	Economy	3200.00
0005435626340	10985	Economy	3200.00
0005435626383	10985	Economy	3200.00
0005435626382	10985	Economy	3200.00
0005435626306	10985	Economy	3200.00
0005435626338	10985	Economy	3200.00
0005435626349	10985	Economy	3500.00
0005435126815	10985	Economy	3500.00
0005435556726	10985	Economy	3500.00
0005435556727	10985	Economy	3500.00
0005435126688	10985	Economy	3200.00
0005435626372	10985	Economy	3200.00
0005435626364	10985	Economy	3200.00
0005435626303	10985	Economy	3200.00
0005435126700	10985	Economy	3200.00
0005434411860	10985	Economy	3200.00
0005435126567	10985	Economy	3200.00
0005435126704	10985	Economy	3200.00
0005435126811	10985	Economy	3200.00
0005435554250	10985	Economy	3200.00
0005435626323	10985	Economy	3200.00
0005435126937	10985	Economy	3200.00
0005435126622	10985	Economy	3200.00
0005434928354	10985	Economy	3200.00
0005434411864	10985	Economy	3200.00
0005434411862	10985	Economy	3200.00
0005435126754	10985	Economy	3200.00
0005435626305	10985	Economy	3200.00
0005435626348	10985	Economy	3200.00
0005435626380	10985	Economy	3200.00
0005435626363	10985	Economy	3200.00
0005435626322	10985	Economy	3200.00
0005435126739	10985	Economy	3200.00
0005435626377	10985	Economy	3200.00
0005434411863	10985	Economy	3200.00
0005435554246	10985	Economy	3200.00
0005435626379	10985	Economy	3200.00
0005435126825	10985	Economy	3200.00
0005434928356	10985	Economy	3200.00
0005435126812	10985	Economy	3200.00
0005435626335	10985	Economy	3200.00
0005435556717	10985	Economy	3200.00
0005434928355	10985	Economy	3200.00
0005435126742	10985	Economy	3200.00
0005435126620	10985	Economy	3200.00
0005435626341	10985	Economy	3200.00
0005435626304	10985	Economy	3200.00
0005435126892	10985	Economy	3200.00
0005435126820	10985	Economy	3200.00
0005435126710	10985	Economy	3200.00
0005435126705	10985	Economy	3200.00
0005435126793	10985	Economy	3200.00
0005435554245	10985	Economy	3200.00
0005435554237	10985	Economy	3200.00
0005435126697	10985	Economy	3200.00
0005435626373	10985	Economy	3200.00
0005434411861	10985	Economy	3200.00
0005435626365	10985	Economy	3200.00
0005435127148	14699	Business	9500.00
0005435626534	14699	Business	9500.00
0005434928329	14699	Business	9500.00
0005435127162	14699	Business	9500.00
0005435127166	14699	Business	9500.00
0005435127184	14699	Business	9500.00
0005435626535	14699	Business	9500.00
0005435127186	14699	Business	9500.00
0005435127180	14699	Economy	3200.00
0005435626533	14699	Economy	3200.00
0005435554279	14699	Economy	3200.00
0005435127179	14699	Economy	3200.00
0005435127168	14699	Economy	3200.00
0005435127157	14699	Economy	3200.00
0005435127149	14699	Economy	3500.00
0005435626531	14699	Economy	3500.00
0005435127188	14699	Economy	3500.00
0005435127152	14699	Economy	3500.00
0005435127181	14699	Economy	3500.00
0005435127158	14699	Economy	3200.00
0005435127171	14699	Economy	3200.00
0005434411810	14699	Economy	3200.00
0005435127173	14699	Economy	3200.00
0005435127163	14699	Economy	3200.00
0005435127172	14699	Economy	3200.00
0005435626532	14699	Economy	3200.00
0005435554280	14699	Economy	3200.00
0005435626537	14699	Economy	3200.00
0005435554276	14699	Economy	3200.00
0005435626538	14699	Economy	3200.00
0005435127175	14699	Economy	3200.00
0005435626536	14699	Economy	3200.00
0005435127170	14699	Economy	3200.00
0005434411808	14699	Economy	3200.00
0005435127161	14699	Economy	3200.00
0005435127178	14699	Economy	3200.00
0005435127187	14699	Economy	3200.00
0005435127182	14699	Economy	3200.00
0005435127176	14699	Economy	3200.00
0005435127169	14699	Economy	3200.00
0005435626542	14699	Economy	3200.00
0005435626530	14699	Economy	3200.00
0005435556741	14699	Economy	3200.00
0005434411807	14699	Economy	3200.00
0005435127153	14699	Economy	3200.00
0005435127155	14699	Economy	3200.00
0005435127156	14699	Economy	3200.00
0005435554277	14699	Economy	3200.00
0005434411813	14699	Economy	3200.00
0005435127183	14699	Economy	3200.00
0005435127185	14699	Economy	3200.00
0005435127189	14699	Economy	3200.00
0005435127154	14699	Economy	3200.00
0005435127160	14699	Economy	3200.00
0005435556742	14699	Economy	3200.00
0005435626541	14699	Economy	3200.00
0005435626539	14699	Economy	3200.00
0005435554278	14699	Economy	3200.00
0005434411812	14699	Economy	3200.00
0005435127159	14699	Economy	3200.00
0005435127165	14699	Economy	3200.00
0005435127150	14699	Economy	3200.00
0005434411809	14699	Economy	3200.00
0005435127174	14699	Economy	3200.00
0005435127167	14699	Economy	3200.00
0005434928328	14699	Economy	3200.00
0005435127164	14699	Economy	3200.00
0005435127177	14699	Economy	3200.00
0005435127151	14699	Economy	3200.00
0005435626540	14699	Economy	3200.00
0005435715809	7149	Business	86900.00
0005435715795	7149	Business	86900.00
0005432400200	7149	Business	86900.00
0005435443435	7149	Business	86900.00
0005435715808	7149	Business	86900.00
0005435715799	7149	Business	86900.00
0005435216605	7149	Business	86900.00
0005435443404	7149	Business	86900.00
0005435715797	7149	Economy	29000.00
0005435715803	7149	Economy	29000.00
0005435219223	7149	Economy	29000.00
0005435216603	7149	Economy	31900.00
0005435443402	7149	Economy	31900.00
0005435443410	7149	Economy	31900.00
0005432398268	7149	Economy	29000.00
0005435715806	7149	Economy	29000.00
0005435443393	7149	Economy	29000.00
0005435443387	7149	Economy	29000.00
0005435715794	7149	Economy	29000.00
0005435216604	7149	Economy	29000.00
0005435715800	7149	Economy	29000.00
0005435216612	7149	Economy	29000.00
0005435715810	7149	Economy	29000.00
0005435715798	7149	Economy	29000.00
0005432400197	7149	Economy	29000.00
0005432400199	7149	Economy	29000.00
0005435443430	7149	Economy	29000.00
0005435219211	7149	Economy	29000.00
0005435715804	7149	Economy	29000.00
0005435443405	7149	Economy	29000.00
0005432400198	7149	Economy	29000.00
0005435715807	7149	Economy	29000.00
0005435443392	7149	Economy	29000.00
0005435715796	7149	Economy	29000.00
0005435443431	7149	Economy	29000.00
0005435443391	7149	Economy	29000.00
0005435715801	7149	Economy	29000.00
0005432398270	7149	Economy	29000.00
0005432398271	7149	Economy	29000.00
0005435178511	7149	Economy	29000.00
0005435216606	7149	Economy	29000.00
0005432398269	7149	Economy	29000.00
0005435715805	7149	Economy	29000.00
0005435715802	7149	Economy	29000.00
0005435178514	7149	Economy	29000.00
0005435217750	27082	Business	86900.00
0005435217747	27082	Business	86900.00
0005435715659	27082	Business	86900.00
0005435715703	27082	Business	86900.00
0005435216630	27082	Business	86900.00
0005435178522	27082	Business	86900.00
0005435715710	27082	Business	86900.00
0005432394141	27082	Business	86900.00
0005435218125	27082	Economy	29000.00
0005432394156	27082	Economy	29000.00
0005435715660	27082	Economy	29000.00
0005432394150	27082	Economy	29000.00
0005435178524	27082	Economy	29000.00
0005435216624	27082	Economy	29000.00
0005435178523	27082	Economy	29000.00
0005435443497	27082	Economy	29000.00
0005435217751	27082	Economy	31900.00
0005435443494	27082	Economy	31900.00
0005435715626	27082	Economy	31900.00
0005432394152	27082	Economy	31900.00
0005435218124	27082	Economy	29000.00
0005435715711	27082	Economy	29000.00
0005435217753	27082	Economy	29000.00
0005435216622	27082	Economy	29000.00
0005435443499	27082	Economy	29000.00
0005435216621	27082	Economy	29000.00
0005435715658	27082	Economy	29000.00
0005435218127	27082	Economy	29000.00
0005432394137	27082	Economy	29000.00
0005435443498	27082	Economy	29000.00
0005435715684	27082	Economy	29000.00
0005432394143	27082	Economy	29000.00
0005435218128	27082	Economy	29000.00
0005435443495	27082	Economy	29000.00
0005435715653	27082	Economy	29000.00
0005432394138	27082	Economy	29000.00
0005435216627	27082	Economy	29000.00
0005435715716	27082	Economy	29000.00
0005435216629	27082	Economy	29000.00
0005435715661	27082	Economy	29000.00
0005435218123	27082	Economy	29000.00
0005435217752	27082	Economy	29000.00
0005435443500	27082	Economy	29000.00
0005432394151	27082	Economy	29000.00
0005435443496	27082	Economy	29000.00
0005435217748	27082	Economy	29000.00
0005435715645	27082	Economy	29000.00
0005435216626	27082	Economy	29000.00
0005435217749	27082	Economy	29000.00
0005432398225	27082	Economy	29000.00
0005435715715	27082	Economy	29000.00
0005435218126	27082	Economy	29000.00
0005435715728	27082	Economy	29000.00
0005435715532	27082	Economy	29000.00
0005435715727	27082	Economy	29000.00
0005435216623	27082	Economy	29000.00
0005435443493	27082	Economy	29000.00
0005435715623	27082	Economy	29000.00
0005435715685	27082	Economy	29000.00
0005435715694	27082	Economy	29000.00
0005435216628	27082	Economy	29000.00
0005435443501	27082	Economy	29000.00
0005435216625	27082	Economy	29000.00
0005434085023	2729	Economy	7700.00
0005434085019	2729	Economy	7700.00
0005433060452	2729	Economy	7700.00
0005434085021	2729	Economy	7700.00
0005433060442	2729	Economy	7700.00
0005433060453	2729	Economy	7700.00
0005434085022	2729	Economy	7700.00
0005434085020	2729	Economy	7700.00
0005433060467	28519	Economy	7700.00
0005433060465	28519	Economy	7700.00
0005434084981	28519	Economy	7700.00
0005434084979	28519	Economy	7700.00
0005434084973	28519	Economy	7700.00
0005434084978	28519	Economy	7700.00
0005434084984	28519	Economy	7700.00
0005433060466	28519	Economy	7700.00
0005434084982	28519	Economy	7700.00
0005434084985	28519	Economy	7700.00
0005434085000	28519	Economy	7700.00
0005433788278	11169	Economy	27100.00
0005435548520	11169	Economy	27100.00
0005435548534	11169	Economy	27100.00
0005435548530	11169	Economy	24600.00
0005435548556	11169	Economy	24600.00
0005433788287	11169	Economy	24600.00
0005433788282	11169	Economy	24600.00
0005433788292	11169	Economy	24600.00
0005433788284	11169	Economy	24600.00
0005433788289	11169	Economy	24600.00
0005435548519	11169	Economy	24600.00
0005433788285	11169	Economy	24600.00
0005435548533	11169	Economy	24600.00
0005435548517	11169	Economy	24600.00
0005435548561	11169	Economy	24600.00
0005435548518	11169	Economy	24600.00
0005435548535	11169	Economy	24600.00
0005433788283	11169	Economy	24600.00
0005433788290	11169	Economy	24600.00
0005433788277	11169	Economy	24600.00
0005433788291	11169	Economy	24600.00
0005433788279	11169	Economy	24600.00
0005435548536	11169	Economy	24600.00
0005433788286	11169	Economy	24600.00
0005433788288	11169	Economy	24600.00
0005435548515	11169	Economy	24600.00
0005433788280	11169	Economy	24600.00
0005435548555	11169	Economy	24600.00
0005435548537	11169	Economy	24600.00
0005433788293	11169	Economy	24600.00
0005435548521	11169	Economy	24600.00
0005433788281	11169	Economy	24600.00
0005435548529	11169	Economy	24600.00
0005435548514	11169	Economy	24600.00
0005435548516	11169	Economy	24600.00
0005433788219	20669	Economy	27100.00
0005433788218	20669	Economy	27100.00
0005435548574	20669	Economy	27100.00
0005433788224	20669	Economy	24600.00
0005435548571	20669	Economy	24600.00
0005435548575	20669	Economy	24600.00
0005435548579	20669	Economy	24600.00
0005435548576	20669	Economy	24600.00
0005433788243	20669	Economy	24600.00
0005435548578	20669	Economy	24600.00
0005433788220	20669	Economy	24600.00
0005433788226	20669	Economy	24600.00
0005433788240	20669	Economy	24600.00
0005435548573	20669	Economy	24600.00
0005435548572	20669	Economy	24600.00
0005433788227	20669	Economy	24600.00
0005435548577	20669	Economy	24600.00
0005433788221	20669	Economy	24600.00
0005433788244	20669	Economy	24600.00
0005435541240	11372	Business	20200.00
0005435541279	11372	Business	20200.00
0005435518095	11372	Business	20200.00
0005435541226	11372	Business	20200.00
0005435518109	11372	Business	20200.00
0005435518063	11372	Economy	6700.00
0005435541308	11372	Economy	6700.00
0005435541290	11372	Economy	6700.00
0005435518100	11372	Economy	6700.00
0005435541209	11372	Economy	7400.00
0005435541149	11372	Economy	7400.00
0005435518157	11372	Economy	6700.00
0005435518121	11372	Economy	6700.00
0005435541262	11372	Economy	6700.00
0005435541280	11372	Economy	6700.00
0005435541309	11372	Economy	6700.00
0005435541208	11372	Economy	6700.00
0005435518174	11372	Economy	6700.00
0005435541274	11372	Economy	6700.00
0005435518096	11372	Economy	6700.00
0005435518140	11372	Economy	6700.00
0005435541273	11372	Economy	6700.00
0005435518175	11372	Economy	6700.00
0005435541170	11372	Economy	6700.00
0005435518097	11372	Economy	6700.00
0005435541234	11372	Economy	6700.00
0005435518116	11372	Economy	6700.00
0005435518023	11372	Economy	6700.00
0005435518183	11372	Economy	6700.00
0005435518101	11372	Economy	6700.00
0005435541233	11372	Economy	6700.00
0005435541169	11372	Economy	6700.00
0005435541235	11372	Economy	6700.00
0005435518108	11372	Economy	6700.00
0005435541275	11372	Economy	6700.00
0005435518182	11372	Economy	6700.00
0005435541281	11372	Economy	6700.00
0005435518111	11372	Economy	6700.00
0005435518074	11372	Economy	6700.00
0005435541310	11372	Economy	6700.00
0005435541148	11372	Economy	6700.00
0005435541197	11372	Economy	6700.00
0005435541225	11372	Economy	6700.00
0005435541230	11372	Economy	6700.00
0005435518120	11372	Economy	6700.00
0005435541236	11372	Economy	6700.00
0005435518110	11372	Economy	6700.00
0005435518131	11372	Economy	6700.00
0005435529655	22233	Business	20200.00
0005432294531	22233	Business	20200.00
0005435529656	22233	Business	20200.00
0005435529669	22233	Business	20200.00
0005435541401	22233	Business	20200.00
0005435529663	22233	Business	20200.00
0005435529667	22233	Economy	6700.00
0005432294533	22233	Economy	6700.00
0005435529661	22233	Economy	6700.00
0005435529658	22233	Economy	6700.00
0005435541404	22233	Economy	6700.00
0005435529660	22233	Economy	6700.00
0005435529657	22233	Economy	6700.00
0005435529665	22233	Economy	6700.00
0005435529997	22233	Economy	6700.00
0005435529996	22233	Economy	7400.00
0005435541411	22233	Economy	7400.00
0005435541412	22233	Economy	7400.00
0005435541405	22233	Economy	7400.00
0005435541407	22233	Economy	6700.00
0005435529675	22233	Economy	6700.00
0005435541410	22233	Economy	6700.00
0005435529998	22233	Economy	6700.00
0005435541408	22233	Economy	6700.00
0005435541398	22233	Economy	6700.00
0005435529664	22233	Economy	6700.00
0005435541400	22233	Economy	6700.00
0005435529654	22233	Economy	6700.00
0005435541417	22233	Economy	6700.00
0005435529670	22233	Economy	6700.00
0005435541399	22233	Economy	6700.00
0005435541403	22233	Economy	6700.00
0005435541415	22233	Economy	6700.00
0005435541413	22233	Economy	6700.00
0005432294532	22233	Economy	6700.00
0005435529673	22233	Economy	6700.00
0005435529668	22233	Economy	6700.00
0005435541402	22233	Economy	6700.00
0005435541419	22233	Economy	6700.00
0005435529999	22233	Economy	6700.00
0005435541418	22233	Economy	6700.00
0005435529672	22233	Economy	6700.00
0005435529671	22233	Economy	6700.00
0005432294534	22233	Economy	6700.00
0005435529995	22233	Economy	6700.00
0005435529659	22233	Economy	6700.00
0005435541414	22233	Economy	6700.00
0005435530000	22233	Economy	6700.00
0005435529674	22233	Economy	6700.00
0005435529666	22233	Economy	6700.00
0005435541406	22233	Economy	6700.00
0005435541416	22233	Economy	6700.00
0005435541409	22233	Economy	6700.00
0005435529662	22233	Economy	6700.00
0005433401025	2286	Business	20200.00
0005433251889	2286	Business	20200.00
0005434908295	2286	Business	20200.00
0005435787456	2286	Business	20200.00
0005434908318	2286	Business	20200.00
0005434908300	2286	Business	20200.00
0005433251821	2286	Business	20200.00
0005434908297	2286	Business	20200.00
0005435787454	2286	Business	20200.00
0005433251874	2286	Economy	6700.00
0005434908309	2286	Economy	6700.00
0005434908292	2286	Economy	6700.00
0005433251788	2286	Economy	6700.00
0005434908325	2286	Economy	6700.00
0005434908327	2286	Economy	6700.00
0005434908301	2286	Economy	6700.00
0005434908290	2286	Economy	6700.00
0005434908302	2286	Economy	6700.00
0005433401009	2286	Economy	6700.00
0005434908299	2286	Economy	7400.00
0005434908307	2286	Economy	7400.00
0005434908322	2286	Economy	7400.00
0005434908310	2286	Economy	7400.00
0005434908323	2286	Economy	7400.00
0005434908316	2286	Economy	6700.00
0005434908283	2286	Economy	6700.00
0005434908285	2286	Economy	6700.00
0005433251890	2286	Economy	6700.00
0005434908326	2286	Economy	6700.00
0005434908279	2286	Economy	6700.00
0005434908305	2286	Economy	6700.00
0005434908313	2286	Economy	6700.00
0005434908280	2286	Economy	6700.00
0005433251912	2286	Economy	6700.00
0005434908330	2286	Economy	6700.00
0005434908331	2286	Economy	6700.00
0005434908334	2286	Economy	6700.00
0005433251837	2286	Economy	6700.00
0005433251968	2286	Economy	6700.00
0005434908281	2286	Economy	6700.00
0005434908308	2286	Economy	6700.00
0005434908298	2286	Economy	6700.00
0005434908317	2286	Economy	6700.00
0005434908329	2286	Economy	6700.00
0005435787453	2286	Economy	6700.00
0005434908333	2286	Economy	6700.00
0005434908288	2286	Economy	6700.00
0005433251846	2286	Economy	6700.00
0005434908303	2286	Economy	6700.00
0005433251709	2286	Economy	6700.00
0005433251980	2286	Economy	6700.00
0005434908289	2286	Economy	6700.00
0005434908296	2286	Economy	6700.00
0005433251954	2286	Economy	6700.00
0005435787455	2286	Economy	6700.00
0005434908293	2286	Economy	6700.00
0005434908324	2286	Economy	6700.00
0005434908314	2286	Economy	6700.00
0005434908321	2286	Economy	6700.00
0005434908306	2286	Economy	6700.00
0005434908291	2286	Economy	6700.00
0005433251778	2286	Economy	6700.00
0005434908332	2286	Economy	6700.00
0005433251708	2286	Economy	6700.00
0005433251939	2286	Economy	6700.00
0005434908282	2286	Economy	6700.00
0005433251811	2286	Economy	6700.00
0005434908294	2286	Economy	6700.00
0005434908286	2286	Economy	6700.00
0005434908328	2286	Economy	6700.00
0005433251840	2286	Economy	6700.00
0005434908304	2286	Economy	6700.00
0005434908320	2286	Economy	6700.00
0005434908311	2286	Economy	6700.00
0005434908335	2286	Economy	6700.00
0005434908287	2286	Economy	6700.00
0005434908284	2286	Economy	6700.00
0005434908319	2286	Economy	6700.00
0005434908312	2286	Economy	6700.00
0005434908315	2286	Economy	6700.00
0005433251779	2286	Economy	6700.00
0005433252087	25607	Business	20200.00
0005433252085	25607	Business	20200.00
0005434907933	25607	Business	20200.00
0005434907770	25607	Business	20200.00
0005434907560	25607	Business	20200.00
0005434907885	25607	Business	20200.00
0005434907940	25607	Business	20200.00
0005433252096	25607	Business	20200.00
0005434907972	25607	Business	20200.00
0005434907819	25607	Business	20200.00
0005433401042	25607	Business	20200.00
0005434907618	25607	Economy	6700.00
0005434907768	25607	Economy	6700.00
0005434907941	25607	Economy	6700.00
0005434907520	25607	Economy	6700.00
0005433252076	25607	Economy	6700.00
0005433252094	25607	Economy	6700.00
0005433252088	25607	Economy	7400.00
0005433252078	25607	Economy	7400.00
0005433252081	25607	Economy	7400.00
0005434907670	25607	Economy	7400.00
0005433252072	25607	Economy	7400.00
0005433252082	25607	Economy	6700.00
0005434907796	25607	Economy	6700.00
0005434907802	25607	Economy	6700.00
0005434907762	25607	Economy	6700.00
0005433252066	25607	Economy	6700.00
0005434907793	25607	Economy	6700.00
0005434907805	25607	Economy	6700.00
0005434907660	25607	Economy	6700.00
0005434907800	25607	Economy	6700.00
0005433252091	25607	Economy	6700.00
0005433252077	25607	Economy	6700.00
0005434907804	25607	Economy	6700.00
0005434907816	25607	Economy	6700.00
0005434907769	25607	Economy	6700.00
0005433252092	25607	Economy	6700.00
0005434907702	25607	Economy	6700.00
0005434907968	25607	Economy	6700.00
0005433252074	25607	Economy	6700.00
0005434907746	25607	Economy	6700.00
0005433252095	25607	Economy	6700.00
0005434908109	25607	Economy	6700.00
0005434907775	25607	Economy	6700.00
0005433252069	25607	Economy	6700.00
0005433252084	25607	Economy	6700.00
0005433252089	25607	Economy	6700.00
0005434907619	25607	Economy	6700.00
0005434907644	25607	Economy	6700.00
0005434907884	25607	Economy	6700.00
0005433252093	25607	Economy	6700.00
0005433252083	25607	Economy	6700.00
0005434907801	25607	Economy	6700.00
0005434907535	25607	Economy	6700.00
0005433252086	25607	Economy	6700.00
0005434907841	25607	Economy	6700.00
0005434907671	25607	Economy	6700.00
0005433401043	25607	Economy	6700.00
0005434907799	25607	Economy	6700.00
0005434907688	25607	Economy	6700.00
0005434907944	25607	Economy	6700.00
0005433252073	25607	Economy	6700.00
0005434907896	25607	Economy	6700.00
0005434907810	25607	Economy	6700.00
0005434907789	25607	Economy	6700.00
0005433252068	25607	Economy	6700.00
0005433252070	25607	Economy	6700.00
0005434907840	25607	Economy	6700.00
0005434907795	25607	Economy	6700.00
0005433252090	25607	Economy	6700.00
0005434907761	25607	Economy	6700.00
0005433252075	25607	Economy	6700.00
0005433252080	25607	Economy	6700.00
0005433252071	25607	Economy	6700.00
0005433252067	25607	Economy	6700.00
0005433252079	25607	Economy	6700.00
0005432862385	2549	Economy	13600.00
0005432621313	2549	Economy	13600.00
0005432621314	2549	Economy	13600.00
0005432862402	2549	Economy	12400.00
0005432621320	2549	Economy	12400.00
0005432862384	2549	Economy	12400.00
0005432621312	2549	Economy	12400.00
0005432621309	2549	Economy	12400.00
0005432621316	2549	Economy	12400.00
0005432621321	2549	Economy	12400.00
0005432862374	2549	Economy	12400.00
0005432862413	2549	Economy	12400.00
0005432621308	2549	Economy	12400.00
0005432621310	2549	Economy	12400.00
0005432621318	2549	Economy	12400.00
0005432862383	2549	Economy	12400.00
0005432621311	2549	Economy	12400.00
0005432621315	2549	Economy	12400.00
0005432621317	2549	Economy	12400.00
0005432621319	2549	Economy	12400.00
0005432862403	2549	Economy	12400.00
0005432621265	28085	Economy	13600.00
0005432862456	28085	Economy	13600.00
0005432621200	28085	Economy	12400.00
0005432862455	28085	Economy	12400.00
0005432621242	28085	Economy	12400.00
0005432862454	28085	Economy	12400.00
0005432621171	28085	Economy	12400.00
0005432621199	28085	Economy	12400.00
0005432621246	28085	Economy	12400.00
0005432862453	28085	Economy	12400.00
0005432621165	28085	Economy	12400.00
0005432621192	28085	Economy	12400.00
0005432621196	28085	Economy	12400.00
0005432862452	28085	Economy	12400.00
0005432621224	28085	Economy	12400.00
0005432862451	28085	Economy	12400.00
0005432621210	28085	Economy	12400.00
0005432621163	28085	Economy	12400.00
0005432621195	28085	Economy	12400.00
0005432621197	28085	Economy	12400.00
0005432621180	28085	Economy	12400.00
0005432621166	28085	Economy	12400.00
0005432862457	28085	Economy	12400.00
0005432621190	28085	Economy	12400.00
0005432621247	28085	Economy	12400.00
0005432621264	28085	Economy	12400.00
0005432621238	28085	Economy	12400.00
0005432621243	28085	Economy	12400.00
0005434097493	11770	Economy	11300.00
0005433451660	31058	Economy	8400.00
0005433451659	31058	Economy	8400.00
0005433452780	31058	Economy	8400.00
0005433454903	31448	Economy	8400.00
0005433454904	31448	Economy	8400.00
0005433134191	12006	Economy	7200.00
0005434184685	12006	Economy	6600.00
0005433134201	12006	Economy	6600.00
0005433129336	12006	Economy	6600.00
0005434142654	12006	Economy	6600.00
0005434142642	12006	Economy	6600.00
0005433129341	12006	Economy	6600.00
0005433134204	12006	Economy	6600.00
0005433129335	12006	Economy	6600.00
0005434142643	12006	Economy	6600.00
0005433134200	12006	Economy	6600.00
0005434142647	12006	Economy	6600.00
0005434142646	12006	Economy	6600.00
0005434142641	12006	Economy	6600.00
0005434184679	12006	Economy	6600.00
0005433134203	12006	Economy	6600.00
0005433129322	12006	Economy	6600.00
0005434142684	29858	Economy	6600.00
0005433134228	29858	Economy	6600.00
0005434142683	29858	Economy	6600.00
0005433134227	29858	Economy	6600.00
0005434326274	29858	Economy	6600.00
0005433134225	29858	Economy	6600.00
0005434142685	29858	Economy	6600.00
0005433131799	29858	Economy	6600.00
0005434183619	29858	Economy	6600.00
0005433131798	29858	Economy	6600.00
0005434326277	29858	Economy	6600.00
0005433134229	29858	Economy	6600.00
0005434326275	29858	Economy	6600.00
0005433131797	29858	Economy	6600.00
0005433131795	29858	Economy	6600.00
0005434326276	29858	Economy	6600.00
0005434183620	29858	Economy	6600.00
0005434142686	29858	Economy	6600.00
0005433131796	29858	Economy	6600.00
0005433134226	29858	Economy	6600.00
0005435798977	21296	Economy	17200.00
0005435798950	21296	Economy	17200.00
0005435798954	21296	Economy	15700.00
0005435798976	21296	Economy	15700.00
0005435798953	21296	Economy	15700.00
0005435798963	21296	Economy	15700.00
0005435798970	21296	Economy	15700.00
0005435798960	21296	Economy	15700.00
0005435798949	21296	Economy	15700.00
0005435798966	21296	Economy	15700.00
0005435798956	21296	Economy	15700.00
0005435798946	21296	Economy	15700.00
0005435798959	21296	Economy	15700.00
0005435798974	21296	Economy	15700.00
0005435798958	21296	Economy	15700.00
0005435798948	21296	Economy	15700.00
0005435798969	21296	Economy	15700.00
0005435798957	21296	Economy	15700.00
0005435798975	21296	Economy	15700.00
0005435798955	21296	Economy	15700.00
0005435798947	21296	Economy	15700.00
0005435697860	16451	Economy	19900.00
0005435697855	16451	Economy	18100.00
0005435697853	16451	Economy	18100.00
0005435697871	16451	Economy	18100.00
0005435697858	16451	Economy	18100.00
0005435697865	16451	Economy	18100.00
0005435697862	16451	Economy	18100.00
0005435935075	16451	Economy	18100.00
0005435697866	16451	Economy	18100.00
0005435697852	16451	Economy	18100.00
0005435697870	16451	Economy	18100.00
0005435697869	16451	Economy	18100.00
0005435697867	16451	Economy	18100.00
0005435697874	16451	Economy	18100.00
0005435935062	16451	Economy	18100.00
0005435697868	16451	Economy	18100.00
0005435697864	16451	Economy	18100.00
0005435697854	16451	Economy	18100.00
0005435697861	16451	Economy	18100.00
0005435697849	16451	Economy	18100.00
0005435697848	16451	Economy	18100.00
0005435697857	16451	Economy	18100.00
0005435697872	16451	Economy	18100.00
0005435697877	16451	Economy	18100.00
0005435697875	16451	Economy	18100.00
0005435697850	16451	Economy	18100.00
0005435697859	16451	Economy	18100.00
0005435697863	16451	Economy	18100.00
0005435697851	16451	Economy	18100.00
0005435697873	16451	Economy	18100.00
0005435697856	16451	Economy	18100.00
0005435697876	16451	Economy	18100.00
0005435697711	24689	Economy	19900.00
0005435697577	24689	Economy	18100.00
0005435697656	24689	Economy	18100.00
0005435697687	24689	Economy	18100.00
0005435697566	24689	Economy	18100.00
0005435697510	24689	Economy	18100.00
0005435697681	24689	Economy	18100.00
0005435697664	24689	Economy	18100.00
0005435697743	24689	Economy	18100.00
0005435697661	24689	Economy	18100.00
0005435697744	24689	Economy	18100.00
0005435697633	24689	Economy	18100.00
0005435697638	24689	Economy	18100.00
0005435697578	24689	Economy	18100.00
0005435935105	24689	Economy	18100.00
0005435697637	24689	Economy	18100.00
0005435697686	24689	Economy	18100.00
0005435697663	24689	Economy	18100.00
0005435697498	24689	Economy	18100.00
0005435697509	24689	Economy	18100.00
0005435697693	24689	Economy	18100.00
0005435697654	24689	Economy	18100.00
0005435697721	24689	Economy	18100.00
0005435935104	24689	Economy	18100.00
0005435697662	24689	Economy	18100.00
0005435697692	24689	Economy	18100.00
0005435697720	24689	Economy	18100.00
0005435697672	24689	Economy	18100.00
0005435697677	24689	Economy	18100.00
0005435697725	24689	Economy	18100.00
0005435697665	24689	Economy	18100.00
0005435697624	24689	Economy	18100.00
0005435935103	24689	Economy	18100.00
0005435697655	24689	Economy	18100.00
0005432968864	18758	Economy	4400.00
0005433724893	18758	Economy	4400.00
0005433724891	18758	Economy	4400.00
0005432968869	18758	Economy	4400.00
0005433724890	18758	Economy	4400.00
0005433724892	18758	Economy	4400.00
0005433724852	21619	Economy	4400.00
0005433724871	21619	Economy	4400.00
0005432968888	21619	Economy	4400.00
0005433724870	21619	Economy	4400.00
0005433724867	21619	Economy	4400.00
0005433724851	21619	Economy	4400.00
0005433724866	21619	Economy	4400.00
0005432968886	21619	Economy	4400.00
0005433724868	21619	Economy	4400.00
0005432968887	21619	Economy	4400.00
0005433724855	21619	Economy	4400.00
0005434139725	7325	Business	23100.00
0005434139714	7325	Business	23100.00
0005434139718	7325	Business	23100.00
0005434139703	7325	Business	23100.00
0005434139710	7325	Business	23100.00
0005434139772	7325	Business	23100.00
0005434139724	7325	Business	23100.00
0005434139751	7325	Business	23100.00
0005434139760	7325	Business	23100.00
0005434139707	7325	Business	23100.00
0005434139713	7325	Business	23100.00
0005434139717	7325	Business	23100.00
0005434139768	7325	Economy	7700.00
0005434139752	7325	Economy	7700.00
0005434139729	7325	Economy	7700.00
0005434139734	7325	Economy	7700.00
0005434139715	7325	Economy	7700.00
0005434139741	7325	Economy	7700.00
0005434139697	7325	Economy	7700.00
0005434087611	7325	Economy	7700.00
0005434139769	7325	Economy	7700.00
0005434139709	7325	Economy	7700.00
0005434139746	7325	Economy	8500.00
0005434139774	7325	Economy	8500.00
0005434087609	7325	Economy	8500.00
0005434139693	7325	Economy	8500.00
0005434139744	7325	Economy	8500.00
0005434139733	7325	Economy	7700.00
0005434139695	7325	Economy	7700.00
0005434139699	7325	Economy	7700.00
0005434139758	7325	Economy	7700.00
0005434139764	7325	Economy	7700.00
0005434139756	7325	Economy	7700.00
0005434139737	7325	Economy	7700.00
0005434139765	7325	Economy	7700.00
0005434139749	7325	Economy	7700.00
0005434087610	7325	Economy	7700.00
0005434139762	7325	Economy	7700.00
0005434139766	7325	Economy	7700.00
0005434139754	7325	Economy	7700.00
0005434139722	7325	Economy	7700.00
0005434087608	7325	Economy	7700.00
0005434139728	7325	Economy	7700.00
0005434139757	7325	Economy	7700.00
0005434139692	7325	Economy	7700.00
0005434139698	7325	Economy	7700.00
0005434139711	7325	Economy	7700.00
0005434139694	7325	Economy	7700.00
0005434139759	7325	Economy	7700.00
0005434139702	7325	Economy	7700.00
0005434139719	7325	Economy	7700.00
0005434139700	7325	Economy	7700.00
0005434139732	7325	Economy	7700.00
0005434139705	7325	Economy	7700.00
0005434139761	7325	Economy	7700.00
0005434139704	7325	Economy	7700.00
0005434139726	7325	Economy	7700.00
0005434139738	7325	Economy	7700.00
0005434139753	7325	Economy	7700.00
0005434139771	7325	Economy	7700.00
0005434087607	7325	Economy	7700.00
0005434139739	7325	Economy	7700.00
0005434139735	7325	Economy	7700.00
0005434139767	7325	Economy	7700.00
0005434139740	7325	Economy	7700.00
0005434139730	7325	Economy	7700.00
0005434139727	7325	Economy	7700.00
0005434139716	7325	Economy	7700.00
0005434139750	7325	Economy	7700.00
0005434139731	7325	Economy	7700.00
0005434139742	7325	Economy	7700.00
0005434139723	7325	Economy	7700.00
0005434139721	7325	Economy	7700.00
0005434139706	7325	Economy	7700.00
0005434139748	7325	Economy	7700.00
0005434139763	7325	Economy	7700.00
0005434139712	7325	Economy	7700.00
0005434139747	7325	Economy	7700.00
0005434139701	7325	Economy	7700.00
0005434139736	7325	Economy	7700.00
0005434139770	7325	Economy	7700.00
0005434139708	7325	Economy	7700.00
0005434139773	7325	Economy	7700.00
0005434139720	7325	Economy	7700.00
0005434139696	7325	Economy	7700.00
0005434139755	7325	Economy	7700.00
0005434139745	7325	Economy	7700.00
0005434139743	7325	Economy	7700.00
0005434138760	28551	Business	23100.00
0005434138937	28551	Business	23100.00
0005434139165	28551	Business	23100.00
0005434138798	28551	Business	23100.00
0005434138734	28551	Business	23100.00
0005434138946	28551	Business	23100.00
0005434138695	28551	Business	23100.00
0005434139042	28551	Business	23100.00
0005434139086	28551	Business	23100.00
0005434139107	28551	Business	23100.00
0005434139191	28551	Business	23100.00
0005434138736	28551	Economy	7700.00
0005434139109	28551	Economy	7700.00
0005434138696	28551	Economy	7700.00
0005434139134	28551	Economy	7700.00
0005434087564	28551	Economy	7700.00
0005434138992	28551	Economy	7700.00
0005434139026	28551	Economy	7700.00
0005434138815	28551	Economy	7700.00
0005434138956	28551	Economy	7700.00
0005434138663	28551	Economy	7700.00
0005434138883	28551	Economy	8500.00
0005434087584	28551	Economy	8500.00
0005434138915	28551	Economy	8500.00
0005434139103	28551	Economy	8500.00
0005434139110	28551	Economy	7700.00
0005434138901	28551	Economy	7700.00
0005434139014	28551	Economy	7700.00
0005434138993	28551	Economy	7700.00
0005434138633	28551	Economy	7700.00
0005434139102	28551	Economy	7700.00
0005434138902	28551	Economy	7700.00
0005434138909	28551	Economy	7700.00
0005434138702	28551	Economy	7700.00
0005434138769	28551	Economy	7700.00
0005434087563	28551	Economy	7700.00
0005434138698	28551	Economy	7700.00
0005434138873	28551	Economy	7700.00
0005434138632	28551	Economy	7700.00
0005434138817	28551	Economy	7700.00
0005434139002	28551	Economy	7700.00
0005434139039	28551	Economy	7700.00
0005434139085	28551	Economy	7700.00
0005434138991	28551	Economy	7700.00
0005434139148	28551	Economy	7700.00
0005434138749	28551	Economy	7700.00
0005434138731	28551	Economy	7700.00
0005434138508	28551	Economy	7700.00
0005434138661	28551	Economy	7700.00
0005434138908	28551	Economy	7700.00
0005434139166	28551	Economy	7700.00
0005434138726	28551	Economy	7700.00
0005434138818	28551	Economy	7700.00
0005434138770	28551	Economy	7700.00
0005434139032	28551	Economy	7700.00
0005434087553	28551	Economy	7700.00
0005434139018	28551	Economy	7700.00
0005434138583	28551	Economy	7700.00
0005434138707	28551	Economy	7700.00
0005434138780	28551	Economy	7700.00
0005434138735	28551	Economy	7700.00
0005434138911	28551	Economy	7700.00
0005434138931	28551	Economy	7700.00
0005434138701	28551	Economy	7700.00
0005434138904	28551	Economy	7700.00
0005434138849	28551	Economy	7700.00
0005434139138	28551	Economy	7700.00
0005434138910	28551	Economy	7700.00
0005434138914	28551	Economy	7700.00
0005434139087	28551	Economy	7700.00
0005434139079	28551	Economy	7700.00
0005434138745	28551	Economy	7700.00
0005434138787	28551	Economy	7700.00
0005434139000	28551	Economy	7700.00
0005434139033	28551	Economy	7700.00
0005434139127	28551	Economy	7700.00
0005434139116	28551	Economy	7700.00
0005434138806	28551	Economy	7700.00
0005434138967	28551	Economy	7700.00
0005434138758	28551	Economy	7700.00
0005434138854	28551	Economy	7700.00
0005434138786	28551	Economy	7700.00
0005434138872	28551	Economy	7700.00
0005434139038	28551	Economy	7700.00
0005434139101	28551	Economy	7700.00
0005434087552	28551	Economy	7700.00
0005434610301	1950	Economy	23900.00
0005435808422	1950	Economy	23900.00
0005435808427	1950	Economy	21700.00
0005435808429	1950	Economy	21700.00
0005434610298	1950	Economy	21700.00
0005433407624	1950	Economy	21700.00
0005433407607	1950	Economy	21700.00
0005434610300	1950	Economy	21700.00
0005435808430	1950	Economy	21700.00
0005434610299	1950	Economy	21700.00
0005435808424	1950	Economy	21700.00
0005435808428	1950	Economy	21700.00
0005435808426	1950	Economy	21700.00
0005435808421	1950	Economy	21700.00
0005435808423	1950	Economy	21700.00
0005435808425	1950	Economy	21700.00
0005435808420	1950	Economy	21700.00
0005435808304	23083	Economy	23900.00
0005435808328	23083	Economy	23900.00
0005433407648	23083	Economy	23900.00
0005435808298	23083	Economy	23900.00
0005433407654	23083	Economy	21700.00
0005435808297	23083	Economy	21700.00
0005433407664	23083	Economy	21700.00
0005435808321	23083	Economy	21700.00
0005433407651	23083	Economy	21700.00
0005435808272	23083	Economy	21700.00
0005433407653	23083	Economy	21700.00
0005435808333	23083	Economy	21700.00
0005435808303	23083	Economy	21700.00
0005433407659	23083	Economy	21700.00
0005435808320	23083	Economy	21700.00
0005435808332	23083	Economy	21700.00
0005435808312	23083	Economy	21700.00
0005433407658	23083	Economy	21700.00
0005435808273	23083	Economy	21700.00
0005435808302	23083	Economy	21700.00
0005435808339	23083	Economy	21700.00
0005435808336	23083	Economy	21700.00
0005435808281	23083	Economy	21700.00
0005433407652	23083	Economy	21700.00
0005434610269	23083	Economy	21700.00
0005435808286	23083	Economy	21700.00
0005435808353	23083	Economy	21700.00
0005433407655	23083	Economy	21700.00
0005435808322	23083	Economy	21700.00
0005433407660	23083	Economy	21700.00
0005435808317	23083	Economy	21700.00
0005433407661	23083	Economy	21700.00
0005435808301	23083	Economy	21700.00
0005433407662	23083	Economy	21700.00
0005435808342	23083	Economy	21700.00
0005435808318	23083	Economy	21700.00
0005433407649	23083	Economy	21700.00
0005433407650	23083	Economy	21700.00
0005435808307	23083	Economy	21700.00
0005433407663	23083	Economy	21700.00
0005435808282	23083	Economy	21700.00
0005435808245	23083	Economy	21700.00
0005433407657	23083	Economy	21700.00
0005433407656	23083	Economy	21700.00
0005434504574	16724	Economy	7600.00
0005434504670	16724	Economy	7600.00
0005434504394	16724	Economy	7600.00
0005434504532	16724	Economy	7600.00
0005434504636	16724	Economy	6900.00
0005434504776	16724	Economy	6900.00
0005434504356	16724	Economy	6900.00
0005434504573	16724	Economy	6900.00
0005434504461	16724	Economy	6900.00
0005434504619	16724	Economy	6900.00
0005434504645	16724	Economy	6900.00
0005434504575	16724	Economy	6900.00
0005434504422	16724	Economy	6900.00
0005434504429	16724	Economy	6900.00
0005434504662	16724	Economy	6900.00
0005434504447	16724	Economy	6900.00
0005434504452	16724	Economy	6900.00
0005434504596	16724	Economy	6900.00
0005434504620	16724	Economy	6900.00
0005434504660	16724	Economy	6900.00
0005434504736	16724	Economy	6900.00
0005434504430	16724	Economy	6900.00
0005434504514	16724	Economy	6900.00
0005434504635	16724	Economy	6900.00
0005434504533	16724	Economy	6900.00
0005434504590	16724	Economy	6900.00
0005434504393	16724	Economy	6900.00
0005434504462	16724	Economy	6900.00
0005434504493	16724	Economy	6900.00
0005434504661	16724	Economy	6900.00
0005434504392	16724	Economy	6900.00
0005434504527	16724	Economy	6900.00
0005434504589	16724	Economy	6900.00
0005434504671	16724	Economy	6900.00
0005434504391	16724	Economy	6900.00
0005434504735	16724	Economy	6900.00
0005434504603	16724	Economy	6900.00
0005434504703	16724	Economy	6900.00
0005434504459	16724	Economy	6900.00
0005434504480	16724	Economy	6900.00
0005434504618	16724	Economy	6900.00
0005434504649	16724	Economy	6900.00
0005434504458	16724	Economy	6900.00
0005434504874	22918	Economy	7600.00
0005434504884	22918	Economy	7600.00
0005434504880	22918	Economy	7600.00
0005434504897	22918	Economy	6900.00
0005434504905	22918	Economy	6900.00
0005434504883	22918	Economy	6900.00
0005434504877	22918	Economy	6900.00
0005434504871	22918	Economy	6900.00
0005434504873	22918	Economy	6900.00
0005434504890	22918	Economy	6900.00
0005434504906	22918	Economy	6900.00
0005434504878	22918	Economy	6900.00
0005434504867	22918	Economy	6900.00
0005434504895	22918	Economy	6900.00
0005434504870	22918	Economy	6900.00
0005434504904	22918	Economy	6900.00
0005434504894	22918	Economy	6900.00
0005434504892	22918	Economy	6900.00
0005434504902	22918	Economy	6900.00
0005434504900	22918	Economy	6900.00
0005434504887	22918	Economy	6900.00
0005434504898	22918	Economy	6900.00
0005434504886	22918	Economy	6900.00
0005434504879	22918	Economy	6900.00
0005434504885	22918	Economy	6900.00
0005434504899	22918	Economy	6900.00
0005434504907	22918	Economy	6900.00
0005434504875	22918	Economy	6900.00
0005434504891	22918	Economy	6900.00
0005434504903	22918	Economy	6900.00
0005434504893	22918	Economy	6900.00
0005434504888	22918	Economy	6900.00
0005434504869	22918	Economy	6900.00
0005434504876	22918	Economy	6900.00
0005434504896	22918	Economy	6900.00
0005434504881	22918	Economy	6900.00
0005434504889	22918	Economy	6900.00
0005434504882	22918	Economy	6900.00
0005434504901	22918	Economy	6900.00
0005434504868	22918	Economy	6900.00
0005434504872	22918	Economy	6900.00
0005435078641	2230	Economy	7700.00
0005435078639	2230	Economy	7700.00
0005433266804	2230	Economy	7700.00
0005435078644	2230	Economy	7700.00
0005435078646	2230	Economy	7000.00
0005433266812	2230	Economy	7000.00
0005435078638	2230	Economy	7000.00
0005433266857	2230	Economy	7000.00
0005433266795	2230	Economy	7000.00
0005435078652	2230	Economy	7000.00
0005433266858	2230	Economy	7000.00
0005433266831	2230	Economy	7000.00
0005435078647	2230	Economy	7000.00
0005435078643	2230	Economy	7000.00
0005435078642	2230	Economy	7000.00
0005435078640	2230	Economy	7000.00
0005435078650	2230	Economy	7000.00
0005435078649	2230	Economy	7000.00
0005433266859	2230	Economy	7000.00
0005435078651	2230	Economy	7000.00
0005435078648	2230	Economy	7000.00
0005433266856	2230	Economy	7000.00
0005435078645	2230	Economy	7000.00
0005433266840	2230	Economy	7000.00
0005435078534	24363	Economy	7700.00
0005435078551	24363	Economy	7700.00
0005435078550	24363	Economy	7000.00
0005433266904	24363	Economy	7000.00
0005433266902	24363	Economy	7000.00
0005433266909	24363	Economy	7000.00
0005433266905	24363	Economy	7000.00
0005433266907	24363	Economy	7000.00
0005435078450	24363	Economy	7000.00
0005433266900	24363	Economy	7000.00
0005433266901	24363	Economy	7000.00
0005433266903	24363	Economy	7000.00
0005435078552	24363	Economy	7000.00
0005435078553	24363	Economy	7000.00
0005435078566	24363	Economy	7000.00
0005435078451	24363	Economy	7000.00
0005433266906	24363	Economy	7000.00
0005435078467	24363	Economy	7000.00
0005433266908	24363	Economy	7000.00
0005435078497	24363	Economy	7000.00
0005435078537	24363	Economy	7000.00
0005435078511	24363	Economy	7000.00
0005435078565	24363	Economy	7000.00
0005435078498	24363	Economy	7000.00
0005434988941	6654	Economy	10800.00
0005434988946	6654	Economy	9800.00
0005434988939	6654	Economy	9800.00
0005434988944	6654	Economy	9800.00
0005434988940	6654	Economy	9800.00
0005434988945	6654	Economy	9800.00
0005434988948	6654	Economy	9800.00
0005434988943	6654	Economy	9800.00
0005434988949	6654	Economy	9800.00
0005434988947	6654	Economy	9800.00
0005435803319	6654	Economy	9800.00
0005435464530	6654	Economy	9800.00
0005434988938	6654	Economy	9800.00
0005434988942	6654	Economy	9800.00
0005434988824	23596	Economy	10800.00
0005435464547	23596	Economy	9800.00
0005434988817	23596	Economy	9800.00
0005434988822	23596	Economy	9800.00
0005434988807	23596	Economy	9800.00
0005435803293	23596	Economy	9800.00
0005434988825	23596	Economy	9800.00
0005435803277	23596	Economy	9800.00
0005434988821	23596	Economy	9800.00
0005434988830	23596	Economy	9800.00
0005434988808	23596	Economy	9800.00
0005435803278	23596	Economy	9800.00
0005434988823	23596	Economy	9800.00
0005435803301	23596	Economy	9800.00
0005434988803	23596	Economy	9800.00
0005434988827	23596	Economy	9800.00
0005434988820	23596	Economy	9800.00
0005434988829	23596	Economy	9800.00
0005435803292	23596	Economy	9800.00
0005435464546	23596	Economy	9800.00
0005432383930	30467	Business	9900.00
0005432383953	30467	Business	9900.00
0005432383921	30467	Business	9900.00
0005432383915	30467	Business	9900.00
0005432383947	30467	Business	9900.00
0005432383951	30467	Business	9900.00
0005433450400	30467	Business	9900.00
0005432383932	30467	Business	9900.00
0005433450402	30467	Business	9900.00
0005433450401	30467	Economy	3300.00
0005432383935	30467	Economy	3300.00
0005432383917	30467	Economy	3300.00
0005432383954	30467	Economy	3300.00
0005433450385	30467	Economy	3300.00
0005433450395	30467	Economy	3300.00
0005433450404	30467	Economy	3300.00
0005433450405	30467	Economy	3300.00
0005433450399	30467	Economy	3300.00
0005432383948	30467	Economy	3600.00
0005433450386	30467	Economy	3600.00
0005432383941	30467	Economy	3600.00
0005433450389	30467	Economy	3600.00
0005432383929	30467	Economy	3300.00
0005433450391	30467	Economy	3300.00
0005433450390	30467	Economy	3300.00
0005433450396	30467	Economy	3300.00
0005432383940	30467	Economy	3300.00
0005433454916	30467	Economy	3300.00
0005433450403	30467	Economy	3300.00
0005432383939	30467	Economy	3300.00
0005432383944	30467	Economy	3300.00
0005432383920	30467	Economy	3300.00
0005432383916	30467	Economy	3300.00
0005432383928	30467	Economy	3300.00
0005432383918	30467	Economy	3300.00
0005432383943	30467	Economy	3300.00
0005432383926	30467	Economy	3300.00
0005432383919	30467	Economy	3300.00
0005432383934	30467	Economy	3300.00
0005432383942	30467	Economy	3300.00
0005432383937	30467	Economy	3300.00
0005432383952	30467	Economy	3300.00
0005432383946	30467	Economy	3300.00
0005433450393	30467	Economy	3300.00
0005432383923	30467	Economy	3300.00
0005433450387	30467	Economy	3300.00
0005432383931	30467	Economy	3300.00
0005432383922	30467	Economy	3300.00
0005433450394	30467	Economy	3300.00
0005432383924	30467	Economy	3300.00
0005432383936	30467	Economy	3300.00
0005433450398	30467	Economy	3300.00
0005432383927	30467	Economy	3300.00
0005433450388	30467	Economy	3300.00
0005433450406	30467	Economy	3300.00
0005433450397	30467	Economy	3300.00
0005433454917	30467	Economy	3300.00
0005432383955	30467	Economy	3300.00
0005432383945	30467	Economy	3300.00
0005433450392	30467	Economy	3300.00
0005432383933	30467	Economy	3300.00
0005432383949	30467	Economy	3300.00
0005432383925	30467	Economy	3300.00
0005432383938	30467	Economy	3300.00
0005432383950	30467	Economy	3300.00
0005432383577	31295	Business	9900.00
0005432383634	31295	Business	9900.00
0005432383606	31295	Business	9900.00
0005432383495	31295	Business	9900.00
0005433450257	31295	Business	9900.00
0005432383638	31295	Business	9900.00
0005432383445	31295	Economy	3300.00
0005433450259	31295	Economy	3300.00
0005432383633	31295	Economy	3300.00
0005432383683	31295	Economy	3300.00
0005432383289	31295	Economy	3300.00
0005433450105	31295	Economy	3300.00
0005432383551	31295	Economy	3600.00
0005433450190	31295	Economy	3600.00
0005432383575	31295	Economy	3600.00
0005433450273	31295	Economy	3300.00
0005432383547	31295	Economy	3300.00
0005432383474	31295	Economy	3300.00
0005433450229	31295	Economy	3300.00
0005433450204	31295	Economy	3300.00
0005432383607	31295	Economy	3300.00
0005432383475	31295	Economy	3300.00
0005432383552	31295	Economy	3300.00
0005433450123	31295	Economy	3300.00
0005432383448	31295	Economy	3300.00
0005432383682	31295	Economy	3300.00
0005432383482	31295	Economy	3300.00
0005433451644	31295	Economy	3300.00
0005432383494	31295	Economy	3300.00
0005432383550	31295	Economy	3300.00
0005433450222	31295	Economy	3300.00
0005432383323	31295	Economy	3300.00
0005432383411	31295	Economy	3300.00
0005433450124	31295	Economy	3300.00
0005433450138	31295	Economy	3300.00
0005432383520	31295	Economy	3300.00
0005432383407	31295	Economy	3300.00
0005433450221	31295	Economy	3300.00
0005432383519	31295	Economy	3300.00
0005432383578	31295	Economy	3300.00
0005432383672	31295	Economy	3300.00
0005433450272	31295	Economy	3300.00
0005432383410	31295	Economy	3300.00
0005432383481	31295	Economy	3300.00
0005432383307	31295	Economy	3300.00
0005432383560	31295	Economy	3300.00
0005433451650	31295	Economy	3300.00
0005433450238	31295	Economy	3300.00
0005435299814	10784	Economy	17100.00
0005433126889	10784	Economy	17100.00
0005433126874	10784	Economy	15600.00
0005433131757	10784	Economy	15600.00
0005433126897	10784	Economy	15600.00
0005435299829	10784	Economy	15600.00
0005433131735	10784	Economy	15600.00
0005433126885	10784	Economy	15600.00
0005435299815	10784	Economy	15600.00
0005433131736	10784	Economy	15600.00
0005435299807	10784	Economy	15600.00
0005433126872	10784	Economy	15600.00
0005433126896	10784	Economy	15600.00
0005435304199	10784	Economy	15600.00
0005435304206	10784	Economy	15600.00
0005435299813	10784	Economy	15600.00
0005435299808	10784	Economy	15600.00
0005433126902	10784	Economy	15600.00
0005433126871	10784	Economy	15600.00
0005433126898	10784	Economy	15600.00
0005435299874	29700	Economy	17100.00
0005433129368	29700	Economy	15600.00
0005435299873	29700	Economy	15600.00
0005433126938	29700	Economy	15600.00
0005433129370	29700	Economy	15600.00
0005435302293	29700	Economy	15600.00
0005433129371	29700	Economy	15600.00
0005435302296	29700	Economy	15600.00
0005433126936	29700	Economy	15600.00
0005433129369	29700	Economy	15600.00
0005433126940	29700	Economy	15600.00
0005435302295	29700	Economy	15600.00
0005433129367	29700	Economy	15600.00
0005433126939	29700	Economy	15600.00
0005435302294	29700	Economy	15600.00
0005435302297	29700	Economy	15600.00
0005435299875	29700	Economy	15600.00
0005433126937	29700	Economy	15600.00
0005435299872	29700	Economy	15600.00
0005435299871	29700	Economy	15600.00
0005433110209	2417	Economy	17200.00
0005432264522	2417	Economy	17200.00
0005432264524	2417	Economy	17200.00
0005434287713	2417	Economy	15700.00
0005434287725	2417	Economy	15700.00
0005434287723	2417	Economy	15700.00
0005434287711	2417	Economy	15700.00
0005433110241	2417	Economy	15700.00
0005433110192	2417	Economy	15700.00
0005434287732	2417	Economy	15700.00
0005433110231	2417	Economy	15700.00
0005433110204	2417	Economy	15700.00
0005434287715	2417	Economy	15700.00
0005432264523	2417	Economy	15700.00
0005434287727	2417	Economy	15700.00
0005433110167	2417	Economy	15700.00
0005434287731	2417	Economy	15700.00
0005434287733	2417	Economy	15700.00
0005433110203	2417	Economy	15700.00
0005433110184	2417	Economy	15700.00
0005433110196	2417	Economy	15700.00
0005434287722	2417	Economy	15700.00
0005434287724	2417	Economy	15700.00
0005434287720	2417	Economy	15700.00
0005434287726	2417	Economy	15700.00
0005434287730	2417	Economy	15700.00
0005434287721	2417	Economy	15700.00
0005434287716	2417	Economy	15700.00
0005434287714	2417	Economy	15700.00
0005433110193	2417	Economy	15700.00
0005434287729	2417	Economy	15700.00
0005433110194	2417	Economy	15700.00
0005433110158	2417	Economy	15700.00
0005434287728	2417	Economy	15700.00
0005434287718	2417	Economy	15700.00
0005434287719	2417	Economy	15700.00
0005433110166	2417	Economy	15700.00
0005434287717	2417	Economy	15700.00
0005434287712	2417	Economy	15700.00
0005434287536	26871	Economy	17200.00
0005434287509	26871	Economy	17200.00
0005434287564	26871	Economy	17200.00
0005433110292	26871	Economy	17200.00
0005434287550	26871	Economy	15700.00
0005434287566	26871	Economy	15700.00
0005434287547	26871	Economy	15700.00
0005434287570	26871	Economy	15700.00
0005434287548	26871	Economy	15700.00
0005434287605	26871	Economy	15700.00
0005433110294	26871	Economy	15700.00
0005434287569	26871	Economy	15700.00
0005433110285	26871	Economy	15700.00
0005433110288	26871	Economy	15700.00
0005433110283	26871	Economy	15700.00
0005434287603	26871	Economy	15700.00
0005433110295	26871	Economy	15700.00
0005434287558	26871	Economy	15700.00
0005433110284	26871	Economy	15700.00
0005433110290	26871	Economy	15700.00
0005434287469	26871	Economy	15700.00
0005433110289	26871	Economy	15700.00
0005433110291	26871	Economy	15700.00
0005434287578	26871	Economy	15700.00
0005434287478	26871	Economy	15700.00
0005433110293	26871	Economy	15700.00
0005433110286	26871	Economy	15700.00
0005434287588	26871	Economy	15700.00
0005434287559	26871	Economy	15700.00
0005434287577	26871	Economy	15700.00
0005434287549	26871	Economy	15700.00
0005434287526	26871	Economy	15700.00
0005433110296	26871	Economy	15700.00
0005433110287	26871	Economy	15700.00
0005435856288	25447	Economy	25000.00
0005435856285	25447	Economy	22800.00
0005435856286	25447	Economy	22800.00
0005435856287	25447	Economy	22800.00
0005434272205	25447	Economy	22800.00
0005435856238	26638	Economy	22800.00
0005434273108	26638	Economy	22800.00
0005435856252	26638	Economy	22800.00
0005435856254	26638	Economy	22800.00
0005433869213	4774	Economy	19400.00
0005433869223	4774	Economy	19400.00
0005433869207	4774	Economy	19400.00
0005433869221	4774	Economy	17600.00
0005433869220	4774	Economy	17600.00
0005433869208	4774	Economy	17600.00
0005433869202	4774	Economy	17600.00
0005433869229	4774	Economy	17600.00
0005433869225	4774	Economy	17600.00
0005433869231	4774	Economy	17600.00
0005433869218	4774	Economy	17600.00
0005433869232	4774	Economy	17600.00
0005433869217	4774	Economy	17600.00
0005433869209	4774	Economy	17600.00
0005435860511	4774	Economy	17600.00
0005433869226	4774	Economy	17600.00
0005433869238	4774	Economy	17600.00
0005433869224	4774	Economy	17600.00
0005433869237	4774	Economy	17600.00
0005433869227	4774	Economy	17600.00
0005433869230	4774	Economy	17600.00
0005433869236	4774	Economy	17600.00
0005433869233	4774	Economy	17600.00
0005433869215	4774	Economy	17600.00
0005433869206	4774	Economy	17600.00
0005433869204	4774	Economy	17600.00
0005433869235	4774	Economy	17600.00
0005433869205	4774	Economy	17600.00
0005433869228	4774	Economy	17600.00
0005433869212	4774	Economy	17600.00
0005433869216	4774	Economy	17600.00
0005433869210	4774	Economy	17600.00
0005433869219	4774	Economy	17600.00
0005433869240	4774	Economy	17600.00
0005433869203	4774	Economy	17600.00
0005433869222	4774	Economy	17600.00
0005433869214	4774	Economy	17600.00
0005433869211	4774	Economy	17600.00
0005433869234	4774	Economy	17600.00
0005433869239	4774	Economy	17600.00
0005433868841	32566	Economy	19400.00
0005435860571	32566	Economy	19400.00
0005433868869	32566	Economy	19400.00
0005433868744	32566	Economy	19400.00
0005433868813	32566	Economy	17600.00
0005435860570	32566	Economy	17600.00
0005433868867	32566	Economy	17600.00
0005435860565	32566	Economy	17600.00
0005435860567	32566	Economy	17600.00
0005433868701	32566	Economy	17600.00
0005433868698	32566	Economy	17600.00
0005433868874	32566	Economy	17600.00
0005435860560	32566	Economy	17600.00
0005433868836	32566	Economy	17600.00
0005435860568	32566	Economy	17600.00
0005433868979	32566	Economy	17600.00
0005433868842	32566	Economy	17600.00
0005435860561	32566	Economy	17600.00
0005435860572	32566	Economy	17600.00
0005433868833	32566	Economy	17600.00
0005433868887	32566	Economy	17600.00
0005433868875	32566	Economy	17600.00
0005433868832	32566	Economy	17600.00
0005435860563	32566	Economy	17600.00
0005433868975	32566	Economy	17600.00
0005433868866	32566	Economy	17600.00
0005435860566	32566	Economy	17600.00
0005433868868	32566	Economy	17600.00
0005433868834	32566	Economy	17600.00
0005435860564	32566	Economy	17600.00
0005433868930	32566	Economy	17600.00
0005433868888	32566	Economy	17600.00
0005433868727	32566	Economy	17600.00
0005433868739	32566	Economy	17600.00
0005433868817	32566	Economy	17600.00
0005435860562	32566	Economy	17600.00
0005433868812	32566	Economy	17600.00
0005435860569	32566	Economy	17600.00
0005433868777	32566	Economy	17600.00
0005433868916	32566	Economy	17600.00
0005433868919	32566	Economy	17600.00
0005433868800	32566	Economy	17600.00
0005433868831	32566	Economy	17600.00
0005433868736	32566	Economy	17600.00
0005434663672	3402	Economy	24800.00
0005435911516	3402	Economy	24800.00
0005435911547	3402	Economy	22600.00
0005434663667	3402	Economy	22600.00
0005434461689	3402	Economy	22600.00
0005434460547	3402	Economy	22600.00
0005434663674	3402	Economy	22600.00
0005434663676	3402	Economy	22600.00
0005434460549	3402	Economy	22600.00
0005434663671	3402	Economy	22600.00
0005434663669	3402	Economy	22600.00
0005434663678	3402	Economy	22600.00
0005435911515	3402	Economy	22600.00
0005434663675	3402	Economy	22600.00
0005434460548	3402	Economy	22600.00
0005434663680	3402	Economy	22600.00
0005435911493	3402	Economy	22600.00
0005434663668	3402	Economy	22600.00
0005434663677	3402	Economy	22600.00
0005434663670	3402	Economy	22600.00
0005434663679	3402	Economy	22600.00
0005434663673	3402	Economy	22600.00
0005435911599	12499	Economy	24800.00
0005434663556	12499	Economy	24800.00
0005435911602	12499	Economy	24800.00
0005435911601	12499	Economy	24800.00
0005434663577	12499	Economy	22600.00
0005434663568	12499	Economy	22600.00
0005435911604	12499	Economy	22600.00
0005434663574	12499	Economy	22600.00
0005434663576	12499	Economy	22600.00
0005434663529	12499	Economy	22600.00
0005434663530	12499	Economy	22600.00
0005434663567	12499	Economy	22600.00
0005434663546	12499	Economy	22600.00
0005435911600	12499	Economy	22600.00
0005434663569	12499	Economy	22600.00
0005434663560	12499	Economy	22600.00
0005434663545	12499	Economy	22600.00
0005434663557	12499	Economy	22600.00
0005435911598	12499	Economy	22600.00
0005434663589	12499	Economy	22600.00
0005435911603	12499	Economy	22600.00
0005434663547	12499	Economy	22600.00
0005435860565	14512	Economy	18500.00
0005433868919	14512	Economy	18500.00
0005433868698	14512	Economy	18500.00
0005433868887	14512	Economy	18500.00
0005433868800	14512	Economy	16800.00
0005433868813	14512	Economy	16800.00
0005433868701	14512	Economy	16800.00
0005433868975	14512	Economy	16800.00
0005435860572	14512	Economy	16800.00
0005433868867	14512	Economy	16800.00
0005433868727	14512	Economy	16800.00
0005435860564	14512	Economy	16800.00
0005435860563	14512	Economy	16800.00
0005435860569	14512	Economy	16800.00
0005433868836	14512	Economy	16800.00
0005433868831	14512	Economy	16800.00
0005433868736	14512	Economy	16800.00
0005433868817	14512	Economy	16800.00
0005433868744	14512	Economy	16800.00
0005435860571	14512	Economy	16800.00
0005433868916	14512	Economy	16800.00
0005435860566	14512	Economy	16800.00
0005433868739	14512	Economy	16800.00
0005433868874	14512	Economy	16800.00
0005433868812	14512	Economy	16800.00
0005433868777	14512	Economy	16800.00
0005433868842	14512	Economy	16800.00
0005435860562	14512	Economy	16800.00
0005433868888	14512	Economy	16800.00
0005433868979	14512	Economy	16800.00
0005435860570	14512	Economy	16800.00
0005433868875	14512	Economy	16800.00
0005433868834	14512	Economy	16800.00
0005433868841	14512	Economy	16800.00
0005435860561	14512	Economy	16800.00
0005433868833	14512	Economy	16800.00
0005433868832	14512	Economy	16800.00
0005433868868	14512	Economy	16800.00
0005433868866	14512	Economy	16800.00
0005435860560	14512	Economy	16800.00
0005433868869	14512	Economy	16800.00
0005435860567	14512	Economy	16800.00
0005433868930	14512	Economy	16800.00
0005435860568	14512	Economy	16800.00
0005433869201	32696	Economy	18500.00
0005433869189	32696	Economy	18500.00
0005433869170	32696	Economy	18500.00
0005433869162	32696	Economy	18500.00
0005433869165	32696	Economy	16800.00
0005433869168	32696	Economy	16800.00
0005433869193	32696	Economy	16800.00
0005433869187	32696	Economy	16800.00
0005433869172	32696	Economy	16800.00
0005433869190	32696	Economy	16800.00
0005433869181	32696	Economy	16800.00
0005433869182	32696	Economy	16800.00
0005433869200	32696	Economy	16800.00
0005433869195	32696	Economy	16800.00
0005433869173	32696	Economy	16800.00
0005433869177	32696	Economy	16800.00
0005433869197	32696	Economy	16800.00
0005435860512	32696	Economy	16800.00
0005433869191	32696	Economy	16800.00
0005433869166	32696	Economy	16800.00
0005433869196	32696	Economy	16800.00
0005433869169	32696	Economy	16800.00
0005433869192	32696	Economy	16800.00
0005433869199	32696	Economy	16800.00
0005433869179	32696	Economy	16800.00
0005433869160	32696	Economy	16800.00
0005433869188	32696	Economy	16800.00
0005433869167	32696	Economy	16800.00
0005433869183	32696	Economy	16800.00
0005433869164	32696	Economy	16800.00
0005433869176	32696	Economy	16800.00
0005433869185	32696	Economy	16800.00
0005433869178	32696	Economy	16800.00
0005433869186	32696	Economy	16800.00
0005433869198	32696	Economy	16800.00
0005433869184	32696	Economy	16800.00
0005433869194	32696	Economy	16800.00
0005433869175	32696	Economy	16800.00
0005435860508	32696	Economy	16800.00
0005433869174	32696	Economy	16800.00
0005433869171	32696	Economy	16800.00
0005433869180	32696	Economy	16800.00
0005433869163	32696	Economy	16800.00
0005433869161	32696	Economy	16800.00
0005432799814	12130	Economy	4900.00
0005432799800	12130	Economy	4900.00
0005432799659	12130	Economy	4900.00
0005432799810	12130	Economy	4400.00
0005432799833	12130	Economy	4400.00
0005432799849	12130	Economy	4400.00
0005432799890	12130	Economy	4400.00
0005432799728	12130	Economy	4400.00
0005432799704	12130	Economy	4400.00
0005432799706	12130	Economy	4400.00
0005432799815	12130	Economy	4400.00
0005432799876	12130	Economy	4400.00
0005432799824	12130	Economy	4400.00
0005432799641	12130	Economy	4400.00
0005432799658	12130	Economy	4400.00
0005432799868	12130	Economy	4400.00
0005432799834	12130	Economy	4400.00
0005432799839	12130	Economy	4400.00
0005432799832	12130	Economy	4400.00
0005432799848	12130	Economy	4400.00
0005432799759	12130	Economy	4400.00
0005432799705	12130	Economy	4400.00
0005432799682	12130	Economy	4400.00
0005432799710	12130	Economy	4400.00
0005432799747	12130	Economy	4400.00
0005432799965	14777	Economy	4900.00
0005432799990	14777	Economy	4400.00
0005432799982	14777	Economy	4400.00
0005432799992	14777	Economy	4400.00
0005432799971	14777	Economy	4400.00
0005432799979	14777	Economy	4400.00
0005432799986	14777	Economy	4400.00
0005432799968	14777	Economy	4400.00
0005432799974	14777	Economy	4400.00
0005432799981	14777	Economy	4400.00
0005432799969	14777	Economy	4400.00
0005432799967	14777	Economy	4400.00
0005432799978	14777	Economy	4400.00
0005432799987	14777	Economy	4400.00
0005432799977	14777	Economy	4400.00
0005432799989	14777	Economy	4400.00
0005432799980	14777	Economy	4400.00
0005432799985	14777	Economy	4400.00
0005432799993	14777	Economy	4400.00
0005432799983	14777	Economy	4400.00
0005432799975	14777	Economy	4400.00
0005432799972	14777	Economy	4400.00
0005432799991	14777	Economy	4400.00
0005432799966	14777	Economy	4400.00
0005432799984	14777	Economy	4400.00
0005432799988	14777	Economy	4400.00
0005432799970	14777	Economy	4400.00
0005432799973	14777	Economy	4400.00
0005432799976	14777	Economy	4400.00
0005434300017	7073	Business	49100.00
0005432154073	7073	Business	49100.00
0005434300011	7073	Business	49100.00
0005432108300	7073	Business	49100.00
0005434300016	7073	Business	49100.00
0005434408978	7073	Business	49100.00
0005434409007	7073	Business	49100.00
0005434408967	7073	Business	49100.00
0005434408979	7073	Business	49100.00
0005435293372	7073	Business	49100.00
0005434409015	7073	Business	49100.00
0005434408977	7073	Business	49100.00
0005435311166	7073	Economy	16400.00
0005435311144	7073	Economy	16400.00
0005435293360	7073	Economy	16400.00
0005435293373	7073	Economy	16400.00
0005434300015	7073	Economy	16400.00
0005432108301	7073	Economy	16400.00
0005432154074	7073	Economy	16400.00
0005434409019	7073	Economy	16400.00
0005435293361	7073	Economy	16400.00
0005434300009	7073	Economy	16400.00
0005435311178	7073	Economy	16400.00
0005434300010	7073	Economy	16400.00
0005434408974	7073	Economy	16400.00
0005435311159	7073	Economy	16400.00
0005435293374	7073	Economy	16400.00
0005435293384	7073	Economy	16400.00
0005435311172	7073	Economy	16400.00
0005434300014	7073	Economy	16400.00
0005434300024	7073	Economy	16400.00
0005434408986	7073	Economy	16400.00
0005435293348	7073	Economy	16400.00
0005434408987	7073	Economy	16400.00
0005434300018	7073	Economy	16400.00
0005434300006	7073	Economy	16400.00
0005435293403	7073	Economy	16400.00
0005434300007	7073	Economy	16400.00
0005434408995	7073	Economy	16400.00
0005434408994	7073	Economy	16400.00
0005435311169	7073	Economy	16400.00
0005434408966	7073	Economy	16400.00
0005432154076	7073	Economy	16400.00
0005434408965	7073	Economy	16400.00
0005434409010	7073	Economy	16400.00
0005435293411	7073	Economy	16400.00
0005434300025	7073	Economy	16400.00
0005435311167	7073	Economy	16400.00
0005434409001	7073	Economy	16400.00
0005434408982	7073	Economy	18000.00
0005434408971	7073	Economy	16400.00
0005434409008	7073	Economy	18000.00
0005434408972	7073	Economy	18000.00
0005434409023	7073	Economy	18000.00
0005434408985	7073	Economy	18000.00
0005434408997	7073	Economy	18000.00
0005434409020	7073	Economy	16400.00
0005435311146	7073	Economy	16400.00
0005435311181	7073	Economy	16400.00
0005435311155	7073	Economy	16400.00
0005435311154	7073	Economy	16400.00
0005434408983	7073	Economy	16400.00
0005435311138	7073	Economy	16400.00
0005434408969	7073	Economy	16400.00
0005434300012	7073	Economy	16400.00
0005434409004	7073	Economy	16400.00
0005434408989	7073	Economy	16400.00
0005434409028	7073	Economy	16400.00
0005434409016	7073	Economy	16400.00
0005434409017	7073	Economy	16400.00
0005434409005	7073	Economy	16400.00
0005434300022	7073	Economy	16400.00
0005435311179	7073	Economy	16400.00
0005434300021	7073	Economy	16400.00
0005434409021	7073	Economy	16400.00
0005434409025	7073	Economy	16400.00
0005434409024	7073	Economy	16400.00
0005434300026	7073	Economy	16400.00
0005435311174	7073	Economy	16400.00
0005434300005	7073	Economy	16400.00
0005434409013	7073	Economy	16400.00
0005434300013	7073	Economy	16400.00
0005434408980	7073	Economy	16400.00
0005434408984	7073	Economy	16400.00
0005434300019	7073	Economy	16400.00
0005434409000	7073	Economy	16400.00
0005434408970	7073	Economy	16400.00
0005434408990	7073	Economy	16400.00
0005434408973	7073	Economy	16400.00
0005435311193	7073	Economy	16400.00
0005434408998	7073	Economy	16400.00
0005435311173	7073	Economy	16400.00
0005435293363	7073	Economy	16400.00
0005435293380	7073	Economy	16400.00
0005434300023	7073	Economy	16400.00
0005434408975	7073	Economy	16400.00
0005434409014	7073	Economy	16400.00
0005434408996	7073	Economy	16400.00
0005434408968	7073	Economy	16400.00
0005432154077	7073	Economy	16400.00
0005434409006	7073	Economy	16400.00
0005434408976	7073	Economy	16400.00
0005434408991	7073	Economy	16400.00
0005435311168	7073	Economy	16400.00
0005434409012	7073	Economy	16400.00
0005434409022	7073	Economy	16400.00
0005434300008	7073	Economy	16400.00
0005434409018	7073	Economy	16400.00
0005434408999	7073	Economy	16400.00
0005435293365	7073	Economy	16400.00
0005434408992	7073	Economy	16400.00
0005434409003	7073	Economy	16400.00
0005432154072	7073	Economy	16400.00
0005434409026	7073	Economy	16400.00
0005434409002	7073	Economy	16400.00
0005432154075	7073	Economy	16400.00
0005434409027	7073	Economy	16400.00
0005432154078	7073	Economy	16400.00
0005434409009	7073	Economy	16400.00
0005435311145	7073	Economy	16400.00
0005434408988	7073	Economy	16400.00
0005434300020	7073	Economy	16400.00
0005434409029	7073	Economy	16400.00
0005434408981	7073	Economy	16400.00
0005434409011	7073	Economy	16400.00
0005434408993	7073	Economy	16400.00
0005434408538	26917	Business	49100.00
0005434408274	26917	Business	49100.00
0005435293493	26917	Business	49100.00
0005434408417	26917	Business	49100.00
0005434407803	26917	Business	49100.00
0005434299765	26917	Business	49100.00
0005434407988	26917	Business	49100.00
0005434299857	26917	Business	49100.00
0005434299850	26917	Business	49100.00
0005434408526	26917	Business	49100.00
0005434408255	26917	Business	49100.00
0005434299832	26917	Business	49100.00
0005434408548	26917	Economy	16400.00
0005434299842	26917	Economy	16400.00
0005434408485	26917	Economy	16400.00
0005434407996	26917	Economy	16400.00
0005434408254	26917	Economy	16400.00
0005434408333	26917	Economy	16400.00
0005434408382	26917	Economy	16400.00
0005434408421	26917	Economy	16400.00
0005434408040	26917	Economy	16400.00
0005435293491	26917	Economy	16400.00
0005434408575	26917	Economy	16400.00
0005434408296	26917	Economy	16400.00
0005435293495	26917	Economy	16400.00
0005434408149	26917	Economy	16400.00
0005434408236	26917	Economy	16400.00
0005434299851	26917	Economy	16400.00
0005434408465	26917	Economy	16400.00
0005434408497	26917	Economy	16400.00
0005434407827	26917	Economy	16400.00
0005434299896	26917	Economy	16400.00
0005434408552	26917	Economy	16400.00
0005435311296	26917	Economy	16400.00
0005435293498	26917	Economy	16400.00
0005435311292	26917	Economy	16400.00
0005434408420	26917	Economy	16400.00
0005434408511	26917	Economy	16400.00
0005434408573	26917	Economy	16400.00
0005434408414	26917	Economy	16400.00
0005434408365	26917	Economy	16400.00
0005434408190	26917	Economy	16400.00
0005432058454	26917	Economy	16400.00
0005434299817	26917	Economy	16400.00
0005434408576	26917	Economy	16400.00
0005435311291	26917	Economy	16400.00
0005434408442	26917	Economy	18000.00
0005434408295	26917	Economy	18000.00
0005434299841	26917	Economy	18000.00
0005435293496	26917	Economy	18000.00
0005434408415	26917	Economy	18000.00
0005434408501	26917	Economy	16400.00
0005434408237	26917	Economy	18000.00
0005435293501	26917	Economy	16400.00
0005434299853	26917	Economy	16400.00
0005434408528	26917	Economy	16400.00
0005434408331	26917	Economy	16400.00
0005434408425	26917	Economy	16400.00
0005434408334	26917	Economy	16400.00
0005434408539	26917	Economy	16400.00
0005434299859	26917	Economy	16400.00
0005435311295	26917	Economy	16400.00
0005434408456	26917	Economy	16400.00
0005434408383	26917	Economy	16400.00
0005434408395	26917	Economy	16400.00
0005434408502	26917	Economy	16400.00
0005434408587	26917	Economy	16400.00
0005434299854	26917	Economy	16400.00
0005435311294	26917	Economy	16400.00
0005434408424	26917	Economy	16400.00
0005434408522	26917	Economy	16400.00
0005434408277	26917	Economy	16400.00
0005432058458	26917	Economy	16400.00
0005434299883	26917	Economy	16400.00
0005434408316	26917	Economy	16400.00
0005434408291	26917	Economy	16400.00
0005432058455	26917	Economy	16400.00
0005435293500	26917	Economy	16400.00
0005434408392	26917	Economy	16400.00
0005434299764	26917	Economy	16400.00
0005434408549	26917	Economy	16400.00
0005434408283	26917	Economy	16400.00
0005434408351	26917	Economy	16400.00
0005432058456	26917	Economy	16400.00
0005432058453	26917	Economy	16400.00
0005435293494	26917	Economy	16400.00
0005435293492	26917	Economy	16400.00
0005434408419	26917	Economy	16400.00
0005434408189	26917	Economy	16400.00
0005434408354	26917	Economy	16400.00
0005434408335	26917	Economy	16400.00
0005434299865	26917	Economy	16400.00
0005434408597	26917	Economy	16400.00
0005434408491	26917	Economy	16400.00
0005434408290	26917	Economy	16400.00
0005434408105	26917	Economy	16400.00
0005434408106	26917	Economy	16400.00
0005435293504	26917	Economy	16400.00
0005434408486	26917	Economy	16400.00
0005435293497	26917	Economy	16400.00
0005434408292	26917	Economy	16400.00
0005434408581	26917	Economy	16400.00
0005435293499	26917	Economy	16400.00
0005434408572	26917	Economy	16400.00
0005434408490	26917	Economy	16400.00
0005434408315	26917	Economy	16400.00
0005435311293	26917	Economy	16400.00
0005434408282	26917	Economy	16400.00
0005434408542	26917	Economy	16400.00
0005435311290	26917	Economy	16400.00
0005432058457	26917	Economy	16400.00
0005434408047	26917	Economy	16400.00
0005435293503	26917	Economy	16400.00
0005434408553	26917	Economy	16400.00
0005435293502	26917	Economy	16400.00
0005434299897	26917	Economy	16400.00
0005434408356	26917	Economy	16400.00
0005434408332	26917	Economy	16400.00
0005432605117	6444	Economy	16500.00
0005432605122	6444	Economy	16500.00
0005434512212	6444	Economy	16500.00
0005432605135	6444	Economy	16500.00
0005432605127	6444	Economy	15000.00
0005432605129	6444	Economy	15000.00
0005432605138	6444	Economy	15000.00
0005434512217	6444	Economy	15000.00
0005432605125	6444	Economy	15000.00
0005432605124	6444	Economy	15000.00
0005432605119	6444	Economy	15000.00
0005432605132	6444	Economy	15000.00
0005432605140	6444	Economy	15000.00
0005432605107	6444	Economy	15000.00
0005432605106	6444	Economy	15000.00
0005432605131	6444	Economy	15000.00
0005432605109	6444	Economy	15000.00
0005434512216	6444	Economy	15000.00
0005432605110	6444	Economy	15000.00
0005432605116	6444	Economy	15000.00
0005432605134	6444	Economy	15000.00
0005434512214	6444	Economy	15000.00
0005432605128	6444	Economy	15000.00
0005432605142	6444	Economy	15000.00
0005434512213	6444	Economy	15000.00
0005432605112	6444	Economy	15000.00
0005432605121	6444	Economy	15000.00
0005434512211	6444	Economy	15000.00
0005432605115	6444	Economy	15000.00
0005434512210	6444	Economy	15000.00
0005432605105	6444	Economy	15000.00
0005432605118	6444	Economy	15000.00
0005432605130	6444	Economy	15000.00
0005432605137	6444	Economy	15000.00
0005432605114	6444	Economy	15000.00
0005434512215	6444	Economy	15000.00
0005432605123	6444	Economy	15000.00
0005432605104	6444	Economy	15000.00
0005434512218	6444	Economy	15000.00
0005432605111	6444	Economy	15000.00
0005432605108	6444	Economy	15000.00
0005432605102	6444	Economy	15000.00
0005432605139	6444	Economy	15000.00
0005432605103	6444	Economy	15000.00
0005432605126	6444	Economy	15000.00
0005432605113	6444	Economy	15000.00
0005432605120	6444	Economy	15000.00
0005432605136	6444	Economy	15000.00
0005432605141	6444	Economy	15000.00
0005432605133	6444	Economy	15000.00
0005432604571	21363	Economy	16500.00
0005432604640	21363	Economy	16500.00
0005432604686	21363	Economy	16500.00
0005432604809	21363	Economy	16500.00
0005432604706	21363	Economy	15000.00
0005432604854	21363	Economy	15000.00
0005434512148	21363	Economy	15000.00
0005432604819	21363	Economy	15000.00
0005432604725	21363	Economy	15000.00
0005432604700	21363	Economy	15000.00
0005432604707	21363	Economy	15000.00
0005432604904	21363	Economy	15000.00
0005432604703	21363	Economy	15000.00
0005432604903	21363	Economy	15000.00
0005432604716	21363	Economy	15000.00
0005432604827	21363	Economy	15000.00
0005432604611	21363	Economy	15000.00
0005432604812	21363	Economy	15000.00
0005432604695	21363	Economy	15000.00
0005432604699	21363	Economy	15000.00
0005432604850	21363	Economy	15000.00
0005432604764	21363	Economy	15000.00
0005432604884	21363	Economy	15000.00
0005432604687	21363	Economy	15000.00
0005432604717	21363	Economy	15000.00
0005432604688	21363	Economy	15000.00
0005432604704	21363	Economy	15000.00
0005432604878	21363	Economy	15000.00
0005432604664	21363	Economy	15000.00
0005432604779	21363	Economy	15000.00
0005432604918	21363	Economy	15000.00
0005432604877	21363	Economy	15000.00
0005432604641	21363	Economy	15000.00
0005432604715	21363	Economy	15000.00
0005432604724	21363	Economy	15000.00
0005432604705	21363	Economy	15000.00
0005432604669	21363	Economy	15000.00
0005432604580	21363	Economy	15000.00
0005432604919	21363	Economy	15000.00
0005432604813	21363	Economy	15000.00
0005432604714	21363	Economy	15000.00
0005432604702	21363	Economy	15000.00
0005432604713	21363	Economy	15000.00
0005432604701	21363	Economy	15000.00
0005432604608	21363	Economy	15000.00
0005434512149	21363	Economy	15000.00
0005432604945	21363	Economy	15000.00
0005432604822	21363	Economy	15000.00
0005432604689	21363	Economy	15000.00
0005432604658	21363	Economy	15000.00
0005433252094	15011	Business	18900.00
0005433252076	15011	Business	18900.00
0005433252066	15011	Business	18900.00
0005434907805	15011	Business	18900.00
0005434907520	15011	Business	18900.00
0005433252090	15011	Business	18900.00
0005434907896	15011	Business	18900.00
0005434907618	15011	Business	18900.00
0005434907688	15011	Business	18900.00
0005434907746	15011	Business	18900.00
0005434907940	15011	Business	18900.00
0005434907819	15011	Economy	6300.00
0005434907944	15011	Economy	6300.00
0005434908109	15011	Economy	6300.00
0005433252092	15011	Economy	6300.00
0005434907801	15011	Economy	6300.00
0005434907793	15011	Economy	6300.00
0005433252069	15011	Economy	6300.00
0005434907560	15011	Economy	6900.00
0005434907941	15011	Economy	6900.00
0005434907800	15011	Economy	6900.00
0005433252081	15011	Economy	6300.00
0005433252093	15011	Economy	6300.00
0005433252073	15011	Economy	6300.00
0005434907761	15011	Economy	6300.00
0005433252085	15011	Economy	6300.00
0005434907644	15011	Economy	6300.00
0005434907816	15011	Economy	6300.00
0005433252077	15011	Economy	6300.00
0005434907841	15011	Economy	6300.00
0005434907799	15011	Economy	6300.00
0005434907810	15011	Economy	6300.00
0005433252086	15011	Economy	6300.00
0005433252082	15011	Economy	6300.00
0005433252083	15011	Economy	6300.00
0005433252087	15011	Economy	6300.00
0005433252095	15011	Economy	6300.00
0005433252084	15011	Economy	6300.00
0005434907619	15011	Economy	6300.00
0005434907789	15011	Economy	6300.00
0005434907968	15011	Economy	6300.00
0005434907804	15011	Economy	6300.00
0005433252072	15011	Economy	6300.00
0005434907972	15011	Economy	6300.00
0005434907660	15011	Economy	6300.00
0005433252080	15011	Economy	6300.00
0005434907768	15011	Economy	6300.00
0005433252096	15011	Economy	6300.00
0005433252079	15011	Economy	6300.00
0005434907933	15011	Economy	6300.00
0005434907796	15011	Economy	6300.00
0005434907775	15011	Economy	6300.00
0005434907769	15011	Economy	6300.00
0005434907702	15011	Economy	6300.00
0005434907770	15011	Economy	6300.00
0005434907671	15011	Economy	6300.00
0005433252068	15011	Economy	6300.00
0005433252067	15011	Economy	6300.00
0005434907840	15011	Economy	6300.00
0005433252091	15011	Economy	6300.00
0005433252074	15011	Economy	6300.00
0005434907802	15011	Economy	6300.00
0005434907762	15011	Economy	6300.00
0005434907670	15011	Economy	6300.00
0005433252071	15011	Economy	6300.00
0005433252070	15011	Economy	6300.00
0005434907795	15011	Economy	6300.00
0005433252078	15011	Economy	6300.00
0005433252088	15011	Economy	6300.00
0005433252075	15011	Economy	6300.00
0005433252089	15011	Economy	6300.00
0005434907885	15011	Economy	6300.00
0005434907535	15011	Economy	6300.00
0005434907884	15011	Economy	6300.00
0005434908238	25848	Business	18900.00
0005433251746	25848	Business	18900.00
0005434908246	25848	Business	18900.00
0005433251797	25848	Business	18900.00
0005434908250	25848	Business	18900.00
0005433251801	25848	Business	18900.00
0005434908252	25848	Business	18900.00
0005434908269	25848	Business	18900.00
0005434908258	25848	Business	18900.00
0005433251754	25848	Business	18900.00
0005434908236	25848	Business	18900.00
0005433251753	25848	Economy	6300.00
0005434908273	25848	Economy	6300.00
0005434908259	25848	Economy	6300.00
0005433251752	25848	Economy	6300.00
0005434908276	25848	Economy	6300.00
0005434908230	25848	Economy	6300.00
0005433251888	25848	Economy	6300.00
0005434908243	25848	Economy	6300.00
0005434908232	25848	Economy	6300.00
0005434908241	25848	Economy	6900.00
0005433251866	25848	Economy	6900.00
0005434908231	25848	Economy	6900.00
0005433251906	25848	Economy	6900.00
0005434908257	25848	Economy	6300.00
0005433251722	25848	Economy	6300.00
0005434908245	25848	Economy	6300.00
0005433251855	25848	Economy	6300.00
0005434908267	25848	Economy	6300.00
0005434908277	25848	Economy	6300.00
0005433251887	25848	Economy	6300.00
0005434908223	25848	Economy	6300.00
0005434908249	25848	Economy	6300.00
0005434908274	25848	Economy	6300.00
0005433251813	25848	Economy	6300.00
0005434908227	25848	Economy	6300.00
0005433251758	25848	Economy	6300.00
0005433251819	25848	Economy	6300.00
0005433251802	25848	Economy	6300.00
0005433251763	25848	Economy	6300.00
0005433251818	25848	Economy	6300.00
0005434908261	25848	Economy	6300.00
0005434908253	25848	Economy	6300.00
0005433251867	25848	Economy	6300.00
0005434908248	25848	Economy	6300.00
0005434908239	25848	Economy	6300.00
0005433251841	25848	Economy	6300.00
0005433251729	25848	Economy	6300.00
0005434908225	25848	Economy	6300.00
0005434908262	25848	Economy	6300.00
0005433251759	25848	Economy	6300.00
0005433251868	25848	Economy	6300.00
0005434908278	25848	Economy	6300.00
0005434908220	25848	Economy	6300.00
0005434908272	25848	Economy	6300.00
0005434908222	25848	Economy	6300.00
0005434908260	25848	Economy	6300.00
0005434908233	25848	Economy	6300.00
0005433251905	25848	Economy	6300.00
0005434908275	25848	Economy	6300.00
0005434908256	25848	Economy	6300.00
0005433251796	25848	Economy	6300.00
0005434908221	25848	Economy	6300.00
0005434908255	25848	Economy	6300.00
0005434908224	25848	Economy	6300.00
0005434908234	25848	Economy	6300.00
0005434908247	25848	Economy	6300.00
0005434908264	25848	Economy	6300.00
0005433251826	25848	Economy	6300.00
0005434908244	25848	Economy	6300.00
0005434908251	25848	Economy	6300.00
0005434908240	25848	Economy	6300.00
0005434908254	25848	Economy	6300.00
0005434908266	25848	Economy	6300.00
0005434908237	25848	Economy	6300.00
0005434908270	25848	Economy	6300.00
0005434908265	25848	Economy	6300.00
0005434908268	25848	Economy	6300.00
0005434908226	25848	Economy	6300.00
0005434908219	25848	Economy	6300.00
0005433251760	25848	Economy	6300.00
0005434908271	25848	Economy	6300.00
0005433251896	25848	Economy	6300.00
0005434908229	25848	Economy	6300.00
0005434908263	25848	Economy	6300.00
0005434908235	25848	Economy	6300.00
0005434908242	25848	Economy	6300.00
0005434908228	25848	Economy	6300.00
0005433009513	14202	Business	52300.00
0005433009498	14202	Business	52300.00
0005433009517	14202	Business	52300.00
0005433009494	14202	Business	52300.00
0005433009502	14202	Economy	17400.00
0005433009520	14202	Economy	17400.00
0005433009529	14202	Economy	17400.00
0005433009509	14202	Economy	17400.00
0005433009504	14202	Economy	17400.00
0005433009521	14202	Economy	17400.00
0005433009518	14202	Economy	19200.00
0005433009497	14202	Economy	17400.00
0005433009495	14202	Economy	17400.00
0005433009522	14202	Economy	17400.00
0005433009515	14202	Economy	17400.00
0005433009535	14202	Economy	17400.00
0005433009525	14202	Economy	17400.00
0005433810569	14202	Economy	17400.00
0005433009493	14202	Economy	17400.00
0005433009511	14202	Economy	17400.00
0005433009532	14202	Economy	17400.00
0005433009492	14202	Economy	17400.00
0005433009496	14202	Economy	17400.00
0005433009510	14202	Economy	17400.00
0005433009514	14202	Economy	17400.00
0005433009503	14202	Economy	17400.00
0005433009500	14202	Economy	17400.00
0005433009523	14202	Economy	17400.00
0005433009524	14202	Economy	17400.00
0005433009530	14202	Economy	17400.00
0005433009507	14202	Economy	17400.00
0005433009534	14202	Economy	17400.00
0005433009528	14202	Economy	17400.00
0005433009512	14202	Economy	17400.00
0005433009531	14202	Economy	17400.00
0005433009527	14202	Economy	17400.00
0005433009516	14202	Economy	17400.00
0005433009505	14202	Economy	17400.00
0005433009506	14202	Economy	17400.00
0005433009519	14202	Economy	17400.00
0005433009533	14202	Economy	17400.00
0005433009537	14202	Economy	17400.00
0005433009501	14202	Economy	17400.00
0005433009499	14202	Economy	17400.00
0005433009536	14202	Economy	17400.00
0005433009508	14202	Economy	17400.00
0005433009526	14202	Economy	17400.00
0005433009095	22823	Business	52300.00
0005433008815	22823	Business	52300.00
0005433008951	22823	Business	52300.00
0005433009040	22823	Business	52300.00
0005433009119	22823	Business	52300.00
0005433810622	22823	Business	52300.00
0005433009001	22823	Economy	17400.00
0005433008988	22823	Economy	17400.00
0005433009107	22823	Economy	17400.00
0005433009114	22823	Economy	19200.00
0005433009112	22823	Economy	19200.00
0005433008995	22823	Economy	19200.00
0005433009230	22823	Economy	17400.00
0005433008949	22823	Economy	17400.00
0005433009164	22823	Economy	17400.00
0005433810620	22823	Economy	17400.00
0005433008916	22823	Economy	17400.00
0005433008956	22823	Economy	17400.00
0005433009147	22823	Economy	17400.00
0005433009055	22823	Economy	17400.00
0005433009115	22823	Economy	17400.00
0005433009232	22823	Economy	17400.00
0005433009109	22823	Economy	17400.00
0005433009151	22823	Economy	17400.00
0005433009163	22823	Economy	17400.00
0005433810617	22823	Economy	17400.00
0005433009108	22823	Economy	17400.00
0005433810616	22823	Economy	17400.00
0005433008994	22823	Economy	17400.00
0005433009064	22823	Economy	17400.00
0005433009254	22823	Economy	17400.00
0005433009194	22823	Economy	17400.00
0005433009078	22823	Economy	17400.00
0005433009113	22823	Economy	17400.00
0005433009150	22823	Economy	17400.00
0005433008933	22823	Economy	17400.00
0005433009032	22823	Economy	17400.00
0005433810619	22823	Economy	17400.00
0005433009037	22823	Economy	17400.00
0005433009094	22823	Economy	17400.00
0005433009133	22823	Economy	17400.00
0005433009136	22823	Economy	17400.00
0005433009104	22823	Economy	17400.00
0005433810621	22823	Economy	17400.00
0005433008950	22823	Economy	17400.00
0005433009002	22823	Economy	17400.00
0005433810618	22823	Economy	17400.00
0005433009231	22823	Economy	17400.00
0005433009144	22823	Economy	17400.00
0005433008996	22823	Economy	17400.00
0005433009005	22823	Economy	17400.00
0005433009056	22823	Economy	17400.00
0005435719024	15520	Business	85200.00
0005435719036	15520	Business	85200.00
0005435719005	15520	Business	85200.00
0005435719016	15520	Business	85200.00
0005435719032	15520	Economy	28400.00
0005435719028	15520	Economy	28400.00
0005435719017	15520	Economy	31200.00
0005435719019	15520	Economy	31200.00
0005435719003	15520	Economy	31200.00
0005435719008	15520	Economy	31200.00
0005435719041	15520	Economy	28400.00
0005435719029	15520	Economy	28400.00
0005435719035	15520	Economy	28400.00
0005435719013	15520	Economy	28400.00
0005435719004	15520	Economy	28400.00
0005435719038	15520	Economy	28400.00
0005435719012	15520	Economy	28400.00
0005435719034	15520	Economy	28400.00
0005435719040	15520	Economy	28400.00
0005435719039	15520	Economy	28400.00
0005435719020	15520	Economy	28400.00
0005435719027	15520	Economy	28400.00
0005435719010	15520	Economy	28400.00
0005435719015	15520	Economy	28400.00
0005435719033	15520	Economy	28400.00
0005435719006	15520	Economy	28400.00
0005435719025	15520	Economy	28400.00
0005435719014	15520	Economy	28400.00
0005435719009	15520	Economy	28400.00
0005435719031	15520	Economy	28400.00
0005435719021	15520	Economy	28400.00
0005435719030	15520	Economy	28400.00
0005435719007	15520	Economy	28400.00
0005435719037	15520	Economy	28400.00
0005435719011	15520	Economy	28400.00
0005435719023	15520	Economy	28400.00
0005435719018	15520	Economy	28400.00
0005435719026	15520	Economy	28400.00
0005435719022	15520	Economy	28400.00
0005434926051	14914	Business	22900.00
0005434925975	14914	Business	22900.00
0005434925973	14914	Economy	7600.00
0005434926165	14914	Economy	7600.00
0005434925976	14914	Economy	7600.00
0005434926047	14914	Economy	7600.00
0005434926029	14914	Economy	7600.00
0005434926111	14914	Economy	7600.00
0005434926121	14914	Economy	8400.00
0005434926093	14914	Economy	8400.00
0005434926117	14914	Economy	7600.00
0005434926067	14914	Economy	7600.00
0005434926127	14914	Economy	7600.00
0005434926078	14914	Economy	7600.00
0005434926143	14914	Economy	7600.00
0005434926115	14914	Economy	7600.00
0005434926146	14914	Economy	7600.00
0005434926114	14914	Economy	7600.00
0005434926159	14914	Economy	7600.00
0005434926050	14914	Economy	7600.00
0005434926021	14914	Economy	7600.00
0005434926126	14914	Economy	7600.00
0005434926062	14914	Economy	7600.00
0005434926085	14914	Economy	7600.00
0005434926084	14914	Economy	7600.00
0005434926138	14914	Economy	7600.00
0005434926066	14914	Economy	7600.00
0005434926079	14914	Economy	7600.00
0005434926139	14914	Economy	7600.00
0005434926122	14914	Economy	7600.00
0005434926030	14914	Economy	7600.00
0005434925974	14914	Economy	7600.00
0005434926395	20522	Business	22900.00
0005434926396	20522	Business	22900.00
0005434926383	20522	Business	22900.00
0005434926372	20522	Business	22900.00
0005434926397	20522	Business	22900.00
0005434926379	20522	Economy	8400.00
0005434926401	20522	Economy	8400.00
0005434926384	20522	Economy	7600.00
0005434926399	20522	Economy	7600.00
0005434926375	20522	Economy	7600.00
0005434926389	20522	Economy	7600.00
0005434926385	20522	Economy	7600.00
0005434926398	20522	Economy	7600.00
0005434926386	20522	Economy	7600.00
0005434926402	20522	Economy	7600.00
0005434926404	20522	Economy	7600.00
0005434926376	20522	Economy	7600.00
0005434926374	20522	Economy	7600.00
0005434926380	20522	Economy	7600.00
0005434926387	20522	Economy	7600.00
0005434926394	20522	Economy	7600.00
0005434926391	20522	Economy	7600.00
0005434926400	20522	Economy	7600.00
0005434926373	20522	Economy	7600.00
0005434926393	20522	Economy	7600.00
0005434926392	20522	Economy	7600.00
0005434926403	20522	Economy	7600.00
0005434926382	20522	Economy	7600.00
0005434926381	20522	Economy	7600.00
0005434926388	20522	Economy	7600.00
0005434926390	20522	Economy	7600.00
0005434926377	20522	Economy	7600.00
0005434926378	20522	Economy	7600.00
0005435488268	15808	Economy	8900.00
0005435488254	15808	Economy	8900.00
0005435488267	15808	Economy	8900.00
0005435999471	15808	Economy	8100.00
0005435999475	15808	Economy	8100.00
0005435488261	15808	Economy	8100.00
0005435999473	15808	Economy	8100.00
0005435488252	15808	Economy	8100.00
0005435488265	15808	Economy	8100.00
0005435999338	15808	Economy	8100.00
0005435488258	15808	Economy	8100.00
0005435488259	15808	Economy	8100.00
0005435488256	15808	Economy	8100.00
0005435488260	15808	Economy	8100.00
0005435999474	15808	Economy	8100.00
0005435999464	15808	Economy	8100.00
0005435488263	15808	Economy	8100.00
0005435999419	15808	Economy	8100.00
0005435999404	15808	Economy	8100.00
0005435999469	15808	Economy	8100.00
0005435999414	15808	Economy	8100.00
0005435999456	15808	Economy	8100.00
0005435999455	15808	Economy	8100.00
0005435488257	15808	Economy	8100.00
0005435488272	15808	Economy	8100.00
0005435488255	15808	Economy	8100.00
0005435999413	15808	Economy	8100.00
0005435999472	15808	Economy	8100.00
0005435488271	15808	Economy	8100.00
0005435488253	15808	Economy	8100.00
0005435488269	15808	Economy	8100.00
0005435488262	15808	Economy	8100.00
0005435999465	15808	Economy	8100.00
0005435488270	15808	Economy	8100.00
0005435488266	15808	Economy	8100.00
0005435488264	15808	Economy	8100.00
0005435999454	15808	Economy	8100.00
0005435488073	19718	Economy	8900.00
0005435488042	19718	Economy	8900.00
0005435999585	19718	Economy	8100.00
0005435999584	19718	Economy	8100.00
0005435488072	19718	Economy	8100.00
0005435488079	19718	Economy	8100.00
0005435488018	19718	Economy	8100.00
0005435488092	19718	Economy	8100.00
0005435488088	19718	Economy	8100.00
0005435999589	19718	Economy	8100.00
0005435999578	19718	Economy	8100.00
0005435488021	19718	Economy	8100.00
0005435999580	19718	Economy	8100.00
0005435488049	19718	Economy	8100.00
0005435487993	19718	Economy	8100.00
0005435999577	19718	Economy	8100.00
0005435488019	19718	Economy	8100.00
0005435999586	19718	Economy	8100.00
0005435488048	19718	Economy	8100.00
0005435488035	19718	Economy	8100.00
0005435488022	19718	Economy	8100.00
0005435999582	19718	Economy	8100.00
0005435488085	19718	Economy	8100.00
0005435488034	19718	Economy	8100.00
0005435488093	19718	Economy	8100.00
0005435999587	19718	Economy	8100.00
0005435488043	19718	Economy	8100.00
0005435487992	19718	Economy	8100.00
0005435999581	19718	Economy	8100.00
0005435999579	19718	Economy	8100.00
0005435488080	19718	Economy	8100.00
0005435999588	19718	Economy	8100.00
0005435488006	19718	Economy	8100.00
0005435488055	19718	Economy	8100.00
0005435488033	19718	Economy	8100.00
0005435999583	19718	Economy	8100.00
0005435488044	19718	Economy	8100.00
0005435488086	19718	Economy	8100.00
0005435840013	5994	Business	199300.00
0005435840015	5994	Business	199300.00
0005432537072	5994	Business	199300.00
0005432537077	5994	Business	199300.00
0005432142314	5994	Business	199300.00
0005435839996	5994	Business	199300.00
0005435840005	5994	Business	199300.00
0005435840022	5994	Business	199300.00
0005435840020	5994	Business	199300.00
0005435472955	5994	Economy	66400.00
0005435473044	5994	Economy	66400.00
0005435473042	5994	Economy	66400.00
0005435473026	5994	Economy	66400.00
0005435473001	5994	Economy	66400.00
0005435840007	5994	Economy	73100.00
0005435840019	5994	Economy	73100.00
0005432660861	5994	Economy	66400.00
0005432537081	5994	Economy	66400.00
0005432660859	5994	Economy	66400.00
0005432659748	5994	Economy	66400.00
0005435472940	5994	Economy	66400.00
0005432142312	5994	Economy	66400.00
0005435473000	5994	Economy	66400.00
0005435840016	5994	Economy	66400.00
0005435840011	5994	Economy	66400.00
0005435840008	5994	Economy	66400.00
0005432537073	5994	Economy	66400.00
0005435840012	5994	Economy	66400.00
0005435472986	5994	Economy	66400.00
0005432660860	5994	Economy	66400.00
0005435840009	5994	Economy	66400.00
0005432659750	5994	Economy	66400.00
0005435840018	5994	Economy	66400.00
0005435839997	5994	Economy	66400.00
0005435840010	5994	Economy	66400.00
0005435840004	5994	Economy	66400.00
0005432537082	5994	Economy	66400.00
0005432658634	5994	Economy	66400.00
0005435472960	5994	Economy	66400.00
0005435472907	5994	Economy	66400.00
0005435472954	5994	Economy	66400.00
0005435840000	5994	Economy	66400.00
0005435840003	5994	Economy	66400.00
0005432142313	5994	Economy	66400.00
0005432537078	5994	Economy	66400.00
0005435840017	5994	Economy	66400.00
0005435839998	5994	Economy	66400.00
0005435840002	5994	Economy	66400.00
0005432142315	5994	Economy	66400.00
0005435472906	5994	Economy	66400.00
0005435473045	5994	Economy	66400.00
0005435840021	5994	Economy	66400.00
0005435473016	5994	Economy	66400.00
0005432659749	5994	Economy	66400.00
0005432658633	5994	Economy	66400.00
0005435840014	5994	Economy	66400.00
0005435840006	5994	Economy	66400.00
0005435840001	5994	Economy	66400.00
0005435839999	5994	Economy	66400.00
0005435473017	5994	Economy	66400.00
0005435473124	18085	Business	199300.00
0005435473130	18085	Business	199300.00
0005435473132	18085	Business	199300.00
0005435839665	18085	Business	199300.00
0005435839675	18085	Business	199300.00
0005435473121	18085	Business	199300.00
0005435839726	18085	Business	199300.00
0005435473135	18085	Economy	66400.00
0005432667469	18085	Economy	66400.00
0005435839801	18085	Economy	66400.00
0005435839829	18085	Economy	73100.00
0005435839704	18085	Economy	66400.00
0005435839787	18085	Economy	66400.00
0005432660826	18085	Economy	66400.00
0005435473137	18085	Economy	66400.00
0005435473128	18085	Economy	66400.00
0005435473127	18085	Economy	66400.00
0005435473131	18085	Economy	66400.00
0005432667470	18085	Economy	66400.00
0005435839826	18085	Economy	66400.00
0005435839788	18085	Economy	66400.00
0005435839708	18085	Economy	66400.00
0005435473129	18085	Economy	66400.00
0005435473134	18085	Economy	66400.00
0005435839770	18085	Economy	66400.00
0005435839830	18085	Economy	66400.00
0005435473126	18085	Economy	66400.00
0005435839796	18085	Economy	66400.00
0005435839827	18085	Economy	66400.00
0005435839676	18085	Economy	66400.00
0005432667473	18085	Economy	66400.00
0005435473120	18085	Economy	66400.00
0005432660837	18085	Economy	66400.00
0005435839847	18085	Economy	66400.00
0005435839831	18085	Economy	66400.00
0005432537100	18085	Economy	66400.00
0005435839784	18085	Economy	66400.00
0005435839671	18085	Economy	66400.00
0005432667464	18085	Economy	66400.00
0005435473136	18085	Economy	66400.00
0005432660831	18085	Economy	66400.00
0005435473125	18085	Economy	66400.00
0005432537101	18085	Economy	66400.00
0005432660838	18085	Economy	66400.00
0005435839793	18085	Economy	66400.00
0005435839771	18085	Economy	66400.00
0005435839848	18085	Economy	66400.00
0005435839773	18085	Economy	66400.00
0005435473133	18085	Economy	66400.00
0005435839709	18085	Economy	66400.00
0005435839666	18085	Economy	66400.00
0005435473122	18085	Economy	66400.00
0005432537102	18085	Economy	66400.00
0005435473123	18085	Economy	66400.00
0005435104091	23045	Business	15700.00
0005435104090	23045	Business	15700.00
0005435104073	23045	Economy	5200.00
0005433285521	23045	Economy	5200.00
0005435104074	23045	Economy	5200.00
0005433285630	23045	Economy	5200.00
0005435104084	23045	Economy	5200.00
0005433285561	23045	Economy	5200.00
0005435104080	23045	Economy	5200.00
0005433285547	23045	Economy	5200.00
0005435104076	23045	Economy	5200.00
0005435104086	23045	Economy	5200.00
0005435104072	23045	Economy	5200.00
0005435104087	23045	Economy	5200.00
0005433285562	23045	Economy	5200.00
0005433285584	23045	Economy	5200.00
0005433285681	23045	Economy	5200.00
0005435104088	23045	Economy	5200.00
0005435104077	23045	Economy	5200.00
0005435104083	23045	Economy	5700.00
0005433285780	23045	Economy	5200.00
0005433285763	23045	Economy	5200.00
0005435104075	23045	Economy	5200.00
0005433285680	23045	Economy	5200.00
0005433285596	23045	Economy	5200.00
0005435104082	23045	Economy	5200.00
0005433285662	23045	Economy	5200.00
0005433285697	23045	Economy	5200.00
0005433285597	23045	Economy	5200.00
0005435104081	23045	Economy	5200.00
0005433285665	23045	Economy	5200.00
0005433285663	23045	Economy	5200.00
0005433285554	23045	Economy	5200.00
0005435104078	23045	Economy	5200.00
0005433285509	23045	Economy	5200.00
0005435104079	23045	Economy	5200.00
0005433285767	23045	Economy	5200.00
0005435104089	23045	Economy	5200.00
0005435104085	23045	Economy	5200.00
0005433285669	23045	Economy	5200.00
0005433285598	23045	Economy	5200.00
0005433285901	32043	Business	15700.00
0005433285927	32043	Economy	5200.00
0005435104008	32043	Economy	5200.00
0005433285906	32043	Economy	5200.00
0005433285920	32043	Economy	5200.00
0005433285929	32043	Economy	5200.00
0005435104006	32043	Economy	5200.00
0005433285907	32043	Economy	5200.00
0005433285903	32043	Economy	5200.00
0005433285930	32043	Economy	5200.00
0005433285915	32043	Economy	5200.00
0005433285928	32043	Economy	5200.00
0005433285916	32043	Economy	5200.00
0005433285931	32043	Economy	5200.00
0005433285911	32043	Economy	5200.00
0005433285905	32043	Economy	5200.00
0005433285921	32043	Economy	5700.00
0005433285925	32043	Economy	5200.00
0005433285914	32043	Economy	5200.00
0005433285924	32043	Economy	5200.00
0005433285909	32043	Economy	5200.00
0005433285926	32043	Economy	5200.00
0005433285910	32043	Economy	5200.00
0005433285913	32043	Economy	5200.00
0005433285918	32043	Economy	5200.00
0005435103983	32043	Economy	5200.00
0005433285912	32043	Economy	5200.00
0005435103994	32043	Economy	5200.00
0005435103991	32043	Economy	5200.00
0005433285900	32043	Economy	5200.00
0005433285902	32043	Economy	5200.00
0005433285908	32043	Economy	5200.00
0005433285923	32043	Economy	5200.00
0005433285919	32043	Economy	5200.00
0005435104009	32043	Economy	5200.00
0005433285904	32043	Economy	5200.00
0005433285922	32043	Economy	5200.00
0005433285917	32043	Economy	5200.00
0005433112380	1477	Business	150400.00
0005432892782	1477	Business	150400.00
0005432802592	1477	Business	150400.00
0005432802588	1477	Business	150400.00
0005432802564	1477	Business	150400.00
0005432892783	1477	Business	150400.00
0005432802581	1477	Business	150400.00
0005432802571	1477	Business	150400.00
0005432892780	1477	Business	150400.00
0005433112387	1477	Business	150400.00
0005432802574	1477	Business	150400.00
0005432892779	1477	Economy	50100.00
0005432892773	1477	Economy	50100.00
0005433112377	1477	Economy	50100.00
0005432802591	1477	Economy	50100.00
0005432892785	1477	Economy	50100.00
0005432892774	1477	Economy	50100.00
0005432802589	1477	Economy	50100.00
0005433112371	1477	Economy	50100.00
0005432802586	1477	Economy	55200.00
0005432802573	1477	Economy	50100.00
0005432802582	1477	Economy	55200.00
0005432802576	1477	Economy	50100.00
0005432892761	1477	Economy	50100.00
0005432802566	1477	Economy	50100.00
0005432802577	1477	Economy	50100.00
0005432802585	1477	Economy	50100.00
0005432802570	1477	Economy	50100.00
0005432892759	1477	Economy	50100.00
0005433112376	1477	Economy	50100.00
0005432892760	1477	Economy	50100.00
0005432892754	1477	Economy	50100.00
0005432802580	1477	Economy	50100.00
0005432892768	1477	Economy	50100.00
0005432802590	1477	Economy	50100.00
0005432802569	1477	Economy	50100.00
0005433112379	1477	Economy	50100.00
0005432802575	1477	Economy	50100.00
0005432892778	1477	Economy	50100.00
0005432802568	1477	Economy	50100.00
0005432892765	1477	Economy	50100.00
0005432802579	1477	Economy	50100.00
0005432802565	1477	Economy	50100.00
0005433112381	1477	Economy	50100.00
0005432802583	1477	Economy	50100.00
0005432802578	1477	Economy	50100.00
0005433112378	1477	Economy	50100.00
0005432892784	1477	Economy	50100.00
0005433112373	1477	Economy	50100.00
0005432892763	1477	Economy	50100.00
0005432802587	1477	Economy	50100.00
0005433112374	1477	Economy	50100.00
0005432802572	1477	Economy	50100.00
0005432802584	1477	Economy	50100.00
0005432802593	1477	Economy	50100.00
0005433112382	1477	Economy	50100.00
0005433112383	1477	Economy	50100.00
0005432892767	1477	Economy	50100.00
0005432802594	1477	Economy	50100.00
0005432892762	1477	Economy	50100.00
0005432802567	1477	Economy	50100.00
0005433475755	23873	Economy	13500.00
0005433475761	23873	Economy	12300.00
0005435852629	23873	Economy	12300.00
0005433475760	23873	Economy	12300.00
0005433475753	23873	Economy	12300.00
0005433475763	23873	Economy	12300.00
0005435852628	23873	Economy	12300.00
0005435852632	23873	Economy	12300.00
0005435852627	23873	Economy	12300.00
0005433475741	23873	Economy	12300.00
0005433475754	23873	Economy	12300.00
0005433475756	23873	Economy	12300.00
0005435852624	23873	Economy	12300.00
0005433475731	23873	Economy	12300.00
0005433475751	23873	Economy	12300.00
0005433475730	23873	Economy	12300.00
0005435852631	23873	Economy	12300.00
0005433475764	23873	Economy	12300.00
0005435852630	23873	Economy	12300.00
0005433475742	23873	Economy	12300.00
0005433475752	23873	Economy	12300.00
0005435852625	23873	Economy	12300.00
0005435852626	23873	Economy	12300.00
0005433475757	23873	Economy	12300.00
0005434068254	30579	Business	42100.00
0005432529827	30579	Business	42100.00
0005432529784	30579	Business	42100.00
0005432529551	30579	Business	42100.00
0005435214915	30579	Business	42100.00
0005432211657	30579	Business	42100.00
0005435214959	30579	Business	42100.00
0005434068653	30579	Business	42100.00
0005435214900	30579	Business	42100.00
0005434068003	30579	Business	42100.00
0005435214938	30579	Business	42100.00
0005432159949	30579	Business	42100.00
0005432529566	30579	Business	42100.00
0005432529745	30579	Business	42100.00
0005435214898	30579	Business	42100.00
0005432529072	30579	Business	42100.00
0005434068284	30579	Business	42100.00
0005434068652	30579	Business	42100.00
0005432529016	30579	Business	42100.00
0005435214921	30579	Business	42100.00
0005432529559	30579	Business	42100.00
0005432529675	30579	Business	42100.00
0005432529497	30579	Business	42100.00
0005434068363	30579	Business	42100.00
0005432529151	30579	Comfort	23900.00
0005432529499	30579	Comfort	23900.00
0005432529796	30579	Comfort	23900.00
0005432529015	30579	Comfort	23900.00
0005432529779	30579	Comfort	23900.00
0005434068595	30579	Comfort	23900.00
0005435214925	30579	Comfort	23900.00
0005435631030	30579	Comfort	23900.00
0005432529432	30579	Comfort	23900.00
0005435214933	30579	Comfort	23900.00
0005435214895	30579	Comfort	23900.00
0005434068281	30579	Comfort	23900.00
0005432428963	30579	Comfort	23900.00
0005432528839	30579	Comfort	23900.00
0005435214927	30579	Comfort	23900.00
0005432529488	30579	Comfort	23900.00
0005435214917	30579	Comfort	23900.00
0005434068437	30579	Comfort	23900.00
0005434068269	30579	Comfort	23900.00
0005434068458	30579	Comfort	23900.00
0005432529284	30579	Comfort	23900.00
0005434068539	30579	Comfort	23900.00
0005432529511	30579	Comfort	23900.00
0005433656740	30579	Comfort	23900.00
0005432529691	30579	Comfort	23900.00
0005434068590	30579	Comfort	23900.00
0005435214939	30579	Comfort	23900.00
0005434068641	30579	Comfort	23900.00
0005434068425	30579	Comfort	23900.00
0005432529808	30579	Comfort	23900.00
0005432529712	30579	Comfort	23900.00
0005432529746	30579	Comfort	23900.00
0005435214932	30579	Comfort	23900.00
0005432529706	30579	Comfort	23900.00
0005434068431	30579	Comfort	23900.00
0005432528958	30579	Comfort	23900.00
0005432529388	30579	Comfort	23900.00
0005432529271	30579	Comfort	23900.00
0005434068293	30579	Comfort	23900.00
0005432533331	30579	Comfort	23900.00
0005432529741	30579	Comfort	23900.00
0005434068246	30579	Comfort	23900.00
0005432529415	30579	Comfort	23900.00
0005432529017	30579	Comfort	23900.00
0005434068411	30579	Economy	14000.00
0005432529469	30579	Economy	14000.00
0005434068605	30579	Economy	14000.00
0005434068263	30579	Economy	14000.00
0005434068361	30579	Economy	14000.00
0005432529883	30579	Economy	14000.00
0005434068424	30579	Economy	14000.00
0005435214922	30579	Economy	14000.00
0005432528864	30579	Economy	14000.00
0005432529602	30579	Economy	14000.00
0005435214896	30579	Economy	14000.00
0005434068294	30579	Economy	14000.00
0005432528918	30579	Economy	14000.00
0005432535874	30579	Economy	14000.00
0005434068247	30579	Economy	14000.00
0005432529510	30579	Economy	14000.00
0005432529138	30579	Economy	14000.00
0005435214962	30579	Economy	14000.00
0005432529452	30579	Economy	14000.00
0005432529822	30579	Economy	14000.00
0005432529386	30579	Economy	14000.00
0005434068491	30579	Economy	14000.00
0005432529389	30579	Economy	14000.00
0005435214947	30579	Economy	14000.00
0005434068327	30579	Economy	14000.00
0005435214918	30579	Economy	14000.00
0005432529334	30579	Economy	14000.00
0005434067962	30579	Economy	14000.00
0005434068487	30579	Economy	14000.00
0005435725701	30579	Economy	14000.00
0005432529872	30579	Economy	14000.00
0005434068295	30579	Economy	14000.00
0005434068576	30579	Economy	14000.00
0005434068446	30579	Economy	14000.00
0005432529943	30579	Economy	14000.00
0005434068026	30579	Economy	14000.00
0005432529459	30579	Economy	14000.00
0005434068454	30579	Economy	14000.00
0005432529227	30579	Economy	14000.00
0005432211654	30579	Economy	14000.00
0005432529686	30579	Economy	14000.00
0005432529603	30579	Economy	14000.00
0005435214940	30579	Economy	14000.00
0005434068216	30579	Economy	14000.00
0005434068362	30579	Economy	14000.00
0005432529139	30579	Economy	14000.00
0005434068297	30579	Economy	14000.00
0005434068596	30579	Economy	14000.00
0005434068654	30579	Economy	14000.00
0005432529617	30579	Economy	14000.00
0005435214948	30579	Economy	14000.00
0005434068415	30579	Economy	14000.00
0005434068385	30579	Economy	14000.00
0005434068183	30579	Economy	14000.00
0005435214956	30579	Economy	14000.00
0005432535875	30579	Economy	14000.00
0005432529326	30579	Economy	14000.00
0005432159951	30579	Economy	14000.00
0005434068325	30579	Economy	14000.00
0005432529792	30579	Economy	14000.00
0005432533327	30579	Economy	14000.00
0005435214931	30579	Economy	14000.00
0005432529718	30579	Economy	14000.00
0005434068422	30579	Economy	15400.00
0005433656741	30579	Economy	14000.00
0005432529285	30579	Economy	15400.00
0005432529403	30579	Economy	14000.00
0005432529454	30579	Economy	14000.00
0005434068577	30579	Economy	15400.00
0005432529768	30579	Economy	14000.00
0005432530162	30579	Economy	15400.00
0005432529674	30579	Economy	14000.00
0005434068443	30579	Economy	14000.00
0005434068408	30579	Economy	14000.00
0005434068218	30579	Economy	14000.00
0005434068397	30579	Economy	14000.00
0005432529820	30579	Economy	14000.00
0005432529944	30579	Economy	14000.00
0005434068215	30579	Economy	14000.00
0005432529012	30579	Economy	14000.00
0005435214897	30579	Economy	14000.00
0005435214919	30579	Economy	14000.00
0005434068165	30579	Economy	14000.00
0005435214942	30579	Economy	14000.00
0005432428972	30579	Economy	14000.00
0005434068025	30579	Economy	14000.00
0005432528838	30579	Economy	14000.00
0005434068542	30579	Economy	14000.00
0005435631029	30579	Economy	14000.00
0005432529364	30579	Economy	14000.00
0005432529152	30579	Economy	14000.00
0005434067953	30579	Economy	14000.00
0005432529491	30579	Economy	14000.00
0005434068457	30579	Economy	14000.00
0005432529788	30579	Economy	14000.00
0005434068436	30579	Economy	14000.00
0005432529871	30579	Economy	14000.00
0005434068430	30579	Economy	14000.00
0005435214961	30579	Economy	14000.00
0005435214946	30579	Economy	14000.00
0005435214928	30579	Economy	14000.00
0005432529752	30579	Economy	14000.00
0005432529680	30579	Economy	14000.00
0005434068288	30579	Economy	14000.00
0005435214913	30579	Economy	14000.00
0005432529544	30579	Economy	14000.00
0005432159953	30579	Economy	14000.00
0005435214949	30579	Economy	14000.00
0005435214905	30579	Economy	14000.00
0005434068093	30579	Economy	14000.00
0005432529819	30579	Economy	14000.00
0005432529247	30579	Economy	14000.00
0005432529755	30579	Economy	14000.00
0005435214902	30579	Economy	14000.00
0005432530328	30579	Economy	14000.00
0005432529868	30579	Economy	14000.00
0005432533323	30579	Economy	14000.00
0005432529563	30579	Economy	14000.00
0005432529698	30579	Economy	14000.00
0005435214937	30579	Economy	14000.00
0005432530070	30579	Economy	14000.00
0005435214958	30579	Economy	14000.00
0005432529676	30579	Economy	14000.00
0005432529529	30579	Economy	14000.00
0005432529387	30579	Economy	14000.00
0005435214941	30579	Economy	14000.00
0005432529214	30579	Economy	14000.00
0005435214924	30579	Economy	14000.00
0005432529687	30579	Economy	14000.00
0005434068150	30579	Economy	14000.00
0005434067948	30579	Economy	14000.00
0005432529720	30579	Economy	14000.00
0005432529874	30579	Economy	14000.00
0005432529697	30579	Economy	14000.00
0005434068473	30579	Economy	14000.00
0005435214945	30579	Economy	14000.00
0005435214964	30579	Economy	14000.00
0005432529962	30579	Economy	14000.00
0005432529177	30579	Economy	14000.00
0005435214908	30579	Economy	14000.00
0005435725702	30579	Economy	14000.00
0005435214955	30579	Economy	14000.00
0005432529679	30579	Economy	14000.00
0005434068170	30579	Economy	14000.00
0005435214963	30579	Economy	14000.00
0005432529283	30579	Economy	14000.00
0005432529683	30579	Economy	14000.00
0005432529226	30579	Economy	14000.00
0005435214936	30579	Economy	14000.00
0005432529795	30579	Economy	14000.00
0005435214952	30579	Economy	14000.00
0005434068452	30579	Economy	14000.00
0005432529434	30579	Economy	14000.00
0005432529727	30579	Economy	14000.00
0005434068365	30579	Economy	14000.00
0005432535878	30579	Economy	14000.00
0005432529140	30579	Economy	14000.00
0005432529719	30579	Economy	14000.00
0005432529500	30579	Economy	14000.00
0005435214916	30579	Economy	14000.00
0005432529765	30579	Economy	14000.00
0005435214934	30579	Economy	14000.00
0005432529941	30579	Economy	14000.00
0005432530086	30579	Economy	14000.00
0005434067954	30579	Economy	14000.00
0005434068184	30579	Economy	14000.00
0005432528857	30579	Economy	14000.00
0005432529229	30579	Economy	14000.00
0005432533328	30579	Economy	14000.00
0005432529639	30579	Economy	14000.00
0005432159952	30579	Economy	14000.00
0005435214953	30579	Economy	14000.00
0005432529484	30579	Economy	14000.00
0005435214920	30579	Economy	14000.00
0005435214923	30579	Economy	14000.00
0005434068311	30579	Economy	14000.00
0005435214914	30579	Economy	14000.00
0005432529225	30579	Economy	14000.00
0005435214899	30579	Economy	14000.00
0005432529579	30579	Economy	14000.00
0005432537092	30579	Economy	15400.00
0005432529928	30579	Economy	15400.00
0005432529613	30579	Economy	15400.00
0005432528990	30579	Economy	15400.00
0005432529258	30579	Economy	14000.00
0005432528955	30579	Economy	15400.00
0005435214910	30579	Economy	14000.00
0005432529764	30579	Economy	14000.00
0005432529492	30579	Economy	14000.00
0005432529785	30579	Economy	14000.00
0005434068447	30579	Economy	14000.00
0005435214951	30579	Economy	14000.00
0005434068265	30579	Economy	14000.00
0005432529299	30579	Economy	14000.00
0005434068151	30579	Economy	14000.00
0005435214907	30579	Economy	14000.00
0005432211656	30579	Economy	14000.00
0005434068442	30579	Economy	14000.00
0005435214957	30579	Economy	14000.00
0005432529816	30579	Economy	14000.00
0005432529794	30579	Economy	14000.00
0005434068407	30579	Economy	14000.00
0005435214929	30579	Economy	14000.00
0005434068421	30579	Economy	14000.00
0005432529807	30579	Economy	14000.00
0005432529455	30579	Economy	14000.00
0005432528863	30579	Economy	14000.00
0005434068474	30579	Economy	14000.00
0005432529942	30579	Economy	14000.00
0005432529834	30579	Economy	14000.00
0005432529228	30579	Economy	14000.00
0005432528865	30579	Economy	14000.00
0005434067961	30579	Economy	14000.00
0005432529212	30579	Economy	14000.00
0005432529414	30579	Economy	14000.00
0005434068488	30579	Economy	14000.00
0005433656742	30579	Economy	14000.00
0005432530164	30579	Economy	14000.00
0005433656743	30579	Economy	14000.00
0005432533322	30579	Economy	14000.00
0005435214906	30579	Economy	14000.00
0005432529251	30579	Economy	14000.00
0005432535895	30579	Economy	14000.00
0005435214926	30579	Economy	14000.00
0005432529869	30579	Economy	14000.00
0005432529413	30579	Economy	14000.00
0005435214911	30579	Economy	14000.00
0005432529793	30579	Economy	14000.00
0005434068012	30579	Economy	14000.00
0005434068260	30579	Economy	14000.00
0005434068541	30579	Economy	14000.00
0005432529614	30579	Economy	14000.00
0005432529828	30579	Economy	14000.00
0005435214943	30579	Economy	14000.00
0005435214909	30579	Economy	14000.00
0005434068444	30579	Economy	14000.00
0005434068575	30579	Economy	14000.00
0005432535889	30579	Economy	14000.00
0005432535894	30579	Economy	14000.00
0005432529423	30579	Economy	14000.00
0005432528954	30579	Economy	14000.00
0005433656739	30579	Economy	14000.00
0005435214930	30579	Economy	14000.00
0005434068149	30579	Economy	14000.00
0005434067949	30579	Economy	14000.00
0005435214954	30579	Economy	14000.00
0005432211655	30579	Economy	14000.00
0005432529056	30579	Economy	14000.00
0005432528866	30579	Economy	14000.00
0005434068305	30579	Economy	14000.00
0005432529410	30579	Economy	14000.00
0005435631031	30579	Economy	14000.00
0005434068655	30579	Economy	14000.00
0005432529014	30579	Economy	14000.00
0005432535879	30579	Economy	14000.00
0005432529310	30579	Economy	14000.00
0005434068261	30579	Economy	14000.00
0005435214960	30579	Economy	14000.00
0005432211653	30579	Economy	14000.00
0005434068384	30579	Economy	14000.00
0005432529191	30579	Economy	14000.00
0005432529612	30579	Economy	14000.00
0005432529596	30579	Economy	14000.00
0005434068002	30579	Economy	14000.00
0005435214904	30579	Economy	14000.00
0005432529655	30579	Economy	14000.00
0005432529489	30579	Economy	14000.00
0005432529634	30579	Economy	14000.00
0005434068296	30579	Economy	14000.00
0005432529751	30579	Economy	14000.00
0005434068453	30579	Economy	14000.00
0005432529656	30579	Economy	14000.00
0005434068264	30579	Economy	14000.00
0005435214935	30579	Economy	14000.00
0005432159950	30579	Economy	14000.00
0005434068217	30579	Economy	14000.00
0005432529424	30579	Economy	14000.00
0005435214903	30579	Economy	14000.00
0005434068538	30579	Economy	14000.00
0005432529536	30579	Economy	14000.00
0005435214912	30579	Economy	14000.00
0005435214950	30579	Economy	14000.00
0005432529845	30579	Economy	14000.00
0005432529458	30579	Economy	14000.00
0005435214944	30579	Economy	14000.00
0005435214901	30579	Economy	14000.00
0005432529250	30579	Economy	14000.00
0005432211652	30579	Economy	14000.00
0005432529311	30579	Economy	14000.00
0005432529809	30579	Economy	14000.00
0005434068127	30579	Economy	14000.00
0005435653510	24862	Business	9800.00
0005435653465	24862	Business	9800.00
0005435653406	24862	Business	9800.00
0005433368643	24862	Business	9800.00
0005433368650	24862	Business	9800.00
0005433368639	24862	Business	9800.00
0005435653385	24862	Business	9800.00
0005435653430	24862	Business	9800.00
0005433368651	24862	Business	9800.00
0005435653536	24862	Business	9800.00
0005433368668	24862	Business	9800.00
0005435653371	24862	Economy	3300.00
0005433368670	24862	Economy	3300.00
0005433368672	24862	Economy	3300.00
0005433368676	24862	Economy	3300.00
0005433368652	24862	Economy	3300.00
0005433368669	24862	Economy	3300.00
0005433368649	24862	Economy	3300.00
0005433368644	24862	Economy	3300.00
0005433368657	24862	Economy	3600.00
0005435653508	24862	Economy	3600.00
0005433368665	24862	Economy	3600.00
0005435653527	24862	Economy	3600.00
0005435653261	24862	Economy	3600.00
0005435653525	24862	Economy	3300.00
0005433368646	24862	Economy	3300.00
0005433368653	24862	Economy	3300.00
0005435653469	24862	Economy	3300.00
0005435653435	24862	Economy	3300.00
0005433368667	24862	Economy	3300.00
0005435653242	24862	Economy	3300.00
0005435653408	24862	Economy	3300.00
0005435653297	24862	Economy	3300.00
0005433368677	24862	Economy	3300.00
0005433368645	24862	Economy	3300.00
0005433368656	24862	Economy	3300.00
0005433368654	24862	Economy	3300.00
0005433368662	24862	Economy	3300.00
0005435653378	24862	Economy	3300.00
0005433368673	24862	Economy	3300.00
0005435653434	24862	Economy	3300.00
0005433368658	24862	Economy	3300.00
0005433368663	24862	Economy	3300.00
0005433368660	24862	Economy	3300.00
0005435653509	24862	Economy	3300.00
0005435653512	24862	Economy	3300.00
0005433368640	24862	Economy	3300.00
0005435653379	24862	Economy	3300.00
0005435653526	24862	Economy	3300.00
0005435653561	24862	Economy	3300.00
0005435653507	24862	Economy	3300.00
0005433368674	24862	Economy	3300.00
0005433368642	24862	Economy	3300.00
0005433368655	24862	Economy	3300.00
0005435653502	24862	Economy	3300.00
0005435653387	24862	Economy	3300.00
0005435653511	24862	Economy	3300.00
0005433368659	24862	Economy	3300.00
0005433368647	24862	Economy	3300.00
0005433368675	24862	Economy	3300.00
0005435653372	24862	Economy	3300.00
0005435653519	24862	Economy	3300.00
0005433368664	24862	Economy	3300.00
0005433368641	24862	Economy	3300.00
0005433368648	24862	Economy	3300.00
0005435653471	24862	Economy	3300.00
0005433368666	24862	Economy	3300.00
0005433368671	24862	Economy	3300.00
0005435653405	24862	Economy	3300.00
0005435653407	24862	Economy	3300.00
0005435653370	24862	Economy	3300.00
0005435653516	24862	Economy	3300.00
0005435653544	24862	Economy	3300.00
0005435653348	24862	Economy	3300.00
0005435653447	24862	Economy	3300.00
0005435653560	24862	Economy	3300.00
0005435653573	24862	Economy	3300.00
0005435653470	24862	Economy	3300.00
0005433368661	24862	Economy	3300.00
0005435653538	24862	Economy	3300.00
0005435653537	24862	Economy	3300.00
0005434980391	2067	Economy	10500.00
0005434980396	2067	Economy	10500.00
0005434980416	2067	Economy	10500.00
0005434980415	2067	Economy	10500.00
0005434980420	2067	Economy	9500.00
0005434980399	2067	Economy	9500.00
0005434980405	2067	Economy	9500.00
0005434980400	2067	Economy	9500.00
0005434980407	2067	Economy	9500.00
0005434980404	2067	Economy	9500.00
0005434980398	2067	Economy	9500.00
0005434980411	2067	Economy	9500.00
0005434980413	2067	Economy	9500.00
0005434980395	2067	Economy	9500.00
0005435801758	2067	Economy	9500.00
0005434980393	2067	Economy	9500.00
0005434980414	2067	Economy	9500.00
0005434980417	2067	Economy	9500.00
0005434980397	2067	Economy	9500.00
0005434980392	2067	Economy	9500.00
0005434980409	2067	Economy	9500.00
0005435801757	2067	Economy	9500.00
0005434980394	2067	Economy	9500.00
0005434980412	2067	Economy	9500.00
0005434980419	2067	Economy	9500.00
0005435801759	2067	Economy	9500.00
0005434980410	2067	Economy	9500.00
0005434980408	2067	Economy	9500.00
0005434980401	2067	Economy	9500.00
0005434980402	2067	Economy	9500.00
0005434980403	2067	Economy	9500.00
0005434980418	2067	Economy	9500.00
0005434980406	2067	Economy	9500.00
0005434980036	23582	Economy	10500.00
0005434980034	23582	Economy	10500.00
0005434979974	23582	Economy	9500.00
0005434980172	23582	Economy	9500.00
0005434980070	23582	Economy	9500.00
0005434980068	23582	Economy	9500.00
0005434980100	23582	Economy	9500.00
0005434979955	23582	Economy	9500.00
0005434980228	23582	Economy	9500.00
0005434980098	23582	Economy	9500.00
0005434979972	23582	Economy	9500.00
0005434980229	23582	Economy	9500.00
0005434980123	23582	Economy	9500.00
0005434980227	23582	Economy	9500.00
0005435801739	23582	Economy	9500.00
0005434980072	23582	Economy	9500.00
0005434980007	23582	Economy	9500.00
0005434980128	23582	Economy	9500.00
0005434980113	23582	Economy	9500.00
0005434980033	23582	Economy	9500.00
0005434980150	23582	Economy	9500.00
0005434980053	23582	Economy	9500.00
0005434980073	23582	Economy	9500.00
0005434980063	23582	Economy	9500.00
0005434980077	23582	Economy	9500.00
0005435801719	23582	Economy	9500.00
0005434979973	23582	Economy	9500.00
0005434980035	23582	Economy	9500.00
0005434980097	23582	Economy	9500.00
0005434980102	23582	Economy	9500.00
0005434980232	23582	Economy	9500.00
0005434980124	23582	Economy	9500.00
0005434980192	23582	Economy	9500.00
0005434980052	23582	Economy	9500.00
0005434980101	23582	Economy	9500.00
0005434980189	23582	Economy	9500.00
0005434980120	23582	Economy	9500.00
0005435801723	23582	Economy	9500.00
0005434980010	23582	Economy	9500.00
0005434952609	2579	Economy	5300.00
0005434952607	2579	Economy	5300.00
0005434952606	2579	Economy	5300.00
0005434952608	2579	Economy	5300.00
0005433256450	2588	Economy	5300.00
0005433256467	28183	Economy	5300.00
0005434952583	28183	Economy	5300.00
0005433256471	28183	Economy	5300.00
0005433256469	28183	Economy	5300.00
0005433256468	28183	Economy	5300.00
0005434952576	28183	Economy	5300.00
0005434952582	28183	Economy	5300.00
0005433256470	28183	Economy	5300.00
0005433111552	19809	Economy	8700.00
0005433112408	19809	Economy	8700.00
0005433111551	19809	Economy	8700.00
0005433112409	19809	Economy	8700.00
0005433112411	19809	Economy	8700.00
0005433111553	19809	Economy	8700.00
0005434302873	19809	Economy	8700.00
0005433112410	19809	Economy	8700.00
0005434302874	19809	Economy	8700.00
0005433112373	20018	Economy	8700.00
0005433112377	20018	Economy	8700.00
0005433112380	20018	Economy	8700.00
0005433112376	20018	Economy	8700.00
0005433112387	20018	Economy	8700.00
0005433112371	20018	Economy	8700.00
0005433112374	20018	Economy	8700.00
0005433112383	20018	Economy	8700.00
0005433112378	20018	Economy	8700.00
0005433112379	20018	Economy	8700.00
0005433112382	20018	Economy	8700.00
0005433112381	20018	Economy	8700.00
0005434139069	11950	Business	9700.00
0005434139299	11950	Business	9700.00
0005434139035	11950	Business	9700.00
0005434139170	11950	Business	9700.00
0005434138999	11950	Business	9700.00
0005434139211	11950	Business	9700.00
0005434138765	11950	Business	9700.00
0005434139219	11950	Business	9700.00
0005434139243	11950	Business	9700.00
0005434139226	11950	Business	9700.00
0005434139314	11950	Business	9700.00
0005434138876	11950	Economy	3200.00
0005434139154	11950	Economy	3200.00
0005434139153	11950	Economy	3200.00
0005434138995	11950	Economy	3200.00
0005434139164	11950	Economy	3200.00
0005434138935	11950	Economy	3200.00
0005434138959	11950	Economy	3200.00
0005434139223	11950	Economy	3500.00
0005434139139	11950	Economy	3500.00
0005434139171	11950	Economy	3200.00
0005434138814	11950	Economy	3200.00
0005434139115	11950	Economy	3200.00
0005434139052	11950	Economy	3200.00
0005434139001	11950	Economy	3200.00
0005434139289	11950	Economy	3200.00
0005434139216	11950	Economy	3200.00
0005434139201	11950	Economy	3200.00
0005434139258	11950	Economy	3200.00
0005434138877	11950	Economy	3200.00
0005434139313	11950	Economy	3200.00
0005434139099	11950	Economy	3200.00
0005434138905	11950	Economy	3200.00
0005434139070	11950	Economy	3200.00
0005434139043	11950	Economy	3200.00
0005434139006	11950	Economy	3200.00
0005434139112	11950	Economy	3200.00
0005434138878	11950	Economy	3200.00
0005434139298	11950	Economy	3200.00
0005434138618	11950	Economy	3200.00
0005434139370	11950	Economy	3200.00
0005434139140	11950	Economy	3200.00
0005434139371	11950	Economy	3200.00
0005434139104	11950	Economy	3200.00
0005434139215	11950	Economy	3200.00
0005434139242	11950	Economy	3200.00
0005434138824	11950	Economy	3200.00
0005434138718	11950	Economy	3200.00
0005434138822	11950	Economy	3200.00
0005434139073	11950	Economy	3200.00
0005434139010	11950	Economy	3200.00
0005434139395	11950	Economy	3200.00
0005434139218	11950	Economy	3200.00
0005434139058	11950	Economy	3200.00
0005434139297	11950	Economy	3200.00
0005434139222	11950	Economy	3200.00
0005434139111	11950	Economy	3200.00
0005434138936	11950	Economy	3200.00
0005434139213	11950	Economy	3200.00
0005434139163	11950	Economy	3200.00
0005434139077	11950	Economy	3200.00
0005434138642	11950	Economy	3200.00
0005434138875	11950	Economy	3200.00
0005434139076	11950	Economy	3200.00
0005434139051	11950	Economy	3200.00
0005434138714	11950	Economy	3200.00
0005434139254	11950	Economy	3200.00
0005434139286	11950	Economy	3200.00
0005434139372	11950	Economy	3200.00
0005434139259	11950	Economy	3200.00
0005434139113	11950	Economy	3200.00
0005434138906	11950	Economy	3200.00
0005434139017	11950	Economy	3200.00
0005434139356	11950	Economy	3200.00
0005434139312	11950	Economy	3200.00
0005434138874	11950	Economy	3200.00
0005434138641	11950	Economy	3200.00
0005434139224	11950	Economy	3200.00
0005434138899	11950	Economy	3200.00
0005434139707	28764	Business	9700.00
0005434139750	28764	Business	9700.00
0005434139753	28764	Business	9700.00
0005434139725	28764	Business	9700.00
0005434139763	28764	Business	9700.00
0005434139769	28764	Business	9700.00
0005434139710	28764	Business	9700.00
0005434139768	28764	Business	9700.00
0005434139730	28764	Business	9700.00
0005434139701	28764	Business	9700.00
0005434139766	28764	Economy	3200.00
0005434139723	28764	Economy	3200.00
0005434139737	28764	Economy	3200.00
0005434139745	28764	Economy	3200.00
0005434139695	28764	Economy	3200.00
0005434139772	28764	Economy	3200.00
0005434139733	28764	Economy	3200.00
0005434139747	28764	Economy	3500.00
0005434139727	28764	Economy	3500.00
0005434139773	28764	Economy	3500.00
0005434139774	28764	Economy	3500.00
0005434139742	28764	Economy	3200.00
0005434139771	28764	Economy	3200.00
0005434139709	28764	Economy	3200.00
0005434139761	28764	Economy	3200.00
0005434139729	28764	Economy	3200.00
0005434139702	28764	Economy	3200.00
0005434139732	28764	Economy	3200.00
0005434139721	28764	Economy	3200.00
0005434139770	28764	Economy	3200.00
0005434139693	28764	Economy	3200.00
0005434139714	28764	Economy	3200.00
0005434139697	28764	Economy	3200.00
0005434139718	28764	Economy	3200.00
0005434139708	28764	Economy	3200.00
0005434139740	28764	Economy	3200.00
0005434139767	28764	Economy	3200.00
0005434139758	28764	Economy	3200.00
0005434139760	28764	Economy	3200.00
0005434139705	28764	Economy	3200.00
0005434139752	28764	Economy	3200.00
0005434139716	28764	Economy	3200.00
0005434139754	28764	Economy	3200.00
0005434139749	28764	Economy	3200.00
0005434139738	28764	Economy	3200.00
0005434139757	28764	Economy	3200.00
0005434139762	28764	Economy	3200.00
0005434139739	28764	Economy	3200.00
0005434139704	28764	Economy	3200.00
0005434139765	28764	Economy	3200.00
0005434139726	28764	Economy	3200.00
0005434139717	28764	Economy	3200.00
0005434139703	28764	Economy	3200.00
0005434139706	28764	Economy	3200.00
0005434139735	28764	Economy	3200.00
0005434139748	28764	Economy	3200.00
0005434139756	28764	Economy	3200.00
0005434139719	28764	Economy	3200.00
0005434139744	28764	Economy	3200.00
0005434139746	28764	Economy	3200.00
0005434139715	28764	Economy	3200.00
0005434139713	28764	Economy	3200.00
0005434139711	28764	Economy	3200.00
0005434139724	28764	Economy	3200.00
0005434139751	28764	Economy	3200.00
0005434139731	28764	Economy	3200.00
0005434139722	28764	Economy	3200.00
0005434139698	28764	Economy	3200.00
0005434139700	28764	Economy	3200.00
0005434139694	28764	Economy	3200.00
0005434139755	28764	Economy	3200.00
0005434139720	28764	Economy	3200.00
0005434139699	28764	Economy	3200.00
0005434139743	28764	Economy	3200.00
0005434139734	28764	Economy	3200.00
0005434139728	28764	Economy	3200.00
0005434139712	28764	Economy	3200.00
0005434139696	28764	Economy	3200.00
0005434139764	28764	Economy	3200.00
0005434139741	28764	Economy	3200.00
0005434139736	28764	Economy	3200.00
0005434139692	28764	Economy	3200.00
0005434139759	28764	Economy	3200.00
0005434466549	6586	Economy	23000.00
0005435312831	6586	Economy	23000.00
0005434466555	6586	Economy	20900.00
0005435312832	6586	Economy	20900.00
0005435312841	6586	Economy	20900.00
0005434466558	6586	Economy	20900.00
0005434466557	6586	Economy	20900.00
0005435312838	6586	Economy	20900.00
0005435312818	6586	Economy	20900.00
0005434466553	6586	Economy	20900.00
0005434466551	6586	Economy	20900.00
0005434466556	6586	Economy	20900.00
0005434466563	6586	Economy	20900.00
0005435312821	6586	Economy	20900.00
0005434466550	6586	Economy	20900.00
0005434466560	6586	Economy	20900.00
0005435312837	6586	Economy	20900.00
0005434466562	6586	Economy	20900.00
0005435312833	6586	Economy	20900.00
0005435312840	6586	Economy	20900.00
0005434466561	6586	Economy	20900.00
0005434466554	6586	Economy	20900.00
0005435312824	6586	Economy	20900.00
0005434466559	6586	Economy	20900.00
0005435312839	6586	Economy	20900.00
0005434466552	6586	Economy	20900.00
0005433539045	6788	Economy	10900.00
0005433534542	6788	Economy	10900.00
0005433539044	6788	Economy	9900.00
0005433539046	6788	Economy	9900.00
0005433539048	6788	Economy	9900.00
0005433534541	6788	Economy	9900.00
0005435259819	6788	Economy	9900.00
0005435259815	6788	Economy	9900.00
0005433539047	6788	Economy	9900.00
0005433539050	6788	Economy	9900.00
0005435259820	6788	Economy	9900.00
0005433539043	6788	Economy	9900.00
0005433539049	6788	Economy	9900.00
0005433534543	6788	Economy	9900.00
0005435259816	6788	Economy	9900.00
0005433538969	25042	Economy	10900.00
0005433538960	25042	Economy	9900.00
0005435259848	25042	Economy	9900.00
0005433538973	25042	Economy	9900.00
0005435259847	25042	Economy	9900.00
0005435259845	25042	Economy	9900.00
0005433538964	25042	Economy	9900.00
0005433538975	25042	Economy	9900.00
0005433534521	25042	Economy	9900.00
0005435259846	25042	Economy	9900.00
0005433538959	25042	Economy	9900.00
0005433534520	25042	Economy	9900.00
0005433538966	25042	Economy	9900.00
0005433538987	25042	Economy	9900.00
0005433538945	25042	Economy	9900.00
0005433538943	25042	Economy	9900.00
0005433538946	25042	Economy	9900.00
0005433538944	25042	Economy	9900.00
0005435259849	25042	Economy	9900.00
0005433538965	25042	Economy	9900.00
0005433512126	844	Economy	14600.00
0005433512120	844	Economy	14600.00
0005433512123	844	Economy	14600.00
0005433512121	844	Economy	14600.00
0005433512124	844	Economy	14600.00
0005433512129	844	Economy	14600.00
0005433512122	844	Economy	14600.00
0005432922584	844	Economy	14600.00
0005433512130	844	Economy	14600.00
0005432922583	844	Economy	14600.00
0005433512127	844	Economy	14600.00
0005433512125	844	Economy	14600.00
0005433512128	844	Economy	14600.00
0005433512090	16127	Economy	16100.00
0005432922609	16127	Economy	14600.00
0005433512040	16127	Economy	14600.00
0005433512061	16127	Economy	14600.00
0005432922610	16127	Economy	14600.00
0005433512051	16127	Economy	14600.00
0005432922607	16127	Economy	14600.00
0005433512093	16127	Economy	14600.00
0005433512094	16127	Economy	14600.00
0005433512027	16127	Economy	14600.00
0005433512042	16127	Economy	14600.00
0005432922608	16127	Economy	14600.00
0005433512049	16127	Economy	14600.00
0005433475795	4029	Economy	13500.00
0005435852609	4029	Economy	13500.00
0005433475796	4029	Economy	12300.00
0005433475792	4029	Economy	12300.00
0005435852600	4029	Economy	12300.00
0005433475797	4029	Economy	12300.00
0005435852617	4029	Economy	12300.00
0005433475790	4029	Economy	12300.00
0005433475793	4029	Economy	12300.00
0005433475791	4029	Economy	12300.00
0005433475794	4029	Economy	12300.00
0005433475798	4029	Economy	12300.00
0005435852610	4029	Economy	12300.00
0005435935071	3693	Economy	7900.00
0005435697926	3693	Economy	7900.00
0005435697924	3693	Economy	7900.00
0005435697920	3693	Economy	7200.00
0005435916204	3693	Economy	7200.00
0005435935073	3693	Economy	7200.00
0005434950623	3693	Economy	7200.00
0005435697923	3693	Economy	7200.00
0005435916208	3693	Economy	7200.00
0005435697928	3693	Economy	7200.00
0005435697922	3693	Economy	7200.00
0005435697914	3693	Economy	7200.00
0005435916195	3693	Economy	7200.00
0005435697927	3693	Economy	7200.00
0005435697917	3693	Economy	7200.00
0005435916193	3693	Economy	7200.00
0005435935098	3693	Economy	7200.00
0005435697921	3693	Economy	7200.00
0005435697933	3693	Economy	7200.00
0005435916202	3693	Economy	7200.00
0005435916194	3693	Economy	7200.00
0005435935084	3693	Economy	7200.00
0005435697915	3693	Economy	7200.00
0005435697932	3693	Economy	7200.00
0005435697913	3693	Economy	7200.00
0005435697934	3693	Economy	7200.00
0005435697908	3693	Economy	7200.00
0005435697931	3693	Economy	7200.00
0005435697929	3693	Economy	7200.00
0005434950620	3693	Economy	7200.00
0005435916205	3693	Economy	7200.00
0005435697918	3693	Economy	7200.00
0005435697911	3693	Economy	7200.00
0005434950624	3693	Economy	7200.00
0005435697912	3693	Economy	7200.00
0005435697909	3693	Economy	7200.00
0005435697930	3693	Economy	7200.00
0005434950621	3693	Economy	7200.00
0005435697916	3693	Economy	7200.00
0005434950622	3693	Economy	7200.00
0005435697925	3693	Economy	7200.00
0005435697910	3693	Economy	7200.00
0005435697919	3693	Economy	7200.00
0005435697633	16307	Economy	7900.00
0005435697624	16307	Economy	7900.00
0005435697662	16307	Economy	7900.00
0005435697510	16307	Economy	7200.00
0005435697672	16307	Economy	7200.00
0005435916224	16307	Economy	7200.00
0005435697578	16307	Economy	7200.00
0005435697664	16307	Economy	7200.00
0005435697577	16307	Economy	7200.00
0005435697692	16307	Economy	7200.00
0005435935105	16307	Economy	7200.00
0005435697663	16307	Economy	7200.00
0005435916225	16307	Economy	7200.00
0005435697566	16307	Economy	7200.00
0005435697509	16307	Economy	7200.00
0005435697725	16307	Economy	7200.00
0005435697693	16307	Economy	7200.00
0005435697661	16307	Economy	7200.00
0005434950587	16307	Economy	7200.00
0005435697721	16307	Economy	7200.00
0005435697654	16307	Economy	7200.00
0005435935103	16307	Economy	7200.00
0005435697720	16307	Economy	7200.00
0005435697686	16307	Economy	7200.00
0005435697655	16307	Economy	7200.00
0005434950589	16307	Economy	7200.00
0005435697711	16307	Economy	7200.00
0005435697687	16307	Economy	7200.00
0005435697743	16307	Economy	7200.00
0005435697665	16307	Economy	7200.00
0005435697677	16307	Economy	7200.00
0005435697638	16307	Economy	7200.00
0005434950600	16307	Economy	7200.00
0005435697637	16307	Economy	7200.00
0005435935104	16307	Economy	7200.00
0005435697656	16307	Economy	7200.00
0005435697744	16307	Economy	7200.00
0005434950590	16307	Economy	7200.00
0005434950586	16307	Economy	7200.00
0005435697681	16307	Economy	7200.00
0005435697498	16307	Economy	7200.00
0005434950571	16307	Economy	7200.00
0005434604973	3956	Economy	21300.00
0005434606898	3956	Economy	21300.00
0005432609816	3956	Economy	19300.00
0005432607652	3956	Economy	19300.00
0005434606896	3956	Economy	19300.00
0005433519550	3956	Economy	19300.00
0005433519553	3956	Economy	19300.00
0005432609814	3956	Economy	19300.00
0005435853636	3956	Economy	19300.00
0005434606897	3956	Economy	19300.00
0005432607651	3956	Economy	19300.00
0005432609817	3956	Economy	19300.00
0005435904900	3956	Economy	19300.00
0005432609815	3956	Economy	19300.00
0005435841479	3956	Economy	19300.00
0005435904901	3956	Economy	19300.00
0005434604972	3956	Economy	19300.00
0005435853629	3956	Economy	19300.00
0005433519551	3956	Economy	19300.00
0005435904902	3956	Economy	19300.00
0005435842332	3956	Economy	19300.00
0005432609818	3956	Economy	19300.00
0005434606895	3956	Economy	19300.00
0005435904903	3956	Economy	19300.00
0005433519552	3956	Economy	19300.00
0005433519554	3956	Economy	19300.00
0005435842333	3956	Economy	19300.00
0005432607650	3956	Economy	19300.00
0005434606870	22073	Economy	19300.00
0005435853648	22073	Economy	19300.00
0005435853649	22073	Economy	19300.00
0005434606864	22073	Economy	19300.00
0005433519528	22073	Economy	19300.00
0005433519529	22073	Economy	19300.00
0005433519514	22073	Economy	19300.00
0005434606865	22073	Economy	19300.00
0005434606871	22073	Economy	19300.00
0005433519515	22073	Economy	19300.00
0005433519527	22073	Economy	19300.00
0005433349071	715	Economy	3700.00
0005435628797	715	Economy	3700.00
0005435628799	715	Economy	3700.00
0005435628798	715	Economy	3700.00
0005433349072	715	Economy	3700.00
0005433349054	715	Economy	3700.00
0005433349046	715	Economy	3700.00
0005435628761	15925	Economy	3700.00
0005435628754	15925	Economy	3700.00
0005433349107	15925	Economy	3700.00
0005433349108	15925	Economy	3700.00
0005433349109	15925	Economy	3700.00
0005433349110	15925	Economy	3700.00
0005433349112	15925	Economy	3700.00
0005435628755	15925	Economy	3700.00
0005435628767	15925	Economy	3700.00
0005433349111	15925	Economy	3700.00
0005434445292	17218	Economy	7100.00
0005434446565	17218	Economy	7100.00
0005434446564	17218	Economy	7100.00
0005434446563	17218	Economy	7100.00
0005434446562	17218	Economy	7100.00
0005434445293	17218	Economy	7100.00
0005434446566	17218	Economy	7100.00
0005434445290	17218	Economy	7100.00
0005433158150	17218	Economy	7100.00
0005434445291	17218	Economy	7100.00
0005433159360	17569	Economy	7100.00
0005433159361	17569	Economy	7100.00
0005433159359	17569	Economy	7100.00
0005435133105	7873	Economy	5900.00
0005435133095	7873	Economy	5400.00
0005435133102	7873	Economy	5400.00
0005435133100	7873	Economy	5400.00
0005435133096	7873	Economy	5400.00
0005435133104	7873	Economy	5400.00
0005435133099	7873	Economy	5400.00
0005435133103	7873	Economy	5400.00
0005435133098	7873	Economy	5400.00
0005435133097	7873	Economy	5400.00
0005435133101	7873	Economy	5400.00
0005435133010	33094	Economy	5900.00
0005435133023	33094	Economy	5900.00
0005435132989	33094	Economy	5400.00
0005435383262	33094	Economy	5400.00
0005435383259	33094	Economy	5400.00
0005435133015	33094	Economy	5400.00
0005435133056	33094	Economy	5400.00
0005435132991	33094	Economy	5400.00
0005435383260	33094	Economy	5400.00
0005435132990	33094	Economy	5400.00
0005435383264	33094	Economy	5400.00
0005435383263	33094	Economy	5400.00
0005435383261	33094	Economy	5400.00
0005435160537	7480	Economy	13800.00
0005435160528	7480	Economy	13800.00
0005435390344	7480	Economy	12500.00
0005435160532	7480	Economy	12500.00
0005435160535	7480	Economy	12500.00
0005435160529	7480	Economy	12500.00
0005435390331	7480	Economy	12500.00
0005435160531	7480	Economy	12500.00
0005435390300	7480	Economy	12500.00
0005435390322	7480	Economy	12500.00
0005435160533	7480	Economy	12500.00
0005435160538	7480	Economy	12500.00
0005435160534	7480	Economy	12500.00
0005435160536	7480	Economy	12500.00
0005435160527	7480	Economy	12500.00
0005435160539	7480	Economy	12500.00
0005435160530	7480	Economy	12500.00
0005435390382	29549	Economy	13800.00
0005435160438	29549	Economy	13800.00
0005435390386	29549	Economy	12500.00
0005435390385	29549	Economy	12500.00
0005435160437	29549	Economy	12500.00
0005435160471	29549	Economy	12500.00
0005435160403	29549	Economy	12500.00
0005435390381	29549	Economy	12500.00
0005435160461	29549	Economy	12500.00
0005435160444	29549	Economy	12500.00
0005435390384	29549	Economy	12500.00
0005435160389	29549	Economy	12500.00
0005435160439	29549	Economy	12500.00
0005435160457	29549	Economy	12500.00
0005435160398	29549	Economy	12500.00
0005435390383	29549	Economy	12500.00
0005435160456	29549	Economy	12500.00
0005432398253	18470	Economy	4900.00
0005432394163	18470	Economy	4900.00
0005435178527	18470	Economy	4900.00
0005432398255	18470	Economy	4900.00
0005432394157	18470	Economy	4900.00
0005432394132	18470	Economy	4900.00
0005432394142	18470	Economy	4900.00
0005432394139	18470	Economy	4900.00
0005432394140	18470	Economy	4900.00
0005432394149	18470	Economy	4900.00
0005432394164	18470	Economy	4900.00
0005432398252	18470	Economy	4900.00
0005432398269	27129	Economy	4900.00
0005432400199	27129	Economy	4900.00
0005432400197	27129	Economy	4900.00
0005435178514	27129	Economy	4900.00
0005432398271	27129	Economy	4900.00
0005432400198	27129	Economy	4900.00
0005432398270	27129	Economy	4900.00
0005432398268	27129	Economy	4900.00
0005435178511	27129	Economy	4900.00
0005432400200	27129	Economy	4900.00
0005432639375	2241	Business	87300.00
0005432639372	2241	Business	87300.00
0005432639369	2241	Business	87300.00
0005432866076	2241	Business	87300.00
0005432639387	2241	Business	87300.00
0005432639381	2241	Business	87300.00
0005432639384	2241	Business	87300.00
0005432866112	2241	Economy	29100.00
0005432639385	2241	Economy	29100.00
0005432639364	2241	Economy	29100.00
0005432639389	2241	Economy	32000.00
0005432639371	2241	Economy	32000.00
0005432639379	2241	Economy	29100.00
0005432639376	2241	Economy	29100.00
0005432639396	2241	Economy	29100.00
0005432866096	2241	Economy	29100.00
0005432866087	2241	Economy	29100.00
0005432639394	2241	Economy	29100.00
0005432639362	2241	Economy	29100.00
0005432639363	2241	Economy	29100.00
0005432639391	2241	Economy	29100.00
0005432866120	2241	Economy	29100.00
0005432866077	2241	Economy	29100.00
0005432639368	2241	Economy	29100.00
0005432639386	2241	Economy	29100.00
0005432639395	2241	Economy	29100.00
0005432866099	2241	Economy	29100.00
0005432639367	2241	Economy	29100.00
0005432639360	2241	Economy	29100.00
0005432639380	2241	Economy	29100.00
0005432639393	2241	Economy	29100.00
0005432866105	2241	Economy	29100.00
0005432866100	2241	Economy	29100.00
0005432639365	2241	Economy	29100.00
0005432639382	2241	Economy	29100.00
0005432639390	2241	Economy	29100.00
0005432639373	2241	Economy	29100.00
0005432639366	2241	Economy	29100.00
0005432866082	2241	Economy	29100.00
0005432639383	2241	Economy	29100.00
0005432639392	2241	Economy	29100.00
0005432639388	2241	Economy	29100.00
0005432639370	2241	Economy	29100.00
0005432866086	2241	Economy	29100.00
0005432639361	2241	Economy	29100.00
0005432639374	2241	Economy	29100.00
0005432639377	2241	Economy	29100.00
0005432639397	2241	Economy	29100.00
0005432639378	2241	Economy	29100.00
0005432866063	2241	Economy	29100.00
0005434552880	9779	Economy	4400.00
0005434552877	9779	Economy	4400.00
0005434552878	9779	Economy	4400.00
0005434552875	9779	Economy	4400.00
0005434552876	9779	Economy	4400.00
0005434552879	9779	Economy	4400.00
0005434552881	9779	Economy	4400.00
0005435104109	6530	Business	48400.00
0005435104115	6530	Business	48400.00
0005434504965	6530	Business	48400.00
0005435104113	6530	Business	48400.00
0005435104118	6530	Business	48400.00
0005434504981	6530	Business	48400.00
0005434504975	6530	Business	48400.00
0005434504949	6530	Business	48400.00
0005434504967	6530	Business	48400.00
0005434504950	6530	Economy	16100.00
0005434504961	6530	Economy	16100.00
0005434504953	6530	Economy	16100.00
0005434504985	6530	Economy	16100.00
0005434504964	6530	Economy	16100.00
0005434504957	6530	Economy	17800.00
0005435104114	6530	Economy	17800.00
0005434504952	6530	Economy	17800.00
0005435104122	6530	Economy	17800.00
0005434504974	6530	Economy	16100.00
0005434504954	6530	Economy	16100.00
0005434504988	6530	Economy	16100.00
0005434504956	6530	Economy	16100.00
0005434504970	6530	Economy	16100.00
0005434504969	6530	Economy	16100.00
0005434504959	6530	Economy	16100.00
0005435104108	6530	Economy	16100.00
0005435104119	6530	Economy	16100.00
0005434504966	6530	Economy	16100.00
0005434504955	6530	Economy	16100.00
0005434504968	6530	Economy	16100.00
0005435104120	6530	Economy	16100.00
0005434504962	6530	Economy	16100.00
0005435104121	6530	Economy	16100.00
0005434504983	6530	Economy	16100.00
0005434504958	6530	Economy	16100.00
0005435104124	6530	Economy	16100.00
0005434504960	6530	Economy	16100.00
0005434504951	6530	Economy	16100.00
0005434504979	6530	Economy	16100.00
0005434504982	6530	Economy	16100.00
0005434504973	6530	Economy	16100.00
0005434504977	6530	Economy	16100.00
0005434504984	6530	Economy	16100.00
0005434504987	6530	Economy	16100.00
0005434504963	6530	Economy	16100.00
0005434504976	6530	Economy	16100.00
0005434504978	6530	Economy	16100.00
0005434504971	6530	Economy	16100.00
0005435104111	6530	Economy	16100.00
0005435104116	6530	Economy	16100.00
0005435104123	6530	Economy	16100.00
0005435104110	6530	Economy	16100.00
0005434504986	6530	Economy	16100.00
0005435104112	6530	Economy	16100.00
0005434504972	6530	Economy	16100.00
0005434504980	6530	Economy	16100.00
0005435104117	6530	Economy	16100.00
0005434504461	22641	Business	48400.00
0005434504394	22641	Business	48400.00
0005434504574	22641	Business	48400.00
0005434504393	22641	Business	48400.00
0005434504635	22641	Business	48400.00
0005434504514	22641	Business	48400.00
0005434504527	22641	Economy	16100.00
0005435103994	22641	Economy	16100.00
0005434504645	22641	Economy	16100.00
0005434504573	22641	Economy	16100.00
0005434504735	22641	Economy	16100.00
0005434504447	22641	Economy	16100.00
0005434504429	22641	Economy	17800.00
0005434504661	22641	Economy	17800.00
0005434504736	22641	Economy	17800.00
0005434504589	22641	Economy	16100.00
0005435103983	22641	Economy	16100.00
0005434504356	22641	Economy	16100.00
0005434504459	22641	Economy	16100.00
0005434504670	22641	Economy	16100.00
0005434504660	22641	Economy	16100.00
0005435104008	22641	Economy	16100.00
0005435104006	22641	Economy	16100.00
0005434504452	22641	Economy	16100.00
0005435103991	22641	Economy	16100.00
0005434504458	22641	Economy	16100.00
0005434504575	22641	Economy	16100.00
0005434504532	22641	Economy	16100.00
0005434504603	22641	Economy	16100.00
0005434504590	22641	Economy	16100.00
0005434504703	22641	Economy	16100.00
0005434504462	22641	Economy	16100.00
0005434504619	22641	Economy	16100.00
0005434504662	22641	Economy	16100.00
0005434504533	22641	Economy	16100.00
0005434504391	22641	Economy	16100.00
0005434504636	22641	Economy	16100.00
0005434504392	22641	Economy	16100.00
0005434504649	22641	Economy	16100.00
0005434504671	22641	Economy	16100.00
0005434504620	22641	Economy	16100.00
0005434504596	22641	Economy	16100.00
0005434504422	22641	Economy	16100.00
0005434504776	22641	Economy	16100.00
0005434504618	22641	Economy	16100.00
0005435104009	22641	Economy	16100.00
0005434504493	22641	Economy	16100.00
0005434504480	22641	Economy	16100.00
0005434504430	22641	Economy	16100.00
0005435800145	6420	Economy	16800.00
0005435800159	6420	Economy	15300.00
0005435800151	6420	Economy	15300.00
0005435800158	6420	Economy	15300.00
0005435800153	6420	Economy	15300.00
0005435800152	6420	Economy	15300.00
0005435800157	6420	Economy	15300.00
0005435800148	6420	Economy	15300.00
0005435800146	6420	Economy	15300.00
0005435800149	6420	Economy	15300.00
0005435800155	6420	Economy	15300.00
0005435800150	6420	Economy	15300.00
0005435800156	6420	Economy	15300.00
0005435800147	6420	Economy	15300.00
0005435800154	6420	Economy	15300.00
0005435800160	6420	Economy	15300.00
0005433368277	1662	Business	50000.00
0005435654005	1662	Business	50000.00
0005433368293	1662	Business	50000.00
0005435654001	1662	Business	50000.00
0005435653980	1662	Business	50000.00
0005435653976	1662	Business	50000.00
0005433368472	1662	Business	50000.00
0005435654007	1662	Business	50000.00
0005435653962	1662	Business	50000.00
0005435653983	1662	Business	50000.00
0005433368424	1662	Business	50000.00
0005435653987	1662	Economy	16700.00
0005435653970	1662	Economy	16700.00
0005435653998	1662	Economy	16700.00
0005435653975	1662	Economy	16700.00
0005435653995	1662	Economy	16700.00
0005433368269	1662	Economy	16700.00
0005433368345	1662	Economy	16700.00
0005433368250	1662	Economy	16700.00
0005433368350	1662	Economy	16700.00
0005435653974	1662	Economy	18300.00
0005433368335	1662	Economy	18300.00
0005435654004	1662	Economy	18300.00
0005433368249	1662	Economy	18300.00
0005435653965	1662	Economy	18300.00
0005433368336	1662	Economy	16700.00
0005433368331	1662	Economy	16700.00
0005433368225	1662	Economy	16700.00
0005433368496	1662	Economy	16700.00
0005433368459	1662	Economy	16700.00
0005433368341	1662	Economy	16700.00
0005433368226	1662	Economy	16700.00
0005433368136	1662	Economy	16700.00
0005433368220	1662	Economy	16700.00
0005433368286	1662	Economy	16700.00
0005435653981	1662	Economy	16700.00
0005435653985	1662	Economy	16700.00
0005435653964	1662	Economy	16700.00
0005435653971	1662	Economy	16700.00
0005435653960	1662	Economy	16700.00
0005435653989	1662	Economy	16700.00
0005433368506	1662	Economy	16700.00
0005435653961	1662	Economy	16700.00
0005435653979	1662	Economy	16700.00
0005435654006	1662	Economy	16700.00
0005435653966	1662	Economy	16700.00
0005435653992	1662	Economy	16700.00
0005435653990	1662	Economy	16700.00
0005435653993	1662	Economy	16700.00
0005433368311	1662	Economy	16700.00
0005435653996	1662	Economy	16700.00
0005433368141	1662	Economy	16700.00
0005435653977	1662	Economy	16700.00
0005435653969	1662	Economy	16700.00
0005435653991	1662	Economy	16700.00
0005435653963	1662	Economy	16700.00
0005433368410	1662	Economy	16700.00
0005433368268	1662	Economy	16700.00
0005435653967	1662	Economy	16700.00
0005435654002	1662	Economy	16700.00
0005433368292	1662	Economy	16700.00
0005433368333	1662	Economy	16700.00
0005435653988	1662	Economy	16700.00
0005433368232	1662	Economy	16700.00
0005435654000	1662	Economy	16700.00
0005433368357	1662	Economy	16700.00
0005435653972	1662	Economy	16700.00
0005433368548	1662	Economy	16700.00
0005435653999	1662	Economy	16700.00
0005433368307	1662	Economy	16700.00
0005433368253	1662	Economy	16700.00
0005433368296	1662	Economy	16700.00
0005435653982	1662	Economy	16700.00
0005435653986	1662	Economy	16700.00
0005435653978	1662	Economy	16700.00
0005433368135	1662	Economy	16700.00
0005435653973	1662	Economy	16700.00
0005435653997	1662	Economy	16700.00
0005433368287	1662	Economy	16700.00
0005435653994	1662	Economy	16700.00
0005433368242	1662	Economy	16700.00
0005433368340	1662	Economy	16700.00
0005433368330	1662	Economy	16700.00
0005433368354	1662	Economy	16700.00
0005435653984	1662	Economy	16700.00
0005433368342	1662	Economy	16700.00
0005435653968	1662	Economy	16700.00
0005435654003	1662	Economy	16700.00
0005433368674	21702	Business	50000.00
0005433368639	21702	Business	50000.00
0005433368664	21702	Business	50000.00
0005433368645	21702	Business	50000.00
0005433368660	21702	Business	50000.00
0005435653538	21702	Business	50000.00
0005433368654	21702	Business	50000.00
0005433368665	21702	Business	50000.00
0005435653544	21702	Business	50000.00
0005435653378	21702	Economy	16700.00
0005435653405	21702	Economy	16700.00
0005433368661	21702	Economy	16700.00
0005433368651	21702	Economy	16700.00
0005435653261	21702	Economy	16700.00
0005435653536	21702	Economy	16700.00
0005433368656	21702	Economy	16700.00
0005433368648	21702	Economy	16700.00
0005435653502	21702	Economy	16700.00
0005433368666	21702	Economy	18300.00
0005433368676	21702	Economy	18300.00
0005435653573	21702	Economy	18300.00
0005435653512	21702	Economy	18300.00
0005433368673	21702	Economy	18300.00
0005435653430	21702	Economy	16700.00
0005433368643	21702	Economy	16700.00
0005433368663	21702	Economy	16700.00
0005435653408	21702	Economy	16700.00
0005435653508	21702	Economy	16700.00
0005433368669	21702	Economy	16700.00
0005433368667	21702	Economy	16700.00
0005433368650	21702	Economy	16700.00
0005435653379	21702	Economy	16700.00
0005435653469	21702	Economy	16700.00
0005435653434	21702	Economy	16700.00
0005435653470	21702	Economy	16700.00
0005433368640	21702	Economy	16700.00
0005435653348	21702	Economy	16700.00
0005435653407	21702	Economy	16700.00
0005433368646	21702	Economy	16700.00
0005435653297	21702	Economy	16700.00
0005435653447	21702	Economy	16700.00
0005435653537	21702	Economy	16700.00
0005433368647	21702	Economy	16700.00
0005433368642	21702	Economy	16700.00
0005433368657	21702	Economy	16700.00
0005435653471	21702	Economy	16700.00
0005433368659	21702	Economy	16700.00
0005433368672	21702	Economy	16700.00
0005435653370	21702	Economy	16700.00
0005435653516	21702	Economy	16700.00
0005435653242	21702	Economy	16700.00
0005435653372	21702	Economy	16700.00
0005433368675	21702	Economy	16700.00
0005435653465	21702	Economy	16700.00
0005435653509	21702	Economy	16700.00
0005433368662	21702	Economy	16700.00
0005435653435	21702	Economy	16700.00
0005435653371	21702	Economy	16700.00
0005433368649	21702	Economy	16700.00
0005435653561	21702	Economy	16700.00
0005435653560	21702	Economy	16700.00
0005435653385	21702	Economy	16700.00
0005433368652	21702	Economy	16700.00
0005433368644	21702	Economy	16700.00
0005435653525	21702	Economy	16700.00
0005435653527	21702	Economy	16700.00
0005433368671	21702	Economy	16700.00
0005435653519	21702	Economy	16700.00
0005435653511	21702	Economy	16700.00
0005433368641	21702	Economy	16700.00
0005435653387	21702	Economy	16700.00
0005435653526	21702	Economy	16700.00
0005435653507	21702	Economy	16700.00
0005433368677	21702	Economy	16700.00
0005433368668	21702	Economy	16700.00
0005433368653	21702	Economy	16700.00
0005435653510	21702	Economy	16700.00
0005435653406	21702	Economy	16700.00
0005433368655	21702	Economy	16700.00
0005433368658	21702	Economy	16700.00
0005433368670	21702	Economy	16700.00
0005434466506	23236	Economy	23000.00
0005435312855	23236	Economy	23000.00
0005434466537	23236	Economy	20900.00
0005434466525	23236	Economy	20900.00
0005434466524	23236	Economy	20900.00
0005434466516	23236	Economy	20900.00
0005435312857	23236	Economy	20900.00
0005435312852	23236	Economy	20900.00
0005434466533	23236	Economy	20900.00
0005434466517	23236	Economy	20900.00
0005434466505	23236	Economy	20900.00
0005435312858	23236	Economy	20900.00
0005434466527	23236	Economy	20900.00
0005434466536	23236	Economy	20900.00
0005435312856	23236	Economy	20900.00
0005434466499	23236	Economy	20900.00
0005434466500	23236	Economy	20900.00
0005434466518	23236	Economy	20900.00
0005434466523	23236	Economy	20900.00
0005434466522	23236	Economy	20900.00
0005435312853	23236	Economy	20900.00
0005434466501	23236	Economy	20900.00
0005435312854	23236	Economy	20900.00
0005434466521	23236	Economy	20900.00
0005433986908	4193	Business	21500.00
0005433986920	4193	Business	21500.00
0005433986904	4193	Business	21500.00
0005433986912	4193	Business	21500.00
0005433986890	4193	Business	21500.00
0005435788825	4193	Business	21500.00
0005433986897	4193	Business	21500.00
0005433986887	4193	Business	21500.00
0005433986924	4193	Economy	7200.00
0005433986878	4193	Economy	7200.00
0005435788824	4193	Economy	7200.00
0005433986914	4193	Economy	7200.00
0005433986913	4193	Economy	7200.00
0005433986884	4193	Economy	7900.00
0005433986915	4193	Economy	7900.00
0005433986905	4193	Economy	7200.00
0005433986910	4193	Economy	7200.00
0005433986903	4193	Economy	7200.00
0005433986896	4193	Economy	7200.00
0005433986922	4193	Economy	7200.00
0005433986923	4193	Economy	7200.00
0005435788823	4193	Economy	7200.00
0005433986899	4193	Economy	7200.00
0005433986879	4193	Economy	7200.00
0005433986893	4193	Economy	7200.00
0005433986902	4193	Economy	7200.00
0005433986892	4193	Economy	7200.00
0005433986891	4193	Economy	7200.00
0005433986889	4193	Economy	7200.00
0005433986901	4193	Economy	7200.00
0005433986918	4193	Economy	7200.00
0005433986911	4193	Economy	7200.00
0005433986909	4193	Economy	7200.00
0005433986882	4193	Economy	7200.00
0005433986906	4193	Economy	7200.00
0005433986900	4193	Economy	7200.00
0005433986881	4193	Economy	7200.00
0005433986885	4193	Economy	7200.00
0005433986894	4193	Economy	7200.00
0005433986886	4193	Economy	7200.00
0005433986888	4193	Economy	7200.00
0005433986880	4193	Economy	7200.00
0005433986907	4193	Economy	7200.00
0005433986919	4193	Economy	7200.00
0005433986883	4193	Economy	7200.00
0005433986895	4193	Economy	7200.00
0005433986898	4193	Economy	7200.00
0005433986921	4193	Economy	7200.00
0005433986917	4193	Economy	7200.00
0005433986916	4193	Economy	7200.00
0005433986325	25650	Business	21500.00
0005433986433	25650	Business	21500.00
0005433986300	25650	Business	21500.00
0005435788809	25650	Business	21500.00
0005433986321	25650	Business	21500.00
0005433986520	25650	Business	21500.00
0005433986351	25650	Business	21500.00
0005433986458	25650	Business	21500.00
0005433986485	25650	Economy	7200.00
0005433986400	25650	Economy	7200.00
0005433986469	25650	Economy	7200.00
0005433986459	25650	Economy	7200.00
0005433986404	25650	Economy	7200.00
0005433986372	25650	Economy	7200.00
0005433986288	25650	Economy	7200.00
0005433986218	25650	Economy	7900.00
0005435788807	25650	Economy	7900.00
0005435788808	25650	Economy	7200.00
0005433986353	25650	Economy	7200.00
0005433986360	25650	Economy	7200.00
0005433986406	25650	Economy	7200.00
0005433986408	25650	Economy	7200.00
0005433986481	25650	Economy	7200.00
0005433986407	25650	Economy	7200.00
0005433986282	25650	Economy	7200.00
0005433986536	25650	Economy	7200.00
0005433986521	25650	Economy	7200.00
0005433986537	25650	Economy	7200.00
0005433986381	25650	Economy	7200.00
0005433986281	25650	Economy	7200.00
0005435788794	25650	Economy	7200.00
0005433986347	25650	Economy	7200.00
0005433986382	25650	Economy	7200.00
0005433986352	25650	Economy	7200.00
0005433986134	25650	Economy	7200.00
0005433986362	25650	Economy	7200.00
0005433986383	25650	Economy	7200.00
0005433986346	25650	Economy	7200.00
0005433986299	25650	Economy	7200.00
0005433986467	25650	Economy	7200.00
0005433986482	25650	Economy	7200.00
0005433986409	25650	Economy	7200.00
0005433986514	25650	Economy	7200.00
0005433986320	25650	Economy	7200.00
0005433986502	25650	Economy	7200.00
0005433986461	25650	Economy	7200.00
0005433986298	25650	Economy	7200.00
0005433986378	25650	Economy	7200.00
0005433986368	25650	Economy	7200.00
0005433986401	25650	Economy	7200.00
0005433986527	25650	Economy	7200.00
0005435720840	21245	Economy	9400.00
0005435720838	21245	Economy	9400.00
0005435719572	21245	Economy	9400.00
0005435720839	21245	Economy	9400.00
0005433168453	21327	Economy	17000.00
0005434509245	21327	Economy	17000.00
0005434509253	21327	Economy	17000.00
0005434509254	21327	Economy	17000.00
0005434509212	21327	Economy	15500.00
0005434509237	21327	Economy	15500.00
0005434509222	21327	Economy	15500.00
0005433168456	21327	Economy	15500.00
0005434509255	21327	Economy	15500.00
0005434509258	21327	Economy	15500.00
0005434509230	21327	Economy	15500.00
0005433168457	21327	Economy	15500.00
0005434509259	21327	Economy	15500.00
0005433168458	21327	Economy	15500.00
0005434509238	21327	Economy	15500.00
0005434509260	21327	Economy	15500.00
0005433168455	21327	Economy	15500.00
0005433168459	21327	Economy	15500.00
0005434509236	21327	Economy	15500.00
0005433168460	21327	Economy	15500.00
0005433168454	21327	Economy	15500.00
0005434509243	21327	Economy	15500.00
0005434509235	21327	Economy	15500.00
0005432657491	17844	Business	18000.00
0005432655669	17844	Business	18000.00
0005432655698	17844	Business	18000.00
0005432665297	17844	Business	18000.00
0005432869663	17844	Business	18000.00
0005432655691	17844	Business	18000.00
0005432667472	17844	Business	18000.00
0005432655716	17844	Business	18000.00
0005432655695	17844	Economy	6000.00
0005432665296	17844	Economy	6000.00
0005434151766	17844	Economy	6000.00
0005432658628	17844	Economy	6600.00
0005432658617	17844	Economy	6600.00
0005432660841	17844	Economy	6600.00
0005432869665	17844	Economy	6000.00
0005432655692	17844	Economy	6000.00
0005432655660	17844	Economy	6000.00
0005434151767	17844	Economy	6000.00
0005432655690	17844	Economy	6000.00
0005432655668	17844	Economy	6000.00
0005432869664	17844	Economy	6000.00
0005432667471	17844	Economy	6000.00
0005432663054	17844	Economy	6000.00
0005432663052	17844	Economy	6000.00
0005432655727	17844	Economy	6000.00
0005432661953	17844	Economy	6000.00
0005432655689	17844	Economy	6000.00
0005432869666	17844	Economy	6000.00
0005432869667	17844	Economy	6000.00
0005432665288	17844	Economy	6000.00
0005432655645	17844	Economy	6000.00
0005432655646	17844	Economy	6000.00
0005432660839	17844	Economy	6000.00
0005432655688	17844	Economy	6000.00
0005432655694	17844	Economy	6000.00
0005432655693	17844	Economy	6000.00
0005432660840	17844	Economy	6000.00
0005432661946	17844	Economy	6000.00
0005432658616	17844	Economy	6000.00
0005432655697	17844	Economy	6000.00
0005432655696	17844	Economy	6000.00
0005432667480	17844	Economy	6000.00
0005432665295	17844	Economy	6000.00
0005432659747	26295	Business	18000.00
0005432658631	26295	Business	18000.00
0005432655756	26295	Business	18000.00
0005432655754	26295	Economy	6000.00
0005432658632	26295	Economy	6000.00
0005432655760	26295	Economy	6600.00
0005432666429	26295	Economy	6600.00
0005432660858	26295	Economy	6000.00
0005432655758	26295	Economy	6000.00
0005434151734	26295	Economy	6000.00
0005432659746	26295	Economy	6000.00
0005432869599	26295	Economy	6000.00
0005432869593	26295	Economy	6000.00
0005432869592	26295	Economy	6000.00
0005432655763	26295	Economy	6000.00
0005432665315	26295	Economy	6000.00
0005432869595	26295	Economy	6000.00
0005432655759	26295	Economy	6000.00
0005432660857	26295	Economy	6000.00
0005432655764	26295	Economy	6000.00
0005432655757	26295	Economy	6000.00
0005432869571	26295	Economy	6000.00
0005432657510	26295	Economy	6000.00
0005432657509	26295	Economy	6000.00
0005432655761	26295	Economy	6000.00
0005432869600	26295	Economy	6000.00
0005432655755	26295	Economy	6000.00
0005432655765	26295	Economy	6000.00
0005432655762	26295	Economy	6000.00
0005434151733	26295	Economy	6000.00
0005432665314	26295	Economy	6000.00
0005432287296	3123	Business	16100.00
0005432329661	3123	Business	16100.00
0005432329670	3123	Business	16100.00
0005432329654	3123	Business	16100.00
0005432329647	3123	Business	16100.00
0005432329629	3123	Business	16100.00
0005432329673	3123	Business	16100.00
0005432329656	3123	Business	16100.00
0005432329644	3123	Economy	5400.00
0005432329669	3123	Economy	5400.00
0005432329640	3123	Economy	5400.00
0005432329639	3123	Economy	5400.00
0005432329658	3123	Economy	5400.00
0005432329667	3123	Economy	5900.00
0005432905198	3123	Economy	5900.00
0005432329655	3123	Economy	5900.00
0005432329649	3123	Economy	5400.00
0005432329646	3123	Economy	5400.00
0005432329660	3123	Economy	5400.00
0005432287297	3123	Economy	5400.00
0005432329674	3123	Economy	5400.00
0005432329642	3123	Economy	5400.00
0005432329671	3123	Economy	5400.00
0005432329630	3123	Economy	5400.00
0005432329628	3123	Economy	5400.00
0005432329638	3123	Economy	5400.00
0005432287294	3123	Economy	5400.00
0005432329664	3123	Economy	5400.00
0005432329657	3123	Economy	5400.00
0005432329668	3123	Economy	5400.00
0005432905192	3123	Economy	5400.00
0005432329672	3123	Economy	5400.00
0005432329666	3123	Economy	5400.00
0005432905173	3123	Economy	5400.00
0005432329651	3123	Economy	5400.00
0005432329631	3123	Economy	5400.00
0005432329645	3123	Economy	5400.00
0005432905174	3123	Economy	5400.00
0005432329665	3123	Economy	5400.00
0005432329641	3123	Economy	5400.00
0005432329635	3123	Economy	5400.00
0005432329643	3123	Economy	5400.00
0005432329663	3123	Economy	5400.00
0005432329659	3123	Economy	5400.00
0005432329636	3123	Economy	5400.00
0005432329650	3123	Economy	5400.00
0005432905193	3123	Economy	5400.00
0005432329648	3123	Economy	5400.00
0005432329634	3123	Economy	5400.00
0005432329633	3123	Economy	5400.00
0005432329653	3123	Economy	5400.00
0005432287295	3123	Economy	5400.00
0005432329632	3123	Economy	5400.00
0005432905196	3123	Economy	5400.00
0005432329652	3123	Economy	5400.00
0005432329662	3123	Economy	5400.00
0005432329637	3123	Economy	5400.00
0005432329142	31127	Business	16100.00
0005432329103	31127	Business	16100.00
0005432329249	31127	Business	16100.00
0005432329207	31127	Business	16100.00
0005432329289	31127	Business	16100.00
0005432329039	31127	Business	16100.00
0005432329251	31127	Business	16100.00
0005432329425	31127	Business	16100.00
0005432329252	31127	Business	16100.00
0005432329169	31127	Business	16100.00
0005432329390	31127	Economy	5400.00
0005432329143	31127	Economy	5400.00
0005432329006	31127	Economy	5400.00
0005432329148	31127	Economy	5400.00
0005432329126	31127	Economy	5400.00
0005432329097	31127	Economy	5400.00
0005432329024	31127	Economy	5400.00
0005432329416	31127	Economy	5400.00
0005432329218	31127	Economy	5900.00
0005432329205	31127	Economy	5900.00
0005432329177	31127	Economy	5900.00
0005432329112	31127	Economy	5400.00
0005432329076	31127	Economy	5400.00
0005432329372	31127	Economy	5400.00
0005432329160	31127	Economy	5400.00
0005432329060	31127	Economy	5400.00
0005432329158	31127	Economy	5400.00
0005432329104	31127	Economy	5400.00
0005432329028	31127	Economy	5400.00
0005432329420	31127	Economy	5400.00
0005432329202	31127	Economy	5400.00
0005432329115	31127	Economy	5400.00
0005432329136	31127	Economy	5400.00
0005432329098	31127	Economy	5400.00
0005432054366	31127	Economy	5400.00
0005432329273	31127	Economy	5400.00
0005432329326	31127	Economy	5400.00
0005432329201	31127	Economy	5400.00
0005432328890	31127	Economy	5400.00
0005432329424	31127	Economy	5400.00
0005432329149	31127	Economy	5400.00
0005432905244	31127	Economy	5400.00
0005432329155	31127	Economy	5400.00
0005432329324	31127	Economy	5400.00
0005432329040	31127	Economy	5400.00
0005432329204	31127	Economy	5400.00
0005432905245	31127	Economy	5400.00
0005432329176	31127	Economy	5400.00
0005432905243	31127	Economy	5400.00
0005432329341	31127	Economy	5400.00
0005432329159	31127	Economy	5400.00
0005432329170	31127	Economy	5400.00
0005432329288	31127	Economy	5400.00
0005432328940	31127	Economy	5400.00
0005432329269	31127	Economy	5400.00
0005432329282	31127	Economy	5400.00
0005432329221	31127	Economy	5400.00
0005432329272	31127	Economy	5400.00
0005432054365	31127	Economy	5400.00
0005432329373	31127	Economy	5400.00
0005432329156	31127	Economy	5400.00
0005432329059	31127	Economy	5400.00
0005432329268	31127	Economy	5400.00
0005432329182	31127	Economy	5400.00
0005432329325	31127	Economy	5400.00
0005432329219	31127	Economy	5400.00
0005432329141	31127	Economy	5400.00
0005432329118	31127	Economy	5400.00
0005432329105	31127	Economy	5400.00
0005434310027	6219	Business	124600.00
0005434310029	6219	Business	124600.00
0005435488075	6219	Business	124600.00
0005435999614	6219	Business	124600.00
0005435487951	6219	Business	124600.00
0005435488017	6219	Business	124600.00
0005434310028	6219	Business	124600.00
0005435999619	6219	Economy	41500.00
0005435488169	6219	Economy	41500.00
0005434310031	6219	Economy	41500.00
0005435999606	6219	Economy	41500.00
0005435488016	6219	Economy	41500.00
0005435488008	6219	Economy	41500.00
0005435999607	6219	Economy	41500.00
0005434310032	6219	Economy	41500.00
0005434310021	6219	Economy	41500.00
0005435488137	6219	Economy	41500.00
0005435999611	6219	Economy	41500.00
0005435488105	6219	Economy	41500.00
0005435999620	6219	Economy	41500.00
0005435297159	6219	Economy	41500.00
0005435297145	6219	Economy	41500.00
0005435999601	6219	Economy	41500.00
0005435488111	6219	Economy	41500.00
0005435999623	6219	Economy	41500.00
0005435999604	6219	Economy	41500.00
0005434310026	6219	Economy	41500.00
0005435297144	6219	Economy	41500.00
0005435999610	6219	Economy	45700.00
0005435999608	6219	Economy	45700.00
0005435297181	6219	Economy	45700.00
0005435297136	6219	Economy	45700.00
0005435488064	6219	Economy	41500.00
0005435999609	6219	Economy	41500.00
0005434310022	6219	Economy	41500.00
0005435999603	6219	Economy	41500.00
0005435297121	6219	Economy	41500.00
0005435488106	6219	Economy	41500.00
0005434310019	6219	Economy	41500.00
0005435999618	6219	Economy	41500.00
0005434310024	6219	Economy	41500.00
0005435488183	6219	Economy	41500.00
0005434310030	6219	Economy	41500.00
0005435999612	6219	Economy	41500.00
0005435488020	6219	Economy	41500.00
0005435999621	6219	Economy	41500.00
0005435999617	6219	Economy	41500.00
0005435999622	6219	Economy	41500.00
0005434310020	6219	Economy	41500.00
0005432146242	6219	Economy	41500.00
0005434310023	6219	Economy	41500.00
0005435488012	6219	Economy	41500.00
0005435999598	6219	Economy	41500.00
0005435999616	6219	Economy	41500.00
0005435488087	6219	Economy	41500.00
0005435999600	6219	Economy	41500.00
0005435488047	6219	Economy	41500.00
0005435297124	6219	Economy	41500.00
0005435999615	6219	Economy	41500.00
0005435488065	6219	Economy	41500.00
0005435488113	6219	Economy	41500.00
0005435999605	6219	Economy	41500.00
0005435488066	6219	Economy	41500.00
0005435999613	6219	Economy	41500.00
0005435297147	6219	Economy	41500.00
0005435999597	6219	Economy	41500.00
0005435488067	6219	Economy	41500.00
0005435488009	6219	Economy	41500.00
0005435999599	6219	Economy	41500.00
0005435297148	6219	Economy	41500.00
0005435999602	6219	Economy	41500.00
0005434310025	6219	Economy	41500.00
0005434309901	19584	Business	124600.00
0005435488258	19584	Business	124600.00
0005434309917	19584	Business	124600.00
0005435297204	19584	Business	124600.00
0005435488269	19584	Business	124600.00
0005435488257	19584	Business	124600.00
0005435999464	19584	Business	124600.00
0005435488262	19584	Business	124600.00
0005434309897	19584	Economy	41500.00
0005435488253	19584	Economy	41500.00
0005434309928	19584	Economy	41500.00
0005435999413	19584	Economy	41500.00
0005435999404	19584	Economy	41500.00
0005434309891	19584	Economy	41500.00
0005435488264	19584	Economy	41500.00
0005435999472	19584	Economy	41500.00
0005434309868	19584	Economy	41500.00
0005435488261	19584	Economy	41500.00
0005435488252	19584	Economy	41500.00
0005434309943	19584	Economy	41500.00
0005435999419	19584	Economy	41500.00
0005435488271	19584	Economy	41500.00
0005435999465	19584	Economy	41500.00
0005435297203	19584	Economy	41500.00
0005434309838	19584	Economy	41500.00
0005434309899	19584	Economy	41500.00
0005435488265	19584	Economy	41500.00
0005434309918	19584	Economy	41500.00
0005435999475	19584	Economy	45700.00
0005435999456	19584	Economy	45700.00
0005435488266	19584	Economy	45700.00
0005434309896	19584	Economy	41500.00
0005435297198	19584	Economy	41500.00
0005434309926	19584	Economy	41500.00
0005435999454	19584	Economy	41500.00
0005434309876	19584	Economy	41500.00
0005434309907	19584	Economy	41500.00
0005434309916	19584	Economy	41500.00
0005435488270	19584	Economy	41500.00
0005435999474	19584	Economy	41500.00
0005435488255	19584	Economy	41500.00
0005435297201	19584	Economy	41500.00
0005435999473	19584	Economy	41500.00
0005435999414	19584	Economy	41500.00
0005435488263	19584	Economy	41500.00
0005434309927	19584	Economy	41500.00
0005434309942	19584	Economy	41500.00
0005435488260	19584	Economy	41500.00
0005434309894	19584	Economy	41500.00
0005434309944	19584	Economy	41500.00
0005435488268	19584	Economy	41500.00
0005434309898	19584	Economy	41500.00
0005435297202	19584	Economy	41500.00
0005435488254	19584	Economy	41500.00
0005435297199	19584	Economy	41500.00
0005435488259	19584	Economy	41500.00
0005435488256	19584	Economy	41500.00
0005435999469	19584	Economy	41500.00
0005434309895	19584	Economy	41500.00
0005435488272	19584	Economy	41500.00
0005435999455	19584	Economy	41500.00
0005435488267	19584	Economy	41500.00
0005435999471	19584	Economy	41500.00
0005434309855	19584	Economy	41500.00
0005435999338	19584	Economy	41500.00
0005435297200	19584	Economy	41500.00
0005434446546	17548	Economy	13600.00
0005433158178	17548	Economy	12300.00
0005434446528	17548	Economy	12300.00
0005434446553	17548	Economy	12300.00
0005434446527	17548	Economy	12300.00
0005433158177	17548	Economy	12300.00
0005434446543	17548	Economy	12300.00
0005434446541	17548	Economy	12300.00
0005434446537	17548	Economy	12300.00
0005434446547	17548	Economy	12300.00
0005434446540	17548	Economy	12300.00
0005433158176	17548	Economy	12300.00
0005434446542	17548	Economy	12300.00
0005435502762	1602	Business	86000.00
0005435518287	1602	Business	86000.00
0005435508628	1602	Business	86000.00
0005435508629	1602	Business	86000.00
0005435502759	1602	Business	86000.00
0005435518289	1602	Business	86000.00
0005434566188	1602	Business	86000.00
0005435502765	1602	Business	86000.00
0005435508637	1602	Business	86000.00
0005433186210	1602	Business	86000.00
0005435518288	1602	Economy	28700.00
0005435508616	1602	Economy	28700.00
0005433186222	1602	Economy	28700.00
0005435518291	1602	Economy	28700.00
0005435502771	1602	Economy	28700.00
0005432291981	1602	Economy	28700.00
0005435508636	1602	Economy	28700.00
0005435502766	1602	Economy	28700.00
0005435508634	1602	Economy	28700.00
0005435518293	1602	Economy	31500.00
0005435502761	1602	Economy	31500.00
0005434566189	1602	Economy	31500.00
0005432291982	1602	Economy	31500.00
0005434566197	1602	Economy	28700.00
0005435502754	1602	Economy	28700.00
0005435508632	1602	Economy	28700.00
0005435518279	1602	Economy	28700.00
0005435508630	1602	Economy	28700.00
0005434566195	1602	Economy	28700.00
0005435508625	1602	Economy	28700.00
0005435518292	1602	Economy	28700.00
0005434566187	1602	Economy	28700.00
0005435502753	1602	Economy	28700.00
0005435518286	1602	Economy	28700.00
0005435508620	1602	Economy	28700.00
0005435518284	1602	Economy	28700.00
0005435502760	1602	Economy	28700.00
0005435502751	1602	Economy	28700.00
0005435502763	1602	Economy	28700.00
0005435518283	1602	Economy	28700.00
0005435502764	1602	Economy	28700.00
0005435502756	1602	Economy	28700.00
0005433186238	1602	Economy	28700.00
0005435518290	1602	Economy	28700.00
0005434566193	1602	Economy	28700.00
0005435502773	1602	Economy	28700.00
0005435518280	1602	Economy	28700.00
0005435502752	1602	Economy	28700.00
0005435508621	1602	Economy	28700.00
0005434566190	1602	Economy	28700.00
0005435508638	1602	Economy	28700.00
0005435508623	1602	Economy	28700.00
0005435502758	1602	Economy	28700.00
0005433186256	1602	Economy	28700.00
0005435502767	1602	Economy	28700.00
0005435508635	1602	Economy	28700.00
0005435508624	1602	Economy	28700.00
0005435508640	1602	Economy	28700.00
0005435508618	1602	Economy	28700.00
0005435502768	1602	Economy	28700.00
0005434566198	1602	Economy	28700.00
0005435502772	1602	Economy	28700.00
0005435518282	1602	Economy	28700.00
0005435508633	1602	Economy	28700.00
0005433186240	1602	Economy	28700.00
0005434566192	1602	Economy	28700.00
0005435502757	1602	Economy	28700.00
0005434566199	1602	Economy	28700.00
0005433186257	1602	Economy	28700.00
0005434566191	1602	Economy	28700.00
0005435508617	1602	Economy	28700.00
0005433186223	1602	Economy	28700.00
0005434566194	1602	Economy	28700.00
0005434566200	1602	Economy	28700.00
0005435502755	1602	Economy	28700.00
0005435508639	1602	Economy	28700.00
0005435518281	1602	Economy	28700.00
0005435508626	1602	Economy	28700.00
0005435508631	1602	Economy	28700.00
0005435518285	1602	Economy	28700.00
0005435508627	1602	Economy	28700.00
0005435508622	1602	Economy	28700.00
0005435502769	1602	Economy	28700.00
0005435508619	1602	Economy	28700.00
0005433186224	1602	Economy	28700.00
0005435502770	1602	Economy	28700.00
0005434566196	1602	Economy	28700.00
0005434566093	20878	Business	86000.00
0005435545829	20878	Business	86000.00
0005435529454	20878	Business	86000.00
0005435545838	20878	Business	86000.00
0005435545793	20878	Business	86000.00
0005435545837	20878	Business	86000.00
0005433186297	20878	Business	86000.00
0005435545806	20878	Business	86000.00
0005435545818	20878	Business	86000.00
0005434566095	20878	Economy	28700.00
0005435545842	20878	Economy	28700.00
0005435529448	20878	Economy	28700.00
0005433186296	20878	Economy	28700.00
0005435502586	20878	Economy	28700.00
0005435529507	20878	Economy	28700.00
0005433186293	20878	Economy	31500.00
0005435545816	20878	Economy	31500.00
0005435529461	20878	Economy	31500.00
0005434566052	20878	Economy	31500.00
0005433186299	20878	Economy	28700.00
0005434566063	20878	Economy	28700.00
0005435502562	20878	Economy	28700.00
0005435529391	20878	Economy	28700.00
0005435529499	20878	Economy	28700.00
0005435529519	20878	Economy	28700.00
0005435502633	20878	Economy	28700.00
0005435502569	20878	Economy	28700.00
0005435502632	20878	Economy	28700.00
0005434566062	20878	Economy	28700.00
0005434566074	20878	Economy	28700.00
0005435529395	20878	Economy	28700.00
0005435529475	20878	Economy	28700.00
0005435502561	20878	Economy	28700.00
0005433186294	20878	Economy	28700.00
0005434566075	20878	Economy	28700.00
0005435502596	20878	Economy	28700.00
0005435529549	20878	Economy	28700.00
0005435502570	20878	Economy	28700.00
0005435545845	20878	Economy	28700.00
0005433186292	20878	Economy	28700.00
0005435529548	20878	Economy	28700.00
0005435545843	20878	Economy	28700.00
0005435545831	20878	Economy	28700.00
0005435529498	20878	Economy	28700.00
0005435529387	20878	Economy	28700.00
0005433186300	20878	Economy	28700.00
0005435545815	20878	Economy	28700.00
0005434566076	20878	Economy	28700.00
0005435502604	20878	Economy	28700.00
0005434566033	20878	Economy	28700.00
0005435545830	20878	Economy	28700.00
0005435502563	20878	Economy	28700.00
0005435545819	20878	Economy	28700.00
0005435545794	20878	Economy	28700.00
0005435529430	20878	Economy	28700.00
0005433186298	20878	Economy	28700.00
0005435502515	20878	Economy	28700.00
0005435502514	20878	Economy	28700.00
0005434566108	20878	Economy	28700.00
0005435529476	20878	Economy	28700.00
0005435502400	20878	Economy	28700.00
0005435502608	20878	Economy	28700.00
0005435502605	20878	Economy	28700.00
0005435529474	20878	Economy	28700.00
0005435502597	20878	Economy	28700.00
0005434566089	20878	Economy	28700.00
0005435529455	20878	Economy	28700.00
0005435529482	20878	Economy	28700.00
0005435529431	20878	Economy	28700.00
0005433186295	20878	Economy	28700.00
0005434566118	20878	Economy	28700.00
0005435502594	20878	Economy	28700.00
0005435931642	3913	Economy	21600.00
0005435153876	3913	Economy	19700.00
0005435153883	3913	Economy	19700.00
0005435931645	3913	Economy	19700.00
0005435153878	3913	Economy	19700.00
0005435153879	3913	Economy	19700.00
0005435931636	3913	Economy	19700.00
0005435142972	3913	Economy	19700.00
0005435142974	3913	Economy	19700.00
0005435931651	3913	Economy	19700.00
0005435931643	3913	Economy	19700.00
0005435153882	3913	Economy	19700.00
0005435931646	3913	Economy	19700.00
0005435153880	3913	Economy	19700.00
0005435142973	3913	Economy	19700.00
0005435153881	3913	Economy	19700.00
0005435931652	3913	Economy	19700.00
0005435153877	3913	Economy	19700.00
0005435931678	21885	Economy	19700.00
0005435153792	21885	Economy	19700.00
0005435153791	21885	Economy	19700.00
0005435153848	21885	Economy	19700.00
0005435153793	21885	Economy	19700.00
0005435931680	21885	Economy	19700.00
0005435153847	21885	Economy	19700.00
0005435931679	21885	Economy	19700.00
0005435153842	21885	Economy	19700.00
0005435225693	7170	Economy	14300.00
0005435225684	7170	Economy	14300.00
0005432629158	7170	Economy	14300.00
0005435225683	7170	Economy	13000.00
0005435225705	7170	Economy	13000.00
0005432629153	7170	Economy	13000.00
0005435225668	7170	Economy	13000.00
0005432629157	7170	Economy	13000.00
0005435225707	7170	Economy	13000.00
0005432629152	7170	Economy	13000.00
0005435225655	7170	Economy	13000.00
0005435225692	7170	Economy	13000.00
0005435225667	7170	Economy	13000.00
0005435225663	7170	Economy	13000.00
0005435225690	7170	Economy	13000.00
0005432629151	7170	Economy	13000.00
0005432629155	7170	Economy	13000.00
0005432629146	7170	Economy	13000.00
0005432629150	7170	Economy	13000.00
0005432629148	7170	Economy	13000.00
0005432629156	7170	Economy	13000.00
0005432629149	7170	Economy	13000.00
0005432629154	7170	Economy	13000.00
0005432629147	7170	Economy	13000.00
0005435225720	7170	Economy	13000.00
0005435225654	7170	Economy	13000.00
0005435225681	7170	Economy	13000.00
0005435225704	7170	Economy	13000.00
0005435225662	7170	Economy	13000.00
0005432629160	7170	Economy	13000.00
0005432629159	7170	Economy	13000.00
0005435225706	7170	Economy	13000.00
0005435225752	28113	Economy	14300.00
0005435225749	28113	Economy	14300.00
0005432629060	28113	Economy	13000.00
0005432629021	28113	Economy	13000.00
0005432629004	28113	Economy	13000.00
0005432628995	28113	Economy	13000.00
0005435225750	28113	Economy	13000.00
0005432629033	28113	Economy	13000.00
0005432629048	28113	Economy	13000.00
0005432629092	28113	Economy	13000.00
0005432629009	28113	Economy	13000.00
0005432629042	28113	Economy	13000.00
0005432629044	28113	Economy	13000.00
0005435225751	28113	Economy	13000.00
0005432629005	28113	Economy	13000.00
0005432629032	28113	Economy	13000.00
0005435225754	28113	Economy	13000.00
0005435225755	28113	Economy	13000.00
0005432629027	28113	Economy	13000.00
0005435225748	28113	Economy	13000.00
0005432629059	28113	Economy	13000.00
0005432629022	28113	Economy	13000.00
0005435225753	28113	Economy	13000.00
0005432629043	28113	Economy	13000.00
0005435960130	8725	Economy	11500.00
0005435960132	8725	Economy	10500.00
0005435960129	8725	Economy	10500.00
0005434268005	8725	Economy	10500.00
0005435960131	8725	Economy	10500.00
0005434268001	8725	Economy	10500.00
0005435960100	15230	Economy	11500.00
0005435960104	15230	Economy	10500.00
0005434268029	15230	Economy	10500.00
0005434268028	15230	Economy	10500.00
0005435960097	15230	Economy	10500.00
0005435960095	15230	Economy	10500.00
0005435960103	15230	Economy	10500.00
0005434268027	15230	Economy	10500.00
0005432675446	1190	Business	115000.00
0005432693689	1190	Business	115000.00
0005432873372	1190	Business	115000.00
0005432693684	1190	Business	115000.00
0005432675444	1190	Business	115000.00
0005432693667	1190	Business	115000.00
0005432675450	1190	Business	115000.00
0005432693670	1190	Business	115000.00
0005432693679	1190	Business	115000.00
0005432675454	1190	Business	115000.00
0005432675442	1190	Business	115000.00
0005432873384	1190	Economy	38300.00
0005432693678	1190	Economy	38300.00
0005432675451	1190	Economy	38300.00
0005432693686	1190	Economy	38300.00
0005432693669	1190	Economy	42200.00
0005432693671	1190	Economy	42200.00
0005432873383	1190	Economy	42200.00
0005432675443	1190	Economy	38300.00
0005432693690	1190	Economy	38300.00
0005432873365	1190	Economy	38300.00
0005432675447	1190	Economy	38300.00
0005432693685	1190	Economy	38300.00
0005432675441	1190	Economy	38300.00
0005432693665	1190	Economy	38300.00
0005432675440	1190	Economy	38300.00
0005432693687	1190	Economy	38300.00
0005432675449	1190	Economy	38300.00
0005432675453	1190	Economy	38300.00
0005432693693	1190	Economy	38300.00
0005432677652	1190	Economy	38300.00
0005432693676	1190	Economy	38300.00
0005432693692	1190	Economy	38300.00
0005432675439	1190	Economy	38300.00
0005432693680	1190	Economy	38300.00
0005432693681	1190	Economy	38300.00
0005432675448	1190	Economy	38300.00
0005432693683	1190	Economy	38300.00
0005432873389	1190	Economy	38300.00
0005432693664	1190	Economy	38300.00
0005432675445	1190	Economy	38300.00
0005432677651	1190	Economy	38300.00
0005432693672	1190	Economy	38300.00
0005432873373	1190	Economy	38300.00
0005432873391	1190	Economy	38300.00
0005432873363	1190	Economy	38300.00
0005432693668	1190	Economy	38300.00
0005432693675	1190	Economy	38300.00
0005432873390	1190	Economy	38300.00
0005432693691	1190	Economy	38300.00
0005432693666	1190	Economy	38300.00
0005432693673	1190	Economy	38300.00
0005432693674	1190	Economy	38300.00
0005432677653	1190	Economy	38300.00
0005432693688	1190	Economy	38300.00
0005432693682	1190	Economy	38300.00
0005432693694	1190	Economy	38300.00
0005432693677	1190	Economy	38300.00
0005432873364	1190	Economy	38300.00
0005432675452	1190	Economy	38300.00
0005432693663	1190	Economy	38300.00
0005432675300	17499	Business	115000.00
0005432675325	17499	Business	115000.00
0005432693414	17499	Business	115000.00
0005432693390	17499	Business	115000.00
0005432675231	17499	Business	115000.00
0005432675385	17499	Business	115000.00
0005432693178	17499	Business	115000.00
0005432693506	17499	Business	115000.00
0005432675261	17499	Business	115000.00
0005432693482	17499	Business	115000.00
0005432693352	17499	Business	115000.00
0005432675232	17499	Business	115000.00
0005432873441	17499	Business	115000.00
0005432693380	17499	Economy	38300.00
0005432693500	17499	Economy	38300.00
0005432675309	17499	Economy	38300.00
0005432693505	17499	Economy	38300.00
0005432677615	17499	Economy	38300.00
0005432873436	17499	Economy	38300.00
0005432693394	17499	Economy	38300.00
0005432693462	17499	Economy	38300.00
0005432675276	17499	Economy	38300.00
0005432675296	17499	Economy	42200.00
0005432693340	17499	Economy	38300.00
0005432675370	17499	Economy	38300.00
0005432693459	17499	Economy	38300.00
0005432693378	17499	Economy	38300.00
0005432873437	17499	Economy	38300.00
0005432675334	17499	Economy	38300.00
0005432675335	17499	Economy	38300.00
0005432675297	17499	Economy	38300.00
0005432693429	17499	Economy	38300.00
0005432675371	17499	Economy	38300.00
0005432693411	17499	Economy	38300.00
0005432675267	17499	Economy	38300.00
0005432675292	17499	Economy	38300.00
0005432693291	17499	Economy	38300.00
0005432675322	17499	Economy	38300.00
0005432693460	17499	Economy	38300.00
0005432693180	17499	Economy	38300.00
0005432693179	17499	Economy	38300.00
0005432873440	17499	Economy	38300.00
0005432675336	17499	Economy	38300.00
0005432677631	17499	Economy	38300.00
0005432675357	17499	Economy	38300.00
0005432693260	17499	Economy	38300.00
0005432675284	17499	Economy	38300.00
0005432675326	17499	Economy	38300.00
0005432675277	17499	Economy	38300.00
0005432693335	17499	Economy	38300.00
0005432675311	17499	Economy	38300.00
0005432693351	17499	Economy	38300.00
0005432675355	17499	Economy	38300.00
0005432677618	17499	Economy	38300.00
0005432693348	17499	Economy	38300.00
0005432693417	17499	Economy	38300.00
0005432693316	17499	Economy	38300.00
0005432675310	17499	Economy	38300.00
0005432693461	17499	Economy	38300.00
0005432675283	17499	Economy	38300.00
0005432693420	17499	Economy	38300.00
0005432675266	17499	Economy	38300.00
0005432675265	17499	Economy	38300.00
0005432873439	17499	Economy	38300.00
0005432873438	17499	Economy	38300.00
0005432675375	17499	Economy	38300.00
0005432675356	17499	Economy	38300.00
0005432873442	17499	Economy	38300.00
0005432675230	17499	Economy	38300.00
0005432677604	17499	Economy	38300.00
0005432693427	17499	Economy	38300.00
0005434435506	1133	Economy	15200.00
0005433156863	1133	Economy	15200.00
0005433156850	1133	Economy	13900.00
0005433156873	1133	Economy	13900.00
0005434435500	1133	Economy	13900.00
0005433156871	1133	Economy	13900.00
0005433156878	1133	Economy	13900.00
0005433156866	1133	Economy	13900.00
0005434435495	1133	Economy	13900.00
0005434435508	1133	Economy	13900.00
0005434435502	1133	Economy	13900.00
0005433156891	1133	Economy	13900.00
0005434435498	1133	Economy	13900.00
0005434435493	1133	Economy	13900.00
0005434435494	1133	Economy	13900.00
0005433156879	1133	Economy	13900.00
0005434435503	1133	Economy	13900.00
0005434435499	1133	Economy	13900.00
0005434435505	1133	Economy	13900.00
0005434435501	1133	Economy	13900.00
0005434435507	1133	Economy	13900.00
0005434435497	1133	Economy	13900.00
0005433156872	1133	Economy	13900.00
0005434435504	1133	Economy	13900.00
0005434435496	1133	Economy	13900.00
0005434435509	1133	Economy	13900.00
0005433156932	17280	Economy	15200.00
0005433156928	17280	Economy	15200.00
0005434435359	17280	Economy	15200.00
0005434435330	17280	Economy	13900.00
0005433156929	17280	Economy	13900.00
0005433156931	17280	Economy	13900.00
0005433156926	17280	Economy	13900.00
0005434435338	17280	Economy	13900.00
0005434435411	17280	Economy	13900.00
0005434435363	17280	Economy	13900.00
0005433156924	17280	Economy	13900.00
0005434435375	17280	Economy	13900.00
0005434435374	17280	Economy	13900.00
0005434435393	17280	Economy	13900.00
0005433156925	17280	Economy	13900.00
0005434435329	17280	Economy	13900.00
0005434435412	17280	Economy	13900.00
0005434435387	17280	Economy	13900.00
0005433156930	17280	Economy	13900.00
0005434435425	17280	Economy	13900.00
0005434435342	17280	Economy	13900.00
0005434435424	17280	Economy	13900.00
0005434435351	17280	Economy	13900.00
0005433156927	17280	Economy	13900.00
0005435086988	4062	Economy	7500.00
0005435086992	4062	Economy	7500.00
0005435086991	4062	Economy	7500.00
0005435086995	4062	Economy	7500.00
0005435086994	4062	Economy	7500.00
0005435928202	4062	Economy	7500.00
0005435928201	4062	Economy	7500.00
0005435928203	4062	Economy	7500.00
0005435086990	4062	Economy	7500.00
0005435086993	4062	Economy	7500.00
0005435086989	4062	Economy	7500.00
0005435928204	4062	Economy	7500.00
0005435086924	24383	Economy	7500.00
0005435928244	24383	Economy	7500.00
0005435928241	24383	Economy	7500.00
0005435086914	24383	Economy	7500.00
0005435086916	24383	Economy	7500.00
0005435928242	24383	Economy	7500.00
0005435086926	24383	Economy	7500.00
0005435086913	24383	Economy	7500.00
0005435928243	24383	Economy	7500.00
0005435706731	2449	Business	86800.00
0005435706717	2449	Business	86800.00
0005435706733	2449	Business	86800.00
0005433373658	2449	Business	86800.00
0005435706712	2449	Business	86800.00
0005435706697	2449	Business	86800.00
0005433373589	2449	Business	86800.00
0005435706689	2449	Business	86800.00
0005435706687	2449	Business	86800.00
0005433373650	2449	Economy	28900.00
0005435706714	2449	Economy	28900.00
0005433373635	2449	Economy	28900.00
0005435706720	2449	Economy	28900.00
0005435706700	2449	Economy	28900.00
0005433373634	2449	Economy	28900.00
0005435706702	2449	Economy	28900.00
0005433373625	2449	Economy	28900.00
0005435706729	2449	Economy	31800.00
0005435706694	2449	Economy	31800.00
0005435706726	2449	Economy	31800.00
0005435706722	2449	Economy	28900.00
0005435706723	2449	Economy	28900.00
0005433373647	2449	Economy	28900.00
0005435706718	2449	Economy	28900.00
0005433373661	2449	Economy	28900.00
0005435706685	2449	Economy	28900.00
0005435706703	2449	Economy	28900.00
0005435706725	2449	Economy	28900.00
0005435706691	2449	Economy	28900.00
0005435706715	2449	Economy	28900.00
0005435706716	2449	Economy	28900.00
0005435706713	2449	Economy	28900.00
0005433373656	2449	Economy	28900.00
0005435706709	2449	Economy	28900.00
0005435706730	2449	Economy	28900.00
0005435706711	2449	Economy	28900.00
0005435706705	2449	Economy	28900.00
0005433373628	2449	Economy	28900.00
0005435706710	2449	Economy	28900.00
0005435706706	2449	Economy	28900.00
0005435706701	2449	Economy	28900.00
0005435706696	2449	Economy	28900.00
0005433373627	2449	Economy	28900.00
0005435706724	2449	Economy	28900.00
0005435706719	2449	Economy	28900.00
0005433373642	2449	Economy	28900.00
0005433373588	2449	Economy	28900.00
0005435706695	2449	Economy	28900.00
0005435706684	2449	Economy	28900.00
0005435706692	2449	Economy	28900.00
0005435706727	2449	Economy	28900.00
0005435706698	2449	Economy	28900.00
0005435706708	2449	Economy	28900.00
0005435706721	2449	Economy	28900.00
0005433373602	2449	Economy	28900.00
0005435706728	2449	Economy	28900.00
0005435706693	2449	Economy	28900.00
0005435706686	2449	Economy	28900.00
0005435706688	2449	Economy	28900.00
0005433373619	2449	Economy	28900.00
0005433373623	2449	Economy	28900.00
0005435706735	2449	Economy	28900.00
0005433373618	2449	Economy	28900.00
0005433373649	2449	Economy	28900.00
0005433373626	2449	Economy	28900.00
0005433373680	2449	Economy	28900.00
0005435706690	2449	Economy	28900.00
0005433373636	2449	Economy	28900.00
0005435706704	2449	Economy	28900.00
0005433373622	2449	Economy	28900.00
0005435706732	2449	Economy	28900.00
0005433373679	2449	Economy	28900.00
0005433373678	2449	Economy	28900.00
0005433373629	2449	Economy	28900.00
0005435706707	2449	Economy	28900.00
0005435706699	2449	Economy	28900.00
0005435706734	2449	Economy	28900.00
0005435706476	27035	Business	86800.00
0005435706605	27035	Business	86800.00
0005435706533	27035	Business	86800.00
0005435706663	27035	Business	86800.00
0005435706464	27035	Business	86800.00
0005435706555	27035	Business	86800.00
0005433373726	27035	Business	86800.00
0005435706614	27035	Business	86800.00
0005435706574	27035	Business	86800.00
0005435706475	27035	Business	86800.00
0005435706556	27035	Economy	28900.00
0005435706541	27035	Economy	28900.00
0005433373706	27035	Economy	28900.00
0005435706527	27035	Economy	28900.00
0005435706664	27035	Economy	28900.00
0005433373702	27035	Economy	28900.00
0005433373717	27035	Economy	28900.00
0005433373723	27035	Economy	28900.00
0005433373715	27035	Economy	28900.00
0005435706626	27035	Economy	31800.00
0005435706505	27035	Economy	31800.00
0005435706543	27035	Economy	31800.00
0005435706449	27035	Economy	31800.00
0005433373727	27035	Economy	28900.00
0005435706470	27035	Economy	28900.00
0005435706549	27035	Economy	28900.00
0005435706568	27035	Economy	28900.00
0005433373713	27035	Economy	28900.00
0005435706598	27035	Economy	28900.00
0005433373705	27035	Economy	28900.00
0005435706606	27035	Economy	28900.00
0005435706559	27035	Economy	28900.00
0005435706639	27035	Economy	28900.00
0005435706554	27035	Economy	28900.00
0005435706597	27035	Economy	28900.00
0005435706518	27035	Economy	28900.00
0005435706609	27035	Economy	28900.00
0005435706608	27035	Economy	28900.00
0005433373718	27035	Economy	28900.00
0005435706575	27035	Economy	28900.00
0005435706506	27035	Economy	28900.00
0005435706535	27035	Economy	28900.00
0005435706500	27035	Economy	28900.00
0005435706450	27035	Economy	28900.00
0005433373703	27035	Economy	28900.00
0005433373704	27035	Economy	28900.00
0005435706522	27035	Economy	28900.00
0005433373709	27035	Economy	28900.00
0005435706588	27035	Economy	28900.00
0005433373724	27035	Economy	28900.00
0005433373716	27035	Economy	28900.00
0005435706519	27035	Economy	28900.00
0005435706488	27035	Economy	28900.00
0005435706544	27035	Economy	28900.00
0005433373719	27035	Economy	28900.00
0005435706507	27035	Economy	28900.00
0005435706501	27035	Economy	28900.00
0005433373721	27035	Economy	28900.00
0005435706542	27035	Economy	28900.00
0005435706530	27035	Economy	28900.00
0005433373725	27035	Economy	28900.00
0005435706529	27035	Economy	28900.00
0005435706550	27035	Economy	28900.00
0005435706596	27035	Economy	28900.00
0005435706480	27035	Economy	28900.00
0005433373707	27035	Economy	28900.00
0005433373711	27035	Economy	28900.00
0005433373722	27035	Economy	28900.00
0005435706521	27035	Economy	28900.00
0005433373728	27035	Economy	28900.00
0005433373714	27035	Economy	28900.00
0005433373708	27035	Economy	28900.00
0005435706576	27035	Economy	28900.00
0005433373712	27035	Economy	28900.00
0005435706625	27035	Economy	28900.00
0005433373710	27035	Economy	28900.00
0005435706613	27035	Economy	28900.00
0005435706463	27035	Economy	28900.00
0005433373720	27035	Economy	28900.00
0005435706599	27035	Economy	28900.00
0005435706469	27035	Economy	28900.00
0005435706677	27035	Economy	28900.00
0005435706481	27035	Economy	28900.00
0005435706452	27035	Economy	28900.00
0005435907537	4862	Business	44200.00
0005433194881	4862	Business	44200.00
0005434626158	4862	Business	44200.00
0005433194867	4862	Economy	14700.00
0005434626156	4862	Economy	14700.00
0005433194891	4862	Economy	16200.00
0005435907551	4862	Economy	14700.00
0005435907557	4862	Economy	14700.00
0005434626157	4862	Economy	14700.00
0005434626155	4862	Economy	14700.00
0005434626161	4862	Economy	14700.00
0005435907536	4862	Economy	14700.00
0005434626159	4862	Economy	14700.00
0005435907550	4862	Economy	14700.00
0005435907549	4862	Economy	14700.00
0005435907579	4862	Economy	14700.00
0005434626162	4862	Economy	14700.00
0005434626163	4862	Economy	14700.00
0005434626154	4862	Economy	14700.00
0005434626160	4862	Economy	14700.00
0005434626093	32934	Business	44200.00
0005434626037	32934	Business	44200.00
0005434626066	32934	Economy	14700.00
0005435907608	32934	Economy	14700.00
0005434626028	32934	Economy	14700.00
0005435907610	32934	Economy	16200.00
0005434626051	32934	Economy	16200.00
0005434626029	32934	Economy	14700.00
0005434626083	32934	Economy	14700.00
0005434626092	32934	Economy	14700.00
0005435907607	32934	Economy	14700.00
0005434626119	32934	Economy	14700.00
0005434626120	32934	Economy	14700.00
0005434626096	32934	Economy	14700.00
0005435907609	32934	Economy	14700.00
0005434626052	32934	Economy	14700.00
0005435937474	13795	Economy	3400.00
0005435785811	13795	Economy	3400.00
0005435785746	13795	Economy	3400.00
0005435785802	13795	Economy	3400.00
0005435785745	13795	Economy	3100.00
0005435937475	13795	Economy	3100.00
0005435785738	13795	Economy	3100.00
0005435785843	13795	Economy	3100.00
0005435937481	13795	Economy	3100.00
0005435785863	13795	Economy	3100.00
0005435787386	13795	Economy	3100.00
0005435785678	13795	Economy	3100.00
0005435785465	13795	Economy	3100.00
0005432195739	13795	Economy	3100.00
0005435785681	13795	Economy	3100.00
0005435785475	13795	Economy	3100.00
0005435787385	13795	Economy	3100.00
0005435785611	13795	Economy	3100.00
0005435785806	13795	Economy	3100.00
0005435785724	13795	Economy	3100.00
0005435937478	13795	Economy	3100.00
0005435785680	13795	Economy	3100.00
0005435937483	13795	Economy	3100.00
0005435937482	13795	Economy	3100.00
0005435785765	13795	Economy	3100.00
0005435937480	13795	Economy	3100.00
0005435785737	13795	Economy	3100.00
0005435785682	13795	Economy	3100.00
0005432195738	13795	Economy	3100.00
0005435937473	13795	Economy	3100.00
0005435785763	13795	Economy	3100.00
0005435785631	13795	Economy	3100.00
0005435937479	13795	Economy	3100.00
0005435785777	13795	Economy	3100.00
0005435937477	13795	Economy	3100.00
0005435785756	13795	Economy	3100.00
0005435937476	13795	Economy	3100.00
0005435785476	13795	Economy	3100.00
0005435785755	13795	Economy	3100.00
0005435785766	13795	Economy	3100.00
0005435785844	13795	Economy	3100.00
0005435937484	13795	Economy	3100.00
0005435785712	13795	Economy	3100.00
0005435785778	13795	Economy	3100.00
0005435785826	13795	Economy	3100.00
0005435937472	13795	Economy	3100.00
0005435785710	13795	Economy	3100.00
0005435785764	13795	Economy	3100.00
0005435937471	13795	Economy	3100.00
0005435937429	27454	Economy	3400.00
0005435786007	27454	Economy	3400.00
0005435786021	27454	Economy	3400.00
0005435937436	27454	Economy	3400.00
0005435937427	27454	Economy	3100.00
0005435786010	27454	Economy	3100.00
0005435937435	27454	Economy	3100.00
0005435786018	27454	Economy	3100.00
0005435786020	27454	Economy	3100.00
0005435786024	27454	Economy	3100.00
0005435937432	27454	Economy	3100.00
0005435786038	27454	Economy	3100.00
0005435787395	27454	Economy	3100.00
0005435786036	27454	Economy	3100.00
0005435786039	27454	Economy	3100.00
0005435786005	27454	Economy	3100.00
0005435786017	27454	Economy	3100.00
0005432190705	27454	Economy	3100.00
0005435786037	27454	Economy	3100.00
0005435786013	27454	Economy	3100.00
0005435937419	27454	Economy	3100.00
0005435786012	27454	Economy	3100.00
0005435787394	27454	Economy	3100.00
0005435786028	27454	Economy	3100.00
0005435937418	27454	Economy	3100.00
0005432190704	27454	Economy	3100.00
0005435787393	27454	Economy	3100.00
0005435786026	27454	Economy	3100.00
0005435786032	27454	Economy	3100.00
0005435786033	27454	Economy	3100.00
0005435786034	27454	Economy	3100.00
0005432190703	27454	Economy	3100.00
0005435786022	27454	Economy	3100.00
0005435786016	27454	Economy	3100.00
0005435786030	27454	Economy	3100.00
0005435786023	27454	Economy	3100.00
0005435786008	27454	Economy	3100.00
0005432190702	27454	Economy	3100.00
0005435786019	27454	Economy	3100.00
0005435786029	27454	Economy	3100.00
0005435937426	27454	Economy	3100.00
0005435786014	27454	Economy	3100.00
0005435786025	27454	Economy	3100.00
0005435786035	27454	Economy	3100.00
0005435786009	27454	Economy	3100.00
0005435786027	27454	Economy	3100.00
0005435786015	27454	Economy	3100.00
0005435786031	27454	Economy	3100.00
0005435786006	27454	Economy	3100.00
0005435786011	27454	Economy	3100.00
0005434408268	20254	Business	12000.00
0005435311335	20254	Business	12000.00
0005435311337	20254	Business	12000.00
0005435311323	20254	Business	12000.00
0005435311354	20254	Business	12000.00
0005434408589	20254	Business	12000.00
0005435311328	20254	Business	12000.00
0005434408221	20254	Business	12000.00
0005434408473	20254	Business	12000.00
0005434408670	20254	Business	12000.00
0005434408462	20254	Business	12000.00
0005432058464	20254	Business	12000.00
0005434408608	20254	Economy	4000.00
0005435311329	20254	Economy	4000.00
0005434408358	20254	Economy	4000.00
0005434408569	20254	Economy	4000.00
0005434408271	20254	Economy	4000.00
0005435311339	20254	Economy	4000.00
0005434408434	20254	Economy	4000.00
0005434408541	20254	Economy	4000.00
0005435311341	20254	Economy	4000.00
0005435311349	20254	Economy	4400.00
0005434408357	20254	Economy	4400.00
0005435311320	20254	Economy	4400.00
0005434408468	20254	Economy	4400.00
0005432058463	20254	Economy	4000.00
0005434408691	20254	Economy	4000.00
0005434408607	20254	Economy	4000.00
0005434408658	20254	Economy	4000.00
0005435311334	20254	Economy	4000.00
0005435311330	20254	Economy	4000.00
0005435311342	20254	Economy	4000.00
0005435311348	20254	Economy	4000.00
0005434408313	20254	Economy	4000.00
0005434408474	20254	Economy	4000.00
0005435311326	20254	Economy	4000.00
0005435311333	20254	Economy	4000.00
0005435311331	20254	Economy	4000.00
0005434408461	20254	Economy	4000.00
0005435311343	20254	Economy	4000.00
0005434408667	20254	Economy	4000.00
0005435311318	20254	Economy	4000.00
0005435311325	20254	Economy	4000.00
0005434408507	20254	Economy	4000.00
0005434408220	20254	Economy	4000.00
0005434408668	20254	Economy	4000.00
0005435311344	20254	Economy	4000.00
0005434408367	20254	Economy	4000.00
0005434408570	20254	Economy	4000.00
0005434408609	20254	Economy	4000.00
0005434408556	20254	Economy	4000.00
0005435311338	20254	Economy	4000.00
0005434408743	20254	Economy	4000.00
0005434408642	20254	Economy	4000.00
0005435311321	20254	Economy	4000.00
0005435311351	20254	Economy	4000.00
0005435311352	20254	Economy	4000.00
0005434408429	20254	Economy	4000.00
0005434408648	20254	Economy	4000.00
0005435311319	20254	Economy	4000.00
0005434408278	20254	Economy	4000.00
0005434408692	20254	Economy	4000.00
0005434408267	20254	Economy	4000.00
0005434408272	20254	Economy	4000.00
0005434408413	20254	Economy	4000.00
0005434408165	20254	Economy	4000.00
0005435311324	20254	Economy	4000.00
0005434408571	20254	Economy	4000.00
0005435311346	20254	Economy	4000.00
0005434408472	20254	Economy	4000.00
0005434408345	20254	Economy	4000.00
0005434408740	20254	Economy	4000.00
0005434408248	20254	Economy	4000.00
0005432058465	20254	Economy	4000.00
0005434408430	20254	Economy	4000.00
0005435311332	20254	Economy	4000.00
0005435311336	20254	Economy	4000.00
0005435311340	20254	Economy	4000.00
0005432058462	20254	Economy	4000.00
0005435311347	20254	Economy	4000.00
0005435311322	20254	Economy	4000.00
0005435311353	20254	Economy	4000.00
0005435311327	20254	Economy	4000.00
0005435311350	20254	Economy	4000.00
0005435311345	20254	Economy	4000.00
0005434408593	20254	Economy	4000.00
0005434409082	27010	Business	12000.00
0005434409090	27010	Business	12000.00
0005435311164	27010	Business	12000.00
0005432154081	27010	Business	12000.00
0005434409050	27010	Business	12000.00
0005434409085	27010	Business	12000.00
0005432154085	27010	Business	12000.00
0005434409068	27010	Business	12000.00
0005435311176	27010	Business	12000.00
0005434409051	27010	Business	12000.00
0005434409071	27010	Business	12000.00
0005434409069	27010	Business	12000.00
0005434409062	27010	Economy	4000.00
0005435311187	27010	Economy	4000.00
0005435311143	27010	Economy	4000.00
0005435311142	27010	Economy	4000.00
0005432154083	27010	Economy	4000.00
0005434409059	27010	Economy	4000.00
0005434409036	27010	Economy	4000.00
0005434409079	27010	Economy	4000.00
0005434409070	27010	Economy	4000.00
0005432154079	27010	Economy	4400.00
0005434409087	27010	Economy	4400.00
0005434409093	27010	Economy	4400.00
0005434409052	27010	Economy	4400.00
0005434409075	27010	Economy	4000.00
0005434409066	27010	Economy	4000.00
0005434409040	27010	Economy	4000.00
0005434409042	27010	Economy	4000.00
0005434409094	27010	Economy	4000.00
0005434409054	27010	Economy	4000.00
0005434409043	27010	Economy	4000.00
0005435311163	27010	Economy	4000.00
0005434409058	27010	Economy	4000.00
0005434409063	27010	Economy	4000.00
0005434409048	27010	Economy	4000.00
0005434409041	27010	Economy	4000.00
0005434409037	27010	Economy	4000.00
0005434409034	27010	Economy	4000.00
0005432154084	27010	Economy	4000.00
0005434409060	27010	Economy	4000.00
0005434409056	27010	Economy	4000.00
0005434409035	27010	Economy	4000.00
0005434409083	27010	Economy	4000.00
0005434409046	27010	Economy	4000.00
0005435311170	27010	Economy	4000.00
0005435311171	27010	Economy	4000.00
0005434409089	27010	Economy	4000.00
0005434409086	27010	Economy	4000.00
0005434409064	27010	Economy	4000.00
0005432154080	27010	Economy	4000.00
0005435311196	27010	Economy	4000.00
0005434409049	27010	Economy	4000.00
0005435311199	27010	Economy	4000.00
0005434409065	27010	Economy	4000.00
0005434409047	27010	Economy	4000.00
0005434409084	27010	Economy	4000.00
0005434409077	27010	Economy	4000.00
0005434409032	27010	Economy	4000.00
0005434409053	27010	Economy	4000.00
0005432154082	27010	Economy	4000.00
0005434409072	27010	Economy	4000.00
0005434409067	27010	Economy	4000.00
0005434409092	27010	Economy	4000.00
0005434409055	27010	Economy	4000.00
0005434409081	27010	Economy	4000.00
0005434409061	27010	Economy	4000.00
0005435311165	27010	Economy	4000.00
0005434409076	27010	Economy	4000.00
0005435311183	27010	Economy	4000.00
0005435311177	27010	Economy	4000.00
0005434409080	27010	Economy	4000.00
0005434409091	27010	Economy	4000.00
0005434409030	27010	Economy	4000.00
0005435311175	27010	Economy	4000.00
0005434409044	27010	Economy	4000.00
0005434409074	27010	Economy	4000.00
0005435311141	27010	Economy	4000.00
0005434409038	27010	Economy	4000.00
0005434409033	27010	Economy	4000.00
0005434409088	27010	Economy	4000.00
0005434409073	27010	Economy	4000.00
0005434409078	27010	Economy	4000.00
0005434409039	27010	Economy	4000.00
0005434409057	27010	Economy	4000.00
0005434409031	27010	Economy	4000.00
0005434409045	27010	Economy	4000.00
0005434319677	5685	Business	43300.00
0005433124200	5685	Business	43300.00
0005433124147	5685	Business	43300.00
0005433124154	5685	Business	43300.00
0005433124080	5685	Business	43300.00
0005433124211	5685	Economy	14400.00
0005433124203	5685	Economy	14400.00
0005433124173	5685	Economy	14400.00
0005432109760	5685	Economy	14400.00
0005433124212	5685	Economy	14400.00
0005433124067	5685	Economy	15900.00
0005434319679	5685	Economy	14400.00
0005433124115	5685	Economy	14400.00
0005433124228	5685	Economy	14400.00
0005433124148	5685	Economy	14400.00
0005434319675	5685	Economy	14400.00
0005433124066	5685	Economy	14400.00
0005434319676	5685	Economy	14400.00
0005432109759	5685	Economy	14400.00
0005434311260	5685	Economy	14400.00
0005433124121	5685	Economy	14400.00
0005434319672	5685	Economy	14400.00
0005433124168	5685	Economy	14400.00
0005433124174	5685	Economy	14400.00
0005432109761	5685	Economy	14400.00
0005433124210	5685	Economy	14400.00
0005434319678	5685	Economy	14400.00
0005433124079	5685	Economy	14400.00
0005433124201	5685	Economy	14400.00
0005434319674	5685	Economy	14400.00
0005433124204	5685	Economy	14400.00
0005433124175	5685	Economy	14400.00
0005434319673	5685	Economy	14400.00
0005433124144	5685	Economy	14400.00
0005433124098	5685	Economy	14400.00
0005434311259	5685	Economy	14400.00
0005433124116	5685	Economy	14400.00
0005433124120	5685	Economy	14400.00
0005435297354	15653	Business	43300.00
0005434319583	15653	Business	43300.00
0005434319559	15653	Business	43300.00
0005435297357	15653	Business	43300.00
0005433124353	15653	Business	43300.00
0005433124364	15653	Business	43300.00
0005434319548	15653	Economy	14400.00
0005434319501	15653	Economy	14400.00
0005433124351	15653	Economy	14400.00
0005434319610	15653	Economy	14400.00
0005435297358	15653	Economy	14400.00
0005434311249	15653	Economy	14400.00
0005433124357	15653	Economy	14400.00
0005434312345	15653	Economy	14400.00
0005433124354	15653	Economy	14400.00
0005434319600	15653	Economy	14400.00
0005433124360	15653	Economy	14400.00
0005433124355	15653	Economy	14400.00
0005434319536	15653	Economy	14400.00
0005434319604	15653	Economy	14400.00
0005435297363	15653	Economy	14400.00
0005434311243	15653	Economy	14400.00
0005434319554	15653	Economy	14400.00
0005433124362	15653	Economy	14400.00
0005433124361	15653	Economy	14400.00
0005433124352	15653	Economy	14400.00
0005433124349	15653	Economy	14400.00
0005434319555	15653	Economy	14400.00
0005434319531	15653	Economy	14400.00
0005434319578	15653	Economy	14400.00
0005433124350	15653	Economy	14400.00
0005433124358	15653	Economy	14400.00
0005435297356	15653	Economy	14400.00
0005434319601	15653	Economy	14400.00
0005435297362	15653	Economy	14400.00
0005435297361	15653	Economy	14400.00
0005433124356	15653	Economy	14400.00
0005435297360	15653	Economy	14400.00
0005433124363	15653	Economy	14400.00
0005435297359	15653	Economy	14400.00
0005434312344	15653	Economy	14400.00
0005433124359	15653	Economy	14400.00
0005435297355	15653	Economy	14400.00
0005433124348	15653	Economy	14400.00
0005435220364	31749	Economy	15500.00
0005435219246	31749	Economy	15500.00
0005435220503	31749	Economy	15500.00
0005435219245	31749	Economy	15500.00
0005435220508	31749	Economy	15500.00
0005435220506	31749	Economy	15500.00
0005435220507	31749	Economy	15500.00
0005435220505	31749	Economy	15500.00
0005435219244	31749	Economy	15500.00
0005435220504	31749	Economy	15500.00
0005435220365	31749	Economy	15500.00
0005435220363	31749	Economy	15500.00
0005434484484	8998	Economy	27400.00
0005434189251	8998	Economy	27400.00
0005434189252	8998	Economy	27400.00
0005434189244	8998	Economy	27400.00
0005434189248	8998	Economy	24900.00
0005434484486	8998	Economy	24900.00
0005434484485	8998	Economy	24900.00
0005434189242	8998	Economy	24900.00
0005434189243	8998	Economy	24900.00
0005434484483	8998	Economy	24900.00
0005434484482	8998	Economy	24900.00
0005434189235	8998	Economy	24900.00
0005434189297	16662	Economy	27400.00
0005434189295	16662	Economy	27400.00
0005434189296	16662	Economy	24900.00
0005434484396	16662	Economy	24900.00
0005434484428	16662	Economy	24900.00
0005434484429	16662	Economy	24900.00
0005434484432	16662	Economy	24900.00
0005434484397	16662	Economy	24900.00
0005434189299	16662	Economy	24900.00
0005434189300	16662	Economy	24900.00
0005434484395	16662	Economy	24900.00
0005434189298	16662	Economy	24900.00
0005434484394	16662	Economy	24900.00
0005434484419	16662	Economy	24900.00
0005433124357	7561	Business	11100.00
0005433124362	7561	Business	11100.00
0005433722288	7561	Business	11100.00
0005433722281	7561	Business	11100.00
0005433722279	7561	Economy	3700.00
0005433124352	7561	Economy	4100.00
0005433722295	7561	Economy	4100.00
0005433722308	7561	Economy	4100.00
0005433124354	7561	Economy	3700.00
0005433124348	7561	Economy	3700.00
0005433722303	7561	Economy	3700.00
0005433124363	7561	Economy	3700.00
0005433124361	7561	Economy	3700.00
0005433124351	7561	Economy	3700.00
0005433124355	7561	Economy	3700.00
0005433722285	7561	Economy	3700.00
0005433124350	7561	Economy	3700.00
0005433124349	7561	Economy	3700.00
0005433722307	7561	Economy	3700.00
0005433124353	7561	Economy	3700.00
0005433124356	7561	Economy	3700.00
0005433124360	7561	Economy	3700.00
0005433722294	7561	Economy	3700.00
0005433124364	7561	Economy	3700.00
0005433124358	7561	Economy	3700.00
0005433124359	7561	Economy	3700.00
0005433722302	7561	Economy	3700.00
0005432693702	7557	Business	11100.00
0005432693725	7557	Business	11100.00
0005432693721	7557	Business	11100.00
0005432721447	7557	Business	11100.00
0005432721455	7557	Business	11100.00
0005432693695	7557	Business	11100.00
0005432693709	7557	Business	11100.00
0005432693717	7557	Business	11100.00
0005432721460	7557	Business	11100.00
0005433450408	7557	Business	11100.00
0005432721471	7557	Economy	3700.00
0005432693722	7557	Economy	3700.00
0005433450410	7557	Economy	3700.00
0005432721451	7557	Economy	3700.00
0005432693704	7557	Economy	3700.00
0005432721453	7557	Economy	3700.00
0005432693718	7557	Economy	3700.00
0005432693703	7557	Economy	3700.00
0005432693700	7557	Economy	3700.00
0005433450414	7557	Economy	4100.00
0005432693696	7557	Economy	4100.00
0005433450425	7557	Economy	4100.00
0005432721469	7557	Economy	4100.00
0005432071634	7557	Economy	4100.00
0005432693711	7557	Economy	3700.00
0005432721449	7557	Economy	3700.00
0005432693724	7557	Economy	3700.00
0005432071635	7557	Economy	3700.00
0005433450427	7557	Economy	3700.00
0005432693723	7557	Economy	3700.00
0005432693720	7557	Economy	3700.00
0005432071633	7557	Economy	3700.00
0005433450420	7557	Economy	3700.00
0005432721457	7557	Economy	3700.00
0005432721467	7557	Economy	3700.00
0005433450426	7557	Economy	3700.00
0005433450421	7557	Economy	3700.00
0005432721462	7557	Economy	3700.00
0005433450418	7557	Economy	3700.00
0005432721458	7557	Economy	3700.00
0005432721459	7557	Economy	3700.00
0005433450409	7557	Economy	3700.00
0005433450422	7557	Economy	3700.00
0005432721466	7557	Economy	3700.00
0005432721470	7557	Economy	3700.00
0005433450415	7557	Economy	3700.00
0005432693707	7557	Economy	3700.00
0005433450430	7557	Economy	3700.00
0005432721465	7557	Economy	3700.00
0005433450429	7557	Economy	3700.00
0005432721446	7557	Economy	3700.00
0005432721464	7557	Economy	3700.00
0005433450407	7557	Economy	3700.00
0005432693713	7557	Economy	3700.00
0005433450419	7557	Economy	3700.00
0005432693698	7557	Economy	3700.00
0005433450424	7557	Economy	3700.00
0005432721468	7557	Economy	3700.00
0005432721448	7557	Economy	3700.00
0005432721463	7557	Economy	3700.00
0005432693697	7557	Economy	3700.00
0005432693712	7557	Economy	3700.00
0005432693719	7557	Economy	3700.00
0005432721461	7557	Economy	3700.00
0005433450423	7557	Economy	3700.00
0005432693726	7557	Economy	3700.00
0005433450413	7557	Economy	3700.00
0005432693699	7557	Economy	3700.00
0005432721450	7557	Economy	3700.00
0005433450428	7557	Economy	3700.00
0005432693710	7557	Economy	3700.00
0005432693708	7557	Economy	3700.00
0005433450411	7557	Economy	3700.00
0005433450412	7557	Economy	3700.00
0005432693714	7557	Economy	3700.00
0005433450417	7557	Economy	3700.00
0005433450416	7557	Economy	3700.00
0005432721456	7557	Economy	3700.00
0005432693715	7557	Economy	3700.00
0005432693701	7557	Economy	3700.00
0005432721452	7557	Economy	3700.00
0005432721454	7557	Economy	3700.00
0005432693706	7557	Economy	3700.00
0005432693705	7557	Economy	3700.00
0005432693716	7557	Economy	3700.00
0005432693459	30426	Business	11100.00
0005433450271	30426	Business	11100.00
0005433450251	30426	Business	11100.00
0005433450142	30426	Business	11100.00
0005433450269	30426	Business	11100.00
0005432693291	30426	Economy	3700.00
0005433450112	30426	Economy	3700.00
0005433450313	30426	Economy	3700.00
0005433450263	30426	Economy	3700.00
0005433450174	30426	Economy	3700.00
0005432693461	30426	Economy	3700.00
0005432693348	30426	Economy	4100.00
0005432693340	30426	Economy	4100.00
0005433450309	30426	Economy	4100.00
0005432693429	30426	Economy	3700.00
0005432693506	30426	Economy	3700.00
0005432693316	30426	Economy	3700.00
0005432693179	30426	Economy	3700.00
0005433450256	30426	Economy	3700.00
0005432693390	30426	Economy	3700.00
0005433450186	30426	Economy	3700.00
0005433450128	30426	Economy	3700.00
0005433450270	30426	Economy	3700.00
0005432693335	30426	Economy	3700.00
0005433450293	30426	Economy	3700.00
0005432693352	30426	Economy	3700.00
0005433450187	30426	Economy	3700.00
0005433450188	30426	Economy	3700.00
0005433450260	30426	Economy	3700.00
0005433450241	30426	Economy	3700.00
0005432693378	30426	Economy	3700.00
0005433450129	30426	Economy	3700.00
0005432693462	30426	Economy	3700.00
0005433450143	30426	Economy	3700.00
0005432693482	30426	Economy	3700.00
0005433450173	30426	Economy	3700.00
0005432693394	30426	Economy	3700.00
0005432693380	30426	Economy	3700.00
0005433450197	30426	Economy	3700.00
0005433450198	30426	Economy	3700.00
0005432693427	30426	Economy	3700.00
0005432693417	30426	Economy	3700.00
0005432693178	30426	Economy	3700.00
0005433450308	30426	Economy	3700.00
0005432693414	30426	Economy	3700.00
0005433450294	30426	Economy	3700.00
0005433450192	30426	Economy	3700.00
0005433450235	30426	Economy	3700.00
0005433450312	30426	Economy	3700.00
0005433450218	30426	Economy	3700.00
0005432693500	30426	Economy	3700.00
0005433450194	30426	Economy	3700.00
0005432693180	30426	Economy	3700.00
0005432693420	30426	Economy	3700.00
0005432693411	30426	Economy	3700.00
0005433450203	30426	Economy	3700.00
0005432693351	30426	Economy	3700.00
0005432693505	30426	Economy	3700.00
0005432693460	30426	Economy	3700.00
0005433450266	30426	Economy	3700.00
0005432693260	30426	Economy	3700.00
0005432721246	30427	Business	11100.00
0005433124148	30427	Business	11100.00
0005432721328	30427	Business	11100.00
0005433124200	30427	Business	11100.00
0005432721061	30427	Business	11100.00
0005433124210	30427	Business	11100.00
0005433124174	30427	Business	11100.00
0005432721227	30427	Business	11100.00
0005433124121	30427	Business	11100.00
0005432721294	30427	Economy	3700.00
0005432721207	30427	Economy	3700.00
0005433124098	30427	Economy	3700.00
0005433124147	30427	Economy	3700.00
0005432721373	30427	Economy	3700.00
0005432721244	30427	Economy	3700.00
0005432721343	30427	Economy	3700.00
0005433722354	30427	Economy	4100.00
0005433124066	30427	Economy	4100.00
0005433722352	30427	Economy	4100.00
0005432721296	30427	Economy	4100.00
0005432721133	30427	Economy	3700.00
0005433124080	30427	Economy	3700.00
0005432721385	30427	Economy	3700.00
0005432721235	30427	Economy	3700.00
0005432721327	30427	Economy	3700.00
0005432721228	30427	Economy	3700.00
0005432721386	30427	Economy	3700.00
0005432721266	30427	Economy	3700.00
0005432721250	30427	Economy	3700.00
0005432721280	30427	Economy	3700.00
0005432721281	30427	Economy	3700.00
0005432721295	30427	Economy	3700.00
0005433124173	30427	Economy	3700.00
0005433124079	30427	Economy	3700.00
0005433124067	30427	Economy	3700.00
0005433124204	30427	Economy	3700.00
0005433124203	30427	Economy	3700.00
0005433124175	30427	Economy	3700.00
0005433124211	30427	Economy	3700.00
0005433124201	30427	Economy	3700.00
0005433124168	30427	Economy	3700.00
0005433124116	30427	Economy	3700.00
0005433722355	30427	Economy	3700.00
0005433722353	30427	Economy	3700.00
0005433124144	30427	Economy	3700.00
0005432721274	30427	Economy	3700.00
0005432721206	30427	Economy	3700.00
0005432721245	30427	Economy	3700.00
0005433124120	30427	Economy	3700.00
0005433124228	30427	Economy	3700.00
0005432721217	30427	Economy	3700.00
0005432721216	30427	Economy	3700.00
0005432721265	30427	Economy	3700.00
0005432721353	30427	Economy	3700.00
0005433124115	30427	Economy	3700.00
0005432721285	30427	Economy	3700.00
0005433124212	30427	Economy	3700.00
0005433124154	30427	Economy	3700.00
0005432721226	30427	Economy	3700.00
0005432721100	30427	Economy	3700.00
0005432928064	1380	Business	70400.00
0005433193262	1380	Business	70400.00
0005433525265	1380	Business	70400.00
0005433193204	1380	Business	70400.00
0005434587139	1380	Business	70400.00
0005434587147	1380	Business	70400.00
0005434587151	1380	Business	70400.00
0005434587145	1380	Business	70400.00
0005433193226	1380	Business	70400.00
0005433525262	1380	Economy	23500.00
0005433193198	1380	Business	70400.00
0005433724902	1380	Economy	23500.00
0005434587143	1380	Economy	23500.00
0005432928031	1380	Economy	23500.00
0005434587144	1380	Economy	23500.00
0005432271062	1380	Economy	23500.00
0005432928036	1380	Economy	23500.00
0005433193205	1380	Economy	23500.00
0005433193258	1380	Economy	25800.00
0005432968876	1380	Economy	25800.00
0005432928039	1380	Economy	25800.00
0005434587137	1380	Economy	25800.00
0005434587152	1380	Economy	23500.00
0005434587138	1380	Economy	23500.00
0005434587155	1380	Economy	23500.00
0005433724903	1380	Economy	23500.00
0005433193224	1380	Economy	23500.00
0005433525263	1380	Economy	23500.00
0005432928038	1380	Economy	23500.00
0005434587131	1380	Economy	23500.00
0005434515022	1380	Economy	23500.00
0005434587140	1380	Economy	23500.00
0005434515021	1380	Economy	23500.00
0005433525264	1380	Economy	23500.00
0005434587134	1380	Economy	23500.00
0005433193166	1380	Economy	23500.00
0005434587154	1380	Economy	23500.00
0005433193192	1380	Economy	23500.00
0005432271063	1380	Economy	23500.00
0005432928067	1380	Economy	23500.00
0005433525266	1380	Economy	23500.00
0005433193209	1380	Economy	23500.00
0005434587153	1380	Economy	23500.00
0005433193239	1380	Economy	23500.00
0005433525267	1380	Economy	23500.00
0005432928065	1380	Economy	23500.00
0005434587146	1380	Economy	23500.00
0005434587132	1380	Economy	23500.00
0005434513634	1380	Economy	23500.00
0005432928066	1380	Economy	23500.00
0005432928052	1380	Economy	23500.00
0005434587142	1380	Economy	23500.00
0005432271064	1380	Economy	23500.00
0005433193210	1380	Economy	23500.00
0005433724899	1380	Economy	23500.00
0005433525269	1380	Economy	23500.00
0005434587141	1380	Economy	23500.00
0005433525268	1380	Economy	23500.00
0005433525261	1380	Economy	23500.00
0005434513635	1380	Economy	23500.00
0005433193263	1380	Economy	23500.00
0005433724900	1380	Economy	23500.00
0005433724901	1380	Economy	23500.00
0005433193165	1380	Economy	23500.00
0005433193199	1380	Economy	23500.00
0005434587135	1380	Economy	23500.00
0005434513633	1380	Economy	23500.00
0005434587150	1380	Economy	23500.00
0005434587149	1380	Economy	23500.00
0005434587156	1380	Economy	23500.00
0005434587148	1380	Economy	23500.00
0005434587136	1380	Economy	23500.00
0005434587133	1380	Economy	23500.00
0005433193225	1380	Economy	23500.00
0005433193203	1380	Economy	23500.00
0005434586983	18541	Business	70400.00
0005433193323	18541	Business	70400.00
0005433724866	18541	Business	70400.00
0005434587001	18541	Business	70400.00
0005434586853	18541	Business	70400.00
0005434586947	18541	Business	70400.00
0005433525135	18541	Business	70400.00
0005433525153	18541	Business	70400.00
0005433193327	18541	Business	70400.00
0005434586742	18541	Economy	23500.00
0005434586821	18541	Economy	23500.00
0005434515002	18541	Economy	23500.00
0005434587049	18541	Economy	23500.00
0005433724851	18541	Economy	23500.00
0005433525107	18541	Economy	23500.00
0005434515003	18541	Economy	23500.00
0005434586956	18541	Economy	23500.00
0005433193325	18541	Economy	25800.00
0005434586988	18541	Economy	25800.00
0005432968888	18541	Economy	25800.00
0005432928093	18541	Economy	25800.00
0005433193317	18541	Economy	23500.00
0005434586840	18541	Economy	23500.00
0005434586935	18541	Economy	23500.00
0005433724855	18541	Economy	23500.00
0005433193315	18541	Economy	23500.00
0005432928095	18541	Economy	23500.00
0005433525126	18541	Economy	23500.00
0005434586743	18541	Economy	23500.00
0005433724870	18541	Economy	23500.00
0005434586765	18541	Economy	23500.00
0005433525154	18541	Economy	23500.00
0005434586971	18541	Economy	23500.00
0005433193318	18541	Economy	23500.00
0005433193324	18541	Economy	23500.00
0005433525174	18541	Economy	23500.00
0005434586930	18541	Economy	23500.00
0005434586961	18541	Economy	23500.00
0005434514988	18541	Economy	23500.00
0005434586841	18541	Economy	23500.00
0005433724871	18541	Economy	23500.00
0005434586990	18541	Economy	23500.00
0005434586900	18541	Economy	23500.00
0005433193321	18541	Economy	23500.00
0005434587058	18541	Economy	23500.00
0005434586917	18541	Economy	23500.00
0005434586933	18541	Economy	23500.00
0005433525189	18541	Economy	23500.00
0005434586916	18541	Economy	23500.00
0005433525134	18541	Economy	23500.00
0005432968886	18541	Economy	23500.00
0005434586926	18541	Economy	23500.00
0005433525149	18541	Economy	23500.00
0005434586915	18541	Economy	23500.00
0005434586936	18541	Economy	23500.00
0005433193329	18541	Economy	23500.00
0005434586894	18541	Economy	23500.00
0005433193319	18541	Economy	23500.00
0005432928092	18541	Economy	23500.00
0005433525133	18541	Economy	23500.00
0005434586903	18541	Economy	23500.00
0005432928097	18541	Economy	23500.00
0005433193328	18541	Economy	23500.00
0005434514987	18541	Economy	23500.00
0005433193322	18541	Economy	23500.00
0005434586976	18541	Economy	23500.00
0005433724867	18541	Economy	23500.00
0005434586946	18541	Economy	23500.00
0005434586932	18541	Economy	23500.00
0005433193320	18541	Economy	23500.00
0005432968887	18541	Economy	23500.00
0005432928096	18541	Economy	23500.00
0005433525172	18541	Economy	23500.00
0005433193326	18541	Economy	23500.00
0005434586921	18541	Economy	23500.00
0005433724852	18541	Economy	23500.00
0005433525168	18541	Economy	23500.00
0005434586955	18541	Economy	23500.00
0005434514992	18541	Economy	23500.00
0005432928094	18541	Economy	23500.00
0005433525142	18541	Economy	23500.00
0005433724868	18541	Economy	23500.00
0005433193316	18541	Economy	23500.00
0005435305033	11454	Economy	4300.00
0005434142696	11454	Economy	4300.00
0005434344912	11454	Economy	4300.00
0005435305031	11454	Economy	4300.00
0005435302233	11454	Economy	4000.00
0005435302234	11454	Economy	4000.00
0005434344901	11454	Economy	4000.00
0005434344924	11454	Economy	4000.00
0005434344906	11454	Economy	4000.00
0005434344927	11454	Economy	4000.00
0005434344897	11454	Economy	4000.00
0005434344916	11454	Economy	4000.00
0005434344908	11454	Economy	4000.00
0005434142694	11454	Economy	4000.00
0005434344903	11454	Economy	4000.00
0005434142695	11454	Economy	4000.00
0005435302253	11454	Economy	4000.00
0005434344913	11454	Economy	4000.00
0005434344904	11454	Economy	4000.00
0005434344905	11454	Economy	4000.00
0005434344895	11454	Economy	4000.00
0005434344898	11454	Economy	4000.00
0005435305035	11454	Economy	4000.00
0005434344920	11454	Economy	4000.00
0005434344929	11454	Economy	4000.00
0005434344928	11454	Economy	4000.00
0005434344907	11454	Economy	4000.00
0005434344899	11454	Economy	4000.00
0005434344922	11454	Economy	4000.00
0005434344894	11454	Economy	4000.00
0005434344921	11454	Economy	4000.00
0005434344915	11454	Economy	4000.00
0005434344918	11454	Economy	4000.00
0005434344909	11454	Economy	4000.00
0005434344902	11454	Economy	4000.00
0005434344917	11454	Economy	4000.00
0005435305040	11454	Economy	4000.00
0005434344926	11454	Economy	4000.00
0005434344914	11454	Economy	4000.00
0005434344910	11454	Economy	4000.00
0005434344896	11454	Economy	4000.00
0005434344923	11454	Economy	4000.00
0005435302232	11454	Economy	4000.00
0005434344893	11454	Economy	4000.00
0005434344919	11454	Economy	4000.00
0005434142693	11454	Economy	4000.00
0005434344925	11454	Economy	4000.00
0005434344911	11454	Economy	4000.00
0005434344900	11454	Economy	4000.00
0005434142692	11454	Economy	4000.00
0005434344441	29795	Economy	4300.00
0005434344637	29795	Economy	4300.00
0005434344581	29795	Economy	4300.00
0005434344519	29795	Economy	4300.00
0005434344520	29795	Economy	4000.00
0005434344723	29795	Economy	4000.00
0005434344640	29795	Economy	4000.00
0005435304244	29795	Economy	4000.00
0005434344328	29795	Economy	4000.00
0005434142641	29795	Economy	4000.00
0005434344660	29795	Economy	4000.00
0005434344440	29795	Economy	4000.00
0005435305054	29795	Economy	4000.00
0005434344721	29795	Economy	4000.00
0005434142642	29795	Economy	4000.00
0005434344627	29795	Economy	4000.00
0005434344722	29795	Economy	4000.00
0005434344546	29795	Economy	4000.00
0005434344619	29795	Economy	4000.00
0005434344630	29795	Economy	4000.00
0005435304243	29795	Economy	4000.00
0005434344614	29795	Economy	4000.00
0005435304242	29795	Economy	4000.00
0005434344639	29795	Economy	4000.00
0005434344547	29795	Economy	4000.00
0005434344521	29795	Economy	4000.00
0005434344498	29795	Economy	4000.00
0005435304246	29795	Economy	4000.00
0005434344541	29795	Economy	4000.00
0005434344659	29795	Economy	4000.00
0005434344550	29795	Economy	4000.00
0005434344542	29795	Economy	4000.00
0005434344618	29795	Economy	4000.00
0005434142647	29795	Economy	4000.00
0005434344551	29795	Economy	4000.00
0005434142643	29795	Economy	4000.00
0005434142646	29795	Economy	4000.00
0005434344716	29795	Economy	4000.00
0005434344645	29795	Economy	4000.00
0005435304245	29795	Economy	4000.00
0005435304247	29795	Economy	4000.00
0005434344578	29795	Economy	4000.00
0005434344548	29795	Economy	4000.00
0005434344646	29795	Economy	4000.00
0005434344580	29795	Economy	4000.00
0005434344620	29795	Economy	4000.00
0005434344514	29795	Economy	4000.00
0005434142654	29795	Economy	4000.00
0005434344613	29795	Economy	4000.00
0005434344669	29795	Economy	4000.00
0005433415900	1288	Business	199800.00
0005433415908	1288	Business	199800.00
0005435825175	1288	Business	199800.00
0005433415888	1288	Business	199800.00
0005433415915	1288	Business	199800.00
0005435825192	1288	Business	199800.00
0005435825190	1288	Business	199800.00
0005433415860	1288	Business	199800.00
0005435825195	1288	Business	199800.00
0005433415823	1288	Economy	66600.00
0005433415858	1288	Economy	66600.00
0005432284619	1288	Economy	66600.00
0005435825182	1288	Economy	66600.00
0005435825181	1288	Economy	66600.00
0005435825173	1288	Economy	66600.00
0005435825186	1288	Economy	66600.00
0005433415952	1288	Economy	73200.00
0005435825189	1288	Economy	66600.00
0005433415909	1288	Economy	66600.00
0005435825172	1288	Economy	66600.00
0005433415794	1288	Economy	66600.00
0005432284618	1288	Economy	66600.00
0005435825174	1288	Economy	66600.00
0005435825184	1288	Economy	66600.00
0005435825178	1288	Economy	66600.00
0005435825176	1288	Economy	66600.00
0005433415887	1288	Economy	66600.00
0005435825188	1288	Economy	66600.00
0005432284621	1288	Economy	66600.00
0005433415914	1288	Economy	66600.00
0005435825170	1288	Economy	66600.00
0005433415951	1288	Economy	66600.00
0005433415896	1288	Economy	66600.00
0005435825177	1288	Economy	66600.00
0005435825171	1288	Economy	66600.00
0005435825185	1288	Economy	66600.00
0005435825180	1288	Economy	66600.00
0005435825183	1288	Economy	66600.00
0005433415899	1288	Economy	66600.00
0005435825179	1288	Economy	66600.00
0005435825191	1288	Economy	66600.00
0005435825187	1288	Economy	66600.00
0005435825193	1288	Economy	66600.00
0005433415793	1288	Economy	66600.00
0005433415897	1288	Economy	66600.00
0005433415898	1288	Economy	66600.00
0005435825169	1288	Economy	66600.00
0005432284620	1288	Economy	66600.00
0005435825194	1288	Economy	66600.00
0005435824877	18016	Business	199800.00
0005435824948	18016	Business	199800.00
0005435824836	18016	Business	199800.00
0005435824855	18016	Business	199800.00
0005433415983	18016	Business	199800.00
0005435825018	18016	Business	199800.00
0005433415985	18016	Economy	66600.00
0005435824876	18016	Economy	66600.00
0005435825025	18016	Economy	66600.00
0005433415996	18016	Economy	66600.00
0005433415988	18016	Economy	66600.00
0005435824965	18016	Economy	66600.00
0005435824966	18016	Economy	73200.00
0005433415995	18016	Economy	73200.00
0005433415989	18016	Economy	66600.00
0005433415986	18016	Economy	66600.00
0005433415984	18016	Economy	66600.00
0005435824930	18016	Economy	66600.00
0005435824922	18016	Economy	66600.00
0005435825034	18016	Economy	66600.00
0005433415994	18016	Economy	66600.00
0005435824835	18016	Economy	66600.00
0005433415993	18016	Economy	66600.00
0005435824991	18016	Economy	66600.00
0005433415997	18016	Economy	66600.00
0005435824976	18016	Economy	66600.00
0005435824997	18016	Economy	66600.00
0005435825017	18016	Economy	66600.00
0005433415982	18016	Economy	66600.00
0005435824923	18016	Economy	66600.00
0005433415987	18016	Economy	66600.00
0005435824860	18016	Economy	66600.00
0005435824728	18016	Economy	66600.00
0005435824929	18016	Economy	66600.00
0005435824998	18016	Economy	66600.00
0005435824837	18016	Economy	66600.00
0005435824918	18016	Economy	66600.00
0005433415991	18016	Economy	66600.00
0005433415990	18016	Economy	66600.00
0005433415992	18016	Economy	66600.00
0005432784913	5625	Business	27800.00
0005432784931	5625	Business	27800.00
0005432784908	5625	Business	27800.00
0005432784926	5625	Business	27800.00
0005435243036	5625	Business	27800.00
0005432784878	5625	Business	27800.00
0005432784925	5625	Business	27800.00
0005432784890	5625	Business	27800.00
0005435243102	5625	Business	27800.00
0005432784919	5625	Business	27800.00
0005435243161	5625	Business	27800.00
0005435243157	5625	Economy	9300.00
0005432784879	5625	Economy	9300.00
0005432784895	5625	Economy	9300.00
0005432784914	5625	Economy	9300.00
0005432784892	5625	Economy	9300.00
0005432784906	5625	Economy	9300.00
0005432784884	5625	Economy	9300.00
0005435243171	5625	Economy	9300.00
0005435243187	5625	Economy	9300.00
0005432784921	5625	Economy	9300.00
0005435243126	5625	Economy	10200.00
0005432784922	5625	Economy	10200.00
0005432784898	5625	Economy	10200.00
0005432784894	5625	Economy	10200.00
0005432784915	5625	Economy	10200.00
0005435243182	5625	Economy	9300.00
0005432784905	5625	Economy	9300.00
0005432784902	5625	Economy	9300.00
0005435243083	5625	Economy	9300.00
0005432784909	5625	Economy	9300.00
0005432784877	5625	Economy	9300.00
0005435243253	5625	Economy	9300.00
0005432784910	5625	Economy	9300.00
0005432144055	5625	Economy	9300.00
0005435243156	5625	Economy	9300.00
0005435243030	5625	Economy	9300.00
0005432784888	5625	Economy	9300.00
0005435243140	5625	Economy	9300.00
0005432784911	5625	Economy	9300.00
0005432784916	5625	Economy	9300.00
0005435243148	5625	Economy	9300.00
0005435243169	5625	Economy	9300.00
0005432784927	5625	Economy	9300.00
0005432784923	5625	Economy	9300.00
0005435243078	5625	Economy	9300.00
0005435243163	5625	Economy	9300.00
0005432784900	5625	Economy	9300.00
0005432784886	5625	Economy	9300.00
0005435243196	5625	Economy	9300.00
0005432784887	5625	Economy	9300.00
0005432784896	5625	Economy	9300.00
0005432784918	5625	Economy	9300.00
0005435243098	5625	Economy	9300.00
0005435243209	5625	Economy	9300.00
0005435243198	5625	Economy	9300.00
0005435243079	5625	Economy	9300.00
0005432784882	5625	Economy	9300.00
0005432784885	5625	Economy	9300.00
0005435243197	5625	Economy	9300.00
0005432784893	5625	Economy	9300.00
0005435243146	5625	Economy	9300.00
0005432784917	5625	Economy	9300.00
0005432784899	5625	Economy	9300.00
0005432144054	5625	Economy	9300.00
0005435243195	5625	Economy	9300.00
0005435243141	5625	Economy	9300.00
0005435243168	5625	Economy	9300.00
0005432144056	5625	Economy	9300.00
0005432784930	5625	Economy	9300.00
0005432784881	5625	Economy	9300.00
0005432784903	5625	Economy	9300.00
0005432784907	5625	Economy	9300.00
0005432784883	5625	Economy	9300.00
0005435243188	5625	Economy	9300.00
0005432784912	5625	Economy	9300.00
0005435243075	5625	Economy	9300.00
0005435243035	5625	Economy	9300.00
0005435243160	5625	Economy	9300.00
0005432784904	5625	Economy	9300.00
0005432784897	5625	Economy	9300.00
0005432784880	5625	Economy	9300.00
0005435243145	5625	Economy	9300.00
0005432784929	5625	Economy	9300.00
0005435243172	5625	Economy	9300.00
0005432784889	5625	Economy	9300.00
0005432784901	5625	Economy	9300.00
0005432784928	5625	Economy	9300.00
0005432784924	5625	Economy	9300.00
0005432784891	5625	Economy	9300.00
0005435243170	5625	Economy	9300.00
0005435243101	5625	Economy	9300.00
0005435243147	5625	Economy	9300.00
0005432784920	5625	Economy	9300.00
0005432784479	15394	Business	27800.00
0005432784366	15394	Business	27800.00
0005432784626	15394	Business	27800.00
0005432784282	15394	Business	27800.00
0005435243380	15394	Business	27800.00
0005435476898	15394	Business	27800.00
0005435243389	15394	Business	27800.00
0005432784223	15394	Business	27800.00
0005432784625	15394	Business	27800.00
0005432784468	15394	Business	27800.00
0005435243387	15394	Business	27800.00
0005432784491	15394	Business	27800.00
0005435243378	15394	Economy	9300.00
0005432784222	15394	Economy	9300.00
0005432784373	15394	Economy	9300.00
0005435243375	15394	Economy	9300.00
0005435476897	15394	Economy	9300.00
0005432784357	15394	Economy	9300.00
0005432784272	15394	Economy	9300.00
0005432784418	15394	Economy	9300.00
0005435243374	15394	Economy	10200.00
0005432784446	15394	Economy	10200.00
0005432784511	15394	Economy	10200.00
0005432784532	15394	Economy	10200.00
0005432784354	15394	Economy	10200.00
0005435243390	15394	Economy	9300.00
0005432784353	15394	Economy	9300.00
0005432784361	15394	Economy	9300.00
0005435243388	15394	Economy	9300.00
0005435243385	15394	Economy	9300.00
0005435243396	15394	Economy	9300.00
0005435243386	15394	Economy	9300.00
0005435243398	15394	Economy	9300.00
0005435243377	15394	Economy	9300.00
0005432784467	15394	Economy	9300.00
0005432784455	15394	Economy	9300.00
0005432784352	15394	Economy	9300.00
0005435243395	15394	Economy	9300.00
0005432784315	15394	Economy	9300.00
0005432784322	15394	Economy	9300.00
0005435243392	15394	Economy	9300.00
0005435243376	15394	Economy	9300.00
0005432784399	15394	Economy	9300.00
0005435243379	15394	Economy	9300.00
0005435476901	15394	Economy	9300.00
0005432784365	15394	Economy	9300.00
0005432784324	15394	Economy	9300.00
0005435243391	15394	Economy	9300.00
0005435476896	15394	Economy	9300.00
0005435476906	15394	Economy	9300.00
0005432784493	15394	Economy	9300.00
0005432784544	15394	Economy	9300.00
0005432784480	15394	Economy	9300.00
0005435243393	15394	Economy	9300.00
0005435243382	15394	Economy	9300.00
0005432784318	15394	Economy	9300.00
0005432784435	15394	Economy	9300.00
0005435476899	15394	Economy	9300.00
0005432784415	15394	Economy	9300.00
0005435476902	15394	Economy	9300.00
0005432784277	15394	Economy	9300.00
0005435476900	15394	Economy	9300.00
0005435243394	15394	Economy	9300.00
0005432784350	15394	Economy	9300.00
0005435243381	15394	Economy	9300.00
0005432784260	15394	Economy	9300.00
0005435476905	15394	Economy	9300.00
0005432784264	15394	Economy	9300.00
0005435476908	15394	Economy	9300.00
0005432784355	15394	Economy	9300.00
0005432784398	15394	Economy	9300.00
0005432784492	15394	Economy	9300.00
0005432784430	15394	Economy	9300.00
0005435243384	15394	Economy	9300.00
0005432784134	15394	Economy	9300.00
0005435476907	15394	Economy	9300.00
0005435476903	15394	Economy	9300.00
0005432784252	15394	Economy	9300.00
0005432784510	15394	Economy	9300.00
0005432784423	15394	Economy	9300.00
0005435243397	15394	Economy	9300.00
0005432784424	15394	Economy	9300.00
0005432784351	15394	Economy	9300.00
0005435243383	15394	Economy	9300.00
0005432784185	15394	Economy	9300.00
0005432784273	15394	Economy	9300.00
0005435243399	15394	Economy	9300.00
0005432784476	15394	Economy	9300.00
0005435476904	15394	Economy	9300.00
0005432784431	15394	Economy	9300.00
0005432848613	4343	Economy	6300.00
0005434463974	4343	Economy	6300.00
0005432848607	4343	Economy	6300.00
0005432848615	4343	Economy	6300.00
0005432848609	4343	Economy	6300.00
0005435851006	4343	Economy	6300.00
0005432848608	4343	Economy	6300.00
0005432848610	4343	Economy	6300.00
0005435850991	4343	Economy	6300.00
0005435851028	4343	Economy	6300.00
0005432848618	4343	Economy	6300.00
0005435851056	4343	Economy	6300.00
0005432848606	4343	Economy	6300.00
0005435850973	4343	Economy	6300.00
0005435850974	4343	Economy	6300.00
0005432848612	4343	Economy	6300.00
0005432848605	4343	Economy	6300.00
0005434462834	4343	Economy	6300.00
0005435851036	4343	Economy	6300.00
0005432848611	4343	Economy	6300.00
0005432848617	4343	Economy	6300.00
0005432848614	4343	Economy	6300.00
0005434462835	4343	Economy	6300.00
0005435851035	4343	Economy	6300.00
0005435850969	4343	Economy	6300.00
0005432848616	4343	Economy	6300.00
0005432848487	28851	Economy	7000.00
0005435851098	28851	Economy	7000.00
0005432848539	28851	Economy	6300.00
0005434461671	28851	Economy	6300.00
0005432848496	28851	Economy	6300.00
0005435851097	28851	Economy	6300.00
0005435851100	28851	Economy	6300.00
0005434461676	28851	Economy	6300.00
0005434461670	28851	Economy	6300.00
0005435851099	28851	Economy	6300.00
0005434461668	28851	Economy	6300.00
0005432848495	28851	Economy	6300.00
0005435851102	28851	Economy	6300.00
0005432848474	28851	Economy	6300.00
0005432848471	28851	Economy	6300.00
0005432848515	28851	Economy	6300.00
0005432848506	28851	Economy	6300.00
0005435851095	28851	Economy	6300.00
0005435851094	28851	Economy	6300.00
0005435851101	28851	Economy	6300.00
0005432848540	28851	Economy	6300.00
0005432848449	28851	Economy	6300.00
0005434461669	28851	Economy	6300.00
0005435851096	28851	Economy	6300.00
0005432848514	28851	Economy	6300.00
0005432848516	28851	Economy	6300.00
0005432848435	28851	Economy	6300.00
0005432075302	6274	Business	11900.00
0005433497607	6274	Business	11900.00
0005434926462	6274	Business	11900.00
0005433497626	6274	Business	11900.00
0005434444040	6274	Business	11900.00
0005434926446	6274	Business	11900.00
0005433497618	6274	Business	11900.00
0005434926466	6274	Business	11900.00
0005434444052	6274	Business	11900.00
0005434444051	6274	Business	11900.00
0005434926450	6274	Economy	4000.00
0005434444041	6274	Economy	4000.00
0005434926449	6274	Economy	4000.00
0005433497609	6274	Economy	4000.00
0005433497615	6274	Economy	4000.00
0005434444048	6274	Economy	4000.00
0005433497611	6274	Economy	4000.00
0005434926454	6274	Economy	4000.00
0005433497632	6274	Economy	4000.00
0005434444047	6274	Economy	4400.00
0005434926453	6274	Economy	4400.00
0005434926467	6274	Economy	4400.00
0005433497608	6274	Economy	4400.00
0005434444038	6274	Economy	4400.00
0005433497610	6274	Economy	4000.00
0005433497628	6274	Economy	4000.00
0005433497627	6274	Economy	4000.00
0005433497604	6274	Economy	4000.00
0005433497620	6274	Economy	4000.00
0005434926441	6274	Economy	4000.00
0005432075301	6274	Economy	4000.00
0005434444042	6274	Economy	4000.00
0005434926464	6274	Economy	4000.00
0005433497612	6274	Economy	4000.00
0005433497622	6274	Economy	4000.00
0005434926444	6274	Economy	4000.00
0005433497616	6274	Economy	4000.00
0005434444050	6274	Economy	4000.00
0005434926452	6274	Economy	4000.00
0005434444043	6274	Economy	4000.00
0005434444039	6274	Economy	4000.00
0005434926459	6274	Economy	4000.00
0005434926448	6274	Economy	4000.00
0005434926469	6274	Economy	4000.00
0005434926461	6274	Economy	4000.00
0005433497602	6274	Economy	4000.00
0005433497614	6274	Economy	4000.00
0005434444045	6274	Economy	4000.00
0005434444036	6274	Economy	4000.00
0005433497623	6274	Economy	4000.00
0005433497603	6274	Economy	4000.00
0005434444044	6274	Economy	4000.00
0005434926470	6274	Economy	4000.00
0005434926440	6274	Economy	4000.00
0005434926451	6274	Economy	4000.00
0005434926456	6274	Economy	4000.00
0005433497630	6274	Economy	4000.00
0005434926473	6274	Economy	4000.00
0005433497605	6274	Economy	4000.00
0005434444049	6274	Economy	4000.00
0005434926474	6274	Economy	4000.00
0005434926447	6274	Economy	4000.00
0005433497625	6274	Economy	4000.00
0005434926472	6274	Economy	4000.00
0005432075303	6274	Economy	4000.00
0005433497606	6274	Economy	4000.00
0005434444037	6274	Economy	4000.00
0005433497629	6274	Economy	4000.00
0005433497601	6274	Economy	4000.00
0005434926455	6274	Economy	4000.00
0005433497621	6274	Economy	4000.00
0005433497617	6274	Economy	4000.00
0005434926468	6274	Economy	4000.00
0005432075300	6274	Economy	4000.00
0005434926442	6274	Economy	4000.00
0005433497619	6274	Economy	4000.00
0005434926460	6274	Economy	4000.00
0005433497624	6274	Economy	4000.00
0005434444046	6274	Economy	4000.00
0005434926445	6274	Economy	4000.00
0005434926443	6274	Economy	4000.00
0005434926457	6274	Economy	4000.00
0005433497631	6274	Economy	4000.00
0005434926458	6274	Economy	4000.00
0005433497613	6274	Economy	4000.00
0005434926465	6274	Economy	4000.00
0005434444053	6274	Economy	4000.00
0005434926471	6274	Economy	4000.00
0005434926463	6274	Economy	4000.00
0005435257417	20372	Business	11900.00
0005435257420	20372	Business	11900.00
0005435257419	20372	Economy	4000.00
0005435257418	20372	Economy	4000.00
0005435257421	20372	Economy	4000.00
0005435257422	20372	Economy	4000.00
0005435257414	20372	Economy	4000.00
0005435257416	20372	Economy	4000.00
0005435257415	20372	Economy	4000.00
0005434443921	20370	Business	11900.00
0005434443920	20370	Business	11900.00
0005433497455	20370	Business	11900.00
0005434443878	20370	Business	11900.00
0005433497434	20370	Business	11900.00
0005434926089	20370	Business	11900.00
0005434926092	20370	Business	11900.00
0005434443952	20370	Business	11900.00
0005434443801	20370	Business	11900.00
0005433497374	20370	Economy	4000.00
0005433497393	20370	Economy	4000.00
0005433497460	20370	Economy	4000.00
0005433497376	20370	Economy	4000.00
0005434926106	20370	Economy	4000.00
0005434443917	20370	Economy	4000.00
0005433497389	20370	Economy	4000.00
0005434926132	20370	Economy	4000.00
0005433497371	20370	Economy	4400.00
0005434925982	20370	Economy	4400.00
0005434443885	20370	Economy	4400.00
0005434926124	20370	Economy	4400.00
0005434443932	20370	Economy	4400.00
0005434926090	20370	Economy	4000.00
0005433497441	20370	Economy	4000.00
0005434926098	20370	Economy	4000.00
0005434926091	20370	Economy	4000.00
0005433497357	20370	Economy	4000.00
0005434926075	20370	Economy	4000.00
0005434443916	20370	Economy	4000.00
0005433497343	20370	Economy	4000.00
0005433497240	20370	Economy	4000.00
0005434443800	20370	Economy	4000.00
0005434926116	20370	Economy	4000.00
0005433497415	20370	Economy	4000.00
0005434443911	20370	Economy	4000.00
0005433497322	20370	Economy	4000.00
0005433497442	20370	Economy	4000.00
0005433497497	20370	Economy	4000.00
0005434443877	20370	Economy	4000.00
0005434926087	20370	Economy	4000.00
0005434926141	20370	Economy	4000.00
0005433497456	20370	Economy	4000.00
0005434443929	20370	Economy	4000.00
0005433497218	20370	Economy	4000.00
0005433497293	20370	Economy	4000.00
0005434443807	20370	Economy	4000.00
0005434926148	20370	Economy	4000.00
0005434926088	20370	Economy	4000.00
0005433497241	20370	Economy	4000.00
0005433497380	20370	Economy	4000.00
0005434443884	20370	Economy	4000.00
0005434925981	20370	Economy	4000.00
0005434926144	20370	Economy	4000.00
0005433497394	20370	Economy	4000.00
0005433497390	20370	Economy	4000.00
0005434926082	20370	Economy	4000.00
0005434443890	20370	Economy	4000.00
0005434443900	20370	Economy	4000.00
0005434926020	20370	Economy	4000.00
0005433497337	20370	Economy	4000.00
0005433497344	20370	Economy	4000.00
0005434443799	20370	Economy	4000.00
0005434926045	20370	Economy	4000.00
0005433497396	20370	Economy	4000.00
0005434926086	20370	Economy	4000.00
0005433497475	20370	Economy	4000.00
0005433497527	20370	Economy	4000.00
0005433497414	20370	Economy	4000.00
0005434443935	20370	Economy	4000.00
0005433497375	20370	Economy	4000.00
0005433497406	20370	Economy	4000.00
0005434926068	20370	Economy	4000.00
0005434926019	20370	Economy	4000.00
0005434443869	20370	Economy	4000.00
0005433497419	20370	Economy	4000.00
0005433497370	20370	Economy	4000.00
0005433497329	20370	Economy	4000.00
0005434443931	20370	Economy	4000.00
0005434443891	20370	Economy	4000.00
0005434926107	20370	Economy	4000.00
0005433497346	20370	Economy	4000.00
0005434926149	20370	Economy	4000.00
0005433497328	20370	Economy	4000.00
0005434443930	20370	Economy	4000.00
0005433497526	20370	Economy	4000.00
0005433497345	20370	Economy	4000.00
0005433497381	20370	Economy	4000.00
0005435243420	12176	Business	41200.00
0005435243415	12176	Business	41200.00
0005432784454	12176	Business	41200.00
0005432784407	12176	Business	41200.00
0005432784595	12176	Business	41200.00
0005432784596	12176	Business	41200.00
0005432784471	12176	Business	41200.00
0005435243401	12176	Business	41200.00
0005435243408	12176	Business	41200.00
0005432784447	12176	Business	41200.00
0005432784472	12176	Business	41200.00
0005432784288	12176	Business	41200.00
0005432784658	12176	Economy	13700.00
0005435243416	12176	Economy	13700.00
0005432784230	12176	Economy	13700.00
0005432784634	12176	Economy	13700.00
0005432784503	12176	Economy	13700.00
0005432784522	12176	Economy	13700.00
0005435243403	12176	Economy	13700.00
0005432784523	12176	Economy	13700.00
0005432784536	12176	Economy	15100.00
0005432784332	12176	Economy	15100.00
0005432784397	12176	Economy	15100.00
0005432784526	12176	Economy	15100.00
0005432784158	12176	Economy	15100.00
0005432784289	12176	Economy	13700.00
0005432784396	12176	Economy	13700.00
0005432784627	12176	Economy	13700.00
0005435243406	12176	Economy	13700.00
0005432784250	12176	Economy	13700.00
0005432784400	12176	Economy	13700.00
0005435243427	12176	Economy	13700.00
0005432784618	12176	Economy	13700.00
0005432784323	12176	Economy	13700.00
0005435243404	12176	Economy	13700.00
0005432784654	12176	Economy	13700.00
0005432784147	12176	Economy	13700.00
0005435243423	12176	Economy	13700.00
0005435243400	12176	Economy	13700.00
0005435243407	12176	Economy	13700.00
0005432784473	12176	Economy	13700.00
0005432784598	12176	Economy	13700.00
0005435243411	12176	Economy	13700.00
0005432784463	12176	Economy	13700.00
0005432784320	12176	Economy	13700.00
0005432784427	12176	Economy	13700.00
0005435243409	12176	Economy	13700.00
0005435243402	12176	Economy	13700.00
0005432784587	12176	Economy	13700.00
0005435243413	12176	Economy	13700.00
0005435243410	12176	Economy	13700.00
0005432784453	12176	Economy	13700.00
0005432784470	12176	Economy	13700.00
0005435243414	12176	Economy	13700.00
0005432784217	12176	Economy	13700.00
0005432784494	12176	Economy	13700.00
0005432784659	12176	Economy	13700.00
0005432784367	12176	Economy	13700.00
0005435243412	12176	Economy	13700.00
0005435243418	12176	Economy	13700.00
0005435243422	12176	Economy	13700.00
0005435243424	12176	Economy	13700.00
0005432784566	12176	Economy	13700.00
0005432784540	12176	Economy	13700.00
0005432784409	12176	Economy	13700.00
0005432784448	12176	Economy	13700.00
0005432784567	12176	Economy	13700.00
0005435243405	12176	Economy	13700.00
0005432784521	12176	Economy	13700.00
0005432784305	12176	Economy	13700.00
0005435243426	12176	Economy	13700.00
0005432784449	12176	Economy	13700.00
0005432784469	12176	Economy	13700.00
0005432784609	12176	Economy	13700.00
0005432784319	12176	Economy	13700.00
0005435243419	12176	Economy	13700.00
0005435243425	12176	Economy	13700.00
0005432784389	12176	Economy	13700.00
0005435243421	12176	Economy	13700.00
0005432784330	12176	Economy	13700.00
0005432784610	12176	Economy	13700.00
0005432784512	12176	Economy	13700.00
0005432784594	12176	Economy	13700.00
0005432784249	12176	Economy	13700.00
0005435243417	12176	Economy	13700.00
0005432784872	15452	Business	41200.00
0005435243111	15452	Business	41200.00
0005432784823	15452	Business	41200.00
0005435243059	15452	Business	41200.00
0005432784861	15452	Business	41200.00
0005432784839	15452	Business	41200.00
0005432784875	15452	Business	41200.00
0005432784860	15452	Economy	13700.00
0005432784831	15452	Economy	13700.00
0005432784857	15452	Economy	13700.00
0005432784864	15452	Economy	13700.00
0005432784842	15452	Economy	13700.00
0005432784830	15452	Economy	13700.00
0005432784870	15452	Economy	15100.00
0005432784848	15452	Economy	15100.00
0005432784843	15452	Economy	15100.00
0005435243150	15452	Economy	15100.00
0005435243104	15452	Economy	15100.00
0005432784874	15452	Economy	13700.00
0005432784851	15452	Economy	13700.00
0005432784854	15452	Economy	13700.00
0005432784834	15452	Economy	13700.00
0005432784838	15452	Economy	13700.00
0005432784867	15452	Economy	13700.00
0005432784837	15452	Economy	13700.00
0005435243073	15452	Economy	13700.00
0005432784855	15452	Economy	13700.00
0005432784844	15452	Economy	13700.00
0005432784835	15452	Economy	13700.00
0005435243165	15452	Economy	13700.00
0005432784829	15452	Economy	13700.00
0005432784822	15452	Economy	13700.00
0005432784856	15452	Economy	13700.00
0005435243060	15452	Economy	13700.00
0005435243080	15452	Economy	13700.00
0005435243103	15452	Economy	13700.00
0005432784826	15452	Economy	13700.00
0005435243105	15452	Economy	13700.00
0005432784862	15452	Economy	13700.00
0005432784824	15452	Economy	13700.00
0005432784865	15452	Economy	13700.00
0005435243112	15452	Economy	13700.00
0005435243228	15452	Economy	13700.00
0005432784846	15452	Economy	13700.00
0005432784876	15452	Economy	13700.00
0005435243032	15452	Economy	13700.00
0005432784859	15452	Economy	13700.00
0005432784825	15452	Economy	13700.00
0005432784873	15452	Economy	13700.00
0005432784852	15452	Economy	13700.00
0005432784833	15452	Economy	13700.00
0005432784836	15452	Economy	13700.00
0005432784828	15452	Economy	13700.00
0005432784849	15452	Economy	13700.00
0005435243131	15452	Economy	13700.00
0005432784869	15452	Economy	13700.00
0005432784832	15452	Economy	13700.00
0005432784847	15452	Economy	13700.00
0005432784840	15452	Economy	13700.00
0005435243227	15452	Economy	13700.00
0005432784858	15452	Economy	13700.00
0005432784871	15452	Economy	13700.00
0005435243061	15452	Economy	13700.00
0005435243116	15452	Economy	13700.00
0005432784827	15452	Economy	13700.00
0005432784850	15452	Economy	13700.00
0005432784868	15452	Economy	13700.00
0005432784866	15452	Economy	13700.00
0005432784853	15452	Economy	13700.00
0005432784841	15452	Economy	13700.00
0005432784863	15452	Economy	13700.00
0005432784845	15452	Economy	13700.00
0005434879231	10120	Business	49700.00
0005434879328	10120	Business	49700.00
0005434879611	10120	Business	49700.00
0005434879339	10120	Business	49700.00
0005434879402	10120	Business	49700.00
0005434879656	10120	Business	49700.00
0005434879678	10120	Business	49700.00
0005434879164	10120	Business	49700.00
0005434879453	10120	Business	49700.00
0005434879439	10120	Business	49700.00
0005434879303	10120	Business	49700.00
0005434879166	10120	Business	49700.00
0005434879230	10120	Business	49700.00
0005434879501	10120	Business	49700.00
0005434879426	10120	Business	49700.00
0005434879289	10120	Business	49700.00
0005434879407	10120	Business	49700.00
0005434879500	10120	Business	49700.00
0005434879284	10120	Business	49700.00
0005434879366	10120	Business	49700.00
0005434879625	10120	Economy	16600.00
0005434879433	10120	Economy	16600.00
0005434879071	10120	Economy	16600.00
0005434879215	10120	Economy	16600.00
0005434879519	10120	Economy	16600.00
0005434879249	10120	Economy	16600.00
0005434879360	10120	Economy	16600.00
0005434879329	10120	Economy	16600.00
0005434879681	10120	Economy	16600.00
0005434879118	10120	Economy	16600.00
0005434879568	10120	Economy	16600.00
0005434879270	10120	Economy	16600.00
0005434878797	10120	Economy	16600.00
0005434879459	10120	Economy	18200.00
0005434879287	10120	Economy	18200.00
0005434879488	10120	Economy	18200.00
0005434879255	10120	Economy	16600.00
0005434879250	10120	Economy	18200.00
0005434879126	10120	Economy	16600.00
0005434879682	10120	Economy	16600.00
0005434879595	10120	Economy	16600.00
0005434879346	10120	Economy	16600.00
0005434879666	10120	Economy	16600.00
0005434879608	10120	Economy	16600.00
0005434879334	10120	Economy	16600.00
0005434879494	10120	Economy	16600.00
0005434879369	10120	Economy	16600.00
0005434879139	10120	Economy	16600.00
0005434879504	10120	Economy	16600.00
0005434879406	10120	Economy	16600.00
0005434879322	10120	Economy	16600.00
0005434879152	10120	Economy	16600.00
0005434879610	10120	Economy	16600.00
0005434879546	10120	Economy	16600.00
0005434879846	10120	Economy	16600.00
0005434878879	10120	Economy	16600.00
0005434879253	10120	Economy	16600.00
0005434879313	10120	Economy	16600.00
0005434879251	10120	Economy	16600.00
0005434879340	10120	Economy	16600.00
0005434879569	10120	Economy	16600.00
0005434879547	10120	Economy	16600.00
0005434879508	10120	Economy	16600.00
0005434879767	10120	Economy	16600.00
0005434879589	10120	Economy	16600.00
0005434878958	10120	Economy	16600.00
0005434879035	10120	Economy	16600.00
0005434879640	10120	Economy	16600.00
0005434879140	10120	Economy	16600.00
0005434879304	10120	Economy	16600.00
0005434879117	10120	Economy	16600.00
0005434879288	10120	Economy	16600.00
0005434879370	10120	Economy	16600.00
0005434879321	10120	Economy	16600.00
0005434879697	10120	Economy	16600.00
0005434879348	10120	Economy	16600.00
0005434879254	10120	Economy	16600.00
0005434910159	10120	Economy	16600.00
0005434879499	10120	Economy	16600.00
0005434879367	10120	Economy	16600.00
0005434879290	10120	Economy	16600.00
0005434879677	10120	Economy	16600.00
0005434879471	10120	Economy	16600.00
0005434879341	10120	Economy	16600.00
0005434879476	10120	Economy	16600.00
0005434879286	10120	Economy	16600.00
0005434879403	10120	Economy	16600.00
0005434879151	10120	Economy	16600.00
0005434879588	10120	Economy	16600.00
0005434879354	10120	Economy	16600.00
0005434879466	10120	Economy	16600.00
0005434879380	10120	Economy	16600.00
0005434878947	10120	Economy	16600.00
0005434878949	10120	Economy	16600.00
0005434879073	10120	Economy	16600.00
0005434879520	10120	Economy	16600.00
0005434879379	10120	Economy	16600.00
0005434879847	10120	Economy	16600.00
0005434878888	10120	Economy	16600.00
0005434879698	10120	Economy	16600.00
0005434879506	10120	Economy	16600.00
0005434879181	10120	Economy	16600.00
0005434879440	10120	Economy	16600.00
0005434879609	10120	Economy	16600.00
0005434879285	10120	Economy	16600.00
0005434879766	10120	Economy	16600.00
0005434879355	10120	Economy	16600.00
0005434879498	10120	Economy	16600.00
0005434879432	10120	Economy	16600.00
0005434879427	10120	Economy	16600.00
0005434879502	10120	Economy	16600.00
0005434879318	10120	Economy	16600.00
0005434878798	10120	Economy	16600.00
0005434879378	10120	Economy	16600.00
0005434879163	10120	Economy	16600.00
0005434879371	10120	Economy	16600.00
0005434880118	14653	Business	49700.00
0005434880203	14653	Business	49700.00
0005434880199	14653	Business	49700.00
0005434880141	14653	Business	49700.00
0005434880167	14653	Business	49700.00
0005434880132	14653	Business	49700.00
0005434880129	14653	Business	49700.00
0005434880192	14653	Business	49700.00
0005434880180	14653	Business	49700.00
0005434880176	14653	Business	49700.00
0005434880174	14653	Business	49700.00
0005434880200	14653	Business	49700.00
0005434880135	14653	Business	49700.00
0005434880116	14653	Business	49700.00
0005434880134	14653	Business	49700.00
0005434880204	14653	Business	49700.00
0005434880122	14653	Economy	16600.00
0005434880171	14653	Business	49700.00
0005434758941	14653	Economy	16600.00
0005434910132	14653	Economy	16600.00
0005434880183	14653	Economy	16600.00
0005434880147	14653	Economy	16600.00
0005434880143	14653	Economy	16600.00
0005434880166	14653	Economy	16600.00
0005434910135	14653	Economy	16600.00
0005434880161	14653	Economy	16600.00
0005434880159	14653	Economy	16600.00
0005434880153	14653	Economy	16600.00
0005434880170	14653	Economy	16600.00
0005434880137	14653	Economy	16600.00
0005434880130	14653	Economy	18200.00
0005434880198	14653	Economy	18200.00
0005434880173	14653	Economy	18200.00
0005434880208	14653	Economy	16600.00
0005434880140	14653	Economy	16600.00
0005434880156	14653	Economy	16600.00
0005434880172	14653	Economy	16600.00
0005434880123	14653	Economy	16600.00
0005434880186	14653	Economy	16600.00
0005434880136	14653	Economy	16600.00
0005434880212	14653	Economy	16600.00
0005434880188	14653	Economy	16600.00
0005434880189	14653	Economy	16600.00
0005434880138	14653	Economy	16600.00
0005434880177	14653	Economy	16600.00
0005434880146	14653	Economy	16600.00
0005434880164	14653	Economy	16600.00
0005434880144	14653	Economy	16600.00
0005434880205	14653	Economy	16600.00
0005434880163	14653	Economy	16600.00
0005434880202	14653	Economy	16600.00
0005434880142	14653	Economy	16600.00
0005434880148	14653	Economy	16600.00
0005434880149	14653	Economy	16600.00
0005434880126	14653	Economy	16600.00
0005434880120	14653	Economy	16600.00
0005434880185	14653	Economy	16600.00
0005434880201	14653	Economy	16600.00
0005434880152	14653	Economy	16600.00
0005434880213	14653	Economy	16600.00
0005434880182	14653	Economy	16600.00
0005434880124	14653	Economy	16600.00
0005434880184	14653	Economy	16600.00
0005434880151	14653	Economy	16600.00
0005434880158	14653	Economy	16600.00
0005434880197	14653	Economy	16600.00
0005434880119	14653	Economy	16600.00
0005434880207	14653	Economy	16600.00
0005434880131	14653	Economy	16600.00
0005434880145	14653	Economy	16600.00
0005434880195	14653	Economy	16600.00
0005434758942	14653	Economy	16600.00
0005434880165	14653	Economy	16600.00
0005434880139	14653	Economy	16600.00
0005434880168	14653	Economy	16600.00
0005434880133	14653	Economy	16600.00
0005434880175	14653	Economy	16600.00
0005434880160	14653	Economy	16600.00
0005434880193	14653	Economy	16600.00
0005434880211	14653	Economy	16600.00
0005434880162	14653	Economy	16600.00
0005435913963	14653	Economy	16600.00
0005434880117	14653	Economy	16600.00
0005434880181	14653	Economy	16600.00
0005434880155	14653	Economy	16600.00
0005434880191	14653	Economy	16600.00
0005434880196	14653	Economy	16600.00
0005434880194	14653	Economy	16600.00
0005434880127	14653	Economy	16600.00
0005434880157	14653	Economy	16600.00
0005434880154	14653	Economy	16600.00
0005434880125	14653	Economy	16600.00
0005434880128	14653	Economy	16600.00
0005434880190	14653	Economy	16600.00
0005434880150	14653	Economy	16600.00
0005434880187	14653	Economy	16600.00
0005434880178	14653	Economy	16600.00
0005434880209	14653	Economy	16600.00
0005434880169	14653	Economy	16600.00
0005434880179	14653	Economy	16600.00
0005434910134	14653	Economy	16600.00
0005434880210	14653	Economy	16600.00
0005434880206	14653	Economy	16600.00
0005434758943	14653	Economy	16600.00
0005434880121	14653	Economy	16600.00
0005434252075	9225	Economy	22400.00
0005435660370	9225	Economy	20300.00
0005435660366	9225	Economy	20300.00
0005434252018	9225	Economy	20300.00
0005434252065	9225	Economy	20300.00
0005435660369	9225	Economy	20300.00
0005434252086	9225	Economy	20300.00
0005434252031	9225	Economy	20300.00
0005434252061	9225	Economy	20300.00
0005435660373	9225	Economy	20300.00
0005434252017	9225	Economy	20300.00
0005435660371	9225	Economy	20300.00
0005434252064	9225	Economy	20300.00
0005434252032	9225	Economy	20300.00
0005435660364	9225	Economy	20300.00
0005435660367	9225	Economy	20300.00
0005434252073	9225	Economy	20300.00
0005435660363	9225	Economy	20300.00
0005435660365	9225	Economy	20300.00
0005434252101	9225	Economy	20300.00
0005435660368	9225	Economy	20300.00
0005434252102	9225	Economy	20300.00
0005435660372	9225	Economy	20300.00
0005434252074	9225	Economy	20300.00
0005435660374	9225	Economy	20300.00
0005434252157	24659	Economy	22400.00
0005435660287	24659	Economy	22400.00
0005435660262	24659	Economy	22400.00
0005435660296	24659	Economy	20300.00
0005434252158	24659	Economy	20300.00
0005434252163	24659	Economy	20300.00
0005435660295	24659	Economy	20300.00
0005435660251	24659	Economy	20300.00
0005434252161	24659	Economy	20300.00
0005434252159	24659	Economy	20300.00
0005434252156	24659	Economy	20300.00
0005434252160	24659	Economy	20300.00
0005434252162	24659	Economy	20300.00
0005434252164	24659	Economy	20300.00
0005433681544	2789	Business	33000.00
0005433681550	2789	Business	33000.00
0005433681549	2789	Business	33000.00
0005433681529	2789	Business	33000.00
0005433681539	2789	Business	33000.00
0005433681524	2789	Business	33000.00
0005432967241	2789	Business	33000.00
0005433681518	2789	Business	33000.00
0005433681545	2789	Business	33000.00
0005433681567	2789	Business	33000.00
0005433681563	2789	Business	33000.00
0005433681548	2789	Economy	11000.00
0005432967333	2789	Economy	11000.00
0005433681534	2789	Economy	11000.00
0005433681564	2789	Economy	11000.00
0005432967282	2789	Economy	11000.00
0005433681562	2789	Economy	11000.00
0005432967127	2789	Economy	11000.00
0005432967178	2789	Economy	11000.00
0005432967214	2789	Economy	11000.00
0005433681554	2789	Economy	12100.00
0005432967246	2789	Economy	12100.00
0005433681551	2789	Economy	12100.00
0005432967231	2789	Economy	12100.00
0005433681558	2789	Economy	11000.00
0005432222890	2789	Economy	11000.00
0005432222893	2789	Economy	11000.00
0005432967295	2789	Economy	11000.00
0005432967213	2789	Economy	11000.00
0005432967269	2789	Economy	11000.00
0005432967198	2789	Economy	11000.00
0005432967249	2789	Economy	11000.00
0005433681553	2789	Economy	11000.00
0005432222889	2789	Economy	11000.00
0005432967250	2789	Economy	11000.00
0005432967120	2789	Economy	11000.00
0005433681540	2789	Economy	11000.00
0005433681557	2789	Economy	11000.00
0005432967251	2789	Economy	11000.00
0005432967245	2789	Economy	11000.00
0005432967142	2789	Economy	11000.00
0005433681566	2789	Economy	11000.00
0005432967128	2789	Economy	11000.00
0005433681535	2789	Economy	11000.00
0005432967294	2789	Economy	11000.00
0005433681559	2789	Economy	11000.00
0005432967116	2789	Economy	11000.00
0005433681526	2789	Economy	11000.00
0005432967117	2789	Economy	11000.00
0005432222892	2789	Economy	11000.00
0005433681530	2789	Economy	11000.00
0005433681522	2789	Economy	11000.00
0005432967197	2789	Economy	11000.00
0005433681552	2789	Economy	11000.00
0005432222888	2789	Economy	11000.00
0005433681532	2789	Economy	11000.00
0005433681523	2789	Economy	11000.00
0005432967302	2789	Economy	11000.00
0005433681546	2789	Economy	11000.00
0005433681541	2789	Economy	11000.00
0005433681561	2789	Economy	11000.00
0005433681543	2789	Economy	11000.00
0005433681520	2789	Economy	11000.00
0005433681525	2789	Economy	11000.00
0005433681533	2789	Economy	11000.00
0005432222891	2789	Economy	11000.00
0005432967121	2789	Economy	11000.00
0005433684462	2789	Economy	11000.00
0005432967230	2789	Economy	11000.00
0005433681555	2789	Economy	11000.00
0005433681528	2789	Economy	11000.00
0005433681560	2789	Economy	11000.00
0005433681536	2789	Economy	11000.00
0005433681547	2789	Economy	11000.00
0005433681527	2789	Economy	11000.00
0005433681521	2789	Economy	11000.00
0005432967224	2789	Economy	11000.00
0005432967216	2789	Economy	11000.00
0005432967143	2789	Economy	11000.00
0005433681537	2789	Economy	11000.00
0005433681556	2789	Economy	11000.00
0005433681542	2789	Economy	11000.00
0005433681565	2789	Economy	11000.00
0005432967132	2789	Economy	11000.00
0005433681519	2789	Economy	11000.00
0005433681538	2789	Economy	11000.00
0005432967131	2789	Economy	11000.00
0005432967281	2789	Economy	11000.00
0005433681531	2789	Economy	11000.00
0005433681110	29156	Business	33000.00
0005432967466	29156	Business	33000.00
0005433681314	29156	Business	33000.00
0005433681240	29156	Business	33000.00
0005433681127	29156	Business	33000.00
0005433681126	29156	Business	33000.00
0005433681202	29156	Business	33000.00
0005432967465	29156	Business	33000.00
0005433681068	29156	Business	33000.00
0005433681388	29156	Business	33000.00
0005433681454	29156	Business	33000.00
0005433681210	29156	Economy	11000.00
0005433684441	29156	Economy	11000.00
0005433681118	29156	Economy	11000.00
0005432967453	29156	Economy	11000.00
0005433680985	29156	Economy	11000.00
0005433681081	29156	Economy	11000.00
0005432967455	29156	Economy	11000.00
0005432967469	29156	Economy	11000.00
0005433681272	29156	Economy	11000.00
0005432005270	29156	Economy	12100.00
0005432967448	29156	Economy	12100.00
0005433680798	29156	Economy	12100.00
0005433681122	29156	Economy	12100.00
0005433690956	29156	Economy	12100.00
0005433681143	29156	Economy	11000.00
0005433681117	29156	Economy	11000.00
0005432967461	29156	Economy	11000.00
0005433684442	29156	Economy	11000.00
0005433681128	29156	Economy	11000.00
0005433681163	29156	Economy	11000.00
0005433681367	29156	Economy	11000.00
0005432967459	29156	Economy	11000.00
0005433681315	29156	Economy	11000.00
0005433681059	29156	Economy	11000.00
0005433680902	29156	Economy	11000.00
0005432967462	29156	Economy	11000.00
0005432967454	29156	Economy	11000.00
0005433681090	29156	Economy	11000.00
0005433681067	29156	Economy	11000.00
0005433681455	29156	Economy	11000.00
0005432967457	29156	Economy	11000.00
0005432967447	29156	Economy	11000.00
0005433681183	29156	Economy	11000.00
0005432967467	29156	Economy	11000.00
0005432967450	29156	Economy	11000.00
0005432967460	29156	Economy	11000.00
0005433681151	29156	Economy	11000.00
0005433681112	29156	Economy	11000.00
0005433681164	29156	Economy	11000.00
0005433681102	29156	Economy	11000.00
0005433681193	29156	Economy	11000.00
0005433681273	29156	Economy	11000.00
0005433680984	29156	Economy	11000.00
0005433681281	29156	Economy	11000.00
0005433681123	29156	Economy	11000.00
0005433680894	29156	Economy	11000.00
0005433681229	29156	Economy	11000.00
0005433681066	29156	Economy	11000.00
0005432005271	29156	Economy	11000.00
0005432005272	29156	Economy	11000.00
0005433681152	29156	Economy	11000.00
0005432967446	29156	Economy	11000.00
0005433681125	29156	Economy	11000.00
0005433681087	29156	Economy	11000.00
0005433681203	29156	Economy	11000.00
0005432967451	29156	Economy	11000.00
0005433681185	29156	Economy	11000.00
0005433681030	29156	Economy	11000.00
0005432967456	29156	Economy	11000.00
0005432967468	29156	Economy	11000.00
0005432967452	29156	Economy	11000.00
0005433681060	29156	Economy	11000.00
0005433681058	29156	Economy	11000.00
0005432967471	29156	Economy	11000.00
0005432967449	29156	Economy	11000.00
0005433681184	29156	Economy	11000.00
0005433681212	29156	Economy	11000.00
0005433681158	29156	Economy	11000.00
0005432967458	29156	Economy	11000.00
0005433681119	29156	Economy	11000.00
0005432967470	29156	Economy	11000.00
0005433681168	29156	Economy	11000.00
0005433681142	29156	Economy	11000.00
0005433681113	29156	Economy	11000.00
0005433684446	29156	Economy	11000.00
0005433684445	29156	Economy	11000.00
0005432967463	29156	Economy	11000.00
0005432967464	29156	Economy	11000.00
0005433681387	29156	Economy	11000.00
0005433681029	29156	Economy	11000.00
0005433680998	29156	Economy	11000.00
0005433616128	9270	Business	132900.00
0005433616151	9270	Business	132900.00
0005433616139	9270	Business	132900.00
0005433616148	9270	Business	132900.00
0005434163716	9270	Business	132900.00
0005433578086	9270	Business	132900.00
0005434269123	9270	Business	132900.00
0005433578078	9270	Business	132900.00
0005433634474	9270	Business	132900.00
0005433634483	9270	Business	132900.00
0005433616144	9270	Business	132900.00
0005433634477	9270	Business	132900.00
0005433634485	9270	Business	132900.00
0005433634484	9270	Business	132900.00
0005433634482	9270	Business	132900.00
0005433578089	9270	Business	132900.00
0005433634475	9270	Business	132900.00
0005433616099	9270	Business	132900.00
0005433616155	9270	Business	132900.00
0005434272210	9270	Business	132900.00
0005433634476	9270	Business	132900.00
0005433616112	9270	Business	132900.00
0005433616129	9270	Business	132900.00
0005432755144	9270	Business	132900.00
0005433634495	9270	Economy	48700.00
0005434152815	9270	Economy	48700.00
0005433616090	9270	Economy	48700.00
0005433616124	9270	Economy	48700.00
0005433616088	9270	Economy	48700.00
0005433616119	9270	Economy	44300.00
0005433616085	9270	Economy	44300.00
0005433616140	9270	Economy	44300.00
0005433616134	9270	Economy	44300.00
0005433616136	9270	Economy	44300.00
0005433616146	9270	Economy	44300.00
0005433616098	9270	Economy	44300.00
0005433616123	9270	Economy	44300.00
0005433634472	9270	Economy	44300.00
0005433634490	9270	Economy	44300.00
0005433616101	9270	Economy	44300.00
0005433616113	9270	Economy	44300.00
0005433634470	9270	Economy	44300.00
0005433616108	9270	Economy	44300.00
0005433616149	9270	Economy	44300.00
0005433616109	9270	Economy	44300.00
0005434153545	9270	Economy	44300.00
0005433616138	9270	Economy	44300.00
0005433616116	9270	Economy	44300.00
0005433634491	9270	Economy	44300.00
0005433578077	9270	Economy	44300.00
0005433634479	9270	Economy	44300.00
0005433578087	9270	Economy	44300.00
0005433634493	9270	Economy	44300.00
0005433616127	9270	Economy	44300.00
0005433578083	9270	Economy	44300.00
0005433616096	9270	Economy	44300.00
0005433616111	9270	Economy	44300.00
0005433616141	9270	Economy	44300.00
0005433616110	9270	Economy	44300.00
0005433616135	9270	Economy	44300.00
0005434163742	9270	Economy	44300.00
0005433616142	9270	Economy	44300.00
0005433616133	9270	Economy	44300.00
0005433634488	9270	Economy	44300.00
0005432145151	9270	Economy	44300.00
0005433578082	9270	Economy	44300.00
0005434163741	9270	Economy	44300.00
0005432755142	9270	Economy	44300.00
0005433578080	9270	Economy	44300.00
0005432755143	9270	Economy	44300.00
0005434152811	9270	Economy	44300.00
0005434269124	9270	Economy	44300.00
0005433616103	9270	Economy	44300.00
0005433616114	9270	Economy	44300.00
0005433616093	9270	Economy	44300.00
0005433616091	9270	Economy	44300.00
0005433616121	9270	Economy	44300.00
0005433616104	9270	Economy	44300.00
0005433634480	9270	Economy	48700.00
0005433616082	9270	Economy	48700.00
0005433616105	9270	Economy	48700.00
0005433616107	9270	Economy	48700.00
0005433616097	9270	Economy	44300.00
0005433616083	9270	Economy	44300.00
0005433616102	9270	Economy	44300.00
0005433634494	9270	Economy	44300.00
0005433578081	9270	Economy	48700.00
0005433634473	9270	Economy	44300.00
0005434163732	9270	Economy	44300.00
0005433634500	9270	Economy	44300.00
0005433616132	9270	Economy	44300.00
0005433616143	9270	Economy	44300.00
0005433634498	9270	Economy	44300.00
0005433634489	9270	Economy	44300.00
0005434152812	9270	Economy	44300.00
0005433616092	9270	Economy	44300.00
0005433634481	9270	Economy	44300.00
0005433634496	9270	Economy	44300.00
0005433616115	9270	Economy	44300.00
0005433616086	9270	Economy	44300.00
0005433634478	9270	Economy	44300.00
0005433616094	9270	Economy	44300.00
0005432145152	9270	Economy	44300.00
0005433616117	9270	Economy	44300.00
0005433616100	9270	Economy	44300.00
0005433616150	9270	Economy	44300.00
0005433578084	9270	Economy	44300.00
0005433634486	9270	Economy	44300.00
0005433634471	9270	Economy	44300.00
0005433616084	9270	Economy	44300.00
0005433578088	9270	Economy	44300.00
0005433616087	9270	Economy	44300.00
0005433616126	9270	Economy	44300.00
0005433616137	9270	Economy	44300.00
0005433616125	9270	Economy	44300.00
0005433616106	9270	Economy	44300.00
0005433616081	9270	Economy	44300.00
0005433616154	9270	Economy	44300.00
0005433634492	9270	Economy	44300.00
0005433578079	9270	Economy	44300.00
0005433616118	9270	Economy	44300.00
0005433616122	9270	Economy	44300.00
0005433634503	9270	Economy	44300.00
0005433616152	9270	Economy	44300.00
0005433578085	9270	Economy	44300.00
0005433616147	9270	Economy	44300.00
0005433634497	9270	Economy	44300.00
0005433634502	9270	Economy	44300.00
0005433616130	9270	Economy	44300.00
0005434163718	9270	Economy	44300.00
0005433616089	9270	Economy	44300.00
0005432756916	9270	Economy	44300.00
0005433616153	9270	Economy	44300.00
0005434163684	9270	Economy	44300.00
0005433578090	9270	Economy	44300.00
0005433616120	9270	Economy	44300.00
0005432756914	9270	Economy	44300.00
0005433634499	9270	Economy	44300.00
0005433634487	9270	Economy	44300.00
0005434269122	9270	Economy	44300.00
0005432756915	9270	Economy	44300.00
0005433616145	9270	Economy	44300.00
0005433616095	9270	Economy	44300.00
0005434153544	9270	Economy	44300.00
0005433616131	9270	Economy	44300.00
0005433634501	9270	Economy	44300.00
0005433615546	25262	Business	132900.00
0005433634192	25262	Business	132900.00
0005433615181	25262	Business	132900.00
0005433634191	25262	Business	132900.00
0005433577939	25262	Business	132900.00
0005433615327	25262	Business	132900.00
0005433615451	25262	Business	132900.00
0005433634199	25262	Business	132900.00
0005433634085	25262	Business	132900.00
0005433615792	25262	Business	132900.00
0005433615494	25262	Business	132900.00
0005433615331	25262	Business	132900.00
0005433634152	25262	Business	132900.00
0005433577969	25262	Business	132900.00
0005433634249	25262	Business	132900.00
0005433634241	25262	Business	132900.00
0005433615625	25262	Business	132900.00
0005433615540	25262	Business	132900.00
0005433577970	25262	Business	132900.00
0005433577938	25262	Business	132900.00
0005433615174	25262	Business	132900.00
0005433578022	25262	Business	132900.00
0005433615466	25262	Business	132900.00
0005433615195	25262	Economy	48700.00
0005433615536	25262	Economy	48700.00
0005433615463	25262	Economy	48700.00
0005433634392	25262	Economy	48700.00
0005433633950	25262	Economy	48700.00
0005433577966	25262	Economy	44300.00
0005433615503	25262	Economy	44300.00
0005433634061	25262	Economy	44300.00
0005433634165	25262	Economy	44300.00
0005433634265	25262	Economy	44300.00
0005433615392	25262	Economy	44300.00
0005433578009	25262	Economy	44300.00
0005433615615	25262	Economy	44300.00
0005433578020	25262	Economy	44300.00
0005433615539	25262	Economy	44300.00
0005433615158	25262	Economy	44300.00
0005434163806	25262	Economy	44300.00
0005433615413	25262	Economy	44300.00
0005433615724	25262	Economy	44300.00
0005433615159	25262	Economy	44300.00
0005433577940	25262	Economy	44300.00
0005433615631	25262	Economy	44300.00
0005433615277	25262	Economy	44300.00
0005433615537	25262	Economy	44300.00
0005433634180	25262	Economy	44300.00
0005433634179	25262	Economy	44300.00
0005433634200	25262	Economy	44300.00
0005433615513	25262	Economy	44300.00
0005433634214	25262	Economy	44300.00
0005433615319	25262	Economy	44300.00
0005434163805	25262	Economy	44300.00
0005433634250	25262	Economy	44300.00
0005433577960	25262	Economy	44300.00
0005434163804	25262	Economy	44300.00
0005434163800	25262	Economy	44300.00
0005433634164	25262	Economy	44300.00
0005433615791	25262	Economy	44300.00
0005433615337	25262	Economy	44300.00
0005433634290	25262	Economy	44300.00
0005433577941	25262	Economy	44300.00
0005433615630	25262	Economy	44300.00
0005433615332	25262	Economy	44300.00
0005434163807	25262	Economy	44300.00
0005433615551	25262	Economy	44300.00
0005433634254	25262	Economy	44300.00
0005433615353	25262	Economy	44300.00
0005433578021	25262	Economy	44300.00
0005433577961	25262	Economy	44300.00
0005433634291	25262	Economy	44300.00
0005435854071	25262	Economy	44300.00
0005433615302	25262	Economy	48700.00
0005433634309	25262	Economy	48700.00
0005433634115	25262	Economy	44300.00
0005433615839	25262	Economy	44300.00
0005433615372	25262	Economy	48700.00
0005433634206	25262	Economy	44300.00
0005433615693	25262	Economy	44300.00
0005433615578	25262	Economy	44300.00
0005433577977	25262	Economy	44300.00
0005433615492	25262	Economy	44300.00
0005433634166	25262	Economy	44300.00
0005433615616	25262	Economy	44300.00
0005433615260	25262	Economy	44300.00
0005433634156	25262	Economy	44300.00
0005433615867	25262	Economy	44300.00
0005434273108	25262	Economy	44300.00
0005433634240	25262	Economy	44300.00
0005433634258	25262	Economy	44300.00
0005434163799	25262	Economy	44300.00
0005433615497	25262	Economy	44300.00
0005433615465	25262	Economy	44300.00
0005433615196	25262	Economy	44300.00
0005434163808	25262	Economy	44300.00
0005433615330	25262	Economy	44300.00
0005433634157	25262	Economy	44300.00
0005433634077	25262	Economy	44300.00
0005433615611	25262	Economy	44300.00
0005433634257	25262	Economy	44300.00
0005433615434	25262	Economy	44300.00
0005433615438	25262	Economy	44300.00
0005433615329	25262	Economy	44300.00
0005433615328	25262	Economy	44300.00
0005434163798	25262	Economy	44300.00
0005433615318	25262	Economy	44300.00
0005433615495	25262	Economy	44300.00
0005435854074	25262	Economy	44300.00
0005434163803	25262	Economy	44300.00
0005433615214	25262	Economy	44300.00
0005433615402	25262	Economy	44300.00
0005435854072	25262	Economy	44300.00
0005433615613	25262	Economy	44300.00
0005433577964	25262	Economy	44300.00
0005434163802	25262	Economy	44300.00
0005433634242	25262	Economy	44300.00
0005433615083	25262	Economy	44300.00
0005433577965	25262	Economy	44300.00
0005433615480	25262	Economy	44300.00
0005433615579	25262	Economy	44300.00
0005433615577	25262	Economy	44300.00
0005433634015	25262	Economy	44300.00
0005433615526	25262	Economy	44300.00
0005434163801	25262	Economy	44300.00
0005433577945	25262	Economy	44300.00
0005433634266	25262	Economy	44300.00
0005433615464	25262	Economy	44300.00
0005435854073	25262	Economy	44300.00
0005433634155	25262	Economy	44300.00
0005433634049	25262	Economy	44300.00
0005433615782	25262	Economy	44300.00
0005433615868	25262	Economy	44300.00
0005435856257	4195	Business	193100.00
0005435947398	4195	Business	193100.00
0005432571357	4195	Business	193100.00
0005435986912	4195	Business	193100.00
0005435986913	4195	Business	193100.00
0005435856259	4195	Business	193100.00
0005435947462	4195	Business	193100.00
0005435986909	4195	Business	193100.00
0005432571372	4195	Economy	64400.00
0005435986905	4195	Economy	64400.00
0005435986907	4195	Economy	64400.00
0005435986908	4195	Economy	64400.00
0005434271334	4195	Economy	64400.00
0005435947483	4195	Economy	64400.00
0005435947395	4195	Economy	64400.00
0005435947435	4195	Economy	64400.00
0005435986906	4195	Economy	64400.00
0005435947443	4195	Economy	64400.00
0005435947434	4195	Economy	64400.00
0005435947378	4195	Economy	64400.00
0005435986910	4195	Economy	64400.00
0005435947450	4195	Economy	64400.00
0005435986911	4195	Economy	70800.00
0005435856258	4195	Economy	64400.00
0005435856256	4195	Economy	64400.00
0005435947415	4195	Economy	64400.00
0005432185010	4195	Economy	64400.00
0005432571358	4195	Economy	64400.00
0005435947422	4195	Economy	64400.00
0005432571359	4195	Economy	64400.00
0005435856235	4195	Economy	64400.00
0005435947463	4195	Economy	64400.00
0005435947421	4195	Economy	64400.00
0005432185009	4195	Economy	64400.00
0005435947385	4195	Economy	64400.00
0005435856236	4195	Economy	64400.00
0005435947552	26558	Business	193100.00
0005435947554	26558	Business	193100.00
0005435986849	26558	Business	193100.00
0005435947558	26558	Business	193100.00
0005432571403	26558	Economy	64400.00
0005435856289	26558	Economy	64400.00
0005435947553	26558	Economy	64400.00
0005432571400	26558	Economy	64400.00
0005435947556	26558	Economy	64400.00
0005435947555	26558	Economy	64400.00
0005435947550	26558	Economy	64400.00
0005435947551	26558	Economy	64400.00
0005435856290	26558	Economy	64400.00
0005435856292	26558	Economy	64400.00
0005435787400	26558	Economy	64400.00
0005435986836	26558	Economy	70800.00
0005435787398	26558	Economy	64400.00
0005435947560	26558	Economy	64400.00
0005435947557	26558	Economy	64400.00
0005432571402	26558	Economy	64400.00
0005435986851	26558	Economy	64400.00
0005435947549	26558	Economy	64400.00
0005435947559	26558	Economy	64400.00
0005435856332	26558	Economy	64400.00
0005435787399	26558	Economy	64400.00
0005435947561	26558	Economy	64400.00
0005435986843	26558	Economy	64400.00
0005432571401	26558	Economy	64400.00
0005435986854	26558	Economy	64400.00
0005435986835	26558	Economy	64400.00
0005435947562	26558	Economy	64400.00
0005435856293	26558	Economy	64400.00
0005435986853	26558	Economy	64400.00
0005435856291	26558	Economy	64400.00
0005433075005	327	Business	21500.00
0005432948958	327	Business	21500.00
0005433570355	327	Business	21500.00
0005432948995	327	Business	21500.00
0005433074999	327	Business	21500.00
0005433074910	327	Business	21500.00
0005433570297	327	Business	21500.00
0005433570317	327	Business	21500.00
0005433570335	327	Business	21500.00
0005432239063	327	Business	21500.00
0005433570332	327	Business	21500.00
0005433570294	327	Business	21500.00
0005432948941	327	Business	21500.00
0005433129345	327	Business	21500.00
0005432949024	327	Business	21500.00
0005433570350	327	Business	21500.00
0005432948984	327	Business	21500.00
0005432948999	327	Business	21500.00
0005433075122	327	Business	21500.00
0005433570291	327	Business	21500.00
0005433570344	327	Business	21500.00
0005433570303	327	Business	21500.00
0005433075101	327	Business	21500.00
0005433570312	327	Business	21500.00
0005432948677	327	Business	21500.00
0005433074987	327	Economy	7900.00
0005433570296	327	Economy	7900.00
0005432948881	327	Economy	7900.00
0005433075095	327	Economy	7900.00
0005433570337	327	Economy	7900.00
0005433570301	327	Economy	7900.00
0005433570322	327	Economy	7200.00
0005433570346	327	Economy	7200.00
0005433570334	327	Economy	7200.00
0005433570331	327	Economy	7200.00
0005433570347	327	Economy	7200.00
0005432949043	327	Economy	7200.00
0005433134197	327	Economy	7200.00
0005432948977	327	Economy	7200.00
0005433134189	327	Economy	7200.00
0005432948880	327	Economy	7200.00
0005433134206	327	Economy	7200.00
0005433075098	327	Economy	7200.00
0005432949042	327	Economy	7200.00
0005432948938	327	Economy	7200.00
0005433570307	327	Economy	7200.00
0005433570353	327	Economy	7200.00
0005433570302	327	Economy	7200.00
0005433570349	327	Economy	7200.00
0005433570318	327	Economy	7200.00
0005433570305	327	Economy	7200.00
0005433074994	327	Economy	7200.00
0005433570343	327	Economy	7200.00
0005433134195	327	Economy	7200.00
0005433570311	327	Economy	7200.00
0005432239062	327	Economy	7200.00
0005433570309	327	Economy	7200.00
0005433570321	327	Economy	7200.00
0005432948919	327	Economy	7200.00
0005432949025	327	Economy	7200.00
0005433570329	327	Economy	7200.00
0005432948986	327	Economy	7200.00
0005433075068	327	Economy	7200.00
0005433570314	327	Economy	7200.00
0005432948943	327	Economy	7200.00
0005432948983	327	Economy	7200.00
0005432948910	327	Economy	7200.00
0005432948879	327	Economy	7200.00
0005433570304	327	Economy	7200.00
0005432948855	327	Economy	7200.00
0005433075102	327	Economy	7200.00
0005432948868	327	Economy	7200.00
0005432239064	327	Economy	7200.00
0005433570358	327	Economy	7200.00
0005433570328	327	Economy	7200.00
0005433570326	327	Economy	7200.00
0005433570299	327	Economy	7200.00
0005432239061	327	Economy	7200.00
0005433570325	327	Economy	7200.00
0005432949005	327	Economy	7200.00
0005433075087	327	Economy	7200.00
0005432949045	327	Economy	7900.00
0005433075088	327	Economy	7200.00
0005433570319	327	Economy	7900.00
0005432239060	327	Economy	7900.00
0005432948985	327	Economy	7900.00
0005432948931	327	Economy	7200.00
0005433570345	327	Economy	7200.00
0005432948846	327	Economy	7200.00
0005433570315	327	Economy	7200.00
0005433074967	327	Economy	7900.00
0005433129324	327	Economy	7200.00
0005433570340	327	Economy	7200.00
0005432948969	327	Economy	7200.00
0005432948678	327	Economy	7200.00
0005432948976	327	Economy	7200.00
0005433570320	327	Economy	7200.00
0005433570359	327	Economy	7200.00
0005432948882	327	Economy	7200.00
0005433570357	327	Economy	7200.00
0005433074921	327	Economy	7200.00
0005433570298	327	Economy	7200.00
0005433570308	327	Economy	7200.00
0005433570293	327	Economy	7200.00
0005433570300	327	Economy	7200.00
0005432949041	327	Economy	7200.00
0005433570339	327	Economy	7200.00
0005433570361	327	Economy	7200.00
0005433570354	327	Economy	7200.00
0005433570316	327	Economy	7200.00
0005433074988	327	Economy	7200.00
0005433570342	327	Economy	7200.00
0005432949091	327	Economy	7200.00
0005432948937	327	Economy	7200.00
0005433570336	327	Economy	7200.00
0005432948828	327	Economy	7200.00
0005433570338	327	Economy	7200.00
0005432948812	327	Economy	7200.00
0005432948981	327	Economy	7200.00
0005433570295	327	Economy	7200.00
0005433075020	327	Economy	7200.00
0005433570341	327	Economy	7200.00
0005432948970	327	Economy	7200.00
0005433075133	327	Economy	7200.00
0005432949006	327	Economy	7200.00
0005432949000	327	Economy	7200.00
0005432949040	327	Economy	7200.00
0005432949092	327	Economy	7200.00
0005433075044	327	Economy	7200.00
0005433570351	327	Economy	7200.00
0005432949094	327	Economy	7200.00
0005433570306	327	Economy	7200.00
0005433570348	327	Economy	7200.00
0005432948872	327	Economy	7200.00
0005433075019	327	Economy	7200.00
0005433570356	327	Economy	7200.00
0005433570330	327	Economy	7200.00
0005433129323	327	Economy	7200.00
0005432239065	327	Economy	7200.00
0005433075021	327	Economy	7200.00
0005433570324	327	Economy	7200.00
0005433075070	327	Economy	7200.00
0005433075112	327	Economy	7200.00
0005433570292	327	Economy	7200.00
0005433134190	327	Economy	7200.00
0005433570352	327	Economy	7200.00
0005433570360	327	Economy	7200.00
0005433570333	327	Economy	7200.00
0005433570310	327	Economy	7200.00
0005433570327	327	Economy	7200.00
0005433570323	327	Economy	7200.00
0005433570313	327	Economy	7200.00
0005433134196	327	Economy	7200.00
0005433569683	11614	Business	21500.00
0005433569660	11614	Business	21500.00
0005432949301	11614	Business	21500.00
0005432949305	11614	Business	21500.00
0005433569825	11614	Business	21500.00
0005433569243	11614	Business	21500.00
0005433569383	11614	Business	21500.00
0005433569862	11614	Business	21500.00
0005432949296	11614	Business	21500.00
0005433569604	11614	Business	21500.00
0005433075288	11614	Business	21500.00
0005433075303	11614	Business	21500.00
0005433075279	11614	Business	21500.00
0005433075293	11614	Business	21500.00
0005433569479	11614	Business	21500.00
0005433569613	11614	Business	21500.00
0005432949304	11614	Business	21500.00
0005433569643	11614	Business	21500.00
0005433569714	11614	Business	21500.00
0005432949266	11614	Business	21500.00
0005433134232	11614	Business	21500.00
0005433131804	11614	Business	21500.00
0005433569551	11614	Business	21500.00
0005433569738	11614	Business	21500.00
0005433569559	11614	Business	21500.00
0005433134234	11614	Economy	7900.00
0005433569542	11614	Economy	7900.00
0005433569450	11614	Economy	7900.00
0005433569739	11614	Economy	7900.00
0005433569547	11614	Economy	7900.00
0005432949276	11614	Economy	7900.00
0005432949283	11614	Economy	7200.00
0005432949306	11614	Economy	7200.00
0005433134230	11614	Economy	7200.00
0005433569756	11614	Economy	7200.00
0005432949274	11614	Economy	7200.00
0005433131805	11614	Economy	7200.00
0005432949268	11614	Economy	7200.00
0005432192386	11614	Economy	7200.00
0005432949273	11614	Economy	7200.00
0005433569737	11614	Economy	7200.00
0005433075296	11614	Economy	7200.00
0005432949294	11614	Economy	7200.00
0005433075281	11614	Economy	7200.00
0005433075286	11614	Economy	7200.00
0005432949271	11614	Economy	7200.00
0005433569657	11614	Economy	7200.00
0005433131803	11614	Economy	7200.00
0005432949270	11614	Economy	7200.00
0005432949286	11614	Economy	7200.00
0005433569661	11614	Economy	7200.00
0005432949272	11614	Economy	7200.00
0005433569622	11614	Economy	7200.00
0005433569532	11614	Economy	7200.00
0005433075301	11614	Economy	7200.00
0005432949284	11614	Economy	7200.00
0005433075292	11614	Economy	7200.00
0005432192385	11614	Economy	7200.00
0005433569684	11614	Economy	7200.00
0005433569645	11614	Economy	7200.00
0005433075297	11614	Economy	7200.00
0005433075299	11614	Economy	7200.00
0005432949298	11614	Economy	7200.00
0005433075287	11614	Economy	7200.00
0005433569638	11614	Economy	7200.00
0005433569631	11614	Economy	7200.00
0005432949280	11614	Economy	7200.00
0005433569658	11614	Economy	7200.00
0005433569586	11614	Economy	7200.00
0005432949281	11614	Economy	7200.00
0005433569605	11614	Economy	7200.00
0005432949307	11614	Economy	7200.00
0005433569690	11614	Economy	7200.00
0005432949279	11614	Economy	7200.00
0005433569720	11614	Economy	7200.00
0005433569861	11614	Economy	7200.00
0005433075285	11614	Economy	7200.00
0005433569449	11614	Economy	7200.00
0005432949295	11614	Economy	7200.00
0005433569757	11614	Economy	7200.00
0005433075280	11614	Economy	7900.00
0005433075284	11614	Economy	7900.00
0005432949275	11614	Economy	7900.00
0005433569713	11614	Economy	7900.00
0005433569585	11614	Economy	7900.00
0005433569611	11614	Economy	7200.00
0005432192384	11614	Economy	7200.00
0005432949289	11614	Economy	7900.00
0005433569599	11614	Economy	7200.00
0005433569302	11614	Economy	7200.00
0005433569462	11614	Economy	7200.00
0005433569691	11614	Economy	7200.00
0005433569618	11614	Economy	7200.00
0005432949288	11614	Economy	7200.00
0005433569740	11614	Economy	7200.00
0005433075291	11614	Economy	7200.00
0005432949287	11614	Economy	7200.00
0005433569836	11614	Economy	7200.00
0005433569743	11614	Economy	7200.00
0005433569758	11614	Economy	7200.00
0005432949297	11614	Economy	7200.00
0005433075302	11614	Economy	7200.00
0005433569742	11614	Economy	7200.00
0005433569667	11614	Economy	7200.00
0005432949292	11614	Economy	7200.00
0005433569718	11614	Economy	7200.00
0005433569668	11614	Economy	7200.00
0005433569741	11614	Economy	7200.00
0005433075289	11614	Economy	7200.00
0005432949267	11614	Economy	7200.00
0005433134233	11614	Economy	7200.00
0005433569637	11614	Economy	7200.00
0005432949278	11614	Economy	7200.00
0005433569355	11614	Economy	7200.00
0005432949277	11614	Economy	7200.00
0005432949299	11614	Economy	7200.00
0005433075294	11614	Economy	7200.00
0005433569735	11614	Economy	7200.00
0005432949302	11614	Economy	7200.00
0005433569666	11614	Economy	7200.00
0005433075290	11614	Economy	7200.00
0005432949293	11614	Economy	7200.00
0005433569242	11614	Economy	7200.00
0005432949282	11614	Economy	7200.00
0005432949285	11614	Economy	7200.00
0005432949303	11614	Economy	7200.00
0005433075300	11614	Economy	7200.00
0005433075282	11614	Economy	7200.00
0005433075277	11614	Economy	7200.00
0005433569510	11614	Economy	7200.00
0005433075295	11614	Economy	7200.00
0005433075276	11614	Economy	7200.00
0005433131802	11614	Economy	7200.00
0005433569461	11614	Economy	7200.00
0005433569478	11614	Economy	7200.00
0005433075298	11614	Economy	7200.00
0005433569394	11614	Economy	7200.00
0005433075278	11614	Economy	7200.00
0005432949290	11614	Economy	7200.00
0005432949269	11614	Economy	7200.00
0005432949300	11614	Economy	7200.00
0005433134231	11614	Economy	7200.00
0005433569543	11614	Economy	7200.00
0005433131801	11614	Economy	7200.00
0005433569644	11614	Economy	7200.00
0005432949291	11614	Economy	7200.00
0005433075283	11614	Economy	7200.00
0005433131800	11614	Economy	7200.00
0005433817550	9995	Economy	6300.00
0005433817547	9995	Economy	6300.00
0005433817548	9995	Economy	6300.00
0005433817549	9995	Economy	6300.00
0005433817514	13994	Economy	6300.00
0005434733052	13994	Economy	6300.00
0005433817524	13994	Economy	6300.00
0005433817516	13994	Economy	6300.00
0005433817508	13994	Economy	6300.00
0005433817523	13994	Economy	6300.00
0005434733053	13994	Economy	6300.00
0005433817510	13994	Economy	6300.00
0005434733054	13994	Economy	6300.00
0005433435031	2347	Business	184500.00
0005432985296	2347	Business	184500.00
0005433755367	2347	Business	184500.00
0005435983200	2347	Business	184500.00
0005432985522	2347	Business	184500.00
0005433755392	2347	Business	184500.00
0005435983232	2347	Business	184500.00
0005433755381	2347	Business	184500.00
0005433755376	2347	Business	184500.00
0005435983242	2347	Business	184500.00
0005433755407	2347	Business	184500.00
0005433435100	2347	Business	184500.00
0005433435001	2347	Business	184500.00
0005433755400	2347	Business	184500.00
0005432985537	2347	Business	184500.00
0005433755385	2347	Business	184500.00
0005432985474	2347	Business	184500.00
0005432655787	2347	Business	184500.00
0005433435003	2347	Business	184500.00
0005435983205	2347	Business	184500.00
0005435983221	2347	Business	184500.00
0005432226184	2347	Business	184500.00
0005435983222	2347	Business	184500.00
0005432226185	2347	Business	184500.00
0005432655788	2347	Business	184500.00
0005433755387	2347	Business	184500.00
0005435983229	2347	Business	184500.00
0005432869596	2347	Economy	67700.00
0005433755406	2347	Economy	67700.00
0005432869591	2347	Economy	61500.00
0005433764722	2347	Economy	67700.00
0005432985381	2347	Economy	61500.00
0005433755405	2347	Economy	61500.00
0005433755402	2347	Economy	61500.00
0005433434971	2347	Economy	61500.00
0005435983243	2347	Economy	61500.00
0005433755370	2347	Economy	61500.00
0005435983215	2347	Economy	61500.00
0005435983228	2347	Economy	61500.00
0005433435013	2347	Economy	61500.00
0005432985408	2347	Economy	61500.00
0005432300387	2347	Economy	61500.00
0005433435032	2347	Economy	61500.00
0005433434871	2347	Economy	61500.00
0005435983227	2347	Economy	61500.00
0005435983238	2347	Economy	61500.00
0005432985445	2347	Economy	61500.00
0005435983220	2347	Economy	61500.00
0005433755368	2347	Economy	61500.00
0005433755384	2347	Economy	61500.00
0005433755396	2347	Economy	61500.00
0005433755373	2347	Economy	61500.00
0005433755355	2347	Economy	61500.00
0005433755388	2347	Economy	61500.00
0005435983240	2347	Economy	61500.00
0005432985431	2347	Economy	61500.00
0005432655789	2347	Economy	61500.00
0005432655781	2347	Economy	61500.00
0005433755397	2347	Economy	61500.00
0005433755403	2347	Economy	61500.00
0005432655780	2347	Economy	61500.00
0005433755359	2347	Economy	61500.00
0005433755382	2347	Economy	61500.00
0005432985539	2347	Economy	61500.00
0005435983225	2347	Economy	61500.00
0005432226187	2347	Economy	61500.00
0005433755369	2347	Economy	61500.00
0005435983236	2347	Economy	61500.00
0005432985440	2347	Economy	61500.00
0005432985509	2347	Economy	61500.00
0005433435028	2347	Economy	61500.00
0005432985542	2347	Economy	61500.00
0005435983219	2347	Economy	61500.00
0005433766755	2347	Economy	61500.00
0005435983226	2347	Economy	61500.00
0005432985521	2347	Economy	61500.00
0005432985428	2347	Economy	61500.00
0005433755366	2347	Economy	61500.00
0005433434977	2347	Economy	61500.00
0005432985455	2347	Economy	61500.00
0005432985499	2347	Economy	61500.00
0005433755404	2347	Economy	61500.00
0005435983206	2347	Economy	61500.00
0005433755399	2347	Economy	61500.00
0005433764721	2347	Economy	61500.00
0005435983237	2347	Economy	61500.00
0005432985487	2347	Economy	61500.00
0005432985441	2347	Economy	61500.00
0005432655783	2347	Economy	61500.00
0005433755383	2347	Economy	61500.00
0005432985551	2347	Economy	61500.00
0005435983213	2347	Economy	61500.00
0005433766754	2347	Economy	61500.00
0005433755391	2347	Economy	61500.00
0005435983231	2347	Economy	61500.00
0005433755393	2347	Economy	61500.00
0005433755377	2347	Economy	61500.00
0005433755386	2347	Economy	61500.00
0005432985463	2347	Economy	61500.00
0005432985449	2347	Economy	61500.00
0005432985486	2347	Economy	61500.00
0005435983194	2347	Economy	61500.00
0005435983230	2347	Economy	61500.00
0005433755361	2347	Economy	61500.00
0005433755408	2347	Economy	61500.00
0005433766718	2347	Economy	61500.00
0005432985446	2347	Economy	61500.00
0005433755398	2347	Economy	61500.00
0005435983203	2347	Economy	61500.00
0005432869597	2347	Economy	61500.00
0005432985448	2347	Economy	61500.00
0005432300384	2347	Economy	61500.00
0005432985541	2347	Economy	61500.00
0005435983202	2347	Economy	61500.00
0005432985511	2347	Economy	61500.00
0005433766717	2347	Economy	61500.00
0005432985437	2347	Economy	61500.00
0005435983197	2347	Economy	61500.00
0005432985385	2347	Economy	61500.00
0005433435101	2347	Economy	61500.00
0005433755363	2347	Economy	61500.00
0005434731214	2347	Economy	61500.00
0005432985390	2347	Economy	61500.00
0005432655782	2347	Economy	61500.00
0005433755374	2347	Economy	61500.00
0005433435023	2347	Economy	61500.00
0005432985473	2347	Economy	67700.00
0005432985389	2347	Economy	67700.00
0005435983204	2347	Economy	61500.00
0005433755379	2347	Economy	61500.00
0005432655785	2347	Economy	67700.00
0005433755378	2347	Economy	61500.00
0005432226188	2347	Economy	67700.00
0005433755356	2347	Economy	61500.00
0005432300386	2347	Economy	61500.00
0005435983224	2347	Economy	61500.00
0005435983218	2347	Economy	61500.00
0005433755390	2347	Economy	61500.00
0005433755364	2347	Economy	61500.00
0005433435093	2347	Economy	61500.00
0005433755360	2347	Economy	61500.00
0005435983210	2347	Economy	61500.00
0005435983209	2347	Economy	61500.00
0005433435180	2347	Economy	61500.00
0005432985432	2347	Economy	61500.00
0005435983214	2347	Economy	61500.00
0005432655784	2347	Economy	61500.00
0005433434917	2347	Economy	61500.00
0005432869604	2347	Economy	61500.00
0005433435094	2347	Economy	61500.00
0005432985423	2347	Economy	61500.00
0005433755357	2347	Economy	61500.00
0005433755372	2347	Economy	61500.00
0005432985475	2347	Economy	61500.00
0005435983241	2347	Economy	61500.00
0005435983198	2347	Economy	61500.00
0005435983216	2347	Economy	61500.00
0005435983199	2347	Economy	61500.00
0005432226186	2347	Economy	61500.00
0005435983212	2347	Economy	61500.00
0005435983234	2347	Economy	61500.00
0005433755365	2347	Economy	61500.00
0005432655786	2347	Economy	61500.00
0005432985515	2347	Economy	61500.00
0005432985433	2347	Economy	61500.00
0005432985421	2347	Economy	61500.00
0005435983235	2347	Economy	61500.00
0005435983208	2347	Economy	61500.00
0005432985472	2347	Economy	61500.00
0005432985384	2347	Economy	61500.00
0005433755380	2347	Economy	61500.00
0005435983211	2347	Economy	61500.00
0005432300382	2347	Economy	61500.00
0005433755389	2347	Economy	61500.00
0005435983207	2347	Economy	61500.00
0005435983233	2347	Economy	61500.00
0005432300385	2347	Economy	61500.00
0005432985447	2347	Economy	61500.00
0005433755354	2347	Economy	61500.00
0005433435022	2347	Economy	61500.00
0005435983195	2347	Economy	61500.00
0005433755395	2347	Economy	61500.00
0005433435016	2347	Economy	61500.00
0005433755401	2347	Economy	61500.00
0005432985351	2347	Economy	61500.00
0005435983201	2347	Economy	61500.00
0005432985350	2347	Economy	61500.00
0005432985337	2347	Economy	61500.00
0005435983239	2347	Economy	61500.00
0005435983223	2347	Economy	61500.00
0005433766719	2347	Economy	61500.00
0005432985454	2347	Economy	61500.00
0005433764723	2347	Economy	61500.00
0005435983217	2347	Economy	61500.00
0005433755353	2347	Economy	61500.00
0005432985550	2347	Economy	61500.00
0005433434970	2347	Economy	61500.00
0005432985531	2347	Economy	61500.00
0005433755394	2347	Economy	61500.00
0005433755362	2347	Economy	61500.00
0005435983196	2347	Economy	61500.00
0005432985380	2347	Economy	61500.00
0005432300383	2347	Economy	61500.00
0005432985383	2347	Economy	61500.00
0005433755358	2347	Economy	61500.00
0005433755371	2347	Economy	61500.00
0005432226189	2347	Economy	61500.00
0005433755375	2347	Economy	61500.00
0005432655779	2347	Economy	61500.00
0005433435070	2347	Economy	61500.00
0005434731256	26190	Business	184500.00
0005432985754	26190	Business	184500.00
0005435982959	26190	Business	184500.00
0005432985740	26190	Business	184500.00
0005435982853	26190	Business	184500.00
0005432655664	26190	Business	184500.00
0005432985733	26190	Business	184500.00
0005432985734	26190	Business	184500.00
0005433435264	26190	Business	184500.00
0005435982770	26190	Business	184500.00
0005432869655	26190	Business	184500.00
0005432655651	26190	Business	184500.00
0005435982677	26190	Business	184500.00
0005432869660	26190	Business	184500.00
0005435982595	26190	Business	184500.00
0005432049538	26190	Business	184500.00
0005435982735	26190	Business	184500.00
0005432985752	26190	Business	184500.00
0005432655654	26190	Business	184500.00
0005432985751	26190	Business	184500.00
0005432655665	26190	Business	184500.00
0005433766678	26190	Business	184500.00
0005432655650	26190	Business	184500.00
0005433435252	26190	Business	184500.00
0005432655641	26190	Business	184500.00
0005433754952	26190	Business	184500.00
0005435983002	26190	Economy	67700.00
0005432985750	26190	Economy	67700.00
0005432985737	26190	Economy	67700.00
0005432655613	26190	Economy	61500.00
0005432985728	26190	Economy	61500.00
0005433754840	26190	Economy	61500.00
0005433754941	26190	Economy	61500.00
0005435982665	26190	Economy	61500.00
0005433754999	26190	Economy	61500.00
0005433754942	26190	Economy	61500.00
0005433754755	26190	Economy	61500.00
0005435982761	26190	Economy	61500.00
0005433754629	26190	Economy	61500.00
0005432985741	26190	Economy	61500.00
0005433755147	26190	Economy	61500.00
0005435983021	26190	Economy	61500.00
0005433435259	26190	Economy	61500.00
0005435982769	26190	Economy	61500.00
0005432985753	26190	Economy	61500.00
0005435982729	26190	Economy	61500.00
0005433754833	26190	Economy	61500.00
0005435982629	26190	Economy	61500.00
0005433435249	26190	Economy	61500.00
0005432985738	26190	Economy	61500.00
0005432049537	26190	Economy	61500.00
0005435982691	26190	Economy	61500.00
0005433754789	26190	Economy	61500.00
0005432655642	26190	Economy	61500.00
0005433435245	26190	Economy	61500.00
0005432869657	26190	Economy	61500.00
0005433755117	26190	Economy	61500.00
0005435982633	26190	Economy	61500.00
0005435982652	26190	Economy	61500.00
0005433435266	26190	Economy	61500.00
0005433754998	26190	Economy	61500.00
0005433435265	26190	Economy	61500.00
0005433754875	26190	Economy	61500.00
0005433435254	26190	Economy	61500.00
0005433435255	26190	Economy	61500.00
0005432985746	26190	Economy	61500.00
0005435982771	26190	Economy	61500.00
0005432985755	26190	Economy	61500.00
0005433754881	26190	Economy	61500.00
0005433435269	26190	Economy	61500.00
0005433754927	26190	Economy	61500.00
0005433754770	26190	Economy	61500.00
0005432985729	26190	Economy	61500.00
0005435982778	26190	Economy	61500.00
0005435982866	26190	Economy	61500.00
0005433435257	26190	Economy	61500.00
0005433754832	26190	Economy	61500.00
0005433755068	26190	Economy	61500.00
0005433754569	26190	Economy	61500.00
0005433755069	26190	Economy	61500.00
0005433754828	26190	Economy	61500.00
0005435982831	26190	Economy	61500.00
0005433754924	26190	Economy	61500.00
0005433754446	26190	Economy	61500.00
0005433754852	26190	Economy	61500.00
0005435982664	26190	Economy	61500.00
0005433435263	26190	Economy	61500.00
0005432985742	26190	Economy	61500.00
0005432869658	26190	Economy	61500.00
0005433754921	26190	Economy	61500.00
0005435982777	26190	Economy	61500.00
0005432985760	26190	Economy	61500.00
0005433755101	26190	Economy	61500.00
0005433754903	26190	Economy	61500.00
0005433754926	26190	Economy	61500.00
0005433435248	26190	Economy	61500.00
0005432985730	26190	Economy	61500.00
0005433435251	26190	Economy	61500.00
0005435982794	26190	Economy	61500.00
0005433754940	26190	Economy	61500.00
0005432985736	26190	Economy	61500.00
0005435982678	26190	Economy	61500.00
0005435982752	26190	Economy	61500.00
0005432655628	26190	Economy	61500.00
0005432985749	26190	Economy	61500.00
0005433754788	26190	Economy	61500.00
0005432985747	26190	Economy	61500.00
0005432985757	26190	Economy	61500.00
0005435982776	26190	Economy	61500.00
0005433755057	26190	Economy	61500.00
0005432985727	26190	Economy	61500.00
0005433755067	26190	Economy	61500.00
0005433435246	26190	Economy	67700.00
0005433435273	26190	Economy	61500.00
0005435982651	26190	Economy	67700.00
0005432655655	26190	Economy	61500.00
0005432985744	26190	Economy	61500.00
0005432049539	26190	Economy	61500.00
0005433754965	26190	Economy	67700.00
0005432985743	26190	Economy	67700.00
0005432869656	26190	Economy	61500.00
0005432869661	26190	Economy	61500.00
0005433754841	26190	Economy	61500.00
0005433754827	26190	Economy	61500.00
0005433754876	26190	Economy	61500.00
0005433435260	26190	Economy	61500.00
0005434731258	26190	Economy	61500.00
0005434731257	26190	Economy	61500.00
0005433435258	26190	Economy	61500.00
0005435983003	26190	Economy	61500.00
0005433435261	26190	Economy	61500.00
0005432985745	26190	Economy	61500.00
0005433435262	26190	Economy	61500.00
0005433754916	26190	Economy	61500.00
0005435982830	26190	Economy	61500.00
0005433754888	26190	Economy	61500.00
0005435982809	26190	Economy	61500.00
0005433435272	26190	Economy	61500.00
0005433754615	26190	Economy	61500.00
0005433755010	26190	Economy	61500.00
0005435982757	26190	Economy	61500.00
0005433435267	26190	Economy	61500.00
0005432985748	26190	Economy	61500.00
0005433754862	26190	Economy	61500.00
0005435982804	26190	Economy	61500.00
0005435982756	26190	Economy	61500.00
0005432985731	26190	Economy	61500.00
0005435982856	26190	Economy	61500.00
0005433435250	26190	Economy	61500.00
0005433435247	26190	Economy	61500.00
0005432049536	26190	Economy	61500.00
0005433754877	26190	Economy	61500.00
0005432869662	26190	Economy	61500.00
0005432985756	26190	Economy	61500.00
0005432985739	26190	Economy	61500.00
0005432985735	26190	Economy	61500.00
0005433754922	26190	Economy	61500.00
0005435982793	26190	Economy	61500.00
0005433754880	26190	Economy	61500.00
0005432051193	26190	Economy	61500.00
0005432869659	26190	Economy	61500.00
0005433435256	26190	Economy	61500.00
0005432985759	26190	Economy	61500.00
0005435982730	26190	Economy	61500.00
0005433754925	26190	Economy	61500.00
0005433754919	26190	Economy	61500.00
0005432985732	26190	Economy	61500.00
0005433435253	26190	Economy	61500.00
0005432985758	26190	Economy	61500.00
0005433435268	26190	Economy	61500.00
0005435982803	26190	Economy	61500.00
0005433435271	26190	Economy	61500.00
0005433754842	26190	Economy	61500.00
0005434731259	26190	Economy	61500.00
0005433755112	26190	Economy	61500.00
0005433754887	26190	Economy	61500.00
0005433754689	26190	Economy	61500.00
0005433435270	26190	Economy	61500.00
0005433754843	26190	Economy	61500.00
0005435982832	26190	Economy	61500.00
0005434375581	1492	Business	38900.00
0005433151835	1492	Business	38900.00
0005433151754	1492	Business	38900.00
0005433151848	1492	Business	38900.00
0005434375591	1492	Business	38900.00
0005432268030	1492	Business	38900.00
0005434375603	1492	Business	38900.00
0005433151846	1492	Business	38900.00
0005434375600	1492	Business	38900.00
0005433461634	1492	Business	38900.00
0005433151841	1492	Economy	13000.00
0005434375566	1492	Economy	13000.00
0005434375567	1492	Economy	13000.00
0005433151829	1492	Economy	13000.00
0005433151815	1492	Economy	13000.00
0005434375585	1492	Economy	13000.00
0005432268033	1492	Economy	13000.00
0005434375595	1492	Economy	13000.00
0005433151926	1492	Economy	13000.00
0005434375606	1492	Economy	13000.00
0005434375586	1492	Economy	13000.00
0005434375593	1492	Economy	13000.00
0005434375563	1492	Economy	13000.00
0005434375590	1492	Economy	13000.00
0005433764694	1492	Economy	13000.00
0005433151996	1492	Economy	13000.00
0005434375582	1492	Economy	13000.00
0005434375580	1492	Economy	13000.00
0005434375576	1492	Economy	13000.00
0005433151942	1492	Economy	13000.00
0005433931500	1492	Economy	13000.00
0005434029689	1492	Economy	13000.00
0005433151850	1492	Economy	13000.00
0005433151809	1492	Economy	13000.00
0005433460481	1492	Economy	13000.00
0005434375565	1492	Economy	13000.00
0005434375564	1492	Economy	13000.00
0005432268035	1492	Economy	13000.00
0005432268034	1492	Economy	13000.00
0005434375583	1492	Economy	13000.00
0005433151775	1492	Economy	13000.00
0005434375597	1492	Economy	13000.00
0005434375571	1492	Economy	14300.00
0005434375596	1492	Economy	14300.00
0005434375572	1492	Economy	14300.00
0005434375584	1492	Economy	14300.00
0005433151849	1492	Economy	14300.00
0005434375559	1492	Economy	13000.00
0005434375570	1492	Economy	13000.00
0005432268032	1492	Economy	13000.00
0005433151833	1492	Economy	13000.00
0005433151864	1492	Economy	13000.00
0005434375604	1492	Economy	13000.00
0005433151845	1492	Economy	13000.00
0005433151973	1492	Economy	13000.00
0005433151823	1492	Economy	13000.00
0005434375562	1492	Economy	13000.00
0005433151881	1492	Economy	13000.00
0005433461633	1492	Economy	13000.00
0005433151925	1492	Economy	13000.00
0005433764707	1492	Economy	13000.00
0005434375598	1492	Economy	13000.00
0005433151804	1492	Economy	13000.00
0005433151879	1492	Economy	13000.00
0005434375589	1492	Economy	13000.00
0005434375575	1492	Economy	13000.00
0005432268031	1492	Economy	13000.00
0005434375577	1492	Economy	13000.00
0005433151878	1492	Economy	13000.00
0005433151909	1492	Economy	13000.00
0005434375569	1492	Economy	13000.00
0005434375605	1492	Economy	13000.00
0005434375594	1492	Economy	13000.00
0005434029690	1492	Economy	13000.00
0005433151917	1492	Economy	13000.00
0005434375561	1492	Economy	13000.00
0005434375601	1492	Economy	13000.00
0005434375602	1492	Economy	13000.00
0005433151780	1492	Economy	13000.00
0005433151749	1492	Economy	13000.00
0005434375558	1492	Economy	13000.00
0005433151856	1492	Economy	13000.00
0005433151908	1492	Economy	13000.00
0005434375588	1492	Economy	13000.00
0005433151686	1492	Economy	13000.00
0005433151818	1492	Economy	13000.00
0005434375578	1492	Economy	13000.00
0005433151803	1492	Economy	13000.00
0005433152008	1492	Economy	13000.00
0005433151687	1492	Economy	13000.00
0005433151748	1492	Economy	13000.00
0005434375573	1492	Economy	13000.00
0005434375592	1492	Economy	13000.00
0005434375579	1492	Economy	13000.00
0005433461635	1492	Economy	13000.00
0005433151852	1492	Economy	13000.00
0005433151822	1492	Economy	13000.00
0005434375599	1492	Economy	13000.00
0005434375560	1492	Economy	13000.00
0005433151853	1492	Economy	13000.00
0005434375574	1492	Economy	13000.00
0005434375587	1492	Economy	13000.00
0005434029688	1492	Economy	13000.00
0005434375568	1492	Economy	13000.00
0005433460480	1492	Economy	13000.00
0005432268036	1492	Economy	13000.00
0005434375136	20139	Business	38900.00
0005432056377	20139	Business	38900.00
0005434375062	20139	Business	38900.00
0005434375228	20139	Business	38900.00
0005433152101	20139	Business	38900.00
0005434375351	20139	Business	38900.00
0005433152113	20139	Business	38900.00
0005434374997	20139	Business	38900.00
0005434375173	20139	Economy	13000.00
0005434375229	20139	Economy	13000.00
0005434375331	20139	Economy	13000.00
0005433152127	20139	Economy	13000.00
0005433152126	20139	Economy	13000.00
0005433152114	20139	Economy	13000.00
0005433152100	20139	Economy	13000.00
0005434375239	20139	Economy	13000.00
0005434375032	20139	Economy	13000.00
0005434375121	20139	Economy	13000.00
0005433152103	20139	Economy	13000.00
0005433152102	20139	Economy	13000.00
0005434375380	20139	Economy	13000.00
0005433152122	20139	Economy	13000.00
0005434375244	20139	Economy	13000.00
0005433152097	20139	Economy	13000.00
0005433152099	20139	Economy	13000.00
0005433152111	20139	Economy	13000.00
0005433152095	20139	Economy	13000.00
0005434375127	20139	Economy	13000.00
0005433152112	20139	Economy	13000.00
0005433152104	20139	Economy	13000.00
0005434375120	20139	Economy	13000.00
0005434375210	20139	Economy	13000.00
0005433152125	20139	Economy	13000.00
0005434029710	20139	Economy	13000.00
0005433931527	20139	Economy	14300.00
0005433152098	20139	Economy	14300.00
0005434375332	20139	Economy	14300.00
0005434375225	20139	Economy	14300.00
0005433764723	20139	Economy	13000.00
0005433152117	20139	Economy	13000.00
0005433152116	20139	Economy	13000.00
0005433152129	20139	Economy	13000.00
0005434375284	20139	Economy	13000.00
0005434375115	20139	Economy	13000.00
0005434375348	20139	Economy	13000.00
0005433152121	20139	Economy	13000.00
0005433152119	20139	Economy	13000.00
0005434375271	20139	Economy	13000.00
0005434375218	20139	Economy	13000.00
0005434375371	20139	Economy	13000.00
0005433152108	20139	Economy	13000.00
0005433152105	20139	Economy	13000.00
0005433931528	20139	Economy	13000.00
0005434375259	20139	Economy	13000.00
0005434375310	20139	Economy	13000.00
0005433152120	20139	Economy	13000.00
0005432056378	20139	Economy	13000.00
0005434375370	20139	Economy	13000.00
0005434375061	20139	Economy	13000.00
0005433152124	20139	Economy	13000.00
0005433152106	20139	Economy	13000.00
0005434375234	20139	Economy	13000.00
0005434375313	20139	Economy	13000.00
0005433152094	20139	Economy	13000.00
0005434375321	20139	Economy	13000.00
0005433152109	20139	Economy	13000.00
0005434375347	20139	Economy	13000.00
0005433152115	20139	Economy	13000.00
0005434375251	20139	Economy	13000.00
0005434375258	20139	Economy	13000.00
0005434375273	20139	Economy	13000.00
0005433152107	20139	Economy	13000.00
0005433152110	20139	Economy	13000.00
0005433152128	20139	Economy	13000.00
0005433152096	20139	Economy	13000.00
0005433152118	20139	Economy	13000.00
0005434375257	20139	Economy	13000.00
0005434375272	20139	Economy	13000.00
0005433764722	20139	Economy	13000.00
0005434029709	20139	Economy	13000.00
0005434375311	20139	Economy	13000.00
0005434375172	20139	Economy	13000.00
0005434029708	20139	Economy	13000.00
0005434375250	20139	Economy	13000.00
0005432056375	20139	Economy	13000.00
0005432056376	20139	Economy	13000.00
0005433152123	20139	Economy	13000.00
0005434375094	20139	Economy	13000.00
0005433764721	20139	Economy	13000.00
0005432425474	605	Business	27500.00
0005432425452	605	Business	27500.00
0005432425438	605	Business	27500.00
0005432425460	605	Business	27500.00
0005432425446	605	Business	27500.00
0005432425448	605	Business	27500.00
0005432425439	605	Business	27500.00
0005432425430	605	Business	27500.00
0005432425477	605	Business	27500.00
0005432425433	605	Business	27500.00
0005432425441	605	Economy	10100.00
0005432283008	605	Economy	10100.00
0005432425456	605	Economy	10100.00
0005432425475	605	Economy	10100.00
0005432425454	605	Economy	9200.00
0005432425442	605	Economy	9200.00
0005432425470	605	Economy	9200.00
0005432425459	605	Economy	9200.00
0005432425451	605	Economy	9200.00
0005432283012	605	Economy	9200.00
0005432425455	605	Economy	9200.00
0005432425440	605	Economy	9200.00
0005432425443	605	Economy	9200.00
0005432425435	605	Economy	9200.00
0005432425466	605	Economy	9200.00
0005432425471	605	Economy	9200.00
0005432425453	605	Economy	9200.00
0005432283013	605	Economy	9200.00
0005432283010	605	Economy	9200.00
0005432425431	605	Economy	9200.00
0005432425436	605	Economy	9200.00
0005432425445	605	Economy	9200.00
0005432425449	605	Economy	9200.00
0005432425476	605	Economy	10100.00
0005432283011	605	Economy	9200.00
0005432425462	605	Economy	9200.00
0005432425457	605	Economy	9200.00
0005432425434	605	Economy	9200.00
0005432425467	605	Economy	9200.00
0005432425427	605	Economy	9200.00
0005432283007	605	Economy	9200.00
0005432425461	605	Economy	9200.00
0005432425472	605	Economy	9200.00
0005432425468	605	Economy	9200.00
0005432425447	605	Economy	9200.00
0005432425463	605	Economy	9200.00
0005432425450	605	Economy	9200.00
0005432425465	605	Economy	9200.00
0005432425464	605	Economy	9200.00
0005432425429	605	Economy	9200.00
0005432425444	605	Economy	9200.00
0005432425437	605	Economy	9200.00
0005432283009	605	Economy	9200.00
0005432425432	605	Economy	9200.00
0005432425458	605	Economy	9200.00
0005432425473	605	Economy	9200.00
0005432425428	605	Economy	9200.00
0005432425469	605	Economy	9200.00
0005434446540	12850	Business	27500.00
0005434446553	12850	Economy	9200.00
0005433261877	12850	Economy	9200.00
0005434446527	12850	Economy	9200.00
0005433766754	12850	Economy	9200.00
0005433158178	12850	Economy	9200.00
0005433158176	12850	Economy	9200.00
0005432302408	12850	Economy	9200.00
0005432302410	12850	Economy	9200.00
0005433261879	12850	Economy	9200.00
0005434446543	12850	Economy	9200.00
0005434446537	12850	Economy	9200.00
0005434446542	12850	Economy	9200.00
0005434446541	12850	Economy	10100.00
0005433766755	12850	Economy	9200.00
0005434446546	12850	Economy	9200.00
0005434446547	12850	Economy	9200.00
0005433261876	12850	Economy	9200.00
0005433261878	12850	Economy	9200.00
0005434446528	12850	Economy	9200.00
0005433158177	12850	Economy	9200.00
0005432302409	12850	Economy	9200.00
0005432424904	12825	Business	27500.00
0005432424886	12825	Business	27500.00
0005432424911	12825	Business	27500.00
0005432425068	12825	Business	27500.00
0005432424895	12825	Business	27500.00
0005432424969	12825	Business	27500.00
0005432424890	12825	Business	27500.00
0005432424939	12825	Economy	10100.00
0005432424979	12825	Economy	9200.00
0005432424952	12825	Economy	9200.00
0005432425003	12825	Economy	9200.00
0005432425074	12825	Economy	9200.00
0005432425054	12825	Economy	9200.00
0005432424971	12825	Economy	9200.00
0005432424943	12825	Economy	9200.00
0005432424966	12825	Economy	9200.00
0005432425005	12825	Economy	9200.00
0005432424861	12825	Economy	9200.00
0005432424953	12825	Economy	9200.00
0005432424936	12825	Economy	9200.00
0005432425044	12825	Economy	9200.00
0005432425053	12825	Economy	9200.00
0005432424872	12825	Economy	9200.00
0005432424892	12825	Economy	9200.00
0005432425001	12825	Economy	9200.00
0005432424883	12825	Economy	9200.00
0005432425002	12825	Economy	10100.00
0005432425036	12825	Economy	10100.00
0005432425067	12825	Economy	9200.00
0005432425010	12825	Economy	9200.00
0005432424967	12825	Economy	9200.00
0005432424976	12825	Economy	9200.00
0005432424940	12825	Economy	9200.00
0005432425056	12825	Economy	9200.00
0005432425058	12825	Economy	9200.00
0005432424993	12825	Economy	9200.00
0005432425055	12825	Economy	9200.00
0005432424978	12825	Economy	9200.00
0005432425024	12825	Economy	9200.00
0005432424918	12825	Economy	9200.00
0005432425041	12825	Economy	9200.00
0005432424905	12825	Economy	9200.00
0005432424954	12825	Economy	9200.00
0005432425006	12825	Economy	9200.00
0005432424882	12825	Economy	9200.00
0005432424931	12825	Economy	9200.00
0005432425043	12825	Economy	9200.00
0005432424891	12825	Economy	9200.00
0005432425042	12825	Economy	9200.00
0005432424837	12825	Economy	9200.00
0005432425007	12825	Economy	9200.00
0005432424987	12825	Economy	9200.00
0005432424917	12825	Economy	9200.00
0005432045651	437	Business	24500.00
0005434025104	437	Business	24500.00
0005433058375	437	Business	24500.00
0005434029705	437	Business	24500.00
0005434735729	437	Business	24500.00
0005433058411	437	Business	24500.00
0005434025066	437	Business	24500.00
0005434029707	437	Business	24500.00
0005434025113	437	Business	24500.00
0005434025071	437	Business	24500.00
0005434025076	437	Business	24500.00
0005434025068	437	Business	24500.00
0005433058475	437	Business	24500.00
0005433058450	437	Business	24500.00
0005434028364	437	Business	24500.00
0005433058332	437	Business	24500.00
0005434032116	437	Business	24500.00
0005433058485	437	Business	24500.00
0005434025103	437	Business	24500.00
0005432235797	437	Economy	9000.00
0005433058443	437	Economy	9000.00
0005434025089	437	Economy	8200.00
0005434025082	437	Economy	8200.00
0005432235793	437	Economy	8200.00
0005433058390	437	Economy	8200.00
0005434025127	437	Economy	8200.00
0005433058471	437	Economy	8200.00
0005434025100	437	Economy	8200.00
0005434735726	437	Economy	8200.00
0005434735742	437	Economy	8200.00
0005434025069	437	Economy	8200.00
0005434025112	437	Economy	8200.00
0005434025087	437	Economy	8200.00
0005434025079	437	Economy	8200.00
0005434025131	437	Economy	8200.00
0005433929665	437	Economy	8200.00
0005434025106	437	Economy	8200.00
0005434025097	437	Economy	8200.00
0005433058412	437	Economy	8200.00
0005434025074	437	Economy	8200.00
0005434025101	437	Economy	8200.00
0005432045652	437	Economy	8200.00
0005434025125	437	Economy	8200.00
0005434025070	437	Economy	8200.00
0005434025081	437	Economy	8200.00
0005434025123	437	Economy	8200.00
0005434025118	437	Economy	8200.00
0005434025114	437	Economy	8200.00
0005433058382	437	Economy	8200.00
0005433058386	437	Economy	8200.00
0005434025090	437	Economy	8200.00
0005434025095	437	Economy	8200.00
0005434735743	437	Economy	8200.00
0005434025128	437	Economy	8200.00
0005434025121	437	Economy	8200.00
0005432235790	437	Economy	8200.00
0005432235798	437	Economy	8200.00
0005434025085	437	Economy	8200.00
0005434025075	437	Economy	8200.00
0005434025107	437	Economy	8200.00
0005434032115	437	Economy	8200.00
0005434025099	437	Economy	8200.00
0005432235796	437	Economy	8200.00
0005433058374	437	Economy	8200.00
0005434025084	437	Economy	8200.00
0005433929641	437	Economy	8200.00
0005433929670	437	Economy	8200.00
0005433058237	437	Economy	8200.00
0005433929667	437	Economy	8200.00
0005434028360	437	Economy	8200.00
0005434025116	437	Economy	8200.00
0005433058452	437	Economy	8200.00
0005433058451	437	Economy	8200.00
0005432235794	437	Economy	8200.00
0005434028361	437	Economy	8200.00
0005434025110	437	Economy	8200.00
0005433058476	437	Economy	8200.00
0005432235792	437	Economy	8200.00
0005434025126	437	Economy	8200.00
0005433058464	437	Economy	8200.00
0005433058384	437	Economy	8200.00
0005434025080	437	Economy	8200.00
0005433929666	437	Economy	8200.00
0005433058385	437	Economy	9000.00
0005433058171	437	Economy	9000.00
0005434025067	437	Economy	9000.00
0005433929669	437	Economy	8200.00
0005434025073	437	Economy	8200.00
0005434025091	437	Economy	8200.00
0005434025117	437	Economy	8200.00
0005434025078	437	Economy	8200.00
0005433058470	437	Economy	8200.00
0005434025102	437	Economy	8200.00
0005432235791	437	Economy	8200.00
0005434025083	437	Economy	8200.00
0005434029706	437	Economy	8200.00
0005434025135	437	Economy	8200.00
0005432235789	437	Economy	8200.00
0005434735728	437	Economy	8200.00
0005433929672	437	Economy	8200.00
0005434735727	437	Economy	8200.00
0005434025086	437	Economy	8200.00
0005433058302	437	Economy	8200.00
0005433058561	437	Economy	8200.00
0005434028363	437	Economy	8200.00
0005434025092	437	Economy	8200.00
0005434025132	437	Economy	8200.00
0005434025133	437	Economy	8200.00
0005433058489	437	Economy	8200.00
0005434025130	437	Economy	8200.00
0005434025124	437	Economy	8200.00
0005434735730	437	Economy	8200.00
0005434025109	437	Economy	8200.00
0005433058488	437	Economy	8200.00
0005434025122	437	Economy	8200.00
0005433058449	437	Economy	8200.00
0005434025120	437	Economy	8200.00
0005434032114	437	Economy	8200.00
0005434025072	437	Economy	8200.00
0005434025105	437	Economy	8200.00
0005434025096	437	Economy	8200.00
0005434025093	437	Economy	8200.00
0005434028362	437	Economy	8200.00
0005433058389	437	Economy	8200.00
0005433058383	437	Economy	8200.00
0005433929640	437	Economy	8200.00
0005434025134	437	Economy	8200.00
0005434025077	437	Economy	8200.00
0005434025094	437	Economy	8200.00
0005434025119	437	Economy	8200.00
0005434025088	437	Economy	8200.00
0005434025108	437	Economy	8200.00
0005434025115	437	Economy	8200.00
0005433058381	437	Economy	8200.00
0005434025111	437	Economy	8200.00
0005434025098	437	Economy	8200.00
0005432235795	437	Economy	8200.00
0005433058243	437	Economy	8200.00
0005434025129	437	Economy	8200.00
0005433058285	437	Economy	8200.00
0005434032080	12656	Business	24500.00
0005433058727	12656	Business	24500.00
0005434735797	12656	Business	24500.00
0005434024042	12656	Business	24500.00
0005433058701	12656	Business	24500.00
0005434032064	12656	Business	24500.00
0005434735798	12656	Business	24500.00
0005432157531	12656	Business	24500.00
0005433058718	12656	Business	24500.00
0005434024396	12656	Business	24500.00
0005434735796	12656	Economy	9000.00
0005433058698	12656	Economy	9000.00
0005433058716	12656	Economy	9000.00
0005433058704	12656	Economy	8200.00
0005433058720	12656	Economy	8200.00
0005433929698	12656	Economy	8200.00
0005434024772	12656	Economy	8200.00
0005433929697	12656	Economy	8200.00
0005433058688	12656	Economy	8200.00
0005434024645	12656	Economy	8200.00
0005433058717	12656	Economy	8200.00
0005433058722	12656	Economy	8200.00
0005433058710	12656	Economy	8200.00
0005432156458	12656	Economy	8200.00
0005434024328	12656	Economy	8200.00
0005434024193	12656	Economy	8200.00
0005434024276	12656	Economy	8200.00
0005434024463	12656	Economy	8200.00
0005434024446	12656	Economy	8200.00
0005434024778	12656	Economy	8200.00
0005434032088	12656	Economy	8200.00
0005434024609	12656	Economy	8200.00
0005433058712	12656	Economy	8200.00
0005433929700	12656	Economy	8200.00
0005433058700	12656	Economy	8200.00
0005434024786	12656	Economy	8200.00
0005434029689	12656	Economy	8200.00
0005433684464	12656	Economy	8200.00
0005433058709	12656	Economy	8200.00
0005432157532	12656	Economy	8200.00
0005432156455	12656	Economy	8200.00
0005434024547	12656	Economy	8200.00
0005433058693	12656	Economy	8200.00
0005434735799	12656	Economy	8200.00
0005432157533	12656	Economy	8200.00
0005433058694	12656	Economy	8200.00
0005433929699	12656	Economy	8200.00
0005434735800	12656	Economy	8200.00
0005433058726	12656	Economy	8200.00
0005433058707	12656	Economy	8200.00
0005434024375	12656	Economy	8200.00
0005434029688	12656	Economy	8200.00
0005434024685	12656	Economy	8200.00
0005434028330	12656	Economy	8200.00
0005433684465	12656	Economy	8200.00
0005434024448	12656	Economy	8200.00
0005434024747	12656	Economy	8200.00
0005434024468	12656	Economy	8200.00
0005434029690	12656	Economy	8200.00
0005433058691	12656	Economy	8200.00
0005432156457	12656	Economy	8200.00
0005433058689	12656	Economy	8200.00
0005433058708	12656	Economy	8200.00
0005434024522	12656	Economy	8200.00
0005433684463	12656	Economy	8200.00
0005434032063	12656	Economy	8200.00
0005434735795	12656	Economy	8200.00
0005434024608	12656	Economy	8200.00
0005434024494	12656	Economy	8200.00
0005433058725	12656	Economy	8200.00
0005432156456	12656	Economy	8200.00
0005434024367	12656	Economy	8200.00
0005433058721	12656	Economy	8200.00
0005433058711	12656	Economy	8200.00
0005433058723	12656	Economy	8200.00
0005434024307	12656	Economy	9000.00
0005433058706	12656	Economy	8200.00
0005434024562	12656	Economy	8200.00
0005434024607	12656	Economy	8200.00
0005433058715	12656	Economy	9000.00
0005434024295	12656	Economy	8200.00
0005434024493	12656	Economy	8200.00
0005434024329	12656	Economy	8200.00
0005433058696	12656	Economy	8200.00
0005434032081	12656	Economy	8200.00
0005434024612	12656	Economy	8200.00
0005434024515	12656	Economy	8200.00
0005434024535	12656	Economy	8200.00
0005434024640	12656	Economy	8200.00
0005433058702	12656	Economy	8200.00
0005434024686	12656	Economy	8200.00
0005434024601	12656	Economy	8200.00
0005433058699	12656	Economy	8200.00
0005434024368	12656	Economy	8200.00
0005434024469	12656	Economy	8200.00
0005434024630	12656	Economy	8200.00
0005434024563	12656	Economy	8200.00
0005434024524	12656	Economy	8200.00
0005433058724	12656	Economy	8200.00
0005433058692	12656	Economy	8200.00
0005433058697	12656	Economy	8200.00
0005434024349	12656	Economy	8200.00
0005434024427	12656	Economy	8200.00
0005434024597	12656	Economy	8200.00
0005433058703	12656	Economy	8200.00
0005433058714	12656	Economy	8200.00
0005434024599	12656	Economy	8200.00
0005434024838	12656	Economy	8200.00
0005434024313	12656	Economy	8200.00
0005434028322	12656	Economy	8200.00
0005433058719	12656	Economy	8200.00
0005434024447	12656	Economy	8200.00
0005433058713	12656	Economy	8200.00
0005434024457	12656	Economy	8200.00
0005434024279	12656	Economy	8200.00
0005434024297	12656	Economy	8200.00
0005434024489	12656	Economy	8200.00
0005434024631	12656	Economy	8200.00
0005433058728	12656	Economy	8200.00
0005434024637	12656	Economy	8200.00
0005433058695	12656	Economy	8200.00
0005433058705	12656	Economy	8200.00
0005434024521	12656	Economy	8200.00
0005434024548	12656	Economy	8200.00
0005434024397	12656	Economy	8200.00
0005433058690	12656	Economy	8200.00
0005434024600	12656	Economy	8200.00
0005433925246	2163	Business	34700.00
0005433925314	2163	Business	34700.00
0005433036939	2163	Business	34700.00
0005433037014	2163	Business	34700.00
0005433036969	2163	Business	34700.00
0005433929697	2163	Business	34700.00
0005433036720	2163	Business	34700.00
0005433036690	2163	Business	34700.00
0005433925234	2163	Business	34700.00
0005433037093	2163	Business	34700.00
0005433925280	2163	Business	34700.00
0005433925292	2163	Business	34700.00
0005433925312	2163	Business	34700.00
0005433925243	2163	Business	34700.00
0005433925284	2163	Business	34700.00
0005433925256	2163	Business	34700.00
0005433925245	2163	Business	34700.00
0005433925259	2163	Business	34700.00
0005433925276	2163	Business	34700.00
0005433036921	2163	Business	34700.00
0005433929699	2163	Business	34700.00
0005433925226	2163	Business	34700.00
0005433925315	2163	Economy	12700.00
0005433875412	2163	Economy	12700.00
0005433925266	2163	Economy	12700.00
0005433925298	2163	Economy	11600.00
0005433925252	2163	Economy	11600.00
0005433925293	2163	Economy	11600.00
0005433929698	2163	Economy	11600.00
0005433925265	2163	Economy	11600.00
0005433925285	2163	Economy	11600.00
0005432231779	2163	Economy	11600.00
0005433925264	2163	Economy	11600.00
0005433925287	2163	Economy	11600.00
0005433925257	2163	Economy	11600.00
0005433925230	2163	Economy	11600.00
0005433925251	2163	Economy	11600.00
0005433036858	2163	Economy	11600.00
0005433925261	2163	Economy	11600.00
0005433925275	2163	Economy	11600.00
0005433925303	2163	Economy	11600.00
0005433925239	2163	Economy	11600.00
0005433925290	2163	Economy	11600.00
0005433036737	2163	Economy	11600.00
0005433036797	2163	Economy	11600.00
0005433925249	2163	Economy	11600.00
0005433925225	2163	Economy	11600.00
0005433925304	2163	Economy	11600.00
0005433925224	2163	Economy	11600.00
0005433929700	2163	Economy	11600.00
0005433925270	2163	Economy	11600.00
0005433925272	2163	Economy	11600.00
0005433036851	2163	Economy	11600.00
0005432231784	2163	Economy	11600.00
0005433925271	2163	Economy	11600.00
0005433925232	2163	Economy	11600.00
0005432231783	2163	Economy	11600.00
0005433036852	2163	Economy	11600.00
0005433925291	2163	Economy	11600.00
0005433925233	2163	Economy	11600.00
0005433925240	2163	Economy	11600.00
0005433925282	2163	Economy	11600.00
0005433037015	2163	Economy	11600.00
0005433925241	2163	Economy	11600.00
0005433925237	2163	Economy	11600.00
0005433037071	2163	Economy	11600.00
0005433036890	2163	Economy	11600.00
0005433036996	2163	Economy	11600.00
0005433925250	2163	Economy	11600.00
0005433925277	2163	Economy	11600.00
0005432231778	2163	Economy	11600.00
0005433036945	2163	Economy	11600.00
0005433036853	2163	Economy	11600.00
0005433925274	2163	Economy	11600.00
0005433925302	2163	Economy	11600.00
0005433036993	2163	Economy	11600.00
0005433036814	2163	Economy	11600.00
0005433925267	2163	Economy	11600.00
0005434028330	2163	Economy	11600.00
0005432231777	2163	Economy	11600.00
0005433036738	2163	Economy	11600.00
0005433925248	2163	Economy	11600.00
0005433931528	2163	Economy	11600.00
0005433925279	2163	Economy	11600.00
0005433925223	2163	Economy	11600.00
0005433925281	2163	Economy	11600.00
0005432231785	2163	Economy	11600.00
0005433925238	2163	Economy	11600.00
0005433036981	2163	Economy	11600.00
0005433925301	2163	Economy	11600.00
0005433036667	2163	Economy	11600.00
0005432231780	2163	Economy	11600.00
0005433925286	2163	Economy	11600.00
0005433925236	2163	Economy	11600.00
0005433037070	2163	Economy	11600.00
0005433925220	2163	Economy	11600.00
0005433925307	2163	Economy	11600.00
0005433925273	2163	Economy	11600.00
0005433925231	2163	Economy	11600.00
0005433925306	2163	Economy	11600.00
0005433036930	2163	Economy	11600.00
0005433875411	2163	Economy	11600.00
0005433925258	2163	Economy	12700.00
0005432749800	2163	Economy	11600.00
0005433036748	2163	Economy	11600.00
0005433036938	2163	Economy	12700.00
0005433925278	2163	Economy	12700.00
0005433925317	2163	Economy	11600.00
0005433925242	2163	Economy	11600.00
0005432231781	2163	Economy	11600.00
0005433925297	2163	Economy	11600.00
0005433925300	2163	Economy	11600.00
0005433925268	2163	Economy	11600.00
0005433931527	2163	Economy	11600.00
0005433925295	2163	Economy	11600.00
0005433925309	2163	Economy	11600.00
0005433925316	2163	Economy	11600.00
0005433925263	2163	Economy	11600.00
0005433925255	2163	Economy	11600.00
0005433037151	2163	Economy	11600.00
0005433036989	2163	Economy	11600.00
0005433036970	2163	Economy	11600.00
0005433925296	2163	Economy	11600.00
0005432231782	2163	Economy	11600.00
0005433925305	2163	Economy	11600.00
0005433925254	2163	Economy	11600.00
0005433925260	2163	Economy	11600.00
0005433925313	2163	Economy	11600.00
0005433036906	2163	Economy	11600.00
0005433036992	2163	Economy	11600.00
0005433925299	2163	Economy	11600.00
0005433037026	2163	Economy	11600.00
0005433925247	2163	Economy	11600.00
0005433036891	2163	Economy	11600.00
0005432044582	2163	Economy	11600.00
0005433925269	2163	Economy	11600.00
0005432231787	2163	Economy	11600.00
0005433925227	2163	Economy	11600.00
0005433925235	2163	Economy	11600.00
0005433925228	2163	Economy	11600.00
0005433036859	2163	Economy	11600.00
0005433925244	2163	Economy	11600.00
0005433037027	2163	Economy	11600.00
0005433036870	2163	Economy	11600.00
0005433036997	2163	Economy	11600.00
0005433036951	2163	Economy	11600.00
0005433036901	2163	Economy	11600.00
0005432044581	2163	Economy	11600.00
0005433036820	2163	Economy	11600.00
0005433036866	2163	Economy	11600.00
0005432231786	2163	Economy	11600.00
0005433925262	2163	Economy	11600.00
0005433925308	2163	Economy	11600.00
0005433925222	2163	Economy	11600.00
0005433036869	2163	Economy	11600.00
0005433037156	2163	Economy	11600.00
0005433925253	2163	Economy	11600.00
0005432044583	2163	Economy	11600.00
0005433925283	2163	Economy	11600.00
0005433925310	2163	Economy	11600.00
0005433925294	2163	Economy	11600.00
0005434028322	2163	Economy	11600.00
0005433925311	2163	Economy	11600.00
0005433925221	2163	Economy	11600.00
0005433925229	2163	Economy	11600.00
0005433925289	2163	Economy	11600.00
0005433925288	2163	Economy	11600.00
0005433924218	24105	Business	34700.00
0005433924649	24105	Business	34700.00
0005434028366	24105	Business	34700.00
0005433037403	24105	Business	34700.00
0005433924521	24105	Business	34700.00
0005433924000	24105	Business	34700.00
0005433931508	24105	Business	34700.00
0005433924885	24105	Business	34700.00
0005433924171	24105	Business	34700.00
0005433924706	24105	Business	34700.00
0005432749831	24105	Business	34700.00
0005433924388	24105	Business	34700.00
0005433924876	24105	Business	34700.00
0005433037380	24105	Business	34700.00
0005432207716	24105	Business	34700.00
0005433924260	24105	Business	34700.00
0005433037398	24105	Business	34700.00
0005433037396	24105	Business	34700.00
0005433924461	24105	Business	34700.00
0005433037364	24105	Business	34700.00
0005433924546	24105	Business	34700.00
0005433924116	24105	Business	34700.00
0005433037359	24105	Business	34700.00
0005434028365	24105	Business	34700.00
0005433037388	24105	Business	34700.00
0005433924749	24105	Economy	12700.00
0005433924397	24105	Economy	12700.00
0005433037401	24105	Economy	11600.00
0005433924565	24105	Economy	12700.00
0005433924673	24105	Economy	11600.00
0005433037382	24105	Economy	11600.00
0005433924294	24105	Economy	11600.00
0005433923998	24105	Economy	11600.00
0005433924298	24105	Economy	11600.00
0005433037355	24105	Economy	11600.00
0005433924548	24105	Economy	11600.00
0005433037361	24105	Economy	11600.00
0005433037366	24105	Economy	11600.00
0005433037365	24105	Economy	11600.00
0005433924678	24105	Economy	11600.00
0005433923999	24105	Economy	11600.00
0005433924478	24105	Economy	11600.00
0005433924472	24105	Economy	11600.00
0005433924541	24105	Economy	11600.00
0005433037395	24105	Economy	11600.00
0005433037392	24105	Economy	11600.00
0005433924695	24105	Economy	11600.00
0005433924424	24105	Economy	11600.00
0005433924580	24105	Economy	11600.00
0005433037367	24105	Economy	11600.00
0005433924875	24105	Economy	11600.00
0005433037375	24105	Economy	11600.00
0005434028367	24105	Economy	11600.00
0005433037399	24105	Economy	11600.00
0005433924299	24105	Economy	11600.00
0005433924480	24105	Economy	11600.00
0005433037358	24105	Economy	11600.00
0005433037372	24105	Economy	11600.00
0005433924628	24105	Economy	11600.00
0005433924449	24105	Economy	11600.00
0005433924385	24105	Economy	11600.00
0005433924254	24105	Economy	11600.00
0005433924462	24105	Economy	11600.00
0005433924452	24105	Economy	11600.00
0005433924336	24105	Economy	11600.00
0005433924410	24105	Economy	11600.00
0005433924545	24105	Economy	11600.00
0005433924866	24105	Economy	11600.00
0005433925003	24105	Economy	11600.00
0005433924476	24105	Economy	11600.00
0005432206315	24105	Economy	11600.00
0005432206317	24105	Economy	11600.00
0005433037394	24105	Economy	11600.00
0005433924881	24105	Economy	11600.00
0005433924296	24105	Economy	11600.00
0005433037354	24105	Economy	11600.00
0005433924477	24105	Economy	11600.00
0005433037391	24105	Economy	11600.00
0005433924263	24105	Economy	11600.00
0005433924460	24105	Economy	11600.00
0005433037387	24105	Economy	11600.00
0005433037400	24105	Economy	11600.00
0005433924320	24105	Economy	11600.00
0005433924470	24105	Economy	11600.00
0005433037376	24105	Economy	11600.00
0005433037383	24105	Economy	11600.00
0005433924359	24105	Economy	11600.00
0005433037390	24105	Economy	11600.00
0005433037404	24105	Economy	11600.00
0005433037370	24105	Economy	11600.00
0005433924448	24105	Economy	11600.00
0005432206314	24105	Economy	11600.00
0005433037389	24105	Economy	11600.00
0005433924623	24105	Economy	11600.00
0005433037377	24105	Economy	11600.00
0005433037362	24105	Economy	11600.00
0005433924246	24105	Economy	11600.00
0005433924209	24105	Economy	11600.00
0005433037384	24105	Economy	11600.00
0005433924638	24105	Economy	11600.00
0005433924369	24105	Economy	11600.00
0005433037386	24105	Economy	11600.00
0005433037397	24105	Economy	11600.00
0005433924489	24105	Economy	11600.00
0005433924456	24105	Economy	12700.00
0005433924750	24105	Economy	11600.00
0005433924560	24105	Economy	12700.00
0005433924026	24105	Economy	11600.00
0005433924406	24105	Economy	11600.00
0005433924457	24105	Economy	11600.00
0005433037402	24105	Economy	12700.00
0005433037405	24105	Economy	11600.00
0005433037360	24105	Economy	11600.00
0005432207714	24105	Economy	11600.00
0005433924732	24105	Economy	11600.00
0005433924634	24105	Economy	11600.00
0005433037379	24105	Economy	11600.00
0005433924226	24105	Economy	11600.00
0005433924173	24105	Economy	11600.00
0005433924172	24105	Economy	11600.00
0005432207717	24105	Economy	11600.00
0005433924610	24105	Economy	11600.00
0005433924178	24105	Economy	11600.00
0005433924436	24105	Economy	11600.00
0005433924867	24105	Economy	11600.00
0005433037368	24105	Economy	11600.00
0005433037406	24105	Economy	11600.00
0005433924542	24105	Economy	11600.00
0005432206316	24105	Economy	11600.00
0005432749830	24105	Economy	11600.00
0005433924305	24105	Economy	11600.00
0005433037374	24105	Economy	11600.00
0005433924447	24105	Economy	11600.00
0005433924891	24105	Economy	11600.00
0005433924389	24105	Economy	11600.00
0005433924596	24105	Economy	11600.00
0005433924065	24105	Economy	11600.00
0005433924437	24105	Economy	11600.00
0005433924306	24105	Economy	11600.00
0005433924865	24105	Economy	11600.00
0005433037369	24105	Economy	11600.00
0005433037371	24105	Economy	11600.00
0005433037363	24105	Economy	11600.00
0005433924581	24105	Economy	11600.00
0005433924611	24105	Economy	11600.00
0005433923791	24105	Economy	11600.00
0005433924295	24105	Economy	11600.00
0005433924376	24105	Economy	11600.00
0005433037378	24105	Economy	11600.00
0005433924633	24105	Economy	11600.00
0005433924597	24105	Economy	11600.00
0005433924390	24105	Economy	11600.00
0005433037393	24105	Economy	11600.00
0005433924318	24105	Economy	11600.00
0005433924731	24105	Economy	11600.00
0005433924821	24105	Economy	11600.00
0005433037356	24105	Economy	11600.00
0005432206312	24105	Economy	11600.00
0005433931507	24105	Economy	11600.00
0005433924177	24105	Economy	11600.00
0005433924543	24105	Economy	11600.00
0005432206313	24105	Economy	11600.00
0005433924368	24105	Economy	11600.00
0005433924407	24105	Economy	11600.00
0005433037373	24105	Economy	11600.00
0005433924357	24105	Economy	11600.00
0005433924729	24105	Economy	11600.00
0005433924396	24105	Economy	11600.00
0005433037357	24105	Economy	11600.00
0005433037381	24105	Economy	11600.00
0005432207715	24105	Economy	11600.00
0005433037385	24105	Economy	11600.00
0005434727971	270	Business	83700.00
0005434302550	270	Business	83700.00
0005434728014	270	Business	83700.00
0005435142857	270	Business	83700.00
0005433235259	270	Business	83700.00
0005433234685	270	Business	83700.00
0005434727903	270	Business	83700.00
0005433234837	270	Business	83700.00
0005432278089	270	Business	83700.00
0005434727938	270	Business	83700.00
0005434727916	270	Business	83700.00
0005434552347	270	Business	83700.00
0005433234928	270	Business	83700.00
0005434552375	270	Business	83700.00
0005435142859	270	Business	83700.00
0005434727943	270	Business	83700.00
0005434727968	270	Business	83700.00
0005435142853	270	Business	83700.00
0005434552335	270	Business	83700.00
0005434727924	270	Business	83700.00
0005433235057	270	Business	83700.00
0005434552344	270	Business	83700.00
0005434727973	270	Business	83700.00
0005434727933	270	Business	83700.00
0005434727952	270	Business	83700.00
0005434727989	270	Business	83700.00
0005433111528	270	Business	83700.00
0005434727980	270	Comfort	47400.00
0005433234834	270	Comfort	47400.00
0005433181286	270	Comfort	47400.00
0005434552376	270	Comfort	47400.00
0005432278083	270	Comfort	47400.00
0005434552348	270	Comfort	47400.00
0005433234931	270	Comfort	47400.00
0005434552352	270	Comfort	47400.00
0005434735792	270	Comfort	47400.00
0005434727927	270	Comfort	47400.00
0005434727986	270	Comfort	47400.00
0005434727929	270	Comfort	47400.00
0005433181377	270	Comfort	47400.00
0005433235065	270	Comfort	47400.00
0005434735793	270	Comfort	47400.00
0005432278080	270	Comfort	47400.00
0005433234901	270	Comfort	47400.00
0005433181375	270	Comfort	47400.00
0005434728013	270	Comfort	47400.00
0005434727957	270	Comfort	47400.00
0005434727974	270	Comfort	47400.00
0005434552364	270	Comfort	47400.00
0005434552358	270	Comfort	47400.00
0005433234884	270	Comfort	47400.00
0005433289923	270	Comfort	47400.00
0005433235036	270	Comfort	47400.00
0005434552336	270	Comfort	47400.00
0005434727939	270	Comfort	47400.00
0005434727926	270	Comfort	47400.00
0005433235011	270	Comfort	47400.00
0005434032082	270	Comfort	47400.00
0005434727948	270	Comfort	47400.00
0005434728015	270	Comfort	47400.00
0005434727993	270	Comfort	47400.00
0005434727915	270	Comfort	47400.00
0005434727967	270	Comfort	47400.00
0005433234833	270	Comfort	47400.00
0005433181264	270	Comfort	47400.00
0005434727976	270	Economy	27900.00
0005434552381	270	Economy	27900.00
0005434727922	270	Economy	27900.00
0005433235058	270	Economy	27900.00
0005433235012	270	Economy	27900.00
0005434552384	270	Economy	27900.00
0005434552350	270	Economy	27900.00
0005434728019	270	Economy	27900.00
0005433234776	270	Economy	27900.00
0005434727919	270	Economy	27900.00
0005434727966	270	Economy	27900.00
0005433235049	270	Economy	27900.00
0005433181299	270	Economy	27900.00
0005433181552	270	Economy	27900.00
0005433181349	270	Economy	27900.00
0005432278085	270	Economy	27900.00
0005434552332	270	Economy	27900.00
0005434552363	270	Economy	27900.00
0005432278082	270	Economy	27900.00
0005434552365	270	Economy	27900.00
0005434727898	270	Economy	27900.00
0005434552337	270	Economy	27900.00
0005434552338	270	Economy	27900.00
0005434735790	270	Economy	27900.00
0005434032070	270	Economy	27900.00
0005433234847	270	Economy	27900.00
0005434727928	270	Economy	27900.00
0005433235102	270	Economy	27900.00
0005433181356	270	Economy	27900.00
0005433235038	270	Economy	27900.00
0005433181322	270	Economy	27900.00
0005433235089	270	Economy	27900.00
0005433234666	270	Economy	27900.00
0005434727936	270	Economy	27900.00
0005434727997	270	Economy	27900.00
0005434552367	270	Economy	27900.00
0005434552349	270	Economy	27900.00
0005434727991	270	Economy	27900.00
0005434727964	270	Economy	27900.00
0005434727925	270	Economy	27900.00
0005434727944	270	Economy	27900.00
0005434728012	270	Economy	27900.00
0005434727920	270	Economy	27900.00
0005433234883	270	Economy	27900.00
0005434552361	270	Economy	27900.00
0005433181455	270	Economy	27900.00
0005435142852	270	Economy	27900.00
0005435142851	270	Economy	27900.00
0005435142849	270	Economy	27900.00
0005433181411	270	Economy	27900.00
0005434552353	270	Economy	27900.00
0005433181417	270	Economy	27900.00
0005434727999	270	Economy	27900.00
0005434728010	270	Economy	27900.00
0005434727982	270	Economy	27900.00
0005433235193	270	Economy	27900.00
0005434727918	270	Economy	27900.00
0005434552357	270	Economy	27900.00
0005434727969	270	Economy	27900.00
0005434727953	270	Economy	27900.00
0005434727958	270	Economy	27900.00
0005433234835	270	Economy	30700.00
0005433235023	270	Economy	27900.00
0005433126903	270	Economy	30700.00
0005433234849	270	Economy	30700.00
0005433234619	270	Economy	27900.00
0005434727977	270	Economy	27900.00
0005434552351	270	Economy	27900.00
0005434728011	270	Economy	30700.00
0005434727950	270	Economy	27900.00
0005433234968	270	Economy	30700.00
0005433235300	270	Economy	27900.00
0005435142856	270	Economy	27900.00
0005434552360	270	Economy	27900.00
0005434552333	270	Economy	27900.00
0005434552368	270	Economy	27900.00
0005434727942	270	Economy	27900.00
0005434727940	270	Economy	27900.00
0005434727955	270	Economy	27900.00
0005434552342	270	Economy	27900.00
0005433131764	270	Economy	27900.00
0005433235037	270	Economy	27900.00
0005434552354	270	Economy	27900.00
0005433289940	270	Economy	27900.00
0005434727946	270	Economy	27900.00
0005434727961	270	Economy	27900.00
0005434727959	270	Economy	27900.00
0005434727909	270	Economy	27900.00
0005434727912	270	Economy	27900.00
0005434552330	270	Economy	27900.00
0005433181433	270	Economy	27900.00
0005433234936	270	Economy	27900.00
0005434735791	270	Economy	27900.00
0005434727951	270	Economy	27900.00
0005434727990	270	Economy	27900.00
0005434727981	270	Economy	27900.00
0005434727947	270	Economy	27900.00
0005433235022	270	Economy	27900.00
0005435142855	270	Economy	27900.00
0005433289939	270	Economy	27900.00
0005432278091	270	Economy	27900.00
0005434727994	270	Economy	27900.00
0005432278086	270	Economy	27900.00
0005433131759	270	Economy	27900.00
0005433234987	270	Economy	27900.00
0005432278087	270	Economy	27900.00
0005433235034	270	Economy	27900.00
0005434302551	270	Economy	27900.00
0005435142860	270	Economy	27900.00
0005434552362	270	Economy	27900.00
0005433289925	270	Economy	27900.00
0005434727905	270	Economy	27900.00
0005434728020	270	Economy	27900.00
0005434552345	270	Economy	27900.00
0005433181416	270	Economy	27900.00
0005434727930	270	Economy	27900.00
0005434552331	270	Economy	27900.00
0005433181425	270	Economy	27900.00
0005434727911	270	Economy	27900.00
0005434727984	270	Economy	27900.00
0005433181300	270	Economy	27900.00
0005433234881	270	Economy	27900.00
0005434731255	270	Economy	27900.00
0005433235116	270	Economy	27900.00
0005433235301	270	Economy	27900.00
0005434552343	270	Economy	27900.00
0005433131758	270	Economy	27900.00
0005434727941	270	Economy	27900.00
0005434032071	270	Economy	27900.00
0005434552371	270	Economy	27900.00
0005433131760	270	Economy	27900.00
0005434302548	270	Economy	27900.00
0005434727921	270	Economy	27900.00
0005434735794	270	Economy	27900.00
0005432278081	270	Economy	27900.00
0005433234721	270	Economy	27900.00
0005434728004	270	Economy	27900.00
0005435142850	270	Economy	27900.00
0005432278090	270	Economy	27900.00
0005434728007	270	Economy	27900.00
0005433181282	270	Economy	27900.00
0005434552341	270	Economy	27900.00
0005434302885	270	Economy	27900.00
0005434727934	270	Economy	27900.00
0005434727996	270	Economy	27900.00
0005434727907	270	Economy	27900.00
0005433181551	270	Economy	27900.00
0005434552373	270	Economy	27900.00
0005434727978	270	Economy	27900.00
0005434727985	270	Economy	27900.00
0005433234980	270	Economy	27900.00
0005435142858	270	Economy	27900.00
0005433235168	270	Economy	27900.00
0005434552386	270	Economy	27900.00
0005433289922	270	Economy	27900.00
0005433234741	270	Economy	27900.00
0005434552370	270	Economy	27900.00
0005433235195	270	Economy	27900.00
0005433111529	270	Economy	27900.00
0005434727913	270	Economy	27900.00
0005434727962	270	Economy	27900.00
0005434727914	270	Economy	27900.00
0005433126906	270	Economy	27900.00
0005434727901	270	Economy	27900.00
0005434032072	270	Economy	27900.00
0005434727945	270	Economy	27900.00
0005433126905	270	Economy	27900.00
0005432278084	270	Economy	27900.00
0005434727906	270	Economy	27900.00
0005433234956	270	Economy	27900.00
0005434552374	270	Economy	27900.00
0005433181353	270	Economy	27900.00
0005434728002	270	Economy	30700.00
0005435142854	270	Economy	27900.00
0005434552378	270	Economy	30700.00
0005434727902	270	Economy	30700.00
0005434727935	270	Economy	30700.00
0005434728017	270	Economy	30700.00
0005433234811	270	Economy	27900.00
0005433181432	270	Economy	30700.00
0005434728006	270	Economy	27900.00
0005434727983	270	Economy	27900.00
0005434552372	270	Economy	27900.00
0005433289921	270	Economy	27900.00
0005434727937	270	Economy	27900.00
0005434727998	270	Economy	27900.00
0005434552346	270	Economy	27900.00
0005434727972	270	Economy	27900.00
0005433235017	270	Economy	27900.00
0005433234775	270	Economy	27900.00
0005434727956	270	Economy	27900.00
0005434727963	270	Economy	27900.00
0005433131765	270	Economy	27900.00
0005432278078	270	Economy	27900.00
0005433234838	270	Economy	27900.00
0005434727899	270	Economy	27900.00
0005434727931	270	Economy	27900.00
0005434727923	270	Economy	27900.00
0005433235073	270	Economy	27900.00
0005433234774	270	Economy	27900.00
0005434727987	270	Economy	27900.00
0005434552380	270	Economy	27900.00
0005434731253	270	Economy	27900.00
0005434728000	270	Economy	27900.00
0005434552355	270	Economy	27900.00
0005433181283	270	Economy	27900.00
0005434727932	270	Economy	27900.00
0005434727979	270	Economy	27900.00
0005433766692	270	Economy	27900.00
0005434302549	270	Economy	27900.00
0005434552366	270	Economy	27900.00
0005434727954	270	Economy	27900.00
0005433234899	270	Economy	27900.00
0005433235005	270	Economy	27900.00
0005434727960	270	Economy	27900.00
0005434552377	270	Economy	27900.00
0005433234777	270	Economy	27900.00
0005434727949	270	Economy	27900.00
0005433234706	270	Economy	27900.00
0005434302884	270	Economy	27900.00
0005432278092	270	Economy	27900.00
0005433235194	270	Economy	27900.00
0005433235018	270	Economy	27900.00
0005434552385	270	Economy	27900.00
0005434552383	270	Economy	27900.00
0005434727965	270	Economy	27900.00
0005433235124	270	Economy	27900.00
0005433235019	270	Economy	27900.00
0005434727992	270	Economy	27900.00
0005433766693	270	Economy	27900.00
0005434727988	270	Economy	27900.00
0005435142861	270	Economy	27900.00
0005434731254	270	Economy	27900.00
0005434727995	270	Economy	27900.00
0005434728016	270	Economy	27900.00
0005432278079	270	Economy	27900.00
0005434727975	270	Economy	27900.00
0005433181355	270	Economy	27900.00
0005434727917	270	Economy	27900.00
0005434728005	270	Economy	27900.00
0005433113566	270	Economy	27900.00
0005434727897	270	Economy	27900.00
0005434727910	270	Economy	27900.00
0005434552356	270	Economy	27900.00
0005433181525	270	Economy	27900.00
0005434728018	270	Economy	27900.00
0005434552369	270	Economy	27900.00
0005434728003	270	Economy	27900.00
0005433181553	270	Economy	27900.00
0005434727900	270	Economy	27900.00
0005434552382	270	Economy	27900.00
0005434727904	270	Economy	27900.00
0005434728001	270	Economy	27900.00
0005433235013	270	Economy	27900.00
0005434727970	270	Economy	27900.00
0005434302547	270	Economy	27900.00
0005433234994	270	Economy	27900.00
0005433234961	270	Economy	27900.00
0005432278088	270	Economy	27900.00
0005434552340	270	Economy	27900.00
0005434552359	270	Economy	27900.00
0005434552334	270	Economy	27900.00
0005434552379	270	Economy	27900.00
0005433131776	270	Economy	27900.00
0005433234907	270	Economy	27900.00
0005433181457	270	Economy	27900.00
0005433234900	270	Economy	27900.00
0005434552339	270	Economy	27900.00
0005433235026	270	Economy	27900.00
0005433235064	270	Economy	27900.00
0005434728008	270	Economy	27900.00
0005433111527	270	Economy	27900.00
0005433289934	270	Economy	27900.00
0005434728009	270	Economy	27900.00
0005433126904	270	Economy	27900.00
0005433181376	270	Economy	27900.00
0005433289961	270	Economy	27900.00
0005433234953	270	Economy	27900.00
0005434727908	270	Economy	27900.00
0005434726227	9824	Business	83700.00
0005434551659	9824	Business	83700.00
0005433235520	9824	Business	83700.00
0005433289996	9824	Business	83700.00
0005434551930	9824	Business	83700.00
0005432199395	9824	Business	83700.00
0005434726567	9824	Business	83700.00
0005435142702	9824	Business	83700.00
0005434551783	9824	Business	83700.00
0005434726798	9824	Business	83700.00
0005435142690	9824	Business	83700.00
0005434727106	9824	Business	83700.00
0005434552089	9824	Business	83700.00
0005433235483	9824	Business	83700.00
0005434727009	9824	Business	83700.00
0005433181630	9824	Business	83700.00
0005433235488	9824	Business	83700.00
0005434727333	9824	Business	83700.00
0005432199388	9824	Business	83700.00
0005434551953	9824	Business	83700.00
0005434726419	9824	Business	83700.00
0005433235518	9824	Business	83700.00
0005434726852	9824	Business	83700.00
0005434551954	9824	Comfort	47400.00
0005433235477	9824	Comfort	47400.00
0005433235519	9824	Comfort	47400.00
0005434726783	9824	Comfort	47400.00
0005433235463	9824	Comfort	47400.00
0005434551646	9824	Comfort	47400.00
0005433126937	9824	Comfort	47400.00
0005434726949	9824	Comfort	47400.00
0005434302505	9824	Comfort	47400.00
0005434551781	9824	Comfort	47400.00
0005434726995	9824	Comfort	47400.00
0005433181627	9824	Comfort	47400.00
0005432199390	9824	Comfort	47400.00
0005433235514	9824	Comfort	47400.00
0005434726871	9824	Comfort	47400.00
0005434726820	9824	Comfort	47400.00
0005434735767	9824	Comfort	47400.00
0005435142674	9824	Comfort	47400.00
0005433181628	9824	Comfort	47400.00
0005433235484	9824	Comfort	47400.00
0005434551929	9824	Comfort	47400.00
0005433181629	9824	Comfort	47400.00
0005434551799	9824	Comfort	47400.00
0005434726638	9824	Comfort	47400.00
0005434726681	9824	Comfort	47400.00
0005434726800	9824	Comfort	47400.00
0005434726909	9824	Comfort	47400.00
0005433235480	9824	Comfort	47400.00
0005434727026	9824	Comfort	47400.00
0005433235482	9824	Comfort	47400.00
0005433126940	9824	Comfort	47400.00
0005433235497	9824	Comfort	47400.00
0005434726446	9824	Comfort	47400.00
0005434726963	9824	Comfort	47400.00
0005433235525	9824	Comfort	47400.00
0005434032120	9824	Comfort	47400.00
0005434727371	9824	Economy	27900.00
0005434735733	9824	Economy	27900.00
0005434726828	9824	Economy	27900.00
0005433235515	9824	Economy	27900.00
0005433113581	9824	Economy	27900.00
0005433235524	9824	Economy	27900.00
0005434726842	9824	Economy	27900.00
0005433289998	9824	Economy	27900.00
0005433181616	9824	Economy	27900.00
0005434551922	9824	Economy	27900.00
0005434727114	9824	Economy	27900.00
0005434302519	9824	Economy	27900.00
0005434726553	9824	Economy	27900.00
0005434726758	9824	Economy	27900.00
0005434727072	9824	Economy	27900.00
0005434551802	9824	Economy	27900.00
0005434551955	9824	Economy	27900.00
0005434551881	9824	Economy	27900.00
0005434726824	9824	Economy	27900.00
0005433235486	9824	Economy	27900.00
0005434726426	9824	Economy	27900.00
0005433235471	9824	Economy	27900.00
0005433126939	9824	Economy	27900.00
0005433235494	9824	Economy	27900.00
0005433235505	9824	Economy	27900.00
0005434726955	9824	Economy	27900.00
0005433235473	9824	Economy	27900.00
0005434551949	9824	Economy	27900.00
0005433129367	9824	Economy	27900.00
0005433235504	9824	Economy	27900.00
0005434551906	9824	Economy	27900.00
0005433235481	9824	Economy	27900.00
0005434551985	9824	Economy	27900.00
0005433235506	9824	Economy	27900.00
0005434727225	9824	Economy	27900.00
0005432199389	9824	Economy	27900.00
0005433235478	9824	Economy	27900.00
0005434551821	9824	Economy	27900.00
0005434726851	9824	Economy	27900.00
0005433235475	9824	Economy	27900.00
0005434727575	9824	Economy	27900.00
0005433181611	9824	Economy	27900.00
0005433129368	9824	Economy	27900.00
0005433235508	9824	Economy	27900.00
0005434727362	9824	Economy	27900.00
0005433181622	9824	Economy	27900.00
0005434726841	9824	Economy	27900.00
0005433289997	9824	Economy	27900.00
0005434727332	9824	Economy	27900.00
0005434726836	9824	Economy	27900.00
0005433235468	9824	Economy	27900.00
0005434551630	9824	Economy	27900.00
0005434726743	9824	Economy	27900.00
0005434727517	9824	Economy	27900.00
0005433235516	9824	Economy	27900.00
0005434726716	9824	Economy	27900.00
0005434551729	9824	Economy	27900.00
0005433235510	9824	Economy	27900.00
0005433235491	9824	Economy	30700.00
0005433235522	9824	Economy	30700.00
0005434726980	9824	Economy	27900.00
0005434727040	9824	Economy	27900.00
0005433181608	9824	Economy	30700.00
0005434726799	9824	Economy	30700.00
0005434727372	9824	Economy	27900.00
0005434727182	9824	Economy	30700.00
0005434727089	9824	Economy	27900.00
0005434727057	9824	Economy	27900.00
0005434552088	9824	Economy	27900.00
0005434551986	9824	Economy	27900.00
0005434727045	9824	Economy	27900.00
0005434551766	9824	Economy	27900.00
0005434727058	9824	Economy	27900.00
0005434726921	9824	Economy	27900.00
0005434727373	9824	Economy	27900.00
0005434726563	9824	Economy	27900.00
0005433289995	9824	Economy	27900.00
0005433181613	9824	Economy	27900.00
0005434726872	9824	Economy	27900.00
0005434727112	9824	Economy	27900.00
0005432199391	9824	Economy	27900.00
0005434726673	9824	Economy	27900.00
0005434551988	9824	Economy	27900.00
0005434551785	9824	Economy	27900.00
0005434302504	9824	Economy	27900.00
0005434726273	9824	Economy	27900.00
0005434726672	9824	Economy	27900.00
0005433235498	9824	Economy	27900.00
0005434727021	9824	Economy	27900.00
0005434727038	9824	Economy	27900.00
0005433235485	9824	Economy	27900.00
0005433181610	9824	Economy	27900.00
0005434727022	9824	Economy	27900.00
0005433181620	9824	Economy	27900.00
0005433181618	9824	Economy	27900.00
0005434726226	9824	Economy	27900.00
0005433235521	9824	Economy	27900.00
0005433289991	9824	Economy	27900.00
0005433235523	9824	Economy	27900.00
0005433766718	9824	Economy	27900.00
0005433235487	9824	Economy	27900.00
0005434727116	9824	Economy	27900.00
0005434727134	9824	Economy	27900.00
0005434551882	9824	Economy	27900.00
0005433235464	9824	Economy	27900.00
0005434551666	9824	Economy	27900.00
0005433235503	9824	Economy	27900.00
0005434727234	9824	Economy	27900.00
0005434726856	9824	Economy	27900.00
0005433235502	9824	Economy	27900.00
0005433235527	9824	Economy	27900.00
0005433181626	9824	Economy	27900.00
0005433235511	9824	Economy	27900.00
0005433235513	9824	Economy	27900.00
0005433235500	9824	Economy	27900.00
0005434302520	9824	Economy	27900.00
0005435142735	9824	Economy	27900.00
0005434032117	9824	Economy	27900.00
0005433289993	9824	Economy	27900.00
0005435142712	9824	Economy	27900.00
0005433235470	9824	Economy	27900.00
0005434726494	9824	Economy	27900.00
0005433289994	9824	Economy	27900.00
0005434727115	9824	Economy	27900.00
0005433129370	9824	Economy	27900.00
0005434726801	9824	Economy	27900.00
0005433235517	9824	Economy	27900.00
0005433235529	9824	Economy	27900.00
0005433181615	9824	Economy	27900.00
0005434726759	9824	Economy	27900.00
0005433235499	9824	Economy	27900.00
0005433235466	9824	Economy	27900.00
0005435142707	9824	Economy	27900.00
0005434726450	9824	Economy	27900.00
0005433181607	9824	Economy	27900.00
0005433766719	9824	Economy	27900.00
0005434727224	9824	Economy	27900.00
0005433235472	9824	Economy	27900.00
0005433181624	9824	Economy	27900.00
0005434726821	9824	Economy	27900.00
0005434727451	9824	Economy	27900.00
0005434726825	9824	Economy	27900.00
0005433235479	9824	Economy	27900.00
0005433235528	9824	Economy	27900.00
0005433235469	9824	Economy	27900.00
0005434551786	9824	Economy	27900.00
0005434726853	9824	Economy	27900.00
0005434727039	9824	Economy	27900.00
0005434726509	9824	Economy	27900.00
0005434726960	9824	Economy	27900.00
0005434726595	9824	Economy	27900.00
0005433126936	9824	Economy	27900.00
0005433181625	9824	Economy	27900.00
0005433181614	9824	Economy	27900.00
0005433235490	9824	Economy	27900.00
0005434726574	9824	Economy	27900.00
0005433181612	9824	Economy	27900.00
0005433113580	9824	Economy	27900.00
0005434726849	9824	Economy	27900.00
0005433129369	9824	Economy	30700.00
0005435142649	9824	Economy	27900.00
0005435142704	9824	Economy	30700.00
0005434726785	9824	Economy	30700.00
0005435142696	9824	Economy	30700.00
0005434727118	9824	Economy	30700.00
0005434735755	9824	Economy	27900.00
0005433235493	9824	Economy	27900.00
0005434551574	9824	Economy	27900.00
0005434726493	9824	Economy	27900.00
0005434726902	9824	Economy	27900.00
0005434735768	9824	Economy	27900.00
0005434726945	9824	Economy	27900.00
0005435142764	9824	Economy	27900.00
0005433235507	9824	Economy	27900.00
0005433235512	9824	Economy	27900.00
0005433235489	9824	Economy	27900.00
0005435142759	9824	Economy	27900.00
0005434726823	9824	Economy	27900.00
0005434727044	9824	Economy	27900.00
0005434551667	9824	Economy	27900.00
0005434726956	9824	Economy	27900.00
0005434726680	9824	Economy	27900.00
0005433181619	9824	Economy	27900.00
0005434551925	9824	Economy	27900.00
0005433235474	9824	Economy	27900.00
0005435142705	9824	Economy	27900.00
0005434551573	9824	Economy	27900.00
0005434731214	9824	Economy	27900.00
0005434551924	9824	Economy	27900.00
0005432199394	9824	Economy	27900.00
0005432199393	9824	Economy	27900.00
0005433235526	9824	Economy	27900.00
0005432199392	9824	Economy	27900.00
0005434551948	9824	Economy	27900.00
0005434726860	9824	Economy	27900.00
0005435142652	9824	Economy	27900.00
0005434726857	9824	Economy	27900.00
0005433181606	9824	Economy	27900.00
0005433235492	9824	Economy	27900.00
0005434726396	9824	Economy	27900.00
0005433235509	9824	Economy	27900.00
0005434727314	9824	Economy	27900.00
0005434727107	9824	Economy	27900.00
0005434726894	9824	Economy	27900.00
0005434032121	9824	Economy	27900.00
0005434735732	9824	Economy	27900.00
0005434726843	9824	Economy	27900.00
0005433235496	9824	Economy	27900.00
0005434726822	9824	Economy	27900.00
0005435142713	9824	Economy	27900.00
0005434726397	9824	Economy	27900.00
0005433126938	9824	Economy	27900.00
0005433181621	9824	Economy	27900.00
0005433289992	9824	Economy	27900.00
0005434726911	9824	Economy	27900.00
0005434726946	9824	Economy	27900.00
0005434302493	9824	Economy	27900.00
0005434726959	9824	Economy	27900.00
0005434727020	9824	Economy	27900.00
0005434726784	9824	Economy	27900.00
0005434551725	9824	Economy	27900.00
0005434551928	9824	Economy	27900.00
0005434032118	9824	Economy	27900.00
0005434727452	9824	Economy	27900.00
0005435142653	9824	Economy	27900.00
0005433181617	9824	Economy	27900.00
0005433235465	9824	Economy	27900.00
0005434726691	9824	Economy	27900.00
0005434551517	9824	Economy	27900.00
0005434726554	9824	Economy	27900.00
0005434727117	9824	Economy	27900.00
0005433766717	9824	Economy	27900.00
0005434552100	9824	Economy	27900.00
0005435142706	9824	Economy	27900.00
0005434726654	9824	Economy	27900.00
0005434551784	9824	Economy	27900.00
0005433235476	9824	Economy	27900.00
0005433235467	9824	Economy	27900.00
0005434726717	9824	Economy	27900.00
0005433181623	9824	Economy	27900.00
0005434032119	9824	Economy	27900.00
0005433235501	9824	Economy	27900.00
0005434735734	9824	Economy	27900.00
0005434726447	9824	Economy	27900.00
0005434551713	9824	Economy	27900.00
0005433129371	9824	Economy	27900.00
0005434551720	9824	Economy	27900.00
0005433235495	9824	Economy	27900.00
0005434727172	9824	Economy	27900.00
0005433181609	9824	Economy	27900.00
0005434551719	9824	Economy	27900.00
0005434727167	9824	Economy	27900.00
0005432530623	7728	Business	42100.00
0005432530710	7728	Business	42100.00
0005432530714	7728	Business	42100.00
0005434069015	7728	Business	42100.00
0005434069019	7728	Business	42100.00
0005432530678	7728	Business	42100.00
0005435630992	7728	Business	42100.00
0005434069038	7728	Business	42100.00
0005434068991	7728	Business	42100.00
0005432530671	7728	Business	42100.00
0005435214606	7728	Business	42100.00
0005435214287	7728	Business	42100.00
0005435630991	7728	Business	42100.00
0005435214490	7728	Business	42100.00
0005432530705	7728	Business	42100.00
0005435214308	7728	Business	42100.00
0005432429001	7728	Business	42100.00
0005432535933	7728	Business	42100.00
0005433656723	7728	Business	42100.00
0005434069024	7728	Business	42100.00
0005432530686	7728	Business	42100.00
0005434069010	7728	Comfort	23900.00
0005435214175	7728	Comfort	23900.00
0005432530722	7728	Comfort	23900.00
0005432530617	7728	Comfort	23900.00
0005434069030	7728	Comfort	23900.00
0005432530727	7728	Comfort	23900.00
0005435214541	7728	Comfort	23900.00
0005434069031	7728	Comfort	23900.00
0005432069955	7728	Comfort	23900.00
0005435725664	7728	Comfort	23900.00
0005434068986	7728	Comfort	23900.00
0005432530670	7728	Comfort	23900.00
0005435214371	7728	Comfort	23900.00
0005432530717	7728	Comfort	23900.00
0005435214279	7728	Comfort	23900.00
0005432530598	7728	Comfort	23900.00
0005432530653	7728	Comfort	23900.00
0005434069054	7728	Comfort	23900.00
0005432069947	7728	Comfort	23900.00
0005432530616	7728	Comfort	23900.00
0005435214174	7728	Comfort	23900.00
0005434069021	7728	Comfort	23900.00
0005432530646	7728	Comfort	23900.00
0005435214482	7728	Comfort	23900.00
0005432530618	7728	Comfort	23900.00
0005432150352	7728	Comfort	23900.00
0005432530649	7728	Comfort	23900.00
0005435214374	7728	Comfort	23900.00
0005434068998	7728	Comfort	23900.00
0005435214258	7728	Comfort	23900.00
0005432533349	7728	Comfort	23900.00
0005435214340	7728	Comfort	23900.00
0005432530611	7728	Comfort	23900.00
0005432069948	7728	Comfort	23900.00
0005432533351	7728	Comfort	23900.00
0005432530597	7728	Comfort	23900.00
0005432530610	7728	Comfort	23900.00
0005434069001	7728	Comfort	23900.00
0005432530698	7728	Comfort	23900.00
0005432069956	7728	Comfort	23900.00
0005434068993	7728	Comfort	23900.00
0005434069036	7728	Comfort	23900.00
0005435214595	7728	Economy	14000.00
0005432530726	7728	Economy	14000.00
0005435630985	7728	Economy	14000.00
0005435725644	7728	Economy	14000.00
0005432530606	7728	Economy	14000.00
0005432150356	7728	Economy	14000.00
0005435214315	7728	Economy	14000.00
0005432530661	7728	Economy	14000.00
0005432530609	7728	Economy	14000.00
0005435214613	7728	Economy	14000.00
0005435214612	7728	Economy	14000.00
0005432530644	7728	Economy	14000.00
0005432530707	7728	Economy	14000.00
0005432530638	7728	Economy	14000.00
0005432530682	7728	Economy	14000.00
0005434069042	7728	Economy	14000.00
0005432530730	7728	Economy	14000.00
0005434069049	7728	Economy	14000.00
0005435214487	7728	Economy	14000.00
0005432530637	7728	Economy	14000.00
0005432530724	7728	Economy	14000.00
0005432530621	7728	Economy	14000.00
0005432530603	7728	Economy	14000.00
0005432530630	7728	Economy	14000.00
0005435214139	7728	Economy	14000.00
0005434068996	7728	Economy	14000.00
0005435214457	7728	Economy	14000.00
0005435214413	7728	Economy	14000.00
0005432530660	7728	Economy	14000.00
0005435725658	7728	Economy	14000.00
0005432069957	7728	Economy	14000.00
0005434069027	7728	Economy	14000.00
0005432530629	7728	Economy	14000.00
0005434068985	7728	Economy	14000.00
0005432530663	7728	Economy	14000.00
0005432530599	7728	Economy	14000.00
0005432530636	7728	Economy	14000.00
0005435214349	7728	Economy	14000.00
0005435214365	7728	Economy	14000.00
0005434069034	7728	Economy	14000.00
0005435214207	7728	Economy	14000.00
0005435214461	7728	Economy	14000.00
0005434069018	7728	Economy	14000.00
0005432530672	7728	Economy	14000.00
0005432537101	7728	Economy	14000.00
0005435214458	7728	Economy	14000.00
0005432530712	7728	Economy	14000.00
0005432530725	7728	Economy	14000.00
0005432530641	7728	Economy	14000.00
0005435725640	7728	Economy	14000.00
0005435214496	7728	Economy	14000.00
0005434069040	7728	Economy	14000.00
0005434069053	7728	Economy	14000.00
0005432535931	7728	Economy	14000.00
0005432530696	7728	Economy	14000.00
0005432150353	7728	Economy	14000.00
0005434069032	7728	Economy	14000.00
0005434068995	7728	Economy	14000.00
0005434069051	7728	Economy	14000.00
0005435214341	7728	Economy	14000.00
0005434069056	7728	Economy	14000.00
0005432530729	7728	Economy	14000.00
0005432530673	7728	Economy	14000.00
0005434069007	7728	Economy	15400.00
0005432530647	7728	Economy	14000.00
0005435214211	7728	Economy	14000.00
0005435725663	7728	Economy	14000.00
0005434069055	7728	Economy	14000.00
0005435214435	7728	Economy	15400.00
0005435213986	7728	Economy	15400.00
0005434069035	7728	Economy	14000.00
0005434069017	7728	Economy	14000.00
0005435725641	7728	Economy	14000.00
0005432530601	7728	Economy	14000.00
0005435214231	7728	Economy	14000.00
0005434068990	7728	Economy	14000.00
0005435214564	7728	Economy	14000.00
0005432530634	7728	Economy	14000.00
0005434069020	7728	Economy	14000.00
0005432069952	7728	Economy	14000.00
0005434068989	7728	Economy	14000.00
0005432530619	7728	Economy	14000.00
0005432530643	7728	Economy	14000.00
0005432530692	7728	Economy	14000.00
0005432530628	7728	Economy	14000.00
0005435214515	7728	Economy	14000.00
0005432530687	7728	Economy	14000.00
0005434068997	7728	Economy	14000.00
0005432530622	7728	Economy	14000.00
0005432530675	7728	Economy	14000.00
0005432150358	7728	Economy	14000.00
0005434069005	7728	Economy	14000.00
0005432530604	7728	Economy	14000.00
0005432150357	7728	Economy	14000.00
0005432069946	7728	Economy	14000.00
0005435214473	7728	Economy	14000.00
0005432530699	7728	Economy	14000.00
0005434069002	7728	Economy	14000.00
0005435214514	7728	Economy	14000.00
0005432428999	7728	Economy	14000.00
0005435214472	7728	Economy	14000.00
0005435214274	7728	Economy	14000.00
0005432530620	7728	Economy	14000.00
0005432530704	7728	Economy	14000.00
0005435214320	7728	Economy	14000.00
0005432530685	7728	Economy	14000.00
0005432150354	7728	Economy	14000.00
0005432530651	7728	Economy	14000.00
0005434069008	7728	Economy	14000.00
0005434069011	7728	Economy	14000.00
0005434069014	7728	Economy	14000.00
0005435214278	7728	Economy	14000.00
0005432537100	7728	Economy	14000.00
0005434069009	7728	Economy	14000.00
0005434069004	7728	Economy	14000.00
0005432069945	7728	Economy	14000.00
0005435214607	7728	Economy	14000.00
0005434068999	7728	Economy	14000.00
0005433656722	7728	Economy	14000.00
0005435725649	7728	Economy	14000.00
0005434069043	7728	Economy	14000.00
0005432530711	7728	Economy	14000.00
0005434069045	7728	Economy	14000.00
0005434069041	7728	Economy	14000.00
0005434069052	7728	Economy	14000.00
0005432530702	7728	Economy	14000.00
0005435631003	7728	Economy	14000.00
0005435214502	7728	Economy	14000.00
0005432069958	7728	Economy	14000.00
0005432530645	7728	Economy	14000.00
0005432530719	7728	Economy	14000.00
0005432530657	7728	Economy	14000.00
0005434069023	7728	Economy	14000.00
0005434069028	7728	Economy	14000.00
0005434069012	7728	Economy	14000.00
0005432530684	7728	Economy	14000.00
0005435725661	7728	Economy	14000.00
0005432530605	7728	Economy	14000.00
0005432530658	7728	Economy	14000.00
0005435214532	7728	Economy	14000.00
0005432530677	7728	Economy	14000.00
0005432530639	7728	Economy	14000.00
0005432530708	7728	Economy	14000.00
0005434069022	7728	Economy	14000.00
0005432530642	7728	Economy	14000.00
0005432530600	7728	Economy	14000.00
0005434069025	7728	Economy	14000.00
0005432530624	7728	Economy	14000.00
0005432530648	7728	Economy	14000.00
0005434069050	7728	Economy	14000.00
0005432069959	7728	Economy	14000.00
0005435214302	7728	Economy	14000.00
0005432530668	7728	Economy	14000.00
0005435214557	7728	Economy	14000.00
0005435214449	7728	Economy	14000.00
0005432530640	7728	Economy	14000.00
0005432429000	7728	Economy	14000.00
0005435214634	7728	Economy	14000.00
0005432530728	7728	Economy	14000.00
0005432530654	7728	Economy	14000.00
0005435214437	7728	Economy	14000.00
0005435214605	7728	Economy	14000.00
0005432530681	7728	Economy	14000.00
0005432537102	7728	Economy	14000.00
0005432069949	7728	Economy	14000.00
0005435214376	7728	Economy	14000.00
0005432069953	7728	Economy	14000.00
0005432530690	7728	Economy	14000.00
0005432530679	7728	Economy	14000.00
0005435214364	7728	Economy	14000.00
0005432530674	7728	Economy	14000.00
0005432530703	7728	Economy	14000.00
0005432530716	7728	Economy	14000.00
0005432530659	7728	Economy	14000.00
0005432530695	7728	Economy	14000.00
0005432530612	7728	Economy	14000.00
0005435214404	7728	Economy	15400.00
0005432530614	7728	Economy	14000.00
0005432530602	7728	Economy	15400.00
0005432530626	7728	Economy	15400.00
0005432069951	7728	Economy	14000.00
0005432530700	7728	Economy	14000.00
0005432530666	7728	Economy	14000.00
0005435725645	7728	Economy	14000.00
0005432530664	7728	Economy	14000.00
0005432530656	7728	Economy	14000.00
0005432530721	7728	Economy	14000.00
0005435631002	7728	Economy	14000.00
0005432535932	7728	Economy	14000.00
0005434068983	7728	Economy	14000.00
0005432535934	7728	Economy	14000.00
0005432530680	7728	Economy	14000.00
0005435214440	7728	Economy	14000.00
0005435214210	7728	Economy	14000.00
0005435725646	7728	Economy	14000.00
0005435214241	7728	Economy	14000.00
0005432530607	7728	Economy	14000.00
0005432530669	7728	Economy	14000.00
0005432530667	7728	Economy	14000.00
0005434068994	7728	Economy	14000.00
0005435725642	7728	Economy	14000.00
0005434069000	7728	Economy	14000.00
0005435214240	7728	Economy	14000.00
0005435214285	7728	Economy	14000.00
0005432530652	7728	Economy	14000.00
0005432530627	7728	Economy	14000.00
0005435725648	7728	Economy	14000.00
0005435725657	7728	Economy	14000.00
0005432530709	7728	Economy	14000.00
0005432150359	7728	Economy	14000.00
0005435214816	7728	Economy	14000.00
0005432530701	7728	Economy	14000.00
0005432530631	7728	Economy	14000.00
0005432069950	7728	Economy	14000.00
0005434069013	7728	Economy	14000.00
0005435214415	7728	Economy	14000.00
0005434069048	7728	Economy	14000.00
0005434069016	7728	Economy	14000.00
0005432530697	7728	Economy	14000.00
0005432530691	7728	Economy	14000.00
0005434069006	7728	Economy	14000.00
0005432535935	7728	Economy	14000.00
0005434069039	7728	Economy	14000.00
0005434069026	7728	Economy	14000.00
0005435214635	7728	Economy	14000.00
0005432530718	7728	Economy	14000.00
0005432069954	7728	Economy	14000.00
0005432530706	7728	Economy	14000.00
0005435725647	7728	Economy	14000.00
0005434068988	7728	Economy	14000.00
0005432530713	7728	Economy	14000.00
0005434069003	7728	Economy	14000.00
0005434068992	7728	Economy	14000.00
0005432530665	7728	Economy	14000.00
0005435214061	7728	Economy	14000.00
0005432533350	7728	Economy	14000.00
0005432530723	7728	Economy	14000.00
0005435630995	7728	Economy	14000.00
0005434069044	7728	Economy	14000.00
0005435214443	7728	Economy	14000.00
0005435214286	7728	Economy	14000.00
0005435214453	7728	Economy	14000.00
0005432530625	7728	Economy	14000.00
0005434069046	7728	Economy	14000.00
0005435214815	7728	Economy	14000.00
0005432530615	7728	Economy	14000.00
0005432530633	7728	Economy	14000.00
0005432530608	7728	Economy	14000.00
0005432530720	7728	Economy	14000.00
0005432530688	7728	Economy	14000.00
0005434069037	7728	Economy	14000.00
0005432530635	7728	Economy	14000.00
0005435214408	7728	Economy	14000.00
0005434068987	7728	Economy	14000.00
0005432530662	7728	Economy	14000.00
0005432530715	7728	Economy	14000.00
0005435214451	7728	Economy	14000.00
0005432530694	7728	Economy	14000.00
0005435725638	7728	Economy	14000.00
0005432428998	7728	Economy	14000.00
0005432530689	7728	Economy	14000.00
0005435725660	7728	Economy	14000.00
0005432150355	7728	Economy	14000.00
0005435214483	7728	Economy	14000.00
0005434069029	7728	Economy	14000.00
0005432530650	7728	Economy	14000.00
0005435214168	7728	Economy	14000.00
0005432530613	7728	Economy	14000.00
0005435214056	7728	Economy	14000.00
0005435214375	7728	Economy	14000.00
0005434068984	7728	Economy	14000.00
0005432530693	7728	Economy	14000.00
0005432530676	7728	Economy	14000.00
0005435214563	7728	Economy	14000.00
0005432530655	7728	Economy	14000.00
0005434069033	7728	Economy	14000.00
0005432530632	7728	Economy	14000.00
0005432530683	7728	Economy	14000.00
0005434069047	7728	Economy	14000.00
0005435615954	5320	Business	43100.00
0005435615923	5320	Business	43100.00
0005435615909	5320	Business	43100.00
0005435615936	5320	Business	43100.00
0005435425734	5320	Business	43100.00
0005434573641	5320	Business	43100.00
0005435425681	5320	Business	43100.00
0005434344947	5320	Business	43100.00
0005435615955	5320	Business	43100.00
0005435490304	5320	Business	43100.00
0005435615917	5320	Business	43100.00
0005434344946	5320	Business	43100.00
0005434344950	5320	Business	43100.00
0005435615951	5320	Business	43100.00
0005435425572	5320	Business	43100.00
0005435319715	5320	Business	43100.00
0005434245350	5320	Business	43100.00
0005435490302	5320	Business	43100.00
0005435615907	5320	Business	43100.00
0005435302258	5320	Business	43100.00
0005435425605	5320	Business	43100.00
0005435615988	5320	Business	43100.00
0005435319694	5320	Business	43100.00
0005435097408	5320	Business	43100.00
0005435425829	5320	Business	43100.00
0005435615904	5320	Business	43100.00
0005435615901	5320	Business	43100.00
0005435555411	5320	Comfort	24400.00
0005435616001	5320	Business	43100.00
0005435615914	5320	Comfort	24400.00
0005435615986	5320	Comfort	24400.00
0005435425755	5320	Comfort	24400.00
0005434573648	5320	Comfort	24400.00
0005435425675	5320	Comfort	24400.00
0005435425925	5320	Comfort	24400.00
0005435615930	5320	Comfort	24400.00
0005435615933	5320	Comfort	24400.00
0005435425737	5320	Comfort	24400.00
0005435426101	5320	Comfort	24400.00
0005435097414	5320	Comfort	24400.00
0005435319695	5320	Comfort	24400.00
0005435615911	5320	Comfort	24400.00
0005435425456	5320	Comfort	24400.00
0005435615943	5320	Comfort	24400.00
0005435380360	5320	Comfort	24400.00
0005434245437	5320	Comfort	24400.00
0005434573646	5320	Comfort	24400.00
0005435425573	5320	Comfort	24400.00
0005435615963	5320	Comfort	24400.00
0005435425304	5320	Comfort	24400.00
0005432363453	5320	Comfort	24400.00
0005435615974	5320	Comfort	24400.00
0005434245285	5320	Comfort	24400.00
0005434573642	5320	Comfort	24400.00
0005434245392	5320	Comfort	24400.00
0005434245397	5320	Comfort	24400.00
0005435615931	5320	Comfort	24400.00
0005434573636	5320	Comfort	24400.00
0005435615961	5320	Comfort	24400.00
0005435425427	5320	Comfort	24400.00
0005434344931	5320	Comfort	24400.00
0005435615985	5320	Comfort	24400.00
0005435615998	5320	Comfort	24400.00
0005435616000	5320	Comfort	24400.00
0005435425499	5320	Comfort	24400.00
0005434344943	5320	Comfort	24400.00
0005435615959	5320	Comfort	24400.00
0005435615983	5320	Comfort	24400.00
0005435425873	5320	Comfort	24400.00
0005435616006	5320	Comfort	24400.00
0005435097413	5320	Comfort	24400.00
0005435425691	5320	Economy	14400.00
0005435425816	5320	Economy	14400.00
0005435425577	5320	Economy	14400.00
0005435425754	5320	Economy	14400.00
0005434344964	5320	Economy	14400.00
0005435302271	5320	Economy	14400.00
0005434573645	5320	Economy	14400.00
0005435425500	5320	Economy	14400.00
0005435319692	5320	Economy	14400.00
0005435425436	5320	Economy	14400.00
0005435425305	5320	Economy	14400.00
0005435615906	5320	Economy	14400.00
0005432133515	5320	Economy	14400.00
0005435305036	5320	Economy	14400.00
0005435305032	5320	Economy	14400.00
0005435546236	5320	Economy	14400.00
0005432133514	5320	Economy	14400.00
0005435615978	5320	Economy	14400.00
0005434245284	5320	Economy	14400.00
0005435615973	5320	Economy	14400.00
0005435425814	5320	Economy	14400.00
0005434344962	5320	Economy	14400.00
0005434245352	5320	Economy	14400.00
0005434573643	5320	Economy	14400.00
0005432133529	5320	Economy	14400.00
0005434344939	5320	Economy	14400.00
0005432841039	5320	Economy	14400.00
0005435425815	5320	Economy	14400.00
0005435425872	5320	Economy	14400.00
0005435425670	5320	Economy	14400.00
0005434573649	5320	Economy	14400.00
0005434344941	5320	Economy	14400.00
0005435425743	5320	Economy	14400.00
0005435615995	5320	Economy	14400.00
0005435546235	5320	Economy	14400.00
0005435616008	5320	Economy	14400.00
0005435319677	5320	Economy	14400.00
0005435615946	5320	Economy	14400.00
0005435615994	5320	Economy	14400.00
0005435615920	5320	Economy	14400.00
0005435615958	5320	Economy	14400.00
0005435615991	5320	Economy	14400.00
0005434344937	5320	Economy	14400.00
0005434656579	5320	Economy	14400.00
0005434245254	5320	Economy	14400.00
0005432363450	5320	Economy	14400.00
0005432133527	5320	Economy	14400.00
0005435097409	5320	Economy	14400.00
0005435615952	5320	Economy	14400.00
0005432133528	5320	Economy	14400.00
0005434344942	5320	Economy	14400.00
0005435615966	5320	Economy	14400.00
0005435425497	5320	Economy	14400.00
0005435615993	5320	Economy	14400.00
0005435302247	5320	Economy	14400.00
0005435615979	5320	Economy	14400.00
0005435425489	5320	Economy	14400.00
0005435042883	5320	Economy	14400.00
0005435425429	5320	Economy	14400.00
0005435425745	5320	Economy	14400.00
0005435615919	5320	Economy	15800.00
0005434245250	5320	Economy	14400.00
0005434245157	5320	Economy	14400.00
0005434245314	5320	Economy	14400.00
0005434245313	5320	Economy	14400.00
0005435615918	5320	Economy	15800.00
0005432363449	5320	Economy	15800.00
0005435319668	5320	Economy	15800.00
0005434344940	5320	Economy	14400.00
0005435615996	5320	Economy	14400.00
0005435546234	5320	Economy	14400.00
0005434245351	5320	Economy	14400.00
0005435425268	5320	Economy	14400.00
0005434344959	5320	Economy	14400.00
0005432047626	5320	Economy	14400.00
0005435615945	5320	Economy	14400.00
0005434344966	5320	Economy	14400.00
0005435616003	5320	Economy	14400.00
0005435615965	5320	Economy	14400.00
0005434245321	5320	Economy	14400.00
0005435425464	5320	Economy	14400.00
0005435319688	5320	Economy	14400.00
0005435426011	5320	Economy	14400.00
0005434656573	5320	Economy	14400.00
0005435615908	5320	Economy	14400.00
0005435042882	5320	Economy	14400.00
0005435615984	5320	Economy	14400.00
0005434245443	5320	Economy	14400.00
0005435425674	5320	Economy	14400.00
0005435042877	5320	Economy	14400.00
0005435491483	5320	Economy	14400.00
0005435615950	5320	Economy	14400.00
0005435380359	5320	Economy	14400.00
0005435616009	5320	Economy	14400.00
0005435615964	5320	Economy	14400.00
0005435319693	5320	Economy	14400.00
0005434344957	5320	Economy	14400.00
0005432047625	5320	Economy	14400.00
0005434573635	5320	Economy	14400.00
0005435615913	5320	Economy	14400.00
0005435615992	5320	Economy	14400.00
0005435615976	5320	Economy	14400.00
0005435302272	5320	Economy	14400.00
0005435615956	5320	Economy	14400.00
0005434573638	5320	Economy	14400.00
0005435319682	5320	Economy	14400.00
0005435615960	5320	Economy	14400.00
0005435425544	5320	Economy	14400.00
0005435615987	5320	Economy	14400.00
0005435425621	5320	Economy	14400.00
0005434245208	5320	Economy	14400.00
0005435615935	5320	Economy	14400.00
0005432133522	5320	Economy	14400.00
0005435305037	5320	Economy	14400.00
0005434245396	5320	Economy	14400.00
0005434344945	5320	Economy	14400.00
0005435615997	5320	Economy	14400.00
0005432133518	5320	Economy	14400.00
0005434344952	5320	Economy	14400.00
0005435615975	5320	Economy	14400.00
0005432133517	5320	Economy	14400.00
0005432133525	5320	Economy	14400.00
0005435425643	5320	Economy	14400.00
0005435425894	5320	Economy	14400.00
0005434344932	5320	Economy	14400.00
0005435615967	5320	Economy	14400.00
0005432133516	5320	Economy	14400.00
0005432363451	5320	Economy	14400.00
0005435319702	5320	Economy	14400.00
0005434573647	5320	Economy	14400.00
0005434344934	5320	Economy	14400.00
0005434344949	5320	Economy	14400.00
0005435097405	5320	Economy	14400.00
0005435615972	5320	Economy	14400.00
0005435615922	5320	Economy	14400.00
0005435615944	5320	Economy	14400.00
0005435319681	5320	Economy	14400.00
0005435616004	5320	Economy	14400.00
0005435425346	5320	Economy	14400.00
0005434245126	5320	Economy	14400.00
0005435097407	5320	Economy	14400.00
0005435097411	5320	Economy	14400.00
0005434245320	5320	Economy	14400.00
0005435425953	5320	Economy	14400.00
0005435615968	5320	Economy	14400.00
0005435615980	5320	Economy	14400.00
0005435042881	5320	Economy	14400.00
0005432133524	5320	Economy	14400.00
0005435425667	5320	Economy	14400.00
0005435425587	5320	Economy	14400.00
0005435616005	5320	Economy	14400.00
0005435380327	5320	Economy	14400.00
0005435616007	5320	Economy	14400.00
0005434344951	5320	Economy	14400.00
0005434245449	5320	Economy	14400.00
0005434344936	5320	Economy	14400.00
0005435425765	5320	Economy	14400.00
0005435302265	5320	Economy	14400.00
0005435615902	5320	Economy	14400.00
0005434344958	5320	Economy	14400.00
0005435555412	5320	Economy	14400.00
0005434344963	5320	Economy	14400.00
0005434344961	5320	Economy	14400.00
0005435615948	5320	Economy	14400.00
0005435425713	5320	Economy	14400.00
0005434245253	5320	Economy	14400.00
0005435615921	5320	Economy	14400.00
0005435425744	5320	Economy	14400.00
0005435425689	5320	Economy	14400.00
0005435425700	5320	Economy	14400.00
0005435615977	5320	Economy	14400.00
0005435615971	5320	Economy	14400.00
0005435425641	5320	Economy	14400.00
0005435425668	5320	Economy	14400.00
0005434573644	5320	Economy	14400.00
0005435615990	5320	Economy	14400.00
0005435425694	5320	Economy	14400.00
0005435319679	5320	Economy	15800.00
0005434344956	5320	Economy	15800.00
0005435615969	5320	Economy	15800.00
0005435615934	5320	Economy	14400.00
0005435491484	5320	Economy	14400.00
0005435616002	5320	Economy	14400.00
0005435615915	5320	Economy	14400.00
0005434573637	5320	Economy	14400.00
0005434245358	5320	Economy	14400.00
0005435425607	5320	Economy	14400.00
0005434344948	5320	Economy	14400.00
0005434344953	5320	Economy	14400.00
0005435615941	5320	Economy	14400.00
0005435615910	5320	Economy	14400.00
0005435425695	5320	Economy	14400.00
0005435425843	5320	Economy	14400.00
0005435319696	5320	Economy	14400.00
0005435426102	5320	Economy	14400.00
0005434344944	5320	Economy	14400.00
0005432363454	5320	Economy	14400.00
0005435615957	5320	Economy	14400.00
0005435615970	5320	Economy	14400.00
0005435425793	5320	Economy	14400.00
0005434573639	5320	Economy	14400.00
0005434344960	5320	Economy	14400.00
0005434344938	5320	Economy	14400.00
0005435425345	5320	Economy	14400.00
0005432133526	5320	Economy	14400.00
0005435380338	5320	Economy	14400.00
0005435615905	5320	Economy	14400.00
0005434656580	5320	Economy	14400.00
0005435302249	5320	Economy	14400.00
0005435615938	5320	Economy	14400.00
0005435097410	5320	Economy	14400.00
0005435425811	5320	Economy	14400.00
0005435615939	5320	Economy	14400.00
0005435615928	5320	Economy	14400.00
0005435097406	5320	Economy	14400.00
0005435425803	5320	Economy	14400.00
0005435615916	5320	Economy	14400.00
0005432047627	5320	Economy	14400.00
0005434245357	5320	Economy	14400.00
0005435425463	5320	Economy	14400.00
0005435615926	5320	Economy	14400.00
0005435380364	5320	Economy	14400.00
0005435425452	5320	Economy	14400.00
0005435615949	5320	Economy	14400.00
0005435490303	5320	Economy	14400.00
0005435425910	5320	Economy	14400.00
0005435425792	5320	Economy	14400.00
0005435425794	5320	Economy	14400.00
0005435425849	5320	Economy	14400.00
0005435615953	5320	Economy	14400.00
0005435425437	5320	Economy	14400.00
0005435425850	5320	Economy	14400.00
0005434573640	5320	Economy	14400.00
0005435615940	5320	Economy	14400.00
0005435615924	5320	Economy	14400.00
0005435302246	5320	Economy	14400.00
0005434245315	5320	Economy	14400.00
0005435615927	5320	Economy	14400.00
0005432133523	5320	Economy	14400.00
0005435491485	5320	Economy	14400.00
0005435615999	5320	Economy	14400.00
0005435425753	5320	Economy	14400.00
0005434344955	5320	Economy	14400.00
0005435425428	5320	Economy	14400.00
0005435615929	5320	Economy	14400.00
0005435615947	5320	Economy	14400.00
0005435425673	5320	Economy	14400.00
0005432133519	5320	Economy	14400.00
0005435425669	5320	Economy	14400.00
0005435302235	5320	Economy	14400.00
0005434344935	5320	Economy	14400.00
0005435097412	5320	Economy	14400.00
0005432133521	5320	Economy	14400.00
0005434344933	5320	Economy	14400.00
0005435380339	5320	Economy	14400.00
0005434245249	5320	Economy	14400.00
0005435615962	5320	Economy	14400.00
0005435615932	5320	Economy	14400.00
0005435425690	5320	Economy	14400.00
0005434344965	5320	Economy	14400.00
0005435615989	5320	Economy	14400.00
0005435425714	5320	Economy	14400.00
0005435490301	5320	Economy	14400.00
0005435425462	5320	Economy	14400.00
0005434344930	5320	Economy	14400.00
0005434656574	5320	Economy	14400.00
0005434245283	5320	Economy	14400.00
0005435615925	5320	Economy	14400.00
0005432133520	5320	Economy	14400.00
0005435615981	5320	Economy	14400.00
0005434245436	5320	Economy	14400.00
0005435615942	5320	Economy	14400.00
0005434344954	5320	Economy	14400.00
0005435615912	5320	Economy	14400.00
0005432047628	5320	Economy	14400.00
0005435615903	5320	Economy	14400.00
0005435615937	5320	Economy	14400.00
0005435615982	5320	Economy	14400.00
0005434344631	10898	Business	43100.00
0005435042901	10898	Business	43100.00
0005435614799	10898	Business	43100.00
0005435426247	10898	Business	43100.00
0005434245589	10898	Business	43100.00
0005435615245	10898	Business	43100.00
0005434573498	10898	Business	43100.00
0005434344593	10898	Business	43100.00
0005435615487	10898	Business	43100.00
0005435426209	10898	Business	43100.00
0005434245583	10898	Business	43100.00
0005435615385	10898	Business	43100.00
0005435614831	10898	Business	43100.00
0005433719210	10898	Business	43100.00
0005435426214	10898	Business	43100.00
0005435615169	10898	Business	43100.00
0005435319757	10898	Business	43100.00
0005435426196	10898	Business	43100.00
0005435491462	10898	Business	43100.00
0005435615032	10898	Business	43100.00
0005435426218	10898	Business	43100.00
0005435615293	10898	Business	43100.00
0005435097302	10898	Business	43100.00
0005432363484	10898	Business	43100.00
0005435614572	10898	Business	43100.00
0005432166968	10898	Business	43100.00
0005434245578	10898	Business	43100.00
0005435615384	10898	Business	43100.00
0005435426199	10898	Business	43100.00
0005435426189	10898	Comfort	24400.00
0005434573502	10898	Comfort	24400.00
0005435426232	10898	Comfort	24400.00
0005435380392	10898	Comfort	24400.00
0005434573527	10898	Comfort	24400.00
0005434245588	10898	Comfort	24400.00
0005435426235	10898	Comfort	24400.00
0005435615081	10898	Comfort	24400.00
0005434344538	10898	Comfort	24400.00
0005435614573	10898	Comfort	24400.00
0005432841056	10898	Comfort	24400.00
0005435097314	10898	Comfort	24400.00
0005435615086	10898	Comfort	24400.00
0005435615034	10898	Comfort	24400.00
0005435614784	10898	Comfort	24400.00
0005434245569	10898	Comfort	24400.00
0005434245581	10898	Comfort	24400.00
0005435426197	10898	Comfort	24400.00
0005432165197	10898	Comfort	24400.00
0005435097313	10898	Comfort	24400.00
0005434245585	10898	Comfort	24400.00
0005435615100	10898	Comfort	24400.00
0005432166969	10898	Comfort	24400.00
0005434573516	10898	Comfort	24400.00
0005435426202	10898	Comfort	24400.00
0005435426185	10898	Comfort	24400.00
0005435614814	10898	Comfort	24400.00
0005435042900	10898	Comfort	24400.00
0005434344641	10898	Comfort	24400.00
0005434344449	10898	Comfort	24400.00
0005435426204	10898	Comfort	24400.00
0005435426228	10898	Comfort	24400.00
0005435615282	10898	Comfort	24400.00
0005435614815	10898	Comfort	24400.00
0005434344445	10898	Comfort	24400.00
0005435426190	10898	Comfort	24400.00
0005435305052	10898	Comfort	24400.00
0005435614854	10898	Economy	14400.00
0005435614544	10898	Comfort	24400.00
0005435426205	10898	Economy	14400.00
0005435490267	10898	Economy	14400.00
0005435614901	10898	Economy	14400.00
0005435614702	10898	Economy	14400.00
0005434344471	10898	Economy	14400.00
0005435614827	10898	Economy	14400.00
0005435304238	10898	Economy	14400.00
0005434245596	10898	Economy	14400.00
0005435614664	10898	Economy	14400.00
0005435426225	10898	Economy	14400.00
0005435426216	10898	Economy	14400.00
0005432841057	10898	Economy	14400.00
0005434245572	10898	Economy	14400.00
0005435426251	10898	Economy	14400.00
0005435097318	10898	Economy	14400.00
0005435614556	10898	Economy	14400.00
0005435426184	10898	Economy	14400.00
0005432165192	10898	Economy	14400.00
0005435614895	10898	Economy	14400.00
0005435615392	10898	Economy	14400.00
0005435615001	10898	Economy	14400.00
0005435614652	10898	Economy	14400.00
0005435615380	10898	Economy	14400.00
0005435614792	10898	Economy	14400.00
0005434573501	10898	Economy	14400.00
0005434245568	10898	Economy	14400.00
0005435426198	10898	Economy	14400.00
0005434245593	10898	Economy	14400.00
0005432165195	10898	Economy	14400.00
0005435614914	10898	Economy	14400.00
0005435614958	10898	Economy	14400.00
0005435426220	10898	Economy	14400.00
0005435615271	10898	Economy	14400.00
0005434245586	10898	Economy	14400.00
0005435615168	10898	Economy	14400.00
0005435614377	10898	Economy	14400.00
0005435426245	10898	Economy	14400.00
0005435615187	10898	Economy	14400.00
0005434245579	10898	Economy	14400.00
0005435614769	10898	Economy	14400.00
0005435614841	10898	Economy	14400.00
0005435614925	10898	Economy	14400.00
0005435614913	10898	Economy	14400.00
0005434245597	10898	Economy	14400.00
0005435426240	10898	Economy	14400.00
0005435426243	10898	Economy	14400.00
0005435614868	10898	Economy	14400.00
0005434344582	10898	Economy	14400.00
0005435615387	10898	Economy	14400.00
0005435615388	10898	Economy	14400.00
0005433719211	10898	Economy	14400.00
0005435614620	10898	Economy	14400.00
0005435614523	10898	Economy	14400.00
0005435615244	10898	Economy	14400.00
0005435305053	10898	Economy	14400.00
0005435614770	10898	Economy	15800.00
0005435426192	10898	Economy	14400.00
0005435426230	10898	Economy	14400.00
0005434344517	10898	Economy	14400.00
0005434344470	10898	Economy	15800.00
0005434245592	10898	Economy	15800.00
0005435304237	10898	Economy	14400.00
0005432363483	10898	Economy	14400.00
0005435426221	10898	Economy	14400.00
0005435426219	10898	Economy	14400.00
0005435615389	10898	Economy	14400.00
0005434245573	10898	Economy	14400.00
0005435614872	10898	Economy	14400.00
0005435614889	10898	Economy	14400.00
0005435426226	10898	Economy	14400.00
0005434245571	10898	Economy	14400.00
0005435426210	10898	Economy	14400.00
0005435615128	10898	Economy	14400.00
0005435426242	10898	Economy	14400.00
0005434573489	10898	Economy	14400.00
0005435319755	10898	Economy	14400.00
0005435614902	10898	Economy	14400.00
0005434344573	10898	Economy	14400.00
0005432363482	10898	Economy	14400.00
0005435615363	10898	Economy	14400.00
0005435615157	10898	Economy	14400.00
0005435319751	10898	Economy	14400.00
0005435615275	10898	Economy	14400.00
0005435615276	10898	Economy	14400.00
0005434573462	10898	Economy	14400.00
0005435614703	10898	Economy	14400.00
0005434344446	10898	Economy	14400.00
0005435615177	10898	Economy	14400.00
0005435614853	10898	Economy	14400.00
0005435380395	10898	Economy	14400.00
0005435615185	10898	Economy	14400.00
0005434245575	10898	Economy	14400.00
0005435615096	10898	Economy	14400.00
0005435615084	10898	Economy	14400.00
0005435426217	10898	Economy	14400.00
0005434573497	10898	Economy	14400.00
0005435380393	10898	Economy	14400.00
0005435426213	10898	Economy	14400.00
0005434344501	10898	Economy	14400.00
0005435615421	10898	Economy	14400.00
0005434245590	10898	Economy	14400.00
0005435304241	10898	Economy	14400.00
0005434344642	10898	Economy	14400.00
0005435614890	10898	Economy	14400.00
0005435615386	10898	Economy	14400.00
0005435614795	10898	Economy	14400.00
0005434344584	10898	Economy	14400.00
0005434245591	10898	Economy	14400.00
0005434344401	10898	Economy	14400.00
0005435614876	10898	Economy	14400.00
0005435615012	10898	Economy	14400.00
0005435042899	10898	Economy	14400.00
0005434656596	10898	Economy	14400.00
0005435426229	10898	Economy	14400.00
0005435615225	10898	Economy	14400.00
0005434344651	10898	Economy	14400.00
0005435319756	10898	Economy	14400.00
0005435426244	10898	Economy	14400.00
0005435426253	10898	Economy	14400.00
0005435615479	10898	Economy	14400.00
0005435615167	10898	Economy	14400.00
0005435426212	10898	Economy	14400.00
0005435615196	10898	Economy	14400.00
0005435426231	10898	Economy	14400.00
0005435304240	10898	Economy	14400.00
0005435614701	10898	Economy	14400.00
0005435615247	10898	Economy	14400.00
0005434245595	10898	Economy	14400.00
0005434245580	10898	Economy	14400.00
0005435615033	10898	Economy	14400.00
0005434573507	10898	Economy	14400.00
0005435614704	10898	Economy	14400.00
0005435615093	10898	Economy	14400.00
0005434245584	10898	Economy	14400.00
0005434656597	10898	Economy	14400.00
0005435426193	10898	Economy	14400.00
0005434245574	10898	Economy	14400.00
0005434245594	10898	Economy	14400.00
0005435615378	10898	Economy	14400.00
0005435319754	10898	Economy	14400.00
0005435097308	10898	Economy	14400.00
0005435614794	10898	Economy	14400.00
0005435615267	10898	Economy	14400.00
0005435426241	10898	Economy	14400.00
0005435614793	10898	Economy	14400.00
0005435615126	10898	Economy	14400.00
0005435615176	10898	Economy	14400.00
0005435304239	10898	Economy	14400.00
0005435614683	10898	Economy	14400.00
0005435615005	10898	Economy	14400.00
0005435426233	10898	Economy	14400.00
0005435426203	10898	Economy	14400.00
0005435614828	10898	Economy	14400.00
0005435614696	10898	Economy	14400.00
0005435426195	10898	Economy	14400.00
0005435319753	10898	Economy	14400.00
0005435555389	10898	Economy	14400.00
0005435305051	10898	Economy	14400.00
0005434573504	10898	Economy	14400.00
0005435426211	10898	Economy	14400.00
0005434344563	10898	Economy	14400.00
0005434344594	10898	Economy	14400.00
0005435426188	10898	Economy	14400.00
0005435426227	10898	Economy	14400.00
0005435426187	10898	Economy	14400.00
0005434344537	10898	Economy	14400.00
0005435426194	10898	Economy	15800.00
0005434573520	10898	Economy	15800.00
0005432165198	10898	Economy	15800.00
0005435614576	10898	Economy	15800.00
0005435097307	10898	Economy	15800.00
0005435426191	10898	Economy	15800.00
0005435097322	10898	Economy	14400.00
0005435426237	10898	Economy	14400.00
0005435615377	10898	Economy	14400.00
0005435615195	10898	Economy	14400.00
0005435615124	10898	Economy	14400.00
0005435426206	10898	Economy	14400.00
0005435426222	10898	Economy	14400.00
0005435615089	10898	Economy	14400.00
0005435614611	10898	Economy	14400.00
0005435426238	10898	Economy	14400.00
0005435615127	10898	Economy	14400.00
0005435426201	10898	Economy	14400.00
0005435319752	10898	Economy	14400.00
0005434344574	10898	Economy	14400.00
0005435305050	10898	Economy	14400.00
0005435615085	10898	Economy	14400.00
0005435614621	10898	Economy	14400.00
0005434245582	10898	Economy	14400.00
0005435614896	10898	Economy	14400.00
0005435615391	10898	Economy	14400.00
0005435426215	10898	Economy	14400.00
0005435426223	10898	Economy	14400.00
0005434344609	10898	Economy	14400.00
0005432166970	10898	Economy	14400.00
0005435614577	10898	Economy	14400.00
0005435042898	10898	Economy	14400.00
0005435615436	10898	Economy	14400.00
0005435426236	10898	Economy	14400.00
0005435614627	10898	Economy	14400.00
0005435614376	10898	Economy	14400.00
0005435380394	10898	Economy	14400.00
0005434344567	10898	Economy	14400.00
0005435426248	10898	Economy	14400.00
0005435615194	10898	Economy	14400.00
0005435615011	10898	Economy	14400.00
0005434344562	10898	Economy	14400.00
0005432165196	10898	Economy	14400.00
0005432165194	10898	Economy	14400.00
0005435426250	10898	Economy	14400.00
0005435614612	10898	Economy	14400.00
0005435426200	10898	Economy	14400.00
0005435614555	10898	Economy	14400.00
0005434573526	10898	Economy	14400.00
0005435426249	10898	Economy	14400.00
0005434245570	10898	Economy	14400.00
0005434573541	10898	Economy	14400.00
0005435426234	10898	Economy	14400.00
0005435614723	10898	Economy	14400.00
0005433719212	10898	Economy	14400.00
0005434344418	10898	Economy	14400.00
0005435380396	10898	Economy	14400.00
0005432166967	10898	Economy	14400.00
0005435319750	10898	Economy	14400.00
0005435615281	10898	Economy	14400.00
0005435614595	10898	Economy	14400.00
0005435615083	10898	Economy	14400.00
0005435614779	10898	Economy	14400.00
0005434344632	10898	Economy	14400.00
0005435097312	10898	Economy	14400.00
0005435615007	10898	Economy	14400.00
0005435426207	10898	Economy	14400.00
0005435319758	10898	Economy	14400.00
0005435615280	10898	Economy	14400.00
0005435615226	10898	Economy	14400.00
0005434245587	10898	Economy	14400.00
0005435490266	10898	Economy	14400.00
0005435614780	10898	Economy	14400.00
0005435490253	10898	Economy	14400.00
0005432165193	10898	Economy	14400.00
0005435614873	10898	Economy	14400.00
0005435426186	10898	Economy	14400.00
0005435615297	10898	Economy	14400.00
0005435615513	10898	Economy	14400.00
0005435426246	10898	Economy	14400.00
0005435614823	10898	Economy	14400.00
0005435426252	10898	Economy	14400.00
0005434245577	10898	Economy	14400.00
0005434344485	10898	Economy	14400.00
0005435614618	10898	Economy	14400.00
0005434245576	10898	Economy	14400.00
0005435614783	10898	Economy	14400.00
0005435615420	10898	Economy	14400.00
0005435614541	10898	Economy	14400.00
0005435426208	10898	Economy	14400.00
0005435615087	10898	Economy	14400.00
0005435426224	10898	Economy	14400.00
0005435426239	10898	Economy	14400.00
0005435614542	10898	Economy	14400.00
0005435614768	10898	Economy	14400.00
0005435615099	10898	Economy	14400.00
0005435614832	10898	Economy	14400.00
0005435097306	10898	Economy	14400.00
0005435305049	10898	Economy	14400.00
0005433634517	3337	Business	18800.00
0005432182180	3337	Business	18800.00
0005432460335	3337	Business	18800.00
0005432182185	3337	Business	18800.00
0005432460576	3337	Business	18800.00
0005433806067	3337	Business	18800.00
0005433507552	3337	Business	18800.00
0005432460368	3337	Business	18800.00
0005433634528	3337	Business	18800.00
0005432460342	3337	Business	18800.00
0005432182174	3337	Business	18800.00
0005433634515	3337	Business	18800.00
0005432460438	3337	Business	18800.00
0005432460452	3337	Business	18800.00
0005432182178	3337	Business	18800.00
0005432460559	3337	Business	18800.00
0005432460543	3337	Business	18800.00
0005433634529	3337	Business	18800.00
0005433806084	3337	Business	18800.00
0005433634513	3337	Business	18800.00
0005433806076	3337	Business	18800.00
0005433507543	3337	Business	18800.00
0005433806079	3337	Business	18800.00
0005433806069	3337	Business	18800.00
0005433634538	3337	Business	18800.00
0005433507548	3337	Business	18800.00
0005433806071	3337	Business	18800.00
0005433806074	3337	Business	18800.00
0005433507536	3337	Economy	6900.00
0005433634533	3337	Economy	6900.00
0005432460400	3337	Economy	6900.00
0005432460557	3337	Economy	6900.00
0005433806087	3337	Economy	6900.00
0005432182169	3337	Economy	6900.00
0005433507547	3337	Economy	6300.00
0005432460319	3337	Economy	6300.00
0005432460530	3337	Economy	6300.00
0005432460531	3337	Economy	6300.00
0005433507544	3337	Economy	6300.00
0005433806072	3337	Economy	6300.00
0005432460372	3337	Economy	6300.00
0005432460230	3337	Economy	6300.00
0005433806090	3337	Economy	6300.00
0005433634526	3337	Economy	6300.00
0005433634506	3337	Economy	6300.00
0005432182177	3337	Economy	6300.00
0005432460575	3337	Economy	6300.00
0005432460468	3337	Economy	6300.00
0005433634511	3337	Economy	6300.00
0005432182175	3337	Economy	6300.00
0005432182171	3337	Economy	6300.00
0005433634521	3337	Economy	6300.00
0005432460691	3337	Economy	6300.00
0005433507551	3337	Economy	6300.00
0005433806089	3337	Economy	6300.00
0005433634527	3337	Economy	6300.00
0005432460696	3337	Economy	6300.00
0005433806068	3337	Economy	6300.00
0005433806091	3337	Economy	6300.00
0005432460445	3337	Economy	6300.00
0005432460506	3337	Economy	6300.00
0005432460485	3337	Economy	6300.00
0005432460533	3337	Economy	6300.00
0005432460366	3337	Economy	6300.00
0005432460690	3337	Economy	6300.00
0005432460420	3337	Economy	6300.00
0005433634516	3337	Economy	6300.00
0005432460515	3337	Economy	6300.00
0005432460254	3337	Economy	6300.00
0005432182165	3337	Economy	6300.00
0005432182172	3337	Economy	6300.00
0005432460217	3337	Economy	6300.00
0005432182167	3337	Economy	6300.00
0005433634512	3337	Economy	6300.00
0005432460492	3337	Economy	6300.00
0005433634531	3337	Economy	6300.00
0005433634520	3337	Economy	6300.00
0005432460329	3337	Economy	6300.00
0005432182183	3337	Economy	6300.00
0005433507542	3337	Economy	6300.00
0005433507539	3337	Economy	6300.00
0005432460508	3337	Economy	6300.00
0005432460330	3337	Economy	6300.00
0005432460264	3337	Economy	6300.00
0005433634507	3337	Economy	6300.00
0005432460317	3337	Economy	6300.00
0005432182186	3337	Economy	6300.00
0005432460507	3337	Economy	6300.00
0005432182168	3337	Economy	6300.00
0005433634530	3337	Economy	6300.00
0005432460532	3337	Economy	6300.00
0005432460318	3337	Economy	6300.00
0005432460399	3337	Economy	6300.00
0005432460494	3337	Economy	6300.00
0005432460249	3337	Economy	6900.00
0005433634509	3337	Economy	6900.00
0005433634535	3337	Economy	6900.00
0005433806078	3337	Economy	6900.00
0005432460648	3337	Economy	6300.00
0005433507540	3337	Economy	6900.00
0005433507538	3337	Economy	6300.00
0005433507541	3337	Economy	6300.00
0005433806077	3337	Economy	6300.00
0005433634504	3337	Economy	6900.00
0005433634522	3337	Economy	6300.00
0005432460486	3337	Economy	6300.00
0005433507537	3337	Economy	6300.00
0005433634524	3337	Economy	6300.00
0005432182164	3337	Economy	6300.00
0005432460280	3337	Economy	6300.00
0005432460373	3337	Economy	6300.00
0005433634514	3337	Economy	6300.00
0005432460558	3337	Economy	6300.00
0005433806088	3337	Economy	6300.00
0005432460451	3337	Economy	6300.00
0005432182181	3337	Economy	6300.00
0005433507550	3337	Economy	6300.00
0005432460265	3337	Economy	6300.00
0005433634519	3337	Economy	6300.00
0005433806070	3337	Economy	6300.00
0005432182182	3337	Economy	6300.00
0005432460349	3337	Economy	6300.00
0005433806093	3337	Economy	6300.00
0005433806082	3337	Economy	6300.00
0005432460450	3337	Economy	6300.00
0005433806086	3337	Economy	6300.00
0005432182176	3337	Economy	6300.00
0005432460447	3337	Economy	6300.00
0005432460358	3337	Economy	6300.00
0005432460449	3337	Economy	6300.00
0005433507545	3337	Economy	6300.00
0005432460437	3337	Economy	6300.00
0005433634508	3337	Economy	6300.00
0005433806092	3337	Economy	6300.00
0005433507546	3337	Economy	6300.00
0005433806085	3337	Economy	6300.00
0005433806080	3337	Economy	6300.00
0005433634510	3337	Economy	6300.00
0005433634536	3337	Economy	6300.00
0005433634537	3337	Economy	6300.00
0005433507556	3337	Economy	6300.00
0005432182166	3337	Economy	6300.00
0005433507535	3337	Economy	6300.00
0005432182184	3337	Economy	6300.00
0005432460582	3337	Economy	6300.00
0005433634518	3337	Economy	6300.00
0005433634532	3337	Economy	6300.00
0005433806075	3337	Economy	6300.00
0005433806094	3337	Economy	6300.00
0005433634525	3337	Economy	6300.00
0005432460369	3337	Economy	6300.00
0005433507549	3337	Economy	6300.00
0005433507557	3337	Economy	6300.00
0005433806081	3337	Economy	6300.00
0005432460661	3337	Economy	6300.00
0005433634505	3337	Economy	6300.00
0005432460448	3337	Economy	6300.00
0005432460331	3337	Economy	6300.00
0005433507555	3337	Economy	6300.00
0005433634523	3337	Economy	6300.00
0005433806083	3337	Economy	6300.00
0005433634534	3337	Economy	6300.00
0005432460578	3337	Economy	6300.00
0005433507554	3337	Economy	6300.00
0005432460343	3337	Economy	6300.00
0005433507553	3337	Economy	6300.00
0005432182179	3337	Economy	6300.00
0005432182173	3337	Economy	6300.00
0005433806073	3337	Economy	6300.00
0005432182170	3337	Economy	6300.00
0005435886007	3336	Business	18800.00
0005435885953	3336	Business	18800.00
0005435886001	3336	Business	18800.00
0005435885886	3336	Business	18800.00
0005435885753	3336	Business	18800.00
0005435885949	3336	Business	18800.00
0005435885950	3336	Business	18800.00
0005435886039	3336	Business	18800.00
0005435885901	3336	Economy	6900.00
0005435886100	3336	Economy	6900.00
0005435885931	3336	Economy	6300.00
0005435885790	3336	Economy	6300.00
0005435885919	3336	Economy	6300.00
0005435885939	3336	Economy	6300.00
0005435885806	3336	Economy	6300.00
0005435885951	3336	Economy	6300.00
0005435885754	3336	Economy	6300.00
0005435885794	3336	Economy	6300.00
0005435885930	3336	Economy	6300.00
0005435885904	3336	Economy	6300.00
0005435885856	3336	Economy	6300.00
0005435885846	3336	Economy	6300.00
0005435886024	3336	Economy	6300.00
0005435885983	3336	Economy	6300.00
0005435885855	3336	Economy	6300.00
0005435885837	3336	Economy	6300.00
0005435886095	3336	Economy	6300.00
0005435885868	3336	Economy	6300.00
0005435885900	3336	Economy	6300.00
0005435885838	3336	Economy	6300.00
0005435885958	3336	Economy	6300.00
0005435886096	3336	Economy	6300.00
0005435885848	3336	Economy	6300.00
0005435885844	3336	Economy	6300.00
0005435885863	3336	Economy	6300.00
0005435885758	3336	Economy	6300.00
0005435885861	3336	Economy	6300.00
0005435885845	3336	Economy	6300.00
0005435885807	3336	Economy	6300.00
0005435885847	3336	Economy	6300.00
0005435885854	3336	Economy	6300.00
0005435885952	3336	Economy	6300.00
0005435885825	3336	Economy	6300.00
0005435885828	3336	Economy	6300.00
0005435885862	3336	Economy	6300.00
0005435885971	3336	Economy	6300.00
0005435885869	3336	Economy	6300.00
0005435885984	3336	Economy	6300.00
0005435885759	3336	Economy	6300.00
0005435886231	8232	Business	18800.00
0005435886244	8232	Business	18800.00
0005432460957	8232	Business	18800.00
0005432460958	8232	Business	18800.00
0005435886270	8232	Business	18800.00
0005433507364	8232	Business	18800.00
0005433507389	8232	Business	18800.00
0005435886266	8232	Business	18800.00
0005432460966	8232	Business	18800.00
0005435886262	8232	Business	18800.00
0005435886235	8232	Business	18800.00
0005432460983	8232	Business	18800.00
0005432460980	8232	Business	18800.00
0005432460984	8232	Business	18800.00
0005433507405	8232	Business	18800.00
0005435886254	8232	Business	18800.00
0005435886274	8232	Business	18800.00
0005432460946	8232	Business	18800.00
0005435886278	8232	Business	18800.00
0005432460955	8232	Business	18800.00
0005435886229	8232	Business	18800.00
0005433507403	8232	Business	18800.00
0005433507425	8232	Business	18800.00
0005432460938	8232	Business	18800.00
0005433507393	8232	Business	18800.00
0005435886276	8232	Business	18800.00
0005432460933	8232	Economy	6900.00
0005435886265	8232	Economy	6900.00
0005435886261	8232	Economy	6900.00
0005432043006	8232	Economy	6900.00
0005432460973	8232	Economy	6900.00
0005433507424	8232	Economy	6300.00
0005432460939	8232	Economy	6300.00
0005435886238	8232	Economy	6300.00
0005432460941	8232	Economy	6300.00
0005432460964	8232	Economy	6300.00
0005433507353	8232	Economy	6300.00
0005432043008	8232	Economy	6300.00
0005435886253	8232	Economy	6300.00
0005433507374	8232	Economy	6300.00
0005432043000	8232	Economy	6300.00
0005432460935	8232	Economy	6300.00
0005432460936	8232	Economy	6300.00
0005432460945	8232	Economy	6300.00
0005432460985	8232	Economy	6300.00
0005435886249	8232	Economy	6300.00
0005435142976	8232	Economy	6300.00
0005432460975	8232	Economy	6300.00
0005433507404	8232	Economy	6300.00
0005432043002	8232	Economy	6300.00
0005435886226	8232	Economy	6300.00
0005435886236	8232	Economy	6300.00
0005432043005	8232	Economy	6300.00
0005432460979	8232	Economy	6300.00
0005432460943	8232	Economy	6300.00
0005435886232	8232	Economy	6300.00
0005432460961	8232	Economy	6300.00
0005432042999	8232	Economy	6300.00
0005435886241	8232	Economy	6300.00
0005432460954	8232	Economy	6300.00
0005432042996	8232	Economy	6300.00
0005435886273	8232	Economy	6300.00
0005432460977	8232	Economy	6300.00
0005435886258	8232	Economy	6300.00
0005435886260	8232	Economy	6300.00
0005435886256	8232	Economy	6300.00
0005432460950	8232	Economy	6300.00
0005435886240	8232	Economy	6300.00
0005433507402	8232	Economy	6300.00
0005432460956	8232	Economy	6300.00
0005435886257	8232	Economy	6300.00
0005432460970	8232	Economy	6300.00
0005434312386	8232	Economy	6300.00
0005435886269	8232	Economy	6300.00
0005433507352	8232	Economy	6300.00
0005432460947	8232	Economy	6300.00
0005433507426	8232	Economy	6900.00
0005435886227	8232	Economy	6900.00
0005435886250	8232	Economy	6300.00
0005432042995	8232	Economy	6300.00
0005432460940	8232	Economy	6300.00
0005434312363	8232	Economy	6300.00
0005432460982	8232	Economy	6900.00
0005432460937	8232	Economy	6300.00
0005435886248	8232	Economy	6300.00
0005435886255	8232	Economy	6300.00
0005435886247	8232	Economy	6300.00
0005432042998	8232	Economy	6300.00
0005435886237	8232	Economy	6300.00
0005432460969	8232	Economy	6300.00
0005432460944	8232	Economy	6300.00
0005432460951	8232	Economy	6300.00
0005432460974	8232	Economy	6300.00
0005432460967	8232	Economy	6300.00
0005435886230	8232	Economy	6300.00
0005432460976	8232	Economy	6300.00
0005435886233	8232	Economy	6300.00
0005432460953	8232	Economy	6300.00
0005435886243	8232	Economy	6300.00
0005435886277	8232	Economy	6300.00
0005432043004	8232	Economy	6300.00
0005432460962	8232	Economy	6300.00
0005432460968	8232	Economy	6300.00
0005432460965	8232	Economy	6300.00
0005432460963	8232	Economy	6300.00
0005432460942	8232	Economy	6300.00
0005432460948	8232	Economy	6300.00
0005435886245	8232	Economy	6300.00
0005432460959	8232	Economy	6300.00
0005435886272	8232	Economy	6300.00
0005432043007	8232	Economy	6300.00
0005432460952	8232	Economy	6300.00
0005435886228	8232	Economy	6300.00
0005435886259	8232	Economy	6300.00
0005435886239	8232	Economy	6300.00
0005435886271	8232	Economy	6300.00
0005432460978	8232	Economy	6300.00
0005432460949	8232	Economy	6300.00
0005433507362	8232	Economy	6300.00
0005435142975	8232	Economy	6300.00
0005435886242	8232	Economy	6300.00
0005432043003	8232	Economy	6300.00
0005435886234	8232	Economy	6300.00
0005435886252	8232	Economy	6300.00
0005435886224	8232	Economy	6300.00
0005435886268	8232	Economy	6300.00
0005432042997	8232	Economy	6300.00
0005432460981	8232	Economy	6300.00
0005432460960	8232	Economy	6300.00
0005435886263	8232	Economy	6300.00
0005435886225	8232	Economy	6300.00
0005435886264	8232	Economy	6300.00
0005435886246	8232	Economy	6300.00
0005432043001	8232	Economy	6300.00
0005432460934	8232	Economy	6300.00
0005433507363	8232	Economy	6300.00
0005434312362	8232	Economy	6300.00
0005432460972	8232	Economy	6300.00
0005435886251	8232	Economy	6300.00
0005435886275	8232	Economy	6300.00
0005432460971	8232	Economy	6300.00
0005433507401	8232	Economy	6300.00
0005435886267	8232	Economy	6300.00
0005433805753	8228	Business	18800.00
0005433805824	8228	Business	18800.00
0005433634157	8228	Business	18800.00
0005433634206	8228	Business	18800.00
0005433805696	8228	Business	18800.00
0005433805734	8228	Business	18800.00
0005433634290	8228	Business	18800.00
0005433634180	8228	Business	18800.00
0005433805939	8228	Business	18800.00
0005433634254	8228	Business	18800.00
0005433805805	8228	Business	18800.00
0005433805944	8228	Business	18800.00
0005433634249	8228	Business	18800.00
0005433634191	8228	Business	18800.00
0005433634240	8228	Business	18800.00
0005433634166	8228	Business	18800.00
0005433805842	8228	Business	18800.00
0005433634241	8228	Economy	6900.00
0005433805735	8228	Economy	6900.00
0005435860643	8228	Economy	6900.00
0005433634077	8228	Economy	6300.00
0005433805768	8228	Economy	6300.00
0005433805819	8228	Economy	6300.00
0005433805779	8228	Economy	6300.00
0005433805871	8228	Economy	6300.00
0005433634266	8228	Economy	6300.00
0005433805772	8228	Economy	6300.00
0005433634199	8228	Economy	6300.00
0005433634242	8228	Economy	6300.00
0005433805818	8228	Economy	6300.00
0005433634155	8228	Economy	6300.00
0005433634115	8228	Economy	6300.00
0005433634265	8228	Economy	6300.00
0005433634015	8228	Economy	6300.00
0005433805744	8228	Economy	6300.00
0005433805787	8228	Economy	6300.00
0005433634179	8228	Economy	6300.00
0005433634192	8228	Economy	6300.00
0005433634164	8228	Economy	6300.00
0005433634200	8228	Economy	6300.00
0005433805854	8228	Economy	6300.00
0005433805817	8228	Economy	6900.00
0005433805767	8228	Economy	6900.00
0005433805752	8228	Economy	6900.00
0005433634250	8228	Economy	6900.00
0005433805820	8228	Economy	6900.00
0005433805743	8228	Economy	6300.00
0005433805729	8228	Economy	6300.00
0005433805850	8228	Economy	6900.00
0005433805849	8228	Economy	6300.00
0005433634049	8228	Economy	6300.00
0005435854073	8228	Economy	6300.00
0005433805823	8228	Economy	6300.00
0005433805730	8228	Economy	6300.00
0005433634152	8228	Economy	6300.00
0005433805737	8228	Economy	6300.00
0005433634214	8228	Economy	6300.00
0005433634392	8228	Economy	6300.00
0005433634156	8228	Economy	6300.00
0005433634258	8228	Economy	6300.00
0005433634291	8228	Economy	6300.00
0005433634257	8228	Economy	6300.00
0005433634309	8228	Economy	6300.00
0005433805695	8228	Economy	6300.00
0005433805766	8228	Economy	6300.00
0005433634085	8228	Economy	6300.00
0005433805786	8228	Economy	6300.00
0005433634165	8228	Economy	6300.00
0005434271337	8228	Economy	6300.00
0005433633950	8228	Economy	6300.00
0005435854074	8228	Economy	6300.00
0005434271338	8228	Economy	6300.00
0005433805841	8228	Economy	6300.00
0005433634061	8228	Economy	6300.00
0005433805736	8228	Economy	6300.00
0005435854072	8228	Economy	6300.00
0005433805804	8228	Economy	6300.00
0005434271341	8228	Economy	6300.00
0005433805940	8228	Economy	6300.00
0005435854071	8228	Economy	6300.00
0005433805806	8228	Economy	6300.00
0005433805941	8228	Economy	6300.00
0005434183613	8224	Economy	6300.00
0005434183603	8224	Economy	6300.00
0005434183608	8224	Economy	6300.00
0005434183602	8224	Economy	6300.00
0005434183609	8224	Economy	6300.00
0005432383960	4630	Business	9900.00
0005432383956	4630	Business	9900.00
0005432383994	4630	Business	9900.00
0005432383959	4630	Business	9900.00
0005432383980	4630	Business	9900.00
0005432728201	4630	Business	9900.00
0005432383961	4630	Business	9900.00
0005433453803	4630	Business	9900.00
0005432383975	4630	Business	9900.00
0005432383976	4630	Business	9900.00
0005432383988	4630	Economy	3300.00
0005433722353	4630	Economy	3300.00
0005432383986	4630	Economy	3300.00
0005432383985	4630	Economy	3300.00
0005432728202	4630	Economy	3600.00
0005432383969	4630	Economy	3600.00
0005432383992	4630	Economy	3600.00
0005432383987	4630	Economy	3600.00
0005432383968	4630	Economy	3300.00
0005432383981	4630	Economy	3300.00
0005432383993	4630	Economy	3300.00
0005432383972	4630	Economy	3300.00
0005433453802	4630	Economy	3300.00
0005432728200	4630	Economy	3300.00
0005432383990	4630	Economy	3300.00
0005432383974	4630	Economy	3300.00
0005433453801	4630	Economy	3300.00
0005432383979	4630	Economy	3300.00
0005432383989	4630	Economy	3300.00
0005432728199	4630	Economy	3300.00
0005432383984	4630	Economy	3300.00
0005432383995	4630	Economy	3300.00
0005432383977	4630	Economy	3300.00
0005432728195	4630	Economy	3300.00
0005432383963	4630	Economy	3300.00
0005433454919	4630	Economy	3300.00
0005432383962	4630	Economy	3300.00
0005432383966	4630	Economy	3300.00
0005433722354	4630	Economy	3300.00
0005433722352	4630	Economy	3300.00
0005432728191	4630	Economy	3300.00
0005433454918	4630	Economy	3300.00
0005432728197	4630	Economy	3300.00
0005432728198	4630	Economy	3300.00
0005432728196	4630	Economy	3300.00
0005432383991	4630	Economy	3300.00
0005432383970	4630	Economy	3300.00
0005432383982	4630	Economy	3300.00
0005432728192	4630	Economy	3300.00
0005432383957	4630	Economy	3300.00
0005432383964	4630	Economy	3300.00
0005432383983	4630	Economy	3300.00
0005432383978	4630	Economy	3300.00
0005433722355	4630	Economy	3300.00
0005432383965	4630	Economy	3300.00
0005433454920	4630	Economy	3300.00
0005432728194	4630	Economy	3300.00
0005432383973	4630	Economy	3300.00
0005432728193	4630	Economy	3300.00
0005432383967	4630	Economy	3300.00
0005432383971	4630	Economy	3300.00
0005432383958	4630	Economy	3300.00
0005432383519	30180	Business	9900.00
0005432383633	30180	Business	9900.00
0005433451650	30180	Business	9900.00
0005432728087	30180	Business	9900.00
0005432383481	30180	Business	9900.00
0005432728052	30180	Economy	3300.00
0005432383638	30180	Economy	3300.00
0005433451644	30180	Economy	3300.00
0005432728082	30180	Economy	3300.00
0005432728081	30180	Economy	3300.00
0005432728088	30180	Economy	3600.00
0005432383682	30180	Economy	3600.00
0005433722265	30180	Economy	3600.00
0005432728090	30180	Economy	3600.00
0005432383289	30180	Economy	3300.00
0005433194867	30180	Economy	3300.00
0005432728061	30180	Economy	3300.00
0005432383323	30180	Economy	3300.00
0005432383578	30180	Economy	3300.00
0005433722272	30180	Economy	3300.00
0005432383494	30180	Economy	3300.00
0005433194881	30180	Economy	3300.00
0005433722292	30180	Economy	3300.00
0005432383550	30180	Economy	3300.00
0005432383551	30180	Economy	3300.00
0005432383560	30180	Economy	3300.00
0005432728092	30180	Economy	3300.00
0005432728065	30180	Economy	3300.00
0005432383520	30180	Economy	3300.00
0005432383683	30180	Economy	3300.00
0005433722268	30180	Economy	3300.00
0005432728116	30180	Economy	3300.00
0005432383577	30180	Economy	3300.00
0005432383475	30180	Economy	3300.00
0005432383474	30180	Economy	3300.00
0005432383307	30180	Economy	3300.00
0005432383448	30180	Economy	3300.00
0005432383411	30180	Economy	3300.00
0005433722280	30180	Economy	3300.00
0005432728066	30180	Economy	3300.00
0005432383445	30180	Economy	3300.00
0005432383575	30180	Economy	3300.00
0005432383607	30180	Economy	3300.00
0005432728085	30180	Economy	3300.00
0005432383672	30180	Economy	3300.00
0005432383634	30180	Economy	3300.00
0005432383606	30180	Economy	3300.00
0005432383410	30180	Economy	3300.00
0005433722300	30180	Economy	3300.00
0005432383552	30180	Economy	3300.00
0005432728106	30180	Economy	3300.00
0005432728091	30180	Economy	3300.00
0005432383407	30180	Economy	3300.00
0005432383547	30180	Economy	3300.00
0005432383482	30180	Economy	3300.00
0005432383495	30180	Economy	3300.00
0005433194891	30180	Economy	3300.00
0005432728060	30180	Economy	3300.00
0005433517082	1757	Business	57200.00
0005435529708	1757	Business	57200.00
0005433517081	1757	Business	57200.00
0005433517077	1757	Business	57200.00
0005435529704	1757	Business	57200.00
0005435541455	1757	Business	57200.00
0005435529709	1757	Business	57200.00
0005435529722	1757	Business	57200.00
0005435529698	1757	Economy	19100.00
0005432925083	1757	Economy	19100.00
0005435529718	1757	Economy	19100.00
0005435529716	1757	Economy	19100.00
0005435529717	1757	Economy	19100.00
0005435541459	1757	Economy	19100.00
0005435541460	1757	Economy	21000.00
0005435529700	1757	Economy	21000.00
0005435541450	1757	Economy	21000.00
0005435541445	1757	Economy	21000.00
0005435541463	1757	Economy	19100.00
0005435541452	1757	Economy	19100.00
0005435529721	1757	Economy	19100.00
0005435530021	1757	Economy	19100.00
0005433517083	1757	Economy	19100.00
0005435541454	1757	Economy	19100.00
0005435530017	1757	Economy	19100.00
0005435530015	1757	Economy	19100.00
0005432925098	1757	Economy	19100.00
0005435541462	1757	Economy	19100.00
0005435529711	1757	Economy	19100.00
0005435530012	1757	Economy	19100.00
0005435529719	1757	Economy	19100.00
0005435541458	1757	Economy	19100.00
0005432294537	1757	Economy	19100.00
0005435529712	1757	Economy	19100.00
0005435530013	1757	Economy	19100.00
0005435541456	1757	Economy	19100.00
0005435541457	1757	Economy	19100.00
0005435529710	1757	Economy	19100.00
0005433517076	1757	Economy	19100.00
0005435530019	1757	Economy	19100.00
0005435530022	1757	Economy	19100.00
0005435541447	1757	Economy	19100.00
0005435530018	1757	Economy	19100.00
0005435541453	1757	Economy	19100.00
0005433517078	1757	Economy	19100.00
0005435529714	1757	Economy	19100.00
0005435541449	1757	Economy	19100.00
0005435530014	1757	Economy	19100.00
0005435530020	1757	Economy	19100.00
0005435529715	1757	Economy	19100.00
0005435541442	1757	Economy	19100.00
0005435541448	1757	Economy	19100.00
0005435529706	1757	Economy	19100.00
0005435541464	1757	Economy	19100.00
0005435541444	1757	Economy	19100.00
0005435541451	1757	Economy	19100.00
0005433517080	1757	Economy	19100.00
0005435529702	1757	Economy	19100.00
0005435529720	1757	Economy	19100.00
0005432294538	1757	Economy	19100.00
0005433517079	1757	Economy	19100.00
0005435530016	1757	Economy	19100.00
0005435529703	1757	Economy	19100.00
0005435529699	1757	Economy	19100.00
0005435529701	1757	Economy	19100.00
0005433517084	1757	Economy	19100.00
0005435529707	1757	Economy	19100.00
0005432294536	1757	Economy	19100.00
0005435529713	1757	Economy	19100.00
0005435541461	1757	Economy	19100.00
0005435541443	1757	Economy	19100.00
0005435529705	1757	Economy	19100.00
0005435541446	1757	Economy	19100.00
0005435518101	21990	Business	57200.00
0005435541280	21990	Business	57200.00
0005435541149	21990	Business	57200.00
0005433517038	21990	Business	57200.00
0005435518182	21990	Business	57200.00
0005433516972	21990	Business	57200.00
0005435518095	21990	Business	57200.00
0005435518111	21990	Business	57200.00
0005435518157	21990	Business	57200.00
0005435541208	21990	Business	57200.00
0005435541197	21990	Economy	19100.00
0005432925137	21990	Economy	19100.00
0005435518097	21990	Economy	19100.00
0005435541209	21990	Economy	19100.00
0005435541233	21990	Economy	19100.00
0005435518183	21990	Economy	19100.00
0005435541235	21990	Economy	21000.00
0005435541310	21990	Economy	21000.00
0005435541290	21990	Economy	19100.00
0005435541262	21990	Economy	19100.00
0005433516954	21990	Economy	19100.00
0005435541309	21990	Economy	19100.00
0005435541230	21990	Economy	19100.00
0005435518121	21990	Economy	19100.00
0005435541281	21990	Economy	19100.00
0005435541275	21990	Economy	19100.00
0005432925134	21990	Economy	19100.00
0005435518023	21990	Economy	19100.00
0005435541170	21990	Economy	19100.00
0005432925135	21990	Economy	19100.00
0005435518120	21990	Economy	19100.00
0005432925133	21990	Economy	19100.00
0005435541273	21990	Economy	19100.00
0005435541226	21990	Economy	19100.00
0005435518175	21990	Economy	19100.00
0005435518140	21990	Economy	19100.00
0005435518096	21990	Economy	19100.00
0005433516978	21990	Economy	19100.00
0005435541225	21990	Economy	19100.00
0005435518131	21990	Economy	19100.00
0005435541274	21990	Economy	19100.00
0005435541279	21990	Economy	19100.00
0005435518174	21990	Economy	19100.00
0005435541234	21990	Economy	19100.00
0005435518110	21990	Economy	19100.00
0005433517002	21990	Economy	19100.00
0005433517037	21990	Economy	19100.00
0005435518108	21990	Economy	19100.00
0005435518116	21990	Economy	19100.00
0005435541169	21990	Economy	19100.00
0005435541240	21990	Economy	19100.00
0005433516971	21990	Economy	19100.00
0005433517020	21990	Economy	19100.00
0005435518100	21990	Economy	19100.00
0005435518074	21990	Economy	19100.00
0005435541148	21990	Economy	19100.00
0005432925136	21990	Economy	19100.00
0005433517006	21990	Economy	19100.00
0005435518109	21990	Economy	19100.00
0005435541308	21990	Economy	19100.00
0005435518063	21990	Economy	19100.00
0005435541236	21990	Economy	19100.00
0005432073463	7389	Business	18500.00
0005432839682	7389	Business	18500.00
0005434459241	7389	Business	18500.00
0005435252906	7389	Business	18500.00
0005432839666	7389	Business	18500.00
0005434459232	7389	Business	18500.00
0005435252798	7389	Business	18500.00
0005434459238	7389	Business	18500.00
0005432839662	7389	Business	18500.00
0005432073461	7389	Business	18500.00
0005432839669	7389	Economy	6200.00
0005435252915	7389	Economy	6200.00
0005435491452	7389	Economy	6200.00
0005434459242	7389	Economy	6200.00
0005434459236	7389	Economy	6200.00
0005432839665	7389	Economy	6200.00
0005434459235	7389	Economy	6200.00
0005432839659	7389	Economy	6200.00
0005432839684	7389	Economy	6800.00
0005435252956	7389	Economy	6800.00
0005432841054	7389	Economy	6800.00
0005432073460	7389	Economy	6800.00
0005432823490	7389	Economy	6800.00
0005435252914	7389	Economy	6200.00
0005435252867	7389	Economy	6200.00
0005432839671	7389	Economy	6200.00
0005434459229	7389	Economy	6200.00
0005434459234	7389	Economy	6200.00
0005432839681	7389	Economy	6200.00
0005432839689	7389	Economy	6200.00
0005432839664	7389	Economy	6200.00
0005435252930	7389	Economy	6200.00
0005435252952	7389	Economy	6200.00
0005432839690	7389	Economy	6200.00
0005435252796	7389	Economy	6200.00
0005435252931	7389	Economy	6200.00
0005435252958	7389	Economy	6200.00
0005432839658	7389	Economy	6200.00
0005434459222	7389	Economy	6200.00
0005435491467	7389	Economy	6200.00
0005435252893	7389	Economy	6200.00
0005432839661	7389	Economy	6200.00
0005435252966	7389	Economy	6200.00
0005435491451	7389	Economy	6200.00
0005432839686	7389	Economy	6200.00
0005434459231	7389	Economy	6200.00
0005432839674	7389	Economy	6200.00
0005434459226	7389	Economy	6200.00
0005435252959	7389	Economy	6200.00
0005434459239	7389	Economy	6200.00
0005432839677	7389	Economy	6200.00
0005432839660	7389	Economy	6200.00
0005432839676	7389	Economy	6200.00
0005432839679	7389	Economy	6200.00
0005434459240	7389	Economy	6200.00
0005432839680	7389	Economy	6200.00
0005434459227	7389	Economy	6200.00
0005432839683	7389	Economy	6200.00
0005432839678	7389	Economy	6200.00
0005432073462	7389	Economy	6200.00
0005435252963	7389	Economy	6200.00
0005432839688	7389	Economy	6200.00
0005434459225	7389	Economy	6200.00
0005435252932	7389	Economy	6200.00
0005432839685	7389	Economy	6200.00
0005434459228	7389	Economy	6200.00
0005432839663	7389	Economy	6200.00
0005432839675	7389	Economy	6200.00
0005434459230	7389	Economy	6200.00
0005432841055	7389	Economy	6200.00
0005432839670	7389	Economy	6200.00
0005432839668	7389	Economy	6200.00
0005432839667	7389	Economy	6200.00
0005432839673	7389	Economy	6200.00
0005435252795	7389	Economy	6200.00
0005434459224	7389	Economy	6200.00
0005434459233	7389	Economy	6200.00
0005434459223	7389	Economy	6200.00
0005434459237	7389	Economy	6200.00
0005432839687	7389	Economy	6200.00
0005432839672	7389	Economy	6200.00
0005432839303	28922	Business	18500.00
0005434459057	28922	Business	18500.00
0005434459013	28922	Business	18500.00
0005432841041	28922	Business	18500.00
0005432823479	28922	Business	18500.00
0005432839456	28922	Business	18500.00
0005434459027	28922	Business	18500.00
0005432839444	28922	Business	18500.00
0005432839403	28922	Business	18500.00
0005435253064	28922	Economy	6200.00
0005432839521	28922	Economy	6200.00
0005432839373	28922	Economy	6200.00
0005432839526	28922	Economy	6200.00
0005432839392	28922	Economy	6200.00
0005434458997	28922	Economy	6200.00
0005434459022	28922	Economy	6200.00
0005435253069	28922	Economy	6200.00
0005432839530	28922	Economy	6800.00
0005432839437	28922	Economy	6800.00
0005432839363	28922	Economy	6800.00
0005435491486	28922	Economy	6800.00
0005434459056	28922	Economy	6800.00
0005434459033	28922	Economy	6200.00
0005432823482	28922	Economy	6200.00
0005432839443	28922	Economy	6200.00
0005432839494	28922	Economy	6200.00
0005435253075	28922	Economy	6200.00
0005435253062	28922	Economy	6200.00
0005434458992	28922	Economy	6200.00
0005432839315	28922	Economy	6200.00
0005432839386	28922	Economy	6200.00
0005432839446	28922	Economy	6200.00
0005434459042	28922	Economy	6200.00
0005432839375	28922	Economy	6200.00
0005435253074	28922	Economy	6200.00
0005432839468	28922	Economy	6200.00
0005432001064	28922	Economy	6200.00
0005432839374	28922	Economy	6200.00
0005434665008	28922	Economy	6200.00
0005432839425	28922	Economy	6200.00
0005432839395	28922	Economy	6200.00
0005434459069	28922	Economy	6200.00
0005432839423	28922	Economy	6200.00
0005432839422	28922	Economy	6200.00
0005435253066	28922	Economy	6200.00
0005432839390	28922	Economy	6200.00
0005432839384	28922	Economy	6200.00
0005435253079	28922	Economy	6200.00
0005434459021	28922	Economy	6200.00
0005432839467	28922	Economy	6200.00
0005435253071	28922	Economy	6200.00
0005435253068	28922	Economy	6200.00
0005432839510	28922	Economy	6200.00
0005432839364	28922	Economy	6200.00
0005432001066	28922	Economy	6200.00
0005435253067	28922	Economy	6200.00
0005432839391	28922	Economy	6200.00
0005435253073	28922	Economy	6200.00
0005434459026	28922	Economy	6200.00
0005434665007	28922	Economy	6200.00
0005435253065	28922	Economy	6200.00
0005432839385	28922	Economy	6200.00
0005435253063	28922	Economy	6200.00
0005434459032	28922	Economy	6200.00
0005434459169	28922	Economy	6200.00
0005435253076	28922	Economy	6200.00
0005434459041	28922	Economy	6200.00
0005435491487	28922	Economy	6200.00
0005435253070	28922	Economy	6200.00
0005435253072	28922	Economy	6200.00
0005435253077	28922	Economy	6200.00
0005432001065	28922	Economy	6200.00
0005432823478	28922	Economy	6200.00
0005434459070	28922	Economy	6200.00
0005432839438	28922	Economy	6200.00
0005434459023	28922	Economy	6200.00
0005434459031	28922	Economy	6200.00
0005434459054	28922	Economy	6200.00
0005434665009	28922	Economy	6200.00
0005432839414	28922	Economy	6200.00
0005434458998	28922	Economy	6200.00
0005432839455	28922	Economy	6200.00
0005434459081	28922	Economy	6200.00
0005435253078	28922	Economy	6200.00
0005434458993	28922	Economy	6200.00
0005434276107	8826	Business	145300.00
0005435990771	8826	Economy	48400.00
0005435990767	8826	Economy	48400.00
0005435990773	8826	Economy	48400.00
0005434276084	8826	Economy	48400.00
0005435990769	8826	Economy	48400.00
0005435990768	8826	Economy	48400.00
0005435990770	8826	Economy	48400.00
0005435990772	8826	Economy	48400.00
0005434276099	8826	Economy	48400.00
0005434276081	8826	Economy	48400.00
0005434276110	8826	Economy	48400.00
0005434276147	15736	Business	145300.00
0005435990666	15736	Business	145300.00
0005435990667	15736	Business	145300.00
0005435990709	15736	Economy	48400.00
0005434276144	15736	Economy	48400.00
0005434276148	15736	Economy	48400.00
0005435990710	15736	Economy	48400.00
0005434276146	15736	Economy	48400.00
0005435990711	15736	Economy	48400.00
0005434276143	15736	Economy	48400.00
0005434276145	15736	Economy	48400.00
0005433468512	2086	Economy	12100.00
0005433468507	2086	Economy	12100.00
0005433468522	2086	Economy	12100.00
0005432909349	2086	Economy	12100.00
0005433468516	2086	Economy	12100.00
0005433468515	2086	Economy	12100.00
0005433468514	2086	Economy	12100.00
0005432909352	2086	Economy	12100.00
0005433468519	2086	Economy	12100.00
0005433468511	2086	Economy	12100.00
0005432909351	2086	Economy	12100.00
0005432909369	2086	Economy	12100.00
0005432909323	2086	Economy	12100.00
0005432909335	2086	Economy	12100.00
0005433468521	2086	Economy	12100.00
0005432909334	2086	Economy	12100.00
0005433468510	2086	Economy	12100.00
0005433468517	2086	Economy	12100.00
0005433468509	2086	Economy	12100.00
0005433468513	2086	Economy	12100.00
0005433468508	2086	Economy	12100.00
0005433468520	2086	Economy	12100.00
0005432909324	2086	Economy	12100.00
0005433468518	2086	Economy	12100.00
0005433468523	2086	Economy	12100.00
0005432909339	2086	Economy	12100.00
0005432909320	2086	Economy	12100.00
0005433468433	23830	Economy	13300.00
0005432909392	23830	Economy	13300.00
0005432909385	23830	Economy	13300.00
0005433468431	23830	Economy	12100.00
0005433468443	23830	Economy	12100.00
0005432909397	23830	Economy	12100.00
0005433468447	23830	Economy	12100.00
0005433468407	23830	Economy	12100.00
0005433468429	23830	Economy	12100.00
0005432909390	23830	Economy	12100.00
0005433468446	23830	Economy	12100.00
0005432909383	23830	Economy	12100.00
0005433468442	23830	Economy	12100.00
0005432909387	23830	Economy	12100.00
0005432909388	23830	Economy	12100.00
0005432909391	23830	Economy	12100.00
0005433468379	23830	Economy	12100.00
0005433468435	23830	Economy	12100.00
0005433468380	23830	Economy	12100.00
0005432909381	23830	Economy	12100.00
0005432909384	23830	Economy	12100.00
0005432909386	23830	Economy	12100.00
0005433468381	23830	Economy	12100.00
0005433468430	23830	Economy	12100.00
0005432909393	23830	Economy	12100.00
0005433468409	23830	Economy	12100.00
0005433468405	23830	Economy	12100.00
0005432909389	23830	Economy	12100.00
0005433468453	23830	Economy	12100.00
0005432909382	23830	Economy	12100.00
0005433468401	23830	Economy	12100.00
0005433468413	23830	Economy	12100.00
0005432909394	23830	Economy	12100.00
0005433468414	23830	Economy	12100.00
0005433468432	23830	Economy	12100.00
0005433468408	23830	Economy	12100.00
0005433468434	23830	Economy	12100.00
0005432909395	23830	Economy	12100.00
0005433468444	23830	Economy	12100.00
0005433468445	23830	Economy	12100.00
0005432909396	23830	Economy	12100.00
0005432361337	6416	Business	36600.00
0005432361354	6416	Business	36600.00
0005432361366	6416	Business	36600.00
0005432361371	6416	Business	36600.00
0005432361355	6416	Business	36600.00
0005435177390	6416	Business	36600.00
0005432062339	6416	Business	36600.00
0005435177389	6416	Business	36600.00
0005435177317	6416	Business	36600.00
0005432361344	6416	Business	36600.00
0005432361361	6416	Economy	12200.00
0005432062341	6416	Economy	12200.00
0005432336284	6416	Economy	12200.00
0005432361367	6416	Economy	12200.00
0005432361331	6416	Economy	12200.00
0005434149898	6416	Economy	12200.00
0005432363484	6416	Economy	12200.00
0005435177485	6416	Economy	12200.00
0005435177444	6416	Economy	12200.00
0005434149902	6416	Economy	12200.00
0005432361328	6416	Economy	12200.00
0005432336276	6416	Economy	12200.00
0005432361345	6416	Economy	12200.00
0005432361332	6416	Economy	12200.00
0005432361356	6416	Economy	12200.00
0005434149828	6416	Economy	12200.00
0005432361358	6416	Economy	12200.00
0005435177358	6416	Economy	12200.00
0005432361338	6416	Economy	12200.00
0005435177439	6416	Economy	12200.00
0005435177411	6416	Economy	12200.00
0005435177539	6416	Economy	12200.00
0005434149869	6416	Economy	12200.00
0005434149905	6416	Economy	12200.00
0005432361351	6416	Economy	12200.00
0005432361370	6416	Economy	12200.00
0005435490267	6416	Economy	12200.00
0005432361349	6416	Economy	12200.00
0005432363483	6416	Economy	12200.00
0005434149886	6416	Economy	12200.00
0005435177406	6416	Economy	12200.00
0005432361342	6416	Economy	12200.00
0005432361346	6416	Economy	12200.00
0005434149815	6416	Economy	12200.00
0005432062338	6416	Economy	12200.00
0005434149870	6416	Economy	13400.00
0005432361348	6416	Economy	13400.00
0005435177408	6416	Economy	13400.00
0005435177431	6416	Economy	13400.00
0005432062340	6416	Economy	13400.00
0005432361360	6416	Economy	13400.00
0005432361343	6416	Economy	12200.00
0005435177298	6416	Economy	12200.00
0005435490266	6416	Economy	12200.00
0005434149887	6416	Economy	12200.00
0005432361350	6416	Economy	12200.00
0005435177312	6416	Economy	12200.00
0005432361359	6416	Economy	12200.00
0005432361329	6416	Economy	12200.00
0005432336283	6416	Economy	12200.00
0005434149827	6416	Economy	12200.00
0005432062337	6416	Economy	12200.00
0005435177407	6416	Economy	12200.00
0005432361336	6416	Economy	12200.00
0005432361335	6416	Economy	12200.00
0005432361364	6416	Economy	12200.00
0005435177513	6416	Economy	12200.00
0005432361363	6416	Economy	12200.00
0005434149906	6416	Economy	12200.00
0005435177377	6416	Economy	12200.00
0005432336281	6416	Economy	12200.00
0005435177514	6416	Economy	12200.00
0005434149825	6416	Economy	12200.00
0005432361368	6416	Economy	12200.00
0005432361373	6416	Economy	12200.00
0005435177318	6416	Economy	12200.00
0005432363482	6416	Economy	12200.00
0005435177430	6416	Economy	12200.00
0005435177538	6416	Economy	12200.00
0005435177420	6416	Economy	12200.00
0005432361352	6416	Economy	12200.00
0005432361341	6416	Economy	12200.00
0005434149911	6416	Economy	12200.00
0005435177235	6416	Economy	12200.00
0005435177356	6416	Economy	12200.00
0005432361327	6416	Economy	12200.00
0005435177398	6416	Economy	12200.00
0005435177394	6416	Economy	12200.00
0005432361334	6416	Economy	12200.00
0005435177357	6416	Economy	12200.00
0005432361362	6416	Economy	12200.00
0005435490253	6416	Economy	12200.00
0005432336277	6416	Economy	12200.00
0005432361374	6416	Economy	12200.00
0005432336282	6416	Economy	12200.00
0005432361353	6416	Economy	12200.00
0005432361339	6416	Economy	12200.00
0005435177366	6416	Economy	12200.00
0005435177413	6416	Economy	12200.00
0005432336278	6416	Economy	12200.00
0005435177275	6416	Economy	12200.00
0005432361330	6416	Economy	12200.00
0005432361333	6416	Economy	12200.00
0005432361372	6416	Economy	12200.00
0005434149826	6416	Economy	12200.00
0005435723062	6416	Economy	12200.00
0005435177393	6416	Economy	12200.00
0005432361365	6416	Economy	12200.00
0005435177399	6416	Economy	12200.00
0005434149852	6416	Economy	12200.00
0005432361357	6416	Economy	12200.00
0005432336280	6416	Economy	12200.00
0005432361340	6416	Economy	12200.00
0005432336275	6416	Economy	12200.00
0005432361347	6416	Economy	12200.00
0005434149899	6416	Economy	12200.00
0005434149829	6416	Economy	12200.00
0005432336279	6416	Economy	12200.00
0005432361369	6416	Economy	12200.00
0005432336274	6416	Economy	12200.00
0005432336140	21021	Business	36600.00
0005432360999	21021	Business	36600.00
0005435177644	21021	Business	36600.00
0005432360997	21021	Business	36600.00
0005432360837	21021	Business	36600.00
0005435490308	21021	Business	36600.00
0005432360996	21021	Business	36600.00
0005432361002	21021	Business	36600.00
0005435490307	21021	Business	36600.00
0005432361039	21021	Business	36600.00
0005432361015	21021	Business	36600.00
0005432360903	21021	Economy	12200.00
0005432336171	21021	Economy	12200.00
0005432360933	21021	Economy	12200.00
0005435490305	21021	Economy	12200.00
0005435177638	21021	Economy	12200.00
0005432360846	21021	Economy	12200.00
0005432360961	21021	Economy	12200.00
0005435177637	21021	Economy	12200.00
0005434149973	21021	Economy	12200.00
0005432360898	21021	Economy	12200.00
0005432360912	21021	Economy	12200.00
0005434149970	21021	Economy	12200.00
0005435723085	21021	Economy	12200.00
0005432360845	21021	Economy	12200.00
0005432052810	21021	Economy	12200.00
0005432360935	21021	Economy	12200.00
0005435177634	21021	Economy	12200.00
0005435177643	21021	Economy	12200.00
0005432360719	21021	Economy	12200.00
0005432360954	21021	Economy	12200.00
0005432360955	21021	Economy	12200.00
0005432052808	21021	Economy	12200.00
0005435177628	21021	Economy	12200.00
0005432361000	21021	Economy	12200.00
0005432360998	21021	Economy	12200.00
0005435177654	21021	Economy	12200.00
0005435177646	21021	Economy	12200.00
0005434149972	21021	Economy	12200.00
0005432363463	21021	Economy	12200.00
0005435177649	21021	Economy	12200.00
0005435177641	21021	Economy	12200.00
0005432360841	21021	Economy	12200.00
0005434149976	21021	Economy	12200.00
0005432361009	21021	Economy	12200.00
0005435177651	21021	Economy	12200.00
0005432360990	21021	Economy	12200.00
0005432360819	21021	Economy	13400.00
0005435177630	21021	Economy	13400.00
0005435177647	21021	Economy	13400.00
0005434149974	21021	Economy	12200.00
0005435177642	21021	Economy	13400.00
0005435177629	21021	Economy	12200.00
0005434149966	21021	Economy	12200.00
0005435177631	21021	Economy	12200.00
0005435490306	21021	Economy	12200.00
0005432336133	21021	Economy	12200.00
0005434149969	21021	Economy	12200.00
0005432360832	21021	Economy	12200.00
0005435177632	21021	Economy	12200.00
0005432361064	21021	Economy	12200.00
0005434149975	21021	Economy	12200.00
0005434149967	21021	Economy	12200.00
0005434149977	21021	Economy	12200.00
0005432360911	21021	Economy	12200.00
0005432360948	21021	Economy	12200.00
0005435177633	21021	Economy	12200.00
0005435177640	21021	Economy	12200.00
0005434149968	21021	Economy	12200.00
0005432361025	21021	Economy	12200.00
0005432361001	21021	Economy	12200.00
0005432360847	21021	Economy	12200.00
0005432360834	21021	Economy	12200.00
0005432360971	21021	Economy	12200.00
0005432360883	21021	Economy	12200.00
0005432336139	21021	Economy	12200.00
0005435177639	21021	Economy	12200.00
0005435723084	21021	Economy	12200.00
0005432360836	21021	Economy	12200.00
0005435177650	21021	Economy	12200.00
0005435177636	21021	Economy	12200.00
0005432336170	21021	Economy	12200.00
0005432052809	21021	Economy	12200.00
0005435177635	21021	Economy	12200.00
0005432361094	21021	Economy	12200.00
0005432336156	21021	Economy	12200.00
0005434149971	21021	Economy	12200.00
0005435177645	21021	Economy	12200.00
0005432363458	21021	Economy	12200.00
0005435177653	21021	Economy	12200.00
0005432361095	21021	Economy	12200.00
0005432360979	21021	Economy	12200.00
0005432361053	21021	Economy	12200.00
0005432336169	21021	Economy	12200.00
0005432363461	21021	Economy	12200.00
0005432360876	21021	Economy	12200.00
0005432361038	21021	Economy	12200.00
0005435177652	21021	Economy	12200.00
0005432360888	21021	Economy	12200.00
0005435177648	21021	Economy	12200.00
0005432363460	21021	Economy	12200.00
0005432361065	21021	Economy	12200.00
0005432360966	21021	Economy	12200.00
0005432336167	21021	Economy	12200.00
0005432360902	21021	Economy	12200.00
0005432360887	21021	Economy	12200.00
0005432360980	21021	Economy	12200.00
0005434461661	17735	Economy	3400.00
0005434458967	17735	Economy	3100.00
0005434461660	17735	Economy	3100.00
0005434448350	17735	Economy	3100.00
0005434463953	17735	Economy	3100.00
0005434463952	17735	Economy	3100.00
0005434459037	17735	Economy	3100.00
0005434459125	17735	Economy	3100.00
0005434458966	17735	Economy	3100.00
0005434459038	17735	Economy	3100.00
0005434459016	17735	Economy	3100.00
0005434459077	17735	Economy	3100.00
0005434463949	17735	Economy	3100.00
0005434461675	17735	Economy	3100.00
0005434459045	17735	Economy	3100.00
0005434458968	17735	Economy	3100.00
0005434461674	17735	Economy	3100.00
0005434459091	17735	Economy	3100.00
0005434459007	17735	Economy	3100.00
0005434186259	17735	Economy	3100.00
0005434448346	17735	Economy	3100.00
0005434459102	17735	Economy	3100.00
0005434459076	17735	Economy	3100.00
0005434459088	17735	Economy	3100.00
0005434459043	17735	Economy	3100.00
0005434459126	17735	Economy	3100.00
0005434459075	17735	Economy	3100.00
0005434448347	17735	Economy	3100.00
0005434459107	17735	Economy	3100.00
0005434459044	17735	Economy	3100.00
0005434459124	17735	Economy	3100.00
0005434186260	17735	Economy	3100.00
0005434186234	29118	Economy	3400.00
0005434463972	29118	Economy	3400.00
0005434459235	29118	Economy	3100.00
0005434459222	29118	Economy	3100.00
0005434459234	29118	Economy	3100.00
0005434448382	29118	Economy	3100.00
0005434459232	29118	Economy	3100.00
0005434459225	29118	Economy	3100.00
0005434459231	29118	Economy	3100.00
0005434459241	29118	Economy	3100.00
0005434459227	29118	Economy	3100.00
0005434459242	29118	Economy	3100.00
0005434459226	29118	Economy	3100.00
0005434459230	29118	Economy	3100.00
0005434459228	29118	Economy	3100.00
0005434459224	29118	Economy	3100.00
0005434459239	29118	Economy	3100.00
0005434462833	29118	Economy	3100.00
0005434459238	29118	Economy	3100.00
0005434459223	29118	Economy	3100.00
0005434448383	29118	Economy	3100.00
0005434462832	29118	Economy	3100.00
0005434459233	29118	Economy	3100.00
0005434459229	29118	Economy	3100.00
0005434463973	29118	Economy	3100.00
0005434459237	29118	Economy	3100.00
0005434459236	29118	Economy	3100.00
0005434459240	29118	Economy	3100.00
0005432605103	21438	Economy	7300.00
0005432605124	21438	Economy	7300.00
0005432605127	21438	Economy	7300.00
0005432605131	21438	Economy	7300.00
0005432605110	21438	Economy	6600.00
0005432605118	21438	Economy	6600.00
0005432605130	21438	Economy	6600.00
0005432605102	21438	Economy	6600.00
0005432605126	21438	Economy	6600.00
0005432605133	21438	Economy	6600.00
0005432605107	21438	Economy	6600.00
0005432605125	21438	Economy	6600.00
0005432605132	21438	Economy	6600.00
0005432605120	21438	Economy	6600.00
0005432605113	21438	Economy	6600.00
0005432605116	21438	Economy	6600.00
0005432605122	21438	Economy	6600.00
0005432605112	21438	Economy	6600.00
0005432605138	21438	Economy	6600.00
0005432605139	21438	Economy	6600.00
0005432605108	21438	Economy	6600.00
0005432605135	21438	Economy	6600.00
0005432605106	21438	Economy	6600.00
0005432605121	21438	Economy	6600.00
0005432605104	21438	Economy	6600.00
0005432605142	21438	Economy	6600.00
0005432605109	21438	Economy	6600.00
0005432605134	21438	Economy	6600.00
0005432605123	21438	Economy	6600.00
0005432605129	21438	Economy	6600.00
0005432605136	21438	Economy	6600.00
0005432605137	21438	Economy	6600.00
0005432605128	21438	Economy	6600.00
0005432605105	21438	Economy	6600.00
0005432605141	21438	Economy	6600.00
0005432605115	21438	Economy	6600.00
0005432605140	21438	Economy	6600.00
0005432605117	21438	Economy	6600.00
0005432605111	21438	Economy	6600.00
0005432605119	21438	Economy	6600.00
0005432605114	21438	Economy	6600.00
0005432604840	31680	Economy	7300.00
0005432604626	31680	Economy	7300.00
0005432604751	31680	Economy	7300.00
0005432604896	31680	Economy	7300.00
0005432604727	31680	Economy	6600.00
0005432604650	31680	Economy	6600.00
0005432604897	31680	Economy	6600.00
0005432604801	31680	Economy	6600.00
0005432604830	31680	Economy	6600.00
0005432604736	31680	Economy	6600.00
0005432604763	31680	Economy	6600.00
0005432604816	31680	Economy	6600.00
0005432604679	31680	Economy	6600.00
0005432604762	31680	Economy	6600.00
0005432604802	31680	Economy	6600.00
0005432604773	31680	Economy	6600.00
0005432604659	31680	Economy	6600.00
0005432604676	31680	Economy	6600.00
0005432604737	31680	Economy	6600.00
0005432604678	31680	Economy	6600.00
0005432604924	31680	Economy	6600.00
0005432604926	31680	Economy	6600.00
0005432604758	31680	Economy	6600.00
0005432604817	31680	Economy	6600.00
0005432604730	31680	Economy	6600.00
0005432604782	31680	Economy	6600.00
0005432604774	31680	Economy	6600.00
0005432604711	31680	Economy	6600.00
0005432604735	31680	Economy	6600.00
0005432604856	31680	Economy	6600.00
0005432604923	31680	Economy	6600.00
0005432604775	31680	Economy	6600.00
0005432604786	31680	Economy	6600.00
0005432604868	31680	Economy	6600.00
0005432604925	31680	Economy	6600.00
0005432604738	31680	Economy	6600.00
0005432604729	31680	Economy	6600.00
0005432604749	31680	Economy	6600.00
0005432604657	31680	Economy	6600.00
0005432604750	31680	Economy	6600.00
0005432604720	31680	Economy	6600.00
0005432604680	31680	Economy	6600.00
0005432604807	31680	Economy	6600.00
0005432604815	31680	Economy	6600.00
0005432604776	31680	Economy	6600.00
0005432604828	31680	Economy	6600.00
0005433293371	29596	Economy	19500.00
0005433293383	29596	Economy	17800.00
0005433293375	29596	Economy	17800.00
0005433293373	29596	Economy	17800.00
0005433293379	29596	Economy	17800.00
0005433293380	29596	Economy	17800.00
0005435154603	29596	Economy	17800.00
0005433293374	29596	Economy	17800.00
0005435154605	29596	Economy	17800.00
0005433293381	29596	Economy	17800.00
0005435154604	29596	Economy	17800.00
0005433293377	29596	Economy	17800.00
0005433293378	29596	Economy	17800.00
0005433293376	29596	Economy	17800.00
0005433293384	29596	Economy	17800.00
0005433293382	29596	Economy	17800.00
0005433293372	29596	Economy	17800.00
0005433473456	6692	Economy	14000.00
0005435257282	6692	Economy	14000.00
0005433473458	6692	Economy	12700.00
0005433473444	6692	Economy	12700.00
0005433473447	6692	Economy	12700.00
0005435257294	6692	Economy	12700.00
0005435257281	6692	Economy	12700.00
0005435257302	6692	Economy	12700.00
0005433473451	6692	Economy	12700.00
0005433473460	6692	Economy	12700.00
0005435257286	6692	Economy	12700.00
0005433473448	6692	Economy	12700.00
0005435257283	6692	Economy	12700.00
0005433473459	6692	Economy	12700.00
0005435257298	6692	Economy	12700.00
0005435257284	6692	Economy	12700.00
0005433473450	6692	Economy	12700.00
0005435257285	6692	Economy	12700.00
0005433473445	6692	Economy	12700.00
0005433473457	6692	Economy	12700.00
0005433473453	6692	Economy	12700.00
0005433473452	6692	Economy	12700.00
0005433473455	6692	Economy	12700.00
0005433473449	6692	Economy	12700.00
0005435257293	6692	Economy	12700.00
0005433473461	6692	Economy	12700.00
0005433473454	6692	Economy	12700.00
0005433473446	6692	Economy	12700.00
0005433473326	23892	Economy	14000.00
0005435257334	23892	Economy	14000.00
0005433473364	23892	Economy	14000.00
0005433473389	23892	Economy	14000.00
0005433473377	23892	Economy	12700.00
0005435257342	23892	Economy	12700.00
0005433473412	23892	Economy	12700.00
0005435257340	23892	Economy	12700.00
0005433473371	23892	Economy	12700.00
0005433473390	23892	Economy	12700.00
0005433473342	23892	Economy	12700.00
0005433473356	23892	Economy	12700.00
0005433473321	23892	Economy	12700.00
0005433473358	23892	Economy	12700.00
0005435257330	23892	Economy	12700.00
0005433473369	23892	Economy	12700.00
0005433473392	23892	Economy	12700.00
0005433473375	23892	Economy	12700.00
0005435257341	23892	Economy	12700.00
0005435257331	23892	Economy	12700.00
0005433473360	23892	Economy	12700.00
0005433473370	23892	Economy	12700.00
0005433473382	23892	Economy	12700.00
0005433473331	23892	Economy	12700.00
0005435257337	23892	Economy	12700.00
0005433473346	23892	Economy	12700.00
0005435257339	23892	Economy	12700.00
0005433473357	23892	Economy	12700.00
0005433473394	23892	Economy	12700.00
0005433473340	23892	Economy	12700.00
0005435257343	23892	Economy	12700.00
0005435257335	23892	Economy	12700.00
0005435257338	23892	Economy	12700.00
0005433473411	23892	Economy	12700.00
0005433473314	23892	Economy	12700.00
0005433473327	23892	Economy	12700.00
0005433473376	23892	Economy	12700.00
0005435257332	23892	Economy	12700.00
0005433473368	23892	Economy	12700.00
0005433473366	23892	Economy	12700.00
0005435257333	23892	Economy	12700.00
0005433473374	23892	Economy	12700.00
0005433473372	23892	Economy	12700.00
0005433473388	23892	Economy	12700.00
0005433473407	23892	Economy	12700.00
0005435257344	23892	Economy	12700.00
0005433473328	23892	Economy	12700.00
0005433473393	23892	Economy	12700.00
0005435257336	23892	Economy	12700.00
0005434606866	18920	Economy	6600.00
0005434606873	18920	Economy	6600.00
0005434606860	18920	Economy	6600.00
0005434606868	18920	Economy	6600.00
0005434606876	18920	Economy	6600.00
0005434606877	18920	Economy	6600.00
0005434606861	18920	Economy	6600.00
0005434606859	18920	Economy	6600.00
0005434606862	18920	Economy	6600.00
0005434606869	18920	Economy	6600.00
0005434606851	18920	Economy	6600.00
0005434604966	22393	Economy	6600.00
0005434606893	22393	Economy	6600.00
0005434604971	22393	Economy	6600.00
0005434606891	22393	Economy	6600.00
0005434606894	22393	Economy	6600.00
0005434604967	22393	Economy	6600.00
0005434604970	22393	Economy	6600.00
0005434604969	22393	Economy	6600.00
0005434604968	22393	Economy	6600.00
0005434606892	22393	Economy	6600.00
0005434602950	3850	Economy	24900.00
0005434522521	3850	Economy	24900.00
0005434522515	3850	Economy	22600.00
0005434522523	3850	Economy	22600.00
0005434522516	3850	Economy	22600.00
0005435904425	3850	Economy	22600.00
0005434602948	3850	Economy	22600.00
0005434522520	3850	Economy	22600.00
0005434522517	3850	Economy	22600.00
0005435904417	3850	Economy	22600.00
0005435904438	3850	Economy	22600.00
0005434522524	3850	Economy	22600.00
0005434522522	3850	Economy	22600.00
0005434522525	3850	Economy	22600.00
0005434522519	3850	Economy	22600.00
0005435904437	3850	Economy	22600.00
0005435904429	3850	Economy	22600.00
0005435904436	3850	Economy	22600.00
0005434602949	3850	Economy	22600.00
0005435904418	3850	Economy	22600.00
0005435904419	3850	Economy	22600.00
0005434522518	3850	Economy	22600.00
0005434522514	3850	Economy	22600.00
0005435904457	19068	Economy	24900.00
0005434604944	19068	Economy	24900.00
0005435904718	19068	Economy	22600.00
0005434522494	19068	Economy	22600.00
0005434604909	19068	Economy	22600.00
0005435904715	19068	Economy	22600.00
0005434522490	19068	Economy	22600.00
0005434522491	19068	Economy	22600.00
0005434522478	19068	Economy	22600.00
0005434522497	19068	Economy	22600.00
0005434604911	19068	Economy	22600.00
0005434604927	19068	Economy	22600.00
0005435904717	19068	Economy	22600.00
0005435904453	19068	Economy	22600.00
0005434604912	19068	Economy	22600.00
0005434522498	19068	Economy	22600.00
0005435904452	19068	Economy	22600.00
0005435904456	19068	Economy	22600.00
0005435904716	19068	Economy	22600.00
0005434602913	19068	Economy	22600.00
0005434602926	19068	Economy	22600.00
0005434604923	19068	Economy	22600.00
0005435904451	19068	Economy	22600.00
0005435904454	19068	Economy	22600.00
0005434604931	19068	Economy	22600.00
0005434522466	19068	Economy	22600.00
0005435904455	19068	Economy	22600.00
0005434604922	19068	Economy	22600.00
0005434522493	19068	Economy	22600.00
0005434604920	19068	Economy	22600.00
0005434522496	19068	Economy	22600.00
0005434522492	19068	Economy	22600.00
0005434604910	19068	Economy	22600.00
0005434602927	19068	Economy	22600.00
0005435904458	19068	Economy	22600.00
0005433293319	408	Business	44500.00
0005432748357	408	Business	44500.00
0005432749827	408	Business	44500.00
0005433875398	408	Business	44500.00
0005432748338	408	Business	44500.00
0005432748332	408	Business	44500.00
0005432748355	408	Business	44500.00
0005432748363	408	Business	44500.00
0005432753367	408	Business	44500.00
0005432748362	408	Business	44500.00
0005432891240	408	Economy	14800.00
0005432751592	408	Economy	14800.00
0005432748358	408	Economy	14800.00
0005432748356	408	Economy	14800.00
0005432748331	408	Economy	14800.00
0005432891251	408	Economy	14800.00
0005432748350	408	Economy	14800.00
0005433875399	408	Economy	14800.00
0005432891316	408	Economy	14800.00
0005432748346	408	Economy	16300.00
0005432748349	408	Economy	16300.00
0005435154638	408	Economy	16300.00
0005432751594	408	Economy	16300.00
0005433293344	408	Economy	14800.00
0005432748341	408	Economy	14800.00
0005432748337	408	Economy	14800.00
0005432748343	408	Economy	14800.00
0005433293343	408	Economy	14800.00
0005432748334	408	Economy	14800.00
0005432891268	408	Economy	14800.00
0005432748336	408	Economy	14800.00
0005432751593	408	Economy	14800.00
0005432748326	408	Economy	14800.00
0005433293320	408	Economy	14800.00
0005432748353	408	Economy	14800.00
0005432748352	408	Economy	14800.00
0005432891155	408	Economy	14800.00
0005432748359	408	Economy	14800.00
0005433293321	408	Economy	14800.00
0005432748329	408	Economy	14800.00
0005435154639	408	Economy	14800.00
0005432220092	408	Economy	14800.00
0005432748335	408	Economy	14800.00
0005432748340	408	Economy	14800.00
0005432751590	408	Economy	14800.00
0005432748361	408	Economy	14800.00
0005432891223	408	Economy	14800.00
0005433293318	408	Economy	14800.00
0005435154647	408	Economy	14800.00
0005432891275	408	Economy	14800.00
0005432748330	408	Economy	14800.00
0005432749829	408	Economy	14800.00
0005432748351	408	Economy	14800.00
0005432748347	408	Economy	14800.00
0005432748324	408	Economy	14800.00
0005432749828	408	Economy	14800.00
0005432753369	408	Economy	14800.00
0005432748345	408	Economy	14800.00
0005432220089	408	Economy	14800.00
0005432891305	408	Economy	14800.00
0005432748325	408	Economy	14800.00
0005432891201	408	Economy	14800.00
0005432220091	408	Economy	14800.00
0005432748344	408	Economy	14800.00
0005432748333	408	Economy	14800.00
0005435154645	408	Economy	14800.00
0005432751591	408	Economy	14800.00
0005435154646	408	Economy	14800.00
0005435154644	408	Economy	14800.00
0005432748348	408	Economy	14800.00
0005435154641	408	Economy	14800.00
0005432891241	408	Economy	14800.00
0005432748360	408	Economy	14800.00
0005432891276	408	Economy	14800.00
0005432748342	408	Economy	14800.00
0005432748339	408	Economy	14800.00
0005432753368	408	Economy	14800.00
0005435154643	408	Economy	14800.00
0005432220090	408	Economy	14800.00
0005432748328	408	Economy	14800.00
0005435154642	408	Economy	14800.00
0005435154640	408	Economy	14800.00
0005432748327	408	Economy	14800.00
0005432748354	408	Economy	14800.00
0005432891420	12037	Business	44500.00
0005432748131	12037	Business	44500.00
0005432748038	12037	Business	44500.00
0005432748194	12037	Business	44500.00
0005432891419	12037	Business	44500.00
0005432891413	12037	Business	44500.00
0005432748253	12037	Business	44500.00
0005432748007	12037	Business	44500.00
0005432748030	12037	Business	44500.00
0005432748092	12037	Economy	14800.00
0005432753354	12037	Economy	14800.00
0005432756877	12037	Economy	14800.00
0005432756870	12037	Economy	14800.00
0005432748176	12037	Economy	14800.00
0005432749813	12037	Economy	14800.00
0005432891427	12037	Economy	14800.00
0005432747951	12037	Economy	16300.00
0005432891416	12037	Economy	16300.00
0005432748050	12037	Economy	16300.00
0005432747972	12037	Economy	16300.00
0005432749812	12037	Economy	14800.00
0005432891423	12037	Economy	14800.00
0005432756878	12037	Economy	14800.00
0005432748252	12037	Economy	14800.00
0005432748074	12037	Economy	14800.00
0005432748153	12037	Economy	14800.00
0005432748075	12037	Economy	14800.00
0005432748151	12037	Economy	14800.00
0005432214848	12037	Economy	14800.00
0005432891429	12037	Economy	14800.00
0005432747995	12037	Economy	14800.00
0005432891415	12037	Economy	14800.00
0005432748214	12037	Economy	14800.00
0005432891418	12037	Economy	14800.00
0005432748139	12037	Economy	14800.00
0005434152854	12037	Economy	14800.00
0005432748106	12037	Economy	14800.00
0005432891411	12037	Economy	14800.00
0005432748125	12037	Economy	14800.00
0005432891414	12037	Economy	14800.00
0005432756886	12037	Economy	14800.00
0005433875413	12037	Economy	14800.00
0005432748138	12037	Economy	14800.00
0005432214847	12037	Economy	14800.00
0005432756875	12037	Economy	14800.00
0005432891428	12037	Economy	14800.00
0005432891422	12037	Economy	14800.00
0005432891412	12037	Economy	14800.00
0005432748124	12037	Economy	14800.00
0005432748056	12037	Economy	14800.00
0005432748204	12037	Economy	14800.00
0005432891421	12037	Economy	14800.00
0005432748051	12037	Economy	14800.00
0005432891424	12037	Economy	14800.00
0005432748008	12037	Economy	14800.00
0005433875414	12037	Economy	14800.00
0005432891425	12037	Economy	14800.00
0005432748137	12037	Economy	14800.00
0005432748072	12037	Economy	14800.00
0005432747971	12037	Economy	14800.00
0005432756876	12037	Economy	14800.00
0005432749814	12037	Economy	14800.00
0005432748154	12037	Economy	14800.00
0005432749810	12037	Economy	14800.00
0005432891417	12037	Economy	14800.00
0005432748070	12037	Economy	14800.00
0005432748037	12037	Economy	14800.00
0005432748071	12037	Economy	14800.00
0005432748036	12037	Economy	14800.00
0005432891430	12037	Economy	14800.00
0005432748213	12037	Economy	14800.00
0005432747943	12037	Economy	14800.00
0005432748205	12037	Economy	14800.00
0005432891426	12037	Economy	14800.00
0005433525252	18950	Economy	28200.00
0005433525254	18950	Economy	28200.00
0005433525249	18950	Economy	25700.00
0005432928005	18950	Economy	25700.00
0005433525258	18950	Economy	25700.00
0005433525257	18950	Economy	25700.00
0005433525256	18950	Economy	25700.00
0005432928050	18950	Economy	25700.00
0005433531366	18950	Economy	25700.00
0005433533383	18950	Economy	25700.00
0005433533382	18950	Economy	25700.00
0005432928043	18950	Economy	25700.00
0005433531367	18950	Economy	25700.00
0005432928049	18950	Economy	25700.00
0005433525250	18950	Economy	25700.00
0005433533380	18950	Economy	25700.00
0005433533381	18950	Economy	25700.00
0005433525255	18950	Economy	25700.00
0005433525251	18950	Economy	25700.00
0005433525259	18950	Economy	25700.00
0005432928044	18950	Economy	25700.00
0005433525253	18950	Economy	25700.00
0005433525260	18950	Economy	25700.00
0005433531368	18950	Economy	25700.00
0005432928006	18950	Economy	25700.00
0005433525167	32462	Economy	28200.00
0005432928103	32462	Economy	28200.00
0005432928100	32462	Economy	25700.00
0005433525212	32462	Economy	25700.00
0005433531338	32462	Economy	25700.00
0005433531332	32462	Economy	25700.00
0005433525213	32462	Economy	25700.00
0005433527302	32462	Economy	25700.00
0005433525093	32462	Economy	25700.00
0005433525187	32462	Economy	25700.00
0005432928102	32462	Economy	25700.00
0005433527309	32462	Economy	25700.00
0005432928099	32462	Economy	25700.00
0005433525128	32462	Economy	25700.00
0005433525152	32462	Economy	25700.00
0005432928101	32462	Economy	25700.00
0005433525140	32462	Economy	25700.00
0005433525179	32462	Economy	25700.00
0005433525127	32462	Economy	25700.00
0005433527308	32462	Economy	25700.00
0005433527307	32462	Economy	25700.00
0005433525181	32462	Economy	25700.00
0005433525180	32462	Economy	25700.00
0005432928098	32462	Economy	25700.00
0005433531336	32462	Economy	25700.00
0005433525158	32462	Economy	25700.00
0005433525169	32462	Economy	25700.00
0005433527305	32462	Economy	25700.00
0005433525214	32462	Economy	25700.00
0005433527314	32462	Economy	25700.00
0005434826210	5285	Business	84000.00
0005435374256	5285	Business	84000.00
0005435661952	5285	Business	84000.00
0005434826246	5285	Business	84000.00
0005434826184	5285	Business	84000.00
0005434826209	5285	Business	84000.00
0005434826165	5285	Business	84000.00
0005434826180	5285	Business	84000.00
0005435735172	5285	Business	84000.00
0005434826153	5285	Business	84000.00
0005434826144	5285	Business	84000.00
0005432121629	5285	Business	84000.00
0005434828751	5285	Business	84000.00
0005432121626	5285	Business	84000.00
0005434826195	5285	Business	84000.00
0005432394188	5285	Business	84000.00
0005434826135	5285	Business	84000.00
0005435150313	5285	Business	84000.00
0005435373863	5285	Business	84000.00
0005434826199	5285	Business	84000.00
0005434826217	5285	Comfort	47600.00
0005435304211	5285	Comfort	47600.00
0005435374033	5285	Comfort	47600.00
0005435374120	5285	Comfort	47600.00
0005435374111	5285	Comfort	47600.00
0005435374065	5285	Comfort	47600.00
0005435373936	5285	Comfort	47600.00
0005434826223	5285	Comfort	47600.00
0005434826212	5285	Comfort	47600.00
0005435150316	5285	Comfort	47600.00
0005434826146	5285	Comfort	47600.00
0005435150310	5285	Comfort	47600.00
0005434826202	5285	Comfort	47600.00
0005435373869	5285	Comfort	47600.00
0005434826162	5285	Comfort	47600.00
0005432121625	5285	Comfort	47600.00
0005434665005	5285	Comfort	47600.00
0005432394185	5285	Comfort	47600.00
0005434826138	5285	Comfort	47600.00
0005434826185	5285	Comfort	47600.00
0005435150309	5285	Comfort	47600.00
0005434826179	5285	Comfort	47600.00
0005434826176	5285	Comfort	47600.00
0005434826187	5285	Comfort	47600.00
0005434665004	5285	Comfort	47600.00
0005432121617	5285	Comfort	47600.00
0005434826120	5285	Comfort	47600.00
0005435150318	5285	Comfort	47600.00
0005434826131	5285	Comfort	47600.00
0005435374204	5285	Comfort	47600.00
0005435299831	5285	Comfort	47600.00
0005435374330	5285	Comfort	47600.00
0005435374107	5285	Comfort	47600.00
0005435304209	5285	Comfort	47600.00
0005434826172	5285	Comfort	47600.00
0005434826128	5285	Comfort	47600.00
0005434826181	5285	Comfort	47600.00
0005434826240	5285	Comfort	47600.00
0005434826137	5285	Comfort	47600.00
0005434665006	5285	Economy	28000.00
0005435150314	5285	Economy	28000.00
0005434826190	5285	Economy	28000.00
0005434831245	5285	Economy	28000.00
0005434826125	5285	Economy	28000.00
0005432121624	5285	Economy	28000.00
0005435374116	5285	Economy	28000.00
0005434826160	5285	Economy	28000.00
0005434826189	5285	Economy	28000.00
0005434826194	5285	Economy	28000.00
0005434826216	5285	Economy	28000.00
0005434558451	5285	Economy	28000.00
0005434826119	5285	Economy	28000.00
0005434826142	5285	Economy	28000.00
0005434826168	5285	Economy	28000.00
0005434826151	5285	Economy	28000.00
0005435373864	5285	Economy	28000.00
0005435373969	5285	Economy	28000.00
0005434826143	5285	Economy	28000.00
0005435374122	5285	Economy	28000.00
0005435374202	5285	Economy	28000.00
0005434826169	5285	Economy	28000.00
0005434826238	5285	Economy	28000.00
0005435374115	5285	Economy	28000.00
0005434826221	5285	Economy	28000.00
0005432121620	5285	Economy	28000.00
0005434826211	5285	Economy	28000.00
0005434826227	5285	Economy	28000.00
0005435735179	5285	Economy	28000.00
0005435373872	5285	Economy	28000.00
0005435373919	5285	Economy	28000.00
0005434826148	5285	Economy	28000.00
0005434826207	5285	Economy	28000.00
0005434826204	5285	Economy	28000.00
0005434826230	5285	Economy	28000.00
0005435374121	5285	Economy	28000.00
0005432394186	5285	Economy	28000.00
0005435150322	5285	Economy	28000.00
0005434826167	5285	Economy	28000.00
0005435661960	5285	Economy	28000.00
0005434558448	5285	Economy	28000.00
0005435373835	5285	Economy	28000.00
0005434826132	5285	Economy	28000.00
0005435374119	5285	Economy	28000.00
0005434826159	5285	Economy	28000.00
0005434826197	5285	Economy	28000.00
0005434558453	5285	Economy	28000.00
0005434826193	5285	Economy	28000.00
0005435374101	5285	Economy	28000.00
0005434826141	5285	Economy	30800.00
0005434826231	5285	Economy	28000.00
0005434826203	5285	Economy	28000.00
0005434826124	5285	Economy	30800.00
0005432823465	5285	Economy	30800.00
0005434558449	5285	Economy	28000.00
0005434826155	5285	Economy	28000.00
0005434826139	5285	Economy	28000.00
0005435150319	5285	Economy	28000.00
0005432121621	5285	Economy	28000.00
0005435373883	5285	Economy	28000.00
0005434558452	5285	Economy	28000.00
0005434826133	5285	Economy	28000.00
0005432121623	5285	Economy	28000.00
0005434826186	5285	Economy	28000.00
0005434826236	5285	Economy	28000.00
0005435374010	5285	Economy	28000.00
0005434826228	5285	Economy	28000.00
0005434828753	5285	Economy	28000.00
0005435150312	5285	Economy	28000.00
0005434826145	5285	Economy	28000.00
0005434826198	5285	Economy	28000.00
0005434831244	5285	Economy	28000.00
0005434826117	5285	Economy	28000.00
0005435386645	5285	Economy	28000.00
0005435299837	5285	Economy	28000.00
0005435150321	5285	Economy	28000.00
0005434826149	5285	Economy	28000.00
0005435373868	5285	Economy	28000.00
0005435374023	5285	Economy	28000.00
0005434826200	5285	Economy	28000.00
0005435735176	5285	Economy	28000.00
0005434826123	5285	Economy	28000.00
0005435735202	5285	Economy	28000.00
0005435374100	5285	Economy	28000.00
0005434826182	5285	Economy	28000.00
0005434826126	5285	Economy	28000.00
0005434828754	5285	Economy	28000.00
0005434826201	5285	Economy	28000.00
0005434826164	5285	Economy	28000.00
0005434826226	5285	Economy	28000.00
0005432396323	5285	Economy	28000.00
0005432394189	5285	Economy	28000.00
0005434826116	5285	Economy	28000.00
0005435374047	5285	Economy	28000.00
0005435374035	5285	Economy	28000.00
0005435299821	5285	Economy	28000.00
0005434831243	5285	Economy	28000.00
0005435374110	5285	Economy	28000.00
0005434826196	5285	Economy	28000.00
0005434826166	5285	Economy	28000.00
0005435374108	5285	Economy	28000.00
0005432823466	5285	Economy	28000.00
0005434826214	5285	Economy	28000.00
0005434826147	5285	Economy	28000.00
0005435373935	5285	Economy	28000.00
0005435373993	5285	Economy	28000.00
0005434826206	5285	Economy	28000.00
0005435373926	5285	Economy	28000.00
0005434826161	5285	Economy	28000.00
0005435373941	5285	Economy	28000.00
0005435374059	5285	Economy	28000.00
0005435661946	5285	Economy	28000.00
0005435373821	5285	Economy	28000.00
0005435373970	5285	Economy	28000.00
0005435374034	5285	Economy	28000.00
0005434826121	5285	Economy	28000.00
0005434826173	5285	Economy	28000.00
0005434826244	5285	Economy	28000.00
0005434826205	5285	Economy	28000.00
0005435661947	5285	Economy	28000.00
0005435150323	5285	Economy	28000.00
0005434826163	5285	Economy	28000.00
0005435386648	5285	Economy	28000.00
0005435299818	5285	Economy	28000.00
0005434826229	5285	Economy	28000.00
0005432121622	5285	Economy	28000.00
0005432396321	5285	Economy	28000.00
0005435150311	5285	Economy	28000.00
0005434826234	5285	Economy	28000.00
0005432396324	5285	Economy	28000.00
0005434826154	5285	Economy	28000.00
0005434828752	5285	Economy	28000.00
0005434826140	5285	Economy	28000.00
0005434826130	5285	Economy	28000.00
0005434826150	5285	Economy	28000.00
0005435304217	5285	Economy	28000.00
0005435735168	5285	Economy	28000.00
0005434826208	5285	Economy	28000.00
0005434826241	5285	Economy	30800.00
0005434831242	5285	Economy	30800.00
0005434826152	5285	Economy	30800.00
0005434826220	5285	Economy	30800.00
0005435374072	5285	Economy	30800.00
0005434826158	5285	Economy	28000.00
0005435661959	5285	Economy	28000.00
0005432121627	5285	Economy	28000.00
0005435373820	5285	Economy	28000.00
0005434826215	5285	Economy	28000.00
0005434826213	5285	Economy	28000.00
0005434826224	5285	Economy	28000.00
0005434826174	5285	Economy	28000.00
0005434826134	5285	Economy	28000.00
0005434558454	5285	Economy	28000.00
0005434826178	5285	Economy	28000.00
0005435735180	5285	Economy	28000.00
0005435150317	5285	Economy	28000.00
0005435373908	5285	Economy	28000.00
0005434826136	5285	Economy	28000.00
0005432394187	5285	Economy	28000.00
0005435373940	5285	Economy	28000.00
0005434826237	5285	Economy	28000.00
0005435374053	5285	Economy	28000.00
0005435374286	5285	Economy	28000.00
0005434826129	5285	Economy	28000.00
0005435373896	5285	Economy	28000.00
0005434826171	5285	Economy	28000.00
0005435299830	5285	Economy	28000.00
0005434826191	5285	Economy	28000.00
0005434826118	5285	Economy	28000.00
0005435374203	5285	Economy	28000.00
0005434826243	5285	Economy	28000.00
0005435374086	5285	Economy	28000.00
0005434826218	5285	Economy	28000.00
0005435373994	5285	Economy	28000.00
0005432121628	5285	Economy	28000.00
0005434826235	5285	Economy	28000.00
0005435386647	5285	Economy	28000.00
0005435374067	5285	Economy	28000.00
0005434826239	5285	Economy	28000.00
0005434826177	5285	Economy	28000.00
0005434826156	5285	Economy	28000.00
0005435373990	5285	Economy	28000.00
0005434826219	5285	Economy	28000.00
0005432121619	5285	Economy	28000.00
0005435374058	5285	Economy	28000.00
0005435374255	5285	Economy	28000.00
0005434826188	5285	Economy	28000.00
0005434826192	5285	Economy	28000.00
0005435179000	5285	Economy	28000.00
0005434826232	5285	Economy	28000.00
0005435299834	5285	Economy	28000.00
0005435150320	5285	Economy	28000.00
0005435304225	5285	Economy	28000.00
0005434826183	5285	Economy	28000.00
0005435179001	5285	Economy	28000.00
0005432121618	5285	Economy	28000.00
0005435374060	5285	Economy	28000.00
0005434826222	5285	Economy	28000.00
0005432396322	5285	Economy	28000.00
0005435373991	5285	Economy	28000.00
0005434826122	5285	Economy	28000.00
0005435373882	5285	Economy	28000.00
0005434826233	5285	Economy	28000.00
0005434826127	5285	Economy	28000.00
0005434826242	5285	Economy	28000.00
0005434558447	5285	Economy	28000.00
0005434558450	5285	Economy	28000.00
0005434826175	5285	Economy	28000.00
0005435373766	5285	Economy	28000.00
0005435179002	5285	Economy	28000.00
0005435373815	5285	Economy	28000.00
0005434826225	5285	Economy	28000.00
0005434826170	5285	Economy	28000.00
0005435386630	5285	Economy	28000.00
0005435150315	5285	Economy	28000.00
0005432121616	5285	Economy	28000.00
0005435373836	5285	Economy	28000.00
0005434826157	5285	Economy	28000.00
0005435373959	5285	Economy	28000.00
0005434826245	5285	Economy	28000.00
0005435374618	9892	Business	84000.00
0005434824401	9892	Business	84000.00
0005432400145	9892	Business	84000.00
0005435150174	9892	Business	84000.00
0005434824992	9892	Business	84000.00
0005435374595	9892	Business	84000.00
0005435374625	9892	Business	84000.00
0005435374579	9892	Business	84000.00
0005434824685	9892	Business	84000.00
0005434558341	9892	Business	84000.00
0005434825300	9892	Business	84000.00
0005434824916	9892	Business	84000.00
0005434825198	9892	Business	84000.00
0005434825244	9892	Business	84000.00
0005435374568	9892	Business	84000.00
0005434831205	9892	Business	84000.00
0005435314983	9892	Business	84000.00
0005434825243	9892	Business	84000.00
0005435374570	9892	Business	84000.00
0005435150173	9892	Business	84000.00
0005435374597	9892	Business	84000.00
0005435299872	9892	Business	84000.00
0005435735237	9892	Business	84000.00
0005435374575	9892	Business	84000.00
0005434824732	9892	Business	84000.00
0005434824335	9892	Business	84000.00
0005434831185	9892	Business	84000.00
0005434825301	9892	Comfort	47600.00
0005435374623	9892	Comfort	47600.00
0005434828726	9892	Comfort	47600.00
0005435374611	9892	Comfort	47600.00
0005434831207	9892	Comfort	47600.00
0005434825171	9892	Comfort	47600.00
0005435374598	9892	Comfort	47600.00
0005434825168	9892	Comfort	47600.00
0005435374627	9892	Comfort	47600.00
0005432823494	9892	Comfort	47600.00
0005434824855	9892	Comfort	47600.00
0005435150153	9892	Comfort	47600.00
0005434825326	9892	Comfort	47600.00
0005434825224	9892	Comfort	47600.00
0005435374571	9892	Comfort	47600.00
0005435386707	9892	Comfort	47600.00
0005434825338	9892	Comfort	47600.00
0005435314978	9892	Comfort	47600.00
0005435150186	9892	Comfort	47600.00
0005434825145	9892	Comfort	47600.00
0005434824511	9892	Comfort	47600.00
0005434558375	9892	Comfort	47600.00
0005435735233	9892	Comfort	47600.00
0005434825020	9892	Comfort	47600.00
0005434824777	9892	Comfort	47600.00
0005434824657	9892	Comfort	47600.00
0005434825109	9892	Comfort	47600.00
0005434824568	9892	Comfort	47600.00
0005435314984	9892	Comfort	47600.00
0005432203213	9892	Comfort	47600.00
0005435374572	9892	Comfort	47600.00
0005435374580	9892	Comfort	47600.00
0005435661990	9892	Comfort	47600.00
0005434825562	9892	Comfort	47600.00
0005435735232	9892	Economy	28000.00
0005435314976	9892	Economy	28000.00
0005434825146	9892	Economy	28000.00
0005435314982	9892	Economy	28000.00
0005435299874	9892	Economy	28000.00
0005435374600	9892	Economy	28000.00
0005434664989	9892	Economy	28000.00
0005435302296	9892	Economy	28000.00
0005435374607	9892	Economy	28000.00
0005432203211	9892	Economy	28000.00
0005435374614	9892	Economy	28000.00
0005434828723	9892	Economy	28000.00
0005435314992	9892	Economy	28000.00
0005435150204	9892	Economy	28000.00
0005434825290	9892	Economy	28000.00
0005432396291	9892	Economy	28000.00
0005434824698	9892	Economy	28000.00
0005434825558	9892	Economy	28000.00
0005434825325	9892	Economy	28000.00
0005434824958	9892	Economy	28000.00
0005434825242	9892	Economy	28000.00
0005435150227	9892	Economy	28000.00
0005435374566	9892	Economy	28000.00
0005434825206	9892	Economy	28000.00
0005435299871	9892	Economy	28000.00
0005434828737	9892	Economy	28000.00
0005435314988	9892	Economy	28000.00
0005434824993	9892	Economy	28000.00
0005434824837	9892	Economy	28000.00
0005434828738	9892	Economy	28000.00
0005435735236	9892	Economy	28000.00
0005434824656	9892	Economy	28000.00
0005434824842	9892	Economy	28000.00
0005434824991	9892	Economy	28000.00
0005435374621	9892	Economy	28000.00
0005435735234	9892	Economy	28000.00
0005434825665	9892	Economy	28000.00
0005434824690	9892	Economy	28000.00
0005435150184	9892	Economy	28000.00
0005435314979	9892	Economy	28000.00
0005435374582	9892	Economy	28000.00
0005434825120	9892	Economy	28000.00
0005434825164	9892	Economy	28000.00
0005435150175	9892	Economy	28000.00
0005432823493	9892	Economy	28000.00
0005435374617	9892	Economy	28000.00
0005434824924	9892	Economy	28000.00
0005434824655	9892	Economy	28000.00
0005435374592	9892	Economy	28000.00
0005435374616	9892	Economy	28000.00
0005435150154	9892	Economy	28000.00
0005434825039	9892	Economy	28000.00
0005435374628	9892	Economy	28000.00
0005434825352	9892	Economy	28000.00
0005434825291	9892	Economy	28000.00
0005434825461	9892	Economy	28000.00
0005435150188	9892	Economy	28000.00
0005435374603	9892	Economy	28000.00
0005435374563	9892	Economy	30800.00
0005434824684	9892	Economy	30800.00
0005432203214	9892	Economy	28000.00
0005435374599	9892	Economy	28000.00
0005434825498	9892	Economy	30800.00
0005435374626	9892	Economy	28000.00
0005435150187	9892	Economy	30800.00
0005434825265	9892	Economy	28000.00
0005434824731	9892	Economy	28000.00
0005435374604	9892	Economy	28000.00
0005434828728	9892	Economy	28000.00
0005434825299	9892	Economy	28000.00
0005434825260	9892	Economy	28000.00
0005434831184	9892	Economy	28000.00
0005434825557	9892	Economy	28000.00
0005432823492	9892	Economy	28000.00
0005434825412	9892	Economy	28000.00
0005435302295	9892	Economy	28000.00
0005435386709	9892	Economy	28000.00
0005434825023	9892	Economy	28000.00
0005434828734	9892	Economy	28000.00
0005435314990	9892	Economy	28000.00
0005435374609	9892	Economy	28000.00
0005434825045	9892	Economy	28000.00
0005434825296	9892	Economy	28000.00
0005435374608	9892	Economy	28000.00
0005435374601	9892	Economy	28000.00
0005434825561	9892	Economy	28000.00
0005435374629	9892	Economy	28000.00
0005435299873	9892	Economy	28000.00
0005435661991	9892	Economy	28000.00
0005435374567	9892	Economy	28000.00
0005435374612	9892	Economy	28000.00
0005434664976	9892	Economy	28000.00
0005434825316	9892	Economy	28000.00
0005434824543	9892	Economy	28000.00
0005432823491	9892	Economy	28000.00
0005435150201	9892	Economy	28000.00
0005435374581	9892	Economy	28000.00
0005434825089	9892	Economy	28000.00
0005435386711	9892	Economy	28000.00
0005434825511	9892	Economy	28000.00
0005435302294	9892	Economy	28000.00
0005434825185	9892	Economy	28000.00
0005432203209	9892	Economy	28000.00
0005434825704	9892	Economy	28000.00
0005435314975	9892	Economy	28000.00
0005434824963	9892	Economy	28000.00
0005434825452	9892	Economy	28000.00
0005435299875	9892	Economy	28000.00
0005435374610	9892	Economy	28000.00
0005434825556	9892	Economy	28000.00
0005435314987	9892	Economy	28000.00
0005434825362	9892	Economy	28000.00
0005435374574	9892	Economy	28000.00
0005434558365	9892	Economy	28000.00
0005434825070	9892	Economy	28000.00
0005434825151	9892	Economy	28000.00
0005435374624	9892	Economy	28000.00
0005434828735	9892	Economy	28000.00
0005434825437	9892	Economy	28000.00
0005434824704	9892	Economy	28000.00
0005435150189	9892	Economy	28000.00
0005435374606	9892	Economy	28000.00
0005434824359	9892	Economy	28000.00
0005434824957	9892	Economy	28000.00
0005435314977	9892	Economy	28000.00
0005434824738	9892	Economy	28000.00
0005435661993	9892	Economy	28000.00
0005435374593	9892	Economy	28000.00
0005435374588	9892	Economy	28000.00
0005434824699	9892	Economy	28000.00
0005434825666	9892	Economy	28000.00
0005434831198	9892	Economy	28000.00
0005435386708	9892	Economy	28000.00
0005432400143	9892	Economy	28000.00
0005435150181	9892	Economy	28000.00
0005434824933	9892	Economy	28000.00
0005434825118	9892	Economy	28000.00
0005434825346	9892	Economy	28000.00
0005435150182	9892	Economy	28000.00
0005434825308	9892	Economy	28000.00
0005435386705	9892	Economy	28000.00
0005434825264	9892	Economy	28000.00
0005435374591	9892	Economy	28000.00
0005434824623	9892	Economy	28000.00
0005434824871	9892	Economy	28000.00
0005435314980	9892	Economy	28000.00
0005434825119	9892	Economy	28000.00
0005435302297	9892	Economy	30800.00
0005434825457	9892	Economy	30800.00
0005435374576	9892	Economy	30800.00
0005434824737	9892	Economy	30800.00
0005432400144	9892	Economy	28000.00
0005435374613	9892	Economy	28000.00
0005434825295	9892	Economy	28000.00
0005435314981	9892	Economy	28000.00
0005432396287	9892	Economy	28000.00
0005435302293	9892	Economy	28000.00
0005435374586	9892	Economy	28000.00
0005435150129	9892	Economy	28000.00
0005434825524	9892	Economy	28000.00
0005434824923	9892	Economy	28000.00
0005434825307	9892	Economy	28000.00
0005435735235	9892	Economy	28000.00
0005435374577	9892	Economy	28000.00
0005434824827	9892	Economy	28000.00
0005435374569	9892	Economy	28000.00
0005435374583	9892	Economy	28000.00
0005435374619	9892	Economy	28000.00
0005435374573	9892	Economy	28000.00
0005435374594	9892	Economy	28000.00
0005434825319	9892	Economy	28000.00
0005435374589	9892	Economy	28000.00
0005432400162	9892	Economy	28000.00
0005435374615	9892	Economy	28000.00
0005435661992	9892	Economy	28000.00
0005432203208	9892	Economy	28000.00
0005432203210	9892	Economy	28000.00
0005435374585	9892	Economy	28000.00
0005434825203	9892	Economy	28000.00
0005432396290	9892	Economy	28000.00
0005435314989	9892	Economy	28000.00
0005434825019	9892	Economy	28000.00
0005435314991	9892	Economy	28000.00
0005434824978	9892	Economy	28000.00
0005434828725	9892	Economy	28000.00
0005435150235	9892	Economy	28000.00
0005434825069	9892	Economy	28000.00
0005435386706	9892	Economy	28000.00
0005434825416	9892	Economy	28000.00
0005432203215	9892	Economy	28000.00
0005435374596	9892	Economy	28000.00
0005432400169	9892	Economy	28000.00
0005435374564	9892	Economy	28000.00
0005434824960	9892	Economy	28000.00
0005435150202	9892	Economy	28000.00
0005435374620	9892	Economy	28000.00
0005435314985	9892	Economy	28000.00
0005434825422	9892	Economy	28000.00
0005434824666	9892	Economy	28000.00
0005434825071	9892	Economy	28000.00
0005434825390	9892	Economy	28000.00
0005434824743	9892	Economy	28000.00
0005432203212	9892	Economy	28000.00
0005432396292	9892	Economy	28000.00
0005435314986	9892	Economy	28000.00
0005434831204	9892	Economy	28000.00
0005435374602	9892	Economy	28000.00
0005435374565	9892	Economy	28000.00
0005435374584	9892	Economy	28000.00
0005432396278	9892	Economy	28000.00
0005435374578	9892	Economy	28000.00
0005435374605	9892	Economy	28000.00
0005435374590	9892	Economy	28000.00
0005434558376	9892	Economy	28000.00
0005434825172	9892	Economy	28000.00
0005435374622	9892	Economy	28000.00
0005435386710	9892	Economy	28000.00
0005434825123	9892	Economy	28000.00
0005434824560	9892	Economy	28000.00
0005435150172	9892	Economy	28000.00
0005435374587	9892	Economy	28000.00
0005435082955	7024	Economy	8200.00
0005435082954	7024	Economy	7400.00
0005435790366	7024	Economy	7400.00
0005435082952	7024	Economy	7400.00
0005435790367	7024	Economy	7400.00
0005435082953	7024	Economy	7400.00
0005435082956	7024	Economy	7400.00
0005435082957	7024	Economy	7400.00
0005435790339	26006	Economy	7400.00
0005435082851	26006	Economy	7400.00
0005435082880	26006	Economy	7400.00
0005435790340	26006	Economy	7400.00
0005435082877	26006	Economy	7400.00
0005435790348	26006	Economy	7400.00
0005435082852	26006	Economy	7400.00
0005435082881	26006	Economy	7400.00
0005435082885	26006	Economy	7400.00
0005435082884	26006	Economy	7400.00
0005435082883	26006	Economy	7400.00
0005435082924	26006	Economy	7400.00
0005434757282	9562	Business	32800.00
0005434757272	9562	Business	32800.00
0005434757257	9562	Business	32800.00
0005434757255	9562	Business	32800.00
0005434215117	9562	Business	32800.00
0005434215132	9562	Business	32800.00
0005434215039	9562	Business	32800.00
0005434215011	9562	Business	32800.00
0005434215133	9562	Business	32800.00
0005434757270	9562	Business	32800.00
0005434757275	9562	Business	32800.00
0005434757253	9562	Business	32800.00
0005434757279	9562	Economy	10900.00
0005434757277	9562	Economy	10900.00
0005434215198	9562	Economy	10900.00
0005434757288	9562	Economy	10900.00
0005434215163	9562	Economy	10900.00
0005434214853	9562	Economy	10900.00
0005434214924	9562	Economy	10900.00
0005434757265	9562	Economy	10900.00
0005434214985	9562	Economy	10900.00
0005434757274	9562	Economy	12000.00
0005434757258	9562	Economy	12000.00
0005434215134	9562	Economy	12000.00
0005434215130	9562	Economy	12000.00
0005434215119	9562	Economy	12000.00
0005434757271	9562	Economy	10900.00
0005434757276	9562	Economy	10900.00
0005434757268	9562	Economy	10900.00
0005434215064	9562	Economy	10900.00
0005434757290	9562	Economy	10900.00
0005434757249	9562	Economy	10900.00
0005434215208	9562	Economy	10900.00
0005434214999	9562	Economy	10900.00
0005434757259	9562	Economy	10900.00
0005434215101	9562	Economy	10900.00
0005434757284	9562	Economy	10900.00
0005434757264	9562	Economy	10900.00
0005434757269	9562	Economy	10900.00
0005434757266	9562	Economy	10900.00
0005434215040	9562	Economy	10900.00
0005434215159	9562	Economy	10900.00
0005434757251	9562	Economy	10900.00
0005434757260	9562	Economy	10900.00
0005434757262	9562	Economy	10900.00
0005434214828	9562	Economy	10900.00
0005434215129	9562	Economy	10900.00
0005434757283	9562	Economy	10900.00
0005434214944	9562	Economy	10900.00
0005434215008	9562	Economy	10900.00
0005434757278	9562	Economy	10900.00
0005434215158	9562	Economy	10900.00
0005434757254	9562	Economy	10900.00
0005434215026	9562	Economy	10900.00
0005434757261	9562	Economy	10900.00
0005434757256	9562	Economy	10900.00
0005434215214	9562	Economy	10900.00
0005434757247	9562	Economy	10900.00
0005434214897	9562	Economy	10900.00
0005434757280	9562	Economy	10900.00
0005434757287	9562	Economy	10900.00
0005434757285	9562	Economy	10900.00
0005434757248	9562	Economy	10900.00
0005434214909	9562	Economy	10900.00
0005434757250	9562	Economy	10900.00
0005434215296	9562	Economy	10900.00
0005434214917	9562	Economy	10900.00
0005434214993	9562	Economy	10900.00
0005434214916	9562	Economy	10900.00
0005434215028	9562	Economy	10900.00
0005434214830	9562	Economy	10900.00
0005434214867	9562	Economy	10900.00
0005434215294	9562	Economy	10900.00
0005434215116	9562	Economy	10900.00
0005434214940	9562	Economy	10900.00
0005434757273	9562	Economy	10900.00
0005434215103	9562	Economy	10900.00
0005434215295	9562	Economy	10900.00
0005434214938	9562	Economy	10900.00
0005434757289	9562	Economy	10900.00
0005434214862	9562	Economy	10900.00
0005434757281	9562	Economy	10900.00
0005434214984	9562	Economy	10900.00
0005434215102	9562	Economy	10900.00
0005434215105	9562	Economy	10900.00
0005434757286	9562	Economy	10900.00
0005434757267	9562	Economy	10900.00
0005434757252	9562	Economy	10900.00
0005434215030	9562	Economy	10900.00
0005434757263	9562	Economy	10900.00
0005434215164	9562	Economy	10900.00
0005434215023	9562	Economy	10900.00
0005434215453	28643	Business	32800.00
0005434215421	28643	Business	32800.00
0005434215449	28643	Business	32800.00
0005434215413	28643	Business	32800.00
0005434756897	28643	Business	32800.00
0005434756901	28643	Business	32800.00
0005434215430	28643	Business	32800.00
0005434215456	28643	Business	32800.00
0005434756713	28643	Business	32800.00
0005434215428	28643	Business	32800.00
0005434215445	28643	Business	32800.00
0005434215439	28643	Business	32800.00
0005434215420	28643	Economy	10900.00
0005434215425	28643	Economy	10900.00
0005434756787	28643	Economy	10900.00
0005434756834	28643	Economy	10900.00
0005434756878	28643	Economy	10900.00
0005434215442	28643	Economy	10900.00
0005434215431	28643	Economy	10900.00
0005434215457	28643	Economy	10900.00
0005434215436	28643	Economy	12000.00
0005434215450	28643	Economy	12000.00
0005434756909	28643	Economy	12000.00
0005434756859	28643	Economy	12000.00
0005434756838	28643	Economy	12000.00
0005434756670	28643	Economy	10900.00
0005434756856	28643	Economy	10900.00
0005434756700	28643	Economy	10900.00
0005434756862	28643	Economy	10900.00
0005434756855	28643	Economy	10900.00
0005434215454	28643	Economy	10900.00
0005434756742	28643	Economy	10900.00
0005434215447	28643	Economy	10900.00
0005434215429	28643	Economy	10900.00
0005434215424	28643	Economy	10900.00
0005434756937	28643	Economy	10900.00
0005434756837	28643	Economy	10900.00
0005434215452	28643	Economy	10900.00
0005434756750	28643	Economy	10900.00
0005434215433	28643	Economy	10900.00
0005434756835	28643	Economy	10900.00
0005434756861	28643	Economy	10900.00
0005434215416	28643	Economy	10900.00
0005434215411	28643	Economy	10900.00
0005434215419	28643	Economy	10900.00
0005434215426	28643	Economy	10900.00
0005434215441	28643	Economy	10900.00
0005434756725	28643	Economy	10900.00
0005434756902	28643	Economy	10900.00
0005434756799	28643	Economy	10900.00
0005434756663	28643	Economy	10900.00
0005434215422	28643	Economy	10900.00
0005434215437	28643	Economy	10900.00
0005434756858	28643	Economy	10900.00
0005434215423	28643	Economy	10900.00
0005434756908	28643	Economy	10900.00
0005434756724	28643	Economy	10900.00
0005434756824	28643	Economy	10900.00
0005434215458	28643	Economy	10900.00
0005434756810	28643	Economy	10900.00
0005434215432	28643	Economy	10900.00
0005434215434	28643	Economy	10900.00
0005434215444	28643	Economy	10900.00
0005434215435	28643	Economy	10900.00
0005434756839	28643	Economy	10900.00
0005434756697	28643	Economy	10900.00
0005434756790	28643	Economy	10900.00
0005434756860	28643	Economy	10900.00
0005434215417	28643	Economy	10900.00
0005434756889	28643	Economy	10900.00
0005434756745	28643	Economy	10900.00
0005434756903	28643	Economy	10900.00
0005434756896	28643	Economy	10900.00
0005434756751	28643	Economy	10900.00
0005434756867	28643	Economy	10900.00
0005434215451	28643	Economy	10900.00
0005434215446	28643	Economy	10900.00
0005434215418	28643	Economy	10900.00
0005434756748	28643	Economy	10900.00
0005434215448	28643	Economy	10900.00
0005434215440	28643	Economy	10900.00
0005434215443	28643	Economy	10900.00
0005434756879	28643	Economy	10900.00
0005434756833	28643	Economy	10900.00
0005434215438	28643	Economy	10900.00
0005434215415	28643	Economy	10900.00
0005434215455	28643	Economy	10900.00
0005434215427	28643	Economy	10900.00
0005434215412	28643	Economy	10900.00
0005434215414	28643	Economy	10900.00
0005434760220	10849	Economy	8900.00
0005434760229	10849	Economy	8900.00
0005435100183	10849	Economy	8900.00
0005435100184	10849	Economy	8900.00
0005434760233	10849	Economy	8900.00
0005435100185	10849	Economy	8900.00
0005434760248	31833	Economy	9800.00
0005434760246	31833	Economy	8900.00
0005434760247	31833	Economy	8900.00
0005435100153	31833	Economy	8900.00
0005435100166	31833	Economy	8900.00
0005434639852	1983	Economy	20900.00
0005433202547	1983	Economy	20900.00
0005433202535	1983	Economy	20900.00
0005434639862	1983	Economy	20900.00
0005433202505	1983	Economy	19000.00
0005434639867	1983	Economy	19000.00
0005433202540	1983	Economy	19000.00
0005434639865	1983	Economy	19000.00
0005433202568	1983	Economy	19000.00
0005434639845	1983	Economy	19000.00
0005434639846	1983	Economy	19000.00
0005434639844	1983	Economy	19000.00
0005434639866	1983	Economy	19000.00
0005432290698	1983	Economy	19000.00
0005433202520	1983	Economy	19000.00
0005434639850	1983	Economy	19000.00
0005434639860	1983	Economy	19000.00
0005433202513	1983	Economy	19000.00
0005433202551	1983	Economy	19000.00
0005433202549	1983	Economy	19000.00
0005433202487	1983	Economy	19000.00
0005434639853	1983	Economy	19000.00
0005434639858	1983	Economy	19000.00
0005433202504	1983	Economy	19000.00
0005433202483	1983	Economy	19000.00
0005433202500	1983	Economy	19000.00
0005433202550	1983	Economy	19000.00
0005434639847	1983	Economy	19000.00
0005433202569	1983	Economy	19000.00
0005433202482	1983	Economy	19000.00
0005434639859	1983	Economy	19000.00
0005434639864	1983	Economy	19000.00
0005432290699	1983	Economy	19000.00
0005434639848	1983	Economy	19000.00
0005434639843	1983	Economy	19000.00
0005433202481	1983	Economy	19000.00
0005434639863	1983	Economy	19000.00
0005434639855	1983	Economy	19000.00
0005434639856	1983	Economy	19000.00
0005433202596	1983	Economy	19000.00
0005434639849	1983	Economy	19000.00
0005434639857	1983	Economy	19000.00
0005434639854	1983	Economy	19000.00
0005434639851	1983	Economy	19000.00
0005433202546	1983	Economy	19000.00
0005433202536	1983	Economy	19000.00
0005434639861	1983	Economy	19000.00
0005434639868	1983	Economy	19000.00
0005432290697	1983	Economy	19000.00
0005434639569	23250	Economy	20900.00
0005434639586	23250	Economy	20900.00
0005433202651	23250	Economy	20900.00
0005433202649	23250	Economy	19000.00
0005433202654	23250	Economy	19000.00
0005433202652	23250	Economy	19000.00
0005434639566	23250	Economy	19000.00
0005433202650	23250	Economy	19000.00
0005434639584	23250	Economy	19000.00
0005434639606	23250	Economy	19000.00
0005434639675	23250	Economy	19000.00
0005433202646	23250	Economy	19000.00
0005434639681	23250	Economy	19000.00
0005434639657	23250	Economy	19000.00
0005433202645	23250	Economy	19000.00
0005434639694	23250	Economy	19000.00
0005434639558	23250	Economy	19000.00
0005434639620	23250	Economy	19000.00
0005434639572	23250	Economy	19000.00
0005434639616	23250	Economy	19000.00
0005434639658	23250	Economy	19000.00
0005434639579	23250	Economy	19000.00
0005433202657	23250	Economy	19000.00
0005434639517	23250	Economy	19000.00
0005434639590	23250	Economy	19000.00
0005433202659	23250	Economy	19000.00
0005433202658	23250	Economy	19000.00
0005434639683	23250	Economy	19000.00
0005434639565	23250	Economy	19000.00
0005433202647	23250	Economy	19000.00
0005433202648	23250	Economy	19000.00
0005434639656	23250	Economy	19000.00
0005434639589	23250	Economy	19000.00
0005434639578	23250	Economy	19000.00
0005433202655	23250	Economy	19000.00
0005433202653	23250	Economy	19000.00
0005433202656	23250	Economy	19000.00
0005435326963	6054	Business	69700.00
0005434601352	6054	Business	69700.00
0005434601364	6054	Business	69700.00
0005434601355	6054	Business	69700.00
0005434601367	6054	Business	69700.00
0005434601359	6054	Business	69700.00
0005435326962	6054	Business	69700.00
0005433533386	6054	Business	69700.00
0005434601362	6054	Economy	23200.00
0005433531371	6054	Economy	23200.00
0005434601370	6054	Economy	23200.00
0005434601368	6054	Economy	23200.00
0005435326826	6054	Economy	23200.00
0005434601354	6054	Economy	23200.00
0005434601371	6054	Economy	23200.00
0005434601351	6054	Economy	23200.00
0005433531370	6054	Economy	23200.00
0005434601365	6054	Economy	23200.00
0005434601369	6054	Economy	23200.00
0005432111340	6054	Economy	23200.00
0005434601353	6054	Economy	23200.00
0005434601350	6054	Economy	23200.00
0005433533384	6054	Economy	23200.00
0005432111339	6054	Economy	23200.00
0005433531369	6054	Economy	23200.00
0005435326866	6054	Economy	23200.00
0005434601360	6054	Economy	23200.00
0005434601349	6054	Economy	23200.00
0005432111341	6054	Economy	23200.00
0005433533387	6054	Economy	23200.00
0005435326957	6054	Economy	23200.00
0005434601358	6054	Economy	23200.00
0005434601374	6054	Economy	23200.00
0005434601356	6054	Economy	23200.00
0005433533385	6054	Economy	23200.00
0005435326913	6054	Economy	23200.00
0005434601363	6054	Economy	23200.00
0005434601366	6054	Economy	23200.00
0005434601372	6054	Economy	23200.00
0005434601361	6054	Economy	23200.00
0005435326891	6054	Economy	23200.00
0005434601373	6054	Economy	23200.00
0005433531372	6054	Economy	23200.00
0005434601348	6054	Economy	23200.00
0005434601357	6054	Economy	23200.00
0005434601138	18602	Business	69700.00
0005435327034	18602	Business	69700.00
0005434601161	18602	Business	69700.00
0005434601106	18602	Business	69700.00
0005433531339	18602	Business	69700.00
0005433527295	18602	Business	69700.00
0005433527294	18602	Economy	23200.00
0005435327025	18602	Economy	23200.00
0005434601159	18602	Economy	25600.00
0005434601238	18602	Economy	25600.00
0005434601044	18602	Economy	25600.00
0005434601139	18602	Economy	25600.00
0005433531335	18602	Economy	23200.00
0005435327026	18602	Economy	23200.00
0005434601071	18602	Economy	23200.00
0005434601229	18602	Economy	23200.00
0005433527306	18602	Economy	23200.00
0005433527297	18602	Economy	23200.00
0005434601074	18602	Economy	23200.00
0005435327023	18602	Economy	23200.00
0005435327029	18602	Economy	23200.00
0005434601178	18602	Economy	23200.00
0005434601190	18602	Economy	23200.00
0005435327027	18602	Economy	23200.00
0005435327028	18602	Economy	23200.00
0005434601137	18602	Economy	23200.00
0005435327035	18602	Economy	23200.00
0005434601107	18602	Economy	23200.00
0005435327022	18602	Economy	23200.00
0005434601075	18602	Economy	23200.00
0005435327031	18602	Economy	23200.00
0005434601207	18602	Economy	23200.00
0005434601148	18602	Economy	23200.00
0005434601128	18602	Economy	23200.00
0005433527296	18602	Economy	23200.00
0005434601094	18602	Economy	23200.00
0005434601101	18602	Economy	23200.00
0005434601136	18602	Economy	23200.00
0005434601206	18602	Economy	23200.00
0005434601112	18602	Economy	23200.00
0005435327030	18602	Economy	23200.00
0005435327032	18602	Economy	23200.00
0005434601237	18602	Economy	23200.00
0005435327024	18602	Economy	23200.00
0005434601072	18602	Economy	23200.00
0005434601103	18602	Economy	23200.00
0005434601129	18602	Economy	23200.00
0005435327033	18602	Economy	23200.00
0005434601115	18602	Economy	23200.00
0005434601168	18602	Economy	23200.00
0005434601177	18602	Economy	23200.00
0005433531340	18602	Economy	23200.00
0005434601073	18602	Economy	23200.00
0005434601076	18602	Economy	23200.00
0005433531333	18602	Economy	23200.00
0005434601105	18602	Economy	23200.00
0005433531334	18602	Economy	23200.00
0005434601189	18602	Economy	23200.00
0005434601127	18602	Economy	23200.00
0005434558446	10644	Business	9100.00
0005434552292	10644	Business	9100.00
0005434552282	10644	Business	9100.00
0005434552296	10644	Business	9100.00
0005434552322	10644	Business	9100.00
0005434552315	10644	Business	9100.00
0005434552326	10644	Business	9100.00
0005433181505	10644	Business	9100.00
0005434552291	10644	Business	9100.00
0005434552307	10644	Business	9100.00
0005434552313	10644	Business	9100.00
0005433181441	10644	Business	9100.00
0005434552294	10644	Economy	3000.00
0005434552288	10644	Economy	3000.00
0005434552310	10644	Economy	3000.00
0005434558440	10644	Economy	3000.00
0005434552277	10644	Economy	3000.00
0005434552317	10644	Economy	3000.00
0005433181326	10644	Economy	3000.00
0005433181408	10644	Economy	3000.00
0005433181202	10644	Economy	3000.00
0005434552309	10644	Economy	3000.00
0005434552284	10644	Economy	3300.00
0005434552325	10644	Economy	3300.00
0005434552283	10644	Economy	3300.00
0005433181304	10644	Economy	3300.00
0005434552324	10644	Economy	3300.00
0005433181386	10644	Economy	3000.00
0005433181430	10644	Economy	3000.00
0005433181429	10644	Economy	3000.00
0005434558435	10644	Economy	3000.00
0005434552293	10644	Economy	3000.00
0005434552301	10644	Economy	3000.00
0005433181351	10644	Economy	3000.00
0005434552304	10644	Economy	3000.00
0005434552275	10644	Economy	3000.00
0005434552321	10644	Economy	3000.00
0005434552314	10644	Economy	3000.00
0005434558438	10644	Economy	3000.00
0005434552280	10644	Economy	3000.00
0005433181373	10644	Economy	3000.00
0005434552276	10644	Economy	3000.00
0005434552302	10644	Economy	3000.00
0005434558441	10644	Economy	3000.00
0005434552274	10644	Economy	3000.00
0005434552306	10644	Economy	3000.00
0005434558439	10644	Economy	3000.00
0005433181360	10644	Economy	3000.00
0005434552289	10644	Economy	3000.00
0005434552305	10644	Economy	3000.00
0005434552323	10644	Economy	3000.00
0005433181391	10644	Economy	3000.00
0005434554105	10644	Economy	3000.00
0005433181403	10644	Economy	3000.00
0005434552281	10644	Economy	3000.00
0005434552279	10644	Economy	3000.00
0005434558445	10644	Economy	3000.00
0005434552303	10644	Economy	3000.00
0005433181305	10644	Economy	3000.00
0005433181390	10644	Economy	3000.00
0005434552285	10644	Economy	3000.00
0005434552290	10644	Economy	3000.00
0005433181359	10644	Economy	3000.00
0005434552297	10644	Economy	3000.00
0005433181325	10644	Economy	3000.00
0005434552298	10644	Economy	3000.00
0005434552329	10644	Economy	3000.00
0005434552300	10644	Economy	3000.00
0005434552295	10644	Economy	3000.00
0005434552278	10644	Economy	3000.00
0005434552316	10644	Economy	3000.00
0005434552311	10644	Economy	3000.00
0005434558442	10644	Economy	3000.00
0005434558434	10644	Economy	3000.00
0005434558436	10644	Economy	3000.00
0005434552312	10644	Economy	3000.00
0005433181385	10644	Economy	3000.00
0005434558444	10644	Economy	3000.00
0005434552327	10644	Economy	3000.00
0005434558443	10644	Economy	3000.00
0005434552318	10644	Economy	3000.00
0005434552287	10644	Economy	3000.00
0005434552319	10644	Economy	3000.00
0005434558437	10644	Economy	3000.00
0005434552308	10644	Economy	3000.00
0005434552328	10644	Economy	3000.00
0005434552299	10644	Economy	3000.00
0005434552320	10644	Economy	3000.00
0005433181431	10644	Economy	3000.00
0005434552286	10644	Economy	3000.00
0005433181350	10644	Economy	3000.00
0005434554106	10644	Economy	3000.00
0005433181618	27744	Business	9100.00
0005433181626	27744	Business	9100.00
0005433181609	27744	Business	9100.00
0005435314975	27744	Business	9100.00
0005435314977	27744	Business	9100.00
0005435314986	27744	Business	9100.00
0005435314989	27744	Economy	3000.00
0005435314981	27744	Economy	3000.00
0005435314991	27744	Economy	3000.00
0005435314976	27744	Economy	3000.00
0005433181607	27744	Economy	3000.00
0005433181627	27744	Economy	3300.00
0005433181612	27744	Economy	3000.00
0005433181608	27744	Economy	3000.00
0005435314978	27744	Economy	3000.00
0005433181624	27744	Economy	3000.00
0005435314984	27744	Economy	3000.00
0005435314992	27744	Economy	3000.00
0005435314990	27744	Economy	3000.00
0005435314979	27744	Economy	3000.00
0005433181625	27744	Economy	3000.00
0005433181628	27744	Economy	3000.00
0005433181606	27744	Economy	3000.00
0005433181611	27744	Economy	3000.00
0005435314985	27744	Economy	3000.00
0005435314980	27744	Economy	3000.00
0005433181613	27744	Economy	3000.00
0005435314988	27744	Economy	3000.00
0005435314987	27744	Economy	3000.00
0005433181614	27744	Economy	3000.00
0005433181623	27744	Economy	3000.00
0005433181615	27744	Economy	3000.00
0005433181619	27744	Economy	3000.00
0005433181629	27744	Economy	3000.00
0005433181617	27744	Economy	3000.00
0005435314983	27744	Economy	3000.00
0005433181630	27744	Economy	3000.00
0005435314982	27744	Economy	3000.00
0005433181621	27744	Economy	3000.00
0005433181622	27744	Economy	3000.00
0005433181616	27744	Economy	3000.00
0005433181610	27744	Economy	3000.00
0005433181620	27744	Economy	3000.00
0005434551819	27745	Business	9100.00
0005434551945	27745	Business	9100.00
0005434551723	27745	Business	9100.00
0005434551806	27745	Business	9100.00
0005434551718	27745	Business	9100.00
0005434551818	27745	Business	9100.00
0005434551879	27745	Business	9100.00
0005434552007	27745	Business	9100.00
0005434558359	27745	Business	9100.00
0005434551829	27745	Business	9100.00
0005434551712	27745	Economy	3000.00
0005434551963	27745	Economy	3000.00
0005434552075	27745	Economy	3000.00
0005434551472	27745	Economy	3000.00
0005434551830	27745	Economy	3000.00
0005434551807	27745	Economy	3000.00
0005434551724	27745	Economy	3000.00
0005434552008	27745	Economy	3000.00
0005434551917	27745	Economy	3300.00
0005434551841	27745	Economy	3300.00
0005434551820	27745	Economy	3300.00
0005434551864	27745	Economy	3300.00
0005434551858	27745	Economy	3300.00
0005434551926	27745	Economy	3000.00
0005434551716	27745	Economy	3000.00
0005434552030	27745	Economy	3000.00
0005434551632	27745	Economy	3000.00
0005434551633	27745	Economy	3000.00
0005434551918	27745	Economy	3000.00
0005434551968	27745	Economy	3000.00
0005434551815	27745	Economy	3000.00
0005434551749	27745	Economy	3000.00
0005434551471	27745	Economy	3000.00
0005434558368	27745	Economy	3000.00
0005434551774	27745	Economy	3000.00
0005434551711	27745	Economy	3000.00
0005434558334	27745	Economy	3000.00
0005434552072	27745	Economy	3000.00
0005434551609	27745	Economy	3000.00
0005434551754	27745	Economy	3000.00
0005434552217	27745	Economy	3000.00
0005434552216	27745	Economy	3000.00
0005434551731	27745	Economy	3000.00
0005434551710	27745	Economy	3000.00
0005434551875	27745	Economy	3000.00
0005434551842	27745	Economy	3000.00
0005434552042	27745	Economy	3000.00
0005434558361	27745	Economy	3000.00
0005434551672	27745	Economy	3000.00
0005434551857	27745	Economy	3000.00
0005434551960	27745	Economy	3000.00
0005434551865	27745	Economy	3000.00
0005434551808	27745	Economy	3000.00
0005434551946	27745	Economy	3000.00
0005434551903	27745	Economy	3000.00
0005434551796	27745	Economy	3000.00
0005434551634	27745	Economy	3000.00
0005434551923	27745	Economy	3000.00
0005434551840	27745	Economy	3000.00
0005434551735	27745	Economy	3000.00
0005434552001	27745	Economy	3000.00
0005434551828	27745	Economy	3000.00
0005434551768	27745	Economy	3000.00
0005434551717	27745	Economy	3000.00
0005434551876	27745	Economy	3000.00
0005434552090	27745	Economy	3000.00
0005434552113	27745	Economy	3000.00
0005434552151	27745	Economy	3000.00
0005434551959	27745	Economy	3000.00
0005434551682	27745	Economy	3000.00
0005434552218	27745	Economy	3000.00
0005434551627	27745	Economy	3000.00
0005434558360	27745	Economy	3000.00
0005434551877	27745	Economy	3000.00
0005434551962	27745	Economy	3000.00
0005434551714	27745	Economy	3000.00
0005434551991	27745	Economy	3000.00
0005434551708	27745	Economy	3000.00
0005434551608	27745	Economy	3000.00
0005434551859	27745	Economy	3000.00
0005434551969	27745	Economy	3000.00
0005434551683	27745	Economy	3000.00
0005434551860	27745	Economy	3000.00
0005434554085	27745	Economy	3000.00
0005434551878	27745	Economy	3000.00
0005434551732	27745	Economy	3000.00
0005433459304	6140	Economy	11700.00
0005435254516	6140	Economy	11700.00
0005433459309	6140	Economy	11700.00
0005433459310	6140	Economy	11700.00
0005435254517	6140	Economy	11700.00
0005433459308	6140	Economy	11700.00
0005433459307	6140	Economy	11700.00
0005433459305	6140	Economy	11700.00
0005433459306	6140	Economy	11700.00
0005435254493	6140	Economy	11700.00
0005433459279	19313	Economy	11700.00
0005433459251	19313	Economy	11700.00
0005435254521	19313	Economy	11700.00
0005435254522	19313	Economy	11700.00
0005433459280	19313	Economy	11700.00
0005435682952	6716	Business	51100.00
0005434828713	6716	Business	51100.00
0005435682940	6716	Business	51100.00
0005435682961	6716	Business	51100.00
0005435438328	6716	Business	51100.00
0005435682937	6716	Business	51100.00
0005435720155	6716	Business	51100.00
0005435719585	6716	Business	51100.00
0005435682966	6716	Business	51100.00
0005435217741	6716	Business	51100.00
0005435682967	6716	Business	51100.00
0005435438281	6716	Economy	17000.00
0005435631026	6716	Economy	17000.00
0005435682953	6716	Economy	17000.00
0005435661987	6716	Economy	17000.00
0005435682968	6716	Economy	17000.00
0005435682939	6716	Economy	17000.00
0005435682964	6716	Economy	17000.00
0005435682970	6716	Economy	17000.00
0005435682947	6716	Economy	17000.00
0005435438327	6716	Economy	17000.00
0005432136270	6716	Economy	18700.00
0005435720154	6716	Economy	18700.00
0005435438257	6716	Economy	18700.00
0005435438219	6716	Economy	18700.00
0005435682974	6716	Economy	18700.00
0005435661989	6716	Economy	17000.00
0005435217737	6716	Economy	17000.00
0005435438255	6716	Economy	17000.00
0005435438116	6716	Economy	17000.00
0005435682971	6716	Economy	17000.00
0005435682945	6716	Economy	17000.00
0005435438240	6716	Economy	17000.00
0005435682936	6716	Economy	17000.00
0005435438139	6716	Economy	17000.00
0005435438117	6716	Economy	17000.00
0005435682941	6716	Economy	17000.00
0005432136272	6716	Economy	17000.00
0005435217726	6716	Economy	17000.00
0005435682960	6716	Economy	17000.00
0005435682946	6716	Economy	17000.00
0005435438261	6716	Economy	17000.00
0005435438292	6716	Economy	17000.00
0005435220344	6716	Economy	17000.00
0005435631027	6716	Economy	17000.00
0005435438326	6716	Economy	17000.00
0005435682977	6716	Economy	17000.00
0005432136271	6716	Economy	17000.00
0005435682950	6716	Economy	17000.00
0005435682957	6716	Economy	17000.00
0005432136268	6716	Economy	17000.00
0005435682975	6716	Economy	17000.00
0005435682942	6716	Economy	17000.00
0005435682944	6716	Economy	17000.00
0005435682965	6716	Economy	17000.00
0005435438175	6716	Economy	17000.00
0005435661988	6716	Economy	17000.00
0005435682976	6716	Economy	17000.00
0005435682972	6716	Economy	17000.00
0005435682979	6716	Economy	17000.00
0005435438239	6716	Economy	17000.00
0005435438224	6716	Economy	17000.00
0005435438287	6716	Economy	17000.00
0005435438158	6716	Economy	17000.00
0005435682959	6716	Economy	17000.00
0005435438256	6716	Economy	17000.00
0005435682956	6716	Economy	17000.00
0005435682958	6716	Economy	17000.00
0005435682980	6716	Economy	17000.00
0005435682962	6716	Economy	17000.00
0005435682951	6716	Economy	17000.00
0005435682954	6716	Economy	17000.00
0005435631028	6716	Economy	17000.00
0005435719586	6716	Economy	17000.00
0005435682973	6716	Economy	17000.00
0005435438272	6716	Economy	17000.00
0005435438295	6716	Economy	17000.00
0005435682978	6716	Economy	17000.00
0005435682963	6716	Economy	17000.00
0005432533314	6716	Economy	17000.00
0005432136269	6716	Economy	17000.00
0005435682938	6716	Economy	17000.00
0005432533315	6716	Economy	17000.00
0005435682949	6716	Economy	17000.00
0005435438273	6716	Economy	17000.00
0005435438181	6716	Economy	17000.00
0005432136273	6716	Economy	17000.00
0005435682981	6716	Economy	17000.00
0005435438293	6716	Economy	17000.00
0005435682969	6716	Economy	17000.00
0005435682943	6716	Economy	17000.00
0005435438245	6716	Economy	17000.00
0005435220335	6716	Economy	17000.00
0005435682955	6716	Economy	17000.00
0005435682948	6716	Economy	17000.00
0005435682577	24613	Business	51100.00
0005435438406	24613	Business	51100.00
0005435438408	24613	Business	51100.00
0005432533350	24613	Business	51100.00
0005435682578	24613	Business	51100.00
0005435682798	24613	Business	51100.00
0005435438396	24613	Business	51100.00
0005435682654	24613	Business	51100.00
0005435682503	24613	Business	51100.00
0005435682548	24613	Business	51100.00
0005434828755	24613	Business	51100.00
0005435438414	24613	Economy	17000.00
0005435438407	24613	Economy	17000.00
0005435682573	24613	Economy	17000.00
0005435682496	24613	Economy	17000.00
0005435682664	24613	Economy	17000.00
0005435682504	24613	Economy	17000.00
0005435682630	24613	Economy	17000.00
0005435438404	24613	Economy	17000.00
0005435682715	24613	Economy	17000.00
0005435682738	24613	Economy	18700.00
0005435631003	24613	Economy	18700.00
0005435438412	24613	Economy	18700.00
0005435438399	24613	Economy	18700.00
0005435438410	24613	Economy	17000.00
0005435682667	24613	Economy	17000.00
0005435682838	24613	Economy	17000.00
0005435438416	24613	Economy	17000.00
0005435438409	24613	Economy	17000.00
0005435682706	24613	Economy	17000.00
0005435661949	24613	Economy	17000.00
0005435682789	24613	Economy	17000.00
0005435682627	24613	Economy	17000.00
0005435438397	24613	Economy	17000.00
0005435682799	24613	Economy	17000.00
0005435682524	24613	Economy	17000.00
0005435682662	24613	Economy	17000.00
0005432305798	24613	Economy	17000.00
0005435682704	24613	Economy	17000.00
0005435682739	24613	Economy	17000.00
0005435682633	24613	Economy	17000.00
0005435682837	24613	Economy	17000.00
0005435682693	24613	Economy	17000.00
0005435682574	24613	Economy	17000.00
0005435682623	24613	Economy	17000.00
0005435682467	24613	Economy	17000.00
0005435682491	24613	Economy	17000.00
0005435682495	24613	Economy	17000.00
0005432305800	24613	Economy	17000.00
0005435438405	24613	Economy	17000.00
0005435682417	24613	Economy	17000.00
0005435661971	24613	Economy	17000.00
0005435438395	24613	Economy	17000.00
0005435682745	24613	Economy	17000.00
0005435438403	24613	Economy	17000.00
0005435682733	24613	Economy	17000.00
0005435682593	24613	Economy	17000.00
0005435682602	24613	Economy	17000.00
0005435438400	24613	Economy	17000.00
0005435682497	24613	Economy	17000.00
0005432305799	24613	Economy	17000.00
0005435630995	24613	Economy	17000.00
0005432533349	24613	Economy	17000.00
0005435631002	24613	Economy	17000.00
0005435682565	24613	Economy	17000.00
0005435682665	24613	Economy	17000.00
0005435438401	24613	Economy	17000.00
0005435682498	24613	Economy	17000.00
0005435438398	24613	Economy	17000.00
0005435682695	24613	Economy	17000.00
0005435438402	24613	Economy	17000.00
0005435630985	24613	Economy	17000.00
0005435682534	24613	Economy	17000.00
0005435682579	24613	Economy	17000.00
0005435438411	24613	Economy	17000.00
0005435438413	24613	Economy	17000.00
0005435438394	24613	Economy	17000.00
0005435630991	24613	Economy	17000.00
0005435682626	24613	Economy	17000.00
0005432533351	24613	Economy	17000.00
0005435682631	24613	Economy	17000.00
0005435682532	24613	Economy	17000.00
0005435682705	24613	Economy	17000.00
0005435438415	24613	Economy	17000.00
0005435682523	24613	Economy	17000.00
0005435682416	24613	Economy	17000.00
0005435630992	24613	Economy	17000.00
0005435127184	11550	Business	26400.00
0005435127159	11550	Business	26400.00
0005435127185	11550	Business	26400.00
0005435127154	11550	Business	26400.00
0005435127172	11550	Business	26400.00
0005435127183	11550	Economy	8800.00
0005435127173	11550	Economy	8800.00
0005435127153	11550	Economy	8800.00
0005435127182	11550	Economy	8800.00
0005435127178	11550	Economy	8800.00
0005435127158	11550	Economy	8800.00
0005435127189	11550	Economy	9700.00
0005435127162	11550	Economy	9700.00
0005435127160	11550	Economy	9700.00
0005435127171	11550	Economy	9700.00
0005435127186	11550	Economy	8800.00
0005435127170	11550	Economy	8800.00
0005435127174	11550	Economy	8800.00
0005435127166	11550	Economy	8800.00
0005435127180	11550	Economy	8800.00
0005435127169	11550	Economy	8800.00
0005435127149	11550	Economy	8800.00
0005435127165	11550	Economy	8800.00
0005435558118	11550	Economy	8800.00
0005435127181	11550	Economy	8800.00
0005435127148	11550	Economy	8800.00
0005435127187	11550	Economy	8800.00
0005435127176	11550	Economy	8800.00
0005435127164	11550	Economy	8800.00
0005435127163	11550	Economy	8800.00
0005435127157	11550	Economy	8800.00
0005435127167	11550	Economy	8800.00
0005435127161	11550	Economy	8800.00
0005435127168	11550	Economy	8800.00
0005435106044	11550	Economy	8800.00
0005435127152	11550	Economy	8800.00
0005435127177	11550	Economy	8800.00
0005435106045	11550	Economy	8800.00
0005435127156	11550	Economy	8800.00
0005435106046	11550	Economy	8800.00
0005435127151	11550	Economy	8800.00
0005435127175	11550	Economy	8800.00
0005435127179	11550	Economy	8800.00
0005435127188	11550	Economy	8800.00
0005435127150	11550	Economy	8800.00
0005435127155	11550	Economy	8800.00
0005435126916	31866	Business	26400.00
0005435126873	31866	Business	26400.00
0005435126884	31866	Business	26400.00
0005435558140	31866	Business	26400.00
0005435106029	31866	Business	26400.00
0005435126950	31866	Business	26400.00
0005435126841	31866	Business	26400.00
0005435127048	31866	Economy	8800.00
0005435126872	31866	Economy	8800.00
0005435126883	31866	Economy	8800.00
0005435126759	31866	Economy	8800.00
0005435126910	31866	Economy	8800.00
0005435126722	31866	Economy	8800.00
0005435127059	31866	Economy	8800.00
0005435126954	31866	Economy	8800.00
0005435126670	31866	Economy	9700.00
0005435126887	31866	Economy	9700.00
0005435126831	31866	Economy	9700.00
0005435126904	31866	Economy	8800.00
0005435126886	31866	Economy	8800.00
0005435106024	31866	Economy	8800.00
0005435106003	31866	Economy	8800.00
0005435098584	31866	Economy	8800.00
0005435126656	31866	Economy	8800.00
0005435127020	31866	Economy	8800.00
0005435126938	31866	Economy	8800.00
0005435126907	31866	Economy	8800.00
0005435098580	31866	Economy	8800.00
0005435126760	31866	Economy	8800.00
0005435126792	31866	Economy	8800.00
0005435106030	31866	Economy	8800.00
0005435126880	31866	Economy	8800.00
0005435098579	31866	Economy	8800.00
0005435126794	31866	Economy	8800.00
0005435126982	31866	Economy	8800.00
0005435127019	31866	Economy	8800.00
0005435126908	31866	Economy	8800.00
0005435126905	31866	Economy	8800.00
0005435126690	31866	Economy	8800.00
0005435126840	31866	Economy	8800.00
0005435126851	31866	Economy	8800.00
0005435126915	31866	Economy	8800.00
0005435126874	31866	Economy	8800.00
0005435106008	31866	Economy	8800.00
0005435126909	31866	Economy	8800.00
0005435098585	31866	Economy	8800.00
0005435126774	31866	Economy	8800.00
0005435558142	31866	Economy	8800.00
0005435558143	31866	Economy	8800.00
0005435126832	31866	Economy	8800.00
0005435126926	31866	Economy	8800.00
0005435126981	31866	Economy	8800.00
0005435558141	31866	Economy	8800.00
0005435126939	31866	Economy	8800.00
0005435126842	31866	Economy	8800.00
0005435126942	31866	Economy	8800.00
0005435126787	31866	Economy	8800.00
0005435126657	31866	Economy	8800.00
0005435126948	31866	Economy	8800.00
0005435126949	31866	Economy	8800.00
0005435126833	31866	Economy	8800.00
0005435558139	31866	Economy	8800.00
0005435126750	31866	Economy	8800.00
0005435126885	31866	Economy	8800.00
0005435126977	31866	Economy	8800.00
0005435126749	31866	Economy	8800.00
0005435126914	31866	Economy	8800.00
0005435126655	31866	Economy	8800.00
0005433399030	13512	Business	36600.00
0005433399021	13512	Business	36600.00
0005433399064	13512	Business	36600.00
0005433399057	13512	Business	36600.00
0005435732519	13512	Business	36600.00
0005433399067	13512	Business	36600.00
0005433399020	13512	Business	36600.00
0005433399035	13512	Business	36600.00
0005433399023	13512	Business	36600.00
0005433399065	13512	Business	36600.00
0005433399028	13512	Economy	12200.00
0005433399019	13512	Economy	12200.00
0005433399038	13512	Economy	12200.00
0005435732506	13512	Economy	12200.00
0005433399031	13512	Economy	12200.00
0005433399048	13512	Economy	12200.00
0005433399062	13512	Economy	13400.00
0005435732442	13512	Economy	13400.00
0005433399042	13512	Economy	13400.00
0005435732526	13512	Economy	12200.00
0005433399055	13512	Economy	12200.00
0005435732507	13512	Economy	12200.00
0005433399034	13512	Economy	12200.00
0005433399045	13512	Economy	12200.00
0005433399059	13512	Economy	12200.00
0005433399046	13512	Economy	12200.00
0005433399043	13512	Economy	12200.00
0005433399040	13512	Economy	12200.00
0005435732527	13512	Economy	12200.00
0005433399049	13512	Economy	12200.00
0005433399025	13512	Economy	12200.00
0005433399051	13512	Economy	12200.00
0005433399039	13512	Economy	12200.00
0005435732469	13512	Economy	12200.00
0005433399032	13512	Economy	12200.00
0005433399058	13512	Economy	12200.00
0005433399066	13512	Economy	12200.00
0005435732523	13512	Economy	12200.00
0005435732521	13512	Economy	12200.00
0005433399056	13512	Economy	12200.00
0005433399060	13512	Economy	12200.00
0005433399033	13512	Economy	12200.00
0005433399061	13512	Economy	12200.00
0005433399027	13512	Economy	12200.00
0005435732501	13512	Economy	12200.00
0005433399050	13512	Economy	12200.00
0005433399047	13512	Economy	12200.00
0005433399063	13512	Economy	12200.00
0005433399052	13512	Economy	12200.00
0005435732522	13512	Economy	12200.00
0005433399054	13512	Economy	12200.00
0005433399037	13512	Economy	12200.00
0005435732492	13512	Economy	12200.00
0005433399053	13512	Economy	12200.00
0005433399036	13512	Economy	12200.00
0005435732436	13512	Economy	12200.00
0005433399044	13512	Economy	12200.00
0005433399024	13512	Economy	12200.00
0005435732486	13512	Economy	12200.00
0005433399026	13512	Economy	12200.00
0005433399029	13512	Economy	12200.00
0005433399022	13512	Economy	12200.00
0005433399041	13512	Economy	12200.00
0005435732596	19421	Business	36600.00
0005433398561	19421	Business	36600.00
0005435732599	19421	Business	36600.00
0005433398734	19421	Business	36600.00
0005433398640	19421	Business	36600.00
0005433398653	19421	Business	36600.00
0005433398584	19421	Business	36600.00
0005435732607	19421	Business	36600.00
0005435732601	19421	Business	36600.00
0005433398712	19421	Economy	12200.00
0005433398731	19421	Economy	12200.00
0005433398713	19421	Economy	12200.00
0005435732592	19421	Economy	12200.00
0005433398641	19421	Economy	12200.00
0005435732610	19421	Economy	12200.00
0005435732615	19421	Economy	12200.00
0005433398546	19421	Economy	12200.00
0005433398814	19421	Economy	13400.00
0005435732597	19421	Economy	13400.00
0005433398560	19421	Economy	13400.00
0005435732603	19421	Economy	13400.00
0005433398601	19421	Economy	12200.00
0005435732598	19421	Economy	12200.00
0005435732606	19421	Economy	12200.00
0005433398569	19421	Economy	12200.00
0005433398637	19421	Economy	12200.00
0005433398583	19421	Economy	12200.00
0005435732594	19421	Economy	12200.00
0005433398698	19421	Economy	12200.00
0005435732602	19421	Economy	12200.00
0005432297331	19421	Economy	12200.00
0005435732600	19421	Economy	12200.00
0005433398732	19421	Economy	12200.00
0005433398571	19421	Economy	12200.00
0005433398755	19421	Economy	12200.00
0005435732595	19421	Economy	12200.00
0005435732608	19421	Economy	12200.00
0005433398636	19421	Economy	12200.00
0005435732591	19421	Economy	12200.00
0005433398350	19421	Economy	12200.00
0005433398804	19421	Economy	12200.00
0005433398331	19421	Economy	12200.00
0005435732613	19421	Economy	12200.00
0005433398579	19421	Economy	12200.00
0005435732614	19421	Economy	12200.00
0005433398679	19421	Economy	12200.00
0005433398680	19421	Economy	12200.00
0005433398628	19421	Economy	12200.00
0005435732604	19421	Economy	12200.00
0005433398349	19421	Economy	12200.00
0005433398853	19421	Economy	12200.00
0005433398714	19421	Economy	12200.00
0005433398633	19421	Economy	12200.00
0005432297332	19421	Economy	12200.00
0005435732612	19421	Economy	12200.00
0005432297330	19421	Economy	12200.00
0005435732611	19421	Economy	12200.00
0005433398459	19421	Economy	12200.00
0005433398670	19421	Economy	12200.00
0005435732609	19421	Economy	12200.00
0005435732605	19421	Economy	12200.00
0005433398638	19421	Economy	12200.00
0005433398687	19421	Economy	12200.00
0005435732593	19421	Economy	12200.00
0005435069420	13156	Business	11300.00
0005435069701	13156	Business	11300.00
0005435069757	13156	Business	11300.00
0005435069725	13156	Business	11300.00
0005435069919	13156	Business	11300.00
0005435069514	13156	Business	11300.00
0005435069821	13156	Business	11300.00
0005435069490	13156	Business	11300.00
0005435069879	13156	Business	11300.00
0005435069790	13156	Economy	3800.00
0005435069533	13156	Economy	3800.00
0005435069591	13156	Economy	3800.00
0005435069426	13156	Economy	3800.00
0005435069710	13156	Economy	3800.00
0005435069513	13156	Economy	3800.00
0005435069368	13156	Economy	3800.00
0005435925568	13156	Economy	3800.00
0005435069702	13156	Economy	4100.00
0005435069427	13156	Economy	4100.00
0005435069733	13156	Economy	3800.00
0005435069531	13156	Economy	3800.00
0005435069748	13156	Economy	3800.00
0005435069704	13156	Economy	3800.00
0005435069633	13156	Economy	3800.00
0005435069649	13156	Economy	3800.00
0005435069735	13156	Economy	3800.00
0005435925567	13156	Economy	3800.00
0005435069791	13156	Economy	3800.00
0005435069532	13156	Economy	3800.00
0005435069421	13156	Economy	3800.00
0005435069783	13156	Economy	3800.00
0005435069380	13156	Economy	3800.00
0005435069666	13156	Economy	3800.00
0005435069506	13156	Economy	3800.00
0005435069690	13156	Economy	3800.00
0005435069652	13156	Economy	3800.00
0005435069651	13156	Economy	3800.00
0005435069826	13156	Economy	3800.00
0005435069830	13156	Economy	3800.00
0005435069367	13156	Economy	3800.00
0005435069670	13156	Economy	3800.00
0005435069723	13156	Economy	3800.00
0005435069694	13156	Economy	3800.00
0005435069366	13156	Economy	3800.00
0005435069516	13156	Economy	3800.00
0005435069524	13156	Economy	3800.00
0005435069573	13156	Economy	3800.00
0005435069525	13156	Economy	3800.00
0005435069537	13156	Economy	3800.00
0005435069665	13156	Economy	3800.00
0005435069569	13156	Economy	3800.00
0005435069605	13156	Economy	3800.00
0005435069784	13156	Economy	3800.00
0005435069700	13156	Economy	3800.00
0005435069827	13156	Economy	3800.00
0005435069747	13156	Economy	3800.00
0005435069570	13156	Economy	3800.00
0005435069495	13156	Economy	3800.00
0005435925570	13156	Economy	3800.00
0005435069724	13156	Economy	3800.00
0005435925569	13156	Economy	3800.00
0005435069496	13156	Economy	3800.00
0005435069526	13156	Economy	3800.00
0005435925571	13156	Economy	3800.00
0005435069381	13156	Economy	3800.00
0005435069680	13156	Economy	3800.00
0005435069782	13156	Economy	3800.00
0005435069534	13156	Economy	3800.00
0005435069422	13156	Economy	3800.00
0005435069382	13156	Economy	3800.00
0005435069458	13156	Economy	3800.00
0005435069491	13156	Economy	3800.00
0005435069921	13156	Economy	3800.00
0005435069828	13156	Economy	3800.00
0005435070101	15501	Business	11300.00
0005435070085	15501	Business	11300.00
0005435070082	15501	Business	11300.00
0005435070111	15501	Business	11300.00
0005435070104	15501	Business	11300.00
0005435070070	15501	Business	11300.00
0005435070099	15501	Business	11300.00
0005435070107	15501	Business	11300.00
0005435925413	15501	Business	11300.00
0005435925450	15501	Economy	3800.00
0005435925456	15501	Economy	3800.00
0005435070100	15501	Economy	3800.00
0005435070114	15501	Economy	3800.00
0005435925305	15501	Economy	3800.00
0005435070112	15501	Economy	3800.00
0005435070069	15501	Economy	3800.00
0005435925430	15501	Economy	3800.00
0005435070076	15501	Economy	4100.00
0005435070090	15501	Economy	4100.00
0005435070073	15501	Economy	4100.00
0005435070092	15501	Economy	4100.00
0005435070074	15501	Economy	3800.00
0005435070067	15501	Economy	3800.00
0005435070081	15501	Economy	3800.00
0005435070118	15501	Economy	3800.00
0005435070068	15501	Economy	3800.00
0005435070084	15501	Economy	3800.00
0005435070117	15501	Economy	3800.00
0005435070071	15501	Economy	3800.00
0005435070091	15501	Economy	3800.00
0005435070086	15501	Economy	3800.00
0005435070108	15501	Economy	3800.00
0005435070089	15501	Economy	3800.00
0005435070113	15501	Economy	3800.00
0005435925424	15501	Economy	3800.00
0005435070110	15501	Economy	3800.00
0005435070097	15501	Economy	3800.00
0005435925436	15501	Economy	3800.00
0005435070077	15501	Economy	3800.00
0005435070075	15501	Economy	3800.00
0005435070094	15501	Economy	3800.00
0005435070087	15501	Economy	3800.00
0005435070109	15501	Economy	3800.00
0005435925362	15501	Economy	3800.00
0005435070102	15501	Economy	3800.00
0005435070096	15501	Economy	3800.00
0005435925442	15501	Economy	3800.00
0005435070103	15501	Economy	3800.00
0005435070080	15501	Economy	3800.00
0005435070066	15501	Economy	3800.00
0005435070115	15501	Economy	3800.00
0005435070116	15501	Economy	3800.00
0005435070072	15501	Economy	3800.00
0005435070098	15501	Economy	3800.00
0005435925425	15501	Economy	3800.00
0005435070079	15501	Economy	3800.00
0005435925459	15501	Economy	3800.00
0005435925443	15501	Economy	3800.00
0005435070088	15501	Economy	3800.00
0005435925380	15501	Economy	3800.00
0005435070093	15501	Economy	3800.00
0005435925449	15501	Economy	3800.00
0005435070106	15501	Economy	3800.00
0005435925400	15501	Economy	3800.00
0005435070105	15501	Economy	3800.00
0005435070078	15501	Economy	3800.00
0005435925399	15501	Economy	3800.00
0005435070083	15501	Economy	3800.00
0005435070095	15501	Economy	3800.00
0005435808356	29482	Economy	27100.00
0005435808291	29482	Economy	27100.00
0005433407667	29482	Economy	24700.00
0005435808324	29482	Economy	24700.00
0005435808315	29482	Economy	24700.00
0005433407665	29482	Economy	24700.00
0005435808349	29482	Economy	24700.00
0005435808305	29482	Economy	24700.00
0005433407674	29482	Economy	24700.00
0005433407669	29482	Economy	24700.00
0005435808306	29482	Economy	24700.00
0005435808330	29482	Economy	24700.00
0005433407671	29482	Economy	24700.00
0005435808348	29482	Economy	24700.00
0005433407672	29482	Economy	24700.00
0005433407668	29482	Economy	24700.00
0005435808383	29482	Economy	24700.00
0005435808293	29482	Economy	24700.00
0005435808327	29482	Economy	24700.00
0005435808313	29482	Economy	24700.00
0005435808314	29482	Economy	24700.00
0005435808292	29482	Economy	24700.00
0005435808360	29482	Economy	24700.00
0005435808325	29482	Economy	24700.00
0005435808319	29482	Economy	24700.00
0005435808337	29482	Economy	24700.00
0005435808384	29482	Economy	24700.00
0005433407666	29482	Economy	24700.00
0005435808366	29482	Economy	24700.00
0005435808382	29482	Economy	24700.00
0005435808326	29482	Economy	24700.00
0005435808290	29482	Economy	24700.00
0005433407673	29482	Economy	24700.00
0005433407670	29482	Economy	24700.00
0005435808354	29482	Economy	24700.00
0005434215474	10707	Business	61300.00
0005434756756	10707	Business	61300.00
0005434215490	10707	Business	61300.00
0005434215497	10707	Business	61300.00
0005434756775	10707	Business	61300.00
0005434756920	10707	Business	61300.00
0005434756841	10707	Business	61300.00
0005434215475	10707	Business	61300.00
0005434756924	10707	Business	61300.00
0005434756794	10707	Business	61300.00
0005434756776	10707	Business	61300.00
0005434215495	10707	Business	61300.00
0005434756802	10707	Economy	20400.00
0005434756956	10707	Economy	20400.00
0005434756953	10707	Economy	20400.00
0005434756623	10707	Economy	20400.00
0005434756622	10707	Economy	20400.00
0005434215484	10707	Economy	20400.00
0005434756893	10707	Economy	20400.00
0005434215473	10707	Economy	20400.00
0005434215477	10707	Economy	20400.00
0005434215472	10707	Economy	22500.00
0005434756820	10707	Economy	22500.00
0005434215492	10707	Economy	22500.00
0005434756919	10707	Economy	22500.00
0005434756683	10707	Economy	22500.00
0005434215505	10707	Economy	20400.00
0005434215485	10707	Economy	20400.00
0005434756925	10707	Economy	20400.00
0005434215501	10707	Economy	20400.00
0005434215496	10707	Economy	20400.00
0005434756675	10707	Economy	20400.00
0005434215469	10707	Economy	20400.00
0005434215494	10707	Economy	20400.00
0005434756703	10707	Economy	20400.00
0005434215486	10707	Economy	20400.00
0005434215489	10707	Economy	20400.00
0005434215467	10707	Economy	20400.00
0005434756944	10707	Economy	20400.00
0005434215471	10707	Economy	20400.00
0005434215461	10707	Economy	20400.00
0005434215466	10707	Economy	20400.00
0005434215459	10707	Economy	20400.00
0005434215482	10707	Economy	20400.00
0005434215462	10707	Economy	20400.00
0005434756807	10707	Economy	20400.00
0005434756852	10707	Economy	20400.00
0005434215465	10707	Economy	20400.00
0005434756945	10707	Economy	20400.00
0005434215488	10707	Economy	20400.00
0005434756791	10707	Economy	20400.00
0005434215479	10707	Economy	20400.00
0005434756877	10707	Economy	20400.00
0005434756749	10707	Economy	20400.00
0005434215506	10707	Economy	20400.00
0005434215478	10707	Economy	20400.00
0005434756755	10707	Economy	20400.00
0005434756850	10707	Economy	20400.00
0005434215504	10707	Economy	20400.00
0005434756912	10707	Economy	20400.00
0005434756792	10707	Economy	20400.00
0005434215502	10707	Economy	20400.00
0005434215470	10707	Economy	20400.00
0005434215503	10707	Economy	20400.00
0005434215483	10707	Economy	20400.00
0005434215468	10707	Economy	20400.00
0005434756747	10707	Economy	20400.00
0005434215499	10707	Economy	20400.00
0005434756806	10707	Economy	20400.00
0005434215491	10707	Economy	20400.00
0005434756801	10707	Economy	20400.00
0005434215460	10707	Economy	20400.00
0005434756961	10707	Economy	20400.00
0005434215463	10707	Economy	20400.00
0005434756621	10707	Economy	20400.00
0005434215487	10707	Economy	20400.00
0005434756857	10707	Economy	20400.00
0005434756923	10707	Economy	20400.00
0005434756921	10707	Economy	20400.00
0005434215476	10707	Economy	20400.00
0005434215493	10707	Economy	20400.00
0005434756954	10707	Economy	20400.00
0005434756702	10707	Economy	20400.00
0005434756935	10707	Economy	20400.00
0005434756684	10707	Economy	20400.00
0005434756946	10707	Economy	20400.00
0005434756922	10707	Economy	20400.00
0005434215500	10707	Economy	20400.00
0005434756955	10707	Economy	20400.00
0005434215480	10707	Economy	20400.00
0005434215464	10707	Economy	20400.00
0005434215498	10707	Economy	20400.00
0005434215481	10707	Economy	20400.00
0005434757225	28687	Business	61300.00
0005434757219	28687	Business	61300.00
0005434214982	28687	Business	61300.00
0005434214937	28687	Business	61300.00
0005434757207	28687	Business	61300.00
0005434214877	28687	Business	61300.00
0005434215200	28687	Business	61300.00
0005434757198	28687	Business	61300.00
0005434757210	28687	Business	61300.00
0005434215127	28687	Business	61300.00
0005434215088	28687	Business	61300.00
0005434757243	28687	Business	61300.00
0005434757203	28687	Economy	20400.00
0005434757218	28687	Economy	20400.00
0005434214915	28687	Economy	20400.00
0005434757234	28687	Economy	20400.00
0005434214864	28687	Economy	20400.00
0005434214949	28687	Economy	20400.00
0005434215036	28687	Economy	20400.00
0005434757217	28687	Economy	20400.00
0005434214936	28687	Economy	20400.00
0005434215126	28687	Economy	20400.00
0005434757227	28687	Economy	22500.00
0005434757232	28687	Economy	22500.00
0005434757208	28687	Economy	22500.00
0005434757228	28687	Economy	22500.00
0005434214861	28687	Economy	22500.00
0005434214844	28687	Economy	20400.00
0005434757242	28687	Economy	20400.00
0005434757238	28687	Economy	20400.00
0005434214965	28687	Economy	20400.00
0005434214975	28687	Economy	20400.00
0005434214971	28687	Economy	20400.00
0005434757244	28687	Economy	20400.00
0005434214974	28687	Economy	20400.00
0005434214904	28687	Economy	20400.00
0005434757197	28687	Economy	20400.00
0005434757233	28687	Economy	20400.00
0005434757204	28687	Economy	20400.00
0005434215043	28687	Economy	20400.00
0005434214903	28687	Economy	20400.00
0005434214918	28687	Economy	20400.00
0005434757226	28687	Economy	20400.00
0005434757215	28687	Economy	20400.00
0005434214791	28687	Economy	20400.00
0005434215201	28687	Economy	20400.00
0005434214866	28687	Economy	20400.00
0005434214790	28687	Economy	20400.00
0005434215051	28687	Economy	20400.00
0005434757211	28687	Economy	20400.00
0005434215068	28687	Economy	20400.00
0005434757224	28687	Economy	20400.00
0005434214826	28687	Economy	20400.00
0005434214935	28687	Economy	20400.00
0005434214939	28687	Economy	20400.00
0005434757212	28687	Economy	20400.00
0005434757235	28687	Economy	20400.00
0005434215001	28687	Economy	20400.00
0005434757231	28687	Economy	20400.00
0005434757221	28687	Economy	20400.00
0005434757209	28687	Economy	20400.00
0005434757200	28687	Economy	20400.00
0005434757205	28687	Economy	20400.00
0005434757236	28687	Economy	20400.00
0005434214833	28687	Economy	20400.00
0005434215143	28687	Economy	20400.00
0005434757213	28687	Economy	20400.00
0005434215205	28687	Economy	20400.00
0005434757201	28687	Economy	20400.00
0005434215000	28687	Economy	20400.00
0005434757222	28687	Economy	20400.00
0005434214963	28687	Economy	20400.00
0005434757223	28687	Economy	20400.00
0005434214792	28687	Economy	20400.00
0005434214865	28687	Economy	20400.00
0005434215067	28687	Economy	20400.00
0005434214827	28687	Economy	20400.00
0005434757202	28687	Economy	20400.00
0005434757241	28687	Economy	20400.00
0005434757239	28687	Economy	20400.00
0005434757214	28687	Economy	20400.00
0005434757246	28687	Economy	20400.00
0005434757199	28687	Economy	20400.00
0005434757229	28687	Economy	20400.00
0005434214934	28687	Economy	20400.00
0005434757237	28687	Economy	20400.00
0005434757216	28687	Economy	20400.00
0005434757220	28687	Economy	20400.00
0005434757240	28687	Economy	20400.00
0005434757245	28687	Economy	20400.00
0005434214998	28687	Economy	20400.00
0005434214959	28687	Economy	20400.00
0005434757230	28687	Economy	20400.00
0005434214986	28687	Economy	20400.00
0005434757206	28687	Economy	20400.00
0005434214736	28687	Economy	20400.00
0005435041094	5478	Business	29500.00
0005432125601	5478	Business	29500.00
0005435007515	5478	Business	29500.00
0005435041062	5478	Business	29500.00
0005435041079	5478	Business	29500.00
0005434229606	5478	Business	29500.00
0005435007507	5478	Business	29500.00
0005434229720	5478	Business	29500.00
0005435041121	5478	Business	29500.00
0005435007499	5478	Business	29500.00
0005435041070	5478	Business	29500.00
0005435041074	5478	Business	29500.00
0005434229661	5478	Economy	9800.00
0005434229667	5478	Economy	9800.00
0005435041058	5478	Economy	9800.00
0005435041102	5478	Economy	9800.00
0005435041078	5478	Economy	9800.00
0005435041104	5478	Economy	9800.00
0005435041067	5478	Economy	9800.00
0005435041071	5478	Economy	9800.00
0005434229574	5478	Economy	9800.00
0005435041084	5478	Economy	9800.00
0005435041114	5478	Economy	9800.00
0005434229680	5478	Economy	9800.00
0005432125605	5478	Economy	9800.00
0005435041118	5478	Economy	9800.00
0005435007494	5478	Economy	9800.00
0005435041091	5478	Economy	9800.00
0005434229575	5478	Economy	9800.00
0005434229623	5478	Economy	9800.00
0005435041069	5478	Economy	9800.00
0005435007513	5478	Economy	9800.00
0005432125602	5478	Economy	9800.00
0005434229610	5478	Economy	9800.00
0005435042898	5478	Economy	9800.00
0005435041116	5478	Economy	9800.00
0005434229634	5478	Economy	9800.00
0005432125603	5478	Economy	9800.00
0005435041096	5478	Economy	9800.00
0005435041095	5478	Economy	9800.00
0005435041108	5478	Economy	9800.00
0005435007501	5478	Economy	9800.00
0005434229591	5478	Economy	9800.00
0005435007495	5478	Economy	9800.00
0005432125600	5478	Economy	9800.00
0005435041109	5478	Economy	9800.00
0005434229719	5478	Economy	9800.00
0005434229538	5478	Economy	9800.00
0005435041112	5478	Economy	9800.00
0005435041101	5478	Economy	9800.00
0005435007493	5478	Economy	9800.00
0005434229603	5478	Economy	10800.00
0005435041059	5478	Economy	10800.00
0005435041063	5478	Economy	10800.00
0005435041090	5478	Economy	10800.00
0005435042899	5478	Economy	10800.00
0005435041098	5478	Economy	10800.00
0005435041068	5478	Economy	9800.00
0005435007497	5478	Economy	9800.00
0005435041087	5478	Economy	9800.00
0005434229793	5478	Economy	9800.00
0005432125599	5478	Economy	9800.00
0005435041065	5478	Economy	9800.00
0005434229646	5478	Economy	9800.00
0005435041054	5478	Economy	9800.00
0005435007512	5478	Economy	9800.00
0005434229794	5478	Economy	9800.00
0005434229685	5478	Economy	9800.00
0005435007514	5478	Economy	9800.00
0005435041066	5478	Economy	9800.00
0005435041092	5478	Economy	9800.00
0005435041082	5478	Economy	9800.00
0005435007503	5478	Economy	9800.00
0005435007500	5478	Economy	9800.00
0005435041106	5478	Economy	9800.00
0005435007516	5478	Economy	9800.00
0005435041081	5478	Economy	9800.00
0005435041057	5478	Economy	9800.00
0005435041080	5478	Economy	9800.00
0005435041111	5478	Economy	9800.00
0005434229520	5478	Economy	9800.00
0005435007496	5478	Economy	9800.00
0005435007502	5478	Economy	9800.00
0005435041086	5478	Economy	9800.00
0005435041072	5478	Economy	9800.00
0005435041110	5478	Economy	9800.00
0005435041089	5478	Economy	9800.00
0005435041120	5478	Economy	9800.00
0005435041093	5478	Economy	9800.00
0005435041055	5478	Economy	9800.00
0005435007504	5478	Economy	9800.00
0005435041115	5478	Economy	9800.00
0005435041083	5478	Economy	9800.00
0005434229681	5478	Economy	9800.00
0005435041076	5478	Economy	9800.00
0005435041097	5478	Economy	9800.00
0005435041100	5478	Economy	9800.00
0005435007506	5478	Economy	9800.00
0005435041060	5478	Economy	9800.00
0005435007505	5478	Economy	9800.00
0005434229604	5478	Economy	9800.00
0005434229660	5478	Economy	9800.00
0005434229690	5478	Economy	9800.00
0005435041061	5478	Economy	9800.00
0005435041103	5478	Economy	9800.00
0005435041119	5478	Economy	9800.00
0005432125604	5478	Economy	9800.00
0005435007509	5478	Economy	9800.00
0005435041085	5478	Economy	9800.00
0005434229677	5478	Economy	9800.00
0005435041099	5478	Economy	9800.00
0005435007511	5478	Economy	9800.00
0005435007508	5478	Economy	9800.00
0005435041117	5478	Economy	9800.00
0005435041056	5478	Economy	9800.00
0005434229576	5478	Economy	9800.00
0005435007510	5478	Economy	9800.00
0005435041105	5478	Economy	9800.00
0005435041075	5478	Economy	9800.00
0005435041077	5478	Economy	9800.00
0005435041073	5478	Economy	9800.00
0005435041107	5478	Economy	9800.00
0005435007498	5478	Economy	9800.00
0005435042900	5478	Economy	9800.00
0005435041088	5478	Economy	9800.00
0005435041064	5478	Economy	9800.00
0005435042901	5478	Economy	9800.00
0005435041113	5478	Economy	9800.00
0005434229828	12979	Business	29500.00
0005434229837	12979	Business	29500.00
0005435007327	12979	Business	29500.00
0005435040514	12979	Business	29500.00
0005435040305	12979	Business	29500.00
0005434229827	12979	Business	29500.00
0005435040289	12979	Business	29500.00
0005435007339	12979	Business	29500.00
0005435040590	12979	Business	29500.00
0005435040521	12979	Economy	9800.00
0005435040620	12979	Economy	9800.00
0005435007185	12979	Economy	9800.00
0005435040626	12979	Economy	9800.00
0005435040525	12979	Economy	9800.00
0005435040690	12979	Economy	9800.00
0005435007268	12979	Economy	9800.00
0005435040753	12979	Economy	9800.00
0005435040633	12979	Economy	9800.00
0005435040524	12979	Economy	9800.00
0005434229840	12979	Economy	9800.00
0005435040348	12979	Economy	9800.00
0005434229831	12979	Economy	9800.00
0005434229842	12979	Economy	9800.00
0005435040472	12979	Economy	9800.00
0005435040548	12979	Economy	9800.00
0005435040413	12979	Economy	9800.00
0005435040533	12979	Economy	9800.00
0005435007354	12979	Economy	9800.00
0005435040605	12979	Economy	9800.00
0005434229823	12979	Economy	9800.00
0005434229833	12979	Economy	9800.00
0005435007316	12979	Economy	9800.00
0005435040492	12979	Economy	9800.00
0005435007237	12979	Economy	9800.00
0005435040624	12979	Economy	9800.00
0005434229838	12979	Economy	9800.00
0005434229829	12979	Economy	9800.00
0005435007334	12979	Economy	9800.00
0005435040636	12979	Economy	9800.00
0005435040448	12979	Economy	9800.00
0005435040843	12979	Economy	9800.00
0005435007253	12979	Economy	9800.00
0005435007331	12979	Economy	9800.00
0005435040539	12979	Economy	9800.00
0005435040640	12979	Economy	9800.00
0005435040429	12979	Economy	9800.00
0005435040604	12979	Economy	9800.00
0005434229839	12979	Economy	10800.00
0005434229836	12979	Economy	10800.00
0005435007288	12979	Economy	10800.00
0005435040405	12979	Economy	10800.00
0005434229844	12979	Economy	10800.00
0005434229830	12979	Economy	9800.00
0005435040400	12979	Economy	9800.00
0005435007195	12979	Economy	9800.00
0005432304476	12979	Economy	9800.00
0005435040427	12979	Economy	9800.00
0005435007238	12979	Economy	9800.00
0005435007315	12979	Economy	9800.00
0005435040484	12979	Economy	9800.00
0005432304480	12979	Economy	9800.00
0005435040844	12979	Economy	9800.00
0005435040291	12979	Economy	9800.00
0005435040591	12979	Economy	9800.00
0005435040473	12979	Economy	9800.00
0005435040534	12979	Economy	9800.00
0005435007340	12979	Economy	9800.00
0005435040465	12979	Economy	9800.00
0005435040506	12979	Economy	9800.00
0005435040431	12979	Economy	9800.00
0005435007430	12979	Economy	9800.00
0005435040725	12979	Economy	9800.00
0005435040090	12979	Economy	9800.00
0005434229834	12979	Economy	9800.00
0005435040523	12979	Economy	9800.00
0005432304479	12979	Economy	9800.00
0005434229832	12979	Economy	9800.00
0005435040526	12979	Economy	9800.00
0005435007229	12979	Economy	9800.00
0005435040654	12979	Economy	9800.00
0005435043295	12979	Economy	9800.00
0005435040316	12979	Economy	9800.00
0005435007230	12979	Economy	9800.00
0005435040540	12979	Economy	9800.00
0005435040617	12979	Economy	9800.00
0005434229824	12979	Economy	9800.00
0005432304478	12979	Economy	9800.00
0005435040637	12979	Economy	9800.00
0005435040724	12979	Economy	9800.00
0005435040355	12979	Economy	9800.00
0005434229835	12979	Economy	9800.00
0005434229843	12979	Economy	9800.00
0005432304477	12979	Economy	9800.00
0005435007319	12979	Economy	9800.00
0005435040420	12979	Economy	9800.00
0005434229826	12979	Economy	9800.00
0005435040357	12979	Economy	9800.00
0005434229841	12979	Economy	9800.00
0005434229825	12979	Economy	9800.00
0005434229822	12979	Economy	9800.00
0005435040426	12979	Economy	9800.00
0005435040313	12979	Economy	9800.00
0005435040625	12979	Economy	9800.00
0005435040557	12979	Economy	9800.00
0005435007338	12979	Economy	9800.00
0005435040317	12979	Economy	9800.00
0005435040611	12979	Economy	9800.00
0005435007378	12979	Economy	9800.00
0005435040089	12979	Economy	9800.00
0005435007231	12979	Economy	9800.00
0005435007304	12979	Economy	9800.00
0005435040845	12979	Economy	9800.00
0005435040513	12979	Economy	9800.00
0005435007328	12979	Economy	9800.00
0005434411861	14880	Business	52900.00
0005434427191	14880	Business	52900.00
0005434427194	14880	Business	52900.00
0005434427180	14880	Business	52900.00
0005434411863	14880	Business	52900.00
0005435902891	14880	Business	52900.00
0005434427173	14880	Business	52900.00
0005435902877	14880	Business	52900.00
0005435554252	14880	Business	52900.00
0005435902938	14880	Economy	17600.00
0005434427182	14880	Economy	17600.00
0005435902878	14880	Economy	17600.00
0005435902900	14880	Economy	17600.00
0005435554237	14880	Economy	17600.00
0005434427177	14880	Economy	17600.00
0005435902899	14880	Economy	19400.00
0005434427181	14880	Economy	19400.00
0005434411860	14880	Economy	19400.00
0005434427171	14880	Economy	19400.00
0005434427184	14880	Economy	17600.00
0005435902882	14880	Economy	17600.00
0005432188670	14880	Economy	17600.00
0005434427197	14880	Economy	17600.00
0005434427189	14880	Economy	17600.00
0005435902905	14880	Economy	17600.00
0005434411862	14880	Economy	17600.00
0005435554249	14880	Economy	17600.00
0005434427193	14880	Economy	17600.00
0005434427178	14880	Economy	17600.00
0005435902922	14880	Economy	17600.00
0005435902993	14880	Economy	17600.00
0005434427195	14880	Economy	17600.00
0005435902904	14880	Economy	17600.00
0005434427172	14880	Economy	17600.00
0005434427187	14880	Economy	17600.00
0005435902875	14880	Economy	17600.00
0005434427188	14880	Economy	17600.00
0005435554246	14880	Economy	17600.00
0005435902870	14880	Economy	17600.00
0005435554236	14880	Economy	17600.00
0005435902937	14880	Economy	17600.00
0005435902992	14880	Economy	17600.00
0005434427198	14880	Economy	17600.00
0005434427183	14880	Economy	17600.00
0005432188671	14880	Economy	17600.00
0005432188673	14880	Economy	17600.00
0005434427185	14880	Economy	17600.00
0005434427170	14880	Economy	17600.00
0005434427196	14880	Economy	17600.00
0005434427174	14880	Economy	17600.00
0005435902901	14880	Economy	17600.00
0005432188672	14880	Economy	17600.00
0005435902876	14880	Economy	17600.00
0005434427192	14880	Economy	17600.00
0005435902936	14880	Economy	17600.00
0005434427186	14880	Economy	17600.00
0005434427190	14880	Economy	17600.00
0005435554250	14880	Economy	17600.00
0005434427175	14880	Economy	17600.00
0005434427179	14880	Economy	17600.00
0005434427176	14880	Economy	17600.00
0005434427199	14880	Economy	17600.00
0005434411864	14880	Economy	17600.00
0005435554245	14880	Economy	17600.00
0005435902883	14880	Economy	17600.00
0005434426914	20221	Business	52900.00
0005434426968	20221	Business	52900.00
0005435903068	20221	Business	52900.00
0005432059546	20221	Business	52900.00
0005435903059	20221	Business	52900.00
0005434426875	20221	Economy	17600.00
0005435554289	20221	Economy	17600.00
0005435903060	20221	Economy	17600.00
0005435903061	20221	Economy	17600.00
0005435903069	20221	Economy	19400.00
0005435554290	20221	Economy	17600.00
0005435554288	20221	Economy	17600.00
0005434426855	20221	Economy	17600.00
0005435903062	20221	Economy	17600.00
0005434426943	20221	Economy	17600.00
0005435554287	20221	Economy	17600.00
0005434426928	20221	Economy	17600.00
0005434427074	20221	Economy	17600.00
0005434427076	20221	Economy	17600.00
0005435903074	20221	Economy	17600.00
0005434427014	20221	Economy	17600.00
0005434426937	20221	Economy	17600.00
0005434426996	20221	Economy	17600.00
0005435903073	20221	Economy	17600.00
0005434426927	20221	Economy	17600.00
0005435903066	20221	Economy	17600.00
0005434426924	20221	Economy	17600.00
0005434426860	20221	Economy	17600.00
0005434427026	20221	Economy	17600.00
0005434426838	20221	Economy	17600.00
0005434426925	20221	Economy	17600.00
0005434426992	20221	Economy	17600.00
0005435903067	20221	Economy	17600.00
0005434426861	20221	Economy	17600.00
0005435554286	20221	Economy	17600.00
0005434426856	20221	Economy	17600.00
0005435903064	20221	Economy	17600.00
0005435903071	20221	Economy	17600.00
0005434426839	20221	Economy	17600.00
0005434427075	20221	Economy	17600.00
0005434427025	20221	Economy	17600.00
0005434427018	20221	Economy	17600.00
0005435554291	20221	Economy	17600.00
0005434426899	20221	Economy	17600.00
0005434426825	20221	Economy	17600.00
0005435903072	20221	Economy	17600.00
0005435903063	20221	Economy	17600.00
0005435903076	20221	Economy	17600.00
0005435903065	20221	Economy	17600.00
0005434426854	20221	Economy	17600.00
0005434426993	20221	Economy	17600.00
0005435903075	20221	Economy	17600.00
0005435903070	20221	Economy	17600.00
0005434426898	20221	Economy	17600.00
0005432462555	28018	Business	106800.00
0005432462554	28018	Business	106800.00
0005432462557	28018	Economy	35600.00
0005434523813	28018	Economy	35600.00
0005432462556	28018	Economy	35600.00
0005434559099	28018	Economy	35600.00
0005432462559	28018	Economy	35600.00
0005434523804	28018	Economy	35600.00
0005434523802	28018	Economy	35600.00
0005432462558	28018	Economy	35600.00
0005434523791	28018	Economy	35600.00
0005434559098	28018	Economy	35600.00
0005434523797	28018	Economy	35600.00
0005432462553	28018	Economy	35600.00
0005434559096	28018	Economy	35600.00
0005435983185	26517	Business	18500.00
0005433435077	26517	Business	18500.00
0005435983191	26517	Business	18500.00
0005433435025	26517	Business	18500.00
0005434270232	26517	Business	18500.00
0005435983183	26517	Business	18500.00
0005435983155	26517	Business	18500.00
0005435983163	26517	Business	18500.00
0005435983154	26517	Business	18500.00
0005433434872	26517	Business	18500.00
0005432300380	26517	Business	18500.00
0005433435041	26517	Business	18500.00
0005433434915	26517	Economy	6200.00
0005433435043	26517	Economy	6200.00
0005435983168	26517	Economy	6200.00
0005432300377	26517	Economy	6200.00
0005435983158	26517	Economy	6200.00
0005433434933	26517	Economy	6200.00
0005432300378	26517	Economy	6200.00
0005435983181	26517	Economy	6200.00
0005435983188	26517	Economy	6200.00
0005433434969	26517	Economy	6800.00
0005433434852	26517	Economy	6800.00
0005435983167	26517	Economy	6800.00
0005435983159	26517	Economy	6800.00
0005435983175	26517	Economy	6800.00
0005435983153	26517	Economy	6200.00
0005433435027	26517	Economy	6200.00
0005433434975	26517	Economy	6200.00
0005435983193	26517	Economy	6200.00
0005433435019	26517	Economy	6200.00
0005435983184	26517	Economy	6200.00
0005435983165	26517	Economy	6200.00
0005433434899	26517	Economy	6200.00
0005435983186	26517	Economy	6200.00
0005435983171	26517	Economy	6200.00
0005435983156	26517	Economy	6200.00
0005435983162	26517	Economy	6200.00
0005433435051	26517	Economy	6200.00
0005432300381	26517	Economy	6200.00
0005434270231	26517	Economy	6200.00
0005433434999	26517	Economy	6200.00
0005435983170	26517	Economy	6200.00
0005433435007	26517	Economy	6200.00
0005435983164	26517	Economy	6200.00
0005433435026	26517	Economy	6200.00
0005433434900	26517	Economy	6200.00
0005435983173	26517	Economy	6200.00
0005433434929	26517	Economy	6200.00
0005435983189	26517	Economy	6200.00
0005433434946	26517	Economy	6200.00
0005435983160	26517	Economy	6200.00
0005432300375	26517	Economy	6200.00
0005433434955	26517	Economy	6200.00
0005435983192	26517	Economy	6200.00
0005433435000	26517	Economy	6200.00
0005435983174	26517	Economy	6200.00
0005433435018	26517	Economy	6200.00
0005433435020	26517	Economy	6200.00
0005433434957	26517	Economy	6200.00
0005433434932	26517	Economy	6200.00
0005435983157	26517	Economy	6200.00
0005435983166	26517	Economy	6200.00
0005435983178	26517	Economy	6200.00
0005433435052	26517	Economy	6200.00
0005433434954	26517	Economy	6200.00
0005433434873	26517	Economy	6200.00
0005435983176	26517	Economy	6200.00
0005433435076	26517	Economy	6200.00
0005435983182	26517	Economy	6200.00
0005433434930	26517	Economy	6200.00
0005435983169	26517	Economy	6200.00
0005435983179	26517	Economy	6200.00
0005433434960	26517	Economy	6200.00
0005435983152	26517	Economy	6200.00
0005434273093	26517	Economy	6200.00
0005433434874	26517	Economy	6200.00
0005435983172	26517	Economy	6200.00
0005433435042	26517	Economy	6200.00
0005435983180	26517	Economy	6200.00
0005435983161	26517	Economy	6200.00
0005435983177	26517	Economy	6200.00
0005432300379	26517	Economy	6200.00
0005433434901	26517	Economy	6200.00
0005435983187	26517	Economy	6200.00
0005432300376	26517	Economy	6200.00
0005435983151	26517	Economy	6200.00
0005435983190	26517	Economy	6200.00
0005434273094	26517	Economy	6200.00
0005433434956	26517	Economy	6200.00
0005435982769	26685	Business	18500.00
0005435982752	26685	Business	18500.00
0005433435254	26685	Business	18500.00
0005434271355	26685	Business	18500.00
0005433435247	26685	Business	18500.00
0005433435265	26685	Business	18500.00
0005435982831	26685	Business	18500.00
0005434271356	26685	Business	18500.00
0005432051193	26685	Business	18500.00
0005435982652	26685	Business	18500.00
0005435982771	26685	Economy	6200.00
0005433435262	26685	Economy	6200.00
0005433435245	26685	Economy	6200.00
0005433435250	26685	Economy	6200.00
0005435982959	26685	Economy	6200.00
0005433435248	26685	Economy	6200.00
0005433435264	26685	Economy	6800.00
0005435983002	26685	Economy	6800.00
0005433435253	26685	Economy	6800.00
0005433435255	26685	Economy	6800.00
0005433435258	26685	Economy	6200.00
0005435982735	26685	Economy	6200.00
0005433435261	26685	Economy	6200.00
0005435982830	26685	Economy	6200.00
0005435982770	26685	Economy	6200.00
0005435983021	26685	Economy	6200.00
0005435982778	26685	Economy	6200.00
0005435982794	26685	Economy	6200.00
0005433435251	26685	Economy	6200.00
0005433435257	26685	Economy	6200.00
0005433435249	26685	Economy	6200.00
0005433435270	26685	Economy	6200.00
0005435982804	26685	Economy	6200.00
0005435982776	26685	Economy	6200.00
0005435982730	26685	Economy	6200.00
0005433435246	26685	Economy	6200.00
0005435982809	26685	Economy	6200.00
0005435982856	26685	Economy	6200.00
0005435982777	26685	Economy	6200.00
0005435982756	26685	Economy	6200.00
0005435982633	26685	Economy	6200.00
0005433435267	26685	Economy	6200.00
0005435983003	26685	Economy	6200.00
0005435982691	26685	Economy	6200.00
0005433435268	26685	Economy	6200.00
0005434270249	26685	Economy	6200.00
0005433435269	26685	Economy	6200.00
0005434269146	26685	Economy	6200.00
0005433435256	26685	Economy	6200.00
0005435982729	26685	Economy	6200.00
0005433435273	26685	Economy	6200.00
0005435982665	26685	Economy	6200.00
0005435982595	26685	Economy	6200.00
0005435982866	26685	Economy	6200.00
0005435982677	26685	Economy	6200.00
0005433435272	26685	Economy	6200.00
0005435982664	26685	Economy	6200.00
0005435982757	26685	Economy	6200.00
0005435982651	26685	Economy	6200.00
0005435982793	26685	Economy	6200.00
0005435982629	26685	Economy	6200.00
0005435982853	26685	Economy	6200.00
0005435982803	26685	Economy	6200.00
0005435982761	26685	Economy	6200.00
0005433435271	26685	Economy	6200.00
0005435982678	26685	Economy	6200.00
0005435982832	26685	Economy	6200.00
0005433435263	26685	Economy	6200.00
0005433435266	26685	Economy	6200.00
0005433435259	26685	Economy	6200.00
0005434270250	26685	Economy	6200.00
0005434269147	26685	Economy	6200.00
0005433435252	26685	Economy	6200.00
0005433435260	26685	Economy	6200.00
0005433686662	29268	Economy	21000.00
0005433686653	29268	Economy	21000.00
0005433686651	29268	Economy	21000.00
0005433686654	29268	Economy	19100.00
0005433689936	29268	Economy	19100.00
0005433689925	29268	Economy	19100.00
0005433686652	29268	Economy	19100.00
0005433689934	29268	Economy	19100.00
0005433686649	29268	Economy	19100.00
0005433689937	29268	Economy	19100.00
0005433689929	29268	Economy	19100.00
0005433686658	29268	Economy	19100.00
0005433686660	29268	Economy	19100.00
0005433686659	29268	Economy	19100.00
0005432858241	3154	Economy	11100.00
0005432584561	3154	Economy	11100.00
0005432858157	3154	Economy	11100.00
0005432216329	3154	Economy	11100.00
0005432584548	3154	Economy	10100.00
0005432584541	3154	Economy	10100.00
0005432858239	3154	Economy	10100.00
0005432584562	3154	Economy	10100.00
0005432858236	3154	Economy	10100.00
0005432858173	3154	Economy	10100.00
0005432584556	3154	Economy	10100.00
0005432858218	3154	Economy	10100.00
0005432584555	3154	Economy	10100.00
0005432584537	3154	Economy	10100.00
0005432858155	3154	Economy	10100.00
0005432584552	3154	Economy	10100.00
0005432584558	3154	Economy	10100.00
0005432584559	3154	Economy	10100.00
0005432858240	3154	Economy	10100.00
0005432584539	3154	Economy	10100.00
0005432858134	3154	Economy	10100.00
0005432584553	3154	Economy	10100.00
0005432584546	3154	Economy	10100.00
0005432584554	3154	Economy	10100.00
0005432584549	3154	Economy	10100.00
0005432584544	3154	Economy	10100.00
0005432584543	3154	Economy	10100.00
0005432858181	3154	Economy	10100.00
0005432584557	3154	Economy	10100.00
0005432858177	3154	Economy	10100.00
0005432858237	3154	Economy	10100.00
0005432584560	3154	Economy	10100.00
0005432584540	3154	Economy	10100.00
0005432584545	3154	Economy	10100.00
0005432584538	3154	Economy	10100.00
0005432584550	3154	Economy	10100.00
0005432858215	3154	Economy	10100.00
0005432584547	3154	Economy	10100.00
0005432584542	3154	Economy	10100.00
0005432216330	3154	Economy	10100.00
0005432858214	3154	Economy	10100.00
0005432584551	3154	Economy	10100.00
0005432858235	3154	Economy	10100.00
0005432584252	31503	Economy	11100.00
0005432584343	31503	Economy	11100.00
0005432584370	31503	Economy	11100.00
0005432584334	31503	Economy	11100.00
0005432584408	31503	Economy	10100.00
0005432584364	31503	Economy	10100.00
0005432584371	31503	Economy	10100.00
0005432584432	31503	Economy	10100.00
0005432584239	31503	Economy	10100.00
0005432584247	31503	Economy	10100.00
0005432584381	31503	Economy	10100.00
0005432584344	31503	Economy	10100.00
0005432584415	31503	Economy	10100.00
0005432584478	31503	Economy	10100.00
0005432584312	31503	Economy	10100.00
0005432584319	31503	Economy	10100.00
0005432584255	31503	Economy	10100.00
0005432858317	31503	Economy	10100.00
0005432858316	31503	Economy	10100.00
0005432584427	31503	Economy	10100.00
0005432584309	31503	Economy	10100.00
0005432584260	31503	Economy	10100.00
0005432858315	31503	Economy	10100.00
0005432584314	31503	Economy	10100.00
0005432584421	31503	Economy	10100.00
0005432584228	31503	Economy	10100.00
0005432858318	31503	Economy	10100.00
0005432584313	31503	Economy	10100.00
0005432858319	31503	Economy	10100.00
0005432858310	31503	Economy	10100.00
0005432584315	31503	Economy	10100.00
0005432584240	31503	Economy	10100.00
0005432584379	31503	Economy	10100.00
0005432584378	31503	Economy	10100.00
0005432858314	31503	Economy	10100.00
0005432584336	31503	Economy	10100.00
0005432858313	31503	Economy	10100.00
0005432858312	31503	Economy	10100.00
0005432584426	31503	Economy	10100.00
0005432584337	31503	Economy	10100.00
0005432584278	31503	Economy	10100.00
0005432584395	31503	Economy	10100.00
0005432584377	31503	Economy	10100.00
0005432584407	31503	Economy	10100.00
0005432584480	31503	Economy	10100.00
0005432584282	31503	Economy	10100.00
0005432858309	31503	Economy	10100.00
0005432584307	31503	Economy	10100.00
0005432858311	31503	Economy	10100.00
0005432584479	31503	Economy	10100.00
0005434943539	867	Economy	7500.00
0005434943537	867	Economy	7500.00
0005433255180	867	Economy	7500.00
0005433255190	867	Economy	7500.00
0005434943536	867	Economy	7500.00
0005433255179	867	Economy	7500.00
0005434943541	867	Economy	7500.00
0005434943542	867	Economy	7500.00
0005434943538	867	Economy	7500.00
0005434943544	867	Economy	7500.00
0005433255189	867	Economy	7500.00
0005434943543	867	Economy	7500.00
0005433255173	867	Economy	7500.00
0005434943540	867	Economy	7500.00
0005433255172	867	Economy	7500.00
0005433255228	16200	Economy	8300.00
0005433255232	16200	Economy	7500.00
0005433255231	16200	Economy	7500.00
0005434943440	16200	Economy	7500.00
0005434943495	16200	Economy	7500.00
0005434943496	16200	Economy	7500.00
0005434943476	16200	Economy	7500.00
0005433255230	16200	Economy	7500.00
0005433255229	16200	Economy	7500.00
0005434943502	16200	Economy	7500.00
0005433811650	14432	Economy	4400.00
0005433927519	14432	Economy	4400.00
0005433927520	14432	Economy	4400.00
0005433927521	14432	Economy	4400.00
0005433927518	14432	Economy	4400.00
0005433811651	14432	Economy	4400.00
0005433811653	14432	Economy	4400.00
0005433368198	21733	Business	9800.00
0005433368224	21733	Business	9800.00
0005435653938	21733	Business	9800.00
0005435653917	21733	Business	9800.00
0005435653953	21733	Business	9800.00
0005435653923	21733	Business	9800.00
0005433368363	21733	Business	9800.00
0005435653939	21733	Business	9800.00
0005435653949	21733	Business	9800.00
0005433368190	21733	Business	9800.00
0005433368334	21733	Business	9800.00
0005435653928	21733	Economy	3300.00
0005435653932	21733	Economy	3300.00
0005433368262	21733	Economy	3300.00
0005435653910	21733	Economy	3300.00
0005435653942	21733	Economy	3300.00
0005435653926	21733	Economy	3300.00
0005435653933	21733	Economy	3300.00
0005435653951	21733	Economy	3300.00
0005433368197	21733	Economy	3300.00
0005435653937	21733	Economy	3600.00
0005433368362	21733	Economy	3600.00
0005435653940	21733	Economy	3600.00
0005435653906	21733	Economy	3600.00
0005435653958	21733	Economy	3300.00
0005435653920	21733	Economy	3300.00
0005435653912	21733	Economy	3300.00
0005435653918	21733	Economy	3300.00
0005435653936	21733	Economy	3300.00
0005435653948	21733	Economy	3300.00
0005435653957	21733	Economy	3300.00
0005435653929	21733	Economy	3300.00
0005435653931	21733	Economy	3300.00
0005435653943	21733	Economy	3300.00
0005435653925	21733	Economy	3300.00
0005435653914	21733	Economy	3300.00
0005433367998	21733	Economy	3300.00
0005435653946	21733	Economy	3300.00
0005433368263	21733	Economy	3300.00
0005435653941	21733	Economy	3300.00
0005433368133	21733	Economy	3300.00
0005433367997	21733	Economy	3300.00
0005435653944	21733	Economy	3300.00
0005433368283	21733	Economy	3300.00
0005435653909	21733	Economy	3300.00
0005433368231	21733	Economy	3300.00
0005433368399	21733	Economy	3300.00
0005435653913	21733	Economy	3300.00
0005435653919	21733	Economy	3300.00
0005435653945	21733	Economy	3300.00
0005435653956	21733	Economy	3300.00
0005433368385	21733	Economy	3300.00
0005433368300	21733	Economy	3300.00
0005435653915	21733	Economy	3300.00
0005433368351	21733	Economy	3300.00
0005435653935	21733	Economy	3300.00
0005435653907	21733	Economy	3300.00
0005435653954	21733	Economy	3300.00
0005433368189	21733	Economy	3300.00
0005435653922	21733	Economy	3300.00
0005435653930	21733	Economy	3300.00
0005435653950	21733	Economy	3300.00
0005435653952	21733	Economy	3300.00
0005433368230	21733	Economy	3300.00
0005435653934	21733	Economy	3300.00
0005435653911	21733	Economy	3300.00
0005433368228	21733	Economy	3300.00
0005435653916	21733	Economy	3300.00
0005433368460	21733	Economy	3300.00
0005435653924	21733	Economy	3300.00
0005433368332	21733	Economy	3300.00
0005435653921	21733	Economy	3300.00
0005435653959	21733	Economy	3300.00
0005433368080	21733	Economy	3300.00
0005433368372	21733	Economy	3300.00
0005433368200	21733	Economy	3300.00
0005433368301	21733	Economy	3300.00
0005433368282	21733	Economy	3300.00
0005435653927	21733	Economy	3300.00
0005433368421	21733	Economy	3300.00
0005433368119	21733	Economy	3300.00
0005435653947	21733	Economy	3300.00
0005435653908	21733	Economy	3300.00
0005435653955	21733	Economy	3300.00
0005433368375	21733	Economy	3300.00
0005433368373	21733	Economy	3300.00
0005433368229	21733	Economy	3300.00
0005433785693	9343	Business	186200.00
0005434171202	9343	Business	186200.00
0005433785680	9343	Business	186200.00
0005432665317	9343	Business	186200.00
0005435269790	9343	Business	186200.00
0005433763503	9343	Business	186200.00
0005434171281	9343	Business	186200.00
0005434171211	9343	Business	186200.00
0005434151727	9343	Business	186200.00
0005433785684	9343	Business	186200.00
0005433763498	9343	Business	186200.00
0005433785702	9343	Business	186200.00
0005433806084	9343	Business	186200.00
0005433785687	9343	Business	186200.00
0005432665316	9343	Business	186200.00
0005434171227	9343	Economy	68300.00
0005433763508	9343	Economy	68300.00
0005433785694	9343	Economy	68300.00
0005433785689	9343	Economy	62100.00
0005432657513	9343	Economy	62100.00
0005433763511	9343	Economy	62100.00
0005434151742	9343	Economy	62100.00
0005435269820	9343	Economy	62100.00
0005433806093	9343	Economy	62100.00
0005434171259	9343	Economy	62100.00
0005433785674	9343	Economy	62100.00
0005433785688	9343	Economy	62100.00
0005432666430	9343	Economy	62100.00
0005432666431	9343	Economy	62100.00
0005434171245	9343	Economy	62100.00
0005433806085	9343	Economy	62100.00
0005434171224	9343	Economy	62100.00
0005433806082	9343	Economy	62100.00
0005433806079	9343	Economy	62100.00
0005434270237	9343	Economy	62100.00
0005433806081	9343	Economy	62100.00
0005434171280	9343	Economy	62100.00
0005433785703	9343	Economy	62100.00
0005433785699	9343	Economy	62100.00
0005434171209	9343	Economy	62100.00
0005435269833	9343	Economy	62100.00
0005434171237	9343	Economy	62100.00
0005433806092	9343	Economy	62100.00
0005433806070	9343	Economy	62100.00
0005433763505	9343	Economy	62100.00
0005433763506	9343	Economy	62100.00
0005434171228	9343	Economy	62100.00
0005433806088	9343	Economy	62100.00
0005434270236	9343	Economy	62100.00
0005434151723	9343	Economy	62100.00
0005433806091	9343	Economy	62100.00
0005434171200	9343	Economy	62100.00
0005434171208	9343	Economy	62100.00
0005434171267	9343	Economy	62100.00
0005433763502	9343	Economy	62100.00
0005435269792	9343	Economy	62100.00
0005433785705	9343	Economy	62100.00
0005435269821	9343	Economy	62100.00
0005432657511	9343	Economy	62100.00
0005433763497	9343	Economy	62100.00
0005433785675	9343	Economy	62100.00
0005434273097	9343	Economy	62100.00
0005435269834	9343	Economy	62100.00
0005433785681	9343	Economy	62100.00
0005433806072	9343	Economy	62100.00
0005433763499	9343	Economy	62100.00
0005433785676	9343	Economy	62100.00
0005434171201	9343	Economy	62100.00
0005433763512	9343	Economy	62100.00
0005433806087	9343	Economy	62100.00
0005433806094	9343	Economy	62100.00
0005433763501	9343	Economy	62100.00
0005434151726	9343	Economy	62100.00
0005434171185	9343	Economy	62100.00
0005433785691	9343	Economy	62100.00
0005433785690	9343	Economy	62100.00
0005433763510	9343	Economy	62100.00
0005434171226	9343	Economy	62100.00
0005435269807	9343	Economy	62100.00
0005433806069	9343	Economy	62100.00
0005433806078	9343	Economy	62100.00
0005434171210	9343	Economy	62100.00
0005433763504	9343	Economy	62100.00
0005433806089	9343	Economy	62100.00
0005433785682	9343	Economy	68300.00
0005433763507	9343	Economy	62100.00
0005434273096	9343	Economy	62100.00
0005433806086	9343	Economy	68300.00
0005433785700	9343	Economy	62100.00
0005433806068	9343	Economy	62100.00
0005432665318	9343	Economy	62100.00
0005434270235	9343	Economy	62100.00
0005435269832	9343	Economy	62100.00
0005433806067	9343	Economy	62100.00
0005435269825	9343	Economy	62100.00
0005434270230	9343	Economy	62100.00
0005433785677	9343	Economy	62100.00
0005434171282	9343	Economy	62100.00
0005433785686	9343	Economy	62100.00
0005433806074	9343	Economy	62100.00
0005434171283	9343	Economy	62100.00
0005433785695	9343	Economy	62100.00
0005434171274	9343	Economy	62100.00
0005434171273	9343	Economy	62100.00
0005433785692	9343	Economy	62100.00
0005433806083	9343	Economy	62100.00
0005433806073	9343	Economy	62100.00
0005433785697	9343	Economy	62100.00
0005433806077	9343	Economy	62100.00
0005432657514	9343	Economy	62100.00
0005433785706	9343	Economy	62100.00
0005433785698	9343	Economy	62100.00
0005433806075	9343	Economy	62100.00
0005432667496	9343	Economy	62100.00
0005434171212	9343	Economy	62100.00
0005435269824	9343	Economy	62100.00
0005434171239	9343	Economy	62100.00
0005435269791	9343	Economy	62100.00
0005433763509	9343	Economy	62100.00
0005433785701	9343	Economy	62100.00
0005433806080	9343	Economy	62100.00
0005435269835	9343	Economy	62100.00
0005434270229	9343	Economy	62100.00
0005433806076	9343	Economy	62100.00
0005433763500	9343	Economy	62100.00
0005435269822	9343	Economy	62100.00
0005433785704	9343	Economy	62100.00
0005434270227	9343	Economy	62100.00
0005433806090	9343	Economy	62100.00
0005434171207	9343	Economy	62100.00
0005432657512	9343	Economy	62100.00
0005433806071	9343	Economy	62100.00
0005433785696	9343	Economy	62100.00
0005433785685	9343	Economy	62100.00
0005433785678	9343	Economy	62100.00
0005434171284	9343	Economy	62100.00
0005432667497	9343	Economy	62100.00
0005433785679	9343	Economy	62100.00
0005432667495	9343	Economy	62100.00
0005433785683	9343	Economy	62100.00
0005434171199	9343	Economy	62100.00
0005434171347	26255	Business	186200.00
0005435269922	26255	Business	186200.00
0005433805779	26255	Business	186200.00
0005433805817	26255	Business	186200.00
0005433805854	26255	Business	186200.00
0005435269917	26255	Business	186200.00
0005433785549	26255	Business	186200.00
0005435269925	26255	Business	186200.00
0005434271353	26255	Business	186200.00
0005435269915	26255	Business	186200.00
0005433805871	26255	Business	186200.00
0005432657486	26255	Business	186200.00
0005433805744	26255	Business	186200.00
0005433763399	26255	Business	186200.00
0005433785395	26255	Business	186200.00
0005433805940	26255	Business	186200.00
0005433785548	26255	Business	186200.00
0005435269918	26255	Business	186200.00
0005433785346	26255	Economy	68300.00
0005433785409	26255	Business	186200.00
0005434171345	26255	Economy	68300.00
0005433805804	26255	Economy	68300.00
0005433805941	26255	Economy	62100.00
0005433805841	26255	Economy	68300.00
0005433763427	26255	Economy	62100.00
0005433805696	26255	Economy	62100.00
0005433805695	26255	Economy	62100.00
0005434269144	26255	Economy	62100.00
0005434269143	26255	Economy	62100.00
0005433785478	26255	Economy	62100.00
0005433785345	26255	Economy	62100.00
0005432657484	26255	Economy	62100.00
0005432659730	26255	Economy	62100.00
0005433805772	26255	Economy	62100.00
0005434269145	26255	Economy	62100.00
0005433805819	26255	Economy	62100.00
0005433785338	26255	Economy	62100.00
0005433763389	26255	Economy	62100.00
0005433805767	26255	Economy	62100.00
0005433785411	26255	Economy	62100.00
0005433805818	26255	Economy	62100.00
0005433785369	26255	Economy	62100.00
0005433805849	26255	Economy	62100.00
0005433763377	26255	Economy	62100.00
0005433805824	26255	Economy	62100.00
0005434270248	26255	Economy	62100.00
0005433805842	26255	Economy	62100.00
0005433805806	26255	Economy	62100.00
0005435269924	26255	Economy	62100.00
0005434171340	26255	Economy	62100.00
0005433805730	26255	Economy	62100.00
0005433785406	26255	Economy	62100.00
0005433805752	26255	Economy	62100.00
0005434171350	26255	Economy	62100.00
0005433763413	26255	Economy	62100.00
0005432659731	26255	Economy	62100.00
0005432657474	26255	Economy	62100.00
0005433763361	26255	Economy	62100.00
0005432663065	26255	Economy	62100.00
0005433785475	26255	Economy	62100.00
0005434171351	26255	Economy	62100.00
0005434151763	26255	Economy	62100.00
0005433785368	26255	Economy	62100.00
0005433805753	26255	Economy	62100.00
0005434151764	26255	Economy	62100.00
0005433805820	26255	Economy	62100.00
0005434271354	26255	Economy	62100.00
0005435269921	26255	Economy	62100.00
0005434171343	26255	Economy	62100.00
0005434171344	26255	Economy	62100.00
0005433805768	26255	Economy	62100.00
0005433805737	26255	Economy	62100.00
0005435269926	26255	Economy	62100.00
0005433805850	26255	Economy	62100.00
0005433763317	26255	Economy	62100.00
0005435269913	26255	Economy	62100.00
0005432659723	26255	Economy	62100.00
0005433763428	26255	Economy	62100.00
0005433785416	26255	Economy	62100.00
0005434171352	26255	Economy	62100.00
0005433785396	26255	Economy	62100.00
0005432657489	26255	Economy	62100.00
0005433805736	26255	Economy	62100.00
0005434151765	26255	Economy	62100.00
0005435269923	26255	Economy	62100.00
0005432659732	26255	Economy	62100.00
0005433785382	26255	Economy	62100.00
0005433785230	26255	Economy	68300.00
0005433785417	26255	Economy	68300.00
0005432659722	26255	Economy	62100.00
0005433785407	26255	Economy	62100.00
0005432666414	26255	Economy	68300.00
0005433805766	26255	Economy	68300.00
0005433805786	26255	Economy	62100.00
0005433785391	26255	Economy	62100.00
0005433785408	26255	Economy	62100.00
0005433785161	26255	Economy	62100.00
0005432666411	26255	Economy	62100.00
0005434171349	26255	Economy	62100.00
0005434171348	26255	Economy	62100.00
0005433785580	26255	Economy	62100.00
0005433805729	26255	Economy	62100.00
0005432657488	26255	Economy	62100.00
0005432659729	26255	Economy	62100.00
0005435269920	26255	Economy	62100.00
0005435269919	26255	Economy	62100.00
0005434171342	26255	Economy	62100.00
0005432659724	26255	Economy	62100.00
0005432657485	26255	Economy	62100.00
0005433763381	26255	Economy	62100.00
0005434171341	26255	Economy	62100.00
0005432666419	26255	Economy	62100.00
0005433785412	26255	Economy	62100.00
0005433805735	26255	Economy	62100.00
0005433805805	26255	Economy	62100.00
0005433805939	26255	Economy	62100.00
0005435269914	26255	Economy	62100.00
0005434171354	26255	Economy	62100.00
0005433785199	26255	Economy	62100.00
0005434151762	26255	Economy	62100.00
0005432657487	26255	Economy	62100.00
0005433805944	26255	Economy	62100.00
0005433785202	26255	Economy	62100.00
0005432659726	26255	Economy	62100.00
0005433785135	26255	Economy	62100.00
0005433805787	26255	Economy	62100.00
0005433763400	26255	Economy	62100.00
0005432657473	26255	Economy	62100.00
0005433805823	26255	Economy	62100.00
0005434171346	26255	Economy	62100.00
0005434270247	26255	Economy	62100.00
0005433805743	26255	Economy	62100.00
0005432663053	26255	Economy	62100.00
0005435269916	26255	Economy	62100.00
0005433785343	26255	Economy	62100.00
0005433805734	26255	Economy	62100.00
0005434171353	26255	Economy	62100.00
0005435135768	4881	Economy	5900.00
0005435929680	4881	Economy	5300.00
0005435135772	4881	Economy	5300.00
0005435135770	4881	Economy	5300.00
0005435929686	4881	Economy	5300.00
0005435135769	4881	Economy	5300.00
0005435135771	4881	Economy	5300.00
0005435929660	4881	Economy	5300.00
0005435929700	33004	Economy	5900.00
0005435135718	33004	Economy	5300.00
0005435135723	33004	Economy	5300.00
0005435135738	33004	Economy	5300.00
0005435135727	33004	Economy	5300.00
0005435135724	33004	Economy	5300.00
0005435135728	33004	Economy	5300.00
0005435135725	33004	Economy	5300.00
0005435135719	33004	Economy	5300.00
0005435929698	33004	Economy	5300.00
0005435929699	33004	Economy	5300.00
0005434983393	9454	Economy	17900.00
0005434218011	9454	Economy	17900.00
0005434983394	9454	Economy	17900.00
0005434983395	9454	Economy	17900.00
0005434218004	9454	Economy	17900.00
0005434983396	9454	Economy	17900.00
0005434983392	9454	Economy	17900.00
0005434983391	9454	Economy	17900.00
0005434983364	27380	Economy	17900.00
0005434218051	27380	Economy	17900.00
0005434218052	27380	Economy	17900.00
0005434218053	27380	Economy	17900.00
0005434218050	27380	Economy	17900.00
0005433986409	24280	Business	36400.00
0005433961272	24280	Business	36400.00
0005433986300	24280	Business	36400.00
0005433961412	24280	Business	36400.00
0005433961435	24280	Business	36400.00
0005433961442	24280	Business	36400.00
0005433986458	24280	Business	36400.00
0005433986346	24280	Business	36400.00
0005433961428	24280	Business	36400.00
0005433961244	24280	Business	36400.00
0005433961488	24280	Business	36400.00
0005433986400	24280	Economy	13400.00
0005433961396	24280	Economy	13400.00
0005433961273	24280	Economy	12100.00
0005433961310	24280	Economy	12100.00
0005433986347	24280	Economy	12100.00
0005433961276	24280	Economy	12100.00
0005433986469	24280	Economy	12100.00
0005433986521	24280	Economy	12100.00
0005433961277	24280	Economy	12100.00
0005433986514	24280	Economy	12100.00
0005433961447	24280	Economy	12100.00
0005433961436	24280	Economy	12100.00
0005433986461	24280	Economy	12100.00
0005433986218	24280	Economy	12100.00
0005433961439	24280	Economy	12100.00
0005433986321	24280	Economy	12100.00
0005433986320	24280	Economy	12100.00
0005433961430	24280	Economy	12100.00
0005433986382	24280	Economy	12100.00
0005433961311	24280	Economy	12100.00
0005433986378	24280	Economy	12100.00
0005433961377	24280	Economy	12100.00
0005433986298	24280	Economy	12100.00
0005433961453	24280	Economy	12100.00
0005433986351	24280	Economy	12100.00
0005433986353	24280	Economy	12100.00
0005433961478	24280	Economy	12100.00
0005433986407	24280	Economy	12100.00
0005433986404	24280	Economy	12100.00
0005433986485	24280	Economy	12100.00
0005433961378	24280	Economy	12100.00
0005433986408	24280	Economy	12100.00
0005433986352	24280	Economy	12100.00
0005433961271	24280	Economy	12100.00
0005433986537	24280	Economy	12100.00
0005433961395	24280	Economy	12100.00
0005433961284	24280	Economy	12100.00
0005433961418	24280	Economy	12100.00
0005433961457	24280	Economy	12100.00
0005433986360	24280	Economy	12100.00
0005433961356	24280	Economy	12100.00
0005433986520	24280	Economy	12100.00
0005433961352	24280	Economy	12100.00
0005433961309	24280	Economy	12100.00
0005433961441	24280	Economy	12100.00
0005433961438	24280	Economy	12100.00
0005433986281	24280	Economy	12100.00
0005433961471	24280	Economy	12100.00
0005433986368	24280	Economy	12100.00
0005433961477	24280	Economy	12100.00
0005433986433	24280	Economy	12100.00
0005433961482	24280	Economy	12100.00
0005433986406	24280	Economy	13400.00
0005433986325	24280	Economy	12100.00
0005433986288	24280	Economy	12100.00
0005433961350	24280	Economy	12100.00
0005433961434	24280	Economy	12100.00
0005433961353	24280	Economy	12100.00
0005433961476	24280	Economy	12100.00
0005433961484	24280	Economy	12100.00
0005433961425	24280	Economy	12100.00
0005433961365	24280	Economy	12100.00
0005433986401	24280	Economy	12100.00
0005433986527	24280	Economy	12100.00
0005433961448	24280	Economy	12100.00
0005433961419	24280	Economy	12100.00
0005433961283	24280	Economy	12100.00
0005433986372	24280	Economy	12100.00
0005433986502	24280	Economy	12100.00
0005433986481	24280	Economy	12100.00
0005433961420	24280	Economy	12100.00
0005433961390	24280	Economy	12100.00
0005433961464	24280	Economy	12100.00
0005433961415	24280	Economy	12100.00
0005433986467	24280	Economy	12100.00
0005433961437	24280	Economy	12100.00
0005433961411	24280	Economy	12100.00
0005433986383	24280	Economy	12100.00
0005433986381	24280	Economy	12100.00
0005433961483	24280	Economy	12100.00
0005433961389	24280	Economy	12100.00
0005433961449	24280	Economy	12100.00
0005433961278	24280	Economy	12100.00
0005433986536	24280	Economy	12100.00
0005433961388	24280	Economy	12100.00
0005433986482	24280	Economy	12100.00
0005433961458	24280	Economy	12100.00
0005433986299	24280	Economy	12100.00
0005433986362	24280	Economy	12100.00
0005433961485	24280	Economy	12100.00
0005433961372	24280	Economy	12100.00
0005433961417	24280	Economy	12100.00
0005433986459	24280	Economy	12100.00
0005433986134	24280	Economy	12100.00
0005433986282	24280	Economy	12100.00
0005433961989	25955	Business	36400.00
0005433986866	25955	Business	36400.00
0005433962012	25955	Business	36400.00
0005433986862	25955	Business	36400.00
0005433962006	25955	Business	36400.00
0005433986863	25955	Business	36400.00
0005433986848	25955	Business	36400.00
0005433986876	25955	Business	36400.00
0005433986872	25955	Business	36400.00
0005433986877	25955	Business	36400.00
0005433986850	25955	Business	36400.00
0005433962013	25955	Business	36400.00
0005433986852	25955	Economy	13400.00
0005433961999	25955	Economy	12100.00
0005433961994	25955	Economy	12100.00
0005433986851	25955	Economy	12100.00
0005433961977	25955	Economy	12100.00
0005433962015	25955	Economy	12100.00
0005433962023	25955	Economy	12100.00
0005433962011	25955	Economy	12100.00
0005433962026	25955	Economy	12100.00
0005433986853	25955	Economy	12100.00
0005433986857	25955	Economy	12100.00
0005433961979	25955	Economy	12100.00
0005433962005	25955	Economy	12100.00
0005433962024	25955	Economy	12100.00
0005433986849	25955	Economy	12100.00
0005433986845	25955	Economy	12100.00
0005433962008	25955	Economy	12100.00
0005433961978	25955	Economy	12100.00
0005433962019	25955	Economy	12100.00
0005433962030	25955	Economy	12100.00
0005433962003	25955	Economy	12100.00
0005433961998	25955	Economy	12100.00
0005433961988	25955	Economy	12100.00
0005433962031	25955	Economy	12100.00
0005433961990	25955	Economy	12100.00
0005433986854	25955	Economy	12100.00
0005433962002	25955	Economy	12100.00
0005433961997	25955	Economy	12100.00
0005433961992	25955	Economy	12100.00
0005433962004	25955	Economy	12100.00
0005433961981	25955	Economy	12100.00
0005433962010	25955	Economy	12100.00
0005433961984	25955	Economy	12100.00
0005433961975	25955	Economy	12100.00
0005433962027	25955	Economy	12100.00
0005433986858	25955	Economy	12100.00
0005433961982	25955	Economy	12100.00
0005433962001	25955	Economy	12100.00
0005433961983	25955	Economy	12100.00
0005433961980	25955	Economy	12100.00
0005433962014	25955	Economy	12100.00
0005433962000	25955	Economy	12100.00
0005433986861	25955	Economy	12100.00
0005433962022	25955	Economy	12100.00
0005433962029	25955	Economy	12100.00
0005433986875	25955	Economy	12100.00
0005433962007	25955	Economy	12100.00
0005433962020	25955	Economy	12100.00
0005433961985	25955	Economy	13400.00
0005433986855	25955	Economy	12100.00
0005433986870	25955	Economy	13400.00
0005433961974	25955	Economy	12100.00
0005433962018	25955	Economy	12100.00
0005433986871	25955	Economy	12100.00
0005433961991	25955	Economy	12100.00
0005433961986	25955	Economy	12100.00
0005433962016	25955	Economy	12100.00
0005433961987	25955	Economy	12100.00
0005433961995	25955	Economy	12100.00
0005433961996	25955	Economy	12100.00
0005433986860	25955	Economy	12100.00
0005433986865	25955	Economy	12100.00
0005433986867	25955	Economy	12100.00
0005433986873	25955	Economy	12100.00
0005433962021	25955	Economy	12100.00
0005433986846	25955	Economy	12100.00
0005433961976	25955	Economy	12100.00
0005433986869	25955	Economy	12100.00
0005433986859	25955	Economy	12100.00
0005433962025	25955	Economy	12100.00
0005433986847	25955	Economy	12100.00
0005433986856	25955	Economy	12100.00
0005433986868	25955	Economy	12100.00
0005433961993	25955	Economy	12100.00
0005433986874	25955	Economy	12100.00
0005433986864	25955	Economy	12100.00
0005433962017	25955	Economy	12100.00
0005433962009	25955	Economy	12100.00
0005433962028	25955	Economy	12100.00
0005433166043	927	Economy	25400.00
0005434480838	927	Economy	25400.00
0005434480825	927	Economy	25400.00
0005433166065	927	Economy	25400.00
0005433166064	927	Economy	23100.00
0005433166097	927	Economy	23100.00
0005433166076	927	Economy	23100.00
0005433166135	927	Economy	23100.00
0005433166073	927	Economy	23100.00
0005434480831	927	Economy	23100.00
0005434480834	927	Economy	23100.00
0005433166106	927	Economy	23100.00
0005434480842	927	Economy	23100.00
0005434480844	927	Economy	23100.00
0005434480833	927	Economy	23100.00
0005434480835	927	Economy	23100.00
0005433166084	927	Economy	23100.00
0005434480843	927	Economy	23100.00
0005434480847	927	Economy	23100.00
0005433166057	927	Economy	23100.00
0005434480836	927	Economy	23100.00
0005433166075	927	Economy	23100.00
0005434480830	927	Economy	23100.00
0005433166019	927	Economy	23100.00
0005434480827	927	Economy	23100.00
0005432269552	927	Economy	23100.00
0005434480840	927	Economy	23100.00
0005434480837	927	Economy	23100.00
0005434480832	927	Economy	23100.00
0005433166105	927	Economy	23100.00
0005434480839	927	Economy	23100.00
0005434480846	927	Economy	23100.00
0005432269553	927	Economy	23100.00
0005434480823	927	Economy	23100.00
0005434480841	927	Economy	23100.00
0005433166018	927	Economy	23100.00
0005433166091	927	Economy	23100.00
0005433166055	927	Economy	23100.00
0005434480828	927	Economy	23100.00
0005433166061	927	Economy	23100.00
0005433166104	927	Economy	23100.00
0005434480824	927	Economy	23100.00
0005434480845	927	Economy	23100.00
0005434480826	927	Economy	23100.00
0005433166100	927	Economy	23100.00
0005433166136	927	Economy	23100.00
0005434480829	927	Economy	23100.00
0005433166053	927	Economy	23100.00
0005433166137	927	Economy	23100.00
0005433166175	16568	Economy	25400.00
0005434480768	16568	Economy	25400.00
0005433166170	16568	Economy	25400.00
0005434480769	16568	Economy	25400.00
0005434480683	16568	Economy	23100.00
0005434480609	16568	Economy	23100.00
0005434480649	16568	Economy	23100.00
0005434480638	16568	Economy	23100.00
0005434480685	16568	Economy	23100.00
0005434480586	16568	Economy	23100.00
0005434480585	16568	Economy	23100.00
0005434480637	16568	Economy	23100.00
0005433166173	16568	Economy	23100.00
0005434480725	16568	Economy	23100.00
0005433166165	16568	Economy	23100.00
0005434480636	16568	Economy	23100.00
0005434480540	16568	Economy	23100.00
0005434480597	16568	Economy	23100.00
0005434480771	16568	Economy	23100.00
0005434480549	16568	Economy	23100.00
0005434480514	16568	Economy	23100.00
0005433166174	16568	Economy	23100.00
0005434480512	16568	Economy	23100.00
0005434480770	16568	Economy	23100.00
0005434480641	16568	Economy	23100.00
0005433166166	16568	Economy	23100.00
0005434480634	16568	Economy	23100.00
0005434480726	16568	Economy	23100.00
0005434480513	16568	Economy	23100.00
0005433166171	16568	Economy	23100.00
0005433166168	16568	Economy	23100.00
0005433166172	16568	Economy	23100.00
0005434480620	16568	Economy	23100.00
0005434480727	16568	Economy	23100.00
0005433166176	16568	Economy	23100.00
0005433166169	16568	Economy	23100.00
0005433166167	16568	Economy	23100.00
0005434480635	16568	Economy	23100.00
0005433872554	3202	Economy	19000.00
0005433872557	3202	Economy	17200.00
0005433872552	3202	Economy	17200.00
0005433872551	3202	Economy	17200.00
0005433872550	3202	Economy	17200.00
0005433872556	3202	Economy	17200.00
0005433872553	3202	Economy	17200.00
0005433872555	3202	Economy	17200.00
0005433872528	32556	Economy	17200.00
0005433872527	32556	Economy	17200.00
0005433872506	32556	Economy	17200.00
0005433872523	32556	Economy	17200.00
0005435142835	10364	Economy	17000.00
0005433289906	10364	Economy	17000.00
0005435150308	10364	Economy	17000.00
0005435142841	10364	Economy	17000.00
0005435150297	10364	Economy	15400.00
0005435142844	10364	Economy	15400.00
0005435150295	10364	Economy	15400.00
0005435142840	10364	Economy	15400.00
0005433289920	10364	Economy	15400.00
0005433289936	10364	Economy	15400.00
0005435150298	10364	Economy	15400.00
0005435142846	10364	Economy	15400.00
0005435150302	10364	Economy	15400.00
0005435150307	10364	Economy	15400.00
0005435150301	10364	Economy	15400.00
0005435386625	10364	Economy	15400.00
0005435386624	10364	Economy	15400.00
0005435150304	10364	Economy	15400.00
0005435142845	10364	Economy	15400.00
0005435150299	10364	Economy	15400.00
0005435142839	10364	Economy	15400.00
0005435150300	10364	Economy	15400.00
0005435142838	10364	Economy	15400.00
0005433289937	10364	Economy	15400.00
0005435150296	10364	Economy	15400.00
0005435142837	10364	Economy	15400.00
0005435386610	10364	Economy	15400.00
0005435150294	10364	Economy	15400.00
0005435142843	10364	Economy	15400.00
0005433289928	10364	Economy	15400.00
0005435150306	10364	Economy	15400.00
0005435142847	10364	Economy	15400.00
0005433289943	10364	Economy	15400.00
0005435386643	10364	Economy	15400.00
0005435150305	10364	Economy	15400.00
0005435142836	10364	Economy	15400.00
0005435142842	10364	Economy	15400.00
0005435150303	10364	Economy	15400.00
0005435142848	10364	Economy	15400.00
0005435386633	10364	Economy	15400.00
0005435386646	10364	Economy	15400.00
0005435142751	21950	Economy	17000.00
0005435150201	21950	Economy	17000.00
0005435142752	21950	Economy	15400.00
0005435150174	21950	Economy	15400.00
0005433290004	21950	Economy	15400.00
0005435150175	21950	Economy	15400.00
0005435150227	21950	Economy	15400.00
0005435150186	21950	Economy	15400.00
0005435150235	21950	Economy	15400.00
0005435386710	21950	Economy	15400.00
0005435150154	21950	Economy	15400.00
0005435150202	21950	Economy	15400.00
0005435150129	21950	Economy	15400.00
0005435150153	21950	Economy	15400.00
0005435150182	21950	Economy	15400.00
0005435386705	21950	Economy	15400.00
0005433290002	21950	Economy	15400.00
0005435150188	21950	Economy	15400.00
0005435142789	21950	Economy	15400.00
0005435142678	21950	Economy	15400.00
0005435150187	21950	Economy	15400.00
0005435150184	21950	Economy	15400.00
0005435150204	21950	Economy	15400.00
0005435150189	21950	Economy	15400.00
0005435142644	21950	Economy	15400.00
0005433290005	21950	Economy	15400.00
0005433290003	21950	Economy	15400.00
0005435386708	21950	Economy	15400.00
0005435386711	21950	Economy	15400.00
0005435386707	21950	Economy	15400.00
0005435386709	21950	Economy	15400.00
0005435142747	21950	Economy	15400.00
0005433290000	21950	Economy	15400.00
0005435150172	21950	Economy	15400.00
0005435150173	21950	Economy	15400.00
0005435150181	21950	Economy	15400.00
0005435386706	21950	Economy	15400.00
0005435142681	21950	Economy	15400.00
0005433290001	21950	Economy	15400.00
0005435142755	21950	Economy	15400.00
0005433289999	21950	Economy	15400.00
0005435545835	11195	Business	57200.00
0005434573631	11195	Business	57200.00
0005435502548	11195	Business	57200.00
0005435529393	11195	Business	57200.00
0005435529503	11195	Business	57200.00
0005435502564	11195	Business	57200.00
0005435545813	11195	Business	57200.00
0005435529555	11195	Business	57200.00
0005435529477	11195	Business	57200.00
0005435529443	11195	Business	57200.00
0005435545834	11195	Business	57200.00
0005435529420	11195	Economy	19100.00
0005435319700	11195	Economy	19100.00
0005435319680	11195	Economy	19100.00
0005435502550	11195	Economy	19100.00
0005435319655	11195	Economy	19100.00
0005435319669	11195	Economy	19100.00
0005435502525	11195	Economy	19100.00
0005435502557	11195	Economy	21000.00
0005435529559	11195	Economy	21000.00
0005435529428	11195	Economy	21000.00
0005435529490	11195	Economy	21000.00
0005435529419	11195	Economy	19100.00
0005434573634	11195	Economy	19100.00
0005435502551	11195	Economy	19100.00
0005434573628	11195	Economy	19100.00
0005435529504	11195	Economy	19100.00
0005435502558	11195	Economy	19100.00
0005435529562	11195	Economy	19100.00
0005435529561	11195	Economy	19100.00
0005435502526	11195	Economy	19100.00
0005435502592	11195	Economy	19100.00
0005435529505	11195	Economy	19100.00
0005435502593	11195	Economy	19100.00
0005435319674	11195	Economy	19100.00
0005435529506	11195	Economy	19100.00
0005434573623	11195	Economy	19100.00
0005435529435	11195	Economy	19100.00
0005435529444	11195	Economy	19100.00
0005435319710	11195	Economy	19100.00
0005435502524	11195	Economy	19100.00
0005435319670	11195	Economy	19100.00
0005435529545	11195	Economy	19100.00
0005435529473	11195	Economy	19100.00
0005435529538	11195	Economy	19100.00
0005435529521	11195	Economy	19100.00
0005435529481	11195	Economy	19100.00
0005435529510	11195	Economy	19100.00
0005435529472	11195	Economy	19100.00
0005435545839	11195	Economy	19100.00
0005435529572	11195	Economy	19100.00
0005434573625	11195	Economy	19100.00
0005435545797	11195	Economy	19100.00
0005434573629	11195	Economy	19100.00
0005434573632	11195	Economy	19100.00
0005435545792	11195	Economy	19100.00
0005434573627	11195	Economy	19100.00
0005435502552	11195	Economy	19100.00
0005434573630	11195	Economy	19100.00
0005435545800	11195	Economy	19100.00
0005435529560	11195	Economy	19100.00
0005435319711	11195	Economy	19100.00
0005435529442	11195	Economy	19100.00
0005435319649	11195	Economy	19100.00
0005434573624	11195	Economy	19100.00
0005435319657	11195	Economy	19100.00
0005435529550	11195	Economy	19100.00
0005434573622	11195	Economy	19100.00
0005435502556	11195	Economy	19100.00
0005434573633	11195	Economy	19100.00
0005435529484	11195	Economy	19100.00
0005435545812	11195	Economy	19100.00
0005435502517	11195	Economy	19100.00
0005435545836	11195	Economy	19100.00
0005435529554	11195	Economy	19100.00
0005434573626	11195	Economy	19100.00
0005435545803	11195	Economy	19100.00
0005435502508	11195	Economy	19100.00
0005435529509	11195	Economy	19100.00
0005435518263	20914	Business	57200.00
0005435508608	20914	Business	57200.00
0005434573472	20914	Business	57200.00
0005435518265	20914	Business	57200.00
0005435502734	20914	Business	57200.00
0005435518275	20914	Business	57200.00
0005435502750	20914	Business	57200.00
0005435508613	20914	Business	57200.00
0005434573465	20914	Business	57200.00
0005435319769	20914	Business	57200.00
0005435502729	20914	Business	57200.00
0005435518266	20914	Business	57200.00
0005435319767	20914	Economy	19100.00
0005435502744	20914	Economy	19100.00
0005434573524	20914	Economy	19100.00
0005435508606	20914	Economy	19100.00
0005435502732	20914	Economy	19100.00
0005435518269	20914	Economy	19100.00
0005435319768	20914	Economy	19100.00
0005434573485	20914	Economy	19100.00
0005434573499	20914	Economy	21000.00
0005435508610	20914	Economy	21000.00
0005435518273	20914	Economy	21000.00
0005435518262	20914	Economy	21000.00
0005432291980	20914	Economy	19100.00
0005435319763	20914	Economy	19100.00
0005435508609	20914	Economy	19100.00
0005435518270	20914	Economy	19100.00
0005435319762	20914	Economy	19100.00
0005435518271	20914	Economy	19100.00
0005435518268	20914	Economy	19100.00
0005435518276	20914	Economy	19100.00
0005434573518	20914	Economy	19100.00
0005435502738	20914	Economy	19100.00
0005435319761	20914	Economy	19100.00
0005434573505	20914	Economy	19100.00
0005435508600	20914	Economy	19100.00
0005435508604	20914	Economy	19100.00
0005435508605	20914	Economy	19100.00
0005435502740	20914	Economy	19100.00
0005435502746	20914	Economy	19100.00
0005435502739	20914	Economy	19100.00
0005435502730	20914	Economy	19100.00
0005435518267	20914	Economy	19100.00
0005435502747	20914	Economy	19100.00
0005435508601	20914	Economy	19100.00
0005435518277	20914	Economy	19100.00
0005435502733	20914	Economy	19100.00
0005434573528	20914	Economy	19100.00
0005435518264	20914	Economy	19100.00
0005434573484	20914	Economy	19100.00
0005435518278	20914	Economy	19100.00
0005435518274	20914	Economy	19100.00
0005434573493	20914	Economy	19100.00
0005435319759	20914	Economy	19100.00
0005435508615	20914	Economy	19100.00
0005435502735	20914	Economy	19100.00
0005434573483	20914	Economy	19100.00
0005435518272	20914	Economy	19100.00
0005435508611	20914	Economy	19100.00
0005435502742	20914	Economy	19100.00
0005435508607	20914	Economy	19100.00
0005435502736	20914	Economy	19100.00
0005435502743	20914	Economy	19100.00
0005435502749	20914	Economy	19100.00
0005435319760	20914	Economy	19100.00
0005435508602	20914	Economy	19100.00
0005435502741	20914	Economy	19100.00
0005435502745	20914	Economy	19100.00
0005435502748	20914	Economy	19100.00
0005435319764	20914	Economy	19100.00
0005435508614	20914	Economy	19100.00
0005432291979	20914	Economy	19100.00
0005434573506	20914	Economy	19100.00
0005435319765	20914	Economy	19100.00
0005435319766	20914	Economy	19100.00
0005432291978	20914	Economy	19100.00
0005435502731	20914	Economy	19100.00
0005435508612	20914	Economy	19100.00
0005434573519	20914	Economy	19100.00
0005435502737	20914	Economy	19100.00
0005435508603	20914	Economy	19100.00
0005432693352	2982	Business	10300.00
0005432693378	2982	Business	10300.00
0005432693390	2982	Economy	3400.00
0005432693417	2982	Economy	3400.00
0005432693506	2982	Economy	3400.00
0005432693348	2982	Economy	3400.00
0005432693500	2982	Economy	3400.00
0005432693178	2982	Economy	3800.00
0005432693411	2982	Economy	3400.00
0005432693459	2982	Economy	3400.00
0005432693482	2982	Economy	3400.00
0005432693414	2982	Economy	3400.00
0005432693316	2982	Economy	3400.00
0005432693380	2982	Economy	3400.00
0005432693420	2982	Economy	3400.00
0005432693180	2982	Economy	3400.00
0005432693460	2982	Economy	3400.00
0005432693427	2982	Economy	3400.00
0005432693291	2982	Economy	3400.00
0005432693429	2982	Economy	3400.00
0005432693394	2982	Economy	3400.00
0005432693179	2982	Economy	3400.00
0005432693260	2982	Economy	3400.00
0005432693351	2982	Economy	3400.00
0005432693461	2982	Economy	3400.00
0005432693462	2982	Economy	3400.00
0005432693335	2982	Economy	3400.00
0005432693505	2982	Economy	3400.00
0005432693340	2982	Economy	3400.00
0005432707292	2985	Business	10300.00
0005432707296	2985	Business	10300.00
0005433124210	2985	Business	10300.00
0005433124203	2985	Business	10300.00
0005432880959	2985	Business	10300.00
0005433194890	2985	Business	10300.00
0005432707278	2985	Business	10300.00
0005432881017	2985	Business	10300.00
0005432880912	2985	Economy	3400.00
0005432707286	2985	Economy	3400.00
0005433124098	2985	Economy	3400.00
0005432707297	2985	Economy	3400.00
0005432707287	2985	Economy	3400.00
0005432707295	2985	Economy	3400.00
0005433124201	2985	Economy	3400.00
0005433124116	2985	Economy	3400.00
0005433124079	2985	Economy	3800.00
0005432707285	2985	Economy	3800.00
0005432880953	2985	Economy	3800.00
0005433124200	2985	Economy	3800.00
0005432707289	2985	Economy	3400.00
0005432707300	2985	Economy	3400.00
0005433124115	2985	Economy	3400.00
0005432707291	2985	Economy	3400.00
0005432707288	2985	Economy	3400.00
0005432707294	2985	Economy	3400.00
0005432707293	2985	Economy	3400.00
0005432707284	2985	Economy	3400.00
0005433194897	2985	Economy	3400.00
0005432707281	2985	Economy	3400.00
0005432880923	2985	Economy	3400.00
0005432707283	2985	Economy	3400.00
0005433124154	2985	Economy	3400.00
0005432217832	2985	Economy	3400.00
0005432707282	2985	Economy	3400.00
0005433124147	2985	Economy	3400.00
0005432707298	2985	Economy	3400.00
0005433124168	2985	Economy	3400.00
0005432707303	2985	Economy	3400.00
0005433194896	2985	Economy	3400.00
0005432881059	2985	Economy	3400.00
0005432707279	2985	Economy	3400.00
0005432880913	2985	Economy	3400.00
0005432880924	2985	Economy	3400.00
0005433124175	2985	Economy	3400.00
0005432707280	2985	Economy	3400.00
0005433124120	2985	Economy	3400.00
0005432881010	2985	Economy	3400.00
0005433124212	2985	Economy	3400.00
0005433124080	2985	Economy	3400.00
0005432707301	2985	Economy	3400.00
0005432880989	2985	Economy	3400.00
0005432707299	2985	Economy	3400.00
0005433194888	2985	Economy	3400.00
0005432217834	2985	Economy	3400.00
0005433124144	2985	Economy	3400.00
0005432707290	2985	Economy	3400.00
0005433124228	2985	Economy	3400.00
0005432880903	2985	Economy	3400.00
0005433124211	2985	Economy	3400.00
0005433124173	2985	Economy	3400.00
0005433124066	2985	Economy	3400.00
0005432880990	2985	Economy	3400.00
0005433194889	2985	Economy	3400.00
0005432880958	2985	Economy	3400.00
0005433124121	2985	Economy	3400.00
0005433124067	2985	Economy	3400.00
0005433124148	2985	Economy	3400.00
0005433124204	2985	Economy	3400.00
0005432217833	2985	Economy	3400.00
0005433124174	2985	Economy	3400.00
0005432707302	2985	Economy	3400.00
0005432693718	29929	Business	10300.00
0005433124340	29929	Business	10300.00
0005432693720	29929	Business	10300.00
0005433124339	29929	Business	10300.00
0005432707124	29929	Business	10300.00
0005433124333	29929	Business	10300.00
0005432707046	29929	Business	10300.00
0005432707135	29929	Business	10300.00
0005432881118	29929	Business	10300.00
0005433124334	29929	Business	10300.00
0005432693698	29929	Business	10300.00
0005433124344	29929	Business	10300.00
0005432693697	29929	Economy	3400.00
0005432707112	29929	Economy	3400.00
0005432881109	29929	Economy	3400.00
0005433124336	29929	Economy	3400.00
0005432706996	29929	Economy	3400.00
0005432881107	29929	Economy	3400.00
0005432693701	29929	Economy	3400.00
0005432693707	29929	Economy	3400.00
0005432693703	29929	Economy	3400.00
0005432707020	29929	Economy	3400.00
0005433124342	29929	Economy	3800.00
0005432881119	29929	Economy	3800.00
0005432881110	29929	Economy	3800.00
0005433124331	29929	Economy	3800.00
0005432693712	29929	Economy	3800.00
0005432707045	29929	Economy	3400.00
0005432707067	29929	Economy	3400.00
0005432693722	29929	Economy	3400.00
0005432693695	29929	Economy	3400.00
0005432693706	29929	Economy	3400.00
0005432693719	29929	Economy	3400.00
0005432707022	29929	Economy	3400.00
0005432693700	29929	Economy	3400.00
0005432707023	29929	Economy	3400.00
0005432706997	29929	Economy	3400.00
0005432706969	29929	Economy	3400.00
0005432881111	29929	Economy	3400.00
0005432707044	29929	Economy	3400.00
0005432707126	29929	Economy	3400.00
0005432881116	29929	Economy	3400.00
0005432707114	29929	Economy	3400.00
0005432707074	29929	Economy	3400.00
0005433124346	29929	Economy	3400.00
0005432693704	29929	Economy	3400.00
0005433124343	29929	Economy	3400.00
0005432881117	29929	Economy	3400.00
0005433124341	29929	Economy	3400.00
0005432707125	29929	Economy	3400.00
0005432693708	29929	Economy	3400.00
0005432707060	29929	Economy	3400.00
0005432693699	29929	Economy	3400.00
0005432707158	29929	Economy	3400.00
0005432693705	29929	Economy	3400.00
0005433124335	29929	Economy	3400.00
0005432707056	29929	Economy	3400.00
0005432707139	29929	Economy	3400.00
0005432881115	29929	Economy	3400.00
0005432693715	29929	Economy	3400.00
0005432693721	29929	Economy	3400.00
0005432693713	29929	Economy	3400.00
0005432693709	29929	Economy	3400.00
0005432693724	29929	Economy	3400.00
0005432693725	29929	Economy	3400.00
0005432707150	29929	Economy	3400.00
0005432881113	29929	Economy	3400.00
0005432707151	29929	Economy	3400.00
0005432693696	29929	Economy	3400.00
0005432693702	29929	Economy	3400.00
0005433124347	29929	Economy	3400.00
0005432881121	29929	Economy	3400.00
0005432693726	29929	Economy	3400.00
0005432707029	29929	Economy	3400.00
0005432707028	29929	Economy	3400.00
0005432693711	29929	Economy	3400.00
0005432707168	29929	Economy	3400.00
0005432707187	29929	Economy	3400.00
0005433124345	29929	Economy	3400.00
0005432881106	29929	Economy	3400.00
0005432693723	29929	Economy	3400.00
0005432707115	29929	Economy	3400.00
0005432707109	29929	Economy	3400.00
0005432881108	29929	Economy	3400.00
0005432881114	29929	Economy	3400.00
0005432881112	29929	Economy	3400.00
0005432707098	29929	Economy	3400.00
0005432693716	29929	Economy	3400.00
0005432693714	29929	Economy	3400.00
0005432707021	29929	Economy	3400.00
0005432707149	29929	Economy	3400.00
0005433124337	29929	Economy	3400.00
0005432881120	29929	Economy	3400.00
0005432693717	29929	Economy	3400.00
0005433124332	29929	Economy	3400.00
0005433124338	29929	Economy	3400.00
0005432693710	29929	Economy	3400.00
0005434988938	23682	Economy	4000.00
0005434980365	23682	Economy	4000.00
0005434980375	23682	Economy	4000.00
0005434980376	23682	Economy	4000.00
0005434980388	23682	Economy	3600.00
0005434988948	23682	Economy	3600.00
0005434980367	23682	Economy	3600.00
0005434980390	23682	Economy	3600.00
0005434980369	23682	Economy	3600.00
0005434988943	23682	Economy	3600.00
0005434980372	23682	Economy	3600.00
0005434980362	23682	Economy	3600.00
0005434988942	23682	Economy	3600.00
0005434988945	23682	Economy	3600.00
0005434980381	23682	Economy	3600.00
0005434988939	23682	Economy	3600.00
0005434980360	23682	Economy	3600.00
0005434980374	23682	Economy	3600.00
0005434980377	23682	Economy	3600.00
0005434980363	23682	Economy	3600.00
0005434980387	23682	Economy	3600.00
0005434988944	23682	Economy	3600.00
0005434980380	23682	Economy	3600.00
0005434988941	23682	Economy	3600.00
0005434980389	23682	Economy	3600.00
0005434980371	23682	Economy	3600.00
0005434980385	23682	Economy	3600.00
0005434988947	23682	Economy	3600.00
0005434980368	23682	Economy	3600.00
0005434988940	23682	Economy	3600.00
0005434980384	23682	Economy	3600.00
0005434980379	23682	Economy	3600.00
0005434980383	23682	Economy	3600.00
0005434980364	23682	Economy	3600.00
0005434980386	23682	Economy	3600.00
0005434980366	23682	Economy	3600.00
0005434980382	23682	Economy	3600.00
0005434980370	23682	Economy	3600.00
0005434980373	23682	Economy	3600.00
0005434980378	23682	Economy	3600.00
0005434980361	23682	Economy	3600.00
0005434988949	23682	Economy	3600.00
0005434988946	23682	Economy	3600.00
0005434980057	27538	Economy	4000.00
0005434980129	27538	Economy	4000.00
0005434980042	27538	Economy	4000.00
0005434980143	27538	Economy	4000.00
0005434988799	27538	Economy	3600.00
0005434980099	27538	Economy	3600.00
0005434980024	27538	Economy	3600.00
0005434980041	27538	Economy	3600.00
0005434980179	27538	Economy	3600.00
0005434979998	27538	Economy	3600.00
0005434980081	27538	Economy	3600.00
0005434988848	27538	Economy	3600.00
0005434980152	27538	Economy	3600.00
0005434980110	27538	Economy	3600.00
0005434980003	27538	Economy	3600.00
0005434988857	27538	Economy	3600.00
0005434980111	27538	Economy	3600.00
0005434988850	27538	Economy	3600.00
0005434988859	27538	Economy	3600.00
0005434980151	27538	Economy	3600.00
0005434980037	27538	Economy	3600.00
0005434988864	27538	Economy	3600.00
0005434980058	27538	Economy	3600.00
0005434988826	27538	Economy	3600.00
0005434980106	27538	Economy	3600.00
0005434980093	27538	Economy	3600.00
0005434980118	27538	Economy	3600.00
0005434988798	27538	Economy	3600.00
0005434980071	27538	Economy	3600.00
0005434979999	27538	Economy	3600.00
0005434979859	27538	Economy	3600.00
0005434988856	27538	Economy	3600.00
0005434988839	27538	Economy	3600.00
0005434980180	27538	Economy	3600.00
0005434988800	27538	Economy	3600.00
0005434980174	27538	Economy	3600.00
0005434980043	27538	Economy	3600.00
0005434988860	27538	Economy	3600.00
0005434988851	27538	Economy	3600.00
0005434980105	27538	Economy	3600.00
0005434980173	27538	Economy	3600.00
0005433113559	10279	Economy	19700.00
0005434302546	10279	Economy	19700.00
0005434302883	10279	Economy	19700.00
0005434302545	10279	Economy	19700.00
0005434302542	10279	Economy	19700.00
0005434302543	10279	Economy	19700.00
0005433113562	10279	Economy	19700.00
0005433113560	10279	Economy	19700.00
0005434302544	10279	Economy	19700.00
0005433113558	10279	Economy	19700.00
0005433111524	10279	Economy	19700.00
0005433113561	10279	Economy	19700.00
0005433113581	19603	Economy	19700.00
0005434302493	19603	Economy	19700.00
0005433113580	19603	Economy	19700.00
0005434302519	19603	Economy	19700.00
0005434302520	19603	Economy	19700.00
0005434302504	19603	Economy	19700.00
0005434302505	19603	Economy	19700.00
0005435070127	3580	Business	26900.00
0005435070154	3580	Business	26900.00
0005435070132	3580	Business	26900.00
0005435070151	3580	Business	26900.00
0005435925418	3580	Business	26900.00
0005435070122	3580	Business	26900.00
0005435719055	3580	Business	26900.00
0005435939897	3580	Business	26900.00
0005435070164	3580	Business	26900.00
0005435070135	3580	Business	26900.00
0005435925414	3580	Economy	9000.00
0005435070146	3580	Economy	9000.00
0005435070149	3580	Economy	9000.00
0005435925477	3580	Economy	9000.00
0005435070165	3580	Economy	9000.00
0005435070137	3580	Economy	9000.00
0005435070155	3580	Economy	9000.00
0005435070129	3580	Economy	9000.00
0005435925453	3580	Economy	9000.00
0005435925446	3580	Economy	9900.00
0005435719056	3580	Economy	9900.00
0005435925417	3580	Economy	9900.00
0005435070160	3580	Economy	9900.00
0005435925447	3580	Economy	9000.00
0005435070143	3580	Economy	9000.00
0005435070131	3580	Economy	9000.00
0005435070150	3580	Economy	9000.00
0005435070167	3580	Economy	9000.00
0005435070144	3580	Economy	9000.00
0005435070139	3580	Economy	9000.00
0005435070163	3580	Economy	9000.00
0005435070147	3580	Economy	9000.00
0005435070136	3580	Economy	9000.00
0005435070125	3580	Economy	9000.00
0005435070121	3580	Economy	9000.00
0005435070161	3580	Economy	9000.00
0005435070134	3580	Economy	9000.00
0005435070119	3580	Economy	9000.00
0005435070152	3580	Economy	9000.00
0005435925433	3580	Economy	9000.00
0005435939904	3580	Economy	9000.00
0005435070157	3580	Economy	9000.00
0005435070170	3580	Economy	9000.00
0005435070159	3580	Economy	9000.00
0005435070168	3580	Economy	9000.00
0005435719051	3580	Economy	9000.00
0005435070140	3580	Economy	9000.00
0005435070123	3580	Economy	9000.00
0005435719050	3580	Economy	9000.00
0005435070138	3580	Economy	9000.00
0005435070153	3580	Economy	9000.00
0005435070158	3580	Economy	9000.00
0005435070141	3580	Economy	9000.00
0005435719053	3580	Economy	9000.00
0005435719054	3580	Economy	9000.00
0005435925464	3580	Economy	9000.00
0005435939896	3580	Economy	9000.00
0005435070133	3580	Economy	9000.00
0005435719057	3580	Economy	9000.00
0005435925460	3580	Economy	9000.00
0005435925457	3580	Economy	9000.00
0005435070145	3580	Economy	9000.00
0005435070124	3580	Economy	9000.00
0005435070130	3580	Economy	9000.00
0005435925466	3580	Economy	9000.00
0005435070166	3580	Economy	9000.00
0005435070156	3580	Economy	9000.00
0005435070162	3580	Economy	9000.00
0005435070169	3580	Economy	9000.00
0005435925448	3580	Economy	9000.00
0005435070126	3580	Economy	9000.00
0005435925435	3580	Economy	9000.00
0005435070142	3580	Economy	9000.00
0005435939898	3580	Economy	9000.00
0005435925440	3580	Economy	9000.00
0005435925481	3580	Economy	9000.00
0005435719052	3580	Economy	9000.00
0005435925458	3580	Economy	9000.00
0005435070128	3580	Economy	9000.00
0005435070120	3580	Economy	9000.00
0005435070148	3580	Economy	9000.00
0005435069680	15310	Business	26900.00
0005435069367	15310	Business	26900.00
0005435069704	15310	Business	26900.00
0005435069458	15310	Business	26900.00
0005435069790	15310	Business	26900.00
0005435069366	15310	Business	26900.00
0005435069516	15310	Business	26900.00
0005435069735	15310	Economy	9000.00
0005435069757	15310	Economy	9000.00
0005435069783	15310	Economy	9000.00
0005435069830	15310	Economy	9000.00
0005435069748	15310	Economy	9000.00
0005435069506	15310	Economy	9000.00
0005435925571	15310	Economy	9000.00
0005435069591	15310	Economy	9900.00
0005435925568	15310	Economy	9900.00
0005435069513	15310	Economy	9900.00
0005435069782	15310	Economy	9900.00
0005435069422	15310	Economy	9000.00
0005435069421	15310	Economy	9000.00
0005435069701	15310	Economy	9000.00
0005435069879	15310	Economy	9000.00
0005435069368	15310	Economy	9000.00
0005435069821	15310	Economy	9000.00
0005435069532	15310	Economy	9000.00
0005435069569	15310	Economy	9000.00
0005435069525	15310	Economy	9000.00
0005435069490	15310	Economy	9000.00
0005435069747	15310	Economy	9000.00
0005435069495	15310	Economy	9000.00
0005435069534	15310	Economy	9000.00
0005435069531	15310	Economy	9000.00
0005435069533	15310	Economy	9000.00
0005435069700	15310	Economy	9000.00
0005435069605	15310	Economy	9000.00
0005435069381	15310	Economy	9000.00
0005435069702	15310	Economy	9000.00
0005435069382	15310	Economy	9000.00
0005435069827	15310	Economy	9000.00
0005435069380	15310	Economy	9000.00
0005435069514	15310	Economy	9000.00
0005435069633	15310	Economy	9000.00
0005435069725	15310	Economy	9000.00
0005435069652	15310	Economy	9000.00
0005435069690	15310	Economy	9000.00
0005435069828	15310	Economy	9000.00
0005435069426	15310	Economy	9000.00
0005435069724	15310	Economy	9000.00
0005435069784	15310	Economy	9000.00
0005435069524	15310	Economy	9000.00
0005435069537	15310	Economy	9000.00
0005435069710	15310	Economy	9000.00
0005435925569	15310	Economy	9000.00
0005435069723	15310	Economy	9000.00
0005435069826	15310	Economy	9000.00
0005435069921	15310	Economy	9000.00
0005435069670	15310	Economy	9000.00
0005435069570	15310	Economy	9000.00
0005435069791	15310	Economy	9000.00
0005435925567	15310	Economy	9000.00
0005435069420	15310	Economy	9000.00
0005435069651	15310	Economy	9000.00
0005435069573	15310	Economy	9000.00
0005435069491	15310	Economy	9000.00
0005435069919	15310	Economy	9000.00
0005435925570	15310	Economy	9000.00
0005435069733	15310	Economy	9000.00
0005435069665	15310	Economy	9000.00
0005435069649	15310	Economy	9000.00
0005435069427	15310	Economy	9000.00
0005435069526	15310	Economy	9000.00
0005435069694	15310	Economy	9000.00
0005435069496	15310	Economy	9000.00
0005435069666	15310	Economy	9000.00
0005432658633	18189	Economy	5900.00
0005432660861	18189	Economy	5900.00
0005432659749	18189	Economy	5900.00
0005432660859	18189	Economy	5900.00
0005432658634	18189	Economy	5900.00
0005432660860	18189	Economy	5900.00
0005432659748	18189	Economy	5900.00
0005432659750	18189	Economy	5900.00
0005432667476	26438	Economy	5900.00
0005432667479	26438	Economy	5900.00
0005433102602	189	Business	20000.00
0005432901893	189	Business	20000.00
0005433102807	189	Business	20000.00
0005432901838	189	Business	20000.00
0005433102687	189	Business	20000.00
0005432920150	189	Business	20000.00
0005433102800	189	Business	20000.00
0005433102750	189	Business	20000.00
0005432920158	189	Business	20000.00
0005432677604	189	Business	20000.00
0005433102696	189	Business	20000.00
0005433102794	189	Business	20000.00
0005432920128	189	Business	20000.00
0005433102849	189	Business	20000.00
0005433102799	189	Business	20000.00
0005432920129	189	Business	20000.00
0005432157532	189	Business	20000.00
0005433102817	189	Economy	7300.00
0005433102754	189	Economy	7300.00
0005433102787	189	Economy	7300.00
0005432901894	189	Economy	7300.00
0005433102753	189	Economy	7300.00
0005433102752	189	Economy	7300.00
0005433102789	189	Economy	6700.00
0005433102703	189	Economy	6700.00
0005432920111	189	Economy	6700.00
0005433102767	189	Economy	6700.00
0005433102736	189	Economy	6700.00
0005432901867	189	Economy	6700.00
0005432920122	189	Economy	6700.00
0005433102806	189	Economy	6700.00
0005432920123	189	Economy	6700.00
0005432920113	189	Economy	6700.00
0005432157531	189	Economy	6700.00
0005433102828	189	Economy	6700.00
0005432920061	189	Economy	6700.00
0005432920091	189	Economy	6700.00
0005433102766	189	Economy	6700.00
0005433102553	189	Economy	6700.00
0005433102676	189	Economy	6700.00
0005432920077	189	Economy	6700.00
0005432920064	189	Economy	6700.00
0005432901855	189	Economy	6700.00
0005432920075	189	Economy	6700.00
0005433102777	189	Economy	6700.00
0005432920060	189	Economy	6700.00
0005433102792	189	Economy	6700.00
0005433102788	189	Economy	6700.00
0005433102764	189	Economy	6700.00
0005433102712	189	Economy	6700.00
0005432920120	189	Economy	6700.00
0005432920084	189	Economy	6700.00
0005432920066	189	Economy	6700.00
0005433102675	189	Economy	6700.00
0005432901759	189	Economy	6700.00
0005432901749	189	Economy	6700.00
0005433102798	189	Economy	6700.00
0005432920112	189	Economy	6700.00
0005433102745	189	Economy	7300.00
0005432677618	189	Economy	7300.00
0005433102783	189	Economy	7300.00
0005433102813	189	Economy	7300.00
0005433102795	189	Economy	7300.00
0005433102651	189	Economy	6700.00
0005433102755	189	Economy	6700.00
0005433102677	189	Economy	6700.00
0005433102738	189	Economy	7300.00
0005433102812	189	Economy	6700.00
0005433102704	189	Economy	6700.00
0005433102808	189	Economy	6700.00
0005433102846	189	Economy	6700.00
0005433102743	189	Economy	6700.00
0005432901884	189	Economy	6700.00
0005433102827	189	Economy	6700.00
0005433102702	189	Economy	6700.00
0005433102756	189	Economy	6700.00
0005433102723	189	Economy	6700.00
0005432920121	189	Economy	6700.00
0005433102727	189	Economy	6700.00
0005432901883	189	Economy	6700.00
0005432901796	189	Economy	6700.00
0005432920067	189	Economy	6700.00
0005432901837	189	Economy	6700.00
0005432920125	189	Economy	6700.00
0005432901793	189	Economy	6700.00
0005432920151	189	Economy	6700.00
0005433102739	189	Economy	6700.00
0005433102555	189	Economy	6700.00
0005432901797	189	Economy	6700.00
0005432157533	189	Economy	6700.00
0005432920175	189	Economy	6700.00
0005433102765	189	Economy	6700.00
0005432901750	189	Economy	6700.00
0005433102697	189	Economy	6700.00
0005432920178	189	Economy	6700.00
0005433102776	189	Economy	6700.00
0005432901868	189	Economy	6700.00
0005432677615	189	Economy	6700.00
0005432677631	189	Economy	6700.00
0005433102554	189	Economy	6700.00
0005432901766	189	Economy	6700.00
0005432901861	189	Economy	6700.00
0005432901845	189	Economy	6700.00
0005432901824	189	Economy	6700.00
0005433102678	189	Economy	6700.00
0005432920176	189	Economy	6700.00
0005433102829	189	Economy	6700.00
0005433102744	189	Economy	6700.00
0005433102722	189	Economy	6700.00
0005432818072	190	Business	20000.00
0005433477002	190	Business	20000.00
0005432262860	190	Business	20000.00
0005433476995	190	Business	20000.00
0005433476998	190	Business	20000.00
0005432818080	190	Business	20000.00
0005433477004	190	Business	20000.00
0005433476992	190	Business	20000.00
0005433690945	190	Business	20000.00
0005432753341	190	Business	20000.00
0005432262855	190	Business	20000.00
0005432262851	190	Business	20000.00
0005432289055	190	Business	20000.00
0005432818062	190	Business	20000.00
0005432262832	190	Business	20000.00
0005432818086	190	Business	20000.00
0005432818078	190	Business	20000.00
0005432262836	190	Business	20000.00
0005432262848	190	Business	20000.00
0005433477008	190	Business	20000.00
0005432262842	190	Business	20000.00
0005433687731	190	Economy	7300.00
0005433476996	190	Economy	7300.00
0005432262840	190	Economy	7300.00
0005432262837	190	Economy	7300.00
0005432262820	190	Economy	6700.00
0005432262819	190	Economy	6700.00
0005433476991	190	Economy	6700.00
0005433477009	190	Economy	6700.00
0005432262854	190	Economy	6700.00
0005432262818	190	Economy	6700.00
0005433476997	190	Economy	6700.00
0005432818088	190	Economy	6700.00
0005432262834	190	Economy	6700.00
0005432262831	190	Economy	6700.00
0005434153558	190	Economy	6700.00
0005432818075	190	Economy	6700.00
0005432818068	190	Economy	6700.00
0005432756872	190	Economy	6700.00
0005432818063	190	Economy	6700.00
0005433477014	190	Economy	6700.00
0005432262847	190	Economy	6700.00
0005432818073	190	Economy	6700.00
0005432262824	190	Economy	6700.00
0005432818085	190	Economy	6700.00
0005432262835	190	Economy	6700.00
0005432818070	190	Economy	6700.00
0005432818082	190	Economy	6700.00
0005434153560	190	Economy	6700.00
0005432262828	190	Economy	6700.00
0005432289056	190	Economy	6700.00
0005433690946	190	Economy	6700.00
0005432818092	190	Economy	6700.00
0005433477013	190	Economy	6700.00
0005432818091	190	Economy	6700.00
0005432262859	190	Economy	6700.00
0005433477005	190	Economy	6700.00
0005432262863	190	Economy	6700.00
0005433477010	190	Economy	6700.00
0005432262839	190	Economy	6700.00
0005432262841	190	Economy	6700.00
0005432262853	190	Economy	6700.00
0005433690952	190	Economy	6700.00
0005432818071	190	Economy	6700.00
0005432262849	190	Economy	6700.00
0005432262826	190	Economy	6700.00
0005432262833	190	Economy	6700.00
0005433477006	190	Economy	6700.00
0005432262830	190	Economy	6700.00
0005432262845	190	Economy	7300.00
0005434152852	190	Economy	7300.00
0005432262825	190	Economy	6700.00
0005432753338	190	Economy	6700.00
0005433477012	190	Economy	6700.00
0005432262850	190	Economy	6700.00
0005432818074	190	Economy	6700.00
0005432262843	190	Economy	6700.00
0005432262822	190	Economy	6700.00
0005432818076	190	Economy	6700.00
0005432818090	190	Economy	6700.00
0005433477001	190	Economy	6700.00
0005432262827	190	Economy	6700.00
0005433477007	190	Economy	6700.00
0005432262821	190	Economy	6700.00
0005432262829	190	Economy	6700.00
0005432818067	190	Economy	6700.00
0005433476990	190	Economy	6700.00
0005432262838	190	Economy	6700.00
0005432262846	190	Economy	6700.00
0005434152853	190	Economy	6700.00
0005432262861	190	Economy	6700.00
0005432262858	190	Economy	6700.00
0005432753346	190	Economy	6700.00
0005433477000	190	Economy	6700.00
0005432818083	190	Economy	6700.00
0005433476993	190	Economy	6700.00
0005432818084	190	Economy	6700.00
0005432262856	190	Economy	6700.00
0005432289054	190	Economy	6700.00
0005432818065	190	Economy	6700.00
0005432818081	190	Economy	6700.00
0005432262857	190	Economy	6700.00
0005432818069	190	Economy	6700.00
0005432289052	190	Economy	6700.00
0005432262862	190	Economy	6700.00
0005432262852	190	Economy	6700.00
0005432262823	190	Economy	6700.00
0005432207712	190	Economy	6700.00
0005432207713	190	Economy	6700.00
0005433476994	190	Economy	6700.00
0005432756869	190	Economy	6700.00
0005432756871	190	Economy	6700.00
0005433477003	190	Economy	6700.00
0005434153559	190	Economy	6700.00
0005432818077	190	Economy	6700.00
0005433477011	190	Economy	6700.00
0005432818087	190	Economy	6700.00
0005432818089	190	Economy	6700.00
0005432818064	190	Economy	6700.00
0005432818066	190	Economy	6700.00
0005433476999	190	Economy	6700.00
0005432289053	190	Economy	6700.00
0005432818079	190	Economy	6700.00
0005432262844	190	Economy	6700.00
0005432020818	8002	Business	20000.00
0005433103247	8002	Business	20000.00
0005432020802	8002	Business	20000.00
0005432920274	8002	Business	20000.00
0005433103233	8002	Business	20000.00
0005433103241	8002	Business	20000.00
0005432751595	8002	Business	20000.00
0005433103230	8002	Business	20000.00
0005432020795	8002	Business	20000.00
0005433103216	8002	Business	20000.00
0005432020803	8002	Business	20000.00
0005433103251	8002	Business	20000.00
0005433103252	8002	Business	20000.00
0005432020812	8002	Business	20000.00
0005432920294	8002	Business	20000.00
0005432020813	8002	Business	20000.00
0005432020809	8002	Business	20000.00
0005433103242	8002	Business	20000.00
0005432020796	8002	Business	20000.00
0005432020820	8002	Economy	7300.00
0005432020811	8002	Economy	7300.00
0005432920278	8002	Economy	7300.00
0005432044582	8002	Economy	7300.00
0005432753370	8002	Economy	6700.00
0005432751596	8002	Economy	6700.00
0005433103220	8002	Economy	6700.00
0005432677658	8002	Economy	6700.00
0005433103236	8002	Economy	6700.00
0005432677655	8002	Economy	6700.00
0005432020822	8002	Economy	6700.00
0005432920292	8002	Economy	6700.00
0005432045654	8002	Economy	6700.00
0005432044581	8002	Economy	6700.00
0005433103228	8002	Economy	6700.00
0005433103238	8002	Economy	6700.00
0005433103232	8002	Economy	6700.00
0005432392062	8002	Economy	6700.00
0005432920289	8002	Economy	6700.00
0005433103226	8002	Economy	6700.00
0005433103218	8002	Economy	6700.00
0005433103235	8002	Economy	6700.00
0005433103221	8002	Economy	6700.00
0005433103224	8002	Economy	6700.00
0005432920277	8002	Economy	6700.00
0005432920281	8002	Economy	6700.00
0005432020797	8002	Economy	6700.00
0005432020817	8002	Economy	6700.00
0005433103231	8002	Economy	6700.00
0005433103234	8002	Economy	6700.00
0005433103237	8002	Economy	6700.00
0005432920287	8002	Economy	6700.00
0005432392061	8002	Economy	6700.00
0005432020800	8002	Economy	6700.00
0005432753371	8002	Economy	6700.00
0005432677656	8002	Economy	6700.00
0005432020804	8002	Economy	6700.00
0005433103222	8002	Economy	6700.00
0005433103229	8002	Economy	6700.00
0005433103240	8002	Economy	6700.00
0005432020801	8002	Economy	6700.00
0005432920285	8002	Economy	7300.00
0005432677654	8002	Economy	7300.00
0005433103255	8002	Economy	7300.00
0005433103217	8002	Economy	7300.00
0005433103253	8002	Economy	7300.00
0005432020807	8002	Economy	6700.00
0005432920284	8002	Economy	6700.00
0005432020808	8002	Economy	6700.00
0005432920280	8002	Economy	6700.00
0005433103245	8002	Economy	6700.00
0005432920276	8002	Economy	6700.00
0005433103246	8002	Economy	6700.00
0005433103256	8002	Economy	6700.00
0005433103243	8002	Economy	6700.00
0005433103248	8002	Economy	6700.00
0005432920282	8002	Economy	6700.00
0005432045653	8002	Economy	6700.00
0005433103259	8002	Economy	6700.00
0005432020810	8002	Economy	6700.00
0005433103257	8002	Economy	6700.00
0005433103227	8002	Economy	6700.00
0005432020814	8002	Economy	6700.00
0005432920290	8002	Economy	6700.00
0005432920283	8002	Economy	6700.00
0005433103260	8002	Economy	6700.00
0005432392060	8002	Economy	6700.00
0005432020805	8002	Economy	6700.00
0005432020806	8002	Economy	6700.00
0005432020816	8002	Economy	6700.00
0005432920275	8002	Economy	6700.00
0005433103215	8002	Economy	6700.00
0005432920273	8002	Economy	6700.00
0005432020798	8002	Economy	6700.00
0005432020819	8002	Economy	6700.00
0005433103219	8002	Economy	6700.00
0005433103223	8002	Economy	6700.00
0005432920288	8002	Economy	6700.00
0005432920291	8002	Economy	6700.00
0005433103254	8002	Economy	6700.00
0005432044583	8002	Economy	6700.00
0005433103244	8002	Economy	6700.00
0005432677657	8002	Economy	6700.00
0005432920286	8002	Economy	6700.00
0005433103239	8002	Economy	6700.00
0005433103225	8002	Economy	6700.00
0005432020821	8002	Economy	6700.00
0005432920293	8002	Economy	6700.00
0005432920279	8002	Economy	6700.00
0005433103249	8002	Economy	6700.00
0005433103250	8002	Economy	6700.00
0005433103258	8002	Economy	6700.00
0005433103261	8002	Economy	6700.00
0005432020815	8002	Economy	6700.00
0005432020799	8002	Economy	6700.00
0005432817737	8001	Business	20000.00
0005432817824	8001	Business	20000.00
0005432817838	8001	Business	20000.00
0005432817897	8001	Business	20000.00
0005432817727	8001	Business	20000.00
0005432818031	8001	Business	20000.00
0005432817738	8001	Business	20000.00
0005432817839	8001	Business	20000.00
0005432817872	8001	Economy	7300.00
0005432817812	8001	Economy	7300.00
0005432817793	8001	Economy	7300.00
0005432817767	8001	Economy	6700.00
0005432817798	8001	Economy	6700.00
0005432817905	8001	Economy	6700.00
0005432817768	8001	Economy	6700.00
0005432817716	8001	Economy	6700.00
0005432817726	8001	Economy	6700.00
0005432901974	8001	Economy	6700.00
0005432901963	8001	Economy	6700.00
0005432817900	8001	Economy	6700.00
0005432817840	8001	Economy	6700.00
0005432901962	8001	Economy	6700.00
0005432817924	8001	Economy	6700.00
0005432901971	8001	Economy	6700.00
0005432901960	8001	Economy	6700.00
0005432901959	8001	Economy	6700.00
0005432817813	8001	Economy	6700.00
0005432817714	8001	Economy	6700.00
0005432901966	8001	Economy	6700.00
0005432817820	8001	Economy	6700.00
0005432901969	8001	Economy	6700.00
0005432901976	8001	Economy	7300.00
0005432817920	8001	Economy	7300.00
0005432901965	8001	Economy	6700.00
0005432817879	8001	Economy	6700.00
0005432002119	8001	Economy	6700.00
0005432817895	8001	Economy	6700.00
0005432817894	8001	Economy	6700.00
0005432901973	8001	Economy	6700.00
0005432817636	8001	Economy	6700.00
0005432817805	8001	Economy	6700.00
0005432901968	8001	Economy	6700.00
0005432901970	8001	Economy	6700.00
0005432817831	8001	Economy	6700.00
0005432817853	8001	Economy	6700.00
0005432901975	8001	Economy	6700.00
0005432817822	8001	Economy	6700.00
0005432901964	8001	Economy	6700.00
0005432817823	8001	Economy	6700.00
0005432817788	8001	Economy	6700.00
0005432002118	8001	Economy	6700.00
0005432817847	8001	Economy	6700.00
0005432817904	8001	Economy	6700.00
0005432901972	8001	Economy	6700.00
0005432817808	8001	Economy	6700.00
0005432817901	8001	Economy	6700.00
0005432901961	8001	Economy	6700.00
0005432817903	8001	Economy	6700.00
0005432901967	8001	Economy	6700.00
0005432817792	8001	Economy	6700.00
0005432817799	8001	Economy	6700.00
0005434175805	9647	Economy	6900.00
0005433870776	9647	Economy	6900.00
0005434175815	9647	Economy	6900.00
0005434175796	9647	Economy	6900.00
0005434175797	9647	Economy	6900.00
0005434175810	9647	Economy	6900.00
0005434175839	32341	Economy	6900.00
0005434175843	32341	Economy	6900.00
0005434175840	32341	Economy	6900.00
0005433870751	32341	Economy	6900.00
0005434175838	32341	Economy	6900.00
0005433870760	32341	Economy	6900.00
0005434175842	32341	Economy	6900.00
0005434175841	32341	Economy	6900.00
0005433870759	32341	Economy	6900.00
0005434880135	3462	Business	35000.00
0005434938548	3462	Business	35000.00
0005435127227	3462	Business	35000.00
0005432800049	3462	Business	35000.00
0005435127195	3462	Business	35000.00
0005434938539	3462	Business	35000.00
0005434880188	3462	Business	35000.00
0005434880186	3462	Business	35000.00
0005434880197	3462	Business	35000.00
0005435127216	3462	Business	35000.00
0005434938553	3462	Business	35000.00
0005432800051	3462	Business	35000.00
0005434880125	3462	Business	35000.00
0005435626552	3462	Business	35000.00
0005434880209	3462	Business	35000.00
0005434880124	3462	Business	35000.00
0005435626550	3462	Business	35000.00
0005435127193	3462	Business	35000.00
0005434880152	3462	Comfort	19900.00
0005434427205	3462	Comfort	19900.00
0005434880168	3462	Comfort	19900.00
0005434880141	3462	Comfort	19900.00
0005435626555	3462	Comfort	19900.00
0005434880143	3462	Comfort	19900.00
0005435127215	3462	Comfort	19900.00
0005434427215	3462	Comfort	19900.00
0005435127214	3462	Comfort	19900.00
0005435127191	3462	Comfort	19900.00
0005435127194	3462	Comfort	19900.00
0005434880196	3462	Comfort	19900.00
0005434880156	3462	Comfort	19900.00
0005435902879	3462	Comfort	19900.00
0005432800043	3462	Comfort	19900.00
0005432800040	3462	Comfort	19900.00
0005434427216	3462	Comfort	19900.00
0005432800036	3462	Comfort	19900.00
0005434880203	3462	Comfort	19900.00
0005435902918	3462	Comfort	19900.00
0005435914702	3462	Comfort	19900.00
0005435127226	3462	Comfort	19900.00
0005432800026	3462	Comfort	19900.00
0005434938543	3462	Comfort	19900.00
0005435127220	3462	Comfort	19900.00
0005432800044	3462	Comfort	19900.00
0005434880157	3462	Comfort	19900.00
0005435127208	3462	Comfort	19900.00
0005434880174	3462	Economy	11700.00
0005435127201	3462	Economy	11700.00
0005434880139	3462	Economy	11700.00
0005432800038	3462	Economy	11700.00
0005434880192	3462	Economy	11700.00
0005432800024	3462	Economy	11700.00
0005434880189	3462	Economy	11700.00
0005434880154	3462	Economy	11700.00
0005434938547	3462	Economy	11700.00
0005434427222	3462	Economy	11700.00
0005434880145	3462	Economy	11700.00
0005434938540	3462	Economy	11700.00
0005432800035	3462	Economy	11700.00
0005435902958	3462	Economy	11700.00
0005434880136	3462	Economy	11700.00
0005434880198	3462	Economy	11700.00
0005435626545	3462	Economy	11700.00
0005434880180	3462	Economy	11700.00
0005435127211	3462	Economy	11700.00
0005435127221	3462	Economy	11700.00
0005432800029	3462	Economy	11700.00
0005434880204	3462	Economy	11700.00
0005435127204	3462	Economy	11700.00
0005435127196	3462	Economy	11700.00
0005434880163	3462	Economy	11700.00
0005434880181	3462	Economy	11700.00
0005435902943	3462	Economy	11700.00
0005434880205	3462	Economy	11700.00
0005432800042	3462	Economy	11700.00
0005434427228	3462	Economy	11700.00
0005435626551	3462	Economy	11700.00
0005435626558	3462	Economy	11700.00
0005434880185	3462	Economy	11700.00
0005435626544	3462	Economy	11700.00
0005434880208	3462	Economy	11700.00
0005434427214	3462	Economy	11700.00
0005434427207	3462	Economy	11700.00
0005434880159	3462	Economy	11700.00
0005434880207	3462	Economy	11700.00
0005435626548	3462	Economy	11700.00
0005434938541	3462	Economy	11700.00
0005432800031	3462	Economy	11700.00
0005435626549	3462	Economy	11700.00
0005435127197	3462	Economy	11700.00
0005432613945	3462	Economy	11700.00
0005434880131	3462	Economy	11700.00
0005434880153	3462	Economy	11700.00
0005434880133	3462	Economy	11700.00
0005434427229	3462	Economy	11700.00
0005435127212	3462	Economy	11700.00
0005434427208	3462	Economy	11700.00
0005434938545	3462	Economy	12800.00
0005435127207	3462	Economy	11700.00
0005434880137	3462	Economy	12800.00
0005434880127	3462	Economy	11700.00
0005435902939	3462	Economy	11700.00
0005434880166	3462	Economy	11700.00
0005432800027	3462	Economy	11700.00
0005435127213	3462	Economy	11700.00
0005435902889	3462	Economy	11700.00
0005432188674	3462	Economy	11700.00
0005434880182	3462	Economy	11700.00
0005435127206	3462	Economy	11700.00
0005432188676	3462	Economy	11700.00
0005434880202	3462	Economy	11700.00
0005434880172	3462	Economy	11700.00
0005434880126	3462	Economy	11700.00
0005434427227	3462	Economy	11700.00
0005434880162	3462	Economy	11700.00
0005434880128	3462	Economy	11700.00
0005434427213	3462	Economy	11700.00
0005434880165	3462	Economy	11700.00
0005435127210	3462	Economy	11700.00
0005434880194	3462	Economy	11700.00
0005434938552	3462	Economy	11700.00
0005432613946	3462	Economy	11700.00
0005432188675	3462	Economy	11700.00
0005434938550	3462	Economy	11700.00
0005434880149	3462	Economy	11700.00
0005434427219	3462	Economy	11700.00
0005434880190	3462	Economy	11700.00
0005432183512	3462	Economy	11700.00
0005432613947	3462	Economy	11700.00
0005434880171	3462	Economy	11700.00
0005435127217	3462	Economy	11700.00
0005434880120	3462	Economy	11700.00
0005434880119	3462	Economy	11700.00
0005435902996	3462	Economy	11700.00
0005434880122	3462	Economy	11700.00
0005434938536	3462	Economy	11700.00
0005434938534	3462	Economy	11700.00
0005435626547	3462	Economy	11700.00
0005435626559	3462	Economy	11700.00
0005434427224	3462	Economy	11700.00
0005434938537	3462	Economy	11700.00
0005434880212	3462	Economy	11700.00
0005434427226	3462	Economy	11700.00
0005435127192	3462	Economy	11700.00
0005432800025	3462	Economy	11700.00
0005432800037	3462	Economy	11700.00
0005434880183	3462	Economy	11700.00
0005434880187	3462	Economy	11700.00
0005432800030	3462	Economy	11700.00
0005435127200	3462	Economy	11700.00
0005434427202	3462	Economy	11700.00
0005435127219	3462	Economy	11700.00
0005432800034	3462	Economy	11700.00
0005434880170	3462	Economy	11700.00
0005432611782	3462	Economy	11700.00
0005435902972	3462	Economy	11700.00
0005434880130	3462	Economy	11700.00
0005435902903	3462	Economy	11700.00
0005435626557	3462	Economy	11700.00
0005434938542	3462	Economy	11700.00
0005434427201	3462	Economy	11700.00
0005435127223	3462	Economy	11700.00
0005435626560	3462	Economy	11700.00
0005434427230	3462	Economy	11700.00
0005434427225	3462	Economy	11700.00
0005434427218	3462	Economy	11700.00
0005434880118	3462	Economy	11700.00
0005435902754	3462	Economy	11700.00
0005435626543	3462	Economy	11700.00
0005434880175	3462	Economy	11700.00
0005434880132	3462	Economy	11700.00
0005435903000	3462	Economy	11700.00
0005432800032	3462	Economy	11700.00
0005434880158	3462	Economy	11700.00
0005434880206	3462	Economy	11700.00
0005434880200	3462	Economy	11700.00
0005435913963	3462	Economy	11700.00
0005434880177	3462	Economy	11700.00
0005434880193	3462	Economy	11700.00
0005434427217	3462	Economy	12800.00
0005434880213	3462	Economy	11700.00
0005435841101	3462	Economy	12800.00
0005434427206	3462	Economy	12800.00
0005434880199	3462	Economy	12800.00
0005435127205	3462	Economy	11700.00
0005435902995	3462	Economy	12800.00
0005434880184	3462	Economy	11700.00
0005434880129	3462	Economy	11700.00
0005434938551	3462	Economy	11700.00
0005435127190	3462	Economy	11700.00
0005434427200	3462	Economy	11700.00
0005434880201	3462	Economy	11700.00
0005434880195	3462	Economy	11700.00
0005434427209	3462	Economy	11700.00
0005434880121	3462	Economy	11700.00
0005434880211	3462	Economy	11700.00
0005434880142	3462	Economy	11700.00
0005435626546	3462	Economy	11700.00
0005432800047	3462	Economy	11700.00
0005432800039	3462	Economy	11700.00
0005434880176	3462	Economy	11700.00
0005434880178	3462	Economy	11700.00
0005432800041	3462	Economy	11700.00
0005434880151	3462	Economy	11700.00
0005435626554	3462	Economy	11700.00
0005435626561	3462	Economy	11700.00
0005434880140	3462	Economy	11700.00
0005434880147	3462	Economy	11700.00
0005432800028	3462	Economy	11700.00
0005435127198	3462	Economy	11700.00
0005434938546	3462	Economy	11700.00
0005435127199	3462	Economy	11700.00
0005434938544	3462	Economy	11700.00
0005434427221	3462	Economy	11700.00
0005434427220	3462	Economy	11700.00
0005432613948	3462	Economy	11700.00
0005434427211	3462	Economy	11700.00
0005434880155	3462	Economy	11700.00
0005435902755	3462	Economy	11700.00
0005434880161	3462	Economy	11700.00
0005434938533	3462	Economy	11700.00
0005434427212	3462	Economy	11700.00
0005434880150	3462	Economy	11700.00
0005434427210	3462	Economy	11700.00
0005434938535	3462	Economy	11700.00
0005434938538	3462	Economy	11700.00
0005434427223	3462	Economy	11700.00
0005435127222	3462	Economy	11700.00
0005434880164	3462	Economy	11700.00
0005434427204	3462	Economy	11700.00
0005432611783	3462	Economy	11700.00
0005435902917	3462	Economy	11700.00
0005434880117	3462	Economy	11700.00
0005435127209	3462	Economy	11700.00
0005432800050	3462	Economy	11700.00
0005434880116	3462	Economy	11700.00
0005432188677	3462	Economy	11700.00
0005435127224	3462	Economy	11700.00
0005432611781	3462	Economy	11700.00
0005432800046	3462	Economy	11700.00
0005432800033	3462	Economy	11700.00
0005434938549	3462	Economy	11700.00
0005435127218	3462	Economy	11700.00
0005434880179	3462	Economy	11700.00
0005434880173	3462	Economy	11700.00
0005434880191	3462	Economy	11700.00
0005435902916	3462	Economy	11700.00
0005434880146	3462	Economy	11700.00
0005432800048	3462	Economy	11700.00
0005435626553	3462	Economy	11700.00
0005434880148	3462	Economy	11700.00
0005434880160	3462	Economy	11700.00
0005434880167	3462	Economy	11700.00
0005434880144	3462	Economy	11700.00
0005435127202	3462	Economy	11700.00
0005435127225	3462	Economy	11700.00
0005434880210	3462	Economy	11700.00
0005435626556	3462	Economy	11700.00
0005432800045	3462	Economy	11700.00
0005434880134	3462	Economy	11700.00
0005434427203	3462	Economy	11700.00
0005435902890	3462	Economy	11700.00
0005434880123	3462	Economy	11700.00
0005435127203	3462	Economy	11700.00
0005435127228	3462	Economy	11700.00
0005434880169	3462	Economy	11700.00
0005434880138	3462	Economy	11700.00
0005435841100	3462	Economy	11700.00
0005435126761	14574	Business	35000.00
0005435127013	14574	Business	35000.00
0005434879681	14574	Business	35000.00
0005434879499	14574	Business	35000.00
0005434879073	14574	Business	35000.00
0005434938417	14574	Business	35000.00
0005434879568	14574	Business	35000.00
0005434879369	14574	Business	35000.00
0005432799852	14574	Business	35000.00
0005435126834	14574	Business	35000.00
0005432799763	14574	Business	35000.00
0005434879609	14574	Business	35000.00
0005434879504	14574	Business	35000.00
0005434879339	14574	Business	35000.00
0005434879406	14574	Business	35000.00
0005434879304	14574	Comfort	19900.00
0005434879285	14574	Comfort	19900.00
0005434879360	14574	Comfort	19900.00
0005435626339	14574	Comfort	19900.00
0005435126866	14574	Comfort	19900.00
0005434879546	14574	Comfort	19900.00
0005435126772	14574	Comfort	19900.00
0005435126692	14574	Comfort	19900.00
0005435626378	14574	Comfort	19900.00
0005434426993	14574	Comfort	19900.00
0005434426875	14574	Comfort	19900.00
0005434879164	14574	Comfort	19900.00
0005435126762	14574	Comfort	19900.00
0005435126867	14574	Comfort	19900.00
0005432799837	14574	Comfort	19900.00
0005435903065	14574	Comfort	19900.00
0005434879682	14574	Comfort	19900.00
0005434879459	14574	Comfort	19900.00
0005432799888	14574	Comfort	19900.00
0005434938407	14574	Comfort	19900.00
0005435626351	14574	Comfort	19900.00
0005434879488	14574	Comfort	19900.00
0005435626319	14574	Comfort	19900.00
0005434879035	14574	Comfort	19900.00
0005435126791	14574	Comfort	19900.00
0005434938346	14574	Comfort	19900.00
0005435626368	14574	Comfort	19900.00
0005434879610	14574	Comfort	19900.00
0005434879151	14574	Comfort	19900.00
0005434879519	14574	Comfort	19900.00
0005435626337	14574	Comfort	19900.00
0005434879366	14574	Comfort	19900.00
0005435841839	14574	Comfort	19900.00
0005434879290	14574	Comfort	19900.00
0005435903059	14574	Comfort	19900.00
0005435126991	14574	Comfort	19900.00
0005434879346	14574	Comfort	19900.00
0005434426992	14574	Comfort	19900.00
0005434426937	14574	Economy	11700.00
0005434879471	14574	Economy	11700.00
0005432611758	14574	Economy	11700.00
0005435126724	14574	Economy	11700.00
0005432799773	14574	Economy	11700.00
0005434879250	14574	Economy	11700.00
0005434879354	14574	Economy	11700.00
0005434879501	14574	Economy	11700.00
0005432799842	14574	Economy	11700.00
0005432799782	14574	Economy	11700.00
0005434879288	14574	Economy	11700.00
0005435903069	14574	Economy	11700.00
0005434879440	14574	Economy	11700.00
0005434427076	14574	Economy	11700.00
0005432799879	14574	Economy	11700.00
0005434938416	14574	Economy	11700.00
0005434426839	14574	Economy	11700.00
0005434879476	14574	Economy	11700.00
0005435626362	14574	Economy	11700.00
0005434879611	14574	Economy	11700.00
0005434938358	14574	Economy	11700.00
0005434426838	14574	Economy	11700.00
0005432799889	14574	Economy	11700.00
0005435626371	14574	Economy	11700.00
0005434879334	14574	Economy	11700.00
0005435626350	14574	Economy	11700.00
0005434879318	14574	Economy	11700.00
0005434426914	14574	Economy	11700.00
0005434879340	14574	Economy	11700.00
0005435126864	14574	Economy	11700.00
0005435126744	14574	Economy	11700.00
0005434879348	14574	Economy	11700.00
0005434879380	14574	Economy	11700.00
0005435842343	14574	Economy	11700.00
0005435903068	14574	Economy	11700.00
0005434426943	14574	Economy	11700.00
0005435126973	14574	Economy	11700.00
0005435626375	14574	Economy	11700.00
0005434879403	14574	Economy	11700.00
0005432611752	14574	Economy	11700.00
0005435126797	14574	Economy	11700.00
0005434879508	14574	Economy	11700.00
0005434879433	14574	Economy	11700.00
0005435903063	14574	Economy	11700.00
0005432799885	14574	Economy	12800.00
0005434427074	14574	Economy	12800.00
0005434938359	14574	Economy	12800.00
0005432799838	14574	Economy	11700.00
0005435126691	14574	Economy	11700.00
0005435126725	14574	Economy	12800.00
0005435903066	14574	Economy	11700.00
0005434879284	14574	Economy	12800.00
0005432799725	14574	Economy	11700.00
0005435126868	14574	Economy	11700.00
0005434879071	14574	Economy	11700.00
0005434879255	14574	Economy	11700.00
0005434879846	14574	Economy	11700.00
0005435126847	14574	Economy	11700.00
0005434879251	14574	Economy	11700.00
0005435126893	14574	Economy	11700.00
0005434879139	14574	Economy	11700.00
0005434427018	14574	Economy	11700.00
0005435126790	14574	Economy	11700.00
0005435126757	14574	Economy	11700.00
0005434879698	14574	Economy	11700.00
0005434879697	14574	Economy	11700.00
0005434879847	14574	Economy	11700.00
0005434879378	14574	Economy	11700.00
0005434878949	14574	Economy	11700.00
0005432799772	14574	Economy	11700.00
0005434878958	14574	Economy	11700.00
0005432799859	14574	Economy	11700.00
0005434879341	14574	Economy	11700.00
0005434879520	14574	Economy	11700.00
0005434879328	14574	Economy	11700.00
0005434879625	14574	Economy	11700.00
0005435126878	14574	Economy	11700.00
0005434879608	14574	Economy	11700.00
0005434938415	14574	Economy	11700.00
0005435126743	14574	Economy	11700.00
0005434879506	14574	Economy	11700.00
0005434426898	14574	Economy	11700.00
0005435626376	14574	Economy	11700.00
0005434879569	14574	Economy	11700.00
0005435126786	14574	Economy	11700.00
0005435126694	14574	Economy	11700.00
0005435126765	14574	Economy	11700.00
0005432799871	14574	Economy	11700.00
0005434427075	14574	Economy	11700.00
0005435126827	14574	Economy	11700.00
0005435903062	14574	Economy	11700.00
0005434879547	14574	Economy	11700.00
0005435903073	14574	Economy	11700.00
0005434879666	14574	Economy	11700.00
0005435626321	14574	Economy	11700.00
0005434879439	14574	Economy	11700.00
0005434426928	14574	Economy	11700.00
0005434426996	14574	Economy	11700.00
0005434879321	14574	Economy	11700.00
0005434879370	14574	Economy	11700.00
0005435126869	14574	Economy	11700.00
0005434879402	14574	Economy	11700.00
0005434879126	14574	Economy	11700.00
0005434426854	14574	Economy	11700.00
0005434426855	14574	Economy	11700.00
0005434879117	14574	Economy	11700.00
0005434426860	14574	Economy	11700.00
0005434879677	14574	Economy	11700.00
0005434427026	14574	Economy	11700.00
0005434879253	14574	Economy	11700.00
0005435126789	14574	Economy	11700.00
0005434878797	14574	Economy	11700.00
0005435126755	14574	Economy	11700.00
0005434879287	14574	Economy	11700.00
0005434879595	14574	Economy	11700.00
0005432799858	14574	Economy	11700.00
0005434879313	14574	Economy	11700.00
0005434426856	14574	Economy	11700.00
0005432799736	14574	Economy	11700.00
0005434426925	14574	Economy	11700.00
0005434879494	14574	Economy	11700.00
0005434938342	14574	Economy	11700.00
0005435903076	14574	Economy	11700.00
0005432799694	14574	Economy	11700.00
0005434938400	14574	Economy	11700.00
0005434879118	14574	Economy	11700.00
0005434879286	14574	Economy	11700.00
0005434879453	14574	Economy	11700.00
0005435126843	14574	Economy	11700.00
0005434879640	14574	Economy	11700.00
0005435626369	14574	Economy	11700.00
0005434879371	14574	Economy	11700.00
0005435903064	14574	Economy	11700.00
0005435126766	14574	Economy	11700.00
0005435126972	14574	Economy	11700.00
0005434879767	14574	Economy	11700.00
0005432611765	14574	Economy	11700.00
0005434879152	14574	Economy	11700.00
0005434879254	14574	Economy	11700.00
0005435126773	14574	Economy	12800.00
0005432799823	14574	Economy	12800.00
0005434879329	14574	Economy	12800.00
0005435126649	14574	Economy	12800.00
0005432799775	14574	Economy	12800.00
0005435126689	14574	Economy	11700.00
0005435126758	14574	Economy	11700.00
0005434427025	14574	Economy	11700.00
0005432799860	14574	Economy	11700.00
0005434879163	14574	Economy	11700.00
0005434879589	14574	Economy	11700.00
0005435126852	14574	Economy	11700.00
0005434879500	14574	Economy	11700.00
0005434879766	14574	Economy	11700.00
0005434938405	14574	Economy	11700.00
0005435626320	14574	Economy	11700.00
0005432799726	14574	Economy	11700.00
0005434879379	14574	Economy	11700.00
0005435626361	14574	Economy	11700.00
0005434878947	14574	Economy	11700.00
0005434938295	14574	Economy	11700.00
0005432611764	14574	Economy	11700.00
0005432059546	14574	Economy	11700.00
0005434879355	14574	Economy	11700.00
0005435903067	14574	Economy	11700.00
0005434879466	14574	Economy	11700.00
0005434427014	14574	Economy	11700.00
0005434426927	14574	Economy	11700.00
0005435903072	14574	Economy	11700.00
0005434879215	14574	Economy	11700.00
0005434426861	14574	Economy	11700.00
0005434426968	14574	Economy	11700.00
0005435842344	14574	Economy	11700.00
0005432799799	14574	Economy	11700.00
0005435126844	14574	Economy	11700.00
0005432799737	14574	Economy	11700.00
0005434879140	14574	Economy	11700.00
0005434426924	14574	Economy	11700.00
0005435903074	14574	Economy	11700.00
0005435626374	14574	Economy	11700.00
0005434879656	14574	Economy	11700.00
0005434879166	14574	Economy	11700.00
0005434878888	14574	Economy	11700.00
0005434879231	14574	Economy	11700.00
0005432799816	14574	Economy	11700.00
0005434879498	14574	Economy	11700.00
0005432799878	14574	Economy	11700.00
0005434879427	14574	Economy	11700.00
0005434879270	14574	Economy	11700.00
0005432799678	14574	Economy	11700.00
0005435903061	14574	Economy	11700.00
0005434879303	14574	Economy	11700.00
0005435903060	14574	Economy	11700.00
0005435903070	14574	Economy	11700.00
0005434938406	14574	Economy	11700.00
0005435126836	14574	Economy	11700.00
0005435126835	14574	Economy	11700.00
0005434938343	14574	Economy	11700.00
0005434879432	14574	Economy	11700.00
0005434879407	14574	Economy	11700.00
0005435903075	14574	Economy	11700.00
0005435626367	14574	Economy	11700.00
0005435903071	14574	Economy	11700.00
0005434426899	14574	Economy	11700.00
0005434878879	14574	Economy	11700.00
0005434879230	14574	Economy	11700.00
0005434879249	14574	Economy	11700.00
0005434879678	14574	Economy	11700.00
0005435126785	14574	Economy	11700.00
0005434879588	14574	Economy	11700.00
0005435126807	14574	Economy	11700.00
0005432799691	14574	Economy	11700.00
0005435126933	14574	Economy	11700.00
0005434879181	14574	Economy	11700.00
0005432799870	14574	Economy	11700.00
0005434879426	14574	Economy	11700.00
0005434426825	14574	Economy	11700.00
0005435126990	14574	Economy	11700.00
0005434879322	14574	Economy	11700.00
0005434878798	14574	Economy	11700.00
0005434879502	14574	Economy	11700.00
0005434879367	14574	Economy	11700.00
0005434879289	14574	Economy	11700.00
0005434325889	3635	Economy	16300.00
0005434325885	3635	Economy	16300.00
0005434325888	3635	Economy	16300.00
0005434325886	3635	Economy	14800.00
0005434325881	3635	Economy	14800.00
0005434325891	3635	Economy	14800.00
0005434325887	3635	Economy	14800.00
0005435889946	3635	Economy	14800.00
0005435889972	3635	Economy	14800.00
0005434325883	3635	Economy	14800.00
0005435889978	3635	Economy	14800.00
0005435889979	3635	Economy	14800.00
0005435889994	3635	Economy	14800.00
0005434325892	3635	Economy	14800.00
0005434312361	3635	Economy	14800.00
0005435889974	3635	Economy	14800.00
0005434312360	3635	Economy	14800.00
0005434325884	3635	Economy	14800.00
0005434325890	3635	Economy	14800.00
0005434325882	3635	Economy	14800.00
0005434325802	15629	Economy	16300.00
0005434325791	15629	Economy	14800.00
0005434325796	15629	Economy	14800.00
0005435890020	15629	Economy	14800.00
0005434325730	15629	Economy	14800.00
0005434325862	15629	Economy	14800.00
0005434325789	15629	Economy	14800.00
0005434325767	15629	Economy	14800.00
0005434325781	15629	Economy	14800.00
0005434325815	15629	Economy	14800.00
0005434325816	15629	Economy	14800.00
0005435890022	15629	Economy	14800.00
0005435890018	15629	Economy	14800.00
0005435890017	15629	Economy	14800.00
0005434325790	15629	Economy	14800.00
0005434325729	15629	Economy	14800.00
0005434325792	15629	Economy	14800.00
0005434325839	15629	Economy	14800.00
0005435890019	15629	Economy	14800.00
0005434325820	15629	Economy	14800.00
0005434325776	15629	Economy	14800.00
0005435890023	15629	Economy	14800.00
0005434325777	15629	Economy	14800.00
0005435890021	15629	Economy	14800.00
0005435958003	656	Economy	4500.00
0005433420509	656	Economy	4100.00
0005435958010	656	Economy	4100.00
0005433420528	656	Economy	4100.00
0005433420473	656	Economy	4100.00
0005435958011	656	Economy	4100.00
0005433420517	656	Economy	4100.00
0005435958000	656	Economy	4100.00
0005433420532	656	Economy	4100.00
0005433420485	656	Economy	4100.00
0005433420529	656	Economy	4100.00
0005435958007	656	Economy	4100.00
0005435958005	656	Economy	4100.00
0005435958004	656	Economy	4100.00
0005435958001	656	Economy	4100.00
0005433420524	656	Economy	4100.00
0005433420488	656	Economy	4100.00
0005433420472	656	Economy	4100.00
0005433420504	656	Economy	4100.00
0005433420536	656	Economy	4100.00
0005435958008	656	Economy	4100.00
0005435958009	656	Economy	4100.00
0005435957999	656	Economy	4100.00
0005435958002	656	Economy	4100.00
0005435957998	656	Economy	4100.00
0005435957997	656	Economy	4100.00
0005435958006	656	Economy	4100.00
0005433420496	656	Economy	4100.00
0005433420581	15168	Economy	4100.00
0005435957856	15168	Economy	4100.00
0005433420575	15168	Economy	4100.00
0005433420578	15168	Economy	4100.00
0005433420579	15168	Economy	4100.00
0005433420580	15168	Economy	4100.00
0005435957876	15168	Economy	4100.00
0005433420582	15168	Economy	4100.00
0005435957813	15168	Economy	4100.00
0005435957843	15168	Economy	4100.00
0005435957814	15168	Economy	4100.00
0005435957860	15168	Economy	4100.00
0005433420577	15168	Economy	4100.00
0005433420576	15168	Economy	4100.00
0005435629431	8865	Economy	10400.00
0005434247180	8865	Economy	10400.00
0005434247190	8865	Economy	10400.00
0005435629430	8865	Economy	10400.00
0005435629429	8865	Economy	10400.00
0005435629428	8865	Economy	10400.00
0005434247199	16035	Economy	10400.00
0005435629418	16035	Economy	10400.00
0005434247201	16035	Economy	10400.00
0005434247200	16035	Economy	10400.00
0005435629419	16035	Economy	10400.00
0005434096758	11830	Economy	14700.00
0005434096763	11830	Economy	13400.00
0005434096760	11830	Economy	13400.00
0005434096757	11830	Economy	13400.00
0005434096759	11830	Economy	13400.00
0005434096769	11830	Economy	13400.00
0005434096761	11830	Economy	13400.00
0005434096762	11830	Economy	13400.00
0005435163337	4425	Economy	13400.00
0005435163342	4425	Economy	13400.00
0005435933491	4425	Economy	12200.00
0005435933492	4425	Economy	12200.00
0005435933497	4425	Economy	12200.00
0005435163335	4425	Economy	12200.00
0005435933501	4425	Economy	12200.00
0005435163341	4425	Economy	12200.00
0005435933500	4425	Economy	12200.00
0005435163339	4425	Economy	12200.00
0005435933493	4425	Economy	12200.00
0005435163336	4425	Economy	12200.00
0005435163333	4425	Economy	12200.00
0005435163334	4425	Economy	12200.00
0005435163338	4425	Economy	12200.00
0005435933489	4425	Economy	12200.00
0005435933513	4425	Economy	12200.00
0005435163340	4425	Economy	12200.00
0005435163281	29512	Economy	13400.00
0005435933522	29512	Economy	12200.00
0005435163303	29512	Economy	12200.00
0005435933526	29512	Economy	12200.00
0005435163304	29512	Economy	12200.00
0005435163309	29512	Economy	12200.00
0005435933523	29512	Economy	12200.00
0005435163284	29512	Economy	12200.00
0005435163280	29512	Economy	12200.00
0005435163292	29512	Economy	12200.00
0005435933524	29512	Economy	12200.00
0005435933525	29512	Economy	12200.00
0005435163272	29512	Economy	12200.00
0005435933527	29512	Economy	12200.00
0005435163270	29512	Economy	12200.00
0005435797764	2859	Business	12600.00
0005435797767	2859	Business	12600.00
0005435797763	2859	Business	12600.00
0005435797762	2859	Business	12600.00
0005435797770	2859	Economy	4200.00
0005435797771	2859	Economy	4200.00
0005433404909	2859	Economy	4200.00
0005435797768	2859	Economy	4600.00
0005433404866	2859	Economy	4200.00
0005435797758	2859	Economy	4200.00
0005435797769	2859	Economy	4200.00
0005435797766	2859	Economy	4200.00
0005435797760	2859	Economy	4200.00
0005435797759	2859	Economy	4200.00
0005435797761	2859	Economy	4200.00
0005435797765	2859	Economy	4200.00
0005433404962	29339	Business	12600.00
0005435797702	29339	Business	12600.00
0005435797705	29339	Business	12600.00
0005435797654	29339	Business	12600.00
0005435797583	29339	Business	12600.00
0005435797665	29339	Economy	4200.00
0005435797703	29339	Economy	4200.00
0005435797675	29339	Economy	4600.00
0005433404964	29339	Economy	4600.00
0005435797676	29339	Economy	4200.00
0005435797646	29339	Economy	4200.00
0005435797674	29339	Economy	4200.00
0005435797631	29339	Economy	4200.00
0005435797694	29339	Economy	4200.00
0005435797678	29339	Economy	4200.00
0005435797605	29339	Economy	4200.00
0005433404960	29339	Economy	4200.00
0005435797663	29339	Economy	4200.00
0005435797622	29339	Economy	4200.00
0005435797623	29339	Economy	4200.00
0005435797664	29339	Economy	4200.00
0005433404966	29339	Economy	4200.00
0005435797704	29339	Economy	4200.00
0005435797695	29339	Economy	4200.00
0005435797681	29339	Economy	4200.00
0005433404965	29339	Economy	4200.00
0005433404961	29339	Economy	4200.00
0005435797706	29339	Economy	4200.00
0005433404963	29339	Economy	4200.00
0005433404959	29339	Economy	4200.00
0005435797677	29339	Economy	4200.00
0005435376397	5781	Economy	6800.00
0005435376385	5781	Economy	6800.00
0005435376369	5781	Economy	6800.00
0005434948191	5779	Economy	6800.00
0005434948188	5779	Economy	6800.00
0005434948190	5779	Economy	6800.00
0005434948193	5779	Economy	6800.00
0005434948194	5779	Economy	6800.00
0005434948189	5779	Economy	6800.00
0005434948192	5779	Economy	6800.00
0005434948120	16406	Economy	6800.00
0005434948119	16406	Economy	6800.00
0005434948128	16406	Economy	6800.00
0005434948055	16406	Economy	6800.00
0005434948129	16406	Economy	6800.00
0005434948123	16406	Economy	6800.00
0005434948108	16406	Economy	6800.00
0005434948122	16406	Economy	6800.00
0005434948130	16406	Economy	6800.00
0005434948109	16406	Economy	6800.00
0005433962042	6876	Business	21400.00
0005433962041	6876	Business	21400.00
0005433962080	6876	Business	21400.00
0005433962062	6876	Business	21400.00
0005433962097	6876	Business	21400.00
0005433962088	6876	Business	21400.00
0005433962072	6876	Business	21400.00
0005433962082	6876	Business	21400.00
0005433962090	6876	Business	21400.00
0005433962059	6876	Business	21400.00
0005433962069	6876	Economy	7100.00
0005433962086	6876	Economy	7100.00
0005433962032	6876	Economy	7100.00
0005433962044	6876	Economy	7100.00
0005433962058	6876	Economy	7100.00
0005433962046	6876	Economy	7100.00
0005433962047	6876	Economy	7800.00
0005433962085	6876	Economy	7800.00
0005433962073	6876	Economy	7800.00
0005433962078	6876	Economy	7800.00
0005433962056	6876	Economy	7100.00
0005433962043	6876	Economy	7100.00
0005433962051	6876	Economy	7100.00
0005433962074	6876	Economy	7100.00
0005433962039	6876	Economy	7100.00
0005433962091	6876	Economy	7100.00
0005433962075	6876	Economy	7100.00
0005433962036	6876	Economy	7100.00
0005433962063	6876	Economy	7100.00
0005433962099	6876	Economy	7100.00
0005433962076	6876	Economy	7100.00
0005433962094	6876	Economy	7100.00
0005433962054	6876	Economy	7100.00
0005433962034	6876	Economy	7100.00
0005433962068	6876	Economy	7100.00
0005433962093	6876	Economy	7100.00
0005433962098	6876	Economy	7100.00
0005433962087	6876	Economy	7100.00
0005433962060	6876	Economy	7100.00
0005433962049	6876	Economy	7100.00
0005433962057	6876	Economy	7100.00
0005433962070	6876	Economy	7100.00
0005433962045	6876	Economy	7100.00
0005433962037	6876	Economy	7100.00
0005433962033	6876	Economy	7100.00
0005433962079	6876	Economy	7100.00
0005433962038	6876	Economy	7100.00
0005433962084	6876	Economy	7100.00
0005433962053	6876	Economy	7100.00
0005433962089	6876	Economy	7100.00
0005433962096	6876	Economy	7100.00
0005433962066	6876	Economy	7100.00
0005433962067	6876	Economy	7100.00
0005433962052	6876	Economy	7100.00
0005433962077	6876	Economy	7100.00
0005433962061	6876	Economy	7100.00
0005433962050	6876	Economy	7100.00
0005433962095	6876	Economy	7100.00
0005433962040	6876	Economy	7100.00
0005433962035	6876	Economy	7100.00
0005433962048	6876	Economy	7100.00
0005433962064	6876	Economy	7100.00
0005433962083	6876	Economy	7100.00
0005433962081	6876	Economy	7100.00
0005433962092	6876	Economy	7100.00
0005433962055	6876	Economy	7100.00
0005433962065	6876	Economy	7100.00
0005433962071	6876	Economy	7100.00
0005433961346	25707	Business	21400.00
0005433961292	25707	Business	21400.00
0005433961359	25707	Business	21400.00
0005433961249	25707	Business	21400.00
0005433961410	25707	Business	21400.00
0005433961461	25707	Business	21400.00
0005433961386	25707	Business	21400.00
0005433961297	25707	Business	21400.00
0005433961463	25707	Economy	7100.00
0005433961468	25707	Economy	7100.00
0005433961401	25707	Economy	7100.00
0005433961469	25707	Economy	7100.00
0005433961367	25707	Economy	7100.00
0005433961259	25707	Economy	7800.00
0005433961348	25707	Economy	7800.00
0005433961330	25707	Economy	7100.00
0005433961230	25707	Economy	7100.00
0005433961355	25707	Economy	7100.00
0005433961293	25707	Economy	7100.00
0005433961427	25707	Economy	7100.00
0005433961268	25707	Economy	7100.00
0005433961460	25707	Economy	7100.00
0005433961459	25707	Economy	7100.00
0005433961421	25707	Economy	7100.00
0005433961368	25707	Economy	7100.00
0005433961329	25707	Economy	7100.00
0005433961229	25707	Economy	7100.00
0005433961432	25707	Economy	7100.00
0005433961399	25707	Economy	7100.00
0005433961381	25707	Economy	7100.00
0005433961192	25707	Economy	7100.00
0005433961462	25707	Economy	7100.00
0005433961347	25707	Economy	7100.00
0005433961337	25707	Economy	7100.00
0005433961257	25707	Economy	7100.00
0005433961400	25707	Economy	7100.00
0005433961450	25707	Economy	7100.00
0005433961258	25707	Economy	7100.00
0005433961440	25707	Economy	7100.00
0005433961369	25707	Economy	7100.00
0005433961256	25707	Economy	7100.00
0005433961429	25707	Economy	7100.00
0005433961291	25707	Economy	7100.00
0005433961382	25707	Economy	7100.00
0005435082877	24553	Economy	3900.00
0005435082885	24553	Economy	3900.00
0005435082851	24553	Economy	3900.00
0005435082852	24553	Economy	3900.00
0005435082883	24553	Economy	3900.00
0005435082884	24553	Economy	3900.00
0005435082881	24553	Economy	3900.00
0005435082880	24553	Economy	3900.00
0005435082924	24553	Economy	3900.00
0005435082951	26075	Economy	3900.00
0005435082948	26075	Economy	3900.00
0005435082950	26075	Economy	3900.00
0005435082949	26075	Economy	3900.00
0005434245574	5239	Business	18000.00
0005434245586	5239	Business	18000.00
0005435286701	5239	Business	18000.00
0005435286679	5239	Business	18000.00
0005434245581	5239	Business	18000.00
0005434245597	5239	Economy	6600.00
0005434245573	5239	Economy	6600.00
0005434245590	5239	Economy	6000.00
0005434245579	5239	Economy	6000.00
0005435286700	5239	Economy	6000.00
0005435286667	5239	Economy	6000.00
0005435286685	5239	Economy	6000.00
0005435286688	5239	Economy	6000.00
0005434245575	5239	Economy	6000.00
0005432166970	5239	Economy	6000.00
0005435286691	5239	Economy	6000.00
0005433534521	5239	Economy	6000.00
0005434245584	5239	Economy	6000.00
0005434245578	5239	Economy	6000.00
0005434245585	5239	Economy	6000.00
0005434245571	5239	Economy	6000.00
0005434245593	5239	Economy	6000.00
0005434245572	5239	Economy	6000.00
0005434245592	5239	Economy	6000.00
0005434245576	5239	Economy	6000.00
0005432166969	5239	Economy	6000.00
0005434245588	5239	Economy	6600.00
0005432166968	5239	Economy	6600.00
0005434245587	5239	Economy	6000.00
0005434245577	5239	Economy	6000.00
0005434245570	5239	Economy	6000.00
0005434245583	5239	Economy	6000.00
0005434245568	5239	Economy	6000.00
0005432166967	5239	Economy	6000.00
0005435286684	5239	Economy	6000.00
0005434245595	5239	Economy	6000.00
0005435286662	5239	Economy	6000.00
0005435286683	5239	Economy	6000.00
0005434245580	5239	Economy	6000.00
0005434245569	5239	Economy	6000.00
0005434245582	5239	Economy	6000.00
0005433534520	5239	Economy	6000.00
0005434245594	5239	Economy	6000.00
0005434245596	5239	Economy	6000.00
0005435286704	5239	Economy	6000.00
0005434245589	5239	Economy	6000.00
0005434245591	5239	Economy	6000.00
0005433785679	5238	Business	18000.00
0005433616210	5238	Business	18000.00
0005432106528	5238	Business	18000.00
0005433785680	5238	Business	18000.00
0005432106562	5238	Business	18000.00
0005433616197	5238	Business	18000.00
0005432106570	5238	Business	18000.00
0005432106548	5238	Business	18000.00
0005433616163	5238	Business	18000.00
0005432106531	5238	Business	18000.00
0005432106555	5238	Business	18000.00
0005432106565	5238	Business	18000.00
0005433616212	5238	Business	18000.00
0005432106533	5238	Business	18000.00
0005433616226	5238	Business	18000.00
0005432665318	5238	Business	18000.00
0005433616208	5238	Business	18000.00
0005433616162	5238	Business	18000.00
0005432666430	5238	Business	18000.00
0005433785676	5238	Business	18000.00
0005433616199	5238	Business	18000.00
0005432106536	5238	Business	18000.00
0005433616213	5238	Business	18000.00
0005433616167	5238	Business	18000.00
0005433616169	5238	Business	18000.00
0005433616230	5238	Business	18000.00
0005433785698	5238	Business	18000.00
0005432106556	5238	Business	18000.00
0005432106534	5238	Economy	6600.00
0005433785694	5238	Economy	6600.00
0005433785703	5238	Economy	6600.00
0005432106563	5238	Economy	6600.00
0005433616219	5238	Economy	6600.00
0005433785685	5238	Economy	6600.00
0005433616193	5238	Economy	6000.00
0005432106542	5238	Economy	6000.00
0005432106537	5238	Economy	6000.00
0005433785683	5238	Economy	6000.00
0005432106549	5238	Economy	6000.00
0005433616189	5238	Economy	6000.00
0005433616215	5238	Economy	6000.00
0005433616194	5238	Economy	6000.00
0005433616186	5238	Economy	6000.00
0005433616216	5238	Economy	6000.00
0005432106539	5238	Economy	6000.00
0005432106530	5238	Economy	6000.00
0005432667496	5238	Economy	6000.00
0005432106569	5238	Economy	6000.00
0005433616184	5238	Economy	6000.00
0005433785701	5238	Economy	6000.00
0005433616180	5238	Economy	6000.00
0005433616203	5238	Economy	6000.00
0005433616217	5238	Economy	6000.00
0005432106567	5238	Economy	6000.00
0005433616166	5238	Economy	6000.00
0005433785692	5238	Economy	6000.00
0005433616223	5238	Economy	6000.00
0005432106560	5238	Economy	6000.00
0005432106552	5238	Economy	6000.00
0005433785693	5238	Economy	6000.00
0005433616211	5238	Economy	6000.00
0005432106571	5238	Economy	6000.00
0005433785682	5238	Economy	6000.00
0005433616178	5238	Economy	6000.00
0005433616175	5238	Economy	6000.00
0005433616191	5238	Economy	6000.00
0005433785688	5238	Economy	6000.00
0005433616229	5238	Economy	6000.00
0005433785675	5238	Economy	6000.00
0005433616158	5238	Economy	6000.00
0005432106545	5238	Economy	6000.00
0005432106561	5238	Economy	6000.00
0005433785687	5238	Economy	6000.00
0005432106540	5238	Economy	6000.00
0005433616164	5238	Economy	6000.00
0005432106557	5238	Economy	6000.00
0005433616156	5238	Economy	6000.00
0005432665317	5238	Economy	6000.00
0005432106524	5238	Economy	6000.00
0005433616174	5238	Economy	6000.00
0005433616187	5238	Economy	6000.00
0005433616225	5238	Economy	6000.00
0005432106546	5238	Economy	6000.00
0005433785699	5238	Economy	6000.00
0005433785674	5238	Economy	6000.00
0005433616192	5238	Economy	6000.00
0005433616161	5238	Economy	6000.00
0005433785696	5238	Economy	6000.00
0005433616190	5238	Economy	6000.00
0005432106544	5238	Economy	6000.00
0005432106558	5238	Economy	6000.00
0005432106541	5238	Economy	6000.00
0005432106529	5238	Economy	6000.00
0005432667497	5238	Economy	6600.00
0005433616159	5238	Economy	6600.00
0005432106523	5238	Economy	6600.00
0005433616168	5238	Economy	6600.00
0005433616227	5238	Economy	6000.00
0005433616221	5238	Economy	6600.00
0005433616172	5238	Economy	6000.00
0005433785689	5238	Economy	6000.00
0005432106526	5238	Economy	6000.00
0005433616182	5238	Economy	6600.00
0005432106547	5238	Economy	6000.00
0005433785684	5238	Economy	6000.00
0005433785704	5238	Economy	6000.00
0005433616165	5238	Economy	6000.00
0005433785700	5238	Economy	6000.00
0005433616201	5238	Economy	6000.00
0005432106551	5238	Economy	6000.00
0005433616220	5238	Economy	6000.00
0005432106550	5238	Economy	6000.00
0005432666431	5238	Economy	6000.00
0005433616206	5238	Economy	6000.00
0005433616207	5238	Economy	6000.00
0005433616160	5238	Economy	6000.00
0005433616181	5238	Economy	6000.00
0005433616224	5238	Economy	6000.00
0005433785697	5238	Economy	6000.00
0005432106535	5238	Economy	6000.00
0005433616179	5238	Economy	6000.00
0005432145155	5238	Economy	6000.00
0005432106527	5238	Economy	6000.00
0005432106568	5238	Economy	6000.00
0005433785691	5238	Economy	6000.00
0005432106564	5238	Economy	6000.00
0005433785706	5238	Economy	6000.00
0005433616157	5238	Economy	6000.00
0005432145153	5238	Economy	6000.00
0005433785695	5238	Economy	6000.00
0005433616222	5238	Economy	6000.00
0005433616214	5238	Economy	6000.00
0005433785686	5238	Economy	6000.00
0005433616202	5238	Economy	6000.00
0005433616170	5238	Economy	6000.00
0005432106538	5238	Economy	6000.00
0005433616200	5238	Economy	6000.00
0005433616198	5238	Economy	6000.00
0005433616228	5238	Economy	6000.00
0005432106559	5238	Economy	6000.00
0005433616196	5238	Economy	6000.00
0005432106525	5238	Economy	6000.00
0005433616204	5238	Economy	6000.00
0005432665316	5238	Economy	6000.00
0005433616195	5238	Economy	6000.00
0005433616173	5238	Economy	6000.00
0005433785702	5238	Economy	6000.00
0005433616188	5238	Economy	6000.00
0005432106554	5238	Economy	6000.00
0005433785678	5238	Economy	6000.00
0005433785690	5238	Economy	6000.00
0005433616171	5238	Economy	6000.00
0005432106566	5238	Economy	6000.00
0005432145154	5238	Economy	6000.00
0005433616218	5238	Economy	6000.00
0005433616176	5238	Economy	6000.00
0005432106532	5238	Economy	6000.00
0005433616183	5238	Economy	6000.00
0005433785705	5238	Economy	6000.00
0005433616185	5238	Economy	6000.00
0005433616177	5238	Economy	6000.00
0005432106543	5238	Economy	6000.00
0005432667495	5238	Economy	6000.00
0005433785681	5238	Economy	6000.00
0005433785677	5238	Economy	6000.00
0005432106553	5238	Economy	6000.00
0005433616205	5238	Economy	6000.00
0005433616209	5238	Economy	6000.00
0005435007268	5236	Business	18000.00
0005433685528	5236	Business	18000.00
0005434229833	5236	Business	18000.00
0005435269827	5236	Business	18000.00
0005434149971	5236	Business	18000.00
0005434229844	5236	Business	18000.00
0005434229843	5236	Business	18000.00
0005434173600	5236	Business	18000.00
0005434229827	5236	Business	18000.00
0005435007319	5236	Business	18000.00
0005435269805	5236	Business	18000.00
0005435269812	5236	Business	18000.00
0005432336133	5236	Business	18000.00
0005434229838	5236	Economy	6600.00
0005435269806	5236	Economy	6600.00
0005434229832	5236	Economy	6600.00
0005434229825	5236	Economy	6600.00
0005434265676	5236	Economy	6000.00
0005434149974	5236	Economy	6000.00
0005435269829	5236	Economy	6000.00
0005434173604	5236	Economy	6000.00
0005434312345	5236	Economy	6000.00
0005434229837	5236	Economy	6000.00
0005434265664	5236	Economy	6000.00
0005434311243	5236	Economy	6000.00
0005434229839	5236	Economy	6000.00
0005434229824	5236	Economy	6000.00
0005434229841	5236	Economy	6000.00
0005433815434	5236	Economy	6000.00
0005434149970	5236	Economy	6000.00
0005434265671	5236	Economy	6000.00
0005434149973	5236	Economy	6000.00
0005434229831	5236	Economy	6000.00
0005434265675	5236	Economy	6000.00
0005434265673	5236	Economy	6000.00
0005434173603	5236	Economy	6000.00
0005435007430	5236	Economy	6000.00
0005435007231	5236	Economy	6000.00
0005434311249	5236	Economy	6000.00
0005434149977	5236	Economy	6000.00
0005432336156	5236	Economy	6000.00
0005433685536	5236	Economy	6000.00
0005435007229	5236	Economy	6000.00
0005434265654	5236	Economy	6000.00
0005435269830	5236	Economy	6000.00
0005434265672	5236	Economy	6000.00
0005434149969	5236	Economy	6000.00
0005434265659	5236	Economy	6000.00
0005434265658	5236	Economy	6000.00
0005434149972	5236	Economy	6000.00
0005435007288	5236	Economy	6000.00
0005434229826	5236	Economy	6000.00
0005435007238	5236	Economy	6000.00
0005434265669	5236	Economy	6000.00
0005434265661	5236	Economy	6000.00
0005434229834	5236	Economy	6000.00
0005434229823	5236	Economy	6000.00
0005435007304	5236	Economy	6000.00
0005432336169	5236	Economy	6000.00
0005433685537	5236	Economy	6000.00
0005432336139	5236	Economy	6000.00
0005435007315	5236	Economy	6000.00
0005434265670	5236	Economy	6600.00
0005434265662	5236	Economy	6000.00
0005435269828	5236	Economy	6600.00
0005434265678	5236	Economy	6600.00
0005435007338	5236	Economy	6000.00
0005434229840	5236	Economy	6000.00
0005435007340	5236	Economy	6600.00
0005434265668	5236	Economy	6000.00
0005434265677	5236	Economy	6000.00
0005434149975	5236	Economy	6000.00
0005434265667	5236	Economy	6000.00
0005434149976	5236	Economy	6000.00
0005434312344	5236	Economy	6000.00
0005435269818	5236	Economy	6000.00
0005434265656	5236	Economy	6000.00
0005435007195	5236	Economy	6000.00
0005435269816	5236	Economy	6000.00
0005434265665	5236	Economy	6000.00
0005435007378	5236	Economy	6000.00
0005434173601	5236	Economy	6000.00
0005434265655	5236	Economy	6000.00
0005435007331	5236	Economy	6000.00
0005434265679	5236	Economy	6000.00
0005433815433	5236	Economy	6000.00
0005434229828	5236	Economy	6000.00
0005435007237	5236	Economy	6000.00
0005435007334	5236	Economy	6000.00
0005434265657	5236	Economy	6000.00
0005432336140	5236	Economy	6000.00
0005434265666	5236	Economy	6000.00
0005435007316	5236	Economy	6000.00
0005434265663	5236	Economy	6000.00
0005434229835	5236	Economy	6000.00
0005435269815	5236	Economy	6000.00
0005435269831	5236	Economy	6000.00
0005433815442	5236	Economy	6000.00
0005432336170	5236	Economy	6000.00
0005434265660	5236	Economy	6000.00
0005434149968	5236	Economy	6000.00
0005435007339	5236	Economy	6000.00
0005434229830	5236	Economy	6000.00
0005435007354	5236	Economy	6000.00
0005433815441	5236	Economy	6000.00
0005435007230	5236	Economy	6000.00
0005432336167	5236	Economy	6000.00
0005432336171	5236	Economy	6000.00
0005435007327	5236	Economy	6000.00
0005435007328	5236	Economy	6000.00
0005434149966	5236	Economy	6000.00
0005434173602	5236	Economy	6000.00
0005434173605	5236	Economy	6000.00
0005434229829	5236	Economy	6000.00
0005434265674	5236	Economy	6000.00
0005435007185	5236	Economy	6000.00
0005434149967	5236	Economy	6000.00
0005434229836	5236	Economy	6000.00
0005434229842	5236	Economy	6000.00
0005435007253	5236	Economy	6000.00
0005434229822	5236	Economy	6000.00
0005435269921	8465	Business	18000.00
0005435269917	8465	Business	18000.00
0005433785199	8465	Business	18000.00
0005435269925	8465	Business	18000.00
0005433785368	8465	Business	18000.00
0005433785382	8465	Business	18000.00
0005433785391	8465	Business	18000.00
0005433785407	8465	Business	18000.00
0005433785478	8465	Business	18000.00
0005432659729	8465	Business	18000.00
0005432663053	8465	Business	18000.00
0005433785409	8465	Business	18000.00
0005433785343	8465	Business	18000.00
0005434245312	8465	Business	18000.00
0005433785580	8465	Business	18000.00
0005434245484	8465	Business	18000.00
0005434245240	8465	Business	18000.00
0005434245448	8465	Economy	6600.00
0005433785346	8465	Economy	6600.00
0005433785230	8465	Economy	6600.00
0005433785416	8465	Economy	6600.00
0005432659724	8465	Economy	6000.00
0005434245416	8465	Economy	6000.00
0005433785417	8465	Economy	6000.00
0005433785412	8465	Economy	6000.00
0005434245311	8465	Economy	6000.00
0005433785475	8465	Economy	6000.00
0005434245334	8465	Economy	6000.00
0005433785135	8465	Economy	6000.00
0005433785408	8465	Economy	6000.00
0005434245415	8465	Economy	6000.00
0005435269922	8465	Economy	6000.00
0005432666419	8465	Economy	6000.00
0005432659722	8465	Economy	6000.00
0005432666414	8465	Economy	6000.00
0005433785369	8465	Economy	6000.00
0005435269919	8465	Economy	6000.00
0005433785338	8465	Economy	6000.00
0005433785411	8465	Economy	6000.00
0005435269924	8465	Economy	6000.00
0005432666411	8465	Economy	6000.00
0005434245287	8465	Economy	6000.00
0005434245386	8465	Economy	6000.00
0005434245336	8465	Economy	6000.00
0005432663065	8465	Economy	6000.00
0005434245263	8465	Economy	6000.00
0005434245310	8465	Economy	6000.00
0005435269918	8465	Economy	6000.00
0005434245474	8465	Economy	6000.00
0005433785161	8465	Economy	6000.00
0005432659726	8465	Economy	6000.00
0005435269914	8465	Economy	6000.00
0005434245376	8465	Economy	6000.00
0005433785202	8465	Economy	6600.00
0005432659731	8465	Economy	6600.00
0005435269916	8465	Economy	6000.00
0005434245427	8465	Economy	6600.00
0005434245483	8465	Economy	6000.00
0005435269923	8465	Economy	6000.00
0005434245475	8465	Economy	6000.00
0005434245364	8465	Economy	6600.00
0005434245372	8465	Economy	6000.00
0005434245239	8465	Economy	6000.00
0005434245241	8465	Economy	6000.00
0005435269915	8465	Economy	6000.00
0005434245277	8465	Economy	6000.00
0005433785406	8465	Economy	6000.00
0005434245373	8465	Economy	6000.00
0005433785549	8465	Economy	6000.00
0005434245365	8465	Economy	6000.00
0005433785548	8465	Economy	6000.00
0005434245337	8465	Economy	6000.00
0005433785396	8465	Economy	6000.00
0005434245445	8465	Economy	6000.00
0005435269920	8465	Economy	6000.00
0005433785395	8465	Economy	6000.00
0005433785345	8465	Economy	6000.00
0005435269913	8465	Economy	6000.00
0005434245307	8465	Economy	6000.00
0005434245286	8465	Economy	6000.00
0005435269926	8465	Economy	6000.00
0005434245390	8465	Economy	6000.00
0005434245417	8465	Economy	6000.00
0005432659723	8465	Economy	6000.00
0005432659732	8465	Economy	6000.00
0005432659730	8465	Economy	6000.00
0005433615792	8466	Business	18000.00
0005433615540	8466	Business	18000.00
0005433615513	8466	Business	18000.00
0005433615613	8466	Business	18000.00
0005433615868	8466	Business	18000.00
0005433615463	8466	Business	18000.00
0005433615318	8466	Business	18000.00
0005433615392	8466	Business	18000.00
0005433615464	8466	Economy	6600.00
0005433615319	8466	Economy	6600.00
0005433615158	8466	Economy	6000.00
0005433615451	8466	Economy	6000.00
0005433615631	8466	Economy	6000.00
0005433615693	8466	Economy	6000.00
0005433615174	8466	Economy	6000.00
0005433615480	8466	Economy	6000.00
0005433615372	8466	Economy	6000.00
0005433615611	8466	Economy	6000.00
0005433615615	8466	Economy	6000.00
0005433615497	8466	Economy	6000.00
0005433615260	8466	Economy	6000.00
0005433615537	8466	Economy	6000.00
0005433615195	8466	Economy	6000.00
0005433615466	8466	Economy	6000.00
0005433615546	8466	Economy	6000.00
0005433615867	8466	Economy	6000.00
0005433615536	8466	Economy	6000.00
0005433615159	8466	Economy	6000.00
0005433615724	8466	Economy	6000.00
0005433615327	8466	Economy	6000.00
0005433615302	8466	Economy	6000.00
0005433615332	8466	Economy	6000.00
0005433615083	8466	Economy	6600.00
0005433615577	8466	Economy	6600.00
0005433615196	8466	Economy	6600.00
0005433615791	8466	Economy	6600.00
0005433615328	8466	Economy	6000.00
0005433615494	8466	Economy	6000.00
0005433615616	8466	Economy	6000.00
0005433615331	8466	Economy	6000.00
0005433615578	8466	Economy	6000.00
0005433615579	8466	Economy	6000.00
0005433615329	8466	Economy	6000.00
0005433615277	8466	Economy	6000.00
0005433615503	8466	Economy	6000.00
0005433615782	8466	Economy	6000.00
0005433615434	8466	Economy	6000.00
0005433615526	8466	Economy	6000.00
0005433615630	8466	Economy	6000.00
0005433615465	8466	Economy	6000.00
0005433615413	8466	Economy	6000.00
0005433615402	8466	Economy	6000.00
0005433615337	8466	Economy	6000.00
0005433615625	8466	Economy	6000.00
0005433615181	8466	Economy	6000.00
0005433615214	8466	Economy	6000.00
0005433615495	8466	Economy	6000.00
0005433615438	8466	Economy	6000.00
0005433615539	8466	Economy	6000.00
0005433615551	8466	Economy	6000.00
0005433615353	8466	Economy	6000.00
0005433615492	8466	Economy	6000.00
0005433615330	8466	Economy	6000.00
0005433615839	8466	Economy	6000.00
0005434229685	8467	Business	18000.00
0005432035514	8467	Business	18000.00
0005434229690	8467	Business	18000.00
0005434149869	8467	Business	18000.00
0005433815485	8467	Business	18000.00
0005432035510	8467	Business	18000.00
0005434229794	8467	Business	18000.00
0005433534542	8467	Business	18000.00
0005432336275	8467	Business	18000.00
0005434265570	8467	Business	18000.00
0005434149898	8467	Business	18000.00
0005435007498	8467	Business	18000.00
0005433534541	8467	Business	18000.00
0005435007493	8467	Business	18000.00
0005434229610	8467	Business	18000.00
0005432047626	8467	Business	18000.00
0005435007506	8467	Business	18000.00
0005432336284	8467	Business	18000.00
0005432035522	8467	Business	18000.00
0005432035525	8467	Business	18000.00
0005434265431	8467	Business	18000.00
0005432035516	8467	Business	18000.00
0005432035506	8467	Business	18000.00
0005434229667	8467	Business	18000.00
0005435007507	8467	Business	18000.00
0005434265416	8467	Economy	6600.00
0005432035524	8467	Economy	6600.00
0005433688852	8467	Economy	6600.00
0005434229538	8467	Economy	6600.00
0005434265456	8467	Economy	6000.00
0005435007515	8467	Economy	6600.00
0005433815486	8467	Economy	6000.00
0005434229660	8467	Economy	6000.00
0005434149911	8467	Economy	6000.00
0005434265398	8467	Economy	6000.00
0005432336277	8467	Economy	6000.00
0005434229603	8467	Economy	6000.00
0005434265481	8467	Economy	6000.00
0005432336281	8467	Economy	6000.00
0005434229681	8467	Economy	6000.00
0005434265526	8467	Economy	6000.00
0005434149870	8467	Economy	6000.00
0005432035523	8467	Economy	6000.00
0005435007514	8467	Economy	6000.00
0005435007497	8467	Economy	6000.00
0005432035520	8467	Economy	6000.00
0005432336282	8467	Economy	6000.00
0005434229661	8467	Economy	6000.00
0005434229520	8467	Economy	6000.00
0005432035517	8467	Economy	6000.00
0005433815483	8467	Economy	6000.00
0005434265433	8467	Economy	6000.00
0005434265407	8467	Economy	6000.00
0005435007509	8467	Economy	6000.00
0005432035511	8467	Economy	6000.00
0005435007502	8467	Economy	6000.00
0005434149825	8467	Economy	6000.00
0005433690967	8467	Economy	6000.00
0005434311260	8467	Economy	6000.00
0005434149905	8467	Economy	6000.00
0005434229680	8467	Economy	6000.00
0005434173566	8467	Economy	6000.00
0005434149815	8467	Economy	6000.00
0005435007512	8467	Economy	6000.00
0005435007511	8467	Economy	6000.00
0005435007508	8467	Economy	6000.00
0005432035521	8467	Economy	6000.00
0005432035526	8467	Economy	6000.00
0005432047628	8467	Economy	6000.00
0005434149852	8467	Economy	6000.00
0005435007500	8467	Economy	6000.00
0005434229576	8467	Economy	6000.00
0005433815484	8467	Economy	6000.00
0005432035512	8467	Economy	6000.00
0005434265429	8467	Economy	6000.00
0005434229720	8467	Economy	6000.00
0005433689954	8467	Economy	6000.00
0005434173548	8467	Economy	6000.00
0005432035503	8467	Economy	6000.00
0005434149828	8467	Economy	6000.00
0005435007496	8467	Economy	6000.00
0005432336278	8467	Economy	6000.00
0005434149902	8467	Economy	6000.00
0005435007504	8467	Economy	6000.00
0005434265432	8467	Economy	6600.00
0005432035504	8467	Economy	6600.00
0005432035527	8467	Economy	6600.00
0005434149899	8467	Economy	6600.00
0005435007503	8467	Economy	6000.00
0005432336276	8467	Economy	6000.00
0005434265593	8467	Economy	6000.00
0005432035529	8467	Economy	6000.00
0005434265544	8467	Economy	6600.00
0005434229575	8467	Economy	6000.00
0005434229591	8467	Economy	6000.00
0005433815487	8467	Economy	6000.00
0005434229606	8467	Economy	6000.00
0005434173547	8467	Economy	6000.00
0005434265334	8467	Economy	6000.00
0005434149829	8467	Economy	6000.00
0005435007499	8467	Economy	6000.00
0005432035519	8467	Economy	6000.00
0005432035518	8467	Economy	6000.00
0005433690966	8467	Economy	6000.00
0005434229634	8467	Economy	6000.00
0005435007513	8467	Economy	6000.00
0005434229677	8467	Economy	6000.00
0005432035509	8467	Economy	6000.00
0005435007501	8467	Economy	6000.00
0005434265491	8467	Economy	6000.00
0005434173572	8467	Economy	6000.00
0005434265437	8467	Economy	6000.00
0005433534543	8467	Economy	6000.00
0005434149826	8467	Economy	6000.00
0005434149886	8467	Economy	6000.00
0005434229574	8467	Economy	6000.00
0005432035505	8467	Economy	6000.00
0005432336283	8467	Economy	6000.00
0005432035515	8467	Economy	6000.00
0005434229604	8467	Economy	6000.00
0005433688853	8467	Economy	6000.00
0005434311259	8467	Economy	6000.00
0005434149827	8467	Economy	6000.00
0005434149887	8467	Economy	6000.00
0005434229623	8467	Economy	6000.00
0005435007505	8467	Economy	6000.00
0005432035528	8467	Economy	6000.00
0005434229646	8467	Economy	6000.00
0005434265571	8467	Economy	6000.00
0005434149906	8467	Economy	6000.00
0005432047625	8467	Economy	6000.00
0005433689955	8467	Economy	6000.00
0005434229793	8467	Economy	6000.00
0005434265498	8467	Economy	6000.00
0005432035513	8467	Economy	6000.00
0005435007516	8467	Economy	6000.00
0005434265408	8467	Economy	6000.00
0005433688851	8467	Economy	6000.00
0005435007510	8467	Economy	6000.00
0005435007494	8467	Economy	6000.00
0005432035507	8467	Economy	6000.00
0005434229719	8467	Economy	6000.00
0005432035508	8467	Economy	6000.00
0005432336274	8467	Economy	6000.00
0005432035530	8467	Economy	6000.00
0005434265499	8467	Economy	6000.00
0005432336280	8467	Economy	6000.00
0005432336279	8467	Economy	6000.00
0005432035531	8467	Economy	6000.00
0005434265415	8467	Economy	6000.00
0005435007495	8467	Economy	6000.00
0005432047627	8467	Economy	6000.00
0005433202671	12586	Economy	16200.00
0005433202664	12586	Economy	16200.00
0005434639673	12586	Economy	16200.00
0005434639602	12586	Economy	16200.00
0005433202668	12586	Economy	14800.00
0005433202673	12586	Economy	14800.00
0005434639643	12586	Economy	14800.00
0005434639594	12586	Economy	14800.00
0005434639671	12586	Economy	14800.00
0005434639608	12586	Economy	14800.00
0005433202670	12586	Economy	14800.00
0005434639591	12586	Economy	14800.00
0005433202674	12586	Economy	14800.00
0005434639650	12586	Economy	14800.00
0005433202667	12586	Economy	14800.00
0005434639615	12586	Economy	14800.00
0005434639685	12586	Economy	14800.00
0005434639661	12586	Economy	14800.00
0005434639721	12586	Economy	14800.00
0005434639614	12586	Economy	14800.00
0005434639644	12586	Economy	14800.00
0005433202660	12586	Economy	14800.00
0005433202661	12586	Economy	14800.00
0005433202666	12586	Economy	14800.00
0005434639552	12586	Economy	14800.00
0005434639663	12586	Economy	14800.00
0005434639670	12586	Economy	14800.00
0005434639537	12586	Economy	14800.00
0005434639649	12586	Economy	14800.00
0005434639551	12586	Economy	14800.00
0005434639690	12586	Economy	14800.00
0005433202662	12586	Economy	14800.00
0005433202665	12586	Economy	14800.00
0005433202672	12586	Economy	14800.00
0005434639603	12586	Economy	14800.00
0005433202669	12586	Economy	14800.00
0005433202663	12586	Economy	14800.00
0005434639655	12586	Economy	14800.00
0005433202472	23392	Economy	16200.00
0005434639826	23392	Economy	16200.00
0005434639832	23392	Economy	16200.00
0005434639825	23392	Economy	16200.00
0005434639821	23392	Economy	14800.00
0005433202522	23392	Economy	14800.00
0005434639824	23392	Economy	14800.00
0005434639829	23392	Economy	14800.00
0005433202553	23392	Economy	14800.00
0005434639835	23392	Economy	14800.00
0005433202501	23392	Economy	14800.00
0005433202437	23392	Economy	14800.00
0005433202464	23392	Economy	14800.00
0005433202510	23392	Economy	14800.00
0005434639817	23392	Economy	14800.00
0005434639819	23392	Economy	14800.00
0005434639840	23392	Economy	14800.00
0005434639831	23392	Economy	14800.00
0005433202502	23392	Economy	14800.00
0005434639834	23392	Economy	14800.00
0005433202440	23392	Economy	14800.00
0005434639838	23392	Economy	14800.00
0005433202539	23392	Economy	14800.00
0005433202537	23392	Economy	14800.00
0005434639837	23392	Economy	14800.00
0005433202538	23392	Economy	14800.00
0005433202523	23392	Economy	14800.00
0005433202516	23392	Economy	14800.00
0005434639828	23392	Economy	14800.00
0005434639816	23392	Economy	14800.00
0005434639827	23392	Economy	14800.00
0005434639822	23392	Economy	14800.00
0005434639830	23392	Economy	14800.00
0005434639836	23392	Economy	14800.00
0005434639833	23392	Economy	14800.00
0005432290694	23392	Economy	14800.00
0005433202564	23392	Economy	14800.00
0005433202529	23392	Economy	14800.00
0005434639823	23392	Economy	14800.00
0005433202508	23392	Economy	14800.00
0005434639818	23392	Economy	14800.00
0005434639841	23392	Economy	14800.00
0005432290693	23392	Economy	14800.00
0005432290695	23392	Economy	14800.00
0005433202441	23392	Economy	14800.00
0005434639820	23392	Economy	14800.00
0005433202563	23392	Economy	14800.00
0005434639839	23392	Economy	14800.00
0005434639842	23392	Economy	14800.00
0005432290696	23392	Economy	14800.00
0005432383505	21111	Business	18900.00
0005432383617	21111	Business	18900.00
0005432383614	21111	Business	18900.00
0005432329126	21111	Business	18900.00
0005432383616	21111	Business	18900.00
0005432329076	21111	Business	18900.00
0005432329373	21111	Business	18900.00
0005432329218	21111	Business	18900.00
0005432329372	21111	Business	18900.00
0005432383559	21111	Business	18900.00
0005432329177	21111	Business	18900.00
0005432329059	21111	Economy	6300.00
0005432329115	21111	Economy	6300.00
0005432328940	21111	Economy	6300.00
0005432329424	21111	Economy	6300.00
0005432329039	21111	Economy	6300.00
0005432329158	21111	Economy	6300.00
0005432383539	21111	Economy	6300.00
0005432383480	21111	Economy	6300.00
0005432329289	21111	Economy	6300.00
0005432383511	21111	Economy	6300.00
0005432054365	21111	Economy	6900.00
0005432329272	21111	Economy	6900.00
0005432328890	21111	Economy	6900.00
0005432329006	21111	Economy	6900.00
0005432383576	21111	Economy	6900.00
0005432329221	21111	Economy	6300.00
0005432329142	21111	Economy	6300.00
0005432383479	21111	Economy	6300.00
0005432383604	21111	Economy	6300.00
0005432329341	21111	Economy	6300.00
0005432329182	21111	Economy	6300.00
0005432329252	21111	Economy	6300.00
0005432329148	21111	Economy	6300.00
0005432329103	21111	Economy	6300.00
0005432383514	21111	Economy	6300.00
0005432329028	21111	Economy	6300.00
0005432329219	21111	Economy	6300.00
0005432329159	21111	Economy	6300.00
0005432329060	21111	Economy	6300.00
0005432383501	21111	Economy	6300.00
0005432329136	21111	Economy	6300.00
0005432329425	21111	Economy	6300.00
0005432329143	21111	Economy	6300.00
0005432329097	21111	Economy	6300.00
0005432383527	21111	Economy	6300.00
0005432329288	21111	Economy	6300.00
0005432383538	21111	Economy	6300.00
0005432329176	21111	Economy	6300.00
0005432329201	21111	Economy	6300.00
0005432329326	21111	Economy	6300.00
0005432329141	21111	Economy	6300.00
0005432383592	21111	Economy	6300.00
0005432383549	21111	Economy	6300.00
0005432383446	21111	Economy	6300.00
0005432329325	21111	Economy	6300.00
0005432329149	21111	Economy	6300.00
0005432329169	21111	Economy	6300.00
0005432329040	21111	Economy	6300.00
0005432329170	21111	Economy	6300.00
0005432329324	21111	Economy	6300.00
0005432329104	21111	Economy	6300.00
0005432329420	21111	Economy	6300.00
0005432383565	21111	Economy	6300.00
0005432383599	21111	Economy	6300.00
0005432329155	21111	Economy	6300.00
0005432383573	21111	Economy	6300.00
0005432329105	21111	Economy	6300.00
0005432383528	21111	Economy	6300.00
0005432329204	21111	Economy	6300.00
0005432054366	21111	Economy	6300.00
0005432329098	21111	Economy	6300.00
0005432329202	21111	Economy	6300.00
0005432383595	21111	Economy	6300.00
0005432383601	21111	Economy	6300.00
0005432329160	21111	Economy	6300.00
0005432329282	21111	Economy	6300.00
0005432329251	21111	Economy	6300.00
0005432329024	21111	Economy	6300.00
0005432329112	21111	Economy	6300.00
0005432329205	21111	Economy	6300.00
0005432383408	21111	Economy	6300.00
0005432383500	21111	Economy	6300.00
0005432329249	21111	Economy	6300.00
0005432329416	21111	Economy	6300.00
0005432383600	21111	Economy	6300.00
0005432329269	21111	Economy	6300.00
0005432383570	21111	Economy	6300.00
0005432329207	21111	Economy	6300.00
0005432383613	21111	Economy	6300.00
0005432383605	21111	Economy	6300.00
0005432329273	21111	Economy	6300.00
0005432329268	21111	Economy	6300.00
0005432329390	21111	Economy	6300.00
0005432329156	21111	Economy	6300.00
0005432329118	21111	Economy	6300.00
0005432329618	31272	Business	18900.00
0005432383931	31272	Business	18900.00
0005432329611	31272	Business	18900.00
0005432383930	31272	Business	18900.00
0005432287292	31272	Business	18900.00
0005432329606	31272	Business	18900.00
0005432383932	31272	Business	18900.00
0005432329619	31272	Business	18900.00
0005432383949	31272	Business	18900.00
0005432383951	31272	Business	18900.00
0005432329623	31272	Business	18900.00
0005432329612	31272	Business	18900.00
0005432383928	31272	Economy	6300.00
0005432329590	31272	Economy	6300.00
0005432383936	31272	Economy	6300.00
0005432383925	31272	Economy	6300.00
0005432287290	31272	Economy	6300.00
0005432383950	31272	Economy	6300.00
0005432329599	31272	Economy	6300.00
0005432383924	31272	Economy	6300.00
0005432383952	31272	Economy	6300.00
0005432329624	31272	Economy	6900.00
0005432329582	31272	Economy	6900.00
0005432383945	31272	Economy	6900.00
0005432383915	31272	Economy	6900.00
0005432329587	31272	Economy	6900.00
0005432329584	31272	Economy	6300.00
0005432329596	31272	Economy	6300.00
0005432329627	31272	Economy	6300.00
0005432383941	31272	Economy	6300.00
0005432383927	31272	Economy	6300.00
0005432329588	31272	Economy	6300.00
0005432383946	31272	Economy	6300.00
0005432329603	31272	Economy	6300.00
0005432329610	31272	Economy	6300.00
0005432329616	31272	Economy	6300.00
0005432383939	31272	Economy	6300.00
0005432329598	31272	Economy	6300.00
0005432329615	31272	Economy	6300.00
0005432329617	31272	Economy	6300.00
0005432329625	31272	Economy	6300.00
0005432383953	31272	Economy	6300.00
0005432383919	31272	Economy	6300.00
0005432329589	31272	Economy	6300.00
0005432383955	31272	Economy	6300.00
0005432383944	31272	Economy	6300.00
0005432287289	31272	Economy	6300.00
0005432383929	31272	Economy	6300.00
0005432383934	31272	Economy	6300.00
0005432329586	31272	Economy	6300.00
0005432329597	31272	Economy	6300.00
0005432287291	31272	Economy	6300.00
0005432383954	31272	Economy	6300.00
0005432329609	31272	Economy	6300.00
0005432287288	31272	Economy	6300.00
0005432383935	31272	Economy	6300.00
0005432383947	31272	Economy	6300.00
0005432329593	31272	Economy	6300.00
0005432329622	31272	Economy	6300.00
0005432383922	31272	Economy	6300.00
0005432329581	31272	Economy	6300.00
0005432329620	31272	Economy	6300.00
0005432329585	31272	Economy	6300.00
0005432329605	31272	Economy	6300.00
0005432383933	31272	Economy	6300.00
0005432329600	31272	Economy	6300.00
0005432383918	31272	Economy	6300.00
0005432329601	31272	Economy	6300.00
0005432329608	31272	Economy	6300.00
0005432329592	31272	Economy	6300.00
0005432383917	31272	Economy	6300.00
0005432329614	31272	Economy	6300.00
0005432329604	31272	Economy	6300.00
0005432383948	31272	Economy	6300.00
0005432383942	31272	Economy	6300.00
0005432329602	31272	Economy	6300.00
0005432329591	31272	Economy	6300.00
0005432383940	31272	Economy	6300.00
0005432329607	31272	Economy	6300.00
0005432383943	31272	Economy	6300.00
0005432329595	31272	Economy	6300.00
0005432329594	31272	Economy	6300.00
0005432383937	31272	Economy	6300.00
0005432383938	31272	Economy	6300.00
0005432383916	31272	Economy	6300.00
0005432329621	31272	Economy	6300.00
0005432383920	31272	Economy	6300.00
0005432329613	31272	Economy	6300.00
0005432383923	31272	Economy	6300.00
0005432329626	31272	Economy	6300.00
0005432329583	31272	Economy	6300.00
0005432383926	31272	Economy	6300.00
0005432383921	31272	Economy	6300.00
0005432287293	31272	Economy	6300.00
0005433642642	2493	Business	89600.00
0005432954049	2493	Business	89600.00
0005433642628	2493	Business	89600.00
0005432953980	2493	Business	89600.00
0005433642645	2493	Economy	29900.00
0005432954030	2493	Economy	29900.00
0005432954057	2493	Economy	29900.00
0005432954050	2493	Economy	29900.00
0005433642634	2493	Economy	29900.00
0005433642651	2493	Economy	29900.00
0005433642633	2493	Economy	29900.00
0005432954021	2493	Economy	29900.00
0005432954020	2493	Economy	32800.00
0005433642639	2493	Economy	29900.00
0005433642630	2493	Economy	29900.00
0005433642655	2493	Economy	29900.00
0005433642643	2493	Economy	29900.00
0005433642649	2493	Economy	29900.00
0005433642657	2493	Economy	29900.00
0005433642654	2493	Economy	29900.00
0005433642653	2493	Economy	29900.00
0005433642650	2493	Economy	29900.00
0005432954007	2493	Economy	29900.00
0005433642647	2493	Economy	29900.00
0005432954058	2493	Economy	29900.00
0005432954012	2493	Economy	29900.00
0005433642637	2493	Economy	29900.00
0005433642646	2493	Economy	29900.00
0005433642638	2493	Economy	29900.00
0005433642652	2493	Economy	29900.00
0005433642635	2493	Economy	29900.00
0005433642632	2493	Economy	29900.00
0005433642641	2493	Economy	29900.00
0005432954039	2493	Economy	29900.00
0005433642656	2493	Economy	29900.00
0005433642644	2493	Economy	29900.00
0005433642636	2493	Economy	29900.00
0005433642640	2493	Economy	29900.00
0005433642648	2493	Economy	29900.00
0005433642631	2493	Economy	29900.00
0005432954031	2493	Economy	29900.00
0005433642629	2493	Economy	29900.00
0005432954097	27600	Business	89600.00
0005433642544	27600	Business	89600.00
0005432954101	27600	Business	89600.00
0005433642475	27600	Business	89600.00
0005432954108	27600	Business	89600.00
0005433642519	27600	Business	89600.00
0005433642495	27600	Business	89600.00
0005433642486	27600	Business	89600.00
0005433642425	27600	Business	89600.00
0005433642550	27600	Economy	29900.00
0005432954104	27600	Economy	29900.00
0005432954102	27600	Economy	29900.00
0005432954110	27600	Economy	29900.00
0005432954095	27600	Economy	29900.00
0005433642441	27600	Economy	29900.00
0005432954116	27600	Economy	29900.00
0005432954111	27600	Economy	29900.00
0005433642517	27600	Economy	32800.00
0005433642420	27600	Economy	32800.00
0005433642575	27600	Economy	32800.00
0005433642545	27600	Economy	32800.00
0005432954100	27600	Economy	32800.00
0005433642540	27600	Economy	29900.00
0005433642514	27600	Economy	29900.00
0005433642421	27600	Economy	29900.00
0005432954103	27600	Economy	29900.00
0005433642548	27600	Economy	29900.00
0005432954105	27600	Economy	29900.00
0005433642526	27600	Economy	29900.00
0005433642482	27600	Economy	29900.00
0005433642521	27600	Economy	29900.00
0005433642513	27600	Economy	29900.00
0005432954114	27600	Economy	29900.00
0005432954091	27600	Economy	29900.00
0005433642454	27600	Economy	29900.00
0005433642499	27600	Economy	29900.00
0005433642527	27600	Economy	29900.00
0005432954113	27600	Economy	29900.00
0005433642481	27600	Economy	29900.00
0005433642416	27600	Economy	29900.00
0005433642474	27600	Economy	29900.00
0005433642549	27600	Economy	29900.00
0005433642576	27600	Economy	29900.00
0005433642533	27600	Economy	29900.00
0005433642492	27600	Economy	29900.00
0005433642543	27600	Economy	29900.00
0005433642460	27600	Economy	29900.00
0005433642461	27600	Economy	29900.00
0005433642491	27600	Economy	29900.00
0005433642479	27600	Economy	29900.00
0005432954098	27600	Economy	29900.00
0005432954094	27600	Economy	29900.00
0005433642498	27600	Economy	29900.00
0005432954115	27600	Economy	29900.00
0005432954107	27600	Economy	29900.00
0005433642511	27600	Economy	29900.00
0005433642477	27600	Economy	29900.00
0005433642536	27600	Economy	29900.00
0005433642494	27600	Economy	29900.00
0005433642488	27600	Economy	29900.00
0005433642485	27600	Economy	29900.00
0005433642424	27600	Economy	29900.00
0005433642551	27600	Economy	29900.00
0005433642572	27600	Economy	29900.00
0005433642505	27600	Economy	29900.00
0005432954092	27600	Economy	29900.00
0005433642470	27600	Economy	29900.00
0005433642487	27600	Economy	29900.00
0005433642571	27600	Economy	29900.00
0005433642446	27600	Economy	29900.00
0005432954109	27600	Economy	29900.00
0005433642516	27600	Economy	29900.00
0005432954099	27600	Economy	29900.00
0005433642532	27600	Economy	29900.00
0005433642478	27600	Economy	29900.00
0005433642552	27600	Economy	29900.00
0005433642538	27600	Economy	29900.00
0005432954093	27600	Economy	29900.00
0005432954090	27600	Economy	29900.00
0005432954096	27600	Economy	29900.00
0005433642578	27600	Economy	29900.00
0005432954106	27600	Economy	29900.00
0005433642547	27600	Economy	29900.00
0005433642493	27600	Economy	29900.00
0005432954112	27600	Economy	29900.00
0005432425381	13378	Business	12700.00
0005432425416	13378	Business	12700.00
0005432425397	13378	Business	12700.00
0005432425401	13378	Business	12700.00
0005432425379	13378	Business	12700.00
0005432425425	13378	Business	12700.00
0005432425423	13378	Economy	4200.00
0005432425419	13378	Economy	4200.00
0005432425408	13378	Economy	4200.00
0005432425384	13378	Economy	4200.00
0005432425426	13378	Economy	4700.00
0005432425407	13378	Economy	4700.00
0005432425395	13378	Economy	4700.00
0005432425388	13378	Economy	4700.00
0005432425412	13378	Economy	4200.00
0005432425406	13378	Economy	4200.00
0005432425409	13378	Economy	4200.00
0005432425422	13378	Economy	4200.00
0005432425405	13378	Economy	4200.00
0005432425421	13378	Economy	4200.00
0005432425400	13378	Economy	4200.00
0005432425417	13378	Economy	4200.00
0005432425378	13378	Economy	4200.00
0005432425382	13378	Economy	4200.00
0005432425396	13378	Economy	4200.00
0005432425413	13378	Economy	4200.00
0005432425399	13378	Economy	4200.00
0005432425386	13378	Economy	4200.00
0005432425411	13378	Economy	4200.00
0005432425393	13378	Economy	4200.00
0005432425414	13378	Economy	4200.00
0005432425410	13378	Economy	4200.00
0005432425404	13378	Economy	4200.00
0005432425389	13378	Economy	4200.00
0005432425402	13378	Economy	4200.00
0005432425390	13378	Economy	4200.00
0005432425385	13378	Economy	4200.00
0005432425392	13378	Economy	4200.00
0005432425383	13378	Economy	4200.00
0005432425391	13378	Economy	4200.00
0005432425403	13378	Economy	4200.00
0005432425420	13378	Economy	4200.00
0005432425398	13378	Economy	4200.00
0005432425418	13378	Economy	4200.00
0005432425394	13378	Economy	4200.00
0005432425415	13378	Economy	4200.00
0005432425424	13378	Economy	4200.00
0005432425380	13378	Economy	4200.00
0005432425387	13378	Economy	4200.00
0005432424993	30776	Business	12700.00
0005432424895	30776	Business	12700.00
0005432424892	30776	Business	12700.00
0005432424940	30776	Business	12700.00
0005432424861	30776	Business	12700.00
0005432425044	30776	Business	12700.00
0005432425005	30776	Business	12700.00
0005432424969	30776	Business	12700.00
0005432425003	30776	Economy	4200.00
0005432424917	30776	Economy	4200.00
0005432425068	30776	Economy	4200.00
0005432425067	30776	Economy	4200.00
0005432424890	30776	Economy	4200.00
0005432424872	30776	Economy	4200.00
0005432425043	30776	Economy	4200.00
0005432425074	30776	Economy	4700.00
0005432424966	30776	Economy	4700.00
0005432424882	30776	Economy	4200.00
0005432424883	30776	Economy	4200.00
0005432424939	30776	Economy	4200.00
0005432424886	30776	Economy	4200.00
0005432425036	30776	Economy	4200.00
0005432425042	30776	Economy	4200.00
0005432425055	30776	Economy	4200.00
0005432425053	30776	Economy	4200.00
0005432424967	30776	Economy	4200.00
0005432425001	30776	Economy	4200.00
0005432424979	30776	Economy	4200.00
0005432424971	30776	Economy	4200.00
0005432424905	30776	Economy	4200.00
0005432424953	30776	Economy	4200.00
0005432424976	30776	Economy	4200.00
0005432424936	30776	Economy	4200.00
0005432424952	30776	Economy	4200.00
0005432425007	30776	Economy	4200.00
0005432424837	30776	Economy	4200.00
0005432424978	30776	Economy	4200.00
0005432425006	30776	Economy	4200.00
0005432424911	30776	Economy	4200.00
0005432425054	30776	Economy	4200.00
0005432424931	30776	Economy	4200.00
0005432424943	30776	Economy	4200.00
0005432425002	30776	Economy	4200.00
0005432424954	30776	Economy	4200.00
0005432425041	30776	Economy	4200.00
0005432424904	30776	Economy	4200.00
0005432425024	30776	Economy	4200.00
0005432425056	30776	Economy	4200.00
0005432424918	30776	Economy	4200.00
0005432424987	30776	Economy	4200.00
0005432424891	30776	Economy	4200.00
0005432425010	30776	Economy	4200.00
0005432425058	30776	Economy	4200.00
0005432818072	9610	Business	32600.00
0005432901816	9610	Business	32600.00
0005432901873	9610	Business	32600.00
0005432901775	9610	Business	32600.00
0005434157564	9610	Business	32600.00
0005432901858	9610	Business	32600.00
0005432901918	9610	Business	32600.00
0005432822363	9610	Business	32600.00
0005434157579	9610	Business	32600.00
0005432822361	9610	Business	32600.00
0005434157570	9610	Economy	10900.00
0005432822360	9610	Economy	10900.00
0005432901784	9610	Economy	10900.00
0005432818080	9610	Economy	10900.00
0005432818076	9610	Economy	10900.00
0005432289052	9610	Economy	10900.00
0005434448386	9610	Economy	10900.00
0005432289056	9610	Economy	10900.00
0005432818075	9610	Economy	10900.00
0005434157581	9610	Economy	11900.00
0005432818065	9610	Economy	11900.00
0005432901795	9610	Economy	11900.00
0005434157613	9610	Economy	10900.00
0005432818077	9610	Economy	10900.00
0005432818092	9610	Economy	10900.00
0005432818085	9610	Economy	10900.00
0005432818069	9610	Economy	10900.00
0005432818073	9610	Economy	10900.00
0005432901773	9610	Economy	10900.00
0005434157580	9610	Economy	10900.00
0005432822358	9610	Economy	10900.00
0005432901774	9610	Economy	10900.00
0005432901807	9610	Economy	10900.00
0005432289055	9610	Economy	10900.00
0005432818078	9610	Economy	10900.00
0005432822357	9610	Economy	10900.00
0005432818070	9610	Economy	10900.00
0005432818086	9610	Economy	10900.00
0005434448387	9610	Economy	10900.00
0005432901919	9610	Economy	10900.00
0005432818087	9610	Economy	10900.00
0005432901857	9610	Economy	10900.00
0005434448384	9610	Economy	10900.00
0005432818068	9610	Economy	10900.00
0005432818088	9610	Economy	10900.00
0005434157571	9610	Economy	10900.00
0005432818074	9610	Economy	10900.00
0005434157563	9610	Economy	10900.00
0005432901841	9610	Economy	10900.00
0005432818064	9610	Economy	10900.00
0005432289053	9610	Economy	10900.00
0005432818079	9610	Economy	10900.00
0005434157612	9610	Economy	10900.00
0005432818084	9610	Economy	10900.00
0005432818089	9610	Economy	10900.00
0005432818063	9610	Economy	10900.00
0005434157529	9610	Economy	10900.00
0005432818081	9610	Economy	10900.00
0005432901825	9610	Economy	10900.00
0005432822362	9610	Economy	10900.00
0005432818083	9610	Economy	10900.00
0005432818066	9610	Economy	10900.00
0005434448385	9610	Economy	10900.00
0005432818067	9610	Economy	10900.00
0005432818062	9610	Economy	10900.00
0005432822359	9610	Economy	10900.00
0005434157545	9610	Economy	10900.00
0005432822364	9610	Economy	10900.00
0005432901817	9610	Economy	10900.00
0005432818091	9610	Economy	10900.00
0005432818071	9610	Economy	10900.00
0005432818090	9610	Economy	10900.00
0005432818082	9610	Economy	10900.00
0005432289054	9610	Economy	10900.00
0005432901808	9610	Economy	10900.00
0005432901959	28967	Business	32600.00
0005432822291	28967	Business	32600.00
0005432817805	28967	Business	32600.00
0005432817737	28967	Business	32600.00
0005432901973	28967	Business	32600.00
0005432817847	28967	Business	32600.00
0005432817894	28967	Business	32600.00
0005432817879	28967	Business	32600.00
0005432817895	28967	Business	32600.00
0005432817824	28967	Economy	10900.00
0005432901961	28967	Economy	10900.00
0005432822315	28967	Economy	10900.00
0005432817738	28967	Economy	10900.00
0005432822251	28967	Economy	10900.00
0005432822292	28967	Economy	10900.00
0005432817812	28967	Economy	10900.00
0005432817840	28967	Economy	10900.00
0005434186258	28967	Economy	10900.00
0005432818031	28967	Economy	11900.00
0005432901975	28967	Economy	11900.00
0005432817904	28967	Economy	11900.00
0005434157635	28967	Economy	10900.00
0005432817853	28967	Economy	10900.00
0005434157637	28967	Economy	10900.00
0005434186256	28967	Economy	10900.00
0005432901971	28967	Economy	10900.00
0005432817920	28967	Economy	10900.00
0005432901969	28967	Economy	10900.00
0005432817838	28967	Economy	10900.00
0005434157636	28967	Economy	10900.00
0005432901964	28967	Economy	10900.00
0005432817901	28967	Economy	10900.00
0005432002118	28967	Economy	10900.00
0005432817903	28967	Economy	10900.00
0005432901960	28967	Economy	10900.00
0005432822217	28967	Economy	10900.00
0005434448356	28967	Economy	10900.00
0005432817767	28967	Economy	10900.00
0005432817813	28967	Economy	10900.00
0005432817900	28967	Economy	10900.00
0005434157642	28967	Economy	10900.00
0005432817872	28967	Economy	10900.00
0005432817808	28967	Economy	10900.00
0005432901968	28967	Economy	10900.00
0005432901976	28967	Economy	10900.00
0005432822290	28967	Economy	10900.00
0005432817897	28967	Economy	10900.00
0005432817792	28967	Economy	10900.00
0005432817716	28967	Economy	10900.00
0005432901974	28967	Economy	10900.00
0005434157641	28967	Economy	10900.00
0005432901970	28967	Economy	10900.00
0005432901967	28967	Economy	10900.00
0005432817839	28967	Economy	10900.00
0005432817788	28967	Economy	10900.00
0005434186257	28967	Economy	10900.00
0005432822307	28967	Economy	10900.00
0005434157639	28967	Economy	10900.00
0005432817905	28967	Economy	10900.00
0005434157638	28967	Economy	10900.00
0005432901963	28967	Economy	10900.00
0005432817636	28967	Economy	10900.00
0005432817924	28967	Economy	10900.00
0005432817726	28967	Economy	10900.00
0005432817820	28967	Economy	10900.00
0005432817768	28967	Economy	10900.00
0005432822265	28967	Economy	10900.00
0005432901972	28967	Economy	10900.00
0005432901966	28967	Economy	10900.00
0005432901965	28967	Economy	10900.00
0005432817727	28967	Economy	10900.00
0005432817799	28967	Economy	10900.00
0005432002119	28967	Economy	10900.00
0005432817714	28967	Economy	10900.00
0005432817831	28967	Economy	10900.00
0005432817823	28967	Economy	10900.00
0005432817798	28967	Economy	10900.00
0005434157640	28967	Economy	10900.00
0005432901962	28967	Economy	10900.00
0005432817822	28967	Economy	10900.00
0005432817793	28967	Economy	10900.00
0005432613947	15031	Economy	11000.00
0005432611781	15031	Economy	11000.00
0005432613948	15031	Economy	11000.00
0005432611783	15031	Economy	11000.00
0005432613945	15031	Economy	11000.00
0005432613946	15031	Economy	11000.00
0005435841101	15031	Economy	11000.00
0005435841100	15031	Economy	11000.00
0005432611782	15031	Economy	11000.00
0005435842343	31594	Economy	11000.00
0005435841839	31594	Economy	11000.00
0005432611764	31594	Economy	11000.00
0005432611752	31594	Economy	11000.00
0005435842344	31594	Economy	11000.00
0005432611758	31594	Economy	11000.00
0005432611765	31594	Economy	11000.00
0005432948738	11884	Business	105900.00
0005433570238	11884	Business	105900.00
0005433570253	11884	Business	105900.00
0005433570268	11884	Business	105900.00
0005433570221	11884	Business	105900.00
0005432948870	11884	Business	105900.00
0005433570262	11884	Business	105900.00
0005433570259	11884	Business	105900.00
0005433570269	11884	Business	105900.00
0005433570233	11884	Business	105900.00
0005433570249	11884	Business	105900.00
0005433570220	11884	Business	105900.00
0005433570232	11884	Business	105900.00
0005433570277	11884	Business	105900.00
0005433570231	11884	Business	105900.00
0005433570270	11884	Business	105900.00
0005433570235	11884	Business	105900.00
0005433570263	11884	Business	105900.00
0005432949066	11884	Business	105900.00
0005433570247	11884	Economy	35300.00
0005433570218	11884	Economy	35300.00
0005432948658	11884	Economy	35300.00
0005432948794	11884	Economy	35300.00
0005432948815	11884	Economy	35300.00
0005432948871	11884	Economy	35300.00
0005433570288	11884	Economy	35300.00
0005432948934	11884	Economy	35300.00
0005432949067	11884	Economy	35300.00
0005433570286	11884	Economy	35300.00
0005433570248	11884	Economy	35300.00
0005433570271	11884	Economy	35300.00
0005433570265	11884	Economy	38800.00
0005432948948	11884	Economy	38800.00
0005433570227	11884	Economy	38800.00
0005433570229	11884	Economy	38800.00
0005432948867	11884	Economy	35300.00
0005433570254	11884	Economy	35300.00
0005433570266	11884	Economy	35300.00
0005433570272	11884	Economy	35300.00
0005432948865	11884	Economy	35300.00
0005433570283	11884	Economy	35300.00
0005432948795	11884	Economy	35300.00
0005432949038	11884	Economy	35300.00
0005432948842	11884	Economy	35300.00
0005433570275	11884	Economy	35300.00
0005432948944	11884	Economy	35300.00
0005433570225	11884	Economy	35300.00
0005432948947	11884	Economy	35300.00
0005433570219	11884	Economy	35300.00
0005433570273	11884	Economy	35300.00
0005433570279	11884	Economy	35300.00
0005433570228	11884	Economy	35300.00
0005432948857	11884	Economy	35300.00
0005432948806	11884	Economy	35300.00
0005432948936	11884	Economy	35300.00
0005432948645	11884	Economy	35300.00
0005433570276	11884	Economy	35300.00
0005433570287	11884	Economy	35300.00
0005432948866	11884	Economy	35300.00
0005433570267	11884	Economy	35300.00
0005433570245	11884	Economy	35300.00
0005432948723	11884	Economy	35300.00
0005433570234	11884	Economy	35300.00
0005433570285	11884	Economy	35300.00
0005432948856	11884	Economy	35300.00
0005433570258	11884	Economy	35300.00
0005433570261	11884	Economy	35300.00
0005433570257	11884	Economy	35300.00
0005432948894	11884	Economy	35300.00
0005432948864	11884	Economy	35300.00
0005433570230	11884	Economy	35300.00
0005433570246	11884	Economy	35300.00
0005432949097	11884	Economy	35300.00
0005433570256	11884	Economy	35300.00
0005433570250	11884	Economy	35300.00
0005433570223	11884	Economy	35300.00
0005432948945	11884	Economy	35300.00
0005433570216	11884	Economy	35300.00
0005432948686	11884	Economy	35300.00
0005433570274	11884	Economy	35300.00
0005433570242	11884	Economy	35300.00
0005433570260	11884	Economy	35300.00
0005433570281	11884	Economy	35300.00
0005433570280	11884	Economy	35300.00
0005432949019	11884	Economy	35300.00
0005433570239	11884	Economy	35300.00
0005433570278	11884	Economy	35300.00
0005433570236	11884	Economy	35300.00
0005432948935	11884	Economy	35300.00
0005433570284	11884	Economy	35300.00
0005433570241	11884	Economy	35300.00
0005433570243	11884	Economy	35300.00
0005433570255	11884	Economy	35300.00
0005433570217	11884	Economy	35300.00
0005432948754	11884	Economy	35300.00
0005433570282	11884	Economy	35300.00
0005432948895	11884	Economy	35300.00
0005433570290	11884	Economy	35300.00
0005433570244	11884	Economy	35300.00
0005433570226	11884	Economy	35300.00
0005432949068	11884	Economy	35300.00
0005433570264	11884	Economy	35300.00
0005433570252	11884	Economy	35300.00
0005432949065	11884	Economy	35300.00
0005433570237	11884	Economy	35300.00
0005433570224	11884	Economy	35300.00
0005433570251	11884	Economy	35300.00
0005433570240	11884	Economy	35300.00
0005433570222	11884	Economy	35300.00
0005433570289	11884	Economy	35300.00
0005432948990	11884	Economy	35300.00
0005432949335	25313	Business	105900.00
0005433569669	25313	Business	105900.00
0005432949320	25313	Business	105900.00
0005433569818	25313	Business	105900.00
0005433569616	25313	Business	105900.00
0005433569726	25313	Business	105900.00
0005432949336	25313	Business	105900.00
0005432949329	25313	Business	105900.00
0005432949315	25313	Business	105900.00
0005433569762	25313	Business	105900.00
0005432949338	25313	Business	105900.00
0005433569736	25313	Business	105900.00
0005433569625	25313	Business	105900.00
0005433569552	25313	Business	105900.00
0005432949343	25313	Business	105900.00
0005432949313	25313	Business	105900.00
0005432949310	25313	Economy	35300.00
0005432949308	25313	Business	105900.00
0005433569610	25313	Economy	35300.00
0005433569789	25313	Economy	35300.00
0005432949314	25313	Economy	35300.00
0005432949341	25313	Economy	35300.00
0005433569680	25313	Economy	35300.00
0005433569780	25313	Economy	35300.00
0005432949317	25313	Economy	35300.00
0005432949311	25313	Economy	35300.00
0005432949319	25313	Economy	35300.00
0005433569723	25313	Economy	35300.00
0005433569810	25313	Economy	38800.00
0005433569619	25313	Economy	38800.00
0005432949309	25313	Economy	38800.00
0005433569749	25313	Economy	38800.00
0005433569533	25313	Economy	35300.00
0005433569379	25313	Economy	35300.00
0005432949346	25313	Economy	35300.00
0005433569878	25313	Economy	35300.00
0005432949337	25313	Economy	35300.00
0005433569865	25313	Economy	35300.00
0005433569764	25313	Economy	35300.00
0005433569378	25313	Economy	35300.00
0005433569724	25313	Economy	35300.00
0005433569765	25313	Economy	35300.00
0005433569894	25313	Economy	35300.00
0005433569725	25313	Economy	35300.00
0005432949345	25313	Economy	35300.00
0005433569864	25313	Economy	35300.00
0005432949327	25313	Economy	35300.00
0005432949318	25313	Economy	35300.00
0005433569584	25313	Economy	35300.00
0005432949325	25313	Economy	35300.00
0005432949347	25313	Economy	35300.00
0005433569788	25313	Economy	35300.00
0005433569779	25313	Economy	35300.00
0005432949333	25313	Economy	35300.00
0005432949321	25313	Economy	35300.00
0005433569801	25313	Economy	35300.00
0005432949322	25313	Economy	35300.00
0005433569927	25313	Economy	35300.00
0005433569506	25313	Economy	35300.00
0005433569626	25313	Economy	35300.00
0005433569866	25313	Economy	35300.00
0005433569576	25313	Economy	35300.00
0005433569900	25313	Economy	35300.00
0005433569561	25313	Economy	35300.00
0005433569560	25313	Economy	35300.00
0005432949342	25313	Economy	35300.00
0005432949316	25313	Economy	35300.00
0005432949332	25313	Economy	35300.00
0005432949340	25313	Economy	35300.00
0005432949326	25313	Economy	35300.00
0005432949339	25313	Economy	35300.00
0005433569709	25313	Economy	35300.00
0005433569763	25313	Economy	35300.00
0005433569895	25313	Economy	35300.00
0005432949324	25313	Economy	35300.00
0005433569826	25313	Economy	35300.00
0005432949328	25313	Economy	35300.00
0005433569642	25313	Economy	35300.00
0005432949330	25313	Economy	35300.00
0005432949348	25313	Economy	35300.00
0005433569685	25313	Economy	35300.00
0005432949331	25313	Economy	35300.00
0005433569844	25313	Economy	35300.00
0005433569675	25313	Economy	35300.00
0005433569877	25313	Economy	35300.00
0005432949312	25313	Economy	35300.00
0005433569872	25313	Economy	35300.00
0005433569759	25313	Economy	35300.00
0005432949323	25313	Economy	35300.00
0005433569827	25313	Economy	35300.00
0005432949334	25313	Economy	35300.00
0005432949344	25313	Economy	35300.00
0005433569600	25313	Economy	35300.00
0005433569482	25313	Economy	35300.00
0005433569782	25313	Economy	35300.00
0005433569544	25313	Economy	35300.00
0005433569781	25313	Economy	35300.00
0005433569831	25313	Economy	35300.00
0005433569577	25313	Economy	35300.00
0005433569676	25313	Economy	35300.00
0005433569853	25313	Economy	35300.00
0005434656597	5394	Business	67200.00
0005434655295	5394	Business	67200.00
0005434655286	5394	Business	67200.00
0005435340416	5394	Business	67200.00
0005435340417	5394	Business	67200.00
0005434655274	5394	Business	67200.00
0005435340528	5394	Business	67200.00
0005434655272	5394	Business	67200.00
0005434655269	5394	Economy	22400.00
0005434655289	5394	Economy	22400.00
0005434655268	5394	Economy	22400.00
0005434655280	5394	Economy	22400.00
0005434655275	5394	Economy	22400.00
0005435340471	5394	Economy	22400.00
0005435340457	5394	Economy	24600.00
0005434655271	5394	Economy	24600.00
0005435340469	5394	Economy	24600.00
0005434655294	5394	Economy	22400.00
0005434655283	5394	Economy	22400.00
0005434655270	5394	Economy	22400.00
0005434655284	5394	Economy	22400.00
0005434655287	5394	Economy	22400.00
0005432114270	5394	Economy	22400.00
0005434655276	5394	Economy	22400.00
0005434655273	5394	Economy	22400.00
0005435340444	5394	Economy	22400.00
0005434655282	5394	Economy	22400.00
0005432114269	5394	Economy	22400.00
0005435340425	5394	Economy	22400.00
0005434655277	5394	Economy	22400.00
0005435340337	5394	Economy	22400.00
0005434655278	5394	Economy	22400.00
0005432114268	5394	Economy	22400.00
0005435340458	5394	Economy	22400.00
0005434655285	5394	Economy	22400.00
0005434655293	5394	Economy	22400.00
0005434655292	5394	Economy	22400.00
0005435340389	5394	Economy	22400.00
0005434656596	5394	Economy	22400.00
0005434655290	5394	Economy	22400.00
0005434655288	5394	Economy	22400.00
0005435340503	5394	Economy	22400.00
0005435340415	5394	Economy	22400.00
0005434655281	5394	Economy	22400.00
0005435340418	5394	Economy	22400.00
0005435340470	5394	Economy	22400.00
0005435555389	5394	Economy	22400.00
0005435340468	5394	Economy	22400.00
0005435340484	5394	Economy	22400.00
0005434655279	5394	Economy	22400.00
0005435340504	5394	Economy	22400.00
0005434655291	5394	Economy	22400.00
0005434655004	12509	Business	67200.00
0005434656581	12509	Business	67200.00
0005435340568	12509	Business	67200.00
0005434654957	12509	Economy	22400.00
0005435340578	12509	Economy	22400.00
0005434656582	12509	Economy	22400.00
0005434655164	12509	Economy	22400.00
0005435340581	12509	Economy	22400.00
0005434655058	12509	Economy	24600.00
0005434655084	12509	Economy	24600.00
0005435340573	12509	Economy	24600.00
0005435340574	12509	Economy	22400.00
0005434655085	12509	Economy	22400.00
0005435340579	12509	Economy	22400.00
0005435340575	12509	Economy	22400.00
0005434655072	12509	Economy	22400.00
0005434655070	12509	Economy	22400.00
0005435340570	12509	Economy	22400.00
0005435340577	12509	Economy	22400.00
0005435340567	12509	Economy	22400.00
0005434655112	12509	Economy	22400.00
0005434655061	12509	Economy	22400.00
0005434655057	12509	Economy	22400.00
0005435340572	12509	Economy	22400.00
0005435555414	12509	Economy	22400.00
0005434655095	12509	Economy	22400.00
0005435340580	12509	Economy	22400.00
0005434655111	12509	Economy	22400.00
0005435555413	12509	Economy	22400.00
0005435340571	12509	Economy	22400.00
0005435340566	12509	Economy	22400.00
0005434655096	12509	Economy	22400.00
0005434655094	12509	Economy	22400.00
0005435340576	12509	Economy	22400.00
0005434655073	12509	Economy	22400.00
0005435340569	12509	Economy	22400.00
0005433717005	7414	Business	32000.00
0005433716964	7414	Business	32000.00
0005433716984	7414	Business	32000.00
0005433716970	7414	Business	32000.00
0005432078221	7414	Business	32000.00
0005435266183	7414	Business	32000.00
0005433716978	7414	Business	32000.00
0005432428959	7414	Business	32000.00
0005433716997	7414	Business	32000.00
0005433716967	7414	Economy	10700.00
0005433716980	7414	Economy	10700.00
0005433716981	7414	Economy	10700.00
0005433719209	7414	Economy	10700.00
0005433716985	7414	Economy	10700.00
0005433716992	7414	Economy	10700.00
0005433716991	7414	Economy	10700.00
0005433717002	7414	Economy	10700.00
0005433716973	7414	Economy	10700.00
0005435266190	7414	Economy	10700.00
0005433716975	7414	Economy	10700.00
0005433717004	7414	Economy	10700.00
0005433716982	7414	Economy	10700.00
0005433716996	7414	Economy	10700.00
0005433717006	7414	Economy	10700.00
0005433716986	7414	Economy	10700.00
0005435266188	7414	Economy	10700.00
0005433722350	7414	Economy	10700.00
0005432078219	7414	Economy	10700.00
0005433719206	7414	Economy	10700.00
0005433716994	7414	Economy	10700.00
0005433689952	7414	Economy	10700.00
0005435266187	7414	Economy	10700.00
0005433716962	7414	Economy	10700.00
0005432428946	7414	Economy	10700.00
0005432428958	7414	Economy	10700.00
0005433717000	7414	Economy	10700.00
0005432078222	7414	Economy	10700.00
0005433717010	7414	Economy	10700.00
0005432078220	7414	Economy	10700.00
0005433656736	7414	Economy	11700.00
0005433656735	7414	Economy	11700.00
0005433722347	7414	Economy	11700.00
0005433690965	7414	Economy	11700.00
0005432428957	7414	Economy	10700.00
0005433716971	7414	Economy	10700.00
0005432428961	7414	Economy	10700.00
0005433716966	7414	Economy	10700.00
0005435266189	7414	Economy	10700.00
0005433722351	7414	Economy	10700.00
0005433716989	7414	Economy	10700.00
0005433716968	7414	Economy	10700.00
0005433716990	7414	Economy	10700.00
0005433716993	7414	Economy	10700.00
0005433722349	7414	Economy	10700.00
0005432428960	7414	Economy	10700.00
0005433716963	7414	Economy	10700.00
0005433717003	7414	Economy	10700.00
0005433716976	7414	Economy	10700.00
0005433716972	7414	Economy	10700.00
0005435266185	7414	Economy	10700.00
0005433716998	7414	Economy	10700.00
0005435266191	7414	Economy	10700.00
0005432078223	7414	Economy	10700.00
0005433719208	7414	Economy	10700.00
0005433716983	7414	Economy	10700.00
0005433656737	7414	Economy	10700.00
0005433656738	7414	Economy	10700.00
0005433717001	7414	Economy	10700.00
0005433716988	7414	Economy	10700.00
0005433716961	7414	Economy	10700.00
0005433716969	7414	Economy	10700.00
0005433717009	7414	Economy	10700.00
0005433716977	7414	Economy	10700.00
0005433716987	7414	Economy	10700.00
0005435266184	7414	Economy	10700.00
0005433717007	7414	Economy	10700.00
0005433716974	7414	Economy	10700.00
0005433689951	7414	Economy	10700.00
0005433716999	7414	Economy	10700.00
0005433716965	7414	Economy	10700.00
0005433722348	7414	Economy	10700.00
0005433716995	7414	Economy	10700.00
0005433716979	7414	Economy	10700.00
0005433717008	7414	Economy	10700.00
0005433689953	7414	Economy	10700.00
0005433719207	7414	Economy	10700.00
0005432429000	29224	Business	32000.00
0005433716433	29224	Business	32000.00
0005433716500	29224	Business	32000.00
0005433716456	29224	Business	32000.00
0005433716453	29224	Business	32000.00
0005433716467	29224	Business	32000.00
0005433716341	29224	Business	32000.00
0005433716490	29224	Economy	10700.00
0005433716473	29224	Economy	10700.00
0005432006822	29224	Economy	10700.00
0005433716554	29224	Economy	10700.00
0005433719175	29224	Economy	10700.00
0005433722294	29224	Economy	10700.00
0005433722285	29224	Economy	10700.00
0005433685537	29224	Economy	10700.00
0005433716651	29224	Economy	10700.00
0005433716637	29224	Economy	10700.00
0005435266265	29224	Economy	10700.00
0005433722303	29224	Economy	10700.00
0005433716577	29224	Economy	10700.00
0005433716513	29224	Economy	10700.00
0005435266259	29224	Economy	10700.00
0005433716367	29224	Economy	10700.00
0005433716472	29224	Economy	10700.00
0005433716546	29224	Economy	10700.00
0005433722295	29224	Economy	10700.00
0005433716474	29224	Economy	10700.00
0005433716449	29224	Economy	10700.00
0005433716529	29224	Economy	10700.00
0005433716592	29224	Economy	10700.00
0005433716369	29224	Economy	10700.00
0005433716630	29224	Economy	11700.00
0005433722281	29224	Economy	11700.00
0005433716567	29224	Economy	10700.00
0005432006821	29224	Economy	11700.00
0005433716636	29224	Economy	10700.00
0005433722307	29224	Economy	10700.00
0005433719174	29224	Economy	10700.00
0005433716340	29224	Economy	10700.00
0005433716597	29224	Economy	10700.00
0005433685536	29224	Economy	10700.00
0005433716366	29224	Economy	10700.00
0005433656723	29224	Economy	10700.00
0005433716498	29224	Economy	10700.00
0005433716568	29224	Economy	10700.00
0005433716662	29224	Economy	10700.00
0005433716478	29224	Economy	10700.00
0005435266264	29224	Economy	10700.00
0005433722288	29224	Economy	10700.00
0005433722302	29224	Economy	10700.00
0005433716749	29224	Economy	10700.00
0005435266263	29224	Economy	10700.00
0005433719176	29224	Economy	10700.00
0005432428998	29224	Economy	10700.00
0005435266256	29224	Economy	10700.00
0005433716599	29224	Economy	10700.00
0005433716569	29224	Economy	10700.00
0005433722279	29224	Economy	10700.00
0005435266262	29224	Economy	10700.00
0005433716432	29224	Economy	10700.00
0005433716468	29224	Economy	10700.00
0005433716353	29224	Economy	10700.00
0005433716598	29224	Economy	10700.00
0005433716663	29224	Economy	10700.00
0005433716530	29224	Economy	10700.00
0005433716553	29224	Economy	10700.00
0005433716652	29224	Economy	10700.00
0005433716434	29224	Economy	10700.00
0005435266257	29224	Economy	10700.00
0005433656722	29224	Economy	10700.00
0005433716648	29224	Economy	10700.00
0005433716428	29224	Economy	10700.00
0005432429001	29224	Economy	10700.00
0005433716748	29224	Economy	10700.00
0005433716494	29224	Economy	10700.00
0005433716591	29224	Economy	10700.00
0005435266261	29224	Economy	10700.00
0005433716342	29224	Economy	10700.00
0005433722308	29224	Economy	10700.00
0005435266258	29224	Economy	10700.00
0005433716479	29224	Economy	10700.00
0005433685528	29224	Economy	10700.00
0005433716501	29224	Economy	10700.00
0005433716370	29224	Economy	10700.00
0005435266260	29224	Economy	10700.00
0005432428999	29224	Economy	10700.00
0005433716352	29224	Economy	10700.00
0005433719173	29224	Economy	10700.00
0005433716427	29224	Economy	10700.00
0005434095566	8659	Business	36500.00
0005434095568	8659	Business	36500.00
0005434184692	8659	Business	36500.00
0005434182311	8659	Business	36500.00
0005434095575	8659	Economy	12200.00
0005434095576	8659	Economy	12200.00
0005434095573	8659	Economy	12200.00
0005434095564	8659	Economy	13400.00
0005434095574	8659	Economy	12200.00
0005434182357	8659	Economy	12200.00
0005434182305	8659	Economy	12200.00
0005434095569	8659	Economy	12200.00
0005434182339	8659	Economy	12200.00
0005434095567	8659	Economy	12200.00
0005434095572	8659	Economy	12200.00
0005434182363	8659	Economy	12200.00
0005434095565	8659	Economy	12200.00
0005434095563	8659	Economy	12200.00
0005434095577	8659	Economy	12200.00
0005434182349	8659	Economy	12200.00
0005434095562	8659	Economy	12200.00
0005434095570	8659	Economy	12200.00
0005434095571	8659	Economy	12200.00
0005434095483	11656	Business	36500.00
0005434182446	11656	Business	36500.00
0005434095484	11656	Business	36500.00
0005434095438	11656	Economy	12200.00
0005434182445	11656	Economy	12200.00
0005434326274	11656	Economy	13400.00
0005435860643	11656	Economy	13400.00
0005434182444	11656	Economy	13400.00
0005434182442	11656	Economy	13400.00
0005434095485	11656	Economy	13400.00
0005434182443	11656	Economy	12200.00
0005434095439	11656	Economy	12200.00
0005434182439	11656	Economy	12200.00
0005434182437	11656	Economy	12200.00
0005434095478	11656	Economy	12200.00
0005434095489	11656	Economy	12200.00
0005434095408	11656	Economy	12200.00
0005434182436	11656	Economy	12200.00
0005434095418	11656	Economy	12200.00
0005434326276	11656	Economy	12200.00
0005434095454	11656	Economy	12200.00
0005434326275	11656	Economy	12200.00
0005434182438	11656	Economy	12200.00
0005434095417	11656	Economy	12200.00
0005434183619	11656	Economy	12200.00
0005434182441	11656	Economy	12200.00
0005434182435	11656	Economy	12200.00
0005434183620	11656	Economy	12200.00
0005434095421	11656	Economy	12200.00
0005434095423	11656	Economy	12200.00
0005434095407	11656	Economy	12200.00
0005434095446	11656	Economy	12200.00
0005434095490	11656	Economy	12200.00
0005434326277	11656	Economy	12200.00
0005434182440	11656	Economy	12200.00
0005434095477	11656	Economy	12200.00
0005433398732	1471	Business	33000.00
0005435732592	1471	Business	33000.00
0005433398636	1471	Business	33000.00
0005433398546	1471	Business	33000.00
0005433398804	1471	Business	33000.00
0005435732612	1471	Business	33000.00
0005435732599	1471	Business	33000.00
0005433398714	1471	Economy	11000.00
0005435732615	1471	Economy	11000.00
0005435732601	1471	Economy	11000.00
0005435732606	1471	Economy	11000.00
0005433398571	1471	Economy	11000.00
0005433398814	1471	Economy	11000.00
0005435732603	1471	Economy	11000.00
0005433398698	1471	Economy	11000.00
0005435732593	1471	Economy	11000.00
0005435732604	1471	Economy	12100.00
0005433398653	1471	Economy	12100.00
0005433398670	1471	Economy	11000.00
0005432297331	1471	Economy	11000.00
0005435732609	1471	Economy	11000.00
0005433457051	1471	Economy	11000.00
0005432297332	1471	Economy	11000.00
0005433398853	1471	Economy	11000.00
0005433398734	1471	Economy	11000.00
0005435732595	1471	Economy	11000.00
0005433398680	1471	Economy	11000.00
0005435732594	1471	Economy	11000.00
0005433398569	1471	Economy	11000.00
0005435732610	1471	Economy	11000.00
0005433457052	1471	Economy	11000.00
0005435732591	1471	Economy	11000.00
0005435732605	1471	Economy	11000.00
0005435732597	1471	Economy	11000.00
0005433398640	1471	Economy	11000.00
0005432297330	1471	Economy	11000.00
0005433398633	1471	Economy	11000.00
0005433398583	1471	Economy	11000.00
0005433398638	1471	Economy	11000.00
0005433398584	1471	Economy	11000.00
0005433398349	1471	Economy	11000.00
0005433398712	1471	Economy	11000.00
0005433398601	1471	Economy	11000.00
0005435732607	1471	Economy	11000.00
0005433398755	1471	Economy	11000.00
0005433398628	1471	Economy	11000.00
0005433398331	1471	Economy	11000.00
0005433398713	1471	Economy	11000.00
0005435732600	1471	Economy	11000.00
0005433398679	1471	Economy	11000.00
0005433398579	1471	Economy	11000.00
0005433398350	1471	Economy	11000.00
0005435732608	1471	Economy	11000.00
0005433398561	1471	Economy	11000.00
0005435732611	1471	Economy	11000.00
0005433398560	1471	Economy	11000.00
0005435732602	1471	Economy	11000.00
0005435732596	1471	Economy	11000.00
0005435732613	1471	Economy	11000.00
0005433398687	1471	Economy	11000.00
0005433398731	1471	Economy	11000.00
0005433457053	1471	Economy	11000.00
0005433398641	1471	Economy	11000.00
0005433398637	1471	Economy	11000.00
0005435732598	1471	Economy	11000.00
0005435732614	1471	Economy	11000.00
0005433398459	1471	Economy	11000.00
0005433399035	19251	Business	33000.00
0005435732519	19251	Business	33000.00
0005433399027	19251	Business	33000.00
0005433399031	19251	Business	33000.00
0005433399038	19251	Business	33000.00
0005433399065	19251	Business	33000.00
0005433399067	19251	Business	33000.00
0005433399024	19251	Economy	11000.00
0005435732527	19251	Economy	11000.00
0005433399029	19251	Economy	11000.00
0005433399046	19251	Economy	11000.00
0005433399055	19251	Economy	11000.00
0005433399047	19251	Economy	11000.00
0005435732469	19251	Economy	11000.00
0005433399045	19251	Economy	12100.00
0005433399048	19251	Economy	12100.00
0005433399066	19251	Economy	12100.00
0005433399050	19251	Economy	11000.00
0005433399030	19251	Economy	11000.00
0005433399026	19251	Economy	11000.00
0005433399032	19251	Economy	11000.00
0005435732526	19251	Economy	11000.00
0005433399064	19251	Economy	11000.00
0005433399033	19251	Economy	11000.00
0005433457016	19251	Economy	11000.00
0005432906586	19251	Economy	11000.00
0005433399040	19251	Economy	11000.00
0005433399060	19251	Economy	11000.00
0005435732501	19251	Economy	11000.00
0005433399042	19251	Economy	11000.00
0005433399063	19251	Economy	11000.00
0005435732436	19251	Economy	11000.00
0005433399056	19251	Economy	11000.00
0005433399036	19251	Economy	11000.00
0005432906587	19251	Economy	11000.00
0005433399039	19251	Economy	11000.00
0005435732522	19251	Economy	11000.00
0005433399037	19251	Economy	11000.00
0005433399057	19251	Economy	11000.00
0005433399025	19251	Economy	11000.00
0005433399051	19251	Economy	11000.00
0005435732486	19251	Economy	11000.00
0005433399058	19251	Economy	11000.00
0005433399052	19251	Economy	11000.00
0005433399059	19251	Economy	11000.00
0005433457028	19251	Economy	11000.00
0005435732521	19251	Economy	11000.00
0005433457017	19251	Economy	11000.00
0005433399041	19251	Economy	11000.00
0005433399021	19251	Economy	11000.00
0005433399053	19251	Economy	11000.00
0005433399043	19251	Economy	11000.00
0005433399022	19251	Economy	11000.00
0005433399061	19251	Economy	11000.00
0005435732523	19251	Economy	11000.00
0005435732442	19251	Economy	11000.00
0005433399023	19251	Economy	11000.00
0005433399028	19251	Economy	11000.00
0005433399044	19251	Economy	11000.00
0005433399019	19251	Economy	11000.00
0005433399049	19251	Economy	11000.00
0005433399062	19251	Economy	11000.00
0005435732507	19251	Economy	11000.00
0005433399054	19251	Economy	11000.00
0005433399020	19251	Economy	11000.00
0005435732492	19251	Economy	11000.00
0005435732506	19251	Economy	11000.00
0005433399034	19251	Economy	11000.00
0005434443801	17385	Economy	15600.00
0005434443931	17385	Economy	15600.00
0005434443891	17385	Economy	15600.00
0005434443911	17385	Economy	14100.00
0005434443917	17385	Economy	14100.00
0005434443877	17385	Economy	14100.00
0005434443929	17385	Economy	14100.00
0005434443932	17385	Economy	14100.00
0005434443884	17385	Economy	14100.00
0005434443952	17385	Economy	14100.00
0005434443885	17385	Economy	14100.00
0005434443920	17385	Economy	14100.00
0005434443890	17385	Economy	14100.00
0005434443869	17385	Economy	14100.00
0005434443799	17385	Economy	14100.00
0005434443916	17385	Economy	14100.00
0005434443930	17385	Economy	14100.00
0005434443878	17385	Economy	14100.00
0005434443921	17385	Economy	14100.00
0005434443800	17385	Economy	14100.00
0005434443900	17385	Economy	14100.00
0005434443807	17385	Economy	14100.00
0005434443935	17385	Economy	14100.00
0005434444029	20574	Economy	15600.00
0005434444027	20574	Economy	15600.00
0005434444031	20574	Economy	14100.00
0005434444035	20574	Economy	14100.00
0005434444034	20574	Economy	14100.00
0005434444024	20574	Economy	14100.00
0005434444023	20574	Economy	14100.00
0005434444019	20574	Economy	14100.00
0005434444021	20574	Economy	14100.00
0005434444025	20574	Economy	14100.00
0005434444026	20574	Economy	14100.00
0005434444032	20574	Economy	14100.00
0005434444030	20574	Economy	14100.00
0005434444022	20574	Economy	14100.00
0005434444033	20574	Economy	14100.00
0005434444028	20574	Economy	14100.00
0005434444020	20574	Economy	14100.00
0005434954687	7250	Economy	5800.00
0005434954690	7250	Economy	5800.00
0005434954688	7250	Economy	5800.00
0005434954689	7250	Economy	5800.00
0005435377607	7250	Economy	5800.00
0005435377627	28302	Economy	5800.00
0005435377628	28302	Economy	5800.00
0005434954641	28302	Economy	5800.00
0005434351956	4508	Economy	15400.00
0005434351949	4508	Economy	14000.00
0005434351959	4508	Economy	14000.00
0005435893721	4508	Economy	14000.00
0005434351958	4508	Economy	14000.00
0005435893722	4508	Economy	14000.00
0005434183600	4508	Economy	14000.00
0005435893720	4508	Economy	14000.00
0005434351950	4508	Economy	14000.00
0005434351954	4508	Economy	14000.00
0005434351955	4508	Economy	14000.00
0005434351952	4508	Economy	14000.00
0005434351951	4508	Economy	14000.00
0005434351953	4508	Economy	14000.00
0005434351960	4508	Economy	14000.00
0005435893697	4508	Economy	14000.00
0005434183601	4508	Economy	14000.00
0005435893707	4508	Economy	14000.00
0005434351957	4508	Economy	14000.00
0005434351961	4508	Economy	14000.00
0005435893779	29684	Economy	15400.00
0005434351861	29684	Economy	14000.00
0005434351830	29684	Economy	14000.00
0005434351855	29684	Economy	14000.00
0005435893778	29684	Economy	14000.00
0005434351822	29684	Economy	14000.00
0005435893777	29684	Economy	14000.00
0005435893774	29684	Economy	14000.00
0005434351843	29684	Economy	14000.00
0005434351825	29684	Economy	14000.00
0005434351794	29684	Economy	14000.00
0005434351867	29684	Economy	14000.00
0005434351842	29684	Economy	14000.00
0005434351846	29684	Economy	14000.00
0005434351826	29684	Economy	14000.00
0005435893775	29684	Economy	14000.00
0005435893776	29684	Economy	14000.00
0005434351860	29684	Economy	14000.00
0005433344462	1075	Business	30600.00
0005433158156	1075	Business	30600.00
0005433344261	1075	Business	30600.00
0005433343735	1075	Business	30600.00
0005433158155	1075	Business	30600.00
0005435092275	1075	Business	30600.00
0005433344511	1075	Business	30600.00
0005433343977	1075	Business	30600.00
0005433344192	1075	Business	30600.00
0005433343821	1075	Business	30600.00
0005433343945	1075	Business	30600.00
0005433344341	1075	Business	30600.00
0005433344353	1075	Business	30600.00
0005433344259	1075	Business	30600.00
0005433343786	1075	Business	30600.00
0005433344367	1075	Business	30600.00
0005433344552	1075	Business	30600.00
0005433344716	1075	Business	30600.00
0005433344258	1075	Economy	11200.00
0005433344207	1075	Economy	11200.00
0005433463947	1075	Economy	11200.00
0005433343984	1075	Economy	10200.00
0005433344115	1075	Economy	10200.00
0005433344063	1075	Economy	10200.00
0005434445294	1075	Economy	10200.00
0005433343629	1075	Economy	10200.00
0005433344381	1075	Economy	10200.00
0005433344067	1075	Economy	10200.00
0005433344379	1075	Economy	10200.00
0005433343733	1075	Economy	10200.00
0005433158159	1075	Economy	10200.00
0005433344340	1075	Economy	10200.00
0005433344493	1075	Economy	10200.00
0005433344031	1075	Economy	10200.00
0005435092276	1075	Economy	10200.00
0005433269780	1075	Economy	10200.00
0005433343785	1075	Economy	10200.00
0005433344133	1075	Economy	10200.00
0005433344316	1075	Economy	10200.00
0005433344205	1075	Economy	10200.00
0005433344354	1075	Economy	10200.00
0005433158158	1075	Economy	10200.00
0005433344715	1075	Economy	10200.00
0005433462792	1075	Economy	10200.00
0005435092277	1075	Economy	10200.00
0005433343884	1075	Economy	10200.00
0005433344509	1075	Economy	10200.00
0005433344560	1075	Economy	10200.00
0005433344523	1075	Economy	10200.00
0005433344119	1075	Economy	10200.00
0005433344202	1075	Economy	10200.00
0005435092273	1075	Economy	10200.00
0005433344356	1075	Economy	10200.00
0005435545887	1075	Economy	10200.00
0005432293258	1075	Economy	10200.00
0005433344426	1075	Economy	10200.00
0005433344494	1075	Economy	10200.00
0005433344233	1075	Economy	10200.00
0005433463944	1075	Economy	10200.00
0005433343835	1075	Economy	10200.00
0005433343958	1075	Economy	10200.00
0005435545888	1075	Economy	10200.00
0005433462791	1075	Economy	10200.00
0005433343886	1075	Economy	10200.00
0005433344380	1075	Economy	10200.00
0005433343678	1075	Economy	10200.00
0005433344276	1075	Economy	10200.00
0005435092278	1075	Economy	10200.00
0005433343946	1075	Economy	10200.00
0005433344053	1075	Economy	10200.00
0005435545889	1075	Economy	10200.00
0005433344069	1075	Economy	10200.00
0005435545886	1075	Economy	10200.00
0005433344208	1075	Economy	10200.00
0005432293259	1075	Economy	10200.00
0005433344714	1075	Economy	10200.00
0005433159328	1075	Economy	10200.00
0005433343677	1075	Economy	10200.00
0005433344357	1075	Economy	10200.00
0005433344414	1075	Economy	10200.00
0005433344217	1075	Economy	10200.00
0005433343885	1075	Economy	10200.00
0005433269804	1075	Economy	10200.00
0005433343967	1075	Economy	10200.00
0005433343822	1075	Economy	10200.00
0005433344204	1075	Economy	10200.00
0005433159342	1075	Economy	11200.00
0005433343798	1075	Economy	11200.00
0005433343913	1075	Economy	10200.00
0005433344064	1075	Economy	10200.00
0005433344222	1075	Economy	10200.00
0005433343823	1075	Economy	11200.00
0005433344262	1075	Economy	11200.00
0005433343974	1075	Economy	10200.00
0005433344065	1075	Economy	10200.00
0005433344214	1075	Economy	10200.00
0005433344570	1075	Economy	10200.00
0005433344275	1075	Economy	10200.00
0005435092279	1075	Economy	10200.00
0005433159343	1075	Economy	10200.00
0005433344209	1075	Economy	10200.00
0005433344678	1075	Economy	10200.00
0005433344562	1075	Economy	10200.00
0005435092274	1075	Economy	10200.00
0005433343985	1075	Economy	10200.00
0005433344351	1075	Economy	10200.00
0005433344677	1075	Economy	10200.00
0005434446567	1075	Economy	10200.00
0005433344679	1075	Economy	10200.00
0005433344051	1075	Economy	10200.00
0005433343975	1075	Economy	10200.00
0005433344358	1075	Economy	10200.00
0005433344561	1075	Economy	10200.00
0005433269803	1075	Economy	10200.00
0005435092280	1075	Economy	10200.00
0005433343539	1075	Economy	10200.00
0005433344632	1075	Economy	10200.00
0005433344362	1075	Economy	10200.00
0005434445295	1075	Economy	10200.00
0005433344190	1075	Economy	10200.00
0005433344118	1075	Economy	10200.00
0005433343914	1075	Economy	10200.00
0005435545884	1075	Economy	10200.00
0005435092281	1075	Economy	10200.00
0005433463945	1075	Economy	10200.00
0005433344083	1075	Economy	10200.00
0005433344522	1075	Economy	10200.00
0005435545885	1075	Economy	10200.00
0005433344203	1075	Economy	10200.00
0005433343957	1075	Economy	10200.00
0005433344052	1075	Economy	10200.00
0005433344281	1075	Economy	10200.00
0005433463946	1075	Economy	10200.00
0005433344322	1075	Economy	10200.00
0005433343947	1075	Economy	10200.00
0005433344068	1075	Economy	10200.00
0005433344263	1075	Economy	10200.00
0005433345063	17020	Business	30600.00
0005433345087	17020	Business	30600.00
0005433345055	17020	Business	30600.00
0005433345102	17020	Business	30600.00
0005433345085	17020	Business	30600.00
0005433345051	17020	Business	30600.00
0005433345130	17020	Business	30600.00
0005433345064	17020	Business	30600.00
0005433345077	17020	Business	30600.00
0005433345118	17020	Business	30600.00
0005433345092	17020	Business	30600.00
0005433345068	17020	Business	30600.00
0005433345125	17020	Business	30600.00
0005433345107	17020	Business	30600.00
0005434445270	17020	Business	30600.00
0005433345054	17020	Business	30600.00
0005433345089	17020	Business	30600.00
0005433345139	17020	Business	30600.00
0005433345119	17020	Economy	11200.00
0005435092208	17020	Economy	11200.00
0005435508489	17020	Economy	10200.00
0005433345074	17020	Economy	10200.00
0005435508456	17020	Economy	10200.00
0005435508469	17020	Economy	10200.00
0005435508500	17020	Economy	10200.00
0005435508437	17020	Economy	10200.00
0005433345071	17020	Economy	10200.00
0005433345105	17020	Economy	10200.00
0005433345045	17020	Economy	10200.00
0005433345111	17020	Economy	10200.00
0005433345050	17020	Economy	10200.00
0005433345056	17020	Economy	10200.00
0005433345127	17020	Economy	10200.00
0005433345093	17020	Economy	10200.00
0005433345112	17020	Economy	10200.00
0005435092207	17020	Economy	10200.00
0005433345128	17020	Economy	10200.00
0005433345108	17020	Economy	10200.00
0005433345146	17020	Economy	10200.00
0005433345086	17020	Economy	10200.00
0005435092191	17020	Economy	10200.00
0005433345075	17020	Economy	10200.00
0005433345131	17020	Economy	10200.00
0005433345138	17020	Economy	10200.00
0005433345088	17020	Economy	10200.00
0005433345057	17020	Economy	10200.00
0005433345091	17020	Economy	10200.00
0005434445265	17020	Economy	10200.00
0005433345083	17020	Economy	10200.00
0005433345113	17020	Economy	10200.00
0005433345084	17020	Economy	10200.00
0005433345044	17020	Economy	10200.00
0005433345124	17020	Economy	10200.00
0005433345058	17020	Economy	10200.00
0005433345101	17020	Economy	10200.00
0005433159357	17020	Economy	10200.00
0005433345076	17020	Economy	10200.00
0005433269828	17020	Economy	10200.00
0005433345072	17020	Economy	10200.00
0005433345141	17020	Economy	10200.00
0005433345097	17020	Economy	10200.00
0005433345090	17020	Economy	10200.00
0005433345136	17020	Economy	10200.00
0005435508505	17020	Economy	10200.00
0005433345137	17020	Economy	10200.00
0005435508450	17020	Economy	10200.00
0005435092215	17020	Economy	10200.00
0005433345062	17020	Economy	10200.00
0005434445264	17020	Economy	10200.00
0005433345144	17020	Economy	10200.00
0005433345061	17020	Economy	10200.00
0005433269830	17020	Economy	10200.00
0005435508486	17020	Economy	10200.00
0005435508475	17020	Economy	10200.00
0005433345078	17020	Economy	10200.00
0005435508467	17020	Economy	10200.00
0005434445262	17020	Economy	10200.00
0005433345103	17020	Economy	10200.00
0005433345070	17020	Economy	10200.00
0005433345052	17020	Economy	10200.00
0005433345115	17020	Economy	10200.00
0005433345132	17020	Economy	10200.00
0005433345116	17020	Economy	10200.00
0005433345053	17020	Economy	11200.00
0005433345110	17020	Economy	11200.00
0005433345094	17020	Economy	10200.00
0005433345082	17020	Economy	10200.00
0005433345067	17020	Economy	10200.00
0005433345047	17020	Economy	10200.00
0005433345145	17020	Economy	10200.00
0005433269829	17020	Economy	10200.00
0005433345126	17020	Economy	10200.00
0005433269827	17020	Economy	10200.00
0005433345114	17020	Economy	10200.00
0005433345121	17020	Economy	10200.00
0005435508484	17020	Economy	10200.00
0005433345135	17020	Economy	10200.00
0005433345080	17020	Economy	10200.00
0005433345098	17020	Economy	10200.00
0005433345122	17020	Economy	10200.00
0005433345104	17020	Economy	10200.00
0005435508436	17020	Economy	10200.00
0005433345049	17020	Economy	10200.00
0005433345073	17020	Economy	10200.00
0005433345117	17020	Economy	10200.00
0005433345059	17020	Economy	10200.00
0005433159358	17020	Economy	10200.00
0005433345134	17020	Economy	10200.00
0005433345079	17020	Economy	10200.00
0005435508468	17020	Economy	10200.00
0005433345140	17020	Economy	10200.00
0005435508451	17020	Economy	10200.00
0005433345046	17020	Economy	10200.00
0005433269831	17020	Economy	10200.00
0005433345095	17020	Economy	10200.00
0005433345048	17020	Economy	10200.00
0005433269832	17020	Economy	10200.00
0005433345142	17020	Economy	10200.00
0005433345065	17020	Economy	10200.00
0005433345109	17020	Economy	10200.00
0005433345099	17020	Economy	10200.00
0005433345069	17020	Economy	10200.00
0005433345143	17020	Economy	10200.00
0005433345096	17020	Economy	10200.00
0005433345081	17020	Economy	10200.00
0005435508449	17020	Economy	10200.00
0005433269826	17020	Economy	10200.00
0005433345106	17020	Economy	10200.00
0005433345133	17020	Economy	10200.00
0005433345123	17020	Economy	10200.00
0005433345129	17020	Economy	10200.00
0005433345120	17020	Economy	10200.00
0005433345100	17020	Economy	10200.00
0005434445263	17020	Economy	10200.00
0005433345060	17020	Economy	10200.00
0005433345066	17020	Economy	10200.00
0005432390361	1349	Business	101000.00
0005432390366	1349	Business	101000.00
0005432390378	1349	Business	101000.00
0005432390369	1349	Business	101000.00
0005432390359	1349	Business	101000.00
0005432390373	1349	Business	101000.00
0005432390351	1349	Business	101000.00
0005432390377	1349	Business	101000.00
0005432851973	1349	Business	101000.00
0005432390353	1349	Business	101000.00
0005432390383	1349	Economy	33700.00
0005432390370	1349	Economy	33700.00
0005432851987	1349	Economy	33700.00
0005432390363	1349	Economy	33700.00
0005432851997	1349	Economy	33700.00
0005432392059	1349	Economy	33700.00
0005432851976	1349	Economy	33700.00
0005432851994	1349	Economy	33700.00
0005432390374	1349	Economy	33700.00
0005432851995	1349	Economy	37000.00
0005432852010	1349	Economy	37000.00
0005432390367	1349	Economy	33700.00
0005432390368	1349	Economy	37000.00
0005432852013	1349	Economy	33700.00
0005432851977	1349	Economy	33700.00
0005432851998	1349	Economy	33700.00
0005432390380	1349	Economy	33700.00
0005432392057	1349	Economy	33700.00
0005432390358	1349	Economy	33700.00
0005432392053	1349	Economy	33700.00
0005432851980	1349	Economy	33700.00
0005432390365	1349	Economy	33700.00
0005432851966	1349	Economy	33700.00
0005432392052	1349	Economy	33700.00
0005432390352	1349	Economy	33700.00
0005432851988	1349	Economy	33700.00
0005432390350	1349	Economy	33700.00
0005432392054	1349	Economy	33700.00
0005432390376	1349	Economy	33700.00
0005432390362	1349	Economy	33700.00
0005432390356	1349	Economy	33700.00
0005432851972	1349	Economy	33700.00
0005432851989	1349	Economy	33700.00
0005432390355	1349	Economy	33700.00
0005432392056	1349	Economy	33700.00
0005432852011	1349	Economy	33700.00
0005432851996	1349	Economy	33700.00
0005432852012	1349	Economy	33700.00
0005432851981	1349	Economy	33700.00
0005432851979	1349	Economy	33700.00
0005432390375	1349	Economy	33700.00
0005432390379	1349	Economy	33700.00
0005432851999	1349	Economy	33700.00
0005432390384	1349	Economy	33700.00
0005432851983	1349	Economy	33700.00
0005432390357	1349	Economy	33700.00
0005432392055	1349	Economy	33700.00
0005432390364	1349	Economy	33700.00
0005432390371	1349	Economy	33700.00
0005432851986	1349	Economy	33700.00
0005432390381	1349	Economy	33700.00
0005432390372	1349	Economy	33700.00
0005432851938	1349	Economy	33700.00
0005432852007	1349	Economy	33700.00
0005432392058	1349	Economy	33700.00
0005432390354	1349	Economy	33700.00
0005432390382	1349	Economy	33700.00
0005432390360	1349	Economy	33700.00
0005434067948	12792	Business	40300.00
0005434082094	12792	Business	40300.00
0005434068297	12792	Business	40300.00
0005434068454	12792	Business	40300.00
0005433989814	12792	Business	40300.00
0005434068487	12792	Business	40300.00
0005434082079	12792	Business	40300.00
0005433989813	12792	Business	40300.00
0005434068284	12792	Business	40300.00
0005434068247	12792	Business	40300.00
0005433989828	12792	Business	40300.00
0005434067953	12792	Business	40300.00
0005434067961	12792	Economy	13400.00
0005434068293	12792	Economy	13400.00
0005433812950	12792	Economy	13400.00
0005434068183	12792	Economy	13400.00
0005434068425	12792	Economy	13400.00
0005434082106	12792	Economy	13400.00
0005434068452	12792	Economy	13400.00
0005434068408	12792	Economy	13400.00
0005434068444	12792	Economy	13400.00
0005434068653	12792	Economy	13400.00
0005434068026	12792	Economy	13400.00
0005434068430	12792	Economy	13400.00
0005434068002	12792	Economy	13400.00
0005434068442	12792	Economy	13400.00
0005434068652	12792	Economy	13400.00
0005434068165	12792	Economy	13400.00
0005432159949	12792	Economy	13400.00
0005434068093	12792	Economy	13400.00
0005433812948	12792	Economy	13400.00
0005434068327	12792	Economy	13400.00
0005432159950	12792	Economy	13400.00
0005434068325	12792	Economy	13400.00
0005434068397	12792	Economy	13400.00
0005434082092	12792	Economy	13400.00
0005434068296	12792	Economy	13400.00
0005434068311	12792	Economy	13400.00
0005434068605	12792	Economy	13400.00
0005432161199	12792	Economy	13400.00
0005434068458	12792	Economy	13400.00
0005434068305	12792	Economy	13400.00
0005434068447	12792	Economy	13400.00
0005434082093	12792	Economy	13400.00
0005434068264	12792	Economy	13400.00
0005434068265	12792	Economy	13400.00
0005433989835	12792	Economy	13400.00
0005434068415	12792	Economy	13400.00
0005432159952	12792	Economy	13400.00
0005434068538	12792	Economy	13400.00
0005434068424	12792	Economy	13400.00
0005434068362	12792	Economy	13400.00
0005434068361	12792	Economy	14800.00
0005434068655	12792	Economy	14800.00
0005434068474	12792	Economy	14800.00
0005434082132	12792	Economy	14800.00
0005434068149	12792	Economy	14800.00
0005434068539	12792	Economy	14800.00
0005434068170	12792	Economy	13400.00
0005434068577	12792	Economy	13400.00
0005434068365	12792	Economy	13400.00
0005433812951	12792	Economy	13400.00
0005434068437	12792	Economy	13400.00
0005434068218	12792	Economy	13400.00
0005434068595	12792	Economy	13400.00
0005434068150	12792	Economy	13400.00
0005434068422	12792	Economy	13400.00
0005434082125	12792	Economy	13400.00
0005434068288	12792	Economy	13400.00
0005434068453	12792	Economy	13400.00
0005434068294	12792	Economy	13400.00
0005434068127	12792	Economy	13400.00
0005434068261	12792	Economy	13400.00
0005434067962	12792	Economy	13400.00
0005434068488	12792	Economy	13400.00
0005432159953	12792	Economy	13400.00
0005434068654	12792	Economy	13400.00
0005434068491	12792	Economy	13400.00
0005433989827	12792	Economy	13400.00
0005432159951	12792	Economy	13400.00
0005434068473	12792	Economy	13400.00
0005432433788	12792	Economy	13400.00
0005434068363	12792	Economy	13400.00
0005432433789	12792	Economy	13400.00
0005434068596	12792	Economy	13400.00
0005434068151	12792	Economy	13400.00
0005434068281	12792	Economy	13400.00
0005434068446	12792	Economy	13400.00
0005434068641	12792	Economy	13400.00
0005434068457	12792	Economy	13400.00
0005434068431	12792	Economy	13400.00
0005434068541	12792	Economy	13400.00
0005432433791	12792	Economy	13400.00
0005434082100	12792	Economy	13400.00
0005434068421	12792	Economy	13400.00
0005434068012	12792	Economy	13400.00
0005434068407	12792	Economy	13400.00
0005434068576	12792	Economy	13400.00
0005434067954	12792	Economy	13400.00
0005434068385	12792	Economy	13400.00
0005434068575	12792	Economy	13400.00
0005434026725	12792	Economy	13400.00
0005434068246	12792	Economy	13400.00
0005434068590	12792	Economy	13400.00
0005434068217	12792	Economy	13400.00
0005434068384	12792	Economy	13400.00
0005434068184	12792	Economy	13400.00
0005434068542	12792	Economy	13400.00
0005434082126	12792	Economy	13400.00
0005434068216	12792	Economy	13400.00
0005434068215	12792	Economy	13400.00
0005434082124	12792	Economy	13400.00
0005433812949	12792	Economy	13400.00
0005434068411	12792	Economy	13400.00
0005434082078	12792	Economy	13400.00
0005432433790	12792	Economy	13400.00
0005434068260	12792	Economy	13400.00
0005434068295	12792	Economy	13400.00
0005432433787	12792	Economy	13400.00
0005434068269	12792	Economy	13400.00
0005434068436	12792	Economy	13400.00
0005434068263	12792	Economy	13400.00
0005434068254	12792	Economy	13400.00
0005434068003	12792	Economy	13400.00
0005434068025	12792	Economy	13400.00
0005434068443	12792	Economy	13400.00
0005434026727	12792	Economy	13400.00
0005434067949	12792	Economy	13400.00
0005434082354	30676	Business	40300.00
0005434082342	30676	Business	40300.00
0005434082356	30676	Business	40300.00
0005434068952	30676	Business	40300.00
0005434068980	30676	Business	40300.00
0005434068970	30676	Business	40300.00
0005434068964	30676	Business	40300.00
0005434068937	30676	Business	40300.00
0005434068945	30676	Business	40300.00
0005434068935	30676	Business	40300.00
0005434068922	30676	Business	40300.00
0005434068951	30676	Business	40300.00
0005434068973	30676	Economy	13400.00
0005434068914	30676	Economy	13400.00
0005432433769	30676	Economy	13400.00
0005432150348	30676	Economy	13400.00
0005434068923	30676	Economy	13400.00
0005434082336	30676	Economy	13400.00
0005434068978	30676	Economy	13400.00
0005434068976	30676	Economy	13400.00
0005434068957	30676	Economy	13400.00
0005434082337	30676	Economy	13400.00
0005434068977	30676	Economy	13400.00
0005434082327	30676	Economy	13400.00
0005434082338	30676	Economy	13400.00
0005434068948	30676	Economy	13400.00
0005434082348	30676	Economy	13400.00
0005434068918	30676	Economy	13400.00
0005434082335	30676	Economy	13400.00
0005434082351	30676	Economy	13400.00
0005432433774	30676	Economy	13400.00
0005434068911	30676	Economy	13400.00
0005434068971	30676	Economy	13400.00
0005434068972	30676	Economy	13400.00
0005432433754	30676	Economy	13400.00
0005434082344	30676	Economy	13400.00
0005432150346	30676	Economy	13400.00
0005434082343	30676	Economy	13400.00
0005434068928	30676	Economy	13400.00
0005434068936	30676	Economy	13400.00
0005434068968	30676	Economy	13400.00
0005434068955	30676	Economy	13400.00
0005434068950	30676	Economy	13400.00
0005434068967	30676	Economy	13400.00
0005432433738	30676	Economy	13400.00
0005432433755	30676	Economy	13400.00
0005434082333	30676	Economy	13400.00
0005434068912	30676	Economy	13400.00
0005434068954	30676	Economy	13400.00
0005433989866	30676	Economy	13400.00
0005433989861	30676	Economy	13400.00
0005434082329	30676	Economy	14800.00
0005434082334	30676	Economy	14800.00
0005434068960	30676	Economy	14800.00
0005434068915	30676	Economy	14800.00
0005434082340	30676	Economy	14800.00
0005434068981	30676	Economy	14800.00
0005433989863	30676	Economy	13400.00
0005434068939	30676	Economy	13400.00
0005434068963	30676	Economy	13400.00
0005434068941	30676	Economy	13400.00
0005434068962	30676	Economy	13400.00
0005433989865	30676	Economy	13400.00
0005432150349	30676	Economy	13400.00
0005434068982	30676	Economy	13400.00
0005434068913	30676	Economy	13400.00
0005432186940	30676	Economy	13400.00
0005432150350	30676	Economy	13400.00
0005434068943	30676	Economy	13400.00
0005434082357	30676	Economy	13400.00
0005432150347	30676	Economy	13400.00
0005432186941	30676	Economy	13400.00
0005434068925	30676	Economy	13400.00
0005434068974	30676	Economy	13400.00
0005433989862	30676	Economy	13400.00
0005434068953	30676	Economy	13400.00
0005434068944	30676	Economy	13400.00
0005434082346	30676	Economy	13400.00
0005434082347	30676	Economy	13400.00
0005434068933	30676	Economy	13400.00
0005434068917	30676	Economy	13400.00
0005434068969	30676	Economy	13400.00
0005434068942	30676	Economy	13400.00
0005434082349	30676	Economy	13400.00
0005434068930	30676	Economy	13400.00
0005434082353	30676	Economy	13400.00
0005434068931	30676	Economy	13400.00
0005434068947	30676	Economy	13400.00
0005434068946	30676	Economy	13400.00
0005434082331	30676	Economy	13400.00
0005434082350	30676	Economy	13400.00
0005432433756	30676	Economy	13400.00
0005434082332	30676	Economy	13400.00
0005434082328	30676	Economy	13400.00
0005433989864	30676	Economy	13400.00
0005432433720	30676	Economy	13400.00
0005434068932	30676	Economy	13400.00
0005434068924	30676	Economy	13400.00
0005434068979	30676	Economy	13400.00
0005434068921	30676	Economy	13400.00
0005434082330	30676	Economy	13400.00
0005434068919	30676	Economy	13400.00
0005434068920	30676	Economy	13400.00
0005434068975	30676	Economy	13400.00
0005434068959	30676	Economy	13400.00
0005432150345	30676	Economy	13400.00
0005434068940	30676	Economy	13400.00
0005434082339	30676	Economy	13400.00
0005434082352	30676	Economy	13400.00
0005434082355	30676	Economy	13400.00
0005434068929	30676	Economy	13400.00
0005434082341	30676	Economy	13400.00
0005434068961	30676	Economy	13400.00
0005432150351	30676	Economy	13400.00
0005434068956	30676	Economy	13400.00
0005434068934	30676	Economy	13400.00
0005434068926	30676	Economy	13400.00
0005434068966	30676	Economy	13400.00
0005434068958	30676	Economy	13400.00
0005434082345	30676	Economy	13400.00
0005434068965	30676	Economy	13400.00
0005434068949	30676	Economy	13400.00
0005434068916	30676	Economy	13400.00
0005434068938	30676	Economy	13400.00
0005434068927	30676	Economy	13400.00
0005432150344	30676	Economy	13400.00
0005434068910	30676	Economy	13400.00
0005434082358	30676	Economy	13400.00
0005434831188	5543	Business	35300.00
0005435043292	5543	Business	35300.00
0005435767477	5543	Business	35300.00
0005435767476	5543	Business	35300.00
0005432535887	5543	Business	35300.00
0005435462775	5543	Business	35300.00
0005435767486	5543	Business	35300.00
0005435462705	5543	Business	35300.00
0005435767445	5543	Business	35300.00
0005435767475	5543	Business	35300.00
0005432140613	5543	Business	35300.00
0005435767439	5543	Business	35300.00
0005435462825	5543	Business	35300.00
0005435767464	5543	Business	35300.00
0005435462857	5543	Business	35300.00
0005435462913	5543	Business	35300.00
0005435767440	5543	Business	35300.00
0005432535866	5543	Business	35300.00
0005432140618	5543	Business	35300.00
0005435767490	5543	Business	35300.00
0005435462982	5543	Business	35300.00
0005435462722	5543	Business	35300.00
0005435767459	5543	Business	35300.00
0005435725697	5543	Business	35300.00
0005435767448	5543	Business	35300.00
0005434265461	5543	Business	35300.00
0005435767462	5543	Business	35300.00
0005435722103	5543	Economy	12900.00
0005434265459	5543	Economy	12900.00
0005435767493	5543	Economy	11800.00
0005434265484	5543	Economy	11800.00
0005432140614	5543	Economy	11800.00
0005432140616	5543	Economy	11800.00
0005435767499	5543	Economy	11800.00
0005432140619	5543	Economy	11800.00
0005433529355	5543	Economy	11800.00
0005435767498	5543	Economy	11800.00
0005435462839	5543	Economy	11800.00
0005434265361	5543	Economy	11800.00
0005435463012	5543	Economy	11800.00
0005434265327	5543	Economy	11800.00
0005435767479	5543	Economy	11800.00
0005435767473	5543	Economy	11800.00
0005434265328	5543	Economy	11800.00
0005435723083	5543	Economy	11800.00
0005434265448	5543	Economy	11800.00
0005434265425	5543	Economy	11800.00
0005435462727	5543	Economy	11800.00
0005435767444	5543	Economy	11800.00
0005435462780	5543	Economy	11800.00
0005434265439	5543	Economy	11800.00
0005435462774	5543	Economy	11800.00
0005435767443	5543	Economy	11800.00
0005435767433	5543	Economy	11800.00
0005435462968	5543	Economy	11800.00
0005435767481	5543	Economy	11800.00
0005433529354	5543	Economy	11800.00
0005435767447	5543	Economy	11800.00
0005434265366	5543	Economy	11800.00
0005435462801	5543	Economy	11800.00
0005435462912	5543	Economy	11800.00
0005434265363	5543	Economy	11800.00
0005435767495	5543	Economy	11800.00
0005435043293	5543	Economy	11800.00
0005433527343	5543	Economy	11800.00
0005433527346	5543	Economy	11800.00
0005435462896	5543	Economy	11800.00
0005435462802	5543	Economy	11800.00
0005435767491	5543	Economy	11800.00
0005435767469	5543	Economy	11800.00
0005435767463	5543	Economy	11800.00
0005435767485	5543	Economy	11800.00
0005435767450	5543	Economy	11800.00
0005434265424	5543	Economy	11800.00
0005435767435	5543	Economy	11800.00
0005435767472	5543	Economy	11800.00
0005435735229	5543	Economy	11800.00
0005435043294	5543	Economy	11800.00
0005434265367	5543	Economy	11800.00
0005435462855	5543	Economy	11800.00
0005435725700	5543	Economy	11800.00
0005435767457	5543	Economy	11800.00
0005434265313	5543	Economy	11800.00
0005435462858	5543	Economy	11800.00
0005435462928	5543	Economy	11800.00
0005435463007	5543	Economy	11800.00
0005434265346	5543	Economy	11800.00
0005433527344	5543	Economy	11800.00
0005435462838	5543	Economy	11800.00
0005435767492	5543	Economy	11800.00
0005435767437	5543	Economy	11800.00
0005435463002	5543	Economy	11800.00
0005435767438	5543	Economy	11800.00
0005435767483	5543	Economy	11800.00
0005435462853	5543	Economy	11800.00
0005432140615	5543	Economy	11800.00
0005432140620	5543	Economy	11800.00
0005435767454	5543	Economy	11800.00
0005435462739	5543	Economy	11800.00
0005435720847	5543	Economy	11800.00
0005434831183	5543	Economy	11800.00
0005435462777	5543	Economy	11800.00
0005435462826	5543	Economy	11800.00
0005435767467	5543	Economy	11800.00
0005435463003	5543	Economy	11800.00
0005434265460	5543	Economy	11800.00
0005434265412	5543	Economy	11800.00
0005435767496	5543	Economy	11800.00
0005435767497	5543	Economy	11800.00
0005435767452	5543	Economy	11800.00
0005435723082	5543	Economy	11800.00
0005435767461	5543	Economy	12900.00
0005435462887	5543	Economy	12900.00
0005435767482	5543	Economy	11800.00
0005435462905	5543	Economy	11800.00
0005435767465	5543	Economy	11800.00
0005435767451	5543	Economy	11800.00
0005435767478	5543	Economy	11800.00
0005435462866	5543	Economy	11800.00
0005435767434	5543	Economy	11800.00
0005435767460	5543	Economy	11800.00
0005435462738	5543	Economy	11800.00
0005434265423	5543	Economy	11800.00
0005435725698	5543	Economy	11800.00
0005434265430	5543	Economy	11800.00
0005435767458	5543	Economy	11800.00
0005435462883	5543	Economy	11800.00
0005435767484	5543	Economy	11800.00
0005435462869	5543	Economy	11800.00
0005434265552	5543	Economy	11800.00
0005435767489	5543	Economy	11800.00
0005435462818	5543	Economy	11800.00
0005433529356	5543	Economy	11800.00
0005435767480	5543	Economy	11800.00
0005434265322	5543	Economy	11800.00
0005435767453	5543	Economy	11800.00
0005435735230	5543	Economy	11800.00
0005435725699	5543	Economy	11800.00
0005432140617	5543	Economy	11800.00
0005434831197	5543	Economy	11800.00
0005435767488	5543	Economy	11800.00
0005435462938	5543	Economy	11800.00
0005435767441	5543	Economy	11800.00
0005435722104	5543	Economy	11800.00
0005435767474	5543	Economy	11800.00
0005435462856	5543	Economy	11800.00
0005435735227	5543	Economy	11800.00
0005435735228	5543	Economy	11800.00
0005435767468	5543	Economy	11800.00
0005435767436	5543	Economy	11800.00
0005433529357	5543	Economy	11800.00
0005435767471	5543	Economy	11800.00
0005435462800	5543	Economy	11800.00
0005434265365	5543	Economy	11800.00
0005435462721	5543	Economy	11800.00
0005435767442	5543	Economy	11800.00
0005435767466	5543	Economy	11800.00
0005435767446	5543	Economy	11800.00
0005435462927	5543	Economy	11800.00
0005435767470	5543	Economy	11800.00
0005435462983	5543	Economy	11800.00
0005433527345	5543	Economy	11800.00
0005435767455	5543	Economy	11800.00
0005434265401	5543	Economy	11800.00
0005435462914	5543	Economy	11800.00
0005435462870	5543	Economy	11800.00
0005435767449	5543	Economy	11800.00
0005432535893	5543	Economy	11800.00
0005434265362	5543	Economy	11800.00
0005435767487	5543	Economy	11800.00
0005435735231	5543	Economy	11800.00
0005435767456	5543	Economy	11800.00
0005434831196	5543	Economy	11800.00
0005435767494	5543	Economy	11800.00
0005434831248	13469	Business	35300.00
0005435463222	13469	Business	35300.00
0005432535934	13469	Business	35300.00
0005435766919	13469	Business	35300.00
0005435463219	13469	Business	35300.00
0005435767042	13469	Business	35300.00
0005435766724	13469	Business	35300.00
0005434265665	13469	Business	35300.00
0005435725648	13469	Business	35300.00
0005435735183	13469	Business	35300.00
0005435766559	13469	Business	35300.00
0005435767008	13469	Business	35300.00
0005434265673	13469	Business	35300.00
0005432194596	13469	Business	35300.00
0005435735190	13469	Business	35300.00
0005435766991	13469	Business	35300.00
0005432194594	13469	Business	35300.00
0005435766911	13469	Business	35300.00
0005434831250	13469	Business	35300.00
0005435463187	13469	Business	35300.00
0005434265677	13469	Business	35300.00
0005435735196	13469	Business	35300.00
0005435766932	13469	Business	35300.00
0005435725640	13469	Business	35300.00
0005435766933	13469	Economy	12900.00
0005435463221	13469	Economy	12900.00
0005434265676	13469	Economy	12900.00
0005435722087	13469	Economy	11800.00
0005435766963	13469	Economy	11800.00
0005435767007	13469	Economy	11800.00
0005435617181	13469	Economy	11800.00
0005435766825	13469	Economy	11800.00
0005435725641	13469	Economy	11800.00
0005435725638	13469	Economy	11800.00
0005435725645	13469	Economy	11800.00
0005435735197	13469	Economy	11800.00
0005435766603	13469	Economy	11800.00
0005435766969	13469	Economy	11800.00
0005435617182	13469	Economy	11800.00
0005435463209	13469	Economy	11800.00
0005435766895	13469	Economy	11800.00
0005434265669	13469	Economy	11800.00
0005435617183	13469	Economy	11800.00
0005435725658	13469	Economy	11800.00
0005435463200	13469	Economy	11800.00
0005435766715	13469	Economy	11800.00
0005435725642	13469	Economy	11800.00
0005435463224	13469	Economy	11800.00
0005435766964	13469	Economy	11800.00
0005435463193	13469	Economy	11800.00
0005435725663	13469	Economy	11800.00
0005435463201	13469	Economy	11800.00
0005434265658	13469	Economy	11800.00
0005435463217	13469	Economy	11800.00
0005434265678	13469	Economy	11800.00
0005435766730	13469	Economy	11800.00
0005435766970	13469	Economy	11800.00
0005434265654	13469	Economy	11800.00
0005435725644	13469	Economy	11800.00
0005435617184	13469	Economy	11800.00
0005435766987	13469	Economy	11800.00
0005435767059	13469	Economy	11800.00
0005435766624	13469	Economy	11800.00
0005435463207	13469	Economy	11800.00
0005435766870	13469	Economy	11800.00
0005435766833	13469	Economy	11800.00
0005435766974	13469	Economy	11800.00
0005435463208	13469	Economy	11800.00
0005435766560	13469	Economy	11800.00
0005435767014	13469	Economy	11800.00
0005435766978	13469	Economy	11800.00
0005435722086	13469	Economy	11800.00
0005435767025	13469	Economy	11800.00
0005432535933	13469	Economy	11800.00
0005434265660	13469	Economy	11800.00
0005434265671	13469	Economy	11800.00
0005435766973	13469	Economy	11800.00
0005435766954	13469	Economy	11800.00
0005434265667	13469	Economy	11800.00
0005434831249	13469	Economy	11800.00
0005434265668	13469	Economy	11800.00
0005435617180	13469	Economy	11800.00
0005432194595	13469	Economy	11800.00
0005434265656	13469	Economy	11800.00
0005435463215	13469	Economy	11800.00
0005432194597	13469	Economy	11800.00
0005435766946	13469	Economy	11800.00
0005435766988	13469	Economy	11800.00
0005435767006	13469	Economy	11800.00
0005435463195	13469	Economy	11800.00
0005435766989	13469	Economy	11800.00
0005434265672	13469	Economy	11800.00
0005435766754	13469	Economy	11800.00
0005435735187	13469	Economy	11800.00
0005434265663	13469	Economy	11800.00
0005434831246	13469	Economy	11800.00
0005435463196	13469	Economy	11800.00
0005432535932	13469	Economy	11800.00
0005435766986	13469	Economy	11800.00
0005435735188	13469	Economy	11800.00
0005435766953	13469	Economy	11800.00
0005435725660	13469	Economy	11800.00
0005435463212	13469	Economy	11800.00
0005435463203	13469	Economy	11800.00
0005434831251	13469	Economy	11800.00
0005435463214	13469	Economy	11800.00
0005435463189	13469	Economy	12900.00
0005434265675	13469	Economy	12900.00
0005435463202	13469	Economy	11800.00
0005435463199	13469	Economy	12900.00
0005435766910	13469	Economy	11800.00
0005435725657	13469	Economy	12900.00
0005435735191	13469	Economy	11800.00
0005435735200	13469	Economy	11800.00
0005434265655	13469	Economy	11800.00
0005434265664	13469	Economy	11800.00
0005435723062	13469	Economy	11800.00
0005435725661	13469	Economy	11800.00
0005435463191	13469	Economy	11800.00
0005435766845	13469	Economy	11800.00
0005434265666	13469	Economy	11800.00
0005435722079	13469	Economy	11800.00
0005435463194	13469	Economy	11800.00
0005435766716	13469	Economy	11800.00
0005435463210	13469	Economy	11800.00
0005435722088	13469	Economy	11800.00
0005435766980	13469	Economy	11800.00
0005434831247	13469	Economy	11800.00
0005435463206	13469	Economy	11800.00
0005434265679	13469	Economy	11800.00
0005435463216	13469	Economy	11800.00
0005435725646	13469	Economy	11800.00
0005434265662	13469	Economy	11800.00
0005432535931	13469	Economy	11800.00
0005434265670	13469	Economy	11800.00
0005434265659	13469	Economy	11800.00
0005435766834	13469	Economy	11800.00
0005435463205	13469	Economy	11800.00
0005435766929	13469	Economy	11800.00
0005434265661	13469	Economy	11800.00
0005435767015	13469	Economy	11800.00
0005435766755	13469	Economy	11800.00
0005435767055	13469	Economy	11800.00
0005435766926	13469	Economy	11800.00
0005435463211	13469	Economy	11800.00
0005435463188	13469	Economy	11800.00
0005435725664	13469	Economy	11800.00
0005432535935	13469	Economy	11800.00
0005435725647	13469	Economy	11800.00
0005435766890	13469	Economy	11800.00
0005435766938	13469	Economy	11800.00
0005435463213	13469	Economy	11800.00
0005434265674	13469	Economy	11800.00
0005435463223	13469	Economy	11800.00
0005435725649	13469	Economy	11800.00
0005435463204	13469	Economy	11800.00
0005435463218	13469	Economy	11800.00
0005435766891	13469	Economy	11800.00
0005435735189	13469	Economy	11800.00
0005434265657	13469	Economy	11800.00
0005435463192	13469	Economy	11800.00
0005435766828	13469	Economy	11800.00
0005435766604	13469	Economy	11800.00
0005435463220	13469	Economy	11800.00
0005435463190	13469	Economy	11800.00
0005435766958	13469	Economy	11800.00
0005435463197	13469	Economy	11800.00
0005435463198	13469	Economy	11800.00
0005435722080	13469	Economy	11800.00
0005434602924	18745	Economy	3300.00
0005434602923	18745	Economy	3300.00
0005434602925	18745	Economy	3300.00
0005434515018	18740	Economy	3300.00
0005434604923	18740	Economy	3300.00
0005434515019	18740	Economy	3300.00
0005434604920	18740	Economy	3300.00
0005435904718	18740	Economy	3300.00
0005434604922	18740	Economy	3300.00
0005435904717	18740	Economy	3300.00
0005434515020	18740	Economy	3300.00
0005434513632	18740	Economy	3300.00
0005434514998	19111	Economy	3300.00
0005434515001	19111	Economy	3300.00
0005434514999	19111	Economy	3300.00
0005434515000	19111	Economy	3300.00
0005434514997	19111	Economy	3300.00
0005434514996	19111	Economy	3300.00
0005435846328	25081	Business	88300.00
0005435846327	25081	Business	88300.00
0005435846329	25081	Business	88300.00
0005435846322	25081	Economy	29400.00
0005435846323	25081	Economy	29400.00
0005435846326	25081	Economy	29400.00
0005432649450	25081	Economy	29400.00
0005432649449	25081	Economy	29400.00
0005435846325	25081	Economy	29400.00
0005435846324	25081	Economy	29400.00
0005432649479	25081	Economy	29400.00
0005433009130	1781	Business	48700.00
0005433009225	1781	Business	48700.00
0005433285647	1781	Business	48700.00
0005433285538	1781	Business	48700.00
0005433009048	1781	Business	48700.00
0005433009082	1781	Business	48700.00
0005433009116	1781	Business	48700.00
0005433009216	1781	Business	48700.00
0005433285553	1781	Business	48700.00
0005433009102	1781	Business	48700.00
0005433009103	1781	Business	48700.00
0005433009121	1781	Business	48700.00
0005433810654	1781	Economy	16200.00
0005433009197	1781	Economy	16200.00
0005433810652	1781	Economy	16200.00
0005433810655	1781	Economy	16200.00
0005433009258	1781	Economy	16200.00
0005433009122	1781	Economy	16200.00
0005433009207	1781	Economy	16200.00
0005433810648	1781	Economy	16200.00
0005433285702	1781	Economy	16200.00
0005433810651	1781	Economy	16200.00
0005433009275	1781	Economy	17900.00
0005433285615	1781	Economy	17900.00
0005433810649	1781	Economy	17900.00
0005433009027	1781	Economy	17900.00
0005433009188	1781	Economy	17900.00
0005433009226	1781	Economy	16200.00
0005433285646	1781	Economy	16200.00
0005433285698	1781	Economy	16200.00
0005433285686	1781	Economy	16200.00
0005433009218	1781	Economy	16200.00
0005433008986	1781	Economy	16200.00
0005433285640	1781	Economy	16200.00
0005433285666	1781	Economy	16200.00
0005433009208	1781	Economy	16200.00
0005433810650	1781	Economy	16200.00
0005433009298	1781	Economy	16200.00
0005433285641	1781	Economy	16200.00
0005433285685	1781	Economy	16200.00
0005433009339	1781	Economy	16200.00
0005433285617	1781	Economy	16200.00
0005433009172	1781	Economy	16200.00
0005433810653	1781	Economy	16200.00
0005433009224	1781	Economy	16200.00
0005433009215	1781	Economy	16200.00
0005433009186	1781	Economy	16200.00
0005433285721	1781	Economy	16200.00
0005433009137	1781	Economy	16200.00
0005433285696	1781	Economy	16200.00
0005433285618	1781	Economy	16200.00
0005433009117	1781	Economy	16200.00
0005433009142	1781	Economy	16200.00
0005433009106	1781	Economy	16200.00
0005433009187	1781	Economy	16200.00
0005433285701	1781	Economy	16200.00
0005433009314	1781	Economy	16200.00
0005433009143	1781	Economy	16200.00
0005433009274	1781	Economy	16200.00
0005433285658	1781	Economy	16200.00
0005433009083	1781	Economy	16200.00
0005433009396	1781	Economy	16200.00
0005433285660	1781	Economy	16200.00
0005433009046	1781	Economy	16200.00
0005433285544	1781	Economy	16200.00
0005433009340	1781	Economy	16200.00
0005433009120	1781	Economy	16200.00
0005433285792	1781	Economy	16200.00
0005433285724	1781	Economy	16200.00
0005433009299	1781	Economy	16200.00
0005433009156	1781	Economy	16200.00
0005433009036	1781	Economy	16200.00
0005433285675	1781	Economy	16200.00
0005433009296	1781	Economy	16200.00
0005433009297	1781	Economy	16200.00
0005433009395	1781	Economy	16200.00
0005433285537	1781	Economy	16200.00
0005432295934	1781	Economy	16200.00
0005433009101	1781	Economy	16200.00
0005433285614	1781	Economy	16200.00
0005433009155	1781	Economy	16200.00
0005433285729	1781	Economy	16200.00
0005433009182	1781	Economy	16200.00
0005433009185	1781	Economy	16200.00
0005433009295	1781	Economy	16200.00
0005433285731	1781	Economy	16200.00
0005432295933	1781	Economy	16200.00
0005433810647	1781	Economy	16200.00
0005433285737	1781	Economy	16200.00
0005433009123	1781	Economy	16200.00
0005433008985	1781	Economy	16200.00
0005433285659	1781	Economy	16200.00
0005433285695	1781	Economy	16200.00
0005433009527	22568	Business	48700.00
0005433009535	22568	Business	48700.00
0005433009502	22568	Business	48700.00
0005433009494	22568	Business	48700.00
0005433285906	22568	Business	48700.00
0005433285907	22568	Business	48700.00
0005433285909	22568	Business	48700.00
0005433009504	22568	Business	48700.00
0005433009526	22568	Business	48700.00
0005433009509	22568	Business	48700.00
0005433009493	22568	Economy	16200.00
0005433285905	22568	Economy	16200.00
0005433009533	22568	Economy	16200.00
0005433009511	22568	Economy	16200.00
0005433285929	22568	Economy	16200.00
0005433285928	22568	Economy	16200.00
0005433009532	22568	Economy	17900.00
0005433285927	22568	Economy	17900.00
0005433285912	22568	Economy	17900.00
0005433285923	22568	Economy	16200.00
0005433285924	22568	Economy	16200.00
0005433285901	22568	Economy	16200.00
0005433009510	22568	Economy	16200.00
0005433009513	22568	Economy	16200.00
0005433009531	22568	Economy	16200.00
0005433285922	22568	Economy	16200.00
0005433285908	22568	Economy	16200.00
0005433285911	22568	Economy	16200.00
0005433009536	22568	Economy	16200.00
0005433285926	22568	Economy	16200.00
0005433285914	22568	Economy	16200.00
0005433009529	22568	Economy	16200.00
0005433009525	22568	Economy	16200.00
0005433009512	22568	Economy	16200.00
0005433009518	22568	Economy	16200.00
0005433285931	22568	Economy	16200.00
0005433285903	22568	Economy	16200.00
0005433009516	22568	Economy	16200.00
0005433285925	22568	Economy	16200.00
0005433285921	22568	Economy	16200.00
0005433009495	22568	Economy	16200.00
0005433009499	22568	Economy	16200.00
0005433285915	22568	Economy	16200.00
0005433009534	22568	Economy	16200.00
0005433009508	22568	Economy	16200.00
0005433009505	22568	Economy	16200.00
0005433009515	22568	Economy	16200.00
0005433009507	22568	Economy	16200.00
0005433285916	22568	Economy	16200.00
0005433009498	22568	Economy	16200.00
0005433009492	22568	Economy	16200.00
0005433285904	22568	Economy	16200.00
0005433009517	22568	Economy	16200.00
0005433009500	22568	Economy	16200.00
0005433285920	22568	Economy	16200.00
0005433285918	22568	Economy	16200.00
0005433009523	22568	Economy	16200.00
0005433009501	22568	Economy	16200.00
0005433009503	22568	Economy	16200.00
0005433009524	22568	Economy	16200.00
0005433009506	22568	Economy	16200.00
0005433285902	22568	Economy	16200.00
0005433009496	22568	Economy	16200.00
0005433810569	22568	Economy	16200.00
0005433009530	22568	Economy	16200.00
0005433009497	22568	Economy	16200.00
0005433009520	22568	Economy	16200.00
0005433009522	22568	Economy	16200.00
0005433285913	22568	Economy	16200.00
0005433009521	22568	Economy	16200.00
0005433285910	22568	Economy	16200.00
0005433285930	22568	Economy	16200.00
0005433009519	22568	Economy	16200.00
0005433285900	22568	Economy	16200.00
0005433285917	22568	Economy	16200.00
0005433009528	22568	Economy	16200.00
0005433009514	22568	Economy	16200.00
0005433009537	22568	Economy	16200.00
0005433285919	22568	Economy	16200.00
0005432751564	12289	Business	83800.00
0005432755115	12289	Business	83800.00
0005432751567	12289	Economy	27900.00
0005432755116	12289	Economy	27900.00
0005432755107	12289	Economy	27900.00
0005432751565	12289	Economy	27900.00
0005434152830	12289	Economy	27900.00
0005432751568	12289	Economy	27900.00
0005432751562	12289	Economy	30700.00
0005432755106	12289	Economy	30700.00
0005432755081	12289	Economy	27900.00
0005432751561	12289	Economy	27900.00
0005434152832	12289	Economy	27900.00
0005434152825	12289	Economy	27900.00
0005432751563	12289	Economy	27900.00
0005434152827	12289	Economy	27900.00
0005432751572	12289	Economy	27900.00
0005434152828	12289	Economy	27900.00
0005432755108	12289	Economy	27900.00
0005432751560	12289	Economy	27900.00
0005434152831	12289	Economy	27900.00
0005432755101	12289	Economy	27900.00
0005432755096	12289	Economy	27900.00
0005432751569	12289	Economy	27900.00
0005432755102	12289	Economy	27900.00
0005432751566	12289	Economy	27900.00
0005434152826	12289	Economy	27900.00
0005432751552	12289	Economy	27900.00
0005432755093	12289	Economy	27900.00
0005432755098	12289	Economy	27900.00
0005432751557	12289	Economy	27900.00
0005432751573	12289	Economy	27900.00
0005432755099	12289	Economy	27900.00
0005434152829	12289	Economy	27900.00
0005432755092	12289	Economy	27900.00
0005432755109	12289	Economy	27900.00
0005432751556	12289	Economy	27900.00
0005433847924	5572	Business	99800.00
0005433847922	5572	Business	99800.00
0005435282817	5572	Business	99800.00
0005433847900	5572	Business	99800.00
0005434173569	5572	Business	99800.00
0005432081642	5572	Business	99800.00
0005435282774	5572	Business	99800.00
0005435282769	5572	Business	99800.00
0005432081643	5572	Business	99800.00
0005435282518	5572	Business	99800.00
0005433847883	5572	Business	99800.00
0005435282801	5572	Business	99800.00
0005433847897	5572	Business	99800.00
0005435282771	5572	Business	99800.00
0005433847885	5572	Business	99800.00
0005433847882	5572	Business	99800.00
0005433847888	5572	Business	99800.00
0005433847901	5572	Business	99800.00
0005433847892	5572	Business	99800.00
0005433847914	5572	Economy	33300.00
0005432081640	5572	Economy	33300.00
0005433847911	5572	Economy	33300.00
0005433847898	5572	Economy	33300.00
0005433847920	5572	Economy	33300.00
0005433847878	5572	Economy	33300.00
0005435282626	5572	Economy	33300.00
0005433847921	5572	Economy	33300.00
0005433847905	5572	Economy	33300.00
0005433847887	5572	Economy	36600.00
0005434173552	5572	Economy	36600.00
0005435282830	5572	Economy	36600.00
0005435282781	5572	Economy	33300.00
0005433847915	5572	Economy	33300.00
0005433847932	5572	Economy	33300.00
0005433847933	5572	Economy	33300.00
0005433847917	5572	Economy	33300.00
0005433847874	5572	Economy	33300.00
0005433847896	5572	Economy	33300.00
0005432081641	5572	Economy	33300.00
0005433847899	5572	Economy	33300.00
0005433847881	5572	Economy	33300.00
0005433847906	5572	Economy	33300.00
0005433815480	5572	Economy	33300.00
0005433847919	5572	Economy	33300.00
0005432081644	5572	Economy	33300.00
0005433847875	5572	Economy	33300.00
0005433847916	5572	Economy	33300.00
0005435282754	5572	Economy	33300.00
0005435282778	5572	Economy	33300.00
0005433847928	5572	Economy	33300.00
0005433847910	5572	Economy	33300.00
0005433847912	5572	Economy	33300.00
0005433847918	5572	Economy	33300.00
0005435282768	5572	Economy	33300.00
0005435282807	5572	Economy	33300.00
0005433847931	5572	Economy	33300.00
0005435282779	5572	Economy	33300.00
0005435282808	5572	Economy	33300.00
0005433847877	5572	Economy	33300.00
0005433815482	5572	Economy	33300.00
0005433815479	5572	Economy	33300.00
0005433847925	5572	Economy	33300.00
0005435282855	5572	Economy	33300.00
0005433847903	5572	Economy	33300.00
0005435282812	5572	Economy	33300.00
0005433847879	5572	Economy	33300.00
0005433847927	5572	Economy	33300.00
0005435282854	5572	Economy	33300.00
0005435282737	5572	Economy	33300.00
0005433847913	5572	Economy	33300.00
0005433815481	5572	Economy	33300.00
0005433847894	5572	Economy	33300.00
0005433847902	5572	Economy	33300.00
0005434173559	5572	Economy	33300.00
0005435282780	5572	Economy	33300.00
0005433815536	5572	Economy	33300.00
0005433847884	5572	Economy	33300.00
0005435282846	5572	Economy	33300.00
0005433847909	5572	Economy	33300.00
0005433847893	5572	Economy	33300.00
0005433847889	5572	Economy	33300.00
0005433847904	5572	Economy	33300.00
0005435282793	5572	Economy	33300.00
0005432081645	5572	Economy	33300.00
0005433847908	5572	Economy	33300.00
0005433847895	5572	Economy	33300.00
0005433847907	5572	Economy	33300.00
0005433847926	5572	Economy	33300.00
0005433847880	5572	Economy	33300.00
0005435282627	5572	Economy	33300.00
0005433815478	5572	Economy	33300.00
0005433847886	5572	Economy	33300.00
0005433847876	5572	Economy	33300.00
0005433847923	5572	Economy	33300.00
0005433847891	5572	Economy	33300.00
0005434173558	5572	Economy	33300.00
0005435282713	5572	Economy	33300.00
0005433847930	5572	Economy	33300.00
0005433847929	5572	Economy	33300.00
0005433847890	5572	Economy	33300.00
0005435282996	13865	Business	99800.00
0005435283001	13865	Business	99800.00
0005433847332	13865	Business	99800.00
0005432003765	13865	Business	99800.00
0005433847595	13865	Business	99800.00
0005433847327	13865	Business	99800.00
0005433847348	13865	Business	99800.00
0005433847173	13865	Business	99800.00
0005433847530	13865	Business	99800.00
0005433847605	13865	Business	99800.00
0005433847254	13865	Business	99800.00
0005435283003	13865	Business	99800.00
0005433847309	13865	Business	99800.00
0005434173603	13865	Business	99800.00
0005433847523	13865	Business	99800.00
0005435283010	13865	Business	99800.00
0005433847403	13865	Business	99800.00
0005435283005	13865	Business	99800.00
0005433847698	13865	Economy	33300.00
0005433815433	13865	Economy	33300.00
0005433847308	13865	Economy	33300.00
0005433847217	13865	Economy	33300.00
0005433847469	13865	Economy	33300.00
0005433847405	13865	Economy	33300.00
0005433847603	13865	Economy	33300.00
0005433847468	13865	Economy	33300.00
0005435283000	13865	Economy	33300.00
0005435283015	13865	Economy	33300.00
0005435282995	13865	Economy	33300.00
0005432003767	13865	Economy	33300.00
0005433847233	13865	Economy	36600.00
0005433847311	13865	Economy	36600.00
0005433847172	13865	Economy	33300.00
0005433815434	13865	Economy	36600.00
0005435283004	13865	Economy	33300.00
0005433847310	13865	Economy	33300.00
0005435283013	13865	Economy	33300.00
0005433847394	13865	Economy	33300.00
0005435283009	13865	Economy	33300.00
0005433847312	13865	Economy	33300.00
0005433847500	13865	Economy	33300.00
0005435283008	13865	Economy	33300.00
0005433847604	13865	Economy	33300.00
0005433847242	13865	Economy	33300.00
0005433847355	13865	Economy	33300.00
0005433847413	13865	Economy	33300.00
0005433847529	13865	Economy	33300.00
0005433847699	13865	Economy	33300.00
0005435283014	13865	Economy	33300.00
0005433815441	13865	Economy	33300.00
0005434173601	13865	Economy	33300.00
0005434173605	13865	Economy	33300.00
0005433847363	13865	Economy	33300.00
0005433847262	13865	Economy	33300.00
0005433847326	13865	Economy	33300.00
0005433847431	13865	Economy	33300.00
0005433847551	13865	Economy	33300.00
0005435283007	13865	Economy	33300.00
0005433847216	13865	Economy	33300.00
0005433847339	13865	Economy	33300.00
0005433847490	13865	Economy	33300.00
0005433847324	13865	Economy	33300.00
0005433847300	13865	Economy	33300.00
0005433847432	13865	Economy	33300.00
0005433847322	13865	Economy	33300.00
0005433847299	13865	Economy	33300.00
0005434173604	13865	Economy	33300.00
0005435282997	13865	Economy	33300.00
0005433847448	13865	Economy	33300.00
0005433815442	13865	Economy	33300.00
0005435283002	13865	Economy	33300.00
0005435283011	13865	Economy	33300.00
0005433847473	13865	Economy	33300.00
0005434173602	13865	Economy	33300.00
0005432003766	13865	Economy	33300.00
0005435283012	13865	Economy	33300.00
0005433847354	13865	Economy	33300.00
0005433847323	13865	Economy	33300.00
0005435282999	13865	Economy	33300.00
0005433847388	13865	Economy	33300.00
0005433847552	13865	Economy	33300.00
0005433847547	13865	Economy	33300.00
0005433847684	13865	Economy	33300.00
0005433847412	13865	Economy	33300.00
0005433847627	13865	Economy	33300.00
0005435282994	13865	Economy	33300.00
0005433847333	13865	Economy	33300.00
0005433847404	13865	Economy	33300.00
0005433847379	13865	Economy	33300.00
0005433847241	13865	Economy	33300.00
0005433847376	13865	Economy	33300.00
0005433847387	13865	Economy	33300.00
0005435283006	13865	Economy	33300.00
0005433847286	13865	Economy	33300.00
0005433847281	13865	Economy	33300.00
0005435282998	13865	Economy	33300.00
0005433847380	13865	Economy	33300.00
0005433847287	13865	Economy	33300.00
0005433847338	13865	Economy	33300.00
0005433847517	13865	Economy	33300.00
0005433847443	13865	Economy	33300.00
0005435282993	13865	Economy	33300.00
0005433847444	13865	Economy	33300.00
0005433847467	13865	Economy	33300.00
0005434173600	13865	Economy	33300.00
0005433847253	13865	Economy	33300.00
0005435332480	7830	Economy	16600.00
0005435332478	7830	Economy	15100.00
0005434621020	7830	Economy	15100.00
0005435332477	7830	Economy	15100.00
0005434621004	7830	Economy	15100.00
0005434621010	7830	Economy	15100.00
0005434621006	7830	Economy	15100.00
0005435332479	7830	Economy	15100.00
0005434621016	7830	Economy	15100.00
0005434621014	7830	Economy	15100.00
0005434621002	7830	Economy	15100.00
0005435332472	7830	Economy	15100.00
0005435332455	7830	Economy	15100.00
0005434621019	7830	Economy	15100.00
0005434621007	7830	Economy	15100.00
0005435332506	7830	Economy	15100.00
0005434621005	7830	Economy	15100.00
0005434621011	7830	Economy	15100.00
0005434621015	7830	Economy	15100.00
0005434621003	7830	Economy	15100.00
0005432112562	7830	Economy	15100.00
0005434621012	7830	Economy	15100.00
0005434621017	7830	Economy	15100.00
0005434621009	7830	Economy	15100.00
0005434621013	7830	Economy	15100.00
0005434621001	7830	Economy	15100.00
0005435332461	7830	Economy	15100.00
0005434621000	7830	Economy	15100.00
0005434621018	7830	Economy	15100.00
0005434621008	7830	Economy	15100.00
0005434620826	32976	Economy	16600.00
0005435332543	32976	Economy	16600.00
0005434620846	32976	Economy	15100.00
0005435332548	32976	Economy	15100.00
0005435332546	32976	Economy	15100.00
0005434620910	32976	Economy	15100.00
0005435332542	32976	Economy	15100.00
0005435332547	32976	Economy	15100.00
0005434620877	32976	Economy	15100.00
0005434620848	32976	Economy	15100.00
0005434620892	32976	Economy	15100.00
0005434620768	32976	Economy	15100.00
0005435332541	32976	Economy	15100.00
0005434620762	32976	Economy	15100.00
0005434620876	32976	Economy	15100.00
0005434620808	32976	Economy	15100.00
0005434620865	32976	Economy	15100.00
0005435332549	32976	Economy	15100.00
0005434620765	32976	Economy	15100.00
0005434620829	32976	Economy	15100.00
0005434620866	32976	Economy	15100.00
0005435332545	32976	Economy	15100.00
0005434620835	32976	Economy	15100.00
0005434620824	32976	Economy	15100.00
0005434620844	32976	Economy	15100.00
0005435332550	32976	Economy	15100.00
0005434620849	32976	Economy	15100.00
0005434620888	32976	Economy	15100.00
0005434620861	32976	Economy	15100.00
0005435332544	32976	Economy	15100.00
0005434620809	32976	Economy	15100.00
0005435786072	4256	Business	38000.00
0005435786044	4256	Business	38000.00
0005435786042	4256	Business	38000.00
0005435918717	4256	Business	38000.00
0005434994220	4256	Business	38000.00
0005435937434	4256	Business	38000.00
0005434994216	4256	Business	38000.00
0005435918716	4256	Economy	12700.00
0005435786057	4256	Economy	12700.00
0005434994218	4256	Economy	12700.00
0005435786074	4256	Economy	12700.00
0005432190709	4256	Economy	12700.00
0005435937420	4256	Economy	12700.00
0005435918710	4256	Economy	12700.00
0005435786050	4256	Economy	12700.00
0005432190708	4256	Economy	13900.00
0005435786071	4256	Economy	13900.00
0005434994219	4256	Economy	13900.00
0005435786056	4256	Economy	12700.00
0005435786052	4256	Economy	12700.00
0005435786054	4256	Economy	12700.00
0005434994221	4256	Economy	12700.00
0005435786063	4256	Economy	12700.00
0005435918731	4256	Economy	12700.00
0005435786048	4256	Economy	12700.00
0005434994224	4256	Economy	12700.00
0005435786058	4256	Economy	12700.00
0005435786051	4256	Economy	12700.00
0005435786065	4256	Economy	12700.00
0005435786062	4256	Economy	12700.00
0005435937421	4256	Economy	12700.00
0005435786049	4256	Economy	12700.00
0005435787396	4256	Economy	12700.00
0005435786075	4256	Economy	12700.00
0005435786055	4256	Economy	12700.00
0005435786053	4256	Economy	12700.00
0005435786070	4256	Economy	12700.00
0005435937437	4256	Economy	12700.00
0005435786041	4256	Economy	12700.00
0005435786060	4256	Economy	12700.00
0005434994217	4256	Economy	12700.00
0005435918711	4256	Economy	12700.00
0005434994222	4256	Economy	12700.00
0005435786069	4256	Economy	12700.00
0005435786043	4256	Economy	12700.00
0005434994225	4256	Economy	12700.00
0005435786066	4256	Economy	12700.00
0005435786073	4256	Economy	12700.00
0005435786067	4256	Economy	12700.00
0005435786061	4256	Economy	12700.00
0005435786068	4256	Economy	12700.00
0005432190706	4256	Economy	12700.00
0005434994226	4256	Economy	12700.00
0005435786045	4256	Economy	12700.00
0005435786046	4256	Economy	12700.00
0005435786047	4256	Economy	12700.00
0005434994223	4256	Economy	12700.00
0005435786064	4256	Economy	12700.00
0005435918698	4256	Economy	12700.00
0005435786040	4256	Economy	12700.00
0005435787397	4256	Economy	12700.00
0005435786059	4256	Economy	12700.00
0005435918699	4256	Economy	12700.00
0005435937431	4256	Economy	12700.00
0005432190707	4256	Economy	12700.00
0005435937467	27286	Business	38000.00
0005435918756	27286	Business	38000.00
0005434994114	27286	Business	38000.00
0005435785688	27286	Business	38000.00
0005435785594	27286	Business	38000.00
0005435785639	27286	Business	38000.00
0005435918752	27286	Business	38000.00
0005435785872	27286	Business	38000.00
0005435785654	27286	Business	38000.00
0005434994139	27286	Economy	12700.00
0005435785810	27286	Economy	12700.00
0005434994121	27286	Economy	12700.00
0005435785696	27286	Economy	12700.00
0005435785655	27286	Economy	12700.00
0005435918751	27286	Economy	12700.00
0005435785690	27286	Economy	12700.00
0005435785693	27286	Economy	12700.00
0005435785683	27286	Economy	12700.00
0005435785674	27286	Economy	12700.00
0005435785640	27286	Economy	13900.00
0005435785686	27286	Economy	13900.00
0005435918753	27286	Economy	12700.00
0005435785754	27286	Economy	12700.00
0005435785838	27286	Economy	12700.00
0005435785787	27286	Economy	12700.00
0005435785621	27286	Economy	12700.00
0005434994105	27286	Economy	12700.00
0005435785605	27286	Economy	12700.00
0005435785873	27286	Economy	12700.00
0005435785679	27286	Economy	12700.00
0005435785606	27286	Economy	12700.00
0005435785734	27286	Economy	12700.00
0005435785630	27286	Economy	12700.00
0005434994086	27286	Economy	12700.00
0005435918755	27286	Economy	12700.00
0005435785702	27286	Economy	12700.00
0005435785486	27286	Economy	12700.00
0005435785689	27286	Economy	12700.00
0005432195736	27286	Economy	12700.00
0005435918754	27286	Economy	12700.00
0005435785676	27286	Economy	12700.00
0005435785647	27286	Economy	12700.00
0005435785715	27286	Economy	12700.00
0005435785713	27286	Economy	12700.00
0005434994180	27286	Economy	12700.00
0005434994132	27286	Economy	12700.00
0005432195735	27286	Economy	12700.00
0005435785697	27286	Economy	12700.00
0005435785691	27286	Economy	12700.00
0005435785757	27286	Economy	12700.00
0005434994133	27286	Economy	12700.00
0005435785687	27286	Economy	12700.00
0005435785839	27286	Economy	12700.00
0005435937469	27286	Economy	12700.00
0005435785692	27286	Economy	12700.00
0005434994153	27286	Economy	12700.00
0005434994181	27286	Economy	12700.00
0005435785620	27286	Economy	12700.00
0005435937470	27286	Economy	12700.00
0005432195737	27286	Economy	12700.00
0005435785671	27286	Economy	12700.00
0005434994098	27286	Economy	12700.00
0005435918757	27286	Economy	12700.00
0005434994116	27286	Economy	12700.00
0005434994140	27286	Economy	12700.00
0005435937468	27286	Economy	12700.00
0005435785840	27286	Economy	12700.00
0005435785776	27286	Economy	12700.00
0005435785646	27286	Economy	12700.00
0005435785703	27286	Economy	12700.00
0005432146239	19892	Economy	12800.00
0005432146240	19892	Economy	12800.00
0005432146241	19892	Economy	12800.00
0005432460880	4722	Business	40900.00
0005432568868	4722	Business	40900.00
0005432460883	4722	Business	40900.00
0005432568861	4722	Business	40900.00
0005432568873	4722	Business	40900.00
0005433726150	4722	Business	40900.00
0005432568892	4722	Business	40900.00
0005432568840	4722	Business	40900.00
0005432460897	4722	Business	40900.00
0005432568901	4722	Business	40900.00
0005432170526	4722	Business	40900.00
0005434082389	4722	Business	40900.00
0005432460894	4722	Business	40900.00
0005432460912	4722	Business	40900.00
0005432568886	4722	Business	40900.00
0005434559119	4722	Business	40900.00
0005432460926	4722	Business	40900.00
0005432460886	4722	Business	40900.00
0005432460887	4722	Business	40900.00
0005434082375	4722	Business	40900.00
0005432568899	4722	Business	40900.00
0005432568895	4722	Business	40900.00
0005434559117	4722	Business	40900.00
0005432568863	4722	Economy	15000.00
0005432460898	4722	Economy	15000.00
0005432568875	4722	Economy	15000.00
0005433726151	4722	Economy	13600.00
0005432460918	4722	Economy	13600.00
0005432568843	4722	Economy	13600.00
0005434082390	4722	Economy	13600.00
0005433451661	4722	Economy	13600.00
0005432460915	4722	Economy	13600.00
0005434082363	4722	Economy	13600.00
0005432460932	4722	Economy	13600.00
0005432460890	4722	Economy	13600.00
0005434082365	4722	Economy	13600.00
0005432460913	4722	Economy	13600.00
0005432170523	4722	Economy	13600.00
0005434082378	4722	Economy	13600.00
0005432568851	4722	Economy	13600.00
0005432568866	4722	Economy	13600.00
0005432186944	4722	Economy	13600.00
0005432568854	4722	Economy	13600.00
0005434082386	4722	Economy	13600.00
0005432460893	4722	Economy	13600.00
0005432460911	4722	Economy	13600.00
0005432568847	4722	Economy	13600.00
0005434559115	4722	Economy	13600.00
0005432460885	4722	Economy	13600.00
0005432568894	4722	Economy	13600.00
0005432571399	4722	Economy	13600.00
0005432568858	4722	Economy	13600.00
0005432460889	4722	Economy	13600.00
0005432460906	4722	Economy	13600.00
0005434082362	4722	Economy	13600.00
0005432568846	4722	Economy	13600.00
0005432571398	4722	Economy	13600.00
0005432186942	4722	Economy	13600.00
0005432460914	4722	Economy	13600.00
0005434082373	4722	Economy	13600.00
0005434082379	4722	Economy	13600.00
0005432568874	4722	Economy	13600.00
0005432568881	4722	Economy	13600.00
0005434559114	4722	Economy	13600.00
0005432170522	4722	Economy	13600.00
0005432460908	4722	Economy	13600.00
0005432460892	4722	Economy	13600.00
0005432568864	4722	Economy	13600.00
0005432568880	4722	Economy	13600.00
0005432460929	4722	Economy	13600.00
0005432568877	4722	Economy	13600.00
0005432460931	4722	Economy	13600.00
0005432568859	4722	Economy	13600.00
0005432460907	4722	Economy	13600.00
0005434082367	4722	Economy	13600.00
0005434082385	4722	Economy	13600.00
0005432568841	4722	Economy	13600.00
0005432460884	4722	Economy	13600.00
0005434082381	4722	Economy	13600.00
0005434082384	4722	Economy	13600.00
0005432460921	4722	Economy	13600.00
0005432568849	4722	Economy	13600.00
0005434082359	4722	Economy	13600.00
0005432568893	4722	Economy	13600.00
0005432568857	4722	Economy	13600.00
0005432568896	4722	Economy	13600.00
0005432460923	4722	Economy	13600.00
0005432460924	4722	Economy	13600.00
0005432460881	4722	Economy	13600.00
0005432568848	4722	Economy	13600.00
0005432568898	4722	Economy	13600.00
0005432568900	4722	Economy	13600.00
0005432460901	4722	Economy	13600.00
0005432460896	4722	Economy	13600.00
0005433452781	4722	Economy	13600.00
0005432571397	4722	Economy	13600.00
0005434082360	4722	Economy	13600.00
0005434082383	4722	Economy	13600.00
0005432460928	4722	Economy	13600.00
0005432568885	4722	Economy	13600.00
0005432460920	4722	Economy	13600.00
0005432568867	4722	Economy	13600.00
0005433452784	4722	Economy	13600.00
0005432460925	4722	Economy	13600.00
0005432460917	4722	Economy	13600.00
0005432568862	4722	Economy	13600.00
0005432568883	4722	Economy	13600.00
0005432568856	4722	Economy	13600.00
0005432568852	4722	Economy	15000.00
0005434082364	4722	Economy	13600.00
0005432568870	4722	Economy	15000.00
0005432568878	4722	Economy	13600.00
0005434082391	4722	Economy	13600.00
0005432568888	4722	Economy	13600.00
0005432460888	4722	Economy	13600.00
0005432568889	4722	Economy	13600.00
0005432460882	4722	Economy	13600.00
0005432170525	4722	Economy	13600.00
0005432460891	4722	Economy	13600.00
0005432568871	4722	Economy	13600.00
0005432568897	4722	Economy	13600.00
0005433452782	4722	Economy	13600.00
0005432460909	4722	Economy	13600.00
0005434082380	4722	Economy	13600.00
0005434082361	4722	Economy	13600.00
0005432568891	4722	Economy	13600.00
0005432460904	4722	Economy	13600.00
0005432568887	4722	Economy	13600.00
0005432460916	4722	Economy	13600.00
0005433452783	4722	Economy	13600.00
0005432460895	4722	Economy	13600.00
0005432460903	4722	Economy	13600.00
0005432460919	4722	Economy	13600.00
0005432568845	4722	Economy	13600.00
0005432568853	4722	Economy	13600.00
0005432460905	4722	Economy	13600.00
0005432568850	4722	Economy	13600.00
0005432460930	4722	Economy	13600.00
0005434082366	4722	Economy	13600.00
0005432460902	4722	Economy	13600.00
0005434082372	4722	Economy	13600.00
0005432568855	4722	Economy	13600.00
0005434559118	4722	Economy	13600.00
0005434082377	4722	Economy	13600.00
0005432568842	4722	Economy	13600.00
0005434559116	4722	Economy	13600.00
0005432568876	4722	Economy	13600.00
0005432568882	4722	Economy	13600.00
0005432568884	4722	Economy	13600.00
0005432568869	4722	Economy	13600.00
0005432568865	4722	Economy	13600.00
0005432186945	4722	Economy	13600.00
0005434082376	4722	Economy	13600.00
0005434082370	4722	Economy	13600.00
0005434082382	4722	Economy	13600.00
0005434082387	4722	Economy	13600.00
0005434082368	4722	Economy	13600.00
0005432460900	4722	Economy	13600.00
0005432170524	4722	Economy	13600.00
0005432568879	4722	Economy	13600.00
0005432568860	4722	Economy	13600.00
0005432460899	4722	Economy	13600.00
0005432186943	4722	Economy	13600.00
0005432460922	4722	Economy	13600.00
0005432186946	4722	Economy	13600.00
0005432568890	4722	Economy	13600.00
0005434082369	4722	Economy	13600.00
0005432568872	4722	Economy	13600.00
0005432170527	4722	Economy	13600.00
0005432568844	4722	Economy	13600.00
0005434082371	4722	Economy	13600.00
0005434082388	4722	Economy	13600.00
0005432460910	4722	Economy	13600.00
0005434082374	4722	Economy	13600.00
0005432460927	4722	Economy	13600.00
0005432568267	30562	Business	40900.00
0005433726121	30562	Business	40900.00
0005432568509	30562	Business	40900.00
0005432568380	30562	Business	40900.00
0005432568393	30562	Business	40900.00
0005432460647	30562	Business	40900.00
0005432460612	30562	Business	40900.00
0005434082125	30562	Business	40900.00
0005432568419	30562	Business	40900.00
0005434082124	30562	Business	40900.00
0005432568266	30562	Business	40900.00
0005432568153	30562	Business	40900.00
0005432568550	30562	Business	40900.00
0005433726098	30562	Business	40900.00
0005432460546	30562	Business	40900.00
0005434082100	30562	Business	40900.00
0005432568385	30562	Business	40900.00
0005434082093	30562	Business	40900.00
0005432568478	30562	Economy	15000.00
0005432460505	30562	Economy	15000.00
0005432568408	30562	Economy	13600.00
0005432568525	30562	Economy	13600.00
0005433726115	30562	Economy	13600.00
0005434082092	30562	Economy	13600.00
0005432460699	30562	Economy	13600.00
0005432460619	30562	Economy	13600.00
0005434082106	30562	Economy	13600.00
0005434559099	30562	Economy	13600.00
0005433452767	30562	Economy	13600.00
0005432460679	30562	Economy	13600.00
0005432568281	30562	Economy	13600.00
0005433452770	30562	Economy	13600.00
0005432568382	30562	Economy	13600.00
0005432460512	30562	Economy	13600.00
0005432568411	30562	Economy	13600.00
0005432460443	30562	Economy	13600.00
0005432568687	30562	Economy	13600.00
0005432460526	30562	Economy	13600.00
0005432571370	30562	Economy	13600.00
0005432568413	30562	Economy	13600.00
0005432568300	30562	Economy	13600.00
0005432568526	30562	Economy	13600.00
0005432460539	30562	Economy	13600.00
0005434559096	30562	Economy	13600.00
0005432568353	30562	Economy	13600.00
0005432213682	30562	Economy	13600.00
0005432571369	30562	Economy	13600.00
0005432460489	30562	Economy	13600.00
0005433726107	30562	Economy	13600.00
0005432568377	30562	Economy	13600.00
0005432568588	30562	Economy	13600.00
0005432460376	30562	Economy	13600.00
0005432568568	30562	Economy	13600.00
0005432571363	30562	Economy	13600.00
0005433454899	30562	Economy	13600.00
0005433726102	30562	Economy	13600.00
0005434082078	30562	Economy	13600.00
0005432460442	30562	Economy	13600.00
0005432460544	30562	Economy	13600.00
0005432460585	30562	Economy	13600.00
0005432460527	30562	Economy	13600.00
0005432568437	30562	Economy	13600.00
0005432568378	30562	Economy	13600.00
0005432460488	30562	Economy	13600.00
0005432460540	30562	Economy	13600.00
0005432460646	30562	Economy	13600.00
0005434559098	30562	Economy	13600.00
0005433726119	30562	Economy	13600.00
0005432460677	30562	Economy	13600.00
0005432460541	30562	Economy	13600.00
0005432213683	30562	Economy	13600.00
0005432460513	30562	Economy	13600.00
0005432460645	30562	Economy	13600.00
0005432460346	30562	Economy	13600.00
0005432568376	30562	Economy	13600.00
0005433726100	30562	Economy	13600.00
0005432568491	30562	Economy	13600.00
0005432460577	30562	Economy	13600.00
0005432460563	30562	Economy	13600.00
0005434082132	30562	Economy	13600.00
0005432460547	30562	Economy	13600.00
0005432568257	30562	Economy	15000.00
0005434082126	30562	Economy	13600.00
0005432161199	30562	Economy	13600.00
0005432460423	30562	Economy	13600.00
0005432460662	30562	Economy	13600.00
0005432213681	30562	Economy	13600.00
0005432568532	30562	Economy	13600.00
0005432568489	30562	Economy	13600.00
0005432568589	30562	Economy	13600.00
0005433726111	30562	Economy	13600.00
0005432460440	30562	Economy	13600.00
0005432460542	30562	Economy	13600.00
0005432460327	30562	Economy	13600.00
0005432568289	30562	Economy	13600.00
0005433452760	30562	Economy	13600.00
0005432460572	30562	Economy	13600.00
0005432568379	30562	Economy	13600.00
0005433452761	30562	Economy	13600.00
0005433452769	30562	Economy	13600.00
0005432213684	30562	Economy	13600.00
0005432460564	30562	Economy	13600.00
0005433726099	30562	Economy	13600.00
0005432568256	30562	Economy	13600.00
0005433726120	30562	Economy	13600.00
0005432568366	30562	Economy	13600.00
0005432568381	30562	Economy	13600.00
0005432568226	30562	Economy	13600.00
0005432460490	30562	Economy	13600.00
0005432460685	30562	Economy	13600.00
0005432460458	30562	Economy	13600.00
0005432460528	30562	Economy	13600.00
0005432568280	30562	Economy	13600.00
0005432571362	30562	Economy	13600.00
0005432568222	30562	Economy	13600.00
0005432460493	30562	Economy	13600.00
0005434082094	30562	Economy	13600.00
0005432568420	30562	Economy	13600.00
0005432568531	30562	Economy	13600.00
0005432568191	30562	Economy	13600.00
0005432460347	30562	Economy	13600.00
0005433726114	30562	Economy	13600.00
0005433726094	30562	Economy	13600.00
0005432460571	30562	Economy	13600.00
0005432568386	30562	Economy	13600.00
0005432568290	30562	Economy	13600.00
0005432568265	30562	Economy	13600.00
0005432460686	30562	Economy	13600.00
0005432460551	30562	Economy	13600.00
0005432568490	30562	Economy	13600.00
0005432460430	30562	Economy	13600.00
0005432460573	30562	Economy	13600.00
0005432568217	30562	Economy	13600.00
0005432568513	30562	Economy	13600.00
0005434082079	30562	Economy	13600.00
0005432568288	30562	Economy	13600.00
0005432568569	30562	Economy	13600.00
0005432568438	30562	Economy	13600.00
0005432460377	30562	Economy	13600.00
0005432460250	30562	Economy	13600.00
0005435722104	13644	Economy	9900.00
0005435720847	13644	Economy	9900.00
0005435722103	13644	Economy	9900.00
0005435720142	21218	Economy	9900.00
0005435720143	21218	Economy	9900.00
0005435720144	21218	Economy	9900.00
0005432295934	22809	Economy	8800.00
0005432295933	22809	Economy	8800.00
0005433345186	11118	Business	23600.00
0005433345229	11118	Business	23600.00
0005433345230	11118	Business	23600.00
0005433345202	11118	Business	23600.00
0005433345214	11118	Business	23600.00
0005433345180	11118	Business	23600.00
0005433345207	11118	Business	23600.00
0005433345246	11118	Business	23600.00
0005433345185	11118	Business	23600.00
0005433345197	11118	Business	23600.00
0005433345209	11118	Business	23600.00
0005433345204	11118	Business	23600.00
0005433345182	11118	Economy	7900.00
0005435097398	11118	Economy	7900.00
0005435097401	11118	Economy	7900.00
0005433345149	11118	Economy	7900.00
0005435097403	11118	Economy	7900.00
0005433345219	11118	Economy	7900.00
0005435508480	11118	Economy	7900.00
0005435097399	11118	Economy	7900.00
0005433345232	11118	Economy	7900.00
0005433345189	11118	Economy	7900.00
0005433345233	11118	Economy	7900.00
0005433345184	11118	Economy	7900.00
0005435097404	11118	Economy	7900.00
0005433345211	11118	Economy	7900.00
0005433345194	11118	Economy	7900.00
0005433345236	11118	Economy	7900.00
0005433345217	11118	Economy	7900.00
0005433345228	11118	Economy	7900.00
0005433345196	11118	Economy	7900.00
0005433345201	11118	Economy	7900.00
0005433345225	11118	Economy	7900.00
0005433345181	11118	Economy	7900.00
0005435508471	11118	Economy	7900.00
0005433345220	11118	Economy	7900.00
0005435508470	11118	Economy	7900.00
0005435097396	11118	Economy	7900.00
0005433345191	11118	Economy	7900.00
0005433345237	11118	Economy	7900.00
0005435097400	11118	Economy	7900.00
0005433345239	11118	Economy	7900.00
0005435380343	11118	Economy	7900.00
0005433345175	11118	Economy	7900.00
0005433345195	11118	Economy	7900.00
0005433345152	11118	Economy	7900.00
0005433345168	11118	Economy	7900.00
0005433345242	11118	Economy	7900.00
0005433345235	11118	Economy	7900.00
0005435380344	11118	Economy	7900.00
0005433345243	11118	Economy	7900.00
0005433345164	11118	Economy	8600.00
0005433345179	11118	Economy	7900.00
0005433345231	11118	Economy	8600.00
0005435508483	11118	Economy	8600.00
0005433345247	11118	Economy	8600.00
0005433345163	11118	Economy	8600.00
0005433345147	11118	Economy	8600.00
0005433345160	11118	Economy	7900.00
0005435508442	11118	Economy	7900.00
0005433345161	11118	Economy	7900.00
0005435097397	11118	Economy	7900.00
0005433345215	11118	Economy	7900.00
0005433345162	11118	Economy	7900.00
0005435097395	11118	Economy	7900.00
0005435380355	11118	Economy	7900.00
0005433345203	11118	Economy	7900.00
0005435508487	11118	Economy	7900.00
0005433345213	11118	Economy	7900.00
0005433345172	11118	Economy	7900.00
0005433345218	11118	Economy	7900.00
0005433345222	11118	Economy	7900.00
0005433345166	11118	Economy	7900.00
0005433345155	11118	Economy	7900.00
0005433345224	11118	Economy	7900.00
0005433345177	11118	Economy	7900.00
0005433345150	11118	Economy	7900.00
0005435380345	11118	Economy	7900.00
0005433345165	11118	Economy	7900.00
0005433345216	11118	Economy	7900.00
0005433345205	11118	Economy	7900.00
0005433345169	11118	Economy	7900.00
0005433345226	11118	Economy	7900.00
0005433345223	11118	Economy	7900.00
0005435380325	11118	Economy	7900.00
0005433345167	11118	Economy	7900.00
0005433345174	11118	Economy	7900.00
0005433345234	11118	Economy	7900.00
0005433345193	11118	Economy	7900.00
0005433345241	11118	Economy	7900.00
0005433345208	11118	Economy	7900.00
0005433345170	11118	Economy	7900.00
0005433345171	11118	Economy	7900.00
0005433345183	11118	Economy	7900.00
0005433345187	11118	Economy	7900.00
0005433345212	11118	Economy	7900.00
0005433345227	11118	Economy	7900.00
0005433345156	11118	Economy	7900.00
0005433345158	11118	Economy	7900.00
0005433345190	11118	Economy	7900.00
0005435097402	11118	Economy	7900.00
0005433345157	11118	Economy	7900.00
0005433345206	11118	Economy	7900.00
0005433345245	11118	Economy	7900.00
0005433345148	11118	Economy	7900.00
0005433345200	11118	Economy	7900.00
0005435508485	11118	Economy	7900.00
0005435508440	11118	Economy	7900.00
0005433345240	11118	Economy	7900.00
0005433345198	11118	Economy	7900.00
0005433345151	11118	Economy	7900.00
0005433345244	11118	Economy	7900.00
0005433345192	11118	Economy	7900.00
0005433345153	11118	Economy	7900.00
0005433345154	11118	Economy	7900.00
0005433345221	11118	Economy	7900.00
0005433345188	11118	Economy	7900.00
0005433345159	11118	Economy	7900.00
0005433345199	11118	Economy	7900.00
0005433345178	11118	Economy	7900.00
0005433345248	11118	Economy	7900.00
0005433345173	11118	Economy	7900.00
0005433345238	11118	Economy	7900.00
0005435508474	11118	Economy	7900.00
0005435380341	11118	Economy	7900.00
0005433345176	11118	Economy	7900.00
0005433345210	11118	Economy	7900.00
0005433344523	17083	Business	23600.00
0005433343786	17083	Business	23600.00
0005433344341	17083	Business	23600.00
0005433344204	17083	Business	23600.00
0005433344511	17083	Business	23600.00
0005435097311	17083	Business	23600.00
0005433343733	17083	Business	23600.00
0005433344133	17083	Business	23600.00
0005435545888	17083	Business	23600.00
0005433344261	17083	Business	23600.00
0005435097325	17083	Business	23600.00
0005433344714	17083	Business	23600.00
0005433344570	17083	Economy	7900.00
0005433343785	17083	Economy	7900.00
0005433343885	17083	Economy	7900.00
0005433344356	17083	Economy	7900.00
0005435097277	17083	Economy	7900.00
0005433343984	17083	Economy	7900.00
0005433344068	17083	Economy	7900.00
0005433344203	17083	Economy	7900.00
0005433344031	17083	Economy	7900.00
0005433344494	17083	Economy	7900.00
0005433344462	17083	Economy	7900.00
0005433344205	17083	Economy	7900.00
0005433344414	17083	Economy	7900.00
0005433344357	17083	Economy	7900.00
0005433344354	17083	Economy	7900.00
0005433344064	17083	Economy	7900.00
0005433343821	17083	Economy	7900.00
0005433343946	17083	Economy	7900.00
0005435380401	17083	Economy	7900.00
0005433344214	17083	Economy	7900.00
0005433344380	17083	Economy	7900.00
0005433344067	17083	Economy	7900.00
0005433344509	17083	Economy	7900.00
0005433343945	17083	Economy	7900.00
0005433343823	17083	Economy	7900.00
0005433343735	17083	Economy	7900.00
0005433344426	17083	Economy	7900.00
0005433344358	17083	Economy	7900.00
0005433344259	17083	Economy	7900.00
0005433344083	17083	Economy	7900.00
0005433343974	17083	Economy	7900.00
0005433344063	17083	Economy	7900.00
0005433344115	17083	Economy	7900.00
0005433343539	17083	Economy	7900.00
0005433344262	17083	Economy	7900.00
0005433343677	17083	Economy	7900.00
0005433344281	17083	Economy	7900.00
0005435380402	17083	Economy	7900.00
0005435097305	17083	Economy	8600.00
0005435545885	17083	Economy	8600.00
0005433344222	17083	Economy	8600.00
0005433344118	17083	Economy	8600.00
0005435380399	17083	Economy	8600.00
0005433344351	17083	Economy	8600.00
0005433344493	17083	Economy	7900.00
0005433344522	17083	Economy	7900.00
0005435097310	17083	Economy	7900.00
0005435545886	17083	Economy	7900.00
0005433344053	17083	Economy	7900.00
0005433343798	17083	Economy	7900.00
0005435380400	17083	Economy	7900.00
0005433344275	17083	Economy	7900.00
0005433344716	17083	Economy	7900.00
0005435545889	17083	Economy	7900.00
0005432293259	17083	Economy	7900.00
0005433343914	17083	Economy	7900.00
0005433343629	17083	Economy	7900.00
0005433344192	17083	Economy	7900.00
0005433344217	17083	Economy	7900.00
0005433343886	17083	Economy	7900.00
0005435097341	17083	Economy	7900.00
0005435380398	17083	Economy	7900.00
0005433344233	17083	Economy	7900.00
0005433343947	17083	Economy	7900.00
0005433344367	17083	Economy	7900.00
0005435545887	17083	Economy	7900.00
0005433343884	17083	Economy	7900.00
0005435097299	17083	Economy	7900.00
0005433344677	17083	Economy	7900.00
0005433344322	17083	Economy	7900.00
0005433344552	17083	Economy	7900.00
0005433344560	17083	Economy	7900.00
0005435545884	17083	Economy	7900.00
0005433343822	17083	Economy	7900.00
0005433344562	17083	Economy	7900.00
0005433344069	17083	Economy	7900.00
0005432293258	17083	Economy	7900.00
0005433344715	17083	Economy	7900.00
0005433344276	17083	Economy	7900.00
0005433344065	17083	Economy	7900.00
0005433343967	17083	Economy	7900.00
0005435097256	17083	Economy	7900.00
0005435097273	17083	Economy	7900.00
0005433343835	17083	Economy	7900.00
0005433344561	17083	Economy	7900.00
0005433344678	17083	Economy	7900.00
0005435097298	17083	Economy	7900.00
0005433344381	17083	Economy	7900.00
0005433344207	17083	Economy	7900.00
0005433344202	17083	Economy	7900.00
0005433344340	17083	Economy	7900.00
0005433343913	17083	Economy	7900.00
0005433343975	17083	Economy	7900.00
0005433343678	17083	Economy	7900.00
0005433343958	17083	Economy	7900.00
0005435380397	17083	Economy	7900.00
0005433344208	17083	Economy	7900.00
0005435097276	17083	Economy	7900.00
0005433344051	17083	Economy	7900.00
0005433344052	17083	Economy	7900.00
0005433343985	17083	Economy	7900.00
0005433343957	17083	Economy	7900.00
0005435097339	17083	Economy	7900.00
0005433344379	17083	Economy	7900.00
0005435097262	17083	Economy	7900.00
0005433344353	17083	Economy	7900.00
0005433343977	17083	Economy	7900.00
0005433344258	17083	Economy	7900.00
0005433344209	17083	Economy	7900.00
0005433344119	17083	Economy	7900.00
0005433344316	17083	Economy	7900.00
0005433344263	17083	Economy	7900.00
0005433344632	17083	Economy	7900.00
0005433344679	17083	Economy	7900.00
0005433344362	17083	Economy	7900.00
0005433344190	17083	Economy	7900.00
0005432920105	9082	Business	26600.00
0005433507555	9082	Business	26600.00
0005432920100	9082	Business	26600.00
0005433477002	9082	Business	26600.00
0005432920107	9082	Business	26600.00
0005433476994	9082	Business	26600.00
0005433507538	9082	Business	26600.00
0005432920152	9082	Business	26600.00
0005433476992	9082	Business	26600.00
0005433477004	9082	Business	26600.00
0005432920057	9082	Economy	8900.00
0005433481326	9082	Economy	8900.00
0005432920157	9082	Economy	8900.00
0005433477009	9082	Economy	8900.00
0005434158992	9082	Economy	8900.00
0005433481329	9082	Economy	8900.00
0005433476993	9082	Economy	8900.00
0005433507545	9082	Economy	8900.00
0005433481324	9082	Economy	8900.00
0005433477006	9082	Economy	9800.00
0005432919967	9082	Economy	9800.00
0005433477005	9082	Economy	9800.00
0005433507550	9082	Economy	8900.00
0005432920096	9082	Economy	8900.00
0005433477000	9082	Economy	8900.00
0005433481325	9082	Economy	8900.00
0005433507541	9082	Economy	8900.00
0005433476991	9082	Economy	8900.00
0005433507536	9082	Economy	8900.00
0005433507540	9082	Economy	8900.00
0005433477001	9082	Economy	8900.00
0005433476995	9082	Economy	8900.00
0005433507551	9082	Economy	8900.00
0005433507553	9082	Economy	8900.00
0005433477010	9082	Economy	8900.00
0005433476996	9082	Economy	8900.00
0005432920098	9082	Economy	8900.00
0005433476990	9082	Economy	8900.00
0005433477008	9082	Economy	8900.00
0005433507544	9082	Economy	8900.00
0005432920104	9082	Economy	8900.00
0005433507539	9082	Economy	8900.00
0005433477012	9082	Economy	8900.00
0005433507542	9082	Economy	8900.00
0005433476999	9082	Economy	8900.00
0005433507557	9082	Economy	8900.00
0005433507535	9082	Economy	8900.00
0005433507543	9082	Economy	8900.00
0005433507554	9082	Economy	8900.00
0005432920097	9082	Economy	8900.00
0005433481327	9082	Economy	8900.00
0005433507548	9082	Economy	8900.00
0005432919968	9082	Economy	8900.00
0005433477014	9082	Economy	8900.00
0005432920099	9082	Economy	8900.00
0005433507556	9082	Economy	8900.00
0005433477003	9082	Economy	8900.00
0005432920048	9082	Economy	8900.00
0005432920179	9082	Economy	8900.00
0005433507552	9082	Economy	8900.00
0005433477007	9082	Economy	8900.00
0005433477013	9082	Economy	8900.00
0005433507546	9082	Economy	8900.00
0005433507537	9082	Economy	8900.00
0005433507547	9082	Economy	8900.00
0005433476998	9082	Economy	8900.00
0005432920058	9082	Economy	8900.00
0005433477011	9082	Economy	8900.00
0005432920045	9082	Economy	8900.00
0005433476997	9082	Economy	8900.00
0005433481323	9082	Economy	8900.00
0005433507549	9082	Economy	8900.00
0005433481328	9082	Economy	8900.00
0005434158991	9082	Economy	8900.00
0005433481322	9082	Economy	8900.00
0005433507385	20452	Business	26600.00
0005432920301	20452	Business	26600.00
0005433507432	20452	Business	26600.00
0005432920304	20452	Business	26600.00
0005433507443	20452	Business	26600.00
0005433507418	20452	Business	26600.00
0005432920315	20452	Business	26600.00
0005434159018	20452	Economy	8900.00
0005432920303	20452	Economy	8900.00
0005433481253	20452	Economy	8900.00
0005433507365	20452	Economy	8900.00
0005434159017	20452	Economy	8900.00
0005433507416	20452	Economy	8900.00
0005433507397	20452	Economy	9800.00
0005433507466	20452	Economy	9800.00
0005433507433	20452	Economy	8900.00
0005432920309	20452	Economy	8900.00
0005433507384	20452	Economy	8900.00
0005433507469	20452	Economy	8900.00
0005432920316	20452	Economy	8900.00
0005433507316	20452	Economy	8900.00
0005432920295	20452	Economy	8900.00
0005432920314	20452	Economy	8900.00
0005433507415	20452	Economy	8900.00
0005432920300	20452	Economy	8900.00
0005433481282	20452	Economy	8900.00
0005432920313	20452	Economy	8900.00
0005432920305	20452	Economy	8900.00
0005432920312	20452	Economy	8900.00
0005432920306	20452	Economy	8900.00
0005432920307	20452	Economy	8900.00
0005433481231	20452	Economy	8900.00
0005432920299	20452	Economy	8900.00
0005433481232	20452	Economy	8900.00
0005432920302	20452	Economy	8900.00
0005432920308	20452	Economy	8900.00
0005432920297	20452	Economy	8900.00
0005433507386	20452	Economy	8900.00
0005434159021	20452	Economy	8900.00
0005433481233	20452	Economy	8900.00
0005433507444	20452	Economy	8900.00
0005434159019	20452	Economy	8900.00
0005433507395	20452	Economy	8900.00
0005433507457	20452	Economy	8900.00
0005432920310	20452	Economy	8900.00
0005433507417	20452	Economy	8900.00
0005432920298	20452	Economy	8900.00
0005433507436	20452	Economy	8900.00
0005432920311	20452	Economy	8900.00
0005433507408	20452	Economy	8900.00
0005433481275	20452	Economy	8900.00
0005434159020	20452	Economy	8900.00
0005433507398	20452	Economy	8900.00
0005432920296	20452	Economy	8900.00
0005432394181	10206	Economy	5800.00
0005432396318	10206	Economy	5800.00
0005432396320	10206	Economy	5800.00
0005432396317	10206	Economy	5800.00
0005432394184	10206	Economy	5800.00
0005432394182	10206	Economy	5800.00
0005435178998	10206	Economy	5800.00
0005432396319	10206	Economy	5800.00
0005432394183	10206	Economy	5800.00
0005435178999	10206	Economy	5800.00
0005432400143	18346	Economy	5800.00
0005432400144	18346	Economy	5800.00
0005432400169	18346	Economy	5800.00
0005432396287	18346	Economy	5800.00
0005432396290	18346	Economy	5800.00
0005432396291	18346	Economy	5800.00
0005432400162	18346	Economy	5800.00
0005432400145	18346	Economy	5800.00
0005432396292	18346	Economy	5800.00
0005432396278	18346	Economy	5800.00
0005435626319	10970	Business	9500.00
0005435126789	10970	Business	9500.00
0005434411867	10970	Business	9500.00
0005435126762	10970	Business	9500.00
0005435556729	10970	Business	9500.00
0005435126725	10970	Business	9500.00
0005435126758	10970	Business	9500.00
0005435126790	10970	Business	9500.00
0005435126844	10970	Business	9500.00
0005435554254	10970	Business	9500.00
0005435556728	10970	Business	9500.00
0005435126990	10970	Economy	3200.00
0005435126797	10970	Economy	3200.00
0005435626339	10970	Economy	3200.00
0005435626376	10970	Economy	3200.00
0005435626374	10970	Economy	3200.00
0005435126694	10970	Economy	3200.00
0005434411866	10970	Economy	3200.00
0005435126867	10970	Economy	3200.00
0005435126689	10970	Economy	3500.00
0005435126843	10970	Economy	3500.00
0005435126786	10970	Economy	3500.00
0005435126785	10970	Economy	3200.00
0005435126766	10970	Economy	3200.00
0005435126743	10970	Economy	3200.00
0005435126692	10970	Economy	3200.00
0005435126933	10970	Economy	3200.00
0005434928358	10970	Economy	3200.00
0005435126852	10970	Economy	3200.00
0005435626368	10970	Economy	3200.00
0005435626361	10970	Economy	3200.00
0005435626375	10970	Economy	3200.00
0005435626350	10970	Economy	3200.00
0005435126691	10970	Economy	3200.00
0005435126991	10970	Economy	3200.00
0005435626337	10970	Economy	3200.00
0005435126972	10970	Economy	3200.00
0005435626320	10970	Economy	3200.00
0005434411868	10970	Economy	3200.00
0005435626351	10970	Economy	3200.00
0005435126761	10970	Economy	3200.00
0005435126772	10970	Economy	3200.00
0005435626362	10970	Economy	3200.00
0005435126973	10970	Economy	3200.00
0005435126765	10970	Economy	3200.00
0005435626369	10970	Economy	3200.00
0005435126755	10970	Economy	3200.00
0005435126649	10970	Economy	3200.00
0005434411865	10970	Economy	3200.00
0005435626321	10970	Economy	3200.00
0005435126868	10970	Economy	3200.00
0005435554255	10970	Economy	3200.00
0005435126744	10970	Economy	3200.00
0005435126847	10970	Economy	3200.00
0005435554233	10970	Economy	3200.00
0005435126791	10970	Economy	3200.00
0005435126807	10970	Economy	3200.00
0005435126893	10970	Economy	3200.00
0005435126866	10970	Economy	3200.00
0005435126869	10970	Economy	3200.00
0005435626371	10970	Economy	3200.00
0005435126757	10970	Economy	3200.00
0005435126864	10970	Economy	3200.00
0005435126835	10970	Economy	3200.00
0005435554234	10970	Economy	3200.00
0005435126836	10970	Economy	3200.00
0005435126834	10970	Economy	3200.00
0005434928359	10970	Economy	3200.00
0005435626367	10970	Economy	3200.00
0005435126773	10970	Economy	3200.00
0005434928357	10970	Economy	3200.00
0005435126878	10970	Economy	3200.00
0005435126724	10970	Economy	3200.00
0005435126827	10970	Economy	3200.00
0005435626378	10970	Economy	3200.00
0005435127013	10970	Economy	3200.00
0005435556743	14707	Business	9500.00
0005435127197	14707	Business	9500.00
0005435626543	14707	Business	9500.00
0005435127199	14707	Business	9500.00
0005435127203	14707	Business	9500.00
0005435127228	14707	Business	9500.00
0005435127219	14707	Business	9500.00
0005435626559	14707	Business	9500.00
0005434411806	14707	Business	9500.00
0005434928326	14707	Economy	3200.00
0005435554285	14707	Economy	3200.00
0005435626555	14707	Economy	3200.00
0005435626545	14707	Economy	3200.00
0005435127216	14707	Economy	3200.00
0005435626557	14707	Economy	3200.00
0005434928327	14707	Economy	3200.00
0005435127190	14707	Economy	3500.00
0005435556744	14707	Economy	3500.00
0005435127207	14707	Economy	3500.00
0005435626558	14707	Economy	3200.00
0005435127191	14707	Economy	3200.00
0005435127205	14707	Economy	3200.00
0005435127222	14707	Economy	3200.00
0005435127217	14707	Economy	3200.00
0005435127192	14707	Economy	3200.00
0005435127202	14707	Economy	3200.00
0005435626550	14707	Economy	3200.00
0005435127224	14707	Economy	3200.00
0005435127210	14707	Economy	3200.00
0005435127223	14707	Economy	3200.00
0005435127226	14707	Economy	3200.00
0005435127194	14707	Economy	3200.00
0005434411825	14707	Economy	3200.00
0005434928323	14707	Economy	3200.00
0005434411805	14707	Economy	3200.00
0005435127208	14707	Economy	3200.00
0005435554281	14707	Economy	3200.00
0005434928324	14707	Economy	3200.00
0005435127215	14707	Economy	3200.00
0005435626554	14707	Economy	3200.00
0005435127196	14707	Economy	3200.00
0005435554283	14707	Economy	3200.00
0005435127213	14707	Economy	3200.00
0005435127218	14707	Economy	3200.00
0005435127200	14707	Economy	3200.00
0005435127204	14707	Economy	3200.00
0005435626560	14707	Economy	3200.00
0005435626561	14707	Economy	3200.00
0005435127193	14707	Economy	3200.00
0005435626556	14707	Economy	3200.00
0005435127212	14707	Economy	3200.00
0005435127220	14707	Economy	3200.00
0005435127211	14707	Economy	3200.00
0005435626548	14707	Economy	3200.00
0005434411832	14707	Economy	3200.00
0005435626546	14707	Economy	3200.00
0005435626544	14707	Economy	3200.00
0005435626551	14707	Economy	3200.00
0005435127198	14707	Economy	3200.00
0005434411824	14707	Economy	3200.00
0005435127209	14707	Economy	3200.00
0005435626553	14707	Economy	3200.00
0005435127206	14707	Economy	3200.00
0005435127221	14707	Economy	3200.00
0005435127201	14707	Economy	3200.00
0005435554284	14707	Economy	3200.00
0005435626552	14707	Economy	3200.00
0005435554282	14707	Economy	3200.00
0005435127225	14707	Economy	3200.00
0005435127227	14707	Economy	3200.00
0005435127214	14707	Economy	3200.00
0005435127195	14707	Economy	3200.00
0005435626549	14707	Economy	3200.00
0005435626547	14707	Economy	3200.00
0005435715825	7147	Business	86900.00
0005435715823	7147	Economy	29000.00
0005435216618	7147	Economy	29000.00
0005432398275	7147	Economy	29000.00
0005435715817	7147	Economy	29000.00
0005432398273	7147	Economy	31900.00
0005435715820	7147	Economy	31900.00
0005435715821	7147	Economy	29000.00
0005435715818	7147	Economy	29000.00
0005435715815	7147	Economy	29000.00
0005435715813	7147	Economy	29000.00
0005435216619	7147	Economy	29000.00
0005435715828	7147	Economy	29000.00
0005432398272	7147	Economy	29000.00
0005435715819	7147	Economy	29000.00
0005435715824	7147	Economy	29000.00
0005435443455	7147	Economy	29000.00
0005435715814	7147	Economy	29000.00
0005435715826	7147	Economy	29000.00
0005435443454	7147	Economy	29000.00
0005435443408	7147	Economy	29000.00
0005435715827	7147	Economy	29000.00
0005435715812	7147	Economy	29000.00
0005435219227	7147	Economy	29000.00
0005432400202	7147	Economy	29000.00
0005435443453	7147	Economy	29000.00
0005435715816	7147	Economy	29000.00
0005435443398	7147	Economy	29000.00
0005435443421	7147	Economy	29000.00
0005435715811	7147	Economy	29000.00
0005432398274	7147	Economy	29000.00
0005435443415	7147	Economy	29000.00
0005435179405	7147	Economy	29000.00
0005435443399	7147	Economy	29000.00
0005432400201	7147	Economy	29000.00
0005435443409	7147	Economy	29000.00
0005435715822	7147	Economy	29000.00
0005435715637	27083	Business	86900.00
0005435715712	27083	Business	86900.00
0005432398247	27083	Business	86900.00
0005435715702	27083	Business	86900.00
0005435715744	27083	Business	86900.00
0005435715657	27083	Business	86900.00
0005435178525	27083	Economy	29000.00
0005435443505	27083	Economy	29000.00
0005435179009	27083	Economy	29000.00
0005435715714	27083	Economy	29000.00
0005435715677	27083	Economy	29000.00
0005432398241	27083	Economy	31900.00
0005435443503	27083	Economy	31900.00
0005435443502	27083	Economy	31900.00
0005435443510	27083	Economy	29000.00
0005435443509	27083	Economy	29000.00
0005435715592	27083	Economy	29000.00
0005432398236	27083	Economy	29000.00
0005435443506	27083	Economy	29000.00
0005435715641	27083	Economy	29000.00
0005432398232	27083	Economy	29000.00
0005435443504	27083	Economy	29000.00
0005435443507	27083	Economy	29000.00
0005435715642	27083	Economy	29000.00
0005435178526	27083	Economy	29000.00
0005432398242	27083	Economy	29000.00
0005432398231	27083	Economy	29000.00
0005435443508	27083	Economy	29000.00
0005435715622	27083	Economy	29000.00
0005435715652	27083	Economy	29000.00
0005435715713	27083	Economy	29000.00
0005435715758	27083	Economy	29000.00
0005432398246	27083	Economy	29000.00
0005435715682	27083	Economy	29000.00
0005432398239	27083	Economy	29000.00
0005435715667	27083	Economy	29000.00
0005435715757	27083	Economy	29000.00
0005435715717	27083	Economy	29000.00
0005435715686	27083	Economy	29000.00
0005433060438	2735	Economy	7700.00
0005433060446	2735	Economy	7700.00
0005434085026	2735	Economy	7700.00
0005433060443	2735	Economy	7700.00
0005434085025	2735	Economy	7700.00
0005434085027	2735	Economy	7700.00
0005433060439	2735	Economy	7700.00
0005434085024	2735	Economy	7700.00
0005433060437	2735	Economy	7700.00
0005433060451	2735	Economy	7700.00
0005433060444	2735	Economy	7700.00
0005434084998	28499	Economy	7700.00
0005433060469	28499	Economy	7700.00
0005434084997	28499	Economy	7700.00
0005434084991	28499	Economy	7700.00
0005434084999	28499	Economy	7700.00
0005433060468	28499	Economy	7700.00
0005435518185	11373	Business	20200.00
0005435541307	11373	Business	20200.00
0005435541266	11373	Business	20200.00
0005435541223	11373	Business	20200.00
0005435518151	11373	Economy	6700.00
0005435541313	11373	Economy	6700.00
0005435518137	11373	Economy	6700.00
0005435518094	11373	Economy	6700.00
0005435518036	11373	Economy	7400.00
0005435541195	11373	Economy	6700.00
0005435518113	11373	Economy	6700.00
0005435541224	11373	Economy	6700.00
0005435541191	11373	Economy	6700.00
0005435518124	11373	Economy	6700.00
0005435541299	11373	Economy	6700.00
0005435518173	11373	Economy	6700.00
0005435541286	11373	Economy	6700.00
0005435518114	11373	Economy	6700.00
0005435518144	11373	Economy	6700.00
0005435541221	11373	Economy	6700.00
0005435518133	11373	Economy	6700.00
0005435518129	11373	Economy	6700.00
0005435518130	11373	Economy	6700.00
0005435541314	11373	Economy	6700.00
0005435541220	11373	Economy	6700.00
0005435518143	11373	Economy	6700.00
0005435541441	22228	Business	20200.00
0005435529692	22228	Business	20200.00
0005435541425	22228	Business	20200.00
0005435541435	22228	Business	20200.00
0005435529689	22228	Business	20200.00
0005435529690	22228	Business	20200.00
0005435541424	22228	Economy	6700.00
0005435541426	22228	Economy	6700.00
0005435541431	22228	Economy	6700.00
0005435529691	22228	Economy	6700.00
0005435530004	22228	Economy	6700.00
0005435530006	22228	Economy	6700.00
0005435529683	22228	Economy	6700.00
0005435530008	22228	Economy	6700.00
0005435541433	22228	Economy	6700.00
0005435530005	22228	Economy	6700.00
0005435541420	22228	Economy	6700.00
0005435529694	22228	Economy	6700.00
0005435529681	22228	Economy	6700.00
0005435541432	22228	Economy	6700.00
0005435529676	22228	Economy	6700.00
0005435529679	22228	Economy	6700.00
0005435529677	22228	Economy	6700.00
0005435529680	22228	Economy	6700.00
0005435541430	22228	Economy	6700.00
0005432294535	22228	Economy	6700.00
0005435530007	22228	Economy	6700.00
0005435530009	22228	Economy	6700.00
0005435529688	22228	Economy	6700.00
0005435541437	22228	Economy	6700.00
0005435541434	22228	Economy	6700.00
0005435541423	22228	Economy	6700.00
0005435541422	22228	Economy	6700.00
0005435529682	22228	Economy	6700.00
0005435541436	22228	Economy	6700.00
0005435529685	22228	Economy	6700.00
0005435530001	22228	Economy	6700.00
0005435541440	22228	Economy	6700.00
0005435529686	22228	Economy	6700.00
0005435530003	22228	Economy	6700.00
0005435541427	22228	Economy	6700.00
0005435541429	22228	Economy	6700.00
0005435541421	22228	Economy	6700.00
0005435529687	22228	Economy	6700.00
0005435529684	22228	Economy	6700.00
0005435541428	22228	Economy	6700.00
0005435530011	22228	Economy	6700.00
0005435529678	22228	Economy	6700.00
0005435529695	22228	Economy	6700.00
0005435529697	22228	Economy	6700.00
0005435541438	22228	Economy	6700.00
0005435541439	22228	Economy	6700.00
0005435529693	22228	Economy	6700.00
0005435530010	22228	Economy	6700.00
0005435529696	22228	Economy	6700.00
0005435530002	22228	Economy	6700.00
0005434908339	2289	Business	20200.00
0005434908340	2289	Business	20200.00
0005434908384	2289	Business	20200.00
0005434908394	2289	Business	20200.00
0005434908380	2289	Business	20200.00
0005434908349	2289	Business	20200.00
0005434908365	2289	Business	20200.00
0005434908393	2289	Business	20200.00
0005434908379	2289	Economy	6700.00
0005434908370	2289	Economy	6700.00
0005434908385	2289	Economy	6700.00
0005434908352	2289	Economy	6700.00
0005433251869	2289	Economy	6700.00
0005434908392	2289	Economy	6700.00
0005433401020	2289	Economy	6700.00
0005434908338	2289	Economy	6700.00
0005433401017	2289	Economy	6700.00
0005434908383	2289	Economy	7400.00
0005434908386	2289	Economy	7400.00
0005433251870	2289	Economy	7400.00
0005434908350	2289	Economy	7400.00
0005434908371	2289	Economy	7400.00
0005434908361	2289	Economy	6700.00
0005434908353	2289	Economy	6700.00
0005434908373	2289	Economy	6700.00
0005434908366	2289	Economy	6700.00
0005435787459	2289	Economy	6700.00
0005434908359	2289	Economy	6700.00
0005434908354	2289	Economy	6700.00
0005434908372	2289	Economy	6700.00
0005435787457	2289	Economy	6700.00
0005434908389	2289	Economy	6700.00
0005433251955	2289	Economy	6700.00
0005434908367	2289	Economy	6700.00
0005434908390	2289	Economy	6700.00
0005433251782	2289	Economy	6700.00
0005434908337	2289	Economy	6700.00
0005434908356	2289	Economy	6700.00
0005434908336	2289	Economy	6700.00
0005433251864	2289	Economy	6700.00
0005433251959	2289	Economy	6700.00
0005434908391	2289	Economy	6700.00
0005434908351	2289	Economy	6700.00
0005434908364	2289	Economy	6700.00
0005434908387	2289	Economy	6700.00
0005433251820	2289	Economy	6700.00
0005434908388	2289	Economy	6700.00
0005434908362	2289	Economy	6700.00
0005433251816	2289	Economy	6700.00
0005433251783	2289	Economy	6700.00
0005434908360	2289	Economy	6700.00
0005433251865	2289	Economy	6700.00
0005434908342	2289	Economy	6700.00
0005434908355	2289	Economy	6700.00
0005433251809	2289	Economy	6700.00
0005434908347	2289	Economy	6700.00
0005434908395	2289	Economy	6700.00
0005433251965	2289	Economy	6700.00
0005434908345	2289	Economy	6700.00
0005434908348	2289	Economy	6700.00
0005434908358	2289	Economy	6700.00
0005434908377	2289	Economy	6700.00
0005433251857	2289	Economy	6700.00
0005435787458	2289	Economy	6700.00
0005434908369	2289	Economy	6700.00
0005434908346	2289	Economy	6700.00
0005434908378	2289	Economy	6700.00
0005433251858	2289	Economy	6700.00
0005434908381	2289	Economy	6700.00
0005433401018	2289	Economy	6700.00
0005434908341	2289	Economy	6700.00
0005434908368	2289	Economy	6700.00
0005434908344	2289	Economy	6700.00
0005434908382	2289	Economy	6700.00
0005434908357	2289	Economy	6700.00
0005433251696	2289	Economy	6700.00
0005433251749	2289	Economy	6700.00
0005434908343	2289	Economy	6700.00
0005434908363	2289	Economy	6700.00
0005433251815	2289	Economy	6700.00
0005434908375	2289	Economy	6700.00
0005434908374	2289	Economy	6700.00
0005434908376	2289	Economy	6700.00
0005434907883	25627	Business	20200.00
0005433252117	25627	Business	20200.00
0005433252111	25627	Business	20200.00
0005433252102	25627	Business	20200.00
0005434907830	25627	Business	20200.00
0005434907714	25627	Business	20200.00
0005434907855	25627	Business	20200.00
0005434907779	25627	Business	20200.00
0005433252104	25627	Business	20200.00
0005434907696	25627	Business	20200.00
0005434907781	25627	Business	20200.00
0005433252124	25627	Economy	6700.00
0005434907843	25627	Economy	6700.00
0005434907825	25627	Economy	6700.00
0005433252128	25627	Economy	6700.00
0005433252098	25627	Economy	6700.00
0005434907610	25627	Economy	6700.00
0005434907811	25627	Economy	6700.00
0005433252113	25627	Economy	6700.00
0005433252099	25627	Economy	6700.00
0005434908001	25627	Economy	7400.00
0005434907979	25627	Economy	7400.00
0005434907812	25627	Economy	7400.00
0005434907803	25627	Economy	6700.00
0005433252123	25627	Economy	6700.00
0005434907834	25627	Economy	6700.00
0005433252107	25627	Economy	6700.00
0005434907831	25627	Economy	6700.00
0005434907905	25627	Economy	6700.00
0005433252112	25627	Economy	6700.00
0005434907785	25627	Economy	6700.00
0005433252108	25627	Economy	6700.00
0005434907862	25627	Economy	6700.00
0005434907833	25627	Economy	6700.00
0005434907698	25627	Economy	6700.00
0005434907950	25627	Economy	6700.00
0005433252105	25627	Economy	6700.00
0005434907611	25627	Economy	6700.00
0005434908025	25627	Economy	6700.00
0005434907912	25627	Economy	6700.00
0005433252122	25627	Economy	6700.00
0005433401044	25627	Economy	6700.00
0005433252101	25627	Economy	6700.00
0005434908021	25627	Economy	6700.00
0005434908026	25627	Economy	6700.00
0005433252100	25627	Economy	6700.00
0005434907914	25627	Economy	6700.00
0005434907829	25627	Economy	6700.00
0005433252114	25627	Economy	6700.00
0005434907792	25627	Economy	6700.00
0005433252121	25627	Economy	6700.00
0005434907854	25627	Economy	6700.00
0005434907906	25627	Economy	6700.00
0005434907784	25627	Economy	6700.00
0005434908004	25627	Economy	6700.00
0005434907965	25627	Economy	6700.00
0005434907594	25627	Economy	6700.00
0005434907935	25627	Economy	6700.00
0005433252097	25627	Economy	6700.00
0005434907960	25627	Economy	6700.00
0005434907848	25627	Economy	6700.00
0005433252127	25627	Economy	6700.00
0005434907856	25627	Economy	6700.00
0005434907836	25627	Economy	6700.00
0005433252119	25627	Economy	6700.00
0005433252125	25627	Economy	6700.00
0005433252118	25627	Economy	6700.00
0005433401045	25627	Economy	6700.00
0005433252109	25627	Economy	6700.00
0005433252106	25627	Economy	6700.00
0005433252115	25627	Economy	6700.00
0005434907842	25627	Economy	6700.00
0005433401046	25627	Economy	6700.00
0005433252103	25627	Economy	6700.00
0005434907593	25627	Economy	6700.00
0005433252126	25627	Economy	6700.00
0005434907786	25627	Economy	6700.00
0005434907826	25627	Economy	6700.00
0005433252120	25627	Economy	6700.00
0005434907835	25627	Economy	6700.00
0005434907780	25627	Economy	6700.00
0005433252116	25627	Economy	6700.00
0005434907850	25627	Economy	6700.00
0005434907936	25627	Economy	6700.00
0005434907861	25627	Economy	6700.00
0005433252110	25627	Economy	6700.00
0005434907882	25627	Economy	6700.00
0005432621335	2505	Economy	13600.00
0005432621332	2505	Economy	13600.00
0005432621328	2505	Economy	13600.00
0005432862371	2505	Economy	12400.00
0005432621324	2505	Economy	12400.00
0005432862409	2505	Economy	12400.00
0005432621334	2505	Economy	12400.00
0005432621326	2505	Economy	12400.00
0005432621331	2505	Economy	12400.00
0005432621322	2505	Economy	12400.00
0005432862424	2505	Economy	12400.00
0005432862408	2505	Economy	12400.00
0005432862388	2505	Economy	12400.00
0005432621333	2505	Economy	12400.00
0005432621327	2505	Economy	12400.00
0005432862389	2505	Economy	12400.00
0005432862417	2505	Economy	12400.00
0005432621329	2505	Economy	12400.00
0005432621323	2505	Economy	12400.00
0005432862387	2505	Economy	12400.00
0005432621325	2505	Economy	12400.00
0005432621330	2505	Economy	12400.00
0005432621222	28045	Economy	12400.00
0005432621181	28045	Economy	12400.00
0005432862458	28045	Economy	12400.00
0005432862459	28045	Economy	12400.00
0005432862465	28045	Economy	12400.00
0005432862461	28045	Economy	12400.00
0005432621216	28045	Economy	12400.00
0005432862460	28045	Economy	12400.00
0005432621215	28045	Economy	12400.00
0005432621209	28045	Economy	12400.00
0005432621213	28045	Economy	12400.00
0005432621182	28045	Economy	12400.00
0005432621122	28045	Economy	12400.00
0005432862462	28045	Economy	12400.00
0005432862464	28045	Economy	12400.00
0005432862463	28045	Economy	12400.00
0005434097495	11751	Economy	11300.00
0005434097491	11751	Economy	11300.00
0005434097492	11751	Economy	11300.00
0005434097499	13124	Economy	11300.00
0005433452783	31006	Economy	8400.00
0005433452781	31006	Economy	8400.00
0005433452784	31006	Economy	8400.00
0005433452782	31006	Economy	8400.00
0005433451661	31006	Economy	8400.00
0005433452761	31374	Economy	8400.00
0005433452760	31374	Economy	8400.00
0005433452769	31374	Economy	8400.00
0005433454899	31374	Economy	8400.00
0005433452770	31374	Economy	8400.00
0005433452767	31374	Economy	8400.00
0005433134206	12010	Economy	7200.00
0005434142670	12010	Economy	6600.00
0005433134195	12010	Economy	6600.00
0005434142650	12010	Economy	6600.00
0005433129323	12010	Economy	6600.00
0005434142669	12010	Economy	6600.00
0005434142658	12010	Economy	6600.00
0005434142636	12010	Economy	6600.00
0005433134197	12010	Economy	6600.00
0005434142659	12010	Economy	6600.00
0005433129324	12010	Economy	6600.00
0005433134190	12010	Economy	6600.00
0005433134196	12010	Economy	6600.00
0005433134189	12010	Economy	6600.00
0005433129345	12010	Economy	6600.00
0005434142653	12010	Economy	6600.00
0005433131803	29846	Economy	7200.00
0005433134233	29846	Economy	7200.00
0005434183623	29846	Economy	6600.00
0005434142687	29846	Economy	6600.00
0005434184707	29846	Economy	6600.00
0005433131800	29846	Economy	6600.00
0005434142689	29846	Economy	6600.00
0005433134234	29846	Economy	6600.00
0005433131805	29846	Economy	6600.00
0005433131804	29846	Economy	6600.00
0005434142688	29846	Economy	6600.00
0005433134231	29846	Economy	6600.00
0005433134230	29846	Economy	6600.00
0005434184708	29846	Economy	6600.00
0005433134232	29846	Economy	6600.00
0005434142690	29846	Economy	6600.00
0005434184706	29846	Economy	6600.00
0005434183621	29846	Economy	6600.00
0005433131801	29846	Economy	6600.00
0005433131802	29846	Economy	6600.00
0005434142691	29846	Economy	6600.00
0005434183622	29846	Economy	6600.00
0005435935078	16445	Economy	19900.00
0005435697888	16445	Economy	19900.00
0005435697896	16445	Economy	18100.00
0005435697884	16445	Economy	18100.00
0005435697878	16445	Economy	18100.00
0005435697882	16445	Economy	18100.00
0005435697892	16445	Economy	18100.00
0005435697890	16445	Economy	18100.00
0005435697879	16445	Economy	18100.00
0005435697893	16445	Economy	18100.00
0005435697881	16445	Economy	18100.00
0005435697899	16445	Economy	18100.00
0005435697906	16445	Economy	18100.00
0005435697902	16445	Economy	18100.00
0005435697880	16445	Economy	18100.00
0005435697895	16445	Economy	18100.00
0005435697891	16445	Economy	18100.00
0005435697897	16445	Economy	18100.00
0005435697903	16445	Economy	18100.00
0005435697889	16445	Economy	18100.00
0005435697886	16445	Economy	18100.00
0005435697887	16445	Economy	18100.00
0005435935079	16445	Economy	18100.00
0005435697904	16445	Economy	18100.00
0005435697885	16445	Economy	18100.00
0005435697907	16445	Economy	18100.00
0005435697905	16445	Economy	18100.00
0005435697898	16445	Economy	18100.00
0005435697894	16445	Economy	18100.00
0005435935076	16445	Economy	18100.00
0005435697883	16445	Economy	18100.00
0005435935074	16445	Economy	18100.00
0005435697900	16445	Economy	18100.00
0005435697901	16445	Economy	18100.00
0005435697666	24715	Economy	19900.00
0005435935106	24715	Economy	19900.00
0005435697632	24715	Economy	18100.00
0005435697696	24715	Economy	18100.00
0005435697592	24715	Economy	18100.00
0005435697759	24715	Economy	18100.00
0005435697513	24715	Economy	18100.00
0005435697714	24715	Economy	18100.00
0005435935108	24715	Economy	18100.00
0005435697697	24715	Economy	18100.00
0005435697699	24715	Economy	18100.00
0005435697615	24715	Economy	18100.00
0005435697700	24715	Economy	18100.00
0005435697602	24715	Economy	18100.00
0005435697758	24715	Economy	18100.00
0005435697512	24715	Economy	18100.00
0005435697760	24715	Economy	18100.00
0005435697713	24715	Economy	18100.00
0005435697648	24715	Economy	18100.00
0005435697667	24715	Economy	18100.00
0005435935107	24715	Economy	18100.00
0005435697753	24715	Economy	18100.00
0005435697550	24715	Economy	18100.00
0005435697728	24715	Economy	18100.00
0005435697790	24715	Economy	18100.00
0005435935109	24715	Economy	18100.00
0005435697605	24715	Economy	18100.00
0005433724898	18795	Economy	4400.00
0005433724894	18795	Economy	4400.00
0005433724897	18795	Economy	4400.00
0005433724896	18795	Economy	4400.00
0005433724895	18795	Economy	4400.00
0005433724832	21652	Economy	4400.00
0005432968889	21652	Economy	4400.00
0005433724879	21652	Economy	4400.00
0005433724878	21652	Economy	4400.00
0005433724854	21652	Economy	4400.00
0005432968890	21652	Economy	4400.00
0005433724877	21652	Economy	4400.00
0005433724875	21652	Economy	4400.00
0005434139815	7318	Business	23100.00
0005434139832	7318	Business	23100.00
0005434139809	7318	Business	23100.00
0005434139835	7318	Business	23100.00
0005434139781	7318	Business	23100.00
0005434139813	7318	Business	23100.00
0005434139792	7318	Business	23100.00
0005434139825	7318	Business	23100.00
0005434139843	7318	Business	23100.00
0005434139801	7318	Business	23100.00
0005434139848	7318	Business	23100.00
0005434139862	7318	Business	23100.00
0005434139807	7318	Economy	7700.00
0005434087614	7318	Economy	7700.00
0005434139818	7318	Economy	7700.00
0005434139852	7318	Economy	7700.00
0005434139777	7318	Economy	7700.00
0005434139820	7318	Economy	7700.00
0005434139845	7318	Economy	7700.00
0005434139863	7318	Economy	7700.00
0005434139834	7318	Economy	7700.00
0005434139814	7318	Economy	7700.00
0005434139838	7318	Economy	8500.00
0005434139816	7318	Economy	8500.00
0005434139778	7318	Economy	8500.00
0005434139856	7318	Economy	8500.00
0005434139841	7318	Economy	8500.00
0005434139803	7318	Economy	7700.00
0005434087615	7318	Economy	7700.00
0005434139780	7318	Economy	7700.00
0005434139782	7318	Economy	7700.00
0005434139800	7318	Economy	7700.00
0005434139812	7318	Economy	7700.00
0005434139798	7318	Economy	7700.00
0005434139855	7318	Economy	7700.00
0005434139823	7318	Economy	7700.00
0005434139775	7318	Economy	7700.00
0005434139785	7318	Economy	7700.00
0005434139854	7318	Economy	7700.00
0005434139791	7318	Economy	7700.00
0005434139860	7318	Economy	7700.00
0005434139830	7318	Economy	7700.00
0005434139842	7318	Economy	7700.00
0005434139846	7318	Economy	7700.00
0005434139850	7318	Economy	7700.00
0005434139790	7318	Economy	7700.00
0005434139847	7318	Economy	7700.00
0005434139797	7318	Economy	7700.00
0005434139806	7318	Economy	7700.00
0005434139810	7318	Economy	7700.00
0005434139861	7318	Economy	7700.00
0005434139864	7318	Economy	7700.00
0005434139779	7318	Economy	7700.00
0005434087612	7318	Economy	7700.00
0005434139858	7318	Economy	7700.00
0005434139849	7318	Economy	7700.00
0005434139786	7318	Economy	7700.00
0005434139821	7318	Economy	7700.00
0005434139805	7318	Economy	7700.00
0005434139819	7318	Economy	7700.00
0005434139776	7318	Economy	7700.00
0005434139828	7318	Economy	7700.00
0005434139833	7318	Economy	7700.00
0005434139853	7318	Economy	7700.00
0005434139859	7318	Economy	7700.00
0005434139804	7318	Economy	7700.00
0005434139788	7318	Economy	7700.00
0005434139793	7318	Economy	7700.00
0005434139796	7318	Economy	7700.00
0005434139839	7318	Economy	7700.00
0005434087617	7318	Economy	7700.00
0005434139822	7318	Economy	7700.00
0005434139827	7318	Economy	7700.00
0005434139817	7318	Economy	7700.00
0005434139802	7318	Economy	7700.00
0005434139844	7318	Economy	7700.00
0005434139857	7318	Economy	7700.00
0005434139826	7318	Economy	7700.00
0005434139840	7318	Economy	7700.00
0005434139808	7318	Economy	7700.00
0005434139837	7318	Economy	7700.00
0005434139795	7318	Economy	7700.00
0005434139799	7318	Economy	7700.00
0005434087616	7318	Economy	7700.00
0005434139831	7318	Economy	7700.00
0005434139811	7318	Economy	7700.00
0005434139836	7318	Economy	7700.00
0005434139787	7318	Economy	7700.00
0005434139851	7318	Economy	7700.00
0005434087613	7318	Economy	7700.00
0005434139824	7318	Economy	7700.00
0005434139794	7318	Economy	7700.00
0005434139783	7318	Economy	7700.00
0005434139789	7318	Economy	7700.00
0005434139829	7318	Economy	7700.00
0005434139784	7318	Economy	7700.00
0005434139178	28544	Business	23100.00
0005434139011	28544	Business	23100.00
0005434138723	28544	Business	23100.00
0005434139015	28544	Business	23100.00
0005434138943	28544	Business	23100.00
0005434138673	28544	Business	23100.00
0005434138962	28544	Business	23100.00
0005434087570	28544	Business	23100.00
0005434138927	28544	Business	23100.00
0005434138722	28544	Business	23100.00
0005434139205	28544	Business	23100.00
0005434139245	28544	Economy	7700.00
0005434139060	28544	Economy	7700.00
0005434138920	28544	Economy	7700.00
0005434138926	28544	Economy	7700.00
0005434138912	28544	Economy	7700.00
0005434087565	28544	Economy	7700.00
0005434087561	28544	Economy	7700.00
0005434138983	28544	Economy	7700.00
0005434139003	28544	Economy	7700.00
0005434139106	28544	Economy	8500.00
0005434139121	28544	Economy	8500.00
0005434138977	28544	Economy	8500.00
0005434139062	28544	Economy	8500.00
0005434139162	28544	Economy	8500.00
0005434139204	28544	Economy	7700.00
0005434138975	28544	Economy	7700.00
0005434139183	28544	Economy	7700.00
0005434138976	28544	Economy	7700.00
0005434139046	28544	Economy	7700.00
0005434138724	28544	Economy	7700.00
0005434139045	28544	Economy	7700.00
0005434139066	28544	Economy	7700.00
0005434138900	28544	Economy	7700.00
0005434138897	28544	Economy	7700.00
0005434138678	28544	Economy	7700.00
0005434139078	28544	Economy	7700.00
0005434139177	28544	Economy	7700.00
0005434138709	28544	Economy	7700.00
0005434087580	28544	Economy	7700.00
0005434139096	28544	Economy	7700.00
0005434139016	28544	Economy	7700.00
0005434139067	28544	Economy	7700.00
0005434139173	28544	Economy	7700.00
0005434139199	28544	Economy	7700.00
0005434139065	28544	Economy	7700.00
0005434138981	28544	Economy	7700.00
0005434139122	28544	Economy	7700.00
0005434139013	28544	Economy	7700.00
0005434139061	28544	Economy	7700.00
0005434139050	28544	Economy	7700.00
0005434138833	28544	Economy	7700.00
0005434139007	28544	Economy	7700.00
0005434139181	28544	Economy	7700.00
0005434139182	28544	Economy	7700.00
0005434139221	28544	Economy	7700.00
0005434139136	28544	Economy	7700.00
0005434138947	28544	Economy	7700.00
0005434138809	28544	Economy	7700.00
0005434139091	28544	Economy	7700.00
0005434087571	28544	Economy	7700.00
0005434139084	28544	Economy	7700.00
0005434139057	28544	Economy	7700.00
0005434138994	28544	Economy	7700.00
0005434139044	28544	Economy	7700.00
0005434138955	28544	Economy	7700.00
0005434139172	28544	Economy	7700.00
0005434139092	28544	Economy	7700.00
0005434139146	28544	Economy	7700.00
0005434138988	28544	Economy	7700.00
0005434138984	28544	Economy	7700.00
0005434139175	28544	Economy	7700.00
0005434139059	28544	Economy	7700.00
0005434139100	28544	Economy	7700.00
0005434139049	28544	Economy	7700.00
0005434138913	28544	Economy	7700.00
0005434139008	28544	Economy	7700.00
0005434139198	28544	Economy	7700.00
0005434139022	28544	Economy	7700.00
0005434087562	28544	Economy	7700.00
0005434139056	28544	Economy	7700.00
0005434138989	28544	Economy	7700.00
0005434139114	28544	Economy	7700.00
0005434139090	28544	Economy	7700.00
0005434139068	28544	Economy	7700.00
0005434138961	28544	Economy	7700.00
0005434139047	28544	Economy	7700.00
0005434139135	28544	Economy	7700.00
0005434139029	28544	Economy	7700.00
0005434139123	28544	Economy	7700.00
0005434139126	28544	Economy	7700.00
0005435808440	1947	Economy	23900.00
0005435808431	1947	Economy	23900.00
0005433407601	1947	Economy	21700.00
0005435808433	1947	Economy	21700.00
0005435808432	1947	Economy	21700.00
0005433407613	1947	Economy	21700.00
0005435808434	1947	Economy	21700.00
0005433407599	1947	Economy	21700.00
0005435808435	1947	Economy	21700.00
0005435808436	1947	Economy	21700.00
0005433407612	1947	Economy	21700.00
0005433407614	1947	Economy	21700.00
0005434610303	1947	Economy	21700.00
0005434610302	1947	Economy	21700.00
0005435808439	1947	Economy	21700.00
0005434610304	1947	Economy	21700.00
0005434610305	1947	Economy	21700.00
0005435808438	1947	Economy	21700.00
0005435808437	1947	Economy	21700.00
0005434610258	23081	Economy	21700.00
0005434610279	23081	Economy	21700.00
0005434610274	23081	Economy	21700.00
0005434610289	23081	Economy	21700.00
0005434504560	16680	Economy	7600.00
0005434504427	16680	Economy	7600.00
0005434504571	16680	Economy	6900.00
0005434504587	16680	Economy	6900.00
0005434504586	16680	Economy	6900.00
0005434504531	16680	Economy	6900.00
0005434504554	16680	Economy	6900.00
0005434504694	16680	Economy	6900.00
0005434504593	16680	Economy	6900.00
0005434504682	16680	Economy	6900.00
0005434504681	16680	Economy	6900.00
0005434504559	16680	Economy	6900.00
0005434504469	16680	Economy	6900.00
0005434504475	16680	Economy	6900.00
0005434504604	16680	Economy	6900.00
0005434504647	16680	Economy	6900.00
0005434504616	16680	Economy	6900.00
0005434504717	16680	Economy	6900.00
0005434504530	16680	Economy	6900.00
0005434504688	16680	Economy	6900.00
0005434504592	16680	Economy	6900.00
0005434504626	16680	Economy	6900.00
0005434504572	16680	Economy	6900.00
0005434504483	16680	Economy	6900.00
0005434504597	16680	Economy	6900.00
0005434504555	16680	Economy	6900.00
0005434504648	16680	Economy	6900.00
0005434504759	16680	Economy	6900.00
0005434504608	16680	Economy	6900.00
0005434504716	16680	Economy	6900.00
0005434504625	16680	Economy	6900.00
0005434504476	16680	Economy	6900.00
0005434504549	16680	Economy	6900.00
0005434504470	16680	Economy	6900.00
0005434504755	16680	Economy	6900.00
0005434504598	16680	Economy	6900.00
0005434504655	16680	Economy	6900.00
0005434504479	16680	Economy	6900.00
0005434504656	16680	Economy	6900.00
0005434504570	16680	Economy	6900.00
0005434504925	22919	Economy	7600.00
0005434504926	22919	Economy	7600.00
0005434504922	22919	Economy	7600.00
0005434504911	22919	Economy	6900.00
0005434504943	22919	Economy	6900.00
0005434504908	22919	Economy	6900.00
0005434504932	22919	Economy	6900.00
0005434504913	22919	Economy	6900.00
0005434504931	22919	Economy	6900.00
0005434504941	22919	Economy	6900.00
0005434504929	22919	Economy	6900.00
0005434504934	22919	Economy	6900.00
0005434504946	22919	Economy	6900.00
0005434504921	22919	Economy	6900.00
0005434504914	22919	Economy	6900.00
0005434504933	22919	Economy	6900.00
0005434504916	22919	Economy	6900.00
0005434504947	22919	Economy	6900.00
0005434504910	22919	Economy	6900.00
0005434504915	22919	Economy	6900.00
0005434504918	22919	Economy	6900.00
0005434504945	22919	Economy	6900.00
0005434504936	22919	Economy	6900.00
0005434504937	22919	Economy	6900.00
0005434504919	22919	Economy	6900.00
0005434504939	22919	Economy	6900.00
0005434504942	22919	Economy	6900.00
0005434504930	22919	Economy	6900.00
0005434504938	22919	Economy	6900.00
0005434504912	22919	Economy	6900.00
0005434504927	22919	Economy	6900.00
0005434504909	22919	Economy	6900.00
0005434504917	22919	Economy	6900.00
0005434504940	22919	Economy	6900.00
0005434504935	22919	Economy	6900.00
0005434504923	22919	Economy	6900.00
0005434504920	22919	Economy	6900.00
0005434504944	22919	Economy	6900.00
0005434504928	22919	Economy	6900.00
0005434504948	22919	Economy	6900.00
0005434504924	22919	Economy	6900.00
0005433266830	2197	Economy	7700.00
0005433266832	2197	Economy	7700.00
0005433266860	2197	Economy	7700.00
0005435078668	2197	Economy	7000.00
0005435078655	2197	Economy	7000.00
0005435078664	2197	Economy	7000.00
0005435078665	2197	Economy	7000.00
0005433266824	2197	Economy	7000.00
0005435078662	2197	Economy	7000.00
0005435078658	2197	Economy	7000.00
0005435078660	2197	Economy	7000.00
0005435078663	2197	Economy	7000.00
0005435078654	2197	Economy	7000.00
0005435078666	2197	Economy	7000.00
0005433266853	2197	Economy	7000.00
0005433266798	2197	Economy	7000.00
0005435078657	2197	Economy	7000.00
0005435078653	2197	Economy	7000.00
0005433266806	2197	Economy	7000.00
0005433266861	2197	Economy	7000.00
0005433266809	2197	Economy	7000.00
0005433266827	2197	Economy	7000.00
0005433266799	2197	Economy	7000.00
0005435078656	2197	Economy	7000.00
0005433266805	2197	Economy	7000.00
0005433266786	2197	Economy	7000.00
0005435078659	2197	Economy	7000.00
0005435078667	2197	Economy	7000.00
0005435078661	2197	Economy	7000.00
0005435078526	24334	Economy	7700.00
0005433266913	24334	Economy	7700.00
0005435078533	24334	Economy	7700.00
0005435078489	24334	Economy	7000.00
0005435078515	24334	Economy	7000.00
0005433266912	24334	Economy	7000.00
0005435078536	24334	Economy	7000.00
0005433266914	24334	Economy	7000.00
0005433266918	24334	Economy	7000.00
0005435078543	24334	Economy	7000.00
0005435078488	24334	Economy	7000.00
0005433266911	24334	Economy	7000.00
0005435078520	24334	Economy	7000.00
0005435078518	24334	Economy	7000.00
0005435078549	24334	Economy	7000.00
0005435078521	24334	Economy	7000.00
0005435078517	24334	Economy	7000.00
0005435078528	24334	Economy	7000.00
0005433266915	24334	Economy	7000.00
0005433266910	24334	Economy	7000.00
0005435078547	24334	Economy	7000.00
0005435078514	24334	Economy	7000.00
0005433266917	24334	Economy	7000.00
0005435078466	24334	Economy	7000.00
0005435078532	24334	Economy	7000.00
0005433266916	24334	Economy	7000.00
0005435078546	24334	Economy	7000.00
0005435078513	24334	Economy	7000.00
0005435078601	24334	Economy	7000.00
0005434988961	6611	Economy	10800.00
0005434988955	6611	Economy	10800.00
0005434988957	6611	Economy	9800.00
0005435803320	6611	Economy	9800.00
0005434988962	6611	Economy	9800.00
0005434988954	6611	Economy	9800.00
0005434988959	6611	Economy	9800.00
0005434988958	6611	Economy	9800.00
0005434988956	6611	Economy	9800.00
0005435803322	6611	Economy	9800.00
0005435803321	6611	Economy	9800.00
0005434988953	6611	Economy	9800.00
0005434988952	6611	Economy	9800.00
0005434988960	6611	Economy	9800.00
0005434988950	6611	Economy	9800.00
0005434988951	6611	Economy	9800.00
0005434988834	23618	Economy	10800.00
0005434988838	23618	Economy	9800.00
0005435803295	23618	Economy	9800.00
0005435464549	23618	Economy	9800.00
0005434988819	23618	Economy	9800.00
0005434988831	23618	Economy	9800.00
0005435803311	23618	Economy	9800.00
0005435803300	23618	Economy	9800.00
0005434988841	23618	Economy	9800.00
0005434988843	23618	Economy	9800.00
0005434988804	23618	Economy	9800.00
0005435803287	23618	Economy	9800.00
0005435803290	23618	Economy	9800.00
0005434988818	23618	Economy	9800.00
0005434988833	23618	Economy	9800.00
0005434988840	23618	Economy	9800.00
0005435803289	23618	Economy	9800.00
0005435803288	23618	Economy	9800.00
0005435464548	23618	Economy	9800.00
0005432383965	30477	Business	9900.00
0005433453801	30477	Business	9900.00
0005433450424	30477	Business	9900.00
0005433450419	30477	Business	9900.00
0005432383994	30477	Business	9900.00
0005433450420	30477	Business	9900.00
0005432383976	30477	Business	9900.00
0005432383967	30477	Business	9900.00
0005432383988	30477	Economy	3300.00
0005432383964	30477	Economy	3300.00
0005432383968	30477	Economy	3300.00
0005433450429	30477	Economy	3300.00
0005433450407	30477	Economy	3300.00
0005433450426	30477	Economy	3300.00
0005433450408	30477	Economy	3300.00
0005432383990	30477	Economy	3300.00
0005432383960	30477	Economy	3600.00
0005433450415	30477	Economy	3600.00
0005433450417	30477	Economy	3600.00
0005432383959	30477	Economy	3600.00
0005432383958	30477	Economy	3300.00
0005433453803	30477	Economy	3300.00
0005432383995	30477	Economy	3300.00
0005432383961	30477	Economy	3300.00
0005432383972	30477	Economy	3300.00
0005432383977	30477	Economy	3300.00
0005432383981	30477	Economy	3300.00
0005432383962	30477	Economy	3300.00
0005432383987	30477	Economy	3300.00
0005432383974	30477	Economy	3300.00
0005432383969	30477	Economy	3300.00
0005433450413	30477	Economy	3300.00
0005432383978	30477	Economy	3300.00
0005432383982	30477	Economy	3300.00
0005433450422	30477	Economy	3300.00
0005433450409	30477	Economy	3300.00
0005432383970	30477	Economy	3300.00
0005433450425	30477	Economy	3300.00
0005433454918	30477	Economy	3300.00
0005432383991	30477	Economy	3300.00
0005432383971	30477	Economy	3300.00
0005433450410	30477	Economy	3300.00
0005432383985	30477	Economy	3300.00
0005433450412	30477	Economy	3300.00
0005433453802	30477	Economy	3300.00
0005432383992	30477	Economy	3300.00
0005432383963	30477	Economy	3300.00
0005432383984	30477	Economy	3300.00
0005432383979	30477	Economy	3300.00
0005432383993	30477	Economy	3300.00
0005433450427	30477	Economy	3300.00
0005433454919	30477	Economy	3300.00
0005432383956	30477	Economy	3300.00
0005432383973	30477	Economy	3300.00
0005432383983	30477	Economy	3300.00
0005433450414	30477	Economy	3300.00
0005433450423	30477	Economy	3300.00
0005432383975	30477	Economy	3300.00
0005433454920	30477	Economy	3300.00
0005432383989	30477	Economy	3300.00
0005433450421	30477	Economy	3300.00
0005432383986	30477	Economy	3300.00
0005432383966	30477	Economy	3300.00
0005433450430	30477	Economy	3300.00
0005433450418	30477	Economy	3300.00
0005433450411	30477	Economy	3300.00
0005432383957	30477	Economy	3300.00
0005433450428	30477	Economy	3300.00
0005432383980	30477	Economy	3300.00
0005433450416	30477	Economy	3300.00
0005433450294	31293	Business	9900.00
0005433450260	31293	Business	9900.00
0005433450203	31293	Business	9900.00
0005432383540	31293	Business	9900.00
0005433450186	31293	Business	9900.00
0005433450198	31293	Business	9900.00
0005432383532	31293	Business	9900.00
0005432383581	31293	Business	9900.00
0005432383504	31293	Business	9900.00
0005432383676	31293	Business	9900.00
0005432383429	31293	Economy	3300.00
0005433450174	31293	Economy	3300.00
0005432383574	31293	Economy	3300.00
0005432383756	31293	Economy	3300.00
0005432383521	31293	Economy	3300.00
0005433450128	31293	Economy	3300.00
0005432383425	31293	Economy	3300.00
0005432383459	31293	Economy	3300.00
0005432383621	31293	Economy	3300.00
0005432383602	31293	Economy	3600.00
0005432383473	31293	Economy	3600.00
0005433450143	31293	Economy	3600.00
0005433450192	31293	Economy	3600.00
0005433450293	31293	Economy	3600.00
0005432383596	31293	Economy	3300.00
0005432383582	31293	Economy	3300.00
0005432383625	31293	Economy	3300.00
0005433450308	31293	Economy	3300.00
0005432383637	31293	Economy	3300.00
0005433450251	31293	Economy	3300.00
0005432383649	31293	Economy	3300.00
0005432383755	31293	Economy	3300.00
0005432383608	31293	Economy	3300.00
0005433450270	31293	Economy	3300.00
0005433450112	31293	Economy	3300.00
0005433450263	31293	Economy	3300.00
0005433450269	31293	Economy	3300.00
0005432383587	31293	Economy	3300.00
0005433453778	31293	Economy	3300.00
0005433450197	31293	Economy	3300.00
0005433450194	31293	Economy	3300.00
0005433450312	31293	Economy	3300.00
0005432383350	31293	Economy	3300.00
0005432383450	31293	Economy	3300.00
0005432383619	31293	Economy	3300.00
0005433450235	31293	Economy	3300.00
0005433450266	31293	Economy	3300.00
0005432383530	31293	Economy	3300.00
0005432383639	31293	Economy	3300.00
0005432383513	31293	Economy	3300.00
0005433450241	31293	Economy	3300.00
0005432383529	31293	Economy	3300.00
0005432383586	31293	Economy	3300.00
0005432383590	31293	Economy	3300.00
0005433450218	31293	Economy	3300.00
0005432383531	31293	Economy	3300.00
0005432383544	31293	Economy	3300.00
0005433450142	31293	Economy	3300.00
0005432383492	31293	Economy	3300.00
0005433450313	31293	Economy	3300.00
0005432383515	31293	Economy	3300.00
0005433451637	31293	Economy	3300.00
0005432383512	31293	Economy	3300.00
0005432383754	31293	Economy	3300.00
0005432383442	31293	Economy	3300.00
0005433450188	31293	Economy	3300.00
0005433450256	31293	Economy	3300.00
0005432383640	31293	Economy	3300.00
0005432383561	31293	Economy	3300.00
0005433450309	31293	Economy	3300.00
0005432383518	31293	Economy	3300.00
0005432383493	31293	Economy	3300.00
0005433450173	31293	Economy	3300.00
0005433450271	31293	Economy	3300.00
0005432383665	31293	Economy	3300.00
0005432383603	31293	Economy	3300.00
0005433450129	31293	Economy	3300.00
0005433450187	31293	Economy	3300.00
0005432383458	31293	Economy	3300.00
0005435548530	20812	Economy	26200.00
0005435548555	20812	Economy	26200.00
0005433788293	20812	Economy	23800.00
0005435548518	20812	Economy	23800.00
0005433788277	20812	Economy	23800.00
0005433788279	20812	Economy	23800.00
0005433788280	20812	Economy	23800.00
0005433788285	20812	Economy	23800.00
0005435548556	20812	Economy	23800.00
0005433788292	20812	Economy	23800.00
0005435548535	20812	Economy	23800.00
0005433788281	20812	Economy	23800.00
0005435548533	20812	Economy	23800.00
0005435548515	20812	Economy	23800.00
0005433788288	20812	Economy	23800.00
0005435548520	20812	Economy	23800.00
0005435548514	20812	Economy	23800.00
0005435548519	20812	Economy	23800.00
0005435548529	20812	Economy	23800.00
0005435548536	20812	Economy	23800.00
0005433788278	20812	Economy	23800.00
0005433788286	20812	Economy	23800.00
0005435548517	20812	Economy	23800.00
0005433788287	20812	Economy	23800.00
0005435548561	20812	Economy	23800.00
0005433788284	20812	Economy	23800.00
0005433788282	20812	Economy	23800.00
0005435548521	20812	Economy	23800.00
0005435548516	20812	Economy	23800.00
0005433788290	20812	Economy	23800.00
0005435548534	20812	Economy	23800.00
0005433788283	20812	Economy	23800.00
0005433788289	20812	Economy	23800.00
0005433788291	20812	Economy	23800.00
0005435548537	20812	Economy	23800.00
0005435548580	26480	Economy	26200.00
0005433788238	26480	Economy	26200.00
0005433788258	26480	Economy	26200.00
0005433788242	26480	Economy	23800.00
0005435548590	26480	Economy	23800.00
0005433788245	26480	Economy	23800.00
0005433788239	26480	Economy	23800.00
0005433788241	26480	Economy	23800.00
0005433788259	26480	Economy	23800.00
0005435548582	26480	Economy	23800.00
0005433788262	26480	Economy	23800.00
0005435548586	26480	Economy	23800.00
0005433788263	26480	Economy	23800.00
0005433788235	26480	Economy	23800.00
0005433788237	26480	Economy	23800.00
0005435548589	26480	Economy	23800.00
0005435548585	26480	Economy	23800.00
0005435548592	26480	Economy	23800.00
0005433788253	26480	Economy	23800.00
0005435548584	26480	Economy	23800.00
0005435548587	26480	Economy	23800.00
0005433788252	26480	Economy	23800.00
0005435548591	26480	Economy	23800.00
0005435548583	26480	Economy	23800.00
0005435548581	26480	Economy	23800.00
0005435548588	26480	Economy	23800.00
0005435299825	10780	Economy	17100.00
0005435299844	10780	Economy	17100.00
0005433131768	10780	Economy	17100.00
0005435299817	10780	Economy	15600.00
0005433131729	10780	Economy	15600.00
0005435304216	10780	Economy	15600.00
0005433126888	10780	Economy	15600.00
0005435299845	10780	Economy	15600.00
0005433126864	10780	Economy	15600.00
0005433126866	10780	Economy	15600.00
0005435304218	10780	Economy	15600.00
0005435304184	10780	Economy	15600.00
0005435304190	10780	Economy	15600.00
0005435299851	10780	Economy	15600.00
0005433126892	10780	Economy	15600.00
0005435304215	10780	Economy	15600.00
0005433126899	10780	Economy	15600.00
0005433131769	10780	Economy	15600.00
0005433131749	10780	Economy	15600.00
0005435299843	10780	Economy	15600.00
0005435304222	10780	Economy	15600.00
0005435299823	10780	Economy	15600.00
0005433126886	10780	Economy	15600.00
0005435304219	10780	Economy	15600.00
0005435299824	10780	Economy	15600.00
0005433129375	29697	Economy	15600.00
0005435299877	29697	Economy	15600.00
0005435302301	29697	Economy	15600.00
0005433126944	29697	Economy	15600.00
0005433129376	29697	Economy	15600.00
0005433129374	29697	Economy	15600.00
0005433126941	29697	Economy	15600.00
0005435299879	29697	Economy	15600.00
0005435302299	29697	Economy	15600.00
0005433126942	29697	Economy	15600.00
0005435302300	29697	Economy	15600.00
0005435299878	29697	Economy	15600.00
0005435302298	29697	Economy	15600.00
0005435299880	29697	Economy	15600.00
0005433129373	29697	Economy	15600.00
0005433129372	29697	Economy	15600.00
0005433126943	29697	Economy	15600.00
0005435299876	29697	Economy	15600.00
0005435302302	29697	Economy	15600.00
0005433126945	29697	Economy	15600.00
0005434287736	2409	Economy	17200.00
0005434287739	2409	Economy	15700.00
0005434287750	2409	Economy	15700.00
0005434287744	2409	Economy	15700.00
0005434287756	2409	Economy	15700.00
0005432264526	2409	Economy	15700.00
0005433110228	2409	Economy	15700.00
0005434287738	2409	Economy	15700.00
0005432264525	2409	Economy	15700.00
0005433110134	2409	Economy	15700.00
0005434287746	2409	Economy	15700.00
0005434287755	2409	Economy	15700.00
0005434287749	2409	Economy	15700.00
0005433110133	2409	Economy	15700.00
0005434287745	2409	Economy	15700.00
0005434287752	2409	Economy	15700.00
0005434287743	2409	Economy	15700.00
0005433110170	2409	Economy	15700.00
0005434287734	2409	Economy	15700.00
0005434287754	2409	Economy	15700.00
0005434287751	2409	Economy	15700.00
0005434287748	2409	Economy	15700.00
0005434287740	2409	Economy	15700.00
0005433110217	2409	Economy	15700.00
0005434287735	2409	Economy	15700.00
0005434287742	2409	Economy	15700.00
0005433110227	2409	Economy	15700.00
0005434287737	2409	Economy	15700.00
0005434287741	2409	Economy	15700.00
0005434287747	2409	Economy	15700.00
0005434287753	2409	Economy	15700.00
0005433110189	2409	Economy	15700.00
0005434287585	26832	Economy	17200.00
0005434287533	26832	Economy	15700.00
0005433110299	26832	Economy	15700.00
0005434287538	26832	Economy	15700.00
0005434287491	26832	Economy	15700.00
0005434287554	26832	Economy	15700.00
0005434287639	26832	Economy	15700.00
0005434287527	26832	Economy	15700.00
0005433110300	26832	Economy	15700.00
0005433110298	26832	Economy	15700.00
0005433110303	26832	Economy	15700.00
0005434287609	26832	Economy	15700.00
0005434287589	26832	Economy	15700.00
0005433110302	26832	Economy	15700.00
0005433110307	26832	Economy	15700.00
0005434287534	26832	Economy	15700.00
0005434287628	26832	Economy	15700.00
0005433110306	26832	Economy	15700.00
0005434287523	26832	Economy	15700.00
0005434287546	26832	Economy	15700.00
0005434287517	26832	Economy	15700.00
0005434287594	26832	Economy	15700.00
0005434287553	26832	Economy	15700.00
0005433110305	26832	Economy	15700.00
0005434287584	26832	Economy	15700.00
0005434287627	26832	Economy	15700.00
0005434287576	26832	Economy	15700.00
0005434287516	26832	Economy	15700.00
0005434287600	26832	Economy	15700.00
0005434287537	26832	Economy	15700.00
0005434287555	26832	Economy	15700.00
0005433110301	26832	Economy	15700.00
0005434287556	26832	Economy	15700.00
0005433110297	26832	Economy	15700.00
0005433110304	26832	Economy	15700.00
0005435856291	25503	Economy	22800.00
0005435856293	25503	Economy	22800.00
0005435856332	25503	Economy	22800.00
0005435856292	25503	Economy	22800.00
0005435856290	25503	Economy	22800.00
0005435856289	25503	Economy	22800.00
0005435856227	26619	Economy	22800.00
0005435856228	26619	Economy	22800.00
0005435856226	26619	Economy	22800.00
0005435856233	26619	Economy	22800.00
0005435856249	26619	Economy	22800.00
0005435856237	26619	Economy	22800.00
0005435856234	26619	Economy	22800.00
0005435314875	6103	Economy	24600.00
0005435314874	6103	Economy	24600.00
0005434520442	6103	Economy	24600.00
0005434520444	6103	Economy	22300.00
0005434520436	6103	Economy	22300.00
0005434520430	6103	Economy	22300.00
0005434520434	6103	Economy	22300.00
0005435314879	6103	Economy	22300.00
0005435314878	6103	Economy	22300.00
0005434520440	6103	Economy	22300.00
0005435314833	6103	Economy	22300.00
0005435314860	6103	Economy	22300.00
0005435314862	6103	Economy	22300.00
0005434520426	6103	Economy	22300.00
0005434520443	6103	Economy	22300.00
0005435314883	6103	Economy	22300.00
0005434520437	6103	Economy	22300.00
0005435314854	6103	Economy	22300.00
0005434520431	6103	Economy	22300.00
0005435314877	6103	Economy	22300.00
0005435314876	6103	Economy	22300.00
0005434520433	6103	Economy	22300.00
0005434520432	6103	Economy	22300.00
0005434520438	6103	Economy	22300.00
0005434520447	6103	Economy	22300.00
0005434520446	6103	Economy	22300.00
0005434520439	6103	Economy	22300.00
0005435314861	6103	Economy	22300.00
0005434520445	6103	Economy	22300.00
0005434520435	6103	Economy	22300.00
0005435314856	6103	Economy	22300.00
0005434520423	6103	Economy	22300.00
0005434520424	6103	Economy	22300.00
0005435314855	6103	Economy	22300.00
0005434520427	6103	Economy	22300.00
0005434520428	6103	Economy	22300.00
0005434520425	6103	Economy	22300.00
0005434520429	6103	Economy	22300.00
0005434520441	6103	Economy	22300.00
0005435263707	7157	Business	89800.00
0005433650942	7157	Business	89800.00
0005433650959	7157	Business	89800.00
0005433650914	7157	Business	89800.00
0005435263688	7157	Business	89800.00
0005433650968	7157	Business	89800.00
0005433650964	7157	Business	89800.00
0005433650950	7157	Business	89800.00
0005433650952	7157	Business	89800.00
0005433650946	7157	Business	89800.00
0005433650956	7157	Business	89800.00
0005433650923	7157	Economy	29900.00
0005435263681	7157	Economy	29900.00
0005433650927	7157	Economy	29900.00
0005433650972	7157	Economy	29900.00
0005433650937	7157	Economy	29900.00
0005435263679	7157	Economy	29900.00
0005433650926	7157	Economy	29900.00
0005433650962	7157	Economy	29900.00
0005433650974	7157	Economy	29900.00
0005433650933	7157	Economy	32900.00
0005433650930	7157	Economy	32900.00
0005435263680	7157	Economy	32900.00
0005435263690	7157	Economy	32900.00
0005433650977	7157	Economy	32900.00
0005435263718	7157	Economy	29900.00
0005433650929	7157	Economy	29900.00
0005433650948	7157	Economy	29900.00
0005433650957	7157	Economy	29900.00
0005435263717	7157	Economy	29900.00
0005433650925	7157	Economy	29900.00
0005433650976	7157	Economy	29900.00
0005433650960	7157	Economy	29900.00
0005435263668	7157	Economy	29900.00
0005435263693	7157	Economy	29900.00
0005433650921	7157	Economy	29900.00
0005435263703	7157	Economy	29900.00
0005433650953	7157	Economy	29900.00
0005433650973	7157	Economy	29900.00
0005433650924	7157	Economy	29900.00
0005433650967	7157	Economy	29900.00
0005435263723	7157	Economy	29900.00
0005433650919	7157	Economy	29900.00
0005433650963	7157	Economy	29900.00
0005433650938	7157	Economy	29900.00
0005433650934	7157	Economy	29900.00
0005433650966	7157	Economy	29900.00
0005433650936	7157	Economy	29900.00
0005435263715	7157	Economy	29900.00
0005433650940	7157	Economy	29900.00
0005433650939	7157	Economy	29900.00
0005433650975	7157	Economy	29900.00
0005433650970	7157	Economy	29900.00
0005433650913	7157	Economy	29900.00
0005433650932	7157	Economy	29900.00
0005433650971	7157	Economy	29900.00
0005433650928	7157	Economy	29900.00
0005435263720	7157	Economy	29900.00
0005435263721	7157	Economy	29900.00
0005433650935	7157	Economy	29900.00
0005433650920	7157	Economy	29900.00
0005433650941	7157	Economy	29900.00
0005433650918	7157	Economy	29900.00
0005433650922	7157	Economy	29900.00
0005433650958	7157	Economy	29900.00
0005433650944	7157	Economy	29900.00
0005433650917	7157	Economy	29900.00
0005433650916	7157	Economy	29900.00
0005433650949	7157	Economy	29900.00
0005433650951	7157	Economy	29900.00
0005433650931	7157	Economy	29900.00
0005433650969	7157	Economy	29900.00
0005433650965	7157	Economy	29900.00
0005435263691	7157	Economy	29900.00
0005433650945	7157	Economy	29900.00
0005435263678	7157	Economy	29900.00
0005435263716	7157	Economy	29900.00
0005433650915	7157	Economy	29900.00
0005435263719	7157	Economy	29900.00
0005435263702	7157	Economy	29900.00
0005433650947	7157	Economy	29900.00
0005433650955	7157	Economy	29900.00
0005435263714	7157	Economy	29900.00
0005433650961	7157	Economy	29900.00
0005433650954	7157	Economy	29900.00
0005433650943	7157	Economy	29900.00
0005433650864	27632	Business	89800.00
0005433650781	27632	Business	89800.00
0005433650824	27632	Business	89800.00
0005433650790	27632	Business	89800.00
0005435263755	27632	Business	89800.00
0005433650694	27632	Business	89800.00
0005435263764	27632	Business	89800.00
0005433650795	27632	Business	89800.00
0005435263758	27632	Business	89800.00
0005433650773	27632	Economy	29900.00
0005435263765	27632	Economy	29900.00
0005433650794	27632	Economy	29900.00
0005433650793	27632	Economy	29900.00
0005433650752	27632	Economy	29900.00
0005433650704	27632	Economy	29900.00
0005435263760	27632	Economy	29900.00
0005435263763	27632	Economy	29900.00
0005435263770	27632	Economy	29900.00
0005433650810	27632	Economy	32900.00
0005433650808	27632	Economy	32900.00
0005433650817	27632	Economy	32900.00
0005433650856	27632	Economy	29900.00
0005433650761	27632	Economy	29900.00
0005433650753	27632	Economy	29900.00
0005433650848	27632	Economy	29900.00
0005433650703	27632	Economy	29900.00
0005435263767	27632	Economy	29900.00
0005433650861	27632	Economy	29900.00
0005433650836	27632	Economy	29900.00
0005433650816	27632	Economy	29900.00
0005435263754	27632	Economy	29900.00
0005433650776	27632	Economy	29900.00
0005433650754	27632	Economy	29900.00
0005435263762	27632	Economy	29900.00
0005433650775	27632	Economy	29900.00
0005433650789	27632	Economy	29900.00
0005433650792	27632	Economy	29900.00
0005433650909	27632	Economy	29900.00
0005435263756	27632	Economy	29900.00
0005433650811	27632	Economy	29900.00
0005433650845	27632	Economy	29900.00
0005433650796	27632	Economy	29900.00
0005435263771	27632	Economy	29900.00
0005433650855	27632	Economy	29900.00
0005433650852	27632	Economy	29900.00
0005433650759	27632	Economy	29900.00
0005433650843	27632	Economy	29900.00
0005435263757	27632	Economy	29900.00
0005433650818	27632	Economy	29900.00
0005433650859	27632	Economy	29900.00
0005435263759	27632	Economy	29900.00
0005435263761	27632	Economy	29900.00
0005433650839	27632	Economy	29900.00
0005433650760	27632	Economy	29900.00
0005433650779	27632	Economy	29900.00
0005433650693	27632	Economy	29900.00
0005433650780	27632	Economy	29900.00
0005433650863	27632	Economy	29900.00
0005435263768	27632	Economy	29900.00
0005433650853	27632	Economy	29900.00
0005435263766	27632	Economy	29900.00
0005433650883	27632	Economy	29900.00
0005435263769	27632	Economy	29900.00
0005433650841	27632	Economy	29900.00
0005433650787	27632	Economy	29900.00
0005433650800	27632	Economy	29900.00
0005433869274	4785	Economy	19400.00
0005433869270	4785	Economy	19400.00
0005433869266	4785	Economy	19400.00
0005433869279	4785	Economy	19400.00
0005433869267	4785	Economy	17600.00
0005435860516	4785	Economy	17600.00
0005433869269	4785	Economy	17600.00
0005433869250	4785	Economy	17600.00
0005433869251	4785	Economy	17600.00
0005433869261	4785	Economy	17600.00
0005433869276	4785	Economy	17600.00
0005433869280	4785	Economy	17600.00
0005433869278	4785	Economy	17600.00
0005433869246	4785	Economy	17600.00
0005433869268	4785	Economy	17600.00
0005433869252	4785	Economy	17600.00
0005433869262	4785	Economy	17600.00
0005435860523	4785	Economy	17600.00
0005433869260	4785	Economy	17600.00
0005433869248	4785	Economy	17600.00
0005433869275	4785	Economy	17600.00
0005433869263	4785	Economy	17600.00
0005433869247	4785	Economy	17600.00
0005433869244	4785	Economy	17600.00
0005433869277	4785	Economy	17600.00
0005433869249	4785	Economy	17600.00
0005433869243	4785	Economy	17600.00
0005435860517	4785	Economy	17600.00
0005433869257	4785	Economy	17600.00
0005433869242	4785	Economy	17600.00
0005433869256	4785	Economy	17600.00
0005435860522	4785	Economy	17600.00
0005433869265	4785	Economy	17600.00
0005433869255	4785	Economy	17600.00
0005433869241	4785	Economy	17600.00
0005433869264	4785	Economy	17600.00
0005435860521	4785	Economy	17600.00
0005433869254	4785	Economy	17600.00
0005433869281	4785	Economy	17600.00
0005433869258	4785	Economy	17600.00
0005433869271	4785	Economy	17600.00
0005433869245	4785	Economy	17600.00
0005433869253	4785	Economy	17600.00
0005433869272	4785	Economy	17600.00
0005433869259	4785	Economy	17600.00
0005433869273	4785	Economy	17600.00
0005433868785	32623	Economy	19400.00
0005433868753	32623	Economy	19400.00
0005433868989	32623	Economy	19400.00
0005435860573	32623	Economy	19400.00
0005433868969	32623	Economy	17600.00
0005433868808	32623	Economy	17600.00
0005433868951	32623	Economy	17600.00
0005433868576	32623	Economy	17600.00
0005433868858	32623	Economy	17600.00
0005433868755	32623	Economy	17600.00
0005433868840	32623	Economy	17600.00
0005433868933	32623	Economy	17600.00
0005433868719	32623	Economy	17600.00
0005433868949	32623	Economy	17600.00
0005433868809	32623	Economy	17600.00
0005435860575	32623	Economy	17600.00
0005433868577	32623	Economy	17600.00
0005433868921	32623	Economy	17600.00
0005433868977	32623	Economy	17600.00
0005433868855	32623	Economy	17600.00
0005433868920	32623	Economy	17600.00
0005433868947	32623	Economy	17600.00
0005433868922	32623	Economy	17600.00
0005433868788	32623	Economy	17600.00
0005433868882	32623	Economy	17600.00
0005433868892	32623	Economy	17600.00
0005433868945	32623	Economy	17600.00
0005433868705	32623	Economy	17600.00
0005433868837	32623	Economy	17600.00
0005433868968	32623	Economy	17600.00
0005433868773	32623	Economy	17600.00
0005433868894	32623	Economy	17600.00
0005433868541	32623	Economy	17600.00
0005433868982	32623	Economy	17600.00
0005433868839	32623	Economy	17600.00
0005433868876	32623	Economy	17600.00
0005433868696	32623	Economy	17600.00
0005433868759	32623	Economy	17600.00
0005433868976	32623	Economy	17600.00
0005433868859	32623	Economy	17600.00
0005435860574	32623	Economy	17600.00
0005433868908	32623	Economy	17600.00
0005433868893	32623	Economy	17600.00
0005433868903	32623	Economy	17600.00
0005433868754	32623	Economy	17600.00
0005433868704	32623	Economy	17600.00
0005433868950	32623	Economy	17600.00
0005433868733	32623	Economy	17600.00
0005433868786	32623	Economy	17600.00
0005433868900	32623	Economy	17600.00
0005434663681	3419	Economy	24800.00
0005434461691	3419	Economy	24800.00
0005434460551	3419	Economy	24800.00
0005434663682	3419	Economy	24800.00
0005435911540	3419	Economy	22600.00
0005435911538	3419	Economy	22600.00
0005435911541	3419	Economy	22600.00
0005434460550	3419	Economy	22600.00
0005435911523	3419	Economy	22600.00
0005435911536	3419	Economy	22600.00
0005434663687	3419	Economy	22600.00
0005435911535	3419	Economy	22600.00
0005434663689	3419	Economy	22600.00
0005434663684	3419	Economy	22600.00
0005434663694	3419	Economy	22600.00
0005434663692	3419	Economy	22600.00
0005434663686	3419	Economy	22600.00
0005434663688	3419	Economy	22600.00
0005435911522	3419	Economy	22600.00
0005435911537	3419	Economy	22600.00
0005435911520	3419	Economy	22600.00
0005434460552	3419	Economy	22600.00
0005434663691	3419	Economy	22600.00
0005435911569	3419	Economy	22600.00
0005435911568	3419	Economy	22600.00
0005434663685	3419	Economy	22600.00
0005434461690	3419	Economy	22600.00
0005434663683	3419	Economy	22600.00
0005435911531	3419	Economy	22600.00
0005434663690	3419	Economy	22600.00
0005434663693	3419	Economy	22600.00
0005435911539	3419	Economy	22600.00
0005434461692	3419	Economy	22600.00
0005434461693	3419	Economy	22600.00
0005434663593	12465	Economy	22600.00
0005434663571	12465	Economy	22600.00
0005434663633	12465	Economy	22600.00
0005434663605	12465	Economy	22600.00
0005434663570	12465	Economy	22600.00
0005434663550	12465	Economy	22600.00
0005434663637	12465	Economy	22600.00
0005435911611	12465	Economy	22600.00
0005435911607	12465	Economy	22600.00
0005434663522	12465	Economy	22600.00
0005434663551	12465	Economy	22600.00
0005434663575	12465	Economy	22600.00
0005434663525	12465	Economy	22600.00
0005435911609	12465	Economy	22600.00
0005434663594	12465	Economy	22600.00
0005434663599	12465	Economy	22600.00
0005435911606	12465	Economy	22600.00
0005435911610	12465	Economy	22600.00
0005435911608	12465	Economy	22600.00
0005434663606	12465	Economy	22600.00
0005434663552	12465	Economy	22600.00
0005435911605	12465	Economy	22600.00
0005434663587	12465	Economy	22600.00
0005433868950	14528	Economy	18500.00
0005433868951	14528	Economy	18500.00
0005433868696	14528	Economy	18500.00
0005433868808	14528	Economy	18500.00
0005433868945	14528	Economy	16800.00
0005433868977	14528	Economy	16800.00
0005433868903	14528	Economy	16800.00
0005433868759	14528	Economy	16800.00
0005433868733	14528	Economy	16800.00
0005433868855	14528	Economy	16800.00
0005433868755	14528	Economy	16800.00
0005433868894	14528	Economy	16800.00
0005433868982	14528	Economy	16800.00
0005433868753	14528	Economy	16800.00
0005433868788	14528	Economy	16800.00
0005433868704	14528	Economy	16800.00
0005433868754	14528	Economy	16800.00
0005433868892	14528	Economy	16800.00
0005435860573	14528	Economy	16800.00
0005433868859	14528	Economy	16800.00
0005433868541	14528	Economy	16800.00
0005433868976	14528	Economy	16800.00
0005433868882	14528	Economy	16800.00
0005433868933	14528	Economy	16800.00
0005433868837	14528	Economy	16800.00
0005433868900	14528	Economy	16800.00
0005435860575	14528	Economy	16800.00
0005433868773	14528	Economy	16800.00
0005433868908	14528	Economy	16800.00
0005433868947	14528	Economy	16800.00
0005433868949	14528	Economy	16800.00
0005433868876	14528	Economy	16800.00
0005433868989	14528	Economy	16800.00
0005433868839	14528	Economy	16800.00
0005433868705	14528	Economy	16800.00
0005433868786	14528	Economy	16800.00
0005433868920	14528	Economy	16800.00
0005433868921	14528	Economy	16800.00
0005433868576	14528	Economy	16800.00
0005435860574	14528	Economy	16800.00
0005433868840	14528	Economy	16800.00
0005433868893	14528	Economy	16800.00
0005433868858	14528	Economy	16800.00
0005433868922	14528	Economy	16800.00
0005433868719	14528	Economy	16800.00
0005433868968	14528	Economy	16800.00
0005433868809	14528	Economy	16800.00
0005433868577	14528	Economy	16800.00
0005433868969	14528	Economy	16800.00
0005433868785	14528	Economy	16800.00
0005433869240	32697	Economy	18500.00
0005433869212	32697	Economy	18500.00
0005433869237	32697	Economy	18500.00
0005433869207	32697	Economy	18500.00
0005433869208	32697	Economy	16800.00
0005433869236	32697	Economy	16800.00
0005433869233	32697	Economy	16800.00
0005433869216	32697	Economy	16800.00
0005433869211	32697	Economy	16800.00
0005433869205	32697	Economy	16800.00
0005433869214	32697	Economy	16800.00
0005433869229	32697	Economy	16800.00
0005433869228	32697	Economy	16800.00
0005433869232	32697	Economy	16800.00
0005433869202	32697	Economy	16800.00
0005433869226	32697	Economy	16800.00
0005433869210	32697	Economy	16800.00
0005433869224	32697	Economy	16800.00
0005433869203	32697	Economy	16800.00
0005433869218	32697	Economy	16800.00
0005433869230	32697	Economy	16800.00
0005433869217	32697	Economy	16800.00
0005433869238	32697	Economy	16800.00
0005433869225	32697	Economy	16800.00
0005433869209	32697	Economy	16800.00
0005433869204	32697	Economy	16800.00
0005433869221	32697	Economy	16800.00
0005435860511	32697	Economy	16800.00
0005433869206	32697	Economy	16800.00
0005433869239	32697	Economy	16800.00
0005433869222	32697	Economy	16800.00
0005433869231	32697	Economy	16800.00
0005433869234	32697	Economy	16800.00
0005433869213	32697	Economy	16800.00
0005433869219	32697	Economy	16800.00
0005433869223	32697	Economy	16800.00
0005433869215	32697	Economy	16800.00
0005433869220	32697	Economy	16800.00
0005433869235	32697	Economy	16800.00
0005433869227	32697	Economy	16800.00
0005432799816	12141	Economy	4900.00
0005432799859	12141	Economy	4900.00
0005432799691	12141	Economy	4400.00
0005432799889	12141	Economy	4400.00
0005432799782	12141	Economy	4400.00
0005432799737	12141	Economy	4400.00
0005432799736	12141	Economy	4400.00
0005432799763	12141	Economy	4400.00
0005432799870	12141	Economy	4400.00
0005432799860	12141	Economy	4400.00
0005432799888	12141	Economy	4400.00
0005432799678	12141	Economy	4400.00
0005432799772	12141	Economy	4400.00
0005432799842	12141	Economy	4400.00
0005432799823	12141	Economy	4400.00
0005432799852	12141	Economy	4400.00
0005432799879	12141	Economy	4400.00
0005432799799	12141	Economy	4400.00
0005432799773	12141	Economy	4400.00
0005432799726	12141	Economy	4400.00
0005432799837	12141	Economy	4400.00
0005432799725	12141	Economy	4400.00
0005432799694	12141	Economy	4400.00
0005432799858	12141	Economy	4400.00
0005432799871	12141	Economy	4400.00
0005432799838	12141	Economy	4400.00
0005432799775	12141	Economy	4400.00
0005432799878	12141	Economy	4400.00
0005432799885	12141	Economy	4400.00
0005432800015	14827	Economy	4900.00
0005432799998	14827	Economy	4900.00
0005432799999	14827	Economy	4900.00
0005432800000	14827	Economy	4400.00
0005432800004	14827	Economy	4400.00
0005432800008	14827	Economy	4400.00
0005432800020	14827	Economy	4400.00
0005432799996	14827	Economy	4400.00
0005432800007	14827	Economy	4400.00
0005432800005	14827	Economy	4400.00
0005432800006	14827	Economy	4400.00
0005432800003	14827	Economy	4400.00
0005432799995	14827	Economy	4400.00
0005432800019	14827	Economy	4400.00
0005432800002	14827	Economy	4400.00
0005432800012	14827	Economy	4400.00
0005432800022	14827	Economy	4400.00
0005432800021	14827	Economy	4400.00
0005432800018	14827	Economy	4400.00
0005432800001	14827	Economy	4400.00
0005432800010	14827	Economy	4400.00
0005432799997	14827	Economy	4400.00
0005432800009	14827	Economy	4400.00
0005432800016	14827	Economy	4400.00
0005432800023	14827	Economy	4400.00
0005432799994	14827	Economy	4400.00
0005432800014	14827	Economy	4400.00
0005432800013	14827	Economy	4400.00
0005432800011	14827	Economy	4400.00
0005432800017	14827	Economy	4400.00
0005435311187	7048	Business	49100.00
0005434409042	7048	Business	49100.00
0005434300047	7048	Business	49100.00
0005434300037	7048	Business	49100.00
0005435311196	7048	Business	49100.00
0005434409091	7048	Business	49100.00
0005435311171	7048	Business	49100.00
0005434409066	7048	Business	49100.00
0005435293389	7048	Business	49100.00
0005435293382	7048	Business	49100.00
0005434409052	7048	Business	49100.00
0005434300030	7048	Business	49100.00
0005434409041	7048	Economy	16400.00
0005434409053	7048	Economy	16400.00
0005435311143	7048	Economy	16400.00
0005434300048	7048	Economy	16400.00
0005432154081	7048	Economy	16400.00
0005434409044	7048	Economy	16400.00
0005435311199	7048	Economy	16400.00
0005434409086	7048	Economy	16400.00
0005432108302	7048	Economy	16400.00
0005432108303	7048	Economy	16400.00
0005434300045	7048	Economy	16400.00
0005434300031	7048	Economy	16400.00
0005434409045	7048	Economy	16400.00
0005434300043	7048	Economy	16400.00
0005434409069	7048	Economy	16400.00
0005434409033	7048	Economy	16400.00
0005435293420	7048	Economy	16400.00
0005434409031	7048	Economy	16400.00
0005434300049	7048	Economy	16400.00
0005432154084	7048	Economy	16400.00
0005435311164	7048	Economy	16400.00
0005435311183	7048	Economy	16400.00
0005435311141	7048	Economy	16400.00
0005434409055	7048	Economy	16400.00
0005434409054	7048	Economy	16400.00
0005434409079	7048	Economy	16400.00
0005434409062	7048	Economy	16400.00
0005435293396	7048	Economy	16400.00
0005435311177	7048	Economy	16400.00
0005432108304	7048	Economy	16400.00
0005434300038	7048	Economy	16400.00
0005434409046	7048	Economy	16400.00
0005434409075	7048	Economy	16400.00
0005434300050	7048	Economy	16400.00
0005434409092	7048	Economy	16400.00
0005434409078	7048	Economy	18000.00
0005434409087	7048	Economy	16400.00
0005434409032	7048	Economy	18000.00
0005434409037	7048	Economy	18000.00
0005434409072	7048	Economy	18000.00
0005434409057	7048	Economy	18000.00
0005434300040	7048	Economy	16400.00
0005435311165	7048	Economy	18000.00
0005434300028	7048	Economy	16400.00
0005435293421	7048	Economy	16400.00
0005434409081	7048	Economy	16400.00
0005434409093	7048	Economy	16400.00
0005434409067	7048	Economy	16400.00
0005434409038	7048	Economy	16400.00
0005434409059	7048	Economy	16400.00
0005435311142	7048	Economy	16400.00
0005435311175	7048	Economy	16400.00
0005434409051	7048	Economy	16400.00
0005434300044	7048	Economy	16400.00
0005434300041	7048	Economy	16400.00
0005434300035	7048	Economy	16400.00
0005434409036	7048	Economy	16400.00
0005434409065	7048	Economy	16400.00
0005434300036	7048	Economy	16400.00
0005434409061	7048	Economy	16400.00
0005434409070	7048	Economy	16400.00
0005434409085	7048	Economy	16400.00
0005434409049	7048	Economy	16400.00
0005434409074	7048	Economy	16400.00
0005434409089	7048	Economy	16400.00
0005434300046	7048	Economy	16400.00
0005434409077	7048	Economy	16400.00
0005434300039	7048	Economy	16400.00
0005432154083	7048	Economy	16400.00
0005435293437	7048	Economy	16400.00
0005434409047	7048	Economy	16400.00
0005434409056	7048	Economy	16400.00
0005432154085	7048	Economy	16400.00
0005434409058	7048	Economy	16400.00
0005435311170	7048	Economy	16400.00
0005435293385	7048	Economy	16400.00
0005435311176	7048	Economy	16400.00
0005434409084	7048	Economy	16400.00
0005432154079	7048	Economy	16400.00
0005434409073	7048	Economy	16400.00
0005434409083	7048	Economy	16400.00
0005434300027	7048	Economy	16400.00
0005432154080	7048	Economy	16400.00
0005434409088	7048	Economy	16400.00
0005434409035	7048	Economy	16400.00
0005434409040	7048	Economy	16400.00
0005434409039	7048	Economy	16400.00
0005434409060	7048	Economy	16400.00
0005434300034	7048	Economy	16400.00
0005434409076	7048	Economy	16400.00
0005434409080	7048	Economy	16400.00
0005434300033	7048	Economy	16400.00
0005434300029	7048	Economy	16400.00
0005434409068	7048	Economy	16400.00
0005434409034	7048	Economy	16400.00
0005432154082	7048	Economy	16400.00
0005435311163	7048	Economy	16400.00
0005434409071	7048	Economy	16400.00
0005435293390	7048	Economy	16400.00
0005435293386	7048	Economy	16400.00
0005435293383	7048	Economy	16400.00
0005434409094	7048	Economy	16400.00
0005434300042	7048	Economy	16400.00
0005434409082	7048	Economy	16400.00
0005434409043	7048	Economy	16400.00
0005434409090	7048	Economy	16400.00
0005434300032	7048	Economy	16400.00
0005434409050	7048	Economy	16400.00
0005434409030	7048	Economy	16400.00
0005434409048	7048	Economy	16400.00
0005434409064	7048	Economy	16400.00
0005434409063	7048	Economy	16400.00
0005434408602	26937	Business	49100.00
0005435293514	26937	Business	49100.00
0005434299831	26937	Business	49100.00
0005434408427	26937	Business	49100.00
0005434299781	26937	Business	49100.00
0005434408050	26937	Business	49100.00
0005434299899	26937	Business	49100.00
0005434408215	26937	Business	49100.00
0005432058460	26937	Business	49100.00
0005434408344	26937	Business	49100.00
0005434299814	26937	Business	49100.00
0005434408638	26937	Economy	16400.00
0005434408454	26937	Economy	16400.00
0005434408688	26937	Economy	16400.00
0005434408260	26937	Economy	16400.00
0005432058461	26937	Economy	16400.00
0005434408577	26937	Economy	16400.00
0005434408596	26937	Economy	16400.00
0005435293515	26937	Economy	16400.00
0005434408368	26937	Economy	16400.00
0005434408410	26937	Economy	16400.00
0005434408687	26937	Economy	16400.00
0005434408503	26937	Economy	16400.00
0005434299892	26937	Economy	16400.00
0005434299740	26937	Economy	16400.00
0005434408404	26937	Economy	16400.00
0005434408426	26937	Economy	16400.00
0005434408158	26937	Economy	16400.00
0005435311305	26937	Economy	16400.00
0005434408759	26937	Economy	16400.00
0005435293510	26937	Economy	16400.00
0005434408363	26937	Economy	16400.00
0005434408525	26937	Economy	16400.00
0005435311311	26937	Economy	16400.00
0005435311302	26937	Economy	16400.00
0005434299864	26937	Economy	16400.00
0005434408343	26937	Economy	16400.00
0005434408588	26937	Economy	16400.00
0005434408478	26937	Economy	16400.00
0005434408370	26937	Economy	16400.00
0005434408744	26937	Economy	16400.00
0005434408515	26937	Economy	16400.00
0005434299782	26937	Economy	16400.00
0005435311300	26937	Economy	16400.00
0005434299741	26937	Economy	16400.00
0005435293513	26937	Economy	16400.00
0005434408603	26937	Economy	16400.00
0005435293512	26937	Economy	16400.00
0005434408524	26937	Economy	16400.00
0005434408594	26937	Economy	16400.00
0005434408654	26937	Economy	18000.00
0005434299869	26937	Economy	18000.00
0005435311313	26937	Economy	18000.00
0005434299861	26937	Economy	18000.00
0005434408317	26937	Economy	18000.00
0005434299840	26937	Economy	18000.00
0005434299751	26937	Economy	16400.00
0005434408379	26937	Economy	16400.00
0005435311298	26937	Economy	16400.00
0005434408428	26937	Economy	16400.00
0005434408342	26937	Economy	16400.00
0005434408386	26937	Economy	16400.00
0005434408455	26937	Economy	16400.00
0005434408476	26937	Economy	16400.00
0005434299813	26937	Economy	16400.00
0005434408551	26937	Economy	16400.00
0005434408505	26937	Economy	16400.00
0005435311299	26937	Economy	16400.00
0005434408523	26937	Economy	16400.00
0005435311304	26937	Economy	16400.00
0005435311310	26937	Economy	16400.00
0005434408745	26937	Economy	16400.00
0005434299908	26937	Economy	16400.00
0005434408380	26937	Economy	16400.00
0005434408508	26937	Economy	16400.00
0005435311312	26937	Economy	16400.00
0005435293506	26937	Economy	16400.00
0005435311317	26937	Economy	16400.00
0005434299830	26937	Economy	16400.00
0005434408403	26937	Economy	16400.00
0005434299954	26937	Economy	16400.00
0005435293511	26937	Economy	16400.00
0005434408369	26937	Economy	16400.00
0005434299752	26937	Economy	16400.00
0005434408579	26937	Economy	16400.00
0005434408479	26937	Economy	16400.00
0005434408483	26937	Economy	16400.00
0005434408389	26937	Economy	16400.00
0005435293508	26937	Economy	16400.00
0005434299953	26937	Economy	16400.00
0005434299812	26937	Economy	16400.00
0005434408089	26937	Economy	16400.00
0005435311303	26937	Economy	16400.00
0005434408373	26937	Economy	16400.00
0005435311314	26937	Economy	16400.00
0005434299871	26937	Economy	16400.00
0005434408506	26937	Economy	16400.00
0005435311301	26937	Economy	16400.00
0005434408418	26937	Economy	16400.00
0005435293507	26937	Economy	16400.00
0005434408374	26937	Economy	16400.00
0005434408622	26937	Economy	16400.00
0005435293505	26937	Economy	16400.00
0005434299863	26937	Economy	16400.00
0005435311316	26937	Economy	16400.00
0005434299856	26937	Economy	16400.00
0005435311297	26937	Economy	16400.00
0005434408728	26937	Economy	16400.00
0005434408601	26937	Economy	16400.00
0005435293509	26937	Economy	16400.00
0005434299888	26937	Economy	16400.00
0005434408637	26937	Economy	16400.00
0005435311306	26937	Economy	16400.00
0005434408735	26937	Economy	16400.00
0005435311315	26937	Economy	16400.00
0005434408679	26937	Economy	16400.00
0005434408540	26937	Economy	16400.00
0005434408580	26937	Economy	16400.00
0005432058459	26937	Economy	16400.00
0005434408432	26937	Economy	16400.00
0005434299909	26937	Economy	16400.00
0005435311307	26937	Economy	16400.00
0005434408197	26937	Economy	16400.00
0005435311308	26937	Economy	16400.00
0005435311309	26937	Economy	16400.00
0005434408475	26937	Economy	16400.00
0005432605168	6427	Economy	16500.00
0005434512220	6427	Economy	16500.00
0005432605181	6427	Economy	16500.00
0005432605178	6427	Economy	16500.00
0005432605156	6427	Economy	15000.00
0005432605160	6427	Economy	15000.00
0005432605166	6427	Economy	15000.00
0005432605164	6427	Economy	15000.00
0005432605153	6427	Economy	15000.00
0005432605174	6427	Economy	15000.00
0005432605161	6427	Economy	15000.00
0005432605149	6427	Economy	15000.00
0005434512219	6427	Economy	15000.00
0005432605151	6427	Economy	15000.00
0005432605171	6427	Economy	15000.00
0005432605170	6427	Economy	15000.00
0005432605175	6427	Economy	15000.00
0005432605177	6427	Economy	15000.00
0005432605162	6427	Economy	15000.00
0005432605176	6427	Economy	15000.00
0005432605150	6427	Economy	15000.00
0005432605167	6427	Economy	15000.00
0005432605157	6427	Economy	15000.00
0005432605143	6427	Economy	15000.00
0005432605144	6427	Economy	15000.00
0005432605158	6427	Economy	15000.00
0005432605152	6427	Economy	15000.00
0005432605145	6427	Economy	15000.00
0005432605169	6427	Economy	15000.00
0005432605179	6427	Economy	15000.00
0005432605163	6427	Economy	15000.00
0005432605172	6427	Economy	15000.00
0005432605173	6427	Economy	15000.00
0005432605182	6427	Economy	15000.00
0005432605147	6427	Economy	15000.00
0005432605154	6427	Economy	15000.00
0005432605146	6427	Economy	15000.00
0005432605159	6427	Economy	15000.00
0005432605155	6427	Economy	15000.00
0005432605165	6427	Economy	15000.00
0005432605183	6427	Economy	15000.00
0005432605180	6427	Economy	15000.00
0005432605148	6427	Economy	15000.00
0005432604828	21394	Economy	16500.00
0005432604750	21394	Economy	16500.00
0005434512162	21394	Economy	16500.00
0005432604776	21394	Economy	16500.00
0005432604774	21394	Economy	15000.00
0005432604801	21394	Economy	15000.00
0005432604676	21394	Economy	15000.00
0005432604782	21394	Economy	15000.00
0005432604868	21394	Economy	15000.00
0005432604896	21394	Economy	15000.00
0005432604830	21394	Economy	15000.00
0005432604735	21394	Economy	15000.00
0005432604749	21394	Economy	15000.00
0005432604679	21394	Economy	15000.00
0005432604680	21394	Economy	15000.00
0005432604730	21394	Economy	15000.00
0005432604758	21394	Economy	15000.00
0005432604657	21394	Economy	15000.00
0005432604897	21394	Economy	15000.00
0005434512171	21394	Economy	15000.00
0005432604751	21394	Economy	15000.00
0005432604763	21394	Economy	15000.00
0005432604711	21394	Economy	15000.00
0005432604650	21394	Economy	15000.00
0005432604678	21394	Economy	15000.00
0005432604729	21394	Economy	15000.00
0005432604737	21394	Economy	15000.00
0005432604659	21394	Economy	15000.00
0005432604924	21394	Economy	15000.00
0005434512167	21394	Economy	15000.00
0005432604816	21394	Economy	15000.00
0005432604926	21394	Economy	15000.00
0005432604923	21394	Economy	15000.00
0005432604762	21394	Economy	15000.00
0005432604773	21394	Economy	15000.00
0005432604840	21394	Economy	15000.00
0005432604817	21394	Economy	15000.00
0005432604786	21394	Economy	15000.00
0005432604807	21394	Economy	15000.00
0005432604626	21394	Economy	15000.00
0005432604856	21394	Economy	15000.00
0005432604925	21394	Economy	15000.00
0005432604802	21394	Economy	15000.00
0005432604815	21394	Economy	15000.00
0005432604720	21394	Economy	15000.00
0005432604775	21394	Economy	15000.00
0005432604736	21394	Economy	15000.00
0005432604738	21394	Economy	15000.00
0005432604727	21394	Economy	15000.00
0005434907611	15001	Business	18900.00
0005433252112	15001	Business	18900.00
0005433252111	15001	Business	18900.00
0005433252115	15001	Business	18900.00
0005434907861	15001	Business	18900.00
0005433252104	15001	Business	18900.00
0005434907856	15001	Business	18900.00
0005433252107	15001	Business	18900.00
0005434907855	15001	Business	18900.00
0005434907803	15001	Business	18900.00
0005434907912	15001	Business	18900.00
0005433252097	15001	Economy	6300.00
0005433252124	15001	Economy	6300.00
0005434907812	15001	Economy	6300.00
0005433252101	15001	Economy	6300.00
0005434908021	15001	Economy	6300.00
0005433252117	15001	Economy	6300.00
0005434907862	15001	Economy	6300.00
0005434907610	15001	Economy	6300.00
0005434907829	15001	Economy	6900.00
0005434907850	15001	Economy	6900.00
0005434908001	15001	Economy	6900.00
0005433252122	15001	Economy	6900.00
0005433252109	15001	Economy	6300.00
0005434907960	15001	Economy	6300.00
0005433252099	15001	Economy	6300.00
0005433252114	15001	Economy	6300.00
0005434907836	15001	Economy	6300.00
0005434907780	15001	Economy	6300.00
0005434907785	15001	Economy	6300.00
0005434907936	15001	Economy	6300.00
0005434907883	15001	Economy	6300.00
0005433252106	15001	Economy	6300.00
0005434907843	15001	Economy	6300.00
0005433252119	15001	Economy	6300.00
0005433252128	15001	Economy	6300.00
0005434907779	15001	Economy	6300.00
0005434907825	15001	Economy	6300.00
0005433252103	15001	Economy	6300.00
0005433252108	15001	Economy	6300.00
0005434907906	15001	Economy	6300.00
0005434907792	15001	Economy	6300.00
0005433252105	15001	Economy	6300.00
0005434907811	15001	Economy	6300.00
0005433252127	15001	Economy	6300.00
0005433252120	15001	Economy	6300.00
0005434907781	15001	Economy	6300.00
0005434907593	15001	Economy	6300.00
0005433252102	15001	Economy	6300.00
0005434907848	15001	Economy	6300.00
0005434907830	15001	Economy	6300.00
0005434907834	15001	Economy	6300.00
0005433252118	15001	Economy	6300.00
0005434907935	15001	Economy	6300.00
0005434907835	15001	Economy	6300.00
0005434907831	15001	Economy	6300.00
0005434907905	15001	Economy	6300.00
0005434907979	15001	Economy	6300.00
0005434907914	15001	Economy	6300.00
0005434907698	15001	Economy	6300.00
0005434907786	15001	Economy	6300.00
0005433252113	15001	Economy	6300.00
0005433252100	15001	Economy	6300.00
0005434907965	15001	Economy	6300.00
0005433252125	15001	Economy	6300.00
0005434907826	15001	Economy	6300.00
0005434908025	15001	Economy	6300.00
0005433252110	15001	Economy	6300.00
0005434907594	15001	Economy	6300.00
0005433252126	15001	Economy	6300.00
0005434907696	15001	Economy	6300.00
0005434907950	15001	Economy	6300.00
0005433252098	15001	Economy	6300.00
0005433252121	15001	Economy	6300.00
0005434908026	15001	Economy	6300.00
0005434907784	15001	Economy	6300.00
0005434907854	15001	Economy	6300.00
0005433252116	15001	Economy	6300.00
0005434907882	15001	Economy	6300.00
0005434908004	15001	Economy	6300.00
0005434907833	15001	Economy	6300.00
0005434907842	15001	Economy	6300.00
0005434907714	15001	Economy	6300.00
0005433252123	15001	Economy	6300.00
0005434908280	25858	Business	18900.00
0005434908317	25858	Business	18900.00
0005433251837	25858	Business	18900.00
0005433251821	25858	Business	18900.00
0005434908288	25858	Business	18900.00
0005434908302	25858	Business	18900.00
0005434908285	25858	Business	18900.00
0005434908328	25858	Business	18900.00
0005434908311	25858	Business	18900.00
0005434908291	25858	Business	18900.00
0005434908314	25858	Economy	6300.00
0005434908282	25858	Economy	6300.00
0005434908298	25858	Economy	6300.00
0005433251889	25858	Economy	6300.00
0005433251840	25858	Economy	6300.00
0005433251980	25858	Economy	6300.00
0005434908294	25858	Economy	6300.00
0005434908330	25858	Economy	6900.00
0005433251779	25858	Economy	6900.00
0005434908329	25858	Economy	6900.00
0005434908318	25858	Economy	6900.00
0005434908334	25858	Economy	6300.00
0005434908286	25858	Economy	6300.00
0005434908281	25858	Economy	6300.00
0005434908310	25858	Economy	6300.00
0005434908296	25858	Economy	6300.00
0005434908333	25858	Economy	6300.00
0005434908290	25858	Economy	6300.00
0005433251778	25858	Economy	6300.00
0005434908325	25858	Economy	6300.00
0005433251912	25858	Economy	6300.00
0005434908309	25858	Economy	6300.00
0005434908307	25858	Economy	6300.00
0005433251968	25858	Economy	6300.00
0005433251788	25858	Economy	6300.00
0005434908319	25858	Economy	6300.00
0005434908287	25858	Economy	6300.00
0005433251846	25858	Economy	6300.00
0005434908295	25858	Economy	6300.00
0005434908293	25858	Economy	6300.00
0005434908297	25858	Economy	6300.00
0005434908332	25858	Economy	6300.00
0005434908308	25858	Economy	6300.00
0005434908316	25858	Economy	6300.00
0005434908306	25858	Economy	6300.00
0005434908331	25858	Economy	6300.00
0005433251874	25858	Economy	6300.00
0005434908299	25858	Economy	6300.00
0005434908292	25858	Economy	6300.00
0005433251939	25858	Economy	6300.00
0005434908301	25858	Economy	6300.00
0005433251811	25858	Economy	6300.00
0005434908321	25858	Economy	6300.00
0005434908313	25858	Economy	6300.00
0005434908312	25858	Economy	6300.00
0005434908300	25858	Economy	6300.00
0005434908304	25858	Economy	6300.00
0005433251954	25858	Economy	6300.00
0005434908320	25858	Economy	6300.00
0005434908323	25858	Economy	6300.00
0005434908303	25858	Economy	6300.00
0005434908322	25858	Economy	6300.00
0005433251708	25858	Economy	6300.00
0005433251709	25858	Economy	6300.00
0005434908289	25858	Economy	6300.00
0005434908324	25858	Economy	6300.00
0005434908327	25858	Economy	6300.00
0005434908305	25858	Economy	6300.00
0005434908326	25858	Economy	6300.00
0005434908283	25858	Economy	6300.00
0005434908315	25858	Economy	6300.00
0005433251890	25858	Economy	6300.00
0005434908335	25858	Economy	6300.00
0005434908279	25858	Economy	6300.00
0005434908284	25858	Economy	6300.00
0005433009560	14154	Business	52300.00
0005433009558	14154	Business	52300.00
0005433009567	14154	Business	52300.00
0005433009566	14154	Business	52300.00
0005433009553	14154	Business	52300.00
0005433009565	14154	Economy	17400.00
0005433009580	14154	Economy	17400.00
0005433009578	14154	Economy	17400.00
0005433009574	14154	Economy	17400.00
0005433009538	14154	Economy	17400.00
0005433009540	14154	Economy	17400.00
0005433009545	14154	Economy	19200.00
0005433009572	14154	Economy	19200.00
0005433009564	14154	Economy	19200.00
0005433009581	14154	Economy	17400.00
0005433009552	14154	Economy	17400.00
0005433009555	14154	Economy	17400.00
0005433009569	14154	Economy	17400.00
0005433009547	14154	Economy	17400.00
0005433009579	14154	Economy	17400.00
0005433009576	14154	Economy	17400.00
0005433009549	14154	Economy	17400.00
0005433009551	14154	Economy	17400.00
0005433009548	14154	Economy	17400.00
0005433009570	14154	Economy	17400.00
0005433009539	14154	Economy	17400.00
0005433009559	14154	Economy	17400.00
0005433009544	14154	Economy	17400.00
0005433009556	14154	Economy	17400.00
0005433009550	14154	Economy	17400.00
0005433009568	14154	Economy	17400.00
0005433009543	14154	Economy	17400.00
0005433009546	14154	Economy	17400.00
0005433009577	14154	Economy	17400.00
0005433009563	14154	Economy	17400.00
0005433009575	14154	Economy	17400.00
0005433009571	14154	Economy	17400.00
0005433009561	14154	Economy	17400.00
0005433810578	14154	Economy	17400.00
0005433009562	14154	Economy	17400.00
0005433009573	14154	Economy	17400.00
0005433009542	14154	Economy	17400.00
0005433009541	14154	Economy	17400.00
0005433009582	14154	Economy	17400.00
0005433009554	14154	Economy	17400.00
0005433009557	14154	Economy	17400.00
0005433009584	14154	Economy	17400.00
0005433009583	14154	Economy	17400.00
0005433810580	14154	Economy	17400.00
0005433009011	22829	Business	52300.00
0005433810646	22829	Business	52300.00
0005433810645	22829	Business	52300.00
0005433810626	22829	Business	52300.00
0005433810638	22829	Business	52300.00
0005433810627	22829	Business	52300.00
0005433009213	22829	Business	52300.00
0005433008964	22829	Economy	17400.00
0005433810633	22829	Economy	17400.00
0005433008797	22829	Economy	17400.00
0005433009098	22829	Economy	17400.00
0005433009183	22829	Economy	19200.00
0005433810642	22829	Economy	19200.00
0005433009097	22829	Economy	19200.00
0005433009237	22829	Economy	17400.00
0005433810629	22829	Economy	17400.00
0005433810636	22829	Economy	17400.00
0005433810634	22829	Economy	17400.00
0005433810631	22829	Economy	17400.00
0005433009203	22829	Economy	17400.00
0005433009214	22829	Economy	17400.00
0005433810632	22829	Economy	17400.00
0005433009184	22829	Economy	17400.00
0005433009118	22829	Economy	17400.00
0005433009014	22829	Economy	17400.00
0005433810641	22829	Economy	17400.00
0005433810624	22829	Economy	17400.00
0005433810644	22829	Economy	17400.00
0005433810639	22829	Economy	17400.00
0005433009292	22829	Economy	17400.00
0005433009057	22829	Economy	17400.00
0005433008843	22829	Economy	17400.00
0005433810630	22829	Economy	17400.00
0005433810635	22829	Economy	17400.00
0005433810623	22829	Economy	17400.00
0005433009099	22829	Economy	17400.00
0005433009176	22829	Economy	17400.00
0005433009255	22829	Economy	17400.00
0005433009013	22829	Economy	17400.00
0005433810637	22829	Economy	17400.00
0005433009100	22829	Economy	17400.00
0005433810643	22829	Economy	17400.00
0005433009041	22829	Economy	17400.00
0005433009134	22829	Economy	17400.00
0005433009252	22829	Economy	17400.00
0005433810625	22829	Economy	17400.00
0005433009175	22829	Economy	17400.00
0005433810640	22829	Economy	17400.00
0005433009276	22829	Economy	17400.00
0005433009042	22829	Economy	17400.00
0005433810628	22829	Economy	17400.00
0005433009079	22829	Economy	17400.00
0005433008842	22829	Economy	17400.00
0005435718942	27122	Business	85200.00
0005435718948	27122	Business	85200.00
0005435718943	27122	Business	85200.00
0005435718974	27122	Business	85200.00
0005435718982	27122	Business	85200.00
0005435718971	27122	Business	85200.00
0005435718962	27122	Economy	28400.00
0005435718973	27122	Economy	28400.00
0005435718956	27122	Economy	28400.00
0005435718947	27122	Economy	28400.00
0005435718941	27122	Economy	28400.00
0005435718984	27122	Economy	31200.00
0005435718981	27122	Economy	28400.00
0005435718970	27122	Economy	28400.00
0005435718924	27122	Economy	28400.00
0005435718969	27122	Economy	28400.00
0005435718931	27122	Economy	28400.00
0005435718967	27122	Economy	28400.00
0005435718940	27122	Economy	28400.00
0005435718975	27122	Economy	28400.00
0005435718978	27122	Economy	28400.00
0005435718923	27122	Economy	28400.00
0005435718958	27122	Economy	28400.00
0005435718954	27122	Economy	28400.00
0005435718929	27122	Economy	28400.00
0005435718980	27122	Economy	28400.00
0005435718963	27122	Economy	28400.00
0005435718927	27122	Economy	28400.00
0005435718957	27122	Economy	28400.00
0005435718968	27122	Economy	28400.00
0005435718921	27122	Economy	28400.00
0005435718979	27122	Economy	28400.00
0005435718972	27122	Economy	28400.00
0005435718983	27122	Economy	28400.00
0005435718926	27122	Economy	28400.00
0005435718922	27122	Economy	28400.00
0005435718986	27122	Economy	28400.00
0005435718944	27122	Economy	28400.00
0005434926087	14920	Business	22900.00
0005434926082	14920	Business	22900.00
0005434926088	14920	Business	22900.00
0005434926132	14920	Business	22900.00
0005434926106	14920	Economy	7600.00
0005434926116	14920	Economy	7600.00
0005434926107	14920	Economy	7600.00
0005434926020	14920	Economy	8400.00
0005434926019	14920	Economy	8400.00
0005434926075	14920	Economy	8400.00
0005434926141	14920	Economy	7600.00
0005434926149	14920	Economy	7600.00
0005434925981	14920	Economy	7600.00
0005434926086	14920	Economy	7600.00
0005434926045	14920	Economy	7600.00
0005434926090	14920	Economy	7600.00
0005434925982	14920	Economy	7600.00
0005434926144	14920	Economy	7600.00
0005434926092	14920	Economy	7600.00
0005434926068	14920	Economy	7600.00
0005434926098	14920	Economy	7600.00
0005434926124	14920	Economy	7600.00
0005434926091	14920	Economy	7600.00
0005434926089	14920	Economy	7600.00
0005434926148	14920	Economy	7600.00
0005434926422	20503	Business	22900.00
0005434926413	20503	Business	22900.00
0005434926409	20503	Business	22900.00
0005434926427	20503	Business	22900.00
0005434926434	20503	Business	22900.00
0005434926411	20503	Business	22900.00
0005434926425	20503	Economy	7600.00
0005434926439	20503	Economy	7600.00
0005434926432	20503	Economy	7600.00
0005434926421	20503	Economy	7600.00
0005434926426	20503	Economy	8400.00
0005434926416	20503	Economy	8400.00
0005434926415	20503	Economy	8400.00
0005434926438	20503	Economy	7600.00
0005434926437	20503	Economy	7600.00
0005434926408	20503	Economy	7600.00
0005434926433	20503	Economy	7600.00
0005434926412	20503	Economy	7600.00
0005434926418	20503	Economy	7600.00
0005434926414	20503	Economy	7600.00
0005434926436	20503	Economy	7600.00
0005434926410	20503	Economy	7600.00
0005434926407	20503	Economy	7600.00
0005434926430	20503	Economy	7600.00
0005434926406	20503	Economy	7600.00
0005434926417	20503	Economy	7600.00
0005434926419	20503	Economy	7600.00
0005434926429	20503	Economy	7600.00
0005434926405	20503	Economy	7600.00
0005434926435	20503	Economy	7600.00
0005434926431	20503	Economy	7600.00
0005434926428	20503	Economy	7600.00
0005434926424	20503	Economy	7600.00
0005434926420	20503	Economy	7600.00
0005434926423	20503	Economy	7600.00
0005435999443	15802	Economy	8900.00
0005435488282	15802	Economy	8900.00
0005435999358	15802	Economy	8900.00
0005435488280	15802	Economy	8900.00
0005435999435	15802	Economy	8100.00
0005435999462	15802	Economy	8100.00
0005435488287	15802	Economy	8100.00
0005435999434	15802	Economy	8100.00
0005435999442	15802	Economy	8100.00
0005435488277	15802	Economy	8100.00
0005435999381	15802	Economy	8100.00
0005435999397	15802	Economy	8100.00
0005435488286	15802	Economy	8100.00
0005435488275	15802	Economy	8100.00
0005435488281	15802	Economy	8100.00
0005435488290	15802	Economy	8100.00
0005435999444	15802	Economy	8100.00
0005435488294	15802	Economy	8100.00
0005435488291	15802	Economy	8100.00
0005435999467	15802	Economy	8100.00
0005435488293	15802	Economy	8100.00
0005435999448	15802	Economy	8100.00
0005435999453	15802	Economy	8100.00
0005435488278	15802	Economy	8100.00
0005435999412	15802	Economy	8100.00
0005435999432	15802	Economy	8100.00
0005435488284	15802	Economy	8100.00
0005435488289	15802	Economy	8100.00
0005435488273	15802	Economy	8100.00
0005435999450	15802	Economy	8100.00
0005435488285	15802	Economy	8100.00
0005435999461	15802	Economy	8100.00
0005435999449	15802	Economy	8100.00
0005435999452	15802	Economy	8100.00
0005435488292	15802	Economy	8100.00
0005435999359	15802	Economy	8100.00
0005435999451	15802	Economy	8100.00
0005435488283	15802	Economy	8100.00
0005435999468	15802	Economy	8100.00
0005435488276	15802	Economy	8100.00
0005435999396	15802	Economy	8100.00
0005435488288	15802	Economy	8100.00
0005435999433	15802	Economy	8100.00
0005435488274	15802	Economy	8100.00
0005435488279	15802	Economy	8100.00
0005435488126	19677	Economy	8900.00
0005435488159	19677	Economy	8900.00
0005435488014	19677	Economy	8900.00
0005435487980	19677	Economy	8900.00
0005435999594	19677	Economy	8100.00
0005435487960	19677	Economy	8100.00
0005435488095	19677	Economy	8100.00
0005435488015	19677	Economy	8100.00
0005435488005	19677	Economy	8100.00
0005435488031	19677	Economy	8100.00
0005435999592	19677	Economy	8100.00
0005435488158	19677	Economy	8100.00
0005435488024	19677	Economy	8100.00
0005435488070	19677	Economy	8100.00
0005435487997	19677	Economy	8100.00
0005435488003	19677	Economy	8100.00
0005435488029	19677	Economy	8100.00
0005435487991	19677	Economy	8100.00
0005435999590	19677	Economy	8100.00
0005435487998	19677	Economy	8100.00
0005435488089	19677	Economy	8100.00
0005435488128	19677	Economy	8100.00
0005435488069	19677	Economy	8100.00
0005435487988	19677	Economy	8100.00
0005435488114	19677	Economy	8100.00
0005435488136	19677	Economy	8100.00
0005435487986	19677	Economy	8100.00
0005435999593	19677	Economy	8100.00
0005435999595	19677	Economy	8100.00
0005435999596	19677	Economy	8100.00
0005435488030	19677	Economy	8100.00
0005435488094	19677	Economy	8100.00
0005435488036	19677	Economy	8100.00
0005435488004	19677	Economy	8100.00
0005435488037	19677	Economy	8100.00
0005435999591	19677	Economy	8100.00
0005435488127	19677	Economy	8100.00
0005435488025	19677	Economy	8100.00
0005435840024	6024	Business	199300.00
0005435840034	6024	Business	199300.00
0005435473018	6024	Business	199300.00
0005435840035	6024	Business	199300.00
0005435472979	6024	Business	199300.00
0005435840040	6024	Business	199300.00
0005435473077	6024	Business	199300.00
0005435840029	6024	Business	199300.00
0005435473030	6024	Economy	66400.00
0005432660863	6024	Economy	66400.00
0005435840037	6024	Economy	66400.00
0005435473007	6024	Economy	66400.00
0005435472998	6024	Economy	66400.00
0005435840031	6024	Economy	66400.00
0005435473031	6024	Economy	66400.00
0005435473015	6024	Economy	66400.00
0005435473019	6024	Economy	73100.00
0005435472948	6024	Economy	73100.00
0005432660862	6024	Economy	66400.00
0005432142316	6024	Economy	66400.00
0005432537084	6024	Economy	66400.00
0005435472980	6024	Economy	66400.00
0005435840043	6024	Economy	66400.00
0005435840025	6024	Economy	66400.00
0005435840050	6024	Economy	66400.00
0005435840038	6024	Economy	66400.00
0005435473008	6024	Economy	66400.00
0005432537079	6024	Economy	66400.00
0005432537083	6024	Economy	66400.00
0005435472949	6024	Economy	66400.00
0005435472981	6024	Economy	66400.00
0005435473078	6024	Economy	66400.00
0005435472995	6024	Economy	66400.00
0005435840042	6024	Economy	66400.00
0005435840051	6024	Economy	66400.00
0005432142317	6024	Economy	66400.00
0005435472947	6024	Economy	66400.00
0005432659752	6024	Economy	66400.00
0005435472993	6024	Economy	66400.00
0005435472992	6024	Economy	66400.00
0005435840048	6024	Economy	66400.00
0005435840036	6024	Economy	66400.00
0005435840047	6024	Economy	66400.00
0005435473028	6024	Economy	66400.00
0005432658635	6024	Economy	66400.00
0005435840032	6024	Economy	66400.00
0005435473027	6024	Economy	66400.00
0005435472985	6024	Economy	66400.00
0005435472975	6024	Economy	66400.00
0005435840027	6024	Economy	66400.00
0005435840023	6024	Economy	66400.00
0005435472971	6024	Economy	66400.00
0005435840039	6024	Economy	66400.00
0005435840030	6024	Economy	66400.00
0005435473009	6024	Economy	66400.00
0005435840028	6024	Economy	66400.00
0005435840049	6024	Economy	66400.00
0005432659751	6024	Economy	66400.00
0005435840026	6024	Economy	66400.00
0005435473020	6024	Economy	66400.00
0005435840046	6024	Economy	66400.00
0005435840045	6024	Economy	66400.00
0005432658636	6024	Economy	66400.00
0005435840033	6024	Economy	66400.00
0005435472937	6024	Economy	66400.00
0005435472970	6024	Economy	66400.00
0005435840041	6024	Economy	66400.00
0005435840044	6024	Economy	66400.00
0005435473151	18065	Business	199300.00
0005435473154	18065	Business	199300.00
0005435473148	18065	Business	199300.00
0005435473142	18065	Business	199300.00
0005435473139	18065	Business	199300.00
0005435839798	18065	Business	199300.00
0005435839699	18065	Business	199300.00
0005435839735	18065	Business	199300.00
0005435839795	18065	Business	199300.00
0005435839811	18065	Economy	66400.00
0005435473140	18065	Economy	66400.00
0005435839727	18065	Economy	66400.00
0005435839794	18065	Economy	66400.00
0005435839779	18065	Economy	66400.00
0005435839885	18065	Economy	66400.00
0005435473153	18065	Economy	73100.00
0005435473145	18065	Economy	66400.00
0005435473149	18065	Economy	66400.00
0005435473146	18065	Economy	66400.00
0005435617239	18065	Economy	66400.00
0005432537104	18065	Economy	66400.00
0005432537103	18065	Economy	66400.00
0005435839890	18065	Economy	66400.00
0005435839841	18065	Economy	66400.00
0005435839736	18065	Economy	66400.00
0005435839797	18065	Economy	66400.00
0005435473147	18065	Economy	66400.00
0005435839786	18065	Economy	66400.00
0005435839645	18065	Economy	66400.00
0005435839768	18065	Economy	66400.00
0005435473141	18065	Economy	66400.00
0005435839816	18065	Economy	66400.00
0005435839720	18065	Economy	66400.00
0005435473144	18065	Economy	66400.00
0005435473150	18065	Economy	66400.00
0005435617240	18065	Economy	66400.00
0005435473152	18065	Economy	66400.00
0005435839817	18065	Economy	66400.00
0005435473143	18065	Economy	66400.00
0005435839767	18065	Economy	66400.00
0005435839728	18065	Economy	66400.00
0005435839785	18065	Economy	66400.00
0005435839824	18065	Economy	66400.00
0005435839711	18065	Economy	66400.00
0005435839799	18065	Economy	66400.00
0005435839721	18065	Economy	66400.00
0005435473138	18065	Economy	66400.00
0005435839810	18065	Economy	66400.00
0005435839800	18065	Economy	66400.00
0005433460456	19907	Business	146400.00
0005433462753	19907	Business	146400.00
0005433460453	19907	Economy	53700.00
0005433460457	19907	Economy	48800.00
0005433460433	19907	Economy	48800.00
0005433460455	19907	Economy	48800.00
0005433462756	19907	Economy	48800.00
0005433462757	19907	Economy	48800.00
0005433462752	19907	Economy	48800.00
0005433460448	19907	Economy	48800.00
0005433462754	19907	Economy	48800.00
0005433460446	19907	Economy	48800.00
0005433462769	19907	Economy	48800.00
0005433460436	19907	Economy	48800.00
0005433460458	19907	Economy	48800.00
0005433462758	19907	Economy	48800.00
0005433462755	19907	Economy	48800.00
0005433462745	19907	Economy	48800.00
0005433460435	19907	Economy	48800.00
0005433462770	19907	Economy	48800.00
0005433462759	19907	Economy	48800.00
0005433460459	19907	Economy	48800.00
0005433462767	19907	Economy	48800.00
0005433462761	19907	Economy	48800.00
0005433460451	19907	Economy	48800.00
0005433462760	19907	Economy	48800.00
0005433462763	19907	Economy	48800.00
0005433462771	19907	Economy	48800.00
0005433462766	19907	Economy	48800.00
0005433462746	19907	Economy	48800.00
0005433462762	19907	Economy	48800.00
0005433460447	19907	Economy	48800.00
0005433460450	19907	Economy	48800.00
0005433460445	19907	Economy	48800.00
0005433462764	19907	Economy	48800.00
0005433460434	19907	Economy	48800.00
0005433460452	19907	Economy	48800.00
0005435104095	23027	Business	15700.00
0005433285701	23027	Business	15700.00
0005435104098	23027	Business	15700.00
0005435104099	23027	Economy	5200.00
0005435104094	23027	Economy	5200.00
0005433285666	23027	Economy	5200.00
0005435104100	23027	Economy	5200.00
0005433285695	23027	Economy	5200.00
0005433285614	23027	Economy	5200.00
0005433285737	23027	Economy	5200.00
0005433285537	23027	Economy	5200.00
0005435104103	23027	Economy	5200.00
0005433285538	23027	Economy	5200.00
0005435104096	23027	Economy	5200.00
0005433285698	23027	Economy	5200.00
0005433285618	23027	Economy	5200.00
0005435104102	23027	Economy	5700.00
0005433285675	23027	Economy	5700.00
0005433285729	23027	Economy	5700.00
0005433285615	23027	Economy	5200.00
0005433285724	23027	Economy	5200.00
0005433285658	23027	Economy	5200.00
0005433285647	23027	Economy	5200.00
0005433285553	23027	Economy	5200.00
0005433285659	23027	Economy	5200.00
0005433285617	23027	Economy	5200.00
0005433285641	23027	Economy	5200.00
0005435104107	23027	Economy	5200.00
0005433285640	23027	Economy	5200.00
0005435104097	23027	Economy	5200.00
0005433285660	23027	Economy	5200.00
0005433285702	23027	Economy	5200.00
0005433285731	23027	Economy	5200.00
0005433285792	23027	Economy	5200.00
0005435104106	23027	Economy	5200.00
0005433285696	23027	Economy	5200.00
0005435104092	23027	Economy	5200.00
0005433285686	23027	Economy	5200.00
0005433285544	23027	Economy	5200.00
0005433285721	23027	Economy	5200.00
0005435104105	23027	Economy	5200.00
0005435104101	23027	Economy	5200.00
0005433285685	23027	Economy	5200.00
0005433285646	23027	Economy	5200.00
0005435104104	23027	Economy	5200.00
0005435104093	23027	Economy	5200.00
0005435103993	32086	Business	15700.00
0005433285956	32086	Business	15700.00
0005433285962	32086	Business	15700.00
0005433285933	32086	Business	15700.00
0005433285949	32086	Economy	5200.00
0005433285947	32086	Economy	5200.00
0005435103984	32086	Economy	5200.00
0005433285959	32086	Economy	5200.00
0005433285943	32086	Economy	5200.00
0005435103995	32086	Economy	5200.00
0005433285948	32086	Economy	5200.00
0005433285938	32086	Economy	5200.00
0005433285935	32086	Economy	5200.00
0005435103990	32086	Economy	5200.00
0005433285961	32086	Economy	5200.00
0005433285952	32086	Economy	5700.00
0005433285934	32086	Economy	5700.00
0005433285957	32086	Economy	5700.00
0005435103982	32086	Economy	5200.00
0005433285953	32086	Economy	5200.00
0005433285945	32086	Economy	5200.00
0005433285937	32086	Economy	5200.00
0005433285940	32086	Economy	5200.00
0005433285932	32086	Economy	5200.00
0005433285942	32086	Economy	5200.00
0005433285954	32086	Economy	5200.00
0005433285951	32086	Economy	5200.00
0005435103980	32086	Economy	5200.00
0005435103996	32086	Economy	5200.00
0005433285944	32086	Economy	5200.00
0005433285950	32086	Economy	5200.00
0005433285941	32086	Economy	5200.00
0005433285960	32086	Economy	5200.00
0005433285939	32086	Economy	5200.00
0005435103985	32086	Economy	5200.00
0005433285946	32086	Economy	5200.00
0005433285958	32086	Economy	5200.00
0005433285955	32086	Economy	5200.00
0005435103989	32086	Economy	5200.00
0005433285936	32086	Economy	5200.00
0005435103986	32086	Economy	5200.00
0005432892804	19946	Business	150400.00
0005432802556	19946	Business	150400.00
0005432802555	19946	Business	150400.00
0005432802560	19946	Business	150400.00
0005433112407	19946	Business	150400.00
0005432802542	19946	Business	150400.00
0005433112400	19946	Business	150400.00
0005432802513	19946	Business	150400.00
0005433111546	19946	Business	150400.00
0005432802524	19946	Business	150400.00
0005432802543	19946	Business	150400.00
0005432802561	19946	Business	150400.00
0005432802511	19946	Business	150400.00
0005432802508	19946	Business	150400.00
0005432802546	19946	Business	150400.00
0005433112403	19946	Business	150400.00
0005432802540	19946	Economy	50100.00
0005433112393	19946	Economy	50100.00
0005433111548	19946	Economy	50100.00
0005432802507	19946	Economy	50100.00
0005433111539	19946	Economy	50100.00
0005432892807	19946	Economy	50100.00
0005433112401	19946	Economy	50100.00
0005433112399	19946	Economy	50100.00
0005433112402	19946	Economy	50100.00
0005432802510	19946	Economy	50100.00
0005432892805	19946	Economy	55200.00
0005433112395	19946	Economy	55200.00
0005432892800	19946	Economy	55200.00
0005432892793	19946	Economy	50100.00
0005433111541	19946	Economy	50100.00
0005433111550	19946	Economy	50100.00
0005433111540	19946	Economy	50100.00
0005432892797	19946	Economy	50100.00
0005432802523	19946	Economy	50100.00
0005432892798	19946	Economy	50100.00
0005432802537	19946	Economy	50100.00
0005433111549	19946	Economy	50100.00
0005432892803	19946	Economy	50100.00
0005432802509	19946	Economy	50100.00
0005432892808	19946	Economy	50100.00
0005433111544	19946	Economy	50100.00
0005432892796	19946	Economy	50100.00
0005432802531	19946	Economy	50100.00
0005433111535	19946	Economy	50100.00
0005433112405	19946	Economy	50100.00
0005432892794	19946	Economy	50100.00
0005432892801	19946	Economy	50100.00
0005433112404	19946	Economy	50100.00
0005433112394	19946	Economy	50100.00
0005432802553	19946	Economy	50100.00
0005432802501	19946	Economy	50100.00
0005432892809	19946	Economy	50100.00
0005432802533	19946	Economy	50100.00
0005432802503	19946	Economy	50100.00
0005432802539	19946	Economy	50100.00
0005432802512	19946	Economy	50100.00
0005433111536	19946	Economy	50100.00
0005433111543	19946	Economy	50100.00
0005433112406	19946	Economy	50100.00
0005433112396	19946	Economy	50100.00
0005433111547	19946	Economy	50100.00
0005432892799	19946	Economy	50100.00
0005432892806	19946	Economy	50100.00
0005432802519	19946	Economy	50100.00
0005433111542	19946	Economy	50100.00
0005432802554	19946	Economy	50100.00
0005433112398	19946	Economy	50100.00
0005432892802	19946	Economy	50100.00
0005432802504	19946	Economy	50100.00
0005433112397	19946	Economy	50100.00
0005432802505	19946	Economy	50100.00
0005432802520	19946	Economy	50100.00
0005432802544	19946	Economy	50100.00
0005432802532	19946	Economy	50100.00
0005432802559	19946	Economy	50100.00
0005433111537	19946	Economy	50100.00
0005432802506	19946	Economy	50100.00
0005433111545	19946	Economy	50100.00
0005433111538	19946	Economy	50100.00
0005432892795	19946	Economy	50100.00
0005432802562	19946	Economy	50100.00
0005432529519	30597	Business	42100.00
0005435283435	30597	Business	42100.00
0005432529461	30597	Business	42100.00
0005432211661	30597	Business	42100.00
0005434068101	30597	Business	42100.00
0005435215020	30597	Business	42100.00
0005434067999	30597	Business	42100.00
0005435215003	30597	Business	42100.00
0005432159956	30597	Business	42100.00
0005434068480	30597	Business	42100.00
0005432529783	30597	Business	42100.00
0005432529632	30597	Business	42100.00
0005432529715	30597	Business	42100.00
0005434068481	30597	Business	42100.00
0005432529661	30597	Business	42100.00
0005435631033	30597	Business	42100.00
0005434067895	30597	Business	42100.00
0005435214997	30597	Business	42100.00
0005435214980	30597	Business	42100.00
0005432529894	30597	Business	42100.00
0005434068584	30597	Business	42100.00
0005435214978	30597	Business	42100.00
0005432529589	30597	Business	42100.00
0005435283437	30597	Business	42100.00
0005435215027	30597	Comfort	23900.00
0005435725706	30597	Comfort	23900.00
0005434068440	30597	Comfort	23900.00
0005432529992	30597	Comfort	23900.00
0005432211660	30597	Comfort	23900.00
0005432530247	30597	Comfort	23900.00
0005435214982	30597	Comfort	23900.00
0005432530069	30597	Comfort	23900.00
0005432529912	30597	Comfort	23900.00
0005432529590	30597	Comfort	23900.00
0005435283436	30597	Comfort	23900.00
0005432529797	30597	Comfort	23900.00
0005435631034	30597	Comfort	23900.00
0005434068438	30597	Comfort	23900.00
0005432529460	30597	Comfort	23900.00
0005432159957	30597	Comfort	23900.00
0005435215029	30597	Comfort	23900.00
0005435214998	30597	Comfort	23900.00
0005432529875	30597	Comfort	23900.00
0005432529190	30597	Comfort	23900.00
0005432530062	30597	Comfort	23900.00
0005432529537	30597	Comfort	23900.00
0005432529908	30597	Comfort	23900.00
0005435215010	30597	Comfort	23900.00
0005432529707	30597	Comfort	23900.00
0005434068335	30597	Comfort	23900.00
0005434068528	30597	Comfort	23900.00
0005432529896	30597	Comfort	23900.00
0005435215002	30597	Comfort	23900.00
0005432211659	30597	Comfort	23900.00
0005432529714	30597	Comfort	23900.00
0005435215030	30597	Comfort	23900.00
0005434068508	30597	Comfort	23900.00
0005432529934	30597	Comfort	23900.00
0005435725709	30597	Comfort	23900.00
0005434068285	30597	Comfort	23900.00
0005432529951	30597	Economy	14000.00
0005435215011	30597	Economy	14000.00
0005434068827	30597	Economy	14000.00
0005432529913	30597	Economy	14000.00
0005434068497	30597	Economy	14000.00
0005435283427	30597	Economy	14000.00
0005432529716	30597	Economy	14000.00
0005432529638	30597	Economy	14000.00
0005432529777	30597	Economy	14000.00
0005432211664	30597	Economy	14000.00
0005432529471	30597	Economy	14000.00
0005432159958	30597	Economy	14000.00
0005435214990	30597	Economy	14000.00
0005434068308	30597	Economy	14000.00
0005432529029	30597	Economy	14000.00
0005432529835	30597	Economy	14000.00
0005435215009	30597	Economy	14000.00
0005435214994	30597	Economy	14000.00
0005432529838	30597	Economy	14000.00
0005434068439	30597	Economy	14000.00
0005432530173	30597	Economy	14000.00
0005432530125	30597	Economy	14000.00
0005432529462	30597	Economy	14000.00
0005435725705	30597	Economy	14000.00
0005435725704	30597	Economy	14000.00
0005432529578	30597	Economy	14000.00
0005432530219	30597	Economy	14000.00
0005435214981	30597	Economy	14000.00
0005434068173	30597	Economy	14000.00
0005432529051	30597	Economy	14000.00
0005432530044	30597	Economy	14000.00
0005432530172	30597	Economy	14000.00
0005432159955	30597	Economy	14000.00
0005435214989	30597	Economy	14000.00
0005432529550	30597	Economy	14000.00
0005434068333	30597	Economy	14000.00
0005435215024	30597	Economy	14000.00
0005434068507	30597	Economy	14000.00
0005432529903	30597	Economy	14000.00
0005432530220	30597	Economy	14000.00
0005432529667	30597	Economy	14000.00
0005432529902	30597	Economy	14000.00
0005434068583	30597	Economy	14000.00
0005432530002	30597	Economy	14000.00
0005432535885	30597	Economy	14000.00
0005434068174	30597	Economy	14000.00
0005432529662	30597	Economy	14000.00
0005432535886	30597	Economy	14000.00
0005432529700	30597	Economy	14000.00
0005435215005	30597	Economy	14000.00
0005435215025	30597	Economy	14000.00
0005435283432	30597	Economy	14000.00
0005434068392	30597	Economy	14000.00
0005434068423	30597	Economy	14000.00
0005434068684	30597	Economy	14000.00
0005434068156	30597	Economy	14000.00
0005434068379	30597	Economy	15400.00
0005434068637	30597	Economy	15400.00
0005432529493	30597	Economy	14000.00
0005435214986	30597	Economy	15400.00
0005435215006	30597	Economy	15400.00
0005432529286	30597	Economy	14000.00
0005432530421	30597	Economy	15400.00
0005435214975	30597	Economy	14000.00
0005432529956	30597	Economy	14000.00
0005432529649	30597	Economy	14000.00
0005435214995	30597	Economy	14000.00
0005432529604	30597	Economy	14000.00
0005434068470	30597	Economy	14000.00
0005432159954	30597	Economy	14000.00
0005435215028	30597	Economy	14000.00
0005434068351	30597	Economy	14000.00
0005432529470	30597	Economy	14000.00
0005434068373	30597	Economy	14000.00
0005435283439	30597	Economy	14000.00
0005432529851	30597	Economy	14000.00
0005432530512	30597	Economy	14000.00
0005432537085	30597	Economy	14000.00
0005432529400	30597	Economy	14000.00
0005435214967	30597	Economy	14000.00
0005435283438	30597	Economy	14000.00
0005435214999	30597	Economy	14000.00
0005432529830	30597	Economy	14000.00
0005434068395	30597	Economy	14000.00
0005432529246	30597	Economy	14000.00
0005435215031	30597	Economy	14000.00
0005432529955	30597	Economy	14000.00
0005435214971	30597	Economy	14000.00
0005435215023	30597	Economy	14000.00
0005434068492	30597	Economy	14000.00
0005432529906	30597	Economy	14000.00
0005435214988	30597	Economy	14000.00
0005432529545	30597	Economy	14000.00
0005434068334	30597	Economy	14000.00
0005432530003	30597	Economy	14000.00
0005432211658	30597	Economy	14000.00
0005432529552	30597	Economy	14000.00
0005435215026	30597	Economy	14000.00
0005434068323	30597	Economy	14000.00
0005435283431	30597	Economy	14000.00
0005433656744	30597	Economy	14000.00
0005432529289	30597	Economy	14000.00
0005435214972	30597	Economy	14000.00
0005432530083	30597	Economy	14000.00
0005432530094	30597	Economy	14000.00
0005434068413	30597	Economy	14000.00
0005434068456	30597	Economy	14000.00
0005435283429	30597	Economy	14000.00
0005432530121	30597	Economy	14000.00
0005435214968	30597	Economy	14000.00
0005434068372	30597	Economy	14000.00
0005432211665	30597	Economy	14000.00
0005432533329	30597	Economy	14000.00
0005432530366	30597	Economy	14000.00
0005432529708	30597	Economy	14000.00
0005432529535	30597	Economy	14000.00
0005432529832	30597	Economy	14000.00
0005432211663	30597	Economy	14000.00
0005432529392	30597	Economy	14000.00
0005432529126	30597	Economy	14000.00
0005435214991	30597	Economy	14000.00
0005432529650	30597	Economy	14000.00
0005435215004	30597	Economy	14000.00
0005432530399	30597	Economy	14000.00
0005435214984	30597	Economy	14000.00
0005435631032	30597	Economy	14000.00
0005432529782	30597	Economy	14000.00
0005432529287	30597	Economy	14000.00
0005432529421	30597	Economy	14000.00
0005435214979	30597	Economy	14000.00
0005432529524	30597	Economy	14000.00
0005432529222	30597	Economy	14000.00
0005435215014	30597	Economy	14000.00
0005432529991	30597	Economy	14000.00
0005432529422	30597	Economy	14000.00
0005432529439	30597	Economy	14000.00
0005434068515	30597	Economy	14000.00
0005432529648	30597	Economy	14000.00
0005432529831	30597	Economy	14000.00
0005434068104	30597	Economy	14000.00
0005432529404	30597	Economy	14000.00
0005432535881	30597	Economy	14000.00
0005434068495	30597	Economy	14000.00
0005434068071	30597	Economy	14000.00
0005435215007	30597	Economy	14000.00
0005434068258	30597	Economy	14000.00
0005432529737	30597	Economy	14000.00
0005432529577	30597	Economy	14000.00
0005435214965	30597	Economy	14000.00
0005432529629	30597	Economy	14000.00
0005432529668	30597	Economy	14000.00
0005432529760	30597	Economy	14000.00
0005432529187	30597	Economy	14000.00
0005435214996	30597	Economy	14000.00
0005435214977	30597	Economy	14000.00
0005434068509	30597	Economy	14000.00
0005434068382	30597	Economy	14000.00
0005435283428	30597	Economy	14000.00
0005432537086	30597	Economy	14000.00
0005432529308	30597	Economy	15400.00
0005435215012	30597	Economy	15400.00
0005435725707	30597	Economy	15400.00
0005434068514	30597	Economy	15400.00
0005435215001	30597	Economy	14000.00
0005432529839	30597	Economy	14000.00
0005432529528	30597	Economy	14000.00
0005432529538	30597	Economy	14000.00
0005432530029	30597	Economy	14000.00
0005432529556	30597	Economy	14000.00
0005432529329	30597	Economy	14000.00
0005435215019	30597	Economy	14000.00
0005432529288	30597	Economy	14000.00
0005435283430	30597	Economy	14000.00
0005432530154	30597	Economy	14000.00
0005435215018	30597	Economy	14000.00
0005432533330	30597	Economy	14000.00
0005432529954	30597	Economy	14000.00
0005434068777	30597	Economy	14000.00
0005432529507	30597	Economy	14000.00
0005435214969	30597	Economy	14000.00
0005435214966	30597	Economy	14000.00
0005434068482	30597	Economy	14000.00
0005432529654	30597	Economy	14000.00
0005432529189	30597	Economy	14000.00
0005434068500	30597	Economy	14000.00
0005434068703	30597	Economy	14000.00
0005432428981	30597	Economy	14000.00
0005432529895	30597	Economy	14000.00
0005432529546	30597	Economy	14000.00
0005432529520	30597	Economy	14000.00
0005432529665	30597	Economy	14000.00
0005435214985	30597	Economy	14000.00
0005432530120	30597	Economy	14000.00
0005432529303	30597	Economy	14000.00
0005432211662	30597	Economy	14000.00
0005432529664	30597	Economy	14000.00
0005435214993	30597	Economy	14000.00
0005435214987	30597	Economy	14000.00
0005435283433	30597	Economy	14000.00
0005432529776	30597	Economy	14000.00
0005432529663	30597	Economy	14000.00
0005435214983	30597	Economy	14000.00
0005435214973	30597	Economy	14000.00
0005432529290	30597	Economy	14000.00
0005435215022	30597	Economy	14000.00
0005432529699	30597	Economy	14000.00
0005432529744	30597	Economy	14000.00
0005432530035	30597	Economy	14000.00
0005432529588	30597	Economy	14000.00
0005435214970	30597	Economy	14000.00
0005432529657	30597	Economy	14000.00
0005435283434	30597	Economy	14000.00
0005432529591	30597	Economy	14000.00
0005432529223	30597	Economy	14000.00
0005432428983	30597	Economy	14000.00
0005432529558	30597	Economy	14000.00
0005434068272	30597	Economy	14000.00
0005434068496	30597	Economy	14000.00
0005432530400	30597	Economy	14000.00
0005434068256	30597	Economy	14000.00
0005432529381	30597	Economy	14000.00
0005435215017	30597	Economy	14000.00
0005435215013	30597	Economy	14000.00
0005434068267	30597	Economy	14000.00
0005434068257	30597	Economy	14000.00
0005432530018	30597	Economy	14000.00
0005435215008	30597	Economy	14000.00
0005432529305	30597	Economy	14000.00
0005434068501	30597	Economy	14000.00
0005432529319	30597	Economy	14000.00
0005432529739	30597	Economy	14000.00
0005434068286	30597	Economy	14000.00
0005434068322	30597	Economy	14000.00
0005435215000	30597	Economy	14000.00
0005432535880	30597	Economy	14000.00
0005435215016	30597	Economy	14000.00
0005434068412	30597	Economy	14000.00
0005432529973	30597	Economy	14000.00
0005432529933	30597	Economy	14000.00
0005432529621	30597	Economy	14000.00
0005435215021	30597	Economy	14000.00
0005435725703	30597	Economy	14000.00
0005432529862	30597	Economy	14000.00
0005432530063	30597	Economy	14000.00
0005434068356	30597	Economy	14000.00
0005434068212	30597	Economy	14000.00
0005435725708	30597	Economy	14000.00
0005432529328	30597	Economy	14000.00
0005432529490	30597	Economy	14000.00
0005432530093	30597	Economy	14000.00
0005435214992	30597	Economy	14000.00
0005435215015	30597	Economy	14000.00
0005435214974	30597	Economy	14000.00
0005432529280	30597	Economy	14000.00
0005434068683	30597	Economy	14000.00
0005435214976	30597	Economy	14000.00
0005432529508	30597	Economy	14000.00
0005432530001	30597	Economy	14000.00
0005432529210	30597	Economy	14000.00
0005432529658	30597	Economy	14000.00
0005434068081	30597	Economy	14000.00
0005433368710	24830	Business	9800.00
0005433368712	24830	Business	9800.00
0005435653619	24830	Business	9800.00
0005433368709	24830	Business	9800.00
0005433368695	24830	Business	9800.00
0005433368699	24830	Business	9800.00
0005433368679	24830	Business	9800.00
0005435653582	24830	Business	9800.00
0005435653602	24830	Business	9800.00
0005433368706	24830	Business	9800.00
0005435653646	24830	Business	9800.00
0005435653618	24830	Economy	3300.00
0005433368711	24830	Economy	3300.00
0005435653554	24830	Economy	3300.00
0005433368696	24830	Economy	3300.00
0005435653479	24830	Economy	3300.00
0005435653399	24830	Economy	3300.00
0005433368678	24830	Economy	3300.00
0005435653712	24830	Economy	3300.00
0005435653569	24830	Economy	3300.00
0005435653567	24830	Economy	3300.00
0005435653562	24830	Economy	3600.00
0005435653491	24830	Economy	3600.00
0005433368703	24830	Economy	3600.00
0005435653663	24830	Economy	3600.00
0005433368681	24830	Economy	3300.00
0005433368692	24830	Economy	3300.00
0005435653624	24830	Economy	3300.00
0005435653584	24830	Economy	3300.00
0005435653669	24830	Economy	3300.00
0005433368685	24830	Economy	3300.00
0005435653344	24830	Economy	3300.00
0005433368689	24830	Economy	3300.00
0005433368687	24830	Economy	3300.00
0005433368691	24830	Economy	3300.00
0005435653679	24830	Economy	3300.00
0005433368694	24830	Economy	3300.00
0005435653643	24830	Economy	3300.00
0005433368702	24830	Economy	3300.00
0005435653677	24830	Economy	3300.00
0005433368680	24830	Economy	3300.00
0005433368683	24830	Economy	3300.00
0005433368688	24830	Economy	3300.00
0005433368713	24830	Economy	3300.00
0005433368684	24830	Economy	3300.00
0005435653568	24830	Economy	3300.00
0005435653581	24830	Economy	3300.00
0005435653711	24830	Economy	3300.00
0005435653574	24830	Economy	3300.00
0005435653592	24830	Economy	3300.00
0005435653639	24830	Economy	3300.00
0005433368686	24830	Economy	3300.00
0005435653391	24830	Economy	3300.00
0005435653668	24830	Economy	3300.00
0005435653580	24830	Economy	3300.00
0005433368682	24830	Economy	3300.00
0005435653697	24830	Economy	3300.00
0005433368707	24830	Economy	3300.00
0005435653662	24830	Economy	3300.00
0005435653566	24830	Economy	3300.00
0005435653552	24830	Economy	3300.00
0005433368697	24830	Economy	3300.00
0005433368708	24830	Economy	3300.00
0005435653678	24830	Economy	3300.00
0005435653645	24830	Economy	3300.00
0005435653631	24830	Economy	3300.00
0005433368690	24830	Economy	3300.00
0005433368700	24830	Economy	3300.00
0005435653680	24830	Economy	3300.00
0005435653398	24830	Economy	3300.00
0005435653553	24830	Economy	3300.00
0005433368705	24830	Economy	3300.00
0005435653629	24830	Economy	3300.00
0005435653625	24830	Economy	3300.00
0005435653601	24830	Economy	3300.00
0005433368704	24830	Economy	3300.00
0005433368701	24830	Economy	3300.00
0005433368698	24830	Economy	3300.00
0005435653628	24830	Economy	3300.00
0005433368693	24830	Economy	3300.00
0005435949837	6598	Economy	20600.00
0005435949836	6598	Economy	18700.00
0005435949838	6598	Economy	18700.00
0005435949844	6598	Economy	18700.00
0005435949840	6598	Economy	18700.00
0005435949843	6598	Economy	18700.00
0005435949842	6598	Economy	18700.00
0005435949841	6598	Economy	18700.00
0005435949834	6598	Economy	18700.00
0005435949833	6598	Economy	18700.00
0005435949835	6598	Economy	18700.00
0005435949839	6598	Economy	18700.00
0005434980433	2066	Economy	10500.00
0005434980428	2066	Economy	10500.00
0005434980448	2066	Economy	10500.00
0005434980422	2066	Economy	9500.00
0005434980432	2066	Economy	9500.00
0005434980452	2066	Economy	9500.00
0005434980427	2066	Economy	9500.00
0005434980440	2066	Economy	9500.00
0005434980425	2066	Economy	9500.00
0005434980438	2066	Economy	9500.00
0005434980447	2066	Economy	9500.00
0005434980442	2066	Economy	9500.00
0005434980437	2066	Economy	9500.00
0005434980429	2066	Economy	9500.00
0005434980435	2066	Economy	9500.00
0005434980443	2066	Economy	9500.00
0005435801760	2066	Economy	9500.00
0005435801763	2066	Economy	9500.00
0005434980449	2066	Economy	9500.00
0005434980445	2066	Economy	9500.00
0005434980446	2066	Economy	9500.00
0005434980431	2066	Economy	9500.00
0005434980450	2066	Economy	9500.00
0005435801764	2066	Economy	9500.00
0005434980436	2066	Economy	9500.00
0005434980444	2066	Economy	9500.00
0005434980441	2066	Economy	9500.00
0005435801761	2066	Economy	9500.00
0005434980421	2066	Economy	9500.00
0005435801762	2066	Economy	9500.00
0005434980434	2066	Economy	9500.00
0005434980430	2066	Economy	9500.00
0005434980423	2066	Economy	9500.00
0005434980439	2066	Economy	9500.00
0005434980451	2066	Economy	9500.00
0005434980426	2066	Economy	9500.00
0005434980424	2066	Economy	9500.00
0005434980106	23548	Economy	10500.00
0005434979999	23548	Economy	10500.00
0005435801733	23548	Economy	10500.00
0005434979859	23548	Economy	9500.00
0005434980129	23548	Economy	9500.00
0005434980105	23548	Economy	9500.00
0005435801741	23548	Economy	9500.00
0005434980174	23548	Economy	9500.00
0005435801742	23548	Economy	9500.00
0005434980180	23548	Economy	9500.00
0005434980058	23548	Economy	9500.00
0005434980110	23548	Economy	9500.00
0005434980043	23548	Economy	9500.00
0005434980042	23548	Economy	9500.00
0005434980037	23548	Economy	9500.00
0005434980173	23548	Economy	9500.00
0005434980118	23548	Economy	9500.00
0005435801717	23548	Economy	9500.00
0005435801716	23548	Economy	9500.00
0005434980071	23548	Economy	9500.00
0005434980041	23548	Economy	9500.00
0005434980151	23548	Economy	9500.00
0005434980057	23548	Economy	9500.00
0005434980093	23548	Economy	9500.00
0005434979998	23548	Economy	9500.00
0005434980024	23548	Economy	9500.00
0005434980111	23548	Economy	9500.00
0005434980081	23548	Economy	9500.00
0005434980099	23548	Economy	9500.00
0005434980179	23548	Economy	9500.00
0005435801730	23548	Economy	9500.00
0005434980152	23548	Economy	9500.00
0005434980003	23548	Economy	9500.00
0005434980143	23548	Economy	9500.00
0005434952612	2653	Economy	5300.00
0005434952611	2653	Economy	5300.00
0005434952613	2653	Economy	5300.00
0005434952610	2653	Economy	5300.00
0005433256454	2654	Economy	5300.00
0005433256456	2654	Economy	5300.00
0005433256453	2654	Economy	5300.00
0005434952590	28295	Economy	5300.00
0005434952563	28295	Economy	5300.00
0005434952574	28295	Economy	5300.00
0005434952569	28295	Economy	5300.00
0005434952601	28295	Economy	5300.00
0005434952562	28295	Economy	5300.00
0005433111554	19821	Economy	8700.00
0005433112412	19821	Economy	8700.00
0005434139097	11966	Business	9700.00
0005434139192	11966	Business	9700.00
0005434139249	11966	Business	9700.00
0005434139120	11966	Business	9700.00
0005434139362	11966	Business	9700.00
0005434139088	11966	Business	9700.00
0005434139532	11966	Business	9700.00
0005434139505	11966	Business	9700.00
0005434138855	11966	Business	9700.00
0005434139276	11966	Business	9700.00
0005434139576	11966	Business	9700.00
0005434138923	11966	Business	9700.00
0005434139387	11966	Economy	3200.00
0005434139292	11966	Economy	3200.00
0005434139048	11966	Economy	3200.00
0005434139268	11966	Economy	3200.00
0005434139263	11966	Economy	3200.00
0005434139267	11966	Economy	3200.00
0005434139251	11966	Economy	3200.00
0005434139128	11966	Economy	3200.00
0005434139089	11966	Economy	3200.00
0005434139341	11966	Economy	3500.00
0005434139064	11966	Economy	3500.00
0005434139361	11966	Economy	3500.00
0005434139098	11966	Economy	3200.00
0005434138925	11966	Economy	3200.00
0005434139150	11966	Economy	3200.00
0005434139577	11966	Economy	3200.00
0005434139157	11966	Economy	3200.00
0005434138885	11966	Economy	3200.00
0005434139209	11966	Economy	3200.00
0005434139200	11966	Economy	3200.00
0005434139019	11966	Economy	3200.00
0005434139260	11966	Economy	3200.00
0005434139228	11966	Economy	3200.00
0005434139394	11966	Economy	3200.00
0005434139212	11966	Economy	3200.00
0005434139144	11966	Economy	3200.00
0005434139141	11966	Economy	3200.00
0005434139271	11966	Economy	3200.00
0005434139083	11966	Economy	3200.00
0005434139506	11966	Economy	3200.00
0005434139483	11966	Economy	3200.00
0005434139277	11966	Economy	3200.00
0005434139424	11966	Economy	3200.00
0005434139129	11966	Economy	3200.00
0005434139082	11966	Economy	3200.00
0005434138949	11966	Economy	3200.00
0005434139367	11966	Economy	3200.00
0005434139347	11966	Economy	3200.00
0005434139227	11966	Economy	3200.00
0005434139360	11966	Economy	3200.00
0005434139156	11966	Economy	3200.00
0005434138880	11966	Economy	3200.00
0005434139248	11966	Economy	3200.00
0005434139400	11966	Economy	3200.00
0005434139375	11966	Economy	3200.00
0005434139442	11966	Economy	3200.00
0005434139142	11966	Economy	3200.00
0005434139578	11966	Economy	3200.00
0005434139105	11966	Economy	3200.00
0005434139425	11966	Economy	3200.00
0005434138932	11966	Economy	3200.00
0005434139250	11966	Economy	3200.00
0005434139443	11966	Economy	3200.00
0005434139311	11966	Economy	3200.00
0005434139261	11966	Economy	3200.00
0005434139317	11966	Economy	3200.00
0005434139272	11966	Economy	3200.00
0005434139143	11966	Economy	3200.00
0005434138884	11966	Economy	3200.00
0005434139167	11966	Economy	3200.00
0005434139214	11966	Economy	3200.00
0005434139193	11966	Economy	3200.00
0005434139208	11966	Economy	3200.00
0005434139119	11966	Economy	3200.00
0005434139349	11966	Economy	3200.00
0005434139081	11966	Economy	3200.00
0005434139553	11966	Economy	3200.00
0005434138924	11966	Economy	3200.00
0005434139340	11966	Economy	3200.00
0005434139287	11966	Economy	3200.00
0005434139274	11966	Economy	3200.00
0005434139264	11966	Economy	3200.00
0005434139053	11966	Economy	3200.00
0005434139131	11966	Economy	3200.00
0005434139376	11966	Economy	3200.00
0005434139848	28732	Business	9700.00
0005434139859	28732	Business	9700.00
0005434139823	28732	Business	9700.00
0005434139783	28732	Business	9700.00
0005434139796	28732	Business	9700.00
0005434139798	28732	Business	9700.00
0005434139825	28732	Business	9700.00
0005434139792	28732	Business	9700.00
0005434139794	28732	Business	9700.00
0005434139854	28732	Business	9700.00
0005434139834	28732	Business	9700.00
0005434139858	28732	Economy	3200.00
0005434139804	28732	Economy	3200.00
0005434139790	28732	Economy	3200.00
0005434139831	28732	Economy	3200.00
0005434139857	28732	Economy	3200.00
0005434139849	28732	Economy	3200.00
0005434139847	28732	Economy	3200.00
0005434139839	28732	Economy	3200.00
0005434139776	28732	Economy	3200.00
0005434139820	28732	Economy	3200.00
0005434139813	28732	Economy	3500.00
0005434139809	28732	Economy	3500.00
0005434139797	28732	Economy	3500.00
0005434139853	28732	Economy	3500.00
0005434139805	28732	Economy	3500.00
0005434139844	28732	Economy	3200.00
0005434139863	28732	Economy	3200.00
0005434139861	28732	Economy	3200.00
0005434139832	28732	Economy	3200.00
0005434139833	28732	Economy	3200.00
0005434139799	28732	Economy	3200.00
0005434139850	28732	Economy	3200.00
0005434139815	28732	Economy	3200.00
0005434139817	28732	Economy	3200.00
0005434139828	28732	Economy	3200.00
0005434139842	28732	Economy	3200.00
0005434139777	28732	Economy	3200.00
0005434139837	28732	Economy	3200.00
0005434139778	28732	Economy	3200.00
0005434139784	28732	Economy	3200.00
0005434139801	28732	Economy	3200.00
0005434139862	28732	Economy	3200.00
0005434139841	28732	Economy	3200.00
0005434139786	28732	Economy	3200.00
0005434139846	28732	Economy	3200.00
0005434139852	28732	Economy	3200.00
0005434139791	28732	Economy	3200.00
0005434139793	28732	Economy	3200.00
0005434139864	28732	Economy	3200.00
0005434139845	28732	Economy	3200.00
0005434139795	28732	Economy	3200.00
0005434139818	28732	Economy	3200.00
0005434139855	28732	Economy	3200.00
0005434139806	28732	Economy	3200.00
0005434139789	28732	Economy	3200.00
0005434139826	28732	Economy	3200.00
0005434139843	28732	Economy	3200.00
0005434139807	28732	Economy	3200.00
0005434139800	28732	Economy	3200.00
0005434139821	28732	Economy	3200.00
0005434139810	28732	Economy	3200.00
0005434139779	28732	Economy	3200.00
0005434139835	28732	Economy	3200.00
0005434139781	28732	Economy	3200.00
0005434139822	28732	Economy	3200.00
0005434139840	28732	Economy	3200.00
0005434139838	28732	Economy	3200.00
0005434139788	28732	Economy	3200.00
0005434139860	28732	Economy	3200.00
0005434139827	28732	Economy	3200.00
0005434139829	28732	Economy	3200.00
0005434139808	28732	Economy	3200.00
0005434139811	28732	Economy	3200.00
0005434139819	28732	Economy	3200.00
0005434139816	28732	Economy	3200.00
0005434139775	28732	Economy	3200.00
0005434139802	28732	Economy	3200.00
0005434139787	28732	Economy	3200.00
0005434139814	28732	Economy	3200.00
0005434139803	28732	Economy	3200.00
0005434139856	28732	Economy	3200.00
0005434139782	28732	Economy	3200.00
0005434139851	28732	Economy	3200.00
0005434139812	28732	Economy	3200.00
0005434139836	28732	Economy	3200.00
0005434139785	28732	Economy	3200.00
0005434139824	28732	Economy	3200.00
0005434139780	28732	Economy	3200.00
0005434139830	28732	Economy	3200.00
0005433539058	6776	Economy	10900.00
0005433539055	6776	Economy	9900.00
0005433539059	6776	Economy	9900.00
0005433539057	6776	Economy	9900.00
0005433539053	6776	Economy	9900.00
0005433534544	6776	Economy	9900.00
0005435259803	6776	Economy	9900.00
0005433539054	6776	Economy	9900.00
0005433539056	6776	Economy	9900.00
0005433539052	6776	Economy	9900.00
0005433539051	6776	Economy	9900.00
0005433534545	6776	Economy	9900.00
0005433538982	24992	Economy	9900.00
0005433538962	24992	Economy	9900.00
0005435259850	24992	Economy	9900.00
0005433538991	24992	Economy	9900.00
0005435259851	24992	Economy	9900.00
0005435259852	24992	Economy	9900.00
0005433538974	24992	Economy	9900.00
0005435259853	24992	Economy	9900.00
0005433538961	24992	Economy	9900.00
0005433534524	24992	Economy	9900.00
0005433534533	24992	Economy	9900.00
0005433534532	24992	Economy	9900.00
0005433538978	24992	Economy	9900.00
0005433534525	24992	Economy	9900.00
0005433512137	820	Economy	14600.00
0005433512132	820	Economy	14600.00
0005433512135	820	Economy	14600.00
0005433512134	820	Economy	14600.00
0005432922589	820	Economy	14600.00
0005432922590	820	Economy	14600.00
0005433512136	820	Economy	14600.00
0005432922577	820	Economy	14600.00
0005433512138	820	Economy	14600.00
0005433512131	820	Economy	14600.00
0005432922591	820	Economy	14600.00
0005432922576	820	Economy	14600.00
0005433512133	820	Economy	14600.00
0005433512063	16122	Economy	14600.00
0005433512068	16122	Economy	14600.00
0005432922614	16122	Economy	14600.00
0005433512069	16122	Economy	14600.00
0005432922613	16122	Economy	14600.00
0005433512073	16122	Economy	14600.00
0005432922611	16122	Economy	14600.00
0005433512072	16122	Economy	14600.00
0005433512044	16122	Economy	14600.00
0005432922612	16122	Economy	14600.00
0005435697942	3689	Economy	7900.00
0005435697937	3689	Economy	7900.00
0005435697962	3689	Economy	7900.00
0005435697961	3689	Economy	7200.00
0005435697938	3689	Economy	7200.00
0005434950627	3689	Economy	7200.00
0005435916206	3689	Economy	7200.00
0005435697944	3689	Economy	7200.00
0005435697953	3689	Economy	7200.00
0005435916207	3689	Economy	7200.00
0005435935077	3689	Economy	7200.00
0005435697956	3689	Economy	7200.00
0005435697957	3689	Economy	7200.00
0005435697939	3689	Economy	7200.00
0005435697947	3689	Economy	7200.00
0005435697954	3689	Economy	7200.00
0005435697943	3689	Economy	7200.00
0005435697945	3689	Economy	7200.00
0005435697955	3689	Economy	7200.00
0005435697935	3689	Economy	7200.00
0005434950625	3689	Economy	7200.00
0005435697948	3689	Economy	7200.00
0005435697946	3689	Economy	7200.00
0005435697959	3689	Economy	7200.00
0005435697958	3689	Economy	7200.00
0005435697941	3689	Economy	7200.00
0005435697949	3689	Economy	7200.00
0005435697952	3689	Economy	7200.00
0005435697936	3689	Economy	7200.00
0005434950628	3689	Economy	7200.00
0005435697951	3689	Economy	7200.00
0005434950626	3689	Economy	7200.00
0005435697940	3689	Economy	7200.00
0005435697960	3689	Economy	7200.00
0005435697950	3689	Economy	7200.00
0005435935106	16251	Economy	7900.00
0005434950598	16251	Economy	7900.00
0005435697592	16251	Economy	7200.00
0005435697714	16251	Economy	7200.00
0005434950570	16251	Economy	7200.00
0005435697648	16251	Economy	7200.00
0005435697697	16251	Economy	7200.00
0005435935108	16251	Economy	7200.00
0005435697790	16251	Economy	7200.00
0005435916227	16251	Economy	7200.00
0005435697550	16251	Economy	7200.00
0005435697667	16251	Economy	7200.00
0005435697602	16251	Economy	7200.00
0005435697605	16251	Economy	7200.00
0005435916226	16251	Economy	7200.00
0005435697699	16251	Economy	7200.00
0005435935109	16251	Economy	7200.00
0005435697760	16251	Economy	7200.00
0005435697758	16251	Economy	7200.00
0005435697632	16251	Economy	7200.00
0005434950592	16251	Economy	7200.00
0005435916228	16251	Economy	7200.00
0005435697759	16251	Economy	7200.00
0005435916229	16251	Economy	7200.00
0005435697615	16251	Economy	7200.00
0005434950597	16251	Economy	7200.00
0005435697713	16251	Economy	7200.00
0005435697666	16251	Economy	7200.00
0005435697728	16251	Economy	7200.00
0005435697512	16251	Economy	7200.00
0005435697700	16251	Economy	7200.00
0005435697696	16251	Economy	7200.00
0005435697753	16251	Economy	7200.00
0005435697513	16251	Economy	7200.00
0005434950596	16251	Economy	7200.00
0005435935107	16251	Economy	7200.00
0005433519558	3981	Economy	21300.00
0005432607655	3981	Economy	19300.00
0005433519557	3981	Economy	19300.00
0005434604975	3981	Economy	19300.00
0005434606902	3981	Economy	19300.00
0005432607656	3981	Economy	19300.00
0005434604976	3981	Economy	19300.00
0005435842338	3981	Economy	19300.00
0005434606903	3981	Economy	19300.00
0005434606900	3981	Economy	19300.00
0005434604974	3981	Economy	19300.00
0005435842334	3981	Economy	19300.00
0005432607653	3981	Economy	19300.00
0005434606899	3981	Economy	19300.00
0005432607654	3981	Economy	19300.00
0005434604977	3981	Economy	19300.00
0005434606901	3981	Economy	19300.00
0005433519555	3981	Economy	19300.00
0005432609822	3981	Economy	19300.00
0005434604978	3981	Economy	19300.00
0005432609819	3981	Economy	19300.00
0005435842337	3981	Economy	19300.00
0005435904710	3981	Economy	19300.00
0005432609820	3981	Economy	19300.00
0005435904709	3981	Economy	19300.00
0005433519556	3981	Economy	19300.00
0005432609821	3981	Economy	19300.00
0005435853652	22071	Economy	21300.00
0005433519512	22071	Economy	19300.00
0005434606866	22071	Economy	19300.00
0005433519513	22071	Economy	19300.00
0005434606876	22071	Economy	19300.00
0005434606859	22071	Economy	19300.00
0005435853651	22071	Economy	19300.00
0005434606877	22071	Economy	19300.00
0005434606862	22071	Economy	19300.00
0005433519530	22071	Economy	19300.00
0005433519511	22071	Economy	19300.00
0005435853650	22071	Economy	19300.00
0005433519510	22071	Economy	19300.00
0005434606851	22071	Economy	19300.00
0005434606860	22071	Economy	19300.00
0005433519522	22071	Economy	19300.00
0005434606861	22071	Economy	19300.00
0005433519521	22071	Economy	19300.00
0005434606873	22071	Economy	19300.00
0005434606868	22071	Economy	19300.00
0005434606869	22071	Economy	19300.00
0005433349052	676	Economy	3700.00
0005433349047	676	Economy	3700.00
0005433349051	676	Economy	3700.00
0005433349057	676	Economy	3700.00
0005433349041	676	Economy	3700.00
0005435628800	676	Economy	3700.00
0005433349040	676	Economy	3700.00
0005433349089	676	Economy	3700.00
0005433349116	15891	Economy	3700.00
0005433349115	15891	Economy	3700.00
0005433349118	15891	Economy	3700.00
0005433349114	15891	Economy	3700.00
0005433349117	15891	Economy	3700.00
0005433349113	15891	Economy	3700.00
0005435628763	15891	Economy	3700.00
0005435628762	15891	Economy	3700.00
0005435628772	15891	Economy	3700.00
0005435628775	15891	Economy	3700.00
0005434445294	17141	Economy	7100.00
0005434446567	17141	Economy	7100.00
0005433158155	17141	Economy	7100.00
0005433159328	17141	Economy	7100.00
0005433159342	17141	Economy	7100.00
0005433158156	17141	Economy	7100.00
0005434445295	17141	Economy	7100.00
0005433158159	17141	Economy	7100.00
0005433158158	17141	Economy	7100.00
0005433159343	17141	Economy	7100.00
0005433159362	17612	Economy	7100.00
0005433158197	17612	Economy	7100.00
0005435383215	7909	Economy	5900.00
0005435133113	7909	Economy	5900.00
0005435133108	7909	Economy	5900.00
0005435383224	7909	Economy	5400.00
0005435133116	7909	Economy	5400.00
0005435133109	7909	Economy	5400.00
0005435133115	7909	Economy	5400.00
0005435133117	7909	Economy	5400.00
0005435383214	7909	Economy	5400.00
0005435383219	7909	Economy	5400.00
0005435133110	7909	Economy	5400.00
0005435383242	7909	Economy	5400.00
0005435383211	7909	Economy	5400.00
0005435383213	7909	Economy	5400.00
0005435133106	7909	Economy	5400.00
0005435383216	7909	Economy	5400.00
0005435133114	7909	Economy	5400.00
0005435133107	7909	Economy	5400.00
0005435133112	7909	Economy	5400.00
0005435133111	7909	Economy	5400.00
0005435383267	33074	Economy	5900.00
0005435133050	33074	Economy	5900.00
0005435133028	33074	Economy	5900.00
0005435133049	33074	Economy	5400.00
0005435383268	33074	Economy	5400.00
0005435133051	33074	Economy	5400.00
0005435133003	33074	Economy	5400.00
0005435133048	33074	Economy	5400.00
0005435133013	33074	Economy	5400.00
0005435133021	33074	Economy	5400.00
0005435383266	33074	Economy	5400.00
0005435133004	33074	Economy	5400.00
0005435383265	33074	Economy	5400.00
0005435383269	33074	Economy	5400.00
0005435133014	33074	Economy	5400.00
0005435133052	33074	Economy	5400.00
0005435133024	33074	Economy	5400.00
0005435160543	7503	Economy	13800.00
0005435160544	7503	Economy	12500.00
0005435160545	7503	Economy	12500.00
0005435160542	7503	Economy	12500.00
0005435160548	7503	Economy	12500.00
0005435160541	7503	Economy	12500.00
0005435390295	7503	Economy	12500.00
0005435160546	7503	Economy	12500.00
0005435390320	7503	Economy	12500.00
0005435390296	7503	Economy	12500.00
0005435160547	7503	Economy	12500.00
0005435160540	7503	Economy	12500.00
0005435160549	7503	Economy	12500.00
0005435160478	29586	Economy	12500.00
0005435390387	29586	Economy	12500.00
0005435390389	29586	Economy	12500.00
0005435160436	29586	Economy	12500.00
0005435160494	29586	Economy	12500.00
0005435160479	29586	Economy	12500.00
0005435390393	29586	Economy	12500.00
0005435390390	29586	Economy	12500.00
0005435390388	29586	Economy	12500.00
0005435160423	29586	Economy	12500.00
0005435160455	29586	Economy	12500.00
0005435390391	29586	Economy	12500.00
0005435390392	29586	Economy	12500.00
0005435160477	29586	Economy	12500.00
0005432394168	18445	Economy	4900.00
0005432398250	18445	Economy	4900.00
0005432394145	18445	Economy	4900.00
0005432394148	18445	Economy	4900.00
0005432394171	18445	Economy	4900.00
0005432394147	18445	Economy	4900.00
0005435178529	18445	Economy	4900.00
0005435179011	18445	Economy	4900.00
0005435178530	18445	Economy	4900.00
0005435178528	18445	Economy	4900.00
0005435179010	18445	Economy	4900.00
0005432398254	18445	Economy	4900.00
0005432400202	27128	Economy	4900.00
0005432400201	27128	Economy	4900.00
0005432398272	27128	Economy	4900.00
0005432398273	27128	Economy	4900.00
0005435179405	27128	Economy	4900.00
0005432398275	27128	Economy	4900.00
0005432398274	27128	Economy	4900.00
0005434191302	9773	Economy	4400.00
0005434552882	9773	Economy	4400.00
0005434552883	9773	Economy	4400.00
0005434552884	9773	Economy	4400.00
0005434191291	9773	Economy	4400.00
0005434191300	9773	Economy	4400.00
0005434191301	9773	Economy	4400.00
0005434191288	9773	Economy	4400.00
0005432664186	21842	Business	92200.00
0005432663075	21842	Business	92200.00
0005432663084	21842	Business	92200.00
0005432661969	21842	Business	92200.00
0005432663071	21842	Business	92200.00
0005432664175	21842	Business	92200.00
0005432663083	21842	Business	92200.00
0005432663072	21842	Business	92200.00
0005432664184	21842	Economy	30700.00
0005432664182	21842	Economy	30700.00
0005432664176	21842	Economy	30700.00
0005432661971	21842	Economy	30700.00
0005432664174	21842	Economy	30700.00
0005432663079	21842	Economy	30700.00
0005432663081	21842	Economy	30700.00
0005432661970	21842	Economy	33800.00
0005432664178	21842	Economy	33800.00
0005432664187	21842	Economy	30700.00
0005432663078	21842	Economy	30700.00
0005432661965	21842	Economy	30700.00
0005432663076	21842	Economy	30700.00
0005432664177	21842	Economy	30700.00
0005432661964	21842	Economy	30700.00
0005432661968	21842	Economy	30700.00
0005432661961	21842	Economy	30700.00
0005432661972	21842	Economy	30700.00
0005432664185	21842	Economy	30700.00
0005432661973	21842	Economy	30700.00
0005432663085	21842	Economy	30700.00
0005432663077	21842	Economy	30700.00
0005432663080	21842	Economy	30700.00
0005432664181	21842	Economy	30700.00
0005432661960	21842	Economy	30700.00
0005432661962	21842	Economy	30700.00
0005432664179	21842	Economy	30700.00
0005432661967	21842	Economy	30700.00
0005432661974	21842	Economy	30700.00
0005432663073	21842	Economy	30700.00
0005432661963	21842	Economy	30700.00
0005432664173	21842	Economy	30700.00
0005432663082	21842	Economy	30700.00
0005432664183	21842	Economy	30700.00
0005432661966	21842	Economy	30700.00
0005432664180	21842	Economy	30700.00
0005432663074	21842	Economy	30700.00
0005434505020	6562	Business	48400.00
0005435104132	6562	Business	48400.00
0005434505029	6562	Business	48400.00
0005434505007	6562	Business	48400.00
0005435104128	6562	Business	48400.00
0005434505017	6562	Business	48400.00
0005434505000	6562	Business	48400.00
0005435104135	6562	Economy	16100.00
0005435104137	6562	Economy	16100.00
0005434505021	6562	Economy	16100.00
0005434504994	6562	Economy	16100.00
0005434505012	6562	Economy	16100.00
0005434505022	6562	Economy	17800.00
0005435104129	6562	Economy	17800.00
0005434504996	6562	Economy	17800.00
0005434505013	6562	Economy	16100.00
0005434505018	6562	Economy	16100.00
0005434505027	6562	Economy	16100.00
0005435104125	6562	Economy	16100.00
0005434505028	6562	Economy	16100.00
0005434505023	6562	Economy	16100.00
0005434505014	6562	Economy	16100.00
0005434504990	6562	Economy	16100.00
0005434505025	6562	Economy	16100.00
0005434505016	6562	Economy	16100.00
0005434505026	6562	Economy	16100.00
0005434505002	6562	Economy	16100.00
0005434505015	6562	Economy	16100.00
0005434505011	6562	Economy	16100.00
0005434505006	6562	Economy	16100.00
0005434504992	6562	Economy	16100.00
0005434504989	6562	Economy	16100.00
0005434504998	6562	Economy	16100.00
0005435104130	6562	Economy	16100.00
0005434504995	6562	Economy	16100.00
0005434505024	6562	Economy	16100.00
0005434504999	6562	Economy	16100.00
0005434505008	6562	Economy	16100.00
0005434505030	6562	Economy	16100.00
0005434504991	6562	Economy	16100.00
0005435104131	6562	Economy	16100.00
0005434505019	6562	Economy	16100.00
0005434505009	6562	Economy	16100.00
0005435104126	6562	Economy	16100.00
0005435104136	6562	Economy	16100.00
0005435104133	6562	Economy	16100.00
0005434504997	6562	Economy	16100.00
0005434505010	6562	Economy	16100.00
0005434505005	6562	Economy	16100.00
0005434504993	6562	Economy	16100.00
0005434505004	6562	Economy	16100.00
0005434505001	6562	Economy	16100.00
0005434505003	6562	Economy	16100.00
0005435104127	6562	Economy	16100.00
0005435104134	6562	Economy	16100.00
0005434504531	22649	Business	48400.00
0005435103986	22649	Business	48400.00
0005434504559	22649	Business	48400.00
0005435103984	22649	Economy	16100.00
0005435103990	22649	Economy	16100.00
0005434504555	22649	Economy	16100.00
0005434504570	22649	Economy	16100.00
0005435103982	22649	Economy	16100.00
0005434504597	22649	Economy	17800.00
0005434504554	22649	Economy	17800.00
0005434504475	22649	Economy	17800.00
0005434504586	22649	Economy	16100.00
0005434504427	22649	Economy	16100.00
0005434504626	22649	Economy	16100.00
0005434504716	22649	Economy	16100.00
0005434504587	22649	Economy	16100.00
0005434504688	22649	Economy	16100.00
0005434504598	22649	Economy	16100.00
0005434504549	22649	Economy	16100.00
0005434504560	22649	Economy	16100.00
0005434504755	22649	Economy	16100.00
0005435103985	22649	Economy	16100.00
0005434504608	22649	Economy	16100.00
0005434504717	22649	Economy	16100.00
0005434504647	22649	Economy	16100.00
0005434504681	22649	Economy	16100.00
0005435103995	22649	Economy	16100.00
0005434504682	22649	Economy	16100.00
0005434504483	22649	Economy	16100.00
0005434504616	22649	Economy	16100.00
0005434504655	22649	Economy	16100.00
0005434504759	22649	Economy	16100.00
0005434504604	22649	Economy	16100.00
0005434504694	22649	Economy	16100.00
0005434504593	22649	Economy	16100.00
0005435103996	22649	Economy	16100.00
0005434504470	22649	Economy	16100.00
0005434504571	22649	Economy	16100.00
0005434504469	22649	Economy	16100.00
0005434504625	22649	Economy	16100.00
0005435103980	22649	Economy	16100.00
0005434504476	22649	Economy	16100.00
0005434504479	22649	Economy	16100.00
0005434504648	22649	Economy	16100.00
0005434504592	22649	Economy	16100.00
0005434504572	22649	Economy	16100.00
0005434504530	22649	Economy	16100.00
0005435103989	22649	Economy	16100.00
0005435103993	22649	Economy	16100.00
0005434504656	22649	Economy	16100.00
0005433368255	1691	Business	50000.00
0005435654037	1691	Business	50000.00
0005433368419	1691	Business	50000.00
0005435654014	1691	Business	50000.00
0005435654020	1691	Business	50000.00
0005435654024	1691	Business	50000.00
0005435654011	1691	Business	50000.00
0005433368377	1691	Economy	16700.00
0005435654013	1691	Economy	16700.00
0005435654038	1691	Economy	16700.00
0005435654021	1691	Economy	16700.00
0005433368348	1691	Economy	16700.00
0005435654048	1691	Economy	16700.00
0005433368320	1691	Economy	16700.00
0005435654042	1691	Economy	16700.00
0005433368325	1691	Economy	16700.00
0005433368256	1691	Economy	18300.00
0005435654041	1691	Economy	18300.00
0005435654030	1691	Economy	18300.00
0005433368403	1691	Economy	18300.00
0005433368343	1691	Economy	16700.00
0005433368309	1691	Economy	16700.00
0005435654029	1691	Economy	16700.00
0005433368349	1691	Economy	16700.00
0005433368368	1691	Economy	16700.00
0005433368299	1691	Economy	16700.00
0005433368392	1691	Economy	16700.00
0005435654031	1691	Economy	16700.00
0005435654015	1691	Economy	16700.00
0005433368405	1691	Economy	16700.00
0005435654043	1691	Economy	16700.00
0005433368279	1691	Economy	16700.00
0005433368369	1691	Economy	16700.00
0005433368376	1691	Economy	16700.00
0005435654008	1691	Economy	16700.00
0005435654035	1691	Economy	16700.00
0005435654026	1691	Economy	16700.00
0005435654019	1691	Economy	16700.00
0005435654039	1691	Economy	16700.00
0005433368122	1691	Economy	16700.00
0005433368338	1691	Economy	16700.00
0005435654040	1691	Economy	16700.00
0005435654027	1691	Economy	16700.00
0005433368284	1691	Economy	16700.00
0005435654017	1691	Economy	16700.00
0005435654023	1691	Economy	16700.00
0005433368406	1691	Economy	16700.00
0005435654045	1691	Economy	16700.00
0005435654022	1691	Economy	16700.00
0005433368444	1691	Economy	16700.00
0005435654028	1691	Economy	16700.00
0005433368326	1691	Economy	16700.00
0005435654044	1691	Economy	16700.00
0005433368391	1691	Economy	16700.00
0005435654012	1691	Economy	16700.00
0005433368428	1691	Economy	16700.00
0005435654046	1691	Economy	16700.00
0005435654009	1691	Economy	16700.00
0005433368183	1691	Economy	16700.00
0005433368210	1691	Economy	16700.00
0005435654033	1691	Economy	16700.00
0005435654010	1691	Economy	16700.00
0005433368430	1691	Economy	16700.00
0005433368516	1691	Economy	16700.00
0005433368344	1691	Economy	16700.00
0005433368124	1691	Economy	16700.00
0005435654032	1691	Economy	16700.00
0005435654047	1691	Economy	16700.00
0005433368278	1691	Economy	16700.00
0005433368185	1691	Economy	16700.00
0005433368209	1691	Economy	16700.00
0005433368288	1691	Economy	16700.00
0005435654036	1691	Economy	16700.00
0005435654018	1691	Economy	16700.00
0005433368123	1691	Economy	16700.00
0005435654016	1691	Economy	16700.00
0005435654025	1691	Economy	16700.00
0005435654034	1691	Economy	16700.00
0005435653643	21671	Business	50000.00
0005435653581	21671	Business	50000.00
0005435653625	21671	Business	50000.00
0005435653645	21671	Business	50000.00
0005435653552	21671	Business	50000.00
0005435653619	21671	Business	50000.00
0005433368709	21671	Business	50000.00
0005433368689	21671	Business	50000.00
0005433368699	21671	Business	50000.00
0005435653574	21671	Business	50000.00
0005433368711	21671	Economy	16700.00
0005433368707	21671	Economy	16700.00
0005435653602	21671	Economy	16700.00
0005433368697	21671	Economy	16700.00
0005433368705	21671	Economy	16700.00
0005433368678	21671	Economy	16700.00
0005435653562	21671	Economy	16700.00
0005435653631	21671	Economy	18300.00
0005435653584	21671	Economy	18300.00
0005435653553	21671	Economy	18300.00
0005435653711	21671	Economy	16700.00
0005433368696	21671	Economy	16700.00
0005433368691	21671	Economy	16700.00
0005435653697	21671	Economy	16700.00
0005433368695	21671	Economy	16700.00
0005435653624	21671	Economy	16700.00
0005435653491	21671	Economy	16700.00
0005433368704	21671	Economy	16700.00
0005435653679	21671	Economy	16700.00
0005433368681	21671	Economy	16700.00
0005433368690	21671	Economy	16700.00
0005435653678	21671	Economy	16700.00
0005435653592	21671	Economy	16700.00
0005435653601	21671	Economy	16700.00
0005433368694	21671	Economy	16700.00
0005435653669	21671	Economy	16700.00
0005433368686	21671	Economy	16700.00
0005435653663	21671	Economy	16700.00
0005435653569	21671	Economy	16700.00
0005433368710	21671	Economy	16700.00
0005435653582	21671	Economy	16700.00
0005433368700	21671	Economy	16700.00
0005433368701	21671	Economy	16700.00
0005433368713	21671	Economy	16700.00
0005435653398	21671	Economy	16700.00
0005435653554	21671	Economy	16700.00
0005435653712	21671	Economy	16700.00
0005435653567	21671	Economy	16700.00
0005433368712	21671	Economy	16700.00
0005435653566	21671	Economy	16700.00
0005435653629	21671	Economy	16700.00
0005435653344	21671	Economy	16700.00
0005435653677	21671	Economy	16700.00
0005435653680	21671	Economy	16700.00
0005433368684	21671	Economy	16700.00
0005433368692	21671	Economy	16700.00
0005435653646	21671	Economy	16700.00
0005433368693	21671	Economy	16700.00
0005433368703	21671	Economy	16700.00
0005433368706	21671	Economy	16700.00
0005435653580	21671	Economy	16700.00
0005433368682	21671	Economy	16700.00
0005433368688	21671	Economy	16700.00
0005435653668	21671	Economy	16700.00
0005433368687	21671	Economy	16700.00
0005435653399	21671	Economy	16700.00
0005433368685	21671	Economy	16700.00
0005435653479	21671	Economy	16700.00
0005433368702	21671	Economy	16700.00
0005433368679	21671	Economy	16700.00
0005435653618	21671	Economy	16700.00
0005433368698	21671	Economy	16700.00
0005435653568	21671	Economy	16700.00
0005435653391	21671	Economy	16700.00
0005433368683	21671	Economy	16700.00
0005435653628	21671	Economy	16700.00
0005433368680	21671	Economy	16700.00
0005435653662	21671	Economy	16700.00
0005433368708	21671	Economy	16700.00
0005435653639	21671	Economy	16700.00
0005433986956	4156	Business	21500.00
0005433986972	4156	Business	21500.00
0005433986933	4156	Business	21500.00
0005433986961	4156	Business	21500.00
0005433986952	4156	Business	21500.00
0005433986926	4156	Business	21500.00
0005433986927	4156	Business	21500.00
0005433986962	4156	Business	21500.00
0005433986930	4156	Economy	7200.00
0005433986947	4156	Economy	7200.00
0005433986928	4156	Economy	7200.00
0005433986957	4156	Economy	7200.00
0005433986942	4156	Economy	7200.00
0005435788826	4156	Economy	7200.00
0005433986971	4156	Economy	7900.00
0005433986929	4156	Economy	7900.00
0005433986950	4156	Economy	7900.00
0005433986959	4156	Economy	7200.00
0005433986964	4156	Economy	7200.00
0005433986948	4156	Economy	7200.00
0005433986973	4156	Economy	7200.00
0005433986935	4156	Economy	7200.00
0005433986939	4156	Economy	7200.00
0005433986931	4156	Economy	7200.00
0005433986946	4156	Economy	7200.00
0005433986963	4156	Economy	7200.00
0005433986945	4156	Economy	7200.00
0005433986938	4156	Economy	7200.00
0005433986951	4156	Economy	7200.00
0005433986941	4156	Economy	7200.00
0005433986925	4156	Economy	7200.00
0005433986936	4156	Economy	7200.00
0005433986944	4156	Economy	7200.00
0005433986974	4156	Economy	7200.00
0005433986940	4156	Economy	7200.00
0005433986968	4156	Economy	7200.00
0005433986934	4156	Economy	7200.00
0005433986953	4156	Economy	7200.00
0005433986970	4156	Economy	7200.00
0005433986967	4156	Economy	7200.00
0005433986958	4156	Economy	7200.00
0005433986949	4156	Economy	7200.00
0005433986966	4156	Economy	7200.00
0005433986955	4156	Economy	7200.00
0005433986960	4156	Economy	7200.00
0005433986943	4156	Economy	7200.00
0005433986969	4156	Economy	7200.00
0005433986937	4156	Economy	7200.00
0005433986954	4156	Economy	7200.00
0005433986932	4156	Economy	7200.00
0005433986965	4156	Economy	7200.00
0005435788827	4156	Economy	7200.00
0005433986430	25646	Business	21500.00
0005433986662	25646	Business	21500.00
0005433986366	25646	Business	21500.00
0005433986488	25646	Business	21500.00
0005433986489	25646	Economy	7200.00
0005433986594	25646	Economy	7200.00
0005433986663	25646	Economy	7200.00
0005433986630	25646	Economy	7200.00
0005433986598	25646	Economy	7900.00
0005433986492	25646	Economy	7900.00
0005433986499	25646	Economy	7900.00
0005433986569	25646	Economy	7900.00
0005433986324	25646	Economy	7200.00
0005433986323	25646	Economy	7200.00
0005433986403	25646	Economy	7200.00
0005433986376	25646	Economy	7200.00
0005433986595	25646	Economy	7200.00
0005433986534	25646	Economy	7200.00
0005433986570	25646	Economy	7200.00
0005433986592	25646	Economy	7200.00
0005433986216	25646	Economy	7200.00
0005433986217	25646	Economy	7200.00
0005433986405	25646	Economy	7200.00
0005433986553	25646	Economy	7200.00
0005433986501	25646	Economy	7200.00
0005433986365	25646	Economy	7200.00
0005433986515	25646	Economy	7200.00
0005433986571	25646	Economy	7200.00
0005433986512	25646	Economy	7200.00
0005433986370	25646	Economy	7200.00
0005433986402	25646	Economy	7200.00
0005433986511	25646	Economy	7200.00
0005433986215	25646	Economy	7200.00
0005433986601	25646	Economy	7200.00
0005433986500	25646	Economy	7200.00
0005433986535	25646	Economy	7200.00
0005433986707	25646	Economy	7200.00
0005433986556	25646	Economy	7200.00
0005433986593	25646	Economy	7200.00
0005433986608	25646	Economy	7200.00
0005433986371	25646	Economy	7200.00
0005433986375	25646	Economy	7200.00
0005433986493	25646	Economy	7200.00
0005433986494	25646	Economy	7200.00
0005433986519	25646	Economy	7200.00
0005433986533	25646	Economy	7200.00
0005435719571	21243	Economy	9400.00
0005435720834	21243	Economy	9400.00
0005435720842	21243	Economy	9400.00
0005435720155	24779	Economy	10400.00
0005435719586	24779	Economy	9400.00
0005435719585	24779	Economy	9400.00
0005435720154	24779	Economy	9400.00
0005434516123	9022	Economy	26000.00
0005434516120	9022	Economy	23600.00
0005434190439	9022	Economy	23600.00
0005434190427	9022	Economy	23600.00
0005434516119	9022	Economy	23600.00
0005434190425	9022	Economy	23600.00
0005434190438	9022	Economy	23600.00
0005434516118	9022	Economy	23600.00
0005434516121	9022	Economy	23600.00
0005434190424	9022	Economy	23600.00
0005434516124	9022	Economy	23600.00
0005434516125	9022	Economy	23600.00
0005434516122	9022	Economy	23600.00
0005432869670	17869	Business	18000.00
0005434151768	17869	Business	18000.00
0005432869668	17869	Business	18000.00
0005432661945	17869	Business	18000.00
0005432869672	17869	Business	18000.00
0005432657477	17869	Business	18000.00
0005432657501	17869	Business	18000.00
0005432660847	17869	Economy	6000.00
0005432655687	17869	Economy	6000.00
0005432664164	17869	Economy	6000.00
0005432666413	17869	Economy	6000.00
0005434151769	17869	Economy	6600.00
0005432655670	17869	Economy	6600.00
0005432666415	17869	Economy	6600.00
0005432666420	17869	Economy	6000.00
0005432655685	17869	Economy	6000.00
0005432660849	17869	Economy	6000.00
0005432657493	17869	Economy	6000.00
0005432655675	17869	Economy	6000.00
0005432655666	17869	Economy	6000.00
0005432869673	17869	Economy	6000.00
0005432657490	17869	Economy	6000.00
0005432869675	17869	Economy	6000.00
0005432657492	17869	Economy	6000.00
0005432666396	17869	Economy	6000.00
0005432869669	17869	Economy	6000.00
0005432869674	17869	Economy	6000.00
0005432660848	17869	Economy	6000.00
0005432664165	17869	Economy	6000.00
0005434151770	17869	Economy	6000.00
0005432663064	17869	Economy	6000.00
0005432655715	17869	Economy	6000.00
0005432869671	17869	Economy	6000.00
0005432655686	17869	Economy	6000.00
0005432664171	17869	Economy	6000.00
0005432666421	17869	Economy	6000.00
0005432655667	17869	Economy	6000.00
0005432658634	26314	Business	18000.00
0005432869616	26314	Business	18000.00
0005432655773	26314	Business	18000.00
0005432666430	26314	Business	18000.00
0005432660860	26314	Business	18000.00
0005432655769	26314	Business	18000.00
0005432655767	26314	Business	18000.00
0005432657514	26314	Business	18000.00
0005432869586	26314	Business	18000.00
0005432869558	26314	Economy	6000.00
0005432667496	26314	Economy	6000.00
0005432869588	26314	Economy	6000.00
0005432655766	26314	Economy	6600.00
0005432655774	26314	Economy	6600.00
0005432659748	26314	Economy	6600.00
0005432659750	26314	Economy	6000.00
0005432660861	26314	Economy	6000.00
0005432655771	26314	Economy	6000.00
0005432655775	26314	Economy	6000.00
0005434151742	26314	Economy	6000.00
0005432869582	26314	Economy	6000.00
0005432660859	26314	Economy	6000.00
0005432657511	26314	Economy	6000.00
0005432869556	26314	Economy	6000.00
0005434151726	26314	Economy	6000.00
0005434151727	26314	Economy	6000.00
0005432655777	26314	Economy	6000.00
0005432869587	26314	Economy	6000.00
0005432658633	26314	Economy	6000.00
0005432869605	26314	Economy	6000.00
0005434151723	26314	Economy	6000.00
0005432655778	26314	Economy	6000.00
0005432655776	26314	Economy	6000.00
0005432655772	26314	Economy	6000.00
0005432655770	26314	Economy	6000.00
0005432655768	26314	Economy	6000.00
0005432665316	26314	Economy	6000.00
0005432869606	26314	Economy	6000.00
0005432665318	26314	Economy	6000.00
0005432667495	26314	Economy	6000.00
0005432657513	26314	Economy	6000.00
0005432666431	26314	Economy	6000.00
0005432659749	26314	Economy	6000.00
0005432869557	26314	Economy	6000.00
0005432667497	26314	Economy	6000.00
0005432869590	26314	Economy	6000.00
0005432869617	26314	Economy	6000.00
0005432665317	26314	Economy	6000.00
0005432657512	26314	Economy	6000.00
0005432329705	3128	Business	16100.00
0005432905206	3128	Business	16100.00
0005432329687	3128	Business	16100.00
0005432329696	3128	Business	16100.00
0005432329680	3128	Business	16100.00
0005432329711	3128	Business	16100.00
0005432329692	3128	Business	16100.00
0005432329704	3128	Economy	5400.00
0005432329698	3128	Economy	5400.00
0005432329682	3128	Economy	5400.00
0005432329714	3128	Economy	5400.00
0005432329721	3128	Economy	5400.00
0005432329708	3128	Economy	5400.00
0005432329675	3128	Economy	5400.00
0005432329720	3128	Economy	5900.00
0005432329684	3128	Economy	5900.00
0005432329718	3128	Economy	5900.00
0005433439008	3128	Economy	5900.00
0005433439013	3128	Economy	5900.00
0005433439011	3128	Economy	5400.00
0005432329695	3128	Economy	5400.00
0005433439006	3128	Economy	5400.00
0005432329713	3128	Economy	5400.00
0005433439009	3128	Economy	5400.00
0005432329676	3128	Economy	5400.00
0005432329699	3128	Economy	5400.00
0005432287300	3128	Economy	5400.00
0005432329689	3128	Economy	5400.00
0005432329710	3128	Economy	5400.00
0005432329683	3128	Economy	5400.00
0005433439012	3128	Economy	5400.00
0005432329694	3128	Economy	5400.00
0005433439017	3128	Economy	5400.00
0005432329706	3128	Economy	5400.00
0005432329686	3128	Economy	5400.00
0005432329700	3128	Economy	5400.00
0005432329693	3128	Economy	5400.00
0005432329717	3128	Economy	5400.00
0005432329679	3128	Economy	5400.00
0005432287301	3128	Economy	5400.00
0005433439015	3128	Economy	5400.00
0005432329678	3128	Economy	5400.00
0005432329716	3128	Economy	5400.00
0005432287299	3128	Economy	5400.00
0005432329701	3128	Economy	5400.00
0005432329702	3128	Economy	5400.00
0005432329690	3128	Economy	5400.00
0005433439014	3128	Economy	5400.00
0005432329685	3128	Economy	5400.00
0005432329681	3128	Economy	5400.00
0005432329677	3128	Economy	5400.00
0005432329703	3128	Economy	5400.00
0005433439005	3128	Economy	5400.00
0005432287302	3128	Economy	5400.00
0005432329707	3128	Economy	5400.00
0005432329691	3128	Economy	5400.00
0005432329688	3128	Economy	5400.00
0005432329715	3128	Economy	5400.00
0005432329697	3128	Economy	5400.00
0005432329709	3128	Economy	5400.00
0005433439007	3128	Economy	5400.00
0005432329719	3128	Economy	5400.00
0005433439010	3128	Economy	5400.00
0005432287298	3128	Economy	5400.00
0005433439016	3128	Economy	5400.00
0005432329712	3128	Economy	5400.00
0005432329232	31101	Business	16100.00
0005432328989	31101	Business	16100.00
0005432329189	31101	Business	16100.00
0005432329082	31101	Business	16100.00
0005432848870	31101	Business	16100.00
0005433438966	31101	Business	16100.00
0005432905249	31101	Business	16100.00
0005432848875	31101	Business	16100.00
0005432329264	31101	Economy	5400.00
0005432905246	31101	Economy	5400.00
0005432329344	31101	Economy	5400.00
0005433438971	31101	Economy	5400.00
0005432848873	31101	Economy	5400.00
0005432329262	31101	Economy	5400.00
0005432905251	31101	Economy	5900.00
0005432329343	31101	Economy	5900.00
0005432329333	31101	Economy	5900.00
0005432329083	31101	Economy	5900.00
0005432329080	31101	Economy	5900.00
0005432329314	31101	Economy	5400.00
0005432848872	31101	Economy	5400.00
0005432848869	31101	Economy	5400.00
0005432329302	31101	Economy	5400.00
0005432329243	31101	Economy	5400.00
0005432329117	31101	Economy	5400.00
0005432329290	31101	Economy	5400.00
0005432848879	31101	Economy	5400.00
0005432329332	31101	Economy	5400.00
0005432848878	31101	Economy	5400.00
0005432329190	31101	Economy	5400.00
0005432329191	31101	Economy	5400.00
0005432329336	31101	Economy	5400.00
0005432054368	31101	Economy	5400.00
0005432329240	31101	Economy	5400.00
0005432848876	31101	Economy	5400.00
0005432848871	31101	Economy	5400.00
0005432848868	31101	Economy	5400.00
0005432905247	31101	Economy	5400.00
0005432329073	31101	Economy	5400.00
0005432905250	31101	Economy	5400.00
0005432329244	31101	Economy	5400.00
0005433438956	31101	Economy	5400.00
0005433438963	31101	Economy	5400.00
0005432905248	31101	Economy	5400.00
0005432329193	31101	Economy	5400.00
0005432848874	31101	Economy	5400.00
0005432329049	31101	Economy	5400.00
0005432329263	31101	Economy	5400.00
0005433438967	31101	Economy	5400.00
0005432329116	31101	Economy	5400.00
0005432329019	31101	Economy	5400.00
0005432329297	31101	Economy	5400.00
0005432054367	31101	Economy	5400.00
0005432329440	31101	Economy	5400.00
0005432329431	31101	Economy	5400.00
0005432054369	31101	Economy	5400.00
0005433438972	31101	Economy	5400.00
0005432329430	31101	Economy	5400.00
0005432848877	31101	Economy	5400.00
0005432905252	31101	Economy	5400.00
0005432329239	31101	Economy	5400.00
0005432329386	31101	Economy	5400.00
0005432329084	31101	Economy	5400.00
0005432329238	31101	Economy	5400.00
0005433438957	31101	Economy	5400.00
0005433438958	31101	Economy	5400.00
0005432146244	6216	Business	124600.00
0005435297142	6216	Business	124600.00
0005435999626	6216	Business	124600.00
0005435488062	6216	Business	124600.00
0005435999634	6216	Business	124600.00
0005435999633	6216	Business	124600.00
0005435297127	6216	Business	124600.00
0005432146247	6216	Business	124600.00
0005435488121	6216	Economy	41500.00
0005435488061	6216	Economy	41500.00
0005435488083	6216	Economy	41500.00
0005435999624	6216	Economy	41500.00
0005435999640	6216	Economy	41500.00
0005434310045	6216	Economy	41500.00
0005435488074	6216	Economy	41500.00
0005434310034	6216	Economy	41500.00
0005434310043	6216	Economy	41500.00
0005434310041	6216	Economy	41500.00
0005435488196	6216	Economy	41500.00
0005435999627	6216	Economy	41500.00
0005435999637	6216	Economy	41500.00
0005435488139	6216	Economy	41500.00
0005435488109	6216	Economy	41500.00
0005434310037	6216	Economy	41500.00
0005435999636	6216	Economy	41500.00
0005435488071	6216	Economy	45700.00
0005435488101	6216	Economy	45700.00
0005435999639	6216	Economy	45700.00
0005432146246	6216	Economy	45700.00
0005435488100	6216	Economy	41500.00
0005432146245	6216	Economy	41500.00
0005434310036	6216	Economy	41500.00
0005435488176	6216	Economy	41500.00
0005435488153	6216	Economy	41500.00
0005435999629	6216	Economy	41500.00
0005435999641	6216	Economy	41500.00
0005435488076	6216	Economy	41500.00
0005435488091	6216	Economy	41500.00
0005432146243	6216	Economy	41500.00
0005434310038	6216	Economy	41500.00
0005434310033	6216	Economy	41500.00
0005435999631	6216	Economy	41500.00
0005434310035	6216	Economy	41500.00
0005434310039	6216	Economy	41500.00
0005435488195	6216	Economy	41500.00
0005434310042	6216	Economy	41500.00
0005435999643	6216	Economy	41500.00
0005435999635	6216	Economy	41500.00
0005434310044	6216	Economy	41500.00
0005435488175	6216	Economy	41500.00
0005435999628	6216	Economy	41500.00
0005435999644	6216	Economy	41500.00
0005435488192	6216	Economy	41500.00
0005435297155	6216	Economy	41500.00
0005434310040	6216	Economy	41500.00
0005435999642	6216	Economy	41500.00
0005435488097	6216	Economy	41500.00
0005435999632	6216	Economy	41500.00
0005435297135	6216	Economy	41500.00
0005435999645	6216	Economy	41500.00
0005435999630	6216	Economy	41500.00
0005435488098	6216	Economy	41500.00
0005434310046	6216	Economy	41500.00
0005435999625	6216	Economy	41500.00
0005435999638	6216	Economy	41500.00
0005435488056	6216	Economy	41500.00
0005435488120	6216	Economy	41500.00
0005435488090	6216	Economy	41500.00
0005435488112	6216	Economy	41500.00
0005435999359	19566	Business	124600.00
0005435999451	19566	Business	124600.00
0005435488276	19566	Business	124600.00
0005434309915	19566	Business	124600.00
0005435488274	19566	Business	124600.00
0005435297206	19566	Business	124600.00
0005435297205	19566	Business	124600.00
0005435999358	19566	Economy	41500.00
0005435488283	19566	Economy	41500.00
0005435488275	19566	Economy	41500.00
0005435488279	19566	Economy	41500.00
0005435297209	19566	Economy	41500.00
0005435999452	19566	Economy	41500.00
0005435999467	19566	Economy	41500.00
0005434309970	19566	Economy	41500.00
0005435488287	19566	Economy	41500.00
0005435488278	19566	Economy	41500.00
0005435999412	19566	Economy	41500.00
0005435488284	19566	Economy	41500.00
0005435999381	19566	Economy	41500.00
0005435488277	19566	Economy	41500.00
0005434309869	19566	Economy	41500.00
0005435999450	19566	Economy	45700.00
0005435999435	19566	Economy	45700.00
0005435488281	19566	Economy	45700.00
0005434309924	19566	Economy	41500.00
0005435488286	19566	Economy	41500.00
0005435999444	19566	Economy	41500.00
0005434309921	19566	Economy	41500.00
0005435488293	19566	Economy	41500.00
0005435999453	19566	Economy	41500.00
0005435297208	19566	Economy	41500.00
0005435488273	19566	Economy	41500.00
0005435999433	19566	Economy	41500.00
0005435297211	19566	Economy	41500.00
0005435999461	19566	Economy	41500.00
0005435999432	19566	Economy	41500.00
0005435999397	19566	Economy	41500.00
0005435488282	19566	Economy	41500.00
0005435297207	19566	Economy	41500.00
0005435999462	19566	Economy	41500.00
0005435999468	19566	Economy	41500.00
0005435488280	19566	Economy	41500.00
0005435488288	19566	Economy	41500.00
0005435297210	19566	Economy	41500.00
0005435999442	19566	Economy	41500.00
0005435488292	19566	Economy	41500.00
0005435488290	19566	Economy	41500.00
0005435999448	19566	Economy	41500.00
0005435488291	19566	Economy	41500.00
0005435488285	19566	Economy	41500.00
0005435488289	19566	Economy	41500.00
0005434309906	19566	Economy	41500.00
0005435999449	19566	Economy	41500.00
0005435488294	19566	Economy	41500.00
0005434309870	19566	Economy	41500.00
0005435999396	19566	Economy	41500.00
0005435999434	19566	Economy	41500.00
0005435999443	19566	Economy	41500.00
0005434566214	1559	Business	86000.00
0005435508643	1559	Business	86000.00
0005435508647	1559	Business	86000.00
0005435508653	1559	Business	86000.00
0005435502782	1559	Business	86000.00
0005435508654	1559	Business	86000.00
0005434566213	1559	Business	86000.00
0005435518312	1559	Business	86000.00
0005435502785	1559	Business	86000.00
0005435502781	1559	Economy	28700.00
0005435502774	1559	Economy	28700.00
0005435518307	1559	Economy	28700.00
0005435518296	1559	Economy	28700.00
0005434566205	1559	Economy	28700.00
0005435508652	1559	Economy	28700.00
0005435502786	1559	Economy	28700.00
0005435508660	1559	Economy	28700.00
0005435502780	1559	Economy	28700.00
0005435508656	1559	Economy	31500.00
0005435518305	1559	Economy	31500.00
0005435502784	1559	Economy	31500.00
0005435508642	1559	Economy	31500.00
0005435502790	1559	Economy	31500.00
0005435518309	1559	Economy	28700.00
0005435508641	1559	Economy	28700.00
0005435518301	1559	Economy	28700.00
0005435508657	1559	Economy	28700.00
0005435518297	1559	Economy	28700.00
0005434566206	1559	Economy	28700.00
0005435518294	1559	Economy	28700.00
0005435518302	1559	Economy	28700.00
0005435502791	1559	Economy	28700.00
0005435508644	1559	Economy	28700.00
0005435518306	1559	Economy	28700.00
0005435508645	1559	Economy	28700.00
0005435518304	1559	Economy	28700.00
0005435518310	1559	Economy	28700.00
0005435518299	1559	Economy	28700.00
0005435518300	1559	Economy	28700.00
0005435502783	1559	Economy	28700.00
0005432291983	1559	Economy	28700.00
0005435502776	1559	Economy	28700.00
0005434566212	1559	Economy	28700.00
0005434566203	1559	Economy	28700.00
0005435518295	1559	Economy	28700.00
0005435508650	1559	Economy	28700.00
0005433186228	1559	Economy	28700.00
0005435518308	1559	Economy	28700.00
0005433186220	1559	Economy	28700.00
0005435518315	1559	Economy	28700.00
0005435518313	1559	Economy	28700.00
0005434566210	1559	Economy	28700.00
0005435508658	1559	Economy	28700.00
0005434566201	1559	Economy	28700.00
0005435508648	1559	Economy	28700.00
0005435508646	1559	Economy	28700.00
0005433186250	1559	Economy	28700.00
0005434566211	1559	Economy	28700.00
0005432291984	1559	Economy	28700.00
0005435508649	1559	Economy	28700.00
0005435502777	1559	Economy	28700.00
0005435502794	1559	Economy	28700.00
0005435502778	1559	Economy	28700.00
0005435502779	1559	Economy	28700.00
0005433186249	1559	Economy	28700.00
0005435518314	1559	Economy	28700.00
0005435508659	1559	Economy	28700.00
0005435502789	1559	Economy	28700.00
0005435518311	1559	Economy	28700.00
0005435502792	1559	Economy	28700.00
0005435502788	1559	Economy	28700.00
0005434566208	1559	Economy	28700.00
0005435508651	1559	Economy	28700.00
0005434566204	1559	Economy	28700.00
0005434566209	1559	Economy	28700.00
0005434566207	1559	Economy	28700.00
0005435502775	1559	Economy	28700.00
0005435502787	1559	Economy	28700.00
0005434566202	1559	Economy	28700.00
0005435518298	1559	Economy	28700.00
0005435518303	1559	Economy	28700.00
0005435502793	1559	Economy	28700.00
0005435508655	1559	Economy	28700.00
0005433186209	1559	Economy	28700.00
0005435502795	1559	Economy	28700.00
0005435545792	20899	Business	86000.00
0005435529554	20899	Business	86000.00
0005435545836	20899	Business	86000.00
0005435502592	20899	Business	86000.00
0005435502517	20899	Business	86000.00
0005435502524	20899	Business	86000.00
0005435529442	20899	Business	86000.00
0005434566065	20899	Business	86000.00
0005435545797	20899	Business	86000.00
0005435529420	20899	Business	86000.00
0005434566041	20899	Business	86000.00
0005435529510	20899	Economy	28700.00
0005435529545	20899	Economy	28700.00
0005433186305	20899	Economy	28700.00
0005435529561	20899	Economy	28700.00
0005435502548	20899	Economy	28700.00
0005435529393	20899	Economy	28700.00
0005435502551	20899	Economy	28700.00
0005435529504	20899	Economy	28700.00
0005435529481	20899	Economy	28700.00
0005435502552	20899	Economy	31500.00
0005435545800	20899	Economy	31500.00
0005435502556	20899	Economy	31500.00
0005435529538	20899	Economy	31500.00
0005433186306	20899	Economy	28700.00
0005435529473	20899	Economy	28700.00
0005435502508	20899	Economy	28700.00
0005435529560	20899	Economy	28700.00
0005435529550	20899	Economy	28700.00
0005434566092	20899	Economy	28700.00
0005434566077	20899	Economy	28700.00
0005434566130	20899	Economy	28700.00
0005435529509	20899	Economy	28700.00
0005435502564	20899	Economy	28700.00
0005435529572	20899	Economy	28700.00
0005434566083	20899	Economy	28700.00
0005434566091	20899	Economy	28700.00
0005435529562	20899	Economy	28700.00
0005435545839	20899	Economy	28700.00
0005435502526	20899	Economy	28700.00
0005434566131	20899	Economy	28700.00
0005435545812	20899	Economy	28700.00
0005435529555	20899	Economy	28700.00
0005433186309	20899	Economy	28700.00
0005435529472	20899	Economy	28700.00
0005435502558	20899	Economy	28700.00
0005435529503	20899	Economy	28700.00
0005434566094	20899	Economy	28700.00
0005435545803	20899	Economy	28700.00
0005435529484	20899	Economy	28700.00
0005434566090	20899	Economy	28700.00
0005433186302	20899	Economy	28700.00
0005435529505	20899	Economy	28700.00
0005434566129	20899	Economy	28700.00
0005434566079	20899	Economy	28700.00
0005435545835	20899	Economy	28700.00
0005435529506	20899	Economy	28700.00
0005433186304	20899	Economy	28700.00
0005435545834	20899	Economy	28700.00
0005435502593	20899	Economy	28700.00
0005435529490	20899	Economy	28700.00
0005435529443	20899	Economy	28700.00
0005435502525	20899	Economy	28700.00
0005433186307	20899	Economy	28700.00
0005435529428	20899	Economy	28700.00
0005435529521	20899	Economy	28700.00
0005433186303	20899	Economy	28700.00
0005434566147	20899	Economy	28700.00
0005435545813	20899	Economy	28700.00
0005435529444	20899	Economy	28700.00
0005435529559	20899	Economy	28700.00
0005435529419	20899	Economy	28700.00
0005434566121	20899	Economy	28700.00
0005435529435	20899	Economy	28700.00
0005434566084	20899	Economy	28700.00
0005434566088	20899	Economy	28700.00
0005435529477	20899	Economy	28700.00
0005433186301	20899	Economy	28700.00
0005435502557	20899	Economy	28700.00
0005433186308	20899	Economy	28700.00
0005434566102	20899	Economy	28700.00
0005435502550	20899	Economy	28700.00
0005435153886	3893	Economy	21600.00
0005435142975	3893	Economy	19700.00
0005435153884	3893	Economy	19700.00
0005435153889	3893	Economy	19700.00
0005435931665	3893	Economy	19700.00
0005435153888	3893	Economy	19700.00
0005435142976	3893	Economy	19700.00
0005435931666	3893	Economy	19700.00
0005435153887	3893	Economy	19700.00
0005435153885	3893	Economy	19700.00
0005435931681	21847	Economy	19700.00
0005435153806	21847	Economy	19700.00
0005435153807	21847	Economy	19700.00
0005435931682	21847	Economy	19700.00
0005435931684	21847	Economy	19700.00
0005435931683	21847	Economy	19700.00
0005432629171	7207	Economy	14300.00
0005435225679	7207	Economy	14300.00
0005435225694	7207	Economy	14300.00
0005435225687	7207	Economy	13000.00
0005435225695	7207	Economy	13000.00
0005432629165	7207	Economy	13000.00
0005432629166	7207	Economy	13000.00
0005435225697	7207	Economy	13000.00
0005435225678	7207	Economy	13000.00
0005432629162	7207	Economy	13000.00
0005432629173	7207	Economy	13000.00
0005432629174	7207	Economy	13000.00
0005432629169	7207	Economy	13000.00
0005432629170	7207	Economy	13000.00
0005435225686	7207	Economy	13000.00
0005432629168	7207	Economy	13000.00
0005432629176	7207	Economy	13000.00
0005432629175	7207	Economy	13000.00
0005432629172	7207	Economy	13000.00
0005432629167	7207	Economy	13000.00
0005432629164	7207	Economy	13000.00
0005435225685	7207	Economy	13000.00
0005435225688	7207	Economy	13000.00
0005435225682	7207	Economy	13000.00
0005432629161	7207	Economy	13000.00
0005435225680	7207	Economy	13000.00
0005432629163	7207	Economy	13000.00
0005435225762	28105	Economy	14300.00
0005432629085	28105	Economy	14300.00
0005432629103	28105	Economy	14300.00
0005432629070	28105	Economy	13000.00
0005435225763	28105	Economy	13000.00
0005432629075	28105	Economy	13000.00
0005432629073	28105	Economy	13000.00
0005435225758	28105	Economy	13000.00
0005432629053	28105	Economy	13000.00
0005432629082	28105	Economy	13000.00
0005432629056	28105	Economy	13000.00
0005435225759	28105	Economy	13000.00
0005435225760	28105	Economy	13000.00
0005432629081	28105	Economy	13000.00
0005432629076	28105	Economy	13000.00
0005432628996	28105	Economy	13000.00
0005432629072	28105	Economy	13000.00
0005432629080	28105	Economy	13000.00
0005432629067	28105	Economy	13000.00
0005432629086	28105	Economy	13000.00
0005432629061	28105	Economy	13000.00
0005432629142	28105	Economy	13000.00
0005435225761	28105	Economy	13000.00
0005435225757	28105	Economy	13000.00
0005432629068	28105	Economy	13000.00
0005432629088	28105	Economy	13000.00
0005435225756	28105	Economy	13000.00
0005434268010	8723	Economy	11500.00
0005435960134	8723	Economy	10500.00
0005435960133	8723	Economy	10500.00
0005434268000	8723	Economy	10500.00
0005435960135	8723	Economy	10500.00
0005434268031	15216	Economy	10500.00
0005434268032	15216	Economy	10500.00
0005435960112	15216	Economy	10500.00
0005435960113	15216	Economy	10500.00
0005435960106	15216	Economy	10500.00
0005434268033	15216	Economy	10500.00
0005434268030	15216	Economy	10500.00
0005432693726	1181	Business	115000.00
0005432675460	1181	Business	115000.00
0005432675463	1181	Business	115000.00
0005432693695	1181	Business	115000.00
0005432693709	1181	Business	115000.00
0005432693718	1181	Business	115000.00
0005432675469	1181	Business	115000.00
0005432675465	1181	Business	115000.00
0005432693706	1181	Business	115000.00
0005432693707	1181	Business	115000.00
0005432693704	1181	Business	115000.00
0005432675466	1181	Economy	38300.00
0005432693716	1181	Economy	38300.00
0005432693713	1181	Economy	38300.00
0005432693708	1181	Economy	38300.00
0005432873386	1181	Economy	38300.00
0005432693710	1181	Economy	38300.00
0005432693725	1181	Economy	42200.00
0005432873387	1181	Economy	38300.00
0005432693717	1181	Economy	38300.00
0005432675455	1181	Economy	38300.00
0005432873407	1181	Economy	38300.00
0005432675462	1181	Economy	38300.00
0005432693711	1181	Economy	38300.00
0005432693724	1181	Economy	38300.00
0005432693698	1181	Economy	38300.00
0005432675470	1181	Economy	38300.00
0005432693721	1181	Economy	38300.00
0005432693714	1181	Economy	38300.00
0005432693719	1181	Economy	38300.00
0005432675464	1181	Economy	38300.00
0005432693715	1181	Economy	38300.00
0005432693712	1181	Economy	38300.00
0005432677654	1181	Economy	38300.00
0005432675459	1181	Economy	38300.00
0005432693705	1181	Economy	38300.00
0005432693703	1181	Economy	38300.00
0005432677655	1181	Economy	38300.00
0005432693696	1181	Economy	38300.00
0005432693699	1181	Economy	38300.00
0005432873408	1181	Economy	38300.00
0005432693697	1181	Economy	38300.00
0005432693700	1181	Economy	38300.00
0005432675467	1181	Economy	38300.00
0005432693723	1181	Economy	38300.00
0005432677657	1181	Economy	38300.00
0005432675457	1181	Economy	38300.00
0005432677658	1181	Economy	38300.00
0005432675456	1181	Economy	38300.00
0005432693722	1181	Economy	38300.00
0005432693720	1181	Economy	38300.00
0005432675461	1181	Economy	38300.00
0005432677656	1181	Economy	38300.00
0005432873396	1181	Economy	38300.00
0005432693701	1181	Economy	38300.00
0005432675458	1181	Economy	38300.00
0005432693702	1181	Economy	38300.00
0005432675468	1181	Economy	38300.00
0005432873443	17470	Business	115000.00
0005432677616	17470	Business	115000.00
0005432873448	17470	Business	115000.00
0005432675353	17470	Business	115000.00
0005432693474	17470	Business	115000.00
0005432675346	17470	Business	115000.00
0005432693415	17470	Business	115000.00
0005432873445	17470	Business	115000.00
0005432693570	17470	Business	115000.00
0005432693527	17470	Business	115000.00
0005432693379	17470	Business	115000.00
0005432693416	17470	Economy	38300.00
0005432675317	17470	Economy	38300.00
0005432873447	17470	Economy	38300.00
0005432693368	17470	Economy	38300.00
0005432693436	17470	Economy	38300.00
0005432675255	17470	Economy	38300.00
0005432693369	17470	Economy	38300.00
0005432693451	17470	Economy	42200.00
0005432693564	17470	Economy	42200.00
0005432693585	17470	Economy	42200.00
0005432693407	17470	Economy	38300.00
0005432677622	17470	Economy	38300.00
0005432693408	17470	Economy	38300.00
0005432693463	17470	Economy	38300.00
0005432693571	17470	Economy	38300.00
0005432693383	17470	Economy	38300.00
0005432693565	17470	Economy	38300.00
0005432675341	17470	Economy	38300.00
0005432693384	17470	Economy	38300.00
0005432693528	17470	Economy	38300.00
0005432693494	17470	Economy	38300.00
0005432675354	17470	Economy	38300.00
0005432675299	17470	Economy	38300.00
0005432693495	17470	Economy	38300.00
0005432675321	17470	Economy	38300.00
0005432873446	17470	Economy	38300.00
0005432693523	17470	Economy	38300.00
0005432873444	17470	Economy	38300.00
0005432693516	17470	Economy	38300.00
0005432693345	17470	Economy	38300.00
0005432693396	17470	Economy	38300.00
0005432675320	17470	Economy	38300.00
0005432675351	17470	Economy	38300.00
0005432693592	17470	Economy	38300.00
0005432693593	17470	Economy	38300.00
0005432873450	17470	Economy	38300.00
0005432675345	17470	Economy	38300.00
0005432873449	17470	Economy	38300.00
0005432675318	17470	Economy	38300.00
0005432693412	17470	Economy	38300.00
0005432693385	17470	Economy	38300.00
0005432693287	17470	Economy	38300.00
0005432693440	17470	Economy	38300.00
0005432675340	17470	Economy	38300.00
0005432675319	17470	Economy	38300.00
0005432693389	17470	Economy	38300.00
0005432675347	17470	Economy	38300.00
0005433156860	1159	Economy	15200.00
0005434435521	1159	Economy	15200.00
0005434435523	1159	Economy	13900.00
0005434435512	1159	Economy	13900.00
0005433156843	1159	Economy	13900.00
0005433156842	1159	Economy	13900.00
0005433156904	1159	Economy	13900.00
0005434435519	1159	Economy	13900.00
0005433156853	1159	Economy	13900.00
0005434435524	1159	Economy	13900.00
0005434435522	1159	Economy	13900.00
0005434435516	1159	Economy	13900.00
0005434435514	1159	Economy	13900.00
0005433156895	1159	Economy	13900.00
0005433156894	1159	Economy	13900.00
0005433156896	1159	Economy	13900.00
0005433156861	1159	Economy	13900.00
0005433156884	1159	Economy	13900.00
0005434435518	1159	Economy	13900.00
0005434435513	1159	Economy	13900.00
0005434435511	1159	Economy	13900.00
0005434435517	1159	Economy	13900.00
0005433156880	1159	Economy	13900.00
0005434435510	1159	Economy	13900.00
0005434435515	1159	Economy	13900.00
0005433156883	1159	Economy	13900.00
0005434435520	1159	Economy	13900.00
0005434435320	17313	Economy	15200.00
0005433156933	17313	Economy	15200.00
0005434435268	17313	Economy	15200.00
0005434435404	17313	Economy	13900.00
0005434435413	17313	Economy	13900.00
0005434435403	17313	Economy	13900.00
0005434435352	17313	Economy	13900.00
0005433156938	17313	Economy	13900.00
0005433156941	17313	Economy	13900.00
0005434435407	17313	Economy	13900.00
0005433156936	17313	Economy	13900.00
0005433156937	17313	Economy	13900.00
0005434435319	17313	Economy	13900.00
0005433156935	17313	Economy	13900.00
0005433156934	17313	Economy	13900.00
0005434435369	17313	Economy	13900.00
0005434435337	17313	Economy	13900.00
0005434435269	17313	Economy	13900.00
0005434435335	17313	Economy	13900.00
0005433156940	17313	Economy	13900.00
0005433156939	17313	Economy	13900.00
0005434435318	17313	Economy	13900.00
0005434435336	17313	Economy	13900.00
0005435086999	4047	Economy	8200.00
0005435087002	4047	Economy	7500.00
0005435928216	4047	Economy	7500.00
0005435928235	4047	Economy	7500.00
0005435086997	4047	Economy	7500.00
0005435087000	4047	Economy	7500.00
0005435928186	4047	Economy	7500.00
0005435087001	4047	Economy	7500.00
0005435086998	4047	Economy	7500.00
0005435928213	4047	Economy	7500.00
0005435928214	4047	Economy	7500.00
0005435928187	4047	Economy	7500.00
0005435928200	4047	Economy	7500.00
0005435087003	4047	Economy	7500.00
0005435086996	4047	Economy	7500.00
0005435086910	24407	Economy	8200.00
0005435086911	24407	Economy	7500.00
0005435086936	24407	Economy	7500.00
0005435928247	24407	Economy	7500.00
0005435086918	24407	Economy	7500.00
0005435928248	24407	Economy	7500.00
0005435086919	24407	Economy	7500.00
0005435086917	24407	Economy	7500.00
0005435928246	24407	Economy	7500.00
0005435086925	24407	Economy	7500.00
0005435086912	24407	Economy	7500.00
0005435928249	24407	Economy	7500.00
0005435086935	24407	Economy	7500.00
0005435928245	24407	Economy	7500.00
0005435086938	24407	Economy	7500.00
0005435086898	24407	Economy	7500.00
0005435928250	24407	Economy	7500.00
0005435086937	24407	Economy	7500.00
0005435551642	11058	Business	144300.00
0005435551644	11058	Economy	52900.00
0005435551629	11058	Economy	48100.00
0005435098585	11058	Economy	48100.00
0005435098584	11058	Economy	48100.00
0005435551646	11058	Economy	48100.00
0005435551653	11058	Economy	48100.00
0005435098573	11058	Economy	48100.00
0005435551676	11058	Economy	48100.00
0005435551643	11058	Economy	48100.00
0005435098579	11058	Economy	48100.00
0005435551648	11058	Economy	48100.00
0005435551670	11058	Economy	48100.00
0005435551626	11058	Economy	48100.00
0005435098580	11058	Economy	48100.00
0005435098581	11058	Economy	48100.00
0005435551645	11058	Economy	48100.00
0005435551686	11058	Economy	48100.00
0005435551622	11058	Economy	48100.00
0005435098582	11058	Economy	48100.00
0005435551652	11058	Economy	48100.00
0005435551647	11058	Economy	48100.00
0005435551669	11058	Economy	48100.00
0005435098578	11058	Economy	48100.00
0005435098571	11058	Economy	48100.00
0005435551712	17007	Business	144300.00
0005435551723	17007	Business	144300.00
0005435551709	17007	Business	144300.00
0005435551721	17007	Economy	52900.00
0005435551714	17007	Economy	48100.00
0005435098601	17007	Economy	48100.00
0005435551716	17007	Economy	48100.00
0005435551720	17007	Economy	48100.00
0005435098602	17007	Economy	48100.00
0005435551713	17007	Economy	48100.00
0005435098604	17007	Economy	48100.00
0005435551710	17007	Economy	48100.00
0005435551724	17007	Economy	48100.00
0005435551711	17007	Economy	48100.00
0005435551715	17007	Economy	48100.00
0005435098599	17007	Economy	48100.00
0005435551718	17007	Economy	48100.00
0005435098598	17007	Economy	48100.00
0005435551707	17007	Economy	48100.00
0005435098600	17007	Economy	48100.00
0005435098603	17007	Economy	48100.00
0005435551719	17007	Economy	48100.00
0005435551722	17007	Economy	48100.00
0005435551708	17007	Economy	48100.00
0005435551717	17007	Economy	48100.00
0005434964431	18233	Business	203300.00
0005433261783	18233	Business	203300.00
0005434964342	18233	Business	203300.00
0005433261773	18233	Business	203300.00
0005433261781	18233	Business	203300.00
0005433261784	18233	Business	203300.00
0005434964469	18233	Business	203300.00
0005433261792	18233	Business	203300.00
0005434964492	18233	Business	203300.00
0005433261782	18233	Economy	74500.00
0005434964446	18233	Economy	67800.00
0005433261791	18233	Economy	67800.00
0005433261778	18233	Economy	67800.00
0005433261785	18233	Economy	67800.00
0005433261787	18233	Economy	67800.00
0005434964341	18233	Economy	67800.00
0005434964495	18233	Economy	67800.00
0005433261793	18233	Economy	67800.00
0005433261790	18233	Economy	67800.00
0005433261777	18233	Economy	67800.00
0005434964519	18233	Economy	67800.00
0005434964418	18233	Economy	67800.00
0005434964520	18233	Economy	67800.00
0005433261788	18233	Economy	67800.00
0005434964496	18233	Economy	67800.00
0005433261789	18233	Economy	67800.00
0005434964447	18233	Economy	67800.00
0005434964488	18233	Economy	67800.00
0005434964470	18233	Economy	67800.00
0005433261786	18233	Economy	67800.00
0005434964421	18233	Economy	67800.00
0005434964452	18233	Economy	67800.00
0005433261780	18233	Economy	67800.00
0005434964408	18233	Economy	67800.00
0005434964448	18233	Economy	67800.00
0005434964518	18233	Economy	67800.00
0005434964422	18233	Economy	67800.00
0005434964481	18233	Economy	67800.00
0005434964482	18233	Economy	67800.00
0005433261776	18233	Economy	67800.00
0005434964407	18233	Economy	67800.00
0005433261779	18233	Economy	67800.00
0005433261775	18233	Economy	67800.00
0005434964439	18233	Economy	67800.00
0005434964468	18233	Economy	67800.00
0005433261774	18233	Economy	67800.00
0005434964537	18233	Economy	67800.00
0005434964487	18233	Economy	67800.00
0005434964430	18233	Economy	67800.00
0005434626171	4859	Business	44200.00
0005433194897	4859	Business	44200.00
0005435907564	4859	Business	44200.00
0005434626167	4859	Business	44200.00
0005433194888	4859	Economy	14700.00
0005433194889	4859	Economy	16200.00
0005433194890	4859	Economy	16200.00
0005435907570	4859	Economy	14700.00
0005434626165	4859	Economy	14700.00
0005434626164	4859	Economy	14700.00
0005434626168	4859	Economy	14700.00
0005434626169	4859	Economy	14700.00
0005434626172	4859	Economy	14700.00
0005433194896	4859	Economy	14700.00
0005434626166	4859	Economy	14700.00
0005435907574	4859	Economy	14700.00
0005434626170	4859	Economy	14700.00
0005435907611	32887	Business	44200.00
0005435907615	32887	Economy	14700.00
0005435907614	32887	Economy	14700.00
0005433194914	32887	Economy	14700.00
0005433194919	32887	Economy	14700.00
0005435907613	32887	Economy	14700.00
0005434626085	32887	Economy	14700.00
0005434626094	32887	Economy	14700.00
0005434626095	32887	Economy	14700.00
0005434626122	32887	Economy	14700.00
0005433194917	32887	Economy	14700.00
0005433194920	32887	Economy	14700.00
0005433194918	32887	Economy	14700.00
0005433194915	32887	Economy	14700.00
0005434626110	32887	Economy	14700.00
0005433194916	32887	Economy	14700.00
0005435907612	32887	Economy	14700.00
0005433194921	32887	Economy	14700.00
0005435937489	13759	Economy	3400.00
0005435937497	13759	Economy	3400.00
0005435937491	13759	Economy	3400.00
0005435785740	13759	Economy	3100.00
0005432195740	13759	Economy	3100.00
0005435785732	13759	Economy	3100.00
0005435785699	13759	Economy	3100.00
0005435785800	13759	Economy	3100.00
0005435785706	13759	Economy	3100.00
0005435785559	13759	Economy	3100.00
0005435785760	13759	Economy	3100.00
0005435937485	13759	Economy	3100.00
0005435937492	13759	Economy	3100.00
0005435787373	13759	Economy	3100.00
0005435937490	13759	Economy	3100.00
0005435785761	13759	Economy	3100.00
0005435785801	13759	Economy	3100.00
0005435785786	13759	Economy	3100.00
0005435937488	13759	Economy	3100.00
0005435785799	13759	Economy	3100.00
0005435937494	13759	Economy	3100.00
0005435785741	13759	Economy	3100.00
0005435785789	13759	Economy	3100.00
0005435785698	13759	Economy	3100.00
0005435937495	13759	Economy	3100.00
0005435937496	13759	Economy	3100.00
0005435785781	13759	Economy	3100.00
0005435785854	13759	Economy	3100.00
0005435785695	13759	Economy	3100.00
0005435937493	13759	Economy	3100.00
0005435937487	13759	Economy	3100.00
0005435787372	13759	Economy	3100.00
0005435785670	13759	Economy	3100.00
0005435785798	13759	Economy	3100.00
0005435785707	13759	Economy	3100.00
0005435785726	13759	Economy	3100.00
0005435785733	13759	Economy	3100.00
0005435787374	13759	Economy	3100.00
0005435937486	13759	Economy	3100.00
0005435785727	13759	Economy	3100.00
0005435785788	13759	Economy	3100.00
0005435785771	13759	Economy	3100.00
0005435785714	13759	Economy	3100.00
0005435785783	13759	Economy	3100.00
0005435785700	13759	Economy	3100.00
0005435785560	13759	Economy	3100.00
0005435785782	13759	Economy	3100.00
0005435786043	27428	Economy	3400.00
0005435786047	27428	Economy	3400.00
0005435786050	27428	Economy	3400.00
0005435786044	27428	Economy	3400.00
0005435786063	27428	Economy	3100.00
0005435786058	27428	Economy	3100.00
0005435786070	27428	Economy	3100.00
0005435786065	27428	Economy	3100.00
0005435786048	27428	Economy	3100.00
0005435786075	27428	Economy	3100.00
0005435787397	27428	Economy	3100.00
0005435786052	27428	Economy	3100.00
0005435937431	27428	Economy	3100.00
0005435786064	27428	Economy	3100.00
0005435786071	27428	Economy	3100.00
0005435786041	27428	Economy	3100.00
0005435786053	27428	Economy	3100.00
0005435786042	27428	Economy	3100.00
0005435786062	27428	Economy	3100.00
0005435786067	27428	Economy	3100.00
0005435786055	27428	Economy	3100.00
0005435786054	27428	Economy	3100.00
0005435786072	27428	Economy	3100.00
0005435786068	27428	Economy	3100.00
0005435786061	27428	Economy	3100.00
0005435786051	27428	Economy	3100.00
0005435937420	27428	Economy	3100.00
0005435786069	27428	Economy	3100.00
0005435786056	27428	Economy	3100.00
0005435786040	27428	Economy	3100.00
0005432190709	27428	Economy	3100.00
0005432190706	27428	Economy	3100.00
0005435786066	27428	Economy	3100.00
0005435937437	27428	Economy	3100.00
0005435786049	27428	Economy	3100.00
0005435786046	27428	Economy	3100.00
0005432190708	27428	Economy	3100.00
0005432190707	27428	Economy	3100.00
0005435786060	27428	Economy	3100.00
0005435786057	27428	Economy	3100.00
0005435786059	27428	Economy	3100.00
0005435937434	27428	Economy	3100.00
0005435786073	27428	Economy	3100.00
0005435786074	27428	Economy	3100.00
0005435937421	27428	Economy	3100.00
0005435786045	27428	Economy	3100.00
0005435787396	27428	Economy	3100.00
0005434408409	20290	Business	12000.00
0005434408704	20290	Business	12000.00
0005434408481	20290	Business	12000.00
0005435311357	20290	Business	12000.00
0005434408562	20290	Business	12000.00
0005435311364	20290	Business	12000.00
0005434408451	20290	Business	12000.00
0005435311385	20290	Business	12000.00
0005435311355	20290	Business	12000.00
0005434408629	20290	Business	12000.00
0005434408471	20290	Business	12000.00
0005434408584	20290	Economy	4000.00
0005435311382	20290	Economy	4000.00
0005435311361	20290	Economy	4000.00
0005435311365	20290	Economy	4000.00
0005435311366	20290	Economy	4000.00
0005434408592	20290	Economy	4000.00
0005435311367	20290	Economy	4000.00
0005434408449	20290	Economy	4000.00
0005434408359	20290	Economy	4000.00
0005434408411	20290	Economy	4000.00
0005434408265	20290	Economy	4400.00
0005434408698	20290	Economy	4400.00
0005434408705	20290	Economy	4400.00
0005434408689	20290	Economy	4400.00
0005435311362	20290	Economy	4400.00
0005434408586	20290	Economy	4000.00
0005435311359	20290	Economy	4000.00
0005434408741	20290	Economy	4000.00
0005434408324	20290	Economy	4000.00
0005434408690	20290	Economy	4000.00
0005434408408	20290	Economy	4000.00
0005434408676	20290	Economy	4000.00
0005435311363	20290	Economy	4000.00
0005434408742	20290	Economy	4000.00
0005434408412	20290	Economy	4000.00
0005434408399	20290	Economy	4000.00
0005434408585	20290	Economy	4000.00
0005434408726	20290	Economy	4000.00
0005435311360	20290	Economy	4000.00
0005434408561	20290	Economy	4000.00
0005435311377	20290	Economy	4000.00
0005434408700	20290	Economy	4000.00
0005434408558	20290	Economy	4000.00
0005435311356	20290	Economy	4000.00
0005434408493	20290	Economy	4000.00
0005434408527	20290	Economy	4000.00
0005434408958	20290	Economy	4000.00
0005434408480	20290	Economy	4000.00
0005434408957	20290	Economy	4000.00
0005434408733	20290	Economy	4000.00
0005434408563	20290	Economy	4000.00
0005434408628	20290	Economy	4000.00
0005432058467	20290	Economy	4000.00
0005435311373	20290	Economy	4000.00
0005434408634	20290	Economy	4000.00
0005434408487	20290	Economy	4000.00
0005432058469	20290	Economy	4000.00
0005435311374	20290	Economy	4000.00
0005434408450	20290	Economy	4000.00
0005434408635	20290	Economy	4000.00
0005435311381	20290	Economy	4000.00
0005432058466	20290	Economy	4000.00
0005435311371	20290	Economy	4000.00
0005435311369	20290	Economy	4000.00
0005435311378	20290	Economy	4000.00
0005434408560	20290	Economy	4000.00
0005435311376	20290	Economy	4000.00
0005434408621	20290	Economy	4000.00
0005434408636	20290	Economy	4000.00
0005435311384	20290	Economy	4000.00
0005435311370	20290	Economy	4000.00
0005435311386	20290	Economy	4000.00
0005435311368	20290	Economy	4000.00
0005435311380	20290	Economy	4000.00
0005434408595	20290	Economy	4000.00
0005434408605	20290	Economy	4000.00
0005434408591	20290	Economy	4000.00
0005435311375	20290	Economy	4000.00
0005434408452	20290	Economy	4000.00
0005435311383	20290	Economy	4000.00
0005434408435	20290	Economy	4000.00
0005434408673	20290	Economy	4000.00
0005434408624	20290	Economy	4000.00
0005434408557	20290	Economy	4000.00
0005434408407	20290	Economy	4000.00
0005435311358	20290	Economy	4000.00
0005434408829	20290	Economy	4000.00
0005434408521	20290	Economy	4000.00
0005435311372	20290	Economy	4000.00
0005435311379	20290	Economy	4000.00
0005434408266	20290	Economy	4000.00
0005432058468	20290	Economy	4000.00
0005434408727	20290	Economy	4000.00
0005434409116	26962	Business	12000.00
0005434409141	26962	Business	12000.00
0005434409120	26962	Business	12000.00
0005434409110	26962	Business	12000.00
0005434409155	26962	Business	12000.00
0005432154090	26962	Business	12000.00
0005434409127	26962	Business	12000.00
0005435311202	26962	Business	12000.00
0005432154091	26962	Business	12000.00
0005432154092	26962	Economy	4000.00
0005434409115	26962	Economy	4000.00
0005434409157	26962	Economy	4000.00
0005434409144	26962	Economy	4000.00
0005434409137	26962	Economy	4000.00
0005434409097	26962	Economy	4000.00
0005434409134	26962	Economy	4000.00
0005434409143	26962	Economy	4000.00
0005434409135	26962	Economy	4000.00
0005434409100	26962	Economy	4400.00
0005434409129	26962	Economy	4400.00
0005434409104	26962	Economy	4400.00
0005435311231	26962	Economy	4400.00
0005434409098	26962	Economy	4400.00
0005435311226	26962	Economy	4000.00
0005434409106	26962	Economy	4000.00
0005434409125	26962	Economy	4000.00
0005434409108	26962	Economy	4000.00
0005435311152	26962	Economy	4000.00
0005434409103	26962	Economy	4000.00
0005434409146	26962	Economy	4000.00
0005435311214	26962	Economy	4000.00
0005434409151	26962	Economy	4000.00
0005432154088	26962	Economy	4000.00
0005434409099	26962	Economy	4000.00
0005434409105	26962	Economy	4000.00
0005435311188	26962	Economy	4000.00
0005435311228	26962	Economy	4000.00
0005434409102	26962	Economy	4000.00
0005435311220	26962	Economy	4000.00
0005434409148	26962	Economy	4000.00
0005432154086	26962	Economy	4000.00
0005434409145	26962	Economy	4000.00
0005434409131	26962	Economy	4000.00
0005434409096	26962	Economy	4000.00
0005434409118	26962	Economy	4000.00
0005434409119	26962	Economy	4000.00
0005434409156	26962	Economy	4000.00
0005434409114	26962	Economy	4000.00
0005435311227	26962	Economy	4000.00
0005435311206	26962	Economy	4000.00
0005434409138	26962	Economy	4000.00
0005434409121	26962	Economy	4000.00
0005434409122	26962	Economy	4000.00
0005432154093	26962	Economy	4000.00
0005435311212	26962	Economy	4000.00
0005435311197	26962	Economy	4000.00
0005434409123	26962	Economy	4000.00
0005435311215	26962	Economy	4000.00
0005434409154	26962	Economy	4000.00
0005435311207	26962	Economy	4000.00
0005434409113	26962	Economy	4000.00
0005434409124	26962	Economy	4000.00
0005434409095	26962	Economy	4000.00
0005434409132	26962	Economy	4000.00
0005435311230	26962	Economy	4000.00
0005434409128	26962	Economy	4000.00
0005434409149	26962	Economy	4000.00
0005434409136	26962	Economy	4000.00
0005432154089	26962	Economy	4000.00
0005434409142	26962	Economy	4000.00
0005434409133	26962	Economy	4000.00
0005434409140	26962	Economy	4000.00
0005434409117	26962	Economy	4000.00
0005434409150	26962	Economy	4000.00
0005434409107	26962	Economy	4000.00
0005434409139	26962	Economy	4000.00
0005435311189	26962	Economy	4000.00
0005434409109	26962	Economy	4000.00
0005432154087	26962	Economy	4000.00
0005434409130	26962	Economy	4000.00
0005434409111	26962	Economy	4000.00
0005435311198	26962	Economy	4000.00
0005434409147	26962	Economy	4000.00
0005434409152	26962	Economy	4000.00
0005434409126	26962	Economy	4000.00
0005434409153	26962	Economy	4000.00
0005434409112	26962	Economy	4000.00
0005434409101	26962	Economy	4000.00
0005433124179	5680	Business	43300.00
0005432109765	5680	Business	43300.00
0005434319682	5680	Business	43300.00
0005434319687	5680	Business	43300.00
0005433124237	5680	Economy	14400.00
0005433124248	5680	Economy	14400.00
0005434311261	5680	Economy	14400.00
0005433124202	5680	Economy	15900.00
0005434319688	5680	Economy	15900.00
0005433124188	5680	Economy	15900.00
0005434311282	5680	Economy	15900.00
0005433124249	5680	Economy	14400.00
0005433124238	5680	Economy	14400.00
0005434311262	5680	Economy	14400.00
0005433124223	5680	Economy	14400.00
0005434319681	5680	Economy	14400.00
0005434319684	5680	Economy	14400.00
0005432109764	5680	Economy	14400.00
0005432109763	5680	Economy	14400.00
0005434319692	5680	Economy	14400.00
0005434319686	5680	Economy	14400.00
0005433124221	5680	Economy	14400.00
0005433124178	5680	Economy	14400.00
0005434319691	5680	Economy	14400.00
0005433124263	5680	Economy	14400.00
0005434319690	5680	Economy	14400.00
0005433124196	5680	Economy	14400.00
0005433124187	5680	Economy	14400.00
0005434319680	5680	Economy	14400.00
0005434319683	5680	Economy	14400.00
0005433124149	5680	Economy	14400.00
0005433124215	5680	Economy	14400.00
0005434319689	5680	Economy	14400.00
0005433124150	5680	Economy	14400.00
0005434311283	5680	Economy	14400.00
0005433124214	5680	Economy	14400.00
0005433124172	5680	Economy	14400.00
0005432109762	5680	Economy	14400.00
0005434319685	5680	Economy	14400.00
0005433124385	15671	Business	43300.00
0005434319570	15671	Business	43300.00
0005434319568	15671	Business	43300.00
0005433124372	15671	Business	43300.00
0005434319561	15671	Business	43300.00
0005434311240	15671	Business	43300.00
0005433124370	15671	Business	43300.00
0005433124374	15671	Economy	14400.00
0005433124382	15671	Economy	14400.00
0005433124378	15671	Economy	14400.00
0005434311238	15671	Economy	15900.00
0005434319546	15671	Economy	15900.00
0005433124379	15671	Economy	15900.00
0005434319566	15671	Economy	14400.00
0005433124387	15671	Economy	14400.00
0005434319564	15671	Economy	14400.00
0005434319572	15671	Economy	14400.00
0005433124367	15671	Economy	14400.00
0005433124376	15671	Economy	14400.00
0005433124369	15671	Economy	14400.00
0005433124366	15671	Economy	14400.00
0005434319524	15671	Economy	14400.00
0005433124371	15671	Economy	14400.00
0005433124388	15671	Economy	14400.00
0005434319579	15671	Economy	14400.00
0005433124386	15671	Economy	14400.00
0005434311239	15671	Economy	14400.00
0005434319565	15671	Economy	14400.00
0005433124375	15671	Economy	14400.00
0005434319562	15671	Economy	14400.00
0005434311241	15671	Economy	14400.00
0005434312354	15671	Economy	14400.00
0005433124373	15671	Economy	14400.00
0005433124380	15671	Economy	14400.00
0005433124365	15671	Economy	14400.00
0005433124377	15671	Economy	14400.00
0005434319567	15671	Economy	14400.00
0005433124384	15671	Economy	14400.00
0005433124368	15671	Economy	14400.00
0005434319571	15671	Economy	14400.00
0005433124381	15671	Economy	14400.00
0005434312341	15671	Economy	14400.00
0005433124383	15671	Economy	14400.00
0005435220335	24977	Economy	15500.00
0005435220334	24977	Economy	15500.00
0005435220340	24977	Economy	15500.00
0005435217737	24977	Economy	15500.00
0005435217741	24977	Economy	15500.00
0005435220338	24977	Economy	15500.00
0005435220337	24977	Economy	15500.00
0005435217716	24977	Economy	15500.00
0005435217726	24977	Economy	15500.00
0005435220339	24977	Economy	15500.00
0005435220344	24977	Economy	15500.00
0005435217717	24977	Economy	15500.00
0005434189234	8959	Economy	27400.00
0005434484489	8959	Economy	24900.00
0005434484488	8959	Economy	24900.00
0005434189259	8959	Economy	24900.00
0005434189253	8959	Economy	24900.00
0005434484487	8959	Economy	24900.00
0005434189262	8959	Economy	24900.00
0005434484493	8959	Economy	24900.00
0005434484490	8959	Economy	24900.00
0005434484491	8959	Economy	24900.00
0005434189260	8959	Economy	24900.00
0005434189249	8959	Economy	24900.00
0005434189261	8959	Economy	24900.00
0005434189236	8959	Economy	24900.00
0005434189250	8959	Economy	24900.00
0005434484492	8959	Economy	24900.00
0005434189258	8959	Economy	24900.00
0005434189305	16661	Economy	24900.00
0005434189301	16661	Economy	24900.00
0005434189304	16661	Economy	24900.00
0005434189306	16661	Economy	24900.00
0005434189302	16661	Economy	24900.00
0005434189303	16661	Economy	24900.00
0005434484450	16661	Economy	24900.00
0005433124367	7629	Business	11100.00
0005433124388	7629	Business	11100.00
0005433124373	7629	Business	11100.00
0005433124386	7629	Business	11100.00
0005433124372	7629	Economy	3700.00
0005433124365	7629	Economy	3700.00
0005433124369	7629	Economy	4100.00
0005433124382	7629	Economy	4100.00
0005433124377	7629	Economy	4100.00
0005433124381	7629	Economy	3700.00
0005433124376	7629	Economy	3700.00
0005433124383	7629	Economy	3700.00
0005433124379	7629	Economy	3700.00
0005433124375	7629	Economy	3700.00
0005433124371	7629	Economy	3700.00
0005433124366	7629	Economy	3700.00
0005433124368	7629	Economy	3700.00
0005433124378	7629	Economy	3700.00
0005433124370	7629	Economy	3700.00
0005433124385	7629	Economy	3700.00
0005433124387	7629	Economy	3700.00
0005433124374	7629	Economy	3700.00
0005433124380	7629	Economy	3700.00
0005433124384	7629	Economy	3700.00
0005433450446	7628	Business	11100.00
0005433450445	7628	Business	11100.00
0005432693744	7628	Business	11100.00
0005432693738	7628	Business	11100.00
0005433450433	7628	Business	11100.00
0005433450451	7628	Business	11100.00
0005432693742	7628	Business	11100.00
0005432721499	7628	Business	11100.00
0005432693737	7628	Business	11100.00
0005432693732	7628	Business	11100.00
0005432721482	7628	Economy	3700.00
0005433450450	7628	Economy	3700.00
0005432071638	7628	Economy	3700.00
0005433450437	7628	Economy	3700.00
0005432693741	7628	Economy	3700.00
0005432071637	7628	Economy	3700.00
0005432721493	7628	Economy	3700.00
0005432721488	7628	Economy	3700.00
0005432693751	7628	Economy	3700.00
0005432721498	7628	Economy	3700.00
0005432071636	7628	Economy	4100.00
0005432721487	7628	Economy	4100.00
0005432693736	7628	Economy	4100.00
0005432693752	7628	Economy	4100.00
0005433450449	7628	Economy	3700.00
0005432693739	7628	Economy	3700.00
0005432721484	7628	Economy	3700.00
0005433450434	7628	Economy	3700.00
0005432693747	7628	Economy	3700.00
0005433450441	7628	Economy	3700.00
0005432693757	7628	Economy	3700.00
0005432721490	7628	Economy	3700.00
0005433450439	7628	Economy	3700.00
0005432693727	7628	Economy	3700.00
0005432721489	7628	Economy	3700.00
0005432071639	7628	Economy	3700.00
0005432721478	7628	Economy	3700.00
0005433450447	7628	Economy	3700.00
0005432721494	7628	Economy	3700.00
0005432721483	7628	Economy	3700.00
0005432693734	7628	Economy	3700.00
0005432721492	7628	Economy	3700.00
0005433450438	7628	Economy	3700.00
0005432721485	7628	Economy	3700.00
0005432721473	7628	Economy	3700.00
0005432693728	7628	Economy	3700.00
0005433450452	7628	Economy	3700.00
0005432693755	7628	Economy	3700.00
0005433450442	7628	Economy	3700.00
0005433450435	7628	Economy	3700.00
0005432693729	7628	Economy	3700.00
0005432721479	7628	Economy	3700.00
0005432693749	7628	Economy	3700.00
0005432693731	7628	Economy	3700.00
0005432721497	7628	Economy	3700.00
0005432693733	7628	Economy	3700.00
0005432721474	7628	Economy	3700.00
0005432721480	7628	Economy	3700.00
0005432693756	7628	Economy	3700.00
0005432693746	7628	Economy	3700.00
0005432721491	7628	Economy	3700.00
0005433450440	7628	Economy	3700.00
0005433450444	7628	Economy	3700.00
0005433450431	7628	Economy	3700.00
0005433450443	7628	Economy	3700.00
0005432721475	7628	Economy	3700.00
0005432693748	7628	Economy	3700.00
0005432721476	7628	Economy	3700.00
0005433450436	7628	Economy	3700.00
0005432721495	7628	Economy	3700.00
0005432721496	7628	Economy	3700.00
0005433450432	7628	Economy	3700.00
0005432693735	7628	Economy	3700.00
0005432721481	7628	Economy	3700.00
0005432693730	7628	Economy	3700.00
0005432693745	7628	Economy	3700.00
0005432693750	7628	Economy	3700.00
0005432721486	7628	Economy	3700.00
0005432721472	7628	Economy	3700.00
0005432693754	7628	Economy	3700.00
0005432693743	7628	Economy	3700.00
0005432693753	7628	Economy	3700.00
0005433450448	7628	Economy	3700.00
0005432721477	7628	Economy	3700.00
0005432693740	7628	Economy	3700.00
0005432693527	30438	Business	11100.00
0005432693385	30438	Business	11100.00
0005432693345	30438	Business	11100.00
0005432693440	30438	Business	11100.00
0005432693585	30438	Business	11100.00
0005433450210	30438	Business	11100.00
0005432693474	30438	Economy	3700.00
0005432693523	30438	Economy	3700.00
0005432693408	30438	Economy	3700.00
0005433450209	30438	Economy	3700.00
0005433450193	30438	Economy	4100.00
0005432693463	30438	Economy	4100.00
0005433450305	30438	Economy	4100.00
0005432693494	30438	Economy	4100.00
0005433450306	30438	Economy	4100.00
0005432693592	30438	Economy	3700.00
0005432693571	30438	Economy	3700.00
0005433450246	30438	Economy	3700.00
0005432693412	30438	Economy	3700.00
0005433450315	30438	Economy	3700.00
0005432693593	30438	Economy	3700.00
0005433450212	30438	Economy	3700.00
0005432693570	30438	Economy	3700.00
0005432693369	30438	Economy	3700.00
0005433450231	30438	Economy	3700.00
0005432693407	30438	Economy	3700.00
0005433450185	30438	Economy	3700.00
0005432693396	30438	Economy	3700.00
0005432693451	30438	Economy	3700.00
0005433450196	30438	Economy	3700.00
0005432693564	30438	Economy	3700.00
0005433450362	30438	Economy	3700.00
0005433450199	30438	Economy	3700.00
0005432693516	30438	Economy	3700.00
0005433450232	30438	Economy	3700.00
0005432693368	30438	Economy	3700.00
0005432693565	30438	Economy	3700.00
0005432693416	30438	Economy	3700.00
0005432693287	30438	Economy	3700.00
0005433450247	30438	Economy	3700.00
0005433450211	30438	Economy	3700.00
0005433450279	30438	Economy	3700.00
0005432693379	30438	Economy	3700.00
0005433450228	30438	Economy	3700.00
0005432693415	30438	Economy	3700.00
0005432693528	30438	Economy	3700.00
0005432693383	30438	Economy	3700.00
0005432693384	30438	Economy	3700.00
0005432693436	30438	Economy	3700.00
0005432693495	30438	Economy	3700.00
0005433450208	30438	Economy	3700.00
0005433450291	30438	Economy	3700.00
0005432693389	30438	Economy	3700.00
0005433450255	30438	Economy	3700.00
0005433450248	30438	Economy	3700.00
0005433450292	30438	Economy	3700.00
0005433124149	30439	Business	11100.00
0005432721270	30439	Business	11100.00
0005433124172	30439	Business	11100.00
0005433124196	30439	Business	11100.00
0005433124179	30439	Business	11100.00
0005432721305	30439	Business	11100.00
0005433722360	30439	Economy	3700.00
0005433124221	30439	Economy	3700.00
0005433124237	30439	Economy	3700.00
0005433722357	30439	Economy	3700.00
0005433124223	30439	Economy	4100.00
0005432721306	30439	Economy	4100.00
0005432721282	30439	Economy	4100.00
0005433722361	30439	Economy	4100.00
0005433124248	30439	Economy	3700.00
0005433124238	30439	Economy	3700.00
0005432721178	30439	Economy	3700.00
0005432721299	30439	Economy	3700.00
0005432721277	30439	Economy	3700.00
0005433722362	30439	Economy	3700.00
0005432721180	30439	Economy	3700.00
0005432721303	30439	Economy	3700.00
0005432721238	30439	Economy	3700.00
0005432721257	30439	Economy	3700.00
0005433124187	30439	Economy	3700.00
0005433722356	30439	Economy	3700.00
0005433124215	30439	Economy	3700.00
0005432721276	30439	Economy	3700.00
0005433124263	30439	Economy	3700.00
0005433124202	30439	Economy	3700.00
0005433722358	30439	Economy	3700.00
0005433124249	30439	Economy	3700.00
0005433124214	30439	Economy	3700.00
0005433722359	30439	Economy	3700.00
0005433124188	30439	Economy	3700.00
0005432721247	30439	Economy	3700.00
0005432721214	30439	Economy	3700.00
0005433124150	30439	Economy	3700.00
0005432721179	30439	Economy	3700.00
0005432721269	30439	Economy	3700.00
0005432721304	30439	Economy	3700.00
0005432721307	30439	Economy	3700.00
0005432721298	30439	Economy	3700.00
0005432721286	30439	Economy	3700.00
0005433124178	30439	Economy	3700.00
0005433193228	1411	Business	70400.00
0005434587172	1411	Business	70400.00
0005433525270	1411	Business	70400.00
0005432968871	1411	Business	70400.00
0005432928029	1411	Business	70400.00
0005433193190	1411	Business	70400.00
0005433193171	1411	Business	70400.00
0005433525273	1411	Business	70400.00
0005433193189	1411	Business	70400.00
0005434587160	1411	Business	70400.00
0005434587159	1411	Business	70400.00
0005432928081	1411	Economy	23500.00
0005434587179	1411	Economy	23500.00
0005433193215	1411	Economy	23500.00
0005432928040	1411	Economy	23500.00
0005434513637	1411	Economy	23500.00
0005434587161	1411	Economy	23500.00
0005432928080	1411	Economy	23500.00
0005434587165	1411	Economy	23500.00
0005434513636	1411	Economy	25800.00
0005434587166	1411	Economy	25800.00
0005432271066	1411	Economy	25800.00
0005433193169	1411	Economy	23500.00
0005434587171	1411	Economy	23500.00
0005433525278	1411	Economy	23500.00
0005433724904	1411	Economy	23500.00
0005434587183	1411	Economy	23500.00
0005434515025	1411	Economy	23500.00
0005433193170	1411	Economy	23500.00
0005433525275	1411	Economy	23500.00
0005432928041	1411	Economy	23500.00
0005434587158	1411	Economy	23500.00
0005433525272	1411	Economy	23500.00
0005434587178	1411	Economy	23500.00
0005434587181	1411	Economy	23500.00
0005434587168	1411	Economy	23500.00
0005434587164	1411	Economy	23500.00
0005434515023	1411	Economy	23500.00
0005433193307	1411	Economy	23500.00
0005434515024	1411	Economy	23500.00
0005432271068	1411	Economy	23500.00
0005432928074	1411	Economy	23500.00
0005433193284	1411	Economy	23500.00
0005433193237	1411	Economy	23500.00
0005434587175	1411	Economy	23500.00
0005433724906	1411	Economy	23500.00
0005433193308	1411	Economy	23500.00
0005433525277	1411	Economy	23500.00
0005434587167	1411	Economy	23500.00
0005433724905	1411	Economy	23500.00
0005434587177	1411	Economy	23500.00
0005433724908	1411	Economy	23500.00
0005433525276	1411	Economy	23500.00
0005433525279	1411	Economy	23500.00
0005432271065	1411	Economy	23500.00
0005433525280	1411	Economy	23500.00
0005433525274	1411	Economy	23500.00
0005432968870	1411	Economy	23500.00
0005434587173	1411	Economy	23500.00
0005434587162	1411	Economy	23500.00
0005434587163	1411	Economy	23500.00
0005434587182	1411	Economy	23500.00
0005434587169	1411	Economy	23500.00
0005433525271	1411	Economy	23500.00
0005434587176	1411	Economy	23500.00
0005434587157	1411	Economy	23500.00
0005434587170	1411	Economy	23500.00
0005432271067	1411	Economy	23500.00
0005433724907	1411	Economy	23500.00
0005434587180	1411	Economy	23500.00
0005434587174	1411	Economy	23500.00
0005433525212	18499	Business	70400.00
0005434587047	18499	Business	70400.00
0005434586931	18499	Business	70400.00
0005434586977	18499	Business	70400.00
0005434586927	18499	Business	70400.00
0005433193339	18499	Business	70400.00
0005434586896	18499	Business	70400.00
0005434587055	18499	Business	70400.00
0005432928098	18499	Economy	23500.00
0005434586960	18499	Economy	23500.00
0005434586958	18499	Economy	23500.00
0005433724879	18499	Economy	23500.00
0005433193334	18499	Economy	23500.00
0005433525128	18499	Economy	23500.00
0005433193341	18499	Economy	25800.00
0005433724875	18499	Economy	25800.00
0005433525140	18499	Economy	25800.00
0005434586954	18499	Economy	23500.00
0005433525187	18499	Economy	23500.00
0005434587007	18499	Economy	23500.00
0005433525180	18499	Economy	23500.00
0005433724878	18499	Economy	23500.00
0005434586847	18499	Economy	23500.00
0005434586923	18499	Economy	23500.00
0005432928102	18499	Economy	23500.00
0005434514997	18499	Economy	23500.00
0005433193337	18499	Economy	23500.00
0005434514999	18499	Economy	23500.00
0005433525181	18499	Economy	23500.00
0005433525093	18499	Economy	23500.00
0005433525158	18499	Economy	23500.00
0005434586922	18499	Economy	23500.00
0005433525214	18499	Economy	23500.00
0005434586876	18499	Economy	23500.00
0005434586892	18499	Economy	23500.00
0005434586975	18499	Economy	23500.00
0005433724854	18499	Economy	23500.00
0005432968889	18499	Economy	23500.00
0005434586895	18499	Economy	23500.00
0005432928101	18499	Economy	23500.00
0005432968890	18499	Economy	23500.00
0005434586913	18499	Economy	23500.00
0005432928099	18499	Economy	23500.00
0005432928100	18499	Economy	23500.00
0005434586829	18499	Economy	23500.00
0005433193338	18499	Economy	23500.00
0005434586996	18499	Economy	23500.00
0005433193336	18499	Economy	23500.00
0005433193332	18499	Economy	23500.00
0005434586914	18499	Economy	23500.00
0005434515001	18499	Economy	23500.00
0005433193335	18499	Economy	23500.00
0005433724877	18499	Economy	23500.00
0005434586912	18499	Economy	23500.00
0005433525152	18499	Economy	23500.00
0005433193330	18499	Economy	23500.00
0005433193333	18499	Economy	23500.00
0005433724832	18499	Economy	23500.00
0005434586959	18499	Economy	23500.00
0005434587027	18499	Economy	23500.00
0005434514998	18499	Economy	23500.00
0005433525213	18499	Economy	23500.00
0005434586877	18499	Economy	23500.00
0005434586943	18499	Economy	23500.00
0005434514996	18499	Economy	23500.00
0005433525169	18499	Economy	23500.00
0005434586899	18499	Economy	23500.00
0005433525127	18499	Economy	23500.00
0005434586974	18499	Economy	23500.00
0005433193340	18499	Economy	23500.00
0005432928103	18499	Economy	23500.00
0005434587037	18499	Economy	23500.00
0005434586891	18499	Economy	23500.00
0005434515000	18499	Economy	23500.00
0005433193331	18499	Economy	23500.00
0005433525167	18499	Economy	23500.00
0005433525179	18499	Economy	23500.00
0005434344930	11440	Economy	4300.00
0005434344964	11440	Economy	4300.00
0005434344940	11440	Economy	4300.00
0005434344954	11440	Economy	4300.00
0005434344956	11440	Economy	4000.00
0005435305032	11440	Economy	4000.00
0005434344947	11440	Economy	4000.00
0005435302235	11440	Economy	4000.00
0005434344943	11440	Economy	4000.00
0005435305036	11440	Economy	4000.00
0005434344959	11440	Economy	4000.00
0005434344934	11440	Economy	4000.00
0005434344951	11440	Economy	4000.00
0005435302258	11440	Economy	4000.00
0005434344942	11440	Economy	4000.00
0005434344949	11440	Economy	4000.00
0005434344950	11440	Economy	4000.00
0005434344957	11440	Economy	4000.00
0005434344962	11440	Economy	4000.00
0005434344933	11440	Economy	4000.00
0005434344952	11440	Economy	4000.00
0005434344937	11440	Economy	4000.00
0005434344965	11440	Economy	4000.00
0005434344939	11440	Economy	4000.00
0005434344938	11440	Economy	4000.00
0005434344946	11440	Economy	4000.00
0005435302272	11440	Economy	4000.00
0005434344961	11440	Economy	4000.00
0005434344966	11440	Economy	4000.00
0005435302271	11440	Economy	4000.00
0005434344944	11440	Economy	4000.00
0005434344941	11440	Economy	4000.00
0005435305037	11440	Economy	4000.00
0005434142697	11440	Economy	4000.00
0005435302246	11440	Economy	4000.00
0005434142698	11440	Economy	4000.00
0005434344936	11440	Economy	4000.00
0005434344963	11440	Economy	4000.00
0005434344953	11440	Economy	4000.00
0005434344948	11440	Economy	4000.00
0005434344932	11440	Economy	4000.00
0005434344931	11440	Economy	4000.00
0005435302249	11440	Economy	4000.00
0005434344945	11440	Economy	4000.00
0005435302265	11440	Economy	4000.00
0005434344960	11440	Economy	4000.00
0005435302247	11440	Economy	4000.00
0005434344955	11440	Economy	4000.00
0005434344935	11440	Economy	4000.00
0005434344958	11440	Economy	4000.00
0005434344629	29758	Economy	4300.00
0005434344683	29758	Economy	4300.00
0005434142659	29758	Economy	4300.00
0005434344684	29758	Economy	4300.00
0005434344508	29758	Economy	4000.00
0005434344743	29758	Economy	4000.00
0005434344612	29758	Economy	4000.00
0005434142650	29758	Economy	4000.00
0005434142653	29758	Economy	4000.00
0005434344717	29758	Economy	4000.00
0005434142658	29758	Economy	4000.00
0005434344601	29758	Economy	4000.00
0005434344606	29758	Economy	4000.00
0005434344579	29758	Economy	4000.00
0005434344607	29758	Economy	4000.00
0005434344572	29758	Economy	4000.00
0005434344685	29758	Economy	4000.00
0005434344691	29758	Economy	4000.00
0005434142670	29758	Economy	4000.00
0005434344585	29758	Economy	4000.00
0005434344586	29758	Economy	4000.00
0005434344608	29758	Economy	4000.00
0005434344768	29758	Economy	4000.00
0005434344665	29758	Economy	4000.00
0005434344566	29758	Economy	4000.00
0005434142669	29758	Economy	4000.00
0005434344523	29758	Economy	4000.00
0005434344718	29758	Economy	4000.00
0005434344617	29758	Economy	4000.00
0005434142636	29758	Economy	4000.00
0005434344611	29758	Economy	4000.00
0005434344571	29758	Economy	4000.00
0005434344530	29758	Economy	4000.00
0005434344596	29758	Economy	4000.00
0005434344576	29758	Economy	4000.00
0005434344744	29758	Economy	4000.00
0005434344522	29758	Economy	4000.00
0005434344597	29758	Economy	4000.00
0005434344668	29758	Economy	4000.00
0005434344689	29758	Economy	4000.00
0005434344692	29758	Economy	4000.00
0005434344583	29758	Economy	4000.00
0005434344529	29758	Economy	4000.00
0005434344647	29758	Economy	4000.00
0005434344616	29758	Economy	4000.00
0005434344628	29758	Economy	4000.00
0005434344664	29758	Economy	4000.00
0005434344667	29758	Economy	4000.00
0005434344600	29758	Economy	4000.00
0005434344690	29758	Economy	4000.00
0005435825219	1273	Business	199800.00
0005432284625	1273	Business	199800.00
0005433415906	1273	Business	199800.00
0005435825209	1273	Business	199800.00
0005435825204	1273	Business	199800.00
0005435825200	1273	Business	199800.00
0005435825220	1273	Business	199800.00
0005435825212	1273	Business	199800.00
0005435825222	1273	Economy	66600.00
0005433415957	1273	Economy	66600.00
0005433415905	1273	Economy	66600.00
0005433415958	1273	Economy	66600.00
0005433415822	1273	Economy	66600.00
0005435825197	1273	Economy	66600.00
0005435825208	1273	Economy	66600.00
0005435825196	1273	Economy	73200.00
0005435825207	1273	Economy	73200.00
0005433415862	1273	Economy	66600.00
0005435825221	1273	Economy	66600.00
0005435825205	1273	Economy	66600.00
0005435825206	1273	Economy	66600.00
0005435825203	1273	Economy	66600.00
0005432284623	1273	Economy	66600.00
0005433415910	1273	Economy	66600.00
0005433415792	1273	Economy	66600.00
0005433415911	1273	Economy	66600.00
0005433415870	1273	Economy	66600.00
0005435825199	1273	Economy	66600.00
0005432284622	1273	Economy	66600.00
0005432284624	1273	Economy	66600.00
0005435825216	1273	Economy	66600.00
0005435825215	1273	Economy	66600.00
0005435825218	1273	Economy	66600.00
0005435825214	1273	Economy	66600.00
0005433415881	1273	Economy	66600.00
0005435825198	1273	Economy	66600.00
0005433415855	1273	Economy	66600.00
0005435825211	1273	Economy	66600.00
0005435825217	1273	Economy	66600.00
0005435825210	1273	Economy	66600.00
0005433415883	1273	Economy	66600.00
0005435825202	1273	Economy	66600.00
0005435825213	1273	Economy	66600.00
0005433415907	1273	Economy	66600.00
0005433415856	1273	Economy	66600.00
0005432284626	1273	Economy	66600.00
0005433415884	1273	Economy	66600.00
0005435825201	1273	Economy	66600.00
0005435825055	18028	Business	199800.00
0005435824949	18028	Business	199800.00
0005433416013	18028	Business	199800.00
0005435824878	18028	Business	199800.00
0005435824935	18028	Business	199800.00
0005435825006	18028	Business	199800.00
0005435824939	18028	Business	199800.00
0005435825054	18028	Economy	66600.00
0005433415999	18028	Economy	66600.00
0005433416010	18028	Economy	66600.00
0005435824881	18028	Economy	66600.00
0005433416011	18028	Economy	66600.00
0005435825069	18028	Economy	66600.00
0005433416002	18028	Economy	66600.00
0005435824872	18028	Economy	73200.00
0005435824944	18028	Economy	73200.00
0005433416005	18028	Economy	66600.00
0005433416006	18028	Economy	66600.00
0005435824979	18028	Economy	66600.00
0005435824880	18028	Economy	66600.00
0005435824907	18028	Economy	66600.00
0005435824869	18028	Economy	66600.00
0005435824970	18028	Economy	66600.00
0005433416000	18028	Economy	66600.00
0005435824873	18028	Economy	66600.00
0005435825070	18028	Economy	66600.00
0005433416004	18028	Economy	66600.00
0005435824905	18028	Economy	66600.00
0005433416009	18028	Economy	66600.00
0005433416012	18028	Economy	66600.00
0005433416008	18028	Economy	66600.00
0005433416007	18028	Economy	66600.00
0005433416003	18028	Economy	66600.00
0005433416001	18028	Economy	66600.00
0005435825005	18028	Economy	66600.00
0005433415998	18028	Economy	66600.00
0005434460530	17529	Economy	14800.00
0005434462817	17529	Economy	14800.00
0005434460520	17529	Economy	13500.00
0005434460525	17529	Economy	13500.00
0005434462812	17529	Economy	13500.00
0005434462813	17529	Economy	13500.00
0005434462815	17529	Economy	13500.00
0005434460519	17529	Economy	13500.00
0005434462820	17529	Economy	13500.00
0005434462818	17529	Economy	13500.00
0005434462816	17529	Economy	13500.00
0005434462814	17529	Economy	13500.00
0005434460518	17529	Economy	13500.00
0005434462805	17529	Economy	13500.00
0005434462819	17529	Economy	13500.00
0005434460529	17529	Economy	13500.00
0005434462821	17529	Economy	13500.00
0005434462822	17529	Economy	13500.00
0005434462824	17529	Economy	13500.00
0005432784961	5661	Business	27800.00
0005435243166	5661	Business	27800.00
0005435243107	5661	Business	27800.00
0005432784944	5661	Business	27800.00
0005435476841	5661	Business	27800.00
0005432784983	5661	Business	27800.00
0005432784954	5661	Business	27800.00
0005435243207	5661	Business	27800.00
0005435243154	5661	Business	27800.00
0005432784955	5661	Business	27800.00
0005435476822	5661	Economy	9300.00
0005432784980	5661	Economy	9300.00
0005432784953	5661	Economy	9300.00
0005432784934	5661	Economy	9300.00
0005435243069	5661	Economy	9300.00
0005435476835	5661	Economy	9300.00
0005432784981	5661	Economy	9300.00
0005435243185	5661	Economy	9300.00
0005435476839	5661	Economy	10200.00
0005432784933	5661	Economy	10200.00
0005432784970	5661	Economy	10200.00
0005432784952	5661	Economy	10200.00
0005435243193	5661	Economy	9300.00
0005435243234	5661	Economy	9300.00
0005435243149	5661	Economy	9300.00
0005432784959	5661	Economy	9300.00
0005432784957	5661	Economy	9300.00
0005432144060	5661	Economy	9300.00
0005432784932	5661	Economy	9300.00
0005432784984	5661	Economy	9300.00
0005432784946	5661	Economy	9300.00
0005435476840	5661	Economy	9300.00
0005432784986	5661	Economy	9300.00
0005432784974	5661	Economy	9300.00
0005432784971	5661	Economy	9300.00
0005432784965	5661	Economy	9300.00
0005432784978	5661	Economy	9300.00
0005432784956	5661	Economy	9300.00
0005432784969	5661	Economy	9300.00
0005432784977	5661	Economy	9300.00
0005432144058	5661	Economy	9300.00
0005432784936	5661	Economy	9300.00
0005432784939	5661	Economy	9300.00
0005432784973	5661	Economy	9300.00
0005432784949	5661	Economy	9300.00
0005432784951	5661	Economy	9300.00
0005435243134	5661	Economy	9300.00
0005435243127	5661	Economy	9300.00
0005435243155	5661	Economy	9300.00
0005432784979	5661	Economy	9300.00
0005432784942	5661	Economy	9300.00
0005432784985	5661	Economy	9300.00
0005432784982	5661	Economy	9300.00
0005432784960	5661	Economy	9300.00
0005432784950	5661	Economy	9300.00
0005432784937	5661	Economy	9300.00
0005432144059	5661	Economy	9300.00
0005435243214	5661	Economy	9300.00
0005432784975	5661	Economy	9300.00
0005435243186	5661	Economy	9300.00
0005435243173	5661	Economy	9300.00
0005432784963	5661	Economy	9300.00
0005432784966	5661	Economy	9300.00
0005432784941	5661	Economy	9300.00
0005435243208	5661	Economy	9300.00
0005432784964	5661	Economy	9300.00
0005432784962	5661	Economy	9300.00
0005435243128	5661	Economy	9300.00
0005432144057	5661	Economy	9300.00
0005432784968	5661	Economy	9300.00
0005432784976	5661	Economy	9300.00
0005435476834	5661	Economy	9300.00
0005432784935	5661	Economy	9300.00
0005435476838	5661	Economy	9300.00
0005432784967	5661	Economy	9300.00
0005432784972	5661	Economy	9300.00
0005432784958	5661	Economy	9300.00
0005435243175	5661	Economy	9300.00
0005432784940	5661	Economy	9300.00
0005432784938	5661	Economy	9300.00
0005432784943	5661	Economy	9300.00
0005435476831	5661	Economy	9300.00
0005435476830	5661	Economy	9300.00
0005435243205	5661	Economy	9300.00
0005432784948	5661	Economy	9300.00
0005435243129	5661	Economy	9300.00
0005435243176	5661	Economy	9300.00
0005432784947	5661	Economy	9300.00
0005432784945	5661	Economy	9300.00
0005432784230	15393	Business	27800.00
0005432784472	15393	Business	27800.00
0005435243408	15393	Business	27800.00
0005432784494	15393	Business	27800.00
0005432784250	15393	Business	27800.00
0005432784453	15393	Business	27800.00
0005432784249	15393	Business	27800.00
0005435243402	15393	Business	27800.00
0005432784566	15393	Business	27800.00
0005435243401	15393	Business	27800.00
0005432784595	15393	Business	27800.00
0005435243425	15393	Business	27800.00
0005432784598	15393	Economy	9300.00
0005432784567	15393	Economy	9300.00
0005432784594	15393	Economy	9300.00
0005432784512	15393	Economy	9300.00
0005435243417	15393	Economy	9300.00
0005435476920	15393	Economy	9300.00
0005435476909	15393	Economy	9300.00
0005432784389	15393	Economy	9300.00
0005435243423	15393	Economy	9300.00
0005432784289	15393	Economy	9300.00
0005432784469	15393	Economy	10200.00
0005432784654	15393	Economy	10200.00
0005432784330	15393	Economy	10200.00
0005435243411	15393	Economy	10200.00
0005435243418	15393	Economy	10200.00
0005432784634	15393	Economy	9300.00
0005435243403	15393	Economy	9300.00
0005432784526	15393	Economy	9300.00
0005435476914	15393	Economy	9300.00
0005435476911	15393	Economy	9300.00
0005435476917	15393	Economy	9300.00
0005432784447	15393	Economy	9300.00
0005435243424	15393	Economy	9300.00
0005435243427	15393	Economy	9300.00
0005435243420	15393	Economy	9300.00
0005432784332	15393	Economy	9300.00
0005432784503	15393	Economy	9300.00
0005432784158	15393	Economy	9300.00
0005435476912	15393	Economy	9300.00
0005435243407	15393	Economy	9300.00
0005435243406	15393	Economy	9300.00
0005435243422	15393	Economy	9300.00
0005432784305	15393	Economy	9300.00
0005432784147	15393	Economy	9300.00
0005432784587	15393	Economy	9300.00
0005435243405	15393	Economy	9300.00
0005432784536	15393	Economy	9300.00
0005435476910	15393	Economy	9300.00
0005435243404	15393	Economy	9300.00
0005435243414	15393	Economy	9300.00
0005432784618	15393	Economy	9300.00
0005435243409	15393	Economy	9300.00
0005432784396	15393	Economy	9300.00
0005432784448	15393	Economy	9300.00
0005435243410	15393	Economy	9300.00
0005432784427	15393	Economy	9300.00
0005432784596	15393	Economy	9300.00
0005435243400	15393	Economy	9300.00
0005432784454	15393	Economy	9300.00
0005432784323	15393	Economy	9300.00
0005435476913	15393	Economy	9300.00
0005432784610	15393	Economy	9300.00
0005432784540	15393	Economy	9300.00
0005432784409	15393	Economy	9300.00
0005432784397	15393	Economy	9300.00
0005432784320	15393	Economy	9300.00
0005432784367	15393	Economy	9300.00
0005432784473	15393	Economy	9300.00
0005435476918	15393	Economy	9300.00
0005432784449	15393	Economy	9300.00
0005435243419	15393	Economy	9300.00
0005435476915	15393	Economy	9300.00
0005432784609	15393	Economy	9300.00
0005432784319	15393	Economy	9300.00
0005432784217	15393	Economy	9300.00
0005432784407	15393	Economy	9300.00
0005435243412	15393	Economy	9300.00
0005432784659	15393	Economy	9300.00
0005432784522	15393	Economy	9300.00
0005435243413	15393	Economy	9300.00
0005435243421	15393	Economy	9300.00
0005432784470	15393	Economy	9300.00
0005432784523	15393	Economy	9300.00
0005435476916	15393	Economy	9300.00
0005435476919	15393	Economy	9300.00
0005432784400	15393	Economy	9300.00
0005432784627	15393	Economy	9300.00
0005435243415	15393	Economy	9300.00
0005432784658	15393	Economy	9300.00
0005432784471	15393	Economy	9300.00
0005435243426	15393	Economy	9300.00
0005435243416	15393	Economy	9300.00
0005432784288	15393	Economy	9300.00
0005432784521	15393	Economy	9300.00
0005432784463	15393	Economy	9300.00
0005432848623	4371	Economy	7000.00
0005434462837	4371	Economy	7000.00
0005432848625	4371	Economy	7000.00
0005435851002	4371	Economy	6300.00
0005435851048	4371	Economy	6300.00
0005432848620	4371	Economy	6300.00
0005434463975	4371	Economy	6300.00
0005432848628	4371	Economy	6300.00
0005432848627	4371	Economy	6300.00
0005435851050	4371	Economy	6300.00
0005432848629	4371	Economy	6300.00
0005432848630	4371	Economy	6300.00
0005435851039	4371	Economy	6300.00
0005432848631	4371	Economy	6300.00
0005434463976	4371	Economy	6300.00
0005432848622	4371	Economy	6300.00
0005432848621	4371	Economy	6300.00
0005435851049	4371	Economy	6300.00
0005434462838	4371	Economy	6300.00
0005432848632	4371	Economy	6300.00
0005435851021	4371	Economy	6300.00
0005434462836	4371	Economy	6300.00
0005432848633	4371	Economy	6300.00
0005432848626	4371	Economy	6300.00
0005432848624	4371	Economy	6300.00
0005432848619	4371	Economy	6300.00
0005435851103	28842	Economy	7000.00
0005435851105	28842	Economy	7000.00
0005432848498	28842	Economy	7000.00
0005432848521	28842	Economy	6300.00
0005432848468	28842	Economy	6300.00
0005432848488	28842	Economy	6300.00
0005432848580	28842	Economy	6300.00
0005432848504	28842	Economy	6300.00
0005432848505	28842	Economy	6300.00
0005435851112	28842	Economy	6300.00
0005432848528	28842	Economy	6300.00
0005435851109	28842	Economy	6300.00
0005435851106	28842	Economy	6300.00
0005434463952	28842	Economy	6300.00
0005432848478	28842	Economy	6300.00
0005435851110	28842	Economy	6300.00
0005435851111	28842	Economy	6300.00
0005434463953	28842	Economy	6300.00
0005434461675	28842	Economy	6300.00
0005432848581	28842	Economy	6300.00
0005432848486	28842	Economy	6300.00
0005432848520	28842	Economy	6300.00
0005432848527	28842	Economy	6300.00
0005435851107	28842	Economy	6300.00
0005432848536	28842	Economy	6300.00
0005434463949	28842	Economy	6300.00
0005435851108	28842	Economy	6300.00
0005432848485	28842	Economy	6300.00
0005432848547	28842	Economy	6300.00
0005434461661	28842	Economy	6300.00
0005435851104	28842	Economy	6300.00
0005434461674	28842	Economy	6300.00
0005434461660	28842	Economy	6300.00
0005434444063	6257	Business	11900.00
0005433497647	6257	Business	11900.00
0005434926500	6257	Business	11900.00
0005434926477	6257	Business	11900.00
0005434926507	6257	Business	11900.00
0005434926490	6257	Business	11900.00
0005433497656	6257	Business	11900.00
0005433497660	6257	Business	11900.00
0005433497648	6257	Business	11900.00
0005433497633	6257	Business	11900.00
0005434444067	6257	Economy	4000.00
0005434926502	6257	Economy	4000.00
0005434444054	6257	Economy	4000.00
0005433497637	6257	Economy	4000.00
0005433497659	6257	Economy	4000.00
0005434926505	6257	Economy	4000.00
0005434926504	6257	Economy	4000.00
0005434926509	6257	Economy	4000.00
0005433497662	6257	Economy	4400.00
0005434444066	6257	Economy	4400.00
0005433497649	6257	Economy	4400.00
0005434926499	6257	Economy	4400.00
0005433497657	6257	Economy	4400.00
0005434444057	6257	Economy	4000.00
0005434926482	6257	Economy	4000.00
0005434926487	6257	Economy	4000.00
0005433497651	6257	Economy	4000.00
0005434926489	6257	Economy	4000.00
0005433497638	6257	Economy	4000.00
0005433497636	6257	Economy	4000.00
0005434926488	6257	Economy	4000.00
0005434926492	6257	Economy	4000.00
0005432075304	6257	Economy	4000.00
0005434444068	6257	Economy	4000.00
0005434444056	6257	Economy	4000.00
0005434926494	6257	Economy	4000.00
0005434926491	6257	Economy	4000.00
0005434926498	6257	Economy	4000.00
0005434926485	6257	Economy	4000.00
0005434444059	6257	Economy	4000.00
0005433497644	6257	Economy	4000.00
0005433497652	6257	Economy	4000.00
0005434926486	6257	Economy	4000.00
0005433497663	6257	Economy	4000.00
0005434926493	6257	Economy	4000.00
0005433497635	6257	Economy	4000.00
0005433497658	6257	Economy	4000.00
0005433497639	6257	Economy	4000.00
0005434926476	6257	Economy	4000.00
0005433497645	6257	Economy	4000.00
0005434444058	6257	Economy	4000.00
0005433497640	6257	Economy	4000.00
0005434926478	6257	Economy	4000.00
0005434444064	6257	Economy	4000.00
0005433497654	6257	Economy	4000.00
0005433497650	6257	Economy	4000.00
0005434926479	6257	Economy	4000.00
0005434926481	6257	Economy	4000.00
0005433497664	6257	Economy	4000.00
0005433497634	6257	Economy	4000.00
0005433497646	6257	Economy	4000.00
0005434444061	6257	Economy	4000.00
0005434444055	6257	Economy	4000.00
0005433497642	6257	Economy	4000.00
0005434926484	6257	Economy	4000.00
0005434926480	6257	Economy	4000.00
0005434926506	6257	Economy	4000.00
0005433497653	6257	Economy	4000.00
0005434926508	6257	Economy	4000.00
0005434444065	6257	Economy	4000.00
0005433497661	6257	Economy	4000.00
0005433497641	6257	Economy	4000.00
0005434926503	6257	Economy	4000.00
0005434444062	6257	Economy	4000.00
0005434926495	6257	Economy	4000.00
0005433497655	6257	Economy	4000.00
0005434926496	6257	Economy	4000.00
0005434926475	6257	Economy	4000.00
0005432075306	6257	Economy	4000.00
0005433497643	6257	Economy	4000.00
0005434926497	6257	Economy	4000.00
0005434926483	6257	Economy	4000.00
0005434444060	6257	Economy	4000.00
0005432075305	6257	Economy	4000.00
0005434926501	6257	Economy	4000.00
0005435257434	20334	Business	11900.00
0005435257430	20334	Economy	4000.00
0005435257435	20334	Economy	4400.00
0005435257424	20334	Economy	4000.00
0005435257423	20334	Economy	4000.00
0005435257426	20334	Economy	4000.00
0005435257436	20334	Economy	4000.00
0005435257429	20334	Economy	4000.00
0005435257431	20334	Economy	4000.00
0005435257432	20334	Economy	4000.00
0005435257425	20334	Economy	4000.00
0005435257427	20334	Economy	4000.00
0005435257428	20334	Economy	4000.00
0005435257433	20334	Economy	4000.00
0005433497339	20333	Business	11900.00
0005433497295	20333	Business	11900.00
0005434926196	20333	Business	11900.00
0005434926186	20333	Business	11900.00
0005433497493	20333	Business	11900.00
0005433497340	20333	Business	11900.00
0005434443909	20333	Business	11900.00
0005433497444	20333	Business	11900.00
0005434443908	20333	Business	11900.00
0005434926140	20333	Business	11900.00
0005434926213	20333	Business	11900.00
0005434443915	20333	Business	11900.00
0005434443855	20333	Economy	4000.00
0005433497423	20333	Economy	4000.00
0005434443872	20333	Economy	4000.00
0005434926208	20333	Economy	4000.00
0005434443901	20333	Economy	4000.00
0005433497440	20333	Economy	4000.00
0005433497410	20333	Economy	4000.00
0005434926212	20333	Economy	4000.00
0005434443928	20333	Economy	4000.00
0005433497427	20333	Economy	4000.00
0005434926209	20333	Economy	4400.00
0005433497482	20333	Economy	4400.00
0005434926217	20333	Economy	4400.00
0005433497385	20333	Economy	4400.00
0005434443852	20333	Economy	4400.00
0005433497529	20333	Economy	4000.00
0005433497428	20333	Economy	4000.00
0005434443919	20333	Economy	4000.00
0005433497483	20333	Economy	4000.00
0005433497352	20333	Economy	4000.00
0005433497480	20333	Economy	4000.00
0005433497498	20333	Economy	4000.00
0005434926210	20333	Economy	4000.00
0005434926158	20333	Economy	4000.00
0005433497360	20333	Economy	4000.00
0005433497437	20333	Economy	4000.00
0005433497549	20333	Economy	4000.00
0005433497363	20333	Economy	4000.00
0005433497481	20333	Economy	4000.00
0005433497351	20333	Economy	4000.00
0005433497359	20333	Economy	4000.00
0005434926189	20333	Economy	4000.00
0005434443972	20333	Economy	4000.00
0005434926136	20333	Economy	4000.00
0005434443947	20333	Economy	4000.00
0005434926058	20333	Economy	4000.00
0005433497369	20333	Economy	4000.00
0005433497411	20333	Economy	4000.00
0005433497362	20333	Economy	4000.00
0005433497412	20333	Economy	4000.00
0005434443927	20333	Economy	4000.00
0005434926147	20333	Economy	4000.00
0005434926156	20333	Economy	4000.00
0005434926155	20333	Economy	4000.00
0005434926170	20333	Economy	4000.00
0005433497333	20333	Economy	4000.00
0005434926188	20333	Economy	4000.00
0005434443842	20333	Economy	4000.00
0005434926063	20333	Economy	4000.00
0005434926211	20333	Economy	4000.00
0005434926181	20333	Economy	4000.00
0005433497459	20333	Economy	4000.00
0005433497334	20333	Economy	4000.00
0005433497392	20333	Economy	4000.00
0005433497422	20333	Economy	4000.00
0005434443837	20333	Economy	4000.00
0005433497470	20333	Economy	4000.00
0005434443871	20333	Economy	4000.00
0005433497384	20333	Economy	4000.00
0005434926190	20333	Economy	4000.00
0005434443859	20333	Economy	4000.00
0005434926157	20333	Economy	4000.00
0005434443854	20333	Economy	4000.00
0005433497466	20333	Economy	4000.00
0005434443914	20333	Economy	4000.00
0005433497453	20333	Economy	4000.00
0005433497479	20333	Economy	4000.00
0005433497454	20333	Economy	4000.00
0005434926059	20333	Economy	4000.00
0005433497303	20333	Economy	4000.00
0005433497429	20333	Economy	4000.00
0005434926218	20333	Economy	4000.00
0005433497364	20333	Economy	4000.00
0005433497471	20333	Economy	4000.00
0005433497338	20333	Economy	4000.00
0005434926135	20333	Economy	4000.00
0005433497465	20333	Economy	4000.00
0005434926142	20333	Economy	4000.00
0005435243442	12183	Business	41200.00
0005432784701	12183	Business	41200.00
0005432784568	12183	Business	41200.00
0005432784639	12183	Business	41200.00
0005432784441	12183	Business	41200.00
0005432784421	12183	Business	41200.00
0005432784563	12183	Business	41200.00
0005435243436	12183	Business	41200.00
0005432784505	12183	Business	41200.00
0005432784116	12183	Business	41200.00
0005432784551	12183	Economy	13700.00
0005435243430	12183	Economy	13700.00
0005435243448	12183	Economy	13700.00
0005432784296	12183	Economy	13700.00
0005432784542	12183	Economy	13700.00
0005435243435	12183	Economy	13700.00
0005435243447	12183	Economy	13700.00
0005432784422	12183	Economy	13700.00
0005432784792	12183	Economy	13700.00
0005432784561	12183	Economy	13700.00
0005435243437	12183	Economy	15100.00
0005432784442	12183	Economy	15100.00
0005432784720	12183	Economy	15100.00
0005435243450	12183	Economy	15100.00
0005432784663	12183	Economy	13700.00
0005432784591	12183	Economy	13700.00
0005435243455	12183	Economy	13700.00
0005432784419	12183	Economy	13700.00
0005432784275	12183	Economy	13700.00
0005432784487	12183	Economy	13700.00
0005432784543	12183	Economy	13700.00
0005435243429	12183	Economy	13700.00
0005432784691	12183	Economy	13700.00
0005435243452	12183	Economy	13700.00
0005435243444	12183	Economy	13700.00
0005435243449	12183	Economy	13700.00
0005432784386	12183	Economy	13700.00
0005432784388	12183	Economy	13700.00
0005432784403	12183	Economy	13700.00
0005435243438	12183	Economy	13700.00
0005432784641	12183	Economy	13700.00
0005432784646	12183	Economy	13700.00
0005432784578	12183	Economy	13700.00
0005432784420	12183	Economy	13700.00
0005432784545	12183	Economy	13700.00
0005432784575	12183	Economy	13700.00
0005432784381	12183	Economy	13700.00
0005432784295	12183	Economy	13700.00
0005435243434	12183	Economy	13700.00
0005432784413	12183	Economy	13700.00
0005432784546	12183	Economy	13700.00
0005435243443	12183	Economy	13700.00
0005435243441	12183	Economy	13700.00
0005432784721	12183	Economy	13700.00
0005435243431	12183	Economy	13700.00
0005432784733	12183	Economy	13700.00
0005432784126	12183	Economy	13700.00
0005432784331	12183	Economy	13700.00
0005432784504	12183	Economy	13700.00
0005432784592	12183	Economy	13700.00
0005435243446	12183	Economy	13700.00
0005432784692	12183	Economy	13700.00
0005435243439	12183	Economy	13700.00
0005435243453	12183	Economy	13700.00
0005432784444	12183	Economy	13700.00
0005432784640	12183	Economy	13700.00
0005432784569	12183	Economy	13700.00
0005435243451	12183	Economy	13700.00
0005432784297	12183	Economy	13700.00
0005435243454	12183	Economy	13700.00
0005435243440	12183	Economy	13700.00
0005432784387	12183	Economy	13700.00
0005432784432	12183	Economy	13700.00
0005435243445	12183	Economy	13700.00
0005432784706	12183	Economy	13700.00
0005432784564	12183	Economy	13700.00
0005432784539	12183	Economy	13700.00
0005432784402	12183	Economy	13700.00
0005432784574	12183	Economy	13700.00
0005432784570	12183	Economy	13700.00
0005435243428	12183	Economy	13700.00
0005432784466	12183	Economy	13700.00
0005432784560	12183	Economy	13700.00
0005435243433	12183	Economy	13700.00
0005432784579	12183	Economy	13700.00
0005432784380	12183	Economy	13700.00
0005435243432	12183	Economy	13700.00
0005432784562	12183	Economy	13700.00
0005432784495	12183	Economy	13700.00
0005432784428	12183	Economy	13700.00
0005432784905	15453	Business	41200.00
0005435243141	15453	Business	41200.00
0005435243101	15453	Business	41200.00
0005432784889	15453	Business	41200.00
0005435243198	15453	Business	41200.00
0005435243160	15453	Business	41200.00
0005435243098	15453	Business	41200.00
0005435243161	15453	Business	41200.00
0005435243146	15453	Business	41200.00
0005432784916	15453	Business	41200.00
0005432784926	15453	Business	41200.00
0005432784927	15453	Business	41200.00
0005432784909	15453	Economy	13700.00
0005435243209	15453	Economy	13700.00
0005435243188	15453	Economy	13700.00
0005435243126	15453	Economy	13700.00
0005435243079	15453	Economy	13700.00
0005432784911	15453	Economy	13700.00
0005432784929	15453	Economy	13700.00
0005432784920	15453	Economy	13700.00
0005432784898	15453	Economy	13700.00
0005435243083	15453	Economy	13700.00
0005432784921	15453	Economy	15100.00
0005432784887	15453	Economy	15100.00
0005435243156	15453	Economy	15100.00
0005432784930	15453	Economy	15100.00
0005432784915	15453	Economy	15100.00
0005432784912	15453	Economy	13700.00
0005432784904	15453	Economy	13700.00
0005435243102	15453	Economy	13700.00
0005435243253	15453	Economy	13700.00
0005435243171	15453	Economy	13700.00
0005432784923	15453	Economy	13700.00
0005432784884	15453	Economy	13700.00
0005432784885	15453	Economy	13700.00
0005435243145	15453	Economy	13700.00
0005432784922	15453	Economy	13700.00
0005435243148	15453	Economy	13700.00
0005432784914	15453	Economy	13700.00
0005432784883	15453	Economy	13700.00
0005435243035	15453	Economy	13700.00
0005435243075	15453	Economy	13700.00
0005432784892	15453	Economy	13700.00
0005435243170	15453	Economy	13700.00
0005432784901	15453	Economy	13700.00
0005435243182	15453	Economy	13700.00
0005432784913	15453	Economy	13700.00
0005435243157	15453	Economy	13700.00
0005432784891	15453	Economy	13700.00
0005435243187	15453	Economy	13700.00
0005432784881	15453	Economy	13700.00
0005432784877	15453	Economy	13700.00
0005432784890	15453	Economy	13700.00
0005432784880	15453	Economy	13700.00
0005435243078	15453	Economy	13700.00
0005432784882	15453	Economy	13700.00
0005435243030	15453	Economy	13700.00
0005435243197	15453	Economy	13700.00
0005432784906	15453	Economy	13700.00
0005432784908	15453	Economy	13700.00
0005432784878	15453	Economy	13700.00
0005435243147	15453	Economy	13700.00
0005435243163	15453	Economy	13700.00
0005432784931	15453	Economy	13700.00
0005432784895	15453	Economy	13700.00
0005432784896	15453	Economy	13700.00
0005432784910	15453	Economy	13700.00
0005432784900	15453	Economy	13700.00
0005435243036	15453	Economy	13700.00
0005432784925	15453	Economy	13700.00
0005435243196	15453	Economy	13700.00
0005432784903	15453	Economy	13700.00
0005432784924	15453	Economy	13700.00
0005432784886	15453	Economy	13700.00
0005435243172	15453	Economy	13700.00
0005432784899	15453	Economy	13700.00
0005432784893	15453	Economy	13700.00
0005432784918	15453	Economy	13700.00
0005432784894	15453	Economy	13700.00
0005432784917	15453	Economy	13700.00
0005432784902	15453	Economy	13700.00
0005435243140	15453	Economy	13700.00
0005432784907	15453	Economy	13700.00
0005435243168	15453	Economy	13700.00
0005432784879	15453	Economy	13700.00
0005435243169	15453	Economy	13700.00
0005432784928	15453	Economy	13700.00
0005432784897	15453	Economy	13700.00
0005435243195	15453	Economy	13700.00
0005432784888	15453	Economy	13700.00
0005432784919	15453	Economy	13700.00
0005434879694	10079	Business	49700.00
0005434879633	10079	Business	49700.00
0005434879465	10079	Business	49700.00
0005434879797	10079	Business	49700.00
0005434879455	10079	Business	49700.00
0005434879429	10079	Business	49700.00
0005434879782	10079	Business	49700.00
0005434879309	10079	Business	49700.00
0005434879668	10079	Business	49700.00
0005434879600	10079	Business	49700.00
0005434879258	10079	Business	49700.00
0005435914033	10079	Business	49700.00
0005434879359	10079	Business	49700.00
0005434879314	10079	Business	49700.00
0005434879475	10079	Business	49700.00
0005434879135	10079	Business	49700.00
0005434878922	10079	Business	49700.00
0005434879291	10079	Business	49700.00
0005434879512	10079	Business	49700.00
0005435914041	10079	Economy	16600.00
0005434879624	10079	Economy	16600.00
0005435914036	10079	Economy	16600.00
0005434879558	10079	Economy	16600.00
0005434879384	10079	Economy	16600.00
0005434879195	10079	Economy	16600.00
0005435914032	10079	Economy	16600.00
0005434879799	10079	Economy	16600.00
0005434879825	10079	Economy	16600.00
0005434879418	10079	Economy	16600.00
0005434879248	10079	Economy	16600.00
0005434879680	10079	Economy	16600.00
0005434879679	10079	Economy	18200.00
0005434879310	10079	Economy	18200.00
0005434879349	10079	Economy	18200.00
0005434879105	10079	Economy	16600.00
0005434879570	10079	Economy	18200.00
0005434879430	10079	Economy	16600.00
0005434879781	10079	Economy	16600.00
0005434879125	10079	Economy	16600.00
0005434879695	10079	Economy	16600.00
0005434879347	10079	Economy	16600.00
0005434879783	10079	Economy	16600.00
0005434879529	10079	Economy	16600.00
0005434879269	10079	Economy	16600.00
0005434910160	10079	Economy	16600.00
0005434879399	10079	Economy	16600.00
0005434879424	10079	Economy	16600.00
0005434879021	10079	Economy	16600.00
0005434879137	10079	Economy	16600.00
0005434879292	10079	Economy	16600.00
0005434879417	10079	Economy	16600.00
0005434879385	10079	Economy	16600.00
0005434879560	10079	Economy	16600.00
0005434879094	10079	Economy	16600.00
0005434879368	10079	Economy	16600.00
0005434879342	10079	Economy	16600.00
0005435914028	10079	Economy	16600.00
0005434879606	10079	Economy	16600.00
0005435914035	10079	Economy	16600.00
0005434879435	10079	Economy	16600.00
0005434879599	10079	Economy	16600.00
0005434879024	10079	Economy	16600.00
0005435914038	10079	Economy	16600.00
0005434879634	10079	Economy	16600.00
0005435914034	10079	Economy	16600.00
0005435914039	10079	Economy	16600.00
0005434879716	10079	Economy	16600.00
0005434879496	10079	Economy	16600.00
0005434910162	10079	Economy	16600.00
0005434879812	10079	Economy	16600.00
0005434879673	10079	Economy	16600.00
0005434879136	10079	Economy	16600.00
0005434879632	10079	Economy	16600.00
0005434880003	10079	Economy	16600.00
0005434879482	10079	Economy	16600.00
0005434879064	10079	Economy	16600.00
0005434879559	10079	Economy	16600.00
0005434879268	10079	Economy	16600.00
0005434879521	10079	Economy	16600.00
0005435914029	10079	Economy	16600.00
0005434879530	10079	Economy	16600.00
0005434879497	10079	Economy	16600.00
0005434879300	10079	Economy	16600.00
0005434910161	10079	Economy	16600.00
0005434879257	10079	Economy	16600.00
0005434879824	10079	Economy	16600.00
0005434879240	10079	Economy	16600.00
0005434879605	10079	Economy	16600.00
0005434879061	10079	Economy	16600.00
0005434879070	10079	Economy	16600.00
0005434879713	10079	Economy	16600.00
0005434879821	10079	Economy	16600.00
0005434879518	10079	Economy	16600.00
0005434879431	10079	Economy	16600.00
0005434879895	10079	Economy	16600.00
0005435914031	10079	Economy	16600.00
0005434879315	10079	Economy	16600.00
0005434879723	10079	Economy	16600.00
0005435914037	10079	Economy	16600.00
0005435914027	10079	Economy	16600.00
0005435914040	10079	Economy	16600.00
0005434879474	10079	Economy	16600.00
0005434879093	10079	Economy	16600.00
0005434879404	10079	Economy	16600.00
0005434879800	10079	Economy	16600.00
0005434879548	10079	Economy	16600.00
0005435914030	10079	Economy	16600.00
0005434879239	10079	Economy	16600.00
0005434880238	14615	Business	49700.00
0005434758944	14615	Business	49700.00
0005434880225	14615	Business	49700.00
0005434880223	14615	Business	49700.00
0005434880272	14615	Business	49700.00
0005434880275	14615	Business	49700.00
0005434880254	14615	Business	49700.00
0005434880290	14615	Business	49700.00
0005434880286	14615	Business	49700.00
0005434880216	14615	Business	49700.00
0005434880268	14615	Business	49700.00
0005434880235	14615	Business	49700.00
0005434880221	14615	Business	49700.00
0005434880258	14615	Business	49700.00
0005434880306	14615	Business	49700.00
0005434880251	14615	Economy	16600.00
0005434910153	14615	Business	49700.00
0005434880295	14615	Economy	16600.00
0005434880217	14615	Economy	16600.00
0005434880265	14615	Economy	16600.00
0005434880236	14615	Economy	16600.00
0005434880229	14615	Economy	16600.00
0005434880277	14615	Economy	16600.00
0005434880227	14615	Economy	16600.00
0005434880215	14615	Economy	16600.00
0005434880305	14615	Economy	16600.00
0005434880237	14615	Economy	16600.00
0005434880255	14615	Economy	16600.00
0005434880284	14615	Economy	18200.00
0005434880270	14615	Economy	18200.00
0005434880308	14615	Economy	18200.00
0005434880301	14615	Economy	16600.00
0005434880224	14615	Economy	16600.00
0005434880304	14615	Economy	16600.00
0005434880282	14615	Economy	16600.00
0005434910138	14615	Economy	16600.00
0005434880307	14615	Economy	16600.00
0005434880232	14615	Economy	16600.00
0005434880246	14615	Economy	16600.00
0005434880247	14615	Economy	16600.00
0005434880300	14615	Economy	16600.00
0005434880287	14615	Economy	16600.00
0005434880260	14615	Economy	16600.00
0005434880243	14615	Economy	16600.00
0005434880273	14615	Economy	16600.00
0005434880271	14615	Economy	16600.00
0005434880279	14615	Economy	16600.00
0005434880266	14615	Economy	16600.00
0005434880293	14615	Economy	16600.00
0005434880264	14615	Economy	16600.00
0005434880288	14615	Economy	16600.00
0005434880298	14615	Economy	16600.00
0005434880239	14615	Economy	16600.00
0005434880220	14615	Economy	16600.00
0005434880276	14615	Economy	16600.00
0005435913962	14615	Economy	16600.00
0005434880249	14615	Economy	16600.00
0005434880285	14615	Economy	16600.00
0005434880240	14615	Economy	16600.00
0005434880252	14615	Economy	16600.00
0005434880244	14615	Economy	16600.00
0005434880257	14615	Economy	16600.00
0005434910154	14615	Economy	16600.00
0005434880259	14615	Economy	16600.00
0005434880302	14615	Economy	16600.00
0005435913965	14615	Economy	16600.00
0005435913964	14615	Economy	16600.00
0005434880253	14615	Economy	16600.00
0005434880296	14615	Economy	16600.00
0005434880292	14615	Economy	16600.00
0005434880291	14615	Economy	16600.00
0005434880262	14615	Economy	16600.00
0005434880226	14615	Economy	16600.00
0005434880228	14615	Economy	16600.00
0005434880278	14615	Economy	16600.00
0005434880263	14615	Economy	16600.00
0005434880250	14615	Economy	16600.00
0005434910140	14615	Economy	16600.00
0005434880283	14615	Economy	16600.00
0005434880309	14615	Economy	16600.00
0005434880219	14615	Economy	16600.00
0005434880248	14615	Economy	16600.00
0005434880261	14615	Economy	16600.00
0005434880234	14615	Economy	16600.00
0005434880281	14615	Economy	16600.00
0005434880303	14615	Economy	16600.00
0005434880294	14615	Economy	16600.00
0005434910139	14615	Economy	16600.00
0005434880241	14615	Economy	16600.00
0005434880222	14615	Economy	16600.00
0005434880231	14615	Economy	16600.00
0005434880245	14615	Economy	16600.00
0005434880297	14615	Economy	16600.00
0005434880299	14615	Economy	16600.00
0005434880242	14615	Economy	16600.00
0005434880218	14615	Economy	16600.00
0005434880267	14615	Economy	16600.00
0005434880214	14615	Economy	16600.00
0005434880269	14615	Economy	16600.00
0005434880233	14615	Economy	16600.00
0005434880289	14615	Economy	16600.00
0005434880280	14615	Economy	16600.00
0005434880230	14615	Economy	16600.00
0005434880274	14615	Economy	16600.00
0005434880256	14615	Economy	16600.00
0005434910152	14615	Economy	16600.00
0005435660375	9243	Economy	22400.00
0005434252109	9243	Economy	22400.00
0005434252097	9243	Economy	22400.00
0005435660377	9243	Economy	22400.00
0005435660378	9243	Economy	20300.00
0005435660385	9243	Economy	20300.00
0005435660384	9243	Economy	20300.00
0005434252108	9243	Economy	20300.00
0005435660383	9243	Economy	20300.00
0005434252100	9243	Economy	20300.00
0005435660376	9243	Economy	20300.00
0005434252085	9243	Economy	20300.00
0005434252068	9243	Economy	20300.00
0005434252082	9243	Economy	20300.00
0005435660381	9243	Economy	20300.00
0005434252084	9243	Economy	20300.00
0005434252103	9243	Economy	20300.00
0005434252089	9243	Economy	20300.00
0005435660382	9243	Economy	20300.00
0005435660379	9243	Economy	20300.00
0005434252076	9243	Economy	20300.00
0005434252083	9243	Economy	20300.00
0005435660380	9243	Economy	20300.00
0005434252098	9243	Economy	20300.00
0005434252078	9243	Economy	20300.00
0005434252172	24634	Economy	22400.00
0005435660278	24634	Economy	20300.00
0005434252170	24634	Economy	20300.00
0005435660249	24634	Economy	20300.00
0005435660236	24634	Economy	20300.00
0005435660274	24634	Economy	20300.00
0005434252165	24634	Economy	20300.00
0005434252174	24634	Economy	20300.00
0005435660268	24634	Economy	20300.00
0005435660230	24634	Economy	20300.00
0005434252168	24634	Economy	20300.00
0005434252171	24634	Economy	20300.00
0005434252173	24634	Economy	20300.00
0005435660297	24634	Economy	20300.00
0005435660298	24634	Economy	20300.00
0005435660289	24634	Economy	20300.00
0005434252166	24634	Economy	20300.00
0005434252169	24634	Economy	20300.00
0005435660288	24634	Economy	20300.00
0005435660286	24634	Economy	20300.00
0005434252167	24634	Economy	20300.00
0005433681608	2788	Business	33000.00
0005432967189	2788	Business	33000.00
0005433681583	2788	Business	33000.00
0005432222897	2788	Business	33000.00
0005432967291	2788	Business	33000.00
0005432967196	2788	Business	33000.00
0005433681582	2788	Business	33000.00
0005432967279	2788	Business	33000.00
0005433681574	2788	Business	33000.00
0005433681590	2788	Business	33000.00
0005433681571	2788	Business	33000.00
0005432967277	2788	Economy	11000.00
0005433681607	2788	Economy	11000.00
0005433681592	2788	Economy	11000.00
0005433681573	2788	Economy	11000.00
0005432967347	2788	Economy	11000.00
0005433684465	2788	Economy	12100.00
0005432967190	2788	Economy	12100.00
0005432222895	2788	Economy	12100.00
0005432967240	2788	Economy	12100.00
0005432967122	2788	Economy	11000.00
0005433681606	2788	Economy	11000.00
0005433681570	2788	Economy	11000.00
0005432967259	2788	Economy	11000.00
0005432967239	2788	Economy	11000.00
0005432967283	2788	Economy	11000.00
0005433681596	2788	Economy	11000.00
0005432967271	2788	Economy	11000.00
0005433681591	2788	Economy	11000.00
0005432967126	2788	Economy	11000.00
0005433681572	2788	Economy	11000.00
0005433684463	2788	Economy	11000.00
0005433681602	2788	Economy	11000.00
0005433681575	2788	Economy	11000.00
0005432967264	2788	Economy	11000.00
0005433681603	2788	Economy	11000.00
0005433681610	2788	Economy	11000.00
0005433681601	2788	Economy	11000.00
0005433681581	2788	Economy	11000.00
0005433681577	2788	Economy	11000.00
0005433681584	2788	Economy	11000.00
0005433684464	2788	Economy	11000.00
0005433681579	2788	Economy	11000.00
0005432967125	2788	Economy	11000.00
0005432967299	2788	Economy	11000.00
0005433681609	2788	Economy	11000.00
0005432967339	2788	Economy	11000.00
0005433681588	2788	Economy	11000.00
0005432222896	2788	Economy	11000.00
0005432967300	2788	Economy	11000.00
0005432222894	2788	Economy	11000.00
0005433681585	2788	Economy	11000.00
0005433681598	2788	Economy	11000.00
0005433681580	2788	Economy	11000.00
0005433681599	2788	Economy	11000.00
0005432222898	2788	Economy	11000.00
0005432967388	2788	Economy	11000.00
0005432967324	2788	Economy	11000.00
0005433681604	2788	Economy	11000.00
0005433681597	2788	Economy	11000.00
0005433681569	2788	Economy	11000.00
0005433681568	2788	Economy	11000.00
0005432967256	2788	Economy	11000.00
0005433681586	2788	Economy	11000.00
0005433681589	2788	Economy	11000.00
0005433681594	2788	Economy	11000.00
0005433681600	2788	Economy	11000.00
0005433681595	2788	Economy	11000.00
0005432967337	2788	Economy	11000.00
0005433681612	2788	Economy	11000.00
0005433681611	2788	Economy	11000.00
0005432967323	2788	Economy	11000.00
0005433681578	2788	Economy	11000.00
0005432967280	2788	Economy	11000.00
0005433681605	2788	Economy	11000.00
0005432967334	2788	Economy	11000.00
0005433681576	2788	Economy	11000.00
0005432967278	2788	Economy	11000.00
0005433681587	2788	Economy	11000.00
0005433681593	2788	Economy	11000.00
0005433680948	29181	Business	33000.00
0005433681262	29181	Business	33000.00
0005433690959	29181	Business	33000.00
0005433681159	29181	Business	33000.00
0005432967488	29181	Business	33000.00
0005433681259	29181	Business	33000.00
0005433681507	29181	Business	33000.00
0005433681253	29181	Business	33000.00
0005433681162	29181	Business	33000.00
0005433687719	29181	Business	33000.00
0005433681340	29181	Business	33000.00
0005433681235	29181	Economy	11000.00
0005433681300	29181	Economy	11000.00
0005432967483	29181	Economy	11000.00
0005433681208	29181	Economy	11000.00
0005432967480	29181	Economy	11000.00
0005432967481	29181	Economy	11000.00
0005433681140	29181	Economy	11000.00
0005433681506	29181	Economy	11000.00
0005433681303	29181	Economy	11000.00
0005432967489	29181	Economy	11000.00
0005433681258	29181	Economy	12100.00
0005433681351	29181	Economy	12100.00
0005432967496	29181	Economy	12100.00
0005433681220	29181	Economy	12100.00
0005433681266	29181	Economy	11000.00
0005433690958	29181	Economy	11000.00
0005433681160	29181	Economy	11000.00
0005432005273	29181	Economy	11000.00
0005433681251	29181	Economy	11000.00
0005433681254	29181	Economy	11000.00
0005432967494	29181	Economy	11000.00
0005432967492	29181	Economy	11000.00
0005433681086	29181	Economy	11000.00
0005433681138	29181	Economy	11000.00
0005432967479	29181	Economy	11000.00
0005433681252	29181	Economy	11000.00
0005433681049	29181	Economy	11000.00
0005432967491	29181	Economy	11000.00
0005433681234	29181	Economy	11000.00
0005433681106	29181	Economy	11000.00
0005432967493	29181	Economy	11000.00
0005433681188	29181	Economy	11000.00
0005433681268	29181	Economy	11000.00
0005433681269	29181	Economy	11000.00
0005432967485	29181	Economy	11000.00
0005433681101	29181	Economy	11000.00
0005432967487	29181	Economy	11000.00
0005433681402	29181	Economy	11000.00
0005433681401	29181	Economy	11000.00
0005433687720	29181	Economy	11000.00
0005432967497	29181	Economy	11000.00
0005433681400	29181	Economy	11000.00
0005432005275	29181	Economy	11000.00
0005433681299	29181	Economy	11000.00
0005432967473	29181	Economy	11000.00
0005433681161	29181	Economy	11000.00
0005433681328	29181	Economy	11000.00
0005433681105	29181	Economy	11000.00
0005433681227	29181	Economy	11000.00
0005432967490	29181	Economy	11000.00
0005433681306	29181	Economy	11000.00
0005433681267	29181	Economy	11000.00
0005432005274	29181	Economy	11000.00
0005432967475	29181	Economy	11000.00
0005432967495	29181	Economy	11000.00
0005433681233	29181	Economy	11000.00
0005433681232	29181	Economy	11000.00
0005433690954	29181	Economy	11000.00
0005433681389	29181	Economy	11000.00
0005432967486	29181	Economy	11000.00
0005432967482	29181	Economy	11000.00
0005433681440	29181	Economy	11000.00
0005433681111	29181	Economy	11000.00
0005432967472	29181	Economy	11000.00
0005432967477	29181	Economy	11000.00
0005433681352	29181	Economy	11000.00
0005433681139	29181	Economy	11000.00
0005432967476	29181	Economy	11000.00
0005432967484	29181	Economy	11000.00
0005433681369	29181	Economy	11000.00
0005433681265	29181	Economy	11000.00
0005433681362	29181	Economy	11000.00
0005433681048	29181	Economy	11000.00
0005433681224	29181	Economy	11000.00
0005433681207	29181	Economy	11000.00
0005433681297	29181	Economy	11000.00
0005432967474	29181	Economy	11000.00
0005433684447	29181	Economy	11000.00
0005432967478	29181	Economy	11000.00
0005432756919	9271	Business	132900.00
0005433616184	9271	Business	132900.00
0005433616212	9271	Business	132900.00
0005433634507	9271	Business	132900.00
0005433616195	9271	Business	132900.00
0005433616169	9271	Business	132900.00
0005432145154	9271	Business	132900.00
0005432145155	9271	Business	132900.00
0005433634511	9271	Business	132900.00
0005432755146	9271	Business	132900.00
0005433616196	9271	Business	132900.00
0005433634531	9271	Business	132900.00
0005433578103	9271	Business	132900.00
0005433616157	9271	Business	132900.00
0005433616202	9271	Business	132900.00
0005432756917	9271	Business	132900.00
0005433616199	9271	Business	132900.00
0005433634537	9271	Business	132900.00
0005433578100	9271	Business	132900.00
0005433616209	9271	Business	132900.00
0005433616174	9271	Business	132900.00
0005433616180	9271	Business	132900.00
0005433616220	9271	Business	132900.00
0005433616170	9271	Business	132900.00
0005433616161	9271	Business	132900.00
0005433616230	9271	Business	132900.00
0005433616198	9271	Economy	48700.00
0005433616179	9271	Economy	48700.00
0005433578101	9271	Economy	48700.00
0005433578099	9271	Economy	48700.00
0005433616201	9271	Economy	44300.00
0005433634527	9271	Economy	44300.00
0005433616226	9271	Economy	44300.00
0005433634536	9271	Economy	44300.00
0005434269126	9271	Economy	44300.00
0005434153542	9271	Economy	44300.00
0005433616210	9271	Economy	44300.00
0005433616183	9271	Economy	44300.00
0005433616181	9271	Economy	44300.00
0005433616200	9271	Economy	44300.00
0005433634508	9271	Economy	44300.00
0005433634515	9271	Economy	44300.00
0005433616208	9271	Economy	44300.00
0005433634513	9271	Economy	44300.00
0005433578092	9271	Economy	44300.00
0005433616222	9271	Economy	44300.00
0005433634519	9271	Economy	44300.00
0005433634518	9271	Economy	44300.00
0005433634535	9271	Economy	44300.00
0005433616187	9271	Economy	44300.00
0005433616213	9271	Economy	44300.00
0005433578098	9271	Economy	44300.00
0005432756920	9271	Economy	44300.00
0005434163696	9271	Economy	44300.00
0005433634506	9271	Economy	44300.00
0005434272214	9271	Economy	44300.00
0005433616225	9271	Economy	44300.00
0005433616186	9271	Economy	44300.00
0005433616227	9271	Economy	44300.00
0005433616203	9271	Economy	44300.00
0005433616215	9271	Economy	44300.00
0005433616218	9271	Economy	44300.00
0005433616214	9271	Economy	44300.00
0005433616207	9271	Economy	44300.00
0005434163749	9271	Economy	44300.00
0005433616228	9271	Economy	44300.00
0005433616165	9271	Economy	44300.00
0005432756918	9271	Economy	44300.00
0005433634516	9271	Economy	44300.00
0005433634517	9271	Economy	44300.00
0005433616216	9271	Economy	44300.00
0005433616178	9271	Economy	44300.00
0005433616182	9271	Economy	44300.00
0005433616159	9271	Economy	44300.00
0005432755147	9271	Economy	44300.00
0005433634505	9271	Economy	44300.00
0005432755145	9271	Economy	44300.00
0005433578102	9271	Economy	44300.00
0005433616192	9271	Economy	44300.00
0005433578096	9271	Economy	44300.00
0005433634523	9271	Economy	44300.00
0005433634504	9271	Economy	44300.00
0005433634529	9271	Economy	44300.00
0005433634534	9271	Economy	48700.00
0005433616189	9271	Economy	48700.00
0005433616211	9271	Economy	48700.00
0005433616185	9271	Economy	48700.00
0005433616194	9271	Economy	48700.00
0005433616219	9271	Economy	44300.00
0005433634522	9271	Economy	44300.00
0005433578097	9271	Economy	44300.00
0005433634530	9271	Economy	44300.00
0005433634510	9271	Economy	48700.00
0005434272215	9271	Economy	44300.00
0005433616204	9271	Economy	44300.00
0005433634521	9271	Economy	44300.00
0005434152806	9271	Economy	44300.00
0005433616193	9271	Economy	44300.00
0005433616175	9271	Economy	44300.00
0005433634526	9271	Economy	44300.00
0005434269128	9271	Economy	44300.00
0005433616191	9271	Economy	44300.00
0005433634524	9271	Economy	44300.00
0005434163727	9271	Economy	44300.00
0005433634512	9271	Economy	44300.00
0005433616224	9271	Economy	44300.00
0005433616166	9271	Economy	44300.00
0005433616168	9271	Economy	44300.00
0005433616164	9271	Economy	44300.00
0005433616229	9271	Economy	44300.00
0005433578093	9271	Economy	44300.00
0005433634514	9271	Economy	44300.00
0005433616206	9271	Economy	44300.00
0005434152783	9271	Economy	44300.00
0005434163750	9271	Economy	44300.00
0005433578095	9271	Economy	44300.00
0005433616156	9271	Economy	44300.00
0005433616160	9271	Economy	44300.00
0005434269129	9271	Economy	44300.00
0005433616223	9271	Economy	44300.00
0005433634538	9271	Economy	44300.00
0005433616188	9271	Economy	44300.00
0005434269127	9271	Economy	44300.00
0005433616171	9271	Economy	44300.00
0005433634532	9271	Economy	44300.00
0005433578104	9271	Economy	44300.00
0005433634528	9271	Economy	44300.00
0005433578094	9271	Economy	44300.00
0005433616190	9271	Economy	44300.00
0005434163736	9271	Economy	44300.00
0005433616176	9271	Economy	44300.00
0005433616173	9271	Economy	44300.00
0005433616162	9271	Economy	44300.00
0005434163735	9271	Economy	44300.00
0005433616217	9271	Economy	44300.00
0005433616177	9271	Economy	44300.00
0005433616197	9271	Economy	44300.00
0005433616205	9271	Economy	44300.00
0005434163743	9271	Economy	44300.00
0005432145153	9271	Economy	44300.00
0005434163734	9271	Economy	44300.00
0005433616158	9271	Economy	44300.00
0005433616172	9271	Economy	44300.00
0005433616163	9271	Economy	44300.00
0005433634509	9271	Economy	44300.00
0005433616167	9271	Economy	44300.00
0005433634533	9271	Economy	44300.00
0005433616221	9271	Economy	44300.00
0005433634520	9271	Economy	44300.00
0005433634525	9271	Economy	44300.00
0005433578091	9271	Economy	44300.00
0005433615636	25218	Business	132900.00
0005432751572	25218	Business	132900.00
0005433615845	25218	Business	132900.00
0005433615538	25218	Business	132900.00
0005432751567	25218	Business	132900.00
0005433615488	25218	Business	132900.00
0005433615601	25218	Business	132900.00
0005433615765	25218	Business	132900.00
0005433615610	25218	Business	132900.00
0005433634259	25218	Business	132900.00
0005433577979	25218	Business	132900.00
0005433615740	25218	Business	132900.00
0005433615781	25218	Business	132900.00
0005432755101	25218	Business	132900.00
0005433615420	25218	Business	132900.00
0005432751564	25218	Business	132900.00
0005433578032	25218	Business	132900.00
0005433634364	25218	Business	132900.00
0005433577988	25218	Business	132900.00
0005433615573	25218	Business	132900.00
0005433634239	25218	Business	132900.00
0005433615850	25218	Business	132900.00
0005433615662	25218	Business	132900.00
0005433615730	25218	Business	132900.00
0005434152831	25218	Business	132900.00
0005433615723	25218	Business	132900.00
0005433634170	25218	Business	132900.00
0005433615851	25218	Business	132900.00
0005433615443	25218	Economy	48700.00
0005433615472	25218	Economy	48700.00
0005433615746	25218	Economy	48700.00
0005433615544	25218	Economy	48700.00
0005432755102	25218	Economy	48700.00
0005432755099	25218	Economy	48700.00
0005433615391	25218	Economy	44300.00
0005433615766	25218	Economy	44300.00
0005433615301	25218	Economy	44300.00
0005433634172	25218	Economy	44300.00
0005433615490	25218	Economy	44300.00
0005432755092	25218	Economy	44300.00
0005433615267	25218	Economy	44300.00
0005433634397	25218	Economy	44300.00
0005433634326	25218	Economy	44300.00
0005433615469	25218	Economy	44300.00
0005433615342	25218	Economy	44300.00
0005432755107	25218	Economy	44300.00
0005433577898	25218	Economy	44300.00
0005433615691	25218	Economy	44300.00
0005432751569	25218	Economy	44300.00
0005433578007	25218	Economy	44300.00
0005433634116	25218	Economy	44300.00
0005433615505	25218	Economy	44300.00
0005434152832	25218	Economy	44300.00
0005433634185	25218	Economy	44300.00
0005432751565	25218	Economy	44300.00
0005433577992	25218	Economy	44300.00
0005433577991	25218	Economy	44300.00
0005432751568	25218	Economy	44300.00
0005433634161	25218	Economy	44300.00
0005433615808	25218	Economy	44300.00
0005433634111	25218	Economy	44300.00
0005433634260	25218	Economy	44300.00
0005433615581	25218	Economy	44300.00
0005432755115	25218	Economy	44300.00
0005433634196	25218	Economy	44300.00
0005433615739	25218	Economy	44300.00
0005433634341	25218	Economy	44300.00
0005432755109	25218	Economy	44300.00
0005433615212	25218	Economy	44300.00
0005433615268	25218	Economy	44300.00
0005432755098	25218	Economy	44300.00
0005433615343	25218	Economy	44300.00
0005433577984	25218	Economy	44300.00
0005433578013	25218	Economy	44300.00
0005433634274	25218	Economy	44300.00
0005433634281	25218	Economy	44300.00
0005433634190	25218	Economy	44300.00
0005432755116	25218	Economy	44300.00
0005433634194	25218	Economy	44300.00
0005432751561	25218	Economy	44300.00
0005433577980	25218	Economy	44300.00
0005434152830	25218	Economy	44300.00
0005434152828	25218	Economy	44300.00
0005433615529	25218	Economy	44300.00
0005433615687	25218	Economy	44300.00
0005433615769	25218	Economy	44300.00
0005432755096	25218	Economy	44300.00
0005433615774	25218	Economy	44300.00
0005432751563	25218	Economy	44300.00
0005432751573	25218	Economy	44300.00
0005433615341	25218	Economy	44300.00
0005434152827	25218	Economy	44300.00
0005433615489	25218	Economy	48700.00
0005433634278	25218	Economy	44300.00
0005433634342	25218	Economy	48700.00
0005433615667	25218	Economy	48700.00
0005432751557	25218	Economy	48700.00
0005433634279	25218	Economy	44300.00
0005433634226	25218	Economy	48700.00
0005433615542	25218	Economy	44300.00
0005433615406	25218	Economy	44300.00
0005432755108	25218	Economy	44300.00
0005432751560	25218	Economy	48700.00
0005433634105	25218	Economy	44300.00
0005433615390	25218	Economy	44300.00
0005433615572	25218	Economy	44300.00
0005433615686	25218	Economy	44300.00
0005433577948	25218	Economy	44300.00
0005433615623	25218	Economy	44300.00
0005432755093	25218	Economy	44300.00
0005433577932	25218	Economy	44300.00
0005433615582	25218	Economy	44300.00
0005433634171	25218	Economy	44300.00
0005433615809	25218	Economy	44300.00
0005433634130	25218	Economy	44300.00
0005433615574	25218	Economy	44300.00
0005433634154	25218	Economy	44300.00
0005433578008	25218	Economy	44300.00
0005434152825	25218	Economy	44300.00
0005433615445	25218	Economy	44300.00
0005434152826	25218	Economy	44300.00
0005432755081	25218	Economy	44300.00
0005432751562	25218	Economy	44300.00
0005433615670	25218	Economy	44300.00
0005432751556	25218	Economy	44300.00
0005432755106	25218	Economy	44300.00
0005433634325	25218	Economy	44300.00
0005433634252	25218	Economy	44300.00
0005433615321	25218	Economy	44300.00
0005433634253	25218	Economy	44300.00
0005433615646	25218	Economy	44300.00
0005433615757	25218	Economy	44300.00
0005433615889	25218	Economy	44300.00
0005433615671	25218	Economy	44300.00
0005433615669	25218	Economy	44300.00
0005433615627	25218	Economy	44300.00
0005433577906	25218	Economy	44300.00
0005433615487	25218	Economy	44300.00
0005433615285	25218	Economy	44300.00
0005434152829	25218	Economy	44300.00
0005433615426	25218	Economy	44300.00
0005433634104	25218	Economy	44300.00
0005433615658	25218	Economy	44300.00
0005433615747	25218	Economy	44300.00
0005433615444	25218	Economy	44300.00
0005433634186	25218	Economy	44300.00
0005433615678	25218	Economy	44300.00
0005433615663	25218	Economy	44300.00
0005433615647	25218	Economy	44300.00
0005433578012	25218	Economy	44300.00
0005432751566	25218	Economy	44300.00
0005433615733	25218	Economy	44300.00
0005433615320	25218	Economy	44300.00
0005432751552	25218	Economy	44300.00
0005433577931	25218	Economy	44300.00
0005433577981	25218	Economy	44300.00
0005433615677	25218	Economy	44300.00
0005433634195	25218	Economy	44300.00
0005433615626	25218	Economy	44300.00
0005433634232	25218	Economy	44300.00
0005433634162	25218	Economy	44300.00
0005432571370	4249	Business	193100.00
0005435787385	4249	Business	193100.00
0005435947360	4249	Business	193100.00
0005435947499	4249	Business	193100.00
0005435856251	4249	Business	193100.00
0005435986917	4249	Business	193100.00
0005434271338	4249	Economy	64400.00
0005435986926	4249	Economy	64400.00
0005435986916	4249	Economy	64400.00
0005435986922	4249	Economy	64400.00
0005435986914	4249	Economy	64400.00
0005435986921	4249	Economy	64400.00
0005435947457	4249	Economy	64400.00
0005435947458	4249	Economy	64400.00
0005435986919	4249	Economy	64400.00
0005435947438	4249	Economy	64400.00
0005432185013	4249	Economy	64400.00
0005435986925	4249	Economy	64400.00
0005435947498	4249	Economy	64400.00
0005435856282	4249	Economy	64400.00
0005435947454	4249	Economy	64400.00
0005432185012	4249	Economy	64400.00
0005435947446	4249	Economy	64400.00
0005435986924	4249	Economy	64400.00
0005435947439	4249	Economy	64400.00
0005432185011	4249	Economy	64400.00
0005435986920	4249	Economy	64400.00
0005432185015	4249	Economy	64400.00
0005435947473	4249	Economy	64400.00
0005435947471	4249	Economy	64400.00
0005435986918	4249	Economy	70800.00
0005434271341	4249	Economy	64400.00
0005435986923	4249	Economy	64400.00
0005435947482	4249	Economy	64400.00
0005435947481	4249	Economy	64400.00
0005435787386	4249	Economy	64400.00
0005435856265	4249	Economy	64400.00
0005432185014	4249	Economy	64400.00
0005435856266	4249	Economy	64400.00
0005432571369	4249	Economy	64400.00
0005432571363	4249	Economy	64400.00
0005434271337	4249	Economy	64400.00
0005435947433	4249	Economy	64400.00
0005435947440	4249	Economy	64400.00
0005435947500	4249	Economy	64400.00
0005432571362	4249	Economy	64400.00
0005435947453	4249	Economy	64400.00
0005435986915	4249	Economy	64400.00
0005435947428	4249	Economy	64400.00
0005435947472	4249	Economy	64400.00
0005435947575	26615	Business	193100.00
0005435947576	26615	Business	193100.00
0005435856294	26615	Business	193100.00
0005435947563	26615	Economy	70800.00
0005435947573	26615	Economy	64400.00
0005435947565	26615	Economy	64400.00
0005435986840	26615	Economy	64400.00
0005435947572	26615	Economy	64400.00
0005435986834	26615	Economy	64400.00
0005435947571	26615	Economy	64400.00
0005435947569	26615	Economy	64400.00
0005435787402	26615	Economy	64400.00
0005432571404	26615	Economy	64400.00
0005435947564	26615	Economy	64400.00
0005432571405	26615	Economy	64400.00
0005435947566	26615	Economy	64400.00
0005435986864	26615	Economy	64400.00
0005435856296	26615	Economy	64400.00
0005435856295	26615	Economy	64400.00
0005435947570	26615	Economy	64400.00
0005435986865	26615	Economy	64400.00
0005435986833	26615	Economy	64400.00
0005435947568	26615	Economy	64400.00
0005435986859	26615	Economy	64400.00
0005435856334	26615	Economy	64400.00
0005435986863	26615	Economy	64400.00
0005435856297	26615	Economy	64400.00
0005435947577	26615	Economy	64400.00
0005435986866	26615	Economy	64400.00
0005432571407	26615	Economy	64400.00
0005435947574	26615	Economy	64400.00
0005432571406	26615	Economy	64400.00
0005435856333	26615	Economy	64400.00
0005435947567	26615	Economy	64400.00
0005435986838	26615	Economy	64400.00
0005435787401	26615	Economy	64400.00
0005432949074	341	Business	21500.00
0005432239069	341	Business	21500.00
0005433129309	341	Business	21500.00
0005433570416	341	Business	21500.00
0005433570427	341	Business	21500.00
0005433570391	341	Business	21500.00
0005432239070	341	Business	21500.00
0005433075170	341	Business	21500.00
0005433075033	341	Business	21500.00
0005433570381	341	Business	21500.00
0005433134199	341	Business	21500.00
0005432948769	341	Business	21500.00
0005432948826	341	Business	21500.00
0005433075029	341	Business	21500.00
0005433570408	341	Business	21500.00
0005433570404	341	Business	21500.00
0005433570424	341	Business	21500.00
0005432948823	341	Business	21500.00
0005433570425	341	Business	21500.00
0005432948987	341	Business	21500.00
0005433570372	341	Business	21500.00
0005433075013	341	Business	21500.00
0005432239073	341	Business	21500.00
0005433570373	341	Economy	7900.00
0005433570388	341	Economy	7900.00
0005432949050	341	Economy	7900.00
0005432948959	341	Economy	7900.00
0005433074986	341	Economy	7900.00
0005432239066	341	Economy	7900.00
0005432948704	341	Economy	7200.00
0005432948988	341	Economy	7200.00
0005433075125	341	Economy	7200.00
0005433570411	341	Economy	7200.00
0005433075089	341	Economy	7200.00
0005432948924	341	Economy	7200.00
0005432948902	341	Economy	7200.00
0005433129320	341	Economy	7200.00
0005433570375	341	Economy	7200.00
0005432948892	341	Economy	7200.00
0005432948916	341	Economy	7200.00
0005433570421	341	Economy	7200.00
0005432239067	341	Economy	7200.00
0005433075202	341	Economy	7200.00
0005432948825	341	Economy	7200.00
0005432239068	341	Economy	7200.00
0005433570409	341	Economy	7200.00
0005432948705	341	Economy	7200.00
0005432949073	341	Economy	7200.00
0005433075085	341	Economy	7200.00
0005432948873	341	Economy	7200.00
0005433570423	341	Economy	7200.00
0005432949035	341	Economy	7200.00
0005433075149	341	Economy	7200.00
0005433075066	341	Economy	7200.00
0005433570397	341	Economy	7200.00
0005433570392	341	Economy	7200.00
0005433075090	341	Economy	7200.00
0005432949117	341	Economy	7200.00
0005433075126	341	Economy	7200.00
0005433570406	341	Economy	7200.00
0005432948875	341	Economy	7200.00
0005433570374	341	Economy	7200.00
0005433570412	341	Economy	7200.00
0005433570402	341	Economy	7200.00
0005433570387	341	Economy	7200.00
0005433570394	341	Economy	7200.00
0005433570395	341	Economy	7200.00
0005432239071	341	Economy	7200.00
0005433570414	341	Economy	7200.00
0005432948768	341	Economy	7200.00
0005432948940	341	Economy	7200.00
0005433075001	341	Economy	7200.00
0005433570382	341	Economy	7200.00
0005433570377	341	Economy	7200.00
0005433075184	341	Economy	7200.00
0005432949004	341	Economy	7200.00
0005432948874	341	Economy	7200.00
0005432948949	341	Economy	7200.00
0005433570389	341	Economy	7200.00
0005432948824	341	Economy	7200.00
0005433570417	341	Economy	7200.00
0005433570418	341	Economy	7200.00
0005432949003	341	Economy	7900.00
0005433570396	341	Economy	7900.00
0005433129318	341	Economy	7900.00
0005432948849	341	Economy	7900.00
0005433570413	341	Economy	7200.00
0005433570405	341	Economy	7900.00
0005432948917	341	Economy	7200.00
0005433075086	341	Economy	7200.00
0005432948926	341	Economy	7200.00
0005432948903	341	Economy	7200.00
0005433570371	341	Economy	7900.00
0005433129334	341	Economy	7200.00
0005433570367	341	Economy	7200.00
0005433570365	341	Economy	7200.00
0005433075201	341	Economy	7200.00
0005433570399	341	Economy	7200.00
0005433570393	341	Economy	7200.00
0005433570398	341	Economy	7200.00
0005433075060	341	Economy	7200.00
0005433570369	341	Economy	7200.00
0005433129310	341	Economy	7200.00
0005433570407	341	Economy	7200.00
0005433075034	341	Economy	7200.00
0005433570370	341	Economy	7200.00
0005432948915	341	Economy	7200.00
0005432949132	341	Economy	7200.00
0005433570366	341	Economy	7200.00
0005433570386	341	Economy	7200.00
0005433075181	341	Economy	7200.00
0005433129319	341	Economy	7200.00
0005433570364	341	Economy	7200.00
0005433570429	341	Economy	7200.00
0005433570420	341	Economy	7200.00
0005432239072	341	Economy	7200.00
0005433570368	341	Economy	7200.00
0005433075092	341	Economy	7200.00
0005433570385	341	Economy	7200.00
0005433570384	341	Economy	7200.00
0005433570401	341	Economy	7200.00
0005433570426	341	Economy	7200.00
0005433075182	341	Economy	7200.00
0005433134175	341	Economy	7200.00
0005433570390	341	Economy	7200.00
0005433570378	341	Economy	7200.00
0005433075169	341	Economy	7200.00
0005433570410	341	Economy	7200.00
0005433570380	341	Economy	7200.00
0005433570422	341	Economy	7200.00
0005432949078	341	Economy	7200.00
0005433570428	341	Economy	7200.00
0005432948851	341	Economy	7200.00
0005433570363	341	Economy	7200.00
0005433129333	341	Economy	7200.00
0005433134205	341	Economy	7200.00
0005433075067	341	Economy	7200.00
0005433075180	341	Economy	7200.00
0005432948893	341	Economy	7200.00
0005433570400	341	Economy	7200.00
0005433570376	341	Economy	7200.00
0005432949082	341	Economy	7200.00
0005433075091	341	Economy	7200.00
0005433570383	341	Economy	7200.00
0005433570415	341	Economy	7200.00
0005433570419	341	Economy	7200.00
0005433570379	341	Economy	7200.00
0005432949131	341	Economy	7200.00
0005432949083	341	Economy	7200.00
0005433570362	341	Economy	7200.00
0005433570403	341	Economy	7200.00
0005433075012	341	Economy	7200.00
0005432949329	11615	Business	21500.00
0005433075314	11615	Business	21500.00
0005433569853	11615	Business	21500.00
0005433569726	11615	Business	21500.00
0005433075332	11615	Business	21500.00
0005433569709	11615	Business	21500.00
0005433569895	11615	Business	21500.00
0005433569900	11615	Business	21500.00
0005433569533	11615	Business	21500.00
0005432949326	11615	Business	21500.00
0005433075321	11615	Business	21500.00
0005432949339	11615	Business	21500.00
0005432192388	11615	Business	21500.00
0005432949308	11615	Business	21500.00
0005433569763	11615	Business	21500.00
0005433075315	11615	Business	21500.00
0005433569749	11615	Business	21500.00
0005433569725	11615	Business	21500.00
0005433569781	11615	Business	21500.00
0005433131808	11615	Business	21500.00
0005433134235	11615	Business	21500.00
0005433075306	11615	Business	21500.00
0005432949319	11615	Business	21500.00
0005433134238	11615	Economy	7900.00
0005432949312	11615	Economy	7900.00
0005433569680	11615	Economy	7900.00
0005432949340	11615	Economy	7900.00
0005433569801	11615	Economy	7200.00
0005433569544	11615	Economy	7200.00
0005433569864	11615	Economy	7200.00
0005433075331	11615	Economy	7200.00
0005432949313	11615	Economy	7200.00
0005433569506	11615	Economy	7200.00
0005433075325	11615	Economy	7200.00
0005433075308	11615	Economy	7200.00
0005433569584	11615	Economy	7200.00
0005433569826	11615	Economy	7200.00
0005433569685	11615	Economy	7200.00
0005433569780	11615	Economy	7200.00
0005433569625	11615	Economy	7200.00
0005433569576	11615	Economy	7200.00
0005433569560	11615	Economy	7200.00
0005433569378	11615	Economy	7200.00
0005433134236	11615	Economy	7200.00
0005433569865	11615	Economy	7200.00
0005433569765	11615	Economy	7200.00
0005433569561	11615	Economy	7200.00
0005432949348	11615	Economy	7200.00
0005433569810	11615	Economy	7200.00
0005433075319	11615	Economy	7200.00
0005433569878	11615	Economy	7200.00
0005432949328	11615	Economy	7200.00
0005433569619	11615	Economy	7200.00
0005433569831	11615	Economy	7200.00
0005433569482	11615	Economy	7200.00
0005433075323	11615	Economy	7200.00
0005432949338	11615	Economy	7200.00
0005433569894	11615	Economy	7200.00
0005432949346	11615	Economy	7200.00
0005432949336	11615	Economy	7200.00
0005433569788	11615	Economy	7200.00
0005432949342	11615	Economy	7200.00
0005432949317	11615	Economy	7200.00
0005433569577	11615	Economy	7200.00
0005432949314	11615	Economy	7200.00
0005433569764	11615	Economy	7200.00
0005432949320	11615	Economy	7200.00
0005432949343	11615	Economy	7200.00
0005433569827	11615	Economy	7200.00
0005433134237	11615	Economy	7200.00
0005433569616	11615	Economy	7200.00
0005433569782	11615	Economy	7200.00
0005433569675	11615	Economy	7200.00
0005432949323	11615	Economy	7200.00
0005433929867	11615	Economy	7200.00
0005433569779	11615	Economy	7200.00
0005433075312	11615	Economy	7200.00
0005433075311	11615	Economy	7200.00
0005433569600	11615	Economy	7200.00
0005433569759	11615	Economy	7900.00
0005432949335	11615	Economy	7200.00
0005432949322	11615	Economy	7900.00
0005433569723	11615	Economy	7900.00
0005432949331	11615	Economy	7900.00
0005433569844	11615	Economy	7200.00
0005433569927	11615	Economy	7900.00
0005432949344	11615	Economy	7200.00
0005432949309	11615	Economy	7200.00
0005432949310	11615	Economy	7900.00
0005433569724	11615	Economy	7200.00
0005432949327	11615	Economy	7200.00
0005433569736	11615	Economy	7200.00
0005432192387	11615	Economy	7200.00
0005433569762	11615	Economy	7200.00
0005432949333	11615	Economy	7200.00
0005433075322	11615	Economy	7200.00
0005433569626	11615	Economy	7200.00
0005433569552	11615	Economy	7200.00
0005433075305	11615	Economy	7200.00
0005433075327	11615	Economy	7200.00
0005433075328	11615	Economy	7200.00
0005433929868	11615	Economy	7200.00
0005432949332	11615	Economy	7200.00
0005433075313	11615	Economy	7200.00
0005432949315	11615	Economy	7200.00
0005433075324	11615	Economy	7200.00
0005432949318	11615	Economy	7200.00
0005432949347	11615	Economy	7200.00
0005432949324	11615	Economy	7200.00
0005433131806	11615	Economy	7200.00
0005433569610	11615	Economy	7200.00
0005433569789	11615	Economy	7200.00
0005433075329	11615	Economy	7200.00
0005433075310	11615	Economy	7200.00
0005433569818	11615	Economy	7200.00
0005432949337	11615	Economy	7200.00
0005433075320	11615	Economy	7200.00
0005432192389	11615	Economy	7200.00
0005433569877	11615	Economy	7200.00
0005433569669	11615	Economy	7200.00
0005433131807	11615	Economy	7200.00
0005432949311	11615	Economy	7200.00
0005433569642	11615	Economy	7200.00
0005432949334	11615	Economy	7200.00
0005433569866	11615	Economy	7200.00
0005432949341	11615	Economy	7200.00
0005432949316	11615	Economy	7200.00
0005433075330	11615	Economy	7200.00
0005432949345	11615	Economy	7200.00
0005432949321	11615	Economy	7200.00
0005433569676	11615	Economy	7200.00
0005433075317	11615	Economy	7200.00
0005433075309	11615	Economy	7200.00
0005433569379	11615	Economy	7200.00
0005432949330	11615	Economy	7200.00
0005433075326	11615	Economy	7200.00
0005432949325	11615	Economy	7200.00
0005433075304	11615	Economy	7200.00
0005433075307	11615	Economy	7200.00
0005433569872	11615	Economy	7200.00
0005433075316	11615	Economy	7200.00
0005433075318	11615	Economy	7200.00
0005434733032	9956	Economy	6300.00
0005434733033	9956	Economy	6300.00
0005433817552	9956	Economy	6300.00
0005433817551	9956	Economy	6300.00
0005433817553	9956	Economy	6300.00
0005433817513	13897	Economy	6300.00
0005433817518	13897	Economy	6300.00
0005434733058	13897	Economy	6300.00
0005434733057	13897	Economy	6300.00
0005433817526	13897	Economy	6300.00
0005434733056	13897	Economy	6300.00
0005434733059	13897	Economy	6300.00
0005433817520	13897	Economy	6300.00
0005434733055	13897	Economy	6300.00
0005433755442	2359	Business	184500.00
0005435983270	2359	Business	184500.00
0005433755447	2359	Business	184500.00
0005435983283	2359	Business	184500.00
0005433435055	2359	Business	184500.00
0005435983274	2359	Business	184500.00
0005433755454	2359	Business	184500.00
0005432985498	2359	Business	184500.00
0005433764726	2359	Business	184500.00
0005435983267	2359	Business	184500.00
0005432985585	2359	Business	184500.00
0005433435071	2359	Business	184500.00
0005432655797	2359	Business	184500.00
0005433764724	2359	Business	184500.00
0005433766720	2359	Business	184500.00
0005432226190	2359	Business	184500.00
0005433755459	2359	Business	184500.00
0005433755438	2359	Business	184500.00
0005435983269	2359	Business	184500.00
0005433755455	2359	Business	184500.00
0005433435135	2359	Business	184500.00
0005433434973	2359	Business	184500.00
0005435983260	2359	Business	184500.00
0005433435080	2359	Business	184500.00
0005433755439	2359	Business	184500.00
0005433755461	2359	Business	184500.00
0005435983286	2359	Business	184500.00
0005435983261	2359	Business	184500.00
0005433435024	2359	Economy	67700.00
0005432300388	2359	Economy	67700.00
0005433434991	2359	Economy	67700.00
0005432985496	2359	Economy	67700.00
0005432226191	2359	Economy	61500.00
0005433755449	2359	Economy	61500.00
0005433434992	2359	Economy	61500.00
0005433766723	2359	Economy	61500.00
0005433755451	2359	Economy	61500.00
0005433435057	2359	Economy	61500.00
0005432985561	2359	Economy	61500.00
0005433755434	2359	Economy	61500.00
0005435983289	2359	Economy	61500.00
0005435983253	2359	Economy	61500.00
0005432985545	2359	Economy	61500.00
0005433434926	2359	Economy	61500.00
0005435983268	2359	Economy	61500.00
0005433755457	2359	Economy	61500.00
0005434731227	2359	Economy	61500.00
0005435983272	2359	Economy	61500.00
0005432655800	2359	Economy	61500.00
0005433755464	2359	Economy	61500.00
0005435983282	2359	Economy	61500.00
0005432985528	2359	Economy	61500.00
0005432226195	2359	Economy	61500.00
0005435983247	2359	Economy	61500.00
0005432655796	2359	Economy	61500.00
0005435983278	2359	Economy	61500.00
0005433435056	2359	Economy	61500.00
0005432655802	2359	Economy	61500.00
0005433434972	2359	Economy	61500.00
0005435983277	2359	Economy	61500.00
0005435983285	2359	Economy	61500.00
0005432655799	2359	Economy	61500.00
0005433755436	2359	Economy	61500.00
0005433435211	2359	Economy	61500.00
0005433434978	2359	Economy	61500.00
0005432226192	2359	Economy	61500.00
0005435983263	2359	Economy	61500.00
0005433755460	2359	Economy	61500.00
0005433755422	2359	Economy	61500.00
0005433755416	2359	Economy	61500.00
0005433435038	2359	Economy	61500.00
0005435983266	2359	Economy	61500.00
0005435983258	2359	Economy	61500.00
0005433755458	2359	Economy	61500.00
0005433755433	2359	Economy	61500.00
0005432655803	2359	Economy	61500.00
0005435983275	2359	Economy	61500.00
0005433434958	2359	Economy	61500.00
0005433764725	2359	Economy	61500.00
0005432985619	2359	Economy	61500.00
0005433435069	2359	Economy	61500.00
0005433755452	2359	Economy	61500.00
0005433434993	2359	Economy	61500.00
0005433434974	2359	Economy	61500.00
0005435983279	2359	Economy	61500.00
0005433435129	2359	Economy	61500.00
0005432985479	2359	Economy	61500.00
0005432985365	2359	Economy	61500.00
0005432985356	2359	Economy	61500.00
0005432985618	2359	Economy	61500.00
0005433755448	2359	Economy	61500.00
0005432985364	2359	Economy	61500.00
0005435983248	2359	Economy	61500.00
0005433755465	2359	Economy	61500.00
0005433434928	2359	Economy	61500.00
0005433766721	2359	Economy	61500.00
0005433755453	2359	Economy	61500.00
0005432300389	2359	Economy	61500.00
0005433755419	2359	Economy	61500.00
0005432985558	2359	Economy	61500.00
0005433755444	2359	Economy	61500.00
0005432985493	2359	Economy	61500.00
0005433755425	2359	Economy	61500.00
0005433755411	2359	Economy	61500.00
0005432985560	2359	Economy	61500.00
0005435983273	2359	Economy	61500.00
0005433435081	2359	Economy	61500.00
0005433434994	2359	Economy	61500.00
0005432985495	2359	Economy	61500.00
0005434731238	2359	Economy	61500.00
0005432985492	2359	Economy	61500.00
0005435983271	2359	Economy	61500.00
0005435983249	2359	Economy	61500.00
0005433435128	2359	Economy	61500.00
0005433755435	2359	Economy	61500.00
0005433766722	2359	Economy	61500.00
0005435983246	2359	Economy	61500.00
0005433755446	2359	Economy	61500.00
0005435983255	2359	Economy	61500.00
0005432655792	2359	Economy	61500.00
0005435983290	2359	Economy	61500.00
0005432300391	2359	Economy	61500.00
0005432300390	2359	Economy	61500.00
0005432985620	2359	Economy	61500.00
0005433435060	2359	Economy	61500.00
0005435983251	2359	Economy	61500.00
0005435983284	2359	Economy	61500.00
0005433755430	2359	Economy	61500.00
0005435983250	2359	Economy	61500.00
0005435983287	2359	Economy	61500.00
0005433434927	2359	Economy	61500.00
0005432300393	2359	Economy	67700.00
0005433755420	2359	Economy	67700.00
0005432985494	2359	Economy	61500.00
0005435983257	2359	Economy	61500.00
0005435983254	2359	Economy	61500.00
0005433755443	2359	Economy	67700.00
0005433755418	2359	Economy	61500.00
0005433755450	2359	Economy	61500.00
0005433755409	2359	Economy	61500.00
0005432985417	2359	Economy	61500.00
0005433755445	2359	Economy	61500.00
0005435983280	2359	Economy	61500.00
0005433435133	2359	Economy	61500.00
0005432655795	2359	Economy	61500.00
0005433755432	2359	Economy	61500.00
0005432985526	2359	Economy	61500.00
0005432985410	2359	Economy	61500.00
0005433434979	2359	Economy	61500.00
0005432655790	2359	Economy	61500.00
0005433755441	2359	Economy	61500.00
0005432985451	2359	Economy	61500.00
0005432985355	2359	Economy	61500.00
0005435983244	2359	Economy	61500.00
0005433435125	2359	Economy	61500.00
0005432985617	2359	Economy	61500.00
0005435983288	2359	Economy	61500.00
0005432985497	2359	Economy	61500.00
0005432226193	2359	Economy	61500.00
0005433755421	2359	Economy	61500.00
0005433434990	2359	Economy	61500.00
0005432985508	2359	Economy	61500.00
0005433755417	2359	Economy	61500.00
0005432985502	2359	Economy	61500.00
0005435983259	2359	Economy	61500.00
0005435983256	2359	Economy	61500.00
0005432985394	2359	Economy	61500.00
0005433755431	2359	Economy	61500.00
0005433755414	2359	Economy	61500.00
0005433435039	2359	Economy	61500.00
0005435983252	2359	Economy	61500.00
0005435983265	2359	Economy	61500.00
0005432985442	2359	Economy	61500.00
0005432655794	2359	Economy	61500.00
0005433435126	2359	Economy	61500.00
0005433755423	2359	Economy	61500.00
0005432655798	2359	Economy	61500.00
0005433434988	2359	Economy	61500.00
0005432300392	2359	Economy	61500.00
0005432985527	2359	Economy	61500.00
0005433755428	2359	Economy	61500.00
0005433755410	2359	Economy	61500.00
0005433435046	2359	Economy	61500.00
0005432655791	2359	Economy	61500.00
0005433755426	2359	Economy	61500.00
0005433755427	2359	Economy	61500.00
0005432985481	2359	Economy	61500.00
0005433755429	2359	Economy	61500.00
0005432655793	2359	Economy	61500.00
0005435983264	2359	Economy	61500.00
0005432226194	2359	Economy	61500.00
0005435983281	2359	Economy	61500.00
0005433435017	2359	Economy	61500.00
0005433755415	2359	Economy	61500.00
0005435983262	2359	Economy	61500.00
0005433755462	2359	Economy	61500.00
0005433755437	2359	Economy	61500.00
0005432655801	2359	Economy	61500.00
0005432869598	2359	Economy	61500.00
0005433755413	2359	Economy	61500.00
0005433755463	2359	Economy	61500.00
0005435983276	2359	Economy	61500.00
0005433435212	2359	Economy	61500.00
0005433755440	2359	Economy	61500.00
0005433434989	2359	Economy	61500.00
0005433435119	2359	Economy	61500.00
0005435983245	2359	Economy	61500.00
0005432985393	2359	Economy	61500.00
0005433434967	2359	Economy	61500.00
0005433755456	2359	Economy	61500.00
0005433755424	2359	Economy	61500.00
0005433755412	2359	Economy	61500.00
0005432985519	2359	Economy	61500.00
0005433754849	26212	Business	184500.00
0005433754783	26212	Business	184500.00
0005433754761	26212	Business	184500.00
0005433755258	26212	Business	184500.00
0005432869665	26212	Business	184500.00
0005434731262	26212	Business	184500.00
0005433755182	26212	Business	184500.00
0005433754823	26212	Business	184500.00
0005435982742	26212	Business	184500.00
0005435982915	26212	Business	184500.00
0005432655690	26212	Business	184500.00
0005432985764	26212	Business	184500.00
0005433754871	26212	Business	184500.00
0005435982702	26212	Business	184500.00
0005433755183	26212	Business	184500.00
0005435982829	26212	Business	184500.00
0005435982669	26212	Business	184500.00
0005433755013	26212	Business	184500.00
0005433754738	26212	Business	184500.00
0005433755021	26212	Business	184500.00
0005435982823	26212	Business	184500.00
0005433754802	26212	Business	184500.00
0005433435300	26212	Business	184500.00
0005433435289	26212	Business	184500.00
0005435982885	26212	Business	184500.00
0005433435277	26212	Business	184500.00
0005433754931	26212	Business	184500.00
0005435982624	26212	Business	184500.00
0005433754816	26212	Business	184500.00
0005433435299	26212	Economy	67700.00
0005432051195	26212	Economy	67700.00
0005435982734	26212	Economy	67700.00
0005433755059	26212	Economy	67700.00
0005433755148	26212	Economy	61500.00
0005432985791	26212	Economy	61500.00
0005433435286	26212	Economy	61500.00
0005433754694	26212	Economy	61500.00
0005433754981	26212	Economy	61500.00
0005433435293	26212	Economy	61500.00
0005433755040	26212	Economy	61500.00
0005433755041	26212	Economy	61500.00
0005432985762	26212	Economy	61500.00
0005432985778	26212	Economy	61500.00
0005435982733	26212	Economy	61500.00
0005433754740	26212	Economy	61500.00
0005432655695	26212	Economy	61500.00
0005433755055	26212	Economy	61500.00
0005435982937	26212	Economy	61500.00
0005435982701	26212	Economy	61500.00
0005435982833	26212	Economy	61500.00
0005432985794	26212	Economy	61500.00
0005432869666	26212	Economy	61500.00
0005433435281	26212	Economy	61500.00
0005435982763	26212	Economy	61500.00
0005433435290	26212	Economy	61500.00
0005435982625	26212	Economy	61500.00
0005433754963	26212	Economy	61500.00
0005435982903	26212	Economy	61500.00
0005433755008	26212	Economy	61500.00
0005433435279	26212	Economy	61500.00
0005433754829	26212	Economy	61500.00
0005435982696	26212	Economy	61500.00
0005433754908	26212	Economy	61500.00
0005432985777	26212	Economy	61500.00
0005432655698	26212	Economy	61500.00
0005433435282	26212	Economy	61500.00
0005432655691	26212	Economy	61500.00
0005435982816	26212	Economy	61500.00
0005434731261	26212	Economy	61500.00
0005432985773	26212	Economy	61500.00
0005435982902	26212	Economy	61500.00
0005435982898	26212	Economy	61500.00
0005432985792	26212	Economy	61500.00
0005435982884	26212	Economy	61500.00
0005432655645	26212	Economy	61500.00
0005433754958	26212	Economy	61500.00
0005434731264	26212	Economy	61500.00
0005433766701	26212	Economy	61500.00
0005432985783	26212	Economy	61500.00
0005432985782	26212	Economy	61500.00
0005433754974	26212	Economy	61500.00
0005432655646	26212	Economy	61500.00
0005433435276	26212	Economy	61500.00
0005432985786	26212	Economy	61500.00
0005433754983	26212	Economy	61500.00
0005435982813	26212	Economy	61500.00
0005432655693	26212	Economy	61500.00
0005432985779	26212	Economy	61500.00
0005432655694	26212	Economy	61500.00
0005432655697	26212	Economy	61500.00
0005435982886	26212	Economy	61500.00
0005432049541	26212	Economy	61500.00
0005432985780	26212	Economy	61500.00
0005435982797	26212	Economy	61500.00
0005432985771	26212	Economy	61500.00
0005432985761	26212	Economy	61500.00
0005435982904	26212	Economy	61500.00
0005435982798	26212	Economy	61500.00
0005433755138	26212	Economy	61500.00
0005435982781	26212	Economy	61500.00
0005435982626	26212	Economy	61500.00
0005433754934	26212	Economy	61500.00
0005435982917	26212	Economy	61500.00
0005433435283	26212	Economy	61500.00
0005432985793	26212	Economy	61500.00
0005435982754	26212	Economy	61500.00
0005433755032	26212	Economy	61500.00
0005435982918	26212	Economy	61500.00
0005433435274	26212	Economy	61500.00
0005432985781	26212	Economy	61500.00
0005433754959	26212	Economy	61500.00
0005433754893	26212	Economy	61500.00
0005435982855	26212	Economy	61500.00
0005435982864	26212	Economy	61500.00
0005432051196	26212	Economy	61500.00
0005432869663	26212	Economy	61500.00
0005432985787	26212	Economy	61500.00
0005435982722	26212	Economy	61500.00
0005433435288	26212	Economy	61500.00
0005432985770	26212	Economy	61500.00
0005433754984	26212	Economy	61500.00
0005433754810	26212	Economy	61500.00
0005433435285	26212	Economy	61500.00
0005433435291	26212	Economy	61500.00
0005435982801	26212	Economy	61500.00
0005433754955	26212	Economy	61500.00
0005433755030	26212	Economy	61500.00
0005433755056	26212	Economy	61500.00
0005435982767	26212	Economy	61500.00
0005432655727	26212	Economy	61500.00
0005433435280	26212	Economy	61500.00
0005435982854	26212	Economy	61500.00
0005435982660	26212	Economy	61500.00
0005433435295	26212	Economy	67700.00
0005432869667	26212	Economy	67700.00
0005433755031	26212	Economy	61500.00
0005435982812	26212	Economy	61500.00
0005432985785	26212	Economy	61500.00
0005435982914	26212	Economy	67700.00
0005432049540	26212	Economy	61500.00
0005435982715	26212	Economy	67700.00
0005433754907	26212	Economy	61500.00
0005435982824	26212	Economy	61500.00
0005432985774	26212	Economy	61500.00
0005432985784	26212	Economy	61500.00
0005432655716	26212	Economy	61500.00
0005433435294	26212	Economy	61500.00
0005432869664	26212	Economy	61500.00
0005433754859	26212	Economy	61500.00
0005432655696	26212	Economy	61500.00
0005435982785	26212	Economy	61500.00
0005433435278	26212	Economy	61500.00
0005433754954	26212	Economy	61500.00
0005432049542	26212	Economy	61500.00
0005432051194	26212	Economy	61500.00
0005435982894	26212	Economy	61500.00
0005432655689	26212	Economy	61500.00
0005435982764	26212	Economy	61500.00
0005435982931	26212	Economy	61500.00
0005432655692	26212	Economy	61500.00
0005433755137	26212	Economy	61500.00
0005433754899	26212	Economy	61500.00
0005432655668	26212	Economy	61500.00
0005432985776	26212	Economy	61500.00
0005435982743	26212	Economy	61500.00
0005433435287	26212	Economy	61500.00
0005435982932	26212	Economy	61500.00
0005432655660	26212	Economy	61500.00
0005435982744	26212	Economy	61500.00
0005432985765	26212	Economy	61500.00
0005435982787	26212	Economy	61500.00
0005432985772	26212	Economy	61500.00
0005435982913	26212	Economy	61500.00
0005433764703	26212	Economy	61500.00
0005432655688	26212	Economy	61500.00
0005435982741	26212	Economy	61500.00
0005435982871	26212	Economy	61500.00
0005433435296	26212	Economy	61500.00
0005433754745	26212	Economy	61500.00
0005433435297	26212	Economy	61500.00
0005433435292	26212	Economy	61500.00
0005432985766	26212	Economy	61500.00
0005435982827	26212	Economy	61500.00
0005433755016	26212	Economy	61500.00
0005432985789	26212	Economy	61500.00
0005432985768	26212	Economy	61500.00
0005432985790	26212	Economy	61500.00
0005433754939	26212	Economy	61500.00
0005432985767	26212	Economy	61500.00
0005435982916	26212	Economy	61500.00
0005433755204	26212	Economy	61500.00
0005433435275	26212	Economy	61500.00
0005432985769	26212	Economy	61500.00
0005435982768	26212	Economy	61500.00
0005432985763	26212	Economy	61500.00
0005433754930	26212	Economy	61500.00
0005433764708	26212	Economy	61500.00
0005433754739	26212	Economy	61500.00
0005435982670	26212	Economy	61500.00
0005434731260	26212	Economy	61500.00
0005435982870	26212	Economy	61500.00
0005433754863	26212	Economy	61500.00
0005432985775	26212	Economy	61500.00
0005435982716	26212	Economy	61500.00
0005433754826	26212	Economy	61500.00
0005433754933	26212	Economy	61500.00
0005433755043	26212	Economy	61500.00
0005433754815	26212	Economy	61500.00
0005434731263	26212	Economy	61500.00
0005432985788	26212	Economy	61500.00
0005433766700	26212	Economy	61500.00
0005435982814	26212	Economy	61500.00
0005433435284	26212	Economy	61500.00
0005433435301	26212	Economy	61500.00
0005432655669	26212	Economy	61500.00
0005433754821	26212	Economy	61500.00
0005433754822	26212	Economy	61500.00
0005433435298	26212	Economy	61500.00
0005434375654	1523	Business	38900.00
0005434375628	1523	Business	38900.00
0005434375661	1523	Business	38900.00
0005434375645	1523	Business	38900.00
0005434375631	1523	Business	38900.00
0005433151764	1523	Business	38900.00
0005433931508	1523	Business	38900.00
0005433151883	1523	Business	38900.00
0005434375662	1523	Business	38900.00
0005433460482	1523	Economy	13000.00
0005434375621	1523	Economy	13000.00
0005434375612	1523	Economy	13000.00
0005434375658	1523	Economy	13000.00
0005434375647	1523	Economy	13000.00
0005434375637	1523	Economy	13000.00
0005433151935	1523	Economy	13000.00
0005434375620	1523	Economy	13000.00
0005433460483	1523	Economy	13000.00
0005434375663	1523	Economy	13000.00
0005433151765	1523	Economy	13000.00
0005433151867	1523	Economy	13000.00
0005434375640	1523	Economy	13000.00
0005434029693	1523	Economy	13000.00
0005433151839	1523	Economy	13000.00
0005434375639	1523	Economy	13000.00
0005434375635	1523	Economy	13000.00
0005433151862	1523	Economy	13000.00
0005434375656	1523	Economy	13000.00
0005434375636	1523	Economy	13000.00
0005432268041	1523	Economy	13000.00
0005433151868	1523	Economy	13000.00
0005433151884	1523	Economy	13000.00
0005432268040	1523	Economy	13000.00
0005434375626	1523	Economy	13000.00
0005434029683	1523	Economy	13000.00
0005433151857	1523	Economy	13000.00
0005433151858	1523	Economy	13000.00
0005432268038	1523	Economy	13000.00
0005432268042	1523	Economy	13000.00
0005434375648	1523	Economy	13000.00
0005434375644	1523	Economy	14300.00
0005433151911	1523	Economy	14300.00
0005433151939	1523	Economy	14300.00
0005434375642	1523	Economy	14300.00
0005432268037	1523	Economy	14300.00
0005433151817	1523	Economy	13000.00
0005434375627	1523	Economy	13000.00
0005434029684	1523	Economy	13000.00
0005434375617	1523	Economy	13000.00
0005433931507	1523	Economy	13000.00
0005433151797	1523	Economy	13000.00
0005434375655	1523	Economy	13000.00
0005434375634	1523	Economy	13000.00
0005433152039	1523	Economy	13000.00
0005434375623	1523	Economy	13000.00
0005433151948	1523	Economy	13000.00
0005433151929	1523	Economy	13000.00
0005434375649	1523	Economy	13000.00
0005433151865	1523	Economy	13000.00
0005434375638	1523	Economy	13000.00
0005433151798	1523	Economy	13000.00
0005434375608	1523	Economy	13000.00
0005434029687	1523	Economy	13000.00
0005433152010	1523	Economy	13000.00
0005433152020	1523	Economy	13000.00
0005434375646	1523	Economy	13000.00
0005433151894	1523	Economy	13000.00
0005434375657	1523	Economy	13000.00
0005434375630	1523	Economy	13000.00
0005432268043	1523	Economy	13000.00
0005433151866	1523	Economy	13000.00
0005434375650	1523	Economy	13000.00
0005434375613	1523	Economy	13000.00
0005434375622	1523	Economy	13000.00
0005433151885	1523	Economy	13000.00
0005434375625	1523	Economy	13000.00
0005434375659	1523	Economy	13000.00
0005433151880	1523	Economy	13000.00
0005434375618	1523	Economy	13000.00
0005434375624	1523	Economy	13000.00
0005433151938	1523	Economy	13000.00
0005434375629	1523	Economy	13000.00
0005432268039	1523	Economy	13000.00
0005433151840	1523	Economy	13000.00
0005434375615	1523	Economy	13000.00
0005434375653	1523	Economy	13000.00
0005434375611	1523	Economy	13000.00
0005434375609	1523	Economy	13000.00
0005434375616	1523	Economy	13000.00
0005434375651	1523	Economy	13000.00
0005434375652	1523	Economy	13000.00
0005434375632	1523	Economy	13000.00
0005434375643	1523	Economy	13000.00
0005433151910	1523	Economy	13000.00
0005433151903	1523	Economy	13000.00
0005434375614	1523	Economy	13000.00
0005434375633	1523	Economy	13000.00
0005433151949	1523	Economy	13000.00
0005434375660	1523	Economy	13000.00
0005434375610	1523	Economy	13000.00
0005434029686	1523	Economy	13000.00
0005433151882	1523	Economy	13000.00
0005434375607	1523	Economy	13000.00
0005434375619	1523	Economy	13000.00
0005434375641	1523	Economy	13000.00
0005434375343	20150	Business	38900.00
0005433152163	20150	Business	38900.00
0005433152147	20150	Business	38900.00
0005434375344	20150	Business	38900.00
0005433152162	20150	Business	38900.00
0005433152138	20150	Business	38900.00
0005434375166	20150	Business	38900.00
0005432056379	20150	Business	38900.00
0005433152142	20150	Business	38900.00
0005434375096	20150	Economy	13000.00
0005434375233	20150	Economy	13000.00
0005434375249	20150	Economy	13000.00
0005433152164	20150	Economy	13000.00
0005433931531	20150	Economy	13000.00
0005434375165	20150	Economy	13000.00
0005434375324	20150	Economy	13000.00
0005434375319	20150	Economy	13000.00
0005434375116	20150	Economy	13000.00
0005434375140	20150	Economy	13000.00
0005433152137	20150	Economy	13000.00
0005434375190	20150	Economy	13000.00
0005433152141	20150	Economy	13000.00
0005433152132	20150	Economy	13000.00
0005434375160	20150	Economy	13000.00
0005432056382	20150	Economy	13000.00
0005434029711	20150	Economy	13000.00
0005433931533	20150	Economy	13000.00
0005434375248	20150	Economy	13000.00
0005433764725	20150	Economy	13000.00
0005433152153	20150	Economy	13000.00
0005433152152	20150	Economy	13000.00
0005433152155	20150	Economy	13000.00
0005433152151	20150	Economy	13000.00
0005433764726	20150	Economy	13000.00
0005432056381	20150	Economy	14300.00
0005433152135	20150	Economy	14300.00
0005434375353	20150	Economy	14300.00
0005434375267	20150	Economy	14300.00
0005433152145	20150	Economy	13000.00
0005433152139	20150	Economy	13000.00
0005434375291	20150	Economy	13000.00
0005434375050	20150	Economy	13000.00
0005434375266	20150	Economy	13000.00
0005434375194	20150	Economy	13000.00
0005433152158	20150	Economy	13000.00
0005433152146	20150	Economy	13000.00
0005433152149	20150	Economy	13000.00
0005433152159	20150	Economy	13000.00
0005434375264	20150	Economy	13000.00
0005433152134	20150	Economy	13000.00
0005434375237	20150	Economy	13000.00
0005433152133	20150	Economy	13000.00
0005433152157	20150	Economy	13000.00
0005433764724	20150	Economy	13000.00
0005434375214	20150	Economy	13000.00
0005434375265	20150	Economy	13000.00
0005432056380	20150	Economy	13000.00
0005434375323	20150	Economy	13000.00
0005433931532	20150	Economy	13000.00
0005433152130	20150	Economy	13000.00
0005433152160	20150	Economy	13000.00
0005434375215	20150	Economy	13000.00
0005433152148	20150	Economy	13000.00
0005434375047	20150	Economy	13000.00
0005433152136	20150	Economy	13000.00
0005434375368	20150	Economy	13000.00
0005434375161	20150	Economy	13000.00
0005433152154	20150	Economy	13000.00
0005433931529	20150	Economy	13000.00
0005433152150	20150	Economy	13000.00
0005433931530	20150	Economy	13000.00
0005433152144	20150	Economy	13000.00
0005433152140	20150	Economy	13000.00
0005433152161	20150	Economy	13000.00
0005433152131	20150	Economy	13000.00
0005434375296	20150	Economy	13000.00
0005433152156	20150	Economy	13000.00
0005434375279	20150	Economy	13000.00
0005433152143	20150	Economy	13000.00
0005434375066	20150	Economy	13000.00
0005432425482	549	Business	27500.00
0005432425480	549	Business	27500.00
0005432283014	549	Business	27500.00
0005432425487	549	Business	27500.00
0005432425516	549	Business	27500.00
0005432425512	549	Business	27500.00
0005432425508	549	Business	27500.00
0005432425495	549	Business	27500.00
0005432425479	549	Economy	10100.00
0005432425513	549	Economy	10100.00
0005432425492	549	Economy	9200.00
0005432425494	549	Economy	9200.00
0005432425519	549	Economy	9200.00
0005432425509	549	Economy	9200.00
0005432425504	549	Economy	9200.00
0005432425514	549	Economy	9200.00
0005432425485	549	Economy	9200.00
0005432425484	549	Economy	9200.00
0005432425522	549	Economy	9200.00
0005432283018	549	Economy	9200.00
0005432425481	549	Economy	9200.00
0005432425502	549	Economy	9200.00
0005432425503	549	Economy	9200.00
0005432425500	549	Economy	9200.00
0005432425478	549	Economy	9200.00
0005432425496	549	Economy	9200.00
0005432425493	549	Economy	9200.00
0005432425497	549	Economy	9200.00
0005432425499	549	Economy	9200.00
0005432283019	549	Economy	10100.00
0005432425517	549	Economy	10100.00
0005432425490	549	Economy	9200.00
0005432425501	549	Economy	9200.00
0005432425483	549	Economy	9200.00
0005432425498	549	Economy	9200.00
0005432283017	549	Economy	9200.00
0005432425518	549	Economy	9200.00
0005432425488	549	Economy	9200.00
0005432425521	549	Economy	9200.00
0005432425506	549	Economy	9200.00
0005432425510	549	Economy	9200.00
0005432425486	549	Economy	9200.00
0005432425507	549	Economy	9200.00
0005432425505	549	Economy	9200.00
0005432425520	549	Economy	9200.00
0005432425511	549	Economy	9200.00
0005432425489	549	Economy	9200.00
0005432283016	549	Economy	9200.00
0005432425515	549	Economy	9200.00
0005432425491	549	Economy	9200.00
0005432283015	549	Economy	9200.00
0005433261882	12859	Business	27500.00
0005432302411	12859	Business	27500.00
0005433261881	12859	Business	27500.00
0005433261880	12859	Economy	9200.00
0005433261883	12859	Economy	9200.00
0005432302412	12859	Economy	9200.00
0005433261884	12859	Economy	9200.00
0005432302413	12859	Economy	9200.00
0005432424924	12903	Business	27500.00
0005432424962	12903	Business	27500.00
0005432424756	12903	Business	27500.00
0005432424964	12903	Business	27500.00
0005432425009	12903	Business	27500.00
0005432424995	12903	Business	27500.00
0005432425028	12903	Business	27500.00
0005432424990	12903	Economy	9200.00
0005432425050	12903	Economy	9200.00
0005432425069	12903	Economy	9200.00
0005432424934	12903	Economy	9200.00
0005432424984	12903	Economy	9200.00
0005432424867	12903	Economy	9200.00
0005432424894	12903	Economy	9200.00
0005432424983	12903	Economy	9200.00
0005432424866	12903	Economy	9200.00
0005432424970	12903	Economy	9200.00
0005432424963	12903	Economy	9200.00
0005432424865	12903	Economy	9200.00
0005432424864	12903	Economy	9200.00
0005432424757	12903	Economy	9200.00
0005432424919	12903	Economy	9200.00
0005432424945	12903	Economy	9200.00
0005432425037	12903	Economy	9200.00
0005432424974	12903	Economy	9200.00
0005432424868	12903	Economy	9200.00
0005432424994	12903	Economy	10100.00
0005432425059	12903	Economy	9200.00
0005432424832	12903	Economy	9200.00
0005432424925	12903	Economy	9200.00
0005432424946	12903	Economy	9200.00
0005432424981	12903	Economy	9200.00
0005432424928	12903	Economy	9200.00
0005432424938	12903	Economy	9200.00
0005432424923	12903	Economy	9200.00
0005432424951	12903	Economy	9200.00
0005432424996	12903	Economy	9200.00
0005432424988	12903	Economy	9200.00
0005432425039	12903	Economy	9200.00
0005432424973	12903	Economy	9200.00
0005432424935	12903	Economy	9200.00
0005432425015	12903	Economy	9200.00
0005432424975	12903	Economy	9200.00
0005432424965	12903	Economy	9200.00
0005432424922	12903	Economy	9200.00
0005432425051	12903	Economy	9200.00
0005432424937	12903	Economy	9200.00
0005432424997	12903	Economy	9200.00
0005432424929	12903	Economy	9200.00
0005432424831	12903	Economy	9200.00
0005432424980	12903	Economy	9200.00
0005433058366	477	Business	24500.00
0005434025156	477	Business	24500.00
0005434025187	477	Business	24500.00
0005434025185	477	Business	24500.00
0005433058286	477	Business	24500.00
0005433684441	477	Business	24500.00
0005433058365	477	Business	24500.00
0005434025145	477	Business	24500.00
0005434025140	477	Business	24500.00
0005433684442	477	Business	24500.00
0005434032117	477	Business	24500.00
0005434025177	477	Business	24500.00
0005434032118	477	Business	24500.00
0005434025183	477	Business	24500.00
0005433058598	477	Business	24500.00
0005434025165	477	Business	24500.00
0005434025141	477	Business	24500.00
0005433058520	477	Business	24500.00
0005434025199	477	Business	24500.00
0005433058428	477	Economy	9000.00
0005434025190	477	Economy	9000.00
0005434025167	477	Economy	9000.00
0005433058334	477	Economy	9000.00
0005433058416	477	Economy	8200.00
0005433058357	477	Economy	8200.00
0005434735733	477	Economy	8200.00
0005434025166	477	Economy	8200.00
0005434025157	477	Economy	8200.00
0005433058521	477	Economy	8200.00
0005434025155	477	Economy	8200.00
0005433058555	477	Economy	8200.00
0005434025181	477	Economy	8200.00
0005434025154	477	Economy	8200.00
0005434032121	477	Economy	8200.00
0005434025200	477	Economy	8200.00
0005434029708	477	Economy	8200.00
0005433058479	477	Economy	8200.00
0005434032119	477	Economy	8200.00
0005434025176	477	Economy	8200.00
0005433684446	477	Economy	8200.00
0005434025204	477	Economy	8200.00
0005432045653	477	Economy	8200.00
0005433058480	477	Economy	8200.00
0005434025197	477	Economy	8200.00
0005432235800	477	Economy	8200.00
0005434025202	477	Economy	8200.00
0005433058427	477	Economy	8200.00
0005434025195	477	Economy	8200.00
0005434025168	477	Economy	8200.00
0005433058456	477	Economy	8200.00
0005433058552	477	Economy	8200.00
0005434735755	477	Economy	8200.00
0005433684445	477	Economy	8200.00
0005434025171	477	Economy	8200.00
0005432235799	477	Economy	8200.00
0005434735767	477	Economy	8200.00
0005432235802	477	Economy	8200.00
0005433058453	477	Economy	8200.00
0005433058506	477	Economy	8200.00
0005433058250	477	Economy	8200.00
0005434028365	477	Economy	8200.00
0005433058473	477	Economy	8200.00
0005434025150	477	Economy	8200.00
0005434025159	477	Economy	8200.00
0005434032120	477	Economy	8200.00
0005434025146	477	Economy	8200.00
0005434735732	477	Economy	8200.00
0005434025184	477	Economy	8200.00
0005434025144	477	Economy	8200.00
0005434025174	477	Economy	8200.00
0005433058454	477	Economy	8200.00
0005433058417	477	Economy	8200.00
0005433058339	477	Economy	8200.00
0005434025137	477	Economy	8200.00
0005434025163	477	Economy	8200.00
0005432045654	477	Economy	8200.00
0005434025138	477	Economy	8200.00
0005434029710	477	Economy	8200.00
0005434025153	477	Economy	8200.00
0005434025173	477	Economy	8200.00
0005434025147	477	Economy	8200.00
0005434025175	477	Economy	9000.00
0005433058565	477	Economy	9000.00
0005434025152	477	Economy	9000.00
0005434735734	477	Economy	8200.00
0005434025151	477	Economy	9000.00
0005433058388	477	Economy	8200.00
0005434025182	477	Economy	8200.00
0005434735768	477	Economy	8200.00
0005434029709	477	Economy	8200.00
0005434025172	477	Economy	8200.00
0005434028366	477	Economy	8200.00
0005434025164	477	Economy	8200.00
0005433058455	477	Economy	8200.00
0005433058429	477	Economy	8200.00
0005432235803	477	Economy	8200.00
0005434025191	477	Economy	8200.00
0005433058338	477	Economy	8200.00
0005434025198	477	Economy	8200.00
0005433058558	477	Economy	8200.00
0005433058519	477	Economy	8200.00
0005434025178	477	Economy	8200.00
0005434025189	477	Economy	8200.00
0005434025170	477	Economy	8200.00
0005434025149	477	Economy	8200.00
0005434025201	477	Economy	8200.00
0005433058498	477	Economy	8200.00
0005434025136	477	Economy	8200.00
0005434025203	477	Economy	8200.00
0005434025142	477	Economy	8200.00
0005434025161	477	Economy	8200.00
0005434025162	477	Economy	8200.00
0005433058249	477	Economy	8200.00
0005434025180	477	Economy	8200.00
0005434025148	477	Economy	8200.00
0005433058590	477	Economy	8200.00
0005433058205	477	Economy	8200.00
0005434025158	477	Economy	8200.00
0005434025143	477	Economy	8200.00
0005432235801	477	Economy	8200.00
0005433058556	477	Economy	8200.00
0005434025193	477	Economy	8200.00
0005434025188	477	Economy	8200.00
0005434028367	477	Economy	8200.00
0005434025139	477	Economy	8200.00
0005434025192	477	Economy	8200.00
0005434025169	477	Economy	8200.00
0005434025179	477	Economy	8200.00
0005434025160	477	Economy	8200.00
0005434025196	477	Economy	8200.00
0005434025194	477	Economy	8200.00
0005433058335	477	Economy	8200.00
0005434025186	477	Economy	8200.00
0005434024696	12681	Business	24500.00
0005434024588	12681	Business	24500.00
0005434032073	12681	Business	24500.00
0005433929703	12681	Business	24500.00
0005433058754	12681	Business	24500.00
0005433929706	12681	Business	24500.00
0005433058747	12681	Business	24500.00
0005434024741	12681	Business	24500.00
0005434024596	12681	Business	24500.00
0005434024454	12681	Business	24500.00
0005433058758	12681	Business	24500.00
0005433058738	12681	Business	24500.00
0005434024499	12681	Business	24500.00
0005434735806	12681	Business	24500.00
0005434024623	12681	Business	24500.00
0005433058730	12681	Business	24500.00
0005434024316	12681	Business	24500.00
0005434024697	12681	Economy	9000.00
0005433058766	12681	Economy	9000.00
0005434029683	12681	Economy	9000.00
0005434024659	12681	Economy	9000.00
0005434024658	12681	Economy	8200.00
0005433058733	12681	Economy	8200.00
0005434029687	12681	Economy	8200.00
0005434024657	12681	Economy	8200.00
0005433058748	12681	Economy	8200.00
0005434024698	12681	Economy	8200.00
0005434024564	12681	Economy	8200.00
0005433058762	12681	Economy	8200.00
0005432157534	12681	Economy	8200.00
0005434024556	12681	Economy	8200.00
0005434024707	12681	Economy	8200.00
0005433058739	12681	Economy	8200.00
0005434024533	12681	Economy	8200.00
0005434024341	12681	Economy	8200.00
0005434024456	12681	Economy	8200.00
0005434024426	12681	Economy	8200.00
0005433929701	12681	Economy	8200.00
0005434735801	12681	Economy	8200.00
0005434735805	12681	Economy	8200.00
0005433058731	12681	Economy	8200.00
0005434024472	12681	Economy	8200.00
0005433058769	12681	Economy	8200.00
0005433058734	12681	Economy	8200.00
0005434024474	12681	Economy	8200.00
0005434029693	12681	Economy	8200.00
0005433058768	12681	Economy	8200.00
0005434024739	12681	Economy	8200.00
0005434024475	12681	Economy	8200.00
0005434024546	12681	Economy	8200.00
0005434024340	12681	Economy	8200.00
0005433058740	12681	Economy	8200.00
0005434024226	12681	Economy	8200.00
0005433058755	12681	Economy	8200.00
0005434024273	12681	Economy	8200.00
0005434032074	12681	Economy	8200.00
0005433058757	12681	Economy	8200.00
0005432156460	12681	Economy	8200.00
0005434024706	12681	Economy	8200.00
0005432156459	12681	Economy	8200.00
0005433058764	12681	Economy	8200.00
0005433684466	12681	Economy	8200.00
0005433058744	12681	Economy	8200.00
0005433058765	12681	Economy	8200.00
0005434735804	12681	Economy	8200.00
0005434024618	12681	Economy	8200.00
0005434032078	12681	Economy	8200.00
0005434024712	12681	Economy	8200.00
0005433058742	12681	Economy	8200.00
0005434029686	12681	Economy	8200.00
0005434024632	12681	Economy	8200.00
0005434024594	12681	Economy	8200.00
0005433058735	12681	Economy	8200.00
0005433058736	12681	Economy	8200.00
0005434024543	12681	Economy	8200.00
0005432156463	12681	Economy	8200.00
0005433058732	12681	Economy	8200.00
0005434024210	12681	Economy	8200.00
0005434032079	12681	Economy	8200.00
0005434024811	12681	Economy	8200.00
0005434024626	12681	Economy	8200.00
0005434024415	12681	Economy	8200.00
0005434024201	12681	Economy	8200.00
0005434024298	12681	Economy	8200.00
0005434024665	12681	Economy	8200.00
0005433058737	12681	Economy	9000.00
0005434024317	12681	Economy	8200.00
0005433058756	12681	Economy	9000.00
0005434024810	12681	Economy	8200.00
0005434024652	12681	Economy	8200.00
0005434024512	12681	Economy	8200.00
0005434028324	12681	Economy	8200.00
0005433929702	12681	Economy	8200.00
0005433058759	12681	Economy	8200.00
0005434024511	12681	Economy	8200.00
0005434024742	12681	Economy	8200.00
0005433058741	12681	Economy	8200.00
0005434024763	12681	Economy	8200.00
0005433058729	12681	Economy	8200.00
0005434024764	12681	Economy	8200.00
0005433058767	12681	Economy	8200.00
0005433058760	12681	Economy	8200.00
0005433058745	12681	Economy	8200.00
0005434735803	12681	Economy	8200.00
0005433058753	12681	Economy	8200.00
0005433058751	12681	Economy	8200.00
0005433058749	12681	Economy	8200.00
0005432156462	12681	Economy	8200.00
0005434024235	12681	Economy	8200.00
0005434024699	12681	Economy	8200.00
0005432156461	12681	Economy	8200.00
0005433058770	12681	Economy	8200.00
0005434024557	12681	Economy	8200.00
0005433058743	12681	Economy	8200.00
0005433058752	12681	Economy	8200.00
0005433929704	12681	Economy	8200.00
0005433058763	12681	Economy	8200.00
0005434028326	12681	Economy	8200.00
0005433929705	12681	Economy	8200.00
0005434024627	12681	Economy	8200.00
0005433058750	12681	Economy	8200.00
0005434029684	12681	Economy	8200.00
0005434024780	12681	Economy	8200.00
0005434024534	12681	Economy	8200.00
0005434024354	12681	Economy	8200.00
0005434032077	12681	Economy	8200.00
0005434024615	12681	Economy	8200.00
0005433058761	12681	Economy	8200.00
0005434735802	12681	Economy	8200.00
0005433058746	12681	Economy	8200.00
0005434024517	12681	Economy	8200.00
0005433529356	13823	Business	111600.00
0005433527344	13823	Business	111600.00
0005433527339	13823	Business	111600.00
0005433527340	13823	Economy	37200.00
0005433527345	13823	Economy	37200.00
0005433527336	13823	Economy	37200.00
0005433527342	13823	Economy	37200.00
0005433529349	13823	Economy	37200.00
0005433527338	13823	Economy	37200.00
0005433527346	13823	Economy	37200.00
0005433529351	13823	Economy	37200.00
0005433527343	13823	Economy	37200.00
0005433529354	13823	Economy	37200.00
0005433529355	13823	Economy	37200.00
0005433529357	13823	Economy	37200.00
0005433529347	13823	Economy	37200.00
0005433529350	13823	Economy	37200.00
0005433527337	13823	Economy	37200.00
0005433529352	13823	Economy	37200.00
0005433529353	13823	Economy	37200.00
0005433527341	13823	Economy	37200.00
0005433529348	13823	Economy	37200.00
0005433533364	32453	Business	111600.00
0005433533363	32453	Business	111600.00
0005433529324	32453	Business	111600.00
0005433533372	32453	Business	111600.00
0005433529308	32453	Economy	37200.00
0005433533353	32453	Economy	37200.00
0005433533352	32453	Economy	37200.00
0005433529315	32453	Economy	37200.00
0005433529325	32453	Economy	37200.00
0005433529319	32453	Economy	37200.00
0005433529320	32453	Economy	37200.00
0005433529326	32453	Economy	37200.00
0005433529316	32453	Economy	37200.00
0005433533362	32453	Economy	37200.00
0005433533371	32453	Economy	37200.00
0005433529304	32453	Economy	37200.00
0005433529322	32453	Economy	37200.00
0005433529318	32453	Economy	37200.00
0005433925327	2110	Business	34700.00
0005433925324	2110	Business	34700.00
0005433925393	2110	Business	34700.00
0005433931533	2110	Business	34700.00
0005433925369	2110	Business	34700.00
0005433925329	2110	Business	34700.00
0005433925358	2110	Business	34700.00
0005433925395	2110	Business	34700.00
0005433925367	2110	Business	34700.00
0005433036963	2110	Business	34700.00
0005433036964	2110	Business	34700.00
0005432044585	2110	Business	34700.00
0005433929702	2110	Business	34700.00
0005433925387	2110	Business	34700.00
0005433037166	2110	Business	34700.00
0005432231791	2110	Business	34700.00
0005433925382	2110	Business	34700.00
0005433925371	2110	Business	34700.00
0005433925322	2110	Business	34700.00
0005433931532	2110	Business	34700.00
0005433925334	2110	Business	34700.00
0005433036871	2110	Economy	12700.00
0005433925365	2110	Economy	12700.00
0005433925359	2110	Economy	11600.00
0005433036893	2110	Economy	11600.00
0005433037245	2110	Economy	11600.00
0005433037098	2110	Economy	11600.00
0005433037167	2110	Economy	11600.00
0005433925412	2110	Economy	11600.00
0005433925343	2110	Economy	11600.00
0005433036894	2110	Economy	11600.00
0005433925372	2110	Economy	11600.00
0005433925337	2110	Economy	11600.00
0005433925364	2110	Economy	11600.00
0005432044584	2110	Economy	11600.00
0005433037004	2110	Economy	11600.00
0005433925366	2110	Economy	11600.00
0005433925320	2110	Economy	11600.00
0005433925348	2110	Economy	11600.00
0005433036886	2110	Economy	11600.00
0005433036949	2110	Economy	11600.00
0005433925347	2110	Economy	11600.00
0005433925342	2110	Economy	11600.00
0005433929703	2110	Economy	11600.00
0005433925409	2110	Economy	11600.00
0005433925380	2110	Economy	11600.00
0005434028324	2110	Economy	11600.00
0005433925341	2110	Economy	11600.00
0005433875414	2110	Economy	11600.00
0005433929704	2110	Economy	11600.00
0005433875413	2110	Economy	11600.00
0005433036879	2110	Economy	11600.00
0005433925389	2110	Economy	11600.00
0005432231796	2110	Economy	11600.00
0005433925331	2110	Economy	11600.00
0005433925414	2110	Economy	11600.00
0005433925352	2110	Economy	11600.00
0005432044586	2110	Economy	11600.00
0005433036857	2110	Economy	11600.00
0005433931531	2110	Economy	11600.00
0005433931529	2110	Economy	11600.00
0005433925326	2110	Economy	11600.00
0005433036856	2110	Economy	11600.00
0005432749810	2110	Economy	11600.00
0005433036836	2110	Economy	11600.00
0005433036998	2110	Economy	11600.00
0005433036953	2110	Economy	11600.00
0005433036948	2110	Economy	11600.00
0005433036844	2110	Economy	11600.00
0005433925318	2110	Economy	11600.00
0005433036885	2110	Economy	11600.00
0005433036837	2110	Economy	11600.00
0005433925374	2110	Economy	11600.00
0005433925406	2110	Economy	11600.00
0005433925356	2110	Economy	11600.00
0005432231797	2110	Economy	11600.00
0005433037053	2110	Economy	11600.00
0005433037081	2110	Economy	11600.00
0005433925357	2110	Economy	11600.00
0005433929701	2110	Economy	11600.00
0005433925330	2110	Economy	11600.00
0005433925410	2110	Economy	11600.00
0005433925378	2110	Economy	11600.00
0005433925385	2110	Economy	11600.00
0005433925397	2110	Economy	11600.00
0005433925377	2110	Economy	11600.00
0005433037046	2110	Economy	11600.00
0005433931530	2110	Economy	11600.00
0005433036956	2110	Economy	11600.00
0005433925411	2110	Economy	11600.00
0005434028326	2110	Economy	11600.00
0005433925403	2110	Economy	11600.00
0005433037061	2110	Economy	11600.00
0005432749812	2110	Economy	11600.00
0005433037244	2110	Economy	11600.00
0005433929706	2110	Economy	11600.00
0005433036843	2110	Economy	11600.00
0005433036950	2110	Economy	11600.00
0005433925332	2110	Economy	11600.00
0005433925392	2110	Economy	11600.00
0005433925344	2110	Economy	11600.00
0005433037117	2110	Economy	11600.00
0005433925333	2110	Economy	11600.00
0005433925405	2110	Economy	11600.00
0005433925354	2110	Economy	11600.00
0005433925335	2110	Economy	11600.00
0005433036912	2110	Economy	11600.00
0005433036931	2110	Economy	11600.00
0005433037124	2110	Economy	11600.00
0005433036943	2110	Economy	11600.00
0005433036892	2110	Economy	11600.00
0005432231790	2110	Economy	11600.00
0005433036962	2110	Economy	12700.00
0005433036872	2110	Economy	11600.00
0005433925401	2110	Economy	11600.00
0005432231788	2110	Economy	11600.00
0005433925361	2110	Economy	12700.00
0005432231798	2110	Economy	12700.00
0005433925400	2110	Economy	11600.00
0005433036777	2110	Economy	11600.00
0005433037003	2110	Economy	11600.00
0005433925388	2110	Economy	11600.00
0005433925363	2110	Economy	11600.00
0005433925362	2110	Economy	11600.00
0005433925383	2110	Economy	11600.00
0005433037064	2110	Economy	11600.00
0005433925373	2110	Economy	11600.00
0005433925319	2110	Economy	11600.00
0005433925340	2110	Economy	11600.00
0005433925391	2110	Economy	11600.00
0005433925398	2110	Economy	11600.00
0005433925384	2110	Economy	11600.00
0005433925325	2110	Economy	11600.00
0005433925321	2110	Economy	11600.00
0005433929705	2110	Economy	11600.00
0005432231795	2110	Economy	11600.00
0005433925407	2110	Economy	11600.00
0005433925339	2110	Economy	11600.00
0005432749814	2110	Economy	11600.00
0005433036932	2110	Economy	11600.00
0005432231794	2110	Economy	11600.00
0005433925370	2110	Economy	11600.00
0005433036845	2110	Economy	11600.00
0005433036795	2110	Economy	11600.00
0005433925404	2110	Economy	11600.00
0005433925386	2110	Economy	11600.00
0005433925368	2110	Economy	11600.00
0005433036942	2110	Economy	11600.00
0005433925390	2110	Economy	11600.00
0005433925402	2110	Economy	11600.00
0005433925353	2110	Economy	11600.00
0005433925351	2110	Economy	11600.00
0005433925381	2110	Economy	11600.00
0005432231793	2110	Economy	11600.00
0005433925399	2110	Economy	11600.00
0005433925338	2110	Economy	11600.00
0005433925336	2110	Economy	11600.00
0005433925396	2110	Economy	11600.00
0005433925346	2110	Economy	11600.00
0005433925345	2110	Economy	11600.00
0005433925323	2110	Economy	11600.00
0005433925376	2110	Economy	11600.00
0005433925350	2110	Economy	11600.00
0005433925415	2110	Economy	11600.00
0005433925394	2110	Economy	11600.00
0005433037035	2110	Economy	11600.00
0005432231789	2110	Economy	11600.00
0005433925408	2110	Economy	11600.00
0005433037080	2110	Economy	11600.00
0005432749813	2110	Economy	11600.00
0005433925355	2110	Economy	11600.00
0005433925375	2110	Economy	11600.00
0005433037036	2110	Economy	11600.00
0005433036946	2110	Economy	11600.00
0005433925360	2110	Economy	11600.00
0005433925379	2110	Economy	11600.00
0005432231792	2110	Economy	11600.00
0005433925349	2110	Economy	11600.00
0005433925328	2110	Economy	11600.00
0005433925413	2110	Economy	11600.00
0005433037438	24116	Business	34700.00
0005433924674	24116	Business	34700.00
0005434028369	24116	Business	34700.00
0005433037447	24116	Business	34700.00
0005433924726	24116	Business	34700.00
0005433037425	24116	Business	34700.00
0005433924503	24116	Business	34700.00
0005433924551	24116	Business	34700.00
0005433924722	24116	Business	34700.00
0005433924653	24116	Business	34700.00
0005433037454	24116	Business	34700.00
0005433924767	24116	Business	34700.00
0005433037445	24116	Business	34700.00
0005433924832	24116	Business	34700.00
0005433924538	24116	Business	34700.00
0005433037441	24116	Business	34700.00
0005433037415	24116	Business	34700.00
0005433924733	24116	Business	34700.00
0005432206320	24116	Business	34700.00
0005433037411	24116	Business	34700.00
0005433924619	24116	Business	34700.00
0005433037451	24116	Business	34700.00
0005433924381	24116	Business	34700.00
0005433924723	24116	Economy	12700.00
0005433037431	24116	Economy	12700.00
0005433923986	24116	Economy	12700.00
0005433037456	24116	Economy	11600.00
0005433924256	24116	Economy	11600.00
0005433924293	24116	Economy	11600.00
0005433037426	24116	Economy	11600.00
0005433924576	24116	Economy	11600.00
0005433924657	24116	Economy	11600.00
0005433924552	24116	Economy	11600.00
0005433924258	24116	Economy	11600.00
0005433924285	24116	Economy	11600.00
0005433037409	24116	Economy	11600.00
0005433037437	24116	Economy	11600.00
0005433924600	24116	Economy	11600.00
0005433037430	24116	Economy	11600.00
0005433037414	24116	Economy	11600.00
0005433037416	24116	Economy	11600.00
0005433037418	24116	Economy	11600.00
0005433924119	24116	Economy	11600.00
0005433924788	24116	Economy	11600.00
0005433924802	24116	Economy	11600.00
0005433924109	24116	Economy	11600.00
0005433924426	24116	Economy	11600.00
0005433924730	24116	Economy	11600.00
0005433924651	24116	Economy	11600.00
0005434028371	24116	Economy	11600.00
0005433037435	24116	Economy	11600.00
0005432206322	24116	Economy	11600.00
0005432207719	24116	Economy	11600.00
0005433924954	24116	Economy	11600.00
0005433924625	24116	Economy	11600.00
0005433037420	24116	Economy	11600.00
0005433923822	24116	Economy	11600.00
0005433924149	24116	Economy	11600.00
0005433037424	24116	Economy	11600.00
0005433924527	24116	Economy	11600.00
0005433924506	24116	Economy	11600.00
0005433037442	24116	Economy	11600.00
0005433923821	24116	Economy	11600.00
0005433037408	24116	Economy	11600.00
0005433037457	24116	Economy	11600.00
0005433924626	24116	Economy	11600.00
0005433924431	24116	Economy	11600.00
0005433931512	24116	Economy	11600.00
0005433924702	24116	Economy	11600.00
0005433931511	24116	Economy	11600.00
0005433037455	24116	Economy	11600.00
0005433924292	24116	Economy	11600.00
0005433037434	24116	Economy	11600.00
0005433037412	24116	Economy	11600.00
0005433929657	24116	Economy	11600.00
0005433924257	24116	Economy	11600.00
0005433924435	24116	Economy	11600.00
0005433924958	24116	Economy	11600.00
0005433037460	24116	Economy	11600.00
0005433924441	24116	Economy	11600.00
0005433037423	24116	Economy	11600.00
0005433037448	24116	Economy	11600.00
0005433924418	24116	Economy	11600.00
0005433924526	24116	Economy	11600.00
0005433037427	24116	Economy	11600.00
0005433037432	24116	Economy	11600.00
0005433924524	24116	Economy	11600.00
0005432206323	24116	Economy	11600.00
0005433037453	24116	Economy	11600.00
0005433875403	24116	Economy	11600.00
0005433037428	24116	Economy	11600.00
0005433924386	24116	Economy	11600.00
0005433924507	24116	Economy	11600.00
0005433924762	24116	Economy	11600.00
0005433924666	24116	Economy	11600.00
0005434028368	24116	Economy	11600.00
0005433037422	24116	Economy	11600.00
0005433924162	24116	Economy	11600.00
0005433037458	24116	Economy	11600.00
0005433037443	24116	Economy	11600.00
0005433924959	24116	Economy	11600.00
0005432749833	24116	Economy	11600.00
0005433924286	24116	Economy	12700.00
0005433037439	24116	Economy	12700.00
0005432749832	24116	Economy	11600.00
0005433924147	24116	Economy	12700.00
0005433929671	24116	Economy	12700.00
0005433924624	24116	Economy	11600.00
0005433924483	24116	Economy	11600.00
0005433037429	24116	Economy	11600.00
0005433037436	24116	Economy	11600.00
0005433924239	24116	Economy	11600.00
0005433037417	24116	Economy	11600.00
0005433037444	24116	Economy	11600.00
0005433924484	24116	Economy	11600.00
0005433924647	24116	Economy	11600.00
0005433924734	24116	Economy	11600.00
0005432206318	24116	Economy	11600.00
0005432206319	24116	Economy	11600.00
0005433924607	24116	Economy	11600.00
0005433924685	24116	Economy	11600.00
0005433037433	24116	Economy	11600.00
0005433924645	24116	Economy	11600.00
0005433924897	24116	Economy	11600.00
0005432207718	24116	Economy	11600.00
0005433037450	24116	Economy	11600.00
0005433037452	24116	Economy	11600.00
0005433037413	24116	Economy	11600.00
0005433924150	24116	Economy	11600.00
0005433924430	24116	Economy	11600.00
0005433924371	24116	Economy	11600.00
0005433924515	24116	Economy	11600.00
0005433929664	24116	Economy	11600.00
0005433924163	24116	Economy	11600.00
0005433924676	24116	Economy	11600.00
0005433924528	24116	Economy	11600.00
0005433924458	24116	Economy	11600.00
0005433037449	24116	Economy	11600.00
0005432206321	24116	Economy	11600.00
0005433924442	24116	Economy	11600.00
0005433924434	24116	Economy	11600.00
0005433924245	24116	Economy	11600.00
0005433924427	24116	Economy	11600.00
0005433037446	24116	Economy	11600.00
0005433924251	24116	Economy	11600.00
0005433924887	24116	Economy	11600.00
0005433929656	24116	Economy	11600.00
0005433037407	24116	Economy	11600.00
0005433037459	24116	Economy	11600.00
0005433037419	24116	Economy	11600.00
0005433924547	24116	Economy	11600.00
0005433924352	24116	Economy	11600.00
0005433037421	24116	Economy	11600.00
0005434028370	24116	Economy	11600.00
0005433924420	24116	Economy	11600.00
0005433931513	24116	Economy	11600.00
0005433924269	24116	Economy	11600.00
0005433037440	24116	Economy	11600.00
0005433037410	24116	Economy	11600.00
0005433924244	24116	Economy	11600.00
0005433923823	24116	Economy	11600.00
0005434728021	290	Business	83700.00
0005434728032	290	Business	83700.00
0005434728108	290	Business	83700.00
0005434735796	290	Business	83700.00
0005434728058	290	Business	83700.00
0005432278093	290	Business	83700.00
0005433126895	290	Business	83700.00
0005433111530	290	Business	83700.00
0005434552425	290	Business	83700.00
0005433234550	290	Business	83700.00
0005433234551	290	Business	83700.00
0005433235016	290	Business	83700.00
0005433234759	290	Business	83700.00
0005434728065	290	Business	83700.00
0005433181420	290	Business	83700.00
0005433181307	290	Business	83700.00
0005433234893	290	Business	83700.00
0005434731259	290	Business	83700.00
0005433131771	290	Business	83700.00
0005434728127	290	Business	83700.00
0005434728029	290	Business	83700.00
0005434552436	290	Business	83700.00
0005434728087	290	Business	83700.00
0005434552399	290	Business	83700.00
0005432278100	290	Business	83700.00
0005434728031	290	Business	83700.00
0005433234905	290	Comfort	47400.00
0005434032063	290	Comfort	47400.00
0005434735795	290	Comfort	47400.00
0005433181419	290	Comfort	47400.00
0005433235076	290	Comfort	47400.00
0005433131750	290	Comfort	47400.00
0005433234894	290	Comfort	47400.00
0005433235167	290	Comfort	47400.00
0005433235077	290	Comfort	47400.00
0005433235150	290	Comfort	47400.00
0005433235201	290	Comfort	47400.00
0005432278097	290	Comfort	47400.00
0005434728074	290	Comfort	47400.00
0005433235196	290	Comfort	47400.00
0005434735797	290	Comfort	47400.00
0005433234921	290	Comfort	47400.00
0005434728132	290	Comfort	47400.00
0005432278099	290	Comfort	47400.00
0005434728086	290	Comfort	47400.00
0005433126909	290	Comfort	47400.00
0005433289903	290	Comfort	47400.00
0005434728077	290	Comfort	47400.00
0005433235108	290	Comfort	47400.00
0005433235260	290	Comfort	47400.00
0005434728052	290	Comfort	47400.00
0005434728035	290	Comfort	47400.00
0005433131756	290	Comfort	47400.00
0005433289932	290	Comfort	47400.00
0005434728066	290	Comfort	47400.00
0005434728091	290	Comfort	47400.00
0005434728039	290	Comfort	47400.00
0005434552388	290	Comfort	47400.00
0005434728084	290	Comfort	47400.00
0005434728061	290	Comfort	47400.00
0005434552440	290	Comfort	47400.00
0005433235008	290	Comfort	47400.00
0005434552393	290	Comfort	47400.00
0005433126890	290	Comfort	47400.00
0005434552431	290	Comfort	47400.00
0005433234903	290	Comfort	47400.00
0005433235052	290	Comfort	47400.00
0005434552439	290	Comfort	47400.00
0005433234780	290	Economy	27900.00
0005433181344	290	Economy	27900.00
0005434728038	290	Economy	27900.00
0005433181378	290	Economy	27900.00
0005434728116	290	Economy	27900.00
0005434552441	290	Economy	27900.00
0005434728135	290	Economy	27900.00
0005434552427	290	Economy	27900.00
0005434728047	290	Economy	27900.00
0005434552413	290	Economy	27900.00
0005434728037	290	Economy	27900.00
0005433235075	290	Economy	27900.00
0005434728025	290	Economy	27900.00
0005435142874	290	Economy	27900.00
0005434728144	290	Economy	27900.00
0005434728143	290	Economy	27900.00
0005434728097	290	Economy	27900.00
0005434735798	290	Economy	27900.00
0005434552429	290	Economy	27900.00
0005433181473	290	Economy	27900.00
0005433181379	290	Economy	27900.00
0005434728118	290	Economy	27900.00
0005433126900	290	Economy	27900.00
0005433234892	290	Economy	27900.00
0005434728055	290	Economy	27900.00
0005435142863	290	Economy	27900.00
0005434552396	290	Economy	27900.00
0005434552422	290	Economy	27900.00
0005433235101	290	Economy	27900.00
0005434032088	290	Economy	27900.00
0005433234957	290	Economy	27900.00
0005434552414	290	Economy	27900.00
0005434728060	290	Economy	27900.00
0005434735799	290	Economy	27900.00
0005434302890	290	Economy	27900.00
0005433181472	290	Economy	27900.00
0005434728068	290	Economy	27900.00
0005433234979	290	Economy	27900.00
0005433235122	290	Economy	27900.00
0005433235040	290	Economy	27900.00
0005434552400	290	Economy	27900.00
0005434728117	290	Economy	27900.00
0005434728069	290	Economy	27900.00
0005433235222	290	Economy	27900.00
0005434728094	290	Economy	27900.00
0005434728048	290	Economy	27900.00
0005432278101	290	Economy	27900.00
0005434728138	290	Economy	27900.00
0005435142868	290	Economy	27900.00
0005433289949	290	Economy	27900.00
0005433181396	290	Economy	27900.00
0005433235039	290	Economy	27900.00
0005434552424	290	Economy	27900.00
0005435142875	290	Economy	27900.00
0005433131746	290	Economy	27900.00
0005433235158	290	Economy	27900.00
0005434728141	290	Economy	27900.00
0005434302886	290	Economy	27900.00
0005434728136	290	Economy	27900.00
0005434552421	290	Economy	27900.00
0005434302553	290	Economy	27900.00
0005433234964	290	Economy	27900.00
0005434728090	290	Economy	27900.00
0005434552407	290	Economy	27900.00
0005434552392	290	Economy	27900.00
0005433234788	290	Economy	30700.00
0005433181437	290	Economy	30700.00
0005434728026	290	Economy	27900.00
0005434728023	290	Economy	30700.00
0005433131763	290	Economy	27900.00
0005434728107	290	Economy	27900.00
0005434731256	290	Economy	27900.00
0005434728096	290	Economy	30700.00
0005434552406	290	Economy	30700.00
0005434552433	290	Economy	27900.00
0005435142869	290	Economy	30700.00
0005433181434	290	Economy	27900.00
0005434552397	290	Economy	27900.00
0005434728062	290	Economy	27900.00
0005434552415	290	Economy	27900.00
0005433234983	290	Economy	27900.00
0005433235054	290	Economy	27900.00
0005434728082	290	Economy	27900.00
0005434735800	290	Economy	27900.00
0005433131755	290	Economy	27900.00
0005434552394	290	Economy	27900.00
0005434728134	290	Economy	27900.00
0005434728104	290	Economy	27900.00
0005434728120	290	Economy	27900.00
0005434552403	290	Economy	27900.00
0005433181323	290	Economy	27900.00
0005434728067	290	Economy	27900.00
0005433235151	290	Economy	27900.00
0005433235188	290	Economy	27900.00
0005434728083	290	Economy	27900.00
0005435142867	290	Economy	27900.00
0005435142866	290	Economy	27900.00
0005434728049	290	Economy	27900.00
0005434728046	290	Economy	27900.00
0005434552395	290	Economy	27900.00
0005435142873	290	Economy	27900.00
0005434728099	290	Economy	27900.00
0005434728133	290	Economy	27900.00
0005434728071	290	Economy	27900.00
0005434728057	290	Economy	27900.00
0005434728115	290	Economy	27900.00
0005433234917	290	Economy	27900.00
0005434552391	290	Economy	27900.00
0005433234965	290	Economy	27900.00
0005434728089	290	Economy	27900.00
0005433235202	290	Economy	27900.00
0005434552398	290	Economy	27900.00
0005434032064	290	Economy	27900.00
0005433126894	290	Economy	27900.00
0005434728063	290	Economy	27900.00
0005434552442	290	Economy	27900.00
0005434552428	290	Economy	27900.00
0005434302887	290	Economy	27900.00
0005434728075	290	Economy	27900.00
0005433181380	290	Economy	27900.00
0005433131779	290	Economy	27900.00
0005434728042	290	Economy	27900.00
0005433234951	290	Economy	27900.00
0005433235015	290	Economy	27900.00
0005433234886	290	Economy	27900.00
0005434552418	290	Economy	27900.00
0005434728095	290	Economy	27900.00
0005433181498	290	Economy	27900.00
0005434728050	290	Economy	27900.00
0005432278098	290	Economy	27900.00
0005434728114	290	Economy	27900.00
0005434728119	290	Economy	27900.00
0005433131745	290	Economy	27900.00
0005433181461	290	Economy	27900.00
0005434728024	290	Economy	27900.00
0005433234841	290	Economy	27900.00
0005433181471	290	Economy	27900.00
0005434728051	290	Economy	27900.00
0005434728105	290	Economy	27900.00
0005435142871	290	Economy	27900.00
0005434552426	290	Economy	27900.00
0005434552389	290	Economy	27900.00
0005434728126	290	Economy	27900.00
0005434552390	290	Economy	27900.00
0005434728124	290	Economy	27900.00
0005433181346	290	Economy	27900.00
0005433131754	290	Economy	27900.00
0005434728034	290	Economy	27900.00
0005433235098	290	Economy	27900.00
0005434728129	290	Economy	27900.00
0005434728044	290	Economy	27900.00
0005433181464	290	Economy	27900.00
0005433234760	290	Economy	27900.00
0005434728043	290	Economy	27900.00
0005432278105	290	Economy	27900.00
0005434728040	290	Economy	27900.00
0005435142864	290	Economy	27900.00
0005433235198	290	Economy	27900.00
0005435142865	290	Economy	27900.00
0005435142872	290	Economy	27900.00
0005434728098	290	Economy	27900.00
0005432278103	290	Economy	27900.00
0005434728139	290	Economy	27900.00
0005433766678	290	Economy	27900.00
0005434302889	290	Economy	27900.00
0005433181389	290	Economy	27900.00
0005434728027	290	Economy	27900.00
0005433234787	290	Economy	27900.00
0005434728123	290	Economy	27900.00
0005432278104	290	Economy	27900.00
0005432278096	290	Economy	27900.00
0005434728054	290	Economy	27900.00
0005434728100	290	Economy	27900.00
0005434728137	290	Economy	27900.00
0005434728092	290	Economy	27900.00
0005434552402	290	Economy	27900.00
0005434728073	290	Economy	27900.00
0005433181374	290	Economy	27900.00
0005434728079	290	Economy	27900.00
0005434302552	290	Economy	27900.00
0005434728109	290	Economy	27900.00
0005434728064	290	Economy	27900.00
0005434728093	290	Economy	30700.00
0005433111533	290	Economy	30700.00
0005433181458	290	Economy	30700.00
0005433235183	290	Economy	30700.00
0005433126893	290	Economy	27900.00
0005434552404	290	Economy	30700.00
0005433126891	290	Economy	27900.00
0005433113569	290	Economy	27900.00
0005432278095	290	Economy	27900.00
0005433234882	290	Economy	27900.00
0005434731257	290	Economy	27900.00
0005434552412	290	Economy	27900.00
0005434728022	290	Economy	27900.00
0005433235095	290	Economy	27900.00
0005434728122	290	Economy	27900.00
0005433235245	290	Economy	27900.00
0005434552437	290	Economy	27900.00
0005434728078	290	Economy	27900.00
0005434728106	290	Economy	27900.00
0005434552411	290	Economy	27900.00
0005434552401	290	Economy	27900.00
0005434728041	290	Economy	27900.00
0005433235166	290	Economy	27900.00
0005434552410	290	Economy	27900.00
0005433126910	290	Economy	27900.00
0005433181394	290	Economy	27900.00
0005433235096	290	Economy	27900.00
0005433111534	290	Economy	27900.00
0005435142862	290	Economy	27900.00
0005434552409	290	Economy	27900.00
0005434728070	290	Economy	27900.00
0005434302554	290	Economy	27900.00
0005433235000	290	Economy	27900.00
0005434728080	290	Economy	27900.00
0005433235097	290	Economy	27900.00
0005433234954	290	Economy	27900.00
0005434032081	290	Economy	27900.00
0005434032080	290	Economy	27900.00
0005433289927	290	Economy	27900.00
0005434552438	290	Economy	27900.00
0005434552387	290	Economy	27900.00
0005433181424	290	Economy	27900.00
0005434728142	290	Economy	27900.00
0005434552405	290	Economy	27900.00
0005432278094	290	Economy	27900.00
0005434731258	290	Economy	27900.00
0005434728121	290	Economy	27900.00
0005433113568	290	Economy	27900.00
0005433181354	290	Economy	27900.00
0005434552432	290	Economy	27900.00
0005434552416	290	Economy	27900.00
0005433289926	290	Economy	27900.00
0005434728033	290	Economy	27900.00
0005432278102	290	Economy	27900.00
0005433235007	290	Economy	27900.00
0005433181401	290	Economy	27900.00
0005434728081	290	Economy	27900.00
0005434728036	290	Economy	27900.00
0005433131780	290	Economy	27900.00
0005434728131	290	Economy	27900.00
0005434728028	290	Economy	27900.00
0005434552435	290	Economy	27900.00
0005433235328	290	Economy	27900.00
0005434728102	290	Economy	27900.00
0005434552417	290	Economy	27900.00
0005434728113	290	Economy	27900.00
0005434728103	290	Economy	27900.00
0005433234955	290	Economy	27900.00
0005434728128	290	Economy	27900.00
0005433234786	290	Economy	27900.00
0005433235014	290	Economy	27900.00
0005433181459	290	Economy	27900.00
0005433235197	290	Economy	27900.00
0005434552423	290	Economy	27900.00
0005434728130	290	Economy	27900.00
0005434552434	290	Economy	27900.00
0005434552420	290	Economy	27900.00
0005433234902	290	Economy	27900.00
0005434728053	290	Economy	27900.00
0005433235244	290	Economy	27900.00
0005433235035	290	Economy	27900.00
0005434728076	290	Economy	27900.00
0005435142870	290	Economy	27900.00
0005433181423	290	Economy	27900.00
0005434728125	290	Economy	27900.00
0005434728085	290	Economy	27900.00
0005433289902	290	Economy	27900.00
0005433181493	290	Economy	27900.00
0005434728111	290	Economy	27900.00
0005433181490	290	Economy	27900.00
0005434728045	290	Economy	27900.00
0005434552430	290	Economy	27900.00
0005434728030	290	Economy	27900.00
0005434302888	290	Economy	27900.00
0005434728110	290	Economy	27900.00
0005434728140	290	Economy	27900.00
0005434552419	290	Economy	27900.00
0005433181345	290	Economy	27900.00
0005434728101	290	Economy	27900.00
0005433289950	290	Economy	27900.00
0005434728059	290	Economy	27900.00
0005434552408	290	Economy	27900.00
0005434728112	290	Economy	27900.00
0005434728072	290	Economy	27900.00
0005434728056	290	Economy	27900.00
0005434728088	290	Economy	27900.00
0005434551841	9842	Business	83700.00
0005434727445	9842	Business	83700.00
0005434551718	9842	Business	83700.00
0005434551878	9842	Business	83700.00
0005433235532	9842	Business	83700.00
0005434032123	9842	Business	83700.00
0005432199397	9842	Business	83700.00
0005434726658	9842	Business	83700.00
0005434552090	9842	Business	83700.00
0005433235559	9842	Business	83700.00
0005433235549	9842	Business	83700.00
0005433235571	9842	Business	83700.00
0005434726660	9842	Business	83700.00
0005435142747	9842	Business	83700.00
0005433290000	9842	Business	83700.00
0005434727380	9842	Business	83700.00
0005434726826	9842	Business	83700.00
0005434552075	9842	Business	83700.00
0005433181643	9842	Business	83700.00
0005434727206	9842	Business	83700.00
0005434726916	9842	Business	83700.00
0005434551724	9842	Business	83700.00
0005434727036	9842	Business	83700.00
0005434551808	9842	Business	83700.00
0005433235542	9842	Business	83700.00
0005434726626	9842	Business	83700.00
0005434727253	9842	Comfort	47400.00
0005434552007	9842	Comfort	47400.00
0005434727290	9842	Comfort	47400.00
0005433235590	9842	Comfort	47400.00
0005433181655	9842	Comfort	47400.00
0005434735748	9842	Comfort	47400.00
0005434726534	9842	Comfort	47400.00
0005434727407	9842	Comfort	47400.00
0005433235552	9842	Comfort	47400.00
0005434551959	9842	Comfort	47400.00
0005434032124	9842	Comfort	47400.00
0005434727028	9842	Comfort	47400.00
0005433129373	9842	Comfort	47400.00
0005434551875	9842	Comfort	47400.00
0005433181650	9842	Comfort	47400.00
0005434727152	9842	Comfort	47400.00
0005434726991	9842	Comfort	47400.00
0005433235547	9842	Comfort	47400.00
0005433126944	9842	Comfort	47400.00
0005433129375	9842	Comfort	47400.00
0005433235563	9842	Comfort	47400.00
0005434552151	9842	Comfort	47400.00
0005433235579	9842	Comfort	47400.00
0005433235570	9842	Comfort	47400.00
0005434032122	9842	Comfort	47400.00
0005433181652	9842	Comfort	47400.00
0005433181638	9842	Comfort	47400.00
0005434551969	9842	Comfort	47400.00
0005434551768	9842	Comfort	47400.00
0005434551857	9842	Comfort	47400.00
0005434727062	9842	Comfort	47400.00
0005434727027	9842	Comfort	47400.00
0005434552042	9842	Comfort	47400.00
0005434727092	9842	Comfort	47400.00
0005434551754	9842	Comfort	47400.00
0005433766721	9842	Comfort	47400.00
0005434726579	9842	Comfort	47400.00
0005435142678	9842	Comfort	47400.00
0005433126943	9842	Comfort	47400.00
0005434551945	9842	Comfort	47400.00
0005434551731	9842	Comfort	47400.00
0005433181633	9842	Economy	27900.00
0005433235535	9842	Economy	27900.00
0005434551633	9842	Economy	27900.00
0005434727133	9842	Economy	27900.00
0005433181641	9842	Economy	27900.00
0005434727316	9842	Economy	27900.00
0005433181644	9842	Economy	27900.00
0005434551820	9842	Economy	27900.00
0005434552072	9842	Economy	27900.00
0005432199396	9842	Economy	27900.00
0005434551683	9842	Economy	27900.00
0005434551735	9842	Economy	27900.00
0005434551749	9842	Economy	27900.00
0005433290001	9842	Economy	27900.00
0005434551864	9842	Economy	27900.00
0005434551903	9842	Economy	27900.00
0005433235557	9842	Economy	27900.00
0005434727088	9842	Economy	27900.00
0005434551717	9842	Economy	27900.00
0005434551829	9842	Economy	27900.00
0005435142681	9842	Economy	27900.00
0005433235562	9842	Economy	27900.00
0005434727271	9842	Economy	27900.00
0005433235569	9842	Economy	27900.00
0005432199400	9842	Economy	27900.00
0005433181645	9842	Economy	27900.00
0005434551877	9842	Economy	27900.00
0005434727344	9842	Economy	27900.00
0005434727346	9842	Economy	27900.00
0005433235531	9842	Economy	27900.00
0005434551962	9842	Economy	27900.00
0005433235585	9842	Economy	27900.00
0005433181636	9842	Economy	27900.00
0005434726469	9842	Economy	27900.00
0005434032126	9842	Economy	27900.00
0005434032125	9842	Economy	27900.00
0005433235583	9842	Economy	27900.00
0005434551815	9842	Economy	27900.00
0005433113585	9842	Economy	27900.00
0005434726928	9842	Economy	27900.00
0005434726690	9842	Economy	27900.00
0005434551723	9842	Economy	27900.00
0005433235554	9842	Economy	27900.00
0005434552217	9842	Economy	27900.00
0005433181642	9842	Economy	27900.00
0005433235576	9842	Economy	27900.00
0005434551796	9842	Economy	27900.00
0005434551991	9842	Economy	27900.00
0005434727450	9842	Economy	27900.00
0005434727069	9842	Economy	27900.00
0005434727671	9842	Economy	30700.00
0005434735745	9842	Economy	30700.00
0005433235572	9842	Economy	27900.00
0005434726912	9842	Economy	27900.00
0005434726793	9842	Economy	30700.00
0005434727184	9842	Economy	27900.00
0005434726646	9842	Economy	30700.00
0005432199398	9842	Economy	30700.00
0005434735758	9842	Economy	27900.00
0005433235574	9842	Economy	27900.00
0005434727434	9842	Economy	27900.00
0005433235544	9842	Economy	27900.00
0005433235582	9842	Economy	27900.00
0005434727318	9842	Economy	27900.00
0005433113582	9842	Economy	27900.00
0005434735754	9842	Economy	27900.00
0005434551923	9842	Economy	27900.00
0005434727343	9842	Economy	27900.00
0005434726965	9842	Economy	27900.00
0005434551806	9842	Economy	27900.00
0005434551918	9842	Economy	27900.00
0005434726889	9842	Economy	27900.00
0005433235548	9842	Economy	27900.00
0005433235575	9842	Economy	27900.00
0005434726913	9842	Economy	27900.00
0005433235581	9842	Economy	27900.00
0005433126942	9842	Economy	27900.00
0005434551917	9842	Economy	27900.00
0005433181637	9842	Economy	27900.00
0005434551716	9842	Economy	27900.00
0005433235588	9842	Economy	27900.00
0005434551632	9842	Economy	27900.00
0005433766723	9842	Economy	27900.00
0005434726929	9842	Economy	27900.00
0005435142752	9842	Economy	27900.00
0005433235584	9842	Economy	27900.00
0005434302506	9842	Economy	27900.00
0005434551712	9842	Economy	27900.00
0005434726926	9842	Economy	27900.00
0005434726858	9842	Economy	27900.00
0005433235541	9842	Economy	27900.00
0005435142644	9842	Economy	27900.00
0005434551858	9842	Economy	27900.00
0005434727263	9842	Economy	27900.00
0005433181635	9842	Economy	27900.00
0005433181631	9842	Economy	27900.00
0005433181654	9842	Economy	27900.00
0005433181648	9842	Economy	27900.00
0005434726736	9842	Economy	27900.00
0005434551926	9842	Economy	27900.00
0005434551471	9842	Economy	27900.00
0005434727315	9842	Economy	27900.00
0005434727764	9842	Economy	27900.00
0005433129372	9842	Economy	27900.00
0005433766720	9842	Economy	27900.00
0005434551828	9842	Economy	27900.00
0005434551774	9842	Economy	27900.00
0005433235553	9842	Economy	27900.00
0005434551818	9842	Economy	27900.00
0005433235578	9842	Economy	27900.00
0005434551859	9842	Economy	27900.00
0005434551627	9842	Economy	27900.00
0005434551968	9842	Economy	27900.00
0005434727075	9842	Economy	27900.00
0005434302490	9842	Economy	27900.00
0005434552008	9842	Economy	27900.00
0005434552001	9842	Economy	27900.00
0005434551714	9842	Economy	27900.00
0005434551960	9842	Economy	27900.00
0005433235530	9842	Economy	27900.00
0005434551710	9842	Economy	27900.00
0005433181634	9842	Economy	27900.00
0005434735756	9842	Economy	27900.00
0005434551609	9842	Economy	27900.00
0005434551634	9842	Economy	27900.00
0005433235568	9842	Economy	27900.00
0005433290003	9842	Economy	27900.00
0005434727145	9842	Economy	27900.00
0005434727444	9842	Economy	27900.00
0005434726887	9842	Economy	27900.00
0005434735747	9842	Economy	27900.00
0005434551860	9842	Economy	27900.00
0005434552216	9842	Economy	27900.00
0005434735759	9842	Economy	27900.00
0005434726795	9842	Economy	27900.00
0005434735766	9842	Economy	27900.00
0005433235550	9842	Economy	27900.00
0005433235543	9842	Economy	27900.00
0005433113583	9842	Economy	27900.00
0005434726835	9842	Economy	27900.00
0005434735777	9842	Economy	27900.00
0005434735757	9842	Economy	27900.00
0005435142751	9842	Economy	27900.00
0005434726581	9842	Economy	27900.00
0005434727433	9842	Economy	27900.00
0005435142789	9842	Economy	27900.00
0005432199401	9842	Economy	27900.00
0005434731227	9842	Economy	27900.00
0005433235556	9842	Economy	27900.00
0005434726468	9842	Economy	27900.00
0005434727462	9842	Economy	27900.00
0005434727381	9842	Economy	27900.00
0005433181646	9842	Economy	27900.00
0005434726533	9842	Economy	27900.00
0005433126945	9842	Economy	27900.00
0005434726990	9842	Economy	27900.00
0005434551879	9842	Economy	30700.00
0005434727264	9842	Economy	30700.00
0005434551672	9842	Economy	30700.00
0005434302502	9842	Economy	30700.00
0005433235536	9842	Economy	27900.00
0005433235561	9842	Economy	30700.00
0005433235555	9842	Economy	27900.00
0005434731238	9842	Economy	27900.00
0005433181651	9842	Economy	27900.00
0005433181639	9842	Economy	27900.00
0005434726827	9842	Economy	27900.00
0005433235577	9842	Economy	27900.00
0005433113584	9842	Economy	27900.00
0005434726689	9842	Economy	27900.00
0005434726627	9842	Economy	27900.00
0005433235551	9842	Economy	27900.00
0005433290004	9842	Economy	27900.00
0005434551807	9842	Economy	27900.00
0005434726888	9842	Economy	27900.00
0005434727408	9842	Economy	27900.00
0005433235539	9842	Economy	27900.00
0005434551682	9842	Economy	27900.00
0005434726688	9842	Economy	27900.00
0005433235545	9842	Economy	27900.00
0005434552030	9842	Economy	27900.00
0005434727035	9842	Economy	27900.00
0005433235565	9842	Economy	27900.00
0005434727250	9842	Economy	27900.00
0005434727018	9842	Economy	27900.00
0005434551865	9842	Economy	27900.00
0005434551842	9842	Economy	27900.00
0005433181640	9842	Economy	27900.00
0005434551963	9842	Economy	27900.00
0005433235580	9842	Economy	27900.00
0005433129374	9842	Economy	27900.00
0005433235560	9842	Economy	27900.00
0005434726930	9842	Economy	27900.00
0005433235591	9842	Economy	27900.00
0005435142755	9842	Economy	27900.00
0005433290002	9842	Economy	27900.00
0005434551708	9842	Economy	27900.00
0005434551711	9842	Economy	27900.00
0005434551840	9842	Economy	27900.00
0005433235540	9842	Economy	27900.00
0005433235558	9842	Economy	27900.00
0005433235586	9842	Economy	27900.00
0005434552218	9842	Economy	27900.00
0005434552113	9842	Economy	27900.00
0005434551819	9842	Economy	27900.00
0005434302512	9842	Economy	27900.00
0005434727252	9842	Economy	27900.00
0005433235533	9842	Economy	27900.00
0005433235537	9842	Economy	27900.00
0005434735765	9842	Economy	27900.00
0005433290005	9842	Economy	27900.00
0005434727251	9842	Economy	27900.00
0005434735752	9842	Economy	27900.00
0005433235573	9842	Economy	27900.00
0005434726964	9842	Economy	27900.00
0005434727126	9842	Economy	27900.00
0005433181653	9842	Economy	27900.00
0005434727200	9842	Economy	27900.00
0005432199399	9842	Economy	27900.00
0005434735746	9842	Economy	27900.00
0005433235546	9842	Economy	27900.00
0005433235564	9842	Economy	27900.00
0005434302507	9842	Economy	27900.00
0005433129376	9842	Economy	27900.00
0005434727317	9842	Economy	27900.00
0005434727091	9842	Economy	27900.00
0005434727185	9842	Economy	27900.00
0005433126941	9842	Economy	27900.00
0005433181632	9842	Economy	27900.00
0005434726794	9842	Economy	27900.00
0005434726992	9842	Economy	27900.00
0005433235587	9842	Economy	27900.00
0005433235534	9842	Economy	27900.00
0005434551472	9842	Economy	27900.00
0005434727023	9842	Economy	27900.00
0005433235538	9842	Economy	27900.00
0005434551876	9842	Economy	27900.00
0005434726993	9842	Economy	27900.00
0005434727199	9842	Economy	27900.00
0005433766722	9842	Economy	27900.00
0005434551830	9842	Economy	27900.00
0005433235589	9842	Economy	27900.00
0005434727187	9842	Economy	27900.00
0005434726748	9842	Economy	27900.00
0005433289999	9842	Economy	27900.00
0005434551608	9842	Economy	27900.00
0005434727074	9842	Economy	27900.00
0005434551732	9842	Economy	27900.00
0005434302513	9842	Economy	27900.00
0005433235566	9842	Economy	27900.00
0005434727063	9842	Economy	27900.00
0005433235567	9842	Economy	27900.00
0005433181649	9842	Economy	27900.00
0005433181647	9842	Economy	27900.00
0005434727144	9842	Economy	27900.00
0005434551946	9842	Economy	27900.00
0005434727360	9842	Economy	27900.00
0005432530746	7764	Business	42100.00
0005435214202	7764	Business	42100.00
0005432069960	7764	Business	42100.00
0005434069092	7764	Business	42100.00
0005432069961	7764	Business	42100.00
0005432530791	7764	Business	42100.00
0005432069973	7764	Business	42100.00
0005435214489	7764	Business	42100.00
0005432530833	7764	Business	42100.00
0005432530807	7764	Business	42100.00
0005432150367	7764	Business	42100.00
0005435214351	7764	Business	42100.00
0005434069116	7764	Business	42100.00
0005432530840	7764	Business	42100.00
0005435214448	7764	Business	42100.00
0005434069119	7764	Business	42100.00
0005435214547	7764	Business	42100.00
0005434069065	7764	Business	42100.00
0005435214428	7764	Business	42100.00
0005432530841	7764	Comfort	23900.00
0005432537104	7764	Business	42100.00
0005432530843	7764	Comfort	23900.00
0005434069071	7764	Comfort	23900.00
0005432069965	7764	Comfort	23900.00
0005432530825	7764	Comfort	23900.00
0005435214047	7764	Comfort	23900.00
0005435214165	7764	Comfort	23900.00
0005432530805	7764	Comfort	23900.00
0005432530802	7764	Comfort	23900.00
0005432150366	7764	Comfort	23900.00
0005434069105	7764	Comfort	23900.00
0005435725682	7764	Comfort	23900.00
0005432530817	7764	Comfort	23900.00
0005432150365	7764	Comfort	23900.00
0005432530812	7764	Comfort	23900.00
0005432530759	7764	Comfort	23900.00
0005434069123	7764	Comfort	23900.00
0005434069089	7764	Comfort	23900.00
0005432530762	7764	Comfort	23900.00
0005432069971	7764	Comfort	23900.00
0005432530839	7764	Comfort	23900.00
0005432530845	7764	Comfort	23900.00
0005434069103	7764	Comfort	23900.00
0005432530777	7764	Comfort	23900.00
0005432150363	7764	Comfort	23900.00
0005432530798	7764	Comfort	23900.00
0005432530737	7764	Comfort	23900.00
0005432530773	7764	Comfort	23900.00
0005435214355	7764	Comfort	23900.00
0005432530768	7764	Comfort	23900.00
0005432530822	7764	Comfort	23900.00
0005434069107	7764	Comfort	23900.00
0005434069088	7764	Comfort	23900.00
0005432530857	7764	Comfort	23900.00
0005435725673	7764	Comfort	23900.00
0005432530792	7764	Comfort	23900.00
0005435214533	7764	Comfort	23900.00
0005435214640	7764	Comfort	23900.00
0005432530793	7764	Comfort	23900.00
0005434069076	7764	Comfort	23900.00
0005432530856	7764	Comfort	23900.00
0005432535941	7764	Comfort	23900.00
0005435214534	7764	Economy	14000.00
0005435214101	7764	Economy	14000.00
0005435214542	7764	Economy	14000.00
0005435214447	7764	Economy	14000.00
0005434069097	7764	Economy	14000.00
0005432530795	7764	Economy	14000.00
0005432530740	7764	Economy	14000.00
0005432530732	7764	Economy	14000.00
0005434069122	7764	Economy	14000.00
0005435214204	7764	Economy	14000.00
0005434069127	7764	Economy	14000.00
0005432530827	7764	Economy	14000.00
0005432150364	7764	Economy	14000.00
0005435214392	7764	Economy	14000.00
0005435214178	7764	Economy	14000.00
0005434069058	7764	Economy	14000.00
0005432150360	7764	Economy	14000.00
0005432530736	7764	Economy	14000.00
0005432530797	7764	Economy	14000.00
0005432530754	7764	Economy	14000.00
0005432530765	7764	Economy	14000.00
0005435214394	7764	Economy	14000.00
0005435725659	7764	Economy	14000.00
0005434069073	7764	Economy	14000.00
0005432069974	7764	Economy	14000.00
0005432530806	7764	Economy	14000.00
0005434069125	7764	Economy	14000.00
0005434069099	7764	Economy	14000.00
0005435214525	7764	Economy	14000.00
0005432533353	7764	Economy	14000.00
0005432530852	7764	Economy	14000.00
0005434069079	7764	Economy	14000.00
0005435214434	7764	Economy	14000.00
0005435214474	7764	Economy	14000.00
0005432530851	7764	Economy	14000.00
0005432530776	7764	Economy	14000.00
0005434069061	7764	Economy	14000.00
0005435214702	7764	Economy	14000.00
0005432530810	7764	Economy	14000.00
0005435214475	7764	Economy	14000.00
0005432530742	7764	Economy	14000.00
0005432530750	7764	Economy	14000.00
0005432530855	7764	Economy	14000.00
0005432537103	7764	Economy	14000.00
0005434069080	7764	Economy	14000.00
0005432530738	7764	Economy	14000.00
0005435725655	7764	Economy	14000.00
0005434069112	7764	Economy	14000.00
0005432530733	7764	Economy	14000.00
0005435214311	7764	Economy	14000.00
0005435214574	7764	Economy	14000.00
0005432530780	7764	Economy	14000.00
0005434069126	7764	Economy	14000.00
0005432530863	7764	Economy	14000.00
0005435214545	7764	Economy	14000.00
0005432530846	7764	Economy	15400.00
0005432530859	7764	Economy	15400.00
0005435214163	7764	Economy	14000.00
0005435214353	7764	Economy	14000.00
0005435214220	7764	Economy	14000.00
0005432530835	7764	Economy	15400.00
0005432069964	7764	Economy	14000.00
0005434069087	7764	Economy	15400.00
0005434069120	7764	Economy	15400.00
0005435214216	7764	Economy	14000.00
0005432530799	7764	Economy	14000.00
0005435214414	7764	Economy	14000.00
0005435214526	7764	Economy	14000.00
0005435214273	7764	Economy	14000.00
0005432530781	7764	Economy	14000.00
0005434069109	7764	Economy	14000.00
0005432069972	7764	Economy	14000.00
0005432535942	7764	Economy	14000.00
0005434069106	7764	Economy	14000.00
0005432530745	7764	Economy	14000.00
0005432530747	7764	Economy	14000.00
0005435214436	7764	Economy	14000.00
0005434069081	7764	Economy	14000.00
0005432530808	7764	Economy	14000.00
0005434069066	7764	Economy	14000.00
0005432530847	7764	Economy	14000.00
0005434069062	7764	Economy	14000.00
0005432530767	7764	Economy	14000.00
0005434069111	7764	Economy	14000.00
0005432530772	7764	Economy	14000.00
0005435214352	7764	Economy	14000.00
0005432530794	7764	Economy	14000.00
0005432530770	7764	Economy	14000.00
0005434069093	7764	Economy	14000.00
0005435214205	7764	Economy	14000.00
0005432530818	7764	Economy	14000.00
0005432530842	7764	Economy	14000.00
0005432530838	7764	Economy	14000.00
0005432530757	7764	Economy	14000.00
0005432530796	7764	Economy	14000.00
0005432530779	7764	Economy	14000.00
0005434069070	7764	Economy	14000.00
0005435214378	7764	Economy	14000.00
0005432530756	7764	Economy	14000.00
0005432150362	7764	Economy	14000.00
0005432530766	7764	Economy	14000.00
0005432530784	7764	Economy	14000.00
0005432530774	7764	Economy	14000.00
0005432530831	7764	Economy	14000.00
0005434069059	7764	Economy	14000.00
0005432530801	7764	Economy	14000.00
0005435214662	7764	Economy	14000.00
0005432535936	7764	Economy	14000.00
0005434069072	7764	Economy	14000.00
0005432530858	7764	Economy	14000.00
0005432533355	7764	Economy	14000.00
0005435214164	7764	Economy	14000.00
0005434069108	7764	Economy	14000.00
0005434069110	7764	Economy	14000.00
0005432530734	7764	Economy	14000.00
0005432530790	7764	Economy	14000.00
0005435214642	7764	Economy	14000.00
0005434069114	7764	Economy	14000.00
0005434069104	7764	Economy	14000.00
0005432530752	7764	Economy	14000.00
0005435214379	7764	Economy	14000.00
0005435214295	7764	Economy	14000.00
0005432530787	7764	Economy	14000.00
0005432530739	7764	Economy	14000.00
0005435214203	7764	Economy	14000.00
0005434069086	7764	Economy	14000.00
0005435214389	7764	Economy	14000.00
0005432530819	7764	Economy	14000.00
0005432535938	7764	Economy	14000.00
0005434069084	7764	Economy	14000.00
0005432530829	7764	Economy	14000.00
0005432530836	7764	Economy	14000.00
0005432069969	7764	Economy	14000.00
0005432069963	7764	Economy	14000.00
0005432530778	7764	Economy	14000.00
0005434069117	7764	Economy	14000.00
0005432530786	7764	Economy	14000.00
0005432530832	7764	Economy	14000.00
0005432530769	7764	Economy	14000.00
0005434069096	7764	Economy	14000.00
0005432530744	7764	Economy	14000.00
0005434069113	7764	Economy	14000.00
0005434069085	7764	Economy	14000.00
0005434069077	7764	Economy	14000.00
0005432069968	7764	Economy	14000.00
0005434069060	7764	Economy	14000.00
0005432530826	7764	Economy	14000.00
0005435725674	7764	Economy	14000.00
0005432530853	7764	Economy	14000.00
0005432533354	7764	Economy	14000.00
0005432530758	7764	Economy	14000.00
0005435725656	7764	Economy	14000.00
0005434069098	7764	Economy	14000.00
0005432530753	7764	Economy	14000.00
0005432530816	7764	Economy	14000.00
0005435214544	7764	Economy	14000.00
0005435214350	7764	Economy	14000.00
0005432535937	7764	Economy	14000.00
0005432069970	7764	Economy	14000.00
0005432530815	7764	Economy	14000.00
0005432530814	7764	Economy	14000.00
0005432530755	7764	Economy	15400.00
0005435214462	7764	Economy	15400.00
0005432530763	7764	Economy	15400.00
0005432530854	7764	Economy	15400.00
0005434069091	7764	Economy	15400.00
0005432530775	7764	Economy	14000.00
0005434069067	7764	Economy	14000.00
0005434069124	7764	Economy	14000.00
0005432530782	7764	Economy	14000.00
0005435214580	7764	Economy	14000.00
0005434069115	7764	Economy	14000.00
0005432069967	7764	Economy	14000.00
0005435214272	7764	Economy	14000.00
0005432530760	7764	Economy	14000.00
0005434069101	7764	Economy	14000.00
0005432530823	7764	Economy	14000.00
0005434069102	7764	Economy	14000.00
0005434069118	7764	Economy	14000.00
0005432530751	7764	Economy	14000.00
0005434069064	7764	Economy	14000.00
0005432530771	7764	Economy	14000.00
0005432530788	7764	Economy	14000.00
0005434069078	7764	Economy	14000.00
0005432530849	7764	Economy	14000.00
0005435214538	7764	Economy	14000.00
0005432530864	7764	Economy	14000.00
0005432530803	7764	Economy	14000.00
0005434069121	7764	Economy	14000.00
0005432530860	7764	Economy	14000.00
0005432429002	7764	Economy	14000.00
0005432530862	7764	Economy	14000.00
0005432530749	7764	Economy	14000.00
0005435214512	7764	Economy	14000.00
0005432530761	7764	Economy	14000.00
0005433656729	7764	Economy	14000.00
0005432530764	7764	Economy	14000.00
0005432530850	7764	Economy	14000.00
0005434069075	7764	Economy	14000.00
0005432069962	7764	Economy	14000.00
0005435214511	7764	Economy	14000.00
0005432530741	7764	Economy	14000.00
0005435214294	7764	Economy	14000.00
0005432530837	7764	Economy	14000.00
0005434069095	7764	Economy	14000.00
0005432530848	7764	Economy	14000.00
0005434069090	7764	Economy	14000.00
0005435214543	7764	Economy	14000.00
0005435213990	7764	Economy	14000.00
0005435214356	7764	Economy	14000.00
0005432530804	7764	Economy	14000.00
0005432530844	7764	Economy	14000.00
0005434069100	7764	Economy	14000.00
0005432530821	7764	Economy	14000.00
0005432530731	7764	Economy	14000.00
0005432530748	7764	Economy	14000.00
0005432069966	7764	Economy	14000.00
0005434069068	7764	Economy	14000.00
0005434069063	7764	Economy	14000.00
0005434069082	7764	Economy	14000.00
0005435214372	7764	Economy	14000.00
0005434069057	7764	Economy	14000.00
0005432530820	7764	Economy	14000.00
0005432530809	7764	Economy	14000.00
0005433656720	7764	Economy	14000.00
0005435214488	7764	Economy	14000.00
0005435214217	7764	Economy	14000.00
0005432530735	7764	Economy	14000.00
0005432535940	7764	Economy	14000.00
0005432530743	7764	Economy	14000.00
0005435214433	7764	Economy	14000.00
0005432530811	7764	Economy	14000.00
0005432530813	7764	Economy	14000.00
0005432530783	7764	Economy	14000.00
0005432530828	7764	Economy	14000.00
0005432150361	7764	Economy	14000.00
0005435214395	7764	Economy	14000.00
0005432530789	7764	Economy	14000.00
0005432533352	7764	Economy	14000.00
0005432530785	7764	Economy	14000.00
0005433656721	7764	Economy	14000.00
0005434069074	7764	Economy	14000.00
0005432530830	7764	Economy	14000.00
0005434069069	7764	Economy	14000.00
0005432530824	7764	Economy	14000.00
0005435214189	7764	Economy	14000.00
0005432530834	7764	Economy	14000.00
0005432530861	7764	Economy	14000.00
0005435214546	7764	Economy	14000.00
0005432429003	7764	Economy	14000.00
0005432530800	7764	Economy	14000.00
0005434069094	7764	Economy	14000.00
0005432535939	7764	Economy	14000.00
0005434069083	7764	Economy	14000.00
0005434245474	5324	Business	43100.00
0005435616011	5324	Business	43100.00
0005434344985	5324	Business	43100.00
0005435319727	5324	Business	43100.00
0005434344972	5324	Business	43100.00
0005435425601	5324	Business	43100.00
0005435616048	5324	Business	43100.00
0005435616034	5324	Business	43100.00
0005435616029	5324	Business	43100.00
0005435425813	5324	Business	43100.00
0005434245286	5324	Business	43100.00
0005434245263	5324	Business	43100.00
0005435616077	5324	Business	43100.00
0005435425736	5324	Business	43100.00
0005434245310	5324	Business	43100.00
0005435616020	5324	Business	43100.00
0005432363460	5324	Business	43100.00
0005435425807	5324	Business	43100.00
0005435425780	5324	Business	43100.00
0005435616033	5324	Business	43100.00
0005434245287	5324	Business	43100.00
0005435616050	5324	Business	43100.00
0005434573660	5324	Business	43100.00
0005434344974	5324	Business	43100.00
0005434656582	5324	Business	43100.00
0005435616081	5324	Business	43100.00
0005434344987	5324	Business	43100.00
0005435616036	5324	Business	43100.00
0005435616106	5324	Comfort	24400.00
0005434573656	5324	Comfort	24400.00
0005432133534	5324	Comfort	24400.00
0005434344996	5324	Comfort	24400.00
0005435425779	5324	Comfort	24400.00
0005435616089	5324	Comfort	24400.00
0005432841041	5324	Comfort	24400.00
0005435617180	5324	Comfort	24400.00
0005432133535	5324	Comfort	24400.00
0005434245448	5324	Comfort	24400.00
0005435616087	5324	Comfort	24400.00
0005435097422	5324	Comfort	24400.00
0005435616096	5324	Comfort	24400.00
0005435616010	5324	Comfort	24400.00
0005434344979	5324	Comfort	24400.00
0005435426079	5324	Comfort	24400.00
0005433719176	5324	Comfort	24400.00
0005435616032	5324	Comfort	24400.00
0005435616076	5324	Comfort	24400.00
0005435616055	5324	Comfort	24400.00
0005435616021	5324	Comfort	24400.00
0005435616051	5324	Comfort	24400.00
0005435616104	5324	Comfort	24400.00
0005435425781	5324	Comfort	24400.00
0005435616142	5324	Comfort	24400.00
0005435617184	5324	Comfort	24400.00
0005435616111	5324	Comfort	24400.00
0005434573657	5324	Comfort	24400.00
0005435555414	5324	Comfort	24400.00
0005435616057	5324	Comfort	24400.00
0005435616112	5324	Comfort	24400.00
0005435616107	5324	Comfort	24400.00
0005434573654	5324	Comfort	24400.00
0005434344992	5324	Comfort	24400.00
0005435616127	5324	Comfort	24400.00
0005435616016	5324	Comfort	24400.00
0005435302263	5324	Comfort	24400.00
0005435616101	5324	Comfort	24400.00
0005435425758	5324	Comfort	24400.00
0005435425795	5324	Comfort	24400.00
0005435616116	5324	Comfort	24400.00
0005435616063	5324	Comfort	24400.00
0005434344978	5324	Comfort	24400.00
0005434573659	5324	Economy	14400.00
0005434245373	5324	Economy	14400.00
0005435425893	5324	Economy	14400.00
0005435425848	5324	Economy	14400.00
0005435425764	5324	Economy	14400.00
0005435616022	5324	Economy	14400.00
0005435616121	5324	Economy	14400.00
0005435425623	5324	Economy	14400.00
0005435425611	5324	Economy	14400.00
0005435616044	5324	Economy	14400.00
0005435616071	5324	Economy	14400.00
0005435616118	5324	Economy	14400.00
0005435616084	5324	Economy	14400.00
0005432133538	5324	Economy	14400.00
0005435617182	5324	Economy	14400.00
0005434245483	5324	Economy	14400.00
0005435616094	5324	Economy	14400.00
0005435097423	5324	Economy	14400.00
0005435425625	5324	Economy	14400.00
0005434573661	5324	Economy	14400.00
0005435616088	5324	Economy	14400.00
0005435425642	5324	Economy	14400.00
0005435616078	5324	Economy	14400.00
0005435616109	5324	Economy	14400.00
0005435491487	5324	Economy	14400.00
0005432363461	5324	Economy	14400.00
0005435319707	5324	Economy	14400.00
0005435425721	5324	Economy	14400.00
0005435616015	5324	Economy	14400.00
0005434245416	5324	Economy	14400.00
0005435616061	5324	Economy	14400.00
0005435425840	5324	Economy	14400.00
0005435616100	5324	Economy	14400.00
0005435097416	5324	Economy	14400.00
0005435616046	5324	Economy	14400.00
0005435617239	5324	Economy	14400.00
0005435616125	5324	Economy	14400.00
0005435616113	5324	Economy	14400.00
0005434573658	5324	Economy	14400.00
0005435616056	5324	Economy	14400.00
0005435616052	5324	Economy	14400.00
0005432133530	5324	Economy	14400.00
0005435616030	5324	Economy	14400.00
0005435616041	5324	Economy	14400.00
0005434344990	5324	Economy	14400.00
0005435616066	5324	Economy	14400.00
0005432363458	5324	Economy	14400.00
0005435425560	5324	Economy	14400.00
0005435616095	5324	Economy	14400.00
0005435490306	5324	Economy	14400.00
0005434344971	5324	Economy	14400.00
0005434344976	5324	Economy	14400.00
0005435616092	5324	Economy	14400.00
0005435616120	5324	Economy	14400.00
0005435097420	5324	Economy	14400.00
0005432047629	5324	Economy	14400.00
0005435616108	5324	Economy	14400.00
0005435616047	5324	Economy	14400.00
0005435616085	5324	Economy	14400.00
0005435616042	5324	Economy	14400.00
0005435616064	5324	Economy	14400.00
0005435426028	5324	Economy	14400.00
0005434345002	5324	Economy	14400.00
0005435616136	5324	Economy	14400.00
0005435616065	5324	Economy	14400.00
0005434245241	5324	Economy	14400.00
0005434344998	5324	Economy	15800.00
0005435616074	5324	Economy	15800.00
0005435425634	5324	Economy	14400.00
0005435616075	5324	Economy	14400.00
0005435425786	5324	Economy	15800.00
0005435490308	5324	Economy	14400.00
0005434245475	5324	Economy	14400.00
0005435616035	5324	Economy	15800.00
0005434245445	5324	Economy	14400.00
0005435616043	5324	Economy	14400.00
0005432133532	5324	Economy	14400.00
0005435616045	5324	Economy	14400.00
0005435097421	5324	Economy	14400.00
0005435616135	5324	Economy	14400.00
0005435616026	5324	Economy	14400.00
0005435616014	5324	Economy	14400.00
0005435616147	5324	Economy	14400.00
0005435616098	5324	Economy	14400.00
0005434245365	5324	Economy	14400.00
0005435616017	5324	Economy	14400.00
0005434245364	5324	Economy	14400.00
0005435426024	5324	Economy	14400.00
0005434344989	5324	Economy	14400.00
0005435302279	5324	Economy	14400.00
0005434245337	5324	Economy	14400.00
0005435097417	5324	Economy	14400.00
0005435380348	5324	Economy	14400.00
0005435616134	5324	Economy	14400.00
0005435425914	5324	Economy	14400.00
0005435616083	5324	Economy	14400.00
0005435425559	5324	Economy	14400.00
0005435616024	5324	Economy	14400.00
0005435616062	5324	Economy	14400.00
0005434344995	5324	Economy	14400.00
0005434573650	5324	Economy	14400.00
0005432133537	5324	Economy	14400.00
0005435426096	5324	Economy	14400.00
0005435616082	5324	Economy	14400.00
0005435616090	5324	Economy	14400.00
0005432133542	5324	Economy	14400.00
0005434245415	5324	Economy	14400.00
0005435616058	5324	Economy	14400.00
0005434245417	5324	Economy	14400.00
0005434345004	5324	Economy	14400.00
0005434344973	5324	Economy	14400.00
0005434245484	5324	Economy	14400.00
0005435425845	5324	Economy	14400.00
0005435616012	5324	Economy	14400.00
0005434344981	5324	Economy	14400.00
0005434344980	5324	Economy	14400.00
0005434344999	5324	Economy	14400.00
0005435616053	5324	Economy	14400.00
0005435490307	5324	Economy	14400.00
0005435616117	5324	Economy	14400.00
0005435616129	5324	Economy	14400.00
0005435616031	5324	Economy	14400.00
0005435616124	5324	Economy	14400.00
0005435616145	5324	Economy	14400.00
0005432133543	5324	Economy	14400.00
0005435097415	5324	Economy	14400.00
0005434245312	5324	Economy	14400.00
0005435491486	5324	Economy	14400.00
0005435616054	5324	Economy	14400.00
0005434245390	5324	Economy	14400.00
0005435425841	5324	Economy	14400.00
0005434245307	5324	Economy	14400.00
0005434344993	5324	Economy	14400.00
0005435425918	5324	Economy	14400.00
0005435616039	5324	Economy	14400.00
0005435616122	5324	Economy	14400.00
0005435302262	5324	Economy	14400.00
0005435616119	5324	Economy	14400.00
0005434344984	5324	Economy	14400.00
0005435425839	5324	Economy	14400.00
0005434345003	5324	Economy	14400.00
0005435616128	5324	Economy	14400.00
0005435616102	5324	Economy	14400.00
0005435425907	5324	Economy	14400.00
0005435616133	5324	Economy	14400.00
0005435380349	5324	Economy	14400.00
0005432047632	5324	Economy	14400.00
0005435616086	5324	Economy	14400.00
0005432133539	5324	Economy	14400.00
0005432363463	5324	Economy	14400.00
0005435616097	5324	Economy	14400.00
0005435616072	5324	Economy	14400.00
0005435616143	5324	Economy	14400.00
0005434344988	5324	Economy	14400.00
0005434245277	5324	Economy	14400.00
0005435616141	5324	Economy	14400.00
0005435617183	5324	Economy	14400.00
0005435616144	5324	Economy	14400.00
0005435616110	5324	Economy	14400.00
0005435616148	5324	Economy	14400.00
0005434344983	5324	Economy	14400.00
0005434345001	5324	Economy	14400.00
0005434245336	5324	Economy	14400.00
0005435616038	5324	Economy	14400.00
0005435616132	5324	Economy	14400.00
0005435617181	5324	Economy	14400.00
0005432133536	5324	Economy	14400.00
0005435616068	5324	Economy	14400.00
0005434245427	5324	Economy	14400.00
0005435616123	5324	Economy	14400.00
0005435490305	5324	Economy	14400.00
0005434344968	5324	Economy	14400.00
0005435425600	5324	Economy	14400.00
0005435425712	5324	Economy	14400.00
0005435425788	5324	Economy	15800.00
0005435616091	5324	Economy	15800.00
0005435425696	5324	Economy	15800.00
0005435616099	5324	Economy	15800.00
0005435425966	5324	Economy	15800.00
0005435616073	5324	Economy	15800.00
0005435616025	5324	Economy	14400.00
0005435319728	5324	Economy	14400.00
0005432047630	5324	Economy	14400.00
0005435319698	5324	Economy	14400.00
0005434245376	5324	Economy	14400.00
0005435616013	5324	Economy	14400.00
0005434573662	5324	Economy	14400.00
0005435425926	5324	Economy	14400.00
0005435425847	5324	Economy	14400.00
0005435616040	5324	Economy	14400.00
0005435425574	5324	Economy	14400.00
0005435616093	5324	Economy	14400.00
0005434245334	5324	Economy	14400.00
0005435425964	5324	Economy	14400.00
0005435616131	5324	Economy	14400.00
0005434656581	5324	Economy	14400.00
0005435616018	5324	Economy	14400.00
0005435302261	5324	Economy	14400.00
0005435097424	5324	Economy	14400.00
0005432047631	5324	Economy	14400.00
0005435425723	5324	Economy	14400.00
0005435302264	5324	Economy	14400.00
0005434245240	5324	Economy	14400.00
0005435616137	5324	Economy	14400.00
0005434245239	5324	Economy	14400.00
0005435425575	5324	Economy	14400.00
0005435380365	5324	Economy	14400.00
0005435555413	5324	Economy	14400.00
0005435426009	5324	Economy	14400.00
0005435302227	5324	Economy	14400.00
0005435426040	5324	Economy	14400.00
0005434345000	5324	Economy	14400.00
0005435425501	5324	Economy	14400.00
0005434344982	5324	Economy	14400.00
0005434245311	5324	Economy	14400.00
0005435616139	5324	Economy	14400.00
0005434573655	5324	Economy	14400.00
0005435616114	5324	Economy	14400.00
0005435616028	5324	Economy	14400.00
0005435616079	5324	Economy	14400.00
0005434245372	5324	Economy	14400.00
0005435616019	5324	Economy	14400.00
0005435425846	5324	Economy	14400.00
0005435616146	5324	Economy	14400.00
0005435380347	5324	Economy	14400.00
0005435097419	5324	Economy	14400.00
0005432133540	5324	Economy	14400.00
0005434344967	5324	Economy	14400.00
0005434344986	5324	Economy	14400.00
0005434344977	5324	Economy	14400.00
0005435097425	5324	Economy	14400.00
0005434245386	5324	Economy	14400.00
0005435425582	5324	Economy	14400.00
0005435302228	5324	Economy	14400.00
0005435425806	5324	Economy	14400.00
0005433719173	5324	Economy	14400.00
0005434344991	5324	Economy	14400.00
0005435616037	5324	Economy	14400.00
0005434573653	5324	Economy	14400.00
0005435616023	5324	Economy	14400.00
0005435616115	5324	Economy	14400.00
0005433719175	5324	Economy	14400.00
0005434344997	5324	Economy	14400.00
0005435616067	5324	Economy	14400.00
0005435425720	5324	Economy	14400.00
0005435425555	5324	Economy	14400.00
0005435616049	5324	Economy	14400.00
0005434344970	5324	Economy	14400.00
0005432133533	5324	Economy	14400.00
0005432133541	5324	Economy	14400.00
0005435616130	5324	Economy	14400.00
0005435616103	5324	Economy	14400.00
0005435426005	5324	Economy	14400.00
0005435616060	5324	Economy	14400.00
0005434344969	5324	Economy	14400.00
0005435616059	5324	Economy	14400.00
0005434344994	5324	Economy	14400.00
0005435616027	5324	Economy	14400.00
0005435425610	5324	Economy	14400.00
0005435425722	5324	Economy	14400.00
0005434573663	5324	Economy	14400.00
0005435425965	5324	Economy	14400.00
0005435425808	5324	Economy	14400.00
0005435616126	5324	Economy	14400.00
0005435616080	5324	Economy	14400.00
0005435425822	5324	Economy	14400.00
0005434573652	5324	Economy	14400.00
0005435425828	5324	Economy	14400.00
0005433719174	5324	Economy	14400.00
0005435616070	5324	Economy	14400.00
0005435097418	5324	Economy	14400.00
0005435616069	5324	Economy	14400.00
0005435616140	5324	Economy	14400.00
0005434344975	5324	Economy	14400.00
0005435616138	5324	Economy	14400.00
0005435616105	5324	Economy	14400.00
0005435617240	5324	Economy	14400.00
0005434573651	5324	Economy	14400.00
0005432133531	5324	Economy	14400.00
0005435615343	10888	Business	43100.00
0005435426284	10888	Business	43100.00
0005434245618	10888	Business	43100.00
0005434344660	10888	Business	43100.00
0005434344646	10888	Business	43100.00
0005435615347	10888	Business	43100.00
0005434344618	10888	Business	43100.00
0005435491450	10888	Business	43100.00
0005435555397	10888	Business	43100.00
0005435426292	10888	Business	43100.00
0005435614961	10888	Business	43100.00
0005435614762	10888	Business	43100.00
0005434573472	10888	Business	43100.00
0005435426285	10888	Business	43100.00
0005435614640	10888	Business	43100.00
0005434344547	10888	Business	43100.00
0005435615017	10888	Business	43100.00
0005434573528	10888	Business	43100.00
0005435615198	10888	Business	43100.00
0005435615370	10888	Business	43100.00
0005434344542	10888	Business	43100.00
0005435614496	10888	Business	43100.00
0005435426307	10888	Comfort	24400.00
0005434245604	10888	Comfort	24400.00
0005433719213	10888	Comfort	24400.00
0005435615107	10888	Comfort	24400.00
0005435615383	10888	Comfort	24400.00
0005434245626	10888	Comfort	24400.00
0005435615158	10888	Comfort	24400.00
0005434245622	10888	Comfort	24400.00
0005434344669	10888	Comfort	24400.00
0005435615425	10888	Comfort	24400.00
0005435319760	10888	Comfort	24400.00
0005434573506	10888	Comfort	24400.00
0005435615427	10888	Comfort	24400.00
0005435426277	10888	Comfort	24400.00
0005435615095	10888	Comfort	24400.00
0005435426259	10888	Comfort	24400.00
0005432363485	10888	Comfort	24400.00
0005434245602	10888	Comfort	24400.00
0005434344541	10888	Comfort	24400.00
0005435042904	10888	Comfort	24400.00
0005435615418	10888	Comfort	24400.00
0005435319765	10888	Comfort	24400.00
0005435426278	10888	Comfort	24400.00
0005435426288	10888	Comfort	24400.00
0005435615243	10888	Comfort	24400.00
0005435426266	10888	Comfort	24400.00
0005435426322	10888	Comfort	24400.00
0005434245617	10888	Comfort	24400.00
0005435614750	10888	Comfort	24400.00
0005435614862	10888	Comfort	24400.00
0005435615238	10888	Comfort	24400.00
0005435426272	10888	Comfort	24400.00
0005435491469	10888	Comfort	24400.00
0005435097262	10888	Comfort	24400.00
0005435426260	10888	Comfort	24400.00
0005434245624	10888	Comfort	24400.00
0005435426299	10888	Comfort	24400.00
0005434344581	10888	Comfort	24400.00
0005434344498	10888	Comfort	24400.00
0005435426268	10888	Comfort	24400.00
0005435615426	10888	Comfort	24400.00
0005434344514	10888	Comfort	24400.00
0005434344580	10888	Comfort	24400.00
0005432165200	10888	Economy	14400.00
0005435615106	10888	Economy	14400.00
0005435555398	10888	Economy	14400.00
0005435426279	10888	Economy	14400.00
0005435615122	10888	Economy	14400.00
0005435426257	10888	Economy	14400.00
0005434245615	10888	Economy	14400.00
0005435426317	10888	Economy	14400.00
0005435491468	10888	Economy	14400.00
0005435319766	10888	Economy	14400.00
0005435615115	10888	Economy	14400.00
0005435426323	10888	Economy	14400.00
0005434344716	10888	Economy	14400.00
0005435615369	10888	Economy	14400.00
0005435319768	10888	Economy	14400.00
0005434656599	10888	Economy	14400.00
0005435615349	10888	Economy	14400.00
0005434245609	10888	Economy	14400.00
0005434245627	10888	Economy	14400.00
0005435615004	10888	Economy	14400.00
0005434245598	10888	Economy	14400.00
0005435042905	10888	Economy	14400.00
0005435426297	10888	Economy	14400.00
0005434245603	10888	Economy	14400.00
0005435614751	10888	Economy	14400.00
0005434245616	10888	Economy	14400.00
0005435615448	10888	Economy	14400.00
0005434344548	10888	Economy	14400.00
0005434573518	10888	Economy	14400.00
0005435426283	10888	Economy	14400.00
0005435319769	10888	Economy	14400.00
0005435304242	10888	Economy	14400.00
0005435615170	10888	Economy	14400.00
0005435097339	10888	Economy	14400.00
0005435490273	10888	Economy	14400.00
0005435614929	10888	Economy	14400.00
0005435555399	10888	Economy	14400.00
0005434344637	10888	Economy	14400.00
0005435426303	10888	Economy	14400.00
0005435426258	10888	Economy	14400.00
0005435426276	10888	Economy	14400.00
0005435555400	10888	Economy	14400.00
0005435615224	10888	Economy	14400.00
0005435426298	10888	Economy	14400.00
0005435615412	10888	Economy	14400.00
0005434344551	10888	Economy	14400.00
0005435615419	10888	Economy	14400.00
0005434245610	10888	Economy	14400.00
0005435614909	10888	Economy	14400.00
0005435380399	10888	Economy	14400.00
0005435426270	10888	Economy	14400.00
0005435097341	10888	Economy	14400.00
0005432165199	10888	Economy	14400.00
0005434573485	10888	Economy	14400.00
0005432363486	10888	Economy	14400.00
0005433719216	10888	Economy	14400.00
0005433719215	10888	Economy	14400.00
0005434344639	10888	Economy	14400.00
0005434245606	10888	Economy	14400.00
0005435426304	10888	Economy	14400.00
0005435615118	10888	Economy	14400.00
0005435615470	10888	Economy	14400.00
0005435615324	10888	Economy	14400.00
0005435426290	10888	Economy	15800.00
0005435614668	10888	Economy	14400.00
0005435614855	10888	Economy	15800.00
0005435097311	10888	Economy	15800.00
0005434344521	10888	Economy	14400.00
0005435380398	10888	Economy	14400.00
0005435426319	10888	Economy	14400.00
0005435615022	10888	Economy	15800.00
0005433719217	10888	Economy	15800.00
0005434344519	10888	Economy	15800.00
0005435615045	10888	Economy	14400.00
0005435426286	10888	Economy	14400.00
0005435380400	10888	Economy	14400.00
0005432841058	10888	Economy	14400.00
0005435614962	10888	Economy	14400.00
0005435615199	10888	Economy	14400.00
0005435380402	10888	Economy	14400.00
0005432165205	10888	Economy	14400.00
0005435614884	10888	Economy	14400.00
0005435319767	10888	Economy	14400.00
0005435426280	10888	Economy	14400.00
0005435615010	10888	Economy	14400.00
0005434344620	10888	Economy	14400.00
0005435426302	10888	Economy	14400.00
0005435490274	10888	Economy	14400.00
0005435426271	10888	Economy	14400.00
0005432165204	10888	Economy	14400.00
0005432166972	10888	Economy	14400.00
0005435097276	10888	Economy	14400.00
0005435426267	10888	Economy	14400.00
0005434573483	10888	Economy	14400.00
0005434344441	10888	Economy	14400.00
0005435614959	10888	Economy	14400.00
0005435426294	10888	Economy	14400.00
0005435097298	10888	Economy	14400.00
0005434573484	10888	Economy	14400.00
0005435615159	10888	Economy	14400.00
0005435614987	10888	Economy	14400.00
0005435614933	10888	Economy	14400.00
0005435426316	10888	Economy	14400.00
0005434344723	10888	Economy	14400.00
0005435426291	10888	Economy	14400.00
0005435615117	10888	Economy	14400.00
0005435614699	10888	Economy	14400.00
0005435426318	10888	Economy	14400.00
0005435426281	10888	Economy	14400.00
0005435614829	10888	Economy	14400.00
0005434344578	10888	Economy	14400.00
0005435426309	10888	Economy	14400.00
0005435614911	10888	Economy	14400.00
0005434344630	10888	Economy	14400.00
0005435426255	10888	Economy	14400.00
0005435615189	10888	Economy	14400.00
0005434245625	10888	Economy	14400.00
0005435615474	10888	Economy	14400.00
0005434344613	10888	Economy	14400.00
0005434344627	10888	Economy	14400.00
0005435614886	10888	Economy	14400.00
0005435615402	10888	Economy	14400.00
0005435426320	10888	Economy	14400.00
0005435426261	10888	Economy	14400.00
0005435614649	10888	Economy	14400.00
0005435615071	10888	Economy	14400.00
0005435304246	10888	Economy	14400.00
0005435042906	10888	Economy	14400.00
0005434245614	10888	Economy	14400.00
0005435615469	10888	Economy	14400.00
0005435426301	10888	Economy	14400.00
0005435426282	10888	Economy	14400.00
0005434344619	10888	Economy	14400.00
0005434245600	10888	Economy	14400.00
0005435305054	10888	Economy	14400.00
0005434573493	10888	Economy	14400.00
0005435614608	10888	Economy	14400.00
0005435426295	10888	Economy	14400.00
0005435426300	10888	Economy	14400.00
0005435097325	10888	Economy	14400.00
0005435615171	10888	Economy	14400.00
0005435614811	10888	Economy	14400.00
0005435615466	10888	Economy	14400.00
0005435615088	10888	Economy	14400.00
0005434573524	10888	Economy	14400.00
0005433719214	10888	Economy	14400.00
0005435615417	10888	Economy	14400.00
0005435304243	10888	Economy	14400.00
0005435614476	10888	Economy	14400.00
0005435614927	10888	Economy	14400.00
0005435614928	10888	Economy	14400.00
0005434344328	10888	Economy	14400.00
0005434245611	10888	Economy	14400.00
0005435614760	10888	Economy	14400.00
0005435615190	10888	Economy	14400.00
0005435426321	10888	Economy	14400.00
0005435614906	10888	Economy	14400.00
0005434245601	10888	Economy	14400.00
0005434245621	10888	Economy	14400.00
0005434344721	10888	Economy	14400.00
0005435426310	10888	Economy	14400.00
0005434344520	10888	Economy	14400.00
0005434245619	10888	Economy	14400.00
0005434344546	10888	Economy	14400.00
0005435097299	10888	Economy	14400.00
0005435042902	10888	Economy	14400.00
0005435319763	10888	Economy	14400.00
0005435426313	10888	Economy	14400.00
0005435614726	10888	Economy	14400.00
0005435426269	10888	Economy	14400.00
0005435319762	10888	Economy	14400.00
0005435380401	10888	Economy	14400.00
0005435426293	10888	Economy	14400.00
0005434245613	10888	Economy	14400.00
0005435426324	10888	Economy	14400.00
0005435614904	10888	Economy	14400.00
0005435614905	10888	Economy	15800.00
0005435615063	10888	Economy	15800.00
0005435304245	10888	Economy	15800.00
0005432363487	10888	Economy	15800.00
0005435491465	10888	Economy	14400.00
0005435614938	10888	Economy	14400.00
0005435615145	10888	Economy	14400.00
0005435426308	10888	Economy	14400.00
0005435319761	10888	Economy	14400.00
0005434573505	10888	Economy	14400.00
0005432166971	10888	Economy	14400.00
0005432165202	10888	Economy	14400.00
0005434344659	10888	Economy	14400.00
0005435426289	10888	Economy	14400.00
0005434344550	10888	Economy	14400.00
0005435615172	10888	Economy	14400.00
0005435426315	10888	Economy	14400.00
0005435614882	10888	Economy	14400.00
0005434573465	10888	Economy	14400.00
0005434344722	10888	Economy	14400.00
0005435426306	10888	Economy	14400.00
0005435426264	10888	Economy	14400.00
0005435426273	10888	Economy	14400.00
0005432165201	10888	Economy	14400.00
0005435614497	10888	Economy	14400.00
0005435426305	10888	Economy	14400.00
0005435304247	10888	Economy	14400.00
0005435614863	10888	Economy	14400.00
0005435426287	10888	Economy	14400.00
0005435614791	10888	Economy	14400.00
0005432165203	10888	Economy	14400.00
0005435615366	10888	Economy	14400.00
0005435380397	10888	Economy	14400.00
0005435615390	10888	Economy	14400.00
0005435614883	10888	Economy	14400.00
0005435615223	10888	Economy	14400.00
0005435491463	10888	Economy	14400.00
0005435042903	10888	Economy	14400.00
0005432841059	10888	Economy	14400.00
0005435614761	10888	Economy	14400.00
0005435615273	10888	Economy	14400.00
0005435319764	10888	Economy	14400.00
0005435426262	10888	Economy	14400.00
0005435615221	10888	Economy	14400.00
0005435097277	10888	Economy	14400.00
0005435615184	10888	Economy	14400.00
0005435097310	10888	Economy	14400.00
0005435319759	10888	Economy	14400.00
0005435614856	10888	Economy	14400.00
0005435614825	10888	Economy	14400.00
0005435614607	10888	Economy	14400.00
0005435615367	10888	Economy	14400.00
0005435614866	10888	Economy	14400.00
0005435304244	10888	Economy	14400.00
0005434573519	10888	Economy	14400.00
0005435615146	10888	Economy	14400.00
0005434245623	10888	Economy	14400.00
0005435097256	10888	Economy	14400.00
0005435615222	10888	Economy	14400.00
0005435615258	10888	Economy	14400.00
0005434344640	10888	Economy	14400.00
0005435614651	10888	Economy	14400.00
0005434245608	10888	Economy	14400.00
0005434573499	10888	Economy	14400.00
0005435615259	10888	Economy	14400.00
0005435426274	10888	Economy	14400.00
0005435426275	10888	Economy	14400.00
0005434344614	10888	Economy	14400.00
0005434245599	10888	Economy	14400.00
0005435426254	10888	Economy	14400.00
0005435614939	10888	Economy	14400.00
0005434245612	10888	Economy	14400.00
0005434344645	10888	Economy	14400.00
0005435491464	10888	Economy	14400.00
0005435614759	10888	Economy	14400.00
0005435426265	10888	Economy	14400.00
0005435614834	10888	Economy	14400.00
0005435426296	10888	Economy	14400.00
0005434245620	10888	Economy	14400.00
0005435426263	10888	Economy	14400.00
0005435615274	10888	Economy	14400.00
0005435614965	10888	Economy	14400.00
0005434245605	10888	Economy	14400.00
0005435614934	10888	Economy	14400.00
0005435426256	10888	Economy	14400.00
0005435426312	10888	Economy	14400.00
0005435615018	10888	Economy	14400.00
0005435097305	10888	Economy	14400.00
0005435615160	10888	Economy	14400.00
0005434344440	10888	Economy	14400.00
0005435614639	10888	Economy	14400.00
0005434245607	10888	Economy	14400.00
0005435614966	10888	Economy	14400.00
0005435426314	10888	Economy	14400.00
0005435615447	10888	Economy	14400.00
0005435097273	10888	Economy	14400.00
0005435614984	10888	Economy	14400.00
0005435614903	10888	Economy	14400.00
0005435614960	10888	Economy	14400.00
0005435426311	10888	Economy	14400.00
0005434656598	10888	Economy	14400.00
0005435615315	10888	Economy	14400.00
0005433634550	3290	Business	18800.00
0005433634557	3290	Business	18800.00
0005433507561	3290	Business	18800.00
0005432182189	3290	Business	18800.00
0005433507566	3290	Business	18800.00
0005432460376	3290	Business	18800.00
0005433634569	3290	Business	18800.00
0005433634553	3290	Business	18800.00
0005432460526	3290	Business	18800.00
0005432182195	3290	Business	18800.00
0005433634573	3290	Business	18800.00
0005433634539	3290	Business	18800.00
0005433806125	3290	Business	18800.00
0005433634565	3290	Business	18800.00
0005433634547	3290	Business	18800.00
0005432182206	3290	Business	18800.00
0005433806129	3290	Business	18800.00
0005433806128	3290	Business	18800.00
0005432182203	3290	Business	18800.00
0005432460377	3290	Business	18800.00
0005433634559	3290	Business	18800.00
0005432460493	3290	Business	18800.00
0005432460490	3290	Business	18800.00
0005432182202	3290	Business	18800.00
0005433806102	3290	Business	18800.00
0005433806097	3290	Business	18800.00
0005433507569	3290	Business	18800.00
0005432460551	3290	Business	18800.00
0005432460662	3290	Economy	6900.00
0005434143751	3290	Economy	6900.00
0005433634568	3290	Economy	6900.00
0005432460443	3290	Economy	6900.00
0005432182191	3290	Economy	6900.00
0005432460645	3290	Economy	6900.00
0005433507567	3290	Economy	6300.00
0005432182190	3290	Economy	6300.00
0005433806122	3290	Economy	6300.00
0005433634545	3290	Economy	6300.00
0005433806121	3290	Economy	6300.00
0005432182198	3290	Economy	6300.00
0005433806105	3290	Economy	6300.00
0005433806107	3290	Economy	6300.00
0005433634556	3290	Economy	6300.00
0005433806116	3290	Economy	6300.00
0005433507574	3290	Economy	6300.00
0005433806110	3290	Economy	6300.00
0005433806112	3290	Economy	6300.00
0005433806109	3290	Economy	6300.00
0005433634552	3290	Economy	6300.00
0005433634549	3290	Economy	6300.00
0005433634541	3290	Economy	6300.00
0005433806132	3290	Economy	6300.00
0005434143752	3290	Economy	6300.00
0005432182199	3290	Economy	6300.00
0005432460577	3290	Economy	6300.00
0005433634570	3290	Economy	6300.00
0005432182204	3290	Economy	6300.00
0005433634571	3290	Economy	6300.00
0005432182205	3290	Economy	6300.00
0005432182201	3290	Economy	6300.00
0005432460646	3290	Economy	6300.00
0005433507577	3290	Economy	6300.00
0005432182197	3290	Economy	6300.00
0005433806096	3290	Economy	6300.00
0005432460572	3290	Economy	6300.00
0005432460346	3290	Economy	6300.00
0005432460250	3290	Economy	6300.00
0005433806136	3290	Economy	6300.00
0005432460686	3290	Economy	6300.00
0005432460564	3290	Economy	6300.00
0005432460699	3290	Economy	6300.00
0005433806100	3290	Economy	6300.00
0005432460619	3290	Economy	6300.00
0005432460647	3290	Economy	6300.00
0005433507570	3290	Economy	6300.00
0005433806126	3290	Economy	6300.00
0005432182194	3290	Economy	6300.00
0005433806103	3290	Economy	6300.00
0005433507576	3290	Economy	6300.00
0005433806098	3290	Economy	6300.00
0005433634563	3290	Economy	6300.00
0005433806111	3290	Economy	6300.00
0005433507560	3290	Economy	6300.00
0005433634551	3290	Economy	6300.00
0005433806104	3290	Economy	6300.00
0005432460505	3290	Economy	6300.00
0005433634542	3290	Economy	6300.00
0005433634555	3290	Economy	6300.00
0005432460563	3290	Economy	6300.00
0005433507578	3290	Economy	6300.00
0005432460430	3290	Economy	6300.00
0005433634546	3290	Economy	6300.00
0005433507572	3290	Economy	6300.00
0005433634564	3290	Economy	6900.00
0005432460528	3290	Economy	6300.00
0005432460571	3290	Economy	6900.00
0005433507571	3290	Economy	6900.00
0005433806123	3290	Economy	6900.00
0005432460539	3290	Economy	6900.00
0005433634566	3290	Economy	6300.00
0005432460347	3290	Economy	6300.00
0005433806114	3290	Economy	6300.00
0005433634544	3290	Economy	6300.00
0005432182192	3290	Economy	6300.00
0005432460547	3290	Economy	6900.00
0005433806124	3290	Economy	6300.00
0005433806118	3290	Economy	6300.00
0005432460513	3290	Economy	6300.00
0005433634561	3290	Economy	6300.00
0005433507573	3290	Economy	6300.00
0005433806115	3290	Economy	6300.00
0005433507568	3290	Economy	6300.00
0005432460573	3290	Economy	6300.00
0005433507563	3290	Economy	6300.00
0005432182188	3290	Economy	6300.00
0005433806134	3290	Economy	6300.00
0005432460488	3290	Economy	6300.00
0005432460527	3290	Economy	6300.00
0005433634543	3290	Economy	6300.00
0005433507565	3290	Economy	6300.00
0005432460677	3290	Economy	6300.00
0005433806106	3290	Economy	6300.00
0005433806095	3290	Economy	6300.00
0005432460489	3290	Economy	6300.00
0005433806113	3290	Economy	6300.00
0005432460679	3290	Economy	6300.00
0005433806099	3290	Economy	6300.00
0005433806130	3290	Economy	6300.00
0005433634567	3290	Economy	6300.00
0005432460546	3290	Economy	6300.00
0005432460540	3290	Economy	6300.00
0005433507559	3290	Economy	6300.00
0005433806108	3290	Economy	6300.00
0005433634560	3290	Economy	6300.00
0005433507564	3290	Economy	6300.00
0005432460541	3290	Economy	6300.00
0005433507575	3290	Economy	6300.00
0005432460612	3290	Economy	6300.00
0005433634572	3290	Economy	6300.00
0005433806101	3290	Economy	6300.00
0005432460512	3290	Economy	6300.00
0005433806127	3290	Economy	6300.00
0005433634554	3290	Economy	6300.00
0005432460458	3290	Economy	6300.00
0005433806117	3290	Economy	6300.00
0005432182196	3290	Economy	6300.00
0005432182207	3290	Economy	6300.00
0005433806119	3290	Economy	6300.00
0005433806120	3290	Economy	6300.00
0005432182208	3290	Economy	6300.00
0005432460327	3290	Economy	6300.00
0005432460423	3290	Economy	6300.00
0005432460442	3290	Economy	6300.00
0005433806133	3290	Economy	6300.00
0005433634562	3290	Economy	6300.00
0005432182193	3290	Economy	6300.00
0005432182187	3290	Economy	6300.00
0005432460685	3290	Economy	6300.00
0005433507562	3290	Economy	6300.00
0005432460544	3290	Economy	6300.00
0005433507558	3290	Economy	6300.00
0005432460542	3290	Economy	6300.00
0005433806131	3290	Economy	6300.00
0005433634540	3290	Economy	6300.00
0005432460440	3290	Economy	6300.00
0005433806135	3290	Economy	6300.00
0005432460585	3290	Economy	6300.00
0005432182200	3290	Economy	6300.00
0005433634558	3290	Economy	6300.00
0005433634548	3290	Economy	6300.00
0005435885873	3289	Business	18800.00
0005435886010	3289	Business	18800.00
0005435886023	3289	Economy	6900.00
0005435886013	3289	Economy	6900.00
0005435885924	3289	Economy	6300.00
0005435885923	3289	Economy	6300.00
0005435886029	3289	Economy	6300.00
0005435885870	3289	Economy	6300.00
0005435886004	3289	Economy	6300.00
0005435886028	3289	Economy	6300.00
0005435885716	3289	Economy	6300.00
0005435885789	3289	Economy	6300.00
0005435885955	3289	Economy	6300.00
0005435885889	3289	Economy	6300.00
0005435885929	3289	Economy	6300.00
0005435885898	3289	Economy	6300.00
0005435885925	3289	Economy	6300.00
0005435885786	3289	Economy	6300.00
0005435885942	3289	Economy	6300.00
0005435886027	3289	Economy	6300.00
0005435885935	3289	Economy	6300.00
0005435885890	3289	Economy	6300.00
0005435885893	3289	Economy	6300.00
0005435886204	3289	Economy	6300.00
0005435885721	3289	Economy	6300.00
0005435885857	3289	Economy	6900.00
0005435885720	3289	Economy	6300.00
0005435885987	3289	Economy	6300.00
0005435885965	3289	Economy	6300.00
0005435885946	3289	Economy	6300.00
0005435885941	3289	Economy	6300.00
0005435886026	3289	Economy	6300.00
0005435886074	3289	Economy	6300.00
0005435886009	3289	Economy	6300.00
0005435885926	3289	Economy	6300.00
0005435886109	3289	Economy	6300.00
0005435885894	3289	Economy	6300.00
0005435885922	3289	Economy	6300.00
0005435885787	3289	Economy	6300.00
0005435885957	3289	Economy	6300.00
0005435886012	3289	Economy	6300.00
0005435885835	3289	Economy	6300.00
0005435886235	3289	Economy	6300.00
0005435885999	3289	Economy	6300.00
0005435885839	3289	Economy	6300.00
0005435886063	3289	Economy	6300.00
0005435885934	3289	Economy	6300.00
0005435885809	3289	Economy	6300.00
0005432461028	8259	Business	18800.00
0005433507408	8259	Business	18800.00
0005435886310	8259	Business	18800.00
0005433507418	8259	Business	18800.00
0005433507397	8259	Business	18800.00
0005433507316	8259	Business	18800.00
0005432460989	8259	Business	18800.00
0005435886296	8259	Business	18800.00
0005433507417	8259	Business	18800.00
0005432043009	8259	Business	18800.00
0005432461026	8259	Business	18800.00
0005432461005	8259	Business	18800.00
0005432461025	8259	Business	18800.00
0005432043020	8259	Business	18800.00
0005435886313	8259	Business	18800.00
0005435142978	8259	Business	18800.00
0005435886282	8259	Business	18800.00
0005432043019	8259	Business	18800.00
0005435886318	8259	Business	18800.00
0005432461012	8259	Business	18800.00
0005434312387	8259	Business	18800.00
0005433507398	8259	Business	18800.00
0005432461021	8259	Economy	6900.00
0005432043018	8259	Economy	6900.00
0005435886307	8259	Economy	6900.00
0005432461032	8259	Economy	6900.00
0005433507457	8259	Economy	6300.00
0005435886302	8259	Economy	6300.00
0005432461038	8259	Economy	6300.00
0005435886290	8259	Economy	6300.00
0005432461024	8259	Economy	6300.00
0005435886285	8259	Economy	6300.00
0005432461031	8259	Economy	6300.00
0005435886299	8259	Economy	6300.00
0005433507416	8259	Economy	6300.00
0005435886303	8259	Economy	6300.00
0005435886322	8259	Economy	6300.00
0005432461020	8259	Economy	6300.00
0005435886306	8259	Economy	6300.00
0005433507466	8259	Economy	6300.00
0005432461034	8259	Economy	6300.00
0005432043012	8259	Economy	6300.00
0005435886286	8259	Economy	6300.00
0005435886297	8259	Economy	6300.00
0005433507395	8259	Economy	6300.00
0005432461033	8259	Economy	6300.00
0005435886289	8259	Economy	6300.00
0005432461037	8259	Economy	6300.00
0005432043022	8259	Economy	6300.00
0005435886321	8259	Economy	6300.00
0005432461030	8259	Economy	6300.00
0005433507469	8259	Economy	6300.00
0005432461018	8259	Economy	6300.00
0005434312366	8259	Economy	6300.00
0005432460997	8259	Economy	6300.00
0005433507436	8259	Economy	6300.00
0005432460992	8259	Economy	6300.00
0005433507384	8259	Economy	6300.00
0005432461003	8259	Economy	6300.00
0005432460996	8259	Economy	6300.00
0005432460993	8259	Economy	6300.00
0005433507432	8259	Economy	6300.00
0005433507433	8259	Economy	6300.00
0005432460999	8259	Economy	6300.00
0005435142979	8259	Economy	6300.00
0005432461019	8259	Economy	6300.00
0005435886315	8259	Economy	6300.00
0005432461008	8259	Economy	6300.00
0005435142980	8259	Economy	6300.00
0005432461006	8259	Economy	6300.00
0005432461017	8259	Economy	6300.00
0005432461010	8259	Economy	6300.00
0005432460995	8259	Economy	6300.00
0005432461022	8259	Economy	6300.00
0005432461029	8259	Economy	6300.00
0005435886311	8259	Economy	6300.00
0005434326283	8259	Economy	6300.00
0005435886298	8259	Economy	6300.00
0005432460986	8259	Economy	6900.00
0005432461011	8259	Economy	6900.00
0005433507385	8259	Economy	6900.00
0005435886314	8259	Economy	6900.00
0005432461023	8259	Economy	6900.00
0005435886317	8259	Economy	6300.00
0005435886301	8259	Economy	6300.00
0005432461035	8259	Economy	6300.00
0005435886305	8259	Economy	6300.00
0005435886300	8259	Economy	6900.00
0005435142977	8259	Economy	6300.00
0005432043013	8259	Economy	6300.00
0005435886281	8259	Economy	6300.00
0005435886312	8259	Economy	6300.00
0005433507386	8259	Economy	6300.00
0005432460994	8259	Economy	6300.00
0005432460998	8259	Economy	6300.00
0005433507444	8259	Economy	6300.00
0005435886320	8259	Economy	6300.00
0005434312365	8259	Economy	6300.00
0005435886291	8259	Economy	6300.00
0005435886294	8259	Economy	6300.00
0005433507365	8259	Economy	6300.00
0005432461027	8259	Economy	6300.00
0005435886283	8259	Economy	6300.00
0005432043011	8259	Economy	6300.00
0005434312364	8259	Economy	6300.00
0005435886287	8259	Economy	6300.00
0005432460987	8259	Economy	6300.00
0005432461016	8259	Economy	6300.00
0005433507415	8259	Economy	6300.00
0005435886292	8259	Economy	6300.00
0005435886288	8259	Economy	6300.00
0005435886280	8259	Economy	6300.00
0005432461014	8259	Economy	6300.00
0005435886293	8259	Economy	6300.00
0005432043015	8259	Economy	6300.00
0005432461001	8259	Economy	6300.00
0005435886308	8259	Economy	6300.00
0005435886316	8259	Economy	6300.00
0005435886309	8259	Economy	6300.00
0005432043016	8259	Economy	6300.00
0005435886279	8259	Economy	6300.00
0005432043021	8259	Economy	6300.00
0005432043014	8259	Economy	6300.00
0005432461009	8259	Economy	6300.00
0005434326282	8259	Economy	6300.00
0005433507443	8259	Economy	6300.00
0005435886319	8259	Economy	6300.00
0005432460991	8259	Economy	6300.00
0005432460990	8259	Economy	6300.00
0005432460988	8259	Economy	6300.00
0005435886284	8259	Economy	6300.00
0005432461036	8259	Economy	6300.00
0005435886295	8259	Economy	6300.00
0005432461004	8259	Economy	6300.00
0005432461015	8259	Economy	6300.00
0005432461040	8259	Economy	6300.00
0005432043017	8259	Economy	6300.00
0005432461039	8259	Economy	6300.00
0005432461002	8259	Economy	6300.00
0005432461013	8259	Economy	6300.00
0005432461007	8259	Economy	6300.00
0005435886304	8259	Economy	6300.00
0005432043010	8259	Economy	6300.00
0005432461000	8259	Economy	6300.00
0005433805918	8261	Business	18800.00
0005433634342	8261	Business	18800.00
0005433634186	8261	Business	18800.00
0005433634130	8261	Business	18800.00
0005433634170	8261	Business	18800.00
0005433634195	8261	Business	18800.00
0005433634226	8261	Business	18800.00
0005433634279	8261	Business	18800.00
0005433805757	8261	Economy	6900.00
0005433805945	8261	Economy	6900.00
0005433634274	8261	Economy	6300.00
0005433634341	8261	Economy	6300.00
0005433805827	8261	Economy	6300.00
0005433805837	8261	Economy	6300.00
0005433805803	8261	Economy	6300.00
0005433805894	8261	Economy	6300.00
0005433805603	8261	Economy	6300.00
0005433805865	8261	Economy	6300.00
0005433634171	8261	Economy	6300.00
0005435858698	8261	Economy	6300.00
0005433805888	8261	Economy	6300.00
0005433634260	8261	Economy	6300.00
0005433634397	8261	Economy	6300.00
0005433805889	8261	Economy	6300.00
0005433634239	8261	Economy	6300.00
0005433634194	8261	Economy	6300.00
0005433805747	8261	Economy	6300.00
0005433634325	8261	Economy	6300.00
0005433805640	8261	Economy	6300.00
0005433634190	8261	Economy	6300.00
0005433805876	8261	Economy	6300.00
0005433805862	8261	Economy	6300.00
0005433634232	8261	Economy	6300.00
0005433805844	8261	Economy	6900.00
0005433634326	8261	Economy	6300.00
0005433634252	8261	Economy	6300.00
0005433805877	8261	Economy	6300.00
0005433805946	8261	Economy	6300.00
0005433805829	8261	Economy	6300.00
0005433634281	8261	Economy	6300.00
0005433805746	8261	Economy	6300.00
0005433634154	8261	Economy	6300.00
0005433634172	8261	Economy	6300.00
0005433634278	8261	Economy	6300.00
0005433634104	8261	Economy	6300.00
0005433805887	8261	Economy	6300.00
0005433805912	8261	Economy	6300.00
0005433634161	8261	Economy	6300.00
0005434271335	8261	Economy	6300.00
0005433634111	8261	Economy	6300.00
0005433634364	8261	Economy	6300.00
0005433805893	8261	Economy	6300.00
0005433805776	8261	Economy	6300.00
0005433805866	8261	Economy	6300.00
0005433634185	8261	Economy	6300.00
0005433805828	8261	Economy	6300.00
0005433805799	8261	Economy	6300.00
0005433634105	8261	Economy	6300.00
0005433634253	8261	Economy	6300.00
0005433805845	8261	Economy	6300.00
0005433634196	8261	Economy	6300.00
0005433805802	8261	Economy	6300.00
0005433805833	8261	Economy	6300.00
0005433805798	8261	Economy	6300.00
0005433805826	8261	Economy	6300.00
0005433634259	8261	Economy	6300.00
0005433634116	8261	Economy	6300.00
0005433634162	8261	Economy	6300.00
0005433805917	8261	Economy	6300.00
0005433805639	8261	Economy	6300.00
0005434183604	8262	Business	18800.00
0005432384033	4634	Business	9900.00
0005432384001	4634	Business	9900.00
0005432384027	4634	Business	9900.00
0005432728206	4634	Business	9900.00
0005432728203	4634	Business	9900.00
0005432728214	4634	Business	9900.00
0005432384015	4634	Economy	3300.00
0005432384014	4634	Economy	3300.00
0005432384031	4634	Economy	3300.00
0005432383998	4634	Economy	3300.00
0005432383999	4634	Economy	3300.00
0005433453805	4634	Economy	3300.00
0005432384032	4634	Economy	3300.00
0005433454922	4634	Economy	3300.00
0005432384034	4634	Economy	3300.00
0005432383997	4634	Economy	3600.00
0005432384007	4634	Economy	3600.00
0005432728210	4634	Economy	3300.00
0005432384020	4634	Economy	3300.00
0005432384008	4634	Economy	3300.00
0005432384006	4634	Economy	3300.00
0005432384011	4634	Economy	3300.00
0005432384025	4634	Economy	3300.00
0005432383996	4634	Economy	3300.00
0005433722357	4634	Economy	3300.00
0005432384024	4634	Economy	3300.00
0005432384010	4634	Economy	3300.00
0005432728207	4634	Economy	3300.00
0005432384000	4634	Economy	3300.00
0005433722359	4634	Economy	3300.00
0005432384029	4634	Economy	3300.00
0005432384036	4634	Economy	3300.00
0005432384018	4634	Economy	3300.00
0005432384017	4634	Economy	3300.00
0005433722356	4634	Economy	3300.00
0005432728212	4634	Economy	3300.00
0005432384004	4634	Economy	3300.00
0005432384009	4634	Economy	3300.00
0005432384023	4634	Economy	3300.00
0005432728204	4634	Economy	3300.00
0005432384019	4634	Economy	3300.00
0005432728205	4634	Economy	3300.00
0005432384003	4634	Economy	3300.00
0005432384016	4634	Economy	3300.00
0005432728209	4634	Economy	3300.00
0005433454921	4634	Economy	3300.00
0005432384035	4634	Economy	3300.00
0005433453804	4634	Economy	3300.00
0005432384013	4634	Economy	3300.00
0005433722362	4634	Economy	3300.00
0005433453806	4634	Economy	3300.00
0005433722360	4634	Economy	3300.00
0005432384026	4634	Economy	3300.00
0005432384030	4634	Economy	3300.00
0005433722361	4634	Economy	3300.00
0005432384022	4634	Economy	3300.00
0005432384002	4634	Economy	3300.00
0005432384021	4634	Economy	3300.00
0005432384012	4634	Economy	3300.00
0005432384005	4634	Economy	3300.00
0005432384028	4634	Economy	3300.00
0005433722358	4634	Economy	3300.00
0005432728215	4634	Economy	3300.00
0005432728211	4634	Economy	3300.00
0005432728213	4634	Economy	3300.00
0005432728208	4634	Economy	3300.00
0005432383619	30096	Business	9900.00
0005432383350	30096	Business	9900.00
0005432383637	30096	Business	9900.00
0005433722294	30096	Business	9900.00
0005433722307	30096	Business	9900.00
0005432383587	30096	Business	9900.00
0005432383518	30096	Economy	3300.00
0005433194896	30096	Economy	3300.00
0005432383450	30096	Economy	3300.00
0005432728161	30096	Economy	3300.00
0005433722302	30096	Economy	3300.00
0005432383665	30096	Economy	3300.00
0005432728104	30096	Economy	3300.00
0005432383493	30096	Economy	3600.00
0005432728105	30096	Economy	3600.00
0005432383754	30096	Economy	3300.00
0005432383459	30096	Economy	3300.00
0005432383561	30096	Economy	3300.00
0005432728048	30096	Economy	3300.00
0005432383512	30096	Economy	3300.00
0005432383530	30096	Economy	3300.00
0005432383532	30096	Economy	3300.00
0005432383531	30096	Economy	3300.00
0005433722281	30096	Economy	3300.00
0005433722308	30096	Economy	3300.00
0005432383756	30096	Economy	3300.00
0005432383603	30096	Economy	3300.00
0005432383540	30096	Economy	3300.00
0005432383602	30096	Economy	3300.00
0005432383473	30096	Economy	3300.00
0005432383544	30096	Economy	3300.00
0005432383581	30096	Economy	3300.00
0005433453778	30096	Economy	3300.00
0005432383625	30096	Economy	3300.00
0005432383586	30096	Economy	3300.00
0005432383515	30096	Economy	3300.00
0005432383574	30096	Economy	3300.00
0005432383639	30096	Economy	3300.00
0005433194897	30096	Economy	3300.00
0005432383676	30096	Economy	3300.00
0005433194888	30096	Economy	3300.00
0005433194889	30096	Economy	3300.00
0005432383442	30096	Economy	3300.00
0005432383458	30096	Economy	3300.00
0005433722285	30096	Economy	3300.00
0005432383649	30096	Economy	3300.00
0005432383429	30096	Economy	3300.00
0005432383621	30096	Economy	3300.00
0005432383582	30096	Economy	3300.00
0005432728103	30096	Economy	3300.00
0005432383521	30096	Economy	3300.00
0005432383425	30096	Economy	3300.00
0005432383608	30096	Economy	3300.00
0005432383755	30096	Economy	3300.00
0005432383513	30096	Economy	3300.00
0005432728067	30096	Economy	3300.00
0005432728068	30096	Economy	3300.00
0005432383590	30096	Economy	3300.00
0005433451637	30096	Economy	3300.00
0005432383640	30096	Economy	3300.00
0005432383492	30096	Economy	3300.00
0005432383529	30096	Economy	3300.00
0005433194890	30096	Economy	3300.00
0005433722279	30096	Economy	3300.00
0005433722295	30096	Economy	3300.00
0005433722303	30096	Economy	3300.00
0005432383504	30096	Economy	3300.00
0005433722288	30096	Economy	3300.00
0005432383596	30096	Economy	3300.00
0005435530032	1752	Business	57200.00
0005435541470	1752	Business	57200.00
0005432294540	1752	Business	57200.00
0005435541478	1752	Business	57200.00
0005435541476	1752	Business	57200.00
0005435541483	1752	Business	57200.00
0005435529737	1752	Business	57200.00
0005435529743	1752	Business	57200.00
0005433517088	1752	Business	57200.00
0005435530029	1752	Business	57200.00
0005435530023	1752	Economy	19100.00
0005435530036	1752	Economy	19100.00
0005435529738	1752	Economy	19100.00
0005435530027	1752	Economy	19100.00
0005435529742	1752	Economy	19100.00
0005435529736	1752	Economy	19100.00
0005435541466	1752	Economy	19100.00
0005435530025	1752	Economy	19100.00
0005435541473	1752	Economy	19100.00
0005435541480	1752	Economy	19100.00
0005435541468	1752	Economy	21000.00
0005435529729	1752	Economy	21000.00
0005433517085	1752	Economy	21000.00
0005435529733	1752	Economy	21000.00
0005435530033	1752	Economy	19100.00
0005435529731	1752	Economy	19100.00
0005433517089	1752	Economy	19100.00
0005435530044	1752	Economy	19100.00
0005435529732	1752	Economy	19100.00
0005433517087	1752	Economy	19100.00
0005435530026	1752	Economy	19100.00
0005435541469	1752	Economy	19100.00
0005435541471	1752	Economy	19100.00
0005435529727	1752	Economy	19100.00
0005435530039	1752	Economy	19100.00
0005435530042	1752	Economy	19100.00
0005435530031	1752	Economy	19100.00
0005435541465	1752	Economy	19100.00
0005432294541	1752	Economy	19100.00
0005435541474	1752	Economy	19100.00
0005432294539	1752	Economy	19100.00
0005435530037	1752	Economy	19100.00
0005435529734	1752	Economy	19100.00
0005435541481	1752	Economy	19100.00
0005435529730	1752	Economy	19100.00
0005435530043	1752	Economy	19100.00
0005435541472	1752	Economy	19100.00
0005435541482	1752	Economy	19100.00
0005435530030	1752	Economy	19100.00
0005435529726	1752	Economy	19100.00
0005435530041	1752	Economy	19100.00
0005435541486	1752	Economy	19100.00
0005435541479	1752	Economy	19100.00
0005435529739	1752	Economy	19100.00
0005435541477	1752	Economy	19100.00
0005435530024	1752	Economy	19100.00
0005435529723	1752	Economy	19100.00
0005435530028	1752	Economy	19100.00
0005435530034	1752	Economy	19100.00
0005435530038	1752	Economy	19100.00
0005432925110	1752	Economy	19100.00
0005435529740	1752	Economy	19100.00
0005435529735	1752	Economy	19100.00
0005433517095	1752	Economy	19100.00
0005435529728	1752	Economy	19100.00
0005435541484	1752	Economy	19100.00
0005432925069	1752	Economy	19100.00
0005435541475	1752	Economy	19100.00
0005435529725	1752	Economy	19100.00
0005433517090	1752	Economy	19100.00
0005433517086	1752	Economy	19100.00
0005435529741	1752	Economy	19100.00
0005433517092	1752	Economy	19100.00
0005435541467	1752	Economy	19100.00
0005432925072	1752	Economy	19100.00
0005432925092	1752	Economy	19100.00
0005435530035	1752	Economy	19100.00
0005433517094	1752	Economy	19100.00
0005435541485	1752	Economy	19100.00
0005433517091	1752	Economy	19100.00
0005435529724	1752	Economy	19100.00
0005435530040	1752	Economy	19100.00
0005433517093	1752	Economy	19100.00
0005433517032	21992	Business	57200.00
0005432925141	21992	Business	57200.00
0005435518143	21992	Business	57200.00
0005433517031	21992	Business	57200.00
0005435541307	21992	Business	57200.00
0005435518114	21992	Business	57200.00
0005432925142	21992	Business	57200.00
0005433516987	21992	Economy	19100.00
0005435518113	21992	Economy	19100.00
0005435518137	21992	Economy	19100.00
0005435518129	21992	Economy	21000.00
0005435541314	21992	Economy	21000.00
0005435518130	21992	Economy	21000.00
0005432925144	21992	Economy	19100.00
0005435518133	21992	Economy	19100.00
0005433517030	21992	Economy	19100.00
0005435518094	21992	Economy	19100.00
0005435518144	21992	Economy	19100.00
0005435541191	21992	Economy	19100.00
0005433517016	21992	Economy	19100.00
0005435541221	21992	Economy	19100.00
0005435541286	21992	Economy	19100.00
0005432925143	21992	Economy	19100.00
0005435541195	21992	Economy	19100.00
0005433517012	21992	Economy	19100.00
0005435541299	21992	Economy	19100.00
0005433516992	21992	Economy	19100.00
0005435518173	21992	Economy	19100.00
0005435518124	21992	Economy	19100.00
0005435541266	21992	Economy	19100.00
0005435541220	21992	Economy	19100.00
0005435541224	21992	Economy	19100.00
0005435518151	21992	Economy	19100.00
0005435518036	21992	Economy	19100.00
0005435541313	21992	Economy	19100.00
0005435541223	21992	Economy	19100.00
0005435518185	21992	Economy	19100.00
0005433517013	21992	Economy	19100.00
0005432925140	21992	Economy	19100.00
0005433517014	21992	Economy	19100.00
0005433517015	21992	Economy	19100.00
0005432925138	21992	Economy	19100.00
0005432925139	21992	Economy	19100.00
0005432073465	7359	Business	18500.00
0005432839718	7359	Business	18500.00
0005434459263	7359	Business	18500.00
0005432839701	7359	Business	18500.00
0005432839714	7359	Business	18500.00
0005432823493	7359	Business	18500.00
0005432839693	7359	Business	18500.00
0005432839692	7359	Business	18500.00
0005434459253	7359	Economy	6200.00
0005434459248	7359	Economy	6200.00
0005432839702	7359	Economy	6200.00
0005432839712	7359	Economy	6200.00
0005432839696	7359	Economy	6200.00
0005432839709	7359	Economy	6200.00
0005434459256	7359	Economy	6200.00
0005435252897	7359	Economy	6200.00
0005432839719	7359	Economy	6800.00
0005432073464	7359	Economy	6800.00
0005435252918	7359	Economy	6800.00
0005432839715	7359	Economy	6800.00
0005432073467	7359	Economy	6200.00
0005432839695	7359	Economy	6200.00
0005434459246	7359	Economy	6200.00
0005434664976	7359	Economy	6200.00
0005435252899	7359	Economy	6200.00
0005434459252	7359	Economy	6200.00
0005435252928	7359	Economy	6200.00
0005434459261	7359	Economy	6200.00
0005432839691	7359	Economy	6200.00
0005432839706	7359	Economy	6200.00
0005432839713	7359	Economy	6200.00
0005432839694	7359	Economy	6200.00
0005434459247	7359	Economy	6200.00
0005435252929	7359	Economy	6200.00
0005434459251	7359	Economy	6200.00
0005432839710	7359	Economy	6200.00
0005432839699	7359	Economy	6200.00
0005432839711	7359	Economy	6200.00
0005432839703	7359	Economy	6200.00
0005434459259	7359	Economy	6200.00
0005435252920	7359	Economy	6200.00
0005434459257	7359	Economy	6200.00
0005434459245	7359	Economy	6200.00
0005432823491	7359	Economy	6200.00
0005432823494	7359	Economy	6200.00
0005434459244	7359	Economy	6200.00
0005434459260	7359	Economy	6200.00
0005432073466	7359	Economy	6200.00
0005435491462	7359	Economy	6200.00
0005435252919	7359	Economy	6200.00
0005432839708	7359	Economy	6200.00
0005432839717	7359	Economy	6200.00
0005432839700	7359	Economy	6200.00
0005435252945	7359	Economy	6200.00
0005434459243	7359	Economy	6200.00
0005432839705	7359	Economy	6200.00
0005435252951	7359	Economy	6200.00
0005435252872	7359	Economy	6200.00
0005434459258	7359	Economy	6200.00
0005434459254	7359	Economy	6200.00
0005435252986	7359	Economy	6200.00
0005432839716	7359	Economy	6200.00
0005434459262	7359	Economy	6200.00
0005434459249	7359	Economy	6200.00
0005435252871	7359	Economy	6200.00
0005432839704	7359	Economy	6200.00
0005432839697	7359	Economy	6200.00
0005434459250	7359	Economy	6200.00
0005432841057	7359	Economy	6200.00
0005432839720	7359	Economy	6200.00
0005432839707	7359	Economy	6200.00
0005435252861	7359	Economy	6200.00
0005432839721	7359	Economy	6200.00
0005435252946	7359	Economy	6200.00
0005432823492	7359	Economy	6200.00
0005434459255	7359	Economy	6200.00
0005432839698	7359	Economy	6200.00
0005434664989	7359	Economy	6200.00
0005432841056	7359	Economy	6200.00
0005435252886	7359	Economy	6200.00
0005434459102	28914	Business	18500.00
0005434458966	28914	Business	18500.00
0005435253090	28914	Business	18500.00
0005434459088	28914	Business	18500.00
0005432839458	28914	Business	18500.00
0005434459007	28914	Business	18500.00
0005435253083	28914	Business	18500.00
0005432001067	28914	Economy	6200.00
0005434459043	28914	Economy	6200.00
0005434458968	28914	Economy	6200.00
0005434458967	28914	Economy	6200.00
0005434459107	28914	Economy	6200.00
0005432839283	28914	Economy	6800.00
0005435253081	28914	Economy	6800.00
0005435253085	28914	Economy	6800.00
0005432839332	28914	Economy	6800.00
0005434459037	28914	Economy	6200.00
0005434459124	28914	Economy	6200.00
0005432839506	28914	Economy	6200.00
0005432839485	28914	Economy	6200.00
0005432839431	28914	Economy	6200.00
0005435491489	28914	Economy	6200.00
0005435253097	28914	Economy	6200.00
0005434459076	28914	Economy	6200.00
0005435253086	28914	Economy	6200.00
0005432839517	28914	Economy	6200.00
0005432839542	28914	Economy	6200.00
0005434459045	28914	Economy	6200.00
0005435253094	28914	Economy	6200.00
0005435253093	28914	Economy	6200.00
0005432839457	28914	Economy	6200.00
0005432839449	28914	Economy	6200.00
0005435253092	28914	Economy	6200.00
0005432839516	28914	Economy	6200.00
0005432839586	28914	Economy	6200.00
0005434459044	28914	Economy	6200.00
0005432841040	28914	Economy	6200.00
0005432839411	28914	Economy	6200.00
0005432839450	28914	Economy	6200.00
0005434459091	28914	Economy	6200.00
0005435253087	28914	Economy	6200.00
0005435253096	28914	Economy	6200.00
0005432839603	28914	Economy	6200.00
0005434459016	28914	Economy	6200.00
0005434459038	28914	Economy	6200.00
0005435491488	28914	Economy	6200.00
0005434459075	28914	Economy	6200.00
0005432841043	28914	Economy	6200.00
0005432841044	28914	Economy	6200.00
0005435253091	28914	Economy	6200.00
0005434459126	28914	Economy	6200.00
0005432839459	28914	Economy	6200.00
0005432001068	28914	Economy	6200.00
0005432839557	28914	Economy	6200.00
0005435253080	28914	Economy	6200.00
0005434459077	28914	Economy	6200.00
0005432823474	28914	Economy	6200.00
0005435253089	28914	Economy	6200.00
0005435253084	28914	Economy	6200.00
0005432839424	28914	Economy	6200.00
0005435253088	28914	Economy	6200.00
0005432839397	28914	Economy	6200.00
0005435253095	28914	Economy	6200.00
0005432839484	28914	Economy	6200.00
0005434459125	28914	Economy	6200.00
0005435253082	28914	Economy	6200.00
0005434665010	28914	Economy	6200.00
0005432823475	28914	Economy	6200.00
0005432823477	28914	Economy	6200.00
0005432839515	28914	Economy	6200.00
0005435990774	8775	Business	145300.00
0005435990776	8775	Business	145300.00
0005434276117	8775	Economy	48400.00
0005434276093	8775	Economy	48400.00
0005434276102	8775	Economy	48400.00
0005434276109	8775	Economy	48400.00
0005435990779	8775	Economy	48400.00
0005434276119	8775	Economy	48400.00
0005435990780	8775	Economy	48400.00
0005434276100	8775	Economy	48400.00
0005435990777	8775	Economy	48400.00
0005435990775	8775	Economy	48400.00
0005434276118	8775	Economy	48400.00
0005434276096	8775	Economy	48400.00
0005435990778	8775	Economy	48400.00
0005434276087	8775	Economy	48400.00
0005434276151	15761	Business	145300.00
0005434276153	15761	Business	145300.00
0005435990725	15761	Business	145300.00
0005434276150	15761	Economy	48400.00
0005434276152	15761	Economy	48400.00
0005434276155	15761	Economy	48400.00
0005435990708	15761	Economy	48400.00
0005435990738	15761	Economy	48400.00
0005434276154	15761	Economy	48400.00
0005435990726	15761	Economy	48400.00
0005434276149	15761	Economy	48400.00
0005432427188	20628	Economy	14500.00
0005432427189	20628	Economy	14500.00
0005432427187	20628	Economy	14500.00
0005435177560	6382	Business	36600.00
0005432361396	6382	Business	36600.00
0005434149890	6382	Business	36600.00
0005432062345	6382	Business	36600.00
0005435177499	6382	Business	36600.00
0005434149935	6382	Business	36600.00
0005432361389	6382	Business	36600.00
0005434149858	6382	Business	36600.00
0005435177561	6382	Business	36600.00
0005432363486	6382	Business	36600.00
0005435177483	6382	Business	36600.00
0005435177482	6382	Business	36600.00
0005434149875	6382	Economy	12200.00
0005432336295	6382	Economy	12200.00
0005435177486	6382	Economy	12200.00
0005432336296	6382	Economy	12200.00
0005432361390	6382	Economy	12200.00
0005432361382	6382	Economy	12200.00
0005432361406	6382	Economy	12200.00
0005435177442	6382	Economy	12200.00
0005432336288	6382	Economy	12200.00
0005432361392	6382	Economy	12200.00
0005432361393	6382	Economy	12200.00
0005434149895	6382	Economy	12200.00
0005435177551	6382	Economy	12200.00
0005434149877	6382	Economy	12200.00
0005435490273	6382	Economy	12200.00
0005432361400	6382	Economy	12200.00
0005435177475	6382	Economy	12200.00
0005432336289	6382	Economy	12200.00
0005432361377	6382	Economy	12200.00
0005435177404	6382	Economy	12200.00
0005432361387	6382	Economy	12200.00
0005432361419	6382	Economy	12200.00
0005432361378	6382	Economy	12200.00
0005432361398	6382	Economy	12200.00
0005432361412	6382	Economy	12200.00
0005435177481	6382	Economy	12200.00
0005432363485	6382	Economy	12200.00
0005432361376	6382	Economy	12200.00
0005435177428	6382	Economy	12200.00
0005432361411	6382	Economy	12200.00
0005435177493	6382	Economy	12200.00
0005432361386	6382	Economy	12200.00
0005432361380	6382	Economy	12200.00
0005432361395	6382	Economy	12200.00
0005432361379	6382	Economy	12200.00
0005435177429	6382	Economy	12200.00
0005432361413	6382	Economy	12200.00
0005432361403	6382	Economy	12200.00
0005435177520	6382	Economy	13400.00
0005432336291	6382	Economy	13400.00
0005432361418	6382	Economy	13400.00
0005434149903	6382	Economy	13400.00
0005432336286	6382	Economy	13400.00
0005435177512	6382	Economy	13400.00
0005432361420	6382	Economy	12200.00
0005434149897	6382	Economy	12200.00
0005432361408	6382	Economy	12200.00
0005432336287	6382	Economy	12200.00
0005435490274	6382	Economy	12200.00
0005435177554	6382	Economy	12200.00
0005432361409	6382	Economy	12200.00
0005432361414	6382	Economy	12200.00
0005432361385	6382	Economy	12200.00
0005432336293	6382	Economy	12200.00
0005435177558	6382	Economy	12200.00
0005435177492	6382	Economy	12200.00
0005432361383	6382	Economy	12200.00
0005432361417	6382	Economy	12200.00
0005435177487	6382	Economy	12200.00
0005432361394	6382	Economy	12200.00
0005435177436	6382	Economy	12200.00
0005432361375	6382	Economy	12200.00
0005432361415	6382	Economy	12200.00
0005434149871	6382	Economy	12200.00
0005432361421	6382	Economy	12200.00
0005432361381	6382	Economy	12200.00
0005435177418	6382	Economy	12200.00
0005432361405	6382	Economy	12200.00
0005434149915	6382	Economy	12200.00
0005435177441	6382	Economy	12200.00
0005434149916	6382	Economy	12200.00
0005434149872	6382	Economy	12200.00
0005434149896	6382	Economy	12200.00
0005432361407	6382	Economy	12200.00
0005435177519	6382	Economy	12200.00
0005432361401	6382	Economy	12200.00
0005432361388	6382	Economy	12200.00
0005432336290	6382	Economy	12200.00
0005435177290	6382	Economy	12200.00
0005435723074	6382	Economy	12200.00
0005432062342	6382	Economy	12200.00
0005432361423	6382	Economy	12200.00
0005435723067	6382	Economy	12200.00
0005432062344	6382	Economy	12200.00
0005435177405	6382	Economy	12200.00
0005435177518	6382	Economy	12200.00
0005435177409	6382	Economy	12200.00
0005435177550	6382	Economy	12200.00
0005432361397	6382	Economy	12200.00
0005435177419	6382	Economy	12200.00
0005432336292	6382	Economy	12200.00
0005432336294	6382	Economy	12200.00
0005434149917	6382	Economy	12200.00
0005432361424	6382	Economy	12200.00
0005432062346	6382	Economy	12200.00
0005432361410	6382	Economy	12200.00
0005432361391	6382	Economy	12200.00
0005432336285	6382	Economy	12200.00
0005435177484	6382	Economy	12200.00
0005434149904	6382	Economy	12200.00
0005432361422	6382	Economy	12200.00
0005432062343	6382	Economy	12200.00
0005435177305	6382	Economy	12200.00
0005432361399	6382	Economy	12200.00
0005434149836	6382	Economy	12200.00
0005435177555	6382	Economy	12200.00
0005432336297	6382	Economy	12200.00
0005432363487	6382	Economy	12200.00
0005432361384	6382	Economy	12200.00
0005432361404	6382	Economy	12200.00
0005434149841	6382	Economy	12200.00
0005435177443	6382	Economy	12200.00
0005432361425	6382	Economy	12200.00
0005432361416	6382	Economy	12200.00
0005432361402	6382	Economy	12200.00
0005432360956	21005	Business	36600.00
0005432336150	21005	Business	36600.00
0005432361049	21005	Business	36600.00
0005432360964	21005	Business	36600.00
0005432360763	21005	Business	36600.00
0005432360839	21005	Business	36600.00
0005432361057	21005	Business	36600.00
0005435177682	21005	Business	36600.00
0005435177680	21005	Business	36600.00
0005432361078	21005	Business	36600.00
0005432360943	21005	Business	36600.00
0005432361074	21005	Business	36600.00
0005435177667	21005	Economy	12200.00
0005434149988	21005	Economy	12200.00
0005435177669	21005	Economy	12200.00
0005435177673	21005	Economy	12200.00
0005432361076	21005	Economy	12200.00
0005432360861	21005	Economy	12200.00
0005435177661	21005	Economy	12200.00
0005432336151	21005	Economy	12200.00
0005435177659	21005	Economy	12200.00
0005432361042	21005	Economy	12200.00
0005432360942	21005	Economy	12200.00
0005432361051	21005	Economy	12200.00
0005435177676	21005	Economy	12200.00
0005432360918	21005	Economy	12200.00
0005435177664	21005	Economy	12200.00
0005432361112	21005	Economy	12200.00
0005435177665	21005	Economy	12200.00
0005435177655	21005	Economy	12200.00
0005432361073	21005	Economy	12200.00
0005432336141	21005	Economy	12200.00
0005435490311	21005	Economy	12200.00
0005435177677	21005	Economy	12200.00
0005432361079	21005	Economy	12200.00
0005432360936	21005	Economy	12200.00
0005435490309	21005	Economy	12200.00
0005435177675	21005	Economy	12200.00
0005435177658	21005	Economy	12200.00
0005432360645	21005	Economy	12200.00
0005435177683	21005	Economy	12200.00
0005432360967	21005	Economy	12200.00
0005435177681	21005	Economy	12200.00
0005435177657	21005	Economy	12200.00
0005435177660	21005	Economy	12200.00
0005432360844	21005	Economy	12200.00
0005432360991	21005	Economy	12200.00
0005435177678	21005	Economy	12200.00
0005432336158	21005	Economy	12200.00
0005434149984	21005	Economy	12200.00
0005432361016	21005	Economy	12200.00
0005435177663	21005	Economy	13400.00
0005434149991	21005	Economy	12200.00
0005434149986	21005	Economy	13400.00
0005432360959	21005	Economy	13400.00
0005435177674	21005	Economy	13400.00
0005432361026	21005	Economy	13400.00
0005435177656	21005	Economy	13400.00
0005432361137	21005	Economy	12200.00
0005435490310	21005	Economy	12200.00
0005432336163	21005	Economy	12200.00
0005435177670	21005	Economy	12200.00
0005432336165	21005	Economy	12200.00
0005432360972	21005	Economy	12200.00
0005434149983	21005	Economy	12200.00
0005432360914	21005	Economy	12200.00
0005432360970	21005	Economy	12200.00
0005432052813	21005	Economy	12200.00
0005432360762	21005	Economy	12200.00
0005432360962	21005	Economy	12200.00
0005435177672	21005	Economy	12200.00
0005432360919	21005	Economy	12200.00
0005432361027	21005	Economy	12200.00
0005435723087	21005	Economy	12200.00
0005432361059	21005	Economy	12200.00
0005432361077	21005	Economy	12200.00
0005434149990	21005	Economy	12200.00
0005435177662	21005	Economy	12200.00
0005432052811	21005	Economy	12200.00
0005434149985	21005	Economy	12200.00
0005432360930	21005	Economy	12200.00
0005432360992	21005	Economy	12200.00
0005434149978	21005	Economy	12200.00
0005434149992	21005	Economy	12200.00
0005432052812	21005	Economy	12200.00
0005434149980	21005	Economy	12200.00
0005435177671	21005	Economy	12200.00
0005432360960	21005	Economy	12200.00
0005432361050	21005	Economy	12200.00
0005432361168	21005	Economy	12200.00
0005432336180	21005	Economy	12200.00
0005432360768	21005	Economy	12200.00
0005432336186	21005	Economy	12200.00
0005435177679	21005	Economy	12200.00
0005432052814	21005	Economy	12200.00
0005434149979	21005	Economy	12200.00
0005432360838	21005	Economy	12200.00
0005432361041	21005	Economy	12200.00
0005432363472	21005	Economy	12200.00
0005432363452	21005	Economy	12200.00
0005435177666	21005	Economy	12200.00
0005432360981	21005	Economy	12200.00
0005432361096	21005	Economy	12200.00
0005434149989	21005	Economy	12200.00
0005432361072	21005	Economy	12200.00
0005435490312	21005	Economy	12200.00
0005432360913	21005	Economy	12200.00
0005432360969	21005	Economy	12200.00
0005432361126	21005	Economy	12200.00
0005432360767	21005	Economy	12200.00
0005432336177	21005	Economy	12200.00
0005434149982	21005	Economy	12200.00
0005435177668	21005	Economy	12200.00
0005432361014	21005	Economy	12200.00
0005435723086	21005	Economy	12200.00
0005434149981	21005	Economy	12200.00
0005432360858	21005	Economy	12200.00
0005434149987	21005	Economy	12200.00
0005432336181	21005	Economy	12200.00
0005434459089	17685	Economy	3400.00
0005434459074	17685	Economy	3400.00
0005434459072	17685	Economy	3400.00
0005434459144	17685	Economy	3100.00
0005434459065	17685	Economy	3100.00
0005434459143	17685	Economy	3100.00
0005434459064	17685	Economy	3100.00
0005434186261	17685	Economy	3100.00
0005434448363	17685	Economy	3100.00
0005434459160	17685	Economy	3100.00
0005434459123	17685	Economy	3100.00
0005434186263	17685	Economy	3100.00
0005434459118	17685	Economy	3100.00
0005434459059	17685	Economy	3100.00
0005434448371	17685	Economy	3100.00
0005434461673	17685	Economy	3100.00
0005434459073	17685	Economy	3100.00
0005434459036	17685	Economy	3100.00
0005434459035	17685	Economy	3100.00
0005434459058	17685	Economy	3100.00
0005434458951	17685	Economy	3100.00
0005434459011	17685	Economy	3100.00
0005434459197	17685	Economy	3100.00
0005434448367	17685	Economy	3100.00
0005434459071	17685	Economy	3100.00
0005434459090	17685	Economy	3100.00
0005434461672	17685	Economy	3100.00
0005434459119	17685	Economy	3100.00
0005434186262	17685	Economy	3100.00
0005434459063	17685	Economy	3100.00
0005434459151	17685	Economy	3100.00
0005434461680	17685	Economy	3100.00
0005434448366	17685	Economy	3100.00
0005434186264	17685	Economy	3100.00
0005434459012	17685	Economy	3100.00
0005434459161	17685	Economy	3100.00
0005434459034	17685	Economy	3100.00
0005434461679	17685	Economy	3100.00
0005434459257	29091	Economy	3400.00
0005434459256	29091	Economy	3400.00
0005434459254	29091	Economy	3400.00
0005434459244	29091	Economy	3400.00
0005434462834	29091	Economy	3100.00
0005434459263	29091	Economy	3100.00
0005434459261	29091	Economy	3100.00
0005434459245	29091	Economy	3100.00
0005434459243	29091	Economy	3100.00
0005434459260	29091	Economy	3100.00
0005434448384	29091	Economy	3100.00
0005434459262	29091	Economy	3100.00
0005434459258	29091	Economy	3100.00
0005434459246	29091	Economy	3100.00
0005434448387	29091	Economy	3100.00
0005434448386	29091	Economy	3100.00
0005434459255	29091	Economy	3100.00
0005434459250	29091	Economy	3100.00
0005434459252	29091	Economy	3100.00
0005434459253	29091	Economy	3100.00
0005434448385	29091	Economy	3100.00
0005434462835	29091	Economy	3100.00
0005434459248	29091	Economy	3100.00
0005434459259	29091	Economy	3100.00
0005434459249	29091	Economy	3100.00
0005434459247	29091	Economy	3100.00
0005434459251	29091	Economy	3100.00
0005434463974	29091	Economy	3100.00
0005432605154	21435	Economy	7300.00
0005432605152	21435	Economy	7300.00
0005432605165	21435	Economy	7300.00
0005432605150	21435	Economy	6600.00
0005432605169	21435	Economy	6600.00
0005432605159	21435	Economy	6600.00
0005432605170	21435	Economy	6600.00
0005432605177	21435	Economy	6600.00
0005432605179	21435	Economy	6600.00
0005432605149	21435	Economy	6600.00
0005432605171	21435	Economy	6600.00
0005432605147	21435	Economy	6600.00
0005432605161	21435	Economy	6600.00
0005432605162	21435	Economy	6600.00
0005432605164	21435	Economy	6600.00
0005432605143	21435	Economy	6600.00
0005432605167	21435	Economy	6600.00
0005432605176	21435	Economy	6600.00
0005432605172	21435	Economy	6600.00
0005432605175	21435	Economy	6600.00
0005432605180	21435	Economy	6600.00
0005432605173	21435	Economy	6600.00
0005432605183	21435	Economy	6600.00
0005432605178	21435	Economy	6600.00
0005432605145	21435	Economy	6600.00
0005432605160	21435	Economy	6600.00
0005432605182	21435	Economy	6600.00
0005432605155	21435	Economy	6600.00
0005432605146	21435	Economy	6600.00
0005432605148	21435	Economy	6600.00
0005432605181	21435	Economy	6600.00
0005432605157	21435	Economy	6600.00
0005432605158	21435	Economy	6600.00
0005432605144	21435	Economy	6600.00
0005432605151	21435	Economy	6600.00
0005432605156	21435	Economy	6600.00
0005432605174	21435	Economy	6600.00
0005432605163	21435	Economy	6600.00
0005432605166	21435	Economy	6600.00
0005432605168	21435	Economy	6600.00
0005432605153	21435	Economy	6600.00
0005435221073	31668	Economy	7300.00
0005432604893	31668	Economy	7300.00
0005432604898	31668	Economy	7300.00
0005432604768	31668	Economy	7300.00
0005432604934	31668	Economy	6600.00
0005432604838	31668	Economy	6600.00
0005432604836	31668	Economy	6600.00
0005432604734	31668	Economy	6600.00
0005432604902	31668	Economy	6600.00
0005432604798	31668	Economy	6600.00
0005432604594	31668	Economy	6600.00
0005432604627	31668	Economy	6600.00
0005432604670	31668	Economy	6600.00
0005432604667	31668	Economy	6600.00
0005432604697	31668	Economy	6600.00
0005432604804	31668	Economy	6600.00
0005432604837	31668	Economy	6600.00
0005432604899	31668	Economy	6600.00
0005435221530	31668	Economy	6600.00
0005432604769	31668	Economy	6600.00
0005432604906	31668	Economy	6600.00
0005432604653	31668	Economy	6600.00
0005432604810	31668	Economy	6600.00
0005432604723	31668	Economy	6600.00
0005432604696	31668	Economy	6600.00
0005432604671	31668	Economy	6600.00
0005435221074	31668	Economy	6600.00
0005432604935	31668	Economy	6600.00
0005432604873	31668	Economy	6600.00
0005435221550	31668	Economy	6600.00
0005432604800	31668	Economy	6600.00
0005432604874	31668	Economy	6600.00
0005435221072	31668	Economy	6600.00
0005432604960	31668	Economy	6600.00
0005432604757	31668	Economy	6600.00
0005432604939	31668	Economy	6600.00
0005435221531	31668	Economy	6600.00
0005432604881	31668	Economy	6600.00
0005432604799	31668	Economy	6600.00
0005432604938	31668	Economy	6600.00
0005435154642	12309	Economy	19500.00
0005433293320	12309	Economy	19500.00
0005435154640	12309	Economy	17800.00
0005433293286	12309	Economy	17800.00
0005433293319	12309	Economy	17800.00
0005435154638	12309	Economy	17800.00
0005435154637	12309	Economy	17800.00
0005435154639	12309	Economy	17800.00
0005433293343	12309	Economy	17800.00
0005433293313	12309	Economy	17800.00
0005435154643	12309	Economy	17800.00
0005435154641	12309	Economy	17800.00
0005433293318	12309	Economy	17800.00
0005433293344	12309	Economy	17800.00
0005435154645	12309	Economy	17800.00
0005433293312	12309	Economy	17800.00
0005435154644	12309	Economy	17800.00
0005435154647	12309	Economy	17800.00
0005433293265	12309	Economy	17800.00
0005433293321	12309	Economy	17800.00
0005435154646	12309	Economy	17800.00
0005435904901	22387	Economy	6600.00
0005434606895	22387	Economy	6600.00
0005434604973	22387	Economy	6600.00
0005434606898	22387	Economy	6600.00
0005435904900	22387	Economy	6600.00
0005434606896	22387	Economy	6600.00
0005435904903	22387	Economy	6600.00
0005435904902	22387	Economy	6600.00
0005434604972	22387	Economy	6600.00
0005434606897	22387	Economy	6600.00
0005432891325	393	Business	44500.00
0005432748371	393	Business	44500.00
0005432748393	393	Business	44500.00
0005432891306	393	Business	44500.00
0005432891380	393	Business	44500.00
0005432748388	393	Business	44500.00
0005432748377	393	Business	44500.00
0005432748386	393	Business	44500.00
0005432891215	393	Business	44500.00
0005432891323	393	Business	44500.00
0005432891283	393	Business	44500.00
0005432748380	393	Economy	14800.00
0005435154652	393	Economy	14800.00
0005432753370	393	Economy	14800.00
0005433293329	393	Economy	14800.00
0005433293323	393	Economy	14800.00
0005432891281	393	Economy	14800.00
0005435154651	393	Economy	14800.00
0005432748390	393	Economy	14800.00
0005433293328	393	Economy	14800.00
0005432748365	393	Economy	16300.00
0005432220093	393	Economy	16300.00
0005432748401	393	Economy	16300.00
0005433293314	393	Economy	16300.00
0005433293332	393	Economy	16300.00
0005432220095	393	Economy	14800.00
0005435154649	393	Economy	14800.00
0005432748396	393	Economy	14800.00
0005432891324	393	Economy	14800.00
0005435154655	393	Economy	14800.00
0005432748372	393	Economy	14800.00
0005432748387	393	Economy	14800.00
0005433293317	393	Economy	14800.00
0005433293330	393	Economy	14800.00
0005432749831	393	Economy	14800.00
0005432891209	393	Economy	14800.00
0005433293316	393	Economy	14800.00
0005432891132	393	Economy	14800.00
0005432748366	393	Economy	14800.00
0005432891224	393	Economy	14800.00
0005432748383	393	Economy	14800.00
0005432753371	393	Economy	14800.00
0005432220094	393	Economy	14800.00
0005432891264	393	Economy	14800.00
0005432891263	393	Economy	14800.00
0005432748384	393	Economy	14800.00
0005432748369	393	Economy	14800.00
0005432748399	393	Economy	14800.00
0005432891381	393	Economy	14800.00
0005432748376	393	Economy	14800.00
0005432748367	393	Economy	14800.00
0005432891298	393	Economy	14800.00
0005433293315	393	Economy	14800.00
0005432748382	393	Economy	14800.00
0005432748364	393	Economy	14800.00
0005432748385	393	Economy	14800.00
0005432748392	393	Economy	14800.00
0005435154648	393	Economy	14800.00
0005432891282	393	Economy	14800.00
0005432748374	393	Economy	14800.00
0005432748394	393	Economy	14800.00
0005432891299	393	Economy	14800.00
0005432748395	393	Economy	14800.00
0005432748379	393	Economy	14800.00
0005432748370	393	Economy	14800.00
0005432748373	393	Economy	14800.00
0005432891269	393	Economy	14800.00
0005432748389	393	Economy	14800.00
0005432751595	393	Economy	14800.00
0005432748375	393	Economy	14800.00
0005432748368	393	Economy	14800.00
0005432748402	393	Economy	14800.00
0005432891219	393	Economy	14800.00
0005432891197	393	Economy	14800.00
0005432748400	393	Economy	14800.00
0005432891277	393	Economy	14800.00
0005433293331	393	Economy	14800.00
0005435154654	393	Economy	14800.00
0005432749830	393	Economy	14800.00
0005432748381	393	Economy	14800.00
0005432891225	393	Economy	14800.00
0005435154653	393	Economy	14800.00
0005435154656	393	Economy	14800.00
0005432891279	393	Economy	14800.00
0005435154650	393	Economy	14800.00
0005432751596	393	Economy	14800.00
0005432220096	393	Economy	14800.00
0005432748397	393	Economy	14800.00
0005433293322	393	Economy	14800.00
0005432748391	393	Economy	14800.00
0005432748398	393	Economy	14800.00
0005432748378	393	Economy	14800.00
0005432891434	12056	Business	44500.00
0005432748083	12056	Business	44500.00
0005432748099	12056	Business	44500.00
0005432891439	12056	Business	44500.00
0005432891438	12056	Business	44500.00
0005433875415	12056	Business	44500.00
0005433293376	12056	Business	44500.00
0005432748094	12056	Business	44500.00
0005432748143	12056	Business	44500.00
0005435154603	12056	Business	44500.00
0005432756885	12056	Business	44500.00
0005432748281	12056	Economy	14800.00
0005433293379	12056	Economy	14800.00
0005432891445	12056	Economy	14800.00
0005432753349	12056	Economy	14800.00
0005432748033	12056	Economy	14800.00
0005432747945	12056	Economy	14800.00
0005433293382	12056	Economy	14800.00
0005432747962	12056	Economy	14800.00
0005432747998	12056	Economy	14800.00
0005432891437	12056	Economy	14800.00
0005432748108	12056	Economy	16300.00
0005432748116	12056	Economy	16300.00
0005432891441	12056	Economy	16300.00
0005432747935	12056	Economy	16300.00
0005432891443	12056	Economy	16300.00
0005432748046	12056	Economy	14800.00
0005435154605	12056	Economy	14800.00
0005432749822	12056	Economy	14800.00
0005432891449	12056	Economy	14800.00
0005432891448	12056	Economy	14800.00
0005432748032	12056	Economy	14800.00
0005432748090	12056	Economy	14800.00
0005432748082	12056	Economy	14800.00
0005432748101	12056	Economy	14800.00
0005432891447	12056	Economy	14800.00
0005434153562	12056	Economy	14800.00
0005432891436	12056	Economy	14800.00
0005432214849	12056	Economy	14800.00
0005432748068	12056	Economy	14800.00
0005432748081	12056	Economy	14800.00
0005432748016	12056	Economy	14800.00
0005432748045	12056	Economy	14800.00
0005432749821	12056	Economy	14800.00
0005432748069	12056	Economy	14800.00
0005435154604	12056	Economy	14800.00
0005432891450	12056	Economy	14800.00
0005432747985	12056	Economy	14800.00
0005432891433	12056	Economy	14800.00
0005432748017	12056	Economy	14800.00
0005432748095	12056	Economy	14800.00
0005432891440	12056	Economy	14800.00
0005433293374	12056	Economy	14800.00
0005433293373	12056	Economy	14800.00
0005432747974	12056	Economy	14800.00
0005432748282	12056	Economy	14800.00
0005432747994	12056	Economy	14800.00
0005432748135	12056	Economy	14800.00
0005432891431	12056	Economy	14800.00
0005432756890	12056	Economy	14800.00
0005432748102	12056	Economy	14800.00
0005432747932	12056	Economy	14800.00
0005433293375	12056	Economy	14800.00
0005432748028	12056	Economy	14800.00
0005432756884	12056	Economy	14800.00
0005432891446	12056	Economy	14800.00
0005432748003	12056	Economy	14800.00
0005433293384	12056	Economy	14800.00
0005432891432	12056	Economy	14800.00
0005433293377	12056	Economy	14800.00
0005433293371	12056	Economy	14800.00
0005434153563	12056	Economy	14800.00
0005432748035	12056	Economy	14800.00
0005433293383	12056	Economy	14800.00
0005432748142	12056	Economy	14800.00
0005433293381	12056	Economy	14800.00
0005432891442	12056	Economy	14800.00
0005433875416	12056	Economy	14800.00
0005432749815	12056	Economy	14800.00
0005432891435	12056	Economy	14800.00
0005434153561	12056	Economy	14800.00
0005432748021	12056	Economy	14800.00
0005433293372	12056	Economy	14800.00
0005432214850	12056	Economy	14800.00
0005433293380	12056	Economy	14800.00
0005432756891	12056	Economy	14800.00
0005432214851	12056	Economy	14800.00
0005432747963	12056	Economy	14800.00
0005432748009	12056	Economy	14800.00
0005432891444	12056	Economy	14800.00
0005433293378	12056	Economy	14800.00
0005432748109	12056	Economy	14800.00
0005433525265	18994	Economy	28200.00
0005432928039	18994	Economy	28200.00
0005433525267	18994	Economy	28200.00
0005432928036	18994	Economy	25700.00
0005433525268	18994	Economy	25700.00
0005433531371	18994	Economy	25700.00
0005433525262	18994	Economy	25700.00
0005433525261	18994	Economy	25700.00
0005433531370	18994	Economy	25700.00
0005433533386	18994	Economy	25700.00
0005433533385	18994	Economy	25700.00
0005433525264	18994	Economy	25700.00
0005433533384	18994	Economy	25700.00
0005433531372	18994	Economy	25700.00
0005433533387	18994	Economy	25700.00
0005433525263	18994	Economy	25700.00
0005433525269	18994	Economy	25700.00
0005432928038	18994	Economy	25700.00
0005433531369	18994	Economy	25700.00
0005432928065	18994	Economy	25700.00
0005433525266	18994	Economy	25700.00
0005432928064	18994	Economy	25700.00
0005432928052	18994	Economy	25700.00
0005432928067	18994	Economy	25700.00
0005432928066	18994	Economy	25700.00
0005432928031	18994	Economy	25700.00
0005432928104	32505	Economy	25700.00
0005432928107	32505	Economy	25700.00
0005433525160	32505	Economy	25700.00
0005432928106	32505	Economy	25700.00
0005432928109	32505	Economy	25700.00
0005433531349	32505	Economy	25700.00
0005433525195	32505	Economy	25700.00
0005433525162	32505	Economy	25700.00
0005433527312	32505	Economy	25700.00
0005433531331	32505	Economy	25700.00
0005433527318	32505	Economy	25700.00
0005433527317	32505	Economy	25700.00
0005432928105	32505	Economy	25700.00
0005433531327	32505	Economy	25700.00
0005432928108	32505	Economy	25700.00
0005433525196	32505	Economy	25700.00
0005433525161	32505	Economy	25700.00
0005435374198	5280	Business	84000.00
0005434826293	5280	Business	84000.00
0005435304214	5280	Business	84000.00
0005434826316	5280	Business	84000.00
0005434826368	5280	Business	84000.00
0005435374050	5280	Business	84000.00
0005434826346	5280	Business	84000.00
0005434826353	5280	Business	84000.00
0005435735187	5280	Business	84000.00
0005434826298	5280	Business	84000.00
0005435374332	5280	Business	84000.00
0005434826271	5280	Business	84000.00
0005435150337	5280	Business	84000.00
0005434826280	5280	Business	84000.00
0005435386631	5280	Business	84000.00
0005435304213	5280	Business	84000.00
0005435374399	5280	Business	84000.00
0005434826367	5280	Business	84000.00
0005434828755	5280	Business	84000.00
0005435150336	5280	Business	84000.00
0005434826265	5280	Business	84000.00
0005434826286	5280	Business	84000.00
0005434826275	5280	Comfort	47600.00
0005435374190	5280	Comfort	47600.00
0005432121642	5280	Comfort	47600.00
0005435373972	5280	Comfort	47600.00
0005434831249	5280	Comfort	47600.00
0005435373945	5280	Comfort	47600.00
0005435374259	5280	Comfort	47600.00
0005435150332	5280	Comfort	47600.00
0005435374049	5280	Comfort	47600.00
0005434826297	5280	Comfort	47600.00
0005434826291	5280	Comfort	47600.00
0005434826272	5280	Comfort	47600.00
0005434665008	5280	Comfort	47600.00
0005435661949	5280	Comfort	47600.00
0005434826362	5280	Comfort	47600.00
0005432396328	5280	Comfort	47600.00
0005435374164	5280	Comfort	47600.00
0005435373987	5280	Comfort	47600.00
0005435373954	5280	Comfort	47600.00
0005434826340	5280	Comfort	47600.00
0005434826334	5280	Comfort	47600.00
0005435150331	5280	Comfort	47600.00
0005435374393	5280	Comfort	47600.00
0005434826344	5280	Comfort	47600.00
0005435374127	5280	Comfort	47600.00
0005435150335	5280	Comfort	47600.00
0005435374068	5280	Comfort	47600.00
0005434831248	5280	Comfort	47600.00
0005435373980	5280	Comfort	47600.00
0005435735190	5280	Comfort	47600.00
0005435373842	5280	Comfort	47600.00
0005434826358	5280	Comfort	47600.00
0005434826332	5280	Comfort	47600.00
0005434826337	5280	Comfort	47600.00
0005435373946	5280	Economy	28000.00
0005435374175	5280	Economy	28000.00
0005435374266	5280	Economy	28000.00
0005434826284	5280	Economy	28000.00
0005435374162	5280	Economy	28000.00
0005434826295	5280	Economy	28000.00
0005432823478	5280	Economy	28000.00
0005434831246	5280	Economy	28000.00
0005434826318	5280	Economy	28000.00
0005434826267	5280	Economy	28000.00
0005435374196	5280	Economy	28000.00
0005435374042	5280	Economy	28000.00
0005435735196	5280	Economy	28000.00
0005434826287	5280	Economy	28000.00
0005434826322	5280	Economy	28000.00
0005434826262	5280	Economy	28000.00
0005434826319	5280	Economy	28000.00
0005434826357	5280	Economy	28000.00
0005434826325	5280	Economy	28000.00
0005434558456	5280	Economy	28000.00
0005435374085	5280	Economy	28000.00
0005432394191	5280	Economy	28000.00
0005435304221	5280	Economy	28000.00
0005435304210	5280	Economy	28000.00
0005434826292	5280	Economy	28000.00
0005434826290	5280	Economy	28000.00
0005432121635	5280	Economy	28000.00
0005432823482	5280	Economy	28000.00
0005435373727	5280	Economy	28000.00
0005435374262	5280	Economy	28000.00
0005435386632	5280	Economy	28000.00
0005435150324	5280	Economy	28000.00
0005434826294	5280	Economy	28000.00
0005435179007	5280	Economy	28000.00
0005434826305	5280	Economy	28000.00
0005435373951	5280	Economy	28000.00
0005434826374	5280	Economy	28000.00
0005435373931	5280	Economy	28000.00
0005435373966	5280	Economy	28000.00
0005434826288	5280	Economy	28000.00
0005434826281	5280	Economy	28000.00
0005435374195	5280	Economy	28000.00
0005435150333	5280	Economy	28000.00
0005434826259	5280	Economy	28000.00
0005434826260	5280	Economy	28000.00
0005435374191	5280	Economy	28000.00
0005434826269	5280	Economy	28000.00
0005434826274	5280	Economy	28000.00
0005435386623	5280	Economy	28000.00
0005434826255	5280	Economy	28000.00
0005434831250	5280	Economy	28000.00
0005435299848	5280	Economy	28000.00
0005435374192	5280	Economy	28000.00
0005434826264	5280	Economy	28000.00
0005435374222	5280	Economy	28000.00
0005434826365	5280	Economy	30800.00
0005434826306	5280	Economy	28000.00
0005435374163	5280	Economy	30800.00
0005434826320	5280	Economy	30800.00
0005435374267	5280	Economy	28000.00
0005434826327	5280	Economy	28000.00
0005434826361	5280	Economy	30800.00
0005435374145	5280	Economy	28000.00
0005435661971	5280	Economy	30800.00
0005432121631	5280	Economy	28000.00
0005435373950	5280	Economy	28000.00
0005434826296	5280	Economy	28000.00
0005432121641	5280	Economy	28000.00
0005434826373	5280	Economy	28000.00
0005435374200	5280	Economy	28000.00
0005434826249	5280	Economy	28000.00
0005432396327	5280	Economy	28000.00
0005434826369	5280	Economy	28000.00
0005435374265	5280	Economy	28000.00
0005434826355	5280	Economy	28000.00
0005434826252	5280	Economy	28000.00
0005434826261	5280	Economy	28000.00
0005434826270	5280	Economy	28000.00
0005432121633	5280	Economy	28000.00
0005435299847	5280	Economy	28000.00
0005434826299	5280	Economy	28000.00
0005432121636	5280	Economy	28000.00
0005435374223	5280	Economy	28000.00
0005434826315	5280	Economy	28000.00
0005434831251	5280	Economy	28000.00
0005435304208	5280	Economy	28000.00
0005434826302	5280	Economy	28000.00
0005432121637	5280	Economy	28000.00
0005435374260	5280	Economy	28000.00
0005435374176	5280	Economy	28000.00
0005434826308	5280	Economy	28000.00
0005432396325	5280	Economy	28000.00
0005432121638	5280	Economy	28000.00
0005434826282	5280	Economy	28000.00
0005434826300	5280	Economy	28000.00
0005434826341	5280	Economy	28000.00
0005435150327	5280	Economy	28000.00
0005435374220	5280	Economy	28000.00
0005434826278	5280	Economy	28000.00
0005435735183	5280	Economy	28000.00
0005432121634	5280	Economy	28000.00
0005434826311	5280	Economy	28000.00
0005435374055	5280	Economy	28000.00
0005434826277	5280	Economy	28000.00
0005432394192	5280	Economy	28000.00
0005434558455	5280	Economy	28000.00
0005434826326	5280	Economy	28000.00
0005434826317	5280	Economy	28000.00
0005432396326	5280	Economy	28000.00
0005434826276	5280	Economy	28000.00
0005432121630	5280	Economy	28000.00
0005434826310	5280	Economy	28000.00
0005435373965	5280	Economy	28000.00
0005435299839	5280	Economy	28000.00
0005434826250	5280	Economy	28000.00
0005435735197	5280	Economy	28000.00
0005434826330	5280	Economy	28000.00
0005434826304	5280	Economy	28000.00
0005434826375	5280	Economy	28000.00
0005434826266	5280	Economy	28000.00
0005434826366	5280	Economy	28000.00
0005434826328	5280	Economy	28000.00
0005435150328	5280	Economy	28000.00
0005435373947	5280	Economy	28000.00
0005434826313	5280	Economy	28000.00
0005434826253	5280	Economy	28000.00
0005434826348	5280	Economy	28000.00
0005435386650	5280	Economy	28000.00
0005435374174	5280	Economy	28000.00
0005434558458	5280	Economy	28000.00
0005435373944	5280	Economy	28000.00
0005435150334	5280	Economy	28000.00
0005435374221	5280	Economy	28000.00
0005435735189	5280	Economy	28000.00
0005435304220	5280	Economy	28000.00
0005435373728	5280	Economy	28000.00
0005434826371	5280	Economy	28000.00
0005434831247	5280	Economy	28000.00
0005434826263	5280	Economy	28000.00
0005435374189	5280	Economy	28000.00
0005435374358	5280	Economy	28000.00
0005434826314	5280	Economy	28000.00
0005435373996	5280	Economy	28000.00
0005435373823	5280	Economy	28000.00
0005435373920	5280	Economy	28000.00
0005435374201	5280	Economy	28000.00
0005434826258	5280	Economy	30800.00
0005435735191	5280	Economy	28000.00
0005434826321	5280	Economy	30800.00
0005435374397	5280	Economy	28000.00
0005435374032	5280	Economy	28000.00
0005432121639	5280	Economy	28000.00
0005432121643	5280	Economy	28000.00
0005435374007	5280	Economy	28000.00
0005435374188	5280	Economy	28000.00
0005434826257	5280	Economy	28000.00
0005434826307	5280	Economy	28000.00
0005434826352	5280	Economy	28000.00
0005434826309	5280	Economy	28000.00
0005434826356	5280	Economy	28000.00
0005434826301	5280	Economy	28000.00
0005435373953	5280	Economy	28000.00
0005435373874	5280	Economy	28000.00
0005435374205	5280	Economy	28000.00
0005434826268	5280	Economy	28000.00
0005434826333	5280	Economy	28000.00
0005434826354	5280	Economy	28000.00
0005434826331	5280	Economy	28000.00
0005434826279	5280	Economy	28000.00
0005434826303	5280	Economy	28000.00
0005435373822	5280	Economy	28000.00
0005434826338	5280	Economy	28000.00
0005434826349	5280	Economy	28000.00
0005434826283	5280	Economy	28000.00
0005435374118	5280	Economy	28000.00
0005434826364	5280	Economy	28000.00
0005435150326	5280	Economy	28000.00
0005432121644	5280	Economy	28000.00
0005435373952	5280	Economy	28000.00
0005434826329	5280	Economy	28000.00
0005434826251	5280	Economy	28000.00
0005432121632	5280	Economy	28000.00
0005434826254	5280	Economy	28000.00
0005435374186	5280	Economy	28000.00
0005434826351	5280	Economy	28000.00
0005435179003	5280	Economy	28000.00
0005434826248	5280	Economy	28000.00
0005434826256	5280	Economy	28000.00
0005434826273	5280	Economy	28000.00
0005435374080	5280	Economy	28000.00
0005434558459	5280	Economy	28000.00
0005434826370	5280	Economy	28000.00
0005435374061	5280	Economy	28000.00
0005435374400	5280	Economy	28000.00
0005434826323	5280	Economy	28000.00
0005435304212	5280	Economy	28000.00
0005435735188	5280	Economy	28000.00
0005435374236	5280	Economy	28000.00
0005435374224	5280	Economy	28000.00
0005435304207	5280	Economy	28000.00
0005434826312	5280	Economy	28000.00
0005434826336	5280	Economy	28000.00
0005434826324	5280	Economy	28000.00
0005434826343	5280	Economy	28000.00
0005434826285	5280	Economy	28000.00
0005434826335	5280	Economy	28000.00
0005435374346	5280	Economy	28000.00
0005434826359	5280	Economy	28000.00
0005435299840	5280	Economy	28000.00
0005434826360	5280	Economy	28000.00
0005435374240	5280	Economy	28000.00
0005435374241	5280	Economy	28000.00
0005434665009	5280	Economy	28000.00
0005434826289	5280	Economy	28000.00
0005434826350	5280	Economy	28000.00
0005435374102	5280	Economy	28000.00
0005434826363	5280	Economy	28000.00
0005435150330	5280	Economy	28000.00
0005434826372	5280	Economy	28000.00
0005435374048	5280	Economy	28000.00
0005434665007	5280	Economy	28000.00
0005435374139	5280	Economy	28000.00
0005432121640	5280	Economy	28000.00
0005434826342	5280	Economy	28000.00
0005435150325	5280	Economy	28000.00
0005434826247	5280	Economy	28000.00
0005435374193	5280	Economy	28000.00
0005435374092	5280	Economy	28000.00
0005434826347	5280	Economy	28000.00
0005435150329	5280	Economy	28000.00
0005432394190	5280	Economy	28000.00
0005435374184	5280	Economy	28000.00
0005432823479	5280	Economy	28000.00
0005435735200	5280	Economy	28000.00
0005434826345	5280	Economy	28000.00
0005434558457	5280	Economy	28000.00
0005435374117	5280	Economy	28000.00
0005434826339	5280	Economy	28000.00
0005435374185	5280	Economy	28000.00
0005435373971	5280	Economy	28000.00
0005435374138	5280	Economy	28000.00
0005435374197	5280	Economy	28000.00
0005434825463	9896	Business	84000.00
0005435302302	9896	Business	84000.00
0005435299876	9896	Business	84000.00
0005434825159	9896	Business	84000.00
0005434825380	9896	Business	84000.00
0005435150192	9896	Business	84000.00
0005434825381	9896	Business	84000.00
0005432396288	9896	Business	84000.00
0005432203217	9896	Business	84000.00
0005435374639	9896	Business	84000.00
0005434825439	9896	Business	84000.00
0005434824995	9896	Business	84000.00
0005435150107	9896	Business	84000.00
0005434558361	9896	Business	84000.00
0005435386718	9896	Business	84000.00
0005434664980	9896	Business	84000.00
0005435150214	9896	Business	84000.00
0005435299877	9896	Business	84000.00
0005435314998	9896	Business	84000.00
0005434825287	9896	Business	84000.00
0005434825378	9896	Business	84000.00
0005435386712	9896	Comfort	47600.00
0005432203221	9896	Comfort	47600.00
0005435150150	9896	Comfort	47600.00
0005434825506	9896	Comfort	47600.00
0005434824900	9896	Comfort	47600.00
0005434825086	9896	Comfort	47600.00
0005434825170	9896	Comfort	47600.00
0005435374650	9896	Comfort	47600.00
0005434825758	9896	Comfort	47600.00
0005435374632	9896	Comfort	47600.00
0005434825692	9896	Comfort	47600.00
0005434825285	9896	Comfort	47600.00
0005435150194	9896	Comfort	47600.00
0005435386714	9896	Comfort	47600.00
0005434824944	9896	Comfort	47600.00
0005435374676	9896	Comfort	47600.00
0005435374633	9896	Comfort	47600.00
0005435374654	9896	Comfort	47600.00
0005434825599	9896	Comfort	47600.00
0005435374678	9896	Comfort	47600.00
0005435314996	9896	Comfort	47600.00
0005435374653	9896	Comfort	47600.00
0005434825237	9896	Comfort	47600.00
0005432203222	9896	Comfort	47600.00
0005434825181	9896	Comfort	47600.00
0005434825255	9896	Comfort	47600.00
0005434824667	9896	Comfort	47600.00
0005434825143	9896	Comfort	47600.00
0005432203219	9896	Comfort	47600.00
0005435374668	9896	Comfort	47600.00
0005434825180	9896	Comfort	47600.00
0005435374638	9896	Comfort	47600.00
0005434825322	9896	Comfort	47600.00
0005434825050	9896	Comfort	47600.00
0005435374651	9896	Economy	28000.00
0005435735238	9896	Economy	28000.00
0005435374664	9896	Economy	28000.00
0005434825554	9896	Economy	28000.00
0005435374641	9896	Economy	28000.00
0005435150149	9896	Economy	28000.00
0005434825681	9896	Economy	28000.00
0005435735240	9896	Economy	28000.00
0005434825884	9896	Economy	28000.00
0005434825132	9896	Economy	28000.00
0005435374685	9896	Economy	28000.00
0005434825819	9896	Economy	28000.00
0005434825315	9896	Economy	28000.00
0005434825342	9896	Economy	28000.00
0005435374696	9896	Economy	28000.00
0005434825085	9896	Economy	28000.00
0005435661995	9896	Economy	28000.00
0005434664979	9896	Economy	28000.00
0005435735239	9896	Economy	28000.00
0005434825248	9896	Economy	28000.00
0005434824866	9896	Economy	28000.00
0005434824817	9896	Economy	28000.00
0005434825343	9896	Economy	28000.00
0005434825007	9896	Economy	28000.00
0005434664981	9896	Economy	28000.00
0005434824692	9896	Economy	28000.00
0005435179414	9896	Economy	28000.00
0005435374677	9896	Economy	28000.00
0005435374635	9896	Economy	28000.00
0005435150185	9896	Economy	28000.00
0005434825447	9896	Economy	28000.00
0005434558360	9896	Economy	28000.00
0005434825286	9896	Economy	28000.00
0005434825234	9896	Economy	28000.00
0005434825189	9896	Economy	28000.00
0005434824721	9896	Economy	28000.00
0005432400180	9896	Economy	28000.00
0005435374648	9896	Economy	28000.00
0005434824863	9896	Economy	28000.00
0005435374636	9896	Economy	28000.00
0005435299879	9896	Economy	28000.00
0005435314993	9896	Economy	28000.00
0005434825179	9896	Economy	28000.00
0005434558359	9896	Economy	28000.00
0005434825298	9896	Economy	28000.00
0005435150196	9896	Economy	28000.00
0005434825476	9896	Economy	28000.00
0005435374642	9896	Economy	30800.00
0005435150106	9896	Economy	28000.00
0005435735241	9896	Economy	28000.00
0005435150207	9896	Economy	28000.00
0005435150191	9896	Economy	30800.00
0005435302300	9896	Economy	28000.00
0005434824565	9896	Economy	28000.00
0005434824669	9896	Economy	28000.00
0005434825404	9896	Economy	28000.00
0005434825183	9896	Economy	28000.00
0005434825601	9896	Economy	28000.00
0005435374640	9896	Economy	28000.00
0005435374655	9896	Economy	28000.00
0005434825603	9896	Economy	28000.00
0005434825440	9896	Economy	28000.00
0005434824883	9896	Economy	28000.00
0005435374637	9896	Economy	28000.00
0005434825448	9896	Economy	28000.00
0005434825227	9896	Economy	28000.00
0005434824773	9896	Economy	28000.00
0005434825133	9896	Economy	28000.00
0005435374680	9896	Economy	28000.00
0005434828730	9896	Economy	28000.00
0005434825228	9896	Economy	28000.00
0005435374689	9896	Economy	28000.00
0005435374631	9896	Economy	28000.00
0005434831206	9896	Economy	28000.00
0005434825190	9896	Economy	28000.00
0005435374686	9896	Economy	28000.00
0005434824774	9896	Economy	28000.00
0005434825288	9896	Economy	28000.00
0005435374646	9896	Economy	28000.00
0005435179709	9896	Economy	28000.00
0005434824798	9896	Economy	28000.00
0005434824921	9896	Economy	28000.00
0005434825236	9896	Economy	28000.00
0005434824996	9896	Economy	28000.00
0005434825543	9896	Economy	28000.00
0005435374673	9896	Economy	28000.00
0005434824787	9896	Economy	28000.00
0005434825054	9896	Economy	28000.00
0005435374670	9896	Economy	28000.00
0005435150232	9896	Economy	28000.00
0005434664998	9896	Economy	28000.00
0005435374684	9896	Economy	28000.00
0005434825333	9896	Economy	28000.00
0005435374662	9896	Economy	28000.00
0005434825741	9896	Economy	28000.00
0005434825239	9896	Economy	28000.00
0005435374671	9896	Economy	28000.00
0005432203218	9896	Economy	28000.00
0005435374672	9896	Economy	28000.00
0005435374679	9896	Economy	28000.00
0005435374691	9896	Economy	28000.00
0005435374645	9896	Economy	28000.00
0005435374656	9896	Economy	28000.00
0005434825449	9896	Economy	28000.00
0005434824870	9896	Economy	28000.00
0005434824925	9896	Economy	28000.00
0005435374693	9896	Economy	28000.00
0005434825142	9896	Economy	28000.00
0005435150158	9896	Economy	28000.00
0005435314994	9896	Economy	28000.00
0005434558368	9896	Economy	28000.00
0005434824668	9896	Economy	28000.00
0005434825073	9896	Economy	28000.00
0005435374652	9896	Economy	28000.00
0005434825759	9896	Economy	28000.00
0005435374630	9896	Economy	28000.00
0005435374659	9896	Economy	28000.00
0005435374694	9896	Economy	28000.00
0005434825586	9896	Economy	28000.00
0005435374674	9896	Economy	28000.00
0005434825141	9896	Economy	28000.00
0005434825163	9896	Economy	28000.00
0005435374669	9896	Economy	28000.00
0005435150124	9896	Economy	28000.00
0005434825202	9896	Economy	28000.00
0005434825066	9896	Economy	28000.00
0005435299878	9896	Economy	28000.00
0005435374661	9896	Economy	28000.00
0005432203220	9896	Economy	28000.00
0005434825757	9896	Economy	28000.00
0005434825149	9896	Economy	28000.00
0005434825201	9896	Economy	28000.00
0005434825015	9896	Economy	28000.00
0005435314995	9896	Economy	28000.00
0005434824772	9896	Economy	28000.00
0005434824251	9896	Economy	28000.00
0005434825261	9896	Economy	30800.00
0005434825355	9896	Economy	28000.00
0005434824829	9896	Economy	30800.00
0005434824720	9896	Economy	28000.00
0005435150195	9896	Economy	28000.00
0005435302301	9896	Economy	28000.00
0005435386717	9896	Economy	28000.00
0005434828721	9896	Economy	28000.00
0005435374675	9896	Economy	28000.00
0005435374660	9896	Economy	28000.00
0005435374667	9896	Economy	28000.00
0005432400188	9896	Economy	28000.00
0005434824586	9896	Economy	28000.00
0005434825553	9896	Economy	28000.00
0005435374644	9896	Economy	28000.00
0005434825297	9896	Economy	28000.00
0005434825162	9896	Economy	28000.00
0005435374647	9896	Economy	28000.00
0005435374634	9896	Economy	28000.00
0005435735242	9896	Economy	28000.00
0005435150233	9896	Economy	28000.00
0005434825232	9896	Economy	28000.00
0005435374666	9896	Economy	28000.00
0005434825238	9896	Economy	28000.00
0005435179706	9896	Economy	28000.00
0005434825949	9896	Economy	28000.00
0005435374682	9896	Economy	28000.00
0005435374695	9896	Economy	28000.00
0005435374690	9896	Economy	28000.00
0005434824977	9896	Economy	28000.00
0005434825256	9896	Economy	28000.00
0005432396310	9896	Economy	28000.00
0005435374683	9896	Economy	28000.00
0005432396284	9896	Economy	28000.00
0005434825072	9896	Economy	28000.00
0005435374688	9896	Economy	28000.00
0005435314997	9896	Economy	28000.00
0005434831199	9896	Economy	28000.00
0005435386715	9896	Economy	28000.00
0005435299880	9896	Economy	28000.00
0005435374649	9896	Economy	28000.00
0005434825434	9896	Economy	28000.00
0005434825602	9896	Economy	28000.00
0005434825144	9896	Economy	28000.00
0005435374657	9896	Economy	28000.00
0005432203216	9896	Economy	28000.00
0005434824775	9896	Economy	28000.00
0005434825191	9896	Economy	28000.00
0005435179707	9896	Economy	28000.00
0005435386716	9896	Economy	28000.00
0005435374643	9896	Economy	28000.00
0005434824722	9896	Economy	28000.00
0005434558334	9896	Economy	28000.00
0005434831190	9896	Economy	28000.00
0005434825229	9896	Economy	28000.00
0005434825097	9896	Economy	28000.00
0005435179708	9896	Economy	28000.00
0005435374692	9896	Economy	28000.00
0005435661994	9896	Economy	28000.00
0005435386713	9896	Economy	28000.00
0005435374665	9896	Economy	28000.00
0005435374663	9896	Economy	28000.00
0005434825006	9896	Economy	28000.00
0005434824566	9896	Economy	28000.00
0005434824818	9896	Economy	28000.00
0005434825098	9896	Economy	28000.00
0005432396289	9896	Economy	28000.00
0005434825150	9896	Economy	28000.00
0005435302298	9896	Economy	28000.00
0005434825384	9896	Economy	28000.00
0005434664997	9896	Economy	28000.00
0005434825230	9896	Economy	28000.00
0005434824891	9896	Economy	28000.00
0005435374658	9896	Economy	28000.00
0005435374681	9896	Economy	28000.00
0005435302299	9896	Economy	28000.00
0005434825105	9896	Economy	28000.00
0005434825148	9896	Economy	28000.00
0005435374687	9896	Economy	28000.00
0005435150206	9896	Economy	28000.00
0005434824869	9896	Economy	28000.00
0005435082966	6989	Economy	8200.00
0005435082962	6989	Economy	7400.00
0005435082963	6989	Economy	7400.00
0005435790368	6989	Economy	7400.00
0005435082965	6989	Economy	7400.00
0005435082961	6989	Economy	7400.00
0005435082964	6989	Economy	7400.00
0005435082959	6989	Economy	7400.00
0005435790369	6989	Economy	7400.00
0005435082967	6989	Economy	7400.00
0005435082958	6989	Economy	7400.00
0005435082960	6989	Economy	7400.00
0005435790370	6989	Economy	7400.00
0005435790347	25965	Economy	7400.00
0005435082874	25965	Economy	7400.00
0005435082858	25965	Economy	7400.00
0005435082876	25965	Economy	7400.00
0005435082857	25965	Economy	7400.00
0005435082864	25965	Economy	7400.00
0005435082875	25965	Economy	7400.00
0005435082888	25965	Economy	7400.00
0005435082889	25965	Economy	7400.00
0005434757299	9520	Business	32800.00
0005434215174	9520	Business	32800.00
0005434215083	9520	Business	32800.00
0005434215247	9520	Business	32800.00
0005434215093	9520	Business	32800.00
0005434757298	9520	Business	32800.00
0005434757325	9520	Business	32800.00
0005434215085	9520	Business	32800.00
0005434757322	9520	Business	32800.00
0005434757297	9520	Business	32800.00
0005434757296	9520	Business	32800.00
0005434214941	9520	Business	32800.00
0005434215151	9520	Economy	10900.00
0005434215062	9520	Economy	10900.00
0005434757313	9520	Economy	10900.00
0005434757295	9520	Economy	10900.00
0005434214988	9520	Economy	10900.00
0005434757309	9520	Economy	10900.00
0005434215237	9520	Economy	10900.00
0005434757335	9520	Economy	10900.00
0005434215305	9520	Economy	10900.00
0005434757330	9520	Economy	10900.00
0005434215211	9520	Economy	12000.00
0005434757303	9520	Economy	12000.00
0005434757323	9520	Economy	12000.00
0005434215084	9520	Economy	12000.00
0005434757328	9520	Economy	12000.00
0005434757332	9520	Economy	10900.00
0005434214987	9520	Economy	10900.00
0005434215049	9520	Economy	10900.00
0005434215029	9520	Economy	10900.00
0005434215266	9520	Economy	10900.00
0005434757307	9520	Economy	10900.00
0005434215152	9520	Economy	10900.00
0005434215236	9520	Economy	10900.00
0005434215041	9520	Economy	10900.00
0005434757316	9520	Economy	10900.00
0005434757324	9520	Economy	10900.00
0005434757317	9520	Economy	10900.00
0005434757300	9520	Economy	10900.00
0005434757302	9520	Economy	10900.00
0005434757333	9520	Economy	10900.00
0005434757308	9520	Economy	10900.00
0005434215042	9520	Economy	10900.00
0005434757319	9520	Economy	10900.00
0005434215243	9520	Economy	10900.00
0005434215094	9520	Economy	10900.00
0005434215063	9520	Economy	10900.00
0005434757292	9520	Economy	10900.00
0005434757336	9520	Economy	10900.00
0005434757293	9520	Economy	10900.00
0005434215169	9520	Economy	10900.00
0005434757314	9520	Economy	10900.00
0005434215065	9520	Economy	10900.00
0005434215076	9520	Economy	10900.00
0005434757321	9520	Economy	10900.00
0005434215203	9520	Economy	10900.00
0005434757334	9520	Economy	10900.00
0005434215248	9520	Economy	10900.00
0005434757306	9520	Economy	10900.00
0005434757327	9520	Economy	10900.00
0005434214829	9520	Economy	10900.00
0005434757294	9520	Economy	10900.00
0005434215135	9520	Economy	10900.00
0005434757326	9520	Economy	10900.00
0005434757329	9520	Economy	10900.00
0005434757305	9520	Economy	10900.00
0005434215072	9520	Economy	10900.00
0005434757331	9520	Economy	10900.00
0005434757310	9520	Economy	10900.00
0005434757304	9520	Economy	10900.00
0005434757311	9520	Economy	10900.00
0005434215104	9520	Economy	10900.00
0005434215010	9520	Economy	10900.00
0005434215220	9520	Economy	10900.00
0005434215087	9520	Economy	10900.00
0005434757320	9520	Economy	10900.00
0005434215221	9520	Economy	10900.00
0005434757318	9520	Economy	10900.00
0005434215020	9520	Economy	10900.00
0005434215037	9520	Economy	10900.00
0005434757315	9520	Economy	10900.00
0005434215120	9520	Economy	10900.00
0005434757301	9520	Economy	10900.00
0005434215246	9520	Economy	10900.00
0005434757312	9520	Economy	10900.00
0005434215077	9520	Economy	10900.00
0005434215073	9520	Economy	10900.00
0005434215219	9520	Economy	10900.00
0005434215021	9520	Economy	10900.00
0005434757291	9520	Economy	10900.00
0005434215268	9520	Economy	10900.00
0005434757337	9520	Economy	10900.00
0005434756621	28602	Business	32800.00
0005434215488	28602	Business	32800.00
0005434215480	28602	Business	32800.00
0005434215470	28602	Business	32800.00
0005434756775	28602	Business	32800.00
0005434756956	28602	Business	32800.00
0005434756857	28602	Business	32800.00
0005434215503	28602	Business	32800.00
0005434756801	28602	Business	32800.00
0005434756893	28602	Business	32800.00
0005434756944	28602	Business	32800.00
0005434215474	28602	Economy	10900.00
0005434756925	28602	Economy	10900.00
0005434756622	28602	Economy	10900.00
0005434756920	28602	Economy	10900.00
0005434756623	28602	Economy	10900.00
0005434756922	28602	Economy	10900.00
0005434756747	28602	Economy	10900.00
0005434215469	28602	Economy	10900.00
0005434756935	28602	Economy	10900.00
0005434756852	28602	Economy	10900.00
0005434215504	28602	Economy	12000.00
0005434756776	28602	Economy	12000.00
0005434215479	28602	Economy	12000.00
0005434756675	28602	Economy	12000.00
0005434756877	28602	Economy	12000.00
0005434215491	28602	Economy	10900.00
0005434756850	28602	Economy	10900.00
0005434215468	28602	Economy	10900.00
0005434756953	28602	Economy	10900.00
0005434756841	28602	Economy	10900.00
0005434215481	28602	Economy	10900.00
0005434215485	28602	Economy	10900.00
0005434756954	28602	Economy	10900.00
0005434215502	28602	Economy	10900.00
0005434215462	28602	Economy	10900.00
0005434215473	28602	Economy	10900.00
0005434215461	28602	Economy	10900.00
0005434215463	28602	Economy	10900.00
0005434215490	28602	Economy	10900.00
0005434756807	28602	Economy	10900.00
0005434215496	28602	Economy	10900.00
0005434756919	28602	Economy	10900.00
0005434215498	28602	Economy	10900.00
0005434215494	28602	Economy	10900.00
0005434756749	28602	Economy	10900.00
0005434756820	28602	Economy	10900.00
0005434756946	28602	Economy	10900.00
0005434215500	28602	Economy	10900.00
0005434756794	28602	Economy	10900.00
0005434756923	28602	Economy	10900.00
0005434756961	28602	Economy	10900.00
0005434215492	28602	Economy	10900.00
0005434756684	28602	Economy	10900.00
0005434756912	28602	Economy	10900.00
0005434756702	28602	Economy	10900.00
0005434215465	28602	Economy	10900.00
0005434215505	28602	Economy	10900.00
0005434215460	28602	Economy	10900.00
0005434215499	28602	Economy	10900.00
0005434756806	28602	Economy	10900.00
0005434215493	28602	Economy	10900.00
0005434215476	28602	Economy	10900.00
0005434756802	28602	Economy	10900.00
0005434756791	28602	Economy	10900.00
0005434756921	28602	Economy	10900.00
0005434215487	28602	Economy	10900.00
0005434756924	28602	Economy	10900.00
0005434756755	28602	Economy	10900.00
0005434215467	28602	Economy	10900.00
0005434215483	28602	Economy	10900.00
0005434215471	28602	Economy	10900.00
0005434756683	28602	Economy	10900.00
0005434756756	28602	Economy	10900.00
0005434215484	28602	Economy	10900.00
0005434756792	28602	Economy	10900.00
0005434215482	28602	Economy	10900.00
0005434215472	28602	Economy	10900.00
0005434215489	28602	Economy	10900.00
0005434756703	28602	Economy	10900.00
0005434215497	28602	Economy	10900.00
0005434215506	28602	Economy	10900.00
0005434215495	28602	Economy	10900.00
0005434756955	28602	Economy	10900.00
0005434215478	28602	Economy	10900.00
0005434215486	28602	Economy	10900.00
0005434215475	28602	Economy	10900.00
0005434756945	28602	Economy	10900.00
0005434215459	28602	Economy	10900.00
0005434215466	28602	Economy	10900.00
0005434215464	28602	Economy	10900.00
0005434215501	28602	Economy	10900.00
0005434215477	28602	Economy	10900.00
0005434760224	10852	Economy	8900.00
0005434760226	10852	Economy	8900.00
0005434760239	10852	Economy	8900.00
0005435100188	10852	Economy	8900.00
0005435100186	10852	Economy	8900.00
0005435100189	10852	Economy	8900.00
0005435100187	10852	Economy	8900.00
0005435100164	31798	Economy	8900.00
0005435100159	31798	Economy	8900.00
0005435100152	31798	Economy	8900.00
0005434760250	31798	Economy	8900.00
0005434760249	31798	Economy	8900.00
0005435100161	31798	Economy	8900.00
0005435100160	31798	Economy	8900.00
0005434639888	2001	Economy	20900.00
0005432290701	2001	Economy	20900.00
0005434639878	2001	Economy	20900.00
0005433202580	2001	Economy	20900.00
0005434639869	2001	Economy	19000.00
0005432290702	2001	Economy	19000.00
0005433202573	2001	Economy	19000.00
0005433202488	2001	Economy	19000.00
0005433202515	2001	Economy	19000.00
0005434639884	2001	Economy	19000.00
0005433202594	2001	Economy	19000.00
0005433202586	2001	Economy	19000.00
0005434639874	2001	Economy	19000.00
0005433202565	2001	Economy	19000.00
0005434639872	2001	Economy	19000.00
0005434639880	2001	Economy	19000.00
0005434639887	2001	Economy	19000.00
0005434639889	2001	Economy	19000.00
0005434639873	2001	Economy	19000.00
0005434639879	2001	Economy	19000.00
0005433202514	2001	Economy	19000.00
0005434639871	2001	Economy	19000.00
0005433202489	2001	Economy	19000.00
0005434639881	2001	Economy	19000.00
0005433202552	2001	Economy	19000.00
0005433202608	2001	Economy	19000.00
0005434639883	2001	Economy	19000.00
0005433202593	2001	Economy	19000.00
0005434639870	2001	Economy	19000.00
0005433202579	2001	Economy	19000.00
0005434639875	2001	Economy	19000.00
0005433202581	2001	Economy	19000.00
0005434639877	2001	Economy	19000.00
0005434639882	2001	Economy	19000.00
0005434639886	2001	Economy	19000.00
0005433202572	2001	Economy	19000.00
0005433202498	2001	Economy	19000.00
0005433202587	2001	Economy	19000.00
0005433202497	2001	Economy	19000.00
0005434639885	2001	Economy	19000.00
0005433202541	2001	Economy	19000.00
0005432290700	2001	Economy	19000.00
0005433202571	2001	Economy	19000.00
0005433202592	2001	Economy	19000.00
0005433202582	2001	Economy	19000.00
0005434639876	2001	Economy	19000.00
0005433202595	2001	Economy	19000.00
0005433202668	23254	Economy	20900.00
0005433202674	23254	Economy	20900.00
0005434639685	23254	Economy	20900.00
0005434639690	23254	Economy	19000.00
0005434639671	23254	Economy	19000.00
0005434639537	23254	Economy	19000.00
0005434639670	23254	Economy	19000.00
0005434639650	23254	Economy	19000.00
0005434639551	23254	Economy	19000.00
0005434639594	23254	Economy	19000.00
0005434639602	23254	Economy	19000.00
0005433202663	23254	Economy	19000.00
0005434639673	23254	Economy	19000.00
0005434639643	23254	Economy	19000.00
0005434639644	23254	Economy	19000.00
0005433202666	23254	Economy	19000.00
0005434639591	23254	Economy	19000.00
0005433202660	23254	Economy	19000.00
0005434639608	23254	Economy	19000.00
0005433202670	23254	Economy	19000.00
0005433202667	23254	Economy	19000.00
0005433202672	23254	Economy	19000.00
0005434639614	23254	Economy	19000.00
0005433202664	23254	Economy	19000.00
0005433202662	23254	Economy	19000.00
0005434639649	23254	Economy	19000.00
0005433202673	23254	Economy	19000.00
0005434639655	23254	Economy	19000.00
0005434639661	23254	Economy	19000.00
0005434639721	23254	Economy	19000.00
0005434639663	23254	Economy	19000.00
0005433202661	23254	Economy	19000.00
0005433202669	23254	Economy	19000.00
0005433202665	23254	Economy	19000.00
0005433202671	23254	Economy	19000.00
0005434639552	23254	Economy	19000.00
0005434639603	23254	Economy	19000.00
0005434639615	23254	Economy	19000.00
0005435326961	6095	Business	69700.00
0005434601396	6095	Business	69700.00
0005435326931	6095	Business	69700.00
0005434601387	6095	Business	69700.00
0005434601391	6095	Business	69700.00
0005435326987	6095	Business	69700.00
0005433531374	6095	Economy	23200.00
0005434601381	6095	Economy	23200.00
0005434601400	6095	Economy	23200.00
0005434601377	6095	Economy	25600.00
0005434601389	6095	Economy	25600.00
0005432111342	6095	Economy	25600.00
0005434601392	6095	Economy	25600.00
0005434601376	6095	Economy	25600.00
0005434601394	6095	Economy	23200.00
0005434601386	6095	Economy	23200.00
0005434601399	6095	Economy	23200.00
0005434601385	6095	Economy	23200.00
0005434601379	6095	Economy	23200.00
0005435326988	6095	Economy	23200.00
0005434601397	6095	Economy	23200.00
0005435326930	6095	Economy	23200.00
0005435326897	6095	Economy	23200.00
0005434601390	6095	Economy	23200.00
0005433533389	6095	Economy	23200.00
0005435326919	6095	Economy	23200.00
0005433533390	6095	Economy	23200.00
0005433531373	6095	Economy	23200.00
0005434601382	6095	Economy	23200.00
0005434601398	6095	Economy	23200.00
0005433533391	6095	Economy	23200.00
0005434601384	6095	Economy	23200.00
0005434601375	6095	Economy	23200.00
0005434601380	6095	Economy	23200.00
0005434601378	6095	Economy	23200.00
0005433531375	6095	Economy	23200.00
0005434601401	6095	Economy	23200.00
0005435326918	6095	Economy	23200.00
0005434601388	6095	Economy	23200.00
0005432111343	6095	Economy	23200.00
0005434601383	6095	Economy	23200.00
0005432111345	6095	Economy	23200.00
0005433531376	6095	Economy	23200.00
0005433533388	6095	Economy	23200.00
0005435326896	6095	Economy	23200.00
0005434601393	6095	Economy	23200.00
0005432111344	6095	Economy	23200.00
0005434601395	6095	Economy	23200.00
0005434601274	18583	Business	69700.00
0005434601130	18583	Business	69700.00
0005435327041	18583	Business	69700.00
0005434601150	18583	Business	69700.00
0005434601213	18583	Business	69700.00
0005435327048	18583	Business	69700.00
0005434601188	18583	Economy	23200.00
0005434601126	18583	Economy	23200.00
0005435327039	18583	Economy	23200.00
0005434601164	18583	Economy	23200.00
0005434601154	18583	Economy	25600.00
0005434601208	18583	Economy	23200.00
0005435327049	18583	Economy	23200.00
0005433527307	18583	Economy	23200.00
0005433527308	18583	Economy	23200.00
0005435327047	18583	Economy	23200.00
0005434601113	18583	Economy	23200.00
0005433527302	18583	Economy	23200.00
0005433527309	18583	Economy	23200.00
0005434601141	18583	Economy	23200.00
0005434601246	18583	Economy	23200.00
0005434601085	18583	Economy	23200.00
0005434601151	18583	Economy	23200.00
0005434601156	18583	Economy	23200.00
0005435327037	18583	Economy	23200.00
0005434601183	18583	Economy	23200.00
0005435327046	18583	Economy	23200.00
0005434601108	18583	Economy	23200.00
0005434601182	18583	Economy	23200.00
0005434601184	18583	Economy	23200.00
0005434601200	18583	Economy	23200.00
0005434601114	18583	Economy	23200.00
0005433527314	18583	Economy	23200.00
0005435327036	18583	Economy	23200.00
0005435327045	18583	Economy	23200.00
0005433527305	18583	Economy	23200.00
0005434601165	18583	Economy	23200.00
0005435327043	18583	Economy	23200.00
0005434601131	18583	Economy	23200.00
0005433531336	18583	Economy	23200.00
0005434601140	18583	Economy	23200.00
0005435327044	18583	Economy	23200.00
0005433531338	18583	Economy	23200.00
0005435327038	18583	Economy	23200.00
0005433531332	18583	Economy	23200.00
0005434601173	18583	Economy	23200.00
0005435327042	18583	Economy	23200.00
0005435327040	18583	Economy	23200.00
0005434601079	18583	Economy	23200.00
0005433181376	10600	Business	9100.00
0005434552352	10600	Business	9100.00
0005434552372	10600	Business	9100.00
0005434552382	10600	Business	9100.00
0005434552357	10600	Business	9100.00
0005434552330	10600	Business	9100.00
0005434558454	10600	Business	9100.00
0005434552354	10600	Business	9100.00
0005433181353	10600	Business	9100.00
0005433181355	10600	Business	9100.00
0005434554107	10600	Business	9100.00
0005434552362	10600	Business	9100.00
0005433181299	10600	Economy	3000.00
0005433181300	10600	Economy	3000.00
0005434552337	10600	Economy	3000.00
0005434552333	10600	Economy	3000.00
0005434552356	10600	Economy	3000.00
0005434552375	10600	Economy	3000.00
0005433181286	10600	Economy	3000.00
0005434552345	10600	Economy	3000.00
0005434552381	10600	Economy	3000.00
0005434552342	10600	Economy	3000.00
0005433181416	10600	Economy	3300.00
0005434552379	10600	Economy	3300.00
0005434552331	10600	Economy	3300.00
0005433181417	10600	Economy	3300.00
0005434552334	10600	Economy	3300.00
0005434552385	10600	Economy	3000.00
0005433181425	10600	Economy	3000.00
0005433181457	10600	Economy	3000.00
0005433181375	10600	Economy	3000.00
0005434552371	10600	Economy	3000.00
0005434558447	10600	Economy	3000.00
0005434558453	10600	Economy	3000.00
0005434552380	10600	Economy	3000.00
0005433181553	10600	Economy	3000.00
0005434552349	10600	Economy	3000.00
0005433181411	10600	Economy	3000.00
0005434554109	10600	Economy	3000.00
0005433181552	10600	Economy	3000.00
0005434552361	10600	Economy	3000.00
0005434552384	10600	Economy	3000.00
0005434552366	10600	Economy	3000.00
0005434552369	10600	Economy	3000.00
0005434552364	10600	Economy	3000.00
0005433181525	10600	Economy	3000.00
0005434552383	10600	Economy	3000.00
0005434552350	10600	Economy	3000.00
0005434558451	10600	Economy	3000.00
0005434558450	10600	Economy	3000.00
0005434552341	10600	Economy	3000.00
0005434552351	10600	Economy	3000.00
0005434552347	10600	Economy	3000.00
0005434552348	10600	Economy	3000.00
0005433181349	10600	Economy	3000.00
0005434558452	10600	Economy	3000.00
0005434552370	10600	Economy	3000.00
0005433181432	10600	Economy	3000.00
0005434552332	10600	Economy	3000.00
0005434552373	10600	Economy	3000.00
0005433181551	10600	Economy	3000.00
0005433181455	10600	Economy	3000.00
0005434552377	10600	Economy	3000.00
0005434552386	10600	Economy	3000.00
0005434552339	10600	Economy	3000.00
0005434552335	10600	Economy	3000.00
0005434552338	10600	Economy	3000.00
0005433181283	10600	Economy	3000.00
0005434552344	10600	Economy	3000.00
0005434552360	10600	Economy	3000.00
0005434552363	10600	Economy	3000.00
0005433181377	10600	Economy	3000.00
0005433181356	10600	Economy	3000.00
0005434558449	10600	Economy	3000.00
0005434552358	10600	Economy	3000.00
0005434552346	10600	Economy	3000.00
0005433181282	10600	Economy	3000.00
0005434552336	10600	Economy	3000.00
0005434552378	10600	Economy	3000.00
0005434554108	10600	Economy	3000.00
0005434552367	10600	Economy	3000.00
0005434552368	10600	Economy	3000.00
0005433181322	10600	Economy	3000.00
0005434552365	10600	Economy	3000.00
0005433181433	10600	Economy	3000.00
0005434552343	10600	Economy	3000.00
0005434552355	10600	Economy	3000.00
0005434552359	10600	Economy	3000.00
0005433181264	10600	Economy	3000.00
0005434552340	10600	Economy	3000.00
0005434558448	10600	Economy	3000.00
0005434552353	10600	Economy	3000.00
0005434552376	10600	Economy	3000.00
0005434552374	10600	Economy	3000.00
0005433181649	27682	Business	9100.00
0005433181646	27682	Business	9100.00
0005435314993	27682	Business	9100.00
0005435314997	27682	Economy	3000.00
0005433181636	27682	Economy	3000.00
0005433181652	27682	Economy	3000.00
0005433181645	27682	Economy	3300.00
0005433181650	27682	Economy	3000.00
0005433181653	27682	Economy	3000.00
0005435314996	27682	Economy	3000.00
0005433181647	27682	Economy	3000.00
0005433181641	27682	Economy	3000.00
0005433181643	27682	Economy	3000.00
0005433181648	27682	Economy	3000.00
0005433181634	27682	Economy	3000.00
0005433181633	27682	Economy	3000.00
0005433181655	27682	Economy	3000.00
0005433181654	27682	Economy	3000.00
0005433181639	27682	Economy	3000.00
0005433181651	27682	Economy	3000.00
0005435314998	27682	Economy	3000.00
0005433181635	27682	Economy	3000.00
0005433181638	27682	Economy	3000.00
0005433181631	27682	Economy	3000.00
0005433181642	27682	Economy	3000.00
0005433181632	27682	Economy	3000.00
0005435314994	27682	Economy	3000.00
0005435314995	27682	Economy	3000.00
0005433181640	27682	Economy	3000.00
0005433181644	27682	Economy	3000.00
0005433181637	27682	Economy	3000.00
0005434757696	27682	Economy	3000.00
0005434554091	27681	Business	9100.00
0005434551901	27681	Business	9100.00
0005434551965	27681	Business	9100.00
0005434551873	27681	Business	9100.00
0005434551990	27681	Business	9100.00
0005434551838	27681	Business	9100.00
0005434551797	27681	Business	9100.00
0005434558337	27681	Business	9100.00
0005434552032	27681	Business	9100.00
0005434551992	27681	Economy	3000.00
0005434551769	27681	Economy	3000.00
0005434551625	27681	Economy	3000.00
0005434558352	27681	Economy	3000.00
0005434551872	27681	Economy	3000.00
0005434554092	27681	Economy	3000.00
0005434552031	27681	Economy	3300.00
0005434551837	27681	Economy	3300.00
0005434558373	27681	Economy	3300.00
0005434551966	27681	Economy	3300.00
0005434551900	27681	Economy	3000.00
0005434551833	27681	Economy	3000.00
0005434551845	27681	Economy	3000.00
0005434551679	27681	Economy	3000.00
0005434551832	27681	Economy	3000.00
0005434558390	27681	Economy	3000.00
0005434554094	27681	Economy	3000.00
0005434552048	27681	Economy	3000.00
0005434552099	27681	Economy	3000.00
0005434554093	27681	Economy	3000.00
0005434551989	27681	Economy	3000.00
0005434554096	27681	Economy	3000.00
0005434551983	27681	Economy	3000.00
0005434558403	27681	Economy	3000.00
0005434552065	27681	Economy	3000.00
0005434551947	27681	Economy	3000.00
0005434551967	27681	Economy	3000.00
0005434551984	27681	Economy	3000.00
0005434551770	27681	Economy	3000.00
0005434558339	27681	Economy	3000.00
0005434552066	27681	Economy	3000.00
0005434551843	27681	Economy	3000.00
0005434551895	27681	Economy	3000.00
0005434551834	27681	Economy	3000.00
0005434551740	27681	Economy	3000.00
0005434558389	27681	Economy	3000.00
0005434552040	27681	Economy	3000.00
0005434551874	27681	Economy	3000.00
0005434551920	27681	Economy	3000.00
0005434558406	27681	Economy	3000.00
0005434554095	27681	Economy	3000.00
0005434558369	27681	Economy	3000.00
0005434551844	27681	Economy	3000.00
0005434551678	27681	Economy	3000.00
0005434558372	27681	Economy	3000.00
0005434558394	27681	Economy	3000.00
0005434551981	27681	Economy	3000.00
0005434554090	27681	Economy	3000.00
0005434552010	27681	Economy	3000.00
0005434551798	27681	Economy	3000.00
0005434554089	27681	Economy	3000.00
0005434558370	27681	Economy	3000.00
0005434552039	27681	Economy	3000.00
0005434551884	27681	Economy	3000.00
0005434552038	27681	Economy	3000.00
0005434558404	27681	Economy	3000.00
0005434552116	27681	Economy	3000.00
0005434551902	27681	Economy	3000.00
0005434552029	27681	Economy	3000.00
0005434552098	27681	Economy	3000.00
0005433459311	6153	Economy	11700.00
0005433459312	6153	Economy	11700.00
0005435254519	6153	Economy	11700.00
0005435254503	6153	Economy	11700.00
0005433459313	6153	Economy	11700.00
0005435254524	19331	Economy	11700.00
0005435254523	19331	Economy	11700.00
0005433459288	19331	Economy	11700.00
0005433459290	19331	Economy	11700.00
0005433459289	19331	Economy	11700.00
0005433459267	19331	Economy	11700.00
0005432136274	6714	Business	51100.00
0005435683022	6714	Business	51100.00
0005435683017	6714	Business	51100.00
0005435438260	6714	Business	51100.00
0005435683002	6714	Business	51100.00
0005435438218	6714	Business	51100.00
0005435438197	6714	Business	51100.00
0005435217740	6714	Business	51100.00
0005435438242	6714	Business	51100.00
0005435438241	6714	Business	51100.00
0005435683013	6714	Business	51100.00
0005432533322	6714	Business	51100.00
0005435438265	6714	Economy	17000.00
0005435683008	6714	Economy	17000.00
0005432136275	6714	Economy	17000.00
0005435682982	6714	Economy	17000.00
0005435661991	6714	Economy	17000.00
0005435438264	6714	Economy	17000.00
0005435682997	6714	Economy	17000.00
0005435631030	6714	Economy	17000.00
0005435438271	6714	Economy	17000.00
0005435217724	6714	Economy	17000.00
0005435220343	6714	Economy	18700.00
0005435682993	6714	Economy	18700.00
0005435683016	6714	Economy	18700.00
0005435682990	6714	Economy	18700.00
0005432136276	6714	Economy	18700.00
0005435682992	6714	Economy	17000.00
0005435438215	6714	Economy	17000.00
0005435438259	6714	Economy	17000.00
0005435682996	6714	Economy	17000.00
0005435438222	6714	Economy	17000.00
0005434828735	6714	Economy	17000.00
0005435661990	6714	Economy	17000.00
0005435438207	6714	Economy	17000.00
0005435683003	6714	Economy	17000.00
0005435683019	6714	Economy	17000.00
0005435217738	6714	Economy	17000.00
0005435631031	6714	Economy	17000.00
0005432533328	6714	Economy	17000.00
0005435682983	6714	Economy	17000.00
0005435683010	6714	Economy	17000.00
0005432533331	6714	Economy	17000.00
0005435683024	6714	Economy	17000.00
0005435682991	6714	Economy	17000.00
0005434828734	6714	Economy	17000.00
0005435682998	6714	Economy	17000.00
0005435438206	6714	Economy	17000.00
0005435683004	6714	Economy	17000.00
0005435631029	6714	Economy	17000.00
0005432136278	6714	Economy	17000.00
0005435220342	6714	Economy	17000.00
0005435683007	6714	Economy	17000.00
0005435682987	6714	Economy	17000.00
0005434828726	6714	Economy	17000.00
0005434828738	6714	Economy	17000.00
0005435661993	6714	Economy	17000.00
0005435682995	6714	Economy	17000.00
0005435683009	6714	Economy	17000.00
0005435682984	6714	Economy	17000.00
0005435683020	6714	Economy	17000.00
0005432533323	6714	Economy	17000.00
0005435683001	6714	Economy	17000.00
0005435438209	6714	Economy	17000.00
0005435683021	6714	Economy	17000.00
0005432136277	6714	Economy	17000.00
0005434828728	6714	Economy	17000.00
0005435683006	6714	Economy	17000.00
0005435683011	6714	Economy	17000.00
0005434828725	6714	Economy	17000.00
0005435682994	6714	Economy	17000.00
0005435438166	6714	Economy	17000.00
0005435683023	6714	Economy	17000.00
0005435217744	6714	Economy	17000.00
0005435682986	6714	Economy	17000.00
0005435683014	6714	Economy	17000.00
0005435683015	6714	Economy	17000.00
0005435683018	6714	Economy	17000.00
0005432136279	6714	Economy	17000.00
0005435438267	6714	Economy	17000.00
0005432533327	6714	Economy	17000.00
0005435661992	6714	Economy	17000.00
0005434828737	6714	Economy	17000.00
0005435438266	6714	Economy	17000.00
0005435683005	6714	Economy	17000.00
0005435683025	6714	Economy	17000.00
0005435682989	6714	Economy	17000.00
0005435682985	6714	Economy	17000.00
0005435683000	6714	Economy	17000.00
0005434828723	6714	Economy	17000.00
0005435682988	6714	Economy	17000.00
0005435682999	6714	Economy	17000.00
0005435683012	6714	Economy	17000.00
0005435438243	6714	Economy	17000.00
0005435661977	24585	Business	51100.00
0005435438436	24585	Business	51100.00
0005435220507	24585	Business	51100.00
0005434828756	24585	Business	51100.00
0005435438428	24585	Business	51100.00
0005435220364	24585	Business	51100.00
0005435661979	24585	Business	51100.00
0005435682700	24585	Business	51100.00
0005435682736	24585	Business	51100.00
0005435438420	24585	Business	51100.00
0005432533354	24585	Business	51100.00
0005435219245	24585	Economy	17000.00
0005435220363	24585	Economy	17000.00
0005435438432	24585	Economy	17000.00
0005435438421	24585	Economy	17000.00
0005435220365	24585	Economy	17000.00
0005435438418	24585	Economy	17000.00
0005435682624	24585	Economy	17000.00
0005435438429	24585	Economy	17000.00
0005435438431	24585	Economy	18700.00
0005435682709	24585	Economy	18700.00
0005435438430	24585	Economy	18700.00
0005435438422	24585	Economy	18700.00
0005435219244	24585	Economy	17000.00
0005432305802	24585	Economy	17000.00
0005435682716	24585	Economy	17000.00
0005435682765	24585	Economy	17000.00
0005434828758	24585	Economy	17000.00
0005435682714	24585	Economy	17000.00
0005435220504	24585	Economy	17000.00
0005435438434	24585	Economy	17000.00
0005435438423	24585	Economy	17000.00
0005435438427	24585	Economy	17000.00
0005435220505	24585	Economy	17000.00
0005432533355	24585	Economy	17000.00
0005435682625	24585	Economy	17000.00
0005432533353	24585	Economy	17000.00
0005435682600	24585	Economy	17000.00
0005435682649	24585	Economy	17000.00
0005435682557	24585	Economy	17000.00
0005435682605	24585	Economy	17000.00
0005435682711	24585	Economy	17000.00
0005435682712	24585	Economy	17000.00
0005432305801	24585	Economy	17000.00
0005435720840	24585	Economy	17000.00
0005435682558	24585	Economy	17000.00
0005435438437	24585	Economy	17000.00
0005432533352	24585	Economy	17000.00
0005435682795	24585	Economy	17000.00
0005435682666	24585	Economy	17000.00
0005435682604	24585	Economy	17000.00
0005435682701	24585	Economy	17000.00
0005435682713	24585	Economy	17000.00
0005435682615	24585	Economy	17000.00
0005435438417	24585	Economy	17000.00
0005435682760	24585	Economy	17000.00
0005435438424	24585	Economy	17000.00
0005435682619	24585	Economy	17000.00
0005435720838	24585	Economy	17000.00
0005435661978	24585	Economy	17000.00
0005435220508	24585	Economy	17000.00
0005435719572	24585	Economy	17000.00
0005435720839	24585	Economy	17000.00
0005435682538	24585	Economy	17000.00
0005435220503	24585	Economy	17000.00
0005435682660	24585	Economy	17000.00
0005435438425	24585	Economy	17000.00
0005435682533	24585	Economy	17000.00
0005435682599	24585	Economy	17000.00
0005435682621	24585	Economy	17000.00
0005435682614	24585	Economy	17000.00
0005434828757	24585	Economy	17000.00
0005435682598	24585	Economy	17000.00
0005435682807	24585	Economy	17000.00
0005435438433	24585	Economy	17000.00
0005435438426	24585	Economy	17000.00
0005435682628	24585	Economy	17000.00
0005435682669	24585	Economy	17000.00
0005435682539	24585	Economy	17000.00
0005435682629	24585	Economy	17000.00
0005435438419	24585	Economy	17000.00
0005435438435	24585	Economy	17000.00
0005435682601	24585	Economy	17000.00
0005435682719	24585	Economy	17000.00
0005435682618	24585	Economy	17000.00
0005435220506	24585	Economy	17000.00
0005435219246	24585	Economy	17000.00
0005435558115	11545	Business	26400.00
0005435127204	11545	Business	26400.00
0005435127228	11545	Business	26400.00
0005435127207	11545	Business	26400.00
0005435127224	11545	Business	26400.00
0005435558111	11545	Business	26400.00
0005435127217	11545	Business	26400.00
0005435106049	11545	Business	26400.00
0005435127205	11545	Business	26400.00
0005435127197	11545	Economy	8800.00
0005435127200	11545	Economy	8800.00
0005435127215	11545	Economy	8800.00
0005435127221	11545	Economy	8800.00
0005435127208	11545	Economy	8800.00
0005435127196	11545	Economy	8800.00
0005435127193	11545	Economy	9700.00
0005435127191	11545	Economy	9700.00
0005435127194	11545	Economy	8800.00
0005435127198	11545	Economy	8800.00
0005435127212	11545	Economy	8800.00
0005435127201	11545	Economy	8800.00
0005435127214	11545	Economy	8800.00
0005435127222	11545	Economy	8800.00
0005435127202	11545	Economy	8800.00
0005435127211	11545	Economy	8800.00
0005435558120	11545	Economy	8800.00
0005435127220	11545	Economy	8800.00
0005435127209	11545	Economy	8800.00
0005435127213	11545	Economy	8800.00
0005435127225	11545	Economy	8800.00
0005435127203	11545	Economy	8800.00
0005435127206	11545	Economy	8800.00
0005435127216	11545	Economy	8800.00
0005435127199	11545	Economy	8800.00
0005435127226	11545	Economy	8800.00
0005435127192	11545	Economy	8800.00
0005435127223	11545	Economy	8800.00
0005435127227	11545	Economy	8800.00
0005435558126	11545	Economy	8800.00
0005435127190	11545	Economy	8800.00
0005435127210	11545	Economy	8800.00
0005435106048	11545	Economy	8800.00
0005435127219	11545	Economy	8800.00
0005435558119	11545	Economy	8800.00
0005435106047	11545	Economy	8800.00
0005435127195	11545	Economy	8800.00
0005435127218	11545	Economy	8800.00
0005435126944	31858	Business	26400.00
0005435106023	31858	Business	26400.00
0005435098574	31858	Business	26400.00
0005435126801	31858	Business	26400.00
0005435126775	31858	Business	26400.00
0005435126906	31858	Economy	8800.00
0005435558144	31858	Economy	8800.00
0005435126854	31858	Economy	8800.00
0005435127052	31858	Economy	8800.00
0005435126845	31858	Economy	9700.00
0005435126747	31858	Economy	9700.00
0005435127014	31858	Economy	9700.00
0005435126855	31858	Economy	9700.00
0005435126838	31858	Economy	8800.00
0005435126870	31858	Economy	8800.00
0005435126857	31858	Economy	8800.00
0005435126666	31858	Economy	8800.00
0005435127015	31858	Economy	8800.00
0005435106022	31858	Economy	8800.00
0005435126846	31858	Economy	8800.00
0005435126943	31858	Economy	8800.00
0005435126902	31858	Economy	8800.00
0005435127044	31858	Economy	8800.00
0005435126898	31858	Economy	8800.00
0005435126965	31858	Economy	8800.00
0005435126871	31858	Economy	8800.00
0005435126783	31858	Economy	8800.00
0005435098575	31858	Economy	8800.00
0005435126968	31858	Economy	8800.00
0005435126780	31858	Economy	8800.00
0005435126771	31858	Economy	8800.00
0005435126795	31858	Economy	8800.00
0005435126803	31858	Economy	8800.00
0005435098586	31858	Economy	8800.00
0005435127049	31858	Economy	8800.00
0005435126930	31858	Economy	8800.00
0005435126853	31858	Economy	8800.00
0005435126929	31858	Economy	8800.00
0005435126903	31858	Economy	8800.00
0005435126837	31858	Economy	8800.00
0005435126802	31858	Economy	8800.00
0005435126784	31858	Economy	8800.00
0005435126901	31858	Economy	8800.00
0005435126748	31858	Economy	8800.00
0005433399100	13514	Business	36600.00
0005433399112	13514	Business	36600.00
0005435732470	13514	Business	36600.00
0005433399113	13514	Business	36600.00
0005433399068	13514	Business	36600.00
0005433399106	13514	Business	36600.00
0005433399117	13514	Business	36600.00
0005433399108	13514	Economy	12200.00
0005433399092	13514	Economy	12200.00
0005435732474	13514	Economy	12200.00
0005435732496	13514	Economy	12200.00
0005433399115	13514	Economy	12200.00
0005433399089	13514	Economy	12200.00
0005433399098	13514	Economy	12200.00
0005435732462	13514	Economy	13400.00
0005433399080	13514	Economy	13400.00
0005433399087	13514	Economy	13400.00
0005433399103	13514	Economy	12200.00
0005433399071	13514	Economy	12200.00
0005433399075	13514	Economy	12200.00
0005433399116	13514	Economy	12200.00
0005435732490	13514	Economy	12200.00
0005433399079	13514	Economy	12200.00
0005433399110	13514	Economy	12200.00
0005435732427	13514	Economy	12200.00
0005435732473	13514	Economy	12200.00
0005433399096	13514	Economy	12200.00
0005433399085	13514	Economy	12200.00
0005433399083	13514	Economy	12200.00
0005433399097	13514	Economy	12200.00
0005435732489	13514	Economy	12200.00
0005433399084	13514	Economy	12200.00
0005435732524	13514	Economy	12200.00
0005433399099	13514	Economy	12200.00
0005435732487	13514	Economy	12200.00
0005435732491	13514	Economy	12200.00
0005435732532	13514	Economy	12200.00
0005433399078	13514	Economy	12200.00
0005435732461	13514	Economy	12200.00
0005433399076	13514	Economy	12200.00
0005433399107	13514	Economy	12200.00
0005433399082	13514	Economy	12200.00
0005433399074	13514	Economy	12200.00
0005433399086	13514	Economy	12200.00
0005433399077	13514	Economy	12200.00
0005433399111	13514	Economy	12200.00
0005435732488	13514	Economy	12200.00
0005433399109	13514	Economy	12200.00
0005433399090	13514	Economy	12200.00
0005435732502	13514	Economy	12200.00
0005433399070	13514	Economy	12200.00
0005433399088	13514	Economy	12200.00
0005433399094	13514	Economy	12200.00
0005433399081	13514	Economy	12200.00
0005433399091	13514	Economy	12200.00
0005435732525	13514	Economy	12200.00
0005433399101	13514	Economy	12200.00
0005433399104	13514	Economy	12200.00
0005433399105	13514	Economy	12200.00
0005433399114	13514	Economy	12200.00
0005433399093	13514	Economy	12200.00
0005433399102	13514	Economy	12200.00
0005433399073	13514	Economy	12200.00
0005433399072	13514	Economy	12200.00
0005433399069	13514	Economy	12200.00
0005433399095	13514	Economy	12200.00
0005433398536	19409	Business	36600.00
0005433398519	19409	Business	36600.00
0005433398821	19409	Business	36600.00
0005433398538	19409	Business	36600.00
0005433398611	19409	Business	36600.00
0005433398587	19409	Business	36600.00
0005433398540	19409	Business	36600.00
0005433398626	19409	Business	36600.00
0005433398494	19409	Business	36600.00
0005433398586	19409	Economy	12200.00
0005433398553	19409	Economy	12200.00
0005433398839	19409	Economy	12200.00
0005433398689	19409	Economy	12200.00
0005433398811	19409	Economy	12200.00
0005433398421	19409	Economy	12200.00
0005433398815	19409	Economy	12200.00
0005433398632	19409	Economy	12200.00
0005433398590	19409	Economy	12200.00
0005432297333	19409	Economy	13400.00
0005433398554	19409	Economy	13400.00
0005433398529	19409	Economy	13400.00
0005433398565	19409	Economy	12200.00
0005433398671	19409	Economy	12200.00
0005433398657	19409	Economy	12200.00
0005433398623	19409	Economy	12200.00
0005433398752	19409	Economy	12200.00
0005433398690	19409	Economy	12200.00
0005433398663	19409	Economy	12200.00
0005433398769	19409	Economy	12200.00
0005433398548	19409	Economy	12200.00
0005433398635	19409	Economy	12200.00
0005433398863	19409	Economy	12200.00
0005433398531	19409	Economy	12200.00
0005433398750	19409	Economy	12200.00
0005433398736	19409	Economy	12200.00
0005433398537	19409	Economy	12200.00
0005433398667	19409	Economy	12200.00
0005432297335	19409	Economy	12200.00
0005433398624	19409	Economy	12200.00
0005433398598	19409	Economy	12200.00
0005432297334	19409	Economy	12200.00
0005433398503	19409	Economy	12200.00
0005433398790	19409	Economy	12200.00
0005433398630	19409	Economy	12200.00
0005433398715	19409	Economy	12200.00
0005433398668	19409	Economy	12200.00
0005433398580	19409	Economy	12200.00
0005433398678	19409	Economy	12200.00
0005433398739	19409	Economy	12200.00
0005433398728	19409	Economy	12200.00
0005433398729	19409	Economy	12200.00
0005433398581	19409	Economy	12200.00
0005433398658	19409	Economy	12200.00
0005433398799	19409	Economy	12200.00
0005433398749	19409	Economy	12200.00
0005433398629	19409	Economy	12200.00
0005433398672	19409	Economy	12200.00
0005433398539	19409	Economy	12200.00
0005433398664	19409	Economy	12200.00
0005433398631	19409	Economy	12200.00
0005433398469	19409	Economy	12200.00
0005433398822	19409	Economy	12200.00
0005433398530	19409	Economy	12200.00
0005433398798	19409	Economy	12200.00
0005433398541	19409	Economy	12200.00
0005435069502	13146	Business	11300.00
0005435069822	13146	Business	11300.00
0005435069736	13146	Business	11300.00
0005435069777	13146	Business	11300.00
0005435069503	13146	Business	11300.00
0005435069631	13146	Business	11300.00
0005435069542	13146	Business	11300.00
0005435069450	13146	Business	11300.00
0005435069598	13146	Business	11300.00
0005435069664	13146	Economy	3800.00
0005435069606	13146	Economy	3800.00
0005435069663	13146	Economy	3800.00
0005435069545	13146	Economy	3800.00
0005435069498	13146	Economy	3800.00
0005435069547	13146	Economy	3800.00
0005435069568	13146	Economy	3800.00
0005435069561	13146	Economy	4100.00
0005435069770	13146	Economy	4100.00
0005435069619	13146	Economy	4100.00
0005435069517	13146	Economy	4100.00
0005435069766	13146	Economy	3800.00
0005435069718	13146	Economy	3800.00
0005435069567	13146	Economy	3800.00
0005435069835	13146	Economy	3800.00
0005435069696	13146	Economy	3800.00
0005435069799	13146	Economy	3800.00
0005435069720	13146	Economy	3800.00
0005435069824	13146	Economy	3800.00
0005435069752	13146	Economy	3800.00
0005435069806	13146	Economy	3800.00
0005435069536	13146	Economy	3800.00
0005435069562	13146	Economy	3800.00
0005435069544	13146	Economy	3800.00
0005435069672	13146	Economy	3800.00
0005435069668	13146	Economy	3800.00
0005435069636	13146	Economy	3800.00
0005435069797	13146	Economy	3800.00
0005435069825	13146	Economy	3800.00
0005435069771	13146	Economy	3800.00
0005435069499	13146	Economy	3800.00
0005435069546	13146	Economy	3800.00
0005435069707	13146	Economy	3800.00
0005435069695	13146	Economy	3800.00
0005435069655	13146	Economy	3800.00
0005435069656	13146	Economy	3800.00
0005435069600	13146	Economy	3800.00
0005435069800	13146	Economy	3800.00
0005435069681	13146	Economy	3800.00
0005435069729	13146	Economy	3800.00
0005435069708	13146	Economy	3800.00
0005435069706	13146	Economy	3800.00
0005435069719	13146	Economy	3800.00
0005435069667	13146	Economy	3800.00
0005435069816	13146	Economy	3800.00
0005435069618	13146	Economy	3800.00
0005435069671	13146	Economy	3800.00
0005435069798	13146	Economy	3800.00
0005435069775	13146	Economy	3800.00
0005435925417	15470	Business	11300.00
0005435070142	15470	Business	11300.00
0005435925418	15470	Business	11300.00
0005435070135	15470	Business	11300.00
0005435070126	15470	Business	11300.00
0005435070161	15470	Business	11300.00
0005435070149	15470	Business	11300.00
0005435070123	15470	Economy	3800.00
0005435070132	15470	Economy	3800.00
0005435070147	15470	Economy	3800.00
0005435070159	15470	Economy	3800.00
0005435070155	15470	Economy	3800.00
0005435925414	15470	Economy	3800.00
0005435070154	15470	Economy	4100.00
0005435925433	15470	Economy	4100.00
0005435070150	15470	Economy	4100.00
0005435070139	15470	Economy	4100.00
0005435070163	15470	Economy	3800.00
0005435070133	15470	Economy	3800.00
0005435070130	15470	Economy	3800.00
0005435070122	15470	Economy	3800.00
0005435070164	15470	Economy	3800.00
0005435925446	15470	Economy	3800.00
0005435070169	15470	Economy	3800.00
0005435070125	15470	Economy	3800.00
0005435070165	15470	Economy	3800.00
0005435925447	15470	Economy	3800.00
0005435925435	15470	Economy	3800.00
0005435070146	15470	Economy	3800.00
0005435070127	15470	Economy	3800.00
0005435925457	15470	Economy	3800.00
0005435070162	15470	Economy	3800.00
0005435070124	15470	Economy	3800.00
0005435925477	15470	Economy	3800.00
0005435070136	15470	Economy	3800.00
0005435925440	15470	Economy	3800.00
0005435070170	15470	Economy	3800.00
0005435070167	15470	Economy	3800.00
0005435925448	15470	Economy	3800.00
0005435070157	15470	Economy	3800.00
0005435070160	15470	Economy	3800.00
0005435070153	15470	Economy	3800.00
0005435070138	15470	Economy	3800.00
0005435070145	15470	Economy	3800.00
0005435070119	15470	Economy	3800.00
0005435070156	15470	Economy	3800.00
0005435070134	15470	Economy	3800.00
0005435070143	15470	Economy	3800.00
0005435070129	15470	Economy	3800.00
0005435070141	15470	Economy	3800.00
0005435070137	15470	Economy	3800.00
0005435070148	15470	Economy	3800.00
0005435925453	15470	Economy	3800.00
0005435070166	15470	Economy	3800.00
0005435070131	15470	Economy	3800.00
0005435925458	15470	Economy	3800.00
0005435070168	15470	Economy	3800.00
0005435070158	15470	Economy	3800.00
0005435925481	15470	Economy	3800.00
0005435925464	15470	Economy	3800.00
0005435925460	15470	Economy	3800.00
0005435070152	15470	Economy	3800.00
0005435070151	15470	Economy	3800.00
0005435070120	15470	Economy	3800.00
0005435070128	15470	Economy	3800.00
0005435070144	15470	Economy	3800.00
0005435925466	15470	Economy	3800.00
0005435070140	15470	Economy	3800.00
0005435070121	15470	Economy	3800.00
0005435808434	23197	Economy	27100.00
0005433407612	23197	Economy	24700.00
0005435808421	23197	Economy	24700.00
0005435808431	23197	Economy	24700.00
0005433407599	23197	Economy	24700.00
0005435808438	23197	Economy	24700.00
0005435808436	23197	Economy	24700.00
0005435808428	23197	Economy	24700.00
0005435808435	23197	Economy	24700.00
0005435808433	23197	Economy	24700.00
0005433407601	23197	Economy	24700.00
0005435808427	23197	Economy	24700.00
0005435808432	23197	Economy	24700.00
0005435808425	23197	Economy	24700.00
0005435808437	23197	Economy	24700.00
0005435808430	23197	Economy	24700.00
0005435808422	23197	Economy	24700.00
0005435808440	23197	Economy	24700.00
0005433407607	23197	Economy	24700.00
0005435808439	23197	Economy	24700.00
0005435808423	23197	Economy	24700.00
0005435808429	23197	Economy	24700.00
0005435808424	23197	Economy	24700.00
0005433407613	23197	Economy	24700.00
0005435808420	23197	Economy	24700.00
0005435808426	23197	Economy	24700.00
0005433407614	23197	Economy	24700.00
0005433407624	23197	Economy	24700.00
0005434757041	10693	Business	61300.00
0005434756757	10693	Business	61300.00
0005434757045	10693	Business	61300.00
0005434215528	10693	Business	61300.00
0005434215543	10693	Business	61300.00
0005434756940	10693	Business	61300.00
0005434756948	10693	Business	61300.00
0005434756888	10693	Business	61300.00
0005434215553	10693	Business	61300.00
0005434756863	10693	Business	61300.00
0005434756707	10693	Business	61300.00
0005434215508	10693	Business	61300.00
0005434756939	10693	Economy	20400.00
0005434756934	10693	Economy	20400.00
0005434215516	10693	Economy	20400.00
0005434756780	10693	Economy	20400.00
0005434215533	10693	Economy	20400.00
0005434756933	10693	Economy	20400.00
0005434757002	10693	Economy	20400.00
0005434215548	10693	Economy	20400.00
0005434756941	10693	Economy	20400.00
0005434215509	10693	Economy	22500.00
0005434756818	10693	Economy	22500.00
0005434215515	10693	Economy	22500.00
0005434756844	10693	Economy	22500.00
0005434215524	10693	Economy	20400.00
0005434215551	10693	Economy	20400.00
0005434215512	10693	Economy	20400.00
0005434215534	10693	Economy	20400.00
0005434756966	10693	Economy	20400.00
0005434756938	10693	Economy	20400.00
0005434215518	10693	Economy	20400.00
0005434215541	10693	Economy	20400.00
0005434215526	10693	Economy	20400.00
0005434757001	10693	Economy	20400.00
0005434215513	10693	Economy	20400.00
0005434215545	10693	Economy	20400.00
0005434215520	10693	Economy	20400.00
0005434757036	10693	Economy	20400.00
0005434215514	10693	Economy	20400.00
0005434215536	10693	Economy	20400.00
0005434215517	10693	Economy	20400.00
0005434756984	10693	Economy	20400.00
0005434757044	10693	Economy	20400.00
0005434756864	10693	Economy	20400.00
0005434756987	10693	Economy	20400.00
0005434215531	10693	Economy	20400.00
0005434215552	10693	Economy	20400.00
0005434756926	10693	Economy	20400.00
0005434757027	10693	Economy	20400.00
0005434756781	10693	Economy	20400.00
0005434215540	10693	Economy	20400.00
0005434215522	10693	Economy	20400.00
0005434215539	10693	Economy	20400.00
0005434756965	10693	Economy	20400.00
0005434215510	10693	Economy	20400.00
0005434215527	10693	Economy	20400.00
0005434215537	10693	Economy	20400.00
0005434756927	10693	Economy	20400.00
0005434756981	10693	Economy	20400.00
0005434215535	10693	Economy	20400.00
0005434215521	10693	Economy	20400.00
0005434215530	10693	Economy	20400.00
0005434757029	10693	Economy	20400.00
0005434215529	10693	Economy	20400.00
0005434215523	10693	Economy	20400.00
0005434215549	10693	Economy	20400.00
0005434215546	10693	Economy	20400.00
0005434215519	10693	Economy	20400.00
0005434756986	10693	Economy	20400.00
0005434756777	10693	Economy	20400.00
0005434215542	10693	Economy	20400.00
0005434756985	10693	Economy	20400.00
0005434756949	10693	Economy	20400.00
0005434215525	10693	Economy	20400.00
0005434757040	10693	Economy	20400.00
0005434215511	10693	Economy	20400.00
0005434756957	10693	Economy	20400.00
0005434215544	10693	Economy	20400.00
0005434756819	10693	Economy	20400.00
0005434215507	10693	Economy	20400.00
0005434756766	10693	Economy	20400.00
0005434756882	10693	Economy	20400.00
0005434215532	10693	Economy	20400.00
0005434756983	10693	Economy	20400.00
0005434215550	10693	Economy	20400.00
0005434756778	10693	Economy	20400.00
0005434215538	10693	Economy	20400.00
0005434756831	10693	Economy	20400.00
0005434215547	10693	Economy	20400.00
0005434757028	10693	Economy	20400.00
0005434215130	28656	Business	61300.00
0005434214862	28656	Business	61300.00
0005434215164	28656	Business	61300.00
0005434757290	28656	Business	61300.00
0005434757259	28656	Business	61300.00
0005434214993	28656	Business	61300.00
0005434215030	28656	Business	61300.00
0005434215158	28656	Business	61300.00
0005434215040	28656	Business	61300.00
0005434214828	28656	Business	61300.00
0005434757268	28656	Economy	20400.00
0005434215214	28656	Economy	20400.00
0005434757254	28656	Economy	20400.00
0005434757272	28656	Economy	20400.00
0005434215134	28656	Economy	20400.00
0005434757270	28656	Economy	20400.00
0005434214944	28656	Economy	20400.00
0005434757257	28656	Economy	20400.00
0005434215023	28656	Economy	20400.00
0005434214853	28656	Economy	20400.00
0005434214999	28656	Economy	22500.00
0005434215102	28656	Economy	22500.00
0005434757263	28656	Economy	22500.00
0005434757275	28656	Economy	22500.00
0005434214909	28656	Economy	22500.00
0005434757274	28656	Economy	20400.00
0005434214916	28656	Economy	20400.00
0005434214917	28656	Economy	20400.00
0005434215103	28656	Economy	20400.00
0005434757284	28656	Economy	20400.00
0005434757253	28656	Economy	20400.00
0005434215008	28656	Economy	20400.00
0005434215039	28656	Economy	20400.00
0005434757277	28656	Economy	20400.00
0005434757252	28656	Economy	20400.00
0005434214940	28656	Economy	20400.00
0005434214984	28656	Economy	20400.00
0005434757282	28656	Economy	20400.00
0005434215105	28656	Economy	20400.00
0005434215119	28656	Economy	20400.00
0005434757286	28656	Economy	20400.00
0005434214830	28656	Economy	20400.00
0005434214938	28656	Economy	20400.00
0005434757287	28656	Economy	20400.00
0005434214985	28656	Economy	20400.00
0005434215116	28656	Economy	20400.00
0005434757288	28656	Economy	20400.00
0005434215132	28656	Economy	20400.00
0005434757262	28656	Economy	20400.00
0005434757260	28656	Economy	20400.00
0005434214897	28656	Economy	20400.00
0005434757269	28656	Economy	20400.00
0005434757278	28656	Economy	20400.00
0005434215296	28656	Economy	20400.00
0005434214924	28656	Economy	20400.00
0005434757267	28656	Economy	20400.00
0005434757280	28656	Economy	20400.00
0005434757266	28656	Economy	20400.00
0005434757250	28656	Economy	20400.00
0005434215101	28656	Economy	20400.00
0005434757261	28656	Economy	20400.00
0005434757271	28656	Economy	20400.00
0005434215026	28656	Economy	20400.00
0005434215028	28656	Economy	20400.00
0005434215011	28656	Economy	20400.00
0005434214867	28656	Economy	20400.00
0005434757276	28656	Economy	20400.00
0005434757264	28656	Economy	20400.00
0005434215064	28656	Economy	20400.00
0005434757258	28656	Economy	20400.00
0005434757251	28656	Economy	20400.00
0005434215159	28656	Economy	20400.00
0005434215117	28656	Economy	20400.00
0005434757279	28656	Economy	20400.00
0005434215294	28656	Economy	20400.00
0005434757285	28656	Economy	20400.00
0005434215133	28656	Economy	20400.00
0005434757248	28656	Economy	20400.00
0005434757273	28656	Economy	20400.00
0005434757256	28656	Economy	20400.00
0005434215198	28656	Economy	20400.00
0005434757247	28656	Economy	20400.00
0005434215295	28656	Economy	20400.00
0005434215163	28656	Economy	20400.00
0005434757255	28656	Economy	20400.00
0005434215208	28656	Economy	20400.00
0005434757249	28656	Economy	20400.00
0005434757265	28656	Economy	20400.00
0005434215129	28656	Economy	20400.00
0005434757281	28656	Economy	20400.00
0005434757283	28656	Economy	20400.00
0005434757289	28656	Economy	20400.00
0005435007520	5460	Business	29500.00
0005435041186	5460	Business	29500.00
0005435041155	5460	Business	29500.00
0005435041139	5460	Business	29500.00
0005434229609	5460	Business	29500.00
0005435007517	5460	Business	29500.00
0005435007536	5460	Business	29500.00
0005435041125	5460	Business	29500.00
0005435041128	5460	Business	29500.00
0005434229666	5460	Business	29500.00
0005435041140	5460	Business	29500.00
0005432125612	5460	Business	29500.00
0005435043298	5460	Economy	9800.00
0005435042902	5460	Economy	9800.00
0005435041143	5460	Economy	9800.00
0005435041164	5460	Economy	9800.00
0005435041144	5460	Economy	9800.00
0005435041169	5460	Economy	9800.00
0005435007526	5460	Economy	9800.00
0005435007538	5460	Economy	9800.00
0005432125607	5460	Economy	9800.00
0005435041154	5460	Economy	9800.00
0005434229566	5460	Economy	9800.00
0005434229590	5460	Economy	9800.00
0005435041136	5460	Economy	9800.00
0005435041175	5460	Economy	9800.00
0005435041134	5460	Economy	9800.00
0005435041129	5460	Economy	9800.00
0005435041157	5460	Economy	9800.00
0005435041145	5460	Economy	9800.00
0005435007531	5460	Economy	9800.00
0005434229716	5460	Economy	9800.00
0005435041148	5460	Economy	9800.00
0005435041147	5460	Economy	9800.00
0005434229588	5460	Economy	9800.00
0005435041167	5460	Economy	9800.00
0005435041152	5460	Economy	9800.00
0005434229779	5460	Economy	9800.00
0005435041180	5460	Economy	9800.00
0005435007528	5460	Economy	9800.00
0005434229694	5460	Economy	9800.00
0005435007527	5460	Economy	9800.00
0005434229698	5460	Economy	9800.00
0005435041171	5460	Economy	9800.00
0005435007539	5460	Economy	9800.00
0005432125610	5460	Economy	9800.00
0005435041189	5460	Economy	9800.00
0005435041177	5460	Economy	9800.00
0005435041131	5460	Economy	9800.00
0005434229619	5460	Economy	9800.00
0005435042906	5460	Economy	9800.00
0005435007522	5460	Economy	9800.00
0005435041149	5460	Economy	10800.00
0005434229676	5460	Economy	10800.00
0005435041176	5460	Economy	10800.00
0005432125608	5460	Economy	10800.00
0005435007519	5460	Economy	10800.00
0005435007529	5460	Economy	9800.00
0005435041153	5460	Economy	9800.00
0005435041163	5460	Economy	9800.00
0005435041127	5460	Economy	9800.00
0005434229669	5460	Economy	9800.00
0005435041133	5460	Economy	9800.00
0005434229664	5460	Economy	9800.00
0005435007525	5460	Economy	9800.00
0005435042905	5460	Economy	9800.00
0005435041161	5460	Economy	9800.00
0005435007518	5460	Economy	9800.00
0005435041174	5460	Economy	9800.00
0005435007535	5460	Economy	9800.00
0005435041124	5460	Economy	9800.00
0005435041179	5460	Economy	9800.00
0005435041165	5460	Economy	9800.00
0005435041187	5460	Economy	9800.00
0005432125606	5460	Economy	9800.00
0005435041142	5460	Economy	9800.00
0005435041160	5460	Economy	9800.00
0005432125609	5460	Economy	9800.00
0005435042903	5460	Economy	9800.00
0005435041130	5460	Economy	9800.00
0005435041138	5460	Economy	9800.00
0005435041146	5460	Economy	9800.00
0005435041158	5460	Economy	9800.00
0005432125611	5460	Economy	9800.00
0005435041159	5460	Economy	9800.00
0005435041181	5460	Economy	9800.00
0005435007537	5460	Economy	9800.00
0005434229727	5460	Economy	9800.00
0005435041173	5460	Economy	9800.00
0005435041166	5460	Economy	9800.00
0005435041162	5460	Economy	9800.00
0005435041137	5460	Economy	9800.00
0005434229668	5460	Economy	9800.00
0005435007530	5460	Economy	9800.00
0005435042904	5460	Economy	9800.00
0005435041184	5460	Economy	9800.00
0005435041141	5460	Economy	9800.00
0005435041150	5460	Economy	9800.00
0005434229589	5460	Economy	9800.00
0005435041168	5460	Economy	9800.00
0005435041132	5460	Economy	9800.00
0005435041123	5460	Economy	9800.00
0005434229565	5460	Economy	9800.00
0005435007532	5460	Economy	9800.00
0005435041156	5460	Economy	9800.00
0005435007533	5460	Economy	9800.00
0005435041185	5460	Economy	9800.00
0005434229665	5460	Economy	9800.00
0005435041170	5460	Economy	9800.00
0005435041188	5460	Economy	9800.00
0005435007523	5460	Economy	9800.00
0005434229652	5460	Economy	9800.00
0005435041183	5460	Economy	9800.00
0005435007534	5460	Economy	9800.00
0005434229659	5460	Economy	9800.00
0005435041172	5460	Economy	9800.00
0005435041182	5460	Economy	9800.00
0005435041126	5460	Economy	9800.00
0005432125613	5460	Economy	9800.00
0005435041135	5460	Economy	9800.00
0005435041151	5460	Economy	9800.00
0005434229675	5460	Economy	9800.00
0005435041178	5460	Economy	9800.00
0005435041122	5460	Economy	9800.00
0005434229608	5460	Economy	9800.00
0005435007524	5460	Economy	9800.00
0005435007521	5460	Economy	9800.00
0005435040649	13000	Business	29500.00
0005435040657	13000	Business	29500.00
0005435040813	13000	Business	29500.00
0005435040257	13000	Business	29500.00
0005435040549	13000	Business	29500.00
0005435007290	13000	Business	29500.00
0005435040535	13000	Business	29500.00
0005435040898	13000	Business	29500.00
0005435040746	13000	Business	29500.00
0005435007217	13000	Business	29500.00
0005435040601	13000	Business	29500.00
0005435040656	13000	Business	29500.00
0005435040600	13000	Economy	9800.00
0005435040418	13000	Economy	9800.00
0005435040701	13000	Economy	9800.00
0005435007313	13000	Economy	9800.00
0005435042874	13000	Economy	9800.00
0005435040852	13000	Economy	9800.00
0005435040459	13000	Economy	9800.00
0005434229851	13000	Economy	9800.00
0005435040814	13000	Economy	9800.00
0005432304481	13000	Economy	9800.00
0005435040551	13000	Economy	9800.00
0005435040346	13000	Economy	9800.00
0005435007332	13000	Economy	9800.00
0005435040256	13000	Economy	9800.00
0005435040337	13000	Economy	9800.00
0005434229865	13000	Economy	9800.00
0005435040792	13000	Economy	9800.00
0005435040721	13000	Economy	9800.00
0005434229848	13000	Economy	9800.00
0005435007314	13000	Economy	9800.00
0005435040150	13000	Economy	9800.00
0005435007306	13000	Economy	9800.00
0005435040336	13000	Economy	9800.00
0005435040711	13000	Economy	9800.00
0005435040899	13000	Economy	9800.00
0005435007287	13000	Economy	9800.00
0005434229866	13000	Economy	9800.00
0005435040553	13000	Economy	9800.00
0005435040564	13000	Economy	9800.00
0005434229846	13000	Economy	9800.00
0005434229856	13000	Economy	9800.00
0005434229853	13000	Economy	9800.00
0005434229864	13000	Economy	9800.00
0005435040793	13000	Economy	9800.00
0005435042879	13000	Economy	9800.00
0005435040503	13000	Economy	9800.00
0005435040417	13000	Economy	9800.00
0005435040720	13000	Economy	9800.00
0005435040610	13000	Economy	10800.00
0005435040395	13000	Economy	10800.00
0005435040502	13000	Economy	10800.00
0005434229850	13000	Economy	10800.00
0005435042880	13000	Economy	10800.00
0005435040646	13000	Economy	10800.00
0005434229852	13000	Economy	9800.00
0005434229845	13000	Economy	9800.00
0005435040608	13000	Economy	9800.00
0005435007317	13000	Economy	9800.00
0005435040437	13000	Economy	9800.00
0005434229854	13000	Economy	9800.00
0005435007257	13000	Economy	9800.00
0005435007300	13000	Economy	9800.00
0005435040710	13000	Economy	9800.00
0005435040550	13000	Economy	9800.00
0005435007255	13000	Economy	9800.00
0005435040910	13000	Economy	9800.00
0005435007223	13000	Economy	9800.00
0005435007261	13000	Economy	9800.00
0005435007367	13000	Economy	9800.00
0005435040496	13000	Economy	9800.00
0005435040298	13000	Economy	9800.00
0005435007283	13000	Economy	9800.00
0005435040635	13000	Economy	9800.00
0005435040719	13000	Economy	9800.00
0005434229860	13000	Economy	9800.00
0005435040652	13000	Economy	9800.00
0005435040901	13000	Economy	9800.00
0005435040529	13000	Economy	9800.00
0005435007382	13000	Economy	9800.00
0005435040520	13000	Economy	9800.00
0005435007260	13000	Economy	9800.00
0005435007302	13000	Economy	9800.00
0005434229849	13000	Economy	9800.00
0005435040647	13000	Economy	9800.00
0005434229855	13000	Economy	9800.00
0005435040505	13000	Economy	9800.00
0005435040648	13000	Economy	9800.00
0005435040639	13000	Economy	9800.00
0005435007383	13000	Economy	9800.00
0005435007256	13000	Economy	9800.00
0005435040668	13000	Economy	9800.00
0005435040255	13000	Economy	9800.00
0005434229862	13000	Economy	9800.00
0005435040655	13000	Economy	9800.00
0005434229847	13000	Economy	9800.00
0005435040544	13000	Economy	9800.00
0005435007305	13000	Economy	9800.00
0005435040747	13000	Economy	9800.00
0005434229857	13000	Economy	9800.00
0005435040498	13000	Economy	9800.00
0005435040651	13000	Economy	9800.00
0005435040542	13000	Economy	9800.00
0005435040745	13000	Economy	9800.00
0005435040887	13000	Economy	9800.00
0005435040577	13000	Economy	9800.00
0005435007318	13000	Economy	9800.00
0005432304483	13000	Economy	9800.00
0005434229863	13000	Economy	9800.00
0005435007218	13000	Economy	9800.00
0005435007282	13000	Economy	9800.00
0005435007289	13000	Economy	9800.00
0005434229861	13000	Economy	9800.00
0005434229867	13000	Economy	9800.00
0005435040911	13000	Economy	9800.00
0005435040638	13000	Economy	9800.00
0005434229858	13000	Economy	9800.00
0005435040778	13000	Economy	9800.00
0005435007422	13000	Economy	9800.00
0005435040634	13000	Economy	9800.00
0005435040394	13000	Economy	9800.00
0005435040517	13000	Economy	9800.00
0005432304482	13000	Economy	9800.00
0005435040528	13000	Economy	9800.00
0005434229859	13000	Economy	9800.00
0005434427208	14878	Business	52900.00
0005434427215	14878	Business	52900.00
0005432188677	14878	Business	52900.00
0005435902943	14878	Business	52900.00
0005434427203	14878	Business	52900.00
0005434427229	14878	Business	52900.00
0005435902755	14878	Economy	17600.00
0005434427224	14878	Economy	17600.00
0005435902903	14878	Economy	17600.00
0005434427220	14878	Economy	17600.00
0005434411865	14878	Economy	17600.00
0005434427221	14878	Economy	17600.00
0005434427216	14878	Economy	17600.00
0005434427227	14878	Economy	17600.00
0005434427200	14878	Economy	19400.00
0005435902939	14878	Economy	19400.00
0005432188676	14878	Economy	17600.00
0005435902754	14878	Economy	17600.00
0005435902890	14878	Economy	17600.00
0005434427212	14878	Economy	17600.00
0005435902916	14878	Economy	17600.00
0005434427226	14878	Economy	17600.00
0005432188674	14878	Economy	17600.00
0005434427206	14878	Economy	17600.00
0005435902918	14878	Economy	17600.00
0005434427214	14878	Economy	17600.00
0005434427217	14878	Economy	17600.00
0005434427219	14878	Economy	17600.00
0005434427223	14878	Economy	17600.00
0005435554233	14878	Economy	17600.00
0005434427201	14878	Economy	17600.00
0005435902879	14878	Economy	17600.00
0005434427230	14878	Economy	17600.00
0005434427222	14878	Economy	17600.00
0005434427207	14878	Economy	17600.00
0005434427210	14878	Economy	17600.00
0005435902917	14878	Economy	17600.00
0005435903000	14878	Economy	17600.00
0005434427228	14878	Economy	17600.00
0005435902958	14878	Economy	17600.00
0005434427205	14878	Economy	17600.00
0005434427211	14878	Economy	17600.00
0005435902889	14878	Economy	17600.00
0005434427225	14878	Economy	17600.00
0005435902972	14878	Economy	17600.00
0005435554234	14878	Economy	17600.00
0005434427202	14878	Economy	17600.00
0005434427218	14878	Economy	17600.00
0005435554255	14878	Economy	17600.00
0005435902995	14878	Economy	17600.00
0005432188675	14878	Economy	17600.00
0005434411867	14878	Economy	17600.00
0005434411868	14878	Economy	17600.00
0005434427213	14878	Economy	17600.00
0005435554254	14878	Economy	17600.00
0005435902996	14878	Economy	17600.00
0005434411866	14878	Economy	17600.00
0005434427209	14878	Economy	17600.00
0005434427204	14878	Economy	17600.00
0005435903080	20216	Business	52900.00
0005435903079	20216	Business	52900.00
0005435903093	20216	Business	52900.00
0005435903091	20216	Business	52900.00
0005434427061	20216	Business	52900.00
0005435903077	20216	Business	52900.00
0005434411842	20216	Business	52900.00
0005434427004	20216	Business	52900.00
0005434426908	20216	Economy	17600.00
0005432059548	20216	Economy	17600.00
0005434427006	20216	Economy	17600.00
0005435903092	20216	Economy	17600.00
0005434426944	20216	Economy	17600.00
0005434411819	20216	Economy	17600.00
0005434427070	20216	Economy	17600.00
0005435903078	20216	Economy	19400.00
0005435903089	20216	Economy	17600.00
0005435903085	20216	Economy	17600.00
0005434427010	20216	Economy	17600.00
0005434426981	20216	Economy	17600.00
0005434426975	20216	Economy	17600.00
0005434426931	20216	Economy	17600.00
0005434427059	20216	Economy	17600.00
0005435903090	20216	Economy	17600.00
0005434426945	20216	Economy	17600.00
0005435903082	20216	Economy	17600.00
0005434411839	20216	Economy	17600.00
0005435903094	20216	Economy	17600.00
0005434411828	20216	Economy	17600.00
0005435903086	20216	Economy	17600.00
0005434427002	20216	Economy	17600.00
0005434427040	20216	Economy	17600.00
0005434411822	20216	Economy	17600.00
0005435554295	20216	Economy	17600.00
0005434411829	20216	Economy	17600.00
0005434427007	20216	Economy	17600.00
0005434426940	20216	Economy	17600.00
0005435903088	20216	Economy	17600.00
0005435554293	20216	Economy	17600.00
0005434411833	20216	Economy	17600.00
0005434426970	20216	Economy	17600.00
0005434426923	20216	Economy	17600.00
0005432059547	20216	Economy	17600.00
0005435903083	20216	Economy	17600.00
0005434427071	20216	Economy	17600.00
0005434427082	20216	Economy	17600.00
0005434426963	20216	Economy	17600.00
0005434426885	20216	Economy	17600.00
0005434411838	20216	Economy	17600.00
0005435903087	20216	Economy	17600.00
0005434427108	20216	Economy	17600.00
0005434427003	20216	Economy	17600.00
0005434427072	20216	Economy	17600.00
0005435554292	20216	Economy	17600.00
0005434426971	20216	Economy	17600.00
0005435903084	20216	Economy	17600.00
0005434411823	20216	Economy	17600.00
0005435903081	20216	Economy	17600.00
0005435554294	20216	Economy	17600.00
0005432462534	30887	Business	106800.00
0005432462527	30887	Business	106800.00
0005434559117	30887	Business	106800.00
0005434559116	30887	Business	106800.00
0005432462536	30887	Business	106800.00
0005432462540	30887	Economy	35600.00
0005432462529	30887	Economy	35600.00
0005432462531	30887	Economy	35600.00
0005434523824	30887	Economy	35600.00
0005432462537	30887	Economy	35600.00
0005434559112	30887	Economy	35600.00
0005432462535	30887	Economy	35600.00
0005434523821	30887	Economy	35600.00
0005432462528	30887	Economy	35600.00
0005434559107	30887	Economy	35600.00
0005434523827	30887	Economy	39200.00
0005434523822	30887	Economy	39200.00
0005434523825	30887	Economy	39200.00
0005434559115	30887	Economy	35600.00
0005434523819	30887	Economy	35600.00
0005434559108	30887	Economy	35600.00
0005434559111	30887	Economy	35600.00
0005434559114	30887	Economy	35600.00
0005434559113	30887	Economy	35600.00
0005432462530	30887	Economy	35600.00
0005434559110	30887	Economy	35600.00
0005434523823	30887	Economy	35600.00
0005434523818	30887	Economy	35600.00
0005432462532	30887	Economy	35600.00
0005434523820	30887	Economy	35600.00
0005432462538	30887	Economy	35600.00
0005434559119	30887	Economy	35600.00
0005434523826	30887	Economy	35600.00
0005434559118	30887	Economy	35600.00
0005434559109	30887	Economy	35600.00
0005432462542	30887	Economy	35600.00
0005435983215	26551	Business	18500.00
0005435983212	26551	Business	18500.00
0005433435031	26551	Business	18500.00
0005435983201	26551	Business	18500.00
0005435983195	26551	Business	18500.00
0005433434977	26551	Business	18500.00
0005435983223	26551	Business	18500.00
0005434273097	26551	Business	18500.00
0005435983205	26551	Economy	6200.00
0005433435100	26551	Economy	6200.00
0005435983198	26551	Economy	6200.00
0005433435032	26551	Economy	6200.00
0005433435001	26551	Economy	6200.00
0005432300382	26551	Economy	6200.00
0005432300384	26551	Economy	6200.00
0005434270230	26551	Economy	6200.00
0005435983210	26551	Economy	6200.00
0005433434971	26551	Economy	6200.00
0005435983240	26551	Economy	6800.00
0005435983202	26551	Economy	6800.00
0005434270227	26551	Economy	6800.00
0005432300386	26551	Economy	6800.00
0005435983238	26551	Economy	6200.00
0005435983229	26551	Economy	6200.00
0005435983204	26551	Economy	6200.00
0005432300387	26551	Economy	6200.00
0005433435094	26551	Economy	6200.00
0005433435023	26551	Economy	6200.00
0005435983226	26551	Economy	6200.00
0005435983213	26551	Economy	6200.00
0005435983203	26551	Economy	6200.00
0005433434917	26551	Economy	6200.00
0005433434970	26551	Economy	6200.00
0005435983197	26551	Economy	6200.00
0005435983211	26551	Economy	6200.00
0005435983230	26551	Economy	6200.00
0005435983216	26551	Economy	6200.00
0005435983239	26551	Economy	6200.00
0005435983207	26551	Economy	6200.00
0005434270237	26551	Economy	6200.00
0005435983219	26551	Economy	6200.00
0005435983231	26551	Economy	6200.00
0005435983220	26551	Economy	6200.00
0005435983221	26551	Economy	6200.00
0005433435022	26551	Economy	6200.00
0005433435003	26551	Economy	6200.00
0005435983225	26551	Economy	6200.00
0005435983208	26551	Economy	6200.00
0005435983227	26551	Economy	6200.00
0005433435016	26551	Economy	6200.00
0005435983237	26551	Economy	6200.00
0005435983218	26551	Economy	6200.00
0005435983228	26551	Economy	6200.00
0005435983209	26551	Economy	6200.00
0005433435070	26551	Economy	6200.00
0005434270236	26551	Economy	6200.00
0005432300383	26551	Economy	6200.00
0005433435093	26551	Economy	6200.00
0005435983217	26551	Economy	6200.00
0005435983235	26551	Economy	6200.00
0005435983196	26551	Economy	6200.00
0005434273096	26551	Economy	6200.00
0005435983241	26551	Economy	6200.00
0005435983232	26551	Economy	6200.00
0005433435013	26551	Economy	6200.00
0005435983222	26551	Economy	6200.00
0005435983194	26551	Economy	6200.00
0005433434871	26551	Economy	6200.00
0005433435180	26551	Economy	6200.00
0005435983242	26551	Economy	6200.00
0005433435028	26551	Economy	6200.00
0005435983234	26551	Economy	6200.00
0005434270229	26551	Economy	6200.00
0005435983214	26551	Economy	6200.00
0005435983199	26551	Economy	6200.00
0005433435101	26551	Economy	6200.00
0005435983206	26551	Economy	6200.00
0005435983200	26551	Economy	6200.00
0005432300385	26551	Economy	6200.00
0005435983236	26551	Economy	6200.00
0005435983243	26551	Economy	6200.00
0005434270235	26551	Economy	6200.00
0005435983233	26551	Economy	6200.00
0005435983224	26551	Economy	6200.00
0005434270253	26716	Business	18500.00
0005435982781	26716	Business	18500.00
0005435982918	26716	Business	18500.00
0005435982816	26716	Business	18500.00
0005435982669	26716	Business	18500.00
0005433435301	26716	Business	18500.00
0005435982902	26716	Business	18500.00
0005435982833	26716	Business	18500.00
0005433435292	26716	Business	18500.00
0005433435283	26716	Business	18500.00
0005435982734	26716	Business	18500.00
0005433435296	26716	Business	18500.00
0005433435294	26716	Economy	6200.00
0005435982823	26716	Economy	6200.00
0005435982884	26716	Economy	6200.00
0005435982813	26716	Economy	6200.00
0005435982798	26716	Economy	6200.00
0005433435288	26716	Economy	6200.00
0005433435274	26716	Economy	6200.00
0005435982733	26716	Economy	6200.00
0005432051194	26716	Economy	6200.00
0005433435289	26716	Economy	6200.00
0005435982885	26716	Economy	6800.00
0005435982915	26716	Economy	6800.00
0005435982764	26716	Economy	6800.00
0005435982917	26716	Economy	6800.00
0005435982702	26716	Economy	6800.00
0005433435298	26716	Economy	6200.00
0005435982754	26716	Economy	6200.00
0005435982741	26716	Economy	6200.00
0005433435281	26716	Economy	6200.00
0005435982696	26716	Economy	6200.00
0005433435299	26716	Economy	6200.00
0005435982855	26716	Economy	6200.00
0005435982916	26716	Economy	6200.00
0005433435278	26716	Economy	6200.00
0005435982722	26716	Economy	6200.00
0005433435287	26716	Economy	6200.00
0005435982801	26716	Economy	6200.00
0005435982743	26716	Economy	6200.00
0005435982744	26716	Economy	6200.00
0005435982716	26716	Economy	6200.00
0005433435275	26716	Economy	6200.00
0005435982785	26716	Economy	6200.00
0005435982768	26716	Economy	6200.00
0005435982814	26716	Economy	6200.00
0005432051195	26716	Economy	6200.00
0005433435277	26716	Economy	6200.00
0005435982660	26716	Economy	6200.00
0005435982670	26716	Economy	6200.00
0005434271357	26716	Economy	6200.00
0005433435295	26716	Economy	6200.00
0005435982701	26716	Economy	6200.00
0005435982767	26716	Economy	6200.00
0005433435284	26716	Economy	6200.00
0005435982864	26716	Economy	6200.00
0005435982763	26716	Economy	6200.00
0005433435279	26716	Economy	6200.00
0005435982829	26716	Economy	6200.00
0005433435285	26716	Economy	6200.00
0005435982931	26716	Economy	6200.00
0005435982624	26716	Economy	6200.00
0005433435286	26716	Economy	6200.00
0005433435282	26716	Economy	6200.00
0005435982871	26716	Economy	6200.00
0005435982787	26716	Economy	6200.00
0005435982932	26716	Economy	6200.00
0005435982870	26716	Economy	6200.00
0005435982742	26716	Economy	6200.00
0005435982894	26716	Economy	6200.00
0005435982824	26716	Economy	6200.00
0005433435293	26716	Economy	6200.00
0005434270252	26716	Economy	6200.00
0005433435300	26716	Economy	6200.00
0005435982827	26716	Economy	6200.00
0005433435276	26716	Economy	6200.00
0005435982797	26716	Economy	6200.00
0005435982854	26716	Economy	6200.00
0005435982903	26716	Economy	6200.00
0005433435291	26716	Economy	6200.00
0005435982715	26716	Economy	6200.00
0005435982914	26716	Economy	6200.00
0005435982904	26716	Economy	6200.00
0005435982812	26716	Economy	6200.00
0005434269148	26716	Economy	6200.00
0005433435297	26716	Economy	6200.00
0005435982886	26716	Economy	6200.00
0005435982937	26716	Economy	6200.00
0005435982898	26716	Economy	6200.00
0005434270251	26716	Economy	6200.00
0005433435280	26716	Economy	6200.00
0005432051196	26716	Economy	6200.00
0005435982625	26716	Economy	6200.00
0005435982626	26716	Economy	6200.00
0005433435290	26716	Economy	6200.00
0005435982913	26716	Economy	6200.00
0005432216332	3158	Economy	11100.00
0005432584580	3158	Economy	11100.00
0005432216333	3158	Economy	11100.00
0005432858228	3158	Economy	11100.00
0005432584584	3158	Economy	10100.00
0005432584583	3158	Economy	10100.00
0005432858213	3158	Economy	10100.00
0005432584585	3158	Economy	10100.00
0005432584564	3158	Economy	10100.00
0005432584575	3158	Economy	10100.00
0005432584565	3158	Economy	10100.00
0005432584582	3158	Economy	10100.00
0005432584572	3158	Economy	10100.00
0005432584574	3158	Economy	10100.00
0005432584586	3158	Economy	10100.00
0005432584568	3158	Economy	10100.00
0005432584581	3158	Economy	10100.00
0005432584579	3158	Economy	10100.00
0005432216331	3158	Economy	10100.00
0005432584569	3158	Economy	10100.00
0005432584587	3158	Economy	10100.00
0005432584567	3158	Economy	10100.00
0005432584578	3158	Economy	10100.00
0005432584588	3158	Economy	10100.00
0005432584576	3158	Economy	10100.00
0005432216335	3158	Economy	10100.00
0005432216334	3158	Economy	10100.00
0005432584563	3158	Economy	10100.00
0005432584577	3158	Economy	10100.00
0005432584573	3158	Economy	10100.00
0005432584566	3158	Economy	10100.00
0005432584570	3158	Economy	10100.00
0005432858222	3158	Economy	10100.00
0005432584571	3158	Economy	10100.00
0005432584403	31487	Economy	11100.00
0005432584279	31487	Economy	11100.00
0005432858323	31487	Economy	11100.00
0005432858329	31487	Economy	10100.00
0005432584391	31487	Economy	10100.00
0005432584438	31487	Economy	10100.00
0005432584397	31487	Economy	10100.00
0005432584416	31487	Economy	10100.00
0005432584330	31487	Economy	10100.00
0005432584273	31487	Economy	10100.00
0005432858322	31487	Economy	10100.00
0005432858330	31487	Economy	10100.00
0005432584396	31487	Economy	10100.00
0005432858320	31487	Economy	10100.00
0005432858331	31487	Economy	10100.00
0005432584476	31487	Economy	10100.00
0005432858327	31487	Economy	10100.00
0005432584385	31487	Economy	10100.00
0005432858324	31487	Economy	10100.00
0005432858328	31487	Economy	10100.00
0005432858326	31487	Economy	10100.00
0005432858325	31487	Economy	10100.00
0005432858321	31487	Economy	10100.00
0005432584383	31487	Economy	10100.00
0005432584510	31487	Economy	10100.00
0005432584384	31487	Economy	10100.00
0005434943549	890	Economy	7500.00
0005434943548	890	Economy	7500.00
0005433255205	890	Economy	7500.00
0005434943550	890	Economy	7500.00
0005434943547	890	Economy	7500.00
0005434943551	890	Economy	7500.00
0005434943554	890	Economy	7500.00
0005434943546	890	Economy	7500.00
0005434943552	890	Economy	7500.00
0005433255171	890	Economy	7500.00
0005433255193	890	Economy	7500.00
0005434943553	890	Economy	7500.00
0005434943545	890	Economy	7500.00
0005433255238	16240	Economy	8300.00
0005433255233	16240	Economy	8300.00
0005434943491	16240	Economy	7500.00
0005433255237	16240	Economy	7500.00
0005434943446	16240	Economy	7500.00
0005434943450	16240	Economy	7500.00
0005434943480	16240	Economy	7500.00
0005434943490	16240	Economy	7500.00
0005434943452	16240	Economy	7500.00
0005433255234	16240	Economy	7500.00
0005434943494	16240	Economy	7500.00
0005433255235	16240	Economy	7500.00
0005434943481	16240	Economy	7500.00
0005434943478	16240	Economy	7500.00
0005433255236	16240	Economy	7500.00
0005434943493	16240	Economy	7500.00
0005434943465	16240	Economy	7500.00
0005435858640	27617	Business	90500.00
0005433654846	27617	Business	90500.00
0005433654806	27617	Business	90500.00
0005433654880	27617	Business	90500.00
0005435858648	27617	Business	90500.00
0005433654869	27617	Business	90500.00
0005433654801	27617	Economy	30200.00
0005435858650	27617	Economy	30200.00
0005433654838	27617	Economy	30200.00
0005435858651	27617	Economy	30200.00
0005433654856	27617	Economy	30200.00
0005435858656	27617	Economy	33200.00
0005433654855	27617	Economy	33200.00
0005435858644	27617	Economy	33200.00
0005435858645	27617	Economy	30200.00
0005433654861	27617	Economy	30200.00
0005433654816	27617	Economy	30200.00
0005433654844	27617	Economy	30200.00
0005433654876	27617	Economy	30200.00
0005435858641	27617	Economy	30200.00
0005435858642	27617	Economy	30200.00
0005435858643	27617	Economy	30200.00
0005435858655	27617	Economy	30200.00
0005433654905	27617	Economy	30200.00
0005435858653	27617	Economy	30200.00
0005435858652	27617	Economy	30200.00
0005435858649	27617	Economy	30200.00
0005433654859	27617	Economy	30200.00
0005433654862	27617	Economy	30200.00
0005433654860	27617	Economy	30200.00
0005433654805	27617	Economy	30200.00
0005433654879	27617	Economy	30200.00
0005435858654	27617	Economy	30200.00
0005435858647	27617	Economy	30200.00
0005433654828	27617	Economy	30200.00
0005433654845	27617	Economy	30200.00
0005433654863	27617	Economy	30200.00
0005433654868	27617	Economy	30200.00
0005433654815	27617	Economy	30200.00
0005435858646	27617	Economy	30200.00
0005433927522	14338	Economy	4400.00
0005433927523	14338	Economy	4400.00
0005433368141	21775	Business	9800.00
0005433368307	21775	Business	9800.00
0005433368341	21775	Business	9800.00
0005433368311	21775	Business	9800.00
0005435653960	21775	Business	9800.00
0005433368357	21775	Business	9800.00
0005435653999	21775	Business	9800.00
0005435654004	21775	Business	9800.00
0005433368268	21775	Business	9800.00
0005435654003	21775	Business	9800.00
0005435653976	21775	Business	9800.00
0005435653998	21775	Business	9800.00
0005433368350	21775	Economy	3300.00
0005435653968	21775	Economy	3300.00
0005435654005	21775	Economy	3300.00
0005433368136	21775	Economy	3300.00
0005435653975	21775	Economy	3300.00
0005435653970	21775	Economy	3300.00
0005435653961	21775	Economy	3300.00
0005435654002	21775	Economy	3300.00
0005435653967	21775	Economy	3300.00
0005435653984	21775	Economy	3600.00
0005435653995	21775	Economy	3600.00
0005435653979	21775	Economy	3600.00
0005433368253	21775	Economy	3300.00
0005435653990	21775	Economy	3300.00
0005435653983	21775	Economy	3300.00
0005435654001	21775	Economy	3300.00
0005435653988	21775	Economy	3300.00
0005433368220	21775	Economy	3300.00
0005435653974	21775	Economy	3300.00
0005433368232	21775	Economy	3300.00
0005435653989	21775	Economy	3300.00
0005433368287	21775	Economy	3300.00
0005433368293	21775	Economy	3300.00
0005435653977	21775	Economy	3300.00
0005433368292	21775	Economy	3300.00
0005435653981	21775	Economy	3300.00
0005435653964	21775	Economy	3300.00
0005433368336	21775	Economy	3300.00
0005433368135	21775	Economy	3300.00
0005433368354	21775	Economy	3300.00
0005433368249	21775	Economy	3300.00
0005433368459	21775	Economy	3300.00
0005435653991	21775	Economy	3300.00
0005433368226	21775	Economy	3300.00
0005435654007	21775	Economy	3300.00
0005435653982	21775	Economy	3300.00
0005433368410	21775	Economy	3300.00
0005433368242	21775	Economy	3300.00
0005433368345	21775	Economy	3300.00
0005435653996	21775	Economy	3300.00
0005435653971	21775	Economy	3300.00
0005433368335	21775	Economy	3300.00
0005435653973	21775	Economy	3300.00
0005433368506	21775	Economy	3300.00
0005435653966	21775	Economy	3300.00
0005433368331	21775	Economy	3300.00
0005435653965	21775	Economy	3300.00
0005433368250	21775	Economy	3300.00
0005435654000	21775	Economy	3300.00
0005435653986	21775	Economy	3300.00
0005433368340	21775	Economy	3300.00
0005435653969	21775	Economy	3300.00
0005435653994	21775	Economy	3300.00
0005433368424	21775	Economy	3300.00
0005435654006	21775	Economy	3300.00
0005435653993	21775	Economy	3300.00
0005433368333	21775	Economy	3300.00
0005433368225	21775	Economy	3300.00
0005435653992	21775	Economy	3300.00
0005433368548	21775	Economy	3300.00
0005433368269	21775	Economy	3300.00
0005435653963	21775	Economy	3300.00
0005433368472	21775	Economy	3300.00
0005435653962	21775	Economy	3300.00
0005435653987	21775	Economy	3300.00
0005433368330	21775	Economy	3300.00
0005433368342	21775	Economy	3300.00
0005433368296	21775	Economy	3300.00
0005435653997	21775	Economy	3300.00
0005433368286	21775	Economy	3300.00
0005433368277	21775	Economy	3300.00
0005435653985	21775	Economy	3300.00
0005435653972	21775	Economy	3300.00
0005435653980	21775	Economy	3300.00
0005435653978	21775	Economy	3300.00
0005433368496	21775	Economy	3300.00
0005435269806	9330	Business	186200.00
0005433763516	9330	Business	186200.00
0005433785725	9330	Business	186200.00
0005432657515	9330	Business	186200.00
0005433806125	9330	Business	186200.00
0005432667498	9330	Business	186200.00
0005435269812	9330	Business	186200.00
0005433806127	9330	Business	186200.00
0005433763520	9330	Business	186200.00
0005433763518	9330	Business	186200.00
0005433806112	9330	Business	186200.00
0005433785710	9330	Business	186200.00
0005433785707	9330	Business	186200.00
0005433785733	9330	Business	186200.00
0005433806126	9330	Business	186200.00
0005434151736	9330	Business	186200.00
0005433785740	9330	Economy	68300.00
0005433785744	9330	Economy	68300.00
0005433785727	9330	Economy	68300.00
0005432667499	9330	Economy	62100.00
0005433806113	9330	Economy	62100.00
0005433806097	9330	Economy	62100.00
0005433785712	9330	Economy	62100.00
0005433785736	9330	Economy	62100.00
0005433763515	9330	Economy	62100.00
0005433763521	9330	Economy	62100.00
0005435269815	9330	Economy	62100.00
0005433785713	9330	Economy	62100.00
0005433806111	9330	Economy	62100.00
0005433806133	9330	Economy	62100.00
0005433806105	9330	Economy	62100.00
0005433806109	9330	Economy	62100.00
0005434273105	9330	Economy	62100.00
0005433806132	9330	Economy	62100.00
0005432665319	9330	Economy	62100.00
0005434273104	9330	Economy	62100.00
0005433785723	9330	Economy	62100.00
0005435269816	9330	Economy	62100.00
0005435269829	9330	Economy	62100.00
0005433806104	9330	Economy	62100.00
0005433785717	9330	Economy	62100.00
0005433806116	9330	Economy	62100.00
0005433785738	9330	Economy	62100.00
0005433785734	9330	Economy	62100.00
0005434151738	9330	Economy	62100.00
0005434151731	9330	Economy	62100.00
0005433785735	9330	Economy	62100.00
0005433763513	9330	Economy	62100.00
0005433806107	9330	Economy	62100.00
0005433785731	9330	Economy	62100.00
0005433785708	9330	Economy	62100.00
0005433785730	9330	Economy	62100.00
0005433806115	9330	Economy	62100.00
0005434171242	9330	Economy	62100.00
0005433806131	9330	Economy	62100.00
0005433785746	9330	Economy	62100.00
0005433763517	9330	Economy	62100.00
0005433806121	9330	Economy	62100.00
0005435269805	9330	Economy	62100.00
0005433785739	9330	Economy	62100.00
0005433806128	9330	Economy	62100.00
0005433785711	9330	Economy	62100.00
0005433806114	9330	Economy	62100.00
0005435269818	9330	Economy	62100.00
0005433806098	9330	Economy	62100.00
0005433763524	9330	Economy	62100.00
0005433785729	9330	Economy	62100.00
0005434171229	9330	Economy	62100.00
0005433785720	9330	Economy	62100.00
0005433806120	9330	Economy	62100.00
0005435269828	9330	Economy	62100.00
0005433785722	9330	Economy	62100.00
0005433806123	9330	Economy	62100.00
0005433763523	9330	Economy	62100.00
0005433806110	9330	Economy	62100.00
0005434151735	9330	Economy	62100.00
0005433806099	9330	Economy	62100.00
0005432666433	9330	Economy	62100.00
0005433806136	9330	Economy	62100.00
0005433763519	9330	Economy	68300.00
0005433785714	9330	Economy	62100.00
0005433806134	9330	Economy	62100.00
0005433785742	9330	Economy	62100.00
0005433785724	9330	Economy	62100.00
0005434171253	9330	Economy	62100.00
0005433806096	9330	Economy	62100.00
0005433785737	9330	Economy	62100.00
0005433785728	9330	Economy	62100.00
0005434151739	9330	Economy	62100.00
0005433806102	9330	Economy	62100.00
0005433785715	9330	Economy	62100.00
0005433806106	9330	Economy	62100.00
0005434151743	9330	Economy	62100.00
0005434171236	9330	Economy	62100.00
0005433806100	9330	Economy	62100.00
0005433785709	9330	Economy	62100.00
0005434171243	9330	Economy	62100.00
0005433785719	9330	Economy	62100.00
0005433785718	9330	Economy	62100.00
0005435269830	9330	Economy	62100.00
0005433806124	9330	Economy	62100.00
0005433763514	9330	Economy	62100.00
0005435269831	9330	Economy	62100.00
0005432657516	9330	Economy	62100.00
0005433785726	9330	Economy	62100.00
0005433785741	9330	Economy	62100.00
0005433806122	9330	Economy	62100.00
0005433806119	9330	Economy	62100.00
0005433806108	9330	Economy	62100.00
0005433785745	9330	Economy	62100.00
0005433806117	9330	Economy	62100.00
0005432666434	9330	Economy	62100.00
0005433785716	9330	Economy	62100.00
0005433806135	9330	Economy	62100.00
0005433763522	9330	Economy	62100.00
0005432666432	9330	Economy	62100.00
0005433785732	9330	Economy	62100.00
0005433806095	9330	Economy	62100.00
0005435269827	9330	Economy	62100.00
0005433785743	9330	Economy	62100.00
0005433806103	9330	Economy	62100.00
0005433806101	9330	Economy	62100.00
0005433806130	9330	Economy	62100.00
0005433806118	9330	Economy	62100.00
0005434171241	9330	Economy	62100.00
0005433806129	9330	Economy	62100.00
0005433785721	9330	Economy	62100.00
0005434171361	26262	Business	186200.00
0005433785342	26262	Business	186200.00
0005433805757	26262	Business	186200.00
0005435269945	26262	Business	186200.00
0005433805828	26262	Business	186200.00
0005433785448	26262	Business	186200.00
0005433805946	26262	Business	186200.00
0005433785430	26262	Business	186200.00
0005433805747	26262	Business	186200.00
0005435858698	26262	Business	186200.00
0005434171362	26262	Business	186200.00
0005435269930	26262	Business	186200.00
0005433805912	26262	Business	186200.00
0005434269146	26262	Business	186200.00
0005433805829	26262	Business	186200.00
0005433805887	26262	Business	186200.00
0005433785429	26262	Business	186200.00
0005433805833	26262	Economy	68300.00
0005435269932	26262	Economy	68300.00
0005433785487	26262	Economy	68300.00
0005433763380	26262	Economy	62100.00
0005433785358	26262	Economy	62100.00
0005433805866	26262	Economy	62100.00
0005433805888	26262	Economy	62100.00
0005434271356	26262	Economy	62100.00
0005433785447	26262	Economy	62100.00
0005434171366	26262	Economy	62100.00
0005434171369	26262	Economy	62100.00
0005433805862	26262	Economy	62100.00
0005433805798	26262	Economy	62100.00
0005433805918	26262	Economy	62100.00
0005433785242	26262	Economy	62100.00
0005433785426	26262	Economy	62100.00
0005433805603	26262	Economy	62100.00
0005435269940	26262	Economy	62100.00
0005434271355	26262	Economy	62100.00
0005433785380	26262	Economy	62100.00
0005433785509	26262	Economy	62100.00
0005433785483	26262	Economy	62100.00
0005433805865	26262	Economy	62100.00
0005433763430	26262	Economy	62100.00
0005434171364	26262	Economy	62100.00
0005433785312	26262	Economy	62100.00
0005433763401	26262	Economy	62100.00
0005433785341	26262	Economy	62100.00
0005433785388	26262	Economy	62100.00
0005433785387	26262	Economy	62100.00
0005433805893	26262	Economy	62100.00
0005434171358	26262	Economy	62100.00
0005433805776	26262	Economy	62100.00
0005433763357	26262	Economy	62100.00
0005433763365	26262	Economy	62100.00
0005433805746	26262	Economy	62100.00
0005433763396	26262	Economy	62100.00
0005435269933	26262	Economy	62100.00
0005435269942	26262	Economy	62100.00
0005435269935	26262	Economy	62100.00
0005435269936	26262	Economy	62100.00
0005433805803	26262	Economy	62100.00
0005433805876	26262	Economy	62100.00
0005433785228	26262	Economy	62100.00
0005433785340	26262	Economy	62100.00
0005434171365	26262	Economy	62100.00
0005435269938	26262	Economy	62100.00
0005435269931	26262	Economy	62100.00
0005435269934	26262	Economy	62100.00
0005434171363	26262	Economy	62100.00
0005434270249	26262	Economy	62100.00
0005433805894	26262	Economy	62100.00
0005433763415	26262	Economy	62100.00
0005434171359	26262	Economy	62100.00
0005433785424	26262	Economy	62100.00
0005434171356	26262	Economy	62100.00
0005433805945	26262	Economy	68300.00
0005433805845	26262	Economy	62100.00
0005435269943	26262	Economy	62100.00
0005433785428	26262	Economy	62100.00
0005435269946	26262	Economy	68300.00
0005433785410	26262	Economy	62100.00
0005433785347	26262	Economy	62100.00
0005433785243	26262	Economy	62100.00
0005433805844	26262	Economy	62100.00
0005432657491	26262	Economy	62100.00
0005433805877	26262	Economy	62100.00
0005433805917	26262	Economy	62100.00
0005433785305	26262	Economy	62100.00
0005434270250	26262	Economy	62100.00
0005434171355	26262	Economy	62100.00
0005435269929	26262	Economy	62100.00
0005433785486	26262	Economy	62100.00
0005433785349	26262	Economy	62100.00
0005435269927	26262	Economy	62100.00
0005435269941	26262	Economy	62100.00
0005433763416	26262	Economy	62100.00
0005433785348	26262	Economy	62100.00
0005433785250	26262	Economy	62100.00
0005432663052	26262	Economy	62100.00
0005434151766	26262	Economy	62100.00
0005435269928	26262	Economy	62100.00
0005433805827	26262	Economy	62100.00
0005433805640	26262	Economy	62100.00
0005433785229	26262	Economy	62100.00
0005435269939	26262	Economy	62100.00
0005433785589	26262	Economy	62100.00
0005433785324	26262	Economy	62100.00
0005433785353	26262	Economy	62100.00
0005434171360	26262	Economy	62100.00
0005434171368	26262	Economy	62100.00
0005433785322	26262	Economy	62100.00
0005433805826	26262	Economy	62100.00
0005434171357	26262	Economy	62100.00
0005433763429	26262	Economy	62100.00
0005433805799	26262	Economy	62100.00
0005433763464	26262	Economy	62100.00
0005433785449	26262	Economy	62100.00
0005435269944	26262	Economy	62100.00
0005433785386	26262	Economy	62100.00
0005432663054	26262	Economy	62100.00
0005433785290	26262	Economy	62100.00
0005433785306	26262	Economy	62100.00
0005434171367	26262	Economy	62100.00
0005433785423	26262	Economy	62100.00
0005434151767	26262	Economy	62100.00
0005433805889	26262	Economy	62100.00
0005433785402	26262	Economy	62100.00
0005435269937	26262	Economy	62100.00
0005433805802	26262	Economy	62100.00
0005433805837	26262	Economy	62100.00
0005433805639	26262	Economy	62100.00
0005433785431	26262	Economy	62100.00
0005433785381	26262	Economy	62100.00
0005433785493	26262	Economy	62100.00
0005433763414	26262	Economy	62100.00
0005434269147	26262	Economy	62100.00
0005433763366	26262	Economy	62100.00
0005435135776	4924	Economy	5900.00
0005435135778	4924	Economy	5300.00
0005435135773	4924	Economy	5300.00
0005435135775	4924	Economy	5300.00
0005435135777	4924	Economy	5300.00
0005435929667	4924	Economy	5300.00
0005435135779	4924	Economy	5300.00
0005435135774	4924	Economy	5300.00
0005435135751	33019	Economy	5300.00
0005435135739	33019	Economy	5300.00
0005435135752	33019	Economy	5300.00
0005435135740	33019	Economy	5300.00
0005435135747	33019	Economy	5300.00
0005435929702	33019	Economy	5300.00
0005435929701	33019	Economy	5300.00
0005435135753	33019	Economy	5300.00
0005435135743	33019	Economy	5300.00
0005434983401	9453	Economy	17900.00
0005434983397	9453	Economy	17900.00
0005434983402	9453	Economy	17900.00
0005434983398	9453	Economy	17900.00
0005434983400	9453	Economy	17900.00
0005434218012	9453	Economy	17900.00
0005434218013	9453	Economy	17900.00
0005434218022	9453	Economy	17900.00
0005434983399	9453	Economy	17900.00
0005434983374	27366	Economy	17900.00
0005434218054	27366	Economy	17900.00
0005434983331	27366	Economy	17900.00
0005434983330	27366	Economy	17900.00
0005434218056	27366	Economy	17900.00
0005434983349	27366	Economy	17900.00
0005434983332	27366	Economy	17900.00
0005434983371	27366	Economy	17900.00
0005434218055	27366	Economy	17900.00
0005434218057	27366	Economy	17900.00
0005434983353	27366	Economy	17900.00
0005434983370	27366	Economy	17900.00
0005433986376	24247	Business	36400.00
0005433961397	24247	Business	36400.00
0005433986595	24247	Business	36400.00
0005433961486	24247	Business	36400.00
0005433986370	24247	Business	36400.00
0005433961599	24247	Business	36400.00
0005433961481	24247	Business	36400.00
0005433961424	24247	Business	36400.00
0005433961406	24247	Business	36400.00
0005433986405	24247	Business	36400.00
0005433961451	24247	Business	36400.00
0005433961581	24247	Business	36400.00
0005433986663	24247	Economy	13400.00
0005433986499	24247	Economy	13400.00
0005433961563	24247	Economy	12100.00
0005433986500	24247	Economy	12100.00
0005433986489	24247	Economy	12100.00
0005433961452	24247	Economy	12100.00
0005433961505	24247	Economy	12100.00
0005433986598	24247	Economy	12100.00
0005433961570	24247	Economy	12100.00
0005433986519	24247	Economy	12100.00
0005433961364	24247	Economy	12100.00
0005433961328	24247	Economy	12100.00
0005433961408	24247	Economy	12100.00
0005433986608	24247	Economy	12100.00
0005433986217	24247	Economy	12100.00
0005433961526	24247	Economy	12100.00
0005433961363	24247	Economy	12100.00
0005433961473	24247	Economy	12100.00
0005433986375	24247	Economy	12100.00
0005433986430	24247	Economy	12100.00
0005433961446	24247	Economy	12100.00
0005433961580	24247	Economy	12100.00
0005433961475	24247	Economy	12100.00
0005433986403	24247	Economy	12100.00
0005433961568	24247	Economy	12100.00
0005433961499	24247	Economy	12100.00
0005433961509	24247	Economy	12100.00
0005433986707	24247	Economy	12100.00
0005433986535	24247	Economy	12100.00
0005433961500	24247	Economy	12100.00
0005433986553	24247	Economy	12100.00
0005433986216	24247	Economy	12100.00
0005433986533	24247	Economy	12100.00
0005433961547	24247	Economy	12100.00
0005433961520	24247	Economy	12100.00
0005433986593	24247	Economy	12100.00
0005433986365	24247	Economy	12100.00
0005433961511	24247	Economy	12100.00
0005433961479	24247	Economy	12100.00
0005433986493	24247	Economy	12100.00
0005433986594	24247	Economy	12100.00
0005433986324	24247	Economy	12100.00
0005433986515	24247	Economy	12100.00
0005433986570	24247	Economy	12100.00
0005433986323	24247	Economy	12100.00
0005433986215	24247	Economy	12100.00
0005433986534	24247	Economy	12100.00
0005433986601	24247	Economy	12100.00
0005433986512	24247	Economy	12100.00
0005433961506	24247	Economy	12100.00
0005433961512	24247	Economy	12100.00
0005433961443	24247	Economy	12100.00
0005433961582	24247	Economy	13400.00
0005433986511	24247	Economy	12100.00
0005433961541	24247	Economy	12100.00
0005433986492	24247	Economy	12100.00
0005433961407	24247	Economy	12100.00
0005433961572	24247	Economy	12100.00
0005433986402	24247	Economy	12100.00
0005433961496	24247	Economy	12100.00
0005433986501	24247	Economy	12100.00
0005433961510	24247	Economy	12100.00
0005433961470	24247	Economy	12100.00
0005433986371	24247	Economy	12100.00
0005433961423	24247	Economy	12100.00
0005433961444	24247	Economy	12100.00
0005433986592	24247	Economy	12100.00
0005433986494	24247	Economy	12100.00
0005433961472	24247	Economy	12100.00
0005433986630	24247	Economy	12100.00
0005433961422	24247	Economy	12100.00
0005433961334	24247	Economy	12100.00
0005433986571	24247	Economy	12100.00
0005433986662	24247	Economy	12100.00
0005433961398	24247	Economy	12100.00
0005433986569	24247	Economy	12100.00
0005433986556	24247	Economy	12100.00
0005433961579	24247	Economy	12100.00
0005433961426	24247	Economy	12100.00
0005433986366	24247	Economy	12100.00
0005433961433	24247	Economy	12100.00
0005433961384	24247	Economy	12100.00
0005433961383	24247	Economy	12100.00
0005433986488	24247	Economy	12100.00
0005433961521	24247	Economy	12100.00
0005433961569	24247	Economy	12100.00
0005433962043	25951	Business	36400.00
0005433986922	25951	Business	36400.00
0005433986886	25951	Business	36400.00
0005433986906	25951	Business	36400.00
0005433962055	25951	Business	36400.00
0005433986901	25951	Business	36400.00
0005433962032	25951	Business	36400.00
0005433986899	25951	Business	36400.00
0005433962049	25951	Business	36400.00
0005433986920	25951	Business	36400.00
0005433962085	25951	Business	36400.00
0005433986888	25951	Economy	13400.00
0005433986924	25951	Economy	13400.00
0005433986911	25951	Economy	13400.00
0005433962050	25951	Economy	12100.00
0005433962071	25951	Economy	12100.00
0005433962076	25951	Economy	12100.00
0005433962087	25951	Economy	12100.00
0005433986909	25951	Economy	12100.00
0005433962096	25951	Economy	12100.00
0005433962073	25951	Economy	12100.00
0005433962042	25951	Economy	12100.00
0005433986902	25951	Economy	12100.00
0005433962048	25951	Economy	12100.00
0005433962066	25951	Economy	12100.00
0005433962091	25951	Economy	12100.00
0005433962056	25951	Economy	12100.00
0005433962059	25951	Economy	12100.00
0005433962057	25951	Economy	12100.00
0005433962089	25951	Economy	12100.00
0005433962097	25951	Economy	12100.00
0005433962051	25951	Economy	12100.00
0005433986896	25951	Economy	12100.00
0005433962064	25951	Economy	12100.00
0005433986897	25951	Economy	12100.00
0005433986914	25951	Economy	12100.00
0005433962080	25951	Economy	12100.00
0005433986910	25951	Economy	12100.00
0005433962095	25951	Economy	12100.00
0005433962099	25951	Economy	12100.00
0005433986908	25951	Economy	12100.00
0005433962058	25951	Economy	12100.00
0005433986894	25951	Economy	12100.00
0005433962070	25951	Economy	12100.00
0005433986887	25951	Economy	12100.00
0005433986917	25951	Economy	12100.00
0005433986905	25951	Economy	12100.00
0005433962045	25951	Economy	12100.00
0005433962077	25951	Economy	12100.00
0005433986890	25951	Economy	12100.00
0005433986918	25951	Economy	12100.00
0005433962079	25951	Economy	12100.00
0005433986915	25951	Economy	12100.00
0005433986903	25951	Economy	12100.00
0005433962090	25951	Economy	12100.00
0005433986893	25951	Economy	12100.00
0005433986923	25951	Economy	12100.00
0005433962046	25951	Economy	12100.00
0005433962038	25951	Economy	12100.00
0005433962092	25951	Economy	12100.00
0005433962037	25951	Economy	12100.00
0005433962060	25951	Economy	12100.00
0005433962041	25951	Economy	12100.00
0005433962075	25951	Economy	12100.00
0005433962068	25951	Economy	12100.00
0005433962074	25951	Economy	13400.00
0005433986880	25951	Economy	12100.00
0005433962088	25951	Economy	12100.00
0005433962044	25951	Economy	12100.00
0005433962039	25951	Economy	12100.00
0005433962084	25951	Economy	13400.00
0005433962072	25951	Economy	12100.00
0005433962069	25951	Economy	12100.00
0005433986913	25951	Economy	12100.00
0005433962053	25951	Economy	12100.00
0005433962093	25951	Economy	12100.00
0005433962040	25951	Economy	12100.00
0005433962067	25951	Economy	12100.00
0005433986912	25951	Economy	12100.00
0005433986895	25951	Economy	12100.00
0005433986889	25951	Economy	12100.00
0005433986891	25951	Economy	12100.00
0005433962086	25951	Economy	12100.00
0005433962035	25951	Economy	12100.00
0005433962081	25951	Economy	12100.00
0005433986900	25951	Economy	12100.00
0005433986921	25951	Economy	12100.00
0005433962078	25951	Economy	12100.00
0005433986884	25951	Economy	12100.00
0005433962054	25951	Economy	12100.00
0005433986919	25951	Economy	12100.00
0005433986907	25951	Economy	12100.00
0005433962098	25951	Economy	12100.00
0005433962063	25951	Economy	12100.00
0005433986916	25951	Economy	12100.00
0005433962082	25951	Economy	12100.00
0005433986904	25951	Economy	12100.00
0005433986883	25951	Economy	12100.00
0005433962061	25951	Economy	12100.00
0005433986881	25951	Economy	12100.00
0005433962034	25951	Economy	12100.00
0005433986878	25951	Economy	12100.00
0005433986885	25951	Economy	12100.00
0005433986898	25951	Economy	12100.00
0005433962083	25951	Economy	12100.00
0005433986879	25951	Economy	12100.00
0005433986892	25951	Economy	12100.00
0005433962062	25951	Economy	12100.00
0005433986882	25951	Economy	12100.00
0005433962036	25951	Economy	12100.00
0005433962065	25951	Economy	12100.00
0005433962047	25951	Economy	12100.00
0005433962033	25951	Economy	12100.00
0005433962094	25951	Economy	12100.00
0005433962052	25951	Economy	12100.00
0005432269554	964	Economy	25400.00
0005433166088	964	Economy	25400.00
0005432269555	964	Economy	25400.00
0005434480855	964	Economy	25400.00
0005434480861	964	Economy	23100.00
0005433166034	964	Economy	23100.00
0005434480854	964	Economy	23100.00
0005434480850	964	Economy	23100.00
0005433166077	964	Economy	23100.00
0005434480848	964	Economy	23100.00
0005434480868	964	Economy	23100.00
0005434480871	964	Economy	23100.00
0005434480866	964	Economy	23100.00
0005434480852	964	Economy	23100.00
0005434480858	964	Economy	23100.00
0005434480864	964	Economy	23100.00
0005434480862	964	Economy	23100.00
0005434480867	964	Economy	23100.00
0005434480870	964	Economy	23100.00
0005433166070	964	Economy	23100.00
0005434480865	964	Economy	23100.00
0005433166069	964	Economy	23100.00
0005433166056	964	Economy	23100.00
0005434480857	964	Economy	23100.00
0005433166068	964	Economy	23100.00
0005433166087	964	Economy	23100.00
0005434480856	964	Economy	23100.00
0005434480853	964	Economy	23100.00
0005433166093	964	Economy	23100.00
0005433166131	964	Economy	23100.00
0005432269556	964	Economy	23100.00
0005433166049	964	Economy	23100.00
0005434480869	964	Economy	23100.00
0005434480860	964	Economy	23100.00
0005433166132	964	Economy	23100.00
0005434480863	964	Economy	23100.00
0005434480873	964	Economy	23100.00
0005434480872	964	Economy	23100.00
0005434480849	964	Economy	23100.00
0005433166052	964	Economy	23100.00
0005434480851	964	Economy	23100.00
0005434480859	964	Economy	23100.00
0005433166078	964	Economy	23100.00
0005434480556	16607	Economy	25400.00
0005434480557	16607	Economy	25400.00
0005434480716	16607	Economy	23100.00
0005434480650	16607	Economy	23100.00
0005433166177	16607	Economy	23100.00
0005434480608	16607	Economy	23100.00
0005434480644	16607	Economy	23100.00
0005434480567	16607	Economy	23100.00
0005433166184	16607	Economy	23100.00
0005433166188	16607	Economy	23100.00
0005433166183	16607	Economy	23100.00
0005434480657	16607	Economy	23100.00
0005434480606	16607	Economy	23100.00
0005433166178	16607	Economy	23100.00
0005434480658	16607	Economy	23100.00
0005434480679	16607	Economy	23100.00
0005434480555	16607	Economy	23100.00
0005434480748	16607	Economy	23100.00
0005433166187	16607	Economy	23100.00
0005433166186	16607	Economy	23100.00
0005434480642	16607	Economy	23100.00
0005433166185	16607	Economy	23100.00
0005434480605	16607	Economy	23100.00
0005434480629	16607	Economy	23100.00
0005434480662	16607	Economy	23100.00
0005433166180	16607	Economy	23100.00
0005433166189	16607	Economy	23100.00
0005433166190	16607	Economy	23100.00
0005433166182	16607	Economy	23100.00
0005433166181	16607	Economy	23100.00
0005434480577	16607	Economy	23100.00
0005434480630	16607	Economy	23100.00
0005433166179	16607	Economy	23100.00
0005434480680	16607	Economy	23100.00
0005434480568	16607	Economy	23100.00
0005434480607	16607	Economy	23100.00
0005435142856	10336	Economy	17000.00
0005433289961	10336	Economy	17000.00
0005433289923	10336	Economy	15400.00
0005435142854	10336	Economy	15400.00
0005435150321	10336	Economy	15400.00
0005435150316	10336	Economy	15400.00
0005435150320	10336	Economy	15400.00
0005435150322	10336	Economy	15400.00
0005433289940	10336	Economy	15400.00
0005435142853	10336	Economy	15400.00
0005435386647	10336	Economy	15400.00
0005435142851	10336	Economy	15400.00
0005435142852	10336	Economy	15400.00
0005433289934	10336	Economy	15400.00
0005435142855	10336	Economy	15400.00
0005435142860	10336	Economy	15400.00
0005433289939	10336	Economy	15400.00
0005435142850	10336	Economy	15400.00
0005433289921	10336	Economy	15400.00
0005435142858	10336	Economy	15400.00
0005435386648	10336	Economy	15400.00
0005435142861	10336	Economy	15400.00
0005435150309	10336	Economy	15400.00
0005433289922	10336	Economy	15400.00
0005435142857	10336	Economy	15400.00
0005435142859	10336	Economy	15400.00
0005435150310	10336	Economy	15400.00
0005435150318	10336	Economy	15400.00
0005435386645	10336	Economy	15400.00
0005435150317	10336	Economy	15400.00
0005435150319	10336	Economy	15400.00
0005435150311	10336	Economy	15400.00
0005435150312	10336	Economy	15400.00
0005435386630	10336	Economy	15400.00
0005435150313	10336	Economy	15400.00
0005433289925	10336	Economy	15400.00
0005435142849	10336	Economy	15400.00
0005435150314	10336	Economy	15400.00
0005435150315	10336	Economy	15400.00
0005435150323	10336	Economy	15400.00
0005435150233	21917	Economy	17000.00
0005435150158	21917	Economy	17000.00
0005435142769	21917	Economy	17000.00
0005435150150	21917	Economy	17000.00
0005435150149	21917	Economy	15400.00
0005433290010	21917	Economy	15400.00
0005433290011	21917	Economy	15400.00
0005435142771	21917	Economy	15400.00
0005433290013	21917	Economy	15400.00
0005435386713	21917	Economy	15400.00
0005435142723	21917	Economy	15400.00
0005433290007	21917	Economy	15400.00
0005435386716	21917	Economy	15400.00
0005435142679	21917	Economy	15400.00
0005433290008	21917	Economy	15400.00
0005435142770	21917	Economy	15400.00
0005435386717	21917	Economy	15400.00
0005435142746	21917	Economy	15400.00
0005433290012	21917	Economy	15400.00
0005435150207	21917	Economy	15400.00
0005435150232	21917	Economy	15400.00
0005435142780	21917	Economy	15400.00
0005435150185	21917	Economy	15400.00
0005433290006	21917	Economy	15400.00
0005435142765	21917	Economy	15400.00
0005435386715	21917	Economy	15400.00
0005435142768	21917	Economy	15400.00
0005435142734	21917	Economy	15400.00
0005435150206	21917	Economy	15400.00
0005435150191	21917	Economy	15400.00
0005435386718	21917	Economy	15400.00
0005435150194	21917	Economy	15400.00
0005435150106	21917	Economy	15400.00
0005435386712	21917	Economy	15400.00
0005435142760	21917	Economy	15400.00
0005435150195	21917	Economy	15400.00
0005435142722	21917	Economy	15400.00
0005435142745	21917	Economy	15400.00
0005435150107	21917	Economy	15400.00
0005435150196	21917	Economy	15400.00
0005435150124	21917	Economy	15400.00
0005435150214	21917	Economy	15400.00
0005435386714	21917	Economy	15400.00
0005435142774	21917	Economy	15400.00
0005435142790	21917	Economy	15400.00
0005433290009	21917	Economy	15400.00
0005435150192	21917	Economy	15400.00
0005435142700	21917	Economy	15400.00
0005435142740	21917	Economy	15400.00
0005435502610	11230	Business	57200.00
0005435529508	11230	Business	57200.00
0005435319679	11230	Business	57200.00
0005435529516	11230	Business	57200.00
0005435319695	11230	Business	57200.00
0005435529544	11230	Business	57200.00
0005434573636	11230	Business	57200.00
0005435319681	11230	Economy	19100.00
0005435319693	11230	Economy	19100.00
0005435319702	11230	Economy	19100.00
0005434573641	11230	Economy	19100.00
0005435529608	11230	Economy	19100.00
0005435545833	11230	Economy	19100.00
0005435502636	11230	Economy	19100.00
0005434573637	11230	Economy	21000.00
0005434573643	11230	Economy	21000.00
0005435529576	11230	Economy	21000.00
0005435529515	11230	Economy	19100.00
0005435529547	11230	Economy	19100.00
0005435529575	11230	Economy	19100.00
0005435502683	11230	Economy	19100.00
0005434573635	11230	Economy	19100.00
0005435502532	11230	Economy	19100.00
0005435545840	11230	Economy	19100.00
0005434573648	11230	Economy	19100.00
0005435529469	11230	Economy	19100.00
0005435529574	11230	Economy	19100.00
0005434573647	11230	Economy	19100.00
0005435545825	11230	Economy	19100.00
0005434573649	11230	Economy	19100.00
0005435319682	11230	Economy	19100.00
0005434573640	11230	Economy	19100.00
0005434573642	11230	Economy	19100.00
0005435319694	11230	Economy	19100.00
0005435319677	11230	Economy	19100.00
0005434573646	11230	Economy	19100.00
0005434573645	11230	Economy	19100.00
0005435319696	11230	Economy	19100.00
0005435319688	11230	Economy	19100.00
0005435545824	11230	Economy	19100.00
0005435545841	11230	Economy	19100.00
0005435502640	11230	Economy	19100.00
0005435502679	11230	Economy	19100.00
0005435319692	11230	Economy	19100.00
0005435502642	11230	Economy	19100.00
0005435319668	11230	Economy	19100.00
0005435529543	11230	Economy	19100.00
0005435529392	11230	Economy	19100.00
0005434573644	11230	Economy	19100.00
0005435502565	11230	Economy	19100.00
0005434573638	11230	Economy	19100.00
0005435529578	11230	Economy	19100.00
0005434573639	11230	Economy	19100.00
0005435502585	11230	Economy	19100.00
0005435502589	11230	Economy	19100.00
0005435319715	11230	Economy	19100.00
0005435502571	11230	Economy	19100.00
0005435502758	20928	Business	57200.00
0005434573459	20928	Business	57200.00
0005435508627	20928	Business	57200.00
0005434573515	20928	Business	57200.00
0005434573512	20928	Business	57200.00
0005435319772	20928	Business	57200.00
0005435319771	20928	Business	57200.00
0005435319775	20928	Business	57200.00
0005435518280	20928	Business	57200.00
0005435508619	20928	Business	57200.00
0005435502762	20928	Business	57200.00
0005434573521	20928	Business	57200.00
0005435508633	20928	Economy	19100.00
0005434573503	20928	Economy	19100.00
0005434573496	20928	Economy	19100.00
0005435518291	20928	Economy	19100.00
0005435508626	20928	Economy	19100.00
0005435502766	20928	Economy	19100.00
0005435319774	20928	Economy	19100.00
0005435502767	20928	Economy	19100.00
0005434573557	20928	Economy	21000.00
0005435502757	20928	Economy	21000.00
0005435508629	20928	Economy	21000.00
0005432291981	20928	Economy	21000.00
0005435518293	20928	Economy	21000.00
0005435508638	20928	Economy	19100.00
0005435502773	20928	Economy	19100.00
0005435502765	20928	Economy	19100.00
0005435508635	20928	Economy	19100.00
0005434573511	20928	Economy	19100.00
0005435508628	20928	Economy	19100.00
0005435518288	20928	Economy	19100.00
0005435518281	20928	Economy	19100.00
0005435508621	20928	Economy	19100.00
0005435508622	20928	Economy	19100.00
0005435508616	20928	Economy	19100.00
0005435502761	20928	Economy	19100.00
0005435508636	20928	Economy	19100.00
0005435508634	20928	Economy	19100.00
0005435502752	20928	Economy	19100.00
0005434573549	20928	Economy	19100.00
0005435502751	20928	Economy	19100.00
0005435502763	20928	Economy	19100.00
0005434573513	20928	Economy	19100.00
0005435518286	20928	Economy	19100.00
0005434573522	20928	Economy	19100.00
0005435508630	20928	Economy	19100.00
0005435508620	20928	Economy	19100.00
0005435502770	20928	Economy	19100.00
0005432291982	20928	Economy	19100.00
0005435518284	20928	Economy	19100.00
0005434573536	20928	Economy	19100.00
0005435502772	20928	Economy	19100.00
0005434573548	20928	Economy	19100.00
0005435319773	20928	Economy	19100.00
0005435508625	20928	Economy	19100.00
0005435502753	20928	Economy	19100.00
0005435518283	20928	Economy	19100.00
0005435508617	20928	Economy	19100.00
0005435502754	20928	Economy	19100.00
0005435502755	20928	Economy	19100.00
0005435508639	20928	Economy	19100.00
0005434573523	20928	Economy	19100.00
0005435502756	20928	Economy	19100.00
0005435508637	20928	Economy	19100.00
0005434573578	20928	Economy	19100.00
0005435502759	20928	Economy	19100.00
0005435502768	20928	Economy	19100.00
0005434573537	20928	Economy	19100.00
0005435508624	20928	Economy	19100.00
0005435508632	20928	Economy	19100.00
0005434573510	20928	Economy	19100.00
0005435518289	20928	Economy	19100.00
0005435508640	20928	Economy	19100.00
0005434573492	20928	Economy	19100.00
0005435502760	20928	Economy	19100.00
0005435508631	20928	Economy	19100.00
0005435319770	20928	Economy	19100.00
0005435518290	20928	Economy	19100.00
0005435518279	20928	Economy	19100.00
0005435508623	20928	Economy	19100.00
0005434573545	20928	Economy	19100.00
0005434573525	20928	Economy	19100.00
0005435508618	20928	Economy	19100.00
0005435319776	20928	Economy	19100.00
0005435502771	20928	Economy	19100.00
0005435518292	20928	Economy	19100.00
0005435518285	20928	Economy	19100.00
0005435518287	20928	Economy	19100.00
0005435502769	20928	Economy	19100.00
0005435502764	20928	Economy	19100.00
0005435518282	20928	Economy	19100.00
0005433683397	24305	Economy	18800.00
0005433927462	24305	Economy	18800.00
0005433683396	24305	Economy	17100.00
0005433927466	24305	Economy	17100.00
0005433927454	24305	Economy	17100.00
0005433683392	24305	Economy	17100.00
0005433683395	24305	Economy	17100.00
0005433927464	24305	Economy	17100.00
0005433927472	24305	Economy	17100.00
0005433927467	24305	Economy	17100.00
0005433683393	24305	Economy	17100.00
0005433683394	24305	Economy	17100.00
0005433927463	24305	Economy	17100.00
0005433683391	24305	Economy	17100.00
0005433927465	24305	Economy	17100.00
0005433927468	24305	Economy	17100.00
0005433927455	24305	Economy	17100.00
0005433927470	24305	Economy	17100.00
0005433927452	24305	Economy	17100.00
0005433927453	24305	Economy	17100.00
0005433927498	29278	Economy	18800.00
0005433927494	29278	Economy	17100.00
0005433927499	29278	Economy	17100.00
0005433927497	29278	Economy	17100.00
0005433683378	29278	Economy	17100.00
0005433927496	29278	Economy	17100.00
0005433927493	29278	Economy	17100.00
0005433927495	29278	Economy	17100.00
0005433683377	29278	Economy	17100.00
0005433683376	29278	Economy	17100.00
0005433683375	29278	Economy	17100.00
0005433927492	29278	Economy	17100.00
0005432693474	2925	Business	10300.00
0005432693415	2925	Business	10300.00
0005432693287	2925	Business	10300.00
0005432693416	2925	Business	10300.00
0005432693523	2925	Business	10300.00
0005432693407	2925	Economy	3400.00
0005432693528	2925	Economy	3400.00
0005432693369	2925	Economy	3800.00
0005432693408	2925	Economy	3800.00
0005432693564	2925	Economy	3800.00
0005432693565	2925	Economy	3400.00
0005432693385	2925	Economy	3400.00
0005432693527	2925	Economy	3400.00
0005432693570	2925	Economy	3400.00
0005432693451	2925	Economy	3400.00
0005432693494	2925	Economy	3400.00
0005432693396	2925	Economy	3400.00
0005432693585	2925	Economy	3400.00
0005432693593	2925	Economy	3400.00
0005432693571	2925	Economy	3400.00
0005432693592	2925	Economy	3400.00
0005432693495	2925	Economy	3400.00
0005432693383	2925	Economy	3400.00
0005432693463	2925	Economy	3400.00
0005432693440	2925	Economy	3400.00
0005432693368	2925	Economy	3400.00
0005432693389	2925	Economy	3400.00
0005432693412	2925	Economy	3400.00
0005432693436	2925	Economy	3400.00
0005432693345	2925	Economy	3400.00
0005432693379	2925	Economy	3400.00
0005432693384	2925	Economy	3400.00
0005432693516	2925	Economy	3400.00
0005432707313	2912	Business	10300.00
0005433124223	2912	Business	10300.00
0005432707319	2912	Business	10300.00
0005432707325	2912	Business	10300.00
0005432880992	2912	Business	10300.00
0005432707318	2912	Business	10300.00
0005432881031	2912	Business	10300.00
0005432707317	2912	Business	10300.00
0005432880991	2912	Business	10300.00
0005432880972	2912	Economy	3400.00
0005433124249	2912	Economy	3400.00
0005433124221	2912	Economy	3400.00
0005432880932	2912	Economy	3400.00
0005432707323	2912	Economy	3400.00
0005432707305	2912	Economy	3400.00
0005432881000	2912	Economy	3800.00
0005433124150	2912	Economy	3400.00
0005432881029	2912	Economy	3400.00
0005432880981	2912	Economy	3400.00
0005432880944	2912	Economy	3400.00
0005432707315	2912	Economy	3400.00
0005433124179	2912	Economy	3400.00
0005433124263	2912	Economy	3400.00
0005432217837	2912	Economy	3400.00
0005432217836	2912	Economy	3400.00
0005433124214	2912	Economy	3400.00
0005432707327	2912	Economy	3400.00
0005433124149	2912	Economy	3400.00
0005432707314	2912	Economy	3400.00
0005433124248	2912	Economy	3400.00
0005432707321	2912	Economy	3400.00
0005432707312	2912	Economy	3400.00
0005433124237	2912	Economy	3400.00
0005433124202	2912	Economy	3400.00
0005432707328	2912	Economy	3400.00
0005432707322	2912	Economy	3400.00
0005433194886	2912	Economy	3400.00
0005432707320	2912	Economy	3400.00
0005433124238	2912	Economy	3400.00
0005432707306	2912	Economy	3400.00
0005432881030	2912	Economy	3400.00
0005432707311	2912	Economy	3400.00
0005432707329	2912	Economy	3400.00
0005433124178	2912	Economy	3400.00
0005433124215	2912	Economy	3400.00
0005432707309	2912	Economy	3400.00
0005432707310	2912	Economy	3400.00
0005432217835	2912	Economy	3400.00
0005432707307	2912	Economy	3400.00
0005432707308	2912	Economy	3400.00
0005432707326	2912	Economy	3400.00
0005432881001	2912	Economy	3400.00
0005433124187	2912	Economy	3400.00
0005432707324	2912	Economy	3400.00
0005432707316	2912	Economy	3400.00
0005433124188	2912	Economy	3400.00
0005432707304	2912	Economy	3400.00
0005433124172	2912	Economy	3400.00
0005433124196	2912	Economy	3400.00
0005433124349	30042	Business	10300.00
0005432707146	30042	Business	10300.00
0005432707287	30042	Business	10300.00
0005433124361	30042	Business	10300.00
0005432707176	30042	Business	10300.00
0005433124360	30042	Business	10300.00
0005432693751	30042	Business	10300.00
0005432693740	30042	Business	10300.00
0005433124363	30042	Business	10300.00
0005432707227	30042	Business	10300.00
0005432706957	30042	Business	10300.00
0005433124364	30042	Business	10300.00
0005432693733	30042	Economy	3400.00
0005432693735	30042	Economy	3400.00
0005432693755	30042	Economy	3400.00
0005433124354	30042	Economy	3400.00
0005432707065	30042	Economy	3400.00
0005432881131	30042	Economy	3400.00
0005432707195	30042	Economy	3400.00
0005432693744	30042	Economy	3400.00
0005432693750	30042	Economy	3400.00
0005432693734	30042	Economy	3400.00
0005433124357	30042	Economy	3800.00
0005432693753	30042	Economy	3800.00
0005432693746	30042	Economy	3800.00
0005432707286	30042	Economy	3800.00
0005432707077	30042	Economy	3800.00
0005432707103	30042	Economy	3400.00
0005432707147	30042	Economy	3400.00
0005432707110	30042	Economy	3400.00
0005432693736	30042	Economy	3400.00
0005432881123	30042	Economy	3400.00
0005433124353	30042	Economy	3400.00
0005432707055	30042	Economy	3400.00
0005433124358	30042	Economy	3400.00
0005432693728	30042	Economy	3400.00
0005432693731	30042	Economy	3400.00
0005432707102	30042	Economy	3400.00
0005432707185	30042	Economy	3400.00
0005433124362	30042	Economy	3400.00
0005432881128	30042	Economy	3400.00
0005432693741	30042	Economy	3400.00
0005432707265	30042	Economy	3400.00
0005432693732	30042	Economy	3400.00
0005432693754	30042	Economy	3400.00
0005433124352	30042	Economy	3400.00
0005432693749	30042	Economy	3400.00
0005432707159	30042	Economy	3400.00
0005432881135	30042	Economy	3400.00
0005432881130	30042	Economy	3400.00
0005432707228	30042	Economy	3400.00
0005432693739	30042	Economy	3400.00
0005432881122	30042	Economy	3400.00
0005432693743	30042	Economy	3400.00
0005433124355	30042	Economy	3400.00
0005432693737	30042	Economy	3400.00
0005432707108	30042	Economy	3400.00
0005432693729	30042	Economy	3400.00
0005432707104	30042	Economy	3400.00
0005432881126	30042	Economy	3400.00
0005432881136	30042	Economy	3400.00
0005432693745	30042	Economy	3400.00
0005432693738	30042	Economy	3400.00
0005432693756	30042	Economy	3400.00
0005432881132	30042	Economy	3400.00
0005432707123	30042	Economy	3400.00
0005432693752	30042	Economy	3400.00
0005432693727	30042	Economy	3400.00
0005432707162	30042	Economy	3400.00
0005432707105	30042	Economy	3400.00
0005432881125	30042	Economy	3400.00
0005432881133	30042	Economy	3400.00
0005432881124	30042	Economy	3400.00
0005432707177	30042	Economy	3400.00
0005432707100	30042	Economy	3400.00
0005432881134	30042	Economy	3400.00
0005432693748	30042	Economy	3400.00
0005432707092	30042	Economy	3400.00
0005432693730	30042	Economy	3400.00
0005432707054	30042	Economy	3400.00
0005432693747	30042	Economy	3400.00
0005432881127	30042	Economy	3400.00
0005432693742	30042	Economy	3400.00
0005432707163	30042	Economy	3400.00
0005432693757	30042	Economy	3400.00
0005432881129	30042	Economy	3400.00
0005433124350	30042	Economy	3400.00
0005433124356	30042	Economy	3400.00
0005432707064	30042	Economy	3400.00
0005432707194	30042	Economy	3400.00
0005432707078	30042	Economy	3400.00
0005433124359	30042	Economy	3400.00
0005433124351	30042	Economy	3400.00
0005433124348	30042	Economy	3400.00
0005432707053	30042	Economy	3400.00
0005432707052	30042	Economy	3400.00
0005432707231	30042	Economy	3400.00
0005434988957	23658	Economy	4000.00
0005434980411	23658	Economy	4000.00
0005434988950	23658	Economy	4000.00
0005434988951	23658	Economy	4000.00
0005434980397	23658	Economy	3600.00
0005434980415	23658	Economy	3600.00
0005434988956	23658	Economy	3600.00
0005434988954	23658	Economy	3600.00
0005434988953	23658	Economy	3600.00
0005434980391	23658	Economy	3600.00
0005434980417	23658	Economy	3600.00
0005434980408	23658	Economy	3600.00
0005434980404	23658	Economy	3600.00
0005434980392	23658	Economy	3600.00
0005434988955	23658	Economy	3600.00
0005434988959	23658	Economy	3600.00
0005434980419	23658	Economy	3600.00
0005434980409	23658	Economy	3600.00
0005434988962	23658	Economy	3600.00
0005434980407	23658	Economy	3600.00
0005434980410	23658	Economy	3600.00
0005434980399	23658	Economy	3600.00
0005434980398	23658	Economy	3600.00
0005434980420	23658	Economy	3600.00
0005434980396	23658	Economy	3600.00
0005434980400	23658	Economy	3600.00
0005434980403	23658	Economy	3600.00
0005434980406	23658	Economy	3600.00
0005434980412	23658	Economy	3600.00
0005434988961	23658	Economy	3600.00
0005434988960	23658	Economy	3600.00
0005434980405	23658	Economy	3600.00
0005434980416	23658	Economy	3600.00
0005434980413	23658	Economy	3600.00
0005434980394	23658	Economy	3600.00
0005434988958	23658	Economy	3600.00
0005434980402	23658	Economy	3600.00
0005434988952	23658	Economy	3600.00
0005434980393	23658	Economy	3600.00
0005434980418	23658	Economy	3600.00
0005434980414	23658	Economy	3600.00
0005434980395	23658	Economy	3600.00
0005434980401	23658	Economy	3600.00
0005434980125	27534	Economy	4000.00
0005434980137	27534	Economy	4000.00
0005434980054	27534	Economy	4000.00
0005434980107	27534	Economy	3600.00
0005434980138	27534	Economy	3600.00
0005434988870	27534	Economy	3600.00
0005434988882	27534	Economy	3600.00
0005434980193	27534	Economy	3600.00
0005434980291	27534	Economy	3600.00
0005434988844	27534	Economy	3600.00
0005434980211	27534	Economy	3600.00
0005434980161	27534	Economy	3600.00
0005434988878	27534	Economy	3600.00
0005434980210	27534	Economy	3600.00
0005434988816	27534	Economy	3600.00
0005434988868	27534	Economy	3600.00
0005434980203	27534	Economy	3600.00
0005434988865	27534	Economy	3600.00
0005434980132	27534	Economy	3600.00
0005434980284	27534	Economy	3600.00
0005434980292	27534	Economy	3600.00
0005434980233	27534	Economy	3600.00
0005434988832	27534	Economy	3600.00
0005434980023	27534	Economy	3600.00
0005434988871	27534	Economy	3600.00
0005434988885	27534	Economy	3600.00
0005434980262	27534	Economy	3600.00
0005434980166	27534	Economy	3600.00
0005434980085	27534	Economy	3600.00
0005434988809	27534	Economy	3600.00
0005434980056	27534	Economy	3600.00
0005434980055	27534	Economy	3600.00
0005434988845	27534	Economy	3600.00
0005434980184	27534	Economy	3600.00
0005434980131	27534	Economy	3600.00
0005434980191	27534	Economy	3600.00
0005434980162	27534	Economy	3600.00
0005434980163	27534	Economy	3600.00
0005434988881	27534	Economy	3600.00
0005434988875	27534	Economy	3600.00
0005434980206	27534	Economy	3600.00
0005434980204	27534	Economy	3600.00
0005434980190	27534	Economy	3600.00
0005434302550	10292	Economy	19700.00
0005434302547	10292	Economy	19700.00
0005433111527	10292	Economy	19700.00
0005434302884	10292	Economy	19700.00
0005434302885	10292	Economy	19700.00
0005433111528	10292	Economy	19700.00
0005433113566	10292	Economy	19700.00
0005434302548	10292	Economy	19700.00
0005434302549	10292	Economy	19700.00
0005433111529	10292	Economy	19700.00
0005434302551	10292	Economy	19700.00
0005433113584	19592	Economy	21600.00
0005434302512	19592	Economy	19700.00
0005433113582	19592	Economy	19700.00
0005434302506	19592	Economy	19700.00
0005434302507	19592	Economy	19700.00
0005434302513	19592	Economy	19700.00
0005433113585	19592	Economy	19700.00
0005434302502	19592	Economy	19700.00
0005434302490	19592	Economy	19700.00
0005433113583	19592	Economy	19700.00
0005435719062	3577	Business	26900.00
0005435070192	3577	Business	26900.00
0005435925439	3577	Business	26900.00
0005435925468	3577	Business	26900.00
0005435070175	3577	Business	26900.00
0005435070195	3577	Business	26900.00
0005435925416	3577	Business	26900.00
0005435925484	3577	Business	26900.00
0005435070194	3577	Business	26900.00
0005435925475	3577	Business	26900.00
0005435070182	3577	Business	26900.00
0005435070209	3577	Economy	9000.00
0005435070190	3577	Economy	9000.00
0005435070217	3577	Economy	9000.00
0005435070215	3577	Economy	9000.00
0005435070202	3577	Economy	9000.00
0005435070186	3577	Economy	9000.00
0005435070213	3577	Economy	9000.00
0005435719058	3577	Economy	9000.00
0005435070219	3577	Economy	9000.00
0005435070216	3577	Economy	9900.00
0005435939901	3577	Economy	9900.00
0005435070174	3577	Economy	9900.00
0005435070218	3577	Economy	9900.00
0005435925498	3577	Economy	9900.00
0005435070179	3577	Economy	9000.00
0005435070203	3577	Economy	9000.00
0005435070210	3577	Economy	9000.00
0005435070193	3577	Economy	9000.00
0005435070183	3577	Economy	9000.00
0005435070197	3577	Economy	9000.00
0005435070184	3577	Economy	9000.00
0005435939900	3577	Economy	9000.00
0005435719064	3577	Economy	9000.00
0005435070205	3577	Economy	9000.00
0005435070212	3577	Economy	9000.00
0005435070211	3577	Economy	9000.00
0005435070177	3577	Economy	9000.00
0005435925452	3577	Economy	9000.00
0005435719066	3577	Economy	9000.00
0005435070185	3577	Economy	9000.00
0005435719065	3577	Economy	9000.00
0005435070223	3577	Economy	9000.00
0005435070201	3577	Economy	9000.00
0005435719063	3577	Economy	9000.00
0005435070188	3577	Economy	9000.00
0005435070199	3577	Economy	9000.00
0005435925470	3577	Economy	9000.00
0005435925471	3577	Economy	9000.00
0005435070171	3577	Economy	9000.00
0005435070191	3577	Economy	9000.00
0005435070176	3577	Economy	9000.00
0005435719059	3577	Economy	9000.00
0005435070172	3577	Economy	9000.00
0005435070181	3577	Economy	9000.00
0005435719061	3577	Economy	9000.00
0005435925451	3577	Economy	9000.00
0005435070189	3577	Economy	9000.00
0005435070196	3577	Economy	9000.00
0005435070187	3577	Economy	9000.00
0005435070207	3577	Economy	9000.00
0005435719060	3577	Economy	9000.00
0005435070222	3577	Economy	9000.00
0005435070208	3577	Economy	9000.00
0005435070173	3577	Economy	9000.00
0005435070204	3577	Economy	9000.00
0005435925497	3577	Economy	9000.00
0005435939903	3577	Economy	9000.00
0005435070214	3577	Economy	9000.00
0005435070220	3577	Economy	9000.00
0005435070200	3577	Economy	9000.00
0005435925438	3577	Economy	9000.00
0005435925472	3577	Economy	9000.00
0005435070198	3577	Economy	9000.00
0005435070178	3577	Economy	9000.00
0005435070221	3577	Economy	9000.00
0005435070180	3577	Economy	9000.00
0005435939902	3577	Economy	9000.00
0005435939899	3577	Economy	9000.00
0005435070206	3577	Economy	9000.00
0005435718958	15327	Business	26900.00
0005435718922	15327	Business	26900.00
0005435069720	15327	Business	26900.00
0005435718967	15327	Business	26900.00
0005435069499	15327	Business	26900.00
0005435718948	15327	Business	26900.00
0005435069618	15327	Business	26900.00
0005435069824	15327	Business	26900.00
0005435069695	15327	Business	26900.00
0005435718971	15327	Business	26900.00
0005435069450	15327	Business	26900.00
0005435718957	15327	Business	26900.00
0005435069536	15327	Economy	9000.00
0005435069545	15327	Economy	9000.00
0005435718924	15327	Economy	9000.00
0005435069775	15327	Economy	9000.00
0005435718931	15327	Economy	9000.00
0005435718943	15327	Economy	9000.00
0005435069568	15327	Economy	9000.00
0005435069752	15327	Economy	9000.00
0005435069656	15327	Economy	9000.00
0005435069822	15327	Economy	9000.00
0005435069668	15327	Economy	9900.00
0005435069606	15327	Economy	9900.00
0005435069771	15327	Economy	9900.00
0005435718972	15327	Economy	9900.00
0005435069825	15327	Economy	9900.00
0005435718984	15327	Economy	9000.00
0005435718986	15327	Economy	9000.00
0005435069671	15327	Economy	9000.00
0005435069631	15327	Economy	9000.00
0005435069696	15327	Economy	9000.00
0005435069706	15327	Economy	9000.00
0005435069729	15327	Economy	9000.00
0005435718970	15327	Economy	9000.00
0005435718926	15327	Economy	9000.00
0005435718980	15327	Economy	9000.00
0005435718921	15327	Economy	9000.00
0005435718979	15327	Economy	9000.00
0005435718941	15327	Economy	9000.00
0005435718923	15327	Economy	9000.00
0005435718929	15327	Economy	9000.00
0005435718974	15327	Economy	9000.00
0005435069562	15327	Economy	9000.00
0005435069799	15327	Economy	9000.00
0005435069503	15327	Economy	9000.00
0005435069708	15327	Economy	9000.00
0005435069546	15327	Economy	9000.00
0005435718973	15327	Economy	9000.00
0005435718942	15327	Economy	9000.00
0005435069664	15327	Economy	9000.00
0005435069672	15327	Economy	9000.00
0005435718982	15327	Economy	9000.00
0005435069816	15327	Economy	9000.00
0005435718983	15327	Economy	9000.00
0005435069736	15327	Economy	9000.00
0005435069770	15327	Economy	9000.00
0005435069619	15327	Economy	9000.00
0005435718956	15327	Economy	9000.00
0005435069707	15327	Economy	9000.00
0005435718978	15327	Economy	9000.00
0005435718975	15327	Economy	9000.00
0005435069766	15327	Economy	9000.00
0005435069544	15327	Economy	9000.00
0005435718927	15327	Economy	9000.00
0005435069681	15327	Economy	9000.00
0005435069797	15327	Economy	9000.00
0005435718963	15327	Economy	9000.00
0005435069798	15327	Economy	9000.00
0005435069547	15327	Economy	9000.00
0005435069567	15327	Economy	9000.00
0005435718940	15327	Economy	9000.00
0005435069663	15327	Economy	9000.00
0005435718968	15327	Economy	9000.00
0005435069517	15327	Economy	9000.00
0005435718981	15327	Economy	9000.00
0005435069598	15327	Economy	9000.00
0005435069719	15327	Economy	9000.00
0005435069561	15327	Economy	9000.00
0005435718969	15327	Economy	9000.00
0005435069806	15327	Economy	9000.00
0005435069655	15327	Economy	9000.00
0005435069718	15327	Economy	9000.00
0005435069777	15327	Economy	9000.00
0005435069800	15327	Economy	9000.00
0005435718962	15327	Economy	9000.00
0005435718947	15327	Economy	9000.00
0005435069498	15327	Economy	9000.00
0005435718954	15327	Economy	9000.00
0005435069600	15327	Economy	9000.00
0005435069542	15327	Economy	9000.00
0005435069667	15327	Economy	9000.00
0005435069502	15327	Economy	9000.00
0005435718944	15327	Economy	9000.00
0005435069636	15327	Economy	9000.00
0005435069835	15327	Economy	9000.00
0005432658636	18137	Economy	5900.00
0005432658635	18137	Economy	5900.00
0005432660863	18137	Economy	5900.00
0005432660862	18137	Economy	5900.00
0005432659752	18137	Economy	5900.00
0005432659751	18137	Economy	5900.00
0005432667472	26352	Economy	5900.00
0005432660841	26352	Economy	5900.00
0005432667471	26352	Economy	5900.00
0005432660840	26352	Economy	5900.00
0005432660839	26352	Economy	5900.00
0005432667480	26352	Economy	5900.00
0005433102734	12	Business	20000.00
0005432901903	12	Business	20000.00
0005433102605	12	Business	20000.00
0005433102720	12	Business	20000.00
0005433102610	12	Business	20000.00
0005432901860	12	Business	20000.00
0005433102864	12	Business	20000.00
0005433102840	12	Business	20000.00
0005432901826	12	Business	20000.00
0005432901830	12	Business	20000.00
0005433102833	12	Business	20000.00
0005433102821	12	Business	20000.00
0005433102774	12	Business	20000.00
0005433102757	12	Business	20000.00
0005432392033	12	Economy	7300.00
0005432920227	12	Economy	6700.00
0005432392026	12	Economy	6700.00
0005432392031	12	Economy	6700.00
0005432920118	12	Economy	6700.00
0005432920119	12	Economy	6700.00
0005432920170	12	Economy	6700.00
0005433102819	12	Economy	6700.00
0005432901829	12	Economy	6700.00
0005432901904	12	Economy	6700.00
0005432901842	12	Economy	6700.00
0005433102858	12	Economy	6700.00
0005432392030	12	Economy	6700.00
0005433102865	12	Economy	6700.00
0005432901822	12	Economy	6700.00
0005433102746	12	Economy	6700.00
0005432901821	12	Economy	6700.00
0005432920109	12	Economy	6700.00
0005433102841	12	Economy	6700.00
0005433102826	12	Economy	6700.00
0005432157534	12	Economy	6700.00
0005433102802	12	Economy	6700.00
0005433102747	12	Economy	6700.00
0005433102659	12	Economy	6700.00
0005433102854	12	Economy	6700.00
0005432920221	12	Economy	6700.00
0005433102732	12	Economy	6700.00
0005433102793	12	Economy	6700.00
0005432392021	12	Economy	6700.00
0005432920171	12	Economy	6700.00
0005433102561	12	Economy	6700.00
0005433102809	12	Economy	6700.00
0005433102593	12	Economy	6700.00
0005433102820	12	Economy	6700.00
0005432901869	12	Economy	6700.00
0005432920260	12	Economy	6700.00
0005433102562	12	Economy	6700.00
0005432392034	12	Economy	7300.00
0005432920059	12	Economy	6700.00
0005433102804	12	Economy	6700.00
0005432392022	12	Economy	7300.00
0005432901831	12	Economy	6700.00
0005432901772	12	Economy	6700.00
0005433102814	12	Economy	6700.00
0005432920258	12	Economy	6700.00
0005432920177	12	Economy	6700.00
0005433102815	12	Economy	6700.00
0005432677616	12	Economy	6700.00
0005432901840	12	Economy	6700.00
0005433102818	12	Economy	6700.00
0005432920110	12	Economy	6700.00
0005432677622	12	Economy	6700.00
0005433102786	12	Economy	6700.00
0005433102868	12	Economy	6700.00
0005433102816	12	Economy	6700.00
0005432920117	12	Economy	6700.00
0005433102733	12	Economy	6700.00
0005433102805	12	Economy	6700.00
0005432920198	12	Economy	6700.00
0005432901876	12	Economy	6700.00
0005433102866	12	Economy	6700.00
0005433102859	12	Economy	6700.00
0005433102594	12	Economy	6700.00
0005433102869	12	Economy	6700.00
0005433102731	12	Economy	6700.00
0005432901859	12	Economy	6700.00
0005433102801	12	Economy	6700.00
0005433102837	12	Economy	6700.00
0005432901827	12	Economy	6700.00
0005433102785	12	Economy	6700.00
0005432920218	12	Economy	6700.00
0005432920257	12	Economy	6700.00
0005433102782	12	Economy	6700.00
0005433102824	12	Economy	6700.00
0005432920259	12	Economy	6700.00
0005433102834	12	Economy	6700.00
0005432262911	13	Business	20000.00
0005432207715	13	Business	20000.00
0005432262906	13	Business	20000.00
0005432262875	13	Business	20000.00
0005433477028	13	Business	20000.00
0005432818106	13	Business	20000.00
0005432818117	13	Business	20000.00
0005432262869	13	Business	20000.00
0005432818101	13	Business	20000.00
0005432818119	13	Business	20000.00
0005432262893	13	Business	20000.00
0005432818118	13	Business	20000.00
0005432818109	13	Business	20000.00
0005433477026	13	Business	20000.00
0005432818110	13	Business	20000.00
0005433477020	13	Business	20000.00
0005432262868	13	Business	20000.00
0005433477018	13	Business	20000.00
0005432818120	13	Economy	7300.00
0005432818098	13	Economy	7300.00
0005432818102	13	Economy	7300.00
0005432818121	13	Economy	7300.00
0005432818112	13	Economy	7300.00
0005432262899	13	Economy	6700.00
0005432262889	13	Economy	6700.00
0005432818115	13	Economy	6700.00
0005432756877	13	Economy	6700.00
0005433477017	13	Economy	6700.00
0005432262903	13	Economy	6700.00
0005432262884	13	Economy	6700.00
0005432818122	13	Economy	6700.00
0005433477027	13	Economy	6700.00
0005432756876	13	Economy	6700.00
0005434152854	13	Economy	6700.00
0005432262883	13	Economy	6700.00
0005432818107	13	Economy	6700.00
0005432262908	13	Economy	6700.00
0005432262902	13	Economy	6700.00
0005432262865	13	Economy	6700.00
0005432262882	13	Economy	6700.00
0005432262872	13	Economy	6700.00
0005432262878	13	Economy	6700.00
0005432262898	13	Economy	6700.00
0005432756878	13	Economy	6700.00
0005432262892	13	Economy	6700.00
0005432818113	13	Economy	6700.00
0005432262866	13	Economy	6700.00
0005432262888	13	Economy	6700.00
0005432262873	13	Economy	6700.00
0005432262904	13	Economy	6700.00
0005432262900	13	Economy	6700.00
0005432262864	13	Economy	6700.00
0005432262879	13	Economy	6700.00
0005432262912	13	Economy	6700.00
0005432818108	13	Economy	6700.00
0005432756870	13	Economy	6700.00
0005432818099	13	Economy	6700.00
0005433477021	13	Economy	6700.00
0005432818097	13	Economy	7300.00
0005432818095	13	Economy	7300.00
0005432262895	13	Economy	7300.00
0005433477029	13	Economy	6700.00
0005432262909	13	Economy	6700.00
0005432262874	13	Economy	7300.00
0005432262901	13	Economy	6700.00
0005432262897	13	Economy	6700.00
0005432818116	13	Economy	6700.00
0005432262871	13	Economy	6700.00
0005433690956	13	Economy	6700.00
0005432262905	13	Economy	6700.00
0005432262881	13	Economy	6700.00
0005432756886	13	Economy	6700.00
0005432207714	13	Economy	6700.00
0005432289057	13	Economy	6700.00
0005432818103	13	Economy	6700.00
0005433477015	13	Economy	6700.00
0005433477024	13	Economy	6700.00
0005433477030	13	Economy	6700.00
0005433477025	13	Economy	6700.00
0005433477032	13	Economy	6700.00
0005432207716	13	Economy	6700.00
0005432818111	13	Economy	6700.00
0005433477016	13	Economy	6700.00
0005432207717	13	Economy	6700.00
0005432756875	13	Economy	6700.00
0005432262896	13	Economy	6700.00
0005432262885	13	Economy	6700.00
0005432289058	13	Economy	6700.00
0005433477019	13	Economy	6700.00
0005432262867	13	Economy	6700.00
0005432262886	13	Economy	6700.00
0005432262891	13	Economy	6700.00
0005432262880	13	Economy	6700.00
0005432818105	13	Economy	6700.00
0005432262870	13	Economy	6700.00
0005432262894	13	Economy	6700.00
0005433477023	13	Economy	6700.00
0005432262910	13	Economy	6700.00
0005432818094	13	Economy	6700.00
0005432818093	13	Economy	6700.00
0005432262876	13	Economy	6700.00
0005432262907	13	Economy	6700.00
0005433477022	13	Economy	6700.00
0005432818114	13	Economy	6700.00
0005432753354	13	Economy	6700.00
0005432818096	13	Economy	6700.00
0005432262890	13	Economy	6700.00
0005433477031	13	Economy	6700.00
0005432262887	13	Economy	6700.00
0005432818104	13	Economy	6700.00
0005432818100	13	Economy	6700.00
0005432262877	13	Economy	6700.00
0005432020824	8139	Business	20000.00
0005433103319	8139	Business	20000.00
0005432020845	8139	Business	20000.00
0005432920300	8139	Business	20000.00
0005433103304	8139	Business	20000.00
0005432020838	8139	Business	20000.00
0005432392065	8139	Business	20000.00
0005433103299	8139	Business	20000.00
0005432751598	8139	Business	20000.00
0005432020839	8139	Business	20000.00
0005432020849	8139	Business	20000.00
0005432020826	8139	Business	20000.00
0005432753372	8139	Business	20000.00
0005433103285	8139	Business	20000.00
0005432920315	8139	Business	20000.00
0005433103331	8139	Business	20000.00
0005433103325	8139	Business	20000.00
0005432920299	8139	Business	20000.00
0005433103275	8139	Business	20000.00
0005432020828	8139	Business	20000.00
0005433103335	8139	Business	20000.00
0005432020847	8139	Business	20000.00
0005433103310	8139	Business	20000.00
0005432920312	8139	Business	20000.00
0005433103290	8139	Business	20000.00
0005432020844	8139	Economy	7300.00
0005433103278	8139	Economy	7300.00
0005432920305	8139	Economy	7300.00
0005432751599	8139	Economy	7300.00
0005433103328	8139	Economy	7300.00
0005433103330	8139	Economy	7300.00
0005433103314	8139	Economy	6700.00
0005432751600	8139	Economy	6700.00
0005432920301	8139	Economy	6700.00
0005433103298	8139	Economy	6700.00
0005433103270	8139	Economy	6700.00
0005432920298	8139	Economy	6700.00
0005432753374	8139	Economy	6700.00
0005433103313	8139	Economy	6700.00
0005432020835	8139	Economy	6700.00
0005432020829	8139	Economy	6700.00
0005432020850	8139	Economy	6700.00
0005432920303	8139	Economy	6700.00
0005432920309	8139	Economy	6700.00
0005433103279	8139	Economy	6700.00
0005433103286	8139	Economy	6700.00
0005432020831	8139	Economy	6700.00
0005432920308	8139	Economy	6700.00
0005433103280	8139	Economy	6700.00
0005433103336	8139	Economy	6700.00
0005433103268	8139	Economy	6700.00
0005433103283	8139	Economy	6700.00
0005432020846	8139	Economy	6700.00
0005433103273	8139	Economy	6700.00
0005432753373	8139	Economy	6700.00
0005432020841	8139	Economy	6700.00
0005433103289	8139	Economy	6700.00
0005433103306	8139	Economy	6700.00
0005433103332	8139	Economy	6700.00
0005433103315	8139	Economy	6700.00
0005433103281	8139	Economy	6700.00
0005433103307	8139	Economy	6700.00
0005432044586	8139	Economy	6700.00
0005432020837	8139	Economy	6700.00
0005433103324	8139	Economy	6700.00
0005432020836	8139	Economy	6700.00
0005432045656	8139	Economy	6700.00
0005432044584	8139	Economy	6700.00
0005433103334	8139	Economy	6700.00
0005432392064	8139	Economy	6700.00
0005432045655	8139	Economy	6700.00
0005433103318	8139	Economy	6700.00
0005432920314	8139	Economy	6700.00
0005432020840	8139	Economy	6700.00
0005433103293	8139	Economy	6700.00
0005433103305	8139	Economy	6700.00
0005433103308	8139	Economy	6700.00
0005432020827	8139	Economy	6700.00
0005433103329	8139	Economy	6700.00
0005433103282	8139	Economy	6700.00
0005432044585	8139	Economy	7300.00
0005432677660	8139	Economy	7300.00
0005433103303	8139	Economy	7300.00
0005433103291	8139	Economy	7300.00
0005433103337	8139	Economy	7300.00
0005432920302	8139	Economy	6700.00
0005433103300	8139	Economy	6700.00
0005433103294	8139	Economy	6700.00
0005433103297	8139	Economy	6700.00
0005432920295	8139	Economy	7300.00
0005433103312	8139	Economy	6700.00
0005432020833	8139	Economy	6700.00
0005432392063	8139	Economy	6700.00
0005433103263	8139	Economy	6700.00
0005432020842	8139	Economy	6700.00
0005433103323	8139	Economy	6700.00
0005433103262	8139	Economy	6700.00
0005433103274	8139	Economy	6700.00
0005433103277	8139	Economy	6700.00
0005433103266	8139	Economy	6700.00
0005433103320	8139	Economy	6700.00
0005432920310	8139	Economy	6700.00
0005433103295	8139	Economy	6700.00
0005433103267	8139	Economy	6700.00
0005433103264	8139	Economy	6700.00
0005433103309	8139	Economy	6700.00
0005432753375	8139	Economy	6700.00
0005433103311	8139	Economy	6700.00
0005432020825	8139	Economy	6700.00
0005433103287	8139	Economy	6700.00
0005433103301	8139	Economy	6700.00
0005433103288	8139	Economy	6700.00
0005433103338	8139	Economy	6700.00
0005432920307	8139	Economy	6700.00
0005433103302	8139	Economy	6700.00
0005432677659	8139	Economy	6700.00
0005433103271	8139	Economy	6700.00
0005433103333	8139	Economy	6700.00
0005433103326	8139	Economy	6700.00
0005432020848	8139	Economy	6700.00
0005432920313	8139	Economy	6700.00
0005433103296	8139	Economy	6700.00
0005432020823	8139	Economy	6700.00
0005432751597	8139	Economy	6700.00
0005433103265	8139	Economy	6700.00
0005433103292	8139	Economy	6700.00
0005432020843	8139	Economy	6700.00
0005433103322	8139	Economy	6700.00
0005432020834	8139	Economy	6700.00
0005433103276	8139	Economy	6700.00
0005433103316	8139	Economy	6700.00
0005432020832	8139	Economy	6700.00
0005432920311	8139	Economy	6700.00
0005433103317	8139	Economy	6700.00
0005433103321	8139	Economy	6700.00
0005432677661	8139	Economy	6700.00
0005433103269	8139	Economy	6700.00
0005433103272	8139	Economy	6700.00
0005432020830	8139	Economy	6700.00
0005433103327	8139	Economy	6700.00
0005432920306	8139	Economy	6700.00
0005432920297	8139	Economy	6700.00
0005432920304	8139	Economy	6700.00
0005433103284	8139	Economy	6700.00
0005432920296	8139	Economy	6700.00
0005432920316	8139	Economy	6700.00
0005432817874	8110	Business	20000.00
0005432817861	8110	Business	20000.00
0005432901988	8110	Business	20000.00
0005432901985	8110	Business	20000.00
0005432901989	8110	Business	20000.00
0005432817946	8110	Business	20000.00
0005432817910	8110	Business	20000.00
0005432901982	8110	Business	20000.00
0005432817876	8110	Business	20000.00
0005432901984	8110	Business	20000.00
0005432901983	8110	Business	20000.00
0005432901977	8110	Economy	7300.00
0005432002121	8110	Economy	7300.00
0005432817931	8110	Economy	7300.00
0005432817704	8110	Economy	7300.00
0005432901990	8110	Economy	6700.00
0005432817846	8110	Economy	6700.00
0005432002122	8110	Economy	6700.00
0005432817887	8110	Economy	6700.00
0005432901981	8110	Economy	6700.00
0005432817888	8110	Economy	6700.00
0005432901979	8110	Economy	6700.00
0005432817993	8110	Economy	6700.00
0005432817705	8110	Economy	6700.00
0005432817709	8110	Economy	6700.00
0005432817898	8110	Economy	6700.00
0005432817909	8110	Economy	6700.00
0005432817939	8110	Economy	6700.00
0005432817706	8110	Economy	6700.00
0005432817842	8110	Economy	6700.00
0005432901980	8110	Economy	7300.00
0005432817710	8110	Economy	6700.00
0005432817870	8110	Economy	6700.00
0005432817791	8110	Economy	6700.00
0005432817938	8110	Economy	6700.00
0005432901978	8110	Economy	6700.00
0005432901986	8110	Economy	6700.00
0005432817862	8110	Economy	6700.00
0005432901993	8110	Economy	6700.00
0005432817935	8110	Economy	6700.00
0005432817818	8110	Economy	6700.00
0005432817949	8110	Economy	6700.00
0005432002120	8110	Economy	6700.00
0005432817637	8110	Economy	6700.00
0005432817863	8110	Economy	6700.00
0005432901992	8110	Economy	6700.00
0005432901994	8110	Economy	6700.00
0005432901991	8110	Economy	6700.00
0005432901987	8110	Economy	6700.00
0005432817868	8110	Economy	6700.00
0005433870777	9666	Economy	6900.00
0005434175811	9666	Economy	6900.00
0005434175812	9666	Economy	6900.00
0005433870779	9666	Economy	6900.00
0005433870778	9666	Economy	6900.00
0005434175844	32336	Economy	6900.00
0005433870758	32336	Economy	6900.00
0005434175845	32336	Economy	6900.00
0005433870754	32336	Economy	6900.00
0005434880219	3520	Business	35000.00
0005432800053	3520	Business	35000.00
0005434427248	3520	Business	35000.00
0005435626567	3520	Business	35000.00
0005435127234	3520	Business	35000.00
0005435902959	3520	Business	35000.00
0005434938555	3520	Business	35000.00
0005434880262	3520	Business	35000.00
0005434427255	3520	Business	35000.00
0005432800059	3520	Business	35000.00
0005434880222	3520	Business	35000.00
0005434880289	3520	Business	35000.00
0005434880225	3520	Business	35000.00
0005435127263	3520	Business	35000.00
0005434427256	3520	Business	35000.00
0005435902991	3520	Business	35000.00
0005434427237	3520	Business	35000.00
0005435626584	3520	Business	35000.00
0005432800060	3520	Business	35000.00
0005435626576	3520	Business	35000.00
0005435626563	3520	Business	35000.00
0005434427259	3520	Business	35000.00
0005434427231	3520	Business	35000.00
0005435127244	3520	Comfort	19900.00
0005434880260	3520	Comfort	19900.00
0005434880272	3520	Comfort	19900.00
0005435127250	3520	Comfort	19900.00
0005434880309	3520	Comfort	19900.00
0005434880268	3520	Comfort	19900.00
0005434880306	3520	Comfort	19900.00
0005432800077	3520	Comfort	19900.00
0005432800071	3520	Comfort	19900.00
0005434427234	3520	Comfort	19900.00
0005434880229	3520	Comfort	19900.00
0005434880246	3520	Comfort	19900.00
0005435914708	3520	Comfort	19900.00
0005434880303	3520	Comfort	19900.00
0005434880238	3520	Comfort	19900.00
0005434938569	3520	Comfort	19900.00
0005434880226	3520	Comfort	19900.00
0005434938567	3520	Comfort	19900.00
0005435626571	3520	Comfort	19900.00
0005434880249	3520	Comfort	19900.00
0005432800067	3520	Comfort	19900.00
0005434880291	3520	Comfort	19900.00
0005434938565	3520	Comfort	19900.00
0005434427232	3520	Comfort	19900.00
0005435626564	3520	Comfort	19900.00
0005435902944	3520	Comfort	19900.00
0005434880227	3520	Comfort	19900.00
0005434880256	3520	Comfort	19900.00
0005434880295	3520	Comfort	19900.00
0005434880234	3520	Comfort	19900.00
0005434880283	3520	Economy	11700.00
0005434880223	3520	Economy	11700.00
0005435127249	3520	Economy	11700.00
0005434427245	3520	Economy	11700.00
0005434880239	3520	Economy	11700.00
0005434880257	3520	Economy	11700.00
0005434427247	3520	Economy	11700.00
0005435902974	3520	Economy	11700.00
0005435913962	3520	Economy	11700.00
0005435127264	3520	Economy	11700.00
0005435127247	3520	Economy	11700.00
0005435902968	3520	Economy	11700.00
0005434880296	3520	Economy	11700.00
0005434427240	3520	Economy	11700.00
0005434427235	3520	Economy	11700.00
0005435127238	3520	Economy	11700.00
0005432611784	3520	Economy	11700.00
0005434427251	3520	Economy	11700.00
0005434880271	3520	Economy	11700.00
0005434938560	3520	Economy	11700.00
0005435902960	3520	Economy	11700.00
0005434880292	3520	Economy	11700.00
0005432188679	3520	Economy	11700.00
0005434880282	3520	Economy	11700.00
0005434880261	3520	Economy	11700.00
0005435913964	3520	Economy	11700.00
0005432800063	3520	Economy	11700.00
0005434427252	3520	Economy	11700.00
0005434880308	3520	Economy	11700.00
0005435127246	3520	Economy	11700.00
0005434880263	3520	Economy	11700.00
0005434938568	3520	Economy	11700.00
0005434880305	3520	Economy	11700.00
0005435626569	3520	Economy	11700.00
0005434880302	3520	Economy	11700.00
0005435127232	3520	Economy	11700.00
0005434880231	3520	Economy	11700.00
0005434427246	3520	Economy	11700.00
0005434880265	3520	Economy	11700.00
0005434880245	3520	Economy	11700.00
0005434880232	3520	Economy	11700.00
0005432800078	3520	Economy	11700.00
0005434880279	3520	Economy	11700.00
0005435127262	3520	Economy	11700.00
0005435127253	3520	Economy	11700.00
0005434880244	3520	Economy	11700.00
0005435626572	3520	Economy	11700.00
0005435626577	3520	Economy	12800.00
0005434427239	3520	Economy	12800.00
0005435914709	3520	Economy	11700.00
0005435902946	3520	Economy	11700.00
0005432800072	3520	Economy	12800.00
0005434880285	3520	Economy	11700.00
0005434880243	3520	Economy	12800.00
0005434880300	3520	Economy	12800.00
0005434880218	3520	Economy	11700.00
0005435902926	3520	Economy	11700.00
0005434880235	3520	Economy	11700.00
0005435127251	3520	Economy	11700.00
0005434880297	3520	Economy	11700.00
0005435127230	3520	Economy	11700.00
0005434880277	3520	Economy	11700.00
0005434880275	3520	Economy	11700.00
0005432800075	3520	Economy	11700.00
0005432800069	3520	Economy	11700.00
0005434938572	3520	Economy	11700.00
0005434880237	3520	Economy	11700.00
0005435127269	3520	Economy	11700.00
0005432613951	3520	Economy	11700.00
0005434427236	3520	Economy	11700.00
0005435626579	3520	Economy	11700.00
0005435902970	3520	Economy	11700.00
0005435626575	3520	Economy	11700.00
0005434880284	3520	Economy	11700.00
0005434880290	3520	Economy	11700.00
0005434938557	3520	Economy	11700.00
0005434880286	3520	Economy	11700.00
0005435902859	3520	Economy	11700.00
0005435127242	3520	Economy	11700.00
0005434880220	3520	Economy	11700.00
0005432188678	3520	Economy	11700.00
0005432611785	3520	Economy	11700.00
0005435127235	3520	Economy	11700.00
0005434880248	3520	Economy	11700.00
0005435902971	3520	Economy	11700.00
0005432800080	3520	Economy	11700.00
0005435127248	3520	Economy	11700.00
0005434880255	3520	Economy	11700.00
0005434880240	3520	Economy	11700.00
0005434880273	3520	Economy	11700.00
0005435902928	3520	Economy	11700.00
0005435127256	3520	Economy	11700.00
0005434427233	3520	Economy	11700.00
0005435626580	3520	Economy	11700.00
0005435127237	3520	Economy	11700.00
0005434427249	3520	Economy	11700.00
0005432183514	3520	Economy	11700.00
0005435902932	3520	Economy	11700.00
0005432800073	3520	Economy	11700.00
0005432800076	3520	Economy	11700.00
0005434880242	3520	Economy	11700.00
0005434880293	3520	Economy	11700.00
0005432613950	3520	Economy	11700.00
0005434880288	3520	Economy	11700.00
0005434880270	3520	Economy	11700.00
0005435127243	3520	Economy	11700.00
0005435914706	3520	Economy	11700.00
0005435626570	3520	Economy	11700.00
0005432800079	3520	Economy	11700.00
0005435127229	3520	Economy	11700.00
0005435841827	3520	Economy	11700.00
0005432183513	3520	Economy	11700.00
0005435626573	3520	Economy	11700.00
0005434938564	3520	Economy	11700.00
0005435127245	3520	Economy	11700.00
0005434880264	3520	Economy	11700.00
0005434880228	3520	Economy	11700.00
0005432800074	3520	Economy	11700.00
0005435841103	3520	Economy	11700.00
0005434938554	3520	Economy	11700.00
0005434880287	3520	Economy	11700.00
0005435127258	3520	Economy	11700.00
0005434880304	3520	Economy	11700.00
0005434880299	3520	Economy	11700.00
0005434880224	3520	Economy	11700.00
0005434880214	3520	Economy	11700.00
0005434938566	3520	Economy	11700.00
0005434427254	3520	Economy	11700.00
0005434880307	3520	Economy	11700.00
0005435914705	3520	Economy	11700.00
0005432611786	3520	Economy	11700.00
0005435626581	3520	Economy	11700.00
0005432800065	3520	Economy	11700.00
0005434427243	3520	Economy	11700.00
0005434938556	3520	Economy	11700.00
0005434938570	3520	Economy	11700.00
0005434880281	3520	Economy	11700.00
0005432800055	3520	Economy	11700.00
0005432613949	3520	Economy	11700.00
0005434880276	3520	Economy	11700.00
0005435127259	3520	Economy	11700.00
0005435626574	3520	Economy	11700.00
0005434880230	3520	Economy	11700.00
0005432800057	3520	Economy	11700.00
0005432611787	3520	Economy	12800.00
0005434880241	3520	Economy	11700.00
0005434938559	3520	Economy	12800.00
0005434880217	3520	Economy	12800.00
0005435127268	3520	Economy	12800.00
0005434880233	3520	Economy	11700.00
0005432800066	3520	Economy	11700.00
0005434880294	3520	Economy	11700.00
0005434880278	3520	Economy	11700.00
0005435626582	3520	Economy	11700.00
0005435626566	3520	Economy	11700.00
0005434880280	3520	Economy	11700.00
0005435841828	3520	Economy	11700.00
0005434880215	3520	Economy	11700.00
0005434880221	3520	Economy	11700.00
0005435841832	3520	Economy	11700.00
0005435127261	3520	Economy	11700.00
0005435127233	3520	Economy	11700.00
0005435127260	3520	Economy	11700.00
0005435127255	3520	Economy	11700.00
0005435841102	3520	Economy	11700.00
0005432800052	3520	Economy	11700.00
0005434938571	3520	Economy	11700.00
0005434880236	3520	Economy	11700.00
0005435127240	3520	Economy	11700.00
0005432800062	3520	Economy	11700.00
0005434880274	3520	Economy	11700.00
0005435902860	3520	Economy	11700.00
0005435127239	3520	Economy	11700.00
0005435127231	3520	Economy	11700.00
0005435903013	3520	Economy	11700.00
0005434938574	3520	Economy	11700.00
0005432800068	3520	Economy	11700.00
0005434880254	3520	Economy	11700.00
0005434880298	3520	Economy	11700.00
0005435626568	3520	Economy	11700.00
0005435902933	3520	Economy	11700.00
0005434938562	3520	Economy	11700.00
0005432800056	3520	Economy	11700.00
0005434427253	3520	Economy	11700.00
0005432800070	3520	Economy	11700.00
0005435626585	3520	Economy	11700.00
0005435626562	3520	Economy	11700.00
0005432800054	3520	Economy	11700.00
0005434938563	3520	Economy	11700.00
0005435127241	3520	Economy	11700.00
0005434880250	3520	Economy	11700.00
0005434880216	3520	Economy	11700.00
0005434880258	3520	Economy	11700.00
0005434938561	3520	Economy	11700.00
0005434938573	3520	Economy	11700.00
0005432800061	3520	Economy	11700.00
0005432800058	3520	Economy	11700.00
0005435626583	3520	Economy	11700.00
0005435127267	3520	Economy	11700.00
0005434938558	3520	Economy	11700.00
0005434880251	3520	Economy	11700.00
0005434880267	3520	Economy	11700.00
0005434427250	3520	Economy	11700.00
0005434880266	3520	Economy	11700.00
0005435127252	3520	Economy	11700.00
0005434427258	3520	Economy	11700.00
0005434427244	3520	Economy	11700.00
0005434427242	3520	Economy	11700.00
0005435626565	3520	Economy	11700.00
0005434427257	3520	Economy	11700.00
0005434880252	3520	Economy	11700.00
0005434880269	3520	Economy	11700.00
0005435902929	3520	Economy	11700.00
0005435127266	3520	Economy	11700.00
0005435127254	3520	Economy	11700.00
0005435914701	3520	Economy	11700.00
0005435913965	3520	Economy	11700.00
0005435127265	3520	Economy	11700.00
0005434880253	3520	Economy	11700.00
0005434427241	3520	Economy	11700.00
0005434880247	3520	Economy	11700.00
0005434880259	3520	Economy	11700.00
0005435626578	3520	Economy	11700.00
0005435902961	3520	Economy	11700.00
0005434427238	3520	Economy	11700.00
0005435127257	3520	Economy	11700.00
0005435127236	3520	Economy	11700.00
0005434880301	3520	Economy	11700.00
0005432800064	3520	Economy	11700.00
0005434938333	14593	Business	35000.00
0005434426971	14593	Business	35000.00
0005432799805	14593	Business	35000.00
0005434427108	14593	Business	35000.00
0005432799829	14593	Business	35000.00
0005435903082	14593	Business	35000.00
0005434879465	14593	Business	35000.00
0005435127059	14593	Business	35000.00
0005434879474	14593	Business	35000.00
0005434879347	14593	Business	35000.00
0005432611755	14593	Business	35000.00
0005434879135	14593	Business	35000.00
0005432607610	14593	Business	35000.00
0005434879248	14593	Business	35000.00
0005434879094	14593	Business	35000.00
0005434427004	14593	Business	35000.00
0005434879125	14593	Business	35000.00
0005434879496	14593	Business	35000.00
0005435126872	14593	Comfort	19900.00
0005434879291	14593	Comfort	19900.00
0005434879521	14593	Comfort	19900.00
0005434879560	14593	Comfort	19900.00
0005435126670	14593	Comfort	19900.00
0005435914041	14593	Comfort	19900.00
0005435626402	14593	Comfort	19900.00
0005435903077	14593	Comfort	19900.00
0005434427071	14593	Comfort	19900.00
0005432799689	14593	Comfort	19900.00
0005434427040	14593	Comfort	19900.00
0005434426944	14593	Comfort	19900.00
0005434879600	14593	Comfort	19900.00
0005435914727	14593	Comfort	19900.00
0005435626330	14593	Comfort	19900.00
0005434879024	14593	Comfort	19900.00
0005434879694	14593	Comfort	19900.00
0005434426931	14593	Comfort	19900.00
0005434879310	14593	Comfort	19900.00
0005435903079	14593	Comfort	19900.00
0005435126950	14593	Comfort	19900.00
0005435126887	14593	Comfort	19900.00
0005434938410	14593	Comfort	19900.00
0005432799752	14593	Comfort	19900.00
0005434879624	14593	Comfort	19900.00
0005432799774	14593	Comfort	19900.00
0005434879300	14593	Comfort	19900.00
0005434427007	14593	Comfort	19900.00
0005434879292	14593	Comfort	19900.00
0005435626403	14593	Comfort	19900.00
0005434879825	14593	Economy	11700.00
0005434938409	14593	Economy	11700.00
0005435126949	14593	Economy	11700.00
0005435903086	14593	Economy	11700.00
0005435914037	14593	Economy	11700.00
0005435914039	14593	Economy	11700.00
0005434879455	14593	Economy	11700.00
0005435626391	14593	Economy	11700.00
0005434427003	14593	Economy	11700.00
0005432799847	14593	Economy	11700.00
0005435914027	14593	Economy	11700.00
0005434879783	14593	Economy	11700.00
0005434879195	14593	Economy	11700.00
0005434427002	14593	Economy	11700.00
0005432611757	14593	Economy	11700.00
0005432611753	14593	Economy	11700.00
0005435126954	14593	Economy	11700.00
0005435126794	14593	Economy	11700.00
0005434879431	14593	Economy	11700.00
0005432799910	14593	Economy	11700.00
0005434879781	14593	Economy	11700.00
0005434879257	14593	Economy	11700.00
0005435126880	14593	Economy	11700.00
0005435126926	14593	Economy	11700.00
0005435126842	14593	Economy	11700.00
0005435126977	14593	Economy	11700.00
0005435127019	14593	Economy	11700.00
0005432799899	14593	Economy	11700.00
0005434879548	14593	Economy	11700.00
0005434879105	14593	Economy	11700.00
0005434427061	14593	Economy	11700.00
0005435126657	14593	Economy	11700.00
0005434879093	14593	Economy	11700.00
0005434879812	14593	Economy	11700.00
0005435842346	14593	Economy	11700.00
0005434426981	14593	Economy	11700.00
0005434938339	14593	Economy	11700.00
0005435626354	14593	Economy	11700.00
0005435914032	14593	Economy	11700.00
0005432799633	14593	Economy	11700.00
0005435914036	14593	Economy	11700.00
0005434879634	14593	Economy	11700.00
0005435126851	14593	Economy	11700.00
0005435914038	14593	Economy	11700.00
0005435903081	14593	Economy	11700.00
0005432799789	14593	Economy	11700.00
0005435903085	14593	Economy	11700.00
0005435914029	14593	Economy	11700.00
0005434879512	14593	Economy	11700.00
0005435126787	14593	Economy	11700.00
0005435126759	14593	Economy	12800.00
0005435126760	14593	Economy	12800.00
0005432799861	14593	Economy	12800.00
0005435903089	14593	Economy	11700.00
0005435626384	14593	Economy	11700.00
0005435903084	14593	Economy	11700.00
0005432611754	14593	Economy	11700.00
0005435126655	14593	Economy	12800.00
0005432799793	14593	Economy	12800.00
0005434938401	14593	Economy	11700.00
0005435126910	14593	Economy	12800.00
0005435841841	14593	Economy	11700.00
0005435626241	14593	Economy	11700.00
0005435914726	14593	Economy	11700.00
0005435903078	14593	Economy	11700.00
0005432611756	14593	Economy	11700.00
0005434879695	14593	Economy	11700.00
0005432799880	14593	Economy	11700.00
0005435126885	14593	Economy	11700.00
0005434879633	14593	Economy	11700.00
0005434879606	14593	Economy	11700.00
0005434879605	14593	Economy	11700.00
0005434426945	14593	Economy	11700.00
0005434879399	14593	Economy	11700.00
0005434879342	14593	Economy	11700.00
0005435126886	14593	Economy	11700.00
0005432799714	14593	Economy	11700.00
0005434427059	14593	Economy	11700.00
0005432799792	14593	Economy	11700.00
0005435126909	14593	Economy	11700.00
0005434938392	14593	Economy	11700.00
0005435127020	14593	Economy	11700.00
0005434879061	14593	Economy	11700.00
0005434879435	14593	Economy	11700.00
0005435126938	14593	Economy	11700.00
0005434879368	14593	Economy	11700.00
0005432059547	14593	Economy	11700.00
0005435126690	14593	Economy	11700.00
0005434879518	14593	Economy	11700.00
0005434879797	14593	Economy	11700.00
0005432799712	14593	Economy	11700.00
0005434879430	14593	Economy	11700.00
0005434879558	14593	Economy	11700.00
0005435126873	14593	Economy	11700.00
0005434879679	14593	Economy	11700.00
0005435626397	14593	Economy	11700.00
0005435626390	14593	Economy	11700.00
0005435626393	14593	Economy	11700.00
0005434426923	14593	Economy	11700.00
0005435126908	14593	Economy	11700.00
0005435126939	14593	Economy	11700.00
0005434879723	14593	Economy	11700.00
0005435126948	14593	Economy	11700.00
0005435903083	14593	Economy	11700.00
0005434879482	14593	Economy	11700.00
0005435626370	14593	Economy	11700.00
0005435126749	14593	Economy	11700.00
0005435126916	14593	Economy	11700.00
0005434879314	14593	Economy	11700.00
0005434427006	14593	Economy	11700.00
0005432799803	14593	Economy	11700.00
0005434427072	14593	Economy	11700.00
0005434938429	14593	Economy	11700.00
0005434426908	14593	Economy	11700.00
0005435626405	14593	Economy	11700.00
0005435126722	14593	Economy	11700.00
0005432799804	14593	Economy	11700.00
0005434879599	14593	Economy	11700.00
0005434427070	14593	Economy	11700.00
0005434879417	14593	Economy	11700.00
0005434879258	14593	Economy	11700.00
0005432799866	14593	Economy	11700.00
0005434878922	14593	Economy	11700.00
0005432799846	14593	Economy	11700.00
0005435914034	14593	Economy	11700.00
0005434879559	14593	Economy	11700.00
0005435126904	14593	Economy	11700.00
0005434879716	14593	Economy	11700.00
0005435126982	14593	Economy	11700.00
0005435903090	14593	Economy	11700.00
0005434938466	14593	Economy	11700.00
0005435914040	14593	Economy	11700.00
0005435126981	14593	Economy	11700.00
0005435903087	14593	Economy	11700.00
0005435903093	14593	Economy	11700.00
0005435126884	14593	Economy	11700.00
0005434879064	14593	Economy	11700.00
0005432059548	14593	Economy	11700.00
0005434879429	14593	Economy	11700.00
0005435126907	14593	Economy	11700.00
0005435126942	14593	Economy	11700.00
0005435126831	14593	Economy	11700.00
0005432607611	14593	Economy	12800.00
0005435127048	14593	Economy	12800.00
0005434938387	14593	Economy	12800.00
0005434879269	14593	Economy	11700.00
0005434879673	14593	Economy	11700.00
0005435126905	14593	Economy	11700.00
0005434879239	14593	Economy	11700.00
0005434879384	14593	Economy	11700.00
0005434879799	14593	Economy	11700.00
0005434879359	14593	Economy	11700.00
0005435841840	14593	Economy	11700.00
0005435903080	14593	Economy	11700.00
0005435126792	14593	Economy	11700.00
0005434879315	14593	Economy	11700.00
0005435914730	14593	Economy	11700.00
0005435126656	14593	Economy	11700.00
0005434426885	14593	Economy	11700.00
0005432799601	14593	Economy	11700.00
0005435914035	14593	Economy	11700.00
0005434879418	14593	Economy	11700.00
0005435126840	14593	Economy	11700.00
0005435914033	14593	Economy	11700.00
0005434938386	14593	Economy	11700.00
0005434879497	14593	Economy	11700.00
0005434879385	14593	Economy	11700.00
0005435903094	14593	Economy	11700.00
0005434880003	14593	Economy	11700.00
0005435914731	14593	Economy	11700.00
0005435914031	14593	Economy	11700.00
0005434427010	14593	Economy	11700.00
0005434426963	14593	Economy	11700.00
0005434879136	14593	Economy	11700.00
0005434879570	14593	Economy	11700.00
0005434879895	14593	Economy	11700.00
0005435126750	14593	Economy	11700.00
0005435126833	14593	Economy	11700.00
0005434426970	14593	Economy	11700.00
0005435903092	14593	Economy	11700.00
0005432799745	14593	Economy	11700.00
0005435126914	14593	Economy	11700.00
0005434879529	14593	Economy	11700.00
0005434879404	14593	Economy	11700.00
0005435914725	14593	Economy	11700.00
0005434879530	14593	Economy	11700.00
0005435126883	14593	Economy	11700.00
0005434879713	14593	Economy	11700.00
0005434879349	14593	Economy	11700.00
0005434879137	14593	Economy	11700.00
0005432799713	14593	Economy	11700.00
0005434879668	14593	Economy	11700.00
0005434879424	14593	Economy	11700.00
0005435626404	14593	Economy	11700.00
0005434879782	14593	Economy	11700.00
0005435126841	14593	Economy	11700.00
0005432799881	14593	Economy	11700.00
0005435914728	14593	Economy	11700.00
0005435126915	14593	Economy	11700.00
0005432799746	14593	Economy	11700.00
0005434879021	14593	Economy	11700.00
0005435903088	14593	Economy	11700.00
0005434879632	14593	Economy	11700.00
0005434426975	14593	Economy	11700.00
0005435126832	14593	Economy	11700.00
0005435903091	14593	Economy	11700.00
0005434427082	14593	Economy	11700.00
0005435842345	14593	Economy	11700.00
0005435914030	14593	Economy	11700.00
0005434879680	14593	Economy	11700.00
0005435126874	14593	Economy	11700.00
0005434879821	14593	Economy	11700.00
0005434879475	14593	Economy	11700.00
0005434879309	14593	Economy	11700.00
0005435126774	14593	Economy	11700.00
0005435626398	14593	Economy	11700.00
0005434879240	14593	Economy	11700.00
0005434879268	14593	Economy	11700.00
0005434879070	14593	Economy	11700.00
0005434879824	14593	Economy	11700.00
0005435914729	14593	Economy	11700.00
0005434426940	14593	Economy	11700.00
0005435914028	14593	Economy	11700.00
0005434879800	14593	Economy	11700.00
0005434312362	3617	Economy	16300.00
0005434312363	3617	Economy	16300.00
0005434325898	3617	Economy	16300.00
0005435889984	3617	Economy	14800.00
0005435889971	3617	Economy	14800.00
0005434325904	3617	Economy	14800.00
0005434312386	3617	Economy	14800.00
0005434325902	3617	Economy	14800.00
0005434325899	3617	Economy	14800.00
0005435889954	3617	Economy	14800.00
0005434325896	3617	Economy	14800.00
0005434325905	3617	Economy	14800.00
0005435889956	3617	Economy	14800.00
0005434325895	3617	Economy	14800.00
0005434325894	3617	Economy	14800.00
0005435889985	3617	Economy	14800.00
0005435889977	3617	Economy	14800.00
0005434325903	3617	Economy	14800.00
0005434325900	3617	Economy	14800.00
0005434325893	3617	Economy	14800.00
0005435889955	3617	Economy	14800.00
0005434325901	3617	Economy	14800.00
0005434325897	3617	Economy	14800.00
0005434325804	15614	Economy	14800.00
0005435890026	15614	Economy	14800.00
0005434325788	15614	Economy	14800.00
0005435890029	15614	Economy	14800.00
0005435890028	15614	Economy	14800.00
0005434325850	15614	Economy	14800.00
0005434325851	15614	Economy	14800.00
0005434325769	15614	Economy	14800.00
0005435890024	15614	Economy	14800.00
0005435890025	15614	Economy	14800.00
0005434325818	15614	Economy	14800.00
0005434325819	15614	Economy	14800.00
0005435890027	15614	Economy	14800.00
0005434325783	15614	Economy	14800.00
0005434325826	15614	Economy	14800.00
0005434325803	15614	Economy	14800.00
0005434325817	15614	Economy	14800.00
0005434325832	15614	Economy	14800.00
0005435958014	671	Economy	4500.00
0005435958018	671	Economy	4500.00
0005435958013	671	Economy	4100.00
0005433420503	671	Economy	4100.00
0005433420508	671	Economy	4100.00
0005435958023	671	Economy	4100.00
0005435958026	671	Economy	4100.00
0005433420502	671	Economy	4100.00
0005435958022	671	Economy	4100.00
0005435958016	671	Economy	4100.00
0005435958017	671	Economy	4100.00
0005435958025	671	Economy	4100.00
0005433420506	671	Economy	4100.00
0005435958024	671	Economy	4100.00
0005435958015	671	Economy	4100.00
0005435958020	671	Economy	4100.00
0005435958012	671	Economy	4100.00
0005435958021	671	Economy	4100.00
0005435958019	671	Economy	4100.00
0005433420588	15187	Economy	4500.00
0005435957854	15187	Economy	4500.00
0005435957903	15187	Economy	4100.00
0005433420586	15187	Economy	4100.00
0005433420590	15187	Economy	4100.00
0005433420589	15187	Economy	4100.00
0005433420584	15187	Economy	4100.00
0005433420585	15187	Economy	4100.00
0005435957938	15187	Economy	4100.00
0005435957853	15187	Economy	4100.00
0005435957901	15187	Economy	4100.00
0005433420587	15187	Economy	4100.00
0005435957872	15187	Economy	4100.00
0005435957900	15187	Economy	4100.00
0005435957904	15187	Economy	4100.00
0005435957905	15187	Economy	4100.00
0005433420583	15187	Economy	4100.00
0005435957848	15187	Economy	4100.00
0005435217755	31779	Economy	28100.00
0005435217759	31779	Economy	28100.00
0005435216633	31779	Economy	28100.00
0005435218130	31779	Economy	25500.00
0005435218129	31779	Economy	25500.00
0005435217760	31779	Economy	25500.00
0005435217754	31779	Economy	25500.00
0005435218133	31779	Economy	25500.00
0005435216631	31779	Economy	25500.00
0005435217758	31779	Economy	25500.00
0005435216635	31779	Economy	25500.00
0005435216632	31779	Economy	25500.00
0005435216634	31779	Economy	25500.00
0005435218131	31779	Economy	25500.00
0005435218132	31779	Economy	25500.00
0005435217757	31779	Economy	25500.00
0005435217756	31779	Economy	25500.00
0005434995351	6703	Business	94000.00
0005434995340	6703	Business	94000.00
0005434995349	6703	Economy	31300.00
0005434995344	6703	Economy	31300.00
0005434995342	6703	Economy	31300.00
0005434995347	6703	Economy	31300.00
0005434995345	6703	Economy	31300.00
0005434995339	6703	Economy	31300.00
0005434995350	6703	Economy	31300.00
0005434995343	6703	Economy	31300.00
0005434995346	6703	Economy	31300.00
0005434995352	6703	Economy	31300.00
0005434995353	6703	Economy	31300.00
0005434995348	6703	Economy	31300.00
0005434995341	6703	Economy	31300.00
0005435629432	8944	Economy	10400.00
0005434247178	8944	Economy	10400.00
0005434247179	8944	Economy	10400.00
0005434247202	16071	Economy	10400.00
0005434247203	16071	Economy	10400.00
0005434247204	16071	Economy	10400.00
0005434467810	4004	Economy	23400.00
0005434467812	4004	Economy	21200.00
0005434467811	4004	Economy	21200.00
0005434467809	4004	Economy	21200.00
0005434467814	4004	Economy	21200.00
0005434467813	4004	Economy	21200.00
0005434467770	23203	Economy	21200.00
0005434467778	23203	Economy	21200.00
0005434467790	23203	Economy	21200.00
0005434467771	23203	Economy	21200.00
0005434096787	20163	Economy	13400.00
0005434096780	20163	Economy	13400.00
0005434096783	20163	Economy	13400.00
0005434096782	20163	Economy	13400.00
0005434096785	20163	Economy	13400.00
0005434096786	20163	Economy	13400.00
0005434096781	20163	Economy	13400.00
0005434096784	20163	Economy	13400.00
0005434096779	20163	Economy	13400.00
0005435229500	6844	Business	87700.00
0005432646263	6844	Business	87700.00
0005432646265	6844	Business	87700.00
0005432646261	6844	Business	87700.00
0005432646244	6844	Business	87700.00
0005435229512	6844	Business	87700.00
0005435229485	6844	Business	87700.00
0005432646270	6844	Economy	29200.00
0005435229464	6844	Economy	29200.00
0005432646262	6844	Economy	29200.00
0005432646273	6844	Economy	29200.00
0005432646250	6844	Economy	29200.00
0005435229515	6844	Economy	29200.00
0005432646253	6844	Economy	29200.00
0005432646258	6844	Economy	32200.00
0005432646268	6844	Economy	32200.00
0005432646246	6844	Economy	29200.00
0005432646241	6844	Economy	29200.00
0005435229498	6844	Economy	29200.00
0005432646269	6844	Economy	29200.00
0005435229466	6844	Economy	29200.00
0005435229493	6844	Economy	29200.00
0005432646242	6844	Economy	29200.00
0005432646271	6844	Economy	29200.00
0005432646276	6844	Economy	29200.00
0005432646277	6844	Economy	29200.00
0005432646264	6844	Economy	29200.00
0005432646266	6844	Economy	29200.00
0005432646254	6844	Economy	29200.00
0005432646279	6844	Economy	29200.00
0005435229467	6844	Economy	29200.00
0005432646274	6844	Economy	29200.00
0005432646259	6844	Economy	29200.00
0005435229499	6844	Economy	29200.00
0005435229509	6844	Economy	29200.00
0005432646256	6844	Economy	29200.00
0005432646243	6844	Economy	29200.00
0005432646278	6844	Economy	29200.00
0005432646251	6844	Economy	29200.00
0005432646247	6844	Economy	29200.00
0005435229486	6844	Economy	29200.00
0005435229517	6844	Economy	29200.00
0005432646255	6844	Economy	29200.00
0005435229505	6844	Economy	29200.00
0005432646272	6844	Economy	29200.00
0005432646257	6844	Economy	29200.00
0005435229514	6844	Economy	29200.00
0005432646260	6844	Economy	29200.00
0005435229518	6844	Economy	29200.00
0005432646248	6844	Economy	29200.00
0005432646275	6844	Economy	29200.00
0005432646252	6844	Economy	29200.00
0005435229465	6844	Economy	29200.00
0005435229510	6844	Economy	29200.00
0005432646249	6844	Economy	29200.00
0005432646245	6844	Economy	29200.00
0005432646267	6844	Economy	29200.00
0005435229579	25107	Business	87700.00
0005435229568	25107	Business	87700.00
0005432646107	25107	Business	87700.00
0005432646175	25107	Business	87700.00
0005432646095	25107	Business	87700.00
0005435229586	25107	Business	87700.00
0005435229571	25107	Business	87700.00
0005432646136	25107	Business	87700.00
0005432646071	25107	Business	87700.00
0005435229570	25107	Business	87700.00
0005432646072	25107	Business	87700.00
0005435229562	25107	Economy	29200.00
0005435229565	25107	Economy	29200.00
0005432646069	25107	Economy	29200.00
0005435229575	25107	Economy	29200.00
0005435229573	25107	Economy	29200.00
0005432646174	25107	Economy	29200.00
0005432646119	25107	Economy	32200.00
0005432646094	25107	Economy	32200.00
0005432646137	25107	Economy	32200.00
0005432646162	25107	Economy	32200.00
0005432646171	25107	Economy	32200.00
0005432646098	25107	Economy	29200.00
0005432646138	25107	Economy	29200.00
0005432646022	25107	Economy	29200.00
0005435229577	25107	Economy	29200.00
0005432646176	25107	Economy	29200.00
0005435229569	25107	Economy	29200.00
0005435229580	25107	Economy	29200.00
0005432646102	25107	Economy	29200.00
0005435229578	25107	Economy	29200.00
0005432646108	25107	Economy	29200.00
0005432646074	25107	Economy	29200.00
0005432646157	25107	Economy	29200.00
0005432646124	25107	Economy	29200.00
0005435229559	25107	Economy	29200.00
0005432646178	25107	Economy	29200.00
0005435229581	25107	Economy	29200.00
0005432646125	25107	Economy	29200.00
0005435229574	25107	Economy	29200.00
0005432646103	25107	Economy	29200.00
0005432646117	25107	Economy	29200.00
0005432646112	25107	Economy	29200.00
0005432646093	25107	Economy	29200.00
0005432646111	25107	Economy	29200.00
0005432646129	25107	Economy	29200.00
0005432646131	25107	Economy	29200.00
0005432646196	25107	Economy	29200.00
0005432646096	25107	Economy	29200.00
0005432646101	25107	Economy	29200.00
0005432646146	25107	Economy	29200.00
0005432646130	25107	Economy	29200.00
0005432646139	25107	Economy	29200.00
0005432646104	25107	Economy	29200.00
0005435229566	25107	Economy	29200.00
0005432646064	25107	Economy	29200.00
0005432646118	25107	Economy	29200.00
0005432646158	25107	Economy	29200.00
0005432646099	25107	Economy	29200.00
0005435229567	25107	Economy	29200.00
0005432646177	25107	Economy	29200.00
0005432646161	25107	Economy	29200.00
0005432646105	25107	Economy	29200.00
0005432646160	25107	Economy	29200.00
0005435229558	25107	Economy	29200.00
0005435229560	25107	Economy	29200.00
0005432646121	25107	Economy	29200.00
0005432646120	25107	Economy	29200.00
0005435229561	25107	Economy	29200.00
0005432646170	25107	Economy	29200.00
0005432646140	25107	Economy	29200.00
0005435229585	25107	Economy	29200.00
0005435229576	25107	Economy	29200.00
0005435229563	25107	Economy	29200.00
0005435229584	25107	Economy	29200.00
0005435229583	25107	Economy	29200.00
0005435229582	25107	Economy	29200.00
0005435229564	25107	Economy	29200.00
0005435229572	25107	Economy	29200.00
0005432646100	25107	Economy	29200.00
0005435797777	2843	Business	12600.00
0005433404892	2843	Business	12600.00
0005435797779	2843	Economy	4200.00
0005435797785	2843	Economy	4200.00
0005435797772	2843	Economy	4200.00
0005433404919	2843	Economy	4600.00
0005435797773	2843	Economy	4600.00
0005433404893	2843	Economy	4200.00
0005433404878	2843	Economy	4200.00
0005435797782	2843	Economy	4200.00
0005435797778	2843	Economy	4200.00
0005433404884	2843	Economy	4200.00
0005435797780	2843	Economy	4200.00
0005435797781	2843	Economy	4200.00
0005435797776	2843	Economy	4200.00
0005433404920	2843	Economy	4200.00
0005433404907	2843	Economy	4200.00
0005435797784	2843	Economy	4200.00
0005433404912	2843	Economy	4200.00
0005435797783	2843	Economy	4200.00
0005435797774	2843	Economy	4200.00
0005435797775	2843	Economy	4200.00
0005433404967	29318	Business	12600.00
0005433404974	29318	Business	12600.00
0005435797693	29318	Business	12600.00
0005435797635	29318	Economy	4200.00
0005433404969	29318	Economy	4200.00
0005435797630	29318	Economy	4200.00
0005435797666	29318	Economy	4200.00
0005433404970	29318	Economy	4600.00
0005433404968	29318	Economy	4600.00
0005435797719	29318	Economy	4200.00
0005433404973	29318	Economy	4200.00
0005433404971	29318	Economy	4200.00
0005435797699	29318	Economy	4200.00
0005435797725	29318	Economy	4200.00
0005435797684	29318	Economy	4200.00
0005435797671	29318	Economy	4200.00
0005435797698	29318	Economy	4200.00
0005435797720	29318	Economy	4200.00
0005435797751	29318	Economy	4200.00
0005435797718	29318	Economy	4200.00
0005435797653	29318	Economy	4200.00
0005435797606	29318	Economy	4200.00
0005435797668	29318	Economy	4200.00
0005435797634	29318	Economy	4200.00
0005435797673	29318	Economy	4200.00
0005435797667	29318	Economy	4200.00
0005433404972	29318	Economy	4200.00
0005435376383	5753	Economy	6800.00
0005435376374	5753	Economy	6800.00
0005434948204	5746	Economy	6800.00
0005434948198	5746	Economy	6800.00
0005434948201	5746	Economy	6800.00
0005434948203	5746	Economy	6800.00
0005434948202	5746	Economy	6800.00
0005434948199	5746	Economy	6800.00
0005434948196	5746	Economy	6800.00
0005434948195	5746	Economy	6800.00
0005434948200	5746	Economy	6800.00
0005434948197	5746	Economy	6800.00
0005434948094	16416	Economy	6800.00
0005434948136	16416	Economy	6800.00
0005434948065	16416	Economy	6800.00
0005434948099	16416	Economy	6800.00
0005434948079	16416	Economy	6800.00
0005434948115	16416	Economy	6800.00
0005434948095	16416	Economy	6800.00
0005434948137	16416	Economy	6800.00
0005434948064	16416	Economy	6800.00
0005434948118	16416	Economy	6800.00
0005434948125	16416	Economy	6800.00
0005433962127	6964	Business	21400.00
0005433962120	6964	Business	21400.00
0005433962103	6964	Business	21400.00
0005433962116	6964	Business	21400.00
0005433962144	6964	Business	21400.00
0005433962113	6964	Business	21400.00
0005433962114	6964	Economy	7100.00
0005433962122	6964	Economy	7100.00
0005433962111	6964	Economy	7100.00
0005433962105	6964	Economy	7100.00
0005433962132	6964	Economy	7100.00
0005433962129	6964	Economy	7100.00
0005433962137	6964	Economy	7100.00
0005433962107	6964	Economy	7100.00
0005433962112	6964	Economy	7100.00
0005433962108	6964	Economy	7100.00
0005433962130	6964	Economy	7100.00
0005433962124	6964	Economy	7100.00
0005433962110	6964	Economy	7100.00
0005433962106	6964	Economy	7100.00
0005433962125	6964	Economy	7100.00
0005433962121	6964	Economy	7100.00
0005433962139	6964	Economy	7100.00
0005433962117	6964	Economy	7100.00
0005433962142	6964	Economy	7100.00
0005433962140	6964	Economy	7100.00
0005433962131	6964	Economy	7100.00
0005433962109	6964	Economy	7100.00
0005433962119	6964	Economy	7100.00
0005433962134	6964	Economy	7100.00
0005433962128	6964	Economy	7100.00
0005433962136	6964	Economy	7100.00
0005433962102	6964	Economy	7100.00
0005433962100	6964	Economy	7100.00
0005433962146	6964	Economy	7100.00
0005433962138	6964	Economy	7100.00
0005433962101	6964	Economy	7100.00
0005433962123	6964	Economy	7100.00
0005433962133	6964	Economy	7100.00
0005433962126	6964	Economy	7100.00
0005433962135	6964	Economy	7100.00
0005433962141	6964	Economy	7100.00
0005433962104	6964	Economy	7100.00
0005433962115	6964	Economy	7100.00
0005433962143	6964	Economy	7100.00
0005433962145	6964	Economy	7100.00
0005433962118	6964	Economy	7100.00
0005433961477	25747	Business	21400.00
0005433961365	25747	Business	21400.00
0005433961458	25747	Business	21400.00
0005433961310	25747	Business	21400.00
0005433961434	25747	Business	21400.00
0005433961412	25747	Business	21400.00
0005433961417	25747	Business	21400.00
0005433961395	25747	Business	21400.00
0005433961482	25747	Economy	7100.00
0005433961277	25747	Economy	7100.00
0005433961283	25747	Economy	7100.00
0005433961476	25747	Economy	7100.00
0005433961484	25747	Economy	7800.00
0005433961352	25747	Economy	7800.00
0005433961309	25747	Economy	7800.00
0005433961453	25747	Economy	7800.00
0005433961483	25747	Economy	7800.00
0005433961436	25747	Economy	7100.00
0005433961356	25747	Economy	7100.00
0005433961430	25747	Economy	7100.00
0005433961449	25747	Economy	7100.00
0005433961415	25747	Economy	7100.00
0005433961425	25747	Economy	7100.00
0005433961438	25747	Economy	7100.00
0005433961442	25747	Economy	7100.00
0005433961244	25747	Economy	7100.00
0005433961372	25747	Economy	7100.00
0005433961311	25747	Economy	7100.00
0005433961388	25747	Economy	7100.00
0005433961390	25747	Economy	7100.00
0005433961278	25747	Economy	7100.00
0005433961419	25747	Economy	7100.00
0005433961478	25747	Economy	7100.00
0005433961396	25747	Economy	7100.00
0005433961378	25747	Economy	7100.00
0005433961276	25747	Economy	7100.00
0005433961273	25747	Economy	7100.00
0005433961284	25747	Economy	7100.00
0005433961435	25747	Economy	7100.00
0005433961411	25747	Economy	7100.00
0005433961350	25747	Economy	7100.00
0005433961353	25747	Economy	7100.00
0005433961464	25747	Economy	7100.00
0005433961377	25747	Economy	7100.00
0005433961447	25747	Economy	7100.00
0005433961418	25747	Economy	7100.00
0005433961485	25747	Economy	7100.00
0005433961271	25747	Economy	7100.00
0005433961457	25747	Economy	7100.00
0005433961389	25747	Economy	7100.00
0005433961439	25747	Economy	7100.00
0005433961428	25747	Economy	7100.00
0005433961488	25747	Economy	7100.00
0005433961448	25747	Economy	7100.00
0005433961471	25747	Economy	7100.00
0005433961272	25747	Economy	7100.00
0005433961420	25747	Economy	7100.00
0005433961441	25747	Economy	7100.00
0005433961437	25747	Economy	7100.00
0005435082888	24519	Economy	3900.00
0005435082875	24519	Economy	3900.00
0005435082874	24519	Economy	3900.00
0005435082876	24519	Economy	3900.00
0005435082857	24519	Economy	3900.00
0005435082864	24519	Economy	3900.00
0005435082889	24519	Economy	3900.00
0005435082858	24519	Economy	3900.00
0005435082954	26079	Economy	3900.00
0005435082955	26079	Economy	3900.00
0005435082952	26079	Economy	3900.00
0005435082957	26079	Economy	3900.00
0005435082956	26079	Economy	3900.00
0005435082953	26079	Economy	3900.00
0005434245626	4968	Business	18000.00
0005435286706	4968	Business	18000.00
0005434245605	4968	Business	18000.00
0005433534524	4968	Business	18000.00
0005435286705	4968	Economy	6600.00
0005434245619	4968	Economy	6000.00
0005434245613	4968	Economy	6000.00
0005434245607	4968	Economy	6000.00
0005433534532	4968	Economy	6000.00
0005434245617	4968	Economy	6000.00
0005434245598	4968	Economy	6000.00
0005432166971	4968	Economy	6000.00
0005434245614	4968	Economy	6000.00
0005434245606	4968	Economy	6000.00
0005434245622	4968	Economy	6000.00
0005434245610	4968	Economy	6000.00
0005434245601	4968	Economy	6000.00
0005435286709	4968	Economy	6000.00
0005434245627	4968	Economy	6000.00
0005435286703	4968	Economy	6000.00
0005435286687	4968	Economy	6000.00
0005434245615	4968	Economy	6000.00
0005435286702	4968	Economy	6000.00
0005434245600	4968	Economy	6000.00
0005434245609	4968	Economy	6000.00
0005433534533	4968	Economy	6000.00
0005435286671	4968	Economy	6000.00
0005434245604	4968	Economy	6600.00
0005434245612	4968	Economy	6000.00
0005434245602	4968	Economy	6600.00
0005434245625	4968	Economy	6000.00
0005434245611	4968	Economy	6000.00
0005432166972	4968	Economy	6000.00
0005434245616	4968	Economy	6000.00
0005434245623	4968	Economy	6000.00
0005434245620	4968	Economy	6000.00
0005434245603	4968	Economy	6000.00
0005434245621	4968	Economy	6000.00
0005433534525	4968	Economy	6000.00
0005434245608	4968	Economy	6000.00
0005434245618	4968	Economy	6000.00
0005434245624	4968	Economy	6000.00
0005434245599	4968	Economy	6000.00
0005432106613	4967	Business	18000.00
0005433785732	4967	Business	18000.00
0005432106584	4967	Business	18000.00
0005432106589	4967	Business	18000.00
0005433616251	4967	Business	18000.00
0005433616264	4967	Business	18000.00
0005432106618	4967	Business	18000.00
0005433785723	4967	Business	18000.00
0005432106575	4967	Business	18000.00
0005433616298	4967	Business	18000.00
0005433616241	4967	Business	18000.00
0005432106600	4967	Business	18000.00
0005432667499	4967	Business	18000.00
0005433785715	4967	Business	18000.00
0005432665319	4967	Business	18000.00
0005433616286	4967	Business	18000.00
0005432106614	4967	Business	18000.00
0005432106577	4967	Business	18000.00
0005432667498	4967	Business	18000.00
0005433616238	4967	Business	18000.00
0005433785713	4967	Business	18000.00
0005433785734	4967	Business	18000.00
0005433616272	4967	Business	18000.00
0005433616250	4967	Business	18000.00
0005433616263	4967	Business	18000.00
0005432106573	4967	Business	18000.00
0005433616284	4967	Business	18000.00
0005433785737	4967	Business	18000.00
0005432106579	4967	Economy	6600.00
0005432106588	4967	Economy	6600.00
0005433616281	4967	Economy	6600.00
0005432106597	4967	Economy	6600.00
0005432106594	4967	Economy	6600.00
0005432106599	4967	Economy	6600.00
0005433785707	4967	Economy	6000.00
0005433616304	4967	Economy	6000.00
0005432106615	4967	Economy	6000.00
0005433616257	4967	Economy	6000.00
0005432106578	4967	Economy	6000.00
0005432106592	4967	Economy	6000.00
0005433616258	4967	Economy	6000.00
0005432666434	4967	Economy	6000.00
0005433616232	4967	Economy	6000.00
0005432106581	4967	Economy	6000.00
0005432106620	4967	Economy	6000.00
0005432106583	4967	Economy	6000.00
0005432106591	4967	Economy	6000.00
0005432106610	4967	Economy	6000.00
0005433616246	4967	Economy	6000.00
0005433616282	4967	Economy	6000.00
0005433616252	4967	Economy	6000.00
0005433616301	4967	Economy	6000.00
0005433785727	4967	Economy	6000.00
0005433785746	4967	Economy	6000.00
0005433785717	4967	Economy	6000.00
0005432106608	4967	Economy	6000.00
0005432106572	4967	Economy	6000.00
0005433785721	4967	Economy	6000.00
0005433616233	4967	Economy	6000.00
0005433785719	4967	Economy	6000.00
0005433616253	4967	Economy	6000.00
0005433616244	4967	Economy	6000.00
0005433785712	4967	Economy	6000.00
0005432106574	4967	Economy	6000.00
0005433616293	4967	Economy	6000.00
0005432666433	4967	Economy	6000.00
0005433785714	4967	Economy	6000.00
0005433616274	4967	Economy	6000.00
0005432106601	4967	Economy	6000.00
0005433616262	4967	Economy	6000.00
0005433616242	4967	Economy	6000.00
0005433616270	4967	Economy	6000.00
0005433616297	4967	Economy	6000.00
0005433616237	4967	Economy	6000.00
0005433616255	4967	Economy	6000.00
0005433616275	4967	Economy	6000.00
0005433785729	4967	Economy	6000.00
0005433785725	4967	Economy	6000.00
0005433616287	4967	Economy	6000.00
0005433785740	4967	Economy	6000.00
0005433616268	4967	Economy	6000.00
0005433616249	4967	Economy	6000.00
0005433785716	4967	Economy	6000.00
0005433616260	4967	Economy	6000.00
0005433616280	4967	Economy	6000.00
0005432106616	4967	Economy	6000.00
0005433616290	4967	Economy	6000.00
0005433785733	4967	Economy	6000.00
0005433616279	4967	Economy	6000.00
0005432106606	4967	Economy	6000.00
0005433616277	4967	Economy	6000.00
0005432106587	4967	Economy	6000.00
0005433785720	4967	Economy	6000.00
0005433785736	4967	Economy	6000.00
0005433785710	4967	Economy	6600.00
0005433785745	4967	Economy	6600.00
0005433616261	4967	Economy	6600.00
0005433785722	4967	Economy	6600.00
0005433785724	4967	Economy	6600.00
0005433616302	4967	Economy	6000.00
0005432106585	4967	Economy	6000.00
0005433616283	4967	Economy	6000.00
0005433785730	4967	Economy	6600.00
0005433616291	4967	Economy	6000.00
0005433616300	4967	Economy	6000.00
0005432106590	4967	Economy	6000.00
0005433616265	4967	Economy	6000.00
0005433785708	4967	Economy	6000.00
0005433616299	4967	Economy	6000.00
0005433616271	4967	Economy	6000.00
0005433616245	4967	Economy	6000.00
0005433785742	4967	Economy	6000.00
0005433616267	4967	Economy	6000.00
0005433785709	4967	Economy	6000.00
0005433616247	4967	Economy	6000.00
0005433785743	4967	Economy	6000.00
0005433616288	4967	Economy	6000.00
0005433616285	4967	Economy	6000.00
0005432106595	4967	Economy	6000.00
0005433785744	4967	Economy	6000.00
0005433616278	4967	Economy	6000.00
0005432106611	4967	Economy	6000.00
0005433785718	4967	Economy	6000.00
0005432666432	4967	Economy	6000.00
0005433616254	4967	Economy	6000.00
0005433616273	4967	Economy	6000.00
0005432106598	4967	Economy	6000.00
0005433785735	4967	Economy	6000.00
0005432106605	4967	Economy	6000.00
0005433616234	4967	Economy	6000.00
0005432106617	4967	Economy	6000.00
0005433616235	4967	Economy	6000.00
0005433616239	4967	Economy	6000.00
0005432106609	4967	Economy	6000.00
0005433616303	4967	Economy	6000.00
0005433616292	4967	Economy	6000.00
0005433616243	4967	Economy	6000.00
0005433616294	4967	Economy	6000.00
0005433785728	4967	Economy	6000.00
0005433616269	4967	Economy	6000.00
0005433616248	4967	Economy	6000.00
0005433616266	4967	Economy	6000.00
0005432145156	4967	Economy	6000.00
0005432106580	4967	Economy	6000.00
0005433785711	4967	Economy	6000.00
0005432106586	4967	Economy	6000.00
0005433616289	4967	Economy	6000.00
0005432106607	4967	Economy	6000.00
0005433616236	4967	Economy	6000.00
0005433785738	4967	Economy	6000.00
0005433616276	4967	Economy	6000.00
0005432106602	4967	Economy	6000.00
0005432106576	4967	Economy	6000.00
0005432106604	4967	Economy	6000.00
0005433785741	4967	Economy	6000.00
0005433785731	4967	Economy	6000.00
0005433785726	4967	Economy	6000.00
0005432106619	4967	Economy	6000.00
0005433616296	4967	Economy	6000.00
0005433616240	4967	Economy	6000.00
0005432106593	4967	Economy	6000.00
0005432106612	4967	Economy	6000.00
0005432106582	4967	Economy	6000.00
0005433616259	4967	Economy	6000.00
0005433616256	4967	Economy	6000.00
0005433616231	4967	Economy	6000.00
0005433785739	4967	Economy	6000.00
0005432106596	4967	Economy	6000.00
0005433616295	4967	Economy	6000.00
0005432106603	4967	Economy	6000.00
0005435007260	4965	Business	18000.00
0005435269850	4965	Business	18000.00
0005432336186	4965	Business	18000.00
0005435007332	4965	Business	18000.00
0005435007289	4965	Business	18000.00
0005434265702	4965	Business	18000.00
0005433685544	4965	Business	18000.00
0005435269836	4965	Business	18000.00
0005435007257	4965	Business	18000.00
0005434311241	4965	Business	18000.00
0005435269853	4965	Business	18000.00
0005434229852	4965	Business	18000.00
0005434229858	4965	Business	18000.00
0005434149985	4965	Business	18000.00
0005435269843	4965	Business	18000.00
0005434265691	4965	Business	18000.00
0005432336180	4965	Business	18000.00
0005434149987	4965	Business	18000.00
0005434312354	4965	Business	18000.00
0005435269841	4965	Business	18000.00
0005435269763	4965	Business	18000.00
0005434265698	4965	Business	18000.00
0005435007218	4965	Economy	6600.00
0005434229865	4965	Economy	6600.00
0005434265705	4965	Economy	6600.00
0005435269840	4965	Economy	6600.00
0005434265693	4965	Economy	6600.00
0005434149989	4965	Economy	6000.00
0005435269764	4965	Economy	6000.00
0005434311240	4965	Economy	6000.00
0005434265686	4965	Economy	6000.00
0005434265694	4965	Economy	6000.00
0005434265684	4965	Economy	6000.00
0005435007255	4965	Economy	6000.00
0005434265696	4965	Economy	6000.00
0005434149978	4965	Economy	6000.00
0005435007283	4965	Economy	6000.00
0005434265701	4965	Economy	6000.00
0005434265703	4965	Economy	6000.00
0005434229860	4965	Economy	6000.00
0005434265690	4965	Economy	6000.00
0005433685547	4965	Economy	6000.00
0005434149986	4965	Economy	6000.00
0005435007422	4965	Economy	6000.00
0005435007302	4965	Economy	6000.00
0005434173608	4965	Economy	6000.00
0005434229853	4965	Economy	6000.00
0005435007290	4965	Economy	6000.00
0005435007261	4965	Economy	6000.00
0005435007305	4965	Economy	6000.00
0005432336150	4965	Economy	6000.00
0005434149991	4965	Economy	6000.00
0005435007306	4965	Economy	6000.00
0005435007317	4965	Economy	6000.00
0005434265704	4965	Economy	6000.00
0005434229856	4965	Economy	6000.00
0005432336158	4965	Economy	6000.00
0005434265692	4965	Economy	6000.00
0005435269844	4965	Economy	6000.00
0005434149988	4965	Economy	6000.00
0005434229854	4965	Economy	6000.00
0005435007313	4965	Economy	6000.00
0005432336165	4965	Economy	6000.00
0005434311238	4965	Economy	6000.00
0005435007382	4965	Economy	6000.00
0005434149981	4965	Economy	6000.00
0005434265695	4965	Economy	6000.00
0005435007282	4965	Economy	6000.00
0005435007217	4965	Economy	6000.00
0005434149990	4965	Economy	6000.00
0005435007367	4965	Economy	6000.00
0005435269839	4965	Economy	6000.00
0005434229866	4965	Economy	6000.00
0005433688827	4965	Economy	6000.00
0005434173607	4965	Economy	6000.00
0005434149980	4965	Economy	6600.00
0005434229851	4965	Economy	6600.00
0005434265689	4965	Economy	6600.00
0005432336151	4965	Economy	6600.00
0005434311239	4965	Economy	6000.00
0005434265682	4965	Economy	6000.00
0005434173637	4965	Economy	6000.00
0005434265700	4965	Economy	6000.00
0005434265681	4965	Economy	6600.00
0005433688845	4965	Economy	6000.00
0005435007223	4965	Economy	6000.00
0005435007318	4965	Economy	6000.00
0005432336141	4965	Economy	6000.00
0005435269804	4965	Economy	6000.00
0005434229859	4965	Economy	6000.00
0005434229850	4965	Economy	6000.00
0005434229845	4965	Economy	6000.00
0005434229867	4965	Economy	6000.00
0005434229862	4965	Economy	6000.00
0005434149992	4965	Economy	6000.00
0005435007300	4965	Economy	6000.00
0005434265688	4965	Economy	6000.00
0005433815453	4965	Economy	6000.00
0005435269838	4965	Economy	6000.00
0005434229861	4965	Economy	6000.00
0005435269852	4965	Economy	6000.00
0005434149979	4965	Economy	6000.00
0005434265680	4965	Economy	6000.00
0005434265699	4965	Economy	6000.00
0005434173636	4965	Economy	6000.00
0005434229848	4965	Economy	6000.00
0005433685540	4965	Economy	6000.00
0005432336163	4965	Economy	6000.00
0005434265685	4965	Economy	6000.00
0005434312341	4965	Economy	6000.00
0005433815456	4965	Economy	6000.00
0005434229864	4965	Economy	6000.00
0005434149984	4965	Economy	6000.00
0005434229847	4965	Economy	6000.00
0005435269837	4965	Economy	6000.00
0005432336177	4965	Economy	6000.00
0005434229846	4965	Economy	6000.00
0005434229849	4965	Economy	6000.00
0005433685546	4965	Economy	6000.00
0005435007287	4965	Economy	6000.00
0005435007383	4965	Economy	6000.00
0005432336181	4965	Economy	6000.00
0005434229857	4965	Economy	6000.00
0005433688844	4965	Economy	6000.00
0005435007256	4965	Economy	6000.00
0005434229855	4965	Economy	6000.00
0005434265687	4965	Economy	6000.00
0005434149983	4965	Economy	6000.00
0005434265683	4965	Economy	6000.00
0005434229863	4965	Economy	6000.00
0005434149982	4965	Economy	6000.00
0005434265697	4965	Economy	6000.00
0005434173606	4965	Economy	6000.00
0005435007314	4965	Economy	6000.00
0005433785353	8535	Business	18000.00
0005433785429	8535	Business	18000.00
0005433785410	8535	Business	18000.00
0005435269944	8535	Business	18000.00
0005433785229	8535	Business	18000.00
0005433785250	8535	Business	18000.00
0005433785380	8535	Business	18000.00
0005434245289	8535	Business	18000.00
0005433785483	8535	Business	18000.00
0005433785324	8535	Business	18000.00
0005435269936	8535	Business	18000.00
0005433785342	8535	Business	18000.00
0005433785290	8535	Business	18000.00
0005435269929	8535	Business	18000.00
0005434245441	8535	Business	18000.00
0005433785431	8535	Business	18000.00
0005434245349	8535	Business	18000.00
0005434245566	8535	Economy	6600.00
0005435269943	8535	Economy	6600.00
0005434245409	8535	Economy	6000.00
0005435269937	8535	Economy	6000.00
0005434245402	8535	Economy	6000.00
0005433785312	8535	Economy	6000.00
0005434245486	8535	Economy	6000.00
0005435269933	8535	Economy	6000.00
0005433785428	8535	Economy	6000.00
0005435269939	8535	Economy	6000.00
0005433785386	8535	Economy	6000.00
0005433785306	8535	Economy	6000.00
0005434245408	8535	Economy	6000.00
0005434245394	8535	Economy	6000.00
0005434245504	8535	Economy	6000.00
0005433785509	8535	Economy	6000.00
0005433785358	8535	Economy	6000.00
0005433785423	8535	Economy	6000.00
0005434245505	8535	Economy	6000.00
0005433785402	8535	Economy	6000.00
0005434245327	8535	Economy	6000.00
0005435269938	8535	Economy	6000.00
0005434245279	8535	Economy	6000.00
0005433785430	8535	Economy	6000.00
0005434245405	8535	Economy	6000.00
0005435269932	8535	Economy	6000.00
0005435269945	8535	Economy	6000.00
0005433785447	8535	Economy	6000.00
0005433785487	8535	Economy	6000.00
0005432663054	8535	Economy	6000.00
0005434245487	8535	Economy	6000.00
0005433785322	8535	Economy	6000.00
0005433785381	8535	Economy	6600.00
0005433785449	8535	Economy	6600.00
0005435269942	8535	Economy	6600.00
0005433785387	8535	Economy	6600.00
0005435269928	8535	Economy	6000.00
0005433785340	8535	Economy	6000.00
0005434245412	8535	Economy	6600.00
0005435269927	8535	Economy	6000.00
0005434245338	8535	Economy	6000.00
0005433785424	8535	Economy	6000.00
0005434245290	8535	Economy	6000.00
0005434245491	8535	Economy	6000.00
0005434245308	8535	Economy	6000.00
0005433785589	8535	Economy	6000.00
0005433785243	8535	Economy	6000.00
0005433785347	8535	Economy	6000.00
0005434245410	8535	Economy	6000.00
0005433785388	8535	Economy	6000.00
0005434245378	8535	Economy	6000.00
0005435269934	8535	Economy	6000.00
0005434245330	8535	Economy	6000.00
0005433785341	8535	Economy	6000.00
0005435269946	8535	Economy	6000.00
0005433785349	8535	Economy	6000.00
0005434245333	8535	Economy	6000.00
0005434245379	8535	Economy	6000.00
0005434245403	8535	Economy	6000.00
0005433785348	8535	Economy	6000.00
0005435269940	8535	Economy	6000.00
0005433785242	8535	Economy	6000.00
0005433785228	8535	Economy	6000.00
0005435269930	8535	Economy	6000.00
0005433785493	8535	Economy	6000.00
0005435269941	8535	Economy	6000.00
0005433785448	8535	Economy	6000.00
0005434245348	8535	Economy	6000.00
0005433785426	8535	Economy	6000.00
0005432663052	8535	Economy	6000.00
0005435269935	8535	Economy	6000.00
0005434245472	8535	Economy	6000.00
0005433785486	8535	Economy	6000.00
0005433785305	8535	Economy	6000.00
0005435269931	8535	Economy	6000.00
0005433615320	8536	Business	18000.00
0005433615488	8536	Business	18000.00
0005433615489	8536	Business	18000.00
0005433615420	8536	Business	18000.00
0005433615662	8536	Business	18000.00
0005433615391	8536	Business	18000.00
0005433615601	8536	Business	18000.00
0005433615663	8536	Business	18000.00
0005433615623	8536	Business	18000.00
0005433615443	8536	Business	18000.00
0005433615505	8536	Business	18000.00
0005433615747	8536	Business	18000.00
0005433615670	8536	Business	18000.00
0005433615739	8536	Business	18000.00
0005433615472	8536	Business	18000.00
0005433615889	8536	Economy	6600.00
0005433615212	8536	Economy	6600.00
0005433615850	8536	Economy	6600.00
0005433615677	8536	Economy	6600.00
0005433615572	8536	Economy	6000.00
0005433615765	8536	Economy	6000.00
0005433615544	8536	Economy	6000.00
0005433615406	8536	Economy	6000.00
0005433615626	8536	Economy	6000.00
0005433615610	8536	Economy	6000.00
0005433615658	8536	Economy	6000.00
0005433615774	8536	Economy	6000.00
0005433615647	8536	Economy	6000.00
0005433615426	8536	Economy	6000.00
0005433615542	8536	Economy	6000.00
0005433615627	8536	Economy	6000.00
0005433615781	8536	Economy	6000.00
0005433615687	8536	Economy	6000.00
0005433615686	8536	Economy	6000.00
0005433615390	8536	Economy	6000.00
0005433615574	8536	Economy	6000.00
0005433615746	8536	Economy	6000.00
0005433615769	8536	Economy	6000.00
0005433615529	8536	Economy	6000.00
0005433615342	8536	Economy	6000.00
0005433615809	8536	Economy	6000.00
0005433615667	8536	Economy	6000.00
0005433615285	8536	Economy	6000.00
0005433615538	8536	Economy	6000.00
0005433615469	8536	Economy	6600.00
0005433615646	8536	Economy	6000.00
0005433615490	8536	Economy	6000.00
0005433615341	8536	Economy	6000.00
0005433615669	8536	Economy	6000.00
0005433615267	8536	Economy	6000.00
0005433615730	8536	Economy	6000.00
0005433615678	8536	Economy	6000.00
0005433615445	8536	Economy	6000.00
0005433615766	8536	Economy	6000.00
0005433615733	8536	Economy	6000.00
0005433615582	8536	Economy	6000.00
0005433615757	8536	Economy	6000.00
0005433615301	8536	Economy	6000.00
0005433615851	8536	Economy	6000.00
0005433615343	8536	Economy	6000.00
0005433615740	8536	Economy	6000.00
0005433615581	8536	Economy	6000.00
0005433615723	8536	Economy	6000.00
0005433615845	8536	Economy	6000.00
0005433615636	8536	Economy	6000.00
0005433615487	8536	Economy	6000.00
0005433615691	8536	Economy	6000.00
0005433615268	8536	Economy	6000.00
0005433615573	8536	Economy	6000.00
0005433615671	8536	Economy	6000.00
0005433615808	8536	Economy	6000.00
0005433615444	8536	Economy	6000.00
0005433615321	8536	Economy	6000.00
0005434229565	8537	Business	18000.00
0005434149871	8537	Business	18000.00
0005432336291	8537	Business	18000.00
0005434229665	8537	Business	18000.00
0005435007528	8537	Business	18000.00
0005434311262	8537	Business	18000.00
0005434149877	8537	Business	18000.00
0005434229779	8537	Business	18000.00
0005432336292	8537	Business	18000.00
0005433534545	8537	Business	18000.00
0005434265337	8537	Business	18000.00
0005435007537	8537	Business	18000.00
0005434265442	8537	Business	18000.00
0005433815489	8537	Business	18000.00
0005434265479	8537	Business	18000.00
0005433689957	8537	Business	18000.00
0005433689958	8537	Business	18000.00
0005432035537	8537	Business	18000.00
0005435007522	8537	Business	18000.00
0005432035549	8537	Business	18000.00
0005434229694	8537	Business	18000.00
0005434265502	8537	Business	18000.00
0005434265451	8537	Business	18000.00
0005434173576	8537	Business	18000.00
0005432035536	8537	Business	18000.00
0005432035544	8537	Business	18000.00
0005435007521	8537	Economy	6600.00
0005434229588	8537	Economy	6600.00
0005432035555	8537	Economy	6600.00
0005432336287	8537	Economy	6600.00
0005434149841	8537	Economy	6600.00
0005434265452	8537	Economy	6600.00
0005434149904	8537	Economy	6000.00
0005433689956	8537	Economy	6000.00
0005434149858	8537	Economy	6000.00
0005434265420	8537	Economy	6000.00
0005434149872	8537	Economy	6000.00
0005435007525	8537	Economy	6000.00
0005435007529	8537	Economy	6000.00
0005434149897	8537	Economy	6000.00
0005432035540	8537	Economy	6000.00
0005434229609	8537	Economy	6000.00
0005434265468	8537	Economy	6000.00
0005434265421	8537	Economy	6000.00
0005432035532	8537	Economy	6000.00
0005433815488	8537	Economy	6000.00
0005434229652	8537	Economy	6000.00
0005434149903	8537	Economy	6000.00
0005435007531	8537	Economy	6000.00
0005434311282	8537	Economy	6000.00
0005434265508	8537	Economy	6000.00
0005432035550	8537	Economy	6000.00
0005435007518	8537	Economy	6000.00
0005434149875	8537	Economy	6000.00
0005434229698	8537	Economy	6000.00
0005434311261	8537	Economy	6000.00
0005434265419	8537	Economy	6000.00
0005432035558	8537	Economy	6000.00
0005435007517	8537	Economy	6000.00
0005434265494	8537	Economy	6000.00
0005434265393	8537	Economy	6000.00
0005435007533	8537	Economy	6000.00
0005434265450	8537	Economy	6000.00
0005433688855	8537	Economy	6000.00
0005432035561	8537	Economy	6000.00
0005432336289	8537	Economy	6000.00
0005434265527	8537	Economy	6000.00
0005435007539	8537	Economy	6000.00
0005435007527	8537	Economy	6000.00
0005434229666	8537	Economy	6000.00
0005434149935	8537	Economy	6000.00
0005432047629	8537	Economy	6000.00
0005434229590	8537	Economy	6000.00
0005432035539	8537	Economy	6000.00
0005433815493	8537	Economy	6000.00
0005432035545	8537	Economy	6000.00
0005432035541	8537	Economy	6000.00
0005432035556	8537	Economy	6000.00
0005434265338	8537	Economy	6000.00
0005432047632	8537	Economy	6000.00
0005432035552	8537	Economy	6000.00
0005432035553	8537	Economy	6000.00
0005432336293	8537	Economy	6000.00
0005432336296	8537	Economy	6000.00
0005434265595	8537	Economy	6000.00
0005434229566	8537	Economy	6000.00
0005433534544	8537	Economy	6000.00
0005433815537	8537	Economy	6000.00
0005432035559	8537	Economy	6600.00
0005434311283	8537	Economy	6600.00
0005432035533	8537	Economy	6600.00
0005433815492	8537	Economy	6600.00
0005435007523	8537	Economy	6600.00
0005432035554	8537	Economy	6000.00
0005434149917	8537	Economy	6000.00
0005432035548	8537	Economy	6000.00
0005434149836	8537	Economy	6000.00
0005434229608	8537	Economy	6600.00
0005435007534	8537	Economy	6000.00
0005434149916	8537	Economy	6000.00
0005435007524	8537	Economy	6000.00
0005434149915	8537	Economy	6000.00
0005435007532	8537	Economy	6000.00
0005432035543	8537	Economy	6000.00
0005434173575	8537	Economy	6000.00
0005434149890	8537	Economy	6000.00
0005432336295	8537	Economy	6000.00
0005434229669	8537	Economy	6000.00
0005432035560	8537	Economy	6000.00
0005434265549	8537	Economy	6000.00
0005432035534	8537	Economy	6000.00
0005432035557	8537	Economy	6000.00
0005432035538	8537	Economy	6000.00
0005433815491	8537	Economy	6000.00
0005434265339	8537	Economy	6000.00
0005434265598	8537	Economy	6000.00
0005434265467	8537	Economy	6000.00
0005434229716	8537	Economy	6000.00
0005432336290	8537	Economy	6000.00
0005434229727	8537	Economy	6000.00
0005435007536	8537	Economy	6000.00
0005432035542	8537	Economy	6000.00
0005434229589	8537	Economy	6000.00
0005432336286	8537	Economy	6000.00
0005434229668	8537	Economy	6000.00
0005434265515	8537	Economy	6000.00
0005434265473	8537	Economy	6000.00
0005433688854	8537	Economy	6000.00
0005434149896	8537	Economy	6000.00
0005432035551	8537	Economy	6000.00
0005432035535	8537	Economy	6000.00
0005434173564	8537	Economy	6000.00
0005435007530	8537	Economy	6000.00
0005432047631	8537	Economy	6000.00
0005434229664	8537	Economy	6000.00
0005434265503	8537	Economy	6000.00
0005432336297	8537	Economy	6000.00
0005432035547	8537	Economy	6000.00
0005433690969	8537	Economy	6000.00
0005435007535	8537	Economy	6000.00
0005434229659	8537	Economy	6000.00
0005433815490	8537	Economy	6000.00
0005432035546	8537	Economy	6000.00
0005432336285	8537	Economy	6000.00
0005434229675	8537	Economy	6000.00
0005434229676	8537	Economy	6000.00
0005435007519	8537	Economy	6000.00
0005434173565	8537	Economy	6000.00
0005432047630	8537	Economy	6000.00
0005434149895	8537	Economy	6000.00
0005434229619	8537	Economy	6000.00
0005434265488	8537	Economy	6000.00
0005435007526	8537	Economy	6000.00
0005433690968	8537	Economy	6000.00
0005435007520	8537	Economy	6000.00
0005434265487	8537	Economy	6000.00
0005432336288	8537	Economy	6000.00
0005435007538	8537	Economy	6000.00
0005432336294	8537	Economy	6000.00
0005434265594	8537	Economy	6000.00
0005434265550	8537	Economy	6000.00
0005434265509	8537	Economy	6000.00
0005434639617	12585	Economy	16200.00
0005434639666	12585	Economy	16200.00
0005433202681	12585	Economy	16200.00
0005433202683	12585	Economy	16200.00
0005434639618	12585	Economy	14800.00
0005434639623	12585	Economy	14800.00
0005434639680	12585	Economy	14800.00
0005433202679	12585	Economy	14800.00
0005433202684	12585	Economy	14800.00
0005433202687	12585	Economy	14800.00
0005434639593	12585	Economy	14800.00
0005433202680	12585	Economy	14800.00
0005434639647	12585	Economy	14800.00
0005434639646	12585	Economy	14800.00
0005434639651	12585	Economy	14800.00
0005434639693	12585	Economy	14800.00
0005434639544	12585	Economy	14800.00
0005434639640	12585	Economy	14800.00
0005434639667	12585	Economy	14800.00
0005434639538	12585	Economy	14800.00
0005434639587	12585	Economy	14800.00
0005433202678	12585	Economy	14800.00
0005434639625	12585	Economy	14800.00
0005434639637	12585	Economy	14800.00
0005434639639	12585	Economy	14800.00
0005434639629	12585	Economy	14800.00
0005433202677	12585	Economy	14800.00
0005434639642	12585	Economy	14800.00
0005434639641	12585	Economy	14800.00
0005433202686	12585	Economy	14800.00
0005433202675	12585	Economy	14800.00
0005433202685	12585	Economy	14800.00
0005434639624	12585	Economy	14800.00
0005434639539	12585	Economy	14800.00
0005433202688	12585	Economy	14800.00
0005434639636	12585	Economy	14800.00
0005434639619	12585	Economy	14800.00
0005434639588	12585	Economy	14800.00
0005434639580	12585	Economy	14800.00
0005434639547	12585	Economy	14800.00
0005434639652	12585	Economy	14800.00
0005434639692	12585	Economy	14800.00
0005434639630	12585	Economy	14800.00
0005434639648	12585	Economy	14800.00
0005433202682	12585	Economy	14800.00
0005434639679	12585	Economy	14800.00
0005434639631	12585	Economy	14800.00
0005434639635	12585	Economy	14800.00
0005434639626	12585	Economy	14800.00
0005433202676	12585	Economy	14800.00
0005434639864	23347	Economy	16200.00
0005433202482	23347	Economy	16200.00
0005433202487	23347	Economy	16200.00
0005434639844	23347	Economy	16200.00
0005434639856	23347	Economy	14800.00
0005434639851	23347	Economy	14800.00
0005433202549	23347	Economy	14800.00
0005433202547	23347	Economy	14800.00
0005433202550	23347	Economy	14800.00
0005433202500	23347	Economy	14800.00
0005433202536	23347	Economy	14800.00
0005432290697	23347	Economy	14800.00
0005434639858	23347	Economy	14800.00
0005434639859	23347	Economy	14800.00
0005433202483	23347	Economy	14800.00
0005434639867	23347	Economy	14800.00
0005434639865	23347	Economy	14800.00
0005434639850	23347	Economy	14800.00
0005433202481	23347	Economy	14800.00
0005433202504	23347	Economy	14800.00
0005434639849	23347	Economy	14800.00
0005434639857	23347	Economy	14800.00
0005433202505	23347	Economy	14800.00
0005432290699	23347	Economy	14800.00
0005433202535	23347	Economy	14800.00
0005434639862	23347	Economy	14800.00
0005434639843	23347	Economy	14800.00
0005434639868	23347	Economy	14800.00
0005433202596	23347	Economy	14800.00
0005434639866	23347	Economy	14800.00
0005434639852	23347	Economy	14800.00
0005433202569	23347	Economy	14800.00
0005433202551	23347	Economy	14800.00
0005433202520	23347	Economy	14800.00
0005434639847	23347	Economy	14800.00
0005434639854	23347	Economy	14800.00
0005433202546	23347	Economy	14800.00
0005434639848	23347	Economy	14800.00
0005433202513	23347	Economy	14800.00
0005434639853	23347	Economy	14800.00
0005434639855	23347	Economy	14800.00
0005434639845	23347	Economy	14800.00
0005434639861	23347	Economy	14800.00
0005433202540	23347	Economy	14800.00
0005434639846	23347	Economy	14800.00
0005434639860	23347	Economy	14800.00
0005434639863	23347	Economy	14800.00
0005433202568	23347	Economy	14800.00
0005432290698	23347	Economy	14800.00
0005432383554	21072	Business	18900.00
0005432329243	21072	Business	18900.00
0005432383569	21072	Business	18900.00
0005432383622	21072	Business	18900.00
0005432329238	21072	Business	18900.00
0005432054369	21072	Business	18900.00
0005432329333	21072	Business	18900.00
0005432329386	21072	Business	18900.00
0005432329239	21072	Business	18900.00
0005432329440	21072	Business	18900.00
0005432383847	21072	Business	18900.00
0005432054367	21072	Business	18900.00
0005432383680	21072	Economy	6300.00
0005432848874	21072	Economy	6300.00
0005432329080	21072	Economy	6300.00
0005432329117	21072	Economy	6300.00
0005432383719	21072	Economy	6300.00
0005432329082	21072	Economy	6300.00
0005432329232	21072	Economy	6300.00
0005432329049	21072	Economy	6300.00
0005432329264	21072	Economy	6300.00
0005432054368	21072	Economy	6900.00
0005432329314	21072	Economy	6900.00
0005432383733	21072	Economy	6900.00
0005432329083	21072	Economy	6900.00
0005432383568	21072	Economy	6300.00
0005432383566	21072	Economy	6300.00
0005432383593	21072	Economy	6300.00
0005432329244	21072	Economy	6300.00
0005432383562	21072	Economy	6300.00
0005432383642	21072	Economy	6300.00
0005432329430	21072	Economy	6300.00
0005432383567	21072	Economy	6300.00
0005432848878	21072	Economy	6300.00
0005432383597	21072	Economy	6300.00
0005432848873	21072	Economy	6300.00
0005432383825	21072	Economy	6300.00
0005432383630	21072	Economy	6300.00
0005432848869	21072	Economy	6300.00
0005432383700	21072	Economy	6300.00
0005432383747	21072	Economy	6300.00
0005432329019	21072	Economy	6300.00
0005432329193	21072	Economy	6300.00
0005432383555	21072	Economy	6300.00
0005432329336	21072	Economy	6300.00
0005432329190	21072	Economy	6300.00
0005432383583	21072	Economy	6300.00
0005432383585	21072	Economy	6300.00
0005432848875	21072	Economy	6300.00
0005432329431	21072	Economy	6300.00
0005432329191	21072	Economy	6300.00
0005432383629	21072	Economy	6300.00
0005432383556	21072	Economy	6300.00
0005432848872	21072	Economy	6300.00
0005432329189	21072	Economy	6300.00
0005432329116	21072	Economy	6300.00
0005432328989	21072	Economy	6300.00
0005432329240	21072	Economy	6300.00
0005432383465	21072	Economy	6300.00
0005432383692	21072	Economy	6300.00
0005432383770	21072	Economy	6300.00
0005432383769	21072	Economy	6300.00
0005432383632	21072	Economy	6300.00
0005432383735	21072	Economy	6300.00
0005432329297	21072	Economy	6300.00
0005432329343	21072	Economy	6300.00
0005432329073	21072	Economy	6300.00
0005432329302	21072	Economy	6300.00
0005432848868	21072	Economy	6300.00
0005432383674	21072	Economy	6300.00
0005432329332	21072	Economy	6300.00
0005432329262	21072	Economy	6300.00
0005432383594	21072	Economy	6300.00
0005432848877	21072	Economy	6300.00
0005432383643	21072	Economy	6300.00
0005432383664	21072	Economy	6300.00
0005432848870	21072	Economy	6300.00
0005432848876	21072	Economy	6300.00
0005432848879	21072	Economy	6300.00
0005432383598	21072	Economy	6300.00
0005432383707	21072	Economy	6300.00
0005432329084	21072	Economy	6300.00
0005432383631	21072	Economy	6300.00
0005432329344	21072	Economy	6300.00
0005432383655	21072	Economy	6300.00
0005432383447	21072	Economy	6300.00
0005432383675	21072	Economy	6300.00
0005432329263	21072	Economy	6300.00
0005432329290	21072	Economy	6300.00
0005432383584	21072	Economy	6300.00
0005432848871	21072	Economy	6300.00
0005432329650	31222	Business	18900.00
0005432329643	31222	Business	18900.00
0005432329638	31222	Business	18900.00
0005432329637	31222	Business	18900.00
0005432383965	31222	Business	18900.00
0005432383987	31222	Business	18900.00
0005432329654	31222	Business	18900.00
0005432329640	31222	Business	18900.00
0005432329652	31222	Business	18900.00
0005432329630	31222	Economy	6300.00
0005432383995	31222	Economy	6300.00
0005432329648	31222	Economy	6300.00
0005432383991	31222	Economy	6300.00
0005432383968	31222	Economy	6300.00
0005432329635	31222	Economy	6300.00
0005432383967	31222	Economy	6300.00
0005432383960	31222	Economy	6300.00
0005432383975	31222	Economy	6300.00
0005432329656	31222	Economy	6300.00
0005432383957	31222	Economy	6900.00
0005432329662	31222	Economy	6900.00
0005432329653	31222	Economy	6900.00
0005432329667	31222	Economy	6300.00
0005432329647	31222	Economy	6300.00
0005432329629	31222	Economy	6300.00
0005432383983	31222	Economy	6300.00
0005432383958	31222	Economy	6300.00
0005432383981	31222	Economy	6300.00
0005432383956	31222	Economy	6300.00
0005432329636	31222	Economy	6300.00
0005432329628	31222	Economy	6300.00
0005432329672	31222	Economy	6300.00
0005432329668	31222	Economy	6300.00
0005432329633	31222	Economy	6300.00
0005432329644	31222	Economy	6300.00
0005432383994	31222	Economy	6300.00
0005432383976	31222	Economy	6300.00
0005432383972	31222	Economy	6300.00
0005432329659	31222	Economy	6300.00
0005432287296	31222	Economy	6300.00
0005432383962	31222	Economy	6300.00
0005432383988	31222	Economy	6300.00
0005432329665	31222	Economy	6300.00
0005432383964	31222	Economy	6300.00
0005432383989	31222	Economy	6300.00
0005432383978	31222	Economy	6300.00
0005432383979	31222	Economy	6300.00
0005432383990	31222	Economy	6300.00
0005432383977	31222	Economy	6300.00
0005432287295	31222	Economy	6300.00
0005432383970	31222	Economy	6300.00
0005432329645	31222	Economy	6300.00
0005432329658	31222	Economy	6300.00
0005432383969	31222	Economy	6300.00
0005432383966	31222	Economy	6300.00
0005432383982	31222	Economy	6300.00
0005432383971	31222	Economy	6300.00
0005432383980	31222	Economy	6300.00
0005432329660	31222	Economy	6300.00
0005432329663	31222	Economy	6300.00
0005432329673	31222	Economy	6300.00
0005432329664	31222	Economy	6300.00
0005432383985	31222	Economy	6300.00
0005432329666	31222	Economy	6300.00
0005432383984	31222	Economy	6300.00
0005432287297	31222	Economy	6300.00
0005432329632	31222	Economy	6300.00
0005432329642	31222	Economy	6300.00
0005432329649	31222	Economy	6300.00
0005432329661	31222	Economy	6300.00
0005432383992	31222	Economy	6300.00
0005432329657	31222	Economy	6300.00
0005432383963	31222	Economy	6300.00
0005432383993	31222	Economy	6300.00
0005432329631	31222	Economy	6300.00
0005432329671	31222	Economy	6300.00
0005432329669	31222	Economy	6300.00
0005432287294	31222	Economy	6300.00
0005432329651	31222	Economy	6300.00
0005432383973	31222	Economy	6300.00
0005432383961	31222	Economy	6300.00
0005432383974	31222	Economy	6300.00
0005432329655	31222	Economy	6300.00
0005432329674	31222	Economy	6300.00
0005432383986	31222	Economy	6300.00
0005432329646	31222	Economy	6300.00
0005432383959	31222	Economy	6300.00
0005432329641	31222	Economy	6300.00
0005432329670	31222	Economy	6300.00
0005432329634	31222	Economy	6300.00
0005432329639	31222	Economy	6300.00
0005432425448	13276	Business	12700.00
0005432425450	13276	Business	12700.00
0005432425471	13276	Business	12700.00
0005432425472	13276	Business	12700.00
0005432425446	13276	Business	12700.00
0005432425453	13276	Business	12700.00
0005432425467	13276	Economy	4200.00
0005432425469	13276	Economy	4200.00
0005432425475	13276	Economy	4200.00
0005432425455	13276	Economy	4200.00
0005432425430	13276	Economy	4200.00
0005432425465	13276	Economy	4700.00
0005432425437	13276	Economy	4700.00
0005432425444	13276	Economy	4700.00
0005432425443	13276	Economy	4700.00
0005432425429	13276	Economy	4700.00
0005432425477	13276	Economy	4200.00
0005432425463	13276	Economy	4200.00
0005432425454	13276	Economy	4200.00
0005432425432	13276	Economy	4200.00
0005432425458	13276	Economy	4200.00
0005432425434	13276	Economy	4200.00
0005432425457	13276	Economy	4200.00
0005432425459	13276	Economy	4200.00
0005432425473	13276	Economy	4200.00
0005432425427	13276	Economy	4200.00
0005432425452	13276	Economy	4200.00
0005432425431	13276	Economy	4200.00
0005432425449	13276	Economy	4200.00
0005432425462	13276	Economy	4200.00
0005432425435	13276	Economy	4200.00
0005432425447	13276	Economy	4200.00
0005432425456	13276	Economy	4200.00
0005432425442	13276	Economy	4200.00
0005432425468	13276	Economy	4200.00
0005432425460	13276	Economy	4200.00
0005432425436	13276	Economy	4200.00
0005432425474	13276	Economy	4200.00
0005432425451	13276	Economy	4200.00
0005432425461	13276	Economy	4200.00
0005432425428	13276	Economy	4200.00
0005432425439	13276	Economy	4200.00
0005432425470	13276	Economy	4200.00
0005432425445	13276	Economy	4200.00
0005432425464	13276	Economy	4200.00
0005432425433	13276	Economy	4200.00
0005432425476	13276	Economy	4200.00
0005432425441	13276	Economy	4200.00
0005432425466	13276	Economy	4200.00
0005432425438	13276	Economy	4200.00
0005432425440	13276	Economy	4200.00
0005432424923	30777	Business	12700.00
0005432425059	30777	Business	12700.00
0005432424946	30777	Business	12700.00
0005432424938	30777	Business	12700.00
0005432424919	30777	Business	12700.00
0005432424832	30777	Business	12700.00
0005432424922	30777	Economy	4200.00
0005432424975	30777	Economy	4200.00
0005432424980	30777	Economy	4200.00
0005432425028	30777	Economy	4200.00
0005432424934	30777	Economy	4200.00
0005432424965	30777	Economy	4200.00
0005432424867	30777	Economy	4200.00
0005432424981	30777	Economy	4700.00
0005432424925	30777	Economy	4700.00
0005432424990	30777	Economy	4700.00
0005432424831	30777	Economy	4200.00
0005432424935	30777	Economy	4200.00
0005432424963	30777	Economy	4200.00
0005432425069	30777	Economy	4200.00
0005432424973	30777	Economy	4200.00
0005432424924	30777	Economy	4200.00
0005432424866	30777	Economy	4200.00
0005432424984	30777	Economy	4200.00
0005432424929	30777	Economy	4200.00
0005432425051	30777	Economy	4200.00
0005432424996	30777	Economy	4200.00
0005432424951	30777	Economy	4200.00
0005432425009	30777	Economy	4200.00
0005432424937	30777	Economy	4200.00
0005432424864	30777	Economy	4200.00
0005432424962	30777	Economy	4200.00
0005432424757	30777	Economy	4200.00
0005432425039	30777	Economy	4200.00
0005432424988	30777	Economy	4200.00
0005432424983	30777	Economy	4200.00
0005432424997	30777	Economy	4200.00
0005432424894	30777	Economy	4200.00
0005432425050	30777	Economy	4200.00
0005432424865	30777	Economy	4200.00
0005432425037	30777	Economy	4200.00
0005432424928	30777	Economy	4200.00
0005432424995	30777	Economy	4200.00
0005432424970	30777	Economy	4200.00
0005432424974	30777	Economy	4200.00
0005432425015	30777	Economy	4200.00
0005432424756	30777	Economy	4200.00
0005432424868	30777	Economy	4200.00
0005432424945	30777	Economy	4200.00
0005432424964	30777	Economy	4200.00
0005432424994	30777	Economy	4200.00
0005434157600	9628	Business	32600.00
0005432822368	9628	Business	32600.00
0005432818118	9628	Business	32600.00
0005432822372	9628	Business	32600.00
0005432818119	9628	Business	32600.00
0005432818108	9628	Business	32600.00
0005432901796	9628	Business	32600.00
0005432818094	9628	Business	32600.00
0005432818113	9628	Business	32600.00
0005432818112	9628	Economy	10900.00
0005432818114	9628	Economy	10900.00
0005432822366	9628	Economy	10900.00
0005432818110	9628	Economy	10900.00
0005432901894	9628	Economy	10900.00
0005432818097	9628	Economy	10900.00
0005432822365	9628	Economy	10900.00
0005432818120	9628	Economy	11900.00
0005432818101	9628	Economy	11900.00
0005432818116	9628	Economy	11900.00
0005432818102	9628	Economy	10900.00
0005432818100	9628	Economy	10900.00
0005432822370	9628	Economy	10900.00
0005432818105	9628	Economy	10900.00
0005432901766	9628	Economy	10900.00
0005432901824	9628	Economy	10900.00
0005432818115	9628	Economy	10900.00
0005432818098	9628	Economy	10900.00
0005434157586	9628	Economy	10900.00
0005432901855	9628	Economy	10900.00
0005432818109	9628	Economy	10900.00
0005432901759	9628	Economy	10900.00
0005434157601	9628	Economy	10900.00
0005432822367	9628	Economy	10900.00
0005432818099	9628	Economy	10900.00
0005432901838	9628	Economy	10900.00
0005432818121	9628	Economy	10900.00
0005432818093	9628	Economy	10900.00
0005432818107	9628	Economy	10900.00
0005432818117	9628	Economy	10900.00
0005432818122	9628	Economy	10900.00
0005432822369	9628	Economy	10900.00
0005432901867	9628	Economy	10900.00
0005432818103	9628	Economy	10900.00
0005432901793	9628	Economy	10900.00
0005434157577	9628	Economy	10900.00
0005434448388	9628	Economy	10900.00
0005434157602	9628	Economy	10900.00
0005432901868	9628	Economy	10900.00
0005432289057	9628	Economy	10900.00
0005434448389	9628	Economy	10900.00
0005434157552	9628	Economy	10900.00
0005432901797	9628	Economy	10900.00
0005432818104	9628	Economy	10900.00
0005432901749	9628	Economy	10900.00
0005434448390	9628	Economy	10900.00
0005432822371	9628	Economy	10900.00
0005432901845	9628	Economy	10900.00
0005432901883	9628	Economy	10900.00
0005432901884	9628	Economy	10900.00
0005432901893	9628	Economy	10900.00
0005432818095	9628	Economy	10900.00
0005432818096	9628	Economy	10900.00
0005432818106	9628	Economy	10900.00
0005432901837	9628	Economy	10900.00
0005432818111	9628	Economy	10900.00
0005432901750	9628	Economy	10900.00
0005432289058	9628	Economy	10900.00
0005432901861	9628	Economy	10900.00
0005432822285	28971	Business	32600.00
0005432817935	28971	Business	32600.00
0005432901981	28971	Business	32600.00
0005432817938	28971	Business	32600.00
0005432817898	28971	Business	32600.00
0005432817868	28971	Business	32600.00
0005434157643	28971	Business	32600.00
0005434157650	28971	Business	32600.00
0005432817706	28971	Economy	10900.00
0005432822313	28971	Economy	10900.00
0005432901979	28971	Economy	10900.00
0005432817874	28971	Economy	10900.00
0005432002120	28971	Economy	10900.00
0005432817704	28971	Economy	11900.00
0005432901990	28971	Economy	11900.00
0005434448346	28971	Economy	11900.00
0005432817862	28971	Economy	10900.00
0005432817710	28971	Economy	10900.00
0005432901978	28971	Economy	10900.00
0005432817876	28971	Economy	10900.00
0005434157646	28971	Economy	10900.00
0005434186260	28971	Economy	10900.00
0005432817709	28971	Economy	10900.00
0005432901989	28971	Economy	10900.00
0005432901985	28971	Economy	10900.00
0005432822288	28971	Economy	10900.00
0005434157648	28971	Economy	10900.00
0005432817818	28971	Economy	10900.00
0005432901984	28971	Economy	10900.00
0005432817842	28971	Economy	10900.00
0005432817887	28971	Economy	10900.00
0005432817931	28971	Economy	10900.00
0005434448347	28971	Economy	10900.00
0005432817939	28971	Economy	10900.00
0005432901988	28971	Economy	10900.00
0005434157645	28971	Economy	10900.00
0005432901991	28971	Economy	10900.00
0005432901977	28971	Economy	10900.00
0005432901994	28971	Economy	10900.00
0005434186259	28971	Economy	10900.00
0005432002121	28971	Economy	10900.00
0005432901980	28971	Economy	10900.00
0005432817909	28971	Economy	10900.00
0005432822335	28971	Economy	10900.00
0005432822289	28971	Economy	10900.00
0005432817637	28971	Economy	10900.00
0005432002122	28971	Economy	10900.00
0005432817946	28971	Economy	10900.00
0005432901987	28971	Economy	10900.00
0005432817949	28971	Economy	10900.00
0005432817870	28971	Economy	10900.00
0005432817863	28971	Economy	10900.00
0005432901986	28971	Economy	10900.00
0005432817861	28971	Economy	10900.00
0005432817791	28971	Economy	10900.00
0005434448350	28971	Economy	10900.00
0005432822302	28971	Economy	10900.00
0005432901993	28971	Economy	10900.00
0005434157644	28971	Economy	10900.00
0005432901982	28971	Economy	10900.00
0005432817705	28971	Economy	10900.00
0005432817993	28971	Economy	10900.00
0005432901992	28971	Economy	10900.00
0005434157649	28971	Economy	10900.00
0005432901983	28971	Economy	10900.00
0005432817888	28971	Economy	10900.00
0005432817910	28971	Economy	10900.00
0005432817846	28971	Economy	10900.00
0005434157647	28971	Economy	10900.00
0005434157651	28971	Economy	10900.00
0005432822298	28971	Economy	10900.00
0005435841832	15107	Economy	11000.00
0005432611786	15107	Economy	11000.00
0005432611784	15107	Economy	11000.00
0005432611787	15107	Economy	11000.00
0005432613951	15107	Economy	11000.00
0005432611785	15107	Economy	11000.00
0005435841828	15107	Economy	11000.00
0005435841102	15107	Economy	11000.00
0005435841103	15107	Economy	11000.00
0005432613950	15107	Economy	11000.00
0005435841827	15107	Economy	11000.00
0005432613949	15107	Economy	11000.00
0005435842346	31625	Economy	11000.00
0005432607611	31625	Economy	11000.00
0005432611756	31625	Economy	11000.00
0005432611753	31625	Economy	11000.00
0005432607610	31625	Economy	11000.00
0005435841841	31625	Economy	11000.00
0005432611755	31625	Economy	11000.00
0005432611757	31625	Economy	11000.00
0005435841840	31625	Economy	11000.00
0005432611754	31625	Economy	11000.00
0005435842345	31625	Economy	11000.00
0005432948969	11875	Business	105900.00
0005432948977	11875	Business	105900.00
0005433570319	11875	Business	105900.00
0005433570297	11875	Business	105900.00
0005433570296	11875	Business	105900.00
0005433570348	11875	Business	105900.00
0005432948879	11875	Business	105900.00
0005433570325	11875	Business	105900.00
0005433570333	11875	Business	105900.00
0005432948970	11875	Business	105900.00
0005433570322	11875	Business	105900.00
0005432948678	11875	Business	105900.00
0005433570345	11875	Business	105900.00
0005432948828	11875	Business	105900.00
0005433570314	11875	Business	105900.00
0005432948881	11875	Business	105900.00
0005433570327	11875	Business	105900.00
0005433570358	11875	Business	105900.00
0005432948976	11875	Business	105900.00
0005432949040	11875	Economy	35300.00
0005432948910	11875	Economy	35300.00
0005433570331	11875	Economy	35300.00
0005433570311	11875	Economy	35300.00
0005433570349	11875	Economy	35300.00
0005433570323	11875	Economy	35300.00
0005432949045	11875	Economy	35300.00
0005433570293	11875	Economy	35300.00
0005433570294	11875	Economy	35300.00
0005433570310	11875	Economy	35300.00
0005433570356	11875	Economy	35300.00
0005433570324	11875	Economy	35300.00
0005433570340	11875	Economy	35300.00
0005432949091	11875	Economy	38800.00
0005432948812	11875	Economy	38800.00
0005433570320	11875	Economy	38800.00
0005432948985	11875	Economy	38800.00
0005433570338	11875	Economy	35300.00
0005433570336	11875	Economy	35300.00
0005432948995	11875	Economy	35300.00
0005433570328	11875	Economy	35300.00
0005432948855	11875	Economy	35300.00
0005433570295	11875	Economy	35300.00
0005433570292	11875	Economy	35300.00
0005433570351	11875	Economy	35300.00
0005433570359	11875	Economy	35300.00
0005433570334	11875	Economy	35300.00
0005433570355	11875	Economy	35300.00
0005432949024	11875	Economy	35300.00
0005433570304	11875	Economy	35300.00
0005432948943	11875	Economy	35300.00
0005432949043	11875	Economy	35300.00
0005433570350	11875	Economy	35300.00
0005433570305	11875	Economy	35300.00
0005432949094	11875	Economy	35300.00
0005432948938	11875	Economy	35300.00
0005433570341	11875	Economy	35300.00
0005432948868	11875	Economy	35300.00
0005432948937	11875	Economy	35300.00
0005432949025	11875	Economy	35300.00
0005432949000	11875	Economy	35300.00
0005432948872	11875	Economy	35300.00
0005432949006	11875	Economy	35300.00
0005433570339	11875	Economy	35300.00
0005432948846	11875	Economy	35300.00
0005433570335	11875	Economy	35300.00
0005432948981	11875	Economy	35300.00
0005433570317	11875	Economy	35300.00
0005433570299	11875	Economy	35300.00
0005433570342	11875	Economy	35300.00
0005433570300	11875	Economy	35300.00
0005433570298	11875	Economy	35300.00
0005432948880	11875	Economy	35300.00
0005433570312	11875	Economy	35300.00
0005433570309	11875	Economy	35300.00
0005433570315	11875	Economy	35300.00
0005432948958	11875	Economy	35300.00
0005433570330	11875	Economy	35300.00
0005432948931	11875	Economy	35300.00
0005432948983	11875	Economy	35300.00
0005433570326	11875	Economy	35300.00
0005433570301	11875	Economy	35300.00
0005432948882	11875	Economy	35300.00
0005433570337	11875	Economy	35300.00
0005433570313	11875	Economy	35300.00
0005432949041	11875	Economy	35300.00
0005432948677	11875	Economy	35300.00
0005433570306	11875	Economy	35300.00
0005432948999	11875	Economy	35300.00
0005433570344	11875	Economy	35300.00
0005432949042	11875	Economy	35300.00
0005432948986	11875	Economy	35300.00
0005433570352	11875	Economy	35300.00
0005433570353	11875	Economy	35300.00
0005433570347	11875	Economy	35300.00
0005433570291	11875	Economy	35300.00
0005432949092	11875	Economy	35300.00
0005433570321	11875	Economy	35300.00
0005433570302	11875	Economy	35300.00
0005433570357	11875	Economy	35300.00
0005433570316	11875	Economy	35300.00
0005433570332	11875	Economy	35300.00
0005433570318	11875	Economy	35300.00
0005432949005	11875	Economy	35300.00
0005433570308	11875	Economy	35300.00
0005433570346	11875	Economy	35300.00
0005433570354	11875	Economy	35300.00
0005433570361	11875	Economy	35300.00
0005433570329	11875	Economy	35300.00
0005432948984	11875	Economy	35300.00
0005433570360	11875	Economy	35300.00
0005433570343	11875	Economy	35300.00
0005433570307	11875	Economy	35300.00
0005433570303	11875	Economy	35300.00
0005432948941	11875	Economy	35300.00
0005432948919	11875	Economy	35300.00
0005433569822	25288	Business	105900.00
0005432949374	25288	Business	105900.00
0005432949355	25288	Business	105900.00
0005433569888	25288	Business	105900.00
0005433569732	25288	Business	105900.00
0005432949360	25288	Business	105900.00
0005432949361	25288	Business	105900.00
0005433569588	25288	Business	105900.00
0005432949388	25288	Business	105900.00
0005433569711	25288	Business	105900.00
0005433569863	25288	Business	105900.00
0005432949362	25288	Business	105900.00
0005433569497	25288	Business	105900.00
0005432949373	25288	Business	105900.00
0005432949375	25288	Business	105900.00
0005432949364	25288	Business	105900.00
0005433569496	25288	Business	105900.00
0005432949354	25288	Economy	35300.00
0005432949378	25288	Economy	35300.00
0005432949359	25288	Economy	35300.00
0005433569802	25288	Economy	35300.00
0005433569701	25288	Economy	35300.00
0005432949369	25288	Economy	35300.00
0005433569602	25288	Economy	35300.00
0005432949389	25288	Economy	35300.00
0005433569517	25288	Economy	35300.00
0005432949386	25288	Economy	35300.00
0005433569814	25288	Economy	35300.00
0005432949357	25288	Economy	35300.00
0005433569730	25288	Economy	35300.00
0005433569549	25288	Economy	38800.00
0005433569817	25288	Economy	38800.00
0005433569679	25288	Economy	38800.00
0005433569766	25288	Economy	38800.00
0005432949383	25288	Economy	35300.00
0005432949352	25288	Economy	35300.00
0005433569769	25288	Economy	35300.00
0005433569686	25288	Economy	35300.00
0005433569803	25288	Economy	35300.00
0005433569689	25288	Economy	35300.00
0005433569662	25288	Economy	35300.00
0005433569703	25288	Economy	35300.00
0005432949384	25288	Economy	35300.00
0005433569523	25288	Economy	35300.00
0005433569698	25288	Economy	35300.00
0005433569849	25288	Economy	35300.00
0005433569745	25288	Economy	35300.00
0005432949385	25288	Economy	35300.00
0005433569804	25288	Economy	35300.00
0005433569839	25288	Economy	35300.00
0005432949372	25288	Economy	35300.00
0005433569748	25288	Economy	35300.00
0005432949358	25288	Economy	35300.00
0005433569715	25288	Economy	35300.00
0005433569630	25288	Economy	35300.00
0005432949380	25288	Economy	35300.00
0005433569592	25288	Economy	35300.00
0005433569687	25288	Economy	35300.00
0005432949356	25288	Economy	35300.00
0005432949349	25288	Economy	35300.00
0005433569875	25288	Economy	35300.00
0005432949387	25288	Economy	35300.00
0005433569489	25288	Economy	35300.00
0005433569677	25288	Economy	35300.00
0005433569874	25288	Economy	35300.00
0005432949366	25288	Economy	35300.00
0005433569744	25288	Economy	35300.00
0005432949371	25288	Economy	35300.00
0005433569768	25288	Economy	35300.00
0005433569688	25288	Economy	35300.00
0005433569747	25288	Economy	35300.00
0005433569704	25288	Economy	35300.00
0005433569733	25288	Economy	35300.00
0005433569590	25288	Economy	35300.00
0005433569774	25288	Economy	35300.00
0005432949368	25288	Economy	35300.00
0005433569816	25288	Economy	35300.00
0005432949363	25288	Economy	35300.00
0005433569587	25288	Economy	35300.00
0005433569591	25288	Economy	35300.00
0005433569879	25288	Economy	35300.00
0005432949370	25288	Economy	35300.00
0005433569770	25288	Economy	35300.00
0005433569840	25288	Economy	35300.00
0005433569731	25288	Economy	35300.00
0005433569828	25288	Economy	35300.00
0005433569838	25288	Economy	35300.00
0005432949382	25288	Economy	35300.00
0005433569848	25288	Economy	35300.00
0005432949377	25288	Economy	35300.00
0005433569700	25288	Economy	35300.00
0005432949367	25288	Economy	35300.00
0005432949365	25288	Economy	35300.00
0005432949351	25288	Economy	35300.00
0005432949350	25288	Economy	35300.00
0005432949381	25288	Economy	35300.00
0005432949376	25288	Economy	35300.00
0005432949353	25288	Economy	35300.00
0005432949379	25288	Economy	35300.00
0005432430906	30821	Business	117400.00
0005434026736	30821	Business	117400.00
0005434026720	30821	Business	117400.00
0005433808459	30821	Business	117400.00
0005433808450	30821	Business	117400.00
0005433812945	30821	Business	117400.00
0005433812946	30821	Business	117400.00
0005433808452	30821	Business	117400.00
0005434026725	30821	Business	117400.00
0005432430890	30821	Business	117400.00
0005432430898	30821	Economy	39100.00
0005432430913	30821	Economy	39100.00
0005434026728	30821	Economy	39100.00
0005432430886	30821	Economy	39100.00
0005432430921	30821	Economy	39100.00
0005432430917	30821	Economy	39100.00
0005433808458	30821	Economy	39100.00
0005432430922	30821	Economy	43000.00
0005432430900	30821	Economy	39100.00
0005433808460	30821	Economy	39100.00
0005434026731	30821	Economy	39100.00
0005433808457	30821	Economy	39100.00
0005433812950	30821	Economy	39100.00
0005434026721	30821	Economy	39100.00
0005433808455	30821	Economy	39100.00
0005433812947	30821	Economy	39100.00
0005434026719	30821	Economy	39100.00
0005433808454	30821	Economy	39100.00
0005432430920	30821	Economy	39100.00
0005433812949	30821	Economy	39100.00
0005434026717	30821	Economy	39100.00
0005433812951	30821	Economy	39100.00
0005432430908	30821	Economy	39100.00
0005433808451	30821	Economy	39100.00
0005432430907	30821	Economy	39100.00
0005432430914	30821	Economy	39100.00
0005433812944	30821	Economy	39100.00
0005434026718	30821	Economy	39100.00
0005434026727	30821	Economy	39100.00
0005433808453	30821	Economy	39100.00
0005433808456	30821	Economy	39100.00
0005433812948	30821	Economy	39100.00
0005434026735	30821	Economy	39100.00
0005432114271	5366	Business	67200.00
0005432114272	5366	Business	67200.00
0005434655296	5366	Business	67200.00
0005434655309	5366	Business	67200.00
0005435340476	5366	Business	67200.00
0005434655313	5366	Economy	22400.00
0005435340451	5366	Economy	22400.00
0005434655311	5366	Economy	22400.00
0005434655303	5366	Economy	22400.00
0005434655315	5366	Economy	22400.00
0005434656598	5366	Economy	22400.00
0005434655310	5366	Economy	22400.00
0005434655297	5366	Economy	22400.00
0005434655318	5366	Economy	24600.00
0005434655305	5366	Economy	24600.00
0005434655314	5366	Economy	24600.00
0005435340454	5366	Economy	22400.00
0005434655302	5366	Economy	22400.00
0005435340507	5366	Economy	22400.00
0005435340475	5366	Economy	22400.00
0005434655300	5366	Economy	22400.00
0005434655321	5366	Economy	22400.00
0005435340442	5366	Economy	22400.00
0005434655316	5366	Economy	22400.00
0005435340357	5366	Economy	22400.00
0005435340428	5366	Economy	22400.00
0005434655322	5366	Economy	22400.00
0005435555400	5366	Economy	22400.00
0005435340477	5366	Economy	22400.00
0005435340455	5366	Economy	22400.00
0005434655304	5366	Economy	22400.00
0005434655306	5366	Economy	22400.00
0005435555399	5366	Economy	22400.00
0005434655307	5366	Economy	22400.00
0005434655299	5366	Economy	22400.00
0005435555397	5366	Economy	22400.00
0005435340497	5366	Economy	22400.00
0005434655320	5366	Economy	22400.00
0005434655319	5366	Economy	22400.00
0005432114273	5366	Economy	22400.00
0005434655323	5366	Economy	22400.00
0005434655312	5366	Economy	22400.00
0005434655324	5366	Economy	22400.00
0005434655308	5366	Economy	22400.00
0005434655301	5366	Economy	22400.00
0005434656599	5366	Economy	22400.00
0005435340356	5366	Economy	22400.00
0005435340450	5366	Economy	22400.00
0005435555398	5366	Economy	22400.00
0005434655317	5366	Economy	22400.00
0005435340449	5366	Economy	22400.00
0005434655298	5366	Economy	22400.00
0005435340583	12520	Business	67200.00
0005434655036	12520	Business	67200.00
0005434654891	12520	Business	67200.00
0005434656588	12520	Business	67200.00
0005434654994	12520	Business	67200.00
0005434654989	12520	Business	67200.00
0005435340596	12520	Business	67200.00
0005434655002	12520	Economy	22400.00
0005434655067	12520	Economy	22400.00
0005435340594	12520	Economy	22400.00
0005434655116	12520	Economy	22400.00
0005435340595	12520	Economy	22400.00
0005434654892	12520	Economy	22400.00
0005434655007	12520	Economy	22400.00
0005434654971	12520	Economy	22400.00
0005434655003	12520	Economy	24600.00
0005434655076	12520	Economy	24600.00
0005434655037	12520	Economy	24600.00
0005434655045	12520	Economy	24600.00
0005434655174	12520	Economy	22400.00
0005435340587	12520	Economy	22400.00
0005435340586	12520	Economy	22400.00
0005434656583	12520	Economy	22400.00
0005435340584	12520	Economy	22400.00
0005434655013	12520	Economy	22400.00
0005434655117	12520	Economy	22400.00
0005434655032	12520	Economy	22400.00
0005434655128	12520	Economy	22400.00
0005435340590	12520	Economy	22400.00
0005434654963	12520	Economy	22400.00
0005435340592	12520	Economy	22400.00
0005434654972	12520	Economy	22400.00
0005434654914	12520	Economy	22400.00
0005434655012	12520	Economy	22400.00
0005434655118	12520	Economy	22400.00
0005435340588	12520	Economy	22400.00
0005435340582	12520	Economy	22400.00
0005434655056	12520	Economy	22400.00
0005434654999	12520	Economy	22400.00
0005435340591	12520	Economy	22400.00
0005434656578	12520	Economy	22400.00
0005434655069	12520	Economy	22400.00
0005434655000	12520	Economy	22400.00
0005434655129	12520	Economy	22400.00
0005434654978	12520	Economy	22400.00
0005434654925	12520	Economy	22400.00
0005434655062	12520	Economy	22400.00
0005434655068	12520	Economy	22400.00
0005434654926	12520	Economy	22400.00
0005434654973	12520	Economy	22400.00
0005435340585	12520	Economy	22400.00
0005435555415	12520	Economy	22400.00
0005435340589	12520	Economy	22400.00
0005434654913	12520	Economy	22400.00
0005434654998	12520	Economy	22400.00
0005434655001	12520	Economy	22400.00
0005434655011	12520	Economy	22400.00
0005434654993	12520	Economy	22400.00
0005434655006	12520	Economy	22400.00
0005435340593	12520	Economy	22400.00
0005433688851	7429	Business	32000.00
0005433717034	7429	Business	32000.00
0005433690966	7429	Business	32000.00
0005432078228	7429	Business	32000.00
0005433722353	7429	Business	32000.00
0005433656740	7429	Economy	10700.00
0005433717018	7429	Economy	10700.00
0005433717016	7429	Economy	10700.00
0005433717023	7429	Economy	10700.00
0005433717012	7429	Economy	10700.00
0005433717049	7429	Economy	10700.00
0005433688852	7429	Economy	10700.00
0005433717029	7429	Economy	10700.00
0005433717017	7429	Economy	10700.00
0005432428963	7429	Economy	10700.00
0005433722354	7429	Economy	10700.00
0005433717053	7429	Economy	10700.00
0005433656742	7429	Economy	10700.00
0005433717030	7429	Economy	10700.00
0005433717027	7429	Economy	10700.00
0005433717014	7429	Economy	10700.00
0005433717046	7429	Economy	10700.00
0005433717038	7429	Economy	10700.00
0005432078225	7429	Economy	10700.00
0005433717058	7429	Economy	10700.00
0005433722352	7429	Economy	10700.00
0005433719211	7429	Economy	10700.00
0005432078226	7429	Economy	10700.00
0005432078229	7429	Economy	10700.00
0005433717040	7429	Economy	10700.00
0005433717019	7429	Economy	11700.00
0005433717020	7429	Economy	11700.00
0005433717033	7429	Economy	11700.00
0005433688853	7429	Economy	10700.00
0005433717059	7429	Economy	10700.00
0005433717056	7429	Economy	10700.00
0005433717050	7429	Economy	10700.00
0005433717013	7429	Economy	10700.00
0005433717011	7429	Economy	10700.00
0005433717035	7429	Economy	10700.00
0005433717055	7429	Economy	10700.00
0005433719210	7429	Economy	10700.00
0005433717048	7429	Economy	10700.00
0005433690967	7429	Economy	10700.00
0005433717057	7429	Economy	10700.00
0005433656739	7429	Economy	10700.00
0005433689955	7429	Economy	10700.00
0005433717024	7429	Economy	10700.00
0005433717037	7429	Economy	10700.00
0005433717039	7429	Economy	10700.00
0005433717022	7429	Economy	10700.00
0005433717047	7429	Economy	10700.00
0005433717044	7429	Economy	10700.00
0005433717031	7429	Economy	10700.00
0005433717028	7429	Economy	10700.00
0005433717036	7429	Economy	10700.00
0005433722355	7429	Economy	10700.00
0005435266197	7429	Economy	10700.00
0005433717051	7429	Economy	10700.00
0005433717061	7429	Economy	10700.00
0005433717043	7429	Economy	10700.00
0005433656743	7429	Economy	10700.00
0005433717021	7429	Economy	10700.00
0005433719212	7429	Economy	10700.00
0005433717052	7429	Economy	10700.00
0005433717054	7429	Economy	10700.00
0005433717060	7429	Economy	10700.00
0005433689954	7429	Economy	10700.00
0005433717026	7429	Economy	10700.00
0005433717042	7429	Economy	10700.00
0005435266196	7429	Economy	10700.00
0005432078227	7429	Economy	10700.00
0005433656741	7429	Economy	10700.00
0005433717045	7429	Economy	10700.00
0005432078224	7429	Economy	10700.00
0005433717025	7429	Economy	10700.00
0005433717015	7429	Economy	10700.00
0005433717032	7429	Economy	10700.00
0005432428972	7429	Economy	10700.00
0005433717041	7429	Economy	10700.00
0005433716633	29212	Business	32000.00
0005433716620	29212	Business	32000.00
0005433716439	29212	Business	32000.00
0005433716469	29212	Business	32000.00
0005433716460	29212	Business	32000.00
0005432006825	29212	Business	32000.00
0005435266269	29212	Economy	10700.00
0005435266266	29212	Economy	10700.00
0005433716688	29212	Economy	10700.00
0005433716508	29212	Economy	10700.00
0005433716578	29212	Economy	10700.00
0005433716481	29212	Economy	10700.00
0005433656729	29212	Economy	10700.00
0005433716695	29212	Economy	10700.00
0005435266271	29212	Economy	10700.00
0005433716689	29212	Economy	10700.00
0005433716649	29212	Economy	10700.00
0005433716685	29212	Economy	10700.00
0005433716539	29212	Economy	10700.00
0005435266268	29212	Economy	10700.00
0005435266272	29212	Economy	10700.00
0005433685547	29212	Economy	10700.00
0005432429002	29212	Economy	10700.00
0005435266270	29212	Economy	10700.00
0005433716522	29212	Economy	10700.00
0005433656721	29212	Economy	10700.00
0005433716750	29212	Economy	10700.00
0005433716564	29212	Economy	10700.00
0005433688827	29212	Economy	10700.00
0005432429003	29212	Economy	10700.00
0005433716684	29212	Economy	10700.00
0005433716806	29212	Economy	10700.00
0005433716413	29212	Economy	10700.00
0005433716602	29212	Economy	10700.00
0005433716579	29212	Economy	10700.00
0005433716447	29212	Economy	10700.00
0005433716677	29212	Economy	11700.00
0005433716418	29212	Economy	11700.00
0005435266275	29212	Economy	11700.00
0005433716706	29212	Economy	11700.00
0005432006823	29212	Economy	11700.00
0005433716417	29212	Economy	10700.00
0005435266267	29212	Economy	10700.00
0005433716804	29212	Economy	10700.00
0005433716701	29212	Economy	10700.00
0005433716807	29212	Economy	10700.00
0005433716653	29212	Economy	10700.00
0005433685540	29212	Economy	10700.00
0005433716509	29212	Economy	10700.00
0005433716454	29212	Economy	10700.00
0005433716671	29212	Economy	10700.00
0005433719180	29212	Economy	10700.00
0005433716606	29212	Economy	10700.00
0005433716644	29212	Economy	10700.00
0005433688845	29212	Economy	10700.00
0005433716471	29212	Economy	10700.00
0005433716419	29212	Economy	10700.00
0005433716782	29212	Economy	10700.00
0005433716538	29212	Economy	10700.00
0005433716436	29212	Economy	10700.00
0005435266273	29212	Economy	10700.00
0005433716676	29212	Economy	10700.00
0005433688844	29212	Economy	10700.00
0005433685544	29212	Economy	10700.00
0005433716345	29212	Economy	10700.00
0005433716645	29212	Economy	10700.00
0005433716412	29212	Economy	10700.00
0005433716654	29212	Economy	10700.00
0005433716623	29212	Economy	10700.00
0005433685546	29212	Economy	10700.00
0005435266277	29212	Economy	10700.00
0005433716480	29212	Economy	10700.00
0005435266276	29212	Economy	10700.00
0005433716628	29212	Economy	10700.00
0005433716503	29212	Economy	10700.00
0005433716942	29212	Economy	10700.00
0005433716832	29212	Economy	10700.00
0005433716531	29212	Economy	10700.00
0005433719181	29212	Economy	10700.00
0005433716523	29212	Economy	10700.00
0005433716514	29212	Economy	10700.00
0005433716627	29212	Economy	10700.00
0005433716559	29212	Economy	10700.00
0005435266274	29212	Economy	10700.00
0005433656720	29212	Economy	10700.00
0005433716673	29212	Economy	10700.00
0005433716783	29212	Economy	10700.00
0005433716622	29212	Economy	10700.00
0005432006824	29212	Economy	10700.00
0005434095586	8685	Business	36500.00
0005434095580	8685	Business	36500.00
0005434182355	8685	Economy	12200.00
0005434143751	8685	Economy	12200.00
0005434095581	8685	Economy	12200.00
0005434095592	8685	Economy	12200.00
0005434095587	8685	Economy	12200.00
0005434095590	8685	Economy	12200.00
0005434095584	8685	Economy	12200.00
0005434095588	8685	Economy	12200.00
0005434095579	8685	Economy	12200.00
0005434184686	8685	Economy	12200.00
0005434095582	8685	Economy	12200.00
0005434182289	8685	Economy	12200.00
0005434095583	8685	Economy	12200.00
0005434182288	8685	Economy	12200.00
0005434095591	8685	Economy	12200.00
0005434095585	8685	Economy	12200.00
0005434182386	8685	Economy	12200.00
0005434143752	8685	Economy	12200.00
0005434184687	8685	Economy	12200.00
0005434182415	8685	Economy	12200.00
0005434095578	8685	Economy	12200.00
0005434182405	8685	Economy	12200.00
0005434182338	8685	Economy	12200.00
0005434182372	8685	Economy	12200.00
0005434095589	8685	Economy	12200.00
0005434182458	11644	Business	36500.00
0005434182460	11644	Business	36500.00
0005434183623	11644	Business	36500.00
0005434095468	11644	Business	36500.00
0005434095453	11644	Economy	12200.00
0005434183622	11644	Economy	13400.00
0005434182447	11644	Economy	12200.00
0005434182454	11644	Economy	12200.00
0005434184708	11644	Economy	12200.00
0005434182450	11644	Economy	12200.00
0005434182457	11644	Economy	12200.00
0005434095465	11644	Economy	12200.00
0005434184707	11644	Economy	12200.00
0005434095429	11644	Economy	12200.00
0005434184706	11644	Economy	12200.00
0005434095487	11644	Economy	12200.00
0005434095486	11644	Economy	12200.00
0005434182452	11644	Economy	12200.00
0005434095492	11644	Economy	12200.00
0005434183621	11644	Economy	12200.00
0005434182448	11644	Economy	12200.00
0005434182456	11644	Economy	12200.00
0005434182459	11644	Economy	12200.00
0005434182451	11644	Economy	12200.00
0005434182449	11644	Economy	12200.00
0005434182453	11644	Economy	12200.00
0005434095515	11644	Economy	12200.00
0005434182455	11644	Economy	12200.00
0005433398728	1455	Business	33000.00
0005433457057	1455	Business	33000.00
0005433398590	1455	Business	33000.00
0005433398540	1455	Business	33000.00
0005433398580	1455	Business	33000.00
0005433398624	1455	Business	33000.00
0005433398790	1455	Business	33000.00
0005433398537	1455	Business	33000.00
0005433398519	1455	Business	33000.00
0005433398667	1455	Economy	11000.00
0005433398494	1455	Economy	11000.00
0005433398736	1455	Economy	11000.00
0005433398729	1455	Economy	11000.00
0005433398581	1455	Economy	11000.00
0005433398631	1455	Economy	11000.00
0005432906567	1455	Economy	11000.00
0005433398822	1455	Economy	12100.00
0005433398421	1455	Economy	12100.00
0005433398658	1455	Economy	12100.00
0005433398629	1455	Economy	12100.00
0005433398715	1455	Economy	11000.00
0005432906564	1455	Economy	11000.00
0005433398565	1455	Economy	11000.00
0005433398635	1455	Economy	11000.00
0005432906561	1455	Economy	11000.00
0005433398671	1455	Economy	11000.00
0005432906560	1455	Economy	11000.00
0005433398769	1455	Economy	11000.00
0005433398503	1455	Economy	11000.00
0005433398539	1455	Economy	11000.00
0005433398657	1455	Economy	11000.00
0005433398690	1455	Economy	11000.00
0005433398469	1455	Economy	11000.00
0005433398630	1455	Economy	11000.00
0005433398839	1455	Economy	11000.00
0005433398863	1455	Economy	11000.00
0005433398538	1455	Economy	11000.00
0005433398689	1455	Economy	11000.00
0005432297334	1455	Economy	11000.00
0005433398672	1455	Economy	11000.00
0005433398598	1455	Economy	11000.00
0005433398536	1455	Economy	11000.00
0005433457054	1455	Economy	11000.00
0005433398750	1455	Economy	11000.00
0005433398626	1455	Economy	11000.00
0005433398623	1455	Economy	11000.00
0005433398530	1455	Economy	11000.00
0005433398611	1455	Economy	11000.00
0005433398815	1455	Economy	11000.00
0005433398798	1455	Economy	11000.00
0005433398811	1455	Economy	11000.00
0005433398664	1455	Economy	11000.00
0005433398554	1455	Economy	11000.00
0005433457055	1455	Economy	11000.00
0005433398821	1455	Economy	11000.00
0005433398799	1455	Economy	11000.00
0005433398678	1455	Economy	11000.00
0005433398529	1455	Economy	11000.00
0005433398749	1455	Economy	11000.00
0005432297333	1455	Economy	11000.00
0005433398553	1455	Economy	11000.00
0005433398548	1455	Economy	11000.00
0005433398632	1455	Economy	11000.00
0005433457056	1455	Economy	11000.00
0005433398663	1455	Economy	11000.00
0005433398541	1455	Economy	11000.00
0005433398586	1455	Economy	11000.00
0005433398752	1455	Economy	11000.00
0005433398531	1455	Economy	11000.00
0005433398739	1455	Economy	11000.00
0005433398587	1455	Economy	11000.00
0005432297335	1455	Economy	11000.00
0005433398668	1455	Economy	11000.00
0005432906588	19238	Business	33000.00
0005433399094	19238	Business	33000.00
0005435732524	19238	Business	33000.00
0005433399111	19238	Business	33000.00
0005433399087	19238	Business	33000.00
0005435732473	19238	Business	33000.00
0005433399104	19238	Business	33000.00
0005433399078	19238	Business	33000.00
0005433399082	19238	Economy	11000.00
0005433399110	19238	Economy	11000.00
0005435732487	19238	Economy	11000.00
0005433399089	19238	Economy	11000.00
0005433399097	19238	Economy	11000.00
0005435732489	19238	Economy	11000.00
0005433399116	19238	Economy	11000.00
0005435732427	19238	Economy	11000.00
0005433399073	19238	Economy	12100.00
0005433399103	19238	Economy	12100.00
0005435732474	19238	Economy	12100.00
0005435732525	19238	Economy	12100.00
0005433457027	19238	Economy	11000.00
0005433399074	19238	Economy	11000.00
0005433399088	19238	Economy	11000.00
0005433399113	19238	Economy	11000.00
0005433399105	19238	Economy	11000.00
0005435732490	19238	Economy	11000.00
0005435732470	19238	Economy	11000.00
0005433399117	19238	Economy	11000.00
0005433399106	19238	Economy	11000.00
0005433399076	19238	Economy	11000.00
0005433399099	19238	Economy	11000.00
0005433399107	19238	Economy	11000.00
0005433399112	19238	Economy	11000.00
0005433399086	19238	Economy	11000.00
0005432906589	19238	Economy	11000.00
0005435732461	19238	Economy	11000.00
0005433399096	19238	Economy	11000.00
0005433399091	19238	Economy	11000.00
0005433399072	19238	Economy	11000.00
0005435732491	19238	Economy	11000.00
0005435732532	19238	Economy	11000.00
0005433399109	19238	Economy	11000.00
0005433399108	19238	Economy	11000.00
0005433399071	19238	Economy	11000.00
0005433399084	19238	Economy	11000.00
0005433399090	19238	Economy	11000.00
0005433399070	19238	Economy	11000.00
0005433399069	19238	Economy	11000.00
0005433399092	19238	Economy	11000.00
0005433399101	19238	Economy	11000.00
0005435732496	19238	Economy	11000.00
0005433399079	19238	Economy	11000.00
0005433399068	19238	Economy	11000.00
0005433399080	19238	Economy	11000.00
0005433399083	19238	Economy	11000.00
0005433399114	19238	Economy	11000.00
0005433399075	19238	Economy	11000.00
0005435732502	19238	Economy	11000.00
0005433399081	19238	Economy	11000.00
0005433399100	19238	Economy	11000.00
0005433399115	19238	Economy	11000.00
0005433399077	19238	Economy	11000.00
0005435732462	19238	Economy	11000.00
0005433399093	19238	Economy	11000.00
0005433399098	19238	Economy	11000.00
0005433399095	19238	Economy	11000.00
0005435732488	19238	Economy	11000.00
0005433399102	19238	Economy	11000.00
0005433457029	19238	Economy	11000.00
0005433399085	19238	Economy	11000.00
0005434443842	17363	Economy	15600.00
0005434443852	17363	Economy	14100.00
0005434443854	17363	Economy	14100.00
0005434443909	17363	Economy	14100.00
0005434443947	17363	Economy	14100.00
0005434443871	17363	Economy	14100.00
0005434443972	17363	Economy	14100.00
0005434443927	17363	Economy	14100.00
0005434443919	17363	Economy	14100.00
0005434443915	17363	Economy	14100.00
0005434443855	17363	Economy	14100.00
0005434443928	17363	Economy	14100.00
0005434443901	17363	Economy	14100.00
0005434443837	17363	Economy	14100.00
0005434443908	17363	Economy	14100.00
0005434443872	17363	Economy	14100.00
0005434443859	17363	Economy	14100.00
0005434443914	17363	Economy	14100.00
0005434444045	20607	Economy	15600.00
0005434444044	20607	Economy	15600.00
0005434444036	20607	Economy	15600.00
0005434444041	20607	Economy	14100.00
0005434444048	20607	Economy	14100.00
0005434444039	20607	Economy	14100.00
0005434444043	20607	Economy	14100.00
0005434444042	20607	Economy	14100.00
0005434444050	20607	Economy	14100.00
0005434444049	20607	Economy	14100.00
0005434444038	20607	Economy	14100.00
0005434444046	20607	Economy	14100.00
0005434444053	20607	Economy	14100.00
0005434444040	20607	Economy	14100.00
0005434444047	20607	Economy	14100.00
0005434444051	20607	Economy	14100.00
0005434444037	20607	Economy	14100.00
0005434444052	20607	Economy	14100.00
0005435377612	7247	Economy	5800.00
0005434954694	7247	Economy	5800.00
0005434954693	7247	Economy	5800.00
0005434954692	7247	Economy	5800.00
0005435377611	7247	Economy	5800.00
0005435377615	7247	Economy	5800.00
0005434954691	7247	Economy	5800.00
0005435377614	7247	Economy	5800.00
0005435377613	7247	Economy	5800.00
0005434954660	28323	Economy	5800.00
0005435377631	28323	Economy	5800.00
0005434954657	28323	Economy	5800.00
0005435377630	28323	Economy	5800.00
0005435377629	28323	Economy	5800.00
0005435377632	28323	Economy	5800.00
0005434954661	28323	Economy	5800.00
0005435893714	4475	Economy	15400.00
0005434351965	4475	Economy	14000.00
0005434351968	4475	Economy	14000.00
0005434351962	4475	Economy	14000.00
0005434351966	4475	Economy	14000.00
0005434351964	4475	Economy	14000.00
0005434183608	4475	Economy	14000.00
0005434326282	4475	Economy	14000.00
0005435893688	4475	Economy	14000.00
0005434351972	4475	Economy	14000.00
0005434351967	4475	Economy	14000.00
0005434351974	4475	Economy	14000.00
0005434183613	4475	Economy	14000.00
0005435893758	4475	Economy	14000.00
0005435893701	4475	Economy	14000.00
0005434351969	4475	Economy	14000.00
0005434183609	4475	Economy	14000.00
0005434351973	4475	Economy	14000.00
0005434183603	4475	Economy	14000.00
0005434351963	4475	Economy	14000.00
0005434326283	4475	Economy	14000.00
0005434351970	4475	Economy	14000.00
0005435893757	4475	Economy	14000.00
0005434351971	4475	Economy	14000.00
0005434183602	4475	Economy	14000.00
0005434351836	29655	Economy	15400.00
0005434351863	29655	Economy	15400.00
0005435893783	29655	Economy	14000.00
0005434351823	29655	Economy	14000.00
0005434351853	29655	Economy	14000.00
0005434351844	29655	Economy	14000.00
0005434351839	29655	Economy	14000.00
0005434351831	29655	Economy	14000.00
0005434351824	29655	Economy	14000.00
0005434351827	29655	Economy	14000.00
0005435893782	29655	Economy	14000.00
0005434351837	29655	Economy	14000.00
0005434351852	29655	Economy	14000.00
0005434351845	29655	Economy	14000.00
0005435893784	29655	Economy	14000.00
0005434351886	29655	Economy	14000.00
0005434351859	29655	Economy	14000.00
0005434351877	29655	Economy	14000.00
0005434351838	29655	Economy	14000.00
0005435893781	29655	Economy	14000.00
0005434351816	29655	Economy	14000.00
0005435893786	29655	Economy	14000.00
0005435893788	29655	Economy	14000.00
0005434351875	29655	Economy	14000.00
0005435893780	29655	Economy	14000.00
0005435893787	29655	Economy	14000.00
0005434351834	29655	Economy	14000.00
0005435893785	29655	Economy	14000.00
0005433344140	1096	Business	30600.00
0005433344343	1096	Business	30600.00
0005433344224	1096	Business	30600.00
0005433344042	1096	Business	30600.00
0005434446569	1096	Business	30600.00
0005435545891	1096	Business	30600.00
0005435092287	1096	Business	30600.00
0005433344567	1096	Business	30600.00
0005435092292	1096	Business	30600.00
0005433344321	1096	Business	30600.00
0005433344394	1096	Business	30600.00
0005433344126	1096	Business	30600.00
0005434446568	1096	Business	30600.00
0005435092285	1096	Business	30600.00
0005433344342	1096	Business	30600.00
0005433344096	1096	Business	30600.00
0005435545892	1096	Business	30600.00
0005433344719	1096	Business	30600.00
0005433344363	1096	Economy	11200.00
0005433344309	1096	Economy	11200.00
0005433158153	1096	Economy	11200.00
0005433343932	1096	Economy	11200.00
0005433344248	1096	Economy	10200.00
0005433344364	1096	Economy	10200.00
0005433344451	1096	Economy	10200.00
0005433344298	1096	Economy	10200.00
0005433344490	1096	Economy	10200.00
0005433344273	1096	Economy	10200.00
0005433344596	1096	Economy	10200.00
0005433344225	1096	Economy	10200.00
0005435092283	1096	Economy	10200.00
0005433344279	1096	Economy	10200.00
0005435092289	1096	Economy	10200.00
0005433344538	1096	Economy	10200.00
0005433344395	1096	Economy	10200.00
0005434445300	1096	Economy	10200.00
0005435545897	1096	Economy	10200.00
0005433344226	1096	Economy	10200.00
0005433343870	1096	Economy	10200.00
0005433344187	1096	Economy	10200.00
0005435092284	1096	Economy	10200.00
0005433344410	1096	Economy	10200.00
0005433344405	1096	Economy	10200.00
0005433269796	1096	Economy	10200.00
0005433344445	1096	Economy	10200.00
0005433344300	1096	Economy	10200.00
0005435545893	1096	Economy	10200.00
0005434445297	1096	Economy	10200.00
0005433344057	1096	Economy	10200.00
0005433344512	1096	Economy	10200.00
0005433344283	1096	Economy	10200.00
0005433344310	1096	Economy	10200.00
0005433344223	1096	Economy	10200.00
0005433344120	1096	Economy	10200.00
0005433344371	1096	Economy	10200.00
0005433344378	1096	Economy	10200.00
0005433344476	1096	Economy	10200.00
0005433344464	1096	Economy	10200.00
0005433344564	1096	Economy	10200.00
0005435545895	1096	Economy	10200.00
0005433344295	1096	Economy	10200.00
0005433344692	1096	Economy	10200.00
0005433344496	1096	Economy	10200.00
0005433269794	1096	Economy	10200.00
0005433344539	1096	Economy	10200.00
0005433344268	1096	Economy	10200.00
0005433343848	1096	Economy	10200.00
0005433344185	1096	Economy	10200.00
0005433344554	1096	Economy	10200.00
0005433343688	1096	Economy	10200.00
0005433158166	1096	Economy	10200.00
0005433344299	1096	Economy	10200.00
0005433344461	1096	Economy	10200.00
0005433344201	1096	Economy	10200.00
0005433344718	1096	Economy	10200.00
0005435092288	1096	Economy	10200.00
0005433343689	1096	Economy	10200.00
0005433344213	1096	Economy	10200.00
0005434446570	1096	Economy	10200.00
0005435545898	1096	Economy	10200.00
0005433343687	1096	Economy	10200.00
0005433159340	1096	Economy	10200.00
0005433269792	1096	Economy	10200.00
0005433462794	1096	Economy	10200.00
0005433344041	1096	Economy	10200.00
0005433269805	1096	Economy	11200.00
0005433344110	1096	Economy	11200.00
0005433344452	1096	Economy	10200.00
0005433344164	1096	Economy	10200.00
0005435092282	1096	Economy	11200.00
0005433344390	1096	Economy	10200.00
0005433344141	1096	Economy	10200.00
0005433344659	1096	Economy	10200.00
0005433344238	1096	Economy	10200.00
0005433344377	1096	Economy	10200.00
0005433344313	1096	Economy	10200.00
0005433344734	1096	Economy	10200.00
0005433344563	1096	Economy	10200.00
0005433269791	1096	Economy	10200.00
0005433269806	1096	Economy	10200.00
0005433344216	1096	Economy	10200.00
0005433344705	1096	Economy	10200.00
0005433344465	1096	Economy	10200.00
0005433344623	1096	Economy	10200.00
0005433344529	1096	Economy	10200.00
0005434445299	1096	Economy	10200.00
0005434445296	1096	Economy	10200.00
0005433344418	1096	Economy	10200.00
0005433344537	1096	Economy	10200.00
0005433344492	1096	Economy	10200.00
0005435545896	1096	Economy	10200.00
0005432293260	1096	Economy	10200.00
0005435545890	1096	Economy	10200.00
0005435092286	1096	Economy	10200.00
0005433344267	1096	Economy	10200.00
0005433344835	1096	Economy	10200.00
0005435545894	1096	Economy	10200.00
0005433344463	1096	Economy	10200.00
0005433343891	1096	Economy	10200.00
0005433344212	1096	Economy	10200.00
0005433158154	1096	Economy	10200.00
0005433462793	1096	Economy	10200.00
0005435092291	1096	Economy	10200.00
0005433344294	1096	Economy	10200.00
0005433344553	1096	Economy	10200.00
0005433344507	1096	Economy	10200.00
0005433344536	1096	Economy	10200.00
0005433344352	1096	Economy	10200.00
0005433344280	1096	Economy	10200.00
0005435092290	1096	Economy	10200.00
0005433344297	1096	Economy	10200.00
0005433344251	1096	Economy	10200.00
0005434445298	1096	Economy	10200.00
0005433344427	1096	Economy	10200.00
0005433344252	1096	Economy	10200.00
0005433344186	1096	Economy	10200.00
0005433344530	1096	Economy	10200.00
0005433269795	1096	Economy	10200.00
0005433344391	1096	Economy	10200.00
0005433344142	1096	Economy	10200.00
0005433344020	1096	Economy	10200.00
0005432293261	1096	Economy	10200.00
0005433344370	1096	Economy	10200.00
0005433460456	17035	Business	30600.00
0005433345162	17035	Business	30600.00
0005433345203	17035	Business	30600.00
0005433345197	17035	Business	30600.00
0005433345156	17035	Business	30600.00
0005433345226	17035	Business	30600.00
0005433462767	17035	Business	30600.00
0005435508471	17035	Business	30600.00
0005433462757	17035	Business	30600.00
0005433460446	17035	Business	30600.00
0005435508480	17035	Business	30600.00
0005433269836	17035	Business	30600.00
0005433345201	17035	Business	30600.00
0005433345208	17035	Business	30600.00
0005433345206	17035	Business	30600.00
0005433345232	17035	Business	30600.00
0005433460453	17035	Business	30600.00
0005433345150	17035	Business	30600.00
0005433460451	17035	Economy	11200.00
0005433460433	17035	Economy	11200.00
0005433460445	17035	Economy	10200.00
0005433345195	17035	Economy	10200.00
0005433345221	17035	Economy	10200.00
0005435508442	17035	Economy	10200.00
0005433269835	17035	Economy	10200.00
0005433345178	17035	Economy	10200.00
0005433345243	17035	Economy	10200.00
0005433345228	17035	Economy	10200.00
0005433345180	17035	Economy	10200.00
0005433345172	17035	Economy	10200.00
0005433345173	17035	Economy	10200.00
0005433345154	17035	Economy	10200.00
0005433345176	17035	Economy	10200.00
0005433159359	17035	Economy	10200.00
0005435508485	17035	Economy	10200.00
0005433345189	17035	Economy	10200.00
0005433462764	17035	Economy	10200.00
0005433460434	17035	Economy	10200.00
0005433345190	17035	Economy	10200.00
0005433345218	17035	Economy	10200.00
0005435508474	17035	Economy	10200.00
0005433345207	17035	Economy	10200.00
0005433345157	17035	Economy	10200.00
0005435508440	17035	Economy	10200.00
0005433462770	17035	Economy	10200.00
0005435508487	17035	Economy	10200.00
0005433345160	17035	Economy	10200.00
0005433462761	17035	Economy	10200.00
0005433345212	17035	Economy	10200.00
0005435092199	17035	Economy	10200.00
0005433345236	17035	Economy	10200.00
0005433462762	17035	Economy	10200.00
0005433345214	17035	Economy	10200.00
0005433345230	17035	Economy	10200.00
0005433345247	17035	Economy	10200.00
0005433345227	17035	Economy	10200.00
0005433345148	17035	Economy	10200.00
0005433345152	17035	Economy	10200.00
0005433345244	17035	Economy	10200.00
0005433462746	17035	Economy	10200.00
0005433345224	17035	Economy	10200.00
0005433269834	17035	Economy	10200.00
0005433345220	17035	Economy	10200.00
0005433345177	17035	Economy	10200.00
0005433462755	17035	Economy	10200.00
0005433345184	17035	Economy	10200.00
0005433345175	17035	Economy	10200.00
0005433345181	17035	Economy	10200.00
0005433460450	17035	Economy	10200.00
0005433345211	17035	Economy	10200.00
0005435092200	17035	Economy	10200.00
0005433345237	17035	Economy	10200.00
0005433345241	17035	Economy	10200.00
0005433345193	17035	Economy	10200.00
0005435508483	17035	Economy	10200.00
0005433345238	17035	Economy	10200.00
0005433460447	17035	Economy	10200.00
0005433345182	17035	Economy	10200.00
0005433460457	17035	Economy	10200.00
0005433345185	17035	Economy	10200.00
0005433462756	17035	Economy	10200.00
0005433345223	17035	Economy	10200.00
0005433462771	17035	Economy	10200.00
0005433345240	17035	Economy	10200.00
0005433460455	17035	Economy	10200.00
0005433345169	17035	Economy	10200.00
0005433462753	17035	Economy	10200.00
0005433345161	17035	Economy	10200.00
0005433345222	17035	Economy	10200.00
0005433460452	17035	Economy	10200.00
0005433269837	17035	Economy	10200.00
0005433345205	17035	Economy	10200.00
0005433345167	17035	Economy	10200.00
0005433345215	17035	Economy	10200.00
0005433345163	17035	Economy	10200.00
0005435092176	17035	Economy	10200.00
0005433345171	17035	Economy	10200.00
0005433345151	17035	Economy	10200.00
0005433345168	17035	Economy	10200.00
0005435092196	17035	Economy	11200.00
0005433345191	17035	Economy	10200.00
0005433345186	17035	Economy	10200.00
0005433345198	17035	Economy	11200.00
0005433159361	17035	Economy	10200.00
0005433345202	17035	Economy	10200.00
0005435092188	17035	Economy	10200.00
0005433460448	17035	Economy	10200.00
0005433345149	17035	Economy	10200.00
0005433462763	17035	Economy	10200.00
0005433159360	17035	Economy	10200.00
0005433345164	17035	Economy	10200.00
0005433345216	17035	Economy	10200.00
0005435508470	17035	Economy	10200.00
0005433462759	17035	Economy	10200.00
0005433345242	17035	Economy	10200.00
0005433345155	17035	Economy	10200.00
0005433345234	17035	Economy	10200.00
0005433345179	17035	Economy	10200.00
0005433345225	17035	Economy	10200.00
0005433345209	17035	Economy	10200.00
0005433460436	17035	Economy	10200.00
0005433462754	17035	Economy	10200.00
0005433345165	17035	Economy	10200.00
0005433345199	17035	Economy	10200.00
0005433345245	17035	Economy	10200.00
0005433462758	17035	Economy	10200.00
0005435092195	17035	Economy	10200.00
0005433345235	17035	Economy	10200.00
0005433345239	17035	Economy	10200.00
0005433345153	17035	Economy	10200.00
0005433345233	17035	Economy	10200.00
0005433462766	17035	Economy	10200.00
0005433460458	17035	Economy	10200.00
0005433345213	17035	Economy	10200.00
0005433269833	17035	Economy	10200.00
0005433345158	17035	Economy	10200.00
0005433345217	17035	Economy	10200.00
0005433345147	17035	Economy	10200.00
0005433345200	17035	Economy	10200.00
0005433345219	17035	Economy	10200.00
0005433345174	17035	Economy	10200.00
0005433460459	17035	Economy	10200.00
0005433345246	17035	Economy	10200.00
0005435092222	17035	Economy	10200.00
0005433462752	17035	Economy	10200.00
0005435092201	17035	Economy	10200.00
0005433462760	17035	Economy	10200.00
0005433345170	17035	Economy	10200.00
0005433345183	17035	Economy	10200.00
0005433345187	17035	Economy	10200.00
0005433345192	17035	Economy	10200.00
0005433345248	17035	Economy	10200.00
0005433345231	17035	Economy	10200.00
0005433345229	17035	Economy	10200.00
0005433345204	17035	Economy	10200.00
0005433345159	17035	Economy	10200.00
0005433345210	17035	Economy	10200.00
0005433345166	17035	Economy	10200.00
0005433460435	17035	Economy	10200.00
0005435092198	17035	Economy	10200.00
0005433345188	17035	Economy	10200.00
0005433462745	17035	Economy	10200.00
0005433345196	17035	Economy	10200.00
0005433345194	17035	Economy	10200.00
0005433462769	17035	Economy	10200.00
0005432390302	18261	Business	101000.00
0005432390289	18261	Business	101000.00
0005432392031	18261	Business	101000.00
0005432390224	18261	Business	101000.00
0005432390297	18261	Business	101000.00
0005432392021	18261	Business	101000.00
0005432390234	18261	Business	101000.00
0005432392022	18261	Business	101000.00
0005432390254	18261	Business	101000.00
0005432390251	18261	Business	101000.00
0005432852047	18261	Business	101000.00
0005432390270	18261	Economy	33700.00
0005432392026	18261	Economy	33700.00
0005432852042	18261	Economy	33700.00
0005432390231	18261	Economy	33700.00
0005432852050	18261	Economy	33700.00
0005432390263	18261	Economy	37000.00
0005432852040	18261	Economy	37000.00
0005432390229	18261	Economy	37000.00
0005432852044	18261	Economy	37000.00
0005432390252	18261	Economy	33700.00
0005432852051	18261	Economy	33700.00
0005432390205	18261	Economy	33700.00
0005432390204	18261	Economy	33700.00
0005432852048	18261	Economy	33700.00
0005432390237	18261	Economy	33700.00
0005432390228	18261	Economy	33700.00
0005432852045	18261	Economy	33700.00
0005432390250	18261	Economy	33700.00
0005432852053	18261	Economy	33700.00
0005432852039	18261	Economy	33700.00
0005432392030	18261	Economy	33700.00
0005432390235	18261	Economy	33700.00
0005432852036	18261	Economy	33700.00
0005432852049	18261	Economy	33700.00
0005432390223	18261	Economy	33700.00
0005432390230	18261	Economy	33700.00
0005432390246	18261	Economy	33700.00
0005432390282	18261	Economy	33700.00
0005432390241	18261	Economy	33700.00
0005432852043	18261	Economy	33700.00
0005432390225	18261	Economy	33700.00
0005432390283	18261	Economy	33700.00
0005432392034	18261	Economy	33700.00
0005432390267	18261	Economy	33700.00
0005432390287	18261	Economy	33700.00
0005432392033	18261	Economy	33700.00
0005432390222	18261	Economy	33700.00
0005432390247	18261	Economy	33700.00
0005432852046	18261	Economy	33700.00
0005432852052	18261	Economy	33700.00
0005432852038	18261	Economy	33700.00
0005432390284	18261	Economy	33700.00
0005432852037	18261	Economy	33700.00
0005432390240	18261	Economy	33700.00
0005432390277	18261	Economy	33700.00
0005432852054	18261	Economy	33700.00
0005432390221	18261	Economy	33700.00
0005432390236	18261	Economy	33700.00
0005432390255	18261	Economy	33700.00
0005432852041	18261	Economy	33700.00
0005434082163	12823	Business	40300.00
0005434082176	12823	Business	40300.00
0005434082138	12823	Business	40300.00
0005434068777	12823	Business	40300.00
0005434068492	12823	Business	40300.00
0005434082165	12823	Business	40300.00
0005434067999	12823	Business	40300.00
0005434082237	12823	Business	40300.00
0005434068286	12823	Business	40300.00
0005432433798	12823	Business	40300.00
0005435283432	12823	Business	40300.00
0005434068267	12823	Economy	13400.00
0005435283433	12823	Economy	13400.00
0005434082228	12823	Economy	13400.00
0005434068584	12823	Economy	13400.00
0005434082229	12823	Economy	13400.00
0005432159954	12823	Economy	13400.00
0005434082195	12823	Economy	13400.00
0005434068373	12823	Economy	13400.00
0005434068500	12823	Economy	13400.00
0005434082209	12823	Economy	13400.00
0005434068334	12823	Economy	13400.00
0005434067895	12823	Economy	13400.00
0005435283437	12823	Economy	13400.00
0005435283427	12823	Economy	13400.00
0005432161201	12823	Economy	13400.00
0005435283436	12823	Economy	13400.00
0005433989830	12823	Economy	13400.00
0005432433796	12823	Economy	13400.00
0005434068423	12823	Economy	13400.00
0005432433795	12823	Economy	13400.00
0005434082199	12823	Economy	13400.00
0005434068438	12823	Economy	13400.00
0005434068256	12823	Economy	13400.00
0005432161200	12823	Economy	13400.00
0005434068482	12823	Economy	13400.00
0005434068285	12823	Economy	13400.00
0005434068333	12823	Economy	13400.00
0005434068508	12823	Economy	13400.00
0005434068827	12823	Economy	13400.00
0005434068515	12823	Economy	13400.00
0005435283431	12823	Economy	13400.00
0005432433792	12823	Economy	13400.00
0005434082130	12823	Economy	13400.00
0005434082187	12823	Economy	13400.00
0005435283429	12823	Economy	13400.00
0005434082212	12823	Economy	13400.00
0005435283434	12823	Economy	13400.00
0005434068470	12823	Economy	14800.00
0005434068637	12823	Economy	14800.00
0005434068440	12823	Economy	14800.00
0005434082156	12823	Economy	14800.00
0005435283435	12823	Economy	14800.00
0005434082159	12823	Economy	14800.00
0005434068514	12823	Economy	13400.00
0005434068101	12823	Economy	13400.00
0005435283439	12823	Economy	13400.00
0005434068480	12823	Economy	13400.00
0005434082166	12823	Economy	13400.00
0005432159956	12823	Economy	13400.00
0005434068258	12823	Economy	13400.00
0005434082196	12823	Economy	13400.00
0005432433794	12823	Economy	13400.00
0005434068379	12823	Economy	13400.00
0005434082242	12823	Economy	13400.00
0005435283438	12823	Economy	13400.00
0005434068322	12823	Economy	13400.00
0005434082177	12823	Economy	13400.00
0005434068583	12823	Economy	13400.00
0005434068509	12823	Economy	13400.00
0005434068081	12823	Economy	13400.00
0005434068372	12823	Economy	13400.00
0005434082164	12823	Economy	13400.00
0005434068683	12823	Economy	13400.00
0005434068495	12823	Economy	13400.00
0005434068413	12823	Economy	13400.00
0005434068308	12823	Economy	13400.00
0005434068456	12823	Economy	13400.00
0005434068497	12823	Economy	13400.00
0005434068507	12823	Economy	13400.00
0005432159955	12823	Economy	13400.00
0005434068335	12823	Economy	13400.00
0005434082243	12823	Economy	13400.00
0005432159957	12823	Economy	13400.00
0005434082161	12823	Economy	13400.00
0005434068392	12823	Economy	13400.00
0005434026726	12823	Economy	13400.00
0005434068272	12823	Economy	13400.00
0005433812952	12823	Economy	13400.00
0005434082210	12823	Economy	13400.00
0005434068496	12823	Economy	13400.00
0005432433793	12823	Economy	13400.00
0005434068382	12823	Economy	13400.00
0005434068703	12823	Economy	13400.00
0005435283430	12823	Economy	13400.00
0005434068528	12823	Economy	13400.00
0005434068104	12823	Economy	13400.00
0005432159958	12823	Economy	13400.00
0005434068156	12823	Economy	13400.00
0005434082087	12823	Economy	13400.00
0005434068501	12823	Economy	13400.00
0005434068356	12823	Economy	13400.00
0005434082157	12823	Economy	13400.00
0005432433797	12823	Economy	13400.00
0005434082230	12823	Economy	13400.00
0005434082160	12823	Economy	13400.00
0005435283428	12823	Economy	13400.00
0005434068481	12823	Economy	13400.00
0005434082194	12823	Economy	13400.00
0005434068395	12823	Economy	13400.00
0005434068257	12823	Economy	13400.00
0005434068071	12823	Economy	13400.00
0005434068412	12823	Economy	13400.00
0005434068684	12823	Economy	13400.00
0005434082129	12823	Economy	13400.00
0005434068323	12823	Economy	13400.00
0005434068173	12823	Economy	13400.00
0005432161202	12823	Economy	13400.00
0005434068351	12823	Economy	13400.00
0005434068174	12823	Economy	13400.00
0005434068212	12823	Economy	13400.00
0005434068439	12823	Economy	13400.00
0005434068999	30655	Business	40300.00
0005434069042	30655	Business	40300.00
0005434069001	30655	Business	40300.00
0005432186946	30655	Business	40300.00
0005434082363	30655	Business	40300.00
0005434069029	30655	Business	40300.00
0005434068986	30655	Business	40300.00
0005434069032	30655	Business	40300.00
0005434082368	30655	Business	40300.00
0005434082375	30655	Business	40300.00
0005434069015	30655	Business	40300.00
0005432433757	30655	Business	40300.00
0005434082391	30655	Economy	13400.00
0005434069055	30655	Economy	13400.00
0005434069045	30655	Economy	13400.00
0005432186943	30655	Economy	13400.00
0005434082377	30655	Economy	13400.00
0005434069027	30655	Economy	13400.00
0005434068996	30655	Economy	13400.00
0005434069023	30655	Economy	13400.00
0005434082388	30655	Economy	13400.00
0005434069002	30655	Economy	13400.00
0005432433746	30655	Economy	13400.00
0005434069007	30655	Economy	13400.00
0005432150359	30655	Economy	13400.00
0005434069010	30655	Economy	13400.00
0005434082378	30655	Economy	13400.00
0005432150358	30655	Economy	13400.00
0005434082381	30655	Economy	13400.00
0005434069031	30655	Economy	13400.00
0005434082359	30655	Economy	13400.00
0005434069016	30655	Economy	13400.00
0005434069013	30655	Economy	13400.00
0005434069008	30655	Economy	13400.00
0005434082360	30655	Economy	13400.00
0005434069056	30655	Economy	13400.00
0005434069004	30655	Economy	13400.00
0005434082364	30655	Economy	13400.00
0005434069003	30655	Economy	13400.00
0005434068987	30655	Economy	13400.00
0005434068984	30655	Economy	13400.00
0005434069019	30655	Economy	13400.00
0005434082365	30655	Economy	13400.00
0005433989870	30655	Economy	13400.00
0005433989868	30655	Economy	13400.00
0005432150353	30655	Economy	13400.00
0005434068997	30655	Economy	13400.00
0005432150357	30655	Economy	13400.00
0005434068993	30655	Economy	13400.00
0005434082369	30655	Economy	13400.00
0005434069043	30655	Economy	13400.00
0005434069011	30655	Economy	14800.00
0005434082389	30655	Economy	14800.00
0005434069041	30655	Economy	14800.00
0005432433749	30655	Economy	14800.00
0005434069020	30655	Economy	14800.00
0005434069028	30655	Economy	14800.00
0005434069052	30655	Economy	13400.00
0005432186944	30655	Economy	13400.00
0005434082387	30655	Economy	13400.00
0005434069025	30655	Economy	13400.00
0005434069044	30655	Economy	13400.00
0005434068991	30655	Economy	13400.00
0005434082362	30655	Economy	13400.00
0005434069051	30655	Economy	13400.00
0005434069035	30655	Economy	13400.00
0005434069018	30655	Economy	13400.00
0005434068992	30655	Economy	13400.00
0005434082386	30655	Economy	13400.00
0005434068994	30655	Economy	13400.00
0005434082373	30655	Economy	13400.00
0005434069050	30655	Economy	13400.00
0005434082385	30655	Economy	13400.00
0005434068988	30655	Economy	13400.00
0005432150354	30655	Economy	13400.00
0005434082372	30655	Economy	13400.00
0005434068995	30655	Economy	13400.00
0005434082376	30655	Economy	13400.00
0005434082371	30655	Economy	13400.00
0005434068990	30655	Economy	13400.00
0005432150355	30655	Economy	13400.00
0005434082370	30655	Economy	13400.00
0005432433760	30655	Economy	13400.00
0005434082366	30655	Economy	13400.00
0005434069024	30655	Economy	13400.00
0005434069038	30655	Economy	13400.00
0005434069005	30655	Economy	13400.00
0005434069047	30655	Economy	13400.00
0005434082383	30655	Economy	13400.00
0005434082384	30655	Economy	13400.00
0005432150356	30655	Economy	13400.00
0005434069000	30655	Economy	13400.00
0005434069014	30655	Economy	13400.00
0005434082382	30655	Economy	13400.00
0005434082390	30655	Economy	13400.00
0005432186942	30655	Economy	13400.00
0005432150352	30655	Economy	13400.00
0005434069012	30655	Economy	13400.00
0005434068998	30655	Economy	13400.00
0005434082374	30655	Economy	13400.00
0005433989867	30655	Economy	13400.00
0005434069017	30655	Economy	13400.00
0005433989869	30655	Economy	13400.00
0005434069040	30655	Economy	13400.00
0005434068983	30655	Economy	13400.00
0005434069030	30655	Economy	13400.00
0005434069034	30655	Economy	13400.00
0005434069006	30655	Economy	13400.00
0005434068989	30655	Economy	13400.00
0005432186945	30655	Economy	13400.00
0005434069021	30655	Economy	13400.00
0005434069026	30655	Economy	13400.00
0005434069009	30655	Economy	13400.00
0005434069046	30655	Economy	13400.00
0005434069033	30655	Economy	13400.00
0005434068985	30655	Economy	13400.00
0005434082367	30655	Economy	13400.00
0005434082380	30655	Economy	13400.00
0005434082379	30655	Economy	13400.00
0005434069037	30655	Economy	13400.00
0005432433783	30655	Economy	13400.00
0005434069048	30655	Economy	13400.00
0005434069054	30655	Economy	13400.00
0005434082361	30655	Economy	13400.00
0005434069036	30655	Economy	13400.00
0005434069039	30655	Economy	13400.00
0005434069053	30655	Economy	13400.00
0005434069049	30655	Economy	13400.00
0005434069022	30655	Economy	13400.00
0005433686679	9043	Economy	19300.00
0005433687756	9043	Economy	19300.00
0005433687753	9043	Economy	19300.00
0005433687750	9043	Economy	17600.00
0005433685570	9043	Economy	17600.00
0005433687755	9043	Economy	17600.00
0005433686678	9043	Economy	17600.00
0005433687752	9043	Economy	17600.00
0005433687757	9043	Economy	17600.00
0005433685566	9043	Economy	17600.00
0005433686683	9043	Economy	17600.00
0005433687754	9043	Economy	17600.00
0005433687749	9043	Economy	17600.00
0005433685572	9043	Economy	17600.00
0005433685573	9043	Economy	17600.00
0005433685567	9043	Economy	17600.00
0005433686686	9043	Economy	17600.00
0005433686684	9043	Economy	17600.00
0005433685568	9043	Economy	17600.00
0005433686682	9043	Economy	17600.00
0005433685571	9043	Economy	17600.00
0005433686687	9043	Economy	17600.00
0005433687751	9043	Economy	17600.00
0005433685569	9043	Economy	17600.00
0005433686685	9043	Economy	17600.00
0005433686680	9043	Economy	17600.00
0005433685574	9043	Economy	17600.00
0005433687748	9043	Economy	17600.00
0005433686681	9043	Economy	17600.00
0005434265570	5510	Business	35300.00
0005435767543	5510	Business	35300.00
0005432140624	5510	Business	35300.00
0005435767507	5510	Business	35300.00
0005435462948	5510	Business	35300.00
0005435767508	5510	Business	35300.00
0005434265456	5510	Business	35300.00
0005435462932	5510	Business	35300.00
0005435767531	5510	Business	35300.00
0005434265398	5510	Business	35300.00
0005434831198	5510	Business	35300.00
0005435767548	5510	Business	35300.00
0005434265429	5510	Business	35300.00
0005435735237	5510	Business	35300.00
0005435462836	5510	Business	35300.00
0005435767517	5510	Business	35300.00
0005435767526	5510	Business	35300.00
0005435722107	5510	Business	35300.00
0005435462822	5510	Business	35300.00
0005435462944	5510	Business	35300.00
0005434831205	5510	Business	35300.00
0005435767523	5510	Business	35300.00
0005435462911	5510	Business	35300.00
0005435767538	5510	Business	35300.00
0005435462987	5510	Business	35300.00
0005435462824	5510	Economy	12900.00
0005435767519	5510	Economy	12900.00
0005433529358	5510	Economy	12900.00
0005435767570	5510	Economy	12900.00
0005435767569	5510	Economy	11800.00
0005435463008	5510	Economy	11800.00
0005435767545	5510	Economy	11800.00
0005435767512	5510	Economy	11800.00
0005432535874	5510	Economy	11800.00
0005435767571	5510	Economy	11800.00
0005435767567	5510	Economy	11800.00
0005434265408	5510	Economy	11800.00
0005435767546	5510	Economy	11800.00
0005435767566	5510	Economy	11800.00
0005435767518	5510	Economy	11800.00
0005435767544	5510	Economy	11800.00
0005435462808	5510	Economy	11800.00
0005434265416	5510	Economy	11800.00
0005435767533	5510	Economy	11800.00
0005435767527	5510	Economy	11800.00
0005435767542	5510	Economy	11800.00
0005435767514	5510	Economy	11800.00
0005435767500	5510	Economy	11800.00
0005434831185	5510	Economy	11800.00
0005435767568	5510	Economy	11800.00
0005435735232	5510	Economy	11800.00
0005435767522	5510	Economy	11800.00
0005435767509	5510	Economy	11800.00
0005435767530	5510	Economy	11800.00
0005435462867	5510	Economy	11800.00
0005435723085	5510	Economy	11800.00
0005434265437	5510	Economy	11800.00
0005435767560	5510	Economy	11800.00
0005435767552	5510	Economy	11800.00
0005435462976	5510	Economy	11800.00
0005434831204	5510	Economy	11800.00
0005434265491	5510	Economy	11800.00
0005432535878	5510	Economy	11800.00
0005435462821	5510	Economy	11800.00
0005435767501	5510	Economy	11800.00
0005432140627	5510	Economy	11800.00
0005435767536	5510	Economy	11800.00
0005432140622	5510	Economy	11800.00
0005432535875	5510	Economy	11800.00
0005435462859	5510	Economy	11800.00
0005432535879	5510	Economy	11800.00
0005435723084	5510	Economy	11800.00
0005435462977	5510	Economy	11800.00
0005435462978	5510	Economy	11800.00
0005435767540	5510	Economy	11800.00
0005435462995	5510	Economy	11800.00
0005434265526	5510	Economy	11800.00
0005435722105	5510	Economy	11800.00
0005435767541	5510	Economy	11800.00
0005433529360	5510	Economy	11800.00
0005433527350	5510	Economy	11800.00
0005432535895	5510	Economy	11800.00
0005435462875	5510	Economy	11800.00
0005435462763	5510	Economy	11800.00
0005435462835	5510	Economy	11800.00
0005435767502	5510	Economy	11800.00
0005435462919	5510	Economy	11800.00
0005435767524	5510	Economy	11800.00
0005434265481	5510	Economy	11800.00
0005435767563	5510	Economy	11800.00
0005435767505	5510	Economy	11800.00
0005434265431	5510	Economy	11800.00
0005435767503	5510	Economy	11800.00
0005433527348	5510	Economy	11800.00
0005435463056	5510	Economy	11800.00
0005435767553	5510	Economy	11800.00
0005432535894	5510	Economy	11800.00
0005435043295	5510	Economy	11800.00
0005434265593	5510	Economy	11800.00
0005434831207	5510	Economy	11800.00
0005434265415	5510	Economy	11800.00
0005435767558	5510	Economy	11800.00
0005435767539	5510	Economy	12900.00
0005435767564	5510	Economy	11800.00
0005434831184	5510	Economy	12900.00
0005432140621	5510	Economy	11800.00
0005435767550	5510	Economy	12900.00
0005433529361	5510	Economy	11800.00
0005435767549	5510	Economy	11800.00
0005435725701	5510	Economy	11800.00
0005435767572	5510	Economy	11800.00
0005435735233	5510	Economy	11800.00
0005434265407	5510	Economy	11800.00
0005434265432	5510	Economy	11800.00
0005435767573	5510	Economy	11800.00
0005435767513	5510	Economy	11800.00
0005433529359	5510	Economy	11800.00
0005435767551	5510	Economy	11800.00
0005432535889	5510	Economy	11800.00
0005433527347	5510	Economy	11800.00
0005435462882	5510	Economy	11800.00
0005435767561	5510	Economy	11800.00
0005435767504	5510	Economy	11800.00
0005434265544	5510	Economy	11800.00
0005435735236	5510	Economy	11800.00
0005432140626	5510	Economy	11800.00
0005434265571	5510	Economy	11800.00
0005435767557	5510	Economy	11800.00
0005434265499	5510	Economy	11800.00
0005435735234	5510	Economy	11800.00
0005435767525	5510	Economy	11800.00
0005435462889	5510	Economy	11800.00
0005435767528	5510	Economy	11800.00
0005435767547	5510	Economy	11800.00
0005435462996	5510	Economy	11800.00
0005435767521	5510	Economy	11800.00
0005435725702	5510	Economy	11800.00
0005435767511	5510	Economy	11800.00
0005435722106	5510	Economy	11800.00
0005435767565	5510	Economy	11800.00
0005435767537	5510	Economy	11800.00
0005435735235	5510	Economy	11800.00
0005435462918	5510	Economy	11800.00
0005435767520	5510	Economy	11800.00
0005435767556	5510	Economy	11800.00
0005432140625	5510	Economy	11800.00
0005434265433	5510	Economy	11800.00
0005435767562	5510	Economy	11800.00
0005435767516	5510	Economy	11800.00
0005435767510	5510	Economy	11800.00
0005432140623	5510	Economy	11800.00
0005435462860	5510	Economy	11800.00
0005435767554	5510	Economy	11800.00
0005434265498	5510	Economy	11800.00
0005435767534	5510	Economy	11800.00
0005435767535	5510	Economy	11800.00
0005433527349	5510	Economy	11800.00
0005435767506	5510	Economy	11800.00
0005435767515	5510	Economy	11800.00
0005435767555	5510	Economy	11800.00
0005435767559	5510	Economy	11800.00
0005435462843	5510	Economy	11800.00
0005435462988	5510	Economy	11800.00
0005435720848	5510	Economy	11800.00
0005435462989	5510	Economy	11800.00
0005435767529	5510	Economy	11800.00
0005435767532	5510	Economy	11800.00
0005434265334	5510	Economy	11800.00
0005435462854	5510	Economy	11800.00
0005432535937	13459	Business	35300.00
0005435720144	13459	Business	35300.00
0005435725655	13459	Business	35300.00
0005435725674	13459	Business	35300.00
0005435463241	13459	Business	35300.00
0005434265685	13459	Business	35300.00
0005435766935	13459	Business	35300.00
0005435767286	13459	Business	35300.00
0005432194598	13459	Business	35300.00
0005434831254	13459	Business	35300.00
0005434265689	13459	Business	35300.00
0005434265697	13459	Business	35300.00
0005434831255	13459	Business	35300.00
0005435463250	13459	Business	35300.00
0005432535936	13459	Business	35300.00
0005434265695	13459	Business	35300.00
0005434265693	13459	Business	35300.00
0005435767063	13459	Business	35300.00
0005435463233	13459	Economy	12900.00
0005435766693	13459	Business	35300.00
0005435463249	13459	Economy	12900.00
0005435766802	13459	Economy	12900.00
0005435766898	13459	Economy	11800.00
0005435766937	13459	Economy	11800.00
0005435766934	13459	Economy	11800.00
0005435766971	13459	Economy	11800.00
0005435463235	13459	Economy	11800.00
0005434831253	13459	Economy	11800.00
0005435463234	13459	Economy	11800.00
0005435766794	13459	Economy	11800.00
0005434265683	13459	Economy	11800.00
0005435463256	13459	Economy	11800.00
0005434265698	13459	Economy	11800.00
0005432194601	13459	Economy	11800.00
0005435463231	13459	Economy	11800.00
0005435463257	13459	Economy	11800.00
0005435720143	13459	Economy	11800.00
0005435735184	13459	Economy	11800.00
0005435463243	13459	Economy	11800.00
0005435767285	13459	Economy	11800.00
0005435767148	13459	Economy	11800.00
0005435463240	13459	Economy	11800.00
0005434265692	13459	Economy	11800.00
0005435463260	13459	Economy	11800.00
0005434265704	13459	Economy	11800.00
0005435463242	13459	Economy	11800.00
0005435766956	13459	Economy	11800.00
0005435723074	13459	Economy	11800.00
0005435767284	13459	Economy	11800.00
0005435463239	13459	Economy	11800.00
0005435463262	13459	Economy	11800.00
0005435463227	13459	Economy	11800.00
0005435766793	13459	Economy	11800.00
0005435766914	13459	Economy	11800.00
0005435735211	13459	Economy	11800.00
0005435767138	13459	Economy	11800.00
0005434265691	13459	Economy	11800.00
0005435766913	13459	Economy	11800.00
0005435767318	13459	Economy	11800.00
0005435766936	13459	Economy	11800.00
0005435463226	13459	Economy	11800.00
0005434831252	13459	Economy	11800.00
0005435463225	13459	Economy	11800.00
0005435463255	13459	Economy	11800.00
0005432194600	13459	Economy	11800.00
0005435463238	13459	Economy	11800.00
0005434265686	13459	Economy	11800.00
0005435463263	13459	Economy	11800.00
0005435463251	13459	Economy	11800.00
0005432535938	13459	Economy	11800.00
0005434265696	13459	Economy	11800.00
0005435766920	13459	Economy	11800.00
0005434265690	13459	Economy	11800.00
0005435463230	13459	Economy	11800.00
0005435725682	13459	Economy	11800.00
0005435766921	13459	Economy	11800.00
0005435767156	13459	Economy	11800.00
0005435463229	13459	Economy	11800.00
0005434265680	13459	Economy	11800.00
0005432535939	13459	Economy	11800.00
0005435463248	13459	Economy	11800.00
0005435766940	13459	Economy	11800.00
0005435766853	13459	Economy	11800.00
0005435725673	13459	Economy	11800.00
0005435767001	13459	Economy	11800.00
0005434265682	13459	Economy	11800.00
0005435767027	13459	Economy	11800.00
0005435463254	13459	Economy	11800.00
0005434265681	13459	Economy	11800.00
0005432535941	13459	Economy	11800.00
0005434265694	13459	Economy	11800.00
0005435725659	13459	Economy	12900.00
0005435767084	13459	Economy	11800.00
0005435463253	13459	Economy	12900.00
0005435723067	13459	Economy	11800.00
0005434265700	13459	Economy	11800.00
0005435766627	13459	Economy	11800.00
0005435766966	13459	Economy	11800.00
0005435463258	13459	Economy	11800.00
0005435767000	13459	Economy	11800.00
0005435766792	13459	Economy	11800.00
0005435767003	13459	Economy	11800.00
0005435463252	13459	Economy	11800.00
0005435767028	13459	Economy	11800.00
0005435766930	13459	Economy	11800.00
0005435463236	13459	Economy	11800.00
0005435766692	13459	Economy	11800.00
0005434265701	13459	Economy	11800.00
0005434265703	13459	Economy	11800.00
0005435463244	13459	Economy	11800.00
0005434265687	13459	Economy	11800.00
0005435766996	13459	Economy	11800.00
0005435463246	13459	Economy	11800.00
0005435766977	13459	Economy	11800.00
0005435767108	13459	Economy	11800.00
0005435766976	13459	Economy	11800.00
0005435767215	13459	Economy	11800.00
0005434265702	13459	Economy	11800.00
0005432535940	13459	Economy	11800.00
0005432194602	13459	Economy	11800.00
0005432194599	13459	Economy	11800.00
0005435767053	13459	Economy	11800.00
0005435463247	13459	Economy	11800.00
0005432194603	13459	Economy	11800.00
0005435725656	13459	Economy	11800.00
0005435463261	13459	Economy	11800.00
0005435463259	13459	Economy	11800.00
0005435766955	13459	Economy	11800.00
0005435766939	13459	Economy	11800.00
0005435463232	13459	Economy	11800.00
0005435766709	13459	Economy	11800.00
0005435767209	13459	Economy	11800.00
0005435766922	13459	Economy	11800.00
0005434265705	13459	Economy	11800.00
0005435463245	13459	Economy	11800.00
0005435766681	13459	Economy	11800.00
0005435463264	13459	Economy	11800.00
0005435043298	13459	Economy	11800.00
0005432535942	13459	Economy	11800.00
0005435766979	13459	Economy	11800.00
0005434265699	13459	Economy	11800.00
0005435766682	13459	Economy	11800.00
0005435767115	13459	Economy	11800.00
0005434265688	13459	Economy	11800.00
0005435766943	13459	Economy	11800.00
0005435767083	13459	Economy	11800.00
0005435463237	13459	Economy	11800.00
0005434265684	13459	Economy	11800.00
0005435766957	13459	Economy	11800.00
0005435463228	13459	Economy	11800.00
0005435767011	13459	Economy	11800.00
0005435720142	13459	Economy	11800.00
0005435766899	13459	Economy	11800.00
0005434602933	18643	Economy	3300.00
0005434602932	18643	Economy	3300.00
0005434602937	18643	Economy	3300.00
0005435904720	18698	Economy	3300.00
0005434513633	18698	Economy	3300.00
0005434513635	18698	Economy	3300.00
0005434604949	18698	Economy	3300.00
0005435904719	18698	Economy	3300.00
0005434513634	18698	Economy	3300.00
0005434604932	18698	Economy	3300.00
0005434515021	18698	Economy	3300.00
0005434604952	18698	Economy	3300.00
0005434515022	18698	Economy	3300.00
0005434514991	19160	Economy	3300.00
0005434602950	19160	Economy	3300.00
0005434602948	19160	Economy	3300.00
0005434515004	19160	Economy	3300.00
0005434602949	19160	Economy	3300.00
0005433009250	1791	Business	48700.00
0005433009165	1791	Business	48700.00
0005433810656	1791	Business	48700.00
0005433009092	1791	Business	48700.00
0005432295935	1791	Business	48700.00
0005433009093	1791	Business	48700.00
0005433009157	1791	Business	48700.00
0005433285657	1791	Business	48700.00
0005433009259	1791	Business	48700.00
0005433285787	1791	Business	48700.00
0005433009318	1791	Business	48700.00
0005433009228	1791	Business	48700.00
0005433285739	1791	Economy	16200.00
0005432295937	1791	Economy	16200.00
0005433009029	1791	Economy	16200.00
0005433009128	1791	Economy	16200.00
0005433008847	1791	Economy	16200.00
0005433009325	1791	Economy	16200.00
0005433810664	1791	Economy	16200.00
0005433009174	1791	Economy	16200.00
0005433009399	1791	Economy	16200.00
0005433009247	1791	Economy	16200.00
0005432295936	1791	Economy	17900.00
0005433285765	1791	Economy	17900.00
0005433285677	1791	Economy	17900.00
0005433009227	1791	Economy	17900.00
0005433285709	1791	Economy	17900.00
0005433285638	1791	Economy	16200.00
0005433009129	1791	Economy	16200.00
0005433285858	1791	Economy	16200.00
0005433009167	1791	Economy	16200.00
0005433009326	1791	Economy	16200.00
0005433009256	1791	Economy	16200.00
0005433009305	1791	Economy	16200.00
0005433285632	1791	Economy	16200.00
0005433285788	1791	Economy	16200.00
0005433009173	1791	Economy	16200.00
0005433009204	1791	Economy	16200.00
0005433285801	1791	Economy	16200.00
0005433810659	1791	Economy	16200.00
0005433285687	1791	Economy	16200.00
0005433009075	1791	Economy	16200.00
0005433285693	1791	Economy	16200.00
0005433009031	1791	Economy	16200.00
0005433009168	1791	Economy	16200.00
0005433009304	1791	Economy	16200.00
0005433009284	1791	Economy	16200.00
0005433810658	1791	Economy	16200.00
0005433810660	1791	Economy	16200.00
0005433285690	1791	Economy	16200.00
0005433285692	1791	Economy	16200.00
0005433810666	1791	Economy	16200.00
0005433009266	1791	Economy	16200.00
0005433009030	1791	Economy	16200.00
0005433009245	1791	Economy	16200.00
0005433009308	1791	Economy	16200.00
0005433008848	1791	Economy	16200.00
0005433285738	1791	Economy	16200.00
0005433810668	1791	Economy	16200.00
0005433285637	1791	Economy	16200.00
0005433009270	1791	Economy	16200.00
0005433009191	1791	Economy	16200.00
0005433285766	1791	Economy	16200.00
0005433285708	1791	Economy	16200.00
0005433810662	1791	Economy	16200.00
0005433008849	1791	Economy	16200.00
0005433810661	1791	Economy	16200.00
0005433810667	1791	Economy	16200.00
0005433285691	1791	Economy	16200.00
0005433009212	1791	Economy	16200.00
0005433009192	1791	Economy	16200.00
0005433009309	1791	Economy	16200.00
0005433009257	1791	Economy	16200.00
0005433009251	1791	Economy	16200.00
0005433009145	1791	Economy	16200.00
0005433810663	1791	Economy	16200.00
0005433285633	1791	Economy	16200.00
0005433285791	1791	Economy	16200.00
0005433285773	1791	Economy	16200.00
0005433009146	1791	Economy	16200.00
0005433009076	1791	Economy	16200.00
0005433009229	1791	Economy	16200.00
0005433009124	1791	Economy	16200.00
0005433810665	1791	Economy	16200.00
0005433009166	1791	Economy	16200.00
0005433285749	1791	Economy	16200.00
0005433009171	1791	Economy	16200.00
0005433009246	1791	Economy	16200.00
0005433810657	1791	Economy	16200.00
0005433810669	1791	Economy	16200.00
0005433009060	1791	Economy	16200.00
0005433009285	1791	Economy	16200.00
0005433285935	22548	Business	48700.00
0005433285946	22548	Business	48700.00
0005433009562	22548	Business	48700.00
0005433009543	22548	Business	48700.00
0005433285961	22548	Business	48700.00
0005433285942	22548	Business	48700.00
0005433009580	22548	Business	48700.00
0005433009582	22548	Business	48700.00
0005433009553	22548	Business	48700.00
0005433009545	22548	Business	48700.00
0005433009557	22548	Business	48700.00
0005433009542	22548	Business	48700.00
0005433285943	22548	Economy	16200.00
0005433009563	22548	Economy	16200.00
0005433009551	22548	Economy	16200.00
0005433285940	22548	Economy	16200.00
0005433009538	22548	Economy	16200.00
0005433285962	22548	Economy	16200.00
0005433285956	22548	Economy	16200.00
0005433009576	22548	Economy	17900.00
0005433009574	22548	Economy	17900.00
0005433285938	22548	Economy	17900.00
0005433285959	22548	Economy	17900.00
0005433009561	22548	Economy	16200.00
0005433285947	22548	Economy	16200.00
0005433009569	22548	Economy	16200.00
0005433009564	22548	Economy	16200.00
0005433009572	22548	Economy	16200.00
0005433285958	22548	Economy	16200.00
0005433285934	22548	Economy	16200.00
0005433285953	22548	Economy	16200.00
0005433009539	22548	Economy	16200.00
0005433285933	22548	Economy	16200.00
0005433009570	22548	Economy	16200.00
0005433009565	22548	Economy	16200.00
0005433009560	22548	Economy	16200.00
0005433285944	22548	Economy	16200.00
0005433009578	22548	Economy	16200.00
0005433285957	22548	Economy	16200.00
0005433285951	22548	Economy	16200.00
0005433009575	22548	Economy	16200.00
0005433009549	22548	Economy	16200.00
0005433285945	22548	Economy	16200.00
0005433285948	22548	Economy	16200.00
0005433009568	22548	Economy	16200.00
0005433009583	22548	Economy	16200.00
0005433009573	22548	Economy	16200.00
0005433810580	22548	Economy	16200.00
0005433810578	22548	Economy	16200.00
0005433009579	22548	Economy	16200.00
0005433009546	22548	Economy	16200.00
0005433009566	22548	Economy	16200.00
0005433009567	22548	Economy	16200.00
0005433285936	22548	Economy	16200.00
0005433009540	22548	Economy	16200.00
0005433285954	22548	Economy	16200.00
0005433009552	22548	Economy	16200.00
0005433009581	22548	Economy	16200.00
0005433009556	22548	Economy	16200.00
0005433285950	22548	Economy	16200.00
0005433009544	22548	Economy	16200.00
0005433009548	22548	Economy	16200.00
0005433285955	22548	Economy	16200.00
0005433009577	22548	Economy	16200.00
0005433285941	22548	Economy	16200.00
0005433285937	22548	Economy	16200.00
0005433285960	22548	Economy	16200.00
0005433009555	22548	Economy	16200.00
0005433009571	22548	Economy	16200.00
0005433009584	22548	Economy	16200.00
0005433009550	22548	Economy	16200.00
0005433009558	22548	Economy	16200.00
0005433285949	22548	Economy	16200.00
0005433009554	22548	Economy	16200.00
0005433285939	22548	Economy	16200.00
0005433009559	22548	Economy	16200.00
0005433285932	22548	Economy	16200.00
0005433009541	22548	Economy	16200.00
0005433285952	22548	Economy	16200.00
0005433009547	22548	Economy	16200.00
0005434152810	25332	Business	83800.00
0005434153543	25332	Economy	27900.00
0005432756912	25332	Economy	27900.00
0005432755140	25332	Economy	27900.00
0005434152809	25332	Economy	27900.00
0005434152807	25332	Economy	30700.00
0005432755136	25332	Economy	30700.00
0005434152815	25332	Economy	27900.00
0005434153545	25332	Economy	27900.00
0005432756909	25332	Economy	27900.00
0005434152813	25332	Economy	27900.00
0005432756911	25332	Economy	27900.00
0005432756910	25332	Economy	27900.00
0005434152812	25332	Economy	27900.00
0005432755143	25332	Economy	27900.00
0005432755137	25332	Economy	27900.00
0005432755139	25332	Economy	27900.00
0005434153541	25332	Economy	27900.00
0005432756914	25332	Economy	27900.00
0005434153540	25332	Economy	27900.00
0005432755142	25332	Economy	27900.00
0005434153544	25332	Economy	27900.00
0005432756915	25332	Economy	27900.00
0005434152811	25332	Economy	27900.00
0005432756908	25332	Economy	27900.00
0005432755138	25332	Economy	27900.00
0005434152804	25332	Economy	27900.00
0005432756913	25332	Economy	27900.00
0005432756916	25332	Economy	27900.00
0005432755141	25332	Economy	27900.00
0005434152805	25332	Economy	27900.00
0005432755144	25332	Economy	27900.00
0005434152808	25332	Economy	27900.00
0005433847983	5587	Business	99800.00
0005433815487	5587	Business	99800.00
0005433847991	5587	Business	99800.00
0005433847955	5587	Business	99800.00
0005433847946	5587	Business	99800.00
0005433847954	5587	Business	99800.00
0005433847952	5587	Business	99800.00
0005434173548	5587	Business	99800.00
0005434173547	5587	Business	99800.00
0005435282862	5587	Business	99800.00
0005433847986	5587	Business	99800.00
0005435282784	5587	Business	99800.00
0005433847940	5587	Business	99800.00
0005433815483	5587	Business	99800.00
0005432081652	5587	Business	99800.00
0005435282740	5587	Business	99800.00
0005435282772	5587	Business	99800.00
0005433847976	5587	Economy	33300.00
0005433847942	5587	Business	99800.00
0005433847953	5587	Economy	33300.00
0005435282865	5587	Economy	33300.00
0005433847959	5587	Economy	33300.00
0005433847975	5587	Economy	33300.00
0005435282857	5587	Economy	33300.00
0005433847978	5587	Economy	33300.00
0005433847944	5587	Economy	33300.00
0005434173572	5587	Economy	33300.00
0005433847993	5587	Economy	36600.00
0005433847958	5587	Economy	36600.00
0005432081647	5587	Economy	36600.00
0005433847965	5587	Economy	36600.00
0005433847956	5587	Economy	33300.00
0005433847950	5587	Economy	33300.00
0005432081649	5587	Economy	33300.00
0005433847964	5587	Economy	33300.00
0005433847988	5587	Economy	33300.00
0005433847982	5587	Economy	33300.00
0005433847985	5587	Economy	33300.00
0005432081651	5587	Economy	33300.00
0005433847966	5587	Economy	33300.00
0005433847989	5587	Economy	33300.00
0005433847951	5587	Economy	33300.00
0005433847960	5587	Economy	33300.00
0005433847969	5587	Economy	33300.00
0005433847990	5587	Economy	33300.00
0005433847967	5587	Economy	33300.00
0005433847973	5587	Economy	33300.00
0005433847992	5587	Economy	33300.00
0005432081648	5587	Economy	33300.00
0005433847948	5587	Economy	33300.00
0005432081646	5587	Economy	33300.00
0005433847941	5587	Economy	33300.00
0005433847963	5587	Economy	33300.00
0005433847981	5587	Economy	33300.00
0005435282757	5587	Economy	33300.00
0005433847977	5587	Economy	33300.00
0005435282761	5587	Economy	33300.00
0005433847979	5587	Economy	33300.00
0005435282803	5587	Economy	33300.00
0005435282762	5587	Economy	33300.00
0005433847972	5587	Economy	33300.00
0005433847957	5587	Economy	33300.00
0005433847943	5587	Economy	33300.00
0005433847984	5587	Economy	33300.00
0005433847970	5587	Economy	33300.00
0005435282860	5587	Economy	33300.00
0005435282756	5587	Economy	33300.00
0005433847938	5587	Economy	33300.00
0005433847968	5587	Economy	33300.00
0005435282844	5587	Economy	33300.00
0005433847939	5587	Economy	33300.00
0005433847935	5587	Economy	33300.00
0005435282783	5587	Economy	33300.00
0005432081650	5587	Economy	33300.00
0005435282802	5587	Economy	33300.00
0005435282861	5587	Economy	33300.00
0005435282842	5587	Economy	33300.00
0005433847934	5587	Economy	33300.00
0005433847971	5587	Economy	33300.00
0005433847936	5587	Economy	33300.00
0005435282741	5587	Economy	33300.00
0005433815484	5587	Economy	33300.00
0005435282840	5587	Economy	33300.00
0005433847945	5587	Economy	33300.00
0005435282866	5587	Economy	33300.00
0005433815485	5587	Economy	33300.00
0005434173566	5587	Economy	33300.00
0005433847937	5587	Economy	33300.00
0005435282843	5587	Economy	33300.00
0005435282686	5587	Economy	33300.00
0005433815486	5587	Economy	33300.00
0005433847962	5587	Economy	33300.00
0005433847961	5587	Economy	33300.00
0005435282841	5587	Economy	33300.00
0005433847974	5587	Economy	33300.00
0005433847947	5587	Economy	33300.00
0005433847980	5587	Economy	33300.00
0005435282767	5587	Economy	33300.00
0005435282798	5587	Economy	33300.00
0005433847987	5587	Economy	33300.00
0005433847949	5587	Economy	33300.00
0005435283035	13844	Business	99800.00
0005433847624	13844	Business	99800.00
0005432003769	13844	Business	99800.00
0005433847710	13844	Business	99800.00
0005435283044	13844	Business	99800.00
0005433847117	13844	Business	99800.00
0005435283032	13844	Business	99800.00
0005433847367	13844	Business	99800.00
0005433847282	13844	Business	99800.00
0005433847538	13844	Business	99800.00
0005433847735	13844	Business	99800.00
0005433847264	13844	Business	99800.00
0005433847741	13844	Business	99800.00
0005433847341	13844	Business	99800.00
0005435283036	13844	Business	99800.00
0005433847614	13844	Business	99800.00
0005433847295	13844	Economy	33300.00
0005433847737	13844	Economy	33300.00
0005435283025	13844	Economy	33300.00
0005433847560	13844	Economy	33300.00
0005433847558	13844	Economy	33300.00
0005433847476	13844	Economy	33300.00
0005433847296	13844	Economy	33300.00
0005435283028	13844	Economy	33300.00
0005433847423	13844	Economy	36600.00
0005435283038	13844	Economy	36600.00
0005435283040	13844	Economy	36600.00
0005435283034	13844	Economy	33300.00
0005433815456	13844	Economy	33300.00
0005433847550	13844	Economy	33300.00
0005435283030	13844	Economy	33300.00
0005433847419	13844	Economy	33300.00
0005433815453	13844	Economy	33300.00
0005433847157	13844	Economy	33300.00
0005433847501	13844	Economy	33300.00
0005433847504	13844	Economy	33300.00
0005435283019	13844	Economy	33300.00
0005433847477	13844	Economy	33300.00
0005433847562	13844	Economy	33300.00
0005433847375	13844	Economy	33300.00
0005434173606	13844	Economy	33300.00
0005433847584	13844	Economy	33300.00
0005433847368	13844	Economy	33300.00
0005435283023	13844	Economy	33300.00
0005434173607	13844	Economy	33300.00
0005435283031	13844	Economy	33300.00
0005433847621	13844	Economy	33300.00
0005433847628	13844	Economy	33300.00
0005433847392	13844	Economy	33300.00
0005435283017	13844	Economy	33300.00
0005433847116	13844	Economy	33300.00
0005434173608	13844	Economy	33300.00
0005433847620	13844	Economy	33300.00
0005433847648	13844	Economy	33300.00
0005435283041	13844	Economy	33300.00
0005435283042	13844	Economy	33300.00
0005433847629	13844	Economy	33300.00
0005433847218	13844	Economy	33300.00
0005435283018	13844	Economy	33300.00
0005433847506	13844	Economy	33300.00
0005433847559	13844	Economy	33300.00
0005433847625	13844	Economy	33300.00
0005435283024	13844	Economy	33300.00
0005435283027	13844	Economy	33300.00
0005435283039	13844	Economy	33300.00
0005434173637	13844	Economy	33300.00
0005433847644	13844	Economy	33300.00
0005433847493	13844	Economy	33300.00
0005435283033	13844	Economy	33300.00
0005435283021	13844	Economy	33300.00
0005433847845	13844	Economy	33300.00
0005433847630	13844	Economy	33300.00
0005435283029	13844	Economy	33300.00
0005433847556	13844	Economy	33300.00
0005433847422	13844	Economy	33300.00
0005434173636	13844	Economy	33300.00
0005435283037	13844	Economy	33300.00
0005433847340	13844	Economy	33300.00
0005433847407	13844	Economy	33300.00
0005433847555	13844	Economy	33300.00
0005433847736	13844	Economy	33300.00
0005435283016	13844	Economy	33300.00
0005433847615	13844	Economy	33300.00
0005435283022	13844	Economy	33300.00
0005433847265	13844	Economy	33300.00
0005432003768	13844	Economy	33300.00
0005433847360	13844	Economy	33300.00
0005435283043	13844	Economy	33300.00
0005435283020	13844	Economy	33300.00
0005435283026	13844	Economy	33300.00
0005433847458	13844	Economy	33300.00
0005435332459	7804	Economy	16600.00
0005434621025	7804	Economy	16600.00
0005434621027	7804	Economy	16600.00
0005434621040	7804	Economy	15100.00
0005434621021	7804	Economy	15100.00
0005434621036	7804	Economy	15100.00
0005434621023	7804	Economy	15100.00
0005434621038	7804	Economy	15100.00
0005434621024	7804	Economy	15100.00
0005434621034	7804	Economy	15100.00
0005432112563	7804	Economy	15100.00
0005434621028	7804	Economy	15100.00
0005434621031	7804	Economy	15100.00
0005434621041	7804	Economy	15100.00
0005432112564	7804	Economy	15100.00
0005434621022	7804	Economy	15100.00
0005435332460	7804	Economy	15100.00
0005434621039	7804	Economy	15100.00
0005432112565	7804	Economy	15100.00
0005434621030	7804	Economy	15100.00
0005434621037	7804	Economy	15100.00
0005434621033	7804	Economy	15100.00
0005434621026	7804	Economy	15100.00
0005434621035	7804	Economy	15100.00
0005435332476	7804	Economy	15100.00
0005434621029	7804	Economy	15100.00
0005435332466	7804	Economy	15100.00
0005434621032	7804	Economy	15100.00
0005434621042	7804	Economy	15100.00
0005434620898	32956	Economy	15100.00
0005435332561	32956	Economy	15100.00
0005434620918	32956	Economy	15100.00
0005435332558	32956	Economy	15100.00
0005435332559	32956	Economy	15100.00
0005435332554	32956	Economy	15100.00
0005434620828	32956	Economy	15100.00
0005435332552	32956	Economy	15100.00
0005435332555	32956	Economy	15100.00
0005434620891	32956	Economy	15100.00
0005434620867	32956	Economy	15100.00
0005434620890	32956	Economy	15100.00
0005434620761	32956	Economy	15100.00
0005435332553	32956	Economy	15100.00
0005434620889	32956	Economy	15100.00
0005435332556	32956	Economy	15100.00
0005434620837	32956	Economy	15100.00
0005435332560	32956	Economy	15100.00
0005435332551	32956	Economy	15100.00
0005434620903	32956	Economy	15100.00
0005434620769	32956	Economy	15100.00
0005434620815	32956	Economy	15100.00
0005435332557	32956	Economy	15100.00
0005434620838	32956	Economy	15100.00
0005434620813	32956	Economy	15100.00
0005434620917	32956	Economy	15100.00
0005434620816	32956	Economy	15100.00
0005435786102	4305	Business	38000.00
0005434994236	4305	Business	38000.00
0005435786083	4305	Business	38000.00
0005435786107	4305	Business	38000.00
0005435786082	4305	Business	38000.00
0005435918743	4305	Business	38000.00
0005435937425	4305	Business	38000.00
0005435786095	4305	Business	38000.00
0005435786089	4305	Business	38000.00
0005434994230	4305	Economy	12700.00
0005435937422	4305	Economy	12700.00
0005435786097	4305	Economy	12700.00
0005435786098	4305	Economy	12700.00
0005435937428	4305	Economy	12700.00
0005432190710	4305	Economy	12700.00
0005435918718	4305	Economy	12700.00
0005434994234	4305	Economy	12700.00
0005435918727	4305	Economy	12700.00
0005435786094	4305	Economy	13900.00
0005435786080	4305	Economy	13900.00
0005435786103	4305	Economy	12700.00
0005434994228	4305	Economy	12700.00
0005435786078	4305	Economy	12700.00
0005435786101	4305	Economy	12700.00
0005435786088	4305	Economy	12700.00
0005434994231	4305	Economy	12700.00
0005435787400	4305	Economy	12700.00
0005435786079	4305	Economy	12700.00
0005435786081	4305	Economy	12700.00
0005434994227	4305	Economy	12700.00
0005435787398	4305	Economy	12700.00
0005435787399	4305	Economy	12700.00
0005435937424	4305	Economy	12700.00
0005435786087	4305	Economy	12700.00
0005435918729	4305	Economy	12700.00
0005435786099	4305	Economy	12700.00
0005435786108	4305	Economy	12700.00
0005435786085	4305	Economy	12700.00
0005435786092	4305	Economy	12700.00
0005435786096	4305	Economy	12700.00
0005435918737	4305	Economy	12700.00
0005435786084	4305	Economy	12700.00
0005432190713	4305	Economy	12700.00
0005435786076	4305	Economy	12700.00
0005435786100	4305	Economy	12700.00
0005432190711	4305	Economy	12700.00
0005435786109	4305	Economy	12700.00
0005432190712	4305	Economy	12700.00
0005434994235	4305	Economy	12700.00
0005435786093	4305	Economy	12700.00
0005435786091	4305	Economy	12700.00
0005435786105	4305	Economy	12700.00
0005435937423	4305	Economy	12700.00
0005435918719	4305	Economy	12700.00
0005435786077	4305	Economy	12700.00
0005434994229	4305	Economy	12700.00
0005435918738	4305	Economy	12700.00
0005435786110	4305	Economy	12700.00
0005435786106	4305	Economy	12700.00
0005434994232	4305	Economy	12700.00
0005435786086	4305	Economy	12700.00
0005435786090	4305	Economy	12700.00
0005434994233	4305	Economy	12700.00
0005435786104	4305	Economy	12700.00
0005435937430	4305	Economy	12700.00
0005435918726	4305	Economy	12700.00
0005432195739	27301	Business	38000.00
0005435785746	27301	Business	38000.00
0005435785844	27301	Business	38000.00
0005435785678	27301	Business	38000.00
0005435785755	27301	Business	38000.00
0005435785826	27301	Business	38000.00
0005435785777	27301	Business	38000.00
0005435785475	27301	Business	38000.00
0005434994137	27301	Business	38000.00
0005435785763	27301	Economy	12700.00
0005434994170	27301	Economy	12700.00
0005434994172	27301	Economy	12700.00
0005435918759	27301	Economy	12700.00
0005435937482	27301	Economy	12700.00
0005434994148	27301	Economy	13900.00
0005435937471	27301	Economy	13900.00
0005435785737	27301	Economy	13900.00
0005435937477	27301	Economy	13900.00
0005435937480	27301	Economy	12700.00
0005435785465	27301	Economy	12700.00
0005435785802	27301	Economy	12700.00
0005435785778	27301	Economy	12700.00
0005435785476	27301	Economy	12700.00
0005434994147	27301	Economy	12700.00
0005435787385	27301	Economy	12700.00
0005435937479	27301	Economy	12700.00
0005434994126	27301	Economy	12700.00
0005435937481	27301	Economy	12700.00
0005435937483	27301	Economy	12700.00
0005435785811	27301	Economy	12700.00
0005435937472	27301	Economy	12700.00
0005435937474	27301	Economy	12700.00
0005435785712	27301	Economy	12700.00
0005435937484	27301	Economy	12700.00
0005434994171	27301	Economy	12700.00
0005432195738	27301	Economy	12700.00
0005435785764	27301	Economy	12700.00
0005435785631	27301	Economy	12700.00
0005434994138	27301	Economy	12700.00
0005435785724	27301	Economy	12700.00
0005435937476	27301	Economy	12700.00
0005435785738	27301	Economy	12700.00
0005435785863	27301	Economy	12700.00
0005434994142	27301	Economy	12700.00
0005434994136	27301	Economy	12700.00
0005435785765	27301	Economy	12700.00
0005435918758	27301	Economy	12700.00
0005434994177	27301	Economy	12700.00
0005435785710	27301	Economy	12700.00
0005435785680	27301	Economy	12700.00
0005434994089	27301	Economy	12700.00
0005435785843	27301	Economy	12700.00
0005435785766	27301	Economy	12700.00
0005434994125	27301	Economy	12700.00
0005435787386	27301	Economy	12700.00
0005435937473	27301	Economy	12700.00
0005435785806	27301	Economy	12700.00
0005435785681	27301	Economy	12700.00
0005435937475	27301	Economy	12700.00
0005435785745	27301	Economy	12700.00
0005435785756	27301	Economy	12700.00
0005435937478	27301	Economy	12700.00
0005435785682	27301	Economy	12700.00
0005435785611	27301	Economy	12700.00
0005432146242	19857	Economy	12800.00
0005432568931	4743	Business	40900.00
0005432568920	4743	Business	40900.00
0005432460984	4743	Business	40900.00
0005432568927	4743	Business	40900.00
0005432571403	4743	Business	40900.00
0005432568911	4743	Business	40900.00
0005432460962	4743	Business	40900.00
0005432460974	4743	Business	40900.00
0005434082422	4743	Business	40900.00
0005434082419	4743	Business	40900.00
0005432568946	4743	Business	40900.00
0005434082392	4743	Business	40900.00
0005432186947	4743	Business	40900.00
0005432460939	4743	Business	40900.00
0005432568914	4743	Business	40900.00
0005432460967	4743	Business	40900.00
0005434082402	4743	Business	40900.00
0005432568913	4743	Business	40900.00
0005432460943	4743	Business	40900.00
0005432460938	4743	Business	40900.00
0005432460970	4743	Business	40900.00
0005432568921	4743	Economy	15000.00
0005432568932	4743	Economy	15000.00
0005432568909	4743	Economy	15000.00
0005434082406	4743	Economy	15000.00
0005432568906	4743	Economy	13600.00
0005432460942	4743	Economy	13600.00
0005432460946	4743	Economy	13600.00
0005432568930	4743	Economy	13600.00
0005432460956	4743	Economy	13600.00
0005432568902	4743	Economy	13600.00
0005434082420	4743	Economy	13600.00
0005432568935	4743	Economy	13600.00
0005432568907	4743	Economy	13600.00
0005432568959	4743	Economy	13600.00
0005432568957	4743	Economy	13600.00
0005432186948	4743	Economy	13600.00
0005432460948	4743	Economy	13600.00
0005432460975	4743	Economy	13600.00
0005434082412	4743	Economy	13600.00
0005432460940	4743	Economy	13600.00
0005432460977	4743	Economy	13600.00
0005432568955	4743	Economy	13600.00
0005432568903	4743	Economy	13600.00
0005432568964	4743	Economy	13600.00
0005432568954	4743	Economy	13600.00
0005432460968	4743	Economy	13600.00
0005432568915	4743	Economy	13600.00
0005432170534	4743	Economy	13600.00
0005433451663	4743	Economy	13600.00
0005434082418	4743	Economy	13600.00
0005432568919	4743	Economy	13600.00
0005434082400	4743	Economy	13600.00
0005432568912	4743	Economy	13600.00
0005432568923	4743	Economy	13600.00
0005432568938	4743	Economy	13600.00
0005432460945	4743	Economy	13600.00
0005432170529	4743	Economy	13600.00
0005434082396	4743	Economy	13600.00
0005432568949	4743	Economy	13600.00
0005432568916	4743	Economy	13600.00
0005432568947	4743	Economy	13600.00
0005434082415	4743	Economy	13600.00
0005434082404	4743	Economy	13600.00
0005434082401	4743	Economy	13600.00
0005434082424	4743	Economy	13600.00
0005432568924	4743	Economy	13600.00
0005432170528	4743	Economy	13600.00
0005432460951	4743	Economy	13600.00
0005434082398	4743	Economy	13600.00
0005432460957	4743	Economy	13600.00
0005432568951	4743	Economy	13600.00
0005432571400	4743	Economy	13600.00
0005433726153	4743	Economy	13600.00
0005432170530	4743	Economy	13600.00
0005433726154	4743	Economy	13600.00
0005432460952	4743	Economy	13600.00
0005432568945	4743	Economy	13600.00
0005432568952	4743	Economy	13600.00
0005434082414	4743	Economy	13600.00
0005434082421	4743	Economy	13600.00
0005432568936	4743	Economy	13600.00
0005432460964	4743	Economy	13600.00
0005432460949	4743	Economy	13600.00
0005434559121	4743	Economy	13600.00
0005432568958	4743	Economy	13600.00
0005432170533	4743	Economy	13600.00
0005432460978	4743	Economy	13600.00
0005432571402	4743	Economy	13600.00
0005432568943	4743	Economy	13600.00
0005432460961	4743	Economy	13600.00
0005432460965	4743	Economy	13600.00
0005432460972	4743	Economy	13600.00
0005432568925	4743	Economy	13600.00
0005434082423	4743	Economy	13600.00
0005432568961	4743	Economy	13600.00
0005434082395	4743	Economy	13600.00
0005432568963	4743	Economy	13600.00
0005432460985	4743	Economy	13600.00
0005432460963	4743	Economy	13600.00
0005432460953	4743	Economy	13600.00
0005434082410	4743	Economy	13600.00
0005434082413	4743	Economy	13600.00
0005432568928	4743	Economy	13600.00
0005432568926	4743	Economy	13600.00
0005432460981	4743	Economy	13600.00
0005433726155	4743	Economy	15000.00
0005434082409	4743	Economy	15000.00
0005432568905	4743	Economy	13600.00
0005432460983	4743	Economy	13600.00
0005432568908	4743	Economy	13600.00
0005432568942	4743	Economy	15000.00
0005432568940	4743	Economy	13600.00
0005434082417	4743	Economy	15000.00
0005432568904	4743	Economy	13600.00
0005434082403	4743	Economy	13600.00
0005432568962	4743	Economy	13600.00
0005432460933	4743	Economy	13600.00
0005434082405	4743	Economy	13600.00
0005433726152	4743	Economy	13600.00
0005432568937	4743	Economy	13600.00
0005432460934	4743	Economy	13600.00
0005434082408	4743	Economy	13600.00
0005432460937	4743	Economy	13600.00
0005433452785	4743	Economy	13600.00
0005432186950	4743	Economy	13600.00
0005432460950	4743	Economy	13600.00
0005432568929	4743	Economy	13600.00
0005432460982	4743	Economy	13600.00
0005432568960	4743	Economy	13600.00
0005432568934	4743	Economy	13600.00
0005432460944	4743	Economy	13600.00
0005432568953	4743	Economy	13600.00
0005434082397	4743	Economy	13600.00
0005432460966	4743	Economy	13600.00
0005433451662	4743	Economy	13600.00
0005432460941	4743	Economy	13600.00
0005432460973	4743	Economy	13600.00
0005432186949	4743	Economy	13600.00
0005432460947	4743	Economy	13600.00
0005432568933	4743	Economy	13600.00
0005434082411	4743	Economy	13600.00
0005434082425	4743	Economy	13600.00
0005432460980	4743	Economy	13600.00
0005432170531	4743	Economy	13600.00
0005432460971	4743	Economy	13600.00
0005432460955	4743	Economy	13600.00
0005434082416	4743	Economy	13600.00
0005434082393	4743	Economy	13600.00
0005434082399	4743	Economy	13600.00
0005432460935	4743	Economy	13600.00
0005432568918	4743	Economy	13600.00
0005432460958	4743	Economy	13600.00
0005432568939	4743	Economy	13600.00
0005432568948	4743	Economy	13600.00
0005434082394	4743	Economy	13600.00
0005432460960	4743	Economy	13600.00
0005434082407	4743	Economy	13600.00
0005432568941	4743	Economy	13600.00
0005432460976	4743	Economy	13600.00
0005432568950	4743	Economy	13600.00
0005432460969	4743	Economy	13600.00
0005432568922	4743	Economy	13600.00
0005432568956	4743	Economy	13600.00
0005432568917	4743	Economy	13600.00
0005432460936	4743	Economy	13600.00
0005432568910	4743	Economy	13600.00
0005432170532	4743	Economy	13600.00
0005432460979	4743	Economy	13600.00
0005434559120	4743	Economy	13600.00
0005432460954	4743	Economy	13600.00
0005432460959	4743	Economy	13600.00
0005432571401	4743	Economy	13600.00
0005432568944	4743	Economy	13600.00
0005432460416	30554	Business	40900.00
0005434082210	30554	Business	40900.00
0005432460802	30554	Business	40900.00
0005432568769	30554	Business	40900.00
0005432460517	30554	Business	40900.00
0005434082130	30554	Business	40900.00
0005434082228	30554	Business	40900.00
0005432460491	30554	Business	40900.00
0005432460710	30554	Business	40900.00
0005432568303	30554	Business	40900.00
0005432213686	30554	Business	40900.00
0005432568323	30554	Business	40900.00
0005435840392	30554	Business	40900.00
0005432568421	30554	Business	40900.00
0005432460481	30554	Business	40900.00
0005432460555	30554	Business	40900.00
0005432460523	30554	Business	40900.00
0005432460545	30554	Business	40900.00
0005432460599	30554	Business	40900.00
0005432460602	30554	Business	40900.00
0005434082165	30554	Business	40900.00
0005432568302	30554	Business	40900.00
0005432568594	30554	Business	40900.00
0005432568516	30554	Economy	15000.00
0005434082161	30554	Economy	15000.00
0005432161201	30554	Economy	15000.00
0005432460548	30554	Economy	15000.00
0005432460417	30554	Economy	13600.00
0005435840396	30554	Economy	13600.00
0005433452764	30554	Economy	13600.00
0005432568741	30554	Economy	13600.00
0005432460687	30554	Economy	13600.00
0005434082160	30554	Economy	13600.00
0005432460674	30554	Economy	13600.00
0005434082138	30554	Economy	13600.00
0005432568505	30554	Economy	13600.00
0005432568593	30554	Economy	13600.00
0005432568277	30554	Economy	13600.00
0005432568441	30554	Economy	13600.00
0005432460587	30554	Economy	13600.00
0005432571379	30554	Economy	13600.00
0005432568254	30554	Economy	13600.00
0005434082163	30554	Economy	13600.00
0005432568545	30554	Economy	13600.00
0005432460630	30554	Economy	13600.00
0005432568486	30554	Economy	13600.00
0005432460529	30554	Economy	13600.00
0005432568454	30554	Economy	13600.00
0005435840393	30554	Economy	13600.00
0005432460554	30554	Economy	13600.00
0005434082230	30554	Economy	13600.00
0005432460518	30554	Economy	13600.00
0005432460516	30554	Economy	13600.00
0005434082243	30554	Economy	13600.00
0005432460601	30554	Economy	13600.00
0005432460632	30554	Economy	13600.00
0005432568523	30554	Economy	13600.00
0005432571376	30554	Economy	13600.00
0005432568440	30554	Economy	13600.00
0005432568500	30554	Economy	13600.00
0005432568580	30554	Economy	13600.00
0005432568503	30554	Economy	13600.00
0005432460593	30554	Economy	13600.00
0005432460549	30554	Economy	13600.00
0005432460256	30554	Economy	13600.00
0005432213687	30554	Economy	13600.00
0005432568414	30554	Economy	13600.00
0005432568546	30554	Economy	13600.00
0005432571377	30554	Economy	13600.00
0005432460600	30554	Economy	13600.00
0005434082166	30554	Economy	13600.00
0005432568717	30554	Economy	13600.00
0005434082209	30554	Economy	13600.00
0005432568415	30554	Economy	13600.00
0005435840394	30554	Economy	13600.00
0005432460631	30554	Economy	13600.00
0005432460483	30554	Economy	13600.00
0005432568371	30554	Economy	13600.00
0005432460398	30554	Economy	13600.00
0005434082156	30554	Economy	13600.00
0005432460419	30554	Economy	13600.00
0005432213685	30554	Economy	13600.00
0005432568507	30554	Economy	13600.00
0005432568416	30554	Economy	13600.00
0005432571383	30554	Economy	13600.00
0005434082177	30554	Economy	13600.00
0005432571382	30554	Economy	13600.00
0005432460520	30554	Economy	13600.00
0005432460467	30554	Economy	13600.00
0005432568536	30554	Economy	13600.00
0005434082199	30554	Economy	13600.00
0005434082196	30554	Economy	13600.00
0005432568596	30554	Economy	13600.00
0005432460592	30554	Economy	13600.00
0005432460695	30554	Economy	13600.00
0005434082157	30554	Economy	13600.00
0005435840395	30554	Economy	13600.00
0005432568320	30554	Economy	13600.00
0005432568541	30554	Economy	13600.00
0005435840390	30554	Economy	13600.00
0005432460484	30554	Economy	13600.00
0005432460586	30554	Economy	13600.00
0005435840398	30554	Economy	15000.00
0005432460519	30554	Economy	13600.00
0005432460455	30554	Economy	13600.00
0005432460626	30554	Economy	15000.00
0005435840397	30554	Economy	13600.00
0005434082087	30554	Economy	13600.00
0005432568714	30554	Economy	13600.00
0005432460758	30554	Economy	13600.00
0005434082176	30554	Economy	13600.00
0005432568597	30554	Economy	13600.00
0005432568681	30554	Economy	13600.00
0005432568742	30554	Economy	13600.00
0005432568455	30554	Economy	13600.00
0005432161202	30554	Economy	13600.00
0005432568448	30554	Economy	13600.00
0005432568240	30554	Economy	13600.00
0005432460613	30554	Economy	13600.00
0005434082242	30554	Economy	13600.00
0005434082229	30554	Economy	13600.00
0005432460711	30554	Economy	13600.00
0005433452762	30554	Economy	13600.00
0005432568424	30554	Economy	13600.00
0005435840389	30554	Economy	13600.00
0005432568466	30554	Economy	13600.00
0005432568537	30554	Economy	13600.00
0005432460565	30554	Economy	13600.00
0005434082194	30554	Economy	13600.00
0005432460117	30554	Economy	13600.00
0005432161200	30554	Economy	13600.00
0005432460257	30554	Economy	13600.00
0005432460550	30554	Economy	13600.00
0005432460642	30554	Economy	13600.00
0005435840391	30554	Economy	13600.00
0005434082195	30554	Economy	13600.00
0005434082237	30554	Economy	13600.00
0005435840400	30554	Economy	13600.00
0005432460712	30554	Economy	13600.00
0005432460809	30554	Economy	13600.00
0005432568298	30554	Economy	13600.00
0005434082159	30554	Economy	13600.00
0005432568543	30554	Economy	13600.00
0005434082129	30554	Economy	13600.00
0005432460116	30554	Economy	13600.00
0005432568449	30554	Economy	13600.00
0005432568586	30554	Economy	13600.00
0005433452768	30554	Economy	13600.00
0005432460439	30554	Economy	13600.00
0005434082187	30554	Economy	13600.00
0005432460643	30554	Economy	13600.00
0005433454909	30554	Economy	13600.00
0005434082212	30554	Economy	13600.00
0005432568657	30554	Economy	13600.00
0005432568293	30554	Economy	13600.00
0005432568508	30554	Economy	13600.00
0005432568808	30554	Economy	13600.00
0005435840399	30554	Economy	13600.00
0005434082164	30554	Economy	13600.00
0005432568540	30554	Economy	13600.00
0005432460688	30554	Economy	13600.00
0005432568422	30554	Economy	13600.00
0005432568423	30554	Economy	13600.00
0005432568272	30554	Economy	13600.00
0005435722105	13626	Economy	9900.00
0005435722106	13626	Economy	9900.00
0005435720848	13626	Economy	9900.00
0005435722107	13626	Economy	9900.00
0005435722081	21194	Economy	9900.00
0005435722091	21194	Economy	9900.00
0005435722083	21194	Economy	9900.00
0005435722085	21194	Economy	9900.00
0005435722084	21194	Economy	9900.00
0005435722078	21194	Economy	9900.00
0005432295937	22808	Economy	9700.00
0005432295935	22808	Economy	8800.00
0005432295936	22808	Economy	8800.00
0005435508503	11086	Business	23600.00
0005433345348	11086	Business	23600.00
0005433345287	11086	Business	23600.00
0005433345273	11086	Business	23600.00
0005433345341	11086	Business	23600.00
0005433345253	11086	Business	23600.00
0005433345311	11086	Business	23600.00
0005433345295	11086	Business	23600.00
0005433345254	11086	Business	23600.00
0005433345256	11086	Business	23600.00
0005435508494	11086	Business	23600.00
0005435380327	11086	Business	23600.00
0005433345258	11086	Economy	7900.00
0005435380339	11086	Economy	7900.00
0005433345310	11086	Economy	7900.00
0005433345290	11086	Economy	7900.00
0005435508501	11086	Economy	7900.00
0005433345255	11086	Economy	7900.00
0005433345286	11086	Economy	7900.00
0005433345301	11086	Economy	7900.00
0005435508504	11086	Economy	7900.00
0005435508419	11086	Economy	7900.00
0005433345250	11086	Economy	7900.00
0005435508490	11086	Economy	7900.00
0005433345334	11086	Economy	7900.00
0005433345345	11086	Economy	7900.00
0005435097407	11086	Economy	7900.00
0005433345337	11086	Economy	7900.00
0005433345302	11086	Economy	7900.00
0005433345252	11086	Economy	7900.00
0005433345296	11086	Economy	7900.00
0005433345347	11086	Economy	7900.00
0005433345316	11086	Economy	7900.00
0005435508511	11086	Economy	7900.00
0005435508491	11086	Economy	7900.00
0005433345320	11086	Economy	7900.00
0005435097411	11086	Economy	7900.00
0005433345305	11086	Economy	7900.00
0005435508452	11086	Economy	7900.00
0005433345297	11086	Economy	7900.00
0005433345272	11086	Economy	7900.00
0005433345299	11086	Economy	7900.00
0005433345251	11086	Economy	7900.00
0005433345346	11086	Economy	7900.00
0005435508495	11086	Economy	7900.00
0005433345260	11086	Economy	7900.00
0005433345333	11086	Economy	7900.00
0005433345312	11086	Economy	7900.00
0005433345324	11086	Economy	7900.00
0005433345303	11086	Economy	7900.00
0005435097405	11086	Economy	7900.00
0005435508466	11086	Economy	7900.00
0005433345264	11086	Economy	8600.00
0005435097414	11086	Economy	8600.00
0005433345327	11086	Economy	8600.00
0005433345283	11086	Economy	8600.00
0005433345282	11086	Economy	8600.00
0005433345276	11086	Economy	8600.00
0005433345330	11086	Economy	7900.00
0005433345317	11086	Economy	7900.00
0005433345271	11086	Economy	7900.00
0005433345325	11086	Economy	7900.00
0005435508493	11086	Economy	7900.00
0005435097410	11086	Economy	7900.00
0005433345306	11086	Economy	7900.00
0005435097408	11086	Economy	7900.00
0005433345275	11086	Economy	7900.00
0005433345274	11086	Economy	7900.00
0005433345270	11086	Economy	7900.00
0005433345257	11086	Economy	7900.00
0005433345323	11086	Economy	7900.00
0005433345344	11086	Economy	7900.00
0005433345307	11086	Economy	7900.00
0005433345262	11086	Economy	7900.00
0005433345278	11086	Economy	7900.00
0005433345322	11086	Economy	7900.00
0005433345261	11086	Economy	7900.00
0005433345281	11086	Economy	7900.00
0005433345249	11086	Economy	7900.00
0005433345277	11086	Economy	7900.00
0005435097409	11086	Economy	7900.00
0005433345331	11086	Economy	7900.00
0005433345285	11086	Economy	7900.00
0005433345269	11086	Economy	7900.00
0005433345291	11086	Economy	7900.00
0005433345332	11086	Economy	7900.00
0005433345318	11086	Economy	7900.00
0005433345309	11086	Economy	7900.00
0005433345308	11086	Economy	7900.00
0005433345321	11086	Economy	7900.00
0005433345315	11086	Economy	7900.00
0005433345284	11086	Economy	7900.00
0005433345279	11086	Economy	7900.00
0005435508502	11086	Economy	7900.00
0005433345292	11086	Economy	7900.00
0005435380360	11086	Economy	7900.00
0005433345329	11086	Economy	7900.00
0005433345268	11086	Economy	7900.00
0005433345288	11086	Economy	7900.00
0005433345319	11086	Economy	7900.00
0005433345328	11086	Economy	7900.00
0005433345266	11086	Economy	7900.00
0005433345294	11086	Economy	7900.00
0005433345336	11086	Economy	7900.00
0005435097413	11086	Economy	7900.00
0005435380338	11086	Economy	7900.00
0005433345343	11086	Economy	7900.00
0005435380359	11086	Economy	7900.00
0005433345313	11086	Economy	7900.00
0005433345326	11086	Economy	7900.00
0005435380364	11086	Economy	7900.00
0005433345335	11086	Economy	7900.00
0005433345293	11086	Economy	7900.00
0005433345338	11086	Economy	7900.00
0005433345263	11086	Economy	7900.00
0005435508418	11086	Economy	7900.00
0005433345339	11086	Economy	7900.00
0005433345314	11086	Economy	7900.00
0005433345280	11086	Economy	7900.00
0005433345298	11086	Economy	7900.00
0005433345342	11086	Economy	7900.00
0005433345340	11086	Economy	7900.00
0005433345265	11086	Economy	7900.00
0005433345267	11086	Economy	7900.00
0005433345300	11086	Economy	7900.00
0005435097412	11086	Economy	7900.00
0005433345304	11086	Economy	7900.00
0005435097406	11086	Economy	7900.00
0005433345289	11086	Economy	7900.00
0005433345259	11086	Economy	7900.00
0005433344734	17139	Business	23600.00
0005433344299	17139	Business	23600.00
0005433344283	17139	Business	23600.00
0005433344273	17139	Business	23600.00
0005433344596	17139	Business	23600.00
0005433344280	17139	Business	23600.00
0005433344390	17139	Business	23600.00
0005435545890	17139	Business	23600.00
0005435380406	17139	Business	23600.00
0005433344563	17139	Business	23600.00
0005433344096	17139	Business	23600.00
0005433344536	17139	Business	23600.00
0005433344529	17139	Economy	7900.00
0005433343932	17139	Economy	7900.00
0005435380408	17139	Economy	7900.00
0005433344378	17139	Economy	7900.00
0005435097346	17139	Economy	7900.00
0005433344835	17139	Economy	7900.00
0005433344140	17139	Economy	7900.00
0005433344300	17139	Economy	7900.00
0005433344377	17139	Economy	7900.00
0005435380403	17139	Economy	7900.00
0005435545891	17139	Economy	7900.00
0005433344212	17139	Economy	7900.00
0005433344223	17139	Economy	7900.00
0005433344718	17139	Economy	7900.00
0005433344298	17139	Economy	7900.00
0005433344692	17139	Economy	7900.00
0005435097348	17139	Economy	7900.00
0005435097340	17139	Economy	7900.00
0005435097323	17139	Economy	7900.00
0005433343848	17139	Economy	7900.00
0005433344248	17139	Economy	7900.00
0005435380405	17139	Economy	7900.00
0005433344216	17139	Economy	7900.00
0005433344492	17139	Economy	7900.00
0005433344295	17139	Economy	7900.00
0005435097347	17139	Economy	7900.00
0005433344141	17139	Economy	7900.00
0005435097317	17139	Economy	7900.00
0005435545896	17139	Economy	7900.00
0005435097342	17139	Economy	7900.00
0005433344343	17139	Economy	7900.00
0005433344252	17139	Economy	7900.00
0005433344041	17139	Economy	7900.00
0005433343688	17139	Economy	7900.00
0005433344451	17139	Economy	7900.00
0005433344623	17139	Economy	7900.00
0005433344537	17139	Economy	7900.00
0005433344185	17139	Economy	7900.00
0005433343687	17139	Economy	7900.00
0005433344554	17139	Economy	7900.00
0005432293261	17139	Economy	8600.00
0005433344445	17139	Economy	8600.00
0005433344463	17139	Economy	8600.00
0005435380407	17139	Economy	8600.00
0005433344201	17139	Economy	8600.00
0005433344530	17139	Economy	8600.00
0005435097324	17139	Economy	7900.00
0005433344405	17139	Economy	7900.00
0005433344187	17139	Economy	7900.00
0005433344224	17139	Economy	7900.00
0005433344110	17139	Economy	7900.00
0005433344042	17139	Economy	7900.00
0005433344507	17139	Economy	7900.00
0005433344567	17139	Economy	7900.00
0005433344297	17139	Economy	7900.00
0005435545898	17139	Economy	7900.00
0005433344564	17139	Economy	7900.00
0005433344364	17139	Economy	7900.00
0005435545897	17139	Economy	7900.00
0005433344279	17139	Economy	7900.00
0005433343891	17139	Economy	7900.00
0005435380404	17139	Economy	7900.00
0005433344352	17139	Economy	7900.00
0005433344553	17139	Economy	7900.00
0005435545895	17139	Economy	7900.00
0005433344126	17139	Economy	7900.00
0005433344186	17139	Economy	7900.00
0005433344391	17139	Economy	7900.00
0005433344370	17139	Economy	7900.00
0005432293260	17139	Economy	7900.00
0005433344394	17139	Economy	7900.00
0005433344020	17139	Economy	7900.00
0005433344496	17139	Economy	7900.00
0005433343689	17139	Economy	7900.00
0005433344452	17139	Economy	7900.00
0005433344371	17139	Economy	7900.00
0005433344164	17139	Economy	7900.00
0005433344464	17139	Economy	7900.00
0005433344226	17139	Economy	7900.00
0005433344395	17139	Economy	7900.00
0005433344057	17139	Economy	7900.00
0005433344321	17139	Economy	7900.00
0005433344213	17139	Economy	7900.00
0005433344268	17139	Economy	7900.00
0005433344363	17139	Economy	7900.00
0005433344659	17139	Economy	7900.00
0005433344719	17139	Economy	7900.00
0005433344410	17139	Economy	7900.00
0005433344465	17139	Economy	7900.00
0005435097327	17139	Economy	7900.00
0005433344461	17139	Economy	7900.00
0005433344539	17139	Economy	7900.00
0005435545894	17139	Economy	7900.00
0005433344310	17139	Economy	7900.00
0005435545892	17139	Economy	7900.00
0005433344309	17139	Economy	7900.00
0005433344427	17139	Economy	7900.00
0005433344490	17139	Economy	7900.00
0005435097328	17139	Economy	7900.00
0005433344512	17139	Economy	7900.00
0005433344538	17139	Economy	7900.00
0005435097316	17139	Economy	7900.00
0005433344313	17139	Economy	7900.00
0005433344120	17139	Economy	7900.00
0005433344225	17139	Economy	7900.00
0005433344267	17139	Economy	7900.00
0005433344476	17139	Economy	7900.00
0005433344418	17139	Economy	7900.00
0005433344142	17139	Economy	7900.00
0005433344251	17139	Economy	7900.00
0005433343870	17139	Economy	7900.00
0005433344705	17139	Economy	7900.00
0005433344342	17139	Economy	7900.00
0005435545893	17139	Economy	7900.00
0005433344238	17139	Economy	7900.00
0005435097326	17139	Economy	7900.00
0005433344294	17139	Economy	7900.00
0005432920128	9105	Business	26600.00
0005432920178	9105	Business	26600.00
0005433481333	9105	Business	26600.00
0005433477031	9105	Business	26600.00
0005433477027	9105	Business	26600.00
0005432920129	9105	Business	26600.00
0005433477020	9105	Business	26600.00
0005432920120	9105	Business	26600.00
0005432920176	9105	Business	26600.00
0005433507569	9105	Business	26600.00
0005433481331	9105	Business	26600.00
0005432920066	9105	Economy	8900.00
0005433481334	9105	Economy	8900.00
0005433507564	9105	Economy	8900.00
0005432920067	9105	Economy	8900.00
0005433507575	9105	Economy	8900.00
0005433477032	9105	Economy	8900.00
0005432920064	9105	Economy	8900.00
0005433481330	9105	Economy	9800.00
0005432920113	9105	Economy	9800.00
0005433477016	9105	Economy	9800.00
0005432920111	9105	Economy	8900.00
0005433507559	9105	Economy	8900.00
0005433477028	9105	Economy	8900.00
0005432920077	9105	Economy	8900.00
0005433477021	9105	Economy	8900.00
0005433507566	9105	Economy	8900.00
0005433477023	9105	Economy	8900.00
0005433481336	9105	Economy	8900.00
0005433507563	9105	Economy	8900.00
0005433507565	9105	Economy	8900.00
0005433477018	9105	Economy	8900.00
0005433477030	9105	Economy	8900.00
0005432920060	9105	Economy	8900.00
0005432920125	9105	Economy	8900.00
0005432920084	9105	Economy	8900.00
0005433477029	9105	Economy	8900.00
0005433477024	9105	Economy	8900.00
0005433507573	9105	Economy	8900.00
0005434159000	9105	Economy	8900.00
0005433507578	9105	Economy	8900.00
0005432920175	9105	Economy	8900.00
0005433507562	9105	Economy	8900.00
0005433477019	9105	Economy	8900.00
0005432920158	9105	Economy	8900.00
0005433507558	9105	Economy	8900.00
0005433477015	9105	Economy	8900.00
0005433477026	9105	Economy	8900.00
0005433477025	9105	Economy	8900.00
0005433507574	9105	Economy	8900.00
0005433481332	9105	Economy	8900.00
0005433477017	9105	Economy	8900.00
0005433507577	9105	Economy	8900.00
0005433507572	9105	Economy	8900.00
0005432920123	9105	Economy	8900.00
0005432920112	9105	Economy	8900.00
0005433507560	9105	Economy	8900.00
0005433507570	9105	Economy	8900.00
0005433507567	9105	Economy	8900.00
0005432920121	9105	Economy	8900.00
0005433481335	9105	Economy	8900.00
0005433507561	9105	Economy	8900.00
0005433507576	9105	Economy	8900.00
0005432920075	9105	Economy	8900.00
0005433481337	9105	Economy	8900.00
0005433507571	9105	Economy	8900.00
0005432920151	9105	Economy	8900.00
0005433507568	9105	Economy	8900.00
0005433477022	9105	Economy	8900.00
0005432920091	9105	Economy	8900.00
0005432920061	9105	Economy	8900.00
0005432920122	9105	Economy	8900.00
0005432920150	9105	Economy	8900.00
0005433507503	20472	Business	26600.00
0005432920318	20472	Business	26600.00
0005432920328	20472	Business	26600.00
0005433507394	20472	Business	26600.00
0005432920331	20472	Business	26600.00
0005432920320	20472	Economy	8900.00
0005433507413	20472	Economy	8900.00
0005432920336	20472	Economy	8900.00
0005434159025	20472	Economy	8900.00
0005432920325	20472	Economy	8900.00
0005432920335	20472	Economy	8900.00
0005433507422	20472	Economy	9800.00
0005433507414	20472	Economy	9800.00
0005432920332	20472	Economy	9800.00
0005433507427	20472	Economy	8900.00
0005433481278	20472	Economy	8900.00
0005432920334	20472	Economy	8900.00
0005433481262	20472	Economy	8900.00
0005434159022	20472	Economy	8900.00
0005433481277	20472	Economy	8900.00
0005433507442	20472	Economy	8900.00
0005432920319	20472	Economy	8900.00
0005434159027	20472	Economy	8900.00
0005433507399	20472	Economy	8900.00
0005433507504	20472	Economy	8900.00
0005432920330	20472	Economy	8900.00
0005432920324	20472	Economy	8900.00
0005432920333	20472	Economy	8900.00
0005433507412	20472	Economy	8900.00
0005433507400	20472	Economy	8900.00
0005432920326	20472	Economy	8900.00
0005433507431	20472	Economy	8900.00
0005434159023	20472	Economy	8900.00
0005433481241	20472	Economy	8900.00
0005433507421	20472	Economy	8900.00
0005433507430	20472	Economy	8900.00
0005432920327	20472	Economy	8900.00
0005434159028	20472	Economy	8900.00
0005434159024	20472	Economy	8900.00
0005432920317	20472	Economy	8900.00
0005433507423	20472	Economy	8900.00
0005433481290	20472	Economy	8900.00
0005432920323	20472	Economy	8900.00
0005433481320	20472	Economy	8900.00
0005434159026	20472	Economy	8900.00
0005433507445	20472	Economy	8900.00
0005433481289	20472	Economy	8900.00
0005432920321	20472	Economy	8900.00
0005432920322	20472	Economy	8900.00
0005432920329	20472	Economy	8900.00
0005433507428	20472	Economy	8900.00
0005432396324	10132	Economy	5800.00
0005432396322	10132	Economy	5800.00
0005432394185	10132	Economy	5800.00
0005435179001	10132	Economy	5800.00
0005435179000	10132	Economy	5800.00
0005432396321	10132	Economy	5800.00
0005435179002	10132	Economy	5800.00
0005432394189	10132	Economy	5800.00
0005432394188	10132	Economy	5800.00
0005432394186	10132	Economy	5800.00
0005432396323	10132	Economy	5800.00
0005432394187	10132	Economy	5800.00
0005435179707	18285	Economy	5800.00
0005432396288	18285	Economy	5800.00
0005435179709	18285	Economy	5800.00
0005432396289	18285	Economy	5800.00
0005435179414	18285	Economy	5800.00
0005435179706	18285	Economy	5800.00
0005432396284	18285	Economy	5800.00
0005432400188	18285	Economy	5800.00
0005432400180	18285	Economy	5800.00
0005435179708	18285	Economy	5800.00
0005432396310	18285	Economy	5800.00
0005435126851	10951	Business	9500.00
0005435126977	10951	Business	9500.00
0005435126760	10951	Business	9500.00
0005435126831	10951	Business	9500.00
0005435126886	10951	Business	9500.00
0005435126655	10951	Business	9500.00
0005435126722	10951	Business	9500.00
0005435126833	10951	Business	9500.00
0005435126885	10951	Business	9500.00
0005435626397	10951	Business	9500.00
0005435126916	10951	Business	9500.00
0005435626241	10951	Economy	3200.00
0005435126938	10951	Economy	3200.00
0005435626354	10951	Economy	3200.00
0005434928363	10951	Economy	3200.00
0005435126690	10951	Economy	3200.00
0005434928361	10951	Economy	3200.00
0005435126942	10951	Economy	3200.00
0005434411871	10951	Economy	3200.00
0005435626402	10951	Economy	3200.00
0005435126950	10951	Economy	3500.00
0005435127019	10951	Economy	3500.00
0005435126759	10951	Economy	3500.00
0005435126982	10951	Economy	3500.00
0005435126749	10951	Economy	3200.00
0005435127048	10951	Economy	3200.00
0005435126874	10951	Economy	3200.00
0005435626370	10951	Economy	3200.00
0005434411873	10951	Economy	3200.00
0005435126981	10951	Economy	3200.00
0005435626393	10951	Economy	3200.00
0005435126656	10951	Economy	3200.00
0005435626391	10951	Economy	3200.00
0005435126832	10951	Economy	3200.00
0005435126908	10951	Economy	3200.00
0005435626390	10951	Economy	3200.00
0005434928362	10951	Economy	3200.00
0005435126794	10951	Economy	3200.00
0005435626404	10951	Economy	3200.00
0005435126873	10951	Economy	3200.00
0005435127059	10951	Economy	3200.00
0005435626405	10951	Economy	3200.00
0005435126915	10951	Economy	3200.00
0005435126774	10951	Economy	3200.00
0005435127020	10951	Economy	3200.00
0005435126939	10951	Economy	3200.00
0005434411870	10951	Economy	3200.00
0005435626330	10951	Economy	3200.00
0005435126840	10951	Economy	3200.00
0005435126904	10951	Economy	3200.00
0005435126926	10951	Economy	3200.00
0005435126657	10951	Economy	3200.00
0005435126905	10951	Economy	3200.00
0005435126883	10951	Economy	3200.00
0005435126914	10951	Economy	3200.00
0005435126880	10951	Economy	3200.00
0005435556720	10951	Economy	3200.00
0005435126910	10951	Economy	3200.00
0005435126750	10951	Economy	3200.00
0005435126872	10951	Economy	3200.00
0005435626398	10951	Economy	3200.00
0005435126884	10951	Economy	3200.00
0005435126954	10951	Economy	3200.00
0005435126948	10951	Economy	3200.00
0005435126841	10951	Economy	3200.00
0005434928360	10951	Economy	3200.00
0005435126842	10951	Economy	3200.00
0005435126907	10951	Economy	3200.00
0005434411869	10951	Economy	3200.00
0005435626403	10951	Economy	3200.00
0005435126792	10951	Economy	3200.00
0005434411872	10951	Economy	3200.00
0005435626384	10951	Economy	3200.00
0005435554242	10951	Economy	3200.00
0005435126670	10951	Economy	3200.00
0005435126909	10951	Economy	3200.00
0005435556719	10951	Economy	3200.00
0005435126887	10951	Economy	3200.00
0005435126787	10951	Economy	3200.00
0005435554224	10951	Economy	3200.00
0005435554241	10951	Economy	3200.00
0005435126949	10951	Economy	3200.00
0005435127259	14739	Business	9500.00
0005435127249	14739	Business	9500.00
0005435626583	14739	Business	9500.00
0005434928334	14739	Business	9500.00
0005435127246	14739	Business	9500.00
0005435127241	14739	Business	9500.00
0005435554289	14739	Business	9500.00
0005435626570	14739	Business	9500.00
0005435127237	14739	Business	9500.00
0005435626585	14739	Business	9500.00
0005435127238	14739	Economy	3200.00
0005435626575	14739	Economy	3200.00
0005435127257	14739	Economy	3200.00
0005435127231	14739	Economy	3200.00
0005435554290	14739	Economy	3200.00
0005435626565	14739	Economy	3200.00
0005435554291	14739	Economy	3500.00
0005435626581	14739	Economy	3500.00
0005435127234	14739	Economy	3200.00
0005435556747	14739	Economy	3200.00
0005435127254	14739	Economy	3200.00
0005435127235	14739	Economy	3200.00
0005435127268	14739	Economy	3200.00
0005435127252	14739	Economy	3200.00
0005435127267	14739	Economy	3200.00
0005435127242	14739	Economy	3200.00
0005435127256	14739	Economy	3200.00
0005435626577	14739	Economy	3200.00
0005435127248	14739	Economy	3200.00
0005435626573	14739	Economy	3200.00
0005435626562	14739	Economy	3200.00
0005435127232	14739	Economy	3200.00
0005435127229	14739	Economy	3200.00
0005435127269	14739	Economy	3200.00
0005435127266	14739	Economy	3200.00
0005435626567	14739	Economy	3200.00
0005435127240	14739	Economy	3200.00
0005435554288	14739	Economy	3200.00
0005435626574	14739	Economy	3200.00
0005435127258	14739	Economy	3200.00
0005435626563	14739	Economy	3200.00
0005435127233	14739	Economy	3200.00
0005435626576	14739	Economy	3200.00
0005435127243	14739	Economy	3200.00
0005435127251	14739	Economy	3200.00
0005435127244	14739	Economy	3200.00
0005435127245	14739	Economy	3200.00
0005435626582	14739	Economy	3200.00
0005435626568	14739	Economy	3200.00
0005435626578	14739	Economy	3200.00
0005434928339	14739	Economy	3200.00
0005435127236	14739	Economy	3200.00
0005435626564	14739	Economy	3200.00
0005435127262	14739	Economy	3200.00
0005435127264	14739	Economy	3200.00
0005435556746	14739	Economy	3200.00
0005435127253	14739	Economy	3200.00
0005435127261	14739	Economy	3200.00
0005435127250	14739	Economy	3200.00
0005435127263	14739	Economy	3200.00
0005435626584	14739	Economy	3200.00
0005435554287	14739	Economy	3200.00
0005435127239	14739	Economy	3200.00
0005435556745	14739	Economy	3200.00
0005435127260	14739	Economy	3200.00
0005435626571	14739	Economy	3200.00
0005435626569	14739	Economy	3200.00
0005435127255	14739	Economy	3200.00
0005435626566	14739	Economy	3200.00
0005435554286	14739	Economy	3200.00
0005435127247	14739	Economy	3200.00
0005435626572	14739	Economy	3200.00
0005435127230	14739	Economy	3200.00
0005435127265	14739	Economy	3200.00
0005435626579	14739	Economy	3200.00
0005435626580	14739	Economy	3200.00
0005435443407	7146	Business	86900.00
0005435443397	7146	Business	86900.00
0005435715829	7146	Business	86900.00
0005435221065	7146	Business	86900.00
0005435221064	7146	Economy	29000.00
0005435715842	7146	Economy	29000.00
0005435715836	7146	Economy	29000.00
0005432400206	7146	Economy	29000.00
0005435715839	7146	Economy	31900.00
0005435219229	7146	Economy	31900.00
0005435443396	7146	Economy	29000.00
0005435715835	7146	Economy	29000.00
0005435715838	7146	Economy	29000.00
0005435443417	7146	Economy	29000.00
0005435715841	7146	Economy	29000.00
0005435443418	7146	Economy	29000.00
0005435443403	7146	Economy	29000.00
0005435715833	7146	Economy	29000.00
0005435443441	7146	Economy	29000.00
0005435715840	7146	Economy	29000.00
0005435715844	7146	Economy	29000.00
0005435178518	7146	Economy	29000.00
0005432400203	7146	Economy	29000.00
0005435715832	7146	Economy	29000.00
0005432398277	7146	Economy	29000.00
0005435715834	7146	Economy	29000.00
0005435715830	7146	Economy	29000.00
0005435443449	7146	Economy	29000.00
0005432398278	7146	Economy	29000.00
0005435219228	7146	Economy	29000.00
0005432400204	7146	Economy	29000.00
0005435715831	7146	Economy	29000.00
0005435715843	7146	Economy	29000.00
0005435715837	7146	Economy	29000.00
0005435443442	7146	Economy	29000.00
0005435715845	7146	Economy	29000.00
0005432400205	7146	Economy	29000.00
0005432398276	7146	Economy	29000.00
0005435443423	7146	Economy	29000.00
0005432394140	27084	Business	86900.00
0005432398252	27084	Business	86900.00
0005435715690	27084	Business	86900.00
0005435443514	27084	Business	86900.00
0005435715718	27084	Economy	29000.00
0005435715688	27084	Economy	29000.00
0005435715668	27084	Economy	29000.00
0005435443519	27084	Economy	29000.00
0005435178527	27084	Economy	29000.00
0005432394163	27084	Economy	31900.00
0005432394164	27084	Economy	29000.00
0005432398255	27084	Economy	29000.00
0005432394139	27084	Economy	29000.00
0005432394132	27084	Economy	29000.00
0005435443513	27084	Economy	29000.00
0005435715704	27084	Economy	29000.00
0005435715763	27084	Economy	29000.00
0005435715687	27084	Economy	29000.00
0005432394157	27084	Economy	29000.00
0005435715701	27084	Economy	29000.00
0005435443517	27084	Economy	29000.00
0005435443518	27084	Economy	29000.00
0005435715719	27084	Economy	29000.00
0005435715764	27084	Economy	29000.00
0005435715634	27084	Economy	29000.00
0005432398253	27084	Economy	29000.00
0005435715689	27084	Economy	29000.00
0005435443515	27084	Economy	29000.00
0005435715705	27084	Economy	29000.00
0005435443512	27084	Economy	29000.00
0005435715635	27084	Economy	29000.00
0005435443511	27084	Economy	29000.00
0005435443520	27084	Economy	29000.00
0005435715669	27084	Economy	29000.00
0005435443516	27084	Economy	29000.00
0005432394149	27084	Economy	29000.00
0005432394142	27084	Economy	29000.00
0005434085028	2703	Economy	7700.00
0005434085032	2703	Economy	7700.00
0005434085030	2703	Economy	7700.00
0005433060448	2703	Economy	7700.00
0005434085029	2703	Economy	7700.00
0005434085031	2703	Economy	7700.00
0005434084996	28485	Economy	7700.00
0005434084989	28485	Economy	7700.00
0005433060470	28485	Economy	7700.00
0005434084986	28485	Economy	7700.00
0005433060472	28485	Economy	7700.00
0005433060471	28485	Economy	7700.00
0005432632871	25194	Economy	29000.00
0005432632872	25194	Economy	29000.00
0005432632868	25194	Economy	29000.00
0005435844351	25194	Economy	26400.00
0005432632873	25194	Economy	26400.00
0005435844353	25194	Economy	26400.00
0005432632876	25194	Economy	26400.00
0005435844350	25194	Economy	26400.00
0005432632859	25194	Economy	26400.00
0005432632858	25194	Economy	26400.00
0005435844341	25194	Economy	26400.00
0005432632880	25194	Economy	26400.00
0005432632860	25194	Economy	26400.00
0005432632857	25194	Economy	26400.00
0005435844340	25194	Economy	26400.00
0005432632874	25194	Economy	26400.00
0005435844348	25194	Economy	26400.00
0005435844339	25194	Economy	26400.00
0005435844359	25194	Economy	26400.00
0005432632879	25194	Economy	26400.00
0005435844358	25194	Economy	26400.00
0005432632861	25194	Economy	26400.00
0005435844360	25194	Economy	26400.00
0005435844346	25194	Economy	26400.00
0005432632866	25194	Economy	26400.00
0005432632869	25194	Economy	26400.00
0005432632854	25194	Economy	26400.00
0005432632878	25194	Economy	26400.00
0005432632875	25194	Economy	26400.00
0005432632863	25194	Economy	26400.00
0005435844344	25194	Economy	26400.00
0005432632855	25194	Economy	26400.00
0005432632864	25194	Economy	26400.00
0005435844349	25194	Economy	26400.00
0005435844361	25194	Economy	26400.00
0005435844356	25194	Economy	26400.00
0005432632865	25194	Economy	26400.00
0005432632870	25194	Economy	26400.00
0005432632856	25194	Economy	26400.00
0005435844347	25194	Economy	26400.00
0005432632877	25194	Economy	26400.00
0005432632867	25194	Economy	26400.00
0005435844352	25194	Economy	26400.00
0005432632862	25194	Economy	26400.00
0005432632825	28175	Economy	29000.00
0005432632800	28175	Economy	29000.00
0005432632827	28175	Economy	29000.00
0005432632806	28175	Economy	29000.00
0005432632818	28175	Economy	26400.00
0005432632830	28175	Economy	26400.00
0005435844406	28175	Economy	26400.00
0005435844402	28175	Economy	26400.00
0005432632829	28175	Economy	26400.00
0005432632788	28175	Economy	26400.00
0005432632797	28175	Economy	26400.00
0005435844393	28175	Economy	26400.00
0005432632821	28175	Economy	26400.00
0005432632813	28175	Economy	26400.00
0005435844394	28175	Economy	26400.00
0005435844397	28175	Economy	26400.00
0005432632828	28175	Economy	26400.00
0005432632831	28175	Economy	26400.00
0005435844395	28175	Economy	26400.00
0005432632809	28175	Economy	26400.00
0005432632814	28175	Economy	26400.00
0005435844404	28175	Economy	26400.00
0005435844396	28175	Economy	26400.00
0005435844398	28175	Economy	26400.00
0005432632849	28175	Economy	26400.00
0005435844401	28175	Economy	26400.00
0005435844400	28175	Economy	26400.00
0005432632817	28175	Economy	26400.00
0005432632826	28175	Economy	26400.00
0005432632796	28175	Economy	26400.00
0005432632771	28175	Economy	26400.00
0005432632820	28175	Economy	26400.00
0005435844407	28175	Economy	26400.00
0005435844405	28175	Economy	26400.00
0005435844403	28175	Economy	26400.00
0005432632822	28175	Economy	26400.00
0005432632785	28175	Economy	26400.00
0005432632791	28175	Economy	26400.00
0005432632848	28175	Economy	26400.00
0005432632807	28175	Economy	26400.00
0005435844399	28175	Economy	26400.00
0005432632819	28175	Economy	26400.00
0005432632836	28175	Economy	26400.00
0005432632789	28175	Economy	26400.00
0005435541246	11395	Business	20200.00
0005435541315	11395	Business	20200.00
0005435518176	11395	Economy	6700.00
0005435518043	11395	Economy	6700.00
0005435518207	11395	Economy	6700.00
0005435518102	11395	Economy	6700.00
0005435518162	11395	Economy	7400.00
0005435518115	11395	Economy	6700.00
0005435518051	11395	Economy	6700.00
0005435518154	11395	Economy	6700.00
0005435541252	11395	Economy	6700.00
0005435541251	11395	Economy	6700.00
0005435541253	11395	Economy	6700.00
0005435541323	11395	Economy	6700.00
0005435541243	11395	Economy	6700.00
0005435541350	11395	Economy	6700.00
0005435541271	11395	Economy	6700.00
0005435541339	11395	Economy	6700.00
0005435541298	11395	Economy	6700.00
0005435541372	11395	Economy	6700.00
0005435541270	11395	Economy	6700.00
0005435541393	11395	Economy	6700.00
0005435541256	11395	Economy	6700.00
0005435541359	11395	Economy	6700.00
0005435541363	11395	Economy	6700.00
0005435541349	11395	Economy	6700.00
0005435518158	11395	Economy	6700.00
0005435518160	11395	Economy	6700.00
0005435518171	11395	Economy	6700.00
0005435518172	11395	Economy	6700.00
0005435541317	11395	Economy	6700.00
0005435518122	11395	Economy	6700.00
0005435541347	11395	Economy	6700.00
0005435541289	11395	Economy	6700.00
0005435541370	11395	Economy	6700.00
0005435518159	11395	Economy	6700.00
0005435541204	11395	Economy	6700.00
0005435541219	11395	Economy	6700.00
0005435541287	11395	Economy	6700.00
0005435541371	11395	Economy	6700.00
0005435541447	22253	Business	20200.00
0005435529705	22253	Business	20200.00
0005435529721	22253	Business	20200.00
0005435541457	22253	Business	20200.00
0005435529698	22253	Business	20200.00
0005435529713	22253	Business	20200.00
0005432294538	22253	Economy	6700.00
0005435530017	22253	Economy	6700.00
0005432294537	22253	Economy	6700.00
0005435541460	22253	Economy	6700.00
0005435541448	22253	Economy	6700.00
0005435541461	22253	Economy	6700.00
0005435541446	22253	Economy	6700.00
0005435541458	22253	Economy	6700.00
0005435529711	22253	Economy	7400.00
0005435529720	22253	Economy	7400.00
0005435541454	22253	Economy	7400.00
0005435529699	22253	Economy	6700.00
0005435530020	22253	Economy	6700.00
0005435529716	22253	Economy	6700.00
0005435529712	22253	Economy	6700.00
0005435529703	22253	Economy	6700.00
0005435541444	22253	Economy	6700.00
0005435529709	22253	Economy	6700.00
0005435541456	22253	Economy	6700.00
0005435530022	22253	Economy	6700.00
0005435529706	22253	Economy	6700.00
0005435541451	22253	Economy	6700.00
0005435529710	22253	Economy	6700.00
0005435530014	22253	Economy	6700.00
0005435541450	22253	Economy	6700.00
0005435541462	22253	Economy	6700.00
0005435529708	22253	Economy	6700.00
0005435529707	22253	Economy	6700.00
0005435529701	22253	Economy	6700.00
0005435530015	22253	Economy	6700.00
0005435541442	22253	Economy	6700.00
0005435530012	22253	Economy	6700.00
0005435529722	22253	Economy	6700.00
0005435529719	22253	Economy	6700.00
0005435530019	22253	Economy	6700.00
0005435529717	22253	Economy	6700.00
0005435541443	22253	Economy	6700.00
0005435541455	22253	Economy	6700.00
0005435529700	22253	Economy	6700.00
0005435529702	22253	Economy	6700.00
0005435529714	22253	Economy	6700.00
0005435530021	22253	Economy	6700.00
0005435541452	22253	Economy	6700.00
0005432294536	22253	Economy	6700.00
0005435530013	22253	Economy	6700.00
0005435541445	22253	Economy	6700.00
0005435530016	22253	Economy	6700.00
0005435529715	22253	Economy	6700.00
0005435541453	22253	Economy	6700.00
0005435541459	22253	Economy	6700.00
0005435529718	22253	Economy	6700.00
0005435541449	22253	Economy	6700.00
0005435530018	22253	Economy	6700.00
0005435541464	22253	Economy	6700.00
0005435541463	22253	Economy	6700.00
0005435529704	22253	Economy	6700.00
0005434908450	2264	Business	20200.00
0005434908399	2264	Business	20200.00
0005434908409	2264	Business	20200.00
0005433401039	2264	Business	20200.00
0005434908422	2264	Business	20200.00
0005434908416	2264	Business	20200.00
0005433251793	2264	Business	20200.00
0005434908407	2264	Business	20200.00
0005434908410	2264	Business	20200.00
0005433251825	2264	Business	20200.00
0005434908398	2264	Business	20200.00
0005433251838	2264	Economy	6700.00
0005433251848	2264	Economy	6700.00
0005433251775	2264	Economy	6700.00
0005434908442	2264	Economy	6700.00
0005434908428	2264	Economy	6700.00
0005434908447	2264	Economy	6700.00
0005434908431	2264	Economy	6700.00
0005434908430	2264	Economy	6700.00
0005434908448	2264	Economy	7400.00
0005434908419	2264	Economy	7400.00
0005433251830	2264	Economy	7400.00
0005433251795	2264	Economy	7400.00
0005433251882	2264	Economy	7400.00
0005434908427	2264	Economy	6700.00
0005433252025	2264	Economy	6700.00
0005434908438	2264	Economy	6700.00
0005433251794	2264	Economy	6700.00
0005433251921	2264	Economy	6700.00
0005433401038	2264	Economy	6700.00
0005433251916	2264	Economy	6700.00
0005434908436	2264	Economy	6700.00
0005433251776	2264	Economy	6700.00
0005433251972	2264	Economy	6700.00
0005433251986	2264	Economy	6700.00
0005434908405	2264	Economy	6700.00
0005433251988	2264	Economy	6700.00
0005433252012	2264	Economy	6700.00
0005433251976	2264	Economy	6700.00
0005433252013	2264	Economy	6700.00
0005433251967	2264	Economy	6700.00
0005433251973	2264	Economy	6700.00
0005434908403	2264	Economy	6700.00
0005434908432	2264	Economy	6700.00
0005434908439	2264	Economy	6700.00
0005434908413	2264	Economy	6700.00
0005434908443	2264	Economy	6700.00
0005434908440	2264	Economy	6700.00
0005433251925	2264	Economy	6700.00
0005433251917	2264	Economy	6700.00
0005433251999	2264	Economy	6700.00
0005434908437	2264	Economy	6700.00
0005434908400	2264	Economy	6700.00
0005434908421	2264	Economy	6700.00
0005434908434	2264	Economy	6700.00
0005434908418	2264	Economy	6700.00
0005433252005	2264	Economy	6700.00
0005434908412	2264	Economy	6700.00
0005433252023	2264	Economy	6700.00
0005433251950	2264	Economy	6700.00
0005434908404	2264	Economy	6700.00
0005433251956	2264	Economy	6700.00
0005434908441	2264	Economy	6700.00
0005434908396	2264	Economy	6700.00
0005433252014	2264	Economy	6700.00
0005434908429	2264	Economy	6700.00
0005434908411	2264	Economy	6700.00
0005434908446	2264	Economy	6700.00
0005434908435	2264	Economy	6700.00
0005433251899	2264	Economy	6700.00
0005434908414	2264	Economy	6700.00
0005433251915	2264	Economy	6700.00
0005434908397	2264	Economy	6700.00
0005434908415	2264	Economy	6700.00
0005434908425	2264	Economy	6700.00
0005434908449	2264	Economy	6700.00
0005434908408	2264	Economy	6700.00
0005433251947	2264	Economy	6700.00
0005434908402	2264	Economy	6700.00
0005434908406	2264	Economy	6700.00
0005434908433	2264	Economy	6700.00
0005433251902	2264	Economy	6700.00
0005434908420	2264	Economy	6700.00
0005434908444	2264	Economy	6700.00
0005434908445	2264	Economy	6700.00
0005434908426	2264	Economy	6700.00
0005434908417	2264	Economy	6700.00
0005433251966	2264	Economy	6700.00
0005434908424	2264	Economy	6700.00
0005433251824	2264	Economy	6700.00
0005434908401	2264	Economy	6700.00
0005434908423	2264	Economy	6700.00
0005433251849	2264	Economy	6700.00
0005433252132	25603	Business	20200.00
0005434907942	25603	Business	20200.00
0005434907943	25603	Business	20200.00
0005433252144	25603	Business	20200.00
0005434907951	25603	Business	20200.00
0005434907921	25603	Business	20200.00
0005434908027	25603	Business	20200.00
0005433401049	25603	Business	20200.00
0005434908024	25603	Business	20200.00
0005433252159	25603	Business	20200.00
0005433401048	25603	Business	20200.00
0005433252138	25603	Economy	6700.00
0005433252130	25603	Economy	6700.00
0005433252131	25603	Economy	6700.00
0005434907718	25603	Economy	6700.00
0005433252150	25603	Economy	6700.00
0005433401047	25603	Economy	6700.00
0005434907872	25603	Economy	6700.00
0005433252135	25603	Economy	6700.00
0005434907839	25603	Economy	6700.00
0005434908028	25603	Economy	6700.00
0005434908045	25603	Economy	7400.00
0005434907911	25603	Economy	7400.00
0005433252148	25603	Economy	7400.00
0005434907817	25603	Economy	7400.00
0005434907923	25603	Economy	7400.00
0005433252149	25603	Economy	6700.00
0005433252151	25603	Economy	6700.00
0005433252133	25603	Economy	6700.00
0005434908007	25603	Economy	6700.00
0005433252153	25603	Economy	6700.00
0005434907964	25603	Economy	6700.00
0005434907808	25603	Economy	6700.00
0005434907958	25603	Economy	6700.00
0005434907957	25603	Economy	6700.00
0005434907892	25603	Economy	6700.00
0005433252139	25603	Economy	6700.00
0005434907922	25603	Economy	6700.00
0005434907948	25603	Economy	6700.00
0005434908015	25603	Economy	6700.00
0005434907766	25603	Economy	6700.00
0005434907926	25603	Economy	6700.00
0005434907837	25603	Economy	6700.00
0005434908008	25603	Economy	6700.00
0005434907873	25603	Economy	6700.00
0005434907838	25603	Economy	6700.00
0005434907932	25603	Economy	6700.00
0005433252154	25603	Economy	6700.00
0005434907824	25603	Economy	6700.00
0005433252155	25603	Economy	6700.00
0005434907925	25603	Economy	6700.00
0005434907740	25603	Economy	6700.00
0005434908059	25603	Economy	6700.00
0005434908102	25603	Economy	6700.00
0005434907715	25603	Economy	6700.00
0005434907907	25603	Economy	6700.00
0005434907807	25603	Economy	6700.00
0005434907863	25603	Economy	6700.00
0005433252157	25603	Economy	6700.00
0005433252140	25603	Economy	6700.00
0005434907813	25603	Economy	6700.00
0005434907739	25603	Economy	6700.00
0005434907904	25603	Economy	6700.00
0005433252156	25603	Economy	6700.00
0005433252152	25603	Economy	6700.00
0005434907707	25603	Economy	6700.00
0005433252158	25603	Economy	6700.00
0005434907864	25603	Economy	6700.00
0005434907806	25603	Economy	6700.00
0005434908014	25603	Economy	6700.00
0005434907708	25603	Economy	6700.00
0005433252146	25603	Economy	6700.00
0005433252147	25603	Economy	6700.00
0005433252141	25603	Economy	6700.00
0005434907809	25603	Economy	6700.00
0005434908023	25603	Economy	6700.00
0005434907961	25603	Economy	6700.00
0005434907962	25603	Economy	6700.00
0005433252143	25603	Economy	6700.00
0005434907868	25603	Economy	6700.00
0005434907893	25603	Economy	6700.00
0005434907767	25603	Economy	6700.00
0005434907719	25603	Economy	6700.00
0005434907823	25603	Economy	6700.00
0005433252134	25603	Economy	6700.00
0005433252142	25603	Economy	6700.00
0005433252137	25603	Economy	6700.00
0005434908003	25603	Economy	6700.00
0005433252145	25603	Economy	6700.00
0005434907674	25603	Economy	6700.00
0005433252129	25603	Economy	6700.00
0005434908017	25603	Economy	6700.00
0005433252136	25603	Economy	6700.00
0005434907717	25603	Economy	6700.00
0005432862448	2514	Economy	13600.00
0005432862446	2514	Economy	13600.00
0005432862405	2514	Economy	12400.00
0005432862450	2514	Economy	12400.00
0005432621343	2514	Economy	12400.00
0005432862425	2514	Economy	12400.00
0005432862426	2514	Economy	12400.00
0005432621344	2514	Economy	12400.00
0005432621346	2514	Economy	12400.00
0005432862393	2514	Economy	12400.00
0005432621340	2514	Economy	12400.00
0005432621338	2514	Economy	12400.00
0005432621336	2514	Economy	12400.00
0005432621345	2514	Economy	12400.00
0005432621347	2514	Economy	12400.00
0005432621348	2514	Economy	12400.00
0005432862432	2514	Economy	12400.00
0005432862449	2514	Economy	12400.00
0005432621341	2514	Economy	12400.00
0005432621349	2514	Economy	12400.00
0005432862447	2514	Economy	12400.00
0005432862394	2514	Economy	12400.00
0005432621339	2514	Economy	12400.00
0005432621342	2514	Economy	12400.00
0005432862433	2514	Economy	12400.00
0005432621337	2514	Economy	12400.00
0005432862471	28038	Economy	13600.00
0005432621228	28038	Economy	13600.00
0005432862467	28038	Economy	12400.00
0005432621221	28038	Economy	12400.00
0005432621193	28038	Economy	12400.00
0005432621217	28038	Economy	12400.00
0005432621245	28038	Economy	12400.00
0005432621223	28038	Economy	12400.00
0005432621244	28038	Economy	12400.00
0005432621235	28038	Economy	12400.00
0005432621283	28038	Economy	12400.00
0005432862472	28038	Economy	12400.00
0005432862470	28038	Economy	12400.00
0005432621284	28038	Economy	12400.00
0005432862468	28038	Economy	12400.00
0005432621227	28038	Economy	12400.00
0005432621281	28038	Economy	12400.00
0005432621194	28038	Economy	12400.00
0005432621204	28038	Economy	12400.00
0005432621241	28038	Economy	12400.00
0005432621208	28038	Economy	12400.00
0005432862469	28038	Economy	12400.00
0005432862466	28038	Economy	12400.00
0005434097494	11728	Economy	11300.00
0005434097500	13018	Economy	11300.00
0005433452785	31038	Economy	8400.00
0005433451662	31038	Economy	8400.00
0005433451663	31038	Economy	8400.00
0005433454909	31345	Economy	8400.00
0005433452764	31345	Economy	8400.00
0005433452762	31345	Economy	8400.00
0005433452768	31345	Economy	8400.00
0005433129333	12027	Economy	7200.00
0005433129318	12027	Economy	7200.00
0005433134205	12027	Economy	6600.00
0005434142663	12027	Economy	6600.00
0005433129320	12027	Economy	6600.00
0005433129334	12027	Economy	6600.00
0005434142675	12027	Economy	6600.00
0005434142649	12027	Economy	6600.00
0005433129310	12027	Economy	6600.00
0005434142662	12027	Economy	6600.00
0005434142664	12027	Economy	6600.00
0005433134175	12027	Economy	6600.00
0005434184692	12027	Economy	6600.00
0005433134199	12027	Economy	6600.00
0005433129319	12027	Economy	6600.00
0005434142672	12027	Economy	6600.00
0005433129309	12027	Economy	6600.00
0005433134237	29825	Economy	6600.00
0005433131807	29825	Economy	6600.00
0005433134235	29825	Economy	6600.00
0005434142694	29825	Economy	6600.00
0005433131808	29825	Economy	6600.00
0005434184710	29825	Economy	6600.00
0005433134236	29825	Economy	6600.00
0005433131806	29825	Economy	6600.00
0005434142695	29825	Economy	6600.00
0005434183624	29825	Economy	6600.00
0005434184709	29825	Economy	6600.00
0005434184711	29825	Economy	6600.00
0005434142693	29825	Economy	6600.00
0005434142692	29825	Economy	6600.00
0005433134238	29825	Economy	6600.00
0005434142696	29825	Economy	6600.00
0005435697909	16498	Economy	19900.00
0005435697924	16498	Economy	19900.00
0005435697916	16498	Economy	19900.00
0005435697914	16498	Economy	19900.00
0005435697917	16498	Economy	18100.00
0005435697927	16498	Economy	18100.00
0005435697913	16498	Economy	18100.00
0005435697918	16498	Economy	18100.00
0005435697928	16498	Economy	18100.00
0005435697931	16498	Economy	18100.00
0005435697911	16498	Economy	18100.00
0005435697923	16498	Economy	18100.00
0005435697912	16498	Economy	18100.00
0005435697925	16498	Economy	18100.00
0005435697930	16498	Economy	18100.00
0005435935084	16498	Economy	18100.00
0005435697910	16498	Economy	18100.00
0005435935098	16498	Economy	18100.00
0005435697921	16498	Economy	18100.00
0005435697922	16498	Economy	18100.00
0005435697926	16498	Economy	18100.00
0005435935071	16498	Economy	18100.00
0005435697915	16498	Economy	18100.00
0005435697919	16498	Economy	18100.00
0005435697929	16498	Economy	18100.00
0005435697932	16498	Economy	18100.00
0005435697920	16498	Economy	18100.00
0005435935073	16498	Economy	18100.00
0005435697908	16498	Economy	18100.00
0005435697934	16498	Economy	18100.00
0005435697933	16498	Economy	18100.00
0005435697649	24706	Economy	19900.00
0005435697600	24706	Economy	19900.00
0005435697778	24706	Economy	19900.00
0005435697601	24706	Economy	19900.00
0005435697780	24706	Economy	18100.00
0005435697701	24706	Economy	18100.00
0005435933569	24706	Economy	18100.00
0005435697599	24706	Economy	18100.00
0005435697718	24706	Economy	18100.00
0005435935111	24706	Economy	18100.00
0005435697781	24706	Economy	18100.00
0005435933568	24706	Economy	18100.00
0005435697678	24706	Economy	18100.00
0005435697731	24706	Economy	18100.00
0005435935110	24706	Economy	18100.00
0005435697734	24706	Economy	18100.00
0005435697742	24706	Economy	18100.00
0005435697574	24706	Economy	18100.00
0005435697803	24706	Economy	18100.00
0005435697756	24706	Economy	18100.00
0005435697702	24706	Economy	18100.00
0005435935112	24706	Economy	18100.00
0005435697751	24706	Economy	18100.00
0005435697703	24706	Economy	18100.00
0005435697580	24706	Economy	18100.00
0005435697750	24706	Economy	18100.00
0005435697704	24706	Economy	18100.00
0005435697754	24706	Economy	18100.00
0005435697733	24706	Economy	18100.00
0005435697712	24706	Economy	18100.00
0005435697819	24706	Economy	18100.00
0005435697804	24706	Economy	18100.00
0005435697717	24706	Economy	18100.00
0005435697694	24706	Economy	18100.00
0005435697747	24706	Economy	18100.00
0005435697695	24706	Economy	18100.00
0005435697732	24706	Economy	18100.00
0005435935113	24706	Economy	18100.00
0005432968876	18805	Economy	4400.00
0005433724902	18805	Economy	4400.00
0005433724903	18805	Economy	4400.00
0005433724900	18805	Economy	4400.00
0005433724899	18805	Economy	4400.00
0005433724901	18805	Economy	4400.00
0005433724833	21594	Economy	4400.00
0005433724847	21594	Economy	4400.00
0005433724884	21594	Economy	4400.00
0005433724858	21594	Economy	4400.00
0005433724859	21594	Economy	4400.00
0005433724874	21594	Economy	4400.00
0005432968892	21594	Economy	4400.00
0005433724860	21594	Economy	4400.00
0005432968891	21594	Economy	4400.00
0005433724869	21594	Economy	4400.00
0005433724883	21594	Economy	4400.00
0005434139870	7298	Business	23100.00
0005434139919	7298	Business	23100.00
0005434139893	7298	Business	23100.00
0005434139940	7298	Business	23100.00
0005434139934	7298	Business	23100.00
0005434139882	7298	Business	23100.00
0005434139884	7298	Business	23100.00
0005434139871	7298	Business	23100.00
0005434139910	7298	Business	23100.00
0005434139925	7298	Business	23100.00
0005434139905	7298	Business	23100.00
0005434139889	7298	Economy	7700.00
0005434139909	7298	Economy	7700.00
0005434139916	7298	Economy	7700.00
0005434139933	7298	Economy	7700.00
0005434139917	7298	Economy	7700.00
0005434139932	7298	Economy	7700.00
0005434139866	7298	Economy	7700.00
0005434087620	7298	Economy	7700.00
0005434139886	7298	Economy	7700.00
0005434139887	7298	Economy	7700.00
0005434139936	7298	Economy	8500.00
0005434139867	7298	Economy	8500.00
0005434139912	7298	Economy	8500.00
0005434139880	7298	Economy	7700.00
0005434139920	7298	Economy	7700.00
0005434139875	7298	Economy	7700.00
0005434139879	7298	Economy	7700.00
0005434139865	7298	Economy	7700.00
0005434139915	7298	Economy	7700.00
0005434139908	7298	Economy	7700.00
0005434139872	7298	Economy	7700.00
0005434139900	7298	Economy	7700.00
0005434139897	7298	Economy	7700.00
0005434139903	7298	Economy	7700.00
0005434139885	7298	Economy	7700.00
0005434139890	7298	Economy	7700.00
0005434139904	7298	Economy	7700.00
0005434139922	7298	Economy	7700.00
0005434139918	7298	Economy	7700.00
0005434139906	7298	Economy	7700.00
0005434139874	7298	Economy	7700.00
0005434139938	7298	Economy	7700.00
0005434139928	7298	Economy	7700.00
0005434087619	7298	Economy	7700.00
0005434139878	7298	Economy	7700.00
0005434139931	7298	Economy	7700.00
0005434139901	7298	Economy	7700.00
0005434139927	7298	Economy	7700.00
0005434139923	7298	Economy	7700.00
0005434139902	7298	Economy	7700.00
0005434139939	7298	Economy	7700.00
0005434139888	7298	Economy	7700.00
0005434139873	7298	Economy	7700.00
0005434139899	7298	Economy	7700.00
0005434139869	7298	Economy	7700.00
0005434139876	7298	Economy	7700.00
0005434139913	7298	Economy	7700.00
0005434139892	7298	Economy	7700.00
0005434087618	7298	Economy	7700.00
0005434087622	7298	Economy	7700.00
0005434139877	7298	Economy	7700.00
0005434139924	7298	Economy	7700.00
0005434139911	7298	Economy	7700.00
0005434087621	7298	Economy	7700.00
0005434139895	7298	Economy	7700.00
0005434139930	7298	Economy	7700.00
0005434139926	7298	Economy	7700.00
0005434139896	7298	Economy	7700.00
0005434139898	7298	Economy	7700.00
0005434139883	7298	Economy	7700.00
0005434139921	7298	Economy	7700.00
0005434139868	7298	Economy	7700.00
0005434139891	7298	Economy	7700.00
0005434139907	7298	Economy	7700.00
0005434139937	7298	Economy	7700.00
0005434139929	7298	Economy	7700.00
0005434139894	7298	Economy	7700.00
0005434139914	7298	Economy	7700.00
0005434139935	7298	Economy	7700.00
0005434139881	7298	Economy	7700.00
0005434139371	28538	Business	23100.00
0005434138905	28538	Business	23100.00
0005434138876	28538	Business	23100.00
0005434139043	28538	Business	23100.00
0005434139298	28538	Business	23100.00
0005434139069	28538	Business	23100.00
0005434139243	28538	Business	23100.00
0005434139006	28538	Business	23100.00
0005434139163	28538	Business	23100.00
0005434139224	28538	Business	23100.00
0005434139222	28538	Business	23100.00
0005434139259	28538	Economy	7700.00
0005434139112	28538	Economy	7700.00
0005434087573	28538	Economy	7700.00
0005434139223	28538	Economy	7700.00
0005434138878	28538	Economy	7700.00
0005434138875	28538	Economy	7700.00
0005434139215	28538	Economy	7700.00
0005434139171	28538	Economy	7700.00
0005434138618	28538	Economy	7700.00
0005434139164	28538	Economy	8500.00
0005434139073	28538	Economy	8500.00
0005434139314	28538	Economy	8500.00
0005434139216	28538	Economy	8500.00
0005434139219	28538	Economy	8500.00
0005434139035	28538	Economy	7700.00
0005434139213	28538	Economy	7700.00
0005434139258	28538	Economy	7700.00
0005434138824	28538	Economy	7700.00
0005434139218	28538	Economy	7700.00
0005434139242	28538	Economy	7700.00
0005434138874	28538	Economy	7700.00
0005434139077	28538	Economy	7700.00
0005434087567	28538	Economy	7700.00
0005434087587	28538	Economy	7700.00
0005434139001	28538	Economy	7700.00
0005434138995	28538	Economy	7700.00
0005434138935	28538	Economy	7700.00
0005434139254	28538	Economy	7700.00
0005434139052	28538	Economy	7700.00
0005434139070	28538	Economy	7700.00
0005434138877	28538	Economy	7700.00
0005434138714	28538	Economy	7700.00
0005434087601	28538	Economy	7700.00
0005434139076	28538	Economy	7700.00
0005434139297	28538	Economy	7700.00
0005434138906	28538	Economy	7700.00
0005434139312	28538	Economy	7700.00
0005434139370	28538	Economy	7700.00
0005434138814	28538	Economy	7700.00
0005434138822	28538	Economy	7700.00
0005434139286	28538	Economy	7700.00
0005434087586	28538	Economy	7700.00
0005434139051	28538	Economy	7700.00
0005434139111	28538	Economy	7700.00
0005434139058	28538	Economy	7700.00
0005434139201	28538	Economy	7700.00
0005434087589	28538	Economy	7700.00
0005434139017	28538	Economy	7700.00
0005434138999	28538	Economy	7700.00
0005434139170	28538	Economy	7700.00
0005434139154	28538	Economy	7700.00
0005434139113	28538	Economy	7700.00
0005434139115	28538	Economy	7700.00
0005434087585	28538	Economy	7700.00
0005434087602	28538	Economy	7700.00
0005434138765	28538	Economy	7700.00
0005434139299	28538	Economy	7700.00
0005434087575	28538	Economy	7700.00
0005434138641	28538	Economy	7700.00
0005434139313	28538	Economy	7700.00
0005434139395	28538	Economy	7700.00
0005434139104	28538	Economy	7700.00
0005434138899	28538	Economy	7700.00
0005434139372	28538	Economy	7700.00
0005434139226	28538	Economy	7700.00
0005434139099	28538	Economy	7700.00
0005434087574	28538	Economy	7700.00
0005434139356	28538	Economy	7700.00
0005434139289	28538	Economy	7700.00
0005434139211	28538	Economy	7700.00
0005434138718	28538	Economy	7700.00
0005434087569	28538	Economy	7700.00
0005434139139	28538	Economy	7700.00
0005434139140	28538	Economy	7700.00
0005434139010	28538	Economy	7700.00
0005434087590	28538	Economy	7700.00
0005434138642	28538	Economy	7700.00
0005434138959	28538	Economy	7700.00
0005434139153	28538	Economy	7700.00
0005434138936	28538	Economy	7700.00
0005434610307	1933	Economy	23900.00
0005435808444	1933	Economy	21700.00
0005433407622	1933	Economy	21700.00
0005435808450	1933	Economy	21700.00
0005434610308	1933	Economy	21700.00
0005435808445	1933	Economy	21700.00
0005435808442	1933	Economy	21700.00
0005435808451	1933	Economy	21700.00
0005433407630	1933	Economy	21700.00
0005433407625	1933	Economy	21700.00
0005433407621	1933	Economy	21700.00
0005435808446	1933	Economy	21700.00
0005433407616	1933	Economy	21700.00
0005434610309	1933	Economy	21700.00
0005435808448	1933	Economy	21700.00
0005435808449	1933	Economy	21700.00
0005435808443	1933	Economy	21700.00
0005434610310	1933	Economy	21700.00
0005435808447	1933	Economy	21700.00
0005435808441	1933	Economy	21700.00
0005435808452	1933	Economy	21700.00
0005434610306	1933	Economy	21700.00
0005435808290	23080	Economy	23900.00
0005435808383	23080	Economy	23900.00
0005434610270	23080	Economy	23900.00
0005435808293	23080	Economy	21700.00
0005433407669	23080	Economy	21700.00
0005435808348	23080	Economy	21700.00
0005435808382	23080	Economy	21700.00
0005435808315	23080	Economy	21700.00
0005433407667	23080	Economy	21700.00
0005435808324	23080	Economy	21700.00
0005434610276	23080	Economy	21700.00
0005433407671	23080	Economy	21700.00
0005435808356	23080	Economy	21700.00
0005435808366	23080	Economy	21700.00
0005433407672	23080	Economy	21700.00
0005435808349	23080	Economy	21700.00
0005433407665	23080	Economy	21700.00
0005434610271	23080	Economy	21700.00
0005434610266	23080	Economy	21700.00
0005433407666	23080	Economy	21700.00
0005435808384	23080	Economy	21700.00
0005435808319	23080	Economy	21700.00
0005435808306	23080	Economy	21700.00
0005435808326	23080	Economy	21700.00
0005433407674	23080	Economy	21700.00
0005435808360	23080	Economy	21700.00
0005433407673	23080	Economy	21700.00
0005435808337	23080	Economy	21700.00
0005434610283	23080	Economy	21700.00
0005435808305	23080	Economy	21700.00
0005435808314	23080	Economy	21700.00
0005435808330	23080	Economy	21700.00
0005433407668	23080	Economy	21700.00
0005435808327	23080	Economy	21700.00
0005435808313	23080	Economy	21700.00
0005435808354	23080	Economy	21700.00
0005435808291	23080	Economy	21700.00
0005435808325	23080	Economy	21700.00
0005434610284	23080	Economy	21700.00
0005435808292	23080	Economy	21700.00
0005433407670	23080	Economy	21700.00
0005434504576	16693	Economy	7600.00
0005434504725	16693	Economy	7600.00
0005434504698	16693	Economy	7600.00
0005434504651	16693	Economy	6900.00
0005434504627	16693	Economy	6900.00
0005434504325	16693	Economy	6900.00
0005434504561	16693	Economy	6900.00
0005434504536	16693	Economy	6900.00
0005434504637	16693	Economy	6900.00
0005434504629	16693	Economy	6900.00
0005434504544	16693	Economy	6900.00
0005434504643	16693	Economy	6900.00
0005434504644	16693	Economy	6900.00
0005434504399	16693	Economy	6900.00
0005434504558	16693	Economy	6900.00
0005434504639	16693	Economy	6900.00
0005434504398	16693	Economy	6900.00
0005434504672	16693	Economy	6900.00
0005434504640	16693	Economy	6900.00
0005434504400	16693	Economy	6900.00
0005434504397	16693	Economy	6900.00
0005434504498	16693	Economy	6900.00
0005434504610	16693	Economy	6900.00
0005434504628	16693	Economy	6900.00
0005434504562	16693	Economy	6900.00
0005434504547	16693	Economy	6900.00
0005434504489	16693	Economy	6900.00
0005434504545	16693	Economy	6900.00
0005434504580	16693	Economy	6900.00
0005434504650	16693	Economy	6900.00
0005434504746	16693	Economy	6900.00
0005434504621	16693	Economy	6900.00
0005434504693	16693	Economy	6900.00
0005434504679	16693	Economy	6900.00
0005434504548	16693	Economy	6900.00
0005434504692	16693	Economy	6900.00
0005434504522	16693	Economy	6900.00
0005434504595	16693	Economy	6900.00
0005434504581	16693	Economy	6900.00
0005434504566	16693	Economy	6900.00
0005434504567	16693	Economy	6900.00
0005434504538	16693	Economy	6900.00
0005434504699	16693	Economy	6900.00
0005434504594	16693	Economy	6900.00
0005434504951	22936	Economy	7600.00
0005434504963	22936	Economy	7600.00
0005434504978	22936	Economy	7600.00
0005434504985	22936	Economy	7600.00
0005434504960	22936	Economy	6900.00
0005434504964	22936	Economy	6900.00
0005434504983	22936	Economy	6900.00
0005434504962	22936	Economy	6900.00
0005434504972	22936	Economy	6900.00
0005434504971	22936	Economy	6900.00
0005434504967	22936	Economy	6900.00
0005434504984	22936	Economy	6900.00
0005434504954	22936	Economy	6900.00
0005434504956	22936	Economy	6900.00
0005434504976	22936	Economy	6900.00
0005434504966	22936	Economy	6900.00
0005434504970	22936	Economy	6900.00
0005434504982	22936	Economy	6900.00
0005434504961	22936	Economy	6900.00
0005434504968	22936	Economy	6900.00
0005434504952	22936	Economy	6900.00
0005434504980	22936	Economy	6900.00
0005434504959	22936	Economy	6900.00
0005434504950	22936	Economy	6900.00
0005434504973	22936	Economy	6900.00
0005434504974	22936	Economy	6900.00
0005434504949	22936	Economy	6900.00
0005434504987	22936	Economy	6900.00
0005434504958	22936	Economy	6900.00
0005434504975	22936	Economy	6900.00
0005434504988	22936	Economy	6900.00
0005434504986	22936	Economy	6900.00
0005434504969	22936	Economy	6900.00
0005434504953	22936	Economy	6900.00
0005434504981	22936	Economy	6900.00
0005434504957	22936	Economy	6900.00
0005434504965	22936	Economy	6900.00
0005434504955	22936	Economy	6900.00
0005434504977	22936	Economy	6900.00
0005434504979	22936	Economy	6900.00
0005433266855	2212	Economy	7700.00
0005435078676	2212	Economy	7700.00
0005435078683	2212	Economy	7700.00
0005433266854	2212	Economy	7000.00
0005433266810	2212	Economy	7000.00
0005435078670	2212	Economy	7000.00
0005435078684	2212	Economy	7000.00
0005433266849	2212	Economy	7000.00
0005433266850	2212	Economy	7000.00
0005435078673	2212	Economy	7000.00
0005433266803	2212	Economy	7000.00
0005435078669	2212	Economy	7000.00
0005435078679	2212	Economy	7000.00
0005435078671	2212	Economy	7000.00
0005435078678	2212	Economy	7000.00
0005433266829	2212	Economy	7000.00
0005433266868	2212	Economy	7000.00
0005433266848	2212	Economy	7000.00
0005433266869	2212	Economy	7000.00
0005435078677	2212	Economy	7000.00
0005435078681	2212	Economy	7000.00
0005435078672	2212	Economy	7000.00
0005435078685	2212	Economy	7000.00
0005435078674	2212	Economy	7000.00
0005435078680	2212	Economy	7000.00
0005435078675	2212	Economy	7000.00
0005433266802	2212	Economy	7000.00
0005435078682	2212	Economy	7000.00
0005433266828	2212	Economy	7000.00
0005435078600	24322	Economy	7700.00
0005435078599	24322	Economy	7700.00
0005433266923	24322	Economy	7700.00
0005435078530	24322	Economy	7000.00
0005435078529	24322	Economy	7000.00
0005435078527	24322	Economy	7000.00
0005435078542	24322	Economy	7000.00
0005435078598	24322	Economy	7000.00
0005435078555	24322	Economy	7000.00
0005435078588	24322	Economy	7000.00
0005433266921	24322	Economy	7000.00
0005433266919	24322	Economy	7000.00
0005435078544	24322	Economy	7000.00
0005435078465	24322	Economy	7000.00
0005435078531	24322	Economy	7000.00
0005435078541	24322	Economy	7000.00
0005435078538	24322	Economy	7000.00
0005433266925	24322	Economy	7000.00
0005433266926	24322	Economy	7000.00
0005435078578	24322	Economy	7000.00
0005435078535	24322	Economy	7000.00
0005433266922	24322	Economy	7000.00
0005435078564	24322	Economy	7000.00
0005433266928	24322	Economy	7000.00
0005433266927	24322	Economy	7000.00
0005435078481	24322	Economy	7000.00
0005435078573	24322	Economy	7000.00
0005435078507	24322	Economy	7000.00
0005433266924	24322	Economy	7000.00
0005435078506	24322	Economy	7000.00
0005433266920	24322	Economy	7000.00
0005434988966	6647	Economy	10800.00
0005434988974	6647	Economy	9800.00
0005434988964	6647	Economy	9800.00
0005434988969	6647	Economy	9800.00
0005434988970	6647	Economy	9800.00
0005435803323	6647	Economy	9800.00
0005434988963	6647	Economy	9800.00
0005435464532	6647	Economy	9800.00
0005435803324	6647	Economy	9800.00
0005434988967	6647	Economy	9800.00
0005434988965	6647	Economy	9800.00
0005435803325	6647	Economy	9800.00
0005434988972	6647	Economy	9800.00
0005434988971	6647	Economy	9800.00
0005434988968	6647	Economy	9800.00
0005434988973	6647	Economy	9800.00
0005435464550	23642	Economy	10800.00
0005435803298	23642	Economy	10800.00
0005435803299	23642	Economy	9800.00
0005435803285	23642	Economy	9800.00
0005434988800	23642	Economy	9800.00
0005434988856	23642	Economy	9800.00
0005434988848	23642	Economy	9800.00
0005434988798	23642	Economy	9800.00
0005434988850	23642	Economy	9800.00
0005434988860	23642	Economy	9800.00
0005435464551	23642	Economy	9800.00
0005434988857	23642	Economy	9800.00
0005434988859	23642	Economy	9800.00
0005434988851	23642	Economy	9800.00
0005434988839	23642	Economy	9800.00
0005434988799	23642	Economy	9800.00
0005434988826	23642	Economy	9800.00
0005434988864	23642	Economy	9800.00
0005435803308	23642	Economy	9800.00
0005433450450	30493	Business	9900.00
0005433450445	30493	Business	9900.00
0005432384012	30493	Business	9900.00
0005432384007	30493	Business	9900.00
0005433450448	30493	Business	9900.00
0005433450451	30493	Business	9900.00
0005433454922	30493	Business	9900.00
0005432384014	30493	Business	9900.00
0005432384003	30493	Business	9900.00
0005432384025	30493	Economy	3300.00
0005433450432	30493	Economy	3300.00
0005433450449	30493	Economy	3300.00
0005433450438	30493	Economy	3300.00
0005433450435	30493	Economy	3300.00
0005433450434	30493	Economy	3300.00
0005433450439	30493	Economy	3300.00
0005433450443	30493	Economy	3300.00
0005432383997	30493	Economy	3600.00
0005432384026	30493	Economy	3600.00
0005432384030	30493	Economy	3600.00
0005433450446	30493	Economy	3600.00
0005433454921	30493	Economy	3300.00
0005432384020	30493	Economy	3300.00
0005432384015	30493	Economy	3300.00
0005432384000	30493	Economy	3300.00
0005432384006	30493	Economy	3300.00
0005432384032	30493	Economy	3300.00
0005432384009	30493	Economy	3300.00
0005433450437	30493	Economy	3300.00
0005432384001	30493	Economy	3300.00
0005432384018	30493	Economy	3300.00
0005432384002	30493	Economy	3300.00
0005432384033	30493	Economy	3300.00
0005432384010	30493	Economy	3300.00
0005432383998	30493	Economy	3300.00
0005432384004	30493	Economy	3300.00
0005432384011	30493	Economy	3300.00
0005432384021	30493	Economy	3300.00
0005432384035	30493	Economy	3300.00
0005433450436	30493	Economy	3300.00
0005433453804	30493	Economy	3300.00
0005433450452	30493	Economy	3300.00
0005432384005	30493	Economy	3300.00
0005432384023	30493	Economy	3300.00
0005432383996	30493	Economy	3300.00
0005432384008	30493	Economy	3300.00
0005432384022	30493	Economy	3300.00
0005432384013	30493	Economy	3300.00
0005432384016	30493	Economy	3300.00
0005433450444	30493	Economy	3300.00
0005433453806	30493	Economy	3300.00
0005432384028	30493	Economy	3300.00
0005432384031	30493	Economy	3300.00
0005432384029	30493	Economy	3300.00
0005432384036	30493	Economy	3300.00
0005432384027	30493	Economy	3300.00
0005433450433	30493	Economy	3300.00
0005433453805	30493	Economy	3300.00
0005432384019	30493	Economy	3300.00
0005433450447	30493	Economy	3300.00
0005432384017	30493	Economy	3300.00
0005432384024	30493	Economy	3300.00
0005433450440	30493	Economy	3300.00
0005433450442	30493	Economy	3300.00
0005433450441	30493	Economy	3300.00
0005433450431	30493	Economy	3300.00
0005432383999	30493	Economy	3300.00
0005432384034	30493	Economy	3300.00
0005432383573	31327	Business	9900.00
0005433451657	31327	Business	9900.00
0005433450306	31327	Business	9900.00
0005433450208	31327	Business	9900.00
0005432383599	31327	Economy	3300.00
0005432383539	31327	Economy	3300.00
0005432383595	31327	Economy	3300.00
0005433451643	31327	Economy	3300.00
0005433450315	31327	Economy	3300.00
0005432383614	31327	Economy	3300.00
0005433450228	31327	Economy	3600.00
0005432383480	31327	Economy	3600.00
0005432383576	31327	Economy	3600.00
0005433450246	31327	Economy	3300.00
0005433450291	31327	Economy	3300.00
0005433450209	31327	Economy	3300.00
0005433450292	31327	Economy	3300.00
0005433450247	31327	Economy	3300.00
0005432383613	31327	Economy	3300.00
0005432383601	31327	Economy	3300.00
0005432383527	31327	Economy	3300.00
0005433450185	31327	Economy	3300.00
0005432383501	31327	Economy	3300.00
0005433451658	31327	Economy	3300.00
0005433451638	31327	Economy	3300.00
0005432383479	31327	Economy	3300.00
0005432383617	31327	Economy	3300.00
0005432383549	31327	Economy	3300.00
0005433450210	31327	Economy	3300.00
0005432383592	31327	Economy	3300.00
0005432383511	31327	Economy	3300.00
0005432383570	31327	Economy	3300.00
0005432383600	31327	Economy	3300.00
0005433450193	31327	Economy	3300.00
0005433450231	31327	Economy	3300.00
0005432383446	31327	Economy	3300.00
0005432383514	31327	Economy	3300.00
0005433450362	31327	Economy	3300.00
0005432383538	31327	Economy	3300.00
0005432383559	31327	Economy	3300.00
0005432383505	31327	Economy	3300.00
0005433450196	31327	Economy	3300.00
0005433450212	31327	Economy	3300.00
0005432383500	31327	Economy	3300.00
0005433450248	31327	Economy	3300.00
0005433450211	31327	Economy	3300.00
0005432383616	31327	Economy	3300.00
0005432383565	31327	Economy	3300.00
0005432383604	31327	Economy	3300.00
0005432383605	31327	Economy	3300.00
0005433450255	31327	Economy	3300.00
0005433450305	31327	Economy	3300.00
0005433450232	31327	Economy	3300.00
0005433450279	31327	Economy	3300.00
0005432383408	31327	Economy	3300.00
0005432383528	31327	Economy	3300.00
0005433450199	31327	Economy	3300.00
0005433131765	10797	Economy	17100.00
0005435299831	10797	Economy	17100.00
0005435304209	10797	Economy	17100.00
0005433131758	10797	Economy	15600.00
0005433126906	10797	Economy	15600.00
0005435299834	10797	Economy	15600.00
0005435299830	10797	Economy	15600.00
0005435299818	10797	Economy	15600.00
0005433126904	10797	Economy	15600.00
0005433131759	10797	Economy	15600.00
0005435299821	10797	Economy	15600.00
0005435304217	10797	Economy	15600.00
0005435299837	10797	Economy	15600.00
0005433126903	10797	Economy	15600.00
0005433131764	10797	Economy	15600.00
0005433131776	10797	Economy	15600.00
0005433126905	10797	Economy	15600.00
0005435304211	10797	Economy	15600.00
0005435304225	10797	Economy	15600.00
0005433131760	10797	Economy	15600.00
0005435299881	29688	Economy	17100.00
0005435302306	29688	Economy	15600.00
0005435302305	29688	Economy	15600.00
0005433129381	29688	Economy	15600.00
0005433126951	29688	Economy	15600.00
0005433126948	29688	Economy	15600.00
0005433126950	29688	Economy	15600.00
0005433129378	29688	Economy	15600.00
0005435299885	29688	Economy	15600.00
0005433126949	29688	Economy	15600.00
0005433129379	29688	Economy	15600.00
0005433126946	29688	Economy	15600.00
0005435299884	29688	Economy	15600.00
0005435299883	29688	Economy	15600.00
0005435302304	29688	Economy	15600.00
0005433129377	29688	Economy	15600.00
0005435299882	29688	Economy	15600.00
0005433126947	29688	Economy	15600.00
0005433129380	29688	Economy	15600.00
0005435302303	29688	Economy	15600.00
0005435302307	29688	Economy	15600.00
0005434287770	2401	Economy	17200.00
0005434287777	2401	Economy	17200.00
0005434287765	2401	Economy	17200.00
0005434287769	2401	Economy	15700.00
0005434287768	2401	Economy	15700.00
0005434287776	2401	Economy	15700.00
0005432264529	2401	Economy	15700.00
0005434287774	2401	Economy	15700.00
0005432264527	2401	Economy	15700.00
0005433110234	2401	Economy	15700.00
0005433110212	2401	Economy	15700.00
0005434287763	2401	Economy	15700.00
0005433110211	2401	Economy	15700.00
0005434287759	2401	Economy	15700.00
0005434287762	2401	Economy	15700.00
0005434287773	2401	Economy	15700.00
0005433110233	2401	Economy	15700.00
0005433110208	2401	Economy	15700.00
0005434287761	2401	Economy	15700.00
0005434287771	2401	Economy	15700.00
0005434287758	2401	Economy	15700.00
0005433110214	2401	Economy	15700.00
0005434287767	2401	Economy	15700.00
0005433110213	2401	Economy	15700.00
0005434287778	2401	Economy	15700.00
0005434287766	2401	Economy	15700.00
0005432264528	2401	Economy	15700.00
0005434287775	2401	Economy	15700.00
0005434287764	2401	Economy	15700.00
0005433110207	2401	Economy	15700.00
0005434287760	2401	Economy	15700.00
0005433110229	2401	Economy	15700.00
0005434287757	2401	Economy	15700.00
0005434287772	2401	Economy	15700.00
0005433110255	2401	Economy	15700.00
0005433110222	2401	Economy	15700.00
0005433110311	26853	Economy	17200.00
0005433110312	26853	Economy	17200.00
0005434287683	26853	Economy	17200.00
0005434287583	26853	Economy	17200.00
0005434287551	26853	Economy	15700.00
0005434287542	26853	Economy	15700.00
0005433110318	26853	Economy	15700.00
0005434287508	26853	Economy	15700.00
0005433110317	26853	Economy	15700.00
0005434287597	26853	Economy	15700.00
0005434287532	26853	Economy	15700.00
0005434287496	26853	Economy	15700.00
0005433110316	26853	Economy	15700.00
0005433110310	26853	Economy	15700.00
0005434287596	26853	Economy	15700.00
0005434287540	26853	Economy	15700.00
0005434287694	26853	Economy	15700.00
0005434287614	26853	Economy	15700.00
0005434287649	26853	Economy	15700.00
0005434287598	26853	Economy	15700.00
0005434287621	26853	Economy	15700.00
0005434287563	26853	Economy	15700.00
0005434287620	26853	Economy	15700.00
0005434287552	26853	Economy	15700.00
0005434287521	26853	Economy	15700.00
0005434287686	26853	Economy	15700.00
0005434287522	26853	Economy	15700.00
0005433110308	26853	Economy	15700.00
0005434287501	26853	Economy	15700.00
0005434287497	26853	Economy	15700.00
0005434287624	26853	Economy	15700.00
0005434287541	26853	Economy	15700.00
0005434287500	26853	Economy	15700.00
0005434287595	26853	Economy	15700.00
0005433110313	26853	Economy	15700.00
0005433110320	26853	Economy	15700.00
0005433110319	26853	Economy	15700.00
0005434287667	26853	Economy	15700.00
0005434287498	26853	Economy	15700.00
0005433110314	26853	Economy	15700.00
0005434287565	26853	Economy	15700.00
0005433110309	26853	Economy	15700.00
0005433110315	26853	Economy	15700.00
0005435856296	25463	Economy	25000.00
0005435856295	25463	Economy	22800.00
0005435856297	25463	Economy	22800.00
0005435856333	25463	Economy	22800.00
0005435856334	25463	Economy	22800.00
0005434269122	25463	Economy	22800.00
0005435856294	25463	Economy	22800.00
0005434272210	25463	Economy	22800.00
0005434269123	25463	Economy	22800.00
0005434269124	25463	Economy	22800.00
0005435856250	26646	Economy	22800.00
0005435854064	26646	Economy	22800.00
0005434272221	26646	Economy	22800.00
0005435854065	26646	Economy	22800.00
0005434272223	26646	Economy	22800.00
0005434272222	26646	Economy	22800.00
0005434273110	26646	Economy	22800.00
0005434273109	26646	Economy	22800.00
0005433869286	4776	Economy	19400.00
0005433869321	4776	Economy	19400.00
0005433869290	4776	Economy	19400.00
0005433869307	4776	Economy	19400.00
0005433869300	4776	Economy	17600.00
0005433869317	4776	Economy	17600.00
0005433869306	4776	Economy	17600.00
0005433869292	4776	Economy	17600.00
0005433869311	4776	Economy	17600.00
0005433869291	4776	Economy	17600.00
0005433869308	4776	Economy	17600.00
0005433869294	4776	Economy	17600.00
0005433869310	4776	Economy	17600.00
0005433869318	4776	Economy	17600.00
0005433869288	4776	Economy	17600.00
0005433869284	4776	Economy	17600.00
0005433869320	4776	Economy	17600.00
0005433869316	4776	Economy	17600.00
0005433869298	4776	Economy	17600.00
0005433869295	4776	Economy	17600.00
0005433869312	4776	Economy	17600.00
0005433869322	4776	Economy	17600.00
0005433869299	4776	Economy	17600.00
0005433869283	4776	Economy	17600.00
0005433869289	4776	Economy	17600.00
0005433869305	4776	Economy	17600.00
0005433869285	4776	Economy	17600.00
0005433869319	4776	Economy	17600.00
0005433869309	4776	Economy	17600.00
0005433869293	4776	Economy	17600.00
0005435860519	4776	Economy	17600.00
0005433869313	4776	Economy	17600.00
0005433869323	4776	Economy	17600.00
0005433869297	4776	Economy	17600.00
0005433869302	4776	Economy	17600.00
0005433869314	4776	Economy	17600.00
0005433869296	4776	Economy	17600.00
0005433869282	4776	Economy	17600.00
0005433869287	4776	Economy	17600.00
0005433869303	4776	Economy	17600.00
0005433869301	4776	Economy	17600.00
0005433869304	4776	Economy	17600.00
0005433869315	4776	Economy	17600.00
0005433868901	32587	Economy	19400.00
0005433868898	32587	Economy	19400.00
0005433868713	32587	Economy	19400.00
0005433868935	32587	Economy	19400.00
0005435860577	32587	Economy	17600.00
0005433868918	32587	Economy	17600.00
0005433868991	32587	Economy	17600.00
0005433869057	32587	Economy	17600.00
0005433868846	32587	Economy	17600.00
0005433869045	32587	Economy	17600.00
0005433868780	32587	Economy	17600.00
0005433869064	32587	Economy	17600.00
0005435860576	32587	Economy	17600.00
0005433869065	32587	Economy	17600.00
0005433868694	32587	Economy	17600.00
0005433868905	32587	Economy	17600.00
0005433868904	32587	Economy	17600.00
0005433868799	32587	Economy	17600.00
0005433868734	32587	Economy	17600.00
0005433869044	32587	Economy	17600.00
0005433868917	32587	Economy	17600.00
0005433868931	32587	Economy	17600.00
0005433869018	32587	Economy	17600.00
0005433868776	32587	Economy	17600.00
0005433868656	32587	Economy	17600.00
0005433868830	32587	Economy	17600.00
0005433868997	32587	Economy	17600.00
0005433869056	32587	Economy	17600.00
0005433868738	32587	Economy	17600.00
0005433868775	32587	Economy	17600.00
0005433868772	32587	Economy	17600.00
0005433868955	32587	Economy	17600.00
0005433868973	32587	Economy	17600.00
0005433868816	32587	Economy	17600.00
0005433868758	32587	Economy	17600.00
0005433868946	32587	Economy	17600.00
0005433869020	32587	Economy	17600.00
0005433868996	32587	Economy	17600.00
0005433868943	32587	Economy	17600.00
0005433868907	32587	Economy	17600.00
0005433868712	32587	Economy	17600.00
0005433868990	32587	Economy	17600.00
0005433868998	32587	Economy	17600.00
0005433868861	32587	Economy	17600.00
0005435860578	32587	Economy	17600.00
0005433868657	32587	Economy	17600.00
0005435911576	3454	Economy	24800.00
0005434663700	3454	Economy	24800.00
0005435911599	3454	Economy	24800.00
0005434663701	3454	Economy	24800.00
0005435911571	3454	Economy	22600.00
0005435911506	3454	Economy	22600.00
0005434663705	3454	Economy	22600.00
0005435911527	3454	Economy	22600.00
0005434663699	3454	Economy	22600.00
0005434663707	3454	Economy	22600.00
0005435911556	3454	Economy	22600.00
0005434663698	3454	Economy	22600.00
0005435911542	3454	Economy	22600.00
0005434663697	3454	Economy	22600.00
0005434663704	3454	Economy	22600.00
0005435911575	3454	Economy	22600.00
0005435911553	3454	Economy	22600.00
0005434663695	3454	Economy	22600.00
0005434461694	3454	Economy	22600.00
0005434663708	3454	Economy	22600.00
0005435911554	3454	Economy	22600.00
0005434663696	3454	Economy	22600.00
0005434663703	3454	Economy	22600.00
0005434663706	3454	Economy	22600.00
0005435911555	3454	Economy	22600.00
0005434663702	3454	Economy	22600.00
0005434663561	12502	Economy	24800.00
0005434663596	12502	Economy	24800.00
0005434663612	12502	Economy	22600.00
0005434663588	12502	Economy	22600.00
0005435911619	12502	Economy	22600.00
0005435911617	12502	Economy	22600.00
0005434663523	12502	Economy	22600.00
0005434663603	12502	Economy	22600.00
0005434663558	12502	Economy	22600.00
0005435911615	12502	Economy	22600.00
0005435911613	12502	Economy	22600.00
0005435911612	12502	Economy	22600.00
0005434663533	12502	Economy	22600.00
0005434663581	12502	Economy	22600.00
0005434663582	12502	Economy	22600.00
0005434663604	12502	Economy	22600.00
0005434663537	12502	Economy	22600.00
0005435911614	12502	Economy	22600.00
0005435911618	12502	Economy	22600.00
0005434663597	12502	Economy	22600.00
0005435911616	12502	Economy	22600.00
0005433868955	14484	Economy	18500.00
0005433869065	14484	Economy	18500.00
0005433869020	14484	Economy	18500.00
0005433868772	14484	Economy	16800.00
0005433868738	14484	Economy	16800.00
0005433868943	14484	Economy	16800.00
0005433868758	14484	Economy	16800.00
0005433868918	14484	Economy	16800.00
0005433869056	14484	Economy	16800.00
0005433868998	14484	Economy	16800.00
0005433868657	14484	Economy	16800.00
0005433868917	14484	Economy	16800.00
0005433868931	14484	Economy	16800.00
0005433868713	14484	Economy	16800.00
0005433868861	14484	Economy	16800.00
0005433868734	14484	Economy	16800.00
0005433868996	14484	Economy	16800.00
0005435860576	14484	Economy	16800.00
0005433868846	14484	Economy	16800.00
0005433868780	14484	Economy	16800.00
0005433868656	14484	Economy	16800.00
0005433869044	14484	Economy	16800.00
0005433868816	14484	Economy	16800.00
0005433869018	14484	Economy	16800.00
0005433868905	14484	Economy	16800.00
0005433868935	14484	Economy	16800.00
0005433868901	14484	Economy	16800.00
0005433868904	14484	Economy	16800.00
0005433868946	14484	Economy	16800.00
0005433869064	14484	Economy	16800.00
0005433868694	14484	Economy	16800.00
0005433869057	14484	Economy	16800.00
0005433868997	14484	Economy	16800.00
0005433868775	14484	Economy	16800.00
0005433868990	14484	Economy	16800.00
0005433868973	14484	Economy	16800.00
0005433868991	14484	Economy	16800.00
0005433868776	14484	Economy	16800.00
0005433868799	14484	Economy	16800.00
0005433869045	14484	Economy	16800.00
0005433868898	14484	Economy	16800.00
0005435860577	14484	Economy	16800.00
0005433868830	14484	Economy	16800.00
0005433868712	14484	Economy	16800.00
0005435860578	14484	Economy	16800.00
0005433868907	14484	Economy	16800.00
0005433869257	32676	Economy	18500.00
0005433869271	32676	Economy	18500.00
0005435860523	32676	Economy	18500.00
0005433869273	32676	Economy	18500.00
0005433869278	32676	Economy	16800.00
0005435860517	32676	Economy	16800.00
0005433869243	32676	Economy	16800.00
0005433869259	32676	Economy	16800.00
0005433869279	32676	Economy	16800.00
0005433869275	32676	Economy	16800.00
0005433869258	32676	Economy	16800.00
0005433869262	32676	Economy	16800.00
0005433869269	32676	Economy	16800.00
0005435860516	32676	Economy	16800.00
0005433869252	32676	Economy	16800.00
0005433869247	32676	Economy	16800.00
0005433869265	32676	Economy	16800.00
0005433869244	32676	Economy	16800.00
0005433869272	32676	Economy	16800.00
0005435860521	32676	Economy	16800.00
0005433869249	32676	Economy	16800.00
0005433869277	32676	Economy	16800.00
0005433869263	32676	Economy	16800.00
0005433869266	32676	Economy	16800.00
0005433869276	32676	Economy	16800.00
0005435860522	32676	Economy	16800.00
0005433869261	32676	Economy	16800.00
0005433869256	32676	Economy	16800.00
0005433869246	32676	Economy	16800.00
0005433869281	32676	Economy	16800.00
0005433869260	32676	Economy	16800.00
0005433869253	32676	Economy	16800.00
0005433869274	32676	Economy	16800.00
0005433869255	32676	Economy	16800.00
0005433869242	32676	Economy	16800.00
0005433869250	32676	Economy	16800.00
0005433869267	32676	Economy	16800.00
0005433869270	32676	Economy	16800.00
0005433869268	32676	Economy	16800.00
0005433869245	32676	Economy	16800.00
0005433869264	32676	Economy	16800.00
0005433869241	32676	Economy	16800.00
0005433869254	32676	Economy	16800.00
0005433869248	32676	Economy	16800.00
0005433869251	32676	Economy	16800.00
0005433869280	32676	Economy	16800.00
0005432799789	12123	Economy	4900.00
0005432799847	12123	Economy	4900.00
0005432799881	12123	Economy	4400.00
0005432799910	12123	Economy	4400.00
0005432799829	12123	Economy	4400.00
0005432799689	12123	Economy	4400.00
0005432799713	12123	Economy	4400.00
0005432799846	12123	Economy	4400.00
0005432799714	12123	Economy	4400.00
0005432799880	12123	Economy	4400.00
0005432799746	12123	Economy	4400.00
0005432799712	12123	Economy	4400.00
0005432799601	12123	Economy	4400.00
0005432799804	12123	Economy	4400.00
0005432799745	12123	Economy	4400.00
0005432799861	12123	Economy	4400.00
0005432799793	12123	Economy	4400.00
0005432799774	12123	Economy	4400.00
0005432799866	12123	Economy	4400.00
0005432799899	12123	Economy	4400.00
0005432799752	12123	Economy	4400.00
0005432799633	12123	Economy	4400.00
0005432799792	12123	Economy	4400.00
0005432799803	12123	Economy	4400.00
0005432799805	12123	Economy	4400.00
0005432800037	14810	Economy	4900.00
0005432800050	14810	Economy	4400.00
0005432800051	14810	Economy	4400.00
0005432800044	14810	Economy	4400.00
0005432800033	14810	Economy	4400.00
0005432800048	14810	Economy	4400.00
0005432800041	14810	Economy	4400.00
0005432800038	14810	Economy	4400.00
0005432800027	14810	Economy	4400.00
0005432800028	14810	Economy	4400.00
0005432800034	14810	Economy	4400.00
0005432800045	14810	Economy	4400.00
0005432800046	14810	Economy	4400.00
0005432800029	14810	Economy	4400.00
0005432800032	14810	Economy	4400.00
0005432800042	14810	Economy	4400.00
0005432800043	14810	Economy	4400.00
0005432800047	14810	Economy	4400.00
0005432800049	14810	Economy	4400.00
0005432800031	14810	Economy	4400.00
0005432800025	14810	Economy	4400.00
0005432800030	14810	Economy	4400.00
0005432800036	14810	Economy	4400.00
0005432800026	14810	Economy	4400.00
0005432800024	14810	Economy	4400.00
0005432800039	14810	Economy	4400.00
0005432800040	14810	Economy	4400.00
0005432800035	14810	Economy	4400.00
0005434409107	7033	Business	49100.00
0005434409105	7033	Business	49100.00
0005432108307	7033	Business	49100.00
0005434409149	7033	Business	49100.00
0005434409119	7033	Business	49100.00
0005434409109	7033	Business	49100.00
0005432154093	7033	Business	49100.00
0005434300074	7033	Business	49100.00
0005434409127	7033	Business	49100.00
0005435311202	7033	Business	49100.00
0005434300054	7033	Economy	16400.00
0005434300065	7033	Economy	16400.00
0005434300052	7033	Economy	16400.00
0005435311198	7033	Economy	16400.00
0005432154092	7033	Economy	16400.00
0005434409150	7033	Economy	16400.00
0005434409157	7033	Economy	16400.00
0005434409106	7033	Economy	16400.00
0005434409156	7033	Economy	16400.00
0005434409154	7033	Economy	16400.00
0005435311220	7033	Economy	16400.00
0005434409142	7033	Economy	16400.00
0005434300056	7033	Economy	16400.00
0005435311207	7033	Economy	16400.00
0005435311188	7033	Economy	16400.00
0005434300051	7033	Economy	16400.00
0005434409098	7033	Economy	16400.00
0005434300072	7033	Economy	16400.00
0005434409121	7033	Economy	16400.00
0005434409099	7033	Economy	16400.00
0005434300055	7033	Economy	16400.00
0005434409110	7033	Economy	16400.00
0005434409144	7033	Economy	16400.00
0005435311227	7033	Economy	16400.00
0005435311215	7033	Economy	16400.00
0005432154091	7033	Economy	16400.00
0005434409115	7033	Economy	16400.00
0005434300061	7033	Economy	16400.00
0005434409153	7033	Economy	16400.00
0005434409101	7033	Economy	16400.00
0005434409114	7033	Economy	16400.00
0005434409139	7033	Economy	16400.00
0005435293419	7033	Economy	16400.00
0005434300068	7033	Economy	16400.00
0005434300069	7033	Economy	16400.00
0005432154088	7033	Economy	16400.00
0005435311226	7033	Economy	16400.00
0005434409135	7033	Economy	18000.00
0005435293418	7033	Economy	18000.00
0005434409113	7033	Economy	18000.00
0005434409095	7033	Economy	18000.00
0005435311214	7033	Economy	16400.00
0005432154089	7033	Economy	18000.00
0005435293422	7033	Economy	16400.00
0005434300062	7033	Economy	16400.00
0005434409096	7033	Economy	16400.00
0005434409143	7033	Economy	16400.00
0005434409097	7033	Economy	16400.00
0005434409128	7033	Economy	16400.00
0005434409126	7033	Economy	16400.00
0005434300064	7033	Economy	16400.00
0005435311212	7033	Economy	16400.00
0005434300070	7033	Economy	16400.00
0005434300058	7033	Economy	16400.00
0005434409141	7033	Economy	16400.00
0005434409100	7033	Economy	16400.00
0005434409133	7033	Economy	16400.00
0005434409137	7033	Economy	16400.00
0005434409102	7033	Economy	16400.00
0005434409138	7033	Economy	16400.00
0005434409123	7033	Economy	16400.00
0005434409146	7033	Economy	16400.00
0005434300057	7033	Economy	16400.00
0005434300071	7033	Economy	16400.00
0005435311197	7033	Economy	16400.00
0005434300073	7033	Economy	16400.00
0005434409151	7033	Economy	16400.00
0005434409104	7033	Economy	16400.00
0005435293438	7033	Economy	16400.00
0005434409125	7033	Economy	16400.00
0005435311230	7033	Economy	16400.00
0005434409145	7033	Economy	16400.00
0005434409112	7033	Economy	16400.00
0005434300066	7033	Economy	16400.00
0005434409117	7033	Economy	16400.00
0005434409122	7033	Economy	16400.00
0005434409152	7033	Economy	16400.00
0005435311228	7033	Economy	16400.00
0005434409131	7033	Economy	16400.00
0005434409129	7033	Economy	16400.00
0005434409108	7033	Economy	16400.00
0005434300060	7033	Economy	16400.00
0005434300053	7033	Economy	16400.00
0005434409118	7033	Economy	16400.00
0005432154090	7033	Economy	16400.00
0005434409134	7033	Economy	16400.00
0005434300063	7033	Economy	16400.00
0005434409111	7033	Economy	16400.00
0005435311231	7033	Economy	16400.00
0005435311189	7033	Economy	16400.00
0005434409147	7033	Economy	16400.00
0005434300067	7033	Economy	16400.00
0005432108305	7033	Economy	16400.00
0005435311206	7033	Economy	16400.00
0005435293391	7033	Economy	16400.00
0005435293376	7033	Economy	16400.00
0005434300059	7033	Economy	16400.00
0005434409132	7033	Economy	16400.00
0005434409130	7033	Economy	16400.00
0005434409124	7033	Economy	16400.00
0005434409136	7033	Economy	16400.00
0005434409120	7033	Economy	16400.00
0005432108306	7033	Economy	16400.00
0005432154086	7033	Economy	16400.00
0005435293435	7033	Economy	16400.00
0005432154087	7033	Economy	16400.00
0005434409155	7033	Economy	16400.00
0005434409103	7033	Economy	16400.00
0005435293375	7033	Economy	16400.00
0005435311152	7033	Economy	16400.00
0005434409148	7033	Economy	16400.00
0005434409140	7033	Economy	16400.00
0005434409116	7033	Economy	16400.00
0005434408692	26918	Business	49100.00
0005434408667	26918	Business	49100.00
0005435293518	26918	Business	49100.00
0005434408367	26918	Business	49100.00
0005435311339	26918	Business	49100.00
0005435293516	26918	Business	49100.00
0005435311322	26918	Business	49100.00
0005435293523	26918	Business	49100.00
0005435293528	26918	Business	49100.00
0005434408271	26918	Business	49100.00
0005435311348	26918	Economy	16400.00
0005434408658	26918	Economy	16400.00
0005434408430	26918	Economy	16400.00
0005434408670	26918	Economy	16400.00
0005434408462	26918	Economy	16400.00
0005435311328	26918	Economy	16400.00
0005432058463	26918	Economy	16400.00
0005435311352	26918	Economy	16400.00
0005434299978	26918	Economy	16400.00
0005435311345	26918	Economy	16400.00
0005434408461	26918	Economy	16400.00
0005434408278	26918	Economy	16400.00
0005435311342	26918	Economy	16400.00
0005435311327	26918	Economy	16400.00
0005434408569	26918	Economy	16400.00
0005434408220	26918	Economy	16400.00
0005434299938	26918	Economy	16400.00
0005432058465	26918	Economy	16400.00
0005435311350	26918	Economy	16400.00
0005435311354	26918	Economy	16400.00
0005435293524	26918	Economy	16400.00
0005435311331	26918	Economy	16400.00
0005435311319	26918	Economy	16400.00
0005434299868	26918	Economy	16400.00
0005434408221	26918	Economy	16400.00
0005435311329	26918	Economy	16400.00
0005434300010	26918	Economy	16400.00
0005435311323	26918	Economy	16400.00
0005434408429	26918	Economy	16400.00
0005435311347	26918	Economy	16400.00
0005434408473	26918	Economy	16400.00
0005435311321	26918	Economy	16400.00
0005434408609	26918	Economy	16400.00
0005434408589	26918	Economy	16400.00
0005435311325	26918	Economy	16400.00
0005434299867	26918	Economy	16400.00
0005432058462	26918	Economy	16400.00
0005435311344	26918	Economy	16400.00
0005434408740	26918	Economy	16400.00
0005434299827	26918	Economy	18000.00
0005435311318	26918	Economy	18000.00
0005435311332	26918	Economy	18000.00
0005434299826	26918	Economy	18000.00
0005435311337	26918	Economy	18000.00
0005435311335	26918	Economy	16400.00
0005435311353	26918	Economy	16400.00
0005434408608	26918	Economy	16400.00
0005434408474	26918	Economy	16400.00
0005435293520	26918	Economy	16400.00
0005435311336	26918	Economy	16400.00
0005435311340	26918	Economy	16400.00
0005435293519	26918	Economy	16400.00
0005432058464	26918	Economy	16400.00
0005435311320	26918	Economy	16400.00
0005435311326	26918	Economy	16400.00
0005434299894	26918	Economy	16400.00
0005434408468	26918	Economy	16400.00
0005434408267	26918	Economy	16400.00
0005434299895	26918	Economy	16400.00
0005435293527	26918	Economy	16400.00
0005434408248	26918	Economy	16400.00
0005434300011	26918	Economy	16400.00
0005434408507	26918	Economy	16400.00
0005434408272	26918	Economy	16400.00
0005434408345	26918	Economy	16400.00
0005435311324	26918	Economy	16400.00
0005434408571	26918	Economy	16400.00
0005434408593	26918	Economy	16400.00
0005435311334	26918	Economy	16400.00
0005435311341	26918	Economy	16400.00
0005434299932	26918	Economy	16400.00
0005434408357	26918	Economy	16400.00
0005434299844	26918	Economy	16400.00
0005434408413	26918	Economy	16400.00
0005434299820	26918	Economy	16400.00
0005435311330	26918	Economy	16400.00
0005434408472	26918	Economy	16400.00
0005434408691	26918	Economy	16400.00
0005434408541	26918	Economy	16400.00
0005434299893	26918	Economy	16400.00
0005435311343	26918	Economy	16400.00
0005434299939	26918	Economy	16400.00
0005434299846	26918	Economy	16400.00
0005434408668	26918	Economy	16400.00
0005434408313	26918	Economy	16400.00
0005435311349	26918	Economy	16400.00
0005435293525	26918	Economy	16400.00
0005435311333	26918	Economy	16400.00
0005434408570	26918	Economy	16400.00
0005434408268	26918	Economy	16400.00
0005434408358	26918	Economy	16400.00
0005435293526	26918	Economy	16400.00
0005435293522	26918	Economy	16400.00
0005434408165	26918	Economy	16400.00
0005434408556	26918	Economy	16400.00
0005434408607	26918	Economy	16400.00
0005434408434	26918	Economy	16400.00
0005435311346	26918	Economy	16400.00
0005434408642	26918	Economy	16400.00
0005434299907	26918	Economy	16400.00
0005435293517	26918	Economy	16400.00
0005435311351	26918	Economy	16400.00
0005434299828	26918	Economy	16400.00
0005435311338	26918	Economy	16400.00
0005434408743	26918	Economy	16400.00
0005434299845	26918	Economy	16400.00
0005435293521	26918	Economy	16400.00
0005434299931	26918	Economy	16400.00
0005434408648	26918	Economy	16400.00
0005432605185	6485	Economy	16500.00
0005432605195	6485	Economy	16500.00
0005432605216	6485	Economy	16500.00
0005432605204	6485	Economy	16500.00
0005432605192	6485	Economy	15000.00
0005432605184	6485	Economy	15000.00
0005432605189	6485	Economy	15000.00
0005434512221	6485	Economy	15000.00
0005432605206	6485	Economy	15000.00
0005432605201	6485	Economy	15000.00
0005432605188	6485	Economy	15000.00
0005432605212	6485	Economy	15000.00
0005432605213	6485	Economy	15000.00
0005432605191	6485	Economy	15000.00
0005432605215	6485	Economy	15000.00
0005432605211	6485	Economy	15000.00
0005432605187	6485	Economy	15000.00
0005432605214	6485	Economy	15000.00
0005432605196	6485	Economy	15000.00
0005432605205	6485	Economy	15000.00
0005432605209	6485	Economy	15000.00
0005432605200	6485	Economy	15000.00
0005432605186	6485	Economy	15000.00
0005432605194	6485	Economy	15000.00
0005432605207	6485	Economy	15000.00
0005432605223	6485	Economy	15000.00
0005432605217	6485	Economy	15000.00
0005432605218	6485	Economy	15000.00
0005432605197	6485	Economy	15000.00
0005432605219	6485	Economy	15000.00
0005432605220	6485	Economy	15000.00
0005432605190	6485	Economy	15000.00
0005432605208	6485	Economy	15000.00
0005432605203	6485	Economy	15000.00
0005432605199	6485	Economy	15000.00
0005432605202	6485	Economy	15000.00
0005432605221	6485	Economy	15000.00
0005432605210	6485	Economy	15000.00
0005432605193	6485	Economy	15000.00
0005432605198	6485	Economy	15000.00
0005432605222	6485	Economy	15000.00
0005432604902	21343	Economy	16500.00
0005432604594	21343	Economy	16500.00
0005434512161	21343	Economy	16500.00
0005432604670	21343	Economy	16500.00
0005435312899	21343	Economy	15000.00
0005432604800	21343	Economy	15000.00
0005432604938	21343	Economy	15000.00
0005432604734	21343	Economy	15000.00
0005435221074	21343	Economy	15000.00
0005432604769	21343	Economy	15000.00
0005432604627	21343	Economy	15000.00
0005434512178	21343	Economy	15000.00
0005432604768	21343	Economy	15000.00
0005432604899	21343	Economy	15000.00
0005432604934	21343	Economy	15000.00
0005432604898	21343	Economy	15000.00
0005432604906	21343	Economy	15000.00
0005435221531	21343	Economy	15000.00
0005432604804	21343	Economy	15000.00
0005432604881	21343	Economy	15000.00
0005434512195	21343	Economy	15000.00
0005432604810	21343	Economy	15000.00
0005432604939	21343	Economy	15000.00
0005432604837	21343	Economy	15000.00
0005434512156	21343	Economy	15000.00
0005432604667	21343	Economy	15000.00
0005435312902	21343	Economy	15000.00
0005432604798	21343	Economy	15000.00
0005432604874	21343	Economy	15000.00
0005435221073	21343	Economy	15000.00
0005435312901	21343	Economy	15000.00
0005432604671	21343	Economy	15000.00
0005435312903	21343	Economy	15000.00
0005432604697	21343	Economy	15000.00
0005435221550	21343	Economy	15000.00
0005432604799	21343	Economy	15000.00
0005432604873	21343	Economy	15000.00
0005432604893	21343	Economy	15000.00
0005432604757	21343	Economy	15000.00
0005432604960	21343	Economy	15000.00
0005432604653	21343	Economy	15000.00
0005432604838	21343	Economy	15000.00
0005432604935	21343	Economy	15000.00
0005435221530	21343	Economy	15000.00
0005432604836	21343	Economy	15000.00
0005435312900	21343	Economy	15000.00
0005432604723	21343	Economy	15000.00
0005435221072	21343	Economy	15000.00
0005432604696	21343	Economy	15000.00
0005434907838	15009	Business	18900.00
0005434908027	15009	Business	18900.00
0005434907817	15009	Business	18900.00
0005434908024	15009	Business	18900.00
0005433252150	15009	Business	18900.00
0005433252154	15009	Business	18900.00
0005434907925	15009	Business	18900.00
0005433252138	15009	Business	18900.00
0005434907674	15009	Business	18900.00
0005433252131	15009	Business	18900.00
0005433252137	15009	Economy	6300.00
0005434907808	15009	Economy	6300.00
0005433252144	15009	Economy	6300.00
0005434907715	15009	Economy	6300.00
0005434908014	15009	Economy	6300.00
0005434907806	15009	Economy	6300.00
0005434908028	15009	Economy	6300.00
0005433252135	15009	Economy	6300.00
0005433252148	15009	Economy	6300.00
0005434907961	15009	Economy	6300.00
0005434908007	15009	Economy	6900.00
0005434907923	15009	Economy	6900.00
0005434907863	15009	Economy	6900.00
0005434907813	15009	Economy	6900.00
0005434907904	15009	Economy	6900.00
0005433252145	15009	Economy	6300.00
0005434907719	15009	Economy	6300.00
0005433252152	15009	Economy	6300.00
0005434907740	15009	Economy	6300.00
0005434907824	15009	Economy	6300.00
0005433252132	15009	Economy	6300.00
0005434907964	15009	Economy	6300.00
0005434907957	15009	Economy	6300.00
0005434907807	15009	Economy	6300.00
0005434908015	15009	Economy	6300.00
0005433252136	15009	Economy	6300.00
0005433252129	15009	Economy	6300.00
0005434907922	15009	Economy	6300.00
0005434907907	15009	Economy	6300.00
0005434907962	15009	Economy	6300.00
0005433252157	15009	Economy	6300.00
0005434908003	15009	Economy	6300.00
0005434907926	15009	Economy	6300.00
0005433252155	15009	Economy	6300.00
0005434907708	15009	Economy	6300.00
0005434907893	15009	Economy	6300.00
0005434907739	15009	Economy	6300.00
0005434907767	15009	Economy	6300.00
0005433252147	15009	Economy	6300.00
0005434907921	15009	Economy	6300.00
0005434907932	15009	Economy	6300.00
0005434907717	15009	Economy	6300.00
0005433252130	15009	Economy	6300.00
0005433252156	15009	Economy	6300.00
0005434907872	15009	Economy	6300.00
0005434908059	15009	Economy	6300.00
0005433252158	15009	Economy	6300.00
0005434907837	15009	Economy	6300.00
0005433252143	15009	Economy	6300.00
0005434908023	15009	Economy	6300.00
0005434908102	15009	Economy	6300.00
0005433252139	15009	Economy	6300.00
0005433252141	15009	Economy	6300.00
0005434907766	15009	Economy	6300.00
0005434907809	15009	Economy	6300.00
0005434907864	15009	Economy	6300.00
0005433252142	15009	Economy	6300.00
0005434907942	15009	Economy	6300.00
0005434907868	15009	Economy	6300.00
0005433252149	15009	Economy	6300.00
0005434907873	15009	Economy	6300.00
0005434907948	15009	Economy	6300.00
0005434907718	15009	Economy	6300.00
0005433252140	15009	Economy	6300.00
0005433252153	15009	Economy	6300.00
0005434908045	15009	Economy	6300.00
0005434907943	15009	Economy	6300.00
0005434907839	15009	Economy	6300.00
0005434907958	15009	Economy	6300.00
0005434907892	15009	Economy	6300.00
0005433252134	15009	Economy	6300.00
0005434907951	15009	Economy	6300.00
0005434907823	15009	Economy	6300.00
0005434908017	15009	Economy	6300.00
0005434907707	15009	Economy	6300.00
0005433252151	15009	Economy	6300.00
0005434907911	15009	Economy	6300.00
0005433252133	15009	Economy	6300.00
0005433252159	15009	Economy	6300.00
0005434908008	15009	Economy	6300.00
0005433252146	15009	Economy	6300.00
0005434908350	25837	Business	18900.00
0005433251749	25837	Business	18900.00
0005434908338	25837	Business	18900.00
0005434908354	25837	Business	18900.00
0005434908340	25837	Business	18900.00
0005434908347	25837	Business	18900.00
0005434908375	25837	Business	18900.00
0005434908362	25837	Business	18900.00
0005434908363	25837	Business	18900.00
0005433251965	25837	Business	18900.00
0005433251865	25837	Economy	6300.00
0005433251864	25837	Economy	6300.00
0005433251816	25837	Economy	6300.00
0005434908391	25837	Economy	6300.00
0005433251696	25837	Economy	6300.00
0005434908366	25837	Economy	6300.00
0005433251815	25837	Economy	6300.00
0005434908389	25837	Economy	6300.00
0005434908357	25837	Economy	6300.00
0005434908372	25837	Economy	6900.00
0005434908360	25837	Economy	6900.00
0005433251820	25837	Economy	6900.00
0005434908367	25837	Economy	6900.00
0005433251959	25837	Economy	6300.00
0005434908353	25837	Economy	6300.00
0005434908343	25837	Economy	6300.00
0005434908381	25837	Economy	6300.00
0005434908370	25837	Economy	6300.00
0005434908384	25837	Economy	6300.00
0005434908373	25837	Economy	6300.00
0005433251809	25837	Economy	6300.00
0005434908388	25837	Economy	6300.00
0005433251858	25837	Economy	6300.00
0005434908342	25837	Economy	6300.00
0005434908378	25837	Economy	6300.00
0005434908387	25837	Economy	6300.00
0005434908386	25837	Economy	6300.00
0005434908344	25837	Economy	6300.00
0005434908341	25837	Economy	6300.00
0005434908359	25837	Economy	6300.00
0005434908380	25837	Economy	6300.00
0005434908369	25837	Economy	6300.00
0005433251955	25837	Economy	6300.00
0005433251870	25837	Economy	6300.00
0005434908394	25837	Economy	6300.00
0005434908365	25837	Economy	6300.00
0005434908382	25837	Economy	6300.00
0005434908393	25837	Economy	6300.00
0005434908345	25837	Economy	6300.00
0005434908351	25837	Economy	6300.00
0005434908377	25837	Economy	6300.00
0005434908390	25837	Economy	6300.00
0005434908376	25837	Economy	6300.00
0005433251857	25837	Economy	6300.00
0005433251783	25837	Economy	6300.00
0005434908355	25837	Economy	6300.00
0005434908374	25837	Economy	6300.00
0005434908348	25837	Economy	6300.00
0005434908361	25837	Economy	6300.00
0005434908358	25837	Economy	6300.00
0005434908385	25837	Economy	6300.00
0005433251869	25837	Economy	6300.00
0005434908392	25837	Economy	6300.00
0005434908346	25837	Economy	6300.00
0005434908336	25837	Economy	6300.00
0005434908349	25837	Economy	6300.00
0005434908356	25837	Economy	6300.00
0005434908339	25837	Economy	6300.00
0005434908364	25837	Economy	6300.00
0005434908379	25837	Economy	6300.00
0005434908395	25837	Economy	6300.00
0005433251782	25837	Economy	6300.00
0005434908383	25837	Economy	6300.00
0005434908371	25837	Economy	6300.00
0005434908352	25837	Economy	6300.00
0005434908368	25837	Economy	6300.00
0005434908337	25837	Economy	6300.00
0005432607652	22472	Economy	14900.00
0005432607648	22472	Economy	14900.00
0005432609817	22472	Economy	14900.00
0005432609815	22472	Economy	14900.00
0005432607645	22472	Economy	14900.00
0005432609806	22472	Economy	14900.00
0005432607646	22472	Economy	14900.00
0005432607647	22472	Economy	14900.00
0005432607650	22472	Economy	14900.00
0005435841482	22472	Economy	14900.00
0005432609809	22472	Economy	14900.00
0005432609812	22472	Economy	14900.00
0005432607651	22472	Economy	14900.00
0005432609807	22472	Economy	14900.00
0005435842332	22472	Economy	14900.00
0005435841479	22472	Economy	14900.00
0005432609814	22472	Economy	14900.00
0005432607644	22472	Economy	14900.00
0005432609818	22472	Economy	14900.00
0005432609810	22472	Economy	14900.00
0005432609811	22472	Economy	14900.00
0005432607649	22472	Economy	14900.00
0005432609816	22472	Economy	14900.00
0005432609813	22472	Economy	14900.00
0005432607643	22472	Economy	14900.00
0005435842333	22472	Economy	14900.00
0005432609808	22472	Economy	14900.00
0005435841119	31717	Economy	16400.00
0005432613906	31717	Economy	16400.00
0005435841120	31717	Economy	16400.00
0005432613912	31717	Economy	16400.00
0005432613894	31717	Economy	14900.00
0005432609778	31717	Economy	14900.00
0005432609800	31717	Economy	14900.00
0005432613914	31717	Economy	14900.00
0005432613903	31717	Economy	14900.00
0005432609755	31717	Economy	14900.00
0005432609773	31717	Economy	14900.00
0005432609776	31717	Economy	14900.00
0005432609787	31717	Economy	14900.00
0005432609774	31717	Economy	14900.00
0005432609799	31717	Economy	14900.00
0005432613895	31717	Economy	14900.00
0005432613913	31717	Economy	14900.00
0005432609742	31717	Economy	14900.00
0005432609775	31717	Economy	14900.00
0005432609783	31717	Economy	14900.00
0005432613900	31717	Economy	14900.00
0005432609786	31717	Economy	14900.00
0005432613896	31717	Economy	14900.00
0005432613915	31717	Economy	14900.00
0005433009627	14203	Business	52300.00
0005433009589	14203	Business	52300.00
0005433009604	14203	Business	52300.00
0005433810582	14203	Business	52300.00
0005433009613	14203	Business	52300.00
0005433009591	14203	Business	52300.00
0005433009594	14203	Business	52300.00
0005433009620	14203	Business	52300.00
0005433009609	14203	Business	52300.00
0005433009617	14203	Economy	17400.00
0005433009610	14203	Economy	17400.00
0005433009585	14203	Economy	17400.00
0005433009598	14203	Economy	19200.00
0005433009614	14203	Economy	19200.00
0005433009599	14203	Economy	19200.00
0005433009593	14203	Economy	17400.00
0005433009605	14203	Economy	17400.00
0005433009606	14203	Economy	17400.00
0005433009586	14203	Economy	17400.00
0005433009615	14203	Economy	17400.00
0005433009628	14203	Economy	17400.00
0005433009602	14203	Economy	17400.00
0005433009587	14203	Economy	17400.00
0005433009588	14203	Economy	17400.00
0005433009616	14203	Economy	17400.00
0005433009603	14203	Economy	17400.00
0005433009597	14203	Economy	17400.00
0005433009630	14203	Economy	17400.00
0005433009626	14203	Economy	17400.00
0005433009622	14203	Economy	17400.00
0005433009601	14203	Economy	17400.00
0005433009608	14203	Economy	17400.00
0005433009595	14203	Economy	17400.00
0005433009621	14203	Economy	17400.00
0005433009612	14203	Economy	17400.00
0005433009607	14203	Economy	17400.00
0005433009590	14203	Economy	17400.00
0005433009611	14203	Economy	17400.00
0005433810581	14203	Economy	17400.00
0005433009625	14203	Economy	17400.00
0005433009600	14203	Economy	17400.00
0005433009592	14203	Economy	17400.00
0005433009596	14203	Economy	17400.00
0005433009624	14203	Economy	17400.00
0005433009619	14203	Economy	17400.00
0005433009629	14203	Economy	17400.00
0005433009623	14203	Economy	17400.00
0005433009618	14203	Economy	17400.00
0005433009186	22864	Business	52300.00
0005433009048	22864	Business	52300.00
0005433810652	22864	Business	52300.00
0005433009027	22864	Business	52300.00
0005433009296	22864	Business	52300.00
0005433009185	22864	Business	52300.00
0005433009224	22864	Business	52300.00
0005433009156	22864	Business	52300.00
0005433810648	22864	Economy	17400.00
0005433009182	22864	Economy	17400.00
0005433810653	22864	Economy	17400.00
0005433009122	22864	Economy	17400.00
0005433009120	22864	Economy	17400.00
0005433009130	22864	Economy	17400.00
0005433009102	22864	Economy	17400.00
0005433009101	22864	Economy	17400.00
0005433009396	22864	Economy	19200.00
0005433009295	22864	Economy	19200.00
0005433009103	22864	Economy	19200.00
0005433009216	22864	Economy	19200.00
0005433009143	22864	Economy	17400.00
0005433009226	22864	Economy	17400.00
0005433009274	22864	Economy	17400.00
0005433009225	22864	Economy	17400.00
0005433810654	22864	Economy	17400.00
0005433009083	22864	Economy	17400.00
0005433009172	22864	Economy	17400.00
0005433009188	22864	Economy	17400.00
0005433009314	22864	Economy	17400.00
0005433009298	22864	Economy	17400.00
0005433009299	22864	Economy	17400.00
0005433009208	22864	Economy	17400.00
0005433009275	22864	Economy	17400.00
0005433008985	22864	Economy	17400.00
0005433009116	22864	Economy	17400.00
0005433009395	22864	Economy	17400.00
0005433009117	22864	Economy	17400.00
0005433009340	22864	Economy	17400.00
0005433009297	22864	Economy	17400.00
0005433810649	22864	Economy	17400.00
0005433009123	22864	Economy	17400.00
0005433810650	22864	Economy	17400.00
0005433009142	22864	Economy	17400.00
0005433810655	22864	Economy	17400.00
0005433009155	22864	Economy	17400.00
0005433009106	22864	Economy	17400.00
0005433810651	22864	Economy	17400.00
0005433009215	22864	Economy	17400.00
0005433009137	22864	Economy	17400.00
0005433009197	22864	Economy	17400.00
0005433009339	22864	Economy	17400.00
0005433008986	22864	Economy	17400.00
0005433009258	22864	Economy	17400.00
0005433009036	22864	Economy	17400.00
0005433009082	22864	Economy	17400.00
0005433009187	22864	Economy	17400.00
0005433009046	22864	Economy	17400.00
0005433009207	22864	Economy	17400.00
0005433810647	22864	Economy	17400.00
0005433009121	22864	Economy	17400.00
0005433009218	22864	Economy	17400.00
0005434926155	14939	Business	22900.00
0005434926217	14939	Business	22900.00
0005434926213	14939	Economy	7600.00
0005434926156	14939	Economy	7600.00
0005434926212	14939	Economy	7600.00
0005434926170	14939	Economy	7600.00
0005434926059	14939	Economy	7600.00
0005434926063	14939	Economy	7600.00
0005434926140	14939	Economy	7600.00
0005434926136	14939	Economy	7600.00
0005434926208	14939	Economy	7600.00
0005434926157	14939	Economy	7600.00
0005434926181	14939	Economy	7600.00
0005434926142	14939	Economy	7600.00
0005434926147	14939	Economy	7600.00
0005434926190	14939	Economy	7600.00
0005434926058	14939	Economy	7600.00
0005434926196	14939	Economy	7600.00
0005434926189	14939	Economy	7600.00
0005434926188	14939	Economy	7600.00
0005434926186	14939	Economy	7600.00
0005434926135	14939	Economy	7600.00
0005434926158	14939	Economy	7600.00
0005434926211	14939	Economy	7600.00
0005434926209	14939	Economy	7600.00
0005434926218	14939	Economy	7600.00
0005434926210	14939	Economy	7600.00
0005434926471	20538	Business	22900.00
0005434926454	20538	Business	22900.00
0005434926444	20538	Business	22900.00
0005434926462	20538	Business	22900.00
0005434926468	20538	Economy	8400.00
0005434926473	20538	Economy	7600.00
0005434926466	20538	Economy	7600.00
0005434926463	20538	Economy	7600.00
0005434926447	20538	Economy	7600.00
0005434926461	20538	Economy	7600.00
0005434926453	20538	Economy	7600.00
0005434926443	20538	Economy	7600.00
0005434926470	20538	Economy	7600.00
0005434926448	20538	Economy	7600.00
0005434926458	20538	Economy	7600.00
0005434926442	20538	Economy	7600.00
0005434926445	20538	Economy	7600.00
0005434926457	20538	Economy	7600.00
0005434926446	20538	Economy	7600.00
0005434926452	20538	Economy	7600.00
0005434926441	20538	Economy	7600.00
0005434926451	20538	Economy	7600.00
0005434926440	20538	Economy	7600.00
0005434926464	20538	Economy	7600.00
0005434926467	20538	Economy	7600.00
0005434926459	20538	Economy	7600.00
0005434926472	20538	Economy	7600.00
0005434926474	20538	Economy	7600.00
0005434926450	20538	Economy	7600.00
0005434926460	20538	Economy	7600.00
0005434926449	20538	Economy	7600.00
0005434926455	20538	Economy	7600.00
0005434926469	20538	Economy	7600.00
0005434926465	20538	Economy	7600.00
0005434926456	20538	Economy	7600.00
0005435999410	15797	Economy	8900.00
0005435488316	15797	Economy	8900.00
0005435488312	15797	Economy	8900.00
0005435999385	15797	Economy	8100.00
0005435999438	15797	Economy	8100.00
0005435488301	15797	Economy	8100.00
0005435488314	15797	Economy	8100.00
0005435999386	15797	Economy	8100.00
0005435999486	15797	Economy	8100.00
0005435488308	15797	Economy	8100.00
0005435488303	15797	Economy	8100.00
0005435488298	15797	Economy	8100.00
0005435488318	15797	Economy	8100.00
0005435488300	15797	Economy	8100.00
0005435999405	15797	Economy	8100.00
0005435488307	15797	Economy	8100.00
0005435488296	15797	Economy	8100.00
0005435999487	15797	Economy	8100.00
0005435488295	15797	Economy	8100.00
0005435488299	15797	Economy	8100.00
0005435488302	15797	Economy	8100.00
0005435999406	15797	Economy	8100.00
0005435488309	15797	Economy	8100.00
0005435488311	15797	Economy	8100.00
0005435488306	15797	Economy	8100.00
0005435999440	15797	Economy	8100.00
0005435488305	15797	Economy	8100.00
0005435999425	15797	Economy	8100.00
0005435999488	15797	Economy	8100.00
0005435999436	15797	Economy	8100.00
0005435488317	15797	Economy	8100.00
0005435488315	15797	Economy	8100.00
0005435999441	15797	Economy	8100.00
0005435999470	15797	Economy	8100.00
0005435488313	15797	Economy	8100.00
0005435488297	15797	Economy	8100.00
0005435488304	15797	Economy	8100.00
0005435999426	15797	Economy	8100.00
0005435488310	15797	Economy	8100.00
0005435999437	15797	Economy	8100.00
0005435999431	15797	Economy	8100.00
0005435999506	15797	Economy	8100.00
0005435488020	19666	Economy	8900.00
0005435999615	19666	Economy	8900.00
0005435999611	19666	Economy	8900.00
0005435488169	19666	Economy	8900.00
0005435999603	19666	Economy	8100.00
0005435999609	19666	Economy	8100.00
0005435488065	19666	Economy	8100.00
0005435488087	19666	Economy	8100.00
0005435999608	19666	Economy	8100.00
0005435999622	19666	Economy	8100.00
0005435999601	19666	Economy	8100.00
0005435488111	19666	Economy	8100.00
0005435488064	19666	Economy	8100.00
0005435488105	19666	Economy	8100.00
0005435488017	19666	Economy	8100.00
0005435999619	19666	Economy	8100.00
0005435999605	19666	Economy	8100.00
0005435488113	19666	Economy	8100.00
0005435488066	19666	Economy	8100.00
0005435999613	19666	Economy	8100.00
0005435999607	19666	Economy	8100.00
0005435488047	19666	Economy	8100.00
0005435999620	19666	Economy	8100.00
0005435488016	19666	Economy	8100.00
0005435488008	19666	Economy	8100.00
0005435488106	19666	Economy	8100.00
0005435999617	19666	Economy	8100.00
0005435999623	19666	Economy	8100.00
0005435999614	19666	Economy	8100.00
0005435999598	19666	Economy	8100.00
0005435999599	19666	Economy	8100.00
0005435488137	19666	Economy	8100.00
0005435999604	19666	Economy	8100.00
0005435488067	19666	Economy	8100.00
0005435999606	19666	Economy	8100.00
0005435999597	19666	Economy	8100.00
0005435488075	19666	Economy	8100.00
0005435999621	19666	Economy	8100.00
0005435999612	19666	Economy	8100.00
0005435999618	19666	Economy	8100.00
0005435999602	19666	Economy	8100.00
0005435487951	19666	Economy	8100.00
0005435999600	19666	Economy	8100.00
0005435488012	19666	Economy	8100.00
0005435488183	19666	Economy	8100.00
0005435999610	19666	Economy	8100.00
0005435488009	19666	Economy	8100.00
0005435999616	19666	Economy	8100.00
0005435840059	5982	Business	199300.00
0005435840057	5982	Business	199300.00
0005435840068	5982	Business	199300.00
0005435840074	5982	Business	199300.00
0005432142318	5982	Business	199300.00
0005435840073	5982	Business	199300.00
0005435840054	5982	Business	199300.00
0005435473034	5982	Economy	66400.00
0005432142320	5982	Economy	66400.00
0005435840055	5982	Economy	66400.00
0005435840079	5982	Economy	66400.00
0005435473033	5982	Economy	73100.00
0005435840078	5982	Economy	73100.00
0005435473062	5982	Economy	73100.00
0005435840056	5982	Economy	66400.00
0005432142321	5982	Economy	66400.00
0005435840065	5982	Economy	66400.00
0005432660864	5982	Economy	66400.00
0005435840058	5982	Economy	66400.00
0005435840075	5982	Economy	66400.00
0005432659753	5982	Economy	66400.00
0005435840077	5982	Economy	66400.00
0005435840052	5982	Economy	66400.00
0005435840067	5982	Economy	66400.00
0005435840069	5982	Economy	66400.00
0005435473050	5982	Economy	66400.00
0005432537092	5982	Economy	66400.00
0005435840061	5982	Economy	66400.00
0005435840076	5982	Economy	66400.00
0005435840060	5982	Economy	66400.00
0005435472953	5982	Economy	66400.00
0005435473054	5982	Economy	66400.00
0005435840062	5982	Economy	66400.00
0005435473011	5982	Economy	66400.00
0005435840053	5982	Economy	66400.00
0005435840063	5982	Economy	66400.00
0005435840066	5982	Economy	66400.00
0005435840072	5982	Economy	66400.00
0005435473014	5982	Economy	66400.00
0005435840071	5982	Economy	66400.00
0005435473049	5982	Economy	66400.00
0005432660865	5982	Economy	66400.00
0005432142319	5982	Economy	66400.00
0005435473012	5982	Economy	66400.00
0005435840070	5982	Economy	66400.00
0005435472945	5982	Economy	66400.00
0005432658639	5982	Economy	66400.00
0005435473043	5982	Economy	66400.00
0005432658637	5982	Economy	66400.00
0005432658638	5982	Economy	66400.00
0005435473063	5982	Economy	66400.00
0005435840064	5982	Economy	66400.00
0005435839803	18057	Business	199300.00
0005435839858	18057	Business	199300.00
0005435839741	18057	Business	199300.00
0005435839776	18057	Business	199300.00
0005435839862	18057	Business	199300.00
0005435473161	18057	Economy	66400.00
0005435839819	18057	Economy	66400.00
0005432537107	18057	Economy	66400.00
0005435839840	18057	Economy	66400.00
0005435473159	18057	Economy	66400.00
0005435839854	18057	Economy	66400.00
0005435839804	18057	Economy	73100.00
0005432667476	18057	Economy	66400.00
0005432537105	18057	Economy	66400.00
0005435473156	18057	Economy	66400.00
0005435839689	18057	Economy	66400.00
0005435839857	18057	Economy	66400.00
0005435839863	18057	Economy	66400.00
0005435839740	18057	Economy	66400.00
0005435839889	18057	Economy	66400.00
0005432667479	18057	Economy	66400.00
0005435839690	18057	Economy	66400.00
0005435473157	18057	Economy	66400.00
0005435839884	18057	Economy	66400.00
0005435839867	18057	Economy	66400.00
0005435473165	18057	Economy	66400.00
0005435473158	18057	Economy	66400.00
0005435473162	18057	Economy	66400.00
0005435473166	18057	Economy	66400.00
0005435839915	18057	Economy	66400.00
0005435473160	18057	Economy	66400.00
0005435473164	18057	Economy	66400.00
0005435839931	18057	Economy	66400.00
0005435839882	18057	Economy	66400.00
0005435473167	18057	Economy	66400.00
0005435839835	18057	Economy	66400.00
0005435839963	18057	Economy	66400.00
0005435473168	18057	Economy	66400.00
0005432537106	18057	Economy	66400.00
0005435839912	18057	Economy	66400.00
0005435839869	18057	Economy	66400.00
0005435839778	18057	Economy	66400.00
0005435839870	18057	Economy	66400.00
0005435473155	18057	Economy	66400.00
0005435473169	18057	Economy	66400.00
0005435839883	18057	Economy	66400.00
0005435839834	18057	Economy	66400.00
0005435839913	18057	Economy	66400.00
0005435839818	18057	Economy	66400.00
0005435473163	18057	Economy	66400.00
0005435839777	18057	Economy	66400.00
0005435839833	18057	Economy	66400.00
0005435104123	23009	Business	15700.00
0005435104120	23009	Business	15700.00
0005435104124	23009	Business	15700.00
0005435104109	23009	Economy	5200.00
0005433285765	23009	Economy	5200.00
0005435104119	23009	Economy	5200.00
0005433285708	23009	Economy	5200.00
0005433285687	23009	Economy	5200.00
0005435104118	23009	Economy	5200.00
0005435104122	23009	Economy	5200.00
0005433285787	23009	Economy	5200.00
0005433285638	23009	Economy	5200.00
0005433285633	23009	Economy	5200.00
0005433285738	23009	Economy	5700.00
0005433285632	23009	Economy	5700.00
0005433285739	23009	Economy	5200.00
0005435104115	23009	Economy	5200.00
0005435104108	23009	Economy	5200.00
0005435104116	23009	Economy	5200.00
0005435104114	23009	Economy	5200.00
0005435104113	23009	Economy	5200.00
0005433285709	23009	Economy	5200.00
0005433285657	23009	Economy	5200.00
0005433285801	23009	Economy	5200.00
0005435104117	23009	Economy	5200.00
0005433285766	23009	Economy	5200.00
0005433285791	23009	Economy	5200.00
0005433285691	23009	Economy	5200.00
0005433285677	23009	Economy	5200.00
0005433285788	23009	Economy	5200.00
0005435104112	23009	Economy	5200.00
0005433285692	23009	Economy	5200.00
0005433285773	23009	Economy	5200.00
0005433285637	23009	Economy	5200.00
0005433285693	23009	Economy	5200.00
0005433285858	23009	Economy	5200.00
0005433285749	23009	Economy	5200.00
0005433285690	23009	Economy	5200.00
0005435104110	23009	Economy	5200.00
0005435104121	23009	Economy	5200.00
0005435104111	23009	Economy	5200.00
0005433285978	32072	Business	15700.00
0005433285964	32072	Business	15700.00
0005433285970	32072	Business	15700.00
0005433285977	32072	Business	15700.00
0005433285976	32072	Business	15700.00
0005433285966	32072	Economy	5200.00
0005433285992	32072	Economy	5200.00
0005433285971	32072	Economy	5200.00
0005433285993	32072	Economy	5200.00
0005435104002	32072	Economy	5200.00
0005433285983	32072	Economy	5200.00
0005433285965	32072	Economy	5200.00
0005433285980	32072	Economy	5200.00
0005433285974	32072	Economy	5200.00
0005433285982	32072	Economy	5200.00
0005433285988	32072	Economy	5200.00
0005433285969	32072	Economy	5200.00
0005435103981	32072	Economy	5700.00
0005433285967	32072	Economy	5700.00
0005433285989	32072	Economy	5700.00
0005433285979	32072	Economy	5200.00
0005433285981	32072	Economy	5200.00
0005433285973	32072	Economy	5200.00
0005433285991	32072	Economy	5200.00
0005433285963	32072	Economy	5200.00
0005433285975	32072	Economy	5200.00
0005433285990	32072	Economy	5200.00
0005433285987	32072	Economy	5200.00
0005435104007	32072	Economy	5200.00
0005433285972	32072	Economy	5200.00
0005433285968	32072	Economy	5200.00
0005435103997	32072	Economy	5200.00
0005433285984	32072	Economy	5200.00
0005435103998	32072	Economy	5200.00
0005433285986	32072	Economy	5200.00
0005433285985	32072	Economy	5200.00
0005435103992	32072	Economy	5200.00
0005435104003	32072	Economy	5200.00
0005435852637	23866	Economy	13500.00
0005433475758	23866	Economy	12300.00
0005433475759	23866	Economy	12300.00
0005433475765	23866	Economy	12300.00
0005433475762	23866	Economy	12300.00
0005435852634	23866	Economy	12300.00
0005433475780	23866	Economy	12300.00
0005433475767	23866	Economy	12300.00
0005435852635	23866	Economy	12300.00
0005435852636	23866	Economy	12300.00
0005435852633	23866	Economy	12300.00
0005432211669	30622	Business	42100.00
0005434068271	30622	Business	42100.00
0005435631036	30622	Business	42100.00
0005434068511	30622	Business	42100.00
0005435215047	30622	Business	42100.00
0005432529379	30622	Business	42100.00
0005435215037	30622	Business	42100.00
0005432530136	30622	Business	42100.00
0005434068549	30622	Business	42100.00
0005432529374	30622	Business	42100.00
0005434068418	30622	Business	42100.00
0005434068594	30622	Business	42100.00
0005435215055	30622	Business	42100.00
0005432530407	30622	Business	42100.00
0005434068479	30622	Business	42100.00
0005432529363	30622	Business	42100.00
0005434068550	30622	Business	42100.00
0005432529429	30622	Business	42100.00
0005432530402	30622	Business	42100.00
0005432159959	30622	Business	42100.00
0005432535882	30622	Business	42100.00
0005434068342	30622	Business	42100.00
0005432529362	30622	Business	42100.00
0005432529144	30622	Business	42100.00
0005432529512	30622	Business	42100.00
0005435215088	30622	Business	42100.00
0005435215079	30622	Business	42100.00
0005432533320	30622	Business	42100.00
0005434068611	30622	Business	42100.00
0005435215060	30622	Comfort	23900.00
0005432159960	30622	Comfort	23900.00
0005432530075	30622	Comfort	23900.00
0005435215070	30622	Comfort	23900.00
0005434068307	30622	Comfort	23900.00
0005432535912	30622	Comfort	23900.00
0005434068381	30622	Comfort	23900.00
0005434068634	30622	Comfort	23900.00
0005435215032	30622	Comfort	23900.00
0005432529847	30622	Comfort	23900.00
0005432529972	30622	Comfort	23900.00
0005435215044	30622	Comfort	23900.00
0005434068400	30622	Comfort	23900.00
0005434068543	30622	Comfort	23900.00
0005434068506	30622	Comfort	23900.00
0005432529787	30622	Comfort	23900.00
0005432530028	30622	Comfort	23900.00
0005432530320	30622	Comfort	23900.00
0005432211668	30622	Comfort	23900.00
0005434068540	30622	Comfort	23900.00
0005432530174	30622	Comfort	23900.00
0005432428974	30622	Comfort	23900.00
0005434068213	30622	Comfort	23900.00
0005432529622	30622	Comfort	23900.00
0005434068614	30622	Comfort	23900.00
0005432529996	30622	Comfort	23900.00
0005432530006	30622	Comfort	23900.00
0005435215061	30622	Comfort	23900.00
0005434067970	30622	Comfort	23900.00
0005434068354	30622	Comfort	23900.00
0005435215062	30622	Comfort	23900.00
0005435215056	30622	Comfort	23900.00
0005434068270	30622	Comfort	23900.00
0005432529990	30622	Comfort	23900.00
0005432529899	30622	Comfort	23900.00
0005432529762	30622	Comfort	23900.00
0005432535896	30622	Comfort	23900.00
0005432529600	30622	Comfort	23900.00
0005432530233	30622	Comfort	23900.00
0005432530406	30622	Comfort	23900.00
0005432211667	30622	Economy	14000.00
0005434068376	30622	Economy	14000.00
0005434068566	30622	Economy	14000.00
0005432530248	30622	Economy	14000.00
0005435215084	30622	Economy	14000.00
0005434068343	30622	Economy	14000.00
0005434068502	30622	Economy	14000.00
0005432529688	30622	Economy	14000.00
0005435215093	30622	Economy	14000.00
0005434068604	30622	Economy	14000.00
0005432529892	30622	Economy	14000.00
0005434068292	30622	Economy	14000.00
0005432529693	30622	Economy	14000.00
0005434068380	30622	Economy	14000.00
0005432530187	30622	Economy	14000.00
0005435215059	30622	Economy	14000.00
0005432529724	30622	Economy	14000.00
0005434068512	30622	Economy	14000.00
0005432529692	30622	Economy	14000.00
0005432529975	30622	Economy	14000.00
0005435215067	30622	Economy	14000.00
0005432529628	30622	Economy	14000.00
0005432529068	30622	Economy	14000.00
0005432529977	30622	Economy	14000.00
0005435631037	30622	Economy	14000.00
0005435215048	30622	Economy	14000.00
0005432530330	30622	Economy	14000.00
0005434068671	30622	Economy	14000.00
0005434068585	30622	Economy	14000.00
0005432530090	30622	Economy	14000.00
0005432535903	30622	Economy	14000.00
0005432529740	30622	Economy	14000.00
0005432530232	30622	Economy	14000.00
0005432529974	30622	Economy	14000.00
0005435215045	30622	Economy	14000.00
0005434068278	30622	Economy	14000.00
0005432529897	30622	Economy	14000.00
0005432529723	30622	Economy	14000.00
0005435725710	30622	Economy	14000.00
0005432529852	30622	Economy	14000.00
0005433656748	30622	Economy	14000.00
0005432529067	30622	Economy	14000.00
0005434068399	30622	Economy	14000.00
0005434068390	30622	Economy	14000.00
0005432529547	30622	Economy	14000.00
0005432529909	30622	Economy	14000.00
0005435215069	30622	Economy	14000.00
0005432530234	30622	Economy	14000.00
0005434068378	30622	Economy	14000.00
0005432529605	30622	Economy	14000.00
0005435215083	30622	Economy	14000.00
0005434068290	30622	Economy	14000.00
0005432428987	30622	Economy	14000.00
0005432529754	30622	Economy	14000.00
0005432530091	30622	Economy	14000.00
0005435215089	30622	Economy	14000.00
0005434068494	30622	Economy	14000.00
0005432529572	30622	Economy	14000.00
0005434068568	30622	Economy	14000.00
0005432529597	30622	Economy	14000.00
0005434068613	30622	Economy	14000.00
0005432159962	30622	Economy	14000.00
0005432529786	30622	Economy	15400.00
0005434068603	30622	Economy	14000.00
0005435215098	30622	Economy	15400.00
0005435215063	30622	Economy	14000.00
0005434068441	30622	Economy	15400.00
0005432529873	30622	Economy	14000.00
0005434068279	30622	Economy	14000.00
0005432529918	30622	Economy	15400.00
0005432529567	30622	Economy	15400.00
0005435215078	30622	Economy	14000.00
0005432529771	30622	Economy	14000.00
0005435215053	30622	Economy	14000.00
0005434068519	30622	Economy	14000.00
0005434068673	30622	Economy	14000.00
0005432529853	30622	Economy	14000.00
0005432530153	30622	Economy	14000.00
0005432530165	30622	Economy	14000.00
0005432535913	30622	Economy	14000.00
0005434068571	30622	Economy	14000.00
0005434068306	30622	Economy	14000.00
0005435215081	30622	Economy	14000.00
0005434068214	30622	Economy	14000.00
0005435215086	30622	Economy	14000.00
0005432529659	30622	Economy	14000.00
0005432529911	30622	Economy	14000.00
0005432529726	30622	Economy	14000.00
0005432529721	30622	Economy	14000.00
0005432529709	30622	Economy	14000.00
0005434068635	30622	Economy	14000.00
0005432529848	30622	Economy	14000.00
0005435215046	30622	Economy	14000.00
0005432530302	30622	Economy	14000.00
0005435215033	30622	Economy	14000.00
0005434068618	30622	Economy	14000.00
0005435215035	30622	Economy	14000.00
0005432529417	30622	Economy	14000.00
0005432530181	30622	Economy	14000.00
0005432530113	30622	Economy	14000.00
0005435215051	30622	Economy	14000.00
0005432530104	30622	Economy	14000.00
0005432529817	30622	Economy	14000.00
0005432529267	30622	Economy	14000.00
0005434068551	30622	Economy	14000.00
0005435725713	30622	Economy	14000.00
0005435215090	30622	Economy	14000.00
0005432533326	30622	Economy	14000.00
0005432530327	30622	Economy	14000.00
0005435215096	30622	Economy	14000.00
0005432530265	30622	Economy	14000.00
0005435215049	30622	Economy	14000.00
0005434068524	30622	Economy	14000.00
0005432529630	30622	Economy	14000.00
0005432530110	30622	Economy	14000.00
0005435215076	30622	Economy	14000.00
0005432211666	30622	Economy	14000.00
0005432530129	30622	Economy	14000.00
0005435215034	30622	Economy	14000.00
0005432530025	30622	Economy	14000.00
0005432529821	30622	Economy	14000.00
0005434068391	30622	Economy	14000.00
0005432529532	30622	Economy	14000.00
0005434068586	30622	Economy	14000.00
0005434068148	30622	Economy	14000.00
0005435215042	30622	Economy	14000.00
0005432529647	30622	Economy	14000.00
0005432530175	30622	Economy	14000.00
0005432530127	30622	Economy	14000.00
0005432529513	30622	Economy	14000.00
0005432530109	30622	Economy	14000.00
0005432533338	30622	Economy	14000.00
0005433656745	30622	Economy	14000.00
0005434068268	30622	Economy	14000.00
0005434068525	30622	Economy	14000.00
0005432529921	30622	Economy	14000.00
0005432211670	30622	Economy	14000.00
0005434068203	30622	Economy	14000.00
0005432528935	30622	Economy	14000.00
0005432533336	30622	Economy	14000.00
0005432529922	30622	Economy	14000.00
0005433656746	30622	Economy	14000.00
0005432529562	30622	Economy	14000.00
0005434068468	30622	Economy	14000.00
0005432529761	30622	Economy	14000.00
0005432529919	30622	Economy	14000.00
0005433656747	30622	Economy	14000.00
0005435215054	30622	Economy	14000.00
0005432529789	30622	Economy	14000.00
0005435215099	30622	Economy	14000.00
0005432211672	30622	Economy	14000.00
0005435215095	30622	Economy	14000.00
0005435215036	30622	Economy	14000.00
0005434068552	30622	Economy	14000.00
0005432529640	30622	Economy	14000.00
0005435215085	30622	Economy	14000.00
0005434068666	30622	Economy	14000.00
0005432529898	30622	Economy	14000.00
0005432530572	30622	Economy	14000.00
0005432159961	30622	Economy	14000.00
0005435215091	30622	Economy	14000.00
0005432529995	30622	Economy	14000.00
0005435215075	30622	Economy	14000.00
0005432529502	30622	Economy	14000.00
0005434068377	30622	Economy	14000.00
0005435215082	30622	Economy	14000.00
0005432529778	30622	Economy	14000.00
0005432529522	30622	Economy	14000.00
0005435215043	30622	Economy	14000.00
0005435725711	30622	Economy	14000.00
0005435215094	30622	Economy	14000.00
0005434068612	30622	Economy	14000.00
0005432529910	30622	Economy	14000.00
0005435215073	30622	Economy	14000.00
0005432529681	30622	Economy	14000.00
0005434068345	30622	Economy	14000.00
0005434068607	30622	Economy	14000.00
0005432530183	30622	Economy	14000.00
0005432529268	30622	Economy	15400.00
0005432529694	30622	Economy	15400.00
0005434068499	30622	Economy	15400.00
0005435215071	30622	Economy	15400.00
0005432529531	30622	Economy	14000.00
0005432529601	30622	Economy	14000.00
0005434068665	30622	Economy	14000.00
0005435215077	30622	Economy	14000.00
0005432211673	30622	Economy	14000.00
0005432530321	30622	Economy	14000.00
0005435215074	30622	Economy	14000.00
0005432530571	30622	Economy	14000.00
0005434068606	30622	Economy	14000.00
0005434068383	30622	Economy	14000.00
0005435215092	30622	Economy	14000.00
0005434068505	30622	Economy	14000.00
0005434068387	30622	Economy	14000.00
0005435215038	30622	Economy	14000.00
0005434068121	30622	Economy	14000.00
0005435215039	30622	Economy	14000.00
0005435215040	30622	Economy	14000.00
0005435215065	30622	Economy	14000.00
0005432529958	30622	Economy	14000.00
0005435215087	30622	Economy	14000.00
0005432530128	30622	Economy	14000.00
0005432529976	30622	Economy	14000.00
0005432530007	30622	Economy	14000.00
0005432529580	30622	Economy	14000.00
0005434068273	30622	Economy	14000.00
0005434068274	30622	Economy	14000.00
0005432529748	30622	Economy	14000.00
0005432529670	30622	Economy	14000.00
0005434068510	30622	Economy	14000.00
0005435631035	30622	Economy	14000.00
0005432529888	30622	Economy	14000.00
0005432529860	30622	Economy	14000.00
0005432529971	30622	Economy	14000.00
0005435215097	30622	Economy	14000.00
0005432535883	30622	Economy	14000.00
0005435215041	30622	Economy	14000.00
0005432535906	30622	Economy	14000.00
0005434068291	30622	Economy	14000.00
0005432535898	30622	Economy	14000.00
0005432535901	30622	Economy	14000.00
0005435215058	30622	Economy	14000.00
0005432529780	30622	Economy	14000.00
0005435215068	30622	Economy	14000.00
0005432529266	30622	Economy	14000.00
0005434068401	30622	Economy	14000.00
0005434068087	30622	Economy	14000.00
0005434067971	30622	Economy	14000.00
0005432529595	30622	Economy	14000.00
0005432529814	30622	Economy	14000.00
0005432529920	30622	Economy	14000.00
0005432530589	30622	Economy	14000.00
0005435215080	30622	Economy	14000.00
0005432529725	30622	Economy	14000.00
0005432529682	30622	Economy	14000.00
0005434067969	30622	Economy	14000.00
0005435215057	30622	Economy	14000.00
0005434068259	30622	Economy	14000.00
0005432535899	30622	Economy	14000.00
0005434068303	30622	Economy	14000.00
0005432529631	30622	Economy	14000.00
0005435215064	30622	Economy	14000.00
0005432530030	30622	Economy	14000.00
0005434068670	30622	Economy	14000.00
0005432529521	30622	Economy	14000.00
0005432533337	30622	Economy	14000.00
0005434068346	30622	Economy	14000.00
0005432530108	30622	Economy	14000.00
0005434068088	30622	Economy	14000.00
0005432529705	30622	Economy	14000.00
0005432530403	30622	Economy	14000.00
0005432529575	30622	Economy	14000.00
0005432428975	30622	Economy	14000.00
0005432530231	30622	Economy	14000.00
0005432535888	30622	Economy	14000.00
0005435215052	30622	Economy	14000.00
0005432529722	30622	Economy	14000.00
0005435215072	30622	Economy	14000.00
0005432530166	30622	Economy	14000.00
0005435215050	30622	Economy	14000.00
0005432530279	30622	Economy	14000.00
0005432428973	30622	Economy	14000.00
0005432529669	30622	Economy	14000.00
0005434068567	30622	Economy	14000.00
0005432211671	30622	Economy	14000.00
0005434068344	30622	Economy	14000.00
0005432529671	30622	Economy	14000.00
0005434068417	30622	Economy	14000.00
0005435215066	30622	Economy	14000.00
0005432533325	30622	Economy	14000.00
0005432529989	30622	Economy	14000.00
0005432529881	30622	Economy	14000.00
0005432529609	30622	Economy	14000.00
0005432529503	30622	Economy	14000.00
0005432529914	30622	Economy	14000.00
0005434068336	30622	Economy	14000.00
0005432535902	30622	Economy	14000.00
0005435725712	30622	Economy	14000.00
0005432529864	30622	Economy	14000.00
0005435653583	24817	Business	9800.00
0005433368719	24817	Business	9800.00
0005433368749	24817	Business	9800.00
0005433368714	24817	Business	9800.00
0005433368738	24817	Business	9800.00
0005435653540	24817	Business	9800.00
0005435653652	24817	Business	9800.00
0005433368743	24817	Business	9800.00
0005433368730	24817	Business	9800.00
0005435653653	24817	Economy	3300.00
0005433368746	24817	Economy	3300.00
0005435653488	24817	Economy	3300.00
0005435653546	24817	Economy	3300.00
0005433368718	24817	Economy	3300.00
0005433368726	24817	Economy	3300.00
0005435653495	24817	Economy	3300.00
0005435653539	24817	Economy	3300.00
0005435653587	24817	Economy	3300.00
0005433368724	24817	Economy	3600.00
0005433368736	24817	Economy	3600.00
0005433368748	24817	Economy	3600.00
0005433368727	24817	Economy	3600.00
0005435653545	24817	Economy	3600.00
0005435653494	24817	Economy	3300.00
0005433368720	24817	Economy	3300.00
0005435653442	24817	Economy	3300.00
0005433368716	24817	Economy	3300.00
0005433368745	24817	Economy	3300.00
0005433368725	24817	Economy	3300.00
0005433368723	24817	Economy	3300.00
0005433368740	24817	Economy	3300.00
0005433368742	24817	Economy	3300.00
0005435653496	24817	Economy	3300.00
0005435653590	24817	Economy	3300.00
0005435653632	24817	Economy	3300.00
0005433368717	24817	Economy	3300.00
0005435653621	24817	Economy	3300.00
0005435653614	24817	Economy	3300.00
0005433368732	24817	Economy	3300.00
0005433368751	24817	Economy	3300.00
0005435653557	24817	Economy	3300.00
0005435653636	24817	Economy	3300.00
0005435653644	24817	Economy	3300.00
0005433368729	24817	Economy	3300.00
0005433368731	24817	Economy	3300.00
0005435653667	24817	Economy	3300.00
0005435653671	24817	Economy	3300.00
0005433368715	24817	Economy	3300.00
0005435653593	24817	Economy	3300.00
0005433368739	24817	Economy	3300.00
0005433368735	24817	Economy	3300.00
0005433368747	24817	Economy	3300.00
0005435653683	24817	Economy	3300.00
0005435653600	24817	Economy	3300.00
0005435653500	24817	Economy	3300.00
0005435653670	24817	Economy	3300.00
0005433368750	24817	Economy	3300.00
0005435653427	24817	Economy	3300.00
0005435653594	24817	Economy	3300.00
0005433368721	24817	Economy	3300.00
0005435653541	24817	Economy	3300.00
0005433368734	24817	Economy	3300.00
0005435653499	24817	Economy	3300.00
0005433368722	24817	Economy	3300.00
0005433368728	24817	Economy	3300.00
0005433368737	24817	Economy	3300.00
0005435653441	24817	Economy	3300.00
0005435653501	24817	Economy	3300.00
0005433368733	24817	Economy	3300.00
0005435653605	24817	Economy	3300.00
0005433368744	24817	Economy	3300.00
0005435653597	24817	Economy	3300.00
0005435653635	24817	Economy	3300.00
0005433368741	24817	Economy	3300.00
0005435653591	24817	Economy	3300.00
0005435653589	24817	Economy	3300.00
0005435949818	23315	Economy	18700.00
0005435949814	23315	Economy	18700.00
0005435949810	23315	Economy	18700.00
0005435949813	23315	Economy	18700.00
0005435949805	23315	Economy	18700.00
0005435949815	23315	Economy	18700.00
0005435949806	23315	Economy	18700.00
0005435949792	23315	Economy	18700.00
0005435949821	23315	Economy	18700.00
0005434980470	2068	Economy	10500.00
0005434980482	2068	Economy	10500.00
0005434980478	2068	Economy	9500.00
0005434980463	2068	Economy	9500.00
0005434980471	2068	Economy	9500.00
0005434980458	2068	Economy	9500.00
0005434980464	2068	Economy	9500.00
0005434980459	2068	Economy	9500.00
0005434980472	2068	Economy	9500.00
0005435801765	2068	Economy	9500.00
0005434980455	2068	Economy	9500.00
0005434980469	2068	Economy	9500.00
0005434980475	2068	Economy	9500.00
0005434980454	2068	Economy	9500.00
0005434980477	2068	Economy	9500.00
0005434980461	2068	Economy	9500.00
0005434980468	2068	Economy	9500.00
0005434980456	2068	Economy	9500.00
0005434980476	2068	Economy	9500.00
0005434980466	2068	Economy	9500.00
0005434980474	2068	Economy	9500.00
0005434980460	2068	Economy	9500.00
0005434980481	2068	Economy	9500.00
0005435801766	2068	Economy	9500.00
0005434980462	2068	Economy	9500.00
0005434980467	2068	Economy	9500.00
0005434980480	2068	Economy	9500.00
0005434980473	2068	Economy	9500.00
0005434980453	2068	Economy	9500.00
0005434980465	2068	Economy	9500.00
0005434980479	2068	Economy	9500.00
0005434980457	2068	Economy	9500.00
0005435801748	23539	Economy	10500.00
0005434980193	23539	Economy	10500.00
0005435801724	23539	Economy	10500.00
0005434980132	23539	Economy	10500.00
0005435801747	23539	Economy	9500.00
0005434980190	23539	Economy	9500.00
0005434980206	23539	Economy	9500.00
0005434980262	23539	Economy	9500.00
0005435801745	23539	Economy	9500.00
0005434980055	23539	Economy	9500.00
0005434980292	23539	Economy	9500.00
0005434980054	23539	Economy	9500.00
0005434980284	23539	Economy	9500.00
0005434980163	23539	Economy	9500.00
0005434980107	23539	Economy	9500.00
0005435801746	23539	Economy	9500.00
0005435801725	23539	Economy	9500.00
0005434980161	23539	Economy	9500.00
0005434980291	23539	Economy	9500.00
0005434980166	23539	Economy	9500.00
0005435801726	23539	Economy	9500.00
0005434980233	23539	Economy	9500.00
0005434980023	23539	Economy	9500.00
0005434980203	23539	Economy	9500.00
0005434980184	23539	Economy	9500.00
0005434980085	23539	Economy	9500.00
0005435801744	23539	Economy	9500.00
0005434980210	23539	Economy	9500.00
0005434980125	23539	Economy	9500.00
0005434980131	23539	Economy	9500.00
0005434980137	23539	Economy	9500.00
0005434980162	23539	Economy	9500.00
0005434980056	23539	Economy	9500.00
0005434980138	23539	Economy	9500.00
0005434980191	23539	Economy	9500.00
0005434980211	23539	Economy	9500.00
0005434980204	23539	Economy	9500.00
0005434952617	2651	Economy	5300.00
0005434952616	2651	Economy	5300.00
0005434952614	2651	Economy	5300.00
0005434952615	2651	Economy	5300.00
0005433256462	2595	Economy	5300.00
0005433256474	28234	Economy	5300.00
0005434952589	28234	Economy	5300.00
0005434952586	28234	Economy	5300.00
0005433256472	28234	Economy	5300.00
0005433256473	28234	Economy	5300.00
0005434952587	28234	Economy	5300.00
0005433111556	19833	Economy	8700.00
0005433111557	19833	Economy	8700.00
0005433111555	19833	Economy	8700.00
0005433112413	19833	Economy	8700.00
0005434139253	11961	Business	9700.00
0005434139445	11961	Business	9700.00
0005434139225	11961	Business	9700.00
0005434139037	11961	Business	9700.00
0005434138954	11961	Business	9700.00
0005434139168	11961	Business	9700.00
0005434139027	11961	Business	9700.00
0005434139239	11961	Business	9700.00
0005434139382	11961	Business	9700.00
0005434139322	11961	Business	9700.00
0005434138980	11961	Economy	3200.00
0005434139220	11961	Economy	3200.00
0005434139189	11961	Economy	3200.00
0005434138965	11961	Economy	3200.00
0005434139310	11961	Economy	3200.00
0005434139343	11961	Economy	3200.00
0005434138979	11961	Economy	3200.00
0005434138958	11961	Economy	3200.00
0005434139160	11961	Economy	3200.00
0005434139285	11961	Economy	3200.00
0005434139252	11961	Economy	3500.00
0005434139210	11961	Economy	3500.00
0005434139331	11961	Economy	3500.00
0005434139169	11961	Economy	3500.00
0005434138966	11961	Economy	3200.00
0005434139269	11961	Economy	3200.00
0005434139501	11961	Economy	3200.00
0005434139244	11961	Economy	3200.00
0005434139472	11961	Economy	3200.00
0005434139491	11961	Economy	3200.00
0005434139028	11961	Economy	3200.00
0005434139284	11961	Economy	3200.00
0005434139430	11961	Economy	3200.00
0005434139190	11961	Economy	3200.00
0005434139187	11961	Economy	3200.00
0005434139185	11961	Economy	3200.00
0005434139335	11961	Economy	3200.00
0005434139152	11961	Economy	3200.00
0005434138953	11961	Economy	3200.00
0005434139429	11961	Economy	3200.00
0005434139238	11961	Economy	3200.00
0005434139025	11961	Economy	3200.00
0005434139334	11961	Economy	3200.00
0005434139159	11961	Economy	3200.00
0005434139024	11961	Economy	3200.00
0005434139416	11961	Economy	3200.00
0005434139188	11961	Economy	3200.00
0005434139282	11961	Economy	3200.00
0005434139305	11961	Economy	3200.00
0005434139095	11961	Economy	3200.00
0005434139036	11961	Economy	3200.00
0005434138960	11961	Economy	3200.00
0005434139332	11961	Economy	3200.00
0005434139352	11961	Economy	3200.00
0005434139495	11961	Economy	3200.00
0005434139309	11961	Economy	3200.00
0005434139374	11961	Economy	3200.00
0005434139333	11961	Economy	3200.00
0005434139410	11961	Economy	3200.00
0005434139155	11961	Economy	3200.00
0005434139414	11961	Economy	3200.00
0005434139432	11961	Economy	3200.00
0005434139316	11961	Economy	3200.00
0005434139403	11961	Economy	3200.00
0005434139484	11961	Economy	3200.00
0005434139063	11961	Economy	3200.00
0005434139336	11961	Economy	3200.00
0005434139494	11961	Economy	3200.00
0005434139493	11961	Economy	3200.00
0005434139266	11961	Economy	3200.00
0005434139428	11961	Economy	3200.00
0005434139402	11961	Economy	3200.00
0005434139151	11961	Economy	3200.00
0005434139023	11961	Economy	3200.00
0005434139390	11961	Economy	3200.00
0005434139447	11961	Economy	3200.00
0005434139306	11961	Economy	3200.00
0005434139273	11961	Economy	3200.00
0005434139283	11961	Economy	3200.00
0005434139270	11961	Economy	3200.00
0005434139411	11961	Economy	3200.00
0005434138990	11961	Economy	3200.00
0005434139436	11961	Economy	3200.00
0005434139461	11961	Economy	3200.00
0005434139415	11961	Economy	3200.00
0005434139468	11961	Economy	3200.00
0005434139373	11961	Economy	3200.00
0005434139158	11961	Economy	3200.00
0005434139871	28730	Business	9700.00
0005434139890	28730	Business	9700.00
0005434139930	28730	Business	9700.00
0005434139914	28730	Business	9700.00
0005434139939	28730	Business	9700.00
0005434139913	28730	Business	9700.00
0005434139920	28730	Economy	3200.00
0005434139910	28730	Economy	3200.00
0005434139896	28730	Economy	3200.00
0005434139921	28730	Economy	3200.00
0005434139918	28730	Economy	3200.00
0005434139870	28730	Economy	3200.00
0005434139883	28730	Economy	3200.00
0005434139901	28730	Economy	3200.00
0005434139934	28730	Economy	3500.00
0005434139937	28730	Economy	3500.00
0005434139881	28730	Economy	3500.00
0005434139886	28730	Economy	3500.00
0005434139925	28730	Economy	3200.00
0005434139903	28730	Economy	3200.00
0005434139891	28730	Economy	3200.00
0005434139884	28730	Economy	3200.00
0005434139923	28730	Economy	3200.00
0005434139931	28730	Economy	3200.00
0005434139905	28730	Economy	3200.00
0005434139908	28730	Economy	3200.00
0005434139933	28730	Economy	3200.00
0005434139936	28730	Economy	3200.00
0005434139938	28730	Economy	3200.00
0005434139915	28730	Economy	3200.00
0005434139899	28730	Economy	3200.00
0005434139911	28730	Economy	3200.00
0005434139887	28730	Economy	3200.00
0005434139876	28730	Economy	3200.00
0005434139867	28730	Economy	3200.00
0005434139875	28730	Economy	3200.00
0005434139868	28730	Economy	3200.00
0005434139872	28730	Economy	3200.00
0005434139917	28730	Economy	3200.00
0005434139935	28730	Economy	3200.00
0005434139894	28730	Economy	3200.00
0005434139907	28730	Economy	3200.00
0005434139924	28730	Economy	3200.00
0005434139906	28730	Economy	3200.00
0005434139873	28730	Economy	3200.00
0005434139912	28730	Economy	3200.00
0005434139882	28730	Economy	3200.00
0005434139932	28730	Economy	3200.00
0005434139940	28730	Economy	3200.00
0005434139866	28730	Economy	3200.00
0005434139928	28730	Economy	3200.00
0005434139895	28730	Economy	3200.00
0005434139879	28730	Economy	3200.00
0005434139927	28730	Economy	3200.00
0005434139926	28730	Economy	3200.00
0005434139898	28730	Economy	3200.00
0005434139919	28730	Economy	3200.00
0005434139880	28730	Economy	3200.00
0005434139878	28730	Economy	3200.00
0005434139874	28730	Economy	3200.00
0005434139929	28730	Economy	3200.00
0005434139902	28730	Economy	3200.00
0005434139900	28730	Economy	3200.00
0005434139885	28730	Economy	3200.00
0005434139889	28730	Economy	3200.00
0005434139865	28730	Economy	3200.00
0005434139916	28730	Economy	3200.00
0005434139892	28730	Economy	3200.00
0005434139888	28730	Economy	3200.00
0005434139909	28730	Economy	3200.00
0005434139877	28730	Economy	3200.00
0005434139922	28730	Economy	3200.00
0005434139897	28730	Economy	3200.00
0005434139869	28730	Economy	3200.00
0005434139904	28730	Economy	3200.00
0005434139893	28730	Economy	3200.00
0005435312830	6575	Economy	23000.00
0005434466565	6575	Economy	20900.00
0005435312834	6575	Economy	20900.00
0005434466573	6575	Economy	20900.00
0005434466568	6575	Economy	20900.00
0005434466571	6575	Economy	20900.00
0005434466567	6575	Economy	20900.00
0005435312836	6575	Economy	20900.00
0005434466564	6575	Economy	20900.00
0005434466566	6575	Economy	20900.00
0005435312846	6575	Economy	20900.00
0005434466572	6575	Economy	20900.00
0005435312835	6575	Economy	20900.00
0005434466569	6575	Economy	20900.00
0005434466570	6575	Economy	20900.00
0005434513615	19089	Economy	26000.00
0005434516099	19089	Economy	26000.00
0005434190449	19089	Economy	23600.00
0005434516109	19089	Economy	23600.00
0005434516100	19089	Economy	23600.00
0005434513613	19089	Economy	23600.00
0005434513612	19089	Economy	23600.00
0005434190446	19089	Economy	23600.00
0005434513605	19089	Economy	23600.00
0005434513607	19089	Economy	23600.00
0005434190451	19089	Economy	23600.00
0005434190452	19089	Economy	23600.00
0005434190450	19089	Economy	23600.00
0005434513611	19089	Economy	23600.00
0005434516103	19089	Economy	23600.00
0005434190447	19089	Economy	23600.00
0005434516105	19089	Economy	23600.00
0005434513604	19089	Economy	23600.00
0005434513597	19089	Economy	23600.00
0005434190453	19089	Economy	23600.00
0005434516115	19089	Economy	23600.00
0005434190448	19089	Economy	23600.00
0005434513596	19089	Economy	23600.00
0005434190454	19089	Economy	23600.00
0005434516102	19089	Economy	23600.00
0005434513609	19089	Economy	23600.00
0005434513608	19089	Economy	23600.00
0005434513616	19089	Economy	23600.00
0005434516108	19089	Economy	23600.00
0005433534547	6821	Economy	9900.00
0005433539068	6821	Economy	9900.00
0005433539060	6821	Economy	9900.00
0005433539061	6821	Economy	9900.00
0005435259795	6821	Economy	9900.00
0005433539064	6821	Economy	9900.00
0005433539063	6821	Economy	9900.00
0005433534546	6821	Economy	9900.00
0005433539065	6821	Economy	9900.00
0005433539066	6821	Economy	9900.00
0005433539067	6821	Economy	9900.00
0005433539062	6821	Economy	9900.00
0005435259823	6821	Economy	9900.00
0005433534528	25028	Economy	10900.00
0005435259854	25028	Economy	10900.00
0005433534531	25028	Economy	10900.00
0005433539011	25028	Economy	9900.00
0005433539005	25028	Economy	9900.00
0005433539010	25028	Economy	9900.00
0005433538984	25028	Economy	9900.00
0005433538990	25028	Economy	9900.00
0005433534527	25028	Economy	9900.00
0005435259856	25028	Economy	9900.00
0005433539004	25028	Economy	9900.00
0005433538940	25028	Economy	9900.00
0005433538939	25028	Economy	9900.00
0005433538998	25028	Economy	9900.00
0005433539003	25028	Economy	9900.00
0005433538989	25028	Economy	9900.00
0005433538988	25028	Economy	9900.00
0005435259855	25028	Economy	9900.00
0005433538999	25028	Economy	9900.00
0005433534529	25028	Economy	9900.00
0005433538938	25028	Economy	9900.00
0005433538992	25028	Economy	9900.00
0005433534522	25028	Economy	9900.00
0005433539024	25028	Economy	9900.00
0005433539025	25028	Economy	9900.00
0005435259858	25028	Economy	9900.00
0005435259857	25028	Economy	9900.00
0005433512142	814	Economy	16100.00
0005432922575	814	Economy	14600.00
0005433512145	814	Economy	14600.00
0005432922582	814	Economy	14600.00
0005432922571	814	Economy	14600.00
0005433512141	814	Economy	14600.00
0005432922594	814	Economy	14600.00
0005433512144	814	Economy	14600.00
0005433512143	814	Economy	14600.00
0005432922585	814	Economy	14600.00
0005433512139	814	Economy	14600.00
0005432922596	814	Economy	14600.00
0005432922602	814	Economy	14600.00
0005432922574	814	Economy	14600.00
0005433512140	814	Economy	14600.00
0005432922593	814	Economy	14600.00
0005432922597	814	Economy	14600.00
0005432922573	814	Economy	14600.00
0005433512076	16170	Economy	16100.00
0005433512086	16170	Economy	16100.00
0005432922615	16170	Economy	14600.00
0005432922616	16170	Economy	14600.00
0005432922619	16170	Economy	14600.00
0005433512060	16170	Economy	14600.00
0005432922618	16170	Economy	14600.00
0005433512080	16170	Economy	14600.00
0005433512085	16170	Economy	14600.00
0005433512055	16170	Economy	14600.00
0005433512062	16170	Economy	14600.00
0005432922617	16170	Economy	14600.00
0005435697989	3653	Economy	7900.00
0005435697972	3653	Economy	7900.00
0005435697979	3653	Economy	7900.00
0005435697978	3653	Economy	7200.00
0005435697965	3653	Economy	7200.00
0005435916210	3653	Economy	7200.00
0005435916215	3653	Economy	7200.00
0005435697991	3653	Economy	7200.00
0005434950633	3653	Economy	7200.00
0005435697967	3653	Economy	7200.00
0005435697981	3653	Economy	7200.00
0005435697963	3653	Economy	7200.00
0005435697983	3653	Economy	7200.00
0005435935080	3653	Economy	7200.00
0005435697984	3653	Economy	7200.00
0005435697974	3653	Economy	7200.00
0005435697968	3653	Economy	7200.00
0005435697966	3653	Economy	7200.00
0005434950629	3653	Economy	7200.00
0005435697990	3653	Economy	7200.00
0005435697964	3653	Economy	7200.00
0005435697977	3653	Economy	7200.00
0005435935087	3653	Economy	7200.00
0005435697973	3653	Economy	7200.00
0005435697988	3653	Economy	7200.00
0005435697971	3653	Economy	7200.00
0005435697970	3653	Economy	7200.00
0005434950631	3653	Economy	7200.00
0005435697980	3653	Economy	7200.00
0005434950632	3653	Economy	7200.00
0005435916209	3653	Economy	7200.00
0005435935086	3653	Economy	7200.00
0005435916216	3653	Economy	7200.00
0005435697976	3653	Economy	7200.00
0005434950630	3653	Economy	7200.00
0005435697987	3653	Economy	7200.00
0005435697985	3653	Economy	7200.00
0005435935085	3653	Economy	7200.00
0005435697986	3653	Economy	7200.00
0005435697975	3653	Economy	7200.00
0005435697982	3653	Economy	7200.00
0005435697969	3653	Economy	7200.00
0005435697601	16267	Economy	7900.00
0005435697819	16267	Economy	7900.00
0005434950601	16267	Economy	7900.00
0005435697733	16267	Economy	7900.00
0005435697704	16267	Economy	7200.00
0005435697574	16267	Economy	7200.00
0005435697718	16267	Economy	7200.00
0005435697600	16267	Economy	7200.00
0005435697732	16267	Economy	7200.00
0005435697599	16267	Economy	7200.00
0005435697754	16267	Economy	7200.00
0005435697678	16267	Economy	7200.00
0005435697742	16267	Economy	7200.00
0005435697703	16267	Economy	7200.00
0005435697750	16267	Economy	7200.00
0005435935110	16267	Economy	7200.00
0005435697649	16267	Economy	7200.00
0005435697702	16267	Economy	7200.00
0005435697751	16267	Economy	7200.00
0005435697701	16267	Economy	7200.00
0005435935111	16267	Economy	7200.00
0005435697694	16267	Economy	7200.00
0005434950603	16267	Economy	7200.00
0005435697780	16267	Economy	7200.00
0005435933569	16267	Economy	7200.00
0005435697731	16267	Economy	7200.00
0005435697580	16267	Economy	7200.00
0005435933568	16267	Economy	7200.00
0005435697778	16267	Economy	7200.00
0005435697803	16267	Economy	7200.00
0005435935113	16267	Economy	7200.00
0005435916230	16267	Economy	7200.00
0005435697734	16267	Economy	7200.00
0005435697747	16267	Economy	7200.00
0005435935112	16267	Economy	7200.00
0005435697717	16267	Economy	7200.00
0005435697804	16267	Economy	7200.00
0005435697712	16267	Economy	7200.00
0005435916231	16267	Economy	7200.00
0005435697695	16267	Economy	7200.00
0005435697756	16267	Economy	7200.00
0005435697781	16267	Economy	7200.00
0005432609823	3973	Economy	21300.00
0005434604979	3973	Economy	21300.00
0005433519560	3973	Economy	19300.00
0005433519561	3973	Economy	19300.00
0005435853640	3973	Economy	19300.00
0005433519562	3973	Economy	19300.00
0005434606906	3973	Economy	19300.00
0005435853635	3973	Economy	19300.00
0005434606907	3973	Economy	19300.00
0005434604980	3973	Economy	19300.00
0005434604981	3973	Economy	19300.00
0005434606905	3973	Economy	19300.00
0005433519563	3973	Economy	19300.00
0005432607657	3973	Economy	19300.00
0005432609824	3973	Economy	19300.00
0005435904711	3973	Economy	19300.00
0005432609825	3973	Economy	19300.00
0005434606904	3973	Economy	19300.00
0005434604982	3973	Economy	19300.00
0005434604983	3973	Economy	19300.00
0005433519559	3973	Economy	19300.00
0005433519564	3973	Economy	19300.00
0005435841480	3973	Economy	19300.00
0005432607658	3973	Economy	19300.00
0005432609786	22081	Economy	21300.00
0005433519518	22081	Economy	19300.00
0005432609774	22081	Economy	19300.00
0005432609778	22081	Economy	19300.00
0005432613913	22081	Economy	19300.00
0005433519539	22081	Economy	19300.00
0005433519541	22081	Economy	19300.00
0005432613895	22081	Economy	19300.00
0005433519532	22081	Economy	19300.00
0005433519533	22081	Economy	19300.00
0005432613903	22081	Economy	19300.00
0005432613896	22081	Economy	19300.00
0005433519517	22081	Economy	19300.00
0005435841119	22081	Economy	19300.00
0005432609742	22081	Economy	19300.00
0005433519540	22081	Economy	19300.00
0005432613915	22081	Economy	19300.00
0005432613912	22081	Economy	19300.00
0005432609783	22081	Economy	19300.00
0005432609755	22081	Economy	19300.00
0005435841120	22081	Economy	19300.00
0005432613894	22081	Economy	19300.00
0005432609775	22081	Economy	19300.00
0005432609773	22081	Economy	19300.00
0005432609799	22081	Economy	19300.00
0005433519526	22081	Economy	19300.00
0005432613900	22081	Economy	19300.00
0005432609776	22081	Economy	19300.00
0005433519502	22081	Economy	19300.00
0005432613906	22081	Economy	19300.00
0005432609800	22081	Economy	19300.00
0005432609787	22081	Economy	19300.00
0005432613914	22081	Economy	19300.00
0005435628801	692	Economy	3700.00
0005433349055	692	Economy	3700.00
0005433349080	692	Economy	3700.00
0005435628802	692	Economy	3700.00
0005433349079	692	Economy	3700.00
0005433349073	692	Economy	3700.00
0005435628803	692	Economy	3700.00
0005433349060	692	Economy	3700.00
0005433349088	692	Economy	3700.00
0005433349099	692	Economy	3700.00
0005433349120	15940	Economy	3700.00
0005433349123	15940	Economy	3700.00
0005435628777	15940	Economy	3700.00
0005433349119	15940	Economy	3700.00
0005435628768	15940	Economy	3700.00
0005433349124	15940	Economy	3700.00
0005435628778	15940	Economy	3700.00
0005435628776	15940	Economy	3700.00
0005433349122	15940	Economy	3700.00
0005433349121	15940	Economy	3700.00
0005433158166	17229	Economy	7100.00
0005434446569	17229	Economy	7100.00
0005434445300	17229	Economy	7100.00
0005434446568	17229	Economy	7100.00
0005434445297	17229	Economy	7100.00
0005433158153	17229	Economy	7100.00
0005434445299	17229	Economy	7100.00
0005433158154	17229	Economy	7100.00
0005434445296	17229	Economy	7100.00
0005434446570	17229	Economy	7100.00
0005434445298	17229	Economy	7100.00
0005433159340	17229	Economy	7100.00
0005433159366	17601	Economy	7100.00
0005433159364	17601	Economy	7100.00
0005434445273	17601	Economy	7100.00
0005434445271	17601	Economy	7100.00
0005433159365	17601	Economy	7100.00
0005433159363	17601	Economy	7100.00
0005435133121	7900	Economy	5900.00
0005435133120	7900	Economy	5400.00
0005435383218	7900	Economy	5400.00
0005435133127	7900	Economy	5400.00
0005435133124	7900	Economy	5400.00
0005435383264	7900	Economy	5400.00
0005435133119	7900	Economy	5400.00
0005435383237	7900	Economy	5400.00
0005435133123	7900	Economy	5400.00
0005435133126	7900	Economy	5400.00
0005435383236	7900	Economy	5400.00
0005435133128	7900	Economy	5400.00
0005435133125	7900	Economy	5400.00
0005435383217	7900	Economy	5400.00
0005435383210	7900	Economy	5400.00
0005435133118	7900	Economy	5400.00
0005435133122	7900	Economy	5400.00
0005435383209	7900	Economy	5400.00
0005435133043	33093	Economy	5400.00
0005435132966	33093	Economy	5400.00
0005435383274	33093	Economy	5400.00
0005435132965	33093	Economy	5400.00
0005435133031	33093	Economy	5400.00
0005435133072	33093	Economy	5400.00
0005435383270	33093	Economy	5400.00
0005435383275	33093	Economy	5400.00
0005435133045	33093	Economy	5400.00
0005435383271	33093	Economy	5400.00
0005435133058	33093	Economy	5400.00
0005435133044	33093	Economy	5400.00
0005435133032	33093	Economy	5400.00
0005435383273	33093	Economy	5400.00
0005435133009	33093	Economy	5400.00
0005435133030	33093	Economy	5400.00
0005435383272	33093	Economy	5400.00
0005435811187	4417	Business	133200.00
0005435811190	4417	Business	133200.00
0005435811180	4417	Business	133200.00
0005435938916	4417	Economy	44400.00
0005435811193	4417	Economy	44400.00
0005435938926	4417	Economy	48800.00
0005435811184	4417	Economy	44400.00
0005435938917	4417	Economy	44400.00
0005435938932	4417	Economy	44400.00
0005435811188	4417	Economy	44400.00
0005435811179	4417	Economy	44400.00
0005435811192	4417	Economy	44400.00
0005435811186	4417	Economy	44400.00
0005435811182	4417	Economy	44400.00
0005435938920	4417	Economy	44400.00
0005435811181	4417	Economy	44400.00
0005435938924	4417	Economy	44400.00
0005435811191	4417	Economy	44400.00
0005435811189	4417	Economy	44400.00
0005435938929	4417	Economy	44400.00
0005435811183	4417	Economy	44400.00
0005435938928	4417	Economy	44400.00
0005435811185	4417	Economy	44400.00
0005435811135	29447	Business	133200.00
0005435938941	29447	Business	133200.00
0005435811142	29447	Business	133200.00
0005435811155	29447	Business	133200.00
0005435811149	29447	Business	133200.00
0005435938947	29447	Economy	44400.00
0005435811148	29447	Economy	44400.00
0005435811157	29447	Economy	44400.00
0005435811132	29447	Economy	44400.00
0005435811143	29447	Economy	44400.00
0005435938946	29447	Economy	44400.00
0005435811137	29447	Economy	44400.00
0005435938948	29447	Economy	44400.00
0005435938942	29447	Economy	44400.00
0005435811122	29447	Economy	44400.00
0005435938944	29447	Economy	44400.00
0005435811136	29447	Economy	44400.00
0005435938943	29447	Economy	44400.00
0005435938945	29447	Economy	44400.00
0005435811141	29447	Economy	44400.00
0005435811140	29447	Economy	44400.00
0005435811156	29447	Economy	44400.00
0005435811131	29447	Economy	44400.00
0005435390326	7517	Economy	13800.00
0005435160554	7517	Economy	13800.00
0005435390325	7517	Economy	12500.00
0005435160560	7517	Economy	12500.00
0005435160550	7517	Economy	12500.00
0005435160551	7517	Economy	12500.00
0005435160559	7517	Economy	12500.00
0005435160555	7517	Economy	12500.00
0005435160552	7517	Economy	12500.00
0005435160561	7517	Economy	12500.00
0005435160558	7517	Economy	12500.00
0005435160556	7517	Economy	12500.00
0005435160553	7517	Economy	12500.00
0005435160557	7517	Economy	12500.00
0005435390349	7517	Economy	12500.00
0005435160484	29544	Economy	13800.00
0005435160469	29544	Economy	13800.00
0005435160460	29544	Economy	12500.00
0005435390401	29544	Economy	12500.00
0005435390396	29544	Economy	12500.00
0005435390398	29544	Economy	12500.00
0005435160468	29544	Economy	12500.00
0005435390394	29544	Economy	12500.00
0005435160449	29544	Economy	12500.00
0005435160450	29544	Economy	12500.00
0005435160448	29544	Economy	12500.00
0005435160467	29544	Economy	12500.00
0005435390402	29544	Economy	12500.00
0005435160466	29544	Economy	12500.00
0005435390399	29544	Economy	12500.00
0005435160483	29544	Economy	12500.00
0005435160475	29544	Economy	12500.00
0005435160440	29544	Economy	12500.00
0005435390397	29544	Economy	12500.00
0005435390395	29544	Economy	12500.00
0005435390400	29544	Economy	12500.00
0005432394146	18447	Economy	4900.00
0005432398256	18447	Economy	4900.00
0005432394179	18447	Economy	4900.00
0005432398249	18447	Economy	4900.00
0005432398243	18447	Economy	4900.00
0005435178532	18447	Economy	4900.00
0005432398257	18447	Economy	4900.00
0005435178531	18447	Economy	4900.00
0005432398244	18447	Economy	4900.00
0005432398248	18447	Economy	4900.00
0005432398245	18447	Economy	4900.00
0005435178533	18447	Economy	4900.00
0005432400206	27126	Economy	4900.00
0005432398276	27126	Economy	4900.00
0005432400204	27126	Economy	4900.00
0005432398278	27126	Economy	4900.00
0005432398277	27126	Economy	4900.00
0005432400203	27126	Economy	4900.00
0005435178518	27126	Economy	4900.00
0005432400205	27126	Economy	4900.00
0005432639400	2236	Business	87300.00
0005432639415	2236	Business	87300.00
0005432639406	2236	Business	87300.00
0005432639399	2236	Business	87300.00
0005432639401	2236	Business	87300.00
0005432866090	2236	Economy	29100.00
0005432866098	2236	Economy	29100.00
0005432866106	2236	Economy	29100.00
0005432639409	2236	Economy	32000.00
0005432639418	2236	Economy	32000.00
0005432639421	2236	Economy	29100.00
0005432639403	2236	Economy	29100.00
0005432639408	2236	Economy	29100.00
0005432639414	2236	Economy	29100.00
0005432639422	2236	Economy	29100.00
0005432639410	2236	Economy	29100.00
0005432639416	2236	Economy	29100.00
0005432639413	2236	Economy	29100.00
0005432639412	2236	Economy	29100.00
0005432639405	2236	Economy	29100.00
0005432866069	2236	Economy	29100.00
0005432639402	2236	Economy	29100.00
0005432866070	2236	Economy	29100.00
0005432639420	2236	Economy	29100.00
0005432866095	2236	Economy	29100.00
0005432639407	2236	Economy	29100.00
0005432639417	2236	Economy	29100.00
0005432639411	2236	Economy	29100.00
0005432639398	2236	Economy	29100.00
0005432866097	2236	Economy	29100.00
0005432639404	2236	Economy	29100.00
0005432639419	2236	Economy	29100.00
0005432866113	2236	Economy	29100.00
0005434552889	9749	Economy	4400.00
0005434552887	9749	Economy	4400.00
0005434552888	9749	Economy	4400.00
0005434191303	9749	Economy	4400.00
0005434552885	9749	Economy	4400.00
0005434552886	9749	Economy	4400.00
0005435104148	6512	Business	48400.00
0005434505063	6512	Business	48400.00
0005434505065	6512	Business	48400.00
0005434505060	6512	Business	48400.00
0005434505058	6512	Business	48400.00
0005434505059	6512	Business	48400.00
0005434505037	6512	Business	48400.00
0005435104144	6512	Economy	16100.00
0005434505069	6512	Economy	16100.00
0005435104146	6512	Economy	17800.00
0005434505053	6512	Economy	17800.00
0005434505057	6512	Economy	16100.00
0005434505062	6512	Economy	16100.00
0005434505039	6512	Economy	16100.00
0005434505043	6512	Economy	16100.00
0005434505045	6512	Economy	16100.00
0005434505055	6512	Economy	16100.00
0005434505033	6512	Economy	16100.00
0005434505042	6512	Economy	16100.00
0005434505061	6512	Economy	16100.00
0005435104147	6512	Economy	16100.00
0005434505051	6512	Economy	16100.00
0005434505031	6512	Economy	16100.00
0005434505040	6512	Economy	16100.00
0005435104145	6512	Economy	16100.00
0005434505066	6512	Economy	16100.00
0005435104138	6512	Economy	16100.00
0005434505044	6512	Economy	16100.00
0005434505046	6512	Economy	16100.00
0005435104141	6512	Economy	16100.00
0005434505056	6512	Economy	16100.00
0005434505067	6512	Economy	16100.00
0005435104140	6512	Economy	16100.00
0005434505047	6512	Economy	16100.00
0005435104149	6512	Economy	16100.00
0005434505054	6512	Economy	16100.00
0005434505068	6512	Economy	16100.00
0005434505064	6512	Economy	16100.00
0005435104143	6512	Economy	16100.00
0005434505036	6512	Economy	16100.00
0005434505038	6512	Economy	16100.00
0005434505049	6512	Economy	16100.00
0005434505048	6512	Economy	16100.00
0005434505052	6512	Economy	16100.00
0005434505035	6512	Economy	16100.00
0005435104142	6512	Economy	16100.00
0005434505041	6512	Economy	16100.00
0005434505050	6512	Economy	16100.00
0005434505032	6512	Economy	16100.00
0005434505034	6512	Economy	16100.00
0005435104139	6512	Economy	16100.00
0005434504566	22692	Business	48400.00
0005435104003	22692	Business	48400.00
0005434504561	22692	Business	48400.00
0005434504398	22692	Economy	16100.00
0005434504545	22692	Economy	16100.00
0005434504628	22692	Economy	16100.00
0005434504725	22692	Economy	17800.00
0005434504637	22692	Economy	17800.00
0005434504489	22692	Economy	17800.00
0005434504627	22692	Economy	17800.00
0005434504397	22692	Economy	16100.00
0005435103998	22692	Economy	16100.00
0005434504547	22692	Economy	16100.00
0005434504325	22692	Economy	16100.00
0005434504621	22692	Economy	16100.00
0005434504558	22692	Economy	16100.00
0005434504522	22692	Economy	16100.00
0005434504580	22692	Economy	16100.00
0005435104002	22692	Economy	16100.00
0005434504679	22692	Economy	16100.00
0005434504544	22692	Economy	16100.00
0005434504548	22692	Economy	16100.00
0005434504650	22692	Economy	16100.00
0005434504746	22692	Economy	16100.00
0005434504595	22692	Economy	16100.00
0005435104007	22692	Economy	16100.00
0005434504581	22692	Economy	16100.00
0005434504562	22692	Economy	16100.00
0005434504498	22692	Economy	16100.00
0005434504698	22692	Economy	16100.00
0005434504640	22692	Economy	16100.00
0005434504610	22692	Economy	16100.00
0005434504399	22692	Economy	16100.00
0005434504672	22692	Economy	16100.00
0005434504643	22692	Economy	16100.00
0005435103992	22692	Economy	16100.00
0005434504699	22692	Economy	16100.00
0005435103981	22692	Economy	16100.00
0005434504644	22692	Economy	16100.00
0005435103997	22692	Economy	16100.00
0005434504538	22692	Economy	16100.00
0005434504693	22692	Economy	16100.00
0005434504651	22692	Economy	16100.00
0005434504576	22692	Economy	16100.00
0005434504629	22692	Economy	16100.00
0005434504400	22692	Economy	16100.00
0005434504594	22692	Economy	16100.00
0005434504639	22692	Economy	16100.00
0005434504567	22692	Economy	16100.00
0005434504536	22692	Economy	16100.00
0005434504692	22692	Economy	16100.00
0005435654066	1699	Business	50000.00
0005435654075	1699	Business	50000.00
0005433368353	1699	Business	50000.00
0005435654091	1699	Business	50000.00
0005433368415	1699	Business	50000.00
0005435654052	1699	Business	50000.00
0005435654069	1699	Business	50000.00
0005433368356	1699	Business	50000.00
0005433368272	1699	Business	50000.00
0005433368531	1699	Business	50000.00
0005435654082	1699	Business	50000.00
0005435654062	1699	Economy	16700.00
0005435654090	1699	Economy	16700.00
0005435654057	1699	Economy	16700.00
0005435654076	1699	Economy	16700.00
0005435654053	1699	Economy	16700.00
0005435654073	1699	Economy	16700.00
0005435654065	1699	Economy	16700.00
0005435654074	1699	Economy	16700.00
0005435654100	1699	Economy	16700.00
0005433368442	1699	Economy	18300.00
0005435654084	1699	Economy	18300.00
0005433368390	1699	Economy	18300.00
0005435654071	1699	Economy	18300.00
0005433368478	1699	Economy	16700.00
0005433368374	1699	Economy	16700.00
0005433368270	1699	Economy	16700.00
0005433368233	1699	Economy	16700.00
0005433368488	1699	Economy	16700.00
0005435654050	1699	Economy	16700.00
0005435654083	1699	Economy	16700.00
0005433368371	1699	Economy	16700.00
0005433368433	1699	Economy	16700.00
0005435654086	1699	Economy	16700.00
0005435654063	1699	Economy	16700.00
0005435654049	1699	Economy	16700.00
0005433368449	1699	Economy	16700.00
0005433368315	1699	Economy	16700.00
0005435654060	1699	Economy	16700.00
0005435654064	1699	Economy	16700.00
0005435654078	1699	Economy	16700.00
0005433368423	1699	Economy	16700.00
0005433368380	1699	Economy	16700.00
0005435654079	1699	Economy	16700.00
0005433368414	1699	Economy	16700.00
0005435654097	1699	Economy	16700.00
0005435654088	1699	Economy	16700.00
0005433368389	1699	Economy	16700.00
0005435654068	1699	Economy	16700.00
0005435654094	1699	Economy	16700.00
0005435654080	1699	Economy	16700.00
0005433368487	1699	Economy	16700.00
0005435654095	1699	Economy	16700.00
0005435654061	1699	Economy	16700.00
0005435654058	1699	Economy	16700.00
0005435654089	1699	Economy	16700.00
0005433368281	1699	Economy	16700.00
0005433368448	1699	Economy	16700.00
0005433368416	1699	Economy	16700.00
0005435654098	1699	Economy	16700.00
0005435654099	1699	Economy	16700.00
0005435654092	1699	Economy	16700.00
0005435654056	1699	Economy	16700.00
0005435654096	1699	Economy	16700.00
0005433368437	1699	Economy	16700.00
0005433368409	1699	Economy	16700.00
0005435654093	1699	Economy	16700.00
0005433368370	1699	Economy	16700.00
0005435654077	1699	Economy	16700.00
0005433368271	1699	Economy	16700.00
0005433368280	1699	Economy	16700.00
0005435654072	1699	Economy	16700.00
0005433368412	1699	Economy	16700.00
0005435654087	1699	Economy	16700.00
0005433368573	1699	Economy	16700.00
0005433368436	1699	Economy	16700.00
0005435654085	1699	Economy	16700.00
0005435654070	1699	Economy	16700.00
0005433368443	1699	Economy	16700.00
0005433368234	1699	Economy	16700.00
0005435654067	1699	Economy	16700.00
0005435654055	1699	Economy	16700.00
0005433368432	1699	Economy	16700.00
0005433368530	1699	Economy	16700.00
0005435654054	1699	Economy	16700.00
0005433368422	1699	Economy	16700.00
0005435654051	1699	Economy	16700.00
0005435654081	1699	Economy	16700.00
0005435654059	1699	Economy	16700.00
0005433368738	21668	Business	50000.00
0005433368744	21668	Business	50000.00
0005433368719	21668	Business	50000.00
0005435653583	21668	Business	50000.00
0005435653427	21668	Business	50000.00
0005435653632	21668	Business	50000.00
0005433368728	21668	Business	50000.00
0005435653501	21668	Business	50000.00
0005433368716	21668	Business	50000.00
0005435653540	21668	Economy	16700.00
0005435653499	21668	Economy	16700.00
0005433368743	21668	Economy	16700.00
0005435653653	21668	Economy	16700.00
0005435653644	21668	Economy	18300.00
0005433368740	21668	Economy	18300.00
0005435653591	21668	Economy	18300.00
0005433368725	21668	Economy	18300.00
0005433368732	21668	Economy	18300.00
0005435653670	21668	Economy	16700.00
0005433368722	21668	Economy	16700.00
0005433368746	21668	Economy	16700.00
0005435653495	21668	Economy	16700.00
0005435653541	21668	Economy	16700.00
0005433368714	21668	Economy	16700.00
0005433368723	21668	Economy	16700.00
0005433368739	21668	Economy	16700.00
0005433368751	21668	Economy	16700.00
0005435653667	21668	Economy	16700.00
0005435653500	21668	Economy	16700.00
0005435653441	21668	Economy	16700.00
0005435653636	21668	Economy	16700.00
0005435653652	21668	Economy	16700.00
0005435653589	21668	Economy	16700.00
0005433368737	21668	Economy	16700.00
0005435653597	21668	Economy	16700.00
0005435653605	21668	Economy	16700.00
0005435653442	21668	Economy	16700.00
0005433368745	21668	Economy	16700.00
0005433368715	21668	Economy	16700.00
0005433368734	21668	Economy	16700.00
0005433368733	21668	Economy	16700.00
0005433368748	21668	Economy	16700.00
0005435653621	21668	Economy	16700.00
0005435653545	21668	Economy	16700.00
0005435653587	21668	Economy	16700.00
0005433368730	21668	Economy	16700.00
0005433368735	21668	Economy	16700.00
0005433368721	21668	Economy	16700.00
0005433368750	21668	Economy	16700.00
0005433368747	21668	Economy	16700.00
0005435653635	21668	Economy	16700.00
0005433368717	21668	Economy	16700.00
0005435653593	21668	Economy	16700.00
0005433368731	21668	Economy	16700.00
0005433368718	21668	Economy	16700.00
0005433368749	21668	Economy	16700.00
0005433368726	21668	Economy	16700.00
0005435653496	21668	Economy	16700.00
0005433368727	21668	Economy	16700.00
0005433368720	21668	Economy	16700.00
0005433368724	21668	Economy	16700.00
0005435653557	21668	Economy	16700.00
0005435653488	21668	Economy	16700.00
0005435653683	21668	Economy	16700.00
0005435653494	21668	Economy	16700.00
0005435653600	21668	Economy	16700.00
0005435653671	21668	Economy	16700.00
0005433368741	21668	Economy	16700.00
0005435653594	21668	Economy	16700.00
0005435653590	21668	Economy	16700.00
0005435653546	21668	Economy	16700.00
0005435653614	21668	Economy	16700.00
0005433368736	21668	Economy	16700.00
0005433368742	21668	Economy	16700.00
0005433368729	21668	Economy	16700.00
0005435653539	21668	Economy	16700.00
0005435312860	23218	Economy	23000.00
0005435312859	23218	Economy	23000.00
0005435312862	23218	Economy	20900.00
0005435312863	23218	Economy	20900.00
0005434466519	23218	Economy	20900.00
0005434466534	23218	Economy	20900.00
0005434466535	23218	Economy	20900.00
0005434466520	23218	Economy	20900.00
0005435312861	23218	Economy	20900.00
0005433987030	4140	Business	21500.00
0005433987016	4140	Business	21500.00
0005433986978	4140	Business	21500.00
0005433986993	4140	Business	21500.00
0005433987013	4140	Business	21500.00
0005433987008	4140	Business	21500.00
0005433987001	4140	Business	21500.00
0005433986999	4140	Business	21500.00
0005433987020	4140	Business	21500.00
0005433987000	4140	Business	21500.00
0005433987004	4140	Business	21500.00
0005433987026	4140	Economy	7200.00
0005433987021	4140	Economy	7200.00
0005433987011	4140	Economy	7200.00
0005433987024	4140	Economy	7200.00
0005433987002	4140	Economy	7900.00
0005433986976	4140	Economy	7900.00
0005433987006	4140	Economy	7900.00
0005433987007	4140	Economy	7900.00
0005435788828	4140	Economy	7900.00
0005433986992	4140	Economy	7200.00
0005433987009	4140	Economy	7200.00
0005433987003	4140	Economy	7200.00
0005433986981	4140	Economy	7200.00
0005433986982	4140	Economy	7200.00
0005433986997	4140	Economy	7200.00
0005433987028	4140	Economy	7200.00
0005433986985	4140	Economy	7200.00
0005433986994	4140	Economy	7200.00
0005433987029	4140	Economy	7200.00
0005433987014	4140	Economy	7200.00
0005433986980	4140	Economy	7200.00
0005435788830	4140	Economy	7200.00
0005433986995	4140	Economy	7200.00
0005433986987	4140	Economy	7200.00
0005435788829	4140	Economy	7200.00
0005433987019	4140	Economy	7200.00
0005433987005	4140	Economy	7200.00
0005433986983	4140	Economy	7200.00
0005433987012	4140	Economy	7200.00
0005433987027	4140	Economy	7200.00
0005433987018	4140	Economy	7200.00
0005433986989	4140	Economy	7200.00
0005433986984	4140	Economy	7200.00
0005433986988	4140	Economy	7200.00
0005433986975	4140	Economy	7200.00
0005433987010	4140	Economy	7200.00
0005433987017	4140	Economy	7200.00
0005433986986	4140	Economy	7200.00
0005433987023	4140	Economy	7200.00
0005433986996	4140	Economy	7200.00
0005433987015	4140	Economy	7200.00
0005433986979	4140	Economy	7200.00
0005433986990	4140	Economy	7200.00
0005433987022	4140	Economy	7200.00
0005433986991	4140	Economy	7200.00
0005433986977	4140	Economy	7200.00
0005433987025	4140	Economy	7200.00
0005433986998	4140	Economy	7200.00
0005433986497	25659	Business	21500.00
0005433986495	25659	Business	21500.00
0005433986426	25659	Business	21500.00
0005433986543	25659	Business	21500.00
0005433986384	25659	Business	21500.00
0005433986423	25659	Business	21500.00
0005433986547	25659	Business	21500.00
0005433986541	25659	Business	21500.00
0005433986581	25659	Economy	7200.00
0005433986525	25659	Economy	7200.00
0005433986551	25659	Economy	7200.00
0005433986498	25659	Economy	7200.00
0005433986462	25659	Economy	7200.00
0005433986463	25659	Economy	7200.00
0005433986466	25659	Economy	7900.00
0005433986359	25659	Economy	7900.00
0005433986539	25659	Economy	7200.00
0005435788815	25659	Economy	7200.00
0005433986444	25659	Economy	7200.00
0005433986585	25659	Economy	7200.00
0005433986496	25659	Economy	7200.00
0005433986546	25659	Economy	7200.00
0005433986619	25659	Economy	7200.00
0005433986540	25659	Economy	7200.00
0005433986584	25659	Economy	7200.00
0005433986424	25659	Economy	7200.00
0005433986532	25659	Economy	7200.00
0005433986622	25659	Economy	7200.00
0005433986632	25659	Economy	7200.00
0005433986564	25659	Economy	7200.00
0005433986479	25659	Economy	7200.00
0005433986579	25659	Economy	7200.00
0005433986565	25659	Economy	7200.00
0005433986505	25659	Economy	7200.00
0005433986634	25659	Economy	7200.00
0005433986464	25659	Economy	7200.00
0005433986615	25659	Economy	7200.00
0005433986591	25659	Economy	7200.00
0005433986563	25659	Economy	7200.00
0005433986580	25659	Economy	7200.00
0005433986504	25659	Economy	7200.00
0005433986465	25659	Economy	7200.00
0005433986345	25659	Economy	7200.00
0005433986357	25659	Economy	7200.00
0005433986508	25659	Economy	7200.00
0005433986616	25659	Economy	7200.00
0005435788817	25659	Economy	7200.00
0005433986607	25659	Economy	7200.00
0005433986428	25659	Economy	7200.00
0005435788816	25659	Economy	7200.00
0005433986443	25659	Economy	7200.00
0005433463901	19921	Business	201300.00
0005433463915	19921	Business	201300.00
0005433463914	19921	Economy	73800.00
0005433461607	19921	Economy	73800.00
0005433463922	19921	Economy	67100.00
0005433463900	19921	Economy	67100.00
0005433461608	19921	Economy	67100.00
0005433463916	19921	Economy	67100.00
0005433461604	19921	Economy	67100.00
0005433461601	19921	Economy	67100.00
0005433461609	19921	Economy	67100.00
0005433463913	19921	Economy	67100.00
0005433461603	19921	Economy	67100.00
0005433463920	19921	Economy	67100.00
0005433461617	19921	Economy	67100.00
0005433461611	19921	Economy	67100.00
0005433461595	19921	Economy	67100.00
0005433461600	19921	Economy	67100.00
0005433463925	19921	Economy	67100.00
0005433463911	19921	Economy	67100.00
0005433461610	19921	Economy	73800.00
0005433461596	19921	Economy	67100.00
0005433463917	19921	Economy	67100.00
0005433461602	19921	Economy	67100.00
0005433461606	19921	Economy	67100.00
0005433463919	19921	Economy	67100.00
0005433463912	19921	Economy	67100.00
0005433461605	19921	Economy	67100.00
0005433463923	19921	Economy	67100.00
0005433463918	19921	Economy	67100.00
0005433463924	19921	Economy	67100.00
0005433463904	19921	Economy	67100.00
0005433463921	19921	Economy	67100.00
0005435719570	21273	Economy	9400.00
0005435720837	21273	Economy	9400.00
0005435719578	21273	Economy	9400.00
0005435719579	21273	Economy	9400.00
0005434509311	1634	Economy	17000.00
0005433168428	1634	Economy	17000.00
0005434509325	1634	Economy	17000.00
0005434509324	1634	Economy	17000.00
0005434509313	1634	Economy	15500.00
0005433168430	1634	Economy	15500.00
0005434509317	1634	Economy	15500.00
0005433168432	1634	Economy	15500.00
0005434509326	1634	Economy	15500.00
0005433168421	1634	Economy	15500.00
0005433168429	1634	Economy	15500.00
0005434509321	1634	Economy	15500.00
0005434509320	1634	Economy	15500.00
0005433168431	1634	Economy	15500.00
0005433168406	1634	Economy	15500.00
0005433168439	1634	Economy	15500.00
0005434509312	1634	Economy	15500.00
0005433168407	1634	Economy	15500.00
0005433168420	1634	Economy	15500.00
0005433168438	1634	Economy	15500.00
0005434509323	1634	Economy	15500.00
0005434509310	1634	Economy	15500.00
0005433168423	1634	Economy	15500.00
0005434509314	1634	Economy	15500.00
0005434509309	1634	Economy	15500.00
0005434509308	1634	Economy	15500.00
0005434509304	1634	Economy	15500.00
0005434509322	1634	Economy	15500.00
0005434509327	1634	Economy	15500.00
0005433168422	1634	Economy	15500.00
0005433168405	1634	Economy	15500.00
0005434509307	1634	Economy	15500.00
0005433168415	1634	Economy	15500.00
0005434509315	1634	Economy	15500.00
0005434509318	1634	Economy	15500.00
0005433168427	1634	Economy	15500.00
0005434509305	1634	Economy	15500.00
0005433168419	1634	Economy	15500.00
0005433168426	1634	Economy	15500.00
0005434509319	1634	Economy	15500.00
0005433168425	1634	Economy	15500.00
0005434509306	1634	Economy	15500.00
0005434509316	1634	Economy	15500.00
0005432869678	17843	Business	18000.00
0005432655659	17843	Business	18000.00
0005432655722	17843	Business	18000.00
0005432869679	17843	Business	18000.00
0005432660850	17843	Business	18000.00
0005432655647	17843	Business	18000.00
0005432655719	17843	Business	18000.00
0005432659727	17843	Economy	6000.00
0005432667481	17843	Economy	6000.00
0005432667485	17843	Economy	6000.00
0005432658623	17843	Economy	6600.00
0005432869676	17843	Economy	6600.00
0005432661950	17843	Economy	6600.00
0005432655750	17843	Economy	6000.00
0005434151772	17843	Economy	6000.00
0005432869680	17843	Economy	6000.00
0005432663056	17843	Economy	6000.00
0005432660844	17843	Economy	6000.00
0005432661951	17843	Economy	6000.00
0005432664161	17843	Economy	6000.00
0005432655709	17843	Economy	6000.00
0005432655703	17843	Economy	6000.00
0005432660845	17843	Economy	6000.00
0005434151771	17843	Economy	6000.00
0005432655649	17843	Economy	6000.00
0005432655652	17843	Economy	6000.00
0005432659733	17843	Economy	6000.00
0005432664160	17843	Economy	6000.00
0005432869681	17843	Economy	6000.00
0005432667484	17843	Economy	6000.00
0005432655648	17843	Economy	6000.00
0005434151773	17843	Economy	6000.00
0005432655723	17843	Economy	6000.00
0005432655704	17843	Economy	6000.00
0005432655717	17843	Economy	6000.00
0005432667482	17843	Economy	6000.00
0005432869677	17843	Economy	6000.00
0005432663066	17843	Economy	6000.00
0005432659737	17843	Economy	6000.00
0005432655749	17843	Economy	6000.00
0005432663061	17843	Economy	6000.00
0005432659734	17843	Economy	6000.00
0005434151774	17843	Economy	6000.00
0005432661944	17843	Economy	6000.00
0005432655611	17843	Economy	6000.00
0005432663057	17843	Economy	6000.00
0005432665319	26288	Business	18000.00
0005432869597	26288	Business	18000.00
0005432664187	26288	Business	18000.00
0005432663081	26288	Business	18000.00
0005432661961	26288	Business	18000.00
0005432661969	26288	Business	18000.00
0005432663085	26288	Business	18000.00
0005432664180	26288	Business	18000.00
0005432661972	26288	Economy	6000.00
0005432655788	26288	Economy	6000.00
0005432661962	26288	Economy	6000.00
0005432661960	26288	Economy	6000.00
0005434151738	26288	Economy	6000.00
0005432655781	26288	Economy	6000.00
0005432661968	26288	Economy	6000.00
0005432664174	26288	Economy	6000.00
0005432664186	26288	Economy	6000.00
0005432661971	26288	Economy	6600.00
0005432663079	26288	Economy	6600.00
0005432657516	26288	Economy	6000.00
0005432663080	26288	Economy	6000.00
0005432664177	26288	Economy	6000.00
0005432664178	26288	Economy	6000.00
0005432663074	26288	Economy	6000.00
0005432663077	26288	Economy	6000.00
0005432655789	26288	Economy	6000.00
0005434151739	26288	Economy	6000.00
0005432664179	26288	Economy	6000.00
0005432655783	26288	Economy	6000.00
0005432667498	26288	Economy	6000.00
0005432663075	26288	Economy	6000.00
0005432664184	26288	Economy	6000.00
0005432663078	26288	Economy	6000.00
0005432664175	26288	Economy	6000.00
0005432664182	26288	Economy	6000.00
0005432666433	26288	Economy	6000.00
0005432663071	26288	Economy	6000.00
0005432661966	26288	Economy	6000.00
0005432655785	26288	Economy	6000.00
0005432664185	26288	Economy	6000.00
0005432663072	26288	Economy	6000.00
0005432661973	26288	Economy	6000.00
0005432869591	26288	Economy	6000.00
0005432666434	26288	Economy	6000.00
0005432661974	26288	Economy	6000.00
0005432659751	26288	Economy	6000.00
0005432663076	26288	Economy	6000.00
0005432660863	26288	Economy	6000.00
0005432661964	26288	Economy	6000.00
0005432664176	26288	Economy	6000.00
0005432658636	26288	Economy	6000.00
0005432661967	26288	Economy	6000.00
0005432666432	26288	Economy	6000.00
0005434151743	26288	Economy	6000.00
0005432655784	26288	Economy	6000.00
0005432659752	26288	Economy	6000.00
0005432664173	26288	Economy	6000.00
0005432655786	26288	Economy	6000.00
0005434151731	26288	Economy	6000.00
0005432661965	26288	Economy	6000.00
0005432661963	26288	Economy	6000.00
0005432663084	26288	Economy	6000.00
0005432869596	26288	Economy	6000.00
0005432869604	26288	Economy	6000.00
0005432663082	26288	Economy	6000.00
0005432661970	26288	Economy	6000.00
0005432667499	26288	Economy	6000.00
0005432655782	26288	Economy	6000.00
0005434151736	26288	Economy	6000.00
0005432657515	26288	Economy	6000.00
0005434151735	26288	Economy	6000.00
0005432660862	26288	Economy	6000.00
0005432658635	26288	Economy	6000.00
0005432655779	26288	Economy	6000.00
0005432664183	26288	Economy	6000.00
0005432655780	26288	Economy	6000.00
0005432663073	26288	Economy	6000.00
0005432663083	26288	Economy	6000.00
0005432664181	26288	Economy	6000.00
0005432655787	26288	Economy	6000.00
0005432639284	25061	Business	87300.00
0005432639251	25061	Business	87300.00
0005432866176	25061	Business	87300.00
0005432639333	25061	Business	87300.00
0005432639214	25061	Business	87300.00
0005432866174	25061	Business	87300.00
0005432639266	25061	Economy	29100.00
0005432866161	25061	Economy	29100.00
0005432866172	25061	Economy	29100.00
0005432866166	25061	Economy	29100.00
0005432866179	25061	Economy	29100.00
0005432639291	25061	Economy	32000.00
0005432866167	25061	Economy	32000.00
0005432639301	25061	Economy	29100.00
0005432866169	25061	Economy	29100.00
0005432639342	25061	Economy	29100.00
0005432639320	25061	Economy	29100.00
0005432639267	25061	Economy	29100.00
0005432866177	25061	Economy	29100.00
0005432639265	25061	Economy	29100.00
0005432639287	25061	Economy	29100.00
0005432639239	25061	Economy	29100.00
0005432866175	25061	Economy	29100.00
0005432639268	25061	Economy	29100.00
0005432866160	25061	Economy	29100.00
0005432639275	25061	Economy	29100.00
0005432639240	25061	Economy	29100.00
0005432866170	25061	Economy	29100.00
0005432639245	25061	Economy	29100.00
0005432639323	25061	Economy	29100.00
0005432639341	25061	Economy	29100.00
0005432639316	25061	Economy	29100.00
0005432866171	25061	Economy	29100.00
0005432639324	25061	Economy	29100.00
0005432639321	25061	Economy	29100.00
0005432866162	25061	Economy	29100.00
0005432866163	25061	Economy	29100.00
0005432639322	25061	Economy	29100.00
0005432866173	25061	Economy	29100.00
0005432639317	25061	Economy	29100.00
0005432639283	25061	Economy	29100.00
0005432866159	25061	Economy	29100.00
0005432866158	25061	Economy	29100.00
0005432639298	25061	Economy	29100.00
0005432639332	25061	Economy	29100.00
0005432866164	25061	Economy	29100.00
0005432866178	25061	Economy	29100.00
0005432639307	25061	Economy	29100.00
0005432639292	25061	Economy	29100.00
0005432866168	25061	Economy	29100.00
0005432639276	25061	Economy	29100.00
0005432866165	25061	Economy	29100.00
0005432639297	25061	Economy	29100.00
0005432639252	25061	Economy	29100.00
0005432639356	25061	Economy	29100.00
0005432639282	25061	Economy	29100.00
0005432287305	3095	Business	16100.00
0005432329753	3095	Business	16100.00
0005432329762	3095	Business	16100.00
0005432329748	3095	Business	16100.00
0005432329734	3095	Business	16100.00
0005432329767	3095	Business	16100.00
0005432848841	3095	Business	16100.00
0005432329732	3095	Business	16100.00
0005432329766	3095	Economy	5400.00
0005433439027	3095	Economy	5400.00
0005432329725	3095	Economy	5400.00
0005432329764	3095	Economy	5400.00
0005432287304	3095	Economy	5400.00
0005432329737	3095	Economy	5400.00
0005432329743	3095	Economy	5400.00
0005432329735	3095	Economy	5900.00
0005432329754	3095	Economy	5900.00
0005432287307	3095	Economy	5400.00
0005432329756	3095	Economy	5400.00
0005432329749	3095	Economy	5400.00
0005432329755	3095	Economy	5400.00
0005433439026	3095	Economy	5400.00
0005433439019	3095	Economy	5400.00
0005432287306	3095	Economy	5400.00
0005432329759	3095	Economy	5400.00
0005432329750	3095	Economy	5400.00
0005433439021	3095	Economy	5400.00
0005432329740	3095	Economy	5400.00
0005432905220	3095	Economy	5400.00
0005432905204	3095	Economy	5400.00
0005432329742	3095	Economy	5400.00
0005432905228	3095	Economy	5400.00
0005433439025	3095	Economy	5400.00
0005432329746	3095	Economy	5400.00
0005432329763	3095	Economy	5400.00
0005432905227	3095	Economy	5400.00
0005433439029	3095	Economy	5400.00
0005432329731	3095	Economy	5400.00
0005432329724	3095	Economy	5400.00
0005432329722	3095	Economy	5400.00
0005432329761	3095	Economy	5400.00
0005432329723	3095	Economy	5400.00
0005432329760	3095	Economy	5400.00
0005432329736	3095	Economy	5400.00
0005432329757	3095	Economy	5400.00
0005432329733	3095	Economy	5400.00
0005433439022	3095	Economy	5400.00
0005432329738	3095	Economy	5400.00
0005432329751	3095	Economy	5400.00
0005432329727	3095	Economy	5400.00
0005433439020	3095	Economy	5400.00
0005432905194	3095	Economy	5400.00
0005432329726	3095	Economy	5400.00
0005432329747	3095	Economy	5400.00
0005432848845	3095	Economy	5400.00
0005432905205	3095	Economy	5400.00
0005432329728	3095	Economy	5400.00
0005432329739	3095	Economy	5400.00
0005433439023	3095	Economy	5400.00
0005433439028	3095	Economy	5400.00
0005432329765	3095	Economy	5400.00
0005432329730	3095	Economy	5400.00
0005432329752	3095	Economy	5400.00
0005432287303	3095	Economy	5400.00
0005433439024	3095	Economy	5400.00
0005432329729	3095	Economy	5400.00
0005432329745	3095	Economy	5400.00
0005432329741	3095	Economy	5400.00
0005432329744	3095	Economy	5400.00
0005432329768	3095	Economy	5400.00
0005432329758	3095	Economy	5400.00
0005433439018	3095	Economy	5400.00
0005432329387	31124	Business	16100.00
0005432329278	31124	Business	16100.00
0005432329345	31124	Business	16100.00
0005432329226	31124	Business	16100.00
0005432329171	31124	Business	16100.00
0005432329334	31124	Business	16100.00
0005432329223	31124	Business	16100.00
0005432329353	31124	Economy	5400.00
0005432329274	31124	Economy	5400.00
0005432329322	31124	Economy	5400.00
0005432329328	31124	Economy	5400.00
0005432848881	31124	Economy	5400.00
0005432329308	31124	Economy	5900.00
0005432329254	31124	Economy	5900.00
0005432328990	31124	Economy	5900.00
0005432848884	31124	Economy	5400.00
0005432329526	31124	Economy	5400.00
0005432329312	31124	Economy	5400.00
0005432329258	31124	Economy	5400.00
0005432848880	31124	Economy	5400.00
0005432905258	31124	Economy	5400.00
0005432329307	31124	Economy	5400.00
0005433438946	31124	Economy	5400.00
0005433438969	31124	Economy	5400.00
0005432329468	31124	Economy	5400.00
0005432329235	31124	Economy	5400.00
0005432328984	31124	Economy	5400.00
0005432329517	31124	Economy	5400.00
0005432329388	31124	Economy	5400.00
0005433438984	31124	Economy	5400.00
0005432329259	31124	Economy	5400.00
0005432329222	31124	Economy	5400.00
0005432054371	31124	Economy	5400.00
0005432848885	31124	Economy	5400.00
0005432329469	31124	Economy	5400.00
0005432905254	31124	Economy	5400.00
0005432329313	31124	Economy	5400.00
0005432329355	31124	Economy	5400.00
0005432329360	31124	Economy	5400.00
0005432329247	31124	Economy	5400.00
0005432848887	31124	Economy	5400.00
0005432905255	31124	Economy	5400.00
0005432329248	31124	Economy	5400.00
0005432905253	31124	Economy	5400.00
0005432329253	31124	Economy	5400.00
0005432054372	31124	Economy	5400.00
0005432848886	31124	Economy	5400.00
0005432329175	31124	Economy	5400.00
0005432054370	31124	Economy	5400.00
0005432848882	31124	Economy	5400.00
0005432848883	31124	Economy	5400.00
0005432329340	31124	Economy	5400.00
0005432848888	31124	Economy	5400.00
0005432329211	31124	Economy	5400.00
0005432329346	31124	Economy	5400.00
0005432905256	31124	Economy	5400.00
0005432905257	31124	Economy	5400.00
0005432329279	31124	Economy	5400.00
0005432329422	31124	Economy	5400.00
0005432329225	31124	Economy	5400.00
0005432329335	31124	Economy	5400.00
0005432329174	31124	Economy	5400.00
0005432329516	31124	Economy	5400.00
0005432329427	31124	Economy	5400.00
0005432329210	31124	Economy	5400.00
0005435999650	6191	Business	124600.00
0005435488131	6191	Business	124600.00
0005435999652	6191	Business	124600.00
0005435297133	6191	Business	124600.00
0005435999647	6191	Business	124600.00
0005435488060	6191	Business	124600.00
0005435488184	6191	Business	124600.00
0005434310055	6191	Business	124600.00
0005435999662	6191	Business	124600.00
0005435999661	6191	Economy	41500.00
0005435488151	6191	Economy	41500.00
0005435297143	6191	Economy	41500.00
0005434310050	6191	Economy	41500.00
0005434310058	6191	Economy	41500.00
0005435999657	6191	Economy	41500.00
0005435999659	6191	Economy	41500.00
0005435999663	6191	Economy	41500.00
0005435297134	6191	Economy	41500.00
0005434310061	6191	Economy	41500.00
0005435999649	6191	Economy	41500.00
0005435999669	6191	Economy	41500.00
0005434310051	6191	Economy	41500.00
0005434310060	6191	Economy	41500.00
0005435488150	6191	Economy	41500.00
0005435999667	6191	Economy	41500.00
0005435488084	6191	Economy	41500.00
0005434310053	6191	Economy	41500.00
0005435999648	6191	Economy	41500.00
0005435999666	6191	Economy	41500.00
0005435488081	6191	Economy	41500.00
0005435297157	6191	Economy	45700.00
0005435488203	6191	Economy	41500.00
0005435297146	6191	Economy	45700.00
0005434310047	6191	Economy	45700.00
0005435999665	6191	Economy	41500.00
0005434310057	6191	Economy	41500.00
0005434310052	6191	Economy	41500.00
0005435297154	6191	Economy	41500.00
0005435297156	6191	Economy	41500.00
0005435488185	6191	Economy	41500.00
0005435999655	6191	Economy	41500.00
0005435488168	6191	Economy	41500.00
0005434310056	6191	Economy	41500.00
0005435999654	6191	Economy	41500.00
0005435999660	6191	Economy	41500.00
0005435488182	6191	Economy	41500.00
0005434310059	6191	Economy	41500.00
0005435297171	6191	Economy	41500.00
0005435488206	6191	Economy	41500.00
0005435999656	6191	Economy	41500.00
0005435488205	6191	Economy	41500.00
0005435999668	6191	Economy	41500.00
0005435488172	6191	Economy	41500.00
0005435488096	6191	Economy	41500.00
0005435999670	6191	Economy	41500.00
0005435999646	6191	Economy	41500.00
0005434310054	6191	Economy	41500.00
0005434310049	6191	Economy	41500.00
0005435999651	6191	Economy	41500.00
0005435488174	6191	Economy	41500.00
0005435488198	6191	Economy	41500.00
0005435999664	6191	Economy	41500.00
0005435999653	6191	Economy	41500.00
0005435488173	6191	Economy	41500.00
0005434310048	6191	Economy	41500.00
0005435297150	6191	Economy	41500.00
0005435488138	6191	Economy	41500.00
0005435999658	6191	Economy	41500.00
0005435297213	19527	Business	124600.00
0005435999425	19527	Business	124600.00
0005435488300	19527	Business	124600.00
0005435488304	19527	Business	124600.00
0005435488297	19527	Business	124600.00
0005434309929	19527	Business	124600.00
0005435999488	19527	Business	124600.00
0005435488299	19527	Economy	41500.00
0005435488311	19527	Economy	41500.00
0005435999438	19527	Economy	41500.00
0005435999406	19527	Economy	41500.00
0005435488307	19527	Economy	41500.00
0005435488314	19527	Economy	41500.00
0005435999426	19527	Economy	41500.00
0005434309933	19527	Economy	41500.00
0005435999486	19527	Economy	41500.00
0005435999385	19527	Economy	41500.00
0005435297215	19527	Economy	41500.00
0005435297218	19527	Economy	41500.00
0005434309967	19527	Economy	41500.00
0005434309882	19527	Economy	41500.00
0005435297214	19527	Economy	41500.00
0005435488308	19527	Economy	41500.00
0005435488313	19527	Economy	41500.00
0005435488306	19527	Economy	41500.00
0005435999441	19527	Economy	41500.00
0005435488309	19527	Economy	45700.00
0005435999440	19527	Economy	41500.00
0005434309935	19527	Economy	41500.00
0005435488296	19527	Economy	41500.00
0005435488298	19527	Economy	41500.00
0005435488317	19527	Economy	41500.00
0005435999410	19527	Economy	41500.00
0005434309934	19527	Economy	41500.00
0005435488315	19527	Economy	41500.00
0005435999487	19527	Economy	41500.00
0005435488310	19527	Economy	41500.00
0005435488316	19527	Economy	41500.00
0005435999470	19527	Economy	41500.00
0005435488305	19527	Economy	41500.00
0005434309930	19527	Economy	41500.00
0005435488318	19527	Economy	41500.00
0005435488295	19527	Economy	41500.00
0005435999436	19527	Economy	41500.00
0005435488312	19527	Economy	41500.00
0005435488303	19527	Economy	41500.00
0005435999431	19527	Economy	41500.00
0005435999506	19527	Economy	41500.00
0005435999437	19527	Economy	41500.00
0005435488301	19527	Economy	41500.00
0005435999386	19527	Economy	41500.00
0005434309910	19527	Economy	41500.00
0005435297217	19527	Economy	41500.00
0005435297212	19527	Economy	41500.00
0005435488302	19527	Economy	41500.00
0005435999405	19527	Economy	41500.00
0005434309957	19527	Economy	41500.00
0005434309968	19527	Economy	41500.00
0005435297216	19527	Economy	41500.00
0005434309908	19527	Economy	41500.00
0005433158180	17559	Economy	13600.00
0005434446551	17559	Economy	12300.00
0005434446554	17559	Economy	12300.00
0005434446544	17559	Economy	12300.00
0005434446550	17559	Economy	12300.00
0005434446539	17559	Economy	12300.00
0005433157010	17559	Economy	12300.00
0005434446533	17559	Economy	12300.00
0005433158181	17559	Economy	12300.00
0005433158182	17559	Economy	12300.00
0005434446545	17559	Economy	12300.00
0005433158183	17559	Economy	12300.00
0005433158179	17559	Economy	12300.00
0005434446538	17559	Economy	12300.00
0005434446549	17559	Economy	12300.00
0005434446548	17559	Economy	12300.00
0005435502810	1590	Business	86000.00
0005435502803	1590	Business	86000.00
0005435518323	1590	Business	86000.00
0005435518318	1590	Business	86000.00
0005435518316	1590	Business	86000.00
0005433186253	1590	Business	86000.00
0005435502811	1590	Business	86000.00
0005433186233	1590	Business	86000.00
0005435508663	1590	Business	86000.00
0005435508672	1590	Economy	28700.00
0005434566227	1590	Economy	28700.00
0005435502800	1590	Economy	28700.00
0005434566221	1590	Economy	28700.00
0005434566215	1590	Economy	28700.00
0005434566219	1590	Economy	28700.00
0005434566218	1590	Economy	28700.00
0005435518330	1590	Economy	28700.00
0005435508661	1590	Economy	28700.00
0005435508662	1590	Economy	31500.00
0005435502806	1590	Economy	31500.00
0005433186252	1590	Economy	31500.00
0005435518320	1590	Economy	31500.00
0005435508680	1590	Economy	31500.00
0005435502801	1590	Economy	28700.00
0005435518324	1590	Economy	28700.00
0005435508677	1590	Economy	28700.00
0005432291988	1590	Economy	28700.00
0005435502812	1590	Economy	28700.00
0005435502796	1590	Economy	28700.00
0005433186217	1590	Economy	28700.00
0005435508667	1590	Economy	28700.00
0005435508664	1590	Economy	28700.00
0005435502797	1590	Economy	28700.00
0005435508679	1590	Economy	28700.00
0005435518329	1590	Economy	28700.00
0005435502815	1590	Economy	28700.00
0005435518327	1590	Economy	28700.00
0005434566225	1590	Economy	28700.00
0005432291987	1590	Economy	28700.00
0005435518325	1590	Economy	28700.00
0005435502798	1590	Economy	28700.00
0005435508666	1590	Economy	28700.00
0005435502808	1590	Economy	28700.00
0005435508682	1590	Economy	28700.00
0005433186234	1590	Economy	28700.00
0005435508670	1590	Economy	28700.00
0005435502809	1590	Economy	28700.00
0005435518326	1590	Economy	28700.00
0005434566222	1590	Economy	28700.00
0005434566228	1590	Economy	28700.00
0005435508671	1590	Economy	28700.00
0005432291986	1590	Economy	28700.00
0005433186235	1590	Economy	28700.00
0005433186251	1590	Economy	28700.00
0005433186213	1590	Economy	28700.00
0005435508669	1590	Economy	28700.00
0005435502805	1590	Economy	28700.00
0005433186232	1590	Economy	28700.00
0005435502799	1590	Economy	28700.00
0005435508683	1590	Economy	28700.00
0005435502817	1590	Economy	28700.00
0005435508676	1590	Economy	28700.00
0005434566223	1590	Economy	28700.00
0005435508678	1590	Economy	28700.00
0005435518328	1590	Economy	28700.00
0005435502807	1590	Economy	28700.00
0005435508681	1590	Economy	28700.00
0005433186214	1590	Economy	28700.00
0005435508668	1590	Economy	28700.00
0005435502802	1590	Economy	28700.00
0005432291985	1590	Economy	28700.00
0005434566217	1590	Economy	28700.00
0005435518322	1590	Economy	28700.00
0005435508675	1590	Economy	28700.00
0005435502816	1590	Economy	28700.00
0005435502804	1590	Economy	28700.00
0005434566220	1590	Economy	28700.00
0005435518321	1590	Economy	28700.00
0005434566226	1590	Economy	28700.00
0005434566224	1590	Economy	28700.00
0005434566216	1590	Economy	28700.00
0005435518319	1590	Economy	28700.00
0005435508673	1590	Economy	28700.00
0005435502813	1590	Economy	28700.00
0005435502814	1590	Economy	28700.00
0005435508665	1590	Economy	28700.00
0005435518317	1590	Economy	28700.00
0005435508674	1590	Economy	28700.00
0005435545833	20877	Business	86000.00
0005433186313	20877	Business	86000.00
0005434566113	20877	Business	86000.00
0005435502532	20877	Business	86000.00
0005433186317	20877	Business	86000.00
0005434566137	20877	Business	86000.00
0005433186318	20877	Business	86000.00
0005433186315	20877	Economy	28700.00
0005435502585	20877	Economy	28700.00
0005435529516	20877	Economy	28700.00
0005433186310	20877	Economy	28700.00
0005435545841	20877	Economy	28700.00
0005434566105	20877	Economy	31500.00
0005435545825	20877	Economy	31500.00
0005434566112	20877	Economy	31500.00
0005434566096	20877	Economy	28700.00
0005435529576	20877	Economy	28700.00
0005433186314	20877	Economy	28700.00
0005435502589	20877	Economy	28700.00
0005434566139	20877	Economy	28700.00
0005434566106	20877	Economy	28700.00
0005435529469	20877	Economy	28700.00
0005435529608	20877	Economy	28700.00
0005435529544	20877	Economy	28700.00
0005434566138	20877	Economy	28700.00
0005434566107	20877	Economy	28700.00
0005435529547	20877	Economy	28700.00
0005435502610	20877	Economy	28700.00
0005435529543	20877	Economy	28700.00
0005435502636	20877	Economy	28700.00
0005434566104	20877	Economy	28700.00
0005435529392	20877	Economy	28700.00
0005435529575	20877	Economy	28700.00
0005434566114	20877	Economy	28700.00
0005433186311	20877	Economy	28700.00
0005435529508	20877	Economy	28700.00
0005434566128	20877	Economy	28700.00
0005434566125	20877	Economy	28700.00
0005435502679	20877	Economy	28700.00
0005434566116	20877	Economy	28700.00
0005434566115	20877	Economy	28700.00
0005435529574	20877	Economy	28700.00
0005435545824	20877	Economy	28700.00
0005433186316	20877	Economy	28700.00
0005435529578	20877	Economy	28700.00
0005435502683	20877	Economy	28700.00
0005435529515	20877	Economy	28700.00
0005435545840	20877	Economy	28700.00
0005435502571	20877	Economy	28700.00
0005435502640	20877	Economy	28700.00
0005433186312	20877	Economy	28700.00
0005435502642	20877	Economy	28700.00
0005435502565	20877	Economy	28700.00
0005435931657	3909	Economy	21600.00
0005435931660	3909	Economy	19700.00
0005435142978	3909	Economy	19700.00
0005435153890	3909	Economy	19700.00
0005435142980	3909	Economy	19700.00
0005435153892	3909	Economy	19700.00
0005435931659	3909	Economy	19700.00
0005435142977	3909	Economy	19700.00
0005435142979	3909	Economy	19700.00
0005435153895	3909	Economy	19700.00
0005435931658	3909	Economy	19700.00
0005435153891	3909	Economy	19700.00
0005435153893	3909	Economy	19700.00
0005435153894	3909	Economy	19700.00
0005435153838	21886	Economy	19700.00
0005435931686	21886	Economy	19700.00
0005435153822	21886	Economy	19700.00
0005435931690	21886	Economy	19700.00
0005435153837	21886	Economy	19700.00
0005435153843	21886	Economy	19700.00
0005435931687	21886	Economy	19700.00
0005435931685	21886	Economy	19700.00
0005435153831	21886	Economy	19700.00
0005435153841	21886	Economy	19700.00
0005435931689	21886	Economy	19700.00
0005435153790	21886	Economy	19700.00
0005435931688	21886	Economy	19700.00
0005435153836	21886	Economy	19700.00
0005435225696	7190	Economy	14300.00
0005432629189	7190	Economy	13000.00
0005435225713	7190	Economy	13000.00
0005432629191	7190	Economy	13000.00
0005432629177	7190	Economy	13000.00
0005432629185	7190	Economy	13000.00
0005432629187	7190	Economy	13000.00
0005435225649	7190	Economy	13000.00
0005432629181	7190	Economy	13000.00
0005432629178	7190	Economy	13000.00
0005432629179	7190	Economy	13000.00
0005432629183	7190	Economy	13000.00
0005432629182	7190	Economy	13000.00
0005432629190	7190	Economy	13000.00
0005432629186	7190	Economy	13000.00
0005432629184	7190	Economy	13000.00
0005435225648	7190	Economy	13000.00
0005435225691	7190	Economy	13000.00
0005432629180	7190	Economy	13000.00
0005432629188	7190	Economy	13000.00
0005435225765	28115	Economy	14300.00
0005435225767	28115	Economy	14300.00
0005432629096	28115	Economy	13000.00
0005432629106	28115	Economy	13000.00
0005432629107	28115	Economy	13000.00
0005432629026	28115	Economy	13000.00
0005432629074	28115	Economy	13000.00
0005435225769	28115	Economy	13000.00
0005432629066	28115	Economy	13000.00
0005432629099	28115	Economy	13000.00
0005432629046	28115	Economy	13000.00
0005432629109	28115	Economy	13000.00
0005432629049	28115	Economy	13000.00
0005432629108	28115	Economy	13000.00
0005432629037	28115	Economy	13000.00
0005435225770	28115	Economy	13000.00
0005435225764	28115	Economy	13000.00
0005432629095	28115	Economy	13000.00
0005432629036	28115	Economy	13000.00
0005435225771	28115	Economy	13000.00
0005435225772	28115	Economy	13000.00
0005435225766	28115	Economy	13000.00
0005435225768	28115	Economy	13000.00
0005432629089	28115	Economy	13000.00
0005434268004	8737	Economy	11500.00
0005435960138	8737	Economy	11500.00
0005435960139	8737	Economy	10500.00
0005435960140	8737	Economy	10500.00
0005435960136	8737	Economy	10500.00
0005434268003	8737	Economy	10500.00
0005435960137	8737	Economy	10500.00
0005434268002	8737	Economy	10500.00
0005435960115	15271	Economy	11500.00
0005435960116	15271	Economy	11500.00
0005435960107	15271	Economy	11500.00
0005434268037	15271	Economy	10500.00
0005435960094	15271	Economy	10500.00
0005435960123	15271	Economy	10500.00
0005435960093	15271	Economy	10500.00
0005434268034	15271	Economy	10500.00
0005434268035	15271	Economy	10500.00
0005434268036	15271	Economy	10500.00
0005432693752	1205	Business	115000.00
0005432675474	1205	Business	115000.00
0005432693740	1205	Business	115000.00
0005432693731	1205	Business	115000.00
0005432693736	1205	Business	115000.00
0005432693747	1205	Business	115000.00
0005432873388	1205	Business	115000.00
0005432873398	1205	Economy	38300.00
0005432873406	1205	Economy	38300.00
0005432693746	1205	Economy	38300.00
0005432693727	1205	Economy	38300.00
0005432693755	1205	Economy	38300.00
0005432693728	1205	Economy	38300.00
0005432693757	1205	Economy	42200.00
0005432693754	1205	Economy	38300.00
0005432675476	1205	Economy	38300.00
0005432693741	1205	Economy	38300.00
0005432675482	1205	Economy	38300.00
0005432693750	1205	Economy	38300.00
0005432693744	1205	Economy	38300.00
0005432693739	1205	Economy	38300.00
0005432693743	1205	Economy	38300.00
0005432675485	1205	Economy	38300.00
0005432675471	1205	Economy	38300.00
0005432693734	1205	Economy	38300.00
0005432693749	1205	Economy	38300.00
0005432693753	1205	Economy	38300.00
0005432693748	1205	Economy	38300.00
0005432693735	1205	Economy	38300.00
0005432675480	1205	Economy	38300.00
0005432675472	1205	Economy	38300.00
0005432675473	1205	Economy	38300.00
0005432675477	1205	Economy	38300.00
0005432693729	1205	Economy	38300.00
0005432693732	1205	Economy	38300.00
0005432873392	1205	Economy	38300.00
0005432693751	1205	Economy	38300.00
0005432693730	1205	Economy	38300.00
0005432677660	1205	Economy	38300.00
0005432675478	1205	Economy	38300.00
0005432873397	1205	Economy	38300.00
0005432693745	1205	Economy	38300.00
0005432675481	1205	Economy	38300.00
0005432693737	1205	Economy	38300.00
0005432675484	1205	Economy	38300.00
0005432675475	1205	Economy	38300.00
0005432693742	1205	Economy	38300.00
0005432677661	1205	Economy	38300.00
0005432675483	1205	Economy	38300.00
0005432677659	1205	Economy	38300.00
0005432675479	1205	Economy	38300.00
0005432693738	1205	Economy	38300.00
0005432693733	1205	Economy	38300.00
0005432693756	1205	Economy	38300.00
0005432693318	17514	Business	115000.00
0005432693549	17514	Business	115000.00
0005432873455	17514	Business	115000.00
0005432693386	17514	Business	115000.00
0005432675405	17514	Business	115000.00
0005432675364	17514	Business	115000.00
0005432693537	17514	Business	115000.00
0005432873456	17514	Business	115000.00
0005432675395	17514	Business	115000.00
0005432693317	17514	Business	115000.00
0005432693480	17514	Business	115000.00
0005432873454	17514	Business	115000.00
0005432675323	17514	Economy	38300.00
0005432675406	17514	Economy	38300.00
0005432693392	17514	Economy	38300.00
0005432675324	17514	Economy	38300.00
0005432675407	17514	Economy	38300.00
0005432693375	17514	Economy	38300.00
0005432693387	17514	Economy	42200.00
0005432693395	17514	Economy	42200.00
0005432675285	17514	Economy	38300.00
0005432693536	17514	Economy	38300.00
0005432675287	17514	Economy	38300.00
0005432677621	17514	Economy	38300.00
0005432693501	17514	Economy	38300.00
0005432693502	17514	Economy	38300.00
0005432873452	17514	Economy	38300.00
0005432675417	17514	Economy	38300.00
0005432675332	17514	Economy	38300.00
0005432675363	17514	Economy	38300.00
0005432693452	17514	Economy	38300.00
0005432675396	17514	Economy	38300.00
0005432693503	17514	Economy	38300.00
0005432693550	17514	Economy	38300.00
0005432677632	17514	Economy	38300.00
0005432693428	17514	Economy	38300.00
0005432693479	17514	Economy	38300.00
0005432693309	17514	Economy	38300.00
0005432693424	17514	Economy	38300.00
0005432675316	17514	Economy	38300.00
0005432873457	17514	Economy	38300.00
0005432693476	17514	Economy	38300.00
0005432675333	17514	Economy	38300.00
0005432675386	17514	Economy	38300.00
0005432693496	17514	Economy	38300.00
0005432693450	17514	Economy	38300.00
0005432693453	17514	Economy	38300.00
0005432693372	17514	Economy	38300.00
0005432873451	17514	Economy	38300.00
0005432873453	17514	Economy	38300.00
0005434435536	1157	Economy	15200.00
0005433156886	1157	Economy	15200.00
0005433156859	1157	Economy	13900.00
0005433156865	1157	Economy	13900.00
0005433156864	1157	Economy	13900.00
0005434435530	1157	Economy	13900.00
0005434435539	1157	Economy	13900.00
0005434435538	1157	Economy	13900.00
0005434435526	1157	Economy	13900.00
0005434435532	1157	Economy	13900.00
0005434435528	1157	Economy	13900.00
0005434435529	1157	Economy	13900.00
0005434435525	1157	Economy	13900.00
0005434435534	1157	Economy	13900.00
0005434435527	1157	Economy	13900.00
0005434435533	1157	Economy	13900.00
0005433156862	1157	Economy	13900.00
0005434435531	1157	Economy	13900.00
0005433156890	1157	Economy	13900.00
0005433156885	1157	Economy	13900.00
0005434435535	1157	Economy	13900.00
0005433156918	1157	Economy	13900.00
0005434435537	1157	Economy	13900.00
0005434435401	17272	Economy	15200.00
0005433156946	17272	Economy	13900.00
0005434435345	17272	Economy	13900.00
0005434435417	17272	Economy	13900.00
0005433156944	17272	Economy	13900.00
0005433156943	17272	Economy	13900.00
0005433156947	17272	Economy	13900.00
0005433156942	17272	Economy	13900.00
0005433156949	17272	Economy	13900.00
0005434435419	17272	Economy	13900.00
0005433156951	17272	Economy	13900.00
0005433156945	17272	Economy	13900.00
0005434435372	17272	Economy	13900.00
0005434435402	17272	Economy	13900.00
0005434435405	17272	Economy	13900.00
0005433156948	17272	Economy	13900.00
0005434435344	17272	Economy	13900.00
0005434435358	17272	Economy	13900.00
0005433156950	17272	Economy	13900.00
0005435087005	4051	Economy	8200.00
0005435087008	4051	Economy	8200.00
0005435928225	4051	Economy	7500.00
0005435087006	4051	Economy	7500.00
0005435087007	4051	Economy	7500.00
0005435087009	4051	Economy	7500.00
0005435087004	4051	Economy	7500.00
0005435928226	4051	Economy	7500.00
0005435928208	4051	Economy	7500.00
0005435086963	24432	Economy	8200.00
0005435086942	24432	Economy	8200.00
0005435928251	24432	Economy	7500.00
0005435928255	24432	Economy	7500.00
0005435086921	24432	Economy	7500.00
0005435086952	24432	Economy	7500.00
0005435086920	24432	Economy	7500.00
0005435928253	24432	Economy	7500.00
0005435928252	24432	Economy	7500.00
0005435928254	24432	Economy	7500.00
0005433373646	2459	Business	86800.00
0005435706753	2459	Business	86800.00
0005435706765	2459	Business	86800.00
0005435706766	2459	Business	86800.00
0005433373660	2459	Business	86800.00
0005435706740	2459	Business	86800.00
0005435706759	2459	Business	86800.00
0005435706745	2459	Economy	28900.00
0005435706749	2459	Economy	28900.00
0005433373675	2459	Economy	28900.00
0005435706756	2459	Economy	28900.00
0005435706737	2459	Economy	28900.00
0005435706741	2459	Economy	31800.00
0005435706760	2459	Economy	31800.00
0005435706752	2459	Economy	31800.00
0005435706764	2459	Economy	28900.00
0005435706748	2459	Economy	28900.00
0005435706743	2459	Economy	28900.00
0005435706754	2459	Economy	28900.00
0005433373631	2459	Economy	28900.00
0005433373670	2459	Economy	28900.00
0005433373630	2459	Economy	28900.00
0005433373640	2459	Economy	28900.00
0005433373671	2459	Economy	28900.00
0005435706755	2459	Economy	28900.00
0005435706751	2459	Economy	28900.00
0005435706750	2459	Economy	28900.00
0005435706739	2459	Economy	28900.00
0005433373633	2459	Economy	28900.00
0005435706738	2459	Economy	28900.00
0005435706757	2459	Economy	28900.00
0005435706761	2459	Economy	28900.00
0005433373577	2459	Economy	28900.00
0005433373576	2459	Economy	28900.00
0005435706758	2459	Economy	28900.00
0005433373673	2459	Economy	28900.00
0005435706742	2459	Economy	28900.00
0005435706762	2459	Economy	28900.00
0005435706736	2459	Economy	28900.00
0005433373645	2459	Economy	28900.00
0005433373637	2459	Economy	28900.00
0005433373644	2459	Economy	28900.00
0005435706767	2459	Economy	28900.00
0005433373641	2459	Economy	28900.00
0005433373632	2459	Economy	28900.00
0005435706744	2459	Economy	28900.00
0005435706746	2459	Economy	28900.00
0005433373672	2459	Economy	28900.00
0005435706747	2459	Economy	28900.00
0005435706763	2459	Economy	28900.00
0005435706590	27022	Business	86800.00
0005435706675	27022	Business	86800.00
0005435706589	27022	Business	86800.00
0005433373743	27022	Business	86800.00
0005435706621	27022	Business	86800.00
0005435706629	27022	Business	86800.00
0005433373741	27022	Business	86800.00
0005435706562	27022	Economy	28900.00
0005435706647	27022	Economy	28900.00
0005433373734	27022	Economy	28900.00
0005435706548	27022	Economy	28900.00
0005433373742	27022	Economy	28900.00
0005435706595	27022	Economy	28900.00
0005435706565	27022	Economy	28900.00
0005435706580	27022	Economy	28900.00
0005435706536	27022	Economy	31800.00
0005433373739	27022	Economy	31800.00
0005433373738	27022	Economy	31800.00
0005433373732	27022	Economy	31800.00
0005435706603	27022	Economy	28900.00
0005435706583	27022	Economy	28900.00
0005433373737	27022	Economy	28900.00
0005435706604	27022	Economy	28900.00
0005435706623	27022	Economy	28900.00
0005433373730	27022	Economy	28900.00
0005435706573	27022	Economy	28900.00
0005433373744	27022	Economy	28900.00
0005433373747	27022	Economy	28900.00
0005435706585	27022	Economy	28900.00
0005435706547	27022	Economy	28900.00
0005435706569	27022	Economy	28900.00
0005433373731	27022	Economy	28900.00
0005435706523	27022	Economy	28900.00
0005435706591	27022	Economy	28900.00
0005433373746	27022	Economy	28900.00
0005433373733	27022	Economy	28900.00
0005435706514	27022	Economy	28900.00
0005433373736	27022	Economy	28900.00
0005435706560	27022	Economy	28900.00
0005435706636	27022	Economy	28900.00
0005435706601	27022	Economy	28900.00
0005435706584	27022	Economy	28900.00
0005435706515	27022	Economy	28900.00
0005435706624	27022	Economy	28900.00
0005433373729	27022	Economy	28900.00
0005433373745	27022	Economy	28900.00
0005435706600	27022	Economy	28900.00
0005435706622	27022	Economy	28900.00
0005435706579	27022	Economy	28900.00
0005435706592	27022	Economy	28900.00
0005435706612	27022	Economy	28900.00
0005435706566	27022	Economy	28900.00
0005435706561	27022	Economy	28900.00
0005433373735	27022	Economy	28900.00
0005435706630	27022	Economy	28900.00
0005435706567	27022	Economy	28900.00
0005435706540	27022	Economy	28900.00
0005433373740	27022	Economy	28900.00
0005435706578	27022	Economy	28900.00
0005435706602	27022	Economy	28900.00
0005434964675	1330	Business	203300.00
0005433261710	1330	Business	203300.00
0005432279323	1330	Business	203300.00
0005432279319	1330	Business	203300.00
0005433261692	1330	Business	203300.00
0005434964667	1330	Business	203300.00
0005434964638	1330	Business	203300.00
0005433261684	1330	Business	203300.00
0005434964617	1330	Business	203300.00
0005434964674	1330	Business	203300.00
0005433261749	1330	Business	203300.00
0005434964618	1330	Business	203300.00
0005434964635	1330	Business	203300.00
0005434964629	1330	Business	203300.00
0005434964648	1330	Business	203300.00
0005434964636	1330	Business	203300.00
0005432279320	1330	Business	203300.00
0005434964623	1330	Business	203300.00
0005433261712	1330	Business	203300.00
0005434964632	1330	Economy	74500.00
0005433261711	1330	Economy	67800.00
0005434964622	1330	Economy	67800.00
0005434964651	1330	Economy	67800.00
0005434964647	1330	Economy	67800.00
0005434964628	1330	Economy	67800.00
0005433261717	1330	Economy	67800.00
0005434964673	1330	Economy	67800.00
0005432279318	1330	Economy	67800.00
0005434964655	1330	Economy	67800.00
0005434964658	1330	Economy	67800.00
0005433261747	1330	Economy	67800.00
0005434964642	1330	Economy	67800.00
0005434964664	1330	Economy	67800.00
0005433261693	1330	Economy	67800.00
0005434964656	1330	Economy	67800.00
0005433261697	1330	Economy	67800.00
0005434964641	1330	Economy	67800.00
0005434964621	1330	Economy	67800.00
0005434964620	1330	Economy	67800.00
0005434964645	1330	Economy	67800.00
0005433261679	1330	Economy	67800.00
0005433261672	1330	Economy	67800.00
0005433261661	1330	Economy	67800.00
0005433261709	1330	Economy	67800.00
0005434964650	1330	Economy	67800.00
0005433261748	1330	Economy	67800.00
0005434964639	1330	Economy	67800.00
0005433261695	1330	Economy	67800.00
0005433261745	1330	Economy	67800.00
0005433261687	1330	Economy	67800.00
0005432279322	1330	Economy	67800.00
0005433261663	1330	Economy	67800.00
0005434964627	1330	Economy	67800.00
0005433261703	1330	Economy	67800.00
0005434964625	1330	Economy	67800.00
0005434964653	1330	Economy	67800.00
0005434964643	1330	Economy	67800.00
0005434964662	1330	Economy	67800.00
0005434964637	1330	Economy	67800.00
0005434964649	1330	Economy	74500.00
0005434964665	1330	Economy	74500.00
0005433261690	1330	Economy	67800.00
0005434964646	1330	Economy	67800.00
0005434964657	1330	Economy	74500.00
0005434964669	1330	Economy	67800.00
0005434964644	1330	Economy	67800.00
0005434964631	1330	Economy	67800.00
0005434964671	1330	Economy	67800.00
0005433261686	1330	Economy	67800.00
0005434964640	1330	Economy	67800.00
0005433261688	1330	Economy	67800.00
0005434964663	1330	Economy	67800.00
0005434964670	1330	Economy	67800.00
0005434964654	1330	Economy	67800.00
0005434964633	1330	Economy	67800.00
0005433261713	1330	Economy	67800.00
0005434964626	1330	Economy	67800.00
0005433261691	1330	Economy	67800.00
0005434964668	1330	Economy	67800.00
0005434964661	1330	Economy	67800.00
0005433261668	1330	Economy	67800.00
0005434964652	1330	Economy	67800.00
0005434964666	1330	Economy	67800.00
0005433261705	1330	Economy	67800.00
0005434964630	1330	Economy	67800.00
0005433261708	1330	Economy	67800.00
0005433261680	1330	Economy	67800.00
0005433261685	1330	Economy	67800.00
0005433261683	1330	Economy	67800.00
0005434964619	1330	Economy	67800.00
0005434964624	1330	Economy	67800.00
0005434964660	1330	Economy	67800.00
0005433261662	1330	Economy	67800.00
0005434964659	1330	Economy	67800.00
0005433261667	1330	Economy	67800.00
0005433261650	1330	Economy	67800.00
0005434964672	1330	Economy	67800.00
0005434964634	1330	Economy	67800.00
0005433261732	1330	Economy	67800.00
0005433261669	1330	Economy	67800.00
0005433261646	1330	Economy	67800.00
0005432279321	1330	Economy	67800.00
0005434626180	4828	Business	44200.00
0005434626177	4828	Business	44200.00
0005435907573	4828	Business	44200.00
0005433194886	4828	Business	44200.00
0005435907588	4828	Economy	14700.00
0005434626183	4828	Economy	16200.00
0005434626181	4828	Economy	16200.00
0005434626173	4828	Economy	14700.00
0005435907583	4828	Economy	14700.00
0005434626174	4828	Economy	14700.00
0005435907589	4828	Economy	14700.00
0005434626178	4828	Economy	14700.00
0005435907571	4828	Economy	14700.00
0005434626179	4828	Economy	14700.00
0005435907578	4828	Economy	14700.00
0005434626176	4828	Economy	14700.00
0005435907587	4828	Economy	14700.00
0005434626175	4828	Economy	14700.00
0005434626182	4828	Economy	14700.00
0005435907618	32917	Business	44200.00
0005435907620	32917	Business	44200.00
0005433194926	32917	Economy	14700.00
0005433194924	32917	Economy	14700.00
0005434626127	32917	Economy	16200.00
0005435907619	32917	Economy	16200.00
0005433194922	32917	Economy	14700.00
0005433194925	32917	Economy	14700.00
0005435907617	32917	Economy	14700.00
0005435907616	32917	Economy	14700.00
0005434626113	32917	Economy	14700.00
0005434626137	32917	Economy	14700.00
0005434626138	32917	Economy	14700.00
0005433194923	32917	Economy	14700.00
0005434626114	32917	Economy	14700.00
0005435907621	32917	Economy	14700.00
0005433194928	32917	Economy	14700.00
0005433194927	32917	Economy	14700.00
0005434626079	32917	Economy	14700.00
0005435785812	13780	Economy	3400.00
0005435785694	13780	Economy	3400.00
0005435785884	13780	Economy	3400.00
0005435785879	13780	Economy	3400.00
0005435785743	13780	Economy	3100.00
0005435785796	13780	Economy	3100.00
0005435785878	13780	Economy	3100.00
0005435785659	13780	Economy	3100.00
0005435937498	13780	Economy	3100.00
0005435785830	13780	Economy	3100.00
0005435785780	13780	Economy	3100.00
0005435785827	13780	Economy	3100.00
0005432195741	13780	Economy	3100.00
0005435785725	13780	Economy	3100.00
0005435785797	13780	Economy	3100.00
0005435785815	13780	Economy	3100.00
0005435785859	13780	Economy	3100.00
0005435785673	13780	Economy	3100.00
0005435785897	13780	Economy	3100.00
0005435785656	13780	Economy	3100.00
0005435787379	13780	Economy	3100.00
0005435785831	13780	Economy	3100.00
0005435785817	13780	Economy	3100.00
0005435937499	13780	Economy	3100.00
0005435785852	13780	Economy	3100.00
0005435787378	13780	Economy	3100.00
0005435785785	13780	Economy	3100.00
0005435785848	13780	Economy	3100.00
0005435785816	13780	Economy	3100.00
0005435785677	13780	Economy	3100.00
0005435785853	13780	Economy	3100.00
0005435785858	13780	Economy	3100.00
0005432195742	13780	Economy	3100.00
0005435785657	13780	Economy	3100.00
0005435785658	13780	Economy	3100.00
0005435785849	13780	Economy	3100.00
0005435785804	13780	Economy	3100.00
0005435785824	13780	Economy	3100.00
0005435786000	13780	Economy	3100.00
0005435785896	13780	Economy	3100.00
0005435785825	13780	Economy	3100.00
0005435785672	13780	Economy	3100.00
0005435787377	13780	Economy	3100.00
0005435785835	13780	Economy	3100.00
0005435785845	13780	Economy	3100.00
0005435785871	13780	Economy	3100.00
0005435785784	13780	Economy	3100.00
0005435785747	13780	Economy	3100.00
0005435785883	13780	Economy	3100.00
0005435785809	13780	Economy	3100.00
0005435786096	27396	Economy	3400.00
0005435937430	27396	Economy	3400.00
0005435786093	27396	Economy	3400.00
0005435786088	27396	Economy	3400.00
0005432190712	27396	Economy	3100.00
0005435786081	27396	Economy	3100.00
0005435937428	27396	Economy	3100.00
0005435786102	27396	Economy	3100.00
0005435786080	27396	Economy	3100.00
0005435786076	27396	Economy	3100.00
0005435937422	27396	Economy	3100.00
0005435786083	27396	Economy	3100.00
0005435786103	27396	Economy	3100.00
0005435786084	27396	Economy	3100.00
0005435937424	27396	Economy	3100.00
0005435786087	27396	Economy	3100.00
0005435787398	27396	Economy	3100.00
0005435786106	27396	Economy	3100.00
0005435786108	27396	Economy	3100.00
0005435786097	27396	Economy	3100.00
0005435786092	27396	Economy	3100.00
0005435787400	27396	Economy	3100.00
0005432190713	27396	Economy	3100.00
0005435786085	27396	Economy	3100.00
0005435786079	27396	Economy	3100.00
0005435786078	27396	Economy	3100.00
0005432190711	27396	Economy	3100.00
0005435786109	27396	Economy	3100.00
0005435937423	27396	Economy	3100.00
0005435786091	27396	Economy	3100.00
0005435786094	27396	Economy	3100.00
0005435937425	27396	Economy	3100.00
0005432190710	27396	Economy	3100.00
0005435786107	27396	Economy	3100.00
0005435786110	27396	Economy	3100.00
0005435786098	27396	Economy	3100.00
0005435786082	27396	Economy	3100.00
0005435786095	27396	Economy	3100.00
0005435787399	27396	Economy	3100.00
0005435786086	27396	Economy	3100.00
0005435786100	27396	Economy	3100.00
0005435786090	27396	Economy	3100.00
0005435786101	27396	Economy	3100.00
0005435786099	27396	Economy	3100.00
0005435786077	27396	Economy	3100.00
0005435786104	27396	Economy	3100.00
0005435786089	27396	Economy	3100.00
0005435786105	27396	Economy	3100.00
0005434408640	20250	Business	12000.00
0005435311413	20250	Business	12000.00
0005435311390	20250	Business	12000.00
0005435311409	20250	Business	12000.00
0005432058474	20250	Business	12000.00
0005434408730	20250	Business	12000.00
0005434408781	20250	Business	12000.00
0005434408649	20250	Business	12000.00
0005435311415	20250	Business	12000.00
0005434408652	20250	Business	12000.00
0005435311397	20250	Economy	4000.00
0005435311401	20250	Economy	4000.00
0005435311403	20250	Economy	4000.00
0005434408433	20250	Economy	4000.00
0005435311388	20250	Economy	4000.00
0005434408531	20250	Economy	4000.00
0005434408703	20250	Economy	4000.00
0005435311407	20250	Economy	4000.00
0005435311387	20250	Economy	4000.00
0005435311395	20250	Economy	4400.00
0005434408458	20250	Economy	4400.00
0005434408514	20250	Economy	4400.00
0005435311408	20250	Economy	4400.00
0005434408706	20250	Economy	4400.00
0005434408492	20250	Economy	4000.00
0005435311411	20250	Economy	4000.00
0005435311417	20250	Economy	4000.00
0005434408229	20250	Economy	4000.00
0005435311392	20250	Economy	4000.00
0005435311404	20250	Economy	4000.00
0005434408564	20250	Economy	4000.00
0005434408914	20250	Economy	4000.00
0005434408355	20250	Economy	4000.00
0005435311405	20250	Economy	4000.00
0005435311398	20250	Economy	4000.00
0005434408747	20250	Economy	4000.00
0005435311399	20250	Economy	4000.00
0005435311400	20250	Economy	4000.00
0005434408702	20250	Economy	4000.00
0005434408924	20250	Economy	4000.00
0005434408228	20250	Economy	4000.00
0005434408625	20250	Economy	4000.00
0005435311412	20250	Economy	4000.00
0005435311402	20250	Economy	4000.00
0005434408651	20250	Economy	4000.00
0005434408884	20250	Economy	4000.00
0005434408446	20250	Economy	4000.00
0005435311396	20250	Economy	4000.00
0005434408925	20250	Economy	4000.00
0005434408852	20250	Economy	4000.00
0005434408666	20250	Economy	4000.00
0005434408574	20250	Economy	4000.00
0005434408312	20250	Economy	4000.00
0005432058473	20250	Economy	4000.00
0005434408459	20250	Economy	4000.00
0005434408543	20250	Economy	4000.00
0005434408626	20250	Economy	4000.00
0005435311394	20250	Economy	4000.00
0005434408655	20250	Economy	4000.00
0005434408604	20250	Economy	4000.00
0005434408610	20250	Economy	4000.00
0005434408748	20250	Economy	4000.00
0005435311419	20250	Economy	4000.00
0005435311391	20250	Economy	4000.00
0005434408686	20250	Economy	4000.00
0005434408749	20250	Economy	4000.00
0005435311418	20250	Economy	4000.00
0005434408669	20250	Economy	4000.00
0005435311389	20250	Economy	4000.00
0005434408460	20250	Economy	4000.00
0005434408883	20250	Economy	4000.00
0005432058471	20250	Economy	4000.00
0005435311416	20250	Economy	4000.00
0005432058470	20250	Economy	4000.00
0005435311406	20250	Economy	4000.00
0005434408650	20250	Economy	4000.00
0005434408328	20250	Economy	4000.00
0005434408815	20250	Economy	4000.00
0005432058472	20250	Economy	4000.00
0005435311410	20250	Economy	4000.00
0005434408627	20250	Economy	4000.00
0005434408544	20250	Economy	4000.00
0005435311393	20250	Economy	4000.00
0005435311414	20250	Economy	4000.00
0005435311421	20250	Economy	4000.00
0005434408729	20250	Economy	4000.00
0005434408851	20250	Economy	4000.00
0005435311420	20250	Economy	4000.00
0005434408495	20250	Economy	4000.00
0005434409169	26971	Business	12000.00
0005434409182	26971	Business	12000.00
0005434409164	26971	Business	12000.00
0005434409158	26971	Business	12000.00
0005434409185	26971	Business	12000.00
0005432154098	26971	Business	12000.00
0005434409159	26971	Business	12000.00
0005434409193	26971	Business	12000.00
0005434409163	26971	Business	12000.00
0005434409179	26971	Business	12000.00
0005432154097	26971	Business	12000.00
0005434409197	26971	Economy	4000.00
0005434409215	26971	Economy	4000.00
0005434409161	26971	Economy	4000.00
0005434409209	26971	Economy	4000.00
0005435311218	26971	Economy	4000.00
0005434409188	26971	Economy	4000.00
0005434409183	26971	Economy	4000.00
0005434409180	26971	Economy	4000.00
0005434409194	26971	Economy	4400.00
0005434409199	26971	Economy	4400.00
0005434409162	26971	Economy	4400.00
0005434409173	26971	Economy	4400.00
0005434409192	26971	Economy	4000.00
0005434409190	26971	Economy	4000.00
0005434409171	26971	Economy	4000.00
0005434409217	26971	Economy	4000.00
0005434409201	26971	Economy	4000.00
0005434409203	26971	Economy	4000.00
0005435311209	26971	Economy	4000.00
0005432154094	26971	Economy	4000.00
0005434409196	26971	Economy	4000.00
0005434409207	26971	Economy	4000.00
0005434409200	26971	Economy	4000.00
0005434409202	26971	Economy	4000.00
0005434409168	26971	Economy	4000.00
0005434409220	26971	Economy	4000.00
0005434409177	26971	Economy	4000.00
0005434409167	26971	Economy	4000.00
0005434409166	26971	Economy	4000.00
0005434409195	26971	Economy	4000.00
0005435311153	26971	Economy	4000.00
0005435311203	26971	Economy	4000.00
0005434409174	26971	Economy	4000.00
0005434409216	26971	Economy	4000.00
0005432154099	26971	Economy	4000.00
0005434409172	26971	Economy	4000.00
0005434409204	26971	Economy	4000.00
0005434409178	26971	Economy	4000.00
0005434409208	26971	Economy	4000.00
0005434409198	26971	Economy	4000.00
0005434409219	26971	Economy	4000.00
0005434409212	26971	Economy	4000.00
0005434409191	26971	Economy	4000.00
0005434409165	26971	Economy	4000.00
0005434409205	26971	Economy	4000.00
0005434409184	26971	Economy	4000.00
0005435311219	26971	Economy	4000.00
0005434409181	26971	Economy	4000.00
0005434409160	26971	Economy	4000.00
0005434409189	26971	Economy	4000.00
0005434409176	26971	Economy	4000.00
0005434409214	26971	Economy	4000.00
0005432154096	26971	Economy	4000.00
0005434409218	26971	Economy	4000.00
0005434409187	26971	Economy	4000.00
0005434409175	26971	Economy	4000.00
0005435311180	26971	Economy	4000.00
0005434409170	26971	Economy	4000.00
0005432154095	26971	Economy	4000.00
0005434409211	26971	Economy	4000.00
0005434409213	26971	Economy	4000.00
0005434409206	26971	Economy	4000.00
0005435311208	26971	Economy	4000.00
0005434409210	26971	Economy	4000.00
0005434409186	26971	Economy	4000.00
0005433124167	5675	Business	43300.00
0005434319697	5675	Business	43300.00
0005434319700	5675	Business	43300.00
0005434319699	5675	Business	43300.00
0005434311265	5675	Business	43300.00
0005433124276	5675	Business	43300.00
0005433124186	5675	Economy	14400.00
0005434319693	5675	Economy	14400.00
0005433124135	5675	Economy	14400.00
0005433124185	5675	Economy	14400.00
0005433124219	5675	Economy	14400.00
0005434319709	5675	Economy	15900.00
0005433124198	5675	Economy	15900.00
0005434319706	5675	Economy	15900.00
0005434319710	5675	Economy	14400.00
0005434319698	5675	Economy	14400.00
0005432109766	5675	Economy	14400.00
0005433124229	5675	Economy	14400.00
0005434319694	5675	Economy	14400.00
0005433124277	5675	Economy	14400.00
0005434319711	5675	Economy	14400.00
0005434311264	5675	Economy	14400.00
0005434319705	5675	Economy	14400.00
0005433124197	5675	Economy	14400.00
0005434319707	5675	Economy	14400.00
0005434319712	5675	Economy	14400.00
0005433124165	5675	Economy	14400.00
0005433124257	5675	Economy	14400.00
0005433124189	5675	Economy	14400.00
0005433124099	5675	Economy	14400.00
0005434319696	5675	Economy	14400.00
0005433124176	5675	Economy	14400.00
0005434319701	5675	Economy	14400.00
0005434311266	5675	Economy	14400.00
0005434311263	5675	Economy	14400.00
0005434319702	5675	Economy	14400.00
0005434319695	5675	Economy	14400.00
0005433124256	5675	Economy	14400.00
0005433124158	5675	Economy	14400.00
0005433124101	5675	Economy	14400.00
0005434319704	5675	Economy	14400.00
0005433124209	5675	Economy	14400.00
0005433124100	5675	Economy	14400.00
0005434319703	5675	Economy	14400.00
0005434319708	5675	Economy	14400.00
0005434319591	15674	Business	43300.00
0005433124406	15674	Business	43300.00
0005434311252	15674	Business	43300.00
0005434319575	15674	Business	43300.00
0005433124402	15674	Business	43300.00
0005433124401	15674	Business	43300.00
0005433124403	15674	Economy	14400.00
0005434311251	15674	Economy	14400.00
0005433124408	15674	Economy	14400.00
0005433124392	15674	Economy	15900.00
0005434319540	15674	Economy	15900.00
0005434319592	15674	Economy	15900.00
0005433124400	15674	Economy	14400.00
0005434319563	15674	Economy	14400.00
0005433124389	15674	Economy	14400.00
0005434319599	15674	Economy	14400.00
0005433124391	15674	Economy	14400.00
0005433124404	15674	Economy	14400.00
0005433124399	15674	Economy	14400.00
0005433124394	15674	Economy	14400.00
0005433124397	15674	Economy	14400.00
0005434311253	15674	Economy	14400.00
0005433124393	15674	Economy	14400.00
0005433124395	15674	Economy	14400.00
0005434312355	15674	Economy	14400.00
0005434319603	15674	Economy	14400.00
0005433124407	15674	Economy	14400.00
0005434311250	15674	Economy	14400.00
0005434311242	15674	Economy	14400.00
0005434319587	15674	Economy	14400.00
0005433124396	15674	Economy	14400.00
0005434319541	15674	Economy	14400.00
0005434319539	15674	Economy	14400.00
0005434319611	15674	Economy	14400.00
0005434319588	15674	Economy	14400.00
0005433124411	15674	Economy	14400.00
0005433124390	15674	Economy	14400.00
0005433124409	15674	Economy	14400.00
0005434319553	15674	Economy	14400.00
0005433124410	15674	Economy	14400.00
0005433124405	15674	Economy	14400.00
0005433124398	15674	Economy	14400.00
0005434319569	15674	Economy	14400.00
0005435220511	31751	Economy	17100.00
0005435220369	31751	Economy	15500.00
0005435219250	31751	Economy	15500.00
0005435220509	31751	Economy	15500.00
0005435220367	31751	Economy	15500.00
0005435219248	31751	Economy	15500.00
0005435219249	31751	Economy	15500.00
0005435220510	31751	Economy	15500.00
0005435220512	31751	Economy	15500.00
0005435220368	31751	Economy	15500.00
0005435220366	31751	Economy	15500.00
0005435219247	31751	Economy	15500.00
0005434189275	8968	Economy	27400.00
0005434484497	8968	Economy	24900.00
0005434484494	8968	Economy	24900.00
0005434484498	8968	Economy	24900.00
0005434484499	8968	Economy	24900.00
0005434189276	8968	Economy	24900.00
0005434484500	8968	Economy	24900.00
0005434484496	8968	Economy	24900.00
0005434189270	8968	Economy	24900.00
0005434189273	8968	Economy	24900.00
0005434484495	8968	Economy	24900.00
0005434189271	8968	Economy	24900.00
0005434484455	16629	Economy	27400.00
0005434484456	16629	Economy	24900.00
0005434484412	16629	Economy	24900.00
0005434189312	16629	Economy	24900.00
0005434189308	16629	Economy	24900.00
0005434484427	16629	Economy	24900.00
0005434484411	16629	Economy	24900.00
0005434189310	16629	Economy	24900.00
0005434189307	16629	Economy	24900.00
0005434189311	16629	Economy	24900.00
0005434189309	16629	Economy	24900.00
0005434484426	16629	Economy	24900.00
0005434484454	16629	Economy	24900.00
0005433124399	7674	Business	11100.00
0005433124408	7674	Business	11100.00
0005433124405	7674	Business	11100.00
0005433124395	7674	Business	11100.00
0005433722278	7674	Economy	3700.00
0005433124406	7674	Economy	3700.00
0005433124398	7674	Economy	3700.00
0005433722277	7674	Economy	4100.00
0005433722305	7674	Economy	4100.00
0005433124397	7674	Economy	3700.00
0005433124394	7674	Economy	3700.00
0005433124402	7674	Economy	3700.00
0005433124400	7674	Economy	3700.00
0005433722291	7674	Economy	3700.00
0005433722289	7674	Economy	3700.00
0005433124392	7674	Economy	3700.00
0005433124404	7674	Economy	3700.00
0005433124410	7674	Economy	3700.00
0005433124393	7674	Economy	3700.00
0005433124390	7674	Economy	3700.00
0005433124407	7674	Economy	3700.00
0005433124389	7674	Economy	3700.00
0005433124403	7674	Economy	3700.00
0005433722304	7674	Economy	3700.00
0005433124401	7674	Economy	3700.00
0005433124409	7674	Economy	3700.00
0005433124411	7674	Economy	3700.00
0005433722293	7674	Economy	3700.00
0005433722290	7674	Economy	3700.00
0005433124396	7674	Economy	3700.00
0005433124391	7674	Economy	3700.00
0005433450461	7675	Business	11100.00
0005432721513	7675	Business	11100.00
0005433450473	7675	Business	11100.00
0005432721508	7675	Business	11100.00
0005432693783	7675	Business	11100.00
0005433450472	7675	Business	11100.00
0005433450470	7675	Business	11100.00
0005432721517	7675	Business	11100.00
0005433450471	7675	Business	11100.00
0005432693772	7675	Business	11100.00
0005432693767	7675	Business	11100.00
0005432693780	7675	Economy	3700.00
0005432071640	7675	Economy	3700.00
0005432693763	7675	Economy	3700.00
0005432721521	7675	Economy	3700.00
0005432721509	7675	Economy	3700.00
0005432721504	7675	Economy	3700.00
0005433450459	7675	Economy	3700.00
0005432721514	7675	Economy	4100.00
0005432693777	7675	Economy	4100.00
0005433450462	7675	Economy	4100.00
0005432693782	7675	Economy	4100.00
0005432721525	7675	Economy	4100.00
0005432693784	7675	Economy	3700.00
0005432721518	7675	Economy	3700.00
0005433450456	7675	Economy	3700.00
0005432693779	7675	Economy	3700.00
0005433450467	7675	Economy	3700.00
0005432721500	7675	Economy	3700.00
0005432721524	7675	Economy	3700.00
0005433450474	7675	Economy	3700.00
0005432693765	7675	Economy	3700.00
0005432721502	7675	Economy	3700.00
0005432693762	7675	Economy	3700.00
0005432721515	7675	Economy	3700.00
0005433450463	7675	Economy	3700.00
0005433450453	7675	Economy	3700.00
0005432721510	7675	Economy	3700.00
0005432693766	7675	Economy	3700.00
0005432693769	7675	Economy	3700.00
0005432721516	7675	Economy	3700.00
0005432693786	7675	Economy	3700.00
0005433450460	7675	Economy	3700.00
0005432693764	7675	Economy	3700.00
0005432721520	7675	Economy	3700.00
0005433450454	7675	Economy	3700.00
0005432693761	7675	Economy	3700.00
0005432693773	7675	Economy	3700.00
0005432693785	7675	Economy	3700.00
0005432693774	7675	Economy	3700.00
0005432693771	7675	Economy	3700.00
0005432693760	7675	Economy	3700.00
0005432071642	7675	Economy	3700.00
0005432721503	7675	Economy	3700.00
0005433450455	7675	Economy	3700.00
0005433450457	7675	Economy	3700.00
0005433450466	7675	Economy	3700.00
0005432721526	7675	Economy	3700.00
0005432693768	7675	Economy	3700.00
0005433450465	7675	Economy	3700.00
0005432693770	7675	Economy	3700.00
0005432721511	7675	Economy	3700.00
0005432721519	7675	Economy	3700.00
0005432721506	7675	Economy	3700.00
0005433450464	7675	Economy	3700.00
0005432721522	7675	Economy	3700.00
0005432693778	7675	Economy	3700.00
0005432071641	7675	Economy	3700.00
0005432721501	7675	Economy	3700.00
0005432693775	7675	Economy	3700.00
0005433450468	7675	Economy	3700.00
0005432693776	7675	Economy	3700.00
0005432721505	7675	Economy	3700.00
0005432693758	7675	Economy	3700.00
0005433450469	7675	Economy	3700.00
0005432721512	7675	Economy	3700.00
0005432721523	7675	Economy	3700.00
0005432693759	7675	Economy	3700.00
0005432721507	7675	Economy	3700.00
0005433450458	7675	Economy	3700.00
0005432693781	7675	Economy	3700.00
0005432693453	30448	Business	11100.00
0005432693428	30448	Business	11100.00
0005432693309	30448	Business	11100.00
0005432693480	30448	Business	11100.00
0005432693424	30448	Business	11100.00
0005433450242	30448	Economy	3700.00
0005432693476	30448	Economy	3700.00
0005432693375	30448	Economy	3700.00
0005433450223	30448	Economy	3700.00
0005432693386	30448	Economy	3700.00
0005432693387	30448	Economy	4100.00
0005432693502	30448	Economy	4100.00
0005433450366	30448	Economy	4100.00
0005433450352	30448	Economy	3700.00
0005432693537	30448	Economy	3700.00
0005433450365	30448	Economy	3700.00
0005432693479	30448	Economy	3700.00
0005433450304	30448	Economy	3700.00
0005433450359	30448	Economy	3700.00
0005433450353	30448	Economy	3700.00
0005433450310	30448	Economy	3700.00
0005432693503	30448	Economy	3700.00
0005432693318	30448	Economy	3700.00
0005432693550	30448	Economy	3700.00
0005433450236	30448	Economy	3700.00
0005433450155	30448	Economy	3700.00
0005432693549	30448	Economy	3700.00
0005433450333	30448	Economy	3700.00
0005433450224	30448	Economy	3700.00
0005432693317	30448	Economy	3700.00
0005433450360	30448	Economy	3700.00
0005432693392	30448	Economy	3700.00
0005433450337	30448	Economy	3700.00
0005432693395	30448	Economy	3700.00
0005432693450	30448	Economy	3700.00
0005433450336	30448	Economy	3700.00
0005433450268	30448	Economy	3700.00
0005432693372	30448	Economy	3700.00
0005432693501	30448	Economy	3700.00
0005432693536	30448	Economy	3700.00
0005432693496	30448	Economy	3700.00
0005433450243	30448	Economy	3700.00
0005433450303	30448	Economy	3700.00
0005432693452	30448	Economy	3700.00
0005433450311	30448	Economy	3700.00
0005433124198	30449	Business	11100.00
0005432721268	30449	Business	11100.00
0005433722370	30449	Business	11100.00
0005433124176	30449	Business	11100.00
0005432721308	30449	Economy	3700.00
0005433124167	30449	Economy	3700.00
0005432721289	30449	Economy	3700.00
0005432721351	30449	Economy	3700.00
0005432721293	30449	Economy	3700.00
0005433124256	30449	Economy	3700.00
0005433124165	30449	Economy	4100.00
0005432721323	30449	Economy	4100.00
0005433722366	30449	Economy	4100.00
0005433722365	30449	Economy	4100.00
0005433124276	30449	Economy	3700.00
0005432721334	30449	Economy	3700.00
0005433124185	30449	Economy	3700.00
0005432721267	30449	Economy	3700.00
0005433722368	30449	Economy	3700.00
0005432721316	30449	Economy	3700.00
0005432721352	30449	Economy	3700.00
0005433124158	30449	Economy	3700.00
0005433124229	30449	Economy	3700.00
0005432721416	30449	Economy	3700.00
0005432721417	30449	Economy	3700.00
0005432721302	30449	Economy	3700.00
0005433124186	30449	Economy	3700.00
0005433722364	30449	Economy	3700.00
0005433124135	30449	Economy	3700.00
0005433124100	30449	Economy	3700.00
0005433124197	30449	Economy	3700.00
0005433722367	30449	Economy	3700.00
0005432721321	30449	Economy	3700.00
0005433124277	30449	Economy	3700.00
0005432721312	30449	Economy	3700.00
0005433124209	30449	Economy	3700.00
0005433124189	30449	Economy	3700.00
0005433124099	30449	Economy	3700.00
0005432721339	30449	Economy	3700.00
0005432721350	30449	Economy	3700.00
0005433124257	30449	Economy	3700.00
0005433722369	30449	Economy	3700.00
0005432721392	30449	Economy	3700.00
0005432721252	30449	Economy	3700.00
0005432721208	30449	Economy	3700.00
0005432721231	30449	Economy	3700.00
0005432721345	30449	Economy	3700.00
0005432721344	30449	Economy	3700.00
0005432721320	30449	Economy	3700.00
0005433722363	30449	Economy	3700.00
0005433124101	30449	Economy	3700.00
0005433124219	30449	Economy	3700.00
0005433525289	1386	Business	70400.00
0005432928058	1386	Business	70400.00
0005434587203	1386	Business	70400.00
0005434515026	1386	Business	70400.00
0005434587188	1386	Business	70400.00
0005433525284	1386	Business	70400.00
0005434587206	1386	Business	70400.00
0005433193232	1386	Business	70400.00
0005433193242	1386	Business	70400.00
0005432928086	1386	Business	70400.00
0005433724911	1386	Business	70400.00
0005432968874	1386	Business	70400.00
0005434587202	1386	Economy	23500.00
0005433193264	1386	Economy	23500.00
0005433193254	1386	Economy	23500.00
0005433193246	1386	Economy	23500.00
0005434587190	1386	Economy	23500.00
0005434513639	1386	Economy	23500.00
0005433193184	1386	Economy	23500.00
0005433724910	1386	Economy	23500.00
0005434587185	1386	Economy	23500.00
0005433193183	1386	Economy	25800.00
0005434587205	1386	Economy	25800.00
0005433525285	1386	Economy	25800.00
0005434587198	1386	Economy	25800.00
0005434587195	1386	Economy	23500.00
0005432928057	1386	Economy	23500.00
0005433193275	1386	Economy	23500.00
0005432928062	1386	Economy	23500.00
0005434515027	1386	Economy	23500.00
0005434587194	1386	Economy	23500.00
0005434587191	1386	Economy	23500.00
0005433724913	1386	Economy	23500.00
0005432928042	1386	Economy	23500.00
0005433193229	1386	Economy	23500.00
0005433193279	1386	Economy	23500.00
0005432928075	1386	Economy	23500.00
0005432928085	1386	Economy	23500.00
0005433525288	1386	Economy	23500.00
0005433193211	1386	Economy	23500.00
0005434587192	1386	Economy	23500.00
0005433193253	1386	Economy	23500.00
0005434587197	1386	Economy	23500.00
0005433525287	1386	Economy	23500.00
0005434587200	1386	Economy	23500.00
0005433724914	1386	Economy	23500.00
0005434587187	1386	Economy	23500.00
0005434587209	1386	Economy	23500.00
0005434587199	1386	Economy	23500.00
0005434513640	1386	Economy	23500.00
0005432968873	1386	Economy	23500.00
0005434587193	1386	Economy	23500.00
0005433193241	1386	Economy	23500.00
0005433724912	1386	Economy	23500.00
0005434587208	1386	Economy	23500.00
0005433193240	1386	Economy	23500.00
0005433525286	1386	Economy	23500.00
0005433525283	1386	Economy	23500.00
0005433193233	1386	Economy	23500.00
0005433525282	1386	Economy	23500.00
0005434587204	1386	Economy	23500.00
0005433525290	1386	Economy	23500.00
0005434587189	1386	Economy	23500.00
0005434587196	1386	Economy	23500.00
0005433193277	1386	Economy	23500.00
0005434513638	1386	Economy	23500.00
0005433724909	1386	Economy	23500.00
0005434587201	1386	Economy	23500.00
0005434515028	1386	Economy	23500.00
0005432271069	1386	Economy	23500.00
0005433193276	1386	Economy	23500.00
0005433193230	1386	Economy	23500.00
0005432928061	1386	Economy	23500.00
0005434587207	1386	Economy	23500.00
0005434587186	1386	Economy	23500.00
0005432271070	1386	Economy	23500.00
0005433193252	1386	Economy	23500.00
0005434587184	1386	Economy	23500.00
0005433525281	1386	Economy	23500.00
0005432928076	1386	Economy	23500.00
0005434586941	18528	Business	70400.00
0005433193346	18528	Business	70400.00
0005433193348	18528	Business	70400.00
0005433525195	18528	Business	70400.00
0005434586994	18528	Business	70400.00
0005434587025	18528	Business	70400.00
0005432928107	18528	Business	70400.00
0005433724858	18528	Business	70400.00
0005433724869	18528	Business	70400.00
0005433193356	18528	Business	70400.00
0005433724860	18528	Economy	23500.00
0005433193352	18528	Economy	23500.00
0005433724884	18528	Economy	23500.00
0005433525160	18528	Economy	23500.00
0005434586883	18528	Economy	23500.00
0005434587012	18528	Economy	25800.00
0005433724847	18528	Economy	23500.00
0005433193354	18528	Economy	23500.00
0005434586884	18528	Economy	23500.00
0005433193345	18528	Economy	23500.00
0005432928105	18528	Economy	23500.00
0005433193350	18528	Economy	23500.00
0005433193343	18528	Economy	23500.00
0005434586942	18528	Economy	23500.00
0005433193342	18528	Economy	23500.00
0005434586939	18528	Economy	23500.00
0005432928104	18528	Economy	23500.00
0005434586957	18528	Economy	23500.00
0005434586948	18528	Economy	23500.00
0005433724874	18528	Economy	23500.00
0005433193355	18528	Economy	23500.00
0005433724859	18528	Economy	23500.00
0005434587050	18528	Economy	23500.00
0005434587011	18528	Economy	23500.00
0005433724883	18528	Economy	23500.00
0005434586982	18528	Economy	23500.00
0005433525162	18528	Economy	23500.00
0005433193344	18528	Economy	23500.00
0005433193353	18528	Economy	23500.00
0005433193349	18528	Economy	23500.00
0005434515004	18528	Economy	23500.00
0005432928108	18528	Economy	23500.00
0005434586950	18528	Economy	23500.00
0005433193347	18528	Economy	23500.00
0005432968891	18528	Economy	23500.00
0005434587051	18528	Economy	23500.00
0005432928109	18528	Economy	23500.00
0005433525161	18528	Economy	23500.00
0005434514991	18528	Economy	23500.00
0005433525196	18528	Economy	23500.00
0005432968892	18528	Economy	23500.00
0005434586940	18528	Economy	23500.00
0005432928106	18528	Economy	23500.00
0005433724833	18528	Economy	23500.00
0005433193351	18528	Economy	23500.00
0005434587038	18528	Economy	23500.00
0005434344973	11473	Economy	4300.00
0005434344971	11473	Economy	4300.00
0005434344981	11473	Economy	4300.00
0005434345003	11473	Economy	4300.00
0005434344974	11473	Economy	4000.00
0005434344996	11473	Economy	4000.00
0005434142701	11473	Economy	4000.00
0005434344968	11473	Economy	4000.00
0005435302263	11473	Economy	4000.00
0005434344983	11473	Economy	4000.00
0005434142700	11473	Economy	4000.00
0005434142703	11473	Economy	4000.00
0005434142702	11473	Economy	4000.00
0005434345000	11473	Economy	4000.00
0005434344993	11473	Economy	4000.00
0005434344986	11473	Economy	4000.00
0005434345002	11473	Economy	4000.00
0005434344967	11473	Economy	4000.00
0005435302261	11473	Economy	4000.00
0005434344976	11473	Economy	4000.00
0005434344992	11473	Economy	4000.00
0005434344998	11473	Economy	4000.00
0005435302264	11473	Economy	4000.00
0005435302228	11473	Economy	4000.00
0005434344994	11473	Economy	4000.00
0005434344988	11473	Economy	4000.00
0005434344980	11473	Economy	4000.00
0005434344975	11473	Economy	4000.00
0005434344970	11473	Economy	4000.00
0005434344990	11473	Economy	4000.00
0005434344979	11473	Economy	4000.00
0005434142699	11473	Economy	4000.00
0005434344999	11473	Economy	4000.00
0005435302262	11473	Economy	4000.00
0005434344984	11473	Economy	4000.00
0005434344995	11473	Economy	4000.00
0005434344978	11473	Economy	4000.00
0005434344972	11473	Economy	4000.00
0005434344985	11473	Economy	4000.00
0005434344969	11473	Economy	4000.00
0005434345004	11473	Economy	4000.00
0005434344977	11473	Economy	4000.00
0005434344987	11473	Economy	4000.00
0005435302227	11473	Economy	4000.00
0005434344982	11473	Economy	4000.00
0005434344991	11473	Economy	4000.00
0005435302279	11473	Economy	4000.00
0005434345001	11473	Economy	4000.00
0005434344997	11473	Economy	4000.00
0005434344989	11473	Economy	4000.00
0005434344816	29776	Economy	4300.00
0005434344737	29776	Economy	4300.00
0005434344701	29776	Economy	4300.00
0005434142663	29776	Economy	4300.00
0005434344745	29776	Economy	4000.00
0005434344621	29776	Economy	4000.00
0005434344568	29776	Economy	4000.00
0005434344623	29776	Economy	4000.00
0005434344705	29776	Economy	4000.00
0005434344610	29776	Economy	4000.00
0005434344720	29776	Economy	4000.00
0005434344797	29776	Economy	4000.00
0005434344817	29776	Economy	4000.00
0005434142662	29776	Economy	4000.00
0005434142664	29776	Economy	4000.00
0005434344782	29776	Economy	4000.00
0005434344765	29776	Economy	4000.00
0005434344558	29776	Economy	4000.00
0005434344602	29776	Economy	4000.00
0005434344738	29776	Economy	4000.00
0005434344658	29776	Economy	4000.00
0005434344839	29776	Economy	4000.00
0005434344746	29776	Economy	4000.00
0005434344569	29776	Economy	4000.00
0005434344719	29776	Economy	4000.00
0005434142672	29776	Economy	4000.00
0005434344751	29776	Economy	4000.00
0005434344702	29776	Economy	4000.00
0005434344672	29776	Economy	4000.00
0005434344766	29776	Economy	4000.00
0005434344622	29776	Economy	4000.00
0005434344703	29776	Economy	4000.00
0005434142675	29776	Economy	4000.00
0005434344688	29776	Economy	4000.00
0005434344643	29776	Economy	4000.00
0005434344757	29776	Economy	4000.00
0005434344710	29776	Economy	4000.00
0005434344652	29776	Economy	4000.00
0005434344726	29776	Economy	4000.00
0005434142649	29776	Economy	4000.00
0005434344592	29776	Economy	4000.00
0005434344704	29776	Economy	4000.00
0005434344706	29776	Economy	4000.00
0005434344559	29776	Economy	4000.00
0005434344758	29776	Economy	4000.00
0005434344709	29776	Economy	4000.00
0005434344736	29776	Economy	4000.00
0005434344725	29776	Economy	4000.00
0005434344644	29776	Economy	4000.00
0005434344774	29776	Economy	4000.00
0005435825239	1298	Business	199800.00
0005435825232	1298	Business	199800.00
0005433415977	1298	Business	199800.00
0005433415890	1298	Business	199800.00
0005435825248	1298	Business	199800.00
0005433415956	1298	Business	199800.00
0005435825229	1298	Business	199800.00
0005433415917	1298	Economy	66600.00
0005435825242	1298	Economy	66600.00
0005435825241	1298	Economy	66600.00
0005435825223	1298	Economy	66600.00
0005435825228	1298	Economy	66600.00
0005433415803	1298	Economy	66600.00
0005435825237	1298	Economy	66600.00
0005435825244	1298	Economy	66600.00
0005435825225	1298	Economy	66600.00
0005435825249	1298	Economy	66600.00
0005433415938	1298	Economy	66600.00
0005435825250	1298	Economy	66600.00
0005433415848	1298	Economy	66600.00
0005433415975	1298	Economy	66600.00
0005435825235	1298	Economy	66600.00
0005435825226	1298	Economy	66600.00
0005433415931	1298	Economy	66600.00
0005435825245	1298	Economy	66600.00
0005432284627	1298	Economy	66600.00
0005435825230	1298	Economy	66600.00
0005435825236	1298	Economy	66600.00
0005433415967	1298	Economy	66600.00
0005433415955	1298	Economy	66600.00
0005433415963	1298	Economy	66600.00
0005435825233	1298	Economy	66600.00
0005435825238	1298	Economy	66600.00
0005435825234	1298	Economy	66600.00
0005435825243	1298	Economy	66600.00
0005435825246	1298	Economy	66600.00
0005433415916	1298	Economy	66600.00
0005433415893	1298	Economy	66600.00
0005435825227	1298	Economy	66600.00
0005435825224	1298	Economy	66600.00
0005433415892	1298	Economy	66600.00
0005433415930	1298	Economy	66600.00
0005433415885	1298	Economy	66600.00
0005435825247	1298	Economy	66600.00
0005433415976	1298	Economy	66600.00
0005433415886	1298	Economy	66600.00
0005433415945	1298	Economy	66600.00
0005435825240	1298	Economy	66600.00
0005435825231	1298	Economy	66600.00
0005433415964	1298	Economy	66600.00
0005433416018	18002	Business	199800.00
0005435825020	18002	Business	199800.00
0005435825082	18002	Business	199800.00
0005435825088	18002	Business	199800.00
0005435824960	18002	Business	199800.00
0005435824951	18002	Business	199800.00
0005435825011	18002	Business	199800.00
0005435824840	18002	Business	199800.00
0005435825030	18002	Business	199800.00
0005435824943	18002	Business	199800.00
0005433416025	18002	Business	199800.00
0005433416029	18002	Economy	66600.00
0005433416023	18002	Economy	66600.00
0005435825083	18002	Economy	66600.00
0005433416026	18002	Economy	66600.00
0005435824962	18002	Economy	66600.00
0005433416028	18002	Economy	73200.00
0005435825103	18002	Economy	73200.00
0005435824871	18002	Economy	73200.00
0005435824916	18002	Economy	66600.00
0005435824893	18002	Economy	66600.00
0005433416021	18002	Economy	66600.00
0005435825036	18002	Economy	66600.00
0005433416024	18002	Economy	66600.00
0005435825031	18002	Economy	66600.00
0005435824894	18002	Economy	66600.00
0005435825051	18002	Economy	66600.00
0005435825028	18002	Economy	66600.00
0005435825057	18002	Economy	66600.00
0005435825009	18002	Economy	66600.00
0005435824993	18002	Economy	66600.00
0005435825120	18002	Economy	66600.00
0005433416014	18002	Economy	66600.00
0005435825008	18002	Economy	66600.00
0005435824841	18002	Economy	66600.00
0005433416016	18002	Economy	66600.00
0005435825001	18002	Economy	66600.00
0005433416020	18002	Economy	66600.00
0005435825021	18002	Economy	66600.00
0005435825024	18002	Economy	66600.00
0005435824981	18002	Economy	66600.00
0005433416022	18002	Economy	66600.00
0005435825033	18002	Economy	66600.00
0005435825032	18002	Economy	66600.00
0005435824963	18002	Economy	66600.00
0005433416017	18002	Economy	66600.00
0005435825063	18002	Economy	66600.00
0005435824961	18002	Economy	66600.00
0005435825042	18002	Economy	66600.00
0005435824958	18002	Economy	66600.00
0005435825084	18002	Economy	66600.00
0005435824952	18002	Economy	66600.00
0005435824959	18002	Economy	66600.00
0005433416027	18002	Economy	66600.00
0005433416019	18002	Economy	66600.00
0005435825000	18002	Economy	66600.00
0005435825052	18002	Economy	66600.00
0005435824953	18002	Economy	66600.00
0005435825007	18002	Economy	66600.00
0005435824982	18002	Economy	66600.00
0005435825029	18002	Economy	66600.00
0005435825071	18002	Economy	66600.00
0005435825023	18002	Economy	66600.00
0005433416015	18002	Economy	66600.00
0005435825056	18002	Economy	66600.00
0005435824999	18002	Economy	66600.00
0005435824992	18002	Economy	66600.00
0005432785011	5626	Business	27800.00
0005432785000	5626	Business	27800.00
0005432785028	5626	Business	27800.00
0005435243260	5626	Business	27800.00
0005432785037	5626	Business	27800.00
0005432785040	5626	Business	27800.00
0005432785016	5626	Business	27800.00
0005432785006	5626	Business	27800.00
0005435243167	5626	Business	27800.00
0005432784999	5626	Business	27800.00
0005432784995	5626	Business	27800.00
0005432785031	5626	Economy	9300.00
0005432785003	5626	Economy	9300.00
0005432784994	5626	Economy	9300.00
0005432784990	5626	Economy	9300.00
0005432784996	5626	Economy	9300.00
0005432784987	5626	Economy	9300.00
0005432785004	5626	Economy	9300.00
0005432785012	5626	Economy	9300.00
0005435243215	5626	Economy	9300.00
0005432784993	5626	Economy	9300.00
0005435243225	5626	Economy	10200.00
0005432784992	5626	Economy	10200.00
0005432144062	5626	Economy	10200.00
0005432785019	5626	Economy	10200.00
0005432785025	5626	Economy	9300.00
0005432784988	5626	Economy	10200.00
0005435243057	5626	Economy	9300.00
0005435243282	5626	Economy	9300.00
0005432785041	5626	Economy	9300.00
0005432785022	5626	Economy	9300.00
0005435243232	5626	Economy	9300.00
0005435243184	5626	Economy	9300.00
0005432785007	5626	Economy	9300.00
0005435476832	5626	Economy	9300.00
0005435243139	5626	Economy	9300.00
0005432785027	5626	Economy	9300.00
0005435243264	5626	Economy	9300.00
0005432785009	5626	Economy	9300.00
0005435476833	5626	Economy	9300.00
0005432784998	5626	Economy	9300.00
0005432785002	5626	Economy	9300.00
0005432785035	5626	Economy	9300.00
0005432785029	5626	Economy	9300.00
0005435243230	5626	Economy	9300.00
0005432785034	5626	Economy	9300.00
0005432785039	5626	Economy	9300.00
0005435243272	5626	Economy	9300.00
0005432785020	5626	Economy	9300.00
0005432785023	5626	Economy	9300.00
0005432785032	5626	Economy	9300.00
0005435243137	5626	Economy	9300.00
0005432785015	5626	Economy	9300.00
0005432144063	5626	Economy	9300.00
0005432785008	5626	Economy	9300.00
0005435243238	5626	Economy	9300.00
0005432785013	5626	Economy	9300.00
0005432785033	5626	Economy	9300.00
0005432784991	5626	Economy	9300.00
0005435243358	5626	Economy	9300.00
0005432785038	5626	Economy	9300.00
0005435243226	5626	Economy	9300.00
0005435243124	5626	Economy	9300.00
0005432785014	5626	Economy	9300.00
0005435243164	5626	Economy	9300.00
0005432784989	5626	Economy	9300.00
0005432785030	5626	Economy	9300.00
0005435476842	5626	Economy	9300.00
0005435243265	5626	Economy	9300.00
0005435243288	5626	Economy	9300.00
0005432785010	5626	Economy	9300.00
0005432144061	5626	Economy	9300.00
0005432785036	5626	Economy	9300.00
0005432785017	5626	Economy	9300.00
0005435243058	5626	Economy	9300.00
0005435243183	5626	Economy	9300.00
0005435243132	5626	Economy	9300.00
0005432785026	5626	Economy	9300.00
0005435243257	5626	Economy	9300.00
0005432785001	5626	Economy	9300.00
0005435243085	5626	Economy	9300.00
0005435476843	5626	Economy	9300.00
0005432785005	5626	Economy	9300.00
0005432785021	5626	Economy	9300.00
0005435243229	5626	Economy	9300.00
0005432785024	5626	Economy	9300.00
0005435243233	5626	Economy	9300.00
0005432785018	5626	Economy	9300.00
0005432784997	5626	Economy	9300.00
0005435243138	5626	Economy	9300.00
0005435243123	5626	Economy	9300.00
0005432784578	15371	Business	27800.00
0005432784733	15371	Business	27800.00
0005435243434	15371	Business	27800.00
0005435243447	15371	Business	27800.00
0005435476923	15371	Business	27800.00
0005432784388	15371	Business	27800.00
0005432784706	15371	Business	27800.00
0005432784126	15371	Business	27800.00
0005432784792	15371	Business	27800.00
0005435243437	15371	Business	27800.00
0005435243436	15371	Business	27800.00
0005432784331	15371	Business	27800.00
0005432784381	15371	Economy	9300.00
0005435243448	15371	Economy	9300.00
0005432784592	15371	Economy	9300.00
0005432784561	15371	Economy	9300.00
0005432784568	15371	Economy	9300.00
0005435243445	15371	Economy	9300.00
0005432784542	15371	Economy	9300.00
0005432784421	15371	Economy	9300.00
0005432784442	15371	Economy	9300.00
0005435476926	15371	Economy	9300.00
0005435243450	15371	Economy	10200.00
0005432784275	15371	Economy	10200.00
0005432784560	15371	Economy	10200.00
0005435243440	15371	Economy	10200.00
0005432784444	15371	Economy	10200.00
0005435243431	15371	Economy	9300.00
0005432784387	15371	Economy	9300.00
0005432784402	15371	Economy	9300.00
0005432784420	15371	Economy	9300.00
0005432784539	15371	Economy	9300.00
0005435243433	15371	Economy	9300.00
0005435476921	15371	Economy	9300.00
0005432784579	15371	Economy	9300.00
0005435243428	15371	Economy	9300.00
0005432784296	15371	Economy	9300.00
0005432784646	15371	Economy	9300.00
0005435243441	15371	Economy	9300.00
0005432784569	15371	Economy	9300.00
0005432784386	15371	Economy	9300.00
0005432784543	15371	Economy	9300.00
0005432784116	15371	Economy	9300.00
0005432784428	15371	Economy	9300.00
0005432784639	15371	Economy	9300.00
0005432784495	15371	Economy	9300.00
0005432784575	15371	Economy	9300.00
0005435243452	15371	Economy	9300.00
0005432784692	15371	Economy	9300.00
0005432784403	15371	Economy	9300.00
0005432784466	15371	Economy	9300.00
0005432784504	15371	Economy	9300.00
0005432784297	15371	Economy	9300.00
0005435476925	15371	Economy	9300.00
0005432784563	15371	Economy	9300.00
0005435243455	15371	Economy	9300.00
0005435476922	15371	Economy	9300.00
0005432784574	15371	Economy	9300.00
0005432784663	15371	Economy	9300.00
0005432784422	15371	Economy	9300.00
0005432784545	15371	Economy	9300.00
0005432784546	15371	Economy	9300.00
0005435243439	15371	Economy	9300.00
0005432784432	15371	Economy	9300.00
0005435243430	15371	Economy	9300.00
0005432784570	15371	Economy	9300.00
0005435243454	15371	Economy	9300.00
0005432784564	15371	Economy	9300.00
0005432784419	15371	Economy	9300.00
0005432784641	15371	Economy	9300.00
0005435243444	15371	Economy	9300.00
0005435243435	15371	Economy	9300.00
0005432784295	15371	Economy	9300.00
0005432784562	15371	Economy	9300.00
0005435243451	15371	Economy	9300.00
0005432784640	15371	Economy	9300.00
0005435243442	15371	Economy	9300.00
0005435243429	15371	Economy	9300.00
0005435243443	15371	Economy	9300.00
0005432784380	15371	Economy	9300.00
0005432784505	15371	Economy	9300.00
0005432784721	15371	Economy	9300.00
0005435243432	15371	Economy	9300.00
0005432784551	15371	Economy	9300.00
0005432784413	15371	Economy	9300.00
0005432784441	15371	Economy	9300.00
0005432784487	15371	Economy	9300.00
0005435243446	15371	Economy	9300.00
0005432784720	15371	Economy	9300.00
0005432784591	15371	Economy	9300.00
0005435243438	15371	Economy	9300.00
0005435243453	15371	Economy	9300.00
0005435243449	15371	Economy	9300.00
0005432784691	15371	Economy	9300.00
0005432784701	15371	Economy	9300.00
0005435476924	15371	Economy	9300.00
0005434463978	4379	Economy	7000.00
0005432848638	4379	Economy	7000.00
0005432848637	4379	Economy	6300.00
0005432848648	4379	Economy	6300.00
0005435851093	4379	Economy	6300.00
0005432848641	4379	Economy	6300.00
0005435851110	4379	Economy	6300.00
0005435851058	4379	Economy	6300.00
0005432848646	4379	Economy	6300.00
0005435851051	4379	Economy	6300.00
0005432848640	4379	Economy	6300.00
0005435851038	4379	Economy	6300.00
0005432848642	4379	Economy	6300.00
0005435851092	4379	Economy	6300.00
0005432848634	4379	Economy	6300.00
0005432848635	4379	Economy	6300.00
0005432848639	4379	Economy	6300.00
0005435851111	4379	Economy	6300.00
0005432848644	4379	Economy	6300.00
0005435851046	4379	Economy	6300.00
0005432848643	4379	Economy	6300.00
0005432848645	4379	Economy	6300.00
0005432848636	4379	Economy	6300.00
0005434463977	4379	Economy	6300.00
0005432848647	4379	Economy	6300.00
0005434462839	4379	Economy	6300.00
0005435851067	4379	Economy	6300.00
0005434463979	4379	Economy	6300.00
0005435851068	4379	Economy	6300.00
0005432848556	28891	Economy	7000.00
0005432848501	28891	Economy	7000.00
0005432848427	28891	Economy	7000.00
0005432848460	28891	Economy	6300.00
0005434461673	28891	Economy	6300.00
0005435851120	28891	Economy	6300.00
0005432848499	28891	Economy	6300.00
0005432848524	28891	Economy	6300.00
0005435851114	28891	Economy	6300.00
0005432848517	28891	Economy	6300.00
0005432848553	28891	Economy	6300.00
0005432848518	28891	Economy	6300.00
0005432848557	28891	Economy	6300.00
0005432848523	28891	Economy	6300.00
0005434461680	28891	Economy	6300.00
0005434461679	28891	Economy	6300.00
0005432848552	28891	Economy	6300.00
0005432848541	28891	Economy	6300.00
0005432848583	28891	Economy	6300.00
0005434461672	28891	Economy	6300.00
0005432848554	28891	Economy	6300.00
0005435851117	28891	Economy	6300.00
0005435851118	28891	Economy	6300.00
0005432848461	28891	Economy	6300.00
0005432848538	28891	Economy	6300.00
0005435851119	28891	Economy	6300.00
0005435851121	28891	Economy	6300.00
0005432848426	28891	Economy	6300.00
0005435851115	28891	Economy	6300.00
0005435851113	28891	Economy	6300.00
0005432848510	28891	Economy	6300.00
0005435851116	28891	Economy	6300.00
0005432848500	28891	Economy	6300.00
0005432848537	28891	Economy	6300.00
0005433497693	6332	Business	11900.00
0005433497680	6332	Business	11900.00
0005432075309	6332	Business	11900.00
0005434926530	6332	Business	11900.00
0005434926543	6332	Business	11900.00
0005434926545	6332	Business	11900.00
0005434926537	6332	Business	11900.00
0005434926541	6332	Business	11900.00
0005433497670	6332	Business	11900.00
0005434926527	6332	Business	11900.00
0005434926550	6332	Business	11900.00
0005432075308	6332	Economy	4000.00
0005434444083	6332	Economy	4000.00
0005434444072	6332	Economy	4000.00
0005434444078	6332	Economy	4000.00
0005433497688	6332	Economy	4000.00
0005433497675	6332	Economy	4000.00
0005434926546	6332	Economy	4000.00
0005434444073	6332	Economy	4000.00
0005434444075	6332	Economy	4000.00
0005433497687	6332	Economy	4000.00
0005434926533	6332	Economy	4400.00
0005433497684	6332	Economy	4400.00
0005433497677	6332	Economy	4400.00
0005434444074	6332	Economy	4400.00
0005434926536	6332	Economy	4400.00
0005434444076	6332	Economy	4000.00
0005434444084	6332	Economy	4000.00
0005434926538	6332	Economy	4000.00
0005434926521	6332	Economy	4000.00
0005434926511	6332	Economy	4000.00
0005434444079	6332	Economy	4000.00
0005434926523	6332	Economy	4000.00
0005433497669	6332	Economy	4000.00
0005434444081	6332	Economy	4000.00
0005433497665	6332	Economy	4000.00
0005434926547	6332	Economy	4000.00
0005433497691	6332	Economy	4000.00
0005434926513	6332	Economy	4000.00
0005433497673	6332	Economy	4000.00
0005434926531	6332	Economy	4000.00
0005434444070	6332	Economy	4000.00
0005433497679	6332	Economy	4000.00
0005434444077	6332	Economy	4000.00
0005433497674	6332	Economy	4000.00
0005433497686	6332	Economy	4000.00
0005434926526	6332	Economy	4000.00
0005433497678	6332	Economy	4000.00
0005434926540	6332	Economy	4000.00
0005434926514	6332	Economy	4000.00
0005434926529	6332	Economy	4000.00
0005433497682	6332	Economy	4000.00
0005434926518	6332	Economy	4000.00
0005433497668	6332	Economy	4000.00
0005434926517	6332	Economy	4000.00
0005434926539	6332	Economy	4000.00
0005433497696	6332	Economy	4000.00
0005432075310	6332	Economy	4000.00
0005433497692	6332	Economy	4000.00
0005434926549	6332	Economy	4000.00
0005434926524	6332	Economy	4000.00
0005434444069	6332	Economy	4000.00
0005432075307	6332	Economy	4000.00
0005434926532	6332	Economy	4000.00
0005433497683	6332	Economy	4000.00
0005434926512	6332	Economy	4000.00
0005433497666	6332	Economy	4000.00
0005433497681	6332	Economy	4000.00
0005434926544	6332	Economy	4000.00
0005434926525	6332	Economy	4000.00
0005434926542	6332	Economy	4000.00
0005434926534	6332	Economy	4000.00
0005434926519	6332	Economy	4000.00
0005434926528	6332	Economy	4000.00
0005433497676	6332	Economy	4000.00
0005434926535	6332	Economy	4000.00
0005433497695	6332	Economy	4000.00
0005433497667	6332	Economy	4000.00
0005434926520	6332	Economy	4000.00
0005434926515	6332	Economy	4000.00
0005434926522	6332	Economy	4000.00
0005433497694	6332	Economy	4000.00
0005434444071	6332	Economy	4000.00
0005433497689	6332	Economy	4000.00
0005434444080	6332	Economy	4000.00
0005433497671	6332	Economy	4000.00
0005434926510	6332	Economy	4000.00
0005434926548	6332	Economy	4000.00
0005434444082	6332	Economy	4000.00
0005434926516	6332	Economy	4000.00
0005433497672	6332	Economy	4000.00
0005433497685	6332	Economy	4000.00
0005433497690	6332	Economy	4000.00
0005435257443	20360	Business	11900.00
0005435257439	20360	Business	11900.00
0005435257442	20360	Business	11900.00
0005435257446	20360	Economy	4000.00
0005435257444	20360	Economy	4000.00
0005435257445	20360	Economy	4000.00
0005435257440	20360	Economy	4000.00
0005435257441	20360	Economy	4000.00
0005435257438	20360	Economy	4000.00
0005435257437	20360	Economy	4000.00
0005434926000	20318	Business	11900.00
0005433497408	20318	Business	11900.00
0005433497298	20318	Business	11900.00
0005433497546	20318	Business	11900.00
0005434926215	20318	Business	11900.00
0005433497515	20318	Business	11900.00
0005434443903	20318	Business	11900.00
0005433497388	20318	Business	11900.00
0005434443889	20318	Economy	4000.00
0005433497407	20318	Economy	4000.00
0005433497534	20318	Economy	4000.00
0005434443949	20318	Economy	4000.00
0005434926248	20318	Economy	4400.00
0005433497283	20318	Economy	4400.00
0005434926292	20318	Economy	4400.00
0005434926329	20318	Economy	4400.00
0005433497397	20318	Economy	4000.00
0005434926152	20318	Economy	4000.00
0005434926327	20318	Economy	4000.00
0005434443933	20318	Economy	4000.00
0005433497438	20318	Economy	4000.00
0005434926103	20318	Economy	4000.00
0005434926214	20318	Economy	4000.00
0005434926206	20318	Economy	4000.00
0005433497431	20318	Economy	4000.00
0005433497421	20318	Economy	4000.00
0005434926366	20318	Economy	4000.00
0005433497387	20318	Economy	4000.00
0005434926272	20318	Economy	4000.00
0005434926230	20318	Economy	4000.00
0005434443983	20318	Economy	4000.00
0005433497361	20318	Economy	4000.00
0005434926104	20318	Economy	4000.00
0005433497420	20318	Economy	4000.00
0005434926172	20318	Economy	4000.00
0005434443904	20318	Economy	4000.00
0005433497439	20318	Economy	4000.00
0005434926173	20318	Economy	4000.00
0005434443918	20318	Economy	4000.00
0005433497402	20318	Economy	4000.00
0005434926171	20318	Economy	4000.00
0005434926229	20318	Economy	4000.00
0005434926216	20318	Economy	4000.00
0005433497464	20318	Economy	4000.00
0005434926293	20318	Economy	4000.00
0005433497449	20318	Economy	4000.00
0005433497516	20318	Economy	4000.00
0005434926283	20318	Economy	4000.00
0005433497467	20318	Economy	4000.00
0005434926269	20318	Economy	4000.00
0005434926268	20318	Economy	4000.00
0005434926249	20318	Economy	4000.00
0005434443805	20318	Economy	4000.00
0005434926203	20318	Economy	4000.00
0005433497533	20318	Economy	4000.00
0005434926108	20318	Economy	4000.00
0005434926193	20318	Economy	4000.00
0005433497450	20318	Economy	4000.00
0005433497401	20318	Economy	4000.00
0005434443948	20318	Economy	4000.00
0005433497430	20318	Economy	4000.00
0005433497472	20318	Economy	4000.00
0005433497664	20318	Economy	4000.00
0005434443953	20318	Economy	4000.00
0005434926284	20318	Economy	4000.00
0005433497400	20318	Economy	4000.00
0005434443888	20318	Economy	4000.00
0005435243471	12179	Business	41200.00
0005435243470	12179	Business	41200.00
0005435243466	12179	Business	41200.00
0005432784445	12179	Business	41200.00
0005435243482	12179	Business	41200.00
0005432784486	12179	Business	41200.00
0005435243475	12179	Business	41200.00
0005432784529	12179	Business	41200.00
0005432784764	12179	Business	41200.00
0005435243479	12179	Business	41200.00
0005432784763	12179	Business	41200.00
0005432784647	12179	Economy	13700.00
0005432784334	12179	Economy	13700.00
0005432784651	12179	Economy	13700.00
0005432784606	12179	Economy	13700.00
0005435243456	12179	Economy	13700.00
0005432784326	12179	Economy	13700.00
0005432784530	12179	Economy	13700.00
0005435243469	12179	Economy	13700.00
0005432784406	12179	Economy	13700.00
0005432784621	12179	Economy	15100.00
0005432784652	12179	Economy	15100.00
0005432784484	12179	Economy	15100.00
0005435243472	12179	Economy	15100.00
0005432784765	12179	Economy	13700.00
0005435243458	12179	Economy	13700.00
0005432784605	12179	Economy	13700.00
0005432784808	12179	Economy	13700.00
0005435243468	12179	Economy	13700.00
0005432784335	12179	Economy	13700.00
0005432784474	12179	Economy	13700.00
0005432784465	12179	Economy	13700.00
0005435243464	12179	Economy	13700.00
0005432784643	12179	Economy	13700.00
0005435243477	12179	Economy	13700.00
0005432784553	12179	Economy	13700.00
0005432784558	12179	Economy	13700.00
0005435243465	12179	Economy	13700.00
0005435243462	12179	Economy	13700.00
0005435243467	12179	Economy	13700.00
0005432784649	12179	Economy	13700.00
0005432784684	12179	Economy	13700.00
0005435243461	12179	Economy	13700.00
0005432784464	12179	Economy	13700.00
0005432784457	12179	Economy	13700.00
0005432784554	12179	Economy	13700.00
0005432784607	12179	Economy	13700.00
0005432784608	12179	Economy	13700.00
0005432784622	12179	Economy	13700.00
0005432784803	12179	Economy	13700.00
0005432784555	12179	Economy	13700.00
0005432784648	12179	Economy	13700.00
0005435243457	12179	Economy	13700.00
0005432784851	12179	Economy	13700.00
0005432784679	12179	Economy	13700.00
0005432784458	12179	Economy	13700.00
0005432784456	12179	Economy	13700.00
0005432784460	12179	Economy	13700.00
0005435243463	12179	Economy	13700.00
0005432784533	12179	Economy	13700.00
0005435243460	12179	Economy	13700.00
0005432784713	12179	Economy	13700.00
0005432784485	12179	Economy	13700.00
0005432784528	12179	Economy	13700.00
0005432784534	12179	Economy	13700.00
0005432784527	12179	Economy	13700.00
0005435243459	12179	Economy	13700.00
0005432784333	12179	Economy	13700.00
0005432784680	12179	Economy	13700.00
0005435243476	12179	Economy	13700.00
0005432784552	12179	Economy	13700.00
0005435243481	12179	Economy	13700.00
0005435243483	12179	Economy	13700.00
0005432784642	12179	Economy	13700.00
0005432784580	12179	Economy	13700.00
0005432784535	12179	Economy	13700.00
0005432784817	12179	Economy	13700.00
0005432784516	12179	Economy	13700.00
0005432784653	12179	Economy	13700.00
0005435243473	12179	Economy	13700.00
0005435243480	12179	Economy	13700.00
0005435243474	12179	Economy	13700.00
0005432784459	12179	Economy	13700.00
0005435243478	12179	Economy	13700.00
0005432784408	12179	Economy	13700.00
0005432784941	15455	Business	41200.00
0005432784953	15455	Business	41200.00
0005435243069	15455	Business	41200.00
0005432784939	15455	Business	41200.00
0005435243208	15455	Business	41200.00
0005432784986	15455	Business	41200.00
0005432784964	15455	Business	41200.00
0005432784977	15455	Business	41200.00
0005432784969	15455	Economy	13700.00
0005432784976	15455	Economy	13700.00
0005432784942	15455	Economy	13700.00
0005435243186	15455	Economy	13700.00
0005435243154	15455	Economy	13700.00
0005432784932	15455	Economy	13700.00
0005432784960	15455	Economy	15100.00
0005435243134	15455	Economy	15100.00
0005432784966	15455	Economy	15100.00
0005435243214	15455	Economy	15100.00
0005432784973	15455	Economy	13700.00
0005432784954	15455	Economy	13700.00
0005435243207	15455	Economy	13700.00
0005432784958	15455	Economy	13700.00
0005432784940	15455	Economy	13700.00
0005432784983	15455	Economy	13700.00
0005432784974	15455	Economy	13700.00
0005435243127	15455	Economy	13700.00
0005432784985	15455	Economy	13700.00
0005432784982	15455	Economy	13700.00
0005432784957	15455	Economy	13700.00
0005432784980	15455	Economy	13700.00
0005435243107	15455	Economy	13700.00
0005432784978	15455	Economy	13700.00
0005435243166	15455	Economy	13700.00
0005432784936	15455	Economy	13700.00
0005432784934	15455	Economy	13700.00
0005432784959	15455	Economy	13700.00
0005435243155	15455	Economy	13700.00
0005432784972	15455	Economy	13700.00
0005432784944	15455	Economy	13700.00
0005435243173	15455	Economy	13700.00
0005432784943	15455	Economy	13700.00
0005432784948	15455	Economy	13700.00
0005432784975	15455	Economy	13700.00
0005432784935	15455	Economy	13700.00
0005432784933	15455	Economy	13700.00
0005435243175	15455	Economy	13700.00
0005432784947	15455	Economy	13700.00
0005435243129	15455	Economy	13700.00
0005432784937	15455	Economy	13700.00
0005432784949	15455	Economy	13700.00
0005432784984	15455	Economy	13700.00
0005432784952	15455	Economy	13700.00
0005432784979	15455	Economy	13700.00
0005435243128	15455	Economy	13700.00
0005432784962	15455	Economy	13700.00
0005435243234	15455	Economy	13700.00
0005435243185	15455	Economy	13700.00
0005432784968	15455	Economy	13700.00
0005435243176	15455	Economy	13700.00
0005432784955	15455	Economy	13700.00
0005432784951	15455	Economy	13700.00
0005435243193	15455	Economy	13700.00
0005432784981	15455	Economy	13700.00
0005432784963	15455	Economy	13700.00
0005432784961	15455	Economy	13700.00
0005432784965	15455	Economy	13700.00
0005432784970	15455	Economy	13700.00
0005432784971	15455	Economy	13700.00
0005432784967	15455	Economy	13700.00
0005432784956	15455	Economy	13700.00
0005432784938	15455	Economy	13700.00
0005435243149	15455	Economy	13700.00
0005435243205	15455	Economy	13700.00
0005432784945	15455	Economy	13700.00
0005432784946	15455	Economy	13700.00
0005432784950	15455	Economy	13700.00
0005435914046	10093	Business	49700.00
0005434879422	10093	Business	49700.00
0005434879721	10093	Business	49700.00
0005434879260	10093	Business	49700.00
0005434879629	10093	Business	49700.00
0005434879879	10093	Business	49700.00
0005434879913	10093	Business	49700.00
0005434910163	10093	Business	49700.00
0005434879275	10093	Business	49700.00
0005434879753	10093	Business	49700.00
0005434879533	10093	Business	49700.00
0005434879693	10093	Business	49700.00
0005434879752	10093	Business	49700.00
0005434879445	10093	Business	49700.00
0005434879523	10093	Business	49700.00
0005434879113	10093	Business	49700.00
0005434879671	10093	Business	49700.00
0005434879891	10093	Business	49700.00
0005434879670	10093	Business	49700.00
0005434879590	10093	Business	49700.00
0005434879719	10093	Economy	16600.00
0005434879621	10093	Economy	16600.00
0005434879660	10093	Economy	16600.00
0005434879954	10093	Economy	16600.00
0005434879478	10093	Economy	16600.00
0005434879178	10093	Economy	16600.00
0005434879376	10093	Economy	16600.00
0005434879604	10093	Economy	16600.00
0005434879765	10093	Economy	16600.00
0005434879526	10093	Economy	16600.00
0005434879630	10093	Economy	16600.00
0005434879419	10093	Economy	16600.00
0005434879515	10093	Economy	16600.00
0005434879692	10093	Economy	18200.00
0005434879527	10093	Economy	18200.00
0005434879536	10093	Economy	18200.00
0005434879238	10093	Economy	16600.00
0005434879822	10093	Economy	18200.00
0005434879420	10093	Economy	16600.00
0005434879308	10093	Economy	16600.00
0005435914044	10093	Economy	16600.00
0005434879549	10093	Economy	16600.00
0005434879596	10093	Economy	16600.00
0005434879375	10093	Economy	16600.00
0005434879717	10093	Economy	16600.00
0005434910165	10093	Economy	16600.00
0005434879669	10093	Economy	16600.00
0005434879483	10093	Economy	16600.00
0005434879372	10093	Economy	16600.00
0005434879330	10093	Economy	16600.00
0005434879447	10093	Economy	16600.00
0005434879591	10093	Economy	16600.00
0005434879524	10093	Economy	16600.00
0005434879784	10093	Economy	16600.00
0005434879237	10093	Economy	16600.00
0005434879446	10093	Economy	16600.00
0005434879616	10093	Economy	16600.00
0005434879914	10093	Economy	16600.00
0005434879708	10093	Economy	16600.00
0005434879631	10093	Economy	16600.00
0005434879892	10093	Economy	16600.00
0005434879252	10093	Economy	16600.00
0005434879987	10093	Economy	16600.00
0005434879218	10093	Economy	16600.00
0005434879437	10093	Economy	16600.00
0005434879620	10093	Economy	16600.00
0005434879643	10093	Economy	16600.00
0005435914045	10093	Economy	16600.00
0005434879741	10093	Economy	16600.00
0005434880000	10093	Economy	16600.00
0005434910164	10093	Economy	16600.00
0005434878986	10093	Economy	16600.00
0005434879532	10093	Economy	16600.00
0005434880014	10093	Economy	16600.00
0005435914042	10093	Economy	16600.00
0005434879525	10093	Economy	16600.00
0005434880013	10093	Economy	16600.00
0005434879571	10093	Economy	16600.00
0005434879789	10093	Economy	16600.00
0005434879464	10093	Economy	16600.00
0005434879316	10093	Economy	16600.00
0005434879534	10093	Economy	16600.00
0005434879552	10093	Economy	16600.00
0005434879635	10093	Economy	16600.00
0005434879274	10093	Economy	16600.00
0005434879528	10093	Economy	16600.00
0005434879299	10093	Economy	16600.00
0005434879593	10093	Economy	16600.00
0005434879551	10093	Economy	16600.00
0005434879543	10093	Economy	16600.00
0005434879522	10093	Economy	16600.00
0005434879823	10093	Economy	16600.00
0005434879623	10093	Economy	16600.00
0005434879356	10093	Economy	16600.00
0005434879729	10093	Economy	16600.00
0005434879516	10093	Economy	16600.00
0005434879531	10093	Economy	16600.00
0005434879484	10093	Economy	16600.00
0005434879553	10093	Economy	16600.00
0005434879809	10093	Economy	16600.00
0005434880043	10093	Economy	16600.00
0005434879730	10093	Economy	16600.00
0005434879514	10093	Economy	16600.00
0005434879854	10093	Economy	16600.00
0005435914043	10093	Economy	16600.00
0005434879718	10093	Economy	16600.00
0005434879853	10093	Economy	16600.00
0005434879615	10093	Economy	16600.00
0005434879405	10093	Economy	16600.00
0005434879267	10093	Economy	16600.00
0005434879377	10093	Economy	16600.00
0005434879731	10093	Economy	16600.00
0005434879999	10093	Economy	16600.00
0005434879477	10093	Economy	16600.00
0005434879691	10093	Economy	16600.00
0005434879307	10093	Economy	16600.00
0005434880377	14652	Business	49700.00
0005434880351	14652	Business	49700.00
0005434910142	14652	Business	49700.00
0005434880328	14652	Business	49700.00
0005434880383	14652	Business	49700.00
0005434880347	14652	Business	49700.00
0005434880374	14652	Business	49700.00
0005434910147	14652	Business	49700.00
0005434880367	14652	Business	49700.00
0005434880316	14652	Business	49700.00
0005434880386	14652	Business	49700.00
0005434880329	14652	Business	49700.00
0005434880365	14652	Business	49700.00
0005434880387	14652	Business	49700.00
0005434880372	14652	Business	49700.00
0005434880344	14652	Business	49700.00
0005434880322	14652	Business	49700.00
0005434880373	14652	Economy	16600.00
0005434880327	14652	Economy	16600.00
0005435913978	14652	Economy	16600.00
0005434880338	14652	Economy	16600.00
0005434880361	14652	Economy	16600.00
0005434880310	14652	Economy	16600.00
0005434758946	14652	Economy	16600.00
0005434880312	14652	Economy	16600.00
0005434880379	14652	Economy	16600.00
0005434880315	14652	Economy	16600.00
0005434880311	14652	Economy	16600.00
0005435913970	14652	Economy	16600.00
0005434880391	14652	Economy	18200.00
0005434880381	14652	Economy	18200.00
0005434880401	14652	Economy	18200.00
0005434880350	14652	Economy	16600.00
0005434880314	14652	Economy	16600.00
0005434880380	14652	Economy	16600.00
0005434880346	14652	Economy	16600.00
0005434880388	14652	Economy	16600.00
0005434880325	14652	Economy	16600.00
0005434880313	14652	Economy	16600.00
0005434880326	14652	Economy	16600.00
0005434880330	14652	Economy	16600.00
0005434880345	14652	Economy	16600.00
0005434880336	14652	Economy	16600.00
0005434880375	14652	Economy	16600.00
0005434880382	14652	Economy	16600.00
0005434880358	14652	Economy	16600.00
0005434880385	14652	Economy	16600.00
0005434880340	14652	Economy	16600.00
0005434880355	14652	Economy	16600.00
0005434880384	14652	Economy	16600.00
0005434880323	14652	Economy	16600.00
0005434880353	14652	Economy	16600.00
0005434880402	14652	Economy	16600.00
0005434880363	14652	Economy	16600.00
0005434880343	14652	Economy	16600.00
0005434880320	14652	Economy	16600.00
0005434880357	14652	Economy	16600.00
0005434880369	14652	Economy	16600.00
0005434880370	14652	Economy	16600.00
0005434880399	14652	Economy	16600.00
0005434910143	14652	Economy	16600.00
0005434880362	14652	Economy	16600.00
0005434880324	14652	Economy	16600.00
0005434880341	14652	Economy	16600.00
0005434880342	14652	Economy	16600.00
0005434880360	14652	Economy	16600.00
0005434880359	14652	Economy	16600.00
0005434880393	14652	Economy	16600.00
0005434880397	14652	Economy	16600.00
0005434880394	14652	Economy	16600.00
0005434880339	14652	Economy	16600.00
0005434880331	14652	Economy	16600.00
0005434880371	14652	Economy	16600.00
0005434880321	14652	Economy	16600.00
0005434880376	14652	Economy	16600.00
0005434880396	14652	Economy	16600.00
0005434880366	14652	Economy	16600.00
0005434880333	14652	Economy	16600.00
0005434880390	14652	Economy	16600.00
0005434910150	14652	Economy	16600.00
0005434758947	14652	Economy	16600.00
0005434880356	14652	Economy	16600.00
0005434910141	14652	Economy	16600.00
0005434880348	14652	Economy	16600.00
0005434880335	14652	Economy	16600.00
0005434880400	14652	Economy	16600.00
0005434880389	14652	Economy	16600.00
0005434880395	14652	Economy	16600.00
0005434880368	14652	Economy	16600.00
0005434880319	14652	Economy	16600.00
0005434880378	14652	Economy	16600.00
0005434880352	14652	Economy	16600.00
0005434758945	14652	Economy	16600.00
0005434880337	14652	Economy	16600.00
0005434880354	14652	Economy	16600.00
0005434880403	14652	Economy	16600.00
0005434880334	14652	Economy	16600.00
0005434880398	14652	Economy	16600.00
0005434880404	14652	Economy	16600.00
0005434880392	14652	Economy	16600.00
0005434880317	14652	Economy	16600.00
0005434880364	14652	Economy	16600.00
0005434880349	14652	Economy	16600.00
0005434880318	14652	Economy	16600.00
0005434880332	14652	Economy	16600.00
0005434252072	9208	Economy	22400.00
0005434252122	9208	Economy	22400.00
0005435660391	9208	Economy	20300.00
0005435660390	9208	Economy	20300.00
0005434252099	9208	Economy	20300.00
0005434252104	9208	Economy	20300.00
0005435660392	9208	Economy	20300.00
0005435660395	9208	Economy	20300.00
0005435660388	9208	Economy	20300.00
0005434252071	9208	Economy	20300.00
0005435660386	9208	Economy	20300.00
0005435660389	9208	Economy	20300.00
0005435660396	9208	Economy	20300.00
0005434252096	9208	Economy	20300.00
0005434252113	9208	Economy	20300.00
0005434252114	9208	Economy	20300.00
0005434252105	9208	Economy	20300.00
0005434252091	9208	Economy	20300.00
0005435660393	9208	Economy	20300.00
0005434252092	9208	Economy	20300.00
0005435660394	9208	Economy	20300.00
0005435660387	9208	Economy	20300.00
0005435660299	24643	Economy	22400.00
0005435660301	24643	Economy	20300.00
0005435660307	24643	Economy	20300.00
0005435660283	24643	Economy	20300.00
0005434252178	24643	Economy	20300.00
0005434252176	24643	Economy	20300.00
0005435660272	24643	Economy	20300.00
0005435660306	24643	Economy	20300.00
0005435660308	24643	Economy	20300.00
0005434252175	24643	Economy	20300.00
0005434252181	24643	Economy	20300.00
0005435660290	24643	Economy	20300.00
0005434252183	24643	Economy	20300.00
0005434252177	24643	Economy	20300.00
0005435660242	24643	Economy	20300.00
0005434252180	24643	Economy	20300.00
0005435660305	24643	Economy	20300.00
0005435660326	24643	Economy	20300.00
0005435660325	24643	Economy	20300.00
0005435660258	24643	Economy	20300.00
0005435660285	24643	Economy	20300.00
0005435660281	24643	Economy	20300.00
0005435660337	24643	Economy	20300.00
0005434252179	24643	Economy	20300.00
0005435660259	24643	Economy	20300.00
0005435660300	24643	Economy	20300.00
0005434252182	24643	Economy	20300.00
0005435660257	24643	Economy	20300.00
0005433681656	2824	Business	33000.00
0005433681623	2824	Business	33000.00
0005432967305	2824	Business	33000.00
0005433681630	2824	Business	33000.00
0005433681619	2824	Business	33000.00
0005432222903	2824	Business	33000.00
0005433681650	2824	Business	33000.00
0005433681629	2824	Business	33000.00
0005432967313	2824	Business	33000.00
0005432967181	2824	Economy	11000.00
0005433681631	2824	Economy	11000.00
0005433681649	2824	Economy	11000.00
0005432967342	2824	Economy	11000.00
0005432967219	2824	Economy	11000.00
0005432222902	2824	Economy	11000.00
0005432967160	2824	Economy	11000.00
0005433681660	2824	Economy	11000.00
0005433681659	2824	Economy	11000.00
0005433681651	2824	Economy	12100.00
0005432967308	2824	Economy	12100.00
0005432967314	2824	Economy	12100.00
0005433681645	2824	Economy	11000.00
0005433681637	2824	Economy	11000.00
0005432222900	2824	Economy	11000.00
0005433681661	2824	Economy	11000.00
0005433681636	2824	Economy	11000.00
0005432967220	2824	Economy	11000.00
0005433681653	2824	Economy	11000.00
0005433681652	2824	Economy	11000.00
0005432967298	2824	Economy	11000.00
0005432222901	2824	Economy	11000.00
0005433681654	2824	Economy	11000.00
0005433681643	2824	Economy	11000.00
0005433681614	2824	Economy	11000.00
0005433684466	2824	Economy	11000.00
0005433681644	2824	Economy	11000.00
0005432967320	2824	Economy	11000.00
0005433681658	2824	Economy	11000.00
0005433681625	2824	Economy	11000.00
0005433681657	2824	Economy	11000.00
0005433681639	2824	Economy	11000.00
0005433681638	2824	Economy	11000.00
0005433681642	2824	Economy	11000.00
0005433681634	2824	Economy	11000.00
0005432967159	2824	Economy	11000.00
0005433681613	2824	Economy	11000.00
0005432222899	2824	Economy	11000.00
0005432967253	2824	Economy	11000.00
0005433681621	2824	Economy	11000.00
0005432967304	2824	Economy	11000.00
0005433681647	2824	Economy	11000.00
0005433681622	2824	Economy	11000.00
0005433681626	2824	Economy	11000.00
0005432967205	2824	Economy	11000.00
0005433681640	2824	Economy	11000.00
0005433681633	2824	Economy	11000.00
0005433681616	2824	Economy	11000.00
0005433681655	2824	Economy	11000.00
0005432967182	2824	Economy	11000.00
0005432967243	2824	Economy	11000.00
0005433681617	2824	Economy	11000.00
0005433681635	2824	Economy	11000.00
0005433681627	2824	Economy	11000.00
0005433681615	2824	Economy	11000.00
0005433681646	2824	Economy	11000.00
0005433681632	2824	Economy	11000.00
0005433681618	2824	Economy	11000.00
0005432967244	2824	Economy	11000.00
0005432967319	2824	Economy	11000.00
0005433681641	2824	Economy	11000.00
0005432967297	2824	Economy	11000.00
0005433681620	2824	Economy	11000.00
0005433681648	2824	Economy	11000.00
0005433681624	2824	Economy	11000.00
0005433681628	2824	Economy	11000.00
0005432967409	2824	Economy	11000.00
0005433681237	29139	Business	33000.00
0005432967521	29139	Business	33000.00
0005433681337	29139	Business	33000.00
0005433681173	29139	Business	33000.00
0005433681228	29139	Business	33000.00
0005432967499	29139	Business	33000.00
0005433681191	29139	Business	33000.00
0005433681357	29139	Business	33000.00
0005432967514	29139	Business	33000.00
0005433690951	29139	Business	33000.00
0005433681248	29139	Business	33000.00
0005432967518	29139	Business	33000.00
0005432967516	29139	Economy	11000.00
0005433681238	29139	Economy	11000.00
0005432967510	29139	Economy	11000.00
0005433681417	29139	Economy	11000.00
0005433681094	29139	Economy	11000.00
0005433681093	29139	Economy	11000.00
0005432967511	29139	Economy	11000.00
0005432967500	29139	Economy	12100.00
0005433681221	29139	Economy	12100.00
0005432967508	29139	Economy	12100.00
0005433681419	29139	Economy	12100.00
0005432967519	29139	Economy	11000.00
0005433681333	29139	Economy	11000.00
0005433681230	29139	Economy	11000.00
0005432967505	29139	Economy	11000.00
0005433681336	29139	Economy	11000.00
0005433681307	29139	Economy	11000.00
0005433684449	29139	Economy	11000.00
0005432967520	29139	Economy	11000.00
0005433681464	29139	Economy	11000.00
0005433681222	29139	Economy	11000.00
0005433690947	29139	Economy	11000.00
0005432967522	29139	Economy	11000.00
0005433684448	29139	Economy	11000.00
0005432967501	29139	Economy	11000.00
0005433681353	29139	Economy	11000.00
0005433681019	29139	Economy	11000.00
0005433681319	29139	Economy	11000.00
0005432967524	29139	Economy	11000.00
0005433681296	29139	Economy	11000.00
0005432005276	29139	Economy	11000.00
0005433681279	29139	Economy	11000.00
0005433681192	29139	Economy	11000.00
0005433687746	29139	Economy	11000.00
0005432967509	29139	Economy	11000.00
0005432967504	29139	Economy	11000.00
0005432005277	29139	Economy	11000.00
0005433681020	29139	Economy	11000.00
0005433681397	29139	Economy	11000.00
0005433684457	29139	Economy	11000.00
0005432967498	29139	Economy	11000.00
0005432967512	29139	Economy	11000.00
0005432967506	29139	Economy	11000.00
0005433681356	29139	Economy	11000.00
0005433681236	29139	Economy	11000.00
0005432967502	29139	Economy	11000.00
0005432967515	29139	Economy	11000.00
0005433681225	29139	Economy	11000.00
0005433681201	29139	Economy	11000.00
0005433681083	29139	Economy	11000.00
0005432005278	29139	Economy	11000.00
0005433681406	29139	Economy	11000.00
0005433681511	29139	Economy	11000.00
0005433681326	29139	Economy	11000.00
0005433681392	29139	Economy	11000.00
0005433681260	29139	Economy	11000.00
0005432967513	29139	Economy	11000.00
0005433681042	29139	Economy	11000.00
0005432967523	29139	Economy	11000.00
0005433681288	29139	Economy	11000.00
0005433681065	29139	Economy	11000.00
0005433681370	29139	Economy	11000.00
0005432967503	29139	Economy	11000.00
0005433681176	29139	Economy	11000.00
0005432967507	29139	Economy	11000.00
0005433681174	29139	Economy	11000.00
0005432967517	29139	Economy	11000.00
0005433681448	29139	Economy	11000.00
0005433681285	29139	Economy	11000.00
0005433681334	29139	Economy	11000.00
0005433681200	29139	Economy	11000.00
0005433681308	29139	Economy	11000.00
0005433681410	29139	Economy	11000.00
0005433681405	29139	Economy	11000.00
0005433616246	9302	Business	132900.00
0005433616251	9302	Business	132900.00
0005433634565	9302	Business	132900.00
0005433634557	9302	Business	132900.00
0005433616283	9302	Business	132900.00
0005433616232	9302	Business	132900.00
0005434153549	9302	Business	132900.00
0005434269131	9302	Business	132900.00
0005433616259	9302	Business	132900.00
0005433616236	9302	Business	132900.00
0005433634560	9302	Business	132900.00
0005433634541	9302	Business	132900.00
0005433634570	9302	Business	132900.00
0005433634551	9302	Business	132900.00
0005434163759	9302	Business	132900.00
0005433616247	9302	Business	132900.00
0005433634542	9302	Business	132900.00
0005434163780	9302	Business	132900.00
0005432756921	9302	Business	132900.00
0005433616281	9302	Business	132900.00
0005433578111	9302	Business	132900.00
0005433634569	9302	Business	132900.00
0005434163761	9302	Business	132900.00
0005433616291	9302	Business	132900.00
0005433616253	9302	Business	132900.00
0005433578108	9302	Business	132900.00
0005433616255	9302	Business	132900.00
0005433616261	9302	Economy	48700.00
0005434163772	9302	Economy	48700.00
0005433634559	9302	Economy	48700.00
0005434272211	9302	Economy	48700.00
0005433634573	9302	Economy	48700.00
0005434163726	9302	Economy	48700.00
0005434163754	9302	Economy	44300.00
0005433616267	9302	Economy	44300.00
0005433616263	9302	Economy	44300.00
0005433616244	9302	Economy	44300.00
0005433578109	9302	Economy	44300.00
0005433616292	9302	Economy	44300.00
0005433616290	9302	Economy	44300.00
0005432755152	9302	Economy	44300.00
0005433616243	9302	Economy	44300.00
0005433616297	9302	Economy	44300.00
0005433616287	9302	Economy	44300.00
0005433634543	9302	Economy	44300.00
0005433634553	9302	Economy	44300.00
0005434163768	9302	Economy	44300.00
0005433634549	9302	Economy	44300.00
0005434163755	9302	Economy	44300.00
0005433578113	9302	Economy	44300.00
0005433616279	9302	Economy	44300.00
0005432756922	9302	Economy	44300.00
0005433578105	9302	Economy	44300.00
0005433634552	9302	Economy	44300.00
0005433616272	9302	Economy	44300.00
0005433634554	9302	Economy	44300.00
0005433616237	9302	Economy	44300.00
0005433634556	9302	Economy	44300.00
0005433634544	9302	Economy	44300.00
0005434152803	9302	Economy	44300.00
0005432755148	9302	Economy	44300.00
0005433634550	9302	Economy	44300.00
0005433616258	9302	Economy	44300.00
0005433578107	9302	Economy	44300.00
0005433616254	9302	Economy	44300.00
0005433616248	9302	Economy	44300.00
0005433634566	9302	Economy	44300.00
0005433616296	9302	Economy	44300.00
0005433634540	9302	Economy	44300.00
0005433616265	9302	Economy	44300.00
0005433616262	9302	Economy	44300.00
0005434163760	9302	Economy	44300.00
0005434163776	9302	Economy	44300.00
0005433616286	9302	Economy	44300.00
0005433616303	9302	Economy	44300.00
0005433616301	9302	Economy	44300.00
0005433616285	9302	Economy	44300.00
0005433634558	9302	Economy	44300.00
0005433634539	9302	Economy	44300.00
0005433578117	9302	Economy	44300.00
0005432755153	9302	Economy	44300.00
0005433616242	9302	Economy	44300.00
0005433634545	9302	Economy	44300.00
0005433616299	9302	Economy	48700.00
0005433616270	9302	Economy	48700.00
0005433616269	9302	Economy	48700.00
0005433616240	9302	Economy	48700.00
0005433578112	9302	Economy	44300.00
0005433616288	9302	Economy	44300.00
0005434163723	9302	Economy	44300.00
0005433616295	9302	Economy	48700.00
0005433616239	9302	Economy	44300.00
0005433616294	9302	Economy	44300.00
0005432756923	9302	Economy	44300.00
0005433616273	9302	Economy	44300.00
0005432755150	9302	Economy	44300.00
0005433616233	9302	Economy	44300.00
0005433578119	9302	Economy	44300.00
0005434272212	9302	Economy	44300.00
0005433616289	9302	Economy	44300.00
0005433578118	9302	Economy	44300.00
0005433616249	9302	Economy	44300.00
0005434269140	9302	Economy	44300.00
0005432755151	9302	Economy	44300.00
0005433616266	9302	Economy	44300.00
0005433616300	9302	Economy	44300.00
0005433634546	9302	Economy	44300.00
0005433616250	9302	Economy	44300.00
0005433616238	9302	Economy	44300.00
0005433616280	9302	Economy	44300.00
0005433616241	9302	Economy	44300.00
0005433616284	9302	Economy	44300.00
0005433616234	9302	Economy	44300.00
0005433634568	9302	Economy	44300.00
0005432145156	9302	Economy	44300.00
0005433634548	9302	Economy	44300.00
0005433634567	9302	Economy	44300.00
0005433616304	9302	Economy	44300.00
0005433578116	9302	Economy	44300.00
0005433616278	9302	Economy	44300.00
0005433616298	9302	Economy	44300.00
0005433634562	9302	Economy	44300.00
0005433616256	9302	Economy	44300.00
0005432755149	9302	Economy	44300.00
0005433616260	9302	Economy	44300.00
0005433616293	9302	Economy	44300.00
0005433616264	9302	Economy	44300.00
0005433616245	9302	Economy	44300.00
0005434153552	9302	Economy	44300.00
0005433578115	9302	Economy	44300.00
0005433616275	9302	Economy	44300.00
0005433634564	9302	Economy	44300.00
0005433616277	9302	Economy	44300.00
0005433634572	9302	Economy	44300.00
0005433634563	9302	Economy	44300.00
0005433634561	9302	Economy	44300.00
0005434153553	9302	Economy	44300.00
0005433616231	9302	Economy	44300.00
0005434163725	9302	Economy	44300.00
0005433578114	9302	Economy	44300.00
0005433634555	9302	Economy	44300.00
0005433616276	9302	Economy	44300.00
0005433616274	9302	Economy	44300.00
0005433616235	9302	Economy	44300.00
0005433616252	9302	Economy	44300.00
0005433634547	9302	Economy	44300.00
0005433634571	9302	Economy	44300.00
0005433578110	9302	Economy	44300.00
0005433578106	9302	Economy	44300.00
0005433616257	9302	Economy	44300.00
0005433616271	9302	Economy	44300.00
0005433616282	9302	Economy	44300.00
0005433616302	9302	Economy	44300.00
0005433616268	9302	Economy	44300.00
0005433615825	25231	Business	132900.00
0005433615657	25231	Business	132900.00
0005434163818	25231	Business	132900.00
0005433615588	25231	Business	132900.00
0005433615767	25231	Business	132900.00
0005433634220	25231	Business	132900.00
0005433615894	25231	Business	132900.00
0005433634339	25231	Business	132900.00
0005433577927	25231	Business	132900.00
0005433634209	25231	Business	132900.00
0005434272222	25231	Business	132900.00
0005434273110	25231	Business	132900.00
0005433615700	25231	Business	132900.00
0005434163813	25231	Business	132900.00
0005434272221	25231	Business	132900.00
0005433634211	25231	Business	132900.00
0005433634320	25231	Business	132900.00
0005433615418	25231	Business	132900.00
0005433578019	25231	Business	132900.00
0005433578004	25231	Business	132900.00
0005433615483	25231	Business	132900.00
0005433634292	25231	Business	132900.00
0005433634334	25231	Business	132900.00
0005433615695	25231	Economy	48700.00
0005433615303	25231	Economy	48700.00
0005434163809	25231	Economy	48700.00
0005433615549	25231	Economy	48700.00
0005433634208	25231	Economy	48700.00
0005433615621	25231	Economy	44300.00
0005434163810	25231	Economy	44300.00
0005433615680	25231	Economy	44300.00
0005433634306	25231	Economy	44300.00
0005433615632	25231	Economy	44300.00
0005434163817	25231	Economy	44300.00
0005433615729	25231	Economy	44300.00
0005433615369	25231	Economy	44300.00
0005433634314	25231	Economy	44300.00
0005433615517	25231	Economy	44300.00
0005433615789	25231	Economy	44300.00
0005433577953	25231	Economy	44300.00
0005433615638	25231	Economy	44300.00
0005433615370	25231	Economy	44300.00
0005433634248	25231	Economy	44300.00
0005434163819	25231	Economy	44300.00
0005433634399	25231	Economy	44300.00
0005433634244	25231	Economy	44300.00
0005433615569	25231	Economy	44300.00
0005433634293	25231	Economy	44300.00
0005433615848	25231	Economy	44300.00
0005433634393	25231	Economy	44300.00
0005433634118	25231	Economy	44300.00
0005433615449	25231	Economy	44300.00
0005433615514	25231	Economy	44300.00
0005433615404	25231	Economy	44300.00
0005433615432	25231	Economy	44300.00
0005434163815	25231	Economy	44300.00
0005433615784	25231	Economy	44300.00
0005433615836	25231	Economy	44300.00
0005433615685	25231	Economy	44300.00
0005433634333	25231	Economy	44300.00
0005433615635	25231	Economy	44300.00
0005433615698	25231	Economy	44300.00
0005433615911	25231	Economy	44300.00
0005433634263	25231	Economy	44300.00
0005433615783	25231	Economy	44300.00
0005433615586	25231	Economy	44300.00
0005433615496	25231	Economy	44300.00
0005433615738	25231	Economy	44300.00
0005433615737	25231	Economy	44300.00
0005433615433	25231	Economy	44300.00
0005433634225	25231	Economy	44300.00
0005433615893	25231	Economy	44300.00
0005433615982	25231	Economy	44300.00
0005433578047	25231	Economy	44300.00
0005433615468	25231	Economy	44300.00
0005433615564	25231	Economy	44300.00
0005433615855	25231	Economy	44300.00
0005433615699	25231	Economy	44300.00
0005433634338	25231	Economy	44300.00
0005433615815	25231	Economy	44300.00
0005433577952	25231	Economy	44300.00
0005433634262	25231	Economy	44300.00
0005433615457	25231	Economy	44300.00
0005434163814	25231	Economy	44300.00
0005434163816	25231	Economy	44300.00
0005433615736	25231	Economy	48700.00
0005433615674	25231	Economy	48700.00
0005433634243	25231	Economy	48700.00
0005433615679	25231	Economy	48700.00
0005433615356	25231	Economy	48700.00
0005433615668	25231	Economy	44300.00
0005433615501	25231	Economy	44300.00
0005433634141	25231	Economy	44300.00
0005433615515	25231	Economy	44300.00
0005433615476	25231	Economy	48700.00
0005433615681	25231	Economy	44300.00
0005433615719	25231	Economy	44300.00
0005434273109	25231	Economy	44300.00
0005433615541	25231	Economy	44300.00
0005433634449	25231	Economy	44300.00
0005433578075	25231	Economy	44300.00
0005433634421	25231	Economy	44300.00
0005433615768	25231	Economy	44300.00
0005433615838	25231	Economy	44300.00
0005433634277	25231	Economy	44300.00
0005433615379	25231	Economy	44300.00
0005433634201	25231	Economy	44300.00
0005433615560	25231	Economy	44300.00
0005433615735	25231	Economy	44300.00
0005433634227	25231	Economy	44300.00
0005433615550	25231	Economy	44300.00
0005433615350	25231	Economy	44300.00
0005433634207	25231	Economy	44300.00
0005433634159	25231	Economy	44300.00
0005433615456	25231	Economy	44300.00
0005433615648	25231	Economy	44300.00
0005433615559	25231	Economy	44300.00
0005433577926	25231	Economy	44300.00
0005433577963	25231	Economy	44300.00
0005433615684	25231	Economy	44300.00
0005433578010	25231	Economy	44300.00
0005434163811	25231	Economy	44300.00
0005433634398	25231	Economy	44300.00
0005433615660	25231	Economy	44300.00
0005433615516	25231	Economy	44300.00
0005433615429	25231	Economy	44300.00
0005433615675	25231	Economy	44300.00
0005433615622	25231	Economy	44300.00
0005433577951	25231	Economy	44300.00
0005433615837	25231	Economy	44300.00
0005433577936	25231	Economy	44300.00
0005433615816	25231	Economy	44300.00
0005433634158	25231	Economy	44300.00
0005433615565	25231	Economy	44300.00
0005433615639	25231	Economy	44300.00
0005433634117	25231	Economy	44300.00
0005433615467	25231	Economy	44300.00
0005433615712	25231	Economy	44300.00
0005433615518	25231	Economy	44300.00
0005433634307	25231	Economy	44300.00
0005433634216	25231	Economy	44300.00
0005433615617	25231	Economy	44300.00
0005433634381	25231	Economy	44300.00
0005434272223	25231	Economy	44300.00
0005433634176	25231	Economy	44300.00
0005434163812	25231	Economy	44300.00
0005433615448	25231	Economy	44300.00
0005433634215	25231	Economy	44300.00
0005433615656	25231	Economy	44300.00
0005433634202	25231	Economy	44300.00
0005433615748	25231	Economy	44300.00
0005433615380	25231	Economy	44300.00
0005433634205	25231	Economy	44300.00
0005433615743	25231	Economy	44300.00
0005433634234	25231	Economy	44300.00
0005433615587	25231	Economy	44300.00
0005433577935	25231	Economy	44300.00
0005435986927	4203	Business	193100.00
0005435986930	4203	Business	193100.00
0005435986928	4203	Business	193100.00
0005435947405	4203	Business	193100.00
0005435947451	4203	Business	193100.00
0005432571379	4203	Business	193100.00
0005435856273	4203	Business	193100.00
0005435854073	4203	Economy	70800.00
0005435947455	4203	Economy	64400.00
0005435787372	4203	Economy	64400.00
0005435947437	4203	Economy	64400.00
0005435947546	4203	Economy	64400.00
0005435854072	4203	Economy	64400.00
0005435947474	4203	Economy	64400.00
0005432571376	4203	Economy	64400.00
0005432185016	4203	Economy	64400.00
0005435947436	4203	Economy	64400.00
0005435986929	4203	Economy	64400.00
0005435856261	4203	Economy	64400.00
0005435947429	4203	Economy	64400.00
0005435947477	4203	Economy	64400.00
0005435947412	4203	Economy	70800.00
0005435787374	4203	Economy	64400.00
0005432571383	4203	Economy	64400.00
0005435787373	4203	Economy	64400.00
0005432571382	4203	Economy	64400.00
0005434271335	4203	Economy	64400.00
0005435947414	4203	Economy	64400.00
0005432571377	4203	Economy	64400.00
0005435947423	4203	Economy	64400.00
0005435947456	4203	Economy	64400.00
0005435947444	4203	Economy	64400.00
0005435856299	26590	Business	193100.00
0005435947579	26590	Business	193100.00
0005432571411	26590	Business	193100.00
0005432571409	26590	Business	193100.00
0005435947589	26590	Economy	64400.00
0005435986877	26590	Economy	64400.00
0005432571408	26590	Economy	64400.00
0005435947592	26590	Economy	64400.00
0005435986852	26590	Economy	64400.00
0005435947591	26590	Economy	64400.00
0005435947578	26590	Economy	64400.00
0005435986837	26590	Economy	64400.00
0005435947581	26590	Economy	64400.00
0005435947585	26590	Economy	64400.00
0005435986845	26590	Economy	64400.00
0005435986876	26590	Economy	64400.00
0005435986878	26590	Economy	64400.00
0005435856301	26590	Economy	64400.00
0005435856303	26590	Economy	64400.00
0005435856298	26590	Economy	64400.00
0005435947583	26590	Economy	64400.00
0005435787403	26590	Economy	64400.00
0005435947582	26590	Economy	64400.00
0005435947588	26590	Economy	64400.00
0005435856336	26590	Economy	64400.00
0005435947580	26590	Economy	64400.00
0005435947587	26590	Economy	64400.00
0005432571410	26590	Economy	64400.00
0005435986846	26590	Economy	64400.00
0005435947586	26590	Economy	64400.00
0005435986857	26590	Economy	64400.00
0005435856300	26590	Economy	64400.00
0005435986803	26590	Economy	64400.00
0005435947584	26590	Economy	64400.00
0005435856302	26590	Economy	64400.00
0005435986839	26590	Economy	64400.00
0005435856335	26590	Economy	64400.00
0005435986858	26590	Economy	64400.00
0005435947590	26590	Economy	64400.00
0005433075145	359	Business	21500.00
0005432949022	359	Business	21500.00
0005433570441	359	Business	21500.00
0005433570489	359	Business	21500.00
0005432949108	359	Business	21500.00
0005433570498	359	Business	21500.00
0005432949098	359	Business	21500.00
0005433570494	359	Business	21500.00
0005433075059	359	Business	21500.00
0005432949036	359	Business	21500.00
0005432948953	359	Business	21500.00
0005433570476	359	Business	21500.00
0005433570452	359	Business	21500.00
0005433570436	359	Business	21500.00
0005433075192	359	Business	21500.00
0005433075104	359	Business	21500.00
0005433074973	359	Business	21500.00
0005433570456	359	Business	21500.00
0005433570433	359	Business	21500.00
0005433570461	359	Business	21500.00
0005432948854	359	Business	21500.00
0005433570488	359	Business	21500.00
0005432949076	359	Business	21500.00
0005433074937	359	Business	21500.00
0005432239078	359	Business	21500.00
0005433570444	359	Business	21500.00
0005433570440	359	Business	21500.00
0005433570493	359	Economy	7900.00
0005433075080	359	Economy	7900.00
0005433570478	359	Economy	7900.00
0005433570459	359	Economy	7900.00
0005433075076	359	Economy	7900.00
0005432949086	359	Economy	7200.00
0005432948975	359	Economy	7900.00
0005433129359	359	Economy	7200.00
0005432948853	359	Economy	7200.00
0005432949029	359	Economy	7200.00
0005433075014	359	Economy	7200.00
0005433570474	359	Economy	7200.00
0005432949087	359	Economy	7200.00
0005432239077	359	Economy	7200.00
0005433075191	359	Economy	7200.00
0005433570481	359	Economy	7200.00
0005433570462	359	Economy	7200.00
0005433570464	359	Economy	7200.00
0005433570486	359	Economy	7200.00
0005433570458	359	Economy	7200.00
0005433074936	359	Economy	7200.00
0005432948978	359	Economy	7200.00
0005433570463	359	Economy	7200.00
0005433075119	359	Economy	7200.00
0005433570479	359	Economy	7200.00
0005433129351	359	Economy	7200.00
0005432948858	359	Economy	7200.00
0005433075163	359	Economy	7200.00
0005433570448	359	Economy	7200.00
0005433075077	359	Economy	7200.00
0005433570468	359	Economy	7200.00
0005433570451	359	Economy	7200.00
0005433570471	359	Economy	7200.00
0005433570484	359	Economy	7200.00
0005433570497	359	Economy	7200.00
0005433570491	359	Economy	7200.00
0005433570460	359	Economy	7200.00
0005433570467	359	Economy	7200.00
0005433570432	359	Economy	7200.00
0005433075050	359	Economy	7200.00
0005432239074	359	Economy	7200.00
0005433570477	359	Economy	7200.00
0005432949039	359	Economy	7200.00
0005433570431	359	Economy	7200.00
0005433570455	359	Economy	7200.00
0005433075118	359	Economy	7200.00
0005432948827	359	Economy	7200.00
0005433075057	359	Economy	7200.00
0005433570445	359	Economy	7200.00
0005433570439	359	Economy	7200.00
0005432949144	359	Economy	7200.00
0005433570482	359	Economy	7200.00
0005433570492	359	Economy	7200.00
0005433075051	359	Economy	7200.00
0005433570437	359	Economy	7200.00
0005432948963	359	Economy	7200.00
0005432948962	359	Economy	7200.00
0005432239076	359	Economy	7200.00
0005433570466	359	Economy	7200.00
0005432949099	359	Economy	7200.00
0005433129339	359	Economy	7200.00
0005433075032	359	Economy	7900.00
0005433570480	359	Economy	7900.00
0005433075047	359	Economy	7900.00
0005433075214	359	Economy	7900.00
0005432949028	359	Economy	7900.00
0005433570446	359	Economy	7200.00
0005432949096	359	Economy	7200.00
0005432949046	359	Economy	7900.00
0005433075075	359	Economy	7200.00
0005433075222	359	Economy	7200.00
0005433134193	359	Economy	7200.00
0005433570457	359	Economy	7200.00
0005433570496	359	Economy	7200.00
0005432948954	359	Economy	7200.00
0005433075138	359	Economy	7200.00
0005433570465	359	Economy	7200.00
0005432949030	359	Economy	7200.00
0005432949122	359	Economy	7200.00
0005433570483	359	Economy	7200.00
0005433570430	359	Economy	7200.00
0005433075124	359	Economy	7200.00
0005433129360	359	Economy	7200.00
0005432948904	359	Economy	7200.00
0005432949193	359	Economy	7200.00
0005433075049	359	Economy	7200.00
0005433570473	359	Economy	7200.00
0005433570469	359	Economy	7200.00
0005433570454	359	Economy	7200.00
0005433075078	359	Economy	7200.00
0005433134192	359	Economy	7200.00
0005432949190	359	Economy	7200.00
0005433570434	359	Economy	7200.00
0005433075127	359	Economy	7200.00
0005433075048	359	Economy	7200.00
0005432949027	359	Economy	7200.00
0005433570447	359	Economy	7200.00
0005433129361	359	Economy	7200.00
0005433570450	359	Economy	7200.00
0005432239075	359	Economy	7200.00
0005432948998	359	Economy	7200.00
0005433570435	359	Economy	7200.00
0005433570442	359	Economy	7200.00
0005433570490	359	Economy	7200.00
0005433129350	359	Economy	7200.00
0005433075164	359	Economy	7200.00
0005433570443	359	Economy	7200.00
0005432948852	359	Economy	7200.00
0005432949145	359	Economy	7200.00
0005433570453	359	Economy	7200.00
0005433129354	359	Economy	7200.00
0005433129340	359	Economy	7200.00
0005433129353	359	Economy	7200.00
0005432948859	359	Economy	7200.00
0005433570472	359	Economy	7200.00
0005433075212	359	Economy	7200.00
0005433570449	359	Economy	7200.00
0005433570487	359	Economy	7200.00
0005433074972	359	Economy	7200.00
0005433075155	359	Economy	7200.00
0005433570495	359	Economy	7200.00
0005433075079	359	Economy	7200.00
0005433570438	359	Economy	7200.00
0005433570475	359	Economy	7200.00
0005433570470	359	Economy	7200.00
0005433570485	359	Economy	7200.00
0005433075000	359	Economy	7200.00
0005432949021	359	Economy	7200.00
0005432949044	359	Economy	7200.00
0005432948964	359	Economy	7200.00
0005433569803	11568	Business	21500.00
0005432949378	11568	Business	21500.00
0005432949382	11568	Business	21500.00
0005433569747	11568	Business	21500.00
0005432949372	11568	Business	21500.00
0005433569549	11568	Business	21500.00
0005432949374	11568	Business	21500.00
0005433569689	11568	Business	21500.00
0005432949387	11568	Business	21500.00
0005432949384	11568	Business	21500.00
0005433569839	11568	Business	21500.00
0005432949375	11568	Business	21500.00
0005433131811	11568	Business	21500.00
0005432949385	11568	Business	21500.00
0005433075346	11568	Business	21500.00
0005432192392	11568	Business	21500.00
0005432949352	11568	Business	21500.00
0005433569588	11568	Business	21500.00
0005432949383	11568	Business	21500.00
0005433075340	11568	Business	21500.00
0005432949363	11568	Business	21500.00
0005433569848	11568	Business	21500.00
0005433569774	11568	Business	21500.00
0005433569768	11568	Economy	7900.00
0005433569766	11568	Business	21500.00
0005433569496	11568	Economy	7900.00
0005433569700	11568	Economy	7900.00
0005433134241	11568	Economy	7900.00
0005433075337	11568	Economy	7900.00
0005433075352	11568	Economy	7900.00
0005432949367	11568	Economy	7200.00
0005433569875	11568	Economy	7200.00
0005432949389	11568	Economy	7200.00
0005432949359	11568	Economy	7200.00
0005433075342	11568	Economy	7200.00
0005433569687	11568	Economy	7200.00
0005433569802	11568	Economy	7200.00
0005432949351	11568	Economy	7200.00
0005432949371	11568	Economy	7200.00
0005432949388	11568	Economy	7200.00
0005433569816	11568	Economy	7200.00
0005433075341	11568	Economy	7200.00
0005433075356	11568	Economy	7200.00
0005433075338	11568	Economy	7200.00
0005433569817	11568	Economy	7200.00
0005433569840	11568	Economy	7200.00
0005432949370	11568	Economy	7200.00
0005433134240	11568	Economy	7200.00
0005433075357	11568	Economy	7200.00
0005432192390	11568	Economy	7200.00
0005433569822	11568	Economy	7200.00
0005433569748	11568	Economy	7200.00
0005433075347	11568	Economy	7200.00
0005433569744	11568	Economy	7200.00
0005433075334	11568	Economy	7200.00
0005432949369	11568	Economy	7200.00
0005432949358	11568	Economy	7200.00
0005432192391	11568	Economy	7200.00
0005433569517	11568	Economy	7200.00
0005432949355	11568	Economy	7200.00
0005433075353	11568	Economy	7200.00
0005433075359	11568	Economy	7200.00
0005433075361	11568	Economy	7200.00
0005433569863	11568	Economy	7200.00
0005433569849	11568	Economy	7200.00
0005432949380	11568	Economy	7200.00
0005433131810	11568	Economy	7200.00
0005433075362	11568	Economy	7200.00
0005433075348	11568	Economy	7200.00
0005433131814	11568	Economy	7200.00
0005432949373	11568	Economy	7200.00
0005433569732	11568	Economy	7200.00
0005432949366	11568	Economy	7200.00
0005433075351	11568	Economy	7200.00
0005432949357	11568	Economy	7200.00
0005433134244	11568	Economy	7200.00
0005433569677	11568	Economy	7200.00
0005432949379	11568	Economy	7200.00
0005433569591	11568	Economy	7200.00
0005433569874	11568	Economy	7200.00
0005433569814	11568	Economy	7200.00
0005432949350	11568	Economy	7200.00
0005433569686	11568	Economy	7900.00
0005433569662	11568	Economy	7900.00
0005433075354	11568	Economy	7900.00
0005433569731	11568	Economy	7200.00
0005433569888	11568	Economy	7200.00
0005433569711	11568	Economy	7200.00
0005433075344	11568	Economy	7200.00
0005433569770	11568	Economy	7200.00
0005433569704	11568	Economy	7200.00
0005433569879	11568	Economy	7200.00
0005433075349	11568	Economy	7200.00
0005433569703	11568	Economy	7200.00
0005432949356	11568	Economy	7200.00
0005432949368	11568	Economy	7200.00
0005433569523	11568	Economy	7200.00
0005433569745	11568	Economy	7200.00
0005432949365	11568	Economy	7200.00
0005433134242	11568	Economy	7200.00
0005432949360	11568	Economy	7200.00
0005433134243	11568	Economy	7200.00
0005433569715	11568	Economy	7200.00
0005432949381	11568	Economy	7200.00
0005433569592	11568	Economy	7200.00
0005433569630	11568	Economy	7200.00
0005433569679	11568	Economy	7200.00
0005432949364	11568	Economy	7200.00
0005432949377	11568	Economy	7200.00
0005433569733	11568	Economy	7200.00
0005432949361	11568	Economy	7200.00
0005433569587	11568	Economy	7200.00
0005433569602	11568	Economy	7200.00
0005433075358	11568	Economy	7200.00
0005433075345	11568	Economy	7200.00
0005433569838	11568	Economy	7200.00
0005433075343	11568	Economy	7200.00
0005433569497	11568	Economy	7200.00
0005432949376	11568	Economy	7200.00
0005433569730	11568	Economy	7200.00
0005433075336	11568	Economy	7200.00
0005433075355	11568	Economy	7200.00
0005433075350	11568	Economy	7200.00
0005433569688	11568	Economy	7200.00
0005432949353	11568	Economy	7200.00
0005433134239	11568	Economy	7200.00
0005432949362	11568	Economy	7200.00
0005433131813	11568	Economy	7200.00
0005432949386	11568	Economy	7200.00
0005433569489	11568	Economy	7200.00
0005433569590	11568	Economy	7200.00
0005433131809	11568	Economy	7200.00
0005433569828	11568	Economy	7200.00
0005433569698	11568	Economy	7200.00
0005433075339	11568	Economy	7200.00
0005433569769	11568	Economy	7200.00
0005433075335	11568	Economy	7200.00
0005433569701	11568	Economy	7200.00
0005433075333	11568	Economy	7200.00
0005432949354	11568	Economy	7200.00
0005433131812	11568	Economy	7200.00
0005433075360	11568	Economy	7200.00
0005433569804	11568	Economy	7200.00
0005432949349	11568	Economy	7200.00
0005434733042	9952	Economy	6300.00
0005434733038	9952	Economy	6300.00
0005433817555	9952	Economy	6300.00
0005434733045	9952	Economy	6300.00
0005433817556	9952	Economy	6300.00
0005434733034	9952	Economy	6300.00
0005433817557	9952	Economy	6300.00
0005434733029	9952	Economy	6300.00
0005434733044	9952	Economy	6300.00
0005433817554	9952	Economy	6300.00
0005434733063	13899	Economy	6300.00
0005434733064	13899	Economy	6300.00
0005434733061	13899	Economy	6300.00
0005434733060	13899	Economy	6300.00
0005433817527	13899	Economy	6300.00
0005434733062	13899	Economy	6300.00
0005432985523	2341	Business	184500.00
0005435983328	2341	Business	184500.00
0005432985603	2341	Business	184500.00
0005435983321	2341	Business	184500.00
0005432985589	2341	Business	184500.00
0005433755495	2341	Business	184500.00
0005432655809	2341	Business	184500.00
0005432300394	2341	Business	184500.00
0005435983340	2341	Business	184500.00
0005435983303	2341	Business	184500.00
0005434731223	2341	Business	184500.00
0005432869594	2341	Business	184500.00
0005432985415	2341	Business	184500.00
0005433755475	2341	Business	184500.00
0005435983317	2341	Business	184500.00
0005433755498	2341	Business	184500.00
0005433755486	2341	Business	184500.00
0005433755491	2341	Business	184500.00
0005435983325	2341	Business	184500.00
0005433435002	2341	Business	184500.00
0005432985500	2341	Business	184500.00
0005435983314	2341	Business	184500.00
0005432226201	2341	Business	184500.00
0005435983299	2341	Business	184500.00
0005432985553	2341	Business	184500.00
0005433755501	2341	Business	184500.00
0005432985559	2341	Business	184500.00
0005435983326	2341	Business	184500.00
0005433435075	2341	Business	184500.00
0005432869581	2341	Economy	67700.00
0005432300396	2341	Economy	67700.00
0005435983331	2341	Economy	67700.00
0005433755512	2341	Economy	67700.00
0005435983327	2341	Economy	61500.00
0005433755510	2341	Economy	61500.00
0005432985636	2341	Economy	61500.00
0005433755489	2341	Economy	61500.00
0005433755507	2341	Economy	61500.00
0005435983305	2341	Economy	61500.00
0005435983295	2341	Economy	61500.00
0005433435130	2341	Economy	61500.00
0005433755496	2341	Economy	61500.00
0005432985512	2341	Economy	61500.00
0005435983336	2341	Economy	61500.00
0005433435114	2341	Economy	61500.00
0005432869580	2341	Economy	61500.00
0005432985567	2341	Economy	61500.00
0005432655812	2341	Economy	61500.00
0005432985555	2341	Economy	61500.00
0005433755466	2341	Economy	61500.00
0005433435103	2341	Economy	61500.00
0005435983293	2341	Economy	61500.00
0005433755474	2341	Economy	61500.00
0005435983310	2341	Economy	61500.00
0005435983296	2341	Economy	61500.00
0005432985501	2341	Economy	61500.00
0005433435063	2341	Economy	61500.00
0005432985583	2341	Economy	61500.00
0005433755494	2341	Economy	61500.00
0005432655815	2341	Economy	61500.00
0005432226199	2341	Economy	61500.00
0005432655811	2341	Economy	61500.00
0005433755515	2341	Economy	61500.00
0005433755478	2341	Economy	61500.00
0005435983341	2341	Economy	61500.00
0005435983334	2341	Economy	61500.00
0005435983298	2341	Economy	61500.00
0005433755482	2341	Economy	61500.00
0005433755493	2341	Economy	61500.00
0005435983338	2341	Economy	61500.00
0005433435175	2341	Economy	61500.00
0005433755484	2341	Economy	61500.00
0005432226202	2341	Economy	61500.00
0005433766756	2341	Economy	61500.00
0005435983292	2341	Economy	61500.00
0005435983308	2341	Economy	61500.00
0005435983311	2341	Economy	61500.00
0005433435072	2341	Economy	61500.00
0005432985465	2341	Economy	61500.00
0005433755472	2341	Economy	61500.00
0005433755514	2341	Economy	61500.00
0005435983319	2341	Economy	61500.00
0005433755506	2341	Economy	61500.00
0005433766725	2341	Economy	61500.00
0005432985584	2341	Economy	61500.00
0005432226200	2341	Economy	61500.00
0005433434935	2341	Economy	61500.00
0005433755471	2341	Economy	61500.00
0005433755517	2341	Economy	61500.00
0005433766727	2341	Economy	61500.00
0005433755520	2341	Economy	61500.00
0005433755467	2341	Economy	61500.00
0005433755492	2341	Economy	61500.00
0005433755513	2341	Economy	61500.00
0005435983304	2341	Economy	61500.00
0005435983322	2341	Economy	61500.00
0005432985658	2341	Economy	61500.00
0005434376159	2341	Economy	61500.00
0005435983318	2341	Economy	61500.00
0005433755477	2341	Economy	61500.00
0005433755490	2341	Economy	61500.00
0005435983307	2341	Economy	61500.00
0005435983313	2341	Economy	61500.00
0005435983315	2341	Economy	61500.00
0005432655808	2341	Economy	61500.00
0005432226198	2341	Economy	61500.00
0005433755479	2341	Economy	61500.00
0005433434996	2341	Economy	61500.00
0005432655806	2341	Economy	61500.00
0005433755502	2341	Economy	61500.00
0005432655814	2341	Economy	61500.00
0005433435121	2341	Economy	61500.00
0005433755497	2341	Economy	61500.00
0005433755481	2341	Economy	61500.00
0005433435104	2341	Economy	61500.00
0005433755511	2341	Economy	61500.00
0005434731217	2341	Economy	61500.00
0005432985335	2341	Economy	61500.00
0005435983301	2341	Economy	61500.00
0005433755468	2341	Economy	61500.00
0005432985525	2341	Economy	61500.00
0005435983332	2341	Economy	61500.00
0005432985656	2341	Economy	61500.00
0005432985483	2341	Economy	61500.00
0005433755518	2341	Economy	61500.00
0005435983329	2341	Economy	61500.00
0005434731216	2341	Economy	61500.00
0005432985485	2341	Economy	61500.00
0005432985401	2341	Economy	61500.00
0005433755488	2341	Economy	61500.00
0005432985657	2341	Economy	61500.00
0005432985518	2341	Economy	67700.00
0005433435006	2341	Economy	67700.00
0005432869612	2341	Economy	61500.00
0005433755519	2341	Economy	61500.00
0005435983316	2341	Economy	61500.00
0005433435005	2341	Economy	67700.00
0005435983335	2341	Economy	61500.00
0005435983337	2341	Economy	67700.00
0005435983306	2341	Economy	61500.00
0005433755500	2341	Economy	61500.00
0005433755480	2341	Economy	61500.00
0005435983339	2341	Economy	61500.00
0005432655810	2341	Economy	61500.00
0005433764727	2341	Economy	61500.00
0005432300395	2341	Economy	61500.00
0005432985607	2341	Economy	61500.00
0005432655807	2341	Economy	61500.00
0005432985655	2341	Economy	61500.00
0005433755470	2341	Economy	61500.00
0005432985540	2341	Economy	61500.00
0005434731215	2341	Economy	61500.00
0005435983309	2341	Economy	61500.00
0005433435111	2341	Economy	61500.00
0005433766726	2341	Economy	61500.00
0005433435097	2341	Economy	61500.00
0005435983294	2341	Economy	61500.00
0005432300397	2341	Economy	61500.00
0005433755516	2341	Economy	61500.00
0005432226197	2341	Economy	61500.00
0005432985426	2341	Economy	61500.00
0005432985507	2341	Economy	61500.00
0005432655813	2341	Economy	61500.00
0005433755499	2341	Economy	61500.00
0005432985416	2341	Economy	61500.00
0005433755508	2341	Economy	61500.00
0005432985524	2341	Economy	61500.00
0005433755504	2341	Economy	61500.00
0005432985424	2341	Economy	61500.00
0005435983291	2341	Economy	61500.00
0005433766724	2341	Economy	61500.00
0005434731222	2341	Economy	61500.00
0005433435035	2341	Economy	61500.00
0005433755509	2341	Economy	61500.00
0005432655804	2341	Economy	61500.00
0005433755503	2341	Economy	61500.00
0005435983323	2341	Economy	61500.00
0005432985513	2341	Economy	61500.00
0005435983342	2341	Economy	61500.00
0005435983312	2341	Economy	61500.00
0005432869645	2341	Economy	61500.00
0005433755483	2341	Economy	61500.00
0005435983333	2341	Economy	61500.00
0005433755473	2341	Economy	61500.00
0005432985443	2341	Economy	61500.00
0005432985637	2341	Economy	61500.00
0005433755485	2341	Economy	61500.00
0005435983302	2341	Economy	61500.00
0005435983324	2341	Economy	61500.00
0005433435062	2341	Economy	61500.00
0005433435073	2341	Economy	61500.00
0005432985552	2341	Economy	61500.00
0005435983330	2341	Economy	61500.00
0005435983300	2341	Economy	61500.00
0005432985604	2341	Economy	61500.00
0005432869644	2341	Economy	61500.00
0005432655805	2341	Economy	61500.00
0005435983297	2341	Economy	61500.00
0005432985407	2341	Economy	61500.00
0005435983320	2341	Economy	61500.00
0005432985734	2341	Economy	61500.00
0005434731237	2341	Economy	61500.00
0005433755469	2341	Economy	61500.00
0005433434995	2341	Economy	61500.00
0005433755487	2341	Economy	61500.00
0005432985425	2341	Economy	61500.00
0005432226196	2341	Economy	61500.00
0005432985476	2341	Economy	61500.00
0005432985578	2341	Economy	61500.00
0005432985573	2341	Economy	61500.00
0005432300398	2341	Economy	61500.00
0005433755505	2341	Economy	61500.00
0005432985566	2341	Economy	61500.00
0005433755476	2341	Economy	61500.00
0005432985602	2341	Economy	61500.00
0005433754912	26160	Business	184500.00
0005432985817	26160	Business	184500.00
0005433435325	26160	Business	184500.00
0005432869672	26160	Business	184500.00
0005432655687	26160	Business	184500.00
0005433754988	26160	Business	184500.00
0005433435326	26160	Business	184500.00
0005432985808	26160	Business	184500.00
0005433754785	26160	Business	184500.00
0005432985799	26160	Business	184500.00
0005434731265	26160	Business	184500.00
0005433755283	26160	Business	184500.00
0005435982863	26160	Business	184500.00
0005432985797	26160	Business	184500.00
0005433755022	26160	Business	184500.00
0005432985818	26160	Business	184500.00
0005435982796	26160	Business	184500.00
0005432985809	26160	Business	184500.00
0005433435310	26160	Business	184500.00
0005433755088	26160	Business	184500.00
0005433755106	26160	Business	184500.00
0005433755035	26160	Business	184500.00
0005433755111	26160	Business	184500.00
0005433755167	26160	Business	184500.00
0005432985813	26160	Business	184500.00
0005433766685	26160	Business	184500.00
0005433755293	26160	Business	184500.00
0005432985807	26160	Business	184500.00
0005435982957	26160	Economy	67700.00
0005433754839	26160	Economy	67700.00
0005433755125	26160	Economy	67700.00
0005433754901	26160	Economy	61500.00
0005435982891	26160	Economy	61500.00
0005433435317	26160	Economy	61500.00
0005433435306	26160	Economy	61500.00
0005432985820	26160	Economy	61500.00
0005432869674	26160	Economy	61500.00
0005432655666	26160	Economy	61500.00
0005432869670	26160	Economy	61500.00
0005435982908	26160	Economy	61500.00
0005433435319	26160	Economy	61500.00
0005433435323	26160	Economy	61500.00
0005432985810	26160	Economy	61500.00
0005433755089	26160	Economy	61500.00
0005433435304	26160	Economy	61500.00
0005435982943	26160	Economy	61500.00
0005433754895	26160	Economy	61500.00
0005432655667	26160	Economy	61500.00
0005433755072	26160	Economy	61500.00
0005432985798	26160	Economy	61500.00
0005435982879	26160	Economy	61500.00
0005433755095	26160	Economy	61500.00
0005432051198	26160	Economy	61500.00
0005433754784	26160	Economy	61500.00
0005433755062	26160	Economy	61500.00
0005435982907	26160	Economy	61500.00
0005433766684	26160	Economy	61500.00
0005433755039	26160	Economy	61500.00
0005435982808	26160	Economy	61500.00
0005435982862	26160	Economy	61500.00
0005432985802	26160	Economy	61500.00
0005433754968	26160	Economy	61500.00
0005432985821	26160	Economy	61500.00
0005435982896	26160	Economy	61500.00
0005435982869	26160	Economy	61500.00
0005432051201	26160	Economy	61500.00
0005433435322	26160	Economy	61500.00
0005435983015	26160	Economy	61500.00
0005433754799	26160	Economy	61500.00
0005433435311	26160	Economy	61500.00
0005435983024	26160	Economy	61500.00
0005433754978	26160	Economy	61500.00
0005432869675	26160	Economy	61500.00
0005432985822	26160	Economy	61500.00
0005433435307	26160	Economy	61500.00
0005433755093	26160	Economy	61500.00
0005433755098	26160	Economy	61500.00
0005433755094	26160	Economy	61500.00
0005433435312	26160	Economy	61500.00
0005433754865	26160	Economy	61500.00
0005433755152	26160	Economy	61500.00
0005435982967	26160	Economy	61500.00
0005433435303	26160	Economy	61500.00
0005432985812	26160	Economy	61500.00
0005433435314	26160	Economy	61500.00
0005432985825	26160	Economy	61500.00
0005432869673	26160	Economy	61500.00
0005432049546	26160	Economy	61500.00
0005432985804	26160	Economy	61500.00
0005433754814	26160	Economy	61500.00
0005435982811	26160	Economy	61500.00
0005432051200	26160	Economy	61500.00
0005433435313	26160	Economy	61500.00
0005435982944	26160	Economy	61500.00
0005433754902	26160	Economy	61500.00
0005433754734	26160	Economy	61500.00
0005432985805	26160	Economy	61500.00
0005433754864	26160	Economy	61500.00
0005435982860	26160	Economy	61500.00
0005432869668	26160	Economy	61500.00
0005433435315	26160	Economy	61500.00
0005434731269	26160	Economy	61500.00
0005433435320	26160	Economy	61500.00
0005435982857	26160	Economy	61500.00
0005433435316	26160	Economy	61500.00
0005435983025	26160	Economy	61500.00
0005432655685	26160	Economy	61500.00
0005433435308	26160	Economy	61500.00
0005435982847	26160	Economy	61500.00
0005433754886	26160	Economy	61500.00
0005435982837	26160	Economy	61500.00
0005433755122	26160	Economy	61500.00
0005435983111	26160	Economy	61500.00
0005434731267	26160	Economy	61500.00
0005432051197	26160	Economy	61500.00
0005433435328	26160	Economy	61500.00
0005433755126	26160	Economy	61500.00
0005432985826	26160	Economy	61500.00
0005432655670	26160	Economy	61500.00
0005433755223	26160	Economy	61500.00
0005433435324	26160	Economy	61500.00
0005435982810	26160	Economy	61500.00
0005433435309	26160	Economy	61500.00
0005435982849	26160	Economy	67700.00
0005435982911	26160	Economy	67700.00
0005433766691	26160	Economy	61500.00
0005433755036	26160	Economy	61500.00
0005435982842	26160	Economy	61500.00
0005433755047	26160	Economy	67700.00
0005433754866	26160	Economy	61500.00
0005433435321	26160	Economy	61500.00
0005433754677	26160	Economy	61500.00
0005433755051	26160	Economy	61500.00
0005435982805	26160	Economy	61500.00
0005433754910	26160	Economy	61500.00
0005433766681	26160	Economy	61500.00
0005435982892	26160	Economy	61500.00
0005433755083	26160	Economy	61500.00
0005433754943	26160	Economy	61500.00
0005434731266	26160	Economy	61500.00
0005432985806	26160	Economy	61500.00
0005432985814	26160	Economy	61500.00
0005433754731	26160	Economy	61500.00
0005435982774	26160	Economy	61500.00
0005433754917	26160	Economy	61500.00
0005433755060	26160	Economy	61500.00
0005433755186	26160	Economy	61500.00
0005435982790	26160	Economy	61500.00
0005433754894	26160	Economy	61500.00
0005432869671	26160	Economy	61500.00
0005432655675	26160	Economy	61500.00
0005432985796	26160	Economy	61500.00
0005433755222	26160	Economy	61500.00
0005433755061	26160	Economy	61500.00
0005433435327	26160	Economy	61500.00
0005432049543	26160	Economy	61500.00
0005435982938	26160	Economy	61500.00
0005434731268	26160	Economy	61500.00
0005433755023	26160	Economy	61500.00
0005432985819	26160	Economy	61500.00
0005432985801	26160	Economy	61500.00
0005432051199	26160	Economy	61500.00
0005433754813	26160	Economy	61500.00
0005433754964	26160	Economy	61500.00
0005433754778	26160	Economy	61500.00
0005432985803	26160	Economy	61500.00
0005435982906	26160	Economy	61500.00
0005433766690	26160	Economy	61500.00
0005435982858	26160	Economy	61500.00
0005433754944	26160	Economy	61500.00
0005432985800	26160	Economy	61500.00
0005433754979	26160	Economy	61500.00
0005432655686	26160	Economy	61500.00
0005432655715	26160	Economy	61500.00
0005433435302	26160	Economy	61500.00
0005432985795	26160	Economy	61500.00
0005435983157	26160	Economy	61500.00
0005432985823	26160	Economy	61500.00
0005432049544	26160	Economy	61500.00
0005433754969	26160	Economy	61500.00
0005435982901	26160	Economy	61500.00
0005435983009	26160	Economy	61500.00
0005435982775	26160	Economy	61500.00
0005433754911	26160	Economy	61500.00
0005435982968	26160	Economy	61500.00
0005433755053	26160	Economy	61500.00
0005432869669	26160	Economy	61500.00
0005433754812	26160	Economy	61500.00
0005432985824	26160	Economy	61500.00
0005433755092	26160	Economy	61500.00
0005433755052	26160	Economy	61500.00
0005433435305	26160	Economy	61500.00
0005435983042	26160	Economy	61500.00
0005435982850	26160	Economy	61500.00
0005432985816	26160	Economy	61500.00
0005432985815	26160	Economy	61500.00
0005432985811	26160	Economy	61500.00
0005433754957	26160	Economy	61500.00
0005435982936	26160	Economy	61500.00
0005433435318	26160	Economy	61500.00
0005432049545	26160	Economy	61500.00
0005435982890	26160	Economy	61500.00
0005435982895	26160	Economy	61500.00
0005434375673	1541	Business	38900.00
0005434375672	1541	Business	38900.00
0005434375690	1541	Business	38900.00
0005433151922	1541	Business	38900.00
0005433151871	1541	Business	38900.00
0005433461638	1541	Business	38900.00
0005434375680	1541	Business	38900.00
0005434375695	1541	Business	38900.00
0005434375693	1541	Business	38900.00
0005434375705	1541	Business	38900.00
0005433460485	1541	Economy	13000.00
0005434375702	1541	Economy	13000.00
0005434375699	1541	Economy	13000.00
0005433151824	1541	Economy	13000.00
0005433151800	1541	Economy	13000.00
0005434375685	1541	Economy	13000.00
0005434375665	1541	Economy	13000.00
0005434375675	1541	Economy	13000.00
0005433151895	1541	Economy	13000.00
0005433151902	1541	Economy	13000.00
0005433460484	1541	Economy	13000.00
0005434375698	1541	Economy	13000.00
0005434375684	1541	Economy	13000.00
0005433931513	1541	Economy	13000.00
0005434375691	1541	Economy	13000.00
0005433151889	1541	Economy	13000.00
0005433931511	1541	Economy	13000.00
0005433460486	1541	Economy	13000.00
0005433151940	1541	Economy	13000.00
0005433151874	1541	Economy	13000.00
0005434375687	1541	Economy	13000.00
0005433151893	1541	Economy	13000.00
0005432268048	1541	Economy	13000.00
0005434375681	1541	Economy	13000.00
0005433152013	1541	Economy	13000.00
0005434375669	1541	Economy	13000.00
0005434375677	1541	Economy	13000.00
0005432268046	1541	Economy	13000.00
0005434375701	1541	Economy	13000.00
0005433764703	1541	Economy	13000.00
0005434375678	1541	Economy	13000.00
0005434375692	1541	Economy	13000.00
0005433931512	1541	Economy	13000.00
0005433151794	1541	Economy	13000.00
0005433152019	1541	Economy	13000.00
0005433151799	1541	Economy	13000.00
0005434375694	1541	Economy	14300.00
0005432268051	1541	Economy	14300.00
0005434375671	1541	Economy	14300.00
0005433151976	1541	Economy	14300.00
0005433152072	1541	Economy	14300.00
0005433151869	1541	Economy	13000.00
0005434375703	1541	Economy	13000.00
0005434375683	1541	Economy	13000.00
0005434375686	1541	Economy	13000.00
0005433151991	1541	Economy	13000.00
0005433151875	1541	Economy	13000.00
0005433151876	1541	Economy	13000.00
0005433152073	1541	Economy	13000.00
0005433152027	1541	Economy	13000.00
0005434375676	1541	Economy	13000.00
0005434375700	1541	Economy	13000.00
0005432268044	1541	Economy	13000.00
0005432268045	1541	Economy	13000.00
0005434375696	1541	Economy	13000.00
0005433151984	1541	Economy	13000.00
0005433151920	1541	Economy	13000.00
0005433151901	1541	Economy	13000.00
0005433151892	1541	Economy	13000.00
0005434375666	1541	Economy	13000.00
0005434375664	1541	Economy	13000.00
0005434375667	1541	Economy	13000.00
0005433151992	1541	Economy	13000.00
0005433151912	1541	Economy	13000.00
0005434375688	1541	Economy	13000.00
0005433461637	1541	Economy	13000.00
0005432268047	1541	Economy	13000.00
0005433151988	1541	Economy	13000.00
0005433151795	1541	Economy	13000.00
0005432268050	1541	Economy	13000.00
0005433151900	1541	Economy	13000.00
0005433151779	1541	Economy	13000.00
0005434375697	1541	Economy	13000.00
0005434375668	1541	Economy	13000.00
0005434375704	1541	Economy	13000.00
0005433461636	1541	Economy	13000.00
0005433151969	1541	Economy	13000.00
0005432268049	1541	Economy	13000.00
0005433151947	1541	Economy	13000.00
0005434375674	1541	Economy	13000.00
0005434375682	1541	Economy	13000.00
0005433152018	1541	Economy	13000.00
0005433151905	1541	Economy	13000.00
0005433151873	1541	Economy	13000.00
0005433151851	1541	Economy	13000.00
0005433152007	1541	Economy	13000.00
0005434375679	1541	Economy	13000.00
0005433764708	1541	Economy	13000.00
0005433151793	1541	Economy	13000.00
0005433151877	1541	Economy	13000.00
0005434375689	1541	Economy	13000.00
0005433151983	1541	Economy	13000.00
0005433151792	1541	Economy	13000.00
0005434375670	1541	Economy	13000.00
0005433151941	1541	Economy	13000.00
0005433151913	1541	Economy	13000.00
0005434375334	20122	Business	38900.00
0005433152186	20122	Business	38900.00
0005434375337	20122	Business	38900.00
0005434029714	20122	Business	38900.00
0005433152169	20122	Business	38900.00
0005434375326	20122	Business	38900.00
0005434375306	20122	Business	38900.00
0005434375342	20122	Business	38900.00
0005433764727	20122	Business	38900.00
0005433152187	20122	Business	38900.00
0005433152185	20122	Economy	13000.00
0005433152195	20122	Economy	13000.00
0005433152165	20122	Economy	13000.00
0005432056383	20122	Economy	13000.00
0005433152192	20122	Economy	13000.00
0005433931537	20122	Economy	13000.00
0005434375289	20122	Economy	13000.00
0005434375320	20122	Economy	13000.00
0005433152168	20122	Economy	13000.00
0005434375278	20122	Economy	13000.00
0005434375181	20122	Economy	13000.00
0005433152182	20122	Economy	13000.00
0005433152196	20122	Economy	13000.00
0005433152188	20122	Economy	13000.00
0005433152198	20122	Economy	13000.00
0005433152170	20122	Economy	13000.00
0005433931536	20122	Economy	13000.00
0005433152171	20122	Economy	13000.00
0005434375305	20122	Economy	13000.00
0005434375346	20122	Economy	13000.00
0005434376227	20122	Economy	13000.00
0005434029712	20122	Economy	13000.00
0005434376159	20122	Economy	13000.00
0005434375192	20122	Economy	13000.00
0005434375405	20122	Economy	13000.00
0005434375327	20122	Economy	13000.00
0005433152178	20122	Economy	13000.00
0005434375191	20122	Economy	13000.00
0005434375220	20122	Economy	14300.00
0005433152172	20122	Economy	14300.00
0005432056385	20122	Economy	14300.00
0005433931535	20122	Economy	14300.00
0005434375277	20122	Economy	14300.00
0005434375435	20122	Economy	14300.00
0005432056387	20122	Economy	13000.00
0005434375083	20122	Economy	13000.00
0005434375152	20122	Economy	13000.00
0005433152194	20122	Economy	13000.00
0005433152179	20122	Economy	13000.00
0005433152177	20122	Economy	13000.00
0005433931534	20122	Economy	13000.00
0005434375354	20122	Economy	13000.00
0005433152183	20122	Economy	13000.00
0005434375471	20122	Economy	13000.00
0005433152191	20122	Economy	13000.00
0005434375186	20122	Economy	13000.00
0005434029713	20122	Economy	13000.00
0005433152181	20122	Economy	13000.00
0005434375093	20122	Economy	13000.00
0005432056386	20122	Economy	13000.00
0005434375216	20122	Economy	13000.00
0005433152193	20122	Economy	13000.00
0005434375420	20122	Economy	13000.00
0005433152166	20122	Economy	13000.00
0005434375309	20122	Economy	13000.00
0005433152199	20122	Economy	13000.00
0005433152189	20122	Economy	13000.00
0005432056384	20122	Economy	13000.00
0005434375221	20122	Economy	13000.00
0005433152184	20122	Economy	13000.00
0005433152174	20122	Economy	13000.00
0005433152197	20122	Economy	13000.00
0005434375187	20122	Economy	13000.00
0005433152176	20122	Economy	13000.00
0005434376226	20122	Economy	13000.00
0005433152175	20122	Economy	13000.00
0005434375170	20122	Economy	13000.00
0005434375330	20122	Economy	13000.00
0005433152190	20122	Economy	13000.00
0005434375067	20122	Economy	13000.00
0005434375201	20122	Economy	13000.00
0005434375203	20122	Economy	13000.00
0005434375386	20122	Economy	13000.00
0005433152180	20122	Economy	13000.00
0005433152167	20122	Economy	13000.00
0005434375409	20122	Economy	13000.00
0005434375333	20122	Economy	13000.00
0005434375314	20122	Economy	13000.00
0005433152173	20122	Economy	13000.00
0005432425575	547	Business	27500.00
0005432425551	547	Business	27500.00
0005432425573	547	Business	27500.00
0005432425559	547	Business	27500.00
0005432425548	547	Business	27500.00
0005432425527	547	Business	27500.00
0005432425571	547	Business	27500.00
0005432425568	547	Business	27500.00
0005432425558	547	Business	27500.00
0005432425560	547	Business	27500.00
0005432425536	547	Business	27500.00
0005432425529	547	Business	27500.00
0005432283021	547	Business	27500.00
0005432425562	547	Business	27500.00
0005432425547	547	Economy	10100.00
0005432425564	547	Economy	10100.00
0005432425553	547	Economy	9200.00
0005432425526	547	Economy	9200.00
0005432425577	547	Economy	9200.00
0005432283024	547	Economy	9200.00
0005432425563	547	Economy	9200.00
0005432283027	547	Economy	9200.00
0005432425525	547	Economy	9200.00
0005432425544	547	Economy	9200.00
0005432425554	547	Economy	9200.00
0005432283023	547	Economy	9200.00
0005432425556	547	Economy	9200.00
0005432425533	547	Economy	9200.00
0005432425574	547	Economy	9200.00
0005432283020	547	Economy	9200.00
0005432425545	547	Economy	9200.00
0005432425540	547	Economy	9200.00
0005432425546	547	Economy	9200.00
0005432283022	547	Economy	9200.00
0005432425539	547	Economy	9200.00
0005432283025	547	Economy	9200.00
0005432425523	547	Economy	10100.00
0005432425557	547	Economy	9200.00
0005432425570	547	Economy	10100.00
0005432425541	547	Economy	10100.00
0005432425542	547	Economy	10100.00
0005432425569	547	Economy	9200.00
0005432425550	547	Economy	9200.00
0005432425538	547	Economy	9200.00
0005432425549	547	Economy	9200.00
0005432425530	547	Economy	9200.00
0005432425524	547	Economy	9200.00
0005432425532	547	Economy	9200.00
0005432425537	547	Economy	9200.00
0005432425531	547	Economy	9200.00
0005432425555	547	Economy	9200.00
0005432425576	547	Economy	9200.00
0005432283026	547	Economy	9200.00
0005432425567	547	Economy	9200.00
0005432425552	547	Economy	9200.00
0005432425535	547	Economy	9200.00
0005432425561	547	Economy	9200.00
0005432425543	547	Economy	9200.00
0005432425566	547	Economy	9200.00
0005432425528	547	Economy	9200.00
0005432425534	547	Economy	9200.00
0005432425565	547	Economy	9200.00
0005432425572	547	Economy	9200.00
0005433261887	12945	Business	27500.00
0005433158179	12945	Business	27500.00
0005434446533	12945	Business	27500.00
0005434446539	12945	Business	27500.00
0005433261886	12945	Business	27500.00
0005433261890	12945	Economy	10100.00
0005433158180	12945	Economy	10100.00
0005433158183	12945	Economy	9200.00
0005433158181	12945	Economy	9200.00
0005433261885	12945	Economy	9200.00
0005434446551	12945	Economy	9200.00
0005432302417	12945	Economy	9200.00
0005433766756	12945	Economy	9200.00
0005432302415	12945	Economy	9200.00
0005434446538	12945	Economy	10100.00
0005433261889	12945	Economy	9200.00
0005434446550	12945	Economy	9200.00
0005434446545	12945	Economy	9200.00
0005433261891	12945	Economy	9200.00
0005434446544	12945	Economy	9200.00
0005433261888	12945	Economy	9200.00
0005432302414	12945	Economy	9200.00
0005434446548	12945	Economy	9200.00
0005434446554	12945	Economy	9200.00
0005433158182	12945	Economy	9200.00
0005433157010	12945	Economy	9200.00
0005432302416	12945	Economy	9200.00
0005434446549	12945	Economy	9200.00
0005432424968	12930	Business	27500.00
0005432425111	12930	Business	27500.00
0005432425004	12930	Business	27500.00
0005432425084	12930	Business	27500.00
0005432425137	12930	Business	27500.00
0005432425114	12930	Business	27500.00
0005432425048	12930	Business	27500.00
0005432425168	12930	Business	27500.00
0005432425023	12930	Business	27500.00
0005432424843	12930	Business	27500.00
0005432424920	12930	Business	27500.00
0005432425106	12930	Business	27500.00
0005432425117	12930	Business	27500.00
0005432425093	12930	Business	27500.00
0005432424991	12930	Business	27500.00
0005432425097	12930	Economy	9200.00
0005432425165	12930	Economy	9200.00
0005432425086	12930	Economy	9200.00
0005432424992	12930	Economy	9200.00
0005432424957	12930	Economy	9200.00
0005432425065	12930	Economy	9200.00
0005432425164	12930	Economy	9200.00
0005432424958	12930	Economy	9200.00
0005432425088	12930	Economy	9200.00
0005432424817	12930	Economy	9200.00
0005432425135	12930	Economy	9200.00
0005432424844	12930	Economy	9200.00
0005432425066	12930	Economy	9200.00
0005432425094	12930	Economy	9200.00
0005432425090	12930	Economy	9200.00
0005432425087	12930	Economy	9200.00
0005432425027	12930	Economy	9200.00
0005432425008	12930	Economy	9200.00
0005432424816	12930	Economy	9200.00
0005432424893	12930	Economy	9200.00
0005432425131	12930	Economy	9200.00
0005432425013	12930	Economy	9200.00
0005432425166	12930	Economy	9200.00
0005432425101	12930	Economy	10100.00
0005432424930	12930	Economy	10100.00
0005432425100	12930	Economy	9200.00
0005432424921	12930	Economy	9200.00
0005432425173	12930	Economy	9200.00
0005432425116	12930	Economy	9200.00
0005432424960	12930	Economy	9200.00
0005432425075	12930	Economy	9200.00
0005432425115	12930	Economy	9200.00
0005432424845	12930	Economy	9200.00
0005432425038	12930	Economy	9200.00
0005432425112	12930	Economy	9200.00
0005432425091	12930	Economy	9200.00
0005432425136	12930	Economy	9200.00
0005432424869	12930	Economy	9200.00
0005432425085	12930	Economy	9200.00
0005432425163	12930	Economy	9200.00
0005432425096	12930	Economy	9200.00
0005432424959	12930	Economy	9200.00
0005434025267	448	Business	24500.00
0005434032124	448	Business	24500.00
0005433058508	448	Business	24500.00
0005434025226	448	Business	24500.00
0005434735766	448	Business	24500.00
0005434025213	448	Business	24500.00
0005433058431	448	Business	24500.00
0005434025259	448	Business	24500.00
0005434025229	448	Business	24500.00
0005433058511	448	Business	24500.00
0005433058645	448	Business	24500.00
0005434025245	448	Business	24500.00
0005432045655	448	Business	24500.00
0005433058448	448	Business	24500.00
0005434025273	448	Business	24500.00
0005434025215	448	Business	24500.00
0005434032122	448	Business	24500.00
0005434025242	448	Business	24500.00
0005432235808	448	Business	24500.00
0005434025252	448	Economy	9000.00
0005434025231	448	Economy	9000.00
0005433058560	448	Economy	9000.00
0005434025236	448	Economy	9000.00
0005433058430	448	Economy	8200.00
0005433929657	448	Economy	8200.00
0005433058625	448	Economy	8200.00
0005433058393	448	Economy	8200.00
0005434025230	448	Economy	8200.00
0005434025239	448	Economy	8200.00
0005434025272	448	Economy	8200.00
0005433058474	448	Economy	8200.00
0005432235811	448	Economy	8200.00
0005434032123	448	Economy	8200.00
0005434025264	448	Economy	8200.00
0005434025232	448	Economy	8200.00
0005434025208	448	Economy	8200.00
0005434025234	448	Economy	8200.00
0005433058536	448	Economy	8200.00
0005434025214	448	Economy	8200.00
0005434025205	448	Economy	8200.00
0005434025235	448	Economy	8200.00
0005434735756	448	Economy	8200.00
0005434025227	448	Economy	8200.00
0005432235810	448	Economy	8200.00
0005433058537	448	Economy	8200.00
0005434735752	448	Economy	8200.00
0005434025206	448	Economy	8200.00
0005433058458	448	Economy	8200.00
0005434025207	448	Economy	8200.00
0005434735746	448	Economy	8200.00
0005434025221	448	Economy	8200.00
0005434032126	448	Economy	8200.00
0005433058266	448	Economy	8200.00
0005434025233	448	Economy	8200.00
0005434025244	448	Economy	8200.00
0005434028368	448	Economy	8200.00
0005434025270	448	Economy	8200.00
0005433058404	448	Economy	8200.00
0005433058378	448	Economy	8200.00
0005434735754	448	Economy	8200.00
0005434028369	448	Economy	8200.00
0005433058441	448	Economy	8200.00
0005434025261	448	Economy	8200.00
0005432235805	448	Economy	8200.00
0005434025247	448	Economy	8200.00
0005434025265	448	Economy	8200.00
0005433058461	448	Economy	8200.00
0005434025257	448	Economy	8200.00
0005434025260	448	Economy	8200.00
0005433929656	448	Economy	8200.00
0005434025241	448	Economy	8200.00
0005433058468	448	Economy	8200.00
0005433058465	448	Economy	8200.00
0005432235804	448	Economy	8200.00
0005434025266	448	Economy	8200.00
0005434025237	448	Economy	8200.00
0005434025210	448	Economy	8200.00
0005434025250	448	Economy	8200.00
0005432235809	448	Economy	8200.00
0005434025253	448	Economy	8200.00
0005433058457	448	Economy	8200.00
0005434025254	448	Economy	8200.00
0005434025240	448	Economy	8200.00
0005433929664	448	Economy	8200.00
0005433058546	448	Economy	8200.00
0005434735745	448	Economy	8200.00
0005433058403	448	Economy	8200.00
0005434025238	448	Economy	8200.00
0005434028371	448	Economy	8200.00
0005433058379	448	Economy	8200.00
0005433058495	448	Economy	8200.00
0005433058460	448	Economy	8200.00
0005432235807	448	Economy	8200.00
0005434025212	448	Economy	8200.00
0005434025218	448	Economy	8200.00
0005433058432	448	Economy	8200.00
0005434025263	448	Economy	8200.00
0005434025256	448	Economy	8200.00
0005434032125	448	Economy	8200.00
0005434025216	448	Economy	8200.00
0005434029711	448	Economy	9000.00
0005432235806	448	Economy	8200.00
0005433058267	448	Economy	8200.00
0005433058596	448	Economy	8200.00
0005434025225	448	Economy	9000.00
0005433058591	448	Economy	9000.00
0005434025223	448	Economy	8200.00
0005433684447	448	Economy	8200.00
0005433058446	448	Economy	8200.00
0005433058647	448	Economy	8200.00
0005434025249	448	Economy	8200.00
0005434025222	448	Economy	8200.00
0005434025271	448	Economy	8200.00
0005434025246	448	Economy	8200.00
0005433058478	448	Economy	8200.00
0005434735759	448	Economy	8200.00
0005434025269	448	Economy	8200.00
0005433058501	448	Economy	8200.00
0005433058354	448	Economy	8200.00
0005433929671	448	Economy	8200.00
0005434025224	448	Economy	8200.00
0005434025211	448	Economy	8200.00
0005433058422	448	Economy	8200.00
0005433058538	448	Economy	8200.00
0005434025220	448	Economy	8200.00
0005434735748	448	Economy	8200.00
0005433058477	448	Economy	8200.00
0005433058421	448	Economy	8200.00
0005434025251	448	Economy	8200.00
0005433058545	448	Economy	8200.00
0005433058646	448	Economy	8200.00
0005433058603	448	Economy	8200.00
0005434028370	448	Economy	8200.00
0005434025219	448	Economy	8200.00
0005433058398	448	Economy	8200.00
0005434025228	448	Economy	8200.00
0005434025217	448	Economy	8200.00
0005433058655	448	Economy	8200.00
0005432045656	448	Economy	8200.00
0005434025255	448	Economy	8200.00
0005434025268	448	Economy	8200.00
0005434735758	448	Economy	8200.00
0005434735747	448	Economy	8200.00
0005434025274	448	Economy	8200.00
0005434735777	448	Economy	8200.00
0005433058539	448	Economy	8200.00
0005434735757	448	Economy	8200.00
0005434025209	448	Economy	8200.00
0005434025248	448	Economy	8200.00
0005433058420	448	Economy	8200.00
0005434735765	448	Economy	8200.00
0005434025243	448	Economy	8200.00
0005434025258	448	Economy	8200.00
0005434025262	448	Economy	8200.00
0005434024731	12655	Business	24500.00
0005434024753	12655	Business	24500.00
0005432156468	12655	Business	24500.00
0005433058774	12655	Business	24500.00
0005433058808	12655	Business	24500.00
0005433684467	12655	Business	24500.00
0005434735807	12655	Business	24500.00
0005434024513	12655	Business	24500.00
0005434024604	12655	Business	24500.00
0005433058798	12655	Business	24500.00
0005434024745	12655	Business	24500.00
0005434024825	12655	Business	24500.00
0005432156467	12655	Business	24500.00
0005434024732	12655	Business	24500.00
0005432156469	12655	Business	24500.00
0005434024323	12655	Business	24500.00
0005434028334	12655	Economy	9000.00
0005432157535	12655	Economy	9000.00
0005433058805	12655	Economy	9000.00
0005433929709	12655	Economy	8200.00
0005433058796	12655	Economy	8200.00
0005434024374	12655	Economy	8200.00
0005434024502	12655	Economy	8200.00
0005433058788	12655	Economy	8200.00
0005434028331	12655	Economy	8200.00
0005434024897	12655	Economy	8200.00
0005434024754	12655	Economy	8200.00
0005434024628	12655	Economy	8200.00
0005434024971	12655	Economy	8200.00
0005434024584	12655	Economy	8200.00
0005434024781	12655	Economy	8200.00
0005433058801	12655	Economy	8200.00
0005434024514	12655	Economy	8200.00
0005434024498	12655	Economy	8200.00
0005433058771	12655	Economy	8200.00
0005434024622	12655	Economy	8200.00
0005432156464	12655	Economy	8200.00
0005434024322	12655	Economy	8200.00
0005434024582	12655	Economy	8200.00
0005433058799	12655	Economy	8200.00
0005434024713	12655	Economy	8200.00
0005433684468	12655	Economy	8200.00
0005434024305	12655	Economy	8200.00
0005434024837	12655	Economy	8200.00
0005434024970	12655	Economy	8200.00
0005434024660	12655	Economy	8200.00
0005433058807	12655	Economy	8200.00
0005434024650	12655	Economy	8200.00
0005434024726	12655	Economy	8200.00
0005433058810	12655	Economy	8200.00
0005433058783	12655	Economy	8200.00
0005434028332	12655	Economy	8200.00
0005433929708	12655	Economy	8200.00
0005433058787	12655	Economy	8200.00
0005432157538	12655	Economy	8200.00
0005434028341	12655	Economy	8200.00
0005434024909	12655	Economy	8200.00
0005434024714	12655	Economy	8200.00
0005434024846	12655	Economy	8200.00
0005434024629	12655	Economy	8200.00
0005434024769	12655	Economy	8200.00
0005433058802	12655	Economy	8200.00
0005434024624	12655	Economy	8200.00
0005434024847	12655	Economy	8200.00
0005434024826	12655	Economy	8200.00
0005433058775	12655	Economy	8200.00
0005434024771	12655	Economy	8200.00
0005433058793	12655	Economy	8200.00
0005432157536	12655	Economy	8200.00
0005433929710	12655	Economy	8200.00
0005434024583	12655	Economy	8200.00
0005433058786	12655	Economy	8200.00
0005433058800	12655	Economy	8200.00
0005433058780	12655	Economy	8200.00
0005433058777	12655	Economy	9000.00
0005434024671	12655	Economy	8200.00
0005433058809	12655	Economy	8200.00
0005434024550	12655	Economy	8200.00
0005433058789	12655	Economy	9000.00
0005434024421	12655	Economy	8200.00
0005434024705	12655	Economy	8200.00
0005433058811	12655	Economy	8200.00
0005434024580	12655	Economy	8200.00
0005433058797	12655	Economy	8200.00
0005433058794	12655	Economy	8200.00
0005433058785	12655	Economy	8200.00
0005433058791	12655	Economy	8200.00
0005434024539	12655	Economy	8200.00
0005432156466	12655	Economy	8200.00
0005434024770	12655	Economy	8200.00
0005434735809	12655	Economy	8200.00
0005433058776	12655	Economy	8200.00
0005434024746	12655	Economy	8200.00
0005434024910	12655	Economy	8200.00
0005434024422	12655	Economy	8200.00
0005434024809	12655	Economy	8200.00
0005434024579	12655	Economy	8200.00
0005434024824	12655	Economy	8200.00
0005434024668	12655	Economy	8200.00
0005433058792	12655	Economy	8200.00
0005432156465	12655	Economy	8200.00
0005434024585	12655	Economy	8200.00
0005434024672	12655	Economy	8200.00
0005434024420	12655	Economy	8200.00
0005433058773	12655	Economy	8200.00
0005434024625	12655	Economy	8200.00
0005434024782	12655	Economy	8200.00
0005433058790	12655	Economy	8200.00
0005434735810	12655	Economy	8200.00
0005434024655	12655	Economy	8200.00
0005434024651	12655	Economy	8200.00
0005433058778	12655	Economy	8200.00
0005433929707	12655	Economy	8200.00
0005433058804	12655	Economy	8200.00
0005433058772	12655	Economy	8200.00
0005433058779	12655	Economy	8200.00
0005433058806	12655	Economy	8200.00
0005434735808	12655	Economy	8200.00
0005433058803	12655	Economy	8200.00
0005434024540	12655	Economy	8200.00
0005432157537	12655	Economy	8200.00
0005434024703	12655	Economy	8200.00
0005433058782	12655	Economy	8200.00
0005434024667	12655	Economy	8200.00
0005434024473	12655	Economy	8200.00
0005434024306	12655	Economy	8200.00
0005434024972	12655	Economy	8200.00
0005434024666	12655	Economy	8200.00
0005433058781	12655	Economy	8200.00
0005433058795	12655	Economy	8200.00
0005434024551	12655	Economy	8200.00
0005434024399	12655	Economy	8200.00
0005433058784	12655	Economy	8200.00
0005434024711	12655	Economy	8200.00
0005434024783	12655	Economy	8200.00
0005434024343	12655	Economy	8200.00
0005433036922	2149	Business	34700.00
0005432231806	2149	Business	34700.00
0005433037169	2149	Business	34700.00
0005433925500	2149	Business	34700.00
0005433925468	2149	Business	34700.00
0005433925420	2149	Business	34700.00
0005433036925	2149	Business	34700.00
0005433925430	2149	Business	34700.00
0005433925514	2149	Business	34700.00
0005433925462	2149	Business	34700.00
0005433036701	2149	Business	34700.00
0005434028334	2149	Business	34700.00
0005432749821	2149	Business	34700.00
0005433037058	2149	Business	34700.00
0005433037068	2149	Business	34700.00
0005433925418	2149	Business	34700.00
0005433037190	2149	Business	34700.00
0005433925509	2149	Business	34700.00
0005433925445	2149	Business	34700.00
0005433925513	2149	Business	34700.00
0005434028331	2149	Business	34700.00
0005433925466	2149	Business	34700.00
0005433925495	2149	Business	34700.00
0005433929868	2149	Business	34700.00
0005433925494	2149	Economy	12700.00
0005433925474	2149	Economy	12700.00
0005433037189	2149	Economy	12700.00
0005433925510	2149	Economy	12700.00
0005433036876	2149	Economy	11600.00
0005433037109	2149	Economy	11600.00
0005432231799	2149	Economy	11600.00
0005433036974	2149	Economy	11600.00
0005433925479	2149	Economy	11600.00
0005432231805	2149	Economy	11600.00
0005433925459	2149	Economy	11600.00
0005432231803	2149	Economy	11600.00
0005433037059	2149	Economy	11600.00
0005433925502	2149	Economy	11600.00
0005433931536	2149	Economy	11600.00
0005432231800	2149	Economy	11600.00
0005433036968	2149	Economy	11600.00
0005433925487	2149	Economy	11600.00
0005433925501	2149	Economy	11600.00
0005433925427	2149	Economy	11600.00
0005433925438	2149	Economy	11600.00
0005433925486	2149	Economy	11600.00
0005433925440	2149	Economy	11600.00
0005432231807	2149	Economy	11600.00
0005433925505	2149	Economy	11600.00
0005433925471	2149	Economy	11600.00
0005433037110	2149	Economy	11600.00
0005433929707	2149	Economy	11600.00
0005433925450	2149	Economy	11600.00
0005433925497	2149	Economy	11600.00
0005433925507	2149	Economy	11600.00
0005433925451	2149	Economy	11600.00
0005433925455	2149	Economy	11600.00
0005432231801	2149	Economy	11600.00
0005433925464	2149	Economy	11600.00
0005433036868	2149	Economy	11600.00
0005433036860	2149	Economy	11600.00
0005433036822	2149	Economy	11600.00
0005433929867	2149	Economy	11600.00
0005433925454	2149	Economy	11600.00
0005433036829	2149	Economy	11600.00
0005433037069	2149	Economy	11600.00
0005433925508	2149	Economy	11600.00
0005433925424	2149	Economy	11600.00
0005433037063	2149	Economy	11600.00
0005433925456	2149	Economy	11600.00
0005433925448	2149	Economy	11600.00
0005433925436	2149	Economy	11600.00
0005433931535	2149	Economy	11600.00
0005433037186	2149	Economy	11600.00
0005433925425	2149	Economy	11600.00
0005433925499	2149	Economy	11600.00
0005433925433	2149	Economy	11600.00
0005433037184	2149	Economy	11600.00
0005433925463	2149	Economy	11600.00
0005433925511	2149	Economy	11600.00
0005433036830	2149	Economy	11600.00
0005433925476	2149	Economy	11600.00
0005433925439	2149	Economy	11600.00
0005433925512	2149	Economy	11600.00
0005433925484	2149	Economy	11600.00
0005432231808	2149	Economy	11600.00
0005433037187	2149	Economy	11600.00
0005432231804	2149	Economy	11600.00
0005433931534	2149	Economy	11600.00
0005432231802	2149	Economy	11600.00
0005433925480	2149	Economy	11600.00
0005432231809	2149	Economy	11600.00
0005434028332	2149	Economy	11600.00
0005433925498	2149	Economy	11600.00
0005433036911	2149	Economy	11600.00
0005433037011	2149	Economy	11600.00
0005433036864	2149	Economy	11600.00
0005433925489	2149	Economy	11600.00
0005433925416	2149	Economy	11600.00
0005433036863	2149	Economy	11600.00
0005433925437	2149	Economy	11600.00
0005433036985	2149	Economy	11600.00
0005433925490	2149	Economy	11600.00
0005433037236	2149	Economy	11600.00
0005433925503	2149	Economy	11600.00
0005433925421	2149	Economy	11600.00
0005433036916	2149	Economy	11600.00
0005433925492	2149	Economy	11600.00
0005433925483	2149	Economy	11600.00
0005433925478	2149	Economy	11600.00
0005433925444	2149	Economy	12700.00
0005433037125	2149	Economy	11600.00
0005433925485	2149	Economy	12700.00
0005433925472	2149	Economy	12700.00
0005433925453	2149	Economy	11600.00
0005433925506	2149	Economy	11600.00
0005433036984	2149	Economy	11600.00
0005433925504	2149	Economy	11600.00
0005432231810	2149	Economy	11600.00
0005433925442	2149	Economy	11600.00
0005433925429	2149	Economy	11600.00
0005433925422	2149	Economy	11600.00
0005433925458	2149	Economy	11600.00
0005433925443	2149	Economy	11600.00
0005433036917	2149	Economy	11600.00
0005433925493	2149	Economy	11600.00
0005432044587	2149	Economy	11600.00
0005433925469	2149	Economy	11600.00
0005433925467	2149	Economy	11600.00
0005433036850	2149	Economy	11600.00
0005433925432	2149	Economy	11600.00
0005433925477	2149	Economy	11600.00
0005433925461	2149	Economy	11600.00
0005433925419	2149	Economy	11600.00
0005433037060	2149	Economy	11600.00
0005433037185	2149	Economy	11600.00
0005433925496	2149	Economy	11600.00
0005432044588	2149	Economy	11600.00
0005432749815	2149	Economy	11600.00
0005433925491	2149	Economy	11600.00
0005433925482	2149	Economy	11600.00
0005433925431	2149	Economy	11600.00
0005433036902	2149	Economy	11600.00
0005433925426	2149	Economy	11600.00
0005433875415	2149	Economy	11600.00
0005433925428	2149	Economy	11600.00
0005433925441	2149	Economy	11600.00
0005433925465	2149	Economy	11600.00
0005433925434	2149	Economy	11600.00
0005433037076	2149	Economy	11600.00
0005433925470	2149	Economy	11600.00
0005433925452	2149	Economy	11600.00
0005433931537	2149	Economy	11600.00
0005434028341	2149	Economy	11600.00
0005433925475	2149	Economy	11600.00
0005433875416	2149	Economy	11600.00
0005433929709	2149	Economy	11600.00
0005433037012	2149	Economy	11600.00
0005433925488	2149	Economy	11600.00
0005433929710	2149	Economy	11600.00
0005433925460	2149	Economy	11600.00
0005433925457	2149	Economy	11600.00
0005433037168	2149	Economy	11600.00
0005433925449	2149	Economy	11600.00
0005433925423	2149	Economy	11600.00
0005433925446	2149	Economy	11600.00
0005433925435	2149	Economy	11600.00
0005433037102	2149	Economy	11600.00
0005433925447	2149	Economy	11600.00
0005433929708	2149	Economy	11600.00
0005432749822	2149	Economy	11600.00
0005433925473	2149	Economy	11600.00
0005433925417	2149	Economy	11600.00
0005433925481	2149	Economy	11600.00
0005433036909	2149	Economy	11600.00
0005432206324	24128	Business	34700.00
0005434028372	24128	Business	34700.00
0005433924584	24128	Business	34700.00
0005433924454	24128	Business	34700.00
0005433924603	24128	Business	34700.00
0005433924563	24128	Business	34700.00
0005433924587	24128	Business	34700.00
0005432206326	24128	Business	34700.00
0005433037467	24128	Business	34700.00
0005433931497	24128	Business	34700.00
0005433931506	24128	Business	34700.00
0005433924455	24128	Business	34700.00
0005433037469	24128	Business	34700.00
0005433924697	24128	Business	34700.00
0005433924474	24128	Business	34700.00
0005433924341	24128	Business	34700.00
0005433924810	24128	Business	34700.00
0005434028373	24128	Business	34700.00
0005433924799	24128	Business	34700.00
0005433037470	24128	Business	34700.00
0005433929677	24128	Business	34700.00
0005433037482	24128	Economy	12700.00
0005433923947	24128	Economy	12700.00
0005433875400	24128	Economy	12700.00
0005433924255	24128	Economy	11600.00
0005433037507	24128	Economy	11600.00
0005433924060	24128	Economy	11600.00
0005432749834	24128	Economy	11600.00
0005433924605	24128	Economy	11600.00
0005433924475	24128	Economy	11600.00
0005433037504	24128	Economy	11600.00
0005433037512	24128	Economy	11600.00
0005433037481	24128	Economy	11600.00
0005433924613	24128	Economy	11600.00
0005433931509	24128	Economy	11600.00
0005433924728	24128	Economy	11600.00
0005433924075	24128	Economy	11600.00
0005433037495	24128	Economy	11600.00
0005433924951	24128	Economy	11600.00
0005433924473	24128	Economy	11600.00
0005433924328	24128	Economy	11600.00
0005433037462	24128	Economy	11600.00
0005433925110	24128	Economy	11600.00
0005433037475	24128	Economy	11600.00
0005433037498	24128	Economy	11600.00
0005433924800	24128	Economy	11600.00
0005433037480	24128	Economy	11600.00
0005433924540	24128	Economy	11600.00
0005433037489	24128	Economy	11600.00
0005433037492	24128	Economy	11600.00
0005433037514	24128	Economy	11600.00
0005433924570	24128	Economy	11600.00
0005433037478	24128	Economy	11600.00
0005433037477	24128	Economy	11600.00
0005434028374	24128	Economy	11600.00
0005433924145	24128	Economy	11600.00
0005433924380	24128	Economy	11600.00
0005433924304	24128	Economy	11600.00
0005433931503	24128	Economy	11600.00
0005433924571	24128	Economy	11600.00
0005433924446	24128	Economy	11600.00
0005433037472	24128	Economy	11600.00
0005433037506	24128	Economy	11600.00
0005433924061	24128	Economy	11600.00
0005433037508	24128	Economy	11600.00
0005433929673	24128	Economy	11600.00
0005433924629	24128	Economy	11600.00
0005433924656	24128	Economy	11600.00
0005433924589	24128	Economy	11600.00
0005433929661	24128	Economy	11600.00
0005433924516	24128	Economy	11600.00
0005433929663	24128	Economy	11600.00
0005433037511	24128	Economy	11600.00
0005433924459	24128	Economy	11600.00
0005433924588	24128	Economy	11600.00
0005433924606	24128	Economy	11600.00
0005433037486	24128	Economy	11600.00
0005433037468	24128	Economy	11600.00
0005433924621	24128	Economy	11600.00
0005433924712	24128	Economy	11600.00
0005433037465	24128	Economy	11600.00
0005433037485	24128	Economy	11600.00
0005433037466	24128	Economy	11600.00
0005433924696	24128	Economy	11600.00
0005433924839	24128	Economy	11600.00
0005433931504	24128	Economy	11600.00
0005433924074	24128	Economy	11600.00
0005433037488	24128	Economy	11600.00
0005433924627	24128	Economy	11600.00
0005433037502	24128	Economy	11600.00
0005433037479	24128	Economy	11600.00
0005433924379	24128	Economy	11600.00
0005433037483	24128	Economy	11600.00
0005433037493	24128	Economy	11600.00
0005434028376	24128	Economy	11600.00
0005433924583	24128	Economy	11600.00
0005434028375	24128	Economy	11600.00
0005433037461	24128	Economy	11600.00
0005433037490	24128	Economy	11600.00
0005433924849	24128	Economy	11600.00
0005433037513	24128	Economy	11600.00
0005433924614	24128	Economy	11600.00
0005432206328	24128	Economy	11600.00
0005433924533	24128	Economy	11600.00
0005433037509	24128	Economy	11600.00
0005433924811	24128	Economy	11600.00
0005433924738	24128	Economy	11600.00
0005433925109	24128	Economy	12700.00
0005433037510	24128	Economy	12700.00
0005433924604	24128	Economy	11600.00
0005433875401	24128	Economy	11600.00
0005433924969	24128	Economy	12700.00
0005433924327	24128	Economy	12700.00
0005433924586	24128	Economy	11600.00
0005433037494	24128	Economy	11600.00
0005433924970	24128	Economy	11600.00
0005432206329	24128	Economy	11600.00
0005433037501	24128	Economy	11600.00
0005433037491	24128	Economy	11600.00
0005433923948	24128	Economy	11600.00
0005432207720	24128	Economy	11600.00
0005433924681	24128	Economy	11600.00
0005433037500	24128	Economy	11600.00
0005433931510	24128	Economy	11600.00
0005433037473	24128	Economy	11600.00
0005433924582	24128	Economy	11600.00
0005433924529	24128	Economy	11600.00
0005433924953	24128	Economy	11600.00
0005433924737	24128	Economy	11600.00
0005433924818	24128	Economy	11600.00
0005433924342	24128	Economy	11600.00
0005433037505	24128	Economy	11600.00
0005433037474	24128	Economy	11600.00
0005433037497	24128	Economy	11600.00
0005432207721	24128	Economy	11600.00
0005433037487	24128	Economy	11600.00
0005433924144	24128	Economy	11600.00
0005433931496	24128	Economy	11600.00
0005433924602	24128	Economy	11600.00
0005433924931	24128	Economy	11600.00
0005433924930	24128	Economy	11600.00
0005433037503	24128	Economy	11600.00
0005433924804	24128	Economy	11600.00
0005433037484	24128	Economy	11600.00
0005433037463	24128	Economy	11600.00
0005433924724	24128	Economy	11600.00
0005432749835	24128	Economy	11600.00
0005433924848	24128	Economy	11600.00
0005433924668	24128	Economy	11600.00
0005433929675	24128	Economy	11600.00
0005433924690	24128	Economy	11600.00
0005433924194	24128	Economy	11600.00
0005433037499	24128	Economy	11600.00
0005433924615	24128	Economy	11600.00
0005433037464	24128	Economy	11600.00
0005433924572	24128	Economy	11600.00
0005433924667	24128	Economy	11600.00
0005433924809	24128	Economy	11600.00
0005433924564	24128	Economy	11600.00
0005433924601	24128	Economy	11600.00
0005433925151	24128	Economy	11600.00
0005433924585	24128	Economy	11600.00
0005433924840	24128	Economy	11600.00
0005433931502	24128	Economy	11600.00
0005432206327	24128	Economy	11600.00
0005433924847	24128	Economy	11600.00
0005433924534	24128	Economy	11600.00
0005433924417	24128	Economy	11600.00
0005433037471	24128	Economy	11600.00
0005433924146	24128	Economy	11600.00
0005432206325	24128	Economy	11600.00
0005433037476	24128	Economy	11600.00
0005433924453	24128	Economy	11600.00
0005433037496	24128	Economy	11600.00
0005433235248	261	Business	83700.00
0005433234860	261	Business	83700.00
0005434728169	261	Business	83700.00
0005433766701	261	Business	83700.00
0005434728211	261	Business	83700.00
0005434552454	261	Business	83700.00
0005433235205	261	Business	83700.00
0005433181451	261	Business	83700.00
0005433131786	261	Business	83700.00
0005434728165	261	Business	83700.00
0005434728201	261	Business	83700.00
0005434728208	261	Business	83700.00
0005434735805	261	Business	83700.00
0005435142879	261	Business	83700.00
0005434728239	261	Business	83700.00
0005434728168	261	Business	83700.00
0005434728209	261	Business	83700.00
0005433235210	261	Business	83700.00
0005434552448	261	Business	83700.00
0005433113565	261	Business	83700.00
0005434302555	261	Business	83700.00
0005434728156	261	Business	83700.00
0005435142888	261	Business	83700.00
0005433289951	261	Business	83700.00
0005434728180	261	Business	83700.00
0005434552496	261	Business	83700.00
0005434728152	261	Comfort	47400.00
0005433234861	261	Comfort	47400.00
0005434302891	261	Comfort	47400.00
0005434728249	261	Comfort	47400.00
0005433234995	261	Comfort	47400.00
0005434552498	261	Comfort	47400.00
0005434552465	261	Comfort	47400.00
0005433234859	261	Comfort	47400.00
0005434552452	261	Comfort	47400.00
0005434728255	261	Comfort	47400.00
0005434728263	261	Comfort	47400.00
0005434728198	261	Comfort	47400.00
0005433289975	261	Comfort	47400.00
0005434728229	261	Comfort	47400.00
0005433111526	261	Comfort	47400.00
0005434552450	261	Comfort	47400.00
0005433235032	261	Comfort	47400.00
0005433235189	261	Comfort	47400.00
0005434552476	261	Comfort	47400.00
0005434728267	261	Comfort	47400.00
0005434728264	261	Comfort	47400.00
0005434728176	261	Comfort	47400.00
0005433235084	261	Comfort	47400.00
0005434552488	261	Comfort	47400.00
0005433289944	261	Comfort	47400.00
0005433113563	261	Comfort	47400.00
0005433235050	261	Comfort	47400.00
0005434552474	261	Comfort	47400.00
0005434728251	261	Comfort	47400.00
0005434552470	261	Comfort	47400.00
0005432278107	261	Comfort	47400.00
0005434728234	261	Comfort	47400.00
0005434552491	261	Comfort	47400.00
0005434552462	261	Comfort	47400.00
0005434552467	261	Comfort	47400.00
0005434731261	261	Comfort	47400.00
0005433235219	261	Comfort	47400.00
0005434728151	261	Comfort	47400.00
0005433235074	261	Comfort	47400.00
0005434552485	261	Comfort	47400.00
0005434728193	261	Economy	27900.00
0005434552479	261	Economy	27900.00
0005434728161	261	Economy	27900.00
0005434731262	261	Economy	27900.00
0005434552456	261	Economy	27900.00
0005435142878	261	Economy	27900.00
0005433235331	261	Economy	27900.00
0005434552445	261	Economy	27900.00
0005435142883	261	Economy	27900.00
0005433181383	261	Economy	27900.00
0005433234970	261	Economy	27900.00
0005433181484	261	Economy	27900.00
0005434032078	261	Economy	27900.00
0005434552490	261	Economy	27900.00
0005433289924	261	Economy	27900.00
0005434728147	261	Economy	27900.00
0005434728215	261	Economy	27900.00
0005433234967	261	Economy	27900.00
0005433234943	261	Economy	27900.00
0005434552486	261	Economy	27900.00
0005434552447	261	Economy	27900.00
0005434728187	261	Economy	27900.00
0005434552472	261	Economy	27900.00
0005433181522	261	Economy	27900.00
0005433235209	261	Economy	27900.00
0005434552469	261	Economy	27900.00
0005434728173	261	Economy	27900.00
0005434728153	261	Economy	27900.00
0005434728195	261	Economy	27900.00
0005434728254	261	Economy	27900.00
0005433234887	261	Economy	27900.00
0005433234969	261	Economy	27900.00
0005434552468	261	Economy	27900.00
0005434728238	261	Economy	27900.00
0005434552494	261	Economy	27900.00
0005433235085	261	Economy	27900.00
0005433235242	261	Economy	27900.00
0005434552495	261	Economy	27900.00
0005433181532	261	Economy	27900.00
0005433235391	261	Economy	27900.00
0005434728159	261	Economy	27900.00
0005433126911	261	Economy	27900.00
0005434728246	261	Economy	27900.00
0005435142877	261	Economy	27900.00
0005434728256	261	Economy	27900.00
0005433289976	261	Economy	27900.00
0005434728266	261	Economy	27900.00
0005432278115	261	Economy	27900.00
0005434728227	261	Economy	27900.00
0005434728182	261	Economy	27900.00
0005434552471	261	Economy	27900.00
0005434728214	261	Economy	27900.00
0005433181483	261	Economy	27900.00
0005434728164	261	Economy	27900.00
0005434728218	261	Economy	27900.00
0005434728157	261	Economy	27900.00
0005433235006	261	Economy	27900.00
0005434728160	261	Economy	27900.00
0005433234988	261	Economy	27900.00
0005434552473	261	Economy	27900.00
0005433126901	261	Economy	30700.00
0005433111523	261	Economy	30700.00
0005434728257	261	Economy	27900.00
0005433181450	261	Economy	30700.00
0005433181517	261	Economy	27900.00
0005433289935	261	Economy	30700.00
0005434552460	261	Economy	30700.00
0005434728213	261	Economy	27900.00
0005433131753	261	Economy	27900.00
0005434728242	261	Economy	27900.00
0005433181365	261	Economy	27900.00
0005434728163	261	Economy	27900.00
0005434728199	261	Economy	27900.00
0005434728260	261	Economy	27900.00
0005434728212	261	Economy	27900.00
0005434552475	261	Economy	27900.00
0005434552451	261	Economy	27900.00
0005434728148	261	Economy	27900.00
0005433235220	261	Economy	27900.00
0005433234898	261	Economy	27900.00
0005433113575	261	Economy	27900.00
0005434728224	261	Economy	27900.00
0005434728259	261	Economy	27900.00
0005432278108	261	Economy	27900.00
0005433235033	261	Economy	27900.00
0005433234831	261	Economy	27900.00
0005434728226	261	Economy	27900.00
0005433234960	261	Economy	27900.00
0005434735804	261	Economy	27900.00
0005434552493	261	Economy	27900.00
0005432278106	261	Economy	27900.00
0005435142882	261	Economy	27900.00
0005434728225	261	Economy	27900.00
0005434552444	261	Economy	27900.00
0005434728200	261	Economy	27900.00
0005434302559	261	Economy	27900.00
0005435142885	261	Economy	27900.00
0005434735801	261	Economy	27900.00
0005434728222	261	Economy	27900.00
0005434728170	261	Economy	27900.00
0005432278109	261	Economy	27900.00
0005434302557	261	Economy	27900.00
0005433111521	261	Economy	27900.00
0005433235123	261	Economy	27900.00
0005434552458	261	Economy	27900.00
0005433111522	261	Economy	27900.00
0005434552478	261	Economy	27900.00
0005433235174	261	Economy	27900.00
0005434728192	261	Economy	27900.00
0005433234978	261	Economy	27900.00
0005434728191	261	Economy	27900.00
0005433234992	261	Economy	27900.00
0005434728253	261	Economy	27900.00
0005434728181	261	Economy	27900.00
0005433234922	261	Economy	27900.00
0005434728223	261	Economy	27900.00
0005434728231	261	Economy	27900.00
0005434728158	261	Economy	27900.00
0005433181523	261	Economy	27900.00
0005433235214	261	Economy	27900.00
0005434728235	261	Economy	27900.00
0005433234989	261	Economy	27900.00
0005434552489	261	Economy	27900.00
0005433181320	261	Economy	27900.00
0005433234993	261	Economy	27900.00
0005434728175	261	Economy	27900.00
0005434728252	261	Economy	27900.00
0005432278112	261	Economy	27900.00
0005434032073	261	Economy	27900.00
0005433181438	261	Economy	27900.00
0005434728155	261	Economy	27900.00
0005434552449	261	Economy	27900.00
0005434728237	261	Economy	27900.00
0005434552453	261	Economy	27900.00
0005434728185	261	Economy	27900.00
0005434552480	261	Economy	27900.00
0005434728171	261	Economy	27900.00
0005434728216	261	Economy	27900.00
0005434728230	261	Economy	27900.00
0005435142886	261	Economy	27900.00
0005432278116	261	Economy	27900.00
0005433235060	261	Economy	27900.00
0005434728206	261	Economy	27900.00
0005433234966	261	Economy	27900.00
0005434728172	261	Economy	27900.00
0005434728265	261	Economy	27900.00
0005434728188	261	Economy	27900.00
0005434728203	261	Economy	27900.00
0005434728261	261	Economy	27900.00
0005434728250	261	Economy	27900.00
0005434728240	261	Economy	27900.00
0005433235314	261	Economy	27900.00
0005434728232	261	Economy	27900.00
0005434728220	261	Economy	27900.00
0005434728205	261	Economy	27900.00
0005434032074	261	Economy	27900.00
0005434032079	261	Economy	27900.00
0005434728166	261	Economy	27900.00
0005434728258	261	Economy	27900.00
0005434728174	261	Economy	30700.00
0005434728167	261	Economy	30700.00
0005432278117	261	Economy	30700.00
0005434731260	261	Economy	30700.00
0005434735806	261	Economy	30700.00
0005434731263	261	Economy	27900.00
0005435142889	261	Economy	30700.00
0005434728221	261	Economy	27900.00
0005433235263	261	Economy	27900.00
0005433235313	261	Economy	27900.00
0005434735802	261	Economy	27900.00
0005434552477	261	Economy	27900.00
0005434728183	261	Economy	27900.00
0005434728204	261	Economy	27900.00
0005433235330	261	Economy	27900.00
0005434552466	261	Economy	27900.00
0005433235206	261	Economy	27900.00
0005434728194	261	Economy	27900.00
0005433766700	261	Economy	27900.00
0005434728184	261	Economy	27900.00
0005434552484	261	Economy	27900.00
0005433235132	261	Economy	27900.00
0005433234767	261	Economy	27900.00
0005434728247	261	Economy	27900.00
0005435142876	261	Economy	27900.00
0005434728202	261	Economy	27900.00
0005434728262	261	Economy	27900.00
0005433235392	261	Economy	27900.00
0005433289952	261	Economy	27900.00
0005434552455	261	Economy	27900.00
0005434728177	261	Economy	27900.00
0005434728228	261	Economy	27900.00
0005434552443	261	Economy	27900.00
0005434728219	261	Economy	27900.00
0005432278111	261	Economy	27900.00
0005433235133	261	Economy	27900.00
0005434728149	261	Economy	27900.00
0005434728189	261	Economy	27900.00
0005433235249	261	Economy	27900.00
0005434728245	261	Economy	27900.00
0005434552497	261	Economy	27900.00
0005432278114	261	Economy	27900.00
0005434728178	261	Economy	27900.00
0005433181469	261	Economy	27900.00
0005435142890	261	Economy	27900.00
0005432278118	261	Economy	27900.00
0005433181516	261	Economy	27900.00
0005434728146	261	Economy	27900.00
0005433289933	261	Economy	27900.00
0005434552481	261	Economy	27900.00
0005434728248	261	Economy	27900.00
0005434552457	261	Economy	27900.00
0005434728197	261	Economy	27900.00
0005434728154	261	Economy	27900.00
0005435142884	261	Economy	27900.00
0005434552446	261	Economy	27900.00
0005434728244	261	Economy	27900.00
0005435142880	261	Economy	27900.00
0005432278110	261	Economy	27900.00
0005433181436	261	Economy	27900.00
0005433235146	261	Economy	27900.00
0005434728196	261	Economy	27900.00
0005433234984	261	Economy	27900.00
0005432278113	261	Economy	27900.00
0005434302558	261	Economy	27900.00
0005433234766	261	Economy	27900.00
0005434728179	261	Economy	27900.00
0005433235184	261	Economy	27900.00
0005434302556	261	Economy	27900.00
0005433235134	261	Economy	27900.00
0005433126912	261	Economy	27900.00
0005434728190	261	Economy	27900.00
0005434728243	261	Economy	27900.00
0005434728210	261	Economy	27900.00
0005434728233	261	Economy	27900.00
0005434728186	261	Economy	27900.00
0005434728236	261	Economy	27900.00
0005435142881	261	Economy	27900.00
0005434552487	261	Economy	27900.00
0005434552492	261	Economy	27900.00
0005434728162	261	Economy	27900.00
0005434728145	261	Economy	27900.00
0005435142887	261	Economy	27900.00
0005434735803	261	Economy	27900.00
0005433234944	261	Economy	27900.00
0005434731264	261	Economy	27900.00
0005434552482	261	Economy	27900.00
0005434728217	261	Economy	27900.00
0005434728150	261	Economy	27900.00
0005434032077	261	Economy	27900.00
0005434552483	261	Economy	27900.00
0005434728241	261	Economy	27900.00
0005434552464	261	Economy	27900.00
0005434552461	261	Economy	27900.00
0005434728207	261	Economy	27900.00
0005434552459	261	Economy	27900.00
0005434552463	261	Economy	27900.00
0005433235318	261	Economy	27900.00
0005433235640	9855	Business	83700.00
0005433766725	9855	Business	83700.00
0005434551770	9855	Business	83700.00
0005433235602	9855	Business	83700.00
0005434731216	9855	Business	83700.00
0005434727635	9855	Business	83700.00
0005434727019	9855	Business	83700.00
0005433235594	9855	Business	83700.00
0005434726879	9855	Business	83700.00
0005433235630	9855	Business	83700.00
0005434551797	9855	Business	83700.00
0005434727339	9855	Business	83700.00
0005433766724	9855	Business	83700.00
0005432199409	9855	Business	83700.00
0005433235651	9855	Business	83700.00
0005434552032	9855	Business	83700.00
0005434726845	9855	Business	83700.00
0005434552048	9855	Business	83700.00
0005434727558	9855	Business	83700.00
0005434727468	9855	Business	83700.00
0005434727143	9855	Business	83700.00
0005434551769	9855	Business	83700.00
0005433235620	9855	Business	83700.00
0005434727149	9855	Business	83700.00
0005434731223	9855	Business	83700.00
0005434726726	9855	Business	83700.00
0005434727104	9855	Comfort	47400.00
0005434032129	9855	Business	83700.00
0005434727415	9855	Comfort	47400.00
0005433235597	9855	Comfort	47400.00
0005433235606	9855	Comfort	47400.00
0005433235647	9855	Comfort	47400.00
0005434727163	9855	Comfort	47400.00
0005434727341	9855	Comfort	47400.00
0005433235643	9855	Comfort	47400.00
0005433181680	9855	Comfort	47400.00
0005433181669	9855	Comfort	47400.00
0005434726576	9855	Comfort	47400.00
0005434551981	9855	Comfort	47400.00
0005433235642	9855	Comfort	47400.00
0005433113586	9855	Comfort	47400.00
0005434727175	9855	Comfort	47400.00
0005434726859	9855	Comfort	47400.00
0005434727226	9855	Comfort	47400.00
0005433181657	9855	Comfort	47400.00
0005434727048	9855	Comfort	47400.00
0005433235592	9855	Comfort	47400.00
0005434727416	9855	Comfort	47400.00
0005433235631	9855	Comfort	47400.00
0005434727276	9855	Comfort	47400.00
0005434727262	9855	Comfort	47400.00
0005434726550	9855	Comfort	47400.00
0005434727559	9855	Comfort	47400.00
0005433235611	9855	Comfort	47400.00
0005434727414	9855	Comfort	47400.00
0005433235622	9855	Comfort	47400.00
0005434727305	9855	Comfort	47400.00
0005434727176	9855	Comfort	47400.00
0005433290011	9855	Comfort	47400.00
0005433235605	9855	Comfort	47400.00
0005434727128	9855	Economy	27900.00
0005434727129	9855	Economy	27900.00
0005434727325	9855	Economy	27900.00
0005433235617	9855	Economy	27900.00
0005433235633	9855	Economy	27900.00
0005434726838	9855	Economy	27900.00
0005434727345	9855	Economy	27900.00
0005433290013	9855	Economy	27900.00
0005434551843	9855	Economy	27900.00
0005434727270	9855	Economy	27900.00
0005433181681	9855	Economy	27900.00
0005434727000	9855	Economy	27900.00
0005434727083	9855	Economy	27900.00
0005435142774	9855	Economy	27900.00
0005434727010	9855	Economy	27900.00
0005433235653	9855	Economy	27900.00
0005434552065	9855	Economy	27900.00
0005434726974	9855	Economy	27900.00
0005434726814	9855	Economy	27900.00
0005434551874	9855	Economy	27900.00
0005434726715	9855	Economy	27900.00
0005433235604	9855	Economy	27900.00
0005434727708	9855	Economy	27900.00
0005434551679	9855	Economy	27900.00
0005435142770	9855	Economy	27900.00
0005434727214	9855	Economy	27900.00
0005433235619	9855	Economy	27900.00
0005434726947	9855	Economy	27900.00
0005434726989	9855	Economy	27900.00
0005432199408	9855	Economy	27900.00
0005433235627	9855	Economy	27900.00
0005434551992	9855	Economy	27900.00
0005433235618	9855	Economy	27900.00
0005434726973	9855	Economy	27900.00
0005434727015	9855	Economy	27900.00
0005433235599	9855	Economy	27900.00
0005433235639	9855	Economy	27900.00
0005433235621	9855	Economy	27900.00
0005434727419	9855	Economy	27900.00
0005433235596	9855	Economy	27900.00
0005434552099	9855	Economy	27900.00
0005434726988	9855	Economy	27900.00
0005434032130	9855	Economy	27900.00
0005434727326	9855	Economy	27900.00
0005434727031	9855	Economy	27900.00
0005434727239	9855	Economy	27900.00
0005434727138	9855	Economy	27900.00
0005433126948	9855	Economy	27900.00
0005434727216	9855	Economy	27900.00
0005434302510	9855	Economy	27900.00
0005434727227	9855	Economy	27900.00
0005433235646	9855	Economy	27900.00
0005434726808	9855	Economy	27900.00
0005434727291	9855	Economy	27900.00
0005434726987	9855	Economy	27900.00
0005434727248	9855	Economy	27900.00
0005434727455	9855	Economy	27900.00
0005432199405	9855	Economy	30700.00
0005433235650	9855	Economy	30700.00
0005433235655	9855	Economy	30700.00
0005433181659	9855	Economy	27900.00
0005434726342	9855	Economy	27900.00
0005434551990	9855	Economy	27900.00
0005434727169	9855	Economy	27900.00
0005434726977	9855	Economy	30700.00
0005434032131	9855	Economy	27900.00
0005433235601	9855	Economy	30700.00
0005434726535	9855	Economy	27900.00
0005433235607	9855	Economy	27900.00
0005434727012	9855	Economy	27900.00
0005434727709	9855	Economy	27900.00
0005433235644	9855	Economy	27900.00
0005434552038	9855	Economy	27900.00
0005434727159	9855	Economy	27900.00
0005434551965	9855	Economy	27900.00
0005433181662	9855	Economy	27900.00
0005433126949	9855	Economy	27900.00
0005434726549	9855	Economy	27900.00
0005433126951	9855	Economy	27900.00
0005433235632	9855	Economy	27900.00
0005434727274	9855	Economy	27900.00
0005433181658	9855	Economy	27900.00
0005434032128	9855	Economy	27900.00
0005434302516	9855	Economy	27900.00
0005434551900	9855	Economy	27900.00
0005432199407	9855	Economy	27900.00
0005433181667	9855	Economy	27900.00
0005434727496	9855	Economy	27900.00
0005433235654	9855	Economy	27900.00
0005434552040	9855	Economy	27900.00
0005434727304	9855	Economy	27900.00
0005433181674	9855	Economy	27900.00
0005434727139	9855	Economy	27900.00
0005433235608	9855	Economy	27900.00
0005434726727	9855	Economy	27900.00
0005433181665	9855	Economy	27900.00
0005434727411	9855	Economy	27900.00
0005433235595	9855	Economy	27900.00
0005434727051	9855	Economy	27900.00
0005433181673	9855	Economy	27900.00
0005434727160	9855	Economy	27900.00
0005434552098	9855	Economy	27900.00
0005433181679	9855	Economy	27900.00
0005434727275	9855	Economy	27900.00
0005433235652	9855	Economy	27900.00
0005434552116	9855	Economy	27900.00
0005435142771	9855	Economy	27900.00
0005435142700	9855	Economy	27900.00
0005435142765	9855	Economy	27900.00
0005434731217	9855	Economy	27900.00
0005434302511	9855	Economy	27900.00
0005433126946	9855	Economy	27900.00
0005434726648	9855	Economy	27900.00
0005433235598	9855	Economy	27900.00
0005433181656	9855	Economy	27900.00
0005433181671	9855	Economy	27900.00
0005435142745	9855	Economy	27900.00
0005434551920	9855	Economy	27900.00
0005433290012	9855	Economy	27900.00
0005433129378	9855	Economy	27900.00
0005434551844	9855	Economy	27900.00
0005435142746	9855	Economy	27900.00
0005434727469	9855	Economy	27900.00
0005434726649	9855	Economy	27900.00
0005434726575	9855	Economy	27900.00
0005433181677	9855	Economy	27900.00
0005434551678	9855	Economy	27900.00
0005434551989	9855	Economy	27900.00
0005434726948	9855	Economy	27900.00
0005434551901	9855	Economy	27900.00
0005433235649	9855	Economy	27900.00
0005433181670	9855	Economy	27900.00
0005433235609	9855	Economy	27900.00
0005435142722	9855	Economy	27900.00
0005433129380	9855	Economy	27900.00
0005434727014	9855	Economy	27900.00
0005434731237	9855	Economy	27900.00
0005434727011	9855	Economy	27900.00
0005433766726	9855	Economy	27900.00
0005434727393	9855	Economy	27900.00
0005433235603	9855	Economy	27900.00
0005434727148	9855	Economy	27900.00
0005433235626	9855	Economy	27900.00
0005433235612	9855	Economy	27900.00
0005435142769	9855	Economy	27900.00
0005435142740	9855	Economy	27900.00
0005434726741	9855	Economy	27900.00
0005434727233	9855	Economy	27900.00
0005434731215	9855	Economy	27900.00
0005433235593	9855	Economy	27900.00
0005434551872	9855	Economy	27900.00
0005435142760	9855	Economy	27900.00
0005433235625	9855	Economy	27900.00
0005433290008	9855	Economy	27900.00
0005433290007	9855	Economy	27900.00
0005435142679	9855	Economy	27900.00
0005434551884	9855	Economy	27900.00
0005434727365	9855	Economy	27900.00
0005434551740	9855	Economy	27900.00
0005434727150	9855	Economy	27900.00
0005432199402	9855	Economy	27900.00
0005433129381	9855	Economy	27900.00
0005434727201	9855	Economy	27900.00
0005434551902	9855	Economy	27900.00
0005433181663	9855	Economy	27900.00
0005433235623	9855	Economy	27900.00
0005434552039	9855	Economy	30700.00
0005432199404	9855	Economy	30700.00
0005434727097	9855	Economy	27900.00
0005433181672	9855	Economy	27900.00
0005433235638	9855	Economy	27900.00
0005433235637	9855	Economy	27900.00
0005434726815	9855	Economy	27900.00
0005434726647	9855	Economy	27900.00
0005433290010	9855	Economy	27900.00
0005433181661	9855	Economy	27900.00
0005433766727	9855	Economy	27900.00
0005434727822	9855	Economy	27900.00
0005434551895	9855	Economy	27900.00
0005433235641	9855	Economy	27900.00
0005432199403	9855	Economy	27900.00
0005434731222	9855	Economy	27900.00
0005433181675	9855	Economy	27900.00
0005433181668	9855	Economy	27900.00
0005435142768	9855	Economy	27900.00
0005434726754	9855	Economy	27900.00
0005433290009	9855	Economy	27900.00
0005434551834	9855	Economy	27900.00
0005433290006	9855	Economy	27900.00
0005435142790	9855	Economy	27900.00
0005435142780	9855	Economy	27900.00
0005434551798	9855	Economy	27900.00
0005434727269	9855	Economy	27900.00
0005434727047	9855	Economy	27900.00
0005434726978	9855	Economy	27900.00
0005433235645	9855	Economy	27900.00
0005434726755	9855	Economy	27900.00
0005433181664	9855	Economy	27900.00
0005434551845	9855	Economy	27900.00
0005434552010	9855	Economy	27900.00
0005434726676	9855	Economy	27900.00
0005433235636	9855	Economy	27900.00
0005433235600	9855	Economy	27900.00
0005433235634	9855	Economy	27900.00
0005434727205	9855	Economy	27900.00
0005435142723	9855	Economy	27900.00
0005434552029	9855	Economy	27900.00
0005434727221	9855	Economy	27900.00
0005434551947	9855	Economy	27900.00
0005434727634	9855	Economy	27900.00
0005432199406	9855	Economy	27900.00
0005434551833	9855	Economy	27900.00
0005434726846	9855	Economy	27900.00
0005434727029	9855	Economy	27900.00
0005435142734	9855	Economy	27900.00
0005433235613	9855	Economy	27900.00
0005433235629	9855	Economy	27900.00
0005434727142	9855	Economy	27900.00
0005434551873	9855	Economy	27900.00
0005433235614	9855	Economy	27900.00
0005434032127	9855	Economy	27900.00
0005433129379	9855	Economy	27900.00
0005434551983	9855	Economy	27900.00
0005434551966	9855	Economy	27900.00
0005434551838	9855	Economy	27900.00
0005434727032	9855	Economy	27900.00
0005434726807	9855	Economy	27900.00
0005433235615	9855	Economy	27900.00
0005434726984	9855	Economy	27900.00
0005433181660	9855	Economy	27900.00
0005433181666	9855	Economy	27900.00
0005433235635	9855	Economy	27900.00
0005434727277	9855	Economy	27900.00
0005434551625	9855	Economy	27900.00
0005433181676	9855	Economy	27900.00
0005434552031	9855	Economy	27900.00
0005434726643	9855	Economy	27900.00
0005434727636	9855	Economy	27900.00
0005434727514	9855	Economy	27900.00
0005433235610	9855	Economy	27900.00
0005434727293	9855	Economy	27900.00
0005433129377	9855	Economy	27900.00
0005434552066	9855	Economy	27900.00
0005434727103	9855	Economy	27900.00
0005433235628	9855	Economy	27900.00
0005434551832	9855	Economy	27900.00
0005433126947	9855	Economy	27900.00
0005434551984	9855	Economy	27900.00
0005434727043	9855	Economy	27900.00
0005433235616	9855	Economy	27900.00
0005434727030	9855	Economy	27900.00
0005433235624	9855	Economy	27900.00
0005434727467	9855	Economy	27900.00
0005433235648	9855	Economy	27900.00
0005433181678	9855	Economy	27900.00
0005433181682	9855	Economy	27900.00
0005434551967	9855	Economy	27900.00
0005433126950	9855	Economy	27900.00
0005434551837	9855	Economy	27900.00
0005432530942	7757	Business	42100.00
0005432530949	7757	Business	42100.00
0005432530972	7757	Business	42100.00
0005432530970	7757	Business	42100.00
0005434069136	7757	Business	42100.00
0005434069198	7757	Business	42100.00
0005434069191	7757	Business	42100.00
0005433656716	7757	Business	42100.00
0005434069192	7757	Business	42100.00
0005432530894	7757	Business	42100.00
0005434069138	7757	Business	42100.00
0005432150375	7757	Business	42100.00
0005435214589	7757	Business	42100.00
0005432150374	7757	Business	42100.00
0005434069130	7757	Business	42100.00
0005432530983	7757	Business	42100.00
0005432069978	7757	Business	42100.00
0005432530880	7757	Business	42100.00
0005432530963	7757	Business	42100.00
0005432530953	7757	Business	42100.00
0005432530896	7757	Business	42100.00
0005432530882	7757	Business	42100.00
0005435214530	7757	Business	42100.00
0005432530968	7757	Business	42100.00
0005432530884	7757	Comfort	23900.00
0005432530977	7757	Comfort	23900.00
0005434069173	7757	Comfort	23900.00
0005432530936	7757	Comfort	23900.00
0005435214416	7757	Comfort	23900.00
0005432150370	7757	Comfort	23900.00
0005435214495	7757	Comfort	23900.00
0005435631004	7757	Comfort	23900.00
0005434069140	7757	Comfort	23900.00
0005434069153	7757	Comfort	23900.00
0005435214776	7757	Comfort	23900.00
0005432530959	7757	Comfort	23900.00
0005432530986	7757	Comfort	23900.00
0005432069981	7757	Comfort	23900.00
0005432530927	7757	Comfort	23900.00
0005432530897	7757	Comfort	23900.00
0005434069145	7757	Comfort	23900.00
0005432069985	7757	Comfort	23900.00
0005435214480	7757	Comfort	23900.00
0005432535943	7757	Comfort	23900.00
0005435214277	7757	Comfort	23900.00
0005434069163	7757	Comfort	23900.00
0005432069975	7757	Comfort	23900.00
0005434069137	7757	Comfort	23900.00
0005434069149	7757	Comfort	23900.00
0005432530895	7757	Comfort	23900.00
0005432530899	7757	Comfort	23900.00
0005432530980	7757	Comfort	23900.00
0005435214630	7757	Comfort	23900.00
0005435214745	7757	Comfort	23900.00
0005434069164	7757	Comfort	23900.00
0005435631005	7757	Comfort	23900.00
0005435214660	7757	Comfort	23900.00
0005432429007	7757	Comfort	23900.00
0005432530876	7757	Comfort	23900.00
0005435214469	7757	Economy	14000.00
0005435214629	7757	Economy	14000.00
0005435631000	7757	Economy	14000.00
0005432530885	7757	Economy	14000.00
0005432069987	7757	Economy	14000.00
0005432530932	7757	Economy	14000.00
0005432530985	7757	Economy	14000.00
0005435214431	7757	Economy	14000.00
0005432530990	7757	Economy	14000.00
0005432530892	7757	Economy	14000.00
0005432535946	7757	Economy	14000.00
0005432530994	7757	Economy	14000.00
0005434069156	7757	Economy	14000.00
0005432530870	7757	Economy	14000.00
0005432530914	7757	Economy	14000.00
0005435214459	7757	Economy	14000.00
0005435214594	7757	Economy	14000.00
0005434069175	7757	Economy	14000.00
0005434069195	7757	Economy	14000.00
0005432530952	7757	Economy	14000.00
0005434069157	7757	Economy	14000.00
0005435214156	7757	Economy	14000.00
0005432530996	7757	Economy	14000.00
0005432530995	7757	Economy	14000.00
0005434069128	7757	Economy	14000.00
0005432530926	7757	Economy	14000.00
0005432069982	7757	Economy	14000.00
0005435214329	7757	Economy	14000.00
0005435214247	7757	Economy	14000.00
0005432530866	7757	Economy	14000.00
0005434069194	7757	Economy	14000.00
0005435214276	7757	Economy	14000.00
0005434069129	7757	Economy	14000.00
0005432533356	7757	Economy	14000.00
0005432530889	7757	Economy	14000.00
0005432530913	7757	Economy	14000.00
0005432530900	7757	Economy	14000.00
0005435214587	7757	Economy	14000.00
0005435214680	7757	Economy	14000.00
0005434069185	7757	Economy	14000.00
0005432530922	7757	Economy	14000.00
0005432530903	7757	Economy	14000.00
0005434069148	7757	Economy	14000.00
0005432530917	7757	Economy	14000.00
0005435214432	7757	Economy	14000.00
0005432530883	7757	Economy	14000.00
0005434069134	7757	Economy	14000.00
0005432530991	7757	Economy	14000.00
0005432530951	7757	Economy	14000.00
0005432530938	7757	Economy	14000.00
0005432530973	7757	Economy	14000.00
0005432530987	7757	Economy	14000.00
0005432530874	7757	Economy	14000.00
0005432530906	7757	Economy	14000.00
0005434069155	7757	Economy	14000.00
0005434069197	7757	Economy	14000.00
0005434069171	7757	Economy	14000.00
0005432530920	7757	Economy	14000.00
0005432530962	7757	Economy	15400.00
0005432530950	7757	Economy	14000.00
0005434069154	7757	Economy	15400.00
0005435214531	7757	Economy	14000.00
0005432530877	7757	Economy	14000.00
0005435214463	7757	Economy	15400.00
0005432069984	7757	Economy	15400.00
0005434069174	7757	Economy	14000.00
0005435214588	7757	Economy	14000.00
0005435214550	7757	Economy	14000.00
0005434069165	7757	Economy	14000.00
0005432530911	7757	Economy	14000.00
0005435214442	7757	Economy	14000.00
0005432530928	7757	Economy	14000.00
0005432530935	7757	Economy	14000.00
0005434069169	7757	Economy	14000.00
0005432069976	7757	Economy	14000.00
0005434069180	7757	Economy	14000.00
0005434069131	7757	Economy	14000.00
0005432150369	7757	Economy	14000.00
0005435214280	7757	Economy	14000.00
0005432069986	7757	Economy	14000.00
0005434069168	7757	Economy	14000.00
0005432530909	7757	Economy	14000.00
0005434069178	7757	Economy	14000.00
0005432530898	7757	Economy	14000.00
0005432530871	7757	Economy	14000.00
0005432530907	7757	Economy	14000.00
0005432530957	7757	Economy	14000.00
0005434069151	7757	Economy	14000.00
0005432429005	7757	Economy	14000.00
0005435214403	7757	Economy	14000.00
0005435214536	7757	Economy	14000.00
0005432530976	7757	Economy	14000.00
0005432150372	7757	Economy	14000.00
0005432530979	7757	Economy	14000.00
0005432530933	7757	Economy	14000.00
0005432150373	7757	Economy	14000.00
0005432530978	7757	Economy	14000.00
0005435214549	7757	Economy	14000.00
0005435214347	7757	Economy	14000.00
0005432530971	7757	Economy	14000.00
0005432429008	7757	Economy	14000.00
0005435214465	7757	Economy	14000.00
0005434069183	7757	Economy	14000.00
0005435214593	7757	Economy	14000.00
0005432530943	7757	Economy	14000.00
0005432530997	7757	Economy	14000.00
0005434069161	7757	Economy	14000.00
0005434069181	7757	Economy	14000.00
0005434069189	7757	Economy	14000.00
0005432530989	7757	Economy	14000.00
0005432530939	7757	Economy	14000.00
0005433656709	7757	Economy	14000.00
0005432530940	7757	Economy	14000.00
0005434069170	7757	Economy	14000.00
0005435214724	7757	Economy	14000.00
0005434069150	7757	Economy	14000.00
0005432530984	7757	Economy	14000.00
0005432530919	7757	Economy	14000.00
0005432530924	7757	Economy	14000.00
0005432429004	7757	Economy	14000.00
0005432530867	7757	Economy	14000.00
0005432530893	7757	Economy	14000.00
0005432150371	7757	Economy	14000.00
0005434069135	7757	Economy	14000.00
0005432533357	7757	Economy	14000.00
0005434069160	7757	Economy	14000.00
0005434069152	7757	Economy	14000.00
0005435725662	7757	Economy	14000.00
0005434069142	7757	Economy	14000.00
0005432530908	7757	Economy	14000.00
0005434069133	7757	Economy	14000.00
0005432530901	7757	Economy	14000.00
0005432150368	7757	Economy	14000.00
0005435214647	7757	Economy	14000.00
0005432530869	7757	Economy	14000.00
0005432530967	7757	Economy	14000.00
0005435214142	7757	Economy	14000.00
0005434069139	7757	Economy	14000.00
0005435725689	7757	Economy	14000.00
0005435214271	7757	Economy	14000.00
0005432537106	7757	Economy	14000.00
0005434069177	7757	Economy	14000.00
0005434069167	7757	Economy	14000.00
0005432530912	7757	Economy	14000.00
0005432530916	7757	Economy	14000.00
0005432530881	7757	Economy	14000.00
0005435214522	7757	Economy	14000.00
0005432530890	7757	Economy	14000.00
0005432530969	7757	Economy	14000.00
0005435725675	7757	Economy	14000.00
0005435214470	7757	Economy	14000.00
0005434069146	7757	Economy	14000.00
0005432530872	7757	Economy	14000.00
0005435214575	7757	Economy	14000.00
0005434069143	7757	Economy	14000.00
0005432537107	7757	Economy	14000.00
0005432530879	7757	Economy	14000.00
0005435214402	7757	Economy	14000.00
0005435214614	7757	Economy	14000.00
0005432530918	7757	Economy	14000.00
0005432530878	7757	Economy	14000.00
0005435214454	7757	Economy	14000.00
0005432537105	7757	Economy	14000.00
0005434069144	7757	Economy	14000.00
0005432069979	7757	Economy	14000.00
0005435214256	7757	Economy	14000.00
0005432530975	7757	Economy	15400.00
0005434069166	7757	Economy	15400.00
0005435214281	7757	Economy	15400.00
0005432069983	7757	Economy	15400.00
0005432530923	7757	Economy	14000.00
0005432069988	7757	Economy	14000.00
0005434069188	7757	Economy	14000.00
0005435214569	7757	Economy	14000.00
0005432530948	7757	Economy	14000.00
0005432530965	7757	Economy	14000.00
0005434069179	7757	Economy	14000.00
0005434069200	7757	Economy	14000.00
0005432530891	7757	Economy	14000.00
0005434069190	7757	Economy	14000.00
0005435214342	7757	Economy	14000.00
0005432530945	7757	Economy	14000.00
0005435214661	7757	Economy	14000.00
0005434069186	7757	Economy	14000.00
0005432530915	7757	Economy	14000.00
0005432530875	7757	Economy	14000.00
0005435214250	7757	Economy	14000.00
0005432530921	7757	Economy	14000.00
0005432530947	7757	Economy	14000.00
0005435214300	7757	Economy	14000.00
0005432530944	7757	Economy	14000.00
0005435214155	7757	Economy	14000.00
0005432530964	7757	Economy	14000.00
0005432530934	7757	Economy	14000.00
0005435214430	7757	Economy	14000.00
0005432535944	7757	Economy	14000.00
0005432530865	7757	Economy	14000.00
0005435631010	7757	Economy	14000.00
0005435214452	7757	Economy	14000.00
0005432530910	7757	Economy	14000.00
0005432069980	7757	Economy	14000.00
0005432530925	7757	Economy	14000.00
0005432530902	7757	Economy	14000.00
0005435214328	7757	Economy	14000.00
0005432429006	7757	Economy	14000.00
0005432530982	7757	Economy	14000.00
0005432530929	7757	Economy	14000.00
0005435214540	7757	Economy	14000.00
0005435214257	7757	Economy	14000.00
0005435214455	7757	Economy	14000.00
0005434069187	7757	Economy	14000.00
0005432530886	7757	Economy	14000.00
0005432530988	7757	Economy	14000.00
0005432530961	7757	Economy	14000.00
0005434069172	7757	Economy	14000.00
0005435631001	7757	Economy	14000.00
0005432530974	7757	Economy	14000.00
0005435214539	7757	Economy	14000.00
0005434069193	7757	Economy	14000.00
0005432530873	7757	Economy	14000.00
0005434069199	7757	Economy	14000.00
0005432530868	7757	Economy	14000.00
0005432530966	7757	Economy	14000.00
0005432069989	7757	Economy	14000.00
0005432530905	7757	Economy	14000.00
0005432530954	7757	Economy	14000.00
0005434069147	7757	Economy	14000.00
0005432530888	7757	Economy	14000.00
0005434069196	7757	Economy	14000.00
0005432530958	7757	Economy	14000.00
0005432530992	7757	Economy	14000.00
0005432530946	7757	Economy	14000.00
0005434069184	7757	Economy	14000.00
0005432530887	7757	Economy	14000.00
0005432069977	7757	Economy	14000.00
0005432530930	7757	Economy	14000.00
0005434069132	7757	Economy	14000.00
0005434069162	7757	Economy	14000.00
0005432530955	7757	Economy	14000.00
0005435214537	7757	Economy	14000.00
0005432530904	7757	Economy	14000.00
0005432530993	7757	Economy	14000.00
0005432535945	7757	Economy	14000.00
0005432530956	7757	Economy	14000.00
0005434069158	7757	Economy	14000.00
0005432530931	7757	Economy	14000.00
0005434069159	7757	Economy	14000.00
0005432530981	7757	Economy	14000.00
0005432530937	7757	Economy	14000.00
0005434069182	7757	Economy	14000.00
0005435214516	7757	Economy	14000.00
0005434069176	7757	Economy	14000.00
0005435214471	7757	Economy	14000.00
0005432530941	7757	Economy	14000.00
0005432530960	7757	Economy	14000.00
0005434069141	7757	Economy	14000.00
0005434345038	5330	Business	43100.00
0005434245409	5330	Business	43100.00
0005434245379	5330	Business	43100.00
0005435425545	5330	Business	43100.00
0005435425988	5330	Business	43100.00
0005435616195	5330	Business	43100.00
0005435616154	5330	Business	43100.00
0005434345010	5330	Business	43100.00
0005434345033	5330	Business	43100.00
0005435616167	5330	Business	43100.00
0005435616188	5330	Business	43100.00
0005435097429	5330	Business	43100.00
0005434245566	5330	Business	43100.00
0005435616258	5330	Business	43100.00
0005434345011	5330	Business	43100.00
0005432133550	5330	Business	43100.00
0005435426064	5330	Business	43100.00
0005435425853	5330	Business	43100.00
0005435616179	5330	Business	43100.00
0005435616255	5330	Business	43100.00
0005434345030	5330	Business	43100.00
0005434345008	5330	Business	43100.00
0005435616174	5330	Business	43100.00
0005435616249	5330	Business	43100.00
0005435616159	5330	Business	43100.00
0005432133554	5330	Business	43100.00
0005435616208	5330	Business	43100.00
0005435616213	5330	Comfort	24400.00
0005435490310	5330	Comfort	24400.00
0005435616194	5330	Comfort	24400.00
0005435616256	5330	Comfort	24400.00
0005435616252	5330	Comfort	24400.00
0005435426044	5330	Comfort	24400.00
0005435616224	5330	Comfort	24400.00
0005435616157	5330	Comfort	24400.00
0005435616246	5330	Comfort	24400.00
0005435425986	5330	Comfort	24400.00
0005435616166	5330	Comfort	24400.00
0005435616262	5330	Comfort	24400.00
0005435319703	5330	Comfort	24400.00
0005434345035	5330	Comfort	24400.00
0005434245279	5330	Comfort	24400.00
0005435616182	5330	Comfort	24400.00
0005434573671	5330	Comfort	24400.00
0005432133548	5330	Comfort	24400.00
0005435425776	5330	Comfort	24400.00
0005434345016	5330	Comfort	24400.00
0005435305039	5330	Comfort	24400.00
0005435425796	5330	Comfort	24400.00
0005435425969	5330	Comfort	24400.00
0005435616197	5330	Comfort	24400.00
0005435097435	5330	Comfort	24400.00
0005432047634	5330	Comfort	24400.00
0005434245472	5330	Comfort	24400.00
0005434345032	5330	Comfort	24400.00
0005435425761	5330	Comfort	24400.00
0005435425546	5330	Comfort	24400.00
0005434573678	5330	Comfort	24400.00
0005435425968	5330	Comfort	24400.00
0005435425496	5330	Comfort	24400.00
0005434245349	5330	Comfort	24400.00
0005435425836	5330	Comfort	24400.00
0005434245491	5330	Comfort	24400.00
0005432133547	5330	Comfort	24400.00
0005435616253	5330	Comfort	24400.00
0005435616233	5330	Comfort	24400.00
0005434656578	5330	Comfort	24400.00
0005435616223	5330	Comfort	24400.00
0005434573664	5330	Comfort	24400.00
0005432133559	5330	Comfort	24400.00
0005435616198	5330	Economy	14400.00
0005434245504	5330	Economy	14400.00
0005435616173	5330	Economy	14400.00
0005435616165	5330	Economy	14400.00
0005435425727	5330	Economy	14400.00
0005435425726	5330	Economy	14400.00
0005435425956	5330	Economy	14400.00
0005435616242	5330	Economy	14400.00
0005432133545	5330	Economy	14400.00
0005432133557	5330	Economy	14400.00
0005434573673	5330	Economy	14400.00
0005432047635	5330	Economy	14400.00
0005435319687	5330	Economy	14400.00
0005435425773	5330	Economy	14400.00
0005435616217	5330	Economy	14400.00
0005435097436	5330	Economy	14400.00
0005435097427	5330	Economy	14400.00
0005435425957	5330	Economy	14400.00
0005435616151	5330	Economy	14400.00
0005434573677	5330	Economy	14400.00
0005432133551	5330	Economy	14400.00
0005435616248	5330	Economy	14400.00
0005435616170	5330	Economy	14400.00
0005435616184	5330	Economy	14400.00
0005435425908	5330	Economy	14400.00
0005435305038	5330	Economy	14400.00
0005435616230	5330	Economy	14400.00
0005435425756	5330	Economy	14400.00
0005435616225	5330	Economy	14400.00
0005434345039	5330	Economy	14400.00
0005435425648	5330	Economy	14400.00
0005435616265	5330	Economy	14400.00
0005435319709	5330	Economy	14400.00
0005435616254	5330	Economy	14400.00
0005434573669	5330	Economy	14400.00
0005432133555	5330	Economy	14400.00
0005435616260	5330	Economy	14400.00
0005435425877	5330	Economy	14400.00
0005435425950	5330	Economy	14400.00
0005434345014	5330	Economy	14400.00
0005435319708	5330	Economy	14400.00
0005435425951	5330	Economy	14400.00
0005435425748	5330	Economy	14400.00
0005435616169	5330	Economy	14400.00
0005432133544	5330	Economy	14400.00
0005435426043	5330	Economy	14400.00
0005435425876	5330	Economy	14400.00
0005434345040	5330	Economy	14400.00
0005434245405	5330	Economy	14400.00
0005435490309	5330	Economy	14400.00
0005435426035	5330	Economy	14400.00
0005435425783	5330	Economy	14400.00
0005435426199	5330	Economy	14400.00
0005435426170	5330	Economy	14400.00
0005434345022	5330	Economy	14400.00
0005435425887	5330	Economy	14400.00
0005435616193	5330	Economy	14400.00
0005435425630	5330	Economy	14400.00
0005435616161	5330	Economy	14400.00
0005435616238	5330	Economy	14400.00
0005435425706	5330	Economy	14400.00
0005434345012	5330	Economy	15800.00
0005435616227	5330	Economy	15800.00
0005434345037	5330	Economy	14400.00
0005435616207	5330	Economy	15800.00
0005435042874	5330	Economy	14400.00
0005435616206	5330	Economy	14400.00
0005434245487	5330	Economy	15800.00
0005435425921	5330	Economy	15800.00
0005435616216	5330	Economy	14400.00
0005432133549	5330	Economy	15800.00
0005435616270	5330	Economy	14400.00
0005434573675	5330	Economy	14400.00
0005435425704	5330	Economy	14400.00
0005434345015	5330	Economy	14400.00
0005434345034	5330	Economy	14400.00
0005435616264	5330	Economy	14400.00
0005435425999	5330	Economy	14400.00
0005434345013	5330	Economy	14400.00
0005435616245	5330	Economy	14400.00
0005435616185	5330	Economy	14400.00
0005435425703	5330	Economy	14400.00
0005435616203	5330	Economy	14400.00
0005435380354	5330	Economy	14400.00
0005435425622	5330	Economy	14400.00
0005435616160	5330	Economy	14400.00
0005435616257	5330	Economy	14400.00
0005435425875	5330	Economy	14400.00
0005435491488	5330	Economy	14400.00
0005435616221	5330	Economy	14400.00
0005435616209	5330	Economy	14400.00
0005435616259	5330	Economy	14400.00
0005435616261	5330	Economy	14400.00
0005435616201	5330	Economy	14400.00
0005434573667	5330	Economy	14400.00
0005435616189	5330	Economy	14400.00
0005435616214	5330	Economy	14400.00
0005435616204	5330	Economy	14400.00
0005435425778	5330	Economy	14400.00
0005432841040	5330	Economy	14400.00
0005435425916	5330	Economy	14400.00
0005435490311	5330	Economy	14400.00
0005435425991	5330	Economy	14400.00
0005435616228	5330	Economy	14400.00
0005435555415	5330	Economy	14400.00
0005434345029	5330	Economy	14400.00
0005435616237	5330	Economy	14400.00
0005435425903	5330	Economy	14400.00
0005435426021	5330	Economy	14400.00
0005434245333	5330	Economy	14400.00
0005434245402	5330	Economy	14400.00
0005434345020	5330	Economy	14400.00
0005434656588	5330	Economy	14400.00
0005435616149	5330	Economy	14400.00
0005434656583	5330	Economy	14400.00
0005435425949	5330	Economy	14400.00
0005435616192	5330	Economy	14400.00
0005435616218	5330	Economy	14400.00
0005435616177	5330	Economy	14400.00
0005435097430	5330	Economy	14400.00
0005434345005	5330	Economy	14400.00
0005435425632	5330	Economy	14400.00
0005434345009	5330	Economy	14400.00
0005435426022	5330	Economy	14400.00
0005432841043	5330	Economy	14400.00
0005435616187	5330	Economy	14400.00
0005435425702	5330	Economy	14400.00
0005434345021	5330	Economy	14400.00
0005434345026	5330	Economy	14400.00
0005435616226	5330	Economy	14400.00
0005434573676	5330	Economy	14400.00
0005435425763	5330	Economy	14400.00
0005435097428	5330	Economy	14400.00
0005435425680	5330	Economy	14400.00
0005435616181	5330	Economy	14400.00
0005435616222	5330	Economy	14400.00
0005434345036	5330	Economy	14400.00
0005432363472	5330	Economy	14400.00
0005434573666	5330	Economy	14400.00
0005435616234	5330	Economy	14400.00
0005435490312	5330	Economy	14400.00
0005435042879	5330	Economy	14400.00
0005434245330	5330	Economy	14400.00
0005433719181	5330	Economy	14400.00
0005435616236	5330	Economy	14400.00
0005434245441	5330	Economy	14400.00
0005435616205	5330	Economy	14400.00
0005435616251	5330	Economy	14400.00
0005435425747	5330	Economy	14400.00
0005435425874	5330	Economy	14400.00
0005435616231	5330	Economy	14400.00
0005435302241	5330	Economy	14400.00
0005432047636	5330	Economy	14400.00
0005434345006	5330	Economy	14400.00
0005434345031	5330	Economy	14400.00
0005435616199	5330	Economy	14400.00
0005435425837	5330	Economy	14400.00
0005435616202	5330	Economy	14400.00
0005432841044	5330	Economy	14400.00
0005435616269	5330	Economy	14400.00
0005434345028	5330	Economy	14400.00
0005435425878	5330	Economy	14400.00
0005435319720	5330	Economy	14400.00
0005435616263	5330	Economy	14400.00
0005434245394	5330	Economy	14400.00
0005435616250	5330	Economy	14400.00
0005435616168	5330	Economy	14400.00
0005434345018	5330	Economy	14400.00
0005435616153	5330	Economy	14400.00
0005435616183	5330	Economy	14400.00
0005435425651	5330	Economy	14400.00
0005432047633	5330	Economy	14400.00
0005432363452	5330	Economy	14400.00
0005435491489	5330	Economy	14400.00
0005435097434	5330	Economy	14400.00
0005435380377	5330	Economy	15800.00
0005434345019	5330	Economy	15800.00
0005435425757	5330	Economy	15800.00
0005435425955	5330	Economy	15800.00
0005435616235	5330	Economy	15800.00
0005435616244	5330	Economy	15800.00
0005434245486	5330	Economy	14400.00
0005435042880	5330	Economy	14400.00
0005435616211	5330	Economy	14400.00
0005435425725	5330	Economy	14400.00
0005435319718	5330	Economy	14400.00
0005434245408	5330	Economy	14400.00
0005435097432	5330	Economy	14400.00
0005435319719	5330	Economy	14400.00
0005434573665	5330	Economy	14400.00
0005434345017	5330	Economy	14400.00
0005435616164	5330	Economy	14400.00
0005434245378	5330	Economy	14400.00
0005432133558	5330	Economy	14400.00
0005434245410	5330	Economy	14400.00
0005435616210	5330	Economy	14400.00
0005434345041	5330	Economy	14400.00
0005434245412	5330	Economy	14400.00
0005434345025	5330	Economy	14400.00
0005435425934	5330	Economy	14400.00
0005435616212	5330	Economy	14400.00
0005435319686	5330	Economy	14400.00
0005435616219	5330	Economy	14400.00
0005435616152	5330	Economy	14400.00
0005435616239	5330	Economy	14400.00
0005435425998	5330	Economy	14400.00
0005435425970	5330	Economy	14400.00
0005435425663	5330	Economy	14400.00
0005434573672	5330	Economy	14400.00
0005435616267	5330	Economy	14400.00
0005435616266	5330	Economy	14400.00
0005432133546	5330	Economy	14400.00
0005435380378	5330	Economy	14400.00
0005435616176	5330	Economy	14400.00
0005435616247	5330	Economy	14400.00
0005434245289	5330	Economy	14400.00
0005434245505	5330	Economy	14400.00
0005435425930	5330	Economy	14400.00
0005435097426	5330	Economy	14400.00
0005435616180	5330	Economy	14400.00
0005435616220	5330	Economy	14400.00
0005435616268	5330	Economy	14400.00
0005435616171	5330	Economy	14400.00
0005435616178	5330	Economy	14400.00
0005435425941	5330	Economy	14400.00
0005435616200	5330	Economy	14400.00
0005435426198	5330	Economy	14400.00
0005435305043	5330	Economy	14400.00
0005435425802	5330	Economy	14400.00
0005434345007	5330	Economy	14400.00
0005435616241	5330	Economy	14400.00
0005434345023	5330	Economy	14400.00
0005434245327	5330	Economy	14400.00
0005435425762	5330	Economy	14400.00
0005434573668	5330	Economy	14400.00
0005434345024	5330	Economy	14400.00
0005434245403	5330	Economy	14400.00
0005432133553	5330	Economy	14400.00
0005435425707	5330	Economy	14400.00
0005435616150	5330	Economy	14400.00
0005435319740	5330	Economy	14400.00
0005435616215	5330	Economy	14400.00
0005435616158	5330	Economy	14400.00
0005435425879	5330	Economy	14400.00
0005434345027	5330	Economy	14400.00
0005435616190	5330	Economy	14400.00
0005435616156	5330	Economy	14400.00
0005435616163	5330	Economy	14400.00
0005434573670	5330	Economy	14400.00
0005434245290	5330	Economy	14400.00
0005435616155	5330	Economy	14400.00
0005435616243	5330	Economy	14400.00
0005435616232	5330	Economy	14400.00
0005435426023	5330	Economy	14400.00
0005432133552	5330	Economy	14400.00
0005435425883	5330	Economy	14400.00
0005435616196	5330	Economy	14400.00
0005435425911	5330	Economy	14400.00
0005435097433	5330	Economy	14400.00
0005435616229	5330	Economy	14400.00
0005435425650	5330	Economy	14400.00
0005432133556	5330	Economy	14400.00
0005435097431	5330	Economy	14400.00
0005435426042	5330	Economy	14400.00
0005434245348	5330	Economy	14400.00
0005435616175	5330	Economy	14400.00
0005433719180	5330	Economy	14400.00
0005435616240	5330	Economy	14400.00
0005435616186	5330	Economy	14400.00
0005434573674	5330	Economy	14400.00
0005435425629	5330	Economy	14400.00
0005435305042	5330	Economy	14400.00
0005435425920	5330	Economy	14400.00
0005435425927	5330	Economy	14400.00
0005435425561	5330	Economy	14400.00
0005435425662	5330	Economy	14400.00
0005435616172	5330	Economy	14400.00
0005434245308	5330	Economy	14400.00
0005435426169	5330	Economy	14400.00
0005435302266	5330	Economy	14400.00
0005434245338	5330	Economy	14400.00
0005435616191	5330	Economy	14400.00
0005435616162	5330	Economy	14400.00
0005435042911	10913	Business	43100.00
0005435426337	10913	Business	43100.00
0005435490269	10913	Business	43100.00
0005435490275	10913	Business	43100.00
0005435097326	10913	Business	43100.00
0005435426347	10913	Business	43100.00
0005434245650	10913	Business	43100.00
0005435615423	10913	Business	43100.00
0005435615163	10913	Business	43100.00
0005435615234	10913	Business	43100.00
0005435615138	10913	Business	43100.00
0005435426344	10913	Business	43100.00
0005435097342	10913	Business	43100.00
0005435319770	10913	Business	43100.00
0005435426336	10913	Business	43100.00
0005432165211	10913	Business	43100.00
0005435615042	10913	Business	43100.00
0005434344647	10913	Business	43100.00
0005435380408	10913	Business	43100.00
0005435426340	10913	Business	43100.00
0005435615302	10913	Business	43100.00
0005432165207	10913	Comfort	24400.00
0005435426385	10913	Business	43100.00
0005435490272	10913	Comfort	24400.00
0005435097327	10913	Comfort	24400.00
0005434573557	10913	Comfort	24400.00
0005435426350	10913	Comfort	24400.00
0005435614700	10913	Comfort	24400.00
0005434573545	10913	Comfort	24400.00
0005434245641	10913	Comfort	24400.00
0005435615429	10913	Comfort	24400.00
0005435490280	10913	Comfort	24400.00
0005435615186	10913	Comfort	24400.00
0005434344689	10913	Comfort	24400.00
0005435615406	10913	Comfort	24400.00
0005435615289	10913	Comfort	24400.00
0005435615434	10913	Comfort	24400.00
0005434573496	10913	Comfort	24400.00
0005435426377	10913	Comfort	24400.00
0005432363490	10913	Comfort	24400.00
0005435426380	10913	Comfort	24400.00
0005434245634	10913	Comfort	24400.00
0005435380405	10913	Comfort	24400.00
0005435614871	10913	Comfort	24400.00
0005434344607	10913	Comfort	24400.00
0005435615256	10913	Comfort	24400.00
0005435615255	10913	Comfort	24400.00
0005435380406	10913	Comfort	24400.00
0005435426327	10913	Comfort	24400.00
0005435426354	10913	Comfort	24400.00
0005435614912	10913	Comfort	24400.00
0005434245658	10913	Comfort	24400.00
0005435614840	10913	Comfort	24400.00
0005435490279	10913	Comfort	24400.00
0005435615433	10913	Comfort	24400.00
0005435426373	10913	Comfort	24400.00
0005435426334	10913	Comfort	24400.00
0005435426379	10913	Economy	14400.00
0005435615362	10913	Economy	14400.00
0005435615373	10913	Economy	14400.00
0005435615365	10913	Economy	14400.00
0005435426372	10913	Economy	14400.00
0005435615051	10913	Economy	14400.00
0005434245638	10913	Economy	14400.00
0005435615142	10913	Economy	14400.00
0005435319772	10913	Economy	14400.00
0005434245657	10913	Economy	14400.00
0005435319774	10913	Economy	14400.00
0005434573492	10913	Economy	14400.00
0005434344606	10913	Economy	14400.00
0005435042910	10913	Economy	14400.00
0005432166976	10913	Economy	14400.00
0005435615438	10913	Economy	14400.00
0005434245639	10913	Economy	14400.00
0005434344596	10913	Economy	14400.00
0005435614695	10913	Economy	14400.00
0005435426325	10913	Economy	14400.00
0005435426346	10913	Economy	14400.00
0005435426367	10913	Economy	14400.00
0005434344718	10913	Economy	14400.00
0005435426329	10913	Economy	14400.00
0005435426358	10913	Economy	14400.00
0005434344684	10913	Economy	14400.00
0005435615320	10913	Economy	14400.00
0005435426326	10913	Economy	14400.00
0005435426355	10913	Economy	14400.00
0005434245636	10913	Economy	14400.00
0005434344692	10913	Economy	14400.00
0005435319773	10913	Economy	14400.00
0005435615061	10913	Economy	14400.00
0005435615308	10913	Economy	14400.00
0005435614754	10913	Economy	14400.00
0005432166975	10913	Economy	14400.00
0005434344744	10913	Economy	14400.00
0005435426338	10913	Economy	14400.00
0005435615301	10913	Economy	14400.00
0005434573522	10913	Economy	14400.00
0005435426359	10913	Economy	14400.00
0005434245644	10913	Economy	14400.00
0005435614574	10913	Economy	14400.00
0005435615411	10913	Economy	14400.00
0005434573525	10913	Economy	14400.00
0005435426352	10913	Economy	14400.00
0005434344586	10913	Economy	14400.00
0005435615321	10913	Economy	14400.00
0005434344664	10913	Economy	14400.00
0005435614818	10913	Economy	14400.00
0005435426351	10913	Economy	14400.00
0005434344691	10913	Economy	14400.00
0005434245632	10913	Economy	14400.00
0005434573521	10913	Economy	14400.00
0005435426387	10913	Economy	14400.00
0005435490281	10913	Economy	14400.00
0005435426348	10913	Economy	14400.00
0005435426393	10913	Economy	14400.00
0005435426382	10913	Economy	14400.00
0005434245655	10913	Economy	14400.00
0005435615287	10913	Economy	14400.00
0005435097328	10913	Economy	14400.00
0005432165212	10913	Economy	15800.00
0005432166974	10913	Economy	15800.00
0005435615441	10913	Economy	14400.00
0005435614644	10913	Economy	14400.00
0005435614920	10913	Economy	14400.00
0005434344612	10913	Economy	14400.00
0005434573549	10913	Economy	15800.00
0005435615254	10913	Economy	15800.00
0005435426378	10913	Economy	14400.00
0005434245629	10913	Economy	14400.00
0005432363489	10913	Economy	14400.00
0005435426390	10913	Economy	14400.00
0005434245643	10913	Economy	14400.00
0005435426361	10913	Economy	14400.00
0005435614857	10913	Economy	14400.00
0005432841060	10913	Economy	14400.00
0005435614972	10913	Economy	14400.00
0005434656600	10913	Economy	14400.00
0005435426363	10913	Economy	14400.00
0005435615233	10913	Economy	14400.00
0005434573510	10913	Economy	14400.00
0005435614897	10913	Economy	14400.00
0005435615192	10913	Economy	14400.00
0005434344743	10913	Economy	14400.00
0005434245654	10913	Economy	14400.00
0005435615077	10913	Economy	14400.00
0005435615428	10913	Economy	14400.00
0005435426342	10913	Economy	14400.00
0005435426331	10913	Economy	14400.00
0005435615361	10913	Economy	14400.00
0005434344690	10913	Economy	14400.00
0005435426330	10913	Economy	14400.00
0005434344579	10913	Economy	14400.00
0005435042909	10913	Economy	14400.00
0005435380407	10913	Economy	14400.00
0005434344683	10913	Economy	14400.00
0005434245640	10913	Economy	14400.00
0005435615319	10913	Economy	14400.00
0005435426345	10913	Economy	14400.00
0005434245647	10913	Economy	14400.00
0005435426389	10913	Economy	14400.00
0005435426371	10913	Economy	14400.00
0005435426353	10913	Economy	14400.00
0005435426328	10913	Economy	14400.00
0005435426369	10913	Economy	14400.00
0005435615041	10913	Economy	14400.00
0005435615060	10913	Economy	14400.00
0005434344628	10913	Economy	14400.00
0005435426383	10913	Economy	14400.00
0005435614919	10913	Economy	14400.00
0005435380404	10913	Economy	14400.00
0005435615249	10913	Economy	14400.00
0005435614826	10913	Economy	14400.00
0005435426365	10913	Economy	14400.00
0005434344508	10913	Economy	14400.00
0005435426335	10913	Economy	14400.00
0005434245635	10913	Economy	14400.00
0005435426357	10913	Economy	14400.00
0005435426360	10913	Economy	14400.00
0005434656601	10913	Economy	14400.00
0005432165208	10913	Economy	14400.00
0005435614870	10913	Economy	14400.00
0005435615407	10913	Economy	14400.00
0005434245645	10913	Economy	14400.00
0005434245633	10913	Economy	14400.00
0005435319775	10913	Economy	14400.00
0005434245646	10913	Economy	14400.00
0005435615430	10913	Economy	14400.00
0005435097348	10913	Economy	14400.00
0005435615035	10913	Economy	14400.00
0005434573523	10913	Economy	14400.00
0005435615036	10913	Economy	14400.00
0005434245651	10913	Economy	14400.00
0005435097346	10913	Economy	14400.00
0005434656602	10913	Economy	14400.00
0005435615058	10913	Economy	14400.00
0005435615439	10913	Economy	14400.00
0005435615037	10913	Economy	14400.00
0005434573513	10913	Economy	14400.00
0005435426366	10913	Economy	14400.00
0005435615272	10913	Economy	14400.00
0005435097340	10913	Economy	14400.00
0005434344566	10913	Economy	14400.00
0005434344522	10913	Economy	14400.00
0005435614981	10913	Economy	14400.00
0005435615394	10913	Economy	14400.00
0005434344611	10913	Economy	14400.00
0005434245630	10913	Economy	14400.00
0005434344523	10913	Economy	14400.00
0005435097324	10913	Economy	14400.00
0005434344608	10913	Economy	14400.00
0005434344600	10913	Economy	14400.00
0005432363488	10913	Economy	14400.00
0005434344576	10913	Economy	14400.00
0005435615164	10913	Economy	14400.00
0005435042907	10913	Economy	14400.00
0005435615040	10913	Economy	14400.00
0005434245631	10913	Economy	14400.00
0005434573503	10913	Economy	14400.00
0005433719219	10913	Economy	14400.00
0005435490276	10913	Economy	14400.00
0005434573536	10913	Economy	14400.00
0005432166973	10913	Economy	14400.00
0005434344572	10913	Economy	14400.00
0005435615129	10913	Economy	14400.00
0005435614743	10913	Economy	15800.00
0005435490271	10913	Economy	15800.00
0005435426370	10913	Economy	15800.00
0005435614977	10913	Economy	15800.00
0005434245648	10913	Economy	15800.00
0005435615208	10913	Economy	14400.00
0005434344616	10913	Economy	14400.00
0005435615288	10913	Economy	14400.00
0005434573548	10913	Economy	14400.00
0005435426388	10913	Economy	14400.00
0005435615432	10913	Economy	14400.00
0005434245653	10913	Economy	14400.00
0005434573511	10913	Economy	14400.00
0005435097323	10913	Economy	14400.00
0005435615408	10913	Economy	14400.00
0005435615000	10913	Economy	14400.00
0005434344629	10913	Economy	14400.00
0005435097347	10913	Economy	14400.00
0005432165209	10913	Economy	14400.00
0005434573515	10913	Economy	14400.00
0005435426343	10913	Economy	14400.00
0005435097316	10913	Economy	14400.00
0005435615325	10913	Economy	14400.00
0005435426356	10913	Economy	14400.00
0005434573537	10913	Economy	14400.00
0005434245656	10913	Economy	14400.00
0005434245628	10913	Economy	14400.00
0005435426381	10913	Economy	14400.00
0005435615178	10913	Economy	14400.00
0005435615422	10913	Economy	14400.00
0005435615079	10913	Economy	14400.00
0005435426375	10913	Economy	14400.00
0005434245659	10913	Economy	14400.00
0005434344583	10913	Economy	14400.00
0005432166977	10913	Economy	14400.00
0005434344601	10913	Economy	14400.00
0005435615295	10913	Economy	14400.00
0005434573459	10913	Economy	14400.00
0005435615181	10913	Economy	14400.00
0005434344597	10913	Economy	14400.00
0005434344685	10913	Economy	14400.00
0005434573512	10913	Economy	14400.00
0005435426341	10913	Economy	14400.00
0005434344768	10913	Economy	14400.00
0005435614878	10913	Economy	14400.00
0005435319771	10913	Economy	14400.00
0005434344665	10913	Economy	14400.00
0005435426384	10913	Economy	14400.00
0005434344667	10913	Economy	14400.00
0005435615125	10913	Economy	14400.00
0005435426362	10913	Economy	14400.00
0005434245652	10913	Economy	14400.00
0005435615409	10913	Economy	14400.00
0005434344668	10913	Economy	14400.00
0005435490278	10913	Economy	14400.00
0005434344529	10913	Economy	14400.00
0005435615191	10913	Economy	14400.00
0005435319776	10913	Economy	14400.00
0005434344617	10913	Economy	14400.00
0005434344585	10913	Economy	14400.00
0005435615193	10913	Economy	14400.00
0005435426364	10913	Economy	14400.00
0005434344571	10913	Economy	14400.00
0005435615424	10913	Economy	14400.00
0005435426339	10913	Economy	14400.00
0005432165213	10913	Economy	14400.00
0005435426374	10913	Economy	14400.00
0005435615246	10913	Economy	14400.00
0005434344717	10913	Economy	14400.00
0005435426333	10913	Economy	14400.00
0005435426332	10913	Economy	14400.00
0005435615435	10913	Economy	14400.00
0005432165206	10913	Economy	14400.00
0005432363491	10913	Economy	14400.00
0005435615050	10913	Economy	14400.00
0005435426386	10913	Economy	14400.00
0005433719218	10913	Economy	14400.00
0005435615372	10913	Economy	14400.00
0005435615059	10913	Economy	14400.00
0005435426368	10913	Economy	14400.00
0005434245642	10913	Economy	14400.00
0005435042908	10913	Economy	14400.00
0005434344530	10913	Economy	14400.00
0005434245637	10913	Economy	14400.00
0005435490268	10913	Economy	14400.00
0005435426391	10913	Economy	14400.00
0005435615013	10913	Economy	14400.00
0005435490277	10913	Economy	14400.00
0005435615364	10913	Economy	14400.00
0005435426376	10913	Economy	14400.00
0005435426349	10913	Economy	14400.00
0005435615080	10913	Economy	14400.00
0005434245649	10913	Economy	14400.00
0005435426392	10913	Economy	14400.00
0005435380403	10913	Economy	14400.00
0005434573578	10913	Economy	14400.00
0005435615431	10913	Economy	14400.00
0005435097317	10913	Economy	14400.00
0005432165210	10913	Economy	14400.00
0005432460642	3245	Business	18800.00
0005433634604	3245	Business	18800.00
0005433634600	3245	Business	18800.00
0005432460256	3245	Business	18800.00
0005433806148	3245	Business	18800.00
0005433634599	3245	Business	18800.00
0005432460439	3245	Business	18800.00
0005432460257	3245	Business	18800.00
0005432460545	3245	Business	18800.00
0005432460758	3245	Business	18800.00
0005433806157	3245	Business	18800.00
0005432182218	3245	Business	18800.00
0005433634593	3245	Business	18800.00
0005433634577	3245	Business	18800.00
0005432182221	3245	Business	18800.00
0005433507588	3245	Business	18800.00
0005432182226	3245	Business	18800.00
0005433806159	3245	Business	18800.00
0005433634591	3245	Business	18800.00
0005433507600	3245	Business	18800.00
0005433806156	3245	Business	18800.00
0005433507590	3245	Business	18800.00
0005432460712	3245	Business	18800.00
0005433806154	3245	Business	18800.00
0005433634598	3245	Business	18800.00
0005432460416	3245	Business	18800.00
0005433507579	3245	Business	18800.00
0005432460467	3245	Business	18800.00
0005432182224	3245	Economy	6900.00
0005433806141	3245	Economy	6900.00
0005433806137	3245	Economy	6900.00
0005433806165	3245	Economy	6900.00
0005432182227	3245	Economy	6900.00
0005432460519	3245	Economy	6900.00
0005433806138	3245	Economy	6300.00
0005432182215	3245	Economy	6300.00
0005432460643	3245	Economy	6300.00
0005433634590	3245	Economy	6300.00
0005432460632	3245	Economy	6300.00
0005433806161	3245	Economy	6300.00
0005433634580	3245	Economy	6300.00
0005433507595	3245	Economy	6300.00
0005433634609	3245	Economy	6300.00
0005432460601	3245	Economy	6300.00
0005433634603	3245	Economy	6300.00
0005433806166	3245	Economy	6300.00
0005432182223	3245	Economy	6300.00
0005432182219	3245	Economy	6300.00
0005433806168	3245	Economy	6300.00
0005432460626	3245	Economy	6300.00
0005433507581	3245	Economy	6300.00
0005433507585	3245	Economy	6300.00
0005433806139	3245	Economy	6300.00
0005432460593	3245	Economy	6300.00
0005433507596	3245	Economy	6300.00
0005432460613	3245	Economy	6300.00
0005432460117	3245	Economy	6300.00
0005433634589	3245	Economy	6300.00
0005432182216	3245	Economy	6300.00
0005433634575	3245	Economy	6300.00
0005432460549	3245	Economy	6300.00
0005433507591	3245	Economy	6300.00
0005433806145	3245	Economy	6300.00
0005432460695	3245	Economy	6300.00
0005433634578	3245	Economy	6300.00
0005433634592	3245	Economy	6300.00
0005433806169	3245	Economy	6300.00
0005433806170	3245	Economy	6300.00
0005432460630	3245	Economy	6300.00
0005432460600	3245	Economy	6300.00
0005432460518	3245	Economy	6300.00
0005433507584	3245	Economy	6300.00
0005432460688	3245	Economy	6300.00
0005433806142	3245	Economy	6300.00
0005433806164	3245	Economy	6300.00
0005432182209	3245	Economy	6300.00
0005433507580	3245	Economy	6300.00
0005432460517	3245	Economy	6300.00
0005432460523	3245	Economy	6300.00
0005433507597	3245	Economy	6300.00
0005432460710	3245	Economy	6300.00
0005433806163	3245	Economy	6300.00
0005433806158	3245	Economy	6300.00
0005433634596	3245	Economy	6300.00
0005433634594	3245	Economy	6300.00
0005432460602	3245	Economy	6300.00
0005432460565	3245	Economy	6300.00
0005432460455	3245	Economy	6300.00
0005432460687	3245	Economy	6300.00
0005432460529	3245	Economy	6300.00
0005433634595	3245	Economy	6300.00
0005432460481	3245	Economy	6300.00
0005433507592	3245	Economy	6300.00
0005433806149	3245	Economy	6300.00
0005433634597	3245	Economy	6900.00
0005433806162	3245	Economy	6900.00
0005433507594	3245	Economy	6900.00
0005432460599	3245	Economy	6900.00
0005433634584	3245	Economy	6900.00
0005433507601	3245	Economy	6300.00
0005433806151	3245	Economy	6300.00
0005432460586	3245	Economy	6300.00
0005432182220	3245	Economy	6300.00
0005433507593	3245	Economy	6900.00
0005432460592	3245	Economy	6300.00
0005433507587	3245	Economy	6300.00
0005433634601	3245	Economy	6300.00
0005433634605	3245	Economy	6300.00
0005433634579	3245	Economy	6300.00
0005433634585	3245	Economy	6300.00
0005432460548	3245	Economy	6300.00
0005433507589	3245	Economy	6300.00
0005432460674	3245	Economy	6300.00
0005432460116	3245	Economy	6300.00
0005433634574	3245	Economy	6300.00
0005432460491	3245	Economy	6300.00
0005433507583	3245	Economy	6300.00
0005433806171	3245	Economy	6300.00
0005433806144	3245	Economy	6300.00
0005433634607	3245	Economy	6300.00
0005433806167	3245	Economy	6300.00
0005433806146	3245	Economy	6300.00
0005432460802	3245	Economy	6300.00
0005432460417	3245	Economy	6300.00
0005432182229	3245	Economy	6300.00
0005432460419	3245	Economy	6300.00
0005432460484	3245	Economy	6300.00
0005432460711	3245	Economy	6300.00
0005432460398	3245	Economy	6300.00
0005432182228	3245	Economy	6300.00
0005433507598	3245	Economy	6300.00
0005433806143	3245	Economy	6300.00
0005432182210	3245	Economy	6300.00
0005432460554	3245	Economy	6300.00
0005433806150	3245	Economy	6300.00
0005433634606	3245	Economy	6300.00
0005432460483	3245	Economy	6300.00
0005433806152	3245	Economy	6300.00
0005432460520	3245	Economy	6300.00
0005432182214	3245	Economy	6300.00
0005433634586	3245	Economy	6300.00
0005433634576	3245	Economy	6300.00
0005433507582	3245	Economy	6300.00
0005433806147	3245	Economy	6300.00
0005433507586	3245	Economy	6300.00
0005433634608	3245	Economy	6300.00
0005433806160	3245	Economy	6300.00
0005432460587	3245	Economy	6300.00
0005432182217	3245	Economy	6300.00
0005432460555	3245	Economy	6300.00
0005432182212	3245	Economy	6300.00
0005432460631	3245	Economy	6300.00
0005433507599	3245	Economy	6300.00
0005433634602	3245	Economy	6300.00
0005433634587	3245	Economy	6300.00
0005432460516	3245	Economy	6300.00
0005432182222	3245	Economy	6300.00
0005433806155	3245	Economy	6300.00
0005432182213	3245	Economy	6300.00
0005432182211	3245	Economy	6300.00
0005432460809	3245	Economy	6300.00
0005433634588	3245	Economy	6300.00
0005432182230	3245	Economy	6300.00
0005433634581	3245	Economy	6300.00
0005433806153	3245	Economy	6300.00
0005432460550	3245	Economy	6300.00
0005432182225	3245	Economy	6300.00
0005433634583	3245	Economy	6300.00
0005433806140	3245	Economy	6300.00
0005433634582	3245	Economy	6300.00
0005435886110	3244	Business	18800.00
0005435886086	3244	Business	18800.00
0005435886089	3244	Business	18800.00
0005435885840	3244	Business	18800.00
0005435885903	3244	Business	18800.00
0005435885936	3244	Business	18800.00
0005435886106	3244	Economy	6300.00
0005435885730	3244	Economy	6300.00
0005435885960	3244	Economy	6300.00
0005435886041	3244	Economy	6300.00
0005435886108	3244	Economy	6300.00
0005435886103	3244	Economy	6300.00
0005435885525	3244	Economy	6300.00
0005435885740	3244	Economy	6300.00
0005435885945	3244	Economy	6300.00
0005435886019	3244	Economy	6300.00
0005435886008	3244	Economy	6300.00
0005435885998	3244	Economy	6300.00
0005435885891	3244	Economy	6300.00
0005435886033	3244	Economy	6300.00
0005435885824	3244	Economy	6300.00
0005435885978	3244	Economy	6300.00
0005435885961	3244	Economy	6300.00
0005435885938	3244	Economy	6300.00
0005435886011	3244	Economy	6300.00
0005435885902	3244	Economy	6300.00
0005435885972	3244	Economy	6300.00
0005435886105	3244	Economy	6300.00
0005435885892	3244	Economy	6300.00
0005435886078	3244	Economy	6300.00
0005435886111	3244	Economy	6900.00
0005435885928	3244	Economy	6300.00
0005435886020	3244	Economy	6900.00
0005435885899	3244	Economy	6300.00
0005435886090	3244	Economy	6300.00
0005435886040	3244	Economy	6300.00
0005435885733	3244	Economy	6300.00
0005435886032	3244	Economy	6300.00
0005435886104	3244	Economy	6300.00
0005435885974	3244	Economy	6300.00
0005435886031	3244	Economy	6300.00
0005435886000	3244	Economy	6300.00
0005435886107	3244	Economy	6300.00
0005435885734	3244	Economy	6300.00
0005435885729	3244	Economy	6300.00
0005435885977	3244	Economy	6300.00
0005435885851	3244	Economy	6300.00
0005435886062	3244	Economy	6300.00
0005435886064	3244	Economy	6300.00
0005433507422	8339	Business	18800.00
0005435886346	8339	Business	18800.00
0005434312368	8339	Business	18800.00
0005432461070	8339	Business	18800.00
0005432461049	8339	Business	18800.00
0005434312367	8339	Business	18800.00
0005432461078	8339	Business	18800.00
0005432461082	8339	Business	18800.00
0005432043036	8339	Business	18800.00
0005432461092	8339	Business	18800.00
0005432461044	8339	Business	18800.00
0005432043023	8339	Business	18800.00
0005433507423	8339	Business	18800.00
0005432461064	8339	Business	18800.00
0005432461075	8339	Business	18800.00
0005433507442	8339	Business	18800.00
0005432043026	8339	Business	18800.00
0005432461074	8339	Business	18800.00
0005435886361	8339	Business	18800.00
0005432461055	8339	Business	18800.00
0005435886333	8339	Business	18800.00
0005432461043	8339	Economy	6900.00
0005435886341	8339	Economy	6900.00
0005433507413	8339	Economy	6900.00
0005435886338	8339	Economy	6300.00
0005432461071	8339	Economy	6300.00
0005435886345	8339	Economy	6300.00
0005432461076	8339	Economy	6300.00
0005432461090	8339	Economy	6300.00
0005432461091	8339	Economy	6300.00
0005435886352	8339	Economy	6300.00
0005435886347	8339	Economy	6300.00
0005432043031	8339	Economy	6300.00
0005432461081	8339	Economy	6300.00
0005433507394	8339	Economy	6300.00
0005432461084	8339	Economy	6300.00
0005432461042	8339	Economy	6300.00
0005432461080	8339	Economy	6300.00
0005435886359	8339	Economy	6300.00
0005432461047	8339	Economy	6300.00
0005432461061	8339	Economy	6300.00
0005432043029	8339	Economy	6300.00
0005432461065	8339	Economy	6300.00
0005433507400	8339	Economy	6300.00
0005435886349	8339	Economy	6300.00
0005432461048	8339	Economy	6300.00
0005432461088	8339	Economy	6300.00
0005435886332	8339	Economy	6300.00
0005432461089	8339	Economy	6300.00
0005435886334	8339	Economy	6300.00
0005435886354	8339	Economy	6300.00
0005433507421	8339	Economy	6300.00
0005432461056	8339	Economy	6300.00
0005435886330	8339	Economy	6300.00
0005432461062	8339	Economy	6300.00
0005435142981	8339	Economy	6300.00
0005435886324	8339	Economy	6300.00
0005435142982	8339	Economy	6300.00
0005433507445	8339	Economy	6300.00
0005432461077	8339	Economy	6300.00
0005432043025	8339	Economy	6300.00
0005432461045	8339	Economy	6300.00
0005435886326	8339	Economy	6300.00
0005432461041	8339	Economy	6300.00
0005434326284	8339	Economy	6300.00
0005433507412	8339	Economy	6300.00
0005435886360	8339	Economy	6300.00
0005435886353	8339	Economy	6300.00
0005432461079	8339	Economy	6300.00
0005432461066	8339	Economy	6300.00
0005432043027	8339	Economy	6300.00
0005435886348	8339	Economy	6300.00
0005435886327	8339	Economy	6300.00
0005432461063	8339	Economy	6300.00
0005435142983	8339	Economy	6300.00
0005435886357	8339	Economy	6300.00
0005433507430	8339	Economy	6900.00
0005432461058	8339	Economy	6900.00
0005432461053	8339	Economy	6900.00
0005435886339	8339	Economy	6900.00
0005433507431	8339	Economy	6300.00
0005432461054	8339	Economy	6300.00
0005435886365	8339	Economy	6300.00
0005432461086	8339	Economy	6300.00
0005432461051	8339	Economy	6300.00
0005435886364	8339	Economy	6300.00
0005435886337	8339	Economy	6300.00
0005435886351	8339	Economy	6300.00
0005433507503	8339	Economy	6300.00
0005432043034	8339	Economy	6300.00
0005435886366	8339	Economy	6300.00
0005435886329	8339	Economy	6300.00
0005433507504	8339	Economy	6300.00
0005432461085	8339	Economy	6300.00
0005432461087	8339	Economy	6300.00
0005432461057	8339	Economy	6300.00
0005432461050	8339	Economy	6300.00
0005432461069	8339	Economy	6300.00
0005432043035	8339	Economy	6300.00
0005432461060	8339	Economy	6300.00
0005435886368	8339	Economy	6300.00
0005435886344	8339	Economy	6300.00
0005435886343	8339	Economy	6300.00
0005435886362	8339	Economy	6300.00
0005432461068	8339	Economy	6300.00
0005435886356	8339	Economy	6300.00
0005433507428	8339	Economy	6300.00
0005434326285	8339	Economy	6300.00
0005435886350	8339	Economy	6300.00
0005432461052	8339	Economy	6300.00
0005432043028	8339	Economy	6300.00
0005435886328	8339	Economy	6300.00
0005435886325	8339	Economy	6300.00
0005432043024	8339	Economy	6300.00
0005432461059	8339	Economy	6300.00
0005432461067	8339	Economy	6300.00
0005435886342	8339	Economy	6300.00
0005433507414	8339	Economy	6300.00
0005432461073	8339	Economy	6300.00
0005432043033	8339	Economy	6300.00
0005433507427	8339	Economy	6300.00
0005432043030	8339	Economy	6300.00
0005435886331	8339	Economy	6300.00
0005435886323	8339	Economy	6300.00
0005432461072	8339	Economy	6300.00
0005432043037	8339	Economy	6300.00
0005435886367	8339	Economy	6300.00
0005435886340	8339	Economy	6300.00
0005435886335	8339	Economy	6300.00
0005435886363	8339	Economy	6300.00
0005435886336	8339	Economy	6300.00
0005435886355	8339	Economy	6300.00
0005435886358	8339	Economy	6300.00
0005433507399	8339	Economy	6300.00
0005432461083	8339	Economy	6300.00
0005432043032	8339	Economy	6300.00
0005432461046	8339	Economy	6300.00
0005433634244	8229	Business	18800.00
0005433634333	8229	Business	18800.00
0005433805924	8229	Business	18800.00
0005433634176	8229	Business	18800.00
0005433805749	8229	Business	18800.00
0005433634234	8229	Business	18800.00
0005433634215	8229	Business	18800.00
0005433634307	8229	Business	18800.00
0005433805874	8229	Business	18800.00
0005433805858	8229	Business	18800.00
0005433634292	8229	Business	18800.00
0005433805822	8229	Business	18800.00
0005433634118	8229	Business	18800.00
0005433634141	8229	Economy	6900.00
0005433634207	8229	Economy	6300.00
0005435860648	8229	Economy	6300.00
0005433634216	8229	Economy	6300.00
0005433634209	8229	Economy	6300.00
0005433634277	8229	Economy	6300.00
0005433805760	8229	Economy	6300.00
0005433634393	8229	Economy	6300.00
0005433634225	8229	Economy	6300.00
0005433634421	8229	Economy	6300.00
0005433805934	8229	Economy	6300.00
0005433634334	8229	Economy	6300.00
0005433634338	8229	Economy	6300.00
0005433634306	8229	Economy	6300.00
0005433634205	8229	Economy	6300.00
0005433805916	8229	Economy	6300.00
0005435860645	8229	Economy	6300.00
0005435860644	8229	Economy	6300.00
0005433634248	8229	Economy	6300.00
0005433805909	8229	Economy	6300.00
0005433634220	8229	Economy	6300.00
0005433805942	8229	Economy	6300.00
0005433805998	8229	Economy	6300.00
0005433634339	8229	Economy	6300.00
0005433805935	8229	Economy	6300.00
0005434271346	8229	Economy	6300.00
0005433634263	8229	Economy	6900.00
0005433805857	8229	Economy	6300.00
0005433634320	8229	Economy	6300.00
0005433805929	8229	Economy	6300.00
0005433805873	8229	Economy	6300.00
0005433634202	8229	Economy	6300.00
0005433634293	8229	Economy	6300.00
0005433634159	8229	Economy	6300.00
0005433805781	8229	Economy	6300.00
0005433805937	8229	Economy	6300.00
0005433634117	8229	Economy	6300.00
0005433805989	8229	Economy	6300.00
0005433805867	8229	Economy	6300.00
0005433634449	8229	Economy	6300.00
0005433634262	8229	Economy	6300.00
0005434271340	8229	Economy	6300.00
0005433634227	8229	Economy	6300.00
0005435860646	8229	Economy	6300.00
0005433634211	8229	Economy	6300.00
0005433634399	8229	Economy	6300.00
0005433805834	8229	Economy	6300.00
0005433634201	8229	Economy	6300.00
0005433634208	8229	Economy	6300.00
0005435860647	8229	Economy	6300.00
0005433634243	8229	Economy	6300.00
0005433634158	8229	Economy	6300.00
0005433634314	8229	Economy	6300.00
0005434271331	8229	Economy	6300.00
0005433805936	8229	Economy	6300.00
0005433805807	8229	Economy	6300.00
0005433634398	8229	Economy	6300.00
0005435860649	8229	Economy	6300.00
0005433634381	8229	Economy	6300.00
0005433805835	8229	Economy	6300.00
0005434183612	8238	Economy	6300.00
0005432384051	4689	Business	9900.00
0005432384047	4689	Business	9900.00
0005432384037	4689	Business	9900.00
0005432384063	4689	Business	9900.00
0005432728218	4689	Business	9900.00
0005433722364	4689	Business	9900.00
0005432728220	4689	Business	9900.00
0005432384064	4689	Business	9900.00
0005432728225	4689	Economy	3300.00
0005432728226	4689	Economy	3300.00
0005432384043	4689	Economy	3300.00
0005433194917	4689	Economy	3300.00
0005432384073	4689	Economy	3300.00
0005432728216	4689	Economy	3600.00
0005433453807	4689	Economy	3600.00
0005432384048	4689	Economy	3600.00
0005432384070	4689	Economy	3600.00
0005432384068	4689	Economy	3300.00
0005432384044	4689	Economy	3300.00
0005432384054	4689	Economy	3300.00
0005432384061	4689	Economy	3300.00
0005433194921	4689	Economy	3300.00
0005432384069	4689	Economy	3300.00
0005433722368	4689	Economy	3300.00
0005433722365	4689	Economy	3300.00
0005432384046	4689	Economy	3300.00
0005432384041	4689	Economy	3300.00
0005432384071	4689	Economy	3300.00
0005433722369	4689	Economy	3300.00
0005432384072	4689	Economy	3300.00
0005432384045	4689	Economy	3300.00
0005432384059	4689	Economy	3300.00
0005433194918	4689	Economy	3300.00
0005433194916	4689	Economy	3300.00
0005432384038	4689	Economy	3300.00
0005432384057	4689	Economy	3300.00
0005432728221	4689	Economy	3300.00
0005432384053	4689	Economy	3300.00
0005433194920	4689	Economy	3300.00
0005432384039	4689	Economy	3300.00
0005433722366	4689	Economy	3300.00
0005433722367	4689	Economy	3300.00
0005432728219	4689	Economy	3300.00
0005432384056	4689	Economy	3300.00
0005432384066	4689	Economy	3300.00
0005432384042	4689	Economy	3300.00
0005433722363	4689	Economy	3300.00
0005433722370	4689	Economy	3300.00
0005432384055	4689	Economy	3300.00
0005432728217	4689	Economy	3300.00
0005432728227	4689	Economy	3300.00
0005432384052	4689	Economy	3300.00
0005433454923	4689	Economy	3300.00
0005432728224	4689	Economy	3300.00
0005432728222	4689	Economy	3300.00
0005432384058	4689	Economy	3300.00
0005433454924	4689	Economy	3300.00
0005433194915	4689	Economy	3300.00
0005432384060	4689	Economy	3300.00
0005432384065	4689	Economy	3300.00
0005433194919	4689	Economy	3300.00
0005432384040	4689	Economy	3300.00
0005432728223	4689	Economy	3300.00
0005433453808	4689	Economy	3300.00
0005432384067	4689	Economy	3300.00
0005432384062	4689	Economy	3300.00
0005433194914	4689	Economy	3300.00
0005432384049	4689	Economy	3300.00
0005432384050	4689	Economy	3300.00
0005432383592	30108	Business	9900.00
0005432383601	30108	Business	9900.00
0005432383605	30108	Economy	3300.00
0005432728083	30108	Economy	3300.00
0005432383514	30108	Economy	3600.00
0005432728139	30108	Economy	3600.00
0005432383570	30108	Economy	3300.00
0005432383446	30108	Economy	3300.00
0005432383501	30108	Economy	3300.00
0005433451658	30108	Economy	3300.00
0005432383595	30108	Economy	3300.00
0005432728070	30108	Economy	3300.00
0005432383565	30108	Economy	3300.00
0005432383549	30108	Economy	3300.00
0005432383505	30108	Economy	3300.00
0005432383500	30108	Economy	3300.00
0005432383480	30108	Economy	3300.00
0005432728138	30108	Economy	3300.00
0005432383616	30108	Economy	3300.00
0005432728117	30108	Economy	3300.00
0005432383528	30108	Economy	3300.00
0005432728119	30108	Economy	3300.00
0005432728118	30108	Economy	3300.00
0005432383559	30108	Economy	3300.00
0005432728079	30108	Economy	3300.00
0005432383604	30108	Economy	3300.00
0005432383408	30108	Economy	3300.00
0005432383539	30108	Economy	3300.00
0005432383613	30108	Economy	3300.00
0005432728140	30108	Economy	3300.00
0005432383511	30108	Economy	3300.00
0005433194886	30108	Economy	3300.00
0005432383617	30108	Economy	3300.00
0005432728136	30108	Economy	3300.00
0005432383614	30108	Economy	3300.00
0005432383479	30108	Economy	3300.00
0005432383599	30108	Economy	3300.00
0005432383600	30108	Economy	3300.00
0005432383573	30108	Economy	3300.00
0005433451657	30108	Economy	3300.00
0005432383527	30108	Economy	3300.00
0005432728037	30108	Economy	3300.00
0005432728080	30108	Economy	3300.00
0005432383538	30108	Economy	3300.00
0005433451643	30108	Economy	3300.00
0005433451638	30108	Economy	3300.00
0005432383576	30108	Economy	3300.00
0005435529760	1725	Business	57200.00
0005435530050	1725	Business	57200.00
0005433517103	1725	Business	57200.00
0005435529749	1725	Business	57200.00
0005435529746	1725	Business	57200.00
0005435541493	1725	Business	57200.00
0005435541495	1725	Business	57200.00
0005435541505	1725	Business	57200.00
0005435530057	1725	Economy	19100.00
0005435530049	1725	Economy	19100.00
0005433517101	1725	Economy	19100.00
0005435541504	1725	Economy	19100.00
0005433517102	1725	Economy	19100.00
0005435541508	1725	Economy	19100.00
0005435530046	1725	Economy	19100.00
0005432294542	1725	Economy	19100.00
0005433517104	1725	Economy	19100.00
0005432925114	1725	Economy	19100.00
0005435541498	1725	Economy	21000.00
0005435529750	1725	Economy	21000.00
0005435541502	1725	Economy	21000.00
0005435529761	1725	Economy	21000.00
0005435529764	1725	Economy	21000.00
0005433517099	1725	Economy	19100.00
0005435529762	1725	Economy	19100.00
0005435530053	1725	Economy	19100.00
0005433517100	1725	Economy	19100.00
0005435541488	1725	Economy	19100.00
0005435530055	1725	Economy	19100.00
0005435541489	1725	Economy	19100.00
0005433517096	1725	Economy	19100.00
0005435541490	1725	Economy	19100.00
0005435529759	1725	Economy	19100.00
0005435529763	1725	Economy	19100.00
0005435529747	1725	Economy	19100.00
0005435530060	1725	Economy	19100.00
0005435541487	1725	Economy	19100.00
0005435541501	1725	Economy	19100.00
0005435529748	1725	Economy	19100.00
0005435530051	1725	Economy	19100.00
0005435541506	1725	Economy	19100.00
0005435541503	1725	Economy	19100.00
0005435541500	1725	Economy	19100.00
0005435530059	1725	Economy	19100.00
0005435529744	1725	Economy	19100.00
0005435529757	1725	Economy	19100.00
0005435541499	1725	Economy	19100.00
0005435530048	1725	Economy	19100.00
0005435530058	1725	Economy	19100.00
0005435530061	1725	Economy	19100.00
0005435529745	1725	Economy	19100.00
0005433517098	1725	Economy	19100.00
0005435529758	1725	Economy	19100.00
0005435541494	1725	Economy	19100.00
0005435530054	1725	Economy	19100.00
0005435529751	1725	Economy	19100.00
0005435530056	1725	Economy	19100.00
0005435529756	1725	Economy	19100.00
0005435541492	1725	Economy	19100.00
0005432925103	1725	Economy	19100.00
0005435530052	1725	Economy	19100.00
0005435529754	1725	Economy	19100.00
0005435541496	1725	Economy	19100.00
0005435529753	1725	Economy	19100.00
0005435530045	1725	Economy	19100.00
0005435529755	1725	Economy	19100.00
0005435541491	1725	Economy	19100.00
0005435530047	1725	Economy	19100.00
0005435541497	1725	Economy	19100.00
0005432925115	1725	Economy	19100.00
0005433517097	1725	Economy	19100.00
0005435541507	1725	Economy	19100.00
0005435529752	1725	Economy	19100.00
0005435541315	21994	Business	57200.00
0005435518159	21994	Business	57200.00
0005435541253	21994	Business	57200.00
0005435541204	21994	Business	57200.00
0005435518043	21994	Business	57200.00
0005433517064	21994	Business	57200.00
0005435541347	21994	Business	57200.00
0005432925148	21994	Business	57200.00
0005435518158	21994	Business	57200.00
0005435541298	21994	Business	57200.00
0005433517035	21994	Economy	19100.00
0005435518160	21994	Economy	19100.00
0005435518102	21994	Economy	21000.00
0005435541339	21994	Economy	19100.00
0005435541219	21994	Economy	19100.00
0005433516979	21994	Economy	19100.00
0005435541359	21994	Economy	19100.00
0005435541393	21994	Economy	19100.00
0005433517001	21994	Economy	19100.00
0005435541289	21994	Economy	19100.00
0005433517026	21994	Economy	19100.00
0005433517029	21994	Economy	19100.00
0005435541271	21994	Economy	19100.00
0005433517034	21994	Economy	19100.00
0005435541251	21994	Economy	19100.00
0005435518154	21994	Economy	19100.00
0005435541372	21994	Economy	19100.00
0005435518162	21994	Economy	19100.00
0005435541349	21994	Economy	19100.00
0005432925147	21994	Economy	19100.00
0005435541252	21994	Economy	19100.00
0005435518207	21994	Economy	19100.00
0005435518171	21994	Economy	19100.00
0005435541256	21994	Economy	19100.00
0005435541246	21994	Economy	19100.00
0005433517022	21994	Economy	19100.00
0005433517027	21994	Economy	19100.00
0005433517000	21994	Economy	19100.00
0005435541371	21994	Economy	19100.00
0005435541323	21994	Economy	19100.00
0005435518172	21994	Economy	19100.00
0005435541270	21994	Economy	19100.00
0005435518176	21994	Economy	19100.00
0005435541370	21994	Economy	19100.00
0005432925145	21994	Economy	19100.00
0005432925146	21994	Economy	19100.00
0005435541287	21994	Economy	19100.00
0005435518122	21994	Economy	19100.00
0005433516980	21994	Economy	19100.00
0005433517063	21994	Economy	19100.00
0005435518051	21994	Economy	19100.00
0005435541317	21994	Economy	19100.00
0005435541350	21994	Economy	19100.00
0005435518115	21994	Economy	19100.00
0005435541363	21994	Economy	19100.00
0005433517033	21994	Economy	19100.00
0005435541243	21994	Economy	19100.00
0005433516999	21994	Economy	19100.00
0005433517028	21994	Economy	19100.00
0005432839724	7370	Business	18500.00
0005432839742	7370	Business	18500.00
0005434459265	7370	Business	18500.00
0005434459282	7370	Business	18500.00
0005435491450	7370	Business	18500.00
0005434459271	7370	Business	18500.00
0005432839745	7370	Business	18500.00
0005434459270	7370	Business	18500.00
0005434459284	7370	Business	18500.00
0005434459274	7370	Business	18500.00
0005432839729	7370	Economy	6200.00
0005435252896	7370	Economy	6200.00
0005435491469	7370	Economy	6200.00
0005434459281	7370	Economy	6200.00
0005432839750	7370	Economy	6200.00
0005432839726	7370	Economy	6200.00
0005432839752	7370	Economy	6200.00
0005432839727	7370	Economy	6200.00
0005432839747	7370	Economy	6200.00
0005432839741	7370	Economy	6800.00
0005435491463	7370	Economy	6800.00
0005435252942	7370	Economy	6800.00
0005432839739	7370	Economy	6800.00
0005435252909	7370	Economy	6200.00
0005435252908	7370	Economy	6200.00
0005434459279	7370	Economy	6200.00
0005432839728	7370	Economy	6200.00
0005434459272	7370	Economy	6200.00
0005434459280	7370	Economy	6200.00
0005432073469	7370	Economy	6200.00
0005434459277	7370	Economy	6200.00
0005434459269	7370	Economy	6200.00
0005432839738	7370	Economy	6200.00
0005435252923	7370	Economy	6200.00
0005434459283	7370	Economy	6200.00
0005434459268	7370	Economy	6200.00
0005434664997	7370	Economy	6200.00
0005432839722	7370	Economy	6200.00
0005432839733	7370	Economy	6200.00
0005435252948	7370	Economy	6200.00
0005432839746	7370	Economy	6200.00
0005432839734	7370	Economy	6200.00
0005434459264	7370	Economy	6200.00
0005434459278	7370	Economy	6200.00
0005432839748	7370	Economy	6200.00
0005432839744	7370	Economy	6200.00
0005432839749	7370	Economy	6200.00
0005434459273	7370	Economy	6200.00
0005432839730	7370	Economy	6200.00
0005432839743	7370	Economy	6200.00
0005432839735	7370	Economy	6200.00
0005434664980	7370	Economy	6200.00
0005432839725	7370	Economy	6200.00
0005432839723	7370	Economy	6200.00
0005432839751	7370	Economy	6200.00
0005432841058	7370	Economy	6200.00
0005432073468	7370	Economy	6200.00
0005432073470	7370	Economy	6200.00
0005434664979	7370	Economy	6200.00
0005435252947	7370	Economy	6200.00
0005435491464	7370	Economy	6200.00
0005434459266	7370	Economy	6200.00
0005432073471	7370	Economy	6200.00
0005435252949	7370	Economy	6200.00
0005435252940	7370	Economy	6200.00
0005432839736	7370	Economy	6200.00
0005435252974	7370	Economy	6200.00
0005432841059	7370	Economy	6200.00
0005434664998	7370	Economy	6200.00
0005435252924	7370	Economy	6200.00
0005434459285	7370	Economy	6200.00
0005435252993	7370	Economy	6200.00
0005435491465	7370	Economy	6200.00
0005435252973	7370	Economy	6200.00
0005435491468	7370	Economy	6200.00
0005434459267	7370	Economy	6200.00
0005435252917	7370	Economy	6200.00
0005432839731	7370	Economy	6200.00
0005435252992	7370	Economy	6200.00
0005435252943	7370	Economy	6200.00
0005432839732	7370	Economy	6200.00
0005432839740	7370	Economy	6200.00
0005432839737	7370	Economy	6200.00
0005434459275	7370	Economy	6200.00
0005434459276	7370	Economy	6200.00
0005434664981	7370	Economy	6200.00
0005432839492	28901	Business	18500.00
0005434459071	28901	Business	18500.00
0005432839594	28901	Business	18500.00
0005434665011	28901	Business	18500.00
0005432839525	28901	Business	18500.00
0005432839583	28901	Business	18500.00
0005432839412	28901	Business	18500.00
0005434459161	28901	Business	18500.00
0005435253114	28901	Business	18500.00
0005435253116	28901	Business	18500.00
0005434459036	28901	Business	18500.00
0005434459012	28901	Economy	6200.00
0005432839440	28901	Economy	6200.00
0005434458951	28901	Economy	6200.00
0005435253107	28901	Economy	6200.00
0005435253105	28901	Economy	6200.00
0005434459118	28901	Economy	6200.00
0005432839529	28901	Economy	6200.00
0005432839479	28901	Economy	6200.00
0005435253102	28901	Economy	6200.00
0005432839442	28901	Economy	6200.00
0005435253104	28901	Economy	6800.00
0005432839454	28901	Economy	6800.00
0005432839430	28901	Economy	6800.00
0005434459064	28901	Economy	6800.00
0005432839581	28901	Economy	6800.00
0005432839550	28901	Economy	6200.00
0005435253112	28901	Economy	6200.00
0005435253100	28901	Economy	6200.00
0005432839623	28901	Economy	6200.00
0005432839501	28901	Economy	6200.00
0005434459151	28901	Economy	6200.00
0005434459090	28901	Economy	6200.00
0005432839429	28901	Economy	6200.00
0005432839527	28901	Economy	6200.00
0005434459197	28901	Economy	6200.00
0005432839666	28901	Economy	6200.00
0005432839667	28901	Economy	6200.00
0005435253115	28901	Economy	6200.00
0005432001069	28901	Economy	6200.00
0005432839622	28901	Economy	6200.00
0005432839488	28901	Economy	6200.00
0005432839493	28901	Economy	6200.00
0005434459160	28901	Economy	6200.00
0005432839416	28901	Economy	6200.00
0005434459035	28901	Economy	6200.00
0005435253111	28901	Economy	6200.00
0005434665012	28901	Economy	6200.00
0005432839486	28901	Economy	6200.00
0005434459011	28901	Economy	6200.00
0005434459143	28901	Economy	6200.00
0005434459119	28901	Economy	6200.00
0005434459063	28901	Economy	6200.00
0005434459073	28901	Economy	6200.00
0005434459089	28901	Economy	6200.00
0005434665013	28901	Economy	6200.00
0005432839415	28901	Economy	6200.00
0005434459059	28901	Economy	6200.00
0005432839441	28901	Economy	6200.00
0005435491492	28901	Economy	6200.00
0005434459072	28901	Economy	6200.00
0005435253109	28901	Economy	6200.00
0005435491490	28901	Economy	6200.00
0005434459144	28901	Economy	6200.00
0005432839524	28901	Economy	6200.00
0005432839511	28901	Economy	6200.00
0005432839453	28901	Economy	6200.00
0005432839331	28901	Economy	6200.00
0005435253108	28901	Economy	6200.00
0005435253101	28901	Economy	6200.00
0005432839502	28901	Economy	6200.00
0005435253099	28901	Economy	6200.00
0005432839487	28901	Economy	6200.00
0005434459058	28901	Economy	6200.00
0005434459034	28901	Economy	6200.00
0005434459065	28901	Economy	6200.00
0005432841036	28901	Economy	6200.00
0005435253110	28901	Economy	6200.00
0005435253106	28901	Economy	6200.00
0005432839582	28901	Economy	6200.00
0005435253113	28901	Economy	6200.00
0005435491493	28901	Economy	6200.00
0005435253103	28901	Economy	6200.00
0005434459123	28901	Economy	6200.00
0005435253098	28901	Economy	6200.00
0005435491491	28901	Economy	6200.00
0005432839478	28901	Economy	6200.00
0005432839528	28901	Economy	6200.00
0005434459074	28901	Economy	6200.00
0005435990784	8823	Business	145300.00
0005435990782	8823	Business	145300.00
0005434276135	8823	Business	145300.00
0005435990785	8823	Business	145300.00
0005435990788	8823	Economy	48400.00
0005434276108	8823	Economy	48400.00
0005435990781	8823	Economy	48400.00
0005435990787	8823	Economy	48400.00
0005435990783	8823	Economy	48400.00
0005435990786	8823	Economy	48400.00
0005434276157	15743	Business	145300.00
0005435990717	15743	Economy	48400.00
0005434276156	15743	Economy	48400.00
0005434276159	15743	Economy	48400.00
0005434276160	15743	Economy	48400.00
0005435990698	15743	Economy	48400.00
0005435990716	15743	Economy	48400.00
0005435990715	15743	Economy	48400.00
0005435990727	15743	Economy	48400.00
0005434276158	15743	Economy	48400.00
0005432427169	30850	Economy	14500.00
0005432427176	30850	Economy	14500.00
0005433476937	30850	Economy	14500.00
0005433476940	30850	Economy	14500.00
0005432427162	30850	Economy	14500.00
0005432427160	30850	Economy	14500.00
0005432427168	30850	Economy	14500.00
0005432427155	30850	Economy	14500.00
0005433476938	30850	Economy	14500.00
0005432427177	30850	Economy	14500.00
0005433476941	30850	Economy	14500.00
0005433476939	30850	Economy	14500.00
0005432427163	30850	Economy	14500.00
0005433476936	30850	Economy	14500.00
0005432427161	30850	Economy	14500.00
0005432427159	30850	Economy	14500.00
0005432427175	30850	Economy	14500.00
0005433468455	23834	Economy	13300.00
0005433468454	23834	Economy	13300.00
0005433468457	23834	Economy	12100.00
0005432909400	23834	Economy	12100.00
0005433468473	23834	Economy	12100.00
0005433468456	23834	Economy	12100.00
0005432909406	23834	Economy	12100.00
0005433468437	23834	Economy	12100.00
0005432909401	23834	Economy	12100.00
0005433468460	23834	Economy	12100.00
0005433468469	23834	Economy	12100.00
0005432909407	23834	Economy	12100.00
0005432909398	23834	Economy	12100.00
0005433468411	23834	Economy	12100.00
0005433468465	23834	Economy	12100.00
0005433468477	23834	Economy	12100.00
0005433468464	23834	Economy	12100.00
0005432909405	23834	Economy	12100.00
0005432909404	23834	Economy	12100.00
0005433468459	23834	Economy	12100.00
0005432909403	23834	Economy	12100.00
0005432909402	23834	Economy	12100.00
0005433468503	23834	Economy	12100.00
0005433468467	23834	Economy	12100.00
0005433468441	23834	Economy	12100.00
0005433468468	23834	Economy	12100.00
0005432909399	23834	Economy	12100.00
0005433468436	23834	Economy	12100.00
0005433468428	23834	Economy	12100.00
0005432909408	23834	Economy	12100.00
0005434149959	6401	Business	36600.00
0005432361435	6401	Business	36600.00
0005435177559	6401	Business	36600.00
0005432361473	6401	Business	36600.00
0005432361455	6401	Business	36600.00
0005434149853	6401	Business	36600.00
0005432361449	6401	Business	36600.00
0005435177577	6401	Business	36600.00
0005432336299	6401	Business	36600.00
0005435490280	6401	Business	36600.00
0005432361470	6401	Business	36600.00
0005432361451	6401	Economy	12200.00
0005432062349	6401	Economy	12200.00
0005432361448	6401	Economy	12200.00
0005434149883	6401	Economy	12200.00
0005432361464	6401	Economy	12200.00
0005434149918	6401	Economy	12200.00
0005432361447	6401	Economy	12200.00
0005432062351	6401	Economy	12200.00
0005432336300	6401	Economy	12200.00
0005435490269	6401	Economy	12200.00
0005432336306	6401	Economy	12200.00
0005435177451	6401	Economy	12200.00
0005434149880	6401	Economy	12200.00
0005432361444	6401	Economy	12200.00
0005435177564	6401	Economy	12200.00
0005435490268	6401	Economy	12200.00
0005432336309	6401	Economy	12200.00
0005432062347	6401	Economy	12200.00
0005432361437	6401	Economy	12200.00
0005432361445	6401	Economy	12200.00
0005432336304	6401	Economy	12200.00
0005432363488	6401	Economy	12200.00
0005432361433	6401	Economy	12200.00
0005432361456	6401	Economy	12200.00
0005432363489	6401	Economy	12200.00
0005435177544	6401	Economy	12200.00
0005435177537	6401	Economy	12200.00
0005434149882	6401	Economy	12200.00
0005432361466	6401	Economy	12200.00
0005435177607	6401	Economy	12200.00
0005432361426	6401	Economy	12200.00
0005432361468	6401	Economy	12200.00
0005432361453	6401	Economy	12200.00
0005432361465	6401	Economy	12200.00
0005435177474	6401	Economy	12200.00
0005434149844	6401	Economy	12200.00
0005432361452	6401	Economy	12200.00
0005434149842	6401	Economy	13400.00
0005432336303	6401	Economy	12200.00
0005435177509	6401	Economy	13400.00
0005435177570	6401	Economy	13400.00
0005435490272	6401	Economy	13400.00
0005432361462	6401	Economy	13400.00
0005432361441	6401	Economy	13400.00
0005432361443	6401	Economy	12200.00
0005435177496	6401	Economy	12200.00
0005434149924	6401	Economy	12200.00
0005432336307	6401	Economy	12200.00
0005435177478	6401	Economy	12200.00
0005432361463	6401	Economy	12200.00
0005432361474	6401	Economy	12200.00
0005432336308	6401	Economy	12200.00
0005432361428	6401	Economy	12200.00
0005435490281	6401	Economy	12200.00
0005432336302	6401	Economy	12200.00
0005432361454	6401	Economy	12200.00
0005432361438	6401	Economy	12200.00
0005432361439	6401	Economy	12200.00
0005435177459	6401	Economy	12200.00
0005435490275	6401	Economy	12200.00
0005435490277	6401	Economy	12200.00
0005435177508	6401	Economy	12200.00
0005432361450	6401	Economy	12200.00
0005435177571	6401	Economy	12200.00
0005434149881	6401	Economy	12200.00
0005432062352	6401	Economy	12200.00
0005434149919	6401	Economy	12200.00
0005432361461	6401	Economy	12200.00
0005432363491	6401	Economy	12200.00
0005435177606	6401	Economy	12200.00
0005434149938	6401	Economy	12200.00
0005432361458	6401	Economy	12200.00
0005434149888	6401	Economy	12200.00
0005432361457	6401	Economy	12200.00
0005435177476	6401	Economy	12200.00
0005432361430	6401	Economy	12200.00
0005432361427	6401	Economy	12200.00
0005432361429	6401	Economy	12200.00
0005432361446	6401	Economy	12200.00
0005435490276	6401	Economy	12200.00
0005432361436	6401	Economy	12200.00
0005432062348	6401	Economy	12200.00
0005432336305	6401	Economy	12200.00
0005432361431	6401	Economy	12200.00
0005432361460	6401	Economy	12200.00
0005432361459	6401	Economy	12200.00
0005435177504	6401	Economy	12200.00
0005435177576	6401	Economy	12200.00
0005432361471	6401	Economy	12200.00
0005432336301	6401	Economy	12200.00
0005432361472	6401	Economy	12200.00
0005435177545	6401	Economy	12200.00
0005432336298	6401	Economy	12200.00
0005432361469	6401	Economy	12200.00
0005435177410	6401	Economy	12200.00
0005435490279	6401	Economy	12200.00
0005435177378	6401	Economy	12200.00
0005432361440	6401	Economy	12200.00
0005435490278	6401	Economy	12200.00
0005435177379	6401	Economy	12200.00
0005432361467	6401	Economy	12200.00
0005435490271	6401	Economy	12200.00
0005435177535	6401	Economy	12200.00
0005435177589	6401	Economy	12200.00
0005435177380	6401	Economy	12200.00
0005432361434	6401	Economy	12200.00
0005432361432	6401	Economy	12200.00
0005432363490	6401	Economy	12200.00
0005432361442	6401	Economy	12200.00
0005432062350	6401	Economy	12200.00
0005435177704	21026	Business	36600.00
0005435177706	21026	Business	36600.00
0005432336190	21026	Business	36600.00
0005432361017	21026	Business	36600.00
0005432361125	21026	Business	36600.00
0005434149998	21026	Business	36600.00
0005432361200	21026	Business	36600.00
0005432361207	21026	Business	36600.00
0005432336238	21026	Business	36600.00
0005435177692	21026	Economy	12200.00
0005432360889	21026	Economy	12200.00
0005432052816	21026	Economy	12200.00
0005432361052	21026	Economy	12200.00
0005432360965	21026	Economy	12200.00
0005435490315	21026	Economy	12200.00
0005435723089	21026	Economy	12200.00
0005432361043	21026	Economy	12200.00
0005432361208	21026	Economy	12200.00
0005435177688	21026	Economy	12200.00
0005432360939	21026	Economy	12200.00
0005435177690	21026	Economy	12200.00
0005435177712	21026	Economy	12200.00
0005432360831	21026	Economy	12200.00
0005435177711	21026	Economy	12200.00
0005432360988	21026	Economy	12200.00
0005432336258	21026	Economy	12200.00
0005435177694	21026	Economy	12200.00
0005435177699	21026	Economy	12200.00
0005432360797	21026	Economy	12200.00
0005434149999	21026	Economy	12200.00
0005432361061	21026	Economy	12200.00
0005435490313	21026	Economy	12200.00
0005434149995	21026	Economy	12200.00
0005435177689	21026	Economy	12200.00
0005435490316	21026	Economy	12200.00
0005432052815	21026	Economy	12200.00
0005435177710	21026	Economy	13400.00
0005434149997	21026	Economy	12200.00
0005434149996	21026	Economy	13400.00
0005432360852	21026	Economy	13400.00
0005432360865	21026	Economy	13400.00
0005432360759	21026	Economy	13400.00
0005432361060	21026	Economy	12200.00
0005434150000	21026	Economy	12200.00
0005432360953	21026	Economy	12200.00
0005435177691	21026	Economy	12200.00
0005432360830	21026	Economy	12200.00
0005435177685	21026	Economy	12200.00
0005432361056	21026	Economy	12200.00
0005432361151	21026	Economy	12200.00
0005434149994	21026	Economy	12200.00
0005432360917	21026	Economy	12200.00
0005432336251	21026	Economy	12200.00
0005435177702	21026	Economy	12200.00
0005435177697	21026	Economy	12200.00
0005432361194	21026	Economy	12200.00
0005432360940	21026	Economy	12200.00
0005432361238	21026	Economy	12200.00
0005435177707	21026	Economy	12200.00
0005432336185	21026	Economy	12200.00
0005435177700	21026	Economy	12200.00
0005435177693	21026	Economy	12200.00
0005432361201	21026	Economy	12200.00
0005432361282	21026	Economy	12200.00
0005432361063	21026	Economy	12200.00
0005435177709	21026	Economy	12200.00
0005432361062	21026	Economy	12200.00
0005435177686	21026	Economy	12200.00
0005435177687	21026	Economy	12200.00
0005432361101	21026	Economy	12200.00
0005432361100	21026	Economy	12200.00
0005435177684	21026	Economy	12200.00
0005435177703	21026	Economy	12200.00
0005435177705	21026	Economy	12200.00
0005432336221	21026	Economy	12200.00
0005435490314	21026	Economy	12200.00
0005432361163	21026	Economy	12200.00
0005432360853	21026	Economy	12200.00
0005432360947	21026	Economy	12200.00
0005432336189	21026	Economy	12200.00
0005432361040	21026	Economy	12200.00
0005432361281	21026	Economy	12200.00
0005435177708	21026	Economy	12200.00
0005435177698	21026	Economy	12200.00
0005434150001	21026	Economy	12200.00
0005432360851	21026	Economy	12200.00
0005434149993	21026	Economy	12200.00
0005435723090	21026	Economy	12200.00
0005432361087	21026	Economy	12200.00
0005432361110	21026	Economy	12200.00
0005432361124	21026	Economy	12200.00
0005434150002	21026	Economy	12200.00
0005435723088	21026	Economy	12200.00
0005435177695	21026	Economy	12200.00
0005435177696	21026	Economy	12200.00
0005435177701	21026	Economy	12200.00
0005434459115	17687	Economy	3400.00
0005434186266	17687	Economy	3400.00
0005434459095	17687	Economy	3400.00
0005434459138	17687	Economy	3400.00
0005434448365	17687	Economy	3100.00
0005434448370	17687	Economy	3100.00
0005434459136	17687	Economy	3100.00
0005434459134	17687	Economy	3100.00
0005434448351	17687	Economy	3100.00
0005434448357	17687	Economy	3100.00
0005434459181	17687	Economy	3100.00
0005434459085	17687	Economy	3100.00
0005434459060	17687	Economy	3100.00
0005434459142	17687	Economy	3100.00
0005434463956	17687	Economy	3100.00
0005434463955	17687	Economy	3100.00
0005434463965	17687	Economy	3100.00
0005434459113	17687	Economy	3100.00
0005434463960	17687	Economy	3100.00
0005434459182	17687	Economy	3100.00
0005434448362	17687	Economy	3100.00
0005434463957	17687	Economy	3100.00
0005434448354	17687	Economy	3100.00
0005434463967	17687	Economy	3100.00
0005434459116	17687	Economy	3100.00
0005434459137	17687	Economy	3100.00
0005434186265	17687	Economy	3100.00
0005434448361	17687	Economy	3100.00
0005434463966	17687	Economy	3100.00
0005434459146	17687	Economy	3100.00
0005434459111	17687	Economy	3100.00
0005434459135	17687	Economy	3100.00
0005434463959	17687	Economy	3100.00
0005434459082	17687	Economy	3100.00
0005434459117	17687	Economy	3100.00
0005434448355	17687	Economy	3100.00
0005434459139	17687	Economy	3100.00
0005434459148	17687	Economy	3100.00
0005434448369	17687	Economy	3100.00
0005434459147	17687	Economy	3100.00
0005434462837	29123	Economy	3400.00
0005434459272	29123	Economy	3400.00
0005434459281	29123	Economy	3100.00
0005434448390	29123	Economy	3100.00
0005434459265	29123	Economy	3100.00
0005434459275	29123	Economy	3100.00
0005434462838	29123	Economy	3100.00
0005434463975	29123	Economy	3100.00
0005434459264	29123	Economy	3100.00
0005434459271	29123	Economy	3100.00
0005434459282	29123	Economy	3100.00
0005434448389	29123	Economy	3100.00
0005434459276	29123	Economy	3100.00
0005434459266	29123	Economy	3100.00
0005434459280	29123	Economy	3100.00
0005434459277	29123	Economy	3100.00
0005434459285	29123	Economy	3100.00
0005434459267	29123	Economy	3100.00
0005434459273	29123	Economy	3100.00
0005434459269	29123	Economy	3100.00
0005434462836	29123	Economy	3100.00
0005434459284	29123	Economy	3100.00
0005434459270	29123	Economy	3100.00
0005434459279	29123	Economy	3100.00
0005434459274	29123	Economy	3100.00
0005434459278	29123	Economy	3100.00
0005434448388	29123	Economy	3100.00
0005434459268	29123	Economy	3100.00
0005434463976	29123	Economy	3100.00
0005434459283	29123	Economy	3100.00
0005432661917	21831	Business	185300.00
0005432658606	21831	Business	185300.00
0005432665290	21831	Business	185300.00
0005432661937	21831	Business	185300.00
0005432661926	21831	Business	185300.00
0005432658602	21831	Economy	61800.00
0005432658607	21831	Economy	61800.00
0005432665281	21831	Economy	61800.00
0005432665284	21831	Economy	61800.00
0005432665298	21831	Economy	61800.00
0005432658597	21831	Economy	61800.00
0005432658593	21831	Economy	61800.00
0005432665289	21831	Economy	67900.00
0005432661916	21831	Economy	67900.00
0005432661927	21831	Economy	67900.00
0005432658595	21831	Economy	61800.00
0005432658598	21831	Economy	61800.00
0005432661934	21831	Economy	61800.00
0005432661913	21831	Economy	61800.00
0005432658610	21831	Economy	61800.00
0005432665268	21831	Economy	61800.00
0005432658611	21831	Economy	61800.00
0005432658599	21831	Economy	61800.00
0005432661940	21831	Economy	61800.00
0005432661920	21831	Economy	61800.00
0005432665282	21831	Economy	61800.00
0005432661921	21831	Economy	61800.00
0005432661925	21831	Economy	61800.00
0005432658594	21831	Economy	61800.00
0005432665276	21831	Economy	61800.00
0005432661941	21831	Economy	61800.00
0005432665291	21831	Economy	61800.00
0005432658596	21831	Economy	61800.00
0005432665283	21831	Economy	61800.00
0005432658604	21831	Economy	61800.00
0005432661935	21831	Economy	61800.00
0005432661938	21831	Economy	61800.00
0005432665280	21831	Economy	61800.00
0005432665292	21831	Economy	61800.00
0005432661928	21831	Economy	61800.00
0005432658603	21831	Economy	61800.00
0005432661939	21831	Economy	61800.00
0005432658608	21831	Economy	61800.00
0005432665285	21831	Economy	61800.00
0005432658615	21831	Economy	61800.00
0005432661936	21831	Economy	61800.00
0005432658605	21831	Economy	61800.00
0005432665277	21831	Economy	61800.00
0005432605188	21456	Economy	7300.00
0005432605200	21456	Economy	7300.00
0005432605189	21456	Economy	7300.00
0005432605191	21456	Economy	6600.00
0005432605202	21456	Economy	6600.00
0005432605184	21456	Economy	6600.00
0005432605190	21456	Economy	6600.00
0005432605212	21456	Economy	6600.00
0005432605197	21456	Economy	6600.00
0005432605201	21456	Economy	6600.00
0005432605217	21456	Economy	6600.00
0005432605206	21456	Economy	6600.00
0005432605186	21456	Economy	6600.00
0005432605195	21456	Economy	6600.00
0005432605187	21456	Economy	6600.00
0005432605220	21456	Economy	6600.00
0005432605199	21456	Economy	6600.00
0005432605194	21456	Economy	6600.00
0005432605209	21456	Economy	6600.00
0005432605193	21456	Economy	6600.00
0005432605216	21456	Economy	6600.00
0005432605192	21456	Economy	6600.00
0005432605213	21456	Economy	6600.00
0005432605204	21456	Economy	6600.00
0005432605215	21456	Economy	6600.00
0005432605205	21456	Economy	6600.00
0005432605203	21456	Economy	6600.00
0005432605207	21456	Economy	6600.00
0005432605196	21456	Economy	6600.00
0005432605219	21456	Economy	6600.00
0005432605210	21456	Economy	6600.00
0005432605185	21456	Economy	6600.00
0005432605223	21456	Economy	6600.00
0005432605211	21456	Economy	6600.00
0005432605218	21456	Economy	6600.00
0005432605221	21456	Economy	6600.00
0005432605198	21456	Economy	6600.00
0005432605208	21456	Economy	6600.00
0005432605214	21456	Economy	6600.00
0005432605222	21456	Economy	6600.00
0005432605055	31687	Economy	7300.00
0005432604820	31687	Economy	7300.00
0005432604972	31687	Economy	6600.00
0005432604792	31687	Economy	6600.00
0005432604946	31687	Economy	6600.00
0005432604733	31687	Economy	6600.00
0005432604910	31687	Economy	6600.00
0005432604740	31687	Economy	6600.00
0005432604891	31687	Economy	6600.00
0005432604743	31687	Economy	6600.00
0005432604793	31687	Economy	6600.00
0005432604791	31687	Economy	6600.00
0005432604911	31687	Economy	6600.00
0005432604744	31687	Economy	6600.00
0005432604789	31687	Economy	6600.00
0005432604947	31687	Economy	6600.00
0005432604914	31687	Economy	6600.00
0005432604796	31687	Economy	6600.00
0005432604855	31687	Economy	6600.00
0005432604833	31687	Economy	6600.00
0005432604787	31687	Economy	6600.00
0005432604722	31687	Economy	6600.00
0005432604913	31687	Economy	6600.00
0005432605005	31687	Economy	6600.00
0005432604795	31687	Economy	6600.00
0005432604912	31687	Economy	6600.00
0005432604745	31687	Economy	6600.00
0005432604915	31687	Economy	6600.00
0005432604790	31687	Economy	6600.00
0005432604721	31687	Economy	6600.00
0005432604742	31687	Economy	6600.00
0005432604803	31687	Economy	6600.00
0005432604844	31687	Economy	6600.00
0005432605006	31687	Economy	6600.00
0005432604741	31687	Economy	6600.00
0005432604890	31687	Economy	6600.00
0005432604875	31687	Economy	6600.00
0005432604871	31687	Economy	6600.00
0005432604739	31687	Economy	6600.00
0005433293388	29604	Economy	19500.00
0005435154606	29604	Economy	19500.00
0005435154614	29604	Economy	19500.00
0005433293386	29604	Economy	17800.00
0005435154607	29604	Economy	17800.00
0005433293394	29604	Economy	17800.00
0005435154608	29604	Economy	17800.00
0005433293395	29604	Economy	17800.00
0005433293391	29604	Economy	17800.00
0005433293392	29604	Economy	17800.00
0005435154610	29604	Economy	17800.00
0005433293398	29604	Economy	17800.00
0005433293396	29604	Economy	17800.00
0005435154611	29604	Economy	17800.00
0005433293387	29604	Economy	17800.00
0005433293389	29604	Economy	17800.00
0005433293385	29604	Economy	17800.00
0005433293390	29604	Economy	17800.00
0005433293399	29604	Economy	17800.00
0005433293393	29604	Economy	17800.00
0005433293397	29604	Economy	17800.00
0005433473475	6695	Economy	14000.00
0005435257323	6695	Economy	14000.00
0005433473480	6695	Economy	12700.00
0005435257303	6695	Economy	12700.00
0005435257296	6695	Economy	12700.00
0005435257287	6695	Economy	12700.00
0005433473468	6695	Economy	12700.00
0005433473473	6695	Economy	12700.00
0005433473462	6695	Economy	12700.00
0005433473472	6695	Economy	12700.00
0005433473476	6695	Economy	12700.00
0005433473463	6695	Economy	12700.00
0005435257299	6695	Economy	12700.00
0005433473469	6695	Economy	12700.00
0005433473477	6695	Economy	12700.00
0005433473467	6695	Economy	12700.00
0005433473465	6695	Economy	12700.00
0005435257291	6695	Economy	12700.00
0005433473474	6695	Economy	12700.00
0005433473479	6695	Economy	12700.00
0005433473471	6695	Economy	12700.00
0005435257321	6695	Economy	12700.00
0005435257304	6695	Economy	12700.00
0005433473464	6695	Economy	12700.00
0005433473466	6695	Economy	12700.00
0005433473470	6695	Economy	12700.00
0005433473478	6695	Economy	12700.00
0005433473373	23906	Economy	14000.00
0005433473378	23906	Economy	12700.00
0005433473391	23906	Economy	12700.00
0005435257354	23906	Economy	12700.00
0005435257356	23906	Economy	12700.00
0005433473367	23906	Economy	12700.00
0005433473379	23906	Economy	12700.00
0005433473397	23906	Economy	12700.00
0005433473347	23906	Economy	12700.00
0005433473386	23906	Economy	12700.00
0005435257353	23906	Economy	12700.00
0005435257350	23906	Economy	12700.00
0005433473362	23906	Economy	12700.00
0005433473348	23906	Economy	12700.00
0005433473345	23906	Economy	12700.00
0005433473349	23906	Economy	12700.00
0005435257347	23906	Economy	12700.00
0005433473352	23906	Economy	12700.00
0005435257355	23906	Economy	12700.00
0005433473400	23906	Economy	12700.00
0005433473384	23906	Economy	12700.00
0005433473406	23906	Economy	12700.00
0005433473381	23906	Economy	12700.00
0005433473385	23906	Economy	12700.00
0005433473405	23906	Economy	12700.00
0005435257345	23906	Economy	12700.00
0005433473351	23906	Economy	12700.00
0005433473402	23906	Economy	12700.00
0005433473396	23906	Economy	12700.00
0005435257346	23906	Economy	12700.00
0005435257349	23906	Economy	12700.00
0005433473365	23906	Economy	12700.00
0005433473361	23906	Economy	12700.00
0005435257351	23906	Economy	12700.00
0005433473380	23906	Economy	12700.00
0005435257352	23906	Economy	12700.00
0005435257348	23906	Economy	12700.00
0005433473350	23906	Economy	12700.00
0005433473401	23906	Economy	12700.00
0005435904908	18908	Economy	6600.00
0005434606872	18908	Economy	6600.00
0005435904907	18908	Economy	6600.00
0005435904723	18908	Economy	6600.00
0005435904906	18908	Economy	6600.00
0005434604978	22331	Economy	6600.00
0005434606901	22331	Economy	6600.00
0005434606903	22331	Economy	6600.00
0005435904710	22331	Economy	6600.00
0005434604977	22331	Economy	6600.00
0005434606902	22331	Economy	6600.00
0005434606899	22331	Economy	6600.00
0005435904709	22331	Economy	6600.00
0005434604975	22331	Economy	6600.00
0005434606900	22331	Economy	6600.00
0005434604976	22331	Economy	6600.00
0005434604974	22331	Economy	6600.00
0005435904443	3855	Economy	22600.00
0005435904442	3855	Economy	22600.00
0005434602951	3855	Economy	22600.00
0005434522533	3855	Economy	22600.00
0005434602956	3855	Economy	22600.00
0005434602959	3855	Economy	22600.00
0005434602960	3855	Economy	22600.00
0005434522529	3855	Economy	22600.00
0005434602952	3855	Economy	22600.00
0005435904441	3855	Economy	22600.00
0005435904444	3855	Economy	22600.00
0005434602957	3855	Economy	22600.00
0005434602955	3855	Economy	22600.00
0005435904440	3855	Economy	22600.00
0005434602958	3855	Economy	22600.00
0005434522532	3855	Economy	22600.00
0005434522527	3855	Economy	22600.00
0005434602953	3855	Economy	22600.00
0005434522526	3855	Economy	22600.00
0005434522530	3855	Economy	22600.00
0005434522531	3855	Economy	22600.00
0005434602954	3855	Economy	22600.00
0005434522528	3855	Economy	22600.00
0005435904439	3855	Economy	22600.00
0005434604952	19055	Economy	24900.00
0005434604935	19055	Economy	24900.00
0005434602925	19055	Economy	24900.00
0005434602937	19055	Economy	22600.00
0005435904460	19055	Economy	22600.00
0005434602923	19055	Economy	22600.00
0005434604936	19055	Economy	22600.00
0005435904463	19055	Economy	22600.00
0005434604942	19055	Economy	22600.00
0005435904459	19055	Economy	22600.00
0005434522504	19055	Economy	22600.00
0005434604949	19055	Economy	22600.00
0005434602924	19055	Economy	22600.00
0005435904461	19055	Economy	22600.00
0005435904720	19055	Economy	22600.00
0005434604943	19055	Economy	22600.00
0005434604938	19055	Economy	22600.00
0005434522506	19055	Economy	22600.00
0005435904719	19055	Economy	22600.00
0005434522505	19055	Economy	22600.00
0005434604937	19055	Economy	22600.00
0005434602932	19055	Economy	22600.00
0005434604930	19055	Economy	22600.00
0005435904462	19055	Economy	22600.00
0005434602933	19055	Economy	22600.00
0005434604932	19055	Economy	22600.00
0005432891358	378	Business	44500.00
0005432748412	378	Business	44500.00
0005432748409	378	Business	44500.00
0005432748410	378	Business	44500.00
0005432748404	378	Business	44500.00
0005432751597	378	Business	44500.00
0005432220099	378	Business	44500.00
0005432748435	378	Business	44500.00
0005433293327	378	Business	44500.00
0005432753374	378	Business	44500.00
0005435154663	378	Business	44500.00
0005432891349	378	Economy	14800.00
0005432748419	378	Economy	14800.00
0005432748422	378	Economy	14800.00
0005432891346	378	Economy	14800.00
0005435154657	378	Economy	14800.00
0005435154664	378	Economy	14800.00
0005432891322	378	Economy	14800.00
0005432891350	378	Economy	14800.00
0005432748428	378	Economy	16300.00
0005432753373	378	Economy	16300.00
0005432748439	378	Economy	16300.00
0005432891259	378	Economy	16300.00
0005432748438	378	Economy	16300.00
0005432748405	378	Economy	14800.00
0005432891291	378	Economy	14800.00
0005432748440	378	Economy	14800.00
0005432891327	378	Economy	14800.00
0005432748424	378	Economy	14800.00
0005435154660	378	Economy	14800.00
0005432751600	378	Economy	14800.00
0005432748406	378	Economy	14800.00
0005432748418	378	Economy	14800.00
0005432749832	378	Economy	14800.00
0005432748411	378	Economy	14800.00
0005432891333	378	Economy	14800.00
0005432220097	378	Economy	14800.00
0005435627124	378	Economy	14800.00
0005432748429	378	Economy	14800.00
0005433293326	378	Economy	14800.00
0005432753375	378	Economy	14800.00
0005432748415	378	Economy	14800.00
0005435627125	378	Economy	14800.00
0005432748407	378	Economy	14800.00
0005432891348	378	Economy	14800.00
0005432748436	378	Economy	14800.00
0005432753372	378	Economy	14800.00
0005432748434	378	Economy	14800.00
0005432748403	378	Economy	14800.00
0005432891357	378	Economy	14800.00
0005433293336	378	Economy	14800.00
0005432748437	378	Economy	14800.00
0005432891292	378	Economy	14800.00
0005432891302	378	Economy	14800.00
0005432220098	378	Economy	14800.00
0005432748421	378	Economy	14800.00
0005432891213	378	Economy	14800.00
0005435627123	378	Economy	14800.00
0005432748433	378	Economy	14800.00
0005435154659	378	Economy	14800.00
0005432748414	378	Economy	14800.00
0005432748427	378	Economy	14800.00
0005435154662	378	Economy	14800.00
0005433875403	378	Economy	14800.00
0005432748430	378	Economy	14800.00
0005433293359	378	Economy	14800.00
0005432748431	378	Economy	14800.00
0005432748413	378	Economy	14800.00
0005432748416	378	Economy	14800.00
0005432748426	378	Economy	14800.00
0005432748420	378	Economy	14800.00
0005432748423	378	Economy	14800.00
0005432748425	378	Economy	14800.00
0005432220100	378	Economy	14800.00
0005435154658	378	Economy	14800.00
0005432748408	378	Economy	14800.00
0005432751599	378	Economy	14800.00
0005432891260	378	Economy	14800.00
0005432748417	378	Economy	14800.00
0005432891265	378	Economy	14800.00
0005432220101	378	Economy	14800.00
0005432749833	378	Economy	14800.00
0005433293338	378	Economy	14800.00
0005435154665	378	Economy	14800.00
0005432751598	378	Economy	14800.00
0005432748432	378	Economy	14800.00
0005435154661	378	Economy	14800.00
0005432747992	12053	Business	44500.00
0005432748120	12053	Business	44500.00
0005434153564	12053	Business	44500.00
0005432747894	12053	Business	44500.00
0005432748006	12053	Business	44500.00
0005434153565	12053	Business	44500.00
0005432748191	12053	Business	44500.00
0005432748321	12053	Business	44500.00
0005432214852	12053	Economy	14800.00
0005432214853	12053	Economy	14800.00
0005432748018	12053	Economy	14800.00
0005432748059	12053	Economy	14800.00
0005432748273	12053	Economy	14800.00
0005432753353	12053	Economy	14800.00
0005432748080	12053	Economy	14800.00
0005432748190	12053	Economy	14800.00
0005432747977	12053	Economy	16300.00
0005432891458	12053	Economy	16300.00
0005432748319	12053	Economy	16300.00
0005432749811	12053	Economy	16300.00
0005432748240	12053	Economy	16300.00
0005432891460	12053	Economy	14800.00
0005432891470	12053	Economy	14800.00
0005432891463	12053	Economy	14800.00
0005432748061	12053	Economy	14800.00
0005432748055	12053	Economy	14800.00
0005432891466	12053	Economy	14800.00
0005432753351	12053	Economy	14800.00
0005432748029	12053	Economy	14800.00
0005432748058	12053	Economy	14800.00
0005432891468	12053	Economy	14800.00
0005432748320	12053	Economy	14800.00
0005432891451	12053	Economy	14800.00
0005432748014	12053	Economy	14800.00
0005432891456	12053	Economy	14800.00
0005433875417	12053	Economy	14800.00
0005432891452	12053	Economy	14800.00
0005432891454	12053	Economy	14800.00
0005432891457	12053	Economy	14800.00
0005432748133	12053	Economy	14800.00
0005432891465	12053	Economy	14800.00
0005432748012	12053	Economy	14800.00
0005432749818	12053	Economy	14800.00
0005432891453	12053	Economy	14800.00
0005432891455	12053	Economy	14800.00
0005432891461	12053	Economy	14800.00
0005432748013	12053	Economy	14800.00
0005432748121	12053	Economy	14800.00
0005432748104	12053	Economy	14800.00
0005432753352	12053	Economy	14800.00
0005432748052	12053	Economy	14800.00
0005432748024	12053	Economy	14800.00
0005432748098	12053	Economy	14800.00
0005432748175	12053	Economy	14800.00
0005432748161	12053	Economy	14800.00
0005432891462	12053	Economy	14800.00
0005432748136	12053	Economy	14800.00
0005432748128	12053	Economy	14800.00
0005432753335	12053	Economy	14800.00
0005432748174	12053	Economy	14800.00
0005432891467	12053	Economy	14800.00
0005432749803	12053	Economy	14800.00
0005432748067	12053	Economy	14800.00
0005432748060	12053	Economy	14800.00
0005432748173	12053	Economy	14800.00
0005433875418	12053	Economy	14800.00
0005432747991	12053	Economy	14800.00
0005432747893	12053	Economy	14800.00
0005432753334	12053	Economy	14800.00
0005432891459	12053	Economy	14800.00
0005434153566	12053	Economy	14800.00
0005432748166	12053	Economy	14800.00
0005432748227	12053	Economy	14800.00
0005432891464	12053	Economy	14800.00
0005432891469	12053	Economy	14800.00
0005432928074	18978	Economy	28200.00
0005433525270	18978	Economy	28200.00
0005433525271	18978	Economy	28200.00
0005433531373	18978	Economy	25700.00
0005432928040	18978	Economy	25700.00
0005433533389	18978	Economy	25700.00
0005433533388	18978	Economy	25700.00
0005433533391	18978	Economy	25700.00
0005433531374	18978	Economy	25700.00
0005433525274	18978	Economy	25700.00
0005432928029	18978	Economy	25700.00
0005432928041	18978	Economy	25700.00
0005433525278	18978	Economy	25700.00
0005433525279	18978	Economy	25700.00
0005433525277	18978	Economy	25700.00
0005432928080	18978	Economy	25700.00
0005433525275	18978	Economy	25700.00
0005433533390	18978	Economy	25700.00
0005433525280	18978	Economy	25700.00
0005433531375	18978	Economy	25700.00
0005433525272	18978	Economy	25700.00
0005433525276	18978	Economy	25700.00
0005433525273	18978	Economy	25700.00
0005433531376	18978	Economy	25700.00
0005432928081	18978	Economy	25700.00
0005433525184	32493	Economy	28200.00
0005433525190	32493	Economy	25700.00
0005433525211	32493	Economy	25700.00
0005433525150	32493	Economy	25700.00
0005433527293	32493	Economy	25700.00
0005433525185	32493	Economy	25700.00
0005432928110	32493	Economy	25700.00
0005433525175	32493	Economy	25700.00
0005432928112	32493	Economy	25700.00
0005432928113	32493	Economy	25700.00
0005433525183	32493	Economy	25700.00
0005433527301	32493	Economy	25700.00
0005433525222	32493	Economy	25700.00
0005433527270	32493	Economy	25700.00
0005433525223	32493	Economy	25700.00
0005433531357	32493	Economy	25700.00
0005432928114	32493	Economy	25700.00
0005433525192	32493	Economy	25700.00
0005433525204	32493	Economy	25700.00
0005433525170	32493	Economy	25700.00
0005432928115	32493	Economy	25700.00
0005433531350	32493	Economy	25700.00
0005432928111	32493	Economy	25700.00
0005432928116	32493	Economy	25700.00
0005433525136	32493	Economy	25700.00
0005433525191	32493	Economy	25700.00
0005435373922	5248	Business	84000.00
0005435374183	5248	Business	84000.00
0005434826412	5248	Business	84000.00
0005434558468	5248	Business	84000.00
0005435374321	5248	Business	84000.00
0005434826426	5248	Business	84000.00
0005432121645	5248	Business	84000.00
0005434826423	5248	Business	84000.00
0005435374376	5248	Business	84000.00
0005435374215	5248	Business	84000.00
0005434826390	5248	Business	84000.00
0005435373870	5248	Business	84000.00
0005434826379	5248	Business	84000.00
0005435373967	5248	Business	84000.00
0005435150348	5248	Business	84000.00
0005432396331	5248	Business	84000.00
0005434826445	5248	Business	84000.00
0005435373861	5248	Business	84000.00
0005434826413	5248	Business	84000.00
0005434828758	5248	Business	84000.00
0005435374232	5248	Business	84000.00
0005432823475	5248	Business	84000.00
0005434826458	5248	Comfort	47600.00
0005434558461	5248	Comfort	47600.00
0005432121659	5248	Comfort	47600.00
0005434826410	5248	Comfort	47600.00
0005435374081	5248	Comfort	47600.00
0005435150342	5248	Comfort	47600.00
0005435374130	5248	Comfort	47600.00
0005435373860	5248	Comfort	47600.00
0005434826472	5248	Comfort	47600.00
0005435374052	5248	Comfort	47600.00
0005434826434	5248	Comfort	47600.00
0005434826395	5248	Comfort	47600.00
0005435374231	5248	Comfort	47600.00
0005432394194	5248	Comfort	47600.00
0005434826438	5248	Comfort	47600.00
0005434826498	5248	Comfort	47600.00
0005435373903	5248	Comfort	47600.00
0005432394197	5248	Comfort	47600.00
0005434558471	5248	Comfort	47600.00
0005435150349	5248	Comfort	47600.00
0005434826478	5248	Comfort	47600.00
0005434826403	5248	Comfort	47600.00
0005434826481	5248	Comfort	47600.00
0005434826435	5248	Comfort	47600.00
0005434826398	5248	Comfort	47600.00
0005434826469	5248	Comfort	47600.00
0005432121652	5248	Comfort	47600.00
0005432121653	5248	Comfort	47600.00
0005434826502	5248	Comfort	47600.00
0005435150343	5248	Comfort	47600.00
0005432396333	5248	Comfort	47600.00
0005435374264	5248	Comfort	47600.00
0005435374129	5248	Comfort	47600.00
0005434826452	5248	Economy	28000.00
0005435150352	5248	Economy	28000.00
0005434826442	5248	Economy	28000.00
0005434826397	5248	Economy	28000.00
0005434826486	5248	Economy	28000.00
0005432823477	5248	Economy	28000.00
0005435374422	5248	Economy	28000.00
0005434826391	5248	Economy	28000.00
0005434826470	5248	Economy	28000.00
0005435299838	5248	Economy	28000.00
0005435374051	5248	Economy	28000.00
0005434826408	5248	Economy	28000.00
0005434826409	5248	Economy	28000.00
0005434826491	5248	Economy	28000.00
0005434826492	5248	Economy	28000.00
0005435374370	5248	Economy	28000.00
0005434826377	5248	Economy	28000.00
0005434826424	5248	Economy	28000.00
0005434826437	5248	Economy	28000.00
0005434826453	5248	Economy	28000.00
0005435374099	5248	Economy	28000.00
0005434826396	5248	Economy	28000.00
0005434826479	5248	Economy	28000.00
0005434826416	5248	Economy	28000.00
0005435299846	5248	Economy	28000.00
0005432121650	5248	Economy	28000.00
0005434826401	5248	Economy	28000.00
0005434826407	5248	Economy	28000.00
0005435374287	5248	Economy	28000.00
0005434826493	5248	Economy	28000.00
0005435374317	5248	Economy	28000.00
0005435374087	5248	Economy	28000.00
0005434826499	5248	Economy	28000.00
0005434826443	5248	Economy	28000.00
0005434826450	5248	Economy	28000.00
0005434558467	5248	Economy	28000.00
0005434826432	5248	Economy	28000.00
0005435373702	5248	Economy	28000.00
0005435386671	5248	Economy	28000.00
0005434826487	5248	Economy	28000.00
0005435150346	5248	Economy	28000.00
0005434826404	5248	Economy	28000.00
0005434826429	5248	Economy	28000.00
0005435373979	5248	Economy	28000.00
0005434826463	5248	Economy	28000.00
0005434826427	5248	Economy	28000.00
0005434826494	5248	Economy	28000.00
0005435374142	5248	Economy	28000.00
0005435374490	5248	Economy	30800.00
0005434826380	5248	Economy	28000.00
0005434826467	5248	Economy	30800.00
0005435374322	5248	Economy	28000.00
0005435150347	5248	Economy	28000.00
0005435299842	5248	Economy	30800.00
0005432121656	5248	Economy	30800.00
0005435150338	5248	Economy	28000.00
0005434558463	5248	Economy	28000.00
0005435150339	5248	Economy	28000.00
0005435374168	5248	Economy	28000.00
0005432121658	5248	Economy	28000.00
0005435661977	5248	Economy	28000.00
0005435374421	5248	Economy	28000.00
0005434826385	5248	Economy	28000.00
0005435374103	5248	Economy	28000.00
0005434826460	5248	Economy	28000.00
0005435374282	5248	Economy	28000.00
0005432394195	5248	Economy	28000.00
0005432394196	5248	Economy	28000.00
0005435374463	5248	Economy	28000.00
0005434831255	5248	Economy	28000.00
0005435373923	5248	Economy	28000.00
0005434826383	5248	Economy	28000.00
0005434558465	5248	Economy	28000.00
0005434826455	5248	Economy	28000.00
0005434826422	5248	Economy	28000.00
0005435374170	5248	Economy	28000.00
0005434831254	5248	Economy	28000.00
0005434826436	5248	Economy	28000.00
0005434558472	5248	Economy	28000.00
0005432396329	5248	Economy	28000.00
0005434826448	5248	Economy	28000.00
0005434826378	5248	Economy	28000.00
0005434826386	5248	Economy	28000.00
0005435386652	5248	Economy	28000.00
0005434826461	5248	Economy	28000.00
0005434826490	5248	Economy	28000.00
0005432121651	5248	Economy	28000.00
0005435374171	5248	Economy	28000.00
0005434826393	5248	Economy	28000.00
0005435374234	5248	Economy	28000.00
0005434826484	5248	Economy	28000.00
0005434826465	5248	Economy	28000.00
0005434826428	5248	Economy	28000.00
0005434826392	5248	Economy	28000.00
0005434828757	5248	Economy	28000.00
0005432394193	5248	Economy	28000.00
0005432121655	5248	Economy	28000.00
0005434826482	5248	Economy	28000.00
0005435150344	5248	Economy	28000.00
0005434826466	5248	Economy	28000.00
0005435374144	5248	Economy	28000.00
0005432396330	5248	Economy	28000.00
0005434826394	5248	Economy	28000.00
0005434826402	5248	Economy	28000.00
0005434826501	5248	Economy	28000.00
0005434826500	5248	Economy	28000.00
0005432823474	5248	Economy	28000.00
0005435374169	5248	Economy	28000.00
0005435374214	5248	Economy	28000.00
0005435373968	5248	Economy	28000.00
0005434826497	5248	Economy	28000.00
0005434558470	5248	Economy	28000.00
0005432121648	5248	Economy	28000.00
0005435150340	5248	Economy	28000.00
0005434558464	5248	Economy	28000.00
0005434826449	5248	Economy	28000.00
0005435661978	5248	Economy	28000.00
0005434831253	5248	Economy	28000.00
0005434826389	5248	Economy	28000.00
0005434826421	5248	Economy	28000.00
0005435374040	5248	Economy	28000.00
0005434826477	5248	Economy	28000.00
0005435373904	5248	Economy	28000.00
0005435374131	5248	Economy	28000.00
0005434826473	5248	Economy	28000.00
0005435374207	5248	Economy	28000.00
0005435374167	5248	Economy	28000.00
0005432396332	5248	Economy	28000.00
0005434826489	5248	Economy	28000.00
0005434826420	5248	Economy	28000.00
0005434826417	5248	Economy	28000.00
0005435374143	5248	Economy	28000.00
0005435374091	5248	Economy	28000.00
0005435374187	5248	Economy	28000.00
0005434826384	5248	Economy	28000.00
0005434826462	5248	Economy	28000.00
0005435374484	5248	Economy	30800.00
0005434826388	5248	Economy	28000.00
0005434826454	5248	Economy	30800.00
0005435386677	5248	Economy	30800.00
0005435386635	5248	Economy	30800.00
0005435150341	5248	Economy	30800.00
0005435299835	5248	Economy	28000.00
0005435373975	5248	Economy	28000.00
0005434826503	5248	Economy	28000.00
0005434826456	5248	Economy	28000.00
0005432121649	5248	Economy	28000.00
0005434826468	5248	Economy	28000.00
0005434826387	5248	Economy	28000.00
0005434558462	5248	Economy	28000.00
0005434826459	5248	Economy	28000.00
0005434558469	5248	Economy	28000.00
0005434826405	5248	Economy	28000.00
0005434826406	5248	Economy	28000.00
0005434828756	5248	Economy	28000.00
0005434826474	5248	Economy	28000.00
0005434826457	5248	Economy	28000.00
0005432121657	5248	Economy	28000.00
0005435374082	5248	Economy	28000.00
0005434826441	5248	Economy	28000.00
0005432121654	5248	Economy	28000.00
0005435735184	5248	Economy	28000.00
0005434826425	5248	Economy	28000.00
0005435373999	5248	Economy	28000.00
0005434826471	5248	Economy	28000.00
0005434826476	5248	Economy	28000.00
0005434665010	5248	Economy	28000.00
0005435386651	5248	Economy	28000.00
0005435661979	5248	Economy	28000.00
0005434826439	5248	Economy	28000.00
0005432121647	5248	Economy	28000.00
0005434826382	5248	Economy	28000.00
0005434826447	5248	Economy	28000.00
0005435150345	5248	Economy	28000.00
0005435299841	5248	Economy	28000.00
0005435386676	5248	Economy	28000.00
0005435150350	5248	Economy	28000.00
0005434826419	5248	Economy	28000.00
0005434826381	5248	Economy	28000.00
0005435373900	5248	Economy	28000.00
0005434826464	5248	Economy	28000.00
0005434831252	5248	Economy	28000.00
0005434826431	5248	Economy	28000.00
0005434826495	5248	Economy	28000.00
0005434826400	5248	Economy	28000.00
0005435374123	5248	Economy	28000.00
0005435374243	5248	Economy	28000.00
0005434826411	5248	Economy	28000.00
0005434826414	5248	Economy	28000.00
0005434826418	5248	Economy	28000.00
0005434826480	5248	Economy	28000.00
0005434826485	5248	Economy	28000.00
0005435374137	5248	Economy	28000.00
0005435374244	5248	Economy	28000.00
0005434826430	5248	Economy	28000.00
0005435374172	5248	Economy	28000.00
0005434558466	5248	Economy	28000.00
0005434826483	5248	Economy	28000.00
0005434826446	5248	Economy	28000.00
0005434826399	5248	Economy	28000.00
0005435735211	5248	Economy	28000.00
0005435374088	5248	Economy	28000.00
0005434826440	5248	Economy	28000.00
0005434826415	5248	Economy	28000.00
0005434558460	5248	Economy	28000.00
0005434826451	5248	Economy	28000.00
0005434826488	5248	Economy	28000.00
0005435150351	5248	Economy	28000.00
0005434826376	5248	Economy	28000.00
0005435386678	5248	Economy	28000.00
0005435374520	5248	Economy	28000.00
0005435374011	5248	Economy	28000.00
0005434826444	5248	Economy	28000.00
0005435373989	5248	Economy	28000.00
0005435374233	5248	Economy	28000.00
0005432121646	5248	Economy	28000.00
0005434826475	5248	Economy	28000.00
0005434826433	5248	Economy	28000.00
0005435374124	5248	Economy	28000.00
0005434826496	5248	Economy	28000.00
0005434825806	9899	Business	84000.00
0005434825420	9899	Business	84000.00
0005435315004	9899	Business	84000.00
0005435374721	9899	Business	84000.00
0005434825153	9899	Business	84000.00
0005434825175	9899	Business	84000.00
0005434825271	9899	Business	84000.00
0005435374715	9899	Business	84000.00
0005434825529	9899	Business	84000.00
0005434825990	9899	Business	84000.00
0005434825668	9899	Business	84000.00
0005435374709	9899	Business	84000.00
0005434825989	9899	Business	84000.00
0005435374699	9899	Business	84000.00
0005435374745	9899	Business	84000.00
0005435374722	9899	Business	84000.00
0005434825226	9899	Business	84000.00
0005435374763	9899	Business	84000.00
0005434825425	9899	Business	84000.00
0005432203225	9899	Business	84000.00
0005434825699	9899	Business	84000.00
0005434825129	9899	Business	84000.00
0005435735246	9899	Business	84000.00
0005435661998	9899	Business	84000.00
0005435374733	9899	Comfort	47600.00
0005435299884	9899	Comfort	47600.00
0005435374755	9899	Comfort	47600.00
0005434825289	9899	Comfort	47600.00
0005434825104	9899	Comfort	47600.00
0005434825257	9899	Comfort	47600.00
0005434825225	9899	Comfort	47600.00
0005435374700	9899	Comfort	47600.00
0005434825710	9899	Comfort	47600.00
0005435302304	9899	Comfort	47600.00
0005434825401	9899	Comfort	47600.00
0005435374736	9899	Comfort	47600.00
0005434828724	9899	Comfort	47600.00
0005435374697	9899	Comfort	47600.00
0005435302306	9899	Comfort	47600.00
0005435374743	9899	Comfort	47600.00
0005435374703	9899	Comfort	47600.00
0005434825031	9899	Comfort	47600.00
0005435374748	9899	Comfort	47600.00
0005434824884	9899	Comfort	47600.00
0005434825793	9899	Comfort	47600.00
0005435374729	9899	Comfort	47600.00
0005434558369	9899	Comfort	47600.00
0005434825628	9899	Comfort	47600.00
0005434558394	9899	Comfort	47600.00
0005435314999	9899	Comfort	47600.00
0005434825544	9899	Comfort	47600.00
0005435302303	9899	Comfort	47600.00
0005434558403	9899	Comfort	47600.00
0005435374735	9899	Comfort	47600.00
0005435374704	9899	Comfort	47600.00
0005434824970	9899	Comfort	47600.00
0005434824922	9899	Comfort	47600.00
0005434825311	9899	Comfort	47600.00
0005434825531	9899	Comfort	47600.00
0005434825314	9899	Comfort	47600.00
0005434824828	9899	Comfort	47600.00
0005435315000	9899	Economy	28000.00
0005435315015	9899	Economy	28000.00
0005434825282	9899	Economy	28000.00
0005434825584	9899	Economy	28000.00
0005435374711	9899	Economy	28000.00
0005434825012	9899	Economy	28000.00
0005434825137	9899	Economy	28000.00
0005435374734	9899	Economy	28000.00
0005434825154	9899	Economy	28000.00
0005434825102	9899	Economy	28000.00
0005434824833	9899	Economy	28000.00
0005434825329	9899	Economy	28000.00
0005434558406	9899	Economy	28000.00
0005435374758	9899	Economy	28000.00
0005434825770	9899	Economy	28000.00
0005435374725	9899	Economy	28000.00
0005434825371	9899	Economy	28000.00
0005434825005	9899	Economy	28000.00
0005432400174	9899	Economy	28000.00
0005434825246	9899	Economy	28000.00
0005435374716	9899	Economy	28000.00
0005434824972	9899	Economy	28000.00
0005434825514	9899	Economy	28000.00
0005434825488	9899	Economy	28000.00
0005434558352	9899	Economy	28000.00
0005434825443	9899	Economy	28000.00
0005434825182	9899	Economy	28000.00
0005434831186	9899	Economy	28000.00
0005435299882	9899	Economy	28000.00
0005435299883	9899	Economy	28000.00
0005434825212	9899	Economy	28000.00
0005434825324	9899	Economy	28000.00
0005434825252	9899	Economy	28000.00
0005434825626	9899	Economy	28000.00
0005434825339	9899	Economy	28000.00
0005435315014	9899	Economy	28000.00
0005434664991	9899	Economy	28000.00
0005434825749	9899	Economy	28000.00
0005435374746	9899	Economy	28000.00
0005435150205	9899	Economy	28000.00
0005434825302	9899	Economy	28000.00
0005432203224	9899	Economy	28000.00
0005434825013	9899	Economy	28000.00
0005434824809	9899	Economy	28000.00
0005434825366	9899	Economy	28000.00
0005435374728	9899	Economy	28000.00
0005434825035	9899	Economy	28000.00
0005435374708	9899	Economy	28000.00
0005434825030	9899	Economy	28000.00
0005435374759	9899	Economy	28000.00
0005435374724	9899	Economy	28000.00
0005435315002	9899	Economy	28000.00
0005434825331	9899	Economy	28000.00
0005435374713	9899	Economy	28000.00
0005434558373	9899	Economy	30800.00
0005434825520	9899	Economy	28000.00
0005435374761	9899	Economy	30800.00
0005434828732	9899	Economy	28000.00
0005435315008	9899	Economy	28000.00
0005432400177	9899	Economy	30800.00
0005434825536	9899	Economy	30800.00
0005432396306	9899	Economy	28000.00
0005434825210	9899	Economy	28000.00
0005434825208	9899	Economy	28000.00
0005434825251	9899	Economy	28000.00
0005435374698	9899	Economy	28000.00
0005434825130	9899	Economy	28000.00
0005435315013	9899	Economy	28000.00
0005435315007	9899	Economy	28000.00
0005434825269	9899	Economy	28000.00
0005434824236	9899	Economy	28000.00
0005432396302	9899	Economy	28000.00
0005434825805	9899	Economy	28000.00
0005434825631	9899	Economy	28000.00
0005434824938	9899	Economy	28000.00
0005435374750	9899	Economy	28000.00
0005435661997	9899	Economy	28000.00
0005435374717	9899	Economy	28000.00
0005434825433	9899	Economy	28000.00
0005432203229	9899	Economy	28000.00
0005434825519	9899	Economy	28000.00
0005435299885	9899	Economy	28000.00
0005434825272	9899	Economy	28000.00
0005435661996	9899	Economy	28000.00
0005434825042	9899	Economy	28000.00
0005435315012	9899	Economy	28000.00
0005435374744	9899	Economy	28000.00
0005435299881	9899	Economy	28000.00
0005434825595	9899	Economy	28000.00
0005435315001	9899	Economy	28000.00
0005434825413	9899	Economy	28000.00
0005434828717	9899	Economy	28000.00
0005434825303	9899	Economy	28000.00
0005434825382	9899	Economy	28000.00
0005435735244	9899	Economy	28000.00
0005435315011	9899	Economy	28000.00
0005434825176	9899	Economy	28000.00
0005435374706	9899	Economy	28000.00
0005435374701	9899	Economy	28000.00
0005434825567	9899	Economy	28000.00
0005435374727	9899	Economy	28000.00
0005434825604	9899	Economy	28000.00
0005435374712	9899	Economy	28000.00
0005434826109	9899	Economy	28000.00
0005432400184	9899	Economy	28000.00
0005435386723	9899	Economy	28000.00
0005435374718	9899	Economy	28000.00
0005434825363	9899	Economy	28000.00
0005435374732	9899	Economy	28000.00
0005435374714	9899	Economy	28000.00
0005435374710	9899	Economy	28000.00
0005435374740	9899	Economy	28000.00
0005434824630	9899	Economy	28000.00
0005434825268	9899	Economy	28000.00
0005435150220	9899	Economy	28000.00
0005434558370	9899	Economy	28000.00
0005434825367	9899	Economy	28000.00
0005434825669	9899	Economy	28000.00
0005435374730	9899	Economy	28000.00
0005435374742	9899	Economy	28000.00
0005434825711	9899	Economy	28000.00
0005435374705	9899	Economy	28000.00
0005435150197	9899	Economy	28000.00
0005434825360	9899	Economy	28000.00
0005435150258	9899	Economy	28000.00
0005432400175	9899	Economy	28000.00
0005435735243	9899	Economy	28000.00
0005434825060	9899	Economy	28000.00
0005435315009	9899	Economy	28000.00
0005434825211	9899	Economy	28000.00
0005434558389	9899	Economy	28000.00
0005435150151	9899	Economy	28000.00
0005434825660	9899	Economy	28000.00
0005434826097	9899	Economy	28000.00
0005434558404	9899	Economy	28000.00
0005434825680	9899	Economy	28000.00
0005435386720	9899	Economy	28000.00
0005435374739	9899	Economy	28000.00
0005434825640	9899	Economy	28000.00
0005435374754	9899	Economy	28000.00
0005432396295	9899	Economy	28000.00
0005432396286	9899	Economy	28000.00
0005434825313	9899	Economy	28000.00
0005435302305	9899	Economy	28000.00
0005432823496	9899	Economy	28000.00
0005435374731	9899	Economy	28000.00
0005435386724	9899	Economy	28000.00
0005434825345	9899	Economy	28000.00
0005434824901	9899	Economy	28000.00
0005435315005	9899	Economy	30800.00
0005435374726	9899	Economy	30800.00
0005435374737	9899	Economy	30800.00
0005432203226	9899	Economy	30800.00
0005434825587	9899	Economy	30800.00
0005435374760	9899	Economy	28000.00
0005435150211	9899	Economy	28000.00
0005435374707	9899	Economy	28000.00
0005434825682	9899	Economy	28000.00
0005434825988	9899	Economy	28000.00
0005432823495	9899	Economy	28000.00
0005435150159	9899	Economy	28000.00
0005435374723	9899	Economy	28000.00
0005434825568	9899	Economy	28000.00
0005434824885	9899	Economy	28000.00
0005435374753	9899	Economy	28000.00
0005432203227	9899	Economy	28000.00
0005434831203	9899	Economy	28000.00
0005432396303	9899	Economy	28000.00
0005435315006	9899	Economy	28000.00
0005434825583	9899	Economy	28000.00
0005435315003	9899	Economy	28000.00
0005434825196	9899	Economy	28000.00
0005435374752	9899	Economy	28000.00
0005434825344	9899	Economy	28000.00
0005434825028	9899	Economy	28000.00
0005435374741	9899	Economy	28000.00
0005435374756	9899	Economy	28000.00
0005435374738	9899	Economy	28000.00
0005435735245	9899	Economy	28000.00
0005432400170	9899	Economy	28000.00
0005434825059	9899	Economy	28000.00
0005432203223	9899	Economy	28000.00
0005434825444	9899	Economy	28000.00
0005434831211	9899	Economy	28000.00
0005435315010	9899	Economy	28000.00
0005434825547	9899	Economy	28000.00
0005435386719	9899	Economy	28000.00
0005434825396	9899	Economy	28000.00
0005435374719	9899	Economy	28000.00
0005432400173	9899	Economy	28000.00
0005434825395	9899	Economy	28000.00
0005434825632	9899	Economy	28000.00
0005434825032	9899	Economy	28000.00
0005435374757	9899	Economy	28000.00
0005434825709	9899	Economy	28000.00
0005434825490	9899	Economy	28000.00
0005434825868	9899	Economy	28000.00
0005432823497	9899	Economy	28000.00
0005435150203	9899	Economy	28000.00
0005435386722	9899	Economy	28000.00
0005435374749	9899	Economy	28000.00
0005434558337	9899	Economy	28000.00
0005434825081	9899	Economy	28000.00
0005434825577	9899	Economy	28000.00
0005434825270	9899	Economy	28000.00
0005434558339	9899	Economy	28000.00
0005434825391	9899	Economy	28000.00
0005435302307	9899	Economy	28000.00
0005434825426	9899	Economy	28000.00
0005434825213	9899	Economy	28000.00
0005432203228	9899	Economy	28000.00
0005435374747	9899	Economy	28000.00
0005435150221	9899	Economy	28000.00
0005434825527	9899	Economy	28000.00
0005435374751	9899	Economy	28000.00
0005434825627	9899	Economy	28000.00
0005435374702	9899	Economy	28000.00
0005434825131	9899	Economy	28000.00
0005434558390	9899	Economy	28000.00
0005434825312	9899	Economy	28000.00
0005435735247	9899	Economy	28000.00
0005434825063	9899	Economy	28000.00
0005434825825	9899	Economy	28000.00
0005434558372	9899	Economy	28000.00
0005434825309	9899	Economy	28000.00
0005432400178	9899	Economy	28000.00
0005434826108	9899	Economy	28000.00
0005434825294	9899	Economy	28000.00
0005434825061	9899	Economy	28000.00
0005434825388	9899	Economy	28000.00
0005434825034	9899	Economy	28000.00
0005434825617	9899	Economy	28000.00
0005435374720	9899	Economy	28000.00
0005435374762	9899	Economy	28000.00
0005434825530	9899	Economy	28000.00
0005435386721	9899	Economy	28000.00
0005435082974	6988	Economy	8200.00
0005435790373	6988	Economy	8200.00
0005435082971	6988	Economy	7400.00
0005435082969	6988	Economy	7400.00
0005435082970	6988	Economy	7400.00
0005435082975	6988	Economy	7400.00
0005435082972	6988	Economy	7400.00
0005435790371	6988	Economy	7400.00
0005435790374	6988	Economy	7400.00
0005435082968	6988	Economy	7400.00
0005435082973	6988	Economy	7400.00
0005435790372	6988	Economy	7400.00
0005435082976	6988	Economy	7400.00
0005435790352	25967	Economy	8200.00
0005435082891	25967	Economy	8200.00
0005435082892	25967	Economy	7400.00
0005435790344	25967	Economy	7400.00
0005435082869	25967	Economy	7400.00
0005435082897	25967	Economy	7400.00
0005435790349	25967	Economy	7400.00
0005435790345	25967	Economy	7400.00
0005435790346	25967	Economy	7400.00
0005435082894	25967	Economy	7400.00
0005435082893	25967	Economy	7400.00
0005435082900	25967	Economy	7400.00
0005434215175	9514	Business	32800.00
0005434757349	9514	Business	32800.00
0005434757382	9514	Business	32800.00
0005434215146	9514	Business	32800.00
0005434757358	9514	Business	32800.00
0005434757374	9514	Business	32800.00
0005434215098	9514	Business	32800.00
0005434757365	9514	Business	32800.00
0005434215110	9514	Business	32800.00
0005434215052	9514	Business	32800.00
0005434757341	9514	Business	32800.00
0005434215162	9514	Business	32800.00
0005434757377	9514	Economy	10900.00
0005434215144	9514	Economy	10900.00
0005434215045	9514	Economy	10900.00
0005434757368	9514	Economy	10900.00
0005434757338	9514	Economy	10900.00
0005434215310	9514	Economy	10900.00
0005434757369	9514	Economy	10900.00
0005434215186	9514	Economy	10900.00
0005434214968	9514	Economy	10900.00
0005434757342	9514	Economy	10900.00
0005434757380	9514	Economy	12000.00
0005434757351	9514	Economy	12000.00
0005434215264	9514	Economy	12000.00
0005434215115	9514	Economy	12000.00
0005434757364	9514	Economy	12000.00
0005434757376	9514	Economy	10900.00
0005434215142	9514	Economy	10900.00
0005434215183	9514	Economy	10900.00
0005434215293	9514	Economy	10900.00
0005434757355	9514	Economy	10900.00
0005434757359	9514	Economy	10900.00
0005434215207	9514	Economy	10900.00
0005434215363	9514	Economy	10900.00
0005434757340	9514	Economy	10900.00
0005434757373	9514	Economy	10900.00
0005434757348	9514	Economy	10900.00
0005434215178	9514	Economy	10900.00
0005434215218	9514	Economy	10900.00
0005434757379	9514	Economy	10900.00
0005434215184	9514	Economy	10900.00
0005434757378	9514	Economy	10900.00
0005434215153	9514	Economy	10900.00
0005434215066	9514	Economy	10900.00
0005434214945	9514	Economy	10900.00
0005434214967	9514	Economy	10900.00
0005434757345	9514	Economy	10900.00
0005434215262	9514	Economy	10900.00
0005434757344	9514	Economy	10900.00
0005434757383	9514	Economy	10900.00
0005434215172	9514	Economy	10900.00
0005434757361	9514	Economy	10900.00
0005434215074	9514	Economy	10900.00
0005434757343	9514	Economy	10900.00
0005434215222	9514	Economy	10900.00
0005434215154	9514	Economy	10900.00
0005434215206	9514	Economy	10900.00
0005434215292	9514	Economy	10900.00
0005434757366	9514	Economy	10900.00
0005434757356	9514	Economy	10900.00
0005434757370	9514	Economy	10900.00
0005434757362	9514	Economy	10900.00
0005434757347	9514	Economy	10900.00
0005434215108	9514	Economy	10900.00
0005434215288	9514	Economy	10900.00
0005434215235	9514	Economy	10900.00
0005434757346	9514	Economy	10900.00
0005434757375	9514	Economy	10900.00
0005434215160	9514	Economy	10900.00
0005434215263	9514	Economy	10900.00
0005434215147	9514	Economy	10900.00
0005434215196	9514	Economy	10900.00
0005434215016	9514	Economy	10900.00
0005434757339	9514	Economy	10900.00
0005434757360	9514	Economy	10900.00
0005434215197	9514	Economy	10900.00
0005434757353	9514	Economy	10900.00
0005434215097	9514	Economy	10900.00
0005434215345	9514	Economy	10900.00
0005434757381	9514	Economy	10900.00
0005434757371	9514	Economy	10900.00
0005434215111	9514	Economy	10900.00
0005434214966	9514	Economy	10900.00
0005434215182	9514	Economy	10900.00
0005434215082	9514	Economy	10900.00
0005434215161	9514	Economy	10900.00
0005434757363	9514	Economy	10900.00
0005434757367	9514	Economy	10900.00
0005434757357	9514	Economy	10900.00
0005434757372	9514	Economy	10900.00
0005434757350	9514	Economy	10900.00
0005434215304	9514	Economy	10900.00
0005434214946	9514	Economy	10900.00
0005434757354	9514	Economy	10900.00
0005434757352	9514	Economy	10900.00
0005434757002	28593	Business	32800.00
0005434757045	28593	Business	32800.00
0005434757001	28593	Business	32800.00
0005434215551	28593	Business	32800.00
0005434756984	28593	Business	32800.00
0005434757027	28593	Business	32800.00
0005434215530	28593	Business	32800.00
0005434215536	28593	Business	32800.00
0005434215540	28593	Business	32800.00
0005434215524	28593	Business	32800.00
0005434215512	28593	Business	32800.00
0005434215515	28593	Business	32800.00
0005434215528	28593	Economy	10900.00
0005434215513	28593	Economy	10900.00
0005434756985	28593	Economy	10900.00
0005434756766	28593	Economy	10900.00
0005434215525	28593	Economy	10900.00
0005434215537	28593	Economy	10900.00
0005434215514	28593	Economy	10900.00
0005434757044	28593	Economy	10900.00
0005434756926	28593	Economy	10900.00
0005434756981	28593	Economy	10900.00
0005434757036	28593	Economy	12000.00
0005434215547	28593	Economy	12000.00
0005434756941	28593	Economy	12000.00
0005434756777	28593	Economy	12000.00
0005434215532	28593	Economy	10900.00
0005434215511	28593	Economy	10900.00
0005434756707	28593	Economy	10900.00
0005434215520	28593	Economy	10900.00
0005434756987	28593	Economy	10900.00
0005434215550	28593	Economy	10900.00
0005434215517	28593	Economy	10900.00
0005434215507	28593	Economy	10900.00
0005434756819	28593	Economy	10900.00
0005434215531	28593	Economy	10900.00
0005434215538	28593	Economy	10900.00
0005434756966	28593	Economy	10900.00
0005434756757	28593	Economy	10900.00
0005434756965	28593	Economy	10900.00
0005434756888	28593	Economy	10900.00
0005434756940	28593	Economy	10900.00
0005434215539	28593	Economy	10900.00
0005434215510	28593	Economy	10900.00
0005434215521	28593	Economy	10900.00
0005434756831	28593	Economy	10900.00
0005434215518	28593	Economy	10900.00
0005434215533	28593	Economy	10900.00
0005434756781	28593	Economy	10900.00
0005434756957	28593	Economy	10900.00
0005434756938	28593	Economy	10900.00
0005434757041	28593	Economy	10900.00
0005434215549	28593	Economy	10900.00
0005434215543	28593	Economy	10900.00
0005434215523	28593	Economy	10900.00
0005434756934	28593	Economy	10900.00
0005434756780	28593	Economy	10900.00
0005434215508	28593	Economy	10900.00
0005434215534	28593	Economy	10900.00
0005434215522	28593	Economy	10900.00
0005434756939	28593	Economy	10900.00
0005434756778	28593	Economy	10900.00
0005434215541	28593	Economy	10900.00
0005434215548	28593	Economy	10900.00
0005434215516	28593	Economy	10900.00
0005434215542	28593	Economy	10900.00
0005434215535	28593	Economy	10900.00
0005434215529	28593	Economy	10900.00
0005434757028	28593	Economy	10900.00
0005434215519	28593	Economy	10900.00
0005434756927	28593	Economy	10900.00
0005434756864	28593	Economy	10900.00
0005434215527	28593	Economy	10900.00
0005434215526	28593	Economy	10900.00
0005434757040	28593	Economy	10900.00
0005434756949	28593	Economy	10900.00
0005434756863	28593	Economy	10900.00
0005434757029	28593	Economy	10900.00
0005434756983	28593	Economy	10900.00
0005434215545	28593	Economy	10900.00
0005434215509	28593	Economy	10900.00
0005434756844	28593	Economy	10900.00
0005434756882	28593	Economy	10900.00
0005434756948	28593	Economy	10900.00
0005434756986	28593	Economy	10900.00
0005434215544	28593	Economy	10900.00
0005434215546	28593	Economy	10900.00
0005434756933	28593	Economy	10900.00
0005434215553	28593	Economy	10900.00
0005434215552	28593	Economy	10900.00
0005434756818	28593	Economy	10900.00
0005434760222	10809	Economy	8900.00
0005435100191	10809	Economy	8900.00
0005434760223	10809	Economy	8900.00
0005434760237	10809	Economy	8900.00
0005435100190	10809	Economy	8900.00
0005434760232	10809	Economy	8900.00
0005435100192	10809	Economy	8900.00
0005434760231	10809	Economy	8900.00
0005434760252	31794	Economy	8900.00
0005435100156	31794	Economy	8900.00
0005435100169	31794	Economy	8900.00
0005434760253	31794	Economy	8900.00
0005434760251	31794	Economy	8900.00
0005435100155	31794	Economy	8900.00
0005435100168	31794	Economy	8900.00
0005434639893	1995	Economy	20900.00
0005433202528	1995	Economy	20900.00
0005434639890	1995	Economy	20900.00
0005433202526	1995	Economy	20900.00
0005435948353	1995	Economy	19000.00
0005434639902	1995	Economy	19000.00
0005433202527	1995	Economy	19000.00
0005434639917	1995	Economy	19000.00
0005434639896	1995	Economy	19000.00
0005433202589	1995	Economy	19000.00
0005434639900	1995	Economy	19000.00
0005434639899	1995	Economy	19000.00
0005434639906	1995	Economy	19000.00
0005433202517	1995	Economy	19000.00
0005434639907	1995	Economy	19000.00
0005434639909	1995	Economy	19000.00
0005434639897	1995	Economy	19000.00
0005434639910	1995	Economy	19000.00
0005433202554	1995	Economy	19000.00
0005435948351	1995	Economy	19000.00
0005434639901	1995	Economy	19000.00
0005432290703	1995	Economy	19000.00
0005434639913	1995	Economy	19000.00
0005434639911	1995	Economy	19000.00
0005433202562	1995	Economy	19000.00
0005434639895	1995	Economy	19000.00
0005434639914	1995	Economy	19000.00
0005434639912	1995	Economy	19000.00
0005434639898	1995	Economy	19000.00
0005434639892	1995	Economy	19000.00
0005432290704	1995	Economy	19000.00
0005433202561	1995	Economy	19000.00
0005434639915	1995	Economy	19000.00
0005434639891	1995	Economy	19000.00
0005434639904	1995	Economy	19000.00
0005434639894	1995	Economy	19000.00
0005434639916	1995	Economy	19000.00
0005433202518	1995	Economy	19000.00
0005433202605	1995	Economy	19000.00
0005433202511	1995	Economy	19000.00
0005433202544	1995	Economy	19000.00
0005433202534	1995	Economy	19000.00
0005434639908	1995	Economy	19000.00
0005434639905	1995	Economy	19000.00
0005432290705	1995	Economy	19000.00
0005435948352	1995	Economy	19000.00
0005434639903	1995	Economy	19000.00
0005434639918	1995	Economy	19000.00
0005434639635	23283	Economy	20900.00
0005434639623	23283	Economy	20900.00
0005434639636	23283	Economy	20900.00
0005434639666	23283	Economy	20900.00
0005434639593	23283	Economy	19000.00
0005433202686	23283	Economy	19000.00
0005434639637	23283	Economy	19000.00
0005434639625	23283	Economy	19000.00
0005434639619	23283	Economy	19000.00
0005433202677	23283	Economy	19000.00
0005434639544	23283	Economy	19000.00
0005433202682	23283	Economy	19000.00
0005433202683	23283	Economy	19000.00
0005433202680	23283	Economy	19000.00
0005434639539	23283	Economy	19000.00
0005434639680	23283	Economy	19000.00
0005433202675	23283	Economy	19000.00
0005434639624	23283	Economy	19000.00
0005434639692	23283	Economy	19000.00
0005433202687	23283	Economy	19000.00
0005433202681	23283	Economy	19000.00
0005434639647	23283	Economy	19000.00
0005433202684	23283	Economy	19000.00
0005434639631	23283	Economy	19000.00
0005434639587	23283	Economy	19000.00
0005434639642	23283	Economy	19000.00
0005434639538	23283	Economy	19000.00
0005434639630	23283	Economy	19000.00
0005434639588	23283	Economy	19000.00
0005434639629	23283	Economy	19000.00
0005434639648	23283	Economy	19000.00
0005434639667	23283	Economy	19000.00
0005434639679	23283	Economy	19000.00
0005434639626	23283	Economy	19000.00
0005434639652	23283	Economy	19000.00
0005434639580	23283	Economy	19000.00
0005434639641	23283	Economy	19000.00
0005434639547	23283	Economy	19000.00
0005433202685	23283	Economy	19000.00
0005434639639	23283	Economy	19000.00
0005434639640	23283	Economy	19000.00
0005434639618	23283	Economy	19000.00
0005434639693	23283	Economy	19000.00
0005434639646	23283	Economy	19000.00
0005433202676	23283	Economy	19000.00
0005434639651	23283	Economy	19000.00
0005433202688	23283	Economy	19000.00
0005433202678	23283	Economy	19000.00
0005434639617	23283	Economy	19000.00
0005433202679	23283	Economy	19000.00
0005432111347	6070	Business	69700.00
0005435326986	6070	Business	69700.00
0005434601409	6070	Business	69700.00
0005434601416	6070	Business	69700.00
0005434601424	6070	Business	69700.00
0005434601425	6070	Business	69700.00
0005434601412	6070	Business	69700.00
0005432111346	6070	Business	69700.00
0005434601408	6070	Economy	23200.00
0005433533392	6070	Economy	23200.00
0005433531378	6070	Economy	23200.00
0005435326984	6070	Economy	23200.00
0005434601422	6070	Economy	23200.00
0005435326915	6070	Economy	23200.00
0005434601406	6070	Economy	23200.00
0005434601402	6070	Economy	23200.00
0005435326942	6070	Economy	23200.00
0005434601411	6070	Economy	25600.00
0005434601428	6070	Economy	25600.00
0005434601423	6070	Economy	25600.00
0005434601427	6070	Economy	23200.00
0005433531379	6070	Economy	23200.00
0005435326935	6070	Economy	23200.00
0005434601404	6070	Economy	23200.00
0005434601410	6070	Economy	23200.00
0005435326927	6070	Economy	23200.00
0005435326983	6070	Economy	23200.00
0005434601414	6070	Economy	23200.00
0005434601407	6070	Economy	23200.00
0005435326939	6070	Economy	23200.00
0005433533393	6070	Economy	23200.00
0005434601420	6070	Economy	23200.00
0005435326908	6070	Economy	23200.00
0005434601415	6070	Economy	23200.00
0005434601417	6070	Economy	23200.00
0005433533394	6070	Economy	23200.00
0005435326941	6070	Economy	23200.00
0005435326978	6070	Economy	23200.00
0005434601413	6070	Economy	23200.00
0005435326937	6070	Economy	23200.00
0005433531377	6070	Economy	23200.00
0005434601405	6070	Economy	23200.00
0005434601429	6070	Economy	23200.00
0005435326936	6070	Economy	23200.00
0005435326909	6070	Economy	23200.00
0005434601403	6070	Economy	23200.00
0005433531380	6070	Economy	23200.00
0005435326934	6070	Economy	23200.00
0005434601421	6070	Economy	23200.00
0005434601419	6070	Economy	23200.00
0005435326926	6070	Economy	23200.00
0005435326938	6070	Economy	23200.00
0005434601426	6070	Economy	23200.00
0005433533395	6070	Economy	23200.00
0005434601418	6070	Economy	23200.00
0005435326985	6070	Economy	23200.00
0005433533396	6070	Economy	23200.00
0005434601279	18568	Business	69700.00
0005435327052	18568	Business	69700.00
0005434601278	18568	Business	69700.00
0005434601051	18568	Business	69700.00
0005433531327	18568	Business	69700.00
0005435327060	18568	Business	69700.00
0005434601167	18568	Economy	23200.00
0005433531349	18568	Economy	23200.00
0005434601286	18568	Economy	23200.00
0005434601195	18568	Economy	23200.00
0005434601050	18568	Economy	23200.00
0005434601285	18568	Economy	23200.00
0005434601196	18568	Economy	23200.00
0005435327053	18568	Economy	23200.00
0005433527317	18568	Economy	23200.00
0005434601176	18568	Economy	25600.00
0005435327054	18568	Economy	25600.00
0005434601261	18568	Economy	25600.00
0005434601193	18568	Economy	23200.00
0005434601277	18568	Economy	23200.00
0005434601276	18568	Economy	23200.00
0005434601226	18568	Economy	23200.00
0005434601209	18568	Economy	23200.00
0005434601191	18568	Economy	23200.00
0005434601169	18568	Economy	23200.00
0005435327063	18568	Economy	23200.00
0005435327058	18568	Economy	23200.00
0005435327055	18568	Economy	23200.00
0005433531331	18568	Economy	23200.00
0005434601133	18568	Economy	23200.00
0005435327062	18568	Economy	23200.00
0005434601216	18568	Economy	23200.00
0005434601288	18568	Economy	23200.00
0005434601262	18568	Economy	23200.00
0005435327050	18568	Economy	23200.00
0005434601217	18568	Economy	23200.00
0005435327064	18568	Economy	23200.00
0005434601192	18568	Economy	23200.00
0005435327056	18568	Economy	23200.00
0005434601080	18568	Economy	23200.00
0005433527312	18568	Economy	23200.00
0005435327057	18568	Economy	23200.00
0005435327061	18568	Economy	23200.00
0005435327059	18568	Economy	23200.00
0005434601234	18568	Economy	23200.00
0005434601047	18568	Economy	23200.00
0005434601155	18568	Economy	23200.00
0005433527318	18568	Economy	23200.00
0005435327051	18568	Economy	23200.00
0005433181459	10631	Business	9100.00
0005434554110	10631	Business	9100.00
0005434552401	10631	Business	9100.00
0005434552423	10631	Business	9100.00
0005434552437	10631	Business	9100.00
0005434558459	10631	Business	9100.00
0005434552412	10631	Business	9100.00
0005433181307	10631	Business	9100.00
0005433181401	10631	Business	9100.00
0005433181380	10631	Business	9100.00
0005434552391	10631	Business	9100.00
0005434552421	10631	Economy	3000.00
0005434552398	10631	Economy	3000.00
0005434552424	10631	Economy	3000.00
0005434552417	10631	Economy	3000.00
0005434552432	10631	Economy	3000.00
0005433181424	10631	Economy	3000.00
0005434552409	10631	Economy	3000.00
0005433181344	10631	Economy	3000.00
0005433181378	10631	Economy	3000.00
0005434552416	10631	Economy	3300.00
0005433181374	10631	Economy	3300.00
0005433181473	10631	Economy	3300.00
0005433181419	10631	Economy	3300.00
0005433181396	10631	Economy	3300.00
0005433181394	10631	Economy	3000.00
0005434552414	10631	Economy	3000.00
0005433181420	10631	Economy	3000.00
0005433181498	10631	Economy	3000.00
0005434552394	10631	Economy	3000.00
0005433181434	10631	Economy	3000.00
0005434552433	10631	Economy	3000.00
0005434552387	10631	Economy	3000.00
0005434552442	10631	Economy	3000.00
0005434552415	10631	Economy	3000.00
0005434552400	10631	Economy	3000.00
0005434552388	10631	Economy	3000.00
0005434552427	10631	Economy	3000.00
0005433181458	10631	Economy	3000.00
0005433181464	10631	Economy	3000.00
0005434552439	10631	Economy	3000.00
0005434552429	10631	Economy	3000.00
0005434552396	10631	Economy	3000.00
0005434552420	10631	Economy	3000.00
0005434552422	10631	Economy	3000.00
0005433181323	10631	Economy	3000.00
0005434552390	10631	Economy	3000.00
0005434552405	10631	Economy	3000.00
0005434552438	10631	Economy	3000.00
0005434552425	10631	Economy	3000.00
0005433181379	10631	Economy	3000.00
0005434552418	10631	Economy	3000.00
0005434552440	10631	Economy	3000.00
0005433181354	10631	Economy	3000.00
0005434552389	10631	Economy	3000.00
0005434552411	10631	Economy	3000.00
0005434552430	10631	Economy	3000.00
0005434552408	10631	Economy	3000.00
0005434558455	10631	Economy	3000.00
0005434558458	10631	Economy	3000.00
0005433181493	10631	Economy	3000.00
0005434552426	10631	Economy	3000.00
0005434552441	10631	Economy	3000.00
0005434552410	10631	Economy	3000.00
0005434552436	10631	Economy	3000.00
0005433181461	10631	Economy	3000.00
0005434552402	10631	Economy	3000.00
0005434552431	10631	Economy	3000.00
0005434552393	10631	Economy	3000.00
0005434552428	10631	Economy	3000.00
0005433181423	10631	Economy	3000.00
0005434552419	10631	Economy	3000.00
0005434552407	10631	Economy	3000.00
0005433181490	10631	Economy	3000.00
0005433181389	10631	Economy	3000.00
0005434552404	10631	Economy	3000.00
0005434552395	10631	Economy	3000.00
0005434552392	10631	Economy	3000.00
0005434552435	10631	Economy	3000.00
0005434558457	10631	Economy	3000.00
0005433181471	10631	Economy	3000.00
0005434552399	10631	Economy	3000.00
0005433181437	10631	Economy	3000.00
0005434552403	10631	Economy	3000.00
0005434558456	10631	Economy	3000.00
0005434552397	10631	Economy	3000.00
0005433181472	10631	Economy	3000.00
0005434552406	10631	Economy	3000.00
0005434552434	10631	Economy	3000.00
0005433181346	10631	Economy	3000.00
0005433181345	10631	Economy	3000.00
0005434552413	10631	Economy	3000.00
0005433181666	27731	Business	9100.00
0005433181660	27731	Business	9100.00
0005435315003	27731	Business	9100.00
0005433181670	27731	Business	9100.00
0005435315015	27731	Business	9100.00
0005433181659	27731	Business	9100.00
0005433181664	27731	Economy	3000.00
0005435315005	27731	Economy	3000.00
0005435315012	27731	Economy	3300.00
0005435315011	27731	Economy	3300.00
0005433181668	27731	Economy	3000.00
0005433181677	27731	Economy	3000.00
0005435315004	27731	Economy	3000.00
0005433181672	27731	Economy	3000.00
0005433181661	27731	Economy	3000.00
0005433181678	27731	Economy	3000.00
0005435315009	27731	Economy	3000.00
0005433181656	27731	Economy	3000.00
0005433181673	27731	Economy	3000.00
0005433181680	27731	Economy	3000.00
0005435315006	27731	Economy	3000.00
0005433181662	27731	Economy	3000.00
0005435314999	27731	Economy	3000.00
0005433181681	27731	Economy	3000.00
0005433181682	27731	Economy	3000.00
0005435315010	27731	Economy	3000.00
0005433181675	27731	Economy	3000.00
0005433181676	27731	Economy	3000.00
0005433181671	27731	Economy	3000.00
0005433181667	27731	Economy	3000.00
0005435315008	27731	Economy	3000.00
0005433181679	27731	Economy	3000.00
0005433181658	27731	Economy	3000.00
0005433181674	27731	Economy	3000.00
0005435315013	27731	Economy	3000.00
0005435315002	27731	Economy	3000.00
0005435315001	27731	Economy	3000.00
0005433181663	27731	Economy	3000.00
0005433181669	27731	Economy	3000.00
0005433181657	27731	Economy	3000.00
0005435315000	27731	Economy	3000.00
0005435315014	27731	Economy	3000.00
0005435315007	27731	Economy	3000.00
0005433181665	27731	Economy	3000.00
0005434552047	27730	Business	9100.00
0005434552058	27730	Business	9100.00
0005434552256	27730	Business	9100.00
0005434552073	27730	Business	9100.00
0005434551995	27730	Business	9100.00
0005434551890	27730	Business	9100.00
0005434552045	27730	Economy	3000.00
0005434551972	27730	Economy	3000.00
0005434552093	27730	Economy	3000.00
0005434552074	27730	Economy	3000.00
0005434551765	27730	Economy	3000.00
0005434552051	27730	Economy	3000.00
0005434558408	27730	Economy	3000.00
0005434552023	27730	Economy	3300.00
0005434551814	27730	Economy	3300.00
0005434552005	27730	Economy	3300.00
0005434551880	27730	Economy	3300.00
0005434558358	27730	Economy	3000.00
0005434551813	27730	Economy	3000.00
0005434552062	27730	Economy	3000.00
0005434551913	27730	Economy	3000.00
0005434552033	27730	Economy	3000.00
0005434551831	27730	Economy	3000.00
0005434552103	27730	Economy	3000.00
0005434552028	27730	Economy	3000.00
0005434558407	27730	Economy	3000.00
0005434551938	27730	Economy	3000.00
0005434558356	27730	Economy	3000.00
0005434552076	27730	Economy	3000.00
0005434551742	27730	Economy	3000.00
0005434558397	27730	Economy	3000.00
0005434552046	27730	Economy	3000.00
0005434552063	27730	Economy	3000.00
0005434551904	27730	Economy	3000.00
0005434551810	27730	Economy	3000.00
0005434558381	27730	Economy	3000.00
0005434558380	27730	Economy	3000.00
0005434558367	27730	Economy	3000.00
0005434551905	27730	Economy	3000.00
0005434552108	27730	Economy	3000.00
0005434551971	27730	Economy	3000.00
0005434551811	27730	Economy	3000.00
0005434551936	27730	Economy	3000.00
0005434552176	27730	Economy	3000.00
0005434551760	27730	Economy	3000.00
0005434551853	27730	Economy	3000.00
0005434558396	27730	Economy	3000.00
0005434552019	27730	Economy	3000.00
0005434552012	27730	Economy	3000.00
0005434551835	27730	Economy	3000.00
0005434552213	27730	Economy	3000.00
0005434552104	27730	Economy	3000.00
0005434551759	27730	Economy	3000.00
0005434551996	27730	Economy	3000.00
0005434552254	27730	Economy	3000.00
0005434552064	27730	Economy	3000.00
0005434558362	27730	Economy	3000.00
0005434552281	27730	Economy	3000.00
0005434558357	27730	Economy	3000.00
0005434552255	27730	Economy	3000.00
0005434558366	27730	Economy	3000.00
0005434551919	27730	Economy	3000.00
0005434558379	27730	Economy	3000.00
0005434552013	27730	Economy	3000.00
0005434552248	27730	Economy	3000.00
0005433459316	6158	Economy	11700.00
0005433459314	6158	Economy	11700.00
0005433459315	6158	Economy	11700.00
0005435254525	19316	Economy	11700.00
0005433459277	19316	Economy	11700.00
0005433459278	19316	Economy	11700.00
0005435254526	19316	Economy	11700.00
0005435683062	6746	Business	51100.00
0005435683072	6746	Business	51100.00
0005435217731	6746	Business	51100.00
0005435683050	6746	Business	51100.00
0005432136281	6746	Business	51100.00
0005435683044	6746	Business	51100.00
0005435683038	6746	Business	51100.00
0005435683057	6746	Business	51100.00
0005435683054	6746	Business	51100.00
0005435438305	6746	Business	51100.00
0005435438161	6746	Economy	17000.00
0005435683030	6746	Economy	17000.00
0005435683041	6746	Economy	17000.00
0005432533330	6746	Economy	17000.00
0005435438205	6746	Economy	17000.00
0005434828730	6746	Economy	17000.00
0005435683039	6746	Economy	17000.00
0005435661994	6746	Economy	17000.00
0005435683026	6746	Economy	17000.00
0005435683045	6746	Economy	18700.00
0005435683059	6746	Economy	18700.00
0005435683065	6746	Economy	18700.00
0005435683068	6746	Economy	18700.00
0005434828721	6746	Economy	18700.00
0005435719588	6746	Economy	17000.00
0005435438280	6746	Economy	17000.00
0005435438341	6746	Economy	17000.00
0005435683069	6746	Economy	17000.00
0005435683071	6746	Economy	17000.00
0005435683063	6746	Economy	17000.00
0005435438353	6746	Economy	17000.00
0005435438194	6746	Economy	17000.00
0005435631033	6746	Economy	17000.00
0005435438354	6746	Economy	17000.00
0005435719589	6746	Economy	17000.00
0005435683040	6746	Economy	17000.00
0005435683031	6746	Economy	17000.00
0005432136285	6746	Economy	17000.00
0005435438379	6746	Economy	17000.00
0005435683029	6746	Economy	17000.00
0005435438276	6746	Economy	17000.00
0005435683049	6746	Economy	17000.00
0005435217739	6746	Economy	17000.00
0005435683066	6746	Economy	17000.00
0005435683035	6746	Economy	17000.00
0005435438275	6746	Economy	17000.00
0005435438291	6746	Economy	17000.00
0005435438193	6746	Economy	17000.00
0005435683055	6746	Economy	17000.00
0005435683070	6746	Economy	17000.00
0005435683033	6746	Economy	17000.00
0005435683061	6746	Economy	17000.00
0005435661995	6746	Economy	17000.00
0005435683034	6746	Economy	17000.00
0005435720156	6746	Economy	17000.00
0005435683052	6746	Economy	17000.00
0005435631034	6746	Economy	17000.00
0005432136284	6746	Economy	17000.00
0005435438233	6746	Economy	17000.00
0005435683064	6746	Economy	17000.00
0005435683067	6746	Economy	17000.00
0005435683036	6746	Economy	17000.00
0005435438189	6746	Economy	17000.00
0005435683060	6746	Economy	17000.00
0005435683058	6746	Economy	17000.00
0005435683047	6746	Economy	17000.00
0005432136280	6746	Economy	17000.00
0005435220349	6746	Economy	17000.00
0005435719587	6746	Economy	17000.00
0005435683032	6746	Economy	17000.00
0005435683037	6746	Economy	17000.00
0005435683042	6746	Economy	17000.00
0005435438342	6746	Economy	17000.00
0005435683043	6746	Economy	17000.00
0005435438380	6746	Economy	17000.00
0005435438213	6746	Economy	17000.00
0005435683028	6746	Economy	17000.00
0005435438335	6746	Economy	17000.00
0005435438336	6746	Economy	17000.00
0005435683051	6746	Economy	17000.00
0005432533329	6746	Economy	17000.00
0005435438290	6746	Economy	17000.00
0005435683056	6746	Economy	17000.00
0005435683046	6746	Economy	17000.00
0005435631032	6746	Economy	17000.00
0005435683053	6746	Economy	17000.00
0005432136282	6746	Economy	17000.00
0005435683048	6746	Economy	17000.00
0005435683027	6746	Economy	17000.00
0005432136283	6746	Economy	17000.00
0005435661962	24603	Business	51100.00
0005435438442	24603	Business	51100.00
0005434828760	24603	Business	51100.00
0005435682748	24603	Business	51100.00
0005432533356	24603	Business	51100.00
0005435438452	24603	Business	51100.00
0005435438449	24603	Business	51100.00
0005435682612	24603	Business	51100.00
0005435438439	24603	Economy	17000.00
0005435682671	24603	Economy	17000.00
0005435661975	24603	Economy	17000.00
0005435682473	24603	Economy	17000.00
0005435682571	24603	Economy	17000.00
0005435682572	24603	Economy	17000.00
0005435682796	24603	Economy	17000.00
0005435661963	24603	Economy	17000.00
0005435438458	24603	Economy	18700.00
0005435438459	24603	Economy	18700.00
0005435438438	24603	Economy	18700.00
0005435438457	24603	Economy	17000.00
0005432305803	24603	Economy	17000.00
0005435682549	24603	Economy	17000.00
0005435682730	24603	Economy	17000.00
0005435682813	24603	Economy	17000.00
0005435682844	24603	Economy	17000.00
0005432533357	24603	Economy	17000.00
0005435682848	24603	Economy	17000.00
0005435438453	24603	Economy	17000.00
0005435438460	24603	Economy	17000.00
0005435682613	24603	Economy	17000.00
0005435682854	24603	Economy	17000.00
0005435682710	24603	Economy	17000.00
0005435682541	24603	Economy	17000.00
0005435682767	24603	Economy	17000.00
0005435682670	24603	Economy	17000.00
0005435631000	24603	Economy	17000.00
0005435438445	24603	Economy	17000.00
0005435682812	24603	Economy	17000.00
0005435682562	24603	Economy	17000.00
0005435438446	24603	Economy	17000.00
0005435682766	24603	Economy	17000.00
0005435682732	24603	Economy	17000.00
0005435719571	24603	Economy	17000.00
0005435682516	24603	Economy	17000.00
0005435631010	24603	Economy	17000.00
0005435661961	24603	Economy	17000.00
0005435631005	24603	Economy	17000.00
0005435438454	24603	Economy	17000.00
0005435438440	24603	Economy	17000.00
0005435682597	24603	Economy	17000.00
0005435438455	24603	Economy	17000.00
0005435438444	24603	Economy	17000.00
0005435631004	24603	Economy	17000.00
0005435682531	24603	Economy	17000.00
0005435438441	24603	Economy	17000.00
0005435720834	24603	Economy	17000.00
0005435631001	24603	Economy	17000.00
0005434828759	24603	Economy	17000.00
0005435438448	24603	Economy	17000.00
0005435438450	24603	Economy	17000.00
0005434828761	24603	Economy	17000.00
0005435720842	24603	Economy	17000.00
0005435438451	24603	Economy	17000.00
0005435438443	24603	Economy	17000.00
0005435682841	24603	Economy	17000.00
0005435682694	24603	Economy	17000.00
0005435682522	24603	Economy	17000.00
0005435682462	24603	Economy	17000.00
0005435682540	24603	Economy	17000.00
0005435438456	24603	Economy	17000.00
0005435682563	24603	Economy	17000.00
0005435682811	24603	Economy	17000.00
0005435682634	24603	Economy	17000.00
0005435682560	24603	Economy	17000.00
0005435438447	24603	Economy	17000.00
0005435127241	11526	Business	26400.00
0005435106052	11526	Business	26400.00
0005435127269	11526	Business	26400.00
0005435127259	11526	Business	26400.00
0005435127245	11526	Business	26400.00
0005435127247	11526	Business	26400.00
0005435127238	11526	Business	26400.00
0005435127230	11526	Economy	8800.00
0005435127252	11526	Economy	8800.00
0005435127232	11526	Economy	8800.00
0005435127243	11526	Economy	8800.00
0005435127253	11526	Economy	8800.00
0005435127239	11526	Economy	9700.00
0005435127250	11526	Economy	9700.00
0005435127258	11526	Economy	8800.00
0005435098599	11526	Economy	8800.00
0005435127244	11526	Economy	8800.00
0005435127234	11526	Economy	8800.00
0005435127255	11526	Economy	8800.00
0005435127236	11526	Economy	8800.00
0005435098601	11526	Economy	8800.00
0005435098600	11526	Economy	8800.00
0005435106050	11526	Economy	8800.00
0005435127260	11526	Economy	8800.00
0005435098602	11526	Economy	8800.00
0005435127267	11526	Economy	8800.00
0005435127235	11526	Economy	8800.00
0005435127266	11526	Economy	8800.00
0005435127254	11526	Economy	8800.00
0005435106051	11526	Economy	8800.00
0005435558138	11526	Economy	8800.00
0005435127263	11526	Economy	8800.00
0005435127261	11526	Economy	8800.00
0005435127233	11526	Economy	8800.00
0005435098598	11526	Economy	8800.00
0005435127256	11526	Economy	8800.00
0005435127248	11526	Economy	8800.00
0005435098603	11526	Economy	8800.00
0005435127265	11526	Economy	8800.00
0005435098604	11526	Economy	8800.00
0005435127242	11526	Economy	8800.00
0005435127231	11526	Economy	8800.00
0005435127262	11526	Economy	8800.00
0005435127249	11526	Economy	8800.00
0005435127257	11526	Economy	8800.00
0005435127246	11526	Economy	8800.00
0005435127268	11526	Economy	8800.00
0005435127237	11526	Economy	8800.00
0005435127264	11526	Economy	8800.00
0005435127240	11526	Economy	8800.00
0005435127229	11526	Economy	8800.00
0005435127251	11526	Economy	8800.00
0005435126936	31849	Business	26400.00
0005435127097	31849	Business	26400.00
0005435126996	31849	Business	26400.00
0005435126788	31849	Business	26400.00
0005435127002	31849	Business	26400.00
0005435558146	31849	Business	26400.00
0005435126740	31849	Economy	8800.00
0005435106038	31849	Economy	8800.00
0005435126978	31849	Economy	8800.00
0005435126863	31849	Economy	8800.00
0005435127096	31849	Economy	8800.00
0005435127060	31849	Economy	8800.00
0005435127053	31849	Economy	8800.00
0005435126956	31849	Economy	9700.00
0005435126817	31849	Economy	9700.00
0005435126953	31849	Economy	9700.00
0005435126966	31849	Economy	9700.00
0005435126805	31849	Economy	8800.00
0005435127115	31849	Economy	8800.00
0005435126861	31849	Economy	8800.00
0005435126806	31849	Economy	8800.00
0005435126975	31849	Economy	8800.00
0005435127004	31849	Economy	8800.00
0005435126967	31849	Economy	8800.00
0005435127051	31849	Economy	8800.00
0005435127017	31849	Economy	8800.00
0005435127031	31849	Economy	8800.00
0005435126920	31849	Economy	8800.00
0005435126980	31849	Economy	8800.00
0005435126816	31849	Economy	8800.00
0005435558145	31849	Economy	8800.00
0005435127054	31849	Economy	8800.00
0005435127079	31849	Economy	8800.00
0005435126862	31849	Economy	8800.00
0005435126799	31849	Economy	8800.00
0005435126964	31849	Economy	8800.00
0005435558147	31849	Economy	8800.00
0005435127027	31849	Economy	8800.00
0005435126813	31849	Economy	8800.00
0005435127038	31849	Economy	8800.00
0005435126976	31849	Economy	8800.00
0005435126979	31849	Economy	8800.00
0005435126865	31849	Economy	8800.00
0005435126858	31849	Economy	8800.00
0005435126983	31849	Economy	8800.00
0005435127062	31849	Economy	8800.00
0005435127057	31849	Economy	8800.00
0005435127050	31849	Economy	8800.00
0005435127030	31849	Economy	8800.00
0005435126919	31849	Economy	8800.00
0005435126856	31849	Economy	8800.00
0005435126829	31849	Economy	8800.00
0005435126912	31849	Economy	8800.00
0005435126634	31849	Economy	8800.00
0005435106040	31849	Economy	8800.00
0005435126974	31849	Economy	8800.00
0005433399134	13504	Business	36600.00
0005433399159	13504	Business	36600.00
0005433399145	13504	Business	36600.00
0005433399161	13504	Business	36600.00
0005435732574	13504	Business	36600.00
0005433399164	13504	Business	36600.00
0005433399123	13504	Business	36600.00
0005435732482	13504	Business	36600.00
0005435732513	13504	Business	36600.00
0005433399128	13504	Business	36600.00
0005433399152	13504	Economy	12200.00
0005433399125	13504	Economy	12200.00
0005433399156	13504	Economy	12200.00
0005433399122	13504	Economy	12200.00
0005433399154	13504	Economy	12200.00
0005433399150	13504	Economy	13400.00
0005433399119	13504	Economy	13400.00
0005433399148	13504	Economy	13400.00
0005433399151	13504	Economy	12200.00
0005433399129	13504	Economy	12200.00
0005433399121	13504	Economy	12200.00
0005433399142	13504	Economy	12200.00
0005433399158	13504	Economy	12200.00
0005433399162	13504	Economy	12200.00
0005433399166	13504	Economy	12200.00
0005433399146	13504	Economy	12200.00
0005435732541	13504	Economy	12200.00
0005433399140	13504	Economy	12200.00
0005435732575	13504	Economy	12200.00
0005433399132	13504	Economy	12200.00
0005433399127	13504	Economy	12200.00
0005433399157	13504	Economy	12200.00
0005433399163	13504	Economy	12200.00
0005433399133	13504	Economy	12200.00
0005433399141	13504	Economy	12200.00
0005433399139	13504	Economy	12200.00
0005433399137	13504	Economy	12200.00
0005433399138	13504	Economy	12200.00
0005435732514	13504	Economy	12200.00
0005433399155	13504	Economy	12200.00
0005433399136	13504	Economy	12200.00
0005433399153	13504	Economy	12200.00
0005433399130	13504	Economy	12200.00
0005433399126	13504	Economy	12200.00
0005433399147	13504	Economy	12200.00
0005433399144	13504	Economy	12200.00
0005433399165	13504	Economy	12200.00
0005433399149	13504	Economy	12200.00
0005433399143	13504	Economy	12200.00
0005433399120	13504	Economy	12200.00
0005433399160	13504	Economy	12200.00
0005433399135	13504	Economy	12200.00
0005435732540	13504	Economy	12200.00
0005433399124	13504	Economy	12200.00
0005435732505	13504	Economy	12200.00
0005433399118	13504	Economy	12200.00
0005433399131	13504	Economy	12200.00
0005433398692	19399	Business	36600.00
0005432297336	19399	Business	36600.00
0005433398767	19399	Business	36600.00
0005433398482	19399	Business	36600.00
0005433398828	19399	Business	36600.00
0005433398788	19399	Business	36600.00
0005433398776	19399	Business	36600.00
0005433398837	19399	Business	36600.00
0005433398613	19399	Economy	12200.00
0005433398954	19399	Economy	12200.00
0005433398558	19399	Economy	12200.00
0005433398594	19399	Economy	12200.00
0005433398941	19399	Economy	12200.00
0005433398764	19399	Economy	12200.00
0005433398706	19399	Economy	12200.00
0005433398812	19399	Economy	12200.00
0005433398644	19399	Economy	12200.00
0005433398766	19399	Economy	13400.00
0005433398708	19399	Economy	13400.00
0005433398444	19399	Economy	13400.00
0005433398707	19399	Economy	13400.00
0005433398746	19399	Economy	12200.00
0005433398892	19399	Economy	12200.00
0005433398808	19399	Economy	12200.00
0005433398615	19399	Economy	12200.00
0005433398445	19399	Economy	12200.00
0005433398761	19399	Economy	12200.00
0005433398701	19399	Economy	12200.00
0005433398787	19399	Economy	12200.00
0005433398688	19399	Economy	12200.00
0005433398738	19399	Economy	12200.00
0005433398765	19399	Economy	12200.00
0005433398859	19399	Economy	12200.00
0005433398886	19399	Economy	12200.00
0005433398685	19399	Economy	12200.00
0005433398813	19399	Economy	12200.00
0005433398782	19399	Economy	12200.00
0005433398533	19399	Economy	12200.00
0005433398768	19399	Economy	12200.00
0005433398614	19399	Economy	12200.00
0005433398665	19399	Economy	12200.00
0005433398704	19399	Economy	12200.00
0005433398691	19399	Economy	12200.00
0005433398745	19399	Economy	12200.00
0005433398823	19399	Economy	12200.00
0005432297337	19399	Economy	12200.00
0005433398532	19399	Economy	12200.00
0005433398702	19399	Economy	12200.00
0005433398703	19399	Economy	12200.00
0005433398860	19399	Economy	12200.00
0005433398643	19399	Economy	12200.00
0005433398726	19399	Economy	12200.00
0005433398666	19399	Economy	12200.00
0005433398639	19399	Economy	12200.00
0005433398940	19399	Economy	12200.00
0005433398829	19399	Economy	12200.00
0005433398483	19399	Economy	12200.00
0005433398595	19399	Economy	12200.00
0005433398748	19399	Economy	12200.00
0005433398622	19399	Economy	12200.00
0005433398559	19399	Economy	12200.00
0005433398616	19399	Economy	12200.00
0005433398693	19399	Economy	12200.00
0005433398836	19399	Economy	12200.00
0005433398711	19399	Economy	12200.00
0005433398747	19399	Economy	12200.00
0005433398858	19399	Economy	12200.00
0005435069611	13151	Business	11300.00
0005435069601	13151	Business	11300.00
0005435069815	13151	Business	11300.00
0005435069794	13151	Business	11300.00
0005435925595	13151	Business	11300.00
0005435925582	13151	Business	11300.00
0005435069925	13151	Business	11300.00
0005435069563	13151	Business	11300.00
0005435069934	13151	Business	11300.00
0005435925589	13151	Business	11300.00
0005435069602	13151	Economy	3800.00
0005435069808	13151	Economy	3800.00
0005435925591	13151	Economy	3800.00
0005435925596	13151	Economy	3800.00
0005435069872	13151	Economy	3800.00
0005435069760	13151	Economy	3800.00
0005435069587	13151	Economy	3800.00
0005435069924	13151	Economy	4100.00
0005435069625	13151	Economy	4100.00
0005435925575	13151	Economy	4100.00
0005435069715	13151	Economy	4100.00
0005435925592	13151	Economy	4100.00
0005435925578	13151	Economy	3800.00
0005435069687	13151	Economy	3800.00
0005435925581	13151	Economy	3800.00
0005435925583	13151	Economy	3800.00
0005435070054	13151	Economy	3800.00
0005435925587	13151	Economy	3800.00
0005435069869	13151	Economy	3800.00
0005435925586	13151	Economy	3800.00
0005435925600	13151	Economy	3800.00
0005435069740	13151	Economy	3800.00
0005435925585	13151	Economy	3800.00
0005435925593	13151	Economy	3800.00
0005435070055	13151	Economy	3800.00
0005435069851	13151	Economy	3800.00
0005435069626	13151	Economy	3800.00
0005435069878	13151	Economy	3800.00
0005435925584	13151	Economy	3800.00
0005435925598	13151	Economy	3800.00
0005435069763	13151	Economy	3800.00
0005435069753	13151	Economy	3800.00
0005435069478	13151	Economy	3800.00
0005435069852	13151	Economy	3800.00
0005435069741	13151	Economy	3800.00
0005435925574	13151	Economy	3800.00
0005435925579	13151	Economy	3800.00
0005435925577	13151	Economy	3800.00
0005435069682	13151	Economy	3800.00
0005435069730	13151	Economy	3800.00
0005435069833	13151	Economy	3800.00
0005435069705	13151	Economy	3800.00
0005435069379	13151	Economy	3800.00
0005435069571	13151	Economy	3800.00
0005435069956	13151	Economy	3800.00
0005435925580	13151	Economy	3800.00
0005435069683	13151	Economy	3800.00
0005435069679	13151	Economy	3800.00
0005435069796	13151	Economy	3800.00
0005435925597	13151	Economy	3800.00
0005435925599	13151	Economy	3800.00
0005435925572	13151	Economy	3800.00
0005435925588	13151	Economy	3800.00
0005435925576	13151	Economy	3800.00
0005435925573	13151	Economy	3800.00
0005435925594	13151	Economy	3800.00
0005435069953	13151	Economy	3800.00
0005435069954	13151	Economy	3800.00
0005435925590	13151	Economy	3800.00
0005435070217	15481	Business	11300.00
0005435070222	15481	Business	11300.00
0005435070198	15481	Business	11300.00
0005435925439	15481	Business	11300.00
0005435070177	15481	Business	11300.00
0005435070223	15481	Business	11300.00
0005435070189	15481	Economy	3800.00
0005435070220	15481	Economy	3800.00
0005435925470	15481	Economy	3800.00
0005435070203	15481	Economy	3800.00
0005435070186	15481	Economy	3800.00
0005435070184	15481	Economy	3800.00
0005435925416	15481	Economy	3800.00
0005435070188	15481	Economy	3800.00
0005435070214	15481	Economy	4100.00
0005435070197	15481	Economy	4100.00
0005435070182	15481	Economy	4100.00
0005435070193	15481	Economy	4100.00
0005435925471	15481	Economy	3800.00
0005435925472	15481	Economy	3800.00
0005435070212	15481	Economy	3800.00
0005435070187	15481	Economy	3800.00
0005435070196	15481	Economy	3800.00
0005435070174	15481	Economy	3800.00
0005435070201	15481	Economy	3800.00
0005435070192	15481	Economy	3800.00
0005435070199	15481	Economy	3800.00
0005435070216	15481	Economy	3800.00
0005435070208	15481	Economy	3800.00
0005435070179	15481	Economy	3800.00
0005435070205	15481	Economy	3800.00
0005435070180	15481	Economy	3800.00
0005435070195	15481	Economy	3800.00
0005435070206	15481	Economy	3800.00
0005435070176	15481	Economy	3800.00
0005435070194	15481	Economy	3800.00
0005435070215	15481	Economy	3800.00
0005435070175	15481	Economy	3800.00
0005435925438	15481	Economy	3800.00
0005435070204	15481	Economy	3800.00
0005435925498	15481	Economy	3800.00
0005435070202	15481	Economy	3800.00
0005435925475	15481	Economy	3800.00
0005435070200	15481	Economy	3800.00
0005435070191	15481	Economy	3800.00
0005435070209	15481	Economy	3800.00
0005435070213	15481	Economy	3800.00
0005435925484	15481	Economy	3800.00
0005435070211	15481	Economy	3800.00
0005435070185	15481	Economy	3800.00
0005435070207	15481	Economy	3800.00
0005435070218	15481	Economy	3800.00
0005435070173	15481	Economy	3800.00
0005435070221	15481	Economy	3800.00
0005435070219	15481	Economy	3800.00
0005435070210	15481	Economy	3800.00
0005435070172	15481	Economy	3800.00
0005435925451	15481	Economy	3800.00
0005435925452	15481	Economy	3800.00
0005435070181	15481	Economy	3800.00
0005435070178	15481	Economy	3800.00
0005435925497	15481	Economy	3800.00
0005435070171	15481	Economy	3800.00
0005435070183	15481	Economy	3800.00
0005435070190	15481	Economy	3800.00
0005435925468	15481	Economy	3800.00
0005435808352	29493	Economy	27100.00
0005433407676	29493	Economy	27100.00
0005435808359	29493	Economy	24700.00
0005435808331	29493	Economy	24700.00
0005435808308	29493	Economy	24700.00
0005433407678	29493	Economy	24700.00
0005435808381	29493	Economy	24700.00
0005435808376	29493	Economy	24700.00
0005435808380	29493	Economy	24700.00
0005435808341	29493	Economy	24700.00
0005433407681	29493	Economy	24700.00
0005435808350	29493	Economy	24700.00
0005435808379	29493	Economy	24700.00
0005435808309	29493	Economy	24700.00
0005435808357	29493	Economy	24700.00
0005435808351	29493	Economy	24700.00
0005435808335	29493	Economy	24700.00
0005435808310	29493	Economy	24700.00
0005435808355	29493	Economy	24700.00
0005433407675	29493	Economy	24700.00
0005433407683	29493	Economy	24700.00
0005435808334	29493	Economy	24700.00
0005433407679	29493	Economy	24700.00
0005433407677	29493	Economy	24700.00
0005435808340	29493	Economy	24700.00
0005433407682	29493	Economy	24700.00
0005433407680	29493	Economy	24700.00
0005435808358	29493	Economy	24700.00
0005435808343	29493	Economy	24700.00
0005435808316	29493	Economy	24700.00
0005434756929	10686	Business	61300.00
0005434215599	10686	Business	61300.00
0005434215564	10686	Business	61300.00
0005434756868	10686	Business	61300.00
0005434215594	10686	Business	61300.00
0005434215570	10686	Business	61300.00
0005434756917	10686	Business	61300.00
0005434215557	10686	Business	61300.00
0005434215588	10686	Business	61300.00
0005434215595	10686	Business	61300.00
0005434756597	10686	Business	61300.00
0005434756967	10686	Business	61300.00
0005434215584	10686	Economy	20400.00
0005434215590	10686	Economy	20400.00
0005434756931	10686	Economy	20400.00
0005434215600	10686	Economy	20400.00
0005434215583	10686	Economy	20400.00
0005434756988	10686	Economy	20400.00
0005434215558	10686	Economy	20400.00
0005434756904	10686	Economy	20400.00
0005434215565	10686	Economy	20400.00
0005434756894	10686	Economy	22500.00
0005434757033	10686	Economy	22500.00
0005434757048	10686	Economy	22500.00
0005434756982	10686	Economy	22500.00
0005434756890	10686	Economy	22500.00
0005434757008	10686	Economy	20400.00
0005434215578	10686	Economy	20400.00
0005434215591	10686	Economy	20400.00
0005434756892	10686	Economy	20400.00
0005434757000	10686	Economy	20400.00
0005434215560	10686	Economy	20400.00
0005434756825	10686	Economy	20400.00
0005434756930	10686	Economy	20400.00
0005434215574	10686	Economy	20400.00
0005434756918	10686	Economy	20400.00
0005434215567	10686	Economy	20400.00
0005434215555	10686	Economy	20400.00
0005434215572	10686	Economy	20400.00
0005434215554	10686	Economy	20400.00
0005434756789	10686	Economy	20400.00
0005434756884	10686	Economy	20400.00
0005434756990	10686	Economy	20400.00
0005434756803	10686	Economy	20400.00
0005434215592	10686	Economy	20400.00
0005434215581	10686	Economy	20400.00
0005434215598	10686	Economy	20400.00
0005434215586	10686	Economy	20400.00
0005434215561	10686	Economy	20400.00
0005434756913	10686	Economy	20400.00
0005434215569	10686	Economy	20400.00
0005434215597	10686	Economy	20400.00
0005434756906	10686	Economy	20400.00
0005434215579	10686	Economy	20400.00
0005434756950	10686	Economy	20400.00
0005434756997	10686	Economy	20400.00
0005434215568	10686	Economy	20400.00
0005434215585	10686	Economy	20400.00
0005434215566	10686	Economy	20400.00
0005434756968	10686	Economy	20400.00
0005434756865	10686	Economy	20400.00
0005434756932	10686	Economy	20400.00
0005434756914	10686	Economy	20400.00
0005434215571	10686	Economy	20400.00
0005434756871	10686	Economy	20400.00
0005434215589	10686	Economy	20400.00
0005434756883	10686	Economy	20400.00
0005434756598	10686	Economy	20400.00
0005434756998	10686	Economy	20400.00
0005434215596	10686	Economy	20400.00
0005434215582	10686	Economy	20400.00
0005434215559	10686	Economy	20400.00
0005434215562	10686	Economy	20400.00
0005434215573	10686	Economy	20400.00
0005434757012	10686	Economy	20400.00
0005434756788	10686	Economy	20400.00
0005434756907	10686	Economy	20400.00
0005434215593	10686	Economy	20400.00
0005434757032	10686	Economy	20400.00
0005434756840	10686	Economy	20400.00
0005434756978	10686	Economy	20400.00
0005434215577	10686	Economy	20400.00
0005434215580	10686	Economy	20400.00
0005434215575	10686	Economy	20400.00
0005434757026	10686	Economy	20400.00
0005434756599	10686	Economy	20400.00
0005434215556	10686	Economy	20400.00
0005434756885	10686	Economy	20400.00
0005434756866	10686	Economy	20400.00
0005434215587	10686	Economy	20400.00
0005434756991	10686	Economy	20400.00
0005434215576	10686	Economy	20400.00
0005434756999	10686	Economy	20400.00
0005434215563	10686	Economy	20400.00
0005434757330	28667	Business	61300.00
0005434757304	28667	Business	61300.00
0005434757337	28667	Business	61300.00
0005434215203	28667	Business	61300.00
0005434757302	28667	Business	61300.00
0005434757317	28667	Business	61300.00
0005434215243	28667	Business	61300.00
0005434757300	28667	Business	61300.00
0005434214987	28667	Business	61300.00
0005434215246	28667	Business	61300.00
0005434757335	28667	Business	61300.00
0005434215236	28667	Business	61300.00
0005434215073	28667	Economy	20400.00
0005434757328	28667	Economy	20400.00
0005434757299	28667	Economy	20400.00
0005434757333	28667	Economy	20400.00
0005434215268	28667	Economy	20400.00
0005434215085	28667	Economy	20400.00
0005434757296	28667	Economy	20400.00
0005434757303	28667	Economy	20400.00
0005434214941	28667	Economy	20400.00
0005434215084	28667	Economy	20400.00
0005434757313	28667	Economy	22500.00
0005434215152	28667	Economy	22500.00
0005434757327	28667	Economy	22500.00
0005434757321	28667	Economy	22500.00
0005434215072	28667	Economy	22500.00
0005434215020	28667	Economy	20400.00
0005434215029	28667	Economy	20400.00
0005434757306	28667	Economy	20400.00
0005434215248	28667	Economy	20400.00
0005434215104	28667	Economy	20400.00
0005434757310	28667	Economy	20400.00
0005434215062	28667	Economy	20400.00
0005434757334	28667	Economy	20400.00
0005434215093	28667	Economy	20400.00
0005434215041	28667	Economy	20400.00
0005434757332	28667	Economy	20400.00
0005434757291	28667	Economy	20400.00
0005434757308	28667	Economy	20400.00
0005434757331	28667	Economy	20400.00
0005434215237	28667	Economy	20400.00
0005434757323	28667	Economy	20400.00
0005434215076	28667	Economy	20400.00
0005434215219	28667	Economy	20400.00
0005434757315	28667	Economy	20400.00
0005434757294	28667	Economy	20400.00
0005434215305	28667	Economy	20400.00
0005434214988	28667	Economy	20400.00
0005434757309	28667	Economy	20400.00
0005434757320	28667	Economy	20400.00
0005434757319	28667	Economy	20400.00
0005434757301	28667	Economy	20400.00
0005434215063	28667	Economy	20400.00
0005434215083	28667	Economy	20400.00
0005434215120	28667	Economy	20400.00
0005434214829	28667	Economy	20400.00
0005434757324	28667	Economy	20400.00
0005434215021	28667	Economy	20400.00
0005434215135	28667	Economy	20400.00
0005434757329	28667	Economy	20400.00
0005434757292	28667	Economy	20400.00
0005434757305	28667	Economy	20400.00
0005434757311	28667	Economy	20400.00
0005434757293	28667	Economy	20400.00
0005434757326	28667	Economy	20400.00
0005434215042	28667	Economy	20400.00
0005434757295	28667	Economy	20400.00
0005434757318	28667	Economy	20400.00
0005434757322	28667	Economy	20400.00
0005434215169	28667	Economy	20400.00
0005434757325	28667	Economy	20400.00
0005434215065	28667	Economy	20400.00
0005434757297	28667	Economy	20400.00
0005434215037	28667	Economy	20400.00
0005434757314	28667	Economy	20400.00
0005434215221	28667	Economy	20400.00
0005434215094	28667	Economy	20400.00
0005434757336	28667	Economy	20400.00
0005434215211	28667	Economy	20400.00
0005434215266	28667	Economy	20400.00
0005434215220	28667	Economy	20400.00
0005434215151	28667	Economy	20400.00
0005434215174	28667	Economy	20400.00
0005434215049	28667	Economy	20400.00
0005434215087	28667	Economy	20400.00
0005434757307	28667	Economy	20400.00
0005434757312	28667	Economy	20400.00
0005434757316	28667	Economy	20400.00
0005434215077	28667	Economy	20400.00
0005434215247	28667	Economy	20400.00
0005434757298	28667	Economy	20400.00
0005434215010	28667	Economy	20400.00
0005435007553	5446	Business	29500.00
0005435042911	5446	Business	29500.00
0005435007559	5446	Business	29500.00
0005435041256	5446	Business	29500.00
0005435007555	5446	Business	29500.00
0005435041203	5446	Business	29500.00
0005435007544	5446	Business	29500.00
0005435041245	5446	Business	29500.00
0005435041222	5446	Business	29500.00
0005435041229	5446	Business	29500.00
0005435041241	5446	Business	29500.00
0005435041217	5446	Business	29500.00
0005435041251	5446	Economy	9800.00
0005435042907	5446	Economy	9800.00
0005435007542	5446	Economy	9800.00
0005435041253	5446	Economy	9800.00
0005435041232	5446	Economy	9800.00
0005435041216	5446	Economy	9800.00
0005435041200	5446	Economy	9800.00
0005434229689	5446	Economy	9800.00
0005435041257	5446	Economy	9800.00
0005435041252	5446	Economy	9800.00
0005435041235	5446	Economy	9800.00
0005435041210	5446	Economy	9800.00
0005435041227	5446	Economy	9800.00
0005434229656	5446	Economy	9800.00
0005435041193	5446	Economy	9800.00
0005435041250	5446	Economy	9800.00
0005435041220	5446	Economy	9800.00
0005434229781	5446	Economy	9800.00
0005435007543	5446	Economy	9800.00
0005435041221	5446	Economy	9800.00
0005435041201	5446	Economy	9800.00
0005435007556	5446	Economy	9800.00
0005435041215	5446	Economy	9800.00
0005432125620	5446	Economy	9800.00
0005435041247	5446	Economy	9800.00
0005435041206	5446	Economy	9800.00
0005434229567	5446	Economy	9800.00
0005435041246	5446	Economy	9800.00
0005435041230	5446	Economy	9800.00
0005435041231	5446	Economy	9800.00
0005435041255	5446	Economy	9800.00
0005432125618	5446	Economy	9800.00
0005434229688	5446	Economy	9800.00
0005434229707	5446	Economy	9800.00
0005434229780	5446	Economy	9800.00
0005434229705	5446	Economy	10800.00
0005435007562	5446	Economy	10800.00
0005434229722	5446	Economy	10800.00
0005435041224	5446	Economy	10800.00
0005435041248	5446	Economy	10800.00
0005435041196	5446	Economy	10800.00
0005432125619	5446	Economy	9800.00
0005435041225	5446	Economy	9800.00
0005435041209	5446	Economy	9800.00
0005432125615	5446	Economy	9800.00
0005435041254	5446	Economy	9800.00
0005435041198	5446	Economy	9800.00
0005435007549	5446	Economy	9800.00
0005435041226	5446	Economy	9800.00
0005435041190	5446	Economy	9800.00
0005435041239	5446	Economy	9800.00
0005435041211	5446	Economy	9800.00
0005434229748	5446	Economy	9800.00
0005435007546	5446	Economy	9800.00
0005435007560	5446	Economy	9800.00
0005435007552	5446	Economy	9800.00
0005434229738	5446	Economy	9800.00
0005435041202	5446	Economy	9800.00
0005435041192	5446	Economy	9800.00
0005435007545	5446	Economy	9800.00
0005435041234	5446	Economy	9800.00
0005432125614	5446	Economy	9800.00
0005435043301	5446	Economy	9800.00
0005435007558	5446	Economy	9800.00
0005435041218	5446	Economy	9800.00
0005434229735	5446	Economy	9800.00
0005435041228	5446	Economy	9800.00
0005435043300	5446	Economy	9800.00
0005435007563	5446	Economy	9800.00
0005435042908	5446	Economy	9800.00
0005435041214	5446	Economy	9800.00
0005435041199	5446	Economy	9800.00
0005435041223	5446	Economy	9800.00
0005435041236	5446	Economy	9800.00
0005435007557	5446	Economy	9800.00
0005435007554	5446	Economy	9800.00
0005435041233	5446	Economy	9800.00
0005435041205	5446	Economy	9800.00
0005435041219	5446	Economy	9800.00
0005435041197	5446	Economy	9800.00
0005435007548	5446	Economy	9800.00
0005432125617	5446	Economy	9800.00
0005435041212	5446	Economy	9800.00
0005435041195	5446	Economy	9800.00
0005435007551	5446	Economy	9800.00
0005435007561	5446	Economy	9800.00
0005434229706	5446	Economy	9800.00
0005435041243	5446	Economy	9800.00
0005435042909	5446	Economy	9800.00
0005435041249	5446	Economy	9800.00
0005435041237	5446	Economy	9800.00
0005435041240	5446	Economy	9800.00
0005435041194	5446	Economy	9800.00
0005435041244	5446	Economy	9800.00
0005435043299	5446	Economy	9800.00
0005435041204	5446	Economy	9800.00
0005435007547	5446	Economy	9800.00
0005435041207	5446	Economy	9800.00
0005435041238	5446	Economy	9800.00
0005435041213	5446	Economy	9800.00
0005435041208	5446	Economy	9800.00
0005432125616	5446	Economy	9800.00
0005435042910	5446	Economy	9800.00
0005434229657	5446	Economy	9800.00
0005435007541	5446	Economy	9800.00
0005435007540	5446	Economy	9800.00
0005435041242	5446	Economy	9800.00
0005435041191	5446	Economy	9800.00
0005434229728	5446	Economy	9800.00
0005435007550	5446	Economy	9800.00
0005434229670	5446	Economy	9800.00
0005435040685	12992	Business	29500.00
0005434229878	12992	Business	29500.00
0005435040804	12992	Business	29500.00
0005435040616	12992	Business	29500.00
0005434229883	12992	Business	29500.00
0005435040632	12992	Business	29500.00
0005435007298	12992	Business	29500.00
0005435040618	12992	Business	29500.00
0005435040511	12992	Business	29500.00
0005435040615	12992	Business	29500.00
0005435040409	12992	Business	29500.00
0005434229889	12992	Business	29500.00
0005435040917	12992	Economy	9800.00
0005435040561	12992	Economy	9800.00
0005435040631	12992	Economy	9800.00
0005435040629	12992	Economy	9800.00
0005435040739	12992	Economy	9800.00
0005435040347	12992	Economy	9800.00
0005435040622	12992	Economy	9800.00
0005434229888	12992	Economy	9800.00
0005435040765	12992	Economy	9800.00
0005435040806	12992	Economy	9800.00
0005435040788	12992	Economy	9800.00
0005434229876	12992	Economy	9800.00
0005435007293	12992	Economy	9800.00
0005434229875	12992	Economy	9800.00
0005435040457	12992	Economy	9800.00
0005435007329	12992	Economy	9800.00
0005435040483	12992	Economy	9800.00
0005435007381	12992	Economy	9800.00
0005435040628	12992	Economy	9800.00
0005435040559	12992	Economy	9800.00
0005435040662	12992	Economy	9800.00
0005432304486	12992	Economy	9800.00
0005434229873	12992	Economy	9800.00
0005435040663	12992	Economy	9800.00
0005435040558	12992	Economy	9800.00
0005435007364	12992	Economy	9800.00
0005435040916	12992	Economy	9800.00
0005435040807	12992	Economy	9800.00
0005435040614	12992	Economy	9800.00
0005434229884	12992	Economy	9800.00
0005435040683	12992	Economy	9800.00
0005435040404	12992	Economy	9800.00
0005435040686	12992	Economy	9800.00
0005435007371	12992	Economy	9800.00
0005435007325	12992	Economy	9800.00
0005435040870	12992	Economy	9800.00
0005435007372	12992	Economy	9800.00
0005435040789	12992	Economy	9800.00
0005435040570	12992	Economy	9800.00
0005435040708	12992	Economy	9800.00
0005435040477	12992	Economy	10800.00
0005434229882	12992	Economy	10800.00
0005435040805	12992	Economy	10800.00
0005435040777	12992	Economy	10800.00
0005435040508	12992	Economy	10800.00
0005435007252	12992	Economy	10800.00
0005435040884	12992	Economy	9800.00
0005435040751	12992	Economy	9800.00
0005432304487	12992	Economy	9800.00
0005435040820	12992	Economy	9800.00
0005435040450	12992	Economy	9800.00
0005435040606	12992	Economy	9800.00
0005432304484	12992	Economy	9800.00
0005435007346	12992	Economy	9800.00
0005434229870	12992	Economy	9800.00
0005435007359	12992	Economy	9800.00
0005435040485	12992	Economy	9800.00
0005434229874	12992	Economy	9800.00
0005435040771	12992	Economy	9800.00
0005435040687	12992	Economy	9800.00
0005435040499	12992	Economy	9800.00
0005435040607	12992	Economy	9800.00
0005435040641	12992	Economy	9800.00
0005435040576	12992	Economy	9800.00
0005435040512	12992	Economy	9800.00
0005435040764	12992	Economy	9800.00
0005435040847	12992	Economy	9800.00
0005435040740	12992	Economy	9800.00
0005434229881	12992	Economy	9800.00
0005435040456	12992	Economy	9800.00
0005435040575	12992	Economy	9800.00
0005435040749	12992	Economy	9800.00
0005435007348	12992	Economy	9800.00
0005435040736	12992	Economy	9800.00
0005435040727	12992	Economy	9800.00
0005434229871	12992	Economy	9800.00
0005434229885	12992	Economy	9800.00
0005434229868	12992	Economy	9800.00
0005434229879	12992	Economy	9800.00
0005435007299	12992	Economy	9800.00
0005435040688	12992	Economy	9800.00
0005435040772	12992	Economy	9800.00
0005435007336	12992	Economy	9800.00
0005435007347	12992	Economy	9800.00
0005435007351	12992	Economy	9800.00
0005435040619	12992	Economy	9800.00
0005435040432	12992	Economy	9800.00
0005435040752	12992	Economy	9800.00
0005432304485	12992	Economy	9800.00
0005435007365	12992	Economy	9800.00
0005435040709	12992	Economy	9800.00
0005434229877	12992	Economy	9800.00
0005435040712	12992	Economy	9800.00
0005435040645	12992	Economy	9800.00
0005434229880	12992	Economy	9800.00
0005435040522	12992	Economy	9800.00
0005435040474	12992	Economy	9800.00
0005434229869	12992	Economy	9800.00
0005435040684	12992	Economy	9800.00
0005435040821	12992	Economy	9800.00
0005434229872	12992	Economy	9800.00
0005435040571	12992	Economy	9800.00
0005434229887	12992	Economy	9800.00
0005435040486	12992	Economy	9800.00
0005435040763	12992	Economy	9800.00
0005435040741	12992	Economy	9800.00
0005434229886	12992	Economy	9800.00
0005435040889	12992	Economy	9800.00
0005435040888	12992	Economy	9800.00
0005434229890	12992	Economy	9800.00
0005435007386	12992	Economy	9800.00
0005435007366	12992	Economy	9800.00
0005435040935	12992	Economy	9800.00
0005435040700	12992	Economy	9800.00
0005435040560	12992	Economy	9800.00
0005435040510	12992	Economy	9800.00
0005435040623	12992	Economy	9800.00
0005434427252	14858	Business	52900.00
0005435902860	14858	Business	52900.00
0005434427256	14858	Business	52900.00
0005434427246	14858	Business	52900.00
0005435903013	14858	Business	52900.00
0005434427248	14858	Business	52900.00
0005435902944	14858	Business	52900.00
0005434427242	14858	Business	52900.00
0005434427232	14858	Economy	17600.00
0005435902970	14858	Economy	17600.00
0005434427245	14858	Economy	17600.00
0005435902991	14858	Economy	17600.00
0005434427240	14858	Economy	17600.00
0005435902929	14858	Economy	17600.00
0005434411869	14858	Economy	19400.00
0005434427231	14858	Economy	19400.00
0005434427236	14858	Economy	17600.00
0005434427258	14858	Economy	17600.00
0005434427249	14858	Economy	17600.00
0005434427235	14858	Economy	17600.00
0005434411873	14858	Economy	17600.00
0005434427250	14858	Economy	17600.00
0005435902961	14858	Economy	17600.00
0005434427254	14858	Economy	17600.00
0005434427233	14858	Economy	17600.00
0005435902959	14858	Economy	17600.00
0005435902960	14858	Economy	17600.00
0005435902932	14858	Economy	17600.00
0005435902859	14858	Economy	17600.00
0005434427259	14858	Economy	17600.00
0005435554224	14858	Economy	17600.00
0005434427237	14858	Economy	17600.00
0005434427234	14858	Economy	17600.00
0005432188679	14858	Economy	17600.00
0005434427257	14858	Economy	17600.00
0005435554242	14858	Economy	17600.00
0005434427243	14858	Economy	17600.00
0005434427251	14858	Economy	17600.00
0005434411871	14858	Economy	17600.00
0005434427247	14858	Economy	17600.00
0005434427239	14858	Economy	17600.00
0005435902974	14858	Economy	17600.00
0005434427253	14858	Economy	17600.00
0005435902926	14858	Economy	17600.00
0005432188678	14858	Economy	17600.00
0005434411870	14858	Economy	17600.00
0005434427241	14858	Economy	17600.00
0005434427255	14858	Economy	17600.00
0005435554241	14858	Economy	17600.00
0005434427244	14858	Economy	17600.00
0005435902928	14858	Economy	17600.00
0005435902933	14858	Economy	17600.00
0005435902968	14858	Economy	17600.00
0005434427238	14858	Economy	17600.00
0005434411872	14858	Economy	17600.00
0005435902946	14858	Economy	17600.00
0005435902971	14858	Economy	17600.00
0005434427058	20231	Business	52900.00
0005435554298	20231	Business	52900.00
0005434427088	20231	Business	52900.00
0005435903109	20231	Business	52900.00
0005435903100	20231	Business	52900.00
0005435554297	20231	Business	52900.00
0005434427008	20231	Business	52900.00
0005434427069	20231	Business	52900.00
0005434411841	20231	Economy	17600.00
0005434411846	20231	Economy	17600.00
0005434426991	20231	Economy	17600.00
0005435903096	20231	Economy	17600.00
0005434411830	20231	Economy	17600.00
0005434426960	20231	Economy	17600.00
0005434426950	20231	Economy	19400.00
0005434427110	20231	Economy	19400.00
0005434427024	20231	Economy	19400.00
0005434427158	20231	Economy	17600.00
0005432059549	20231	Economy	17600.00
0005435903095	20231	Economy	17600.00
0005434426999	20231	Economy	17600.00
0005434426905	20231	Economy	17600.00
0005434426888	20231	Economy	17600.00
0005434427111	20231	Economy	17600.00
0005435554296	20231	Economy	17600.00
0005435903108	20231	Economy	17600.00
0005434427112	20231	Economy	17600.00
0005434426848	20231	Economy	17600.00
0005434426904	20231	Economy	17600.00
0005434411851	20231	Economy	17600.00
0005435903110	20231	Economy	17600.00
0005434411835	20231	Economy	17600.00
0005434427063	20231	Economy	17600.00
0005435903112	20231	Economy	17600.00
0005434426995	20231	Economy	17600.00
0005434427001	20231	Economy	17600.00
0005434427009	20231	Economy	17600.00
0005435903103	20231	Economy	17600.00
0005434426961	20231	Economy	17600.00
0005434411834	20231	Economy	17600.00
0005432059550	20231	Economy	17600.00
0005435903102	20231	Economy	17600.00
0005435903111	20231	Economy	17600.00
0005434427035	20231	Economy	17600.00
0005435903099	20231	Economy	17600.00
0005434411831	20231	Economy	17600.00
0005434427015	20231	Economy	17600.00
0005435554299	20231	Economy	17600.00
0005434427047	20231	Economy	17600.00
0005434427023	20231	Economy	17600.00
0005435903106	20231	Economy	17600.00
0005435903097	20231	Economy	17600.00
0005434427062	20231	Economy	17600.00
0005434411844	20231	Economy	17600.00
0005435903104	20231	Economy	17600.00
0005434426979	20231	Economy	17600.00
0005434427120	20231	Economy	17600.00
0005434411855	20231	Economy	17600.00
0005434426988	20231	Economy	17600.00
0005434426911	20231	Economy	17600.00
0005434426990	20231	Economy	17600.00
0005434411845	20231	Economy	17600.00
0005434427119	20231	Economy	17600.00
0005435903098	20231	Economy	17600.00
0005435903107	20231	Economy	17600.00
0005434411840	20231	Economy	17600.00
0005434427116	20231	Economy	17600.00
0005435903105	20231	Economy	17600.00
0005434411826	20231	Economy	17600.00
0005435903101	20231	Economy	17600.00
0005434411850	20231	Economy	17600.00
0005432059551	20231	Economy	17600.00
0005433434926	26506	Business	18500.00
0005433434928	26506	Business	18500.00
0005435983256	26506	Business	18500.00
0005435983257	26506	Business	18500.00
0005432300391	26506	Business	18500.00
0005432300392	26506	Business	18500.00
0005435983244	26506	Business	18500.00
0005433435071	26506	Business	18500.00
0005435983252	26506	Business	18500.00
0005435983288	26506	Business	18500.00
0005433435017	26506	Business	18500.00
0005433435055	26506	Business	18500.00
0005435983276	26506	Economy	6200.00
0005435983255	26506	Economy	6200.00
0005435983267	26506	Economy	6200.00
0005435983282	26506	Economy	6200.00
0005435983254	26506	Economy	6200.00
0005433435211	26506	Economy	6200.00
0005435983248	26506	Economy	6200.00
0005435983275	26506	Economy	6200.00
0005433435069	26506	Economy	6200.00
0005435983247	26506	Economy	6200.00
0005435983264	26506	Economy	6800.00
0005432300393	26506	Economy	6800.00
0005433435126	26506	Economy	6800.00
0005432300390	26506	Economy	6800.00
0005432300389	26506	Economy	6800.00
0005435983268	26506	Economy	6200.00
0005433435129	26506	Economy	6200.00
0005433435128	26506	Economy	6200.00
0005435983283	26506	Economy	6200.00
0005435983266	26506	Economy	6200.00
0005433434993	26506	Economy	6200.00
0005435983286	26506	Economy	6200.00
0005435983271	26506	Economy	6200.00
0005433434967	26506	Economy	6200.00
0005433435119	26506	Economy	6200.00
0005435983263	26506	Economy	6200.00
0005433435081	26506	Economy	6200.00
0005435983280	26506	Economy	6200.00
0005433435060	26506	Economy	6200.00
0005435983261	26506	Economy	6200.00
0005435983273	26506	Economy	6200.00
0005433434974	26506	Economy	6200.00
0005433435039	26506	Economy	6200.00
0005435983274	26506	Economy	6200.00
0005434273104	26506	Economy	6200.00
0005435983281	26506	Economy	6200.00
0005433435133	26506	Economy	6200.00
0005433434958	26506	Economy	6200.00
0005435983249	26506	Economy	6200.00
0005432300388	26506	Economy	6200.00
0005435983251	26506	Economy	6200.00
0005433434978	26506	Economy	6200.00
0005435983265	26506	Economy	6200.00
0005435983290	26506	Economy	6200.00
0005435983284	26506	Economy	6200.00
0005433435038	26506	Economy	6200.00
0005433435056	26506	Economy	6200.00
0005433435135	26506	Economy	6200.00
0005433434989	26506	Economy	6200.00
0005435983250	26506	Economy	6200.00
0005433435080	26506	Economy	6200.00
0005433435057	26506	Economy	6200.00
0005435983258	26506	Economy	6200.00
0005433434990	26506	Economy	6200.00
0005433434972	26506	Economy	6200.00
0005435983260	26506	Economy	6200.00
0005435983245	26506	Economy	6200.00
0005433435046	26506	Economy	6200.00
0005435983287	26506	Economy	6200.00
0005433434973	26506	Economy	6200.00
0005433434979	26506	Economy	6200.00
0005435983289	26506	Economy	6200.00
0005435983246	26506	Economy	6200.00
0005435983262	26506	Economy	6200.00
0005435983259	26506	Economy	6200.00
0005435983253	26506	Economy	6200.00
0005435983278	26506	Economy	6200.00
0005433434991	26506	Economy	6200.00
0005433435125	26506	Economy	6200.00
0005435983272	26506	Economy	6200.00
0005435983270	26506	Economy	6200.00
0005435983277	26506	Economy	6200.00
0005433434927	26506	Economy	6200.00
0005435983285	26506	Economy	6200.00
0005433434988	26506	Economy	6200.00
0005435983279	26506	Economy	6200.00
0005435983269	26506	Economy	6200.00
0005433435212	26506	Economy	6200.00
0005433435024	26506	Economy	6200.00
0005433434994	26506	Economy	6200.00
0005433434992	26506	Economy	6200.00
0005434273105	26506	Economy	6200.00
0005435983157	26714	Business	18500.00
0005433435317	26714	Business	18500.00
0005433435313	26714	Business	18500.00
0005435982775	26714	Business	18500.00
0005433435323	26714	Business	18500.00
0005434270256	26714	Business	18500.00
0005433435314	26714	Business	18500.00
0005435983024	26714	Business	18500.00
0005435982906	26714	Business	18500.00
0005433435321	26714	Business	18500.00
0005433435326	26714	Economy	6200.00
0005433435311	26714	Economy	6200.00
0005433435319	26714	Economy	6200.00
0005432051201	26714	Economy	6200.00
0005435982842	26714	Economy	6200.00
0005435982847	26714	Economy	6200.00
0005435983015	26714	Economy	6200.00
0005435982967	26714	Economy	6200.00
0005433435316	26714	Economy	6200.00
0005435982943	26714	Economy	6800.00
0005434271360	26714	Economy	6800.00
0005433435324	26714	Economy	6800.00
0005433435322	26714	Economy	6800.00
0005435982860	26714	Economy	6800.00
0005433435304	26714	Economy	6200.00
0005433435318	26714	Economy	6200.00
0005432051199	26714	Economy	6200.00
0005434270255	26714	Economy	6200.00
0005435982857	26714	Economy	6200.00
0005435982774	26714	Economy	6200.00
0005435983009	26714	Economy	6200.00
0005434271361	26714	Economy	6200.00
0005433435303	26714	Economy	6200.00
0005434269149	26714	Economy	6200.00
0005433435320	26714	Economy	6200.00
0005435982892	26714	Economy	6200.00
0005435982936	26714	Economy	6200.00
0005432051198	26714	Economy	6200.00
0005435982858	26714	Economy	6200.00
0005433435309	26714	Economy	6200.00
0005433435310	26714	Economy	6200.00
0005435982891	26714	Economy	6200.00
0005435982837	26714	Economy	6200.00
0005433435307	26714	Economy	6200.00
0005435982957	26714	Economy	6200.00
0005435983042	26714	Economy	6200.00
0005435982944	26714	Economy	6200.00
0005435982869	26714	Economy	6200.00
0005435982901	26714	Economy	6200.00
0005435982796	26714	Economy	6200.00
0005433435306	26714	Economy	6200.00
0005435982862	26714	Economy	6200.00
0005434271358	26714	Economy	6200.00
0005435982811	26714	Economy	6200.00
0005432051200	26714	Economy	6200.00
0005435982863	26714	Economy	6200.00
0005435982808	26714	Economy	6200.00
0005433435305	26714	Economy	6200.00
0005435982849	26714	Economy	6200.00
0005433435328	26714	Economy	6200.00
0005435982938	26714	Economy	6200.00
0005435982810	26714	Economy	6200.00
0005435982896	26714	Economy	6200.00
0005433435312	26714	Economy	6200.00
0005435982879	26714	Economy	6200.00
0005433435315	26714	Economy	6200.00
0005434269150	26714	Economy	6200.00
0005435983111	26714	Economy	6200.00
0005435982895	26714	Economy	6200.00
0005435982805	26714	Economy	6200.00
0005433435302	26714	Economy	6200.00
0005435982850	26714	Economy	6200.00
0005433435325	26714	Economy	6200.00
0005435982790	26714	Economy	6200.00
0005432051197	26714	Economy	6200.00
0005435982968	26714	Economy	6200.00
0005435982911	26714	Economy	6200.00
0005434271359	26714	Economy	6200.00
0005435982908	26714	Economy	6200.00
0005434270254	26714	Economy	6200.00
0005435982890	26714	Economy	6200.00
0005433435327	26714	Economy	6200.00
0005433435308	26714	Economy	6200.00
0005435983025	26714	Economy	6200.00
0005435982907	26714	Economy	6200.00
0005432584590	3157	Economy	11100.00
0005432858255	3157	Economy	11100.00
0005432584609	3157	Economy	11100.00
0005432584607	3157	Economy	11100.00
0005432584597	3157	Economy	10100.00
0005432584599	3157	Economy	10100.00
0005432584591	3157	Economy	10100.00
0005432584598	3157	Economy	10100.00
0005432584603	3157	Economy	10100.00
0005432584605	3157	Economy	10100.00
0005432858259	3157	Economy	10100.00
0005432584604	3157	Economy	10100.00
0005432858220	3157	Economy	10100.00
0005432584613	3157	Economy	10100.00
0005432216336	3157	Economy	10100.00
0005432584600	3157	Economy	10100.00
0005432584614	3157	Economy	10100.00
0005432858234	3157	Economy	10100.00
0005432584596	3157	Economy	10100.00
0005432858257	3157	Economy	10100.00
0005432584611	3157	Economy	10100.00
0005432584606	3157	Economy	10100.00
0005432584601	3157	Economy	10100.00
0005432584615	3157	Economy	10100.00
0005432858233	3157	Economy	10100.00
0005432584593	3157	Economy	10100.00
0005432858250	3157	Economy	10100.00
0005432584608	3157	Economy	10100.00
0005432584610	3157	Economy	10100.00
0005432858258	3157	Economy	10100.00
0005432858232	3157	Economy	10100.00
0005432584595	3157	Economy	10100.00
0005432584592	3157	Economy	10100.00
0005432584594	3157	Economy	10100.00
0005432584602	3157	Economy	10100.00
0005432584612	3157	Economy	10100.00
0005432584589	3157	Economy	10100.00
0005432858219	3157	Economy	10100.00
0005432584360	31480	Economy	11100.00
0005432584446	31480	Economy	11100.00
0005432858340	31480	Economy	11100.00
0005432584437	31480	Economy	10100.00
0005432858339	31480	Economy	10100.00
0005432858338	31480	Economy	10100.00
0005432584363	31480	Economy	10100.00
0005432584439	31480	Economy	10100.00
0005432858336	31480	Economy	10100.00
0005432584493	31480	Economy	10100.00
0005432858333	31480	Economy	10100.00
0005432584413	31480	Economy	10100.00
0005432584335	31480	Economy	10100.00
0005432584433	31480	Economy	10100.00
0005432584412	31480	Economy	10100.00
0005432584405	31480	Economy	10100.00
0005432584340	31480	Economy	10100.00
0005432584414	31480	Economy	10100.00
0005432584311	31480	Economy	10100.00
0005432584357	31480	Economy	10100.00
0005432858335	31480	Economy	10100.00
0005432584461	31480	Economy	10100.00
0005432584380	31480	Economy	10100.00
0005432584445	31480	Economy	10100.00
0005432584462	31480	Economy	10100.00
0005432584341	31480	Economy	10100.00
0005432858337	31480	Economy	10100.00
0005432858334	31480	Economy	10100.00
0005432584494	31480	Economy	10100.00
0005432584318	31480	Economy	10100.00
0005432584353	31480	Economy	10100.00
0005432858332	31480	Economy	10100.00
0005432584400	31480	Economy	10100.00
0005432584310	31480	Economy	10100.00
0005434943564	900	Economy	8300.00
0005433255183	900	Economy	8300.00
0005434943560	900	Economy	7500.00
0005434943562	900	Economy	7500.00
0005433255192	900	Economy	7500.00
0005433255199	900	Economy	7500.00
0005434943555	900	Economy	7500.00
0005434943558	900	Economy	7500.00
0005434943563	900	Economy	7500.00
0005434943557	900	Economy	7500.00
0005434943559	900	Economy	7500.00
0005433255182	900	Economy	7500.00
0005433255200	900	Economy	7500.00
0005434943556	900	Economy	7500.00
0005434943561	900	Economy	7500.00
0005433255241	16225	Economy	8300.00
0005434943498	16225	Economy	8300.00
0005433255240	16225	Economy	7500.00
0005434943506	16225	Economy	7500.00
0005433255242	16225	Economy	7500.00
0005434943497	16225	Economy	7500.00
0005434943525	16225	Economy	7500.00
0005434943459	16225	Economy	7500.00
0005434943488	16225	Economy	7500.00
0005433255244	16225	Economy	7500.00
0005433255243	16225	Economy	7500.00
0005434943479	16225	Economy	7500.00
0005434943482	16225	Economy	7500.00
0005434943507	16225	Economy	7500.00
0005433255239	16225	Economy	7500.00
0005434943486	16225	Economy	7500.00
0005434943485	16225	Economy	7500.00
0005435858624	4317	Business	90500.00
0005433654935	4317	Business	90500.00
0005435858621	4317	Business	90500.00
0005435858610	4317	Business	90500.00
0005433654941	4317	Business	90500.00
0005433654928	4317	Business	90500.00
0005433654922	4317	Business	90500.00
0005433654938	4317	Economy	30200.00
0005433654933	4317	Economy	30200.00
0005433654944	4317	Economy	30200.00
0005435858613	4317	Economy	30200.00
0005433654924	4317	Economy	30200.00
0005433654934	4317	Economy	30200.00
0005435858619	4317	Economy	30200.00
0005435858596	4317	Economy	30200.00
0005435858620	4317	Economy	30200.00
0005433654921	4317	Economy	30200.00
0005433654930	4317	Economy	30200.00
0005433654932	4317	Economy	30200.00
0005433654926	4317	Economy	30200.00
0005435858614	4317	Economy	30200.00
0005433654942	4317	Economy	30200.00
0005433654943	4317	Economy	30200.00
0005433654925	4317	Economy	30200.00
0005433654918	4317	Economy	30200.00
0005435858602	4317	Economy	30200.00
0005433654947	4317	Economy	30200.00
0005433654936	4317	Economy	30200.00
0005433654919	4317	Economy	30200.00
0005435858603	4317	Economy	30200.00
0005433654929	4317	Economy	30200.00
0005433654946	4317	Economy	30200.00
0005433654945	4317	Economy	30200.00
0005433654940	4317	Economy	30200.00
0005435858601	4317	Economy	30200.00
0005433654939	4317	Economy	30200.00
0005435858595	4317	Economy	30200.00
0005433654923	4317	Economy	30200.00
0005435858604	4317	Economy	30200.00
0005433654920	4317	Economy	30200.00
0005433654937	4317	Economy	30200.00
0005435858611	4317	Economy	30200.00
0005433654931	4317	Economy	30200.00
0005435858608	4317	Economy	30200.00
0005433654927	4317	Economy	30200.00
0005433811649	14403	Economy	4400.00
0005433927525	14403	Economy	4400.00
0005433811645	14403	Economy	4400.00
0005433927524	14403	Economy	4400.00
0005435654047	21780	Business	9800.00
0005435654022	21780	Business	9800.00
0005433368444	21780	Business	9800.00
0005433368123	21780	Business	9800.00
0005435654040	21780	Business	9800.00
0005435654016	21780	Business	9800.00
0005433368124	21780	Business	9800.00
0005433368405	21780	Business	9800.00
0005435654025	21780	Business	9800.00
0005433368419	21780	Business	9800.00
0005435654042	21780	Business	9800.00
0005433368309	21780	Economy	3300.00
0005435654038	21780	Economy	3300.00
0005435654045	21780	Economy	3300.00
0005435654013	21780	Economy	3300.00
0005435654019	21780	Economy	3300.00
0005433368299	21780	Economy	3300.00
0005435654014	21780	Economy	3600.00
0005433368391	21780	Economy	3600.00
0005435654033	21780	Economy	3600.00
0005435654012	21780	Economy	3300.00
0005433368325	21780	Economy	3300.00
0005435654027	21780	Economy	3300.00
0005435654034	21780	Economy	3300.00
0005435654021	21780	Economy	3300.00
0005435654044	21780	Economy	3300.00
0005433368284	21780	Economy	3300.00
0005435654039	21780	Economy	3300.00
0005433368288	21780	Economy	3300.00
0005433368338	21780	Economy	3300.00
0005433368185	21780	Economy	3300.00
0005435654023	21780	Economy	3300.00
0005433368516	21780	Economy	3300.00
0005433368392	21780	Economy	3300.00
0005433368210	21780	Economy	3300.00
0005435654009	21780	Economy	3300.00
0005433368368	21780	Economy	3300.00
0005433368343	21780	Economy	3300.00
0005433368430	21780	Economy	3300.00
0005433368348	21780	Economy	3300.00
0005433368369	21780	Economy	3300.00
0005433368344	21780	Economy	3300.00
0005435654020	21780	Economy	3300.00
0005435654018	21780	Economy	3300.00
0005433368349	21780	Economy	3300.00
0005435654031	21780	Economy	3300.00
0005433368256	21780	Economy	3300.00
0005435654011	21780	Economy	3300.00
0005435654037	21780	Economy	3300.00
0005433368377	21780	Economy	3300.00
0005433368406	21780	Economy	3300.00
0005435654028	21780	Economy	3300.00
0005433368183	21780	Economy	3300.00
0005433368279	21780	Economy	3300.00
0005435654015	21780	Economy	3300.00
0005433368209	21780	Economy	3300.00
0005433368403	21780	Economy	3300.00
0005435654046	21780	Economy	3300.00
0005433368376	21780	Economy	3300.00
0005435654030	21780	Economy	3300.00
0005433368326	21780	Economy	3300.00
0005435654043	21780	Economy	3300.00
0005435654024	21780	Economy	3300.00
0005435654026	21780	Economy	3300.00
0005433368255	21780	Economy	3300.00
0005435654035	21780	Economy	3300.00
0005433368320	21780	Economy	3300.00
0005435654032	21780	Economy	3300.00
0005435654008	21780	Economy	3300.00
0005433368122	21780	Economy	3300.00
0005435654029	21780	Economy	3300.00
0005435654017	21780	Economy	3300.00
0005433368428	21780	Economy	3300.00
0005435654010	21780	Economy	3300.00
0005435654036	21780	Economy	3300.00
0005435654041	21780	Economy	3300.00
0005433368278	21780	Economy	3300.00
0005435654048	21780	Economy	3300.00
0005435269837	9331	Business	186200.00
0005433806142	9331	Business	186200.00
0005434151744	9331	Business	186200.00
0005433763530	9331	Business	186200.00
0005433763529	9331	Business	186200.00
0005434171263	9331	Business	186200.00
0005433785762	9331	Business	186200.00
0005433806167	9331	Business	186200.00
0005434171269	9331	Business	186200.00
0005432667500	9331	Business	186200.00
0005432667501	9331	Business	186200.00
0005433785771	9331	Business	186200.00
0005432657518	9331	Business	186200.00
0005433785749	9331	Business	186200.00
0005433763537	9331	Business	186200.00
0005434151745	9331	Business	186200.00
0005433785755	9331	Business	186200.00
0005432657519	9331	Economy	68300.00
0005433763526	9331	Economy	68300.00
0005433806144	9331	Economy	62100.00
0005432665321	9331	Economy	62100.00
0005433785759	9331	Economy	62100.00
0005434171246	9331	Economy	62100.00
0005433763539	9331	Economy	62100.00
0005435269852	9331	Economy	62100.00
0005433806164	9331	Economy	62100.00
0005433806169	9331	Economy	62100.00
0005433806163	9331	Economy	62100.00
0005435269839	9331	Economy	62100.00
0005433785760	9331	Economy	62100.00
0005433785752	9331	Economy	62100.00
0005433806150	9331	Economy	62100.00
0005433785758	9331	Economy	62100.00
0005433785761	9331	Economy	62100.00
0005435269850	9331	Economy	62100.00
0005432665322	9331	Economy	62100.00
0005433785773	9331	Economy	62100.00
0005433785776	9331	Economy	62100.00
0005433806171	9331	Economy	62100.00
0005433806145	9331	Economy	62100.00
0005433763527	9331	Economy	62100.00
0005433806147	9331	Economy	62100.00
0005433785750	9331	Economy	62100.00
0005434171260	9331	Economy	62100.00
0005433785764	9331	Economy	62100.00
0005433806138	9331	Economy	62100.00
0005433806158	9331	Economy	62100.00
0005433785748	9331	Economy	62100.00
0005433785780	9331	Economy	62100.00
0005433785774	9331	Economy	62100.00
0005433785769	9331	Economy	62100.00
0005433806156	9331	Economy	62100.00
0005433785775	9331	Economy	62100.00
0005434270243	9331	Economy	62100.00
0005435269804	9331	Economy	62100.00
0005435269843	9331	Economy	62100.00
0005433806155	9331	Economy	62100.00
0005433806146	9331	Economy	62100.00
0005433806151	9331	Economy	62100.00
0005433806165	9331	Economy	62100.00
0005433806162	9331	Economy	62100.00
0005434151746	9331	Economy	62100.00
0005433763536	9331	Economy	62100.00
0005433785779	9331	Economy	62100.00
0005433763525	9331	Economy	62100.00
0005433806161	9331	Economy	62100.00
0005433785753	9331	Economy	62100.00
0005433785763	9331	Economy	62100.00
0005435269836	9331	Economy	62100.00
0005434273100	9331	Economy	62100.00
0005433806157	9331	Economy	62100.00
0005434273099	9331	Economy	62100.00
0005435269853	9331	Economy	62100.00
0005433763532	9331	Economy	62100.00
0005433806159	9331	Economy	62100.00
0005434151747	9331	Economy	62100.00
0005433785767	9331	Economy	62100.00
0005434171254	9331	Economy	62100.00
0005433806141	9331	Economy	62100.00
0005433785778	9331	Economy	62100.00
0005432657517	9331	Economy	62100.00
0005433785747	9331	Economy	62100.00
0005433785754	9331	Economy	62100.00
0005433806148	9331	Economy	62100.00
0005433785756	9331	Economy	68300.00
0005432667503	9331	Economy	62100.00
0005432665323	9331	Economy	68300.00
0005434151756	9331	Economy	62100.00
0005434171292	9331	Economy	62100.00
0005433806154	9331	Economy	62100.00
0005433806143	9331	Economy	62100.00
0005435269838	9331	Economy	62100.00
0005433785768	9331	Economy	62100.00
0005432666435	9331	Economy	62100.00
0005434171238	9331	Economy	62100.00
0005433806139	9331	Economy	62100.00
0005434171247	9331	Economy	62100.00
0005434270244	9331	Economy	62100.00
0005433763533	9331	Economy	62100.00
0005433785766	9331	Economy	62100.00
0005434171294	9331	Economy	62100.00
0005432667502	9331	Economy	62100.00
0005435269764	9331	Economy	62100.00
0005434171310	9331	Economy	62100.00
0005433806168	9331	Economy	62100.00
0005433763534	9331	Economy	62100.00
0005434171268	9331	Economy	62100.00
0005433806166	9331	Economy	62100.00
0005433806149	9331	Economy	62100.00
0005433785770	9331	Economy	62100.00
0005435269840	9331	Economy	62100.00
0005434171264	9331	Economy	62100.00
0005433806153	9331	Economy	62100.00
0005433785765	9331	Economy	62100.00
0005433785777	9331	Economy	62100.00
0005433806152	9331	Economy	62100.00
0005433763538	9331	Economy	62100.00
0005433785751	9331	Economy	62100.00
0005433806160	9331	Economy	62100.00
0005435269763	9331	Economy	62100.00
0005433785772	9331	Economy	62100.00
0005433763535	9331	Economy	62100.00
0005433806137	9331	Economy	62100.00
0005435269844	9331	Economy	62100.00
0005434171293	9331	Economy	62100.00
0005434151755	9331	Economy	62100.00
0005433806140	9331	Economy	62100.00
0005433785757	9331	Economy	62100.00
0005434171278	9331	Economy	62100.00
0005434171255	9331	Economy	62100.00
0005435269841	9331	Economy	62100.00
0005432665320	9331	Economy	62100.00
0005433806170	9331	Economy	62100.00
0005433763531	9331	Economy	62100.00
0005432666436	9331	Economy	62100.00
0005433763528	9331	Economy	62100.00
0005434171381	26237	Business	186200.00
0005433763433	26237	Business	186200.00
0005433785184	26237	Business	186200.00
0005433805874	26237	Business	186200.00
0005433805942	26237	Business	186200.00
0005433785539	26237	Business	186200.00
0005435269949	26237	Business	186200.00
0005433785482	26237	Business	186200.00
0005435269965	26237	Business	186200.00
0005433785355	26237	Business	186200.00
0005434269148	26237	Business	186200.00
0005432666396	26237	Business	186200.00
0005433785379	26237	Business	186200.00
0005433785464	26237	Business	186200.00
0005433785397	26237	Economy	68300.00
0005433763386	26237	Economy	68300.00
0005435269956	26237	Economy	62100.00
0005435269961	26237	Economy	62100.00
0005433805936	26237	Economy	62100.00
0005433763371	26237	Economy	62100.00
0005435269955	26237	Economy	62100.00
0005433805935	26237	Economy	62100.00
0005433785313	26237	Economy	62100.00
0005433785540	26237	Economy	62100.00
0005433805781	26237	Economy	62100.00
0005433785554	26237	Economy	62100.00
0005435269963	26237	Economy	62100.00
0005435269959	26237	Economy	62100.00
0005435269947	26237	Economy	62100.00
0005433763412	26237	Economy	62100.00
0005434171380	26237	Economy	62100.00
0005433805807	26237	Economy	62100.00
0005434171378	26237	Economy	62100.00
0005433805924	26237	Economy	62100.00
0005433785501	26237	Economy	62100.00
0005433785364	26237	Economy	62100.00
0005433805749	26237	Economy	62100.00
0005433763422	26237	Economy	62100.00
0005435269967	26237	Economy	62100.00
0005434171383	26237	Economy	62100.00
0005433763417	26237	Economy	62100.00
0005435269971	26237	Economy	62100.00
0005434171371	26237	Economy	62100.00
0005433763392	26237	Economy	62100.00
0005433763425	26237	Economy	62100.00
0005435269954	26237	Economy	62100.00
0005434171377	26237	Economy	62100.00
0005435269962	26237	Economy	62100.00
0005433763372	26237	Economy	62100.00
0005432666421	26237	Economy	62100.00
0005433805873	26237	Economy	62100.00
0005434171374	26237	Economy	62100.00
0005433785392	26237	Economy	62100.00
0005433763394	26237	Economy	62100.00
0005433785490	26237	Economy	62100.00
0005432657490	26237	Economy	62100.00
0005433805916	26237	Economy	62100.00
0005433763424	26237	Economy	62100.00
0005434171373	26237	Economy	62100.00
0005433805998	26237	Economy	62100.00
0005433805989	26237	Economy	62100.00
0005435269970	26237	Economy	62100.00
0005434171372	26237	Economy	62100.00
0005433763454	26237	Economy	62100.00
0005433785628	26237	Economy	62100.00
0005435269972	26237	Economy	62100.00
0005433763457	26237	Economy	62100.00
0005434270252	26237	Economy	62100.00
0005433805857	26237	Economy	62100.00
0005433785321	26237	Economy	62100.00
0005433805867	26237	Economy	62100.00
0005433805835	26237	Economy	62100.00
0005435269969	26237	Economy	62100.00
0005434270251	26237	Economy	62100.00
0005432666420	26237	Economy	62100.00
0005435269957	26237	Economy	62100.00
0005433785356	26237	Economy	62100.00
0005433805834	26237	Economy	62100.00
0005433785185	26237	Economy	62100.00
0005434151769	26237	Economy	62100.00
0005435269953	26237	Economy	62100.00
0005433785530	26237	Economy	62100.00
0005433785456	26237	Economy	62100.00
0005433763383	26237	Economy	62100.00
0005434151768	26237	Economy	62100.00
0005432657501	26237	Economy	62100.00
0005433805858	26237	Economy	62100.00
0005433785513	26237	Economy	62100.00
0005433785352	26237	Economy	68300.00
0005433763423	26237	Economy	68300.00
0005433763385	26237	Economy	62100.00
0005433763456	26237	Economy	62100.00
0005434171370	26237	Economy	68300.00
0005434151770	26237	Economy	62100.00
0005433785461	26237	Economy	62100.00
0005433785455	26237	Economy	62100.00
0005432657492	26237	Economy	62100.00
0005433805822	26237	Economy	62100.00
0005433763393	26237	Economy	62100.00
0005433785375	26237	Economy	62100.00
0005433785498	26237	Economy	62100.00
0005435269948	26237	Economy	62100.00
0005435269960	26237	Economy	62100.00
0005434270253	26237	Economy	62100.00
0005432666415	26237	Economy	62100.00
0005435269958	26237	Economy	62100.00
0005433805929	26237	Economy	62100.00
0005433785328	26237	Economy	62100.00
0005433785440	26237	Economy	62100.00
0005433785459	26237	Economy	62100.00
0005434171376	26237	Economy	62100.00
0005433763431	26237	Economy	62100.00
0005435269968	26237	Economy	62100.00
0005433805934	26237	Economy	62100.00
0005433785481	26237	Economy	62100.00
0005433785427	26237	Economy	62100.00
0005435269964	26237	Economy	62100.00
0005434171382	26237	Economy	62100.00
0005433805937	26237	Economy	62100.00
0005433785365	26237	Economy	62100.00
0005434271357	26237	Economy	62100.00
0005432657477	26237	Economy	62100.00
0005435269951	26237	Economy	62100.00
0005433785433	26237	Economy	62100.00
0005434171379	26237	Economy	62100.00
0005433763453	26237	Economy	62100.00
0005433805760	26237	Economy	62100.00
0005432657493	26237	Economy	62100.00
0005435269966	26237	Economy	62100.00
0005435269952	26237	Economy	62100.00
0005432663064	26237	Economy	62100.00
0005433805909	26237	Economy	62100.00
0005433785378	26237	Economy	62100.00
0005435269950	26237	Economy	62100.00
0005434171375	26237	Economy	62100.00
0005433763485	26237	Economy	62100.00
0005432666413	26237	Economy	62100.00
0005433763434	26237	Economy	62100.00
0005435929668	4907	Economy	5900.00
0005435929682	4907	Economy	5900.00
0005435135784	4907	Economy	5300.00
0005435135782	4907	Economy	5300.00
0005435929676	4907	Economy	5300.00
0005435929669	4907	Economy	5300.00
0005435929677	4907	Economy	5300.00
0005435135781	4907	Economy	5300.00
0005435135780	4907	Economy	5300.00
0005435929681	4907	Economy	5300.00
0005435135783	4907	Economy	5300.00
0005435929704	33058	Economy	5900.00
0005435929703	33058	Economy	5300.00
0005435135732	33058	Economy	5300.00
0005435929705	33058	Economy	5300.00
0005435929706	33058	Economy	5300.00
0005435135749	33058	Economy	5300.00
0005435135748	33058	Economy	5300.00
0005434983406	9481	Economy	19700.00
0005434983403	9481	Economy	17900.00
0005434983404	9481	Economy	17900.00
0005434983405	9481	Economy	17900.00
0005434983356	27394	Economy	17900.00
0005434983369	27394	Economy	17900.00
0005434218061	27394	Economy	17900.00
0005434218059	27394	Economy	17900.00
0005434983385	27394	Economy	17900.00
0005434218062	27394	Economy	17900.00
0005434983357	27394	Economy	17900.00
0005434218060	27394	Economy	17900.00
0005434218058	27394	Economy	17900.00
0005433986345	24239	Business	36400.00
0005433986444	24239	Business	36400.00
0005433986634	24239	Business	36400.00
0005433961387	24239	Business	36400.00
0005433986551	24239	Business	36400.00
0005433986616	24239	Business	36400.00
0005433986581	24239	Business	36400.00
0005433961561	24239	Business	36400.00
0005433961502	24239	Business	36400.00
0005433961575	24239	Business	36400.00
0005433986565	24239	Business	36400.00
0005433961491	24239	Business	36400.00
0005433986532	24239	Business	36400.00
0005433986359	24239	Economy	13400.00
0005433961360	24239	Economy	13400.00
0005433961585	24239	Economy	13400.00
0005433961536	24239	Economy	12100.00
0005433986464	24239	Economy	12100.00
0005433961543	24239	Economy	12100.00
0005433986580	24239	Economy	12100.00
0005433986541	24239	Economy	12100.00
0005433961539	24239	Economy	12100.00
0005433986423	24239	Economy	12100.00
0005433961416	24239	Economy	12100.00
0005433986495	24239	Economy	12100.00
0005433961361	24239	Economy	12100.00
0005433986443	24239	Economy	12100.00
0005433961596	24239	Economy	12100.00
0005433986543	24239	Economy	12100.00
0005433986564	24239	Economy	12100.00
0005433961542	24239	Economy	12100.00
0005433961607	24239	Economy	12100.00
0005433961566	24239	Economy	12100.00
0005433961501	24239	Economy	12100.00
0005433986462	24239	Economy	12100.00
0005433986622	24239	Economy	12100.00
0005433961456	24239	Economy	12100.00
0005433961513	24239	Economy	12100.00
0005433961553	24239	Economy	12100.00
0005433986357	24239	Economy	12100.00
0005433961571	24239	Economy	12100.00
0005433961493	24239	Economy	12100.00
0005433961515	24239	Economy	12100.00
0005433961567	24239	Economy	12100.00
0005433961558	24239	Economy	12100.00
0005433961454	24239	Economy	12100.00
0005433986579	24239	Economy	12100.00
0005433961586	24239	Economy	12100.00
0005433986496	24239	Economy	12100.00
0005433986466	24239	Economy	12100.00
0005433986508	24239	Economy	12100.00
0005433986479	24239	Economy	12100.00
0005433961595	24239	Economy	12100.00
0005433961537	24239	Economy	12100.00
0005433986563	24239	Economy	12100.00
0005433961625	24239	Economy	12100.00
0005433986546	24239	Economy	12100.00
0005433961550	24239	Economy	12100.00
0005433986498	24239	Economy	12100.00
0005433961494	24239	Economy	12100.00
0005433961445	24239	Economy	12100.00
0005433986619	24239	Economy	13400.00
0005433986539	24239	Economy	12100.00
0005433961338	24239	Economy	13400.00
0005433961544	24239	Economy	12100.00
0005433986615	24239	Economy	13400.00
0005433986426	24239	Economy	13400.00
0005433961517	24239	Economy	12100.00
0005433961214	24239	Economy	12100.00
0005433961597	24239	Economy	12100.00
0005433986591	24239	Economy	12100.00
0005433986607	24239	Economy	12100.00
0005433961545	24239	Economy	12100.00
0005433961480	24239	Economy	12100.00
0005433986428	24239	Economy	12100.00
0005433986384	24239	Economy	12100.00
0005433986585	24239	Economy	12100.00
0005433986540	24239	Economy	12100.00
0005433961627	24239	Economy	12100.00
0005433961455	24239	Economy	12100.00
0005433986547	24239	Economy	12100.00
0005433986424	24239	Economy	12100.00
0005433961362	24239	Economy	12100.00
0005433961331	24239	Economy	12100.00
0005433961529	24239	Economy	12100.00
0005433961560	24239	Economy	12100.00
0005433961562	24239	Economy	12100.00
0005433961584	24239	Economy	12100.00
0005433961608	24239	Economy	12100.00
0005433961507	24239	Economy	12100.00
0005433961606	24239	Economy	12100.00
0005433986465	24239	Economy	12100.00
0005433961551	24239	Economy	12100.00
0005433961552	24239	Economy	12100.00
0005433986584	24239	Economy	12100.00
0005433986632	24239	Economy	12100.00
0005433986463	24239	Economy	12100.00
0005433961495	24239	Economy	12100.00
0005433961559	24239	Economy	12100.00
0005433986497	24239	Economy	12100.00
0005433961626	24239	Economy	12100.00
0005433986505	24239	Economy	12100.00
0005433961503	24239	Economy	12100.00
0005433986525	24239	Economy	12100.00
0005433986504	24239	Economy	12100.00
0005433962120	25905	Business	36400.00
0005433986958	25905	Business	36400.00
0005433962145	25905	Business	36400.00
0005433962114	25905	Business	36400.00
0005433962116	25905	Business	36400.00
0005433962111	25905	Business	36400.00
0005433986954	25905	Business	36400.00
0005433986925	25905	Business	36400.00
0005433986941	25905	Business	36400.00
0005433986959	25905	Business	36400.00
0005433962146	25905	Business	36400.00
0005433962118	25905	Business	36400.00
0005433962107	25905	Business	36400.00
0005433962134	25905	Economy	13400.00
0005433962130	25905	Economy	12100.00
0005433986967	25905	Economy	12100.00
0005433986944	25905	Economy	12100.00
0005433962115	25905	Economy	12100.00
0005433986932	25905	Economy	12100.00
0005433962125	25905	Economy	12100.00
0005433962104	25905	Economy	12100.00
0005433962113	25905	Economy	12100.00
0005433986965	25905	Economy	12100.00
0005433962136	25905	Economy	12100.00
0005433986929	25905	Economy	12100.00
0005433962127	25905	Economy	12100.00
0005433986937	25905	Economy	12100.00
0005433986956	25905	Economy	12100.00
0005433986934	25905	Economy	12100.00
0005433986970	25905	Economy	12100.00
0005433986955	25905	Economy	12100.00
0005433986940	25905	Economy	12100.00
0005433986957	25905	Economy	12100.00
0005433986969	25905	Economy	12100.00
0005433962102	25905	Economy	12100.00
0005433986950	25905	Economy	12100.00
0005433986928	25905	Economy	12100.00
0005433962101	25905	Economy	12100.00
0005433962138	25905	Economy	12100.00
0005433986948	25905	Economy	12100.00
0005433986927	25905	Economy	12100.00
0005433962135	25905	Economy	12100.00
0005433986960	25905	Economy	12100.00
0005433986935	25905	Economy	12100.00
0005433986933	25905	Economy	12100.00
0005433986938	25905	Economy	12100.00
0005433962117	25905	Economy	12100.00
0005433962128	25905	Economy	12100.00
0005433962132	25905	Economy	12100.00
0005433986951	25905	Economy	12100.00
0005433962139	25905	Economy	12100.00
0005433962124	25905	Economy	12100.00
0005433986936	25905	Economy	12100.00
0005433986942	25905	Economy	12100.00
0005433962126	25905	Economy	12100.00
0005433962144	25905	Economy	12100.00
0005433986952	25905	Economy	12100.00
0005433986962	25905	Economy	12100.00
0005433962109	25905	Economy	12100.00
0005433962108	25905	Economy	12100.00
0005433986930	25905	Economy	12100.00
0005433962119	25905	Economy	12100.00
0005433962143	25905	Economy	12100.00
0005433986963	25905	Economy	12100.00
0005433962105	25905	Economy	12100.00
0005433986953	25905	Economy	12100.00
0005433986939	25905	Economy	12100.00
0005433962103	25905	Economy	12100.00
0005433986945	25905	Economy	12100.00
0005433986926	25905	Economy	12100.00
0005433986946	25905	Economy	12100.00
0005433986964	25905	Economy	12100.00
0005433962137	25905	Economy	12100.00
0005433962110	25905	Economy	12100.00
0005433986966	25905	Economy	12100.00
0005433962133	25905	Economy	12100.00
0005433986943	25905	Economy	12100.00
0005433986973	25905	Economy	12100.00
0005433986961	25905	Economy	12100.00
0005433986968	25905	Economy	12100.00
0005433962142	25905	Economy	12100.00
0005433986972	25905	Economy	12100.00
0005433962141	25905	Economy	12100.00
0005433986971	25905	Economy	12100.00
0005433962100	25905	Economy	12100.00
0005433986974	25905	Economy	12100.00
0005433962112	25905	Economy	12100.00
0005433962123	25905	Economy	12100.00
0005433986949	25905	Economy	12100.00
0005433986931	25905	Economy	12100.00
0005433962106	25905	Economy	12100.00
0005433962121	25905	Economy	12100.00
0005433962129	25905	Economy	12100.00
0005433986947	25905	Economy	12100.00
0005433962140	25905	Economy	12100.00
0005433962131	25905	Economy	12100.00
0005433962122	25905	Economy	12100.00
0005434480875	926	Economy	25400.00
0005433166150	926	Economy	25400.00
0005434480892	926	Economy	25400.00
0005434480885	926	Economy	25400.00
0005433166101	926	Economy	23100.00
0005434480893	926	Economy	23100.00
0005434480889	926	Economy	23100.00
0005433166117	926	Economy	23100.00
0005432269559	926	Economy	23100.00
0005434480883	926	Economy	23100.00
0005434480896	926	Economy	23100.00
0005434480882	926	Economy	23100.00
0005434480884	926	Economy	23100.00
0005433166090	926	Economy	23100.00
0005433166099	926	Economy	23100.00
0005433166054	926	Economy	23100.00
0005433166146	926	Economy	23100.00
0005433166118	926	Economy	23100.00
0005434480874	926	Economy	23100.00
0005432269557	926	Economy	23100.00
0005434480894	926	Economy	23100.00
0005434480886	926	Economy	23100.00
0005434480881	926	Economy	23100.00
0005434480879	926	Economy	23100.00
0005434480880	926	Economy	23100.00
0005433166115	926	Economy	23100.00
0005433166048	926	Economy	23100.00
0005433166086	926	Economy	23100.00
0005434480898	926	Economy	23100.00
0005434480877	926	Economy	23100.00
0005433166125	926	Economy	23100.00
0005434480891	926	Economy	23100.00
0005434480890	926	Economy	23100.00
0005433166085	926	Economy	23100.00
0005434480899	926	Economy	23100.00
0005434480897	926	Economy	23100.00
0005433166151	926	Economy	23100.00
0005434480887	926	Economy	23100.00
0005434480895	926	Economy	23100.00
0005432269558	926	Economy	23100.00
0005433166089	926	Economy	23100.00
0005434480876	926	Economy	23100.00
0005433166120	926	Economy	23100.00
0005434480888	926	Economy	23100.00
0005433166175	926	Economy	23100.00
0005433166160	926	Economy	23100.00
0005434480878	926	Economy	23100.00
0005434480689	16562	Economy	25400.00
0005434480711	16562	Economy	25400.00
0005434480719	16562	Economy	25400.00
0005434480684	16562	Economy	25400.00
0005434480670	16562	Economy	23100.00
0005434480687	16562	Economy	23100.00
0005434480529	16562	Economy	23100.00
0005434480718	16562	Economy	23100.00
0005434480653	16562	Economy	23100.00
0005434480578	16562	Economy	23100.00
0005434480626	16562	Economy	23100.00
0005433166195	16562	Economy	23100.00
0005433166199	16562	Economy	23100.00
0005434480714	16562	Economy	23100.00
0005433166202	16562	Economy	23100.00
0005433166193	16562	Economy	23100.00
0005434480664	16562	Economy	23100.00
0005434480541	16562	Economy	23100.00
0005434480631	16562	Economy	23100.00
0005434480579	16562	Economy	23100.00
0005434480531	16562	Economy	23100.00
0005433166203	16562	Economy	23100.00
0005433166200	16562	Economy	23100.00
0005434480652	16562	Economy	23100.00
0005434480666	16562	Economy	23100.00
0005434480591	16562	Economy	23100.00
0005434480715	16562	Economy	23100.00
0005434480693	16562	Economy	23100.00
0005434480592	16562	Economy	23100.00
0005433166197	16562	Economy	23100.00
0005434480694	16562	Economy	23100.00
0005433166192	16562	Economy	23100.00
0005434480645	16562	Economy	23100.00
0005434480646	16562	Economy	23100.00
0005433166196	16562	Economy	23100.00
0005434480688	16562	Economy	23100.00
0005434480720	16562	Economy	23100.00
0005434480695	16562	Economy	23100.00
0005434480530	16562	Economy	23100.00
0005434480625	16562	Economy	23100.00
0005433166191	16562	Economy	23100.00
0005434480623	16562	Economy	23100.00
0005433166198	16562	Economy	23100.00
0005434480600	16562	Economy	23100.00
0005434480665	16562	Economy	23100.00
0005434480651	16562	Economy	23100.00
0005433166194	16562	Economy	23100.00
0005434480542	16562	Economy	23100.00
0005434480632	16562	Economy	23100.00
0005433166201	16562	Economy	23100.00
0005433872562	3203	Economy	19000.00
0005433872561	3203	Economy	17200.00
0005433872563	3203	Economy	17200.00
0005433872559	3203	Economy	17200.00
0005433872560	3203	Economy	17200.00
0005433872558	3203	Economy	17200.00
0005433872522	32561	Economy	19000.00
0005433872534	32561	Economy	17200.00
0005433872525	32561	Economy	17200.00
0005433872526	32561	Economy	17200.00
0005435142868	10365	Economy	17000.00
0005433289932	10365	Economy	17000.00
0005435142862	10365	Economy	17000.00
0005433289950	10365	Economy	15400.00
0005435386632	10365	Economy	15400.00
0005435150335	10365	Economy	15400.00
0005435150328	10365	Economy	15400.00
0005435386623	10365	Economy	15400.00
0005433289902	10365	Economy	15400.00
0005435150334	10365	Economy	15400.00
0005435150336	10365	Economy	15400.00
0005433289903	10365	Economy	15400.00
0005435142871	10365	Economy	15400.00
0005435142867	10365	Economy	15400.00
0005435150332	10365	Economy	15400.00
0005435150325	10365	Economy	15400.00
0005433289949	10365	Economy	15400.00
0005435150331	10365	Economy	15400.00
0005435142864	10365	Economy	15400.00
0005435142863	10365	Economy	15400.00
0005435142870	10365	Economy	15400.00
0005435150333	10365	Economy	15400.00
0005435150327	10365	Economy	15400.00
0005435150326	10365	Economy	15400.00
0005435142873	10365	Economy	15400.00
0005435150329	10365	Economy	15400.00
0005435142865	10365	Economy	15400.00
0005435386650	10365	Economy	15400.00
0005435142866	10365	Economy	15400.00
0005435150324	10365	Economy	15400.00
0005433289927	10365	Economy	15400.00
0005435142869	10365	Economy	15400.00
0005435386631	10365	Economy	15400.00
0005435142872	10365	Economy	15400.00
0005435150337	10365	Economy	15400.00
0005435142874	10365	Economy	15400.00
0005435142875	10365	Economy	15400.00
0005435150330	10365	Economy	15400.00
0005433289926	10365	Economy	15400.00
0005433290020	21958	Economy	17000.00
0005435386721	21958	Economy	17000.00
0005433290017	21958	Economy	17000.00
0005433290014	21958	Economy	15400.00
0005435142703	21958	Economy	15400.00
0005435142684	21958	Economy	15400.00
0005435150258	21958	Economy	15400.00
0005435142777	21958	Economy	15400.00
0005435142793	21958	Economy	15400.00
0005435386723	21958	Economy	15400.00
0005435386722	21958	Economy	15400.00
0005435150151	21958	Economy	15400.00
0005435386719	21958	Economy	15400.00
0005435386724	21958	Economy	15400.00
0005435142743	21958	Economy	15400.00
0005435150220	21958	Economy	15400.00
0005433290019	21958	Economy	15400.00
0005435150221	21958	Economy	15400.00
0005435142711	21958	Economy	15400.00
0005433290016	21958	Economy	15400.00
0005435150197	21958	Economy	15400.00
0005435150205	21958	Economy	15400.00
0005433290018	21958	Economy	15400.00
0005435150159	21958	Economy	15400.00
0005435150211	21958	Economy	15400.00
0005435386720	21958	Economy	15400.00
0005433290015	21958	Economy	15400.00
0005435150203	21958	Economy	15400.00
0005435142744	21958	Economy	15400.00
0005435142710	21958	Economy	15400.00
0005434573658	11231	Business	57200.00
0005435529553	11231	Business	57200.00
0005435529557	11231	Business	57200.00
0005435529552	11231	Business	57200.00
0005435502639	11231	Business	57200.00
0005435529571	11231	Business	57200.00
0005435529524	11231	Business	57200.00
0005435502637	11231	Economy	19100.00
0005435502644	11231	Economy	19100.00
0005435529534	11231	Economy	19100.00
0005435529517	11231	Economy	19100.00
0005435319698	11231	Economy	19100.00
0005435502651	11231	Economy	19100.00
0005435502566	11231	Economy	19100.00
0005435502643	11231	Economy	21000.00
0005435529438	11231	Economy	21000.00
0005435502590	11231	Economy	21000.00
0005435529535	11231	Economy	19100.00
0005435529518	11231	Economy	19100.00
0005434573654	11231	Economy	19100.00
0005435502703	11231	Economy	19100.00
0005435545846	11231	Economy	19100.00
0005434573657	11231	Economy	19100.00
0005435502533	11231	Economy	19100.00
0005435502578	11231	Economy	19100.00
0005435529523	11231	Economy	19100.00
0005435502680	11231	Economy	19100.00
0005434573653	11231	Economy	19100.00
0005435502544	11231	Economy	19100.00
0005435502748	11231	Economy	19100.00
0005435319707	11231	Economy	19100.00
0005434573661	11231	Economy	19100.00
0005435529439	11231	Economy	19100.00
0005434573660	11231	Economy	19100.00
0005435529441	11231	Economy	19100.00
0005435502573	11231	Economy	19100.00
0005434573651	11231	Economy	19100.00
0005434573659	11231	Economy	19100.00
0005434573663	11231	Economy	19100.00
0005435502591	11231	Economy	19100.00
0005435545802	11231	Economy	19100.00
0005434573662	11231	Economy	19100.00
0005435502631	11231	Economy	19100.00
0005435529570	11231	Economy	19100.00
0005435529595	11231	Economy	19100.00
0005435529652	11231	Economy	19100.00
0005435502577	11231	Economy	19100.00
0005435529594	11231	Economy	19100.00
0005435319728	11231	Economy	19100.00
0005435529483	11231	Economy	19100.00
0005435529569	11231	Economy	19100.00
0005435502627	11231	Economy	19100.00
0005434573655	11231	Economy	19100.00
0005435529514	11231	Economy	19100.00
0005435502646	11231	Economy	19100.00
0005434573656	11231	Economy	19100.00
0005434573650	11231	Economy	19100.00
0005435529440	11231	Economy	19100.00
0005435502595	11231	Economy	19100.00
0005435502702	11231	Economy	19100.00
0005435529502	11231	Economy	19100.00
0005435545847	11231	Economy	19100.00
0005435319727	11231	Economy	19100.00
0005434573652	11231	Economy	19100.00
0005435529558	11231	Economy	19100.00
0005435529581	11231	Economy	19100.00
0005435502579	11231	Economy	19100.00
0005435529546	11231	Economy	19100.00
0005435529573	11231	Economy	19100.00
0005435545848	11231	Economy	19100.00
0005435508657	20963	Business	57200.00
0005434573481	20963	Business	57200.00
0005435508653	20963	Business	57200.00
0005435502782	20963	Business	57200.00
0005435518294	20963	Business	57200.00
0005435518307	20963	Business	57200.00
0005435518300	20963	Business	57200.00
0005435319781	20963	Business	57200.00
0005435508656	20963	Business	57200.00
0005434573544	20963	Business	57200.00
0005435518298	20963	Business	57200.00
0005435502775	20963	Business	57200.00
0005434573546	20963	Economy	19100.00
0005435518313	20963	Economy	19100.00
0005435508655	20963	Economy	19100.00
0005435508649	20963	Economy	19100.00
0005435319778	20963	Economy	19100.00
0005435502786	20963	Economy	19100.00
0005432291984	20963	Economy	19100.00
0005435518297	20963	Economy	19100.00
0005435518315	20963	Economy	19100.00
0005435518295	20963	Economy	19100.00
0005434573562	20963	Economy	21000.00
0005434573475	20963	Economy	21000.00
0005435502787	20963	Economy	21000.00
0005434573547	20963	Economy	21000.00
0005434573563	20963	Economy	21000.00
0005435508660	20963	Economy	19100.00
0005435502789	20963	Economy	19100.00
0005435502776	20963	Economy	19100.00
0005435502781	20963	Economy	19100.00
0005435508643	20963	Economy	19100.00
0005435502784	20963	Economy	19100.00
0005435502795	20963	Economy	19100.00
0005435508658	20963	Economy	19100.00
0005434573600	20963	Economy	19100.00
0005435319779	20963	Economy	19100.00
0005432291983	20963	Economy	19100.00
0005434573574	20963	Economy	19100.00
0005435502793	20963	Economy	19100.00
0005435502780	20963	Economy	19100.00
0005435518301	20963	Economy	19100.00
0005435319783	20963	Economy	19100.00
0005434573474	20963	Economy	19100.00
0005435508645	20963	Economy	19100.00
0005435502777	20963	Economy	19100.00
0005435508650	20963	Economy	19100.00
0005435508641	20963	Economy	19100.00
0005435518305	20963	Economy	19100.00
0005435319785	20963	Economy	19100.00
0005435518314	20963	Economy	19100.00
0005435518312	20963	Economy	19100.00
0005434573476	20963	Economy	19100.00
0005434573482	20963	Economy	19100.00
0005435319780	20963	Economy	19100.00
0005435502791	20963	Economy	19100.00
0005435502774	20963	Economy	19100.00
0005435508651	20963	Economy	19100.00
0005434573450	20963	Economy	19100.00
0005435508647	20963	Economy	19100.00
0005434573561	20963	Economy	19100.00
0005435502778	20963	Economy	19100.00
0005435518296	20963	Economy	19100.00
0005434573473	20963	Economy	19100.00
0005435518306	20963	Economy	19100.00
0005435319777	20963	Economy	19100.00
0005435319782	20963	Economy	19100.00
0005435508642	20963	Economy	19100.00
0005435502779	20963	Economy	19100.00
0005435502783	20963	Economy	19100.00
0005434573480	20963	Economy	19100.00
0005434573529	20963	Economy	19100.00
0005435518299	20963	Economy	19100.00
0005435502794	20963	Economy	19100.00
0005435508654	20963	Economy	19100.00
0005435518311	20963	Economy	19100.00
0005434573584	20963	Economy	19100.00
0005435518308	20963	Economy	19100.00
0005435518309	20963	Economy	19100.00
0005435319786	20963	Economy	19100.00
0005435508659	20963	Economy	19100.00
0005435502785	20963	Economy	19100.00
0005434573531	20963	Economy	19100.00
0005435508648	20963	Economy	19100.00
0005435518303	20963	Economy	19100.00
0005435518302	20963	Economy	19100.00
0005435502792	20963	Economy	19100.00
0005435319784	20963	Economy	19100.00
0005435518310	20963	Economy	19100.00
0005435508646	20963	Economy	19100.00
0005435508652	20963	Economy	19100.00
0005435502790	20963	Economy	19100.00
0005434573530	20963	Economy	19100.00
0005435502788	20963	Economy	19100.00
0005435518304	20963	Economy	19100.00
0005435508644	20963	Economy	19100.00
0005432693549	2916	Business	10300.00
0005432693428	2916	Business	10300.00
0005432693536	2916	Business	10300.00
0005432693450	2916	Economy	3400.00
0005432693501	2916	Economy	3400.00
0005432693309	2916	Economy	3400.00
0005432693392	2916	Economy	3400.00
0005432693550	2916	Economy	3400.00
0005432693476	2916	Economy	3400.00
0005432693395	2916	Economy	3400.00
0005432693452	2916	Economy	3400.00
0005432693537	2916	Economy	3400.00
0005432693375	2916	Economy	3400.00
0005432693386	2916	Economy	3400.00
0005432693372	2916	Economy	3400.00
0005432693317	2916	Economy	3400.00
0005432693502	2916	Economy	3400.00
0005432693424	2916	Economy	3400.00
0005432693318	2916	Economy	3400.00
0005432693479	2916	Economy	3400.00
0005432693503	2916	Economy	3400.00
0005432693496	2916	Economy	3400.00
0005432693453	2916	Economy	3400.00
0005432693387	2916	Economy	3400.00
0005432693480	2916	Economy	3400.00
0005432880961	2915	Business	10300.00
0005432707353	2915	Business	10300.00
0005432707349	2915	Business	10300.00
0005432707335	2915	Business	10300.00
0005432707354	2915	Business	10300.00
0005432707350	2915	Business	10300.00
0005432707333	2915	Economy	3400.00
0005432707355	2915	Economy	3400.00
0005432707344	2915	Economy	3400.00
0005432707345	2915	Economy	3400.00
0005432217840	2915	Economy	3400.00
0005433124189	2915	Economy	3400.00
0005432707340	2915	Economy	3400.00
0005433124257	2915	Economy	3400.00
0005432707351	2915	Economy	3400.00
0005433194879	2915	Economy	3800.00
0005432881006	2915	Economy	3800.00
0005433124135	2915	Economy	3800.00
0005432707338	2915	Economy	3400.00
0005432707341	2915	Economy	3400.00
0005433124167	2915	Economy	3400.00
0005433124197	2915	Economy	3400.00
0005433124186	2915	Economy	3400.00
0005432881014	2915	Economy	3400.00
0005433124176	2915	Economy	3400.00
0005432707334	2915	Economy	3400.00
0005432707337	2915	Economy	3400.00
0005433194880	2915	Economy	3400.00
0005432881004	2915	Economy	3400.00
0005433124219	2915	Economy	3400.00
0005432707347	2915	Economy	3400.00
0005432881064	2915	Economy	3400.00
0005432707342	2915	Economy	3400.00
0005432881063	2915	Economy	3400.00
0005433124165	2915	Economy	3400.00
0005432881007	2915	Economy	3400.00
0005432707346	2915	Economy	3400.00
0005433124158	2915	Economy	3400.00
0005432707348	2915	Economy	3400.00
0005433124229	2915	Economy	3400.00
0005432707343	2915	Economy	3400.00
0005432707339	2915	Economy	3400.00
0005433124185	2915	Economy	3400.00
0005433124276	2915	Economy	3400.00
0005432881008	2915	Economy	3400.00
0005432881013	2915	Economy	3400.00
0005433124277	2915	Economy	3400.00
0005432880962	2915	Economy	3400.00
0005432217838	2915	Economy	3400.00
0005433124256	2915	Economy	3400.00
0005433124099	2915	Economy	3400.00
0005432881009	2915	Economy	3400.00
0005432880997	2915	Economy	3400.00
0005432707331	2915	Economy	3400.00
0005432707336	2915	Economy	3400.00
0005432881015	2915	Economy	3400.00
0005432707332	2915	Economy	3400.00
0005432880994	2915	Economy	3400.00
0005433124100	2915	Economy	3400.00
0005433194894	2915	Economy	3400.00
0005432707352	2915	Economy	3400.00
0005432707330	2915	Economy	3400.00
0005433124198	2915	Economy	3400.00
0005432880998	2915	Economy	3400.00
0005433124209	2915	Economy	3400.00
0005433124101	2915	Economy	3400.00
0005432217839	2915	Economy	3400.00
0005432693786	29966	Business	10300.00
0005433194918	29966	Business	10300.00
0005432693763	29966	Business	10300.00
0005432881144	29966	Business	10300.00
0005432693761	29966	Business	10300.00
0005432707122	29966	Business	10300.00
0005432881137	29966	Business	10300.00
0005432707137	29966	Business	10300.00
0005432693780	29966	Business	10300.00
0005432693772	29966	Business	10300.00
0005432693759	29966	Business	10300.00
0005432707197	29966	Business	10300.00
0005432707198	29966	Economy	3400.00
0005433124379	29966	Economy	3400.00
0005433124383	29966	Economy	3400.00
0005432707199	29966	Economy	3400.00
0005432693775	29966	Economy	3400.00
0005432693765	29966	Economy	3400.00
0005433124366	29966	Economy	3400.00
0005432693771	29966	Economy	3400.00
0005433124386	29966	Economy	3400.00
0005433124365	29966	Economy	3400.00
0005433194916	29966	Economy	3800.00
0005432693768	29966	Economy	3800.00
0005432693774	29966	Economy	3800.00
0005433124371	29966	Economy	3800.00
0005432881147	29966	Economy	3800.00
0005432707113	29966	Economy	3400.00
0005433124375	29966	Economy	3400.00
0005433194915	29966	Economy	3400.00
0005432693762	29966	Economy	3400.00
0005433124367	29966	Economy	3400.00
0005432707196	29966	Economy	3400.00
0005432693783	29966	Economy	3400.00
0005433124388	29966	Economy	3400.00
0005433124377	29966	Economy	3400.00
0005432707096	29966	Economy	3400.00
0005432693776	29966	Economy	3400.00
0005432881141	29966	Economy	3400.00
0005433124376	29966	Economy	3400.00
0005433194917	29966	Economy	3400.00
0005432693758	29966	Economy	3400.00
0005432693773	29966	Economy	3400.00
0005432707160	29966	Economy	3400.00
0005432693781	29966	Economy	3400.00
0005432707212	29966	Economy	3400.00
0005433124387	29966	Economy	3400.00
0005432707136	29966	Economy	3400.00
0005432707213	29966	Economy	3400.00
0005432693778	29966	Economy	3400.00
0005432881140	29966	Economy	3400.00
0005432693785	29966	Economy	3400.00
0005432707207	29966	Economy	3400.00
0005432707191	29966	Economy	3400.00
0005433124378	29966	Economy	3400.00
0005433124373	29966	Economy	3400.00
0005432881150	29966	Economy	3400.00
0005433124384	29966	Economy	3400.00
0005432881143	29966	Economy	3400.00
0005432707192	29966	Economy	3400.00
0005432707076	29966	Economy	3400.00
0005432707164	29966	Economy	3400.00
0005432707148	29966	Economy	3400.00
0005433194920	29966	Economy	3400.00
0005432707214	29966	Economy	3400.00
0005432693760	29966	Economy	3400.00
0005433124374	29966	Economy	3400.00
0005432881138	29966	Economy	3400.00
0005432881146	29966	Economy	3400.00
0005433124380	29966	Economy	3400.00
0005432881139	29966	Economy	3400.00
0005432707095	29966	Economy	3400.00
0005432693764	29966	Economy	3400.00
0005433194919	29966	Economy	3400.00
0005433124368	29966	Economy	3400.00
0005432881142	29966	Economy	3400.00
0005433124381	29966	Economy	3400.00
0005433194914	29966	Economy	3400.00
0005433124372	29966	Economy	3400.00
0005432707141	29966	Economy	3400.00
0005432693782	29966	Economy	3400.00
0005432693767	29966	Economy	3400.00
0005432881145	29966	Economy	3400.00
0005433124385	29966	Economy	3400.00
0005432881149	29966	Economy	3400.00
0005432693777	29966	Economy	3400.00
0005432881148	29966	Economy	3400.00
0005432693784	29966	Economy	3400.00
0005432707172	29966	Economy	3400.00
0005432693779	29966	Economy	3400.00
0005433124382	29966	Economy	3400.00
0005432693766	29966	Economy	3400.00
0005433124369	29966	Economy	3400.00
0005433194921	29966	Economy	3400.00
0005433124370	29966	Economy	3400.00
0005432693769	29966	Economy	3400.00
0005432693770	29966	Economy	3400.00
0005434980445	23653	Economy	4000.00
0005434980437	23653	Economy	4000.00
0005434980432	23653	Economy	4000.00
0005434980447	23653	Economy	3600.00
0005434980440	23653	Economy	3600.00
0005434980448	23653	Economy	3600.00
0005434980446	23653	Economy	3600.00
0005434988973	23653	Economy	3600.00
0005434980451	23653	Economy	3600.00
0005434988964	23653	Economy	3600.00
0005434980431	23653	Economy	3600.00
0005434980438	23653	Economy	3600.00
0005434988972	23653	Economy	3600.00
0005434980435	23653	Economy	3600.00
0005434980436	23653	Economy	3600.00
0005434988968	23653	Economy	3600.00
0005434988969	23653	Economy	3600.00
0005434980422	23653	Economy	3600.00
0005434980424	23653	Economy	3600.00
0005434988974	23653	Economy	3600.00
0005434980439	23653	Economy	3600.00
0005434980428	23653	Economy	3600.00
0005434980444	23653	Economy	3600.00
0005434988970	23653	Economy	3600.00
0005434980441	23653	Economy	3600.00
0005434980427	23653	Economy	3600.00
0005434988965	23653	Economy	3600.00
0005434980423	23653	Economy	3600.00
0005434980450	23653	Economy	3600.00
0005434988971	23653	Economy	3600.00
0005434980434	23653	Economy	3600.00
0005434988966	23653	Economy	3600.00
0005434980433	23653	Economy	3600.00
0005434980426	23653	Economy	3600.00
0005434980429	23653	Economy	3600.00
0005434988963	23653	Economy	3600.00
0005434980443	23653	Economy	3600.00
0005434980449	23653	Economy	3600.00
0005434980442	23653	Economy	3600.00
0005434980425	23653	Economy	3600.00
0005434980452	23653	Economy	3600.00
0005434988967	23653	Economy	3600.00
0005434980430	23653	Economy	3600.00
0005434980421	23653	Economy	3600.00
0005434980242	27524	Economy	4000.00
0005434980231	27524	Economy	4000.00
0005434988879	27524	Economy	4000.00
0005434980109	27524	Economy	3600.00
0005434980145	27524	Economy	3600.00
0005434988855	27524	Economy	3600.00
0005434980217	27524	Economy	3600.00
0005434980078	27524	Economy	3600.00
0005434988884	27524	Economy	3600.00
0005434980108	27524	Economy	3600.00
0005434980219	27524	Economy	3600.00
0005434980176	27524	Economy	3600.00
0005434980205	27524	Economy	3600.00
0005434980133	27524	Economy	3600.00
0005434988877	27524	Economy	3600.00
0005434980238	27524	Economy	3600.00
0005434980237	27524	Economy	3600.00
0005434980079	27524	Economy	3600.00
0005434980074	27524	Economy	3600.00
0005434980283	27524	Economy	3600.00
0005434988854	27524	Economy	3600.00
0005434980147	27524	Economy	3600.00
0005434980144	27524	Economy	3600.00
0005434988887	27524	Economy	3600.00
0005434980084	27524	Economy	3600.00
0005434980148	27524	Economy	3600.00
0005434980177	27524	Economy	3600.00
0005434980310	27524	Economy	3600.00
0005434988847	27524	Economy	3600.00
0005434980083	27524	Economy	3600.00
0005434980156	27524	Economy	3600.00
0005434980153	27524	Economy	3600.00
0005434988846	27524	Economy	3600.00
0005434980257	27524	Economy	3600.00
0005434988880	27524	Economy	3600.00
0005434980218	27524	Economy	3600.00
0005434980248	27524	Economy	3600.00
0005434980157	27524	Economy	3600.00
0005434980175	27524	Economy	3600.00
0005434980146	27524	Economy	3600.00
0005434980201	27524	Economy	3600.00
0005434980202	27524	Economy	3600.00
0005434302888	10262	Economy	21600.00
0005434302554	10262	Economy	21600.00
0005433113569	10262	Economy	19700.00
0005433111534	10262	Economy	19700.00
0005434302887	10262	Economy	19700.00
0005434302552	10262	Economy	19700.00
0005434302553	10262	Economy	19700.00
0005433113568	10262	Economy	19700.00
0005433111530	10262	Economy	19700.00
0005434302890	10262	Economy	19700.00
0005434302886	10262	Economy	19700.00
0005433111533	10262	Economy	19700.00
0005434302889	10262	Economy	19700.00
0005434302511	19631	Economy	21600.00
0005434302516	19631	Economy	19700.00
0005433113586	19631	Economy	19700.00
0005434302510	19631	Economy	19700.00
0005435070230	3541	Business	26900.00
0005435070275	3541	Business	26900.00
0005435719070	3541	Business	26900.00
0005435070265	3541	Business	26900.00
0005435925478	3541	Business	26900.00
0005435070233	3541	Business	26900.00
0005435070236	3541	Business	26900.00
0005435925476	3541	Business	26900.00
0005435070267	3541	Business	26900.00
0005435070252	3541	Business	26900.00
0005435070273	3541	Business	26900.00
0005435070270	3541	Economy	9000.00
0005435070257	3541	Economy	9000.00
0005435925427	3541	Economy	9000.00
0005435070266	3541	Economy	9000.00
0005435925461	3541	Economy	9000.00
0005435719071	3541	Economy	9000.00
0005435925489	3541	Economy	9000.00
0005435719075	3541	Economy	9900.00
0005435719073	3541	Economy	9900.00
0005435070261	3541	Economy	9900.00
0005435719069	3541	Economy	9000.00
0005435070226	3541	Economy	9000.00
0005435070225	3541	Economy	9000.00
0005435070262	3541	Economy	9000.00
0005435070254	3541	Economy	9000.00
0005435925483	3541	Economy	9000.00
0005435925467	3541	Economy	9000.00
0005435070274	3541	Economy	9000.00
0005435070241	3541	Economy	9000.00
0005435925463	3541	Economy	9000.00
0005435070243	3541	Economy	9000.00
0005435070245	3541	Economy	9000.00
0005435070227	3541	Economy	9000.00
0005435070256	3541	Economy	9000.00
0005435070263	3541	Economy	9000.00
0005435070240	3541	Economy	9000.00
0005435070235	3541	Economy	9000.00
0005435070249	3541	Economy	9000.00
0005435070258	3541	Economy	9000.00
0005435070244	3541	Economy	9000.00
0005435070260	3541	Economy	9000.00
0005435070232	3541	Economy	9000.00
0005435070224	3541	Economy	9000.00
0005435925482	3541	Economy	9000.00
0005435070269	3541	Economy	9000.00
0005435070250	3541	Economy	9000.00
0005435070259	3541	Economy	9000.00
0005435070231	3541	Economy	9000.00
0005435925488	3541	Economy	9000.00
0005435719067	3541	Economy	9000.00
0005435070228	3541	Economy	9000.00
0005435070246	3541	Economy	9000.00
0005435070239	3541	Economy	9000.00
0005435925473	3541	Economy	9000.00
0005435070255	3541	Economy	9000.00
0005435070234	3541	Economy	9000.00
0005435070251	3541	Economy	9000.00
0005435070247	3541	Economy	9000.00
0005435070264	3541	Economy	9000.00
0005435070253	3541	Economy	9000.00
0005435070248	3541	Economy	9000.00
0005435070229	3541	Economy	9000.00
0005435925441	3541	Economy	9000.00
0005435925412	3541	Economy	9000.00
0005435070271	3541	Economy	9000.00
0005435070237	3541	Economy	9000.00
0005435719068	3541	Economy	9000.00
0005435070272	3541	Economy	9000.00
0005435719072	3541	Economy	9000.00
0005435070238	3541	Economy	9000.00
0005435070268	3541	Economy	9000.00
0005435719074	3541	Economy	9000.00
0005435925474	3541	Economy	9000.00
0005435925462	3541	Economy	9000.00
0005435070242	3541	Economy	9000.00
0005435069626	15321	Business	26900.00
0005435925586	15321	Business	26900.00
0005435925591	15321	Business	26900.00
0005435069869	15321	Business	26900.00
0005435069956	15321	Business	26900.00
0005435069715	15321	Business	26900.00
0005435925600	15321	Business	26900.00
0005435925574	15321	Business	26900.00
0005435925594	15321	Economy	9000.00
0005435925583	15321	Economy	9000.00
0005435925584	15321	Economy	9000.00
0005435070054	15321	Economy	9000.00
0005435925590	15321	Economy	9000.00
0005435069815	15321	Economy	9000.00
0005435925577	15321	Economy	9000.00
0005435069878	15321	Economy	9000.00
0005435069679	15321	Economy	9900.00
0005435070055	15321	Economy	9900.00
0005435925593	15321	Economy	9900.00
0005435925587	15321	Economy	9900.00
0005435925579	15321	Economy	9000.00
0005435069925	15321	Economy	9000.00
0005435925575	15321	Economy	9000.00
0005435069934	15321	Economy	9000.00
0005435925578	15321	Economy	9000.00
0005435925595	15321	Economy	9000.00
0005435069687	15321	Economy	9000.00
0005435069833	15321	Economy	9000.00
0005435069705	15321	Economy	9000.00
0005435939928	15321	Economy	9000.00
0005435925582	15321	Economy	9000.00
0005435069611	15321	Economy	9000.00
0005435939930	15321	Economy	9000.00
0005435069379	15321	Economy	9000.00
0005435069953	15321	Economy	9000.00
0005435925581	15321	Economy	9000.00
0005435925573	15321	Economy	9000.00
0005435939926	15321	Economy	9000.00
0005435925572	15321	Economy	9000.00
0005435939925	15321	Economy	9000.00
0005435069601	15321	Economy	9000.00
0005435069753	15321	Economy	9000.00
0005435925596	15321	Economy	9000.00
0005435069851	15321	Economy	9000.00
0005435069682	15321	Economy	9000.00
0005435925588	15321	Economy	9000.00
0005435069741	15321	Economy	9000.00
0005435925598	15321	Economy	9000.00
0005435939929	15321	Economy	9000.00
0005435069763	15321	Economy	9000.00
0005435069563	15321	Economy	9000.00
0005435069924	15321	Economy	9000.00
0005435939927	15321	Economy	9000.00
0005435069730	15321	Economy	9000.00
0005435925576	15321	Economy	9000.00
0005435069625	15321	Economy	9000.00
0005435069602	15321	Economy	9000.00
0005435069587	15321	Economy	9000.00
0005435069796	15321	Economy	9000.00
0005435069872	15321	Economy	9000.00
0005435925580	15321	Economy	9000.00
0005435069852	15321	Economy	9000.00
0005435925592	15321	Economy	9000.00
0005435069683	15321	Economy	9000.00
0005435925599	15321	Economy	9000.00
0005435069954	15321	Economy	9000.00
0005435069571	15321	Economy	9000.00
0005435069478	15321	Economy	9000.00
0005435069760	15321	Economy	9000.00
0005435925597	15321	Economy	9000.00
0005435925585	15321	Economy	9000.00
0005435069808	15321	Economy	9000.00
0005435069794	15321	Economy	9000.00
0005435069740	15321	Economy	9000.00
0005435925589	15321	Economy	9000.00
0005432660864	18230	Economy	5900.00
0005432660865	18230	Economy	5900.00
0005432658639	18230	Economy	5900.00
0005432658638	18230	Economy	5900.00
0005432659753	18230	Economy	5900.00
0005432658637	18230	Economy	5900.00
0005432660848	26430	Economy	5900.00
0005432664171	26430	Economy	5900.00
0005432660849	26430	Economy	5900.00
0005432664164	26430	Economy	5900.00
0005432664165	26430	Economy	5900.00
0005432660847	26430	Economy	5900.00
0005433102715	97	Business	20000.00
0005432901922	97	Business	20000.00
0005433102790	97	Business	20000.00
0005432901886	97	Business	20000.00
0005433102863	97	Business	20000.00
0005432920132	97	Business	20000.00
0005433102920	97	Business	20000.00
0005433102926	97	Business	20000.00
0005433102751	97	Business	20000.00
0005433102668	97	Business	20000.00
0005433102861	97	Business	20000.00
0005432920116	97	Business	20000.00
0005432920169	97	Economy	7300.00
0005432920228	97	Economy	7300.00
0005433102737	97	Economy	7300.00
0005432901839	97	Economy	6700.00
0005432920207	97	Economy	6700.00
0005432920144	97	Economy	6700.00
0005432901843	97	Economy	6700.00
0005433102925	97	Economy	6700.00
0005433102791	97	Economy	6700.00
0005432920138	97	Economy	6700.00
0005432920094	97	Economy	6700.00
0005432920141	97	Economy	6700.00
0005432901818	97	Economy	6700.00
0005432920216	97	Economy	6700.00
0005433102729	97	Economy	6700.00
0005432901844	97	Economy	6700.00
0005433102915	97	Economy	6700.00
0005433102905	97	Economy	6700.00
0005433102877	97	Economy	6700.00
0005432920168	97	Economy	6700.00
0005433102848	97	Economy	6700.00
0005433102895	97	Economy	6700.00
0005433102761	97	Economy	6700.00
0005432901875	97	Economy	6700.00
0005432920292	97	Economy	6700.00
0005432901833	97	Economy	6700.00
0005432901912	97	Economy	6700.00
0005433102853	97	Economy	6700.00
0005432920076	97	Economy	6700.00
0005433102845	97	Economy	6700.00
0005432920220	97	Economy	6700.00
0005433102769	97	Economy	6700.00
0005432157537	97	Economy	6700.00
0005432901892	97	Economy	6700.00
0005432677632	97	Economy	6700.00
0005432920217	97	Economy	6700.00
0005433102860	97	Economy	6700.00
0005433102847	97	Economy	6700.00
0005432901891	97	Economy	6700.00
0005432901874	97	Economy	6700.00
0005433102906	97	Economy	6700.00
0005433102740	97	Economy	6700.00
0005433102781	97	Economy	7300.00
0005433102784	97	Economy	7300.00
0005432920245	97	Economy	6700.00
0005433102838	97	Economy	7300.00
0005433102894	97	Economy	7300.00
0005432157536	97	Economy	6700.00
0005433102867	97	Economy	6700.00
0005432920093	97	Economy	6700.00
0005433102852	97	Economy	6700.00
0005432920156	97	Economy	6700.00
0005432901910	97	Economy	6700.00
0005432901834	97	Economy	6700.00
0005433102839	97	Economy	6700.00
0005432920124	97	Economy	6700.00
0005432920191	97	Economy	6700.00
0005432920146	97	Economy	6700.00
0005432920126	97	Economy	6700.00
0005432901819	97	Economy	6700.00
0005433102728	97	Economy	6700.00
0005433102571	97	Economy	6700.00
0005433102872	97	Economy	6700.00
0005432901832	97	Economy	6700.00
0005433102768	97	Economy	6700.00
0005432920293	97	Economy	6700.00
0005432157538	97	Economy	6700.00
0005432157535	97	Economy	6700.00
0005432920145	97	Economy	6700.00
0005433102899	97	Economy	6700.00
0005433102570	97	Economy	6700.00
0005433102927	97	Economy	6700.00
0005433102886	97	Economy	6700.00
0005433102876	97	Economy	6700.00
0005433102844	97	Economy	6700.00
0005433102730	97	Economy	6700.00
0005433102835	97	Economy	6700.00
0005432901913	97	Economy	6700.00
0005433102836	97	Economy	6700.00
0005432677621	97	Economy	6700.00
0005433102873	97	Economy	6700.00
0005432920137	97	Economy	6700.00
0005432901887	97	Economy	6700.00
0005433102780	97	Economy	6700.00
0005432920155	97	Economy	6700.00
0005432920208	97	Economy	6700.00
0005433102669	97	Economy	6700.00
0005432207719	98	Business	20000.00
0005432262951	98	Business	20000.00
0005432262950	98	Business	20000.00
0005432262943	98	Business	20000.00
0005432818137	98	Business	20000.00
0005432262949	98	Business	20000.00
0005433477037	98	Business	20000.00
0005432262932	98	Business	20000.00
0005433477046	98	Business	20000.00
0005432756891	98	Business	20000.00
0005432262918	98	Business	20000.00
0005432753349	98	Business	20000.00
0005432818129	98	Business	20000.00
0005432756885	98	Business	20000.00
0005432262941	98	Business	20000.00
0005432262926	98	Business	20000.00
0005434153562	98	Business	20000.00
0005432262933	98	Business	20000.00
0005432262935	98	Business	20000.00
0005432262934	98	Business	20000.00
0005432262919	98	Business	20000.00
0005433477039	98	Economy	7300.00
0005433687719	98	Economy	7300.00
0005432262931	98	Economy	7300.00
0005432818136	98	Economy	7300.00
0005432818143	98	Economy	6700.00
0005432818139	98	Economy	6700.00
0005432818148	98	Economy	6700.00
0005432818144	98	Economy	6700.00
0005432262930	98	Economy	6700.00
0005432262922	98	Economy	6700.00
0005433477053	98	Economy	6700.00
0005432262956	98	Economy	6700.00
0005432262948	98	Economy	6700.00
0005432818146	98	Economy	6700.00
0005432262923	98	Economy	6700.00
0005433477048	98	Economy	6700.00
0005432818141	98	Economy	6700.00
0005432289060	98	Economy	6700.00
0005432262939	98	Economy	6700.00
0005432262921	98	Economy	6700.00
0005434153561	98	Economy	6700.00
0005433690959	98	Economy	6700.00
0005432262925	98	Economy	6700.00
0005432818132	98	Economy	6700.00
0005432818140	98	Economy	6700.00
0005432262945	98	Economy	6700.00
0005432207718	98	Economy	6700.00
0005432262914	98	Economy	6700.00
0005432262927	98	Economy	6700.00
0005433477044	98	Economy	6700.00
0005432818151	98	Economy	6700.00
0005433690954	98	Economy	6700.00
0005432818125	98	Economy	6700.00
0005433477040	98	Economy	6700.00
0005433477033	98	Economy	6700.00
0005432818134	98	Economy	6700.00
0005432818152	98	Economy	6700.00
0005434153563	98	Economy	6700.00
0005433477043	98	Economy	6700.00
0005432262929	98	Economy	6700.00
0005432818131	98	Economy	6700.00
0005432262916	98	Economy	6700.00
0005432818135	98	Economy	6700.00
0005432262913	98	Economy	7300.00
0005433477041	98	Economy	7300.00
0005432818133	98	Economy	6700.00
0005432262936	98	Economy	7300.00
0005432756884	98	Economy	6700.00
0005432262937	98	Economy	6700.00
0005432262947	98	Economy	6700.00
0005433477050	98	Economy	6700.00
0005432262952	98	Economy	6700.00
0005432262946	98	Economy	6700.00
0005433477042	98	Economy	6700.00
0005432262917	98	Economy	6700.00
0005433690958	98	Economy	6700.00
0005433477045	98	Economy	6700.00
0005432818138	98	Economy	6700.00
0005432818145	98	Economy	6700.00
0005433477034	98	Economy	6700.00
0005433687720	98	Economy	6700.00
0005432818149	98	Economy	6700.00
0005432818128	98	Economy	6700.00
0005433477054	98	Economy	6700.00
0005432262942	98	Economy	6700.00
0005432818127	98	Economy	6700.00
0005432262924	98	Economy	6700.00
0005432756890	98	Economy	6700.00
0005432818142	98	Economy	6700.00
0005432262954	98	Economy	6700.00
0005433477047	98	Economy	6700.00
0005433477052	98	Economy	6700.00
0005432818124	98	Economy	6700.00
0005432262953	98	Economy	6700.00
0005432262940	98	Economy	6700.00
0005433477035	98	Economy	6700.00
0005432818130	98	Economy	6700.00
0005432818126	98	Economy	6700.00
0005432818147	98	Economy	6700.00
0005432818150	98	Economy	6700.00
0005432289059	98	Economy	6700.00
0005433477051	98	Economy	6700.00
0005433477049	98	Economy	6700.00
0005432262920	98	Economy	6700.00
0005432262955	98	Economy	6700.00
0005433477038	98	Economy	6700.00
0005432262944	98	Economy	6700.00
0005432818123	98	Economy	6700.00
0005432289061	98	Economy	6700.00
0005432262938	98	Economy	6700.00
0005432262928	98	Economy	6700.00
0005433477036	98	Economy	6700.00
0005432262915	98	Economy	6700.00
0005432920324	7967	Business	20000.00
0005433103366	7967	Business	20000.00
0005432920320	7967	Business	20000.00
0005433103376	7967	Business	20000.00
0005433103365	7967	Business	20000.00
0005432045658	7967	Business	20000.00
0005432920317	7967	Business	20000.00
0005433103380	7967	Business	20000.00
0005432020853	7967	Business	20000.00
0005433103344	7967	Business	20000.00
0005432920322	7967	Business	20000.00
0005432920329	7967	Business	20000.00
0005432044588	7967	Business	20000.00
0005432020864	7967	Business	20000.00
0005432020858	7967	Business	20000.00
0005433103367	7967	Business	20000.00
0005432920325	7967	Business	20000.00
0005433103364	7967	Economy	7300.00
0005432677664	7967	Economy	7300.00
0005432020859	7967	Economy	7300.00
0005432920318	7967	Economy	6700.00
0005433103361	7967	Economy	6700.00
0005432045657	7967	Economy	6700.00
0005433103357	7967	Economy	6700.00
0005432020862	7967	Economy	6700.00
0005432920336	7967	Economy	6700.00
0005433103354	7967	Economy	6700.00
0005432920334	7967	Economy	6700.00
0005432920321	7967	Economy	6700.00
0005432020873	7967	Economy	6700.00
0005433103368	7967	Economy	6700.00
0005433103379	7967	Economy	6700.00
0005433103339	7967	Economy	6700.00
0005433103359	7967	Economy	6700.00
0005433103375	7967	Economy	6700.00
0005433103358	7967	Economy	6700.00
0005433103346	7967	Economy	6700.00
0005432020861	7967	Economy	6700.00
0005432751603	7967	Economy	6700.00
0005433103350	7967	Economy	6700.00
0005433103342	7967	Economy	6700.00
0005432020874	7967	Economy	6700.00
0005432753378	7967	Economy	6700.00
0005432020870	7967	Economy	6700.00
0005432020877	7967	Economy	6700.00
0005433103362	7967	Economy	6700.00
0005432020857	7967	Economy	6700.00
0005433103363	7967	Economy	6700.00
0005432020869	7967	Economy	6700.00
0005432751601	7967	Economy	6700.00
0005432392068	7967	Economy	6700.00
0005433103356	7967	Economy	6700.00
0005432392066	7967	Economy	6700.00
0005432677665	7967	Economy	6700.00
0005432020871	7967	Economy	6700.00
0005432020872	7967	Economy	6700.00
0005432920326	7967	Economy	6700.00
0005433103353	7967	Economy	6700.00
0005433103371	7967	Economy	6700.00
0005432020875	7967	Economy	6700.00
0005433103355	7967	Economy	6700.00
0005432020865	7967	Economy	7300.00
0005433103345	7967	Economy	7300.00
0005432920331	7967	Economy	7300.00
0005432020863	7967	Economy	6700.00
0005432677663	7967	Economy	6700.00
0005433103343	7967	Economy	7300.00
0005433103352	7967	Economy	6700.00
0005432020852	7967	Economy	6700.00
0005432020855	7967	Economy	6700.00
0005433103348	7967	Economy	6700.00
0005433103370	7967	Economy	6700.00
0005433103347	7967	Economy	6700.00
0005432920333	7967	Economy	6700.00
0005432753377	7967	Economy	6700.00
0005433103373	7967	Economy	6700.00
0005432677662	7967	Economy	6700.00
0005432020860	7967	Economy	6700.00
0005433103351	7967	Economy	6700.00
0005432020854	7967	Economy	6700.00
0005433103360	7967	Economy	6700.00
0005432020876	7967	Economy	6700.00
0005432020856	7967	Economy	6700.00
0005432920323	7967	Economy	6700.00
0005433103372	7967	Economy	6700.00
0005432020868	7967	Economy	6700.00
0005433103341	7967	Economy	6700.00
0005432920328	7967	Economy	6700.00
0005433103349	7967	Economy	6700.00
0005432044587	7967	Economy	6700.00
0005432751602	7967	Economy	6700.00
0005432753376	7967	Economy	6700.00
0005432920335	7967	Economy	6700.00
0005432020867	7967	Economy	6700.00
0005432020851	7967	Economy	6700.00
0005432392067	7967	Economy	6700.00
0005433103340	7967	Economy	6700.00
0005433103374	7967	Economy	6700.00
0005432020866	7967	Economy	6700.00
0005433103378	7967	Economy	6700.00
0005432920332	7967	Economy	6700.00
0005432920330	7967	Economy	6700.00
0005433103369	7967	Economy	6700.00
0005432920319	7967	Economy	6700.00
0005433103377	7967	Economy	6700.00
0005432920327	7967	Economy	6700.00
0005434513605	7972	Business	20000.00
0005432817927	7972	Business	20000.00
0005434513616	7972	Business	20000.00
0005432817833	7972	Business	20000.00
0005432901998	7972	Business	20000.00
0005432817860	7972	Business	20000.00
0005432817918	7972	Business	20000.00
0005432817766	7972	Business	20000.00
0005432902011	7972	Business	20000.00
0005432817945	7972	Economy	7300.00
0005432902008	7972	Economy	7300.00
0005432817762	7972	Economy	7300.00
0005434513609	7972	Economy	7300.00
0005432817754	7972	Economy	6700.00
0005434513613	7972	Economy	6700.00
0005432817980	7972	Economy	6700.00
0005432002123	7972	Economy	6700.00
0005434513608	7972	Economy	6700.00
0005434513604	7972	Economy	6700.00
0005432902009	7972	Economy	6700.00
0005432817825	7972	Economy	6700.00
0005432902012	7972	Economy	6700.00
0005432817890	7972	Economy	6700.00
0005434513597	7972	Economy	6700.00
0005432817826	7972	Economy	6700.00
0005432817921	7972	Economy	6700.00
0005432817821	7972	Economy	6700.00
0005432901996	7972	Economy	6700.00
0005432902010	7972	Economy	6700.00
0005432817893	7972	Economy	6700.00
0005432817952	7972	Economy	6700.00
0005432817817	7972	Economy	6700.00
0005432817835	7972	Economy	6700.00
0005434513615	7972	Economy	6700.00
0005432817923	7972	Economy	6700.00
0005434513611	7972	Economy	6700.00
0005432817843	7972	Economy	6700.00
0005432902007	7972	Economy	7300.00
0005432902002	7972	Economy	6700.00
0005432817928	7972	Economy	6700.00
0005432902001	7972	Economy	6700.00
0005434513596	7972	Economy	6700.00
0005432817832	7972	Economy	6700.00
0005434513607	7972	Economy	6700.00
0005432901997	7972	Economy	6700.00
0005432902005	7972	Economy	6700.00
0005432817758	7972	Economy	6700.00
0005432817759	7972	Economy	6700.00
0005432901995	7972	Economy	6700.00
0005432901999	7972	Economy	6700.00
0005432817755	7972	Economy	6700.00
0005432817834	7972	Economy	6700.00
0005432817889	7972	Economy	6700.00
0005432902003	7972	Economy	6700.00
0005434513612	7972	Economy	6700.00
0005432902006	7972	Economy	6700.00
0005432902000	7972	Economy	6700.00
0005432817816	7972	Economy	6700.00
0005432902004	7972	Economy	6700.00
0005432817922	7972	Economy	6700.00
0005432817765	7972	Economy	6700.00
0005433870780	9636	Economy	6900.00
0005434175803	9636	Economy	6900.00
0005434175813	9636	Economy	6900.00
0005434175804	9636	Economy	6900.00
0005434175798	9636	Economy	6900.00
0005434175799	9636	Economy	6900.00
0005434175814	9636	Economy	6900.00
0005433870781	9636	Economy	6900.00
0005434175846	32357	Economy	6900.00
0005434175850	32357	Economy	6900.00
0005434175848	32357	Economy	6900.00
0005434175847	32357	Economy	6900.00
0005434175849	32357	Economy	6900.00
0005434427280	3467	Business	35000.00
0005434880395	3467	Business	35000.00
0005434880313	3467	Business	35000.00
0005434938580	3467	Business	35000.00
0005432800101	3467	Business	35000.00
0005435902945	3467	Business	35000.00
0005435626594	3467	Business	35000.00
0005435903037	3467	Business	35000.00
0005434880319	3467	Business	35000.00
0005435626599	3467	Business	35000.00
0005434880404	3467	Business	35000.00
0005435127278	3467	Business	35000.00
0005432800107	3467	Business	35000.00
0005435127271	3467	Business	35000.00
0005435626587	3467	Business	35000.00
0005434880358	3467	Business	35000.00
0005432800105	3467	Business	35000.00
0005432800096	3467	Business	35000.00
0005434427275	3467	Business	35000.00
0005432800090	3467	Business	35000.00
0005435626590	3467	Business	35000.00
0005434880344	3467	Comfort	19900.00
0005435127284	3467	Comfort	19900.00
0005435127300	3467	Comfort	19900.00
0005435626606	3467	Comfort	19900.00
0005434427266	3467	Comfort	19900.00
0005434880383	3467	Comfort	19900.00
0005434880389	3467	Comfort	19900.00
0005435902888	3467	Comfort	19900.00
0005434427271	3467	Comfort	19900.00
0005432613954	3467	Comfort	19900.00
0005434427288	3467	Comfort	19900.00
0005434880316	3467	Comfort	19900.00
0005432800095	3467	Comfort	19900.00
0005434880390	3467	Comfort	19900.00
0005434880376	3467	Comfort	19900.00
0005434880385	3467	Comfort	19900.00
0005435626598	3467	Comfort	19900.00
0005434938584	3467	Comfort	19900.00
0005434880341	3467	Comfort	19900.00
0005432800106	3467	Comfort	19900.00
0005435902990	3467	Comfort	19900.00
0005434880359	3467	Comfort	19900.00
0005434880340	3467	Comfort	19900.00
0005432800104	3467	Comfort	19900.00
0005435903005	3467	Comfort	19900.00
0005434880329	3467	Comfort	19900.00
0005432800083	3467	Comfort	19900.00
0005435902934	3467	Comfort	19900.00
0005434880345	3467	Comfort	19900.00
0005434880381	3467	Comfort	19900.00
0005434427284	3467	Comfort	19900.00
0005434938587	3467	Comfort	19900.00
0005435127309	3467	Comfort	19900.00
0005434427278	3467	Comfort	19900.00
0005435626607	3467	Comfort	19900.00
0005434880400	3467	Comfort	19900.00
0005432800102	3467	Comfort	19900.00
0005434880356	3467	Economy	11700.00
0005434427279	3467	Economy	11700.00
0005435626602	3467	Economy	11700.00
0005432183516	3467	Economy	11700.00
0005434880360	3467	Economy	11700.00
0005435626595	3467	Economy	11700.00
0005434880335	3467	Economy	11700.00
0005435626597	3467	Economy	11700.00
0005432800086	3467	Economy	11700.00
0005434880393	3467	Economy	11700.00
0005434938575	3467	Economy	11700.00
0005432800100	3467	Economy	11700.00
0005434938582	3467	Economy	11700.00
0005434938577	3467	Economy	11700.00
0005434880367	3467	Economy	11700.00
0005434880323	3467	Economy	11700.00
0005432800085	3467	Economy	11700.00
0005434427268	3467	Economy	11700.00
0005435127299	3467	Economy	11700.00
0005435127275	3467	Economy	11700.00
0005435127294	3467	Economy	11700.00
0005435127304	3467	Economy	11700.00
0005434880403	3467	Economy	11700.00
0005435127290	3467	Economy	11700.00
0005434880322	3467	Economy	11700.00
0005434880320	3467	Economy	11700.00
0005434938586	3467	Economy	11700.00
0005435127311	3467	Economy	11700.00
0005432611788	3467	Economy	11700.00
0005435127297	3467	Economy	11700.00
0005432800093	3467	Economy	11700.00
0005432800098	3467	Economy	11700.00
0005434880370	3467	Economy	11700.00
0005435127306	3467	Economy	11700.00
0005434880362	3467	Economy	11700.00
0005435127283	3467	Economy	11700.00
0005434880311	3467	Economy	11700.00
0005435127295	3467	Economy	11700.00
0005434880317	3467	Economy	11700.00
0005435127272	3467	Economy	11700.00
0005435902989	3467	Economy	11700.00
0005434427269	3467	Economy	11700.00
0005434880394	3467	Economy	11700.00
0005435127286	3467	Economy	11700.00
0005434880332	3467	Economy	11700.00
0005432613952	3467	Economy	11700.00
0005435127277	3467	Economy	11700.00
0005434938585	3467	Economy	11700.00
0005434880342	3467	Economy	11700.00
0005435127280	3467	Economy	11700.00
0005432613957	3467	Economy	11700.00
0005434938576	3467	Economy	11700.00
0005434880343	3467	Economy	12800.00
0005435127288	3467	Economy	12800.00
0005434880347	3467	Economy	11700.00
0005435127274	3467	Economy	12800.00
0005434880386	3467	Economy	11700.00
0005435127293	3467	Economy	11700.00
0005435127292	3467	Economy	12800.00
0005435626604	3467	Economy	12800.00
0005434427273	3467	Economy	11700.00
0005434880380	3467	Economy	11700.00
0005434880361	3467	Economy	11700.00
0005434880331	3467	Economy	11700.00
0005435127273	3467	Economy	11700.00
0005434880357	3467	Economy	11700.00
0005434938591	3467	Economy	11700.00
0005435902896	3467	Economy	11700.00
0005434880379	3467	Economy	11700.00
0005434880355	3467	Economy	11700.00
0005434427267	3467	Economy	11700.00
0005435902967	3467	Economy	11700.00
0005434880348	3467	Economy	11700.00
0005434938581	3467	Economy	11700.00
0005434880392	3467	Economy	11700.00
0005435902895	3467	Economy	11700.00
0005435626593	3467	Economy	11700.00
0005435127301	3467	Economy	11700.00
0005435902887	3467	Economy	11700.00
0005434427286	3467	Economy	11700.00
0005435902979	3467	Economy	11700.00
0005434880333	3467	Economy	11700.00
0005432613955	3467	Economy	11700.00
0005434427285	3467	Economy	11700.00
0005435903032	3467	Economy	11700.00
0005435626596	3467	Economy	11700.00
0005435127291	3467	Economy	11700.00
0005432800088	3467	Economy	11700.00
0005435626600	3467	Economy	11700.00
0005435127298	3467	Economy	11700.00
0005434880339	3467	Economy	11700.00
0005434427276	3467	Economy	11700.00
0005435913978	3467	Economy	11700.00
0005434880373	3467	Economy	11700.00
0005434427283	3467	Economy	11700.00
0005434880328	3467	Economy	11700.00
0005432800082	3467	Economy	11700.00
0005435903006	3467	Economy	11700.00
0005434880397	3467	Economy	11700.00
0005434880398	3467	Economy	11700.00
0005434880315	3467	Economy	11700.00
0005434880364	3467	Economy	11700.00
0005434880351	3467	Economy	11700.00
0005434880310	3467	Economy	11700.00
0005435127287	3467	Economy	11700.00
0005435626586	3467	Economy	11700.00
0005434880350	3467	Economy	11700.00
0005435626603	3467	Economy	11700.00
0005435127296	3467	Economy	11700.00
0005434880369	3467	Economy	11700.00
0005435127285	3467	Economy	11700.00
0005432800092	3467	Economy	11700.00
0005435902897	3467	Economy	11700.00
0005432800087	3467	Economy	11700.00
0005432613953	3467	Economy	11700.00
0005434880336	3467	Economy	11700.00
0005435127276	3467	Economy	11700.00
0005434938579	3467	Economy	11700.00
0005434427287	3467	Economy	11700.00
0005434880374	3467	Economy	11700.00
0005432800089	3467	Economy	11700.00
0005434938589	3467	Economy	11700.00
0005434880402	3467	Economy	11700.00
0005434880352	3467	Economy	11700.00
0005434880372	3467	Economy	11700.00
0005434880337	3467	Economy	11700.00
0005435127305	3467	Economy	11700.00
0005434427262	3467	Economy	11700.00
0005434880338	3467	Economy	11700.00
0005434427281	3467	Economy	11700.00
0005435841107	3467	Economy	12800.00
0005434938590	3467	Economy	12800.00
0005435127302	3467	Economy	12800.00
0005434880327	3467	Economy	12800.00
0005434880312	3467	Economy	11700.00
0005435914704	3467	Economy	11700.00
0005434880365	3467	Economy	11700.00
0005434427274	3467	Economy	11700.00
0005432800094	3467	Economy	11700.00
0005434880396	3467	Economy	11700.00
0005435902913	3467	Economy	11700.00
0005434880321	3467	Economy	11700.00
0005434880325	3467	Economy	11700.00
0005435626601	3467	Economy	11700.00
0005435626588	3467	Economy	11700.00
0005435626592	3467	Economy	11700.00
0005432611791	3467	Economy	11700.00
0005435127303	3467	Economy	11700.00
0005434880401	3467	Economy	11700.00
0005434880353	3467	Economy	11700.00
0005434880391	3467	Economy	11700.00
0005432800097	3467	Economy	11700.00
0005435127308	3467	Economy	11700.00
0005435127310	3467	Economy	11700.00
0005435127270	3467	Economy	11700.00
0005434427277	3467	Economy	11700.00
0005434880324	3467	Economy	11700.00
0005434880326	3467	Economy	11700.00
0005435626589	3467	Economy	11700.00
0005434427270	3467	Economy	11700.00
0005435127282	3467	Economy	11700.00
0005432800099	3467	Economy	11700.00
0005432188680	3467	Economy	11700.00
0005435626605	3467	Economy	11700.00
0005434880363	3467	Economy	11700.00
0005434880371	3467	Economy	11700.00
0005435626591	3467	Economy	11700.00
0005432611790	3467	Economy	11700.00
0005435902912	3467	Economy	11700.00
0005435127281	3467	Economy	11700.00
0005435127289	3467	Economy	11700.00
0005432800091	3467	Economy	11700.00
0005434427260	3467	Economy	11700.00
0005434938583	3467	Economy	11700.00
0005434427265	3467	Economy	11700.00
0005432800084	3467	Economy	11700.00
0005435913970	3467	Economy	11700.00
0005434880375	3467	Economy	11700.00
0005432800103	3467	Economy	11700.00
0005434880318	3467	Economy	11700.00
0005434427263	3467	Economy	11700.00
0005434880368	3467	Economy	11700.00
0005434880377	3467	Economy	11700.00
0005434880388	3467	Economy	11700.00
0005432183515	3467	Economy	11700.00
0005432800081	3467	Economy	11700.00
0005434880330	3467	Economy	11700.00
0005434427272	3467	Economy	11700.00
0005435903036	3467	Economy	11700.00
0005434880384	3467	Economy	11700.00
0005432800108	3467	Economy	11700.00
0005434880314	3467	Economy	11700.00
0005434880346	3467	Economy	11700.00
0005432611789	3467	Economy	11700.00
0005434938592	3467	Economy	11700.00
0005432188681	3467	Economy	11700.00
0005434427261	3467	Economy	11700.00
0005434880354	3467	Economy	11700.00
0005434880366	3467	Economy	11700.00
0005434880387	3467	Economy	11700.00
0005432800109	3467	Economy	11700.00
0005434880334	3467	Economy	11700.00
0005434938578	3467	Economy	11700.00
0005434427282	3467	Economy	11700.00
0005434938588	3467	Economy	11700.00
0005435127307	3467	Economy	11700.00
0005434880349	3467	Economy	11700.00
0005434880382	3467	Economy	11700.00
0005435127279	3467	Economy	11700.00
0005434427264	3467	Economy	11700.00
0005432188682	3467	Economy	11700.00
0005434880378	3467	Economy	11700.00
0005432613956	3467	Economy	11700.00
0005434880399	3467	Economy	11700.00
0005435126838	14573	Business	35000.00
0005434879238	14573	Business	35000.00
0005435626423	14573	Business	35000.00
0005434879531	14573	Business	35000.00
0005434879549	14573	Business	35000.00
0005432799806	14573	Business	35000.00
0005435126846	14573	Business	35000.00
0005435914046	14573	Business	35000.00
0005434427119	14573	Business	35000.00
0005435903106	14573	Business	35000.00
0005435126903	14573	Business	35000.00
0005435126870	14573	Business	35000.00
0005435626427	14573	Business	35000.00
0005434878986	14573	Business	35000.00
0005434426911	14573	Business	35000.00
0005434879522	14573	Business	35000.00
0005434879356	14573	Business	35000.00
0005435126968	14573	Business	35000.00
0005435626333	14573	Business	35000.00
0005435126802	14573	Business	35000.00
0005434879879	14573	Business	35000.00
0005434879604	14573	Business	35000.00
0005434938507	14573	Business	35000.00
0005435126775	14573	Comfort	19900.00
0005434427024	14573	Comfort	19900.00
0005434427015	14573	Comfort	19900.00
0005434938477	14573	Comfort	19900.00
0005434879478	14573	Comfort	19900.00
0005432799856	14573	Comfort	19900.00
0005435626407	14573	Comfort	19900.00
0005434938447	14573	Comfort	19900.00
0005435626385	14573	Comfort	19900.00
0005434879784	14573	Comfort	19900.00
0005434879999	14573	Comfort	19900.00
0005434938502	14573	Comfort	19900.00
0005434879464	14573	Comfort	19900.00
0005434426961	14573	Comfort	19900.00
0005434427088	14573	Comfort	19900.00
0005432059551	14573	Comfort	19900.00
0005435126666	14573	Comfort	19900.00
0005435903097	14573	Comfort	19900.00
0005434879954	14573	Comfort	19900.00
0005432799835	14573	Comfort	19900.00
0005434879853	14573	Comfort	19900.00
0005434879405	14573	Comfort	19900.00
0005434879692	14573	Comfort	19900.00
0005432611763	14573	Comfort	19900.00
0005432799863	14573	Comfort	19900.00
0005435127052	14573	Comfort	19900.00
0005434879621	14573	Comfort	19900.00
0005435626389	14573	Comfort	19900.00
0005434427120	14573	Comfort	19900.00
0005432799904	14573	Comfort	19900.00
0005434879526	14573	Economy	11700.00
0005434879516	14573	Economy	11700.00
0005434427001	14573	Economy	11700.00
0005432799869	14573	Economy	11700.00
0005434427069	14573	Economy	11700.00
0005434879823	14573	Economy	11700.00
0005435903099	14573	Economy	11700.00
0005435626421	14573	Economy	11700.00
0005435626388	14573	Economy	11700.00
0005434879533	14573	Economy	11700.00
0005432799826	14573	Economy	11700.00
0005435914042	14573	Economy	11700.00
0005434879596	14573	Economy	11700.00
0005435126965	14573	Economy	11700.00
0005432799843	14573	Economy	11700.00
0005434879693	14573	Economy	11700.00
0005434879376	14573	Economy	11700.00
0005434426995	14573	Economy	11700.00
0005435626317	14573	Economy	11700.00
0005434879447	14573	Economy	11700.00
0005435126780	14573	Economy	11700.00
0005434426960	14573	Economy	11700.00
0005434427062	14573	Economy	11700.00
0005434879260	14573	Economy	11700.00
0005434879765	14573	Economy	11700.00
0005434427009	14573	Economy	11700.00
0005434879375	14573	Economy	11700.00
0005435914045	14573	Economy	11700.00
0005434879620	14573	Economy	11700.00
0005434879914	14573	Economy	11700.00
0005434879308	14573	Economy	11700.00
0005434879275	14573	Economy	11700.00
0005434879237	14573	Economy	11700.00
0005435903101	14573	Economy	11700.00
0005435626406	14573	Economy	11700.00
0005435903109	14573	Economy	11700.00
0005434879629	14573	Economy	11700.00
0005435903100	14573	Economy	11700.00
0005435626316	14573	Economy	11700.00
0005434879643	14573	Economy	11700.00
0005434879892	14573	Economy	11700.00
0005435626387	14573	Economy	11700.00
0005434880043	14573	Economy	11700.00
0005434426905	14573	Economy	11700.00
0005434879515	14573	Economy	11700.00
0005434426979	14573	Economy	11700.00
0005434879218	14573	Economy	11700.00
0005435126837	14573	Economy	11700.00
0005435903108	14573	Economy	11700.00
0005435841842	14573	Economy	11700.00
0005432059549	14573	Economy	11700.00
0005435127049	14573	Economy	11700.00
0005434879483	14573	Economy	11700.00
0005434938508	14573	Economy	11700.00
0005434879822	14573	Economy	11700.00
0005435903098	14573	Economy	11700.00
0005434879484	14573	Economy	12800.00
0005434879854	14573	Economy	12800.00
0005434879316	14573	Economy	12800.00
0005435126901	14573	Economy	11700.00
0005434879616	14573	Economy	12800.00
0005434879731	14573	Economy	11700.00
0005434879615	14573	Economy	11700.00
0005434879551	14573	Economy	12800.00
0005434938430	14573	Economy	11700.00
0005432799807	14573	Economy	11700.00
0005434879252	14573	Economy	11700.00
0005434938336	14573	Economy	11700.00
0005434879753	14573	Economy	11700.00
0005432799822	14573	Economy	11700.00
0005432799836	14573	Economy	11700.00
0005435903095	14573	Economy	11700.00
0005434879527	14573	Economy	11700.00
0005432799940	14573	Economy	11700.00
0005434880014	14573	Economy	11700.00
0005434938444	14573	Economy	11700.00
0005434879524	14573	Economy	11700.00
0005435903105	14573	Economy	11700.00
0005434879590	14573	Economy	11700.00
0005434938503	14573	Economy	11700.00
0005435914044	14573	Economy	11700.00
0005434879730	14573	Economy	11700.00
0005434879536	14573	Economy	11700.00
0005432799674	14573	Economy	11700.00
0005435126784	14573	Economy	11700.00
0005434880000	14573	Economy	11700.00
0005434938422	14573	Economy	11700.00
0005432799809	14573	Economy	11700.00
0005432799844	14573	Economy	11700.00
0005435126783	14573	Economy	11700.00
0005435841843	14573	Economy	11700.00
0005435126929	14573	Economy	11700.00
0005434938456	14573	Economy	11700.00
0005434879741	14573	Economy	11700.00
0005435126795	14573	Economy	11700.00
0005434880013	14573	Economy	11700.00
0005434879552	14573	Economy	11700.00
0005434879891	14573	Economy	11700.00
0005434879307	14573	Economy	11700.00
0005434879525	14573	Economy	11700.00
0005434879553	14573	Economy	11700.00
0005434879630	14573	Economy	11700.00
0005434427035	14573	Economy	11700.00
0005434879571	14573	Economy	11700.00
0005434938361	14573	Economy	11700.00
0005435626412	14573	Economy	11700.00
0005435626429	14573	Economy	11700.00
0005434879477	14573	Economy	11700.00
0005434426888	14573	Economy	11700.00
0005434938360	14573	Economy	11700.00
0005435126853	14573	Economy	11700.00
0005434879299	14573	Economy	11700.00
0005434879669	14573	Economy	11700.00
0005435626386	14573	Economy	11700.00
0005432607616	14573	Economy	11700.00
0005434879660	14573	Economy	11700.00
0005435626411	14573	Economy	11700.00
0005434879267	14573	Economy	11700.00
0005434879631	14573	Economy	11700.00
0005435626334	14573	Economy	11700.00
0005432799912	14573	Economy	11700.00
0005435626422	14573	Economy	11700.00
0005435126898	14573	Economy	11700.00
0005435626413	14573	Economy	11700.00
0005435126855	14573	Economy	11700.00
0005434879422	14573	Economy	11700.00
0005434879419	14573	Economy	11700.00
0005434938486	14573	Economy	11700.00
0005434427112	14573	Economy	11700.00
0005435126803	14573	Economy	11700.00
0005434426988	14573	Economy	11700.00
0005434426991	14573	Economy	11700.00
0005434879752	14573	Economy	11700.00
0005435127044	14573	Economy	11700.00
0005434938478	14573	Economy	11700.00
0005434879532	14573	Economy	11700.00
0005434879593	14573	Economy	11700.00
0005434879437	14573	Economy	11700.00
0005432799855	14573	Economy	11700.00
0005434879113	14573	Economy	11700.00
0005434426999	14573	Economy	11700.00
0005434879708	14573	Economy	11700.00
0005434938423	14573	Economy	11700.00
0005434879377	14573	Economy	11700.00
0005434879719	14573	Economy	11700.00
0005432799884	14573	Economy	11700.00
0005435626381	14573	Economy	11700.00
0005435626419	14573	Economy	12800.00
0005434938421	14573	Economy	11700.00
0005434427058	14573	Economy	12800.00
0005434427063	14573	Economy	12800.00
0005434427110	14573	Economy	12800.00
0005434879446	14573	Economy	11700.00
0005434879178	14573	Economy	11700.00
0005434879987	14573	Economy	11700.00
0005435126747	14573	Economy	11700.00
0005432799841	14573	Economy	11700.00
0005434879717	14573	Economy	11700.00
0005434938443	14573	Economy	11700.00
0005432059550	14573	Economy	11700.00
0005434938481	14573	Economy	11700.00
0005434427047	14573	Economy	11700.00
0005435126944	14573	Economy	11700.00
0005435626417	14573	Economy	11700.00
0005435126906	14573	Economy	11700.00
0005432799914	14573	Economy	11700.00
0005435126854	14573	Economy	11700.00
0005434879591	14573	Economy	11700.00
0005435626432	14573	Economy	11700.00
0005435903103	14573	Economy	11700.00
0005434879789	14573	Economy	11700.00
0005432799857	14573	Economy	11700.00
0005434879635	14573	Economy	11700.00
0005435903112	14573	Economy	11700.00
0005435626420	14573	Economy	11700.00
0005435903107	14573	Economy	11700.00
0005434879534	14573	Economy	11700.00
0005434426848	14573	Economy	11700.00
0005434879671	14573	Economy	11700.00
0005432799825	14573	Economy	11700.00
0005432611762	14573	Economy	11700.00
0005435126857	14573	Economy	11700.00
0005434938449	14573	Economy	11700.00
0005434938464	14573	Economy	11700.00
0005435126943	14573	Economy	11700.00
0005432799840	14573	Economy	11700.00
0005435126871	14573	Economy	11700.00
0005434879721	14573	Economy	11700.00
0005435914043	14573	Economy	11700.00
0005434879670	14573	Economy	11700.00
0005434938515	14573	Economy	11700.00
0005434879809	14573	Economy	11700.00
0005434426904	14573	Economy	11700.00
0005432799894	14573	Economy	11700.00
0005434879330	14573	Economy	11700.00
0005434938362	14573	Economy	11700.00
0005435903104	14573	Economy	11700.00
0005434938322	14573	Economy	11700.00
0005435903111	14573	Economy	11700.00
0005434879691	14573	Economy	11700.00
0005435842347	14573	Economy	11700.00
0005434879420	14573	Economy	11700.00
0005434427008	14573	Economy	11700.00
0005432799896	14573	Economy	11700.00
0005434879372	14573	Economy	11700.00
0005435127015	14573	Economy	11700.00
0005435126930	14573	Economy	11700.00
0005434427158	14573	Economy	11700.00
0005434938420	14573	Economy	11700.00
0005435126801	14573	Economy	11700.00
0005434938487	14573	Economy	11700.00
0005434426990	14573	Economy	11700.00
0005434938476	14573	Economy	11700.00
0005435903110	14573	Economy	11700.00
0005432799750	14573	Economy	11700.00
0005434427116	14573	Economy	11700.00
0005435626416	14573	Economy	11700.00
0005434879523	14573	Economy	11700.00
0005435126771	14573	Economy	11700.00
0005434879274	14573	Economy	11700.00
0005432799749	14573	Economy	11700.00
0005434426950	14573	Economy	11700.00
0005434879514	14573	Economy	11700.00
0005435126748	14573	Economy	11700.00
0005435903096	14573	Economy	11700.00
0005434879913	14573	Economy	11700.00
0005435903102	14573	Economy	11700.00
0005435126902	14573	Economy	11700.00
0005435626392	14573	Economy	11700.00
0005434938321	14573	Economy	11700.00
0005432799913	14573	Economy	11700.00
0005434879718	14573	Economy	11700.00
0005435127014	14573	Economy	11700.00
0005434879729	14573	Economy	11700.00
0005434879445	14573	Economy	11700.00
0005434427111	14573	Economy	11700.00
0005434427023	14573	Economy	11700.00
0005434938514	14573	Economy	11700.00
0005434879543	14573	Economy	11700.00
0005434879623	14573	Economy	11700.00
0005434879528	14573	Economy	11700.00
0005435626426	14573	Economy	11700.00
0005435126845	14573	Economy	11700.00
0005434325914	3628	Economy	16300.00
0005434312364	3628	Economy	14800.00
0005434325909	3628	Economy	14800.00
0005435889947	3628	Economy	14800.00
0005434325912	3628	Economy	14800.00
0005434312387	3628	Economy	14800.00
0005435889966	3628	Economy	14800.00
0005434325910	3628	Economy	14800.00
0005435889986	3628	Economy	14800.00
0005435889990	3628	Economy	14800.00
0005435889991	3628	Economy	14800.00
0005434325915	3628	Economy	14800.00
0005434325913	3628	Economy	14800.00
0005434312365	3628	Economy	14800.00
0005434325907	3628	Economy	14800.00
0005434325908	3628	Economy	14800.00
0005434325916	3628	Economy	14800.00
0005434325911	3628	Economy	14800.00
0005435889980	3628	Economy	14800.00
0005435889992	3628	Economy	14800.00
0005435889998	3628	Economy	14800.00
0005434325906	3628	Economy	14800.00
0005434312366	3628	Economy	14800.00
0005435889993	3628	Economy	14800.00
0005435889965	3628	Economy	14800.00
0005435889989	3628	Economy	14800.00
0005434325856	15597	Economy	16300.00
0005434325880	15597	Economy	16300.00
0005434325838	15597	Economy	14800.00
0005435890031	15597	Economy	14800.00
0005434325785	15597	Economy	14800.00
0005434325823	15597	Economy	14800.00
0005434325814	15597	Economy	14800.00
0005434325784	15597	Economy	14800.00
0005435890032	15597	Economy	14800.00
0005435890036	15597	Economy	14800.00
0005435890030	15597	Economy	14800.00
0005435890035	15597	Economy	14800.00
0005435890033	15597	Economy	14800.00
0005435890034	15597	Economy	14800.00
0005434325854	15597	Economy	14800.00
0005434325837	15597	Economy	14800.00
0005435958035	649	Economy	4500.00
0005433420498	649	Economy	4500.00
0005435958040	649	Economy	4100.00
0005433420493	649	Economy	4100.00
0005435958031	649	Economy	4100.00
0005435958039	649	Economy	4100.00
0005435958027	649	Economy	4100.00
0005433420533	649	Economy	4100.00
0005433420492	649	Economy	4100.00
0005435958032	649	Economy	4100.00
0005435958029	649	Economy	4100.00
0005435958036	649	Economy	4100.00
0005435958034	649	Economy	4100.00
0005433420519	649	Economy	4100.00
0005435958038	649	Economy	4100.00
0005433420527	649	Economy	4100.00
0005435958033	649	Economy	4100.00
0005435958041	649	Economy	4100.00
0005435958042	649	Economy	4100.00
0005435958030	649	Economy	4100.00
0005435958037	649	Economy	4100.00
0005433420559	649	Economy	4100.00
0005433420518	649	Economy	4100.00
0005433420511	649	Economy	4100.00
0005433420512	649	Economy	4100.00
0005435958028	649	Economy	4100.00
0005435957906	15167	Economy	4500.00
0005433420598	15167	Economy	4500.00
0005435957920	15167	Economy	4100.00
0005433420592	15167	Economy	4100.00
0005435957899	15167	Economy	4100.00
0005433420596	15167	Economy	4100.00
0005435957921	15167	Economy	4100.00
0005433420591	15167	Economy	4100.00
0005435957914	15167	Economy	4100.00
0005435957935	15167	Economy	4100.00
0005435957891	15167	Economy	4100.00
0005435957922	15167	Economy	4100.00
0005435957926	15167	Economy	4100.00
0005435957863	15167	Economy	4100.00
0005433420597	15167	Economy	4100.00
0005435957862	15167	Economy	4100.00
0005435957945	15167	Economy	4100.00
0005433420595	15167	Economy	4100.00
0005433420594	15167	Economy	4100.00
0005433420593	15167	Economy	4100.00
0005435957917	15167	Economy	4100.00
0005435957890	15167	Economy	4100.00
0005435957998	15167	Economy	4100.00
0005435957907	15167	Economy	4100.00
0005435216607	27258	Economy	25500.00
0005435219227	27258	Economy	25500.00
0005435216619	27258	Economy	25500.00
0005435219229	27258	Economy	25500.00
0005435216618	27258	Economy	25500.00
0005435216603	27258	Economy	25500.00
0005435219223	27258	Economy	25500.00
0005435221064	27258	Economy	25500.00
0005435216605	27258	Economy	25500.00
0005435216613	27258	Economy	25500.00
0005435216604	27258	Economy	25500.00
0005435219211	27258	Economy	25500.00
0005435216606	27258	Economy	25500.00
0005435219228	27258	Economy	25500.00
0005435216612	27258	Economy	25500.00
0005435221065	27258	Economy	25500.00
0005435629433	8867	Economy	10400.00
0005435629434	8867	Economy	10400.00
0005435629435	8867	Economy	10400.00
0005435629436	8867	Economy	10400.00
0005435629420	16102	Economy	10400.00
0005435629422	16102	Economy	10400.00
0005435629423	16102	Economy	10400.00
0005434247206	16102	Economy	10400.00
0005435629424	16102	Economy	10400.00
0005434247205	16102	Economy	10400.00
0005435933504	4445	Economy	13400.00
0005435163343	4445	Economy	12200.00
0005435163353	4445	Economy	12200.00
0005435163348	4445	Economy	12200.00
0005435163345	4445	Economy	12200.00
0005435163350	4445	Economy	12200.00
0005435933505	4445	Economy	12200.00
0005435933494	4445	Economy	12200.00
0005435163346	4445	Economy	12200.00
0005435163351	4445	Economy	12200.00
0005435933507	4445	Economy	12200.00
0005435933502	4445	Economy	12200.00
0005435163352	4445	Economy	12200.00
0005435163344	4445	Economy	12200.00
0005435163349	4445	Economy	12200.00
0005435163347	4445	Economy	12200.00
0005435933506	4445	Economy	12200.00
0005435797793	2854	Business	12600.00
0005435797788	2854	Economy	4200.00
0005435797796	2854	Economy	4600.00
0005435797801	2854	Economy	4600.00
0005433404918	2854	Economy	4600.00
0005435797790	2854	Economy	4600.00
0005435797799	2854	Economy	4200.00
0005433404902	2854	Economy	4200.00
0005435797795	2854	Economy	4200.00
0005435797791	2854	Economy	4200.00
0005435797798	2854	Economy	4200.00
0005433404891	2854	Economy	4200.00
0005433404930	2854	Economy	4200.00
0005435797786	2854	Economy	4200.00
0005435797794	2854	Economy	4200.00
0005435797787	2854	Economy	4200.00
0005433404903	2854	Economy	4200.00
0005435797800	2854	Economy	4200.00
0005433404931	2854	Economy	4200.00
0005435797802	2854	Economy	4200.00
0005435797792	2854	Economy	4200.00
0005433404928	2854	Economy	4200.00
0005435797797	2854	Economy	4200.00
0005435797789	2854	Economy	4200.00
0005433404976	29329	Business	12600.00
0005433404975	29329	Economy	4200.00
0005435797734	29329	Economy	4600.00
0005435797724	29329	Economy	4200.00
0005435797723	29329	Economy	4200.00
0005433404978	29329	Economy	4200.00
0005435797680	29329	Economy	4200.00
0005435797716	29329	Economy	4200.00
0005433404981	29329	Economy	4200.00
0005433404979	29329	Economy	4200.00
0005433404982	29329	Economy	4200.00
0005433404977	29329	Economy	4200.00
0005435797733	29329	Economy	4200.00
0005435797708	29329	Economy	4200.00
0005435797707	29329	Economy	4200.00
0005435797689	29329	Economy	4200.00
0005433404980	29329	Economy	4200.00
0005435797662	29329	Economy	4200.00
0005435376384	5764	Economy	6800.00
0005435376393	5764	Economy	6800.00
0005435376394	5764	Economy	6800.00
0005434948209	5776	Economy	6800.00
0005434948206	5776	Economy	6800.00
0005434948207	5776	Economy	6800.00
0005434948205	5776	Economy	6800.00
0005434948208	5776	Economy	6800.00
0005434948103	16427	Economy	6800.00
0005435376411	16427	Economy	6800.00
0005435376412	16427	Economy	6800.00
0005435376414	16427	Economy	6800.00
0005434948141	16427	Economy	6800.00
0005434948111	16427	Economy	6800.00
0005434948127	16427	Economy	6800.00
0005434948142	16427	Economy	6800.00
0005434948126	16427	Economy	6800.00
0005434948167	16427	Economy	6800.00
0005434948168	16427	Economy	6800.00
0005435376413	16427	Economy	6800.00
0005433962150	6881	Business	21400.00
0005433962188	6881	Business	21400.00
0005433962199	6881	Business	21400.00
0005433962195	6881	Business	21400.00
0005433962173	6881	Business	21400.00
0005433962183	6881	Business	21400.00
0005433962182	6881	Business	21400.00
0005433962172	6881	Business	21400.00
0005433962171	6881	Economy	7100.00
0005433962180	6881	Economy	7100.00
0005433962190	6881	Economy	7100.00
0005433962149	6881	Economy	7100.00
0005433962151	6881	Economy	7100.00
0005433962175	6881	Economy	7100.00
0005433962166	6881	Economy	7800.00
0005433962192	6881	Economy	7800.00
0005433962194	6881	Economy	7100.00
0005433962189	6881	Economy	7100.00
0005433962177	6881	Economy	7100.00
0005433962165	6881	Economy	7100.00
0005433962187	6881	Economy	7100.00
0005433962162	6881	Economy	7100.00
0005433962161	6881	Economy	7100.00
0005433962168	6881	Economy	7100.00
0005433962160	6881	Economy	7100.00
0005433962181	6881	Economy	7100.00
0005433962191	6881	Economy	7100.00
0005433962193	6881	Economy	7100.00
0005433962152	6881	Economy	7100.00
0005433962186	6881	Economy	7100.00
0005433962197	6881	Economy	7100.00
0005433962198	6881	Economy	7100.00
0005433962184	6881	Economy	7100.00
0005433962147	6881	Economy	7100.00
0005433962196	6881	Economy	7100.00
0005433962159	6881	Economy	7100.00
0005433962157	6881	Economy	7100.00
0005433962155	6881	Economy	7100.00
0005433962176	6881	Economy	7100.00
0005433962185	6881	Economy	7100.00
0005433962153	6881	Economy	7100.00
0005433962179	6881	Economy	7100.00
0005433962169	6881	Economy	7100.00
0005433962163	6881	Economy	7100.00
0005433962170	6881	Economy	7100.00
0005433962148	6881	Economy	7100.00
0005433962174	6881	Economy	7100.00
0005433962156	6881	Economy	7100.00
0005433962158	6881	Economy	7100.00
0005433962178	6881	Economy	7100.00
0005433962167	6881	Economy	7100.00
0005433962164	6881	Economy	7100.00
0005433962154	6881	Economy	7100.00
0005433961475	25789	Business	21400.00
0005433961426	25789	Business	21400.00
0005433961521	25789	Business	21400.00
0005433961481	25789	Business	21400.00
0005433961526	25789	Business	21400.00
0005433961452	25789	Business	21400.00
0005433961541	25789	Business	21400.00
0005433961472	25789	Business	21400.00
0005433961384	25789	Business	21400.00
0005433961579	25789	Business	21400.00
0005433961486	25789	Economy	7100.00
0005433961511	25789	Economy	7100.00
0005433961563	25789	Economy	7100.00
0005433961505	25789	Economy	7100.00
0005433961397	25789	Economy	7800.00
0005433961451	25789	Economy	7800.00
0005433961473	25789	Economy	7100.00
0005433961408	25789	Economy	7100.00
0005433961328	25789	Economy	7100.00
0005433961364	25789	Economy	7100.00
0005433961443	25789	Economy	7100.00
0005433961423	25789	Economy	7100.00
0005433961363	25789	Economy	7100.00
0005433961500	25789	Economy	7100.00
0005433961383	25789	Economy	7100.00
0005433961570	25789	Economy	7100.00
0005433961569	25789	Economy	7100.00
0005433961568	25789	Economy	7100.00
0005433961509	25789	Economy	7100.00
0005433961506	25789	Economy	7100.00
0005433961512	25789	Economy	7100.00
0005433961398	25789	Economy	7100.00
0005433961520	25789	Economy	7100.00
0005433961407	25789	Economy	7100.00
0005433961479	25789	Economy	7100.00
0005433961444	25789	Economy	7100.00
0005433961599	25789	Economy	7100.00
0005433961580	25789	Economy	7100.00
0005433961572	25789	Economy	7100.00
0005433961470	25789	Economy	7100.00
0005433961510	25789	Economy	7100.00
0005433961422	25789	Economy	7100.00
0005433961406	25789	Economy	7100.00
0005433961499	25789	Economy	7100.00
0005433961547	25789	Economy	7100.00
0005433961334	25789	Economy	7100.00
0005433961424	25789	Economy	7100.00
0005433961433	25789	Economy	7100.00
0005433961446	25789	Economy	7100.00
0005433961496	25789	Economy	7100.00
0005433961582	25789	Economy	7100.00
0005433961581	25789	Economy	7100.00
0005435082893	24468	Economy	3900.00
0005435082894	24468	Economy	3900.00
0005435082869	24468	Economy	3900.00
0005435082892	24468	Economy	3900.00
0005435082900	24468	Economy	3900.00
0005435082897	24468	Economy	3900.00
0005435082891	24468	Economy	3900.00
0005435082965	26128	Economy	3900.00
0005435082961	26128	Economy	3900.00
0005435082967	26128	Economy	3900.00
0005435082958	26128	Economy	3900.00
0005435082964	26128	Economy	3900.00
0005435082962	26128	Economy	3900.00
0005435082960	26128	Economy	3900.00
0005435082959	26128	Economy	3900.00
0005435082963	26128	Economy	3900.00
0005435082966	26128	Economy	3900.00
0005434245628	5186	Business	18000.00
0005434245638	5186	Business	18000.00
0005434245635	5186	Business	18000.00
0005434245642	5186	Business	18000.00
0005434245653	5186	Business	18000.00
0005433534529	5186	Business	18000.00
0005435286708	5186	Business	18000.00
0005434245631	5186	Business	18000.00
0005432166977	5186	Economy	6600.00
0005434245633	5186	Economy	6600.00
0005434245643	5186	Economy	6000.00
0005434245639	5186	Economy	6000.00
0005434245640	5186	Economy	6000.00
0005434245645	5186	Economy	6000.00
0005433534528	5186	Economy	6000.00
0005435286697	5186	Economy	6000.00
0005434245652	5186	Economy	6000.00
0005434245632	5186	Economy	6000.00
0005434245650	5186	Economy	6000.00
0005434245636	5186	Economy	6000.00
0005432166975	5186	Economy	6000.00
0005434245646	5186	Economy	6000.00
0005432166973	5186	Economy	6000.00
0005433534531	5186	Economy	6000.00
0005434245648	5186	Economy	6000.00
0005434245654	5186	Economy	6000.00
0005435286696	5186	Economy	6000.00
0005434245644	5186	Economy	6000.00
0005434245656	5186	Economy	6600.00
0005433534527	5186	Economy	6600.00
0005434245657	5186	Economy	6000.00
0005434245637	5186	Economy	6000.00
0005434245641	5186	Economy	6000.00
0005435286698	5186	Economy	6000.00
0005434245647	5186	Economy	6000.00
0005433534522	5186	Economy	6000.00
0005434245651	5186	Economy	6000.00
0005434245634	5186	Economy	6000.00
0005434245630	5186	Economy	6000.00
0005432166974	5186	Economy	6000.00
0005434245658	5186	Economy	6000.00
0005434245629	5186	Economy	6000.00
0005434245659	5186	Economy	6000.00
0005432166976	5186	Economy	6000.00
0005434245649	5186	Economy	6000.00
0005434245655	5186	Economy	6000.00
0005432665320	5187	Business	18000.00
0005432106654	5187	Business	18000.00
0005433785756	5187	Business	18000.00
0005432106649	5187	Business	18000.00
0005432106665	5187	Business	18000.00
0005433785760	5187	Business	18000.00
0005433616362	5187	Business	18000.00
0005433616376	5187	Business	18000.00
0005433785747	5187	Business	18000.00
0005433616307	5187	Business	18000.00
0005433616368	5187	Business	18000.00
0005433785771	5187	Business	18000.00
0005433616351	5187	Business	18000.00
0005433785773	5187	Business	18000.00
0005433616332	5187	Business	18000.00
0005432145158	5187	Business	18000.00
0005432667501	5187	Business	18000.00
0005433785767	5187	Business	18000.00
0005432106640	5187	Business	18000.00
0005432145157	5187	Business	18000.00
0005433616310	5187	Business	18000.00
0005432106642	5187	Business	18000.00
0005433785780	5187	Business	18000.00
0005432106627	5187	Business	18000.00
0005433785776	5187	Business	18000.00
0005432106626	5187	Business	18000.00
0005433616366	5187	Business	18000.00
0005433785764	5187	Business	18000.00
0005433785759	5187	Economy	6600.00
0005433616327	5187	Economy	6600.00
0005432106621	5187	Economy	6600.00
0005433616335	5187	Economy	6600.00
0005432106637	5187	Economy	6600.00
0005432106625	5187	Economy	6600.00
0005433616352	5187	Economy	6000.00
0005433616330	5187	Economy	6000.00
0005433616339	5187	Economy	6000.00
0005433616365	5187	Economy	6000.00
0005432106635	5187	Economy	6000.00
0005432106648	5187	Economy	6000.00
0005432665322	5187	Economy	6000.00
0005433616354	5187	Economy	6000.00
0005433616369	5187	Economy	6000.00
0005433785770	5187	Economy	6000.00
0005433616358	5187	Economy	6000.00
0005433616319	5187	Economy	6000.00
0005433616355	5187	Economy	6000.00
0005433616367	5187	Economy	6000.00
0005432106657	5187	Economy	6000.00
0005433616346	5187	Economy	6000.00
0005433785754	5187	Economy	6000.00
0005432106644	5187	Economy	6000.00
0005433616345	5187	Economy	6000.00
0005433616341	5187	Economy	6000.00
0005433616373	5187	Economy	6000.00
0005433616356	5187	Economy	6000.00
0005433616363	5187	Economy	6000.00
0005433616309	5187	Economy	6000.00
0005433616375	5187	Economy	6000.00
0005433785778	5187	Economy	6000.00
0005433785772	5187	Economy	6000.00
0005432106630	5187	Economy	6000.00
0005432666435	5187	Economy	6000.00
0005433616326	5187	Economy	6000.00
0005433616359	5187	Economy	6000.00
0005433785758	5187	Economy	6000.00
0005433785765	5187	Economy	6000.00
0005433616378	5187	Economy	6000.00
0005433785762	5187	Economy	6000.00
0005432665321	5187	Economy	6000.00
0005433616374	5187	Economy	6000.00
0005433616360	5187	Economy	6000.00
0005433616334	5187	Economy	6000.00
0005433785769	5187	Economy	6000.00
0005433616370	5187	Economy	6000.00
0005432667503	5187	Economy	6000.00
0005433616344	5187	Economy	6000.00
0005432106658	5187	Economy	6000.00
0005433785750	5187	Economy	6000.00
0005432106638	5187	Economy	6000.00
0005433616338	5187	Economy	6000.00
0005432106647	5187	Economy	6000.00
0005432106666	5187	Economy	6000.00
0005433616318	5187	Economy	6000.00
0005432106623	5187	Economy	6000.00
0005432106650	5187	Economy	6000.00
0005432106633	5187	Economy	6000.00
0005432106669	5187	Economy	6000.00
0005433616377	5187	Economy	6000.00
0005433616311	5187	Economy	6000.00
0005432106655	5187	Economy	6000.00
0005432106645	5187	Economy	6000.00
0005433616329	5187	Economy	6000.00
0005433616316	5187	Economy	6000.00
0005433616320	5187	Economy	6600.00
0005433785751	5187	Economy	6600.00
0005432106622	5187	Economy	6600.00
0005433616342	5187	Economy	6600.00
0005432106660	5187	Economy	6600.00
0005432106634	5187	Economy	6000.00
0005433785768	5187	Economy	6000.00
0005432106624	5187	Economy	6000.00
0005433785755	5187	Economy	6000.00
0005433785763	5187	Economy	6600.00
0005433616312	5187	Economy	6000.00
0005433616372	5187	Economy	6000.00
0005433785777	5187	Economy	6000.00
0005433616340	5187	Economy	6000.00
0005433616314	5187	Economy	6000.00
0005433616336	5187	Economy	6000.00
0005432667502	5187	Economy	6000.00
0005432106663	5187	Economy	6000.00
0005433616348	5187	Economy	6000.00
0005433616347	5187	Economy	6000.00
0005432106653	5187	Economy	6000.00
0005433616357	5187	Economy	6000.00
0005433785748	5187	Economy	6000.00
0005433616349	5187	Economy	6000.00
0005432106664	5187	Economy	6000.00
0005433616333	5187	Economy	6000.00
0005432106628	5187	Economy	6000.00
0005433785752	5187	Economy	6000.00
0005433616371	5187	Economy	6000.00
0005433616353	5187	Economy	6000.00
0005433616361	5187	Economy	6000.00
0005432106656	5187	Economy	6000.00
0005433785779	5187	Economy	6000.00
0005432106636	5187	Economy	6000.00
0005432106668	5187	Economy	6000.00
0005432106659	5187	Economy	6000.00
0005432106631	5187	Economy	6000.00
0005432106629	5187	Economy	6000.00
0005433616350	5187	Economy	6000.00
0005433785775	5187	Economy	6000.00
0005432106667	5187	Economy	6000.00
0005433616331	5187	Economy	6000.00
0005433616317	5187	Economy	6000.00
0005433616306	5187	Economy	6000.00
0005433785757	5187	Economy	6000.00
0005433616315	5187	Economy	6000.00
0005433785749	5187	Economy	6000.00
0005432667500	5187	Economy	6000.00
0005432106661	5187	Economy	6000.00
0005433785766	5187	Economy	6000.00
0005433785761	5187	Economy	6000.00
0005432106639	5187	Economy	6000.00
0005433616328	5187	Economy	6000.00
0005432106652	5187	Economy	6000.00
0005433785753	5187	Economy	6000.00
0005432106632	5187	Economy	6000.00
0005432106646	5187	Economy	6000.00
0005432106643	5187	Economy	6000.00
0005432106641	5187	Economy	6000.00
0005433616305	5187	Economy	6000.00
0005433616325	5187	Economy	6000.00
0005433616321	5187	Economy	6000.00
0005433616337	5187	Economy	6000.00
0005433616343	5187	Economy	6000.00
0005432665323	5187	Economy	6000.00
0005433616324	5187	Economy	6000.00
0005433785774	5187	Economy	6000.00
0005433616322	5187	Economy	6000.00
0005432666436	5187	Economy	6000.00
0005433616308	5187	Economy	6000.00
0005433616323	5187	Economy	6000.00
0005432106662	5187	Economy	6000.00
0005433616313	5187	Economy	6000.00
0005433616364	5187	Economy	6000.00
0005433616379	5187	Economy	6000.00
0005432106651	5187	Economy	6000.00
0005434265711	5189	Business	18000.00
0005434229878	5189	Business	18000.00
0005434149995	5189	Business	18000.00
0005434229879	5189	Business	18000.00
0005435269857	5189	Business	18000.00
0005434311252	5189	Business	18000.00
0005433815444	5189	Business	18000.00
0005434311250	5189	Business	18000.00
0005434265716	5189	Business	18000.00
0005434265719	5189	Business	18000.00
0005434149999	5189	Business	18000.00
0005435007371	5189	Business	18000.00
0005434229881	5189	Business	18000.00
0005435007329	5189	Business	18000.00
0005434150002	5189	Business	18000.00
0005434229888	5189	Business	18000.00
0005435269845	5189	Business	18000.00
0005435269860	5189	Business	18000.00
0005434149993	5189	Business	18000.00
0005432336185	5189	Business	18000.00
0005435269856	5189	Business	18000.00
0005434312355	5189	Economy	6600.00
0005434149998	5189	Economy	6600.00
0005433688846	5189	Economy	6600.00
0005434265726	5189	Economy	6600.00
0005432336238	5189	Economy	6000.00
0005434265727	5189	Economy	6600.00
0005433815450	5189	Economy	6000.00
0005435007366	5189	Economy	6000.00
0005434229877	5189	Economy	6000.00
0005434265712	5189	Economy	6000.00
0005434265730	5189	Economy	6000.00
0005434265725	5189	Economy	6000.00
0005435007252	5189	Economy	6000.00
0005434229871	5189	Economy	6000.00
0005435007364	5189	Economy	6000.00
0005434265718	5189	Economy	6000.00
0005434265715	5189	Economy	6000.00
0005434149994	5189	Economy	6000.00
0005434265721	5189	Economy	6000.00
0005433815455	5189	Economy	6000.00
0005434265708	5189	Economy	6000.00
0005435269858	5189	Economy	6000.00
0005435007293	5189	Economy	6000.00
0005434229873	5189	Economy	6000.00
0005434265728	5189	Economy	6000.00
0005434265707	5189	Economy	6000.00
0005434173611	5189	Economy	6000.00
0005434265709	5189	Economy	6000.00
0005435269865	5189	Economy	6000.00
0005434265714	5189	Economy	6000.00
0005434149997	5189	Economy	6000.00
0005434150001	5189	Economy	6000.00
0005434311242	5189	Economy	6000.00
0005434229883	5189	Economy	6000.00
0005434173641	5189	Economy	6000.00
0005434265724	5189	Economy	6000.00
0005435007325	5189	Economy	6000.00
0005435007365	5189	Economy	6000.00
0005434173610	5189	Economy	6000.00
0005435269859	5189	Economy	6000.00
0005433688833	5189	Economy	6000.00
0005433688832	5189	Economy	6000.00
0005434173609	5189	Economy	6000.00
0005434265729	5189	Economy	6000.00
0005435269862	5189	Economy	6000.00
0005433815454	5189	Economy	6000.00
0005432336221	5189	Economy	6000.00
0005433688847	5189	Economy	6000.00
0005435269871	5189	Economy	6000.00
0005435269870	5189	Economy	6000.00
0005434173638	5189	Economy	6000.00
0005434229882	5189	Economy	6000.00
0005435007347	5189	Economy	6600.00
0005435269867	5189	Economy	6600.00
0005435269863	5189	Economy	6600.00
0005433688831	5189	Economy	6600.00
0005435007346	5189	Economy	6600.00
0005435269864	5189	Economy	6000.00
0005434229880	5189	Economy	6000.00
0005434229872	5189	Economy	6000.00
0005434265710	5189	Economy	6000.00
0005435269869	5189	Economy	6600.00
0005433815439	5189	Economy	6000.00
0005434229884	5189	Economy	6000.00
0005435007381	5189	Economy	6000.00
0005435269868	5189	Economy	6000.00
0005432336251	5189	Economy	6000.00
0005435007348	5189	Economy	6000.00
0005434265722	5189	Economy	6000.00
0005434229870	5189	Economy	6000.00
0005434265723	5189	Economy	6000.00
0005434311251	5189	Economy	6000.00
0005435007372	5189	Economy	6000.00
0005435007336	5189	Economy	6000.00
0005434229886	5189	Economy	6000.00
0005434229890	5189	Economy	6000.00
0005432336258	5189	Economy	6000.00
0005434229869	5189	Economy	6000.00
0005433815425	5189	Economy	6000.00
0005434229885	5189	Economy	6000.00
0005434265720	5189	Economy	6000.00
0005435269842	5189	Economy	6000.00
0005434265717	5189	Economy	6000.00
0005432336190	5189	Economy	6000.00
0005435007386	5189	Economy	6000.00
0005433688842	5189	Economy	6000.00
0005434150000	5189	Economy	6000.00
0005435007351	5189	Economy	6000.00
0005434229874	5189	Economy	6000.00
0005434229875	5189	Economy	6000.00
0005434229887	5189	Economy	6000.00
0005432336189	5189	Economy	6000.00
0005433815449	5189	Economy	6000.00
0005434265731	5189	Economy	6000.00
0005434229876	5189	Economy	6000.00
0005435007298	5189	Economy	6000.00
0005434149996	5189	Economy	6000.00
0005434173640	5189	Economy	6000.00
0005434265732	5189	Economy	6000.00
0005433815440	5189	Economy	6000.00
0005435269819	5189	Economy	6000.00
0005434265713	5189	Economy	6000.00
0005434311253	5189	Economy	6000.00
0005435269861	5189	Economy	6000.00
0005434229868	5189	Economy	6000.00
0005434265706	5189	Economy	6000.00
0005435007359	5189	Economy	6000.00
0005435007299	5189	Economy	6000.00
0005434229889	5189	Economy	6000.00
0005434173639	5189	Economy	6000.00
0005433815438	5189	Economy	6000.00
0005433785501	8615	Business	18000.00
0005435269960	8615	Business	18000.00
0005433785379	8615	Business	18000.00
0005433785539	8615	Business	18000.00
0005434245401	8615	Business	18000.00
0005434245384	8615	Business	18000.00
0005433785355	8615	Business	18000.00
0005433785540	8615	Business	18000.00
0005433785184	8615	Business	18000.00
0005434245469	8615	Business	18000.00
0005434245459	8615	Business	18000.00
0005434245271	8615	Business	18000.00
0005435269971	8615	Business	18000.00
0005432666420	8615	Business	18000.00
0005435269952	8615	Business	18000.00
0005435269970	8615	Business	18000.00
0005434245433	8615	Business	18000.00
0005433785481	8615	Business	18000.00
0005435269969	8615	Business	18000.00
0005434245385	8615	Business	18000.00
0005434245506	8615	Business	18000.00
0005434245359	8615	Business	18000.00
0005433785433	8615	Business	18000.00
0005435269967	8615	Economy	6600.00
0005434245493	8615	Economy	6600.00
0005433785365	8615	Economy	6600.00
0005435269953	8615	Economy	6600.00
0005433785464	8615	Economy	6000.00
0005435269947	8615	Economy	6000.00
0005433785364	8615	Economy	6000.00
0005433785321	8615	Economy	6000.00
0005434245404	8615	Economy	6000.00
0005435269959	8615	Economy	6000.00
0005432666396	8615	Economy	6000.00
0005435269948	8615	Economy	6000.00
0005435269949	8615	Economy	6000.00
0005433785352	8615	Economy	6000.00
0005435269954	8615	Economy	6000.00
0005434245393	8615	Economy	6000.00
0005435269961	8615	Economy	6000.00
0005434245395	8615	Economy	6000.00
0005435269965	8615	Economy	6000.00
0005434245440	8615	Economy	6000.00
0005434245457	8615	Economy	6000.00
0005433785397	8615	Economy	6000.00
0005433785427	8615	Economy	6000.00
0005433785628	8615	Economy	6000.00
0005433785554	8615	Economy	6000.00
0005434245342	8615	Economy	6000.00
0005434245278	8615	Economy	6000.00
0005433785498	8615	Economy	6000.00
0005433785455	8615	Economy	6000.00
0005433785461	8615	Economy	6000.00
0005432666421	8615	Economy	6000.00
0005434245341	8615	Economy	6000.00
0005434245380	8615	Economy	6000.00
0005433785482	8615	Economy	6000.00
0005435269951	8615	Economy	6600.00
0005433785185	8615	Economy	6600.00
0005434245288	8615	Economy	6000.00
0005435269950	8615	Economy	6000.00
0005433785375	8615	Economy	6000.00
0005432666415	8615	Economy	6000.00
0005433785356	8615	Economy	6000.00
0005432663064	8615	Economy	6000.00
0005432666413	8615	Economy	6000.00
0005433785456	8615	Economy	6000.00
0005433785313	8615	Economy	6000.00
0005435269957	8615	Economy	6000.00
0005434245432	8615	Economy	6000.00
0005433785490	8615	Economy	6000.00
0005433785513	8615	Economy	6000.00
0005434245496	8615	Economy	6000.00
0005433785392	8615	Economy	6000.00
0005435269964	8615	Economy	6000.00
0005434245400	8615	Economy	6000.00
0005434245492	8615	Economy	6000.00
0005434245399	8615	Economy	6000.00
0005434245381	8615	Economy	6000.00
0005435269958	8615	Economy	6000.00
0005435269963	8615	Economy	6000.00
0005433785378	8615	Economy	6000.00
0005434245340	8615	Economy	6000.00
0005435269956	8615	Economy	6000.00
0005435269955	8615	Economy	6000.00
0005435269972	8615	Economy	6000.00
0005434245272	8615	Economy	6000.00
0005435269968	8615	Economy	6000.00
0005435269966	8615	Economy	6000.00
0005433785530	8615	Economy	6000.00
0005434245528	8615	Economy	6000.00
0005434245458	8615	Economy	6000.00
0005434245507	8615	Economy	6000.00
0005434245494	8615	Economy	6000.00
0005435269962	8615	Economy	6000.00
0005433785440	8615	Economy	6000.00
0005433785459	8615	Economy	6000.00
0005434245439	8615	Economy	6000.00
0005433785328	8615	Economy	6000.00
0005433615588	8616	Business	18000.00
0005433615356	8616	Business	18000.00
0005433615680	8616	Business	18000.00
0005433615674	8616	Business	18000.00
0005433615303	8616	Business	18000.00
0005433615496	8616	Business	18000.00
0005433615518	8616	Business	18000.00
0005433615550	8616	Business	18000.00
0005433615743	8616	Business	18000.00
0005433615911	8616	Business	18000.00
0005433615350	8616	Business	18000.00
0005433615467	8616	Business	18000.00
0005433615370	8616	Economy	6600.00
0005433615559	8616	Economy	6600.00
0005433615848	8616	Economy	6600.00
0005433615695	8616	Economy	6600.00
0005433615560	8616	Economy	6600.00
0005433615698	8616	Economy	6600.00
0005433615501	8616	Economy	6000.00
0005433615816	8616	Economy	6000.00
0005433615712	8616	Economy	6000.00
0005433615432	8616	Economy	6000.00
0005433615685	8616	Economy	6000.00
0005433615893	8616	Economy	6000.00
0005433615679	8616	Economy	6000.00
0005433615648	8616	Economy	6000.00
0005433615468	8616	Economy	6000.00
0005433615632	8616	Economy	6000.00
0005433615456	8616	Economy	6000.00
0005433615815	8616	Economy	6000.00
0005433615894	8616	Economy	6000.00
0005433615418	8616	Economy	6000.00
0005433615622	8616	Economy	6000.00
0005433615783	8616	Economy	6000.00
0005433615789	8616	Economy	6000.00
0005433615517	8616	Economy	6000.00
0005433615836	8616	Economy	6000.00
0005433615700	8616	Economy	6000.00
0005433615738	8616	Economy	6000.00
0005433615516	8616	Economy	6000.00
0005433615433	8616	Economy	6000.00
0005433615748	8616	Economy	6000.00
0005433615379	8616	Economy	6000.00
0005433615736	8616	Economy	6600.00
0005433615635	8616	Economy	6000.00
0005433615825	8616	Economy	6000.00
0005433615767	8616	Economy	6000.00
0005433615448	8616	Economy	6000.00
0005433615837	8616	Economy	6000.00
0005433615855	8616	Economy	6000.00
0005433615768	8616	Economy	6000.00
0005433615541	8616	Economy	6000.00
0005433615476	8616	Economy	6000.00
0005433615784	8616	Economy	6000.00
0005433615660	8616	Economy	6000.00
0005433615656	8616	Economy	6000.00
0005433615449	8616	Economy	6000.00
0005433615729	8616	Economy	6000.00
0005433615675	8616	Economy	6000.00
0005433615564	8616	Economy	6000.00
0005433615457	8616	Economy	6000.00
0005433615549	8616	Economy	6000.00
0005433615569	8616	Economy	6000.00
0005433615638	8616	Economy	6000.00
0005433615639	8616	Economy	6000.00
0005433615668	8616	Economy	6000.00
0005433615514	8616	Economy	6000.00
0005433615587	8616	Economy	6000.00
0005433615586	8616	Economy	6000.00
0005433615515	8616	Economy	6000.00
0005433615982	8616	Economy	6000.00
0005433615657	8616	Economy	6000.00
0005433615735	8616	Economy	6000.00
0005433615617	8616	Economy	6000.00
0005433615621	8616	Economy	6000.00
0005433615838	8616	Economy	6000.00
0005433615483	8616	Economy	6000.00
0005433615699	8616	Economy	6000.00
0005433615565	8616	Economy	6000.00
0005433615429	8616	Economy	6000.00
0005433615404	8616	Economy	6000.00
0005433615369	8616	Economy	6000.00
0005433615684	8616	Economy	6000.00
0005433615380	8616	Economy	6000.00
0005433615737	8616	Economy	6000.00
0005433615719	8616	Economy	6000.00
0005433615681	8616	Economy	6000.00
0005435007552	8617	Business	18000.00
0005434265495	8617	Business	18000.00
0005434173567	8617	Business	18000.00
0005433690971	8617	Business	18000.00
0005434229657	8617	Business	18000.00
0005435286747	8617	Business	18000.00
0005434173585	8617	Business	18000.00
0005432336303	8617	Business	18000.00
0005432336302	8617	Business	18000.00
0005435286740	8617	Business	18000.00
0005435007551	8617	Business	18000.00
0005432035571	8617	Business	18000.00
0005434149924	8617	Business	18000.00
0005435007563	8617	Business	18000.00
0005434149853	8617	Business	18000.00
0005432035573	8617	Business	18000.00
0005432035565	8617	Business	18000.00
0005435007540	8617	Business	18000.00
0005434229688	8617	Business	18000.00
0005435007555	8617	Business	18000.00
0005433815538	8617	Business	18000.00
0005432336300	8617	Business	18000.00
0005432035584	8617	Business	18000.00
0005432035579	8617	Business	18000.00
0005435286738	8617	Business	18000.00
0005434229689	8617	Economy	6600.00
0005432035564	8617	Business	18000.00
0005432035585	8617	Economy	6600.00
0005434149881	8617	Economy	6600.00
0005434265470	8617	Economy	6600.00
0005435007554	8617	Economy	6600.00
0005432035567	8617	Economy	6600.00
0005432035576	8617	Economy	6000.00
0005434265475	8617	Economy	6000.00
0005432047633	8617	Economy	6000.00
0005432336299	8617	Economy	6000.00
0005434265380	8617	Economy	6000.00
0005434229706	8617	Economy	6000.00
0005433688856	8617	Economy	6000.00
0005434173587	8617	Economy	6000.00
0005435007542	8617	Economy	6000.00
0005433689959	8617	Economy	6000.00
0005433815539	8617	Economy	6000.00
0005434265457	8617	Economy	6000.00
0005434229728	8617	Economy	6000.00
0005432035581	8617	Economy	6000.00
0005434265529	8617	Economy	6000.00
0005432035570	8617	Economy	6000.00
0005434173568	8617	Economy	6000.00
0005434265471	8617	Economy	6000.00
0005433815495	8617	Economy	6000.00
0005434265474	8617	Economy	6000.00
0005434229656	8617	Economy	6000.00
0005434229722	8617	Economy	6000.00
0005434311266	8617	Economy	6000.00
0005435007545	8617	Economy	6000.00
0005434149919	8617	Economy	6000.00
0005435286744	8617	Economy	6000.00
0005433688858	8617	Economy	6000.00
0005434229670	8617	Economy	6000.00
0005435286736	8617	Economy	6000.00
0005435286742	8617	Economy	6000.00
0005435007548	8617	Economy	6000.00
0005435286735	8617	Economy	6000.00
0005435286741	8617	Economy	6000.00
0005434265381	8617	Economy	6000.00
0005434311263	8617	Economy	6000.00
0005435286743	8617	Economy	6000.00
0005434311264	8617	Economy	6000.00
0005435007558	8617	Economy	6000.00
0005434265395	8617	Economy	6000.00
0005432336305	8617	Economy	6000.00
0005435007541	8617	Economy	6000.00
0005434229707	8617	Economy	6000.00
0005434265501	8617	Economy	6000.00
0005434265472	8617	Economy	6000.00
0005434149844	8617	Economy	6000.00
0005435007546	8617	Economy	6000.00
0005434265566	8617	Economy	6000.00
0005432035566	8617	Economy	6000.00
0005432336308	8617	Economy	6000.00
0005434149938	8617	Economy	6000.00
0005434265379	8617	Economy	6000.00
0005435007550	8617	Economy	6000.00
0005435007559	8617	Economy	6000.00
0005434265565	8617	Economy	6000.00
0005432035572	8617	Economy	6000.00
0005433815497	8617	Economy	6000.00
0005432336309	8617	Economy	6000.00
0005432035580	8617	Economy	6000.00
0005435286746	8617	Economy	6600.00
0005435286745	8617	Economy	6600.00
0005434265490	8617	Economy	6600.00
0005433534547	8617	Economy	6600.00
0005432035582	8617	Economy	6600.00
0005432336304	8617	Economy	6000.00
0005434265496	8617	Economy	6000.00
0005432035562	8617	Economy	6000.00
0005434149959	8617	Economy	6000.00
0005434265519	8617	Economy	6600.00
0005434229735	8617	Economy	6000.00
0005434229780	8617	Economy	6000.00
0005432035583	8617	Economy	6000.00
0005434265500	8617	Economy	6000.00
0005434149918	8617	Economy	6000.00
0005433815496	8617	Economy	6000.00
0005432035587	8617	Economy	6000.00
0005434311265	8617	Economy	6000.00
0005433688857	8617	Economy	6000.00
0005434149883	8617	Economy	6000.00
0005432336301	8617	Economy	6000.00
0005434265531	8617	Economy	6000.00
0005434229781	8617	Economy	6000.00
0005432047634	8617	Economy	6000.00
0005432336307	8617	Economy	6000.00
0005432035575	8617	Economy	6000.00
0005435286737	8617	Economy	6000.00
0005434265520	8617	Economy	6000.00
0005433690972	8617	Economy	6000.00
0005435007562	8617	Economy	6000.00
0005432336298	8617	Economy	6000.00
0005432035577	8617	Economy	6000.00
0005435007553	8617	Economy	6000.00
0005432035574	8617	Economy	6000.00
0005435007547	8617	Economy	6000.00
0005432035569	8617	Economy	6000.00
0005433815540	8617	Economy	6000.00
0005432047636	8617	Economy	6000.00
0005433815494	8617	Economy	6000.00
0005432047635	8617	Economy	6000.00
0005432336306	8617	Economy	6000.00
0005434149888	8617	Economy	6000.00
0005435007561	8617	Economy	6000.00
0005435007544	8617	Economy	6000.00
0005435286739	8617	Economy	6000.00
0005432035586	8617	Economy	6000.00
0005434229567	8617	Economy	6000.00
0005434229748	8617	Economy	6000.00
0005435007557	8617	Economy	6000.00
0005434229738	8617	Economy	6000.00
0005435007560	8617	Economy	6000.00
0005434265458	8617	Economy	6000.00
0005434149880	8617	Economy	6000.00
0005433534546	8617	Economy	6000.00
0005434149842	8617	Economy	6000.00
0005434265585	8617	Economy	6000.00
0005432035563	8617	Economy	6000.00
0005434173584	8617	Economy	6000.00
0005433690970	8617	Economy	6000.00
0005435007549	8617	Economy	6000.00
0005434265394	8617	Economy	6000.00
0005435007543	8617	Economy	6000.00
0005433815541	8617	Economy	6000.00
0005432035568	8617	Economy	6000.00
0005432035578	8617	Economy	6000.00
0005434149882	8617	Economy	6000.00
0005434229705	8617	Economy	6000.00
0005435286748	8617	Economy	6000.00
0005435007556	8617	Economy	6000.00
0005434639719	12613	Economy	16200.00
0005434639599	12613	Economy	16200.00
0005434639770	12613	Economy	16200.00
0005434639613	12613	Economy	16200.00
0005433202692	12613	Economy	14800.00
0005434639609	12613	Economy	14800.00
0005434639699	12613	Economy	14800.00
0005433202700	12613	Economy	14800.00
0005434639697	12613	Economy	14800.00
0005433202694	12613	Economy	14800.00
0005433202702	12613	Economy	14800.00
0005433202698	12613	Economy	14800.00
0005433202699	12613	Economy	14800.00
0005434639612	12613	Economy	14800.00
0005434639610	12613	Economy	14800.00
0005434639632	12613	Economy	14800.00
0005433202691	12613	Economy	14800.00
0005434639634	12613	Economy	14800.00
0005434639740	12613	Economy	14800.00
0005433202695	12613	Economy	14800.00
0005434639738	12613	Economy	14800.00
0005434639633	12613	Economy	14800.00
0005434639769	12613	Economy	14800.00
0005434639727	12613	Economy	14800.00
0005434639695	12613	Economy	14800.00
0005434639754	12613	Economy	14800.00
0005434639768	12613	Economy	14800.00
0005434639739	12613	Economy	14800.00
0005434639728	12613	Economy	14800.00
0005433202703	12613	Economy	14800.00
0005434639698	12613	Economy	14800.00
0005434639576	12613	Economy	14800.00
0005433202696	12613	Economy	14800.00
0005433202701	12613	Economy	14800.00
0005433202690	12613	Economy	14800.00
0005433202697	12613	Economy	14800.00
0005434639677	12613	Economy	14800.00
0005434639726	12613	Economy	14800.00
0005434639583	12613	Economy	14800.00
0005433202689	12613	Economy	14800.00
0005434639735	12613	Economy	14800.00
0005434639611	12613	Economy	14800.00
0005433202693	12613	Economy	14800.00
0005434639645	12613	Economy	14800.00
0005434639532	12613	Economy	14800.00
0005434639575	12613	Economy	14800.00
0005433202514	23368	Economy	16200.00
0005434639871	23368	Economy	16200.00
0005434639886	23368	Economy	16200.00
0005432290701	23368	Economy	14800.00
0005434639876	23368	Economy	14800.00
0005433202581	23368	Economy	14800.00
0005433202582	23368	Economy	14800.00
0005434639883	23368	Economy	14800.00
0005433202541	23368	Economy	14800.00
0005433202515	23368	Economy	14800.00
0005433202497	23368	Economy	14800.00
0005433202571	23368	Economy	14800.00
0005434639889	23368	Economy	14800.00
0005434639878	23368	Economy	14800.00
0005433202489	23368	Economy	14800.00
0005433202608	23368	Economy	14800.00
0005433202488	23368	Economy	14800.00
0005434639888	23368	Economy	14800.00
0005434639884	23368	Economy	14800.00
0005433202586	23368	Economy	14800.00
0005432290700	23368	Economy	14800.00
0005434639872	23368	Economy	14800.00
0005433202592	23368	Economy	14800.00
0005433202573	23368	Economy	14800.00
0005434639875	23368	Economy	14800.00
0005434639880	23368	Economy	14800.00
0005434639885	23368	Economy	14800.00
0005433202595	23368	Economy	14800.00
0005434639882	23368	Economy	14800.00
0005433202594	23368	Economy	14800.00
0005433202587	23368	Economy	14800.00
0005433202565	23368	Economy	14800.00
0005434639873	23368	Economy	14800.00
0005434639874	23368	Economy	14800.00
0005434639877	23368	Economy	14800.00
0005433202580	23368	Economy	14800.00
0005434639887	23368	Economy	14800.00
0005433202579	23368	Economy	14800.00
0005434639879	23368	Economy	14800.00
0005434639870	23368	Economy	14800.00
0005433202593	23368	Economy	14800.00
0005433202498	23368	Economy	14800.00
0005433202552	23368	Economy	14800.00
0005434639869	23368	Economy	14800.00
0005432290702	23368	Economy	14800.00
0005433202572	23368	Economy	14800.00
0005434639881	23368	Economy	14800.00
0005432383695	21098	Business	18900.00
0005432848881	21098	Business	18900.00
0005432329312	21098	Business	18900.00
0005432329345	21098	Business	18900.00
0005432383681	21098	Business	18900.00
0005432383803	21098	Business	18900.00
0005432329225	21098	Business	18900.00
0005432329322	21098	Business	18900.00
0005432383678	21098	Business	18900.00
0005432848882	21098	Business	18900.00
0005432383588	21098	Business	18900.00
0005432329360	21098	Economy	6300.00
0005432383711	21098	Economy	6300.00
0005432329313	21098	Economy	6300.00
0005432329248	21098	Economy	6300.00
0005432848887	21098	Economy	6300.00
0005432383563	21098	Economy	6300.00
0005432329171	21098	Economy	6300.00
0005432383679	21098	Economy	6300.00
0005432848885	21098	Economy	6300.00
0005432329223	21098	Economy	6300.00
0005432329235	21098	Economy	6900.00
0005432329210	21098	Economy	6900.00
0005432383723	21098	Economy	6900.00
0005432054370	21098	Economy	6900.00
0005432383558	21098	Economy	6900.00
0005432054372	21098	Economy	6300.00
0005432329259	21098	Economy	6300.00
0005432054371	21098	Economy	6300.00
0005432329517	21098	Economy	6300.00
0005432329253	21098	Economy	6300.00
0005432329469	21098	Economy	6300.00
0005432328990	21098	Economy	6300.00
0005432383623	21098	Economy	6300.00
0005432383548	21098	Economy	6300.00
0005432329222	21098	Economy	6300.00
0005432383571	21098	Economy	6300.00
0005432329422	21098	Economy	6300.00
0005432848888	21098	Economy	6300.00
0005432329211	21098	Economy	6300.00
0005432329328	21098	Economy	6300.00
0005432383610	21098	Economy	6300.00
0005432329335	21098	Economy	6300.00
0005432383705	21098	Economy	6300.00
0005432329307	21098	Economy	6300.00
0005432383718	21098	Economy	6300.00
0005432383677	21098	Economy	6300.00
0005432383773	21098	Economy	6300.00
0005432848886	21098	Economy	6300.00
0005432383611	21098	Economy	6300.00
0005432329468	21098	Economy	6300.00
0005432383635	21098	Economy	6300.00
0005432383684	21098	Economy	6300.00
0005432383693	21098	Economy	6300.00
0005432329254	21098	Economy	6300.00
0005432383624	21098	Economy	6300.00
0005432329175	21098	Economy	6300.00
0005432329278	21098	Economy	6300.00
0005432383557	21098	Economy	6300.00
0005432328984	21098	Economy	6300.00
0005432329346	21098	Economy	6300.00
0005432329334	21098	Economy	6300.00
0005432329174	21098	Economy	6300.00
0005432383612	21098	Economy	6300.00
0005432329226	21098	Economy	6300.00
0005432329353	21098	Economy	6300.00
0005432329308	21098	Economy	6300.00
0005432383654	21098	Economy	6300.00
0005432329247	21098	Economy	6300.00
0005432383636	21098	Economy	6300.00
0005432329388	21098	Economy	6300.00
0005432383667	21098	Economy	6300.00
0005432329427	21098	Economy	6300.00
0005432329340	21098	Economy	6300.00
0005432383694	21098	Economy	6300.00
0005432329279	21098	Economy	6300.00
0005432848884	21098	Economy	6300.00
0005432329387	21098	Economy	6300.00
0005432329526	21098	Economy	6300.00
0005432383660	21098	Economy	6300.00
0005432329274	21098	Economy	6300.00
0005432383701	21098	Economy	6300.00
0005432383831	21098	Economy	6300.00
0005432329516	21098	Economy	6300.00
0005432383656	21098	Economy	6300.00
0005432848883	21098	Economy	6300.00
0005432329258	21098	Economy	6300.00
0005432383589	21098	Economy	6300.00
0005432383609	21098	Economy	6300.00
0005432848880	21098	Economy	6300.00
0005432383666	21098	Economy	6300.00
0005432383810	21098	Economy	6300.00
0005432383761	21098	Economy	6300.00
0005432329355	21098	Economy	6300.00
0005432384011	31271	Business	18900.00
0005432329720	31271	Business	18900.00
0005432384002	31271	Business	18900.00
0005432329716	31271	Business	18900.00
0005432384035	31271	Business	18900.00
0005432329707	31271	Business	18900.00
0005432329713	31271	Business	18900.00
0005432329700	31271	Business	18900.00
0005432329684	31271	Business	18900.00
0005432329714	31271	Business	18900.00
0005432384022	31271	Business	18900.00
0005432329679	31271	Economy	6300.00
0005432384001	31271	Economy	6300.00
0005432384016	31271	Economy	6300.00
0005432384010	31271	Economy	6300.00
0005432384008	31271	Economy	6300.00
0005432329717	31271	Economy	6300.00
0005432329675	31271	Economy	6300.00
0005432329711	31271	Economy	6300.00
0005432329702	31271	Economy	6300.00
0005432329676	31271	Economy	6300.00
0005432329690	31271	Economy	6900.00
0005432329721	31271	Economy	6900.00
0005432384032	31271	Economy	6900.00
0005432383996	31271	Economy	6900.00
0005432329706	31271	Economy	6900.00
0005432384029	31271	Economy	6300.00
0005432329709	31271	Economy	6300.00
0005432329688	31271	Economy	6300.00
0005432329697	31271	Economy	6300.00
0005432329695	31271	Economy	6300.00
0005432384036	31271	Economy	6300.00
0005432329681	31271	Economy	6300.00
0005432329689	31271	Economy	6300.00
0005432287299	31271	Economy	6300.00
0005432329687	31271	Economy	6300.00
0005432329685	31271	Economy	6300.00
0005432329704	31271	Economy	6300.00
0005432384005	31271	Economy	6300.00
0005432384009	31271	Economy	6300.00
0005432329712	31271	Economy	6300.00
0005432384015	31271	Economy	6300.00
0005432329686	31271	Economy	6300.00
0005432329715	31271	Economy	6300.00
0005432384013	31271	Economy	6300.00
0005432329692	31271	Economy	6300.00
0005432329698	31271	Economy	6300.00
0005432329710	31271	Economy	6300.00
0005432329705	31271	Economy	6300.00
0005432287301	31271	Economy	6300.00
0005432384018	31271	Economy	6300.00
0005432329683	31271	Economy	6300.00
0005432384006	31271	Economy	6300.00
0005432383999	31271	Economy	6300.00
0005432329682	31271	Economy	6300.00
0005432384017	31271	Economy	6300.00
0005432384021	31271	Economy	6300.00
0005432329693	31271	Economy	6300.00
0005432329696	31271	Economy	6300.00
0005432329677	31271	Economy	6300.00
0005432384019	31271	Economy	6300.00
0005432384027	31271	Economy	6300.00
0005432384033	31271	Economy	6300.00
0005432384023	31271	Economy	6300.00
0005432287298	31271	Economy	6300.00
0005432384025	31271	Economy	6300.00
0005432384028	31271	Economy	6300.00
0005432329691	31271	Economy	6300.00
0005432383998	31271	Economy	6300.00
0005432287302	31271	Economy	6300.00
0005432329703	31271	Economy	6300.00
0005432329708	31271	Economy	6300.00
0005432384000	31271	Economy	6300.00
0005432329678	31271	Economy	6300.00
0005432384030	31271	Economy	6300.00
0005432384031	31271	Economy	6300.00
0005432329719	31271	Economy	6300.00
0005432383997	31271	Economy	6300.00
0005432329699	31271	Economy	6300.00
0005432384020	31271	Economy	6300.00
0005432329694	31271	Economy	6300.00
0005432287300	31271	Economy	6300.00
0005432384012	31271	Economy	6300.00
0005432384004	31271	Economy	6300.00
0005432384024	31271	Economy	6300.00
0005432384007	31271	Economy	6300.00
0005432329701	31271	Economy	6300.00
0005432329680	31271	Economy	6300.00
0005432384034	31271	Economy	6300.00
0005432384003	31271	Economy	6300.00
0005432384026	31271	Economy	6300.00
0005432329718	31271	Economy	6300.00
0005432384014	31271	Economy	6300.00
0005433642663	2476	Business	89600.00
0005433642672	2476	Business	89600.00
0005433642661	2476	Business	89600.00
0005433642687	2476	Business	89600.00
0005433642664	2476	Business	89600.00
0005432954004	2476	Business	89600.00
0005432954040	2476	Business	89600.00
0005432954017	2476	Business	89600.00
0005433642684	2476	Economy	29900.00
0005433642660	2476	Economy	29900.00
0005433642680	2476	Economy	29900.00
0005432954036	2476	Economy	29900.00
0005432954063	2476	Economy	29900.00
0005433642674	2476	Economy	29900.00
0005432954048	2476	Economy	32800.00
0005432954034	2476	Economy	32800.00
0005432954065	2476	Economy	29900.00
0005433642682	2476	Economy	29900.00
0005433642668	2476	Economy	29900.00
0005432954059	2476	Economy	29900.00
0005433642675	2476	Economy	29900.00
0005433642686	2476	Economy	29900.00
0005432954067	2476	Economy	29900.00
0005433642669	2476	Economy	29900.00
0005433642681	2476	Economy	29900.00
0005432954071	2476	Economy	29900.00
0005432954045	2476	Economy	29900.00
0005433642666	2476	Economy	29900.00
0005433642678	2476	Economy	29900.00
0005433642677	2476	Economy	29900.00
0005433642683	2476	Economy	29900.00
0005433642658	2476	Economy	29900.00
0005432954072	2476	Economy	29900.00
0005432954066	2476	Economy	29900.00
0005432954035	2476	Economy	29900.00
0005432954015	2476	Economy	29900.00
0005433642673	2476	Economy	29900.00
0005432954047	2476	Economy	29900.00
0005433642662	2476	Economy	29900.00
0005433642676	2476	Economy	29900.00
0005433642685	2476	Economy	29900.00
0005433642659	2476	Economy	29900.00
0005432954043	2476	Economy	29900.00
0005432954037	2476	Economy	29900.00
0005432954046	2476	Economy	29900.00
0005432954005	2476	Economy	29900.00
0005432954064	2476	Economy	29900.00
0005432954038	2476	Economy	29900.00
0005433642688	2476	Economy	29900.00
0005433642667	2476	Economy	29900.00
0005432954077	2476	Economy	29900.00
0005433642665	2476	Economy	29900.00
0005432954018	2476	Economy	29900.00
0005433642679	2476	Economy	29900.00
0005433642671	2476	Economy	29900.00
0005433642670	2476	Economy	29900.00
0005432954062	2476	Economy	29900.00
0005433642531	27578	Business	89600.00
0005432954118	27578	Business	89600.00
0005433642612	27578	Business	89600.00
0005433642573	27578	Business	89600.00
0005432954128	27578	Business	89600.00
0005433642542	27578	Economy	29900.00
0005432954126	27578	Economy	29900.00
0005433642523	27578	Economy	29900.00
0005432954133	27578	Economy	29900.00
0005432954123	27578	Economy	29900.00
0005432954117	27578	Economy	29900.00
0005432954131	27578	Economy	32800.00
0005432954129	27578	Economy	32800.00
0005432954120	27578	Economy	32800.00
0005432954127	27578	Economy	29900.00
0005433642574	27578	Economy	29900.00
0005433642500	27578	Economy	29900.00
0005432954125	27578	Economy	29900.00
0005432954122	27578	Economy	29900.00
0005433642594	27578	Economy	29900.00
0005432954124	27578	Economy	29900.00
0005433642537	27578	Economy	29900.00
0005432954121	27578	Economy	29900.00
0005433642476	27578	Economy	29900.00
0005433642593	27578	Economy	29900.00
0005433642518	27578	Economy	29900.00
0005432954132	27578	Economy	29900.00
0005433642539	27578	Economy	29900.00
0005433642522	27578	Economy	29900.00
0005432954130	27578	Economy	29900.00
0005433642555	27578	Economy	29900.00
0005433642556	27578	Economy	29900.00
0005433642515	27578	Economy	29900.00
0005433642582	27578	Economy	29900.00
0005432954119	27578	Economy	29900.00
0005433642525	27578	Economy	29900.00
0005433642530	27578	Economy	29900.00
0005433642524	27578	Economy	29900.00
0005432425490	13326	Business	12700.00
0005432425494	13326	Business	12700.00
0005432425479	13326	Business	12700.00
0005432425521	13326	Business	12700.00
0005432425495	13326	Business	12700.00
0005432425519	13326	Business	12700.00
0005432425499	13326	Economy	4200.00
0005432425483	13326	Economy	4200.00
0005432425518	13326	Economy	4200.00
0005432425481	13326	Economy	4200.00
0005432425514	13326	Economy	4200.00
0005432425497	13326	Economy	4200.00
0005432425504	13326	Economy	4200.00
0005432425492	13326	Economy	4200.00
0005432425506	13326	Economy	4200.00
0005432425485	13326	Economy	4700.00
0005432425507	13326	Economy	4200.00
0005432425489	13326	Economy	4200.00
0005432425493	13326	Economy	4200.00
0005432425484	13326	Economy	4200.00
0005432425478	13326	Economy	4200.00
0005432425516	13326	Economy	4200.00
0005432425513	13326	Economy	4200.00
0005432425509	13326	Economy	4200.00
0005432425508	13326	Economy	4200.00
0005432425503	13326	Economy	4200.00
0005432425512	13326	Economy	4200.00
0005432425480	13326	Economy	4200.00
0005432425482	13326	Economy	4200.00
0005432425517	13326	Economy	4200.00
0005432425488	13326	Economy	4200.00
0005432425520	13326	Economy	4200.00
0005432425487	13326	Economy	4200.00
0005432425500	13326	Economy	4200.00
0005432425505	13326	Economy	4200.00
0005432425501	13326	Economy	4200.00
0005432425491	13326	Economy	4200.00
0005432425496	13326	Economy	4200.00
0005432425515	13326	Economy	4200.00
0005432425498	13326	Economy	4200.00
0005432425510	13326	Economy	4200.00
0005432425486	13326	Economy	4200.00
0005432425522	13326	Economy	4200.00
0005432425502	13326	Economy	4200.00
0005432425511	13326	Economy	4200.00
0005432425004	30806	Business	12700.00
0005432424845	30806	Business	12700.00
0005432425164	30806	Business	12700.00
0005432425168	30806	Business	12700.00
0005432425112	30806	Business	12700.00
0005432424893	30806	Business	12700.00
0005432424968	30806	Business	12700.00
0005432425116	30806	Business	12700.00
0005432425013	30806	Economy	4200.00
0005432425038	30806	Economy	4200.00
0005432424869	30806	Economy	4200.00
0005432425091	30806	Economy	4700.00
0005432424930	30806	Economy	4700.00
0005432425117	30806	Economy	4700.00
0005432424959	30806	Economy	4200.00
0005432425163	30806	Economy	4200.00
0005432424920	30806	Economy	4200.00
0005432425084	30806	Economy	4200.00
0005432425048	30806	Economy	4200.00
0005432425088	30806	Economy	4200.00
0005432425097	30806	Economy	4200.00
0005432425086	30806	Economy	4200.00
0005432425115	30806	Economy	4200.00
0005432424817	30806	Economy	4200.00
0005432425027	30806	Economy	4200.00
0005432425023	30806	Economy	4200.00
0005432425094	30806	Economy	4200.00
0005432425085	30806	Economy	4200.00
0005432424921	30806	Economy	4200.00
0005432424816	30806	Economy	4200.00
0005432424957	30806	Economy	4200.00
0005432425066	30806	Economy	4200.00
0005432425096	30806	Economy	4200.00
0005432424844	30806	Economy	4200.00
0005432425008	30806	Economy	4200.00
0005432425135	30806	Economy	4200.00
0005432425100	30806	Economy	4200.00
0005432425087	30806	Economy	4200.00
0005432425137	30806	Economy	4200.00
0005432424843	30806	Economy	4200.00
0005432424992	30806	Economy	4200.00
0005432425101	30806	Economy	4200.00
0005432425173	30806	Economy	4200.00
0005432425106	30806	Economy	4200.00
0005432425165	30806	Economy	4200.00
0005432425111	30806	Economy	4200.00
0005432425136	30806	Economy	4200.00
0005432425114	30806	Economy	4200.00
0005432425131	30806	Economy	4200.00
0005432425090	30806	Economy	4200.00
0005432424958	30806	Economy	4200.00
0005432425075	30806	Economy	4200.00
0005432424960	30806	Economy	4200.00
0005432425093	30806	Economy	4200.00
0005432425065	30806	Economy	4200.00
0005432425166	30806	Economy	4200.00
0005432424991	30806	Economy	4200.00
0005432289061	9632	Business	32600.00
0005434157593	9632	Business	32600.00
0005432818137	9632	Business	32600.00
0005432818128	9632	Business	32600.00
0005432822373	9632	Business	32600.00
0005432818131	9632	Business	32600.00
0005432818152	9632	Business	32600.00
0005432901904	9632	Business	32600.00
0005432822380	9632	Business	32600.00
0005432822378	9632	Economy	10900.00
0005434448392	9632	Economy	10900.00
0005432901772	9632	Economy	10900.00
0005432901826	9632	Economy	10900.00
0005432818147	9632	Economy	10900.00
0005432822377	9632	Economy	10900.00
0005432818126	9632	Economy	10900.00
0005434448395	9632	Economy	10900.00
0005432289059	9632	Economy	11900.00
0005432901842	9632	Economy	11900.00
0005432818124	9632	Economy	11900.00
0005432818125	9632	Economy	10900.00
0005432901869	9632	Economy	10900.00
0005432818150	9632	Economy	10900.00
0005434186240	9632	Economy	10900.00
0005434448391	9632	Economy	10900.00
0005432818139	9632	Economy	10900.00
0005432818144	9632	Economy	10900.00
0005434448394	9632	Economy	10900.00
0005432901827	9632	Economy	10900.00
0005432818135	9632	Economy	10900.00
0005432818133	9632	Economy	10900.00
0005432901840	9632	Economy	10900.00
0005432818123	9632	Economy	10900.00
0005432901821	9632	Economy	10900.00
0005432818143	9632	Economy	10900.00
0005432901876	9632	Economy	10900.00
0005432901822	9632	Economy	10900.00
0005432818130	9632	Economy	10900.00
0005432822381	9632	Economy	10900.00
0005432818142	9632	Economy	10900.00
0005432818136	9632	Economy	10900.00
0005432901829	9632	Economy	10900.00
0005432822374	9632	Economy	10900.00
0005432901830	9632	Economy	10900.00
0005432818149	9632	Economy	10900.00
0005432818145	9632	Economy	10900.00
0005432818148	9632	Economy	10900.00
0005432818132	9632	Economy	10900.00
0005432822375	9632	Economy	10900.00
0005432901859	9632	Economy	10900.00
0005432901831	9632	Economy	10900.00
0005432901860	9632	Economy	10900.00
0005432822379	9632	Economy	10900.00
0005432818151	9632	Economy	10900.00
0005432822376	9632	Economy	10900.00
0005434157608	9632	Economy	10900.00
0005432818129	9632	Economy	10900.00
0005432818134	9632	Economy	10900.00
0005432818140	9632	Economy	10900.00
0005432818146	9632	Economy	10900.00
0005432901903	9632	Economy	10900.00
0005432818138	9632	Economy	10900.00
0005432818127	9632	Economy	10900.00
0005432289060	9632	Economy	10900.00
0005434448393	9632	Economy	10900.00
0005432818141	9632	Economy	10900.00
0005432902008	28969	Business	32600.00
0005432817927	28969	Business	32600.00
0005434157652	28969	Business	32600.00
0005432817922	28969	Business	32600.00
0005434186261	28969	Business	32600.00
0005432822306	28969	Business	32600.00
0005432817893	28969	Business	32600.00
0005434448366	28969	Business	32600.00
0005432901999	28969	Business	32600.00
0005432822316	28969	Economy	10900.00
0005432817834	28969	Economy	10900.00
0005432817921	28969	Economy	10900.00
0005432817835	28969	Economy	10900.00
0005434186263	28969	Economy	10900.00
0005434157657	28969	Economy	10900.00
0005432817918	28969	Economy	11900.00
0005434157653	28969	Economy	11900.00
0005432817754	28969	Economy	11900.00
0005434448363	28969	Economy	11900.00
0005434186262	28969	Economy	10900.00
0005434448371	28969	Economy	10900.00
0005432817826	28969	Economy	10900.00
0005432817928	28969	Economy	10900.00
0005432817766	28969	Economy	10900.00
0005432822323	28969	Economy	10900.00
0005432817765	28969	Economy	10900.00
0005432902007	28969	Economy	10900.00
0005432817889	28969	Economy	10900.00
0005432817860	28969	Economy	10900.00
0005432902011	28969	Economy	10900.00
0005432902004	28969	Economy	10900.00
0005432902002	28969	Economy	10900.00
0005432817923	28969	Economy	10900.00
0005432817755	28969	Economy	10900.00
0005432902010	28969	Economy	10900.00
0005432901997	28969	Economy	10900.00
0005432901998	28969	Economy	10900.00
0005432822308	28969	Economy	10900.00
0005432817821	28969	Economy	10900.00
0005432902001	28969	Economy	10900.00
0005432817952	28969	Economy	10900.00
0005434157656	28969	Economy	10900.00
0005432901995	28969	Economy	10900.00
0005432822317	28969	Economy	10900.00
0005432822297	28969	Economy	10900.00
0005432902005	28969	Economy	10900.00
0005432002123	28969	Economy	10900.00
0005432902003	28969	Economy	10900.00
0005432822309	28969	Economy	10900.00
0005432817759	28969	Economy	10900.00
0005432817945	28969	Economy	10900.00
0005432817762	28969	Economy	10900.00
0005434157658	28969	Economy	10900.00
0005434157655	28969	Economy	10900.00
0005432817758	28969	Economy	10900.00
0005432817890	28969	Economy	10900.00
0005434157654	28969	Economy	10900.00
0005432902006	28969	Economy	10900.00
0005432817816	28969	Economy	10900.00
0005432822305	28969	Economy	10900.00
0005432817817	28969	Economy	10900.00
0005432902009	28969	Economy	10900.00
0005432817980	28969	Economy	10900.00
0005432901996	28969	Economy	10900.00
0005432902000	28969	Economy	10900.00
0005432817825	28969	Economy	10900.00
0005434448367	28969	Economy	10900.00
0005434186264	28969	Economy	10900.00
0005432902012	28969	Economy	10900.00
0005432817833	28969	Economy	10900.00
0005432817843	28969	Economy	10900.00
0005432822304	28969	Economy	10900.00
0005432817832	28969	Economy	10900.00
0005432611788	15099	Economy	11000.00
0005432611791	15099	Economy	11000.00
0005435841107	15099	Economy	11000.00
0005432613957	15099	Economy	11000.00
0005432613955	15099	Economy	11000.00
0005432611789	15099	Economy	11000.00
0005432613954	15099	Economy	11000.00
0005432613952	15099	Economy	11000.00
0005432611790	15099	Economy	11000.00
0005432613956	15099	Economy	11000.00
0005432613953	15099	Economy	11000.00
0005435841843	31531	Economy	11000.00
0005435842347	31531	Economy	11000.00
0005432611762	31531	Economy	11000.00
0005432611763	31531	Economy	11000.00
0005432607616	31531	Economy	11000.00
0005435841842	31531	Economy	11000.00
0005433570400	11849	Business	105900.00
0005433570399	11849	Business	105900.00
0005432949082	11849	Business	105900.00
0005432948768	11849	Business	105900.00
0005432948874	11849	Business	105900.00
0005433570375	11849	Business	105900.00
0005432948705	11849	Business	105900.00
0005433570420	11849	Business	105900.00
0005433570415	11849	Business	105900.00
0005432949083	11849	Business	105900.00
0005433570366	11849	Business	105900.00
0005433570382	11849	Business	105900.00
0005433570380	11849	Business	105900.00
0005433570368	11849	Business	105900.00
0005432948903	11849	Business	105900.00
0005433570381	11849	Business	105900.00
0005433570421	11849	Business	105900.00
0005433570417	11849	Economy	35300.00
0005433570409	11849	Business	105900.00
0005433570369	11849	Economy	35300.00
0005433570394	11849	Economy	35300.00
0005432949132	11849	Economy	35300.00
0005432949073	11849	Economy	35300.00
0005433570379	11849	Economy	35300.00
0005433570388	11849	Economy	35300.00
0005433570427	11849	Economy	35300.00
0005432948902	11849	Economy	35300.00
0005433570391	11849	Economy	35300.00
0005433570404	11849	Economy	35300.00
0005433570362	11849	Economy	35300.00
0005432949035	11849	Economy	38800.00
0005432948826	11849	Economy	38800.00
0005433570419	11849	Economy	38800.00
0005433570418	11849	Economy	35300.00
0005433570384	11849	Economy	38800.00
0005432948916	11849	Economy	35300.00
0005433570414	11849	Economy	35300.00
0005433570398	11849	Economy	35300.00
0005433570390	11849	Economy	35300.00
0005432948988	11849	Economy	35300.00
0005433570426	11849	Economy	35300.00
0005433570425	11849	Economy	35300.00
0005433570402	11849	Economy	35300.00
0005433570383	11849	Economy	35300.00
0005432948849	11849	Economy	35300.00
0005433570365	11849	Economy	35300.00
0005433570363	11849	Economy	35300.00
0005432948940	11849	Economy	35300.00
0005432948769	11849	Economy	35300.00
0005433570373	11849	Economy	35300.00
0005432948823	11849	Economy	35300.00
0005433570423	11849	Economy	35300.00
0005433570429	11849	Economy	35300.00
0005433570428	11849	Economy	35300.00
0005432948873	11849	Economy	35300.00
0005433570397	11849	Economy	35300.00
0005433570386	11849	Economy	35300.00
0005432948892	11849	Economy	35300.00
0005432949074	11849	Economy	35300.00
0005433570376	11849	Economy	35300.00
0005433570387	11849	Economy	35300.00
0005432949078	11849	Economy	35300.00
0005433570371	11849	Economy	35300.00
0005433570396	11849	Economy	35300.00
0005433570411	11849	Economy	35300.00
0005433570413	11849	Economy	35300.00
0005433570370	11849	Economy	35300.00
0005432948704	11849	Economy	35300.00
0005433570389	11849	Economy	35300.00
0005433570393	11849	Economy	35300.00
0005433570405	11849	Economy	35300.00
0005432948959	11849	Economy	35300.00
0005433570406	11849	Economy	35300.00
0005432948926	11849	Economy	35300.00
0005433570378	11849	Economy	35300.00
0005433570403	11849	Economy	35300.00
0005432948949	11849	Economy	35300.00
0005433570410	11849	Economy	35300.00
0005433570385	11849	Economy	35300.00
0005433570408	11849	Economy	35300.00
0005432948924	11849	Economy	35300.00
0005432949117	11849	Economy	35300.00
0005432948893	11849	Economy	35300.00
0005433570395	11849	Economy	35300.00
0005432948824	11849	Economy	35300.00
0005433570412	11849	Economy	35300.00
0005432949003	11849	Economy	35300.00
0005432949004	11849	Economy	35300.00
0005433570416	11849	Economy	35300.00
0005432949050	11849	Economy	35300.00
0005433570407	11849	Economy	35300.00
0005433570374	11849	Economy	35300.00
0005433570401	11849	Economy	35300.00
0005432948825	11849	Economy	35300.00
0005432948987	11849	Economy	35300.00
0005432948851	11849	Economy	35300.00
0005433570392	11849	Economy	35300.00
0005432949131	11849	Economy	35300.00
0005432948875	11849	Economy	35300.00
0005432948917	11849	Economy	35300.00
0005433570424	11849	Economy	35300.00
0005433570377	11849	Economy	35300.00
0005432948915	11849	Economy	35300.00
0005433570372	11849	Economy	35300.00
0005433570367	11849	Economy	35300.00
0005433570364	11849	Economy	35300.00
0005433570422	11849	Economy	35300.00
0005432949421	25292	Business	105900.00
0005433569856	25292	Business	105900.00
0005433569800	25292	Business	105900.00
0005433569678	25292	Business	105900.00
0005433569794	25292	Business	105900.00
0005433569858	25292	Business	105900.00
0005433569819	25292	Business	105900.00
0005432949397	25292	Business	105900.00
0005433569925	25292	Business	105900.00
0005433569926	25292	Business	105900.00
0005432949416	25292	Business	105900.00
0005432949399	25292	Business	105900.00
0005433569860	25292	Business	105900.00
0005432949422	25292	Business	105900.00
0005432949401	25292	Business	105900.00
0005432949391	25292	Business	105900.00
0005432949417	25292	Business	105900.00
0005432949408	25292	Business	105900.00
0005433569693	25292	Economy	35300.00
0005432949431	25292	Economy	35300.00
0005432949430	25292	Economy	35300.00
0005433569707	25292	Economy	35300.00
0005433569806	25292	Economy	35300.00
0005432949395	25292	Economy	35300.00
0005432949406	25292	Economy	35300.00
0005433569573	25292	Economy	35300.00
0005433569603	25292	Economy	35300.00
0005433569706	25292	Economy	35300.00
0005433569785	25292	Economy	35300.00
0005433569990	25292	Economy	35300.00
0005433569787	25292	Economy	38800.00
0005432949428	25292	Economy	38800.00
0005432949426	25292	Economy	35300.00
0005433569805	25292	Economy	35300.00
0005433569832	25292	Economy	35300.00
0005432949394	25292	Economy	35300.00
0005433569965	25292	Economy	35300.00
0005432949404	25292	Economy	35300.00
0005433570019	25292	Economy	35300.00
0005433569935	25292	Economy	35300.00
0005433569609	25292	Economy	35300.00
0005433569917	25292	Economy	35300.00
0005433569909	25292	Economy	35300.00
0005433569993	25292	Economy	35300.00
0005432949392	25292	Economy	35300.00
0005432949396	25292	Economy	35300.00
0005432949414	25292	Economy	35300.00
0005432949420	25292	Economy	35300.00
0005433569628	25292	Economy	35300.00
0005432949424	25292	Economy	35300.00
0005433569712	25292	Economy	35300.00
0005433569820	25292	Economy	35300.00
0005433569708	25292	Economy	35300.00
0005433570008	25292	Economy	35300.00
0005432949419	25292	Economy	35300.00
0005433569937	25292	Economy	35300.00
0005433569979	25292	Economy	35300.00
0005433569966	25292	Economy	35300.00
0005433569833	25292	Economy	35300.00
0005432949409	25292	Economy	35300.00
0005432949412	25292	Economy	35300.00
0005433569786	25292	Economy	35300.00
0005433569790	25292	Economy	35300.00
0005433569880	25292	Economy	35300.00
0005433569656	25292	Economy	35300.00
0005432949398	25292	Economy	35300.00
0005432949407	25292	Economy	35300.00
0005432949393	25292	Economy	35300.00
0005433569904	25292	Economy	35300.00
0005433569728	25292	Economy	35300.00
0005433569837	25292	Economy	35300.00
0005432949403	25292	Economy	35300.00
0005432949423	25292	Economy	35300.00
0005433569692	25292	Economy	35300.00
0005432949405	25292	Economy	35300.00
0005433569727	25292	Economy	35300.00
0005433569699	25292	Economy	35300.00
0005433569809	25292	Economy	35300.00
0005433569807	25292	Economy	35300.00
0005433569808	25292	Economy	35300.00
0005433569710	25292	Economy	35300.00
0005433569964	25292	Economy	35300.00
0005433569813	25292	Economy	35300.00
0005433569972	25292	Economy	35300.00
0005432949413	25292	Economy	35300.00
0005433570020	25292	Economy	35300.00
0005432949418	25292	Economy	35300.00
0005433569910	25292	Economy	35300.00
0005433569792	25292	Economy	35300.00
0005432949400	25292	Economy	35300.00
0005433569761	25292	Economy	35300.00
0005432949427	25292	Economy	35300.00
0005432949429	25292	Economy	35300.00
0005433569791	25292	Economy	35300.00
0005432949390	25292	Economy	35300.00
0005432949402	25292	Economy	35300.00
0005433569694	25292	Economy	35300.00
0005432949411	25292	Economy	35300.00
0005433569811	25292	Economy	35300.00
0005433569627	25292	Economy	35300.00
0005432949425	25292	Economy	35300.00
0005433569947	25292	Economy	35300.00
0005432949415	25292	Economy	35300.00
0005433569784	25292	Economy	35300.00
0005433569655	25292	Economy	35300.00
0005432949410	25292	Economy	35300.00
0005433569942	25292	Economy	35300.00
0005433569854	25292	Economy	35300.00
0005433569936	25292	Economy	35300.00
0005433808410	14469	Business	117400.00
0005433808420	14469	Business	117400.00
0005433808395	14469	Business	117400.00
0005433812923	14469	Business	117400.00
0005433808432	14469	Business	117400.00
0005433812925	14469	Business	117400.00
0005432430947	14469	Business	117400.00
0005433808425	14469	Business	117400.00
0005434026748	14469	Economy	39100.00
0005433812930	14469	Economy	39100.00
0005433808402	14469	Economy	39100.00
0005433812927	14469	Economy	39100.00
0005433808411	14469	Economy	43000.00
0005432430939	14469	Economy	43000.00
0005433808414	14469	Economy	39100.00
0005433812928	14469	Economy	39100.00
0005433808417	14469	Economy	39100.00
0005433812931	14469	Economy	39100.00
0005433812912	14469	Economy	39100.00
0005433808428	14469	Economy	39100.00
0005433808427	14469	Economy	39100.00
0005432430950	14469	Economy	39100.00
0005433808413	14469	Economy	39100.00
0005434026743	14469	Economy	39100.00
0005432430946	14469	Economy	39100.00
0005434026745	14469	Economy	39100.00
0005434026750	14469	Economy	39100.00
0005433808431	14469	Economy	39100.00
0005433808424	14469	Economy	39100.00
0005432430940	14469	Economy	39100.00
0005433808421	14469	Economy	39100.00
0005434026747	14469	Economy	39100.00
0005434026744	14469	Economy	39100.00
0005432430938	14469	Economy	39100.00
0005433808426	14469	Economy	39100.00
0005433808419	14469	Economy	39100.00
0005432430942	14469	Economy	39100.00
0005434026746	14469	Economy	39100.00
0005432430941	14469	Economy	39100.00
0005432430944	14469	Economy	39100.00
0005433812919	14469	Economy	39100.00
0005433812921	14469	Economy	39100.00
0005433808418	14469	Economy	39100.00
0005432430943	14469	Economy	39100.00
0005433808405	14469	Economy	39100.00
0005432430948	14469	Economy	39100.00
0005432430949	14469	Economy	39100.00
0005433808429	14469	Economy	39100.00
0005434026749	14469	Economy	39100.00
0005433808416	14469	Economy	39100.00
0005433808430	14469	Economy	39100.00
0005433812929	14469	Economy	39100.00
0005433808412	14469	Economy	39100.00
0005433812911	14469	Economy	39100.00
0005432430945	14469	Economy	39100.00
0005433808409	14469	Economy	39100.00
0005435340535	5406	Business	67200.00
0005434655349	5406	Business	67200.00
0005434655328	5406	Business	67200.00
0005432114275	5406	Business	67200.00
0005435340536	5406	Business	67200.00
0005434656601	5406	Business	67200.00
0005435340500	5406	Economy	22400.00
0005435340495	5406	Economy	22400.00
0005434655330	5406	Economy	22400.00
0005435340486	5406	Economy	22400.00
0005434655325	5406	Economy	22400.00
0005434655326	5406	Economy	22400.00
0005434655343	5406	Economy	24600.00
0005434655354	5406	Economy	24600.00
0005432114276	5406	Economy	24600.00
0005435340494	5406	Economy	22400.00
0005435340525	5406	Economy	22400.00
0005435340560	5406	Economy	22400.00
0005435340499	5406	Economy	22400.00
0005434655351	5406	Economy	22400.00
0005432114277	5406	Economy	22400.00
0005435340447	5406	Economy	22400.00
0005434655338	5406	Economy	22400.00
0005434656602	5406	Economy	22400.00
0005435340501	5406	Economy	22400.00
0005434655332	5406	Economy	22400.00
0005435340410	5406	Economy	22400.00
0005434655333	5406	Economy	22400.00
0005434655352	5406	Economy	22400.00
0005435340496	5406	Economy	22400.00
0005434655344	5406	Economy	22400.00
0005434655331	5406	Economy	22400.00
0005435340487	5406	Economy	22400.00
0005435340472	5406	Economy	22400.00
0005434655329	5406	Economy	22400.00
0005435340411	5406	Economy	22400.00
0005434655346	5406	Economy	22400.00
0005434655353	5406	Economy	22400.00
0005434655327	5406	Economy	22400.00
0005435340473	5406	Economy	22400.00
0005434655342	5406	Economy	22400.00
0005434655335	5406	Economy	22400.00
0005435340446	5406	Economy	22400.00
0005434655348	5406	Economy	22400.00
0005432114274	5406	Economy	22400.00
0005435340448	5406	Economy	22400.00
0005434655339	5406	Economy	22400.00
0005435340412	5406	Economy	22400.00
0005434655341	5406	Economy	22400.00
0005434655336	5406	Economy	22400.00
0005434656600	5406	Economy	22400.00
0005434655337	5406	Economy	22400.00
0005434655334	5406	Economy	22400.00
0005434655340	5406	Economy	22400.00
0005434655345	5406	Economy	22400.00
0005434655347	5406	Economy	22400.00
0005434655350	5406	Economy	22400.00
0005434655083	12552	Business	67200.00
0005435340600	12552	Business	67200.00
0005434655047	12552	Business	67200.00
0005435340606	12552	Business	67200.00
0005435340603	12552	Economy	22400.00
0005434655088	12552	Economy	22400.00
0005434655077	12552	Economy	22400.00
0005434655101	12552	Economy	22400.00
0005434655051	12552	Economy	22400.00
0005434655142	12552	Economy	22400.00
0005434654946	12552	Economy	22400.00
0005435340599	12552	Economy	22400.00
0005434655010	12552	Economy	24600.00
0005434655046	12552	Economy	24600.00
0005434656577	12552	Economy	24600.00
0005435340604	12552	Economy	24600.00
0005434655078	12552	Economy	24600.00
0005434655150	12552	Economy	22400.00
0005434656576	12552	Economy	22400.00
0005435340601	12552	Economy	22400.00
0005434655100	12552	Economy	22400.00
0005434655149	12552	Economy	22400.00
0005434655081	12552	Economy	22400.00
0005434655156	12552	Economy	22400.00
0005434655140	12552	Economy	22400.00
0005434654962	12552	Economy	22400.00
0005435340607	12552	Economy	22400.00
0005434655097	12552	Economy	22400.00
0005435555417	12552	Economy	22400.00
0005434655080	12552	Economy	22400.00
0005434655066	12552	Economy	22400.00
0005434655079	12552	Economy	22400.00
0005434655155	12552	Economy	22400.00
0005434654983	12552	Economy	22400.00
0005434655093	12552	Economy	22400.00
0005435340608	12552	Economy	22400.00
0005435555416	12552	Economy	22400.00
0005435340602	12552	Economy	22400.00
0005434655092	12552	Economy	22400.00
0005434655042	12552	Economy	22400.00
0005435340597	12552	Economy	22400.00
0005434655143	12552	Economy	22400.00
0005435340609	12552	Economy	22400.00
0005434654984	12552	Economy	22400.00
0005435340611	12552	Economy	22400.00
0005435340612	12552	Economy	22400.00
0005434655139	12552	Economy	22400.00
0005434654958	12552	Economy	22400.00
0005435340610	12552	Economy	22400.00
0005434655148	12552	Economy	22400.00
0005434655098	12552	Economy	22400.00
0005435340605	12552	Economy	22400.00
0005435340598	12552	Economy	22400.00
0005433717105	7421	Business	32000.00
0005433717086	7421	Business	32000.00
0005433717064	7421	Business	32000.00
0005432078232	7421	Business	32000.00
0005433717099	7421	Business	32000.00
0005433717102	7421	Business	32000.00
0005433722357	7421	Business	32000.00
0005433717085	7421	Business	32000.00
0005433717070	7421	Economy	10700.00
0005433717112	7421	Economy	10700.00
0005433717072	7421	Economy	10700.00
0005433722360	7421	Economy	10700.00
0005432078235	7421	Economy	10700.00
0005433719217	7421	Economy	10700.00
0005433717087	7421	Economy	10700.00
0005433690969	7421	Economy	10700.00
0005433719213	7421	Economy	10700.00
0005433722358	7421	Economy	10700.00
0005433717109	7421	Economy	10700.00
0005433717078	7421	Economy	10700.00
0005433717065	7421	Economy	10700.00
0005433717095	7421	Economy	10700.00
0005432078230	7421	Economy	10700.00
0005433717094	7421	Economy	10700.00
0005433719214	7421	Economy	10700.00
0005433722361	7421	Economy	10700.00
0005435266198	7421	Economy	10700.00
0005433717093	7421	Economy	10700.00
0005433717071	7421	Economy	10700.00
0005433717108	7421	Economy	10700.00
0005433717111	7421	Economy	10700.00
0005433717092	7421	Economy	10700.00
0005433717088	7421	Economy	10700.00
0005433717106	7421	Economy	10700.00
0005433717100	7421	Economy	10700.00
0005432428983	7421	Economy	10700.00
0005433717075	7421	Economy	11700.00
0005432078231	7421	Economy	11700.00
0005433717096	7421	Economy	11700.00
0005433722356	7421	Economy	10700.00
0005432078236	7421	Economy	10700.00
0005433689958	7421	Economy	10700.00
0005433717098	7421	Economy	10700.00
0005432428981	7421	Economy	10700.00
0005433717091	7421	Economy	10700.00
0005433689957	7421	Economy	10700.00
0005433717076	7421	Economy	10700.00
0005433717081	7421	Economy	10700.00
0005433690968	7421	Economy	10700.00
0005433656744	7421	Economy	10700.00
0005433688854	7421	Economy	10700.00
0005433717074	7421	Economy	10700.00
0005433719215	7421	Economy	10700.00
0005433717107	7421	Economy	10700.00
0005433717069	7421	Economy	10700.00
0005432078234	7421	Economy	10700.00
0005433717082	7421	Economy	10700.00
0005433717089	7421	Economy	10700.00
0005433689956	7421	Economy	10700.00
0005432078237	7421	Economy	10700.00
0005433717090	7421	Economy	10700.00
0005433717110	7421	Economy	10700.00
0005433717068	7421	Economy	10700.00
0005433688855	7421	Economy	10700.00
0005433717079	7421	Economy	10700.00
0005433717103	7421	Economy	10700.00
0005433717066	7421	Economy	10700.00
0005433717077	7421	Economy	10700.00
0005433717104	7421	Economy	10700.00
0005433719216	7421	Economy	10700.00
0005433717063	7421	Economy	10700.00
0005433717062	7421	Economy	10700.00
0005433717084	7421	Economy	10700.00
0005433717097	7421	Economy	10700.00
0005433717080	7421	Economy	10700.00
0005433722362	7421	Economy	10700.00
0005433722359	7421	Economy	10700.00
0005433717067	7421	Economy	10700.00
0005433717073	7421	Economy	10700.00
0005432078233	7421	Economy	10700.00
0005433717113	7421	Economy	10700.00
0005433717083	7421	Economy	10700.00
0005433717101	7421	Economy	10700.00
0005433716625	29218	Business	32000.00
0005433716458	29218	Business	32000.00
0005433716762	29218	Business	32000.00
0005435266279	29218	Business	32000.00
0005435266278	29218	Business	32000.00
0005433722278	29218	Business	32000.00
0005433716853	29218	Business	32000.00
0005433716415	29218	Business	32000.00
0005433716808	29218	Business	32000.00
0005433716624	29218	Economy	10700.00
0005433716560	29218	Economy	10700.00
0005433656716	29218	Economy	10700.00
0005432006826	29218	Economy	10700.00
0005432006827	29218	Economy	10700.00
0005433722293	29218	Economy	10700.00
0005435266289	29218	Economy	10700.00
0005433716686	29218	Economy	10700.00
0005433716711	29218	Economy	10700.00
0005433719179	29218	Economy	10700.00
0005433716823	29218	Economy	10700.00
0005433688847	29218	Economy	10700.00
0005435266288	29218	Economy	10700.00
0005433716640	29218	Economy	10700.00
0005435266287	29218	Economy	10700.00
0005433716476	29218	Economy	10700.00
0005433716572	29218	Economy	10700.00
0005433716477	29218	Economy	10700.00
0005433716634	29218	Economy	10700.00
0005433716702	29218	Economy	10700.00
0005433716450	29218	Economy	10700.00
0005433722277	29218	Economy	10700.00
0005433716457	29218	Economy	10700.00
0005433716587	29218	Economy	10700.00
0005433716738	29218	Economy	10700.00
0005433716664	29218	Economy	10700.00
0005433716666	29218	Economy	10700.00
0005435266284	29218	Economy	10700.00
0005435266292	29218	Economy	10700.00
0005433716665	29218	Economy	11700.00
0005433688833	29218	Economy	11700.00
0005433719191	29218	Economy	11700.00
0005433716521	29218	Economy	11700.00
0005433716837	29218	Economy	10700.00
0005433716520	29218	Economy	10700.00
0005433716475	29218	Economy	10700.00
0005433716607	29218	Economy	10700.00
0005435266281	29218	Economy	10700.00
0005433716639	29218	Economy	10700.00
0005433716761	29218	Economy	10700.00
0005433719184	29218	Economy	10700.00
0005433716769	29218	Economy	10700.00
0005433716768	29218	Economy	10700.00
0005432006828	29218	Economy	10700.00
0005435266291	29218	Economy	10700.00
0005433688832	29218	Economy	10700.00
0005433719189	29218	Economy	10700.00
0005433716852	29218	Economy	10700.00
0005433716687	29218	Economy	10700.00
0005433722304	29218	Economy	10700.00
0005433716533	29218	Economy	10700.00
0005432429008	29218	Economy	10700.00
0005433722289	29218	Economy	10700.00
0005433716847	29218	Economy	10700.00
0005435266283	29218	Economy	10700.00
0005433716786	29218	Economy	10700.00
0005435266293	29218	Economy	10700.00
0005433656709	29218	Economy	10700.00
0005433716754	29218	Economy	10700.00
0005432429005	29218	Economy	10700.00
0005433688842	29218	Economy	10700.00
0005433688831	29218	Economy	10700.00
0005435266282	29218	Economy	10700.00
0005433722305	29218	Economy	10700.00
0005433716845	29218	Economy	10700.00
0005433716561	29218	Economy	10700.00
0005433716635	29218	Economy	10700.00
0005435266280	29218	Economy	10700.00
0005433722291	29218	Economy	10700.00
0005433722290	29218	Economy	10700.00
0005432429006	29218	Economy	10700.00
0005433716573	29218	Economy	10700.00
0005433688846	29218	Economy	10700.00
0005432429007	29218	Economy	10700.00
0005432429004	29218	Economy	10700.00
0005433719188	29218	Economy	10700.00
0005433716739	29218	Economy	10700.00
0005435266285	29218	Economy	10700.00
0005433716822	29218	Economy	10700.00
0005433719185	29218	Economy	10700.00
0005435266286	29218	Economy	10700.00
0005433716753	29218	Economy	10700.00
0005435266290	29218	Economy	10700.00
0005433716846	29218	Economy	10700.00
0005434182331	8704	Business	36500.00
0005434182362	8704	Business	36500.00
0005434182361	8704	Business	36500.00
0005434182365	8704	Business	36500.00
0005434095604	8704	Business	36500.00
0005434095593	8704	Economy	12200.00
0005434182376	8704	Economy	12200.00
0005434184698	8704	Economy	12200.00
0005434095596	8704	Economy	13400.00
0005434095603	8704	Economy	12200.00
0005434182428	8704	Economy	12200.00
0005434095599	8704	Economy	12200.00
0005434184695	8704	Economy	12200.00
0005434095600	8704	Economy	12200.00
0005434182390	8704	Economy	12200.00
0005434095602	8704	Economy	12200.00
0005434095606	8704	Economy	12200.00
0005434182360	8704	Economy	12200.00
0005434182378	8704	Economy	12200.00
0005434095594	8704	Economy	12200.00
0005434095598	8704	Economy	12200.00
0005434184697	8704	Economy	12200.00
0005434184694	8704	Economy	12200.00
0005434184696	8704	Economy	12200.00
0005434182389	8704	Economy	12200.00
0005434182377	8704	Economy	12200.00
0005434095605	8704	Economy	12200.00
0005434182347	8704	Economy	12200.00
0005434095595	8704	Economy	12200.00
0005434095597	8704	Economy	12200.00
0005434182382	8704	Economy	12200.00
0005434182379	8704	Economy	12200.00
0005434095601	8704	Economy	12200.00
0005434182366	8704	Economy	12200.00
0005434182429	8704	Economy	12200.00
0005434182367	8704	Economy	12200.00
0005434182464	11664	Business	36500.00
0005434095457	11664	Business	36500.00
0005434095435	11664	Economy	12200.00
0005435860649	11664	Economy	12200.00
0005434095522	11664	Economy	13400.00
0005434095521	11664	Economy	12200.00
0005434095516	11664	Economy	12200.00
0005434182468	11664	Economy	12200.00
0005434095523	11664	Economy	12200.00
0005434182469	11664	Economy	12200.00
0005434182463	11664	Economy	12200.00
0005435860646	11664	Economy	12200.00
0005434095422	11664	Economy	12200.00
0005434182470	11664	Economy	12200.00
0005434182461	11664	Economy	12200.00
0005435860648	11664	Economy	12200.00
0005434095400	11664	Economy	12200.00
0005434095458	11664	Economy	12200.00
0005434184711	11664	Economy	12200.00
0005434182471	11664	Economy	12200.00
0005435860644	11664	Economy	12200.00
0005434182465	11664	Economy	12200.00
0005434095428	11664	Economy	12200.00
0005434095504	11664	Economy	12200.00
0005435860647	11664	Economy	12200.00
0005434095513	11664	Economy	12200.00
0005434182467	11664	Economy	12200.00
0005434095401	11664	Economy	12200.00
0005434182466	11664	Economy	12200.00
0005434184710	11664	Economy	12200.00
0005434182462	11664	Economy	12200.00
0005434183624	11664	Economy	12200.00
0005434184709	11664	Economy	12200.00
0005435860645	11664	Economy	12200.00
0005433398706	1459	Business	33000.00
0005433398482	1459	Business	33000.00
0005433398639	1459	Business	33000.00
0005433398595	1459	Business	33000.00
0005433398808	1459	Business	33000.00
0005433398594	1459	Business	33000.00
0005433398711	1459	Business	33000.00
0005433457059	1459	Business	33000.00
0005433398702	1459	Business	33000.00
0005433398766	1459	Economy	11000.00
0005433398768	1459	Economy	11000.00
0005433398558	1459	Economy	11000.00
0005433398693	1459	Economy	11000.00
0005433398764	1459	Economy	11000.00
0005433398892	1459	Economy	11000.00
0005433398782	1459	Economy	11000.00
0005432906569	1459	Economy	12100.00
0005433398886	1459	Economy	12100.00
0005433398643	1459	Economy	12100.00
0005433398813	1459	Economy	12100.00
0005433398954	1459	Economy	11000.00
0005433398823	1459	Economy	11000.00
0005432297337	1459	Economy	11000.00
0005433398688	1459	Economy	11000.00
0005433398859	1459	Economy	11000.00
0005433398837	1459	Economy	11000.00
0005433398615	1459	Economy	11000.00
0005433398701	1459	Economy	11000.00
0005433398691	1459	Economy	11000.00
0005433398622	1459	Economy	11000.00
0005433398616	1459	Economy	11000.00
0005433398788	1459	Economy	11000.00
0005433398746	1459	Economy	11000.00
0005433398685	1459	Economy	11000.00
0005433398738	1459	Economy	11000.00
0005433457061	1459	Economy	11000.00
0005433457058	1459	Economy	11000.00
0005433398860	1459	Economy	11000.00
0005433398532	1459	Economy	11000.00
0005433398559	1459	Economy	11000.00
0005433398812	1459	Economy	11000.00
0005432906568	1459	Economy	11000.00
0005433398665	1459	Economy	11000.00
0005433457060	1459	Economy	11000.00
0005433398941	1459	Economy	11000.00
0005433398533	1459	Economy	11000.00
0005433398703	1459	Economy	11000.00
0005433398745	1459	Economy	11000.00
0005433398483	1459	Economy	11000.00
0005432297336	1459	Economy	11000.00
0005433398829	1459	Economy	11000.00
0005433398787	1459	Economy	11000.00
0005433398726	1459	Economy	11000.00
0005433398692	1459	Economy	11000.00
0005433398836	1459	Economy	11000.00
0005433398767	1459	Economy	11000.00
0005433398666	1459	Economy	11000.00
0005433398445	1459	Economy	11000.00
0005433398761	1459	Economy	11000.00
0005433398765	1459	Economy	11000.00
0005432906570	1459	Economy	11000.00
0005433398704	1459	Economy	11000.00
0005433398444	1459	Economy	11000.00
0005433398747	1459	Economy	11000.00
0005433398613	1459	Economy	11000.00
0005433398707	1459	Economy	11000.00
0005433398828	1459	Economy	11000.00
0005433398614	1459	Economy	11000.00
0005433398776	1459	Economy	11000.00
0005433457062	1459	Economy	11000.00
0005433398858	1459	Economy	11000.00
0005433398644	1459	Economy	11000.00
0005433398748	1459	Economy	11000.00
0005433398708	1459	Economy	11000.00
0005433398940	1459	Economy	11000.00
0005433457038	19242	Business	33000.00
0005433399159	19242	Business	33000.00
0005433399136	19242	Business	33000.00
0005433399163	19242	Business	33000.00
0005433399119	19242	Business	33000.00
0005433399121	19242	Business	33000.00
0005433399118	19242	Business	33000.00
0005433399156	19242	Business	33000.00
0005433399165	19242	Economy	11000.00
0005433399127	19242	Economy	11000.00
0005433399150	19242	Economy	11000.00
0005433399160	19242	Economy	11000.00
0005433399149	19242	Economy	11000.00
0005433399142	19242	Economy	11000.00
0005433399129	19242	Economy	12100.00
0005435732574	19242	Economy	12100.00
0005432906590	19242	Economy	12100.00
0005433399124	19242	Economy	11000.00
0005435732575	19242	Economy	11000.00
0005433399154	19242	Economy	11000.00
0005433399131	19242	Economy	11000.00
0005435732541	19242	Economy	11000.00
0005433399126	19242	Economy	11000.00
0005433399130	19242	Economy	11000.00
0005433399128	19242	Economy	11000.00
0005433399140	19242	Economy	11000.00
0005433399151	19242	Economy	11000.00
0005433399157	19242	Economy	11000.00
0005433399148	19242	Economy	11000.00
0005433399161	19242	Economy	11000.00
0005433399122	19242	Economy	11000.00
0005435732540	19242	Economy	11000.00
0005433399155	19242	Economy	11000.00
0005433457015	19242	Economy	11000.00
0005433399132	19242	Economy	11000.00
0005433399139	19242	Economy	11000.00
0005432906593	19242	Economy	11000.00
0005435732505	19242	Economy	11000.00
0005433399123	19242	Economy	11000.00
0005433399133	19242	Economy	11000.00
0005433399143	19242	Economy	11000.00
0005432906592	19242	Economy	11000.00
0005433399134	19242	Economy	11000.00
0005433399164	19242	Economy	11000.00
0005433399146	19242	Economy	11000.00
0005433399120	19242	Economy	11000.00
0005433399152	19242	Economy	11000.00
0005433399135	19242	Economy	11000.00
0005432906591	19242	Economy	11000.00
0005433399144	19242	Economy	11000.00
0005433399153	19242	Economy	11000.00
0005433399125	19242	Economy	11000.00
0005433399137	19242	Economy	11000.00
0005433399158	19242	Economy	11000.00
0005433399166	19242	Economy	11000.00
0005433399147	19242	Economy	11000.00
0005435732514	19242	Economy	11000.00
0005433399138	19242	Economy	11000.00
0005433399141	19242	Economy	11000.00
0005433399145	19242	Economy	11000.00
0005433399162	19242	Economy	11000.00
0005435732482	19242	Economy	11000.00
0005435732513	19242	Economy	11000.00
0005434443903	17370	Economy	14100.00
0005434443889	17370	Economy	14100.00
0005434443933	17370	Economy	14100.00
0005434443949	17370	Economy	14100.00
0005434443904	17370	Economy	14100.00
0005434443888	17370	Economy	14100.00
0005434443953	17370	Economy	14100.00
0005434443983	17370	Economy	14100.00
0005434443918	17370	Economy	14100.00
0005434443805	17370	Economy	14100.00
0005434443948	17370	Economy	14100.00
0005434444054	20566	Economy	15600.00
0005434444063	20566	Economy	15600.00
0005434444066	20566	Economy	14100.00
0005434444061	20566	Economy	14100.00
0005434444056	20566	Economy	14100.00
0005434444058	20566	Economy	14100.00
0005434444068	20566	Economy	14100.00
0005434444059	20566	Economy	14100.00
0005434444060	20566	Economy	14100.00
0005434444064	20566	Economy	14100.00
0005434444062	20566	Economy	14100.00
0005434444055	20566	Economy	14100.00
0005434444067	20566	Economy	14100.00
0005434444057	20566	Economy	14100.00
0005434444065	20566	Economy	14100.00
0005434954699	7281	Economy	5800.00
0005434954695	7281	Economy	5800.00
0005434954697	7281	Economy	5800.00
0005434954698	7281	Economy	5800.00
0005435377618	7281	Economy	5800.00
0005434954696	7281	Economy	5800.00
0005435377617	7281	Economy	5800.00
0005435377616	7281	Economy	5800.00
0005435377634	28332	Economy	5800.00
0005434954655	28332	Economy	5800.00
0005434954656	28332	Economy	5800.00
0005435377633	28332	Economy	5800.00
0005434351984	4502	Economy	15400.00
0005434351978	4502	Economy	15400.00
0005434351980	4502	Economy	14000.00
0005434351977	4502	Economy	14000.00
0005434351975	4502	Economy	14000.00
0005434351985	4502	Economy	14000.00
0005434326285	4502	Economy	14000.00
0005435893736	4502	Economy	14000.00
0005434326284	4502	Economy	14000.00
0005434351981	4502	Economy	14000.00
0005435893735	4502	Economy	14000.00
0005434351983	4502	Economy	14000.00
0005434351982	4502	Economy	14000.00
0005434351979	4502	Economy	14000.00
0005434351986	4502	Economy	14000.00
0005434351976	4502	Economy	14000.00
0005435893733	4502	Economy	14000.00
0005434183604	4502	Economy	14000.00
0005434351987	4502	Economy	14000.00
0005435893794	29661	Economy	15400.00
0005435893792	29661	Economy	14000.00
0005435893793	29661	Economy	14000.00
0005434351800	29661	Economy	14000.00
0005435893789	29661	Economy	14000.00
0005434351878	29661	Economy	14000.00
0005434351854	29661	Economy	14000.00
0005434351890	29661	Economy	14000.00
0005434351895	29661	Economy	14000.00
0005435893791	29661	Economy	14000.00
0005435893790	29661	Economy	14000.00
0005434351879	29661	Economy	14000.00
0005435893795	29661	Economy	14000.00
0005433344742	1074	Business	30600.00
0005433344025	1074	Business	30600.00
0005433344613	1074	Business	30600.00
0005433344105	1074	Business	30600.00
0005435545902	1074	Business	30600.00
0005433343857	1074	Business	30600.00
0005433344593	1074	Business	30600.00
0005433463952	1074	Business	30600.00
0005433344415	1074	Business	30600.00
0005433344717	1074	Business	30600.00
0005434445302	1074	Business	30600.00
0005433344019	1074	Business	30600.00
0005435092295	1074	Business	30600.00
0005435545909	1074	Business	30600.00
0005433344741	1074	Business	30600.00
0005433344471	1074	Economy	11200.00
0005434446571	1074	Economy	11200.00
0005433344607	1074	Economy	11200.00
0005433344138	1074	Economy	11200.00
0005434445301	1074	Economy	10200.00
0005433344628	1074	Economy	10200.00
0005433344417	1074	Economy	10200.00
0005433344024	1074	Economy	10200.00
0005433344626	1074	Economy	10200.00
0005435545908	1074	Economy	10200.00
0005433344855	1074	Economy	10200.00
0005433344485	1074	Economy	10200.00
0005433344577	1074	Economy	10200.00
0005433344372	1074	Economy	10200.00
0005433344196	1074	Economy	10200.00
0005433344050	1074	Economy	10200.00
0005435092296	1074	Economy	10200.00
0005435545901	1074	Economy	10200.00
0005433344740	1074	Economy	10200.00
0005433344503	1074	Economy	10200.00
0005433344346	1074	Economy	10200.00
0005433344347	1074	Economy	10200.00
0005435092299	1074	Economy	10200.00
0005433344237	1074	Economy	10200.00
0005433344129	1074	Economy	10200.00
0005433344694	1074	Economy	10200.00
0005433344754	1074	Economy	10200.00
0005433344510	1074	Economy	10200.00
0005433344675	1074	Economy	10200.00
0005433344106	1074	Economy	10200.00
0005433344368	1074	Economy	10200.00
0005433344314	1074	Economy	10200.00
0005434446573	1074	Economy	10200.00
0005433344323	1074	Economy	10200.00
0005433344696	1074	Economy	10200.00
0005433344188	1074	Economy	10200.00
0005433344758	1074	Economy	10200.00
0005435092302	1074	Economy	10200.00
0005433462795	1074	Economy	10200.00
0005433344557	1074	Economy	10200.00
0005433344517	1074	Economy	10200.00
0005433344128	1074	Economy	10200.00
0005433344752	1074	Economy	10200.00
0005433344753	1074	Economy	10200.00
0005433344854	1074	Economy	10200.00
0005433344618	1074	Economy	10200.00
0005433344210	1074	Economy	10200.00
0005433344513	1074	Economy	10200.00
0005435545907	1074	Economy	10200.00
0005433344625	1074	Economy	10200.00
0005433344303	1074	Economy	10200.00
0005435092300	1074	Economy	10200.00
0005433344606	1074	Economy	10200.00
0005433343943	1074	Economy	10200.00
0005435545906	1074	Economy	10200.00
0005433344484	1074	Economy	10200.00
0005433344048	1074	Economy	10200.00
0005435092293	1074	Economy	10200.00
0005433159341	1074	Economy	10200.00
0005435545900	1074	Economy	10200.00
0005432293263	1074	Economy	10200.00
0005433344291	1074	Economy	10200.00
0005435545905	1074	Economy	10200.00
0005433344624	1074	Economy	10200.00
0005434446572	1074	Economy	10200.00
0005433159338	1074	Economy	10200.00
0005433344525	1074	Economy	10200.00
0005433344256	1074	Economy	10200.00
0005433344548	1074	Economy	10200.00
0005433344420	1074	Economy	10200.00
0005433344556	1074	Economy	10200.00
0005433344547	1074	Economy	10200.00
0005433463948	1074	Economy	11200.00
0005433344308	1074	Economy	10200.00
0005435545911	1074	Economy	11200.00
0005433269779	1074	Economy	10200.00
0005433344602	1074	Economy	11200.00
0005433343944	1074	Economy	11200.00
0005433344369	1074	Economy	10200.00
0005433344173	1074	Economy	10200.00
0005433344472	1074	Economy	10200.00
0005433344360	1074	Economy	10200.00
0005433344403	1074	Economy	10200.00
0005435545910	1074	Economy	10200.00
0005435092298	1074	Economy	10200.00
0005433344049	1074	Economy	10200.00
0005433344359	1074	Economy	10200.00
0005435092297	1074	Economy	10200.00
0005433344195	1074	Economy	10200.00
0005435092301	1074	Economy	10200.00
0005433463951	1074	Economy	10200.00
0005433344495	1074	Economy	10200.00
0005433344215	1074	Economy	10200.00
0005433344448	1074	Economy	10200.00
0005433269802	1074	Economy	10200.00
0005433344627	1074	Economy	10200.00
0005433344575	1074	Economy	10200.00
0005435545903	1074	Economy	10200.00
0005433344676	1074	Economy	10200.00
0005433463949	1074	Economy	10200.00
0005435545899	1074	Economy	10200.00
0005433344374	1074	Economy	10200.00
0005433344656	1074	Economy	10200.00
0005433344047	1074	Economy	10200.00
0005433344442	1074	Economy	10200.00
0005433463950	1074	Economy	10200.00
0005433344601	1074	Economy	10200.00
0005433344928	1074	Economy	10200.00
0005433344697	1074	Economy	10200.00
0005435092294	1074	Economy	10200.00
0005433344636	1074	Economy	10200.00
0005433344864	1074	Economy	10200.00
0005433344788	1074	Economy	10200.00
0005433345027	1074	Economy	10200.00
0005433344466	1074	Economy	10200.00
0005433344373	1074	Economy	10200.00
0005433269797	1074	Economy	10200.00
0005433344257	1074	Economy	10200.00
0005432293262	1074	Economy	10200.00
0005433269776	1074	Economy	10200.00
0005433344654	1074	Economy	10200.00
0005433344189	1074	Economy	10200.00
0005433344104	1074	Economy	10200.00
0005435545904	1074	Economy	10200.00
0005433344518	1074	Economy	10200.00
0005433344576	1074	Economy	10200.00
0005434446574	1074	Economy	10200.00
0005433344732	1074	Economy	10200.00
0005433344603	1074	Economy	10200.00
0005433344137	1074	Economy	10200.00
0005433344914	1074	Economy	10200.00
0005433345323	17033	Business	30600.00
0005433345310	17033	Business	30600.00
0005435508493	17033	Business	30600.00
0005433345258	17033	Business	30600.00
0005433269840	17033	Business	30600.00
0005433345267	17033	Business	30600.00
0005433345333	17033	Business	30600.00
0005435092227	17033	Business	30600.00
0005433345314	17033	Business	30600.00
0005433345338	17033	Business	30600.00
0005435092233	17033	Business	30600.00
0005433345274	17033	Business	30600.00
0005433345264	17033	Business	30600.00
0005433345298	17033	Business	30600.00
0005433345303	17033	Business	30600.00
0005433345278	17033	Business	30600.00
0005433345299	17033	Business	30600.00
0005433345260	17033	Economy	11200.00
0005433345337	17033	Economy	11200.00
0005433345317	17033	Economy	11200.00
0005433345321	17033	Economy	10200.00
0005433345342	17033	Economy	10200.00
0005433345285	17033	Economy	10200.00
0005433159362	17033	Economy	10200.00
0005433345307	17033	Economy	10200.00
0005433345282	17033	Economy	10200.00
0005435508452	17033	Economy	10200.00
0005433345252	17033	Economy	10200.00
0005433345301	17033	Economy	10200.00
0005433345255	17033	Economy	10200.00
0005435092210	17033	Economy	10200.00
0005435508490	17033	Economy	10200.00
0005433345313	17033	Economy	10200.00
0005433345249	17033	Economy	10200.00
0005433345293	17033	Economy	10200.00
0005435508511	17033	Economy	10200.00
0005433345263	17033	Economy	10200.00
0005433345335	17033	Economy	10200.00
0005433345340	17033	Economy	10200.00
0005435508504	17033	Economy	10200.00
0005435092209	17033	Economy	10200.00
0005435508418	17033	Economy	10200.00
0005433345270	17033	Economy	10200.00
0005433345268	17033	Economy	10200.00
0005435092221	17033	Economy	10200.00
0005433345308	17033	Economy	10200.00
0005433345326	17033	Economy	10200.00
0005433345311	17033	Economy	10200.00
0005433345277	17033	Economy	10200.00
0005435092251	17033	Economy	10200.00
0005433345318	17033	Economy	10200.00
0005433345348	17033	Economy	10200.00
0005433345254	17033	Economy	10200.00
0005433345259	17033	Economy	10200.00
0005433345309	17033	Economy	10200.00
0005433345331	17033	Economy	10200.00
0005433345322	17033	Economy	10200.00
0005433345290	17033	Economy	10200.00
0005433345344	17033	Economy	10200.00
0005433345294	17033	Economy	10200.00
0005433345302	17033	Economy	10200.00
0005433345347	17033	Economy	10200.00
0005433345345	17033	Economy	10200.00
0005433345312	17033	Economy	10200.00
0005433345269	17033	Economy	10200.00
0005433345280	17033	Economy	10200.00
0005435092232	17033	Economy	10200.00
0005433345281	17033	Economy	10200.00
0005433345292	17033	Economy	10200.00
0005435508419	17033	Economy	10200.00
0005433345343	17033	Economy	10200.00
0005435092260	17033	Economy	10200.00
0005433345284	17033	Economy	10200.00
0005433345304	17033	Economy	10200.00
0005433345297	17033	Economy	10200.00
0005433345262	17033	Economy	11200.00
0005433345273	17033	Economy	10200.00
0005433345330	17033	Economy	10200.00
0005433345286	17033	Economy	11200.00
0005433345306	17033	Economy	10200.00
0005433345336	17033	Economy	10200.00
0005433345305	17033	Economy	10200.00
0005433345339	17033	Economy	10200.00
0005433345251	17033	Economy	10200.00
0005433345250	17033	Economy	10200.00
0005435508466	17033	Economy	10200.00
0005433345287	17033	Economy	10200.00
0005433345319	17033	Economy	10200.00
0005433345289	17033	Economy	10200.00
0005435092211	17033	Economy	10200.00
0005433345291	17033	Economy	10200.00
0005433345288	17033	Economy	10200.00
0005433269839	17033	Economy	10200.00
0005433345295	17033	Economy	10200.00
0005433269838	17033	Economy	10200.00
0005433345332	17033	Economy	10200.00
0005433345316	17033	Economy	10200.00
0005433345334	17033	Economy	10200.00
0005433345300	17033	Economy	10200.00
0005433345275	17033	Economy	10200.00
0005433345324	17033	Economy	10200.00
0005433345329	17033	Economy	10200.00
0005433345253	17033	Economy	10200.00
0005433345261	17033	Economy	10200.00
0005433345279	17033	Economy	10200.00
0005433345266	17033	Economy	10200.00
0005433345283	17033	Economy	10200.00
0005433345296	17033	Economy	10200.00
0005435508503	17033	Economy	10200.00
0005433345271	17033	Economy	10200.00
0005433269843	17033	Economy	10200.00
0005433345257	17033	Economy	10200.00
0005433345346	17033	Economy	10200.00
0005433345341	17033	Economy	10200.00
0005433158197	17033	Economy	10200.00
0005433345272	17033	Economy	10200.00
0005435508495	17033	Economy	10200.00
0005435508501	17033	Economy	10200.00
0005435508491	17033	Economy	10200.00
0005435508502	17033	Economy	10200.00
0005435092212	17033	Economy	10200.00
0005433345265	17033	Economy	10200.00
0005433345325	17033	Economy	10200.00
0005433345328	17033	Economy	10200.00
0005435092228	17033	Economy	10200.00
0005435508494	17033	Economy	10200.00
0005433269842	17033	Economy	10200.00
0005433345320	17033	Economy	10200.00
0005433269841	17033	Economy	10200.00
0005433345315	17033	Economy	10200.00
0005433345256	17033	Economy	10200.00
0005433345327	17033	Economy	10200.00
0005433345276	17033	Economy	10200.00
0005434082200	12796	Business	40300.00
0005433812955	12796	Business	40300.00
0005434068378	12796	Business	40300.00
0005434068499	12796	Business	40300.00
0005434068510	12796	Business	40300.00
0005434068383	12796	Business	40300.00
0005434068665	12796	Business	40300.00
0005434068468	12796	Business	40300.00
0005434082179	12796	Business	40300.00
0005434082203	12796	Business	40300.00
0005434068271	12796	Business	40300.00
0005434068377	12796	Economy	13400.00
0005434082216	12796	Economy	13400.00
0005434082184	12796	Economy	13400.00
0005432433799	12796	Economy	13400.00
0005434068203	12796	Economy	13400.00
0005434068519	12796	Economy	13400.00
0005434082183	12796	Economy	13400.00
0005434026732	12796	Economy	13400.00
0005434068417	12796	Economy	13400.00
0005434068279	12796	Economy	13400.00
0005434068344	12796	Economy	13400.00
0005434026733	12796	Economy	13400.00
0005434068087	12796	Economy	13400.00
0005434082247	12796	Economy	13400.00
0005434068148	12796	Economy	13400.00
0005434068673	12796	Economy	13400.00
0005434082169	12796	Economy	13400.00
0005432159960	12796	Economy	13400.00
0005434082191	12796	Economy	13400.00
0005434068607	12796	Economy	13400.00
0005434068550	12796	Economy	13400.00
0005434068441	12796	Economy	13400.00
0005433812953	12796	Economy	13400.00
0005434068606	12796	Economy	13400.00
0005434068568	12796	Economy	13400.00
0005434068292	12796	Economy	13400.00
0005434068613	12796	Economy	13400.00
0005434082213	12796	Economy	13400.00
0005434068666	12796	Economy	13400.00
0005434068214	12796	Economy	13400.00
0005434082226	12796	Economy	13400.00
0005434068343	12796	Economy	13400.00
0005434068524	12796	Economy	13400.00
0005434068551	12796	Economy	13400.00
0005434082259	12796	Economy	13400.00
0005434068549	12796	Economy	13400.00
0005434082178	12796	Economy	13400.00
0005434068345	12796	Economy	13400.00
0005434026730	12796	Economy	14800.00
0005434068387	12796	Economy	14800.00
0005434068594	12796	Economy	14800.00
0005434082192	12796	Economy	14800.00
0005434068306	12796	Economy	14800.00
0005434068585	12796	Economy	14800.00
0005434068259	12796	Economy	13400.00
0005434068418	12796	Economy	13400.00
0005434068381	12796	Economy	13400.00
0005434068512	12796	Economy	13400.00
0005434068391	12796	Economy	13400.00
0005434068291	12796	Economy	13400.00
0005434068303	12796	Economy	13400.00
0005432159959	12796	Economy	13400.00
0005434068506	12796	Economy	13400.00
0005434068278	12796	Economy	13400.00
0005434068634	12796	Economy	13400.00
0005434068390	12796	Economy	13400.00
0005434068525	12796	Economy	13400.00
0005434067970	12796	Economy	13400.00
0005434068586	12796	Economy	13400.00
0005434068342	12796	Economy	13400.00
0005433812954	12796	Economy	13400.00
0005434068614	12796	Economy	13400.00
0005434068543	12796	Economy	13400.00
0005434068635	12796	Economy	13400.00
0005434068121	12796	Economy	13400.00
0005432433800	12796	Economy	13400.00
0005432433802	12796	Economy	13400.00
0005434068354	12796	Economy	13400.00
0005434068670	12796	Economy	13400.00
0005434068505	12796	Economy	13400.00
0005434082182	12796	Economy	13400.00
0005434082123	12796	Economy	13400.00
0005434082193	12796	Economy	13400.00
0005434068273	12796	Economy	13400.00
0005434068307	12796	Economy	13400.00
0005434068479	12796	Economy	13400.00
0005434082250	12796	Economy	13400.00
0005434068399	12796	Economy	13400.00
0005434068274	12796	Economy	13400.00
0005434068567	12796	Economy	13400.00
0005434068604	12796	Economy	13400.00
0005434068552	12796	Economy	13400.00
0005434068502	12796	Economy	13400.00
0005434067969	12796	Economy	13400.00
0005432433801	12796	Economy	13400.00
0005434068400	12796	Economy	13400.00
0005434068346	12796	Economy	13400.00
0005434068566	12796	Economy	13400.00
0005434082214	12796	Economy	13400.00
0005434068618	12796	Economy	13400.00
0005434068603	12796	Economy	13400.00
0005432159961	12796	Economy	13400.00
0005434082185	12796	Economy	13400.00
0005434068401	12796	Economy	13400.00
0005434068213	12796	Economy	13400.00
0005434068540	12796	Economy	13400.00
0005434082251	12796	Economy	13400.00
0005434082258	12796	Economy	13400.00
0005434068612	12796	Economy	13400.00
0005434068494	12796	Economy	13400.00
0005434068380	12796	Economy	13400.00
0005434068511	12796	Economy	13400.00
0005434068290	12796	Economy	13400.00
0005434068611	12796	Economy	13400.00
0005434068571	12796	Economy	13400.00
0005432159962	12796	Economy	13400.00
0005432161203	12796	Economy	13400.00
0005434068270	12796	Economy	13400.00
0005434068268	12796	Economy	13400.00
0005434068376	12796	Economy	13400.00
0005434068671	12796	Economy	13400.00
0005434067971	12796	Economy	13400.00
0005434068336	12796	Economy	13400.00
0005432161204	12796	Economy	13400.00
0005434068088	12796	Economy	13400.00
0005434069072	30692	Business	40300.00
0005434069112	30692	Business	40300.00
0005434069122	30692	Business	40300.00
0005434069064	30692	Business	40300.00
0005434069119	30692	Business	40300.00
0005432433761	30692	Business	40300.00
0005434069073	30692	Business	40300.00
0005434069059	30692	Business	40300.00
0005434069075	30692	Business	40300.00
0005434069124	30692	Business	40300.00
0005434069057	30692	Business	40300.00
0005434082399	30692	Business	40300.00
0005432433748	30692	Economy	13400.00
0005432186948	30692	Economy	13400.00
0005434069099	30692	Economy	13400.00
0005434069070	30692	Economy	13400.00
0005434069089	30692	Economy	13400.00
0005434069110	30692	Economy	13400.00
0005434069108	30692	Economy	13400.00
0005432186947	30692	Economy	13400.00
0005433989875	30692	Economy	13400.00
0005432433752	30692	Economy	13400.00
0005434082394	30692	Economy	13400.00
0005434082395	30692	Economy	13400.00
0005432433762	30692	Economy	13400.00
0005434069060	30692	Economy	13400.00
0005434069065	30692	Economy	13400.00
0005434082401	30692	Economy	13400.00
0005434082423	30692	Economy	13400.00
0005433989871	30692	Economy	13400.00
0005434069092	30692	Economy	13400.00
0005434069103	30692	Economy	13400.00
0005434069091	30692	Economy	13400.00
0005434069109	30692	Economy	13400.00
0005434069106	30692	Economy	13400.00
0005434082406	30692	Economy	13400.00
0005432150363	30692	Economy	13400.00
0005434069084	30692	Economy	13400.00
0005434069078	30692	Economy	13400.00
0005434082420	30692	Economy	13400.00
0005434069071	30692	Economy	13400.00
0005434082421	30692	Economy	13400.00
0005434082397	30692	Economy	13400.00
0005432433772	30692	Economy	13400.00
0005434069114	30692	Economy	13400.00
0005434069095	30692	Economy	13400.00
0005434082419	30692	Economy	13400.00
0005434082396	30692	Economy	13400.00
0005434069081	30692	Economy	13400.00
0005434069102	30692	Economy	13400.00
0005434082408	30692	Economy	14800.00
0005433989873	30692	Economy	14800.00
0005432150361	30692	Economy	14800.00
0005432150366	30692	Economy	14800.00
0005434069096	30692	Economy	14800.00
0005434082414	30692	Economy	14800.00
0005434069067	30692	Economy	13400.00
0005434069077	30692	Economy	13400.00
0005434069117	30692	Economy	13400.00
0005434069082	30692	Economy	13400.00
0005434069080	30692	Economy	13400.00
0005434069115	30692	Economy	13400.00
0005434069097	30692	Economy	13400.00
0005434082415	30692	Economy	13400.00
0005432186950	30692	Economy	13400.00
0005434069066	30692	Economy	13400.00
0005434082407	30692	Economy	13400.00
0005434069076	30692	Economy	13400.00
0005434069104	30692	Economy	13400.00
0005434069126	30692	Economy	13400.00
0005434069107	30692	Economy	13400.00
0005434082402	30692	Economy	13400.00
0005434082393	30692	Economy	13400.00
0005434069086	30692	Economy	13400.00
0005434069068	30692	Economy	13400.00
0005432186949	30692	Economy	13400.00
0005434069083	30692	Economy	13400.00
0005434082417	30692	Economy	13400.00
0005433989874	30692	Economy	13400.00
0005434069101	30692	Economy	13400.00
0005434069093	30692	Economy	13400.00
0005434069074	30692	Economy	13400.00
0005432433763	30692	Economy	13400.00
0005433989872	30692	Economy	13400.00
0005434069113	30692	Economy	13400.00
0005432150362	30692	Economy	13400.00
0005434069123	30692	Economy	13400.00
0005434082409	30692	Economy	13400.00
0005434069121	30692	Economy	13400.00
0005434082412	30692	Economy	13400.00
0005434069118	30692	Economy	13400.00
0005434069116	30692	Economy	13400.00
0005434069105	30692	Economy	13400.00
0005432150364	30692	Economy	13400.00
0005434082392	30692	Economy	13400.00
0005434069087	30692	Economy	13400.00
0005434082422	30692	Economy	13400.00
0005434069062	30692	Economy	13400.00
0005434082425	30692	Economy	13400.00
0005434082410	30692	Economy	13400.00
0005432150367	30692	Economy	13400.00
0005434082405	30692	Economy	13400.00
0005434069088	30692	Economy	13400.00
0005434069085	30692	Economy	13400.00
0005434069063	30692	Economy	13400.00
0005434069094	30692	Economy	13400.00
0005434082418	30692	Economy	13400.00
0005434069127	30692	Economy	13400.00
0005434069120	30692	Economy	13400.00
0005434082416	30692	Economy	13400.00
0005432150365	30692	Economy	13400.00
0005434069090	30692	Economy	13400.00
0005434069069	30692	Economy	13400.00
0005434082424	30692	Economy	13400.00
0005434069125	30692	Economy	13400.00
0005434069111	30692	Economy	13400.00
0005434082403	30692	Economy	13400.00
0005434082398	30692	Economy	13400.00
0005434082411	30692	Economy	13400.00
0005434069100	30692	Economy	13400.00
0005434082404	30692	Economy	13400.00
0005434082413	30692	Economy	13400.00
0005434069098	30692	Economy	13400.00
0005434069079	30692	Economy	13400.00
0005434069058	30692	Economy	13400.00
0005434082400	30692	Economy	13400.00
0005432150360	30692	Economy	13400.00
0005434069061	30692	Economy	13400.00
0005433686662	19349	Economy	19300.00
0005433689934	19349	Economy	19300.00
0005433686658	19349	Economy	17600.00
0005433686654	19349	Economy	17600.00
0005433689925	19349	Economy	17600.00
0005433689936	19349	Economy	17600.00
0005433686653	19349	Economy	17600.00
0005433689929	19349	Economy	17600.00
0005433686649	19349	Economy	17600.00
0005433686652	19349	Economy	17600.00
0005433686651	19349	Economy	17600.00
0005433689937	19349	Economy	17600.00
0005433686660	19349	Economy	17600.00
0005433686659	19349	Economy	17600.00
0005435767583	5495	Business	35300.00
0005434265515	5495	Business	35300.00
0005435767615	5495	Business	35300.00
0005433527351	5495	Business	35300.00
0005435767579	5495	Business	35300.00
0005435767626	5495	Business	35300.00
0005435725703	5495	Business	35300.00
0005435767582	5495	Business	35300.00
0005435462789	5495	Business	35300.00
0005435767613	5495	Business	35300.00
0005435767622	5495	Business	35300.00
0005435767601	5495	Business	35300.00
0005433529363	5495	Business	35300.00
0005435767593	5495	Business	35300.00
0005435767588	5495	Business	35300.00
0005434265479	5495	Business	35300.00
0005435767610	5495	Business	35300.00
0005434265527	5495	Business	35300.00
0005434265442	5495	Business	35300.00
0005435767599	5495	Business	35300.00
0005435462904	5495	Business	35300.00
0005435462850	5495	Business	35300.00
0005435463084	5495	Business	35300.00
0005435720849	5495	Business	35300.00
0005434265488	5495	Business	35300.00
0005435767620	5495	Economy	12900.00
0005435463058	5495	Economy	12900.00
0005434265487	5495	Economy	11800.00
0005435462845	5495	Economy	12900.00
0005435462969	5495	Economy	11800.00
0005435767625	5495	Economy	11800.00
0005435725705	5495	Economy	11800.00
0005435722109	5495	Economy	11800.00
0005435767609	5495	Economy	11800.00
0005435767591	5495	Economy	11800.00
0005434265419	5495	Economy	11800.00
0005435767596	5495	Economy	11800.00
0005435767597	5495	Economy	11800.00
0005435462961	5495	Economy	11800.00
0005435767628	5495	Economy	11800.00
0005432140630	5495	Economy	11800.00
0005435462788	5495	Economy	11800.00
0005434265509	5495	Economy	11800.00
0005434265393	5495	Economy	11800.00
0005433527354	5495	Economy	11800.00
0005434265473	5495	Economy	11800.00
0005434265549	5495	Economy	11800.00
0005435462967	5495	Economy	11800.00
0005435723087	5495	Economy	11800.00
0005435735240	5495	Economy	11800.00
0005435767602	5495	Economy	11800.00
0005434831206	5495	Economy	11800.00
0005434265450	5495	Economy	11800.00
0005435767616	5495	Economy	11800.00
0005435767577	5495	Economy	11800.00
0005435463108	5495	Economy	11800.00
0005435463048	5495	Economy	11800.00
0005434265503	5495	Economy	11800.00
0005435767630	5495	Economy	11800.00
0005435767623	5495	Economy	11800.00
0005434265598	5495	Economy	11800.00
0005435462906	5495	Economy	11800.00
0005435462985	5495	Economy	11800.00
0005435767619	5495	Economy	11800.00
0005435463004	5495	Economy	11800.00
0005435767629	5495	Economy	11800.00
0005434265595	5495	Economy	11800.00
0005435735242	5495	Economy	11800.00
0005435462920	5495	Economy	11800.00
0005435462943	5495	Economy	11800.00
0005435462931	5495	Economy	11800.00
0005435462993	5495	Economy	11800.00
0005435767585	5495	Economy	11800.00
0005435735241	5495	Economy	11800.00
0005435725709	5495	Economy	11800.00
0005435462787	5495	Economy	11800.00
0005435767584	5495	Economy	11800.00
0005435767617	5495	Economy	11800.00
0005432140633	5495	Economy	11800.00
0005435462903	5495	Economy	11800.00
0005434265338	5495	Economy	11800.00
0005435723086	5495	Economy	11800.00
0005435767595	5495	Economy	11800.00
0005435720850	5495	Economy	11800.00
0005434265337	5495	Economy	11800.00
0005433529362	5495	Economy	11800.00
0005435735238	5495	Economy	11800.00
0005434831199	5495	Economy	11800.00
0005435767603	5495	Economy	11800.00
0005435767627	5495	Economy	11800.00
0005435725707	5495	Economy	11800.00
0005435767605	5495	Economy	11800.00
0005435767580	5495	Economy	11800.00
0005435767574	5495	Economy	11800.00
0005434265550	5495	Economy	11800.00
0005435735239	5495	Economy	11800.00
0005432140628	5495	Economy	11800.00
0005432140629	5495	Economy	11800.00
0005435462874	5495	Economy	11800.00
0005435767606	5495	Economy	11800.00
0005435462999	5495	Economy	11800.00
0005435462934	5495	Economy	11800.00
0005435462965	5495	Economy	11800.00
0005435462898	5495	Economy	11800.00
0005435767621	5495	Economy	11800.00
0005435463059	5495	Economy	11800.00
0005432140635	5495	Economy	12900.00
0005435462902	5495	Economy	11800.00
0005434265452	5495	Economy	12900.00
0005435462844	5495	Economy	11800.00
0005435462861	5495	Economy	12900.00
0005435767631	5495	Economy	11800.00
0005435462757	5495	Economy	11800.00
0005435767592	5495	Economy	11800.00
0005435462901	5495	Economy	11800.00
0005435462811	5495	Economy	11800.00
0005435462935	5495	Economy	11800.00
0005435722108	5495	Economy	11800.00
0005434265451	5495	Economy	11800.00
0005434265467	5495	Economy	11800.00
0005434265494	5495	Economy	11800.00
0005432140634	5495	Economy	11800.00
0005435767607	5495	Economy	11800.00
0005435767604	5495	Economy	11800.00
0005434265502	5495	Economy	11800.00
0005435767598	5495	Economy	11800.00
0005434265421	5495	Economy	11800.00
0005435722110	5495	Economy	11800.00
0005435767611	5495	Economy	11800.00
0005435767586	5495	Economy	11800.00
0005435767578	5495	Economy	11800.00
0005435767633	5495	Economy	11800.00
0005435725708	5495	Economy	11800.00
0005434265339	5495	Economy	11800.00
0005435462851	5495	Economy	11800.00
0005432535885	5495	Economy	11800.00
0005435767614	5495	Economy	11800.00
0005432140631	5495	Economy	11800.00
0005433527353	5495	Economy	11800.00
0005435767624	5495	Economy	11800.00
0005435767581	5495	Economy	11800.00
0005432535880	5495	Economy	11800.00
0005435463085	5495	Economy	11800.00
0005435462949	5495	Economy	11800.00
0005433527352	5495	Economy	11800.00
0005435767576	5495	Economy	11800.00
0005434265420	5495	Economy	11800.00
0005435462888	5495	Economy	11800.00
0005435725706	5495	Economy	11800.00
0005435725704	5495	Economy	11800.00
0005435767589	5495	Economy	11800.00
0005433529366	5495	Economy	11800.00
0005435767612	5495	Economy	11800.00
0005434265508	5495	Economy	11800.00
0005435767594	5495	Economy	11800.00
0005433529365	5495	Economy	11800.00
0005432140632	5495	Economy	11800.00
0005434831190	5495	Economy	11800.00
0005432535881	5495	Economy	11800.00
0005435462994	5495	Economy	11800.00
0005433529364	5495	Economy	11800.00
0005435767632	5495	Economy	11800.00
0005434265594	5495	Economy	11800.00
0005435462945	5495	Economy	11800.00
0005435767575	5495	Economy	11800.00
0005435767587	5495	Economy	11800.00
0005435767618	5495	Economy	11800.00
0005435767608	5495	Economy	11800.00
0005432140636	5495	Economy	11800.00
0005434265468	5495	Economy	11800.00
0005435767590	5495	Economy	11800.00
0005435767600	5495	Economy	11800.00
0005432535886	5495	Economy	11800.00
0005435463294	13442	Business	35300.00
0005435767076	13442	Business	35300.00
0005435767024	13442	Business	35300.00
0005435766942	13442	Business	35300.00
0005433529320	13442	Business	35300.00
0005435725689	13442	Business	35300.00
0005435766867	13442	Business	35300.00
0005435463266	13442	Business	35300.00
0005435735193	13442	Business	35300.00
0005435766816	13442	Business	35300.00
0005435766875	13442	Business	35300.00
0005435766902	13442	Business	35300.00
0005435043301	13442	Business	35300.00
0005435463289	13442	Business	35300.00
0005435766994	13442	Business	35300.00
0005434265706	13442	Business	35300.00
0005435767121	13442	Business	35300.00
0005432535945	13442	Business	35300.00
0005435767147	13442	Business	35300.00
0005435463281	13442	Business	35300.00
0005435463290	13442	Business	35300.00
0005435725662	13442	Business	35300.00
0005432535943	13442	Business	35300.00
0005435463278	13442	Economy	12900.00
0005435735194	13442	Economy	12900.00
0005435463280	13442	Economy	12900.00
0005432194608	13442	Economy	12900.00
0005432535944	13442	Economy	11800.00
0005435767114	13442	Economy	11800.00
0005434265713	13442	Economy	11800.00
0005435767082	13442	Economy	11800.00
0005435767112	13442	Economy	11800.00
0005435463271	13442	Economy	11800.00
0005435463283	13442	Economy	11800.00
0005433533364	13442	Economy	11800.00
0005435767068	13442	Economy	11800.00
0005433529318	13442	Economy	11800.00
0005434831258	13442	Economy	11800.00
0005435767018	13442	Economy	11800.00
0005435766960	13442	Economy	11800.00
0005435766849	13442	Economy	11800.00
0005435767092	13442	Economy	11800.00
0005435463300	13442	Economy	11800.00
0005433533353	13442	Economy	11800.00
0005435463265	13442	Economy	11800.00
0005435767019	13442	Economy	11800.00
0005434265711	13442	Economy	11800.00
0005435463296	13442	Economy	11800.00
0005434265714	13442	Economy	11800.00
0005435463279	13442	Economy	11800.00
0005434831257	13442	Economy	11800.00
0005435463274	13442	Economy	11800.00
0005435463275	13442	Economy	11800.00
0005435463292	13442	Economy	11800.00
0005435463268	13442	Economy	11800.00
0005435766894	13442	Economy	11800.00
0005434265721	13442	Economy	11800.00
0005435767044	13442	Economy	11800.00
0005434265723	13442	Economy	11800.00
0005435722085	13442	Economy	11800.00
0005435767081	13442	Economy	11800.00
0005434265720	13442	Economy	11800.00
0005435766866	13442	Economy	11800.00
0005433529308	13442	Economy	11800.00
0005433533352	13442	Economy	11800.00
0005435767069	13442	Economy	11800.00
0005434265730	13442	Economy	11800.00
0005434265724	13442	Economy	11800.00
0005435463287	13442	Economy	11800.00
0005433529315	13442	Economy	11800.00
0005434265707	13442	Economy	11800.00
0005435766995	13442	Economy	11800.00
0005434265726	13442	Economy	11800.00
0005433529322	13442	Economy	11800.00
0005435767010	13442	Economy	11800.00
0005433529319	13442	Economy	11800.00
0005432194607	13442	Economy	11800.00
0005434265708	13442	Economy	11800.00
0005435766944	13442	Economy	11800.00
0005435463286	13442	Economy	11800.00
0005435722078	13442	Economy	11800.00
0005433529325	13442	Economy	11800.00
0005433529324	13442	Economy	11800.00
0005435463276	13442	Economy	11800.00
0005435766941	13442	Economy	11800.00
0005435766983	13442	Economy	11800.00
0005435735207	13442	Economy	11800.00
0005435463267	13442	Economy	11800.00
0005435463295	13442	Economy	11800.00
0005435767009	13442	Economy	11800.00
0005435767023	13442	Economy	11800.00
0005435766838	13442	Economy	11800.00
0005435722084	13442	Economy	11800.00
0005434831256	13442	Economy	11800.00
0005432194604	13442	Economy	11800.00
0005435767091	13442	Economy	11800.00
0005434265719	13442	Economy	11800.00
0005432535946	13442	Economy	11800.00
0005433533371	13442	Economy	11800.00
0005435463285	13442	Economy	11800.00
0005435766999	13442	Economy	11800.00
0005433533363	13442	Economy	11800.00
0005432194605	13442	Economy	11800.00
0005435463298	13442	Economy	11800.00
0005435766975	13442	Economy	11800.00
0005434831259	13442	Economy	11800.00
0005432194606	13442	Economy	11800.00
0005435766961	13442	Economy	11800.00
0005435767093	13442	Economy	11800.00
0005435767067	13442	Economy	11800.00
0005435463293	13442	Economy	11800.00
0005435767032	13442	Economy	12900.00
0005435767026	13442	Economy	11800.00
0005434265732	13442	Economy	11800.00
0005435766776	13442	Economy	11800.00
0005434265715	13442	Economy	12900.00
0005435725675	13442	Economy	12900.00
0005435722091	13442	Economy	11800.00
0005435766981	13442	Economy	11800.00
0005434265718	13442	Economy	11800.00
0005435463284	13442	Economy	11800.00
0005435463301	13442	Economy	11800.00
0005435463299	13442	Economy	11800.00
0005435463297	13442	Economy	11800.00
0005435766982	13442	Economy	11800.00
0005434265709	13442	Economy	11800.00
0005434265716	13442	Economy	11800.00
0005435463270	13442	Economy	11800.00
0005435043299	13442	Economy	11800.00
0005435766857	13442	Economy	11800.00
0005435767016	13442	Economy	11800.00
0005435463291	13442	Economy	11800.00
0005435735210	13442	Economy	11800.00
0005435722083	13442	Economy	11800.00
0005434265728	13442	Economy	11800.00
0005434265722	13442	Economy	11800.00
0005435463273	13442	Economy	11800.00
0005433529304	13442	Economy	11800.00
0005435766901	13442	Economy	11800.00
0005435722081	13442	Economy	11800.00
0005433533372	13442	Economy	11800.00
0005435767039	13442	Economy	11800.00
0005435463277	13442	Economy	11800.00
0005435463269	13442	Economy	11800.00
0005435766959	13442	Economy	11800.00
0005434831260	13442	Economy	11800.00
0005435767088	13442	Economy	11800.00
0005435767087	13442	Economy	11800.00
0005435766839	13442	Economy	11800.00
0005435767031	13442	Economy	11800.00
0005433529326	13442	Economy	11800.00
0005434265717	13442	Economy	11800.00
0005434265725	13442	Economy	11800.00
0005435767037	13442	Economy	11800.00
0005434265729	13442	Economy	11800.00
0005435043300	13442	Economy	11800.00
0005435767030	13442	Economy	11800.00
0005434265712	13442	Economy	11800.00
0005433533362	13442	Economy	11800.00
0005435767066	13442	Economy	11800.00
0005434265727	13442	Economy	11800.00
0005435767038	13442	Economy	11800.00
0005435463282	13442	Economy	11800.00
0005435463288	13442	Economy	11800.00
0005435463272	13442	Economy	11800.00
0005435766861	13442	Economy	11800.00
0005435766878	13442	Economy	11800.00
0005434265710	13442	Economy	11800.00
0005433529316	13442	Economy	11800.00
0005435766774	13442	Economy	11800.00
0005434265731	13442	Economy	11800.00
0005435766998	13442	Economy	11800.00
0005435766841	13442	Economy	11800.00
0005435766858	13442	Economy	11800.00
0005435766775	13442	Economy	11800.00
0005435767118	13442	Economy	11800.00
0005434602931	18694	Economy	3300.00
0005434602929	18694	Economy	3300.00
0005434602930	18694	Economy	3300.00
0005434602936	18694	Economy	3300.00
0005434604943	18718	Economy	3300.00
0005434513637	18718	Economy	3300.00
0005434604935	18718	Economy	3300.00
0005434604937	18718	Economy	3300.00
0005434513636	18718	Economy	3300.00
0005434515024	18718	Economy	3300.00
0005434515025	18718	Economy	3300.00
0005434604930	18718	Economy	3300.00
0005434604938	18718	Economy	3300.00
0005434604942	18718	Economy	3300.00
0005434604936	18718	Economy	3300.00
0005434515023	18718	Economy	3300.00
0005434515012	19211	Economy	3300.00
0005434515011	19211	Economy	3300.00
0005434515007	19211	Economy	3300.00
0005434515008	19211	Economy	3300.00
0005434515005	19211	Economy	3300.00
0005432649530	4133	Business	88300.00
0005432649540	4133	Business	88300.00
0005435846298	4133	Business	88300.00
0005432632898	4133	Business	88300.00
0005432632888	4133	Business	88300.00
0005435846280	4133	Business	88300.00
0005432632890	4133	Economy	29400.00
0005432649529	4133	Economy	29400.00
0005432632882	4133	Economy	29400.00
0005435844342	4133	Economy	29400.00
0005432649535	4133	Economy	29400.00
0005432649537	4133	Economy	29400.00
0005432649531	4133	Economy	32400.00
0005432632895	4133	Economy	32400.00
0005432632902	4133	Economy	32400.00
0005432632894	4133	Economy	29400.00
0005435844355	4133	Economy	29400.00
0005432632887	4133	Economy	29400.00
0005432649532	4133	Economy	29400.00
0005432649538	4133	Economy	29400.00
0005432649542	4133	Economy	29400.00
0005432632891	4133	Economy	29400.00
0005432632889	4133	Economy	29400.00
0005432632892	4133	Economy	29400.00
0005432632884	4133	Economy	29400.00
0005432632897	4133	Economy	29400.00
0005432632883	4133	Economy	29400.00
0005435844354	4133	Economy	29400.00
0005432649533	4133	Economy	29400.00
0005435846301	4133	Economy	29400.00
0005435844372	4133	Economy	29400.00
0005432649528	4133	Economy	29400.00
0005432632899	4133	Economy	29400.00
0005432649527	4133	Economy	29400.00
0005432632893	4133	Economy	29400.00
0005435844368	4133	Economy	29400.00
0005435844373	4133	Economy	29400.00
0005432632886	4133	Economy	29400.00
0005432632901	4133	Economy	29400.00
0005432632881	4133	Economy	29400.00
0005435844378	4133	Economy	29400.00
0005432649543	4133	Economy	29400.00
0005435844338	4133	Economy	29400.00
0005432649534	4133	Economy	29400.00
0005432649539	4133	Economy	29400.00
0005435844364	4133	Economy	29400.00
0005435844371	4133	Economy	29400.00
0005435846292	4133	Economy	29400.00
0005432649536	4133	Economy	29400.00
0005435844367	4133	Economy	29400.00
0005435844365	4133	Economy	29400.00
0005432632896	4133	Economy	29400.00
0005435846311	4133	Economy	29400.00
0005432649541	4133	Economy	29400.00
0005435844357	4133	Economy	29400.00
0005432632885	4133	Economy	29400.00
0005432632900	4133	Economy	29400.00
0005433285689	1886	Business	48700.00
0005433285762	1886	Business	48700.00
0005433009358	1886	Business	48700.00
0005433009329	1886	Business	48700.00
0005433009328	1886	Business	48700.00
0005433009472	1886	Business	48700.00
0005433008909	1886	Business	48700.00
0005433009301	1886	Business	48700.00
0005433009445	1886	Business	48700.00
0005433285755	1886	Business	48700.00
0005433285809	1886	Business	48700.00
0005433009170	1886	Business	48700.00
0005433009196	1886	Economy	16200.00
0005433009000	1886	Economy	16200.00
0005433009428	1886	Economy	16200.00
0005433009376	1886	Economy	16200.00
0005433009169	1886	Economy	16200.00
0005433009375	1886	Economy	16200.00
0005433285730	1886	Economy	16200.00
0005433009377	1886	Economy	16200.00
0005433009397	1886	Economy	16200.00
0005433009223	1886	Economy	16200.00
0005433285754	1886	Economy	17900.00
0005433009179	1886	Economy	17900.00
0005433009243	1886	Economy	17900.00
0005433008908	1886	Economy	17900.00
0005433009271	1886	Economy	17900.00
0005433285688	1886	Economy	16200.00
0005433285656	1886	Economy	16200.00
0005433009367	1886	Economy	16200.00
0005433009127	1886	Economy	16200.00
0005433009570	1886	Economy	16200.00
0005433009291	1886	Economy	16200.00
0005433285741	1886	Economy	16200.00
0005433285793	1886	Economy	16200.00
0005433008999	1886	Economy	16200.00
0005433009241	1886	Economy	16200.00
0005433009504	1886	Economy	16200.00
0005432295939	1886	Economy	16200.00
0005433285649	1886	Economy	16200.00
0005433285774	1886	Economy	16200.00
0005433009028	1886	Economy	16200.00
0005433009240	1886	Economy	16200.00
0005433009180	1886	Economy	16200.00
0005433285710	1886	Economy	16200.00
0005433285759	1886	Economy	16200.00
0005433285761	1886	Economy	16200.00
0005433285744	1886	Economy	16200.00
0005433285728	1886	Economy	16200.00
0005433009374	1886	Economy	16200.00
0005433285750	1886	Economy	16200.00
0005433285826	1886	Economy	16200.00
0005433285742	1886	Economy	16200.00
0005433009074	1886	Economy	16200.00
0005433009126	1886	Economy	16200.00
0005433285751	1886	Economy	16200.00
0005433009287	1886	Economy	16200.00
0005433009217	1886	Economy	16200.00
0005433009429	1886	Economy	16200.00
0005433285621	1886	Economy	16200.00
0005433009391	1886	Economy	16200.00
0005433009505	1886	Economy	16200.00
0005433285620	1886	Economy	16200.00
0005433285672	1886	Economy	16200.00
0005432295938	1886	Economy	16200.00
0005433009238	1886	Economy	16200.00
0005433009153	1886	Economy	16200.00
0005433285771	1886	Economy	16200.00
0005433009200	1886	Economy	16200.00
0005433285652	1886	Economy	16200.00
0005433009330	1886	Economy	16200.00
0005433009390	1886	Economy	16200.00
0005433009389	1886	Economy	16200.00
0005433009239	1886	Economy	16200.00
0005433009199	1886	Economy	16200.00
0005433009181	1886	Economy	16200.00
0005433009302	1886	Economy	16200.00
0005433009371	1886	Economy	16200.00
0005433009242	1886	Economy	16200.00
0005433285683	1886	Economy	16200.00
0005433285682	1886	Economy	16200.00
0005433285648	1886	Economy	16200.00
0005433009244	1886	Economy	16200.00
0005433285864	1886	Economy	16200.00
0005433285757	1886	Economy	16200.00
0005433009278	1886	Economy	16200.00
0005433009152	1886	Economy	16200.00
0005433285758	1886	Economy	16200.00
0005433009125	1886	Economy	16200.00
0005433009154	1886	Economy	16200.00
0005433285781	1886	Economy	16200.00
0005433009210	1886	Economy	16200.00
0005433009306	1886	Economy	16200.00
0005433009571	1886	Economy	16200.00
0005433285851	1886	Economy	16200.00
0005433285794	1886	Economy	16200.00
0005433285631	1886	Economy	16200.00
0005433285992	22524	Business	48700.00
0005433009630	22524	Business	48700.00
0005433285973	22524	Business	48700.00
0005433009589	22524	Business	48700.00
0005433009611	22524	Business	48700.00
0005433285972	22524	Business	48700.00
0005433285982	22524	Business	48700.00
0005433285963	22524	Business	48700.00
0005433285988	22524	Business	48700.00
0005433285971	22524	Business	48700.00
0005433009588	22524	Business	48700.00
0005433009620	22524	Business	48700.00
0005433009601	22524	Economy	16200.00
0005433285980	22524	Economy	16200.00
0005433009599	22524	Economy	16200.00
0005433009602	22524	Economy	16200.00
0005433009594	22524	Economy	16200.00
0005433009604	22524	Economy	16200.00
0005433009605	22524	Economy	16200.00
0005433285969	22524	Economy	17900.00
0005433009619	22524	Economy	17900.00
0005433285981	22524	Economy	17900.00
0005433009591	22524	Economy	17900.00
0005433009598	22524	Economy	16200.00
0005433009614	22524	Economy	16200.00
0005433285970	22524	Economy	16200.00
0005433009592	22524	Economy	16200.00
0005433009606	22524	Economy	16200.00
0005433009612	22524	Economy	16200.00
0005433285986	22524	Economy	16200.00
0005433009613	22524	Economy	16200.00
0005433285987	22524	Economy	16200.00
0005433285984	22524	Economy	16200.00
0005433009600	22524	Economy	16200.00
0005433009586	22524	Economy	16200.00
0005433009590	22524	Economy	16200.00
0005433285966	22524	Economy	16200.00
0005433285975	22524	Economy	16200.00
0005433285977	22524	Economy	16200.00
0005433285991	22524	Economy	16200.00
0005433285993	22524	Economy	16200.00
0005433285983	22524	Economy	16200.00
0005433009625	22524	Economy	16200.00
0005433009595	22524	Economy	16200.00
0005433285968	22524	Economy	16200.00
0005433285985	22524	Economy	16200.00
0005433009627	22524	Economy	16200.00
0005433285978	22524	Economy	16200.00
0005433810582	22524	Economy	16200.00
0005433009624	22524	Economy	16200.00
0005433285976	22524	Economy	16200.00
0005433009628	22524	Economy	16200.00
0005433009607	22524	Economy	16200.00
0005433285964	22524	Economy	16200.00
0005433285989	22524	Economy	16200.00
0005433810581	22524	Economy	16200.00
0005433009610	22524	Economy	16200.00
0005433285974	22524	Economy	16200.00
0005433009621	22524	Economy	16200.00
0005433009615	22524	Economy	16200.00
0005433009585	22524	Economy	16200.00
0005433009609	22524	Economy	16200.00
0005433285967	22524	Economy	16200.00
0005433009596	22524	Economy	16200.00
0005433009597	22524	Economy	16200.00
0005433009593	22524	Economy	16200.00
0005433285990	22524	Economy	16200.00
0005433009629	22524	Economy	16200.00
0005433009608	22524	Economy	16200.00
0005433285979	22524	Economy	16200.00
0005433009626	22524	Economy	16200.00
0005433009617	22524	Economy	16200.00
0005433009618	22524	Economy	16200.00
0005433009623	22524	Economy	16200.00
0005433009603	22524	Economy	16200.00
0005433009622	22524	Economy	16200.00
0005433285965	22524	Economy	16200.00
0005433009616	22524	Economy	16200.00
0005433009587	22524	Economy	16200.00
0005433848024	5585	Business	99800.00
0005433848012	5585	Business	99800.00
0005433848036	5585	Business	99800.00
0005433848009	5585	Business	99800.00
0005432081655	5585	Business	99800.00
0005433848048	5585	Business	99800.00
0005435282925	5585	Business	99800.00
0005432081658	5585	Business	99800.00
0005433848038	5585	Business	99800.00
0005435282879	5585	Business	99800.00
0005433848026	5585	Business	99800.00
0005435282789	5585	Business	99800.00
0005433815492	5585	Business	99800.00
0005435282868	5585	Business	99800.00
0005432081654	5585	Business	99800.00
0005433848051	5585	Business	99800.00
0005433848032	5585	Business	99800.00
0005433848039	5585	Economy	33300.00
0005435282825	5585	Business	99800.00
0005433848044	5585	Economy	33300.00
0005433848023	5585	Economy	33300.00
0005433848018	5585	Economy	33300.00
0005433847999	5585	Economy	33300.00
0005435282824	5585	Economy	33300.00
0005433848049	5585	Economy	33300.00
0005433847994	5585	Economy	33300.00
0005433848007	5585	Economy	33300.00
0005433848021	5585	Economy	33300.00
0005435282899	5585	Economy	33300.00
0005435282926	5585	Economy	33300.00
0005433848027	5585	Economy	36600.00
0005433848035	5585	Economy	33300.00
0005433815489	5585	Economy	36600.00
0005433815491	5585	Economy	33300.00
0005435282847	5585	Economy	33300.00
0005433848005	5585	Economy	33300.00
0005433847996	5585	Economy	33300.00
0005433848020	5585	Economy	33300.00
0005435282765	5585	Economy	33300.00
0005435282918	5585	Economy	33300.00
0005432081657	5585	Economy	33300.00
0005432081653	5585	Economy	33300.00
0005433848003	5585	Economy	33300.00
0005435282787	5585	Economy	33300.00
0005433848013	5585	Economy	33300.00
0005435282946	5585	Economy	33300.00
0005434173565	5585	Economy	33300.00
0005433815488	5585	Economy	33300.00
0005435282839	5585	Economy	33300.00
0005433848006	5585	Economy	33300.00
0005435282883	5585	Economy	33300.00
0005433847998	5585	Economy	33300.00
0005433848030	5585	Economy	33300.00
0005433848041	5585	Economy	33300.00
0005433848001	5585	Economy	33300.00
0005433848037	5585	Economy	33300.00
0005433848043	5585	Economy	33300.00
0005434173576	5585	Economy	33300.00
0005433848047	5585	Economy	33300.00
0005433848031	5585	Economy	33300.00
0005435282809	5585	Economy	33300.00
0005432081656	5585	Economy	33300.00
0005434173564	5585	Economy	33300.00
0005433848014	5585	Economy	33300.00
0005433848050	5585	Economy	33300.00
0005434173575	5585	Economy	33300.00
0005433848002	5585	Economy	33300.00
0005433847995	5585	Economy	33300.00
0005435282852	5585	Economy	33300.00
0005433848025	5585	Economy	33300.00
0005433848046	5585	Economy	33300.00
0005435282869	5585	Economy	33300.00
0005433848017	5585	Economy	33300.00
0005433848010	5585	Economy	33300.00
0005433815490	5585	Economy	33300.00
0005433848016	5585	Economy	33300.00
0005433848034	5585	Economy	33300.00
0005433848015	5585	Economy	33300.00
0005433848008	5585	Economy	33300.00
0005433815537	5585	Economy	33300.00
0005435282849	5585	Economy	33300.00
0005435282850	5585	Economy	33300.00
0005433847997	5585	Economy	33300.00
0005435282810	5585	Economy	33300.00
0005433848028	5585	Economy	33300.00
0005433848019	5585	Economy	33300.00
0005433848052	5585	Economy	33300.00
0005433848011	5585	Economy	33300.00
0005435282851	5585	Economy	33300.00
0005435282837	5585	Economy	33300.00
0005435282788	5585	Economy	33300.00
0005433815493	5585	Economy	33300.00
0005435282917	5585	Economy	33300.00
0005433848040	5585	Economy	33300.00
0005433848004	5585	Economy	33300.00
0005435282828	5585	Economy	33300.00
0005435282870	5585	Economy	33300.00
0005433848033	5585	Economy	33300.00
0005433848000	5585	Economy	33300.00
0005433848029	5585	Economy	33300.00
0005435282871	5585	Economy	33300.00
0005433848022	5585	Economy	33300.00
0005435282797	5585	Economy	33300.00
0005433848053	5585	Economy	33300.00
0005433848042	5585	Economy	33300.00
0005435282838	5585	Economy	33300.00
0005433848045	5585	Economy	33300.00
0005433847505	13837	Business	99800.00
0005433847750	13837	Business	99800.00
0005433847442	13837	Business	99800.00
0005433815454	13837	Business	99800.00
0005433847400	13837	Business	99800.00
0005435283068	13837	Business	99800.00
0005435283054	13837	Business	99800.00
0005433847288	13837	Business	99800.00
0005433847148	13837	Business	99800.00
0005433847350	13837	Business	99800.00
0005433847623	13837	Business	99800.00
0005435283062	13837	Business	99800.00
0005433847663	13837	Business	99800.00
0005435283069	13837	Business	99800.00
0005433815455	13837	Business	99800.00
0005432003773	13837	Business	99800.00
0005433815439	13837	Business	99800.00
0005432003770	13837	Business	99800.00
0005435283065	13837	Business	99800.00
0005433847232	13837	Economy	33300.00
0005432003771	13837	Economy	33300.00
0005433847508	13837	Economy	33300.00
0005433847590	13837	Economy	33300.00
0005435283057	13837	Economy	33300.00
0005433847662	13837	Economy	33300.00
0005435283045	13837	Economy	33300.00
0005433847570	13837	Economy	33300.00
0005433847279	13837	Economy	33300.00
0005435283053	13837	Economy	33300.00
0005433847147	13837	Economy	33300.00
0005433847589	13837	Economy	36600.00
0005433847149	13837	Economy	36600.00
0005433847667	13837	Economy	36600.00
0005433847520	13837	Economy	36600.00
0005435283047	13837	Economy	33300.00
0005434173611	13837	Economy	33300.00
0005434173610	13837	Economy	33300.00
0005433847598	13837	Economy	33300.00
0005435283060	13837	Economy	33300.00
0005435283052	13837	Economy	33300.00
0005433847401	13837	Economy	33300.00
0005433815444	13837	Economy	33300.00
0005435283049	13837	Economy	33300.00
0005433847754	13837	Economy	33300.00
0005433847237	13837	Economy	33300.00
0005435283056	13837	Economy	33300.00
0005435283058	13837	Economy	33300.00
0005433847539	13837	Economy	33300.00
0005434173609	13837	Economy	33300.00
0005433847491	13837	Economy	33300.00
0005433847661	13837	Economy	33300.00
0005433847456	13837	Economy	33300.00
0005433847540	13837	Economy	33300.00
0005433815450	13837	Economy	33300.00
0005435283046	13837	Economy	33300.00
0005433847349	13837	Economy	33300.00
0005435283051	13837	Economy	33300.00
0005433847519	13837	Economy	33300.00
0005433847502	13837	Economy	33300.00
0005435283064	13837	Economy	33300.00
0005434173641	13837	Economy	33300.00
0005433847238	13837	Economy	33300.00
0005433847194	13837	Economy	33300.00
0005433847193	13837	Economy	33300.00
0005433847472	13837	Economy	33300.00
0005434173640	13837	Economy	33300.00
0005435283050	13837	Economy	33300.00
0005433847455	13837	Economy	33300.00
0005433847567	13837	Economy	33300.00
0005433847497	13837	Economy	33300.00
0005433847674	13837	Economy	33300.00
0005433847566	13837	Economy	33300.00
0005435283048	13837	Economy	33300.00
0005434173639	13837	Economy	33300.00
0005433847510	13837	Economy	33300.00
0005433847399	13837	Economy	33300.00
0005433815440	13837	Economy	33300.00
0005435283063	13837	Economy	33300.00
0005435283070	13837	Economy	33300.00
0005432003772	13837	Economy	33300.00
0005433847715	13837	Economy	33300.00
0005433847498	13837	Economy	33300.00
0005433847599	13837	Economy	33300.00
0005433847457	13837	Economy	33300.00
0005435283061	13837	Economy	33300.00
0005433815449	13837	Economy	33300.00
0005435283066	13837	Economy	33300.00
0005433815438	13837	Economy	33300.00
0005433847351	13837	Economy	33300.00
0005433847408	13837	Economy	33300.00
0005433847415	13837	Economy	33300.00
0005433847675	13837	Economy	33300.00
0005435283071	13837	Economy	33300.00
0005433847549	13837	Economy	33300.00
0005435283067	13837	Economy	33300.00
0005435283059	13837	Economy	33300.00
0005434173638	13837	Economy	33300.00
0005433847541	13837	Economy	33300.00
0005433815425	13837	Economy	33300.00
0005433847509	13837	Economy	33300.00
0005435283055	13837	Economy	33300.00
0005435283072	13837	Economy	33300.00
0005433847236	13837	Economy	33300.00
0005433847276	13837	Economy	33300.00
0005434621049	7838	Economy	16600.00
0005434621048	7838	Economy	16600.00
0005432112566	7838	Economy	15100.00
0005435332502	7838	Economy	15100.00
0005432112567	7838	Economy	15100.00
0005434621053	7838	Economy	15100.00
0005434621054	7838	Economy	15100.00
0005434621051	7838	Economy	15100.00
0005434621050	7838	Economy	15100.00
0005435332464	7838	Economy	15100.00
0005435332448	7838	Economy	15100.00
0005435332501	7838	Economy	15100.00
0005435332500	7838	Economy	15100.00
0005434621061	7838	Economy	15100.00
0005435332487	7838	Economy	15100.00
0005434621058	7838	Economy	15100.00
0005434621062	7838	Economy	15100.00
0005434621046	7838	Economy	15100.00
0005434621055	7838	Economy	15100.00
0005434621043	7838	Economy	15100.00
0005434621057	7838	Economy	15100.00
0005434621044	7838	Economy	15100.00
0005434621045	7838	Economy	15100.00
0005434621052	7838	Economy	15100.00
0005434621059	7838	Economy	15100.00
0005435332503	7838	Economy	15100.00
0005434621060	7838	Economy	15100.00
0005435332496	7838	Economy	15100.00
0005434621056	7838	Economy	15100.00
0005434621047	7838	Economy	15100.00
0005434620817	32965	Economy	16600.00
0005434620845	32965	Economy	15100.00
0005435332562	32965	Economy	15100.00
0005435332563	32965	Economy	15100.00
0005434620934	32965	Economy	15100.00
0005435332566	32965	Economy	15100.00
0005435332571	32965	Economy	15100.00
0005434620818	32965	Economy	15100.00
0005435332567	32965	Economy	15100.00
0005434620847	32965	Economy	15100.00
0005434620882	32965	Economy	15100.00
0005434620881	32965	Economy	15100.00
0005434620830	32965	Economy	15100.00
0005435332564	32965	Economy	15100.00
0005434620950	32965	Economy	15100.00
0005435332570	32965	Economy	15100.00
0005435332569	32965	Economy	15100.00
0005435332565	32965	Economy	15100.00
0005435332568	32965	Economy	15100.00
0005434620949	32965	Economy	15100.00
0005435787401	4302	Business	38000.00
0005435786118	4302	Business	38000.00
0005435786115	4302	Business	38000.00
0005435786131	4302	Business	38000.00
0005434994244	4302	Economy	12700.00
0005432190716	4302	Economy	12700.00
0005432190715	4302	Economy	12700.00
0005435786120	4302	Economy	12700.00
0005435786121	4302	Economy	13900.00
0005435786129	4302	Economy	13900.00
0005435786112	4302	Economy	13900.00
0005434994238	4302	Economy	13900.00
0005434994245	4302	Economy	12700.00
0005435786117	4302	Economy	12700.00
0005435786125	4302	Economy	12700.00
0005435787402	4302	Economy	12700.00
0005434994239	4302	Economy	12700.00
0005435918702	4302	Economy	12700.00
0005435918732	4302	Economy	12700.00
0005435786132	4302	Economy	12700.00
0005435786122	4302	Economy	12700.00
0005435918734	4302	Economy	12700.00
0005432190717	4302	Economy	12700.00
0005434994237	4302	Economy	12700.00
0005435786142	4302	Economy	12700.00
0005435786124	4302	Economy	12700.00
0005435786133	4302	Economy	12700.00
0005435786145	4302	Economy	12700.00
0005435786136	4302	Economy	12700.00
0005435786113	4302	Economy	12700.00
0005435786127	4302	Economy	12700.00
0005435937415	4302	Economy	12700.00
0005435786114	4302	Economy	12700.00
0005435786134	4302	Economy	12700.00
0005435937444	4302	Economy	12700.00
0005432190714	4302	Economy	12700.00
0005435786128	4302	Economy	12700.00
0005435786135	4302	Economy	12700.00
0005434994240	4302	Economy	12700.00
0005435786130	4302	Economy	12700.00
0005435786116	4302	Economy	12700.00
0005435786141	4302	Economy	12700.00
0005434994241	4302	Economy	12700.00
0005435786139	4302	Economy	12700.00
0005435786111	4302	Economy	12700.00
0005435786119	4302	Economy	12700.00
0005435786126	4302	Economy	12700.00
0005435786146	4302	Economy	12700.00
0005435786140	4302	Economy	12700.00
0005434994242	4302	Economy	12700.00
0005435786143	4302	Economy	12700.00
0005435786123	4302	Economy	12700.00
0005435786138	4302	Economy	12700.00
0005434994243	4302	Economy	12700.00
0005435786137	4302	Economy	12700.00
0005435918733	4302	Economy	12700.00
0005435786144	4302	Economy	12700.00
0005435918761	27279	Business	38000.00
0005435785740	27279	Business	38000.00
0005435785783	27279	Business	38000.00
0005435785771	27279	Business	38000.00
0005435937485	27279	Business	38000.00
0005434994122	27279	Business	38000.00
0005435918760	27279	Business	38000.00
0005435785782	27279	Business	38000.00
0005435785695	27279	Business	38000.00
0005434994144	27279	Economy	12700.00
0005435785560	27279	Economy	12700.00
0005435937496	27279	Economy	12700.00
0005435785707	27279	Economy	12700.00
0005435785698	27279	Economy	12700.00
0005435787374	27279	Economy	12700.00
0005435937491	27279	Economy	12700.00
0005435787373	27279	Economy	12700.00
0005435937488	27279	Economy	13900.00
0005435937489	27279	Economy	13900.00
0005434994143	27279	Economy	13900.00
0005435937487	27279	Economy	12700.00
0005435785781	27279	Economy	12700.00
0005435785733	27279	Economy	12700.00
0005435937492	27279	Economy	12700.00
0005435937490	27279	Economy	12700.00
0005435937486	27279	Economy	12700.00
0005435937497	27279	Economy	12700.00
0005435785854	27279	Economy	12700.00
0005432195740	27279	Economy	12700.00
0005435785714	27279	Economy	12700.00
0005435787372	27279	Economy	12700.00
0005434994123	27279	Economy	12700.00
0005434994127	27279	Economy	12700.00
0005434994173	27279	Economy	12700.00
0005435785727	27279	Economy	12700.00
0005435785786	27279	Economy	12700.00
0005434994128	27279	Economy	12700.00
0005435937493	27279	Economy	12700.00
0005435785761	27279	Economy	12700.00
0005435785706	27279	Economy	12700.00
0005435785760	27279	Economy	12700.00
0005435785699	27279	Economy	12700.00
0005435785798	27279	Economy	12700.00
0005434994162	27279	Economy	12700.00
0005435785559	27279	Economy	12700.00
0005435785732	27279	Economy	12700.00
0005435918762	27279	Economy	12700.00
0005435785788	27279	Economy	12700.00
0005435785800	27279	Economy	12700.00
0005435937494	27279	Economy	12700.00
0005434994129	27279	Economy	12700.00
0005435785726	27279	Economy	12700.00
0005434994131	27279	Economy	12700.00
0005435785801	27279	Economy	12700.00
0005435918764	27279	Economy	12700.00
0005435785700	27279	Economy	12700.00
0005435937495	27279	Economy	12700.00
0005435918763	27279	Economy	12700.00
0005435785670	27279	Economy	12700.00
0005435785741	27279	Economy	12700.00
0005435785799	27279	Economy	12700.00
0005435785789	27279	Economy	12700.00
0005434994130	27279	Economy	12700.00
0005432146244	19885	Economy	12800.00
0005432146243	19885	Economy	12800.00
0005432146247	19885	Economy	12800.00
0005432146245	19885	Economy	12800.00
0005432146246	19885	Economy	12800.00
0005432569015	4716	Business	40900.00
0005432461020	4716	Business	40900.00
0005432569011	4716	Business	40900.00
0005434082432	4716	Business	40900.00
0005434082439	4716	Business	40900.00
0005432571407	4716	Business	40900.00
0005432461004	4716	Business	40900.00
0005433452787	4716	Business	40900.00
0005432461022	4716	Business	40900.00
0005432568975	4716	Business	40900.00
0005432460989	4716	Business	40900.00
0005432461005	4716	Business	40900.00
0005432569005	4716	Business	40900.00
0005432568980	4716	Business	40900.00
0005434082430	4716	Business	40900.00
0005432569023	4716	Business	40900.00
0005432460987	4716	Business	40900.00
0005432460992	4716	Business	40900.00
0005432461008	4716	Business	40900.00
0005432186951	4716	Business	40900.00
0005432461034	4716	Business	40900.00
0005432568971	4716	Business	40900.00
0005433452786	4716	Business	40900.00
0005432461029	4716	Economy	15000.00
0005432569008	4716	Economy	15000.00
0005432186952	4716	Economy	15000.00
0005432569002	4716	Economy	13600.00
0005432460988	4716	Economy	13600.00
0005432569000	4716	Economy	13600.00
0005432461033	4716	Economy	13600.00
0005432568995	4716	Economy	13600.00
0005434082428	4716	Economy	13600.00
0005433726156	4716	Economy	13600.00
0005432460986	4716	Economy	13600.00
0005432569004	4716	Economy	13600.00
0005432569022	4716	Economy	13600.00
0005432568985	4716	Economy	13600.00
0005432568981	4716	Economy	13600.00
0005432568968	4716	Economy	13600.00
0005432569014	4716	Economy	13600.00
0005432461006	4716	Economy	13600.00
0005432461027	4716	Economy	13600.00
0005432461038	4716	Economy	13600.00
0005432569006	4716	Economy	13600.00
0005432569001	4716	Economy	13600.00
0005434082426	4716	Economy	13600.00
0005434082437	4716	Economy	13600.00
0005432461032	4716	Economy	13600.00
0005432569020	4716	Economy	13600.00
0005432568986	4716	Economy	13600.00
0005432461037	4716	Economy	13600.00
0005432170537	4716	Economy	13600.00
0005432461001	4716	Economy	13600.00
0005432461000	4716	Economy	13600.00
0005432568977	4716	Economy	13600.00
0005432568970	4716	Economy	13600.00
0005432461014	4716	Economy	13600.00
0005432568999	4716	Economy	13600.00
0005432460999	4716	Economy	13600.00
0005432461031	4716	Economy	13600.00
0005432568997	4716	Economy	13600.00
0005432568978	4716	Economy	13600.00
0005432461002	4716	Economy	13600.00
0005432568988	4716	Economy	13600.00
0005432569027	4716	Economy	13600.00
0005432568979	4716	Economy	13600.00
0005432460991	4716	Economy	13600.00
0005432568974	4716	Economy	13600.00
0005432461010	4716	Economy	13600.00
0005432568992	4716	Economy	13600.00
0005434082429	4716	Economy	13600.00
0005432568972	4716	Economy	13600.00
0005434082438	4716	Economy	13600.00
0005432461012	4716	Economy	13600.00
0005432460993	4716	Economy	13600.00
0005432569019	4716	Economy	13600.00
0005432186953	4716	Economy	13600.00
0005434082440	4716	Economy	13600.00
0005432461024	4716	Economy	13600.00
0005432460990	4716	Economy	13600.00
0005432569009	4716	Economy	13600.00
0005432170536	4716	Economy	13600.00
0005434082436	4716	Economy	13600.00
0005434082431	4716	Economy	13600.00
0005432569003	4716	Economy	13600.00
0005432569024	4716	Economy	13600.00
0005432461007	4716	Economy	13600.00
0005432568993	4716	Economy	13600.00
0005432170539	4716	Economy	13600.00
0005432461009	4716	Economy	13600.00
0005433451664	4716	Economy	13600.00
0005432170541	4716	Economy	13600.00
0005432568984	4716	Economy	13600.00
0005432568989	4716	Economy	13600.00
0005432461023	4716	Economy	15000.00
0005432170535	4716	Economy	15000.00
0005432569010	4716	Economy	13600.00
0005432569021	4716	Economy	13600.00
0005432569007	4716	Economy	15000.00
0005432568987	4716	Economy	13600.00
0005432571405	4716	Economy	15000.00
0005432461026	4716	Economy	13600.00
0005432461018	4716	Economy	13600.00
0005432461013	4716	Economy	13600.00
0005432568982	4716	Economy	13600.00
0005432571406	4716	Economy	13600.00
0005432461011	4716	Economy	13600.00
0005432569025	4716	Economy	13600.00
0005432569012	4716	Economy	13600.00
0005432569013	4716	Economy	13600.00
0005432568991	4716	Economy	13600.00
0005432568996	4716	Economy	13600.00
0005432461003	4716	Economy	13600.00
0005432461039	4716	Economy	13600.00
0005432568994	4716	Economy	13600.00
0005432571404	4716	Economy	13600.00
0005432568998	4716	Economy	13600.00
0005432568976	4716	Economy	13600.00
0005432461028	4716	Economy	13600.00
0005432569016	4716	Economy	13600.00
0005433451665	4716	Economy	13600.00
0005432461036	4716	Economy	13600.00
0005432568983	4716	Economy	13600.00
0005432568966	4716	Economy	13600.00
0005432568973	4716	Economy	13600.00
0005432460994	4716	Economy	13600.00
0005432461016	4716	Economy	13600.00
0005434082433	4716	Economy	13600.00
0005432460997	4716	Economy	13600.00
0005432569026	4716	Economy	13600.00
0005432170538	4716	Economy	13600.00
0005432170540	4716	Economy	13600.00
0005432460996	4716	Economy	13600.00
0005432460998	4716	Economy	13600.00
0005432568990	4716	Economy	13600.00
0005432568967	4716	Economy	13600.00
0005432461025	4716	Economy	13600.00
0005432568969	4716	Economy	13600.00
0005432569018	4716	Economy	13600.00
0005432461015	4716	Economy	13600.00
0005432568965	4716	Economy	13600.00
0005432461035	4716	Economy	13600.00
0005434082427	4716	Economy	13600.00
0005432461019	4716	Economy	13600.00
0005432461017	4716	Economy	13600.00
0005434082434	4716	Economy	13600.00
0005432461040	4716	Economy	13600.00
0005432461030	4716	Economy	13600.00
0005432461021	4716	Economy	13600.00
0005432569017	4716	Economy	13600.00
0005434082435	4716	Economy	13600.00
0005432460995	4716	Economy	13600.00
0005432568484	30546	Business	40900.00
0005432568647	30546	Business	40900.00
0005432460640	30546	Business	40900.00
0005432568554	30546	Business	40900.00
0005432460826	30546	Business	40900.00
0005432460641	30546	Business	40900.00
0005434082247	30546	Business	40900.00
0005432568361	30546	Business	40900.00
0005432460595	30546	Business	40900.00
0005432460487	30546	Business	40900.00
0005432568294	30546	Business	40900.00
0005432460394	30546	Business	40900.00
0005432568621	30546	Business	40900.00
0005432568934	30546	Business	40900.00
0005432568555	30546	Business	40900.00
0005433452763	30546	Business	40900.00
0005432161203	30546	Business	40900.00
0005432460609	30546	Business	40900.00
0005432568460	30546	Business	40900.00
0005432568671	30546	Business	40900.00
0005432571374	30546	Business	40900.00
0005432568318	30546	Economy	15000.00
0005434082183	30546	Economy	15000.00
0005432460480	30546	Economy	13600.00
0005432568809	30546	Economy	13600.00
0005432568625	30546	Economy	13600.00
0005432460683	30546	Economy	13600.00
0005432460670	30546	Economy	13600.00
0005434082192	30546	Economy	13600.00
0005432460435	30546	Economy	13600.00
0005432568435	30546	Economy	13600.00
0005432213691	30546	Economy	13600.00
0005433454900	30546	Economy	13600.00
0005432568815	30546	Economy	13600.00
0005432568485	30546	Economy	13600.00
0005432460745	30546	Economy	13600.00
0005432460387	30546	Economy	13600.00
0005432568571	30546	Economy	13600.00
0005432460720	30546	Economy	13600.00
0005434082203	30546	Economy	13600.00
0005432568933	30546	Economy	13600.00
0005432213690	30546	Economy	13600.00
0005432568707	30546	Economy	13600.00
0005432460617	30546	Economy	13600.00
0005434082259	30546	Economy	13600.00
0005432568501	30546	Economy	13600.00
0005432460479	30546	Economy	13600.00
0005432460482	30546	Economy	13600.00
0005432460746	30546	Economy	13600.00
0005434082250	30546	Economy	13600.00
0005432568355	30546	Economy	13600.00
0005432460514	30546	Economy	13600.00
0005434082216	30546	Economy	13600.00
0005432568702	30546	Economy	13600.00
0005432161204	30546	Economy	13600.00
0005434082182	30546	Economy	13600.00
0005432460436	30546	Economy	13600.00
0005432568326	30546	Economy	13600.00
0005432460584	30546	Economy	13600.00
0005432460832	30546	Economy	13600.00
0005432460511	30546	Economy	13600.00
0005432568606	30546	Economy	13600.00
0005432568703	30546	Economy	13600.00
0005432460510	30546	Economy	13600.00
0005434082123	30546	Economy	13600.00
0005434082169	30546	Economy	13600.00
0005432568502	30546	Economy	13600.00
0005432568459	30546	Economy	13600.00
0005432571387	30546	Economy	13600.00
0005432571380	30546	Economy	13600.00
0005434082251	30546	Economy	13600.00
0005432568356	30546	Economy	13600.00
0005432568562	30546	Economy	13600.00
0005432460625	30546	Economy	13600.00
0005432568311	30546	Economy	13600.00
0005432460352	30546	Economy	13600.00
0005432568529	30546	Economy	13600.00
0005434082185	30546	Economy	13600.00
0005432460701	30546	Economy	13600.00
0005432568388	30546	Economy	13600.00
0005433454911	30546	Economy	13600.00
0005432460627	30546	Economy	13600.00
0005432460659	30546	Economy	13600.00
0005432568521	30546	Economy	13600.00
0005432568706	30546	Economy	13600.00
0005432460537	30546	Economy	13600.00
0005432460735	30546	Economy	13600.00
0005432460675	30546	Economy	13600.00
0005432460787	30546	Economy	13600.00
0005432571373	30546	Economy	13600.00
0005432568479	30546	Economy	13600.00
0005432568767	30546	Economy	13600.00
0005432568628	30546	Economy	13600.00
0005432460667	30546	Economy	13600.00
0005432568451	30546	Economy	13600.00
0005432568457	30546	Economy	13600.00
0005432568816	30546	Economy	13600.00
0005432460628	30546	Economy	13600.00
0005432213689	30546	Economy	13600.00
0005432460471	30546	Economy	13600.00
0005432460629	30546	Economy	13600.00
0005432568387	30546	Economy	13600.00
0005432571390	30546	Economy	13600.00
0005432568297	30546	Economy	13600.00
0005432568480	30546	Economy	13600.00
0005434082184	30546	Economy	13600.00
0005432568352	30546	Economy	15000.00
0005434082213	30546	Economy	13600.00
0005432568609	30546	Economy	13600.00
0005432460566	30546	Economy	15000.00
0005432568584	30546	Economy	13600.00
0005432568309	30546	Economy	13600.00
0005432460654	30546	Economy	13600.00
0005432571381	30546	Economy	13600.00
0005432568351	30546	Economy	13600.00
0005432568620	30546	Economy	13600.00
0005432460650	30546	Economy	13600.00
0005434082226	30546	Economy	13600.00
0005432460742	30546	Economy	13600.00
0005432460610	30546	Economy	13600.00
0005432460441	30546	Economy	13600.00
0005432460594	30546	Economy	13600.00
0005432568794	30546	Economy	13600.00
0005432568482	30546	Economy	13600.00
0005432568585	30546	Economy	13600.00
0005433454910	30546	Economy	13600.00
0005432460649	30546	Economy	13600.00
0005432460852	30546	Economy	13600.00
0005432568610	30546	Economy	13600.00
0005432460663	30546	Economy	13600.00
0005432568434	30546	Economy	13600.00
0005432568527	30546	Economy	13600.00
0005432460669	30546	Economy	13600.00
0005432568676	30546	Economy	13600.00
0005432568704	30546	Economy	13600.00
0005434082214	30546	Economy	13600.00
0005432460583	30546	Economy	13600.00
0005434082191	30546	Economy	13600.00
0005434082258	30546	Economy	13600.00
0005434082193	30546	Economy	13600.00
0005432460598	30546	Economy	13600.00
0005434082179	30546	Economy	13600.00
0005434082178	30546	Economy	13600.00
0005432568431	30546	Economy	13600.00
0005432460833	30546	Economy	13600.00
0005432568729	30546	Economy	13600.00
0005432568522	30546	Economy	13600.00
0005432213688	30546	Economy	13600.00
0005432568456	30546	Economy	13600.00
0005433454895	30546	Economy	13600.00
0005434082200	30546	Economy	13600.00
0005432568544	30546	Economy	13600.00
0005432568340	30546	Economy	13600.00
0005432568935	30546	Economy	13600.00
0005432568672	30546	Economy	13600.00
0005432460653	30546	Economy	13600.00
0005432568626	30546	Economy	13600.00
0005432568611	30546	Economy	13600.00
0005432568218	30546	Economy	13600.00
0005432460395	30546	Economy	13600.00
0005432460749	30546	Economy	13600.00
0005432568409	30546	Economy	13600.00
0005432460608	30546	Economy	13600.00
0005432460719	30546	Economy	13600.00
0005432460607	30546	Economy	13600.00
0005432568444	30546	Economy	13600.00
0005432460825	30546	Economy	13600.00
0005432568445	30546	Economy	13600.00
0005432568458	30546	Economy	13600.00
0005435720850	13671	Economy	9900.00
0005435722110	13671	Economy	9900.00
0005435720849	13671	Economy	9900.00
0005435722109	13671	Economy	9900.00
0005435722108	13671	Economy	9900.00
0005435722089	21163	Economy	9900.00
0005435722082	21163	Economy	9900.00
0005435722090	21163	Economy	9900.00
0005432295938	22787	Economy	8800.00
0005432295939	22787	Economy	8800.00
0005433345389	11085	Business	23600.00
0005433345418	11085	Business	23600.00
0005433345385	11085	Business	23600.00
0005435508499	11085	Business	23600.00
0005433345386	11085	Business	23600.00
0005433345443	11085	Business	23600.00
0005435097423	11085	Business	23600.00
0005435508548	11085	Business	23600.00
0005433345401	11085	Business	23600.00
0005433345429	11085	Business	23600.00
0005433345357	11085	Business	23600.00
0005433345408	11085	Business	23600.00
0005433345398	11085	Economy	7900.00
0005433345403	11085	Economy	7900.00
0005433345440	11085	Economy	7900.00
0005433345451	11085	Economy	7900.00
0005435097422	11085	Economy	7900.00
0005433345358	11085	Economy	7900.00
0005433345396	11085	Economy	7900.00
0005433345374	11085	Economy	7900.00
0005435508497	11085	Economy	7900.00
0005433345431	11085	Economy	7900.00
0005433345446	11085	Economy	7900.00
0005433345414	11085	Economy	7900.00
0005433345409	11085	Economy	7900.00
0005433345352	11085	Economy	7900.00
0005433345382	11085	Economy	7900.00
0005433345359	11085	Economy	7900.00
0005435508498	11085	Economy	7900.00
0005433345410	11085	Economy	7900.00
0005433345369	11085	Economy	7900.00
0005433345450	11085	Economy	7900.00
0005433345436	11085	Economy	7900.00
0005433345402	11085	Economy	7900.00
0005435508510	11085	Economy	7900.00
0005433345428	11085	Economy	7900.00
0005433345415	11085	Economy	7900.00
0005433345371	11085	Economy	7900.00
0005433345442	11085	Economy	7900.00
0005433345392	11085	Economy	7900.00
0005433345350	11085	Economy	7900.00
0005433345381	11085	Economy	7900.00
0005435508477	11085	Economy	7900.00
0005433345439	11085	Economy	7900.00
0005433345380	11085	Economy	7900.00
0005433345433	11085	Economy	7900.00
0005433345364	11085	Economy	7900.00
0005433345354	11085	Economy	7900.00
0005433345416	11085	Economy	7900.00
0005433345449	11085	Economy	7900.00
0005433345394	11085	Economy	7900.00
0005433345366	11085	Economy	8600.00
0005433345361	11085	Economy	7900.00
0005433345405	11085	Economy	8600.00
0005433345406	11085	Economy	8600.00
0005435097424	11085	Economy	8600.00
0005435097415	11085	Economy	8600.00
0005433345430	11085	Economy	8600.00
0005435097425	11085	Economy	7900.00
0005433345395	11085	Economy	7900.00
0005433345421	11085	Economy	7900.00
0005433345349	11085	Economy	7900.00
0005433345426	11085	Economy	7900.00
0005433345419	11085	Economy	7900.00
0005433345445	11085	Economy	7900.00
0005433345360	11085	Economy	7900.00
0005435508518	11085	Economy	7900.00
0005433345356	11085	Economy	7900.00
0005433345448	11085	Economy	7900.00
0005435097419	11085	Economy	7900.00
0005435380347	11085	Economy	7900.00
0005433345373	11085	Economy	7900.00
0005433345388	11085	Economy	7900.00
0005435097421	11085	Economy	7900.00
0005433345447	11085	Economy	7900.00
0005435508478	11085	Economy	7900.00
0005433345417	11085	Economy	7900.00
0005433345444	11085	Economy	7900.00
0005435508517	11085	Economy	7900.00
0005435097417	11085	Economy	7900.00
0005433345435	11085	Economy	7900.00
0005435097416	11085	Economy	7900.00
0005433345420	11085	Economy	7900.00
0005433345375	11085	Economy	7900.00
0005433345355	11085	Economy	7900.00
0005433345424	11085	Economy	7900.00
0005433345441	11085	Economy	7900.00
0005433345387	11085	Economy	7900.00
0005435380365	11085	Economy	7900.00
0005433345377	11085	Economy	7900.00
0005433345367	11085	Economy	7900.00
0005433345422	11085	Economy	7900.00
0005433345432	11085	Economy	7900.00
0005433345378	11085	Economy	7900.00
0005433345397	11085	Economy	7900.00
0005435508519	11085	Economy	7900.00
0005433345391	11085	Economy	7900.00
0005435380348	11085	Economy	7900.00
0005433345365	11085	Economy	7900.00
0005433345353	11085	Economy	7900.00
0005433345411	11085	Economy	7900.00
0005433345383	11085	Economy	7900.00
0005435097418	11085	Economy	7900.00
0005433345423	11085	Economy	7900.00
0005433345370	11085	Economy	7900.00
0005433345425	11085	Economy	7900.00
0005433345393	11085	Economy	7900.00
0005433345413	11085	Economy	7900.00
0005435097420	11085	Economy	7900.00
0005433345384	11085	Economy	7900.00
0005433345362	11085	Economy	7900.00
0005435508479	11085	Economy	7900.00
0005433345412	11085	Economy	7900.00
0005433345379	11085	Economy	7900.00
0005433345437	11085	Economy	7900.00
0005433345400	11085	Economy	7900.00
0005435380349	11085	Economy	7900.00
0005433345351	11085	Economy	7900.00
0005433345376	11085	Economy	7900.00
0005433345427	11085	Economy	7900.00
0005433345434	11085	Economy	7900.00
0005433345404	11085	Economy	7900.00
0005435508509	11085	Economy	7900.00
0005433345372	11085	Economy	7900.00
0005433345407	11085	Economy	7900.00
0005433345399	11085	Economy	7900.00
0005433345368	11085	Economy	7900.00
0005433345438	11085	Economy	7900.00
0005433345390	11085	Economy	7900.00
0005433345363	11085	Economy	7900.00
0005435097290	17116	Business	23600.00
0005433344237	17116	Business	23600.00
0005433344741	17116	Business	23600.00
0005433344195	17116	Business	23600.00
0005433344472	17116	Business	23600.00
0005433344732	17116	Business	23600.00
0005432293262	17116	Business	23600.00
0005435545908	17116	Business	23600.00
0005433344518	17116	Business	23600.00
0005433343857	17116	Business	23600.00
0005433344636	17116	Business	23600.00
0005433344403	17116	Business	23600.00
0005435097345	17116	Economy	7900.00
0005433344654	17116	Economy	7900.00
0005435545906	17116	Economy	7900.00
0005435097363	17116	Economy	7900.00
0005433344189	17116	Economy	7900.00
0005433344548	17116	Economy	7900.00
0005433344855	17116	Economy	7900.00
0005433344291	17116	Economy	7900.00
0005435545909	17116	Economy	7900.00
0005433344104	17116	Economy	7900.00
0005433344024	17116	Economy	7900.00
0005433344048	17116	Economy	7900.00
0005433344717	17116	Economy	7900.00
0005435097309	17116	Economy	7900.00
0005433344624	17116	Economy	7900.00
0005432293263	17116	Economy	7900.00
0005433344788	17116	Economy	7900.00
0005433344696	17116	Economy	7900.00
0005435380411	17116	Economy	7900.00
0005435380413	17116	Economy	7900.00
0005433344188	17116	Economy	7900.00
0005433344517	17116	Economy	7900.00
0005433344593	17116	Economy	7900.00
0005433344308	17116	Economy	7900.00
0005433344346	17116	Economy	7900.00
0005433344758	17116	Economy	7900.00
0005433344697	17116	Economy	7900.00
0005435545902	17116	Economy	7900.00
0005435545900	17116	Economy	7900.00
0005433344448	17116	Economy	7900.00
0005433344740	17116	Economy	7900.00
0005433344369	17116	Economy	7900.00
0005433344627	17116	Economy	7900.00
0005433344420	17116	Economy	7900.00
0005433344442	17116	Economy	7900.00
0005433344626	17116	Economy	7900.00
0005433344613	17116	Economy	7900.00
0005433344625	17116	Economy	7900.00
0005435545911	17116	Economy	7900.00
0005433344374	17116	Economy	7900.00
0005433344575	17116	Economy	8600.00
0005433344675	17116	Economy	8600.00
0005433344025	17116	Economy	8600.00
0005435545903	17116	Economy	8600.00
0005433344606	17116	Economy	8600.00
0005433344106	17116	Economy	8600.00
0005433344525	17116	Economy	7900.00
0005433344047	17116	Economy	7900.00
0005433344360	17116	Economy	7900.00
0005433344618	17116	Economy	7900.00
0005433344417	17116	Economy	7900.00
0005433344601	17116	Economy	7900.00
0005433344603	17116	Economy	7900.00
0005433344513	17116	Economy	7900.00
0005433344495	17116	Economy	7900.00
0005433344323	17116	Economy	7900.00
0005433344577	17116	Economy	7900.00
0005433344754	17116	Economy	7900.00
0005433344210	17116	Economy	7900.00
0005435545899	17116	Economy	7900.00
0005433344556	17116	Economy	7900.00
0005433344373	17116	Economy	7900.00
0005433344742	17116	Economy	7900.00
0005433344347	17116	Economy	7900.00
0005435097319	17116	Economy	7900.00
0005433344752	17116	Economy	7900.00
0005435380412	17116	Economy	7900.00
0005435380414	17116	Economy	7900.00
0005435545901	17116	Economy	7900.00
0005435380409	17116	Economy	7900.00
0005433344484	17116	Economy	7900.00
0005433344196	17116	Economy	7900.00
0005433344466	17116	Economy	7900.00
0005433344050	17116	Economy	7900.00
0005433344173	17116	Economy	7900.00
0005433344019	17116	Economy	7900.00
0005433344557	17116	Economy	7900.00
0005433344257	17116	Economy	7900.00
0005433344854	17116	Economy	7900.00
0005433344359	17116	Economy	7900.00
0005433344105	17116	Economy	7900.00
0005433344607	17116	Economy	7900.00
0005433344256	17116	Economy	7900.00
0005433344138	17116	Economy	7900.00
0005433344368	17116	Economy	7900.00
0005435545910	17116	Economy	7900.00
0005433344656	17116	Economy	7900.00
0005433344753	17116	Economy	7900.00
0005433344510	17116	Economy	7900.00
0005433344372	17116	Economy	7900.00
0005433344314	17116	Economy	7900.00
0005435380410	17116	Economy	7900.00
0005433345027	17116	Economy	7900.00
0005433344049	17116	Economy	7900.00
0005433344676	17116	Economy	7900.00
0005433344914	17116	Economy	7900.00
0005433344628	17116	Economy	7900.00
0005435545904	17116	Economy	7900.00
0005433344137	17116	Economy	7900.00
0005433344928	17116	Economy	7900.00
0005433344129	17116	Economy	7900.00
0005435545907	17116	Economy	7900.00
0005433344128	17116	Economy	7900.00
0005433344471	17116	Economy	7900.00
0005433344547	17116	Economy	7900.00
0005433344694	17116	Economy	7900.00
0005433344503	17116	Economy	7900.00
0005433344485	17116	Economy	7900.00
0005433344415	17116	Economy	7900.00
0005433344215	17116	Economy	7900.00
0005433344303	17116	Economy	7900.00
0005433343944	17116	Economy	7900.00
0005435545905	17116	Economy	7900.00
0005433343943	17116	Economy	7900.00
0005433344576	17116	Economy	7900.00
0005433344864	17116	Economy	7900.00
0005433344602	17116	Economy	7900.00
0005433477051	9084	Business	26600.00
0005433507591	9084	Business	26600.00
0005433507594	9084	Business	26600.00
0005433507581	9084	Business	26600.00
0005433507600	9084	Business	26600.00
0005433507589	9084	Business	26600.00
0005433507590	9084	Business	26600.00
0005432920258	9084	Business	26600.00
0005433481340	9084	Business	26600.00
0005433507598	9084	Economy	8900.00
0005432920198	9084	Economy	8900.00
0005432920110	9084	Economy	8900.00
0005433477033	9084	Economy	8900.00
0005433481344	9084	Economy	8900.00
0005432920109	9084	Economy	9800.00
0005432920119	9084	Economy	9800.00
0005433477041	9084	Economy	9800.00
0005433507585	9084	Economy	9800.00
0005433481345	9084	Economy	8900.00
0005433507583	9084	Economy	8900.00
0005432920170	9084	Economy	8900.00
0005433507601	9084	Economy	8900.00
0005433477034	9084	Economy	8900.00
0005433507599	9084	Economy	8900.00
0005432920221	9084	Economy	8900.00
0005432920218	9084	Economy	8900.00
0005433507587	9084	Economy	8900.00
0005433481342	9084	Economy	8900.00
0005433507580	9084	Economy	8900.00
0005433481339	9084	Economy	8900.00
0005433477049	9084	Economy	8900.00
0005434159006	9084	Economy	8900.00
0005432920117	9084	Economy	8900.00
0005433477043	9084	Economy	8900.00
0005432920059	9084	Economy	8900.00
0005433507597	9084	Economy	8900.00
0005433481338	9084	Economy	8900.00
0005433507596	9084	Economy	8900.00
0005433477048	9084	Economy	8900.00
0005433477036	9084	Economy	8900.00
0005432920260	9084	Economy	8900.00
0005433481343	9084	Economy	8900.00
0005432920118	9084	Economy	8900.00
0005433507595	9084	Economy	8900.00
0005434159007	9084	Economy	8900.00
0005433507586	9084	Economy	8900.00
0005433477037	9084	Economy	8900.00
0005433477054	9084	Economy	8900.00
0005433507592	9084	Economy	8900.00
0005432920227	9084	Economy	8900.00
0005433477045	9084	Economy	8900.00
0005433507582	9084	Economy	8900.00
0005433477050	9084	Economy	8900.00
0005433507579	9084	Economy	8900.00
0005433477040	9084	Economy	8900.00
0005433477046	9084	Economy	8900.00
0005433481341	9084	Economy	8900.00
0005433477039	9084	Economy	8900.00
0005433507584	9084	Economy	8900.00
0005433507593	9084	Economy	8900.00
0005433477047	9084	Economy	8900.00
0005433477044	9084	Economy	8900.00
0005432920257	9084	Economy	8900.00
0005433507588	9084	Economy	8900.00
0005433477042	9084	Economy	8900.00
0005433477053	9084	Economy	8900.00
0005433477052	9084	Economy	8900.00
0005432920259	9084	Economy	8900.00
0005433477035	9084	Economy	8900.00
0005432920177	9084	Economy	8900.00
0005432920171	9084	Economy	8900.00
0005433477038	9084	Economy	8900.00
0005432920355	20489	Business	26600.00
0005432920342	20489	Business	26600.00
0005432920348	20489	Business	26600.00
0005432920353	20489	Business	26600.00
0005433507464	20489	Business	26600.00
0005434159035	20489	Business	26600.00
0005434159029	20489	Business	26600.00
0005432920340	20489	Business	26600.00
0005432920341	20489	Economy	8900.00
0005433507491	20489	Economy	8900.00
0005433507452	20489	Economy	8900.00
0005433507379	20489	Economy	8900.00
0005433481280	20489	Economy	8900.00
0005433507434	20489	Economy	8900.00
0005433507461	20489	Economy	9800.00
0005433507453	20489	Economy	8900.00
0005433481279	20489	Economy	9800.00
0005434159036	20489	Economy	9800.00
0005433507451	20489	Economy	8900.00
0005433507490	20489	Economy	8900.00
0005432920343	20489	Economy	8900.00
0005432920357	20489	Economy	8900.00
0005432920352	20489	Economy	8900.00
0005434159032	20489	Economy	8900.00
0005433507446	20489	Economy	8900.00
0005432920345	20489	Economy	8900.00
0005434159033	20489	Economy	8900.00
0005433507463	20489	Economy	8900.00
0005433507454	20489	Economy	8900.00
0005433481285	20489	Economy	8900.00
0005433507473	20489	Economy	8900.00
0005433481291	20489	Economy	8900.00
0005432920351	20489	Economy	8900.00
0005432920344	20489	Economy	8900.00
0005432920346	20489	Economy	8900.00
0005432920349	20489	Economy	8900.00
0005433481292	20489	Economy	8900.00
0005433507474	20489	Economy	8900.00
0005433481294	20489	Economy	8900.00
0005432920338	20489	Economy	8900.00
0005433481276	20489	Economy	8900.00
0005432920356	20489	Economy	8900.00
0005432920358	20489	Economy	8900.00
0005433481287	20489	Economy	8900.00
0005433481306	20489	Economy	8900.00
0005432920350	20489	Economy	8900.00
0005434159030	20489	Economy	8900.00
0005433507479	20489	Economy	8900.00
0005432920354	20489	Economy	8900.00
0005433507471	20489	Economy	8900.00
0005432920337	20489	Economy	8900.00
0005434159031	20489	Economy	8900.00
0005432920339	20489	Economy	8900.00
0005433507396	20489	Economy	8900.00
0005434159034	20489	Economy	8900.00
0005432920347	20489	Economy	8900.00
0005432396325	10191	Economy	5800.00
0005432394190	10191	Economy	5800.00
0005432396327	10191	Economy	5800.00
0005435179007	10191	Economy	5800.00
0005432394191	10191	Economy	5800.00
0005432396326	10191	Economy	5800.00
0005435179003	10191	Economy	5800.00
0005432394192	10191	Economy	5800.00
0005432396328	10191	Economy	5800.00
0005432400177	18373	Economy	5800.00
0005432400184	18373	Economy	5800.00
0005432400174	18373	Economy	5800.00
0005432396302	18373	Economy	5800.00
0005432396303	18373	Economy	5800.00
0005432400175	18373	Economy	5800.00
0005432400173	18373	Economy	5800.00
0005432396295	18373	Economy	5800.00
0005432400170	18373	Economy	5800.00
0005432396286	18373	Economy	5800.00
0005432400178	18373	Economy	5800.00
0005432396306	18373	Economy	5800.00
0005434411875	11036	Business	9500.00
0005435126944	11036	Business	9500.00
0005435626416	11036	Business	9500.00
0005435554248	11036	Business	9500.00
0005435626413	11036	Business	9500.00
0005435626407	11036	Business	9500.00
0005435126870	11036	Business	9500.00
0005435127052	11036	Business	9500.00
0005435126666	11036	Business	9500.00
0005435556723	11036	Business	9500.00
0005435126943	11036	Business	9500.00
0005435126775	11036	Economy	3200.00
0005435626412	11036	Economy	3200.00
0005434411876	11036	Economy	3200.00
0005434928365	11036	Economy	3200.00
0005435126898	11036	Economy	3200.00
0005435554268	11036	Economy	3200.00
0005435126846	11036	Economy	3500.00
0005434411877	11036	Economy	3500.00
0005435126795	11036	Economy	3500.00
0005435626422	11036	Economy	3200.00
0005435626432	11036	Economy	3200.00
0005435626392	11036	Economy	3200.00
0005434928364	11036	Economy	3200.00
0005435126771	11036	Economy	3200.00
0005435626411	11036	Economy	3200.00
0005435126857	11036	Economy	3200.00
0005435126780	11036	Economy	3200.00
0005435626387	11036	Economy	3200.00
0005435126837	11036	Economy	3200.00
0005435626417	11036	Economy	3200.00
0005435126903	11036	Economy	3200.00
0005435626419	11036	Economy	3200.00
0005435626427	11036	Economy	3200.00
0005435127044	11036	Economy	3200.00
0005435126968	11036	Economy	3200.00
0005435626333	11036	Economy	3200.00
0005435626420	11036	Economy	3200.00
0005435126855	11036	Economy	3200.00
0005435626385	11036	Economy	3200.00
0005435626334	11036	Economy	3200.00
0005435626381	11036	Economy	3200.00
0005435126838	11036	Economy	3200.00
0005435626423	11036	Economy	3200.00
0005435126783	11036	Economy	3200.00
0005435626386	11036	Economy	3200.00
0005435126784	11036	Economy	3200.00
0005435126845	11036	Economy	3200.00
0005435554243	11036	Economy	3200.00
0005435126854	11036	Economy	3200.00
0005435127049	11036	Economy	3200.00
0005434411878	11036	Economy	3200.00
0005435127014	11036	Economy	3200.00
0005435554265	11036	Economy	3200.00
0005435126871	11036	Economy	3200.00
0005435126902	11036	Economy	3200.00
0005435626426	11036	Economy	3200.00
0005435126929	11036	Economy	3200.00
0005435126853	11036	Economy	3200.00
0005435126906	11036	Economy	3200.00
0005435554267	11036	Economy	3200.00
0005435126901	11036	Economy	3200.00
0005434411874	11036	Economy	3200.00
0005435626429	11036	Economy	3200.00
0005435126803	11036	Economy	3200.00
0005435626388	11036	Economy	3200.00
0005435127015	11036	Economy	3200.00
0005435126747	11036	Economy	3200.00
0005435626406	11036	Economy	3200.00
0005435126801	11036	Economy	3200.00
0005435626421	11036	Economy	3200.00
0005435126748	11036	Economy	3200.00
0005435626389	11036	Economy	3200.00
0005435126930	11036	Economy	3200.00
0005435626316	11036	Economy	3200.00
0005435554266	11036	Economy	3200.00
0005435126965	11036	Economy	3200.00
0005435126802	11036	Economy	3200.00
0005435554247	11036	Economy	3200.00
0005435626317	11036	Economy	3200.00
0005435554244	11036	Economy	3200.00
0005435127279	14660	Business	9500.00
0005434411819	14660	Business	9500.00
0005435626594	14660	Business	9500.00
0005435127274	14660	Business	9500.00
0005435626600	14660	Business	9500.00
0005435127285	14660	Business	9500.00
0005435127277	14660	Business	9500.00
0005435626599	14660	Business	9500.00
0005435127311	14660	Business	9500.00
0005435127306	14660	Business	9500.00
0005435626601	14660	Business	9500.00
0005435127291	14660	Economy	3200.00
0005435626595	14660	Economy	3200.00
0005435127300	14660	Economy	3200.00
0005434411822	14660	Economy	3200.00
0005434411823	14660	Economy	3200.00
0005435127308	14660	Economy	3200.00
0005435127273	14660	Economy	3200.00
0005435127296	14660	Economy	3200.00
0005435127286	14660	Economy	3500.00
0005435626592	14660	Economy	3500.00
0005435556749	14660	Economy	3500.00
0005435127287	14660	Economy	3500.00
0005435127298	14660	Economy	3500.00
0005434411838	14660	Economy	3200.00
0005435626587	14660	Economy	3200.00
0005435626602	14660	Economy	3200.00
0005435554293	14660	Economy	3200.00
0005435554292	14660	Economy	3200.00
0005435127303	14660	Economy	3200.00
0005435626597	14660	Economy	3200.00
0005435127293	14660	Economy	3200.00
0005435127272	14660	Economy	3200.00
0005434411828	14660	Economy	3200.00
0005435626589	14660	Economy	3200.00
0005435626591	14660	Economy	3200.00
0005435127281	14660	Economy	3200.00
0005435127278	14660	Economy	3200.00
0005435127283	14660	Economy	3200.00
0005435127302	14660	Economy	3200.00
0005435127310	14660	Economy	3200.00
0005435127275	14660	Economy	3200.00
0005435127288	14660	Economy	3200.00
0005435127292	14660	Economy	3200.00
0005435127270	14660	Economy	3200.00
0005435127297	14660	Economy	3200.00
0005435127271	14660	Economy	3200.00
0005435626603	14660	Economy	3200.00
0005435127276	14660	Economy	3200.00
0005435554295	14660	Economy	3200.00
0005435127282	14660	Economy	3200.00
0005435626596	14660	Economy	3200.00
0005435127299	14660	Economy	3200.00
0005435626607	14660	Economy	3200.00
0005435127280	14660	Economy	3200.00
0005435127309	14660	Economy	3200.00
0005435127295	14660	Economy	3200.00
0005434928344	14660	Economy	3200.00
0005435127294	14660	Economy	3200.00
0005435127301	14660	Economy	3200.00
0005435554294	14660	Economy	3200.00
0005435127304	14660	Economy	3200.00
0005435127289	14660	Economy	3200.00
0005435626606	14660	Economy	3200.00
0005434411839	14660	Economy	3200.00
0005435127305	14660	Economy	3200.00
0005434411829	14660	Economy	3200.00
0005435556748	14660	Economy	3200.00
0005434411833	14660	Economy	3200.00
0005435626605	14660	Economy	3200.00
0005435626604	14660	Economy	3200.00
0005435626593	14660	Economy	3200.00
0005435626590	14660	Economy	3200.00
0005435127307	14660	Economy	3200.00
0005435127284	14660	Economy	3200.00
0005435626598	14660	Economy	3200.00
0005435626586	14660	Economy	3200.00
0005435127290	14660	Economy	3200.00
0005435626588	14660	Economy	3200.00
0005434411842	14660	Economy	3200.00
0005432400207	7125	Business	86900.00
0005435443400	7125	Business	86900.00
0005435179403	7125	Business	86900.00
0005435715858	7125	Business	86900.00
0005435443438	7125	Business	86900.00
0005435715860	7125	Business	86900.00
0005435715854	7125	Business	86900.00
0005432398281	7125	Economy	29000.00
0005435216613	7125	Economy	29000.00
0005435715851	7125	Economy	29000.00
0005435715850	7125	Economy	29000.00
0005435715863	7125	Economy	31900.00
0005435715856	7125	Economy	31900.00
0005435715848	7125	Economy	29000.00
0005435715855	7125	Economy	29000.00
0005435715847	7125	Economy	29000.00
0005435443432	7125	Economy	29000.00
0005432400208	7125	Economy	29000.00
0005435443456	7125	Economy	29000.00
0005435216607	7125	Economy	29000.00
0005435443437	7125	Economy	29000.00
0005432400210	7125	Economy	29000.00
0005435443427	7125	Economy	29000.00
0005432398282	7125	Economy	29000.00
0005435443428	7125	Economy	29000.00
0005435715846	7125	Economy	29000.00
0005435715862	7125	Economy	29000.00
0005435443433	7125	Economy	29000.00
0005435715859	7125	Economy	29000.00
0005435715853	7125	Economy	29000.00
0005435443429	7125	Economy	29000.00
0005435443481	7125	Economy	29000.00
0005435715857	7125	Economy	29000.00
0005432398279	7125	Economy	29000.00
0005435443434	7125	Economy	29000.00
0005435715852	7125	Economy	29000.00
0005432400209	7125	Economy	29000.00
0005432398280	7125	Economy	29000.00
0005435715861	7125	Economy	29000.00
0005435715849	7125	Economy	29000.00
0005435715864	7125	Economy	29000.00
0005435443524	27087	Business	86900.00
0005435216635	27087	Business	86900.00
0005435715707	27087	Business	86900.00
0005435443523	27087	Business	86900.00
0005435217760	27087	Business	86900.00
0005435715709	27087	Business	86900.00
0005435443527	27087	Business	86900.00
0005435178530	27087	Economy	29000.00
0005435715692	27087	Economy	29000.00
0005435443525	27087	Economy	29000.00
0005432394168	27087	Economy	29000.00
0005435715706	27087	Economy	29000.00
0005435218131	27087	Economy	29000.00
0005435179010	27087	Economy	29000.00
0005435216634	27087	Economy	31900.00
0005435715708	27087	Economy	31900.00
0005435218129	27087	Economy	31900.00
0005435443530	27087	Economy	31900.00
0005435216631	27087	Economy	29000.00
0005435216633	27087	Economy	29000.00
0005435218133	27087	Economy	29000.00
0005435715760	27087	Economy	29000.00
0005432394145	27087	Economy	29000.00
0005435715725	27087	Economy	29000.00
0005435179011	27087	Economy	29000.00
0005435178529	27087	Economy	29000.00
0005432394171	27087	Economy	29000.00
0005435443526	27087	Economy	29000.00
0005435216632	27087	Economy	29000.00
0005435715691	27087	Economy	29000.00
0005435217757	27087	Economy	29000.00
0005435715736	27087	Economy	29000.00
0005435217758	27087	Economy	29000.00
0005435715651	27087	Economy	29000.00
0005435217759	27087	Economy	29000.00
0005435715650	27087	Economy	29000.00
0005435715749	27087	Economy	29000.00
0005435178528	27087	Economy	29000.00
0005435217756	27087	Economy	29000.00
0005435443528	27087	Economy	29000.00
0005435715679	27087	Economy	29000.00
0005435217755	27087	Economy	29000.00
0005435218132	27087	Economy	29000.00
0005435443522	27087	Economy	29000.00
0005435443529	27087	Economy	29000.00
0005432394147	27087	Economy	29000.00
0005435218130	27087	Economy	29000.00
0005432398250	27087	Economy	29000.00
0005435217754	27087	Economy	29000.00
0005435715681	27087	Economy	29000.00
0005435715724	27087	Economy	29000.00
0005435715678	27087	Economy	29000.00
0005432394148	27087	Economy	29000.00
0005432398254	27087	Economy	29000.00
0005435443521	27087	Economy	29000.00
0005433060455	2710	Economy	7700.00
0005434085034	2710	Economy	7700.00
0005434085033	2710	Economy	7700.00
0005433060454	2710	Economy	7700.00
0005434085035	2710	Economy	7700.00
0005434085036	2710	Economy	7700.00
0005433060458	2710	Economy	7700.00
0005434085037	2710	Economy	7700.00
0005434085009	28516	Economy	7700.00
0005433060473	28516	Economy	7700.00
0005433060474	28516	Economy	7700.00
0005433060475	28516	Economy	7700.00
0005434085010	28516	Economy	7700.00
0005434084983	28516	Economy	7700.00
0005434084987	28516	Economy	7700.00
0005434084988	28516	Economy	7700.00
0005433788303	11173	Economy	27100.00
0005435548540	11173	Economy	27100.00
0005435548542	11173	Economy	24600.00
0005433788294	11173	Economy	24600.00
0005433788304	11173	Economy	24600.00
0005433788301	11173	Economy	24600.00
0005435548543	11173	Economy	24600.00
0005435548541	11173	Economy	24600.00
0005435548551	11173	Economy	24600.00
0005435548568	11173	Economy	24600.00
0005435548567	11173	Economy	24600.00
0005435548544	11173	Economy	24600.00
0005435548522	11173	Economy	24600.00
0005435548569	11173	Economy	24600.00
0005435548558	11173	Economy	24600.00
0005435548532	11173	Economy	24600.00
0005433788300	11173	Economy	24600.00
0005433788298	11173	Economy	24600.00
0005435548539	11173	Economy	24600.00
0005433788297	11173	Economy	24600.00
0005435548552	11173	Economy	24600.00
0005435548570	11173	Economy	24600.00
0005435548538	11173	Economy	24600.00
0005433788302	11173	Economy	24600.00
0005433788295	11173	Economy	24600.00
0005435548553	11173	Economy	24600.00
0005433788299	11173	Economy	24600.00
0005433788296	11173	Economy	24600.00
0005433788259	20674	Economy	27100.00
0005433788242	20674	Economy	27100.00
0005435548580	20674	Economy	27100.00
0005433788241	20674	Economy	27100.00
0005435548602	20674	Economy	24600.00
0005433788254	20674	Economy	24600.00
0005433788238	20674	Economy	24600.00
0005433788263	20674	Economy	24600.00
0005435548584	20674	Economy	24600.00
0005433788245	20674	Economy	24600.00
0005435548588	20674	Economy	24600.00
0005435548592	20674	Economy	24600.00
0005433788262	20674	Economy	24600.00
0005435548600	20674	Economy	24600.00
0005433788252	20674	Economy	24600.00
0005433788236	20674	Economy	24600.00
0005435548596	20674	Economy	24600.00
0005435548598	20674	Economy	24600.00
0005435548587	20674	Economy	24600.00
0005435548583	20674	Economy	24600.00
0005435548599	20674	Economy	24600.00
0005435548594	20674	Economy	24600.00
0005435548595	20674	Economy	24600.00
0005433788237	20674	Economy	24600.00
0005435548585	20674	Economy	24600.00
0005435548593	20674	Economy	24600.00
0005433788239	20674	Economy	24600.00
0005435548601	20674	Economy	24600.00
0005433788253	20674	Economy	24600.00
0005433788255	20674	Economy	24600.00
0005435548597	20674	Economy	24600.00
0005433788235	20674	Economy	24600.00
0005435548590	20674	Economy	24600.00
0005433788249	20674	Economy	24600.00
0005435548581	20674	Economy	24600.00
0005435548589	20674	Economy	24600.00
0005435548582	20674	Economy	24600.00
0005433788251	20674	Economy	24600.00
0005433788258	20674	Economy	24600.00
0005435548586	20674	Economy	24600.00
0005435548591	20674	Economy	24600.00
0005433788256	20674	Economy	24600.00
0005435541334	11413	Business	20200.00
0005435541303	11413	Business	20200.00
0005435541327	11413	Business	20200.00
0005435541335	11413	Business	20200.00
0005435518260	11413	Business	20200.00
0005435518189	11413	Business	20200.00
0005435518235	11413	Business	20200.00
0005435541440	11413	Economy	6700.00
0005435541384	11413	Economy	6700.00
0005435541332	11413	Economy	6700.00
0005435518135	11413	Economy	6700.00
0005435541258	11413	Economy	6700.00
0005435541292	11413	Economy	7400.00
0005435518192	11413	Economy	7400.00
0005435518211	11413	Economy	7400.00
0005435541341	11413	Economy	6700.00
0005435541343	11413	Economy	6700.00
0005435518119	11413	Economy	6700.00
0005435541336	11413	Economy	6700.00
0005435518197	11413	Economy	6700.00
0005435518060	11413	Economy	6700.00
0005435518196	11413	Economy	6700.00
0005435541277	11413	Economy	6700.00
0005435541408	11413	Economy	6700.00
0005435518236	11413	Economy	6700.00
0005435541318	11413	Economy	6700.00
0005435518146	11413	Economy	6700.00
0005435541259	11413	Economy	6700.00
0005435541353	11413	Economy	6700.00
0005435541333	11413	Economy	6700.00
0005435541302	11413	Economy	6700.00
0005435518186	11413	Economy	6700.00
0005435541361	11413	Economy	6700.00
0005435518139	11413	Economy	6700.00
0005435518212	11413	Economy	6700.00
0005435541288	11413	Economy	6700.00
0005435518118	11413	Economy	6700.00
0005435518193	11413	Economy	6700.00
0005435541328	11413	Economy	6700.00
0005435541265	11413	Economy	6700.00
0005435518205	11413	Economy	6700.00
0005435518195	11413	Economy	6700.00
0005435541188	11413	Economy	6700.00
0005435541293	11413	Economy	6700.00
0005435518232	11413	Economy	6700.00
0005435518191	11413	Economy	6700.00
0005435518223	11413	Economy	6700.00
0005435541385	11413	Economy	6700.00
0005435541316	11413	Economy	6700.00
0005435529734	22246	Business	20200.00
0005435529740	22246	Business	20200.00
0005435541466	22246	Business	20200.00
0005435541476	22246	Business	20200.00
0005435530030	22246	Business	20200.00
0005435530040	22246	Business	20200.00
0005435530039	22246	Business	20200.00
0005432294540	22246	Business	20200.00
0005435529729	22246	Economy	6700.00
0005435530033	22246	Economy	6700.00
0005435541474	22246	Economy	6700.00
0005435529737	22246	Economy	6700.00
0005435530031	22246	Economy	6700.00
0005432294541	22246	Economy	6700.00
0005435541465	22246	Economy	7400.00
0005435541480	22246	Economy	7400.00
0005435541468	22246	Economy	6700.00
0005435529739	22246	Economy	6700.00
0005435529726	22246	Economy	6700.00
0005435541485	22246	Economy	6700.00
0005435530028	22246	Economy	6700.00
0005435530024	22246	Economy	6700.00
0005435529731	22246	Economy	6700.00
0005435530042	22246	Economy	6700.00
0005435529742	22246	Economy	6700.00
0005435530034	22246	Economy	6700.00
0005435529733	22246	Economy	6700.00
0005435541483	22246	Economy	6700.00
0005435529724	22246	Economy	6700.00
0005435541478	22246	Economy	6700.00
0005435530036	22246	Economy	6700.00
0005435530029	22246	Economy	6700.00
0005435530025	22246	Economy	6700.00
0005435529723	22246	Economy	6700.00
0005435529730	22246	Economy	6700.00
0005435541481	22246	Economy	6700.00
0005435529735	22246	Economy	6700.00
0005435529732	22246	Economy	6700.00
0005435530043	22246	Economy	6700.00
0005435529736	22246	Economy	6700.00
0005435530027	22246	Economy	6700.00
0005435529741	22246	Economy	6700.00
0005435529728	22246	Economy	6700.00
0005435541482	22246	Economy	6700.00
0005435529727	22246	Economy	6700.00
0005432294539	22246	Economy	6700.00
0005435541469	22246	Economy	6700.00
0005435541484	22246	Economy	6700.00
0005435541479	22246	Economy	6700.00
0005435529743	22246	Economy	6700.00
0005435541473	22246	Economy	6700.00
0005435541472	22246	Economy	6700.00
0005435541477	22246	Economy	6700.00
0005435541471	22246	Economy	6700.00
0005435541475	22246	Economy	6700.00
0005435530035	22246	Economy	6700.00
0005435541467	22246	Economy	6700.00
0005435541470	22246	Economy	6700.00
0005435530037	22246	Economy	6700.00
0005435529738	22246	Economy	6700.00
0005435530023	22246	Economy	6700.00
0005435541486	22246	Economy	6700.00
0005435530041	22246	Economy	6700.00
0005435530032	22246	Economy	6700.00
0005435529725	22246	Economy	6700.00
0005435530038	22246	Economy	6700.00
0005435530044	22246	Economy	6700.00
0005435530026	22246	Economy	6700.00
0005434908458	2302	Business	20200.00
0005434908464	2302	Business	20200.00
0005434908473	2302	Business	20200.00
0005433251856	2302	Business	20200.00
0005434908465	2302	Business	20200.00
0005433252020	2302	Business	20200.00
0005433251929	2302	Business	20200.00
0005433251979	2302	Business	20200.00
0005434908498	2302	Business	20200.00
0005433251932	2302	Business	20200.00
0005434908483	2302	Business	20200.00
0005433251933	2302	Business	20200.00
0005434908454	2302	Economy	6700.00
0005434908494	2302	Economy	6700.00
0005433251878	2302	Economy	6700.00
0005433251851	2302	Economy	6700.00
0005434908455	2302	Economy	6700.00
0005434908460	2302	Economy	6700.00
0005433251938	2302	Economy	6700.00
0005433401031	2302	Economy	6700.00
0005434908461	2302	Economy	6700.00
0005434908496	2302	Economy	7400.00
0005433252070	2302	Economy	7400.00
0005434908478	2302	Economy	7400.00
0005434908452	2302	Economy	7400.00
0005434908476	2302	Economy	7400.00
0005433251839	2302	Economy	6700.00
0005433251924	2302	Economy	6700.00
0005434908489	2302	Economy	6700.00
0005434908451	2302	Economy	6700.00
0005434908488	2302	Economy	6700.00
0005433251995	2302	Economy	6700.00
0005434908457	2302	Economy	6700.00
0005434908502	2302	Economy	6700.00
0005434908481	2302	Economy	6700.00
0005433251934	2302	Economy	6700.00
0005433251853	2302	Economy	6700.00
0005433251994	2302	Economy	6700.00
0005434908459	2302	Economy	6700.00
0005433251737	2302	Economy	6700.00
0005434908490	2302	Economy	6700.00
0005433252071	2302	Economy	6700.00
0005434908485	2302	Economy	6700.00
0005434908467	2302	Economy	6700.00
0005434908486	2302	Economy	6700.00
0005433251990	2302	Economy	6700.00
0005433251944	2302	Economy	6700.00
0005433252003	2302	Economy	6700.00
0005433251854	2302	Economy	6700.00
0005433401024	2302	Economy	6700.00
0005434908463	2302	Economy	6700.00
0005433251996	2302	Economy	6700.00
0005434908469	2302	Economy	6700.00
0005434908472	2302	Economy	6700.00
0005433251898	2302	Economy	6700.00
0005433251946	2302	Economy	6700.00
0005434908497	2302	Economy	6700.00
0005433251957	2302	Economy	6700.00
0005434908456	2302	Economy	6700.00
0005434908493	2302	Economy	6700.00
0005434908482	2302	Economy	6700.00
0005434908501	2302	Economy	6700.00
0005433252118	2302	Economy	6700.00
0005433251897	2302	Economy	6700.00
0005434908484	2302	Economy	6700.00
0005434908477	2302	Economy	6700.00
0005433251850	2302	Economy	6700.00
0005434908495	2302	Economy	6700.00
0005433251833	2302	Economy	6700.00
0005433251928	2302	Economy	6700.00
0005434908462	2302	Economy	6700.00
0005434908479	2302	Economy	6700.00
0005433251863	2302	Economy	6700.00
0005434908468	2302	Economy	6700.00
0005434908474	2302	Economy	6700.00
0005434908475	2302	Economy	6700.00
0005434908470	2302	Economy	6700.00
0005433252019	2302	Economy	6700.00
0005433401023	2302	Economy	6700.00
0005434908499	2302	Economy	6700.00
0005434908453	2302	Economy	6700.00
0005433251914	2302	Economy	6700.00
0005433251852	2302	Economy	6700.00
0005434908503	2302	Economy	6700.00
0005434908466	2302	Economy	6700.00
0005434908491	2302	Economy	6700.00
0005434908500	2302	Economy	6700.00
0005434908480	2302	Economy	6700.00
0005434908492	2302	Economy	6700.00
0005433251834	2302	Economy	6700.00
0005434908487	2302	Economy	6700.00
0005434908471	2302	Economy	6700.00
0005434907820	25606	Business	20200.00
0005434907895	25606	Business	20200.00
0005434907827	25606	Business	20200.00
0005434907952	25606	Business	20200.00
0005433252169	25606	Business	20200.00
0005434907881	25606	Business	20200.00
0005433252187	25606	Business	20200.00
0005434907971	25606	Business	20200.00
0005434907894	25606	Business	20200.00
0005434907878	25606	Business	20200.00
0005434908051	25606	Business	20200.00
0005434907928	25606	Economy	6700.00
0005433401050	25606	Economy	6700.00
0005433252171	25606	Economy	6700.00
0005433252175	25606	Economy	6700.00
0005433401051	25606	Economy	6700.00
0005433252185	25606	Economy	6700.00
0005433252163	25606	Economy	6700.00
0005434907879	25606	Economy	6700.00
0005433252182	25606	Economy	6700.00
0005434907877	25606	Economy	6700.00
0005433252173	25606	Economy	7400.00
0005434907956	25606	Economy	7400.00
0005434907851	25606	Economy	7400.00
0005434908013	25606	Economy	7400.00
0005434907744	25606	Economy	7400.00
0005433252165	25606	Economy	6700.00
0005433252167	25606	Economy	6700.00
0005434907913	25606	Economy	6700.00
0005434907927	25606	Economy	6700.00
0005434907874	25606	Economy	6700.00
0005433252191	25606	Economy	6700.00
0005433252177	25606	Economy	6700.00
0005434907815	25606	Economy	6700.00
0005434907859	25606	Economy	6700.00
0005434907999	25606	Economy	6700.00
0005434907945	25606	Economy	6700.00
0005434907853	25606	Economy	6700.00
0005434907902	25606	Economy	6700.00
0005433252172	25606	Economy	6700.00
0005434908040	25606	Economy	6700.00
0005434907852	25606	Economy	6700.00
0005434907980	25606	Economy	6700.00
0005433252166	25606	Economy	6700.00
0005434908019	25606	Economy	6700.00
0005434907743	25606	Economy	6700.00
0005434907865	25606	Economy	6700.00
0005433252178	25606	Economy	6700.00
0005434907975	25606	Economy	6700.00
0005433252181	25606	Economy	6700.00
0005433252160	25606	Economy	6700.00
0005433252189	25606	Economy	6700.00
0005433252179	25606	Economy	6700.00
0005434907880	25606	Economy	6700.00
0005433252174	25606	Economy	6700.00
0005434908000	25606	Economy	6700.00
0005434907917	25606	Economy	6700.00
0005434908042	25606	Economy	6700.00
0005433252164	25606	Economy	6700.00
0005433252168	25606	Economy	6700.00
0005433252170	25606	Economy	6700.00
0005434907858	25606	Economy	6700.00
0005433252190	25606	Economy	6700.00
0005433252176	25606	Economy	6700.00
0005434908020	25606	Economy	6700.00
0005434907876	25606	Economy	6700.00
0005434907976	25606	Economy	6700.00
0005434907998	25606	Economy	6700.00
0005433252180	25606	Economy	6700.00
0005434907777	25606	Economy	6700.00
0005433252183	25606	Economy	6700.00
0005434907901	25606	Economy	6700.00
0005434907915	25606	Economy	6700.00
0005433252186	25606	Economy	6700.00
0005433401052	25606	Economy	6700.00
0005434907974	25606	Economy	6700.00
0005433252162	25606	Economy	6700.00
0005433252161	25606	Economy	6700.00
0005434908018	25606	Economy	6700.00
0005433252184	25606	Economy	6700.00
0005434907771	25606	Economy	6700.00
0005434907875	25606	Economy	6700.00
0005434907814	25606	Economy	6700.00
0005434907916	25606	Economy	6700.00
0005433252188	25606	Economy	6700.00
0005434907782	25606	Economy	6700.00
0005432621359	2532	Economy	13600.00
0005432621351	2532	Economy	13600.00
0005432862404	2532	Economy	12400.00
0005432862390	2532	Economy	12400.00
0005432621358	2532	Economy	12400.00
0005432621352	2532	Economy	12400.00
0005432621363	2532	Economy	12400.00
0005432621355	2532	Economy	12400.00
0005432621360	2532	Economy	12400.00
0005432621356	2532	Economy	12400.00
0005432621364	2532	Economy	12400.00
0005432621354	2532	Economy	12400.00
0005432621353	2532	Economy	12400.00
0005432621350	2532	Economy	12400.00
0005432862391	2532	Economy	12400.00
0005432621361	2532	Economy	12400.00
0005432621362	2532	Economy	12400.00
0005432621357	2532	Economy	12400.00
0005432862412	2532	Economy	12400.00
0005432621177	28074	Economy	13600.00
0005432621229	28074	Economy	13600.00
0005432621226	28074	Economy	12400.00
0005432862476	28074	Economy	12400.00
0005432862475	28074	Economy	12400.00
0005432621249	28074	Economy	12400.00
0005432621252	28074	Economy	12400.00
0005432621259	28074	Economy	12400.00
0005432621234	28074	Economy	12400.00
0005432621261	28074	Economy	12400.00
0005432621287	28074	Economy	12400.00
0005432621251	28074	Economy	12400.00
0005432621260	28074	Economy	12400.00
0005432862479	28074	Economy	12400.00
0005432621262	28074	Economy	12400.00
0005432621178	28074	Economy	12400.00
0005432862480	28074	Economy	12400.00
0005432621188	28074	Economy	12400.00
0005432862477	28074	Economy	12400.00
0005432621233	28074	Economy	12400.00
0005432621219	28074	Economy	12400.00
0005432862478	28074	Economy	12400.00
0005432862473	28074	Economy	12400.00
0005432621220	28074	Economy	12400.00
0005432621206	28074	Economy	12400.00
0005432621225	28074	Economy	12400.00
0005432621267	28074	Economy	12400.00
0005432862474	28074	Economy	12400.00
0005432621205	28074	Economy	12400.00
0005434097501	13114	Economy	11300.00
0005433451664	31073	Economy	8400.00
0005433452786	31073	Economy	8400.00
0005433451665	31073	Economy	8400.00
0005433452787	31073	Economy	8400.00
0005433454895	31426	Economy	8400.00
0005433452763	31426	Economy	8400.00
0005433454900	31426	Economy	8400.00
0005433454911	31426	Economy	8400.00
0005433454910	31426	Economy	8400.00
0005433134193	12004	Economy	6600.00
0005433129359	12004	Economy	6600.00
0005433129339	12004	Economy	6600.00
0005433129353	12004	Economy	6600.00
0005433134192	12004	Economy	6600.00
0005434184687	12004	Economy	6600.00
0005434142668	12004	Economy	6600.00
0005433129361	12004	Economy	6600.00
0005434142661	12004	Economy	6600.00
0005433129354	12004	Economy	6600.00
0005433129351	12004	Economy	6600.00
0005434184686	12004	Economy	6600.00
0005433129360	12004	Economy	6600.00
0005433129350	12004	Economy	6600.00
0005433129340	12004	Economy	6600.00
0005433134244	29813	Economy	7200.00
0005433131814	29813	Economy	6600.00
0005433134239	29813	Economy	6600.00
0005434142698	29813	Economy	6600.00
0005433134241	29813	Economy	6600.00
0005434183627	29813	Economy	6600.00
0005434142697	29813	Economy	6600.00
0005433131811	29813	Economy	6600.00
0005433131810	29813	Economy	6600.00
0005433134243	29813	Economy	6600.00
0005434183626	29813	Economy	6600.00
0005433134240	29813	Economy	6600.00
0005434184712	29813	Economy	6600.00
0005433131809	29813	Economy	6600.00
0005433131812	29813	Economy	6600.00
0005433134242	29813	Economy	6600.00
0005433131813	29813	Economy	6600.00
0005434183625	29813	Economy	6600.00
0005435697960	16491	Economy	19900.00
0005435697946	16491	Economy	19900.00
0005435697937	16491	Economy	18100.00
0005435697958	16491	Economy	18100.00
0005435697955	16491	Economy	18100.00
0005435697945	16491	Economy	18100.00
0005435697954	16491	Economy	18100.00
0005435697942	16491	Economy	18100.00
0005435697948	16491	Economy	18100.00
0005435935077	16491	Economy	18100.00
0005435697943	16491	Economy	18100.00
0005435697951	16491	Economy	18100.00
0005435697944	16491	Economy	18100.00
0005435697959	16491	Economy	18100.00
0005435697939	16491	Economy	18100.00
0005435697940	16491	Economy	18100.00
0005435697938	16491	Economy	18100.00
0005435697957	16491	Economy	18100.00
0005435697961	16491	Economy	18100.00
0005435697962	16491	Economy	18100.00
0005435697941	16491	Economy	18100.00
0005435697949	16491	Economy	18100.00
0005435697952	16491	Economy	18100.00
0005435697950	16491	Economy	18100.00
0005435697953	16491	Economy	18100.00
0005435697956	16491	Economy	18100.00
0005435697936	16491	Economy	18100.00
0005435697935	16491	Economy	18100.00
0005435697947	16491	Economy	18100.00
0005435697719	24721	Economy	19900.00
0005435935117	24721	Economy	18100.00
0005435697775	24721	Economy	18100.00
0005435697670	24721	Economy	18100.00
0005435697651	24721	Economy	18100.00
0005435697739	24721	Economy	18100.00
0005435697858	24721	Economy	18100.00
0005435697812	24721	Economy	18100.00
0005435697776	24721	Economy	18100.00
0005435697749	24721	Economy	18100.00
0005435935115	24721	Economy	18100.00
0005435697594	24721	Economy	18100.00
0005435697740	24721	Economy	18100.00
0005435933570	24721	Economy	18100.00
0005435697784	24721	Economy	18100.00
0005435935116	24721	Economy	18100.00
0005435697814	24721	Economy	18100.00
0005435933571	24721	Economy	18100.00
0005435697748	24721	Economy	18100.00
0005435935114	24721	Economy	18100.00
0005435697892	24721	Economy	18100.00
0005435697682	24721	Economy	18100.00
0005435697683	24721	Economy	18100.00
0005435935118	24721	Economy	18100.00
0005435697685	24721	Economy	18100.00
0005435697690	24721	Economy	18100.00
0005435697741	24721	Economy	18100.00
0005435697813	24721	Economy	18100.00
0005435697684	24721	Economy	18100.00
0005435697652	24721	Economy	18100.00
0005435697857	24721	Economy	18100.00
0005435697794	24721	Economy	18100.00
0005435697891	24721	Economy	18100.00
0005435697679	24721	Economy	18100.00
0005435697691	24721	Economy	18100.00
0005435697639	24721	Economy	18100.00
0005435697818	24721	Economy	18100.00
0005435697680	24721	Economy	18100.00
0005433724906	18790	Economy	4400.00
0005432968871	18790	Economy	4400.00
0005433724904	18790	Economy	4400.00
0005433724908	18790	Economy	4400.00
0005433724907	18790	Economy	4400.00
0005432968870	18790	Economy	4400.00
0005433724905	18790	Economy	4400.00
0005433724856	21593	Economy	4400.00
0005432968895	21593	Economy	4400.00
0005432968893	21593	Economy	4400.00
0005432968894	21593	Economy	4400.00
0005434139980	7301	Business	23100.00
0005434140014	7301	Business	23100.00
0005434139989	7301	Business	23100.00
0005434140027	7301	Business	23100.00
0005434140031	7301	Business	23100.00
0005434139996	7301	Business	23100.00
0005434140032	7301	Business	23100.00
0005434139949	7301	Business	23100.00
0005434140010	7301	Business	23100.00
0005434087625	7301	Business	23100.00
0005434139981	7301	Business	23100.00
0005434139968	7301	Business	23100.00
0005434139994	7301	Economy	7700.00
0005434140002	7301	Economy	7700.00
0005434140030	7301	Economy	7700.00
0005434087623	7301	Economy	7700.00
0005434140011	7301	Economy	7700.00
0005434140026	7301	Economy	7700.00
0005434139948	7301	Economy	7700.00
0005434139944	7301	Economy	7700.00
0005434140024	7301	Economy	7700.00
0005434139997	7301	Economy	8500.00
0005434139947	7301	Economy	8500.00
0005434139955	7301	Economy	8500.00
0005434139985	7301	Economy	8500.00
0005434139964	7301	Economy	8500.00
0005434139950	7301	Economy	7700.00
0005434139956	7301	Economy	7700.00
0005434139999	7301	Economy	7700.00
0005434140004	7301	Economy	7700.00
0005434139993	7301	Economy	7700.00
0005434139960	7301	Economy	7700.00
0005434140009	7301	Economy	7700.00
0005434139974	7301	Economy	7700.00
0005434139982	7301	Economy	7700.00
0005434139984	7301	Economy	7700.00
0005434139986	7301	Economy	7700.00
0005434139943	7301	Economy	7700.00
0005434139988	7301	Economy	7700.00
0005434139962	7301	Economy	7700.00
0005434139966	7301	Economy	7700.00
0005434139995	7301	Economy	7700.00
0005434140005	7301	Economy	7700.00
0005434139963	7301	Economy	7700.00
0005434140003	7301	Economy	7700.00
0005434139945	7301	Economy	7700.00
0005434139979	7301	Economy	7700.00
0005434139946	7301	Economy	7700.00
0005434140017	7301	Economy	7700.00
0005434139958	7301	Economy	7700.00
0005434087626	7301	Economy	7700.00
0005434140019	7301	Economy	7700.00
0005434139969	7301	Economy	7700.00
0005434140007	7301	Economy	7700.00
0005434139957	7301	Economy	7700.00
0005434139998	7301	Economy	7700.00
0005434139952	7301	Economy	7700.00
0005434140023	7301	Economy	7700.00
0005434139976	7301	Economy	7700.00
0005434139990	7301	Economy	7700.00
0005434140015	7301	Economy	7700.00
0005434140025	7301	Economy	7700.00
0005434140016	7301	Economy	7700.00
0005434139961	7301	Economy	7700.00
0005434139971	7301	Economy	7700.00
0005434139959	7301	Economy	7700.00
0005434139991	7301	Economy	7700.00
0005434140018	7301	Economy	7700.00
0005434140000	7301	Economy	7700.00
0005434139953	7301	Economy	7700.00
0005434139970	7301	Economy	7700.00
0005434139951	7301	Economy	7700.00
0005434140028	7301	Economy	7700.00
0005434139941	7301	Economy	7700.00
0005434139992	7301	Economy	7700.00
0005434139942	7301	Economy	7700.00
0005434140012	7301	Economy	7700.00
0005434139973	7301	Economy	7700.00
0005434140022	7301	Economy	7700.00
0005434140006	7301	Economy	7700.00
0005434139977	7301	Economy	7700.00
0005434139967	7301	Economy	7700.00
0005434139975	7301	Economy	7700.00
0005434139972	7301	Economy	7700.00
0005434087624	7301	Economy	7700.00
0005434140013	7301	Economy	7700.00
0005434139983	7301	Economy	7700.00
0005434139987	7301	Economy	7700.00
0005434140001	7301	Economy	7700.00
0005434139954	7301	Economy	7700.00
0005434140020	7301	Economy	7700.00
0005434139965	7301	Economy	7700.00
0005434139978	7301	Economy	7700.00
0005434140029	7301	Economy	7700.00
0005434140021	7301	Economy	7700.00
0005434140008	7301	Economy	7700.00
0005434139192	28531	Business	23100.00
0005434139150	28531	Business	23100.00
0005434139097	28531	Business	23100.00
0005434139424	28531	Business	23100.00
0005434139209	28531	Business	23100.00
0005434139271	28531	Business	23100.00
0005434139442	28531	Business	23100.00
0005434138949	28531	Business	23100.00
0005434139193	28531	Business	23100.00
0005434087572	28531	Business	23100.00
0005434139119	28531	Business	23100.00
0005434139553	28531	Economy	7700.00
0005434139276	28531	Economy	7700.00
0005434139228	28531	Economy	7700.00
0005434139349	28531	Economy	7700.00
0005434139274	28531	Economy	7700.00
0005434138885	28531	Economy	7700.00
0005434138855	28531	Economy	7700.00
0005434139483	28531	Economy	7700.00
0005434139227	28531	Economy	7700.00
0005434139250	28531	Economy	8500.00
0005434139128	28531	Economy	8500.00
0005434139340	28531	Economy	8500.00
0005434139375	28531	Economy	8500.00
0005434139208	28531	Economy	8500.00
0005434139105	28531	Economy	7700.00
0005434139341	28531	Economy	7700.00
0005434139362	28531	Economy	7700.00
0005434087591	28531	Economy	7700.00
0005434139249	28531	Economy	7700.00
0005434139089	28531	Economy	7700.00
0005434139200	28531	Economy	7700.00
0005434139268	28531	Economy	7700.00
0005434139292	28531	Economy	7700.00
0005434139263	28531	Economy	7700.00
0005434139212	28531	Economy	7700.00
0005434139360	28531	Economy	7700.00
0005434139577	28531	Economy	7700.00
0005434139019	28531	Economy	7700.00
0005434139048	28531	Economy	7700.00
0005434139317	28531	Economy	7700.00
0005434139376	28531	Economy	7700.00
0005434139142	28531	Economy	7700.00
0005434139167	28531	Economy	7700.00
0005434139098	28531	Economy	7700.00
0005434139082	28531	Economy	7700.00
0005434139088	28531	Economy	7700.00
0005434139394	28531	Economy	7700.00
0005434139443	28531	Economy	7700.00
0005434139053	28531	Economy	7700.00
0005434138924	28531	Economy	7700.00
0005434139260	28531	Economy	7700.00
0005434139264	28531	Economy	7700.00
0005434139248	28531	Economy	7700.00
0005434138884	28531	Economy	7700.00
0005434139367	28531	Economy	7700.00
0005434139081	28531	Economy	7700.00
0005434139131	28531	Economy	7700.00
0005434139141	28531	Economy	7700.00
0005434139505	28531	Economy	7700.00
0005434087592	28531	Economy	7700.00
0005434139387	28531	Economy	7700.00
0005434087596	28531	Economy	7700.00
0005434139214	28531	Economy	7700.00
0005434139400	28531	Economy	7700.00
0005434087582	28531	Economy	7700.00
0005434139532	28531	Economy	7700.00
0005434139425	28531	Economy	7700.00
0005434138923	28531	Economy	7700.00
0005434139287	28531	Economy	7700.00
0005434139064	28531	Economy	7700.00
0005434139143	28531	Economy	7700.00
0005434139157	28531	Economy	7700.00
0005434138880	28531	Economy	7700.00
0005434139361	28531	Economy	7700.00
0005434087581	28531	Economy	7700.00
0005434139144	28531	Economy	7700.00
0005434139120	28531	Economy	7700.00
0005434139272	28531	Economy	7700.00
0005434087595	28531	Economy	7700.00
0005434139156	28531	Economy	7700.00
0005434139129	28531	Economy	7700.00
0005434139083	28531	Economy	7700.00
0005434139576	28531	Economy	7700.00
0005434139506	28531	Economy	7700.00
0005434139277	28531	Economy	7700.00
0005434139311	28531	Economy	7700.00
0005434139261	28531	Economy	7700.00
0005434138932	28531	Economy	7700.00
0005434139578	28531	Economy	7700.00
0005434139251	28531	Economy	7700.00
0005434138925	28531	Economy	7700.00
0005434139267	28531	Economy	7700.00
0005434139347	28531	Economy	7700.00
0005433407631	1921	Economy	21700.00
0005435808456	1921	Economy	21700.00
0005435808461	1921	Economy	21700.00
0005434610312	1921	Economy	21700.00
0005433407632	1921	Economy	21700.00
0005433407627	1921	Economy	21700.00
0005433407619	1921	Economy	21700.00
0005435808459	1921	Economy	21700.00
0005435808453	1921	Economy	21700.00
0005434610311	1921	Economy	21700.00
0005433407635	1921	Economy	21700.00
0005435808454	1921	Economy	21700.00
0005435808455	1921	Economy	21700.00
0005433407636	1921	Economy	21700.00
0005435808457	1921	Economy	21700.00
0005435808458	1921	Economy	21700.00
0005433407634	1921	Economy	21700.00
0005435808460	1921	Economy	21700.00
0005434610268	23090	Economy	21700.00
0005434610281	23090	Economy	21700.00
0005434610272	23090	Economy	21700.00
0005434610277	23090	Economy	21700.00
0005434610280	23090	Economy	21700.00
0005434610267	23090	Economy	21700.00
0005434504843	16691	Economy	7600.00
0005434504437	16691	Economy	7600.00
0005434504579	16691	Economy	7600.00
0005434504583	16691	Economy	7600.00
0005434504654	16691	Economy	6900.00
0005434504842	16691	Economy	6900.00
0005434504658	16691	Economy	6900.00
0005434504550	16691	Economy	6900.00
0005434504638	16691	Economy	6900.00
0005434504738	16691	Economy	6900.00
0005434504719	16691	Economy	6900.00
0005434504588	16691	Economy	6900.00
0005434504659	16691	Economy	6900.00
0005434504436	16691	Economy	6900.00
0005434504526	16691	Economy	6900.00
0005434504710	16691	Economy	6900.00
0005434504563	16691	Economy	6900.00
0005434504721	16691	Economy	6900.00
0005434504520	16691	Economy	6900.00
0005434504737	16691	Economy	6900.00
0005434504584	16691	Economy	6900.00
0005434504882	16691	Economy	6900.00
0005434504557	16691	Economy	6900.00
0005434504741	16691	Economy	6900.00
0005434504714	16691	Economy	6900.00
0005434504773	16691	Economy	6900.00
0005434504438	16691	Economy	6900.00
0005434504657	16691	Economy	6900.00
0005434504702	16691	Economy	6900.00
0005434504484	16691	Economy	6900.00
0005434504519	16691	Economy	6900.00
0005434504585	16691	Economy	6900.00
0005434504775	16691	Economy	6900.00
0005434504762	16691	Economy	6900.00
0005434504535	16691	Economy	6900.00
0005434504709	16691	Economy	6900.00
0005434504565	16691	Economy	6900.00
0005434504642	16691	Economy	6900.00
0005434504819	16691	Economy	6900.00
0005434504718	16691	Economy	6900.00
0005434504491	16691	Economy	6900.00
0005434504685	16691	Economy	6900.00
0005434504855	16691	Economy	6900.00
0005434504525	16691	Economy	6900.00
0005434504700	16691	Economy	6900.00
0005434504720	16691	Economy	6900.00
0005434504582	16691	Economy	6900.00
0005434504490	16691	Economy	6900.00
0005434504774	16691	Economy	6900.00
0005434505015	22927	Economy	7600.00
0005434505023	22927	Economy	7600.00
0005434505003	22927	Economy	7600.00
0005434505004	22927	Economy	6900.00
0005434505016	22927	Economy	6900.00
0005434505020	22927	Economy	6900.00
0005434505011	22927	Economy	6900.00
0005434505005	22927	Economy	6900.00
0005434504996	22927	Economy	6900.00
0005434505028	22927	Economy	6900.00
0005434505001	22927	Economy	6900.00
0005434505008	22927	Economy	6900.00
0005434505019	22927	Economy	6900.00
0005434505009	22927	Economy	6900.00
0005434505017	22927	Economy	6900.00
0005434504991	22927	Economy	6900.00
0005434505007	22927	Economy	6900.00
0005434504989	22927	Economy	6900.00
0005434504995	22927	Economy	6900.00
0005434505002	22927	Economy	6900.00
0005434504997	22927	Economy	6900.00
0005434505025	22927	Economy	6900.00
0005434505010	22927	Economy	6900.00
0005434505013	22927	Economy	6900.00
0005434504994	22927	Economy	6900.00
0005434505030	22927	Economy	6900.00
0005434504998	22927	Economy	6900.00
0005434505024	22927	Economy	6900.00
0005434505018	22927	Economy	6900.00
0005434504990	22927	Economy	6900.00
0005434505022	22927	Economy	6900.00
0005434505027	22927	Economy	6900.00
0005434505000	22927	Economy	6900.00
0005434505021	22927	Economy	6900.00
0005434505026	22927	Economy	6900.00
0005434505012	22927	Economy	6900.00
0005434504992	22927	Economy	6900.00
0005434504993	22927	Economy	6900.00
0005434505006	22927	Economy	6900.00
0005434505014	22927	Economy	6900.00
0005434505029	22927	Economy	6900.00
0005434504999	22927	Economy	6900.00
0005435078698	2203	Economy	7700.00
0005435078700	2203	Economy	7700.00
0005435078692	2203	Economy	7000.00
0005435078695	2203	Economy	7000.00
0005435078687	2203	Economy	7000.00
0005433266863	2203	Economy	7000.00
0005433266870	2203	Economy	7000.00
0005433266846	2203	Economy	7000.00
0005433266845	2203	Economy	7000.00
0005433266867	2203	Economy	7000.00
0005433266843	2203	Economy	7000.00
0005435078691	2203	Economy	7000.00
0005435078689	2203	Economy	7000.00
0005435078696	2203	Economy	7000.00
0005435078699	2203	Economy	7000.00
0005433266862	2203	Economy	7000.00
0005435078697	2203	Economy	7000.00
0005435078686	2203	Economy	7000.00
0005433266844	2203	Economy	7000.00
0005435078690	2203	Economy	7000.00
0005435078693	2203	Economy	7000.00
0005435078688	2203	Economy	7000.00
0005435078694	2203	Economy	7000.00
0005433266877	2203	Economy	7000.00
0005435078540	24348	Economy	7700.00
0005435078491	24348	Economy	7000.00
0005433266932	24348	Economy	7000.00
0005435078516	24348	Economy	7000.00
0005433266930	24348	Economy	7000.00
0005435078571	24348	Economy	7000.00
0005435078634	24348	Economy	7000.00
0005435078606	24348	Economy	7000.00
0005433266937	24348	Economy	7000.00
0005435078586	24348	Economy	7000.00
0005435078539	24348	Economy	7000.00
0005435078605	24348	Economy	7000.00
0005433266929	24348	Economy	7000.00
0005435078502	24348	Economy	7000.00
0005435078503	24348	Economy	7000.00
0005435078572	24348	Economy	7000.00
0005433266933	24348	Economy	7000.00
0005433266935	24348	Economy	7000.00
0005435078587	24348	Economy	7000.00
0005433266931	24348	Economy	7000.00
0005435078622	24348	Economy	7000.00
0005435078591	24348	Economy	7000.00
0005433266934	24348	Economy	7000.00
0005433266936	24348	Economy	7000.00
0005434988979	6661	Economy	9800.00
0005434988978	6661	Economy	9800.00
0005434988982	6661	Economy	9800.00
0005435803328	6661	Economy	9800.00
0005434988991	6661	Economy	9800.00
0005434988983	6661	Economy	9800.00
0005434988989	6661	Economy	9800.00
0005434988985	6661	Economy	9800.00
0005434988987	6661	Economy	9800.00
0005434988990	6661	Economy	9800.00
0005434988977	6661	Economy	9800.00
0005434988980	6661	Economy	9800.00
0005435803327	6661	Economy	9800.00
0005434988976	6661	Economy	9800.00
0005435464535	6661	Economy	9800.00
0005435803326	6661	Economy	9800.00
0005434988975	6661	Economy	9800.00
0005434988986	6661	Economy	9800.00
0005434988981	6661	Economy	9800.00
0005434988984	6661	Economy	9800.00
0005434988988	6661	Economy	9800.00
0005435464536	6661	Economy	9800.00
0005434988870	23588	Economy	10800.00
0005434988832	23588	Economy	9800.00
0005434988844	23588	Economy	9800.00
0005434988885	23588	Economy	9800.00
0005434988845	23588	Economy	9800.00
0005434988875	23588	Economy	9800.00
0005435464553	23588	Economy	9800.00
0005434988816	23588	Economy	9800.00
0005435803307	23588	Economy	9800.00
0005434988878	23588	Economy	9800.00
0005434988865	23588	Economy	9800.00
0005434988868	23588	Economy	9800.00
0005434988882	23588	Economy	9800.00
0005434988871	23588	Economy	9800.00
0005434988809	23588	Economy	9800.00
0005435464552	23588	Economy	9800.00
0005434988881	23588	Economy	9800.00
0005432384038	30481	Business	9900.00
0005433450463	30481	Business	9900.00
0005432384044	30481	Business	9900.00
0005433450471	30481	Business	9900.00
0005433450454	30481	Business	9900.00
0005433453808	30481	Business	9900.00
0005433450468	30481	Business	9900.00
0005432384063	30481	Economy	3300.00
0005432384040	30481	Economy	3300.00
0005433450455	30481	Economy	3300.00
0005432384053	30481	Economy	3300.00
0005432384069	30481	Economy	3300.00
0005432384071	30481	Economy	3300.00
0005433450461	30481	Economy	3300.00
0005432384046	30481	Economy	3300.00
0005432384048	30481	Economy	3600.00
0005433450462	30481	Economy	3600.00
0005432384047	30481	Economy	3600.00
0005433450460	30481	Economy	3300.00
0005433450464	30481	Economy	3300.00
0005432384061	30481	Economy	3300.00
0005433454923	30481	Economy	3300.00
0005433450453	30481	Economy	3300.00
0005433450473	30481	Economy	3300.00
0005432384070	30481	Economy	3300.00
0005432384064	30481	Economy	3300.00
0005432384057	30481	Economy	3300.00
0005432384041	30481	Economy	3300.00
0005433450456	30481	Economy	3300.00
0005433450457	30481	Economy	3300.00
0005432384073	30481	Economy	3300.00
0005432384068	30481	Economy	3300.00
0005432384043	30481	Economy	3300.00
0005432384037	30481	Economy	3300.00
0005433454924	30481	Economy	3300.00
0005433450469	30481	Economy	3300.00
0005433450470	30481	Economy	3300.00
0005433450474	30481	Economy	3300.00
0005432384056	30481	Economy	3300.00
0005432384045	30481	Economy	3300.00
0005433450459	30481	Economy	3300.00
0005432384049	30481	Economy	3300.00
0005432384054	30481	Economy	3300.00
0005432384052	30481	Economy	3300.00
0005432384062	30481	Economy	3300.00
0005433450465	30481	Economy	3300.00
0005432384059	30481	Economy	3300.00
0005432384055	30481	Economy	3300.00
0005432384060	30481	Economy	3300.00
0005433450467	30481	Economy	3300.00
0005432384042	30481	Economy	3300.00
0005432384039	30481	Economy	3300.00
0005433450466	30481	Economy	3300.00
0005432384072	30481	Economy	3300.00
0005433450472	30481	Economy	3300.00
0005432384051	30481	Economy	3300.00
0005432384050	30481	Economy	3300.00
0005432384067	30481	Economy	3300.00
0005433450458	30481	Economy	3300.00
0005433453807	30481	Economy	3300.00
0005432384058	30481	Economy	3300.00
0005432384065	30481	Economy	3300.00
0005432384066	30481	Economy	3300.00
0005432383556	31313	Business	9900.00
0005433453784	31313	Business	9900.00
0005433450352	31313	Business	9900.00
0005432383692	31313	Business	9900.00
0005433450336	31313	Business	9900.00
0005433450304	31313	Business	9900.00
0005432383567	31313	Business	9900.00
0005432383555	31313	Business	9900.00
0005433450223	31313	Business	9900.00
0005432383664	31313	Economy	3300.00
0005433453790	31313	Economy	3300.00
0005433453783	31313	Economy	3300.00
0005433450310	31313	Economy	3300.00
0005433450236	31313	Economy	3600.00
0005433450366	31313	Economy	3600.00
0005432383675	31313	Economy	3300.00
0005433450360	31313	Economy	3300.00
0005432383568	31313	Economy	3300.00
0005432383631	31313	Economy	3300.00
0005432383554	31313	Economy	3300.00
0005432383585	31313	Economy	3300.00
0005433453788	31313	Economy	3300.00
0005432383719	31313	Economy	3300.00
0005432383584	31313	Economy	3300.00
0005432383655	31313	Economy	3300.00
0005432383642	31313	Economy	3300.00
0005432383770	31313	Economy	3300.00
0005432383465	31313	Economy	3300.00
0005433450242	31313	Economy	3300.00
0005433450303	31313	Economy	3300.00
0005432383707	31313	Economy	3300.00
0005432383593	31313	Economy	3300.00
0005432383643	31313	Economy	3300.00
0005432383700	31313	Economy	3300.00
0005432383622	31313	Economy	3300.00
0005432383629	31313	Economy	3300.00
0005432383735	31313	Economy	3300.00
0005432383680	31313	Economy	3300.00
0005432383769	31313	Economy	3300.00
0005433450311	31313	Economy	3300.00
0005432383562	31313	Economy	3300.00
0005433450243	31313	Economy	3300.00
0005433450333	31313	Economy	3300.00
0005433451646	31313	Economy	3300.00
0005432383447	31313	Economy	3300.00
0005433450155	31313	Economy	3300.00
0005432383847	31313	Economy	3300.00
0005433450337	31313	Economy	3300.00
0005432383566	31313	Economy	3300.00
0005432383569	31313	Economy	3300.00
0005432383674	31313	Economy	3300.00
0005433453785	31313	Economy	3300.00
0005433453786	31313	Economy	3300.00
0005432383632	31313	Economy	3300.00
0005433450353	31313	Economy	3300.00
0005433453791	31313	Economy	3300.00
0005432383733	31313	Economy	3300.00
0005433450224	31313	Economy	3300.00
0005432383594	31313	Economy	3300.00
0005433450365	31313	Economy	3300.00
0005432383825	31313	Economy	3300.00
0005432383583	31313	Economy	3300.00
0005433453782	31313	Economy	3300.00
0005432383747	31313	Economy	3300.00
0005433450359	31313	Economy	3300.00
0005433451642	31313	Economy	3300.00
0005432383597	31313	Economy	3300.00
0005432383630	31313	Economy	3300.00
0005432383598	31313	Economy	3300.00
0005433450268	31313	Economy	3300.00
0005433788251	26481	Economy	26200.00
0005433788236	26481	Economy	26200.00
0005433788256	26481	Economy	26200.00
0005435548600	26481	Economy	23800.00
0005433788255	26481	Economy	23800.00
0005433788254	26481	Economy	23800.00
0005435548594	26481	Economy	23800.00
0005435548601	26481	Economy	23800.00
0005435548593	26481	Economy	23800.00
0005435548598	26481	Economy	23800.00
0005435548599	26481	Economy	23800.00
0005435548595	26481	Economy	23800.00
0005435548597	26481	Economy	23800.00
0005435548602	26481	Economy	23800.00
0005433788249	26481	Economy	23800.00
0005435548596	26481	Economy	23800.00
0005435299848	10777	Economy	17100.00
0005435304207	10777	Economy	17100.00
0005435304221	10777	Economy	15600.00
0005433131755	10777	Economy	15600.00
0005435304213	10777	Economy	15600.00
0005433131750	10777	Economy	15600.00
0005433131779	10777	Economy	15600.00
0005433131771	10777	Economy	15600.00
0005435304210	10777	Economy	15600.00
0005435299839	10777	Economy	15600.00
0005433126891	10777	Economy	15600.00
0005433126895	10777	Economy	15600.00
0005433126893	10777	Economy	15600.00
0005433131756	10777	Economy	15600.00
0005435304214	10777	Economy	15600.00
0005435304212	10777	Economy	15600.00
0005433126910	10777	Economy	15600.00
0005435304208	10777	Economy	15600.00
0005435304220	10777	Economy	15600.00
0005433126894	10777	Economy	15600.00
0005433126909	10777	Economy	15600.00
0005435299847	10777	Economy	15600.00
0005433131746	10777	Economy	15600.00
0005433131763	10777	Economy	15600.00
0005433131754	10777	Economy	15600.00
0005435299840	10777	Economy	15600.00
0005433131745	10777	Economy	15600.00
0005433131780	10777	Economy	15600.00
0005433126890	10777	Economy	15600.00
0005433126900	10777	Economy	15600.00
0005433126952	29695	Economy	15600.00
0005435299888	29695	Economy	15600.00
0005435299889	29695	Economy	15600.00
0005433129382	29695	Economy	15600.00
0005435299887	29695	Economy	15600.00
0005435302311	29695	Economy	15600.00
0005433126954	29695	Economy	15600.00
0005433129385	29695	Economy	15600.00
0005433129383	29695	Economy	15600.00
0005433126953	29695	Economy	15600.00
0005435299886	29695	Economy	15600.00
0005435302308	29695	Economy	15600.00
0005435302309	29695	Economy	15600.00
0005435302310	29695	Economy	15600.00
0005433129384	29695	Economy	15600.00
0005433126955	29695	Economy	15600.00
0005434287795	2419	Economy	17200.00
0005434287783	2419	Economy	17200.00
0005434287779	2419	Economy	15700.00
0005434287801	2419	Economy	15700.00
0005434287781	2419	Economy	15700.00
0005434287799	2419	Economy	15700.00
0005433110210	2419	Economy	15700.00
0005433110236	2419	Economy	15700.00
0005433110242	2419	Economy	15700.00
0005434287797	2419	Economy	15700.00
0005434287787	2419	Economy	15700.00
0005434287792	2419	Economy	15700.00
0005433110243	2419	Economy	15700.00
0005432264531	2419	Economy	15700.00
0005434287788	2419	Economy	15700.00
0005434287790	2419	Economy	15700.00
0005434287798	2419	Economy	15700.00
0005434287794	2419	Economy	15700.00
0005434287791	2419	Economy	15700.00
0005434287800	2419	Economy	15700.00
0005434287782	2419	Economy	15700.00
0005434287786	2419	Economy	15700.00
0005434287784	2419	Economy	15700.00
0005433110248	2419	Economy	15700.00
0005434287789	2419	Economy	15700.00
0005433110277	2419	Economy	15700.00
0005434287780	2419	Economy	15700.00
0005434287802	2419	Economy	15700.00
0005432264530	2419	Economy	15700.00
0005434287793	2419	Economy	15700.00
0005434287785	2419	Economy	15700.00
0005434287796	2419	Economy	15700.00
0005433110237	2419	Economy	15700.00
0005434287602	26826	Economy	17200.00
0005434287644	26826	Economy	17200.00
0005433110331	26826	Economy	17200.00
0005433110321	26826	Economy	15700.00
0005434287567	26826	Economy	15700.00
0005434287606	26826	Economy	15700.00
0005434287668	26826	Economy	15700.00
0005433110332	26826	Economy	15700.00
0005434287643	26826	Economy	15700.00
0005433110322	26826	Economy	15700.00
0005434287587	26826	Economy	15700.00
0005434287629	26826	Economy	15700.00
0005433110324	26826	Economy	15700.00
0005434287613	26826	Economy	15700.00
0005434287655	26826	Economy	15700.00
0005434287539	26826	Economy	15700.00
0005434287608	26826	Economy	15700.00
0005434287617	26826	Economy	15700.00
0005434287529	26826	Economy	15700.00
0005433110333	26826	Economy	15700.00
0005434287568	26826	Economy	15700.00
0005433110328	26826	Economy	15700.00
0005434287612	26826	Economy	15700.00
0005433110327	26826	Economy	15700.00
0005434287641	26826	Economy	15700.00
0005434287592	26826	Economy	15700.00
0005434287636	26826	Economy	15700.00
0005434287601	26826	Economy	15700.00
0005434287557	26826	Economy	15700.00
0005434287586	26826	Economy	15700.00
0005434287673	26826	Economy	15700.00
0005433110330	26826	Economy	15700.00
0005434287674	26826	Economy	15700.00
0005434287635	26826	Economy	15700.00
0005434287645	26826	Economy	15700.00
0005434287642	26826	Economy	15700.00
0005433110323	26826	Economy	15700.00
0005434287669	26826	Economy	15700.00
0005433110329	26826	Economy	15700.00
0005433110326	26826	Economy	15700.00
0005433110325	26826	Economy	15700.00
0005435856302	25493	Economy	22800.00
0005434269128	25493	Economy	22800.00
0005434269129	25493	Economy	22800.00
0005434272215	25493	Economy	22800.00
0005435856336	25493	Economy	22800.00
0005434272214	25493	Economy	22800.00
0005435856299	25493	Economy	22800.00
0005435856303	25493	Economy	22800.00
0005434269126	25493	Economy	22800.00
0005434269127	25493	Economy	22800.00
0005435856300	25493	Economy	22800.00
0005435856301	25493	Economy	22800.00
0005435856335	25493	Economy	22800.00
0005435856298	25493	Economy	22800.00
0005434273111	26671	Economy	22800.00
0005434272224	26671	Economy	22800.00
0005435856259	26671	Economy	22800.00
0005435856256	26671	Economy	22800.00
0005434273112	26671	Economy	22800.00
0005435856257	26671	Economy	22800.00
0005434272225	26671	Economy	22800.00
0005435856235	26671	Economy	22800.00
0005435856236	26671	Economy	22800.00
0005435856258	26671	Economy	22800.00
0005435314920	19069	Economy	24600.00
0005435314926	19069	Economy	24600.00
0005434520353	19069	Economy	24600.00
0005435314928	19069	Economy	24600.00
0005434520367	19069	Economy	22300.00
0005435314925	19069	Economy	22300.00
0005434520365	19069	Economy	22300.00
0005434520404	19069	Economy	22300.00
0005434520343	19069	Economy	22300.00
0005434520345	19069	Economy	22300.00
0005434520362	19069	Economy	22300.00
0005434520388	19069	Economy	22300.00
0005434520381	19069	Economy	22300.00
0005435314918	19069	Economy	22300.00
0005434520334	19069	Economy	22300.00
0005435314924	19069	Economy	22300.00
0005434520364	19069	Economy	22300.00
0005434520350	19069	Economy	22300.00
0005434520336	19069	Economy	22300.00
0005435314915	19069	Economy	22300.00
0005435314914	19069	Economy	22300.00
0005434520370	19069	Economy	22300.00
0005434520385	19069	Economy	22300.00
0005434520354	19069	Economy	22300.00
0005435314922	19069	Economy	22300.00
0005435314917	19069	Economy	22300.00
0005434520351	19069	Economy	22300.00
0005435314923	19069	Economy	22300.00
0005434520352	19069	Economy	22300.00
0005434520349	19069	Economy	22300.00
0005434520344	19069	Economy	22300.00
0005434520380	19069	Economy	22300.00
0005435314927	19069	Economy	22300.00
0005435314916	19069	Economy	22300.00
0005434520378	19069	Economy	22300.00
0005434520398	19069	Economy	22300.00
0005434520384	19069	Economy	22300.00
0005434520403	19069	Economy	22300.00
0005435314930	19069	Economy	22300.00
0005435314919	19069	Economy	22300.00
0005434520366	19069	Economy	22300.00
0005434520373	19069	Economy	22300.00
0005434520363	19069	Economy	22300.00
0005434520369	19069	Economy	22300.00
0005434520331	19069	Economy	22300.00
0005435314921	19069	Economy	22300.00
0005435314913	19069	Economy	22300.00
0005434520359	19069	Economy	22300.00
0005435314929	19069	Economy	22300.00
0005433874433	7790	Economy	19200.00
0005433874427	7790	Economy	17400.00
0005433874429	7790	Economy	17400.00
0005433874422	7790	Economy	17400.00
0005433874431	7790	Economy	17400.00
0005433874435	7790	Economy	17400.00
0005433874432	7790	Economy	17400.00
0005433874434	7790	Economy	17400.00
0005433874428	7790	Economy	17400.00
0005433874426	7790	Economy	17400.00
0005433874423	7790	Economy	17400.00
0005433874425	7790	Economy	17400.00
0005433874420	7790	Economy	17400.00
0005433874430	7790	Economy	17400.00
0005433874421	7790	Economy	17400.00
0005433874424	7790	Economy	17400.00
0005433874406	32641	Economy	17400.00
0005433874407	32641	Economy	17400.00
0005433874390	32641	Economy	17400.00
0005433874396	32641	Economy	17400.00
0005433874391	32641	Economy	17400.00
0005433874402	32641	Economy	17400.00
0005433874376	32641	Economy	17400.00
0005433874403	32641	Economy	17400.00
0005433874401	32641	Economy	17400.00
0005433874418	32641	Economy	17400.00
0005433874410	32641	Economy	17400.00
0005433874397	32641	Economy	17400.00
0005433874389	32641	Economy	17400.00
0005433874409	32641	Economy	17400.00
0005433874411	32641	Economy	17400.00
0005433874388	32641	Economy	17400.00
0005433874387	32641	Economy	17400.00
0005433874408	32641	Economy	17400.00
0005433869331	4773	Economy	19400.00
0005433869329	4773	Economy	19400.00
0005433869345	4773	Economy	19400.00
0005435860531	4773	Economy	19400.00
0005433869361	4773	Economy	17600.00
0005433869343	4773	Economy	17600.00
0005433869363	4773	Economy	17600.00
0005433869330	4773	Economy	17600.00
0005433869352	4773	Economy	17600.00
0005433869356	4773	Economy	17600.00
0005433869357	4773	Economy	17600.00
0005433869337	4773	Economy	17600.00
0005433869332	4773	Economy	17600.00
0005433869336	4773	Economy	17600.00
0005433869326	4773	Economy	17600.00
0005433869354	4773	Economy	17600.00
0005433869347	4773	Economy	17600.00
0005433869324	4773	Economy	17600.00
0005433869325	4773	Economy	17600.00
0005433869344	4773	Economy	17600.00
0005433869358	4773	Economy	17600.00
0005433869339	4773	Economy	17600.00
0005433869341	4773	Economy	17600.00
0005433869342	4773	Economy	17600.00
0005433869334	4773	Economy	17600.00
0005435860532	4773	Economy	17600.00
0005433869338	4773	Economy	17600.00
0005433869333	4773	Economy	17600.00
0005433869365	4773	Economy	17600.00
0005433869364	4773	Economy	17600.00
0005433869328	4773	Economy	17600.00
0005433869359	4773	Economy	17600.00
0005433869346	4773	Economy	17600.00
0005433869362	4773	Economy	17600.00
0005433869340	4773	Economy	17600.00
0005433869348	4773	Economy	17600.00
0005433869351	4773	Economy	17600.00
0005433869335	4773	Economy	17600.00
0005433869350	4773	Economy	17600.00
0005433869327	4773	Economy	17600.00
0005433869349	4773	Economy	17600.00
0005435860540	4773	Economy	17600.00
0005433869355	4773	Economy	17600.00
0005433869360	4773	Economy	17600.00
0005433869353	4773	Economy	17600.00
0005435860587	32594	Economy	19400.00
0005433869091	32594	Economy	19400.00
0005433869102	32594	Economy	19400.00
0005433869008	32594	Economy	19400.00
0005433868985	32594	Economy	17600.00
0005433869032	32594	Economy	17600.00
0005433868853	32594	Economy	17600.00
0005433869043	32594	Economy	17600.00
0005435860589	32594	Economy	17600.00
0005435860583	32594	Economy	17600.00
0005433869098	32594	Economy	17600.00
0005433869156	32594	Economy	17600.00
0005433869038	32594	Economy	17600.00
0005433869059	32594	Economy	17600.00
0005435860582	32594	Economy	17600.00
0005433869014	32594	Economy	17600.00
0005433868984	32594	Economy	17600.00
0005433869077	32594	Economy	17600.00
0005433869019	32594	Economy	17600.00
0005433869119	32594	Economy	17600.00
0005433869160	32594	Economy	17600.00
0005433869092	32594	Economy	17600.00
0005435860591	32594	Economy	17600.00
0005435860579	32594	Economy	17600.00
0005433868934	32594	Economy	17600.00
0005435860585	32594	Economy	17600.00
0005433868941	32594	Economy	17600.00
0005433868794	32594	Economy	17600.00
0005433869058	32594	Economy	17600.00
0005433869033	32594	Economy	17600.00
0005433868953	32594	Economy	17600.00
0005433869073	32594	Economy	17600.00
0005433868978	32594	Economy	17600.00
0005433868895	32594	Economy	17600.00
0005433869072	32594	Economy	17600.00
0005433868897	32594	Economy	17600.00
0005433869015	32594	Economy	17600.00
0005435860590	32594	Economy	17600.00
0005433869063	32594	Economy	17600.00
0005433868954	32594	Economy	17600.00
0005435860580	32594	Economy	17600.00
0005435860586	32594	Economy	17600.00
0005433868940	32594	Economy	17600.00
0005433868938	32594	Economy	17600.00
0005435860584	32594	Economy	17600.00
0005433868796	32594	Economy	17600.00
0005433869060	32594	Economy	17600.00
0005435860581	32594	Economy	17600.00
0005433868795	32594	Economy	17600.00
0005435860588	32594	Economy	17600.00
0005435911545	3443	Economy	24800.00
0005434663719	3443	Economy	24800.00
0005434460554	3443	Economy	24800.00
0005434460556	3443	Economy	22600.00
0005434663720	3443	Economy	22600.00
0005434663712	3443	Economy	22600.00
0005434461696	3443	Economy	22600.00
0005435911561	3443	Economy	22600.00
0005434461695	3443	Economy	22600.00
0005434663709	3443	Economy	22600.00
0005434663721	3443	Economy	22600.00
0005434663715	3443	Economy	22600.00
0005435911567	3443	Economy	22600.00
0005435911551	3443	Economy	22600.00
0005434663713	3443	Economy	22600.00
0005435911557	3443	Economy	22600.00
0005434663718	3443	Economy	22600.00
0005434663716	3443	Economy	22600.00
0005434460553	3443	Economy	22600.00
0005434663710	3443	Economy	22600.00
0005435911565	3443	Economy	22600.00
0005434663722	3443	Economy	22600.00
0005434663711	3443	Economy	22600.00
0005435911529	3443	Economy	22600.00
0005435911530	3443	Economy	22600.00
0005434663717	3443	Economy	22600.00
0005435911528	3443	Economy	22600.00
0005434663714	3443	Economy	22600.00
0005434460555	3443	Economy	22600.00
0005435911544	3443	Economy	22600.00
0005435911562	3443	Economy	22600.00
0005435911579	3443	Economy	22600.00
0005435911564	3443	Economy	22600.00
0005435911625	12479	Economy	24800.00
0005434462813	12479	Economy	24800.00
0005434663620	12479	Economy	24800.00
0005434462822	12479	Economy	22600.00
0005434663632	12479	Economy	22600.00
0005434460530	12479	Economy	22600.00
0005434462818	12479	Economy	22600.00
0005434460529	12479	Economy	22600.00
0005434663592	12479	Economy	22600.00
0005434462817	12479	Economy	22600.00
0005435911628	12479	Economy	22600.00
0005434460519	12479	Economy	22600.00
0005435911626	12479	Economy	22600.00
0005435911622	12479	Economy	22600.00
0005434462805	12479	Economy	22600.00
0005434462815	12479	Economy	22600.00
0005435911621	12479	Economy	22600.00
0005434460518	12479	Economy	22600.00
0005435911624	12479	Economy	22600.00
0005435911623	12479	Economy	22600.00
0005435911627	12479	Economy	22600.00
0005434462824	12479	Economy	22600.00
0005434462819	12479	Economy	22600.00
0005434460520	12479	Economy	22600.00
0005434462821	12479	Economy	22600.00
0005435911620	12479	Economy	22600.00
0005434462820	12479	Economy	22600.00
0005434663572	12479	Economy	22600.00
0005434663602	12479	Economy	22600.00
0005434663573	12479	Economy	22600.00
0005434663562	12479	Economy	22600.00
0005434663563	12479	Economy	22600.00
0005434663619	12479	Economy	22600.00
0005434462814	12479	Economy	22600.00
0005434462816	12479	Economy	22600.00
0005434663636	12479	Economy	22600.00
0005434460525	12479	Economy	22600.00
0005434462812	12479	Economy	22600.00
0005433869038	14476	Economy	18500.00
0005433869033	14476	Economy	18500.00
0005433869058	14476	Economy	18500.00
0005435860589	14476	Economy	18500.00
0005433869156	14476	Economy	16800.00
0005433869060	14476	Economy	16800.00
0005433868795	14476	Economy	16800.00
0005433869059	14476	Economy	16800.00
0005433869043	14476	Economy	16800.00
0005433869032	14476	Economy	16800.00
0005433868953	14476	Economy	16800.00
0005433869008	14476	Economy	16800.00
0005435860580	14476	Economy	16800.00
0005435860585	14476	Economy	16800.00
0005433868940	14476	Economy	16800.00
0005435860587	14476	Economy	16800.00
0005433868984	14476	Economy	16800.00
0005433869119	14476	Economy	16800.00
0005433869077	14476	Economy	16800.00
0005433868985	14476	Economy	16800.00
0005435860591	14476	Economy	16800.00
0005433868954	14476	Economy	16800.00
0005433869014	14476	Economy	16800.00
0005435860586	14476	Economy	16800.00
0005433868796	14476	Economy	16800.00
0005433868934	14476	Economy	16800.00
0005433868853	14476	Economy	16800.00
0005433868895	14476	Economy	16800.00
0005435860581	14476	Economy	16800.00
0005433869073	14476	Economy	16800.00
0005433869091	14476	Economy	16800.00
0005433868938	14476	Economy	16800.00
0005433868978	14476	Economy	16800.00
0005433869015	14476	Economy	16800.00
0005433868897	14476	Economy	16800.00
0005435860583	14476	Economy	16800.00
0005433869160	14476	Economy	16800.00
0005435860588	14476	Economy	16800.00
0005433868794	14476	Economy	16800.00
0005433869092	14476	Economy	16800.00
0005435860584	14476	Economy	16800.00
0005433869072	14476	Economy	16800.00
0005433869063	14476	Economy	16800.00
0005435860579	14476	Economy	16800.00
0005433869019	14476	Economy	16800.00
0005435860590	14476	Economy	16800.00
0005433869102	14476	Economy	16800.00
0005435860582	14476	Economy	16800.00
0005433869098	14476	Economy	16800.00
0005433868941	14476	Economy	16800.00
0005433869316	32661	Economy	18500.00
0005433869300	32661	Economy	18500.00
0005433869310	32661	Economy	18500.00
0005433869284	32661	Economy	18500.00
0005433869322	32661	Economy	16800.00
0005433869304	32661	Economy	16800.00
0005433869307	32661	Economy	16800.00
0005433869285	32661	Economy	16800.00
0005433869287	32661	Economy	16800.00
0005433869311	32661	Economy	16800.00
0005435860519	32661	Economy	16800.00
0005433869319	32661	Economy	16800.00
0005433869296	32661	Economy	16800.00
0005433869294	32661	Economy	16800.00
0005433869282	32661	Economy	16800.00
0005433869291	32661	Economy	16800.00
0005433869286	32661	Economy	16800.00
0005433869293	32661	Economy	16800.00
0005433869318	32661	Economy	16800.00
0005433869317	32661	Economy	16800.00
0005433869298	32661	Economy	16800.00
0005433869297	32661	Economy	16800.00
0005433869292	32661	Economy	16800.00
0005433869309	32661	Economy	16800.00
0005433869303	32661	Economy	16800.00
0005433869283	32661	Economy	16800.00
0005433869320	32661	Economy	16800.00
0005433869305	32661	Economy	16800.00
0005433869302	32661	Economy	16800.00
0005433869289	32661	Economy	16800.00
0005433869308	32661	Economy	16800.00
0005433869314	32661	Economy	16800.00
0005433869288	32661	Economy	16800.00
0005433869301	32661	Economy	16800.00
0005433869290	32661	Economy	16800.00
0005433869306	32661	Economy	16800.00
0005433869295	32661	Economy	16800.00
0005433869321	32661	Economy	16800.00
0005433869299	32661	Economy	16800.00
0005433869312	32661	Economy	16800.00
0005433869315	32661	Economy	16800.00
0005433869323	32661	Economy	16800.00
0005433869313	32661	Economy	16800.00
0005432799884	12150	Economy	4900.00
0005432799840	12150	Economy	4900.00
0005432799826	12150	Economy	4400.00
0005432799844	12150	Economy	4400.00
0005432799940	12150	Economy	4400.00
0005432799825	12150	Economy	4400.00
0005432799806	12150	Economy	4400.00
0005432799822	12150	Economy	4400.00
0005432799841	12150	Economy	4400.00
0005432799835	12150	Economy	4400.00
0005432799843	12150	Economy	4400.00
0005432799857	12150	Economy	4400.00
0005432799749	12150	Economy	4400.00
0005432799809	12150	Economy	4400.00
0005432799913	12150	Economy	4400.00
0005432799674	12150	Economy	4400.00
0005432799912	12150	Economy	4400.00
0005432799894	12150	Economy	4400.00
0005432799863	12150	Economy	4400.00
0005432799807	12150	Economy	4400.00
0005432799914	12150	Economy	4400.00
0005432799904	12150	Economy	4400.00
0005432799869	12150	Economy	4400.00
0005432799750	12150	Economy	4400.00
0005432799855	12150	Economy	4400.00
0005432799856	12150	Economy	4400.00
0005432799836	12150	Economy	4400.00
0005432799896	12150	Economy	4400.00
0005432800058	14807	Economy	4900.00
0005432800062	14807	Economy	4900.00
0005432800059	14807	Economy	4400.00
0005432800056	14807	Economy	4400.00
0005432800053	14807	Economy	4400.00
0005432800070	14807	Economy	4400.00
0005432800080	14807	Economy	4400.00
0005432800073	14807	Economy	4400.00
0005432800067	14807	Economy	4400.00
0005432800068	14807	Economy	4400.00
0005432800064	14807	Economy	4400.00
0005432800061	14807	Economy	4400.00
0005432800060	14807	Economy	4400.00
0005432800078	14807	Economy	4400.00
0005432800063	14807	Economy	4400.00
0005432800055	14807	Economy	4400.00
0005432800065	14807	Economy	4400.00
0005432800071	14807	Economy	4400.00
0005432800075	14807	Economy	4400.00
0005432800079	14807	Economy	4400.00
0005432800054	14807	Economy	4400.00
0005432800072	14807	Economy	4400.00
0005432800057	14807	Economy	4400.00
0005432800052	14807	Economy	4400.00
0005432800077	14807	Economy	4400.00
0005432800076	14807	Economy	4400.00
0005432800074	14807	Economy	4400.00
0005432800069	14807	Economy	4400.00
0005432800066	14807	Economy	4400.00
0005434300077	7083	Business	49100.00
0005434409168	7083	Business	49100.00
0005435293423	7083	Business	49100.00
0005434409206	7083	Business	49100.00
0005434300086	7083	Business	49100.00
0005434300092	7083	Business	49100.00
0005435293398	7083	Business	49100.00
0005434409214	7083	Business	49100.00
0005434409184	7083	Business	49100.00
0005435293425	7083	Business	49100.00
0005434300075	7083	Business	49100.00
0005435293424	7083	Business	49100.00
0005434409194	7083	Economy	16400.00
0005434300081	7083	Economy	16400.00
0005434409212	7083	Economy	16400.00
0005434409217	7083	Economy	16400.00
0005434409209	7083	Economy	16400.00
0005435293447	7083	Economy	16400.00
0005434409204	7083	Economy	16400.00
0005434409198	7083	Economy	16400.00
0005434409159	7083	Economy	16400.00
0005432108310	7083	Economy	16400.00
0005432154099	7083	Economy	16400.00
0005434409182	7083	Economy	16400.00
0005434409177	7083	Economy	16400.00
0005434409161	7083	Economy	16400.00
0005435293429	7083	Economy	16400.00
0005434409164	7083	Economy	16400.00
0005434409205	7083	Economy	16400.00
0005434409163	7083	Economy	16400.00
0005435311208	7083	Economy	16400.00
0005435311180	7083	Economy	16400.00
0005434409165	7083	Economy	16400.00
0005435293404	7083	Economy	16400.00
0005434409219	7083	Economy	16400.00
0005434409210	7083	Economy	16400.00
0005434300085	7083	Economy	16400.00
0005434409215	7083	Economy	16400.00
0005435293399	7083	Economy	16400.00
0005432108308	7083	Economy	16400.00
0005434409188	7083	Economy	16400.00
0005435311209	7083	Economy	16400.00
0005432154097	7083	Economy	16400.00
0005434409192	7083	Economy	16400.00
0005434409195	7083	Economy	16400.00
0005434409220	7083	Economy	16400.00
0005434409166	7083	Economy	16400.00
0005434409175	7083	Economy	16400.00
0005434409180	7083	Economy	18000.00
0005434409171	7083	Economy	18000.00
0005435293405	7083	Economy	18000.00
0005434409208	7083	Economy	18000.00
0005434409218	7083	Economy	18000.00
0005434409172	7083	Economy	16400.00
0005434409191	7083	Economy	18000.00
0005434300089	7083	Economy	16400.00
0005434300076	7083	Economy	16400.00
0005432154095	7083	Economy	16400.00
0005434300079	7083	Economy	16400.00
0005435311203	7083	Economy	16400.00
0005434300088	7083	Economy	16400.00
0005434409211	7083	Economy	16400.00
0005434300098	7083	Economy	16400.00
0005434300097	7083	Economy	16400.00
0005435311153	7083	Economy	16400.00
0005435293456	7083	Economy	16400.00
0005434409187	7083	Economy	16400.00
0005434409216	7083	Economy	16400.00
0005435293417	7083	Economy	16400.00
0005434300093	7083	Economy	16400.00
0005434300094	7083	Economy	16400.00
0005432108309	7083	Economy	16400.00
0005434409186	7083	Economy	16400.00
0005434409213	7083	Economy	16400.00
0005434300087	7083	Economy	16400.00
0005434409200	7083	Economy	16400.00
0005434300095	7083	Economy	16400.00
0005434409170	7083	Economy	16400.00
0005434409176	7083	Economy	16400.00
0005434409196	7083	Economy	16400.00
0005434409173	7083	Economy	16400.00
0005434300082	7083	Economy	16400.00
0005434409167	7083	Economy	16400.00
0005435293413	7083	Economy	16400.00
0005434300080	7083	Economy	16400.00
0005434300090	7083	Economy	16400.00
0005434409169	7083	Economy	16400.00
0005434409193	7083	Economy	16400.00
0005434409160	7083	Economy	16400.00
0005434300078	7083	Economy	16400.00
0005435293436	7083	Economy	16400.00
0005435293416	7083	Economy	16400.00
0005434409174	7083	Economy	16400.00
0005434409197	7083	Economy	16400.00
0005435293412	7083	Economy	16400.00
0005432154096	7083	Economy	16400.00
0005434300083	7083	Economy	16400.00
0005434409190	7083	Economy	16400.00
0005432154094	7083	Economy	16400.00
0005434409178	7083	Economy	16400.00
0005434409202	7083	Economy	16400.00
0005435293428	7083	Economy	16400.00
0005434409207	7083	Economy	16400.00
0005434409179	7083	Economy	16400.00
0005434300084	7083	Economy	16400.00
0005434409181	7083	Economy	16400.00
0005434300091	7083	Economy	16400.00
0005434409183	7083	Economy	16400.00
0005434409189	7083	Economy	16400.00
0005434409158	7083	Economy	16400.00
0005435293449	7083	Economy	16400.00
0005434300096	7083	Economy	16400.00
0005435293455	7083	Economy	16400.00
0005432154098	7083	Economy	16400.00
0005435311218	7083	Economy	16400.00
0005435293402	7083	Economy	16400.00
0005435311219	7083	Economy	16400.00
0005435293415	7083	Economy	16400.00
0005434409203	7083	Economy	16400.00
0005435293414	7083	Economy	16400.00
0005434409201	7083	Economy	16400.00
0005434409199	7083	Economy	16400.00
0005434409162	7083	Economy	16400.00
0005434409185	7083	Economy	16400.00
0005435311359	26886	Business	49100.00
0005435311374	26886	Business	49100.00
0005435293534	26886	Business	49100.00
0005434299858	26886	Business	49100.00
0005435293537	26886	Business	49100.00
0005432058469	26886	Business	49100.00
0005434299874	26886	Business	49100.00
0005434300019	26886	Business	49100.00
0005435311356	26886	Business	49100.00
0005434299930	26886	Business	49100.00
0005434408690	26886	Business	49100.00
0005434408741	26886	Business	49100.00
0005435311373	26886	Economy	16400.00
0005435311380	26886	Economy	16400.00
0005434299933	26886	Economy	16400.00
0005434408742	26886	Economy	16400.00
0005434408450	26886	Economy	16400.00
0005434408726	26886	Economy	16400.00
0005434408324	26886	Economy	16400.00
0005435311367	26886	Economy	16400.00
0005434408705	26886	Economy	16400.00
0005434299882	26886	Economy	16400.00
0005435311370	26886	Economy	16400.00
0005435311376	26886	Economy	16400.00
0005434408584	26886	Economy	16400.00
0005434408676	26886	Economy	16400.00
0005434408629	26886	Economy	16400.00
0005434299937	26886	Economy	16400.00
0005434408636	26886	Economy	16400.00
0005434408673	26886	Economy	16400.00
0005435311364	26886	Economy	16400.00
0005434299943	26886	Economy	16400.00
0005434408408	26886	Economy	16400.00
0005434408471	26886	Economy	16400.00
0005435311382	26886	Economy	16400.00
0005434408493	26886	Economy	16400.00
0005432058468	26886	Economy	16400.00
0005435293541	26886	Economy	16400.00
0005435311378	26886	Economy	16400.00
0005434408557	26886	Economy	16400.00
0005434408558	26886	Economy	16400.00
0005432058467	26886	Economy	16400.00
0005434408586	26886	Economy	16400.00
0005434299924	26886	Economy	16400.00
0005432058466	26886	Economy	16400.00
0005435311362	26886	Economy	16400.00
0005434408733	26886	Economy	16400.00
0005434408452	26886	Economy	16400.00
0005435311383	26886	Economy	16400.00
0005435293535	26886	Economy	16400.00
0005434299873	26886	Economy	16400.00
0005434299936	26886	Economy	16400.00
0005434408605	26886	Economy	18000.00
0005434408560	26886	Economy	18000.00
0005434408700	26886	Economy	18000.00
0005434408628	26886	Economy	18000.00
0005434408481	26886	Economy	18000.00
0005434408957	26886	Economy	18000.00
0005435293540	26886	Economy	16400.00
0005434408561	26886	Economy	16400.00
0005435293530	26886	Economy	16400.00
0005434299887	26886	Economy	16400.00
0005434408411	26886	Economy	16400.00
0005434408562	26886	Economy	16400.00
0005434408480	26886	Economy	16400.00
0005434408563	26886	Economy	16400.00
0005435311377	26886	Economy	16400.00
0005434408435	26886	Economy	16400.00
0005434408449	26886	Economy	16400.00
0005435311360	26886	Economy	16400.00
0005434408624	26886	Economy	16400.00
0005434408829	26886	Economy	16400.00
0005435311361	26886	Economy	16400.00
0005434299876	26886	Economy	16400.00
0005434408635	26886	Economy	16400.00
0005435311368	26886	Economy	16400.00
0005434408958	26886	Economy	16400.00
0005435311384	26886	Economy	16400.00
0005434408634	26886	Economy	16400.00
0005434408409	26886	Economy	16400.00
0005434408704	26886	Economy	16400.00
0005435293542	26886	Economy	16400.00
0005435293529	26886	Economy	16400.00
0005434408266	26886	Economy	16400.00
0005434408621	26886	Economy	16400.00
0005434408265	26886	Economy	16400.00
0005434408591	26886	Economy	16400.00
0005435311355	26886	Economy	16400.00
0005434299985	26886	Economy	16400.00
0005435293532	26886	Economy	16400.00
0005434408399	26886	Economy	16400.00
0005434408727	26886	Economy	16400.00
0005434408595	26886	Economy	16400.00
0005434408412	26886	Economy	16400.00
0005435293538	26886	Economy	16400.00
0005434408487	26886	Economy	16400.00
0005435311372	26886	Economy	16400.00
0005435293539	26886	Economy	16400.00
0005434299885	26886	Economy	16400.00
0005435311375	26886	Economy	16400.00
0005435311371	26886	Economy	16400.00
0005434408592	26886	Economy	16400.00
0005435311363	26886	Economy	16400.00
0005434299886	26886	Economy	16400.00
0005435311358	26886	Economy	16400.00
0005434408527	26886	Economy	16400.00
0005435311357	26886	Economy	16400.00
0005435293536	26886	Economy	16400.00
0005435311365	26886	Economy	16400.00
0005434299901	26886	Economy	16400.00
0005435293531	26886	Economy	16400.00
0005435293533	26886	Economy	16400.00
0005434299872	26886	Economy	16400.00
0005434408521	26886	Economy	16400.00
0005434408698	26886	Economy	16400.00
0005434299900	26886	Economy	16400.00
0005435311366	26886	Economy	16400.00
0005435311385	26886	Economy	16400.00
0005434300020	26886	Economy	16400.00
0005435311379	26886	Economy	16400.00
0005434299952	26886	Economy	16400.00
0005434408689	26886	Economy	16400.00
0005435311381	26886	Economy	16400.00
0005434299984	26886	Economy	16400.00
0005435311369	26886	Economy	16400.00
0005434408407	26886	Economy	16400.00
0005434408359	26886	Economy	16400.00
0005434408451	26886	Economy	16400.00
0005435311386	26886	Economy	16400.00
0005434408585	26886	Economy	16400.00
0005432605259	6436	Economy	16500.00
0005434512224	6436	Economy	16500.00
0005432605255	6436	Economy	16500.00
0005432605247	6436	Economy	16500.00
0005432605226	6436	Economy	15000.00
0005432605228	6436	Economy	15000.00
0005434512222	6436	Economy	15000.00
0005432605238	6436	Economy	15000.00
0005432605233	6436	Economy	15000.00
0005432605234	6436	Economy	15000.00
0005432605241	6436	Economy	15000.00
0005432605248	6436	Economy	15000.00
0005432605256	6436	Economy	15000.00
0005432605260	6436	Economy	15000.00
0005432605230	6436	Economy	15000.00
0005432605258	6436	Economy	15000.00
0005432605264	6436	Economy	15000.00
0005432605242	6436	Economy	15000.00
0005432605254	6436	Economy	15000.00
0005432605253	6436	Economy	15000.00
0005435220491	6436	Economy	15000.00
0005432605251	6436	Economy	15000.00
0005432605236	6436	Economy	15000.00
0005432605240	6436	Economy	15000.00
0005432605244	6436	Economy	15000.00
0005432605250	6436	Economy	15000.00
0005432605237	6436	Economy	15000.00
0005432605231	6436	Economy	15000.00
0005432605229	6436	Economy	15000.00
0005432605249	6436	Economy	15000.00
0005432605246	6436	Economy	15000.00
0005432605232	6436	Economy	15000.00
0005432605245	6436	Economy	15000.00
0005432605235	6436	Economy	15000.00
0005432605263	6436	Economy	15000.00
0005432605239	6436	Economy	15000.00
0005432605225	6436	Economy	15000.00
0005432605224	6436	Economy	15000.00
0005432605257	6436	Economy	15000.00
0005432605227	6436	Economy	15000.00
0005434512223	6436	Economy	15000.00
0005432605262	6436	Economy	15000.00
0005432605243	6436	Economy	15000.00
0005432605261	6436	Economy	15000.00
0005432605252	6436	Economy	15000.00
0005432604911	21391	Economy	16500.00
0005432605055	21391	Economy	16500.00
0005432604733	21391	Economy	16500.00
0005432604793	21391	Economy	16500.00
0005434512168	21391	Economy	15000.00
0005432604946	21391	Economy	15000.00
0005434512169	21391	Economy	15000.00
0005432604742	21391	Economy	15000.00
0005432604787	21391	Economy	15000.00
0005432604820	21391	Economy	15000.00
0005432604890	21391	Economy	15000.00
0005432604833	21391	Economy	15000.00
0005432604722	21391	Economy	15000.00
0005432605006	21391	Economy	15000.00
0005432604947	21391	Economy	15000.00
0005432604914	21391	Economy	15000.00
0005432604912	21391	Economy	15000.00
0005432604910	21391	Economy	15000.00
0005434512187	21391	Economy	15000.00
0005432604855	21391	Economy	15000.00
0005434512173	21391	Economy	15000.00
0005432604744	21391	Economy	15000.00
0005432604792	21391	Economy	15000.00
0005432605005	21391	Economy	15000.00
0005432604743	21391	Economy	15000.00
0005432604844	21391	Economy	15000.00
0005432604739	21391	Economy	15000.00
0005434512181	21391	Economy	15000.00
0005434512166	21391	Economy	15000.00
0005432604803	21391	Economy	15000.00
0005432604913	21391	Economy	15000.00
0005432604972	21391	Economy	15000.00
0005434512190	21391	Economy	15000.00
0005432604915	21391	Economy	15000.00
0005432604740	21391	Economy	15000.00
0005432604789	21391	Economy	15000.00
0005432604796	21391	Economy	15000.00
0005434512186	21391	Economy	15000.00
0005432604875	21391	Economy	15000.00
0005432604790	21391	Economy	15000.00
0005432604791	21391	Economy	15000.00
0005432604891	21391	Economy	15000.00
0005432604741	21391	Economy	15000.00
0005432604745	21391	Economy	15000.00
0005434512172	21391	Economy	15000.00
0005434512189	21391	Economy	15000.00
0005432604795	21391	Economy	15000.00
0005432604721	21391	Economy	15000.00
0005432604871	21391	Economy	15000.00
0005433252167	14995	Business	18900.00
0005434907945	14995	Business	18900.00
0005433252162	14995	Business	18900.00
0005434907980	14995	Business	18900.00
0005434907902	14995	Business	18900.00
0005434907927	14995	Business	18900.00
0005433252186	14995	Business	18900.00
0005434907878	14995	Business	18900.00
0005434907999	14995	Business	18900.00
0005434907879	14995	Business	18900.00
0005434907952	14995	Economy	6300.00
0005434907881	14995	Economy	6300.00
0005434907777	14995	Economy	6300.00
0005433252184	14995	Economy	6300.00
0005434907975	14995	Economy	6300.00
0005434907974	14995	Economy	6300.00
0005434907865	14995	Economy	6300.00
0005433252183	14995	Economy	6300.00
0005434907971	14995	Economy	6900.00
0005434907782	14995	Economy	6900.00
0005433252177	14995	Economy	6900.00
0005434908051	14995	Economy	6900.00
0005434907851	14995	Economy	6300.00
0005434907827	14995	Economy	6300.00
0005434907874	14995	Economy	6300.00
0005434908040	14995	Economy	6300.00
0005433252187	14995	Economy	6300.00
0005434907880	14995	Economy	6300.00
0005434908013	14995	Economy	6300.00
0005434907901	14995	Economy	6300.00
0005433252180	14995	Economy	6300.00
0005433252169	14995	Economy	6300.00
0005433252172	14995	Economy	6300.00
0005434908020	14995	Economy	6300.00
0005434907743	14995	Economy	6300.00
0005434907853	14995	Economy	6300.00
0005433252168	14995	Economy	6300.00
0005433252182	14995	Economy	6300.00
0005434907875	14995	Economy	6300.00
0005434907998	14995	Economy	6300.00
0005433252166	14995	Economy	6300.00
0005433252173	14995	Economy	6300.00
0005433252171	14995	Economy	6300.00
0005434907928	14995	Economy	6300.00
0005433252164	14995	Economy	6300.00
0005434907815	14995	Economy	6300.00
0005433252175	14995	Economy	6300.00
0005434907771	14995	Economy	6300.00
0005434907877	14995	Economy	6300.00
0005434907916	14995	Economy	6300.00
0005433252179	14995	Economy	6300.00
0005433252178	14995	Economy	6300.00
0005434907956	14995	Economy	6300.00
0005434907913	14995	Economy	6300.00
0005433252165	14995	Economy	6300.00
0005434907858	14995	Economy	6300.00
0005433252189	14995	Economy	6300.00
0005434907895	14995	Economy	6300.00
0005433252181	14995	Economy	6300.00
0005433252161	14995	Economy	6300.00
0005434907814	14995	Economy	6300.00
0005433252191	14995	Economy	6300.00
0005434907744	14995	Economy	6300.00
0005434907976	14995	Economy	6300.00
0005434907852	14995	Economy	6300.00
0005434908019	14995	Economy	6300.00
0005433252163	14995	Economy	6300.00
0005433252190	14995	Economy	6300.00
0005434907876	14995	Economy	6300.00
0005434907917	14995	Economy	6300.00
0005433252170	14995	Economy	6300.00
0005434908018	14995	Economy	6300.00
0005434907859	14995	Economy	6300.00
0005434907820	14995	Economy	6300.00
0005433252185	14995	Economy	6300.00
0005433252174	14995	Economy	6300.00
0005433252160	14995	Economy	6300.00
0005434908042	14995	Economy	6300.00
0005433252188	14995	Economy	6300.00
0005433252176	14995	Economy	6300.00
0005434907894	14995	Economy	6300.00
0005434908000	14995	Economy	6300.00
0005434907915	14995	Economy	6300.00
0005433251848	25866	Business	18900.00
0005434908445	25866	Business	18900.00
0005434908397	25866	Business	18900.00
0005433252014	25866	Business	18900.00
0005434908400	25866	Business	18900.00
0005434908428	25866	Business	18900.00
0005433251830	25866	Business	18900.00
0005433251973	25866	Business	18900.00
0005434908403	25866	Business	18900.00
0005434908430	25866	Business	18900.00
0005434908441	25866	Business	18900.00
0005434908431	25866	Economy	6300.00
0005433251921	25866	Economy	6300.00
0005433251956	25866	Economy	6300.00
0005434908408	25866	Economy	6300.00
0005433251838	25866	Economy	6300.00
0005434908449	25866	Economy	6300.00
0005433251902	25866	Economy	6300.00
0005433251825	25866	Economy	6300.00
0005434908415	25866	Economy	6300.00
0005434908447	25866	Economy	6300.00
0005434908421	25866	Economy	6900.00
0005433251915	25866	Economy	6900.00
0005434908450	25866	Economy	6900.00
0005433251882	25866	Economy	6900.00
0005434908425	25866	Economy	6300.00
0005434908412	25866	Economy	6300.00
0005433251824	25866	Economy	6300.00
0005433251795	25866	Economy	6300.00
0005434908427	25866	Economy	6300.00
0005434908418	25866	Economy	6300.00
0005434908440	25866	Economy	6300.00
0005433251849	25866	Economy	6300.00
0005434908413	25866	Economy	6300.00
0005434908398	25866	Economy	6300.00
0005434908438	25866	Economy	6300.00
0005433251925	25866	Economy	6300.00
0005434908410	25866	Economy	6300.00
0005434908426	25866	Economy	6300.00
0005434908414	25866	Economy	6300.00
0005433252013	25866	Economy	6300.00
0005434908439	25866	Economy	6300.00
0005433251972	25866	Economy	6300.00
0005434908444	25866	Economy	6300.00
0005434908435	25866	Economy	6300.00
0005434908433	25866	Economy	6300.00
0005434908406	25866	Economy	6300.00
0005434908434	25866	Economy	6300.00
0005433251793	25866	Economy	6300.00
0005434908411	25866	Economy	6300.00
0005434908443	25866	Economy	6300.00
0005433251986	25866	Economy	6300.00
0005434908399	25866	Economy	6300.00
0005433251966	25866	Economy	6300.00
0005434908446	25866	Economy	6300.00
0005433251967	25866	Economy	6300.00
0005434908404	25866	Economy	6300.00
0005433252012	25866	Economy	6300.00
0005434908448	25866	Economy	6300.00
0005434908420	25866	Economy	6300.00
0005433251988	25866	Economy	6300.00
0005434908442	25866	Economy	6300.00
0005433251916	25866	Economy	6300.00
0005433251976	25866	Economy	6300.00
0005434908401	25866	Economy	6300.00
0005434908437	25866	Economy	6300.00
0005433251947	25866	Economy	6300.00
0005433251999	25866	Economy	6300.00
0005433251950	25866	Economy	6300.00
0005433251775	25866	Economy	6300.00
0005433251899	25866	Economy	6300.00
0005434908432	25866	Economy	6300.00
0005434908407	25866	Economy	6300.00
0005434908423	25866	Economy	6300.00
0005433251776	25866	Economy	6300.00
0005434908416	25866	Economy	6300.00
0005433251917	25866	Economy	6300.00
0005434908405	25866	Economy	6300.00
0005434908424	25866	Economy	6300.00
0005434908429	25866	Economy	6300.00
0005434908409	25866	Economy	6300.00
0005434908436	25866	Economy	6300.00
0005433252023	25866	Economy	6300.00
0005433251794	25866	Economy	6300.00
0005434908419	25866	Economy	6300.00
0005434908402	25866	Economy	6300.00
0005434908422	25866	Economy	6300.00
0005434908417	25866	Economy	6300.00
0005433252005	25866	Economy	6300.00
0005434908396	25866	Economy	6300.00
0005433252025	25866	Economy	6300.00
0005433009665	14157	Business	52300.00
0005433009674	14157	Business	52300.00
0005433009640	14157	Business	52300.00
0005433009654	14157	Business	52300.00
0005433009664	14157	Business	52300.00
0005433009638	14157	Business	52300.00
0005433009677	14157	Economy	17400.00
0005433009671	14157	Economy	17400.00
0005433009673	14157	Economy	17400.00
0005433009632	14157	Economy	17400.00
0005433009662	14157	Economy	17400.00
0005433009672	14157	Economy	17400.00
0005433009661	14157	Economy	19200.00
0005433009668	14157	Economy	19200.00
0005433009657	14157	Economy	17400.00
0005433009659	14157	Economy	17400.00
0005433009639	14157	Economy	17400.00
0005433009669	14157	Economy	17400.00
0005433009645	14157	Economy	17400.00
0005433009653	14157	Economy	17400.00
0005433009646	14157	Economy	17400.00
0005433009637	14157	Economy	17400.00
0005433009649	14157	Economy	17400.00
0005433009660	14157	Economy	17400.00
0005433009667	14157	Economy	17400.00
0005433009636	14157	Economy	17400.00
0005433009663	14157	Economy	17400.00
0005433009643	14157	Economy	17400.00
0005433009670	14157	Economy	17400.00
0005433009633	14157	Economy	17400.00
0005433009651	14157	Economy	17400.00
0005433009675	14157	Economy	17400.00
0005433009666	14157	Economy	17400.00
0005433009641	14157	Economy	17400.00
0005433009642	14157	Economy	17400.00
0005433009650	14157	Economy	17400.00
0005433009631	14157	Economy	17400.00
0005433810586	14157	Economy	17400.00
0005433810585	14157	Economy	17400.00
0005433009676	14157	Economy	17400.00
0005433009648	14157	Economy	17400.00
0005433009658	14157	Economy	17400.00
0005433810584	14157	Economy	17400.00
0005433009656	14157	Economy	17400.00
0005433009655	14157	Economy	17400.00
0005433009652	14157	Economy	17400.00
0005433009644	14157	Economy	17400.00
0005433810597	14157	Economy	17400.00
0005433009635	14157	Economy	17400.00
0005433009647	14157	Economy	17400.00
0005433009634	14157	Economy	17400.00
0005433009167	22831	Business	52300.00
0005433008848	22831	Business	52300.00
0005433810662	22831	Business	52300.00
0005433009129	22831	Business	52300.00
0005433009285	22831	Business	52300.00
0005433009157	22831	Business	52300.00
0005433009093	22831	Business	52300.00
0005433009060	22831	Business	52300.00
0005433009191	22831	Economy	17400.00
0005433009165	22831	Economy	17400.00
0005433810659	22831	Economy	17400.00
0005433009257	22831	Economy	17400.00
0005433009212	22831	Economy	17400.00
0005433810669	22831	Economy	17400.00
0005433009326	22831	Economy	17400.00
0005433810660	22831	Economy	17400.00
0005433009168	22831	Economy	19200.00
0005433009092	22831	Economy	19200.00
0005433009171	22831	Economy	19200.00
0005433009173	22831	Economy	17400.00
0005433009256	22831	Economy	17400.00
0005433009076	22831	Economy	17400.00
0005433009166	22831	Economy	17400.00
0005433009246	22831	Economy	17400.00
0005433009266	22831	Economy	17400.00
0005433009245	22831	Economy	17400.00
0005433810658	22831	Economy	17400.00
0005433009325	22831	Economy	17400.00
0005433009124	22831	Economy	17400.00
0005433810657	22831	Economy	17400.00
0005433810665	22831	Economy	17400.00
0005433009250	22831	Economy	17400.00
0005433009270	22831	Economy	17400.00
0005433009229	22831	Economy	17400.00
0005433009128	22831	Economy	17400.00
0005433009399	22831	Economy	17400.00
0005433009174	22831	Economy	17400.00
0005433008847	22831	Economy	17400.00
0005433009308	22831	Economy	17400.00
0005433009145	22831	Economy	17400.00
0005433810668	22831	Economy	17400.00
0005433009305	22831	Economy	17400.00
0005433009309	22831	Economy	17400.00
0005433009227	22831	Economy	17400.00
0005433810664	22831	Economy	17400.00
0005433009031	22831	Economy	17400.00
0005433009029	22831	Economy	17400.00
0005433008849	22831	Economy	17400.00
0005433810661	22831	Economy	17400.00
0005433009251	22831	Economy	17400.00
0005433009204	22831	Economy	17400.00
0005433009075	22831	Economy	17400.00
0005433009228	22831	Economy	17400.00
0005433009030	22831	Economy	17400.00
0005433009284	22831	Economy	17400.00
0005433009304	22831	Economy	17400.00
0005433810656	22831	Economy	17400.00
0005433009259	22831	Economy	17400.00
0005433009192	22831	Economy	17400.00
0005433810663	22831	Economy	17400.00
0005433810666	22831	Economy	17400.00
0005433810667	22831	Economy	17400.00
0005433009146	22831	Economy	17400.00
0005433009318	22831	Economy	17400.00
0005433009247	22831	Economy	17400.00
0005434926193	14931	Business	22900.00
0005434926269	14931	Business	22900.00
0005434926329	14931	Business	22900.00
0005434926249	14931	Economy	7600.00
0005434926214	14931	Economy	7600.00
0005434926000	14931	Economy	7600.00
0005434926103	14931	Economy	8400.00
0005434926272	14931	Economy	7600.00
0005434926104	14931	Economy	7600.00
0005434926215	14931	Economy	7600.00
0005434926171	14931	Economy	7600.00
0005434926206	14931	Economy	7600.00
0005434926203	14931	Economy	7600.00
0005434926230	14931	Economy	7600.00
0005434926108	14931	Economy	7600.00
0005434926229	14931	Economy	7600.00
0005434926152	14931	Economy	7600.00
0005434926292	14931	Economy	7600.00
0005434926248	14931	Economy	7600.00
0005434926172	14931	Economy	7600.00
0005434926173	14931	Economy	7600.00
0005434926268	14931	Economy	7600.00
0005434926327	14931	Economy	7600.00
0005434926216	14931	Economy	7600.00
0005434926293	14931	Economy	7600.00
0005434926284	14931	Economy	7600.00
0005434926283	14931	Economy	7600.00
0005434926366	14931	Economy	7600.00
0005434926507	20507	Business	22900.00
0005434926483	20507	Business	22900.00
0005434926494	20507	Business	22900.00
0005434926475	20507	Business	22900.00
0005434926496	20507	Economy	7600.00
0005434926504	20507	Economy	7600.00
0005434926477	20507	Economy	7600.00
0005434926478	20507	Economy	7600.00
0005434926501	20507	Economy	7600.00
0005434926506	20507	Economy	7600.00
0005434926503	20507	Economy	7600.00
0005434926492	20507	Economy	7600.00
0005434926499	20507	Economy	7600.00
0005434926484	20507	Economy	7600.00
0005434926485	20507	Economy	7600.00
0005434926476	20507	Economy	7600.00
0005434926495	20507	Economy	7600.00
0005434926488	20507	Economy	7600.00
0005434926490	20507	Economy	7600.00
0005434926482	20507	Economy	7600.00
0005434926480	20507	Economy	7600.00
0005434926487	20507	Economy	7600.00
0005434926498	20507	Economy	7600.00
0005434926508	20507	Economy	7600.00
0005434926493	20507	Economy	7600.00
0005434926505	20507	Economy	7600.00
0005434926491	20507	Economy	7600.00
0005434926486	20507	Economy	7600.00
0005434926481	20507	Economy	7600.00
0005434926509	20507	Economy	7600.00
0005434926489	20507	Economy	7600.00
0005434926497	20507	Economy	7600.00
0005434926500	20507	Economy	7600.00
0005434926479	20507	Economy	7600.00
0005434926502	20507	Economy	7600.00
0005435999493	15790	Economy	8900.00
0005435488331	15790	Economy	8100.00
0005435488330	15790	Economy	8100.00
0005435999424	15790	Economy	8100.00
0005435488334	15790	Economy	8100.00
0005435999445	15790	Economy	8100.00
0005435488328	15790	Economy	8100.00
0005435488327	15790	Economy	8100.00
0005435999395	15790	Economy	8100.00
0005435488332	15790	Economy	8100.00
0005435999407	15790	Economy	8100.00
0005435999484	15790	Economy	8100.00
0005435488323	15790	Economy	8100.00
0005435488338	15790	Economy	8100.00
0005435488329	15790	Economy	8100.00
0005435488337	15790	Economy	8100.00
0005435999466	15790	Economy	8100.00
0005435488335	15790	Economy	8100.00
0005435488325	15790	Economy	8100.00
0005435488321	15790	Economy	8100.00
0005435488319	15790	Economy	8100.00
0005435999463	15790	Economy	8100.00
0005435999491	15790	Economy	8100.00
0005435488336	15790	Economy	8100.00
0005435488333	15790	Economy	8100.00
0005435488339	15790	Economy	8100.00
0005435488320	15790	Economy	8100.00
0005435488326	15790	Economy	8100.00
0005435488324	15790	Economy	8100.00
0005435999476	15790	Economy	8100.00
0005435999490	15790	Economy	8100.00
0005435488322	15790	Economy	8100.00
0005435999492	15790	Economy	8100.00
0005435999629	19703	Economy	8900.00
0005435488101	19703	Economy	8900.00
0005435488100	19703	Economy	8900.00
0005435488090	19703	Economy	8900.00
0005435488121	19703	Economy	8100.00
0005435999637	19703	Economy	8100.00
0005435488175	19703	Economy	8100.00
0005435999634	19703	Economy	8100.00
0005435999626	19703	Economy	8100.00
0005435999639	19703	Economy	8100.00
0005435999628	19703	Economy	8100.00
0005435488139	19703	Economy	8100.00
0005435999624	19703	Economy	8100.00
0005435999640	19703	Economy	8100.00
0005435999641	19703	Economy	8100.00
0005435488196	19703	Economy	8100.00
0005435488062	19703	Economy	8100.00
0005435999630	19703	Economy	8100.00
0005435488076	19703	Economy	8100.00
0005435488083	19703	Economy	8100.00
0005435488091	19703	Economy	8100.00
0005435999642	19703	Economy	8100.00
0005435488098	19703	Economy	8100.00
0005435488109	19703	Economy	8100.00
0005435999632	19703	Economy	8100.00
0005435999627	19703	Economy	8100.00
0005435999636	19703	Economy	8100.00
0005435488061	19703	Economy	8100.00
0005435999643	19703	Economy	8100.00
0005435488074	19703	Economy	8100.00
0005435488112	19703	Economy	8100.00
0005435999633	19703	Economy	8100.00
0005435488056	19703	Economy	8100.00
0005435999638	19703	Economy	8100.00
0005435488153	19703	Economy	8100.00
0005435488071	19703	Economy	8100.00
0005435999635	19703	Economy	8100.00
0005435999645	19703	Economy	8100.00
0005435999644	19703	Economy	8100.00
0005435488120	19703	Economy	8100.00
0005435488176	19703	Economy	8100.00
0005435488195	19703	Economy	8100.00
0005435999631	19703	Economy	8100.00
0005435999625	19703	Economy	8100.00
0005435488192	19703	Economy	8100.00
0005435488097	19703	Economy	8100.00
0005435473065	6034	Business	199300.00
0005435473068	6034	Business	199300.00
0005435473046	6034	Business	199300.00
0005435840081	6034	Business	199300.00
0005435840103	6034	Business	199300.00
0005435473023	6034	Business	199300.00
0005435473022	6034	Business	199300.00
0005435840085	6034	Business	199300.00
0005435840094	6034	Business	199300.00
0005435473092	6034	Business	199300.00
0005435840088	6034	Economy	66400.00
0005435840097	6034	Economy	66400.00
0005435840105	6034	Economy	66400.00
0005435472976	6034	Economy	66400.00
0005432659755	6034	Economy	66400.00
0005435840087	6034	Economy	66400.00
0005435840091	6034	Economy	73100.00
0005432659756	6034	Economy	73100.00
0005435473013	6034	Economy	73100.00
0005435840082	6034	Economy	66400.00
0005435472966	6034	Economy	66400.00
0005435473091	6034	Economy	66400.00
0005435840108	6034	Economy	66400.00
0005435472972	6034	Economy	66400.00
0005435473064	6034	Economy	66400.00
0005435840100	6034	Economy	66400.00
0005432660866	6034	Economy	66400.00
0005435840090	6034	Economy	66400.00
0005435840092	6034	Economy	66400.00
0005435840089	6034	Economy	66400.00
0005435840093	6034	Economy	66400.00
0005435473024	6034	Economy	66400.00
0005435840098	6034	Economy	66400.00
0005435840086	6034	Economy	66400.00
0005432142322	6034	Economy	66400.00
0005432537085	6034	Economy	66400.00
0005432660867	6034	Economy	66400.00
0005432142323	6034	Economy	66400.00
0005435840084	6034	Economy	66400.00
0005435840096	6034	Economy	66400.00
0005435840106	6034	Economy	66400.00
0005435473089	6034	Economy	66400.00
0005435473040	6034	Economy	66400.00
0005435473021	6034	Economy	66400.00
0005435840102	6034	Economy	66400.00
0005435840083	6034	Economy	66400.00
0005435840080	6034	Economy	66400.00
0005435473038	6034	Economy	66400.00
0005435840101	6034	Economy	66400.00
0005435840095	6034	Economy	66400.00
0005435473079	6034	Economy	66400.00
0005435473041	6034	Economy	66400.00
0005432142324	6034	Economy	66400.00
0005432658641	6034	Economy	66400.00
0005435473037	6034	Economy	66400.00
0005432537086	6034	Economy	66400.00
0005435840099	6034	Economy	66400.00
0005435473025	6034	Economy	66400.00
0005432658640	6034	Economy	66400.00
0005435473090	6034	Economy	66400.00
0005435473069	6034	Economy	66400.00
0005435472988	6034	Economy	66400.00
0005435840107	6034	Economy	66400.00
0005432659754	6034	Economy	66400.00
0005435840104	6034	Economy	66400.00
0005432660840	18049	Business	199300.00
0005435839823	18049	Business	199300.00
0005435839945	18049	Business	199300.00
0005435839927	18049	Business	199300.00
0005435473175	18049	Business	199300.00
0005432660839	18049	Business	199300.00
0005435473182	18049	Business	199300.00
0005435473171	18049	Business	199300.00
0005435473181	18049	Business	199300.00
0005432667471	18049	Business	199300.00
0005432660841	18049	Business	199300.00
0005435839877	18049	Business	199300.00
0005435839928	18049	Economy	66400.00
0005435839802	18049	Economy	66400.00
0005432667472	18049	Economy	66400.00
0005435839842	18049	Economy	66400.00
0005435473185	18049	Economy	66400.00
0005435473174	18049	Economy	66400.00
0005435839960	18049	Economy	66400.00
0005435839805	18049	Economy	73100.00
0005432667480	18049	Economy	73100.00
0005435473177	18049	Economy	66400.00
0005435473170	18049	Economy	66400.00
0005435839754	18049	Economy	66400.00
0005435839813	18049	Economy	66400.00
0005435839907	18049	Economy	66400.00
0005435839856	18049	Economy	66400.00
0005435839855	18049	Economy	66400.00
0005435839881	18049	Economy	66400.00
0005435839821	18049	Economy	66400.00
0005435839944	18049	Economy	66400.00
0005435839964	18049	Economy	66400.00
0005435839892	18049	Economy	66400.00
0005435839893	18049	Economy	66400.00
0005435839707	18049	Economy	66400.00
0005435839871	18049	Economy	66400.00
0005435473178	18049	Economy	66400.00
0005435473186	18049	Economy	66400.00
0005435473183	18049	Economy	66400.00
0005432537108	18049	Economy	66400.00
0005435839808	18049	Economy	66400.00
0005435839753	18049	Economy	66400.00
0005435473173	18049	Economy	66400.00
0005435839880	18049	Economy	66400.00
0005435839901	18049	Economy	66400.00
0005435839906	18049	Economy	66400.00
0005435839902	18049	Economy	66400.00
0005435839896	18049	Economy	66400.00
0005435473180	18049	Economy	66400.00
0005435473184	18049	Economy	66400.00
0005435473172	18049	Economy	66400.00
0005435839832	18049	Economy	66400.00
0005435839943	18049	Economy	66400.00
0005435839864	18049	Economy	66400.00
0005435839872	18049	Economy	66400.00
0005435839905	18049	Economy	66400.00
0005435839822	18049	Economy	66400.00
0005435839809	18049	Economy	66400.00
0005435839942	18049	Economy	66400.00
0005435839900	18049	Economy	66400.00
0005435473176	18049	Economy	66400.00
0005435473179	18049	Economy	66400.00
0005435839941	18049	Economy	66400.00
0005433285809	23030	Business	15700.00
0005433285744	23030	Business	15700.00
0005433285751	23030	Business	15700.00
0005433285672	23030	Business	15700.00
0005433285750	23030	Business	15700.00
0005433285758	23030	Business	15700.00
0005435104137	23030	Business	15700.00
0005435104127	23030	Economy	5200.00
0005433285774	23030	Economy	5200.00
0005433285755	23030	Economy	5200.00
0005435104126	23030	Economy	5200.00
0005435104129	23030	Economy	5200.00
0005435104131	23030	Economy	5200.00
0005433285656	23030	Economy	5200.00
0005435104132	23030	Economy	5200.00
0005433285851	23030	Economy	5200.00
0005433285826	23030	Economy	5200.00
0005433285682	23030	Economy	5200.00
0005433285754	23030	Economy	5200.00
0005433285620	23030	Economy	5200.00
0005433285794	23030	Economy	5200.00
0005433285688	23030	Economy	5700.00
0005435104125	23030	Economy	5700.00
0005433285683	23030	Economy	5700.00
0005433285730	23030	Economy	5200.00
0005435104135	23030	Economy	5200.00
0005435104136	23030	Economy	5200.00
0005435104134	23030	Economy	5200.00
0005433285649	23030	Economy	5200.00
0005433285728	23030	Economy	5200.00
0005435104128	23030	Economy	5200.00
0005433285781	23030	Economy	5200.00
0005433285621	23030	Economy	5200.00
0005433285761	23030	Economy	5200.00
0005433285652	23030	Economy	5200.00
0005433285742	23030	Economy	5200.00
0005433285631	23030	Economy	5200.00
0005435104133	23030	Economy	5200.00
0005433285771	23030	Economy	5200.00
0005433285710	23030	Economy	5200.00
0005433285741	23030	Economy	5200.00
0005433285648	23030	Economy	5200.00
0005433285759	23030	Economy	5200.00
0005435104130	23030	Economy	5200.00
0005433285689	23030	Economy	5200.00
0005433285793	23030	Economy	5200.00
0005433285864	23030	Economy	5200.00
0005433285762	23030	Economy	5200.00
0005433285757	23030	Economy	5200.00
0005433286006	32082	Business	15700.00
0005433286024	32082	Business	15700.00
0005433285995	32082	Business	15700.00
0005433286000	32082	Business	15700.00
0005435104016	32082	Business	15700.00
0005433286026	32082	Business	15700.00
0005433286016	32082	Economy	5200.00
0005433286021	32082	Economy	5200.00
0005433286001	32082	Economy	5200.00
0005433286009	32082	Economy	5200.00
0005433286020	32082	Economy	5200.00
0005433286022	32082	Economy	5200.00
0005433286007	32082	Economy	5200.00
0005433286013	32082	Economy	5200.00
0005433286018	32082	Economy	5200.00
0005433286008	32082	Economy	5200.00
0005433286015	32082	Economy	5200.00
0005433286017	32082	Economy	5700.00
0005433286005	32082	Economy	5200.00
0005435104027	32082	Economy	5200.00
0005433285996	32082	Economy	5200.00
0005433286014	32082	Economy	5200.00
0005433285999	32082	Economy	5200.00
0005433286023	32082	Economy	5200.00
0005433286011	32082	Economy	5200.00
0005435104010	32082	Economy	5200.00
0005433286004	32082	Economy	5200.00
0005433286003	32082	Economy	5200.00
0005435103988	32082	Economy	5200.00
0005435104015	32082	Economy	5200.00
0005435104030	32082	Economy	5200.00
0005433286012	32082	Economy	5200.00
0005433286002	32082	Economy	5200.00
0005435104026	32082	Economy	5200.00
0005433285998	32082	Economy	5200.00
0005433286019	32082	Economy	5200.00
0005435103987	32082	Economy	5200.00
0005433285994	32082	Economy	5200.00
0005433286025	32082	Economy	5200.00
0005433286010	32082	Economy	5200.00
0005433285997	32082	Economy	5200.00
0005435215165	30577	Business	42100.00
0005434068738	30577	Business	42100.00
0005435215115	30577	Business	42100.00
0005435283456	30577	Business	42100.00
0005435215164	30577	Business	42100.00
0005434068520	30577	Business	42100.00
0005435283446	30577	Business	42100.00
0005432428986	30577	Business	42100.00
0005435215111	30577	Business	42100.00
0005432529135	30577	Business	42100.00
0005435215168	30577	Business	42100.00
0005434068713	30577	Business	42100.00
0005432530519	30577	Business	42100.00
0005435215121	30577	Business	42100.00
0005434068818	30577	Business	42100.00
0005432530368	30577	Business	42100.00
0005435215161	30577	Business	42100.00
0005435283453	30577	Business	42100.00
0005435215166	30577	Business	42100.00
0005432535904	30577	Business	42100.00
0005432211675	30577	Business	42100.00
0005434068819	30577	Business	42100.00
0005432529533	30577	Business	42100.00
0005432529750	30577	Business	42100.00
0005432530144	30577	Comfort	23900.00
0005435725716	30577	Comfort	23900.00
0005434068573	30577	Comfort	23900.00
0005432428985	30577	Comfort	23900.00
0005435215101	30577	Comfort	23900.00
0005432529959	30577	Comfort	23900.00
0005432530342	30577	Comfort	23900.00
0005432530076	30577	Comfort	23900.00
0005432529927	30577	Comfort	23900.00
0005432535900	30577	Comfort	23900.00
0005435631041	30577	Comfort	23900.00
0005432529960	30577	Comfort	23900.00
0005432529855	30577	Comfort	23900.00
0005434068251	30577	Comfort	23900.00
0005435215119	30577	Comfort	23900.00
0005432529931	30577	Comfort	23900.00
0005434068406	30577	Comfort	23900.00
0005432529924	30577	Comfort	23900.00
0005432428977	30577	Comfort	23900.00
0005432529844	30577	Comfort	23900.00
0005432530235	30577	Comfort	23900.00
0005432529701	30577	Comfort	23900.00
0005435215145	30577	Comfort	23900.00
0005432529887	30577	Comfort	23900.00
0005432530017	30577	Comfort	23900.00
0005435215151	30577	Comfort	23900.00
0005433656749	30577	Comfort	23900.00
0005435215158	30577	Comfort	23900.00
0005432530092	30577	Comfort	23900.00
0005432529468	30577	Comfort	23900.00
0005435631039	30577	Comfort	23900.00
0005432530325	30577	Comfort	23900.00
0005432530262	30577	Economy	14000.00
0005432529886	30577	Comfort	23900.00
0005432537097	30577	Economy	14000.00
0005435215141	30577	Economy	14000.00
0005435215155	30577	Economy	14000.00
0005435215140	30577	Economy	14000.00
0005432529843	30577	Economy	14000.00
0005435215118	30577	Economy	14000.00
0005434068572	30577	Economy	14000.00
0005432530051	30577	Economy	14000.00
0005432529799	30577	Economy	14000.00
0005432529957	30577	Economy	14000.00
0005432529813	30577	Economy	14000.00
0005432529923	30577	Economy	14000.00
0005434068677	30577	Economy	14000.00
0005435215146	30577	Economy	14000.00
0005432159963	30577	Economy	14000.00
0005435215125	30577	Economy	14000.00
0005432529610	30577	Economy	14000.00
0005434068405	30577	Economy	14000.00
0005434068736	30577	Economy	14000.00
0005432530365	30577	Economy	14000.00
0005432530157	30577	Economy	14000.00
0005432529980	30577	Economy	14000.00
0005432530367	30577	Economy	14000.00
0005432530305	30577	Economy	14000.00
0005432535897	30577	Economy	14000.00
0005435215142	30577	Economy	14000.00
0005432528860	30577	Economy	14000.00
0005434068386	30577	Economy	14000.00
0005432529623	30577	Economy	14000.00
0005432530401	30577	Economy	14000.00
0005432530344	30577	Economy	14000.00
0005432530369	30577	Economy	14000.00
0005435725714	30577	Economy	14000.00
0005435215136	30577	Economy	14000.00
0005434068191	30577	Economy	14000.00
0005435283447	30577	Economy	14000.00
0005434068466	30577	Economy	14000.00
0005432529840	30577	Economy	14000.00
0005432530315	30577	Economy	14000.00
0005434068484	30577	Economy	14000.00
0005432530372	30577	Economy	14000.00
0005434068574	30577	Economy	14000.00
0005435215131	30577	Economy	14000.00
0005432529812	30577	Economy	14000.00
0005435283448	30577	Economy	14000.00
0005434068244	30577	Economy	14000.00
0005434068698	30577	Economy	14000.00
0005435215159	30577	Economy	14000.00
0005432529543	30577	Economy	14000.00
0005432529988	30577	Economy	14000.00
0005432529965	30577	Economy	14000.00
0005432530119	30577	Economy	14000.00
0005432529753	30577	Economy	14000.00
0005432529856	30577	Economy	14000.00
0005432211674	30577	Economy	14000.00
0005432533332	30577	Economy	14000.00
0005432529587	30577	Economy	14000.00
0005435215163	30577	Economy	14000.00
0005434068716	30577	Economy	15400.00
0005432529884	30577	Economy	14000.00
0005435283455	30577	Economy	15400.00
0005434068301	30577	Economy	14000.00
0005432529581	30577	Economy	15400.00
0005435215114	30577	Economy	14000.00
0005435283451	30577	Economy	14000.00
0005435215128	30577	Economy	14000.00
0005435215113	30577	Economy	15400.00
0005434068589	30577	Economy	15400.00
0005432530147	30577	Economy	14000.00
0005432528859	30577	Economy	15400.00
0005432211679	30577	Economy	14000.00
0005434068503	30577	Economy	14000.00
0005434068609	30577	Economy	14000.00
0005432530343	30577	Economy	14000.00
0005432535909	30577	Economy	14000.00
0005435215153	30577	Economy	14000.00
0005435725717	30577	Economy	14000.00
0005435215152	30577	Economy	14000.00
0005432529826	30577	Economy	14000.00
0005434068219	30577	Economy	14000.00
0005434068674	30577	Economy	14000.00
0005434068364	30577	Economy	14000.00
0005432530460	30577	Economy	14000.00
0005434068565	30577	Economy	14000.00
0005432529963	30577	Economy	14000.00
0005432529800	30577	Economy	14000.00
0005432529824	30577	Economy	14000.00
0005435215144	30577	Economy	14000.00
0005432529646	30577	Economy	14000.00
0005435283444	30577	Economy	14000.00
0005432211677	30577	Economy	14000.00
0005434068250	30577	Economy	14000.00
0005432529685	30577	Economy	14000.00
0005432535914	30577	Economy	14000.00
0005434068646	30577	Economy	14000.00
0005432529733	30577	Economy	14000.00
0005435215130	30577	Economy	14000.00
0005435283441	30577	Economy	14000.00
0005432530101	30577	Economy	14000.00
0005432529433	30577	Economy	14000.00
0005432530326	30577	Economy	14000.00
0005435215154	30577	Economy	14000.00
0005435631038	30577	Economy	14000.00
0005435215149	30577	Economy	14000.00
0005432529633	30577	Economy	14000.00
0005434068337	30577	Economy	14000.00
0005434068662	30577	Economy	14000.00
0005434068616	30577	Economy	14000.00
0005434068553	30577	Economy	14000.00
0005432211680	30577	Economy	14000.00
0005434068192	30577	Economy	14000.00
0005435283442	30577	Economy	14000.00
0005432528858	30577	Economy	14000.00
0005432530204	30577	Economy	14000.00
0005435215135	30577	Economy	14000.00
0005435215143	30577	Economy	14000.00
0005432529950	30577	Economy	14000.00
0005435283454	30577	Economy	14000.00
0005435215107	30577	Economy	14000.00
0005435215105	30577	Economy	14000.00
0005432530520	30577	Economy	14000.00
0005435215116	30577	Economy	14000.00
0005434068564	30577	Economy	14000.00
0005432529880	30577	Economy	14000.00
0005434068220	30577	Economy	14000.00
0005435283445	30577	Economy	14000.00
0005432537091	30577	Economy	14000.00
0005435215150	30577	Economy	14000.00
0005435215124	30577	Economy	14000.00
0005432530033	30577	Economy	14000.00
0005434068704	30577	Economy	14000.00
0005432530042	30577	Economy	14000.00
0005432211678	30577	Economy	14000.00
0005434068599	30577	Economy	14000.00
0005432529964	30577	Economy	14000.00
0005432530411	30577	Economy	14000.00
0005435215126	30577	Economy	14000.00
0005434068699	30577	Economy	14000.00
0005432530102	30577	Economy	14000.00
0005432530054	30577	Economy	14000.00
0005432529324	30577	Economy	14000.00
0005435215103	30577	Economy	14000.00
0005432428976	30577	Economy	14000.00
0005435215156	30577	Economy	14000.00
0005432530088	30577	Economy	14000.00
0005432530679	30577	Economy	14000.00
0005434068533	30577	Economy	14000.00
0005432529901	30577	Economy	14000.00
0005434068563	30577	Economy	14000.00
0005432529518	30577	Economy	14000.00
0005435631040	30577	Economy	14000.00
0005432529945	30577	Economy	14000.00
0005432530314	30577	Economy	14000.00
0005432529611	30577	Economy	14000.00
0005432530371	30577	Economy	14000.00
0005432530260	30577	Economy	14000.00
0005435215123	30577	Economy	14000.00
0005434068521	30577	Economy	14000.00
0005432529153	30577	Economy	14000.00
0005432529940	30577	Economy	14000.00
0005432529606	30577	Economy	14000.00
0005434068462	30577	Economy	14000.00
0005435283443	30577	Economy	14000.00
0005434068535	30577	Economy	14000.00
0005434068434	30577	Economy	14000.00
0005434068792	30577	Economy	14000.00
0005432533333	30577	Economy	14000.00
0005435215120	30577	Economy	14000.00
0005434068475	30577	Economy	14000.00
0005433656750	30577	Economy	14000.00
0005432529929	30577	Economy	15400.00
0005435283440	30577	Economy	15400.00
0005435215112	30577	Economy	15400.00
0005432530061	30577	Economy	15400.00
0005435725718	30577	Economy	15400.00
0005432529801	30577	Economy	14000.00
0005434068781	30577	Economy	14000.00
0005432535910	30577	Economy	14000.00
0005434068681	30577	Economy	14000.00
0005435215137	30577	Economy	14000.00
0005435283452	30577	Economy	14000.00
0005432529582	30577	Economy	14000.00
0005434068780	30577	Economy	14000.00
0005432530236	30577	Economy	14000.00
0005435215100	30577	Economy	14000.00
0005432428989	30577	Economy	14000.00
0005432529710	30577	Economy	14000.00
0005432530316	30577	Economy	14000.00
0005432529904	30577	Economy	14000.00
0005432535905	30577	Economy	14000.00
0005435215167	30577	Economy	14000.00
0005435215122	30577	Economy	14000.00
0005432529749	30577	Economy	14000.00
0005434068302	30577	Economy	14000.00
0005432530387	30577	Economy	14000.00
0005432159967	30577	Economy	14000.00
0005433656751	30577	Economy	14000.00
0005434068680	30577	Economy	14000.00
0005435215109	30577	Economy	14000.00
0005432530454	30577	Economy	14000.00
0005434068554	30577	Economy	14000.00
0005432530057	30577	Economy	14000.00
0005435215157	30577	Economy	14000.00
0005435215138	30577	Economy	14000.00
0005432530145	30577	Economy	14000.00
0005432530273	30577	Economy	14000.00
0005432159965	30577	Economy	14000.00
0005435215106	30577	Economy	14000.00
0005432529477	30577	Economy	14000.00
0005435215162	30577	Economy	14000.00
0005432530032	30577	Economy	14000.00
0005435215160	30577	Economy	14000.00
0005432529859	30577	Economy	14000.00
0005432535890	30577	Economy	14000.00
0005432529323	30577	Economy	14000.00
0005432211676	30577	Economy	14000.00
0005435215102	30577	Economy	14000.00
0005435215104	30577	Economy	14000.00
0005432530100	30577	Economy	14000.00
0005435215134	30577	Economy	14000.00
0005432529534	30577	Economy	14000.00
0005434068578	30577	Economy	14000.00
0005432529734	30577	Economy	14000.00
0005432529240	30577	Economy	14000.00
0005434068588	30577	Economy	14000.00
0005435283457	30577	Economy	14000.00
0005432530207	30577	Economy	14000.00
0005435725715	30577	Economy	14000.00
0005432529925	30577	Economy	14000.00
0005435215127	30577	Economy	14000.00
0005435215139	30577	Economy	14000.00
0005432529987	30577	Economy	14000.00
0005435283450	30577	Economy	14000.00
0005435215132	30577	Economy	14000.00
0005435215147	30577	Economy	14000.00
0005432529946	30577	Economy	14000.00
0005432529948	30577	Economy	14000.00
0005434068252	30577	Economy	14000.00
0005435283449	30577	Economy	14000.00
0005434068504	30577	Economy	14000.00
0005432530341	30577	Economy	14000.00
0005432529798	30577	Economy	14000.00
0005435215108	30577	Economy	14000.00
0005432159964	30577	Economy	14000.00
0005432529624	30577	Economy	14000.00
0005434068697	30577	Economy	14000.00
0005435215110	30577	Economy	14000.00
0005435215117	30577	Economy	14000.00
0005434068890	30577	Economy	14000.00
0005435215129	30577	Economy	14000.00
0005435215133	30577	Economy	14000.00
0005432529747	30577	Economy	14000.00
0005432529930	30577	Economy	14000.00
0005432533335	30577	Economy	14000.00
0005432529202	30577	Economy	14000.00
0005435215148	30577	Economy	14000.00
0005432529833	30577	Economy	14000.00
0005432533334	30577	Economy	14000.00
0005432530052	30577	Economy	14000.00
0005432529592	30577	Economy	14000.00
0005432529870	30577	Economy	14000.00
0005432529879	30577	Economy	14000.00
0005432159966	30577	Economy	14000.00
0005432530306	30577	Economy	14000.00
0005434068476	30577	Economy	14000.00
0005432529564	30577	Economy	14000.00
0005432530026	30577	Economy	14000.00
0005433368761	24838	Business	9800.00
0005435653771	24838	Business	9800.00
0005433368767	24838	Business	9800.00
0005433368780	24838	Business	9800.00
0005435653687	24838	Business	9800.00
0005435653651	24838	Business	9800.00
0005433368760	24838	Business	9800.00
0005435653700	24838	Business	9800.00
0005435653630	24838	Business	9800.00
0005435653517	24838	Business	9800.00
0005433368778	24838	Economy	3300.00
0005433368756	24838	Economy	3300.00
0005435653608	24838	Economy	3300.00
0005435653578	24838	Economy	3300.00
0005433368764	24838	Economy	3300.00
0005435653649	24838	Economy	3300.00
0005435653666	24838	Economy	3300.00
0005433368755	24838	Economy	3300.00
0005433368768	24838	Economy	3600.00
0005435653740	24838	Economy	3600.00
0005435653617	24838	Economy	3600.00
0005435653647	24838	Economy	3600.00
0005435653648	24838	Economy	3600.00
0005435653607	24838	Economy	3300.00
0005435653735	24838	Economy	3300.00
0005435653665	24838	Economy	3300.00
0005435653640	24838	Economy	3300.00
0005433368785	24838	Economy	3300.00
0005433368789	24838	Economy	3300.00
0005433368763	24838	Economy	3300.00
0005435653805	24838	Economy	3300.00
0005433368783	24838	Economy	3300.00
0005435653535	24838	Economy	3300.00
0005433368777	24838	Economy	3300.00
0005433368758	24838	Economy	3300.00
0005433368765	24838	Economy	3300.00
0005433368752	24838	Economy	3300.00
0005433368770	24838	Economy	3300.00
0005433368784	24838	Economy	3300.00
0005435653622	24838	Economy	3300.00
0005433368781	24838	Economy	3300.00
0005433368779	24838	Economy	3300.00
0005435653806	24838	Economy	3300.00
0005435653803	24838	Economy	3300.00
0005435653577	24838	Economy	3300.00
0005433368772	24838	Economy	3300.00
0005435653804	24838	Economy	3300.00
0005435653807	24838	Economy	3300.00
0005433368776	24838	Economy	3300.00
0005433368766	24838	Economy	3300.00
0005433368773	24838	Economy	3300.00
0005435653754	24838	Economy	3300.00
0005433368753	24838	Economy	3300.00
0005435653892	24838	Economy	3300.00
0005433368754	24838	Economy	3300.00
0005435653565	24838	Economy	3300.00
0005435653610	24838	Economy	3300.00
0005435653681	24838	Economy	3300.00
0005433368775	24838	Economy	3300.00
0005435653693	24838	Economy	3300.00
0005433368786	24838	Economy	3300.00
0005435653623	24838	Economy	3300.00
0005435653782	24838	Economy	3300.00
0005433368774	24838	Economy	3300.00
0005435653620	24838	Economy	3300.00
0005435653606	24838	Economy	3300.00
0005433368762	24838	Economy	3300.00
0005433368757	24838	Economy	3300.00
0005433368769	24838	Economy	3300.00
0005433368782	24838	Economy	3300.00
0005435653688	24838	Economy	3300.00
0005435653664	24838	Economy	3300.00
0005435653699	24838	Economy	3300.00
0005433368787	24838	Economy	3300.00
0005435653775	24838	Economy	3300.00
0005433368759	24838	Economy	3300.00
0005435653781	24838	Economy	3300.00
0005435653682	24838	Economy	3300.00
0005433368771	24838	Economy	3300.00
0005435653641	24838	Economy	3300.00
0005433368788	24838	Economy	3300.00
0005435653741	24838	Economy	3300.00
0005434980488	2049	Economy	10500.00
0005434980492	2049	Economy	9500.00
0005434980496	2049	Economy	9500.00
0005434980486	2049	Economy	9500.00
0005434980508	2049	Economy	9500.00
0005435801769	2049	Economy	9500.00
0005434980499	2049	Economy	9500.00
0005434980483	2049	Economy	9500.00
0005434980512	2049	Economy	9500.00
0005434980491	2049	Economy	9500.00
0005434980505	2049	Economy	9500.00
0005434980513	2049	Economy	9500.00
0005434980484	2049	Economy	9500.00
0005434980509	2049	Economy	9500.00
0005434980487	2049	Economy	9500.00
0005434980500	2049	Economy	9500.00
0005435801768	2049	Economy	9500.00
0005434980497	2049	Economy	9500.00
0005434980493	2049	Economy	9500.00
0005434980485	2049	Economy	9500.00
0005434980511	2049	Economy	9500.00
0005434980502	2049	Economy	9500.00
0005434980489	2049	Economy	9500.00
0005434980504	2049	Economy	9500.00
0005434980510	2049	Economy	9500.00
0005434980498	2049	Economy	9500.00
0005434980490	2049	Economy	9500.00
0005434980503	2049	Economy	9500.00
0005435801767	2049	Economy	9500.00
0005434980501	2049	Economy	9500.00
0005434980494	2049	Economy	9500.00
0005434980507	2049	Economy	9500.00
0005434980506	2049	Economy	9500.00
0005434980495	2049	Economy	9500.00
0005434980108	23553	Economy	10500.00
0005434980202	23553	Economy	10500.00
0005434980237	23553	Economy	10500.00
0005434980175	23553	Economy	9500.00
0005434980231	23553	Economy	9500.00
0005434980078	23553	Economy	9500.00
0005434980177	23553	Economy	9500.00
0005434980074	23553	Economy	9500.00
0005434980079	23553	Economy	9500.00
0005434980153	23553	Economy	9500.00
0005434980242	23553	Economy	9500.00
0005434980205	23553	Economy	9500.00
0005434980084	23553	Economy	9500.00
0005434980083	23553	Economy	9500.00
0005434980238	23553	Economy	9500.00
0005434980156	23553	Economy	9500.00
0005434980109	23553	Economy	9500.00
0005434980146	23553	Economy	9500.00
0005434980257	23553	Economy	9500.00
0005434980144	23553	Economy	9500.00
0005434980283	23553	Economy	9500.00
0005434980148	23553	Economy	9500.00
0005434980176	23553	Economy	9500.00
0005434980310	23553	Economy	9500.00
0005434980157	23553	Economy	9500.00
0005434980218	23553	Economy	9500.00
0005434980145	23553	Economy	9500.00
0005434980147	23553	Economy	9500.00
0005434980133	23553	Economy	9500.00
0005434980219	23553	Economy	9500.00
0005434980201	23553	Economy	9500.00
0005434980248	23553	Economy	9500.00
0005434980217	23553	Economy	9500.00
0005434952620	2673	Economy	5300.00
0005434952618	2673	Economy	5300.00
0005434952619	2673	Economy	5300.00
0005434952621	2673	Economy	5300.00
0005433256457	2603	Economy	5300.00
0005433256458	2603	Economy	5300.00
0005433256451	2603	Economy	5300.00
0005433256459	2603	Economy	5300.00
0005433256465	2603	Economy	5300.00
0005433256476	28208	Economy	5300.00
0005434952572	28208	Economy	5300.00
0005434952588	28208	Economy	5300.00
0005434952579	28208	Economy	5300.00
0005434952571	28208	Economy	5300.00
0005434952570	28208	Economy	5300.00
0005434952580	28208	Economy	5300.00
0005434952575	28208	Economy	5300.00
0005434952581	28208	Economy	5300.00
0005433256475	28208	Economy	5300.00
0005433111558	19843	Economy	8700.00
0005433112414	19843	Economy	8700.00
0005433111559	19843	Economy	8700.00
0005433112415	19843	Economy	8700.00
0005434139656	11956	Business	9700.00
0005434139529	11956	Business	9700.00
0005434139459	11956	Business	9700.00
0005434139366	11956	Business	9700.00
0005434139377	11956	Business	9700.00
0005434139308	11956	Business	9700.00
0005434138986	11956	Business	9700.00
0005434139074	11956	Business	9700.00
0005434139655	11956	Economy	3200.00
0005434139363	11956	Economy	3200.00
0005434139666	11956	Economy	3200.00
0005434139262	11956	Economy	3200.00
0005434139384	11956	Economy	3200.00
0005434139304	11956	Economy	3200.00
0005434139660	11956	Economy	3500.00
0005434139325	11956	Economy	3500.00
0005434139530	11956	Economy	3500.00
0005434138732	11956	Economy	3500.00
0005434139601	11956	Economy	3500.00
0005434139265	11956	Economy	3200.00
0005434139608	11956	Economy	3200.00
0005434139186	11956	Economy	3200.00
0005434139731	11956	Economy	3200.00
0005434138841	11956	Economy	3200.00
0005434139478	11956	Economy	3200.00
0005434139147	11956	Economy	3200.00
0005434139296	11956	Economy	3200.00
0005434139072	11956	Economy	3200.00
0005434139406	11956	Economy	3200.00
0005434139654	11956	Economy	3200.00
0005434139510	11956	Economy	3200.00
0005434139326	11956	Economy	3200.00
0005434139511	11956	Economy	3200.00
0005434139441	11956	Economy	3200.00
0005434139507	11956	Economy	3200.00
0005434139279	11956	Economy	3200.00
0005434139528	11956	Economy	3200.00
0005434139240	11956	Economy	3200.00
0005434139661	11956	Economy	3200.00
0005434139385	11956	Economy	3200.00
0005434138985	11956	Economy	3200.00
0005434138842	11956	Economy	3200.00
0005434139465	11956	Economy	3200.00
0005434139460	11956	Economy	3200.00
0005434139497	11956	Economy	3200.00
0005434139404	11956	Economy	3200.00
0005434139664	11956	Economy	3200.00
0005434139498	11956	Economy	3200.00
0005434139646	11956	Economy	3200.00
0005434139541	11956	Economy	3200.00
0005434139075	11956	Economy	3200.00
0005434139280	11956	Economy	3200.00
0005434139031	11956	Economy	3200.00
0005434139665	11956	Economy	3200.00
0005434139241	11956	Economy	3200.00
0005434139378	11956	Economy	3200.00
0005434139457	11956	Economy	3200.00
0005434138970	11956	Economy	3200.00
0005434139557	11956	Economy	3200.00
0005434139609	11956	Economy	3200.00
0005434139560	11956	Economy	3200.00
0005434139479	11956	Economy	3200.00
0005434139030	11956	Economy	3200.00
0005434139071	11956	Economy	3200.00
0005434139383	11956	Economy	3200.00
0005434139381	11956	Economy	3200.00
0005434139547	11956	Economy	3200.00
0005434139573	11956	Economy	3200.00
0005434139365	11956	Economy	3200.00
0005434138843	11956	Economy	3200.00
0005434139440	11956	Economy	3200.00
0005434139572	11956	Economy	3200.00
0005434139125	11956	Economy	3200.00
0005434139508	11956	Economy	3200.00
0005434138987	11956	Economy	3200.00
0005434139176	11956	Economy	3200.00
0005434139509	11956	Economy	3200.00
0005434139342	11956	Economy	3200.00
0005434139278	11956	Economy	3200.00
0005434139943	28716	Business	9700.00
0005434139941	28716	Business	9700.00
0005434139995	28716	Business	9700.00
0005434139999	28716	Business	9700.00
0005434139958	28716	Business	9700.00
0005434140008	28716	Business	9700.00
0005434139980	28716	Business	9700.00
0005434139962	28716	Business	9700.00
0005434139989	28716	Business	9700.00
0005434139945	28716	Business	9700.00
0005434140012	28716	Business	9700.00
0005434139972	28716	Business	9700.00
0005434139981	28716	Economy	3200.00
0005434139983	28716	Economy	3200.00
0005434139984	28716	Economy	3200.00
0005434139988	28716	Economy	3200.00
0005434140004	28716	Economy	3200.00
0005434139998	28716	Economy	3200.00
0005434140028	28716	Economy	3200.00
0005434140016	28716	Economy	3500.00
0005434139987	28716	Economy	3500.00
0005434140026	28716	Economy	3500.00
0005434140023	28716	Economy	3500.00
0005434139997	28716	Economy	3500.00
0005434140005	28716	Economy	3200.00
0005434139991	28716	Economy	3200.00
0005434139975	28716	Economy	3200.00
0005434139969	28716	Economy	3200.00
0005434140006	28716	Economy	3200.00
0005434139968	28716	Economy	3200.00
0005434139996	28716	Economy	3200.00
0005434139970	28716	Economy	3200.00
0005434139982	28716	Economy	3200.00
0005434139963	28716	Economy	3200.00
0005434139956	28716	Economy	3200.00
0005434139952	28716	Economy	3200.00
0005434139973	28716	Economy	3200.00
0005434139976	28716	Economy	3200.00
0005434139960	28716	Economy	3200.00
0005434140022	28716	Economy	3200.00
0005434139961	28716	Economy	3200.00
0005434139974	28716	Economy	3200.00
0005434139944	28716	Economy	3200.00
0005434140011	28716	Economy	3200.00
0005434139977	28716	Economy	3200.00
0005434140000	28716	Economy	3200.00
0005434139950	28716	Economy	3200.00
0005434140010	28716	Economy	3200.00
0005434139990	28716	Economy	3200.00
0005434139966	28716	Economy	3200.00
0005434140020	28716	Economy	3200.00
0005434140019	28716	Economy	3200.00
0005434139978	28716	Economy	3200.00
0005434139971	28716	Economy	3200.00
0005434140018	28716	Economy	3200.00
0005434139951	28716	Economy	3200.00
0005434140032	28716	Economy	3200.00
0005434139957	28716	Economy	3200.00
0005434140002	28716	Economy	3200.00
0005434140009	28716	Economy	3200.00
0005434139954	28716	Economy	3200.00
0005434139955	28716	Economy	3200.00
0005434140017	28716	Economy	3200.00
0005434139992	28716	Economy	3200.00
0005434140003	28716	Economy	3200.00
0005434140031	28716	Economy	3200.00
0005434140029	28716	Economy	3200.00
0005434139942	28716	Economy	3200.00
0005434139948	28716	Economy	3200.00
0005434139959	28716	Economy	3200.00
0005434139986	28716	Economy	3200.00
0005434139964	28716	Economy	3200.00
0005434140021	28716	Economy	3200.00
0005434140030	28716	Economy	3200.00
0005434139946	28716	Economy	3200.00
0005434139967	28716	Economy	3200.00
0005434139985	28716	Economy	3200.00
0005434139993	28716	Economy	3200.00
0005434140001	28716	Economy	3200.00
0005434139965	28716	Economy	3200.00
0005434140015	28716	Economy	3200.00
0005434140013	28716	Economy	3200.00
0005434139953	28716	Economy	3200.00
0005434140024	28716	Economy	3200.00
0005434140007	28716	Economy	3200.00
0005434139979	28716	Economy	3200.00
0005434140027	28716	Economy	3200.00
0005434140025	28716	Economy	3200.00
0005434140014	28716	Economy	3200.00
0005434139947	28716	Economy	3200.00
0005434139949	28716	Economy	3200.00
0005434139994	28716	Economy	3200.00
0005433539072	6791	Economy	10900.00
0005433539077	6791	Economy	9900.00
0005433539071	6791	Economy	9900.00
0005433539074	6791	Economy	9900.00
0005433534549	6791	Economy	9900.00
0005433539069	6791	Economy	9900.00
0005433539075	6791	Economy	9900.00
0005435259822	6791	Economy	9900.00
0005433539073	6791	Economy	9900.00
0005433534548	6791	Economy	9900.00
0005435259821	6791	Economy	9900.00
0005435259845	6791	Economy	9900.00
0005433539076	6791	Economy	9900.00
0005433539070	6791	Economy	9900.00
0005433539002	25024	Economy	9900.00
0005433538996	25024	Economy	9900.00
0005435259862	25024	Economy	9900.00
0005433538997	25024	Economy	9900.00
0005435259860	25024	Economy	9900.00
0005433539035	25024	Economy	9900.00
0005435259861	25024	Economy	9900.00
0005435259859	25024	Economy	9900.00
0005432922587	812	Economy	14600.00
0005432922588	812	Economy	14600.00
0005433512147	812	Economy	14600.00
0005433512151	812	Economy	14600.00
0005433512148	812	Economy	14600.00
0005433512150	812	Economy	14600.00
0005433512149	812	Economy	14600.00
0005433512146	812	Economy	14600.00
0005433512100	16180	Economy	14600.00
0005433512064	16180	Economy	14600.00
0005432922623	16180	Economy	14600.00
0005433512067	16180	Economy	14600.00
0005432922620	16180	Economy	14600.00
0005433512058	16180	Economy	14600.00
0005433512116	16180	Economy	14600.00
0005433512117	16180	Economy	14600.00
0005433512089	16180	Economy	14600.00
0005433512099	16180	Economy	14600.00
0005433512108	16180	Economy	14600.00
0005432922622	16180	Economy	14600.00
0005432922621	16180	Economy	14600.00
0005433512109	16180	Economy	14600.00
0005433512111	16180	Economy	14600.00
0005435852619	4037	Economy	12300.00
0005435852605	4037	Economy	12300.00
0005433475804	4037	Economy	12300.00
0005435852596	4037	Economy	12300.00
0005433475811	4037	Economy	12300.00
0005433475806	4037	Economy	12300.00
0005433475803	4037	Economy	12300.00
0005435852620	4037	Economy	12300.00
0005433475805	4037	Economy	12300.00
0005433475809	4037	Economy	12300.00
0005433475808	4037	Economy	12300.00
0005433475812	4037	Economy	12300.00
0005433475807	4037	Economy	12300.00
0005433475801	4037	Economy	12300.00
0005433475802	4037	Economy	12300.00
0005435852621	4037	Economy	12300.00
0005433475810	4037	Economy	12300.00
0005435852622	4037	Economy	12300.00
0005435852614	4037	Economy	12300.00
0005433475799	4037	Economy	12300.00
0005433475800	4037	Economy	12300.00
0005435852606	4037	Economy	12300.00
0005435852597	4037	Economy	12300.00
0005435697994	3661	Economy	7900.00
0005435698000	3661	Economy	7900.00
0005435698015	3661	Economy	7900.00
0005435916213	3661	Economy	7900.00
0005435698012	3661	Economy	7200.00
0005435697995	3661	Economy	7200.00
0005435698003	3661	Economy	7200.00
0005435698017	3661	Economy	7200.00
0005435698002	3661	Economy	7200.00
0005435698009	3661	Economy	7200.00
0005435698004	3661	Economy	7200.00
0005434950636	3661	Economy	7200.00
0005435698013	3661	Economy	7200.00
0005435697992	3661	Economy	7200.00
0005435698007	3661	Economy	7200.00
0005435698014	3661	Economy	7200.00
0005435698001	3661	Economy	7200.00
0005435935083	3661	Economy	7200.00
0005435697993	3661	Economy	7200.00
0005435697997	3661	Economy	7200.00
0005435698005	3661	Economy	7200.00
0005435916218	3661	Economy	7200.00
0005435698011	3661	Economy	7200.00
0005435935100	3661	Economy	7200.00
0005435698008	3661	Economy	7200.00
0005435698018	3661	Economy	7200.00
0005435697998	3661	Economy	7200.00
0005435698010	3661	Economy	7200.00
0005435935093	3661	Economy	7200.00
0005435698006	3661	Economy	7200.00
0005434950637	3661	Economy	7200.00
0005435916214	3661	Economy	7200.00
0005435697996	3661	Economy	7200.00
0005435698016	3661	Economy	7200.00
0005434950634	3661	Economy	7200.00
0005435697999	3661	Economy	7200.00
0005434950638	3661	Economy	7200.00
0005434950635	3661	Economy	7200.00
0005435935117	16261	Economy	7900.00
0005435697776	16261	Economy	7900.00
0005435697739	16261	Economy	7900.00
0005435697670	16261	Economy	7200.00
0005435697784	16261	Economy	7200.00
0005435933571	16261	Economy	7200.00
0005435697639	16261	Economy	7200.00
0005435697749	16261	Economy	7200.00
0005435935118	16261	Economy	7200.00
0005435697891	16261	Economy	7200.00
0005435916234	16261	Economy	7200.00
0005435697794	16261	Economy	7200.00
0005435933570	16261	Economy	7200.00
0005435697691	16261	Economy	7200.00
0005435697813	16261	Economy	7200.00
0005434950591	16261	Economy	7200.00
0005435697857	16261	Economy	7200.00
0005435935116	16261	Economy	7200.00
0005435935115	16261	Economy	7200.00
0005435697652	16261	Economy	7200.00
0005435697679	16261	Economy	7200.00
0005435697814	16261	Economy	7200.00
0005435697685	16261	Economy	7200.00
0005435697748	16261	Economy	7200.00
0005435697812	16261	Economy	7200.00
0005435697892	16261	Economy	7200.00
0005435697682	16261	Economy	7200.00
0005435697741	16261	Economy	7200.00
0005435697858	16261	Economy	7200.00
0005435935114	16261	Economy	7200.00
0005435697719	16261	Economy	7200.00
0005435697740	16261	Economy	7200.00
0005435697651	16261	Economy	7200.00
0005435916232	16261	Economy	7200.00
0005435697684	16261	Economy	7200.00
0005435697818	16261	Economy	7200.00
0005435697594	16261	Economy	7200.00
0005435916233	16261	Economy	7200.00
0005435697680	16261	Economy	7200.00
0005435697690	16261	Economy	7200.00
0005435697683	16261	Economy	7200.00
0005435697775	16261	Economy	7200.00
0005434604984	3979	Economy	21300.00
0005435842331	3979	Economy	21300.00
0005434606911	3979	Economy	21300.00
0005435853643	3979	Economy	19300.00
0005435841477	3979	Economy	19300.00
0005434604985	3979	Economy	19300.00
0005433519566	3979	Economy	19300.00
0005433519567	3979	Economy	19300.00
0005433519568	3979	Economy	19300.00
0005434604987	3979	Economy	19300.00
0005435904712	3979	Economy	19300.00
0005432607662	3979	Economy	19300.00
0005432609830	3979	Economy	19300.00
0005432609828	3979	Economy	19300.00
0005432609826	3979	Economy	19300.00
0005432607660	3979	Economy	19300.00
0005432607663	3979	Economy	19300.00
0005434606908	3979	Economy	19300.00
0005432609827	3979	Economy	19300.00
0005434606910	3979	Economy	19300.00
0005434604986	3979	Economy	19300.00
0005435904713	3979	Economy	19300.00
0005433519565	3979	Economy	19300.00
0005432607659	3979	Economy	19300.00
0005434606909	3979	Economy	19300.00
0005435841478	3979	Economy	19300.00
0005432609829	3979	Economy	19300.00
0005432607661	3979	Economy	19300.00
0005435853654	22040	Economy	21300.00
0005435904908	22040	Economy	19300.00
0005435904907	22040	Economy	19300.00
0005434606872	22040	Economy	19300.00
0005435853653	22040	Economy	19300.00
0005435904723	22040	Economy	19300.00
0005435853655	22040	Economy	19300.00
0005435904906	22040	Economy	19300.00
0005435628807	736	Economy	3700.00
0005435628806	736	Economy	3700.00
0005433349058	736	Economy	3700.00
0005433349082	736	Economy	3700.00
0005435628805	736	Economy	3700.00
0005433349081	736	Economy	3700.00
0005435628804	736	Economy	3700.00
0005433349059	736	Economy	3700.00
0005433349061	736	Economy	3700.00
0005433349063	736	Economy	3700.00
0005433349056	736	Economy	3700.00
0005433349062	736	Economy	3700.00
0005435628782	15890	Economy	3700.00
0005433349125	15890	Economy	3700.00
0005433349130	15890	Economy	3700.00
0005435628765	15890	Economy	3700.00
0005433349128	15890	Economy	3700.00
0005433349127	15890	Economy	3700.00
0005433349129	15890	Economy	3700.00
0005435628766	15890	Economy	3700.00
0005433349126	15890	Economy	3700.00
0005433159341	17193	Economy	7100.00
0005434446573	17193	Economy	7100.00
0005434445301	17193	Economy	7100.00
0005434445302	17193	Economy	7100.00
0005433159338	17193	Economy	7100.00
0005434446571	17193	Economy	7100.00
0005434446572	17193	Economy	7100.00
0005434446574	17193	Economy	7100.00
0005434445282	17675	Economy	7100.00
0005434445275	17675	Economy	7100.00
0005434445283	17675	Economy	7100.00
0005433159367	17675	Economy	7100.00
0005434445269	17675	Economy	7100.00
0005433158198	17675	Economy	7100.00
0005434445277	17675	Economy	7100.00
0005435133131	7874	Economy	5900.00
0005435383221	7874	Economy	5400.00
0005435133129	7874	Economy	5400.00
0005435133132	7874	Economy	5400.00
0005435383233	7874	Economy	5400.00
0005435383222	7874	Economy	5400.00
0005435383238	7874	Economy	5400.00
0005435133133	7874	Economy	5400.00
0005435133138	7874	Economy	5400.00
0005435133137	7874	Economy	5400.00
0005435133135	7874	Economy	5400.00
0005435133136	7874	Economy	5400.00
0005435133134	7874	Economy	5400.00
0005435133130	7874	Economy	5400.00
0005435383277	33085	Economy	5400.00
0005435383278	33085	Economy	5400.00
0005435133055	33085	Economy	5400.00
0005435383279	33085	Economy	5400.00
0005435133076	33085	Economy	5400.00
0005435133020	33085	Economy	5400.00
0005435133046	33085	Economy	5400.00
0005435133042	33085	Economy	5400.00
0005435133019	33085	Economy	5400.00
0005435383276	33085	Economy	5400.00
0005435383280	33085	Economy	5400.00
0005435132988	33085	Economy	5400.00
0005435133063	33085	Economy	5400.00
0005435132987	33085	Economy	5400.00
0005435133083	33085	Economy	5400.00
0005435133094	33085	Economy	5400.00
0005435133069	33085	Economy	5400.00
0005435133084	33085	Economy	5400.00
0005435383281	33085	Economy	5400.00
0005435133025	33085	Economy	5400.00
0005435133085	33085	Economy	5400.00
0005435133075	33085	Economy	5400.00
0005435160570	7476	Economy	13800.00
0005435160564	7476	Economy	12500.00
0005435390338	7476	Economy	12500.00
0005435160571	7476	Economy	12500.00
0005435160567	7476	Economy	12500.00
0005435390351	7476	Economy	12500.00
0005435160566	7476	Economy	12500.00
0005435390342	7476	Economy	12500.00
0005435390350	7476	Economy	12500.00
0005435160568	7476	Economy	12500.00
0005435160563	7476	Economy	12500.00
0005435160562	7476	Economy	12500.00
0005435390330	7476	Economy	12500.00
0005435390324	7476	Economy	12500.00
0005435160565	7476	Economy	12500.00
0005435390321	7476	Economy	12500.00
0005435390315	7476	Economy	12500.00
0005435160569	7476	Economy	12500.00
0005435160572	7476	Economy	12500.00
0005435160573	7476	Economy	12500.00
0005435390407	29553	Economy	12500.00
0005435390405	29553	Economy	12500.00
0005435160428	29553	Economy	12500.00
0005435390403	29553	Economy	12500.00
0005435160454	29553	Economy	12500.00
0005435160492	29553	Economy	12500.00
0005435390406	29553	Economy	12500.00
0005435160463	29553	Economy	12500.00
0005435390408	29553	Economy	12500.00
0005435160513	29553	Economy	12500.00
0005435160476	29553	Economy	12500.00
0005435160506	29553	Economy	12500.00
0005435160462	29553	Economy	12500.00
0005435390404	29553	Economy	12500.00
0005435160507	29553	Economy	12500.00
0005432398240	18458	Economy	4900.00
0005432398226	18458	Economy	4900.00
0005435179014	18458	Economy	4900.00
0005435179012	18458	Economy	4900.00
0005432398263	18458	Economy	4900.00
0005432398264	18458	Economy	4900.00
0005432394176	18458	Economy	4900.00
0005432394177	18458	Economy	4900.00
0005432394159	18458	Economy	4900.00
0005435179013	18458	Economy	4900.00
0005432398280	27125	Economy	4900.00
0005432400207	27125	Economy	4900.00
0005432398282	27125	Economy	4900.00
0005432400209	27125	Economy	4900.00
0005432398279	27125	Economy	4900.00
0005435179403	27125	Economy	4900.00
0005432400208	27125	Economy	4900.00
0005432400210	27125	Economy	4900.00
0005432398281	27125	Economy	4900.00
0005434191297	9751	Economy	4400.00
0005434505104	6564	Business	48400.00
0005434505096	6564	Business	48400.00
0005434505081	6564	Business	48400.00
0005435104162	6564	Business	48400.00
0005434505103	6564	Business	48400.00
0005435104157	6564	Business	48400.00
0005434505085	6564	Business	48400.00
0005434505091	6564	Business	48400.00
0005435104158	6564	Business	48400.00
0005434505107	6564	Economy	16100.00
0005434505099	6564	Economy	16100.00
0005434505090	6564	Economy	16100.00
0005434505105	6564	Economy	16100.00
0005434505094	6564	Economy	16100.00
0005434505108	6564	Economy	16100.00
0005434505088	6564	Economy	16100.00
0005434505086	6564	Economy	16100.00
0005434505074	6564	Economy	16100.00
0005434505083	6564	Economy	16100.00
0005434505075	6564	Economy	16100.00
0005435104150	6564	Economy	16100.00
0005434505080	6564	Economy	16100.00
0005434505077	6564	Economy	16100.00
0005434505095	6564	Economy	16100.00
0005435104160	6564	Economy	16100.00
0005435104164	6564	Economy	16100.00
0005434505102	6564	Economy	16100.00
0005434505079	6564	Economy	16100.00
0005435104163	6564	Economy	16100.00
0005435104165	6564	Economy	16100.00
0005435104159	6564	Economy	16100.00
0005434505106	6564	Economy	16100.00
0005434505098	6564	Economy	16100.00
0005434505076	6564	Economy	16100.00
0005434505100	6564	Economy	16100.00
0005434505082	6564	Economy	16100.00
0005434505087	6564	Economy	16100.00
0005434505072	6564	Economy	16100.00
0005435104161	6564	Economy	16100.00
0005435104153	6564	Economy	16100.00
0005435104151	6564	Economy	16100.00
0005434505071	6564	Economy	16100.00
0005434505089	6564	Economy	16100.00
0005434505092	6564	Economy	16100.00
0005435104155	6564	Economy	16100.00
0005434505084	6564	Economy	16100.00
0005435104154	6564	Economy	16100.00
0005434505073	6564	Economy	16100.00
0005435104156	6564	Economy	16100.00
0005435104152	6564	Economy	16100.00
0005434505078	6564	Economy	16100.00
0005434505070	6564	Economy	16100.00
0005434505110	6564	Economy	16100.00
0005434505093	6564	Economy	16100.00
0005434505097	6564	Economy	16100.00
0005435104166	6564	Economy	16100.00
0005434505109	6564	Economy	16100.00
0005435104167	6564	Economy	16100.00
0005434505101	6564	Economy	16100.00
0005434504658	22676	Business	48400.00
0005434504535	22676	Business	48400.00
0005434504762	22676	Business	48400.00
0005434504855	22676	Business	48400.00
0005434504685	22676	Business	48400.00
0005434504654	22676	Business	48400.00
0005435103988	22676	Business	48400.00
0005435104016	22676	Business	48400.00
0005434504721	22676	Business	48400.00
0005434504585	22676	Business	48400.00
0005434504819	22676	Economy	16100.00
0005434504718	22676	Economy	16100.00
0005434504563	22676	Economy	17800.00
0005434504882	22676	Economy	17800.00
0005435104026	22676	Economy	16100.00
0005434504484	22676	Economy	16100.00
0005434504584	22676	Economy	16100.00
0005435104030	22676	Economy	16100.00
0005435103987	22676	Economy	16100.00
0005434504437	22676	Economy	16100.00
0005435104010	22676	Economy	16100.00
0005434504714	22676	Economy	16100.00
0005434504659	22676	Economy	16100.00
0005434504719	22676	Economy	16100.00
0005434504642	22676	Economy	16100.00
0005434504774	22676	Economy	16100.00
0005434504438	22676	Economy	16100.00
0005434504709	22676	Economy	16100.00
0005434504519	22676	Economy	16100.00
0005434504702	22676	Economy	16100.00
0005434504737	22676	Economy	16100.00
0005434504700	22676	Economy	16100.00
0005434504565	22676	Economy	16100.00
0005434504843	22676	Economy	16100.00
0005434504710	22676	Economy	16100.00
0005434504775	22676	Economy	16100.00
0005434504525	22676	Economy	16100.00
0005434504583	22676	Economy	16100.00
0005434504436	22676	Economy	16100.00
0005434504582	22676	Economy	16100.00
0005434504657	22676	Economy	16100.00
0005434504638	22676	Economy	16100.00
0005434504491	22676	Economy	16100.00
0005434504842	22676	Economy	16100.00
0005434504557	22676	Economy	16100.00
0005434504490	22676	Economy	16100.00
0005434504773	22676	Economy	16100.00
0005434504526	22676	Economy	16100.00
0005434504588	22676	Economy	16100.00
0005434504520	22676	Economy	16100.00
0005434504741	22676	Economy	16100.00
0005434504550	22676	Economy	16100.00
0005434504720	22676	Economy	16100.00
0005435104015	22676	Economy	16100.00
0005434504738	22676	Economy	16100.00
0005435104027	22676	Economy	16100.00
0005434504579	22676	Economy	16100.00
0005435654122	1696	Business	50000.00
0005435654147	1696	Business	50000.00
0005433368613	1696	Business	50000.00
0005435654130	1696	Business	50000.00
0005435654121	1696	Business	50000.00
0005435654138	1696	Business	50000.00
0005433368462	1696	Business	50000.00
0005433368463	1696	Business	50000.00
0005435654129	1696	Business	50000.00
0005435654109	1696	Business	50000.00
0005435654128	1696	Business	50000.00
0005435654157	1696	Economy	16700.00
0005435654127	1696	Economy	16700.00
0005433368418	1696	Economy	16700.00
0005435654104	1696	Economy	16700.00
0005435654106	1696	Economy	16700.00
0005435654131	1696	Economy	16700.00
0005433368417	1696	Economy	16700.00
0005433368426	1696	Economy	16700.00
0005435654112	1696	Economy	16700.00
0005435654150	1696	Economy	16700.00
0005435654105	1696	Economy	18300.00
0005435654143	1696	Economy	18300.00
0005433368453	1696	Economy	18300.00
0005435654101	1696	Economy	18300.00
0005433368427	1696	Economy	18300.00
0005435654108	1696	Economy	16700.00
0005435654155	1696	Economy	16700.00
0005435654113	1696	Economy	16700.00
0005435654142	1696	Economy	16700.00
0005433368401	1696	Economy	16700.00
0005435654118	1696	Economy	16700.00
0005433368461	1696	Economy	16700.00
0005433368364	1696	Economy	16700.00
0005433368495	1696	Economy	16700.00
0005435654126	1696	Economy	16700.00
0005435654124	1696	Economy	16700.00
0005433368438	1696	Economy	16700.00
0005433368536	1696	Economy	16700.00
0005433368445	1696	Economy	16700.00
0005433368440	1696	Economy	16700.00
0005433368346	1696	Economy	16700.00
0005435654133	1696	Economy	16700.00
0005435654141	1696	Economy	16700.00
0005433368571	1696	Economy	16700.00
0005435654137	1696	Economy	16700.00
0005435654158	1696	Economy	16700.00
0005435654117	1696	Economy	16700.00
0005433368452	1696	Economy	16700.00
0005433368420	1696	Economy	16700.00
0005435654132	1696	Economy	16700.00
0005433368555	1696	Economy	16700.00
0005435654116	1696	Economy	16700.00
0005435654134	1696	Economy	16700.00
0005435654107	1696	Economy	16700.00
0005435654145	1696	Economy	16700.00
0005435654114	1696	Economy	16700.00
0005435654154	1696	Economy	16700.00
0005433368441	1696	Economy	16700.00
0005433368471	1696	Economy	16700.00
0005435654139	1696	Economy	16700.00
0005435654144	1696	Economy	16700.00
0005433368470	1696	Economy	16700.00
0005435654151	1696	Economy	16700.00
0005435654103	1696	Economy	16700.00
0005433368321	1696	Economy	16700.00
0005435654120	1696	Economy	16700.00
0005435654119	1696	Economy	16700.00
0005435654102	1696	Economy	16700.00
0005435654153	1696	Economy	16700.00
0005435654148	1696	Economy	16700.00
0005435654146	1696	Economy	16700.00
0005433368322	1696	Economy	16700.00
0005435654123	1696	Economy	16700.00
0005433368649	1696	Economy	16700.00
0005433368446	1696	Economy	16700.00
0005433368481	1696	Economy	16700.00
0005435654152	1696	Economy	16700.00
0005435654125	1696	Economy	16700.00
0005433368402	1696	Economy	16700.00
0005433368650	1696	Economy	16700.00
0005433368400	1696	Economy	16700.00
0005435654149	1696	Economy	16700.00
0005433368365	1696	Economy	16700.00
0005435654110	1696	Economy	16700.00
0005433368570	1696	Economy	16700.00
0005433368535	1696	Economy	16700.00
0005435654111	1696	Economy	16700.00
0005435654135	1696	Economy	16700.00
0005435654140	1696	Economy	16700.00
0005435654156	1696	Economy	16700.00
0005433368556	1696	Economy	16700.00
0005435654115	1696	Economy	16700.00
0005435654136	1696	Economy	16700.00
0005433368776	21722	Business	50000.00
0005433368775	21722	Business	50000.00
0005435653804	21722	Business	50000.00
0005435653665	21722	Business	50000.00
0005435653666	21722	Business	50000.00
0005435653700	21722	Business	50000.00
0005435653687	21722	Business	50000.00
0005433368788	21722	Business	50000.00
0005435653682	21722	Business	50000.00
0005433368783	21722	Business	50000.00
0005433368789	21722	Business	50000.00
0005435653630	21722	Economy	16700.00
0005433368777	21722	Economy	16700.00
0005433368772	21722	Economy	16700.00
0005435653688	21722	Economy	16700.00
0005433368763	21722	Economy	16700.00
0005435653806	21722	Economy	16700.00
0005435653771	21722	Economy	16700.00
0005435653741	21722	Economy	16700.00
0005435653641	21722	Economy	16700.00
0005433368756	21722	Economy	16700.00
0005435653578	21722	Economy	18300.00
0005433368759	21722	Economy	18300.00
0005435653649	21722	Economy	18300.00
0005435653647	21722	Economy	18300.00
0005435653775	21722	Economy	16700.00
0005433368770	21722	Economy	16700.00
0005435653782	21722	Economy	16700.00
0005433368782	21722	Economy	16700.00
0005435653681	21722	Economy	16700.00
0005435653803	21722	Economy	16700.00
0005433368757	21722	Economy	16700.00
0005435653699	21722	Economy	16700.00
0005435653608	21722	Economy	16700.00
0005433368754	21722	Economy	16700.00
0005433368767	21722	Economy	16700.00
0005435653754	21722	Economy	16700.00
0005435653651	21722	Economy	16700.00
0005435653781	21722	Economy	16700.00
0005433368761	21722	Economy	16700.00
0005433368785	21722	Economy	16700.00
0005433368771	21722	Economy	16700.00
0005435653693	21722	Economy	16700.00
0005435653607	21722	Economy	16700.00
0005433368766	21722	Economy	16700.00
0005433368787	21722	Economy	16700.00
0005433368779	21722	Economy	16700.00
0005433368778	21722	Economy	16700.00
0005435653648	21722	Economy	16700.00
0005433368753	21722	Economy	16700.00
0005433368762	21722	Economy	16700.00
0005435653617	21722	Economy	16700.00
0005433368755	21722	Economy	16700.00
0005433368769	21722	Economy	16700.00
0005435653805	21722	Economy	16700.00
0005433368760	21722	Economy	16700.00
0005435653517	21722	Economy	16700.00
0005433368764	21722	Economy	16700.00
0005433368781	21722	Economy	16700.00
0005435653735	21722	Economy	16700.00
0005433368768	21722	Economy	16700.00
0005435653622	21722	Economy	16700.00
0005433368765	21722	Economy	16700.00
0005433368784	21722	Economy	16700.00
0005435653807	21722	Economy	16700.00
0005435653577	21722	Economy	16700.00
0005435653610	21722	Economy	16700.00
0005435653535	21722	Economy	16700.00
0005435653664	21722	Economy	16700.00
0005433368758	21722	Economy	16700.00
0005435653640	21722	Economy	16700.00
0005435653740	21722	Economy	16700.00
0005435653606	21722	Economy	16700.00
0005435653565	21722	Economy	16700.00
0005435653623	21722	Economy	16700.00
0005435653620	21722	Economy	16700.00
0005433368774	21722	Economy	16700.00
0005433368773	21722	Economy	16700.00
0005435653892	21722	Economy	16700.00
0005433368752	21722	Economy	16700.00
0005433368780	21722	Economy	16700.00
0005433368786	21722	Economy	16700.00
0005435627123	12236	Economy	11200.00
0005435627125	12236	Economy	11200.00
0005435627124	12236	Economy	11200.00
0005433987044	4136	Business	21500.00
0005433987083	4136	Business	21500.00
0005433987054	4136	Business	21500.00
0005433987046	4136	Business	21500.00
0005433987072	4136	Business	21500.00
0005433987076	4136	Business	21500.00
0005433987081	4136	Business	21500.00
0005433987035	4136	Business	21500.00
0005433987068	4136	Business	21500.00
0005433987033	4136	Economy	7200.00
0005433987038	4136	Economy	7200.00
0005433987063	4136	Economy	7200.00
0005433987073	4136	Economy	7200.00
0005433987067	4136	Economy	7200.00
0005433987040	4136	Economy	7200.00
0005435788831	4136	Economy	7900.00
0005433987079	4136	Economy	7200.00
0005433987053	4136	Economy	7200.00
0005433987056	4136	Economy	7200.00
0005435788832	4136	Economy	7200.00
0005433987036	4136	Economy	7200.00
0005433987066	4136	Economy	7200.00
0005433987041	4136	Economy	7200.00
0005435788833	4136	Economy	7200.00
0005433987060	4136	Economy	7200.00
0005433987048	4136	Economy	7200.00
0005433987070	4136	Economy	7200.00
0005433987055	4136	Economy	7200.00
0005433987039	4136	Economy	7200.00
0005433987077	4136	Economy	7200.00
0005433987085	4136	Economy	7200.00
0005433987049	4136	Economy	7200.00
0005433987074	4136	Economy	7200.00
0005433987037	4136	Economy	7200.00
0005433987032	4136	Economy	7200.00
0005433987061	4136	Economy	7200.00
0005433987051	4136	Economy	7200.00
0005433987084	4136	Economy	7200.00
0005433987062	4136	Economy	7200.00
0005433987050	4136	Economy	7200.00
0005433987064	4136	Economy	7200.00
0005433987071	4136	Economy	7200.00
0005433987059	4136	Economy	7200.00
0005433987052	4136	Economy	7200.00
0005433987047	4136	Economy	7200.00
0005433987080	4136	Economy	7200.00
0005433987058	4136	Economy	7200.00
0005433987065	4136	Economy	7200.00
0005433987069	4136	Economy	7200.00
0005433987045	4136	Economy	7200.00
0005433987075	4136	Economy	7200.00
0005433987078	4136	Economy	7200.00
0005433987042	4136	Economy	7200.00
0005435788835	4136	Economy	7200.00
0005435788834	4136	Economy	7200.00
0005433987034	4136	Economy	7200.00
0005433987031	4136	Economy	7200.00
0005433987057	4136	Economy	7200.00
0005433987043	4136	Economy	7200.00
0005433987086	4136	Economy	7200.00
0005433987082	4136	Economy	7200.00
0005433986625	25682	Business	21500.00
0005433986618	25682	Business	21500.00
0005433986574	25682	Business	21500.00
0005433986638	25682	Business	21500.00
0005433986572	25682	Economy	7200.00
0005433986786	25682	Economy	7200.00
0005433986737	25682	Economy	7200.00
0005433986633	25682	Economy	7200.00
0005433986686	25682	Economy	7900.00
0005433986613	25682	Economy	7900.00
0005433986573	25682	Economy	7200.00
0005433986605	25682	Economy	7200.00
0005433986451	25682	Economy	7200.00
0005433986526	25682	Economy	7200.00
0005433986577	25682	Economy	7200.00
0005433986661	25682	Economy	7200.00
0005433986644	25682	Economy	7200.00
0005433986610	25682	Economy	7200.00
0005433986609	25682	Economy	7200.00
0005433986486	25682	Economy	7200.00
0005433986548	25682	Economy	7200.00
0005433986667	25682	Economy	7200.00
0005433986452	25682	Economy	7200.00
0005433986791	25682	Economy	7200.00
0005433986518	25682	Economy	7200.00
0005433986617	25682	Economy	7200.00
0005433986472	25682	Economy	7200.00
0005433986575	25682	Economy	7200.00
0005433986542	25682	Economy	7200.00
0005433986517	25682	Economy	7200.00
0005433986468	25682	Economy	7200.00
0005433986552	25682	Economy	7200.00
0005433986623	25682	Economy	7200.00
0005433986723	25682	Economy	7200.00
0005433986660	25682	Economy	7200.00
0005433986473	25682	Economy	7200.00
0005433986545	25682	Economy	7200.00
0005433986516	25682	Economy	7200.00
0005433986566	25682	Economy	7200.00
0005433986576	25682	Economy	7200.00
0005433986487	25682	Economy	7200.00
0005433986704	25682	Economy	7200.00
0005433986600	25682	Economy	7200.00
0005433986550	25682	Economy	7200.00
0005433986710	25682	Economy	7200.00
0005433986484	25682	Economy	7200.00
0005433986549	25682	Economy	7200.00
0005433986749	25682	Economy	7200.00
0005433986724	25682	Economy	7200.00
0005433986691	25682	Economy	7200.00
0005433986578	25682	Economy	7200.00
0005433986538	25682	Economy	7200.00
0005433986685	25682	Economy	7200.00
0005433986670	25682	Economy	7200.00
0005433986636	25682	Economy	7200.00
0005433986736	25682	Economy	7200.00
0005433986544	25682	Economy	7200.00
0005435720836	21281	Economy	9400.00
0005435720841	21281	Economy	9400.00
0005435719588	24755	Economy	9400.00
0005435719587	24755	Economy	9400.00
0005435720156	24755	Economy	9400.00
0005435719589	24755	Economy	9400.00
0005433168472	21315	Economy	17000.00
0005433168471	21315	Economy	17000.00
0005434509249	21315	Economy	15500.00
0005434509270	21315	Economy	15500.00
0005433168464	21315	Economy	15500.00
0005434509250	21315	Economy	15500.00
0005434509271	21315	Economy	15500.00
0005434509275	21315	Economy	15500.00
0005434509277	21315	Economy	15500.00
0005433168470	21315	Economy	15500.00
0005434509247	21315	Economy	15500.00
0005433168468	21315	Economy	15500.00
0005434509272	21315	Economy	15500.00
0005434509303	21315	Economy	15500.00
0005433168465	21315	Economy	15500.00
0005433168467	21315	Economy	15500.00
0005433168462	21315	Economy	15500.00
0005434509248	21315	Economy	15500.00
0005434509262	21315	Economy	15500.00
0005433168463	21315	Economy	15500.00
0005433168473	21315	Economy	15500.00
0005434509239	21315	Economy	15500.00
0005434509252	21315	Economy	15500.00
0005434509264	21315	Economy	15500.00
0005434509293	21315	Economy	15500.00
0005433168466	21315	Economy	15500.00
0005433168461	21315	Economy	15500.00
0005433168469	21315	Economy	15500.00
0005434509273	21315	Economy	15500.00
0005434509292	21315	Economy	15500.00
0005434509291	21315	Economy	15500.00
0005434509244	21315	Economy	15500.00
0005434509299	21315	Economy	15500.00
0005434509261	21315	Economy	15500.00
0005434509279	21315	Economy	15500.00
0005432655639	17815	Business	18000.00
0005432655658	17815	Business	18000.00
0005432655707	17815	Business	18000.00
0005432869688	17815	Business	18000.00
0005432660854	17815	Business	18000.00
0005432665304	17815	Business	18000.00
0005432655632	17815	Business	18000.00
0005432657482	17815	Business	18000.00
0005432869684	17815	Economy	6000.00
0005432869683	17815	Economy	6000.00
0005432658626	17815	Economy	6000.00
0005432660851	17815	Economy	6000.00
0005432665313	17815	Economy	6600.00
0005432655711	17815	Economy	6600.00
0005432658627	17815	Economy	6600.00
0005432665303	17815	Economy	6000.00
0005432655677	17815	Economy	6000.00
0005432655657	17815	Economy	6000.00
0005434151779	17815	Economy	6000.00
0005432869687	17815	Economy	6000.00
0005432665305	17815	Economy	6000.00
0005432655682	17815	Economy	6000.00
0005432660853	17815	Economy	6000.00
0005432655702	17815	Economy	6000.00
0005432660855	17815	Economy	6000.00
0005432655683	17815	Economy	6000.00
0005432666416	17815	Economy	6000.00
0005434151777	17815	Economy	6000.00
0005432665302	17815	Economy	6000.00
0005432869686	17815	Economy	6000.00
0005432663059	17815	Economy	6000.00
0005432657483	17815	Economy	6000.00
0005432869682	17815	Economy	6000.00
0005432655701	17815	Economy	6000.00
0005434151778	17815	Economy	6000.00
0005432655640	17815	Economy	6000.00
0005432655676	17815	Economy	6000.00
0005432657480	17815	Economy	6000.00
0005432655680	17815	Economy	6000.00
0005434151776	17815	Economy	6000.00
0005432655663	17815	Economy	6000.00
0005432655744	17815	Economy	6000.00
0005432869685	17815	Economy	6000.00
0005432655745	17815	Economy	6000.00
0005434151775	17815	Economy	6000.00
0005432658612	17815	Economy	6000.00
0005432655681	17815	Economy	6000.00
0005432661952	17815	Economy	6000.00
0005432655794	26323	Business	18000.00
0005432665323	26323	Business	18000.00
0005432667503	26323	Business	18000.00
0005434151755	26323	Business	18000.00
0005432666436	26323	Business	18000.00
0005432657518	26323	Business	18000.00
0005432665320	26323	Economy	6000.00
0005432655803	26323	Economy	6600.00
0005432655801	26323	Economy	6000.00
0005432665322	26323	Economy	6000.00
0005432655797	26323	Economy	6000.00
0005434151747	26323	Economy	6000.00
0005432667501	26323	Economy	6000.00
0005432658638	26323	Economy	6000.00
0005432665321	26323	Economy	6000.00
0005432655802	26323	Economy	6000.00
0005432660865	26323	Economy	6000.00
0005432657519	26323	Economy	6000.00
0005434151756	26323	Economy	6000.00
0005432658637	26323	Economy	6000.00
0005432666435	26323	Economy	6000.00
0005432655800	26323	Economy	6000.00
0005432658639	26323	Economy	6000.00
0005432657517	26323	Economy	6000.00
0005432655792	26323	Economy	6000.00
0005432655791	26323	Economy	6000.00
0005434151745	26323	Economy	6000.00
0005432655793	26323	Economy	6000.00
0005432660864	26323	Economy	6000.00
0005434151746	26323	Economy	6000.00
0005434151744	26323	Economy	6000.00
0005432655799	26323	Economy	6000.00
0005432655790	26323	Economy	6000.00
0005432659753	26323	Economy	6000.00
0005432655795	26323	Economy	6000.00
0005432667502	26323	Economy	6000.00
0005432869598	26323	Economy	6000.00
0005432655798	26323	Economy	6000.00
0005432667500	26323	Economy	6000.00
0005432655796	26323	Economy	6000.00
0005432329810	3074	Business	16100.00
0005432329795	3074	Business	16100.00
0005433439039	3074	Business	16100.00
0005432329775	3074	Business	16100.00
0005433439040	3074	Business	16100.00
0005432329772	3074	Business	16100.00
0005432329788	3074	Business	16100.00
0005432329804	3074	Business	16100.00
0005432329803	3074	Economy	5400.00
0005432905219	3074	Economy	5400.00
0005433439041	3074	Economy	5400.00
0005432329779	3074	Economy	5400.00
0005433439033	3074	Economy	5400.00
0005432329799	3074	Economy	5400.00
0005432329811	3074	Economy	5400.00
0005432329791	3074	Economy	5400.00
0005432329780	3074	Economy	5400.00
0005432329777	3074	Economy	5900.00
0005432287310	3074	Economy	5900.00
0005432287311	3074	Economy	5900.00
0005433439032	3074	Economy	5400.00
0005432329808	3074	Economy	5400.00
0005432329786	3074	Economy	5400.00
0005432848844	3074	Economy	5400.00
0005432329809	3074	Economy	5400.00
0005432329801	3074	Economy	5400.00
0005433439034	3074	Economy	5400.00
0005432287309	3074	Economy	5400.00
0005432329773	3074	Economy	5400.00
0005433439030	3074	Economy	5400.00
0005432329790	3074	Economy	5400.00
0005432329798	3074	Economy	5400.00
0005432905221	3074	Economy	5400.00
0005433439035	3074	Economy	5400.00
0005433439036	3074	Economy	5400.00
0005432329769	3074	Economy	5400.00
0005432905215	3074	Economy	5400.00
0005432329789	3074	Economy	5400.00
0005433439031	3074	Economy	5400.00
0005433439037	3074	Economy	5400.00
0005432329806	3074	Economy	5400.00
0005432329813	3074	Economy	5400.00
0005432329771	3074	Economy	5400.00
0005432329800	3074	Economy	5400.00
0005432329794	3074	Economy	5400.00
0005432329784	3074	Economy	5400.00
0005432329776	3074	Economy	5400.00
0005432329781	3074	Economy	5400.00
0005432287308	3074	Economy	5400.00
0005432329807	3074	Economy	5400.00
0005432329778	3074	Economy	5400.00
0005432329812	3074	Economy	5400.00
0005432905214	3074	Economy	5400.00
0005432329797	3074	Economy	5400.00
0005433439038	3074	Economy	5400.00
0005432329787	3074	Economy	5400.00
0005432329805	3074	Economy	5400.00
0005433439042	3074	Economy	5400.00
0005432329792	3074	Economy	5400.00
0005432329774	3074	Economy	5400.00
0005432329802	3074	Economy	5400.00
0005432329793	3074	Economy	5400.00
0005432329770	3074	Economy	5400.00
0005432329796	3074	Economy	5400.00
0005432287312	3074	Economy	5400.00
0005432329783	3074	Economy	5400.00
0005432329785	3074	Economy	5400.00
0005432329782	3074	Economy	5400.00
0005432329499	31151	Business	16100.00
0005432329480	31151	Business	16100.00
0005432329196	31151	Business	16100.00
0005432329260	31151	Business	16100.00
0005432329299	31151	Business	16100.00
0005432329588	31151	Business	16100.00
0005432329428	31151	Business	16100.00
0005432329381	31151	Business	16100.00
0005432329398	31151	Business	16100.00
0005432329379	31151	Economy	5400.00
0005432329456	31151	Economy	5400.00
0005432905261	31151	Economy	5400.00
0005432905260	31151	Economy	5400.00
0005432329306	31151	Economy	5400.00
0005432905259	31151	Economy	5400.00
0005432329473	31151	Economy	5400.00
0005432329380	31151	Economy	5900.00
0005432329364	31151	Economy	5900.00
0005432329317	31151	Economy	5900.00
0005432329217	31151	Economy	5900.00
0005432329091	31151	Economy	5900.00
0005432329256	31151	Economy	5400.00
0005432329099	31151	Economy	5400.00
0005432054373	31151	Economy	5400.00
0005432329419	31151	Economy	5400.00
0005432905262	31151	Economy	5400.00
0005432905263	31151	Economy	5400.00
0005432329396	31151	Economy	5400.00
0005432329394	31151	Economy	5400.00
0005432329366	31151	Economy	5400.00
0005432329479	31151	Economy	5400.00
0005432329257	31151	Economy	5400.00
0005432329316	31151	Economy	5400.00
0005432329304	31151	Economy	5400.00
0005432329367	31151	Economy	5400.00
0005432329347	31151	Economy	5400.00
0005432329100	31151	Economy	5400.00
0005432329195	31151	Economy	5400.00
0005432329220	31151	Economy	5400.00
0005432329433	31151	Economy	5400.00
0005432329348	31151	Economy	5400.00
0005432329429	31151	Economy	5400.00
0005432905265	31151	Economy	5400.00
0005432329498	31151	Economy	5400.00
0005432329213	31151	Economy	5400.00
0005432329319	31151	Economy	5400.00
0005432329321	31151	Economy	5400.00
0005432329276	31151	Economy	5400.00
0005432329130	31151	Economy	5400.00
0005432329305	31151	Economy	5400.00
0005432329395	31151	Economy	5400.00
0005432329303	31151	Economy	5400.00
0005432329351	31151	Economy	5400.00
0005432329077	31151	Economy	5400.00
0005432329337	31151	Economy	5400.00
0005432329399	31151	Economy	5400.00
0005432054374	31151	Economy	5400.00
0005432054375	31151	Economy	5400.00
0005432329283	31151	Economy	5400.00
0005432905264	31151	Economy	5400.00
0005432329365	31151	Economy	5400.00
0005432329338	31151	Economy	5400.00
0005432329363	31151	Economy	5400.00
0005432329320	31151	Economy	5400.00
0005432329421	31151	Economy	5400.00
0005435488119	6186	Business	124600.00
0005435488068	6186	Business	124600.00
0005435999694	6186	Business	124600.00
0005435999683	6186	Business	124600.00
0005434310069	6186	Business	124600.00
0005435999685	6186	Economy	41500.00
0005434310066	6186	Economy	41500.00
0005435488115	6186	Economy	41500.00
0005435297160	6186	Economy	41500.00
0005435488102	6186	Economy	41500.00
0005435297180	6186	Economy	41500.00
0005435488217	6186	Economy	41500.00
0005434310073	6186	Economy	41500.00
0005434310064	6186	Economy	41500.00
0005435999677	6186	Economy	41500.00
0005432146249	6186	Economy	41500.00
0005434310065	6186	Economy	41500.00
0005432146248	6186	Economy	41500.00
0005435999692	6186	Economy	41500.00
0005435999681	6186	Economy	41500.00
0005435999682	6186	Economy	41500.00
0005434310070	6186	Economy	41500.00
0005435999690	6186	Economy	41500.00
0005435488140	6186	Economy	41500.00
0005435488218	6186	Economy	41500.00
0005435999674	6186	Economy	41500.00
0005435297165	6186	Economy	41500.00
0005435999688	6186	Economy	41500.00
0005435488107	6186	Economy	41500.00
0005435297153	6186	Economy	45700.00
0005435999673	6186	Economy	45700.00
0005435488144	6186	Economy	45700.00
0005435999678	6186	Economy	41500.00
0005435999693	6186	Economy	41500.00
0005435488149	6186	Economy	41500.00
0005435488053	6186	Economy	41500.00
0005434310074	6186	Economy	41500.00
0005435297152	6186	Economy	41500.00
0005434310063	6186	Economy	41500.00
0005434310067	6186	Economy	41500.00
0005432146250	6186	Economy	41500.00
0005435999680	6186	Economy	41500.00
0005435999675	6186	Economy	41500.00
0005435297168	6186	Economy	41500.00
0005435488108	6186	Economy	41500.00
0005435488246	6186	Economy	41500.00
0005435297169	6186	Economy	41500.00
0005435297161	6186	Economy	41500.00
0005435999671	6186	Economy	41500.00
0005435999676	6186	Economy	41500.00
0005435488145	6186	Economy	41500.00
0005435297166	6186	Economy	41500.00
0005435999691	6186	Economy	41500.00
0005435999687	6186	Economy	41500.00
0005435999684	6186	Economy	41500.00
0005435297164	6186	Economy	41500.00
0005435999679	6186	Economy	41500.00
0005435297167	6186	Economy	41500.00
0005434310062	6186	Economy	41500.00
0005435488147	6186	Economy	41500.00
0005435488146	6186	Economy	41500.00
0005435488157	6186	Economy	41500.00
0005435999696	6186	Economy	41500.00
0005435297149	6186	Economy	41500.00
0005434310071	6186	Economy	41500.00
0005435488054	6186	Economy	41500.00
0005435488156	6186	Economy	41500.00
0005435999695	6186	Economy	41500.00
0005435297162	6186	Economy	41500.00
0005435999686	6186	Economy	41500.00
0005435297151	6186	Economy	41500.00
0005435999689	6186	Economy	41500.00
0005435999697	6186	Economy	41500.00
0005434310072	6186	Economy	41500.00
0005435488148	6186	Economy	41500.00
0005435999672	6186	Economy	41500.00
0005434310068	6186	Economy	41500.00
0005435999484	19564	Business	124600.00
0005434309981	19564	Business	124600.00
0005435488324	19564	Economy	41500.00
0005435999492	19564	Economy	41500.00
0005435488323	19564	Economy	41500.00
0005435999491	19564	Economy	41500.00
0005434309914	19564	Economy	41500.00
0005435488337	19564	Economy	41500.00
0005435488328	19564	Economy	41500.00
0005435297224	19564	Economy	41500.00
0005434309937	19564	Economy	41500.00
0005435488325	19564	Economy	41500.00
0005435488335	19564	Economy	41500.00
0005435297225	19564	Economy	41500.00
0005434309940	19564	Economy	41500.00
0005435297220	19564	Economy	41500.00
0005435488336	19564	Economy	41500.00
0005435297221	19564	Economy	41500.00
0005434309913	19564	Economy	41500.00
0005435488331	19564	Economy	41500.00
0005435999476	19564	Economy	41500.00
0005435999395	19564	Economy	41500.00
0005435488319	19564	Economy	45700.00
0005435999407	19564	Economy	45700.00
0005435999466	19564	Economy	41500.00
0005435999490	19564	Economy	41500.00
0005434309885	19564	Economy	41500.00
0005435488330	19564	Economy	41500.00
0005435297223	19564	Economy	41500.00
0005434309958	19564	Economy	41500.00
0005435297222	19564	Economy	41500.00
0005435488333	19564	Economy	41500.00
0005435999463	19564	Economy	41500.00
0005435488326	19564	Economy	41500.00
0005434309920	19564	Economy	41500.00
0005435999445	19564	Economy	41500.00
0005435999493	19564	Economy	41500.00
0005435488320	19564	Economy	41500.00
0005435488334	19564	Economy	41500.00
0005434309923	19564	Economy	41500.00
0005435488321	19564	Economy	41500.00
0005435488338	19564	Economy	41500.00
0005434309938	19564	Economy	41500.00
0005435488332	19564	Economy	41500.00
0005434309936	19564	Economy	41500.00
0005435488339	19564	Economy	41500.00
0005435488322	19564	Economy	41500.00
0005434309959	19564	Economy	41500.00
0005435488327	19564	Economy	41500.00
0005434309996	19564	Economy	41500.00
0005435999424	19564	Economy	41500.00
0005435297219	19564	Economy	41500.00
0005435488329	19564	Economy	41500.00
0005434566233	1600	Business	86000.00
0005435502827	1600	Business	86000.00
0005434566236	1600	Business	86000.00
0005435508687	1600	Business	86000.00
0005435502837	1600	Business	86000.00
0005435502831	1600	Business	86000.00
0005435508693	1600	Business	86000.00
0005435518348	1600	Business	86000.00
0005435502826	1600	Business	86000.00
0005435518335	1600	Business	86000.00
0005435502823	1600	Business	86000.00
0005435502830	1600	Economy	28700.00
0005435518333	1600	Economy	28700.00
0005435518334	1600	Economy	28700.00
0005435508684	1600	Economy	28700.00
0005435518339	1600	Economy	28700.00
0005435518338	1600	Economy	28700.00
0005433186276	1600	Economy	28700.00
0005433186193	1600	Economy	28700.00
0005434566235	1600	Economy	31500.00
0005433186289	1600	Economy	31500.00
0005435502829	1600	Economy	31500.00
0005435518341	1600	Economy	31500.00
0005433186288	1600	Economy	31500.00
0005435518342	1600	Economy	28700.00
0005435518337	1600	Economy	28700.00
0005433186290	1600	Economy	28700.00
0005435518345	1600	Economy	28700.00
0005435508699	1600	Economy	28700.00
0005435502820	1600	Economy	28700.00
0005435518332	1600	Economy	28700.00
0005435508701	1600	Economy	28700.00
0005435508691	1600	Economy	28700.00
0005435502834	1600	Economy	28700.00
0005435518344	1600	Economy	28700.00
0005435508697	1600	Economy	28700.00
0005435508704	1600	Economy	28700.00
0005435508694	1600	Economy	28700.00
0005433186241	1600	Economy	28700.00
0005434566231	1600	Economy	28700.00
0005435502828	1600	Economy	28700.00
0005435508700	1600	Economy	28700.00
0005435508698	1600	Economy	28700.00
0005434566240	1600	Economy	28700.00
0005435508689	1600	Economy	28700.00
0005435518340	1600	Economy	28700.00
0005433186242	1600	Economy	28700.00
0005435508688	1600	Economy	28700.00
0005435508690	1600	Economy	28700.00
0005433186219	1600	Economy	28700.00
0005435508686	1600	Economy	28700.00
0005435502821	1600	Economy	28700.00
0005435508703	1600	Economy	28700.00
0005435502824	1600	Economy	28700.00
0005435508702	1600	Economy	28700.00
0005435502838	1600	Economy	28700.00
0005435518336	1600	Economy	28700.00
0005435518347	1600	Economy	28700.00
0005433186248	1600	Economy	28700.00
0005435518346	1600	Economy	28700.00
0005434566239	1600	Economy	28700.00
0005432291989	1600	Economy	28700.00
0005435508692	1600	Economy	28700.00
0005435502833	1600	Economy	28700.00
0005434566241	1600	Economy	28700.00
0005434566232	1600	Economy	28700.00
0005434566234	1600	Economy	28700.00
0005434566238	1600	Economy	28700.00
0005435502818	1600	Economy	28700.00
0005435508705	1600	Economy	28700.00
0005434566229	1600	Economy	28700.00
0005435502825	1600	Economy	28700.00
0005435502832	1600	Economy	28700.00
0005433186243	1600	Economy	28700.00
0005435502836	1600	Economy	28700.00
0005435518343	1600	Economy	28700.00
0005433186229	1600	Economy	28700.00
0005434566237	1600	Economy	28700.00
0005435508685	1600	Economy	28700.00
0005435508706	1600	Economy	28700.00
0005435502822	1600	Economy	28700.00
0005435502819	1600	Economy	28700.00
0005435508696	1600	Economy	28700.00
0005435502839	1600	Economy	28700.00
0005435502835	1600	Economy	28700.00
0005434566230	1600	Economy	28700.00
0005435518331	1600	Economy	28700.00
0005435508695	1600	Economy	28700.00
0005435529517	20898	Business	86000.00
0005433186324	20898	Business	86000.00
0005433186323	20898	Business	86000.00
0005435529581	20898	Business	86000.00
0005435529571	20898	Business	86000.00
0005434566117	20898	Business	86000.00
0005435502579	20898	Business	86000.00
0005434566164	20898	Business	86000.00
0005435529439	20898	Economy	28700.00
0005435502643	20898	Economy	28700.00
0005435529594	20898	Economy	28700.00
0005433186325	20898	Economy	28700.00
0005435502627	20898	Economy	28700.00
0005435529523	20898	Economy	28700.00
0005435529441	20898	Economy	28700.00
0005435502644	20898	Economy	31500.00
0005435502591	20898	Economy	31500.00
0005435502595	20898	Economy	31500.00
0005435529595	20898	Economy	31500.00
0005435529570	20898	Economy	28700.00
0005435529546	20898	Economy	28700.00
0005435502544	20898	Economy	28700.00
0005435502703	20898	Economy	28700.00
0005434566099	20898	Economy	28700.00
0005435502577	20898	Economy	28700.00
0005435529652	20898	Economy	28700.00
0005435502566	20898	Economy	28700.00
0005435529553	20898	Economy	28700.00
0005435502646	20898	Economy	28700.00
0005435529535	20898	Economy	28700.00
0005435529573	20898	Economy	28700.00
0005434566050	20898	Economy	28700.00
0005435529557	20898	Economy	28700.00
0005435502651	20898	Economy	28700.00
0005434566119	20898	Economy	28700.00
0005435529558	20898	Economy	28700.00
0005433186326	20898	Economy	28700.00
0005433186319	20898	Economy	28700.00
0005435502578	20898	Economy	28700.00
0005435529440	20898	Economy	28700.00
0005435529502	20898	Economy	28700.00
0005435545802	20898	Economy	28700.00
0005435529514	20898	Economy	28700.00
0005435502573	20898	Economy	28700.00
0005435529524	20898	Economy	28700.00
0005435502590	20898	Economy	28700.00
0005433186322	20898	Economy	28700.00
0005435529552	20898	Economy	28700.00
0005434566042	20898	Economy	28700.00
0005435502702	20898	Economy	28700.00
0005435529483	20898	Economy	28700.00
0005435502533	20898	Economy	28700.00
0005434566150	20898	Economy	28700.00
0005434566098	20898	Economy	28700.00
0005435545847	20898	Economy	28700.00
0005435529569	20898	Economy	28700.00
0005435545846	20898	Economy	28700.00
0005433186321	20898	Economy	28700.00
0005435545848	20898	Economy	28700.00
0005434566051	20898	Economy	28700.00
0005435502748	20898	Economy	28700.00
0005435502680	20898	Economy	28700.00
0005435529438	20898	Economy	28700.00
0005435529534	20898	Economy	28700.00
0005435502639	20898	Economy	28700.00
0005434566144	20898	Economy	28700.00
0005433186320	20898	Economy	28700.00
0005435502631	20898	Economy	28700.00
0005435529518	20898	Economy	28700.00
0005435502637	20898	Economy	28700.00
0005434566180	20898	Economy	28700.00
0005434566120	20898	Economy	28700.00
0005435142982	3889	Economy	21600.00
0005435931662	3889	Economy	19700.00
0005435153900	3889	Economy	19700.00
0005435931641	3889	Economy	19700.00
0005435153901	3889	Economy	19700.00
0005435153897	3889	Economy	19700.00
0005435931661	3889	Economy	19700.00
0005435931664	3889	Economy	19700.00
0005435153899	3889	Economy	19700.00
0005435142983	3889	Economy	19700.00
0005435931663	3889	Economy	19700.00
0005435142981	3889	Economy	19700.00
0005435153898	3889	Economy	19700.00
0005435153902	3889	Economy	19700.00
0005435153896	3889	Economy	19700.00
0005435931691	21887	Economy	21600.00
0005435153818	21887	Economy	21600.00
0005435153832	21887	Economy	19700.00
0005435931692	21887	Economy	19700.00
0005435153844	21887	Economy	19700.00
0005435153839	21887	Economy	19700.00
0005435153817	21887	Economy	19700.00
0005435153863	21887	Economy	19700.00
0005435153840	21887	Economy	19700.00
0005435153819	21887	Economy	19700.00
0005435153820	21887	Economy	19700.00
0005435153862	21887	Economy	19700.00
0005432629202	7171	Economy	14300.00
0005435225674	7171	Economy	13000.00
0005432629205	7171	Economy	13000.00
0005435225710	7171	Economy	13000.00
0005432629199	7171	Economy	13000.00
0005435225709	7171	Economy	13000.00
0005432629198	7171	Economy	13000.00
0005432629201	7171	Economy	13000.00
0005435225743	7171	Economy	13000.00
0005432629200	7171	Economy	13000.00
0005432629196	7171	Economy	13000.00
0005432629195	7171	Economy	13000.00
0005432629193	7171	Economy	13000.00
0005432629206	7171	Economy	13000.00
0005435225708	7171	Economy	13000.00
0005432629204	7171	Economy	13000.00
0005432629194	7171	Economy	13000.00
0005435225724	7171	Economy	13000.00
0005432629203	7171	Economy	13000.00
0005432629192	7171	Economy	13000.00
0005435225745	7171	Economy	13000.00
0005432629197	7171	Economy	13000.00
0005435225698	7171	Economy	13000.00
0005435225723	7171	Economy	13000.00
0005435225776	28108	Economy	14300.00
0005432629118	28108	Economy	14300.00
0005435225777	28108	Economy	14300.00
0005432629147	28108	Economy	13000.00
0005432629084	28108	Economy	13000.00
0005432629100	28108	Economy	13000.00
0005432629057	28108	Economy	13000.00
0005432629119	28108	Economy	13000.00
0005432629124	28108	Economy	13000.00
0005432629058	28108	Economy	13000.00
0005432629174	28108	Economy	13000.00
0005435225774	28108	Economy	13000.00
0005432629123	28108	Economy	13000.00
0005435225775	28108	Economy	13000.00
0005432629148	28108	Economy	13000.00
0005435225778	28108	Economy	13000.00
0005432629173	28108	Economy	13000.00
0005432629125	28108	Economy	13000.00
0005435225773	28108	Economy	13000.00
0005432629157	28108	Economy	13000.00
0005434267995	8750	Economy	10500.00
0005435960141	8750	Economy	10500.00
0005435960143	8750	Economy	10500.00
0005435960142	8750	Economy	10500.00
0005434268038	15241	Economy	10500.00
0005434268041	15241	Economy	10500.00
0005434268039	15241	Economy	10500.00
0005435960098	15241	Economy	10500.00
0005434268040	15241	Economy	10500.00
0005432675490	1193	Business	115000.00
0005432675491	1193	Business	115000.00
0005432693767	1193	Business	115000.00
0005432693784	1193	Business	115000.00
0005432675493	1193	Business	115000.00
0005432675495	1193	Business	115000.00
0005432693760	1193	Business	115000.00
0005432693786	1193	Business	115000.00
0005432693758	1193	Business	115000.00
0005432873404	1193	Business	115000.00
0005432693762	1193	Economy	38300.00
0005432693759	1193	Economy	38300.00
0005432873395	1193	Economy	38300.00
0005432693774	1193	Economy	38300.00
0005432693783	1193	Economy	38300.00
0005432693771	1193	Economy	38300.00
0005432675487	1193	Economy	42200.00
0005432693782	1193	Economy	38300.00
0005432693764	1193	Economy	38300.00
0005432693785	1193	Economy	38300.00
0005432693776	1193	Economy	38300.00
0005432677663	1193	Economy	38300.00
0005432693778	1193	Economy	38300.00
0005432693763	1193	Economy	38300.00
0005432693781	1193	Economy	38300.00
0005432675500	1193	Economy	38300.00
0005432693768	1193	Economy	38300.00
0005432675489	1193	Economy	38300.00
0005432675494	1193	Economy	38300.00
0005432693770	1193	Economy	38300.00
0005432675488	1193	Economy	38300.00
0005432693765	1193	Economy	38300.00
0005432693766	1193	Economy	38300.00
0005432675498	1193	Economy	38300.00
0005432675497	1193	Economy	38300.00
0005432677664	1193	Economy	38300.00
0005432873403	1193	Economy	38300.00
0005432693761	1193	Economy	38300.00
0005432693779	1193	Economy	38300.00
0005432873382	1193	Economy	38300.00
0005432693772	1193	Economy	38300.00
0005432693775	1193	Economy	38300.00
0005432675492	1193	Economy	38300.00
0005432693769	1193	Economy	38300.00
0005432693773	1193	Economy	38300.00
0005432675486	1193	Economy	38300.00
0005432693777	1193	Economy	38300.00
0005432677665	1193	Economy	38300.00
0005432675499	1193	Economy	38300.00
0005432677662	1193	Economy	38300.00
0005432693780	1193	Economy	38300.00
0005432675501	1193	Economy	38300.00
0005432675496	1193	Economy	38300.00
0005432675337	17504	Business	115000.00
0005432693583	17504	Business	115000.00
0005432675379	17504	Business	115000.00
0005432677617	17504	Business	115000.00
0005432675344	17504	Business	115000.00
0005432675383	17504	Business	115000.00
0005432693558	17504	Business	115000.00
0005432693443	17504	Business	115000.00
0005432675327	17504	Business	115000.00
0005432677625	17504	Business	115000.00
0005432675366	17504	Business	115000.00
0005432677620	17504	Business	115000.00
0005432693410	17504	Business	115000.00
0005432675352	17504	Business	115000.00
0005432693616	17504	Economy	38300.00
0005432693572	17504	Economy	38300.00
0005432693512	17504	Economy	38300.00
0005432693358	17504	Economy	38300.00
0005432677635	17504	Economy	38300.00
0005432873458	17504	Economy	38300.00
0005432693568	17504	Economy	38300.00
0005432693567	17504	Economy	38300.00
0005432693468	17504	Economy	38300.00
0005432677633	17504	Economy	42200.00
0005432693442	17504	Economy	42200.00
0005432693535	17504	Economy	42200.00
0005432677614	17504	Economy	42200.00
0005432675315	17504	Economy	38300.00
0005432693454	17504	Economy	38300.00
0005432693560	17504	Economy	38300.00
0005432693464	17504	Economy	38300.00
0005432693652	17504	Economy	38300.00
0005432675329	17504	Economy	38300.00
0005432675394	17504	Economy	38300.00
0005432693477	17504	Economy	38300.00
0005432873461	17504	Economy	38300.00
0005432693534	17504	Economy	38300.00
0005432873464	17504	Economy	38300.00
0005432693561	17504	Economy	38300.00
0005432693478	17504	Economy	38300.00
0005432693548	17504	Economy	38300.00
0005432675380	17504	Economy	38300.00
0005432693542	17504	Economy	38300.00
0005432675328	17504	Economy	38300.00
0005432675303	17504	Economy	38300.00
0005432693455	17504	Economy	38300.00
0005432675384	17504	Economy	38300.00
0005432873459	17504	Economy	38300.00
0005432677630	17504	Economy	38300.00
0005432693401	17504	Economy	38300.00
0005432873460	17504	Economy	38300.00
0005432677648	17504	Economy	38300.00
0005432693409	17504	Economy	38300.00
0005432693465	17504	Economy	38300.00
0005432873463	17504	Economy	38300.00
0005432693559	17504	Economy	38300.00
0005432693357	17504	Economy	38300.00
0005432675374	17504	Economy	38300.00
0005432675343	17504	Economy	38300.00
0005432693594	17504	Economy	38300.00
0005432675350	17504	Economy	38300.00
0005432677634	17504	Economy	38300.00
0005432677636	17504	Economy	38300.00
0005432693475	17504	Economy	38300.00
0005432693547	17504	Economy	38300.00
0005432693402	17504	Economy	38300.00
0005432873462	17504	Economy	38300.00
0005432675372	17504	Economy	38300.00
0005432675304	17504	Economy	38300.00
0005432693517	17504	Economy	38300.00
0005432675362	17504	Economy	38300.00
0005432693467	17504	Economy	38300.00
0005432675393	17504	Economy	38300.00
0005432675422	17504	Economy	38300.00
0005432675339	17504	Economy	38300.00
0005432675373	17504	Economy	38300.00
0005432675365	17504	Economy	38300.00
0005432693557	17504	Economy	38300.00
0005432693544	17504	Economy	38300.00
0005432693519	17504	Economy	38300.00
0005432675367	17504	Economy	38300.00
0005432693518	17504	Economy	38300.00
0005432675421	17504	Economy	38300.00
0005434435544	1100	Economy	15200.00
0005434435550	1100	Economy	15200.00
0005434435543	1100	Economy	15200.00
0005433156899	1100	Economy	13900.00
0005434435542	1100	Economy	13900.00
0005433156868	1100	Economy	13900.00
0005434435551	1100	Economy	13900.00
0005434435546	1100	Economy	13900.00
0005433156856	1100	Economy	13900.00
0005434435553	1100	Economy	13900.00
0005434435547	1100	Economy	13900.00
0005434435540	1100	Economy	13900.00
0005434435555	1100	Economy	13900.00
0005434435545	1100	Economy	13900.00
0005434435554	1100	Economy	13900.00
0005434435552	1100	Economy	13900.00
0005434435549	1100	Economy	13900.00
0005433156855	1100	Economy	13900.00
0005434435548	1100	Economy	13900.00
0005433156854	1100	Economy	13900.00
0005433156892	1100	Economy	13900.00
0005434435541	1100	Economy	13900.00
0005434435397	17273	Economy	15200.00
0005433156952	17273	Economy	15200.00
0005433156956	17273	Economy	13900.00
0005434435399	17273	Economy	13900.00
0005434435454	17273	Economy	13900.00
0005434435453	17273	Economy	13900.00
0005433156959	17273	Economy	13900.00
0005434435430	17273	Economy	13900.00
0005433156957	17273	Economy	13900.00
0005433156954	17273	Economy	13900.00
0005434435450	17273	Economy	13900.00
0005434435346	17273	Economy	13900.00
0005434435416	17273	Economy	13900.00
0005434435378	17273	Economy	13900.00
0005434435347	17273	Economy	13900.00
0005434435420	17273	Economy	13900.00
0005434435376	17273	Economy	13900.00
0005434435395	17273	Economy	13900.00
0005434435414	17273	Economy	13900.00
0005434435406	17273	Economy	13900.00
0005433156953	17273	Economy	13900.00
0005434435452	17273	Economy	13900.00
0005433156955	17273	Economy	13900.00
0005434435357	17273	Economy	13900.00
0005434435431	17273	Economy	13900.00
0005433156958	17273	Economy	13900.00
0005434435382	17273	Economy	13900.00
0005434435381	17273	Economy	13900.00
0005434435398	17273	Economy	13900.00
0005435928210	4076	Economy	7500.00
0005435928212	4076	Economy	7500.00
0005435087012	4076	Economy	7500.00
0005435928211	4076	Economy	7500.00
0005435928215	4076	Economy	7500.00
0005435087015	4076	Economy	7500.00
0005435087010	4076	Economy	7500.00
0005435087014	4076	Economy	7500.00
0005435087011	4076	Economy	7500.00
0005435087017	4076	Economy	7500.00
0005435928224	4076	Economy	7500.00
0005435087013	4076	Economy	7500.00
0005435087016	4076	Economy	7500.00
0005435086960	24390	Economy	8200.00
0005435086943	24390	Economy	8200.00
0005435928258	24390	Economy	7500.00
0005435086980	24390	Economy	7500.00
0005435928257	24390	Economy	7500.00
0005435086940	24390	Economy	7500.00
0005435928259	24390	Economy	7500.00
0005435086945	24390	Economy	7500.00
0005435086961	24390	Economy	7500.00
0005435086950	24390	Economy	7500.00
0005435086944	24390	Economy	7500.00
0005435086959	24390	Economy	7500.00
0005435086969	24390	Economy	7500.00
0005435086962	24390	Economy	7500.00
0005435086949	24390	Economy	7500.00
0005435928256	24390	Economy	7500.00
0005435086970	24390	Economy	7500.00
0005435086976	24390	Economy	7500.00
0005435907572	4825	Business	44200.00
0005434626191	4825	Business	44200.00
0005435907556	4825	Economy	16200.00
0005435907567	4825	Economy	16200.00
0005434626184	4825	Economy	14700.00
0005435907566	4825	Economy	14700.00
0005433194880	4825	Economy	14700.00
0005434626186	4825	Economy	14700.00
0005434626187	4825	Economy	14700.00
0005435907585	4825	Economy	14700.00
0005435907582	4825	Economy	14700.00
0005435907584	4825	Economy	14700.00
0005434626190	4825	Economy	14700.00
0005434626189	4825	Economy	14700.00
0005434626188	4825	Economy	14700.00
0005433194879	4825	Economy	14700.00
0005433194894	4825	Economy	14700.00
0005434626192	4825	Economy	14700.00
0005434626185	4825	Economy	14700.00
0005434626100	32932	Business	44200.00
0005435907622	32932	Business	44200.00
0005434626117	32932	Economy	14700.00
0005435907623	32932	Economy	14700.00
0005435907624	32932	Economy	14700.00
0005434626099	32932	Economy	14700.00
0005435907625	32932	Economy	14700.00
0005434626098	32932	Economy	14700.00
0005434626167	32932	Economy	14700.00
0005435907626	32932	Economy	14700.00
0005435785792	13761	Economy	3400.00
0005435785857	13761	Economy	3400.00
0005435785876	13761	Economy	3400.00
0005435785979	13761	Economy	3400.00
0005435785753	13761	Economy	3100.00
0005435937503	13761	Economy	3100.00
0005435785978	13761	Economy	3100.00
0005435785662	13761	Economy	3100.00
0005435937512	13761	Economy	3100.00
0005435785663	13761	Economy	3100.00
0005435785861	13761	Economy	3100.00
0005435785774	13761	Economy	3100.00
0005435937509	13761	Economy	3100.00
0005435937500	13761	Economy	3100.00
0005435785939	13761	Economy	3100.00
0005432195743	13761	Economy	3100.00
0005435785752	13761	Economy	3100.00
0005435937504	13761	Economy	3100.00
0005435785731	13761	Economy	3100.00
0005435785642	13761	Economy	3100.00
0005435785775	13761	Economy	3100.00
0005435785874	13761	Economy	3100.00
0005435937510	13761	Economy	3100.00
0005435785847	13761	Economy	3100.00
0005435785641	13761	Economy	3100.00
0005435937511	13761	Economy	3100.00
0005435785951	13761	Economy	3100.00
0005435937505	13761	Economy	3100.00
0005432195745	13761	Economy	3100.00
0005435937508	13761	Economy	3100.00
0005435937501	13761	Economy	3100.00
0005435785773	13761	Economy	3100.00
0005435785855	13761	Economy	3100.00
0005435785638	13761	Economy	3100.00
0005435785877	13761	Economy	3100.00
0005435785940	13761	Economy	3100.00
0005435937506	13761	Economy	3100.00
0005435785637	13761	Economy	3100.00
0005435785866	13761	Economy	3100.00
0005435785903	13761	Economy	3100.00
0005435785836	13761	Economy	3100.00
0005435937507	13761	Economy	3100.00
0005435785862	13761	Economy	3100.00
0005435785867	13761	Economy	3100.00
0005432195744	13761	Economy	3100.00
0005435785899	13761	Economy	3100.00
0005435785900	13761	Economy	3100.00
0005435937502	13761	Economy	3100.00
0005435786008	13761	Economy	3100.00
0005435785856	13761	Economy	3100.00
0005435786133	27400	Economy	3400.00
0005435786140	27400	Economy	3400.00
0005435786136	27400	Economy	3400.00
0005432190717	27400	Economy	3100.00
0005435786131	27400	Economy	3100.00
0005435786125	27400	Economy	3100.00
0005435786144	27400	Economy	3100.00
0005435786114	27400	Economy	3100.00
0005435786117	27400	Economy	3100.00
0005435786126	27400	Economy	3100.00
0005435786141	27400	Economy	3100.00
0005435787402	27400	Economy	3100.00
0005435786142	27400	Economy	3100.00
0005435786135	27400	Economy	3100.00
0005435786112	27400	Economy	3100.00
0005435786146	27400	Economy	3100.00
0005435786132	27400	Economy	3100.00
0005435937444	27400	Economy	3100.00
0005435786134	27400	Economy	3100.00
0005435937415	27400	Economy	3100.00
0005435786138	27400	Economy	3100.00
0005435786128	27400	Economy	3100.00
0005435786120	27400	Economy	3100.00
0005435786116	27400	Economy	3100.00
0005435786118	27400	Economy	3100.00
0005435787401	27400	Economy	3100.00
0005435786145	27400	Economy	3100.00
0005435786121	27400	Economy	3100.00
0005435786113	27400	Economy	3100.00
0005435786119	27400	Economy	3100.00
0005435786122	27400	Economy	3100.00
0005435786129	27400	Economy	3100.00
0005435786143	27400	Economy	3100.00
0005435786139	27400	Economy	3100.00
0005432190714	27400	Economy	3100.00
0005432190716	27400	Economy	3100.00
0005435786123	27400	Economy	3100.00
0005435786130	27400	Economy	3100.00
0005435786124	27400	Economy	3100.00
0005435786127	27400	Economy	3100.00
0005432190715	27400	Economy	3100.00
0005435786137	27400	Economy	3100.00
0005435786115	27400	Economy	3100.00
0005435786111	27400	Economy	3100.00
0005435311427	20301	Business	12000.00
0005434408606	20301	Business	12000.00
0005435311422	20301	Business	12000.00
0005434408644	20301	Business	12000.00
0005435311425	20301	Business	12000.00
0005434408567	20301	Business	12000.00
0005434408723	20301	Business	12000.00
0005434408713	20301	Business	12000.00
0005434408565	20301	Business	12000.00
0005434408823	20301	Business	12000.00
0005434408529	20301	Economy	4000.00
0005434408816	20301	Economy	4000.00
0005434408633	20301	Economy	4000.00
0005434408641	20301	Economy	4000.00
0005434408760	20301	Economy	4000.00
0005434408813	20301	Economy	4000.00
0005434408693	20301	Economy	4000.00
0005434408881	20301	Economy	4000.00
0005435311423	20301	Economy	4400.00
0005434408469	20301	Economy	4400.00
0005434408645	20301	Economy	4400.00
0005434408893	20301	Economy	4400.00
0005434408470	20301	Economy	4000.00
0005434408381	20301	Economy	4000.00
0005435311426	20301	Economy	4000.00
0005434408754	20301	Economy	4000.00
0005434408864	20301	Economy	4000.00
0005434408812	20301	Economy	4000.00
0005434408830	20301	Economy	4000.00
0005434408853	20301	Economy	4000.00
0005434408396	20301	Economy	4000.00
0005434408758	20301	Economy	4000.00
0005434408631	20301	Economy	4000.00
0005434408438	20301	Economy	4000.00
0005434408943	20301	Economy	4000.00
0005434408731	20301	Economy	4000.00
0005434408710	20301	Economy	4000.00
0005434408737	20301	Economy	4000.00
0005434408530	20301	Economy	4000.00
0005434408967	20301	Economy	4000.00
0005434408545	20301	Economy	4000.00
0005434408900	20301	Economy	4000.00
0005434408709	20301	Economy	4000.00
0005434408632	20301	Economy	4000.00
0005435311428	20301	Economy	4000.00
0005434408516	20301	Economy	4000.00
0005432058476	20301	Economy	4000.00
0005434408578	20301	Economy	4000.00
0005434408753	20301	Economy	4000.00
0005434408615	20301	Economy	4000.00
0005434408738	20301	Economy	4000.00
0005434408659	20301	Economy	4000.00
0005435311430	20301	Economy	4000.00
0005434408684	20301	Economy	4000.00
0005434408513	20301	Economy	4000.00
0005435311424	20301	Economy	4000.00
0005432058475	20301	Economy	4000.00
0005434408498	20301	Economy	4000.00
0005434408786	20301	Economy	4000.00
0005434408656	20301	Economy	4000.00
0005434408387	20301	Economy	4000.00
0005434408734	20301	Economy	4000.00
0005432058477	20301	Economy	4000.00
0005434408882	20301	Economy	4000.00
0005434408899	20301	Economy	4000.00
0005434408682	20301	Economy	4000.00
0005434408547	20301	Economy	4000.00
0005434408661	20301	Economy	4000.00
0005434408757	20301	Economy	4000.00
0005434408437	20301	Economy	4000.00
0005434408568	20301	Economy	4000.00
0005434408616	20301	Economy	4000.00
0005435311429	20301	Economy	4000.00
0005434408202	20301	Economy	4000.00
0005434408294	20301	Economy	4000.00
0005434408293	20301	Economy	4000.00
0005434408732	20301	Economy	4000.00
0005434408554	20301	Economy	4000.00
0005434408546	20301	Economy	4000.00
0005434408865	20301	Economy	4000.00
0005434408906	20301	Economy	4000.00
0005434408824	20301	Economy	4000.00
0005434408817	20301	Economy	4000.00
0005434408600	20301	Economy	4000.00
0005434408630	20301	Economy	4000.00
0005434408643	20301	Economy	4000.00
0005434408724	20301	Economy	4000.00
0005434409237	27006	Business	12000.00
0005434409248	27006	Business	12000.00
0005434409254	27006	Business	12000.00
0005434409229	27006	Business	12000.00
0005434409236	27006	Business	12000.00
0005434409281	27006	Business	12000.00
0005434409228	27006	Business	12000.00
0005435311223	27006	Business	12000.00
0005434409258	27006	Business	12000.00
0005435311216	27006	Business	12000.00
0005434409221	27006	Business	12000.00
0005434409247	27006	Business	12000.00
0005434409267	27006	Economy	4000.00
0005432154102	27006	Economy	4000.00
0005434409233	27006	Economy	4000.00
0005434409227	27006	Economy	4000.00
0005434409268	27006	Economy	4000.00
0005434409239	27006	Economy	4000.00
0005434409235	27006	Economy	4000.00
0005434409234	27006	Economy	4000.00
0005434409231	27006	Economy	4000.00
0005434409277	27006	Economy	4400.00
0005435311225	27006	Economy	4400.00
0005434409224	27006	Economy	4400.00
0005435311217	27006	Economy	4400.00
0005434409269	27006	Economy	4400.00
0005435311190	27006	Economy	4000.00
0005434409252	27006	Economy	4000.00
0005434409259	27006	Economy	4000.00
0005434409245	27006	Economy	4000.00
0005434409262	27006	Economy	4000.00
0005434409276	27006	Economy	4000.00
0005434409243	27006	Economy	4000.00
0005434409249	27006	Economy	4000.00
0005432154106	27006	Economy	4000.00
0005434409275	27006	Economy	4000.00
0005434409274	27006	Economy	4000.00
0005434409261	27006	Economy	4000.00
0005434409280	27006	Economy	4000.00
0005434409260	27006	Economy	4000.00
0005434409244	27006	Economy	4000.00
0005432154103	27006	Economy	4000.00
0005432154105	27006	Economy	4000.00
0005434409242	27006	Economy	4000.00
0005435311211	27006	Economy	4000.00
0005434409278	27006	Economy	4000.00
0005434409256	27006	Economy	4000.00
0005432154101	27006	Economy	4000.00
0005434409282	27006	Economy	4000.00
0005435311234	27006	Economy	4000.00
0005435311224	27006	Economy	4000.00
0005434409266	27006	Economy	4000.00
0005434409250	27006	Economy	4000.00
0005434409273	27006	Economy	4000.00
0005434409226	27006	Economy	4000.00
0005434409232	27006	Economy	4000.00
0005434409253	27006	Economy	4000.00
0005434409279	27006	Economy	4000.00
0005434409238	27006	Economy	4000.00
0005435311229	27006	Economy	4000.00
0005434409272	27006	Economy	4000.00
0005435311182	27006	Economy	4000.00
0005434409255	27006	Economy	4000.00
0005434409240	27006	Economy	4000.00
0005432154107	27006	Economy	4000.00
0005434409223	27006	Economy	4000.00
0005432154100	27006	Economy	4000.00
0005432154108	27006	Economy	4000.00
0005435311236	27006	Economy	4000.00
0005434409264	27006	Economy	4000.00
0005434409265	27006	Economy	4000.00
0005434409263	27006	Economy	4000.00
0005434409230	27006	Economy	4000.00
0005435311210	27006	Economy	4000.00
0005434409241	27006	Economy	4000.00
0005434409270	27006	Economy	4000.00
0005434409257	27006	Economy	4000.00
0005434409271	27006	Economy	4000.00
0005435311235	27006	Economy	4000.00
0005434409251	27006	Economy	4000.00
0005434409222	27006	Economy	4000.00
0005434409246	27006	Economy	4000.00
0005434409225	27006	Economy	4000.00
0005432154104	27006	Economy	4000.00
0005435311222	27006	Economy	4000.00
0005434319721	5670	Business	43300.00
0005433124207	5670	Business	43300.00
0005433124193	5670	Business	43300.00
0005433124170	5670	Business	43300.00
0005434319719	5670	Business	43300.00
0005434319713	5670	Business	43300.00
0005434319731	5670	Business	43300.00
0005434319718	5670	Economy	14400.00
0005433124190	5670	Economy	14400.00
0005434319728	5670	Economy	14400.00
0005434319717	5670	Economy	14400.00
0005433124088	5670	Economy	15900.00
0005433124177	5670	Economy	15900.00
0005433124279	5670	Economy	15900.00
0005433124166	5670	Economy	14400.00
0005434319722	5670	Economy	14400.00
0005432109768	5670	Economy	14400.00
0005434319714	5670	Economy	14400.00
0005433124327	5670	Economy	14400.00
0005433124312	5670	Economy	14400.00
0005434319724	5670	Economy	14400.00
0005433124220	5670	Economy	14400.00
0005434319729	5670	Economy	14400.00
0005433124169	5670	Economy	14400.00
0005434311267	5670	Economy	14400.00
0005433124230	5670	Economy	14400.00
0005434319730	5670	Economy	14400.00
0005434319726	5670	Economy	14400.00
0005434319715	5670	Economy	14400.00
0005434319727	5670	Economy	14400.00
0005433124171	5670	Economy	14400.00
0005434319725	5670	Economy	14400.00
0005433124258	5670	Economy	14400.00
0005434319723	5670	Economy	14400.00
0005434319720	5670	Economy	14400.00
0005434319716	5670	Economy	14400.00
0005432109767	5670	Economy	14400.00
0005432109770	5670	Economy	14400.00
0005433124206	5670	Economy	14400.00
0005432109769	5670	Economy	14400.00
0005433124419	15698	Business	43300.00
0005434319573	15698	Business	43300.00
0005434319595	15698	Business	43300.00
0005433124421	15698	Business	43300.00
0005433124425	15698	Business	43300.00
0005434312351	15698	Economy	14400.00
0005433124430	15698	Economy	14400.00
0005433124415	15698	Economy	14400.00
0005433124413	15698	Economy	14400.00
0005434312348	15698	Economy	15900.00
0005433124434	15698	Economy	15900.00
0005433124417	15698	Economy	14400.00
0005433124418	15698	Economy	14400.00
0005433124422	15698	Economy	14400.00
0005434312349	15698	Economy	14400.00
0005433124431	15698	Economy	14400.00
0005434319596	15698	Economy	14400.00
0005434319574	15698	Economy	14400.00
0005433124433	15698	Economy	14400.00
0005433124426	15698	Economy	14400.00
0005433124432	15698	Economy	14400.00
0005434311248	15698	Economy	14400.00
0005434319614	15698	Economy	14400.00
0005434319608	15698	Economy	14400.00
0005433124428	15698	Economy	14400.00
0005433124423	15698	Economy	14400.00
0005434312350	15698	Economy	14400.00
0005433124424	15698	Economy	14400.00
0005433124412	15698	Economy	14400.00
0005434319609	15698	Economy	14400.00
0005433124427	15698	Economy	14400.00
0005433124429	15698	Economy	14400.00
0005433124420	15698	Economy	14400.00
0005434319585	15698	Economy	14400.00
0005433124414	15698	Economy	14400.00
0005434319615	15698	Economy	14400.00
0005433124416	15698	Economy	14400.00
0005434189295	9002	Economy	27400.00
0005434189272	9002	Economy	24900.00
0005434189274	9002	Economy	24900.00
0005434484506	9002	Economy	24900.00
0005434189263	9002	Economy	24900.00
0005434484502	9002	Economy	24900.00
0005434484504	9002	Economy	24900.00
0005434189282	9002	Economy	24900.00
0005434189254	9002	Economy	24900.00
0005434484505	9002	Economy	24900.00
0005434484503	9002	Economy	24900.00
0005434189255	9002	Economy	24900.00
0005434484501	9002	Economy	24900.00
0005434189281	9002	Economy	24900.00
0005434484507	9002	Economy	24900.00
0005434484443	16615	Economy	24900.00
0005434189318	16615	Economy	24900.00
0005434189313	16615	Economy	24900.00
0005434484439	16615	Economy	24900.00
0005434189319	16615	Economy	24900.00
0005434189317	16615	Economy	24900.00
0005434484451	16615	Economy	24900.00
0005434189315	16615	Economy	24900.00
0005434484471	16615	Economy	24900.00
0005434189314	16615	Economy	24900.00
0005434189316	16615	Economy	24900.00
0005434484460	16615	Economy	24900.00
0005433124412	7605	Business	11100.00
0005433124429	7605	Business	11100.00
0005433124431	7605	Economy	3700.00
0005433124420	7605	Economy	4100.00
0005433124425	7605	Economy	4100.00
0005433124421	7605	Economy	3700.00
0005433722299	7605	Economy	3700.00
0005433722287	7605	Economy	3700.00
0005433124424	7605	Economy	3700.00
0005433722282	7605	Economy	3700.00
0005433124434	7605	Economy	3700.00
0005433722286	7605	Economy	3700.00
0005433124427	7605	Economy	3700.00
0005433124428	7605	Economy	3700.00
0005433124415	7605	Economy	3700.00
0005433722301	7605	Economy	3700.00
0005433124426	7605	Economy	3700.00
0005433124413	7605	Economy	3700.00
0005433124422	7605	Economy	3700.00
0005433124423	7605	Economy	3700.00
0005433722283	7605	Economy	3700.00
0005433124414	7605	Economy	3700.00
0005433124433	7605	Economy	3700.00
0005433124417	7605	Economy	3700.00
0005433722284	7605	Economy	3700.00
0005433124432	7605	Economy	3700.00
0005433124416	7605	Economy	3700.00
0005433124419	7605	Economy	3700.00
0005433124418	7605	Economy	3700.00
0005433722298	7605	Economy	3700.00
0005433124430	7605	Economy	3700.00
0005432721541	7604	Business	11100.00
0005433450482	7604	Business	11100.00
0005433450488	7604	Business	11100.00
0005433450477	7604	Business	11100.00
0005433450480	7604	Business	11100.00
0005432693799	7604	Business	11100.00
0005432071643	7604	Business	11100.00
0005432693812	7604	Business	11100.00
0005432693803	7604	Business	11100.00
0005432693814	7604	Business	11100.00
0005432721542	7604	Business	11100.00
0005432721546	7604	Economy	3700.00
0005432693808	7604	Economy	3700.00
0005432721540	7604	Economy	3700.00
0005432721553	7604	Economy	3700.00
0005433450475	7604	Economy	3700.00
0005432693813	7604	Economy	3700.00
0005432721552	7604	Economy	3700.00
0005433450481	7604	Economy	3700.00
0005433450494	7604	Economy	3700.00
0005432721536	7604	Economy	4100.00
0005432693792	7604	Economy	4100.00
0005432721554	7604	Economy	4100.00
0005432721550	7604	Economy	4100.00
0005433450490	7604	Economy	4100.00
0005432693791	7604	Economy	3700.00
0005432693793	7604	Economy	3700.00
0005433450478	7604	Economy	3700.00
0005432721529	7604	Economy	3700.00
0005432721539	7604	Economy	3700.00
0005432693797	7604	Economy	3700.00
0005433450483	7604	Economy	3700.00
0005432721531	7604	Economy	3700.00
0005432693809	7604	Economy	3700.00
0005433450491	7604	Economy	3700.00
0005432721527	7604	Economy	3700.00
0005432721532	7604	Economy	3700.00
0005432693806	7604	Economy	3700.00
0005433450496	7604	Economy	3700.00
0005432693811	7604	Economy	3700.00
0005432693801	7604	Economy	3700.00
0005432693788	7604	Economy	3700.00
0005432693815	7604	Economy	3700.00
0005432721538	7604	Economy	3700.00
0005432693790	7604	Economy	3700.00
0005432693800	7604	Economy	3700.00
0005432693807	7604	Economy	3700.00
0005432693810	7604	Economy	3700.00
0005432721530	7604	Economy	3700.00
0005433450484	7604	Economy	3700.00
0005432693796	7604	Economy	3700.00
0005432693798	7604	Economy	3700.00
0005432721549	7604	Economy	3700.00
0005433450492	7604	Economy	3700.00
0005433450479	7604	Economy	3700.00
0005432721548	7604	Economy	3700.00
0005432721551	7604	Economy	3700.00
0005432693795	7604	Economy	3700.00
0005432071644	7604	Economy	3700.00
0005432693805	7604	Economy	3700.00
0005432721543	7604	Economy	3700.00
0005432693789	7604	Economy	3700.00
0005432721544	7604	Economy	3700.00
0005432721528	7604	Economy	3700.00
0005433450485	7604	Economy	3700.00
0005432693794	7604	Economy	3700.00
0005432693787	7604	Economy	3700.00
0005432721533	7604	Economy	3700.00
0005433450487	7604	Economy	3700.00
0005432693802	7604	Economy	3700.00
0005433450489	7604	Economy	3700.00
0005433450476	7604	Economy	3700.00
0005433450486	7604	Economy	3700.00
0005432721537	7604	Economy	3700.00
0005433450493	7604	Economy	3700.00
0005432721545	7604	Economy	3700.00
0005432693804	7604	Economy	3700.00
0005432721534	7604	Economy	3700.00
0005432721535	7604	Economy	3700.00
0005433450495	7604	Economy	3700.00
0005432721547	7604	Economy	3700.00
0005433450288	30418	Business	11100.00
0005432693567	30418	Business	11100.00
0005432693542	30418	Business	11100.00
0005433450284	30418	Business	11100.00
0005433450252	30418	Business	11100.00
0005432693409	30418	Business	11100.00
0005432693517	30418	Business	11100.00
0005433450283	30418	Economy	3700.00
0005432693477	30418	Economy	3700.00
0005433450253	30418	Economy	3700.00
0005432693401	30418	Economy	3700.00
0005432693548	30418	Economy	4100.00
0005432693583	30418	Economy	4100.00
0005432693443	30418	Economy	4100.00
0005433450335	30418	Economy	4100.00
0005432693512	30418	Economy	3700.00
0005433450334	30418	Economy	3700.00
0005432693561	30418	Economy	3700.00
0005432693616	30418	Economy	3700.00
0005432693454	30418	Economy	3700.00
0005433450316	30418	Economy	3700.00
0005432693410	30418	Economy	3700.00
0005432693465	30418	Economy	3700.00
0005433450285	30418	Economy	3700.00
0005432693534	30418	Economy	3700.00
0005432693558	30418	Economy	3700.00
0005432693568	30418	Economy	3700.00
0005432693402	30418	Economy	3700.00
0005432693468	30418	Economy	3700.00
0005433450230	30418	Economy	3700.00
0005432693455	30418	Economy	3700.00
0005432693358	30418	Economy	3700.00
0005433450286	30418	Economy	3700.00
0005432693559	30418	Economy	3700.00
0005432693547	30418	Economy	3700.00
0005433450237	30418	Economy	3700.00
0005432693557	30418	Economy	3700.00
0005432693544	30418	Economy	3700.00
0005432693594	30418	Economy	3700.00
0005432693535	30418	Economy	3700.00
0005432693475	30418	Economy	3700.00
0005432693652	30418	Economy	3700.00
0005432693442	30418	Economy	3700.00
0005432693519	30418	Economy	3700.00
0005433450287	30418	Economy	3700.00
0005432693467	30418	Economy	3700.00
0005433450314	30418	Economy	3700.00
0005432693464	30418	Economy	3700.00
0005433450289	30418	Economy	3700.00
0005432693478	30418	Economy	3700.00
0005432693572	30418	Economy	3700.00
0005432693357	30418	Economy	3700.00
0005433450357	30418	Economy	3700.00
0005432693518	30418	Economy	3700.00
0005432693560	30418	Economy	3700.00
0005432721241	30440	Business	11100.00
0005432721354	30440	Business	11100.00
0005433722372	30440	Business	11100.00
0005432721374	30440	Business	11100.00
0005432721444	30440	Business	11100.00
0005432721260	30440	Business	11100.00
0005433722373	30440	Business	11100.00
0005433124171	30440	Economy	3700.00
0005433124206	30440	Economy	3700.00
0005432721361	30440	Economy	3700.00
0005433124312	30440	Economy	3700.00
0005432721283	30440	Economy	3700.00
0005433722377	30440	Economy	3700.00
0005432721421	30440	Economy	4100.00
0005433124230	30440	Economy	4100.00
0005433722378	30440	Economy	3700.00
0005433722375	30440	Economy	3700.00
0005433722371	30440	Economy	3700.00
0005433722379	30440	Economy	3700.00
0005432721427	30440	Economy	3700.00
0005433124207	30440	Economy	3700.00
0005433124220	30440	Economy	3700.00
0005433124170	30440	Economy	3700.00
0005432721362	30440	Economy	3700.00
0005433124088	30440	Economy	3700.00
0005433722376	30440	Economy	3700.00
0005433124258	30440	Economy	3700.00
0005432721420	30440	Economy	3700.00
0005433124177	30440	Economy	3700.00
0005433124327	30440	Economy	3700.00
0005432721326	30440	Economy	3700.00
0005433124166	30440	Economy	3700.00
0005433722374	30440	Economy	3700.00
0005432721428	30440	Economy	3700.00
0005432721199	30440	Economy	3700.00
0005433124190	30440	Economy	3700.00
0005433124279	30440	Economy	3700.00
0005432721240	30440	Economy	3700.00
0005432721445	30440	Economy	3700.00
0005433124169	30440	Economy	3700.00
0005433124193	30440	Economy	3700.00
0005432721261	30440	Economy	3700.00
0005432721319	30440	Economy	3700.00
0005432721325	30440	Economy	3700.00
0005432721324	30440	Economy	3700.00
0005432721284	30440	Economy	3700.00
0005433525299	1402	Business	70400.00
0005433525295	1402	Business	70400.00
0005433525293	1402	Business	70400.00
0005433193281	1402	Business	70400.00
0005434587214	1402	Business	70400.00
0005434587212	1402	Business	70400.00
0005434513643	1402	Business	70400.00
0005432271072	1402	Business	70400.00
0005434513642	1402	Business	70400.00
0005433193208	1402	Business	70400.00
0005433724915	1402	Economy	23500.00
0005433525301	1402	Economy	23500.00
0005433525294	1402	Economy	23500.00
0005432928060	1402	Economy	23500.00
0005433525297	1402	Economy	23500.00
0005433193319	1402	Economy	23500.00
0005432928082	1402	Economy	23500.00
0005434587231	1402	Economy	25800.00
0005434587226	1402	Economy	25800.00
0005433193286	1402	Economy	25800.00
0005434587217	1402	Economy	25800.00
0005433193328	1402	Economy	25800.00
0005433193207	1402	Economy	23500.00
0005433193256	1402	Economy	23500.00
0005432968875	1402	Economy	23500.00
0005433193247	1402	Economy	23500.00
0005434587222	1402	Economy	23500.00
0005432968865	1402	Economy	23500.00
0005432928072	1402	Economy	23500.00
0005433193255	1402	Economy	23500.00
0005434587218	1402	Economy	23500.00
0005434587228	1402	Economy	23500.00
0005434515029	1402	Economy	23500.00
0005434587227	1402	Economy	23500.00
0005434587211	1402	Economy	23500.00
0005433193250	1402	Economy	23500.00
0005434587229	1402	Economy	23500.00
0005433193238	1402	Economy	23500.00
0005433193291	1402	Economy	23500.00
0005433193219	1402	Economy	23500.00
0005433193289	1402	Economy	23500.00
0005434587223	1402	Economy	23500.00
0005433525292	1402	Economy	23500.00
0005434515030	1402	Economy	23500.00
0005434587210	1402	Economy	23500.00
0005434587233	1402	Economy	23500.00
0005433193271	1402	Economy	23500.00
0005434587221	1402	Economy	23500.00
0005434587224	1402	Economy	23500.00
0005432968868	1402	Economy	23500.00
0005434513641	1402	Economy	23500.00
0005434587220	1402	Economy	23500.00
0005433724917	1402	Economy	23500.00
0005433193272	1402	Economy	23500.00
0005434587213	1402	Economy	23500.00
0005432968866	1402	Economy	23500.00
0005432968878	1402	Economy	23500.00
0005433193222	1402	Economy	23500.00
0005434587215	1402	Economy	23500.00
0005433193212	1402	Economy	23500.00
0005434587219	1402	Economy	23500.00
0005433193290	1402	Economy	23500.00
0005433525300	1402	Economy	23500.00
0005433724916	1402	Economy	23500.00
0005433193315	1402	Economy	23500.00
0005433193285	1402	Economy	23500.00
0005432271073	1402	Economy	23500.00
0005433193213	1402	Economy	23500.00
0005434587230	1402	Economy	23500.00
0005432928068	1402	Economy	23500.00
0005432271071	1402	Economy	23500.00
0005432928059	1402	Economy	23500.00
0005434587232	1402	Economy	23500.00
0005433193282	1402	Economy	23500.00
0005433525298	1402	Economy	23500.00
0005434587216	1402	Economy	23500.00
0005433525291	1402	Economy	23500.00
0005433193266	1402	Economy	23500.00
0005433525296	1402	Economy	23500.00
0005433193227	1402	Economy	23500.00
0005433193223	1402	Economy	23500.00
0005433193329	1402	Economy	23500.00
0005433193316	1402	Economy	23500.00
0005434587225	1402	Economy	23500.00
0005432968893	18511	Business	70400.00
0005434587064	18511	Business	70400.00
0005434587036	18511	Business	70400.00
0005434586897	18511	Business	70400.00
0005433525184	18511	Business	70400.00
0005433193357	18511	Business	70400.00
0005433525190	18511	Business	70400.00
0005433193361	18511	Economy	23500.00
0005434586972	18511	Economy	23500.00
0005432928115	18511	Economy	23500.00
0005433193366	18511	Economy	23500.00
0005433525191	18511	Economy	23500.00
0005434586965	18511	Economy	23500.00
0005434586986	18511	Economy	23500.00
0005434586979	18511	Economy	25800.00
0005434586989	18511	Economy	25800.00
0005434586998	18511	Economy	25800.00
0005434586973	18511	Economy	25800.00
0005432968894	18511	Economy	23500.00
0005432928114	18511	Economy	23500.00
0005434515011	18511	Economy	23500.00
0005433193367	18511	Economy	23500.00
0005433193362	18511	Economy	23500.00
0005434586845	18511	Economy	23500.00
0005433193368	18511	Economy	23500.00
0005434586951	18511	Economy	23500.00
0005433724856	18511	Economy	23500.00
0005433193359	18511	Economy	23500.00
0005434586980	18511	Economy	23500.00
0005433525150	18511	Economy	23500.00
0005434587060	18511	Economy	23500.00
0005433193358	18511	Economy	23500.00
0005432928112	18511	Economy	23500.00
0005433525192	18511	Economy	23500.00
0005432928110	18511	Economy	23500.00
0005433525175	18511	Economy	23500.00
0005434586981	18511	Economy	23500.00
0005433525211	18511	Economy	23500.00
0005434586911	18511	Economy	23500.00
0005433525223	18511	Economy	23500.00
0005432968895	18511	Economy	23500.00
0005433525204	18511	Economy	23500.00
0005434586929	18511	Economy	23500.00
0005434586985	18511	Economy	23500.00
0005433525222	18511	Economy	23500.00
0005434587035	18511	Economy	23500.00
0005433193363	18511	Economy	23500.00
0005433525185	18511	Economy	23500.00
0005434515008	18511	Economy	23500.00
0005434587019	18511	Economy	23500.00
0005434586898	18511	Economy	23500.00
0005434587061	18511	Economy	23500.00
0005433525170	18511	Economy	23500.00
0005434515005	18511	Economy	23500.00
0005433193365	18511	Economy	23500.00
0005433525183	18511	Economy	23500.00
0005434587043	18511	Economy	23500.00
0005432928111	18511	Economy	23500.00
0005434515007	18511	Economy	23500.00
0005434587098	18511	Economy	23500.00
0005433193364	18511	Economy	23500.00
0005434586984	18511	Economy	23500.00
0005434586966	18511	Economy	23500.00
0005432928116	18511	Economy	23500.00
0005433193360	18511	Economy	23500.00
0005434587018	18511	Economy	23500.00
0005434515012	18511	Economy	23500.00
0005432928113	18511	Economy	23500.00
0005433525136	18511	Economy	23500.00
0005434345005	11431	Economy	4300.00
0005434345040	11431	Economy	4300.00
0005434345031	11431	Economy	4300.00
0005434345041	11431	Economy	4300.00
0005434345023	11431	Economy	4000.00
0005434345016	11431	Economy	4000.00
0005434345014	11431	Economy	4000.00
0005434345009	11431	Economy	4000.00
0005435305042	11431	Economy	4000.00
0005434345007	11431	Economy	4000.00
0005435305039	11431	Economy	4000.00
0005434345019	11431	Economy	4000.00
0005435302266	11431	Economy	4000.00
0005435305038	11431	Economy	4000.00
0005434142704	11431	Economy	4000.00
0005434345027	11431	Economy	4000.00
0005434345006	11431	Economy	4000.00
0005434345037	11431	Economy	4000.00
0005434345029	11431	Economy	4000.00
0005434345030	11431	Economy	4000.00
0005434345008	11431	Economy	4000.00
0005434345035	11431	Economy	4000.00
0005434345021	11431	Economy	4000.00
0005434345028	11431	Economy	4000.00
0005434345015	11431	Economy	4000.00
0005434345039	11431	Economy	4000.00
0005434345032	11431	Economy	4000.00
0005435305043	11431	Economy	4000.00
0005434345034	11431	Economy	4000.00
0005434345026	11431	Economy	4000.00
0005434345012	11431	Economy	4000.00
0005434345038	11431	Economy	4000.00
0005435302241	11431	Economy	4000.00
0005434345011	11431	Economy	4000.00
0005434345020	11431	Economy	4000.00
0005434142705	11431	Economy	4000.00
0005434345013	11431	Economy	4000.00
0005434345033	11431	Economy	4000.00
0005434345036	11431	Economy	4000.00
0005434345025	11431	Economy	4000.00
0005434345010	11431	Economy	4000.00
0005434345017	11431	Economy	4000.00
0005434345018	11431	Economy	4000.00
0005434345024	11431	Economy	4000.00
0005434345022	11431	Economy	4000.00
0005434142706	11431	Economy	4000.00
0005434344754	29788	Economy	4300.00
0005434344728	29788	Economy	4300.00
0005435304249	29788	Economy	4300.00
0005434344809	29788	Economy	4300.00
0005434344680	29788	Economy	4000.00
0005434344695	29788	Economy	4000.00
0005434344810	29788	Economy	4000.00
0005434344699	29788	Economy	4000.00
0005435305059	29788	Economy	4000.00
0005434344656	29788	Economy	4000.00
0005434344673	29788	Economy	4000.00
0005434344655	29788	Economy	4000.00
0005434344679	29788	Economy	4000.00
0005434344674	29788	Economy	4000.00
0005434344654	29788	Economy	4000.00
0005435304252	29788	Economy	4000.00
0005435304251	29788	Economy	4000.00
0005434344712	29788	Economy	4000.00
0005435305055	29788	Economy	4000.00
0005434344755	29788	Economy	4000.00
0005434344804	29788	Economy	4000.00
0005435304248	29788	Economy	4000.00
0005434344770	29788	Economy	4000.00
0005434344687	29788	Economy	4000.00
0005434344696	29788	Economy	4000.00
0005434344682	29788	Economy	4000.00
0005434344803	29788	Economy	4000.00
0005434344776	29788	Economy	4000.00
0005435305056	29788	Economy	4000.00
0005434344686	29788	Economy	4000.00
0005435305057	29788	Economy	4000.00
0005434344802	29788	Economy	4000.00
0005434344604	29788	Economy	4000.00
0005434344727	29788	Economy	4000.00
0005434344713	29788	Economy	4000.00
0005434344681	29788	Economy	4000.00
0005434344777	29788	Economy	4000.00
0005434344847	29788	Economy	4000.00
0005434344846	29788	Economy	4000.00
0005434344753	29788	Economy	4000.00
0005434142668	29788	Economy	4000.00
0005435305058	29788	Economy	4000.00
0005434344845	29788	Economy	4000.00
0005434344603	29788	Economy	4000.00
0005435304250	29788	Economy	4000.00
0005434344750	29788	Economy	4000.00
0005434344831	29788	Economy	4000.00
0005434142661	29788	Economy	4000.00
0005435825251	1264	Business	199800.00
0005435825267	1264	Business	199800.00
0005435825269	1264	Business	199800.00
0005435825272	1264	Business	199800.00
0005433415903	1264	Business	199800.00
0005433415913	1264	Business	199800.00
0005435825258	1264	Business	199800.00
0005432284630	1264	Economy	66600.00
0005435825263	1264	Economy	66600.00
0005435825264	1264	Economy	66600.00
0005433415750	1264	Economy	66600.00
0005432284629	1264	Economy	66600.00
0005433415894	1264	Economy	73200.00
0005435825268	1264	Economy	73200.00
0005435825255	1264	Economy	66600.00
0005435825256	1264	Economy	66600.00
0005433415926	1264	Economy	66600.00
0005435825265	1264	Economy	66600.00
0005435825266	1264	Economy	66600.00
0005435825273	1264	Economy	66600.00
0005435825271	1264	Economy	66600.00
0005433415889	1264	Economy	66600.00
0005435825253	1264	Economy	66600.00
0005435825254	1264	Economy	66600.00
0005435825259	1264	Economy	66600.00
0005433415904	1264	Economy	66600.00
0005432284628	1264	Economy	66600.00
0005435825260	1264	Economy	66600.00
0005435825257	1264	Economy	66600.00
0005435825276	1264	Economy	66600.00
0005433415865	1264	Economy	66600.00
0005435825262	1264	Economy	66600.00
0005435825274	1264	Economy	66600.00
0005435825277	1264	Economy	66600.00
0005433415846	1264	Economy	66600.00
0005433415895	1264	Economy	66600.00
0005433415927	1264	Economy	66600.00
0005435825261	1264	Economy	66600.00
0005435825275	1264	Economy	66600.00
0005435825252	1264	Economy	66600.00
0005435825270	1264	Economy	66600.00
0005435824867	18001	Business	199800.00
0005435824954	18001	Business	199800.00
0005433416034	18001	Business	199800.00
0005433416040	18001	Business	199800.00
0005433416038	18001	Business	199800.00
0005433416039	18001	Business	199800.00
0005435824950	18001	Business	199800.00
0005435824848	18001	Business	199800.00
0005435825061	18001	Business	199800.00
0005435825058	18001	Economy	66600.00
0005435824912	18001	Economy	66600.00
0005435824994	18001	Economy	66600.00
0005433416036	18001	Economy	66600.00
0005435825041	18001	Economy	66600.00
0005435825089	18001	Economy	66600.00
0005435825062	18001	Economy	66600.00
0005435825035	18001	Economy	73200.00
0005435825026	18001	Economy	66600.00
0005435824914	18001	Economy	66600.00
0005433416030	18001	Economy	66600.00
0005435824915	18001	Economy	66600.00
0005433416032	18001	Economy	66600.00
0005435824955	18001	Economy	66600.00
0005435824910	18001	Economy	66600.00
0005435825155	18001	Economy	66600.00
0005433416037	18001	Economy	66600.00
0005433416031	18001	Economy	66600.00
0005435825078	18001	Economy	66600.00
0005435824977	18001	Economy	66600.00
0005435824988	18001	Economy	66600.00
0005435825156	18001	Economy	66600.00
0005435825154	18001	Economy	66600.00
0005433416033	18001	Economy	66600.00
0005435824985	18001	Economy	66600.00
0005433416042	18001	Economy	66600.00
0005435825053	18001	Economy	66600.00
0005435825037	18001	Economy	66600.00
0005433416035	18001	Economy	66600.00
0005435825027	18001	Economy	66600.00
0005433416045	18001	Economy	66600.00
0005435824911	18001	Economy	66600.00
0005435824986	18001	Economy	66600.00
0005433416046	18001	Economy	66600.00
0005435824980	18001	Economy	66600.00
0005435825010	18001	Economy	66600.00
0005433416043	18001	Economy	66600.00
0005435825059	18001	Economy	66600.00
0005435825166	18001	Economy	66600.00
0005433416041	18001	Economy	66600.00
0005433416044	18001	Economy	66600.00
0005435825046	18001	Economy	66600.00
0005434461692	12565	Economy	14800.00
0005434461691	12565	Economy	13500.00
0005434461693	12565	Economy	13500.00
0005434461694	12565	Economy	13500.00
0005434460554	12565	Economy	13500.00
0005434460547	12565	Economy	13500.00
0005434460555	12565	Economy	13500.00
0005434460550	12565	Economy	13500.00
0005434460556	12565	Economy	13500.00
0005434460553	12565	Economy	13500.00
0005434461696	12565	Economy	13500.00
0005434460552	12565	Economy	13500.00
0005434461690	12565	Economy	13500.00
0005434460548	12565	Economy	13500.00
0005434461695	12565	Economy	13500.00
0005434460549	12565	Economy	13500.00
0005434461689	12565	Economy	13500.00
0005434460551	12565	Economy	13500.00
0005435476878	5613	Business	27800.00
0005435243213	5613	Business	27800.00
0005435243319	5613	Business	27800.00
0005432785075	5613	Business	27800.00
0005432785084	5613	Business	27800.00
0005432785046	5613	Business	27800.00
0005432785069	5613	Business	27800.00
0005435243292	5613	Business	27800.00
0005435243180	5613	Business	27800.00
0005432785070	5613	Business	27800.00
0005432785044	5613	Business	27800.00
0005435243275	5613	Economy	9300.00
0005435243283	5613	Economy	9300.00
0005432785053	5613	Economy	9300.00
0005435243320	5613	Economy	9300.00
0005435243381	5613	Economy	9300.00
0005432785065	5613	Economy	9300.00
0005435476846	5613	Economy	9300.00
0005435476875	5613	Economy	9300.00
0005432785077	5613	Economy	9300.00
0005435243368	5613	Economy	10200.00
0005432785042	5613	Economy	10200.00
0005432785058	5613	Economy	10200.00
0005435476855	5613	Economy	10200.00
0005432785078	5613	Economy	10200.00
0005432785087	5613	Economy	9300.00
0005432785064	5613	Economy	9300.00
0005432785080	5613	Economy	9300.00
0005432785049	5613	Economy	9300.00
0005432785071	5613	Economy	9300.00
0005432785048	5613	Economy	9300.00
0005432785057	5613	Economy	9300.00
0005435243329	5613	Economy	9300.00
0005435243321	5613	Economy	9300.00
0005432785076	5613	Economy	9300.00
0005435476863	5613	Economy	9300.00
0005435243252	5613	Economy	9300.00
0005435243261	5613	Economy	9300.00
0005432785073	5613	Economy	9300.00
0005432785072	5613	Economy	9300.00
0005432785068	5613	Economy	9300.00
0005432785051	5613	Economy	9300.00
0005435243276	5613	Economy	9300.00
0005432785047	5613	Economy	9300.00
0005435243189	5613	Economy	9300.00
0005432785089	5613	Economy	9300.00
0005435476877	5613	Economy	9300.00
0005432144065	5613	Economy	9300.00
0005432785079	5613	Economy	9300.00
0005432785067	5613	Economy	9300.00
0005432785043	5613	Economy	9300.00
0005435243181	5613	Economy	9300.00
0005432785056	5613	Economy	9300.00
0005432785074	5613	Economy	9300.00
0005435476862	5613	Economy	9300.00
0005432785086	5613	Economy	9300.00
0005432785066	5613	Economy	9300.00
0005432785059	5613	Economy	9300.00
0005432785085	5613	Economy	9300.00
0005432785060	5613	Economy	9300.00
0005432785091	5613	Economy	9300.00
0005435243308	5613	Economy	9300.00
0005432785081	5613	Economy	9300.00
0005435476826	5613	Economy	9300.00
0005435243356	5613	Economy	9300.00
0005435243220	5613	Economy	9300.00
0005432785062	5613	Economy	9300.00
0005432785045	5613	Economy	9300.00
0005435243267	5613	Economy	9300.00
0005432785083	5613	Economy	9300.00
0005432785082	5613	Economy	9300.00
0005435476856	5613	Economy	9300.00
0005432785050	5613	Economy	9300.00
0005435476876	5613	Economy	9300.00
0005432785088	5613	Economy	9300.00
0005432785063	5613	Economy	9300.00
0005435476857	5613	Economy	9300.00
0005432144066	5613	Economy	9300.00
0005435476854	5613	Economy	9300.00
0005432785061	5613	Economy	9300.00
0005435476845	5613	Economy	9300.00
0005432785090	5613	Economy	9300.00
0005435476868	5613	Economy	9300.00
0005432785055	5613	Economy	9300.00
0005432785054	5613	Economy	9300.00
0005432144064	5613	Economy	9300.00
0005432785052	5613	Economy	9300.00
0005435476864	5613	Economy	9300.00
0005435243471	15370	Business	27800.00
0005435243477	15370	Business	27800.00
0005435476928	15370	Business	27800.00
0005435243470	15370	Business	27800.00
0005435243476	15370	Business	27800.00
0005432784529	15370	Business	27800.00
0005432784607	15370	Business	27800.00
0005432784652	15370	Business	27800.00
0005435243457	15370	Business	27800.00
0005432784534	15370	Business	27800.00
0005432784527	15370	Business	27800.00
0005435243462	15370	Business	27800.00
0005432784334	15370	Economy	9300.00
0005432784530	15370	Economy	9300.00
0005435476932	15370	Economy	9300.00
0005432784684	15370	Economy	9300.00
0005435243465	15370	Economy	9300.00
0005435243456	15370	Economy	9300.00
0005432784408	15370	Economy	9300.00
0005432784642	15370	Economy	9300.00
0005435476933	15370	Economy	9300.00
0005432784621	15370	Economy	9300.00
0005432784580	15370	Economy	10200.00
0005432784651	15370	Economy	10200.00
0005432784765	15370	Economy	10200.00
0005435243469	15370	Economy	10200.00
0005435243473	15370	Economy	10200.00
0005435243464	15370	Economy	9300.00
0005432784459	15370	Economy	9300.00
0005432784817	15370	Economy	9300.00
0005435243468	15370	Economy	9300.00
0005435243482	15370	Economy	9300.00
0005432784516	15370	Economy	9300.00
0005435243474	15370	Economy	9300.00
0005435476931	15370	Economy	9300.00
0005432784458	15370	Economy	9300.00
0005435243460	15370	Economy	9300.00
0005432784653	15370	Economy	9300.00
0005432784558	15370	Economy	9300.00
0005435243481	15370	Economy	9300.00
0005432784333	15370	Economy	9300.00
0005432784764	15370	Economy	9300.00
0005432784555	15370	Economy	9300.00
0005435243458	15370	Economy	9300.00
0005435243459	15370	Economy	9300.00
0005435476934	15370	Economy	9300.00
0005432784465	15370	Economy	9300.00
0005432784851	15370	Economy	9300.00
0005432784535	15370	Economy	9300.00
0005432784486	15370	Economy	9300.00
0005432784528	15370	Economy	9300.00
0005432784474	15370	Economy	9300.00
0005435243478	15370	Economy	9300.00
0005432784335	15370	Economy	9300.00
0005432784457	15370	Economy	9300.00
0005435243466	15370	Economy	9300.00
0005435476938	15370	Economy	9300.00
0005432784460	15370	Economy	9300.00
0005432784763	15370	Economy	9300.00
0005432784649	15370	Economy	9300.00
0005432784533	15370	Economy	9300.00
0005435476927	15370	Economy	9300.00
0005432784484	15370	Economy	9300.00
0005432784608	15370	Economy	9300.00
0005432784456	15370	Economy	9300.00
0005435476937	15370	Economy	9300.00
0005432784552	15370	Economy	9300.00
0005435243483	15370	Economy	9300.00
0005435476930	15370	Economy	9300.00
0005432784808	15370	Economy	9300.00
0005432784648	15370	Economy	9300.00
0005432784406	15370	Economy	9300.00
0005435476935	15370	Economy	9300.00
0005432784679	15370	Economy	9300.00
0005432784326	15370	Economy	9300.00
0005435243461	15370	Economy	9300.00
0005432784464	15370	Economy	9300.00
0005432784680	15370	Economy	9300.00
0005435243480	15370	Economy	9300.00
0005435243463	15370	Economy	9300.00
0005435243472	15370	Economy	9300.00
0005432784713	15370	Economy	9300.00
0005432784643	15370	Economy	9300.00
0005432784554	15370	Economy	9300.00
0005432784553	15370	Economy	9300.00
0005435243479	15370	Economy	9300.00
0005432784485	15370	Economy	9300.00
0005432784647	15370	Economy	9300.00
0005435243467	15370	Economy	9300.00
0005432784605	15370	Economy	9300.00
0005435476929	15370	Economy	9300.00
0005432784803	15370	Economy	9300.00
0005432784606	15370	Economy	9300.00
0005432784622	15370	Economy	9300.00
0005432784445	15370	Economy	9300.00
0005435243475	15370	Economy	9300.00
0005435476936	15370	Economy	9300.00
0005432848652	4381	Economy	7000.00
0005432848654	4381	Economy	6300.00
0005432848662	4381	Economy	6300.00
0005432848649	4381	Economy	6300.00
0005435851066	4381	Economy	6300.00
0005435851072	4381	Economy	6300.00
0005432848660	4381	Economy	6300.00
0005435851047	4381	Economy	6300.00
0005435851094	4381	Economy	6300.00
0005432848659	4381	Economy	6300.00
0005432848656	4381	Economy	6300.00
0005432848663	4381	Economy	6300.00
0005432848655	4381	Economy	6300.00
0005435851071	4381	Economy	6300.00
0005435851095	4381	Economy	6300.00
0005435851096	4381	Economy	6300.00
0005435851023	4381	Economy	6300.00
0005435851043	4381	Economy	6300.00
0005432848657	4381	Economy	6300.00
0005435851052	4381	Economy	6300.00
0005435851065	4381	Economy	6300.00
0005432848653	4381	Economy	6300.00
0005434463980	4381	Economy	6300.00
0005432848658	4381	Economy	6300.00
0005432848651	4381	Economy	6300.00
0005432848661	4381	Economy	6300.00
0005434462842	4381	Economy	6300.00
0005435851057	4381	Economy	6300.00
0005434463981	4381	Economy	6300.00
0005435851044	4381	Economy	6300.00
0005435851033	4381	Economy	6300.00
0005434462841	4381	Economy	6300.00
0005434462840	4381	Economy	6300.00
0005432848650	4381	Economy	6300.00
0005435851129	28888	Economy	7000.00
0005434463956	28888	Economy	7000.00
0005434463960	28888	Economy	7000.00
0005434463957	28888	Economy	6300.00
0005434463955	28888	Economy	6300.00
0005432848503	28888	Economy	6300.00
0005435851130	28888	Economy	6300.00
0005435851123	28888	Economy	6300.00
0005432848584	28888	Economy	6300.00
0005435851122	28888	Economy	6300.00
0005432848568	28888	Economy	6300.00
0005432848569	28888	Economy	6300.00
0005434463966	28888	Economy	6300.00
0005434463965	28888	Economy	6300.00
0005434463959	28888	Economy	6300.00
0005432848533	28888	Economy	6300.00
0005432848543	28888	Economy	6300.00
0005432848574	28888	Economy	6300.00
0005435851128	28888	Economy	6300.00
0005432848490	28888	Economy	6300.00
0005432848567	28888	Economy	6300.00
0005435851125	28888	Economy	6300.00
0005432848432	28888	Economy	6300.00
0005434463967	28888	Economy	6300.00
0005435851124	28888	Economy	6300.00
0005432848526	28888	Economy	6300.00
0005435851126	28888	Economy	6300.00
0005432848548	28888	Economy	6300.00
0005432848502	28888	Economy	6300.00
0005432848549	28888	Economy	6300.00
0005432848525	28888	Economy	6300.00
0005432848509	28888	Economy	6300.00
0005435851127	28888	Economy	6300.00
0005432848508	28888	Economy	6300.00
0005432848433	28888	Economy	6300.00
0005432848519	28888	Economy	6300.00
0005433497706	6239	Business	11900.00
0005433497704	6239	Business	11900.00
0005434444087	6239	Business	11900.00
0005433497705	6239	Business	11900.00
0005434926561	6239	Business	11900.00
0005434926567	6239	Business	11900.00
0005434444090	6239	Business	11900.00
0005433497701	6239	Business	11900.00
0005434444093	6239	Business	11900.00
0005432075311	6239	Business	11900.00
0005433497698	6239	Business	11900.00
0005433497716	6239	Economy	4000.00
0005434926563	6239	Economy	4000.00
0005434926558	6239	Economy	4000.00
0005433497711	6239	Economy	4000.00
0005434926577	6239	Economy	4000.00
0005434926559	6239	Economy	4000.00
0005434444098	6239	Economy	4000.00
0005434444095	6239	Economy	4000.00
0005434926554	6239	Economy	4400.00
0005433497719	6239	Economy	4400.00
0005433497697	6239	Economy	4400.00
0005433497708	6239	Economy	4000.00
0005434444094	6239	Economy	4000.00
0005433497722	6239	Economy	4000.00
0005433497702	6239	Economy	4000.00
0005434444089	6239	Economy	4000.00
0005433497727	6239	Economy	4000.00
0005434444091	6239	Economy	4000.00
0005434926588	6239	Economy	4000.00
0005433497720	6239	Economy	4000.00
0005433497710	6239	Economy	4000.00
0005434926570	6239	Economy	4000.00
0005434926562	6239	Economy	4000.00
0005434926579	6239	Economy	4000.00
0005434444099	6239	Economy	4000.00
0005434926555	6239	Economy	4000.00
0005434926585	6239	Economy	4000.00
0005433497715	6239	Economy	4000.00
0005434926581	6239	Economy	4000.00
0005434926565	6239	Economy	4000.00
0005433497721	6239	Economy	4000.00
0005434926575	6239	Economy	4000.00
0005434444096	6239	Economy	4000.00
0005434926574	6239	Economy	4000.00
0005434926569	6239	Economy	4000.00
0005434926556	6239	Economy	4000.00
0005433497726	6239	Economy	4000.00
0005434926552	6239	Economy	4000.00
0005434926560	6239	Economy	4000.00
0005433497728	6239	Economy	4000.00
0005433497700	6239	Economy	4000.00
0005433497724	6239	Economy	4000.00
0005434926564	6239	Economy	4000.00
0005434444085	6239	Economy	4000.00
0005433497712	6239	Economy	4000.00
0005433497709	6239	Economy	4000.00
0005434926586	6239	Economy	4000.00
0005434926551	6239	Economy	4000.00
0005434926582	6239	Economy	4000.00
0005434926573	6239	Economy	4000.00
0005434926566	6239	Economy	4000.00
0005434444097	6239	Economy	4000.00
0005434926578	6239	Economy	4000.00
0005433497725	6239	Economy	4000.00
0005434444088	6239	Economy	4000.00
0005433497718	6239	Economy	4000.00
0005433497713	6239	Economy	4000.00
0005434926580	6239	Economy	4000.00
0005433497703	6239	Economy	4000.00
0005433497707	6239	Economy	4000.00
0005434444086	6239	Economy	4000.00
0005434926557	6239	Economy	4000.00
0005432075312	6239	Economy	4000.00
0005434444101	6239	Economy	4000.00
0005433497723	6239	Economy	4000.00
0005433497717	6239	Economy	4000.00
0005434926568	6239	Economy	4000.00
0005434926583	6239	Economy	4000.00
0005434926553	6239	Economy	4000.00
0005434926576	6239	Economy	4000.00
0005434926572	6239	Economy	4000.00
0005433497714	6239	Economy	4000.00
0005434926571	6239	Economy	4000.00
0005434444100	6239	Economy	4000.00
0005433497699	6239	Economy	4000.00
0005434926584	6239	Economy	4000.00
0005434926587	6239	Economy	4000.00
0005434444092	6239	Economy	4000.00
0005435257462	20314	Business	11900.00
0005435257453	20314	Business	11900.00
0005435257458	20314	Economy	4000.00
0005435257460	20314	Economy	4000.00
0005435257450	20314	Economy	4400.00
0005435257463	20314	Economy	4000.00
0005435257455	20314	Economy	4000.00
0005435257459	20314	Economy	4000.00
0005435257447	20314	Economy	4000.00
0005435257452	20314	Economy	4000.00
0005435257456	20314	Economy	4000.00
0005435257448	20314	Economy	4000.00
0005435257451	20314	Economy	4000.00
0005435257465	20314	Economy	4000.00
0005435257449	20314	Economy	4000.00
0005435257461	20314	Economy	4000.00
0005435257454	20314	Economy	4000.00
0005435257464	20314	Economy	4000.00
0005435257457	20314	Economy	4000.00
0005434926220	20326	Business	11900.00
0005434443940	20326	Business	11900.00
0005433497404	20326	Business	11900.00
0005434926198	20326	Business	11900.00
0005434926267	20326	Business	11900.00
0005433497489	20326	Business	11900.00
0005434926185	20326	Business	11900.00
0005434926183	20326	Business	11900.00
0005434926221	20326	Business	11900.00
0005433497403	20326	Business	11900.00
0005434926176	20326	Economy	4000.00
0005434926184	20326	Economy	4000.00
0005434926245	20326	Economy	4000.00
0005434926120	20326	Economy	4000.00
0005434443874	20326	Economy	4000.00
0005434443946	20326	Economy	4000.00
0005433497545	20326	Economy	4000.00
0005433497659	20326	Economy	4000.00
0005434926197	20326	Economy	4400.00
0005434443985	20326	Economy	4400.00
0005434443966	20326	Economy	4400.00
0005433497418	20326	Economy	4400.00
0005434443942	20326	Economy	4400.00
0005434443939	20326	Economy	4000.00
0005434926252	20326	Economy	4000.00
0005434926277	20326	Economy	4000.00
0005433497543	20326	Economy	4000.00
0005434926281	20326	Economy	4000.00
0005433497558	20326	Economy	4000.00
0005433497537	20326	Economy	4000.00
0005433497486	20326	Economy	4000.00
0005434443984	20326	Economy	4000.00
0005433497496	20326	Economy	4000.00
0005434444021	20326	Economy	4000.00
0005434926239	20326	Economy	4000.00
0005434443898	20326	Economy	4000.00
0005434443907	20326	Economy	4000.00
0005434443910	20326	Economy	4000.00
0005433497557	20326	Economy	4000.00
0005434926192	20326	Economy	4000.00
0005433497409	20326	Economy	4000.00
0005434926191	20326	Economy	4000.00
0005433497432	20326	Economy	4000.00
0005434444022	20326	Economy	4000.00
0005434926174	20326	Economy	4000.00
0005433497538	20326	Economy	4000.00
0005433497490	20326	Economy	4000.00
0005434443973	20326	Economy	4000.00
0005434926256	20326	Economy	4000.00
0005433497386	20326	Economy	4000.00
0005433497395	20326	Economy	4000.00
0005434926255	20326	Economy	4000.00
0005433497445	20326	Economy	4000.00
0005434926251	20326	Economy	4000.00
0005433497495	20326	Economy	4000.00
0005433497356	20326	Economy	4000.00
0005434926207	20326	Economy	4000.00
0005434443943	20326	Economy	4000.00
0005434926238	20326	Economy	4000.00
0005434926175	20326	Economy	4000.00
0005433497542	20326	Economy	4000.00
0005434443938	20326	Economy	4000.00
0005434926294	20326	Economy	4000.00
0005434443905	20326	Economy	4000.00
0005434926182	20326	Economy	4000.00
0005433497446	20326	Economy	4000.00
0005433497484	20326	Economy	4000.00
0005433497278	20326	Economy	4000.00
0005433497433	20326	Economy	4000.00
0005434926231	20326	Economy	4000.00
0005434926244	20326	Economy	4000.00
0005434926201	20326	Economy	4000.00
0005434443906	20326	Economy	4000.00
0005433497485	20326	Economy	4000.00
0005434926240	20326	Economy	4000.00
0005434926119	20326	Economy	4000.00
0005434926202	20326	Economy	4000.00
0005432784953	12191	Business	41200.00
0005432784668	12191	Business	41200.00
0005435243498	12191	Business	41200.00
0005432784538	12191	Business	41200.00
0005432784920	12191	Business	41200.00
0005435243490	12191	Business	41200.00
0005432784650	12191	Business	41200.00
0005432784278	12191	Business	41200.00
0005432784490	12191	Business	41200.00
0005432784629	12191	Business	41200.00
0005432784823	12191	Economy	13700.00
0005435243502	12191	Economy	13700.00
0005432784669	12191	Economy	13700.00
0005432784794	12191	Economy	13700.00
0005435243487	12191	Economy	13700.00
0005432784696	12191	Economy	13700.00
0005432784426	12191	Economy	13700.00
0005432784438	12191	Economy	13700.00
0005432784481	12191	Economy	13700.00
0005435243489	12191	Economy	13700.00
0005435243486	12191	Economy	15100.00
0005432784525	12191	Economy	15100.00
0005435243484	12191	Economy	15100.00
0005432784726	12191	Economy	15100.00
0005432784699	12191	Economy	15100.00
0005435243491	12191	Economy	13700.00
0005435243508	12191	Economy	13700.00
0005432784710	12191	Economy	13700.00
0005435243505	12191	Economy	13700.00
0005432784718	12191	Economy	13700.00
0005432784822	12191	Economy	13700.00
0005432784719	12191	Economy	13700.00
0005432784597	12191	Economy	13700.00
0005432784815	12191	Economy	13700.00
0005432784483	12191	Economy	13700.00
0005435243503	12191	Economy	13700.00
0005435243497	12191	Economy	13700.00
0005432784390	12191	Economy	13700.00
0005432784662	12191	Economy	13700.00
0005432784524	12191	Economy	13700.00
0005435243507	12191	Economy	13700.00
0005432784425	12191	Economy	13700.00
0005435243493	12191	Economy	13700.00
0005432784617	12191	Economy	13700.00
0005432784711	12191	Economy	13700.00
0005435243509	12191	Economy	13700.00
0005435243485	12191	Economy	13700.00
0005432784603	12191	Economy	13700.00
0005435243492	12191	Economy	13700.00
0005432784559	12191	Economy	13700.00
0005432784604	12191	Economy	13700.00
0005432784342	12191	Economy	13700.00
0005432784704	12191	Economy	13700.00
0005432784664	12191	Economy	13700.00
0005432784614	12191	Economy	13700.00
0005435243494	12191	Economy	13700.00
0005435243500	12191	Economy	13700.00
0005432784547	12191	Economy	13700.00
0005432784632	12191	Economy	13700.00
0005432784391	12191	Economy	13700.00
0005432784633	12191	Economy	13700.00
0005432784556	12191	Economy	13700.00
0005432784572	12191	Economy	13700.00
0005432784392	12191	Economy	13700.00
0005432784550	12191	Economy	13700.00
0005432784548	12191	Economy	13700.00
0005435243506	12191	Economy	13700.00
0005432784549	12191	Economy	13700.00
0005432784700	12191	Economy	13700.00
0005435243510	12191	Economy	13700.00
0005435243496	12191	Economy	13700.00
0005432784475	12191	Economy	13700.00
0005432784440	12191	Economy	13700.00
0005432784709	12191	Economy	13700.00
0005432784734	12191	Economy	13700.00
0005432784661	12191	Economy	13700.00
0005432784341	12191	Economy	13700.00
0005435243501	12191	Economy	13700.00
0005435243499	12191	Economy	13700.00
0005432784712	12191	Economy	13700.00
0005435243504	12191	Economy	13700.00
0005435243488	12191	Economy	13700.00
0005432784437	12191	Economy	13700.00
0005435243495	12191	Economy	13700.00
0005432784573	12191	Economy	13700.00
0005432784730	12191	Economy	13700.00
0005432784593	12191	Economy	13700.00
0005432784439	12191	Economy	13700.00
0005432785015	15456	Business	41200.00
0005432785016	15456	Business	41200.00
0005435243272	15456	Business	41200.00
0005432785027	15456	Business	41200.00
0005432785041	15456	Business	41200.00
0005435243232	15456	Business	41200.00
0005432785036	15456	Business	41200.00
0005435243137	15456	Business	41200.00
0005432785006	15456	Business	41200.00
0005435243233	15456	Business	41200.00
0005432785034	15456	Economy	13700.00
0005432785013	15456	Economy	13700.00
0005435243132	15456	Economy	13700.00
0005435243183	15456	Economy	13700.00
0005432784994	15456	Economy	13700.00
0005435243257	15456	Economy	13700.00
0005432785037	15456	Economy	13700.00
0005435243085	15456	Economy	15100.00
0005435243184	15456	Economy	15100.00
0005432785003	15456	Economy	15100.00
0005432784993	15456	Economy	15100.00
0005432785012	15456	Economy	15100.00
0005435243058	15456	Economy	13700.00
0005432784995	15456	Economy	13700.00
0005435243123	15456	Economy	13700.00
0005435243264	15456	Economy	13700.00
0005432785005	15456	Economy	13700.00
0005435243238	15456	Economy	13700.00
0005435243057	15456	Economy	13700.00
0005432785007	15456	Economy	13700.00
0005435243358	15456	Economy	13700.00
0005432784988	15456	Economy	13700.00
0005432785031	15456	Economy	13700.00
0005432785017	15456	Economy	13700.00
0005432785029	15456	Economy	13700.00
0005432784998	15456	Economy	13700.00
0005435243215	15456	Economy	13700.00
0005432785018	15456	Economy	13700.00
0005435243139	15456	Economy	13700.00
0005435243282	15456	Economy	13700.00
0005432784987	15456	Economy	13700.00
0005432785039	15456	Economy	13700.00
0005432785011	15456	Economy	13700.00
0005432784991	15456	Economy	13700.00
0005435243229	15456	Economy	13700.00
0005435243265	15456	Economy	13700.00
0005432785026	15456	Economy	13700.00
0005432785025	15456	Economy	13700.00
0005432785028	15456	Economy	13700.00
0005435243230	15456	Economy	13700.00
0005432785024	15456	Economy	13700.00
0005432785021	15456	Economy	13700.00
0005432784997	15456	Economy	13700.00
0005435243164	15456	Economy	13700.00
0005432785004	15456	Economy	13700.00
0005435243226	15456	Economy	13700.00
0005432785019	15456	Economy	13700.00
0005432785030	15456	Economy	13700.00
0005432785040	15456	Economy	13700.00
0005432785038	15456	Economy	13700.00
0005432784999	15456	Economy	13700.00
0005432785020	15456	Economy	13700.00
0005432784992	15456	Economy	13700.00
0005435243138	15456	Economy	13700.00
0005435243260	15456	Economy	13700.00
0005432785035	15456	Economy	13700.00
0005432785033	15456	Economy	13700.00
0005432785010	15456	Economy	13700.00
0005432784996	15456	Economy	13700.00
0005432785008	15456	Economy	13700.00
0005435243124	15456	Economy	13700.00
0005432785032	15456	Economy	13700.00
0005432785002	15456	Economy	13700.00
0005432785014	15456	Economy	13700.00
0005432784989	15456	Economy	13700.00
0005432785023	15456	Economy	13700.00
0005432785001	15456	Economy	13700.00
0005435243288	15456	Economy	13700.00
0005435243225	15456	Economy	13700.00
0005432785022	15456	Economy	13700.00
0005432784990	15456	Economy	13700.00
0005432785009	15456	Economy	13700.00
0005435243167	15456	Economy	13700.00
0005432785000	15456	Economy	13700.00
0005434879587	10083	Business	49700.00
0005434879927	10083	Business	49700.00
0005434879956	10083	Business	49700.00
0005434879434	10083	Business	49700.00
0005434879710	10083	Business	49700.00
0005435914056	10083	Business	49700.00
0005434879807	10083	Business	49700.00
0005434879654	10083	Business	49700.00
0005435914059	10083	Business	49700.00
0005434879580	10083	Business	49700.00
0005434879049	10083	Business	49700.00
0005434879556	10083	Business	49700.00
0005434879684	10083	Business	49700.00
0005434879979	10083	Business	49700.00
0005434879573	10083	Business	49700.00
0005434879607	10083	Business	49700.00
0005434879747	10083	Business	49700.00
0005434879409	10083	Business	49700.00
0005434879408	10083	Business	49700.00
0005434879642	10083	Business	49700.00
0005434879798	10083	Economy	16600.00
0005434879617	10083	Economy	16600.00
0005434879839	10083	Economy	16600.00
0005434879479	10083	Economy	16600.00
0005434879572	10083	Economy	16600.00
0005434879725	10083	Economy	16600.00
0005435914057	10083	Economy	16600.00
0005434879805	10083	Economy	16600.00
0005434879777	10083	Economy	16600.00
0005435914054	10083	Economy	16600.00
0005435914047	10083	Economy	16600.00
0005434879280	10083	Economy	16600.00
0005434879414	10083	Economy	16600.00
0005434879778	10083	Economy	18200.00
0005435914062	10083	Economy	18200.00
0005434879603	10083	Economy	18200.00
0005435914048	10083	Economy	18200.00
0005434879503	10083	Economy	16600.00
0005434879441	10083	Economy	16600.00
0005434879804	10083	Economy	16600.00
0005434879639	10083	Economy	16600.00
0005435914053	10083	Economy	16600.00
0005434879649	10083	Economy	16600.00
0005434879653	10083	Economy	16600.00
0005435914058	10083	Economy	16600.00
0005435914065	10083	Economy	16600.00
0005434879211	10083	Economy	16600.00
0005434879586	10083	Economy	16600.00
0005434910166	10083	Economy	16600.00
0005434879463	10083	Economy	16600.00
0005435914063	10083	Economy	16600.00
0005434879828	10083	Economy	16600.00
0005434879916	10083	Economy	16600.00
0005434879663	10083	Economy	16600.00
0005434879325	10083	Economy	16600.00
0005434879323	10083	Economy	16600.00
0005434879364	10083	Economy	16600.00
0005434879774	10083	Economy	16600.00
0005434879648	10083	Economy	16600.00
0005434879746	10083	Economy	16600.00
0005434910167	10083	Economy	16600.00
0005434879701	10083	Economy	16600.00
0005434879806	10083	Economy	16600.00
0005435914069	10083	Economy	16600.00
0005434879410	10083	Economy	16600.00
0005434879827	10083	Economy	16600.00
0005434879775	10083	Economy	16600.00
0005435914070	10083	Economy	16600.00
0005434879711	10083	Economy	16600.00
0005435914051	10083	Economy	16600.00
0005434758923	10083	Economy	16600.00
0005434879575	10083	Economy	16600.00
0005434879647	10083	Economy	16600.00
0005435914050	10083	Economy	16600.00
0005435914064	10083	Economy	16600.00
0005434879813	10083	Economy	16600.00
0005434879685	10083	Economy	16600.00
0005434879712	10083	Economy	16600.00
0005434879214	10083	Economy	16600.00
0005434879210	10083	Economy	16600.00
0005435914068	10083	Economy	16600.00
0005434879517	10083	Economy	16600.00
0005434758922	10083	Economy	16600.00
0005434879326	10083	Economy	16600.00
0005434879803	10083	Economy	16600.00
0005435914049	10083	Economy	16600.00
0005434879535	10083	Economy	16600.00
0005434879618	10083	Economy	16600.00
0005434879958	10083	Economy	16600.00
0005434879796	10083	Economy	16600.00
0005434879513	10083	Economy	16600.00
0005434879724	10083	Economy	16600.00
0005434879722	10083	Economy	16600.00
0005434879557	10083	Economy	16600.00
0005434879574	10083	Economy	16600.00
0005434879882	10083	Economy	16600.00
0005434879959	10083	Economy	16600.00
0005434879707	10083	Economy	16600.00
0005435914066	10083	Economy	16600.00
0005435914071	10083	Economy	16600.00
0005435914072	10083	Economy	16600.00
0005435914052	10083	Economy	16600.00
0005434879705	10083	Economy	16600.00
0005434879619	10083	Economy	16600.00
0005434758926	10083	Economy	16600.00
0005435914061	10083	Economy	16600.00
0005435914067	10083	Economy	16600.00
0005434879622	10083	Economy	16600.00
0005434879343	10083	Economy	16600.00
0005434879867	10083	Economy	16600.00
0005435914060	10083	Economy	16600.00
0005434879985	10083	Economy	16600.00
0005435914055	10083	Economy	16600.00
0005434879655	10083	Economy	16600.00
0005434879900	10083	Economy	16600.00
0005434910168	10083	Economy	16600.00
0005434880419	14636	Business	49700.00
0005434880478	14636	Business	49700.00
0005434880494	14636	Business	49700.00
0005434880433	14636	Business	49700.00
0005434880432	14636	Business	49700.00
0005434880415	14636	Business	49700.00
0005434880441	14636	Business	49700.00
0005434880485	14636	Business	49700.00
0005434880406	14636	Business	49700.00
0005434880479	14636	Business	49700.00
0005434880423	14636	Business	49700.00
0005434880459	14636	Business	49700.00
0005434880446	14636	Business	49700.00
0005434880452	14636	Business	49700.00
0005434880449	14636	Business	49700.00
0005434880469	14636	Business	49700.00
0005434880451	14636	Business	49700.00
0005434758948	14636	Business	49700.00
0005434880481	14636	Business	49700.00
0005434880454	14636	Economy	16600.00
0005434880416	14636	Economy	16600.00
0005434880455	14636	Economy	16600.00
0005434880475	14636	Economy	16600.00
0005434880463	14636	Economy	16600.00
0005434880465	14636	Economy	16600.00
0005434880460	14636	Economy	16600.00
0005434880443	14636	Economy	16600.00
0005434880430	14636	Economy	16600.00
0005434880418	14636	Economy	18200.00
0005434880427	14636	Economy	18200.00
0005434880445	14636	Economy	18200.00
0005434880495	14636	Economy	18200.00
0005434880409	14636	Economy	16600.00
0005434880424	14636	Economy	16600.00
0005434880471	14636	Economy	16600.00
0005434880492	14636	Economy	16600.00
0005434880458	14636	Economy	16600.00
0005434880486	14636	Economy	16600.00
0005434880489	14636	Economy	16600.00
0005434880467	14636	Economy	16600.00
0005434880440	14636	Economy	16600.00
0005434880490	14636	Economy	16600.00
0005434880474	14636	Economy	16600.00
0005434880414	14636	Economy	16600.00
0005434880422	14636	Economy	16600.00
0005434880497	14636	Economy	16600.00
0005434880408	14636	Economy	16600.00
0005435913968	14636	Economy	16600.00
0005434880407	14636	Economy	16600.00
0005434880466	14636	Economy	16600.00
0005434910148	14636	Economy	16600.00
0005434880421	14636	Economy	16600.00
0005434910149	14636	Economy	16600.00
0005434880498	14636	Economy	16600.00
0005434880448	14636	Economy	16600.00
0005434758949	14636	Economy	16600.00
0005434880431	14636	Economy	16600.00
0005434880429	14636	Economy	16600.00
0005434880472	14636	Economy	16600.00
0005434880480	14636	Economy	16600.00
0005434880483	14636	Economy	16600.00
0005434880442	14636	Economy	16600.00
0005434880493	14636	Economy	16600.00
0005434880501	14636	Economy	16600.00
0005434880499	14636	Economy	16600.00
0005434880468	14636	Economy	16600.00
0005434880473	14636	Economy	16600.00
0005434880488	14636	Economy	16600.00
0005434880413	14636	Economy	16600.00
0005434880410	14636	Economy	16600.00
0005434880444	14636	Economy	16600.00
0005434880447	14636	Economy	16600.00
0005434880437	14636	Economy	16600.00
0005434880476	14636	Economy	16600.00
0005434880462	14636	Economy	16600.00
0005434880464	14636	Economy	16600.00
0005434880425	14636	Economy	16600.00
0005434880484	14636	Economy	16600.00
0005434880450	14636	Economy	16600.00
0005434880439	14636	Economy	16600.00
0005434880438	14636	Economy	16600.00
0005434880491	14636	Economy	16600.00
0005434880456	14636	Economy	16600.00
0005435913967	14636	Economy	16600.00
0005434880482	14636	Economy	16600.00
0005434880457	14636	Economy	16600.00
0005434758950	14636	Economy	16600.00
0005434880436	14636	Economy	16600.00
0005434880405	14636	Economy	16600.00
0005434880428	14636	Economy	16600.00
0005434880470	14636	Economy	16600.00
0005434880487	14636	Economy	16600.00
0005434880411	14636	Economy	16600.00
0005434880500	14636	Economy	16600.00
0005434880420	14636	Economy	16600.00
0005434880426	14636	Economy	16600.00
0005434880496	14636	Economy	16600.00
0005434880453	14636	Economy	16600.00
0005434880435	14636	Economy	16600.00
0005434880417	14636	Economy	16600.00
0005434880412	14636	Economy	16600.00
0005434880477	14636	Economy	16600.00
0005434880461	14636	Economy	16600.00
0005434880434	14636	Economy	16600.00
0005434910146	14636	Economy	16600.00
0005434252063	9212	Economy	22400.00
0005434252095	9212	Economy	22400.00
0005435660404	9212	Economy	20300.00
0005435660400	9212	Economy	20300.00
0005435660407	9212	Economy	20300.00
0005435660406	9212	Economy	20300.00
0005435660405	9212	Economy	20300.00
0005435660402	9212	Economy	20300.00
0005434252033	9212	Economy	20300.00
0005434252034	9212	Economy	20300.00
0005435660399	9212	Economy	20300.00
0005434252069	9212	Economy	20300.00
0005435660397	9212	Economy	20300.00
0005435660403	9212	Economy	20300.00
0005434252079	9212	Economy	20300.00
0005434252116	9212	Economy	20300.00
0005434252077	9212	Economy	20300.00
0005435660398	9212	Economy	20300.00
0005434252115	9212	Economy	20300.00
0005434252120	9212	Economy	20300.00
0005434252138	9212	Economy	20300.00
0005435660401	9212	Economy	20300.00
0005434252137	9212	Economy	20300.00
0005435660313	24673	Economy	22400.00
0005434252185	24673	Economy	20300.00
0005434252193	24673	Economy	20300.00
0005434252189	24673	Economy	20300.00
0005435660304	24673	Economy	20300.00
0005435660267	24673	Economy	20300.00
0005434252184	24673	Economy	20300.00
0005435660302	24673	Economy	20300.00
0005435660303	24673	Economy	20300.00
0005434252190	24673	Economy	20300.00
0005434252186	24673	Economy	20300.00
0005435660362	24673	Economy	20300.00
0005434252192	24673	Economy	20300.00
0005435660292	24673	Economy	20300.00
0005435660329	24673	Economy	20300.00
0005435660328	24673	Economy	20300.00
0005435660349	24673	Economy	20300.00
0005435660338	24673	Economy	20300.00
0005434252187	24673	Economy	20300.00
0005435660311	24673	Economy	20300.00
0005434252191	24673	Economy	20300.00
0005434252188	24673	Economy	20300.00
0005435660327	24673	Economy	20300.00
0005435660310	24673	Economy	20300.00
0005433681691	2795	Business	33000.00
0005433681700	2795	Business	33000.00
0005433681680	2795	Business	33000.00
0005433681675	2795	Business	33000.00
0005433681678	2795	Business	33000.00
0005433681701	2795	Business	33000.00
0005433681696	2795	Business	33000.00
0005433681683	2795	Business	33000.00
0005433681687	2795	Business	33000.00
0005433681703	2795	Economy	11000.00
0005432967429	2795	Economy	11000.00
0005432967248	2795	Economy	11000.00
0005433681684	2795	Economy	11000.00
0005432967272	2795	Economy	11000.00
0005432967346	2795	Economy	11000.00
0005432967410	2795	Economy	11000.00
0005433681710	2795	Economy	11000.00
0005433681673	2795	Economy	11000.00
0005432967265	2795	Economy	12100.00
0005433681677	2795	Economy	12100.00
0005433681679	2795	Economy	12100.00
0005432222908	2795	Economy	12100.00
0005432967301	2795	Economy	12100.00
0005433681694	2795	Economy	11000.00
0005432222907	2795	Economy	11000.00
0005432967266	2795	Economy	11000.00
0005432967303	2795	Economy	11000.00
0005433681662	2795	Economy	11000.00
0005433681692	2795	Economy	11000.00
0005433681704	2795	Economy	11000.00
0005433681666	2795	Economy	11000.00
0005432967411	2795	Economy	11000.00
0005432967361	2795	Economy	11000.00
0005433681667	2795	Economy	11000.00
0005432222904	2795	Economy	11000.00
0005433681690	2795	Economy	11000.00
0005433681708	2795	Economy	11000.00
0005433681663	2795	Economy	11000.00
0005433681702	2795	Economy	11000.00
0005432967329	2795	Economy	11000.00
0005433681668	2795	Economy	11000.00
0005433681707	2795	Economy	11000.00
0005433681686	2795	Economy	11000.00
0005433681674	2795	Economy	11000.00
0005433681671	2795	Economy	11000.00
0005433681676	2795	Economy	11000.00
0005432967285	2795	Economy	11000.00
0005432967406	2795	Economy	11000.00
0005433681685	2795	Economy	11000.00
0005432967290	2795	Economy	11000.00
0005432967209	2795	Economy	11000.00
0005433681670	2795	Economy	11000.00
0005433681669	2795	Economy	11000.00
0005433681693	2795	Economy	11000.00
0005433684468	2795	Economy	11000.00
0005432222909	2795	Economy	11000.00
0005432222906	2795	Economy	11000.00
0005433681664	2795	Economy	11000.00
0005432222905	2795	Economy	11000.00
0005433681697	2795	Economy	11000.00
0005433681695	2795	Economy	11000.00
0005432967401	2795	Economy	11000.00
0005433681665	2795	Economy	11000.00
0005432967292	2795	Economy	11000.00
0005433681688	2795	Economy	11000.00
0005433681681	2795	Economy	11000.00
0005433681689	2795	Economy	11000.00
0005433681705	2795	Economy	11000.00
0005433681682	2795	Economy	11000.00
0005433681672	2795	Economy	11000.00
0005433681699	2795	Economy	11000.00
0005433681698	2795	Economy	11000.00
0005432967412	2795	Economy	11000.00
0005432967345	2795	Economy	11000.00
0005433681709	2795	Economy	11000.00
0005432967328	2795	Economy	11000.00
0005432967242	2795	Economy	11000.00
0005433684467	2795	Economy	11000.00
0005433681706	2795	Economy	11000.00
0005433681257	29190	Business	33000.00
0005433684458	29190	Business	33000.00
0005433681342	29190	Business	33000.00
0005433681444	29190	Business	33000.00
0005432967535	29190	Business	33000.00
0005432967546	29190	Business	33000.00
0005433681256	29190	Business	33000.00
0005432005279	29190	Business	33000.00
0005433681441	29190	Business	33000.00
0005433681317	29190	Business	33000.00
0005432967540	29190	Economy	11000.00
0005432967539	29190	Economy	11000.00
0005432967527	29190	Economy	11000.00
0005433681283	29190	Economy	11000.00
0005432967550	29190	Economy	11000.00
0005433681177	29190	Economy	11000.00
0005433681277	29190	Economy	11000.00
0005433687747	29190	Economy	12100.00
0005432967544	29190	Economy	12100.00
0005433681324	29190	Economy	12100.00
0005433681198	29190	Economy	12100.00
0005433681276	29190	Economy	12100.00
0005433681421	29190	Economy	11000.00
0005432967542	29190	Economy	11000.00
0005433681197	29190	Economy	11000.00
0005433681311	29190	Economy	11000.00
0005433681344	29190	Economy	11000.00
0005432967548	29190	Economy	11000.00
0005432967532	29190	Economy	11000.00
0005432967526	29190	Economy	11000.00
0005433681420	29190	Economy	11000.00
0005432967538	29190	Economy	11000.00
0005432967537	29190	Economy	11000.00
0005432005281	29190	Economy	11000.00
0005432005280	29190	Economy	11000.00
0005433681261	29190	Economy	11000.00
0005432967549	29190	Economy	11000.00
0005433681316	29190	Economy	11000.00
0005432967534	29190	Economy	11000.00
0005432967541	29190	Economy	11000.00
0005432967547	29190	Economy	11000.00
0005432967525	29190	Economy	11000.00
0005432967528	29190	Economy	11000.00
0005433681309	29190	Economy	11000.00
0005433681465	29190	Economy	11000.00
0005433681291	29190	Economy	11000.00
0005433681509	29190	Economy	11000.00
0005433681609	29190	Economy	11000.00
0005433681445	29190	Economy	11000.00
0005432967530	29190	Economy	11000.00
0005433681510	29190	Economy	11000.00
0005433681466	29190	Economy	11000.00
0005432967529	29190	Economy	11000.00
0005432967533	29190	Economy	11000.00
0005433681335	29190	Economy	11000.00
0005433681437	29190	Economy	11000.00
0005433681284	29190	Economy	11000.00
0005432967543	29190	Economy	11000.00
0005433681206	29190	Economy	11000.00
0005432967536	29190	Economy	11000.00
0005433681318	29190	Economy	11000.00
0005433681199	29190	Economy	11000.00
0005433681343	29190	Economy	11000.00
0005433681323	29190	Economy	11000.00
0005433687729	29190	Economy	11000.00
0005433681325	29190	Economy	11000.00
0005433690949	29190	Economy	11000.00
0005432967545	29190	Economy	11000.00
0005433681175	29190	Economy	11000.00
0005433681330	29190	Economy	11000.00
0005433681449	29190	Economy	11000.00
0005432967531	29190	Economy	11000.00
0005433616333	9292	Business	132900.00
0005433578129	9292	Business	132900.00
0005433634602	9292	Business	132900.00
0005433616378	9292	Business	132900.00
0005433616357	9292	Business	132900.00
0005433616330	9292	Business	132900.00
0005433634574	9292	Business	132900.00
0005433616309	9292	Business	132900.00
0005434152818	9292	Business	132900.00
0005433616372	9292	Business	132900.00
0005434269133	9292	Business	132900.00
0005433634601	9292	Business	132900.00
0005434269134	9292	Business	132900.00
0005434269132	9292	Business	132900.00
0005433616328	9292	Business	132900.00
0005433616375	9292	Business	132900.00
0005433634585	9292	Business	132900.00
0005433616343	9292	Business	132900.00
0005433578127	9292	Business	132900.00
0005433634604	9292	Business	132900.00
0005434163769	9292	Business	132900.00
0005433616365	9292	Business	132900.00
0005433634586	9292	Business	132900.00
0005433578131	9292	Business	132900.00
0005433616374	9292	Business	132900.00
0005433578120	9292	Business	132900.00
0005433616373	9292	Economy	48700.00
0005433616355	9292	Economy	48700.00
0005433634600	9292	Economy	48700.00
0005433616371	9292	Economy	48700.00
0005434163781	9292	Economy	48700.00
0005434163747	9292	Economy	48700.00
0005433616331	9292	Economy	44300.00
0005433616361	9292	Economy	44300.00
0005434152817	9292	Economy	44300.00
0005433616310	9292	Economy	44300.00
0005433634577	9292	Economy	44300.00
0005433616317	9292	Economy	44300.00
0005433634587	9292	Economy	44300.00
0005433634579	9292	Economy	44300.00
0005433616340	9292	Economy	44300.00
0005433634578	9292	Economy	44300.00
0005433634596	9292	Economy	44300.00
0005432756925	9292	Economy	44300.00
0005433616319	9292	Economy	44300.00
0005433634595	9292	Economy	44300.00
0005433634599	9292	Economy	44300.00
0005433616337	9292	Economy	44300.00
0005434163775	9292	Economy	44300.00
0005433634576	9292	Economy	44300.00
0005433616376	9292	Economy	44300.00
0005434163782	9292	Economy	44300.00
0005434163763	9292	Economy	44300.00
0005433616362	9292	Economy	44300.00
0005433616377	9292	Economy	44300.00
0005433616369	9292	Economy	44300.00
0005433616345	9292	Economy	44300.00
0005433616324	9292	Economy	44300.00
0005433616338	9292	Economy	44300.00
0005433634605	9292	Economy	44300.00
0005433634581	9292	Economy	44300.00
0005433634608	9292	Economy	44300.00
0005433616346	9292	Economy	44300.00
0005434163746	9292	Economy	44300.00
0005433616312	9292	Economy	44300.00
0005432756924	9292	Economy	44300.00
0005433616325	9292	Economy	44300.00
0005434163717	9292	Economy	44300.00
0005433616336	9292	Economy	44300.00
0005433616368	9292	Economy	44300.00
0005434163764	9292	Economy	44300.00
0005433634583	9292	Economy	44300.00
0005434152822	9292	Economy	44300.00
0005434163774	9292	Economy	44300.00
0005433578122	9292	Economy	44300.00
0005433616352	9292	Economy	44300.00
0005433616320	9292	Economy	44300.00
0005433616322	9292	Economy	44300.00
0005433616342	9292	Economy	44300.00
0005434152823	9292	Economy	44300.00
0005433616332	9292	Economy	44300.00
0005433616344	9292	Economy	44300.00
0005433616348	9292	Economy	44300.00
0005433616311	9292	Economy	44300.00
0005433616318	9292	Economy	44300.00
0005433616307	9292	Economy	44300.00
0005432755154	9292	Economy	44300.00
0005433616359	9292	Economy	48700.00
0005433616316	9292	Economy	48700.00
0005433616323	9292	Economy	48700.00
0005433634575	9292	Economy	44300.00
0005433634584	9292	Economy	48700.00
0005433578123	9292	Economy	44300.00
0005434152816	9292	Economy	44300.00
0005433616335	9292	Economy	44300.00
0005433616358	9292	Economy	44300.00
0005434152820	9292	Economy	44300.00
0005433616327	9292	Economy	44300.00
0005433634589	9292	Economy	44300.00
0005433616349	9292	Economy	44300.00
0005433634580	9292	Economy	44300.00
0005433616334	9292	Economy	44300.00
0005433616354	9292	Economy	44300.00
0005433578125	9292	Economy	44300.00
0005433616363	9292	Economy	44300.00
0005433616366	9292	Economy	44300.00
0005433578126	9292	Economy	44300.00
0005433616313	9292	Economy	44300.00
0005432145158	9292	Economy	44300.00
0005433634590	9292	Economy	44300.00
0005433616360	9292	Economy	44300.00
0005433616329	9292	Economy	44300.00
0005433634598	9292	Economy	44300.00
0005433634606	9292	Economy	44300.00
0005432756928	9292	Economy	44300.00
0005433616364	9292	Economy	44300.00
0005433634603	9292	Economy	44300.00
0005433634592	9292	Economy	44300.00
0005433634594	9292	Economy	44300.00
0005433616370	9292	Economy	44300.00
0005433634593	9292	Economy	44300.00
0005433578121	9292	Economy	44300.00
0005432145157	9292	Economy	44300.00
0005433616367	9292	Economy	44300.00
0005434152819	9292	Economy	44300.00
0005433634609	9292	Economy	44300.00
0005433634582	9292	Economy	44300.00
0005433616326	9292	Economy	44300.00
0005434163773	9292	Economy	44300.00
0005433616341	9292	Economy	44300.00
0005433578130	9292	Economy	44300.00
0005434163770	9292	Economy	44300.00
0005433616353	9292	Economy	44300.00
0005433616339	9292	Economy	44300.00
0005433616347	9292	Economy	44300.00
0005433634588	9292	Economy	44300.00
0005433616305	9292	Economy	44300.00
0005433616356	9292	Economy	44300.00
0005433634607	9292	Economy	44300.00
0005433616321	9292	Economy	44300.00
0005433578124	9292	Economy	44300.00
0005433616350	9292	Economy	44300.00
0005433616379	9292	Economy	44300.00
0005432756926	9292	Economy	44300.00
0005433616351	9292	Economy	44300.00
0005432756927	9292	Economy	44300.00
0005433616315	9292	Economy	44300.00
0005433578128	9292	Economy	44300.00
0005433634597	9292	Economy	44300.00
0005433616306	9292	Economy	44300.00
0005433634591	9292	Economy	44300.00
0005433616314	9292	Economy	44300.00
0005434272213	9292	Economy	44300.00
0005433616308	9292	Economy	44300.00
0005433616000	25254	Business	132900.00
0005433577986	25254	Business	132900.00
0005433634197	25254	Business	132900.00
0005433615852	25254	Business	132900.00
0005433615853	25254	Business	132900.00
0005433615892	25254	Business	132900.00
0005433615813	25254	Business	132900.00
0005433615801	25254	Business	132900.00
0005433577997	25254	Business	132900.00
0005433634382	25254	Business	132900.00
0005433634390	25254	Business	132900.00
0005433578014	25254	Business	132900.00
0005433615918	25254	Business	132900.00
0005433615978	25254	Business	132900.00
0005433615846	25254	Business	132900.00
0005433615926	25254	Business	132900.00
0005433615704	25254	Business	132900.00
0005433577985	25254	Business	132900.00
0005433634251	25254	Business	132900.00
0005433634340	25254	Business	132900.00
0005433634294	25254	Business	132900.00
0005434163824	25254	Business	132900.00
0005433634411	25254	Economy	48700.00
0005433578051	25254	Economy	48700.00
0005433615706	25254	Economy	48700.00
0005433615891	25254	Economy	48700.00
0005433615705	25254	Economy	48700.00
0005433634285	25254	Economy	44300.00
0005433577962	25254	Economy	44300.00
0005433634296	25254	Economy	44300.00
0005433615683	25254	Economy	44300.00
0005433615812	25254	Economy	44300.00
0005434272224	25254	Economy	44300.00
0005433577996	25254	Economy	44300.00
0005433634315	25254	Economy	44300.00
0005435854077	25254	Economy	44300.00
0005433615917	25254	Economy	44300.00
0005433578052	25254	Economy	44300.00
0005433615641	25254	Economy	44300.00
0005433615607	25254	Economy	44300.00
0005434163828	25254	Economy	44300.00
0005433634069	25254	Economy	44300.00
0005433615614	25254	Economy	44300.00
0005433615800	25254	Economy	44300.00
0005433615502	25254	Economy	44300.00
0005434163829	25254	Economy	44300.00
0005433634295	25254	Economy	44300.00
0005433615764	25254	Economy	44300.00
0005433615799	25254	Economy	44300.00
0005433634068	25254	Economy	44300.00
0005433615509	25254	Economy	44300.00
0005433615707	25254	Economy	44300.00
0005433615589	25254	Economy	44300.00
0005433578024	25254	Economy	44300.00
0005433634177	25254	Economy	44300.00
0005433615773	25254	Economy	44300.00
0005433615890	25254	Economy	44300.00
0005434163827	25254	Economy	44300.00
0005433577999	25254	Economy	44300.00
0005433634367	25254	Economy	44300.00
0005433615832	25254	Economy	44300.00
0005433634310	25254	Economy	44300.00
0005433634356	25254	Economy	44300.00
0005433615590	25254	Economy	44300.00
0005433615659	25254	Economy	44300.00
0005434272225	25254	Economy	44300.00
0005433615592	25254	Economy	44300.00
0005433615645	25254	Economy	44300.00
0005433634178	25254	Economy	44300.00
0005433615511	25254	Economy	44300.00
0005433616051	25254	Economy	44300.00
0005433578006	25254	Economy	44300.00
0005433615786	25254	Economy	48700.00
0005433634212	25254	Economy	48700.00
0005433615759	25254	Economy	48700.00
0005433577976	25254	Economy	48700.00
0005434163830	25254	Economy	48700.00
0005433577987	25254	Economy	44300.00
0005434273111	25254	Economy	44300.00
0005433615760	25254	Economy	44300.00
0005433615676	25254	Economy	48700.00
0005433615600	25254	Economy	44300.00
0005433616027	25254	Economy	44300.00
0005433615900	25254	Economy	44300.00
0005434273112	25254	Economy	44300.00
0005433577998	25254	Economy	44300.00
0005434163826	25254	Economy	44300.00
0005433634221	25254	Economy	44300.00
0005433615873	25254	Economy	44300.00
0005433615703	25254	Economy	44300.00
0005433615817	25254	Economy	44300.00
0005433577990	25254	Economy	44300.00
0005434163821	25254	Economy	44300.00
0005433577995	25254	Economy	44300.00
0005433615989	25254	Economy	44300.00
0005433615510	25254	Economy	44300.00
0005433577989	25254	Economy	44300.00
0005433615835	25254	Economy	44300.00
0005434163820	25254	Economy	44300.00
0005433634387	25254	Economy	44300.00
0005433634383	25254	Economy	44300.00
0005434163825	25254	Economy	44300.00
0005433615606	25254	Economy	44300.00
0005433577915	25254	Economy	44300.00
0005435854075	25254	Economy	44300.00
0005433615710	25254	Economy	44300.00
0005433615603	25254	Economy	44300.00
0005433615763	25254	Economy	44300.00
0005433615688	25254	Economy	44300.00
0005433634316	25254	Economy	44300.00
0005433615758	25254	Economy	44300.00
0005433615619	25254	Economy	44300.00
0005433578039	25254	Economy	44300.00
0005433615927	25254	Economy	44300.00
0005433634366	25254	Economy	44300.00
0005433615557	25254	Economy	44300.00
0005435854076	25254	Economy	44300.00
0005433634173	25254	Economy	44300.00
0005433634389	25254	Economy	44300.00
0005433615555	25254	Economy	44300.00
0005433634264	25254	Economy	44300.00
0005433634363	25254	Economy	44300.00
0005433615919	25254	Economy	44300.00
0005433615568	25254	Economy	44300.00
0005434163822	25254	Economy	44300.00
0005433615734	25254	Economy	44300.00
0005433615642	25254	Economy	44300.00
0005433615486	25254	Economy	44300.00
0005433615977	25254	Economy	44300.00
0005433615558	25254	Economy	44300.00
0005433615470	25254	Economy	44300.00
0005434163823	25254	Economy	44300.00
0005433615620	25254	Economy	44300.00
0005433615491	25254	Economy	44300.00
0005435947460	4210	Business	193100.00
0005435986943	4210	Business	193100.00
0005435856263	4210	Business	193100.00
0005435856277	4210	Business	193100.00
0005435986931	4210	Business	193100.00
0005435986942	4210	Business	193100.00
0005434271331	4210	Economy	70800.00
0005435947441	4210	Economy	64400.00
0005435986944	4210	Economy	64400.00
0005435947445	4210	Economy	64400.00
0005435986946	4210	Economy	64400.00
0005435986952	4210	Economy	64400.00
0005435947528	4210	Economy	64400.00
0005435986950	4210	Economy	64400.00
0005432571380	4210	Economy	64400.00
0005435986933	4210	Economy	64400.00
0005432571381	4210	Economy	64400.00
0005435787377	4210	Economy	64400.00
0005435947503	4210	Economy	64400.00
0005435986954	4210	Economy	64400.00
0005435787379	4210	Economy	64400.00
0005435947485	4210	Economy	64400.00
0005432185018	4210	Economy	64400.00
0005435986940	4210	Economy	64400.00
0005435787378	4210	Economy	64400.00
0005435986948	4210	Economy	64400.00
0005432571373	4210	Economy	64400.00
0005435947470	4210	Economy	64400.00
0005435856267	4210	Economy	64400.00
0005432185019	4210	Economy	64400.00
0005432571390	4210	Economy	64400.00
0005435986939	4210	Economy	64400.00
0005435856276	4210	Economy	70800.00
0005435986936	4210	Economy	64400.00
0005435986938	4210	Economy	64400.00
0005435947469	4210	Economy	64400.00
0005435986955	4210	Economy	64400.00
0005435856264	4210	Economy	64400.00
0005432185017	4210	Economy	64400.00
0005435986953	4210	Economy	64400.00
0005435986937	4210	Economy	64400.00
0005435947504	4210	Economy	64400.00
0005435986941	4210	Economy	64400.00
0005435986949	4210	Economy	64400.00
0005435986947	4210	Economy	64400.00
0005435986945	4210	Economy	64400.00
0005435947442	4210	Economy	64400.00
0005432571387	4210	Economy	64400.00
0005435856271	4210	Economy	64400.00
0005435947476	4210	Economy	64400.00
0005435856262	4210	Economy	64400.00
0005435947461	4210	Economy	64400.00
0005435986934	4210	Economy	64400.00
0005434271346	4210	Economy	64400.00
0005432571374	4210	Economy	64400.00
0005435986951	4210	Economy	64400.00
0005435986935	4210	Economy	64400.00
0005435986932	4210	Economy	64400.00
0005434271340	4210	Economy	64400.00
0005435856272	4210	Economy	64400.00
0005432571412	26576	Business	193100.00
0005435947593	26576	Business	193100.00
0005435947599	26576	Business	193100.00
0005435986856	26576	Business	193100.00
0005435947598	26576	Economy	70800.00
0005435947600	26576	Economy	70800.00
0005435986848	26576	Economy	64400.00
0005435856338	26576	Economy	64400.00
0005435947603	26576	Economy	64400.00
0005432571415	26576	Economy	64400.00
0005435856304	26576	Economy	64400.00
0005435947597	26576	Economy	64400.00
0005435787404	26576	Economy	64400.00
0005435986825	26576	Economy	64400.00
0005435947605	26576	Economy	64400.00
0005435947594	26576	Economy	64400.00
0005435947607	26576	Economy	64400.00
0005435947606	26576	Economy	70800.00
0005432571414	26576	Economy	64400.00
0005435787406	26576	Economy	64400.00
0005435787405	26576	Economy	64400.00
0005435947596	26576	Economy	64400.00
0005435947602	26576	Economy	64400.00
0005435856340	26576	Economy	64400.00
0005435856339	26576	Economy	64400.00
0005435856306	26576	Economy	64400.00
0005432571416	26576	Economy	64400.00
0005435856305	26576	Economy	64400.00
0005435947595	26576	Economy	64400.00
0005435947604	26576	Economy	64400.00
0005435947601	26576	Economy	64400.00
0005435856337	26576	Economy	64400.00
0005432571413	26576	Economy	64400.00
0005433129331	345	Business	21500.00
0005433570535	345	Business	21500.00
0005433570541	345	Business	21500.00
0005433570526	345	Business	21500.00
0005432948930	345	Business	21500.00
0005433570554	345	Business	21500.00
0005433075258	345	Business	21500.00
0005433075108	345	Business	21500.00
0005433570559	345	Business	21500.00
0005433570527	345	Business	21500.00
0005432949059	345	Business	21500.00
0005433570521	345	Business	21500.00
0005432949196	345	Business	21500.00
0005433075052	345	Business	21500.00
0005433075232	345	Business	21500.00
0005433570505	345	Business	21500.00
0005432948912	345	Business	21500.00
0005432949072	345	Business	21500.00
0005433570519	345	Business	21500.00
0005433570501	345	Business	21500.00
0005432949058	345	Business	21500.00
0005432948905	345	Business	21500.00
0005432949085	345	Business	21500.00
0005433570546	345	Business	21500.00
0005433570565	345	Business	21500.00
0005433570544	345	Business	21500.00
0005433570511	345	Business	21500.00
0005433075110	345	Business	21500.00
0005432948913	345	Economy	7900.00
0005432949014	345	Economy	7900.00
0005433075111	345	Economy	7900.00
0005433570533	345	Economy	7900.00
0005432949008	345	Economy	7900.00
0005433570516	345	Economy	7900.00
0005432949133	345	Economy	7200.00
0005433570562	345	Economy	7200.00
0005432239085	345	Economy	7200.00
0005433075128	345	Economy	7200.00
0005432239082	345	Economy	7200.00
0005432948991	345	Economy	7200.00
0005433075113	345	Economy	7200.00
0005432239084	345	Economy	7200.00
0005433570560	345	Economy	7200.00
0005433570550	345	Economy	7200.00
0005432239079	345	Economy	7200.00
0005432949195	345	Economy	7200.00
0005432949093	345	Economy	7200.00
0005433570522	345	Economy	7200.00
0005433570551	345	Economy	7200.00
0005433570547	345	Economy	7200.00
0005433570512	345	Economy	7200.00
0005432949147	345	Economy	7200.00
0005432948952	345	Economy	7200.00
0005433075158	345	Economy	7200.00
0005433075186	345	Economy	7200.00
0005433570539	345	Economy	7200.00
0005432239083	345	Economy	7200.00
0005433075231	345	Economy	7200.00
0005433075129	345	Economy	7200.00
0005433129357	345	Economy	7200.00
0005433075024	345	Economy	7200.00
0005433075259	345	Economy	7200.00
0005433570553	345	Economy	7200.00
0005433075114	345	Economy	7200.00
0005433570549	345	Economy	7200.00
0005433570508	345	Economy	7200.00
0005433570564	345	Economy	7200.00
0005433570536	345	Economy	7200.00
0005433570503	345	Economy	7200.00
0005432949063	345	Economy	7200.00
0005433075230	345	Economy	7200.00
0005433570568	345	Economy	7200.00
0005433570520	345	Economy	7200.00
0005433570530	345	Economy	7200.00
0005432948869	345	Economy	7200.00
0005433570529	345	Economy	7200.00
0005433075139	345	Economy	7200.00
0005433570567	345	Economy	7200.00
0005433570552	345	Economy	7200.00
0005432948951	345	Economy	7200.00
0005433570515	345	Economy	7200.00
0005433570502	345	Economy	7200.00
0005433570542	345	Economy	7200.00
0005433075159	345	Economy	7200.00
0005432239081	345	Economy	7200.00
0005433570557	345	Economy	7200.00
0005433570532	345	Economy	7200.00
0005433075135	345	Economy	7200.00
0005432949171	345	Economy	7200.00
0005433570540	345	Economy	7200.00
0005433570499	345	Economy	7200.00
0005432948974	345	Economy	7200.00
0005432948925	345	Economy	7200.00
0005433570509	345	Economy	7200.00
0005433570525	345	Economy	7900.00
0005432949197	345	Economy	7900.00
0005433570524	345	Economy	7900.00
0005433570517	345	Economy	7900.00
0005432949071	345	Economy	7900.00
0005433570513	345	Economy	7200.00
0005433075130	345	Economy	7200.00
0005432949121	345	Economy	7200.00
0005433570518	345	Economy	7900.00
0005433075211	345	Economy	7200.00
0005433570514	345	Economy	7200.00
0005433075197	345	Economy	7200.00
0005433570563	345	Economy	7200.00
0005433129337	345	Economy	7200.00
0005433570523	345	Economy	7200.00
0005432948989	345	Economy	7200.00
0005433570555	345	Economy	7200.00
0005432949009	345	Economy	7200.00
0005433570561	345	Economy	7200.00
0005433570534	345	Economy	7200.00
0005433075187	345	Economy	7200.00
0005433570504	345	Economy	7200.00
0005432949134	345	Economy	7200.00
0005433570500	345	Economy	7200.00
0005432239080	345	Economy	7200.00
0005432949088	345	Economy	7200.00
0005433075233	345	Economy	7200.00
0005433134207	345	Economy	7200.00
0005432949023	345	Economy	7200.00
0005433570537	345	Economy	7200.00
0005432948942	345	Economy	7200.00
0005432948992	345	Economy	7200.00
0005433075109	345	Economy	7200.00
0005433075058	345	Economy	7200.00
0005433570531	345	Economy	7200.00
0005433570556	345	Economy	7200.00
0005432948907	345	Economy	7200.00
0005432949015	345	Economy	7200.00
0005433570558	345	Economy	7200.00
0005433570545	345	Economy	7200.00
0005433075025	345	Economy	7200.00
0005433075205	345	Economy	7200.00
0005433570538	345	Economy	7200.00
0005432949128	345	Economy	7200.00
0005432948807	345	Economy	7200.00
0005432949120	345	Economy	7200.00
0005433570528	345	Economy	7200.00
0005433570543	345	Economy	7200.00
0005433075073	345	Economy	7200.00
0005433129332	345	Economy	7200.00
0005433570510	345	Economy	7200.00
0005433075157	345	Economy	7200.00
0005433075198	345	Economy	7200.00
0005432948909	345	Economy	7200.00
0005433129346	345	Economy	7200.00
0005433134208	345	Economy	7200.00
0005432949146	345	Economy	7200.00
0005433075257	345	Economy	7200.00
0005433570548	345	Economy	7200.00
0005433129330	345	Economy	7200.00
0005433134198	345	Economy	7200.00
0005433075206	345	Economy	7200.00
0005433570506	345	Economy	7200.00
0005433075107	345	Economy	7200.00
0005433134209	345	Economy	7200.00
0005433075140	345	Economy	7200.00
0005433570569	345	Economy	7200.00
0005433075103	345	Economy	7200.00
0005432949089	345	Economy	7200.00
0005433570566	345	Economy	7200.00
0005433075134	345	Economy	7200.00
0005433570507	345	Economy	7200.00
0005433075379	11595	Business	21500.00
0005433075385	11595	Business	21500.00
0005433569990	11595	Business	21500.00
0005433569856	11595	Business	21500.00
0005432949420	11595	Business	21500.00
0005433569942	11595	Business	21500.00
0005433075366	11595	Business	21500.00
0005432949405	11595	Business	21500.00
0005433569837	11595	Business	21500.00
0005433569712	11595	Business	21500.00
0005433569790	11595	Business	21500.00
0005433569926	11595	Business	21500.00
0005433075368	11595	Business	21500.00
0005433569860	11595	Business	21500.00
0005433569784	11595	Business	21500.00
0005433929869	11595	Business	21500.00
0005433569854	11595	Business	21500.00
0005433569806	11595	Business	21500.00
0005433569791	11595	Business	21500.00
0005432192395	11595	Business	21500.00
0005433569964	11595	Business	21500.00
0005432949402	11595	Business	21500.00
0005433569707	11595	Business	21500.00
0005433569819	11595	Business	21500.00
0005433134247	11595	Business	21500.00
0005433134246	11595	Business	21500.00
0005433075374	11595	Business	21500.00
0005433075373	11595	Economy	7900.00
0005432949422	11595	Economy	7900.00
0005433075375	11595	Economy	7900.00
0005433929871	11595	Economy	7900.00
0005433570019	11595	Economy	7900.00
0005433569858	11595	Economy	7200.00
0005432949428	11595	Economy	7200.00
0005433569693	11595	Economy	7200.00
0005433569832	11595	Economy	7200.00
0005433569699	11595	Economy	7200.00
0005433075364	11595	Economy	7200.00
0005432949430	11595	Economy	7200.00
0005433569603	11595	Economy	7200.00
0005433570008	11595	Economy	7200.00
0005432949403	11595	Economy	7200.00
0005433929870	11595	Economy	7200.00
0005432949408	11595	Economy	7200.00
0005433569966	11595	Economy	7200.00
0005433569794	11595	Economy	7200.00
0005433569727	11595	Economy	7200.00
0005432949399	11595	Economy	7200.00
0005433134248	11595	Economy	7200.00
0005432949390	11595	Economy	7200.00
0005433569833	11595	Economy	7200.00
0005433569805	11595	Economy	7200.00
0005432949411	11595	Economy	7200.00
0005433569909	11595	Economy	7200.00
0005433569786	11595	Economy	7200.00
0005433075381	11595	Economy	7200.00
0005433569813	11595	Economy	7200.00
0005433569972	11595	Economy	7200.00
0005433569627	11595	Economy	7200.00
0005432949415	11595	Economy	7200.00
0005433569925	11595	Economy	7200.00
0005433134245	11595	Economy	7200.00
0005433569655	11595	Economy	7200.00
0005432949409	11595	Economy	7200.00
0005433075380	11595	Economy	7200.00
0005433569808	11595	Economy	7200.00
0005433075377	11595	Economy	7200.00
0005433075369	11595	Economy	7200.00
0005432949413	11595	Economy	7200.00
0005432949418	11595	Economy	7200.00
0005432949424	11595	Economy	7200.00
0005433569792	11595	Economy	7200.00
0005433569761	11595	Economy	7200.00
0005433131816	11595	Economy	7200.00
0005432949401	11595	Economy	7200.00
0005432949427	11595	Economy	7200.00
0005433131818	11595	Economy	7200.00
0005433075365	11595	Economy	7200.00
0005433570020	11595	Economy	7200.00
0005433569573	11595	Economy	7200.00
0005432949398	11595	Economy	7900.00
0005433569936	11595	Economy	7200.00
0005433569935	11595	Economy	7900.00
0005433569937	11595	Economy	7900.00
0005433075367	11595	Economy	7900.00
0005433569728	11595	Economy	7900.00
0005433569628	11595	Economy	7200.00
0005433131815	11595	Economy	7200.00
0005432949404	11595	Economy	7200.00
0005433569787	11595	Economy	7900.00
0005433075372	11595	Economy	7200.00
0005432949400	11595	Economy	7200.00
0005432192394	11595	Economy	7200.00
0005432949397	11595	Economy	7200.00
0005433569947	11595	Economy	7200.00
0005432949426	11595	Economy	7200.00
0005433075389	11595	Economy	7200.00
0005433569694	11595	Economy	7200.00
0005433075371	11595	Economy	7200.00
0005432949394	11595	Economy	7200.00
0005432949410	11595	Economy	7200.00
0005432949392	11595	Economy	7200.00
0005433569656	11595	Economy	7200.00
0005433075363	11595	Economy	7200.00
0005432949393	11595	Economy	7200.00
0005433075386	11595	Economy	7200.00
0005432949407	11595	Economy	7200.00
0005433569678	11595	Economy	7200.00
0005433569979	11595	Economy	7200.00
0005433569807	11595	Economy	7200.00
0005433569809	11595	Economy	7200.00
0005433075383	11595	Economy	7200.00
0005433075391	11595	Economy	7200.00
0005433569880	11595	Economy	7200.00
0005432949417	11595	Economy	7200.00
0005432949414	11595	Economy	7200.00
0005433569904	11595	Economy	7200.00
0005433569993	11595	Economy	7200.00
0005433075382	11595	Economy	7200.00
0005432949431	11595	Economy	7200.00
0005433569706	11595	Economy	7200.00
0005432949421	11595	Economy	7200.00
0005433569811	11595	Economy	7200.00
0005433569710	11595	Economy	7200.00
0005433075388	11595	Economy	7200.00
0005433075392	11595	Economy	7200.00
0005433075384	11595	Economy	7200.00
0005432949396	11595	Economy	7200.00
0005433131817	11595	Economy	7200.00
0005432949419	11595	Economy	7200.00
0005433569708	11595	Economy	7200.00
0005433569609	11595	Economy	7200.00
0005433569692	11595	Economy	7200.00
0005433569800	11595	Economy	7200.00
0005433075387	11595	Economy	7200.00
0005432949395	11595	Economy	7200.00
0005432949425	11595	Economy	7200.00
0005433569910	11595	Economy	7200.00
0005433075390	11595	Economy	7200.00
0005432949391	11595	Economy	7200.00
0005432949429	11595	Economy	7200.00
0005433075376	11595	Economy	7200.00
0005432949406	11595	Economy	7200.00
0005433075378	11595	Economy	7200.00
0005432949416	11595	Economy	7200.00
0005433075370	11595	Economy	7200.00
0005433569917	11595	Economy	7200.00
0005432949423	11595	Economy	7200.00
0005433569785	11595	Economy	7200.00
0005433569965	11595	Economy	7200.00
0005432949412	11595	Economy	7200.00
0005433569820	11595	Economy	7200.00
0005432192393	11595	Economy	7200.00
0005433817559	9989	Economy	6300.00
0005433817558	9989	Economy	6300.00
0005434733040	9989	Economy	6300.00
0005434733035	9989	Economy	6300.00
0005433817560	9989	Economy	6300.00
0005433817561	9989	Economy	6300.00
0005434733041	9989	Economy	6300.00
0005433817562	9989	Economy	6300.00
0005433817521	14000	Economy	6300.00
0005433817529	14000	Economy	6300.00
0005433817525	14000	Economy	6300.00
0005433817532	14000	Economy	6300.00
0005434733066	14000	Economy	6300.00
0005433817528	14000	Economy	6300.00
0005433817530	14000	Economy	6300.00
0005433817537	14000	Economy	6300.00
0005434733065	14000	Economy	6300.00
0005435983345	2344	Business	184500.00
0005433755559	2344	Business	184500.00
0005435983370	2344	Business	184500.00
0005433766729	2344	Business	184500.00
0005435983367	2344	Business	184500.00
0005433764729	2344	Business	184500.00
0005432300401	2344	Business	184500.00
0005432869632	2344	Business	184500.00
0005433755560	2344	Business	184500.00
0005435983375	2344	Business	184500.00
0005435983372	2344	Business	184500.00
0005432985328	2344	Business	184500.00
0005435983346	2344	Business	184500.00
0005433755566	2344	Business	184500.00
0005435983361	2344	Business	184500.00
0005435983356	2344	Business	184500.00
0005435983383	2344	Business	184500.00
0005432985514	2344	Business	184500.00
0005432655821	2344	Business	184500.00
0005433755537	2344	Business	184500.00
0005433755548	2344	Business	184500.00
0005433755561	2344	Business	184500.00
0005435983363	2344	Business	184500.00
0005433755522	2344	Business	184500.00
0005432300402	2344	Business	184500.00
0005435983368	2344	Business	184500.00
0005433755562	2344	Business	184500.00
0005435983359	2344	Business	184500.00
0005432300399	2344	Business	184500.00
0005433435047	2344	Business	184500.00
0005432869627	2344	Economy	67700.00
0005432985669	2344	Economy	67700.00
0005435983380	2344	Economy	67700.00
0005433755549	2344	Economy	67700.00
0005432985453	2344	Economy	61500.00
0005432985659	2344	Economy	61500.00
0005432226205	2344	Economy	61500.00
0005433755531	2344	Economy	61500.00
0005435983371	2344	Economy	61500.00
0005433755570	2344	Economy	61500.00
0005435983381	2344	Economy	61500.00
0005435983349	2344	Economy	61500.00
0005432985516	2344	Economy	61500.00
0005432985544	2344	Economy	61500.00
0005433755526	2344	Economy	61500.00
0005435983355	2344	Economy	61500.00
0005433755527	2344	Economy	61500.00
0005432985477	2344	Economy	61500.00
0005433755543	2344	Economy	61500.00
0005432655819	2344	Economy	61500.00
0005433755534	2344	Economy	61500.00
0005435983364	2344	Economy	61500.00
0005433755535	2344	Economy	61500.00
0005433755521	2344	Economy	61500.00
0005433764728	2344	Economy	61500.00
0005432655817	2344	Economy	61500.00
0005435983388	2344	Economy	61500.00
0005435983387	2344	Economy	61500.00
0005432869641	2344	Economy	61500.00
0005433755569	2344	Economy	61500.00
0005433755544	2344	Economy	61500.00
0005432655816	2344	Economy	61500.00
0005435983365	2344	Economy	61500.00
0005432655822	2344	Economy	61500.00
0005432655820	2344	Economy	61500.00
0005432985605	2344	Economy	61500.00
0005433755524	2344	Economy	61500.00
0005432655826	2344	Economy	61500.00
0005433435124	2344	Economy	61500.00
0005434731226	2344	Economy	61500.00
0005433755564	2344	Economy	61500.00
0005433435053	2344	Economy	61500.00
0005433435155	2344	Economy	61500.00
0005435983386	2344	Economy	61500.00
0005432985510	2344	Economy	61500.00
0005432869613	2344	Economy	61500.00
0005433435050	2344	Economy	61500.00
0005433755542	2344	Economy	61500.00
0005432985548	2344	Economy	61500.00
0005435983354	2344	Economy	61500.00
0005433755529	2344	Economy	61500.00
0005433755550	2344	Economy	61500.00
0005435983352	2344	Economy	61500.00
0005432985627	2344	Economy	61500.00
0005435983344	2344	Economy	61500.00
0005432985588	2344	Economy	61500.00
0005433755555	2344	Economy	61500.00
0005433435092	2344	Economy	61500.00
0005432985650	2344	Economy	61500.00
0005432985543	2344	Economy	61500.00
0005432985596	2344	Economy	61500.00
0005433435082	2344	Economy	61500.00
0005433755530	2344	Economy	61500.00
0005433755576	2344	Economy	61500.00
0005435983362	2344	Economy	61500.00
0005433434968	2344	Economy	61500.00
0005435983394	2344	Economy	61500.00
0005433766732	2344	Economy	61500.00
0005433755528	2344	Economy	61500.00
0005432655825	2344	Economy	61500.00
0005433755539	2344	Economy	61500.00
0005435983382	2344	Economy	61500.00
0005435983378	2344	Economy	61500.00
0005433755525	2344	Economy	61500.00
0005435983360	2344	Economy	61500.00
0005433434985	2344	Economy	61500.00
0005433435049	2344	Economy	61500.00
0005432985478	2344	Economy	61500.00
0005435983395	2344	Economy	61500.00
0005432985668	2344	Economy	61500.00
0005432985586	2344	Economy	61500.00
0005432985529	2344	Economy	61500.00
0005433435169	2344	Economy	61500.00
0005432655823	2344	Economy	61500.00
0005433755551	2344	Economy	61500.00
0005433435172	2344	Economy	61500.00
0005435983389	2344	Economy	61500.00
0005432300403	2344	Economy	61500.00
0005432226207	2344	Economy	61500.00
0005433755540	2344	Economy	61500.00
0005433755567	2344	Economy	61500.00
0005433435170	2344	Economy	61500.00
0005435983393	2344	Economy	61500.00
0005432655818	2344	Economy	61500.00
0005433755533	2344	Economy	61500.00
0005435983353	2344	Economy	61500.00
0005432985614	2344	Economy	61500.00
0005433755573	2344	Economy	61500.00
0005432300404	2344	Economy	61500.00
0005433755563	2344	Economy	67700.00
0005432226203	2344	Economy	61500.00
0005433755574	2344	Economy	67700.00
0005433755571	2344	Economy	61500.00
0005433755538	2344	Economy	61500.00
0005432985576	2344	Economy	61500.00
0005433755541	2344	Economy	67700.00
0005433435204	2344	Economy	67700.00
0005432985530	2344	Economy	61500.00
0005433755554	2344	Economy	61500.00
0005433435091	2344	Economy	61500.00
0005433755575	2344	Economy	61500.00
0005433755536	2344	Economy	61500.00
0005435983366	2344	Economy	61500.00
0005435983377	2344	Economy	61500.00
0005435983373	2344	Economy	61500.00
0005433435061	2344	Economy	61500.00
0005433766731	2344	Economy	61500.00
0005433755547	2344	Economy	61500.00
0005433755532	2344	Economy	61500.00
0005432869614	2344	Economy	61500.00
0005433435148	2344	Economy	61500.00
0005432985606	2344	Economy	61500.00
0005433434885	2344	Economy	61500.00
0005433755558	2344	Economy	61500.00
0005433435048	2344	Economy	61500.00
0005432869628	2344	Economy	61500.00
0005435983385	2344	Economy	61500.00
0005433755565	2344	Economy	61500.00
0005432226204	2344	Economy	61500.00
0005435983376	2344	Economy	61500.00
0005435983358	2344	Economy	61500.00
0005433755556	2344	Economy	61500.00
0005432985587	2344	Economy	61500.00
0005433435156	2344	Economy	61500.00
0005434731225	2344	Economy	61500.00
0005435983369	2344	Economy	61500.00
0005433435173	2344	Economy	61500.00
0005433766728	2344	Economy	61500.00
0005435983379	2344	Economy	61500.00
0005435983357	2344	Economy	61500.00
0005433755557	2344	Economy	61500.00
0005435983392	2344	Economy	61500.00
0005435983343	2344	Economy	61500.00
0005433755545	2344	Economy	61500.00
0005435983347	2344	Economy	61500.00
0005432869615	2344	Economy	61500.00
0005433755552	2344	Economy	61500.00
0005435983384	2344	Economy	61500.00
0005432985533	2344	Economy	61500.00
0005432985577	2344	Economy	61500.00
0005435983348	2344	Economy	61500.00
0005433755568	2344	Economy	61500.00
0005432300400	2344	Economy	61500.00
0005433435086	2344	Economy	61500.00
0005432985608	2344	Economy	61500.00
0005432985536	2344	Economy	61500.00
0005433755572	2344	Economy	61500.00
0005432869640	2344	Economy	61500.00
0005432869633	2344	Economy	61500.00
0005433435134	2344	Economy	61500.00
0005435983396	2344	Economy	61500.00
0005432985651	2344	Economy	61500.00
0005432985549	2344	Economy	61500.00
0005432655824	2344	Economy	61500.00
0005435983351	2344	Economy	61500.00
0005433435123	2344	Economy	61500.00
0005433434937	2344	Economy	61500.00
0005432985593	2344	Economy	61500.00
0005435983374	2344	Economy	61500.00
0005432985538	2344	Economy	61500.00
0005433435179	2344	Economy	61500.00
0005433766730	2344	Economy	61500.00
0005433435037	2344	Economy	61500.00
0005433435120	2344	Economy	61500.00
0005434731236	2344	Economy	61500.00
0005435983390	2344	Economy	61500.00
0005435983350	2344	Economy	61500.00
0005433755546	2344	Economy	61500.00
0005433755523	2344	Economy	61500.00
0005432226206	2344	Economy	61500.00
0005435983391	2344	Economy	61500.00
0005433755553	2344	Economy	61500.00
0005433435334	26167	Business	184500.00
0005433755028	26167	Business	184500.00
0005432655709	26167	Business	184500.00
0005433435355	26167	Business	184500.00
0005433755220	26167	Business	184500.00
0005435982897	26167	Business	184500.00
0005432985858	26167	Business	184500.00
0005433755029	26167	Business	184500.00
0005435982978	26167	Business	184500.00
0005433755110	26167	Business	184500.00
0005432985849	26167	Business	184500.00
0005433435353	26167	Business	184500.00
0005435983005	26167	Business	184500.00
0005433754786	26167	Business	184500.00
0005433754977	26167	Business	184500.00
0005432985827	26167	Business	184500.00
0005433755221	26167	Business	184500.00
0005433435347	26167	Business	184500.00
0005435982985	26167	Business	184500.00
0005435982875	26167	Business	184500.00
0005433755155	26167	Business	184500.00
0005435982783	26167	Business	184500.00
0005432869676	26167	Business	184500.00
0005433755044	26167	Business	184500.00
0005435982872	26167	Business	184500.00
0005433764712	26167	Business	184500.00
0005435983047	26167	Business	184500.00
0005435982876	26167	Business	184500.00
0005433755203	26167	Business	184500.00
0005433754853	26167	Economy	67700.00
0005433764713	26167	Economy	67700.00
0005435982861	26167	Economy	61500.00
0005433435341	26167	Economy	61500.00
0005433755156	26167	Economy	61500.00
0005434731270	26167	Economy	61500.00
0005433435340	26167	Economy	61500.00
0005432049547	26167	Economy	61500.00
0005433755121	26167	Economy	61500.00
0005433435349	26167	Economy	61500.00
0005433755170	26167	Economy	61500.00
0005433755054	26167	Economy	61500.00
0005435983058	26167	Economy	61500.00
0005433755239	26167	Economy	61500.00
0005435983020	26167	Economy	61500.00
0005435982962	26167	Economy	61500.00
0005435982929	26167	Economy	61500.00
0005432985834	26167	Economy	61500.00
0005433754856	26167	Economy	61500.00
0005433435333	26167	Economy	61500.00
0005435983149	26167	Economy	61500.00
0005435982953	26167	Economy	61500.00
0005434731272	26167	Economy	61500.00
0005432985850	26167	Economy	61500.00
0005432655648	26167	Economy	61500.00
0005432655722	26167	Economy	61500.00
0005432049548	26167	Economy	61500.00
0005432985846	26167	Economy	61500.00
0005433754976	26167	Economy	61500.00
0005435983150	26167	Economy	61500.00
0005435982984	26167	Economy	61500.00
0005435982806	26167	Economy	61500.00
0005432985837	26167	Economy	61500.00
0005435982865	26167	Economy	61500.00
0005432869677	26167	Economy	61500.00
0005435982952	26167	Economy	61500.00
0005435983057	26167	Economy	61500.00
0005433755003	26167	Economy	61500.00
0005432985856	26167	Economy	61500.00
0005434376160	26167	Economy	61500.00
0005433754748	26167	Economy	61500.00
0005433435338	26167	Economy	61500.00
0005433755207	26167	Economy	61500.00
0005433435339	26167	Economy	61500.00
0005432655649	26167	Economy	61500.00
0005433435332	26167	Economy	61500.00
0005433754966	26167	Economy	61500.00
0005432985842	26167	Economy	61500.00
0005433755034	26167	Economy	61500.00
0005433755118	26167	Economy	61500.00
0005435983011	26167	Economy	61500.00
0005435982991	26167	Economy	61500.00
0005435983014	26167	Economy	61500.00
0005433435342	26167	Economy	61500.00
0005435982843	26167	Economy	61500.00
0005435982961	26167	Economy	61500.00
0005435982874	26167	Economy	61500.00
0005432655719	26167	Economy	61500.00
0005433435346	26167	Economy	61500.00
0005432869679	26167	Economy	61500.00
0005432655659	26167	Economy	61500.00
0005435982947	26167	Economy	61500.00
0005433754938	26167	Economy	61500.00
0005432985843	26167	Economy	61500.00
0005433754989	26167	Economy	61500.00
0005432655723	26167	Economy	61500.00
0005432985838	26167	Economy	61500.00
0005435982934	26167	Economy	61500.00
0005433435331	26167	Economy	61500.00
0005432655704	26167	Economy	61500.00
0005432985854	26167	Economy	61500.00
0005435982820	26167	Economy	61500.00
0005433755236	26167	Economy	61500.00
0005433435350	26167	Economy	61500.00
0005432985836	26167	Economy	61500.00
0005435982873	26167	Economy	61500.00
0005435982852	26167	Economy	61500.00
0005432985855	26167	Economy	61500.00
0005434376161	26167	Economy	61500.00
0005433754854	26167	Economy	61500.00
0005432985857	26167	Economy	61500.00
0005433754855	26167	Economy	61500.00
0005435982736	26167	Economy	61500.00
0005432655703	26167	Economy	61500.00
0005432655647	26167	Economy	61500.00
0005433766717	26167	Economy	61500.00
0005435983000	26167	Economy	61500.00
0005435982867	26167	Economy	61500.00
0005433435354	26167	Economy	61500.00
0005433435335	26167	Economy	61500.00
0005433754775	26167	Economy	61500.00
0005432049551	26167	Economy	61500.00
0005433755033	26167	Economy	61500.00
0005433435337	26167	Economy	61500.00
0005433755256	26167	Economy	61500.00
0005432049550	26167	Economy	67700.00
0005433755004	26167	Economy	61500.00
0005433754928	26167	Economy	61500.00
0005435983036	26167	Economy	61500.00
0005435982883	26167	Economy	61500.00
0005432985832	26167	Economy	67700.00
0005435982882	26167	Economy	67700.00
0005432869680	26167	Economy	61500.00
0005435982889	26167	Economy	61500.00
0005432985845	26167	Economy	61500.00
0005432985831	26167	Economy	61500.00
0005432655749	26167	Economy	61500.00
0005432985829	26167	Economy	61500.00
0005433755027	26167	Economy	61500.00
0005432985841	26167	Economy	61500.00
0005433755133	26167	Economy	61500.00
0005432051204	26167	Economy	61500.00
0005432869678	26167	Economy	61500.00
0005435983010	26167	Economy	61500.00
0005435982998	26167	Economy	61500.00
0005435982928	26167	Economy	61500.00
0005435982881	26167	Economy	61500.00
0005433755097	26167	Economy	61500.00
0005432985852	26167	Economy	61500.00
0005433754787	26167	Economy	61500.00
0005433755109	26167	Economy	61500.00
0005432985828	26167	Economy	61500.00
0005432985833	26167	Economy	61500.00
0005432985853	26167	Economy	61500.00
0005433435343	26167	Economy	61500.00
0005432869681	26167	Economy	61500.00
0005433435351	26167	Economy	61500.00
0005433755074	26167	Economy	61500.00
0005435982951	26167	Economy	61500.00
0005432985835	26167	Economy	61500.00
0005433755255	26167	Economy	61500.00
0005432985847	26167	Economy	61500.00
0005433435336	26167	Economy	61500.00
0005432985848	26167	Economy	61500.00
0005433435330	26167	Economy	61500.00
0005432985840	26167	Economy	61500.00
0005433435345	26167	Economy	61500.00
0005433754747	26167	Economy	61500.00
0005433755009	26167	Economy	61500.00
0005433435352	26167	Economy	61500.00
0005433754970	26167	Economy	61500.00
0005435982996	26167	Economy	61500.00
0005433435356	26167	Economy	61500.00
0005432049549	26167	Economy	61500.00
0005433755096	26167	Economy	61500.00
0005432655652	26167	Economy	61500.00
0005433754967	26167	Economy	61500.00
0005433755169	26167	Economy	61500.00
0005433755168	26167	Economy	61500.00
0005435982807	26167	Economy	61500.00
0005432051202	26167	Economy	61500.00
0005435982933	26167	Economy	61500.00
0005435982868	26167	Economy	61500.00
0005435982999	26167	Economy	61500.00
0005435983059	26167	Economy	61500.00
0005432985839	26167	Economy	61500.00
0005435983148	26167	Economy	61500.00
0005433435329	26167	Economy	61500.00
0005433755151	26167	Economy	61500.00
0005432655750	26167	Economy	61500.00
0005435982983	26167	Economy	61500.00
0005432655717	26167	Economy	61500.00
0005432655611	26167	Economy	61500.00
0005433435348	26167	Economy	61500.00
0005432985844	26167	Economy	61500.00
0005435983013	26167	Economy	61500.00
0005435982969	26167	Economy	61500.00
0005432985830	26167	Economy	61500.00
0005432051203	26167	Economy	61500.00
0005433435344	26167	Economy	61500.00
0005433754971	26167	Economy	61500.00
0005433754937	26167	Economy	61500.00
0005433435357	26167	Economy	61500.00
0005433755202	26167	Economy	61500.00
0005432985851	26167	Economy	61500.00
0005434731271	26167	Economy	61500.00
0005433151970	1511	Business	38900.00
0005433931502	1511	Business	38900.00
0005434375706	1511	Business	38900.00
0005433151813	1511	Business	38900.00
0005434375708	1511	Business	38900.00
0005432268053	1511	Business	38900.00
0005433151953	1511	Business	38900.00
0005434029704	1511	Business	38900.00
0005433151887	1511	Business	38900.00
0005433151860	1511	Economy	13000.00
0005433151825	1511	Economy	13000.00
0005434375723	1511	Economy	13000.00
0005433152108	1511	Economy	13000.00
0005433152088	1511	Economy	13000.00
0005434375742	1511	Economy	13000.00
0005434375737	1511	Economy	13000.00
0005433152040	1511	Economy	13000.00
0005433151944	1511	Economy	13000.00
0005434375745	1511	Economy	13000.00
0005432268052	1511	Economy	13000.00
0005433152006	1511	Economy	13000.00
0005433152009	1511	Economy	13000.00
0005434375743	1511	Economy	13000.00
0005433151770	1511	Economy	13000.00
0005433931503	1511	Economy	13000.00
0005433152107	1511	Economy	13000.00
0005434375719	1511	Economy	13000.00
0005434375733	1511	Economy	13000.00
0005433151964	1511	Economy	13000.00
0005434375739	1511	Economy	13000.00
0005433460488	1511	Economy	13000.00
0005433151756	1511	Economy	13000.00
0005434375722	1511	Economy	13000.00
0005433152087	1511	Economy	13000.00
0005433461640	1511	Economy	13000.00
0005433461639	1511	Economy	13000.00
0005434375726	1511	Economy	13000.00
0005433151755	1511	Economy	13000.00
0005433152005	1511	Economy	13000.00
0005433151906	1511	Economy	13000.00
0005434375728	1511	Economy	13000.00
0005434375729	1511	Economy	13000.00
0005434375741	1511	Economy	13000.00
0005433931497	1511	Economy	13000.00
0005433151980	1511	Economy	14300.00
0005433151932	1511	Economy	14300.00
0005433151937	1511	Economy	14300.00
0005432268055	1511	Economy	14300.00
0005434375746	1511	Economy	14300.00
0005433931504	1511	Economy	13000.00
0005433151921	1511	Economy	13000.00
0005434375738	1511	Economy	13000.00
0005433152012	1511	Economy	13000.00
0005433151898	1511	Economy	13000.00
0005434375709	1511	Economy	13000.00
0005434375736	1511	Economy	13000.00
0005433151945	1511	Economy	13000.00
0005434375735	1511	Economy	13000.00
0005434375724	1511	Economy	13000.00
0005433151978	1511	Economy	13000.00
0005433151886	1511	Economy	13000.00
0005433152003	1511	Economy	13000.00
0005433151961	1511	Economy	13000.00
0005434375744	1511	Economy	13000.00
0005434375707	1511	Economy	13000.00
0005433151930	1511	Economy	13000.00
0005434029692	1511	Economy	13000.00
0005434375734	1511	Economy	13000.00
0005433151928	1511	Economy	13000.00
0005433151897	1511	Economy	13000.00
0005433152063	1511	Economy	13000.00
0005434375727	1511	Economy	13000.00
0005433151986	1511	Economy	13000.00
0005433152058	1511	Economy	13000.00
0005433151916	1511	Economy	13000.00
0005433151915	1511	Economy	13000.00
0005433152002	1511	Economy	13000.00
0005433151907	1511	Economy	13000.00
0005433931510	1511	Economy	13000.00
0005433151963	1511	Economy	13000.00
0005432268054	1511	Economy	13000.00
0005434375747	1511	Economy	13000.00
0005434375740	1511	Economy	13000.00
0005434375732	1511	Economy	13000.00
0005433151962	1511	Economy	13000.00
0005434375730	1511	Economy	13000.00
0005434375721	1511	Economy	13000.00
0005434029691	1511	Economy	13000.00
0005434375717	1511	Economy	13000.00
0005433152093	1511	Economy	13000.00
0005433151943	1511	Economy	13000.00
0005434375710	1511	Economy	13000.00
0005434375720	1511	Economy	13000.00
0005433152041	1511	Economy	13000.00
0005433151931	1511	Economy	13000.00
0005432268056	1511	Economy	13000.00
0005434375713	1511	Economy	13000.00
0005433152086	1511	Economy	13000.00
0005433460487	1511	Economy	13000.00
0005433151859	1511	Economy	13000.00
0005434375714	1511	Economy	13000.00
0005434375718	1511	Economy	13000.00
0005434375725	1511	Economy	13000.00
0005433931509	1511	Economy	13000.00
0005433931506	1511	Economy	13000.00
0005433152011	1511	Economy	13000.00
0005433931496	1511	Economy	13000.00
0005434375711	1511	Economy	13000.00
0005433152057	1511	Economy	13000.00
0005433151814	1511	Economy	13000.00
0005434375712	1511	Economy	13000.00
0005434375716	1511	Economy	13000.00
0005434375731	1511	Economy	13000.00
0005433152025	1511	Economy	13000.00
0005434375715	1511	Economy	13000.00
0005433463919	20136	Business	38900.00
0005433152216	20136	Business	38900.00
0005433152202	20136	Business	38900.00
0005433463917	20136	Business	38900.00
0005433461605	20136	Business	38900.00
0005434375103	20136	Business	38900.00
0005433152206	20136	Business	38900.00
0005433152207	20136	Business	38900.00
0005433463923	20136	Business	38900.00
0005433463913	20136	Business	38900.00
0005433152224	20136	Business	38900.00
0005433461610	20136	Economy	13000.00
0005433152221	20136	Economy	13000.00
0005434375252	20136	Economy	13000.00
0005433152228	20136	Economy	13000.00
0005433152205	20136	Economy	13000.00
0005434375243	20136	Economy	13000.00
0005432056391	20136	Economy	13000.00
0005433152225	20136	Economy	13000.00
0005433461595	20136	Economy	13000.00
0005434375298	20136	Economy	13000.00
0005434375246	20136	Economy	13000.00
0005433463920	20136	Economy	13000.00
0005434375154	20136	Economy	13000.00
0005433461602	20136	Economy	13000.00
0005434375180	20136	Economy	13000.00
0005433463921	20136	Economy	13000.00
0005433152227	20136	Economy	13000.00
0005434375235	20136	Economy	13000.00
0005433152201	20136	Economy	13000.00
0005433461604	20136	Economy	13000.00
0005433152210	20136	Economy	13000.00
0005433152232	20136	Economy	13000.00
0005433764728	20136	Economy	13000.00
0005434375286	20136	Economy	13000.00
0005433463911	20136	Economy	13000.00
0005434375253	20136	Economy	13000.00
0005433461609	20136	Economy	13000.00
0005433461611	20136	Economy	13000.00
0005433461608	20136	Economy	13000.00
0005434375179	20136	Economy	13000.00
0005433152223	20136	Economy	13000.00
0005433152215	20136	Economy	13000.00
0005433152204	20136	Economy	13000.00
0005433152200	20136	Economy	14300.00
0005433461600	20136	Economy	14300.00
0005433461617	20136	Economy	14300.00
0005434375137	20136	Economy	14300.00
0005433463915	20136	Economy	14300.00
0005433152214	20136	Economy	13000.00
0005433152226	20136	Economy	13000.00
0005434029715	20136	Economy	13000.00
0005433461601	20136	Economy	13000.00
0005433463901	20136	Economy	13000.00
0005433152218	20136	Economy	13000.00
0005434375268	20136	Economy	13000.00
0005432056390	20136	Economy	13000.00
0005433152229	20136	Economy	13000.00
0005433463912	20136	Economy	13000.00
0005433152222	20136	Economy	13000.00
0005434375285	20136	Economy	13000.00
0005434029716	20136	Economy	13000.00
0005433152203	20136	Economy	13000.00
0005434375297	20136	Economy	13000.00
0005433931538	20136	Economy	13000.00
0005433463904	20136	Economy	13000.00
0005433463925	20136	Economy	13000.00
0005433461596	20136	Economy	13000.00
0005433152212	20136	Economy	13000.00
0005433463918	20136	Economy	13000.00
0005434375226	20136	Economy	13000.00
0005434375301	20136	Economy	13000.00
0005434375300	20136	Economy	13000.00
0005434375236	20136	Economy	13000.00
0005433152217	20136	Economy	13000.00
0005434375299	20136	Economy	13000.00
0005434375245	20136	Economy	13000.00
0005434375184	20136	Economy	13000.00
0005434375164	20136	Economy	13000.00
0005433463914	20136	Economy	13000.00
0005432056388	20136	Economy	13000.00
0005432056389	20136	Economy	13000.00
0005433463922	20136	Economy	13000.00
0005433152208	20136	Economy	13000.00
0005433152230	20136	Economy	13000.00
0005433152219	20136	Economy	13000.00
0005433463924	20136	Economy	13000.00
0005433152211	20136	Economy	13000.00
0005433463916	20136	Economy	13000.00
0005433461607	20136	Economy	13000.00
0005434375308	20136	Economy	13000.00
0005433461603	20136	Economy	13000.00
0005433461606	20136	Economy	13000.00
0005433152209	20136	Economy	13000.00
0005433463900	20136	Economy	13000.00
0005433764729	20136	Economy	13000.00
0005434375269	20136	Economy	13000.00
0005433152213	20136	Economy	13000.00
0005433152231	20136	Economy	13000.00
0005434375227	20136	Economy	13000.00
0005433931539	20136	Economy	13000.00
0005434375153	20136	Economy	13000.00
0005434375198	20136	Economy	13000.00
0005433152220	20136	Economy	13000.00
0005432283032	580	Business	27500.00
0005432425584	580	Business	27500.00
0005432425619	580	Business	27500.00
0005432425580	580	Business	27500.00
0005432425592	580	Business	27500.00
0005432425578	580	Business	27500.00
0005432425590	580	Business	27500.00
0005432425579	580	Economy	10100.00
0005432425582	580	Economy	10100.00
0005432425607	580	Economy	9200.00
0005432425598	580	Economy	9200.00
0005432425618	580	Economy	9200.00
0005432283035	580	Economy	9200.00
0005432425588	580	Economy	9200.00
0005432425615	580	Economy	9200.00
0005432283030	580	Economy	9200.00
0005432425596	580	Economy	9200.00
0005432425611	580	Economy	9200.00
0005432425614	580	Economy	9200.00
0005432283031	580	Economy	9200.00
0005432283028	580	Economy	9200.00
0005432425583	580	Economy	9200.00
0005432425605	580	Economy	9200.00
0005432425589	580	Economy	9200.00
0005432425617	580	Economy	9200.00
0005432425602	580	Economy	9200.00
0005432425613	580	Economy	9200.00
0005432425601	580	Economy	9200.00
0005432283033	580	Economy	9200.00
0005432283034	580	Economy	9200.00
0005432425587	580	Economy	9200.00
0005432425606	580	Economy	9200.00
0005432425585	580	Economy	9200.00
0005432425610	580	Economy	9200.00
0005432425604	580	Economy	9200.00
0005432283029	580	Economy	9200.00
0005432425603	580	Economy	9200.00
0005432425593	580	Economy	9200.00
0005432425581	580	Economy	9200.00
0005432425597	580	Economy	9200.00
0005432425616	580	Economy	9200.00
0005432425586	580	Economy	9200.00
0005432425595	580	Economy	9200.00
0005432425609	580	Economy	9200.00
0005432425591	580	Economy	9200.00
0005432425608	580	Economy	9200.00
0005432425594	580	Economy	9200.00
0005432425600	580	Economy	9200.00
0005432425612	580	Economy	9200.00
0005432425599	580	Economy	9200.00
0005432302420	12912	Business	27500.00
0005433261893	12912	Business	27500.00
0005433261898	12912	Business	27500.00
0005433261900	12912	Business	27500.00
0005433261902	12912	Business	27500.00
0005433261903	12912	Business	27500.00
0005433261895	12912	Economy	9200.00
0005432302419	12912	Economy	9200.00
0005433261901	12912	Economy	9200.00
0005433261906	12912	Economy	9200.00
0005433261899	12912	Economy	9200.00
0005432302421	12912	Economy	9200.00
0005433261897	12912	Economy	9200.00
0005432302418	12912	Economy	9200.00
0005433261904	12912	Economy	9200.00
0005433261905	12912	Economy	9200.00
0005433261894	12912	Economy	9200.00
0005433261892	12912	Economy	9200.00
0005433261896	12912	Economy	9200.00
0005432424998	12833	Business	27500.00
0005432424859	12833	Business	27500.00
0005432424972	12833	Business	27500.00
0005432425148	12833	Business	27500.00
0005432425089	12833	Business	27500.00
0005432425144	12833	Business	27500.00
0005432425147	12833	Business	27500.00
0005432425000	12833	Business	27500.00
0005432425132	12833	Business	27500.00
0005432425081	12833	Business	27500.00
0005432425170	12833	Economy	10100.00
0005432425124	12833	Economy	9200.00
0005432425046	12833	Economy	9200.00
0005432425077	12833	Economy	9200.00
0005432424989	12833	Economy	9200.00
0005432425150	12833	Economy	9200.00
0005432425159	12833	Economy	9200.00
0005432425172	12833	Economy	9200.00
0005432425078	12833	Economy	9200.00
0005432424858	12833	Economy	9200.00
0005432425057	12833	Economy	9200.00
0005432425123	12833	Economy	9200.00
0005432425160	12833	Economy	9200.00
0005432425076	12833	Economy	9200.00
0005432425079	12833	Economy	9200.00
0005432425167	12833	Economy	9200.00
0005432425011	12833	Economy	9200.00
0005432425146	12833	Economy	9200.00
0005432425151	12833	Economy	10100.00
0005432425102	12833	Economy	9200.00
0005432425125	12833	Economy	9200.00
0005432425141	12833	Economy	9200.00
0005432425033	12833	Economy	9200.00
0005432425017	12833	Economy	9200.00
0005432425019	12833	Economy	9200.00
0005432424781	12833	Economy	9200.00
0005432425064	12833	Economy	9200.00
0005432425063	12833	Economy	9200.00
0005432424999	12833	Economy	9200.00
0005432425140	12833	Economy	9200.00
0005432425145	12833	Economy	9200.00
0005432425018	12833	Economy	9200.00
0005432425021	12833	Economy	9200.00
0005432424780	12833	Economy	9200.00
0005432425134	12833	Economy	9200.00
0005432424944	12833	Economy	9200.00
0005432424857	12833	Economy	9200.00
0005432425016	12833	Economy	9200.00
0005432425133	12833	Economy	9200.00
0005432425062	12833	Economy	9200.00
0005432425142	12833	Economy	9200.00
0005432425022	12833	Economy	9200.00
0005432425012	12833	Economy	9200.00
0005432425052	12833	Economy	9200.00
0005432425149	12833	Economy	9200.00
0005432424782	12833	Economy	9200.00
0005432425047	12833	Economy	9200.00
0005432425080	12833	Economy	9200.00
0005432425020	12833	Economy	9200.00
0005432425092	12833	Economy	9200.00
0005434025277	450	Business	24500.00
0005432235818	450	Business	24500.00
0005434025333	450	Business	24500.00
0005433058588	450	Business	24500.00
0005434025286	450	Business	24500.00
0005434025329	450	Business	24500.00
0005434025312	450	Business	24500.00
0005433058530	450	Business	24500.00
0005434025323	450	Business	24500.00
0005434025318	450	Business	24500.00
0005433058466	450	Business	24500.00
0005434025339	450	Business	24500.00
0005433058609	450	Business	24500.00
0005433058397	450	Business	24500.00
0005433058616	450	Business	24500.00
0005434025309	450	Business	24500.00
0005433684457	450	Economy	9000.00
0005434025289	450	Business	24500.00
0005432235812	450	Economy	9000.00
0005434025315	450	Economy	9000.00
0005434025311	450	Economy	9000.00
0005434025319	450	Economy	8200.00
0005433058572	450	Economy	8200.00
0005434025332	450	Economy	8200.00
0005434025342	450	Economy	8200.00
0005434025304	450	Economy	8200.00
0005434025299	450	Economy	8200.00
0005434025325	450	Economy	8200.00
0005434032131	450	Economy	8200.00
0005434025298	450	Economy	8200.00
0005433929673	450	Economy	8200.00
0005433058522	450	Economy	8200.00
0005434025338	450	Economy	8200.00
0005433058439	450	Economy	8200.00
0005434025290	450	Economy	8200.00
0005434025317	450	Economy	8200.00
0005434025294	450	Economy	8200.00
0005434029712	450	Economy	8200.00
0005434025297	450	Economy	8200.00
0005434028373	450	Economy	8200.00
0005434025321	450	Economy	8200.00
0005434025281	450	Economy	8200.00
0005433058348	450	Economy	8200.00
0005434032130	450	Economy	8200.00
0005434025313	450	Economy	8200.00
0005434025302	450	Economy	8200.00
0005434025337	450	Economy	8200.00
0005434025287	450	Economy	8200.00
0005434025340	450	Economy	8200.00
0005434025330	450	Economy	8200.00
0005433058532	450	Economy	8200.00
0005434032127	450	Economy	8200.00
0005434025320	450	Economy	8200.00
0005434025336	450	Economy	8200.00
0005432235813	450	Economy	8200.00
0005433058469	450	Economy	8200.00
0005434028374	450	Economy	8200.00
0005434025334	450	Economy	8200.00
0005433684448	450	Economy	8200.00
0005434025301	450	Economy	8200.00
0005434028372	450	Economy	8200.00
0005433058406	450	Economy	8200.00
0005434028376	450	Economy	8200.00
0005434025306	450	Economy	8200.00
0005433058444	450	Economy	8200.00
0005432235819	450	Economy	8200.00
0005434025331	450	Economy	8200.00
0005433058513	450	Economy	8200.00
0005434025276	450	Economy	8200.00
0005432235815	450	Economy	8200.00
0005432235817	450	Economy	8200.00
0005434025307	450	Economy	8200.00
0005434029713	450	Economy	8200.00
0005434025316	450	Economy	8200.00
0005434025343	450	Economy	8200.00
0005434025295	450	Economy	8200.00
0005433929661	450	Economy	8200.00
0005434025284	450	Economy	8200.00
0005434025291	450	Economy	8200.00
0005434025288	450	Economy	9000.00
0005433058526	450	Economy	8200.00
0005434025293	450	Economy	8200.00
0005434025314	450	Economy	9000.00
0005433929677	450	Economy	8200.00
0005433058368	450	Economy	9000.00
0005432045657	450	Economy	8200.00
0005434376227	450	Economy	8200.00
0005433058467	450	Economy	8200.00
0005434025308	450	Economy	8200.00
0005434025324	450	Economy	8200.00
0005433058568	450	Economy	8200.00
0005434025322	450	Economy	8200.00
0005434025280	450	Economy	8200.00
0005433058367	450	Economy	8200.00
0005433058608	450	Economy	8200.00
0005434025310	450	Economy	8200.00
0005432235814	450	Economy	8200.00
0005434025283	450	Economy	8200.00
0005433058523	450	Economy	8200.00
0005433058459	450	Economy	8200.00
0005434025285	450	Economy	8200.00
0005434025326	450	Economy	8200.00
0005433058507	450	Economy	8200.00
0005433058581	450	Economy	8200.00
0005434028375	450	Economy	8200.00
0005434032129	450	Economy	8200.00
0005433929675	450	Economy	8200.00
0005433684449	450	Economy	8200.00
0005434025300	450	Economy	8200.00
0005434032128	450	Economy	8200.00
0005433058504	450	Economy	8200.00
0005433929663	450	Economy	8200.00
0005432045658	450	Economy	8200.00
0005434029714	450	Economy	8200.00
0005434025282	450	Economy	8200.00
0005434025303	450	Economy	8200.00
0005433058533	450	Economy	8200.00
0005434025296	450	Economy	8200.00
0005434025305	450	Economy	8200.00
0005433058766	450	Economy	8200.00
0005434025278	450	Economy	8200.00
0005432235816	450	Economy	8200.00
0005434376226	450	Economy	8200.00
0005434025341	450	Economy	8200.00
0005434025327	450	Economy	8200.00
0005434025279	450	Economy	8200.00
0005434025275	450	Economy	8200.00
0005434025328	450	Economy	8200.00
0005433058531	450	Economy	8200.00
0005434025292	450	Economy	8200.00
0005434025335	450	Economy	8200.00
0005433058604	450	Economy	8200.00
0005434735811	12702	Business	24500.00
0005434024536	12702	Business	24500.00
0005432156470	12702	Business	24500.00
0005434024777	12702	Business	24500.00
0005434024529	12702	Business	24500.00
0005433058841	12702	Business	24500.00
0005434024695	12702	Business	24500.00
0005434735816	12702	Business	24500.00
0005434024674	12702	Business	24500.00
0005434028335	12702	Business	24500.00
0005434024750	12702	Business	24500.00
0005433058846	12702	Business	24500.00
0005433058814	12702	Business	24500.00
0005434024700	12702	Business	24500.00
0005434024923	12702	Business	24500.00
0005434024610	12702	Business	24500.00
0005432156472	12702	Business	24500.00
0005433058853	12702	Business	24500.00
0005433058836	12702	Economy	9000.00
0005434024734	12702	Economy	9000.00
0005433058844	12702	Economy	9000.00
0005433058827	12702	Economy	8200.00
0005434032084	12702	Economy	8200.00
0005434024788	12702	Economy	8200.00
0005433058849	12702	Economy	8200.00
0005434024684	12702	Economy	8200.00
0005434024878	12702	Economy	8200.00
0005434024642	12702	Economy	8200.00
0005434024552	12702	Economy	8200.00
0005433058838	12702	Economy	8200.00
0005434024958	12702	Economy	8200.00
0005434024531	12702	Economy	8200.00
0005434024614	12702	Economy	8200.00
0005434024877	12702	Economy	8200.00
0005433058833	12702	Economy	8200.00
0005433058832	12702	Economy	8200.00
0005434024785	12702	Economy	8200.00
0005434024800	12702	Economy	8200.00
0005433058822	12702	Economy	8200.00
0005433058829	12702	Economy	8200.00
0005434024843	12702	Economy	8200.00
0005434024848	12702	Economy	8200.00
0005433058854	12702	Economy	8200.00
0005434024924	12702	Economy	8200.00
0005434024537	12702	Economy	8200.00
0005434024592	12702	Economy	8200.00
0005434024767	12702	Economy	8200.00
0005434024683	12702	Economy	8200.00
0005434024768	12702	Economy	8200.00
0005433058826	12702	Economy	8200.00
0005433058825	12702	Economy	8200.00
0005433058835	12702	Economy	8200.00
0005433058845	12702	Economy	8200.00
0005434024565	12702	Economy	8200.00
0005434024756	12702	Economy	8200.00
0005433058812	12702	Economy	8200.00
0005433058837	12702	Economy	8200.00
0005433058842	12702	Economy	8200.00
0005434024959	12702	Economy	8200.00
0005433058847	12702	Economy	8200.00
0005433684470	12702	Economy	8200.00
0005434032087	12702	Economy	8200.00
0005434024558	12702	Economy	8200.00
0005434024757	12702	Economy	8200.00
0005433058850	12702	Economy	8200.00
0005432156473	12702	Economy	8200.00
0005434028337	12702	Economy	8200.00
0005434024530	12702	Economy	8200.00
0005433058840	12702	Economy	8200.00
0005433058823	12702	Economy	8200.00
0005433058831	12702	Economy	8200.00
0005433058851	12702	Economy	8200.00
0005433058828	12702	Economy	8200.00
0005434024842	12702	Economy	8200.00
0005434024526	12702	Economy	8200.00
0005433058830	12702	Economy	8200.00
0005433058839	12702	Economy	8200.00
0005433058816	12702	Economy	8200.00
0005434735815	12702	Economy	8200.00
0005434024476	12702	Economy	8200.00
0005434029691	12702	Economy	8200.00
0005434024718	12702	Economy	8200.00
0005433058843	12702	Economy	8200.00
0005434024752	12702	Economy	8200.00
0005434024701	12702	Economy	8200.00
0005434028340	12702	Economy	8200.00
0005434024687	12702	Economy	8200.00
0005434735814	12702	Economy	8200.00
0005434024836	12702	Economy	8200.00
0005434024827	12702	Economy	9000.00
0005434024951	12702	Economy	8200.00
0005434024462	12702	Economy	9000.00
0005433058834	12702	Economy	8200.00
0005434024773	12702	Economy	8200.00
0005434024789	12702	Economy	9000.00
0005433058819	12702	Economy	8200.00
0005434024691	12702	Economy	8200.00
0005434024710	12702	Economy	8200.00
0005433058821	12702	Economy	8200.00
0005434024525	12702	Economy	8200.00
0005434024593	12702	Economy	8200.00
0005432156471	12702	Economy	8200.00
0005434024852	12702	Economy	8200.00
0005434024653	12702	Economy	8200.00
0005434735812	12702	Economy	8200.00
0005434024613	12702	Economy	8200.00
0005434024876	12702	Economy	8200.00
0005434024656	12702	Economy	8200.00
0005434024532	12702	Economy	8200.00
0005434024864	12702	Economy	8200.00
0005433058852	12702	Economy	8200.00
0005434024938	12702	Economy	8200.00
0005434024875	12702	Economy	8200.00
0005433058815	12702	Economy	8200.00
0005434024581	12702	Economy	8200.00
0005434024464	12702	Economy	8200.00
0005434024567	12702	Economy	8200.00
0005433058848	12702	Economy	8200.00
0005433058818	12702	Economy	8200.00
0005434028348	12702	Economy	8200.00
0005433058817	12702	Economy	8200.00
0005434024784	12702	Economy	8200.00
0005434029692	12702	Economy	8200.00
0005434032085	12702	Economy	8200.00
0005434024669	12702	Economy	8200.00
0005434024953	12702	Economy	8200.00
0005434024801	12702	Economy	8200.00
0005434024620	12702	Economy	8200.00
0005434024702	12702	Economy	8200.00
0005433929712	12702	Economy	8200.00
0005434024906	12702	Economy	8200.00
0005434024688	12702	Economy	8200.00
0005434029704	12702	Economy	8200.00
0005434735813	12702	Economy	8200.00
0005433058820	12702	Economy	8200.00
0005434024812	12702	Economy	8200.00
0005434024851	12702	Economy	8200.00
0005433929711	12702	Economy	8200.00
0005434024797	12702	Economy	8200.00
0005434024834	12702	Economy	8200.00
0005433058824	12702	Economy	8200.00
0005434024690	12702	Economy	8200.00
0005433684469	12702	Economy	8200.00
0005434028336	12702	Economy	8200.00
0005434024740	12702	Economy	8200.00
0005434024802	12702	Economy	8200.00
0005434024798	12702	Economy	8200.00
0005434024566	12702	Economy	8200.00
0005433058813	12702	Economy	8200.00
0005434032098	12702	Economy	8200.00
0005434024694	12702	Economy	8200.00
0005433037078	2145	Business	34700.00
0005432231815	2145	Business	34700.00
0005433925581	2145	Business	34700.00
0005433037140	2145	Business	34700.00
0005433925570	2145	Business	34700.00
0005433925566	2145	Business	34700.00
0005433929711	2145	Business	34700.00
0005433925542	2145	Business	34700.00
0005432231812	2145	Business	34700.00
0005433925592	2145	Business	34700.00
0005433925533	2145	Business	34700.00
0005433925608	2145	Business	34700.00
0005433925520	2145	Business	34700.00
0005432231811	2145	Business	34700.00
0005433925576	2145	Business	34700.00
0005432231813	2145	Business	34700.00
0005432044591	2145	Business	34700.00
0005433037016	2145	Business	34700.00
0005433925604	2145	Business	34700.00
0005433925517	2145	Business	34700.00
0005433925540	2145	Business	34700.00
0005433925560	2145	Business	34700.00
0005433036873	2145	Business	34700.00
0005433925582	2145	Business	34700.00
0005433875418	2145	Business	34700.00
0005433037023	2145	Economy	12700.00
0005433925516	2145	Economy	12700.00
0005433925612	2145	Economy	12700.00
0005433925600	2145	Economy	12700.00
0005433925573	2145	Economy	11600.00
0005433925536	2145	Economy	11600.00
0005433925548	2145	Economy	11600.00
0005434028336	2145	Economy	11600.00
0005433931539	2145	Economy	11600.00
0005433925603	2145	Economy	11600.00
0005433037067	2145	Economy	11600.00
0005433925521	2145	Economy	11600.00
0005433925530	2145	Economy	11600.00
0005433925557	2145	Economy	11600.00
0005433929712	2145	Economy	11600.00
0005433037006	2145	Economy	11600.00
0005433925550	2145	Economy	11600.00
0005433925543	2145	Economy	11600.00
0005433925518	2145	Economy	11600.00
0005433925574	2145	Economy	11600.00
0005433925611	2145	Economy	11600.00
0005433036878	2145	Economy	11600.00
0005433925567	2145	Economy	11600.00
0005433037208	2145	Economy	11600.00
0005433037123	2145	Economy	11600.00
0005433925528	2145	Economy	11600.00
0005433925575	2145	Economy	11600.00
0005433925545	2145	Economy	11600.00
0005433925588	2145	Economy	11600.00
0005434028340	2145	Economy	11600.00
0005433925589	2145	Economy	11600.00
0005433925534	2145	Economy	11600.00
0005432044589	2145	Economy	11600.00
0005433925529	2145	Economy	11600.00
0005434028337	2145	Economy	11600.00
0005433875417	2145	Economy	11600.00
0005433925605	2145	Economy	11600.00
0005432231814	2145	Economy	11600.00
0005433037062	2145	Economy	11600.00
0005432231820	2145	Economy	11600.00
0005432749818	2145	Economy	11600.00
0005433925547	2145	Economy	11600.00
0005433925584	2145	Economy	11600.00
0005433925578	2145	Economy	11600.00
0005433925519	2145	Economy	11600.00
0005433037180	2145	Economy	11600.00
0005433925541	2145	Economy	11600.00
0005433931538	2145	Economy	11600.00
0005433925583	2145	Economy	11600.00
0005433925537	2145	Economy	11600.00
0005434028335	2145	Economy	11600.00
0005433925598	2145	Economy	11600.00
0005433925558	2145	Economy	11600.00
0005433925538	2145	Economy	11600.00
0005433925591	2145	Economy	11600.00
0005433037204	2145	Economy	11600.00
0005433925602	2145	Economy	11600.00
0005433925594	2145	Economy	11600.00
0005433037281	2145	Economy	11600.00
0005433925515	2145	Economy	11600.00
0005433037122	2145	Economy	11600.00
0005433036991	2145	Economy	11600.00
0005433037066	2145	Economy	11600.00
0005433925527	2145	Economy	11600.00
0005433925531	2145	Economy	11600.00
0005433925580	2145	Economy	11600.00
0005433925539	2145	Economy	11600.00
0005433925579	2145	Economy	11600.00
0005433036648	2145	Economy	11600.00
0005433036977	2145	Economy	11600.00
0005433925596	2145	Economy	11600.00
0005433925569	2145	Economy	11600.00
0005433037083	2145	Economy	11600.00
0005433037314	2145	Economy	11600.00
0005432749803	2145	Economy	11600.00
0005432749811	2145	Economy	11600.00
0005433925559	2145	Economy	11600.00
0005432231817	2145	Economy	11600.00
0005433037181	2145	Economy	11600.00
0005432231819	2145	Economy	11600.00
0005433925549	2145	Economy	11600.00
0005433037085	2145	Economy	12700.00
0005433037005	2145	Economy	12700.00
0005433037096	2145	Economy	11600.00
0005433925599	2145	Economy	11600.00
0005433925526	2145	Economy	12700.00
0005433037100	2145	Economy	11600.00
0005433925607	2145	Economy	12700.00
0005433925535	2145	Economy	11600.00
0005433925523	2145	Economy	11600.00
0005432231816	2145	Economy	11600.00
0005433037121	2145	Economy	11600.00
0005433925565	2145	Economy	11600.00
0005432044590	2145	Economy	11600.00
0005433925568	2145	Economy	11600.00
0005433925563	2145	Economy	11600.00
0005433037077	2145	Economy	11600.00
0005433925544	2145	Economy	11600.00
0005434028348	2145	Economy	11600.00
0005433925595	2145	Economy	11600.00
0005433925572	2145	Economy	11600.00
0005433925601	2145	Economy	11600.00
0005433037009	2145	Economy	11600.00
0005433925564	2145	Economy	11600.00
0005433925562	2145	Economy	11600.00
0005433925546	2145	Economy	11600.00
0005433037057	2145	Economy	11600.00
0005433925524	2145	Economy	11600.00
0005433925587	2145	Economy	11600.00
0005433037038	2145	Economy	11600.00
0005433036978	2145	Economy	11600.00
0005433925553	2145	Economy	11600.00
0005433037040	2145	Economy	11600.00
0005433925590	2145	Economy	11600.00
0005433037239	2145	Economy	11600.00
0005433925571	2145	Economy	11600.00
0005433925586	2145	Economy	11600.00
0005433925606	2145	Economy	11600.00
0005433037202	2145	Economy	11600.00
0005433037173	2145	Economy	11600.00
0005433925585	2145	Economy	11600.00
0005433925609	2145	Economy	11600.00
0005433925522	2145	Economy	11600.00
0005433036647	2145	Economy	11600.00
0005433037065	2145	Economy	11600.00
0005433925577	2145	Economy	11600.00
0005433925597	2145	Economy	11600.00
0005433037174	2145	Economy	11600.00
0005433036920	2145	Economy	11600.00
0005433037074	2145	Economy	11600.00
0005433037049	2145	Economy	11600.00
0005433925593	2145	Economy	11600.00
0005433925525	2145	Economy	11600.00
0005433925556	2145	Economy	11600.00
0005433037282	2145	Economy	11600.00
0005433925610	2145	Economy	11600.00
0005433037039	2145	Economy	11600.00
0005433925552	2145	Economy	11600.00
0005433037056	2145	Economy	11600.00
0005432231818	2145	Economy	11600.00
0005433925551	2145	Economy	11600.00
0005433037203	2145	Economy	11600.00
0005433925532	2145	Economy	11600.00
0005433037134	2145	Economy	11600.00
0005433037212	2145	Economy	11600.00
0005433036979	2145	Economy	11600.00
0005433037280	2145	Economy	11600.00
0005433037101	2145	Economy	11600.00
0005433925555	2145	Economy	11600.00
0005433925554	2145	Economy	11600.00
0005433925561	2145	Economy	11600.00
0005433037553	24094	Business	34700.00
0005433037548	24094	Business	34700.00
0005433037529	24094	Business	34700.00
0005433924640	24094	Business	34700.00
0005432206331	24094	Business	34700.00
0005433037559	24094	Business	34700.00
0005433924694	24094	Business	34700.00
0005433924429	24094	Business	34700.00
0005433924530	24094	Business	34700.00
0005433924400	24094	Business	34700.00
0005433925174	24094	Business	34700.00
0005433924906	24094	Business	34700.00
0005433037535	24094	Business	34700.00
0005433924765	24094	Business	34700.00
0005433924815	24094	Business	34700.00
0005433924158	24094	Business	34700.00
0005433037544	24094	Business	34700.00
0005433925099	24094	Business	34700.00
0005433924753	24094	Business	34700.00
0005433037551	24094	Business	34700.00
0005433924822	24094	Business	34700.00
0005433037526	24094	Business	34700.00
0005433924795	24094	Business	34700.00
0005432206333	24094	Business	34700.00
0005433924844	24094	Business	34700.00
0005433924351	24094	Economy	12700.00
0005433924922	24094	Economy	12700.00
0005433037527	24094	Economy	11600.00
0005433037554	24094	Economy	11600.00
0005432749837	24094	Economy	11600.00
0005433924399	24094	Economy	11600.00
0005433929662	24094	Economy	11600.00
0005433925062	24094	Economy	11600.00
0005433924536	24094	Economy	11600.00
0005433037546	24094	Economy	11600.00
0005433924992	24094	Economy	11600.00
0005433924499	24094	Economy	11600.00
0005433924566	24094	Economy	11600.00
0005433924791	24094	Economy	11600.00
0005433924157	24094	Economy	11600.00
0005433924416	24094	Economy	11600.00
0005433924641	24094	Economy	11600.00
0005433924977	24094	Economy	11600.00
0005433924905	24094	Economy	11600.00
0005433037522	24094	Economy	11600.00
0005433037523	24094	Economy	11600.00
0005433924878	24094	Economy	11600.00
0005433924550	24094	Economy	11600.00
0005433924078	24094	Economy	11600.00
0005433037547	24094	Economy	11600.00
0005433037550	24094	Economy	11600.00
0005433925147	24094	Economy	11600.00
0005433925013	24094	Economy	11600.00
0005433924759	24094	Economy	11600.00
0005433924942	24094	Economy	11600.00
0005433924704	24094	Economy	11600.00
0005433924725	24094	Economy	11600.00
0005433924660	24094	Economy	11600.00
0005433037530	24094	Economy	11600.00
0005433037564	24094	Economy	11600.00
0005433924469	24094	Economy	11600.00
0005433037560	24094	Economy	11600.00
0005433924708	24094	Economy	11600.00
0005433037542	24094	Economy	11600.00
0005433037519	24094	Economy	11600.00
0005433924917	24094	Economy	11600.00
0005433924639	24094	Economy	11600.00
0005433924903	24094	Economy	11600.00
0005433037556	24094	Economy	11600.00
0005432206335	24094	Economy	11600.00
0005433924823	24094	Economy	11600.00
0005433924918	24094	Economy	11600.00
0005433924893	24094	Economy	11600.00
0005433924978	24094	Economy	11600.00
0005433924682	24094	Economy	11600.00
0005433924609	24094	Economy	11600.00
0005433037557	24094	Economy	11600.00
0005433924492	24094	Economy	11600.00
0005433924599	24094	Economy	11600.00
0005433924961	24094	Economy	11600.00
0005433924758	24094	Economy	11600.00
0005433037561	24094	Economy	11600.00
0005433924428	24094	Economy	11600.00
0005432206330	24094	Economy	11600.00
0005433924919	24094	Economy	11600.00
0005433924646	24094	Economy	11600.00
0005433924747	24094	Economy	11600.00
0005433924877	24094	Economy	11600.00
0005433924612	24094	Economy	11600.00
0005433924392	24094	Economy	11600.00
0005433037531	24094	Economy	11600.00
0005433924783	24094	Economy	11600.00
0005433037555	24094	Economy	11600.00
0005433924879	24094	Economy	11600.00
0005433924567	24094	Economy	11600.00
0005433925145	24094	Economy	11600.00
0005433037524	24094	Economy	11600.00
0005433925150	24094	Economy	11600.00
0005433037545	24094	Economy	11600.00
0005433924892	24094	Economy	11600.00
0005433037525	24094	Economy	11600.00
0005433037552	24094	Economy	11600.00
0005433924468	24094	Economy	11600.00
0005433037534	24094	Economy	11600.00
0005433924955	24094	Economy	11600.00
0005433037562	24094	Economy	11600.00
0005433924675	24094	Economy	11600.00
0005433924983	24094	Economy	11600.00
0005433037515	24094	Economy	11600.00
0005433924064	24094	Economy	11600.00
0005433037520	24094	Economy	11600.00
0005432207724	24094	Economy	11600.00
0005433037566	24094	Economy	11600.00
0005433924608	24094	Economy	11600.00
0005433037538	24094	Economy	11600.00
0005433924401	24094	Economy	11600.00
0005433925012	24094	Economy	11600.00
0005433037558	24094	Economy	11600.00
0005432749836	24094	Economy	11600.00
0005433924923	24094	Economy	11600.00
0005433037537	24094	Economy	11600.00
0005433037540	24094	Economy	11600.00
0005433924909	24094	Economy	11600.00
0005433924537	24094	Economy	12700.00
0005433924595	24094	Economy	12700.00
0005433924658	24094	Economy	11600.00
0005433924500	24094	Economy	11600.00
0005433925100	24094	Economy	11600.00
0005433924763	24094	Economy	12700.00
0005432207722	24094	Economy	12700.00
0005433924671	24094	Economy	11600.00
0005433037532	24094	Economy	11600.00
0005433924593	24094	Economy	11600.00
0005432206334	24094	Economy	11600.00
0005433924739	24094	Economy	11600.00
0005433925063	24094	Economy	11600.00
0005433924904	24094	Economy	11600.00
0005433037521	24094	Economy	11600.00
0005433924908	24094	Economy	11600.00
0005433924569	24094	Economy	11600.00
0005433037517	24094	Economy	11600.00
0005433037536	24094	Economy	11600.00
0005433037543	24094	Economy	11600.00
0005433924568	24094	Economy	11600.00
0005433924960	24094	Economy	11600.00
0005433924707	24094	Economy	11600.00
0005433924792	24094	Economy	11600.00
0005433924557	24094	Economy	11600.00
0005433924752	24094	Economy	11600.00
0005433924831	24094	Economy	11600.00
0005433924896	24094	Economy	11600.00
0005432207723	24094	Economy	11600.00
0005433924943	24094	Economy	11600.00
0005433924573	24094	Economy	11600.00
0005433924350	24094	Economy	11600.00
0005433037541	24094	Economy	11600.00
0005433037549	24094	Economy	11600.00
0005433924760	24094	Economy	11600.00
0005433924433	24094	Economy	11600.00
0005433924575	24094	Economy	11600.00
0005433924771	24094	Economy	11600.00
0005433924797	24094	Economy	11600.00
0005433924994	24094	Economy	11600.00
0005433924705	24094	Economy	11600.00
0005433925146	24094	Economy	11600.00
0005433924785	24094	Economy	11600.00
0005433037528	24094	Economy	11600.00
0005433037533	24094	Economy	11600.00
0005433924683	24094	Economy	11600.00
0005433925101	24094	Economy	11600.00
0005433924772	24094	Economy	11600.00
0005433924349	24094	Economy	11600.00
0005433875393	24094	Economy	11600.00
0005433924490	24094	Economy	11600.00
0005433925098	24094	Economy	11600.00
0005433929688	24094	Economy	11600.00
0005433924912	24094	Economy	11600.00
0005433924826	24094	Economy	11600.00
0005433924873	24094	Economy	11600.00
0005433037565	24094	Economy	11600.00
0005433924993	24094	Economy	11600.00
0005433924784	24094	Economy	11600.00
0005433037518	24094	Economy	11600.00
0005433924786	24094	Economy	11600.00
0005433925175	24094	Economy	11600.00
0005433929674	24094	Economy	11600.00
0005433924598	24094	Economy	11600.00
0005433924488	24094	Economy	11600.00
0005433037563	24094	Economy	11600.00
0005433924710	24094	Economy	11600.00
0005432206332	24094	Economy	11600.00
0005433924594	24094	Economy	11600.00
0005433925184	24094	Economy	11600.00
0005433924796	24094	Economy	11600.00
0005433924680	24094	Economy	11600.00
0005433037516	24094	Economy	11600.00
0005433037567	24094	Economy	11600.00
0005433924709	24094	Economy	11600.00
0005433924659	24094	Economy	11600.00
0005433924854	24094	Economy	11600.00
0005433037539	24094	Economy	11600.00
0005433924798	24094	Economy	11600.00
0005432278124	269	Business	83700.00
0005433235091	269	Business	83700.00
0005434728276	269	Business	83700.00
0005434552514	269	Business	83700.00
0005434728386	269	Business	83700.00
0005434552535	269	Business	83700.00
0005432278121	269	Business	83700.00
0005434728298	269	Business	83700.00
0005433235139	269	Business	83700.00
0005434728384	269	Business	83700.00
0005433235120	269	Business	83700.00
0005434728328	269	Business	83700.00
0005433235092	269	Business	83700.00
0005435142903	269	Business	83700.00
0005434302561	269	Business	83700.00
0005434552503	269	Business	83700.00
0005433126923	269	Business	83700.00
0005434728347	269	Business	83700.00
0005433235380	269	Business	83700.00
0005434728284	269	Business	83700.00
0005434728344	269	Business	83700.00
0005434728367	269	Business	83700.00
0005434552538	269	Business	83700.00
0005434728383	269	Business	83700.00
0005434728321	269	Business	83700.00
0005434728319	269	Comfort	47400.00
0005433181371	269	Business	83700.00
0005432278133	269	Comfort	47400.00
0005434728302	269	Comfort	47400.00
0005434728314	269	Comfort	47400.00
0005433131772	269	Comfort	47400.00
0005434728268	269	Comfort	47400.00
0005434552519	269	Comfort	47400.00
0005433235212	269	Comfort	47400.00
0005434552549	269	Comfort	47400.00
0005433234932	269	Comfort	47400.00
0005434728338	269	Comfort	47400.00
0005433235284	269	Comfort	47400.00
0005432278130	269	Comfort	47400.00
0005434552524	269	Comfort	47400.00
0005433181444	269	Comfort	47400.00
0005434552515	269	Comfort	47400.00
0005435142895	269	Comfort	47400.00
0005434728313	269	Comfort	47400.00
0005434728286	269	Comfort	47400.00
0005434728369	269	Comfort	47400.00
0005433235159	269	Comfort	47400.00
0005434728326	269	Comfort	47400.00
0005433235176	269	Comfort	47400.00
0005434552540	269	Comfort	47400.00
0005433181518	269	Comfort	47400.00
0005434728301	269	Comfort	47400.00
0005432278131	269	Comfort	47400.00
0005432278122	269	Comfort	47400.00
0005433235321	269	Comfort	47400.00
0005433181370	269	Comfort	47400.00
0005435142898	269	Comfort	47400.00
0005433235217	269	Comfort	47400.00
0005434728377	269	Comfort	47400.00
0005434728318	269	Comfort	47400.00
0005434728360	269	Comfort	47400.00
0005434728316	269	Economy	27900.00
0005434552513	269	Economy	27900.00
0005434728325	269	Economy	27900.00
0005434728272	269	Economy	27900.00
0005434728389	269	Economy	27900.00
0005433235046	269	Economy	27900.00
0005434552548	269	Economy	27900.00
0005434728376	269	Economy	27900.00
0005434552527	269	Economy	27900.00
0005434552506	269	Economy	27900.00
0005434552543	269	Economy	27900.00
0005434728279	269	Economy	27900.00
0005432278120	269	Economy	27900.00
0005434552510	269	Economy	27900.00
0005433289945	269	Economy	27900.00
0005433235118	269	Economy	27900.00
0005434728285	269	Economy	27900.00
0005433181600	269	Economy	27900.00
0005434728346	269	Economy	27900.00
0005434728373	269	Economy	27900.00
0005434552500	269	Economy	27900.00
0005434728270	269	Economy	27900.00
0005435142891	269	Economy	27900.00
0005434728341	269	Economy	27900.00
0005433181460	269	Economy	27900.00
0005432278125	269	Economy	27900.00
0005433289966	269	Economy	27900.00
0005433234975	269	Economy	27900.00
0005434552504	269	Economy	27900.00
0005434728293	269	Economy	27900.00
0005434728310	269	Economy	27900.00
0005434728329	269	Economy	27900.00
0005433235398	269	Economy	27900.00
0005434728343	269	Economy	27900.00
0005434728336	269	Economy	27900.00
0005434728382	269	Economy	27900.00
0005433235119	269	Economy	27900.00
0005433766685	269	Economy	27900.00
0005434728307	269	Economy	27900.00
0005434728332	269	Economy	27900.00
0005434302560	269	Economy	27900.00
0005434728378	269	Economy	27900.00
0005432278126	269	Economy	27900.00
0005434728362	269	Economy	27900.00
0005434728311	269	Economy	27900.00
0005434728380	269	Economy	27900.00
0005434552507	269	Economy	27900.00
0005433234971	269	Economy	27900.00
0005433235071	269	Economy	27900.00
0005434728295	269	Economy	27900.00
0005433235083	269	Economy	27900.00
0005434302892	269	Economy	27900.00
0005433235397	269	Economy	27900.00
0005433235047	269	Economy	27900.00
0005433181511	269	Economy	27900.00
0005434728349	269	Economy	27900.00
0005433235185	269	Economy	27900.00
0005433235322	269	Economy	27900.00
0005433235226	269	Economy	27900.00
0005434552502	269	Economy	27900.00
0005434552509	269	Economy	27900.00
0005433235287	269	Economy	27900.00
0005433235329	269	Economy	27900.00
0005434728288	269	Economy	27900.00
0005434728312	269	Economy	30700.00
0005434731266	269	Economy	30700.00
0005434731267	269	Economy	27900.00
0005434728358	269	Economy	30700.00
0005434552518	269	Economy	27900.00
0005434728353	269	Economy	27900.00
0005432278128	269	Economy	27900.00
0005433235412	269	Economy	30700.00
0005434552537	269	Economy	27900.00
0005434731265	269	Economy	30700.00
0005434728303	269	Economy	27900.00
0005434735808	269	Economy	27900.00
0005433289958	269	Economy	27900.00
0005433181533	269	Economy	27900.00
0005435142894	269	Economy	27900.00
0005433766684	269	Economy	27900.00
0005434728387	269	Economy	27900.00
0005434552533	269	Economy	27900.00
0005435142902	269	Economy	27900.00
0005433181547	269	Economy	27900.00
0005433235228	269	Economy	27900.00
0005434728287	269	Economy	27900.00
0005434728354	269	Economy	27900.00
0005434552530	269	Economy	27900.00
0005435142901	269	Economy	27900.00
0005434728340	269	Economy	27900.00
0005433235021	269	Economy	27900.00
0005433234977	269	Economy	27900.00
0005434728281	269	Economy	27900.00
0005433235396	269	Economy	27900.00
0005434728364	269	Economy	27900.00
0005433235082	269	Economy	27900.00
0005433235288	269	Economy	27900.00
0005433235051	269	Economy	27900.00
0005434552536	269	Economy	27900.00
0005435142899	269	Economy	27900.00
0005434728374	269	Economy	27900.00
0005434728269	269	Economy	27900.00
0005433235227	269	Economy	27900.00
0005434552512	269	Economy	27900.00
0005434552531	269	Economy	27900.00
0005434728271	269	Economy	27900.00
0005434728371	269	Economy	27900.00
0005432278127	269	Economy	27900.00
0005434728306	269	Economy	27900.00
0005433235289	269	Economy	27900.00
0005434552516	269	Economy	27900.00
0005433181489	269	Economy	27900.00
0005433289965	269	Economy	27900.00
0005434728366	269	Economy	27900.00
0005434728335	269	Economy	27900.00
0005435142904	269	Economy	27900.00
0005433235090	269	Economy	27900.00
0005433235121	269	Economy	27900.00
0005433235302	269	Economy	27900.00
0005433181561	269	Economy	27900.00
0005434728339	269	Economy	27900.00
0005434728292	269	Economy	27900.00
0005433766681	269	Economy	27900.00
0005434731268	269	Economy	27900.00
0005434728297	269	Economy	27900.00
0005434728275	269	Economy	27900.00
0005435142897	269	Economy	27900.00
0005434728368	269	Economy	27900.00
0005434552541	269	Economy	27900.00
0005434552521	269	Economy	27900.00
0005434728351	269	Economy	27900.00
0005434552546	269	Economy	27900.00
0005433234974	269	Economy	27900.00
0005433234942	269	Economy	27900.00
0005434728350	269	Economy	27900.00
0005433235043	269	Economy	27900.00
0005434728372	269	Economy	27900.00
0005433181372	269	Economy	27900.00
0005434552526	269	Economy	27900.00
0005432278129	269	Economy	27900.00
0005433235128	269	Economy	27900.00
0005433181538	269	Economy	27900.00
0005433766690	269	Economy	27900.00
0005434552544	269	Economy	27900.00
0005434552550	269	Economy	27900.00
0005434552553	269	Economy	27900.00
0005434728355	269	Economy	27900.00
0005434728315	269	Economy	27900.00
0005434552523	269	Economy	27900.00
0005434552551	269	Economy	27900.00
0005434552545	269	Economy	27900.00
0005434552525	269	Economy	27900.00
0005434728324	269	Economy	27900.00
0005434552547	269	Economy	27900.00
0005434728334	269	Economy	27900.00
0005433234933	269	Economy	27900.00
0005432278119	269	Economy	27900.00
0005434302563	269	Economy	27900.00
0005434728290	269	Economy	27900.00
0005433181445	269	Economy	27900.00
0005434728337	269	Economy	27900.00
0005434735810	269	Economy	27900.00
0005434552542	269	Economy	27900.00
0005434735809	269	Economy	27900.00
0005434728348	269	Economy	27900.00
0005434728299	269	Economy	27900.00
0005433181475	269	Economy	27900.00
0005434728356	269	Economy	27900.00
0005433181537	269	Economy	27900.00
0005433113570	269	Economy	27900.00
0005433235070	269	Economy	27900.00
0005435142896	269	Economy	27900.00
0005434728274	269	Economy	27900.00
0005434728320	269	Economy	27900.00
0005434302562	269	Economy	27900.00
0005434552534	269	Economy	30700.00
0005434552528	269	Economy	30700.00
0005434728361	269	Economy	27900.00
0005434552508	269	Economy	30700.00
0005433235177	269	Economy	27900.00
0005434728296	269	Economy	27900.00
0005434728278	269	Economy	27900.00
0005433131767	269	Economy	27900.00
0005434728323	269	Economy	27900.00
0005434728300	269	Economy	27900.00
0005434552532	269	Economy	27900.00
0005434728283	269	Economy	27900.00
0005434552511	269	Economy	27900.00
0005433235087	269	Economy	27900.00
0005433234879	269	Economy	27900.00
0005434728379	269	Economy	27900.00
0005434728385	269	Economy	27900.00
0005434552517	269	Economy	27900.00
0005432278132	269	Economy	27900.00
0005433235061	269	Economy	27900.00
0005433181488	269	Economy	27900.00
0005433235311	269	Economy	27900.00
0005433235042	269	Economy	27900.00
0005433235129	269	Economy	27900.00
0005434552552	269	Economy	27900.00
0005434728345	269	Economy	27900.00
0005433766691	269	Economy	27900.00
0005433235323	269	Economy	27900.00
0005434552505	269	Economy	27900.00
0005433181487	269	Economy	27900.00
0005434728322	269	Economy	27900.00
0005433235236	269	Economy	27900.00
0005434728331	269	Economy	27900.00
0005433235002	269	Economy	27900.00
0005433131766	269	Economy	27900.00
0005434728390	269	Economy	27900.00
0005434735807	269	Economy	27900.00
0005434302564	269	Economy	27900.00
0005433235081	269	Economy	27900.00
0005433289963	269	Economy	27900.00
0005433181531	269	Economy	27900.00
0005433235215	269	Economy	27900.00
0005434552501	269	Economy	27900.00
0005434728333	269	Economy	27900.00
0005433235048	269	Economy	27900.00
0005434728370	269	Economy	27900.00
0005433181508	269	Economy	27900.00
0005434728375	269	Economy	27900.00
0005434728308	269	Economy	27900.00
0005433181492	269	Economy	27900.00
0005434302893	269	Economy	27900.00
0005434728357	269	Economy	27900.00
0005434731269	269	Economy	27900.00
0005433235160	269	Economy	27900.00
0005433181486	269	Economy	27900.00
0005434552499	269	Economy	27900.00
0005434728365	269	Economy	27900.00
0005434552539	269	Economy	27900.00
0005434728282	269	Economy	27900.00
0005433235216	269	Economy	27900.00
0005434728289	269	Economy	27900.00
0005433234880	269	Economy	27900.00
0005433235297	269	Economy	27900.00
0005434728277	269	Economy	27900.00
0005434552520	269	Economy	27900.00
0005433181534	269	Economy	27900.00
0005432278123	269	Economy	27900.00
0005433181442	269	Economy	27900.00
0005434728342	269	Economy	27900.00
0005433235186	269	Economy	27900.00
0005433235088	269	Economy	27900.00
0005433235020	269	Economy	27900.00
0005434728330	269	Economy	27900.00
0005434728273	269	Economy	27900.00
0005433131782	269	Economy	27900.00
0005434552529	269	Economy	27900.00
0005434728304	269	Economy	27900.00
0005434728317	269	Economy	27900.00
0005435142892	269	Economy	27900.00
0005434728352	269	Economy	27900.00
0005434728291	269	Economy	27900.00
0005433235312	269	Economy	27900.00
0005434728280	269	Economy	27900.00
0005434728327	269	Economy	27900.00
0005433235117	269	Economy	27900.00
0005434728294	269	Economy	27900.00
0005434728388	269	Economy	27900.00
0005434728359	269	Economy	27900.00
0005435142900	269	Economy	27900.00
0005433235356	269	Economy	27900.00
0005433111540	269	Economy	27900.00
0005433235213	269	Economy	27900.00
0005434552522	269	Economy	27900.00
0005434728381	269	Economy	27900.00
0005434728305	269	Economy	27900.00
0005433235069	269	Economy	27900.00
0005435142893	269	Economy	27900.00
0005433181474	269	Economy	27900.00
0005433113571	269	Economy	27900.00
0005434728309	269	Economy	27900.00
0005434728363	269	Economy	27900.00
0005433234972	269	Economy	27900.00
0005433181446	269	Economy	27900.00
0005434727432	9832	Business	83700.00
0005434726837	9832	Business	83700.00
0005434727431	9832	Business	83700.00
0005434727766	9832	Business	83700.00
0005434726915	9832	Business	83700.00
0005434727587	9832	Business	83700.00
0005434552012	9832	Business	83700.00
0005434726907	9832	Business	83700.00
0005434551759	9832	Business	83700.00
0005433235707	9832	Business	83700.00
0005434551880	9832	Business	83700.00
0005433126954	9832	Business	83700.00
0005434727146	9832	Business	83700.00
0005433126955	9832	Business	83700.00
0005434727590	9832	Business	83700.00
0005434551890	9832	Business	83700.00
0005433181689	9832	Business	83700.00
0005434727324	9832	Business	83700.00
0005434727589	9832	Business	83700.00
0005434551835	9832	Business	83700.00
0005434727639	9832	Business	83700.00
0005434726874	9832	Business	83700.00
0005434727229	9832	Business	83700.00
0005434551853	9832	Business	83700.00
0005434727640	9832	Comfort	47400.00
0005433181684	9832	Comfort	47400.00
0005434727238	9832	Comfort	47400.00
0005433235706	9832	Comfort	47400.00
0005433181703	9832	Comfort	47400.00
0005434727195	9832	Comfort	47400.00
0005434727690	9832	Comfort	47400.00
0005434727397	9832	Comfort	47400.00
0005433235701	9832	Comfort	47400.00
0005434551904	9832	Comfort	47400.00
0005434731226	9832	Comfort	47400.00
0005434726950	9832	Comfort	47400.00
0005434552103	9832	Comfort	47400.00
0005434727337	9832	Comfort	47400.00
0005433290018	9832	Comfort	47400.00
0005433235693	9832	Comfort	47400.00
0005434726901	9832	Comfort	47400.00
0005434727504	9832	Comfort	47400.00
0005434731225	9832	Comfort	47400.00
0005434551996	9832	Comfort	47400.00
0005433235669	9832	Comfort	47400.00
0005434552023	9832	Comfort	47400.00
0005433235679	9832	Comfort	47400.00
0005434727256	9832	Comfort	47400.00
0005433181692	9832	Comfort	47400.00
0005434727621	9832	Comfort	47400.00
0005434727180	9832	Comfort	47400.00
0005433235681	9832	Comfort	47400.00
0005433235708	9832	Comfort	47400.00
0005434726487	9832	Comfort	47400.00
0005434727247	9832	Comfort	47400.00
0005434727125	9832	Comfort	47400.00
0005434727581	9832	Comfort	47400.00
0005434551814	9832	Economy	27900.00
0005433235713	9832	Economy	27900.00
0005434727418	9832	Economy	27900.00
0005434552047	9832	Economy	27900.00
0005433181688	9832	Economy	27900.00
0005433235688	9832	Economy	27900.00
0005434727398	9832	Economy	27900.00
0005433235711	9832	Economy	27900.00
0005434726829	9832	Economy	27900.00
0005434552074	9832	Economy	27900.00
0005434552248	9832	Economy	27900.00
0005433290014	9832	Economy	27900.00
0005433235661	9832	Economy	27900.00
0005434726957	9832	Economy	27900.00
0005434726972	9832	Economy	27900.00
0005433235702	9832	Economy	27900.00
0005433235691	9832	Economy	27900.00
0005433181691	9832	Economy	27900.00
0005434727255	9832	Economy	27900.00
0005434727208	9832	Economy	27900.00
0005433235690	9832	Economy	27900.00
0005434727130	9832	Economy	27900.00
0005433181702	9832	Economy	27900.00
0005434552058	9832	Economy	27900.00
0005434727453	9832	Economy	27900.00
0005433126953	9832	Economy	27900.00
0005434727086	9832	Economy	27900.00
0005433235678	9832	Economy	27900.00
0005434551811	9832	Economy	27900.00
0005433235660	9832	Economy	27900.00
0005434551831	9832	Economy	27900.00
0005433235672	9832	Economy	27900.00
0005434726790	9832	Economy	27900.00
0005434727196	9832	Economy	27900.00
0005433235656	9832	Economy	27900.00
0005434727079	9832	Economy	27900.00
0005434552254	9832	Economy	27900.00
0005434727479	9832	Economy	27900.00
0005434726694	9832	Economy	27900.00
0005434727536	9832	Economy	27900.00
0005434552255	9832	Economy	27900.00
0005433235667	9832	Economy	27900.00
0005434727327	9832	Economy	27900.00
0005434727454	9832	Economy	27900.00
0005433129383	9832	Economy	27900.00
0005433181700	9832	Economy	27900.00
0005434727302	9832	Economy	27900.00
0005433181690	9832	Economy	27900.00
0005434726951	9832	Economy	27900.00
0005434032133	9832	Economy	27900.00
0005433290020	9832	Economy	27900.00
0005434727475	9832	Economy	27900.00
0005434727580	9832	Economy	27900.00
0005433235662	9832	Economy	27900.00
0005434727591	9832	Economy	27900.00
0005433235675	9832	Economy	30700.00
0005434726855	9832	Economy	27900.00
0005433235704	9832	Economy	30700.00
0005434726776	9832	Economy	27900.00
0005434727237	9832	Economy	27900.00
0005433113588	9832	Economy	30700.00
0005434727230	9832	Economy	30700.00
0005434552213	9832	Economy	27900.00
0005434727078	9832	Economy	30700.00
0005433235674	9832	Economy	27900.00
0005434727033	9832	Economy	27900.00
0005433235659	9832	Economy	27900.00
0005434727611	9832	Economy	27900.00
0005432199413	9832	Economy	27900.00
0005435142777	9832	Economy	27900.00
0005434727179	9832	Economy	27900.00
0005434727494	9832	Economy	27900.00
0005433181697	9832	Economy	27900.00
0005433235664	9832	Economy	27900.00
0005434726635	9832	Economy	27900.00
0005434302515	9832	Economy	27900.00
0005433235710	9832	Economy	27900.00
0005434727034	9832	Economy	27900.00
0005433235687	9832	Economy	27900.00
0005434551938	9832	Economy	27900.00
0005434735751	9832	Economy	27900.00
0005434727077	9832	Economy	27900.00
0005433235670	9832	Economy	27900.00
0005432199417	9832	Economy	27900.00
0005433235682	9832	Economy	27900.00
0005434727307	9832	Economy	27900.00
0005434552045	9832	Economy	27900.00
0005434302514	9832	Economy	27900.00
0005434727338	9832	Economy	27900.00
0005434727231	9832	Economy	27900.00
0005434727313	9832	Economy	27900.00
0005433235671	9832	Economy	27900.00
0005433235658	9832	Economy	27900.00
0005433235685	9832	Economy	27900.00
0005433235677	9832	Economy	27900.00
0005434552063	9832	Economy	27900.00
0005434727875	9832	Economy	27900.00
0005434727181	9832	Economy	27900.00
0005434727355	9832	Economy	27900.00
0005434727719	9832	Economy	27900.00
0005434727539	9832	Economy	27900.00
0005434727632	9832	Economy	27900.00
0005434552051	9832	Economy	27900.00
0005434551913	9832	Economy	27900.00
0005433181701	9832	Economy	27900.00
0005434735782	9832	Economy	27900.00
0005433766731	9832	Economy	27900.00
0005434727368	9832	Economy	27900.00
0005434551813	9832	Economy	27900.00
0005434735763	9832	Economy	27900.00
0005433290019	9832	Economy	27900.00
0005433181687	9832	Economy	27900.00
0005433235709	9832	Economy	27900.00
0005434727235	9832	Economy	27900.00
0005433290017	9832	Economy	27900.00
0005434727217	9832	Economy	27900.00
0005433235657	9832	Economy	27900.00
0005433235689	9832	Economy	27900.00
0005434726763	9832	Economy	27900.00
0005434726789	9832	Economy	27900.00
0005433235694	9832	Economy	27900.00
0005434727379	9832	Economy	27900.00
0005434552073	9832	Economy	27900.00
0005433235684	9832	Economy	27900.00
0005434552062	9832	Economy	27900.00
0005434727442	9832	Economy	27900.00
0005433181693	9832	Economy	27900.00
0005435142711	9832	Economy	27900.00
0005434302528	9832	Economy	27900.00
0005435142743	9832	Economy	27900.00
0005434727299	9832	Economy	27900.00
0005434726693	9832	Economy	27900.00
0005434551742	9832	Economy	27900.00
0005433181683	9832	Economy	27900.00
0005434726407	9832	Economy	27900.00
0005433766730	9832	Economy	27900.00
0005434727308	9832	Economy	27900.00
0005434551919	9832	Economy	27900.00
0005433235676	9832	Economy	27900.00
0005433290015	9832	Economy	27900.00
0005433113587	9832	Economy	27900.00
0005433181704	9832	Economy	27900.00
0005434726274	9832	Economy	27900.00
0005433181705	9832	Economy	27900.00
0005433235666	9832	Economy	27900.00
0005435142744	9832	Economy	27900.00
0005434032136	9832	Economy	27900.00
0005434726617	9832	Economy	27900.00
0005434726971	9832	Economy	27900.00
0005434032134	9832	Economy	27900.00
0005433129382	9832	Economy	27900.00
0005433235665	9832	Economy	27900.00
0005434727171	9832	Economy	27900.00
0005433181706	9832	Economy	27900.00
0005434726692	9832	Economy	27900.00
0005434551972	9832	Economy	27900.00
0005434551810	9832	Economy	27900.00
0005433235700	9832	Economy	27900.00
0005434731236	9832	Economy	27900.00
0005434552033	9832	Economy	27900.00
0005434727592	9832	Economy	27900.00
0005434727588	9832	Economy	27900.00
0005434552064	9832	Economy	27900.00
0005433129385	9832	Economy	27900.00
0005434727771	9832	Economy	27900.00
0005433290016	9832	Economy	27900.00
0005433235692	9832	Economy	30700.00
0005433181696	9832	Economy	30700.00
0005434727744	9832	Economy	30700.00
0005434551765	9832	Economy	30700.00
0005433766732	9832	Economy	30700.00
0005434727490	9832	Economy	27900.00
0005434552281	9832	Economy	30700.00
0005433181707	9832	Economy	27900.00
0005434552019	9832	Economy	27900.00
0005434727348	9832	Economy	27900.00
0005434552005	9832	Economy	27900.00
0005433181695	9832	Economy	27900.00
0005434726925	9832	Economy	27900.00
0005434726924	9832	Economy	27900.00
0005433766729	9832	Economy	27900.00
0005435142703	9832	Economy	27900.00
0005433181698	9832	Economy	27900.00
0005434726467	9832	Economy	27900.00
0005434551995	9832	Economy	27900.00
0005433235683	9832	Economy	27900.00
0005433181686	9832	Economy	27900.00
0005434552104	9832	Economy	27900.00
0005434727059	9832	Economy	27900.00
0005433235695	9832	Economy	27900.00
0005433766728	9832	Economy	27900.00
0005434727321	9832	Economy	27900.00
0005432199412	9832	Economy	27900.00
0005434551936	9832	Economy	27900.00
0005434727491	9832	Economy	27900.00
0005433235673	9832	Economy	27900.00
0005434727025	9832	Economy	27900.00
0005434552013	9832	Economy	27900.00
0005434727306	9832	Economy	27900.00
0005432199415	9832	Economy	27900.00
0005434551971	9832	Economy	27900.00
0005434552176	9832	Economy	27900.00
0005433235703	9832	Economy	27900.00
0005434727349	9832	Economy	27900.00
0005434551760	9832	Economy	27900.00
0005434727537	9832	Economy	27900.00
0005434727486	9832	Economy	27900.00
0005434032135	9832	Economy	27900.00
0005433235696	9832	Economy	27900.00
0005434552028	9832	Economy	27900.00
0005433235699	9832	Economy	27900.00
0005433235686	9832	Economy	27900.00
0005434727071	9832	Economy	27900.00
0005434727127	9832	Economy	27900.00
0005434726979	9832	Economy	27900.00
0005432199410	9832	Economy	27900.00
0005434726663	9832	Economy	27900.00
0005433235697	9832	Economy	27900.00
0005434552093	9832	Economy	27900.00
0005434727064	9832	Economy	27900.00
0005433181699	9832	Economy	27900.00
0005434727624	9832	Economy	27900.00
0005434727070	9832	Economy	27900.00
0005434552046	9832	Economy	27900.00
0005433235714	9832	Economy	27900.00
0005435142684	9832	Economy	27900.00
0005434727623	9832	Economy	27900.00
0005434552076	9832	Economy	27900.00
0005434727515	9832	Economy	27900.00
0005434726601	9832	Economy	27900.00
0005433126952	9832	Economy	27900.00
0005434727753	9832	Economy	27900.00
0005434727312	9832	Economy	27900.00
0005434552108	9832	Economy	27900.00
0005434726406	9832	Economy	27900.00
0005434727223	9832	Economy	27900.00
0005434727378	9832	Economy	27900.00
0005434726914	9832	Economy	27900.00
0005434735764	9832	Economy	27900.00
0005433235712	9832	Economy	27900.00
0005435142710	9832	Economy	27900.00
0005433235663	9832	Economy	27900.00
0005433235698	9832	Economy	27900.00
0005434727443	9832	Economy	27900.00
0005432199414	9832	Economy	27900.00
0005434726602	9832	Economy	27900.00
0005434727633	9832	Economy	27900.00
0005433129384	9832	Economy	27900.00
0005432199416	9832	Economy	27900.00
0005434727287	9832	Economy	27900.00
0005432199411	9832	Economy	27900.00
0005434727024	9832	Economy	27900.00
0005434727197	9832	Economy	27900.00
0005435142793	9832	Economy	27900.00
0005433235705	9832	Economy	27900.00
0005433181685	9832	Economy	27900.00
0005433235668	9832	Economy	27900.00
0005433181694	9832	Economy	27900.00
0005433235680	9832	Economy	27900.00
0005434552256	9832	Economy	27900.00
0005434726466	9832	Economy	27900.00
0005434551905	9832	Economy	27900.00
0005434032132	9832	Economy	27900.00
0005434727298	9832	Economy	27900.00
0005433235715	9832	Economy	27900.00
0005434727487	9832	Economy	27900.00
0005435214585	7742	Business	42100.00
0005432531055	7742	Business	42100.00
0005435214419	7742	Business	42100.00
0005432069993	7742	Business	42100.00
0005434069238	7742	Business	42100.00
0005432531031	7742	Business	42100.00
0005432531051	7742	Business	42100.00
0005432531067	7742	Business	42100.00
0005432531019	7742	Business	42100.00
0005435214309	7742	Business	42100.00
0005432531057	7742	Business	42100.00
0005432531108	7742	Business	42100.00
0005435214648	7742	Business	42100.00
0005435214344	7742	Business	42100.00
0005434069231	7742	Business	42100.00
0005434069268	7742	Business	42100.00
0005432531021	7742	Business	42100.00
0005432531050	7742	Business	42100.00
0005435214506	7742	Business	42100.00
0005434069230	7742	Business	42100.00
0005432531026	7742	Business	42100.00
0005434069254	7742	Business	42100.00
0005432150376	7742	Business	42100.00
0005434069267	7742	Business	42100.00
0005432531084	7742	Business	42100.00
0005432530998	7742	Business	42100.00
0005435214649	7742	Comfort	23900.00
0005434069208	7742	Comfort	23900.00
0005432531046	7742	Comfort	23900.00
0005434069250	7742	Comfort	23900.00
0005434069240	7742	Comfort	23900.00
0005432531070	7742	Comfort	23900.00
0005432150381	7742	Comfort	23900.00
0005434069205	7742	Comfort	23900.00
0005434069260	7742	Comfort	23900.00
0005434069201	7742	Comfort	23900.00
0005435214615	7742	Comfort	23900.00
0005434069206	7742	Comfort	23900.00
0005432070002	7742	Comfort	23900.00
0005432531112	7742	Comfort	23900.00
0005435214596	7742	Comfort	23900.00
0005432531107	7742	Comfort	23900.00
0005432531109	7742	Comfort	23900.00
0005435214425	7742	Comfort	23900.00
0005434069258	7742	Comfort	23900.00
0005435214650	7742	Comfort	23900.00
0005434069213	7742	Comfort	23900.00
0005432531032	7742	Comfort	23900.00
0005434069235	7742	Comfort	23900.00
0005432531081	7742	Comfort	23900.00
0005432531076	7742	Comfort	23900.00
0005432531096	7742	Comfort	23900.00
0005434069212	7742	Comfort	23900.00
0005432531115	7742	Comfort	23900.00
0005434069244	7742	Comfort	23900.00
0005433656713	7742	Comfort	23900.00
0005435214535	7742	Comfort	23900.00
0005434069229	7742	Comfort	23900.00
0005435214736	7742	Comfort	23900.00
0005432531042	7742	Comfort	23900.00
0005434069210	7742	Comfort	23900.00
0005432531058	7742	Comfort	23900.00
0005434069203	7742	Comfort	23900.00
0005432531074	7742	Economy	14000.00
0005432531006	7742	Economy	14000.00
0005435214479	7742	Economy	14000.00
0005432537108	7742	Economy	14000.00
0005432535950	7742	Economy	14000.00
0005434069222	7742	Economy	14000.00
0005435214236	7742	Economy	14000.00
0005435214804	7742	Economy	14000.00
0005434069246	7742	Economy	14000.00
0005435214778	7742	Economy	14000.00
0005432531111	7742	Economy	14000.00
0005435214424	7742	Economy	14000.00
0005432531002	7742	Economy	14000.00
0005435725667	7742	Economy	14000.00
0005432531123	7742	Economy	14000.00
0005434069272	7742	Economy	14000.00
0005432531009	7742	Economy	14000.00
0005432070003	7742	Economy	14000.00
0005434069269	7742	Economy	14000.00
0005432531013	7742	Economy	14000.00
0005432531073	7742	Economy	14000.00
0005432531114	7742	Economy	14000.00
0005434069266	7742	Economy	14000.00
0005432531027	7742	Economy	14000.00
0005432531116	7742	Economy	14000.00
0005432531080	7742	Economy	14000.00
0005432531037	7742	Economy	14000.00
0005434069214	7742	Economy	14000.00
0005434069217	7742	Economy	14000.00
0005432531110	7742	Economy	14000.00
0005435214616	7742	Economy	14000.00
0005434069263	7742	Economy	14000.00
0005432531094	7742	Economy	14000.00
0005435725671	7742	Economy	14000.00
0005432531028	7742	Economy	14000.00
0005432069998	7742	Economy	14000.00
0005432531092	7742	Economy	14000.00
0005434069236	7742	Economy	14000.00
0005435214507	7742	Economy	14000.00
0005432531007	7742	Economy	14000.00
0005432530999	7742	Economy	14000.00
0005435214499	7742	Economy	14000.00
0005432069997	7742	Economy	14000.00
0005435214710	7742	Economy	14000.00
0005432531004	7742	Economy	14000.00
0005432531029	7742	Economy	14000.00
0005432531106	7742	Economy	14000.00
0005432531036	7742	Economy	14000.00
0005432531072	7742	Economy	14000.00
0005432533360	7742	Economy	14000.00
0005432069996	7742	Economy	14000.00
0005432531034	7742	Economy	14000.00
0005432531063	7742	Economy	14000.00
0005432531113	7742	Economy	14000.00
0005434069252	7742	Economy	14000.00
0005435214478	7742	Economy	14000.00
0005435725666	7742	Economy	14000.00
0005432531099	7742	Economy	14000.00
0005432150379	7742	Economy	14000.00
0005432531054	7742	Economy	15400.00
0005434069207	7742	Economy	15400.00
0005432429010	7742	Economy	14000.00
0005435214396	7742	Economy	14000.00
0005434069225	7742	Economy	14000.00
0005432531075	7742	Economy	15400.00
0005432533358	7742	Economy	14000.00
0005432531014	7742	Economy	15400.00
0005432531088	7742	Economy	14000.00
0005432531066	7742	Economy	15400.00
0005432150382	7742	Economy	14000.00
0005432531041	7742	Economy	14000.00
0005435214753	7742	Economy	14000.00
0005434069262	7742	Economy	14000.00
0005432533359	7742	Economy	14000.00
0005432531065	7742	Economy	14000.00
0005434069228	7742	Economy	14000.00
0005432531022	7742	Economy	14000.00
0005435214503	7742	Economy	14000.00
0005435725670	7742	Economy	14000.00
0005434069209	7742	Economy	14000.00
0005434069242	7742	Economy	14000.00
0005432531122	7742	Economy	14000.00
0005432429011	7742	Economy	14000.00
0005432531119	7742	Economy	14000.00
0005435214565	7742	Economy	14000.00
0005432531010	7742	Economy	14000.00
0005432531097	7742	Economy	14000.00
0005432531124	7742	Economy	14000.00
0005432069994	7742	Economy	14000.00
0005434069216	7742	Economy	14000.00
0005435214306	7742	Economy	14000.00
0005435214517	7742	Economy	14000.00
0005435214669	7742	Economy	14000.00
0005434069255	7742	Economy	14000.00
0005435214387	7742	Economy	14000.00
0005432531040	7742	Economy	14000.00
0005432531033	7742	Economy	14000.00
0005432531015	7742	Economy	14000.00
0005432531060	7742	Economy	14000.00
0005432531043	7742	Economy	14000.00
0005435214518	7742	Economy	14000.00
0005434069271	7742	Economy	14000.00
0005434069237	7742	Economy	14000.00
0005435214716	7742	Economy	14000.00
0005432150383	7742	Economy	14000.00
0005435214504	7742	Economy	14000.00
0005432531001	7742	Economy	14000.00
0005435214686	7742	Economy	14000.00
0005435214731	7742	Economy	14000.00
0005432531024	7742	Economy	14000.00
0005434069259	7742	Economy	14000.00
0005432070001	7742	Economy	14000.00
0005432531131	7742	Economy	14000.00
0005432531102	7742	Economy	14000.00
0005434069265	7742	Economy	14000.00
0005435214725	7742	Economy	14000.00
0005432531069	7742	Economy	14000.00
0005435214338	7742	Economy	14000.00
0005435214401	7742	Economy	14000.00
0005435214584	7742	Economy	14000.00
0005432531017	7742	Economy	14000.00
0005432531103	7742	Economy	14000.00
0005432531130	7742	Economy	14000.00
0005434069253	7742	Economy	14000.00
0005435214260	7742	Economy	14000.00
0005432531077	7742	Economy	14000.00
0005435214597	7742	Economy	14000.00
0005432531128	7742	Economy	14000.00
0005432531035	7742	Economy	14000.00
0005432531056	7742	Economy	14000.00
0005435214567	7742	Economy	14000.00
0005434069243	7742	Economy	14000.00
0005434069227	7742	Economy	14000.00
0005434069249	7742	Economy	14000.00
0005435214524	7742	Economy	14000.00
0005435214398	7742	Economy	14000.00
0005432531071	7742	Economy	14000.00
0005432531020	7742	Economy	14000.00
0005432531126	7742	Economy	14000.00
0005435214711	7742	Economy	14000.00
0005432531048	7742	Economy	14000.00
0005435214397	7742	Economy	14000.00
0005432531082	7742	Economy	14000.00
0005432535948	7742	Economy	14000.00
0005434069245	7742	Economy	14000.00
0005432531095	7742	Economy	14000.00
0005434069239	7742	Economy	14000.00
0005433656712	7742	Economy	14000.00
0005435214491	7742	Economy	14000.00
0005432150378	7742	Economy	14000.00
0005432531044	7742	Economy	14000.00
0005435214270	7742	Economy	14000.00
0005432069992	7742	Economy	14000.00
0005434069226	7742	Economy	14000.00
0005432069995	7742	Economy	14000.00
0005432531011	7742	Economy	14000.00
0005432531059	7742	Economy	14000.00
0005432531086	7742	Economy	14000.00
0005432069991	7742	Economy	14000.00
0005434069248	7742	Economy	15400.00
0005435214553	7742	Economy	15400.00
0005432531078	7742	Economy	15400.00
0005432531003	7742	Economy	15400.00
0005432531121	7742	Economy	15400.00
0005434069270	7742	Economy	14000.00
0005434069241	7742	Economy	14000.00
0005432531008	7742	Economy	14000.00
0005435214343	7742	Economy	14000.00
0005435214566	7742	Economy	14000.00
0005432531018	7742	Economy	14000.00
0005434069204	7742	Economy	14000.00
0005432531045	7742	Economy	14000.00
0005434069211	7742	Economy	14000.00
0005434069256	7742	Economy	14000.00
0005432535949	7742	Economy	14000.00
0005434069247	7742	Economy	14000.00
0005435214337	7742	Economy	14000.00
0005435214750	7742	Economy	14000.00
0005432531038	7742	Economy	14000.00
0005435214322	7742	Economy	14000.00
0005432531104	7742	Economy	14000.00
0005432429009	7742	Economy	14000.00
0005432070004	7742	Economy	14000.00
0005434069221	7742	Economy	14000.00
0005432531090	7742	Economy	14000.00
0005432531016	7742	Economy	14000.00
0005432531005	7742	Economy	14000.00
0005432531129	7742	Economy	14000.00
0005434069233	7742	Economy	14000.00
0005432150380	7742	Economy	14000.00
0005435725668	7742	Economy	14000.00
0005432531105	7742	Economy	14000.00
0005434069223	7742	Economy	14000.00
0005435214420	7742	Economy	14000.00
0005435214310	7742	Economy	14000.00
0005435214259	7742	Economy	14000.00
0005432069990	7742	Economy	14000.00
0005432531049	7742	Economy	14000.00
0005432531125	7742	Economy	14000.00
0005432531039	7742	Economy	14000.00
0005435214423	7742	Economy	14000.00
0005432531127	7742	Economy	14000.00
0005432531025	7742	Economy	14000.00
0005435214339	7742	Economy	14000.00
0005432531093	7742	Economy	14000.00
0005432531030	7742	Economy	14000.00
0005432531068	7742	Economy	14000.00
0005434069224	7742	Economy	14000.00
0005435214508	7742	Economy	14000.00
0005434069251	7742	Economy	14000.00
0005432531061	7742	Economy	14000.00
0005434069234	7742	Economy	14000.00
0005432531064	7742	Economy	14000.00
0005435214578	7742	Economy	14000.00
0005432070000	7742	Economy	14000.00
0005432531047	7742	Economy	14000.00
0005432069999	7742	Economy	14000.00
0005434069220	7742	Economy	14000.00
0005435214610	7742	Economy	14000.00
0005432531089	7742	Economy	14000.00
0005432531062	7742	Economy	14000.00
0005434069232	7742	Economy	14000.00
0005434069261	7742	Economy	14000.00
0005434069257	7742	Economy	14000.00
0005435214658	7742	Economy	14000.00
0005435214659	7742	Economy	14000.00
0005432531087	7742	Economy	14000.00
0005432531083	7742	Economy	14000.00
0005432531098	7742	Economy	14000.00
0005432531117	7742	Economy	14000.00
0005432535951	7742	Economy	14000.00
0005432531118	7742	Economy	14000.00
0005435214552	7742	Economy	14000.00
0005432531100	7742	Economy	14000.00
0005432531052	7742	Economy	14000.00
0005435214604	7742	Economy	14000.00
0005434069219	7742	Economy	14000.00
0005434069215	7742	Economy	14000.00
0005432531012	7742	Economy	14000.00
0005432535947	7742	Economy	14000.00
0005432531023	7742	Economy	14000.00
0005432150377	7742	Economy	14000.00
0005435214586	7742	Economy	14000.00
0005432531085	7742	Economy	14000.00
0005434069218	7742	Economy	14000.00
0005432531101	7742	Economy	14000.00
0005435214800	7742	Economy	14000.00
0005434069202	7742	Economy	14000.00
0005432531053	7742	Economy	14000.00
0005432531091	7742	Economy	14000.00
0005432531120	7742	Economy	14000.00
0005432531079	7742	Economy	14000.00
0005432531000	7742	Economy	14000.00
0005434069264	7742	Economy	14000.00
0005435214345	7742	Economy	14000.00
0005435426193	5329	Business	43100.00
0005434573684	5329	Business	43100.00
0005435616348	5329	Business	43100.00
0005435616368	5329	Business	43100.00
0005432047638	5329	Business	43100.00
0005435490315	5329	Business	43100.00
0005435302255	5329	Business	43100.00
0005435426112	5329	Business	43100.00
0005434245506	5329	Business	43100.00
0005435616340	5329	Business	43100.00
0005432133574	5329	Business	43100.00
0005435616365	5329	Business	43100.00
0005435616381	5329	Business	43100.00
0005435097446	5329	Business	43100.00
0005432133561	5329	Business	43100.00
0005432841036	5329	Business	43100.00
0005435616329	5329	Business	43100.00
0005434245340	5329	Business	43100.00
0005435616317	5329	Business	43100.00
0005435616378	5329	Business	43100.00
0005434573679	5329	Business	43100.00
0005435425958	5329	Business	43100.00
0005435616276	5329	Business	43100.00
0005434573686	5329	Business	43100.00
0005433719191	5329	Business	43100.00
0005435616308	5329	Comfort	24400.00
0005434245395	5329	Business	43100.00
0005432133560	5329	Comfort	24400.00
0005434345063	5329	Comfort	24400.00
0005435319749	5329	Comfort	24400.00
0005435425770	5329	Comfort	24400.00
0005434245278	5329	Comfort	24400.00
0005435097444	5329	Comfort	24400.00
0005435616287	5329	Comfort	24400.00
0005434245359	5329	Comfort	24400.00
0005434345053	5329	Comfort	24400.00
0005434656577	5329	Comfort	24400.00
0005435425784	5329	Comfort	24400.00
0005435426187	5329	Comfort	24400.00
0005434245399	5329	Comfort	24400.00
0005435616298	5329	Comfort	24400.00
0005435425834	5329	Comfort	24400.00
0005435616282	5329	Comfort	24400.00
0005434345073	5329	Comfort	24400.00
0005435616379	5329	Comfort	24400.00
0005435425851	5329	Comfort	24400.00
0005435425553	5329	Comfort	24400.00
0005434345069	5329	Comfort	24400.00
0005435616328	5329	Comfort	24400.00
0005435490316	5329	Comfort	24400.00
0005435616386	5329	Comfort	24400.00
0005435425701	5329	Comfort	24400.00
0005432133568	5329	Comfort	24400.00
0005435425952	5329	Comfort	24400.00
0005435616362	5329	Comfort	24400.00
0005435425735	5329	Comfort	24400.00
0005435616295	5329	Comfort	24400.00
0005434345050	5329	Comfort	24400.00
0005434245528	5329	Comfort	24400.00
0005434345077	5329	Comfort	24400.00
0005434573681	5329	Comfort	24400.00
0005435425638	5329	Comfort	24400.00
0005435319675	5329	Comfort	24400.00
0005435616318	5329	Comfort	24400.00
0005434573683	5329	Comfort	24400.00
0005435616302	5329	Economy	14400.00
0005435319697	5329	Comfort	24400.00
0005434245492	5329	Economy	14400.00
0005435426077	5329	Economy	14400.00
0005435616286	5329	Economy	14400.00
0005434573680	5329	Economy	14400.00
0005435426188	5329	Economy	14400.00
0005434345049	5329	Economy	14400.00
0005435616339	5329	Economy	14400.00
0005434245440	5329	Economy	14400.00
0005433719189	5329	Economy	14400.00
0005435616323	5329	Economy	14400.00
0005435426178	5329	Economy	14400.00
0005434573691	5329	Economy	14400.00
0005435426078	5329	Economy	14400.00
0005435616366	5329	Economy	14400.00
0005435616304	5329	Economy	14400.00
0005434245380	5329	Economy	14400.00
0005435616289	5329	Economy	14400.00
0005434245494	5329	Economy	14400.00
0005432133564	5329	Economy	14400.00
0005435425688	5329	Economy	14400.00
0005435616284	5329	Economy	14400.00
0005435097445	5329	Economy	14400.00
0005435616355	5329	Economy	14400.00
0005435616361	5329	Economy	14400.00
0005434573689	5329	Economy	14400.00
0005435616345	5329	Economy	14400.00
0005435616288	5329	Economy	14400.00
0005435319716	5329	Economy	14400.00
0005435425676	5329	Economy	14400.00
0005435616344	5329	Economy	14400.00
0005435616301	5329	Economy	14400.00
0005434245400	5329	Economy	14400.00
0005435425967	5329	Economy	14400.00
0005435425769	5329	Economy	14400.00
0005434345043	5329	Economy	14400.00
0005435426068	5329	Economy	14400.00
0005435616367	5329	Economy	14400.00
0005434345046	5329	Economy	14400.00
0005435425959	5329	Economy	14400.00
0005435616327	5329	Economy	14400.00
0005435426194	5329	Economy	14400.00
0005435616320	5329	Economy	14400.00
0005434345047	5329	Economy	14400.00
0005434345044	5329	Economy	14400.00
0005435616291	5329	Economy	14400.00
0005432133562	5329	Economy	14400.00
0005435616279	5329	Economy	14400.00
0005435616342	5329	Economy	14400.00
0005435425835	5329	Economy	14400.00
0005435097441	5329	Economy	14400.00
0005434573685	5329	Economy	14400.00
0005435616306	5329	Economy	14400.00
0005435425943	5329	Economy	14400.00
0005435302283	5329	Economy	14400.00
0005435616296	5329	Economy	14400.00
0005435616376	5329	Economy	14400.00
0005435426059	5329	Economy	14400.00
0005432133566	5329	Economy	14400.00
0005435426111	5329	Economy	14400.00
0005434345062	5329	Economy	14400.00
0005435616338	5329	Economy	14400.00
0005435491492	5329	Economy	15800.00
0005435490314	5329	Economy	15800.00
0005435616326	5329	Economy	14400.00
0005435491491	5329	Economy	15800.00
0005435616384	5329	Economy	14400.00
0005432133572	5329	Economy	14400.00
0005434345061	5329	Economy	15800.00
0005435616303	5329	Economy	14400.00
0005434345042	5329	Economy	14400.00
0005434656576	5329	Economy	15800.00
0005434345067	5329	Economy	14400.00
0005434345071	5329	Economy	14400.00
0005435616273	5329	Economy	14400.00
0005435616374	5329	Economy	14400.00
0005435616390	5329	Economy	14400.00
0005434345052	5329	Economy	14400.00
0005435616357	5329	Economy	14400.00
0005435616377	5329	Economy	14400.00
0005435097443	5329	Economy	14400.00
0005432133571	5329	Economy	14400.00
0005435425888	5329	Economy	14400.00
0005435616315	5329	Economy	14400.00
0005434245401	5329	Economy	14400.00
0005435097437	5329	Economy	14400.00
0005435425960	5329	Economy	14400.00
0005435616399	5329	Economy	14400.00
0005435616330	5329	Economy	14400.00
0005434245341	5329	Economy	14400.00
0005434245469	5329	Economy	14400.00
0005434245381	5329	Economy	14400.00
0005435616334	5329	Economy	14400.00
0005435616337	5329	Economy	14400.00
0005435616274	5329	Economy	14400.00
0005435616305	5329	Economy	14400.00
0005433719188	5329	Economy	14400.00
0005435616389	5329	Economy	14400.00
0005435426026	5329	Economy	14400.00
0005435425768	5329	Economy	14400.00
0005435425699	5329	Economy	14400.00
0005434345068	5329	Economy	14400.00
0005434345066	5329	Economy	14400.00
0005435425789	5329	Economy	14400.00
0005435319717	5329	Economy	14400.00
0005435616371	5329	Economy	14400.00
0005435426123	5329	Economy	14400.00
0005435555416	5329	Economy	14400.00
0005435616293	5329	Economy	14400.00
0005434245458	5329	Economy	14400.00
0005435616356	5329	Economy	14400.00
0005435319730	5329	Economy	14400.00
0005434245272	5329	Economy	14400.00
0005434345076	5329	Economy	14400.00
0005435616360	5329	Economy	14400.00
0005435616393	5329	Economy	14400.00
0005435616277	5329	Economy	14400.00
0005434345064	5329	Economy	14400.00
0005434245432	5329	Economy	14400.00
0005435616373	5329	Economy	14400.00
0005434245342	5329	Economy	14400.00
0005435425637	5329	Economy	14400.00
0005435616385	5329	Economy	14400.00
0005434345075	5329	Economy	14400.00
0005435616313	5329	Economy	14400.00
0005432133565	5329	Economy	14400.00
0005435380388	5329	Economy	14400.00
0005435491490	5329	Economy	14400.00
0005435616335	5329	Economy	14400.00
0005435616395	5329	Economy	14400.00
0005435616300	5329	Economy	14400.00
0005435425889	5329	Economy	14400.00
0005435616398	5329	Economy	14400.00
0005435425490	5329	Economy	14400.00
0005433719179	5329	Economy	14400.00
0005435616314	5329	Economy	14400.00
0005434573688	5329	Economy	14400.00
0005435302284	5329	Economy	14400.00
0005435490313	5329	Economy	14400.00
0005435616391	5329	Economy	14400.00
0005435425892	5329	Economy	14400.00
0005435380363	5329	Economy	14400.00
0005435616353	5329	Economy	14400.00
0005435616292	5329	Economy	14400.00
0005435616394	5329	Economy	14400.00
0005435616370	5329	Economy	14400.00
0005434345070	5329	Economy	14400.00
0005435616372	5329	Economy	14400.00
0005435616343	5329	Economy	14400.00
0005434345057	5329	Economy	14400.00
0005435616322	5329	Economy	14400.00
0005435097438	5329	Economy	14400.00
0005435425654	5329	Economy	14400.00
0005435425856	5329	Economy	14400.00
0005435302254	5329	Economy	14400.00
0005434345045	5329	Economy	14400.00
0005435616325	5329	Economy	14400.00
0005434345056	5329	Economy	14400.00
0005435616283	5329	Economy	14400.00
0005435616309	5329	Economy	14400.00
0005435616349	5329	Economy	14400.00
0005435380367	5329	Economy	14400.00
0005435616382	5329	Economy	14400.00
0005435425422	5329	Economy	14400.00
0005435616332	5329	Economy	14400.00
0005435616307	5329	Economy	14400.00
0005435426124	5329	Economy	14400.00
0005432133563	5329	Economy	14400.00
0005435319678	5329	Economy	14400.00
0005434345074	5329	Economy	14400.00
0005435616358	5329	Economy	14400.00
0005434245457	5329	Economy	14400.00
0005435616354	5329	Economy	14400.00
0005432047637	5329	Economy	14400.00
0005435425993	5329	Economy	14400.00
0005434245507	5329	Economy	14400.00
0005434245496	5329	Economy	14400.00
0005435425661	5329	Economy	14400.00
0005434345078	5329	Economy	14400.00
0005434345054	5329	Economy	15800.00
0005434245439	5329	Economy	15800.00
0005435616359	5329	Economy	15800.00
0005435616324	5329	Economy	15800.00
0005435425785	5329	Economy	14400.00
0005435616285	5329	Economy	14400.00
0005435491493	5329	Economy	14400.00
0005435425824	5329	Economy	14400.00
0005435319699	5329	Economy	14400.00
0005434345065	5329	Economy	14400.00
0005435616333	5329	Economy	14400.00
0005435319714	5329	Economy	14400.00
0005434573690	5329	Economy	14400.00
0005435616350	5329	Economy	14400.00
0005434245459	5329	Economy	14400.00
0005435425660	5329	Economy	14400.00
0005434573692	5329	Economy	14400.00
0005435616316	5329	Economy	14400.00
0005434245385	5329	Economy	14400.00
0005435616297	5329	Economy	14400.00
0005435616347	5329	Economy	14400.00
0005432133570	5329	Economy	14400.00
0005435616397	5329	Economy	14400.00
0005434345051	5329	Economy	14400.00
0005434345060	5329	Economy	14400.00
0005435425421	5329	Economy	14400.00
0005435426016	5329	Economy	14400.00
0005435616271	5329	Economy	14400.00
0005434345048	5329	Economy	14400.00
0005435616388	5329	Economy	14400.00
0005435097440	5329	Economy	14400.00
0005435426045	5329	Economy	14400.00
0005435426097	5329	Economy	14400.00
0005435616363	5329	Economy	14400.00
0005435097439	5329	Economy	14400.00
0005435616396	5329	Economy	14400.00
0005435425823	5329	Economy	14400.00
0005435302273	5329	Economy	14400.00
0005435319729	5329	Economy	14400.00
0005434573682	5329	Economy	14400.00
0005435616278	5329	Economy	14400.00
0005435426179	5329	Economy	14400.00
0005435616352	5329	Economy	14400.00
0005435425942	5329	Economy	14400.00
0005433719184	5329	Economy	14400.00
0005432133569	5329	Economy	14400.00
0005433719185	5329	Economy	14400.00
0005435425863	5329	Economy	14400.00
0005434345072	5329	Economy	14400.00
0005435616387	5329	Economy	14400.00
0005434245288	5329	Economy	14400.00
0005435302285	5329	Economy	14400.00
0005434245404	5329	Economy	14400.00
0005435616331	5329	Economy	14400.00
0005435616281	5329	Economy	14400.00
0005435616294	5329	Economy	14400.00
0005435616364	5329	Economy	14400.00
0005435616346	5329	Economy	14400.00
0005434345079	5329	Economy	14400.00
0005434345058	5329	Economy	14400.00
0005432047639	5329	Economy	14400.00
0005432133567	5329	Economy	14400.00
0005435616299	5329	Economy	14400.00
0005435616310	5329	Economy	14400.00
0005435616275	5329	Economy	14400.00
0005435616311	5329	Economy	14400.00
0005434245271	5329	Economy	14400.00
0005435616369	5329	Economy	14400.00
0005435426125	5329	Economy	14400.00
0005434245393	5329	Economy	14400.00
0005432047640	5329	Economy	14400.00
0005435425946	5329	Economy	14400.00
0005435616290	5329	Economy	14400.00
0005435616312	5329	Economy	14400.00
0005434245493	5329	Economy	14400.00
0005432133573	5329	Economy	14400.00
0005435425633	5329	Economy	14400.00
0005435425859	5329	Economy	14400.00
0005434245433	5329	Economy	14400.00
0005435425554	5329	Economy	14400.00
0005435616351	5329	Economy	14400.00
0005435425790	5329	Economy	14400.00
0005435425639	5329	Economy	14400.00
0005435616392	5329	Economy	14400.00
0005435616319	5329	Economy	14400.00
0005435616375	5329	Economy	14400.00
0005434345055	5329	Economy	14400.00
0005435555417	5329	Economy	14400.00
0005434573687	5329	Economy	14400.00
0005435616336	5329	Economy	14400.00
0005435425552	5329	Economy	14400.00
0005435097442	5329	Economy	14400.00
0005435616280	5329	Economy	14400.00
0005435426121	5329	Economy	14400.00
0005434245384	5329	Economy	14400.00
0005435616272	5329	Economy	14400.00
0005434345059	5329	Economy	14400.00
0005432047641	5329	Economy	14400.00
0005435616341	5329	Economy	14400.00
0005435616380	5329	Economy	14400.00
0005435616383	5329	Economy	14400.00
0005435616321	5329	Economy	14400.00
0005435615114	10876	Business	43100.00
0005432165215	10876	Business	43100.00
0005432165220	10876	Business	43100.00
0005432363494	10876	Business	43100.00
0005434344701	10876	Business	43100.00
0005435426460	10876	Business	43100.00
0005434245663	10876	Business	43100.00
0005435615486	10876	Business	43100.00
0005435615333	10876	Business	43100.00
0005434573531	10876	Business	43100.00
0005434573482	10876	Business	43100.00
0005435426452	10876	Business	43100.00
0005432841063	10876	Business	43100.00
0005435615506	10876	Business	43100.00
0005435426448	10876	Business	43100.00
0005435615415	10876	Business	43100.00
0005435426456	10876	Business	43100.00
0005435042915	10876	Business	43100.00
0005435615110	10876	Business	43100.00
0005435615121	10876	Business	43100.00
0005435615143	10876	Business	43100.00
0005435490299	10876	Business	43100.00
0005434245660	10876	Business	43100.00
0005435319782	10876	Business	43100.00
0005435426442	10876	Business	43100.00
0005435426447	10876	Business	43100.00
0005435426394	10876	Comfort	24400.00
0005435426419	10876	Business	43100.00
0005435490285	10876	Comfort	24400.00
0005435426404	10876	Comfort	24400.00
0005434245665	10876	Comfort	24400.00
0005435615309	10876	Comfort	24400.00
0005435426414	10876	Comfort	24400.00
0005435615353	10876	Comfort	24400.00
0005434344720	10876	Comfort	24400.00
0005432363492	10876	Comfort	24400.00
0005435615454	10876	Comfort	24400.00
0005435426396	10876	Comfort	24400.00
0005435426423	10876	Comfort	24400.00
0005434245667	10876	Comfort	24400.00
0005435615197	10876	Comfort	24400.00
0005435615356	10876	Comfort	24400.00
0005434245679	10876	Comfort	24400.00
0005435426431	10876	Comfort	24400.00
0005432165214	10876	Comfort	24400.00
0005434573473	10876	Comfort	24400.00
0005435615355	10876	Comfort	24400.00
0005434344688	10876	Comfort	24400.00
0005434245687	10876	Comfort	24400.00
0005434245685	10876	Comfort	24400.00
0005435615023	10876	Comfort	24400.00
0005434245674	10876	Comfort	24400.00
0005434344757	10876	Comfort	24400.00
0005435615082	10876	Comfort	24400.00
0005435615135	10876	Comfort	24400.00
0005435426415	10876	Comfort	24400.00
0005435615062	10876	Comfort	24400.00
0005435615522	10876	Comfort	24400.00
0005434573546	10876	Comfort	24400.00
0005432841061	10876	Comfort	24400.00
0005435615517	10876	Comfort	24400.00
0005435426449	10876	Comfort	24400.00
0005435615264	10876	Comfort	24400.00
0005435614982	10876	Comfort	24400.00
0005434245690	10876	Economy	14400.00
0005435615413	10876	Economy	14400.00
0005432363495	10876	Economy	14400.00
0005434573475	10876	Economy	14400.00
0005434245677	10876	Economy	14400.00
0005435615303	10876	Economy	14400.00
0005434245673	10876	Economy	14400.00
0005435615452	10876	Economy	14400.00
0005433719222	10876	Economy	14400.00
0005435615008	10876	Economy	14400.00
0005434344726	10876	Economy	14400.00
0005434344817	10876	Economy	14400.00
0005435380411	10876	Economy	14400.00
0005434344774	10876	Economy	14400.00
0005435042912	10876	Economy	14400.00
0005435042916	10876	Economy	14400.00
0005434245688	10876	Economy	14400.00
0005434344797	10876	Economy	14400.00
0005434344706	10876	Economy	14400.00
0005435615024	10876	Economy	14400.00
0005435426441	10876	Economy	14400.00
0005435615375	10876	Economy	14400.00
0005432165218	10876	Economy	14400.00
0005435426420	10876	Economy	14400.00
0005435615352	10876	Economy	14400.00
0005435319784	10876	Economy	14400.00
0005435615450	10876	Economy	14400.00
0005434573562	10876	Economy	14400.00
0005434245676	10876	Economy	14400.00
0005435615039	10876	Economy	14400.00
0005434245682	10876	Economy	14400.00
0005435426462	10876	Economy	14400.00
0005434245668	10876	Economy	14400.00
0005435319778	10876	Economy	14400.00
0005434344709	10876	Economy	14400.00
0005435097363	10876	Economy	14400.00
0005435615154	10876	Economy	14400.00
0005434245681	10876	Economy	14400.00
0005432165217	10876	Economy	14400.00
0005435615505	10876	Economy	14400.00
0005434573574	10876	Economy	14400.00
0005435615165	10876	Economy	14400.00
0005435615461	10876	Economy	14400.00
0005434573563	10876	Economy	14400.00
0005435614771	10876	Economy	14400.00
0005435615175	10876	Economy	14400.00
0005435491466	10876	Economy	14400.00
0005435615526	10876	Economy	14400.00
0005435319785	10876	Economy	14400.00
0005434344725	10876	Economy	14400.00
0005435426416	10876	Economy	14400.00
0005435614894	10876	Economy	14400.00
0005435490298	10876	Economy	14400.00
0005434344559	10876	Economy	14400.00
0005435615340	10876	Economy	14400.00
0005435426413	10876	Economy	14400.00
0005434344703	10876	Economy	14400.00
0005435380413	10876	Economy	14400.00
0005435426436	10876	Economy	14400.00
0005435380414	10876	Economy	15800.00
0005435615212	10876	Economy	15800.00
0005435319786	10876	Economy	15800.00
0005435615132	10876	Economy	14400.00
0005435097319	10876	Economy	14400.00
0005434656604	10876	Economy	14400.00
0005435615440	10876	Economy	15800.00
0005435426454	10876	Economy	15800.00
0005435615210	10876	Economy	14400.00
0005434344719	10876	Economy	14400.00
0005434656603	10876	Economy	14400.00
0005435426418	10876	Economy	14400.00
0005433719223	10876	Economy	14400.00
0005435319780	10876	Economy	14400.00
0005435615215	10876	Economy	14400.00
0005435426403	10876	Economy	14400.00
0005435319777	10876	Economy	14400.00
0005435615533	10876	Economy	14400.00
0005435426458	10876	Economy	14400.00
0005434344610	10876	Economy	14400.00
0005435615252	10876	Economy	14400.00
0005435426395	10876	Economy	14400.00
0005434245683	10876	Economy	14400.00
0005435426400	10876	Economy	14400.00
0005435426430	10876	Economy	14400.00
0005435426405	10876	Economy	14400.00
0005435615458	10876	Economy	14400.00
0005435097309	10876	Economy	14400.00
0005435426451	10876	Economy	14400.00
0005435380410	10876	Economy	14400.00
0005434573474	10876	Economy	14400.00
0005435615334	10876	Economy	14400.00
0005435426426	10876	Economy	14400.00
0005432166978	10876	Economy	14400.00
0005435615305	10876	Economy	14400.00
0005435097345	10876	Economy	14400.00
0005435426443	10876	Economy	14400.00
0005435615520	10876	Economy	14400.00
0005435615341	10876	Economy	14400.00
0005434245661	10876	Economy	14400.00
0005434573544	10876	Economy	14400.00
0005435615494	10876	Economy	14400.00
0005435615166	10876	Economy	14400.00
0005435426440	10876	Economy	14400.00
0005435426428	10876	Economy	14400.00
0005434344746	10876	Economy	14400.00
0005435615290	10876	Economy	14400.00
0005435426438	10876	Economy	14400.00
0005435615298	10876	Economy	14400.00
0005434245664	10876	Economy	14400.00
0005434245671	10876	Economy	14400.00
0005435614507	10876	Economy	14400.00
0005434344710	10876	Economy	14400.00
0005435615153	10876	Economy	14400.00
0005435615183	10876	Economy	14400.00
0005435615025	10876	Economy	14400.00
0005435614983	10876	Economy	14400.00
0005434573547	10876	Economy	14400.00
0005435426434	10876	Economy	14400.00
0005434344569	10876	Economy	14400.00
0005434344745	10876	Economy	14400.00
0005434245675	10876	Economy	14400.00
0005435042914	10876	Economy	14400.00
0005434344816	10876	Economy	14400.00
0005435615530	10876	Economy	14400.00
0005434344658	10876	Economy	14400.00
0005435615206	10876	Economy	14400.00
0005435615211	10876	Economy	14400.00
0005435615339	10876	Economy	14400.00
0005434573480	10876	Economy	14400.00
0005435615144	10876	Economy	14400.00
0005433719221	10876	Economy	14400.00
0005435426455	10876	Economy	14400.00
0005435426397	10876	Economy	14400.00
0005434573476	10876	Economy	14400.00
0005435615236	10876	Economy	14400.00
0005434245662	10876	Economy	14400.00
0005435426457	10876	Economy	14400.00
0005435380409	10876	Economy	14400.00
0005435615376	10876	Economy	14400.00
0005435615228	10876	Economy	14400.00
0005435426461	10876	Economy	14400.00
0005435426421	10876	Economy	14400.00
0005434573530	10876	Economy	14400.00
0005435426435	10876	Economy	14400.00
0005435615207	10876	Economy	14400.00
0005432165216	10876	Economy	14400.00
0005434344568	10876	Economy	14400.00
0005435615251	10876	Economy	14400.00
0005434344622	10876	Economy	14400.00
0005435615266	10876	Economy	14400.00
0005434245669	10876	Economy	14400.00
0005434344623	10876	Economy	14400.00
0005434344738	10876	Economy	14400.00
0005435615484	10876	Economy	14400.00
0005435615182	10876	Economy	14400.00
0005435042913	10876	Economy	14400.00
0005435615382	10876	Economy	14400.00
0005435426432	10876	Economy	14400.00
0005434573529	10876	Economy	14400.00
0005435614851	10876	Economy	14400.00
0005435319781	10876	Economy	14400.00
0005434573600	10876	Economy	14400.00
0005435426425	10876	Economy	14400.00
0005435426417	10876	Economy	15800.00
0005434245680	10876	Economy	14400.00
0005435319783	10876	Economy	15800.00
0005435426465	10876	Economy	15800.00
0005435426398	10876	Economy	15800.00
0005435614859	10876	Economy	15800.00
0005435615371	10876	Economy	15800.00
0005434344652	10876	Economy	14400.00
0005432841062	10876	Economy	14400.00
0005434245689	10876	Economy	14400.00
0005435426464	10876	Economy	14400.00
0005434344736	10876	Economy	14400.00
0005432363493	10876	Economy	14400.00
0005435615457	10876	Economy	14400.00
0005435615485	10876	Economy	14400.00
0005434344704	10876	Economy	14400.00
0005435614752	10876	Economy	14400.00
0005435615531	10876	Economy	14400.00
0005435615299	10876	Economy	14400.00
0005435615137	10876	Economy	14400.00
0005435426402	10876	Economy	14400.00
0005435426427	10876	Economy	14400.00
0005435615400	10876	Economy	14400.00
0005435426445	10876	Economy	14400.00
0005435426463	10876	Economy	14400.00
0005435614852	10876	Economy	14400.00
0005434245678	10876	Economy	14400.00
0005435615446	10876	Economy	14400.00
0005434344643	10876	Economy	14400.00
0005435615403	10876	Economy	14400.00
0005435426466	10876	Economy	14400.00
0005434344644	10876	Economy	14400.00
0005435426446	10876	Economy	14400.00
0005435615136	10876	Economy	14400.00
0005435615235	10876	Economy	14400.00
0005434245666	10876	Economy	14400.00
0005435615552	10876	Economy	14400.00
0005435615250	10876	Economy	14400.00
0005435319779	10876	Economy	14400.00
0005432165221	10876	Economy	14400.00
0005435615396	10876	Economy	14400.00
0005434344705	10876	Economy	14400.00
0005434344737	10876	Economy	14400.00
0005434344602	10876	Economy	14400.00
0005435615038	10876	Economy	14400.00
0005435615304	10876	Economy	14400.00
0005435614648	10876	Economy	14400.00
0005435426439	10876	Economy	14400.00
0005434245686	10876	Economy	14400.00
0005435615404	10876	Economy	14400.00
0005435615532	10876	Economy	14400.00
0005435426399	10876	Economy	14400.00
0005435615414	10876	Economy	14400.00
0005435615219	10876	Economy	14400.00
0005434573584	10876	Economy	14400.00
0005435615229	10876	Economy	14400.00
0005434344766	10876	Economy	14400.00
0005435615147	10876	Economy	14400.00
0005433719220	10876	Economy	14400.00
0005435426459	10876	Economy	14400.00
0005435426444	10876	Economy	14400.00
0005435426409	10876	Economy	14400.00
0005434344672	10876	Economy	14400.00
0005434344758	10876	Economy	14400.00
0005435426424	10876	Economy	14400.00
0005435615310	10876	Economy	14400.00
0005435426433	10876	Economy	14400.00
0005435615265	10876	Economy	14400.00
0005434344751	10876	Economy	14400.00
0005435615257	10876	Economy	14400.00
0005434344621	10876	Economy	14400.00
0005434573450	10876	Economy	14400.00
0005435615009	10876	Economy	14400.00
0005435426407	10876	Economy	14400.00
0005434344702	10876	Economy	14400.00
0005435426450	10876	Economy	14400.00
0005435615538	10876	Economy	14400.00
0005435426408	10876	Economy	14400.00
0005435426406	10876	Economy	14400.00
0005434573481	10876	Economy	14400.00
0005435426437	10876	Economy	14400.00
0005435615209	10876	Economy	14400.00
0005435615495	10876	Economy	14400.00
0005435615291	10876	Economy	14400.00
0005432166979	10876	Economy	14400.00
0005434245684	10876	Economy	14400.00
0005435380412	10876	Economy	14400.00
0005435426411	10876	Economy	14400.00
0005435426401	10876	Economy	14400.00
0005434245670	10876	Economy	14400.00
0005435426410	10876	Economy	14400.00
0005435615521	10876	Economy	14400.00
0005435426453	10876	Economy	14400.00
0005435097290	10876	Economy	14400.00
0005435426429	10876	Economy	14400.00
0005435490300	10876	Economy	14400.00
0005432165219	10876	Economy	14400.00
0005435615344	10876	Economy	14400.00
0005434344765	10876	Economy	14400.00
0005434344782	10876	Economy	14400.00
0005434344592	10876	Economy	14400.00
0005434344839	10876	Economy	14400.00
0005434573561	10876	Economy	14400.00
0005434245672	10876	Economy	14400.00
0005434344558	10876	Economy	14400.00
0005435615442	10876	Economy	14400.00
0005435426422	10876	Economy	14400.00
0005435426412	10876	Economy	14400.00
0005435615449	10876	Economy	14400.00
0005432460650	3298	Business	18800.00
0005433634631	3298	Business	18800.00
0005433806191	3298	Business	18800.00
0005432460479	3298	Business	18800.00
0005432460471	3298	Business	18800.00
0005432460669	3298	Business	18800.00
0005433634624	3298	Business	18800.00
0005433634617	3298	Business	18800.00
0005433507621	3298	Business	18800.00
0005432460595	3298	Business	18800.00
0005433634635	3298	Business	18800.00
0005432460594	3298	Business	18800.00
0005432182235	3298	Business	18800.00
0005433634622	3298	Business	18800.00
0005432460742	3298	Business	18800.00
0005433806185	3298	Business	18800.00
0005433806201	3298	Business	18800.00
0005433634613	3298	Business	18800.00
0005432460394	3298	Business	18800.00
0005432460746	3298	Business	18800.00
0005433634634	3298	Business	18800.00
0005432182240	3298	Business	18800.00
0005432460395	3298	Business	18800.00
0005432182237	3298	Business	18800.00
0005432460825	3298	Business	18800.00
0005432460663	3298	Business	18800.00
0005433507620	3298	Business	18800.00
0005432182250	3298	Business	18800.00
0005433806173	3298	Economy	6900.00
0005433634633	3298	Economy	6900.00
0005433806196	3298	Economy	6900.00
0005433806188	3298	Economy	6900.00
0005433806203	3298	Economy	6900.00
0005433806205	3298	Economy	6900.00
0005433806175	3298	Economy	6300.00
0005432460653	3298	Economy	6300.00
0005433634629	3298	Economy	6300.00
0005432460735	3298	Economy	6300.00
0005433806189	3298	Economy	6300.00
0005433634610	3298	Economy	6300.00
0005432460787	3298	Economy	6300.00
0005433507619	3298	Economy	6300.00
0005432460617	3298	Economy	6300.00
0005433806197	3298	Economy	6300.00
0005433634637	3298	Economy	6300.00
0005432460667	3298	Economy	6300.00
0005433806176	3298	Economy	6300.00
0005432460852	3298	Economy	6300.00
0005433806186	3298	Economy	6300.00
0005433634626	3298	Economy	6300.00
0005433507609	3298	Economy	6300.00
0005433634628	3298	Economy	6300.00
0005433507608	3298	Economy	6300.00
0005432460833	3298	Economy	6300.00
0005433634615	3298	Economy	6300.00
0005432460719	3298	Economy	6300.00
0005433806192	3298	Economy	6300.00
0005432460641	3298	Economy	6300.00
0005432460628	3298	Economy	6300.00
0005432182245	3298	Economy	6300.00
0005432182251	3298	Economy	6300.00
0005432460487	3298	Economy	6300.00
0005433507614	3298	Economy	6300.00
0005432460675	3298	Economy	6300.00
0005432460749	3298	Economy	6300.00
0005433806202	3298	Economy	6300.00
0005433806172	3298	Economy	6300.00
0005432460610	3298	Economy	6300.00
0005433507617	3298	Economy	6300.00
0005433634627	3298	Economy	6300.00
0005433507604	3298	Economy	6300.00
0005433806177	3298	Economy	6300.00
0005432182243	3298	Economy	6300.00
0005433634640	3298	Economy	6300.00
0005432460608	3298	Economy	6300.00
0005433507616	3298	Economy	6300.00
0005433507611	3298	Economy	6300.00
0005432182246	3298	Economy	6300.00
0005432460701	3298	Economy	6300.00
0005433634638	3298	Economy	6300.00
0005432460832	3298	Economy	6300.00
0005432460609	3298	Economy	6300.00
0005432182252	3298	Economy	6300.00
0005432460627	3298	Economy	6300.00
0005432460745	3298	Economy	6300.00
0005432460720	3298	Economy	6300.00
0005432460826	3298	Economy	6300.00
0005432182242	3298	Economy	6300.00
0005433806184	3298	Economy	6300.00
0005433634639	3298	Economy	6300.00
0005433507605	3298	Economy	6300.00
0005432182249	3298	Economy	6300.00
0005433634614	3298	Economy	6300.00
0005433806182	3298	Economy	6900.00
0005432460670	3298	Economy	6900.00
0005432182233	3298	Economy	6900.00
0005432460514	3298	Economy	6900.00
0005433806194	3298	Economy	6900.00
0005432460387	3298	Economy	6300.00
0005433806200	3298	Economy	6300.00
0005432460480	3298	Economy	6300.00
0005433507612	3298	Economy	6300.00
0005432460625	3298	Economy	6900.00
0005433806198	3298	Economy	6300.00
0005432182248	3298	Economy	6300.00
0005432182231	3298	Economy	6300.00
0005432460352	3298	Economy	6300.00
0005433634618	3298	Economy	6300.00
0005433806199	3298	Economy	6300.00
0005432460435	3298	Economy	6300.00
0005433634621	3298	Economy	6300.00
0005432460511	3298	Economy	6300.00
0005432460683	3298	Economy	6300.00
0005433634632	3298	Economy	6300.00
0005433806174	3298	Economy	6300.00
0005433806180	3298	Economy	6300.00
0005432460583	3298	Economy	6300.00
0005433507615	3298	Economy	6300.00
0005432460584	3298	Economy	6300.00
0005432460640	3298	Economy	6300.00
0005433507602	3298	Economy	6300.00
0005433634611	3298	Economy	6300.00
0005433634619	3298	Economy	6300.00
0005433634630	3298	Economy	6300.00
0005432460629	3298	Economy	6300.00
0005432182234	3298	Economy	6300.00
0005432182236	3298	Economy	6300.00
0005432182247	3298	Economy	6300.00
0005432182241	3298	Economy	6300.00
0005432460566	3298	Economy	6300.00
0005432460537	3298	Economy	6300.00
0005433507606	3298	Economy	6300.00
0005432182232	3298	Economy	6300.00
0005433806206	3298	Economy	6300.00
0005432182253	3298	Economy	6300.00
0005433806181	3298	Economy	6300.00
0005432460436	3298	Economy	6300.00
0005433507622	3298	Economy	6300.00
0005433634616	3298	Economy	6300.00
0005433634620	3298	Economy	6300.00
0005433507603	3298	Economy	6300.00
0005432460510	3298	Economy	6300.00
0005433806178	3298	Economy	6300.00
0005433634641	3298	Economy	6300.00
0005433634612	3298	Economy	6300.00
0005433634636	3298	Economy	6300.00
0005433806179	3298	Economy	6300.00
0005432460659	3298	Economy	6300.00
0005433507607	3298	Economy	6300.00
0005433507613	3298	Economy	6300.00
0005433806183	3298	Economy	6300.00
0005432460649	3298	Economy	6300.00
0005433806190	3298	Economy	6300.00
0005432182244	3298	Economy	6300.00
0005432460441	3298	Economy	6300.00
0005433634623	3298	Economy	6300.00
0005432182239	3298	Economy	6300.00
0005433806193	3298	Economy	6300.00
0005433507618	3298	Economy	6300.00
0005433806187	3298	Economy	6300.00
0005432460598	3298	Economy	6300.00
0005433507610	3298	Economy	6300.00
0005432460654	3298	Economy	6300.00
0005432182238	3298	Economy	6300.00
0005433634625	3298	Economy	6300.00
0005432460607	3298	Economy	6300.00
0005433806204	3298	Economy	6300.00
0005432460482	3298	Economy	6300.00
0005433806195	3298	Economy	6300.00
0005435885933	3294	Business	18800.00
0005435885852	3294	Business	18800.00
0005435886232	3294	Business	18800.00
0005435886035	3294	Business	18800.00
0005435886092	3294	Business	18800.00
0005435885982	3294	Business	18800.00
0005435886006	3294	Business	18800.00
0005435885970	3294	Business	18800.00
0005435886202	3294	Business	18800.00
0005435886069	3294	Business	18800.00
0005435885989	3294	Business	18800.00
0005435886005	3294	Business	18800.00
0005435886017	3294	Business	18800.00
0005435886021	3294	Business	18800.00
0005435886043	3294	Economy	6900.00
0005435885927	3294	Economy	6900.00
0005435885909	3294	Economy	6900.00
0005435885990	3294	Economy	6900.00
0005435886134	3294	Economy	6300.00
0005435886117	3294	Economy	6300.00
0005435885623	3294	Economy	6300.00
0005435886034	3294	Economy	6300.00
0005435886157	3294	Economy	6300.00
0005435885944	3294	Economy	6300.00
0005435885988	3294	Economy	6300.00
0005435886048	3294	Economy	6300.00
0005435886302	3294	Economy	6300.00
0005435885981	3294	Economy	6300.00
0005435885991	3294	Economy	6300.00
0005435886187	3294	Economy	6300.00
0005435885911	3294	Economy	6300.00
0005435885994	3294	Economy	6300.00
0005435885811	3294	Economy	6300.00
0005435885921	3294	Economy	6300.00
0005435885995	3294	Economy	6300.00
0005435885979	3294	Economy	6300.00
0005435886067	3294	Economy	6900.00
0005435886101	3294	Economy	6900.00
0005435886037	3294	Economy	6300.00
0005435886047	3294	Economy	6300.00
0005435885943	3294	Economy	6300.00
0005435885980	3294	Economy	6300.00
0005435886093	3294	Economy	6300.00
0005435886016	3294	Economy	6300.00
0005435886044	3294	Economy	6300.00
0005435885853	3294	Economy	6300.00
0005435886203	3294	Economy	6300.00
0005435886231	3294	Economy	6300.00
0005435886137	3294	Economy	6300.00
0005435886158	3294	Economy	6300.00
0005435886216	3294	Economy	6300.00
0005435886036	3294	Economy	6300.00
0005435886085	3294	Economy	6300.00
0005435886053	3294	Economy	6300.00
0005435886018	3294	Economy	6300.00
0005435886003	3294	Economy	6300.00
0005435885964	3294	Economy	6300.00
0005432461107	8215	Business	18800.00
0005433507446	8215	Business	18800.00
0005432461131	8215	Business	18800.00
0005432461138	8215	Business	18800.00
0005435886408	8215	Business	18800.00
0005432461112	8215	Business	18800.00
0005432461129	8215	Business	18800.00
0005432461105	8215	Business	18800.00
0005435886410	8215	Business	18800.00
0005432461095	8215	Business	18800.00
0005432461140	8215	Business	18800.00
0005432461143	8215	Business	18800.00
0005433507379	8215	Business	18800.00
0005433507479	8215	Business	18800.00
0005432461121	8215	Business	18800.00
0005435886372	8215	Business	18800.00
0005435886381	8215	Business	18800.00
0005432461100	8215	Business	18800.00
0005432461110	8215	Business	18800.00
0005434312388	8215	Business	18800.00
0005432461097	8215	Business	18800.00
0005432461133	8215	Business	18800.00
0005435886379	8215	Business	18800.00
0005435886411	8215	Business	18800.00
0005432043042	8215	Business	18800.00
0005435886396	8215	Economy	6900.00
0005435886413	8215	Economy	6900.00
0005435142985	8215	Economy	6900.00
0005432461108	8215	Economy	6900.00
0005435886412	8215	Economy	6900.00
0005435142984	8215	Economy	6300.00
0005435886397	8215	Economy	6300.00
0005432461116	8215	Economy	6300.00
0005432461117	8215	Economy	6300.00
0005433507461	8215	Economy	6300.00
0005432043046	8215	Economy	6300.00
0005432043043	8215	Economy	6300.00
0005435886394	8215	Economy	6300.00
0005434326094	8215	Economy	6300.00
0005435886406	8215	Economy	6300.00
0005432461142	8215	Economy	6300.00
0005434312370	8215	Economy	6300.00
0005432461096	8215	Economy	6300.00
0005432461124	8215	Economy	6300.00
0005435886393	8215	Economy	6300.00
0005435142987	8215	Economy	6300.00
0005433507396	8215	Economy	6300.00
0005435886377	8215	Economy	6300.00
0005432461139	8215	Economy	6300.00
0005432461130	8215	Economy	6300.00
0005435886380	8215	Economy	6300.00
0005432043045	8215	Economy	6300.00
0005434326287	8215	Economy	6300.00
0005432461137	8215	Economy	6300.00
0005435886384	8215	Economy	6300.00
0005433507434	8215	Economy	6300.00
0005432461125	8215	Economy	6300.00
0005433507490	8215	Economy	6300.00
0005435886395	8215	Economy	6300.00
0005432461127	8215	Economy	6300.00
0005432043050	8215	Economy	6300.00
0005432043039	8215	Economy	6300.00
0005432461103	8215	Economy	6300.00
0005432461109	8215	Economy	6300.00
0005435886370	8215	Economy	6300.00
0005435886409	8215	Economy	6300.00
0005435886398	8215	Economy	6300.00
0005435886382	8215	Economy	6300.00
0005433507451	8215	Economy	6300.00
0005432461119	8215	Economy	6300.00
0005432043047	8215	Economy	6300.00
0005432461118	8215	Economy	6300.00
0005433507471	8215	Economy	6300.00
0005435886392	8215	Economy	6300.00
0005435886375	8215	Economy	6300.00
0005432461120	8215	Economy	6300.00
0005432043041	8215	Economy	6300.00
0005432461093	8215	Economy	6300.00
0005435886390	8215	Economy	6300.00
0005435886374	8215	Economy	6300.00
0005435886401	8215	Economy	6300.00
0005435886376	8215	Economy	6900.00
0005435886371	8215	Economy	6900.00
0005435886373	8215	Economy	6900.00
0005432461104	8215	Economy	6900.00
0005432461111	8215	Economy	6300.00
0005433507453	8215	Economy	6300.00
0005435886387	8215	Economy	6300.00
0005432461136	8215	Economy	6300.00
0005432461094	8215	Economy	6300.00
0005434312371	8215	Economy	6900.00
0005432043044	8215	Economy	6300.00
0005435142986	8215	Economy	6300.00
0005434312369	8215	Economy	6300.00
0005433507473	8215	Economy	6300.00
0005435886399	8215	Economy	6300.00
0005432461113	8215	Economy	6300.00
0005432461141	8215	Economy	6300.00
0005432461101	8215	Economy	6300.00
0005433507474	8215	Economy	6300.00
0005435886400	8215	Economy	6300.00
0005432043048	8215	Economy	6300.00
0005432461106	8215	Economy	6300.00
0005434326093	8215	Economy	6300.00
0005435886407	8215	Economy	6300.00
0005432043038	8215	Economy	6300.00
0005433507491	8215	Economy	6300.00
0005435886369	8215	Economy	6300.00
0005433507454	8215	Economy	6300.00
0005435886383	8215	Economy	6300.00
0005435886402	8215	Economy	6300.00
0005432461146	8215	Economy	6300.00
0005435886388	8215	Economy	6300.00
0005432461134	8215	Economy	6300.00
0005432461128	8215	Economy	6300.00
0005435886404	8215	Economy	6300.00
0005432461123	8215	Economy	6300.00
0005432461135	8215	Economy	6300.00
0005432043051	8215	Economy	6300.00
0005432461126	8215	Economy	6300.00
0005432043040	8215	Economy	6300.00
0005433507452	8215	Economy	6300.00
0005432461147	8215	Economy	6300.00
0005432461145	8215	Economy	6300.00
0005435886389	8215	Economy	6300.00
0005435886403	8215	Economy	6300.00
0005432461114	8215	Economy	6300.00
0005432461115	8215	Economy	6300.00
0005432461144	8215	Economy	6300.00
0005435886386	8215	Economy	6300.00
0005432043049	8215	Economy	6300.00
0005433507464	8215	Economy	6300.00
0005435886391	8215	Economy	6300.00
0005432461122	8215	Economy	6300.00
0005434326286	8215	Economy	6300.00
0005432461099	8215	Economy	6300.00
0005435886405	8215	Economy	6300.00
0005435886378	8215	Economy	6300.00
0005432461098	8215	Economy	6300.00
0005435886385	8215	Economy	6300.00
0005432461102	8215	Economy	6300.00
0005433507463	8215	Economy	6300.00
0005432461132	8215	Economy	6300.00
0005433634294	8190	Business	18800.00
0005433805996	8190	Business	18800.00
0005433805733	8190	Business	18800.00
0005433634390	8190	Business	18800.00
0005433634363	8190	Business	18800.00
0005433805904	8190	Business	18800.00
0005433634212	8190	Business	18800.00
0005433805947	8190	Business	18800.00
0005433634178	8190	Business	18800.00
0005434271344	8190	Business	18800.00
0005433634316	8190	Business	18800.00
0005435860651	8190	Business	18800.00
0005433634069	8190	Business	18800.00
0005433805913	8190	Business	18800.00
0005433634264	8190	Economy	6300.00
0005433805869	8190	Economy	6300.00
0005433805810	8190	Economy	6300.00
0005433806030	8190	Economy	6300.00
0005433634221	8190	Economy	6300.00
0005433634068	8190	Economy	6300.00
0005435858700	8190	Economy	6300.00
0005433805792	8190	Economy	6300.00
0005433634411	8190	Economy	6300.00
0005433805764	8190	Economy	6300.00
0005433805903	8190	Economy	6300.00
0005433805825	8190	Economy	6300.00
0005434271333	8190	Economy	6300.00
0005434271354	8190	Economy	6300.00
0005433805907	8190	Economy	6300.00
0005433634382	8190	Economy	6300.00
0005433805955	8190	Economy	6300.00
0005433634197	8190	Economy	6300.00
0005433634285	8190	Economy	6300.00
0005435854077	8190	Economy	6300.00
0005433634366	8190	Economy	6300.00
0005435860656	8190	Economy	6300.00
0005433634315	8190	Economy	6300.00
0005433806056	8190	Economy	6300.00
0005433805868	8190	Economy	6300.00
0005433805997	8190	Economy	6900.00
0005435854076	8190	Economy	6900.00
0005433634251	8190	Economy	6900.00
0005433634387	8190	Economy	6900.00
0005435860657	8190	Economy	6300.00
0005433805930	8190	Economy	6900.00
0005433634367	8190	Economy	6300.00
0005434271345	8190	Economy	6300.00
0005433634340	8190	Economy	6300.00
0005434271353	8190	Economy	6300.00
0005433805778	8190	Economy	6300.00
0005433634383	8190	Economy	6300.00
0005433805811	8190	Economy	6300.00
0005433806062	8190	Economy	6300.00
0005433805870	8190	Economy	6300.00
0005433634177	8190	Economy	6300.00
0005433805932	8190	Economy	6300.00
0005435860653	8190	Economy	6300.00
0005435860652	8190	Economy	6300.00
0005433634296	8190	Economy	6300.00
0005433805859	8190	Economy	6300.00
0005435860650	8190	Economy	6300.00
0005434271348	8190	Economy	6300.00
0005433805902	8190	Economy	6300.00
0005433634295	8190	Economy	6300.00
0005433806011	8190	Economy	6300.00
0005433805931	8190	Economy	6300.00
0005433805847	8190	Economy	6300.00
0005433805634	8190	Economy	6300.00
0005435860654	8190	Economy	6300.00
0005435860655	8190	Economy	6300.00
0005435858699	8190	Economy	6300.00
0005433805933	8190	Economy	6300.00
0005433634173	8190	Economy	6300.00
0005433634310	8190	Economy	6300.00
0005433634389	8190	Economy	6300.00
0005435854075	8190	Economy	6300.00
0005433634356	8190	Economy	6300.00
0005433806001	8190	Economy	6300.00
0005435860658	8190	Economy	6300.00
0005434183606	8316	Business	18800.00
0005434183607	8316	Economy	6300.00
0005432384111	4550	Business	9900.00
0005433194926	4550	Business	9900.00
0005432384075	4550	Business	9900.00
0005433194925	4550	Business	9900.00
0005432384114	4550	Business	9900.00
0005432384112	4550	Business	9900.00
0005432384094	4550	Business	9900.00
0005432384110	4550	Business	9900.00
0005432728238	4550	Business	9900.00
0005432384081	4550	Economy	3300.00
0005432728229	4550	Economy	3300.00
0005432384086	4550	Economy	3300.00
0005433722372	4550	Economy	3300.00
0005432384096	4550	Economy	3300.00
0005433722373	4550	Economy	3300.00
0005432384105	4550	Economy	3300.00
0005432384091	4550	Economy	3300.00
0005432384089	4550	Economy	3600.00
0005432384093	4550	Economy	3600.00
0005432384102	4550	Economy	3600.00
0005432728237	4550	Economy	3600.00
0005432728233	4550	Economy	3300.00
0005432384077	4550	Economy	3300.00
0005432384098	4550	Economy	3300.00
0005432384084	4550	Economy	3300.00
0005432384109	4550	Economy	3300.00
0005432384074	4550	Economy	3300.00
0005433194927	4550	Economy	3300.00
0005432384076	4550	Economy	3300.00
0005432384097	4550	Economy	3300.00
0005433722374	4550	Economy	3300.00
0005433722377	4550	Economy	3300.00
0005433454926	4550	Economy	3300.00
0005432384087	4550	Economy	3300.00
0005432384082	4550	Economy	3300.00
0005432384104	4550	Economy	3300.00
0005433194928	4550	Economy	3300.00
0005433453809	4550	Economy	3300.00
0005432384080	4550	Economy	3300.00
0005432384092	4550	Economy	3300.00
0005432728230	4550	Economy	3300.00
0005433722376	4550	Economy	3300.00
0005432384079	4550	Economy	3300.00
0005433722375	4550	Economy	3300.00
0005432384095	4550	Economy	3300.00
0005432728228	4550	Economy	3300.00
0005432728231	4550	Economy	3300.00
0005432384090	4550	Economy	3300.00
0005433194924	4550	Economy	3300.00
0005432384113	4550	Economy	3300.00
0005432728234	4550	Economy	3300.00
0005432384088	4550	Economy	3300.00
0005432384106	4550	Economy	3300.00
0005433722371	4550	Economy	3300.00
0005433722379	4550	Economy	3300.00
0005432384115	4550	Economy	3300.00
0005432384100	4550	Economy	3300.00
0005432384078	4550	Economy	3300.00
0005433722378	4550	Economy	3300.00
0005432384116	4550	Economy	3300.00
0005432384101	4550	Economy	3300.00
0005433194923	4550	Economy	3300.00
0005432384083	4550	Economy	3300.00
0005432384107	4550	Economy	3300.00
0005433454925	4550	Economy	3300.00
0005432728239	4550	Economy	3300.00
0005432728236	4550	Economy	3300.00
0005432384108	4550	Economy	3300.00
0005432728232	4550	Economy	3300.00
0005432384103	4550	Economy	3300.00
0005433194922	4550	Economy	3300.00
0005432384099	4550	Economy	3300.00
0005432384085	4550	Economy	3300.00
0005432728235	4550	Economy	3300.00
0005432383631	30165	Business	9900.00
0005432383733	30165	Business	9900.00
0005432728141	30165	Business	9900.00
0005432383598	30165	Business	9900.00
0005432383735	30165	Business	9900.00
0005432383630	30165	Business	9900.00
0005432728133	30165	Business	9900.00
0005432383556	30165	Business	9900.00
0005432383566	30165	Economy	3300.00
0005432383825	30165	Economy	3300.00
0005433453788	30165	Economy	3300.00
0005432383584	30165	Economy	3300.00
0005432383622	30165	Economy	3300.00
0005432728142	30165	Economy	3300.00
0005432383770	30165	Economy	3300.00
0005433722278	30165	Economy	3300.00
0005432728143	30165	Economy	3300.00
0005432383769	30165	Economy	3600.00
0005432383719	30165	Economy	3600.00
0005432728096	30165	Economy	3600.00
0005433722305	30165	Economy	3300.00
0005432383680	30165	Economy	3300.00
0005433194894	30165	Economy	3300.00
0005432383594	30165	Economy	3300.00
0005432383707	30165	Economy	3300.00
0005432383643	30165	Economy	3300.00
0005433722291	30165	Economy	3300.00
0005432383555	30165	Economy	3300.00
0005433453791	30165	Economy	3300.00
0005432383585	30165	Economy	3300.00
0005433453783	30165	Economy	3300.00
0005433722293	30165	Economy	3300.00
0005432728132	30165	Economy	3300.00
0005432383847	30165	Economy	3300.00
0005433451642	30165	Economy	3300.00
0005432383692	30165	Economy	3300.00
0005433722277	30165	Economy	3300.00
0005433722290	30165	Economy	3300.00
0005432383632	30165	Economy	3300.00
0005432728097	30165	Economy	3300.00
0005432383700	30165	Economy	3300.00
0005432383447	30165	Economy	3300.00
0005432383655	30165	Economy	3300.00
0005432383629	30165	Economy	3300.00
0005432383747	30165	Economy	3300.00
0005432383583	30165	Economy	3300.00
0005432383642	30165	Economy	3300.00
0005432728114	30165	Economy	3300.00
0005432383567	30165	Economy	3300.00
0005432728120	30165	Economy	3300.00
0005433722289	30165	Economy	3300.00
0005433194879	30165	Economy	3300.00
0005432383674	30165	Economy	3300.00
0005432728086	30165	Economy	3300.00
0005432383597	30165	Economy	3300.00
0005433453785	30165	Economy	3300.00
0005432383569	30165	Economy	3300.00
0005432383568	30165	Economy	3300.00
0005432728113	30165	Economy	3300.00
0005433722304	30165	Economy	3300.00
0005433453782	30165	Economy	3300.00
0005432728121	30165	Economy	3300.00
0005432383675	30165	Economy	3300.00
0005432383554	30165	Economy	3300.00
0005432728178	30165	Economy	3300.00
0005433194880	30165	Economy	3300.00
0005432383465	30165	Economy	3300.00
0005432383664	30165	Economy	3300.00
0005432728131	30165	Economy	3300.00
0005432383593	30165	Economy	3300.00
0005432383562	30165	Economy	3300.00
0005433453784	30165	Economy	3300.00
0005433451646	30165	Economy	3300.00
0005432728122	30165	Economy	3300.00
0005433453790	30165	Economy	3300.00
0005433453786	30165	Economy	3300.00
0005435530063	1713	Business	57200.00
0005435530074	1713	Business	57200.00
0005432294545	1713	Business	57200.00
0005435541526	1713	Business	57200.00
0005435530075	1713	Business	57200.00
0005432294543	1713	Business	57200.00
0005435541513	1713	Business	57200.00
0005435541531	1713	Business	57200.00
0005435530070	1713	Business	57200.00
0005432925129	1713	Business	57200.00
0005435530073	1713	Economy	19100.00
0005435529777	1713	Economy	19100.00
0005435529784	1713	Economy	19100.00
0005435541511	1713	Economy	19100.00
0005435541529	1713	Economy	19100.00
0005433517109	1713	Economy	19100.00
0005435529779	1713	Economy	19100.00
0005433517113	1713	Economy	19100.00
0005432294544	1713	Economy	21000.00
0005435541523	1713	Economy	21000.00
0005435541514	1713	Economy	21000.00
0005435530081	1713	Economy	19100.00
0005435541510	1713	Economy	19100.00
0005435541517	1713	Economy	19100.00
0005435529771	1713	Economy	19100.00
0005435529769	1713	Economy	19100.00
0005435541527	1713	Economy	19100.00
0005432925102	1713	Economy	19100.00
0005435529785	1713	Economy	19100.00
0005435529780	1713	Economy	19100.00
0005435530078	1713	Economy	19100.00
0005433517108	1713	Economy	19100.00
0005435530082	1713	Economy	19100.00
0005435529772	1713	Economy	19100.00
0005435541515	1713	Economy	19100.00
0005435530079	1713	Economy	19100.00
0005435529767	1713	Economy	19100.00
0005435529773	1713	Economy	19100.00
0005435541521	1713	Economy	19100.00
0005435529778	1713	Economy	19100.00
0005435530067	1713	Economy	19100.00
0005433517105	1713	Economy	19100.00
0005435529774	1713	Economy	19100.00
0005435529768	1713	Economy	19100.00
0005435530062	1713	Economy	19100.00
0005435541512	1713	Economy	19100.00
0005435541518	1713	Economy	19100.00
0005433517107	1713	Economy	19100.00
0005433517106	1713	Economy	19100.00
0005432925116	1713	Economy	19100.00
0005435529782	1713	Economy	19100.00
0005435541520	1713	Economy	19100.00
0005435541532	1713	Economy	19100.00
0005435529776	1713	Economy	19100.00
0005432925119	1713	Economy	19100.00
0005433517110	1713	Economy	19100.00
0005435541530	1713	Economy	19100.00
0005435530069	1713	Economy	19100.00
0005435529775	1713	Economy	19100.00
0005435530080	1713	Economy	19100.00
0005432925097	1713	Economy	19100.00
0005435529766	1713	Economy	19100.00
0005432925101	1713	Economy	19100.00
0005435541519	1713	Economy	19100.00
0005433517111	1713	Economy	19100.00
0005435530076	1713	Economy	19100.00
0005432925128	1713	Economy	19100.00
0005435541524	1713	Economy	19100.00
0005435541522	1713	Economy	19100.00
0005435530066	1713	Economy	19100.00
0005435530064	1713	Economy	19100.00
0005435529781	1713	Economy	19100.00
0005435541509	1713	Economy	19100.00
0005435530071	1713	Economy	19100.00
0005435530072	1713	Economy	19100.00
0005433517112	1713	Economy	19100.00
0005435529787	1713	Economy	19100.00
0005435530065	1713	Economy	19100.00
0005435541525	1713	Economy	19100.00
0005435541516	1713	Economy	19100.00
0005435530068	1713	Economy	19100.00
0005435530077	1713	Economy	19100.00
0005435529765	1713	Economy	19100.00
0005435529783	1713	Economy	19100.00
0005435529770	1713	Economy	19100.00
0005435541528	1713	Economy	19100.00
0005435529786	1713	Economy	19100.00
0005435530083	1713	Economy	19100.00
0005435518195	22013	Business	57200.00
0005435541316	22013	Business	57200.00
0005435541328	22013	Business	57200.00
0005435518118	22013	Business	57200.00
0005435541341	22013	Business	57200.00
0005435541334	22013	Business	57200.00
0005432925153	22013	Business	57200.00
0005435541353	22013	Economy	19100.00
0005435518205	22013	Economy	19100.00
0005433516998	22013	Economy	19100.00
0005435541277	22013	Economy	19100.00
0005432925151	22013	Economy	19100.00
0005435518192	22013	Economy	21000.00
0005435541292	22013	Economy	21000.00
0005433517046	22013	Economy	21000.00
0005435541335	22013	Economy	19100.00
0005435541302	22013	Economy	19100.00
0005435541384	22013	Economy	19100.00
0005435541327	22013	Economy	19100.00
0005432925152	22013	Economy	19100.00
0005435541440	22013	Economy	19100.00
0005435541288	22013	Economy	19100.00
0005433517021	22013	Economy	19100.00
0005432925149	22013	Economy	19100.00
0005435518186	22013	Economy	19100.00
0005433517040	22013	Economy	19100.00
0005433517041	22013	Economy	19100.00
0005435541188	22013	Economy	19100.00
0005435518236	22013	Economy	19100.00
0005435541293	22013	Economy	19100.00
0005435541318	22013	Economy	19100.00
0005435518197	22013	Economy	19100.00
0005433517045	22013	Economy	19100.00
0005435518211	22013	Economy	19100.00
0005435541265	22013	Economy	19100.00
0005435518223	22013	Economy	19100.00
0005435541259	22013	Economy	19100.00
0005435518146	22013	Economy	19100.00
0005435518193	22013	Economy	19100.00
0005435518060	22013	Economy	19100.00
0005435518196	22013	Economy	19100.00
0005435518235	22013	Economy	19100.00
0005435518189	22013	Economy	19100.00
0005435541258	22013	Economy	19100.00
0005432925150	22013	Economy	19100.00
0005435541333	22013	Economy	19100.00
0005435518119	22013	Economy	19100.00
0005435541303	22013	Economy	19100.00
0005435541361	22013	Economy	19100.00
0005435518135	22013	Economy	19100.00
0005433517024	22013	Economy	19100.00
0005435518139	22013	Economy	19100.00
0005435518212	22013	Economy	19100.00
0005435541343	22013	Economy	19100.00
0005433517042	22013	Economy	19100.00
0005435518191	22013	Economy	19100.00
0005435541385	22013	Economy	19100.00
0005433517019	22013	Economy	19100.00
0005435541408	22013	Economy	19100.00
0005435541336	22013	Economy	19100.00
0005435518232	22013	Economy	19100.00
0005435541332	22013	Economy	19100.00
0005433516997	22013	Economy	19100.00
0005435518260	22013	Economy	19100.00
0005432839757	7399	Business	18500.00
0005432839761	7399	Business	18500.00
0005432839754	7399	Business	18500.00
0005435252926	7399	Business	18500.00
0005435252976	7399	Business	18500.00
0005434459287	7399	Business	18500.00
0005434459303	7399	Business	18500.00
0005434459299	7399	Business	18500.00
0005435252907	7399	Business	18500.00
0005432839765	7399	Business	18500.00
0005434459288	7399	Economy	6200.00
0005435252975	7399	Economy	6200.00
0005432839780	7399	Economy	6200.00
0005435253015	7399	Economy	6200.00
0005435253005	7399	Economy	6200.00
0005432839770	7399	Economy	6200.00
0005434459292	7399	Economy	6200.00
0005435252971	7399	Economy	6200.00
0005434664991	7399	Economy	6800.00
0005435252939	7399	Economy	6800.00
0005432839766	7399	Economy	6800.00
0005432839759	7399	Economy	6800.00
0005434459289	7399	Economy	6200.00
0005435252977	7399	Economy	6200.00
0005434459306	7399	Economy	6200.00
0005434459295	7399	Economy	6200.00
0005432073473	7399	Economy	6200.00
0005432839764	7399	Economy	6200.00
0005435252970	7399	Economy	6200.00
0005432839775	7399	Economy	6200.00
0005434459301	7399	Economy	6200.00
0005432839758	7399	Economy	6200.00
0005432839779	7399	Economy	6200.00
0005432839767	7399	Economy	6200.00
0005434459294	7399	Economy	6200.00
0005435252936	7399	Economy	6200.00
0005435252998	7399	Economy	6200.00
0005435252925	7399	Economy	6200.00
0005434459291	7399	Economy	6200.00
0005432073472	7399	Economy	6200.00
0005434459304	7399	Economy	6200.00
0005432839760	7399	Economy	6200.00
0005434459297	7399	Economy	6200.00
0005435252935	7399	Economy	6200.00
0005432839771	7399	Economy	6200.00
0005432839776	7399	Economy	6200.00
0005435252938	7399	Economy	6200.00
0005435252960	7399	Economy	6200.00
0005432823497	7399	Economy	6200.00
0005434459300	7399	Economy	6200.00
0005432839763	7399	Economy	6200.00
0005432839768	7399	Economy	6200.00
0005432839755	7399	Economy	6200.00
0005432839772	7399	Economy	6200.00
0005432839774	7399	Economy	6200.00
0005434459305	7399	Economy	6200.00
0005435252912	7399	Economy	6200.00
0005434459290	7399	Economy	6200.00
0005432823495	7399	Economy	6200.00
0005432823496	7399	Economy	6200.00
0005432839773	7399	Economy	6200.00
0005432839762	7399	Economy	6200.00
0005435252927	7399	Economy	6200.00
0005432839781	7399	Economy	6200.00
0005432839777	7399	Economy	6200.00
0005434459293	7399	Economy	6200.00
0005435252911	7399	Economy	6200.00
0005435252996	7399	Economy	6200.00
0005435252905	7399	Economy	6200.00
0005432839753	7399	Economy	6200.00
0005432839756	7399	Economy	6200.00
0005435252999	7399	Economy	6200.00
0005434459296	7399	Economy	6200.00
0005434459286	7399	Economy	6200.00
0005432839778	7399	Economy	6200.00
0005434459298	7399	Economy	6200.00
0005434459302	7399	Economy	6200.00
0005432841060	7399	Economy	6200.00
0005432839769	7399	Economy	6200.00
0005435253122	28931	Business	18500.00
0005432839367	28931	Business	18500.00
0005432839366	28931	Business	18500.00
0005432839508	28931	Business	18500.00
0005432839343	28931	Business	18500.00
0005434459139	28931	Business	18500.00
0005432839523	28931	Business	18500.00
0005435253127	28931	Business	18500.00
0005435253133	28931	Business	18500.00
0005432839368	28931	Business	18500.00
0005434459095	28931	Economy	6200.00
0005435253135	28931	Economy	6200.00
0005435253118	28931	Economy	6200.00
0005432839549	28931	Economy	6200.00
0005432839471	28931	Economy	6200.00
0005435253130	28931	Economy	6200.00
0005432001071	28931	Economy	6200.00
0005432839439	28931	Economy	6200.00
0005435253125	28931	Economy	6200.00
0005432839650	28931	Economy	6800.00
0005434459134	28931	Economy	6800.00
0005432839626	28931	Economy	6800.00
0005434459142	28931	Economy	6800.00
0005432839435	28931	Economy	6200.00
0005432839618	28931	Economy	6200.00
0005432839507	28931	Economy	6200.00
0005432839500	28931	Economy	6200.00
0005432839482	28931	Economy	6200.00
0005435491495	28931	Economy	6200.00
0005432839436	28931	Economy	6200.00
0005434459137	28931	Economy	6200.00
0005434665014	28931	Economy	6200.00
0005434459116	28931	Economy	6200.00
0005434459135	28931	Economy	6200.00
0005434459182	28931	Economy	6200.00
0005434459115	28931	Economy	6200.00
0005432839490	28931	Economy	6200.00
0005432839539	28931	Economy	6200.00
0005435253123	28931	Economy	6200.00
0005435253132	28931	Economy	6200.00
0005434459148	28931	Economy	6200.00
0005434459060	28931	Economy	6200.00
0005432839489	28931	Economy	6200.00
0005432839584	28931	Economy	6200.00
0005432839462	28931	Economy	6200.00
0005434459117	28931	Economy	6200.00
0005432839647	28931	Economy	6200.00
0005435253120	28931	Economy	6200.00
0005432839649	28931	Economy	6200.00
0005432839396	28931	Economy	6200.00
0005435253119	28931	Economy	6200.00
0005435253136	28931	Economy	6200.00
0005432823484	28931	Economy	6200.00
0005435253128	28931	Economy	6200.00
0005434459113	28931	Economy	6200.00
0005432823483	28931	Economy	6200.00
0005432839477	28931	Economy	6200.00
0005434459136	28931	Economy	6200.00
0005432839470	28931	Economy	6200.00
0005432839499	28931	Economy	6200.00
0005435253129	28931	Economy	6200.00
0005432001070	28931	Economy	6200.00
0005432839469	28931	Economy	6200.00
0005434459146	28931	Economy	6200.00
0005435253121	28931	Economy	6200.00
0005434459085	28931	Economy	6200.00
0005432839625	28931	Economy	6200.00
0005435253126	28931	Economy	6200.00
0005434459111	28931	Economy	6200.00
0005435253124	28931	Economy	6200.00
0005434665015	28931	Economy	6200.00
0005432839537	28931	Economy	6200.00
0005432839587	28931	Economy	6200.00
0005432839538	28931	Economy	6200.00
0005435491494	28931	Economy	6200.00
0005432839522	28931	Economy	6200.00
0005434459181	28931	Economy	6200.00
0005434459138	28931	Economy	6200.00
0005434459147	28931	Economy	6200.00
0005432839503	28931	Economy	6200.00
0005435253131	28931	Economy	6200.00
0005432839509	28931	Economy	6200.00
0005435253134	28931	Economy	6200.00
0005435253117	28931	Economy	6200.00
0005434459082	28931	Economy	6200.00
0005435990791	8816	Business	145300.00
0005435990790	8816	Business	145300.00
0005434276105	8816	Economy	48400.00
0005435990793	8816	Economy	53300.00
0005434276136	8816	Economy	48400.00
0005435990795	8816	Economy	48400.00
0005434276104	8816	Economy	48400.00
0005434276103	8816	Economy	48400.00
0005434276137	8816	Economy	48400.00
0005434276113	8816	Economy	48400.00
0005435990789	8816	Economy	48400.00
0005435990792	8816	Economy	48400.00
0005435990794	8816	Economy	48400.00
0005434276101	8816	Economy	48400.00
0005434276161	15710	Business	145300.00
0005434276164	15710	Business	145300.00
0005435990730	15710	Business	145300.00
0005435990703	15710	Economy	48400.00
0005434276162	15710	Economy	48400.00
0005435990686	15710	Economy	48400.00
0005434276163	15710	Economy	48400.00
0005434276165	15710	Economy	48400.00
0005435990704	15710	Economy	48400.00
0005432909359	2084	Economy	13300.00
0005433468542	2084	Economy	13300.00
0005432909366	2084	Economy	13300.00
0005433468525	2084	Economy	13300.00
0005433468535	2084	Economy	12100.00
0005433468549	2084	Economy	12100.00
0005433468546	2084	Economy	12100.00
0005432909380	2084	Economy	12100.00
0005433468529	2084	Economy	12100.00
0005433468541	2084	Economy	12100.00
0005433468534	2084	Economy	12100.00
0005433468543	2084	Economy	12100.00
0005433468545	2084	Economy	12100.00
0005433468544	2084	Economy	12100.00
0005433468540	2084	Economy	12100.00
0005433468530	2084	Economy	12100.00
0005433468537	2084	Economy	12100.00
0005432909379	2084	Economy	12100.00
0005433468528	2084	Economy	12100.00
0005432909368	2084	Economy	12100.00
0005432909360	2084	Economy	12100.00
0005433468526	2084	Economy	12100.00
0005433468536	2084	Economy	12100.00
0005432909345	2084	Economy	12100.00
0005433468551	2084	Economy	12100.00
0005432909354	2084	Economy	12100.00
0005433468533	2084	Economy	12100.00
0005433468531	2084	Economy	12100.00
0005433468552	2084	Economy	12100.00
0005433468550	2084	Economy	12100.00
0005432909355	2084	Economy	12100.00
0005432909353	2084	Economy	12100.00
0005433468527	2084	Economy	12100.00
0005433468532	2084	Economy	12100.00
0005433468548	2084	Economy	12100.00
0005432909365	2084	Economy	12100.00
0005433468538	2084	Economy	12100.00
0005433468524	2084	Economy	12100.00
0005432909363	2084	Economy	12100.00
0005433468547	2084	Economy	12100.00
0005432909346	2084	Economy	12100.00
0005433468539	2084	Economy	12100.00
0005432909362	2084	Economy	12100.00
0005432909361	2084	Economy	12100.00
0005432361515	6376	Business	36600.00
0005432361518	6376	Business	36600.00
0005434149884	6376	Business	36600.00
0005432336317	6376	Business	36600.00
0005434149909	6376	Business	36600.00
0005435177437	6376	Business	36600.00
0005435723077	6376	Business	36600.00
0005435177532	6376	Business	36600.00
0005432361519	6376	Business	36600.00
0005432361481	6376	Business	36600.00
0005432336311	6376	Business	36600.00
0005432361516	6376	Business	36600.00
0005432361499	6376	Economy	12200.00
0005432062356	6376	Economy	12200.00
0005435177412	6376	Economy	12200.00
0005435723079	6376	Economy	12200.00
0005432361495	6376	Economy	12200.00
0005432336310	6376	Economy	12200.00
0005432361505	6376	Economy	12200.00
0005435177511	6376	Economy	12200.00
0005435177614	6376	Economy	12200.00
0005432361508	6376	Economy	12200.00
0005432361513	6376	Economy	12200.00
0005432361477	6376	Economy	12200.00
0005434149855	6376	Economy	12200.00
0005432361510	6376	Economy	12200.00
0005435177574	6376	Economy	12200.00
0005432363494	6376	Economy	12200.00
0005432336312	6376	Economy	12200.00
0005432361493	6376	Economy	12200.00
0005432361478	6376	Economy	12200.00
0005432361496	6376	Economy	12200.00
0005432336314	6376	Economy	12200.00
0005435177479	6376	Economy	12200.00
0005435177619	6376	Economy	12200.00
0005432361503	6376	Economy	12200.00
0005432361502	6376	Economy	12200.00
0005435177460	6376	Economy	12200.00
0005432361501	6376	Economy	12200.00
0005435177626	6376	Economy	12200.00
0005432336319	6376	Economy	12200.00
0005432361490	6376	Economy	12200.00
0005434149885	6376	Economy	12200.00
0005435177536	6376	Economy	12200.00
0005435177455	6376	Economy	12200.00
0005435177627	6376	Economy	12200.00
0005432336321	6376	Economy	12200.00
0005432363492	6376	Economy	12200.00
0005432361483	6376	Economy	12200.00
0005432361511	6376	Economy	12200.00
0005432361492	6376	Economy	13400.00
0005432062355	6376	Economy	12200.00
0005435723078	6376	Economy	13400.00
0005434149922	6376	Economy	13400.00
0005432361488	6376	Economy	13400.00
0005432363493	6376	Economy	13400.00
0005434149932	6376	Economy	13400.00
0005432361487	6376	Economy	12200.00
0005434149923	6376	Economy	12200.00
0005435490298	6376	Economy	12200.00
0005432361521	6376	Economy	12200.00
0005432361507	6376	Economy	12200.00
0005435177633	6376	Economy	12200.00
0005432361512	6376	Economy	12200.00
0005434149879	6376	Economy	12200.00
0005432361504	6376	Economy	12200.00
0005432361476	6376	Economy	12200.00
0005434149940	6376	Economy	12200.00
0005434149901	6376	Economy	12200.00
0005435177454	6376	Economy	12200.00
0005435723076	6376	Economy	12200.00
0005435177461	6376	Economy	12200.00
0005434149910	6376	Economy	12200.00
0005434149933	6376	Economy	12200.00
0005432336320	6376	Economy	12200.00
0005435490285	6376	Economy	12200.00
0005432062353	6376	Economy	12200.00
0005432361497	6376	Economy	12200.00
0005435177507	6376	Economy	12200.00
0005435177463	6376	Economy	12200.00
0005435490299	6376	Economy	12200.00
0005434149908	6376	Economy	12200.00
0005432361520	6376	Economy	12200.00
0005432361491	6376	Economy	12200.00
0005432361500	6376	Economy	12200.00
0005435177440	6376	Economy	12200.00
0005432361486	6376	Economy	12200.00
0005432336315	6376	Economy	12200.00
0005435723080	6376	Economy	12200.00
0005432336318	6376	Economy	12200.00
0005435490300	6376	Economy	12200.00
0005432361494	6376	Economy	12200.00
0005432361482	6376	Economy	12200.00
0005435177521	6376	Economy	12200.00
0005432363495	6376	Economy	12200.00
0005432361479	6376	Economy	12200.00
0005432361480	6376	Economy	12200.00
0005435177613	6376	Economy	12200.00
0005434149900	6376	Economy	12200.00
0005434149941	6376	Economy	12200.00
0005432361522	6376	Economy	12200.00
0005435177620	6376	Economy	12200.00
0005435177453	6376	Economy	12200.00
0005432361489	6376	Economy	12200.00
0005435177612	6376	Economy	12200.00
0005432062357	6376	Economy	12200.00
0005432062354	6376	Economy	12200.00
0005434149931	6376	Economy	12200.00
0005434149921	6376	Economy	12200.00
0005432361509	6376	Economy	12200.00
0005435177552	6376	Economy	12200.00
0005432361484	6376	Economy	12200.00
0005432336313	6376	Economy	12200.00
0005435177480	6376	Economy	12200.00
0005432361475	6376	Economy	12200.00
0005432361498	6376	Economy	12200.00
0005432361517	6376	Economy	12200.00
0005435177491	6376	Economy	12200.00
0005432336316	6376	Economy	12200.00
0005432361485	6376	Economy	12200.00
0005432361506	6376	Economy	12200.00
0005435177438	6376	Economy	12200.00
0005432361514	6376	Economy	12200.00
0005434149878	6376	Economy	12200.00
0005432052817	21011	Business	36600.00
0005435177737	21011	Business	36600.00
0005432361255	21011	Business	36600.00
0005432361115	21011	Business	36600.00
0005434150005	21011	Business	36600.00
0005432361244	21011	Business	36600.00
0005434150006	21011	Business	36600.00
0005432052818	21011	Business	36600.00
0005432361256	21011	Business	36600.00
0005435177724	21011	Business	36600.00
0005435490319	21011	Business	36600.00
0005432361088	21011	Economy	12200.00
0005432336205	21011	Economy	12200.00
0005432360983	21011	Economy	12200.00
0005432360860	21011	Economy	12200.00
0005432361253	21011	Economy	12200.00
0005435177733	21011	Economy	12200.00
0005432361070	21011	Economy	12200.00
0005432361019	21011	Economy	12200.00
0005432336199	21011	Economy	12200.00
0005432361066	21011	Economy	12200.00
0005434150004	21011	Economy	12200.00
0005432361150	21011	Economy	12200.00
0005432361048	21011	Economy	12200.00
0005432361034	21011	Economy	12200.00
0005435723092	21011	Economy	12200.00
0005435177722	21011	Economy	12200.00
0005432052819	21011	Economy	12200.00
0005432360982	21011	Economy	12200.00
0005432360951	21011	Economy	12200.00
0005432336179	21011	Economy	12200.00
0005432361130	21011	Economy	12200.00
0005432361047	21011	Economy	12200.00
0005432361145	21011	Economy	12200.00
0005435177728	21011	Economy	12200.00
0005435490318	21011	Economy	12200.00
0005432336218	21011	Economy	12200.00
0005432363459	21011	Economy	12200.00
0005432363465	21011	Economy	12200.00
0005435490317	21011	Economy	12200.00
0005435177736	21011	Economy	12200.00
0005432361217	21011	Economy	12200.00
0005435177735	21011	Economy	12200.00
0005435723091	21011	Economy	12200.00
0005435177721	21011	Economy	12200.00
0005432336244	21011	Economy	12200.00
0005432361211	21011	Economy	12200.00
0005432361184	21011	Economy	12200.00
0005432360907	21011	Economy	12200.00
0005432363467	21011	Economy	12200.00
0005432361243	21011	Economy	12200.00
0005432361144	21011	Economy	13400.00
0005435177732	21011	Economy	13400.00
0005432361142	21011	Economy	13400.00
0005432336188	21011	Economy	13400.00
0005432363464	21011	Economy	13400.00
0005435177713	21011	Economy	12200.00
0005432361022	21011	Economy	12200.00
0005435177714	21011	Economy	12200.00
0005432361204	21011	Economy	12200.00
0005432361116	21011	Economy	12200.00
0005432360950	21011	Economy	12200.00
0005434150008	21011	Economy	12200.00
0005432361068	21011	Economy	12200.00
0005432361058	21011	Economy	12200.00
0005432361183	21011	Economy	12200.00
0005432361205	21011	Economy	12200.00
0005432361046	21011	Economy	12200.00
0005435177719	21011	Economy	12200.00
0005432361149	21011	Economy	12200.00
0005432361135	21011	Economy	12200.00
0005434150007	21011	Economy	12200.00
0005432363475	21011	Economy	12200.00
0005432361069	21011	Economy	12200.00
0005435177716	21011	Economy	12200.00
0005432361122	21011	Economy	12200.00
0005432361309	21011	Economy	12200.00
0005435177734	21011	Economy	12200.00
0005432363474	21011	Economy	12200.00
0005435177715	21011	Economy	12200.00
0005432361071	21011	Economy	12200.00
0005432361258	21011	Economy	12200.00
0005432052820	21011	Economy	12200.00
0005432361165	21011	Economy	12200.00
0005432361067	21011	Economy	12200.00
0005435177738	21011	Economy	12200.00
0005435177717	21011	Economy	12200.00
0005432336217	21011	Economy	12200.00
0005432361091	21011	Economy	12200.00
0005434150013	21011	Economy	12200.00
0005435177727	21011	Economy	12200.00
0005434150014	21011	Economy	12200.00
0005434150009	21011	Economy	12200.00
0005432360984	21011	Economy	12200.00
0005432361148	21011	Economy	12200.00
0005432360949	21011	Economy	12200.00
0005434150010	21011	Economy	12200.00
0005434150011	21011	Economy	12200.00
0005432361032	21011	Economy	12200.00
0005432361131	21011	Economy	12200.00
0005432360973	21011	Economy	12200.00
0005432361121	21011	Economy	12200.00
0005435177718	21011	Economy	12200.00
0005435177725	21011	Economy	12200.00
0005432360958	21011	Economy	12200.00
0005432336187	21011	Economy	12200.00
0005432361031	21011	Economy	12200.00
0005435177720	21011	Economy	12200.00
0005432361010	21011	Economy	12200.00
0005435177731	21011	Economy	12200.00
0005432361216	21011	Economy	12200.00
0005432361036	21011	Economy	12200.00
0005432336231	21011	Economy	12200.00
0005435177730	21011	Economy	12200.00
0005432361143	21011	Economy	12200.00
0005435177723	21011	Economy	12200.00
0005432361035	21011	Economy	12200.00
0005432360934	21011	Economy	12200.00
0005432336209	21011	Economy	12200.00
0005432336212	21011	Economy	12200.00
0005432360957	21011	Economy	12200.00
0005435177729	21011	Economy	12200.00
0005432361011	21011	Economy	12200.00
0005432361090	21011	Economy	12200.00
0005434150003	21011	Economy	12200.00
0005434150012	21011	Economy	12200.00
0005435177739	21011	Economy	12200.00
0005435177726	21011	Economy	12200.00
0005434186267	17710	Economy	3400.00
0005434463961	17710	Economy	3400.00
0005434461688	17710	Economy	3400.00
0005434459149	17710	Economy	3400.00
0005434459084	17710	Economy	3100.00
0005434459086	17710	Economy	3100.00
0005434186269	17710	Economy	3100.00
0005434459087	17710	Economy	3100.00
0005434461687	17710	Economy	3100.00
0005434459083	17710	Economy	3100.00
0005434448364	17710	Economy	3100.00
0005434186268	17710	Economy	3100.00
0005434463973	17710	Economy	3100.00
0005434459110	17710	Economy	3100.00
0005434459062	17710	Economy	3100.00
0005434459114	17710	Economy	3100.00
0005434459154	17710	Economy	3100.00
0005434459108	17710	Economy	3100.00
0005434459105	17710	Economy	3100.00
0005434459179	17710	Economy	3100.00
0005434459167	17710	Economy	3100.00
0005434463962	17710	Economy	3100.00
0005434459103	17710	Economy	3100.00
0005434459180	17710	Economy	3100.00
0005434459163	17710	Economy	3100.00
0005434459104	17710	Economy	3100.00
0005434459109	17710	Economy	3100.00
0005434463972	17710	Economy	3100.00
0005434459155	17710	Economy	3100.00
0005434459168	17710	Economy	3100.00
0005434459078	17710	Economy	3100.00
0005434459300	29089	Economy	3400.00
0005434459305	29089	Economy	3400.00
0005434459302	29089	Economy	3100.00
0005434459293	29089	Economy	3100.00
0005434186240	29089	Economy	3100.00
0005434459292	29089	Economy	3100.00
0005434459287	29089	Economy	3100.00
0005434463979	29089	Economy	3100.00
0005434459289	29089	Economy	3100.00
0005434459301	29089	Economy	3100.00
0005434459306	29089	Economy	3100.00
0005434459291	29089	Economy	3100.00
0005434448394	29089	Economy	3100.00
0005434459296	29089	Economy	3100.00
0005434463977	29089	Economy	3100.00
0005434459294	29089	Economy	3100.00
0005434448393	29089	Economy	3100.00
0005434459295	29089	Economy	3100.00
0005434459297	29089	Economy	3100.00
0005434459290	29089	Economy	3100.00
0005434459304	29089	Economy	3100.00
0005434462839	29089	Economy	3100.00
0005434459288	29089	Economy	3100.00
0005434448391	29089	Economy	3100.00
0005434459286	29089	Economy	3100.00
0005434459299	29089	Economy	3100.00
0005434459298	29089	Economy	3100.00
0005434448392	29089	Economy	3100.00
0005434448395	29089	Economy	3100.00
0005434459303	29089	Economy	3100.00
0005434463978	29089	Economy	3100.00
0005432605226	21423	Economy	7300.00
0005432605253	21423	Economy	7300.00
0005432605258	21423	Economy	7300.00
0005432605246	21423	Economy	7300.00
0005432605264	21423	Economy	6600.00
0005432605261	21423	Economy	6600.00
0005432605233	21423	Economy	6600.00
0005432605231	21423	Economy	6600.00
0005432605240	21423	Economy	6600.00
0005432605259	21423	Economy	6600.00
0005432605263	21423	Economy	6600.00
0005432605229	21423	Economy	6600.00
0005432605257	21423	Economy	6600.00
0005432605262	21423	Economy	6600.00
0005432605237	21423	Economy	6600.00
0005432605239	21423	Economy	6600.00
0005432605251	21423	Economy	6600.00
0005432605241	21423	Economy	6600.00
0005432605224	21423	Economy	6600.00
0005432605247	21423	Economy	6600.00
0005435220491	21423	Economy	6600.00
0005432605230	21423	Economy	6600.00
0005432605250	21423	Economy	6600.00
0005432605232	21423	Economy	6600.00
0005432605238	21423	Economy	6600.00
0005432605252	21423	Economy	6600.00
0005432605256	21423	Economy	6600.00
0005432605260	21423	Economy	6600.00
0005432605236	21423	Economy	6600.00
0005432605235	21423	Economy	6600.00
0005432605245	21423	Economy	6600.00
0005432605243	21423	Economy	6600.00
0005432605244	21423	Economy	6600.00
0005432605249	21423	Economy	6600.00
0005432605242	21423	Economy	6600.00
0005432605225	21423	Economy	6600.00
0005432605254	21423	Economy	6600.00
0005432605234	21423	Economy	6600.00
0005432605255	21423	Economy	6600.00
0005432605227	21423	Economy	6600.00
0005432605248	21423	Economy	6600.00
0005432605228	21423	Economy	6600.00
0005432604794	31695	Economy	7300.00
0005432604825	31695	Economy	7300.00
0005432604950	31695	Economy	7300.00
0005432604852	31695	Economy	7300.00
0005432604966	31695	Economy	6600.00
0005435221076	31695	Economy	6600.00
0005432604920	31695	Economy	6600.00
0005432604814	31695	Economy	6600.00
0005432604811	31695	Economy	6600.00
0005432604909	31695	Economy	6600.00
0005432604866	31695	Economy	6600.00
0005432604759	31695	Economy	6600.00
0005432604928	31695	Economy	6600.00
0005432604936	31695	Economy	6600.00
0005432604829	31695	Economy	6600.00
0005432604842	31695	Economy	6600.00
0005432604848	31695	Economy	6600.00
0005432604824	31695	Economy	6600.00
0005432604964	31695	Economy	6600.00
0005432604937	31695	Economy	6600.00
0005432604865	31695	Economy	6600.00
0005432604932	31695	Economy	6600.00
0005432604876	31695	Economy	6600.00
0005432604929	31695	Economy	6600.00
0005432604965	31695	Economy	6600.00
0005435221077	31695	Economy	6600.00
0005432604951	31695	Economy	6600.00
0005432605038	31695	Economy	6600.00
0005435221075	31695	Economy	6600.00
0005432604839	31695	Economy	6600.00
0005432604930	31695	Economy	6600.00
0005432604846	31695	Economy	6600.00
0005432604908	31695	Economy	6600.00
0005432604858	31695	Economy	6600.00
0005432604953	31695	Economy	6600.00
0005432605007	31695	Economy	6600.00
0005432604931	31695	Economy	6600.00
0005432604835	31695	Economy	6600.00
0005432604784	31695	Economy	6600.00
0005432604985	31695	Economy	6600.00
0005432604859	31695	Economy	6600.00
0005432604841	31695	Economy	6600.00
0005432605036	31695	Economy	6600.00
0005432604843	31695	Economy	6600.00
0005432605037	31695	Economy	6600.00
0005432604927	31695	Economy	6600.00
0005432604847	31695	Economy	6600.00
0005434606875	18895	Economy	6600.00
0005434606882	18895	Economy	6600.00
0005434606878	18895	Economy	6600.00
0005434606879	18895	Economy	6600.00
0005434606880	18895	Economy	6600.00
0005434606874	18895	Economy	6600.00
0005434606904	22344	Economy	6600.00
0005435904711	22344	Economy	6600.00
0005434604980	22344	Economy	6600.00
0005434606907	22344	Economy	6600.00
0005434604981	22344	Economy	6600.00
0005434604983	22344	Economy	6600.00
0005434604982	22344	Economy	6600.00
0005434606905	22344	Economy	6600.00
0005434606906	22344	Economy	6600.00
0005434604979	22344	Economy	6600.00
0005432891278	368	Business	44500.00
0005432748444	368	Business	44500.00
0005432748464	368	Business	44500.00
0005432891356	368	Business	44500.00
0005432748472	368	Business	44500.00
0005432753376	368	Business	44500.00
0005433293341	368	Business	44500.00
0005432748473	368	Business	44500.00
0005433293335	368	Business	44500.00
0005432748454	368	Business	44500.00
0005432748456	368	Economy	14800.00
0005432891330	368	Economy	14800.00
0005432748459	368	Economy	14800.00
0005433293351	368	Economy	14800.00
0005432748462	368	Economy	14800.00
0005432220103	368	Economy	14800.00
0005432220104	368	Economy	14800.00
0005432748469	368	Economy	14800.00
0005432891308	368	Economy	16300.00
0005432751601	368	Economy	16300.00
0005432748447	368	Economy	16300.00
0005432891319	368	Economy	16300.00
0005432748461	368	Economy	14800.00
0005432748455	368	Economy	14800.00
0005432748471	368	Economy	14800.00
0005432753377	368	Economy	14800.00
0005432748466	368	Economy	14800.00
0005432748458	368	Economy	14800.00
0005432891339	368	Economy	14800.00
0005432748441	368	Economy	14800.00
0005432748453	368	Economy	14800.00
0005435154666	368	Economy	14800.00
0005432748446	368	Economy	14800.00
0005433875401	368	Economy	14800.00
0005433293349	368	Economy	14800.00
0005432891303	368	Economy	14800.00
0005432891353	368	Economy	14800.00
0005433293334	368	Economy	14800.00
0005432891301	368	Economy	14800.00
0005433875400	368	Economy	14800.00
0005432891341	368	Economy	14800.00
0005432748449	368	Economy	14800.00
0005432748477	368	Economy	14800.00
0005432748443	368	Economy	14800.00
0005435154667	368	Economy	14800.00
0005433293333	368	Economy	14800.00
0005432891331	368	Economy	14800.00
0005435627126	368	Economy	14800.00
0005432748442	368	Economy	14800.00
0005433293350	368	Economy	14800.00
0005432748475	368	Economy	14800.00
0005432748468	368	Economy	14800.00
0005432751603	368	Economy	14800.00
0005432891340	368	Economy	14800.00
0005432748450	368	Economy	14800.00
0005432220105	368	Economy	14800.00
0005432749834	368	Economy	14800.00
0005432748452	368	Economy	14800.00
0005432748463	368	Economy	14800.00
0005432748448	368	Economy	14800.00
0005432748474	368	Economy	14800.00
0005432220102	368	Economy	14800.00
0005432748476	368	Economy	14800.00
0005435627127	368	Economy	14800.00
0005432748467	368	Economy	14800.00
0005432748451	368	Economy	14800.00
0005432751602	368	Economy	14800.00
0005432748465	368	Economy	14800.00
0005432891217	368	Economy	14800.00
0005432891326	368	Economy	14800.00
0005432748470	368	Economy	14800.00
0005432748457	368	Economy	14800.00
0005432891396	368	Economy	14800.00
0005432748460	368	Economy	14800.00
0005432748445	368	Economy	14800.00
0005432749835	368	Economy	14800.00
0005432753378	368	Economy	14800.00
0005432891300	368	Economy	14800.00
0005432891314	368	Economy	14800.00
0005432748165	12042	Business	44500.00
0005432891476	12042	Business	44500.00
0005433875419	12042	Business	44500.00
0005432756896	12042	Business	44500.00
0005432756897	12042	Business	44500.00
0005432748238	12042	Business	44500.00
0005434153568	12042	Business	44500.00
0005432214855	12042	Business	44500.00
0005432748134	12042	Business	44500.00
0005432748244	12042	Business	44500.00
0005432748088	12042	Business	44500.00
0005432748199	12042	Business	44500.00
0005432756905	12042	Economy	14800.00
0005433293391	12042	Economy	14800.00
0005432748157	12042	Economy	14800.00
0005433293394	12042	Economy	14800.00
0005433875420	12042	Economy	14800.00
0005432753340	12042	Economy	14800.00
0005432747982	12042	Economy	14800.00
0005433293399	12042	Economy	14800.00
0005432748087	12042	Economy	14800.00
0005432748180	12042	Economy	14800.00
0005432891483	12042	Economy	16300.00
0005433293393	12042	Economy	16300.00
0005432756904	12042	Economy	16300.00
0005432891472	12042	Economy	16300.00
0005432891478	12042	Economy	16300.00
0005432748103	12042	Economy	14800.00
0005432891475	12042	Economy	14800.00
0005433293397	12042	Economy	14800.00
0005433293395	12042	Economy	14800.00
0005433293392	12042	Economy	14800.00
0005432891482	12042	Economy	14800.00
0005432891490	12042	Economy	14800.00
0005432891487	12042	Economy	14800.00
0005435154608	12042	Economy	14800.00
0005432891484	12042	Economy	14800.00
0005432748226	12042	Economy	14800.00
0005432891480	12042	Economy	14800.00
0005432747923	12042	Economy	14800.00
0005432214854	12042	Economy	14800.00
0005432748031	12042	Economy	14800.00
0005432891473	12042	Economy	14800.00
0005432756883	12042	Economy	14800.00
0005432748206	12042	Economy	14800.00
0005434152855	12042	Economy	14800.00
0005432748228	12042	Economy	14800.00
0005432891486	12042	Economy	14800.00
0005432891485	12042	Economy	14800.00
0005432748019	12042	Economy	14800.00
0005432891474	12042	Economy	14800.00
0005432748358	12042	Economy	14800.00
0005433293388	12042	Economy	14800.00
0005433293385	12042	Economy	14800.00
0005432748145	12042	Economy	14800.00
0005432891488	12042	Economy	14800.00
0005432748200	12042	Economy	14800.00
0005432891477	12042	Economy	14800.00
0005434152858	12042	Economy	14800.00
0005432748187	12042	Economy	14800.00
0005434152857	12042	Economy	14800.00
0005432747922	12042	Economy	14800.00
0005432748062	12042	Economy	14800.00
0005432748100	12042	Economy	14800.00
0005434153569	12042	Economy	14800.00
0005432748132	12042	Economy	14800.00
0005432891471	12042	Economy	14800.00
0005432748011	12042	Economy	14800.00
0005432748091	12042	Economy	14800.00
0005432748223	12042	Economy	14800.00
0005432748144	12042	Economy	14800.00
0005432891479	12042	Economy	14800.00
0005433293390	12042	Economy	14800.00
0005435154610	12042	Economy	14800.00
0005432748160	12042	Economy	14800.00
0005432748207	12042	Economy	14800.00
0005434152856	12042	Economy	14800.00
0005433293389	12042	Economy	14800.00
0005432748245	12042	Economy	14800.00
0005435154614	12042	Economy	14800.00
0005432891481	12042	Economy	14800.00
0005435154611	12042	Economy	14800.00
0005433293386	12042	Economy	14800.00
0005433293396	12042	Economy	14800.00
0005432748248	12042	Economy	14800.00
0005434153567	12042	Economy	14800.00
0005433293387	12042	Economy	14800.00
0005432748186	12042	Economy	14800.00
0005432749820	12042	Economy	14800.00
0005435154607	12042	Economy	14800.00
0005433293398	12042	Economy	14800.00
0005432748147	12042	Economy	14800.00
0005435154606	12042	Economy	14800.00
0005432748053	12042	Economy	14800.00
0005432748063	12042	Economy	14800.00
0005432891489	12042	Economy	14800.00
0005432748279	12042	Economy	14800.00
0005433533395	18963	Economy	28200.00
0005433525290	18963	Economy	28200.00
0005433533394	18963	Economy	28200.00
0005432928042	18963	Economy	25700.00
0005433525283	18963	Economy	25700.00
0005432928075	18963	Economy	25700.00
0005432928057	18963	Economy	25700.00
0005433525286	18963	Economy	25700.00
0005432928076	18963	Economy	25700.00
0005433533392	18963	Economy	25700.00
0005433525287	18963	Economy	25700.00
0005432928085	18963	Economy	25700.00
0005433525282	18963	Economy	25700.00
0005432928086	18963	Economy	25700.00
0005433533393	18963	Economy	25700.00
0005433531379	18963	Economy	25700.00
0005433531380	18963	Economy	25700.00
0005433531377	18963	Economy	25700.00
0005433525284	18963	Economy	25700.00
0005433525281	18963	Economy	25700.00
0005433533396	18963	Economy	25700.00
0005432928058	18963	Economy	25700.00
0005432928062	18963	Economy	25700.00
0005433525289	18963	Economy	25700.00
0005433525285	18963	Economy	25700.00
0005433531378	18963	Economy	25700.00
0005432928061	18963	Economy	25700.00
0005433525288	18963	Economy	25700.00
0005433525209	32499	Economy	28200.00
0005433527299	32499	Economy	25700.00
0005433525197	32499	Economy	25700.00
0005433525194	32499	Economy	25700.00
0005433531344	32499	Economy	25700.00
0005433525229	32499	Economy	25700.00
0005432928117	32499	Economy	25700.00
0005432928119	32499	Economy	25700.00
0005433525245	32499	Economy	25700.00
0005433525215	32499	Economy	25700.00
0005432928118	32499	Economy	25700.00
0005433525199	32499	Economy	25700.00
0005432928120	32499	Economy	25700.00
0005433525210	32499	Economy	25700.00
0005433525230	32499	Economy	25700.00
0005433527313	32499	Economy	25700.00
0005433527316	32499	Economy	25700.00
0005433525182	32499	Economy	25700.00
0005433525198	32499	Economy	25700.00
0005432928121	32499	Economy	25700.00
0005432121667	5281	Business	84000.00
0005435150361	5281	Business	84000.00
0005434826604	5281	Business	84000.00
0005434826515	5281	Business	84000.00
0005434826504	5281	Business	84000.00
0005435304230	5281	Business	84000.00
0005435150364	5281	Business	84000.00
0005434826538	5281	Business	84000.00
0005434831257	5281	Business	84000.00
0005434558475	5281	Business	84000.00
0005434831259	5281	Business	84000.00
0005434665012	5281	Business	84000.00
0005435661962	5281	Business	84000.00
0005434826550	5281	Business	84000.00
0005434826606	5281	Business	84000.00
0005434826551	5281	Business	84000.00
0005432396335	5281	Business	84000.00
0005434826537	5281	Business	84000.00
0005434826576	5281	Comfort	47600.00
0005432121665	5281	Comfort	47600.00
0005434826556	5281	Comfort	47600.00
0005435374210	5281	Comfort	47600.00
0005434826624	5281	Comfort	47600.00
0005435373982	5281	Comfort	47600.00
0005435661963	5281	Comfort	47600.00
0005434826586	5281	Comfort	47600.00
0005435299852	5281	Comfort	47600.00
0005435374225	5281	Comfort	47600.00
0005435150363	5281	Comfort	47600.00
0005434826510	5281	Comfort	47600.00
0005434826627	5281	Comfort	47600.00
0005434826571	5281	Comfort	47600.00
0005432394199	5281	Comfort	47600.00
0005435374031	5281	Comfort	47600.00
0005434826595	5281	Comfort	47600.00
0005435374283	5281	Comfort	47600.00
0005434826514	5281	Comfort	47600.00
0005434826630	5281	Comfort	47600.00
0005434558479	5281	Comfort	47600.00
0005434826582	5281	Comfort	47600.00
0005434826569	5281	Comfort	47600.00
0005435304223	5281	Comfort	47600.00
0005434826554	5281	Comfort	47600.00
0005434826626	5281	Comfort	47600.00
0005435374285	5281	Comfort	47600.00
0005434826593	5281	Comfort	47600.00
0005434826631	5281	Comfort	47600.00
0005435374434	5281	Comfort	47600.00
0005435374152	5281	Comfort	47600.00
0005434826568	5281	Comfort	47600.00
0005434826546	5281	Comfort	47600.00
0005434826607	5281	Economy	28000.00
0005434826579	5281	Economy	28000.00
0005435374433	5281	Economy	28000.00
0005435299857	5281	Economy	28000.00
0005434826589	5281	Economy	28000.00
0005435374297	5281	Economy	28000.00
0005432394200	5281	Economy	28000.00
0005434665013	5281	Economy	28000.00
0005434826575	5281	Economy	28000.00
0005434826605	5281	Economy	28000.00
0005432121672	5281	Economy	28000.00
0005435735210	5281	Economy	28000.00
0005435374079	5281	Economy	28000.00
0005435374206	5281	Economy	28000.00
0005435374008	5281	Economy	28000.00
0005435374030	5281	Economy	28000.00
0005435386674	5281	Economy	28000.00
0005435150356	5281	Economy	28000.00
0005434826566	5281	Economy	28000.00
0005434826544	5281	Economy	28000.00
0005434826506	5281	Economy	28000.00
0005435386664	5281	Economy	28000.00
0005435374211	5281	Economy	28000.00
0005434826507	5281	Economy	28000.00
0005434826615	5281	Economy	28000.00
0005435386657	5281	Economy	28000.00
0005434826558	5281	Economy	28000.00
0005434826520	5281	Economy	28000.00
0005435374316	5281	Economy	28000.00
0005434826523	5281	Economy	28000.00
0005435374314	5281	Economy	28000.00
0005434826620	5281	Economy	28000.00
0005434826540	5281	Economy	28000.00
0005434826611	5281	Economy	28000.00
0005434826618	5281	Economy	28000.00
0005434826599	5281	Economy	28000.00
0005434826526	5281	Economy	28000.00
0005434826584	5281	Economy	28000.00
0005434826588	5281	Economy	28000.00
0005435374298	5281	Economy	28000.00
0005435374345	5281	Economy	28000.00
0005434826617	5281	Economy	28000.00
0005434826525	5281	Economy	28000.00
0005434826619	5281	Economy	28000.00
0005434826583	5281	Economy	30800.00
0005435374353	5281	Economy	30800.00
0005435374293	5281	Economy	28000.00
0005432121671	5281	Economy	28000.00
0005434826570	5281	Economy	28000.00
0005432121660	5281	Economy	30800.00
0005435374165	5281	Economy	30800.00
0005435374392	5281	Economy	30800.00
0005434826600	5281	Economy	28000.00
0005434828759	5281	Economy	28000.00
0005435374327	5281	Economy	28000.00
0005434826549	5281	Economy	28000.00
0005434826521	5281	Economy	28000.00
0005435374459	5281	Economy	28000.00
0005435374331	5281	Economy	28000.00
0005434826532	5281	Economy	28000.00
0005435386637	5281	Economy	28000.00
0005434826621	5281	Economy	28000.00
0005434826628	5281	Economy	28000.00
0005434826547	5281	Economy	28000.00
0005435735194	5281	Economy	28000.00
0005435386688	5281	Economy	28000.00
0005435374429	5281	Economy	28000.00
0005435299858	5281	Economy	28000.00
0005435304224	5281	Economy	28000.00
0005434826543	5281	Economy	28000.00
0005435386662	5281	Economy	28000.00
0005434826622	5281	Economy	28000.00
0005434826542	5281	Economy	28000.00
0005434831256	5281	Economy	28000.00
0005434826562	5281	Economy	28000.00
0005434826509	5281	Economy	28000.00
0005434826629	5281	Economy	28000.00
0005435150359	5281	Economy	28000.00
0005432121669	5281	Economy	28000.00
0005435374315	5281	Economy	28000.00
0005434826535	5281	Economy	28000.00
0005432396337	5281	Economy	28000.00
0005434558474	5281	Economy	28000.00
0005434826536	5281	Economy	28000.00
0005434826530	5281	Economy	28000.00
0005435374136	5281	Economy	28000.00
0005432394201	5281	Economy	28000.00
0005435374462	5281	Economy	28000.00
0005434826573	5281	Economy	28000.00
0005434826616	5281	Economy	28000.00
0005432121663	5281	Economy	28000.00
0005434826587	5281	Economy	28000.00
0005434558478	5281	Economy	28000.00
0005435374226	5281	Economy	28000.00
0005434826534	5281	Economy	28000.00
0005434826594	5281	Economy	28000.00
0005435386655	5281	Economy	28000.00
0005435386658	5281	Economy	28000.00
0005434826612	5281	Economy	28000.00
0005435179700	5281	Economy	28000.00
0005434826531	5281	Economy	28000.00
0005434826596	5281	Economy	28000.00
0005434826529	5281	Economy	28000.00
0005435304227	5281	Economy	28000.00
0005434665011	5281	Economy	28000.00
0005435374029	5281	Economy	28000.00
0005435735207	5281	Economy	28000.00
0005434826614	5281	Economy	28000.00
0005435386661	5281	Economy	28000.00
0005434826516	5281	Economy	28000.00
0005434826590	5281	Economy	28000.00
0005434826625	5281	Economy	28000.00
0005435150365	5281	Economy	28000.00
0005434826553	5281	Economy	28000.00
0005434826601	5281	Economy	28000.00
0005435374046	5281	Economy	28000.00
0005434831258	5281	Economy	28000.00
0005435373938	5281	Economy	28000.00
0005432121668	5281	Economy	28000.00
0005435150360	5281	Economy	28000.00
0005434826585	5281	Economy	28000.00
0005435374004	5281	Economy	28000.00
0005435374313	5281	Economy	28000.00
0005432396336	5281	Economy	28000.00
0005435374044	5281	Economy	28000.00
0005434826623	5281	Economy	28000.00
0005434826555	5281	Economy	28000.00
0005435374383	5281	Economy	28000.00
0005434826598	5281	Economy	28000.00
0005434826592	5281	Economy	28000.00
0005435374278	5281	Economy	28000.00
0005435150353	5281	Economy	28000.00
0005432394198	5281	Economy	28000.00
0005435374134	5281	Economy	28000.00
0005434558480	5281	Economy	28000.00
0005435150355	5281	Economy	28000.00
0005434826560	5281	Economy	28000.00
0005434826527	5281	Economy	28000.00
0005435386638	5281	Economy	30800.00
0005435661975	5281	Economy	30800.00
0005434826572	5281	Economy	28000.00
0005435150358	5281	Economy	30800.00
0005435304226	5281	Economy	28000.00
0005435374245	5281	Economy	28000.00
0005432121661	5281	Economy	28000.00
0005434558476	5281	Economy	28000.00
0005434826565	5281	Economy	28000.00
0005434826557	5281	Economy	28000.00
0005434558473	5281	Economy	28000.00
0005434826524	5281	Economy	28000.00
0005434826591	5281	Economy	28000.00
0005435386659	5281	Economy	28000.00
0005434826541	5281	Economy	28000.00
0005434828760	5281	Economy	28000.00
0005435374181	5281	Economy	28000.00
0005435374066	5281	Economy	28000.00
0005434826548	5281	Economy	28000.00
0005434826518	5281	Economy	28000.00
0005435150354	5281	Economy	28000.00
0005432396334	5281	Economy	28000.00
0005432121664	5281	Economy	28000.00
0005434826522	5281	Economy	28000.00
0005435374084	5281	Economy	28000.00
0005434826552	5281	Economy	28000.00
0005435374003	5281	Economy	28000.00
0005435374563	5281	Economy	28000.00
0005434826610	5281	Economy	28000.00
0005435374239	5281	Economy	28000.00
0005434826609	5281	Economy	28000.00
0005435374329	5281	Economy	28000.00
0005434826533	5281	Economy	28000.00
0005435374430	5281	Economy	28000.00
0005435299836	5281	Economy	28000.00
0005435304228	5281	Economy	28000.00
0005435150357	5281	Economy	28000.00
0005434826508	5281	Economy	28000.00
0005435304231	5281	Economy	28000.00
0005434828761	5281	Economy	28000.00
0005434826505	5281	Economy	28000.00
0005434826539	5281	Economy	28000.00
0005434826603	5281	Economy	28000.00
0005434826561	5281	Economy	28000.00
0005435374149	5281	Economy	28000.00
0005435374354	5281	Economy	28000.00
0005434826567	5281	Economy	28000.00
0005435374135	5281	Economy	28000.00
0005434826564	5281	Economy	28000.00
0005434558477	5281	Economy	28000.00
0005434826545	5281	Economy	28000.00
0005435386660	5281	Economy	28000.00
0005434826581	5281	Economy	28000.00
0005434831260	5281	Economy	28000.00
0005435735193	5281	Economy	28000.00
0005434826580	5281	Economy	28000.00
0005435374292	5281	Economy	28000.00
0005432121666	5281	Economy	28000.00
0005434826602	5281	Economy	28000.00
0005434826613	5281	Economy	28000.00
0005434826608	5281	Economy	28000.00
0005435374083	5281	Economy	28000.00
0005434826517	5281	Economy	28000.00
0005434826577	5281	Economy	28000.00
0005435374106	5281	Economy	28000.00
0005434826563	5281	Economy	28000.00
0005432121662	5281	Economy	28000.00
0005434826528	5281	Economy	28000.00
0005434826574	5281	Economy	28000.00
0005434826578	5281	Economy	28000.00
0005434826597	5281	Economy	28000.00
0005434826512	5281	Economy	28000.00
0005435304229	5281	Economy	28000.00
0005435373939	5281	Economy	28000.00
0005432121670	5281	Economy	28000.00
0005435373973	5281	Economy	28000.00
0005434826559	5281	Economy	28000.00
0005434826513	5281	Economy	28000.00
0005434826519	5281	Economy	28000.00
0005435150362	5281	Economy	28000.00
0005434826511	5281	Economy	28000.00
0005435661961	5281	Economy	28000.00
0005435374045	5281	Economy	28000.00
0005434825824	9905	Business	84000.00
0005435374800	9905	Business	84000.00
0005435374770	9905	Business	84000.00
0005435374772	9905	Business	84000.00
0005435150209	9905	Business	84000.00
0005435315029	9905	Business	84000.00
0005434825472	9905	Business	84000.00
0005434825641	9905	Business	84000.00
0005435315032	9905	Business	84000.00
0005434825062	9905	Business	84000.00
0005435315031	9905	Business	84000.00
0005435374798	9905	Business	84000.00
0005434825932	9905	Business	84000.00
0005434825970	9905	Business	84000.00
0005432203231	9905	Business	84000.00
0005435374819	9905	Business	84000.00
0005434825470	9905	Business	84000.00
0005434825882	9905	Business	84000.00
0005434558362	9905	Business	84000.00
0005435315022	9905	Business	84000.00
0005434825139	9905	Business	84000.00
0005434825138	9905	Business	84000.00
0005435374777	9905	Business	84000.00
0005434664994	9905	Business	84000.00
0005434825639	9905	Business	84000.00
0005435374767	9905	Comfort	47600.00
0005434824880	9905	Comfort	47600.00
0005434824940	9905	Comfort	47600.00
0005434825082	9905	Comfort	47600.00
0005434558380	9905	Comfort	47600.00
0005434825658	9905	Comfort	47600.00
0005435299887	9905	Comfort	47600.00
0005434825018	9905	Comfort	47600.00
0005435374775	9905	Comfort	47600.00
0005434825720	9905	Comfort	47600.00
0005434825673	9905	Comfort	47600.00
0005432823498	9905	Comfort	47600.00
0005435302309	9905	Comfort	47600.00
0005435315024	9905	Comfort	47600.00
0005434825516	9905	Comfort	47600.00
0005435150178	9905	Comfort	47600.00
0005434824326	9905	Comfort	47600.00
0005434825399	9905	Comfort	47600.00
0005432396301	9905	Comfort	47600.00
0005434825471	9905	Comfort	47600.00
0005435374792	9905	Comfort	47600.00
0005434825500	9905	Comfort	47600.00
0005435374801	9905	Comfort	47600.00
0005434825221	9905	Comfort	47600.00
0005432203230	9905	Comfort	47600.00
0005434558397	9905	Comfort	47600.00
0005435315025	9905	Comfort	47600.00
0005435302311	9905	Comfort	47600.00
0005434825220	9905	Comfort	47600.00
0005435374806	9905	Comfort	47600.00
0005434825200	9905	Comfort	47600.00
0005434558407	9905	Comfort	47600.00
0005434825021	9905	Comfort	47600.00
0005435315020	9905	Comfort	47600.00
0005435315016	9905	Comfort	47600.00
0005435374812	9905	Comfort	47600.00
0005435150165	9905	Comfort	47600.00
0005434825460	9905	Comfort	47600.00
0005434824941	9905	Economy	28000.00
0005435374808	9905	Economy	28000.00
0005435735249	9905	Economy	28000.00
0005435150231	9905	Economy	28000.00
0005434825493	9905	Economy	28000.00
0005434558408	9905	Economy	28000.00
0005435315021	9905	Economy	28000.00
0005435374787	9905	Economy	28000.00
0005435374788	9905	Economy	28000.00
0005435315033	9905	Economy	28000.00
0005435315018	9905	Economy	28000.00
0005434558367	9905	Economy	28000.00
0005434825458	9905	Economy	28000.00
0005435374783	9905	Economy	28000.00
0005434825674	9905	Economy	28000.00
0005434664996	9905	Economy	28000.00
0005434824873	9905	Economy	28000.00
0005434825241	9905	Economy	28000.00
0005435150162	9905	Economy	28000.00
0005435374811	9905	Economy	28000.00
0005435374797	9905	Economy	28000.00
0005434825703	9905	Economy	28000.00
0005434825451	9905	Economy	28000.00
0005434825140	9905	Economy	28000.00
0005434558356	9905	Economy	28000.00
0005434825223	9905	Economy	28000.00
0005434824813	9905	Economy	28000.00
0005434825662	9905	Economy	28000.00
0005434824874	9905	Economy	28000.00
0005435374773	9905	Economy	28000.00
0005435735251	9905	Economy	28000.00
0005435302308	9905	Economy	28000.00
0005434824844	9905	Economy	28000.00
0005432400190	9905	Economy	28000.00
0005435150176	9905	Economy	28000.00
0005435374817	9905	Economy	28000.00
0005435315028	9905	Economy	28000.00
0005435150177	9905	Economy	28000.00
0005434825492	9905	Economy	28000.00
0005435374764	9905	Economy	28000.00
0005435150210	9905	Economy	28000.00
0005435374816	9905	Economy	28000.00
0005435374803	9905	Economy	28000.00
0005435374781	9905	Economy	28000.00
0005434824939	9905	Economy	28000.00
0005435374778	9905	Economy	28000.00
0005434825836	9905	Economy	28000.00
0005434825349	9905	Economy	28000.00
0005432203237	9905	Economy	28000.00
0005435150219	9905	Economy	28000.00
0005434825966	9905	Economy	30800.00
0005434825865	9905	Economy	30800.00
0005435150223	9905	Economy	28000.00
0005434825750	9905	Economy	30800.00
0005434825240	9905	Economy	28000.00
0005435374799	9905	Economy	28000.00
0005435374784	9905	Economy	30800.00
0005434825930	9905	Economy	28000.00
0005434825459	9905	Economy	30800.00
0005434831215	9905	Economy	30800.00
0005435150288	9905	Economy	28000.00
0005435150161	9905	Economy	28000.00
0005432400194	9905	Economy	28000.00
0005434825375	9905	Economy	28000.00
0005435374793	9905	Economy	28000.00
0005434825441	9905	Economy	28000.00
0005434825931	9905	Economy	28000.00
0005434825582	9905	Economy	28000.00
0005434824814	9905	Economy	28000.00
0005434825209	9905	Economy	28000.00
0005434825746	9905	Economy	28000.00
0005435374805	9905	Economy	28000.00
0005434825482	9905	Economy	28000.00
0005434825199	9905	Economy	28000.00
0005435374779	9905	Economy	28000.00
0005435374824	9905	Economy	28000.00
0005434826329	9905	Economy	28000.00
0005435374820	9905	Economy	28000.00
0005434825751	9905	Economy	28000.00
0005435302310	9905	Economy	28000.00
0005435299886	9905	Economy	28000.00
0005434826038	9905	Economy	28000.00
0005435374815	9905	Economy	28000.00
0005434825101	9905	Economy	28000.00
0005434825590	9905	Economy	28000.00
0005434825113	9905	Economy	28000.00
0005434825864	9905	Economy	28000.00
0005434825400	9905	Economy	28000.00
0005434558357	9905	Economy	28000.00
0005434825566	9905	Economy	28000.00
0005435374789	9905	Economy	28000.00
0005435374826	9905	Economy	28000.00
0005434825083	9905	Economy	28000.00
0005434825305	9905	Economy	28000.00
0005434825499	9905	Economy	28000.00
0005435315027	9905	Economy	28000.00
0005435150247	9905	Economy	28000.00
0005435374813	9905	Economy	28000.00
0005435374774	9905	Economy	28000.00
0005435374771	9905	Economy	28000.00
0005435374810	9905	Economy	28000.00
0005434825445	9905	Economy	28000.00
0005434825262	9905	Economy	28000.00
0005434825609	9905	Economy	28000.00
0005435735252	9905	Economy	28000.00
0005435150208	9905	Economy	28000.00
0005434825756	9905	Economy	28000.00
0005434825545	9905	Economy	28000.00
0005432203236	9905	Economy	28000.00
0005435374807	9905	Economy	28000.00
0005434825580	9905	Economy	28000.00
0005435150224	9905	Economy	28000.00
0005435374765	9905	Economy	28000.00
0005435661999	9905	Economy	28000.00
0005435150217	9905	Economy	28000.00
0005434558381	9905	Economy	28000.00
0005435150230	9905	Economy	28000.00
0005434825657	9905	Economy	28000.00
0005435374794	9905	Economy	28000.00
0005435374822	9905	Economy	28000.00
0005435315026	9905	Economy	28000.00
0005435374823	9905	Economy	28000.00
0005435374791	9905	Economy	28000.00
0005434831219	9905	Economy	28000.00
0005432203234	9905	Economy	28000.00
0005434825430	9905	Economy	28000.00
0005434825372	9905	Economy	28000.00
0005434825055	9905	Economy	28000.00
0005435315017	9905	Economy	28000.00
0005435374818	9905	Economy	28000.00
0005434825084	9905	Economy	28000.00
0005434825644	9905	Economy	28000.00
0005434825454	9905	Economy	28000.00
0005432400191	9905	Economy	28000.00
0005434825464	9905	Economy	28000.00
0005435374804	9905	Economy	28000.00
0005434831209	9905	Economy	28000.00
0005434825446	9905	Economy	28000.00
0005435374802	9905	Economy	28000.00
0005434825847	9905	Economy	28000.00
0005434664995	9905	Economy	28000.00
0005434825789	9905	Economy	28000.00
0005432203235	9905	Economy	28000.00
0005434825675	9905	Economy	28000.00
0005434831208	9905	Economy	28000.00
0005435179415	9905	Economy	28000.00
0005435150167	9905	Economy	30800.00
0005434558358	9905	Economy	28000.00
0005435374780	9905	Economy	30800.00
0005434825867	9905	Economy	30800.00
0005434825732	9905	Economy	30800.00
0005435179417	9905	Economy	28000.00
0005434825167	9905	Economy	28000.00
0005435374786	9905	Economy	28000.00
0005435374766	9905	Economy	28000.00
0005434825494	9905	Economy	28000.00
0005435374776	9905	Economy	28000.00
0005434825633	9905	Economy	28000.00
0005435374782	9905	Economy	28000.00
0005434824985	9905	Economy	28000.00
0005435374825	9905	Economy	28000.00
0005434824908	9905	Economy	28000.00
0005434825535	9905	Economy	28000.00
0005434825788	9905	Economy	28000.00
0005434825515	9905	Economy	28000.00
0005434824917	9905	Economy	28000.00
0005435374790	9905	Economy	28000.00
0005434825368	9905	Economy	28000.00
0005434825369	9905	Economy	28000.00
0005435374768	9905	Economy	28000.00
0005435374769	9905	Economy	28000.00
0005434825428	9905	Economy	28000.00
0005434825691	9905	Economy	28000.00
0005432203232	9905	Economy	28000.00
0005434664992	9905	Economy	28000.00
0005434825276	9905	Economy	28000.00
0005434825565	9905	Economy	28000.00
0005434825965	9905	Economy	28000.00
0005434826330	9905	Economy	28000.00
0005435315023	9905	Economy	28000.00
0005434825495	9905	Economy	28000.00
0005434824984	9905	Economy	28000.00
0005434825661	9905	Economy	28000.00
0005435374796	9905	Economy	28000.00
0005434558379	9905	Economy	28000.00
0005434825892	9905	Economy	28000.00
0005432396294	9905	Economy	28000.00
0005435299888	9905	Economy	28000.00
0005435374814	9905	Economy	28000.00
0005435374795	9905	Economy	28000.00
0005434825560	9905	Economy	28000.00
0005434825091	9905	Economy	28000.00
0005434825431	9905	Economy	28000.00
0005435735248	9905	Economy	28000.00
0005435150179	9905	Economy	28000.00
0005434825866	9905	Economy	28000.00
0005432396316	9905	Economy	28000.00
0005434558396	9905	Economy	28000.00
0005434825659	9905	Economy	28000.00
0005434824843	9905	Economy	28000.00
0005434825555	9905	Economy	28000.00
0005432396293	9905	Economy	28000.00
0005434825112	9905	Economy	28000.00
0005435374785	9905	Economy	28000.00
0005434825127	9905	Economy	28000.00
0005432203233	9905	Economy	28000.00
0005435315030	9905	Economy	28000.00
0005435374809	9905	Economy	28000.00
0005435735250	9905	Economy	28000.00
0005435299889	9905	Economy	28000.00
0005434825392	9905	Economy	28000.00
0005434825393	9905	Economy	28000.00
0005434825103	9905	Economy	28000.00
0005434825581	9905	Economy	28000.00
0005435179416	9905	Economy	28000.00
0005435150166	9905	Economy	28000.00
0005434824969	9905	Economy	28000.00
0005435150213	9905	Economy	28000.00
0005435374821	9905	Economy	28000.00
0005434825011	9905	Economy	28000.00
0005434825068	9905	Economy	28000.00
0005434825473	9905	Economy	28000.00
0005434825605	9905	Economy	28000.00
0005434825090	9905	Economy	28000.00
0005434825024	9905	Economy	28000.00
0005435315034	9905	Economy	28000.00
0005435315019	9905	Economy	28000.00
0005434825955	9905	Economy	28000.00
0005434825638	9905	Economy	28000.00
0005434558366	9905	Economy	28000.00
0005434831220	9905	Economy	28000.00
0005435082983	6982	Economy	8200.00
0005435082981	6982	Economy	8200.00
0005435082984	6982	Economy	7400.00
0005435082982	6982	Economy	7400.00
0005435082977	6982	Economy	7400.00
0005435082979	6982	Economy	7400.00
0005435082980	6982	Economy	7400.00
0005435790376	6982	Economy	7400.00
0005435790375	6982	Economy	7400.00
0005435082985	6982	Economy	7400.00
0005435082978	6982	Economy	7400.00
0005435790354	25983	Economy	8200.00
0005435082905	25983	Economy	7400.00
0005435790357	25983	Economy	7400.00
0005435082879	25983	Economy	7400.00
0005435790355	25983	Economy	7400.00
0005435082895	25983	Economy	7400.00
0005435082904	25983	Economy	7400.00
0005435082878	25983	Economy	7400.00
0005435082944	25983	Economy	7400.00
0005435082890	25983	Economy	7400.00
0005435082918	25983	Economy	7400.00
0005435082896	25983	Economy	7400.00
0005435790351	25983	Economy	7400.00
0005435082919	25983	Economy	7400.00
0005434757394	9534	Business	32800.00
0005434214977	9534	Business	32800.00
0005434215253	9534	Business	32800.00
0005434215031	9534	Business	32800.00
0005434757422	9534	Business	32800.00
0005434757392	9534	Business	32800.00
0005434215289	9534	Business	32800.00
0005434757400	9534	Business	32800.00
0005434214983	9534	Business	32800.00
0005434215107	9534	Business	32800.00
0005434757407	9534	Business	32800.00
0005434215113	9534	Business	32800.00
0005434757418	9534	Economy	10900.00
0005434215004	9534	Economy	10900.00
0005434757389	9534	Economy	10900.00
0005434757423	9534	Economy	10900.00
0005434215122	9534	Economy	10900.00
0005434757403	9534	Economy	10900.00
0005434757425	9534	Economy	10900.00
0005434215025	9534	Economy	10900.00
0005434757384	9534	Economy	10900.00
0005434215114	9534	Economy	10900.00
0005434214898	9534	Economy	12000.00
0005434757415	9534	Economy	12000.00
0005434757420	9534	Economy	12000.00
0005434214976	9534	Economy	12000.00
0005434757424	9534	Economy	12000.00
0005434757393	9534	Economy	10900.00
0005434757414	9534	Economy	10900.00
0005434757413	9534	Economy	10900.00
0005434757411	9534	Economy	10900.00
0005434757405	9534	Economy	10900.00
0005434215032	9534	Economy	10900.00
0005434757406	9534	Economy	10900.00
0005434757416	9534	Economy	10900.00
0005434757408	9534	Economy	10900.00
0005434757426	9534	Economy	10900.00
0005434215168	9534	Economy	10900.00
0005434215406	9534	Economy	10900.00
0005434215059	9534	Economy	10900.00
0005434215124	9534	Economy	10900.00
0005434215204	9534	Economy	10900.00
0005434757399	9534	Economy	10900.00
0005434215057	9534	Economy	10900.00
0005434757402	9534	Economy	10900.00
0005434215181	9534	Economy	10900.00
0005434757391	9534	Economy	10900.00
0005434757396	9534	Economy	10900.00
0005434215050	9534	Economy	10900.00
0005434757412	9534	Economy	10900.00
0005434215331	9534	Economy	10900.00
0005434757397	9534	Economy	10900.00
0005434215251	9534	Economy	10900.00
0005434757409	9534	Economy	10900.00
0005434215095	9534	Economy	10900.00
0005434757429	9534	Economy	10900.00
0005434215229	9534	Economy	10900.00
0005434757430	9534	Economy	10900.00
0005434757410	9534	Economy	10900.00
0005434215173	9534	Economy	10900.00
0005434215290	9534	Economy	10900.00
0005434215405	9534	Economy	10900.00
0005434215166	9534	Economy	10900.00
0005434215330	9534	Economy	10900.00
0005434757428	9534	Economy	10900.00
0005434757387	9534	Economy	10900.00
0005434215070	9534	Economy	10900.00
0005434757404	9534	Economy	10900.00
0005434757401	9534	Economy	10900.00
0005434757432	9534	Economy	10900.00
0005434215252	9534	Economy	10900.00
0005434215272	9534	Economy	10900.00
0005434757390	9534	Economy	10900.00
0005434215271	9534	Economy	10900.00
0005434757398	9534	Economy	10900.00
0005434215404	9534	Economy	10900.00
0005434757395	9534	Economy	10900.00
0005434215285	9534	Economy	10900.00
0005434215400	9534	Economy	10900.00
0005434757386	9534	Economy	10900.00
0005434215180	9534	Economy	10900.00
0005434215121	9534	Economy	10900.00
0005434757431	9534	Economy	10900.00
0005434215165	9534	Economy	10900.00
0005434757419	9534	Economy	10900.00
0005434215033	9534	Economy	10900.00
0005434757427	9534	Economy	10900.00
0005434757388	9534	Economy	10900.00
0005434215112	9534	Economy	10900.00
0005434215100	9534	Economy	10900.00
0005434215019	9534	Economy	10900.00
0005434215179	9534	Economy	10900.00
0005434215125	9534	Economy	10900.00
0005434757417	9534	Economy	10900.00
0005434757385	9534	Economy	10900.00
0005434215058	9534	Economy	10900.00
0005434757421	9534	Economy	10900.00
0005434756597	28618	Business	32800.00
0005434215581	28618	Business	32800.00
0005434215584	28618	Business	32800.00
0005434756598	28618	Business	32800.00
0005434215571	28618	Business	32800.00
0005434215583	28618	Business	32800.00
0005434215592	28618	Business	32800.00
0005434215578	28618	Business	32800.00
0005434215564	28618	Business	32800.00
0005434215563	28618	Business	32800.00
0005434756868	28618	Business	32800.00
0005434756988	28618	Business	32800.00
0005434756840	28618	Economy	10900.00
0005434215588	28618	Economy	10900.00
0005434757032	28618	Economy	10900.00
0005434215567	28618	Economy	10900.00
0005434215573	28618	Economy	10900.00
0005434756865	28618	Economy	10900.00
0005434756883	28618	Economy	10900.00
0005434215587	28618	Economy	10900.00
0005434756978	28618	Economy	10900.00
0005434215599	28618	Economy	10900.00
0005434215557	28618	Economy	12000.00
0005434756930	28618	Economy	12000.00
0005434756884	28618	Economy	12000.00
0005434756950	28618	Economy	12000.00
0005434756904	28618	Economy	10900.00
0005434215590	28618	Economy	10900.00
0005434215597	28618	Economy	10900.00
0005434757012	28618	Economy	10900.00
0005434215591	28618	Economy	10900.00
0005434756789	28618	Economy	10900.00
0005434215580	28618	Economy	10900.00
0005434756866	28618	Economy	10900.00
0005434756907	28618	Economy	10900.00
0005434757033	28618	Economy	10900.00
0005434215572	28618	Economy	10900.00
0005434756967	28618	Economy	10900.00
0005434756885	28618	Economy	10900.00
0005434215562	28618	Economy	10900.00
0005434757026	28618	Economy	10900.00
0005434757048	28618	Economy	10900.00
0005434215565	28618	Economy	10900.00
0005434756998	28618	Economy	10900.00
0005434756871	28618	Economy	10900.00
0005434215576	28618	Economy	10900.00
0005434215558	28618	Economy	10900.00
0005434215559	28618	Economy	10900.00
0005434215574	28618	Economy	10900.00
0005434215555	28618	Economy	10900.00
0005434756990	28618	Economy	10900.00
0005434756929	28618	Economy	10900.00
0005434215585	28618	Economy	10900.00
0005434215577	28618	Economy	10900.00
0005434215596	28618	Economy	10900.00
0005434756914	28618	Economy	10900.00
0005434215595	28618	Economy	10900.00
0005434215594	28618	Economy	10900.00
0005434215566	28618	Economy	10900.00
0005434215554	28618	Economy	10900.00
0005434756982	28618	Economy	10900.00
0005434756999	28618	Economy	10900.00
0005434756991	28618	Economy	10900.00
0005434215586	28618	Economy	10900.00
0005434215568	28618	Economy	10900.00
0005434757008	28618	Economy	10900.00
0005434215556	28618	Economy	10900.00
0005434215560	28618	Economy	10900.00
0005434756906	28618	Economy	10900.00
0005434757000	28618	Economy	10900.00
0005434215575	28618	Economy	10900.00
0005434756931	28618	Economy	10900.00
0005434756997	28618	Economy	10900.00
0005434756932	28618	Economy	10900.00
0005434756913	28618	Economy	10900.00
0005434756894	28618	Economy	10900.00
0005434756918	28618	Economy	10900.00
0005434756803	28618	Economy	10900.00
0005434756788	28618	Economy	10900.00
0005434215593	28618	Economy	10900.00
0005434215570	28618	Economy	10900.00
0005434756890	28618	Economy	10900.00
0005434215582	28618	Economy	10900.00
0005434756892	28618	Economy	10900.00
0005434215598	28618	Economy	10900.00
0005434215569	28618	Economy	10900.00
0005434756917	28618	Economy	10900.00
0005434215600	28618	Economy	10900.00
0005434215589	28618	Economy	10900.00
0005434215561	28618	Economy	10900.00
0005434215579	28618	Economy	10900.00
0005434756825	28618	Economy	10900.00
0005434756599	28618	Economy	10900.00
0005434756968	28618	Economy	10900.00
0005434760230	10860	Economy	8900.00
0005435100194	10860	Economy	8900.00
0005435100193	10860	Economy	8900.00
0005434760255	31802	Economy	8900.00
0005435100171	31802	Economy	8900.00
0005434760254	31802	Economy	8900.00
0005435100177	31802	Economy	8900.00
0005435100176	31802	Economy	8900.00
0005432290708	1997	Economy	20900.00
0005433202607	1997	Economy	20900.00
0005434639944	1997	Economy	20900.00
0005434639934	1997	Economy	19000.00
0005434639937	1997	Economy	19000.00
0005434639929	1997	Economy	19000.00
0005435948356	1997	Economy	19000.00
0005434639924	1997	Economy	19000.00
0005434639921	1997	Economy	19000.00
0005434639923	1997	Economy	19000.00
0005434639941	1997	Economy	19000.00
0005433202532	1997	Economy	19000.00
0005434639933	1997	Economy	19000.00
0005435948355	1997	Economy	19000.00
0005434639926	1997	Economy	19000.00
0005433202636	1997	Economy	19000.00
0005434639927	1997	Economy	19000.00
0005432290707	1997	Economy	19000.00
0005434639932	1997	Economy	19000.00
0005434639931	1997	Economy	19000.00
0005434639919	1997	Economy	19000.00
0005434639925	1997	Economy	19000.00
0005435948354	1997	Economy	19000.00
0005434639930	1997	Economy	19000.00
0005434639943	1997	Economy	19000.00
0005433202637	1997	Economy	19000.00
0005434639940	1997	Economy	19000.00
0005434639936	1997	Economy	19000.00
0005434639928	1997	Economy	19000.00
0005433202578	1997	Economy	19000.00
0005434639939	1997	Economy	19000.00
0005434639922	1997	Economy	19000.00
0005434639942	1997	Economy	19000.00
0005433202533	1997	Economy	19000.00
0005434639935	1997	Economy	19000.00
0005433202545	1997	Economy	19000.00
0005434639920	1997	Economy	19000.00
0005434639938	1997	Economy	19000.00
0005432290706	1997	Economy	19000.00
0005433202691	23281	Economy	20900.00
0005434639611	23281	Economy	20900.00
0005434639583	23281	Economy	20900.00
0005434639740	23281	Economy	20900.00
0005434639677	23281	Economy	19000.00
0005433202692	23281	Economy	19000.00
0005434639728	23281	Economy	19000.00
0005433202703	23281	Economy	19000.00
0005434639610	23281	Economy	19000.00
0005434639532	23281	Economy	19000.00
0005433202701	23281	Economy	19000.00
0005434639738	23281	Economy	19000.00
0005434639609	23281	Economy	19000.00
0005434639754	23281	Economy	19000.00
0005434639719	23281	Economy	19000.00
0005433202695	23281	Economy	19000.00
0005435948338	23281	Economy	19000.00
0005434639599	23281	Economy	19000.00
0005433202696	23281	Economy	19000.00
0005433202694	23281	Economy	19000.00
0005434639739	23281	Economy	19000.00
0005433202702	23281	Economy	19000.00
0005434639576	23281	Economy	19000.00
0005434639770	23281	Economy	19000.00
0005434639634	23281	Economy	19000.00
0005434639699	23281	Economy	19000.00
0005433202697	23281	Economy	19000.00
0005433202693	23281	Economy	19000.00
0005434639575	23281	Economy	19000.00
0005433202698	23281	Economy	19000.00
0005434639645	23281	Economy	19000.00
0005435948346	23281	Economy	19000.00
0005434639768	23281	Economy	19000.00
0005433202699	23281	Economy	19000.00
0005434639633	23281	Economy	19000.00
0005434639697	23281	Economy	19000.00
0005434639632	23281	Economy	19000.00
0005433202689	23281	Economy	19000.00
0005433202700	23281	Economy	19000.00
0005434639726	23281	Economy	19000.00
0005434639613	23281	Economy	19000.00
0005434639698	23281	Economy	19000.00
0005434639735	23281	Economy	19000.00
0005434639727	23281	Economy	19000.00
0005434639695	23281	Economy	19000.00
0005434639612	23281	Economy	19000.00
0005434639769	23281	Economy	19000.00
0005433202690	23281	Economy	19000.00
0005435326924	6043	Business	69700.00
0005434601432	6043	Business	69700.00
0005434601435	6043	Business	69700.00
0005435326921	6043	Business	69700.00
0005433531382	6043	Business	69700.00
0005433531381	6043	Business	69700.00
0005434601456	6043	Business	69700.00
0005434601444	6043	Economy	23200.00
0005434601440	6043	Economy	23200.00
0005433531384	6043	Economy	23200.00
0005434601437	6043	Economy	23200.00
0005434601439	6043	Economy	23200.00
0005434601450	6043	Economy	23200.00
0005435326973	6043	Economy	23200.00
0005432111348	6043	Economy	25600.00
0005432111349	6043	Economy	25600.00
0005434601455	6043	Economy	25600.00
0005434601436	6043	Economy	23200.00
0005435326991	6043	Economy	23200.00
0005434601451	6043	Economy	23200.00
0005432111351	6043	Economy	23200.00
0005434601454	6043	Economy	23200.00
0005434601448	6043	Economy	23200.00
0005435327017	6043	Economy	23200.00
0005434601452	6043	Economy	23200.00
0005435326943	6043	Economy	23200.00
0005433533397	6043	Economy	23200.00
0005435327002	6043	Economy	23200.00
0005435326894	6043	Economy	23200.00
0005434601430	6043	Economy	23200.00
0005435326940	6043	Economy	23200.00
0005432111350	6043	Economy	23200.00
0005435326929	6043	Economy	23200.00
0005435326990	6043	Economy	23200.00
0005435327007	6043	Economy	23200.00
0005435326928	6043	Economy	23200.00
0005434601434	6043	Economy	23200.00
0005435327003	6043	Economy	23200.00
0005434601438	6043	Economy	23200.00
0005434601449	6043	Economy	23200.00
0005434601443	6043	Economy	23200.00
0005434601431	6043	Economy	23200.00
0005435327008	6043	Economy	23200.00
0005434601458	6043	Economy	23200.00
0005434601445	6043	Economy	23200.00
0005434601441	6043	Economy	23200.00
0005433533398	6043	Economy	23200.00
0005434601447	6043	Economy	23200.00
0005434601442	6043	Economy	23200.00
0005434601453	6043	Economy	23200.00
0005434601433	6043	Economy	23200.00
0005434601457	6043	Economy	23200.00
0005435326895	6043	Economy	23200.00
0005434601446	6043	Economy	23200.00
0005433531383	6043	Economy	23200.00
0005435326944	6043	Economy	23200.00
0005434601221	18593	Business	69700.00
0005434601102	18593	Business	69700.00
0005434601204	18593	Business	69700.00
0005434601368	18593	Business	69700.00
0005434601205	18593	Business	69700.00
0005433531350	18593	Business	69700.00
0005434601078	18593	Business	69700.00
0005433527301	18593	Economy	23200.00
0005435327065	18593	Economy	23200.00
0005435327068	18593	Economy	23200.00
0005434601240	18593	Economy	23200.00
0005435327070	18593	Economy	25600.00
0005435327074	18593	Economy	23200.00
0005434601251	18593	Economy	23200.00
0005435327069	18593	Economy	23200.00
0005434601143	18593	Economy	23200.00
0005435327067	18593	Economy	23200.00
0005434601263	18593	Economy	23200.00
0005434601222	18593	Economy	23200.00
0005434601174	18593	Economy	23200.00
0005434601298	18593	Economy	23200.00
0005434601194	18593	Economy	23200.00
0005434601264	18593	Economy	23200.00
0005435327072	18593	Economy	23200.00
0005435327075	18593	Economy	23200.00
0005434601175	18593	Economy	23200.00
0005433531357	18593	Economy	23200.00
0005435327071	18593	Economy	23200.00
0005435327073	18593	Economy	23200.00
0005434601162	18593	Economy	23200.00
0005434601250	18593	Economy	23200.00
0005433527293	18593	Economy	23200.00
0005434601212	18593	Economy	23200.00
0005434601134	18593	Economy	23200.00
0005434601163	18593	Economy	23200.00
0005434601147	18593	Economy	23200.00
0005434601132	18593	Economy	23200.00
0005435327066	18593	Economy	23200.00
0005434601297	18593	Economy	23200.00
0005434601252	18593	Economy	23200.00
0005433527270	18593	Economy	23200.00
0005434601144	18593	Economy	23200.00
0005434558470	10584	Business	9100.00
0005433181451	10584	Business	9100.00
0005434552454	10584	Business	9100.00
0005434554113	10584	Business	9100.00
0005434552453	10584	Business	9100.00
0005434552478	10584	Business	9100.00
0005434552486	10584	Business	9100.00
0005433181450	10584	Business	9100.00
0005434552468	10584	Business	9100.00
0005434552498	10584	Business	9100.00
0005434552493	10584	Business	9100.00
0005434552476	10584	Business	9100.00
0005434552475	10584	Economy	3000.00
0005434552462	10584	Economy	3000.00
0005434552491	10584	Economy	3000.00
0005434552465	10584	Economy	3000.00
0005434552483	10584	Economy	3000.00
0005434558461	10584	Economy	3000.00
0005434552461	10584	Economy	3000.00
0005434558469	10584	Economy	3000.00
0005433181484	10584	Economy	3000.00
0005434552477	10584	Economy	3000.00
0005434558463	10584	Economy	3300.00
0005434558464	10584	Economy	3300.00
0005433181320	10584	Economy	3300.00
0005433181438	10584	Economy	3300.00
0005434552471	10584	Economy	3300.00
0005434558462	10584	Economy	3000.00
0005434552449	10584	Economy	3000.00
0005433181436	10584	Economy	3000.00
0005433181483	10584	Economy	3000.00
0005433181516	10584	Economy	3000.00
0005433181365	10584	Economy	3000.00
0005434552488	10584	Economy	3000.00
0005434552479	10584	Economy	3000.00
0005433181532	10584	Economy	3000.00
0005434558468	10584	Economy	3000.00
0005434552487	10584	Economy	3000.00
0005434552489	10584	Economy	3000.00
0005434552497	10584	Economy	3000.00
0005434558472	10584	Economy	3000.00
0005434552481	10584	Economy	3000.00
0005434554112	10584	Economy	3000.00
0005433181523	10584	Economy	3000.00
0005434552495	10584	Economy	3000.00
0005434552452	10584	Economy	3000.00
0005434552484	10584	Economy	3000.00
0005434552463	10584	Economy	3000.00
0005434552457	10584	Economy	3000.00
0005434552460	10584	Economy	3000.00
0005434552458	10584	Economy	3000.00
0005434552464	10584	Economy	3000.00
0005434558465	10584	Economy	3000.00
0005434552480	10584	Economy	3000.00
0005434552443	10584	Economy	3000.00
0005434552466	10584	Economy	3000.00
0005433181469	10584	Economy	3000.00
0005434552496	10584	Economy	3000.00
0005434552469	10584	Economy	3000.00
0005434552450	10584	Economy	3000.00
0005434552456	10584	Economy	3000.00
0005433181383	10584	Economy	3000.00
0005434558471	10584	Economy	3000.00
0005434552490	10584	Economy	3000.00
0005434552494	10584	Economy	3000.00
0005434552473	10584	Economy	3000.00
0005434552472	10584	Economy	3000.00
0005434552447	10584	Economy	3000.00
0005434552448	10584	Economy	3000.00
0005434552459	10584	Economy	3000.00
0005434552444	10584	Economy	3000.00
0005434552445	10584	Economy	3000.00
0005434552474	10584	Economy	3000.00
0005434552451	10584	Economy	3000.00
0005434552446	10584	Economy	3000.00
0005434552455	10584	Economy	3000.00
0005434552482	10584	Economy	3000.00
0005434558467	10584	Economy	3000.00
0005434558466	10584	Economy	3000.00
0005434554111	10584	Economy	3000.00
0005434552470	10584	Economy	3000.00
0005434552467	10584	Economy	3000.00
0005433181517	10584	Economy	3000.00
0005433181522	10584	Economy	3000.00
0005434558460	10584	Economy	3000.00
0005434552492	10584	Economy	3000.00
0005434552485	10584	Economy	3000.00
0005433181688	27757	Business	9100.00
0005435315028	27757	Business	9100.00
0005433181683	27757	Business	9100.00
0005434757699	27757	Business	9100.00
0005433181695	27757	Business	9100.00
0005433181685	27757	Business	9100.00
0005433181690	27757	Economy	3000.00
0005433181706	27757	Economy	3000.00
0005433181691	27757	Economy	3000.00
0005435315031	27757	Economy	3000.00
0005433181689	27757	Economy	3300.00
0005433181699	27757	Economy	3000.00
0005435315026	27757	Economy	3000.00
0005433181705	27757	Economy	3000.00
0005435315024	27757	Economy	3000.00
0005433181684	27757	Economy	3000.00
0005435315022	27757	Economy	3000.00
0005435315034	27757	Economy	3000.00
0005433181702	27757	Economy	3000.00
0005435315032	27757	Economy	3000.00
0005434757700	27757	Economy	3000.00
0005435315016	27757	Economy	3000.00
0005433181687	27757	Economy	3000.00
0005433181694	27757	Economy	3000.00
0005433181698	27757	Economy	3000.00
0005434757697	27757	Economy	3000.00
0005433181703	27757	Economy	3000.00
0005433181701	27757	Economy	3000.00
0005435315033	27757	Economy	3000.00
0005433181700	27757	Economy	3000.00
0005435315019	27757	Economy	3000.00
0005433181697	27757	Economy	3000.00
0005433181693	27757	Economy	3000.00
0005434757698	27757	Economy	3000.00
0005435315023	27757	Economy	3000.00
0005435315018	27757	Economy	3000.00
0005435315021	27757	Economy	3000.00
0005433181686	27757	Economy	3000.00
0005433181707	27757	Economy	3000.00
0005435315025	27757	Economy	3000.00
0005433181692	27757	Economy	3000.00
0005433181704	27757	Economy	3000.00
0005435315020	27757	Economy	3000.00
0005435315029	27757	Economy	3000.00
0005435315017	27757	Economy	3000.00
0005435315027	27757	Economy	3000.00
0005433181696	27757	Economy	3000.00
0005435315030	27757	Economy	3000.00
0005434552247	27776	Business	9100.00
0005434558393	27776	Business	9100.00
0005434551940	27776	Business	9100.00
0005434551847	27776	Business	9100.00
0005434552097	27776	Business	9100.00
0005434551836	27776	Business	9100.00
0005434552054	27776	Economy	3000.00
0005434552330	27776	Economy	3000.00
0005434552021	27776	Economy	3000.00
0005434551888	27776	Economy	3000.00
0005434551690	27776	Economy	3000.00
0005434551943	27776	Economy	3000.00
0005434552139	27776	Economy	3000.00
0005434551849	27776	Economy	3000.00
0005434558423	27776	Economy	3300.00
0005434551973	27776	Economy	3300.00
0005434551891	27776	Economy	3300.00
0005434551689	27776	Economy	3000.00
0005434552059	27776	Economy	3000.00
0005434552102	27776	Economy	3000.00
0005434552127	27776	Economy	3000.00
0005434552362	27776	Economy	3000.00
0005434558417	27776	Economy	3000.00
0005434552144	27776	Economy	3000.00
0005434551939	27776	Economy	3000.00
0005434551978	27776	Economy	3000.00
0005434552101	27776	Economy	3000.00
0005434551700	27776	Economy	3000.00
0005434551850	27776	Economy	3000.00
0005434558415	27776	Economy	3000.00
0005434551889	27776	Economy	3000.00
0005434551958	27776	Economy	3000.00
0005434552041	27776	Economy	3000.00
0005434551892	27776	Economy	3000.00
0005434558416	27776	Economy	3000.00
0005434558410	27776	Economy	3000.00
0005434552034	27776	Economy	3000.00
0005434558414	27776	Economy	3000.00
0005434558387	27776	Economy	3000.00
0005434552146	27776	Economy	3000.00
0005434558386	27776	Economy	3000.00
0005434558418	27776	Economy	3000.00
0005434558354	27776	Economy	3000.00
0005434551942	27776	Economy	3000.00
0005434552152	27776	Economy	3000.00
0005434551887	27776	Economy	3000.00
0005434552036	27776	Economy	3000.00
0005434551693	27776	Economy	3000.00
0005434551950	27776	Economy	3000.00
0005434551993	27776	Economy	3000.00
0005434552035	27776	Economy	3000.00
0005434552183	27776	Economy	3000.00
0005434552145	27776	Economy	3000.00
0005434552132	27776	Economy	3000.00
0005434552022	27776	Economy	3000.00
0005434551848	27776	Economy	3000.00
0005434552131	27776	Economy	3000.00
0005434551944	27776	Economy	3000.00
0005434558388	27776	Economy	3000.00
0005434552140	27776	Economy	3000.00
0005434552055	27776	Economy	3000.00
0005434551974	27776	Economy	3000.00
0005434558378	27776	Economy	3000.00
0005434551907	27776	Economy	3000.00
0005434551931	27776	Economy	3000.00
0005434551868	27776	Economy	3000.00
0005434551886	27776	Economy	3000.00
0005433459318	6151	Economy	11700.00
0005435254508	6151	Economy	11700.00
0005433459321	6151	Economy	11700.00
0005435254507	6151	Economy	11700.00
0005435254512	6151	Economy	11700.00
0005433459320	6151	Economy	11700.00
0005435254513	6151	Economy	11700.00
0005433459319	6151	Economy	11700.00
0005433459317	6151	Economy	11700.00
0005435254528	19337	Economy	11700.00
0005433459266	19337	Economy	11700.00
0005435254527	19337	Economy	11700.00
0005435217753	6736	Business	51100.00
0005435438384	6736	Business	51100.00
0005435683077	6736	Business	51100.00
0005435683090	6736	Business	51100.00
0005435683085	6736	Business	51100.00
0005435661998	6736	Business	51100.00
0005435221525	6736	Business	51100.00
0005435683073	6736	Business	51100.00
0005435438297	6736	Business	51100.00
0005435438308	6736	Business	51100.00
0005435683088	6736	Business	51100.00
0005435683082	6736	Business	51100.00
0005435683086	6736	Economy	17000.00
0005435683099	6736	Economy	17000.00
0005435683102	6736	Economy	17000.00
0005435683106	6736	Economy	17000.00
0005435683089	6736	Economy	17000.00
0005435220352	6736	Economy	17000.00
0005432533336	6736	Economy	17000.00
0005435720158	6736	Economy	17000.00
0005434828724	6736	Economy	17000.00
0005435683083	6736	Economy	17000.00
0005435631036	6736	Economy	18700.00
0005435683096	6736	Economy	18700.00
0005435438307	6736	Economy	18700.00
0005435438246	6736	Economy	18700.00
0005435438285	6736	Economy	18700.00
0005432136288	6736	Economy	17000.00
0005435683110	6736	Economy	17000.00
0005432136286	6736	Economy	17000.00
0005435683103	6736	Economy	17000.00
0005434828732	6736	Economy	17000.00
0005432533325	6736	Economy	17000.00
0005435683076	6736	Economy	17000.00
0005432533338	6736	Economy	17000.00
0005435631035	6736	Economy	17000.00
0005435683094	6736	Economy	17000.00
0005435683081	6736	Economy	17000.00
0005435217748	6736	Economy	17000.00
0005435683109	6736	Economy	17000.00
0005435438282	6736	Economy	17000.00
0005435217745	6736	Economy	17000.00
0005435438299	6736	Economy	17000.00
0005435683114	6736	Economy	17000.00
0005435631037	6736	Economy	17000.00
0005432533337	6736	Economy	17000.00
0005435217746	6736	Economy	17000.00
0005435683097	6736	Economy	17000.00
0005435438296	6736	Economy	17000.00
0005435683116	6736	Economy	17000.00
0005435719590	6736	Economy	17000.00
0005435438376	6736	Economy	17000.00
0005435683104	6736	Economy	17000.00
0005435720157	6736	Economy	17000.00
0005435683091	6736	Economy	17000.00
0005435683098	6736	Economy	17000.00
0005435683074	6736	Economy	17000.00
0005432533320	6736	Economy	17000.00
0005435683080	6736	Economy	17000.00
0005434828717	6736	Economy	17000.00
0005435683101	6736	Economy	17000.00
0005435438300	6736	Economy	17000.00
0005435683107	6736	Economy	17000.00
0005435683117	6736	Economy	17000.00
0005435683079	6736	Economy	17000.00
0005435683095	6736	Economy	17000.00
0005435683113	6736	Economy	17000.00
0005435683105	6736	Economy	17000.00
0005435438304	6736	Economy	17000.00
0005435683078	6736	Economy	17000.00
0005435683112	6736	Economy	17000.00
0005435719591	6736	Economy	17000.00
0005435683100	6736	Economy	17000.00
0005435438262	6736	Economy	17000.00
0005435221524	6736	Economy	17000.00
0005435438320	6736	Economy	17000.00
0005432136287	6736	Economy	17000.00
0005435438235	6736	Economy	17000.00
0005435661997	6736	Economy	17000.00
0005435683115	6736	Economy	17000.00
0005435438263	6736	Economy	17000.00
0005435661996	6736	Economy	17000.00
0005432533326	6736	Economy	17000.00
0005435683075	6736	Economy	17000.00
0005435438303	6736	Economy	17000.00
0005435683093	6736	Economy	17000.00
0005435683087	6736	Economy	17000.00
0005435683108	6736	Economy	17000.00
0005435438270	6736	Economy	17000.00
0005435683084	6736	Economy	17000.00
0005435683092	6736	Economy	17000.00
0005435683111	6736	Economy	17000.00
0005435438338	6736	Economy	17000.00
0005435682675	24584	Business	51100.00
0005435682547	24584	Business	51100.00
0005435682758	24584	Business	51100.00
0005434828766	24584	Business	51100.00
0005435682661	24584	Business	51100.00
0005435682764	24584	Business	51100.00
0005435682830	24584	Business	51100.00
0005435682595	24584	Business	51100.00
0005435719579	24584	Business	51100.00
0005435438478	24584	Business	51100.00
0005435682610	24584	Business	51100.00
0005435682591	24584	Business	51100.00
0005434828763	24584	Economy	17000.00
0005435438482	24584	Economy	17000.00
0005435682889	24584	Economy	17000.00
0005435438475	24584	Economy	17000.00
0005435438465	24584	Economy	17000.00
0005434828762	24584	Economy	17000.00
0005435220510	24584	Economy	17000.00
0005435661966	24584	Economy	17000.00
0005435438461	24584	Economy	17000.00
0005435220511	24584	Economy	17000.00
0005435438483	24584	Economy	18700.00
0005435682594	24584	Economy	18700.00
0005435438470	24584	Economy	18700.00
0005435682869	24584	Economy	18700.00
0005435438480	24584	Economy	18700.00
0005435438462	24584	Economy	17000.00
0005435682682	24584	Economy	17000.00
0005435220368	24584	Economy	17000.00
0005435682858	24584	Economy	17000.00
0005434828765	24584	Economy	17000.00
0005435682845	24584	Economy	17000.00
0005434828764	24584	Economy	17000.00
0005435682552	24584	Economy	17000.00
0005435219249	24584	Economy	17000.00
0005435438479	24584	Economy	17000.00
0005435682708	24584	Economy	17000.00
0005435682592	24584	Economy	17000.00
0005435438477	24584	Economy	17000.00
0005432305807	24584	Economy	17000.00
0005435682797	24584	Economy	17000.00
0005435438481	24584	Economy	17000.00
0005435682763	24584	Economy	17000.00
0005435438473	24584	Economy	17000.00
0005435682590	24584	Economy	17000.00
0005435682843	24584	Economy	17000.00
0005435682890	24584	Economy	17000.00
0005435438469	24584	Economy	17000.00
0005435220509	24584	Economy	17000.00
0005435682656	24584	Economy	17000.00
0005435682761	24584	Economy	17000.00
0005435220512	24584	Economy	17000.00
0005435720837	24584	Economy	17000.00
0005435661967	24584	Economy	17000.00
0005432533358	24584	Economy	17000.00
0005435682655	24584	Economy	17000.00
0005435219250	24584	Economy	17000.00
0005435682842	24584	Economy	17000.00
0005435438484	24584	Economy	17000.00
0005432305804	24584	Economy	17000.00
0005432305805	24584	Economy	17000.00
0005435682857	24584	Economy	17000.00
0005435682762	24584	Economy	17000.00
0005435682707	24584	Economy	17000.00
0005435438466	24584	Economy	17000.00
0005435682727	24584	Economy	17000.00
0005435438468	24584	Economy	17000.00
0005435220366	24584	Economy	17000.00
0005435661976	24584	Economy	17000.00
0005435438467	24584	Economy	17000.00
0005435719570	24584	Economy	17000.00
0005435438471	24584	Economy	17000.00
0005435220367	24584	Economy	17000.00
0005435219248	24584	Economy	17000.00
0005432533359	24584	Economy	17000.00
0005435682829	24584	Economy	17000.00
0005435682606	24584	Economy	17000.00
0005435682757	24584	Economy	17000.00
0005432305806	24584	Economy	17000.00
0005435682678	24584	Economy	17000.00
0005435719578	24584	Economy	17000.00
0005435438463	24584	Economy	17000.00
0005435438476	24584	Economy	17000.00
0005435219247	24584	Economy	17000.00
0005435438472	24584	Economy	17000.00
0005435682827	24584	Economy	17000.00
0005435661984	24584	Economy	17000.00
0005432533360	24584	Economy	17000.00
0005435220369	24584	Economy	17000.00
0005435682744	24584	Economy	17000.00
0005435438464	24584	Economy	17000.00
0005435682685	24584	Economy	17000.00
0005435682679	24584	Economy	17000.00
0005435438474	24584	Economy	17000.00
0005435127305	11532	Business	26400.00
0005435127295	11532	Business	26400.00
0005435127300	11532	Business	26400.00
0005435127289	11532	Business	26400.00
0005435558112	11532	Economy	8800.00
0005435127282	11532	Economy	8800.00
0005435127309	11532	Economy	8800.00
0005435558113	11532	Economy	8800.00
0005435127273	11532	Economy	8800.00
0005435127286	11532	Economy	8800.00
0005435127283	11532	Economy	8800.00
0005435127301	11532	Economy	9700.00
0005435127276	11532	Economy	8800.00
0005435127310	11532	Economy	8800.00
0005435127287	11532	Economy	8800.00
0005435106055	11532	Economy	8800.00
0005435127284	11532	Economy	8800.00
0005435127279	11532	Economy	8800.00
0005435127278	11532	Economy	8800.00
0005435558127	11532	Economy	8800.00
0005435127292	11532	Economy	8800.00
0005435106054	11532	Economy	8800.00
0005435127293	11532	Economy	8800.00
0005435127299	11532	Economy	8800.00
0005435127303	11532	Economy	8800.00
0005435127274	11532	Economy	8800.00
0005435127290	11532	Economy	8800.00
0005435127304	11532	Economy	8800.00
0005435127280	11532	Economy	8800.00
0005435127288	11532	Economy	8800.00
0005435127271	11532	Economy	8800.00
0005435127285	11532	Economy	8800.00
0005435127296	11532	Economy	8800.00
0005435106053	11532	Economy	8800.00
0005435127308	11532	Economy	8800.00
0005435127291	11532	Economy	8800.00
0005435127277	11532	Economy	8800.00
0005435127272	11532	Economy	8800.00
0005435127281	11532	Economy	8800.00
0005435127294	11532	Economy	8800.00
0005435127306	11532	Economy	8800.00
0005435127275	11532	Economy	8800.00
0005435127297	11532	Economy	8800.00
0005435127302	11532	Economy	8800.00
0005435127311	11532	Economy	8800.00
0005435127307	11532	Economy	8800.00
0005435127270	11532	Economy	8800.00
0005435127298	11532	Economy	8800.00
0005435558150	31890	Business	26400.00
0005435126931	31890	Business	26400.00
0005435126999	31890	Business	26400.00
0005435126888	31890	Business	26400.00
0005435126986	31890	Business	26400.00
0005435126952	31890	Economy	8800.00
0005435126932	31890	Economy	8800.00
0005435127109	31890	Economy	8800.00
0005435126963	31890	Economy	9700.00
0005435106033	31890	Economy	9700.00
0005435126882	31890	Economy	8800.00
0005435127067	31890	Economy	8800.00
0005435126925	31890	Economy	8800.00
0005435127190	31890	Economy	8800.00
0005435126962	31890	Economy	8800.00
0005435127023	31890	Economy	8800.00
0005435126924	31890	Economy	8800.00
0005435127071	31890	Economy	8800.00
0005435127055	31890	Economy	8800.00
0005435126889	31890	Economy	8800.00
0005435558149	31890	Economy	8800.00
0005435126881	31890	Economy	8800.00
0005435127003	31890	Economy	8800.00
0005435558148	31890	Economy	8800.00
0005435126850	31890	Economy	8800.00
0005435127068	31890	Economy	8800.00
0005435126928	31890	Economy	8800.00
0005435127022	31890	Economy	8800.00
0005435098583	31890	Economy	8800.00
0005435126927	31890	Economy	8800.00
0005435126947	31890	Economy	8800.00
0005435106032	31890	Economy	8800.00
0005433399168	13552	Business	36600.00
0005433399204	13552	Business	36600.00
0005433399190	13552	Business	36600.00
0005433399178	13552	Business	36600.00
0005433399212	13552	Business	36600.00
0005435732543	13552	Economy	12200.00
0005433399176	13552	Economy	12200.00
0005433399170	13552	Economy	12200.00
0005433399189	13552	Economy	12200.00
0005433399185	13552	Economy	12200.00
0005433399187	13552	Economy	12200.00
0005433399195	13552	Economy	13400.00
0005433399196	13552	Economy	13400.00
0005433399169	13552	Economy	12200.00
0005435732495	13552	Economy	12200.00
0005433399193	13552	Economy	12200.00
0005433399192	13552	Economy	12200.00
0005433399215	13552	Economy	12200.00
0005433399172	13552	Economy	12200.00
0005433399181	13552	Economy	12200.00
0005433399182	13552	Economy	12200.00
0005433399175	13552	Economy	12200.00
0005433399177	13552	Economy	12200.00
0005433399213	13552	Economy	12200.00
0005433399194	13552	Economy	12200.00
0005433399173	13552	Economy	12200.00
0005433399186	13552	Economy	12200.00
0005433399208	13552	Economy	12200.00
0005433399211	13552	Economy	12200.00
0005433399184	13552	Economy	12200.00
0005433399198	13552	Economy	12200.00
0005433399214	13552	Economy	12200.00
0005435732478	13552	Economy	12200.00
0005433399199	13552	Economy	12200.00
0005435732500	13552	Economy	12200.00
0005433399200	13552	Economy	12200.00
0005433399179	13552	Economy	12200.00
0005433399202	13552	Economy	12200.00
0005433399210	13552	Economy	12200.00
0005435732512	13552	Economy	12200.00
0005433399201	13552	Economy	12200.00
0005433399191	13552	Economy	12200.00
0005433399207	13552	Economy	12200.00
0005433399209	13552	Economy	12200.00
0005433399183	13552	Economy	12200.00
0005433399188	13552	Economy	12200.00
0005433399206	13552	Economy	12200.00
0005433399180	13552	Economy	12200.00
0005433399167	13552	Economy	12200.00
0005433399203	13552	Economy	12200.00
0005433399174	13552	Economy	12200.00
0005433399197	13552	Economy	12200.00
0005433399205	13552	Economy	12200.00
0005433399171	13552	Economy	12200.00
0005435732479	13552	Economy	12200.00
0005433398794	19419	Business	36600.00
0005435732633	19419	Business	36600.00
0005433398802	19419	Business	36600.00
0005433398841	19419	Business	36600.00
0005433398720	19419	Business	36600.00
0005435732630	19419	Business	36600.00
0005433398920	19419	Business	36600.00
0005433398918	19419	Business	36600.00
0005435732636	19419	Economy	12200.00
0005435732618	19419	Economy	12200.00
0005435732627	19419	Economy	12200.00
0005433398959	19419	Economy	12200.00
0005433398784	19419	Economy	12200.00
0005433398857	19419	Economy	12200.00
0005433398642	19419	Economy	12200.00
0005433398878	19419	Economy	13400.00
0005433398425	19419	Economy	13400.00
0005433398686	19419	Economy	13400.00
0005433398426	19419	Economy	13400.00
0005433398625	19419	Economy	13400.00
0005433398869	19419	Economy	12200.00
0005433398921	19419	Economy	12200.00
0005435732634	19419	Economy	12200.00
0005435732617	19419	Economy	12200.00
0005433398801	19419	Economy	12200.00
0005435732625	19419	Economy	12200.00
0005433398722	19419	Economy	12200.00
0005435732623	19419	Economy	12200.00
0005435732621	19419	Economy	12200.00
0005433398694	19419	Economy	12200.00
0005435732616	19419	Economy	12200.00
0005433398844	19419	Economy	12200.00
0005435732629	19419	Economy	12200.00
0005433398843	19419	Economy	12200.00
0005433398695	19419	Economy	12200.00
0005435732624	19419	Economy	12200.00
0005432297339	19419	Economy	12200.00
0005433398800	19419	Economy	12200.00
0005433398634	19419	Economy	12200.00
0005433399015	19419	Economy	12200.00
0005433398922	19419	Economy	12200.00
0005433398627	19419	Economy	12200.00
0005435732635	19419	Economy	12200.00
0005435732626	19419	Economy	12200.00
0005433398718	19419	Economy	12200.00
0005435732619	19419	Economy	12200.00
0005433398727	19419	Economy	12200.00
0005433398960	19419	Economy	12200.00
0005435732631	19419	Economy	12200.00
0005433398725	19419	Economy	12200.00
0005433398806	19419	Economy	12200.00
0005433398810	19419	Economy	12200.00
0005435732628	19419	Economy	12200.00
0005433398896	19419	Economy	12200.00
0005433398673	19419	Economy	12200.00
0005432297340	19419	Economy	12200.00
0005433398819	19419	Economy	12200.00
0005435732632	19419	Economy	12200.00
0005433398763	19419	Economy	12200.00
0005433398471	19419	Economy	12200.00
0005432297338	19419	Economy	12200.00
0005433398842	19419	Economy	12200.00
0005435732620	19419	Economy	12200.00
0005435732622	19419	Economy	12200.00
0005433398762	19419	Economy	12200.00
0005433398807	19419	Economy	12200.00
0005435925620	13154	Business	11300.00
0005435069811	13154	Business	11300.00
0005435069759	13154	Business	11300.00
0005435925616	13154	Business	11300.00
0005435925603	13154	Business	11300.00
0005435069810	13154	Business	11300.00
0005435069939	13154	Business	11300.00
0005435069659	13154	Economy	3800.00
0005435925617	13154	Economy	3800.00
0005435069685	13154	Economy	3800.00
0005435069943	13154	Economy	3800.00
0005435925607	13154	Economy	3800.00
0005435069761	13154	Economy	3800.00
0005435069996	13154	Economy	3800.00
0005435069889	13154	Economy	3800.00
0005435925606	13154	Economy	3800.00
0005435069712	13154	Economy	4100.00
0005435069629	13154	Economy	4100.00
0005435069893	13154	Economy	4100.00
0005435925629	13154	Economy	3800.00
0005435925608	13154	Economy	3800.00
0005435069947	13154	Economy	3800.00
0005435925612	13154	Economy	3800.00
0005435069888	13154	Economy	3800.00
0005435925602	13154	Economy	3800.00
0005435925614	13154	Economy	3800.00
0005435069709	13154	Economy	3800.00
0005435925624	13154	Economy	3800.00
0005435069698	13154	Economy	3800.00
0005435925610	13154	Economy	3800.00
0005435069905	13154	Economy	3800.00
0005435069758	13154	Economy	3800.00
0005435925618	13154	Economy	3800.00
0005435069646	13154	Economy	3800.00
0005435925621	13154	Economy	3800.00
0005435925601	13154	Economy	3800.00
0005435925622	13154	Economy	3800.00
0005435069792	13154	Economy	3800.00
0005435925626	13154	Economy	3800.00
0005435069737	13154	Economy	3800.00
0005435069926	13154	Economy	3800.00
0005435069832	13154	Economy	3800.00
0005435925619	13154	Economy	3800.00
0005435925615	13154	Economy	3800.00
0005435069684	13154	Economy	3800.00
0005435925625	13154	Economy	3800.00
0005435069942	13154	Economy	3800.00
0005435069877	13154	Economy	3800.00
0005435069746	13154	Economy	3800.00
0005435925605	13154	Economy	3800.00
0005435925604	13154	Economy	3800.00
0005435925627	13154	Economy	3800.00
0005435069628	13154	Economy	3800.00
0005435069769	13154	Economy	3800.00
0005435069716	13154	Economy	3800.00
0005435069754	13154	Economy	3800.00
0005435925611	13154	Economy	3800.00
0005435069892	13154	Economy	3800.00
0005435069713	13154	Economy	3800.00
0005435925628	13154	Economy	3800.00
0005435069627	13154	Economy	3800.00
0005435069864	13154	Economy	3800.00
0005435925613	13154	Economy	3800.00
0005435069703	13154	Economy	3800.00
0005435069657	13154	Economy	3800.00
0005435069714	13154	Economy	3800.00
0005435069896	13154	Economy	3800.00
0005435069812	13154	Economy	3800.00
0005435069983	13154	Economy	3800.00
0005435925623	13154	Economy	3800.00
0005435925609	13154	Economy	3800.00
0005435069589	13154	Economy	3800.00
0005435069472	13154	Economy	3800.00
0005435069946	13154	Economy	3800.00
0005435069940	13154	Economy	3800.00
0005435069658	13154	Economy	3800.00
0005435070249	15480	Business	11300.00
0005435070244	15480	Business	11300.00
0005435070253	15480	Business	11300.00
0005435070240	15480	Business	11300.00
0005435925483	15480	Business	11300.00
0005435070232	15480	Business	11300.00
0005435925427	15480	Business	11300.00
0005435070261	15480	Economy	3800.00
0005435070271	15480	Economy	3800.00
0005435925488	15480	Economy	3800.00
0005435070264	15480	Economy	3800.00
0005435070233	15480	Economy	3800.00
0005435070250	15480	Economy	3800.00
0005435925412	15480	Economy	3800.00
0005435070231	15480	Economy	4100.00
0005435925482	15480	Economy	4100.00
0005435070242	15480	Economy	3800.00
0005435925473	15480	Economy	3800.00
0005435070248	15480	Economy	3800.00
0005435070226	15480	Economy	3800.00
0005435070265	15480	Economy	3800.00
0005435070251	15480	Economy	3800.00
0005435925476	15480	Economy	3800.00
0005435070255	15480	Economy	3800.00
0005435925462	15480	Economy	3800.00
0005435070267	15480	Economy	3800.00
0005435070234	15480	Economy	3800.00
0005435070254	15480	Economy	3800.00
0005435070275	15480	Economy	3800.00
0005435925467	15480	Economy	3800.00
0005435070237	15480	Economy	3800.00
0005435070269	15480	Economy	3800.00
0005435070262	15480	Economy	3800.00
0005435070273	15480	Economy	3800.00
0005435070227	15480	Economy	3800.00
0005435070246	15480	Economy	3800.00
0005435070238	15480	Economy	3800.00
0005435070266	15480	Economy	3800.00
0005435070270	15480	Economy	3800.00
0005435070245	15480	Economy	3800.00
0005435070260	15480	Economy	3800.00
0005435070229	15480	Economy	3800.00
0005435070259	15480	Economy	3800.00
0005435070225	15480	Economy	3800.00
0005435070247	15480	Economy	3800.00
0005435070230	15480	Economy	3800.00
0005435070268	15480	Economy	3800.00
0005435070235	15480	Economy	3800.00
0005435070241	15480	Economy	3800.00
0005435925474	15480	Economy	3800.00
0005435070257	15480	Economy	3800.00
0005435070256	15480	Economy	3800.00
0005435070236	15480	Economy	3800.00
0005435925463	15480	Economy	3800.00
0005435070274	15480	Economy	3800.00
0005435070252	15480	Economy	3800.00
0005435070243	15480	Economy	3800.00
0005435070263	15480	Economy	3800.00
0005435070224	15480	Economy	3800.00
0005435925461	15480	Economy	3800.00
0005435070258	15480	Economy	3800.00
0005435925478	15480	Economy	3800.00
0005435070228	15480	Economy	3800.00
0005435070239	15480	Economy	3800.00
0005435925489	15480	Economy	3800.00
0005435070272	15480	Economy	3800.00
0005435925441	15480	Economy	3800.00
0005434757147	10697	Business	61300.00
0005434215602	10697	Business	61300.00
0005434215618	10697	Business	61300.00
0005434215636	10697	Business	61300.00
0005434215611	10697	Business	61300.00
0005434757052	10697	Business	61300.00
0005434756853	10697	Business	61300.00
0005434215615	10697	Business	61300.00
0005434215645	10697	Business	61300.00
0005434756980	10697	Business	61300.00
0005434757067	10697	Economy	20400.00
0005434215647	10697	Economy	20400.00
0005434756916	10697	Economy	20400.00
0005434215640	10697	Economy	20400.00
0005434756873	10697	Economy	20400.00
0005434757119	10697	Economy	20400.00
0005434215644	10697	Economy	20400.00
0005434215628	10697	Economy	20400.00
0005434756898	10697	Economy	20400.00
0005434756942	10697	Economy	20400.00
0005434215607	10697	Economy	22500.00
0005434756971	10697	Economy	22500.00
0005434215629	10697	Economy	22500.00
0005434215604	10697	Economy	22500.00
0005434756963	10697	Economy	22500.00
0005434215614	10697	Economy	20400.00
0005434215637	10697	Economy	20400.00
0005434215613	10697	Economy	20400.00
0005434757090	10697	Economy	20400.00
0005434215641	10697	Economy	20400.00
0005434757011	10697	Economy	20400.00
0005434215601	10697	Economy	20400.00
0005434757024	10697	Economy	20400.00
0005434756974	10697	Economy	20400.00
0005434215635	10697	Economy	20400.00
0005434215609	10697	Economy	20400.00
0005434756995	10697	Economy	20400.00
0005434215608	10697	Economy	20400.00
0005434215642	10697	Economy	20400.00
0005434215605	10697	Economy	20400.00
0005434757120	10697	Economy	20400.00
0005434757023	10697	Economy	20400.00
0005434756822	10697	Economy	20400.00
0005434215612	10697	Economy	20400.00
0005434756973	10697	Economy	20400.00
0005434215638	10697	Economy	20400.00
0005434757010	10697	Economy	20400.00
0005434215619	10697	Economy	20400.00
0005434215627	10697	Economy	20400.00
0005434215622	10697	Economy	20400.00
0005434215621	10697	Economy	20400.00
0005434756959	10697	Economy	20400.00
0005434215643	10697	Economy	20400.00
0005434215631	10697	Economy	20400.00
0005434756943	10697	Economy	20400.00
0005434756958	10697	Economy	20400.00
0005434215633	10697	Economy	20400.00
0005434757066	10697	Economy	20400.00
0005434757149	10697	Economy	20400.00
0005434215610	10697	Economy	20400.00
0005434215646	10697	Economy	20400.00
0005434215617	10697	Economy	20400.00
0005434756962	10697	Economy	20400.00
0005434215623	10697	Economy	20400.00
0005434215630	10697	Economy	20400.00
0005434215620	10697	Economy	20400.00
0005434215624	10697	Economy	20400.00
0005434215632	10697	Economy	20400.00
0005434756847	10697	Economy	20400.00
0005434215625	10697	Economy	20400.00
0005434215626	10697	Economy	20400.00
0005434756928	10697	Economy	20400.00
0005434756970	10697	Economy	20400.00
0005434215606	10697	Economy	20400.00
0005434756915	10697	Economy	20400.00
0005434215603	10697	Economy	20400.00
0005434757007	10697	Economy	20400.00
0005434215634	10697	Economy	20400.00
0005434215616	10697	Economy	20400.00
0005434215639	10697	Economy	20400.00
0005434757374	28677	Business	61300.00
0005434215222	28677	Business	61300.00
0005434757361	28677	Business	61300.00
0005434757340	28677	Business	61300.00
0005434757379	28677	Business	61300.00
0005434757359	28677	Business	61300.00
0005434215293	28677	Business	61300.00
0005434215263	28677	Business	61300.00
0005434215097	28677	Business	61300.00
0005434757370	28677	Business	61300.00
0005434757360	28677	Business	61300.00
0005434757358	28677	Business	61300.00
0005434757346	28677	Economy	20400.00
0005434757348	28677	Economy	20400.00
0005434215074	28677	Economy	20400.00
0005434215218	28677	Economy	20400.00
0005434757377	28677	Economy	20400.00
0005434215264	28677	Economy	20400.00
0005434215162	28677	Economy	20400.00
0005434757375	28677	Economy	20400.00
0005434757347	28677	Economy	20400.00
0005434215196	28677	Economy	20400.00
0005434757365	28677	Economy	22500.00
0005434215082	28677	Economy	22500.00
0005434757355	28677	Economy	22500.00
0005434757343	28677	Economy	22500.00
0005434215144	28677	Economy	22500.00
0005434215172	28677	Economy	20400.00
0005434215045	28677	Economy	20400.00
0005434757378	28677	Economy	20400.00
0005434215161	28677	Economy	20400.00
0005434215108	28677	Economy	20400.00
0005434757363	28677	Economy	20400.00
0005434757372	28677	Economy	20400.00
0005434757373	28677	Economy	20400.00
0005434757364	28677	Economy	20400.00
0005434757376	28677	Economy	20400.00
0005434215016	28677	Economy	20400.00
0005434215111	28677	Economy	20400.00
0005434215197	28677	Economy	20400.00
0005434757357	28677	Economy	20400.00
0005434215207	28677	Economy	20400.00
0005434215310	28677	Economy	20400.00
0005434757354	28677	Economy	20400.00
0005434215146	28677	Economy	20400.00
0005434215154	28677	Economy	20400.00
0005434757380	28677	Economy	20400.00
0005434215160	28677	Economy	20400.00
0005434757342	28677	Economy	20400.00
0005434757339	28677	Economy	20400.00
0005434215206	28677	Economy	20400.00
0005434215363	28677	Economy	20400.00
0005434215183	28677	Economy	20400.00
0005434214967	28677	Economy	20400.00
0005434215178	28677	Economy	20400.00
0005434757371	28677	Economy	20400.00
0005434757367	28677	Economy	20400.00
0005434757369	28677	Economy	20400.00
0005434757341	28677	Economy	20400.00
0005434214946	28677	Economy	20400.00
0005434215115	28677	Economy	20400.00
0005434214968	28677	Economy	20400.00
0005434215304	28677	Economy	20400.00
0005434215262	28677	Economy	20400.00
0005434215098	28677	Economy	20400.00
0005434215345	28677	Economy	20400.00
0005434215175	28677	Economy	20400.00
0005434757366	28677	Economy	20400.00
0005434757350	28677	Economy	20400.00
0005434757381	28677	Economy	20400.00
0005434757356	28677	Economy	20400.00
0005434215147	28677	Economy	20400.00
0005434215182	28677	Economy	20400.00
0005434215142	28677	Economy	20400.00
0005434757349	28677	Economy	20400.00
0005434757362	28677	Economy	20400.00
0005434757344	28677	Economy	20400.00
0005434757382	28677	Economy	20400.00
0005434215184	28677	Economy	20400.00
0005434215052	28677	Economy	20400.00
0005434215288	28677	Economy	20400.00
0005434215186	28677	Economy	20400.00
0005434757345	28677	Economy	20400.00
0005434757383	28677	Economy	20400.00
0005434757352	28677	Economy	20400.00
0005434215110	28677	Economy	20400.00
0005434757351	28677	Economy	20400.00
0005434215066	28677	Economy	20400.00
0005434214945	28677	Economy	20400.00
0005434214966	28677	Economy	20400.00
0005434757353	28677	Economy	20400.00
0005434215235	28677	Economy	20400.00
0005434215292	28677	Economy	20400.00
0005434757338	28677	Economy	20400.00
0005434757368	28677	Economy	20400.00
0005434215153	28677	Economy	20400.00
0005435041270	5438	Business	29500.00
0005434229686	5438	Business	29500.00
0005435041294	5438	Business	29500.00
0005435041261	5438	Business	29500.00
0005435007567	5438	Business	29500.00
0005435041319	5438	Business	29500.00
0005435041267	5438	Business	29500.00
0005435041269	5438	Business	29500.00
0005435041259	5438	Business	29500.00
0005435007582	5438	Business	29500.00
0005432125624	5438	Business	29500.00
0005432125621	5438	Business	29500.00
0005435041284	5438	Economy	9800.00
0005434229687	5438	Economy	9800.00
0005434229772	5438	Economy	9800.00
0005435041289	5438	Economy	9800.00
0005435041317	5438	Economy	9800.00
0005435041296	5438	Economy	9800.00
0005435041275	5438	Economy	9800.00
0005435041285	5438	Economy	9800.00
0005432125625	5438	Economy	9800.00
0005435041279	5438	Economy	9800.00
0005434229749	5438	Economy	9800.00
0005435041282	5438	Economy	9800.00
0005435041265	5438	Economy	9800.00
0005435041288	5438	Economy	9800.00
0005435041309	5438	Economy	9800.00
0005435041287	5438	Economy	9800.00
0005435007585	5438	Economy	9800.00
0005435041273	5438	Economy	9800.00
0005432125623	5438	Economy	9800.00
0005435041305	5438	Economy	9800.00
0005435041277	5438	Economy	9800.00
0005435041304	5438	Economy	9800.00
0005434229663	5438	Economy	9800.00
0005435007580	5438	Economy	9800.00
0005435042913	5438	Economy	9800.00
0005435041281	5438	Economy	9800.00
0005435007579	5438	Economy	9800.00
0005434229715	5438	Economy	9800.00
0005435007573	5438	Economy	9800.00
0005434229771	5438	Economy	9800.00
0005435041295	5438	Economy	9800.00
0005435007571	5438	Economy	9800.00
0005435041292	5438	Economy	9800.00
0005432125628	5438	Economy	9800.00
0005435007569	5438	Economy	9800.00
0005435007568	5438	Economy	9800.00
0005435041293	5438	Economy	9800.00
0005435007572	5438	Economy	10800.00
0005435043302	5438	Economy	10800.00
0005435041274	5438	Economy	10800.00
0005435007584	5438	Economy	10800.00
0005435041300	5438	Economy	10800.00
0005435041291	5438	Economy	10800.00
0005435041299	5438	Economy	9800.00
0005435041264	5438	Economy	9800.00
0005435042912	5438	Economy	9800.00
0005434229597	5438	Economy	9800.00
0005435041263	5438	Economy	9800.00
0005435007566	5438	Economy	9800.00
0005435041307	5438	Economy	9800.00
0005435041316	5438	Economy	9800.00
0005435041311	5438	Economy	9800.00
0005435041321	5438	Economy	9800.00
0005435041323	5438	Economy	9800.00
0005435041303	5438	Economy	9800.00
0005434229750	5438	Economy	9800.00
0005432125626	5438	Economy	9800.00
0005435007587	5438	Economy	9800.00
0005435041314	5438	Economy	9800.00
0005435041290	5438	Economy	9800.00
0005435007564	5438	Economy	9800.00
0005434229679	5438	Economy	9800.00
0005435043303	5438	Economy	9800.00
0005435041297	5438	Economy	9800.00
0005435041318	5438	Economy	9800.00
0005434229770	5438	Economy	9800.00
0005435007570	5438	Economy	9800.00
0005435041298	5438	Economy	9800.00
0005435041271	5438	Economy	9800.00
0005435007576	5438	Economy	9800.00
0005434229769	5438	Economy	9800.00
0005435042916	5438	Economy	9800.00
0005435041313	5438	Economy	9800.00
0005435041268	5438	Economy	9800.00
0005435041308	5438	Economy	9800.00
0005432125622	5438	Economy	9800.00
0005435041322	5438	Economy	9800.00
0005435041278	5438	Economy	9800.00
0005435041306	5438	Economy	9800.00
0005435041272	5438	Economy	9800.00
0005435007574	5438	Economy	9800.00
0005434229648	5438	Economy	9800.00
0005435041286	5438	Economy	9800.00
0005435007578	5438	Economy	9800.00
0005435041276	5438	Economy	9800.00
0005435007583	5438	Economy	9800.00
0005435041260	5438	Economy	9800.00
0005435041320	5438	Economy	9800.00
0005435041312	5438	Economy	9800.00
0005435041302	5438	Economy	9800.00
0005435041315	5438	Economy	9800.00
0005435041301	5438	Economy	9800.00
0005435041283	5438	Economy	9800.00
0005435041258	5438	Economy	9800.00
0005435042914	5438	Economy	9800.00
0005434229711	5438	Economy	9800.00
0005435041262	5438	Economy	9800.00
0005435041280	5438	Economy	9800.00
0005434229678	5438	Economy	9800.00
0005435041310	5438	Economy	9800.00
0005435007565	5438	Economy	9800.00
0005435007577	5438	Economy	9800.00
0005434229768	5438	Economy	9800.00
0005435007586	5438	Economy	9800.00
0005435007588	5438	Economy	9800.00
0005435007575	5438	Economy	9800.00
0005435041266	5438	Economy	9800.00
0005432125627	5438	Economy	9800.00
0005435042915	5438	Economy	9800.00
0005435007581	5438	Economy	9800.00
0005435377922	12978	Business	29500.00
0005435007450	12978	Business	29500.00
0005435040797	12978	Business	29500.00
0005435040827	12978	Business	29500.00
0005435040927	12978	Business	29500.00
0005435040742	12978	Business	29500.00
0005435007404	12978	Business	29500.00
0005432304488	12978	Business	29500.00
0005435040850	12978	Business	29500.00
0005435040734	12978	Business	29500.00
0005434229908	12978	Business	29500.00
0005435040892	12978	Business	29500.00
0005434229894	12978	Economy	9800.00
0005435007395	12978	Economy	9800.00
0005435040766	12978	Economy	9800.00
0005432304489	12978	Economy	9800.00
0005435042889	12978	Economy	9800.00
0005435040545	12978	Economy	9800.00
0005435007307	12978	Economy	9800.00
0005435040665	12978	Economy	9800.00
0005435040938	12978	Economy	9800.00
0005435007489	12978	Economy	9800.00
0005434229911	12978	Economy	9800.00
0005435040599	12978	Economy	9800.00
0005432304491	12978	Economy	9800.00
0005434229905	12978	Economy	9800.00
0005434229912	12978	Economy	9800.00
0005435040644	12978	Economy	9800.00
0005435007401	12978	Economy	9800.00
0005435040728	12978	Economy	9800.00
0005434229896	12978	Economy	9800.00
0005434229901	12978	Economy	9800.00
0005435040695	12978	Economy	9800.00
0005435007254	12978	Economy	9800.00
0005435040586	12978	Economy	9800.00
0005435040703	12978	Economy	9800.00
0005435040531	12978	Economy	9800.00
0005434229909	12978	Economy	9800.00
0005434229892	12978	Economy	9800.00
0005435377921	12978	Economy	9800.00
0005435040837	12978	Economy	9800.00
0005435040810	12978	Economy	9800.00
0005435040767	12978	Economy	9800.00
0005435040743	12978	Economy	9800.00
0005435007292	12978	Economy	9800.00
0005434229898	12978	Economy	9800.00
0005434229897	12978	Economy	9800.00
0005435007414	12978	Economy	9800.00
0005434229906	12978	Economy	10800.00
0005435007393	12978	Economy	10800.00
0005435007333	12978	Economy	10800.00
0005434229913	12978	Economy	10800.00
0005434229914	12978	Economy	10800.00
0005435377923	12978	Economy	10800.00
0005435040732	12978	Economy	9800.00
0005435040661	12978	Economy	9800.00
0005434229904	12978	Economy	9800.00
0005435040812	12978	Economy	9800.00
0005434229910	12978	Economy	9800.00
0005435040689	12978	Economy	9800.00
0005435007439	12978	Economy	9800.00
0005435040731	12978	Economy	9800.00
0005435377925	12978	Economy	9800.00
0005435040730	12978	Economy	9800.00
0005435040666	12978	Economy	9800.00
0005435040660	12978	Economy	9800.00
0005434229895	12978	Economy	9800.00
0005434229899	12978	Economy	9800.00
0005435040928	12978	Economy	9800.00
0005435042897	12978	Economy	9800.00
0005435007392	12978	Economy	9800.00
0005435007344	12978	Economy	9800.00
0005434229891	12978	Economy	9800.00
0005435042887	12978	Economy	9800.00
0005435040612	12978	Economy	9800.00
0005435007409	12978	Economy	9800.00
0005435040563	12978	Economy	9800.00
0005435040704	12978	Economy	9800.00
0005435040678	12978	Economy	9800.00
0005434229903	12978	Economy	9800.00
0005435040854	12978	Economy	9800.00
0005435040441	12978	Economy	9800.00
0005435040836	12978	Economy	9800.00
0005435007400	12978	Economy	9800.00
0005435007413	12978	Economy	9800.00
0005435040733	12978	Economy	9800.00
0005435007396	12978	Economy	9800.00
0005435377924	12978	Economy	9800.00
0005435040919	12978	Economy	9800.00
0005435040585	12978	Economy	9800.00
0005435040552	12978	Economy	9800.00
0005435007345	12978	Economy	9800.00
0005435040729	12978	Economy	9800.00
0005435040466	12978	Economy	9800.00
0005435040593	12978	Economy	9800.00
0005435040587	12978	Economy	9800.00
0005435040562	12978	Economy	9800.00
0005434229893	12978	Economy	9800.00
0005435040891	12978	Economy	9800.00
0005435007399	12978	Economy	9800.00
0005434229900	12978	Economy	9800.00
0005435040936	12978	Economy	9800.00
0005435040530	12978	Economy	9800.00
0005435040859	12978	Economy	9800.00
0005435040796	12978	Economy	9800.00
0005435007394	12978	Economy	9800.00
0005435040716	12978	Economy	9800.00
0005434229907	12978	Economy	9800.00
0005434229902	12978	Economy	9800.00
0005435007488	12978	Economy	9800.00
0005435040462	12978	Economy	9800.00
0005435007343	12978	Economy	9800.00
0005435042888	12978	Economy	9800.00
0005435007291	12978	Economy	9800.00
0005435040613	12978	Economy	9800.00
0005432304490	12978	Economy	9800.00
0005435040569	12978	Economy	9800.00
0005435040705	12978	Economy	9800.00
0005435040696	12978	Economy	9800.00
0005435042886	12978	Economy	9800.00
0005435040750	12978	Economy	9800.00
0005435007369	12978	Economy	9800.00
0005435040679	12978	Economy	9800.00
0005435007410	12978	Economy	9800.00
0005434427283	14879	Business	52900.00
0005434427267	14879	Business	52900.00
0005435902912	14879	Business	52900.00
0005434427286	14879	Business	52900.00
0005435902913	14879	Business	52900.00
0005434427271	14879	Business	52900.00
0005435902989	14879	Business	52900.00
0005434427263	14879	Business	52900.00
0005434427266	14879	Business	52900.00
0005434427278	14879	Economy	17600.00
0005434411876	14879	Economy	17600.00
0005434427282	14879	Economy	17600.00
0005434411878	14879	Economy	17600.00
0005432188680	14879	Economy	17600.00
0005435903032	14879	Economy	19400.00
0005434427280	14879	Economy	19400.00
0005434427268	14879	Economy	19400.00
0005434427285	14879	Economy	19400.00
0005434427261	14879	Economy	19400.00
0005435902979	14879	Economy	17600.00
0005434427279	14879	Economy	17600.00
0005435902945	14879	Economy	17600.00
0005434427272	14879	Economy	17600.00
0005435902990	14879	Economy	17600.00
0005435902895	14879	Economy	17600.00
0005434427287	14879	Economy	17600.00
0005435903005	14879	Economy	17600.00
0005435902896	14879	Economy	17600.00
0005434427284	14879	Economy	17600.00
0005434427260	14879	Economy	17600.00
0005435554267	14879	Economy	17600.00
0005434427281	14879	Economy	17600.00
0005435903036	14879	Economy	17600.00
0005435554243	14879	Economy	17600.00
0005435903006	14879	Economy	17600.00
0005435554244	14879	Economy	17600.00
0005434411877	14879	Economy	17600.00
0005432188681	14879	Economy	17600.00
0005434427277	14879	Economy	17600.00
0005434427288	14879	Economy	17600.00
0005435554265	14879	Economy	17600.00
0005434427269	14879	Economy	17600.00
0005434427262	14879	Economy	17600.00
0005434427274	14879	Economy	17600.00
0005435554248	14879	Economy	17600.00
0005435902897	14879	Economy	17600.00
0005434427275	14879	Economy	17600.00
0005434427276	14879	Economy	17600.00
0005435902887	14879	Economy	17600.00
0005435554268	14879	Economy	17600.00
0005435554266	14879	Economy	17600.00
0005435554247	14879	Economy	17600.00
0005434427273	14879	Economy	17600.00
0005434411874	14879	Economy	17600.00
0005435903037	14879	Economy	17600.00
0005434427264	14879	Economy	17600.00
0005435902888	14879	Economy	17600.00
0005435902967	14879	Economy	17600.00
0005435902934	14879	Economy	17600.00
0005434427265	14879	Economy	17600.00
0005434411875	14879	Economy	17600.00
0005432188682	14879	Economy	17600.00
0005434427270	14879	Economy	17600.00
0005434426871	20236	Business	52900.00
0005434426962	20236	Business	52900.00
0005434427092	20236	Business	52900.00
0005435903126	20236	Business	52900.00
0005435903117	20236	Business	52900.00
0005434411853	20236	Economy	17600.00
0005435554305	20236	Economy	17600.00
0005434427090	20236	Economy	17600.00
0005434411848	20236	Economy	17600.00
0005435554304	20236	Economy	19400.00
0005435903125	20236	Economy	19400.00
0005435554300	20236	Economy	19400.00
0005435903124	20236	Economy	17600.00
0005434426969	20236	Economy	17600.00
0005434426872	20236	Economy	17600.00
0005434411837	20236	Economy	17600.00
0005435903127	20236	Economy	17600.00
0005434426974	20236	Economy	17600.00
0005435903123	20236	Economy	17600.00
0005435554302	20236	Economy	17600.00
0005435903118	20236	Economy	17600.00
0005435903120	20236	Economy	17600.00
0005435903128	20236	Economy	17600.00
0005434427117	20236	Economy	17600.00
0005434426973	20236	Economy	17600.00
0005434427044	20236	Economy	17600.00
0005434427000	20236	Economy	17600.00
0005434411849	20236	Economy	17600.00
0005435903116	20236	Economy	17600.00
0005434427055	20236	Economy	17600.00
0005435903114	20236	Economy	17600.00
0005435903122	20236	Economy	17600.00
0005434427129	20236	Economy	17600.00
0005434427089	20236	Economy	17600.00
0005435554301	20236	Economy	17600.00
0005434427086	20236	Economy	17600.00
0005435554303	20236	Economy	17600.00
0005434427121	20236	Economy	17600.00
0005435903115	20236	Economy	17600.00
0005435903129	20236	Economy	17600.00
0005434427091	20236	Economy	17600.00
0005435903119	20236	Economy	17600.00
0005435903121	20236	Economy	17600.00
0005435903113	20236	Economy	17600.00
0005434427060	20236	Economy	17600.00
0005432059552	20236	Economy	17600.00
0005435983327	26512	Business	18500.00
0005435983307	26512	Business	18500.00
0005435983326	26512	Business	18500.00
0005435983309	26512	Business	18500.00
0005435983342	26512	Business	18500.00
0005432300395	26512	Business	18500.00
0005433434996	26512	Business	18500.00
0005433435130	26512	Business	18500.00
0005435983334	26512	Business	18500.00
0005435983315	26512	Economy	6200.00
0005435983341	26512	Economy	6200.00
0005435983323	26512	Economy	6200.00
0005435983318	26512	Economy	6200.00
0005433435062	26512	Economy	6200.00
0005435983325	26512	Economy	6200.00
0005435983303	26512	Economy	6200.00
0005432300397	26512	Economy	6800.00
0005435983299	26512	Economy	6800.00
0005435983300	26512	Economy	6800.00
0005433435063	26512	Economy	6800.00
0005432300394	26512	Economy	6800.00
0005432300398	26512	Economy	6200.00
0005435983328	26512	Economy	6200.00
0005435983339	26512	Economy	6200.00
0005435983335	26512	Economy	6200.00
0005433435073	26512	Economy	6200.00
0005435983312	26512	Economy	6200.00
0005433435104	26512	Economy	6200.00
0005435983297	26512	Economy	6200.00
0005435983294	26512	Economy	6200.00
0005433435072	26512	Economy	6200.00
0005435983330	26512	Economy	6200.00
0005433435035	26512	Economy	6200.00
0005434273099	26512	Economy	6200.00
0005434273100	26512	Economy	6200.00
0005433435005	26512	Economy	6200.00
0005435983332	26512	Economy	6200.00
0005435983340	26512	Economy	6200.00
0005435983329	26512	Economy	6200.00
0005433434935	26512	Economy	6200.00
0005435983333	26512	Economy	6200.00
0005435983313	26512	Economy	6200.00
0005434270243	26512	Economy	6200.00
0005433435111	26512	Economy	6200.00
0005435983324	26512	Economy	6200.00
0005433435114	26512	Economy	6200.00
0005435983306	26512	Economy	6200.00
0005435983292	26512	Economy	6200.00
0005435983320	26512	Economy	6200.00
0005435983316	26512	Economy	6200.00
0005435983319	26512	Economy	6200.00
0005435983305	26512	Economy	6200.00
0005433435097	26512	Economy	6200.00
0005433435121	26512	Economy	6200.00
0005435983301	26512	Economy	6200.00
0005432300396	26512	Economy	6200.00
0005435983298	26512	Economy	6200.00
0005435983322	26512	Economy	6200.00
0005435983314	26512	Economy	6200.00
0005433435006	26512	Economy	6200.00
0005435983321	26512	Economy	6200.00
0005435983310	26512	Economy	6200.00
0005435983293	26512	Economy	6200.00
0005434270244	26512	Economy	6200.00
0005435983304	26512	Economy	6200.00
0005435983317	26512	Economy	6200.00
0005433435103	26512	Economy	6200.00
0005435983302	26512	Economy	6200.00
0005435983311	26512	Economy	6200.00
0005433435075	26512	Economy	6200.00
0005435983295	26512	Economy	6200.00
0005435983338	26512	Economy	6200.00
0005433435002	26512	Economy	6200.00
0005435983331	26512	Economy	6200.00
0005435983296	26512	Economy	6200.00
0005435983308	26512	Economy	6200.00
0005435983336	26512	Economy	6200.00
0005435983337	26512	Economy	6200.00
0005433434995	26512	Economy	6200.00
0005433435175	26512	Economy	6200.00
0005435983291	26512	Economy	6200.00
0005433435352	26734	Business	18500.00
0005435983011	26734	Business	18500.00
0005435982953	26734	Business	18500.00
0005435982889	26734	Business	18500.00
0005435983148	26734	Business	18500.00
0005433435355	26734	Business	18500.00
0005433435331	26734	Business	18500.00
0005435982978	26734	Business	18500.00
0005435983013	26734	Business	18500.00
0005435983036	26734	Business	18500.00
0005433435341	26734	Business	18500.00
0005435982783	26734	Business	18500.00
0005433435346	26734	Economy	6200.00
0005435983005	26734	Economy	6200.00
0005434269151	26734	Economy	6200.00
0005435982875	26734	Economy	6200.00
0005435983057	26734	Economy	6200.00
0005433435342	26734	Economy	6200.00
0005435982928	26734	Economy	6200.00
0005435982868	26734	Economy	6200.00
0005435982933	26734	Economy	6200.00
0005435983058	26734	Economy	6800.00
0005435983047	26734	Economy	6800.00
0005435982984	26734	Economy	6800.00
0005435982961	26734	Economy	6800.00
0005435982985	26734	Economy	6800.00
0005433435332	26734	Economy	6200.00
0005435982874	26734	Economy	6200.00
0005435982996	26734	Economy	6200.00
0005435982969	26734	Economy	6200.00
0005433435353	26734	Economy	6200.00
0005435982929	26734	Economy	6200.00
0005435982876	26734	Economy	6200.00
0005435982951	26734	Economy	6200.00
0005435983149	26734	Economy	6200.00
0005433435354	26734	Economy	6200.00
0005432051203	26734	Economy	6200.00
0005435982983	26734	Economy	6200.00
0005435983020	26734	Economy	6200.00
0005433435345	26734	Economy	6200.00
0005435982872	26734	Economy	6200.00
0005435982865	26734	Economy	6200.00
0005435982897	26734	Economy	6200.00
0005433435329	26734	Economy	6200.00
0005433435340	26734	Economy	6200.00
0005433435343	26734	Economy	6200.00
0005435982873	26734	Economy	6200.00
0005435982991	26734	Economy	6200.00
0005433435335	26734	Economy	6200.00
0005435982820	26734	Economy	6200.00
0005433435333	26734	Economy	6200.00
0005435982947	26734	Economy	6200.00
0005433435338	26734	Economy	6200.00
0005432051204	26734	Economy	6200.00
0005435982962	26734	Economy	6200.00
0005435982883	26734	Economy	6200.00
0005435982736	26734	Economy	6200.00
0005435982861	26734	Economy	6200.00
0005435983014	26734	Economy	6200.00
0005435983000	26734	Economy	6200.00
0005433435350	26734	Economy	6200.00
0005433435334	26734	Economy	6200.00
0005435983059	26734	Economy	6200.00
0005435982881	26734	Economy	6200.00
0005433435337	26734	Economy	6200.00
0005433435351	26734	Economy	6200.00
0005433435339	26734	Economy	6200.00
0005433435330	26734	Economy	6200.00
0005435982952	26734	Economy	6200.00
0005435983150	26734	Economy	6200.00
0005435982806	26734	Economy	6200.00
0005435982999	26734	Economy	6200.00
0005434270257	26734	Economy	6200.00
0005435983010	26734	Economy	6200.00
0005433435349	26734	Economy	6200.00
0005435982807	26734	Economy	6200.00
0005432051202	26734	Economy	6200.00
0005435982852	26734	Economy	6200.00
0005435982998	26734	Economy	6200.00
0005435982867	26734	Economy	6200.00
0005435982882	26734	Economy	6200.00
0005433435357	26734	Economy	6200.00
0005434269153	26734	Economy	6200.00
0005433435348	26734	Economy	6200.00
0005435982843	26734	Economy	6200.00
0005433435356	26734	Economy	6200.00
0005433435336	26734	Economy	6200.00
0005433435347	26734	Economy	6200.00
0005434269152	26734	Economy	6200.00
0005433435344	26734	Economy	6200.00
0005435982934	26734	Economy	6200.00
0005432216338	3139	Economy	11100.00
0005432584623	3139	Economy	11100.00
0005432216337	3139	Economy	11100.00
0005432858246	3139	Economy	10100.00
0005432584616	3139	Economy	10100.00
0005432584626	3139	Economy	10100.00
0005432858217	3139	Economy	10100.00
0005432858248	3139	Economy	10100.00
0005432584635	3139	Economy	10100.00
0005432858245	3139	Economy	10100.00
0005432584620	3139	Economy	10100.00
0005432584636	3139	Economy	10100.00
0005432584638	3139	Economy	10100.00
0005432216339	3139	Economy	10100.00
0005432584633	3139	Economy	10100.00
0005432584624	3139	Economy	10100.00
0005432584621	3139	Economy	10100.00
0005432584627	3139	Economy	10100.00
0005432858216	3139	Economy	10100.00
0005432584632	3139	Economy	10100.00
0005432584619	3139	Economy	10100.00
0005432584631	3139	Economy	10100.00
0005432584637	3139	Economy	10100.00
0005432584628	3139	Economy	10100.00
0005432584617	3139	Economy	10100.00
0005432584625	3139	Economy	10100.00
0005432584634	3139	Economy	10100.00
0005432584618	3139	Economy	10100.00
0005432858247	3139	Economy	10100.00
0005432858275	3139	Economy	10100.00
0005432584639	3139	Economy	10100.00
0005432584629	3139	Economy	10100.00
0005432858274	3139	Economy	10100.00
0005432584622	3139	Economy	10100.00
0005432584640	3139	Economy	10100.00
0005432584630	3139	Economy	10100.00
0005432858345	31484	Economy	11100.00
0005432584374	31484	Economy	11100.00
0005432584534	31484	Economy	10100.00
0005432858354	31484	Economy	10100.00
0005432584501	31484	Economy	10100.00
0005432584339	31484	Economy	10100.00
0005432584441	31484	Economy	10100.00
0005432584453	31484	Economy	10100.00
0005432584450	31484	Economy	10100.00
0005432858348	31484	Economy	10100.00
0005432584355	31484	Economy	10100.00
0005432584440	31484	Economy	10100.00
0005432584373	31484	Economy	10100.00
0005432584477	31484	Economy	10100.00
0005432858342	31484	Economy	10100.00
0005432858351	31484	Economy	10100.00
0005432584430	31484	Economy	10100.00
0005432584376	31484	Economy	10100.00
0005432584482	31484	Economy	10100.00
0005432858352	31484	Economy	10100.00
0005432858346	31484	Economy	10100.00
0005432584382	31484	Economy	10100.00
0005432584362	31484	Economy	10100.00
0005432858347	31484	Economy	10100.00
0005432858341	31484	Economy	10100.00
0005432584452	31484	Economy	10100.00
0005432584431	31484	Economy	10100.00
0005432858350	31484	Economy	10100.00
0005432584533	31484	Economy	10100.00
0005432858344	31484	Economy	10100.00
0005432858353	31484	Economy	10100.00
0005432584390	31484	Economy	10100.00
0005432584389	31484	Economy	10100.00
0005432584451	31484	Economy	10100.00
0005432858349	31484	Economy	10100.00
0005432584356	31484	Economy	10100.00
0005432584361	31484	Economy	10100.00
0005432858343	31484	Economy	10100.00
0005434943573	882	Economy	8300.00
0005433255174	882	Economy	7500.00
0005434943568	882	Economy	7500.00
0005434943572	882	Economy	7500.00
0005434943565	882	Economy	7500.00
0005434943569	882	Economy	7500.00
0005434943570	882	Economy	7500.00
0005433255198	882	Economy	7500.00
0005433255202	882	Economy	7500.00
0005434943566	882	Economy	7500.00
0005433255203	882	Economy	7500.00
0005434943567	882	Economy	7500.00
0005434943571	882	Economy	7500.00
0005433255245	16190	Economy	7500.00
0005433255247	16190	Economy	7500.00
0005434943521	16190	Economy	7500.00
0005434943515	16190	Economy	7500.00
0005433255249	16190	Economy	7500.00
0005434943514	16190	Economy	7500.00
0005433255248	16190	Economy	7500.00
0005434943501	16190	Economy	7500.00
0005434943512	16190	Economy	7500.00
0005433255246	16190	Economy	7500.00
0005434943483	16190	Economy	7500.00
0005434943524	16190	Economy	7500.00
0005433927526	14436	Economy	4400.00
0005433927528	14436	Economy	4400.00
0005433927527	14436	Economy	4400.00
0005435654092	21773	Business	9800.00
0005433368442	21773	Business	9800.00
0005435654091	21773	Business	9800.00
0005435654054	21773	Business	9800.00
0005435654052	21773	Business	9800.00
0005435654076	21773	Business	9800.00
0005435654075	21773	Business	9800.00
0005435654063	21773	Business	9800.00
0005435654059	21773	Business	9800.00
0005435654097	21773	Business	9800.00
0005435654057	21773	Business	9800.00
0005435654071	21773	Business	9800.00
0005435654084	21773	Economy	3300.00
0005433368531	21773	Economy	3300.00
0005433368272	21773	Economy	3300.00
0005433368423	21773	Economy	3300.00
0005433368356	21773	Economy	3300.00
0005435654067	21773	Economy	3300.00
0005435654096	21773	Economy	3300.00
0005435654086	21773	Economy	3300.00
0005435654074	21773	Economy	3300.00
0005435654093	21773	Economy	3300.00
0005435654053	21773	Economy	3600.00
0005435654056	21773	Economy	3600.00
0005435654085	21773	Economy	3600.00
0005435654062	21773	Economy	3600.00
0005435654060	21773	Economy	3600.00
0005433368530	21773	Economy	3300.00
0005435654049	21773	Economy	3300.00
0005433368488	21773	Economy	3300.00
0005435654066	21773	Economy	3300.00
0005435654080	21773	Economy	3300.00
0005433368270	21773	Economy	3300.00
0005433368487	21773	Economy	3300.00
0005435654082	21773	Economy	3300.00
0005433368433	21773	Economy	3300.00
0005435654077	21773	Economy	3300.00
0005435654089	21773	Economy	3300.00
0005435654100	21773	Economy	3300.00
0005433368414	21773	Economy	3300.00
0005433368443	21773	Economy	3300.00
0005435654095	21773	Economy	3300.00
0005433368415	21773	Economy	3300.00
0005435654069	21773	Economy	3300.00
0005433368380	21773	Economy	3300.00
0005433368412	21773	Economy	3300.00
0005433368315	21773	Economy	3300.00
0005433368432	21773	Economy	3300.00
0005433368371	21773	Economy	3300.00
0005435654090	21773	Economy	3300.00
0005435654081	21773	Economy	3300.00
0005435654094	21773	Economy	3300.00
0005433368390	21773	Economy	3300.00
0005435654070	21773	Economy	3300.00
0005435654078	21773	Economy	3300.00
0005435654087	21773	Economy	3300.00
0005435654072	21773	Economy	3300.00
0005435654055	21773	Economy	3300.00
0005435654061	21773	Economy	3300.00
0005435654073	21773	Economy	3300.00
0005433368422	21773	Economy	3300.00
0005435654051	21773	Economy	3300.00
0005433368281	21773	Economy	3300.00
0005433368389	21773	Economy	3300.00
0005433368437	21773	Economy	3300.00
0005433368478	21773	Economy	3300.00
0005435654099	21773	Economy	3300.00
0005433368448	21773	Economy	3300.00
0005433368416	21773	Economy	3300.00
0005433368449	21773	Economy	3300.00
0005435654098	21773	Economy	3300.00
0005435654050	21773	Economy	3300.00
0005433368234	21773	Economy	3300.00
0005433368370	21773	Economy	3300.00
0005435654068	21773	Economy	3300.00
0005433368353	21773	Economy	3300.00
0005435654088	21773	Economy	3300.00
0005433368573	21773	Economy	3300.00
0005433368374	21773	Economy	3300.00
0005435654079	21773	Economy	3300.00
0005435654064	21773	Economy	3300.00
0005433368436	21773	Economy	3300.00
0005433368280	21773	Economy	3300.00
0005435654065	21773	Economy	3300.00
0005433368271	21773	Economy	3300.00
0005433368233	21773	Economy	3300.00
0005435654083	21773	Economy	3300.00
0005433368409	21773	Economy	3300.00
0005435654058	21773	Economy	3300.00
0005435269819	9367	Business	186200.00
0005433806183	9367	Business	186200.00
0005433763551	9367	Business	186200.00
0005435269859	9367	Business	186200.00
0005433763547	9367	Business	186200.00
0005433806173	9367	Business	186200.00
0005433785782	9367	Business	186200.00
0005434171279	9367	Business	186200.00
0005433785814	9367	Business	186200.00
0005433806182	9367	Business	186200.00
0005433806187	9367	Business	186200.00
0005433763543	9367	Business	186200.00
0005433785802	9367	Business	186200.00
0005432657520	9367	Business	186200.00
0005434171325	9367	Business	186200.00
0005435269857	9367	Business	186200.00
0005434171271	9367	Economy	68300.00
0005434151748	9367	Business	186200.00
0005433785801	9367	Economy	68300.00
0005432657522	9367	Economy	62100.00
0005433763549	9367	Economy	62100.00
0005433785803	9367	Economy	62100.00
0005433763554	9367	Economy	62100.00
0005433785793	9367	Economy	62100.00
0005433806200	9367	Economy	62100.00
0005433806190	9367	Economy	62100.00
0005433806202	9367	Economy	62100.00
0005433785812	9367	Economy	62100.00
0005434171258	9367	Economy	62100.00
0005433763553	9367	Economy	62100.00
0005434171309	9367	Economy	62100.00
0005435269845	9367	Economy	62100.00
0005433785799	9367	Economy	62100.00
0005433806176	9367	Economy	62100.00
0005433763541	9367	Economy	62100.00
0005433785781	9367	Economy	62100.00
0005433785809	9367	Economy	62100.00
0005433806198	9367	Economy	62100.00
0005433785805	9367	Economy	62100.00
0005433806195	9367	Economy	62100.00
0005433785785	9367	Economy	62100.00
0005435269870	9367	Economy	62100.00
0005433763540	9367	Economy	62100.00
0005433785818	9367	Economy	62100.00
0005433806174	9367	Economy	62100.00
0005435269868	9367	Economy	62100.00
0005433806191	9367	Economy	62100.00
0005433763545	9367	Economy	62100.00
0005435269865	9367	Economy	62100.00
0005432665324	9367	Economy	62100.00
0005433785813	9367	Economy	62100.00
0005433806172	9367	Economy	62100.00
0005434151749	9367	Economy	62100.00
0005433806186	9367	Economy	62100.00
0005433785798	9367	Economy	62100.00
0005433806193	9367	Economy	62100.00
0005433806203	9367	Economy	62100.00
0005434171326	9367	Economy	62100.00
0005432666438	9367	Economy	62100.00
0005434171233	9367	Economy	62100.00
0005433785797	9367	Economy	62100.00
0005432657521	9367	Economy	62100.00
0005435269871	9367	Economy	62100.00
0005435269861	9367	Economy	62100.00
0005434171275	9367	Economy	62100.00
0005435269858	9367	Economy	62100.00
0005433785794	9367	Economy	62100.00
0005433806189	9367	Economy	62100.00
0005434171249	9367	Economy	62100.00
0005433785811	9367	Economy	62100.00
0005433785786	9367	Economy	62100.00
0005433785816	9367	Economy	62100.00
0005433785807	9367	Economy	62100.00
0005433785796	9367	Economy	62100.00
0005433806206	9367	Economy	62100.00
0005433785815	9367	Economy	62100.00
0005433763544	9367	Economy	62100.00
0005433763546	9367	Economy	62100.00
0005433763542	9367	Economy	62100.00
0005435269842	9367	Economy	62100.00
0005433763548	9367	Economy	62100.00
0005434171270	9367	Economy	62100.00
0005433806177	9367	Economy	68300.00
0005433785788	9367	Economy	62100.00
0005435269862	9367	Economy	62100.00
0005433785791	9367	Economy	62100.00
0005433763550	9367	Economy	62100.00
0005433806201	9367	Economy	62100.00
0005435269863	9367	Economy	62100.00
0005432666437	9367	Economy	62100.00
0005433785792	9367	Economy	62100.00
0005434171328	9367	Economy	62100.00
0005433806197	9367	Economy	62100.00
0005433806192	9367	Economy	62100.00
0005433785804	9367	Economy	62100.00
0005433806178	9367	Economy	62100.00
0005434171327	9367	Economy	62100.00
0005435269869	9367	Economy	62100.00
0005433785789	9367	Economy	62100.00
0005433806180	9367	Economy	62100.00
0005433785787	9367	Economy	62100.00
0005433806181	9367	Economy	62100.00
0005433785810	9367	Economy	62100.00
0005434171290	9367	Economy	62100.00
0005435269864	9367	Economy	62100.00
0005433785783	9367	Economy	62100.00
0005435269867	9367	Economy	62100.00
0005433806205	9367	Economy	62100.00
0005433806179	9367	Economy	62100.00
0005435269860	9367	Economy	62100.00
0005433806175	9367	Economy	62100.00
0005433806184	9367	Economy	62100.00
0005433806188	9367	Economy	62100.00
0005433806204	9367	Economy	62100.00
0005433785800	9367	Economy	62100.00
0005433763552	9367	Economy	62100.00
0005433785790	9367	Economy	62100.00
0005433785817	9367	Economy	62100.00
0005433806199	9367	Economy	62100.00
0005433806194	9367	Economy	62100.00
0005433785808	9367	Economy	62100.00
0005434171318	9367	Economy	62100.00
0005435269856	9367	Economy	62100.00
0005434171248	9367	Economy	62100.00
0005432665325	9367	Economy	62100.00
0005433785806	9367	Economy	62100.00
0005433806196	9367	Economy	62100.00
0005433785784	9367	Economy	62100.00
0005433806185	9367	Economy	62100.00
0005433785795	9367	Economy	62100.00
0005434171324	9367	Economy	62100.00
0005432657523	9367	Economy	62100.00
0005433785562	26275	Business	186200.00
0005435269997	26275	Business	186200.00
0005434171393	26275	Business	186200.00
0005433785625	26275	Business	186200.00
0005434151774	26275	Business	186200.00
0005433785484	26275	Business	186200.00
0005433785393	26275	Business	186200.00
0005433785435	26275	Business	186200.00
0005433806001	26275	Business	186200.00
0005434151771	26275	Business	186200.00
0005433805634	26275	Business	186200.00
0005433805778	26275	Business	186200.00
0005435270004	26275	Business	186200.00
0005435270000	26275	Business	186200.00
0005435269999	26275	Business	186200.00
0005433763407	26275	Business	186200.00
0005433785517	26275	Business	186200.00
0005433805947	26275	Business	186200.00
0005435269996	26275	Economy	68300.00
0005435269973	26275	Business	186200.00
0005433806030	26275	Economy	68300.00
0005434171394	26275	Economy	68300.00
0005435270001	26275	Economy	68300.00
0005433785492	26275	Economy	62100.00
0005434271358	26275	Economy	62100.00
0005435269977	26275	Economy	62100.00
0005435270010	26275	Economy	62100.00
0005433785376	26275	Economy	62100.00
0005435269991	26275	Economy	62100.00
0005434171390	26275	Economy	62100.00
0005433805930	26275	Economy	62100.00
0005433805931	26275	Economy	62100.00
0005433763378	26275	Economy	62100.00
0005434171398	26275	Economy	62100.00
0005434171384	26275	Economy	62100.00
0005432663066	26275	Economy	62100.00
0005434271360	26275	Economy	62100.00
0005433805904	26275	Economy	62100.00
0005435269985	26275	Economy	62100.00
0005433763403	26275	Economy	62100.00
0005435858699	26275	Economy	62100.00
0005433785506	26275	Economy	62100.00
0005434269149	26275	Economy	62100.00
0005433805733	26275	Economy	62100.00
0005434151773	26275	Economy	62100.00
0005434269150	26275	Economy	62100.00
0005434171386	26275	Economy	62100.00
0005434270256	26275	Economy	62100.00
0005435269983	26275	Economy	62100.00
0005433805764	26275	Economy	62100.00
0005433785377	26275	Economy	62100.00
0005433785552	26275	Economy	62100.00
0005433805903	26275	Economy	62100.00
0005435270005	26275	Economy	62100.00
0005435269976	26275	Economy	62100.00
0005433805907	26275	Economy	62100.00
0005435269975	26275	Economy	62100.00
0005435269980	26275	Economy	62100.00
0005433785485	26275	Economy	62100.00
0005434171388	26275	Economy	62100.00
0005435858700	26275	Economy	62100.00
0005433805792	26275	Economy	62100.00
0005435269992	26275	Economy	62100.00
0005433763408	26275	Economy	62100.00
0005433785521	26275	Economy	62100.00
0005435269990	26275	Economy	62100.00
0005433805932	26275	Economy	62100.00
0005435270003	26275	Economy	62100.00
0005433805868	26275	Economy	62100.00
0005433805847	26275	Economy	62100.00
0005435270009	26275	Economy	62100.00
0005433785558	26275	Economy	62100.00
0005433785443	26275	Economy	62100.00
0005435270002	26275	Economy	62100.00
0005434171392	26275	Economy	62100.00
0005434171395	26275	Economy	62100.00
0005435269988	26275	Economy	62100.00
0005433785505	26275	Economy	62100.00
0005433805902	26275	Economy	62100.00
0005434171389	26275	Economy	62100.00
0005435269982	26275	Economy	62100.00
0005433785551	26275	Economy	62100.00
0005433805997	26275	Economy	62100.00
0005434151772	26275	Economy	62100.00
0005434171391	26275	Economy	62100.00
0005433805913	26275	Economy	62100.00
0005433785514	26275	Economy	62100.00
0005435270008	26275	Economy	62100.00
0005433785624	26275	Economy	62100.00
0005432663056	26275	Economy	62100.00
0005435269989	26275	Economy	62100.00
0005433785444	26275	Economy	62100.00
0005433785598	26275	Economy	68300.00
0005435269986	26275	Economy	68300.00
0005433785422	26275	Economy	62100.00
0005434171396	26275	Economy	68300.00
0005434171397	26275	Economy	68300.00
0005433763441	26275	Economy	62100.00
0005435270007	26275	Economy	62100.00
0005434270255	26275	Economy	62100.00
0005433806056	26275	Economy	62100.00
0005434171399	26275	Economy	62100.00
0005433785360	26275	Economy	62100.00
0005433805810	26275	Economy	62100.00
0005435269998	26275	Economy	62100.00
0005435270006	26275	Economy	62100.00
0005432663061	26275	Economy	62100.00
0005433785597	26275	Economy	62100.00
0005433805811	26275	Economy	62100.00
0005433805870	26275	Economy	62100.00
0005435269987	26275	Economy	62100.00
0005434171385	26275	Economy	62100.00
0005433785469	26275	Economy	62100.00
0005435269981	26275	Economy	62100.00
0005434270254	26275	Economy	62100.00
0005433805955	26275	Economy	62100.00
0005433805933	26275	Economy	62100.00
0005435270012	26275	Economy	62100.00
0005434271361	26275	Economy	62100.00
0005433763397	26275	Economy	62100.00
0005433785550	26275	Economy	62100.00
0005433785500	26275	Economy	62100.00
0005433805859	26275	Economy	62100.00
0005432659727	26275	Economy	62100.00
0005435269984	26275	Economy	62100.00
0005432659733	26275	Economy	62100.00
0005434171387	26275	Economy	62100.00
0005433806062	26275	Economy	62100.00
0005433785596	26275	Economy	62100.00
0005433785394	26275	Economy	62100.00
0005433763451	26275	Economy	62100.00
0005433763387	26275	Economy	62100.00
0005435269978	26275	Economy	62100.00
0005435269995	26275	Economy	62100.00
0005433805996	26275	Economy	62100.00
0005433763379	26275	Economy	62100.00
0005435269994	26275	Economy	62100.00
0005432663057	26275	Economy	62100.00
0005433785361	26275	Economy	62100.00
0005435270011	26275	Economy	62100.00
0005433806011	26275	Economy	62100.00
0005432659737	26275	Economy	62100.00
0005434271359	26275	Economy	62100.00
0005433805825	26275	Economy	62100.00
0005433805869	26275	Economy	62100.00
0005435269974	26275	Economy	62100.00
0005433785359	26275	Economy	62100.00
0005433785434	26275	Economy	62100.00
0005435269979	26275	Economy	62100.00
0005433763402	26275	Economy	62100.00
0005433785445	26275	Economy	62100.00
0005435269993	26275	Economy	62100.00
0005432659734	26275	Economy	62100.00
0005435135786	4928	Economy	5300.00
0005435135785	4928	Economy	5300.00
0005435135787	4928	Economy	5300.00
0005435929687	4928	Economy	5300.00
0005435135750	33000	Economy	5900.00
0005435929708	33000	Economy	5900.00
0005435929707	33000	Economy	5300.00
0005435135770	33000	Economy	5300.00
0005435135763	33000	Economy	5300.00
0005435135746	33000	Economy	5300.00
0005434218024	9500	Economy	19700.00
0005434218047	9500	Economy	17900.00
0005434983410	9500	Economy	17900.00
0005434218016	9500	Economy	17900.00
0005434218026	9500	Economy	17900.00
0005434218015	9500	Economy	17900.00
0005434218025	9500	Economy	17900.00
0005434218027	9500	Economy	17900.00
0005434218014	9500	Economy	17900.00
0005434218046	9500	Economy	17900.00
0005434218029	9500	Economy	17900.00
0005434983407	9500	Economy	17900.00
0005434218028	9500	Economy	17900.00
0005434983411	9500	Economy	17900.00
0005434983409	9500	Economy	17900.00
0005434983408	9500	Economy	17900.00
0005434983375	27346	Economy	19700.00
0005434983361	27346	Economy	19700.00
0005434983386	27346	Economy	17900.00
0005434983367	27346	Economy	17900.00
0005434218066	27346	Economy	17900.00
0005434218063	27346	Economy	17900.00
0005434983376	27346	Economy	17900.00
0005434218065	27346	Economy	17900.00
0005434983366	27346	Economy	17900.00
0005434983373	27346	Economy	17900.00
0005434983387	27346	Economy	17900.00
0005434983368	27346	Economy	17900.00
0005434218064	27346	Economy	17900.00
0005433961508	24279	Business	36400.00
0005433961619	24279	Business	36400.00
0005433961490	24279	Business	36400.00
0005433986487	24279	Business	36400.00
0005433986518	24279	Business	36400.00
0005433961467	24279	Business	36400.00
0005433986685	24279	Business	36400.00
0005433986550	24279	Business	36400.00
0005433961465	24279	Business	36400.00
0005433986545	24279	Business	36400.00
0005433961684	24279	Business	36400.00
0005433961712	24279	Business	36400.00
0005433986538	24279	Business	36400.00
0005433961644	24279	Business	36400.00
0005433986686	24279	Business	36400.00
0005433961600	24279	Business	36400.00
0005433986577	24279	Economy	13400.00
0005433961615	24279	Economy	13400.00
0005433961671	24279	Economy	13400.00
0005433961519	24279	Economy	12100.00
0005433961489	24279	Economy	12100.00
0005433961492	24279	Economy	12100.00
0005433986544	24279	Economy	12100.00
0005433961466	24279	Economy	12100.00
0005433986472	24279	Economy	12100.00
0005433961614	24279	Economy	12100.00
0005433986736	24279	Economy	12100.00
0005433986638	24279	Economy	12100.00
0005433961610	24279	Economy	12100.00
0005433986578	24279	Economy	12100.00
0005433986710	24279	Economy	12100.00
0005433961702	24279	Economy	12100.00
0005433986605	24279	Economy	12100.00
0005433961589	24279	Economy	12100.00
0005433961628	24279	Economy	12100.00
0005433986670	24279	Economy	12100.00
0005433986574	24279	Economy	12100.00
0005433986548	24279	Economy	12100.00
0005433986526	24279	Economy	12100.00
0005433986618	24279	Economy	12100.00
0005433986704	24279	Economy	12100.00
0005433961528	24279	Economy	12100.00
0005433986633	24279	Economy	12100.00
0005433961609	24279	Economy	12100.00
0005433961527	24279	Economy	12100.00
0005433986517	24279	Economy	12100.00
0005433961634	24279	Economy	12100.00
0005433986609	24279	Economy	12100.00
0005433961648	24279	Economy	12100.00
0005433986452	24279	Economy	12100.00
0005433986572	24279	Economy	12100.00
0005433986749	24279	Economy	12100.00
0005433961564	24279	Economy	12100.00
0005433961685	24279	Economy	12100.00
0005433961631	24279	Economy	12100.00
0005433986625	24279	Economy	12100.00
0005433986737	24279	Economy	12100.00
0005433986549	24279	Economy	12100.00
0005433986486	24279	Economy	12100.00
0005433961629	24279	Economy	12100.00
0005433986724	24279	Economy	12100.00
0005433961655	24279	Economy	12100.00
0005433986623	24279	Economy	12100.00
0005433961497	24279	Economy	12100.00
0005433986636	24279	Economy	12100.00
0005433961498	24279	Economy	12100.00
0005433986542	24279	Economy	12100.00
0005433961693	24279	Economy	12100.00
0005433986661	24279	Economy	12100.00
0005433961668	24279	Economy	12100.00
0005433986600	24279	Economy	12100.00
0005433986484	24279	Economy	13400.00
0005433961692	24279	Economy	12100.00
0005433961474	24279	Economy	12100.00
0005433986667	24279	Economy	12100.00
0005433961649	24279	Economy	12100.00
0005433961694	24279	Economy	12100.00
0005433986573	24279	Economy	12100.00
0005433986791	24279	Economy	12100.00
0005433986516	24279	Economy	12100.00
0005433986617	24279	Economy	12100.00
0005433961605	24279	Economy	12100.00
0005433961672	24279	Economy	12100.00
0005433986552	24279	Economy	12100.00
0005433961643	24279	Economy	12100.00
0005433961315	24279	Economy	12100.00
0005433961549	24279	Economy	12100.00
0005433961518	24279	Economy	12100.00
0005433986575	24279	Economy	12100.00
0005433961557	24279	Economy	12100.00
0005433986610	24279	Economy	12100.00
0005433986473	24279	Economy	12100.00
0005433961624	24279	Economy	12100.00
0005433986468	24279	Economy	12100.00
0005433961487	24279	Economy	12100.00
0005433986786	24279	Economy	12100.00
0005433961588	24279	Economy	12100.00
0005433986723	24279	Economy	12100.00
0005433961617	24279	Economy	12100.00
0005433961540	24279	Economy	12100.00
0005433986691	24279	Economy	12100.00
0005433986576	24279	Economy	12100.00
0005433986613	24279	Economy	12100.00
0005433986566	24279	Economy	12100.00
0005433961601	24279	Economy	12100.00
0005433986660	24279	Economy	12100.00
0005433986644	24279	Economy	12100.00
0005433986451	24279	Economy	12100.00
0005433961587	24279	Economy	12100.00
0005433961548	24279	Economy	12100.00
0005433986981	25914	Business	36400.00
0005433962173	25914	Business	36400.00
0005433987001	25914	Business	36400.00
0005433962194	25914	Business	36400.00
0005433962158	25914	Business	36400.00
0005433962171	25914	Business	36400.00
0005433987019	25914	Business	36400.00
0005433987006	25914	Business	36400.00
0005433986995	25914	Business	36400.00
0005433962180	25914	Business	36400.00
0005433986979	25914	Business	36400.00
0005433987013	25914	Business	36400.00
0005433987014	25914	Business	36400.00
0005433962179	25914	Business	36400.00
0005433987004	25914	Economy	12100.00
0005433986985	25914	Economy	12100.00
0005433962167	25914	Economy	12100.00
0005433987007	25914	Economy	12100.00
0005433986975	25914	Economy	12100.00
0005433962186	25914	Economy	12100.00
0005433986986	25914	Economy	12100.00
0005433987015	25914	Economy	12100.00
0005433986999	25914	Economy	12100.00
0005433962160	25914	Economy	12100.00
0005433987024	25914	Economy	12100.00
0005433987021	25914	Economy	12100.00
0005433986978	25914	Economy	12100.00
0005433962157	25914	Economy	12100.00
0005433962172	25914	Economy	12100.00
0005433986990	25914	Economy	12100.00
0005433962175	25914	Economy	12100.00
0005433986997	25914	Economy	12100.00
0005433987028	25914	Economy	12100.00
0005433962182	25914	Economy	12100.00
0005433987018	25914	Economy	12100.00
0005433962181	25914	Economy	12100.00
0005433986983	25914	Economy	12100.00
0005433987026	25914	Economy	12100.00
0005433987016	25914	Economy	12100.00
0005433987009	25914	Economy	12100.00
0005433962153	25914	Economy	12100.00
0005433962169	25914	Economy	12100.00
0005433986980	25914	Economy	12100.00
0005433987012	25914	Economy	12100.00
0005433962150	25914	Economy	12100.00
0005433962166	25914	Economy	12100.00
0005433962188	25914	Economy	12100.00
0005433987017	25914	Economy	12100.00
0005433962152	25914	Economy	12100.00
0005433986996	25914	Economy	12100.00
0005433986989	25914	Economy	12100.00
0005433986977	25914	Economy	12100.00
0005433986984	25914	Economy	12100.00
0005433962147	25914	Economy	12100.00
0005433962198	25914	Economy	12100.00
0005433962164	25914	Economy	12100.00
0005433962151	25914	Economy	12100.00
0005433986988	25914	Economy	12100.00
0005433987030	25914	Economy	12100.00
0005433962170	25914	Economy	13400.00
0005433962177	25914	Economy	12100.00
0005433987003	25914	Economy	12100.00
0005433962163	25914	Economy	12100.00
0005433986976	25914	Economy	13400.00
0005433962195	25914	Economy	13400.00
0005433962193	25914	Economy	12100.00
0005433962190	25914	Economy	12100.00
0005433987010	25914	Economy	12100.00
0005433987008	25914	Economy	12100.00
0005433962185	25914	Economy	12100.00
0005433987020	25914	Economy	12100.00
0005433962161	25914	Economy	12100.00
0005433987011	25914	Economy	12100.00
0005433986982	25914	Economy	12100.00
0005433962162	25914	Economy	12100.00
0005433962156	25914	Economy	12100.00
0005433987002	25914	Economy	12100.00
0005433986991	25914	Economy	12100.00
0005433962174	25914	Economy	12100.00
0005433962184	25914	Economy	12100.00
0005433962154	25914	Economy	12100.00
0005433962165	25914	Economy	12100.00
0005433987027	25914	Economy	12100.00
0005433962183	25914	Economy	12100.00
0005433962149	25914	Economy	12100.00
0005433986993	25914	Economy	12100.00
0005433962176	25914	Economy	12100.00
0005433962199	25914	Economy	12100.00
0005433962189	25914	Economy	12100.00
0005433986992	25914	Economy	12100.00
0005433962192	25914	Economy	12100.00
0005433962197	25914	Economy	12100.00
0005433962148	25914	Economy	12100.00
0005433986998	25914	Economy	12100.00
0005433986994	25914	Economy	12100.00
0005433962187	25914	Economy	12100.00
0005433962159	25914	Economy	12100.00
0005433987000	25914	Economy	12100.00
0005433987022	25914	Economy	12100.00
0005433987029	25914	Economy	12100.00
0005433987005	25914	Economy	12100.00
0005433962155	25914	Economy	12100.00
0005433962191	25914	Economy	12100.00
0005433962196	25914	Economy	12100.00
0005433962168	25914	Economy	12100.00
0005433962178	25914	Economy	12100.00
0005433987025	25914	Economy	12100.00
0005433986987	25914	Economy	12100.00
0005433987023	25914	Economy	12100.00
0005434480923	936	Economy	25400.00
0005433166129	936	Economy	25400.00
0005434480910	936	Economy	25400.00
0005434480926	936	Economy	25400.00
0005432269562	936	Economy	23100.00
0005434480912	936	Economy	23100.00
0005433166016	936	Economy	23100.00
0005434480922	936	Economy	23100.00
0005434480921	936	Economy	23100.00
0005434480914	936	Economy	23100.00
0005434480924	936	Economy	23100.00
0005434480915	936	Economy	23100.00
0005434480905	936	Economy	23100.00
0005433166133	936	Economy	23100.00
0005434480916	936	Economy	23100.00
0005434480906	936	Economy	23100.00
0005434480909	936	Economy	23100.00
0005433166082	936	Economy	23100.00
0005433166017	936	Economy	23100.00
0005434480918	936	Economy	23100.00
0005434480913	936	Economy	23100.00
0005434480908	936	Economy	23100.00
0005433166103	936	Economy	23100.00
0005433166190	936	Economy	23100.00
0005434480917	936	Economy	23100.00
0005433166081	936	Economy	23100.00
0005434480925	936	Economy	23100.00
0005432269560	936	Economy	23100.00
0005433166147	936	Economy	23100.00
0005434480911	936	Economy	23100.00
0005434480904	936	Economy	23100.00
0005434480900	936	Economy	23100.00
0005434480919	936	Economy	23100.00
0005434480927	936	Economy	23100.00
0005434480920	936	Economy	23100.00
0005434480903	936	Economy	23100.00
0005434480901	936	Economy	23100.00
0005434480902	936	Economy	23100.00
0005434480907	936	Economy	23100.00
0005433166130	936	Economy	23100.00
0005433166102	936	Economy	23100.00
0005432269561	936	Economy	23100.00
0005434480751	16600	Economy	25400.00
0005433166208	16600	Economy	25400.00
0005433166206	16600	Economy	23100.00
0005434480655	16600	Economy	23100.00
0005434480654	16600	Economy	23100.00
0005434480713	16600	Economy	23100.00
0005434480681	16600	Economy	23100.00
0005433166213	16600	Economy	23100.00
0005433166205	16600	Economy	23100.00
0005433166209	16600	Economy	23100.00
0005434480760	16600	Economy	23100.00
0005434480682	16600	Economy	23100.00
0005434480705	16600	Economy	23100.00
0005434480628	16600	Economy	23100.00
0005433166207	16600	Economy	23100.00
0005434480618	16600	Economy	23100.00
0005433166204	16600	Economy	23100.00
0005433166211	16600	Economy	23100.00
0005434480722	16600	Economy	23100.00
0005433166215	16600	Economy	23100.00
0005434480752	16600	Economy	23100.00
0005434480613	16600	Economy	23100.00
0005433166212	16600	Economy	23100.00
0005434480668	16600	Economy	23100.00
0005433166210	16600	Economy	23100.00
0005434480667	16600	Economy	23100.00
0005434480656	16600	Economy	23100.00
0005434480678	16600	Economy	23100.00
0005434480731	16600	Economy	23100.00
0005434480704	16600	Economy	23100.00
0005434480721	16600	Economy	23100.00
0005434480619	16600	Economy	23100.00
0005434480677	16600	Economy	23100.00
0005433166214	16600	Economy	23100.00
0005434480596	16600	Economy	23100.00
0005434480730	16600	Economy	23100.00
0005435142876	10332	Economy	17000.00
0005435150340	10332	Economy	17000.00
0005433289951	10332	Economy	17000.00
0005433289933	10332	Economy	17000.00
0005435150344	10332	Economy	15400.00
0005435142880	10332	Economy	15400.00
0005435150351	10332	Economy	15400.00
0005435142878	10332	Economy	15400.00
0005435142885	10332	Economy	15400.00
0005435142881	10332	Economy	15400.00
0005435150341	10332	Economy	15400.00
0005435150350	10332	Economy	15400.00
0005435150349	10332	Economy	15400.00
0005435150343	10332	Economy	15400.00
0005435142882	10332	Economy	15400.00
0005435142886	10332	Economy	15400.00
0005435142877	10332	Economy	15400.00
0005435150348	10332	Economy	15400.00
0005435142887	10332	Economy	15400.00
0005435142889	10332	Economy	15400.00
0005435142884	10332	Economy	15400.00
0005435386651	10332	Economy	15400.00
0005433289944	10332	Economy	15400.00
0005435150346	10332	Economy	15400.00
0005435150345	10332	Economy	15400.00
0005435150342	10332	Economy	15400.00
0005433289924	10332	Economy	15400.00
0005435142883	10332	Economy	15400.00
0005433289952	10332	Economy	15400.00
0005435386671	10332	Economy	15400.00
0005435150339	10332	Economy	15400.00
0005435150338	10332	Economy	15400.00
0005433289975	10332	Economy	15400.00
0005435142890	10332	Economy	15400.00
0005435386676	10332	Economy	15400.00
0005435386677	10332	Economy	15400.00
0005435142888	10332	Economy	15400.00
0005435150352	10332	Economy	15400.00
0005435386678	10332	Economy	15400.00
0005433289935	10332	Economy	15400.00
0005435142879	10332	Economy	15400.00
0005435150347	10332	Economy	15400.00
0005433289976	10332	Economy	15400.00
0005435386652	10332	Economy	15400.00
0005435386635	10332	Economy	15400.00
0005433290030	21945	Economy	17000.00
0005435142742	21945	Economy	17000.00
0005433290021	21945	Economy	17000.00
0005435142791	21945	Economy	17000.00
0005435142720	21945	Economy	15400.00
0005435150208	21945	Economy	15400.00
0005435150219	21945	Economy	15400.00
0005435142753	21945	Economy	15400.00
0005435150178	21945	Economy	15400.00
0005433290026	21945	Economy	15400.00
0005435150167	21945	Economy	15400.00
0005435142721	21945	Economy	15400.00
0005435150165	21945	Economy	15400.00
0005435150179	21945	Economy	15400.00
0005435150161	21945	Economy	15400.00
0005435142739	21945	Economy	15400.00
0005435150223	21945	Economy	15400.00
0005435150224	21945	Economy	15400.00
0005433290025	21945	Economy	15400.00
0005435150213	21945	Economy	15400.00
0005435150210	21945	Economy	15400.00
0005435142756	21945	Economy	15400.00
0005435142783	21945	Economy	15400.00
0005435142728	21945	Economy	15400.00
0005435150217	21945	Economy	15400.00
0005435150288	21945	Economy	15400.00
0005435142738	21945	Economy	15400.00
0005435150177	21945	Economy	15400.00
0005433290023	21945	Economy	15400.00
0005435150230	21945	Economy	15400.00
0005435142804	21945	Economy	15400.00
0005433290027	21945	Economy	15400.00
0005433290028	21945	Economy	15400.00
0005435150247	21945	Economy	15400.00
0005435150166	21945	Economy	15400.00
0005435142750	21945	Economy	15400.00
0005435142757	21945	Economy	15400.00
0005435150176	21945	Economy	15400.00
0005433290022	21945	Economy	15400.00
0005435142781	21945	Economy	15400.00
0005435150231	21945	Economy	15400.00
0005435150162	21945	Economy	15400.00
0005435142805	21945	Economy	15400.00
0005435142792	21945	Economy	15400.00
0005433290024	21945	Economy	15400.00
0005435142782	21945	Economy	15400.00
0005435142741	21945	Economy	15400.00
0005433290029	21945	Economy	15400.00
0005435150209	21945	Economy	15400.00
0005434573675	11178	Business	57200.00
0005435502761	11178	Business	57200.00
0005435502583	11178	Business	57200.00
0005435529520	11178	Business	57200.00
0005435529597	11178	Business	57200.00
0005435529565	11178	Business	57200.00
0005435502738	11178	Business	57200.00
0005435502673	11178	Business	57200.00
0005435502600	11178	Business	57200.00
0005435502674	11178	Business	57200.00
0005435502626	11178	Business	57200.00
0005435319708	11178	Business	57200.00
0005434573674	11178	Economy	19100.00
0005434573665	11178	Economy	19100.00
0005434573677	11178	Economy	19100.00
0005435502529	11178	Economy	19100.00
0005435502772	11178	Economy	19100.00
0005435502661	11178	Economy	19100.00
0005435529418	11178	Economy	19100.00
0005435545801	11178	Economy	19100.00
0005435502705	11178	Economy	19100.00
0005435529551	11178	Economy	21000.00
0005435502624	11178	Economy	21000.00
0005435529623	11178	Economy	21000.00
0005435319719	11178	Economy	21000.00
0005435502622	11178	Economy	19100.00
0005435502584	11178	Economy	19100.00
0005435529540	11178	Economy	19100.00
0005435319740	11178	Economy	19100.00
0005435529604	11178	Economy	19100.00
0005435529620	11178	Economy	19100.00
0005435502706	11178	Economy	19100.00
0005435502603	11178	Economy	19100.00
0005434573676	11178	Economy	19100.00
0005435502609	11178	Economy	19100.00
0005435502666	11178	Economy	19100.00
0005435529607	11178	Economy	19100.00
0005435502645	11178	Economy	19100.00
0005434573671	11178	Economy	19100.00
0005434573670	11178	Economy	19100.00
0005435529539	11178	Economy	19100.00
0005435529593	11178	Economy	19100.00
0005435502621	11178	Economy	19100.00
0005434573673	11178	Economy	19100.00
0005435529579	11178	Economy	19100.00
0005435319709	11178	Economy	19100.00
0005434573678	11178	Economy	19100.00
0005435502675	11178	Economy	19100.00
0005435502606	11178	Economy	19100.00
0005434573667	11178	Economy	19100.00
0005435529497	11178	Economy	19100.00
0005435529606	11178	Economy	19100.00
0005435502549	11178	Economy	19100.00
0005435502613	11178	Economy	19100.00
0005435502663	11178	Economy	19100.00
0005435319686	11178	Economy	19100.00
0005435502607	11178	Economy	19100.00
0005435529621	11178	Economy	19100.00
0005434573668	11178	Economy	19100.00
0005434573672	11178	Economy	19100.00
0005435502629	11178	Economy	19100.00
0005435502616	11178	Economy	19100.00
0005434573669	11178	Economy	19100.00
0005435502599	11178	Economy	19100.00
0005435502754	11178	Economy	19100.00
0005435502598	11178	Economy	19100.00
0005435502560	11178	Economy	19100.00
0005435529566	11178	Economy	19100.00
0005435319720	11178	Economy	19100.00
0005435502710	11178	Economy	19100.00
0005434573664	11178	Economy	19100.00
0005435319687	11178	Economy	19100.00
0005435529622	11178	Economy	19100.00
0005435502662	11178	Economy	19100.00
0005435529541	11178	Economy	19100.00
0005435319703	11178	Economy	19100.00
0005435502528	11178	Economy	19100.00
0005435502553	11178	Economy	19100.00
0005435502601	11178	Economy	19100.00
0005435502527	11178	Economy	19100.00
0005435502623	11178	Economy	19100.00
0005434573666	11178	Economy	19100.00
0005435529522	11178	Economy	19100.00
0005435319718	11178	Economy	19100.00
0005435502602	11178	Economy	19100.00
0005435502628	11178	Economy	19100.00
0005435529605	11178	Economy	19100.00
0005435508666	20920	Business	57200.00
0005435319787	20920	Business	57200.00
0005435518327	20920	Business	57200.00
0005435518318	20920	Business	57200.00
0005435502797	20920	Business	57200.00
0005435502803	20920	Business	57200.00
0005435502811	20920	Business	57200.00
0005435319794	20920	Business	57200.00
0005435508674	20920	Business	57200.00
0005435319791	20920	Business	57200.00
0005435502805	20920	Business	57200.00
0005432291987	20920	Economy	19100.00
0005435502808	20920	Economy	19100.00
0005435319790	20920	Economy	19100.00
0005434573588	20920	Economy	19100.00
0005435508669	20920	Economy	19100.00
0005435502815	20920	Economy	19100.00
0005435518323	20920	Economy	19100.00
0005432291988	20920	Economy	19100.00
0005435518325	20920	Economy	19100.00
0005435508682	20920	Economy	21000.00
0005432291986	20920	Economy	21000.00
0005432291985	20920	Economy	21000.00
0005435502799	20920	Economy	19100.00
0005435508670	20920	Economy	19100.00
0005434573579	20920	Economy	19100.00
0005435508679	20920	Economy	19100.00
0005435508676	20920	Economy	19100.00
0005435508663	20920	Economy	19100.00
0005435502807	20920	Economy	19100.00
0005435319789	20920	Economy	19100.00
0005435502804	20920	Economy	19100.00
0005434573580	20920	Economy	19100.00
0005435502812	20920	Economy	19100.00
0005435518329	20920	Economy	19100.00
0005435518320	20920	Economy	19100.00
0005435502802	20920	Economy	19100.00
0005435518326	20920	Economy	19100.00
0005435502813	20920	Economy	19100.00
0005435319793	20920	Economy	19100.00
0005435508677	20920	Economy	19100.00
0005435508671	20920	Economy	19100.00
0005435508675	20920	Economy	19100.00
0005435502810	20920	Economy	19100.00
0005435518319	20920	Economy	19100.00
0005435508665	20920	Economy	19100.00
0005435508668	20920	Economy	19100.00
0005435508683	20920	Economy	19100.00
0005435508672	20920	Economy	19100.00
0005435508662	20920	Economy	19100.00
0005434573596	20920	Economy	19100.00
0005434573471	20920	Economy	19100.00
0005435502809	20920	Economy	19100.00
0005435508680	20920	Economy	19100.00
0005435518322	20920	Economy	19100.00
0005435319788	20920	Economy	19100.00
0005435518317	20920	Economy	19100.00
0005435502814	20920	Economy	19100.00
0005435319792	20920	Economy	19100.00
0005435502817	20920	Economy	19100.00
0005435518328	20920	Economy	19100.00
0005435508664	20920	Economy	19100.00
0005435508673	20920	Economy	19100.00
0005434573607	20920	Economy	19100.00
0005434573581	20920	Economy	19100.00
0005435508681	20920	Economy	19100.00
0005435518316	20920	Economy	19100.00
0005435508667	20920	Economy	19100.00
0005435319795	20920	Economy	19100.00
0005434573470	20920	Economy	19100.00
0005435518330	20920	Economy	19100.00
0005434573556	20920	Economy	19100.00
0005435502816	20920	Economy	19100.00
0005435508678	20920	Economy	19100.00
0005434573478	20920	Economy	19100.00
0005435518321	20920	Economy	19100.00
0005435502806	20920	Economy	19100.00
0005435502801	20920	Economy	19100.00
0005435502796	20920	Economy	19100.00
0005435502798	20920	Economy	19100.00
0005435518324	20920	Economy	19100.00
0005434573539	20920	Economy	19100.00
0005435508661	20920	Economy	19100.00
0005434573606	20920	Economy	19100.00
0005435502800	20920	Economy	19100.00
0005434573538	20920	Economy	19100.00
0005432693557	2953	Business	10300.00
0005432693455	2953	Business	10300.00
0005432693475	2953	Economy	3400.00
0005432693517	2953	Economy	3400.00
0005432693616	2953	Economy	3400.00
0005432693561	2953	Economy	3400.00
0005432693594	2953	Economy	3400.00
0005432693534	2953	Economy	3800.00
0005432693548	2953	Economy	3800.00
0005432693542	2953	Economy	3400.00
0005432693547	2953	Economy	3400.00
0005432693402	2953	Economy	3400.00
0005432693567	2953	Economy	3400.00
0005432693518	2953	Economy	3400.00
0005432693401	2953	Economy	3400.00
0005432693559	2953	Economy	3400.00
0005432693652	2953	Economy	3400.00
0005432693443	2953	Economy	3400.00
0005432693358	2953	Economy	3400.00
0005432693560	2953	Economy	3400.00
0005432693442	2953	Economy	3400.00
0005432693519	2953	Economy	3400.00
0005432693583	2953	Economy	3400.00
0005432693478	2953	Economy	3400.00
0005432693468	2953	Economy	3400.00
0005432693357	2953	Economy	3400.00
0005432693465	2953	Economy	3400.00
0005432693467	2953	Economy	3400.00
0005432693409	2953	Economy	3400.00
0005432693454	2953	Economy	3400.00
0005432693558	2953	Economy	3400.00
0005432693568	2953	Economy	3400.00
0005432693544	2953	Economy	3400.00
0005432693477	2953	Economy	3400.00
0005432693512	2953	Economy	3400.00
0005432693535	2953	Economy	3400.00
0005432693572	2953	Economy	3400.00
0005432693410	2953	Economy	3400.00
0005432693464	2953	Economy	3400.00
0005433124220	3019	Business	10300.00
0005432707360	3019	Business	10300.00
0005433124327	3019	Business	10300.00
0005432707356	3019	Business	10300.00
0005432707379	3019	Business	10300.00
0005432707381	3019	Business	10300.00
0005433194899	3019	Business	10300.00
0005432881060	3019	Economy	3400.00
0005432880986	3019	Economy	3400.00
0005432881072	3019	Economy	3400.00
0005433124206	3019	Economy	3400.00
0005432707380	3019	Economy	3400.00
0005432881061	3019	Economy	3800.00
0005432707363	3019	Economy	3800.00
0005432707357	3019	Economy	3800.00
0005432707368	3019	Economy	3800.00
0005432707374	3019	Economy	3400.00
0005432881073	3019	Economy	3400.00
0005432881043	3019	Economy	3400.00
0005432881020	3019	Economy	3400.00
0005432881086	3019	Economy	3400.00
0005433124177	3019	Economy	3400.00
0005432707367	3019	Economy	3400.00
0005432707378	3019	Economy	3400.00
0005433124190	3019	Economy	3400.00
0005432707377	3019	Economy	3400.00
0005432880982	3019	Economy	3400.00
0005432881011	3019	Economy	3400.00
0005433124279	3019	Economy	3400.00
0005432217842	3019	Economy	3400.00
0005432707370	3019	Economy	3400.00
0005432707359	3019	Economy	3400.00
0005432881049	3019	Economy	3400.00
0005433124258	3019	Economy	3400.00
0005433124088	3019	Economy	3400.00
0005433124166	3019	Economy	3400.00
0005432707371	3019	Economy	3400.00
0005433124312	3019	Economy	3400.00
0005432217844	3019	Economy	3400.00
0005432707372	3019	Economy	3400.00
0005432707358	3019	Economy	3400.00
0005433124230	3019	Economy	3400.00
0005432707382	3019	Economy	3400.00
0005432217843	3019	Economy	3400.00
0005432707364	3019	Economy	3400.00
0005432881044	3019	Economy	3400.00
0005432707361	3019	Economy	3400.00
0005432881062	3019	Economy	3400.00
0005432707375	3019	Economy	3400.00
0005433124171	3019	Economy	3400.00
0005433124193	3019	Economy	3400.00
0005432707373	3019	Economy	3400.00
0005432707362	3019	Economy	3400.00
0005433124169	3019	Economy	3400.00
0005432707369	3019	Economy	3400.00
0005433124170	3019	Economy	3400.00
0005432707376	3019	Economy	3400.00
0005432707365	3019	Economy	3400.00
0005432707366	3019	Economy	3400.00
0005433124207	3019	Economy	3400.00
0005432217841	3019	Economy	3400.00
0005432707247	30034	Business	10300.00
0005433124397	30034	Business	10300.00
0005433124395	30034	Business	10300.00
0005432693800	30034	Business	10300.00
0005432707083	30034	Business	10300.00
0005432707138	30034	Business	10300.00
0005432693805	30034	Business	10300.00
0005432693787	30034	Business	10300.00
0005432881157	30034	Business	10300.00
0005433124389	30034	Business	10300.00
0005432693815	30034	Business	10300.00
0005432707043	30034	Business	10300.00
0005432693808	30034	Economy	3400.00
0005432693809	30034	Economy	3400.00
0005432881160	30034	Economy	3400.00
0005432693793	30034	Economy	3400.00
0005433124411	30034	Economy	3400.00
0005432707183	30034	Economy	3400.00
0005433194924	30034	Economy	3400.00
0005433124408	30034	Economy	3400.00
0005432693806	30034	Economy	3400.00
0005432707239	30034	Economy	3400.00
0005433124390	30034	Economy	3800.00
0005432881156	30034	Economy	3800.00
0005432881158	30034	Economy	3800.00
0005433124391	30034	Economy	3800.00
0005432693795	30034	Economy	3800.00
0005433124399	30034	Economy	3400.00
0005433124402	30034	Economy	3400.00
0005432881151	30034	Economy	3400.00
0005432707161	30034	Economy	3400.00
0005433124401	30034	Economy	3400.00
0005432707222	30034	Economy	3400.00
0005432707142	30034	Economy	3400.00
0005432881159	30034	Economy	3400.00
0005433124398	30034	Economy	3400.00
0005432707184	30034	Economy	3400.00
0005432693803	30034	Economy	3400.00
0005433194926	30034	Economy	3400.00
0005432881161	30034	Economy	3400.00
0005432707232	30034	Economy	3400.00
0005432707041	30034	Economy	3400.00
0005432693811	30034	Economy	3400.00
0005433194923	30034	Economy	3400.00
0005433194925	30034	Economy	3400.00
0005432707082	30034	Economy	3400.00
0005433124393	30034	Economy	3400.00
0005432693799	30034	Economy	3400.00
0005432693792	30034	Economy	3400.00
0005432707093	30034	Economy	3400.00
0005432707143	30034	Economy	3400.00
0005432693804	30034	Economy	3400.00
0005432693796	30034	Economy	3400.00
0005432881153	30034	Economy	3400.00
0005432693813	30034	Economy	3400.00
0005433124396	30034	Economy	3400.00
0005433124407	30034	Economy	3400.00
0005433124405	30034	Economy	3400.00
0005432693801	30034	Economy	3400.00
0005433194928	30034	Economy	3400.00
0005432707099	30034	Economy	3400.00
0005432707063	30034	Economy	3400.00
0005433124394	30034	Economy	3400.00
0005432693790	30034	Economy	3400.00
0005432693802	30034	Economy	3400.00
0005432707285	30034	Economy	3400.00
0005432707248	30034	Economy	3400.00
0005433124403	30034	Economy	3400.00
0005433124400	30034	Economy	3400.00
0005432707221	30034	Economy	3400.00
0005432693798	30034	Economy	3400.00
0005432881165	30034	Economy	3400.00
0005432881154	30034	Economy	3400.00
0005433194922	30034	Economy	3400.00
0005432881164	30034	Economy	3400.00
0005433124409	30034	Economy	3400.00
0005432693788	30034	Economy	3400.00
0005433124404	30034	Economy	3400.00
0005432707144	30034	Economy	3400.00
0005432693810	30034	Economy	3400.00
0005432693789	30034	Economy	3400.00
0005432693794	30034	Economy	3400.00
0005432707101	30034	Economy	3400.00
0005432881155	30034	Economy	3400.00
0005432881152	30034	Economy	3400.00
0005433124406	30034	Economy	3400.00
0005432693791	30034	Economy	3400.00
0005432693797	30034	Economy	3400.00
0005432693812	30034	Economy	3400.00
0005433124410	30034	Economy	3400.00
0005432693807	30034	Economy	3400.00
0005432693814	30034	Economy	3400.00
0005432881163	30034	Economy	3400.00
0005432881162	30034	Economy	3400.00
0005432707087	30034	Economy	3400.00
0005433124392	30034	Economy	3400.00
0005433194927	30034	Economy	3400.00
0005434988990	23646	Economy	4000.00
0005434980455	23646	Economy	4000.00
0005434980468	23646	Economy	4000.00
0005434980481	23646	Economy	3600.00
0005434980456	23646	Economy	3600.00
0005434988988	23646	Economy	3600.00
0005434980462	23646	Economy	3600.00
0005434980464	23646	Economy	3600.00
0005434980469	23646	Economy	3600.00
0005434980480	23646	Economy	3600.00
0005434980471	23646	Economy	3600.00
0005434988985	23646	Economy	3600.00
0005434980454	23646	Economy	3600.00
0005434988979	23646	Economy	3600.00
0005434980453	23646	Economy	3600.00
0005434988986	23646	Economy	3600.00
0005434980461	23646	Economy	3600.00
0005434988991	23646	Economy	3600.00
0005434980477	23646	Economy	3600.00
0005434988987	23646	Economy	3600.00
0005434980470	23646	Economy	3600.00
0005434980478	23646	Economy	3600.00
0005434980482	23646	Economy	3600.00
0005434988976	23646	Economy	3600.00
0005434988980	23646	Economy	3600.00
0005434980463	23646	Economy	3600.00
0005434988984	23646	Economy	3600.00
0005434980467	23646	Economy	3600.00
0005434988978	23646	Economy	3600.00
0005434980474	23646	Economy	3600.00
0005434988975	23646	Economy	3600.00
0005434988989	23646	Economy	3600.00
0005434980466	23646	Economy	3600.00
0005434988981	23646	Economy	3600.00
0005434980479	23646	Economy	3600.00
0005434980472	23646	Economy	3600.00
0005434988983	23646	Economy	3600.00
0005434980458	23646	Economy	3600.00
0005434980476	23646	Economy	3600.00
0005434980459	23646	Economy	3600.00
0005434980473	23646	Economy	3600.00
0005434980457	23646	Economy	3600.00
0005434980465	23646	Economy	3600.00
0005434988977	23646	Economy	3600.00
0005434988982	23646	Economy	3600.00
0005434980460	23646	Economy	3600.00
0005434980475	23646	Economy	3600.00
0005434988920	27551	Economy	4000.00
0005434988889	27551	Economy	4000.00
0005434980243	27551	Economy	4000.00
0005434980159	27551	Economy	3600.00
0005434988902	27551	Economy	3600.00
0005434980181	27551	Economy	3600.00
0005434980258	27551	Economy	3600.00
0005434988911	27551	Economy	3600.00
0005434988907	27551	Economy	3600.00
0005434980294	27551	Economy	3600.00
0005434980187	27551	Economy	3600.00
0005434980154	27551	Economy	3600.00
0005434980214	27551	Economy	3600.00
0005434980215	27551	Economy	3600.00
0005434980185	27551	Economy	3600.00
0005434980149	27551	Economy	3600.00
0005434988886	27551	Economy	3600.00
0005434980160	27551	Economy	3600.00
0005434980155	27551	Economy	3600.00
0005434980165	27551	Economy	3600.00
0005434988837	27551	Economy	3600.00
0005434980135	27551	Economy	3600.00
0005434980200	27551	Economy	3600.00
0005434980208	27551	Economy	3600.00
0005434980244	27551	Economy	3600.00
0005434980134	27551	Economy	3600.00
0005434988836	27551	Economy	3600.00
0005434980295	27551	Economy	3600.00
0005434988888	27551	Economy	3600.00
0005434980186	27551	Economy	3600.00
0005434980216	27551	Economy	3600.00
0005434988919	27551	Economy	3600.00
0005434980209	27551	Economy	3600.00
0005434980136	27551	Economy	3600.00
0005434980213	27551	Economy	3600.00
0005434302559	10296	Economy	21600.00
0005433111526	10296	Economy	21600.00
0005433113563	10296	Economy	19700.00
0005434302557	10296	Economy	19700.00
0005433111521	10296	Economy	19700.00
0005433111522	10296	Economy	19700.00
0005434302555	10296	Economy	19700.00
0005433113565	10296	Economy	19700.00
0005434302558	10296	Economy	19700.00
0005433111523	10296	Economy	19700.00
0005433113575	10296	Economy	19700.00
0005434302556	10296	Economy	19700.00
0005434302891	10296	Economy	19700.00
0005434302514	19609	Economy	21600.00
0005433113587	19609	Economy	21600.00
0005434302515	19609	Economy	19700.00
0005433113588	19609	Economy	19700.00
0005434302528	19609	Economy	19700.00
0005435070308	3534	Business	26900.00
0005435939911	3534	Business	26900.00
0005435070316	3534	Business	26900.00
0005435070297	3534	Business	26900.00
0005435070310	3534	Business	26900.00
0005435925444	3534	Business	26900.00
0005435070296	3534	Business	26900.00
0005435070293	3534	Business	26900.00
0005435070295	3534	Business	26900.00
0005435070299	3534	Business	26900.00
0005435070321	3534	Business	26900.00
0005435070304	3534	Economy	9000.00
0005435925558	3534	Economy	9000.00
0005435070317	3534	Economy	9000.00
0005435070311	3534	Economy	9000.00
0005435925437	3534	Economy	9000.00
0005435070319	3534	Economy	9000.00
0005435070307	3534	Economy	9000.00
0005435925515	3534	Economy	9900.00
0005435070277	3534	Economy	9900.00
0005435925493	3534	Economy	9900.00
0005435925504	3534	Economy	9900.00
0005435070286	3534	Economy	9000.00
0005435925505	3534	Economy	9000.00
0005435070309	3534	Economy	9000.00
0005435070318	3534	Economy	9000.00
0005435925445	3534	Economy	9000.00
0005435719082	3534	Economy	9000.00
0005435070305	3534	Economy	9000.00
0005435070279	3534	Economy	9000.00
0005435925469	3534	Economy	9000.00
0005435070287	3534	Economy	9000.00
0005435070282	3534	Economy	9000.00
0005435070294	3534	Economy	9000.00
0005435070285	3534	Economy	9000.00
0005435070324	3534	Economy	9000.00
0005435925535	3534	Economy	9000.00
0005435070314	3534	Economy	9000.00
0005435070283	3534	Economy	9000.00
0005435070276	3534	Economy	9000.00
0005435925495	3534	Economy	9000.00
0005435070291	3534	Economy	9000.00
0005435719080	3534	Economy	9000.00
0005435070306	3534	Economy	9000.00
0005435070280	3534	Economy	9000.00
0005435070313	3534	Economy	9000.00
0005435719081	3534	Economy	9000.00
0005435925501	3534	Economy	9000.00
0005435070303	3534	Economy	9000.00
0005435939908	3534	Economy	9000.00
0005435070281	3534	Economy	9000.00
0005435070320	3534	Economy	9000.00
0005435719077	3534	Economy	9000.00
0005435925496	3534	Economy	9000.00
0005435070290	3534	Economy	9000.00
0005435070323	3534	Economy	9000.00
0005435070288	3534	Economy	9000.00
0005435939906	3534	Economy	9000.00
0005435070322	3534	Economy	9000.00
0005435925494	3534	Economy	9000.00
0005435070289	3534	Economy	9000.00
0005435070298	3534	Economy	9000.00
0005435925512	3534	Economy	9000.00
0005435070284	3534	Economy	9000.00
0005435070292	3534	Economy	9000.00
0005435925500	3534	Economy	9000.00
0005435719076	3534	Economy	9000.00
0005435070302	3534	Economy	9000.00
0005435070325	3534	Economy	9000.00
0005435070327	3534	Economy	9000.00
0005435070328	3534	Economy	9000.00
0005435070315	3534	Economy	9000.00
0005435070278	3534	Economy	9000.00
0005435070326	3534	Economy	9000.00
0005435070300	3534	Economy	9000.00
0005435070312	3534	Economy	9000.00
0005435939907	3534	Economy	9000.00
0005435719079	3534	Economy	9000.00
0005435939909	3534	Economy	9000.00
0005435070301	3534	Economy	9000.00
0005435719078	3534	Economy	9000.00
0005435925619	15292	Business	26900.00
0005435069832	15292	Business	26900.00
0005435069709	15292	Business	26900.00
0005435925622	15292	Business	26900.00
0005435939935	15292	Business	26900.00
0005435069737	15292	Business	26900.00
0005435069589	15292	Business	26900.00
0005435925629	15292	Business	26900.00
0005435069746	15292	Business	26900.00
0005435939936	15292	Business	26900.00
0005435939934	15292	Business	26900.00
0005435925610	15292	Economy	9000.00
0005435069629	15292	Economy	9000.00
0005435069698	15292	Economy	9000.00
0005435925601	15292	Economy	9000.00
0005435925603	15292	Economy	9000.00
0005435069926	15292	Economy	9000.00
0005435925609	15292	Economy	9000.00
0005435939931	15292	Economy	9000.00
0005435925627	15292	Economy	9000.00
0005435069905	15292	Economy	9000.00
0005435925620	15292	Economy	9900.00
0005435069946	15292	Economy	9900.00
0005435925614	15292	Economy	9900.00
0005435069810	15292	Economy	9900.00
0005435069947	15292	Economy	9000.00
0005435069983	15292	Economy	9000.00
0005435069940	15292	Economy	9000.00
0005435950297	15292	Economy	9000.00
0005435925618	15292	Economy	9000.00
0005435069714	15292	Economy	9000.00
0005435925628	15292	Economy	9000.00
0005435069943	15292	Economy	9000.00
0005435069716	15292	Economy	9000.00
0005435925623	15292	Economy	9000.00
0005435939933	15292	Economy	9000.00
0005435069759	15292	Economy	9000.00
0005435939937	15292	Economy	9000.00
0005435069761	15292	Economy	9000.00
0005435925608	15292	Economy	9000.00
0005435925611	15292	Economy	9000.00
0005435069472	15292	Economy	9000.00
0005435925626	15292	Economy	9000.00
0005435069754	15292	Economy	9000.00
0005435069939	15292	Economy	9000.00
0005435069712	15292	Economy	9000.00
0005435925612	15292	Economy	9000.00
0005435069888	15292	Economy	9000.00
0005435069758	15292	Economy	9000.00
0005435069811	15292	Economy	9000.00
0005435069877	15292	Economy	9000.00
0005435069892	15292	Economy	9000.00
0005435069659	15292	Economy	9000.00
0005435925605	15292	Economy	9000.00
0005435069713	15292	Economy	9000.00
0005435925613	15292	Economy	9000.00
0005435069812	15292	Economy	9000.00
0005435925625	15292	Economy	9000.00
0005435069628	15292	Economy	9000.00
0005435925616	15292	Economy	9000.00
0005435925624	15292	Economy	9000.00
0005435069627	15292	Economy	9000.00
0005435069657	15292	Economy	9000.00
0005435069996	15292	Economy	9000.00
0005435925615	15292	Economy	9000.00
0005435939932	15292	Economy	9000.00
0005435069685	15292	Economy	9000.00
0005435069893	15292	Economy	9000.00
0005435925617	15292	Economy	9000.00
0005435069889	15292	Economy	9000.00
0005435925604	15292	Economy	9000.00
0005435925606	15292	Economy	9000.00
0005435925607	15292	Economy	9000.00
0005435939938	15292	Economy	9000.00
0005435069658	15292	Economy	9000.00
0005435069864	15292	Economy	9000.00
0005435069942	15292	Economy	9000.00
0005435925602	15292	Economy	9000.00
0005435925621	15292	Economy	9000.00
0005435069792	15292	Economy	9000.00
0005435069703	15292	Economy	9000.00
0005435069684	15292	Economy	9000.00
0005435069646	15292	Economy	9000.00
0005435069896	15292	Economy	9000.00
0005435069769	15292	Economy	9000.00
0005432659755	18120	Economy	5900.00
0005432659754	18120	Economy	5900.00
0005432658641	18120	Economy	5900.00
0005432658640	18120	Economy	5900.00
0005432660867	18120	Economy	5900.00
0005432660866	18120	Economy	5900.00
0005432659756	18120	Economy	5900.00
0005432660845	26377	Economy	5900.00
0005432667484	26377	Economy	5900.00
0005432667481	26377	Economy	5900.00
0005432667485	26377	Economy	5900.00
0005432660844	26377	Economy	5900.00
0005432667482	26377	Economy	5900.00
0005432660850	26377	Economy	5900.00
0005432664161	26377	Economy	5900.00
0005432664160	26377	Economy	5900.00
0005433102984	137	Business	20000.00
0005433102964	137	Business	20000.00
0005432677634	137	Business	20000.00
0005433102888	137	Business	20000.00
0005432920148	137	Business	20000.00
0005432677648	137	Business	20000.00
0005433102724	137	Business	20000.00
0005433102897	137	Business	20000.00
0005433102958	137	Business	20000.00
0005432901879	137	Business	20000.00
0005433102935	137	Business	20000.00
0005433102857	137	Business	20000.00
0005433102832	137	Business	20000.00
0005433102803	137	Business	20000.00
0005432901890	137	Business	20000.00
0005433102981	137	Business	20000.00
0005433102830	137	Business	20000.00
0005432920139	137	Economy	7300.00
0005433102902	137	Economy	7300.00
0005432920236	137	Economy	7300.00
0005433102879	137	Economy	7300.00
0005433102931	137	Economy	6700.00
0005432677614	137	Economy	6700.00
0005432920274	137	Economy	6700.00
0005433102843	137	Economy	6700.00
0005433102900	137	Economy	6700.00
0005433102954	137	Economy	6700.00
0005432920140	137	Economy	6700.00
0005433102874	137	Economy	6700.00
0005433102652	137	Economy	6700.00
0005433102974	137	Economy	6700.00
0005433102721	137	Economy	6700.00
0005432901878	137	Economy	6700.00
0005433102921	137	Economy	6700.00
0005432920159	137	Economy	6700.00
0005433102634	137	Economy	6700.00
0005433102856	137	Economy	6700.00
0005433102944	137	Economy	6700.00
0005433102901	137	Economy	6700.00
0005432901856	137	Economy	6700.00
0005433102887	137	Economy	6700.00
0005433102934	137	Economy	6700.00
0005433102893	137	Economy	6700.00
0005433102797	137	Economy	6700.00
0005433102922	137	Economy	6700.00
0005433102636	137	Economy	6700.00
0005433103003	137	Economy	6700.00
0005432920147	137	Economy	6700.00
0005433102953	137	Economy	6700.00
0005432677625	137	Economy	6700.00
0005433102871	137	Economy	6700.00
0005432901896	137	Economy	6700.00
0005432901846	137	Economy	6700.00
0005433102770	137	Economy	6700.00
0005432920160	137	Economy	6700.00
0005433102796	137	Economy	6700.00
0005433102991	137	Economy	6700.00
0005433102771	137	Economy	6700.00
0005432901853	137	Economy	6700.00
0005432677620	137	Economy	6700.00
0005432920206	137	Economy	6700.00
0005433102965	137	Economy	6700.00
0005432901871	137	Economy	6700.00
0005432920163	137	Economy	7300.00
0005432677617	137	Economy	6700.00
0005433102966	137	Economy	6700.00
0005432677635	137	Economy	6700.00
0005432920087	137	Economy	6700.00
0005433103006	137	Economy	6700.00
0005432901930	137	Economy	6700.00
0005433102943	137	Economy	6700.00
0005432901942	137	Economy	6700.00
0005433102896	137	Economy	6700.00
0005432901898	137	Economy	6700.00
0005433102948	137	Economy	6700.00
0005433102911	137	Economy	6700.00
0005432920167	137	Economy	6700.00
0005433102957	137	Economy	6700.00
0005433102932	137	Economy	6700.00
0005432901931	137	Economy	6700.00
0005432920232	137	Economy	6700.00
0005432901895	137	Economy	6700.00
0005432677636	137	Economy	6700.00
0005432920095	137	Economy	6700.00
0005433102903	137	Economy	6700.00
0005433103004	137	Economy	6700.00
0005432920237	137	Economy	6700.00
0005433102880	137	Economy	6700.00
0005433102914	137	Economy	6700.00
0005433102881	137	Economy	6700.00
0005432920133	137	Economy	6700.00
0005433102831	137	Economy	6700.00
0005432677633	137	Economy	6700.00
0005432901932	137	Economy	6700.00
0005432901959	137	Economy	6700.00
0005432901880	137	Economy	6700.00
0005433102985	137	Economy	6700.00
0005433102870	137	Economy	6700.00
0005432920149	137	Economy	6700.00
0005432901941	137	Economy	6700.00
0005432901870	137	Economy	6700.00
0005433102976	137	Economy	6700.00
0005433102898	137	Economy	6700.00
0005433102851	137	Economy	6700.00
0005433102892	137	Economy	6700.00
0005433102969	137	Economy	6700.00
0005433102980	137	Economy	6700.00
0005432901872	137	Economy	6700.00
0005432677630	137	Economy	6700.00
0005432901864	137	Economy	6700.00
0005433102635	137	Economy	6700.00
0005433102842	137	Economy	6700.00
0005433102908	137	Economy	6700.00
0005433102875	137	Economy	6700.00
0005432920291	137	Economy	6700.00
0005432262959	9	Business	20000.00
0005433477079	9	Business	20000.00
0005433477063	9	Business	20000.00
0005432262958	9	Business	20000.00
0005433477076	9	Business	20000.00
0005432262970	9	Business	20000.00
0005432818183	9	Business	20000.00
0005432818155	9	Business	20000.00
0005432262963	9	Business	20000.00
0005432818181	9	Business	20000.00
0005432289064	9	Business	20000.00
0005432818166	9	Business	20000.00
0005432262974	9	Business	20000.00
0005432818177	9	Business	20000.00
0005432263002	9	Business	20000.00
0005432262975	9	Business	20000.00
0005432262962	9	Business	20000.00
0005432818172	9	Economy	7300.00
0005432818162	9	Economy	7300.00
0005433687746	9	Economy	6700.00
0005433477072	9	Economy	6700.00
0005432753353	9	Economy	6700.00
0005432818180	9	Economy	6700.00
0005432753351	9	Economy	6700.00
0005432262997	9	Economy	6700.00
0005432262988	9	Economy	6700.00
0005433477070	9	Economy	6700.00
0005432818158	9	Economy	6700.00
0005432818164	9	Economy	6700.00
0005432262964	9	Economy	6700.00
0005433477067	9	Economy	6700.00
0005433477087	9	Economy	6700.00
0005432207720	9	Economy	6700.00
0005432818176	9	Economy	6700.00
0005433477073	9	Economy	6700.00
0005433477055	9	Economy	6700.00
0005432262989	9	Economy	6700.00
0005432753335	9	Economy	6700.00
0005433477082	9	Economy	6700.00
0005433477074	9	Economy	6700.00
0005432262981	9	Economy	6700.00
0005432818154	9	Economy	6700.00
0005433690951	9	Economy	6700.00
0005432262980	9	Economy	6700.00
0005433477058	9	Economy	6700.00
0005433477088	9	Economy	6700.00
0005432818167	9	Economy	6700.00
0005432818178	9	Economy	6700.00
0005432818170	9	Economy	6700.00
0005432262995	9	Economy	6700.00
0005433477066	9	Economy	6700.00
0005432753334	9	Economy	6700.00
0005432818163	9	Economy	6700.00
0005432818169	9	Economy	6700.00
0005433477078	9	Economy	6700.00
0005432818156	9	Economy	6700.00
0005432262982	9	Economy	6700.00
0005432207721	9	Economy	6700.00
0005433477089	9	Economy	6700.00
0005432818153	9	Economy	6700.00
0005433690947	9	Economy	6700.00
0005432262984	9	Economy	6700.00
0005433477081	9	Economy	6700.00
0005432262969	9	Economy	6700.00
0005432262979	9	Economy	6700.00
0005432262987	9	Economy	6700.00
0005432818160	9	Economy	7300.00
0005433477084	9	Economy	7300.00
0005433477075	9	Economy	7300.00
0005433477059	9	Economy	6700.00
0005432818182	9	Economy	6700.00
0005432263001	9	Economy	7300.00
0005433477056	9	Economy	6700.00
0005433477061	9	Economy	6700.00
0005432289063	9	Economy	6700.00
0005432262978	9	Economy	6700.00
0005433477090	9	Economy	6700.00
0005434157716	9	Economy	6700.00
0005433477071	9	Economy	6700.00
0005433477064	9	Economy	6700.00
0005432262994	9	Economy	6700.00
0005432262993	9	Economy	6700.00
0005432262992	9	Economy	6700.00
0005432262996	9	Economy	6700.00
0005432818168	9	Economy	6700.00
0005433477068	9	Economy	6700.00
0005433477062	9	Economy	6700.00
0005432262968	9	Economy	6700.00
0005434153565	9	Economy	6700.00
0005432262966	9	Economy	6700.00
0005432262986	9	Economy	6700.00
0005432262967	9	Economy	6700.00
0005432262976	9	Economy	6700.00
0005432262977	9	Economy	6700.00
0005432262971	9	Economy	6700.00
0005432262990	9	Economy	6700.00
0005432818159	9	Economy	6700.00
0005432262972	9	Economy	6700.00
0005432262973	9	Economy	6700.00
0005433477069	9	Economy	6700.00
0005433477085	9	Economy	6700.00
0005432262991	9	Economy	6700.00
0005432818179	9	Economy	6700.00
0005432262983	9	Economy	6700.00
0005434153564	9	Economy	6700.00
0005432818161	9	Economy	6700.00
0005432818171	9	Economy	6700.00
0005432753352	9	Economy	6700.00
0005432262985	9	Economy	6700.00
0005434153566	9	Economy	6700.00
0005433477060	9	Economy	6700.00
0005433477080	9	Economy	6700.00
0005433477057	9	Economy	6700.00
0005432262999	9	Economy	6700.00
0005432262957	9	Economy	6700.00
0005433477077	9	Economy	6700.00
0005432818157	9	Economy	6700.00
0005433477091	9	Economy	6700.00
0005432262960	9	Economy	6700.00
0005432263000	9	Economy	6700.00
0005432262961	9	Economy	6700.00
0005432818165	9	Economy	6700.00
0005432818174	9	Economy	6700.00
0005432262998	9	Economy	6700.00
0005432818175	9	Economy	6700.00
0005432818173	9	Economy	6700.00
0005433477065	9	Economy	6700.00
0005432289062	9	Economy	6700.00
0005433477083	9	Economy	6700.00
0005433477086	9	Economy	6700.00
0005432262965	9	Economy	6700.00
0005433103442	8042	Business	20000.00
0005432020894	8042	Business	20000.00
0005433103390	8042	Business	20000.00
0005432020893	8042	Business	20000.00
0005432020880	8042	Business	20000.00
0005433103440	8042	Business	20000.00
0005433103424	8042	Business	20000.00
0005432753379	8042	Business	20000.00
0005432920346	8042	Business	20000.00
0005432020897	8042	Business	20000.00
0005432920349	8042	Business	20000.00
0005432020901	8042	Business	20000.00
0005433103387	8042	Business	20000.00
0005432020904	8042	Business	20000.00
0005433103428	8042	Business	20000.00
0005432920350	8042	Business	20000.00
0005433103436	8042	Business	20000.00
0005433103441	8042	Business	20000.00
0005433103411	8042	Business	20000.00
0005432020899	8042	Business	20000.00
0005432020898	8042	Business	20000.00
0005433103388	8042	Business	20000.00
0005433103438	8042	Economy	7300.00
0005432677667	8042	Economy	7300.00
0005432920353	8042	Economy	7300.00
0005432753381	8042	Economy	7300.00
0005433103385	8042	Economy	7300.00
0005432020886	8042	Economy	7300.00
0005433103430	8042	Economy	6700.00
0005432920356	8042	Economy	6700.00
0005432020884	8042	Economy	6700.00
0005432751604	8042	Economy	6700.00
0005432045660	8042	Economy	6700.00
0005432020892	8042	Economy	6700.00
0005433103404	8042	Economy	6700.00
0005432045659	8042	Economy	6700.00
0005432392069	8042	Economy	6700.00
0005433103391	8042	Economy	6700.00
0005433103398	8042	Economy	6700.00
0005433103410	8042	Economy	6700.00
0005433103426	8042	Economy	6700.00
0005433103433	8042	Economy	6700.00
0005432020883	8042	Economy	6700.00
0005433103396	8042	Economy	6700.00
0005432920351	8042	Economy	6700.00
0005433103415	8042	Economy	6700.00
0005433103439	8042	Economy	6700.00
0005433103399	8042	Economy	6700.00
0005433103393	8042	Economy	6700.00
0005432020895	8042	Economy	6700.00
0005433103382	8042	Economy	6700.00
0005433103427	8042	Economy	6700.00
0005433103425	8042	Economy	6700.00
0005433103408	8042	Economy	6700.00
0005433103416	8042	Economy	6700.00
0005433103419	8042	Economy	6700.00
0005432677668	8042	Economy	6700.00
0005432920357	8042	Economy	6700.00
0005433103418	8042	Economy	6700.00
0005433103402	8042	Economy	6700.00
0005432751606	8042	Economy	6700.00
0005433103437	8042	Economy	6700.00
0005433103414	8042	Economy	6700.00
0005432020902	8042	Economy	6700.00
0005433103422	8042	Economy	6700.00
0005432020896	8042	Economy	6700.00
0005432920341	8042	Economy	6700.00
0005432020887	8042	Economy	6700.00
0005433103394	8042	Economy	6700.00
0005433103432	8042	Economy	6700.00
0005433103429	8042	Economy	6700.00
0005432020890	8042	Economy	7300.00
0005432392072	8042	Economy	6700.00
0005433103389	8042	Economy	7300.00
0005433103405	8042	Economy	7300.00
0005432677669	8042	Economy	6700.00
0005433103395	8042	Economy	6700.00
0005433103431	8042	Economy	6700.00
0005432920343	8042	Economy	6700.00
0005432920344	8042	Economy	7300.00
0005433103392	8042	Economy	6700.00
0005432920352	8042	Economy	6700.00
0005432753380	8042	Economy	6700.00
0005432920338	8042	Economy	6700.00
0005432920342	8042	Economy	6700.00
0005432392070	8042	Economy	6700.00
0005432044591	8042	Economy	6700.00
0005432920355	8042	Economy	6700.00
0005433103443	8042	Economy	6700.00
0005432020878	8042	Economy	6700.00
0005432020881	8042	Economy	6700.00
0005433103383	8042	Economy	6700.00
0005433103409	8042	Economy	6700.00
0005433103406	8042	Economy	6700.00
0005432677666	8042	Economy	6700.00
0005432920339	8042	Economy	6700.00
0005433103400	8042	Economy	6700.00
0005433103401	8042	Economy	6700.00
0005433103412	8042	Economy	6700.00
0005433103413	8042	Economy	6700.00
0005432920337	8042	Economy	6700.00
0005433103397	8042	Economy	6700.00
0005432920358	8042	Economy	6700.00
0005433103435	8042	Economy	6700.00
0005433103417	8042	Economy	6700.00
0005432020900	8042	Economy	6700.00
0005432920348	8042	Economy	6700.00
0005432920340	8042	Economy	6700.00
0005433103381	8042	Economy	6700.00
0005433103421	8042	Economy	6700.00
0005433103434	8042	Economy	6700.00
0005432020882	8042	Economy	6700.00
0005432920354	8042	Economy	6700.00
0005433103407	8042	Economy	6700.00
0005432020891	8042	Economy	6700.00
0005432751605	8042	Economy	6700.00
0005433103386	8042	Economy	6700.00
0005433103403	8042	Economy	6700.00
0005432044590	8042	Economy	6700.00
0005432920347	8042	Economy	6700.00
0005433103420	8042	Economy	6700.00
0005432020889	8042	Economy	6700.00
0005433103384	8042	Economy	6700.00
0005432751607	8042	Economy	6700.00
0005432020879	8042	Economy	6700.00
0005432020903	8042	Economy	6700.00
0005432020888	8042	Economy	6700.00
0005432920345	8042	Economy	6700.00
0005432020885	8042	Economy	6700.00
0005432044589	8042	Economy	6700.00
0005432045661	8042	Economy	6700.00
0005433103423	8042	Economy	6700.00
0005432392071	8042	Economy	6700.00
0005432817990	8039	Business	20000.00
0005432902013	8039	Business	20000.00
0005432902017	8039	Business	20000.00
0005432817989	8039	Business	20000.00
0005432817941	8039	Business	20000.00
0005432817781	8039	Business	20000.00
0005432817960	8039	Business	20000.00
0005432902023	8039	Economy	7300.00
0005432902014	8039	Economy	6700.00
0005432817988	8039	Economy	6700.00
0005432002124	8039	Economy	6700.00
0005432817858	8039	Economy	6700.00
0005432902030	8039	Economy	6700.00
0005432817883	8039	Economy	6700.00
0005432817828	8039	Economy	6700.00
0005432817961	8039	Economy	6700.00
0005432817855	8039	Economy	6700.00
0005432902026	8039	Economy	6700.00
0005432817851	8039	Economy	6700.00
0005432902019	8039	Economy	7300.00
0005432902021	8039	Economy	6700.00
0005432817807	8039	Economy	6700.00
0005432902016	8039	Economy	6700.00
0005432902015	8039	Economy	6700.00
0005432902028	8039	Economy	6700.00
0005432902022	8039	Economy	6700.00
0005432902024	8039	Economy	6700.00
0005432817962	8039	Economy	6700.00
0005432817951	8039	Economy	6700.00
0005432817871	8039	Economy	6700.00
0005432818056	8039	Economy	6700.00
0005432902025	8039	Economy	6700.00
0005432902029	8039	Economy	6700.00
0005432817950	8039	Economy	6700.00
0005432902027	8039	Economy	6700.00
0005432902018	8039	Economy	6700.00
0005432002125	8039	Economy	6700.00
0005432817844	8039	Economy	6700.00
0005432817985	8039	Economy	6700.00
0005432817940	8039	Economy	6700.00
0005432817944	8039	Economy	6700.00
0005432002126	8039	Economy	6700.00
0005432817850	8039	Economy	6700.00
0005432817856	8039	Economy	6700.00
0005432902020	8039	Economy	6700.00
0005432817784	8039	Economy	6700.00
0005434175820	9674	Economy	6900.00
0005434175823	9674	Economy	6900.00
0005434175816	9674	Economy	6900.00
0005434175819	9674	Economy	6900.00
0005434175817	9674	Economy	6900.00
0005433870783	9674	Economy	6900.00
0005433870784	9674	Economy	6900.00
0005434175818	9674	Economy	6900.00
0005433870782	9674	Economy	6900.00
0005434175851	32352	Economy	6900.00
0005434175854	32352	Economy	6900.00
0005434175852	32352	Economy	6900.00
0005433870757	32352	Economy	6900.00
0005433870767	32352	Economy	6900.00
0005434175853	32352	Economy	6900.00
0005435127349	3505	Business	35000.00
0005435127341	3505	Business	35000.00
0005432611794	3505	Business	35000.00
0005434880437	3505	Business	35000.00
0005435626616	3505	Business	35000.00
0005435626619	3505	Business	35000.00
0005434880419	3505	Business	35000.00
0005435626620	3505	Business	35000.00
0005434938610	3505	Business	35000.00
0005434880461	3505	Business	35000.00
0005434427289	3505	Business	35000.00
0005435127336	3505	Business	35000.00
0005434427305	3505	Business	35000.00
0005435903008	3505	Business	35000.00
0005434427314	3505	Business	35000.00
0005435902920	3505	Business	35000.00
0005434880483	3505	Business	35000.00
0005435626609	3505	Business	35000.00
0005435127344	3505	Business	35000.00
0005434427297	3505	Business	35000.00
0005434938596	3505	Business	35000.00
0005434880413	3505	Comfort	19900.00
0005435127348	3505	Comfort	19900.00
0005434880492	3505	Comfort	19900.00
0005434880407	3505	Comfort	19900.00
0005434938599	3505	Comfort	19900.00
0005432800122	3505	Comfort	19900.00
0005434427306	3505	Comfort	19900.00
0005434880411	3505	Comfort	19900.00
0005434880466	3505	Comfort	19900.00
0005434880409	3505	Comfort	19900.00
0005434880476	3505	Comfort	19900.00
0005432800112	3505	Comfort	19900.00
0005435902914	3505	Comfort	19900.00
0005434938606	3505	Comfort	19900.00
0005434880447	3505	Comfort	19900.00
0005434880494	3505	Comfort	19900.00
0005434427292	3505	Comfort	19900.00
0005434880478	3505	Comfort	19900.00
0005434427298	3505	Comfort	19900.00
0005432800129	3505	Comfort	19900.00
0005434880423	3505	Comfort	19900.00
0005432800119	3505	Comfort	19900.00
0005435626610	3505	Comfort	19900.00
0005432800120	3505	Comfort	19900.00
0005434938607	3505	Comfort	19900.00
0005434880442	3505	Economy	11700.00
0005435626621	3505	Economy	11700.00
0005434427308	3505	Economy	11700.00
0005435127327	3505	Economy	11700.00
0005434880459	3505	Economy	11700.00
0005434427315	3505	Economy	11700.00
0005434880481	3505	Economy	11700.00
0005432188686	3505	Economy	11700.00
0005432611792	3505	Economy	11700.00
0005435127346	3505	Economy	11700.00
0005434938597	3505	Economy	11700.00
0005434880415	3505	Economy	11700.00
0005435127312	3505	Economy	11700.00
0005434880470	3505	Economy	11700.00
0005435127316	3505	Economy	11700.00
0005434427290	3505	Economy	11700.00
0005435626614	3505	Economy	11700.00
0005434427311	3505	Economy	11700.00
0005434427299	3505	Economy	11700.00
0005434427312	3505	Economy	11700.00
0005434880460	3505	Economy	11700.00
0005434880454	3505	Economy	11700.00
0005434880473	3505	Economy	11700.00
0005434880422	3505	Economy	11700.00
0005434427296	3505	Economy	11700.00
0005434880500	3505	Economy	11700.00
0005434880456	3505	Economy	11700.00
0005434880464	3505	Economy	11700.00
0005435127315	3505	Economy	11700.00
0005432800132	3505	Economy	11700.00
0005434938595	3505	Economy	11700.00
0005432800131	3505	Economy	11700.00
0005432800111	3505	Economy	11700.00
0005432800123	3505	Economy	11700.00
0005432183519	3505	Economy	11700.00
0005434880495	3505	Economy	11700.00
0005434880405	3505	Economy	11700.00
0005432800127	3505	Economy	11700.00
0005434880458	3505	Economy	11700.00
0005435127339	3505	Economy	11700.00
0005434880455	3505	Economy	11700.00
0005434880445	3505	Economy	11700.00
0005435127318	3505	Economy	11700.00
0005435902923	3505	Economy	11700.00
0005434427304	3505	Economy	11700.00
0005434880452	3505	Economy	11700.00
0005434880487	3505	Economy	11700.00
0005435127322	3505	Economy	11700.00
0005432800116	3505	Economy	11700.00
0005435127329	3505	Economy	11700.00
0005435127333	3505	Economy	11700.00
0005435626622	3505	Economy	11700.00
0005434880416	3505	Economy	11700.00
0005434880488	3505	Economy	12800.00
0005434938605	3505	Economy	12800.00
0005435127330	3505	Economy	11700.00
0005434880490	3505	Economy	11700.00
0005434880449	3505	Economy	12800.00
0005434427295	3505	Economy	11700.00
0005434427300	3505	Economy	12800.00
0005435914707	3505	Economy	11700.00
0005434427291	3505	Economy	11700.00
0005435903004	3505	Economy	11700.00
0005434880493	3505	Economy	11700.00
0005432800126	3505	Economy	11700.00
0005434880428	3505	Economy	11700.00
0005435626613	3505	Economy	11700.00
0005432800117	3505	Economy	11700.00
0005434880441	3505	Economy	11700.00
0005434880443	3505	Economy	11700.00
0005435902874	3505	Economy	11700.00
0005435903009	3505	Economy	11700.00
0005434880498	3505	Economy	11700.00
0005435903044	3505	Economy	11700.00
0005435127338	3505	Economy	11700.00
0005432613958	3505	Economy	11700.00
0005434880421	3505	Economy	11700.00
0005435127328	3505	Economy	11700.00
0005432188685	3505	Economy	11700.00
0005434880465	3505	Economy	11700.00
0005432611796	3505	Economy	11700.00
0005434880432	3505	Economy	11700.00
0005434880491	3505	Economy	11700.00
0005434938608	3505	Economy	11700.00
0005434880427	3505	Economy	11700.00
0005434880418	3505	Economy	11700.00
0005434880417	3505	Economy	11700.00
0005434427309	3505	Economy	11700.00
0005434880430	3505	Economy	11700.00
0005434427317	3505	Economy	11700.00
0005434938609	3505	Economy	11700.00
0005434427310	3505	Economy	11700.00
0005434880499	3505	Economy	11700.00
0005435626611	3505	Economy	11700.00
0005432800130	3505	Economy	11700.00
0005434427301	3505	Economy	11700.00
0005432800128	3505	Economy	11700.00
0005434880450	3505	Economy	11700.00
0005432183517	3505	Economy	11700.00
0005435626615	3505	Economy	11700.00
0005434427318	3505	Economy	11700.00
0005434880420	3505	Economy	11700.00
0005434880480	3505	Economy	11700.00
0005432188683	3505	Economy	11700.00
0005434427313	3505	Economy	11700.00
0005435626618	3505	Economy	11700.00
0005435127347	3505	Economy	11700.00
0005435626617	3505	Economy	11700.00
0005435127313	3505	Economy	11700.00
0005434427302	3505	Economy	11700.00
0005432611795	3505	Economy	11700.00
0005435127340	3505	Economy	11700.00
0005434938602	3505	Economy	11700.00
0005435913968	3505	Economy	11700.00
0005432611793	3505	Economy	11700.00
0005434880425	3505	Economy	11700.00
0005435127343	3505	Economy	11700.00
0005434880453	3505	Economy	11700.00
0005435127350	3505	Economy	11700.00
0005434880431	3505	Economy	11700.00
0005434427319	3505	Economy	11700.00
0005435127326	3505	Economy	11700.00
0005432800125	3505	Economy	11700.00
0005432188684	3505	Economy	11700.00
0005432188687	3505	Economy	11700.00
0005435903007	3505	Economy	11700.00
0005435902924	3505	Economy	11700.00
0005434427303	3505	Economy	11700.00
0005434880468	3505	Economy	11700.00
0005435903043	3505	Economy	11700.00
0005432800134	3505	Economy	11700.00
0005432800137	3505	Economy	11700.00
0005432800110	3505	Economy	11700.00
0005435127321	3505	Economy	11700.00
0005434880467	3505	Economy	11700.00
0005434880451	3505	Economy	11700.00
0005432800133	3505	Economy	11700.00
0005434880406	3505	Economy	11700.00
0005434880475	3505	Economy	11700.00
0005435626608	3505	Economy	11700.00
0005435127335	3505	Economy	11700.00
0005434938594	3505	Economy	11700.00
0005434880426	3505	Economy	12800.00
0005434880474	3505	Economy	11700.00
0005435127334	3505	Economy	12800.00
0005432800135	3505	Economy	12800.00
0005434938600	3505	Economy	11700.00
0005434880412	3505	Economy	11700.00
0005434880436	3505	Economy	11700.00
0005435127325	3505	Economy	11700.00
0005434880434	3505	Economy	11700.00
0005435127317	3505	Economy	11700.00
0005434880463	3505	Economy	11700.00
0005434880410	3505	Economy	11700.00
0005435913967	3505	Economy	11700.00
0005432800121	3505	Economy	11700.00
0005435127332	3505	Economy	11700.00
0005435127342	3505	Economy	11700.00
0005435127337	3505	Economy	11700.00
0005434938601	3505	Economy	11700.00
0005434427294	3505	Economy	11700.00
0005434938598	3505	Economy	11700.00
0005434880429	3505	Economy	11700.00
0005434880497	3505	Economy	11700.00
0005434880501	3505	Economy	11700.00
0005435127345	3505	Economy	11700.00
0005434880462	3505	Economy	11700.00
0005434880482	3505	Economy	11700.00
0005434880446	3505	Economy	11700.00
0005432611797	3505	Economy	11700.00
0005434938593	3505	Economy	11700.00
0005435841833	3505	Economy	11700.00
0005434880439	3505	Economy	11700.00
0005434880438	3505	Economy	11700.00
0005434938604	3505	Economy	11700.00
0005435902984	3505	Economy	11700.00
0005435903003	3505	Economy	11700.00
0005434880433	3505	Economy	11700.00
0005434880484	3505	Economy	11700.00
0005435127324	3505	Economy	11700.00
0005432183518	3505	Economy	11700.00
0005432800115	3505	Economy	11700.00
0005434938603	3505	Economy	11700.00
0005435127314	3505	Economy	11700.00
0005434880486	3505	Economy	11700.00
0005432800118	3505	Economy	11700.00
0005434880414	3505	Economy	11700.00
0005434880472	3505	Economy	11700.00
0005432800136	3505	Economy	11700.00
0005434880435	3505	Economy	11700.00
0005435903021	3505	Economy	11700.00
0005434880477	3505	Economy	11700.00
0005435902983	3505	Economy	11700.00
0005432800114	3505	Economy	11700.00
0005434880496	3505	Economy	11700.00
0005434880444	3505	Economy	11700.00
0005435127319	3505	Economy	11700.00
0005434880440	3505	Economy	11700.00
0005434427307	3505	Economy	11700.00
0005434880471	3505	Economy	11700.00
0005434880424	3505	Economy	11700.00
0005432613959	3505	Economy	11700.00
0005434880485	3505	Economy	11700.00
0005435127320	3505	Economy	11700.00
0005435626612	3505	Economy	11700.00
0005432800124	3505	Economy	11700.00
0005432800113	3505	Economy	11700.00
0005434427316	3505	Economy	11700.00
0005435903022	3505	Economy	11700.00
0005435127323	3505	Economy	11700.00
0005434880469	3505	Economy	11700.00
0005434880408	3505	Economy	11700.00
0005434880448	3505	Economy	11700.00
0005434880479	3505	Economy	11700.00
0005434880489	3505	Economy	11700.00
0005434427293	3505	Economy	11700.00
0005432613960	3505	Economy	11700.00
0005434880457	3505	Economy	11700.00
0005435127351	3505	Economy	11700.00
0005435127331	3505	Economy	11700.00
0005434879325	14578	Business	35000.00
0005432799969	14578	Business	35000.00
0005432611744	14578	Business	35000.00
0005432799983	14578	Business	35000.00
0005434879642	14578	Business	35000.00
0005434879882	14578	Business	35000.00
0005434427000	14578	Business	35000.00
0005434879647	14578	Business	35000.00
0005434879619	14578	Business	35000.00
0005434938490	14578	Business	35000.00
0005435626431	14578	Business	35000.00
0005435126813	14578	Business	35000.00
0005434879654	14578	Business	35000.00
0005435914068	14578	Business	35000.00
0005434879959	14578	Business	35000.00
0005434879655	14578	Business	35000.00
0005435903118	14578	Business	35000.00
0005434879778	14578	Business	35000.00
0005435126805	14578	Business	35000.00
0005432799882	14578	Business	35000.00
0005434938491	14578	Business	35000.00
0005435914063	14578	Business	35000.00
0005435914062	14578	Comfort	19900.00
0005434426974	14578	Comfort	19900.00
0005434879653	14578	Comfort	19900.00
0005434879777	14578	Comfort	19900.00
0005434879803	14578	Comfort	19900.00
0005432059552	14578	Comfort	19900.00
0005434879663	14578	Comfort	19900.00
0005434879408	14578	Comfort	19900.00
0005435914070	14578	Comfort	19900.00
0005435126858	14578	Comfort	19900.00
0005435127038	14578	Comfort	19900.00
0005432799922	14578	Comfort	19900.00
0005435903113	14578	Comfort	19900.00
0005435903127	14578	Comfort	19900.00
0005432799901	14578	Comfort	19900.00
0005435126967	14578	Comfort	19900.00
0005434879725	14578	Comfort	19900.00
0005435914059	14578	Comfort	19900.00
0005434879916	14578	Comfort	19900.00
0005435914053	14578	Comfort	19900.00
0005434879807	14578	Comfort	19900.00
0005432611759	14578	Comfort	19900.00
0005435914052	14578	Comfort	19900.00
0005435914050	14578	Comfort	19900.00
0005434879985	14578	Comfort	19900.00
0005435126964	14578	Comfort	19900.00
0005432799935	14578	Comfort	19900.00
0005435626424	14578	Comfort	19900.00
0005435914060	14578	Comfort	19900.00
0005432799982	14578	Comfort	19900.00
0005435914064	14578	Comfort	19900.00
0005435626394	14578	Comfort	19900.00
0005434879211	14578	Economy	11700.00
0005434879586	14578	Economy	11700.00
0005434427090	14578	Economy	11700.00
0005434938389	14578	Economy	11700.00
0005434879409	14578	Economy	11700.00
0005432607615	14578	Economy	11700.00
0005434879326	14578	Economy	11700.00
0005435127051	14578	Economy	11700.00
0005435127050	14578	Economy	11700.00
0005434879724	14578	Economy	11700.00
0005435903126	14578	Economy	11700.00
0005435914051	14578	Economy	11700.00
0005434879574	14578	Economy	11700.00
0005435842348	14578	Economy	11700.00
0005434426872	14578	Economy	11700.00
0005435903122	14578	Economy	11700.00
0005435126966	14578	Economy	11700.00
0005435914734	14578	Economy	11700.00
0005435126788	14578	Economy	11700.00
0005435914056	14578	Economy	11700.00
0005434879575	14578	Economy	11700.00
0005434879535	14578	Economy	11700.00
0005435914072	14578	Economy	11700.00
0005434938445	14578	Economy	11700.00
0005434879343	14578	Economy	11700.00
0005435626401	14578	Economy	11700.00
0005435127057	14578	Economy	11700.00
0005434938350	14578	Economy	11700.00
0005434427121	14578	Economy	11700.00
0005432607614	14578	Economy	11700.00
0005434879956	14578	Economy	11700.00
0005432799933	14578	Economy	11700.00
0005434938472	14578	Economy	11700.00
0005432799981	14578	Economy	11700.00
0005435126863	14578	Economy	11700.00
0005435914736	14578	Economy	11700.00
0005434879210	14578	Economy	11700.00
0005435126829	14578	Economy	11700.00
0005432799903	14578	Economy	11700.00
0005434879049	14578	Economy	11700.00
0005432799956	14578	Economy	11700.00
0005432799938	14578	Economy	11700.00
0005432799916	14578	Economy	11700.00
0005434427091	14578	Economy	11700.00
0005434879503	14578	Economy	11700.00
0005435127004	14578	Economy	11700.00
0005435903115	14578	Economy	11700.00
0005435914733	14578	Economy	11700.00
0005435626410	14578	Economy	11700.00
0005434879607	14578	Economy	11700.00
0005434879463	14578	Economy	11700.00
0005435126861	14578	Economy	11700.00
0005434879513	14578	Economy	11700.00
0005435914732	14578	Economy	12800.00
0005434879867	14578	Economy	12800.00
0005432799883	14578	Economy	11700.00
0005435903120	14578	Economy	11700.00
0005435126817	14578	Economy	12800.00
0005435126865	14578	Economy	11700.00
0005434879705	14578	Economy	12800.00
0005434879572	14578	Economy	11700.00
0005434879900	14578	Economy	11700.00
0005432799908	14578	Economy	11700.00
0005434879684	14578	Economy	11700.00
0005435841845	14578	Economy	11700.00
0005435127060	14578	Economy	11700.00
0005434427092	14578	Economy	11700.00
0005435903123	14578	Economy	11700.00
0005434879479	14578	Economy	11700.00
0005435914067	14578	Economy	11700.00
0005434879979	14578	Economy	11700.00
0005432799808	14578	Economy	11700.00
0005434879364	14578	Economy	11700.00
0005432799720	14578	Economy	11700.00
0005434879722	14578	Economy	11700.00
0005434879828	14578	Economy	11700.00
0005434427089	14578	Economy	11700.00
0005435903114	14578	Economy	11700.00
0005434426871	14578	Economy	11700.00
0005434938349	14578	Economy	11700.00
0005435127054	14578	Economy	11700.00
0005434879774	14578	Economy	11700.00
0005434879580	14578	Economy	11700.00
0005434879958	14578	Economy	11700.00
0005435126634	14578	Economy	11700.00
0005435126976	14578	Economy	11700.00
0005435126978	14578	Economy	11700.00
0005435903117	14578	Economy	11700.00
0005435126980	14578	Economy	11700.00
0005434879711	14578	Economy	11700.00
0005434879617	14578	Economy	11700.00
0005435914071	14578	Economy	11700.00
0005435126856	14578	Economy	11700.00
0005435914069	14578	Economy	11700.00
0005432799970	14578	Economy	11700.00
0005435126936	14578	Economy	11700.00
0005435903116	14578	Economy	11700.00
0005435914058	14578	Economy	11700.00
0005434879622	14578	Economy	11700.00
0005435127079	14578	Economy	11700.00
0005435903124	14578	Economy	11700.00
0005435127115	14578	Economy	11700.00
0005434879587	14578	Economy	11700.00
0005434879434	14578	Economy	11700.00
0005432799915	14578	Economy	11700.00
0005435626399	14578	Economy	11700.00
0005435127017	14578	Economy	11700.00
0005434879712	14578	Economy	11700.00
0005432799780	14578	Economy	11700.00
0005435903119	14578	Economy	11700.00
0005435914735	14578	Economy	11700.00
0005435914066	14578	Economy	11700.00
0005434879517	14578	Economy	11700.00
0005434879827	14578	Economy	11700.00
0005435126862	14578	Economy	11700.00
0005432799781	14578	Economy	11700.00
0005435126983	14578	Economy	11700.00
0005435626425	14578	Economy	11700.00
0005435914737	14578	Economy	11700.00
0005435914048	14578	Economy	11700.00
0005435903129	14578	Economy	11700.00
0005434879639	14578	Economy	11700.00
0005434879927	14578	Economy	11700.00
0005435914061	14578	Economy	11700.00
0005434879573	14578	Economy	11700.00
0005434427086	14578	Economy	11700.00
0005435626395	14578	Economy	11700.00
0005435126956	14578	Economy	11700.00
0005434879648	14578	Economy	11700.00
0005435127096	14578	Economy	11700.00
0005432799762	14578	Economy	11700.00
0005434879280	14578	Economy	11700.00
0005434938450	14578	Economy	11700.00
0005435626418	14578	Economy	11700.00
0005432799936	14578	Economy	11700.00
0005434938393	14578	Economy	11700.00
0005434879323	14578	Economy	12800.00
0005435914057	14578	Economy	12800.00
0005434879775	14578	Economy	12800.00
0005434426969	14578	Economy	11700.00
0005434427060	14578	Economy	11700.00
0005432799722	14578	Economy	11700.00
0005432611743	14578	Economy	11700.00
0005435126799	14578	Economy	11700.00
0005434879707	14578	Economy	11700.00
0005435126975	14578	Economy	11700.00
0005435127027	14578	Economy	11700.00
0005434938485	14578	Economy	11700.00
0005435126806	14578	Economy	11700.00
0005435126979	14578	Economy	11700.00
0005434427117	14578	Economy	11700.00
0005434879710	14578	Economy	11700.00
0005435841844	14578	Economy	11700.00
0005434879806	14578	Economy	11700.00
0005434879649	14578	Economy	11700.00
0005434879746	14578	Economy	11700.00
0005435914055	14578	Economy	11700.00
0005435626400	14578	Economy	11700.00
0005434427044	14578	Economy	11700.00
0005435126740	14578	Economy	11700.00
0005435914054	14578	Economy	11700.00
0005435126953	14578	Economy	11700.00
0005435914047	14578	Economy	11700.00
0005435903121	14578	Economy	11700.00
0005434938425	14578	Economy	11700.00
0005432607606	14578	Economy	11700.00
0005434938437	14578	Economy	11700.00
0005434427129	14578	Economy	11700.00
0005435842349	14578	Economy	11700.00
0005432607607	14578	Economy	11700.00
0005434879214	14578	Economy	11700.00
0005435914065	14578	Economy	11700.00
0005435126919	14578	Economy	11700.00
0005434879441	14578	Economy	11700.00
0005434879839	14578	Economy	11700.00
0005435127030	14578	Economy	11700.00
0005434879557	14578	Economy	11700.00
0005432799867	14578	Economy	11700.00
0005434879805	14578	Economy	11700.00
0005434879414	14578	Economy	11700.00
0005434879701	14578	Economy	11700.00
0005432799909	14578	Economy	11700.00
0005435626409	14578	Economy	11700.00
0005435903128	14578	Economy	11700.00
0005435127031	14578	Economy	11700.00
0005435127062	14578	Economy	11700.00
0005435914049	14578	Economy	11700.00
0005435626430	14578	Economy	11700.00
0005434938388	14578	Economy	11700.00
0005435126920	14578	Economy	11700.00
0005434426973	14578	Economy	11700.00
0005434426962	14578	Economy	11700.00
0005432799721	14578	Economy	11700.00
0005435126996	14578	Economy	11700.00
0005435127053	14578	Economy	11700.00
0005434879685	14578	Economy	11700.00
0005435126974	14578	Economy	11700.00
0005434879618	14578	Economy	11700.00
0005434879410	14578	Economy	11700.00
0005434879813	14578	Economy	11700.00
0005434879747	14578	Economy	11700.00
0005435626396	14578	Economy	11700.00
0005435127002	14578	Economy	11700.00
0005434938461	14578	Economy	11700.00
0005434879603	14578	Economy	11700.00
0005435842350	14578	Economy	11700.00
0005432799902	14578	Economy	11700.00
0005434938373	14578	Economy	11700.00
0005434879804	14578	Economy	11700.00
0005435126816	14578	Economy	11700.00
0005435126912	14578	Economy	11700.00
0005435127097	14578	Economy	11700.00
0005435903125	14578	Economy	11700.00
0005434879798	14578	Economy	11700.00
0005432799911	14578	Economy	11700.00
0005434879556	14578	Economy	11700.00
0005434427055	14578	Economy	11700.00
0005434879796	14578	Economy	11700.00
0005434325918	3601	Economy	16300.00
0005434325923	3601	Economy	16300.00
0005434325927	3601	Economy	14800.00
0005435890000	3601	Economy	14800.00
0005434325917	3601	Economy	14800.00
0005434325924	3601	Economy	14800.00
0005434325921	3601	Economy	14800.00
0005434325925	3601	Economy	14800.00
0005434325919	3601	Economy	14800.00
0005434325920	3601	Economy	14800.00
0005435890007	3601	Economy	14800.00
0005434325929	3601	Economy	14800.00
0005434325926	3601	Economy	14800.00
0005435890001	3601	Economy	14800.00
0005434325928	3601	Economy	14800.00
0005435890008	3601	Economy	14800.00
0005434312367	3601	Economy	14800.00
0005434325922	3601	Economy	14800.00
0005434312368	3601	Economy	14800.00
0005434325833	15593	Economy	16300.00
0005434325879	15593	Economy	16300.00
0005434325824	15593	Economy	14800.00
0005434325807	15593	Economy	14800.00
0005435890040	15593	Economy	14800.00
0005434325902	15593	Economy	14800.00
0005435890038	15593	Economy	14800.00
0005434325842	15593	Economy	14800.00
0005434325794	15593	Economy	14800.00
0005434325806	15593	Economy	14800.00
0005434325901	15593	Economy	14800.00
0005435890037	15593	Economy	14800.00
0005434325858	15593	Economy	14800.00
0005435890039	15593	Economy	14800.00
0005434325793	15593	Economy	14800.00
0005434325770	15593	Economy	14800.00
0005434325900	15593	Economy	14800.00
0005434325841	15593	Economy	14800.00
0005434325848	15593	Economy	14800.00
0005435890041	15593	Economy	14800.00
0005434325827	15593	Economy	14800.00
0005434325847	15593	Economy	14800.00
0005434325825	15593	Economy	14800.00
0005433420523	654	Economy	4500.00
0005433420505	654	Economy	4500.00
0005435958055	654	Economy	4500.00
0005433420534	654	Economy	4100.00
0005435958049	654	Economy	4100.00
0005435958045	654	Economy	4100.00
0005435958047	654	Economy	4100.00
0005433420546	654	Economy	4100.00
0005433420565	654	Economy	4100.00
0005435958056	654	Economy	4100.00
0005433420541	654	Economy	4100.00
0005435958054	654	Economy	4100.00
0005435958046	654	Economy	4100.00
0005435958043	654	Economy	4100.00
0005435958051	654	Economy	4100.00
0005433420547	654	Economy	4100.00
0005435958050	654	Economy	4100.00
0005433420542	654	Economy	4100.00
0005433420555	654	Economy	4100.00
0005435958053	654	Economy	4100.00
0005435958048	654	Economy	4100.00
0005435958044	654	Economy	4100.00
0005433420563	654	Economy	4100.00
0005435958052	654	Economy	4100.00
0005433420535	654	Economy	4100.00
0005433420606	15190	Economy	4500.00
0005433420600	15190	Economy	4500.00
0005435957934	15190	Economy	4500.00
0005435957888	15190	Economy	4100.00
0005433420603	15190	Economy	4100.00
0005435957889	15190	Economy	4100.00
0005435957909	15190	Economy	4100.00
0005435957925	15190	Economy	4100.00
0005435957894	15190	Economy	4100.00
0005435957919	15190	Economy	4100.00
0005433420607	15190	Economy	4100.00
0005435957962	15190	Economy	4100.00
0005435957930	15190	Economy	4100.00
0005435957912	15190	Economy	4100.00
0005435957924	15190	Economy	4100.00
0005435957933	15190	Economy	4100.00
0005433420605	15190	Economy	4100.00
0005435957875	15190	Economy	4100.00
0005435957955	15190	Economy	4100.00
0005433420599	15190	Economy	4100.00
0005435957887	15190	Economy	4100.00
0005433420604	15190	Economy	4100.00
0005433420602	15190	Economy	4100.00
0005435957886	15190	Economy	4100.00
0005433420601	15190	Economy	4100.00
0005435957892	15190	Economy	4100.00
0005435957918	15190	Economy	4100.00
0005435957913	15190	Economy	4100.00
0005434247185	8857	Economy	10400.00
0005435629437	8857	Economy	10400.00
0005435629438	8857	Economy	10400.00
0005434247186	8857	Economy	10400.00
0005434247182	8857	Economy	10400.00
0005434247207	16109	Economy	10400.00
0005434247208	16109	Economy	10400.00
0005434247210	16109	Economy	10400.00
0005434247209	16109	Economy	10400.00
0005435933533	29522	Economy	13400.00
0005435163288	29522	Economy	13400.00
0005435933534	29522	Economy	13400.00
0005435163279	29522	Economy	12200.00
0005435163316	29522	Economy	12200.00
0005435933529	29522	Economy	12200.00
0005435163298	29522	Economy	12200.00
0005435163297	29522	Economy	12200.00
0005435933530	29522	Economy	12200.00
0005435163294	29522	Economy	12200.00
0005435163299	29522	Economy	12200.00
0005435163308	29522	Economy	12200.00
0005435933532	29522	Economy	12200.00
0005435933538	29522	Economy	12200.00
0005435163307	29522	Economy	12200.00
0005435163296	29522	Economy	12200.00
0005435933531	29522	Economy	12200.00
0005435163285	29522	Economy	12200.00
0005435163315	29522	Economy	12200.00
0005435163286	29522	Economy	12200.00
0005435933536	29522	Economy	12200.00
0005435933535	29522	Economy	12200.00
0005435163311	29522	Economy	12200.00
0005435933537	29522	Economy	12200.00
0005435933528	29522	Economy	12200.00
0005433404923	2828	Economy	4200.00
0005433404904	2828	Economy	4200.00
0005433404947	2828	Economy	4200.00
0005435797810	2828	Economy	4200.00
0005435797811	2828	Economy	4200.00
0005435797813	2828	Economy	4200.00
0005435797803	2828	Economy	4200.00
0005433404906	2828	Economy	4200.00
0005435797806	2828	Economy	4200.00
0005435797807	2828	Economy	4200.00
0005433404934	2828	Economy	4200.00
0005433404948	2828	Economy	4200.00
0005435797804	2828	Economy	4200.00
0005433404897	2828	Economy	4200.00
0005435797814	2828	Economy	4200.00
0005435797809	2828	Economy	4200.00
0005435797805	2828	Economy	4200.00
0005435797808	2828	Economy	4200.00
0005433404939	2828	Economy	4200.00
0005433404905	2828	Economy	4200.00
0005435797812	2828	Economy	4200.00
0005433404949	2828	Economy	4200.00
0005435797649	29297	Business	12600.00
0005433404985	29297	Business	12600.00
0005435797727	29297	Business	12600.00
0005435797651	29297	Business	12600.00
0005433404986	29297	Economy	4200.00
0005435797650	29297	Economy	4600.00
0005435797728	29297	Economy	4200.00
0005433404988	29297	Economy	4200.00
0005433404989	29297	Economy	4200.00
0005435797696	29297	Economy	4200.00
0005435797691	29297	Economy	4200.00
0005435797722	29297	Economy	4200.00
0005433404983	29297	Economy	4200.00
0005435797765	29297	Economy	4200.00
0005433404984	29297	Economy	4200.00
0005435797641	29297	Economy	4200.00
0005435797690	29297	Economy	4200.00
0005433404987	29297	Economy	4200.00
0005435797661	29297	Economy	4200.00
0005435376390	5840	Economy	6800.00
0005435376410	5840	Economy	6800.00
0005435376396	5840	Economy	6800.00
0005435376391	5840	Economy	6800.00
0005434948215	5836	Economy	6800.00
0005434948219	5836	Economy	6800.00
0005434948216	5836	Economy	6800.00
0005434948212	5836	Economy	6800.00
0005434948211	5836	Economy	6800.00
0005434948214	5836	Economy	6800.00
0005434948210	5836	Economy	6800.00
0005434948217	5836	Economy	6800.00
0005434948213	5836	Economy	6800.00
0005434948218	5836	Economy	6800.00
0005434948169	16430	Economy	6800.00
0005434948182	16430	Economy	6800.00
0005434948110	16430	Economy	6800.00
0005434948195	16430	Economy	6800.00
0005434948176	16430	Economy	6800.00
0005435376415	16430	Economy	6800.00
0005434948165	16430	Economy	6800.00
0005434948175	16430	Economy	6800.00
0005434948174	16430	Economy	6800.00
0005434948170	16430	Economy	6800.00
0005434948171	16430	Economy	6800.00
0005434948166	16430	Economy	6800.00
0005433962264	6874	Business	21400.00
0005433962219	6874	Business	21400.00
0005433962254	6874	Business	21400.00
0005433962232	6874	Business	21400.00
0005433962223	6874	Business	21400.00
0005433962234	6874	Business	21400.00
0005433962265	6874	Business	21400.00
0005433962255	6874	Business	21400.00
0005433962228	6874	Business	21400.00
0005433962250	6874	Economy	7100.00
0005433962261	6874	Economy	7100.00
0005433962236	6874	Economy	7100.00
0005433962211	6874	Economy	7100.00
0005433962213	6874	Economy	7100.00
0005433962259	6874	Economy	7100.00
0005433962245	6874	Economy	7100.00
0005433962247	6874	Economy	7100.00
0005433962252	6874	Economy	7800.00
0005433962204	6874	Economy	7800.00
0005433962200	6874	Economy	7800.00
0005433962217	6874	Economy	7800.00
0005433962206	6874	Economy	7800.00
0005433962226	6874	Economy	7100.00
0005433962216	6874	Economy	7100.00
0005433962212	6874	Economy	7100.00
0005433962215	6874	Economy	7100.00
0005433962260	6874	Economy	7100.00
0005433962238	6874	Economy	7100.00
0005433962239	6874	Economy	7100.00
0005433962221	6874	Economy	7100.00
0005433962244	6874	Economy	7100.00
0005433962218	6874	Economy	7100.00
0005433962251	6874	Economy	7100.00
0005433962262	6874	Economy	7100.00
0005433962203	6874	Economy	7100.00
0005433962208	6874	Economy	7100.00
0005433962253	6874	Economy	7100.00
0005433962257	6874	Economy	7100.00
0005433962222	6874	Economy	7100.00
0005433962220	6874	Economy	7100.00
0005433962229	6874	Economy	7100.00
0005433962263	6874	Economy	7100.00
0005433962249	6874	Economy	7100.00
0005433962231	6874	Economy	7100.00
0005433962235	6874	Economy	7100.00
0005433962205	6874	Economy	7100.00
0005433962248	6874	Economy	7100.00
0005433962214	6874	Economy	7100.00
0005433962258	6874	Economy	7100.00
0005433962224	6874	Economy	7100.00
0005433962237	6874	Economy	7100.00
0005433962202	6874	Economy	7100.00
0005433962256	6874	Economy	7100.00
0005433962241	6874	Economy	7100.00
0005433962242	6874	Economy	7100.00
0005433962227	6874	Economy	7100.00
0005433962246	6874	Economy	7100.00
0005433962230	6874	Economy	7100.00
0005433962207	6874	Economy	7100.00
0005433962210	6874	Economy	7100.00
0005433962201	6874	Economy	7100.00
0005433962225	6874	Economy	7100.00
0005433962233	6874	Economy	7100.00
0005433962240	6874	Economy	7100.00
0005433962243	6874	Economy	7100.00
0005433962209	6874	Economy	7100.00
0005433961627	25775	Business	21400.00
0005433961585	25775	Business	21400.00
0005433961560	25775	Business	21400.00
0005433961361	25775	Business	21400.00
0005433961331	25775	Business	21400.00
0005433961362	25775	Business	21400.00
0005433961495	25775	Business	21400.00
0005433961596	25775	Business	21400.00
0005433961445	25775	Business	21400.00
0005433961507	25775	Economy	7100.00
0005433961338	25775	Economy	7100.00
0005433961550	25775	Economy	7100.00
0005433961562	25775	Economy	7100.00
0005433961567	25775	Economy	7800.00
0005433961606	25775	Economy	7800.00
0005433961494	25775	Economy	7100.00
0005433961584	25775	Economy	7100.00
0005433961626	25775	Economy	7100.00
0005433961586	25775	Economy	7100.00
0005433961566	25775	Economy	7100.00
0005433961545	25775	Economy	7100.00
0005433961454	25775	Economy	7100.00
0005433961455	25775	Economy	7100.00
0005433961480	25775	Economy	7100.00
0005433961539	25775	Economy	7100.00
0005433961456	25775	Economy	7100.00
0005433961537	25775	Economy	7100.00
0005433961517	25775	Economy	7100.00
0005433961502	25775	Economy	7100.00
0005433961360	25775	Economy	7100.00
0005433961558	25775	Economy	7100.00
0005433961387	25775	Economy	7100.00
0005433961491	25775	Economy	7100.00
0005433961515	25775	Economy	7100.00
0005433961493	25775	Economy	7100.00
0005433961607	25775	Economy	7100.00
0005433961608	25775	Economy	7100.00
0005433961543	25775	Economy	7100.00
0005433961416	25775	Economy	7100.00
0005433961536	25775	Economy	7100.00
0005433961503	25775	Economy	7100.00
0005433961542	25775	Economy	7100.00
0005433961595	25775	Economy	7100.00
0005433961214	25775	Economy	7100.00
0005433961501	25775	Economy	7100.00
0005433961551	25775	Economy	7100.00
0005433961625	25775	Economy	7100.00
0005433961575	25775	Economy	7100.00
0005433961597	25775	Economy	7100.00
0005433961544	25775	Economy	7100.00
0005433961513	25775	Economy	7100.00
0005433961571	25775	Economy	7100.00
0005433961561	25775	Economy	7100.00
0005433961553	25775	Economy	7100.00
0005433961559	25775	Economy	7100.00
0005433961529	25775	Economy	7100.00
0005433961552	25775	Economy	7100.00
0005435082918	24465	Economy	3900.00
0005435082919	24465	Economy	3900.00
0005435082878	24465	Economy	3900.00
0005435082904	24465	Economy	3900.00
0005435082944	24465	Economy	3900.00
0005435082890	24465	Economy	3900.00
0005435082896	24465	Economy	3900.00
0005435082905	24465	Economy	3900.00
0005435082879	24465	Economy	3900.00
0005435082895	24465	Economy	3900.00
0005435082972	26115	Economy	3900.00
0005435082973	26115	Economy	3900.00
0005435082970	26115	Economy	3900.00
0005435082968	26115	Economy	3900.00
0005435082976	26115	Economy	3900.00
0005435082971	26115	Economy	3900.00
0005435082974	26115	Economy	3900.00
0005435082969	26115	Economy	3900.00
0005435082975	26115	Economy	3900.00
0005434245682	5216	Business	18000.00
0005434245689	5216	Business	18000.00
0005434245679	5216	Business	18000.00
0005435286699	5216	Business	18000.00
0005434245662	5216	Business	18000.00
0005434245678	5216	Business	18000.00
0005434245684	5216	Business	18000.00
0005434245665	5216	Economy	6000.00
0005434245670	5216	Economy	6000.00
0005432166979	5216	Economy	6000.00
0005434245680	5216	Economy	6000.00
0005434245675	5216	Economy	6000.00
0005434245690	5216	Economy	6000.00
0005434245666	5216	Economy	6000.00
0005434245673	5216	Economy	6000.00
0005435286681	5216	Economy	6000.00
0005434245688	5216	Economy	6000.00
0005432166978	5216	Economy	6000.00
0005434245661	5216	Economy	6000.00
0005434245685	5216	Economy	6000.00
0005434245664	5216	Economy	6000.00
0005434245687	5216	Economy	6000.00
0005434245663	5216	Economy	6000.00
0005434245681	5216	Economy	6000.00
0005434245676	5216	Economy	6000.00
0005434245674	5216	Economy	6000.00
0005434245671	5216	Economy	6000.00
0005434245660	5216	Economy	6000.00
0005434245667	5216	Economy	6000.00
0005434245686	5216	Economy	6000.00
0005434245683	5216	Economy	6000.00
0005434245672	5216	Economy	6000.00
0005434245677	5216	Economy	6000.00
0005434245669	5216	Economy	6000.00
0005434245668	5216	Economy	6000.00
0005432665324	5213	Business	18000.00
0005433616439	5213	Business	18000.00
0005432106671	5213	Business	18000.00
0005433616425	5213	Business	18000.00
0005433616409	5213	Business	18000.00
0005433616406	5213	Business	18000.00
0005432106680	5213	Business	18000.00
0005432145161	5213	Business	18000.00
0005433785801	5213	Business	18000.00
0005433616455	5213	Business	18000.00
0005433616410	5213	Business	18000.00
0005433785809	5213	Business	18000.00
0005432106689	5213	Business	18000.00
0005433785813	5213	Business	18000.00
0005433616422	5213	Business	18000.00
0005433616435	5213	Business	18000.00
0005432106700	5213	Business	18000.00
0005433785781	5213	Business	18000.00
0005433616392	5213	Business	18000.00
0005432106670	5213	Business	18000.00
0005432106681	5213	Business	18000.00
0005433616429	5213	Business	18000.00
0005433616400	5213	Business	18000.00
0005432106714	5213	Business	18000.00
0005433616443	5213	Business	18000.00
0005432106682	5213	Business	18000.00
0005433616403	5213	Business	18000.00
0005433785811	5213	Business	18000.00
0005432106672	5213	Economy	6600.00
0005433616414	5213	Economy	6600.00
0005433616450	5213	Economy	6600.00
0005433616426	5213	Economy	6600.00
0005433785806	5213	Economy	6600.00
0005433616433	5213	Economy	6600.00
0005433616413	5213	Economy	6000.00
0005432145162	5213	Economy	6000.00
0005432106712	5213	Economy	6000.00
0005433785789	5213	Economy	6000.00
0005433616421	5213	Economy	6000.00
0005432106702	5213	Economy	6000.00
0005433616394	5213	Economy	6000.00
0005432106690	5213	Economy	6000.00
0005433616441	5213	Economy	6000.00
0005433785785	5213	Economy	6000.00
0005433616382	5213	Economy	6000.00
0005433785812	5213	Economy	6000.00
0005432106674	5213	Economy	6000.00
0005432106711	5213	Economy	6000.00
0005433785791	5213	Economy	6000.00
0005433616430	5213	Economy	6000.00
0005433616442	5213	Economy	6000.00
0005433616423	5213	Economy	6000.00
0005433616420	5213	Economy	6000.00
0005433616387	5213	Economy	6000.00
0005433616418	5213	Economy	6000.00
0005432145159	5213	Economy	6000.00
0005433785802	5213	Economy	6000.00
0005432106707	5213	Economy	6000.00
0005433616385	5213	Economy	6000.00
0005433616449	5213	Economy	6000.00
0005433616397	5213	Economy	6000.00
0005433616405	5213	Economy	6000.00
0005432106683	5213	Economy	6000.00
0005433616452	5213	Economy	6000.00
0005432106715	5213	Economy	6000.00
0005433616398	5213	Economy	6000.00
0005433616380	5213	Economy	6000.00
0005433785795	5213	Economy	6000.00
0005433785799	5213	Economy	6000.00
0005432106686	5213	Economy	6000.00
0005433616390	5213	Economy	6000.00
0005433616415	5213	Economy	6000.00
0005432106709	5213	Economy	6000.00
0005432106716	5213	Economy	6000.00
0005433616424	5213	Economy	6000.00
0005433616440	5213	Economy	6000.00
0005432106710	5213	Economy	6000.00
0005433616399	5213	Economy	6000.00
0005432106676	5213	Economy	6000.00
0005433785814	5213	Economy	6000.00
0005433785793	5213	Economy	6000.00
0005432106704	5213	Economy	6000.00
0005433616381	5213	Economy	6000.00
0005433616389	5213	Economy	6000.00
0005433785818	5213	Economy	6000.00
0005433616437	5213	Economy	6000.00
0005433616407	5213	Economy	6000.00
0005432106706	5213	Economy	6000.00
0005432106703	5213	Economy	6000.00
0005433616404	5213	Economy	6000.00
0005432106678	5213	Economy	6000.00
0005432106708	5213	Economy	6000.00
0005433785805	5213	Economy	6000.00
0005433785807	5213	Economy	6000.00
0005433616444	5213	Economy	6600.00
0005433616419	5213	Economy	6600.00
0005432106673	5213	Economy	6600.00
0005432106677	5213	Economy	6600.00
0005433785803	5213	Economy	6600.00
0005433616391	5213	Economy	6000.00
0005433616448	5213	Economy	6000.00
0005433616454	5213	Economy	6000.00
0005433616395	5213	Economy	6000.00
0005432666437	5213	Economy	6600.00
0005432106685	5213	Economy	6000.00
0005433616453	5213	Economy	6000.00
0005433616402	5213	Economy	6000.00
0005433616431	5213	Economy	6000.00
0005433616436	5213	Economy	6000.00
0005432106698	5213	Economy	6000.00
0005433785788	5213	Economy	6000.00
0005432106695	5213	Economy	6000.00
0005433785784	5213	Economy	6000.00
0005432106697	5213	Economy	6000.00
0005433785797	5213	Economy	6000.00
0005433785786	5213	Economy	6000.00
0005432666438	5213	Economy	6000.00
0005433616445	5213	Economy	6000.00
0005432106705	5213	Economy	6000.00
0005433785800	5213	Economy	6000.00
0005432106688	5213	Economy	6000.00
0005433616384	5213	Economy	6000.00
0005433616411	5213	Economy	6000.00
0005433616401	5213	Economy	6000.00
0005433616416	5213	Economy	6000.00
0005432106684	5213	Economy	6000.00
0005433785808	5213	Economy	6000.00
0005432106696	5213	Economy	6000.00
0005433785810	5213	Economy	6000.00
0005432106693	5213	Economy	6000.00
0005433785787	5213	Economy	6000.00
0005432106692	5213	Economy	6000.00
0005433616408	5213	Economy	6000.00
0005433616451	5213	Economy	6000.00
0005433616447	5213	Economy	6000.00
0005433616388	5213	Economy	6000.00
0005432665325	5213	Economy	6000.00
0005432106675	5213	Economy	6000.00
0005433785798	5213	Economy	6000.00
0005433616432	5213	Economy	6000.00
0005433785783	5213	Economy	6000.00
0005433616396	5213	Economy	6000.00
0005432106694	5213	Economy	6000.00
0005433785792	5213	Economy	6000.00
0005432106701	5213	Economy	6000.00
0005433785804	5213	Economy	6000.00
0005433616386	5213	Economy	6000.00
0005433616446	5213	Economy	6000.00
0005433616434	5213	Economy	6000.00
0005433785816	5213	Economy	6000.00
0005433785794	5213	Economy	6000.00
0005432106679	5213	Economy	6000.00
0005433785782	5213	Economy	6000.00
0005432106691	5213	Economy	6000.00
0005433616427	5213	Economy	6000.00
0005433616417	5213	Economy	6000.00
0005432106699	5213	Economy	6000.00
0005433785815	5213	Economy	6000.00
0005433785817	5213	Economy	6000.00
0005433616412	5213	Economy	6000.00
0005433616428	5213	Economy	6000.00
0005433616393	5213	Economy	6000.00
0005433616383	5213	Economy	6000.00
0005432106687	5213	Economy	6000.00
0005432145160	5213	Economy	6000.00
0005432106713	5213	Economy	6000.00
0005433785790	5213	Economy	6000.00
0005433785796	5213	Economy	6000.00
0005433616438	5213	Economy	6000.00
0005434229901	5207	Business	18000.00
0005434265755	5207	Business	18000.00
0005434173644	5207	Business	18000.00
0005434150007	5207	Business	18000.00
0005434265737	5207	Business	18000.00
0005434265738	5207	Business	18000.00
0005435007439	5207	Business	18000.00
0005435007394	5207	Business	18000.00
0005434229900	5207	Business	18000.00
0005435269813	5207	Business	18000.00
0005434229904	5207	Business	18000.00
0005433815451	5207	Business	18000.00
0005434229892	5207	Business	18000.00
0005435007345	5207	Business	18000.00
0005432336231	5207	Business	18000.00
0005434265746	5207	Business	18000.00
0005435007409	5207	Business	18000.00
0005434265748	5207	Business	18000.00
0005434265751	5207	Business	18000.00
0005432336205	5207	Business	18000.00
0005434150010	5207	Economy	6600.00
0005434265740	5207	Economy	6600.00
0005433685541	5207	Economy	6600.00
0005435007333	5207	Economy	6000.00
0005435007489	5207	Economy	6000.00
0005434150005	5207	Economy	6000.00
0005435007413	5207	Economy	6000.00
0005434229905	5207	Economy	6000.00
0005435007369	5207	Economy	6000.00
0005434229907	5207	Economy	6000.00
0005434173643	5207	Economy	6000.00
0005434265743	5207	Economy	6000.00
0005434150012	5207	Economy	6000.00
0005433815448	5207	Economy	6000.00
0005434265744	5207	Economy	6000.00
0005432336179	5207	Economy	6000.00
0005435007344	5207	Economy	6000.00
0005432336199	5207	Economy	6000.00
0005434229909	5207	Economy	6000.00
0005433685548	5207	Economy	6000.00
0005434150008	5207	Economy	6000.00
0005434150011	5207	Economy	6000.00
0005434229903	5207	Economy	6000.00
0005434265733	5207	Economy	6000.00
0005432336209	5207	Economy	6000.00
0005435007393	5207	Economy	6000.00
0005434229910	5207	Economy	6000.00
0005434173616	5207	Economy	6000.00
0005434229912	5207	Economy	6000.00
0005434229893	5207	Economy	6000.00
0005434265753	5207	Economy	6000.00
0005434265752	5207	Economy	6000.00
0005432336212	5207	Economy	6000.00
0005435269814	5207	Economy	6000.00
0005432336218	5207	Economy	6000.00
0005434229896	5207	Economy	6000.00
0005435007410	5207	Economy	6000.00
0005432336244	5207	Economy	6000.00
0005434265742	5207	Economy	6000.00
0005435007396	5207	Economy	6000.00
0005435007414	5207	Economy	6000.00
0005434150003	5207	Economy	6000.00
0005434229897	5207	Economy	6000.00
0005434150004	5207	Economy	6000.00
0005434229906	5207	Economy	6000.00
0005435007399	5207	Economy	6000.00
0005434312350	5207	Economy	6000.00
0005434229902	5207	Economy	6000.00
0005435007392	5207	Economy	6600.00
0005434265736	5207	Economy	6600.00
0005432336217	5207	Economy	6000.00
0005434173612	5207	Economy	6000.00
0005435007404	5207	Economy	6000.00
0005434265745	5207	Economy	6000.00
0005434265741	5207	Economy	6000.00
0005433685551	5207	Economy	6000.00
0005434265750	5207	Economy	6000.00
0005435007291	5207	Economy	6000.00
0005433685550	5207	Economy	6000.00
0005434229894	5207	Economy	6000.00
0005434229913	5207	Economy	6000.00
0005435007395	5207	Economy	6000.00
0005434229908	5207	Economy	6000.00
0005434229891	5207	Economy	6000.00
0005435007343	5207	Economy	6000.00
0005434229895	5207	Economy	6000.00
0005434265734	5207	Economy	6000.00
0005434150006	5207	Economy	6000.00
0005434150013	5207	Economy	6000.00
0005434265735	5207	Economy	6000.00
0005435007307	5207	Economy	6000.00
0005435007450	5207	Economy	6000.00
0005433685542	5207	Economy	6000.00
0005434265739	5207	Economy	6000.00
0005434229911	5207	Economy	6000.00
0005435007401	5207	Economy	6000.00
0005434150014	5207	Economy	6000.00
0005434173642	5207	Economy	6000.00
0005434229914	5207	Economy	6000.00
0005434173613	5207	Economy	6000.00
0005433685549	5207	Economy	6000.00
0005433688838	5207	Economy	6000.00
0005435007254	5207	Economy	6000.00
0005434173615	5207	Economy	6000.00
0005435007292	5207	Economy	6000.00
0005434312351	5207	Economy	6000.00
0005434265754	5207	Economy	6000.00
0005434265749	5207	Economy	6000.00
0005434312349	5207	Economy	6000.00
0005434265747	5207	Economy	6000.00
0005432336187	5207	Economy	6000.00
0005434229899	5207	Economy	6000.00
0005434173614	5207	Economy	6000.00
0005432336188	5207	Economy	6000.00
0005435007488	5207	Economy	6000.00
0005434311248	5207	Economy	6000.00
0005435007400	5207	Economy	6000.00
0005434229898	5207	Economy	6000.00
0005434312348	5207	Economy	6000.00
0005434150009	5207	Economy	6000.00
0005435269979	8622	Business	18000.00
0005434245453	8622	Business	18000.00
0005434245362	8622	Business	18000.00
0005432659733	8622	Business	18000.00
0005433785625	8622	Business	18000.00
0005433785517	8622	Business	18000.00
0005433785444	8622	Business	18000.00
0005434245360	8622	Business	18000.00
0005435269992	8622	Business	18000.00
0005433785422	8622	Business	18000.00
0005434245561	8622	Business	18000.00
0005434245490	8622	Business	18000.00
0005433785596	8622	Business	18000.00
0005434245442	8622	Business	18000.00
0005435269991	8622	Business	18000.00
0005434245466	8622	Business	18000.00
0005433785376	8622	Business	18000.00
0005435269998	8622	Business	18000.00
0005434245468	8622	Business	18000.00
0005435269974	8622	Business	18000.00
0005435269986	8622	Economy	6600.00
0005434245531	8622	Economy	6600.00
0005434245430	8622	Economy	6600.00
0005435269989	8622	Economy	6600.00
0005433785434	8622	Economy	6000.00
0005433785393	8622	Economy	6000.00
0005433785435	8622	Economy	6000.00
0005433785597	8622	Economy	6000.00
0005435270008	8622	Economy	6000.00
0005432663061	8622	Economy	6000.00
0005433785505	8622	Economy	6000.00
0005435269976	8622	Economy	6000.00
0005435269978	8622	Economy	6000.00
0005434245431	8622	Economy	6000.00
0005435269996	8622	Economy	6000.00
0005433785598	8622	Economy	6000.00
0005434245265	8622	Economy	6000.00
0005435270009	8622	Economy	6000.00
0005435269981	8622	Economy	6000.00
0005435269984	8622	Economy	6000.00
0005433785359	8622	Economy	6000.00
0005432663066	8622	Economy	6000.00
0005435270012	8622	Economy	6000.00
0005435269975	8622	Economy	6000.00
0005434245470	8622	Economy	6000.00
0005433785506	8622	Economy	6000.00
0005434245398	8622	Economy	6000.00
0005435269999	8622	Economy	6000.00
0005434245488	8622	Economy	6000.00
0005434245467	8622	Economy	6000.00
0005434245361	8622	Economy	6000.00
0005435270005	8622	Economy	6000.00
0005433785484	8622	Economy	6000.00
0005435270011	8622	Economy	6000.00
0005435270000	8622	Economy	6000.00
0005433785394	8622	Economy	6000.00
0005435269973	8622	Economy	6000.00
0005434245301	8622	Economy	6000.00
0005434245456	8622	Economy	6600.00
0005434245300	8622	Economy	6600.00
0005433785500	8622	Economy	6000.00
0005432659734	8622	Economy	6000.00
0005435270006	8622	Economy	6000.00
0005435269983	8622	Economy	6600.00
0005433785360	8622	Economy	6000.00
0005435270002	8622	Economy	6000.00
0005433785492	8622	Economy	6000.00
0005435270001	8622	Economy	6000.00
0005435269997	8622	Economy	6000.00
0005434245413	8622	Economy	6000.00
0005433785624	8622	Economy	6000.00
0005433785485	8622	Economy	6000.00
0005432659727	8622	Economy	6000.00
0005433785562	8622	Economy	6000.00
0005435269988	8622	Economy	6000.00
0005433785552	8622	Economy	6000.00
0005434245471	8622	Economy	6000.00
0005433785377	8622	Economy	6000.00
0005435270004	8622	Economy	6000.00
0005434245446	8622	Economy	6000.00
0005434245299	8622	Economy	6000.00
0005433785443	8622	Economy	6000.00
0005435269987	8622	Economy	6000.00
0005433785445	8622	Economy	6000.00
0005433785469	8622	Economy	6000.00
0005434245525	8622	Economy	6000.00
0005434245447	8622	Economy	6000.00
0005435269993	8622	Economy	6000.00
0005435270010	8622	Economy	6000.00
0005434245473	8622	Economy	6000.00
0005432659737	8622	Economy	6000.00
0005433785521	8622	Economy	6000.00
0005435270007	8622	Economy	6000.00
0005435270003	8622	Economy	6000.00
0005435269977	8622	Economy	6000.00
0005433785361	8622	Economy	6000.00
0005434245455	8622	Economy	6000.00
0005432663057	8622	Economy	6000.00
0005433785551	8622	Economy	6000.00
0005433785558	8622	Economy	6000.00
0005435269982	8622	Economy	6000.00
0005435269995	8622	Economy	6000.00
0005434245391	8622	Economy	6000.00
0005434245500	8622	Economy	6000.00
0005433785550	8622	Economy	6000.00
0005435269990	8622	Economy	6000.00
0005434245375	8622	Economy	6000.00
0005435269980	8622	Economy	6000.00
0005432663056	8622	Economy	6000.00
0005434245264	8622	Economy	6000.00
0005434245489	8622	Economy	6000.00
0005433785514	8622	Economy	6000.00
0005435269985	8622	Economy	6000.00
0005435269994	8622	Economy	6000.00
0005433615799	8621	Business	18000.00
0005433615557	8621	Business	18000.00
0005433615706	8621	Business	18000.00
0005433615892	8621	Business	18000.00
0005433615603	8621	Business	18000.00
0005433615989	8621	Business	18000.00
0005433616027	8621	Business	18000.00
0005433615502	8621	Business	18000.00
0005433615927	8621	Business	18000.00
0005433616051	8621	Business	18000.00
0005433615817	8621	Business	18000.00
0005433615509	8621	Business	18000.00
0005433615619	8621	Economy	6600.00
0005433615786	8621	Economy	6600.00
0005433615614	8621	Economy	6000.00
0005433615491	8621	Economy	6000.00
0005433615703	8621	Economy	6000.00
0005433615511	8621	Economy	6000.00
0005433615510	8621	Economy	6000.00
0005433615978	8621	Economy	6000.00
0005433615568	8621	Economy	6000.00
0005433616000	8621	Economy	6000.00
0005433615486	8621	Economy	6000.00
0005433615800	8621	Economy	6000.00
0005433615590	8621	Economy	6000.00
0005433615707	8621	Economy	6000.00
0005433615873	8621	Economy	6000.00
0005433615470	8621	Economy	6000.00
0005433615760	8621	Economy	6000.00
0005433615832	8621	Economy	6000.00
0005433615919	8621	Economy	6000.00
0005433615688	8621	Economy	6000.00
0005433615645	8621	Economy	6000.00
0005433615705	8621	Economy	6000.00
0005433615600	8621	Economy	6000.00
0005433615683	8621	Economy	6000.00
0005433615801	8621	Economy	6600.00
0005433615676	8621	Economy	6000.00
0005433615852	8621	Economy	6000.00
0005433615759	8621	Economy	6000.00
0005433615734	8621	Economy	6000.00
0005433615620	8621	Economy	6000.00
0005433615890	8621	Economy	6000.00
0005433615589	8621	Economy	6000.00
0005433615704	8621	Economy	6000.00
0005433615710	8621	Economy	6000.00
0005433615764	8621	Economy	6000.00
0005433615812	8621	Economy	6000.00
0005433615917	8621	Economy	6000.00
0005433615926	8621	Economy	6000.00
0005433615891	8621	Economy	6000.00
0005433615763	8621	Economy	6000.00
0005433615642	8621	Economy	6000.00
0005433615758	8621	Economy	6000.00
0005433615900	8621	Economy	6000.00
0005433615835	8621	Economy	6000.00
0005433615659	8621	Economy	6000.00
0005433615555	8621	Economy	6000.00
0005433615813	8621	Economy	6000.00
0005433615773	8621	Economy	6000.00
0005433615641	8621	Economy	6000.00
0005433615977	8621	Economy	6000.00
0005433615846	8621	Economy	6000.00
0005433615607	8621	Economy	6000.00
0005433615853	8621	Economy	6000.00
0005433615558	8621	Economy	6000.00
0005433615592	8621	Economy	6000.00
0005433615918	8621	Economy	6000.00
0005433615606	8621	Economy	6000.00
0005432336315	8620	Business	18000.00
0005434229711	8620	Business	18000.00
0005435007582	8620	Business	18000.00
0005434229648	8620	Business	18000.00
0005434149909	8620	Business	18000.00
0005435007567	8620	Business	18000.00
0005433690974	8620	Business	18000.00
0005434229770	8620	Business	18000.00
0005434149931	8620	Business	18000.00
0005432336313	8620	Business	18000.00
0005435007584	8620	Business	18000.00
0005432336319	8620	Business	18000.00
0005432035595	8620	Business	18000.00
0005434149923	8620	Business	18000.00
0005435007572	8620	Business	18000.00
0005435007579	8620	Business	18000.00
0005432035611	8620	Business	18000.00
0005434265516	8620	Business	18000.00
0005434149922	8620	Business	18000.00
0005435007570	8620	Business	18000.00
0005435007574	8620	Business	18000.00
0005434265623	8620	Business	18000.00
0005434265486	8620	Business	18000.00
0005432035606	8620	Business	18000.00
0005434265511	8620	Business	18000.00
0005434229715	8620	Business	18000.00
0005433690973	8620	Economy	6600.00
0005435286755	8620	Economy	6600.00
0005432336318	8620	Economy	6600.00
0005434149878	8620	Economy	6600.00
0005432035609	8620	Economy	6600.00
0005432035613	8620	Economy	6600.00
0005432047637	8620	Economy	6000.00
0005432035600	8620	Economy	6000.00
0005434265376	8620	Economy	6000.00
0005434229750	8620	Economy	6000.00
0005434149910	8620	Economy	6000.00
0005434265507	8620	Economy	6000.00
0005435286750	8620	Economy	6000.00
0005432336311	8620	Economy	6000.00
0005434149941	8620	Economy	6000.00
0005434149933	8620	Economy	6000.00
0005432035615	8620	Economy	6000.00
0005434265536	8620	Economy	6000.00
0005433688860	8620	Economy	6000.00
0005435007565	8620	Economy	6000.00
0005434265559	8620	Economy	6000.00
0005434265592	8620	Economy	6000.00
0005432336321	8620	Economy	6000.00
0005432336312	8620	Economy	6000.00
0005435286752	8620	Economy	6000.00
0005434265535	8620	Economy	6000.00
0005434311267	8620	Economy	6000.00
0005435007588	8620	Economy	6000.00
0005434229679	8620	Economy	6000.00
0005432047641	8620	Economy	6000.00
0005432035617	8620	Economy	6000.00
0005434265444	8620	Economy	6000.00
0005434229771	8620	Economy	6000.00
0005435007568	8620	Economy	6000.00
0005435007571	8620	Economy	6000.00
0005434265534	8620	Economy	6000.00
0005435007587	8620	Economy	6000.00
0005432035614	8620	Economy	6000.00
0005434149885	8620	Economy	6000.00
0005435286757	8620	Economy	6000.00
0005432047640	8620	Economy	6000.00
0005434229749	8620	Economy	6000.00
0005434265582	8620	Economy	6000.00
0005434149921	8620	Economy	6000.00
0005435007564	8620	Economy	6000.00
0005433534548	8620	Economy	6000.00
0005434229678	8620	Economy	6000.00
0005433815499	8620	Economy	6000.00
0005434229772	8620	Economy	6000.00
0005432336314	8620	Economy	6000.00
0005432035605	8620	Economy	6000.00
0005434265485	8620	Economy	6000.00
0005433815498	8620	Economy	6000.00
0005435286749	8620	Economy	6000.00
0005432035607	8620	Economy	6000.00
0005435286753	8620	Economy	6000.00
0005434265489	8620	Economy	6000.00
0005432035603	8620	Economy	6000.00
0005433534549	8620	Economy	6000.00
0005433688859	8620	Economy	6000.00
0005432035589	8620	Economy	6000.00
0005432035591	8620	Economy	6000.00
0005432035604	8620	Economy	6000.00
0005434149932	8620	Economy	6600.00
0005432035590	8620	Economy	6000.00
0005434265581	8620	Economy	6600.00
0005434265512	8620	Economy	6600.00
0005435007573	8620	Economy	6600.00
0005434149900	8620	Economy	6600.00
0005435007583	8620	Economy	6000.00
0005435007577	8620	Economy	6000.00
0005434265624	8620	Economy	6000.00
0005433815501	8620	Economy	6600.00
0005435007580	8620	Economy	6000.00
0005435007566	8620	Economy	6000.00
0005434265426	8620	Economy	6000.00
0005434229687	8620	Economy	6000.00
0005435286754	8620	Economy	6000.00
0005432035610	8620	Economy	6000.00
0005432336310	8620	Economy	6000.00
0005434265464	8620	Economy	6000.00
0005433689961	8620	Economy	6000.00
0005432035588	8620	Economy	6000.00
0005432035592	8620	Economy	6000.00
0005434265548	8620	Economy	6000.00
0005432035594	8620	Economy	6000.00
0005432336320	8620	Economy	6000.00
0005434149940	8620	Economy	6000.00
0005435007576	8620	Economy	6000.00
0005434229768	8620	Economy	6000.00
0005434149855	8620	Economy	6000.00
0005434265465	8620	Economy	6000.00
0005434265547	8620	Economy	6000.00
0005432336316	8620	Economy	6000.00
0005435007586	8620	Economy	6000.00
0005432035602	8620	Economy	6000.00
0005434229663	8620	Economy	6000.00
0005432035597	8620	Economy	6000.00
0005432035593	8620	Economy	6000.00
0005435007569	8620	Economy	6000.00
0005432047638	8620	Economy	6000.00
0005434265443	8620	Economy	6000.00
0005435286751	8620	Economy	6000.00
0005432035599	8620	Economy	6000.00
0005432035612	8620	Economy	6000.00
0005432035598	8620	Economy	6000.00
0005434229769	8620	Economy	6000.00
0005432035601	8620	Economy	6000.00
0005434173582	8620	Economy	6000.00
0005434173579	8620	Economy	6000.00
0005434149884	8620	Economy	6000.00
0005433815542	8620	Economy	6000.00
0005434149908	8620	Economy	6000.00
0005432047639	8620	Economy	6000.00
0005434229597	8620	Economy	6000.00
0005434265558	8620	Economy	6000.00
0005434229686	8620	Economy	6000.00
0005433689960	8620	Economy	6000.00
0005435007578	8620	Economy	6000.00
0005434265639	8620	Economy	6000.00
0005434265546	8620	Economy	6000.00
0005434265427	8620	Economy	6000.00
0005432035596	8620	Economy	6000.00
0005434265583	8620	Economy	6000.00
0005434149879	8620	Economy	6000.00
0005435007585	8620	Economy	6000.00
0005435007581	8620	Economy	6000.00
0005432336317	8620	Economy	6000.00
0005435007575	8620	Economy	6000.00
0005435286756	8620	Economy	6000.00
0005433815502	8620	Economy	6000.00
0005432035616	8620	Economy	6000.00
0005432035608	8620	Economy	6000.00
0005434149901	8620	Economy	6000.00
0005433815500	8620	Economy	6000.00
0005434265545	8620	Economy	6000.00
0005434639669	12626	Economy	16200.00
0005433202715	12626	Economy	14800.00
0005433202707	12626	Economy	14800.00
0005433202716	12626	Economy	14800.00
0005434639723	12626	Economy	14800.00
0005433202712	12626	Economy	14800.00
0005434639687	12626	Economy	14800.00
0005434639828	12626	Economy	14800.00
0005434639717	12626	Economy	14800.00
0005433202711	12626	Economy	14800.00
0005434639731	12626	Economy	14800.00
0005434639827	12626	Economy	14800.00
0005434639758	12626	Economy	14800.00
0005434639712	12626	Economy	14800.00
0005433202718	12626	Economy	14800.00
0005434639752	12626	Economy	14800.00
0005434639713	12626	Economy	14800.00
0005434639686	12626	Economy	14800.00
0005434639730	12626	Economy	14800.00
0005434639715	12626	Economy	14800.00
0005433202719	12626	Economy	14800.00
0005434639767	12626	Economy	14800.00
0005434639672	12626	Economy	14800.00
0005434639785	12626	Economy	14800.00
0005433202709	12626	Economy	14800.00
0005434639780	12626	Economy	14800.00
0005434639682	12626	Economy	14800.00
0005434639638	12626	Economy	14800.00
0005433202713	12626	Economy	14800.00
0005434639784	12626	Economy	14800.00
0005434639662	12626	Economy	14800.00
0005433202710	12626	Economy	14800.00
0005433202708	12626	Economy	14800.00
0005434639781	12626	Economy	14800.00
0005434639753	12626	Economy	14800.00
0005433202717	12626	Economy	14800.00
0005434639718	12626	Economy	14800.00
0005433202704	12626	Economy	14800.00
0005434639668	12626	Economy	14800.00
0005433202705	12626	Economy	14800.00
0005433202714	12626	Economy	14800.00
0005433202706	12626	Economy	14800.00
0005434639905	23367	Economy	16200.00
0005434639909	23367	Economy	16200.00
0005434639896	23367	Economy	16200.00
0005434639918	23367	Economy	16200.00
0005433202511	23367	Economy	14800.00
0005434639910	23367	Economy	14800.00
0005434639911	23367	Economy	14800.00
0005433202518	23367	Economy	14800.00
0005432290704	23367	Economy	14800.00
0005434639916	23367	Economy	14800.00
0005433202526	23367	Economy	14800.00
0005433202605	23367	Economy	14800.00
0005433202561	23367	Economy	14800.00
0005434639892	23367	Economy	14800.00
0005434639901	23367	Economy	14800.00
0005434639904	23367	Economy	14800.00
0005434639912	23367	Economy	14800.00
0005433202528	23367	Economy	14800.00
0005434639903	23367	Economy	14800.00
0005433202517	23367	Economy	14800.00
0005434639898	23367	Economy	14800.00
0005434639908	23367	Economy	14800.00
0005433202554	23367	Economy	14800.00
0005433202544	23367	Economy	14800.00
0005432290703	23367	Economy	14800.00
0005432290705	23367	Economy	14800.00
0005433202534	23367	Economy	14800.00
0005434639917	23367	Economy	14800.00
0005434639907	23367	Economy	14800.00
0005434639894	23367	Economy	14800.00
0005434639897	23367	Economy	14800.00
0005434639915	23367	Economy	14800.00
0005433202527	23367	Economy	14800.00
0005433202562	23367	Economy	14800.00
0005434639913	23367	Economy	14800.00
0005434639893	23367	Economy	14800.00
0005434639890	23367	Economy	14800.00
0005433202589	23367	Economy	14800.00
0005434639906	23367	Economy	14800.00
0005434639895	23367	Economy	14800.00
0005434639900	23367	Economy	14800.00
0005434639914	23367	Economy	14800.00
0005434639902	23367	Economy	14800.00
0005434639899	23367	Economy	14800.00
0005434639891	23367	Economy	14800.00
0005432329304	21099	Business	18900.00
0005432329395	21099	Business	18900.00
0005432383533	21099	Business	18900.00
0005432383808	21099	Business	18900.00
0005432329456	21099	Business	18900.00
0005432383802	21099	Business	18900.00
0005432329399	21099	Business	18900.00
0005432329480	21099	Business	18900.00
0005432383736	21099	Business	18900.00
0005432383669	21099	Business	18900.00
0005432329479	21099	Business	18900.00
0005432329367	21099	Business	18900.00
0005432383696	21099	Economy	6300.00
0005432329217	21099	Economy	6300.00
0005432329363	21099	Economy	6300.00
0005432383741	21099	Economy	6300.00
0005432329366	21099	Economy	6300.00
0005432329260	21099	Economy	6300.00
0005432329220	21099	Economy	6300.00
0005432383806	21099	Economy	6300.00
0005432329348	21099	Economy	6300.00
0005432383706	21099	Economy	6300.00
0005432329398	21099	Economy	6900.00
0005432329396	21099	Economy	6900.00
0005432329305	21099	Economy	6900.00
0005432383626	21099	Economy	6900.00
0005432383687	21099	Economy	6900.00
0005432329433	21099	Economy	6300.00
0005432383668	21099	Economy	6300.00
0005432383591	21099	Economy	6300.00
0005432383714	21099	Economy	6300.00
0005432383710	21099	Economy	6300.00
0005432383618	21099	Economy	6300.00
0005432329351	21099	Economy	6300.00
0005432329316	21099	Economy	6300.00
0005432054375	21099	Economy	6300.00
0005432383671	21099	Economy	6300.00
0005432054374	21099	Economy	6300.00
0005432383709	21099	Economy	6300.00
0005432383746	21099	Economy	6300.00
0005432383751	21099	Economy	6300.00
0005432383750	21099	Economy	6300.00
0005432329195	21099	Economy	6300.00
0005432383732	21099	Economy	6300.00
0005432329303	21099	Economy	6300.00
0005432329499	21099	Economy	6300.00
0005432329299	21099	Economy	6300.00
0005432329256	21099	Economy	6300.00
0005432329196	21099	Economy	6300.00
0005432383697	21099	Economy	6300.00
0005432329257	21099	Economy	6300.00
0005432329498	21099	Economy	6300.00
0005432329381	21099	Economy	6300.00
0005432329428	21099	Economy	6300.00
0005432383807	21099	Economy	6300.00
0005432383670	21099	Economy	6300.00
0005432329321	21099	Economy	6300.00
0005432329091	21099	Economy	6300.00
0005432383777	21099	Economy	6300.00
0005432329276	21099	Economy	6300.00
0005432383849	21099	Economy	6300.00
0005432329319	21099	Economy	6300.00
0005432329394	21099	Economy	6300.00
0005432383715	21099	Economy	6300.00
0005432383698	21099	Economy	6300.00
0005432383648	21099	Economy	6300.00
0005432383752	21099	Economy	6300.00
0005432329419	21099	Economy	6300.00
0005432054373	21099	Economy	6300.00
0005432329213	21099	Economy	6300.00
0005432383699	21099	Economy	6300.00
0005432329421	21099	Economy	6300.00
0005432329130	21099	Economy	6300.00
0005432383778	21099	Economy	6300.00
0005432329317	21099	Economy	6300.00
0005432329588	21099	Economy	6300.00
0005432329320	21099	Economy	6300.00
0005432329337	21099	Economy	6300.00
0005432329429	21099	Economy	6300.00
0005432383688	21099	Economy	6300.00
0005432329100	21099	Economy	6300.00
0005432329338	21099	Economy	6300.00
0005432383731	21099	Economy	6300.00
0005432383615	21099	Economy	6300.00
0005432329379	21099	Economy	6300.00
0005432383627	21099	Economy	6300.00
0005432329283	21099	Economy	6300.00
0005432329306	21099	Economy	6300.00
0005432329077	21099	Economy	6300.00
0005432329364	21099	Economy	6300.00
0005432329473	21099	Economy	6300.00
0005432329380	21099	Economy	6300.00
0005432329099	21099	Economy	6300.00
0005432329347	21099	Economy	6300.00
0005432383673	21099	Economy	6300.00
0005432383717	21099	Economy	6300.00
0005432329365	21099	Economy	6300.00
0005432384047	31257	Business	18900.00
0005432384062	31257	Business	18900.00
0005432384037	31257	Business	18900.00
0005432384072	31257	Business	18900.00
0005432384043	31257	Business	18900.00
0005432329726	31257	Business	18900.00
0005432329758	31257	Business	18900.00
0005432384061	31257	Business	18900.00
0005432329762	31257	Business	18900.00
0005432384056	31257	Business	18900.00
0005432384054	31257	Business	18900.00
0005432384073	31257	Business	18900.00
0005432329740	31257	Economy	6300.00
0005432329737	31257	Economy	6300.00
0005432329744	31257	Economy	6300.00
0005432384066	31257	Economy	6300.00
0005432329764	31257	Economy	6300.00
0005432329754	31257	Economy	6300.00
0005432384068	31257	Economy	6300.00
0005432329733	31257	Economy	6300.00
0005432329755	31257	Economy	6300.00
0005432384053	31257	Economy	6900.00
0005432329739	31257	Economy	6900.00
0005432384046	31257	Economy	6900.00
0005432287303	31257	Economy	6900.00
0005432384050	31257	Economy	6300.00
0005432287307	31257	Economy	6300.00
0005432384058	31257	Economy	6300.00
0005432384039	31257	Economy	6300.00
0005432329753	31257	Economy	6300.00
0005432329745	31257	Economy	6300.00
0005432329736	31257	Economy	6300.00
0005432848841	31257	Economy	6300.00
0005432287306	31257	Economy	6300.00
0005432287304	31257	Economy	6300.00
0005432384049	31257	Economy	6300.00
0005432384048	31257	Economy	6300.00
0005432329732	31257	Economy	6300.00
0005432329746	31257	Economy	6300.00
0005432384057	31257	Economy	6300.00
0005432329730	31257	Economy	6300.00
0005432384051	31257	Economy	6300.00
0005432384055	31257	Economy	6300.00
0005432329767	31257	Economy	6300.00
0005432329729	31257	Economy	6300.00
0005432329765	31257	Economy	6300.00
0005432384042	31257	Economy	6300.00
0005432329734	31257	Economy	6300.00
0005432384059	31257	Economy	6300.00
0005432329742	31257	Economy	6300.00
0005432384045	31257	Economy	6300.00
0005432329751	31257	Economy	6300.00
0005432384063	31257	Economy	6300.00
0005432329747	31257	Economy	6300.00
0005432384038	31257	Economy	6300.00
0005432329763	31257	Economy	6300.00
0005432329731	31257	Economy	6300.00
0005432384064	31257	Economy	6300.00
0005432384065	31257	Economy	6300.00
0005432329728	31257	Economy	6300.00
0005432848845	31257	Economy	6300.00
0005432329759	31257	Economy	6300.00
0005432329735	31257	Economy	6300.00
0005432329766	31257	Economy	6300.00
0005432329768	31257	Economy	6300.00
0005432329750	31257	Economy	6300.00
0005432329757	31257	Economy	6300.00
0005432384052	31257	Economy	6300.00
0005432384040	31257	Economy	6300.00
0005432329725	31257	Economy	6300.00
0005432329760	31257	Economy	6300.00
0005432329738	31257	Economy	6300.00
0005432384071	31257	Economy	6300.00
0005432329761	31257	Economy	6300.00
0005432384041	31257	Economy	6300.00
0005432329752	31257	Economy	6300.00
0005432329743	31257	Economy	6300.00
0005432329741	31257	Economy	6300.00
0005432329727	31257	Economy	6300.00
0005432384060	31257	Economy	6300.00
0005432329723	31257	Economy	6300.00
0005432329749	31257	Economy	6300.00
0005432384069	31257	Economy	6300.00
0005432329722	31257	Economy	6300.00
0005432287305	31257	Economy	6300.00
0005432384044	31257	Economy	6300.00
0005432329724	31257	Economy	6300.00
0005432329748	31257	Economy	6300.00
0005432384070	31257	Economy	6300.00
0005432329756	31257	Economy	6300.00
0005432384067	31257	Economy	6300.00
0005432425566	13282	Business	12700.00
0005432425571	13282	Business	12700.00
0005432425553	13282	Business	12700.00
0005432425577	13282	Business	12700.00
0005432425543	13282	Business	12700.00
0005432425573	13282	Business	12700.00
0005432425540	13282	Economy	4200.00
0005432425539	13282	Economy	4200.00
0005432425576	13282	Economy	4200.00
0005432425533	13282	Economy	4200.00
0005432425550	13282	Economy	4200.00
0005432425574	13282	Economy	4200.00
0005432425546	13282	Economy	4700.00
0005432425532	13282	Economy	4700.00
0005432425528	13282	Economy	4700.00
0005432425557	13282	Economy	4200.00
0005432425562	13282	Economy	4200.00
0005432425558	13282	Economy	4200.00
0005432425524	13282	Economy	4200.00
0005432425548	13282	Economy	4200.00
0005432425547	13282	Economy	4200.00
0005432425560	13282	Economy	4200.00
0005432425563	13282	Economy	4200.00
0005432425565	13282	Economy	4200.00
0005432425559	13282	Economy	4200.00
0005432425537	13282	Economy	4200.00
0005432425554	13282	Economy	4200.00
0005432425561	13282	Economy	4200.00
0005432425575	13282	Economy	4200.00
0005432425535	13282	Economy	4200.00
0005432425564	13282	Economy	4200.00
0005432425530	13282	Economy	4200.00
0005432425529	13282	Economy	4200.00
0005432425556	13282	Economy	4200.00
0005432425544	13282	Economy	4200.00
0005432425542	13282	Economy	4200.00
0005432425538	13282	Economy	4200.00
0005432425541	13282	Economy	4200.00
0005432425536	13282	Economy	4200.00
0005432425568	13282	Economy	4200.00
0005432425545	13282	Economy	4200.00
0005432425523	13282	Economy	4200.00
0005432425526	13282	Economy	4200.00
0005432425552	13282	Economy	4200.00
0005432425534	13282	Economy	4200.00
0005432425525	13282	Economy	4200.00
0005432425527	13282	Economy	4200.00
0005432425551	13282	Economy	4200.00
0005432425549	13282	Economy	4200.00
0005432425567	13282	Economy	4200.00
0005432425531	13282	Economy	4200.00
0005432425555	13282	Economy	4200.00
0005432425570	13282	Economy	4200.00
0005432425572	13282	Economy	4200.00
0005432425569	13282	Economy	4200.00
0005432425089	30807	Business	12700.00
0005432425133	30807	Business	12700.00
0005432425102	30807	Business	12700.00
0005432425011	30807	Business	12700.00
0005432425064	30807	Business	12700.00
0005432425151	30807	Business	12700.00
0005432425124	30807	Business	12700.00
0005432424782	30807	Business	12700.00
0005432425021	30807	Business	12700.00
0005432425018	30807	Economy	4200.00
0005432425170	30807	Economy	4200.00
0005432425125	30807	Economy	4200.00
0005432425147	30807	Economy	4200.00
0005432424858	30807	Economy	4200.00
0005432425047	30807	Economy	4700.00
0005432424972	30807	Economy	4700.00
0005432425012	30807	Economy	4700.00
0005432424944	30807	Economy	4200.00
0005432425020	30807	Economy	4200.00
0005432425148	30807	Economy	4200.00
0005432425022	30807	Economy	4200.00
0005432425172	30807	Economy	4200.00
0005432425145	30807	Economy	4200.00
0005432425160	30807	Economy	4200.00
0005432425140	30807	Economy	4200.00
0005432425134	30807	Economy	4200.00
0005432425146	30807	Economy	4200.00
0005432425078	30807	Economy	4200.00
0005432424998	30807	Economy	4200.00
0005432425052	30807	Economy	4200.00
0005432425016	30807	Economy	4200.00
0005432425159	30807	Economy	4200.00
0005432424999	30807	Economy	4200.00
0005432425063	30807	Economy	4200.00
0005432425079	30807	Economy	4200.00
0005432425144	30807	Economy	4200.00
0005432424857	30807	Economy	4200.00
0005432424780	30807	Economy	4200.00
0005432425033	30807	Economy	4200.00
0005432424781	30807	Economy	4200.00
0005432425132	30807	Economy	4200.00
0005432425081	30807	Economy	4200.00
0005432425080	30807	Economy	4200.00
0005432425150	30807	Economy	4200.00
0005432425017	30807	Economy	4200.00
0005432425046	30807	Economy	4200.00
0005432424859	30807	Economy	4200.00
0005432425077	30807	Economy	4200.00
0005432425149	30807	Economy	4200.00
0005432425000	30807	Economy	4200.00
0005432425092	30807	Economy	4200.00
0005432425167	30807	Economy	4200.00
0005432425141	30807	Economy	4200.00
0005432425142	30807	Economy	4200.00
0005432425019	30807	Economy	4200.00
0005432425123	30807	Economy	4200.00
0005432425062	30807	Economy	4200.00
0005432424989	30807	Economy	4200.00
0005432425057	30807	Economy	4200.00
0005432425076	30807	Economy	4200.00
0005432818174	9623	Business	32600.00
0005432901912	9623	Business	32600.00
0005432818178	9623	Business	32600.00
0005432818161	9623	Business	32600.00
0005434157588	9623	Business	32600.00
0005434448396	9623	Business	32600.00
0005432818179	9623	Business	32600.00
0005432818167	9623	Business	32600.00
0005434186235	9623	Economy	10900.00
0005434448398	9623	Economy	10900.00
0005432901910	9623	Economy	10900.00
0005432901913	9623	Economy	10900.00
0005432901892	9623	Economy	10900.00
0005432818170	9623	Economy	10900.00
0005434186232	9623	Economy	10900.00
0005432901886	9623	Economy	10900.00
0005432818162	9623	Economy	10900.00
0005432818181	9623	Economy	11900.00
0005432818166	9623	Economy	11900.00
0005432901819	9623	Economy	11900.00
0005432818176	9623	Economy	10900.00
0005434186239	9623	Economy	10900.00
0005432901832	9623	Economy	10900.00
0005432818175	9623	Economy	10900.00
0005434186236	9623	Economy	10900.00
0005432901891	9623	Economy	10900.00
0005432818171	9623	Economy	10900.00
0005432901818	9623	Economy	10900.00
0005432818158	9623	Economy	10900.00
0005432818157	9623	Economy	10900.00
0005432818154	9623	Economy	10900.00
0005432822387	9623	Economy	10900.00
0005432818177	9623	Economy	10900.00
0005432901843	9623	Economy	10900.00
0005434186242	9623	Economy	10900.00
0005434157594	9623	Economy	10900.00
0005432818163	9623	Economy	10900.00
0005432818156	9623	Economy	10900.00
0005434186238	9623	Economy	10900.00
0005432818160	9623	Economy	10900.00
0005434157597	9623	Economy	10900.00
0005432822382	9623	Economy	10900.00
0005432822385	9623	Economy	10900.00
0005432818180	9623	Economy	10900.00
0005432901833	9623	Economy	10900.00
0005434157606	9623	Economy	10900.00
0005432289063	9623	Economy	10900.00
0005432818168	9623	Economy	10900.00
0005432901844	9623	Economy	10900.00
0005432822383	9623	Economy	10900.00
0005432818159	9623	Economy	10900.00
0005434157596	9623	Economy	10900.00
0005432822386	9623	Economy	10900.00
0005434157595	9623	Economy	10900.00
0005434157607	9623	Economy	10900.00
0005432901834	9623	Economy	10900.00
0005432818164	9623	Economy	10900.00
0005432818173	9623	Economy	10900.00
0005434157622	9623	Economy	10900.00
0005432818183	9623	Economy	10900.00
0005432289062	9623	Economy	10900.00
0005432818182	9623	Economy	10900.00
0005432818169	9623	Economy	10900.00
0005432901839	9623	Economy	10900.00
0005432901922	9623	Economy	10900.00
0005432822384	9623	Economy	10900.00
0005434157589	9623	Economy	10900.00
0005434157587	9623	Economy	10900.00
0005432818155	9623	Economy	10900.00
0005432818153	9623	Economy	10900.00
0005434448397	9623	Economy	10900.00
0005432901875	9623	Economy	10900.00
0005432818172	9623	Economy	10900.00
0005432901874	9623	Economy	10900.00
0005432901887	9623	Economy	10900.00
0005432822388	9623	Economy	10900.00
0005434186237	9623	Economy	10900.00
0005432289064	9623	Economy	10900.00
0005432818165	9623	Economy	10900.00
0005432902026	28981	Business	32600.00
0005434157664	28981	Business	32600.00
0005434186265	28981	Business	32600.00
0005432902018	28981	Business	32600.00
0005432817989	28981	Business	32600.00
0005434157659	28981	Business	32600.00
0005432817844	28981	Business	32600.00
0005434448355	28981	Economy	10900.00
0005434157662	28981	Economy	10900.00
0005432817858	28981	Economy	10900.00
0005432817855	28981	Economy	10900.00
0005434448357	28981	Economy	10900.00
0005432902021	28981	Economy	10900.00
0005434448369	28981	Economy	10900.00
0005432817781	28981	Economy	10900.00
0005432902030	28981	Economy	11900.00
0005432817950	28981	Economy	11900.00
0005434157661	28981	Economy	11900.00
0005432822327	28981	Economy	11900.00
0005434157660	28981	Economy	11900.00
0005432817961	28981	Economy	10900.00
0005432817940	28981	Economy	10900.00
0005432817941	28981	Economy	10900.00
0005434157666	28981	Economy	10900.00
0005432902022	28981	Economy	10900.00
0005432822320	28981	Economy	10900.00
0005434448351	28981	Economy	10900.00
0005432817962	28981	Economy	10900.00
0005432002126	28981	Economy	10900.00
0005432902014	28981	Economy	10900.00
0005432817784	28981	Economy	10900.00
0005434448354	28981	Economy	10900.00
0005434186266	28981	Economy	10900.00
0005432902016	28981	Economy	10900.00
0005432817990	28981	Economy	10900.00
0005432902025	28981	Economy	10900.00
0005432902023	28981	Economy	10900.00
0005434448361	28981	Economy	10900.00
0005434448362	28981	Economy	10900.00
0005432002124	28981	Economy	10900.00
0005432817988	28981	Economy	10900.00
0005432817828	28981	Economy	10900.00
0005434448370	28981	Economy	10900.00
0005432817851	28981	Economy	10900.00
0005432817807	28981	Economy	10900.00
0005432817856	28981	Economy	10900.00
0005432817951	28981	Economy	10900.00
0005432902028	28981	Economy	10900.00
0005432902029	28981	Economy	10900.00
0005432822296	28981	Economy	10900.00
0005432817850	28981	Economy	10900.00
0005432902019	28981	Economy	10900.00
0005434157663	28981	Economy	10900.00
0005432817883	28981	Economy	10900.00
0005432822319	28981	Economy	10900.00
0005432817944	28981	Economy	10900.00
0005432817985	28981	Economy	10900.00
0005432902013	28981	Economy	10900.00
0005432902020	28981	Economy	10900.00
0005434157665	28981	Economy	10900.00
0005432822336	28981	Economy	10900.00
0005432818056	28981	Economy	10900.00
0005432817871	28981	Economy	10900.00
0005432902015	28981	Economy	10900.00
0005434448365	28981	Economy	10900.00
0005432902017	28981	Economy	10900.00
0005432002125	28981	Economy	10900.00
0005432902024	28981	Economy	10900.00
0005432902027	28981	Economy	10900.00
0005432822303	28981	Economy	10900.00
0005432822312	28981	Economy	10900.00
0005432817960	28981	Economy	10900.00
0005432611795	15116	Economy	11000.00
0005432611792	15116	Economy	11000.00
0005435841833	15116	Economy	11000.00
0005432611796	15116	Economy	11000.00
0005432613958	15116	Economy	11000.00
0005432611794	15116	Economy	11000.00
0005432611793	15116	Economy	11000.00
0005432611797	15116	Economy	11000.00
0005432613959	15116	Economy	11000.00
0005432613960	15116	Economy	11000.00
0005432611744	31525	Economy	11000.00
0005432607614	31525	Economy	11000.00
0005435842350	31525	Economy	11000.00
0005432611759	31525	Economy	11000.00
0005432607607	31525	Economy	11000.00
0005435841845	31525	Economy	11000.00
0005435842349	31525	Economy	11000.00
0005432607606	31525	Economy	11000.00
0005432611743	31525	Economy	11000.00
0005435841844	31525	Economy	11000.00
0005435842348	31525	Economy	11000.00
0005432607615	31525	Economy	11000.00
0005433570439	11835	Business	105900.00
0005433570477	11835	Business	105900.00
0005432949096	11835	Business	105900.00
0005433570449	11835	Business	105900.00
0005433570443	11835	Business	105900.00
0005433570457	11835	Business	105900.00
0005433570455	11835	Business	105900.00
0005432948904	11835	Business	105900.00
0005433570467	11835	Business	105900.00
0005432949144	11835	Business	105900.00
0005433570483	11835	Business	105900.00
0005433570453	11835	Business	105900.00
0005433570472	11835	Business	105900.00
0005433570438	11835	Business	105900.00
0005432949099	11835	Business	105900.00
0005433570458	11835	Business	105900.00
0005433570462	11835	Business	105900.00
0005433570492	11835	Economy	35300.00
0005433570474	11835	Business	105900.00
0005432949076	11835	Economy	35300.00
0005433570436	11835	Economy	35300.00
0005433570466	11835	Economy	35300.00
0005433570468	11835	Economy	35300.00
0005433570476	11835	Economy	35300.00
0005432949046	11835	Economy	35300.00
0005432949098	11835	Economy	35300.00
0005433570432	11835	Economy	35300.00
0005433570441	11835	Economy	35300.00
0005432948858	11835	Economy	35300.00
0005433570473	11835	Economy	35300.00
0005433570481	11835	Economy	35300.00
0005433570487	11835	Economy	38800.00
0005433570450	11835	Economy	38800.00
0005432949086	11835	Economy	38800.00
0005433570465	11835	Economy	38800.00
0005432948827	11835	Economy	35300.00
0005433570480	11835	Economy	35300.00
0005433570464	11835	Economy	35300.00
0005432948853	11835	Economy	35300.00
0005433570479	11835	Economy	35300.00
0005432949122	11835	Economy	35300.00
0005433570459	11835	Economy	35300.00
0005433570430	11835	Economy	35300.00
0005433570456	11835	Economy	35300.00
0005432948962	11835	Economy	35300.00
0005433570484	11835	Economy	35300.00
0005433570446	11835	Economy	35300.00
0005433570486	11835	Economy	35300.00
0005432949044	11835	Economy	35300.00
0005433570437	11835	Economy	35300.00
0005433570454	11835	Economy	35300.00
0005432948963	11835	Economy	35300.00
0005433570498	11835	Economy	35300.00
0005433570471	11835	Economy	35300.00
0005433570440	11835	Economy	35300.00
0005433570460	11835	Economy	35300.00
0005432949108	11835	Economy	35300.00
0005433570482	11835	Economy	35300.00
0005433570497	11835	Economy	35300.00
0005432949087	11835	Economy	35300.00
0005432949193	11835	Economy	35300.00
0005432949030	11835	Economy	35300.00
0005432948953	11835	Economy	35300.00
0005433570470	11835	Economy	35300.00
0005433570452	11835	Economy	35300.00
0005432949029	11835	Economy	35300.00
0005432949145	11835	Economy	35300.00
0005432949190	11835	Economy	35300.00
0005432949036	11835	Economy	35300.00
0005433570493	11835	Economy	35300.00
0005432949039	11835	Economy	35300.00
0005433570491	11835	Economy	35300.00
0005433570475	11835	Economy	35300.00
0005433570495	11835	Economy	35300.00
0005432948854	11835	Economy	35300.00
0005433570485	11835	Economy	35300.00
0005432948998	11835	Economy	35300.00
0005432948954	11835	Economy	35300.00
0005433570478	11835	Economy	35300.00
0005433570448	11835	Economy	35300.00
0005432948978	11835	Economy	35300.00
0005433570488	11835	Economy	35300.00
0005432949021	11835	Economy	35300.00
0005432949027	11835	Economy	35300.00
0005433570447	11835	Economy	35300.00
0005432948975	11835	Economy	35300.00
0005433570434	11835	Economy	35300.00
0005433570445	11835	Economy	35300.00
0005433570463	11835	Economy	35300.00
0005433570433	11835	Economy	35300.00
0005433570494	11835	Economy	35300.00
0005433570490	11835	Economy	35300.00
0005432948964	11835	Economy	35300.00
0005433570442	11835	Economy	35300.00
0005433570431	11835	Economy	35300.00
0005433570496	11835	Economy	35300.00
0005433570451	11835	Economy	35300.00
0005432949022	11835	Economy	35300.00
0005432948859	11835	Economy	35300.00
0005433570489	11835	Economy	35300.00
0005433570435	11835	Economy	35300.00
0005433570461	11835	Economy	35300.00
0005432948852	11835	Economy	35300.00
0005432949028	11835	Economy	35300.00
0005433570444	11835	Economy	35300.00
0005433570469	11835	Economy	35300.00
0005432949441	25327	Business	105900.00
0005433569897	25327	Business	105900.00
0005432949468	25327	Business	105900.00
0005433569777	25327	Business	105900.00
0005433569997	25327	Business	105900.00
0005432949475	25327	Business	105900.00
0005432949472	25327	Business	105900.00
0005432949469	25327	Business	105900.00
0005433569671	25327	Business	105900.00
0005433569772	25327	Business	105900.00
0005433570026	25327	Business	105900.00
0005433569851	25327	Business	105900.00
0005432949473	25327	Business	105900.00
0005432949462	25327	Business	105900.00
0005433569845	25327	Business	105900.00
0005433569929	25327	Business	105900.00
0005432949451	25327	Business	105900.00
0005433569672	25327	Economy	35300.00
0005433569824	25327	Economy	35300.00
0005432949465	25327	Economy	35300.00
0005433569673	25327	Economy	35300.00
0005433569996	25327	Economy	35300.00
0005433569908	25327	Economy	35300.00
0005433569821	25327	Economy	35300.00
0005433569852	25327	Economy	35300.00
0005432949470	25327	Economy	35300.00
0005433569783	25327	Economy	35300.00
0005433569889	25327	Economy	35300.00
0005432949445	25327	Economy	38800.00
0005433569416	25327	Economy	38800.00
0005433569949	25327	Economy	38800.00
0005432949467	25327	Economy	38800.00
0005433569415	25327	Economy	35300.00
0005432949460	25327	Economy	35300.00
0005432949446	25327	Economy	35300.00
0005432949443	25327	Economy	35300.00
0005433569855	25327	Economy	35300.00
0005433569823	25327	Economy	35300.00
0005433569722	25327	Economy	35300.00
0005432949450	25327	Economy	35300.00
0005433570003	25327	Economy	35300.00
0005432949458	25327	Economy	35300.00
0005433569654	25327	Economy	35300.00
0005433570025	25327	Economy	35300.00
0005432949440	25327	Economy	35300.00
0005432949432	25327	Economy	35300.00
0005433569971	25327	Economy	35300.00
0005432949437	25327	Economy	35300.00
0005432949448	25327	Economy	35300.00
0005432949433	25327	Economy	35300.00
0005432949463	25327	Economy	35300.00
0005432949466	25327	Economy	35300.00
0005433569859	25327	Economy	35300.00
0005432949461	25327	Economy	35300.00
0005433569928	25327	Economy	35300.00
0005433569815	25327	Economy	35300.00
0005433569951	25327	Economy	35300.00
0005433569869	25327	Economy	35300.00
0005433570016	25327	Economy	35300.00
0005433569846	25327	Economy	35300.00
0005433569653	25327	Economy	35300.00
0005433569923	25327	Economy	35300.00
0005433569999	25327	Economy	35300.00
0005433569601	25327	Economy	35300.00
0005433569970	25327	Economy	35300.00
0005433569931	25327	Economy	35300.00
0005433569890	25327	Economy	35300.00
0005433569887	25327	Economy	35300.00
0005432949434	25327	Economy	35300.00
0005433569886	25327	Economy	35300.00
0005432949471	25327	Economy	35300.00
0005432949456	25327	Economy	35300.00
0005433569771	25327	Economy	35300.00
0005432949455	25327	Economy	35300.00
0005432949435	25327	Economy	35300.00
0005432949449	25327	Economy	35300.00
0005433569987	25327	Economy	35300.00
0005433569950	25327	Economy	35300.00
0005433569659	25327	Economy	35300.00
0005432949464	25327	Economy	35300.00
0005433569554	25327	Economy	35300.00
0005432949447	25327	Economy	35300.00
0005432949444	25327	Economy	35300.00
0005433569775	25327	Economy	35300.00
0005432949457	25327	Economy	35300.00
0005432949453	25327	Economy	35300.00
0005432949439	25327	Economy	35300.00
0005432949442	25327	Economy	35300.00
0005433569734	25327	Economy	35300.00
0005432949436	25327	Economy	35300.00
0005433569663	25327	Economy	35300.00
0005432949474	25327	Economy	35300.00
0005432949452	25327	Economy	35300.00
0005433569868	25327	Economy	35300.00
0005433569414	25327	Economy	35300.00
0005432949459	25327	Economy	35300.00
0005433570000	25327	Economy	35300.00
0005433569891	25327	Economy	35300.00
0005432949438	25327	Economy	35300.00
0005433569924	25327	Economy	35300.00
0005433569898	25327	Economy	35300.00
0005432949454	25327	Economy	35300.00
0005433569847	25327	Economy	35300.00
0005433569988	25327	Economy	35300.00
0005435340544	5391	Business	67200.00
0005434655368	5391	Business	67200.00
0005435340431	5391	Business	67200.00
0005435340480	5391	Business	67200.00
0005434655373	5391	Business	67200.00
0005435340514	5391	Business	67200.00
0005435340437	5391	Business	67200.00
0005434656604	5391	Economy	22400.00
0005434655356	5391	Economy	22400.00
0005435340462	5391	Economy	22400.00
0005434655380	5391	Economy	22400.00
0005434655375	5391	Economy	22400.00
0005432114278	5391	Economy	22400.00
0005435340445	5391	Economy	22400.00
0005435340515	5391	Economy	24600.00
0005435340432	5391	Economy	24600.00
0005434655370	5391	Economy	22400.00
0005434655382	5391	Economy	22400.00
0005432114280	5391	Economy	22400.00
0005435340543	5391	Economy	22400.00
0005435340466	5391	Economy	22400.00
0005434655381	5391	Economy	22400.00
0005434655355	5391	Economy	22400.00
0005434655358	5391	Economy	22400.00
0005434655374	5391	Economy	22400.00
0005432114279	5391	Economy	22400.00
0005434655362	5391	Economy	22400.00
0005434655359	5391	Economy	22400.00
0005434655363	5391	Economy	22400.00
0005434655365	5391	Economy	22400.00
0005435340513	5391	Economy	22400.00
0005434655379	5391	Economy	22400.00
0005434655366	5391	Economy	22400.00
0005434655367	5391	Economy	22400.00
0005434655372	5391	Economy	22400.00
0005434655376	5391	Economy	22400.00
0005434656603	5391	Economy	22400.00
0005434655378	5391	Economy	22400.00
0005434655364	5391	Economy	22400.00
0005435340438	5391	Economy	22400.00
0005435340505	5391	Economy	22400.00
0005435340429	5391	Economy	22400.00
0005434655369	5391	Economy	22400.00
0005434655371	5391	Economy	22400.00
0005434655357	5391	Economy	22400.00
0005435340430	5391	Economy	22400.00
0005434655361	5391	Economy	22400.00
0005434655377	5391	Economy	22400.00
0005435340463	5391	Economy	22400.00
0005435340530	5391	Economy	22400.00
0005434655360	5391	Economy	22400.00
0005435340622	12562	Business	67200.00
0005435340617	12562	Business	67200.00
0005434655121	12562	Business	67200.00
0005435555420	12562	Business	67200.00
0005434655108	12562	Business	67200.00
0005434655204	12562	Business	67200.00
0005434655190	12562	Economy	22400.00
0005435340624	12562	Economy	22400.00
0005434655186	12562	Economy	24600.00
0005434655107	12562	Economy	24600.00
0005434655099	12562	Economy	22400.00
0005434655035	12562	Economy	22400.00
0005434655215	12562	Economy	22400.00
0005435340618	12562	Economy	22400.00
0005434655313	12562	Economy	22400.00
0005434655130	12562	Economy	22400.00
0005435340619	12562	Economy	22400.00
0005435340615	12562	Economy	22400.00
0005434655167	12562	Economy	22400.00
0005435555418	12562	Economy	22400.00
0005434655138	12562	Economy	22400.00
0005435555419	12562	Economy	22400.00
0005434655044	12562	Economy	22400.00
0005435340626	12562	Economy	22400.00
0005435340616	12562	Economy	22400.00
0005435340623	12562	Economy	22400.00
0005435340620	12562	Economy	22400.00
0005434655314	12562	Economy	22400.00
0005434654977	12562	Economy	22400.00
0005435340613	12562	Economy	22400.00
0005435340625	12562	Economy	22400.00
0005435340627	12562	Economy	22400.00
0005434655106	12562	Economy	22400.00
0005435340621	12562	Economy	22400.00
0005434655131	12562	Economy	22400.00
0005435340614	12562	Economy	22400.00
0005434655132	12562	Economy	22400.00
0005433717122	7441	Business	32000.00
0005433690971	7441	Business	32000.00
0005432078238	7441	Business	32000.00
0005432428975	7441	Business	32000.00
0005433722370	7441	Business	32000.00
0005433717128	7441	Business	32000.00
0005433717118	7441	Economy	10700.00
0005433717143	7441	Economy	10700.00
0005433717155	7441	Economy	10700.00
0005433717151	7441	Economy	10700.00
0005433717114	7441	Economy	10700.00
0005433717163	7441	Economy	10700.00
0005433717137	7441	Economy	10700.00
0005433717152	7441	Economy	10700.00
0005433722367	7441	Economy	10700.00
0005433717131	7441	Economy	10700.00
0005433717157	7441	Economy	10700.00
0005433717126	7441	Economy	10700.00
0005433688857	7441	Economy	10700.00
0005433717146	7441	Economy	10700.00
0005433719218	7441	Economy	10700.00
0005433717142	7441	Economy	10700.00
0005432428987	7441	Economy	10700.00
0005433717121	7441	Economy	10700.00
0005433717130	7441	Economy	10700.00
0005435266205	7441	Economy	10700.00
0005433717115	7441	Economy	10700.00
0005433717140	7441	Economy	10700.00
0005433690970	7441	Economy	10700.00
0005433717158	7441	Economy	10700.00
0005433717129	7441	Economy	11700.00
0005433719219	7441	Economy	11700.00
0005433717148	7441	Economy	11700.00
0005433722369	7441	Economy	11700.00
0005433717156	7441	Economy	10700.00
0005433689959	7441	Economy	10700.00
0005433717117	7441	Economy	10700.00
0005433717123	7441	Economy	10700.00
0005433690972	7441	Economy	10700.00
0005433717135	7441	Economy	10700.00
0005433717119	7441	Economy	10700.00
0005433717162	7441	Economy	10700.00
0005433717134	7441	Economy	10700.00
0005433722365	7441	Economy	10700.00
0005433717136	7441	Economy	10700.00
0005433717133	7441	Economy	10700.00
0005433717132	7441	Economy	10700.00
0005433717147	7441	Economy	10700.00
0005433717141	7441	Economy	10700.00
0005433717125	7441	Economy	10700.00
0005435266204	7441	Economy	10700.00
0005433717160	7441	Economy	10700.00
0005433722363	7441	Economy	10700.00
0005433717153	7441	Economy	10700.00
0005433656747	7441	Economy	10700.00
0005433722368	7441	Economy	10700.00
0005433688856	7441	Economy	10700.00
0005433717154	7441	Economy	10700.00
0005433717124	7441	Economy	10700.00
0005433688858	7441	Economy	10700.00
0005433722366	7441	Economy	10700.00
0005433717159	7441	Economy	10700.00
0005432428974	7441	Economy	10700.00
0005433717161	7441	Economy	10700.00
0005433717149	7441	Economy	10700.00
0005433717139	7441	Economy	10700.00
0005433722364	7441	Economy	10700.00
0005433717116	7441	Economy	10700.00
0005433717144	7441	Economy	10700.00
0005433717164	7441	Economy	10700.00
0005433656748	7441	Economy	10700.00
0005433717127	7441	Economy	10700.00
0005433656745	7441	Economy	10700.00
0005433717120	7441	Economy	10700.00
0005432428973	7441	Economy	10700.00
0005433717150	7441	Economy	10700.00
0005433717145	7441	Economy	10700.00
0005433656746	7441	Economy	10700.00
0005433717138	7441	Economy	10700.00
0005433716657	29225	Business	32000.00
0005433716616	29225	Business	32000.00
0005433716584	29225	Business	32000.00
0005433716574	29225	Business	32000.00
0005433722284	29225	Business	32000.00
0005433716703	29225	Business	32000.00
0005433716882	29225	Business	32000.00
0005433719203	29225	Business	32000.00
0005432006832	29225	Economy	10700.00
0005433716724	29225	Economy	10700.00
0005433719201	29225	Economy	10700.00
0005433685551	29225	Economy	10700.00
0005433716715	29225	Economy	10700.00
0005433716841	29225	Economy	10700.00
0005433716629	29225	Economy	10700.00
0005433685548	29225	Economy	10700.00
0005433716615	29225	Economy	10700.00
0005433716605	29225	Economy	10700.00
0005433716655	29225	Economy	10700.00
0005433716668	29225	Economy	10700.00
0005433716392	29225	Economy	10700.00
0005433716643	29225	Economy	10700.00
0005433716642	29225	Economy	10700.00
0005433722299	29225	Economy	10700.00
0005433716700	29225	Economy	10700.00
0005433685542	29225	Economy	10700.00
0005433716756	29225	Economy	10700.00
0005432429009	29225	Economy	10700.00
0005433716781	29225	Economy	10700.00
0005433722286	29225	Economy	10700.00
0005433716742	29225	Economy	10700.00
0005433722287	29225	Economy	10700.00
0005433685550	29225	Economy	10700.00
0005433716604	29225	Economy	11700.00
0005433716638	29225	Economy	11700.00
0005433716537	29225	Economy	11700.00
0005433716827	29225	Economy	11700.00
0005433716495	29225	Economy	11700.00
0005433716883	29225	Economy	10700.00
0005433716667	29225	Economy	10700.00
0005433716767	29225	Economy	10700.00
0005433716704	29225	Economy	10700.00
0005433716766	29225	Economy	10700.00
0005432006831	29225	Economy	10700.00
0005433716641	29225	Economy	10700.00
0005433716725	29225	Economy	10700.00
0005432429011	29225	Economy	10700.00
0005433722298	29225	Economy	10700.00
0005433719202	29225	Economy	10700.00
0005433716683	29225	Economy	10700.00
0005433656712	29225	Economy	10700.00
0005433716699	29225	Economy	10700.00
0005433722301	29225	Economy	10700.00
0005433688838	29225	Economy	10700.00
0005433716682	29225	Economy	10700.00
0005433716705	29225	Economy	10700.00
0005433656713	29225	Economy	10700.00
0005433717020	29225	Economy	10700.00
0005433716881	29225	Economy	10700.00
0005433716543	29225	Economy	10700.00
0005433716899	29225	Economy	10700.00
0005433716656	29225	Economy	10700.00
0005433716898	29225	Economy	10700.00
0005433716805	29225	Economy	10700.00
0005433719190	29225	Economy	10700.00
0005433716650	29225	Economy	10700.00
0005433716542	29225	Economy	10700.00
0005433685549	29225	Economy	10700.00
0005433716609	29225	Economy	10700.00
0005433716840	29225	Economy	10700.00
0005433716747	29225	Economy	10700.00
0005433722283	29225	Economy	10700.00
0005433716746	29225	Economy	10700.00
0005433716621	29225	Economy	10700.00
0005433716764	29225	Economy	10700.00
0005433716588	29225	Economy	10700.00
0005433716765	29225	Economy	10700.00
0005433716860	29225	Economy	10700.00
0005433716595	29225	Economy	10700.00
0005433722282	29225	Economy	10700.00
0005433716631	29225	Economy	10700.00
0005433716681	29225	Economy	10700.00
0005433685541	29225	Economy	10700.00
0005432006829	29225	Economy	10700.00
0005432006830	29225	Economy	10700.00
0005432429010	29225	Economy	10700.00
0005434182403	8689	Business	36500.00
0005434182364	8689	Business	36500.00
0005434182388	8689	Economy	12200.00
0005434095620	8689	Economy	12200.00
0005434182342	8689	Economy	13400.00
0005434095615	8689	Economy	13400.00
0005434095614	8689	Economy	12200.00
0005434182393	8689	Economy	12200.00
0005434095616	8689	Economy	12200.00
0005434182358	8689	Economy	12200.00
0005434095619	8689	Economy	12200.00
0005434182392	8689	Economy	12200.00
0005434095609	8689	Economy	12200.00
0005434095611	8689	Economy	12200.00
0005434095613	8689	Economy	12200.00
0005434182380	8689	Economy	12200.00
0005434326086	8689	Economy	12200.00
0005434095610	8689	Economy	12200.00
0005434095607	8689	Economy	12200.00
0005434095617	8689	Economy	12200.00
0005434326053	8689	Economy	12200.00
0005434182394	8689	Economy	12200.00
0005434182402	8689	Economy	12200.00
0005434326054	8689	Economy	12200.00
0005434095612	8689	Economy	12200.00
0005434095621	8689	Economy	12200.00
0005434182359	8689	Economy	12200.00
0005434095608	8689	Economy	12200.00
0005434095618	8689	Economy	12200.00
0005434182472	11663	Business	36500.00
0005434095459	11663	Business	36500.00
0005434182478	11663	Business	36500.00
0005434182473	11663	Business	36500.00
0005434095403	11663	Business	36500.00
0005435860658	11663	Economy	12200.00
0005434182476	11663	Economy	12200.00
0005434095442	11663	Economy	12200.00
0005434095494	11663	Economy	13400.00
0005434183626	11663	Economy	13400.00
0005435860655	11663	Economy	12200.00
0005434095496	11663	Economy	12200.00
0005434095528	11663	Economy	12200.00
0005434095480	11663	Economy	12200.00
0005434095479	11663	Economy	12200.00
0005434095461	11663	Economy	12200.00
0005434095493	11663	Economy	12200.00
0005434095472	11663	Economy	12200.00
0005434182477	11663	Economy	12200.00
0005434182475	11663	Economy	12200.00
0005434182480	11663	Economy	12200.00
0005434095534	11663	Economy	12200.00
0005434182474	11663	Economy	12200.00
0005434183625	11663	Economy	12200.00
0005434095555	11663	Economy	12200.00
0005434095434	11663	Economy	12200.00
0005435860657	11663	Economy	12200.00
0005435860656	11663	Economy	12200.00
0005434095464	11663	Economy	12200.00
0005435860652	11663	Economy	12200.00
0005435860651	11663	Economy	12200.00
0005434182479	11663	Economy	12200.00
0005434183627	11663	Economy	12200.00
0005435860650	11663	Economy	12200.00
0005435860654	11663	Economy	12200.00
0005434182482	11663	Economy	12200.00
0005435860653	11663	Economy	12200.00
0005434184712	11663	Economy	12200.00
0005434095460	11663	Economy	12200.00
0005434182481	11663	Economy	12200.00
0005434095527	11663	Economy	12200.00
0005435732629	1444	Business	33000.00
0005433457063	1444	Business	33000.00
0005435732620	1444	Business	33000.00
0005433398918	1444	Business	33000.00
0005433398842	1444	Business	33000.00
0005433398673	1444	Business	33000.00
0005433398920	1444	Business	33000.00
0005433398878	1444	Business	33000.00
0005433398425	1444	Business	33000.00
0005433398627	1444	Business	33000.00
0005433398800	1444	Economy	11000.00
0005433398686	1444	Economy	11000.00
0005433398725	1444	Economy	11000.00
0005433398841	1444	Economy	11000.00
0005435732626	1444	Economy	11000.00
0005435732624	1444	Economy	11000.00
0005433398857	1444	Economy	11000.00
0005433398625	1444	Economy	12100.00
0005435732636	1444	Economy	12100.00
0005433398634	1444	Economy	12100.00
0005433398807	1444	Economy	12100.00
0005435732633	1444	Economy	11000.00
0005433398695	1444	Economy	11000.00
0005433399015	1444	Economy	11000.00
0005432906566	1444	Economy	11000.00
0005433398801	1444	Economy	11000.00
0005433398727	1444	Economy	11000.00
0005433398844	1444	Economy	11000.00
0005433398794	1444	Economy	11000.00
0005435732630	1444	Economy	11000.00
0005433398806	1444	Economy	11000.00
0005433398471	1444	Economy	11000.00
0005435732635	1444	Economy	11000.00
0005433398763	1444	Economy	11000.00
0005433398869	1444	Economy	11000.00
0005435732623	1444	Economy	11000.00
0005432906571	1444	Economy	11000.00
0005435732621	1444	Economy	11000.00
0005433398720	1444	Economy	11000.00
0005435732625	1444	Economy	11000.00
0005433457065	1444	Economy	11000.00
0005435732617	1444	Economy	11000.00
0005433398642	1444	Economy	11000.00
0005435732634	1444	Economy	11000.00
0005433398718	1444	Economy	11000.00
0005435732619	1444	Economy	11000.00
0005432297340	1444	Economy	11000.00
0005433398802	1444	Economy	11000.00
0005433398722	1444	Economy	11000.00
0005435732622	1444	Economy	11000.00
0005433398810	1444	Economy	11000.00
0005435732631	1444	Economy	11000.00
0005433457064	1444	Economy	11000.00
0005433398694	1444	Economy	11000.00
0005433398896	1444	Economy	11000.00
0005433398959	1444	Economy	11000.00
0005435732632	1444	Economy	11000.00
0005435732618	1444	Economy	11000.00
0005435732616	1444	Economy	11000.00
0005432906565	1444	Economy	11000.00
0005433398426	1444	Economy	11000.00
0005433457066	1444	Economy	11000.00
0005433398819	1444	Economy	11000.00
0005433398921	1444	Economy	11000.00
0005433398843	1444	Economy	11000.00
0005433398960	1444	Economy	11000.00
0005435732628	1444	Economy	11000.00
0005432297338	1444	Economy	11000.00
0005435732627	1444	Economy	11000.00
0005433398784	1444	Economy	11000.00
0005432297339	1444	Economy	11000.00
0005433398762	1444	Economy	11000.00
0005433398922	1444	Economy	11000.00
0005433399196	19259	Business	33000.00
0005435732479	19259	Business	33000.00
0005433399189	19259	Business	33000.00
0005435732478	19259	Business	33000.00
0005432906594	19259	Business	33000.00
0005433399195	19259	Business	33000.00
0005433399210	19259	Business	33000.00
0005433399211	19259	Economy	11000.00
0005433399199	19259	Economy	11000.00
0005433399169	19259	Economy	11000.00
0005433399178	19259	Economy	11000.00
0005433399213	19259	Economy	12100.00
0005433399201	19259	Economy	12100.00
0005433399193	19259	Economy	12100.00
0005433399186	19259	Economy	11000.00
0005433399182	19259	Economy	11000.00
0005433399181	19259	Economy	11000.00
0005433399185	19259	Economy	11000.00
0005433399198	19259	Economy	11000.00
0005433399187	19259	Economy	11000.00
0005433399174	19259	Economy	11000.00
0005433399212	19259	Economy	11000.00
0005433399176	19259	Economy	11000.00
0005435732495	19259	Economy	11000.00
0005433399191	19259	Economy	11000.00
0005433399179	19259	Economy	11000.00
0005433399203	19259	Economy	11000.00
0005433399171	19259	Economy	11000.00
0005433399175	19259	Economy	11000.00
0005433399194	19259	Economy	11000.00
0005433457033	19259	Economy	11000.00
0005433399206	19259	Economy	11000.00
0005433399207	19259	Economy	11000.00
0005433399172	19259	Economy	11000.00
0005433399183	19259	Economy	11000.00
0005433399197	19259	Economy	11000.00
0005433399214	19259	Economy	11000.00
0005433399177	19259	Economy	11000.00
0005433399190	19259	Economy	11000.00
0005433399208	19259	Economy	11000.00
0005433399204	19259	Economy	11000.00
0005433399209	19259	Economy	11000.00
0005433399173	19259	Economy	11000.00
0005433399168	19259	Economy	11000.00
0005435732512	19259	Economy	11000.00
0005433399188	19259	Economy	11000.00
0005433399167	19259	Economy	11000.00
0005433399200	19259	Economy	11000.00
0005433399202	19259	Economy	11000.00
0005433399215	19259	Economy	11000.00
0005435732500	19259	Economy	11000.00
0005433399184	19259	Economy	11000.00
0005435732543	19259	Economy	11000.00
0005433399180	19259	Economy	11000.00
0005433399192	19259	Economy	11000.00
0005433399170	19259	Economy	11000.00
0005433399205	19259	Economy	11000.00
0005434443940	17356	Economy	15600.00
0005434443939	17356	Economy	15600.00
0005434443943	17356	Economy	14100.00
0005434443905	17356	Economy	14100.00
0005434443938	17356	Economy	14100.00
0005434443942	17356	Economy	14100.00
0005434443966	17356	Economy	14100.00
0005434443910	17356	Economy	14100.00
0005434443907	17356	Economy	14100.00
0005434444021	17356	Economy	14100.00
0005434443973	17356	Economy	14100.00
0005434444022	17356	Economy	14100.00
0005434443985	17356	Economy	14100.00
0005434443874	17356	Economy	14100.00
0005434443906	17356	Economy	14100.00
0005434443898	17356	Economy	14100.00
0005434443946	17356	Economy	14100.00
0005434443984	17356	Economy	14100.00
0005434444070	20559	Economy	15600.00
0005434444073	20559	Economy	14100.00
0005434444071	20559	Economy	14100.00
0005434444080	20559	Economy	14100.00
0005434444079	20559	Economy	14100.00
0005434444075	20559	Economy	14100.00
0005434444083	20559	Economy	14100.00
0005434444084	20559	Economy	14100.00
0005434444078	20559	Economy	14100.00
0005434444082	20559	Economy	14100.00
0005434444072	20559	Economy	14100.00
0005434444074	20559	Economy	14100.00
0005434444077	20559	Economy	14100.00
0005434444076	20559	Economy	14100.00
0005434444081	20559	Economy	14100.00
0005434444069	20559	Economy	14100.00
0005434954701	7268	Economy	5800.00
0005434954700	7268	Economy	5800.00
0005434954702	7268	Economy	5800.00
0005434954668	28325	Economy	5800.00
0005435377635	28325	Economy	5800.00
0005435377636	28325	Economy	5800.00
0005434954669	28325	Economy	5800.00
0005435893767	4499	Economy	14000.00
0005434351996	4499	Economy	14000.00
0005435893734	4499	Economy	14000.00
0005434326094	4499	Economy	14000.00
0005434351990	4499	Economy	14000.00
0005434326286	4499	Economy	14000.00
0005434326287	4499	Economy	14000.00
0005434351991	4499	Economy	14000.00
0005434351997	4499	Economy	14000.00
0005435893729	4499	Economy	14000.00
0005434351999	4499	Economy	14000.00
0005434351993	4499	Economy	14000.00
0005434183612	4499	Economy	14000.00
0005434351995	4499	Economy	14000.00
0005434351989	4499	Economy	14000.00
0005434326093	4499	Economy	14000.00
0005434351992	4499	Economy	14000.00
0005434351988	4499	Economy	14000.00
0005435893751	4499	Economy	14000.00
0005434352000	4499	Economy	14000.00
0005434351998	4499	Economy	14000.00
0005435893772	4499	Economy	14000.00
0005435893773	4499	Economy	14000.00
0005435893730	4499	Economy	14000.00
0005434351994	4499	Economy	14000.00
0005434351868	29666	Economy	15400.00
0005434351866	29666	Economy	15400.00
0005434351889	29666	Economy	14000.00
0005434351900	29666	Economy	14000.00
0005435893800	29666	Economy	14000.00
0005434351934	29666	Economy	14000.00
0005434351874	29666	Economy	14000.00
0005434351872	29666	Economy	14000.00
0005434351787	29666	Economy	14000.00
0005434351873	29666	Economy	14000.00
0005434351937	29666	Economy	14000.00
0005435893798	29666	Economy	14000.00
0005434351894	29666	Economy	14000.00
0005434351870	29666	Economy	14000.00
0005434351865	29666	Economy	14000.00
0005434351909	29666	Economy	14000.00
0005434351869	29666	Economy	14000.00
0005434351893	29666	Economy	14000.00
0005435893797	29666	Economy	14000.00
0005434351888	29666	Economy	14000.00
0005434351881	29666	Economy	14000.00
0005434351898	29666	Economy	14000.00
0005435893799	29666	Economy	14000.00
0005434351896	29666	Economy	14000.00
0005435893801	29666	Economy	14000.00
0005434351880	29666	Economy	14000.00
0005434351905	29666	Economy	14000.00
0005434351899	29666	Economy	14000.00
0005435893796	29666	Economy	14000.00
0005434351871	29666	Economy	14000.00
0005433344326	1044	Business	30600.00
0005433344609	1044	Business	30600.00
0005433345096	1044	Business	30600.00
0005433344230	1044	Business	30600.00
0005433344800	1044	Business	30600.00
0005433158162	1044	Business	30600.00
0005433344947	1044	Business	30600.00
0005433344446	1044	Business	30600.00
0005433344786	1044	Business	30600.00
0005435092306	1044	Business	30600.00
0005435092304	1044	Business	30600.00
0005433158173	1044	Business	30600.00
0005433344092	1044	Business	30600.00
0005435092309	1044	Business	30600.00
0005433344621	1044	Business	30600.00
0005433344652	1044	Business	30600.00
0005433344163	1044	Business	30600.00
0005433344555	1044	Economy	11200.00
0005433344565	1044	Economy	10200.00
0005435092308	1044	Economy	10200.00
0005433344269	1044	Economy	10200.00
0005433344135	1044	Economy	10200.00
0005433344480	1044	Economy	10200.00
0005433344695	1044	Economy	10200.00
0005433344608	1044	Economy	10200.00
0005433344736	1044	Economy	10200.00
0005433344955	1044	Economy	10200.00
0005433158160	1044	Economy	10200.00
0005433344361	1044	Economy	10200.00
0005433344858	1044	Economy	10200.00
0005433344558	1044	Economy	10200.00
0005433344766	1044	Economy	10200.00
0005433344332	1044	Economy	10200.00
0005433159344	1044	Economy	10200.00
0005433344366	1044	Economy	10200.00
0005433344093	1044	Economy	10200.00
0005433344317	1044	Economy	10200.00
0005435092312	1044	Economy	10200.00
0005433344790	1044	Economy	10200.00
0005433344909	1044	Economy	10200.00
0005433344184	1044	Economy	10200.00
0005433159349	1044	Economy	10200.00
0005435092303	1044	Economy	10200.00
0005433344325	1044	Economy	10200.00
0005435092310	1044	Economy	10200.00
0005435092305	1044	Economy	10200.00
0005433344901	1044	Economy	10200.00
0005433344478	1044	Economy	10200.00
0005432293264	1044	Economy	10200.00
0005433344689	1044	Economy	10200.00
0005433344329	1044	Economy	10200.00
0005433344460	1044	Economy	10200.00
0005433344686	1044	Economy	10200.00
0005433344278	1044	Economy	10200.00
0005433344614	1044	Economy	10200.00
0005433344425	1044	Economy	10200.00
0005433344274	1044	Economy	10200.00
0005433344450	1044	Economy	10200.00
0005433344005	1044	Economy	10200.00
0005433344781	1044	Economy	10200.00
0005433159345	1044	Economy	10200.00
0005433344846	1044	Economy	10200.00
0005433344896	1044	Economy	10200.00
0005433344349	1044	Economy	10200.00
0005433344136	1044	Economy	10200.00
0005433344799	1044	Economy	10200.00
0005433344162	1044	Economy	10200.00
0005433344397	1044	Economy	10200.00
0005433344365	1044	Economy	10200.00
0005435092311	1044	Economy	10200.00
0005433344481	1044	Economy	10200.00
0005433344573	1044	Economy	10200.00
0005433344277	1044	Economy	10200.00
0005435092307	1044	Economy	10200.00
0005433344170	1044	Economy	10200.00
0005433344265	1044	Economy	10200.00
0005433344605	1044	Economy	10200.00
0005433344337	1044	Economy	10200.00
0005433158161	1044	Economy	10200.00
0005433344726	1044	Economy	10200.00
0005433344387	1044	Economy	10200.00
0005433344699	1044	Economy	11200.00
0005433344500	1044	Economy	10200.00
0005433344475	1044	Economy	10200.00
0005433345097	1044	Economy	10200.00
0005433158172	1044	Economy	11200.00
0005433344477	1044	Economy	10200.00
0005433344711	1044	Economy	10200.00
0005433344470	1044	Economy	10200.00
0005433344486	1044	Economy	10200.00
0005433344336	1044	Economy	10200.00
0005433344350	1044	Economy	10200.00
0005433344499	1044	Economy	10200.00
0005433345057	1044	Economy	10200.00
0005433344375	1044	Economy	10200.00
0005433344897	1044	Economy	10200.00
0005433344622	1044	Economy	10200.00
0005433344376	1044	Economy	10200.00
0005433344245	1044	Economy	10200.00
0005433344703	1044	Economy	10200.00
0005433344701	1044	Economy	10200.00
0005433344735	1044	Economy	10200.00
0005433159347	1044	Economy	10200.00
0005433462798	1044	Economy	10200.00
0005433344700	1044	Economy	10200.00
0005433344780	1044	Economy	10200.00
0005433344777	1044	Economy	10200.00
0005433344604	1044	Economy	10200.00
0005433344845	1044	Economy	10200.00
0005433344344	1044	Economy	10200.00
0005433344853	1044	Economy	10200.00
0005433344787	1044	Economy	10200.00
0005433344339	1044	Economy	10200.00
0005433344479	1044	Economy	10200.00
0005433344393	1044	Economy	10200.00
0005433344334	1044	Economy	10200.00
0005433344661	1044	Economy	10200.00
0005433344615	1044	Economy	10200.00
0005433344757	1044	Economy	10200.00
0005433159348	1044	Economy	10200.00
0005433344639	1044	Economy	10200.00
0005433344244	1044	Economy	10200.00
0005433344751	1044	Economy	10200.00
0005433344900	1044	Economy	10200.00
0005433159346	1044	Economy	10200.00
0005433344396	1044	Economy	10200.00
0005432293265	1044	Economy	10200.00
0005433344765	1044	Economy	10200.00
0005433344469	1044	Economy	10200.00
0005433344132	1044	Economy	10200.00
0005433462797	1044	Economy	10200.00
0005433344978	1044	Economy	10200.00
0005433344006	1044	Economy	10200.00
0005433344231	1044	Economy	10200.00
0005433344333	1044	Economy	10200.00
0005433344253	1044	Economy	10200.00
0005433344386	1044	Economy	10200.00
0005433344568	1044	Economy	10200.00
0005433344968	1044	Economy	10200.00
0005433344404	1044	Economy	10200.00
0005433344424	1044	Economy	10200.00
0005433462796	1044	Economy	10200.00
0005433269814	1044	Economy	10200.00
0005433345388	17057	Business	30600.00
0005435508478	17057	Business	30600.00
0005433345386	17057	Business	30600.00
0005433345358	17057	Business	30600.00
0005433345380	17057	Business	30600.00
0005433345432	17057	Business	30600.00
0005433345385	17057	Business	30600.00
0005433159366	17057	Business	30600.00
0005433345442	17057	Business	30600.00
0005435092255	17057	Business	30600.00
0005435092256	17057	Business	30600.00
0005433345360	17057	Business	30600.00
0005433345393	17057	Business	30600.00
0005433345353	17057	Business	30600.00
0005433345402	17057	Business	30600.00
0005435508498	17057	Business	30600.00
0005433345430	17057	Business	30600.00
0005433345444	17057	Business	30600.00
0005433345410	17057	Business	30600.00
0005433345359	17057	Economy	11200.00
0005433345366	17057	Economy	11200.00
0005435092230	17057	Economy	10200.00
0005433345417	17057	Economy	11200.00
0005433345397	17057	Economy	10200.00
0005435508477	17057	Economy	10200.00
0005433345426	17057	Economy	10200.00
0005433345441	17057	Economy	10200.00
0005433345414	17057	Economy	10200.00
0005435092203	17057	Economy	10200.00
0005433345431	17057	Economy	10200.00
0005435508548	17057	Economy	10200.00
0005433345384	17057	Economy	10200.00
0005433345350	17057	Economy	10200.00
0005435508518	17057	Economy	10200.00
0005433345354	17057	Economy	10200.00
0005433345424	17057	Economy	10200.00
0005433345391	17057	Economy	10200.00
0005433345394	17057	Economy	10200.00
0005433345357	17057	Economy	10200.00
0005435508510	17057	Economy	10200.00
0005433345349	17057	Economy	10200.00
0005433345411	17057	Economy	10200.00
0005434445273	17057	Economy	10200.00
0005433345364	17057	Economy	10200.00
0005433345433	17057	Economy	10200.00
0005433345395	17057	Economy	10200.00
0005433345439	17057	Economy	10200.00
0005433345370	17057	Economy	10200.00
0005433345443	17057	Economy	10200.00
0005435508517	17057	Economy	10200.00
0005435508479	17057	Economy	10200.00
0005433345435	17057	Economy	10200.00
0005433269846	17057	Economy	10200.00
0005433345420	17057	Economy	10200.00
0005433269847	17057	Economy	10200.00
0005433345381	17057	Economy	10200.00
0005435092214	17057	Economy	10200.00
0005433345401	17057	Economy	10200.00
0005433345399	17057	Economy	10200.00
0005433345416	17057	Economy	10200.00
0005433345425	17057	Economy	10200.00
0005433345409	17057	Economy	10200.00
0005433345374	17057	Economy	10200.00
0005433345356	17057	Economy	10200.00
0005433345369	17057	Economy	10200.00
0005435508499	17057	Economy	10200.00
0005433345387	17057	Economy	10200.00
0005433345392	17057	Economy	10200.00
0005433345403	17057	Economy	10200.00
0005433345428	17057	Economy	10200.00
0005433345396	17057	Economy	10200.00
0005433345440	17057	Economy	10200.00
0005433345383	17057	Economy	10200.00
0005433345421	17057	Economy	10200.00
0005433345404	17057	Economy	10200.00
0005433345446	17057	Economy	10200.00
0005433269845	17057	Economy	10200.00
0005433345415	17057	Economy	10200.00
0005433345367	17057	Economy	10200.00
0005433345389	17057	Economy	10200.00
0005433345449	17057	Economy	10200.00
0005433345422	17057	Economy	10200.00
0005435092258	17057	Economy	10200.00
0005433345448	17057	Economy	11200.00
0005433345365	17057	Economy	11200.00
0005433345363	17057	Economy	10200.00
0005433345398	17057	Economy	10200.00
0005433345375	17057	Economy	10200.00
0005433345405	17057	Economy	10200.00
0005433345451	17057	Economy	10200.00
0005434445271	17057	Economy	10200.00
0005433345408	17057	Economy	10200.00
0005433345355	17057	Economy	10200.00
0005435092204	17057	Economy	10200.00
0005433345362	17057	Economy	10200.00
0005435508519	17057	Economy	10200.00
0005433345419	17057	Economy	10200.00
0005433345418	17057	Economy	10200.00
0005433345437	17057	Economy	10200.00
0005433345390	17057	Economy	10200.00
0005433345445	17057	Economy	10200.00
0005435508509	17057	Economy	10200.00
0005433345352	17057	Economy	10200.00
0005433345361	17057	Economy	10200.00
0005435092241	17057	Economy	10200.00
0005435508497	17057	Economy	10200.00
0005433345407	17057	Economy	10200.00
0005433345436	17057	Economy	10200.00
0005433345372	17057	Economy	10200.00
0005433345413	17057	Economy	10200.00
0005433159363	17057	Economy	10200.00
0005433345450	17057	Economy	10200.00
0005433345377	17057	Economy	10200.00
0005433345351	17057	Economy	10200.00
0005433345434	17057	Economy	10200.00
0005433345378	17057	Economy	10200.00
0005433345373	17057	Economy	10200.00
0005433345379	17057	Economy	10200.00
0005433345438	17057	Economy	10200.00
0005433269844	17057	Economy	10200.00
0005433345400	17057	Economy	10200.00
0005433345406	17057	Economy	10200.00
0005433159365	17057	Economy	10200.00
0005433345368	17057	Economy	10200.00
0005433345376	17057	Economy	10200.00
0005433345412	17057	Economy	10200.00
0005433345423	17057	Economy	10200.00
0005433345427	17057	Economy	10200.00
0005433345382	17057	Economy	10200.00
0005433345429	17057	Economy	10200.00
0005435092259	17057	Economy	10200.00
0005433345371	17057	Economy	10200.00
0005433159364	17057	Economy	10200.00
0005433345447	17057	Economy	10200.00
0005434082284	12803	Business	40300.00
0005435283440	12803	Business	40300.00
0005434082245	12803	Business	40300.00
0005434082225	12803	Business	40300.00
0005434068252	12803	Business	40300.00
0005434068504	12803	Business	40300.00
0005433812957	12803	Business	40300.00
0005434068589	12803	Business	40300.00
0005435283441	12803	Business	40300.00
0005434068554	12803	Business	40300.00
0005434068588	12803	Business	40300.00
0005434082217	12803	Business	40300.00
0005434082223	12803	Economy	13400.00
0005434068616	12803	Economy	13400.00
0005433989826	12803	Economy	13400.00
0005434068890	12803	Economy	13400.00
0005434082281	12803	Economy	13400.00
0005434082354	12803	Economy	13400.00
0005432159964	12803	Economy	13400.00
0005434068662	12803	Economy	13400.00
0005434082204	12803	Economy	13400.00
0005434082224	12803	Economy	13400.00
0005434068563	12803	Economy	13400.00
0005433989834	12803	Economy	13400.00
0005434082222	12803	Economy	13400.00
0005434082282	12803	Economy	13400.00
0005434068677	12803	Economy	13400.00
0005435283456	12803	Economy	13400.00
0005434068738	12803	Economy	13400.00
0005434068698	12803	Economy	13400.00
0005434082190	12803	Economy	13400.00
0005434082202	12803	Economy	13400.00
0005434068818	12803	Economy	13400.00
0005432433804	12803	Economy	13400.00
0005434068699	12803	Economy	13400.00
0005434068406	12803	Economy	13400.00
0005434068364	12803	Economy	13400.00
0005432433805	12803	Economy	13400.00
0005434068599	12803	Economy	13400.00
0005434068244	12803	Economy	13400.00
0005434068337	12803	Economy	13400.00
0005432433803	12803	Economy	13400.00
0005434068301	12803	Economy	13400.00
0005434068578	12803	Economy	13400.00
0005434082162	12803	Economy	13400.00
0005433812958	12803	Economy	13400.00
0005432159967	12803	Economy	13400.00
0005433989837	12803	Economy	13400.00
0005434082188	12803	Economy	13400.00
0005434068792	12803	Economy	13400.00
0005434082240	12803	Economy	13400.00
0005434068250	12803	Economy	13400.00
0005434068476	12803	Economy	14800.00
0005434068781	12803	Economy	14800.00
0005435283450	12803	Economy	14800.00
0005434068503	12803	Economy	14800.00
0005434082244	12803	Economy	14800.00
0005434068716	12803	Economy	14800.00
0005434068697	12803	Economy	13400.00
0005433989836	12803	Economy	13400.00
0005435283443	12803	Economy	13400.00
0005432433806	12803	Economy	13400.00
0005434068219	12803	Economy	13400.00
0005435283455	12803	Economy	13400.00
0005434082144	12803	Economy	13400.00
0005435283457	12803	Economy	13400.00
0005434082173	12803	Economy	13400.00
0005434068251	12803	Economy	13400.00
0005434068681	12803	Economy	13400.00
0005435283442	12803	Economy	13400.00
0005434068475	12803	Economy	13400.00
0005434026724	12803	Economy	13400.00
0005434068713	12803	Economy	13400.00
0005435283445	12803	Economy	13400.00
0005433989815	12803	Economy	13400.00
0005434068646	12803	Economy	13400.00
0005434068565	12803	Economy	13400.00
0005435283447	12803	Economy	13400.00
0005434068462	12803	Economy	13400.00
0005435283451	12803	Economy	13400.00
0005434082277	12803	Economy	13400.00
0005435283452	12803	Economy	13400.00
0005434068780	12803	Economy	13400.00
0005433989864	12803	Economy	13400.00
0005434068704	12803	Economy	13400.00
0005434068819	12803	Economy	13400.00
0005434068573	12803	Economy	13400.00
0005434068302	12803	Economy	13400.00
0005435283448	12803	Economy	13400.00
0005434068484	12803	Economy	13400.00
0005434082147	12803	Economy	13400.00
0005434068535	12803	Economy	13400.00
0005432433808	12803	Economy	13400.00
0005432159963	12803	Economy	13400.00
0005434082174	12803	Economy	13400.00
0005434068574	12803	Economy	13400.00
0005435283444	12803	Economy	13400.00
0005434068680	12803	Economy	13400.00
0005434082274	12803	Economy	13400.00
0005434068521	12803	Economy	13400.00
0005434068405	12803	Economy	13400.00
0005433989816	12803	Economy	13400.00
0005434068192	12803	Economy	13400.00
0005432433807	12803	Economy	13400.00
0005434068386	12803	Economy	13400.00
0005435283449	12803	Economy	13400.00
0005434068572	12803	Economy	13400.00
0005432159966	12803	Economy	13400.00
0005434068466	12803	Economy	13400.00
0005435283454	12803	Economy	13400.00
0005435283446	12803	Economy	13400.00
0005434068553	12803	Economy	13400.00
0005434082278	12803	Economy	13400.00
0005435283453	12803	Economy	13400.00
0005432159965	12803	Economy	13400.00
0005434082275	12803	Economy	13400.00
0005434068674	12803	Economy	13400.00
0005434068520	12803	Economy	13400.00
0005434068434	12803	Economy	13400.00
0005432161205	12803	Economy	13400.00
0005434068736	12803	Economy	13400.00
0005434082232	12803	Economy	13400.00
0005434068609	12803	Economy	13400.00
0005434082271	12803	Economy	13400.00
0005433812956	12803	Economy	13400.00
0005434068533	12803	Economy	13400.00
0005434068564	12803	Economy	13400.00
0005434068191	12803	Economy	13400.00
0005434068220	12803	Economy	13400.00
0005434069164	30693	Business	40300.00
0005432186952	30693	Business	40300.00
0005434069170	30693	Business	40300.00
0005434069145	30693	Business	40300.00
0005433989880	30693	Business	40300.00
0005433989881	30693	Business	40300.00
0005434069151	30693	Business	40300.00
0005434069186	30693	Business	40300.00
0005434069156	30693	Business	40300.00
0005434069189	30693	Business	40300.00
0005434069181	30693	Business	40300.00
0005433812931	30693	Business	40300.00
0005434069199	30693	Economy	13400.00
0005434082439	30693	Economy	13400.00
0005434069193	30693	Economy	13400.00
0005433812923	30693	Economy	13400.00
0005434069152	30693	Economy	13400.00
0005434069176	30693	Economy	13400.00
0005434082438	30693	Economy	13400.00
0005433812921	30693	Economy	13400.00
0005434026750	30693	Economy	13400.00
0005434069198	30693	Economy	13400.00
0005434069139	30693	Economy	13400.00
0005434069171	30693	Economy	13400.00
0005432150372	30693	Economy	13400.00
0005434069169	30693	Economy	13400.00
0005432433741	30693	Economy	13400.00
0005432150369	30693	Economy	13400.00
0005434069144	30693	Economy	13400.00
0005434082440	30693	Economy	13400.00
0005434069133	30693	Economy	13400.00
0005434069158	30693	Economy	13400.00
0005434069134	30693	Economy	13400.00
0005432186951	30693	Economy	13400.00
0005434069185	30693	Economy	13400.00
0005434026743	30693	Economy	13400.00
0005434026745	30693	Economy	13400.00
0005434069149	30693	Economy	13400.00
0005434069132	30693	Economy	13400.00
0005433812928	30693	Economy	13400.00
0005434069146	30693	Economy	13400.00
0005434069141	30693	Economy	13400.00
0005434069197	30693	Economy	13400.00
0005434069182	30693	Economy	13400.00
0005434069190	30693	Economy	13400.00
0005432150374	30693	Economy	13400.00
0005434069148	30693	Economy	13400.00
0005432433740	30693	Economy	13400.00
0005434026749	30693	Economy	13400.00
0005433812911	30693	Economy	13400.00
0005434069166	30693	Economy	13400.00
0005433989877	30693	Economy	14800.00
0005434069155	30693	Economy	14800.00
0005434069196	30693	Economy	14800.00
0005434069180	30693	Economy	14800.00
0005432150370	30693	Economy	14800.00
0005434082436	30693	Economy	14800.00
0005434069163	30693	Economy	13400.00
0005434069178	30693	Economy	13400.00
0005434026747	30693	Economy	13400.00
0005434069165	30693	Economy	13400.00
0005434069147	30693	Economy	13400.00
0005434069128	30693	Economy	13400.00
0005434069154	30693	Economy	13400.00
0005434069183	30693	Economy	13400.00
0005434082434	30693	Economy	13400.00
0005434069130	30693	Economy	13400.00
0005434069168	30693	Economy	13400.00
0005434069150	30693	Economy	13400.00
0005434069191	30693	Economy	13400.00
0005434082429	30693	Economy	13400.00
0005434069142	30693	Economy	13400.00
0005433812919	30693	Economy	13400.00
0005432186953	30693	Economy	13400.00
0005433812925	30693	Economy	13400.00
0005434082435	30693	Economy	13400.00
0005434069179	30693	Economy	13400.00
0005433989878	30693	Economy	13400.00
0005432150375	30693	Economy	13400.00
0005434069174	30693	Economy	13400.00
0005434026744	30693	Economy	13400.00
0005433812929	30693	Economy	13400.00
0005434069195	30693	Economy	13400.00
0005434069175	30693	Economy	13400.00
0005433812927	30693	Economy	13400.00
0005434026746	30693	Economy	13400.00
0005433812930	30693	Economy	13400.00
0005434069157	30693	Economy	13400.00
0005434069162	30693	Economy	13400.00
0005434069187	30693	Economy	13400.00
0005434069143	30693	Economy	13400.00
0005434069172	30693	Economy	13400.00
0005434069192	30693	Economy	13400.00
0005433989876	30693	Economy	13400.00
0005434069137	30693	Economy	13400.00
0005434069159	30693	Economy	13400.00
0005434069161	30693	Economy	13400.00
0005432433770	30693	Economy	13400.00
0005434069194	30693	Economy	13400.00
0005434069188	30693	Economy	13400.00
0005434082430	30693	Economy	13400.00
0005434082428	30693	Economy	13400.00
0005434069177	30693	Economy	13400.00
0005432433739	30693	Economy	13400.00
0005434082427	30693	Economy	13400.00
0005434082432	30693	Economy	13400.00
0005434069138	30693	Economy	13400.00
0005434069184	30693	Economy	13400.00
0005434069200	30693	Economy	13400.00
0005434069167	30693	Economy	13400.00
0005434082426	30693	Economy	13400.00
0005434026748	30693	Economy	13400.00
0005434069131	30693	Economy	13400.00
0005432150368	30693	Economy	13400.00
0005434082431	30693	Economy	13400.00
0005433812912	30693	Economy	13400.00
0005434069140	30693	Economy	13400.00
0005434069135	30693	Economy	13400.00
0005432433750	30693	Economy	13400.00
0005434082433	30693	Economy	13400.00
0005434069153	30693	Economy	13400.00
0005432150373	30693	Economy	13400.00
0005434069173	30693	Economy	13400.00
0005434069136	30693	Economy	13400.00
0005434082437	30693	Economy	13400.00
0005434069160	30693	Economy	13400.00
0005434069129	30693	Economy	13400.00
0005433989879	30693	Economy	13400.00
0005432150371	30693	Economy	13400.00
0005435767694	5540	Business	35300.00
0005435725711	5540	Business	35300.00
0005434831211	5540	Business	35300.00
0005435767692	5540	Business	35300.00
0005432535913	5540	Business	35300.00
0005433527359	5540	Business	35300.00
0005435463051	5540	Business	35300.00
0005435767671	5540	Business	35300.00
0005435767680	5540	Business	35300.00
0005435767665	5540	Business	35300.00
0005435767636	5540	Business	35300.00
0005435767637	5540	Business	35300.00
0005435767643	5540	Business	35300.00
0005435463119	5540	Business	35300.00
0005435462863	5540	Business	35300.00
0005435767675	5540	Business	35300.00
0005435463065	5540	Business	35300.00
0005433527357	5540	Business	35300.00
0005435463023	5540	Business	35300.00
0005435767666	5540	Business	35300.00
0005435767658	5540	Business	35300.00
0005432535903	5540	Business	35300.00
0005435767689	5540	Business	35300.00
0005435767670	5540	Economy	12900.00
0005435463057	5540	Economy	12900.00
0005434831186	5540	Economy	12900.00
0005435463101	5540	Economy	11800.00
0005435463010	5540	Economy	11800.00
0005435462879	5540	Economy	11800.00
0005435725710	5540	Economy	11800.00
0005435767652	5540	Economy	11800.00
0005432140642	5540	Economy	11800.00
0005435767677	5540	Economy	11800.00
0005435767651	5540	Economy	11800.00
0005435767653	5540	Economy	11800.00
0005435463021	5540	Economy	11800.00
0005435735246	5540	Economy	11800.00
0005435767635	5540	Economy	11800.00
0005435767659	5540	Economy	11800.00
0005435767681	5540	Economy	11800.00
0005435463064	5540	Economy	11800.00
0005435767644	5540	Economy	11800.00
0005435723088	5540	Economy	11800.00
0005435767683	5540	Economy	11800.00
0005435462921	5540	Economy	11800.00
0005435767650	5540	Economy	11800.00
0005435767648	5540	Economy	11800.00
0005435767690	5540	Economy	11800.00
0005435767663	5540	Economy	11800.00
0005435462841	5540	Economy	11800.00
0005434265566	5540	Economy	11800.00
0005435767668	5540	Economy	11800.00
0005435463006	5540	Economy	11800.00
0005435767672	5540	Economy	11800.00
0005435767678	5540	Economy	11800.00
0005434265458	5540	Economy	11800.00
0005435463050	5540	Economy	11800.00
0005432535898	5540	Economy	11800.00
0005434265457	5540	Economy	11800.00
0005434831203	5540	Economy	11800.00
0005435767657	5540	Economy	11800.00
0005432535883	5540	Economy	11800.00
0005435767685	5540	Economy	11800.00
0005435767673	5540	Economy	11800.00
0005433529368	5540	Economy	11800.00
0005435463120	5540	Economy	11800.00
0005435767655	5540	Economy	11800.00
0005434265496	5540	Economy	11800.00
0005435767684	5540	Economy	11800.00
0005432140640	5540	Economy	11800.00
0005435463086	5540	Economy	11800.00
0005434265381	5540	Economy	11800.00
0005435722111	5540	Economy	11800.00
0005435767693	5540	Economy	11800.00
0005435462924	5540	Economy	11800.00
0005432535902	5540	Economy	11800.00
0005434265495	5540	Economy	11800.00
0005435463014	5540	Economy	11800.00
0005435462930	5540	Economy	11800.00
0005435767634	5540	Economy	11800.00
0005432535912	5540	Economy	11800.00
0005434265470	5540	Economy	11800.00
0005435462741	5540	Economy	11800.00
0005435463087	5540	Economy	11800.00
0005435767662	5540	Economy	11800.00
0005435735243	5540	Economy	11800.00
0005432535882	5540	Economy	11800.00
0005435735244	5540	Economy	11800.00
0005435462897	5540	Economy	11800.00
0005435725713	5540	Economy	11800.00
0005435767640	5540	Economy	11800.00
0005434265474	5540	Economy	11800.00
0005435767641	5540	Economy	11800.00
0005435767674	5540	Economy	11800.00
0005435767646	5540	Economy	11800.00
0005432535888	5540	Economy	11800.00
0005435720852	5540	Economy	11800.00
0005434265531	5540	Economy	11800.00
0005433529369	5540	Economy	11800.00
0005435463037	5540	Economy	11800.00
0005435767649	5540	Economy	11800.00
0005435463088	5540	Economy	11800.00
0005435767679	5540	Economy	11800.00
0005434265475	5540	Economy	11800.00
0005432140638	5540	Economy	11800.00
0005435767686	5540	Economy	11800.00
0005435767682	5540	Economy	11800.00
0005432140639	5540	Economy	11800.00
0005435462962	5540	Economy	11800.00
0005435463036	5540	Economy	11800.00
0005435462893	5540	Economy	11800.00
0005435767661	5540	Economy	11800.00
0005432535906	5540	Economy	12900.00
0005435463011	5540	Economy	12900.00
0005435767647	5540	Economy	11800.00
0005435735245	5540	Economy	11800.00
0005434265380	5540	Economy	11800.00
0005435767639	5540	Economy	12900.00
0005435767660	5540	Economy	12900.00
0005432535899	5540	Economy	11800.00
0005433527358	5540	Economy	11800.00
0005435462929	5540	Economy	11800.00
0005435462842	5540	Economy	11800.00
0005435725712	5540	Economy	11800.00
0005434265529	5540	Economy	11800.00
0005434265565	5540	Economy	11800.00
0005432140645	5540	Economy	11800.00
0005433527360	5540	Economy	11800.00
0005435463186	5540	Economy	11800.00
0005435723089	5540	Economy	11800.00
0005435462963	5540	Economy	11800.00
0005432140643	5540	Economy	11800.00
0005435767691	5540	Economy	11800.00
0005435735247	5540	Economy	11800.00
0005435767695	5540	Economy	11800.00
0005435767656	5540	Economy	11800.00
0005432140641	5540	Economy	11800.00
0005434265490	5540	Economy	11800.00
0005434265520	5540	Economy	11800.00
0005435720851	5540	Economy	11800.00
0005435767687	5540	Economy	11800.00
0005434265394	5540	Economy	11800.00
0005434265501	5540	Economy	11800.00
0005434265395	5540	Economy	11800.00
0005435767654	5540	Economy	11800.00
0005435767645	5540	Economy	11800.00
0005435767664	5540	Economy	11800.00
0005435462880	5540	Economy	11800.00
0005432535901	5540	Economy	11800.00
0005435767676	5540	Economy	11800.00
0005435462986	5540	Economy	11800.00
0005435462864	5540	Economy	11800.00
0005433527355	5540	Economy	11800.00
0005435767688	5540	Economy	11800.00
0005435723090	5540	Economy	11800.00
0005434265585	5540	Economy	11800.00
0005434265471	5540	Economy	11800.00
0005435462956	5540	Economy	11800.00
0005435767669	5540	Economy	11800.00
0005435767667	5540	Economy	11800.00
0005435463185	5540	Economy	11800.00
0005435767638	5540	Economy	11800.00
0005435463025	5540	Economy	11800.00
0005433529367	5540	Economy	11800.00
0005434265379	5540	Economy	11800.00
0005435462840	5540	Economy	11800.00
0005433527356	5540	Economy	11800.00
0005432140637	5540	Economy	11800.00
0005435767642	5540	Economy	11800.00
0005435463038	5540	Economy	11800.00
0005432140644	5540	Economy	11800.00
0005435463032	5540	Economy	11800.00
0005432535896	5540	Economy	11800.00
0005434265519	5540	Economy	11800.00
0005435463121	5540	Economy	11800.00
0005435767696	5540	Economy	11800.00
0005434265472	5540	Economy	11800.00
0005434265500	5540	Economy	11800.00
0005435463322	13484	Business	35300.00
0005432194609	13484	Business	35300.00
0005435463315	13484	Business	35300.00
0005435767117	13484	Business	35300.00
0005435767048	13484	Business	35300.00
0005435043302	13484	Business	35300.00
0005435463314	13484	Business	35300.00
0005435463312	13484	Business	35300.00
0005434265749	13484	Business	35300.00
0005435723079	13484	Business	35300.00
0005435463339	13484	Business	35300.00
0005435463333	13484	Business	35300.00
0005435463335	13484	Business	35300.00
0005434265739	13484	Business	35300.00
0005435767281	13484	Business	35300.00
0005434265746	13484	Business	35300.00
0005435767163	13484	Business	35300.00
0005435463326	13484	Business	35300.00
0005435766968	13484	Business	35300.00
0005435766631	13484	Economy	12900.00
0005435463307	13484	Economy	12900.00
0005435463331	13484	Economy	11800.00
0005432535949	13484	Economy	11800.00
0005435043303	13484	Economy	11800.00
0005435463306	13484	Economy	11800.00
0005435767155	13484	Economy	11800.00
0005434831261	13484	Economy	11800.00
0005435463334	13484	Economy	11800.00
0005435767033	13484	Economy	11800.00
0005435767098	13484	Economy	11800.00
0005435767310	13484	Economy	11800.00
0005435463328	13484	Economy	11800.00
0005434265735	13484	Economy	11800.00
0005435767056	13484	Economy	11800.00
0005435463319	13484	Economy	11800.00
0005435767100	13484	Economy	11800.00
0005435723080	13484	Economy	11800.00
0005435463332	13484	Economy	11800.00
0005435463323	13484	Economy	11800.00
0005435766923	13484	Economy	11800.00
0005434265741	13484	Economy	11800.00
0005434265754	13484	Economy	11800.00
0005435766967	13484	Economy	11800.00
0005435722089	13484	Economy	11800.00
0005435463330	13484	Economy	11800.00
0005434265743	13484	Economy	11800.00
0005434265736	13484	Economy	11800.00
0005435463329	13484	Economy	11800.00
0005432535951	13484	Economy	11800.00
0005435767311	13484	Economy	11800.00
0005434831263	13484	Economy	11800.00
0005435722082	13484	Economy	11800.00
0005435767152	13484	Economy	11800.00
0005435767197	13484	Economy	11800.00
0005434265747	13484	Economy	11800.00
0005435463302	13484	Economy	11800.00
0005435723078	13484	Economy	11800.00
0005435463309	13484	Economy	11800.00
0005434265734	13484	Economy	11800.00
0005435767002	13484	Economy	11800.00
0005434265755	13484	Economy	11800.00
0005435723076	13484	Economy	11800.00
0005435767196	13484	Economy	11800.00
0005435767150	13484	Economy	11800.00
0005435767021	13484	Economy	11800.00
0005435767133	13484	Economy	11800.00
0005434265748	13484	Economy	11800.00
0005435463317	13484	Economy	11800.00
0005435463304	13484	Economy	11800.00
0005432194610	13484	Economy	11800.00
0005435766824	13484	Economy	11800.00
0005434265753	13484	Economy	11800.00
0005435767200	13484	Economy	11800.00
0005435767065	13484	Economy	11800.00
0005435767340	13484	Economy	11800.00
0005434265742	13484	Economy	11800.00
0005434831262	13484	Economy	11800.00
0005435463341	13484	Economy	11800.00
0005435735206	13484	Economy	11800.00
0005435766856	13484	Economy	11800.00
0005435767127	13484	Economy	11800.00
0005434265740	13484	Economy	11800.00
0005435463321	13484	Economy	11800.00
0005435463310	13484	Economy	11800.00
0005435767211	13484	Economy	11800.00
0005434265738	13484	Economy	11800.00
0005435722090	13484	Economy	11800.00
0005435725670	13484	Economy	11800.00
0005435767099	13484	Economy	11800.00
0005435767179	13484	Economy	11800.00
0005434265733	13484	Economy	11800.00
0005434265750	13484	Economy	11800.00
0005435767201	13484	Economy	11800.00
0005435767101	13484	Economy	11800.00
0005435463316	13484	Economy	12900.00
0005435463320	13484	Economy	12900.00
0005435767049	13484	Economy	11800.00
0005435735218	13484	Economy	11800.00
0005435725671	13484	Economy	11800.00
0005435735199	13484	Economy	11800.00
0005435725668	13484	Economy	11800.00
0005435767136	13484	Economy	11800.00
0005435767050	13484	Economy	11800.00
0005434265752	13484	Economy	11800.00
0005435767020	13484	Economy	11800.00
0005435723077	13484	Economy	11800.00
0005435767137	13484	Economy	11800.00
0005435463325	13484	Economy	11800.00
0005435766823	13484	Economy	11800.00
0005435766820	13484	Economy	11800.00
0005435767047	13484	Economy	11800.00
0005434265745	13484	Economy	11800.00
0005435463313	13484	Economy	11800.00
0005432535948	13484	Economy	11800.00
0005435767132	13484	Economy	11800.00
0005435767151	13484	Economy	11800.00
0005435767210	13484	Economy	11800.00
0005435463318	13484	Economy	11800.00
0005435725666	13484	Economy	11800.00
0005435767145	13484	Economy	11800.00
0005432535947	13484	Economy	11800.00
0005435725667	13484	Economy	11800.00
0005435463340	13484	Economy	11800.00
0005435767105	13484	Economy	11800.00
0005435767149	13484	Economy	11800.00
0005435766905	13484	Economy	11800.00
0005435463303	13484	Economy	11800.00
0005435735205	13484	Economy	11800.00
0005435767135	13484	Economy	11800.00
0005435735192	13484	Economy	11800.00
0005435463336	13484	Economy	11800.00
0005434265737	13484	Economy	11800.00
0005435767280	13484	Economy	11800.00
0005435463338	13484	Economy	11800.00
0005435463337	13484	Economy	11800.00
0005435766962	13484	Economy	11800.00
0005435463308	13484	Economy	11800.00
0005435463327	13484	Economy	11800.00
0005435767116	13484	Economy	11800.00
0005435463311	13484	Economy	11800.00
0005435767128	13484	Economy	11800.00
0005435463324	13484	Economy	11800.00
0005434265744	13484	Economy	11800.00
0005435767199	13484	Economy	11800.00
0005435766952	13484	Economy	11800.00
0005435766855	13484	Economy	11800.00
0005432535950	13484	Economy	11800.00
0005435463305	13484	Economy	11800.00
0005434265751	13484	Economy	11800.00
0005434602938	18655	Economy	3300.00
0005434602939	18655	Economy	3300.00
0005434604940	18653	Economy	3300.00
0005434513639	18653	Economy	3300.00
0005434604965	18653	Economy	3300.00
0005434515028	18653	Economy	3300.00
0005434604928	18653	Economy	3300.00
0005434513638	18653	Economy	3300.00
0005434604929	18653	Economy	3300.00
0005434515026	18653	Economy	3300.00
0005434604945	18653	Economy	3300.00
0005434515027	18653	Economy	3300.00
0005434513640	18653	Economy	3300.00
0005434604941	18653	Economy	3300.00
0005434602959	19198	Economy	3300.00
0005434602955	19198	Economy	3300.00
0005434602951	19198	Economy	3300.00
0005434602953	19198	Economy	3300.00
0005434602956	19198	Economy	3300.00
0005434602960	19198	Economy	3300.00
0005434602957	19198	Economy	3300.00
0005434602954	19198	Economy	3300.00
0005434602952	19198	Economy	3300.00
0005434602958	19198	Economy	3300.00
0005432632814	25078	Business	88300.00
0005432649490	25078	Business	88300.00
0005432649489	25078	Business	88300.00
0005432649498	25078	Business	88300.00
0005435846330	25078	Business	88300.00
0005432649457	25078	Business	88300.00
0005435844403	25078	Business	88300.00
0005432632830	25078	Business	88300.00
0005432649507	25078	Business	88300.00
0005435844401	25078	Economy	29400.00
0005435846333	25078	Economy	29400.00
0005435844394	25078	Economy	29400.00
0005432649476	25078	Economy	29400.00
0005435846337	25078	Economy	29400.00
0005432632826	25078	Economy	29400.00
0005432632829	25078	Economy	29400.00
0005435846335	25078	Economy	29400.00
0005435844405	25078	Economy	32400.00
0005432632822	25078	Economy	32400.00
0005435844399	25078	Economy	32400.00
0005435844402	25078	Economy	29400.00
0005432649506	25078	Economy	29400.00
0005432632813	25078	Economy	29400.00
0005432632818	25078	Economy	29400.00
0005435844406	25078	Economy	29400.00
0005432649477	25078	Economy	29400.00
0005435846339	25078	Economy	29400.00
0005435846336	25078	Economy	29400.00
0005432632806	25078	Economy	29400.00
0005432632819	25078	Economy	29400.00
0005432632771	25078	Economy	29400.00
0005432649440	25078	Economy	29400.00
0005432649469	25078	Economy	29400.00
0005432632797	25078	Economy	29400.00
0005432632828	25078	Economy	29400.00
0005432632827	25078	Economy	29400.00
0005432632789	25078	Economy	29400.00
0005435846338	25078	Economy	29400.00
0005435844398	25078	Economy	29400.00
0005432632831	25078	Economy	29400.00
0005432632796	25078	Economy	29400.00
0005435844397	25078	Economy	29400.00
0005432632836	25078	Economy	29400.00
0005432649509	25078	Economy	29400.00
0005435844393	25078	Economy	29400.00
0005435844396	25078	Economy	29400.00
0005435844400	25078	Economy	29400.00
0005432649497	25078	Economy	29400.00
0005432632817	25078	Economy	29400.00
0005432632791	25078	Economy	29400.00
0005432649463	25078	Economy	29400.00
0005432649464	25078	Economy	29400.00
0005432632821	25078	Economy	29400.00
0005435844395	25078	Economy	29400.00
0005432649475	25078	Economy	29400.00
0005435846331	25078	Economy	29400.00
0005435844404	25078	Economy	29400.00
0005435846332	25078	Economy	29400.00
0005432632848	25078	Economy	29400.00
0005432632809	25078	Economy	29400.00
0005432632800	25078	Economy	29400.00
0005432632825	25078	Economy	29400.00
0005432649441	25078	Economy	29400.00
0005432632849	25078	Economy	29400.00
0005432632807	25078	Economy	29400.00
0005432632820	25078	Economy	29400.00
0005432649508	25078	Economy	29400.00
0005435844407	25078	Economy	29400.00
0005432632788	25078	Economy	29400.00
0005435846334	25078	Economy	29400.00
0005432632785	25078	Economy	29400.00
0005433285723	1838	Business	48700.00
0005433009460	1838	Business	48700.00
0005433285849	1838	Business	48700.00
0005433285746	1838	Business	48700.00
0005433009422	1838	Business	48700.00
0005433285816	1838	Business	48700.00
0005433285776	1838	Business	48700.00
0005433009442	1838	Business	48700.00
0005433009209	1838	Business	48700.00
0005433285706	1838	Business	48700.00
0005433285772	1838	Business	48700.00
0005433009491	1838	Economy	16200.00
0005433009281	1838	Economy	16200.00
0005433009490	1838	Economy	16200.00
0005433009413	1838	Economy	16200.00
0005433285679	1838	Economy	16200.00
0005433810670	1838	Economy	16200.00
0005433009461	1838	Economy	16200.00
0005433009282	1838	Economy	16200.00
0005433009414	1838	Economy	16200.00
0005433009264	1838	Economy	17900.00
0005433285713	1838	Economy	17900.00
0005433285694	1838	Economy	17900.00
0005433285812	1838	Economy	17900.00
0005433285825	1838	Economy	16200.00
0005433810676	1838	Economy	16200.00
0005433810671	1838	Economy	16200.00
0005433810674	1838	Economy	16200.00
0005433285717	1838	Economy	16200.00
0005433009253	1838	Economy	16200.00
0005433009440	1838	Economy	16200.00
0005433009392	1838	Economy	16200.00
0005433285803	1838	Economy	16200.00
0005433285707	1838	Economy	16200.00
0005433285785	1838	Economy	16200.00
0005433009235	1838	Economy	16200.00
0005433285705	1838	Economy	16200.00
0005433009189	1838	Economy	16200.00
0005433009343	1838	Economy	16200.00
0005433009261	1838	Economy	16200.00
0005433285815	1838	Economy	16200.00
0005433009085	1838	Economy	16200.00
0005433285804	1838	Economy	16200.00
0005433009462	1838	Economy	16200.00
0005433285655	1838	Economy	16200.00
0005433009084	1838	Economy	16200.00
0005433009441	1838	Economy	16200.00
0005433009344	1838	Economy	16200.00
0005433285800	1838	Economy	16200.00
0005433810675	1838	Economy	16200.00
0005432295940	1838	Economy	16200.00
0005433810673	1838	Economy	16200.00
0005433285556	1838	Economy	16200.00
0005433009313	1838	Economy	16200.00
0005433009419	1838	Economy	16200.00
0005433285718	1838	Economy	16200.00
0005432295942	1838	Economy	16200.00
0005433009406	1838	Economy	16200.00
0005433009086	1838	Economy	16200.00
0005433285786	1838	Economy	16200.00
0005433009190	1838	Economy	16200.00
0005433009421	1838	Economy	16200.00
0005433009202	1838	Economy	16200.00
0005433285783	1838	Economy	16200.00
0005433009201	1838	Economy	16200.00
0005433009404	1838	Economy	16200.00
0005433009300	1838	Economy	16200.00
0005433810672	1838	Economy	16200.00
0005433285821	1838	Economy	16200.00
0005433285810	1838	Economy	16200.00
0005433285719	1838	Economy	16200.00
0005433285703	1838	Economy	16200.00
0005433285634	1838	Economy	16200.00
0005432295941	1838	Economy	16200.00
0005433285811	1838	Economy	16200.00
0005433285747	1838	Economy	16200.00
0005433009398	1838	Economy	16200.00
0005433285740	1838	Economy	16200.00
0005433285938	1838	Economy	16200.00
0005433009234	1838	Economy	16200.00
0005433009303	1838	Economy	16200.00
0005433285756	1838	Economy	16200.00
0005433009260	1838	Economy	16200.00
0005433285684	1838	Economy	16200.00
0005433810677	1838	Economy	16200.00
0005433285725	1838	Economy	16200.00
0005433009319	1838	Economy	16200.00
0005433009069	1838	Economy	16200.00
0005433286021	22531	Business	48700.00
0005433009669	22531	Business	48700.00
0005433285996	22531	Business	48700.00
0005433009676	22531	Business	48700.00
0005433009637	22531	Business	48700.00
0005433009650	22531	Business	48700.00
0005433009645	22531	Business	48700.00
0005433810597	22531	Business	48700.00
0005433009663	22531	Business	48700.00
0005433286000	22531	Business	48700.00
0005433009635	22531	Business	48700.00
0005433009675	22531	Economy	16200.00
0005433009639	22531	Economy	16200.00
0005433286001	22531	Economy	16200.00
0005433009674	22531	Economy	16200.00
0005433009677	22531	Economy	16200.00
0005433810585	22531	Economy	16200.00
0005433009670	22531	Economy	16200.00
0005433286009	22531	Economy	16200.00
0005433009631	22531	Economy	16200.00
0005433286005	22531	Economy	17900.00
0005433286010	22531	Economy	17900.00
0005433286026	22531	Economy	17900.00
0005433009668	22531	Economy	17900.00
0005433009633	22531	Economy	17900.00
0005433009652	22531	Economy	16200.00
0005433285999	22531	Economy	16200.00
0005433009660	22531	Economy	16200.00
0005433286014	22531	Economy	16200.00
0005433009671	22531	Economy	16200.00
0005433810586	22531	Economy	16200.00
0005433009658	22531	Economy	16200.00
0005433286018	22531	Economy	16200.00
0005433009641	22531	Economy	16200.00
0005433286020	22531	Economy	16200.00
0005433286006	22531	Economy	16200.00
0005433286015	22531	Economy	16200.00
0005433286019	22531	Economy	16200.00
0005433009665	22531	Economy	16200.00
0005433009662	22531	Economy	16200.00
0005433286017	22531	Economy	16200.00
0005433286013	22531	Economy	16200.00
0005433286008	22531	Economy	16200.00
0005433009672	22531	Economy	16200.00
0005433009655	22531	Economy	16200.00
0005433285998	22531	Economy	16200.00
0005433009632	22531	Economy	16200.00
0005433810584	22531	Economy	16200.00
0005433009646	22531	Economy	16200.00
0005433285994	22531	Economy	16200.00
0005433286011	22531	Economy	16200.00
0005433009667	22531	Economy	16200.00
0005433009644	22531	Economy	16200.00
0005433009636	22531	Economy	16200.00
0005433009657	22531	Economy	16200.00
0005433009659	22531	Economy	16200.00
0005433286023	22531	Economy	16200.00
0005433286002	22531	Economy	16200.00
0005433009649	22531	Economy	16200.00
0005433009653	22531	Economy	16200.00
0005433009648	22531	Economy	16200.00
0005433009640	22531	Economy	16200.00
0005433286024	22531	Economy	16200.00
0005433009664	22531	Economy	16200.00
0005433286007	22531	Economy	16200.00
0005433009656	22531	Economy	16200.00
0005433009666	22531	Economy	16200.00
0005433285995	22531	Economy	16200.00
0005433009661	22531	Economy	16200.00
0005433286025	22531	Economy	16200.00
0005433009642	22531	Economy	16200.00
0005433009654	22531	Economy	16200.00
0005433009673	22531	Economy	16200.00
0005433286012	22531	Economy	16200.00
0005433286022	22531	Economy	16200.00
0005433286004	22531	Economy	16200.00
0005433286003	22531	Economy	16200.00
0005433285997	22531	Economy	16200.00
0005433009643	22531	Economy	16200.00
0005433286016	22531	Economy	16200.00
0005433009634	22531	Economy	16200.00
0005433009638	22531	Economy	16200.00
0005433009651	22531	Economy	16200.00
0005433009647	22531	Economy	16200.00
0005432081663	5569	Business	99800.00
0005433848069	5569	Business	99800.00
0005433848054	5569	Business	99800.00
0005433848061	5569	Business	99800.00
0005433848062	5569	Business	99800.00
0005433848068	5569	Business	99800.00
0005433848056	5569	Business	99800.00
0005433848109	5569	Business	99800.00
0005433848098	5569	Business	99800.00
0005433848091	5569	Business	99800.00
0005433848092	5569	Business	99800.00
0005435282935	5569	Business	99800.00
0005432081659	5569	Business	99800.00
0005433848105	5569	Business	99800.00
0005433848083	5569	Business	99800.00
0005433815494	5569	Business	99800.00
0005434173567	5569	Business	99800.00
0005433848076	5569	Business	99800.00
0005435282792	5569	Business	99800.00
0005433848077	5569	Economy	33300.00
0005435282732	5569	Economy	33300.00
0005433848093	5569	Economy	33300.00
0005434173568	5569	Economy	33300.00
0005433848073	5569	Economy	33300.00
0005432081665	5569	Economy	33300.00
0005435282893	5569	Economy	33300.00
0005435282927	5569	Economy	33300.00
0005433848085	5569	Economy	33300.00
0005433848089	5569	Economy	33300.00
0005433848110	5569	Economy	33300.00
0005434173584	5569	Economy	33300.00
0005435282863	5569	Economy	36600.00
0005434173587	5569	Economy	36600.00
0005435282864	5569	Economy	36600.00
0005433848106	5569	Economy	33300.00
0005433815496	5569	Economy	36600.00
0005435282815	5569	Economy	33300.00
0005433848104	5569	Economy	33300.00
0005433848096	5569	Economy	33300.00
0005435282878	5569	Economy	33300.00
0005433848102	5569	Economy	33300.00
0005433848079	5569	Economy	33300.00
0005433848064	5569	Economy	33300.00
0005433848072	5569	Economy	33300.00
0005433848080	5569	Economy	33300.00
0005435282856	5569	Economy	33300.00
0005433848086	5569	Economy	33300.00
0005433848100	5569	Economy	33300.00
0005433848065	5569	Economy	33300.00
0005433848074	5569	Economy	33300.00
0005433848107	5569	Economy	33300.00
0005432081661	5569	Economy	33300.00
0005435282889	5569	Economy	33300.00
0005433848067	5569	Economy	33300.00
0005433848101	5569	Economy	33300.00
0005433848087	5569	Economy	33300.00
0005433848112	5569	Economy	33300.00
0005435282897	5569	Economy	33300.00
0005435282876	5569	Economy	33300.00
0005435282816	5569	Economy	33300.00
0005433848090	5569	Economy	33300.00
0005433815495	5569	Economy	33300.00
0005435282910	5569	Economy	33300.00
0005435282872	5569	Economy	33300.00
0005433848060	5569	Economy	33300.00
0005433848071	5569	Economy	33300.00
0005433848070	5569	Economy	33300.00
0005432081662	5569	Economy	33300.00
0005432081660	5569	Economy	33300.00
0005433848099	5569	Economy	33300.00
0005433848058	5569	Economy	33300.00
0005433848075	5569	Economy	33300.00
0005435282882	5569	Economy	33300.00
0005435282877	5569	Economy	33300.00
0005433848097	5569	Economy	33300.00
0005433815539	5569	Economy	33300.00
0005434173585	5569	Economy	33300.00
0005433815497	5569	Economy	33300.00
0005433848095	5569	Economy	33300.00
0005433848094	5569	Economy	33300.00
0005433815540	5569	Economy	33300.00
0005433848103	5569	Economy	33300.00
0005433848078	5569	Economy	33300.00
0005435282898	5569	Economy	33300.00
0005432081664	5569	Economy	33300.00
0005435282723	5569	Economy	33300.00
0005433848108	5569	Economy	33300.00
0005433848084	5569	Economy	33300.00
0005433815541	5569	Economy	33300.00
0005433848066	5569	Economy	33300.00
0005435282903	5569	Economy	33300.00
0005433815538	5569	Economy	33300.00
0005433848055	5569	Economy	33300.00
0005433848111	5569	Economy	33300.00
0005433848063	5569	Economy	33300.00
0005435282912	5569	Economy	33300.00
0005433848059	5569	Economy	33300.00
0005435282939	5569	Economy	33300.00
0005433848082	5569	Economy	33300.00
0005435282911	5569	Economy	33300.00
0005435282886	5569	Economy	33300.00
0005433848081	5569	Economy	33300.00
0005433848088	5569	Economy	33300.00
0005435282722	5569	Economy	33300.00
0005435282733	5569	Economy	33300.00
0005433848057	5569	Economy	33300.00
0005433847396	13870	Business	99800.00
0005433847481	13870	Business	99800.00
0005433847535	13870	Business	99800.00
0005433847465	13870	Business	99800.00
0005433847864	13870	Business	99800.00
0005433847779	13870	Business	99800.00
0005433847290	13870	Business	99800.00
0005433847385	13870	Business	99800.00
0005435283073	13870	Business	99800.00
0005433847711	13870	Business	99800.00
0005433847865	13870	Business	99800.00
0005435283091	13870	Business	99800.00
0005433847609	13870	Business	99800.00
0005433847487	13870	Business	99800.00
0005435283080	13870	Business	99800.00
0005435283074	13870	Business	99800.00
0005435283081	13870	Business	99800.00
0005433847397	13870	Business	99800.00
0005435283087	13870	Business	99800.00
0005433847548	13870	Business	99800.00
0005433847619	13870	Economy	33300.00
0005433847370	13870	Economy	33300.00
0005433847682	13870	Economy	33300.00
0005433847649	13870	Economy	33300.00
0005434173643	13870	Economy	33300.00
0005433847732	13870	Economy	33300.00
0005433847531	13870	Economy	33300.00
0005435283076	13870	Economy	33300.00
0005433847503	13870	Economy	33300.00
0005433847722	13870	Economy	33300.00
0005435283082	13870	Economy	33300.00
0005435283095	13870	Economy	36600.00
0005435283090	13870	Economy	36600.00
0005435283097	13870	Economy	36600.00
0005435283088	13870	Economy	33300.00
0005433847369	13870	Economy	36600.00
0005433847672	13870	Economy	33300.00
0005433847398	13870	Economy	33300.00
0005432003775	13870	Economy	33300.00
0005433847580	13870	Economy	33300.00
0005434173616	13870	Economy	33300.00
0005433847418	13870	Economy	33300.00
0005435283075	13870	Economy	33300.00
0005433847668	13870	Economy	33300.00
0005435283083	13870	Economy	33300.00
0005433847607	13870	Economy	33300.00
0005435283100	13870	Economy	33300.00
0005432003776	13870	Economy	33300.00
0005434173644	13870	Economy	33300.00
0005433847720	13870	Economy	33300.00
0005435283089	13870	Economy	33300.00
0005433847417	13870	Economy	33300.00
0005433847464	13870	Economy	33300.00
0005435283092	13870	Economy	33300.00
0005433815448	13870	Economy	33300.00
0005433847536	13870	Economy	33300.00
0005435283077	13870	Economy	33300.00
0005433847475	13870	Economy	33300.00
0005433847659	13870	Economy	33300.00
0005433847640	13870	Economy	33300.00
0005433847610	13870	Economy	33300.00
0005433847721	13870	Economy	33300.00
0005435283079	13870	Economy	33300.00
0005433847703	13870	Economy	33300.00
0005433847219	13870	Economy	33300.00
0005433847314	13870	Economy	33300.00
0005433847683	13870	Economy	33300.00
0005433815451	13870	Economy	33300.00
0005434173613	13870	Economy	33300.00
0005433847766	13870	Economy	33300.00
0005434173615	13870	Economy	33300.00
0005433847813	13870	Economy	33300.00
0005435283078	13870	Economy	33300.00
0005433847690	13870	Economy	33300.00
0005435283084	13870	Economy	33300.00
0005433847482	13870	Economy	33300.00
0005433847658	13870	Economy	33300.00
0005433847489	13870	Economy	33300.00
0005434173612	13870	Economy	33300.00
0005434173642	13870	Economy	33300.00
0005432003774	13870	Economy	33300.00
0005435283086	13870	Economy	33300.00
0005433847714	13870	Economy	33300.00
0005433847416	13870	Economy	33300.00
0005435283094	13870	Economy	33300.00
0005433847731	13870	Economy	33300.00
0005435283099	13870	Economy	33300.00
0005433847669	13870	Economy	33300.00
0005433847657	13870	Economy	33300.00
0005433847453	13870	Economy	33300.00
0005433847673	13870	Economy	33300.00
0005435283093	13870	Economy	33300.00
0005433847680	13870	Economy	33300.00
0005433847742	13870	Economy	33300.00
0005435283098	13870	Economy	33300.00
0005435283096	13870	Economy	33300.00
0005433847383	13870	Economy	33300.00
0005433847488	13870	Economy	33300.00
0005435283085	13870	Economy	33300.00
0005434173614	13870	Economy	33300.00
0005433847705	13870	Economy	33300.00
0005435332493	7831	Economy	16600.00
0005435332522	7831	Economy	16600.00
0005434621080	7831	Economy	16600.00
0005434621064	7831	Economy	16600.00
0005435332528	7831	Economy	15100.00
0005434621073	7831	Economy	15100.00
0005434621069	7831	Economy	15100.00
0005434621084	7831	Economy	15100.00
0005434621068	7831	Economy	15100.00
0005434621065	7831	Economy	15100.00
0005435332523	7831	Economy	15100.00
0005435332505	7831	Economy	15100.00
0005434621072	7831	Economy	15100.00
0005435332529	7831	Economy	15100.00
0005435332462	7831	Economy	15100.00
0005434621078	7831	Economy	15100.00
0005435332494	7831	Economy	15100.00
0005432112569	7831	Economy	15100.00
0005435332495	7831	Economy	15100.00
0005435332504	7831	Economy	15100.00
0005435332488	7831	Economy	15100.00
0005435332526	7831	Economy	15100.00
0005434621074	7831	Economy	15100.00
0005434621071	7831	Economy	15100.00
0005435332530	7831	Economy	15100.00
0005434621076	7831	Economy	15100.00
0005435332490	7831	Economy	15100.00
0005434621063	7831	Economy	15100.00
0005435332492	7831	Economy	15100.00
0005435332469	7831	Economy	15100.00
0005434621085	7831	Economy	15100.00
0005435332489	7831	Economy	15100.00
0005434621077	7831	Economy	15100.00
0005434621082	7831	Economy	15100.00
0005435332491	7831	Economy	15100.00
0005434621075	7831	Economy	15100.00
0005432112568	7831	Economy	15100.00
0005434621083	7831	Economy	15100.00
0005434621067	7831	Economy	15100.00
0005435332468	7831	Economy	15100.00
0005434621079	7831	Economy	15100.00
0005435332463	7831	Economy	15100.00
0005434621081	7831	Economy	15100.00
0005434621066	7831	Economy	15100.00
0005434621070	7831	Economy	15100.00
0005435332580	32945	Economy	16600.00
0005435332578	32945	Economy	16600.00
0005434620921	32945	Economy	15100.00
0005434620923	32945	Economy	15100.00
0005435332583	32945	Economy	15100.00
0005434620936	32945	Economy	15100.00
0005434620886	32945	Economy	15100.00
0005435332582	32945	Economy	15100.00
0005435332573	32945	Economy	15100.00
0005434620875	32945	Economy	15100.00
0005435332581	32945	Economy	15100.00
0005434620919	32945	Economy	15100.00
0005434620794	32945	Economy	15100.00
0005434620885	32945	Economy	15100.00
0005434620991	32945	Economy	15100.00
0005435332579	32945	Economy	15100.00
0005435332584	32945	Economy	15100.00
0005434620799	32945	Economy	15100.00
0005434620922	32945	Economy	15100.00
0005434620795	32945	Economy	15100.00
0005435332576	32945	Economy	15100.00
0005435332572	32945	Economy	15100.00
0005435332574	32945	Economy	15100.00
0005435332577	32945	Economy	15100.00
0005435332575	32945	Economy	15100.00
0005434620944	32945	Economy	15100.00
0005434994248	4281	Business	38000.00
0005435786157	4281	Business	38000.00
0005435937440	4281	Business	38000.00
0005435786159	4281	Business	38000.00
0005435786161	4281	Business	38000.00
0005435786169	4281	Business	38000.00
0005435786171	4281	Economy	12700.00
0005435786162	4281	Economy	12700.00
0005435786147	4281	Economy	12700.00
0005435786148	4281	Economy	13900.00
0005435937468	4281	Economy	13900.00
0005435786167	4281	Economy	13900.00
0005435786163	4281	Economy	12700.00
0005435918728	4281	Economy	12700.00
0005435786156	4281	Economy	12700.00
0005435786153	4281	Economy	12700.00
0005435786164	4281	Economy	12700.00
0005435786166	4281	Economy	12700.00
0005435786172	4281	Economy	12700.00
0005435786149	4281	Economy	12700.00
0005432190718	4281	Economy	12700.00
0005435937451	4281	Economy	12700.00
0005434994246	4281	Economy	12700.00
0005435786155	4281	Economy	12700.00
0005435786151	4281	Economy	12700.00
0005435786174	4281	Economy	12700.00
0005435937467	4281	Economy	12700.00
0005435786170	4281	Economy	12700.00
0005432190719	4281	Economy	12700.00
0005432190721	4281	Economy	12700.00
0005435786173	4281	Economy	12700.00
0005434994255	4281	Economy	12700.00
0005435786168	4281	Economy	12700.00
0005435786180	4281	Economy	12700.00
0005435786152	4281	Economy	12700.00
0005435786181	4281	Economy	12700.00
0005435937449	4281	Economy	12700.00
0005435786165	4281	Economy	12700.00
0005435786177	4281	Economy	12700.00
0005435787403	4281	Economy	12700.00
0005435786176	4281	Economy	12700.00
0005434994254	4281	Economy	12700.00
0005435786179	4281	Economy	12700.00
0005435786150	4281	Economy	12700.00
0005435937443	4281	Economy	12700.00
0005435937450	4281	Economy	12700.00
0005435786158	4281	Economy	12700.00
0005434994251	4281	Economy	12700.00
0005434994250	4281	Economy	12700.00
0005434994247	4281	Economy	12700.00
0005435786154	4281	Economy	12700.00
0005435786175	4281	Economy	12700.00
0005435786160	4281	Economy	12700.00
0005435786178	4281	Economy	12700.00
0005432190720	4281	Economy	12700.00
0005434994252	4281	Economy	12700.00
0005434994249	4281	Economy	12700.00
0005434994253	4281	Economy	12700.00
0005435785812	27297	Business	38000.00
0005435785804	27297	Business	38000.00
0005435937498	27297	Business	38000.00
0005432195742	27297	Business	38000.00
0005435785884	27297	Business	38000.00
0005435918766	27297	Business	38000.00
0005435785815	27297	Business	38000.00
0005435785694	27297	Business	38000.00
0005435785816	27297	Business	38000.00
0005435785656	27297	Business	38000.00
0005435785673	27297	Economy	12700.00
0005435785871	27297	Economy	12700.00
0005435785853	27297	Economy	12700.00
0005434994154	27297	Economy	12700.00
0005435785835	27297	Economy	12700.00
0005435918769	27297	Economy	12700.00
0005435918768	27297	Economy	12700.00
0005435785725	27297	Economy	13900.00
0005435785858	27297	Economy	13900.00
0005435785879	27297	Economy	13900.00
0005434994141	27297	Economy	12700.00
0005435785852	27297	Economy	12700.00
0005434994158	27297	Economy	12700.00
0005435785785	27297	Economy	12700.00
0005435785743	27297	Economy	12700.00
0005435785824	27297	Economy	12700.00
0005435787378	27297	Economy	12700.00
0005435937499	27297	Economy	12700.00
0005435785859	27297	Economy	12700.00
0005435785848	27297	Economy	12700.00
0005435785825	27297	Economy	12700.00
0005435785878	27297	Economy	12700.00
0005435785657	27297	Economy	12700.00
0005435785831	27297	Economy	12700.00
0005435785827	27297	Economy	12700.00
0005435785883	27297	Economy	12700.00
0005435785784	27297	Economy	12700.00
0005435918765	27297	Economy	12700.00
0005435786000	27297	Economy	12700.00
0005435785809	27297	Economy	12700.00
0005435785849	27297	Economy	12700.00
0005435785672	27297	Economy	12700.00
0005435785797	27297	Economy	12700.00
0005435785845	27297	Economy	12700.00
0005435918767	27297	Economy	12700.00
0005435785796	27297	Economy	12700.00
0005435785897	27297	Economy	12700.00
0005435787379	27297	Economy	12700.00
0005434994179	27297	Economy	12700.00
0005434994178	27297	Economy	12700.00
0005434994151	27297	Economy	12700.00
0005432195741	27297	Economy	12700.00
0005435785677	27297	Economy	12700.00
0005434994118	27297	Economy	12700.00
0005435787377	27297	Economy	12700.00
0005435785659	27297	Economy	12700.00
0005435785830	27297	Economy	12700.00
0005435785896	27297	Economy	12700.00
0005435785817	27297	Economy	12700.00
0005435785658	27297	Economy	12700.00
0005435785747	27297	Economy	12700.00
0005435785780	27297	Economy	12700.00
0005432461055	4697	Business	40900.00
0005432569074	4697	Business	40900.00
0005434082453	4697	Business	40900.00
0005432569031	4697	Business	40900.00
0005432569049	4697	Business	40900.00
0005432461091	4697	Business	40900.00
0005434082456	4697	Business	40900.00
0005432461056	4697	Business	40900.00
0005432569065	4697	Business	40900.00
0005432569037	4697	Business	40900.00
0005432461090	4697	Business	40900.00
0005434082445	4697	Business	40900.00
0005434082470	4697	Business	40900.00
0005432569050	4697	Business	40900.00
0005432461042	4697	Business	40900.00
0005434082451	4697	Business	40900.00
0005434082464	4697	Business	40900.00
0005432569064	4697	Business	40900.00
0005432186955	4697	Business	40900.00
0005432461045	4697	Business	40900.00
0005432569072	4697	Business	40900.00
0005432569084	4697	Business	40900.00
0005432569036	4697	Business	40900.00
0005432461081	4697	Business	40900.00
0005432461070	4697	Business	40900.00
0005434082463	4697	Economy	15000.00
0005432569077	4697	Economy	15000.00
0005432569034	4697	Economy	15000.00
0005434082460	4697	Economy	13600.00
0005432461062	4697	Economy	13600.00
0005432461052	4697	Economy	13600.00
0005432461092	4697	Economy	13600.00
0005432571408	4697	Economy	13600.00
0005432461061	4697	Economy	13600.00
0005434082461	4697	Economy	13600.00
0005434082455	4697	Economy	13600.00
0005432461067	4697	Economy	13600.00
0005433726158	4697	Economy	13600.00
0005432461060	4697	Economy	13600.00
0005432569075	4697	Economy	13600.00
0005434082449	4697	Economy	13600.00
0005432461087	4697	Economy	13600.00
0005434082448	4697	Economy	13600.00
0005432571410	4697	Economy	13600.00
0005434082462	4697	Economy	13600.00
0005432569079	4697	Economy	13600.00
0005432569085	4697	Economy	13600.00
0005432569062	4697	Economy	13600.00
0005432461074	4697	Economy	13600.00
0005432569030	4697	Economy	13600.00
0005432569047	4697	Economy	13600.00
0005432461064	4697	Economy	13600.00
0005432569039	4697	Economy	13600.00
0005432461083	4697	Economy	13600.00
0005432569069	4697	Economy	13600.00
0005432569058	4697	Economy	13600.00
0005432569046	4697	Economy	13600.00
0005432569078	4697	Economy	13600.00
0005432569055	4697	Economy	13600.00
0005434082471	4697	Economy	13600.00
0005432170543	4697	Economy	13600.00
0005432461050	4697	Economy	13600.00
0005432569059	4697	Economy	13600.00
0005434082446	4697	Economy	13600.00
0005432569053	4697	Economy	13600.00
0005432461065	4697	Economy	13600.00
0005432461078	4697	Economy	13600.00
0005432170545	4697	Economy	13600.00
0005434082472	4697	Economy	13600.00
0005432461086	4697	Economy	13600.00
0005432569033	4697	Economy	13600.00
0005432569040	4697	Economy	13600.00
0005432461044	4697	Economy	13600.00
0005432569029	4697	Economy	13600.00
0005432170544	4697	Economy	13600.00
0005432569044	4697	Economy	13600.00
0005432461051	4697	Economy	13600.00
0005432569051	4697	Economy	13600.00
0005432461068	4697	Economy	13600.00
0005432569070	4697	Economy	13600.00
0005432569043	4697	Economy	13600.00
0005432461080	4697	Economy	13600.00
0005434082443	4697	Economy	13600.00
0005432186957	4697	Economy	13600.00
0005434082452	4697	Economy	13600.00
0005432461084	4697	Economy	13600.00
0005432461063	4697	Economy	13600.00
0005432569086	4697	Economy	13600.00
0005432461041	4697	Economy	13600.00
0005432569048	4697	Economy	13600.00
0005432569081	4697	Economy	13600.00
0005432569076	4697	Economy	13600.00
0005434082450	4697	Economy	13600.00
0005432461053	4697	Economy	13600.00
0005432569042	4697	Economy	13600.00
0005432461082	4697	Economy	13600.00
0005433452788	4697	Economy	13600.00
0005434082454	4697	Economy	13600.00
0005433451667	4697	Economy	13600.00
0005432170547	4697	Economy	13600.00
0005432461076	4697	Economy	15000.00
0005432569052	4697	Economy	13600.00
0005432461049	4697	Economy	15000.00
0005432571409	4697	Economy	15000.00
0005432569067	4697	Economy	13600.00
0005432569045	4697	Economy	13600.00
0005432569035	4697	Economy	13600.00
0005433451668	4697	Economy	13600.00
0005432186954	4697	Economy	13600.00
0005432569028	4697	Economy	13600.00
0005432461059	4697	Economy	13600.00
0005432569088	4697	Economy	13600.00
0005432461088	4697	Economy	13600.00
0005432461069	4697	Economy	13600.00
0005432571411	4697	Economy	13600.00
0005432569041	4697	Economy	13600.00
0005432569057	4697	Economy	13600.00
0005434082466	4697	Economy	13600.00
0005432569082	4697	Economy	13600.00
0005432186956	4697	Economy	13600.00
0005432569066	4697	Economy	13600.00
0005432461072	4697	Economy	13600.00
0005432569063	4697	Economy	13600.00
0005432461047	4697	Economy	13600.00
0005432461073	4697	Economy	13600.00
0005432461071	4697	Economy	13600.00
0005432461079	4697	Economy	13600.00
0005434082457	4697	Economy	13600.00
0005433726159	4697	Economy	13600.00
0005432569032	4697	Economy	13600.00
0005432461077	4697	Economy	13600.00
0005432569080	4697	Economy	13600.00
0005434082447	4697	Economy	13600.00
0005432569071	4697	Economy	13600.00
0005432461048	4697	Economy	13600.00
0005434082475	4697	Economy	13600.00
0005434082474	4697	Economy	13600.00
0005432569060	4697	Economy	13600.00
0005432461066	4697	Economy	13600.00
0005432569087	4697	Economy	13600.00
0005432569061	4697	Economy	13600.00
0005433726160	4697	Economy	13600.00
0005432461057	4697	Economy	13600.00
0005432461085	4697	Economy	13600.00
0005434082458	4697	Economy	13600.00
0005434082442	4697	Economy	13600.00
0005433726157	4697	Economy	13600.00
0005432461089	4697	Economy	13600.00
0005434082467	4697	Economy	13600.00
0005433451666	4697	Economy	13600.00
0005432461043	4697	Economy	13600.00
0005432569068	4697	Economy	13600.00
0005432569073	4697	Economy	13600.00
0005432170542	4697	Economy	13600.00
0005434082444	4697	Economy	13600.00
0005432461054	4697	Economy	13600.00
0005432569054	4697	Economy	13600.00
0005434082459	4697	Economy	13600.00
0005434082465	4697	Economy	13600.00
0005434082468	4697	Economy	13600.00
0005433452789	4697	Economy	13600.00
0005434082473	4697	Economy	13600.00
0005432170546	4697	Economy	13600.00
0005432170548	4697	Economy	13600.00
0005432461058	4697	Economy	13600.00
0005434082469	4697	Economy	13600.00
0005434082441	4697	Economy	13600.00
0005432569056	4697	Economy	13600.00
0005432569038	4697	Economy	13600.00
0005432461075	4697	Economy	13600.00
0005432461046	4697	Economy	13600.00
0005432569083	4697	Economy	13600.00
0005432460692	30540	Business	40900.00
0005434082354	30540	Business	40900.00
0005432568651	30540	Business	40900.00
0005434082277	30540	Business	40900.00
0005432568498	30540	Business	40900.00
0005434082274	30540	Business	40900.00
0005435840411	30540	Business	40900.00
0005434082223	30540	Business	40900.00
0005435840416	30540	Business	40900.00
0005434082202	30540	Business	40900.00
0005432568344	30540	Business	40900.00
0005432460652	30540	Business	40900.00
0005432568570	30540	Business	40900.00
0005432568680	30540	Business	40900.00
0005434082204	30540	Business	40900.00
0005432568469	30540	Business	40900.00
0005435840419	30540	Business	40900.00
0005432568746	30540	Business	40900.00
0005432568472	30540	Business	40900.00
0005435840401	30540	Business	40900.00
0005432460538	30540	Business	40900.00
0005432460782	30540	Business	40900.00
0005435840417	30540	Business	40900.00
0005432568410	30540	Economy	15000.00
0005432568774	30540	Economy	15000.00
0005432568834	30540	Economy	15000.00
0005434082225	30540	Economy	15000.00
0005432460753	30540	Economy	13600.00
0005432460668	30540	Economy	13600.00
0005432460822	30540	Economy	13600.00
0005432460878	30540	Economy	13600.00
0005432568587	30540	Economy	13600.00
0005434082245	30540	Economy	13600.00
0005432161205	30540	Economy	13600.00
0005432568962	30540	Economy	13600.00
0005432568450	30540	Economy	13600.00
0005432568446	30540	Economy	13600.00
0005432568752	30540	Economy	13600.00
0005432568357	30540	Economy	13600.00
0005432568559	30540	Economy	13600.00
0005432213693	30540	Economy	13600.00
0005434082190	30540	Economy	13600.00
0005432568877	30540	Economy	13600.00
0005432460472	30540	Economy	13600.00
0005432460614	30540	Economy	13600.00
0005434082147	30540	Economy	13600.00
0005432460605	30540	Economy	13600.00
0005432460864	30540	Economy	13600.00
0005432460812	30540	Economy	13600.00
0005432460618	30540	Economy	13600.00
0005432568577	30540	Economy	13600.00
0005432568605	30540	Economy	13600.00
0005432568659	30540	Economy	13600.00
0005434082224	30540	Economy	13600.00
0005432568285	30540	Economy	13600.00
0005432568692	30540	Economy	13600.00
0005432460755	30540	Economy	13600.00
0005435840415	30540	Economy	13600.00
0005434082240	30540	Economy	13600.00
0005432460684	30540	Economy	13600.00
0005432460721	30540	Economy	13600.00
0005432568447	30540	Economy	13600.00
0005435840408	30540	Economy	13600.00
0005434082222	30540	Economy	13600.00
0005432460713	30540	Economy	13600.00
0005432568345	30540	Economy	13600.00
0005434082271	30540	Economy	13600.00
0005432460821	30540	Economy	13600.00
0005434082244	30540	Economy	13600.00
0005432460568	30540	Economy	13600.00
0005432568517	30540	Economy	13600.00
0005433454906	30540	Economy	13600.00
0005435840424	30540	Economy	13600.00
0005432568691	30540	Economy	13600.00
0005434082174	30540	Economy	13600.00
0005432568346	30540	Economy	13600.00
0005435840412	30540	Economy	13600.00
0005432460756	30540	Economy	13600.00
0005432460499	30540	Economy	13600.00
0005432460703	30540	Economy	13600.00
0005435840421	30540	Economy	13600.00
0005432568694	30540	Economy	13600.00
0005432568660	30540	Economy	13600.00
0005435840409	30540	Economy	13600.00
0005432568506	30540	Economy	13600.00
0005434082284	30540	Economy	13600.00
0005432460567	30540	Economy	13600.00
0005432568468	30540	Economy	13600.00
0005435840413	30540	Economy	13600.00
0005434082173	30540	Economy	13600.00
0005434082232	30540	Economy	13600.00
0005432460524	30540	Economy	13600.00
0005432568604	30540	Economy	13600.00
0005432460781	30540	Economy	13600.00
0005433454908	30540	Economy	13600.00
0005432213694	30540	Economy	13600.00
0005434082281	30540	Economy	13600.00
0005435840407	30540	Economy	13600.00
0005432460811	30540	Economy	13600.00
0005432568583	30540	Economy	13600.00
0005432460498	30540	Economy	13600.00
0005432568602	30540	Economy	13600.00
0005432460757	30540	Economy	15000.00
0005435840418	30540	Economy	15000.00
0005435840403	30540	Economy	13600.00
0005432568836	30540	Economy	13600.00
0005435840410	30540	Economy	15000.00
0005432213692	30540	Economy	15000.00
0005434082275	30540	Economy	13600.00
0005432460604	30540	Economy	13600.00
0005432568653	30540	Economy	13600.00
0005433452773	30540	Economy	13600.00
0005435840423	30540	Economy	13600.00
0005435840426	30540	Economy	13600.00
0005432460847	30540	Economy	13600.00
0005432568679	30540	Economy	13600.00
0005432568578	30540	Economy	13600.00
0005432460556	30540	Economy	13600.00
0005432568775	30540	Economy	13600.00
0005432460754	30540	Economy	13600.00
0005434082217	30540	Economy	13600.00
0005435840402	30540	Economy	13600.00
0005432460744	30540	Economy	13600.00
0005434082144	30540	Economy	13600.00
0005432568695	30540	Economy	13600.00
0005432568612	30540	Economy	13600.00
0005432460680	30540	Economy	13600.00
0005432568284	30540	Economy	13600.00
0005434082282	30540	Economy	13600.00
0005435840427	30540	Economy	13600.00
0005432568499	30540	Economy	13600.00
0005432460743	30540	Economy	13600.00
0005432460660	30540	Economy	13600.00
0005432568467	30540	Economy	13600.00
0005432213695	30540	Economy	13600.00
0005432568768	30540	Economy	13600.00
0005432460702	30540	Economy	13600.00
0005432460525	30540	Economy	13600.00
0005434082188	30540	Economy	13600.00
0005432568442	30540	Economy	13600.00
0005432568477	30540	Economy	13600.00
0005432568637	30540	Economy	13600.00
0005432568530	30540	Economy	13600.00
0005435840404	30540	Economy	13600.00
0005432460694	30540	Economy	13600.00
0005432460606	30540	Economy	13600.00
0005432460689	30540	Economy	13600.00
0005432460697	30540	Economy	13600.00
0005432568754	30540	Economy	13600.00
0005432460879	30540	Economy	13600.00
0005434082162	30540	Economy	13600.00
0005432568492	30540	Economy	13600.00
0005432571388	30540	Economy	13600.00
0005435840420	30540	Economy	13600.00
0005435840405	30540	Economy	13600.00
0005432568755	30540	Economy	13600.00
0005432568682	30540	Economy	13600.00
0005435840422	30540	Economy	13600.00
0005432568683	30540	Economy	13600.00
0005435840425	30540	Economy	13600.00
0005433454901	30540	Economy	13600.00
0005432568613	30540	Economy	13600.00
0005432460603	30540	Economy	13600.00
0005432568690	30540	Economy	13600.00
0005432460473	30540	Economy	13600.00
0005432568636	30540	Economy	13600.00
0005432460500	30540	Economy	13600.00
0005432460733	30540	Economy	13600.00
0005435840414	30540	Economy	13600.00
0005432460814	30540	Economy	13600.00
0005435840406	30540	Economy	13600.00
0005434082278	30540	Economy	13600.00
0005432568718	30540	Economy	13600.00
0005435720851	13653	Economy	9900.00
0005435722111	13653	Economy	9900.00
0005435720852	13653	Economy	9900.00
0005435720145	21215	Economy	9900.00
0005435722092	21215	Economy	9900.00
0005435720148	21215	Economy	9900.00
0005432295941	22776	Economy	8800.00
0005432295940	22776	Economy	8800.00
0005432295942	22776	Economy	8800.00
0005433345454	11101	Business	23600.00
0005433345495	11101	Business	23600.00
0005433345514	11101	Business	23600.00
0005435097436	11101	Business	23600.00
0005433345524	11101	Business	23600.00
0005433345521	11101	Business	23600.00
0005433345474	11101	Business	23600.00
0005433345456	11101	Business	23600.00
0005433345467	11101	Business	23600.00
0005433345535	11101	Business	23600.00
0005433345453	11101	Business	23600.00
0005433345510	11101	Business	23600.00
0005433345489	11101	Economy	7900.00
0005435508533	11101	Economy	7900.00
0005433345523	11101	Economy	7900.00
0005435380354	11101	Economy	7900.00
0005433345550	11101	Economy	7900.00
0005435097427	11101	Economy	7900.00
0005435097428	11101	Economy	7900.00
0005433345482	11101	Economy	7900.00
0005433345538	11101	Economy	7900.00
0005433345472	11101	Economy	7900.00
0005433345478	11101	Economy	7900.00
0005433345501	11101	Economy	7900.00
0005433345549	11101	Economy	7900.00
0005433345516	11101	Economy	7900.00
0005433345537	11101	Economy	7900.00
0005433345513	11101	Economy	7900.00
0005435508512	11101	Economy	7900.00
0005435380377	11101	Economy	7900.00
0005433345512	11101	Economy	7900.00
0005433345483	11101	Economy	7900.00
0005435097426	11101	Economy	7900.00
0005433345546	11101	Economy	7900.00
0005433345458	11101	Economy	7900.00
0005433345471	11101	Economy	7900.00
0005433345536	11101	Economy	7900.00
0005433345466	11101	Economy	7900.00
0005433345519	11101	Economy	7900.00
0005435508573	11101	Economy	7900.00
0005433345517	11101	Economy	7900.00
0005435508568	11101	Economy	7900.00
0005433345511	11101	Economy	7900.00
0005433345480	11101	Economy	7900.00
0005435508574	11101	Economy	7900.00
0005435508472	11101	Economy	7900.00
0005435097435	11101	Economy	7900.00
0005433345527	11101	Economy	7900.00
0005433345545	11101	Economy	7900.00
0005433345475	11101	Economy	7900.00
0005433345532	11101	Economy	7900.00
0005433345468	11101	Economy	8600.00
0005433345497	11101	Economy	7900.00
0005433345477	11101	Economy	8600.00
0005433345452	11101	Economy	8600.00
0005433345488	11101	Economy	8600.00
0005433345506	11101	Economy	8600.00
0005433345504	11101	Economy	8600.00
0005433345462	11101	Economy	7900.00
0005433345485	11101	Economy	7900.00
0005435508534	11101	Economy	7900.00
0005435508570	11101	Economy	7900.00
0005435508571	11101	Economy	7900.00
0005433345457	11101	Economy	7900.00
0005435508552	11101	Economy	7900.00
0005433345503	11101	Economy	7900.00
0005433345486	11101	Economy	7900.00
0005433345531	11101	Economy	7900.00
0005435508569	11101	Economy	7900.00
0005433345533	11101	Economy	7900.00
0005433345499	11101	Economy	7900.00
0005433345487	11101	Economy	7900.00
0005433345470	11101	Economy	7900.00
0005435097433	11101	Economy	7900.00
0005435097432	11101	Economy	7900.00
0005433345493	11101	Economy	7900.00
0005433345539	11101	Economy	7900.00
0005435508524	11101	Economy	7900.00
0005435097430	11101	Economy	7900.00
0005433345534	11101	Economy	7900.00
0005433345548	11101	Economy	7900.00
0005433345528	11101	Economy	7900.00
0005435508605	11101	Economy	7900.00
0005433345505	11101	Economy	7900.00
0005435508532	11101	Economy	7900.00
0005433345525	11101	Economy	7900.00
0005433345463	11101	Economy	7900.00
0005433345522	11101	Economy	7900.00
0005433345461	11101	Economy	7900.00
0005433345542	11101	Economy	7900.00
0005435508537	11101	Economy	7900.00
0005435097431	11101	Economy	7900.00
0005435508572	11101	Economy	7900.00
0005435097429	11101	Economy	7900.00
0005433345469	11101	Economy	7900.00
0005433345515	11101	Economy	7900.00
0005435097434	11101	Economy	7900.00
0005433345496	11101	Economy	7900.00
0005433345492	11101	Economy	7900.00
0005433345547	11101	Economy	7900.00
0005433345520	11101	Economy	7900.00
0005433345476	11101	Economy	7900.00
0005433345491	11101	Economy	7900.00
0005433345481	11101	Economy	7900.00
0005433345502	11101	Economy	7900.00
0005433345526	11101	Economy	7900.00
0005433345460	11101	Economy	7900.00
0005433345498	11101	Economy	7900.00
0005435380378	11101	Economy	7900.00
0005433345530	11101	Economy	7900.00
0005433345544	11101	Economy	7900.00
0005433345540	11101	Economy	7900.00
0005433345507	11101	Economy	7900.00
0005433345455	11101	Economy	7900.00
0005433345508	11101	Economy	7900.00
0005433345509	11101	Economy	7900.00
0005433345490	11101	Economy	7900.00
0005433345543	11101	Economy	7900.00
0005433345465	11101	Economy	7900.00
0005433345473	11101	Economy	7900.00
0005433345494	11101	Economy	7900.00
0005433345529	11101	Economy	7900.00
0005433345500	11101	Economy	7900.00
0005433345479	11101	Economy	7900.00
0005433345464	11101	Economy	7900.00
0005433345459	11101	Economy	7900.00
0005433345541	11101	Economy	7900.00
0005433345484	11101	Economy	7900.00
0005433345518	11101	Economy	7900.00
0005435508525	11101	Economy	7900.00
0005433344757	17093	Business	23600.00
0005433344955	17093	Business	23600.00
0005433344365	17093	Business	23600.00
0005433344349	17093	Business	23600.00
0005433344170	17093	Business	23600.00
0005433344486	17093	Business	23600.00
0005433344499	17093	Business	23600.00
0005433344336	17093	Business	23600.00
0005433344555	17093	Business	23600.00
0005433344274	17093	Business	23600.00
0005433344786	17093	Business	23600.00
0005433344700	17093	Business	23600.00
0005433344766	17093	Economy	7900.00
0005433344478	17093	Economy	7900.00
0005433345057	17093	Economy	7900.00
0005433344978	17093	Economy	7900.00
0005435097364	17093	Economy	7900.00
0005433344163	17093	Economy	7900.00
0005433344344	17093	Economy	7900.00
0005435097369	17093	Economy	7900.00
0005433344604	17093	Economy	7900.00
0005435097350	17093	Economy	7900.00
0005433344397	17093	Economy	7900.00
0005433344332	17093	Economy	7900.00
0005433345096	17093	Economy	7900.00
0005433344446	17093	Economy	7900.00
0005433344622	17093	Economy	7900.00
0005433344726	17093	Economy	7900.00
0005433344387	17093	Economy	7900.00
0005433344334	17093	Economy	7900.00
0005435380415	17093	Economy	7900.00
0005433344781	17093	Economy	7900.00
0005433344350	17093	Economy	7900.00
0005433344006	17093	Economy	7900.00
0005435097283	17093	Economy	7900.00
0005433344386	17093	Economy	7900.00
0005432293264	17093	Economy	7900.00
0005433344265	17093	Economy	7900.00
0005433344608	17093	Economy	7900.00
0005433344269	17093	Economy	7900.00
0005433344162	17093	Economy	7900.00
0005433344253	17093	Economy	7900.00
0005433344184	17093	Economy	7900.00
0005433344339	17093	Economy	7900.00
0005433344686	17093	Economy	7900.00
0005433344565	17093	Economy	7900.00
0005433344799	17093	Economy	7900.00
0005433344901	17093	Economy	7900.00
0005433344329	17093	Economy	7900.00
0005433344711	17093	Economy	7900.00
0005433344853	17093	Economy	7900.00
0005433344470	17093	Economy	7900.00
0005433344751	17093	Economy	8600.00
0005433344790	17093	Economy	8600.00
0005433344858	17093	Economy	8600.00
0005433344244	17093	Economy	8600.00
0005433344005	17093	Economy	8600.00
0005433344136	17093	Economy	7900.00
0005433344909	17093	Economy	7900.00
0005433344765	17093	Economy	7900.00
0005433344424	17093	Economy	7900.00
0005433344132	17093	Economy	7900.00
0005433344703	17093	Economy	7900.00
0005433344558	17093	Economy	7900.00
0005433344404	17093	Economy	7900.00
0005433344639	17093	Economy	7900.00
0005433344845	17093	Economy	7900.00
0005433344361	17093	Economy	7900.00
0005433345097	17093	Economy	7900.00
0005435380416	17093	Economy	7900.00
0005433344366	17093	Economy	7900.00
0005433344614	17093	Economy	7900.00
0005433344375	17093	Economy	7900.00
0005433344230	17093	Economy	7900.00
0005433344460	17093	Economy	7900.00
0005435097370	17093	Economy	7900.00
0005433344475	17093	Economy	7900.00
0005432293265	17093	Economy	7900.00
0005433344615	17093	Economy	7900.00
0005433344573	17093	Economy	7900.00
0005433344699	17093	Economy	7900.00
0005433344479	17093	Economy	7900.00
0005433344093	17093	Economy	7900.00
0005433344897	17093	Economy	7900.00
0005433344325	17093	Economy	7900.00
0005433344469	17093	Economy	7900.00
0005433344800	17093	Economy	7900.00
0005433344661	17093	Economy	7900.00
0005433344695	17093	Economy	7900.00
0005433344777	17093	Economy	7900.00
0005433344689	17093	Economy	7900.00
0005433344968	17093	Economy	7900.00
0005433344735	17093	Economy	7900.00
0005433344481	17093	Economy	7900.00
0005433344278	17093	Economy	7900.00
0005433344609	17093	Economy	7900.00
0005433344652	17093	Economy	7900.00
0005435097359	17093	Economy	7900.00
0005435097349	17093	Economy	7900.00
0005433344900	17093	Economy	7900.00
0005433344245	17093	Economy	7900.00
0005435097301	17093	Economy	7900.00
0005435097284	17093	Economy	7900.00
0005433344450	17093	Economy	7900.00
0005433344701	17093	Economy	7900.00
0005433344425	17093	Economy	7900.00
0005433344326	17093	Economy	7900.00
0005433344333	17093	Economy	7900.00
0005433344605	17093	Economy	7900.00
0005433344621	17093	Economy	7900.00
0005433344376	17093	Economy	7900.00
0005433344568	17093	Economy	7900.00
0005433344396	17093	Economy	7900.00
0005433344477	17093	Economy	7900.00
0005433344846	17093	Economy	7900.00
0005433344947	17093	Economy	7900.00
0005433344393	17093	Economy	7900.00
0005433344736	17093	Economy	7900.00
0005433344317	17093	Economy	7900.00
0005433344780	17093	Economy	7900.00
0005433344231	17093	Economy	7900.00
0005433344277	17093	Economy	7900.00
0005433344135	17093	Economy	7900.00
0005433344480	17093	Economy	7900.00
0005433344896	17093	Economy	7900.00
0005433344787	17093	Economy	7900.00
0005433344337	17093	Economy	7900.00
0005433344500	17093	Economy	7900.00
0005433344092	17093	Economy	7900.00
0005432920245	9093	Business	26600.00
0005433507603	9093	Business	26600.00
0005433481352	9093	Business	26600.00
0005432920132	9093	Business	26600.00
0005432920292	9093	Business	26600.00
0005433477068	9093	Business	26600.00
0005433481351	9093	Business	26600.00
0005433477080	9093	Business	26600.00
0005433477070	9093	Business	26600.00
0005432920116	9093	Business	26600.00
0005433477067	9093	Economy	8900.00
0005433477088	9093	Economy	8900.00
0005433477055	9093	Economy	8900.00
0005433507604	9093	Economy	8900.00
0005433507614	9093	Economy	8900.00
0005433477083	9093	Economy	8900.00
0005432920168	9093	Economy	8900.00
0005433477084	9093	Economy	8900.00
0005433481350	9093	Economy	8900.00
0005433477063	9093	Economy	8900.00
0005433477082	9093	Economy	9800.00
0005433477087	9093	Economy	9800.00
0005433477079	9093	Economy	9800.00
0005433507615	9093	Economy	9800.00
0005433477060	9093	Economy	9800.00
0005433477065	9093	Economy	8900.00
0005432920146	9093	Economy	8900.00
0005433507606	9093	Economy	8900.00
0005433507620	9093	Economy	8900.00
0005433507612	9093	Economy	8900.00
0005433507617	9093	Economy	8900.00
0005432920076	9093	Economy	8900.00
0005433507618	9093	Economy	8900.00
0005433481347	9093	Economy	8900.00
0005433477077	9093	Economy	8900.00
0005432920293	9093	Economy	8900.00
0005432920169	9093	Economy	8900.00
0005432920094	9093	Economy	8900.00
0005433507619	9093	Economy	8900.00
0005433507610	9093	Economy	8900.00
0005432920144	9093	Economy	8900.00
0005433477064	9093	Economy	8900.00
0005433477066	9093	Economy	8900.00
0005432920191	9093	Economy	8900.00
0005433507609	9093	Economy	8900.00
0005432920126	9093	Economy	8900.00
0005433477071	9093	Economy	8900.00
0005432920124	9093	Economy	8900.00
0005433477075	9093	Economy	8900.00
0005432920220	9093	Economy	8900.00
0005432920217	9093	Economy	8900.00
0005432920137	9093	Economy	8900.00
0005432920138	9093	Economy	8900.00
0005432920093	9093	Economy	8900.00
0005433481348	9093	Economy	8900.00
0005433477089	9093	Economy	8900.00
0005433477091	9093	Economy	8900.00
0005433477081	9093	Economy	8900.00
0005433477061	9093	Economy	8900.00
0005433481349	9093	Economy	8900.00
0005432920156	9093	Economy	8900.00
0005433477072	9093	Economy	8900.00
0005433507607	9093	Economy	8900.00
0005433507613	9093	Economy	8900.00
0005433481346	9093	Economy	8900.00
0005432920155	9093	Economy	8900.00
0005433507602	9093	Economy	8900.00
0005433477076	9093	Economy	8900.00
0005433477059	9093	Economy	8900.00
0005433477073	9093	Economy	8900.00
0005433477086	9093	Economy	8900.00
0005433477074	9093	Economy	8900.00
0005433477062	9093	Economy	8900.00
0005433481353	9093	Economy	8900.00
0005433507622	9093	Economy	8900.00
0005433507608	9093	Economy	8900.00
0005433477090	9093	Economy	8900.00
0005432920207	9093	Economy	8900.00
0005433477058	9093	Economy	8900.00
0005433477085	9093	Economy	8900.00
0005433477056	9093	Economy	8900.00
0005433507621	9093	Economy	8900.00
0005432920216	9093	Economy	8900.00
0005432920141	9093	Economy	8900.00
0005432920208	9093	Economy	8900.00
0005433507611	9093	Economy	8900.00
0005433507605	9093	Economy	8900.00
0005433477057	9093	Economy	8900.00
0005433507616	9093	Economy	8900.00
0005433477078	9093	Economy	8900.00
0005432920145	9093	Economy	8900.00
0005432920228	9093	Economy	8900.00
0005433477069	9093	Economy	8900.00
0005432920377	20484	Business	26600.00
0005432920359	20484	Business	26600.00
0005432920378	20484	Business	26600.00
0005432920363	20484	Business	26600.00
0005432920362	20484	Economy	8900.00
0005433481309	20484	Economy	8900.00
0005432920364	20484	Economy	8900.00
0005433481297	20484	Economy	8900.00
0005432920367	20484	Economy	9800.00
0005432920369	20484	Economy	9800.00
0005433507390	20484	Economy	8900.00
0005433481311	20484	Economy	8900.00
0005432920376	20484	Economy	8900.00
0005433481315	20484	Economy	8900.00
0005433507493	20484	Economy	8900.00
0005432920370	20484	Economy	8900.00
0005433507420	20484	Economy	8900.00
0005434159037	20484	Economy	8900.00
0005433507462	20484	Economy	8900.00
0005433507456	20484	Economy	8900.00
0005432920366	20484	Economy	8900.00
0005433481308	20484	Economy	8900.00
0005432920375	20484	Economy	8900.00
0005433481310	20484	Economy	8900.00
0005433481298	20484	Economy	8900.00
0005433507391	20484	Economy	8900.00
0005433507470	20484	Economy	8900.00
0005433507467	20484	Economy	8900.00
0005432920360	20484	Economy	8900.00
0005433507468	20484	Economy	8900.00
0005432920368	20484	Economy	8900.00
0005432920373	20484	Economy	8900.00
0005432920374	20484	Economy	8900.00
0005432920361	20484	Economy	8900.00
0005433481312	20484	Economy	8900.00
0005432920372	20484	Economy	8900.00
0005432920365	20484	Economy	8900.00
0005433507419	20484	Economy	8900.00
0005432920371	20484	Economy	8900.00
0005433507441	20484	Economy	8900.00
0005432394195	10151	Economy	5800.00
0005432396329	10151	Economy	5800.00
0005432396332	10151	Economy	5800.00
0005432396331	10151	Economy	5800.00
0005432394196	10151	Economy	5800.00
0005432396330	10151	Economy	5800.00
0005432396333	10151	Economy	5800.00
0005432394197	10151	Economy	5800.00
0005432394193	10151	Economy	5800.00
0005432394194	10151	Economy	5800.00
0005432396316	18334	Economy	5800.00
0005435179416	18334	Economy	5800.00
0005432396301	18334	Economy	5800.00
0005435179417	18334	Economy	5800.00
0005432400190	18334	Economy	5800.00
0005432400194	18334	Economy	5800.00
0005432396294	18334	Economy	5800.00
0005432396293	18334	Economy	5800.00
0005432400191	18334	Economy	5800.00
0005435179415	18334	Economy	5800.00
0005435626425	10986	Business	9500.00
0005434411879	10986	Business	9500.00
0005435626396	10986	Business	9500.00
0005435554257	10986	Business	9500.00
0005435127053	10986	Business	9500.00
0005435126996	10986	Business	9500.00
0005435126799	10986	Business	9500.00
0005435126956	10986	Business	9500.00
0005434928367	10986	Business	9500.00
0005435126865	10986	Business	9500.00
0005435126862	10986	Economy	3200.00
0005435556735	10986	Economy	3200.00
0005435126978	10986	Economy	3200.00
0005435126979	10986	Economy	3200.00
0005435626424	10986	Economy	3200.00
0005435626418	10986	Economy	3200.00
0005435626431	10986	Economy	3200.00
0005435126806	10986	Economy	3200.00
0005435126980	10986	Economy	3200.00
0005435626399	10986	Economy	3500.00
0005435127050	10986	Economy	3500.00
0005434411880	10986	Economy	3500.00
0005435126863	10986	Economy	3500.00
0005435127057	10986	Economy	3500.00
0005435126861	10986	Economy	3200.00
0005435554253	10986	Economy	3200.00
0005435626395	10986	Economy	3200.00
0005435126634	10986	Economy	3200.00
0005435127002	10986	Economy	3200.00
0005435127096	10986	Economy	3200.00
0005435126967	10986	Economy	3200.00
0005434928368	10986	Economy	3200.00
0005435554229	10986	Economy	3200.00
0005435126919	10986	Economy	3200.00
0005435126740	10986	Economy	3200.00
0005435127097	10986	Economy	3200.00
0005435127079	10986	Economy	3200.00
0005435554230	10986	Economy	3200.00
0005435127051	10986	Economy	3200.00
0005435126829	10986	Economy	3200.00
0005435127054	10986	Economy	3200.00
0005435126813	10986	Economy	3200.00
0005435126964	10986	Economy	3200.00
0005435126912	10986	Economy	3200.00
0005435626410	10986	Economy	3200.00
0005435127004	10986	Economy	3200.00
0005434928366	10986	Economy	3200.00
0005435126975	10986	Economy	3200.00
0005435626401	10986	Economy	3200.00
0005435126816	10986	Economy	3200.00
0005435626430	10986	Economy	3200.00
0005434411881	10986	Economy	3200.00
0005435126817	10986	Economy	3200.00
0005435126974	10986	Economy	3200.00
0005435626400	10986	Economy	3200.00
0005435554258	10986	Economy	3200.00
0005435126953	10986	Economy	3200.00
0005435127062	10986	Economy	3200.00
0005435626394	10986	Economy	3200.00
0005435554228	10986	Economy	3200.00
0005435127115	10986	Economy	3200.00
0005435127038	10986	Economy	3200.00
0005435126856	10986	Economy	3200.00
0005435126805	10986	Economy	3200.00
0005435126936	10986	Economy	3200.00
0005435127031	10986	Economy	3200.00
0005435127017	10986	Economy	3200.00
0005435126920	10986	Economy	3200.00
0005435126858	10986	Economy	3200.00
0005435126976	10986	Economy	3200.00
0005435126966	10986	Economy	3200.00
0005435126983	10986	Economy	3200.00
0005435556731	10986	Economy	3200.00
0005435127030	10986	Economy	3200.00
0005435127060	10986	Economy	3200.00
0005435126788	10986	Economy	3200.00
0005435626409	10986	Economy	3200.00
0005435127027	10986	Economy	3200.00
0005435127333	14696	Business	9500.00
0005435554299	14696	Business	9500.00
0005435626618	14696	Business	9500.00
0005435127348	14696	Business	9500.00
0005435626617	14696	Business	9500.00
0005434411840	14696	Business	9500.00
0005435127325	14696	Business	9500.00
0005435626621	14696	Business	9500.00
0005435626616	14696	Economy	3200.00
0005435626610	14696	Economy	3200.00
0005434411844	14696	Economy	3200.00
0005435554296	14696	Economy	3200.00
0005434411841	14696	Economy	3200.00
0005435127339	14696	Economy	3200.00
0005435127345	14696	Economy	3200.00
0005435626612	14696	Economy	3500.00
0005435626614	14696	Economy	3500.00
0005435127340	14696	Economy	3500.00
0005435556750	14696	Economy	3500.00
0005435127346	14696	Economy	3200.00
0005435127313	14696	Economy	3200.00
0005434411855	14696	Economy	3200.00
0005435127335	14696	Economy	3200.00
0005435127314	14696	Economy	3200.00
0005434411826	14696	Economy	3200.00
0005434411834	14696	Economy	3200.00
0005434411850	14696	Economy	3200.00
0005435127319	14696	Economy	3200.00
0005435626613	14696	Economy	3200.00
0005435127324	14696	Economy	3200.00
0005435626622	14696	Economy	3200.00
0005435127332	14696	Economy	3200.00
0005435127323	14696	Economy	3200.00
0005435554297	14696	Economy	3200.00
0005434928345	14696	Economy	3200.00
0005434928346	14696	Economy	3200.00
0005434411830	14696	Economy	3200.00
0005434928348	14696	Economy	3200.00
0005435127322	14696	Economy	3200.00
0005434411851	14696	Economy	3200.00
0005435127331	14696	Economy	3200.00
0005435127330	14696	Economy	3200.00
0005435127342	14696	Economy	3200.00
0005435556753	14696	Economy	3200.00
0005435626609	14696	Economy	3200.00
0005435127327	14696	Economy	3200.00
0005435127320	14696	Economy	3200.00
0005435127336	14696	Economy	3200.00
0005434411845	14696	Economy	3200.00
0005435626619	14696	Economy	3200.00
0005434411846	14696	Economy	3200.00
0005435127341	14696	Economy	3200.00
0005435127329	14696	Economy	3200.00
0005435127318	14696	Economy	3200.00
0005435127328	14696	Economy	3200.00
0005435127312	14696	Economy	3200.00
0005435127317	14696	Economy	3200.00
0005435127344	14696	Economy	3200.00
0005434411835	14696	Economy	3200.00
0005435127337	14696	Economy	3200.00
0005435127351	14696	Economy	3200.00
0005435127349	14696	Economy	3200.00
0005435626608	14696	Economy	3200.00
0005435127316	14696	Economy	3200.00
0005435127334	14696	Economy	3200.00
0005435127338	14696	Economy	3200.00
0005435556751	14696	Economy	3200.00
0005434928347	14696	Economy	3200.00
0005434411831	14696	Economy	3200.00
0005435554298	14696	Economy	3200.00
0005435127343	14696	Economy	3200.00
0005435127347	14696	Economy	3200.00
0005435626615	14696	Economy	3200.00
0005435626611	14696	Economy	3200.00
0005435127350	14696	Economy	3200.00
0005435127315	14696	Economy	3200.00
0005435626620	14696	Economy	3200.00
0005435127326	14696	Economy	3200.00
0005435556752	14696	Economy	3200.00
0005435127321	14696	Economy	3200.00
0005435715867	7102	Business	86900.00
0005435443426	7102	Business	86900.00
0005435715871	7102	Business	86900.00
0005435715881	7102	Business	86900.00
0005435715875	7102	Business	86900.00
0005432400212	7102	Business	86900.00
0005435178515	7102	Business	86900.00
0005435443496	7102	Economy	29000.00
0005435715865	7102	Economy	29000.00
0005435443446	7102	Economy	29000.00
0005435178516	7102	Economy	29000.00
0005435715868	7102	Economy	31900.00
0005435443488	7102	Economy	31900.00
0005435715878	7102	Economy	31900.00
0005435715877	7102	Economy	29000.00
0005435219233	7102	Economy	29000.00
0005435715874	7102	Economy	29000.00
0005435443445	7102	Economy	29000.00
0005435715872	7102	Economy	29000.00
0005435715879	7102	Economy	29000.00
0005435216620	7102	Economy	29000.00
0005435216610	7102	Economy	29000.00
0005435219231	7102	Economy	29000.00
0005435216615	7102	Economy	29000.00
0005435443452	7102	Economy	29000.00
0005435216616	7102	Economy	29000.00
0005435715876	7102	Economy	29000.00
0005435178520	7102	Economy	29000.00
0005435216614	7102	Economy	29000.00
0005435715866	7102	Economy	29000.00
0005432398284	7102	Economy	29000.00
0005435443425	7102	Economy	29000.00
0005432398283	7102	Economy	29000.00
0005432400211	7102	Economy	29000.00
0005435715873	7102	Economy	29000.00
0005435715870	7102	Economy	29000.00
0005435219236	7102	Economy	29000.00
0005435715880	7102	Economy	29000.00
0005435443489	7102	Economy	29000.00
0005435715869	7102	Economy	29000.00
0005432394146	27054	Business	86900.00
0005435715743	27054	Economy	29000.00
0005435715735	27054	Economy	29000.00
0005432398245	27054	Economy	29000.00
0005432394179	27054	Economy	29000.00
0005435443539	27054	Economy	31900.00
0005435443535	27054	Economy	31900.00
0005435715680	27054	Economy	29000.00
0005435715726	27054	Economy	29000.00
0005435178533	27054	Economy	29000.00
0005435178532	27054	Economy	29000.00
0005435443540	27054	Economy	29000.00
0005435443537	27054	Economy	29000.00
0005432398249	27054	Economy	29000.00
0005432398257	27054	Economy	29000.00
0005435443536	27054	Economy	29000.00
0005435443531	27054	Economy	29000.00
0005435715670	27054	Economy	29000.00
0005435443538	27054	Economy	29000.00
0005432398243	27054	Economy	29000.00
0005435443534	27054	Economy	29000.00
0005435178531	27054	Economy	29000.00
0005435443532	27054	Economy	29000.00
0005435715734	27054	Economy	29000.00
0005435715721	27054	Economy	29000.00
0005435715695	27054	Economy	29000.00
0005435715761	27054	Economy	29000.00
0005435715699	27054	Economy	29000.00
0005435715794	27054	Economy	29000.00
0005432398256	27054	Economy	29000.00
0005432398248	27054	Economy	29000.00
0005435443533	27054	Economy	29000.00
0005435715742	27054	Economy	29000.00
0005432398244	27054	Economy	29000.00
0005435715729	27054	Economy	29000.00
0005435715773	27054	Economy	29000.00
0005435715696	27054	Economy	29000.00
0005434085039	2741	Economy	7700.00
0005434085041	2741	Economy	7700.00
0005434085042	2741	Economy	7700.00
0005434085040	2741	Economy	7700.00
0005434085038	2741	Economy	7700.00
0005433060476	28515	Economy	7700.00
0005433060478	28515	Economy	7700.00
0005434085001	28515	Economy	7700.00
0005433060477	28515	Economy	7700.00
0005435541284	11403	Business	20200.00
0005435541354	11403	Business	20200.00
0005435518216	11403	Business	20200.00
0005435541405	11403	Business	20200.00
0005435541386	11403	Economy	6700.00
0005435541338	11403	Economy	7400.00
0005435541285	11403	Economy	7400.00
0005435541324	11403	Economy	7400.00
0005435541351	11403	Economy	7400.00
0005435541321	11403	Economy	6700.00
0005435518145	11403	Economy	6700.00
0005435541325	11403	Economy	6700.00
0005435518138	11403	Economy	6700.00
0005435541404	11403	Economy	6700.00
0005435518242	11403	Economy	6700.00
0005435541291	11403	Economy	6700.00
0005435541268	11403	Economy	6700.00
0005435541337	11403	Economy	6700.00
0005435541300	11403	Economy	6700.00
0005435518241	11403	Economy	6700.00
0005435541387	11403	Economy	6700.00
0005435541301	11403	Economy	6700.00
0005435541278	11403	Economy	6700.00
0005435541322	11403	Economy	6700.00
0005435541409	11403	Economy	6700.00
0005435541410	11403	Economy	6700.00
0005435518208	11403	Economy	6700.00
0005435541383	11403	Economy	6700.00
0005435541344	11403	Economy	6700.00
0005435518194	11403	Economy	6700.00
0005435518128	11403	Economy	6700.00
0005435541379	11403	Economy	6700.00
0005435541304	11403	Economy	6700.00
0005435518202	11403	Economy	6700.00
0005435518240	11403	Economy	6700.00
0005435541348	11403	Economy	6700.00
0005435541352	11403	Economy	6700.00
0005435530060	22220	Business	20200.00
0005435541501	22220	Business	20200.00
0005435530061	22220	Business	20200.00
0005435530045	22220	Business	20200.00
0005435529760	22220	Business	20200.00
0005435541500	22220	Business	20200.00
0005435530049	22220	Economy	6700.00
0005435529754	22220	Economy	6700.00
0005435530059	22220	Economy	6700.00
0005435541505	22220	Economy	6700.00
0005432294542	22220	Economy	6700.00
0005435529759	22220	Economy	6700.00
0005435530046	22220	Economy	6700.00
0005435529763	22220	Economy	6700.00
0005435529748	22220	Economy	6700.00
0005435530057	22220	Economy	7400.00
0005435541491	22220	Economy	7400.00
0005435529745	22220	Economy	7400.00
0005435541489	22220	Economy	6700.00
0005435529758	22220	Economy	6700.00
0005435530051	22220	Economy	6700.00
0005435541498	22220	Economy	6700.00
0005435529762	22220	Economy	6700.00
0005435529749	22220	Economy	6700.00
0005435541487	22220	Economy	6700.00
0005435541507	22220	Economy	6700.00
0005435529744	22220	Economy	6700.00
0005435541502	22220	Economy	6700.00
0005435541495	22220	Economy	6700.00
0005435541488	22220	Economy	6700.00
0005435541490	22220	Economy	6700.00
0005435529751	22220	Economy	6700.00
0005435530058	22220	Economy	6700.00
0005435530054	22220	Economy	6700.00
0005435541492	22220	Economy	6700.00
0005435541503	22220	Economy	6700.00
0005435541499	22220	Economy	6700.00
0005435530056	22220	Economy	6700.00
0005435541494	22220	Economy	6700.00
0005435529757	22220	Economy	6700.00
0005435530048	22220	Economy	6700.00
0005435530050	22220	Economy	6700.00
0005435529750	22220	Economy	6700.00
0005435541496	22220	Economy	6700.00
0005435529747	22220	Economy	6700.00
0005435529755	22220	Economy	6700.00
0005435530055	22220	Economy	6700.00
0005435529764	22220	Economy	6700.00
0005435529753	22220	Economy	6700.00
0005435530052	22220	Economy	6700.00
0005435541497	22220	Economy	6700.00
0005435530053	22220	Economy	6700.00
0005435541493	22220	Economy	6700.00
0005435541504	22220	Economy	6700.00
0005435529756	22220	Economy	6700.00
0005435541506	22220	Economy	6700.00
0005435529746	22220	Economy	6700.00
0005435530047	22220	Economy	6700.00
0005435529752	22220	Economy	6700.00
0005435541508	22220	Economy	6700.00
0005435529761	22220	Economy	6700.00
0005434908541	2295	Business	20200.00
0005434908544	2295	Business	20200.00
0005434908542	2295	Business	20200.00
0005434908510	2295	Business	20200.00
0005434908508	2295	Business	20200.00
0005434908509	2295	Business	20200.00
0005434908511	2295	Business	20200.00
0005433251923	2295	Business	20200.00
0005433251989	2295	Business	20200.00
0005433251948	2295	Business	20200.00
0005434908517	2295	Business	20200.00
0005433251961	2295	Business	20200.00
0005434908513	2295	Economy	6700.00
0005433251844	2295	Economy	6700.00
0005434908536	2295	Economy	6700.00
0005433401037	2295	Economy	6700.00
0005434908523	2295	Economy	6700.00
0005434908539	2295	Economy	6700.00
0005434908521	2295	Economy	6700.00
0005434908533	2295	Economy	6700.00
0005433251807	2295	Economy	6700.00
0005433251962	2295	Economy	6700.00
0005434908537	2295	Economy	7400.00
0005433401028	2295	Economy	7400.00
0005434908522	2295	Economy	7400.00
0005434908543	2295	Economy	7400.00
0005433401021	2295	Economy	7400.00
0005434908534	2295	Economy	6700.00
0005433251983	2295	Economy	6700.00
0005433251977	2295	Economy	6700.00
0005434908526	2295	Economy	6700.00
0005433252096	2295	Economy	6700.00
0005433401029	2295	Economy	6700.00
0005433251992	2295	Economy	6700.00
0005434908540	2295	Economy	6700.00
0005434908504	2295	Economy	6700.00
0005433251984	2295	Economy	6700.00
0005433251949	2295	Economy	6700.00
0005434908546	2295	Economy	6700.00
0005434908549	2295	Economy	6700.00
0005434908548	2295	Economy	6700.00
0005434908547	2295	Economy	6700.00
0005434908529	2295	Economy	6700.00
0005433251985	2295	Economy	6700.00
0005433251845	2295	Economy	6700.00
0005434908512	2295	Economy	6700.00
0005434908518	2295	Economy	6700.00
0005433251951	2295	Economy	6700.00
0005434908530	2295	Economy	6700.00
0005433252018	2295	Economy	6700.00
0005434908505	2295	Economy	6700.00
0005434908514	2295	Economy	6700.00
0005433251894	2295	Economy	6700.00
0005434908532	2295	Economy	6700.00
0005433401022	2295	Economy	6700.00
0005434908506	2295	Economy	6700.00
0005433401030	2295	Economy	6700.00
0005434908520	2295	Economy	6700.00
0005433251975	2295	Economy	6700.00
0005434908516	2295	Economy	6700.00
0005433251895	2295	Economy	6700.00
0005434908515	2295	Economy	6700.00
0005433252033	2295	Economy	6700.00
0005434908550	2295	Economy	6700.00
0005434908527	2295	Economy	6700.00
0005433252053	2295	Economy	6700.00
0005434908538	2295	Economy	6700.00
0005434908525	2295	Economy	6700.00
0005433251883	2295	Economy	6700.00
0005434908528	2295	Economy	6700.00
0005433251884	2295	Economy	6700.00
0005434908524	2295	Economy	6700.00
0005433251926	2295	Economy	6700.00
0005433252000	2295	Economy	6700.00
0005433401040	2295	Economy	6700.00
0005433251927	2295	Economy	6700.00
0005433401041	2295	Economy	6700.00
0005433251808	2295	Economy	6700.00
0005433251993	2295	Economy	6700.00
0005434908507	2295	Economy	6700.00
0005434908519	2295	Economy	6700.00
0005433251922	2295	Economy	6700.00
0005433251885	2295	Economy	6700.00
0005433251978	2295	Economy	6700.00
0005433251952	2295	Economy	6700.00
0005433252021	2295	Economy	6700.00
0005433251913	2295	Economy	6700.00
0005434908531	2295	Economy	6700.00
0005433251918	2295	Economy	6700.00
0005434908545	2295	Economy	6700.00
0005434908535	2295	Economy	6700.00
0005433251875	2295	Economy	6700.00
0005433252198	25614	Business	20200.00
0005433401055	25614	Business	20200.00
0005433401054	25614	Business	20200.00
0005433252212	25614	Business	20200.00
0005433252217	25614	Business	20200.00
0005434907681	25614	Business	20200.00
0005434908114	25614	Business	20200.00
0005434908046	25614	Business	20200.00
0005434907939	25614	Business	20200.00
0005434907993	25614	Business	20200.00
0005434908061	25614	Economy	6700.00
0005433252194	25614	Economy	6700.00
0005433252197	25614	Economy	6700.00
0005434908113	25614	Economy	6700.00
0005434907973	25614	Economy	6700.00
0005434908053	25614	Economy	6700.00
0005433252219	25614	Economy	6700.00
0005434907937	25614	Economy	6700.00
0005434907989	25614	Economy	6700.00
0005434907963	25614	Economy	6700.00
0005433252192	25614	Economy	7400.00
0005434907986	25614	Economy	7400.00
0005433252207	25614	Economy	7400.00
0005433252218	25614	Economy	7400.00
0005434908080	25614	Economy	7400.00
0005434907755	25614	Economy	6700.00
0005433401056	25614	Economy	6700.00
0005433252221	25614	Economy	6700.00
0005433252214	25614	Economy	6700.00
0005433252193	25614	Economy	6700.00
0005434907869	25614	Economy	6700.00
0005433252202	25614	Economy	6700.00
0005433252199	25614	Economy	6700.00
0005434907981	25614	Economy	6700.00
0005434908106	25614	Economy	6700.00
0005433252220	25614	Economy	6700.00
0005434907988	25614	Economy	6700.00
0005433252195	25614	Economy	6700.00
0005434908060	25614	Economy	6700.00
0005434908084	25614	Economy	6700.00
0005433252210	25614	Economy	6700.00
0005434908090	25614	Economy	6700.00
0005434907955	25614	Economy	6700.00
0005434907910	25614	Economy	6700.00
0005434908070	25614	Economy	6700.00
0005434908103	25614	Economy	6700.00
0005434907897	25614	Economy	6700.00
0005434907953	25614	Economy	6700.00
0005434908123	25614	Economy	6700.00
0005434907847	25614	Economy	6700.00
0005433252209	25614	Economy	6700.00
0005434907977	25614	Economy	6700.00
0005434907773	25614	Economy	6700.00
0005434907791	25614	Economy	6700.00
0005434907920	25614	Economy	6700.00
0005434908036	25614	Economy	6700.00
0005434907954	25614	Economy	6700.00
0005434907990	25614	Economy	6700.00
0005434908039	25614	Economy	6700.00
0005433252204	25614	Economy	6700.00
0005434908122	25614	Economy	6700.00
0005434907991	25614	Economy	6700.00
0005433252203	25614	Economy	6700.00
0005434908099	25614	Economy	6700.00
0005433252213	25614	Economy	6700.00
0005434907756	25614	Economy	6700.00
0005434908107	25614	Economy	6700.00
0005434908081	25614	Economy	6700.00
0005434907992	25614	Economy	6700.00
0005433252216	25614	Economy	6700.00
0005433252201	25614	Economy	6700.00
0005434908096	25614	Economy	6700.00
0005433252196	25614	Economy	6700.00
0005433252222	25614	Economy	6700.00
0005433252215	25614	Economy	6700.00
0005434908091	25614	Economy	6700.00
0005434907982	25614	Economy	6700.00
0005433252211	25614	Economy	6700.00
0005434908124	25614	Economy	6700.00
0005434907754	25614	Economy	6700.00
0005434907828	25614	Economy	6700.00
0005434908092	25614	Economy	6700.00
0005434908054	25614	Economy	6700.00
0005433252200	25614	Economy	6700.00
0005434908082	25614	Economy	6700.00
0005433401053	25614	Economy	6700.00
0005434908126	25614	Economy	6700.00
0005434907846	25614	Economy	6700.00
0005433252208	25614	Economy	6700.00
0005434907938	25614	Economy	6700.00
0005433252206	25614	Economy	6700.00
0005434907931	25614	Economy	6700.00
0005433252205	25614	Economy	6700.00
0005432621375	2544	Economy	13600.00
0005432862453	2544	Economy	13600.00
0005432621365	2544	Economy	13600.00
0005432621373	2544	Economy	12400.00
0005432621380	2544	Economy	12400.00
0005432862410	2544	Economy	12400.00
0005432621369	2544	Economy	12400.00
0005432621368	2544	Economy	12400.00
0005432621379	2544	Economy	12400.00
0005432862429	2544	Economy	12400.00
0005432621366	2544	Economy	12400.00
0005432862440	2544	Economy	12400.00
0005432862428	2544	Economy	12400.00
0005432621374	2544	Economy	12400.00
0005432621376	2544	Economy	12400.00
0005432862411	2544	Economy	12400.00
0005432621378	2544	Economy	12400.00
0005432621371	2544	Economy	12400.00
0005432621370	2544	Economy	12400.00
0005432862418	2544	Economy	12400.00
0005432621372	2544	Economy	12400.00
0005432621367	2544	Economy	12400.00
0005432621377	2544	Economy	12400.00
0005432621317	28064	Economy	13600.00
0005432621294	28064	Economy	12400.00
0005432621239	28064	Economy	12400.00
0005432621301	28064	Economy	12400.00
0005432621304	28064	Economy	12400.00
0005432621240	28064	Economy	12400.00
0005432862486	28064	Economy	12400.00
0005432862484	28064	Economy	12400.00
0005432862481	28064	Economy	12400.00
0005432862485	28064	Economy	12400.00
0005432862482	28064	Economy	12400.00
0005432862487	28064	Economy	12400.00
0005432621295	28064	Economy	12400.00
0005432862488	28064	Economy	12400.00
0005432862483	28064	Economy	12400.00
0005432621276	28064	Economy	12400.00
0005434097502	13088	Economy	11300.00
0005434097503	13088	Economy	11300.00
0005433451666	31053	Economy	8400.00
0005433452789	31053	Economy	8400.00
0005433451668	31053	Economy	8400.00
0005433452788	31053	Economy	8400.00
0005433451667	31053	Economy	8400.00
0005433454901	31442	Economy	8400.00
0005433454906	31442	Economy	8400.00
0005433452773	31442	Economy	8400.00
0005433454908	31442	Economy	8400.00
0005434142676	11991	Economy	7200.00
0005434142656	11991	Economy	6600.00
0005433129331	11991	Economy	6600.00
0005433134208	11991	Economy	6600.00
0005434142665	11991	Economy	6600.00
0005433129337	11991	Economy	6600.00
0005434142660	11991	Economy	6600.00
0005433134209	11991	Economy	6600.00
0005434184698	11991	Economy	6600.00
0005434142666	11991	Economy	6600.00
0005434142655	11991	Economy	6600.00
0005434184694	11991	Economy	6600.00
0005433129330	11991	Economy	6600.00
0005433134198	11991	Economy	6600.00
0005434142667	11991	Economy	6600.00
0005433134207	11991	Economy	6600.00
0005434184695	11991	Economy	6600.00
0005434184696	11991	Economy	6600.00
0005433129346	11991	Economy	6600.00
0005433129357	11991	Economy	6600.00
0005434142673	11991	Economy	6600.00
0005434184697	11991	Economy	6600.00
0005433129332	11991	Economy	6600.00
0005433131816	29852	Economy	7200.00
0005434142699	29852	Economy	6600.00
0005434184715	29852	Economy	6600.00
0005434184714	29852	Economy	6600.00
0005433134245	29852	Economy	6600.00
0005434142703	29852	Economy	6600.00
0005434142701	29852	Economy	6600.00
0005433131815	29852	Economy	6600.00
0005434184713	29852	Economy	6600.00
0005433131817	29852	Economy	6600.00
0005434142702	29852	Economy	6600.00
0005434142700	29852	Economy	6600.00
0005433134248	29852	Economy	6600.00
0005433131818	29852	Economy	6600.00
0005433134246	29852	Economy	6600.00
0005434183628	29852	Economy	6600.00
0005433134247	29852	Economy	6600.00
0005435697979	16485	Economy	19900.00
0005435697983	16485	Economy	19900.00
0005435697984	16485	Economy	19900.00
0005435935080	16485	Economy	18100.00
0005435697976	16485	Economy	18100.00
0005435697985	16485	Economy	18100.00
0005435697977	16485	Economy	18100.00
0005435697978	16485	Economy	18100.00
0005435697968	16485	Economy	18100.00
0005435697967	16485	Economy	18100.00
0005435697964	16485	Economy	18100.00
0005435697980	16485	Economy	18100.00
0005435697981	16485	Economy	18100.00
0005435697975	16485	Economy	18100.00
0005435697972	16485	Economy	18100.00
0005435935087	16485	Economy	18100.00
0005435697989	16485	Economy	18100.00
0005435697982	16485	Economy	18100.00
0005435697965	16485	Economy	18100.00
0005435697988	16485	Economy	18100.00
0005435697970	16485	Economy	18100.00
0005435697974	16485	Economy	18100.00
0005435935086	16485	Economy	18100.00
0005435697973	16485	Economy	18100.00
0005435697990	16485	Economy	18100.00
0005435697963	16485	Economy	18100.00
0005435697987	16485	Economy	18100.00
0005435697966	16485	Economy	18100.00
0005435935085	16485	Economy	18100.00
0005435697986	16485	Economy	18100.00
0005435697991	16485	Economy	18100.00
0005435697971	16485	Economy	18100.00
0005435697969	16485	Economy	18100.00
0005435935122	24725	Economy	19900.00
0005435697795	24725	Economy	19900.00
0005435697593	24725	Economy	19900.00
0005435697705	24725	Economy	19900.00
0005435697730	24725	Economy	18100.00
0005435697675	24725	Economy	18100.00
0005435697646	24725	Economy	18100.00
0005435697777	24725	Economy	18100.00
0005435697793	24725	Economy	18100.00
0005435697865	24725	Economy	18100.00
0005435697635	24725	Economy	18100.00
0005435933572	24725	Economy	18100.00
0005435697788	24725	Economy	18100.00
0005435697806	24725	Economy	18100.00
0005435697866	24725	Economy	18100.00
0005435697805	24725	Economy	18100.00
0005435697736	24725	Economy	18100.00
0005435697647	24725	Economy	18100.00
0005435697706	24725	Economy	18100.00
0005435697786	24725	Economy	18100.00
0005435697761	24725	Economy	18100.00
0005435697636	24725	Economy	18100.00
0005435935121	24725	Economy	18100.00
0005435935119	24725	Economy	18100.00
0005435697799	24725	Economy	18100.00
0005435697800	24725	Economy	18100.00
0005435697766	24725	Economy	18100.00
0005435697634	24725	Economy	18100.00
0005435697729	24725	Economy	18100.00
0005435697735	24725	Economy	18100.00
0005435697782	24725	Economy	18100.00
0005435697650	24725	Economy	18100.00
0005435697796	24725	Economy	18100.00
0005435697769	24725	Economy	18100.00
0005435697785	24725	Economy	18100.00
0005435697798	24725	Economy	18100.00
0005435697844	24725	Economy	18100.00
0005435697757	24725	Economy	18100.00
0005435935120	24725	Economy	18100.00
0005433724911	18756	Economy	4400.00
0005433724912	18756	Economy	4400.00
0005433724914	18756	Economy	4400.00
0005432968874	18756	Economy	4400.00
0005433724910	18756	Economy	4400.00
0005433724913	18756	Economy	4400.00
0005432968873	18756	Economy	4400.00
0005433724909	18756	Economy	4400.00
0005432968897	21592	Economy	4400.00
0005433724886	21592	Economy	4400.00
0005432968896	21592	Economy	4400.00
0005433724887	21592	Economy	4400.00
0005434140065	7320	Business	23100.00
0005434140052	7320	Business	23100.00
0005434140091	7320	Business	23100.00
0005434140071	7320	Business	23100.00
0005434140033	7320	Business	23100.00
0005434140040	7320	Business	23100.00
0005434140097	7320	Business	23100.00
0005434087628	7320	Business	23100.00
0005434140092	7320	Business	23100.00
0005434140042	7320	Business	23100.00
0005434140054	7320	Business	23100.00
0005434140043	7320	Business	23100.00
0005434140089	7320	Economy	7700.00
0005434140096	7320	Economy	7700.00
0005434140084	7320	Economy	7700.00
0005434140078	7320	Economy	7700.00
0005434140101	7320	Economy	7700.00
0005434140093	7320	Economy	7700.00
0005434140082	7320	Economy	7700.00
0005434140111	7320	Economy	8500.00
0005434140072	7320	Economy	8500.00
0005434087632	7320	Economy	8500.00
0005434087629	7320	Economy	8500.00
0005434140055	7320	Economy	7700.00
0005434140059	7320	Economy	7700.00
0005434140070	7320	Economy	7700.00
0005434140041	7320	Economy	7700.00
0005434140053	7320	Economy	7700.00
0005434140037	7320	Economy	7700.00
0005434087627	7320	Economy	7700.00
0005434140106	7320	Economy	7700.00
0005434140108	7320	Economy	7700.00
0005434140051	7320	Economy	7700.00
0005434140050	7320	Economy	7700.00
0005434140079	7320	Economy	7700.00
0005434140061	7320	Economy	7700.00
0005434140080	7320	Economy	7700.00
0005434140081	7320	Economy	7700.00
0005434140036	7320	Economy	7700.00
0005434140049	7320	Economy	7700.00
0005434140067	7320	Economy	7700.00
0005434140090	7320	Economy	7700.00
0005434140087	7320	Economy	7700.00
0005434140076	7320	Economy	7700.00
0005434140069	7320	Economy	7700.00
0005434140047	7320	Economy	7700.00
0005434140103	7320	Economy	7700.00
0005434087630	7320	Economy	7700.00
0005434140048	7320	Economy	7700.00
0005434140035	7320	Economy	7700.00
0005434140034	7320	Economy	7700.00
0005434140094	7320	Economy	7700.00
0005434140105	7320	Economy	7700.00
0005434140110	7320	Economy	7700.00
0005434140039	7320	Economy	7700.00
0005434140104	7320	Economy	7700.00
0005434140068	7320	Economy	7700.00
0005434140100	7320	Economy	7700.00
0005434140066	7320	Economy	7700.00
0005434140107	7320	Economy	7700.00
0005434140074	7320	Economy	7700.00
0005434140056	7320	Economy	7700.00
0005434140044	7320	Economy	7700.00
0005434140063	7320	Economy	7700.00
0005434140073	7320	Economy	7700.00
0005434140102	7320	Economy	7700.00
0005434140075	7320	Economy	7700.00
0005434140057	7320	Economy	7700.00
0005434140086	7320	Economy	7700.00
0005434140062	7320	Economy	7700.00
0005434140058	7320	Economy	7700.00
0005434140099	7320	Economy	7700.00
0005434140045	7320	Economy	7700.00
0005434140077	7320	Economy	7700.00
0005434140088	7320	Economy	7700.00
0005434087631	7320	Economy	7700.00
0005434140098	7320	Economy	7700.00
0005434140046	7320	Economy	7700.00
0005434140060	7320	Economy	7700.00
0005434140109	7320	Economy	7700.00
0005434140085	7320	Economy	7700.00
0005434140083	7320	Economy	7700.00
0005434140064	7320	Economy	7700.00
0005434140038	7320	Economy	7700.00
0005434140095	7320	Economy	7700.00
0005434087605	28534	Business	23100.00
0005434138958	28534	Business	23100.00
0005434139494	28534	Business	23100.00
0005434139336	28534	Business	23100.00
0005434139273	28534	Business	23100.00
0005434139252	28534	Business	23100.00
0005434139027	28534	Business	23100.00
0005434139501	28534	Business	23100.00
0005434139495	28534	Business	23100.00
0005434139095	28534	Business	23100.00
0005434139270	28534	Economy	7700.00
0005434139063	28534	Economy	7700.00
0005434139155	28534	Economy	7700.00
0005434139239	28534	Economy	7700.00
0005434139253	28534	Economy	7700.00
0005434138953	28534	Economy	7700.00
0005434138965	28534	Economy	7700.00
0005434139244	28534	Economy	7700.00
0005434139025	28534	Economy	8500.00
0005434139238	28534	Economy	7700.00
0005434139152	28534	Economy	8500.00
0005434139445	28534	Economy	8500.00
0005434139024	28534	Economy	8500.00
0005434087604	28534	Economy	8500.00
0005434139472	28534	Economy	7700.00
0005434139036	28534	Economy	7700.00
0005434139159	28534	Economy	7700.00
0005434139151	28534	Economy	7700.00
0005434139316	28534	Economy	7700.00
0005434139343	28534	Economy	7700.00
0005434138966	28534	Economy	7700.00
0005434139352	28534	Economy	7700.00
0005434087606	28534	Economy	7700.00
0005434139430	28534	Economy	7700.00
0005434139461	28534	Economy	7700.00
0005434139283	28534	Economy	7700.00
0005434139491	28534	Economy	7700.00
0005434139335	28534	Economy	7700.00
0005434139416	28534	Economy	7700.00
0005434139402	28534	Economy	7700.00
0005434139210	28534	Economy	7700.00
0005434139266	28534	Economy	7700.00
0005434087599	28534	Economy	7700.00
0005434139382	28534	Economy	7700.00
0005434139429	28534	Economy	7700.00
0005434139447	28534	Economy	7700.00
0005434139333	28534	Economy	7700.00
0005434139189	28534	Economy	7700.00
0005434139484	28534	Economy	7700.00
0005434139037	28534	Economy	7700.00
0005434139414	28534	Economy	7700.00
0005434139305	28534	Economy	7700.00
0005434139468	28534	Economy	7700.00
0005434138980	28534	Economy	7700.00
0005434139282	28534	Economy	7700.00
0005434139028	28534	Economy	7700.00
0005434139374	28534	Economy	7700.00
0005434139432	28534	Economy	7700.00
0005434139390	28534	Economy	7700.00
0005434139410	28534	Economy	7700.00
0005434139331	28534	Economy	7700.00
0005434139269	28534	Economy	7700.00
0005434138954	28534	Economy	7700.00
0005434139322	28534	Economy	7700.00
0005434139403	28534	Economy	7700.00
0005434139285	28534	Economy	7700.00
0005434139225	28534	Economy	7700.00
0005434138990	28534	Economy	7700.00
0005434139188	28534	Economy	7700.00
0005434139023	28534	Economy	7700.00
0005434139428	28534	Economy	7700.00
0005434139187	28534	Economy	7700.00
0005434139493	28534	Economy	7700.00
0005434139436	28534	Economy	7700.00
0005434139160	28534	Economy	7700.00
0005434139310	28534	Economy	7700.00
0005434139334	28534	Economy	7700.00
0005434139332	28534	Economy	7700.00
0005434138960	28534	Economy	7700.00
0005434139306	28534	Economy	7700.00
0005434139158	28534	Economy	7700.00
0005434087603	28534	Economy	7700.00
0005434139169	28534	Economy	7700.00
0005434139373	28534	Economy	7700.00
0005434139168	28534	Economy	7700.00
0005434139284	28534	Economy	7700.00
0005434139220	28534	Economy	7700.00
0005434139190	28534	Economy	7700.00
0005434139309	28534	Economy	7700.00
0005434139411	28534	Economy	7700.00
0005434139185	28534	Economy	7700.00
0005434138979	28534	Economy	7700.00
0005434139415	28534	Economy	7700.00
0005434610314	1907	Economy	23900.00
0005435808463	1907	Economy	21700.00
0005435808462	1907	Economy	21700.00
0005435808470	1907	Economy	21700.00
0005433407638	1907	Economy	21700.00
0005435808469	1907	Economy	21700.00
0005435808472	1907	Economy	21700.00
0005434610316	1907	Economy	21700.00
0005434610315	1907	Economy	21700.00
0005435808467	1907	Economy	21700.00
0005435808465	1907	Economy	21700.00
0005435808466	1907	Economy	21700.00
0005435808471	1907	Economy	21700.00
0005435808468	1907	Economy	21700.00
0005434610313	1907	Economy	21700.00
0005435808464	1907	Economy	21700.00
0005433407615	1907	Economy	21700.00
0005435808335	23060	Economy	23900.00
0005435808359	23060	Economy	23900.00
0005435808341	23060	Economy	21700.00
0005433407680	23060	Economy	23900.00
0005435808380	23060	Economy	21700.00
0005435808334	23060	Economy	21700.00
0005435808331	23060	Economy	21700.00
0005435808309	23060	Economy	21700.00
0005433407675	23060	Economy	21700.00
0005433407679	23060	Economy	21700.00
0005433407677	23060	Economy	21700.00
0005435808376	23060	Economy	21700.00
0005435808308	23060	Economy	21700.00
0005435808357	23060	Economy	21700.00
0005434610282	23060	Economy	21700.00
0005435808343	23060	Economy	21700.00
0005435808316	23060	Economy	21700.00
0005433407678	23060	Economy	21700.00
0005434610286	23060	Economy	21700.00
0005435808351	23060	Economy	21700.00
0005433407683	23060	Economy	21700.00
0005435808358	23060	Economy	21700.00
0005435808355	23060	Economy	21700.00
0005433407676	23060	Economy	21700.00
0005435808381	23060	Economy	21700.00
0005434610294	23060	Economy	21700.00
0005435808310	23060	Economy	21700.00
0005435808340	23060	Economy	21700.00
0005433407681	23060	Economy	21700.00
0005435808350	23060	Economy	21700.00
0005435808379	23060	Economy	21700.00
0005435808352	23060	Economy	21700.00
0005433407682	23060	Economy	21700.00
0005434504634	16703	Economy	7600.00
0005434504713	16703	Economy	7600.00
0005434504747	16703	Economy	7600.00
0005434504817	16703	Economy	7600.00
0005434504712	16703	Economy	6900.00
0005434504431	16703	Economy	6900.00
0005434504780	16703	Economy	6900.00
0005434504512	16703	Economy	6900.00
0005434504787	16703	Economy	6900.00
0005434504435	16703	Economy	6900.00
0005434504434	16703	Economy	6900.00
0005434504605	16703	Economy	6900.00
0005434504630	16703	Economy	6900.00
0005434504631	16703	Economy	6900.00
0005434504687	16703	Economy	6900.00
0005434504824	16703	Economy	6900.00
0005434504743	16703	Economy	6900.00
0005434504777	16703	Economy	6900.00
0005434504617	16703	Economy	6900.00
0005434504723	16703	Economy	6900.00
0005434504727	16703	Economy	6900.00
0005434504633	16703	Economy	6900.00
0005434504606	16703	Economy	6900.00
0005434504818	16703	Economy	6900.00
0005434504792	16703	Economy	6900.00
0005434504813	16703	Economy	6900.00
0005434504726	16703	Economy	6900.00
0005434504740	16703	Economy	6900.00
0005434504724	16703	Economy	6900.00
0005434504674	16703	Economy	6900.00
0005434504697	16703	Economy	6900.00
0005434504675	16703	Economy	6900.00
0005434504686	16703	Economy	6900.00
0005434504609	16703	Economy	6900.00
0005434504632	16703	Economy	6900.00
0005434504748	16703	Economy	6900.00
0005434504673	16703	Economy	6900.00
0005434504513	16703	Economy	6900.00
0005434504739	16703	Economy	6900.00
0005434504696	16703	Economy	6900.00
0005434504732	16703	Economy	6900.00
0005434504825	16703	Economy	6900.00
0005434504432	16703	Economy	6900.00
0005434505034	22900	Economy	7600.00
0005434505051	22900	Economy	7600.00
0005434505039	22900	Economy	6900.00
0005434505055	22900	Economy	6900.00
0005434505063	22900	Economy	6900.00
0005434505050	22900	Economy	6900.00
0005434505047	22900	Economy	6900.00
0005434505038	22900	Economy	6900.00
0005434505032	22900	Economy	6900.00
0005434505064	22900	Economy	6900.00
0005434505052	22900	Economy	6900.00
0005434505031	22900	Economy	6900.00
0005434505059	22900	Economy	6900.00
0005434505045	22900	Economy	6900.00
0005434505048	22900	Economy	6900.00
0005434505066	22900	Economy	6900.00
0005434505053	22900	Economy	6900.00
0005434505041	22900	Economy	6900.00
0005434505061	22900	Economy	6900.00
0005434505044	22900	Economy	6900.00
0005434505067	22900	Economy	6900.00
0005434505046	22900	Economy	6900.00
0005434505040	22900	Economy	6900.00
0005434505060	22900	Economy	6900.00
0005434505068	22900	Economy	6900.00
0005434505065	22900	Economy	6900.00
0005434505033	22900	Economy	6900.00
0005434505058	22900	Economy	6900.00
0005434505062	22900	Economy	6900.00
0005434505069	22900	Economy	6900.00
0005434505036	22900	Economy	6900.00
0005434505042	22900	Economy	6900.00
0005434505043	22900	Economy	6900.00
0005434505035	22900	Economy	6900.00
0005434505057	22900	Economy	6900.00
0005434505049	22900	Economy	6900.00
0005434505056	22900	Economy	6900.00
0005434505054	22900	Economy	6900.00
0005434505037	22900	Economy	6900.00
0005433266852	2174	Economy	7700.00
0005435078702	2174	Economy	7000.00
0005435078705	2174	Economy	7000.00
0005433266842	2174	Economy	7000.00
0005435078713	2174	Economy	7000.00
0005435078711	2174	Economy	7000.00
0005433266836	2174	Economy	7000.00
0005435078712	2174	Economy	7000.00
0005435078706	2174	Economy	7000.00
0005433266866	2174	Economy	7000.00
0005435078715	2174	Economy	7000.00
0005435078708	2174	Economy	7000.00
0005435078714	2174	Economy	7000.00
0005433266847	2174	Economy	7000.00
0005433266841	2174	Economy	7000.00
0005433266838	2174	Economy	7000.00
0005435078701	2174	Economy	7000.00
0005433266835	2174	Economy	7000.00
0005435078704	2174	Economy	7000.00
0005435078710	2174	Economy	7000.00
0005435078709	2174	Economy	7000.00
0005433266839	2174	Economy	7000.00
0005435078716	2174	Economy	7000.00
0005435078707	2174	Economy	7000.00
0005433266851	2174	Economy	7000.00
0005435078703	2174	Economy	7000.00
0005435078594	24330	Economy	7700.00
0005433266943	24330	Economy	7700.00
0005433266942	24330	Economy	7700.00
0005433266945	24330	Economy	7700.00
0005435078615	24330	Economy	7000.00
0005435078545	24330	Economy	7000.00
0005435078554	24330	Economy	7000.00
0005435078614	24330	Economy	7000.00
0005435078582	24330	Economy	7000.00
0005435078626	24330	Economy	7000.00
0005435078583	24330	Economy	7000.00
0005433266947	24330	Economy	7000.00
0005435078560	24330	Economy	7000.00
0005435078625	24330	Economy	7000.00
0005433266939	24330	Economy	7000.00
0005433266938	24330	Economy	7000.00
0005433266941	24330	Economy	7000.00
0005435078559	24330	Economy	7000.00
0005435078558	24330	Economy	7000.00
0005435078596	24330	Economy	7000.00
0005433266940	24330	Economy	7000.00
0005435078592	24330	Economy	7000.00
0005435078493	24330	Economy	7000.00
0005435078580	24330	Economy	7000.00
0005433266944	24330	Economy	7000.00
0005435078666	24330	Economy	7000.00
0005435078593	24330	Economy	7000.00
0005435078557	24330	Economy	7000.00
0005435078610	24330	Economy	7000.00
0005433266946	24330	Economy	7000.00
0005435078570	24330	Economy	7000.00
0005435078556	24330	Economy	7000.00
0005434989002	6637	Economy	10800.00
0005435803332	6637	Economy	10800.00
0005434988997	6637	Economy	9800.00
0005435803331	6637	Economy	9800.00
0005435803330	6637	Economy	9800.00
0005434988996	6637	Economy	9800.00
0005435464533	6637	Economy	9800.00
0005434989000	6637	Economy	9800.00
0005434988998	6637	Economy	9800.00
0005435464534	6637	Economy	9800.00
0005434989003	6637	Economy	9800.00
0005434988993	6637	Economy	9800.00
0005434989001	6637	Economy	9800.00
0005434988999	6637	Economy	9800.00
0005435803329	6637	Economy	9800.00
0005434988994	6637	Economy	9800.00
0005434989006	6637	Economy	9800.00
0005434988992	6637	Economy	9800.00
0005434989005	6637	Economy	9800.00
0005434988995	6637	Economy	9800.00
0005434989004	6637	Economy	9800.00
0005434988846	23621	Economy	10800.00
0005434988855	23621	Economy	10800.00
0005434988847	23621	Economy	9800.00
0005434988879	23621	Economy	9800.00
0005435464555	23621	Economy	9800.00
0005434988880	23621	Economy	9800.00
0005434988854	23621	Economy	9800.00
0005434988877	23621	Economy	9800.00
0005434988884	23621	Economy	9800.00
0005435803303	23621	Economy	9800.00
0005435464554	23621	Economy	9800.00
0005435803304	23621	Economy	9800.00
0005435803302	23621	Economy	9800.00
0005434988887	23621	Economy	9800.00
0005432384097	30489	Business	9900.00
0005433450476	30489	Business	9900.00
0005432384098	30489	Business	9900.00
0005432384089	30489	Business	9900.00
0005433454926	30489	Business	9900.00
0005432384108	30489	Business	9900.00
0005432384080	30489	Business	9900.00
0005433450482	30489	Business	9900.00
0005433450494	30489	Business	9900.00
0005432384114	30489	Economy	3300.00
0005432384102	30489	Economy	3300.00
0005432384078	30489	Economy	3300.00
0005432384112	30489	Economy	3300.00
0005432384095	30489	Economy	3300.00
0005433450478	30489	Economy	3300.00
0005432384099	30489	Economy	3300.00
0005432384106	30489	Economy	3300.00
0005433450488	30489	Economy	3600.00
0005432384074	30489	Economy	3600.00
0005432384086	30489	Economy	3600.00
0005433453809	30489	Economy	3600.00
0005432384115	30489	Economy	3600.00
0005432384092	30489	Economy	3300.00
0005432384100	30489	Economy	3300.00
0005433450484	30489	Economy	3300.00
0005433450496	30489	Economy	3300.00
0005432384085	30489	Economy	3300.00
0005433450495	30489	Economy	3300.00
0005433454925	30489	Economy	3300.00
0005432384103	30489	Economy	3300.00
0005432384087	30489	Economy	3300.00
0005432384077	30489	Economy	3300.00
0005432384110	30489	Economy	3300.00
0005432384113	30489	Economy	3300.00
0005433450490	30489	Economy	3300.00
0005433450480	30489	Economy	3300.00
0005432384104	30489	Economy	3300.00
0005432384101	30489	Economy	3300.00
0005433450491	30489	Economy	3300.00
0005432384079	30489	Economy	3300.00
0005433450485	30489	Economy	3300.00
0005432384116	30489	Economy	3300.00
0005432384096	30489	Economy	3300.00
0005432384084	30489	Economy	3300.00
0005432384076	30489	Economy	3300.00
0005432384107	30489	Economy	3300.00
0005432384091	30489	Economy	3300.00
0005432384088	30489	Economy	3300.00
0005432384093	30489	Economy	3300.00
0005432384083	30489	Economy	3300.00
0005432384081	30489	Economy	3300.00
0005433450493	30489	Economy	3300.00
0005433450479	30489	Economy	3300.00
0005433450486	30489	Economy	3300.00
0005432384075	30489	Economy	3300.00
0005433450477	30489	Economy	3300.00
0005433450475	30489	Economy	3300.00
0005433450487	30489	Economy	3300.00
0005432384082	30489	Economy	3300.00
0005433450492	30489	Economy	3300.00
0005433450489	30489	Economy	3300.00
0005433450483	30489	Economy	3300.00
0005432384090	30489	Economy	3300.00
0005432384094	30489	Economy	3300.00
0005432384109	30489	Economy	3300.00
0005432384111	30489	Economy	3300.00
0005433450481	30489	Economy	3300.00
0005432384105	30489	Economy	3300.00
0005433453793	31306	Business	9900.00
0005432383660	31306	Business	9900.00
0005432383694	31306	Business	9900.00
0005433450284	31306	Business	9900.00
0005432383571	31306	Business	9900.00
0005433450283	31306	Business	9900.00
0005432383761	31306	Business	9900.00
0005432383667	31306	Business	9900.00
0005433450230	31306	Economy	3300.00
0005432383773	31306	Economy	3300.00
0005432383656	31306	Economy	3300.00
0005432383695	31306	Economy	3300.00
0005433450334	31306	Economy	3300.00
0005432383679	31306	Economy	3300.00
0005432383636	31306	Economy	3300.00
0005432383654	31306	Economy	3600.00
0005433453789	31306	Economy	3600.00
0005432383831	31306	Economy	3600.00
0005433450289	31306	Economy	3300.00
0005432383723	31306	Economy	3300.00
0005433453792	31306	Economy	3300.00
0005433450357	31306	Economy	3300.00
0005432383557	31306	Economy	3300.00
0005432383693	31306	Economy	3300.00
0005433450252	31306	Economy	3300.00
0005433450287	31306	Economy	3300.00
0005433451652	31306	Economy	3300.00
0005432383563	31306	Economy	3300.00
0005432383666	31306	Economy	3300.00
0005432383624	31306	Economy	3300.00
0005432383810	31306	Economy	3300.00
0005433453800	31306	Economy	3300.00
0005433453798	31306	Economy	3300.00
0005433450314	31306	Economy	3300.00
0005432383678	31306	Economy	3300.00
0005432383711	31306	Economy	3300.00
0005432383803	31306	Economy	3300.00
0005432383681	31306	Economy	3300.00
0005432383701	31306	Economy	3300.00
0005433450237	31306	Economy	3300.00
0005432383684	31306	Economy	3300.00
0005433450286	31306	Economy	3300.00
0005432383611	31306	Economy	3300.00
0005432383718	31306	Economy	3300.00
0005433453799	31306	Economy	3300.00
0005432383609	31306	Economy	3300.00
0005432383705	31306	Economy	3300.00
0005432383635	31306	Economy	3300.00
0005432383677	31306	Economy	3300.00
0005433450335	31306	Economy	3300.00
0005432383558	31306	Economy	3300.00
0005432383548	31306	Economy	3300.00
0005432383610	31306	Economy	3300.00
0005433450253	31306	Economy	3300.00
0005433450316	31306	Economy	3300.00
0005433450288	31306	Economy	3300.00
0005432383588	31306	Economy	3300.00
0005433450285	31306	Economy	3300.00
0005432383612	31306	Economy	3300.00
0005432383589	31306	Economy	3300.00
0005432383623	31306	Economy	3300.00
0005435299842	10759	Economy	17100.00
0005435299841	10759	Economy	15600.00
0005435299838	10759	Economy	15600.00
0005433126912	10759	Economy	15600.00
0005433126901	10759	Economy	15600.00
0005433126911	10759	Economy	15600.00
0005433131753	10759	Economy	15600.00
0005435299846	10759	Economy	15600.00
0005435299835	10759	Economy	15600.00
0005433131786	10759	Economy	15600.00
0005435302315	29726	Economy	17100.00
0005435299891	29726	Economy	17100.00
0005435299890	29726	Economy	15600.00
0005435299894	29726	Economy	15600.00
0005433129387	29726	Economy	15600.00
0005435299893	29726	Economy	15600.00
0005435302316	29726	Economy	15600.00
0005433126956	29726	Economy	15600.00
0005435302314	29726	Economy	15600.00
0005435302312	29726	Economy	15600.00
0005435299892	29726	Economy	15600.00
0005433129389	29726	Economy	15600.00
0005433129386	29726	Economy	15600.00
0005433129390	29726	Economy	15600.00
0005433126957	29726	Economy	15600.00
0005433129388	29726	Economy	15600.00
0005435302313	29726	Economy	15600.00
0005434287818	2387	Economy	17200.00
0005434287810	2387	Economy	17200.00
0005433110235	2387	Economy	17200.00
0005434287823	2387	Economy	15700.00
0005432264533	2387	Economy	15700.00
0005433110239	2387	Economy	15700.00
0005434287806	2387	Economy	15700.00
0005433110275	2387	Economy	15700.00
0005434287816	2387	Economy	15700.00
0005433110272	2387	Economy	15700.00
0005434287808	2387	Economy	15700.00
0005433110190	2387	Economy	15700.00
0005434287820	2387	Economy	15700.00
0005434287817	2387	Economy	15700.00
0005434287803	2387	Economy	15700.00
0005434287821	2387	Economy	15700.00
0005434287811	2387	Economy	15700.00
0005434287824	2387	Economy	15700.00
0005434287815	2387	Economy	15700.00
0005434287807	2387	Economy	15700.00
0005434287805	2387	Economy	15700.00
0005434287809	2387	Economy	15700.00
0005434287812	2387	Economy	15700.00
0005434287813	2387	Economy	15700.00
0005432264534	2387	Economy	15700.00
0005434287804	2387	Economy	15700.00
0005434287819	2387	Economy	15700.00
0005434287814	2387	Economy	15700.00
0005433110221	2387	Economy	15700.00
0005432264532	2387	Economy	15700.00
0005434287822	2387	Economy	15700.00
0005433110238	2387	Economy	15700.00
0005434287561	26877	Economy	17200.00
0005433110342	26877	Economy	15700.00
0005433110338	26877	Economy	15700.00
0005434287531	26877	Economy	15700.00
0005434287692	26877	Economy	15700.00
0005433110336	26877	Economy	15700.00
0005434287676	26877	Economy	15700.00
0005433110345	26877	Economy	15700.00
0005434287544	26877	Economy	15700.00
0005434287640	26877	Economy	15700.00
0005434287562	26877	Economy	15700.00
0005433110341	26877	Economy	15700.00
0005433110343	26877	Economy	15700.00
0005434287677	26877	Economy	15700.00
0005434287593	26877	Economy	15700.00
0005433110339	26877	Economy	15700.00
0005434287626	26877	Economy	15700.00
0005434287579	26877	Economy	15700.00
0005433110334	26877	Economy	15700.00
0005433110340	26877	Economy	15700.00
0005434287623	26877	Economy	15700.00
0005434287622	26877	Economy	15700.00
0005434287634	26877	Economy	15700.00
0005434287581	26877	Economy	15700.00
0005434287607	26877	Economy	15700.00
0005433110337	26877	Economy	15700.00
0005434287693	26877	Economy	15700.00
0005433110344	26877	Economy	15700.00
0005434287513	26877	Economy	15700.00
0005433110335	26877	Economy	15700.00
0005434287560	26877	Economy	15700.00
0005434287625	26877	Economy	15700.00
0005434287647	26877	Economy	15700.00
0005434287543	26877	Economy	15700.00
0005434287582	26877	Economy	15700.00
0005434269140	25479	Economy	25000.00
0005435856339	25479	Economy	25000.00
0005435856305	25479	Economy	25000.00
0005435856340	25479	Economy	22800.00
0005434269131	25479	Economy	22800.00
0005435856338	25479	Economy	22800.00
0005434272211	25479	Economy	22800.00
0005435856306	25479	Economy	22800.00
0005435856337	25479	Economy	22800.00
0005434272212	25479	Economy	22800.00
0005435856304	25479	Economy	22800.00
0005434272226	26653	Economy	25000.00
0005434273113	26653	Economy	22800.00
0005435856251	26653	Economy	22800.00
0005435856265	26653	Economy	22800.00
0005435856266	26653	Economy	22800.00
0005435856282	26653	Economy	22800.00
0005434273114	26653	Economy	22800.00
0005433651016	7166	Business	89800.00
0005433650983	7166	Business	89800.00
0005435263712	7166	Business	89800.00
0005433651023	7166	Business	89800.00
0005433650999	7166	Business	89800.00
0005435263697	7166	Business	89800.00
0005433650989	7166	Business	89800.00
0005435263701	7166	Business	89800.00
0005433651006	7166	Business	89800.00
0005433650978	7166	Economy	29900.00
0005433651014	7166	Economy	29900.00
0005433650980	7166	Economy	29900.00
0005433651005	7166	Economy	29900.00
0005433650998	7166	Economy	29900.00
0005435263708	7166	Economy	29900.00
0005435263704	7166	Economy	29900.00
0005433650993	7166	Economy	32900.00
0005435263751	7166	Economy	32900.00
0005433651022	7166	Economy	32900.00
0005433651002	7166	Economy	32900.00
0005433650982	7166	Economy	29900.00
0005435263685	7166	Economy	29900.00
0005433651019	7166	Economy	29900.00
0005433650995	7166	Economy	29900.00
0005433651008	7166	Economy	29900.00
0005435263753	7166	Economy	29900.00
0005433651011	7166	Economy	29900.00
0005433650988	7166	Economy	29900.00
0005433651013	7166	Economy	29900.00
0005435263738	7166	Economy	29900.00
0005433650986	7166	Economy	29900.00
0005433651012	7166	Economy	29900.00
0005433651020	7166	Economy	29900.00
0005435263713	7166	Economy	29900.00
0005433651007	7166	Economy	29900.00
0005433650985	7166	Economy	29900.00
0005433650992	7166	Economy	29900.00
0005433651004	7166	Economy	29900.00
0005433650979	7166	Economy	29900.00
0005433651009	7166	Economy	29900.00
0005433650981	7166	Economy	29900.00
0005435263684	7166	Economy	29900.00
0005435263698	7166	Economy	29900.00
0005433651000	7166	Economy	29900.00
0005433650990	7166	Economy	29900.00
0005433651018	7166	Economy	29900.00
0005433650991	7166	Economy	29900.00
0005435263737	7166	Economy	29900.00
0005433651015	7166	Economy	29900.00
0005435263752	7166	Economy	29900.00
0005433650994	7166	Economy	29900.00
0005433650987	7166	Economy	29900.00
0005433650996	7166	Economy	29900.00
0005433651001	7166	Economy	29900.00
0005433651024	7166	Economy	29900.00
0005433651010	7166	Economy	29900.00
0005433650997	7166	Economy	29900.00
0005433650984	7166	Economy	29900.00
0005435263699	7166	Economy	29900.00
0005435263710	7166	Economy	29900.00
0005435263750	7166	Economy	29900.00
0005433651021	7166	Economy	29900.00
0005433651025	7166	Economy	29900.00
0005433651003	7166	Economy	29900.00
0005435263722	7166	Economy	29900.00
0005435263746	7166	Economy	29900.00
0005435263767	7166	Economy	29900.00
0005433651017	7166	Economy	29900.00
0005433869382	4755	Economy	19400.00
0005433869401	4755	Economy	19400.00
0005435860514	4755	Economy	19400.00
0005433869397	4755	Economy	17600.00
0005433869393	4755	Economy	17600.00
0005433869366	4755	Economy	17600.00
0005433869380	4755	Economy	17600.00
0005433869384	4755	Economy	17600.00
0005433869376	4755	Economy	17600.00
0005433869390	4755	Economy	17600.00
0005433869369	4755	Economy	17600.00
0005433869377	4755	Economy	17600.00
0005433869370	4755	Economy	17600.00
0005433869399	4755	Economy	17600.00
0005433869373	4755	Economy	17600.00
0005433869372	4755	Economy	17600.00
0005433869388	4755	Economy	17600.00
0005433869381	4755	Economy	17600.00
0005433869367	4755	Economy	17600.00
0005433869398	4755	Economy	17600.00
0005433869394	4755	Economy	17600.00
0005433869386	4755	Economy	17600.00
0005435860515	4755	Economy	17600.00
0005433869404	4755	Economy	17600.00
0005433869385	4755	Economy	17600.00
0005433869375	4755	Economy	17600.00
0005433869374	4755	Economy	17600.00
0005433869387	4755	Economy	17600.00
0005433869389	4755	Economy	17600.00
0005433869368	4755	Economy	17600.00
0005433869395	4755	Economy	17600.00
0005433869396	4755	Economy	17600.00
0005433869379	4755	Economy	17600.00
0005433869402	4755	Economy	17600.00
0005433869371	4755	Economy	17600.00
0005433869391	4755	Economy	17600.00
0005433869403	4755	Economy	17600.00
0005433869383	4755	Economy	17600.00
0005433869378	4755	Economy	17600.00
0005433869392	4755	Economy	17600.00
0005433869400	4755	Economy	17600.00
0005433868912	32571	Economy	19400.00
0005433868983	32571	Economy	19400.00
0005433868854	32571	Economy	19400.00
0005433868870	32571	Economy	19400.00
0005433869024	32571	Economy	17600.00
0005433868952	32571	Economy	17600.00
0005433869088	32571	Economy	17600.00
0005433869039	32571	Economy	17600.00
0005433868909	32571	Economy	17600.00
0005433868988	32571	Economy	17600.00
0005433868972	32571	Economy	17600.00
0005433868924	32571	Economy	17600.00
0005433868826	32571	Economy	17600.00
0005433868787	32571	Economy	17600.00
0005433868970	32571	Economy	17600.00
0005433869069	32571	Economy	17600.00
0005433868932	32571	Economy	17600.00
0005433868880	32571	Economy	17600.00
0005433869106	32571	Economy	17600.00
0005433868944	32571	Economy	17600.00
0005433869107	32571	Economy	17600.00
0005433868948	32571	Economy	17600.00
0005433868911	32571	Economy	17600.00
0005433869087	32571	Economy	17600.00
0005433868730	32571	Economy	17600.00
0005433869040	32571	Economy	17600.00
0005433869023	32571	Economy	17600.00
0005433868910	32571	Economy	17600.00
0005433868881	32571	Economy	17600.00
0005433869079	32571	Economy	17600.00
0005433868731	32571	Economy	17600.00
0005433869120	32571	Economy	17600.00
0005433869082	32571	Economy	17600.00
0005433869012	32571	Economy	17600.00
0005433868883	32571	Economy	17600.00
0005433868770	32571	Economy	17600.00
0005433868942	32571	Economy	17600.00
0005433868871	32571	Economy	17600.00
0005433868971	32571	Economy	17600.00
0005433868987	32571	Economy	17600.00
0005433868913	32571	Economy	17600.00
0005433869005	32571	Economy	17600.00
0005433869022	32571	Economy	17600.00
0005433868798	32571	Economy	17600.00
0005433869041	32571	Economy	17600.00
0005433869076	32571	Economy	17600.00
0005433869068	32571	Economy	17600.00
0005433869021	32571	Economy	17600.00
0005433869062	32571	Economy	17600.00
0005433869013	32571	Economy	17600.00
0005434663726	3425	Economy	24800.00
0005434663731	3425	Economy	22600.00
0005434663732	3425	Economy	22600.00
0005434460558	3425	Economy	22600.00
0005434663734	3425	Economy	22600.00
0005434663729	3425	Economy	22600.00
0005435911559	3425	Economy	22600.00
0005434663723	3425	Economy	22600.00
0005434663727	3425	Economy	22600.00
0005435911560	3425	Economy	22600.00
0005434663730	3425	Economy	22600.00
0005434663728	3425	Economy	22600.00
0005434460557	3425	Economy	22600.00
0005434663725	3425	Economy	22600.00
0005434460559	3425	Economy	22600.00
0005434461697	3425	Economy	22600.00
0005434663735	3425	Economy	22600.00
0005434461698	3425	Economy	22600.00
0005434663724	3425	Economy	22600.00
0005434663736	3425	Economy	22600.00
0005434663733	3425	Economy	22600.00
0005435911563	3425	Economy	22600.00
0005435911635	12458	Economy	24800.00
0005435911632	12458	Economy	24800.00
0005434663649	12458	Economy	22600.00
0005434663613	12458	Economy	22600.00
0005434663595	12458	Economy	22600.00
0005435911629	12458	Economy	22600.00
0005435911631	12458	Economy	22600.00
0005435911634	12458	Economy	22600.00
0005434663617	12458	Economy	22600.00
0005435911630	12458	Economy	22600.00
0005434663598	12458	Economy	22600.00
0005435911633	12458	Economy	22600.00
0005434663671	12458	Economy	22600.00
0005434663586	12458	Economy	22600.00
0005434663618	12458	Economy	22600.00
0005435911636	12458	Economy	22600.00
0005433869040	14474	Economy	18500.00
0005433868987	14474	Economy	18500.00
0005433869024	14474	Economy	18500.00
0005433868911	14474	Economy	18500.00
0005433869023	14474	Economy	16800.00
0005433868871	14474	Economy	16800.00
0005433868770	14474	Economy	16800.00
0005433869106	14474	Economy	16800.00
0005433868826	14474	Economy	16800.00
0005433868912	14474	Economy	16800.00
0005433869068	14474	Economy	16800.00
0005433868909	14474	Economy	16800.00
0005433869041	14474	Economy	16800.00
0005433869039	14474	Economy	16800.00
0005433868944	14474	Economy	16800.00
0005433869088	14474	Economy	16800.00
0005433869120	14474	Economy	16800.00
0005433868952	14474	Economy	16800.00
0005433869107	14474	Economy	16800.00
0005433868971	14474	Economy	16800.00
0005433868970	14474	Economy	16800.00
0005433868948	14474	Economy	16800.00
0005433868787	14474	Economy	16800.00
0005433868988	14474	Economy	16800.00
0005433869013	14474	Economy	16800.00
0005433868924	14474	Economy	16800.00
0005433869062	14474	Economy	16800.00
0005433868883	14474	Economy	16800.00
0005433868932	14474	Economy	16800.00
0005433868731	14474	Economy	16800.00
0005433869082	14474	Economy	16800.00
0005433868870	14474	Economy	16800.00
0005433869021	14474	Economy	16800.00
0005433868730	14474	Economy	16800.00
0005433869079	14474	Economy	16800.00
0005433868798	14474	Economy	16800.00
0005433868881	14474	Economy	16800.00
0005433869069	14474	Economy	16800.00
0005433868880	14474	Economy	16800.00
0005433869005	14474	Economy	16800.00
0005433868942	14474	Economy	16800.00
0005433868972	14474	Economy	16800.00
0005433869012	14474	Economy	16800.00
0005433869087	14474	Economy	16800.00
0005433869076	14474	Economy	16800.00
0005433869022	14474	Economy	16800.00
0005433868910	14474	Economy	16800.00
0005433868854	14474	Economy	16800.00
0005433868983	14474	Economy	16800.00
0005433868913	14474	Economy	16800.00
0005433869348	32648	Economy	18500.00
0005433869339	32648	Economy	18500.00
0005433869336	32648	Economy	18500.00
0005433869330	32648	Economy	18500.00
0005433869329	32648	Economy	16800.00
0005433869354	32648	Economy	16800.00
0005433869360	32648	Economy	16800.00
0005433869328	32648	Economy	16800.00
0005433869358	32648	Economy	16800.00
0005433869347	32648	Economy	16800.00
0005433869359	32648	Economy	16800.00
0005433869356	32648	Economy	16800.00
0005433869349	32648	Economy	16800.00
0005433869325	32648	Economy	16800.00
0005433869342	32648	Economy	16800.00
0005433869351	32648	Economy	16800.00
0005433869350	32648	Economy	16800.00
0005433869355	32648	Economy	16800.00
0005433869333	32648	Economy	16800.00
0005433869332	32648	Economy	16800.00
0005433869324	32648	Economy	16800.00
0005433869344	32648	Economy	16800.00
0005435860531	32648	Economy	16800.00
0005433869352	32648	Economy	16800.00
0005433869326	32648	Economy	16800.00
0005433869362	32648	Economy	16800.00
0005433869341	32648	Economy	16800.00
0005433869365	32648	Economy	16800.00
0005433869346	32648	Economy	16800.00
0005433869338	32648	Economy	16800.00
0005433869343	32648	Economy	16800.00
0005433869361	32648	Economy	16800.00
0005433869364	32648	Economy	16800.00
0005433869334	32648	Economy	16800.00
0005433869331	32648	Economy	16800.00
0005433869340	32648	Economy	16800.00
0005433869357	32648	Economy	16800.00
0005433869345	32648	Economy	16800.00
0005433869337	32648	Economy	16800.00
0005433869327	32648	Economy	16800.00
0005433869363	32648	Economy	16800.00
0005433869335	32648	Economy	16800.00
0005433869353	32648	Economy	16800.00
0005435860540	32648	Economy	16800.00
0005435860532	32648	Economy	16800.00
0005432799915	12126	Economy	4900.00
0005432799908	12126	Economy	4400.00
0005432799903	12126	Economy	4400.00
0005432799983	12126	Economy	4400.00
0005432799781	12126	Economy	4400.00
0005432799883	12126	Economy	4400.00
0005432799882	12126	Economy	4400.00
0005432799916	12126	Economy	4400.00
0005432799981	12126	Economy	4400.00
0005432799970	12126	Economy	4400.00
0005432799780	12126	Economy	4400.00
0005432799969	12126	Economy	4400.00
0005432799935	12126	Economy	4400.00
0005432799762	12126	Economy	4400.00
0005432799938	12126	Economy	4400.00
0005432799867	12126	Economy	4400.00
0005432799909	12126	Economy	4400.00
0005432799922	12126	Economy	4400.00
0005432799721	12126	Economy	4400.00
0005432799901	12126	Economy	4400.00
0005432799933	12126	Economy	4400.00
0005432799936	12126	Economy	4400.00
0005432799808	12126	Economy	4400.00
0005432799902	12126	Economy	4400.00
0005432799722	12126	Economy	4400.00
0005432799911	12126	Economy	4400.00
0005432799720	12126	Economy	4400.00
0005432799956	12126	Economy	4400.00
0005432799982	12126	Economy	4400.00
0005432800102	14804	Economy	4900.00
0005432800100	14804	Economy	4400.00
0005432800081	14804	Economy	4400.00
0005432800083	14804	Economy	4400.00
0005432800086	14804	Economy	4400.00
0005432800091	14804	Economy	4400.00
0005432800085	14804	Economy	4400.00
0005432800082	14804	Economy	4400.00
0005432800104	14804	Economy	4400.00
0005432800087	14804	Economy	4400.00
0005432800098	14804	Economy	4400.00
0005432800101	14804	Economy	4400.00
0005432800090	14804	Economy	4400.00
0005432800097	14804	Economy	4400.00
0005432800089	14804	Economy	4400.00
0005432800099	14804	Economy	4400.00
0005432800084	14804	Economy	4400.00
0005432800093	14804	Economy	4400.00
0005432800105	14804	Economy	4400.00
0005432800107	14804	Economy	4400.00
0005432800103	14804	Economy	4400.00
0005432800109	14804	Economy	4400.00
0005432800094	14804	Economy	4400.00
0005432800108	14804	Economy	4400.00
0005432800088	14804	Economy	4400.00
0005432800092	14804	Economy	4400.00
0005432800096	14804	Economy	4400.00
0005432800095	14804	Economy	4400.00
0005432800106	14804	Economy	4400.00
0005434409256	7045	Business	49100.00
0005434409238	7045	Business	49100.00
0005434409233	7045	Business	49100.00
0005434409271	7045	Business	49100.00
0005434409280	7045	Business	49100.00
0005434300100	7045	Business	49100.00
0005434300116	7045	Business	49100.00
0005434409257	7045	Business	49100.00
0005434409266	7045	Business	49100.00
0005434409270	7045	Business	49100.00
0005434409250	7045	Business	49100.00
0005434409232	7045	Business	49100.00
0005434300102	7045	Economy	16400.00
0005434300115	7045	Economy	16400.00
0005435311229	7045	Economy	16400.00
0005434300117	7045	Economy	16400.00
0005434409222	7045	Economy	16400.00
0005435311236	7045	Economy	16400.00
0005435293443	7045	Economy	16400.00
0005432154103	7045	Economy	16400.00
0005434300108	7045	Economy	16400.00
0005435293469	7045	Economy	16400.00
0005434409237	7045	Economy	16400.00
0005432108311	7045	Economy	16400.00
0005434409281	7045	Economy	16400.00
0005434409261	7045	Economy	16400.00
0005434409242	7045	Economy	16400.00
0005432154105	7045	Economy	16400.00
0005432154107	7045	Economy	16400.00
0005435293487	7045	Economy	16400.00
0005435293460	7045	Economy	16400.00
0005435311216	7045	Economy	16400.00
0005434409268	7045	Economy	16400.00
0005434409276	7045	Economy	16400.00
0005434300122	7045	Economy	16400.00
0005434409221	7045	Economy	16400.00
0005435293461	7045	Economy	16400.00
0005432154101	7045	Economy	16400.00
0005434409260	7045	Economy	16400.00
0005434300118	7045	Economy	16400.00
0005434409254	7045	Economy	16400.00
0005434409278	7045	Economy	16400.00
0005432108312	7045	Economy	16400.00
0005434409245	7045	Economy	16400.00
0005434409230	7045	Economy	16400.00
0005435293451	7045	Economy	16400.00
0005434409282	7045	Economy	16400.00
0005435293472	7045	Economy	16400.00
0005434300101	7045	Economy	16400.00
0005435293452	7045	Economy	16400.00
0005434409264	7045	Economy	16400.00
0005434409223	7045	Economy	16400.00
0005434300114	7045	Economy	18000.00
0005434409267	7045	Economy	18000.00
0005432154100	7045	Economy	18000.00
0005432154106	7045	Economy	18000.00
0005434409279	7045	Economy	18000.00
0005434409252	7045	Economy	18000.00
0005435311210	7045	Economy	16400.00
0005434409226	7045	Economy	16400.00
0005434409273	7045	Economy	16400.00
0005434409247	7045	Economy	16400.00
0005434300121	7045	Economy	16400.00
0005432154104	7045	Economy	16400.00
0005434300105	7045	Economy	16400.00
0005432154102	7045	Economy	16400.00
0005435311225	7045	Economy	16400.00
0005435311224	7045	Economy	16400.00
0005434409274	7045	Economy	16400.00
0005434409269	7045	Economy	16400.00
0005435293430	7045	Economy	16400.00
0005435293400	7045	Economy	16400.00
0005434300119	7045	Economy	16400.00
0005434300113	7045	Economy	16400.00
0005434409229	7045	Economy	16400.00
0005435293450	7045	Economy	16400.00
0005434409272	7045	Economy	16400.00
0005435311217	7045	Economy	16400.00
0005435293477	7045	Economy	16400.00
0005435293442	7045	Economy	16400.00
0005434300123	7045	Economy	16400.00
0005435311190	7045	Economy	16400.00
0005435311182	7045	Economy	16400.00
0005434409251	7045	Economy	16400.00
0005434409225	7045	Economy	16400.00
0005434409224	7045	Economy	16400.00
0005434409236	7045	Economy	16400.00
0005434409228	7045	Economy	16400.00
0005435293462	7045	Economy	16400.00
0005434300106	7045	Economy	16400.00
0005434300107	7045	Economy	16400.00
0005434409244	7045	Economy	16400.00
0005434300112	7045	Economy	16400.00
0005435311234	7045	Economy	16400.00
0005434409240	7045	Economy	16400.00
0005434409243	7045	Economy	16400.00
0005434409258	7045	Economy	16400.00
0005435311223	7045	Economy	16400.00
0005434300099	7045	Economy	16400.00
0005434300110	7045	Economy	16400.00
0005434409241	7045	Economy	16400.00
0005434409249	7045	Economy	16400.00
0005434300120	7045	Economy	16400.00
0005434300109	7045	Economy	16400.00
0005434409248	7045	Economy	16400.00
0005434409259	7045	Economy	16400.00
0005434409227	7045	Economy	16400.00
0005434409235	7045	Economy	16400.00
0005434409234	7045	Economy	16400.00
0005435311222	7045	Economy	16400.00
0005434409277	7045	Economy	16400.00
0005434409275	7045	Economy	16400.00
0005434300103	7045	Economy	16400.00
0005434409246	7045	Economy	16400.00
0005434409262	7045	Economy	16400.00
0005434409231	7045	Economy	16400.00
0005434409253	7045	Economy	16400.00
0005435311235	7045	Economy	16400.00
0005434409265	7045	Economy	16400.00
0005434300104	7045	Economy	16400.00
0005434409255	7045	Economy	16400.00
0005434409263	7045	Economy	16400.00
0005434300111	7045	Economy	16400.00
0005432154108	7045	Economy	16400.00
0005434409239	7045	Economy	16400.00
0005435311211	7045	Economy	16400.00
0005434408748	26932	Business	49100.00
0005434408730	26932	Business	49100.00
0005435311405	26932	Business	49100.00
0005434408852	26932	Business	49100.00
0005434408531	26932	Business	49100.00
0005434408655	26932	Business	49100.00
0005434408686	26932	Business	49100.00
0005434408883	26932	Business	49100.00
0005434408328	26932	Business	49100.00
0005434300021	26932	Business	49100.00
0005434300000	26932	Business	49100.00
0005432058470	26932	Economy	16400.00
0005435311415	26932	Economy	16400.00
0005435293546	26932	Economy	16400.00
0005434408649	26932	Economy	16400.00
0005434408355	26932	Economy	16400.00
0005435311402	26932	Economy	16400.00
0005434408433	26932	Economy	16400.00
0005434408564	26932	Economy	16400.00
0005435311411	26932	Economy	16400.00
0005435311394	26932	Economy	16400.00
0005435311388	26932	Economy	16400.00
0005435311395	26932	Economy	16400.00
0005435311409	26932	Economy	16400.00
0005435311390	26932	Economy	16400.00
0005434408627	26932	Economy	16400.00
0005434408446	26932	Economy	16400.00
0005434299904	26932	Economy	16400.00
0005434408495	26932	Economy	16400.00
0005434299925	26932	Economy	16400.00
0005434299999	26932	Economy	16400.00
0005434408458	26932	Economy	16400.00
0005434408749	26932	Economy	16400.00
0005434299860	26932	Economy	16400.00
0005435311413	26932	Economy	16400.00
0005434408650	26932	Economy	16400.00
0005434408706	26932	Economy	16400.00
0005434408666	26932	Economy	16400.00
0005434408651	26932	Economy	16400.00
0005435293552	26932	Economy	16400.00
0005434408702	26932	Economy	16400.00
0005435311403	26932	Economy	16400.00
0005434299803	26932	Economy	16400.00
0005432058473	26932	Economy	16400.00
0005435311393	26932	Economy	16400.00
0005434408729	26932	Economy	16400.00
0005434408312	26932	Economy	16400.00
0005434408815	26932	Economy	16400.00
0005434408652	26932	Economy	18000.00
0005435311401	26932	Economy	18000.00
0005434300001	26932	Economy	18000.00
0005434408914	26932	Economy	18000.00
0005435311406	26932	Economy	18000.00
0005434408884	26932	Economy	16400.00
0005435311408	26932	Economy	18000.00
0005435311419	26932	Economy	16400.00
0005435311420	26932	Economy	16400.00
0005434408543	26932	Economy	16400.00
0005435311400	26932	Economy	16400.00
0005434299905	26932	Economy	16400.00
0005434408924	26932	Economy	16400.00
0005435293553	26932	Economy	16400.00
0005434408514	26932	Economy	16400.00
0005432058474	26932	Economy	16400.00
0005434408574	26932	Economy	16400.00
0005435293551	26932	Economy	16400.00
0005435311421	26932	Economy	16400.00
0005434408703	26932	Economy	16400.00
0005434408229	26932	Economy	16400.00
0005434299834	26932	Economy	16400.00
0005435311412	26932	Economy	16400.00
0005435311414	26932	Economy	16400.00
0005435311397	26932	Economy	16400.00
0005435311387	26932	Economy	16400.00
0005434299804	26932	Economy	16400.00
0005435293545	26932	Economy	16400.00
0005434299815	26932	Economy	16400.00
0005434408459	26932	Economy	16400.00
0005434299920	26932	Economy	16400.00
0005435293547	26932	Economy	16400.00
0005434299948	26932	Economy	16400.00
0005435311410	26932	Economy	16400.00
0005435311391	26932	Economy	16400.00
0005434408669	26932	Economy	16400.00
0005434299903	26932	Economy	16400.00
0005434408851	26932	Economy	16400.00
0005435311398	26932	Economy	16400.00
0005435293554	26932	Economy	16400.00
0005435293549	26932	Economy	16400.00
0005432058472	26932	Economy	16400.00
0005434408228	26932	Economy	16400.00
0005434408640	26932	Economy	16400.00
0005434299839	26932	Economy	16400.00
0005435311404	26932	Economy	16400.00
0005432058471	26932	Economy	16400.00
0005435293548	26932	Economy	16400.00
0005434408626	26932	Economy	16400.00
0005434408544	26932	Economy	16400.00
0005434299967	26932	Economy	16400.00
0005434408610	26932	Economy	16400.00
0005434408781	26932	Economy	16400.00
0005435311417	26932	Economy	16400.00
0005434299880	26932	Economy	16400.00
0005435311418	26932	Economy	16400.00
0005435311416	26932	Economy	16400.00
0005435293550	26932	Economy	16400.00
0005434299949	26932	Economy	16400.00
0005434408460	26932	Economy	16400.00
0005434299957	26932	Economy	16400.00
0005434299833	26932	Economy	16400.00
0005434408604	26932	Economy	16400.00
0005435311389	26932	Economy	16400.00
0005435311399	26932	Economy	16400.00
0005435311407	26932	Economy	16400.00
0005434408492	26932	Economy	16400.00
0005434299956	26932	Economy	16400.00
0005434299919	26932	Economy	16400.00
0005434408925	26932	Economy	16400.00
0005434408747	26932	Economy	16400.00
0005435293544	26932	Economy	16400.00
0005435311396	26932	Economy	16400.00
0005435311392	26932	Economy	16400.00
0005435293543	26932	Economy	16400.00
0005434408625	26932	Economy	16400.00
0005432605296	6475	Economy	16500.00
0005432605271	6475	Economy	16500.00
0005432605265	6475	Economy	15000.00
0005434512226	6475	Economy	15000.00
0005432605275	6475	Economy	15000.00
0005432605282	6475	Economy	15000.00
0005432605269	6475	Economy	15000.00
0005434512225	6475	Economy	15000.00
0005432605280	6475	Economy	15000.00
0005432605300	6475	Economy	15000.00
0005432605273	6475	Economy	15000.00
0005432605267	6475	Economy	15000.00
0005432605276	6475	Economy	15000.00
0005432605283	6475	Economy	15000.00
0005432605291	6475	Economy	15000.00
0005432605295	6475	Economy	15000.00
0005432605278	6475	Economy	15000.00
0005432605292	6475	Economy	15000.00
0005432605290	6475	Economy	15000.00
0005432605293	6475	Economy	15000.00
0005432605279	6475	Economy	15000.00
0005432605297	6475	Economy	15000.00
0005432605270	6475	Economy	15000.00
0005432605284	6475	Economy	15000.00
0005432605266	6475	Economy	15000.00
0005432605281	6475	Economy	15000.00
0005432605288	6475	Economy	15000.00
0005432605294	6475	Economy	15000.00
0005432605277	6475	Economy	15000.00
0005432605274	6475	Economy	15000.00
0005432605268	6475	Economy	15000.00
0005432605289	6475	Economy	15000.00
0005432605285	6475	Economy	15000.00
0005432605287	6475	Economy	15000.00
0005432605286	6475	Economy	15000.00
0005432605298	6475	Economy	15000.00
0005432605272	6475	Economy	15000.00
0005432605299	6475	Economy	15000.00
0005432604848	21354	Economy	16500.00
0005432604909	21354	Economy	16500.00
0005432604953	21354	Economy	16500.00
0005432604841	21354	Economy	16500.00
0005432604866	21354	Economy	15000.00
0005432604966	21354	Economy	15000.00
0005432604865	21354	Economy	15000.00
0005435221076	21354	Economy	15000.00
0005432604784	21354	Economy	15000.00
0005432604835	21354	Economy	15000.00
0005432604908	21354	Economy	15000.00
0005432604927	21354	Economy	15000.00
0005432604985	21354	Economy	15000.00
0005432604839	21354	Economy	15000.00
0005432604965	21354	Economy	15000.00
0005432604858	21354	Economy	15000.00
0005432604951	21354	Economy	15000.00
0005432604937	21354	Economy	15000.00
0005432604876	21354	Economy	15000.00
0005432604825	21354	Economy	15000.00
0005432604829	21354	Economy	15000.00
0005435221075	21354	Economy	15000.00
0005432605038	21354	Economy	15000.00
0005435221077	21354	Economy	15000.00
0005432605036	21354	Economy	15000.00
0005432604811	21354	Economy	15000.00
0005432605007	21354	Economy	15000.00
0005432604950	21354	Economy	15000.00
0005432604929	21354	Economy	15000.00
0005434512207	21354	Economy	15000.00
0005432604936	21354	Economy	15000.00
0005432604932	21354	Economy	15000.00
0005432604852	21354	Economy	15000.00
0005432604794	21354	Economy	15000.00
0005432604847	21354	Economy	15000.00
0005432604759	21354	Economy	15000.00
0005432604964	21354	Economy	15000.00
0005432604931	21354	Economy	15000.00
0005432604920	21354	Economy	15000.00
0005434512177	21354	Economy	15000.00
0005432604859	21354	Economy	15000.00
0005432604842	21354	Economy	15000.00
0005432604814	21354	Economy	15000.00
0005432604843	21354	Economy	15000.00
0005432604928	21354	Economy	15000.00
0005432604846	21354	Economy	15000.00
0005434512176	21354	Economy	15000.00
0005432604930	21354	Economy	15000.00
0005432605037	21354	Economy	15000.00
0005432604824	21354	Economy	15000.00
0005434907847	14969	Business	18900.00
0005433252211	14969	Business	18900.00
0005433252219	14969	Business	18900.00
0005434907992	14969	Business	18900.00
0005433252205	14969	Business	18900.00
0005434908096	14969	Business	18900.00
0005433252214	14969	Business	18900.00
0005434907681	14969	Business	18900.00
0005434908080	14969	Business	18900.00
0005433252212	14969	Business	18900.00
0005433252193	14969	Business	18900.00
0005434907989	14969	Business	18900.00
0005434907869	14969	Economy	6300.00
0005433252210	14969	Economy	6300.00
0005434907755	14969	Economy	6300.00
0005434908084	14969	Economy	6300.00
0005434908113	14969	Economy	6300.00
0005433252195	14969	Economy	6300.00
0005434908124	14969	Economy	6300.00
0005433252222	14969	Economy	6300.00
0005433252198	14969	Economy	6900.00
0005434908092	14969	Economy	6900.00
0005434908070	14969	Economy	6900.00
0005434908099	14969	Economy	6900.00
0005434908126	14969	Economy	6300.00
0005434908053	14969	Economy	6300.00
0005434908103	14969	Economy	6300.00
0005434907963	14969	Economy	6300.00
0005434907937	14969	Economy	6300.00
0005433252204	14969	Economy	6300.00
0005434908036	14969	Economy	6300.00
0005434907920	14969	Economy	6300.00
0005434907986	14969	Economy	6300.00
0005433252218	14969	Economy	6300.00
0005433252217	14969	Economy	6300.00
0005433252207	14969	Economy	6300.00
0005434907954	14969	Economy	6300.00
0005433252201	14969	Economy	6300.00
0005434907939	14969	Economy	6300.00
0005434908107	14969	Economy	6300.00
0005434907897	14969	Economy	6300.00
0005433252194	14969	Economy	6300.00
0005433252215	14969	Economy	6300.00
0005434908090	14969	Economy	6300.00
0005434908082	14969	Economy	6300.00
0005433252200	14969	Economy	6300.00
0005434908081	14969	Economy	6300.00
0005433252196	14969	Economy	6300.00
0005434907990	14969	Economy	6300.00
0005433252209	14969	Economy	6300.00
0005434907953	14969	Economy	6300.00
0005433252197	14969	Economy	6300.00
0005434907977	14969	Economy	6300.00
0005433252220	14969	Economy	6300.00
0005433252202	14969	Economy	6300.00
0005433252192	14969	Economy	6300.00
0005433252206	14969	Economy	6300.00
0005434907846	14969	Economy	6300.00
0005434907791	14969	Economy	6300.00
0005434907991	14969	Economy	6300.00
0005434907756	14969	Economy	6300.00
0005434908046	14969	Economy	6300.00
0005434908106	14969	Economy	6300.00
0005434907993	14969	Economy	6300.00
0005434907981	14969	Economy	6300.00
0005434908091	14969	Economy	6300.00
0005433252221	14969	Economy	6300.00
0005433252213	14969	Economy	6300.00
0005434908122	14969	Economy	6300.00
0005434908060	14969	Economy	6300.00
0005433252199	14969	Economy	6300.00
0005434907828	14969	Economy	6300.00
0005434907955	14969	Economy	6300.00
0005434907910	14969	Economy	6300.00
0005433252203	14969	Economy	6300.00
0005433252208	14969	Economy	6300.00
0005434907773	14969	Economy	6300.00
0005434908054	14969	Economy	6300.00
0005434908123	14969	Economy	6300.00
0005434907931	14969	Economy	6300.00
0005434907938	14969	Economy	6300.00
0005433252216	14969	Economy	6300.00
0005434908061	14969	Economy	6300.00
0005434907754	14969	Economy	6300.00
0005434907988	14969	Economy	6300.00
0005434907973	14969	Economy	6300.00
0005434907982	14969	Economy	6300.00
0005434908039	14969	Economy	6300.00
0005434908114	14969	Economy	6300.00
0005433252019	25832	Business	18900.00
0005433251928	25832	Business	18900.00
0005434908454	25832	Business	18900.00
0005433251834	25832	Business	18900.00
0005434908459	25832	Business	18900.00
0005433251914	25832	Business	18900.00
0005434908453	25832	Business	18900.00
0005433251996	25832	Business	18900.00
0005434908457	25832	Business	18900.00
0005434908460	25832	Business	18900.00
0005434908501	25832	Business	18900.00
0005434908502	25832	Economy	6300.00
0005433251833	25832	Economy	6300.00
0005434908490	25832	Economy	6300.00
0005433251850	25832	Economy	6300.00
0005434908487	25832	Economy	6300.00
0005433252070	25832	Economy	6300.00
0005433251878	25832	Economy	6300.00
0005434908455	25832	Economy	6300.00
0005434908500	25832	Economy	6300.00
0005433251944	25832	Economy	6300.00
0005434908488	25832	Economy	6900.00
0005433251852	25832	Economy	6900.00
0005433251839	25832	Economy	6900.00
0005433251897	25832	Economy	6900.00
0005434908464	25832	Economy	6300.00
0005434908492	25832	Economy	6300.00
0005434908494	25832	Economy	6300.00
0005434908474	25832	Economy	6300.00
0005433251995	25832	Economy	6300.00
0005434908476	25832	Economy	6300.00
0005434908463	25832	Economy	6300.00
0005433251929	25832	Economy	6300.00
0005433252003	25832	Economy	6300.00
0005434908489	25832	Economy	6300.00
0005433251990	25832	Economy	6300.00
0005433252118	25832	Economy	6300.00
0005433251898	25832	Economy	6300.00
0005433251853	25832	Economy	6300.00
0005433251979	25832	Economy	6300.00
0005433251994	25832	Economy	6300.00
0005434908484	25832	Economy	6300.00
0005433251933	25832	Economy	6300.00
0005434908467	25832	Economy	6300.00
0005434908499	25832	Economy	6300.00
0005434908478	25832	Economy	6300.00
0005434908472	25832	Economy	6300.00
0005434908465	25832	Economy	6300.00
0005434908458	25832	Economy	6300.00
0005434908461	25832	Economy	6300.00
0005433251737	25832	Economy	6300.00
0005433251934	25832	Economy	6300.00
0005433251924	25832	Economy	6300.00
0005433251932	25832	Economy	6300.00
0005433251863	25832	Economy	6300.00
0005433251946	25832	Economy	6300.00
0005434908481	25832	Economy	6300.00
0005433252020	25832	Economy	6300.00
0005434908491	25832	Economy	6300.00
0005433252071	25832	Economy	6300.00
0005434908452	25832	Economy	6300.00
0005434908473	25832	Economy	6300.00
0005434908480	25832	Economy	6300.00
0005434908497	25832	Economy	6300.00
0005433251856	25832	Economy	6300.00
0005433251854	25832	Economy	6300.00
0005434908470	25832	Economy	6300.00
0005434908486	25832	Economy	6300.00
0005434908462	25832	Economy	6300.00
0005434908485	25832	Economy	6300.00
0005434908493	25832	Economy	6300.00
0005434908503	25832	Economy	6300.00
0005433251938	25832	Economy	6300.00
0005434908495	25832	Economy	6300.00
0005434908496	25832	Economy	6300.00
0005434908451	25832	Economy	6300.00
0005433251957	25832	Economy	6300.00
0005434908498	25832	Economy	6300.00
0005434908482	25832	Economy	6300.00
0005434908466	25832	Economy	6300.00
0005434908468	25832	Economy	6300.00
0005434908475	25832	Economy	6300.00
0005434908471	25832	Economy	6300.00
0005434908477	25832	Economy	6300.00
0005434908469	25832	Economy	6300.00
0005434908483	25832	Economy	6300.00
0005434908479	25832	Economy	6300.00
0005433251851	25832	Economy	6300.00
0005434908456	25832	Economy	6300.00
0005433009681	14190	Business	52300.00
0005433810589	14190	Business	52300.00
0005433009682	14190	Business	52300.00
0005433009694	14190	Business	52300.00
0005433009704	14190	Business	52300.00
0005433009680	14190	Business	52300.00
0005433009709	14190	Business	52300.00
0005433009688	14190	Business	52300.00
0005433009706	14190	Economy	17400.00
0005433009686	14190	Economy	17400.00
0005433009687	14190	Economy	17400.00
0005433009705	14190	Economy	17400.00
0005433009711	14190	Economy	17400.00
0005433810592	14190	Economy	19200.00
0005433009679	14190	Economy	19200.00
0005433810591	14190	Economy	19200.00
0005433009690	14190	Economy	17400.00
0005433009696	14190	Economy	17400.00
0005433009710	14190	Economy	17400.00
0005433009699	14190	Economy	17400.00
0005433009693	14190	Economy	17400.00
0005433009683	14190	Economy	17400.00
0005433009685	14190	Economy	17400.00
0005433009713	14190	Economy	17400.00
0005433009717	14190	Economy	17400.00
0005433009718	14190	Economy	17400.00
0005433009708	14190	Economy	17400.00
0005433009712	14190	Economy	17400.00
0005433009714	14190	Economy	17400.00
0005433009722	14190	Economy	17400.00
0005433009721	14190	Economy	17400.00
0005433009697	14190	Economy	17400.00
0005433009698	14190	Economy	17400.00
0005433009695	14190	Economy	17400.00
0005433009691	14190	Economy	17400.00
0005433009692	14190	Economy	17400.00
0005433009719	14190	Economy	17400.00
0005433009678	14190	Economy	17400.00
0005433009701	14190	Economy	17400.00
0005433009716	14190	Economy	17400.00
0005433009700	14190	Economy	17400.00
0005433009720	14190	Economy	17400.00
0005433009707	14190	Economy	17400.00
0005433009689	14190	Economy	17400.00
0005433009702	14190	Economy	17400.00
0005433009684	14190	Economy	17400.00
0005433009715	14190	Economy	17400.00
0005433009703	14190	Economy	17400.00
0005433009723	14190	Economy	17400.00
0005433009179	22868	Business	52300.00
0005433009330	22868	Business	52300.00
0005433009125	22868	Business	52300.00
0005433009472	22868	Business	52300.00
0005433009376	22868	Business	52300.00
0005433009505	22868	Business	52300.00
0005433009389	22868	Economy	17400.00
0005433009169	22868	Economy	17400.00
0005433009126	22868	Economy	17400.00
0005433009170	22868	Economy	17400.00
0005433009301	22868	Economy	19200.00
0005433009306	22868	Economy	19200.00
0005433009445	22868	Economy	17400.00
0005433009397	22868	Economy	17400.00
0005433009244	22868	Economy	17400.00
0005433009291	22868	Economy	17400.00
0005433009241	22868	Economy	17400.00
0005433009154	22868	Economy	17400.00
0005433009180	22868	Economy	17400.00
0005433009217	22868	Economy	17400.00
0005433009240	22868	Economy	17400.00
0005433009377	22868	Economy	17400.00
0005433009127	22868	Economy	17400.00
0005433009210	22868	Economy	17400.00
0005433009196	22868	Economy	17400.00
0005433009391	22868	Economy	17400.00
0005433009287	22868	Economy	17400.00
0005433008909	22868	Economy	17400.00
0005433009428	22868	Economy	17400.00
0005433009223	22868	Economy	17400.00
0005433008908	22868	Economy	17400.00
0005433009153	22868	Economy	17400.00
0005433009504	22868	Economy	17400.00
0005433009242	22868	Economy	17400.00
0005433009199	22868	Economy	17400.00
0005433009429	22868	Economy	17400.00
0005433009367	22868	Economy	17400.00
0005433009571	22868	Economy	17400.00
0005433009278	22868	Economy	17400.00
0005433009238	22868	Economy	17400.00
0005433009243	22868	Economy	17400.00
0005433009181	22868	Economy	17400.00
0005433009028	22868	Economy	17400.00
0005433009302	22868	Economy	17400.00
0005433009239	22868	Economy	17400.00
0005433009570	22868	Economy	17400.00
0005433009358	22868	Economy	17400.00
0005433009200	22868	Economy	17400.00
0005433009000	22868	Economy	17400.00
0005433009375	22868	Economy	17400.00
0005433009390	22868	Economy	17400.00
0005433009371	22868	Economy	17400.00
0005433008999	22868	Economy	17400.00
0005433009074	22868	Economy	17400.00
0005433009329	22868	Economy	17400.00
0005433009374	22868	Economy	17400.00
0005433009271	22868	Economy	17400.00
0005433009152	22868	Economy	17400.00
0005433009328	22868	Economy	17400.00
0005434926240	14918	Business	22900.00
0005434926220	14918	Business	22900.00
0005434926221	14918	Business	22900.00
0005434926207	14918	Business	22900.00
0005434926191	14918	Business	22900.00
0005434926231	14918	Business	22900.00
0005434926238	14918	Economy	7600.00
0005434926175	14918	Economy	7600.00
0005434926120	14918	Economy	7600.00
0005434926245	14918	Economy	8400.00
0005434926174	14918	Economy	8400.00
0005434926119	14918	Economy	7600.00
0005434926294	14918	Economy	7600.00
0005434926277	14918	Economy	7600.00
0005434926267	14918	Economy	7600.00
0005434926256	14918	Economy	7600.00
0005434926198	14918	Economy	7600.00
0005434926281	14918	Economy	7600.00
0005434926251	14918	Economy	7600.00
0005434926185	14918	Economy	7600.00
0005434926192	14918	Economy	7600.00
0005434926244	14918	Economy	7600.00
0005434926255	14918	Economy	7600.00
0005434926184	14918	Economy	7600.00
0005434926202	14918	Economy	7600.00
0005434926201	14918	Economy	7600.00
0005434926197	14918	Economy	7600.00
0005434926176	14918	Economy	7600.00
0005434926252	14918	Economy	7600.00
0005434926239	14918	Economy	7600.00
0005434926182	14918	Economy	7600.00
0005434926183	14918	Economy	7600.00
0005434926544	20493	Business	22900.00
0005434926519	20493	Business	22900.00
0005434926522	20493	Business	22900.00
0005434926537	20493	Business	22900.00
0005434926543	20493	Business	22900.00
0005434926535	20493	Economy	7600.00
0005434926510	20493	Economy	7600.00
0005434926513	20493	Economy	7600.00
0005434926526	20493	Economy	7600.00
0005434926524	20493	Economy	8400.00
0005434926532	20493	Economy	8400.00
0005434926541	20493	Economy	8400.00
0005434926529	20493	Economy	7600.00
0005434926530	20493	Economy	7600.00
0005434926549	20493	Economy	7600.00
0005434926550	20493	Economy	7600.00
0005434926533	20493	Economy	7600.00
0005434926527	20493	Economy	7600.00
0005434926516	20493	Economy	7600.00
0005434926536	20493	Economy	7600.00
0005434926538	20493	Economy	7600.00
0005434926548	20493	Economy	7600.00
0005434926521	20493	Economy	7600.00
0005434926517	20493	Economy	7600.00
0005434926547	20493	Economy	7600.00
0005434926525	20493	Economy	7600.00
0005434926518	20493	Economy	7600.00
0005434926534	20493	Economy	7600.00
0005434926540	20493	Economy	7600.00
0005434926515	20493	Economy	7600.00
0005434926546	20493	Economy	7600.00
0005434926511	20493	Economy	7600.00
0005434926528	20493	Economy	7600.00
0005434926520	20493	Economy	7600.00
0005434926514	20493	Economy	7600.00
0005434926512	20493	Economy	7600.00
0005434926531	20493	Economy	7600.00
0005434926539	20493	Economy	7600.00
0005434926523	20493	Economy	7600.00
0005434926545	20493	Economy	7600.00
0005434926542	20493	Economy	7600.00
0005435999576	15796	Economy	8900.00
0005435999496	15796	Economy	8900.00
0005435488346	15796	Economy	8900.00
0005435999459	15796	Economy	8100.00
0005435488355	15796	Economy	8100.00
0005435999439	15796	Economy	8100.00
0005435488351	15796	Economy	8100.00
0005435488349	15796	Economy	8100.00
0005435488361	15796	Economy	8100.00
0005435999485	15796	Economy	8100.00
0005435488342	15796	Economy	8100.00
0005435999503	15796	Economy	8100.00
0005435488344	15796	Economy	8100.00
0005435999562	15796	Economy	8100.00
0005435488359	15796	Economy	8100.00
0005435488348	15796	Economy	8100.00
0005435488354	15796	Economy	8100.00
0005435488341	15796	Economy	8100.00
0005435999482	15796	Economy	8100.00
0005435999460	15796	Economy	8100.00
0005435488353	15796	Economy	8100.00
0005435488343	15796	Economy	8100.00
0005435999483	15796	Economy	8100.00
0005435488356	15796	Economy	8100.00
0005435999529	15796	Economy	8100.00
0005435999569	15796	Economy	8100.00
0005435488345	15796	Economy	8100.00
0005435999586	15796	Economy	8100.00
0005435999557	15796	Economy	8100.00
0005435488352	15796	Economy	8100.00
0005435488350	15796	Economy	8100.00
0005435488340	15796	Economy	8100.00
0005435488357	15796	Economy	8100.00
0005435999502	15796	Economy	8100.00
0005435999522	15796	Economy	8100.00
0005435488347	15796	Economy	8100.00
0005435488358	15796	Economy	8100.00
0005435488360	15796	Economy	8100.00
0005435999664	19722	Economy	8900.00
0005435999649	19722	Economy	8900.00
0005435999648	19722	Economy	8900.00
0005435488151	19722	Economy	8100.00
0005435999670	19722	Economy	8100.00
0005435999656	19722	Economy	8100.00
0005435999661	19722	Economy	8100.00
0005435999651	19722	Economy	8100.00
0005435999666	19722	Economy	8100.00
0005435488206	19722	Economy	8100.00
0005435999653	19722	Economy	8100.00
0005435999663	19722	Economy	8100.00
0005435488084	19722	Economy	8100.00
0005435999657	19722	Economy	8100.00
0005435488174	19722	Economy	8100.00
0005435999658	19722	Economy	8100.00
0005435999667	19722	Economy	8100.00
0005435488173	19722	Economy	8100.00
0005435999662	19722	Economy	8100.00
0005435488060	19722	Economy	8100.00
0005435999655	19722	Economy	8100.00
0005435999647	19722	Economy	8100.00
0005435488185	19722	Economy	8100.00
0005435488172	19722	Economy	8100.00
0005435999650	19722	Economy	8100.00
0005435999654	19722	Economy	8100.00
0005435488198	19722	Economy	8100.00
0005435488096	19722	Economy	8100.00
0005435999652	19722	Economy	8100.00
0005435999660	19722	Economy	8100.00
0005435488182	19722	Economy	8100.00
0005435488205	19722	Economy	8100.00
0005435488184	19722	Economy	8100.00
0005435488138	19722	Economy	8100.00
0005435488081	19722	Economy	8100.00
0005435488131	19722	Economy	8100.00
0005435999668	19722	Economy	8100.00
0005435999669	19722	Economy	8100.00
0005435488168	19722	Economy	8100.00
0005435999659	19722	Economy	8100.00
0005435999665	19722	Economy	8100.00
0005435488203	19722	Economy	8100.00
0005435999646	19722	Economy	8100.00
0005435488150	19722	Economy	8100.00
0005435473123	6007	Business	199300.00
0005435840127	6007	Business	199300.00
0005435840122	6007	Business	199300.00
0005435840131	6007	Business	199300.00
0005435840125	6007	Business	199300.00
0005435840120	6007	Business	199300.00
0005435840121	6007	Business	199300.00
0005435840116	6007	Business	199300.00
0005435473005	6007	Business	199300.00
0005435473108	6007	Economy	66400.00
0005435473081	6007	Economy	66400.00
0005432658643	6007	Economy	66400.00
0005435840132	6007	Economy	66400.00
0005432660869	6007	Economy	73100.00
0005435840128	6007	Economy	73100.00
0005435473080	6007	Economy	66400.00
0005435473010	6007	Economy	66400.00
0005432659758	6007	Economy	66400.00
0005435473057	6007	Economy	66400.00
0005435840109	6007	Economy	66400.00
0005435473039	6007	Economy	66400.00
0005435840134	6007	Economy	66400.00
0005435840119	6007	Economy	66400.00
0005432658642	6007	Economy	66400.00
0005435840130	6007	Economy	66400.00
0005435840135	6007	Economy	66400.00
0005435840133	6007	Economy	66400.00
0005435473004	6007	Economy	66400.00
0005435840114	6007	Economy	66400.00
0005432142327	6007	Economy	66400.00
0005435840118	6007	Economy	66400.00
0005435840124	6007	Economy	66400.00
0005435473055	6007	Economy	66400.00
0005435473003	6007	Economy	66400.00
0005432142326	6007	Economy	66400.00
0005435840115	6007	Economy	66400.00
0005435840123	6007	Economy	66400.00
0005435840126	6007	Economy	66400.00
0005435840117	6007	Economy	66400.00
0005432660868	6007	Economy	66400.00
0005435473056	6007	Economy	66400.00
0005432659757	6007	Economy	66400.00
0005435473122	6007	Economy	66400.00
0005435840112	6007	Economy	66400.00
0005435840111	6007	Economy	66400.00
0005435840113	6007	Economy	66400.00
0005435840110	6007	Economy	66400.00
0005432142328	6007	Economy	66400.00
0005432142325	6007	Economy	66400.00
0005435840129	6007	Economy	66400.00
0005435840136	6007	Economy	66400.00
0005435473198	18074	Business	199300.00
0005432537110	18074	Business	199300.00
0005432664164	18074	Business	199300.00
0005435839815	18074	Business	199300.00
0005432660847	18074	Business	199300.00
0005435473188	18074	Business	199300.00
0005435473191	18074	Business	199300.00
0005435473200	18074	Economy	66400.00
0005435473187	18074	Economy	66400.00
0005435473202	18074	Economy	66400.00
0005435473196	18074	Economy	66400.00
0005435839849	18074	Economy	66400.00
0005435473197	18074	Economy	73100.00
0005435839766	18074	Economy	66400.00
0005435473190	18074	Economy	66400.00
0005432664171	18074	Economy	66400.00
0005435839851	18074	Economy	66400.00
0005432660849	18074	Economy	66400.00
0005435473193	18074	Economy	66400.00
0005435839985	18074	Economy	66400.00
0005435839991	18074	Economy	66400.00
0005432664165	18074	Economy	66400.00
0005432537109	18074	Economy	66400.00
0005435473203	18074	Economy	66400.00
0005435473195	18074	Economy	66400.00
0005435839950	18074	Economy	66400.00
0005435473194	18074	Economy	66400.00
0005435839791	18074	Economy	66400.00
0005435839772	18074	Economy	66400.00
0005435839792	18074	Economy	66400.00
0005435473189	18074	Economy	66400.00
0005435839852	18074	Economy	66400.00
0005435839996	18074	Economy	66400.00
0005435839828	18074	Economy	66400.00
0005435839866	18074	Economy	66400.00
0005435473201	18074	Economy	66400.00
0005432660848	18074	Economy	66400.00
0005435839952	18074	Economy	66400.00
0005435473192	18074	Economy	66400.00
0005435839904	18074	Economy	66400.00
0005435839850	18074	Economy	66400.00
0005435839814	18074	Economy	66400.00
0005435839865	18074	Economy	66400.00
0005435839951	18074	Economy	66400.00
0005435840016	18074	Economy	66400.00
0005435473199	18074	Economy	66400.00
0005435839846	18074	Economy	66400.00
0005435839765	18074	Economy	66400.00
0005435839998	18074	Economy	66400.00
0005435839997	18074	Economy	66400.00
0005435840018	18074	Economy	66400.00
0005435839845	18074	Economy	66400.00
0005433285747	23014	Business	15700.00
0005433285719	23014	Business	15700.00
0005433285740	23014	Business	15700.00
0005433285718	23014	Business	15700.00
0005433285849	23014	Business	15700.00
0005433285707	23014	Economy	5200.00
0005435104148	23014	Economy	5200.00
0005433285756	23014	Economy	5200.00
0005435104142	23014	Economy	5200.00
0005433285694	23014	Economy	5200.00
0005433285938	23014	Economy	5200.00
0005433285684	23014	Economy	5200.00
0005433285703	23014	Economy	5200.00
0005433285679	23014	Economy	5200.00
0005435104149	23014	Economy	5200.00
0005433285655	23014	Economy	5200.00
0005433285821	23014	Economy	5200.00
0005433285783	23014	Economy	5700.00
0005433285825	23014	Economy	5700.00
0005433285713	23014	Economy	5700.00
0005433285812	23014	Economy	5700.00
0005433285785	23014	Economy	5200.00
0005435104143	23014	Economy	5200.00
0005433285772	23014	Economy	5200.00
0005435104139	23014	Economy	5200.00
0005433285816	23014	Economy	5200.00
0005435104140	23014	Economy	5200.00
0005435104147	23014	Economy	5200.00
0005435104144	23014	Economy	5200.00
0005433285746	23014	Economy	5200.00
0005433285634	23014	Economy	5200.00
0005433285786	23014	Economy	5200.00
0005435104145	23014	Economy	5200.00
0005433285803	23014	Economy	5200.00
0005433285705	23014	Economy	5200.00
0005433285811	23014	Economy	5200.00
0005435104141	23014	Economy	5200.00
0005433285556	23014	Economy	5200.00
0005433285804	23014	Economy	5200.00
0005435104146	23014	Economy	5200.00
0005435104138	23014	Economy	5200.00
0005433285810	23014	Economy	5200.00
0005433285800	23014	Economy	5200.00
0005433285717	23014	Economy	5200.00
0005433285776	23014	Economy	5200.00
0005433285815	23014	Economy	5200.00
0005433285725	23014	Economy	5200.00
0005433285706	23014	Economy	5200.00
0005433285723	23014	Economy	5200.00
0005433286046	32080	Business	15700.00
0005433286041	32080	Business	15700.00
0005433286032	32080	Business	15700.00
0005433286033	32080	Business	15700.00
0005435104045	32080	Economy	5200.00
0005433286048	32080	Economy	5200.00
0005433286056	32080	Economy	5200.00
0005433286027	32080	Economy	5200.00
0005433286057	32080	Economy	5200.00
0005433286039	32080	Economy	5200.00
0005433286055	32080	Economy	5200.00
0005433286037	32080	Economy	5200.00
0005435104047	32080	Economy	5200.00
0005433286028	32080	Economy	5200.00
0005433286049	32080	Economy	5200.00
0005433286053	32080	Economy	5200.00
0005435103999	32080	Economy	5200.00
0005433286040	32080	Economy	5200.00
0005433286030	32080	Economy	5200.00
0005435104023	32080	Economy	5200.00
0005433286051	32080	Economy	5200.00
0005433286052	32080	Economy	5200.00
0005435104046	32080	Economy	5200.00
0005433286042	32080	Economy	5200.00
0005433286035	32080	Economy	5200.00
0005433286045	32080	Economy	5200.00
0005435104025	32080	Economy	5200.00
0005433286044	32080	Economy	5200.00
0005433286036	32080	Economy	5200.00
0005433286031	32080	Economy	5200.00
0005433286038	32080	Economy	5200.00
0005433286050	32080	Economy	5200.00
0005433286034	32080	Economy	5200.00
0005433286054	32080	Economy	5200.00
0005433286047	32080	Economy	5200.00
0005433286029	32080	Economy	5200.00
0005433286043	32080	Economy	5200.00
0005433475766	23855	Economy	13500.00
0005435852641	23855	Economy	13500.00
0005435852642	23855	Economy	12300.00
0005435852639	23855	Economy	12300.00
0005433475790	23855	Economy	12300.00
0005435852638	23855	Economy	12300.00
0005433475768	23855	Economy	12300.00
0005433475784	23855	Economy	12300.00
0005433475779	23855	Economy	12300.00
0005433475744	23855	Economy	12300.00
0005433475775	23855	Economy	12300.00
0005433475743	23855	Economy	12300.00
0005435852640	23855	Economy	12300.00
0005433475776	23855	Economy	12300.00
0005433475778	23855	Economy	12300.00
0005433475772	23855	Economy	12300.00
0005433475740	23855	Economy	12300.00
0005432159972	30605	Business	42100.00
0005434068352	30605	Business	42100.00
0005432530289	30605	Business	42100.00
0005432530282	30605	Business	42100.00
0005432530182	30605	Business	42100.00
0005434068210	30605	Business	42100.00
0005432529823	30605	Business	42100.00
0005432529530	30605	Business	42100.00
0005432530297	30605	Business	42100.00
0005434068784	30605	Business	42100.00
0005432530068	30605	Business	42100.00
0005432530216	30605	Business	42100.00
0005434068498	30605	Business	42100.00
0005434068086	30605	Business	42100.00
0005434068304	30605	Business	42100.00
0005434068638	30605	Business	42100.00
0005432529738	30605	Business	42100.00
0005434068643	30605	Comfort	23900.00
0005434068721	30605	Business	42100.00
0005434068536	30605	Comfort	23900.00
0005435725720	30605	Comfort	23900.00
0005435215222	30605	Comfort	23900.00
0005435215207	30605	Comfort	23900.00
0005434068591	30605	Comfort	23900.00
0005432530498	30605	Comfort	23900.00
0005433656753	30605	Comfort	23900.00
0005435215224	30605	Comfort	23900.00
0005432530497	30605	Comfort	23900.00
0005434068490	30605	Comfort	23900.00
0005432530085	30605	Comfort	23900.00
0005432530348	30605	Comfort	23900.00
0005432530004	30605	Comfort	23900.00
0005432211687	30605	Comfort	23900.00
0005432530817	30605	Comfort	23900.00
0005435215221	30605	Comfort	23900.00
0005432529730	30605	Comfort	23900.00
0005432529982	30605	Comfort	23900.00
0005434068353	30605	Comfort	23900.00
0005432530067	30605	Comfort	23900.00
0005434068602	30605	Comfort	23900.00
0005432529815	30605	Comfort	23900.00
0005432529549	30605	Comfort	23900.00
0005435215189	30605	Comfort	23900.00
0005432530445	30605	Comfort	23900.00
0005432530072	30605	Comfort	23900.00
0005434068744	30605	Comfort	23900.00
0005432530451	30605	Comfort	23900.00
0005435725719	30605	Comfort	23900.00
0005434068824	30605	Comfort	23900.00
0005432530193	30605	Comfort	23900.00
0005435215200	30605	Comfort	23900.00
0005435215194	30605	Comfort	23900.00
0005434068823	30605	Comfort	23900.00
0005432530034	30605	Comfort	23900.00
0005435215218	30605	Comfort	23900.00
0005432530416	30605	Comfort	23900.00
0005432530462	30605	Economy	14000.00
0005432529907	30605	Comfort	23900.00
0005432530036	30605	Economy	14000.00
0005435215225	30605	Economy	14000.00
0005435215216	30605	Economy	14000.00
0005432529728	30605	Economy	14000.00
0005434068465	30605	Economy	14000.00
0005432530009	30605	Economy	14000.00
0005435215196	30605	Economy	14000.00
0005435215182	30605	Economy	14000.00
0005434068756	30605	Economy	14000.00
0005432530037	30605	Economy	14000.00
0005435215212	30605	Economy	14000.00
0005432530065	30605	Economy	14000.00
0005434068768	30605	Economy	14000.00
0005434068600	30605	Economy	14000.00
0005432530013	30605	Economy	14000.00
0005434068742	30605	Economy	14000.00
0005432533343	30605	Economy	14000.00
0005432529825	30605	Economy	14000.00
0005432529858	30605	Economy	14000.00
0005432530557	30605	Economy	14000.00
0005435215175	30605	Economy	14000.00
0005432530347	30605	Economy	14000.00
0005434068722	30605	Economy	14000.00
0005435215197	30605	Economy	14000.00
0005435725723	30605	Economy	14000.00
0005432530131	30605	Economy	14000.00
0005435215228	30605	Economy	14000.00
0005432530080	30605	Economy	14000.00
0005432530161	30605	Economy	14000.00
0005435215226	30605	Economy	14000.00
0005432529905	30605	Economy	14000.00
0005434068691	30605	Economy	14000.00
0005432529644	30605	Economy	14000.00
0005434068537	30605	Economy	14000.00
0005432529678	30605	Economy	14000.00
0005435215223	30605	Economy	14000.00
0005432530243	30605	Economy	14000.00
0005434068660	30605	Economy	14000.00
0005432530244	30605	Economy	14000.00
0005435215193	30605	Economy	14000.00
0005432530452	30605	Economy	14000.00
0005432530296	30605	Economy	14000.00
0005432530160	30605	Economy	14000.00
0005435215176	30605	Economy	14000.00
0005434068472	30605	Economy	14000.00
0005434068556	30605	Economy	14000.00
0005434068601	30605	Economy	14000.00
0005432530194	30605	Economy	14000.00
0005432530186	30605	Economy	14000.00
0005435215195	30605	Economy	14000.00
0005432211686	30605	Economy	14000.00
0005432529406	30605	Economy	14000.00
0005432529501	30605	Economy	14000.00
0005435215233	30605	Economy	15400.00
0005435215206	30605	Economy	15400.00
0005432530130	30605	Economy	14000.00
0005435215191	30605	Economy	15400.00
0005434068790	30605	Economy	14000.00
0005432530169	30605	Economy	14000.00
0005434068659	30605	Economy	14000.00
0005435215171	30605	Economy	15400.00
0005432530079	30605	Economy	15400.00
0005432530556	30605	Economy	15400.00
0005435215208	30605	Economy	14000.00
0005435215192	30605	Economy	14000.00
0005434068831	30605	Economy	14000.00
0005434068871	30605	Economy	14000.00
0005434068628	30605	Economy	14000.00
0005434068211	30605	Economy	14000.00
0005432530185	30605	Economy	14000.00
0005435215204	30605	Economy	14000.00
0005434068617	30605	Economy	14000.00
0005432530155	30605	Economy	14000.00
0005432530488	30605	Economy	14000.00
0005432530027	30605	Economy	14000.00
0005432530440	30605	Economy	14000.00
0005434068529	30605	Economy	14000.00
0005435215183	30605	Economy	14000.00
0005432530361	30605	Economy	14000.00
0005432530038	30605	Economy	14000.00
0005432530039	30605	Economy	14000.00
0005432530376	30605	Economy	14000.00
0005432529300	30605	Economy	14000.00
0005435215231	30605	Economy	14000.00
0005435215203	30605	Economy	14000.00
0005432529949	30605	Economy	14000.00
0005432529939	30605	Economy	14000.00
0005432530280	30605	Economy	14000.00
0005434068715	30605	Economy	14000.00
0005432529729	30605	Economy	14000.00
0005435215202	30605	Economy	14000.00
0005432530450	30605	Economy	14000.00
0005432530276	30605	Economy	14000.00
0005432529890	30605	Economy	14000.00
0005435631042	30605	Economy	14000.00
0005435215199	30605	Economy	14000.00
0005432529769	30605	Economy	14000.00
0005434068338	30605	Economy	14000.00
0005434068629	30605	Economy	14000.00
0005434068627	30605	Economy	14000.00
0005432428979	30605	Economy	14000.00
0005435215180	30605	Economy	14000.00
0005434068886	30605	Economy	14000.00
0005435215209	30605	Economy	14000.00
0005432529643	30605	Economy	14000.00
0005434068598	30605	Economy	14000.00
0005432529891	30605	Economy	14000.00
0005434068801	30605	Economy	14000.00
0005434068747	30605	Economy	14000.00
0005432159974	30605	Economy	14000.00
0005435215179	30605	Economy	14000.00
0005432530377	30605	Economy	14000.00
0005434068767	30605	Economy	14000.00
0005435215181	30605	Economy	14000.00
0005432529625	30605	Economy	14000.00
0005435215215	30605	Economy	14000.00
0005434068822	30605	Economy	14000.00
0005434068825	30605	Economy	14000.00
0005435215188	30605	Economy	14000.00
0005435215211	30605	Economy	14000.00
0005432159970	30605	Economy	14000.00
0005432529915	30605	Economy	14000.00
0005435215173	30605	Economy	14000.00
0005432530449	30605	Economy	14000.00
0005434068782	30605	Economy	14000.00
0005432428982	30605	Economy	14000.00
0005434068639	30605	Economy	14000.00
0005435215229	30605	Economy	14000.00
0005432529981	30605	Economy	14000.00
0005432529938	30605	Economy	14000.00
0005432529818	30605	Economy	14000.00
0005432530318	30605	Economy	14000.00
0005435215210	30605	Economy	14000.00
0005432529984	30605	Economy	14000.00
0005432530308	30605	Economy	14000.00
0005434068489	30605	Economy	14000.00
0005434068402	30605	Economy	14000.00
0005434068610	30605	Economy	14000.00
0005435215201	30605	Economy	14000.00
0005432529713	30605	Economy	14000.00
0005434068559	30605	Economy	14000.00
0005434068830	30605	Economy	14000.00
0005432530008	30605	Economy	14000.00
0005434068690	30605	Economy	14000.00
0005432159968	30605	Economy	14000.00
0005432530543	30605	Economy	14000.00
0005434068692	30605	Economy	14000.00
0005432211684	30605	Economy	14000.00
0005432159969	30605	Economy	14000.00
0005432211685	30605	Economy	14000.00
0005432529767	30605	Economy	14000.00
0005434068530	30605	Economy	14000.00
0005434068404	30605	Economy	14000.00
0005432530558	30605	Economy	14000.00
0005434068593	30605	Economy	14000.00
0005435215174	30605	Economy	14000.00
0005432529450	30605	Economy	14000.00
0005432159971	30605	Economy	15400.00
0005432529735	30605	Economy	15400.00
0005432530298	30605	Economy	15400.00
0005434068555	30605	Economy	15400.00
0005434068339	30605	Economy	15400.00
0005432529770	30605	Economy	15400.00
0005432429002	30605	Economy	14000.00
0005432529805	30605	Economy	14000.00
0005432530242	30605	Economy	14000.00
0005435215214	30605	Economy	14000.00
0005432530195	30605	Economy	14000.00
0005432530148	30605	Economy	14000.00
0005432530671	30605	Economy	14000.00
0005434068833	30605	Economy	14000.00
0005432529806	30605	Economy	14000.00
0005434068557	30605	Economy	14000.00
0005432530078	30605	Economy	14000.00
0005432530014	30605	Economy	14000.00
0005432428978	30605	Economy	14000.00
0005435215177	30605	Economy	14000.00
0005434068544	30605	Economy	14000.00
0005434068783	30605	Economy	14000.00
0005434068633	30605	Economy	14000.00
0005434068420	30605	Economy	14000.00
0005434068664	30605	Economy	14000.00
0005432211682	30605	Economy	14000.00
0005432159973	30605	Economy	14000.00
0005432530192	30605	Economy	14000.00
0005435215235	30605	Economy	14000.00
0005432211681	30605	Economy	14000.00
0005435215217	30605	Economy	14000.00
0005434068859	30605	Economy	14000.00
0005434068368	30605	Economy	14000.00
0005434068321	30605	Economy	14000.00
0005432530611	30605	Economy	14000.00
0005432530189	30605	Economy	14000.00
0005434068714	30605	Economy	14000.00
0005435215186	30605	Economy	14000.00
0005434068471	30605	Economy	14000.00
0005432530064	30605	Economy	14000.00
0005432530441	30605	Economy	14000.00
0005435215190	30605	Economy	14000.00
0005435215213	30605	Economy	14000.00
0005432529408	30605	Economy	14000.00
0005433656754	30605	Economy	14000.00
0005435725721	30605	Economy	14000.00
0005432530031	30605	Economy	14000.00
0005432530168	30605	Economy	14000.00
0005434068592	30605	Economy	14000.00
0005435215220	30605	Economy	14000.00
0005435725722	30605	Economy	14000.00
0005435215198	30605	Economy	14000.00
0005435215230	30605	Economy	14000.00
0005432529523	30605	Economy	14000.00
0005435215169	30605	Economy	14000.00
0005435215172	30605	Economy	14000.00
0005433656752	30605	Economy	14000.00
0005432530415	30605	Economy	14000.00
0005432530184	30605	Economy	14000.00
0005432529407	30605	Economy	14000.00
0005434068843	30605	Economy	14000.00
0005435215178	30605	Economy	14000.00
0005434068229	30605	Economy	14000.00
0005434068650	30605	Economy	14000.00
0005435215205	30605	Economy	14000.00
0005435215227	30605	Economy	14000.00
0005432530084	30605	Economy	14000.00
0005432530005	30605	Economy	14000.00
0005435631044	30605	Economy	14000.00
0005435631043	30605	Economy	14000.00
0005434068689	30605	Economy	14000.00
0005435215232	30605	Economy	14000.00
0005434068707	30605	Economy	14000.00
0005432530290	30605	Economy	14000.00
0005432530439	30605	Economy	14000.00
0005435215187	30605	Economy	14000.00
0005433656755	30605	Economy	14000.00
0005435215234	30605	Economy	14000.00
0005432530544	30605	Economy	14000.00
0005432530141	30605	Economy	14000.00
0005434068266	30605	Economy	14000.00
0005434068757	30605	Economy	14000.00
0005432529702	30605	Economy	14000.00
0005435215170	30605	Economy	14000.00
0005432529893	30605	Economy	14000.00
0005434068483	30605	Economy	14000.00
0005434068802	30605	Economy	14000.00
0005435215184	30605	Economy	14000.00
0005432211688	30605	Economy	14000.00
0005435215219	30605	Economy	14000.00
0005434068745	30605	Economy	14000.00
0005434068746	30605	Economy	14000.00
0005435215185	30605	Economy	14000.00
0005432211683	30605	Economy	14000.00
0005432530188	30605	Economy	14000.00
0005435653654	24822	Business	9800.00
0005435653733	24822	Business	9800.00
0005433368799	24822	Business	9800.00
0005433368804	24822	Business	9800.00
0005433368807	24822	Business	9800.00
0005435653814	24822	Business	9800.00
0005433368824	24822	Business	9800.00
0005435653675	24822	Business	9800.00
0005433368815	24822	Business	9800.00
0005435653751	24822	Business	9800.00
0005435653747	24822	Economy	3300.00
0005435653708	24822	Economy	3300.00
0005435653514	24822	Economy	3300.00
0005435653729	24822	Economy	3300.00
0005435653586	24822	Economy	3300.00
0005433368793	24822	Economy	3300.00
0005433368791	24822	Economy	3300.00
0005435653655	24822	Economy	3600.00
0005435653575	24822	Economy	3600.00
0005433368812	24822	Economy	3600.00
0005435653696	24822	Economy	3600.00
0005435653813	24822	Economy	3300.00
0005435653672	24822	Economy	3300.00
0005435653798	24822	Economy	3300.00
0005433368796	24822	Economy	3300.00
0005433368810	24822	Economy	3300.00
0005435653710	24822	Economy	3300.00
0005433368809	24822	Economy	3300.00
0005433368819	24822	Economy	3300.00
0005435653742	24822	Economy	3300.00
0005433368826	24822	Economy	3300.00
0005435653752	24822	Economy	3300.00
0005435653576	24822	Economy	3300.00
0005435653674	24822	Economy	3300.00
0005433368802	24822	Economy	3300.00
0005435653770	24822	Economy	3300.00
0005435653748	24822	Economy	3300.00
0005435653642	24822	Economy	3300.00
0005433368816	24822	Economy	3300.00
0005435653547	24822	Economy	3300.00
0005433368813	24822	Economy	3300.00
0005433368790	24822	Economy	3300.00
0005435653743	24822	Economy	3300.00
0005435653719	24822	Economy	3300.00
0005433368794	24822	Economy	3300.00
0005433368814	24822	Economy	3300.00
0005435653750	24822	Economy	3300.00
0005435653718	24822	Economy	3300.00
0005433368797	24822	Economy	3300.00
0005435653637	24822	Economy	3300.00
0005433368806	24822	Economy	3300.00
0005433368808	24822	Economy	3300.00
0005433368801	24822	Economy	3300.00
0005435653673	24822	Economy	3300.00
0005433368821	24822	Economy	3300.00
0005435653716	24822	Economy	3300.00
0005433368817	24822	Economy	3300.00
0005435653717	24822	Economy	3300.00
0005433368798	24822	Economy	3300.00
0005433368818	24822	Economy	3300.00
0005435653638	24822	Economy	3300.00
0005433368822	24822	Economy	3300.00
0005433368800	24822	Economy	3300.00
0005435653706	24822	Economy	3300.00
0005435653548	24822	Economy	3300.00
0005435653513	24822	Economy	3300.00
0005433368811	24822	Economy	3300.00
0005435653730	24822	Economy	3300.00
0005435653785	24822	Economy	3300.00
0005435653634	24822	Economy	3300.00
0005435653705	24822	Economy	3300.00
0005435653676	24822	Economy	3300.00
0005435653707	24822	Economy	3300.00
0005433368792	24822	Economy	3300.00
0005435653626	24822	Economy	3300.00
0005433368825	24822	Economy	3300.00
0005433368803	24822	Economy	3300.00
0005433368823	24822	Economy	3300.00
0005433368805	24822	Economy	3300.00
0005435653786	24822	Economy	3300.00
0005433368795	24822	Economy	3300.00
0005435653476	24822	Economy	3300.00
0005433368820	24822	Economy	3300.00
0005435653815	24822	Economy	3300.00
0005435949845	6605	Economy	20600.00
0005435949851	6605	Economy	18700.00
0005435949849	6605	Economy	18700.00
0005435949846	6605	Economy	18700.00
0005435949852	6605	Economy	18700.00
0005435949850	6605	Economy	18700.00
0005435949847	6605	Economy	18700.00
0005435949848	6605	Economy	18700.00
0005434980528	2043	Economy	10500.00
0005434980524	2043	Economy	10500.00
0005434980531	2043	Economy	10500.00
0005434980514	2043	Economy	10500.00
0005434980539	2043	Economy	9500.00
0005434980532	2043	Economy	9500.00
0005434980535	2043	Economy	9500.00
0005434980529	2043	Economy	9500.00
0005434980534	2043	Economy	9500.00
0005434980538	2043	Economy	9500.00
0005434980519	2043	Economy	9500.00
0005434980536	2043	Economy	9500.00
0005434980520	2043	Economy	9500.00
0005434980526	2043	Economy	9500.00
0005434980517	2043	Economy	9500.00
0005434980523	2043	Economy	9500.00
0005434980525	2043	Economy	9500.00
0005434980533	2043	Economy	9500.00
0005434980521	2043	Economy	9500.00
0005434980541	2043	Economy	9500.00
0005434980540	2043	Economy	9500.00
0005435801770	2043	Economy	9500.00
0005434980530	2043	Economy	9500.00
0005434980516	2043	Economy	9500.00
0005434980537	2043	Economy	9500.00
0005434980522	2043	Economy	9500.00
0005434980518	2043	Economy	9500.00
0005435801771	2043	Economy	9500.00
0005434980515	2043	Economy	9500.00
0005435801773	2043	Economy	9500.00
0005435801772	2043	Economy	9500.00
0005434980527	2043	Economy	9500.00
0005434980200	23576	Economy	10500.00
0005434980136	23576	Economy	10500.00
0005434980216	23576	Economy	9500.00
0005434980187	23576	Economy	9500.00
0005434980295	23576	Economy	9500.00
0005434980135	23576	Economy	9500.00
0005434980208	23576	Economy	9500.00
0005434980155	23576	Economy	9500.00
0005434980186	23576	Economy	9500.00
0005434980294	23576	Economy	9500.00
0005434980214	23576	Economy	9500.00
0005435801736	23576	Economy	9500.00
0005434980149	23576	Economy	9500.00
0005434980244	23576	Economy	9500.00
0005434980154	23576	Economy	9500.00
0005434980181	23576	Economy	9500.00
0005434980258	23576	Economy	9500.00
0005434980160	23576	Economy	9500.00
0005434980159	23576	Economy	9500.00
0005434980185	23576	Economy	9500.00
0005435801751	23576	Economy	9500.00
0005435801753	23576	Economy	9500.00
0005434980134	23576	Economy	9500.00
0005434980213	23576	Economy	9500.00
0005434980215	23576	Economy	9500.00
0005435801752	23576	Economy	9500.00
0005434980165	23576	Economy	9500.00
0005434980243	23576	Economy	9500.00
0005434980209	23576	Economy	9500.00
0005434952625	2635	Economy	5300.00
0005434952624	2635	Economy	5300.00
0005434952622	2635	Economy	5300.00
0005434952623	2635	Economy	5300.00
0005433256455	2597	Economy	5300.00
0005434952591	28287	Economy	5300.00
0005433256477	28287	Economy	5300.00
0005433256478	28287	Economy	5300.00
0005434952585	28287	Economy	5300.00
0005434952592	28287	Economy	5300.00
0005434952595	28287	Economy	5300.00
0005433112416	19832	Economy	8700.00
0005433111560	19832	Economy	8700.00
0005433112417	19832	Economy	8700.00
0005434302876	19832	Economy	8700.00
0005434302875	19832	Economy	8700.00
0005433111561	19832	Economy	8700.00
0005434139302	11962	Business	9700.00
0005434139339	11962	Business	9700.00
0005434139521	11962	Business	9700.00
0005434139093	11962	Business	9700.00
0005434139409	11962	Business	9700.00
0005434139195	11962	Business	9700.00
0005434139236	11962	Business	9700.00
0005434139477	11962	Business	9700.00
0005434139514	11962	Business	9700.00
0005434139398	11962	Business	9700.00
0005434139463	11962	Business	9700.00
0005434139596	11962	Economy	3200.00
0005434139462	11962	Economy	3200.00
0005434139446	11962	Economy	3200.00
0005434139589	11962	Economy	3200.00
0005434139295	11962	Economy	3200.00
0005434139433	11962	Economy	3200.00
0005434139499	11962	Economy	3200.00
0005434139327	11962	Economy	3200.00
0005434139246	11962	Economy	3200.00
0005434139233	11962	Economy	3200.00
0005434139257	11962	Economy	3500.00
0005434139591	11962	Economy	3500.00
0005434139519	11962	Economy	3500.00
0005434139132	11962	Economy	3500.00
0005434139500	11962	Economy	3200.00
0005434139595	11962	Economy	3200.00
0005434139418	11962	Economy	3200.00
0005434139413	11962	Economy	3200.00
0005434139232	11962	Economy	3200.00
0005434139235	11962	Economy	3200.00
0005434139526	11962	Economy	3200.00
0005434139323	11962	Economy	3200.00
0005434139329	11962	Economy	3200.00
0005434139130	11962	Economy	3200.00
0005434139194	11962	Economy	3200.00
0005434139496	11962	Economy	3200.00
0005434139230	11962	Economy	3200.00
0005434139423	11962	Economy	3200.00
0005434139301	11962	Economy	3200.00
0005434139520	11962	Economy	3200.00
0005434139320	11962	Economy	3200.00
0005434139408	11962	Economy	3200.00
0005434139540	11962	Economy	3200.00
0005434139539	11962	Economy	3200.00
0005434139434	11962	Economy	3200.00
0005434139217	11962	Economy	3200.00
0005434139467	11962	Economy	3200.00
0005434139450	11962	Economy	3200.00
0005434139437	11962	Economy	3200.00
0005434139319	11962	Economy	3200.00
0005434139513	11962	Economy	3200.00
0005434139330	11962	Economy	3200.00
0005434139307	11962	Economy	3200.00
0005434139247	11962	Economy	3200.00
0005434139229	11962	Economy	3200.00
0005434139426	11962	Economy	3200.00
0005434139346	11962	Economy	3200.00
0005434139444	11962	Economy	3200.00
0005434139407	11962	Economy	3200.00
0005434139315	11962	Economy	3200.00
0005434139438	11962	Economy	3200.00
0005434139466	11962	Economy	3200.00
0005434139449	11962	Economy	3200.00
0005434139592	11962	Economy	3200.00
0005434139427	11962	Economy	3200.00
0005434139527	11962	Economy	3200.00
0005434139548	11962	Economy	3200.00
0005434139412	11962	Economy	3200.00
0005434139348	11962	Economy	3200.00
0005434138781	11962	Economy	3200.00
0005434139328	11962	Economy	3200.00
0005434139294	11962	Economy	3200.00
0005434139318	11962	Economy	3200.00
0005434139321	11962	Economy	3200.00
0005434139300	11962	Economy	3200.00
0005434139431	11962	Economy	3200.00
0005434139350	11962	Economy	3200.00
0005434139351	11962	Economy	3200.00
0005434139399	11962	Economy	3200.00
0005434139439	11962	Economy	3200.00
0005434139448	11962	Economy	3200.00
0005434139590	11962	Economy	3200.00
0005434139231	11962	Economy	3200.00
0005434139234	11962	Economy	3200.00
0005434139522	11962	Economy	3200.00
0005434139456	11962	Economy	3200.00
0005434140101	28742	Business	9700.00
0005434140064	28742	Business	9700.00
0005434140088	28742	Business	9700.00
0005434140065	28742	Business	9700.00
0005434140108	28742	Business	9700.00
0005434140077	28742	Business	9700.00
0005434140046	28742	Business	9700.00
0005434140053	28742	Business	9700.00
0005434140091	28742	Business	9700.00
0005434140047	28742	Business	9700.00
0005434140061	28742	Economy	3200.00
0005434140057	28742	Economy	3200.00
0005434140104	28742	Economy	3200.00
0005434140081	28742	Economy	3200.00
0005434140097	28742	Economy	3200.00
0005434140039	28742	Economy	3200.00
0005434140090	28742	Economy	3200.00
0005434140040	28742	Economy	3200.00
0005434140041	28742	Economy	3200.00
0005434140096	28742	Economy	3500.00
0005434140062	28742	Economy	3500.00
0005434140042	28742	Economy	3500.00
0005434140059	28742	Economy	3500.00
0005434140085	28742	Economy	3200.00
0005434140045	28742	Economy	3200.00
0005434140036	28742	Economy	3200.00
0005434140068	28742	Economy	3200.00
0005434140073	28742	Economy	3200.00
0005434140082	28742	Economy	3200.00
0005434140034	28742	Economy	3200.00
0005434140087	28742	Economy	3200.00
0005434140084	28742	Economy	3200.00
0005434140050	28742	Economy	3200.00
0005434140052	28742	Economy	3200.00
0005434140058	28742	Economy	3200.00
0005434140044	28742	Economy	3200.00
0005434140075	28742	Economy	3200.00
0005434140089	28742	Economy	3200.00
0005434140083	28742	Economy	3200.00
0005434140092	28742	Economy	3200.00
0005434140100	28742	Economy	3200.00
0005434140109	28742	Economy	3200.00
0005434140078	28742	Economy	3200.00
0005434140048	28742	Economy	3200.00
0005434140111	28742	Economy	3200.00
0005434140069	28742	Economy	3200.00
0005434140051	28742	Economy	3200.00
0005434140054	28742	Economy	3200.00
0005434140037	28742	Economy	3200.00
0005434140074	28742	Economy	3200.00
0005434140094	28742	Economy	3200.00
0005434140066	28742	Economy	3200.00
0005434140080	28742	Economy	3200.00
0005434140070	28742	Economy	3200.00
0005434140035	28742	Economy	3200.00
0005434140095	28742	Economy	3200.00
0005434140086	28742	Economy	3200.00
0005434140067	28742	Economy	3200.00
0005434140038	28742	Economy	3200.00
0005434140060	28742	Economy	3200.00
0005434140063	28742	Economy	3200.00
0005434140106	28742	Economy	3200.00
0005434140103	28742	Economy	3200.00
0005434140105	28742	Economy	3200.00
0005434140072	28742	Economy	3200.00
0005434140098	28742	Economy	3200.00
0005434140055	28742	Economy	3200.00
0005434140093	28742	Economy	3200.00
0005434140102	28742	Economy	3200.00
0005434140110	28742	Economy	3200.00
0005434140099	28742	Economy	3200.00
0005434140033	28742	Economy	3200.00
0005434140076	28742	Economy	3200.00
0005434140049	28742	Economy	3200.00
0005434140071	28742	Economy	3200.00
0005434140043	28742	Economy	3200.00
0005434140079	28742	Economy	3200.00
0005434140107	28742	Economy	3200.00
0005434140056	28742	Economy	3200.00
0005434466576	6582	Economy	23000.00
0005434466582	6582	Economy	23000.00
0005434466580	6582	Economy	20900.00
0005434466574	6582	Economy	20900.00
0005435312842	6582	Economy	20900.00
0005435312844	6582	Economy	20900.00
0005435312843	6582	Economy	20900.00
0005434466577	6582	Economy	20900.00
0005435312849	6582	Economy	20900.00
0005434466575	6582	Economy	20900.00
0005434466578	6582	Economy	20900.00
0005434466581	6582	Economy	20900.00
0005435312845	6582	Economy	20900.00
0005434466579	6582	Economy	20900.00
0005435259833	6787	Economy	10900.00
0005433539083	6787	Economy	10900.00
0005433539081	6787	Economy	9900.00
0005433539079	6787	Economy	9900.00
0005433539078	6787	Economy	9900.00
0005433539082	6787	Economy	9900.00
0005433539080	6787	Economy	9900.00
0005433539084	6787	Economy	9900.00
0005433539086	6787	Economy	9900.00
0005435259826	6787	Economy	9900.00
0005433534550	6787	Economy	9900.00
0005435259830	6787	Economy	9900.00
0005435259825	6787	Economy	9900.00
0005435259831	6787	Economy	9900.00
0005433539085	6787	Economy	9900.00
0005435259832	6787	Economy	9900.00
0005435259867	25031	Economy	10900.00
0005435259866	25031	Economy	10900.00
0005433534536	25031	Economy	9900.00
0005433539008	25031	Economy	9900.00
0005433539023	25031	Economy	9900.00
0005433539001	25031	Economy	9900.00
0005433539000	25031	Economy	9900.00
0005435259863	25031	Economy	9900.00
0005435259868	25031	Economy	9900.00
0005433539017	25031	Economy	9900.00
0005435259865	25031	Economy	9900.00
0005433539019	25031	Economy	9900.00
0005433539018	25031	Economy	9900.00
0005433539033	25031	Economy	9900.00
0005435259864	25031	Economy	9900.00
0005433534534	25031	Economy	9900.00
0005433534535	25031	Economy	9900.00
0005432922579	810	Economy	14600.00
0005432922580	810	Economy	14600.00
0005433512153	810	Economy	14600.00
0005433512157	810	Economy	14600.00
0005432922578	810	Economy	14600.00
0005433512152	810	Economy	14600.00
0005433512154	810	Economy	14600.00
0005433512155	810	Economy	14600.00
0005432922586	810	Economy	14600.00
0005433512156	810	Economy	14600.00
0005433512158	810	Economy	14600.00
0005433512077	16165	Economy	16100.00
0005433512107	16165	Economy	14600.00
0005433512104	16165	Economy	14600.00
0005432922627	16165	Economy	14600.00
0005433512096	16165	Economy	14600.00
0005433512056	16165	Economy	14600.00
0005433512103	16165	Economy	14600.00
0005432922624	16165	Economy	14600.00
0005433512105	16165	Economy	14600.00
0005433512057	16165	Economy	14600.00
0005432922625	16165	Economy	14600.00
0005432922626	16165	Economy	14600.00
0005433512106	16165	Economy	14600.00
0005435698020	3695	Economy	7900.00
0005435698044	3695	Economy	7900.00
0005435698033	3695	Economy	7200.00
0005435698037	3695	Economy	7200.00
0005435698022	3695	Economy	7200.00
0005435698038	3695	Economy	7200.00
0005435698031	3695	Economy	7200.00
0005435698039	3695	Economy	7200.00
0005435698042	3695	Economy	7200.00
0005435935092	3695	Economy	7200.00
0005435698030	3695	Economy	7200.00
0005435698028	3695	Economy	7200.00
0005435698043	3695	Economy	7200.00
0005435698029	3695	Economy	7200.00
0005435916225	3695	Economy	7200.00
0005434950642	3695	Economy	7200.00
0005434950639	3695	Economy	7200.00
0005434950640	3695	Economy	7200.00
0005435698036	3695	Economy	7200.00
0005435698019	3695	Economy	7200.00
0005435698026	3695	Economy	7200.00
0005435935091	3695	Economy	7200.00
0005435698023	3695	Economy	7200.00
0005435698035	3695	Economy	7200.00
0005435916217	3695	Economy	7200.00
0005435698032	3695	Economy	7200.00
0005435698041	3695	Economy	7200.00
0005435698024	3695	Economy	7200.00
0005435935094	3695	Economy	7200.00
0005435698025	3695	Economy	7200.00
0005434950641	3695	Economy	7200.00
0005435698027	3695	Economy	7200.00
0005435698040	3695	Economy	7200.00
0005435698021	3695	Economy	7200.00
0005435698034	3695	Economy	7200.00
0005434950643	3695	Economy	7200.00
0005435697805	16304	Economy	7900.00
0005435697769	16304	Economy	7900.00
0005435697675	16304	Economy	7900.00
0005435697636	16304	Economy	7200.00
0005435935122	16304	Economy	7200.00
0005435697777	16304	Economy	7200.00
0005435697786	16304	Economy	7200.00
0005435697646	16304	Economy	7200.00
0005435697782	16304	Economy	7200.00
0005435697766	16304	Economy	7200.00
0005435933572	16304	Economy	7200.00
0005434950607	16304	Economy	7200.00
0005435697795	16304	Economy	7200.00
0005435697735	16304	Economy	7200.00
0005435697785	16304	Economy	7200.00
0005435697761	16304	Economy	7200.00
0005435697757	16304	Economy	7200.00
0005435697635	16304	Economy	7200.00
0005435697729	16304	Economy	7200.00
0005434950608	16304	Economy	7200.00
0005435697800	16304	Economy	7200.00
0005435697650	16304	Economy	7200.00
0005435935121	16304	Economy	7200.00
0005435697705	16304	Economy	7200.00
0005435916235	16304	Economy	7200.00
0005435697793	16304	Economy	7200.00
0005435697806	16304	Economy	7200.00
0005435916237	16304	Economy	7200.00
0005435916236	16304	Economy	7200.00
0005435697788	16304	Economy	7200.00
0005435697798	16304	Economy	7200.00
0005435697706	16304	Economy	7200.00
0005434950595	16304	Economy	7200.00
0005435697593	16304	Economy	7200.00
0005435697799	16304	Economy	7200.00
0005435697796	16304	Economy	7200.00
0005435935120	16304	Economy	7200.00
0005435697866	16304	Economy	7200.00
0005435697736	16304	Economy	7200.00
0005435697730	16304	Economy	7200.00
0005435697647	16304	Economy	7200.00
0005435697844	16304	Economy	7200.00
0005435697865	16304	Economy	7200.00
0005435935119	16304	Economy	7200.00
0005435697634	16304	Economy	7200.00
0005433519573	3936	Economy	19300.00
0005435853642	3936	Economy	19300.00
0005434604990	3936	Economy	19300.00
0005432609832	3936	Economy	19300.00
0005434606912	3936	Economy	19300.00
0005434604988	3936	Economy	19300.00
0005435853638	3936	Economy	19300.00
0005434604989	3936	Economy	19300.00
0005433519571	3936	Economy	19300.00
0005435841485	3936	Economy	19300.00
0005432607666	3936	Economy	19300.00
0005432609833	3936	Economy	19300.00
0005432609834	3936	Economy	19300.00
0005432607664	3936	Economy	19300.00
0005433519570	3936	Economy	19300.00
0005435853641	3936	Economy	19300.00
0005434606913	3936	Economy	19300.00
0005434606915	3936	Economy	19300.00
0005432609831	3936	Economy	19300.00
0005435853644	3936	Economy	19300.00
0005433519572	3936	Economy	19300.00
0005434606914	3936	Economy	19300.00
0005433519569	3936	Economy	19300.00
0005432607665	3936	Economy	19300.00
0005432607667	3936	Economy	19300.00
0005434606874	22068	Economy	21300.00
0005433519542	22068	Economy	19300.00
0005434606878	22068	Economy	19300.00
0005435853656	22068	Economy	19300.00
0005434606879	22068	Economy	19300.00
0005434606880	22068	Economy	19300.00
0005435853657	22068	Economy	19300.00
0005434606882	22068	Economy	19300.00
0005434606875	22068	Economy	19300.00
0005433349077	775	Economy	3700.00
0005433349095	775	Economy	3700.00
0005433349075	775	Economy	3700.00
0005433349078	775	Economy	3700.00
0005433349086	775	Economy	3700.00
0005433349093	775	Economy	3700.00
0005433349076	775	Economy	3700.00
0005435628771	15958	Economy	3700.00
0005433349134	15958	Economy	3700.00
0005433349135	15958	Economy	3700.00
0005433349132	15958	Economy	3700.00
0005433349133	15958	Economy	3700.00
0005433349131	15958	Economy	3700.00
0005435628770	15958	Economy	3700.00
0005433349136	15958	Economy	3700.00
0005435628780	15958	Economy	3700.00
0005435628792	15958	Economy	3700.00
0005435628769	15958	Economy	3700.00
0005435628783	15958	Economy	3700.00
0005433158161	17239	Economy	7100.00
0005433159344	17239	Economy	7100.00
0005433159347	17239	Economy	7100.00
0005433158172	17239	Economy	7100.00
0005433159345	17239	Economy	7100.00
0005433159349	17239	Economy	7100.00
0005433159348	17239	Economy	7100.00
0005433158162	17239	Economy	7100.00
0005433158173	17239	Economy	7100.00
0005433158160	17239	Economy	7100.00
0005433159346	17239	Economy	7100.00
0005433159368	17624	Economy	7100.00
0005433158199	17624	Economy	7100.00
0005434445276	17624	Economy	7100.00
0005434445291	17624	Economy	7100.00
0005433159369	17624	Economy	7100.00
0005435133143	7890	Economy	5900.00
0005435133140	7890	Economy	5900.00
0005435133145	7890	Economy	5400.00
0005435383248	7890	Economy	5400.00
0005435133141	7890	Economy	5400.00
0005435133144	7890	Economy	5400.00
0005435133146	7890	Economy	5400.00
0005435133142	7890	Economy	5400.00
0005435383228	7890	Economy	5400.00
0005435133148	7890	Economy	5400.00
0005435133147	7890	Economy	5400.00
0005435383249	7890	Economy	5400.00
0005435133139	7890	Economy	5400.00
0005435133078	33121	Economy	5900.00
0005435383285	33121	Economy	5900.00
0005435133038	33121	Economy	5900.00
0005435133036	33121	Economy	5400.00
0005435133027	33121	Economy	5400.00
0005435133026	33121	Economy	5400.00
0005435383284	33121	Economy	5400.00
0005435383283	33121	Economy	5400.00
0005435383287	33121	Economy	5400.00
0005435383286	33121	Economy	5400.00
0005435133039	33121	Economy	5400.00
0005435133073	33121	Economy	5400.00
0005435133077	33121	Economy	5400.00
0005435133101	33121	Economy	5400.00
0005435133057	33121	Economy	5400.00
0005435133104	33121	Economy	5400.00
0005435133037	33121	Economy	5400.00
0005435383282	33121	Economy	5400.00
0005435938925	4419	Business	133200.00
0005435811203	4419	Business	133200.00
0005435811198	4419	Business	133200.00
0005435811196	4419	Business	133200.00
0005435938918	4419	Business	133200.00
0005435811201	4419	Economy	44400.00
0005435811200	4419	Economy	44400.00
0005435811194	4419	Economy	44400.00
0005435938921	4419	Economy	44400.00
0005435811197	4419	Economy	44400.00
0005435811195	4419	Economy	44400.00
0005435811202	4419	Economy	44400.00
0005435811199	4419	Economy	44400.00
0005435811164	29441	Business	133200.00
0005435938953	29441	Business	133200.00
0005435811134	29441	Business	133200.00
0005435811144	29441	Economy	44400.00
0005435811147	29441	Economy	44400.00
0005435811154	29441	Economy	44400.00
0005435938951	29441	Economy	44400.00
0005435938952	29441	Economy	44400.00
0005435938950	29441	Economy	44400.00
0005435811153	29441	Economy	44400.00
0005435938949	29441	Economy	44400.00
0005435938954	29441	Economy	44400.00
0005435811151	29441	Economy	44400.00
0005435811145	29441	Economy	44400.00
0005435811152	29441	Economy	44400.00
0005435811146	29441	Economy	44400.00
0005435160576	7500	Economy	13800.00
0005435160583	7500	Economy	12500.00
0005435160579	7500	Economy	12500.00
0005435160575	7500	Economy	12500.00
0005435390357	7500	Economy	12500.00
0005435160582	7500	Economy	12500.00
0005435390335	7500	Economy	12500.00
0005435390365	7500	Economy	12500.00
0005435160584	7500	Economy	12500.00
0005435390345	7500	Economy	12500.00
0005435390336	7500	Economy	12500.00
0005435160577	7500	Economy	12500.00
0005435390355	7500	Economy	12500.00
0005435160574	7500	Economy	12500.00
0005435390343	7500	Economy	12500.00
0005435160578	7500	Economy	12500.00
0005435390354	7500	Economy	12500.00
0005435390366	7500	Economy	12500.00
0005435390375	7500	Economy	12500.00
0005435160580	7500	Economy	12500.00
0005435390358	7500	Economy	12500.00
0005435160581	7500	Economy	12500.00
0005435390341	7500	Economy	12500.00
0005435160514	29589	Economy	12500.00
0005435160518	29589	Economy	12500.00
0005435160474	29589	Economy	12500.00
0005435160487	29589	Economy	12500.00
0005435390413	29589	Economy	12500.00
0005435390409	29589	Economy	12500.00
0005435160500	29589	Economy	12500.00
0005435390411	29589	Economy	12500.00
0005435390415	29589	Economy	12500.00
0005435160519	29589	Economy	12500.00
0005435390414	29589	Economy	12500.00
0005435160528	29589	Economy	12500.00
0005435390410	29589	Economy	12500.00
0005435160486	29589	Economy	12500.00
0005435160501	29589	Economy	12500.00
0005435390412	29589	Economy	12500.00
0005435160522	29589	Economy	12500.00
0005435160488	29589	Economy	12500.00
0005435160527	29589	Economy	12500.00
0005435160472	29589	Economy	12500.00
0005432394182	18432	Economy	4900.00
0005432394167	18432	Economy	4900.00
0005432394169	18432	Economy	4900.00
0005432394178	18432	Economy	4900.00
0005432394181	18432	Economy	4900.00
0005432394165	18432	Economy	4900.00
0005432394155	18432	Economy	4900.00
0005432394173	18432	Economy	4900.00
0005432394172	18432	Economy	4900.00
0005432394174	18432	Economy	4900.00
0005432394170	18432	Economy	4900.00
0005432394175	18432	Economy	4900.00
0005432400211	27127	Economy	4900.00
0005435178516	27127	Economy	4900.00
0005432400212	27127	Economy	4900.00
0005432398284	27127	Economy	4900.00
0005432398283	27127	Economy	4900.00
0005435178520	27127	Economy	4900.00
0005435178515	27127	Economy	4900.00
0005432639446	2234	Business	87300.00
0005432866094	2234	Business	87300.00
0005432866101	2234	Business	87300.00
0005432866124	2234	Business	87300.00
0005432639427	2234	Business	87300.00
0005432639441	2234	Business	87300.00
0005432639439	2234	Business	87300.00
0005432866102	2234	Economy	29100.00
0005432639438	2234	Economy	29100.00
0005432639445	2234	Economy	29100.00
0005432639444	2234	Economy	32000.00
0005432866088	2234	Economy	32000.00
0005432866114	2234	Economy	29100.00
0005432866130	2234	Economy	29100.00
0005432639437	2234	Economy	29100.00
0005432866118	2234	Economy	29100.00
0005432866104	2234	Economy	29100.00
0005432866103	2234	Economy	29100.00
0005432866146	2234	Economy	29100.00
0005432866132	2234	Economy	29100.00
0005432639433	2234	Economy	29100.00
0005432639443	2234	Economy	29100.00
0005432866131	2234	Economy	29100.00
0005432639425	2234	Economy	29100.00
0005432866116	2234	Economy	29100.00
0005432639436	2234	Economy	29100.00
0005432866140	2234	Economy	29100.00
0005432639447	2234	Economy	29100.00
0005432866123	2234	Economy	29100.00
0005432639431	2234	Economy	29100.00
0005432639440	2234	Economy	29100.00
0005432639424	2234	Economy	29100.00
0005432639428	2234	Economy	29100.00
0005432639423	2234	Economy	29100.00
0005432639435	2234	Economy	29100.00
0005432866121	2234	Economy	29100.00
0005432639448	2234	Economy	29100.00
0005432866115	2234	Economy	29100.00
0005432866117	2234	Economy	29100.00
0005432639432	2234	Economy	29100.00
0005432866089	2234	Economy	29100.00
0005432866122	2234	Economy	29100.00
0005432639442	2234	Economy	29100.00
0005432866119	2234	Economy	29100.00
0005432639430	2234	Economy	29100.00
0005432639426	2234	Economy	29100.00
0005432639429	2234	Economy	29100.00
0005432639434	2234	Economy	29100.00
0005432866145	2234	Economy	29100.00
0005433811669	24299	Economy	35100.00
0005433811679	24299	Economy	35100.00
0005433811676	24299	Economy	35100.00
0005433811677	24299	Economy	38600.00
0005433811678	24299	Economy	35100.00
0005433811675	24299	Economy	35100.00
0005433811671	24299	Economy	35100.00
0005433811670	24299	Economy	35100.00
0005433811673	24299	Economy	35100.00
0005433811674	24299	Economy	35100.00
0005433811672	24299	Economy	35100.00
0005434191306	9785	Economy	4400.00
0005434191307	9785	Economy	4400.00
0005434191318	32770	Economy	4400.00
0005434191308	32770	Economy	4400.00
0005434191310	32770	Economy	4400.00
0005434191315	32770	Economy	4400.00
0005434191316	32770	Economy	4400.00
0005434191313	32770	Economy	4400.00
0005434191314	32770	Economy	4400.00
0005434191312	32770	Economy	4400.00
0005434191311	32770	Economy	4400.00
0005434191309	32770	Economy	4400.00
0005434191317	32770	Economy	4400.00
0005432665302	26488	Business	92200.00
0005432661953	26488	Business	92200.00
0005432665293	26488	Business	92200.00
0005432665300	26488	Business	92200.00
0005432658609	26488	Business	92200.00
0005432661942	26488	Business	92200.00
0005432661946	26488	Business	92200.00
0005432661945	26488	Economy	30700.00
0005432665301	26488	Economy	33800.00
0005432658613	26488	Economy	33800.00
0005432665305	26488	Economy	33800.00
0005432658617	26488	Economy	30700.00
0005432665313	26488	Economy	30700.00
0005432665303	26488	Economy	30700.00
0005432665286	26488	Economy	30700.00
0005432665295	26488	Economy	30700.00
0005432665294	26488	Economy	30700.00
0005432661932	26488	Economy	30700.00
0005432665287	26488	Economy	30700.00
0005432661931	26488	Economy	30700.00
0005432661943	26488	Economy	30700.00
0005432661952	26488	Economy	30700.00
0005432661929	26488	Economy	30700.00
0005432658612	26488	Economy	30700.00
0005432665297	26488	Economy	30700.00
0005432661951	26488	Economy	30700.00
0005432661933	26488	Economy	30700.00
0005432658628	26488	Economy	30700.00
0005432665304	26488	Economy	30700.00
0005432658614	26488	Economy	30700.00
0005432661950	26488	Economy	30700.00
0005432665288	26488	Economy	30700.00
0005432665296	26488	Economy	30700.00
0005432658626	26488	Economy	30700.00
0005432658616	26488	Economy	30700.00
0005432661930	26488	Economy	30700.00
0005432658627	26488	Economy	30700.00
0005432658623	26488	Economy	30700.00
0005432661944	26488	Economy	30700.00
0005434505134	6534	Business	48400.00
0005434505129	6534	Business	48400.00
0005434505118	6534	Business	48400.00
0005434505123	6534	Economy	16100.00
0005435104173	6534	Economy	16100.00
0005434505136	6534	Economy	16100.00
0005434505127	6534	Economy	16100.00
0005434505128	6534	Economy	16100.00
0005434505146	6534	Economy	16100.00
0005434505130	6534	Economy	16100.00
0005434505144	6534	Economy	17800.00
0005435104171	6534	Economy	17800.00
0005435104172	6534	Economy	17800.00
0005434505141	6534	Economy	16100.00
0005434505143	6534	Economy	16100.00
0005434505139	6534	Economy	16100.00
0005434505138	6534	Economy	16100.00
0005435104170	6534	Economy	16100.00
0005434505149	6534	Economy	16100.00
0005434505121	6534	Economy	16100.00
0005434505125	6534	Economy	16100.00
0005434505135	6534	Economy	16100.00
0005434505113	6534	Economy	16100.00
0005434505119	6534	Economy	16100.00
0005435104174	6534	Economy	16100.00
0005434505142	6534	Economy	16100.00
0005434505116	6534	Economy	16100.00
0005434505132	6534	Economy	16100.00
0005434505124	6534	Economy	16100.00
0005435104168	6534	Economy	16100.00
0005434505145	6534	Economy	16100.00
0005434505122	6534	Economy	16100.00
0005434505111	6534	Economy	16100.00
0005434505140	6534	Economy	16100.00
0005434505133	6534	Economy	16100.00
0005434505148	6534	Economy	16100.00
0005434505114	6534	Economy	16100.00
0005434505115	6534	Economy	16100.00
0005434505126	6534	Economy	16100.00
0005434505120	6534	Economy	16100.00
0005434505137	6534	Economy	16100.00
0005434505112	6534	Economy	16100.00
0005435104169	6534	Economy	16100.00
0005435104175	6534	Economy	16100.00
0005434505150	6534	Economy	16100.00
0005434505117	6534	Economy	16100.00
0005434505131	6534	Economy	16100.00
0005434505147	6534	Economy	16100.00
0005434505151	6534	Economy	16100.00
0005434504740	22640	Business	48400.00
0005434504697	22640	Business	48400.00
0005434504817	22640	Business	48400.00
0005434504632	22640	Business	48400.00
0005434504633	22640	Business	48400.00
0005434504748	22640	Economy	16100.00
0005435103999	22640	Economy	16100.00
0005435104046	22640	Economy	16100.00
0005434504605	22640	Economy	16100.00
0005434504743	22640	Economy	17800.00
0005434504818	22640	Economy	17800.00
0005435104023	22640	Economy	17800.00
0005434504687	22640	Economy	16100.00
0005434504512	22640	Economy	16100.00
0005434504747	22640	Economy	16100.00
0005434504712	22640	Economy	16100.00
0005434504824	22640	Economy	16100.00
0005434504432	22640	Economy	16100.00
0005434504434	22640	Economy	16100.00
0005434504696	22640	Economy	16100.00
0005434504513	22640	Economy	16100.00
0005435104047	22640	Economy	16100.00
0005434504777	22640	Economy	16100.00
0005434504726	22640	Economy	16100.00
0005434504825	22640	Economy	16100.00
0005434504674	22640	Economy	16100.00
0005434504723	22640	Economy	16100.00
0005434504780	22640	Economy	16100.00
0005435104025	22640	Economy	16100.00
0005434504686	22640	Economy	16100.00
0005434504675	22640	Economy	16100.00
0005434504606	22640	Economy	16100.00
0005434504727	22640	Economy	16100.00
0005434504732	22640	Economy	16100.00
0005435104045	22640	Economy	16100.00
0005434504724	22640	Economy	16100.00
0005434504673	22640	Economy	16100.00
0005434504631	22640	Economy	16100.00
0005434504787	22640	Economy	16100.00
0005434504739	22640	Economy	16100.00
0005434504813	22640	Economy	16100.00
0005434504435	22640	Economy	16100.00
0005434504609	22640	Economy	16100.00
0005434504713	22640	Economy	16100.00
0005434504634	22640	Economy	16100.00
0005434504431	22640	Economy	16100.00
0005434504792	22640	Economy	16100.00
0005434504617	22640	Economy	16100.00
0005434504630	22640	Economy	16100.00
0005435654176	1648	Business	50000.00
0005433368413	1648	Business	50000.00
0005435654169	1648	Business	50000.00
0005433368384	1648	Business	50000.00
0005433368434	1648	Business	50000.00
0005433368592	1648	Business	50000.00
0005435654205	1648	Business	50000.00
0005433368529	1648	Business	50000.00
0005435654172	1648	Business	50000.00
0005433368591	1648	Business	50000.00
0005433368486	1648	Business	50000.00
0005433368490	1648	Economy	16700.00
0005435654200	1648	Economy	16700.00
0005433368664	1648	Economy	16700.00
0005435654183	1648	Economy	16700.00
0005433368545	1648	Economy	16700.00
0005435654180	1648	Economy	16700.00
0005435654198	1648	Economy	16700.00
0005435654189	1648	Economy	16700.00
0005433368546	1648	Economy	16700.00
0005435654197	1648	Economy	16700.00
0005435654177	1648	Economy	18300.00
0005433368547	1648	Economy	18300.00
0005435654182	1648	Economy	18300.00
0005435654175	1648	Economy	18300.00
0005435654185	1648	Economy	18300.00
0005435654179	1648	Economy	16700.00
0005435654171	1648	Economy	16700.00
0005433368674	1648	Economy	16700.00
0005433368393	1648	Economy	16700.00
0005433368585	1648	Economy	16700.00
0005435654167	1648	Economy	16700.00
0005435654191	1648	Economy	16700.00
0005435654178	1648	Economy	16700.00
0005433368693	1648	Economy	16700.00
0005433368435	1648	Economy	16700.00
0005435654195	1648	Economy	16700.00
0005435654184	1648	Economy	16700.00
0005433368605	1648	Economy	16700.00
0005435654164	1648	Economy	16700.00
0005435654173	1648	Economy	16700.00
0005433368381	1648	Economy	16700.00
0005435654181	1648	Economy	16700.00
0005433368469	1648	Economy	16700.00
0005435654170	1648	Economy	16700.00
0005433368491	1648	Economy	16700.00
0005433368485	1648	Economy	16700.00
0005433368316	1648	Economy	16700.00
0005435654186	1648	Economy	16700.00
0005435654190	1648	Economy	16700.00
0005435654202	1648	Economy	16700.00
0005435654193	1648	Economy	16700.00
0005433368382	1648	Economy	16700.00
0005435654174	1648	Economy	16700.00
0005433368692	1648	Economy	16700.00
0005435654160	1648	Economy	16700.00
0005435654196	1648	Economy	16700.00
0005435654203	1648	Economy	16700.00
0005435654162	1648	Economy	16700.00
0005433368554	1648	Economy	16700.00
0005433368504	1648	Economy	16700.00
0005433368557	1648	Economy	16700.00
0005435654163	1648	Economy	16700.00
0005433368505	1648	Economy	16700.00
0005433368464	1648	Economy	16700.00
0005433368474	1648	Economy	16700.00
0005433368673	1648	Economy	16700.00
0005433368455	1648	Economy	16700.00
0005435654168	1648	Economy	16700.00
0005435654187	1648	Economy	16700.00
0005435654165	1648	Economy	16700.00
0005433368582	1648	Economy	16700.00
0005435654192	1648	Economy	16700.00
0005433368355	1648	Economy	16700.00
0005433368500	1648	Economy	16700.00
0005433368383	1648	Economy	16700.00
0005435654204	1648	Economy	16700.00
0005433368361	1648	Economy	16700.00
0005435654161	1648	Economy	16700.00
0005433368497	1648	Economy	16700.00
0005433368456	1648	Economy	16700.00
0005433368473	1648	Economy	16700.00
0005435654199	1648	Economy	16700.00
0005435654188	1648	Economy	16700.00
0005435654194	1648	Economy	16700.00
0005435654166	1648	Economy	16700.00
0005433368484	1648	Economy	16700.00
0005435654159	1648	Economy	16700.00
0005435654201	1648	Economy	16700.00
0005433368489	1648	Economy	16700.00
0005433368465	1648	Economy	16700.00
0005433368454	1648	Economy	16700.00
0005433368824	21664	Business	50000.00
0005435653547	21664	Business	50000.00
0005433368810	21664	Business	50000.00
0005435653730	21664	Business	50000.00
0005435653748	21664	Business	50000.00
0005433368797	21664	Business	50000.00
0005435653814	21664	Business	50000.00
0005435653476	21664	Business	50000.00
0005435653733	21664	Business	50000.00
0005435653513	21664	Business	50000.00
0005433368794	21664	Business	50000.00
0005435653729	21664	Economy	16700.00
0005435653710	21664	Economy	16700.00
0005433368820	21664	Economy	16700.00
0005435653676	21664	Economy	16700.00
0005435653786	21664	Economy	16700.00
0005435653716	21664	Economy	16700.00
0005433368823	21664	Economy	16700.00
0005435653705	21664	Economy	16700.00
0005435653747	21664	Economy	16700.00
0005433368819	21664	Economy	18300.00
0005433368792	21664	Economy	18300.00
0005435653706	21664	Economy	18300.00
0005433368806	21664	Economy	18300.00
0005433368808	21664	Economy	18300.00
0005435653743	21664	Economy	16700.00
0005435653626	21664	Economy	16700.00
0005433368817	21664	Economy	16700.00
0005435653586	21664	Economy	16700.00
0005435653672	21664	Economy	16700.00
0005435653708	21664	Economy	16700.00
0005433368811	21664	Economy	16700.00
0005435653655	21664	Economy	16700.00
0005435653637	21664	Economy	16700.00
0005435653750	21664	Economy	16700.00
0005433368798	21664	Economy	16700.00
0005433368791	21664	Economy	16700.00
0005433368825	21664	Economy	16700.00
0005433368795	21664	Economy	16700.00
0005435653752	21664	Economy	16700.00
0005435653718	21664	Economy	16700.00
0005435653642	21664	Economy	16700.00
0005433368814	21664	Economy	16700.00
0005435653575	21664	Economy	16700.00
0005435653719	21664	Economy	16700.00
0005433368815	21664	Economy	16700.00
0005433368821	21664	Economy	16700.00
0005435653751	21664	Economy	16700.00
0005435653673	21664	Economy	16700.00
0005433368809	21664	Economy	16700.00
0005433368807	21664	Economy	16700.00
0005433368802	21664	Economy	16700.00
0005435653654	21664	Economy	16700.00
0005433368803	21664	Economy	16700.00
0005433368818	21664	Economy	16700.00
0005433368793	21664	Economy	16700.00
0005433368816	21664	Economy	16700.00
0005435653675	21664	Economy	16700.00
0005435653815	21664	Economy	16700.00
0005433368822	21664	Economy	16700.00
0005435653717	21664	Economy	16700.00
0005435653634	21664	Economy	16700.00
0005435653742	21664	Economy	16700.00
0005435653798	21664	Economy	16700.00
0005433368826	21664	Economy	16700.00
0005435653674	21664	Economy	16700.00
0005433368796	21664	Economy	16700.00
0005433368801	21664	Economy	16700.00
0005435653785	21664	Economy	16700.00
0005433368805	21664	Economy	16700.00
0005433368800	21664	Economy	16700.00
0005433368813	21664	Economy	16700.00
0005433368799	21664	Economy	16700.00
0005433368790	21664	Economy	16700.00
0005433368804	21664	Economy	16700.00
0005435653576	21664	Economy	16700.00
0005435653813	21664	Economy	16700.00
0005435653696	21664	Economy	16700.00
0005435653548	21664	Economy	16700.00
0005435653707	21664	Economy	16700.00
0005435653514	21664	Economy	16700.00
0005435653770	21664	Economy	16700.00
0005435653638	21664	Economy	16700.00
0005433368812	21664	Economy	16700.00
0005435627127	12261	Economy	11200.00
0005435627126	12261	Economy	11200.00
0005434466515	23224	Economy	23000.00
0005435312867	23224	Economy	20900.00
0005434466529	23224	Economy	20900.00
0005434466531	23224	Economy	20900.00
0005434466528	23224	Economy	20900.00
0005434466543	23224	Economy	20900.00
0005435312864	23224	Economy	20900.00
0005434466542	23224	Economy	20900.00
0005434466538	23224	Economy	20900.00
0005435312865	23224	Economy	20900.00
0005434466545	23224	Economy	20900.00
0005435312866	23224	Economy	20900.00
0005434466539	23224	Economy	20900.00
0005434466548	23224	Economy	20900.00
0005434466530	23224	Economy	20900.00
0005434466544	23224	Economy	20900.00
0005433987089	4165	Business	21500.00
0005433987123	4165	Business	21500.00
0005433987105	4165	Business	21500.00
0005433987118	4165	Business	21500.00
0005433987122	4165	Business	21500.00
0005433987126	4165	Business	21500.00
0005433987130	4165	Business	21500.00
0005433987113	4165	Business	21500.00
0005433987087	4165	Business	21500.00
0005433987104	4165	Business	21500.00
0005433987133	4165	Economy	7200.00
0005433987111	4165	Economy	7200.00
0005433987096	4165	Economy	7200.00
0005433987092	4165	Economy	7200.00
0005433987119	4165	Economy	7900.00
0005433987129	4165	Economy	7900.00
0005433987120	4165	Economy	7200.00
0005433987101	4165	Economy	7200.00
0005433987125	4165	Economy	7200.00
0005433987094	4165	Economy	7200.00
0005433987099	4165	Economy	7200.00
0005433987114	4165	Economy	7200.00
0005433987110	4165	Economy	7200.00
0005433987131	4165	Economy	7200.00
0005433987100	4165	Economy	7200.00
0005433987095	4165	Economy	7200.00
0005433987128	4165	Economy	7200.00
0005433987124	4165	Economy	7200.00
0005433987098	4165	Economy	7200.00
0005433987108	4165	Economy	7200.00
0005433987132	4165	Economy	7200.00
0005433987103	4165	Economy	7200.00
0005433987088	4165	Economy	7200.00
0005433987090	4165	Economy	7200.00
0005433987127	4165	Economy	7200.00
0005433987107	4165	Economy	7200.00
0005433987106	4165	Economy	7200.00
0005433987102	4165	Economy	7200.00
0005433987109	4165	Economy	7200.00
0005433987116	4165	Economy	7200.00
0005433987115	4165	Economy	7200.00
0005433987093	4165	Economy	7200.00
0005433987091	4165	Economy	7200.00
0005433987117	4165	Economy	7200.00
0005433987121	4165	Economy	7200.00
0005433987097	4165	Economy	7200.00
0005433987112	4165	Economy	7200.00
0005435788826	25694	Business	21500.00
0005433986590	25694	Business	21500.00
0005433986699	25694	Business	21500.00
0005433986531	25694	Business	21500.00
0005433986529	25694	Business	21500.00
0005433986728	25694	Business	21500.00
0005433986631	25694	Business	21500.00
0005433986681	25694	Economy	7200.00
0005433986554	25694	Economy	7200.00
0005433986750	25694	Economy	7200.00
0005433986732	25694	Economy	7200.00
0005433986583	25694	Economy	7200.00
0005433986796	25694	Economy	7200.00
0005433986562	25694	Economy	7900.00
0005433986759	25694	Economy	7900.00
0005433986756	25694	Economy	7900.00
0005433986698	25694	Economy	7900.00
0005433986738	25694	Economy	7200.00
0005433986702	25694	Economy	7200.00
0005433986798	25694	Economy	7200.00
0005433986780	25694	Economy	7200.00
0005433986717	25694	Economy	7200.00
0005433986503	25694	Economy	7200.00
0005433986528	25694	Economy	7200.00
0005433986785	25694	Economy	7200.00
0005433986840	25694	Economy	7200.00
0005433986695	25694	Economy	7200.00
0005433986689	25694	Economy	7200.00
0005433986490	25694	Economy	7200.00
0005433986596	25694	Economy	7200.00
0005433986709	25694	Economy	7200.00
0005433986714	25694	Economy	7200.00
0005433986711	25694	Economy	7200.00
0005433986795	25694	Economy	7200.00
0005433986735	25694	Economy	7200.00
0005435788811	25694	Economy	7200.00
0005433986734	25694	Economy	7200.00
0005433986680	25694	Economy	7200.00
0005433986703	25694	Economy	7200.00
0005433986779	25694	Economy	7200.00
0005433986560	25694	Economy	7200.00
0005433986450	25694	Economy	7200.00
0005433986561	25694	Economy	7200.00
0005433986757	25694	Economy	7200.00
0005433986558	25694	Economy	7200.00
0005433986559	25694	Economy	7200.00
0005435788827	25694	Economy	7200.00
0005433986733	25694	Economy	7200.00
0005433986555	25694	Economy	7200.00
0005433986788	25694	Economy	7200.00
0005433986442	25694	Economy	7200.00
0005433986784	25694	Economy	7200.00
0005433986763	25694	Economy	7200.00
0005433986727	25694	Economy	7200.00
0005433986530	25694	Economy	7200.00
0005433986802	25694	Economy	7200.00
0005433986731	25694	Economy	7200.00
0005433986690	25694	Economy	7200.00
0005433986760	25694	Economy	7200.00
0005433986774	25694	Economy	7200.00
0005433986614	25694	Economy	7200.00
0005433986789	25694	Economy	7200.00
0005433986694	25694	Economy	7200.00
0005433986729	25694	Economy	7200.00
0005435719577	21260	Economy	9400.00
0005435719581	21260	Economy	9400.00
0005435719575	21260	Economy	9400.00
0005435719576	21260	Economy	9400.00
0005435719590	24754	Economy	9400.00
0005435720157	24754	Economy	9400.00
0005435719591	24754	Economy	9400.00
0005435720158	24754	Economy	9400.00
0005434509331	1619	Economy	17000.00
0005434509338	1619	Economy	17000.00
0005434509329	1619	Economy	15500.00
0005434509342	1619	Economy	15500.00
0005434509341	1619	Economy	15500.00
0005434509340	1619	Economy	15500.00
0005434509334	1619	Economy	15500.00
0005434509332	1619	Economy	15500.00
0005434509336	1619	Economy	15500.00
0005434509339	1619	Economy	15500.00
0005433168441	1619	Economy	15500.00
0005433168444	1619	Economy	15500.00
0005434509335	1619	Economy	15500.00
0005434509333	1619	Economy	15500.00
0005434509328	1619	Economy	15500.00
0005434509337	1619	Economy	15500.00
0005433168442	1619	Economy	15500.00
0005433168443	1619	Economy	15500.00
0005434509330	1619	Economy	15500.00
0005434516132	9026	Economy	23600.00
0005434516130	9026	Economy	23600.00
0005434516128	9026	Economy	23600.00
0005434516131	9026	Economy	23600.00
0005434190437	9026	Economy	23600.00
0005434190433	9026	Economy	23600.00
0005434190434	9026	Economy	23600.00
0005434190432	9026	Economy	23600.00
0005434516129	9026	Economy	23600.00
0005434190443	9026	Economy	23600.00
0005434190435	9026	Economy	23600.00
0005434516126	9026	Economy	23600.00
0005434516127	9026	Economy	23600.00
0005432655708	17849	Business	18000.00
0005432655713	17849	Business	18000.00
0005432660842	17849	Business	18000.00
0005432655684	17849	Business	18000.00
0005432657505	17849	Business	18000.00
0005432658625	17849	Business	18000.00
0005432655714	17849	Economy	6000.00
0005432666424	17849	Economy	6000.00
0005432664158	17849	Economy	6000.00
0005432660843	17849	Economy	6600.00
0005432869691	17849	Economy	6600.00
0005432667493	17849	Economy	6000.00
0005432663069	17849	Economy	6000.00
0005432657504	17849	Economy	6000.00
0005432664170	17849	Economy	6000.00
0005432663070	17849	Economy	6000.00
0005432666425	17849	Economy	6000.00
0005432655732	17849	Economy	6000.00
0005432658624	17849	Economy	6000.00
0005432667494	17849	Economy	6000.00
0005432869692	17849	Economy	6000.00
0005432667492	17849	Economy	6000.00
0005432655733	17849	Economy	6000.00
0005432665311	17849	Economy	6000.00
0005432655718	17849	Economy	6000.00
0005432869694	17849	Economy	6000.00
0005432667478	17849	Economy	6000.00
0005432667487	17849	Economy	6000.00
0005432667483	17849	Economy	6000.00
0005432661955	17849	Economy	6000.00
0005432666426	17849	Economy	6000.00
0005432657503	17849	Economy	6000.00
0005432665299	17849	Economy	6000.00
0005432869695	17849	Economy	6000.00
0005432664159	17849	Economy	6000.00
0005432869689	17849	Economy	6000.00
0005432655743	17849	Economy	6000.00
0005432655731	17849	Economy	6000.00
0005432664169	17849	Economy	6000.00
0005432661954	17849	Economy	6000.00
0005432869690	17849	Economy	6000.00
0005432663060	17849	Economy	6000.00
0005432869693	17849	Economy	6000.00
0005432659754	26282	Business	18000.00
0005432665324	26282	Business	18000.00
0005432657522	26282	Business	18000.00
0005434151749	26282	Business	18000.00
0005432655807	26282	Business	18000.00
0005432655806	26282	Economy	6000.00
0005432655804	26282	Economy	6600.00
0005432869645	26282	Economy	6600.00
0005432655808	26282	Economy	6600.00
0005434151748	26282	Economy	6000.00
0005432655810	26282	Economy	6000.00
0005432658640	26282	Economy	6000.00
0005432666437	26282	Economy	6000.00
0005432666438	26282	Economy	6000.00
0005432655812	26282	Economy	6000.00
0005432655815	26282	Economy	6000.00
0005432659755	26282	Economy	6000.00
0005432660866	26282	Economy	6000.00
0005432657520	26282	Economy	6000.00
0005432655813	26282	Economy	6000.00
0005432655811	26282	Economy	6000.00
0005432657521	26282	Economy	6000.00
0005432657523	26282	Economy	6000.00
0005432659756	26282	Economy	6000.00
0005432869594	26282	Economy	6000.00
0005432869580	26282	Economy	6000.00
0005432658641	26282	Economy	6000.00
0005432660867	26282	Economy	6000.00
0005432869644	26282	Economy	6000.00
0005432869612	26282	Economy	6000.00
0005432655809	26282	Economy	6000.00
0005432655814	26282	Economy	6000.00
0005432655805	26282	Economy	6000.00
0005432869581	26282	Economy	6000.00
0005432665325	26282	Economy	6000.00
0005432639383	25076	Business	87300.00
0005432639273	25076	Business	87300.00
0005432639300	25076	Business	87300.00
0005432639357	25076	Economy	29100.00
0005432639328	25076	Economy	29100.00
0005432639325	25076	Economy	29100.00
0005432866186	25076	Economy	29100.00
0005432866181	25076	Economy	29100.00
0005432639305	25076	Economy	29100.00
0005432866188	25076	Economy	29100.00
0005432639343	25076	Economy	32000.00
0005432866192	25076	Economy	32000.00
0005432639299	25076	Economy	32000.00
0005432866182	25076	Economy	29100.00
0005432866185	25076	Economy	29100.00
0005432639302	25076	Economy	29100.00
0005432866180	25076	Economy	29100.00
0005432639303	25076	Economy	29100.00
0005432639306	25076	Economy	29100.00
0005432639339	25076	Economy	29100.00
0005432866187	25076	Economy	29100.00
0005432639308	25076	Economy	29100.00
0005432866190	25076	Economy	29100.00
0005432639315	25076	Economy	29100.00
0005432639296	25076	Economy	29100.00
0005432639326	25076	Economy	29100.00
0005432639327	25076	Economy	29100.00
0005432639319	25076	Economy	29100.00
0005432639384	25076	Economy	29100.00
0005432639335	25076	Economy	29100.00
0005432639331	25076	Economy	29100.00
0005432866184	25076	Economy	29100.00
0005432866191	25076	Economy	29100.00
0005432639340	25076	Economy	29100.00
0005432866189	25076	Economy	29100.00
0005432639257	25076	Economy	29100.00
0005432866183	25076	Economy	29100.00
0005432639256	25076	Economy	29100.00
0005432866193	25076	Economy	29100.00
0005432639295	25076	Economy	29100.00
0005432639261	25076	Economy	29100.00
0005432639318	25076	Economy	29100.00
0005432639274	25076	Economy	29100.00
0005433439043	3099	Business	16100.00
0005432329832	3099	Business	16100.00
0005432329831	3099	Business	16100.00
0005433439050	3099	Business	16100.00
0005432329841	3099	Business	16100.00
0005432329819	3099	Business	16100.00
0005432329824	3099	Business	16100.00
0005432329833	3099	Business	16100.00
0005432329843	3099	Economy	5400.00
0005432329820	3099	Economy	5400.00
0005432329838	3099	Economy	5400.00
0005433439051	3099	Economy	5400.00
0005432329823	3099	Economy	5400.00
0005432329846	3099	Economy	5400.00
0005432329847	3099	Economy	5400.00
0005432329815	3099	Economy	5400.00
0005432329830	3099	Economy	5900.00
0005432329818	3099	Economy	5900.00
0005432329836	3099	Economy	5900.00
0005432329816	3099	Economy	5900.00
0005433439048	3099	Economy	5900.00
0005432329844	3099	Economy	5400.00
0005433439044	3099	Economy	5400.00
0005433439049	3099	Economy	5400.00
0005432905212	3099	Economy	5400.00
0005433439052	3099	Economy	5400.00
0005432287314	3099	Economy	5400.00
0005432329821	3099	Economy	5400.00
0005432848849	3099	Economy	5400.00
0005433439046	3099	Economy	5400.00
0005432329852	3099	Economy	5400.00
0005432329834	3099	Economy	5400.00
0005432329842	3099	Economy	5400.00
0005433439053	3099	Economy	5400.00
0005432329840	3099	Economy	5400.00
0005432848843	3099	Economy	5400.00
0005432329828	3099	Economy	5400.00
0005432905241	3099	Economy	5400.00
0005432329839	3099	Economy	5400.00
0005432329855	3099	Economy	5400.00
0005433439055	3099	Economy	5400.00
0005432905242	3099	Economy	5400.00
0005432287315	3099	Economy	5400.00
0005432329822	3099	Economy	5400.00
0005432848846	3099	Economy	5400.00
0005433439047	3099	Economy	5400.00
0005432287313	3099	Economy	5400.00
0005432329845	3099	Economy	5400.00
0005432329857	3099	Economy	5400.00
0005433439045	3099	Economy	5400.00
0005432329849	3099	Economy	5400.00
0005432329817	3099	Economy	5400.00
0005432329850	3099	Economy	5400.00
0005432329856	3099	Economy	5400.00
0005433439054	3099	Economy	5400.00
0005432329829	3099	Economy	5400.00
0005432329835	3099	Economy	5400.00
0005432329853	3099	Economy	5400.00
0005432329848	3099	Economy	5400.00
0005432329854	3099	Economy	5400.00
0005432329827	3099	Economy	5400.00
0005432329826	3099	Economy	5400.00
0005432329851	3099	Economy	5400.00
0005432329814	3099	Economy	5400.00
0005432329837	3099	Economy	5400.00
0005432848851	3099	Economy	5400.00
0005432329825	3099	Economy	5400.00
0005432329200	31110	Business	16100.00
0005432054376	31110	Business	16100.00
0005432329361	31110	Business	16100.00
0005432329357	31110	Business	16100.00
0005432329462	31110	Business	16100.00
0005432329487	31110	Business	16100.00
0005432054377	31110	Business	16100.00
0005432329406	31110	Economy	5400.00
0005432054379	31110	Economy	5400.00
0005432329486	31110	Economy	5400.00
0005432329311	31110	Economy	5400.00
0005432329046	31110	Economy	5400.00
0005432329393	31110	Economy	5400.00
0005432329453	31110	Economy	5400.00
0005432329377	31110	Economy	5400.00
0005432329535	31110	Economy	5900.00
0005432329452	31110	Economy	5900.00
0005432329352	31110	Economy	5900.00
0005432329560	31110	Economy	5900.00
0005432329391	31110	Economy	5400.00
0005432329310	31110	Economy	5400.00
0005432329405	31110	Economy	5400.00
0005432329449	31110	Economy	5400.00
0005432329368	31110	Economy	5400.00
0005432329446	31110	Economy	5400.00
0005432329371	31110	Economy	5400.00
0005432329403	31110	Economy	5400.00
0005432329414	31110	Economy	5400.00
0005432329492	31110	Economy	5400.00
0005432329255	31110	Economy	5400.00
0005432329194	31110	Economy	5400.00
0005432329315	31110	Economy	5400.00
0005432329370	31110	Economy	5400.00
0005432329404	31110	Economy	5400.00
0005432054378	31110	Economy	5400.00
0005432329389	31110	Economy	5400.00
0005432329507	31110	Economy	5400.00
0005432329561	31110	Economy	5400.00
0005432329448	31110	Economy	5400.00
0005432329241	31110	Economy	5400.00
0005432329407	31110	Economy	5400.00
0005432329534	31110	Economy	5400.00
0005432329450	31110	Economy	5400.00
0005432329521	31110	Economy	5400.00
0005432329423	31110	Economy	5400.00
0005432329275	31110	Economy	5400.00
0005432329280	31110	Economy	5400.00
0005432329455	31110	Economy	5400.00
0005432329392	31110	Economy	5400.00
0005432329563	31110	Economy	5400.00
0005432329491	31110	Economy	5400.00
0005432329287	31110	Economy	5400.00
0005432329415	31110	Economy	5400.00
0005432329500	31110	Economy	5400.00
0005432329532	31110	Economy	5400.00
0005432329231	31110	Economy	5400.00
0005432329522	31110	Economy	5400.00
0005432329154	31110	Economy	5400.00
0005432329369	31110	Economy	5400.00
0005432329451	31110	Economy	5400.00
0005432329533	31110	Economy	5400.00
0005432329523	31110	Economy	5400.00
0005432329286	31110	Economy	5400.00
0005432329562	31110	Economy	5400.00
0005432329501	31110	Economy	5400.00
0005432329413	31110	Economy	5400.00
0005432329401	31110	Economy	5400.00
0005432329447	31110	Economy	5400.00
0005432329402	31110	Economy	5400.00
0005432329412	31110	Economy	5400.00
0005432329454	31110	Economy	5400.00
0005435999703	6183	Business	124600.00
0005435999715	6183	Business	124600.00
0005434310079	6183	Business	124600.00
0005435999716	6183	Economy	41500.00
0005434310086	6183	Economy	41500.00
0005435999711	6183	Economy	41500.00
0005435488116	6183	Economy	41500.00
0005435488125	6183	Economy	41500.00
0005435999707	6183	Economy	41500.00
0005434310075	6183	Economy	41500.00
0005432146253	6183	Economy	41500.00
0005435999702	6183	Economy	41500.00
0005435488202	6183	Economy	41500.00
0005434310083	6183	Economy	41500.00
0005435488082	6183	Economy	41500.00
0005435488230	6183	Economy	41500.00
0005435488129	6183	Economy	41500.00
0005435488219	6183	Economy	41500.00
0005435999701	6183	Economy	41500.00
0005434310082	6183	Economy	41500.00
0005435999700	6183	Economy	41500.00
0005435488177	6183	Economy	41500.00
0005434310077	6183	Economy	41500.00
0005435999712	6183	Economy	41500.00
0005435999699	6183	Economy	41500.00
0005434310087	6183	Economy	41500.00
0005435488122	6183	Economy	45700.00
0005435488077	6183	Economy	45700.00
0005435488110	6183	Economy	41500.00
0005432146252	6183	Economy	41500.00
0005435999698	6183	Economy	41500.00
0005435488123	6183	Economy	41500.00
0005434310081	6183	Economy	41500.00
0005435488260	6183	Economy	41500.00
0005435488170	6183	Economy	41500.00
0005434310076	6183	Economy	41500.00
0005432146251	6183	Economy	41500.00
0005435999709	6183	Economy	41500.00
0005435488057	6183	Economy	41500.00
0005435999705	6183	Economy	41500.00
0005435999713	6183	Economy	41500.00
0005434310084	6183	Economy	41500.00
0005435488103	6183	Economy	41500.00
0005435999710	6183	Economy	41500.00
0005435488187	6183	Economy	41500.00
0005435297163	6183	Economy	41500.00
0005435488058	6183	Economy	41500.00
0005435488117	6183	Economy	41500.00
0005435488155	6183	Economy	41500.00
0005434310080	6183	Economy	41500.00
0005435488130	6183	Economy	41500.00
0005434310085	6183	Economy	41500.00
0005435488104	6183	Economy	41500.00
0005435999714	6183	Economy	41500.00
0005435488229	6183	Economy	41500.00
0005435999706	6183	Economy	41500.00
0005435999704	6183	Economy	41500.00
0005435488124	6183	Economy	41500.00
0005434310078	6183	Economy	41500.00
0005435488078	6183	Economy	41500.00
0005435488231	6183	Economy	41500.00
0005435488154	6183	Economy	41500.00
0005435999708	6183	Economy	41500.00
0005435488118	6183	Economy	41500.00
0005434309941	19582	Business	124600.00
0005434309909	19582	Business	124600.00
0005435297226	19582	Business	124600.00
0005435297229	19582	Business	124600.00
0005434309977	19582	Economy	41500.00
0005435488345	19582	Economy	41500.00
0005435488357	19582	Economy	41500.00
0005435297228	19582	Economy	41500.00
0005435297230	19582	Economy	41500.00
0005435488348	19582	Economy	41500.00
0005435297231	19582	Economy	41500.00
0005434309925	19582	Economy	41500.00
0005435488352	19582	Economy	41500.00
0005435488360	19582	Economy	41500.00
0005435999485	19582	Economy	41500.00
0005435999460	19582	Economy	41500.00
0005435297227	19582	Economy	41500.00
0005434309971	19582	Economy	41500.00
0005435999569	19582	Economy	41500.00
0005435488351	19582	Economy	41500.00
0005434309976	19582	Economy	41500.00
0005434310000	19582	Economy	41500.00
0005434309969	19582	Economy	41500.00
0005435999529	19582	Economy	45700.00
0005434309931	19582	Economy	41500.00
0005435488344	19582	Economy	41500.00
0005435999482	19582	Economy	41500.00
0005435297232	19582	Economy	41500.00
0005435999483	19582	Economy	41500.00
0005435999576	19582	Economy	41500.00
0005435999557	19582	Economy	41500.00
0005435999502	19582	Economy	41500.00
0005435488358	19582	Economy	41500.00
0005435999439	19582	Economy	41500.00
0005435488343	19582	Economy	41500.00
0005435488361	19582	Economy	41500.00
0005435999586	19582	Economy	41500.00
0005435999522	19582	Economy	41500.00
0005435999496	19582	Economy	41500.00
0005434309956	19582	Economy	41500.00
0005435488342	19582	Economy	41500.00
0005435999562	19582	Economy	41500.00
0005435488356	19582	Economy	41500.00
0005435488355	19582	Economy	41500.00
0005435999459	19582	Economy	41500.00
0005435488349	19582	Economy	41500.00
0005434309979	19582	Economy	41500.00
0005434309972	19582	Economy	41500.00
0005435488350	19582	Economy	41500.00
0005435488340	19582	Economy	41500.00
0005435488347	19582	Economy	41500.00
0005435488359	19582	Economy	41500.00
0005434309955	19582	Economy	41500.00
0005435488353	19582	Economy	41500.00
0005435999503	19582	Economy	41500.00
0005435488341	19582	Economy	41500.00
0005435488346	19582	Economy	41500.00
0005435488354	19582	Economy	41500.00
0005435508717	1573	Business	86000.00
0005435518355	1573	Business	86000.00
0005435508707	1573	Business	86000.00
0005435518360	1573	Business	86000.00
0005435508720	1573	Business	86000.00
0005435508715	1573	Business	86000.00
0005433186261	1573	Business	86000.00
0005433186281	1573	Business	86000.00
0005434566242	1573	Business	86000.00
0005435518363	1573	Business	86000.00
0005434566252	1573	Business	86000.00
0005434566255	1573	Business	86000.00
0005435518353	1573	Economy	28700.00
0005435502840	1573	Economy	28700.00
0005435508721	1573	Economy	28700.00
0005434566246	1573	Economy	28700.00
0005434566245	1573	Economy	28700.00
0005435502851	1573	Economy	28700.00
0005434566243	1573	Economy	28700.00
0005435518357	1573	Economy	31500.00
0005433186225	1573	Economy	31500.00
0005433186262	1573	Economy	31500.00
0005435502856	1573	Economy	31500.00
0005435502841	1573	Economy	31500.00
0005435508725	1573	Economy	28700.00
0005435518351	1573	Economy	28700.00
0005435508723	1573	Economy	28700.00
0005434566247	1573	Economy	28700.00
0005434566248	1573	Economy	28700.00
0005435508714	1573	Economy	28700.00
0005434566254	1573	Economy	28700.00
0005433186246	1573	Economy	28700.00
0005435502848	1573	Economy	28700.00
0005433186291	1573	Economy	28700.00
0005433186247	1573	Economy	28700.00
0005435518361	1573	Economy	28700.00
0005433186264	1573	Economy	28700.00
0005435502853	1573	Economy	28700.00
0005435502854	1573	Economy	28700.00
0005432291993	1573	Economy	28700.00
0005435518349	1573	Economy	28700.00
0005432291992	1573	Economy	28700.00
0005435502849	1573	Economy	28700.00
0005435502843	1573	Economy	28700.00
0005435502852	1573	Economy	28700.00
0005434566250	1573	Economy	28700.00
0005433186282	1573	Economy	28700.00
0005435508718	1573	Economy	28700.00
0005435508726	1573	Economy	28700.00
0005435518358	1573	Economy	28700.00
0005435508712	1573	Economy	28700.00
0005435518356	1573	Economy	28700.00
0005435502861	1573	Economy	28700.00
0005435518365	1573	Economy	28700.00
0005435508716	1573	Economy	28700.00
0005434566244	1573	Economy	28700.00
0005435502844	1573	Economy	28700.00
0005435518354	1573	Economy	28700.00
0005432291990	1573	Economy	28700.00
0005435508709	1573	Economy	28700.00
0005435502847	1573	Economy	28700.00
0005435508711	1573	Economy	28700.00
0005435518350	1573	Economy	28700.00
0005435518364	1573	Economy	28700.00
0005435508722	1573	Economy	28700.00
0005435518352	1573	Economy	28700.00
0005435518366	1573	Economy	28700.00
0005434566249	1573	Economy	28700.00
0005435508713	1573	Economy	28700.00
0005435518359	1573	Economy	28700.00
0005433186245	1573	Economy	28700.00
0005435508708	1573	Economy	28700.00
0005435508727	1573	Economy	28700.00
0005434566251	1573	Economy	28700.00
0005433186265	1573	Economy	28700.00
0005435502859	1573	Economy	28700.00
0005435502850	1573	Economy	28700.00
0005435502858	1573	Economy	28700.00
0005432291991	1573	Economy	28700.00
0005435502845	1573	Economy	28700.00
0005435508719	1573	Economy	28700.00
0005435502846	1573	Economy	28700.00
0005434566253	1573	Economy	28700.00
0005435502860	1573	Economy	28700.00
0005435508724	1573	Economy	28700.00
0005433186227	1573	Economy	28700.00
0005435502855	1573	Economy	28700.00
0005435508710	1573	Economy	28700.00
0005435518362	1573	Economy	28700.00
0005435502842	1573	Economy	28700.00
0005435502857	1573	Economy	28700.00
0005433186327	20875	Business	86000.00
0005434566165	20875	Business	86000.00
0005435529497	20875	Business	86000.00
0005435529541	20875	Business	86000.00
0005434566172	20875	Business	86000.00
0005435502528	20875	Business	86000.00
0005435502529	20875	Business	86000.00
0005435502584	20875	Business	86000.00
0005433186332	20875	Business	86000.00
0005435529623	20875	Business	86000.00
0005434566181	20875	Business	86000.00
0005434566101	20875	Economy	28700.00
0005435502622	20875	Economy	28700.00
0005435502600	20875	Economy	28700.00
0005434566126	20875	Economy	28700.00
0005435502598	20875	Economy	28700.00
0005435502629	20875	Economy	28700.00
0005434566135	20875	Economy	28700.00
0005435502674	20875	Economy	28700.00
0005435502661	20875	Economy	28700.00
0005435502583	20875	Economy	31500.00
0005435502603	20875	Economy	31500.00
0005435502527	20875	Economy	31500.00
0005433186333	20875	Economy	31500.00
0005435529593	20875	Economy	31500.00
0005435529565	20875	Economy	28700.00
0005434566071	20875	Economy	28700.00
0005435502754	20875	Economy	28700.00
0005435502553	20875	Economy	28700.00
0005433186329	20875	Economy	28700.00
0005435502621	20875	Economy	28700.00
0005435502738	20875	Economy	28700.00
0005434566134	20875	Economy	28700.00
0005435529606	20875	Economy	28700.00
0005435529607	20875	Economy	28700.00
0005435529539	20875	Economy	28700.00
0005434566103	20875	Economy	28700.00
0005435502599	20875	Economy	28700.00
0005435502772	20875	Economy	28700.00
0005435529622	20875	Economy	28700.00
0005435502666	20875	Economy	28700.00
0005435502616	20875	Economy	28700.00
0005435502602	20875	Economy	28700.00
0005435502662	20875	Economy	28700.00
0005435502601	20875	Economy	28700.00
0005435502706	20875	Economy	28700.00
0005435529604	20875	Economy	28700.00
0005435502549	20875	Economy	28700.00
0005433186334	20875	Economy	28700.00
0005435502613	20875	Economy	28700.00
0005433186328	20875	Economy	28700.00
0005433186335	20875	Economy	28700.00
0005435529540	20875	Economy	28700.00
0005435502609	20875	Economy	28700.00
0005435502623	20875	Economy	28700.00
0005435529605	20875	Economy	28700.00
0005435529566	20875	Economy	28700.00
0005435529522	20875	Economy	28700.00
0005434566100	20875	Economy	28700.00
0005434566143	20875	Economy	28700.00
0005434566166	20875	Economy	28700.00
0005435502628	20875	Economy	28700.00
0005434566124	20875	Economy	28700.00
0005433186330	20875	Economy	28700.00
0005435502705	20875	Economy	28700.00
0005435502761	20875	Economy	28700.00
0005435502675	20875	Economy	28700.00
0005435502606	20875	Economy	28700.00
0005435502710	20875	Economy	28700.00
0005435529579	20875	Economy	28700.00
0005434566072	20875	Economy	28700.00
0005435529520	20875	Economy	28700.00
0005435529621	20875	Economy	28700.00
0005435529620	20875	Economy	28700.00
0005434566064	20875	Economy	28700.00
0005435502645	20875	Economy	28700.00
0005435545801	20875	Economy	28700.00
0005435502663	20875	Economy	28700.00
0005435502624	20875	Economy	28700.00
0005435502626	20875	Economy	28700.00
0005435502607	20875	Economy	28700.00
0005435502673	20875	Economy	28700.00
0005435502560	20875	Economy	28700.00
0005435529418	20875	Economy	28700.00
0005433186331	20875	Economy	28700.00
0005435529551	20875	Economy	28700.00
0005435529597	20875	Economy	28700.00
0005435153908	3928	Economy	21600.00
0005435931671	3928	Economy	21600.00
0005435142985	3928	Economy	19700.00
0005435153904	3928	Economy	19700.00
0005435931655	3928	Economy	19700.00
0005435153907	3928	Economy	19700.00
0005435142986	3928	Economy	19700.00
0005435153906	3928	Economy	19700.00
0005435153903	3928	Economy	19700.00
0005435931670	3928	Economy	19700.00
0005435153910	3928	Economy	19700.00
0005435153905	3928	Economy	19700.00
0005435142984	3928	Economy	19700.00
0005435931656	3928	Economy	19700.00
0005435153909	3928	Economy	19700.00
0005435142987	3928	Economy	19700.00
0005435153860	21888	Economy	21600.00
0005435153856	21888	Economy	19700.00
0005435931696	21888	Economy	19700.00
0005435153864	21888	Economy	19700.00
0005435931693	21888	Economy	19700.00
0005435153845	21888	Economy	19700.00
0005435153853	21888	Economy	19700.00
0005435931695	21888	Economy	19700.00
0005435931694	21888	Economy	19700.00
0005432629221	7195	Economy	14300.00
0005432629217	7195	Economy	14300.00
0005432629219	7195	Economy	13000.00
0005435225738	7195	Economy	13000.00
0005432629215	7195	Economy	13000.00
0005432629212	7195	Economy	13000.00
0005432629216	7195	Economy	13000.00
0005432629207	7195	Economy	13000.00
0005432629213	7195	Economy	13000.00
0005435225737	7195	Economy	13000.00
0005432629214	7195	Economy	13000.00
0005432629218	7195	Economy	13000.00
0005432629210	7195	Economy	13000.00
0005432629209	7195	Economy	13000.00
0005435225714	7195	Economy	13000.00
0005432629211	7195	Economy	13000.00
0005432629208	7195	Economy	13000.00
0005432629220	7195	Economy	13000.00
0005432629090	28098	Economy	14300.00
0005432629077	28098	Economy	14300.00
0005435225781	28098	Economy	14300.00
0005432629040	28098	Economy	13000.00
0005432629039	28098	Economy	13000.00
0005432629051	28098	Economy	13000.00
0005432629102	28098	Economy	13000.00
0005435225784	28098	Economy	13000.00
0005435225783	28098	Economy	13000.00
0005432629091	28098	Economy	13000.00
0005435225779	28098	Economy	13000.00
0005435225782	28098	Economy	13000.00
0005432629101	28098	Economy	13000.00
0005432629041	28098	Economy	13000.00
0005432629128	28098	Economy	13000.00
0005432629111	28098	Economy	13000.00
0005432629050	28098	Economy	13000.00
0005432629052	28098	Economy	13000.00
0005435225780	28098	Economy	13000.00
0005432629166	28098	Economy	13000.00
0005432629165	28098	Economy	13000.00
0005432629047	28098	Economy	13000.00
0005435960145	8722	Economy	11500.00
0005434268014	8722	Economy	11500.00
0005434268015	8722	Economy	11500.00
0005434268022	8722	Economy	10500.00
0005435960144	8722	Economy	10500.00
0005435960147	8722	Economy	10500.00
0005435960146	8722	Economy	10500.00
0005434268009	8722	Economy	10500.00
0005434268021	8722	Economy	10500.00
0005434268008	8722	Economy	10500.00
0005435960108	15226	Economy	11500.00
0005435960117	15226	Economy	10500.00
0005435960118	15226	Economy	10500.00
0005434268046	15226	Economy	10500.00
0005434268042	15226	Economy	10500.00
0005435960105	15226	Economy	10500.00
0005434268045	15226	Economy	10500.00
0005435960114	15226	Economy	10500.00
0005435960109	15226	Economy	10500.00
0005434268043	15226	Economy	10500.00
0005434268044	15226	Economy	10500.00
0005432675513	1161	Business	115000.00
0005432675510	1161	Business	115000.00
0005432873411	1161	Business	115000.00
0005432873394	1161	Business	115000.00
0005432693815	1161	Business	115000.00
0005432693793	1161	Business	115000.00
0005432693803	1161	Business	115000.00
0005432693792	1161	Business	115000.00
0005432693807	1161	Business	115000.00
0005432693797	1161	Business	115000.00
0005432675514	1161	Business	115000.00
0005432693810	1161	Business	115000.00
0005432677669	1161	Business	115000.00
0005432675503	1161	Business	115000.00
0005432693811	1161	Business	115000.00
0005432693806	1161	Business	115000.00
0005432693791	1161	Economy	38300.00
0005432693802	1161	Economy	38300.00
0005432873401	1161	Economy	38300.00
0005432675515	1161	Economy	38300.00
0005432693790	1161	Economy	38300.00
0005432677667	1161	Economy	38300.00
0005432677666	1161	Economy	38300.00
0005432873418	1161	Economy	38300.00
0005432675504	1161	Economy	42200.00
0005432693808	1161	Economy	42200.00
0005432873417	1161	Economy	38300.00
0005432693788	1161	Economy	38300.00
0005432873402	1161	Economy	38300.00
0005432693812	1161	Economy	38300.00
0005432675512	1161	Economy	38300.00
0005432693796	1161	Economy	38300.00
0005432693789	1161	Economy	38300.00
0005432677668	1161	Economy	38300.00
0005432693801	1161	Economy	38300.00
0005432693798	1161	Economy	38300.00
0005432693805	1161	Economy	38300.00
0005432675505	1161	Economy	38300.00
0005432693799	1161	Economy	38300.00
0005432693795	1161	Economy	38300.00
0005432675506	1161	Economy	38300.00
0005432675507	1161	Economy	38300.00
0005432693800	1161	Economy	38300.00
0005432693794	1161	Economy	38300.00
0005432675508	1161	Economy	38300.00
0005432675511	1161	Economy	38300.00
0005432693809	1161	Economy	38300.00
0005432675502	1161	Economy	38300.00
0005432873393	1161	Economy	38300.00
0005432693787	1161	Economy	38300.00
0005432873400	1161	Economy	38300.00
0005432873429	1161	Economy	38300.00
0005432693804	1161	Economy	38300.00
0005432873410	1161	Economy	38300.00
0005432693813	1161	Economy	38300.00
0005432693814	1161	Economy	38300.00
0005432675509	1161	Economy	38300.00
0005432873428	1161	Economy	38300.00
0005432693421	17489	Business	115000.00
0005432693589	17489	Business	115000.00
0005432873466	17489	Business	115000.00
0005432675447	17489	Business	115000.00
0005432873470	17489	Business	115000.00
0005432675446	17489	Business	115000.00
0005432693485	17489	Business	115000.00
0005432693483	17489	Business	115000.00
0005432873467	17489	Economy	38300.00
0005432693510	17489	Economy	38300.00
0005432873472	17489	Economy	38300.00
0005432693691	17489	Economy	38300.00
0005432693680	17489	Economy	38300.00
0005432693606	17489	Economy	38300.00
0005432693456	17489	Economy	38300.00
0005432693628	17489	Economy	38300.00
0005432693508	17489	Economy	38300.00
0005432693491	17489	Economy	38300.00
0005432693484	17489	Economy	38300.00
0005432693469	17489	Economy	38300.00
0005432873465	17489	Economy	38300.00
0005432675360	17489	Economy	38300.00
0005432693532	17489	Economy	38300.00
0005432677624	17489	Economy	38300.00
0005432693638	17489	Economy	38300.00
0005432873469	17489	Economy	38300.00
0005432693507	17489	Economy	38300.00
0005432693533	17489	Economy	38300.00
0005432693618	17489	Economy	38300.00
0005432693481	17489	Economy	38300.00
0005432693520	17489	Economy	38300.00
0005432675400	17489	Economy	38300.00
0005432693470	17489	Economy	38300.00
0005432675448	17489	Economy	38300.00
0005432693692	17489	Economy	38300.00
0005432677623	17489	Economy	38300.00
0005432693457	17489	Economy	38300.00
0005432873471	17489	Economy	38300.00
0005432693530	17489	Economy	38300.00
0005432693513	17489	Economy	38300.00
0005432693509	17489	Economy	38300.00
0005432693374	17489	Economy	38300.00
0005432693588	17489	Economy	38300.00
0005432693605	17489	Economy	38300.00
0005432693350	17489	Economy	38300.00
0005432693566	17489	Economy	38300.00
0005432693627	17489	Economy	38300.00
0005432693432	17489	Economy	38300.00
0005432675312	17489	Economy	38300.00
0005432693526	17489	Economy	38300.00
0005432873468	17489	Economy	38300.00
0005434435563	1137	Economy	15200.00
0005433156909	1137	Economy	15200.00
0005434435569	1137	Economy	13900.00
0005434435564	1137	Economy	13900.00
0005433156888	1137	Economy	13900.00
0005433156919	1137	Economy	13900.00
0005433156887	1137	Economy	13900.00
0005434435567	1137	Economy	13900.00
0005434435560	1137	Economy	13900.00
0005433156898	1137	Economy	13900.00
0005433156869	1137	Economy	13900.00
0005434435559	1137	Economy	13900.00
0005433156901	1137	Economy	13900.00
0005433156897	1137	Economy	13900.00
0005434435565	1137	Economy	13900.00
0005434435562	1137	Economy	13900.00
0005434435561	1137	Economy	13900.00
0005433156903	1137	Economy	13900.00
0005434435557	1137	Economy	13900.00
0005434435558	1137	Economy	13900.00
0005433156870	1137	Economy	13900.00
0005434435566	1137	Economy	13900.00
0005433156881	1137	Economy	13900.00
0005433156889	1137	Economy	13900.00
0005434435556	1137	Economy	13900.00
0005433156882	1137	Economy	13900.00
0005434435570	1137	Economy	13900.00
0005434435571	1137	Economy	13900.00
0005434435568	1137	Economy	13900.00
0005434435487	17276	Economy	15200.00
0005433156968	17276	Economy	13900.00
0005434435438	17276	Economy	13900.00
0005433156965	17276	Economy	13900.00
0005433156961	17276	Economy	13900.00
0005434435427	17276	Economy	13900.00
0005434435486	17276	Economy	13900.00
0005434435385	17276	Economy	13900.00
0005433156962	17276	Economy	13900.00
0005434435368	17276	Economy	13900.00
0005434435426	17276	Economy	13900.00
0005434435434	17276	Economy	13900.00
0005434435390	17276	Economy	13900.00
0005434435439	17276	Economy	13900.00
0005433156963	17276	Economy	13900.00
0005434435386	17276	Economy	13900.00
0005434435467	17276	Economy	13900.00
0005434435392	17276	Economy	13900.00
0005433156960	17276	Economy	13900.00
0005434435391	17276	Economy	13900.00
0005433156967	17276	Economy	13900.00
0005434435384	17276	Economy	13900.00
0005433156966	17276	Economy	13900.00
0005434435470	17276	Economy	13900.00
0005433156964	17276	Economy	13900.00
0005434435432	17276	Economy	13900.00
0005435087024	4087	Economy	8200.00
0005435087020	4087	Economy	7500.00
0005435928219	4087	Economy	7500.00
0005435087023	4087	Economy	7500.00
0005435087019	4087	Economy	7500.00
0005435087022	4087	Economy	7500.00
0005435087025	4087	Economy	7500.00
0005435087018	4087	Economy	7500.00
0005435087021	4087	Economy	7500.00
0005435928262	24380	Economy	8200.00
0005435086975	24380	Economy	7500.00
0005435928261	24380	Economy	7500.00
0005435086974	24380	Economy	7500.00
0005435086946	24380	Economy	7500.00
0005435086964	24380	Economy	7500.00
0005435086995	24380	Economy	7500.00
0005435928264	24380	Economy	7500.00
0005435086994	24380	Economy	7500.00
0005435928263	24380	Economy	7500.00
0005435086941	24380	Economy	7500.00
0005435086973	24380	Economy	7500.00
0005435928260	24380	Economy	7500.00
0005435086958	24380	Economy	7500.00
0005435551694	11064	Business	144300.00
0005435551658	11064	Business	144300.00
0005435551663	11064	Business	144300.00
0005435098586	11064	Business	144300.00
0005435551674	11064	Business	144300.00
0005435551634	11064	Economy	52900.00
0005435551672	11064	Economy	48100.00
0005435551664	11064	Economy	48100.00
0005435098583	11064	Economy	48100.00
0005435551666	11064	Economy	48100.00
0005435098574	11064	Economy	48100.00
0005435551671	11064	Economy	48100.00
0005435551675	11064	Economy	48100.00
0005435551659	11064	Economy	48100.00
0005435551662	11064	Economy	48100.00
0005435551680	11064	Economy	48100.00
0005435098575	11064	Economy	48100.00
0005435551690	11064	Economy	48100.00
0005435551695	11064	Economy	48100.00
0005435551665	11064	Economy	48100.00
0005435551684	11064	Economy	48100.00
0005435551678	11064	Economy	48100.00
0005435551677	11064	Economy	48100.00
0005435551693	11064	Economy	48100.00
0005435551635	11064	Economy	48100.00
0005435551668	11064	Economy	48100.00
0005435551673	11064	Economy	48100.00
0005435551655	11064	Economy	48100.00
0005435551679	11064	Economy	48100.00
0005435551656	11064	Economy	48100.00
0005435551689	11064	Economy	48100.00
0005435706769	2444	Business	86800.00
0005435706774	2444	Business	86800.00
0005433373669	2444	Business	86800.00
0005433373663	2444	Business	86800.00
0005435706793	2444	Business	86800.00
0005433373652	2444	Business	86800.00
0005433373691	2444	Economy	28900.00
0005433373651	2444	Economy	28900.00
0005435706797	2444	Economy	28900.00
0005435706785	2444	Economy	28900.00
0005435706779	2444	Economy	28900.00
0005433373668	2444	Economy	28900.00
0005433373659	2444	Economy	31800.00
0005435706778	2444	Economy	31800.00
0005435706792	2444	Economy	28900.00
0005435706775	2444	Economy	28900.00
0005435706794	2444	Economy	28900.00
0005433373665	2444	Economy	28900.00
0005435706770	2444	Economy	28900.00
0005435706782	2444	Economy	28900.00
0005433373654	2444	Economy	28900.00
0005435706783	2444	Economy	28900.00
0005435706800	2444	Economy	28900.00
0005433373674	2444	Economy	28900.00
0005435706789	2444	Economy	28900.00
0005435706777	2444	Economy	28900.00
0005435706773	2444	Economy	28900.00
0005435706799	2444	Economy	28900.00
0005435706784	2444	Economy	28900.00
0005435706781	2444	Economy	28900.00
0005435706776	2444	Economy	28900.00
0005433373684	2444	Economy	28900.00
0005435706790	2444	Economy	28900.00
0005435706772	2444	Economy	28900.00
0005435706791	2444	Economy	28900.00
0005435706795	2444	Economy	28900.00
0005433373648	2444	Economy	28900.00
0005433373685	2444	Economy	28900.00
0005435706788	2444	Economy	28900.00
0005435706798	2444	Economy	28900.00
0005433373686	2444	Economy	28900.00
0005435706771	2444	Economy	28900.00
0005435706780	2444	Economy	28900.00
0005435706768	2444	Economy	28900.00
0005435706787	2444	Economy	28900.00
0005433373638	2444	Economy	28900.00
0005433373639	2444	Economy	28900.00
0005433373666	2444	Economy	28900.00
0005433373621	2444	Economy	28900.00
0005435706796	2444	Economy	28900.00
0005433373667	2444	Economy	28900.00
0005435706786	2444	Economy	28900.00
0005435706653	27030	Business	86800.00
0005433373761	27030	Business	86800.00
0005435706638	27030	Economy	28900.00
0005433373763	27030	Economy	28900.00
0005435706667	27030	Economy	28900.00
0005435706607	27030	Economy	28900.00
0005433373764	27030	Economy	28900.00
0005433373754	27030	Economy	28900.00
0005435706637	27030	Economy	31800.00
0005435706640	27030	Economy	31800.00
0005435706593	27030	Economy	28900.00
0005433373748	27030	Economy	28900.00
0005435706631	27030	Economy	28900.00
0005433373752	27030	Economy	28900.00
0005435706652	27030	Economy	28900.00
0005433373750	27030	Economy	28900.00
0005435706632	27030	Economy	28900.00
0005433373760	27030	Economy	28900.00
0005435706668	27030	Economy	28900.00
0005435706676	27030	Economy	28900.00
0005433373756	27030	Economy	28900.00
0005435706577	27030	Economy	28900.00
0005435706615	27030	Economy	28900.00
0005433373759	27030	Economy	28900.00
0005433373749	27030	Economy	28900.00
0005433373757	27030	Economy	28900.00
0005435706587	27030	Economy	28900.00
0005435706616	27030	Economy	28900.00
0005433373758	27030	Economy	28900.00
0005435706586	27030	Economy	28900.00
0005433373751	27030	Economy	28900.00
0005435706620	27030	Economy	28900.00
0005433373765	27030	Economy	28900.00
0005435706681	27030	Economy	28900.00
0005433373762	27030	Economy	28900.00
0005435706572	27030	Economy	28900.00
0005435706571	27030	Economy	28900.00
0005435706594	27030	Economy	28900.00
0005435706570	27030	Economy	28900.00
0005435706633	27030	Economy	28900.00
0005435706581	27030	Economy	28900.00
0005433373753	27030	Economy	28900.00
0005433373755	27030	Economy	28900.00
0005435706582	27030	Economy	28900.00
0005434964696	1312	Business	203300.00
0005434964690	1312	Business	203300.00
0005433261657	1312	Business	203300.00
0005433261681	1312	Business	203300.00
0005434964680	1312	Business	203300.00
0005433261762	1312	Business	203300.00
0005434964694	1312	Economy	67800.00
0005434964691	1312	Economy	67800.00
0005434964683	1312	Economy	67800.00
0005434964693	1312	Economy	67800.00
0005434964698	1312	Economy	67800.00
0005433261706	1312	Economy	67800.00
0005433261699	1312	Economy	67800.00
0005433261700	1312	Economy	67800.00
0005434964701	1312	Economy	67800.00
0005434964686	1312	Economy	67800.00
0005434964699	1312	Economy	67800.00
0005434964703	1312	Economy	67800.00
0005434964681	1312	Economy	67800.00
0005434964677	1312	Economy	67800.00
0005432279326	1312	Economy	67800.00
0005434964676	1312	Economy	67800.00
0005432279324	1312	Economy	67800.00
0005434964708	1312	Economy	67800.00
0005434964682	1312	Economy	67800.00
0005434964704	1312	Economy	67800.00
0005434964687	1312	Economy	67800.00
0005434964678	1312	Economy	67800.00
0005434964692	1312	Economy	67800.00
0005434964689	1312	Economy	67800.00
0005432279327	1312	Economy	67800.00
0005434964706	1312	Economy	67800.00
0005434964709	1312	Economy	67800.00
0005433261740	1312	Economy	67800.00
0005433261704	1312	Economy	74500.00
0005433261737	1312	Economy	74500.00
0005434964700	1312	Economy	67800.00
0005432279325	1312	Economy	67800.00
0005434964688	1312	Economy	67800.00
0005434964685	1312	Economy	67800.00
0005434964695	1312	Economy	67800.00
0005433261698	1312	Economy	67800.00
0005434964697	1312	Economy	67800.00
0005434964679	1312	Economy	67800.00
0005434964707	1312	Economy	67800.00
0005433261739	1312	Economy	67800.00
0005433261707	1312	Economy	67800.00
0005434964684	1312	Economy	67800.00
0005434964702	1312	Economy	67800.00
0005433261682	1312	Economy	67800.00
0005434964705	1312	Economy	67800.00
0005433261796	18240	Business	203300.00
0005434964567	18240	Business	203300.00
0005434964549	18240	Business	203300.00
0005434964560	18240	Business	203300.00
0005434964539	18240	Business	203300.00
0005433261818	18240	Business	203300.00
0005433261803	18240	Business	203300.00
0005434964571	18240	Business	203300.00
0005434964568	18240	Business	203300.00
0005433261822	18240	Business	203300.00
0005433261813	18240	Business	203300.00
0005434964580	18240	Economy	74500.00
0005434964602	18240	Economy	74500.00
0005434964538	18240	Economy	74500.00
0005434964559	18240	Economy	67800.00
0005434964433	18240	Economy	67800.00
0005434964478	18240	Economy	67800.00
0005433261799	18240	Economy	67800.00
0005434964509	18240	Economy	67800.00
0005433261801	18240	Economy	67800.00
0005434964451	18240	Economy	67800.00
0005433261814	18240	Economy	67800.00
0005433261820	18240	Economy	67800.00
0005434964464	18240	Economy	67800.00
0005434964612	18240	Economy	67800.00
0005434964564	18240	Economy	67800.00
0005434964576	18240	Economy	67800.00
0005434964454	18240	Economy	67800.00
0005434964484	18240	Economy	67800.00
0005434964575	18240	Economy	67800.00
0005434964505	18240	Economy	67800.00
0005433261824	18240	Economy	67800.00
0005433261809	18240	Economy	67800.00
0005434964485	18240	Economy	67800.00
0005434964532	18240	Economy	67800.00
0005434964531	18240	Economy	67800.00
0005434964415	18240	Economy	67800.00
0005434964577	18240	Economy	67800.00
0005434964477	18240	Economy	67800.00
0005434964414	18240	Economy	67800.00
0005434964459	18240	Economy	67800.00
0005433261795	18240	Economy	67800.00
0005433261798	18240	Economy	67800.00
0005433261804	18240	Economy	67800.00
0005434964533	18240	Economy	67800.00
0005434964457	18240	Economy	67800.00
0005433261810	18240	Economy	67800.00
0005434964541	18240	Economy	67800.00
0005433261819	18240	Economy	67800.00
0005434964506	18240	Economy	67800.00
0005434964601	18240	Economy	67800.00
0005434964375	18240	Economy	67800.00
0005433261805	18240	Economy	67800.00
0005434964548	18240	Economy	67800.00
0005434964472	18240	Economy	67800.00
0005434964416	18240	Economy	67800.00
0005433261821	18240	Economy	74500.00
0005434964570	18240	Economy	67800.00
0005434964510	18240	Economy	67800.00
0005434964536	18240	Economy	67800.00
0005433261794	18240	Economy	67800.00
0005433261808	18240	Economy	67800.00
0005434964569	18240	Economy	67800.00
0005434964573	18240	Economy	67800.00
0005433261811	18240	Economy	67800.00
0005433261807	18240	Economy	67800.00
0005433261816	18240	Economy	67800.00
0005433261802	18240	Economy	67800.00
0005433261812	18240	Economy	67800.00
0005433261800	18240	Economy	67800.00
0005434964462	18240	Economy	67800.00
0005434964566	18240	Economy	67800.00
0005433261817	18240	Economy	67800.00
0005434964540	18240	Economy	67800.00
0005433261797	18240	Economy	67800.00
0005434964461	18240	Economy	67800.00
0005434964517	18240	Economy	67800.00
0005433261823	18240	Economy	67800.00
0005434964572	18240	Economy	67800.00
0005433261806	18240	Economy	67800.00
0005434964486	18240	Economy	67800.00
0005434964574	18240	Economy	67800.00
0005433261815	18240	Economy	67800.00
0005434964460	18240	Economy	67800.00
0005434964491	18240	Economy	67800.00
0005434964471	18240	Economy	67800.00
0005434626195	4832	Business	44200.00
0005434626196	4832	Business	44200.00
0005434626193	4832	Business	44200.00
0005435907580	4832	Economy	16200.00
0005435907598	4832	Economy	14700.00
0005433194899	4832	Economy	14700.00
0005434626199	4832	Economy	14700.00
0005434626201	4832	Economy	14700.00
0005435907575	4832	Economy	14700.00
0005434626200	4832	Economy	14700.00
0005434626194	4832	Economy	14700.00
0005435907563	4832	Economy	14700.00
0005434626197	4832	Economy	14700.00
0005435907609	4832	Economy	14700.00
0005435907597	4832	Economy	14700.00
0005434626198	4832	Economy	14700.00
0005435907576	4832	Economy	14700.00
0005435907610	4832	Economy	14700.00
0005434626146	32891	Business	44200.00
0005435907627	32891	Business	44200.00
0005434626125	32891	Economy	14700.00
0005434626147	32891	Economy	14700.00
0005434626158	32891	Economy	16200.00
0005434626112	32891	Economy	14700.00
0005435907629	32891	Economy	14700.00
0005434626126	32891	Economy	14700.00
0005434626139	32891	Economy	14700.00
0005435907628	32891	Economy	14700.00
0005434626128	32891	Economy	14700.00
0005434626087	32891	Economy	14700.00
0005435907630	32891	Economy	14700.00
0005434626157	32891	Economy	14700.00
0005435907631	32891	Economy	14700.00
0005434626111	32891	Economy	14700.00
0005434626106	32891	Economy	14700.00
0005435787389	13783	Economy	3400.00
0005435937528	13783	Economy	3400.00
0005435937516	13783	Economy	3400.00
0005435785864	13783	Economy	3400.00
0005435785762	13783	Economy	3100.00
0005432195747	13783	Economy	3100.00
0005435937518	13783	Economy	3100.00
0005435785964	13783	Economy	3100.00
0005435937527	13783	Economy	3100.00
0005435785922	13783	Economy	3100.00
0005435785875	13783	Economy	3100.00
0005435785923	13783	Economy	3100.00
0005435785913	13783	Economy	3100.00
0005435787387	13783	Economy	3100.00
0005435785807	13783	Economy	3100.00
0005435937526	13783	Economy	3100.00
0005435787376	13783	Economy	3100.00
0005435937529	13783	Economy	3100.00
0005435937519	13783	Economy	3100.00
0005435937515	13783	Economy	3100.00
0005435785814	13783	Economy	3100.00
0005435787380	13783	Economy	3100.00
0005435787390	13783	Economy	3100.00
0005435937524	13783	Economy	3100.00
0005435787388	13783	Economy	3100.00
0005435787381	13783	Economy	3100.00
0005435937520	13783	Economy	3100.00
0005435937513	13783	Economy	3100.00
0005432195746	13783	Economy	3100.00
0005435785865	13783	Economy	3100.00
0005435785822	13783	Economy	3100.00
0005432195748	13783	Economy	3100.00
0005435785758	13783	Economy	3100.00
0005435785742	13783	Economy	3100.00
0005435785803	13783	Economy	3100.00
0005435937523	13783	Economy	3100.00
0005435937517	13783	Economy	3100.00
0005435937522	13783	Economy	3100.00
0005435937521	13783	Economy	3100.00
0005435937514	13783	Economy	3100.00
0005435785989	13783	Economy	3100.00
0005435785795	13783	Economy	3100.00
0005435785794	13783	Economy	3100.00
0005435785759	13783	Economy	3100.00
0005435785977	13783	Economy	3100.00
0005435785744	13783	Economy	3100.00
0005435785790	13783	Economy	3100.00
0005435937525	13783	Economy	3100.00
0005435785898	13783	Economy	3100.00
0005435785823	13783	Economy	3100.00
0005435786165	27436	Economy	3400.00
0005435937440	27436	Economy	3400.00
0005432190718	27436	Economy	3400.00
0005435786147	27436	Economy	3400.00
0005435786158	27436	Economy	3100.00
0005435786152	27436	Economy	3100.00
0005435786148	27436	Economy	3100.00
0005432190719	27436	Economy	3100.00
0005435786173	27436	Economy	3100.00
0005435786179	27436	Economy	3100.00
0005435786166	27436	Economy	3100.00
0005435786155	27436	Economy	3100.00
0005435786177	27436	Economy	3100.00
0005435937468	27436	Economy	3100.00
0005435786150	27436	Economy	3100.00
0005435786178	27436	Economy	3100.00
0005435937467	27436	Economy	3100.00
0005435786156	27436	Economy	3100.00
0005435937451	27436	Economy	3100.00
0005435786174	27436	Economy	3100.00
0005435786167	27436	Economy	3100.00
0005435786172	27436	Economy	3100.00
0005435786169	27436	Economy	3100.00
0005432190721	27436	Economy	3100.00
0005435786175	27436	Economy	3100.00
0005432190720	27436	Economy	3100.00
0005435786170	27436	Economy	3100.00
0005435786164	27436	Economy	3100.00
0005435786160	27436	Economy	3100.00
0005435786154	27436	Economy	3100.00
0005435786180	27436	Economy	3100.00
0005435786168	27436	Economy	3100.00
0005435937443	27436	Economy	3100.00
0005435786161	27436	Economy	3100.00
0005435786151	27436	Economy	3100.00
0005435786157	27436	Economy	3100.00
0005435786149	27436	Economy	3100.00
0005435786181	27436	Economy	3100.00
0005435786153	27436	Economy	3100.00
0005435786176	27436	Economy	3100.00
0005435786162	27436	Economy	3100.00
0005435786171	27436	Economy	3100.00
0005435937450	27436	Economy	3100.00
0005435937449	27436	Economy	3100.00
0005435787403	27436	Economy	3100.00
0005435786163	27436	Economy	3100.00
0005435786159	27436	Economy	3100.00
0005434408827	20257	Business	12000.00
0005434408867	20257	Business	12000.00
0005434408961	20257	Business	12000.00
0005435311431	20257	Business	12000.00
0005434408694	20257	Business	12000.00
0005434408711	20257	Business	12000.00
0005434408907	20257	Business	12000.00
0005434408858	20257	Business	12000.00
0005434408769	20257	Business	12000.00
0005434408708	20257	Business	12000.00
0005434408722	20257	Business	12000.00
0005434408774	20257	Economy	4000.00
0005435311441	20257	Economy	4000.00
0005434408537	20257	Economy	4000.00
0005435311444	20257	Economy	4000.00
0005434408773	20257	Economy	4000.00
0005434408566	20257	Economy	4000.00
0005434408765	20257	Economy	4000.00
0005434408866	20257	Economy	4000.00
0005432058480	20257	Economy	4000.00
0005434408746	20257	Economy	4000.00
0005434408962	20257	Economy	4400.00
0005434408672	20257	Economy	4400.00
0005434408614	20257	Economy	4400.00
0005434408756	20257	Economy	4400.00
0005434408935	20257	Economy	4400.00
0005434408977	20257	Economy	4000.00
0005434408662	20257	Economy	4000.00
0005434408960	20257	Economy	4000.00
0005434408660	20257	Economy	4000.00
0005434408809	20257	Economy	4000.00
0005434408936	20257	Economy	4000.00
0005434408583	20257	Economy	4000.00
0005434408898	20257	Economy	4000.00
0005434408855	20257	Economy	4000.00
0005434408789	20257	Economy	4000.00
0005434408712	20257	Economy	4000.00
0005434408771	20257	Economy	4000.00
0005434408874	20257	Economy	4000.00
0005434408964	20257	Economy	4000.00
0005434409004	20257	Economy	4000.00
0005434409005	20257	Economy	4000.00
0005434408975	20257	Economy	4000.00
0005435311433	20257	Economy	4000.00
0005434408555	20257	Economy	4000.00
0005434408836	20257	Economy	4000.00
0005434408790	20257	Economy	4000.00
0005434408721	20257	Economy	4000.00
0005434408699	20257	Economy	4000.00
0005432058479	20257	Economy	4000.00
0005434408857	20257	Economy	4000.00
0005434408718	20257	Economy	4000.00
0005434408664	20257	Economy	4000.00
0005434408720	20257	Economy	4000.00
0005435311436	20257	Economy	4000.00
0005434408873	20257	Economy	4000.00
0005434408762	20257	Economy	4000.00
0005435311435	20257	Economy	4000.00
0005435311434	20257	Economy	4000.00
0005434408696	20257	Economy	4000.00
0005434408725	20257	Economy	4000.00
0005434408826	20257	Economy	4000.00
0005434408976	20257	Economy	4000.00
0005434408647	20257	Economy	4000.00
0005432058481	20257	Economy	4000.00
0005435311437	20257	Economy	4000.00
0005434408811	20257	Economy	4000.00
0005434408717	20257	Economy	4000.00
0005434408582	20257	Economy	4000.00
0005435311442	20257	Economy	4000.00
0005435311438	20257	Economy	4000.00
0005434408755	20257	Economy	4000.00
0005434408663	20257	Economy	4000.00
0005434408937	20257	Economy	4000.00
0005435311440	20257	Economy	4000.00
0005435311432	20257	Economy	4000.00
0005434408697	20257	Economy	4000.00
0005434408715	20257	Economy	4000.00
0005434408707	20257	Economy	4000.00
0005434408825	20257	Economy	4000.00
0005434408477	20257	Economy	4000.00
0005434408716	20257	Economy	4000.00
0005434408854	20257	Economy	4000.00
0005435311443	20257	Economy	4000.00
0005434408828	20257	Economy	4000.00
0005434408776	20257	Economy	4000.00
0005434408801	20257	Economy	4000.00
0005434408775	20257	Economy	4000.00
0005432058478	20257	Economy	4000.00
0005434408613	20257	Economy	4000.00
0005435311439	20257	Economy	4000.00
0005434408653	20257	Economy	4000.00
0005435311244	26996	Business	12000.00
0005434409339	26996	Business	12000.00
0005434409302	26996	Business	12000.00
0005434409312	26996	Business	12000.00
0005435311192	26996	Business	12000.00
0005434409303	26996	Business	12000.00
0005434409325	26996	Business	12000.00
0005434409320	26996	Business	12000.00
0005434409284	26996	Business	12000.00
0005434409322	26996	Business	12000.00
0005434409310	26996	Business	12000.00
0005434409283	26996	Business	12000.00
0005435311281	26996	Economy	4000.00
0005434409327	26996	Economy	4000.00
0005434409304	26996	Economy	4000.00
0005434409313	26996	Economy	4000.00
0005432154110	26996	Economy	4000.00
0005434409335	26996	Economy	4000.00
0005434409342	26996	Economy	4000.00
0005434409299	26996	Economy	4000.00
0005435311247	26996	Economy	4400.00
0005434409319	26996	Economy	4400.00
0005435311232	26996	Economy	4400.00
0005434409336	26996	Economy	4400.00
0005434409308	26996	Economy	4000.00
0005435311240	26996	Economy	4000.00
0005435311255	26996	Economy	4000.00
0005435311195	26996	Economy	4000.00
0005435311253	26996	Economy	4000.00
0005435311186	26996	Economy	4000.00
0005434409292	26996	Economy	4000.00
0005435311270	26996	Economy	4000.00
0005434409318	26996	Economy	4000.00
0005435311191	26996	Economy	4000.00
0005434409332	26996	Economy	4000.00
0005434409328	26996	Economy	4000.00
0005434409330	26996	Economy	4000.00
0005434409300	26996	Economy	4000.00
0005434409297	26996	Economy	4000.00
0005434409338	26996	Economy	4000.00
0005434409298	26996	Economy	4000.00
0005435311254	26996	Economy	4000.00
0005434409309	26996	Economy	4000.00
0005434409337	26996	Economy	4000.00
0005432154113	26996	Economy	4000.00
0005434409307	26996	Economy	4000.00
0005434409293	26996	Economy	4000.00
0005434409326	26996	Economy	4000.00
0005434409305	26996	Economy	4000.00
0005434409311	26996	Economy	4000.00
0005434409321	26996	Economy	4000.00
0005434409290	26996	Economy	4000.00
0005434409295	26996	Economy	4000.00
0005434409291	26996	Economy	4000.00
0005435311233	26996	Economy	4000.00
0005434409341	26996	Economy	4000.00
0005434409294	26996	Economy	4000.00
0005434409287	26996	Economy	4000.00
0005434409323	26996	Economy	4000.00
0005434409331	26996	Economy	4000.00
0005435311252	26996	Economy	4000.00
0005434409324	26996	Economy	4000.00
0005434409288	26996	Economy	4000.00
0005434409329	26996	Economy	4000.00
0005435311185	26996	Economy	4000.00
0005434409316	26996	Economy	4000.00
0005435311204	26996	Economy	4000.00
0005434409306	26996	Economy	4000.00
0005432154109	26996	Economy	4000.00
0005435311184	26996	Economy	4000.00
0005435311265	26996	Economy	4000.00
0005434409301	26996	Economy	4000.00
0005432154114	26996	Economy	4000.00
0005434409333	26996	Economy	4000.00
0005434409296	26996	Economy	4000.00
0005434409286	26996	Economy	4000.00
0005435311269	26996	Economy	4000.00
0005435311194	26996	Economy	4000.00
0005435311205	26996	Economy	4000.00
0005434409317	26996	Economy	4000.00
0005432154111	26996	Economy	4000.00
0005434409340	26996	Economy	4000.00
0005434409314	26996	Economy	4000.00
0005434409285	26996	Economy	4000.00
0005435311246	26996	Economy	4000.00
0005434409315	26996	Economy	4000.00
0005435311262	26996	Economy	4000.00
0005432154112	26996	Economy	4000.00
0005434409289	26996	Economy	4000.00
0005434409334	26996	Economy	4000.00
0005433124242	5677	Business	43300.00
0005434319740	5677	Business	43300.00
0005432109771	5677	Business	43300.00
0005433124233	5677	Economy	14400.00
0005434319745	5677	Economy	14400.00
0005433124234	5677	Economy	14400.00
0005434319747	5677	Economy	14400.00
0005434319744	5677	Economy	14400.00
0005434319739	5677	Economy	14400.00
0005433124208	5677	Economy	14400.00
0005434319734	5677	Economy	14400.00
0005433124260	5677	Economy	14400.00
0005434319735	5677	Economy	14400.00
0005433124308	5677	Economy	14400.00
0005434319743	5677	Economy	14400.00
0005434319733	5677	Economy	14400.00
0005433124294	5677	Economy	14400.00
0005434319737	5677	Economy	14400.00
0005433124293	5677	Economy	14400.00
0005435297360	5677	Economy	14400.00
0005433124255	5677	Economy	14400.00
0005434319746	5677	Economy	14400.00
0005433124274	5677	Economy	14400.00
0005432109772	5677	Economy	14400.00
0005434319741	5677	Economy	14400.00
0005434319738	5677	Economy	14400.00
0005434311268	5677	Economy	14400.00
0005433124222	5677	Economy	14400.00
0005434319748	5677	Economy	14400.00
0005434311269	5677	Economy	14400.00
0005434319732	5677	Economy	14400.00
0005433124292	5677	Economy	14400.00
0005435297359	5677	Economy	14400.00
0005433124241	5677	Economy	14400.00
0005434319736	5677	Economy	14400.00
0005434319749	5677	Economy	14400.00
0005434319742	5677	Economy	14400.00
0005434311284	5677	Economy	14400.00
0005434311270	5677	Economy	14400.00
0005433124273	5677	Economy	14400.00
0005433124199	5677	Economy	14400.00
0005434311285	5677	Economy	14400.00
0005434319593	15684	Business	43300.00
0005434312342	15684	Business	43300.00
0005433124440	15684	Business	43300.00
0005433124438	15684	Business	43300.00
0005434312343	15684	Economy	14400.00
0005433124443	15684	Economy	14400.00
0005434311256	15684	Economy	15900.00
0005434319594	15684	Economy	14400.00
0005433124441	15684	Economy	14400.00
0005433124439	15684	Economy	14400.00
0005433124435	15684	Economy	14400.00
0005434319584	15684	Economy	14400.00
0005434319590	15684	Economy	14400.00
0005434319576	15684	Economy	14400.00
0005433124437	15684	Economy	14400.00
0005433124436	15684	Economy	14400.00
0005433124442	15684	Economy	14400.00
0005434311255	15684	Economy	14400.00
0005434311247	15684	Economy	14400.00
0005434319589	15684	Economy	14400.00
0005435217740	24966	Economy	17100.00
0005435220342	24966	Economy	15500.00
0005435220352	24966	Economy	15500.00
0005435221524	24966	Economy	15500.00
0005435217744	24966	Economy	15500.00
0005435217746	24966	Economy	15500.00
0005435220349	24966	Economy	15500.00
0005435217753	24966	Economy	15500.00
0005435217724	24966	Economy	15500.00
0005435217739	24966	Economy	15500.00
0005435221525	24966	Economy	15500.00
0005435217745	24966	Economy	15500.00
0005435220343	24966	Economy	15500.00
0005435217731	24966	Economy	15500.00
0005435217748	24966	Economy	15500.00
0005435217738	24966	Economy	15500.00
0005434484511	9010	Economy	24900.00
0005434189265	9010	Economy	24900.00
0005434484512	9010	Economy	24900.00
0005434484513	9010	Economy	24900.00
0005434189284	9010	Economy	24900.00
0005434189286	9010	Economy	24900.00
0005434189264	9010	Economy	24900.00
0005434484514	9010	Economy	24900.00
0005434484508	9010	Economy	24900.00
0005434484510	9010	Economy	24900.00
0005434484509	9010	Economy	24900.00
0005434484473	16611	Economy	27400.00
0005434484470	16611	Economy	24900.00
0005434189321	16611	Economy	24900.00
0005434484459	16611	Economy	24900.00
0005434484442	16611	Economy	24900.00
0005434484458	16611	Economy	24900.00
0005434189322	16611	Economy	24900.00
0005434484465	16611	Economy	24900.00
0005434189320	16611	Economy	24900.00
0005434484436	16611	Economy	24900.00
0005434484462	16611	Economy	24900.00
0005434484461	16611	Economy	24900.00
0005433722297	7585	Business	11100.00
0005433124438	7585	Economy	3700.00
0005433124440	7585	Economy	3700.00
0005433124436	7585	Economy	3700.00
0005433722306	7585	Economy	3700.00
0005433124441	7585	Economy	3700.00
0005433124439	7585	Economy	3700.00
0005433124435	7585	Economy	3700.00
0005433124443	7585	Economy	3700.00
0005433722309	7585	Economy	3700.00
0005433124442	7585	Economy	3700.00
0005433124437	7585	Economy	3700.00
0005433722296	7585	Economy	3700.00
0005432693843	7584	Business	11100.00
0005432721558	7584	Business	11100.00
0005432721563	7584	Business	11100.00
0005432721579	7584	Business	11100.00
0005432693831	7584	Business	11100.00
0005432721577	7584	Business	11100.00
0005432693842	7584	Business	11100.00
0005432693832	7584	Business	11100.00
0005432071645	7584	Business	11100.00
0005432693835	7584	Business	11100.00
0005432721566	7584	Business	11100.00
0005433450512	7584	Economy	3700.00
0005433450506	7584	Economy	3700.00
0005432693845	7584	Economy	3700.00
0005433450513	7584	Economy	3700.00
0005432693826	7584	Economy	3700.00
0005432693839	7584	Economy	3700.00
0005432693847	7584	Economy	3700.00
0005433450498	7584	Economy	3700.00
0005433450518	7584	Economy	3700.00
0005432693841	7584	Economy	4100.00
0005432071647	7584	Economy	4100.00
0005432721567	7584	Economy	4100.00
0005432721570	7584	Economy	4100.00
0005432693840	7584	Economy	3700.00
0005432721582	7584	Economy	3700.00
0005433450497	7584	Economy	3700.00
0005433450514	7584	Economy	3700.00
0005433450502	7584	Economy	3700.00
0005432693817	7584	Economy	3700.00
0005432693818	7584	Economy	3700.00
0005432721569	7584	Economy	3700.00
0005433450505	7584	Economy	3700.00
0005432721572	7584	Economy	3700.00
0005432693846	7584	Economy	3700.00
0005433450516	7584	Economy	3700.00
0005432693834	7584	Economy	3700.00
0005432721580	7584	Economy	3700.00
0005432721581	7584	Economy	3700.00
0005432693833	7584	Economy	3700.00
0005432721562	7584	Economy	3700.00
0005433450504	7584	Economy	3700.00
0005432693816	7584	Economy	3700.00
0005432721565	7584	Economy	3700.00
0005433450509	7584	Economy	3700.00
0005432693837	7584	Economy	3700.00
0005432693829	7584	Economy	3700.00
0005432071646	7584	Economy	3700.00
0005433450503	7584	Economy	3700.00
0005432693844	7584	Economy	3700.00
0005432721578	7584	Economy	3700.00
0005432721561	7584	Economy	3700.00
0005432693825	7584	Economy	3700.00
0005432721560	7584	Economy	3700.00
0005432693823	7584	Economy	3700.00
0005432693838	7584	Economy	3700.00
0005432721556	7584	Economy	3700.00
0005432721559	7584	Economy	3700.00
0005432721576	7584	Economy	3700.00
0005432071648	7584	Economy	3700.00
0005432693824	7584	Economy	3700.00
0005432693819	7584	Economy	3700.00
0005432721557	7584	Economy	3700.00
0005433450515	7584	Economy	3700.00
0005433450501	7584	Economy	3700.00
0005432693827	7584	Economy	3700.00
0005432693820	7584	Economy	3700.00
0005432721575	7584	Economy	3700.00
0005432693821	7584	Economy	3700.00
0005433450499	7584	Economy	3700.00
0005433450500	7584	Economy	3700.00
0005432721555	7584	Economy	3700.00
0005433450511	7584	Economy	3700.00
0005432721568	7584	Economy	3700.00
0005432693828	7584	Economy	3700.00
0005433450508	7584	Economy	3700.00
0005432693822	7584	Economy	3700.00
0005432721573	7584	Economy	3700.00
0005433450510	7584	Economy	3700.00
0005432693836	7584	Economy	3700.00
0005432721574	7584	Economy	3700.00
0005433450517	7584	Economy	3700.00
0005432721571	7584	Economy	3700.00
0005432721564	7584	Economy	3700.00
0005433450507	7584	Economy	3700.00
0005432693830	7584	Economy	3700.00
0005433450318	30442	Business	11100.00
0005432693627	30442	Business	11100.00
0005433450361	30442	Business	11100.00
0005432693432	30442	Business	11100.00
0005432693457	30442	Business	11100.00
0005432693508	30442	Business	11100.00
0005432693483	30442	Business	11100.00
0005432693628	30442	Economy	3700.00
0005432693509	30442	Economy	3700.00
0005433450347	30442	Economy	3700.00
0005432693484	30442	Economy	3700.00
0005432693491	30442	Economy	3700.00
0005432693520	30442	Economy	3700.00
0005433450330	30442	Economy	3700.00
0005432693680	30442	Economy	3700.00
0005432693589	30442	Economy	4100.00
0005432693513	30442	Economy	4100.00
0005432693485	30442	Economy	3700.00
0005432693691	30442	Economy	3700.00
0005432693526	30442	Economy	3700.00
0005433450250	30442	Economy	3700.00
0005433450296	30442	Economy	3700.00
0005432693618	30442	Economy	3700.00
0005433450317	30442	Economy	3700.00
0005433450244	30442	Economy	3700.00
0005433450215	30442	Economy	3700.00
0005432693530	30442	Economy	3700.00
0005432693469	30442	Economy	3700.00
0005432693533	30442	Economy	3700.00
0005433450249	30442	Economy	3700.00
0005432693470	30442	Economy	3700.00
0005432693510	30442	Economy	3700.00
0005433450295	30442	Economy	3700.00
0005433450329	30442	Economy	3700.00
0005432693588	30442	Economy	3700.00
0005433450348	30442	Economy	3700.00
0005433450346	30442	Economy	3700.00
0005432693374	30442	Economy	3700.00
0005432693481	30442	Economy	3700.00
0005433450345	30442	Economy	3700.00
0005433450340	30442	Economy	3700.00
0005432693421	30442	Economy	3700.00
0005433450302	30442	Economy	3700.00
0005433450254	30442	Economy	3700.00
0005432693692	30442	Economy	3700.00
0005433450341	30442	Economy	3700.00
0005432693638	30442	Economy	3700.00
0005433450342	30442	Economy	3700.00
0005432693456	30442	Economy	3700.00
0005433450207	30442	Economy	3700.00
0005432693605	30442	Economy	3700.00
0005432693566	30442	Economy	3700.00
0005433450258	30442	Economy	3700.00
0005432693532	30442	Economy	3700.00
0005432693350	30442	Economy	3700.00
0005432693507	30442	Economy	3700.00
0005432693606	30442	Economy	3700.00
0005433124208	30441	Business	11100.00
0005432721360	30441	Business	11100.00
0005432721309	30441	Business	11100.00
0005432721311	30441	Business	11100.00
0005432721342	30441	Business	11100.00
0005432721357	30441	Business	11100.00
0005432721288	30441	Economy	3700.00
0005433124273	30441	Economy	3700.00
0005432721341	30441	Economy	3700.00
0005432721239	30441	Economy	3700.00
0005432721499	30441	Economy	3700.00
0005433722388	30441	Economy	3700.00
0005433124242	30441	Economy	3700.00
0005433124292	30441	Economy	4100.00
0005432721396	30441	Economy	4100.00
0005432721236	30441	Economy	4100.00
0005433722387	30441	Economy	4100.00
0005432721237	30441	Economy	3700.00
0005433722383	30441	Economy	3700.00
0005432721198	30441	Economy	3700.00
0005433124233	30441	Economy	3700.00
0005432721378	30441	Economy	3700.00
0005432721310	30441	Economy	3700.00
0005433124260	30441	Economy	3700.00
0005433722390	30441	Economy	3700.00
0005432721442	30441	Economy	3700.00
0005432721400	30441	Economy	3700.00
0005433124293	30441	Economy	3700.00
0005432721359	30441	Economy	3700.00
0005433124234	30441	Economy	3700.00
0005433124222	30441	Economy	3700.00
0005432721337	30441	Economy	3700.00
0005433722385	30441	Economy	3700.00
0005433124274	30441	Economy	3700.00
0005433124255	30441	Economy	3700.00
0005432721382	30441	Economy	3700.00
0005432721409	30441	Economy	3700.00
0005433722382	30441	Economy	3700.00
0005433722389	30441	Economy	3700.00
0005432721454	30441	Economy	3700.00
0005432721377	30441	Economy	3700.00
0005432721443	30441	Economy	3700.00
0005432721340	30441	Economy	3700.00
0005433124241	30441	Economy	3700.00
0005432721404	30441	Economy	3700.00
0005432721414	30441	Economy	3700.00
0005433124199	30441	Economy	3700.00
0005433722386	30441	Economy	3700.00
0005432721287	30441	Economy	3700.00
0005433722381	30441	Economy	3700.00
0005432721447	30441	Economy	3700.00
0005433124294	30441	Economy	3700.00
0005433124308	30441	Economy	3700.00
0005432721358	30441	Economy	3700.00
0005432721347	30441	Economy	3700.00
0005432721410	30441	Economy	3700.00
0005433722384	30441	Economy	3700.00
0005432721381	30441	Economy	3700.00
0005433722380	30441	Economy	3700.00
0005432721475	30441	Economy	3700.00
0005432721348	30441	Economy	3700.00
0005432968883	1389	Business	70400.00
0005433525314	1389	Business	70400.00
0005433525311	1389	Business	70400.00
0005434515031	1389	Business	70400.00
0005433193201	1389	Business	70400.00
0005434587236	1389	Business	70400.00
0005434587242	1389	Business	70400.00
0005433525312	1389	Economy	23500.00
0005433193234	1389	Economy	23500.00
0005434515033	1389	Economy	23500.00
0005433193251	1389	Economy	23500.00
0005433193269	1389	Economy	23500.00
0005433525305	1389	Economy	23500.00
0005434587244	1389	Economy	25800.00
0005432928087	1389	Economy	25800.00
0005433724919	1389	Economy	25800.00
0005433525304	1389	Economy	25800.00
0005432271074	1389	Economy	23500.00
0005434587254	1389	Economy	23500.00
0005434515035	1389	Economy	23500.00
0005434587253	1389	Economy	23500.00
0005434587249	1389	Economy	23500.00
0005434587257	1389	Economy	23500.00
0005434587241	1389	Economy	23500.00
0005434587240	1389	Economy	23500.00
0005434587237	1389	Economy	23500.00
0005434587258	1389	Economy	23500.00
0005433193292	1389	Economy	23500.00
0005433525306	1389	Economy	23500.00
0005434587248	1389	Economy	23500.00
0005433525307	1389	Economy	23500.00
0005433193294	1389	Economy	23500.00
0005434587250	1389	Economy	23500.00
0005433525310	1389	Economy	23500.00
0005433525302	1389	Economy	23500.00
0005433724922	1389	Economy	23500.00
0005432968885	1389	Economy	23500.00
0005434513645	1389	Economy	23500.00
0005433193293	1389	Economy	23500.00
0005432968877	1389	Economy	23500.00
0005434513644	1389	Economy	23500.00
0005433193268	1389	Economy	23500.00
0005433525313	1389	Economy	23500.00
0005434587238	1389	Economy	23500.00
0005434587235	1389	Economy	23500.00
0005434515034	1389	Economy	23500.00
0005434587252	1389	Economy	23500.00
0005434587243	1389	Economy	23500.00
0005433525309	1389	Economy	23500.00
0005434587256	1389	Economy	23500.00
0005433193235	1389	Economy	23500.00
0005432968879	1389	Economy	23500.00
0005433724921	1389	Economy	23500.00
0005432968884	1389	Economy	23500.00
0005432271076	1389	Economy	23500.00
0005434587234	1389	Economy	23500.00
0005433193236	1389	Economy	23500.00
0005434587247	1389	Economy	23500.00
0005432928071	1389	Economy	23500.00
0005433724918	1389	Economy	23500.00
0005432271075	1389	Economy	23500.00
0005432928073	1389	Economy	23500.00
0005434587246	1389	Economy	23500.00
0005433525303	1389	Economy	23500.00
0005434587251	1389	Economy	23500.00
0005434587239	1389	Economy	23500.00
0005433525308	1389	Economy	23500.00
0005433193200	1389	Economy	23500.00
0005434515032	1389	Economy	23500.00
0005434587255	1389	Economy	23500.00
0005433724920	1389	Economy	23500.00
0005432928091	1389	Economy	23500.00
0005434587245	1389	Economy	23500.00
0005434586992	18529	Business	70400.00
0005434587034	18529	Business	70400.00
0005434587072	18529	Business	70400.00
0005434587078	18529	Business	70400.00
0005434587079	18529	Business	70400.00
0005434587045	18529	Business	70400.00
0005434586997	18529	Business	70400.00
0005433193376	18529	Business	70400.00
0005433525198	18529	Business	70400.00
0005433193379	18529	Business	70400.00
0005434587046	18529	Economy	23500.00
0005433525245	18529	Economy	23500.00
0005434587074	18529	Economy	23500.00
0005433193377	18529	Economy	23500.00
0005434587048	18529	Economy	23500.00
0005434587008	18529	Economy	23500.00
0005433525199	18529	Economy	23500.00
0005434587030	18529	Economy	25800.00
0005434587031	18529	Economy	25800.00
0005434586993	18529	Economy	25800.00
0005433525197	18529	Economy	25800.00
0005433193370	18529	Economy	23500.00
0005433193373	18529	Economy	23500.00
0005434587077	18529	Economy	23500.00
0005434587073	18529	Economy	23500.00
0005433193371	18529	Economy	23500.00
0005433193380	18529	Economy	23500.00
0005433525209	18529	Economy	23500.00
0005434586863	18529	Economy	23500.00
0005434587089	18529	Economy	23500.00
0005434586999	18529	Economy	23500.00
0005433724886	18529	Economy	23500.00
0005433525215	18529	Economy	23500.00
0005434587202	18529	Economy	23500.00
0005432968897	18529	Economy	23500.00
0005434587006	18529	Economy	23500.00
0005434587003	18529	Economy	23500.00
0005434587086	18529	Economy	23500.00
0005433193375	18529	Economy	23500.00
0005434587159	18529	Economy	23500.00
0005434587067	18529	Economy	23500.00
0005433193381	18529	Economy	23500.00
0005432928120	18529	Economy	23500.00
0005432928117	18529	Economy	23500.00
0005434587132	18529	Economy	23500.00
0005433193378	18529	Economy	23500.00
0005432968896	18529	Economy	23500.00
0005434587000	18529	Economy	23500.00
0005434587075	18529	Economy	23500.00
0005433193369	18529	Economy	23500.00
0005434587071	18529	Economy	23500.00
0005433525229	18529	Economy	23500.00
0005433193374	18529	Economy	23500.00
0005434587059	18529	Economy	23500.00
0005433525194	18529	Economy	23500.00
0005433724887	18529	Economy	23500.00
0005433525230	18529	Economy	23500.00
0005433525210	18529	Economy	23500.00
0005434587076	18529	Economy	23500.00
0005434586991	18529	Economy	23500.00
0005433525182	18529	Economy	23500.00
0005432928118	18529	Economy	23500.00
0005432928119	18529	Economy	23500.00
0005432928121	18529	Economy	23500.00
0005434587160	18529	Economy	23500.00
0005434587100	18529	Economy	23500.00
0005433193372	18529	Economy	23500.00
0005434142707	11466	Economy	4300.00
0005434345059	11466	Economy	4300.00
0005434345051	11466	Economy	4300.00
0005435302254	11466	Economy	4300.00
0005434345078	11466	Economy	4000.00
0005434142709	11466	Economy	4000.00
0005434345056	11466	Economy	4000.00
0005434345055	11466	Economy	4000.00
0005434345076	11466	Economy	4000.00
0005434345047	11466	Economy	4000.00
0005434345050	11466	Economy	4000.00
0005434345054	11466	Economy	4000.00
0005434345071	11466	Economy	4000.00
0005435302273	11466	Economy	4000.00
0005434345043	11466	Economy	4000.00
0005434142710	11466	Economy	4000.00
0005434345049	11466	Economy	4000.00
0005434345045	11466	Economy	4000.00
0005434345077	11466	Economy	4000.00
0005435302255	11466	Economy	4000.00
0005434345073	11466	Economy	4000.00
0005435302285	11466	Economy	4000.00
0005434345061	11466	Economy	4000.00
0005434345067	11466	Economy	4000.00
0005434345068	11466	Economy	4000.00
0005434345070	11466	Economy	4000.00
0005434345064	11466	Economy	4000.00
0005434345069	11466	Economy	4000.00
0005434345058	11466	Economy	4000.00
0005435302284	11466	Economy	4000.00
0005434345062	11466	Economy	4000.00
0005434345066	11466	Economy	4000.00
0005434345065	11466	Economy	4000.00
0005434345075	11466	Economy	4000.00
0005434345052	11466	Economy	4000.00
0005435302283	11466	Economy	4000.00
0005434345046	11466	Economy	4000.00
0005434142711	11466	Economy	4000.00
0005434142708	11466	Economy	4000.00
0005434345079	11466	Economy	4000.00
0005434345042	11466	Economy	4000.00
0005434345074	11466	Economy	4000.00
0005434345057	11466	Economy	4000.00
0005434345048	11466	Economy	4000.00
0005434345063	11466	Economy	4000.00
0005434345044	11466	Economy	4000.00
0005434345060	11466	Economy	4000.00
0005434345072	11466	Economy	4000.00
0005434345053	11466	Economy	4000.00
0005434142712	11466	Economy	4000.00
0005434344756	29757	Economy	4300.00
0005434344814	29757	Economy	4300.00
0005434344708	29757	Economy	4300.00
0005434344732	29757	Economy	4300.00
0005435304253	29757	Economy	4000.00
0005434344778	29757	Economy	4000.00
0005434344842	29757	Economy	4000.00
0005434142667	29757	Economy	4000.00
0005434344739	29757	Economy	4000.00
0005434344707	29757	Economy	4000.00
0005434344772	29757	Economy	4000.00
0005434344832	29757	Economy	4000.00
0005434344780	29757	Economy	4000.00
0005434344790	29757	Economy	4000.00
0005434142676	29757	Economy	4000.00
0005435304257	29757	Economy	4000.00
0005434344700	29757	Economy	4000.00
0005434344771	29757	Economy	4000.00
0005434142673	29757	Economy	4000.00
0005435305060	29757	Economy	4000.00
0005434142666	29757	Economy	4000.00
0005434344843	29757	Economy	4000.00
0005435304256	29757	Economy	4000.00
0005434344648	29757	Economy	4000.00
0005434344784	29757	Economy	4000.00
0005434142660	29757	Economy	4000.00
0005435305061	29757	Economy	4000.00
0005434344791	29757	Economy	4000.00
0005434344779	29757	Economy	4000.00
0005434142655	29757	Economy	4000.00
0005434344798	29757	Economy	4000.00
0005434344731	29757	Economy	4000.00
0005434344820	29757	Economy	4000.00
0005435304254	29757	Economy	4000.00
0005434142656	29757	Economy	4000.00
0005434344605	29757	Economy	4000.00
0005435304255	29757	Economy	4000.00
0005434344653	29757	Economy	4000.00
0005434344561	29757	Economy	4000.00
0005434344844	29757	Economy	4000.00
0005434344752	29757	Economy	4000.00
0005435305062	29757	Economy	4000.00
0005434344783	29757	Economy	4000.00
0005434344781	29757	Economy	4000.00
0005434344747	29757	Economy	4000.00
0005434344822	29757	Economy	4000.00
0005434344740	29757	Economy	4000.00
0005434344821	29757	Economy	4000.00
0005434142665	29757	Economy	4000.00
0005434344649	29757	Economy	4000.00
0005433415921	1261	Business	199800.00
0005435825284	1261	Business	199800.00
0005435825299	1261	Business	199800.00
0005435825286	1261	Business	199800.00
0005435825300	1261	Business	199800.00
0005435825292	1261	Business	199800.00
0005435825298	1261	Economy	66600.00
0005435825296	1261	Economy	66600.00
0005433415901	1261	Economy	73200.00
0005435825295	1261	Economy	66600.00
0005433415869	1261	Economy	66600.00
0005435825289	1261	Economy	66600.00
0005435825297	1261	Economy	66600.00
0005435825301	1261	Economy	66600.00
0005435825303	1261	Economy	66600.00
0005433415934	1261	Economy	66600.00
0005435825283	1261	Economy	66600.00
0005435825287	1261	Economy	66600.00
0005433415960	1261	Economy	66600.00
0005435825280	1261	Economy	66600.00
0005432284631	1261	Economy	66600.00
0005435825285	1261	Economy	66600.00
0005433415992	1261	Economy	66600.00
0005435825293	1261	Economy	66600.00
0005435825278	1261	Economy	66600.00
0005435825291	1261	Economy	66600.00
0005435825279	1261	Economy	66600.00
0005433415918	1261	Economy	66600.00
0005435825282	1261	Economy	66600.00
0005435825288	1261	Economy	66600.00
0005433415940	1261	Economy	66600.00
0005432284632	1261	Economy	66600.00
0005433415925	1261	Economy	66600.00
0005435825302	1261	Economy	66600.00
0005435825290	1261	Economy	66600.00
0005433415924	1261	Economy	66600.00
0005435825281	1261	Economy	66600.00
0005433415891	1261	Economy	66600.00
0005433415993	1261	Economy	66600.00
0005435825294	1261	Economy	66600.00
0005435825013	18004	Business	199800.00
0005433416055	18004	Business	199800.00
0005435825168	18004	Business	199800.00
0005433416061	18004	Business	199800.00
0005433416050	18004	Economy	66600.00
0005435825065	18004	Economy	66600.00
0005433416060	18004	Economy	66600.00
0005433416053	18004	Economy	66600.00
0005435825045	18004	Economy	73200.00
0005435825107	18004	Economy	73200.00
0005435825073	18004	Economy	66600.00
0005435825016	18004	Economy	66600.00
0005435825043	18004	Economy	66600.00
0005435825085	18004	Economy	66600.00
0005433416057	18004	Economy	66600.00
0005435825090	18004	Economy	66600.00
0005433416058	18004	Economy	66600.00
0005435824987	18004	Economy	66600.00
0005435825074	18004	Economy	66600.00
0005435825106	18004	Economy	66600.00
0005433416048	18004	Economy	66600.00
0005435825086	18004	Economy	66600.00
0005433416051	18004	Economy	66600.00
0005435825064	18004	Economy	66600.00
0005433416047	18004	Economy	66600.00
0005435824926	18004	Economy	66600.00
0005435825148	18004	Economy	66600.00
0005435825014	18004	Economy	66600.00
0005435825167	18004	Economy	66600.00
0005435825105	18004	Economy	66600.00
0005435825044	18004	Economy	66600.00
0005433416062	18004	Economy	66600.00
0005433416052	18004	Economy	66600.00
0005433416054	18004	Economy	66600.00
0005435825015	18004	Economy	66600.00
0005433416059	18004	Economy	66600.00
0005433416049	18004	Economy	66600.00
0005433416056	18004	Economy	66600.00
0005434460546	17524	Economy	14800.00
0005434460531	17524	Economy	13500.00
0005434460538	17524	Economy	13500.00
0005434460532	17524	Economy	13500.00
0005434460534	17524	Economy	13500.00
0005434460539	17524	Economy	13500.00
0005434460545	17524	Economy	13500.00
0005435243203	5614	Business	27800.00
0005432785102	5614	Business	27800.00
0005432144067	5614	Business	27800.00
0005432785139	5614	Business	27800.00
0005432785118	5614	Business	27800.00
0005435243224	5614	Business	27800.00
0005435243373	5614	Business	27800.00
0005432785133	5614	Business	27800.00
0005432785109	5614	Business	27800.00
0005435243363	5614	Business	27800.00
0005432785135	5614	Business	27800.00
0005432785144	5614	Business	27800.00
0005432785129	5614	Economy	9300.00
0005432785137	5614	Economy	9300.00
0005435243222	5614	Economy	9300.00
0005432785141	5614	Economy	9300.00
0005432785106	5614	Economy	9300.00
0005435243192	5614	Economy	9300.00
0005432785126	5614	Economy	9300.00
0005435243202	5614	Economy	9300.00
0005432785097	5614	Economy	9300.00
0005432785143	5614	Economy	9300.00
0005435243204	5614	Economy	10200.00
0005432785113	5614	Economy	10200.00
0005435243221	5614	Economy	10200.00
0005432785114	5614	Economy	10200.00
0005432785111	5614	Economy	10200.00
0005432785093	5614	Economy	9300.00
0005432785115	5614	Economy	9300.00
0005432785132	5614	Economy	9300.00
0005435243273	5614	Economy	9300.00
0005432785140	5614	Economy	9300.00
0005432785123	5614	Economy	9300.00
0005435243244	5614	Economy	9300.00
0005432785110	5614	Economy	9300.00
0005435243347	5614	Economy	9300.00
0005432785142	5614	Economy	9300.00
0005432144068	5614	Economy	9300.00
0005435243247	5614	Economy	9300.00
0005432785130	5614	Economy	9300.00
0005435243314	5614	Economy	9300.00
0005432785098	5614	Economy	9300.00
0005432785136	5614	Economy	9300.00
0005432785092	5614	Economy	9300.00
0005432785100	5614	Economy	9300.00
0005432785099	5614	Economy	9300.00
0005435243323	5614	Economy	9300.00
0005435243341	5614	Economy	9300.00
0005435243216	5614	Economy	9300.00
0005432785146	5614	Economy	9300.00
0005432785131	5614	Economy	9300.00
0005435243298	5614	Economy	9300.00
0005435243340	5614	Economy	9300.00
0005435476844	5614	Economy	9300.00
0005435243200	5614	Economy	9300.00
0005435243151	5614	Economy	9300.00
0005435243372	5614	Economy	9300.00
0005432785124	5614	Economy	9300.00
0005432785121	5614	Economy	9300.00
0005432785108	5614	Economy	9300.00
0005435243345	5614	Economy	9300.00
0005435243243	5614	Economy	9300.00
0005432785119	5614	Economy	9300.00
0005435243191	5614	Economy	9300.00
0005432785117	5614	Economy	9300.00
0005432785105	5614	Economy	9300.00
0005432785096	5614	Economy	9300.00
0005432785095	5614	Economy	9300.00
0005435243152	5614	Economy	9300.00
0005432785103	5614	Economy	9300.00
0005432785101	5614	Economy	9300.00
0005435243239	5614	Economy	9300.00
0005435243289	5614	Economy	9300.00
0005432785134	5614	Economy	9300.00
0005435243291	5614	Economy	9300.00
0005432144069	5614	Economy	9300.00
0005432785120	5614	Economy	9300.00
0005435243223	5614	Economy	9300.00
0005432785112	5614	Economy	9300.00
0005432785116	5614	Economy	9300.00
0005435243277	5614	Economy	9300.00
0005435243199	5614	Economy	9300.00
0005432785145	5614	Economy	9300.00
0005432785107	5614	Economy	9300.00
0005435243274	5614	Economy	9300.00
0005435243194	5614	Economy	9300.00
0005432785104	5614	Economy	9300.00
0005432785122	5614	Economy	9300.00
0005432785128	5614	Economy	9300.00
0005432785094	5614	Economy	9300.00
0005432785125	5614	Economy	9300.00
0005432785127	5614	Economy	9300.00
0005432785138	5614	Economy	9300.00
0005435243248	5614	Economy	9300.00
0005435243324	5614	Economy	9300.00
0005435243487	15352	Business	27800.00
0005432784604	15352	Business	27800.00
0005432784614	15352	Business	27800.00
0005432784700	15352	Business	27800.00
0005432784573	15352	Business	27800.00
0005435243498	15352	Business	27800.00
0005435476945	15352	Business	27800.00
0005435476939	15352	Business	27800.00
0005432784709	15352	Business	27800.00
0005432784278	15352	Business	27800.00
0005432784525	15352	Business	27800.00
0005435243510	15352	Business	27800.00
0005432784734	15352	Economy	9300.00
0005435243490	15352	Economy	9300.00
0005432784815	15352	Economy	9300.00
0005435243502	15352	Economy	9300.00
0005432784633	15352	Economy	9300.00
0005435243506	15352	Economy	9300.00
0005432784822	15352	Economy	9300.00
0005432784668	15352	Economy	9300.00
0005435476946	15352	Economy	9300.00
0005432784341	15352	Economy	9300.00
0005435476943	15352	Economy	10200.00
0005432784593	15352	Economy	10200.00
0005432784538	15352	Economy	10200.00
0005432784632	15352	Economy	10200.00
0005435243497	15352	Economy	10200.00
0005432784696	15352	Economy	9300.00
0005435243496	15352	Economy	9300.00
0005432784730	15352	Economy	9300.00
0005435243509	15352	Economy	9300.00
0005435243493	15352	Economy	9300.00
0005435243491	15352	Economy	9300.00
0005432784953	15352	Economy	9300.00
0005432784556	15352	Economy	9300.00
0005435243485	15352	Economy	9300.00
0005435243500	15352	Economy	9300.00
0005435243504	15352	Economy	9300.00
0005432784392	15352	Economy	9300.00
0005432784664	15352	Economy	9300.00
0005432784481	15352	Economy	9300.00
0005432784475	15352	Economy	9300.00
0005432784550	15352	Economy	9300.00
0005435243484	15352	Economy	9300.00
0005432784483	15352	Economy	9300.00
0005435476947	15352	Economy	9300.00
0005432784549	15352	Economy	9300.00
0005435476942	15352	Economy	9300.00
0005432784572	15352	Economy	9300.00
0005432784547	15352	Economy	9300.00
0005432784426	15352	Economy	9300.00
0005435243499	15352	Economy	9300.00
0005432784559	15352	Economy	9300.00
0005432784548	15352	Economy	9300.00
0005432784597	15352	Economy	9300.00
0005432784439	15352	Economy	9300.00
0005435243486	15352	Economy	9300.00
0005432784390	15352	Economy	9300.00
0005432784704	15352	Economy	9300.00
0005432784603	15352	Economy	9300.00
0005432784699	15352	Economy	9300.00
0005432784629	15352	Economy	9300.00
0005435243503	15352	Economy	9300.00
0005432784662	15352	Economy	9300.00
0005432784726	15352	Economy	9300.00
0005432784794	15352	Economy	9300.00
0005432784823	15352	Economy	9300.00
0005435476941	15352	Economy	9300.00
0005432784490	15352	Economy	9300.00
0005435243495	15352	Economy	9300.00
0005432784342	15352	Economy	9300.00
0005435243494	15352	Economy	9300.00
0005435476940	15352	Economy	9300.00
0005432784391	15352	Economy	9300.00
0005432784440	15352	Economy	9300.00
0005432784719	15352	Economy	9300.00
0005432784438	15352	Economy	9300.00
0005435243489	15352	Economy	9300.00
0005432784524	15352	Economy	9300.00
0005432784710	15352	Economy	9300.00
0005432784437	15352	Economy	9300.00
0005432784718	15352	Economy	9300.00
0005435243492	15352	Economy	9300.00
0005435243488	15352	Economy	9300.00
0005432784920	15352	Economy	9300.00
0005432784617	15352	Economy	9300.00
0005432784425	15352	Economy	9300.00
0005432784669	15352	Economy	9300.00
0005435243508	15352	Economy	9300.00
0005435476944	15352	Economy	9300.00
0005435243505	15352	Economy	9300.00
0005435243507	15352	Economy	9300.00
0005432784712	15352	Economy	9300.00
0005432784711	15352	Economy	9300.00
0005432784650	15352	Economy	9300.00
0005435243501	15352	Economy	9300.00
0005432784661	15352	Economy	9300.00
0005432848664	4363	Economy	7000.00
0005432848676	4363	Economy	6300.00
0005434462844	4363	Economy	6300.00
0005432848670	4363	Economy	6300.00
0005434463983	4363	Economy	6300.00
0005434463985	4363	Economy	6300.00
0005432848675	4363	Economy	6300.00
0005432848671	4363	Economy	6300.00
0005432848672	4363	Economy	6300.00
0005432848666	4363	Economy	6300.00
0005434463982	4363	Economy	6300.00
0005432848668	4363	Economy	6300.00
0005435851062	4363	Economy	6300.00
0005432848673	4363	Economy	6300.00
0005435851080	4363	Economy	6300.00
0005432848667	4363	Economy	6300.00
0005435851061	4363	Economy	6300.00
0005434463984	4363	Economy	6300.00
0005434462843	4363	Economy	6300.00
0005435851089	4363	Economy	6300.00
0005432848665	4363	Economy	6300.00
0005432848674	4363	Economy	6300.00
0005432848669	4363	Economy	6300.00
0005435851136	28881	Economy	7000.00
0005432848570	28881	Economy	7000.00
0005432848562	28881	Economy	6300.00
0005432848555	28881	Economy	6300.00
0005434463972	28881	Economy	6300.00
0005434461687	28881	Economy	6300.00
0005434463962	28881	Economy	6300.00
0005432848492	28881	Economy	6300.00
0005435851140	28881	Economy	6300.00
0005434463961	28881	Economy	6300.00
0005435851135	28881	Economy	6300.00
0005434463973	28881	Economy	6300.00
0005435851134	28881	Economy	6300.00
0005435851138	28881	Economy	6300.00
0005432848563	28881	Economy	6300.00
0005432848599	28881	Economy	6300.00
0005432848600	28881	Economy	6300.00
0005432848560	28881	Economy	6300.00
0005435851131	28881	Economy	6300.00
0005435851132	28881	Economy	6300.00
0005435851133	28881	Economy	6300.00
0005435851139	28881	Economy	6300.00
0005432848571	28881	Economy	6300.00
0005435851137	28881	Economy	6300.00
0005434461688	28881	Economy	6300.00
0005434926606	6305	Business	11900.00
0005434926618	6305	Business	11900.00
0005434444104	6305	Business	11900.00
0005434926604	6305	Business	11900.00
0005434444115	6305	Business	11900.00
0005433497729	6305	Business	11900.00
0005434926605	6305	Business	11900.00
0005434926617	6305	Business	11900.00
0005432075313	6305	Business	11900.00
0005433497744	6305	Business	11900.00
0005432075315	6305	Business	11900.00
0005434926610	6305	Economy	4000.00
0005434926602	6305	Economy	4000.00
0005433497751	6305	Economy	4000.00
0005434926598	6305	Economy	4000.00
0005434444116	6305	Economy	4000.00
0005434926599	6305	Economy	4000.00
0005433497736	6305	Economy	4000.00
0005434926624	6305	Economy	4000.00
0005433497748	6305	Economy	4000.00
0005434926622	6305	Economy	4400.00
0005434926607	6305	Economy	4400.00
0005434926619	6305	Economy	4400.00
0005433497757	6305	Economy	4400.00
0005434926613	6305	Economy	4400.00
0005434926594	6305	Economy	4000.00
0005433497759	6305	Economy	4000.00
0005434926614	6305	Economy	4000.00
0005434444103	6305	Economy	4000.00
0005434444105	6305	Economy	4000.00
0005433497752	6305	Economy	4000.00
0005434444113	6305	Economy	4000.00
0005433497756	6305	Economy	4000.00
0005433497746	6305	Economy	4000.00
0005434444110	6305	Economy	4000.00
0005434926593	6305	Economy	4000.00
0005434926616	6305	Economy	4000.00
0005433497755	6305	Economy	4000.00
0005434926603	6305	Economy	4000.00
0005433497730	6305	Economy	4000.00
0005433497750	6305	Economy	4000.00
0005434444108	6305	Economy	4000.00
0005434926609	6305	Economy	4000.00
0005433497753	6305	Economy	4000.00
0005433497732	6305	Economy	4000.00
0005434444109	6305	Economy	4000.00
0005433497733	6305	Economy	4000.00
0005434444102	6305	Economy	4000.00
0005434444107	6305	Economy	4000.00
0005433497754	6305	Economy	4000.00
0005434926591	6305	Economy	4000.00
0005432075314	6305	Economy	4000.00
0005434444111	6305	Economy	4000.00
0005434926620	6305	Economy	4000.00
0005434926600	6305	Economy	4000.00
0005433497740	6305	Economy	4000.00
0005433497743	6305	Economy	4000.00
0005433497749	6305	Economy	4000.00
0005434926595	6305	Economy	4000.00
0005434444112	6305	Economy	4000.00
0005434926608	6305	Economy	4000.00
0005433497739	6305	Economy	4000.00
0005433497758	6305	Economy	4000.00
0005433497731	6305	Economy	4000.00
0005433497745	6305	Economy	4000.00
0005434926612	6305	Economy	4000.00
0005434444106	6305	Economy	4000.00
0005434926601	6305	Economy	4000.00
0005434926621	6305	Economy	4000.00
0005434926623	6305	Economy	4000.00
0005434926615	6305	Economy	4000.00
0005433497741	6305	Economy	4000.00
0005434926596	6305	Economy	4000.00
0005433497747	6305	Economy	4000.00
0005434926597	6305	Economy	4000.00
0005434926611	6305	Economy	4000.00
0005433497742	6305	Economy	4000.00
0005433497738	6305	Economy	4000.00
0005433497735	6305	Economy	4000.00
0005434926625	6305	Economy	4000.00
0005434926589	6305	Economy	4000.00
0005433497734	6305	Economy	4000.00
0005433497737	6305	Economy	4000.00
0005434444114	6305	Economy	4000.00
0005434926592	6305	Economy	4000.00
0005434926590	6305	Economy	4000.00
0005435257478	20341	Business	11900.00
0005435257470	20341	Business	11900.00
0005435257479	20341	Economy	4000.00
0005435257469	20341	Economy	4000.00
0005435257473	20341	Economy	4400.00
0005435257477	20341	Economy	4000.00
0005435257471	20341	Economy	4000.00
0005435257467	20341	Economy	4000.00
0005435257468	20341	Economy	4000.00
0005435257466	20341	Economy	4000.00
0005435257474	20341	Economy	4000.00
0005435257476	20341	Economy	4000.00
0005435257475	20341	Economy	4000.00
0005435257472	20341	Economy	4000.00
0005433497462	20340	Business	11900.00
0005433497531	20340	Business	11900.00
0005434926166	20340	Business	11900.00
0005434926313	20340	Business	11900.00
0005434926225	20340	Business	11900.00
0005433497592	20340	Business	11900.00
0005434926113	20340	Business	11900.00
0005434926282	20340	Business	11900.00
0005434926263	20340	Business	11900.00
0005433497555	20340	Business	11900.00
0005434926235	20340	Economy	4000.00
0005434926312	20340	Economy	4000.00
0005434926232	20340	Economy	4000.00
0005433497487	20340	Economy	4000.00
0005434926297	20340	Economy	4000.00
0005434926167	20340	Economy	4000.00
0005434926180	20340	Economy	4000.00
0005433497553	20340	Economy	4000.00
0005434443937	20340	Economy	4000.00
0005434926298	20340	Economy	4000.00
0005433497474	20340	Economy	4400.00
0005433497488	20340	Economy	4400.00
0005433497473	20340	Economy	4400.00
0005434926260	20340	Economy	4400.00
0005434926243	20340	Economy	4000.00
0005434926242	20340	Economy	4000.00
0005434443990	20340	Economy	4000.00
0005434443913	20340	Economy	4000.00
0005433497617	20340	Economy	4000.00
0005434926299	20340	Economy	4000.00
0005434926236	20340	Economy	4000.00
0005433497577	20340	Economy	4000.00
0005433497618	20340	Economy	4000.00
0005433497619	20340	Economy	4000.00
0005433497566	20340	Economy	4000.00
0005434443954	20340	Economy	4000.00
0005434926315	20340	Economy	4000.00
0005434443956	20340	Economy	4000.00
0005433497594	20340	Economy	4000.00
0005433497505	20340	Economy	4000.00
0005434926179	20340	Economy	4000.00
0005433497461	20340	Economy	4000.00
0005434926241	20340	Economy	4000.00
0005434443936	20340	Economy	4000.00
0005434926285	20340	Economy	4000.00
0005433497591	20340	Economy	4000.00
0005434926311	20340	Economy	4000.00
0005434926314	20340	Economy	4000.00
0005433497507	20340	Economy	4000.00
0005434443963	20340	Economy	4000.00
0005434926237	20340	Economy	4000.00
0005433497499	20340	Economy	4000.00
0005434926177	20340	Economy	4000.00
0005433497458	20340	Economy	4000.00
0005433497563	20340	Economy	4000.00
0005434443965	20340	Economy	4000.00
0005434926205	20340	Economy	4000.00
0005433497512	20340	Economy	4000.00
0005433497522	20340	Economy	4000.00
0005434443945	20340	Economy	4000.00
0005433497513	20340	Economy	4000.00
0005433497581	20340	Economy	4000.00
0005434926265	20340	Economy	4000.00
0005434926291	20340	Economy	4000.00
0005434926288	20340	Economy	4000.00
0005434926264	20340	Economy	4000.00
0005433497447	20340	Economy	4000.00
0005434443912	20340	Economy	4000.00
0005433497510	20340	Economy	4000.00
0005433497554	20340	Economy	4000.00
0005434926250	20340	Economy	4000.00
0005434926112	20340	Economy	4000.00
0005433497654	20340	Economy	4000.00
0005433497576	20340	Economy	4000.00
0005433497506	20340	Economy	4000.00
0005434926224	20340	Economy	4000.00
0005433497424	20340	Economy	4000.00
0005434443934	20340	Economy	4000.00
0005433497565	20340	Economy	4000.00
0005433497426	20340	Economy	4000.00
0005434926286	20340	Economy	4000.00
0005434926247	20340	Economy	4000.00
0005434926125	20340	Economy	4000.00
0005434926178	20340	Economy	4000.00
0005433497425	20340	Economy	4000.00
0005433497532	20340	Economy	4000.00
0005434926204	20340	Economy	4000.00
0005434926233	20340	Economy	4000.00
0005434443922	20340	Economy	4000.00
0005433497530	20340	Economy	4000.00
0005433497514	20340	Economy	4000.00
0005434443955	20340	Economy	4000.00
0005432784946	12190	Business	41200.00
0005432784666	12190	Business	41200.00
0005432784812	12190	Business	41200.00
0005435243525	12190	Business	41200.00
0005435243538	12190	Business	41200.00
0005435243513	12190	Business	41200.00
0005432784695	12190	Business	41200.00
0005432784848	12190	Business	41200.00
0005435243530	12190	Business	41200.00
0005435243518	12190	Business	41200.00
0005432784784	12190	Business	41200.00
0005435243524	12190	Economy	13700.00
0005432784859	12190	Economy	13700.00
0005432784766	12190	Economy	13700.00
0005432784934	12190	Economy	13700.00
0005435243527	12190	Economy	13700.00
0005435243514	12190	Economy	13700.00
0005432784914	12190	Economy	13700.00
0005432784612	12190	Economy	13700.00
0005432784698	12190	Economy	13700.00
0005435243520	12190	Economy	13700.00
0005432784804	12190	Economy	15100.00
0005435243526	12190	Economy	15100.00
0005435243536	12190	Economy	15100.00
0005432784676	12190	Economy	15100.00
0005435243537	12190	Economy	13700.00
0005432784773	12190	Economy	13700.00
0005432784947	12190	Economy	13700.00
0005432784681	12190	Economy	13700.00
0005432784697	12190	Economy	13700.00
0005432784670	12190	Economy	13700.00
0005432784867	12190	Economy	13700.00
0005435243532	12190	Economy	13700.00
0005432784933	12190	Economy	13700.00
0005432784636	12190	Economy	13700.00
0005432784816	12190	Economy	13700.00
0005432784735	12190	Economy	13700.00
0005432784611	12190	Economy	13700.00
0005435243517	12190	Economy	13700.00
0005432784557	12190	Economy	13700.00
0005435243529	12190	Economy	13700.00
0005435243539	12190	Economy	13700.00
0005435243531	12190	Economy	13700.00
0005432784785	12190	Economy	13700.00
0005432784674	12190	Economy	13700.00
0005432784675	12190	Economy	13700.00
0005432784637	12190	Economy	13700.00
0005435243528	12190	Economy	13700.00
0005435243516	12190	Economy	13700.00
0005432784935	12190	Economy	13700.00
0005435243512	12190	Economy	13700.00
0005435243511	12190	Economy	13700.00
0005432784660	12190	Economy	13700.00
0005432784571	12190	Economy	13700.00
0005435243533	12190	Economy	13700.00
0005432784860	12190	Economy	13700.00
0005435243535	12190	Economy	13700.00
0005435243519	12190	Economy	13700.00
0005432784509	12190	Economy	13700.00
0005432784506	12190	Economy	13700.00
0005432784665	12190	Economy	13700.00
0005432784443	12190	Economy	13700.00
0005432784314	12190	Economy	13700.00
0005435243522	12190	Economy	13700.00
0005432784708	12190	Economy	13700.00
0005432784508	12190	Economy	13700.00
0005432784616	12190	Economy	13700.00
0005432784786	12190	Economy	13700.00
0005435243534	12190	Economy	13700.00
0005432784772	12190	Economy	13700.00
0005432784638	12190	Economy	13700.00
0005435243521	12190	Economy	13700.00
0005435243523	12190	Economy	13700.00
0005435243515	12190	Economy	13700.00
0005432784849	12190	Economy	13700.00
0005432784847	12190	Economy	13700.00
0005432784694	12190	Economy	13700.00
0005432784507	12190	Economy	13700.00
0005432784613	12190	Economy	13700.00
0005432785046	15454	Business	41200.00
0005435243181	15454	Business	41200.00
0005435243320	15454	Business	41200.00
0005432785080	15454	Business	41200.00
0005435243180	15454	Business	41200.00
0005432785060	15454	Business	41200.00
0005435243189	15454	Business	41200.00
0005432785091	15454	Business	41200.00
0005432785071	15454	Business	41200.00
0005432785057	15454	Economy	13700.00
0005432785087	15454	Economy	13700.00
0005432785049	15454	Economy	13700.00
0005432785047	15454	Economy	13700.00
0005435243329	15454	Economy	13700.00
0005435243276	15454	Economy	13700.00
0005432785061	15454	Economy	13700.00
0005432785051	15454	Economy	15100.00
0005432785054	15454	Economy	15100.00
0005432785082	15454	Economy	13700.00
0005432785052	15454	Economy	13700.00
0005432785056	15454	Economy	13700.00
0005432785064	15454	Economy	13700.00
0005435243321	15454	Economy	13700.00
0005435243220	15454	Economy	13700.00
0005432785063	15454	Economy	13700.00
0005435243267	15454	Economy	13700.00
0005435243261	15454	Economy	13700.00
0005432785089	15454	Economy	13700.00
0005432785074	15454	Economy	13700.00
0005432785088	15454	Economy	13700.00
0005432785083	15454	Economy	13700.00
0005432785062	15454	Economy	13700.00
0005435243275	15454	Economy	13700.00
0005435243356	15454	Economy	13700.00
0005432785072	15454	Economy	13700.00
0005435243368	15454	Economy	13700.00
0005432785070	15454	Economy	13700.00
0005432785090	15454	Economy	13700.00
0005435243292	15454	Economy	13700.00
0005432785058	15454	Economy	13700.00
0005432785073	15454	Economy	13700.00
0005435243252	15454	Economy	13700.00
0005432785079	15454	Economy	13700.00
0005432785076	15454	Economy	13700.00
0005432785068	15454	Economy	13700.00
0005432785059	15454	Economy	13700.00
0005432785048	15454	Economy	13700.00
0005432785085	15454	Economy	13700.00
0005432785077	15454	Economy	13700.00
0005435243319	15454	Economy	13700.00
0005432785043	15454	Economy	13700.00
0005432785055	15454	Economy	13700.00
0005432785086	15454	Economy	13700.00
0005432785078	15454	Economy	13700.00
0005432785045	15454	Economy	13700.00
0005435243381	15454	Economy	13700.00
0005432785044	15454	Economy	13700.00
0005432785084	15454	Economy	13700.00
0005435243283	15454	Economy	13700.00
0005435243308	15454	Economy	13700.00
0005432785066	15454	Economy	13700.00
0005432785050	15454	Economy	13700.00
0005432785075	15454	Economy	13700.00
0005435243213	15454	Economy	13700.00
0005432785067	15454	Economy	13700.00
0005432785065	15454	Economy	13700.00
0005432785069	15454	Economy	13700.00
0005432785053	15454	Economy	13700.00
0005432785042	15454	Economy	13700.00
0005432785081	15454	Economy	13700.00
0005434879628	10097	Business	49700.00
0005434879966	10097	Business	49700.00
0005434879510	10097	Business	49700.00
0005434880112	10097	Business	49700.00
0005434879738	10097	Business	49700.00
0005434879757	10097	Business	49700.00
0005434879626	10097	Business	49700.00
0005434879912	10097	Business	49700.00
0005434910171	10097	Business	49700.00
0005434879171	10097	Business	49700.00
0005434879826	10097	Business	49700.00
0005434910169	10097	Business	49700.00
0005434879454	10097	Business	49700.00
0005434879386	10097	Business	49700.00
0005434879473	10097	Business	49700.00
0005435914079	10097	Business	49700.00
0005435914093	10097	Business	49700.00
0005434880039	10097	Business	49700.00
0005434879735	10097	Business	49700.00
0005434879851	10097	Business	49700.00
0005434879714	10097	Economy	16600.00
0005434879793	10097	Economy	16600.00
0005434879931	10097	Economy	16600.00
0005434879843	10097	Economy	16600.00
0005434880170	10097	Economy	16600.00
0005434879858	10097	Economy	16600.00
0005435914089	10097	Economy	16600.00
0005434879894	10097	Economy	16600.00
0005434879507	10097	Economy	16600.00
0005434879773	10097	Economy	16600.00
0005434879467	10097	Economy	16600.00
0005434879888	10097	Economy	16600.00
0005434879584	10097	Economy	18200.00
0005434879442	10097	Economy	18200.00
0005434879594	10097	Economy	18200.00
0005434879889	10097	Economy	16600.00
0005434879563	10097	Economy	18200.00
0005434910170	10097	Economy	16600.00
0005434879756	10097	Economy	16600.00
0005435914085	10097	Economy	16600.00
0005435914084	10097	Economy	16600.00
0005435914094	10097	Economy	16600.00
0005435914073	10097	Economy	16600.00
0005434879583	10097	Economy	16600.00
0005435914080	10097	Economy	16600.00
0005434880001	10097	Economy	16600.00
0005434879470	10097	Economy	16600.00
0005434880040	10097	Economy	16600.00
0005434879636	10097	Economy	16600.00
0005434879950	10097	Economy	16600.00
0005434879911	10097	Economy	16600.00
0005434879792	10097	Economy	16600.00
0005435914096	10097	Economy	16600.00
0005434879876	10097	Economy	16600.00
0005434879881	10097	Economy	16600.00
0005434879132	10097	Economy	16600.00
0005435914086	10097	Economy	16600.00
0005435914077	10097	Economy	16600.00
0005434879363	10097	Economy	16600.00
0005435914082	10097	Economy	16600.00
0005435914076	10097	Economy	16600.00
0005434879362	10097	Economy	16600.00
0005435914081	10097	Economy	16600.00
0005435914078	10097	Economy	16600.00
0005434758932	10097	Economy	16600.00
0005434879337	10097	Economy	16600.00
0005434879664	10097	Economy	16600.00
0005434879443	10097	Economy	16600.00
0005434879764	10097	Economy	16600.00
0005434879582	10097	Economy	16600.00
0005434880231	10097	Economy	16600.00
0005434879177	10097	Economy	16600.00
0005434879890	10097	Economy	16600.00
0005434879700	10097	Economy	16600.00
0005434879859	10097	Economy	16600.00
0005434879772	10097	Economy	16600.00
0005434758935	10097	Economy	16600.00
0005434880263	10097	Economy	16600.00
0005435914092	10097	Economy	16600.00
0005434879820	10097	Economy	16600.00
0005434879762	10097	Economy	16600.00
0005434879763	10097	Economy	16600.00
0005434879951	10097	Economy	16600.00
0005434758933	10097	Economy	16600.00
0005434879715	10097	Economy	16600.00
0005434758934	10097	Economy	16600.00
0005434879581	10097	Economy	16600.00
0005434879564	10097	Economy	16600.00
0005435914087	10097	Economy	16600.00
0005435914083	10097	Economy	16600.00
0005434879176	10097	Economy	16600.00
0005434880169	10097	Economy	16600.00
0005434879387	10097	Economy	16600.00
0005434879978	10097	Economy	16600.00
0005434879915	10097	Economy	16600.00
0005435914088	10097	Economy	16600.00
0005434879674	10097	Economy	16600.00
0005434879744	10097	Economy	16600.00
0005434879472	10097	Economy	16600.00
0005434880074	10097	Economy	16600.00
0005435914091	10097	Economy	16600.00
0005434879659	10097	Economy	16600.00
0005434879361	10097	Economy	16600.00
0005434879842	10097	Economy	16600.00
0005435914074	10097	Economy	16600.00
0005434879884	10097	Economy	16600.00
0005434879650	10097	Economy	16600.00
0005434880248	10097	Economy	16600.00
0005435914095	10097	Economy	16600.00
0005435914090	10097	Economy	16600.00
0005434879852	10097	Economy	16600.00
0005434879870	10097	Economy	16600.00
0005434879221	10097	Economy	16600.00
0005434879771	10097	Economy	16600.00
0005435914075	10097	Economy	16600.00
0005434880559	14651	Business	49700.00
0005434880566	14651	Business	49700.00
0005434880553	14651	Business	49700.00
0005434880502	14651	Business	49700.00
0005434880572	14651	Business	49700.00
0005434880587	14651	Business	49700.00
0005434880581	14651	Business	49700.00
0005434880562	14651	Business	49700.00
0005434880511	14651	Business	49700.00
0005434880539	14651	Business	49700.00
0005434880551	14651	Business	49700.00
0005434880546	14651	Business	49700.00
0005434880563	14651	Business	49700.00
0005434880577	14651	Business	49700.00
0005434880527	14651	Business	49700.00
0005434880507	14651	Business	49700.00
0005435913961	14651	Business	49700.00
0005434880524	14651	Business	49700.00
0005434880585	14651	Business	49700.00
0005434880548	14651	Economy	16600.00
0005435913974	14651	Economy	16600.00
0005434880545	14651	Economy	16600.00
0005435913976	14651	Economy	16600.00
0005434880573	14651	Economy	16600.00
0005434758952	14651	Economy	16600.00
0005434880525	14651	Economy	16600.00
0005434880537	14651	Economy	16600.00
0005434880544	14651	Economy	16600.00
0005434880529	14651	Economy	16600.00
0005434880512	14651	Economy	16600.00
0005434880549	14651	Economy	18200.00
0005434880508	14651	Economy	18200.00
0005435913975	14651	Economy	18200.00
0005434880513	14651	Economy	16600.00
0005434880520	14651	Economy	16600.00
0005434880558	14651	Economy	16600.00
0005434880589	14651	Economy	16600.00
0005434880582	14651	Economy	16600.00
0005434880594	14651	Economy	16600.00
0005434880503	14651	Economy	16600.00
0005434880593	14651	Economy	16600.00
0005434880583	14651	Economy	16600.00
0005434880565	14651	Economy	16600.00
0005434880576	14651	Economy	16600.00
0005434880564	14651	Economy	16600.00
0005434880538	14651	Economy	16600.00
0005434880560	14651	Economy	16600.00
0005434880550	14651	Economy	16600.00
0005434880514	14651	Economy	16600.00
0005434880505	14651	Economy	16600.00
0005434880580	14651	Economy	16600.00
0005434880531	14651	Economy	16600.00
0005434880578	14651	Economy	16600.00
0005434880590	14651	Economy	16600.00
0005434880523	14651	Economy	16600.00
0005434880592	14651	Economy	16600.00
0005434880556	14651	Economy	16600.00
0005434880528	14651	Economy	16600.00
0005434880588	14651	Economy	16600.00
0005434880574	14651	Economy	16600.00
0005434880530	14651	Economy	16600.00
0005434880542	14651	Economy	16600.00
0005435913973	14651	Economy	16600.00
0005434880552	14651	Economy	16600.00
0005434880517	14651	Economy	16600.00
0005434880570	14651	Economy	16600.00
0005435913971	14651	Economy	16600.00
0005434880533	14651	Economy	16600.00
0005434880584	14651	Economy	16600.00
0005434880521	14651	Economy	16600.00
0005434880518	14651	Economy	16600.00
0005434880571	14651	Economy	16600.00
0005434880510	14651	Economy	16600.00
0005434880519	14651	Economy	16600.00
0005434880569	14651	Economy	16600.00
0005434880567	14651	Economy	16600.00
0005434880516	14651	Economy	16600.00
0005434880557	14651	Economy	16600.00
0005434880509	14651	Economy	16600.00
0005434880522	14651	Economy	16600.00
0005435913969	14651	Economy	16600.00
0005434880532	14651	Economy	16600.00
0005434880554	14651	Economy	16600.00
0005434880540	14651	Economy	16600.00
0005434880575	14651	Economy	16600.00
0005434880561	14651	Economy	16600.00
0005435913972	14651	Economy	16600.00
0005434880536	14651	Economy	16600.00
0005434880534	14651	Economy	16600.00
0005434880568	14651	Economy	16600.00
0005434880543	14651	Economy	16600.00
0005434880526	14651	Economy	16600.00
0005434880541	14651	Economy	16600.00
0005434880555	14651	Economy	16600.00
0005434880586	14651	Economy	16600.00
0005434880515	14651	Economy	16600.00
0005434880535	14651	Economy	16600.00
0005434880579	14651	Economy	16600.00
0005434880506	14651	Economy	16600.00
0005434758951	14651	Economy	16600.00
0005434880504	14651	Economy	16600.00
0005434880591	14651	Economy	16600.00
0005434880547	14651	Economy	16600.00
0005434252062	9238	Economy	22400.00
0005434252110	9238	Economy	22400.00
0005435660412	9238	Economy	20300.00
0005435660410	9238	Economy	20300.00
0005435660417	9238	Economy	20300.00
0005435660409	9238	Economy	20300.00
0005435660415	9238	Economy	20300.00
0005434252124	9238	Economy	20300.00
0005434252055	9238	Economy	20300.00
0005434252054	9238	Economy	20300.00
0005435660413	9238	Economy	20300.00
0005434252125	9238	Economy	20300.00
0005435660414	9238	Economy	20300.00
0005435660418	9238	Economy	20300.00
0005435660411	9238	Economy	20300.00
0005434252126	9238	Economy	20300.00
0005434252056	9238	Economy	20300.00
0005435660416	9238	Economy	20300.00
0005435660408	9238	Economy	20300.00
0005435660381	24684	Economy	22400.00
0005435660291	24684	Economy	22400.00
0005434252202	24684	Economy	22400.00
0005435660294	24684	Economy	20300.00
0005434252199	24684	Economy	20300.00
0005434252201	24684	Economy	20300.00
0005435660284	24684	Economy	20300.00
0005434252203	24684	Economy	20300.00
0005435660293	24684	Economy	20300.00
0005435660347	24684	Economy	20300.00
0005434252204	24684	Economy	20300.00
0005435660312	24684	Economy	20300.00
0005435660348	24684	Economy	20300.00
0005434252198	24684	Economy	20300.00
0005435660316	24684	Economy	20300.00
0005435660334	24684	Economy	20300.00
0005435660355	24684	Economy	20300.00
0005434252194	24684	Economy	20300.00
0005434252197	24684	Economy	20300.00
0005434252195	24684	Economy	20300.00
0005434252196	24684	Economy	20300.00
0005435660321	24684	Economy	20300.00
0005434252200	24684	Economy	20300.00
0005433681712	2781	Business	33000.00
0005433681728	2781	Business	33000.00
0005432967386	2781	Business	33000.00
0005432967344	2781	Business	33000.00
0005433681738	2781	Business	33000.00
0005433681747	2781	Business	33000.00
0005432967325	2781	Business	33000.00
0005433681724	2781	Business	33000.00
0005433681751	2781	Business	33000.00
0005433681717	2781	Business	33000.00
0005433681748	2781	Business	33000.00
0005433681741	2781	Economy	11000.00
0005432967360	2781	Economy	11000.00
0005432967233	2781	Economy	11000.00
0005433681746	2781	Economy	11000.00
0005432967353	2781	Economy	11000.00
0005432967275	2781	Economy	11000.00
0005433681734	2781	Economy	11000.00
0005432967286	2781	Economy	11000.00
0005433681740	2781	Economy	11000.00
0005433681743	2781	Economy	12100.00
0005433681729	2781	Economy	12100.00
0005433681719	2781	Economy	12100.00
0005432967341	2781	Economy	12100.00
0005433684470	2781	Economy	11000.00
0005432967293	2781	Economy	11000.00
0005433681736	2781	Economy	11000.00
0005433681727	2781	Economy	11000.00
0005432967359	2781	Economy	11000.00
0005433681735	2781	Economy	11000.00
0005432967389	2781	Economy	11000.00
0005432967296	2781	Economy	11000.00
0005433681714	2781	Economy	11000.00
0005432967397	2781	Economy	11000.00
0005432967403	2781	Economy	11000.00
0005433681716	2781	Economy	11000.00
0005432222913	2781	Economy	11000.00
0005432967234	2781	Economy	11000.00
0005433681725	2781	Economy	11000.00
0005432967405	2781	Economy	11000.00
0005433681720	2781	Economy	11000.00
0005433681742	2781	Economy	11000.00
0005433681733	2781	Economy	11000.00
0005433681753	2781	Economy	11000.00
0005433681754	2781	Economy	11000.00
0005433681723	2781	Economy	11000.00
0005433681730	2781	Economy	11000.00
0005432967267	2781	Economy	11000.00
0005432967349	2781	Economy	11000.00
0005433681732	2781	Economy	11000.00
0005432967321	2781	Economy	11000.00
0005432967263	2781	Economy	11000.00
0005433681752	2781	Economy	11000.00
0005433681731	2781	Economy	11000.00
0005432967365	2781	Economy	11000.00
0005433681755	2781	Economy	11000.00
0005432967343	2781	Economy	11000.00
0005432967322	2781	Economy	11000.00
0005432967225	2781	Economy	11000.00
0005432967287	2781	Economy	11000.00
0005432222910	2781	Economy	11000.00
0005432967326	2781	Economy	11000.00
0005433681739	2781	Economy	11000.00
0005433681713	2781	Economy	11000.00
0005432222912	2781	Economy	11000.00
0005433681715	2781	Economy	11000.00
0005433681726	2781	Economy	11000.00
0005433681722	2781	Economy	11000.00
0005433681750	2781	Economy	11000.00
0005433684469	2781	Economy	11000.00
0005432967421	2781	Economy	11000.00
0005433681737	2781	Economy	11000.00
0005433681718	2781	Economy	11000.00
0005432967358	2781	Economy	11000.00
0005432967352	2781	Economy	11000.00
0005433681711	2781	Economy	11000.00
0005433681757	2781	Economy	11000.00
0005432967340	2781	Economy	11000.00
0005432967331	2781	Economy	11000.00
0005432967268	2781	Economy	11000.00
0005432967309	2781	Economy	11000.00
0005432967276	2781	Economy	11000.00
0005432967260	2781	Economy	11000.00
0005432222914	2781	Economy	11000.00
0005433681744	2781	Economy	11000.00
0005433681756	2781	Economy	11000.00
0005432967385	2781	Economy	11000.00
0005433681745	2781	Economy	11000.00
0005433681721	2781	Economy	11000.00
0005433681749	2781	Economy	11000.00
0005432222911	2781	Economy	11000.00
0005432967565	29173	Business	33000.00
0005433681341	29173	Business	33000.00
0005432967560	29173	Business	33000.00
0005433681452	29173	Business	33000.00
0005432967558	29173	Business	33000.00
0005433681244	29173	Business	33000.00
0005433681346	29173	Business	33000.00
0005433681438	29173	Business	33000.00
0005433681363	29173	Business	33000.00
0005433681298	29173	Business	33000.00
0005433681247	29173	Economy	11000.00
0005433681408	29173	Economy	11000.00
0005433681223	29173	Economy	11000.00
0005433681481	29173	Economy	11000.00
0005433681434	29173	Economy	11000.00
0005433681480	29173	Economy	11000.00
0005432967554	29173	Economy	11000.00
0005433681278	29173	Economy	11000.00
0005432967562	29173	Economy	11000.00
0005433681380	29173	Economy	11000.00
0005433681494	29173	Economy	12100.00
0005433681327	29173	Economy	12100.00
0005433681435	29173	Economy	12100.00
0005432967564	29173	Economy	12100.00
0005432005282	29173	Economy	12100.00
0005433681611	29173	Economy	11000.00
0005433681295	29173	Economy	11000.00
0005433684450	29173	Economy	11000.00
0005433681302	29173	Economy	11000.00
0005433681214	29173	Economy	11000.00
0005433681347	29173	Economy	11000.00
0005433681385	29173	Economy	11000.00
0005433681249	29173	Economy	11000.00
0005433681479	29173	Economy	11000.00
0005433681456	29173	Economy	11000.00
0005432967555	29173	Economy	11000.00
0005433681246	29173	Economy	11000.00
0005432005284	29173	Economy	11000.00
0005433681628	29173	Economy	11000.00
0005433681428	29173	Economy	11000.00
0005433681245	29173	Economy	11000.00
0005433681348	29173	Economy	11000.00
0005432967567	29173	Economy	11000.00
0005432967559	29173	Economy	11000.00
0005432967568	29173	Economy	11000.00
0005433681338	29173	Economy	11000.00
0005433681409	29173	Economy	11000.00
0005432967563	29173	Economy	11000.00
0005433681415	29173	Economy	11000.00
0005432967561	29173	Economy	11000.00
0005433681287	29173	Economy	11000.00
0005433690948	29173	Economy	11000.00
0005432967556	29173	Economy	11000.00
0005433681180	29173	Economy	11000.00
0005433681181	29173	Economy	11000.00
0005433681418	29173	Economy	11000.00
0005432967571	29173	Economy	11000.00
0005433681182	29173	Economy	11000.00
0005433681536	29173	Economy	11000.00
0005432967551	29173	Economy	11000.00
0005432967553	29173	Economy	11000.00
0005432967566	29173	Economy	11000.00
0005433681213	29173	Economy	11000.00
0005432967569	29173	Economy	11000.00
0005433681427	29173	Economy	11000.00
0005432967572	29173	Economy	11000.00
0005433681280	29173	Economy	11000.00
0005432967570	29173	Economy	11000.00
0005433681493	29173	Economy	11000.00
0005432967552	29173	Economy	11000.00
0005432967557	29173	Economy	11000.00
0005433681470	29173	Economy	11000.00
0005433681453	29173	Economy	11000.00
0005433681345	29173	Economy	11000.00
0005433681366	29173	Economy	11000.00
0005433681301	29173	Economy	11000.00
0005433681414	29173	Economy	11000.00
0005433681471	29173	Economy	11000.00
0005433681495	29173	Economy	11000.00
0005432005283	29173	Economy	11000.00
0005432967573	29173	Economy	11000.00
0005433681339	29173	Economy	11000.00
0005433681355	29173	Economy	11000.00
0005434163730	9286	Business	132900.00
0005433616446	9286	Business	132900.00
0005433616394	9286	Business	132900.00
0005433616395	9286	Business	132900.00
0005433634625	9286	Business	132900.00
0005432755155	9286	Business	132900.00
0005433616392	9286	Business	132900.00
0005434163779	9286	Business	132900.00
0005433616404	9286	Business	132900.00
0005433616412	9286	Business	132900.00
0005433616422	9286	Business	132900.00
0005433616442	9286	Business	132900.00
0005432145160	9286	Business	132900.00
0005434163753	9286	Business	132900.00
0005433616441	9286	Business	132900.00
0005433616416	9286	Business	132900.00
0005433578133	9286	Business	132900.00
0005433616413	9286	Business	132900.00
0005433616439	9286	Business	132900.00
0005433616430	9286	Business	132900.00
0005433578141	9286	Business	132900.00
0005433634640	9286	Business	132900.00
0005433616387	9286	Business	132900.00
0005432755158	9286	Business	132900.00
0005432145161	9286	Economy	48700.00
0005434269136	9286	Economy	48700.00
0005433634623	9286	Economy	48700.00
0005433616455	9286	Economy	48700.00
0005433616453	9286	Economy	48700.00
0005433616380	9286	Economy	44300.00
0005433616420	9286	Economy	44300.00
0005434163748	9286	Economy	44300.00
0005434163751	9286	Economy	44300.00
0005433578134	9286	Economy	44300.00
0005433578139	9286	Economy	44300.00
0005433616437	9286	Economy	44300.00
0005434163789	9286	Economy	44300.00
0005433616398	9286	Economy	44300.00
0005433616440	9286	Economy	44300.00
0005433578142	9286	Economy	44300.00
0005433616406	9286	Economy	44300.00
0005433616434	9286	Economy	44300.00
0005433634634	9286	Economy	44300.00
0005433616448	9286	Economy	44300.00
0005433616427	9286	Economy	44300.00
0005433616452	9286	Economy	44300.00
0005433634631	9286	Economy	44300.00
0005433634641	9286	Economy	44300.00
0005433578135	9286	Economy	44300.00
0005433616417	9286	Economy	44300.00
0005433616388	9286	Economy	44300.00
0005433616450	9286	Economy	44300.00
0005433634630	9286	Economy	44300.00
0005433616400	9286	Economy	44300.00
0005433578144	9286	Economy	44300.00
0005433616405	9286	Economy	44300.00
0005433616435	9286	Economy	44300.00
0005433634622	9286	Economy	44300.00
0005433634639	9286	Economy	44300.00
0005433616408	9286	Economy	44300.00
0005433634636	9286	Economy	44300.00
0005434269135	9286	Economy	44300.00
0005432145159	9286	Economy	44300.00
0005433616429	9286	Economy	44300.00
0005434163745	9286	Economy	44300.00
0005433616414	9286	Economy	44300.00
0005432755157	9286	Economy	44300.00
0005433616409	9286	Economy	44300.00
0005433616421	9286	Economy	44300.00
0005433578136	9286	Economy	44300.00
0005433634638	9286	Economy	44300.00
0005434163744	9286	Economy	44300.00
0005434163752	9286	Economy	44300.00
0005433616436	9286	Economy	44300.00
0005433634637	9286	Economy	44300.00
0005433634626	9286	Economy	44300.00
0005433616401	9286	Economy	44300.00
0005433616397	9286	Economy	44300.00
0005433616447	9286	Economy	44300.00
0005433616385	9286	Economy	44300.00
0005433616389	9286	Economy	44300.00
0005433616382	9286	Economy	44300.00
0005433616432	9286	Economy	48700.00
0005433616449	9286	Economy	48700.00
0005433616407	9286	Economy	48700.00
0005433634633	9286	Economy	48700.00
0005433578140	9286	Economy	48700.00
0005433634616	9286	Economy	44300.00
0005433616403	9286	Economy	44300.00
0005433616451	9286	Economy	44300.00
0005432755156	9286	Economy	48700.00
0005433616426	9286	Economy	44300.00
0005434269137	9286	Economy	44300.00
0005433634611	9286	Economy	44300.00
0005433634618	9286	Economy	44300.00
0005433616391	9286	Economy	44300.00
0005433634612	9286	Economy	44300.00
0005433616402	9286	Economy	44300.00
0005433634617	9286	Economy	44300.00
0005433616386	9286	Economy	44300.00
0005432755159	9286	Economy	44300.00
0005433616428	9286	Economy	44300.00
0005433578138	9286	Economy	44300.00
0005433616381	9286	Economy	44300.00
0005433616393	9286	Economy	44300.00
0005434153547	9286	Economy	44300.00
0005433578143	9286	Economy	44300.00
0005433616411	9286	Economy	44300.00
0005433634632	9286	Economy	44300.00
0005433578145	9286	Economy	44300.00
0005433616418	9286	Economy	44300.00
0005433616410	9286	Economy	44300.00
0005433578132	9286	Economy	44300.00
0005433616415	9286	Economy	44300.00
0005433616444	9286	Economy	44300.00
0005433616419	9286	Economy	44300.00
0005433634610	9286	Economy	44300.00
0005433616384	9286	Economy	44300.00
0005433634613	9286	Economy	44300.00
0005433634614	9286	Economy	44300.00
0005433634620	9286	Economy	44300.00
0005433634624	9286	Economy	44300.00
0005433634627	9286	Economy	44300.00
0005433616443	9286	Economy	44300.00
0005433616399	9286	Economy	44300.00
0005433634619	9286	Economy	44300.00
0005433616438	9286	Economy	44300.00
0005434163733	9286	Economy	44300.00
0005433616390	9286	Economy	44300.00
0005433616423	9286	Economy	44300.00
0005432145162	9286	Economy	44300.00
0005433616425	9286	Economy	44300.00
0005433578137	9286	Economy	44300.00
0005433634629	9286	Economy	44300.00
0005433616383	9286	Economy	44300.00
0005433616445	9286	Economy	44300.00
0005433616424	9286	Economy	44300.00
0005433634628	9286	Economy	44300.00
0005434163731	9286	Economy	44300.00
0005433634635	9286	Economy	44300.00
0005433616396	9286	Economy	44300.00
0005433616431	9286	Economy	44300.00
0005433634615	9286	Economy	44300.00
0005434163758	9286	Economy	44300.00
0005433616433	9286	Economy	44300.00
0005433634621	9286	Economy	44300.00
0005433616454	9286	Economy	44300.00
0005434163833	25227	Business	132900.00
0005433634353	25227	Business	132900.00
0005433615818	25227	Business	132900.00
0005433615652	25227	Business	132900.00
0005433615556	25227	Business	132900.00
0005434163835	25227	Business	132900.00
0005433615651	25227	Business	132900.00
0005433615987	25227	Business	132900.00
0005433615960	25227	Business	132900.00
0005434163840	25227	Business	132900.00
0005433634312	25227	Business	132900.00
0005433615732	25227	Business	132900.00
0005433615694	25227	Business	132900.00
0005434272226	25227	Business	132900.00
0005433615346	25227	Business	132900.00
0005433615708	25227	Business	132900.00
0005433634297	25227	Business	132900.00
0005433615869	25227	Business	132900.00
0005433577993	25227	Business	132900.00
0005433615427	25227	Business	132900.00
0005433634378	25227	Business	132900.00
0005433634273	25227	Business	132900.00
0005433615571	25227	Business	132900.00
0005433634486	25227	Economy	48700.00
0005433634284	25227	Economy	48700.00
0005433615915	25227	Economy	48700.00
0005433615727	25227	Economy	48700.00
0005434163837	25227	Economy	48700.00
0005433615807	25227	Economy	44300.00
0005433615819	25227	Economy	48700.00
0005433578053	25227	Economy	44300.00
0005433615841	25227	Economy	44300.00
0005433616171	25227	Economy	44300.00
0005433578041	25227	Economy	44300.00
0005433616072	25227	Economy	44300.00
0005433634237	25227	Economy	44300.00
0005433615649	25227	Economy	44300.00
0005433634229	25227	Economy	44300.00
0005434163839	25227	Economy	44300.00
0005433578017	25227	Economy	44300.00
0005433634423	25227	Economy	44300.00
0005433634317	25227	Economy	44300.00
0005433615896	25227	Economy	44300.00
0005434163836	25227	Economy	44300.00
0005433578035	25227	Economy	44300.00
0005433578040	25227	Economy	44300.00
0005433615875	25227	Economy	44300.00
0005433615692	25227	Economy	44300.00
0005433634308	25227	Economy	44300.00
0005433615762	25227	Economy	44300.00
0005433615834	25227	Economy	44300.00
0005433634288	25227	Economy	44300.00
0005433634245	25227	Economy	44300.00
0005433578042	25227	Economy	44300.00
0005433615936	25227	Economy	44300.00
0005433634318	25227	Economy	44300.00
0005433578003	25227	Economy	44300.00
0005433616112	25227	Economy	44300.00
0005433616052	25227	Economy	44300.00
0005433615814	25227	Economy	44300.00
0005433634311	25227	Economy	44300.00
0005433634413	25227	Economy	44300.00
0005433578030	25227	Economy	44300.00
0005433616015	25227	Economy	44300.00
0005433634145	25227	Economy	44300.00
0005433616025	25227	Economy	44300.00
0005433615854	25227	Economy	44300.00
0005433634409	25227	Economy	44300.00
0005433634354	25227	Economy	44300.00
0005433615970	25227	Economy	44300.00
0005433634238	25227	Economy	44300.00
0005433615533	25227	Economy	44300.00
0005433634386	25227	Economy	44300.00
0005433615947	25227	Economy	44300.00
0005433615922	25227	Economy	44300.00
0005433615447	25227	Economy	44300.00
0005433615728	25227	Economy	44300.00
0005433578000	25227	Economy	48700.00
0005433615937	25227	Economy	48700.00
0005433634269	25227	Economy	48700.00
0005434163838	25227	Economy	48700.00
0005433615998	25227	Economy	48700.00
0005433615986	25227	Economy	44300.00
0005433615805	25227	Economy	44300.00
0005433634236	25227	Economy	44300.00
0005433634425	25227	Economy	48700.00
0005433577925	25227	Economy	44300.00
0005433615865	25227	Economy	44300.00
0005433615777	25227	Economy	44300.00
0005433634424	25227	Economy	44300.00
0005433615945	25227	Economy	44300.00
0005433578025	25227	Economy	44300.00
0005434163831	25227	Economy	44300.00
0005433634280	25227	Economy	44300.00
0005433615806	25227	Economy	44300.00
0005434273113	25227	Economy	44300.00
0005433578005	25227	Economy	44300.00
0005433615778	25227	Economy	44300.00
0005433634289	25227	Economy	44300.00
0005433634327	25227	Economy	44300.00
0005433634319	25227	Economy	44300.00
0005433578029	25227	Economy	44300.00
0005433634362	25227	Economy	44300.00
0005433616073	25227	Economy	44300.00
0005433634328	25227	Economy	44300.00
0005433615776	25227	Economy	44300.00
0005433615877	25227	Economy	44300.00
0005433615788	25227	Economy	44300.00
0005433616172	25227	Economy	44300.00
0005433634422	25227	Economy	44300.00
0005433615895	25227	Economy	44300.00
0005433615594	25227	Economy	44300.00
0005433634385	25227	Economy	44300.00
0005433615644	25227	Economy	44300.00
0005434273114	25227	Economy	44300.00
0005433615787	25227	Economy	44300.00
0005433615643	25227	Economy	44300.00
0005433577994	25227	Economy	44300.00
0005433615725	25227	Economy	44300.00
0005433578046	25227	Economy	44300.00
0005433616041	25227	Economy	44300.00
0005433615793	25227	Economy	44300.00
0005433615500	25227	Economy	44300.00
0005433615650	25227	Economy	44300.00
0005433615785	25227	Economy	44300.00
0005433615726	25227	Economy	44300.00
0005433634228	25227	Economy	44300.00
0005434163834	25227	Economy	44300.00
0005433616136	25227	Economy	44300.00
0005433577972	25227	Economy	44300.00
0005433615731	25227	Economy	44300.00
0005433615874	25227	Economy	44300.00
0005433634337	25227	Economy	44300.00
0005433615847	25227	Economy	44300.00
0005434163832	25227	Economy	44300.00
0005433615840	25227	Economy	44300.00
0005433634282	25227	Economy	44300.00
0005435986965	4254	Business	193100.00
0005435986970	4254	Business	193100.00
0005435986972	4254	Business	193100.00
0005435986963	4254	Business	193100.00
0005435856281	4254	Business	193100.00
0005434271345	4254	Business	193100.00
0005435947464	4254	Business	193100.00
0005435986956	4254	Business	193100.00
0005432185020	4254	Business	193100.00
0005435986959	4254	Business	193100.00
0005435947478	4254	Business	193100.00
0005435947399	4254	Economy	70800.00
0005435947466	4254	Economy	64400.00
0005435947489	4254	Economy	64400.00
0005435856275	4254	Economy	64400.00
0005435947541	4254	Economy	64400.00
0005435856248	4254	Economy	64400.00
0005435947447	4254	Economy	64400.00
0005435986964	4254	Economy	64400.00
0005435986968	4254	Economy	64400.00
0005435856268	4254	Economy	64400.00
0005432185021	4254	Economy	64400.00
0005432571388	4254	Economy	64400.00
0005435947465	4254	Economy	64400.00
0005434271354	4254	Economy	64400.00
0005434271333	4254	Economy	64400.00
0005435986958	4254	Economy	64400.00
0005434271353	4254	Economy	64400.00
0005435947486	4254	Economy	64400.00
0005435986971	4254	Economy	64400.00
0005435856247	4254	Economy	64400.00
0005435856255	4254	Economy	64400.00
0005435947515	4254	Economy	64400.00
0005434271344	4254	Economy	64400.00
0005435947496	4254	Economy	64400.00
0005435856246	4254	Economy	64400.00
0005435856253	4254	Economy	64400.00
0005435986969	4254	Economy	64400.00
0005435986967	4254	Economy	64400.00
0005435947452	4254	Economy	70800.00
0005435986961	4254	Economy	64400.00
0005435986957	4254	Economy	64400.00
0005435986962	4254	Economy	64400.00
0005435986960	4254	Economy	64400.00
0005434271348	4254	Economy	64400.00
0005435986966	4254	Economy	64400.00
0005435947404	4254	Economy	64400.00
0005435947406	4254	Economy	64400.00
0005435947487	4254	Economy	64400.00
0005435947479	4254	Economy	64400.00
0005435947622	26600	Business	193100.00
0005435986870	26600	Business	193100.00
0005435947608	26600	Business	193100.00
0005435947617	26600	Business	193100.00
0005435947621	26600	Business	193100.00
0005435947620	26600	Business	193100.00
0005435787409	26600	Economy	70800.00
0005435947609	26600	Economy	64400.00
0005435856311	26600	Economy	64400.00
0005435947612	26600	Economy	64400.00
0005435986881	26600	Economy	64400.00
0005435947616	26600	Economy	64400.00
0005435947611	26600	Economy	64400.00
0005435986855	26600	Economy	64400.00
0005435787407	26600	Economy	64400.00
0005435986873	26600	Economy	64400.00
0005435986872	26600	Economy	64400.00
0005435986841	26600	Economy	64400.00
0005435856342	26600	Economy	64400.00
0005432571419	26600	Economy	64400.00
0005435947614	26600	Economy	64400.00
0005435947610	26600	Economy	64400.00
0005435986869	26600	Economy	64400.00
0005435947618	26600	Economy	64400.00
0005435856341	26600	Economy	64400.00
0005432571418	26600	Economy	64400.00
0005435986880	26600	Economy	64400.00
0005435986842	26600	Economy	64400.00
0005435856309	26600	Economy	64400.00
0005432571417	26600	Economy	64400.00
0005435856310	26600	Economy	64400.00
0005435856308	26600	Economy	64400.00
0005435856343	26600	Economy	64400.00
0005435856307	26600	Economy	64400.00
0005435947619	26600	Economy	64400.00
0005435986860	26600	Economy	64400.00
0005435986885	26600	Economy	64400.00
0005435986871	26600	Economy	64400.00
0005435947613	26600	Economy	64400.00
0005435947615	26600	Economy	64400.00
0005435787408	26600	Economy	64400.00
0005433570581	348	Business	21500.00
0005432948979	348	Business	21500.00
0005432949221	348	Business	21500.00
0005432949292	348	Business	21500.00
0005433075152	348	Business	21500.00
0005433570627	348	Business	21500.00
0005433570621	348	Business	21500.00
0005432949034	348	Business	21500.00
0005433570589	348	Business	21500.00
0005433570582	348	Business	21500.00
0005433570623	348	Business	21500.00
0005433570606	348	Business	21500.00
0005433570614	348	Business	21500.00
0005433129362	348	Business	21500.00
0005433075062	348	Business	21500.00
0005433570580	348	Business	21500.00
0005433075272	348	Business	21500.00
0005433570625	348	Business	21500.00
0005433134211	348	Business	21500.00
0005433570592	348	Business	21500.00
0005433134210	348	Business	21500.00
0005433570572	348	Business	21500.00
0005432949047	348	Business	21500.00
0005433570605	348	Business	21500.00
0005433075096	348	Business	21500.00
0005432949149	348	Business	21500.00
0005433129342	348	Economy	7900.00
0005432949112	348	Economy	7900.00
0005433570576	348	Economy	7900.00
0005433570588	348	Economy	7900.00
0005433075196	348	Economy	7900.00
0005433570595	348	Economy	7900.00
0005433570619	348	Economy	7200.00
0005432949135	348	Economy	7200.00
0005433570583	348	Economy	7200.00
0005433075289	348	Economy	7200.00
0005432949032	348	Economy	7200.00
0005433570603	348	Economy	7200.00
0005433570633	348	Economy	7200.00
0005433570615	348	Economy	7200.00
0005433570600	348	Economy	7200.00
0005433129364	348	Economy	7200.00
0005433075168	348	Economy	7200.00
0005433570618	348	Economy	7200.00
0005432949125	348	Economy	7200.00
0005432949062	348	Economy	7200.00
0005432948968	348	Economy	7200.00
0005432948967	348	Economy	7200.00
0005432949167	348	Economy	7200.00
0005433075300	348	Economy	7200.00
0005433075273	348	Economy	7200.00
0005433570577	348	Economy	7200.00
0005432948960	348	Economy	7200.00
0005433570617	348	Economy	7200.00
0005432949298	348	Economy	7200.00
0005432949052	348	Economy	7200.00
0005433570607	348	Economy	7200.00
0005433570579	348	Economy	7200.00
0005433129363	348	Economy	7200.00
0005433074991	348	Economy	7200.00
0005432948900	348	Economy	7200.00
0005433570628	348	Economy	7200.00
0005433570604	348	Economy	7200.00
0005433570571	348	Economy	7200.00
0005433570601	348	Economy	7200.00
0005432949170	348	Economy	7200.00
0005433075072	348	Economy	7200.00
0005432949118	348	Economy	7200.00
0005433570620	348	Economy	7200.00
0005433075242	348	Economy	7200.00
0005432949138	348	Economy	7200.00
0005433570596	348	Economy	7200.00
0005432949191	348	Economy	7200.00
0005433570629	348	Economy	7200.00
0005432949267	348	Economy	7200.00
0005433570573	348	Economy	7200.00
0005433570599	348	Economy	7200.00
0005433570631	348	Economy	7200.00
0005433075183	348	Economy	7200.00
0005433570616	348	Economy	7200.00
0005433075121	348	Economy	7200.00
0005433570598	348	Economy	7200.00
0005432949064	348	Economy	7200.00
0005432949013	348	Economy	7200.00
0005432948918	348	Economy	7200.00
0005433570591	348	Economy	7200.00
0005433570597	348	Economy	7900.00
0005433570610	348	Economy	7900.00
0005432949203	348	Economy	7900.00
0005433570590	348	Economy	7900.00
0005433570611	348	Economy	7900.00
0005433570632	348	Economy	7200.00
0005432949266	348	Economy	7200.00
0005432949192	348	Economy	7200.00
0005432949261	348	Economy	7200.00
0005433570626	348	Economy	7900.00
0005432949180	348	Economy	7200.00
0005433570570	348	Economy	7200.00
0005433075243	348	Economy	7200.00
0005432949204	348	Economy	7200.00
0005432239089	348	Economy	7200.00
0005432948901	348	Economy	7200.00
0005433129343	348	Economy	7200.00
0005433075241	348	Economy	7200.00
0005432949148	348	Economy	7200.00
0005433570622	348	Economy	7200.00
0005433075120	348	Economy	7200.00
0005432949136	348	Economy	7200.00
0005433570585	348	Economy	7200.00
0005432949262	348	Economy	7200.00
0005433075061	348	Economy	7200.00
0005433075071	348	Economy	7200.00
0005432949139	348	Economy	7200.00
0005433570612	348	Economy	7200.00
0005432949293	348	Economy	7200.00
0005433570630	348	Economy	7200.00
0005433570587	348	Economy	7200.00
0005433075143	348	Economy	7200.00
0005433570593	348	Economy	7200.00
0005432239087	348	Economy	7200.00
0005432949126	348	Economy	7200.00
0005433075167	348	Economy	7200.00
0005433570584	348	Economy	7200.00
0005433570634	348	Economy	7200.00
0005433129355	348	Economy	7200.00
0005432949137	348	Economy	7200.00
0005433075239	348	Economy	7200.00
0005433129356	348	Economy	7200.00
0005433570575	348	Economy	7200.00
0005433570613	348	Economy	7200.00
0005432949033	348	Economy	7200.00
0005433129352	348	Economy	7200.00
0005432949048	348	Economy	7200.00
0005432948980	348	Economy	7200.00
0005433129344	348	Economy	7200.00
0005432949051	348	Economy	7200.00
0005433570624	348	Economy	7200.00
0005432239088	348	Economy	7200.00
0005433075288	348	Economy	7200.00
0005433570594	348	Economy	7200.00
0005432239086	348	Economy	7200.00
0005432949111	348	Economy	7200.00
0005432949183	348	Economy	7200.00
0005433570608	348	Economy	7200.00
0005433570574	348	Economy	7200.00
0005433075200	348	Economy	7200.00
0005432949061	348	Economy	7200.00
0005432949012	348	Economy	7200.00
0005433570586	348	Economy	7200.00
0005433075144	348	Economy	7200.00
0005433570578	348	Economy	7200.00
0005432949163	348	Economy	7200.00
0005433075199	348	Economy	7200.00
0005433570609	348	Economy	7200.00
0005433075185	348	Economy	7200.00
0005432949018	348	Economy	7200.00
0005433570602	348	Economy	7200.00
0005433075218	348	Economy	7200.00
0005432949469	11620	Business	21500.00
0005433075402	11620	Business	21500.00
0005433075394	11620	Business	21500.00
0005433075404	11620	Business	21500.00
0005432949463	11620	Business	21500.00
0005432949437	11620	Business	21500.00
0005432949445	11620	Business	21500.00
0005432949440	11620	Business	21500.00
0005433569869	11620	Business	21500.00
0005433569554	11620	Business	21500.00
0005433131819	11620	Business	21500.00
0005433075410	11620	Business	21500.00
0005432949462	11620	Business	21500.00
0005433075397	11620	Business	21500.00
0005432192396	11620	Business	21500.00
0005433569775	11620	Business	21500.00
0005432949433	11620	Business	21500.00
0005432949458	11620	Business	21500.00
0005433569734	11620	Business	21500.00
0005433569949	11620	Business	21500.00
0005433569671	11620	Business	21500.00
0005433075400	11620	Business	21500.00
0005432949459	11620	Business	21500.00
0005432949464	11620	Economy	7900.00
0005432949474	11620	Economy	7900.00
0005433075409	11620	Economy	7900.00
0005432949455	11620	Economy	7200.00
0005432949470	11620	Economy	7200.00
0005433569908	11620	Economy	7200.00
0005433569653	11620	Economy	7200.00
0005432949435	11620	Economy	7200.00
0005433131820	11620	Economy	7200.00
0005433131821	11620	Economy	7200.00
0005433569823	11620	Economy	7200.00
0005432949465	11620	Economy	7200.00
0005433570025	11620	Economy	7200.00
0005433569987	11620	Economy	7200.00
0005433569923	11620	Economy	7200.00
0005432949466	11620	Economy	7200.00
0005433075408	11620	Economy	7200.00
0005432949453	11620	Economy	7200.00
0005433569824	11620	Economy	7200.00
0005433569415	11620	Economy	7200.00
0005432949449	11620	Economy	7200.00
0005433569951	11620	Economy	7200.00
0005433569851	11620	Economy	7200.00
0005433075418	11620	Economy	7200.00
0005432949432	11620	Economy	7200.00
0005433569897	11620	Economy	7200.00
0005433569891	11620	Economy	7200.00
0005433569889	11620	Economy	7200.00
0005432949454	11620	Economy	7200.00
0005433075395	11620	Economy	7200.00
0005433569855	11620	Economy	7200.00
0005432949468	11620	Economy	7200.00
0005433569846	11620	Economy	7200.00
0005433075399	11620	Economy	7200.00
0005433569988	11620	Economy	7200.00
0005432949457	11620	Economy	7200.00
0005433075416	11620	Economy	7200.00
0005432949452	11620	Economy	7200.00
0005433075417	11620	Economy	7200.00
0005432949460	11620	Economy	7200.00
0005432949444	11620	Economy	7200.00
0005433569672	11620	Economy	7200.00
0005432949461	11620	Economy	7200.00
0005433075412	11620	Economy	7200.00
0005433569950	11620	Economy	7200.00
0005433075393	11620	Economy	7200.00
0005432949439	11620	Economy	7200.00
0005432192398	11620	Economy	7200.00
0005432949473	11620	Economy	7200.00
0005433569997	11620	Economy	7200.00
0005432949442	11620	Economy	7200.00
0005433569996	11620	Economy	7200.00
0005432949446	11620	Economy	7200.00
0005432949434	11620	Economy	7200.00
0005433569847	11620	Economy	7900.00
0005433075414	11620	Economy	7900.00
0005433569654	11620	Economy	7900.00
0005432949456	11620	Economy	7900.00
0005433075406	11620	Economy	7900.00
0005432949443	11620	Economy	7200.00
0005433569886	11620	Economy	7200.00
0005433569659	11620	Economy	7200.00
0005432949436	11620	Economy	7900.00
0005432949471	11620	Economy	7200.00
0005433569601	11620	Economy	7200.00
0005433075413	11620	Economy	7200.00
0005433569868	11620	Economy	7200.00
0005433075403	11620	Economy	7200.00
0005433570026	11620	Economy	7200.00
0005433569931	11620	Economy	7200.00
0005433075398	11620	Economy	7200.00
0005433569845	11620	Economy	7200.00
0005432949441	11620	Economy	7200.00
0005433569815	11620	Economy	7200.00
0005433134249	11620	Economy	7200.00
0005433569971	11620	Economy	7200.00
0005433569783	11620	Economy	7200.00
0005433569821	11620	Economy	7200.00
0005433075415	11620	Economy	7200.00
0005433569414	11620	Economy	7200.00
0005432949467	11620	Economy	7200.00
0005433075407	11620	Economy	7200.00
0005432949451	11620	Economy	7200.00
0005433569722	11620	Economy	7200.00
0005432949472	11620	Economy	7200.00
0005433569859	11620	Economy	7200.00
0005433134250	11620	Economy	7200.00
0005432192397	11620	Economy	7200.00
0005433569928	11620	Economy	7200.00
0005433569929	11620	Economy	7200.00
0005433075396	11620	Economy	7200.00
0005433569673	11620	Economy	7200.00
0005432949438	11620	Economy	7200.00
0005432949448	11620	Economy	7200.00
0005432949475	11620	Economy	7200.00
0005433075401	11620	Economy	7200.00
0005433570003	11620	Economy	7200.00
0005433569898	11620	Economy	7200.00
0005433131822	11620	Economy	7200.00
0005433569777	11620	Economy	7200.00
0005433569852	11620	Economy	7200.00
0005433570000	11620	Economy	7200.00
0005433569890	11620	Economy	7200.00
0005433570016	11620	Economy	7200.00
0005433569924	11620	Economy	7200.00
0005433569887	11620	Economy	7200.00
0005433569416	11620	Economy	7200.00
0005433569999	11620	Economy	7200.00
0005432949450	11620	Economy	7200.00
0005433075411	11620	Economy	7200.00
0005433075405	11620	Economy	7200.00
0005433569771	11620	Economy	7200.00
0005432192399	11620	Economy	7200.00
0005433131823	11620	Economy	7200.00
0005432949447	11620	Economy	7200.00
0005433569772	11620	Economy	7200.00
0005433569970	11620	Economy	7200.00
0005433569663	11620	Economy	7200.00
0005434733031	9975	Economy	6300.00
0005434733026	9975	Economy	6300.00
0005434733028	9975	Economy	6300.00
0005433817565	9975	Economy	6300.00
0005433817563	9975	Economy	6300.00
0005433817564	9975	Economy	6300.00
0005434733037	9975	Economy	6300.00
0005434733030	9975	Economy	6300.00
0005433817542	13919	Economy	6300.00
0005433817541	13919	Economy	6300.00
0005434733067	13919	Economy	6300.00
0005434733070	13919	Economy	6300.00
0005434733069	13919	Economy	6300.00
0005433817536	13919	Economy	6300.00
0005434733068	13919	Economy	6300.00
0005432869602	2369	Business	184500.00
0005433755617	2369	Business	184500.00
0005433755629	2369	Business	184500.00
0005435983427	2369	Business	184500.00
0005432985692	2369	Business	184500.00
0005435983422	2369	Business	184500.00
0005434731230	2369	Business	184500.00
0005432985713	2369	Business	184500.00
0005432655836	2369	Business	184500.00
0005433755599	2369	Business	184500.00
0005435983433	2369	Business	184500.00
0005433766758	2369	Business	184500.00
0005433435195	2369	Business	184500.00
0005435983437	2369	Business	184500.00
0005432300408	2369	Business	184500.00
0005433755579	2369	Business	184500.00
0005434731242	2369	Business	184500.00
0005432985688	2369	Business	184500.00
0005435983400	2369	Business	184500.00
0005433755624	2369	Business	184500.00
0005432869638	2369	Business	184500.00
0005433435074	2369	Business	184500.00
0005435983426	2369	Business	184500.00
0005433755626	2369	Business	184500.00
0005433435177	2369	Business	184500.00
0005435983397	2369	Business	184500.00
0005433435174	2369	Business	184500.00
0005433755616	2369	Business	184500.00
0005433755595	2369	Business	184500.00
0005435983440	2369	Economy	67700.00
0005433435181	2369	Economy	67700.00
0005433766757	2369	Economy	67700.00
0005433435065	2369	Economy	67700.00
0005432985613	2369	Economy	61500.00
0005435983410	2369	Economy	61500.00
0005433755593	2369	Economy	61500.00
0005435983418	2369	Economy	61500.00
0005432869601	2369	Economy	61500.00
0005435983443	2369	Economy	61500.00
0005433435106	2369	Economy	61500.00
0005435983438	2369	Economy	61500.00
0005432300411	2369	Economy	61500.00
0005432985489	2369	Economy	61500.00
0005433755620	2369	Economy	61500.00
0005432985691	2369	Economy	61500.00
0005432226212	2369	Economy	61500.00
0005432985642	2369	Economy	61500.00
0005433755622	2369	Economy	61500.00
0005433755587	2369	Economy	61500.00
0005432985694	2369	Economy	61500.00
0005432655833	2369	Economy	61500.00
0005433755621	2369	Economy	61500.00
0005432655832	2369	Economy	61500.00
0005432655830	2369	Economy	61500.00
0005432300405	2369	Economy	61500.00
0005435983420	2369	Economy	61500.00
0005435983399	2369	Economy	61500.00
0005432869636	2369	Economy	61500.00
0005433755591	2369	Economy	61500.00
0005433766734	2369	Economy	61500.00
0005432226209	2369	Economy	61500.00
0005433755605	2369	Economy	61500.00
0005433755597	2369	Economy	61500.00
0005432985565	2369	Economy	61500.00
0005432985715	2369	Economy	61500.00
0005435983408	2369	Economy	61500.00
0005433435087	2369	Economy	61500.00
0005435983402	2369	Economy	61500.00
0005433755625	2369	Economy	61500.00
0005433755588	2369	Economy	61500.00
0005432655831	2369	Economy	61500.00
0005432985564	2369	Economy	61500.00
0005433755600	2369	Economy	61500.00
0005432655834	2369	Economy	61500.00
0005433766759	2369	Economy	61500.00
0005432226211	2369	Economy	61500.00
0005433755607	2369	Economy	61500.00
0005432300409	2369	Economy	61500.00
0005433755606	2369	Economy	61500.00
0005435983412	2369	Economy	61500.00
0005435983435	2369	Economy	61500.00
0005435983424	2369	Economy	61500.00
0005435983407	2369	Economy	61500.00
0005433755602	2369	Economy	61500.00
0005435983442	2369	Economy	61500.00
0005433434997	2369	Economy	61500.00
0005432985653	2369	Economy	61500.00
0005433755604	2369	Economy	61500.00
0005433435105	2369	Economy	61500.00
0005432985673	2369	Economy	61500.00
0005433435186	2369	Economy	61500.00
0005435983414	2369	Economy	61500.00
0005433755582	2369	Economy	61500.00
0005435983404	2369	Economy	61500.00
0005433755598	2369	Economy	61500.00
0005433435227	2369	Economy	61500.00
0005433435064	2369	Economy	61500.00
0005434731249	2369	Economy	61500.00
0005433755578	2369	Economy	61500.00
0005433764731	2369	Economy	61500.00
0005432869639	2369	Economy	61500.00
0005435983430	2369	Economy	61500.00
0005434731248	2369	Economy	61500.00
0005433755609	2369	Economy	61500.00
0005435983411	2369	Economy	61500.00
0005435983445	2369	Economy	61500.00
0005432985532	2369	Economy	61500.00
0005435983428	2369	Economy	61500.00
0005435983417	2369	Economy	61500.00
0005432985665	2369	Economy	61500.00
0005433755608	2369	Economy	61500.00
0005435983423	2369	Economy	61500.00
0005432869603	2369	Economy	61500.00
0005432985693	2369	Economy	61500.00
0005432655829	2369	Economy	61500.00
0005435983409	2369	Economy	61500.00
0005432226208	2369	Economy	61500.00
0005434731247	2369	Economy	61500.00
0005432985615	2369	Economy	61500.00
0005433755627	2369	Economy	61500.00
0005435983444	2369	Economy	61500.00
0005434731224	2369	Economy	61500.00
0005433435118	2369	Economy	61500.00
0005433755618	2369	Economy	61500.00
0005432300406	2369	Economy	61500.00
0005432655837	2369	Economy	61500.00
0005433435203	2369	Economy	61500.00
0005433435122	2369	Economy	61500.00
0005433755630	2369	Economy	61500.00
0005433755603	2369	Economy	61500.00
0005435983415	2369	Economy	61500.00
0005432655827	2369	Economy	61500.00
0005433755615	2369	Economy	61500.00
0005433755577	2369	Economy	61500.00
0005435983421	2369	Economy	67700.00
0005433755619	2369	Economy	67700.00
0005433755628	2369	Economy	61500.00
0005432655838	2369	Economy	61500.00
0005433755612	2369	Economy	61500.00
0005435983434	2369	Economy	67700.00
0005434731250	2369	Economy	67700.00
0005435983429	2369	Economy	61500.00
0005432985714	2369	Economy	61500.00
0005435983431	2369	Economy	61500.00
0005432226210	2369	Economy	61500.00
0005435983446	2369	Economy	61500.00
0005433755583	2369	Economy	61500.00
0005433766735	2369	Economy	61500.00
0005433755589	2369	Economy	61500.00
0005435983406	2369	Economy	61500.00
0005433766760	2369	Economy	61500.00
0005433755580	2369	Economy	61500.00
0005434731243	2369	Economy	61500.00
0005433435096	2369	Economy	61500.00
0005432869611	2369	Economy	61500.00
0005433755586	2369	Economy	61500.00
0005433435194	2369	Economy	61500.00
0005433755585	2369	Economy	61500.00
0005435983425	2369	Economy	61500.00
0005432655835	2369	Economy	61500.00
0005433755592	2369	Economy	61500.00
0005435983447	2369	Economy	61500.00
0005435983448	2369	Economy	61500.00
0005433755596	2369	Economy	61500.00
0005432985724	2369	Economy	61500.00
0005433755613	2369	Economy	61500.00
0005433435158	2369	Economy	61500.00
0005433766733	2369	Economy	61500.00
0005432985666	2369	Economy	61500.00
0005433755614	2369	Economy	61500.00
0005435983419	2369	Economy	61500.00
0005432869610	2369	Economy	61500.00
0005435983432	2369	Economy	61500.00
0005433755601	2369	Economy	61500.00
0005435983441	2369	Economy	61500.00
0005433755590	2369	Economy	61500.00
0005433755623	2369	Economy	61500.00
0005433755610	2369	Economy	61500.00
0005435983436	2369	Economy	61500.00
0005433755581	2369	Economy	61500.00
0005432655828	2369	Economy	61500.00
0005435983403	2369	Economy	61500.00
0005433435095	2369	Economy	61500.00
0005432985616	2369	Economy	61500.00
0005433755584	2369	Economy	61500.00
0005432985654	2369	Economy	61500.00
0005435983405	2369	Economy	61500.00
0005433435187	2369	Economy	61500.00
0005433435113	2369	Economy	61500.00
0005432300410	2369	Economy	61500.00
0005432869621	2369	Economy	61500.00
0005432985575	2369	Economy	61500.00
0005433764730	2369	Economy	61500.00
0005435983416	2369	Economy	61500.00
0005432985610	2369	Economy	61500.00
0005432985689	2369	Economy	61500.00
0005433435161	2369	Economy	61500.00
0005435983401	2369	Economy	61500.00
0005433435159	2369	Economy	61500.00
0005432985582	2369	Economy	61500.00
0005435983439	2369	Economy	61500.00
0005432985628	2369	Economy	61500.00
0005435983413	2369	Economy	61500.00
0005432300407	2369	Economy	61500.00
0005433435160	2369	Economy	61500.00
0005433435178	2369	Economy	61500.00
0005432869635	2369	Economy	61500.00
0005433755594	2369	Economy	61500.00
0005434731229	2369	Economy	61500.00
0005433755611	2369	Economy	61500.00
0005435983398	2369	Economy	61500.00
0005433435112	2369	Economy	61500.00
0005433434998	2369	Economy	61500.00
0005433435182	2369	Economy	61500.00
0005435982755	26199	Business	184500.00
0005433435368	26199	Business	184500.00
0005433754990	26199	Business	184500.00
0005435982925	26199	Business	184500.00
0005432985870	26199	Business	184500.00
0005433755115	26199	Business	184500.00
0005433754792	26199	Business	184500.00
0005434731277	26199	Business	184500.00
0005433754897	26199	Business	184500.00
0005435982926	26199	Business	184500.00
0005433435372	26199	Business	184500.00
0005435982993	26199	Business	184500.00
0005435982799	26199	Business	184500.00
0005432049553	26199	Business	184500.00
0005433755119	26199	Business	184500.00
0005432655745	26199	Business	184500.00
0005433755091	26199	Business	184500.00
0005433435377	26199	Business	184500.00
0005432051206	26199	Business	184500.00
0005433755086	26199	Business	184500.00
0005433755025	26199	Business	184500.00
0005432869688	26199	Business	184500.00
0005432985878	26199	Business	184500.00
0005432985888	26199	Business	184500.00
0005432869685	26199	Business	184500.00
0005435982817	26199	Business	184500.00
0005433755289	26199	Business	184500.00
0005432655744	26199	Business	184500.00
0005432655676	26199	Economy	67700.00
0005433755048	26199	Economy	67700.00
0005432655683	26199	Economy	67700.00
0005433755001	26199	Economy	67700.00
0005433435376	26199	Economy	61500.00
0005433755066	26199	Economy	61500.00
0005433435364	26199	Economy	61500.00
0005433755174	26199	Economy	61500.00
0005433754896	26199	Economy	61500.00
0005433435369	26199	Economy	61500.00
0005433755130	26199	Economy	61500.00
0005433435370	26199	Economy	61500.00
0005433755339	26199	Economy	61500.00
0005432655639	26199	Economy	61500.00
0005433755237	26199	Economy	61500.00
0005432985860	26199	Economy	61500.00
0005435982992	26199	Economy	61500.00
0005433754996	26199	Economy	61500.00
0005433755173	26199	Economy	61500.00
0005435982924	26199	Economy	61500.00
0005433435380	26199	Economy	61500.00
0005432985861	26199	Economy	61500.00
0005433755107	26199	Economy	61500.00
0005435982779	26199	Economy	61500.00
0005432985889	26199	Economy	61500.00
0005435982979	26199	Economy	61500.00
0005433435378	26199	Economy	61500.00
0005432985874	26199	Economy	61500.00
0005433755116	26199	Economy	61500.00
0005432985884	26199	Economy	61500.00
0005432655707	26199	Economy	61500.00
0005433755166	26199	Economy	61500.00
0005432655682	26199	Economy	61500.00
0005434731273	26199	Economy	61500.00
0005432985875	26199	Economy	61500.00
0005433766712	26199	Economy	61500.00
0005432985883	26199	Economy	61500.00
0005435982956	26199	Economy	61500.00
0005433755000	26199	Economy	61500.00
0005433764714	26199	Economy	61500.00
0005433755065	26199	Economy	61500.00
0005433764723	26199	Economy	61500.00
0005433435373	26199	Economy	61500.00
0005435982839	26199	Economy	61500.00
0005432985882	26199	Economy	61500.00
0005432985869	26199	Economy	61500.00
0005435982964	26199	Economy	61500.00
0005432985862	26199	Economy	61500.00
0005432049554	26199	Economy	61500.00
0005433435366	26199	Economy	61500.00
0005435982994	26199	Economy	61500.00
0005433764705	26199	Economy	61500.00
0005432985886	26199	Economy	61500.00
0005433755178	26199	Economy	61500.00
0005432985866	26199	Economy	61500.00
0005432985877	26199	Economy	61500.00
0005433754985	26199	Economy	61500.00
0005433755334	26199	Economy	61500.00
0005433754994	26199	Economy	61500.00
0005433755238	26199	Economy	61500.00
0005433435365	26199	Economy	61500.00
0005433755058	26199	Economy	61500.00
0005432985872	26199	Economy	61500.00
0005432655680	26199	Economy	61500.00
0005432985873	26199	Economy	61500.00
0005432655640	26199	Economy	61500.00
0005435982762	26199	Economy	61500.00
0005432985880	26199	Economy	61500.00
0005435982728	26199	Economy	61500.00
0005433755342	26199	Economy	61500.00
0005433755193	26199	Economy	61500.00
0005435982976	26199	Economy	61500.00
0005433435363	26199	Economy	61500.00
0005433766704	26199	Economy	61500.00
0005433754995	26199	Economy	61500.00
0005432985868	26199	Economy	61500.00
0005434731275	26199	Economy	61500.00
0005432655701	26199	Economy	61500.00
0005433435362	26199	Economy	61500.00
0005433755187	26199	Economy	61500.00
0005433755143	26199	Economy	61500.00
0005435982780	26199	Economy	61500.00
0005433435382	26199	Economy	61500.00
0005433755084	26199	Economy	61500.00
0005433435358	26199	Economy	61500.00
0005433755184	26199	Economy	61500.00
0005433755026	26199	Economy	61500.00
0005433755108	26199	Economy	61500.00
0005433755049	26199	Economy	61500.00
0005432985859	26199	Economy	61500.00
0005433435367	26199	Economy	61500.00
0005433755102	26199	Economy	61500.00
0005435982753	26199	Economy	61500.00
0005433754992	26199	Economy	61500.00
0005435982948	26199	Economy	61500.00
0005432985867	26199	Economy	61500.00
0005432051205	26199	Economy	61500.00
0005435982800	26199	Economy	67700.00
0005433755129	26199	Economy	61500.00
0005432985871	26199	Economy	67700.00
0005433755070	26199	Economy	61500.00
0005433435381	26199	Economy	61500.00
0005432655702	26199	Economy	61500.00
0005435982988	26199	Economy	67700.00
0005433755335	26199	Economy	67700.00
0005433435371	26199	Economy	61500.00
0005433755322	26199	Economy	61500.00
0005432985876	26199	Economy	61500.00
0005432049552	26199	Economy	61500.00
0005433755077	26199	Economy	61500.00
0005432985864	26199	Economy	61500.00
0005432655658	26199	Economy	61500.00
0005433755146	26199	Economy	61500.00
0005433755087	26199	Economy	61500.00
0005435982949	26199	Economy	61500.00
0005432985881	26199	Economy	61500.00
0005432869682	26199	Economy	61500.00
0005433755085	26199	Economy	61500.00
0005435982838	26199	Economy	61500.00
0005432985879	26199	Economy	61500.00
0005433764706	26199	Economy	61500.00
0005432869687	26199	Economy	61500.00
0005434731274	26199	Economy	61500.00
0005433435359	26199	Economy	61500.00
0005432655657	26199	Economy	61500.00
0005433755340	26199	Economy	61500.00
0005435982980	26199	Economy	61500.00
0005433435360	26199	Economy	61500.00
0005432655677	26199	Economy	61500.00
0005432655632	26199	Economy	61500.00
0005432655681	26199	Economy	61500.00
0005433754993	26199	Economy	61500.00
0005433764704	26199	Economy	61500.00
0005433754834	26199	Economy	61500.00
0005435982927	26199	Economy	61500.00
0005433435361	26199	Economy	61500.00
0005433766709	26199	Economy	61500.00
0005435982958	26199	Economy	61500.00
0005433766707	26199	Economy	61500.00
0005435982966	26199	Economy	61500.00
0005435982905	26199	Economy	61500.00
0005435982965	26199	Economy	61500.00
0005433755343	26199	Economy	61500.00
0005432985863	26199	Economy	61500.00
0005432655711	26199	Economy	61500.00
0005434731276	26199	Economy	61500.00
0005435982972	26199	Economy	61500.00
0005435982899	26199	Economy	61500.00
0005435982668	26199	Economy	61500.00
0005433766694	26199	Economy	61500.00
0005433754997	26199	Economy	61500.00
0005433435375	26199	Economy	61500.00
0005433755079	26199	Economy	61500.00
0005432985865	26199	Economy	61500.00
0005432985885	26199	Economy	61500.00
0005433755076	26199	Economy	61500.00
0005435982923	26199	Economy	61500.00
0005432869684	26199	Economy	61500.00
0005435982930	26199	Economy	61500.00
0005433754991	26199	Economy	61500.00
0005435982977	26199	Economy	61500.00
0005433435374	26199	Economy	61500.00
0005433754780	26199	Economy	61500.00
0005432655663	26199	Economy	61500.00
0005433755071	26199	Economy	61500.00
0005433754781	26199	Economy	61500.00
0005432869686	26199	Economy	61500.00
0005433766708	26199	Economy	61500.00
0005433755017	26199	Economy	61500.00
0005433435379	26199	Economy	61500.00
0005432985887	26199	Economy	61500.00
0005433755131	26199	Economy	61500.00
0005432869683	26199	Economy	61500.00
0005435982981	26199	Economy	61500.00
0005434375768	1528	Business	38900.00
0005434375805	1528	Business	38900.00
0005433152079	1528	Business	38900.00
0005434375774	1528	Business	38900.00
0005432268062	1528	Business	38900.00
0005434375773	1528	Business	38900.00
0005434375762	1528	Business	38900.00
0005434376161	1528	Business	38900.00
0005434376229	1528	Economy	13000.00
0005434375752	1528	Economy	13000.00
0005434375796	1528	Economy	13000.00
0005434375764	1528	Economy	13000.00
0005433151843	1528	Economy	13000.00
0005433151955	1528	Economy	13000.00
0005434375767	1528	Economy	13000.00
0005434375753	1528	Economy	13000.00
0005434375751	1528	Economy	13000.00
0005434375769	1528	Economy	13000.00
0005434375801	1528	Economy	13000.00
0005434375787	1528	Economy	13000.00
0005434375808	1528	Economy	13000.00
0005434375766	1528	Economy	13000.00
0005434375795	1528	Economy	13000.00
0005433460489	1528	Economy	13000.00
0005433764712	1528	Economy	13000.00
0005434375756	1528	Economy	13000.00
0005434375809	1528	Economy	13000.00
0005432268057	1528	Economy	13000.00
0005434375754	1528	Economy	13000.00
0005434375771	1528	Economy	13000.00
0005433461643	1528	Economy	13000.00
0005434375758	1528	Economy	13000.00
0005433152052	1528	Economy	13000.00
0005433152142	1528	Economy	13000.00
0005434375749	1528	Economy	13000.00
0005433152056	1528	Economy	13000.00
0005434375797	1528	Economy	13000.00
0005434375784	1528	Economy	13000.00
0005434375785	1528	Economy	13000.00
0005432268063	1528	Economy	13000.00
0005434375770	1528	Economy	13000.00
0005434375778	1528	Economy	14300.00
0005434375781	1528	Economy	14300.00
0005434029682	1528	Economy	14300.00
0005433152026	1528	Economy	14300.00
0005433151987	1528	Economy	14300.00
0005434375798	1528	Economy	13000.00
0005434375759	1528	Economy	13000.00
0005433460490	1528	Economy	13000.00
0005434375776	1528	Economy	13000.00
0005434375786	1528	Economy	13000.00
0005433152083	1528	Economy	13000.00
0005434375799	1528	Economy	13000.00
0005434375775	1528	Economy	13000.00
0005433152015	1528	Economy	13000.00
0005433152103	1528	Economy	13000.00
0005432268061	1528	Economy	13000.00
0005434375802	1528	Economy	13000.00
0005434375788	1528	Economy	13000.00
0005433151956	1528	Economy	13000.00
0005434375806	1528	Economy	13000.00
0005434375807	1528	Economy	13000.00
0005434375792	1528	Economy	13000.00
0005434375748	1528	Economy	13000.00
0005433461642	1528	Economy	13000.00
0005434375761	1528	Economy	13000.00
0005433152034	1528	Economy	13000.00
0005434375750	1528	Economy	13000.00
0005434375793	1528	Economy	13000.00
0005433151979	1528	Economy	13000.00
0005434375790	1528	Economy	13000.00
0005434375779	1528	Economy	13000.00
0005432268059	1528	Economy	13000.00
0005433152080	1528	Economy	13000.00
0005434375782	1528	Economy	13000.00
0005434376160	1528	Economy	13000.00
0005434375765	1528	Economy	13000.00
0005433151982	1528	Economy	13000.00
0005433152100	1528	Economy	13000.00
0005434375763	1528	Economy	13000.00
0005433152035	1528	Economy	13000.00
0005434375755	1528	Economy	13000.00
0005432268060	1528	Economy	13000.00
0005433152156	1528	Economy	13000.00
0005434375777	1528	Economy	13000.00
0005434375794	1528	Economy	13000.00
0005433152051	1528	Economy	13000.00
0005434375791	1528	Economy	13000.00
0005434376230	1528	Economy	13000.00
0005434375760	1528	Economy	13000.00
0005434375772	1528	Economy	13000.00
0005433461641	1528	Economy	13000.00
0005433152055	1528	Economy	13000.00
0005434375757	1528	Economy	13000.00
0005433152038	1528	Economy	13000.00
0005434375803	1528	Economy	13000.00
0005434375789	1528	Economy	13000.00
0005434375800	1528	Economy	13000.00
0005434375783	1528	Economy	13000.00
0005433152014	1528	Economy	13000.00
0005432268058	1528	Economy	13000.00
0005433151981	1528	Economy	13000.00
0005434375780	1528	Economy	13000.00
0005433764713	1528	Economy	13000.00
0005434375804	1528	Economy	13000.00
0005434376228	1528	Economy	13000.00
0005433152247	20142	Business	38900.00
0005434375484	20142	Business	38900.00
0005434375373	20142	Business	38900.00
0005433152257	20142	Business	38900.00
0005434375372	20142	Business	38900.00
0005434375056	20142	Business	38900.00
0005433152245	20142	Business	38900.00
0005434375231	20142	Business	38900.00
0005434375350	20142	Business	38900.00
0005434375483	20142	Business	38900.00
0005434375352	20142	Business	38900.00
0005434375349	20142	Economy	13000.00
0005434375422	20142	Economy	13000.00
0005434375340	20142	Economy	13000.00
0005434375316	20142	Economy	13000.00
0005433152241	20142	Economy	13000.00
0005434375288	20142	Economy	13000.00
0005434375270	20142	Economy	13000.00
0005433152234	20142	Economy	13000.00
0005434375209	20142	Economy	13000.00
0005434375293	20142	Economy	13000.00
0005433152266	20142	Economy	13000.00
0005434375434	20142	Economy	13000.00
0005432056394	20142	Economy	13000.00
0005434375364	20142	Economy	13000.00
0005434375394	20142	Economy	13000.00
0005433152246	20142	Economy	13000.00
0005434029717	20142	Economy	13000.00
0005434375230	20142	Economy	13000.00
0005434029718	20142	Economy	13000.00
0005433152243	20142	Economy	13000.00
0005433152235	20142	Economy	13000.00
0005434375312	20142	Economy	13000.00
0005434375328	20142	Economy	13000.00
0005433152240	20142	Economy	13000.00
0005434375168	20142	Economy	13000.00
0005434375361	20142	Economy	13000.00
0005434375423	20142	Economy	13000.00
0005434375362	20142	Economy	13000.00
0005433152255	20142	Economy	13000.00
0005433152237	20142	Economy	13000.00
0005434029719	20142	Economy	13000.00
0005433152265	20142	Economy	13000.00
0005434375360	20142	Economy	14300.00
0005433152267	20142	Economy	14300.00
0005433152251	20142	Economy	14300.00
0005434375537	20142	Economy	14300.00
0005433931542	20142	Economy	14300.00
0005434375232	20142	Economy	13000.00
0005434375317	20142	Economy	13000.00
0005433931543	20142	Economy	13000.00
0005433152254	20142	Economy	13000.00
0005433931541	20142	Economy	13000.00
0005434375335	20142	Economy	13000.00
0005434375057	20142	Economy	13000.00
0005433152249	20142	Economy	13000.00
0005434375238	20142	Economy	13000.00
0005433152260	20142	Economy	13000.00
0005433152248	20142	Economy	13000.00
0005432056392	20142	Economy	13000.00
0005434375395	20142	Economy	13000.00
0005433152258	20142	Economy	13000.00
0005434375292	20142	Economy	13000.00
0005434375403	20142	Economy	13000.00
0005434375263	20142	Economy	13000.00
0005434375195	20142	Economy	13000.00
0005434375436	20142	Economy	13000.00
0005433764730	20142	Economy	13000.00
0005434375401	20142	Economy	13000.00
0005434375167	20142	Economy	13000.00
0005434375433	20142	Economy	13000.00
0005433152252	20142	Economy	13000.00
0005434375392	20142	Economy	13000.00
0005433152236	20142	Economy	13000.00
0005433152262	20142	Economy	13000.00
0005432056393	20142	Economy	13000.00
0005434375287	20142	Economy	13000.00
0005434375402	20142	Economy	13000.00
0005433152233	20142	Economy	13000.00
0005434375355	20142	Economy	13000.00
0005433152259	20142	Economy	13000.00
0005434375432	20142	Economy	13000.00
0005434375459	20142	Economy	13000.00
0005433152253	20142	Economy	13000.00
0005433152244	20142	Economy	13000.00
0005434375336	20142	Economy	13000.00
0005433931540	20142	Economy	13000.00
0005434375322	20142	Economy	13000.00
0005434375411	20142	Economy	13000.00
0005433152242	20142	Economy	13000.00
0005433152263	20142	Economy	13000.00
0005434375193	20142	Economy	13000.00
0005433152238	20142	Economy	13000.00
0005433152250	20142	Economy	13000.00
0005433152264	20142	Economy	13000.00
0005434375438	20142	Economy	13000.00
0005434375381	20142	Economy	13000.00
0005433152261	20142	Economy	13000.00
0005433152256	20142	Economy	13000.00
0005433152239	20142	Economy	13000.00
0005434375280	20142	Economy	13000.00
0005434375262	20142	Economy	13000.00
0005434375318	20142	Economy	13000.00
0005434375304	20142	Economy	13000.00
0005434375295	20142	Economy	13000.00
0005433764731	20142	Economy	13000.00
0005432283040	542	Business	27500.00
0005432425640	542	Business	27500.00
0005432425634	542	Business	27500.00
0005432425653	542	Business	27500.00
0005432425635	542	Business	27500.00
0005432425650	542	Business	27500.00
0005432283038	542	Business	27500.00
0005432425659	542	Business	27500.00
0005432283039	542	Economy	9200.00
0005432425644	542	Economy	9200.00
0005432425620	542	Economy	9200.00
0005432425648	542	Economy	9200.00
0005432425658	542	Economy	9200.00
0005432425623	542	Economy	9200.00
0005432425628	542	Economy	9200.00
0005432425643	542	Economy	9200.00
0005432425631	542	Economy	9200.00
0005432425642	542	Economy	9200.00
0005432425624	542	Economy	9200.00
0005432425649	542	Economy	9200.00
0005432425639	542	Economy	9200.00
0005432425636	542	Economy	9200.00
0005432425660	542	Economy	9200.00
0005432425621	542	Economy	10100.00
0005432283036	542	Economy	10100.00
0005432425641	542	Economy	10100.00
0005432425652	542	Economy	9200.00
0005432425645	542	Economy	9200.00
0005432425638	542	Economy	9200.00
0005432425651	542	Economy	9200.00
0005432425627	542	Economy	9200.00
0005432425646	542	Economy	9200.00
0005432425625	542	Economy	9200.00
0005432425633	542	Economy	9200.00
0005432425630	542	Economy	9200.00
0005432425655	542	Economy	9200.00
0005432425622	542	Economy	9200.00
0005432283041	542	Economy	9200.00
0005432425626	542	Economy	9200.00
0005432425629	542	Economy	9200.00
0005432425656	542	Economy	9200.00
0005432425637	542	Economy	9200.00
0005432425657	542	Economy	9200.00
0005432425632	542	Economy	9200.00
0005432425654	542	Economy	9200.00
0005432425647	542	Economy	9200.00
0005432283037	542	Economy	9200.00
0005433261918	12864	Business	27500.00
0005433766760	12864	Economy	10100.00
0005432302423	12864	Economy	9200.00
0005432302424	12864	Economy	9200.00
0005433261923	12864	Economy	9200.00
0005433261910	12864	Economy	9200.00
0005433261913	12864	Economy	9200.00
0005433261920	12864	Economy	9200.00
0005433766757	12864	Economy	9200.00
0005433261914	12864	Economy	9200.00
0005433261908	12864	Economy	9200.00
0005433261916	12864	Economy	9200.00
0005433261919	12864	Economy	9200.00
0005432302425	12864	Economy	9200.00
0005433261912	12864	Economy	9200.00
0005432302422	12864	Economy	9200.00
0005433261922	12864	Economy	9200.00
0005433261907	12864	Economy	9200.00
0005433261921	12864	Economy	9200.00
0005433261915	12864	Economy	9200.00
0005433261911	12864	Economy	9200.00
0005433261909	12864	Economy	9200.00
0005433261917	12864	Economy	9200.00
0005433766759	12864	Economy	9200.00
0005433766758	12864	Economy	9200.00
0005432425189	12906	Business	27500.00
0005432425194	12906	Business	27500.00
0005432424915	12906	Business	27500.00
0005432425070	12906	Business	27500.00
0005432425198	12906	Business	27500.00
0005432425190	12906	Business	27500.00
0005432425221	12906	Business	27500.00
0005432425121	12906	Economy	10100.00
0005432425035	12906	Economy	9200.00
0005432425107	12906	Economy	9200.00
0005432425195	12906	Economy	9200.00
0005432425152	12906	Economy	9200.00
0005432425224	12906	Economy	9200.00
0005432424916	12906	Economy	9200.00
0005432425082	12906	Economy	9200.00
0005432425083	12906	Economy	9200.00
0005432425122	12906	Economy	9200.00
0005432425199	12906	Economy	9200.00
0005432425220	12906	Economy	9200.00
0005432425108	12906	Economy	9200.00
0005432425073	12906	Economy	9200.00
0005432425109	12906	Economy	9200.00
0005432425128	12906	Economy	9200.00
0005432425139	12906	Economy	9200.00
0005432424985	12906	Economy	9200.00
0005432425045	12906	Economy	9200.00
0005432425126	12906	Economy	9200.00
0005432425127	12906	Economy	9200.00
0005432425034	12906	Economy	10100.00
0005432425110	12906	Economy	9200.00
0005432425153	12906	Economy	9200.00
0005432425225	12906	Economy	9200.00
0005432425226	12906	Economy	9200.00
0005432425119	12906	Economy	9200.00
0005432424982	12906	Economy	9200.00
0005432425072	12906	Economy	9200.00
0005432424986	12906	Economy	9200.00
0005432425129	12906	Economy	9200.00
0005432425217	12906	Economy	9200.00
0005432425049	12906	Economy	9200.00
0005432424977	12906	Economy	9200.00
0005432425130	12906	Economy	9200.00
0005432425113	12906	Economy	9200.00
0005432425230	12906	Economy	9200.00
0005432425171	12906	Economy	9200.00
0005432425026	12906	Economy	9200.00
0005432425143	12906	Economy	9200.00
0005433684458	488	Business	24500.00
0005433058515	488	Business	24500.00
0005434025357	488	Business	24500.00
0005434025359	488	Business	24500.00
0005434025365	488	Business	24500.00
0005434025353	488	Business	24500.00
0005434032133	488	Business	24500.00
0005434025376	488	Business	24500.00
0005434025361	488	Business	24500.00
0005434025393	488	Business	24500.00
0005434025354	488	Business	24500.00
0005434735751	488	Business	24500.00
0005432045659	488	Business	24500.00
0005434025396	488	Business	24500.00
0005433929662	488	Business	24500.00
0005434025351	488	Business	24500.00
0005433929688	488	Economy	9000.00
0005433058527	488	Economy	9000.00
0005434025399	488	Economy	9000.00
0005434025346	488	Economy	9000.00
0005434025355	488	Economy	8200.00
0005434025356	488	Economy	8200.00
0005434025397	488	Economy	8200.00
0005434025375	488	Economy	8200.00
0005434025388	488	Economy	8200.00
0005434025349	488	Economy	8200.00
0005434025390	488	Economy	8200.00
0005433058570	488	Economy	8200.00
0005434025379	488	Economy	8200.00
0005434025373	488	Economy	8200.00
0005434025400	488	Economy	8200.00
0005433058438	488	Economy	8200.00
0005433058562	488	Economy	8200.00
0005434025344	488	Economy	8200.00
0005434025387	488	Economy	8200.00
0005433058617	488	Economy	8200.00
0005433058569	488	Economy	8200.00
0005434025405	488	Economy	8200.00
0005434032132	488	Economy	8200.00
0005434025362	488	Economy	8200.00
0005434025360	488	Economy	8200.00
0005432045660	488	Economy	8200.00
0005432235823	488	Economy	8200.00
0005432235820	488	Economy	8200.00
0005434025384	488	Economy	8200.00
0005432235824	488	Economy	8200.00
0005434025366	488	Economy	8200.00
0005433058717	488	Economy	8200.00
0005433058584	488	Economy	8200.00
0005433058613	488	Economy	8200.00
0005432235822	488	Economy	8200.00
0005434025352	488	Economy	8200.00
0005434025383	488	Economy	8200.00
0005432235827	488	Economy	8200.00
0005433058585	488	Economy	8200.00
0005434735764	488	Economy	8200.00
0005434025407	488	Economy	8200.00
0005434025385	488	Economy	8200.00
0005433058445	488	Economy	8200.00
0005434029715	488	Economy	8200.00
0005434025403	488	Economy	8200.00
0005433058363	488	Economy	8200.00
0005434735782	488	Economy	8200.00
0005434025392	488	Economy	8200.00
0005433058525	488	Economy	8200.00
0005433058503	488	Economy	8200.00
0005434025402	488	Economy	8200.00
0005434025378	488	Economy	8200.00
0005434025348	488	Economy	8200.00
0005434025372	488	Economy	8200.00
0005433058514	488	Economy	8200.00
0005433058437	488	Economy	8200.00
0005433058679	488	Economy	8200.00
0005433058571	488	Economy	8200.00
0005434735763	488	Economy	9000.00
0005434025347	488	Economy	8200.00
0005434025358	488	Economy	8200.00
0005434025363	488	Economy	8200.00
0005433058524	488	Economy	9000.00
0005434025391	488	Economy	9000.00
0005432045661	488	Economy	8200.00
0005433058534	488	Economy	8200.00
0005434025364	488	Economy	8200.00
0005434025404	488	Economy	8200.00
0005433058611	488	Economy	8200.00
0005433058582	488	Economy	8200.00
0005432235821	488	Economy	8200.00
0005434025395	488	Economy	8200.00
0005433058583	488	Economy	8200.00
0005433058493	488	Economy	8200.00
0005433058502	488	Economy	8200.00
0005433058618	488	Economy	8200.00
0005434025398	488	Economy	8200.00
0005434025381	488	Economy	8200.00
0005433058589	488	Economy	8200.00
0005434025368	488	Economy	8200.00
0005434032136	488	Economy	8200.00
0005434025370	488	Economy	8200.00
0005432235825	488	Economy	8200.00
0005434025350	488	Economy	8200.00
0005433058615	488	Economy	8200.00
0005434025377	488	Economy	8200.00
0005434025386	488	Economy	8200.00
0005434025401	488	Economy	8200.00
0005433058548	488	Economy	8200.00
0005434025394	488	Economy	8200.00
0005434025374	488	Economy	8200.00
0005433058637	488	Economy	8200.00
0005434025371	488	Economy	8200.00
0005433929674	488	Economy	8200.00
0005434032134	488	Economy	8200.00
0005434025406	488	Economy	8200.00
0005434032135	488	Economy	8200.00
0005432235826	488	Economy	8200.00
0005434025382	488	Economy	8200.00
0005434025380	488	Economy	8200.00
0005434025389	488	Economy	8200.00
0005434025367	488	Economy	8200.00
0005434025345	488	Economy	8200.00
0005434025369	488	Economy	8200.00
0005434029716	488	Economy	8200.00
0005433058364	488	Economy	8200.00
0005434024867	12687	Business	24500.00
0005433058876	12687	Business	24500.00
0005434032112	12687	Business	24500.00
0005434024841	12687	Business	24500.00
0005432156477	12687	Business	24500.00
0005434024395	12687	Business	24500.00
0005433058861	12687	Business	24500.00
0005434024673	12687	Business	24500.00
0005434024654	12687	Business	24500.00
0005434376228	12687	Business	24500.00
0005434024873	12687	Business	24500.00
0005433929714	12687	Business	24500.00
0005434024738	12687	Business	24500.00
0005434024675	12687	Business	24500.00
0005433058879	12687	Business	24500.00
0005434024677	12687	Business	24500.00
0005434024480	12687	Business	24500.00
0005434024544	12687	Business	24500.00
0005433058890	12687	Economy	9000.00
0005434024985	12687	Business	24500.00
0005434735817	12687	Economy	8200.00
0005433058882	12687	Economy	8200.00
0005434025196	12687	Economy	8200.00
0005434024725	12687	Economy	8200.00
0005434024709	12687	Economy	8200.00
0005434029682	12687	Economy	8200.00
0005434024898	12687	Economy	8200.00
0005434024894	12687	Economy	8200.00
0005434024606	12687	Economy	8200.00
0005433058874	12687	Economy	8200.00
0005433058858	12687	Economy	8200.00
0005434024886	12687	Economy	8200.00
0005434024993	12687	Economy	8200.00
0005434024393	12687	Economy	8200.00
0005433058889	12687	Economy	8200.00
0005433058860	12687	Economy	8200.00
0005434024465	12687	Economy	8200.00
0005433058891	12687	Economy	8200.00
0005434025015	12687	Economy	8200.00
0005433058886	12687	Economy	8200.00
0005433058878	12687	Economy	8200.00
0005434025115	12687	Economy	8200.00
0005434024724	12687	Economy	8200.00
0005433684471	12687	Economy	8200.00
0005433058867	12687	Economy	8200.00
0005434024994	12687	Economy	8200.00
0005433058872	12687	Economy	8200.00
0005433058877	12687	Economy	8200.00
0005434024860	12687	Economy	8200.00
0005434024766	12687	Economy	8200.00
0005434024737	12687	Economy	8200.00
0005433058865	12687	Economy	8200.00
0005434024589	12687	Economy	8200.00
0005434024561	12687	Economy	8200.00
0005434024803	12687	Economy	8200.00
0005434024587	12687	Economy	8200.00
0005434025028	12687	Economy	8200.00
0005434024931	12687	Economy	8200.00
0005434735820	12687	Economy	8200.00
0005434024874	12687	Economy	8200.00
0005434024416	12687	Economy	8200.00
0005434024882	12687	Economy	8200.00
0005433058866	12687	Economy	8200.00
0005434024896	12687	Economy	8200.00
0005434025020	12687	Economy	8200.00
0005434024636	12687	Economy	8200.00
0005434024865	12687	Economy	8200.00
0005434376230	12687	Economy	8200.00
0005433058875	12687	Economy	8200.00
0005434024969	12687	Economy	8200.00
0005434024545	12687	Economy	8200.00
0005434024603	12687	Economy	8200.00
0005432156475	12687	Economy	8200.00
0005434024394	12687	Economy	8200.00
0005434024555	12687	Economy	8200.00
0005433058885	12687	Economy	8200.00
0005434024733	12687	Economy	8200.00
0005433058869	12687	Economy	8200.00
0005434024572	12687	Economy	8200.00
0005434024907	12687	Economy	8200.00
0005434025059	12687	Economy	8200.00
0005434032090	12687	Economy	8200.00
0005434028352	12687	Economy	8200.00
0005434028346	12687	Economy	8200.00
0005434024905	12687	Economy	8200.00
0005434028347	12687	Economy	8200.00
0005433929713	12687	Economy	8200.00
0005434024586	12687	Economy	9000.00
0005434735819	12687	Economy	8200.00
0005434024868	12687	Economy	8200.00
0005433929715	12687	Economy	9000.00
0005434024995	12687	Economy	8200.00
0005433058881	12687	Economy	8200.00
0005433058892	12687	Economy	9000.00
0005432156476	12687	Economy	8200.00
0005433058883	12687	Economy	8200.00
0005433058880	12687	Economy	8200.00
0005433929716	12687	Economy	8200.00
0005434024723	12687	Economy	8200.00
0005433058870	12687	Economy	8200.00
0005434735818	12687	Economy	8200.00
0005434024937	12687	Economy	8200.00
0005434024595	12687	Economy	8200.00
0005434024635	12687	Economy	8200.00
0005433058856	12687	Economy	8200.00
0005434024670	12687	Economy	8200.00
0005434376229	12687	Economy	8200.00
0005432156474	12687	Economy	8200.00
0005433058868	12687	Economy	8200.00
0005433058884	12687	Economy	8200.00
0005434025019	12687	Economy	8200.00
0005432157539	12687	Economy	8200.00
0005434024787	12687	Economy	8200.00
0005433058862	12687	Economy	8200.00
0005433058863	12687	Economy	8200.00
0005433929717	12687	Economy	8200.00
0005434025014	12687	Economy	8200.00
0005434024748	12687	Economy	8200.00
0005434024735	12687	Economy	8200.00
0005433058864	12687	Economy	8200.00
0005433058859	12687	Economy	8200.00
0005434735821	12687	Economy	8200.00
0005433058888	12687	Economy	8200.00
0005434024932	12687	Economy	8200.00
0005434024915	12687	Economy	8200.00
0005434024605	12687	Economy	8200.00
0005434024804	12687	Economy	8200.00
0005434024913	12687	Economy	8200.00
0005433058857	12687	Economy	8200.00
0005434032113	12687	Economy	8200.00
0005433058855	12687	Economy	8200.00
0005434024662	12687	Economy	8200.00
0005434024765	12687	Economy	8200.00
0005434028351	12687	Economy	8200.00
0005434024881	12687	Economy	8200.00
0005433058887	12687	Economy	8200.00
0005433058873	12687	Economy	8200.00
0005433058871	12687	Economy	8200.00
0005433037328	2159	Business	34700.00
0005433037118	2159	Business	34700.00
0005433037143	2159	Business	34700.00
0005433925644	2159	Business	34700.00
0005433925706	2159	Business	34700.00
0005433037252	2159	Business	34700.00
0005433037269	2159	Business	34700.00
0005433037135	2159	Business	34700.00
0005433875420	2159	Business	34700.00
0005433925670	2159	Business	34700.00
0005432044593	2159	Business	34700.00
0005433925646	2159	Business	34700.00
0005433925636	2159	Business	34700.00
0005433925658	2159	Business	34700.00
0005433925695	2159	Business	34700.00
0005433925673	2159	Business	34700.00
0005433925707	2159	Economy	12700.00
0005434028346	2159	Economy	12700.00
0005433925686	2159	Economy	12700.00
0005433929717	2159	Economy	12700.00
0005433925635	2159	Economy	11600.00
0005433925618	2159	Economy	11600.00
0005433037222	2159	Economy	11600.00
0005433037008	2159	Economy	11600.00
0005433925624	2159	Economy	11600.00
0005433925652	2159	Economy	11600.00
0005432231822	2159	Economy	11600.00
0005433925676	2159	Economy	11600.00
0005433925684	2159	Economy	11600.00
0005433037235	2159	Economy	11600.00
0005433929715	2159	Economy	11600.00
0005433036960	2159	Economy	11600.00
0005433037316	2159	Economy	11600.00
0005433925704	2159	Economy	11600.00
0005433925622	2159	Economy	11600.00
0005433037381	2159	Economy	11600.00
0005433925616	2159	Economy	11600.00
0005433925699	2159	Economy	11600.00
0005433925668	2159	Economy	11600.00
0005433925687	2159	Economy	11600.00
0005433925645	2159	Economy	11600.00
0005433037089	2159	Economy	11600.00
0005433037086	2159	Economy	11600.00
0005433037028	2159	Economy	11600.00
0005433925654	2159	Economy	11600.00
0005433037030	2159	Economy	11600.00
0005433925614	2159	Economy	11600.00
0005433925663	2159	Economy	11600.00
0005433925701	2159	Economy	11600.00
0005432231823	2159	Economy	11600.00
0005433037224	2159	Economy	11600.00
0005433037120	2159	Economy	11600.00
0005433925683	2159	Economy	11600.00
0005433929716	2159	Economy	11600.00
0005433925666	2159	Economy	11600.00
0005433925619	2159	Economy	11600.00
0005433925703	2159	Economy	11600.00
0005433925708	2159	Economy	11600.00
0005433037402	2159	Economy	11600.00
0005433925697	2159	Economy	11600.00
0005433925639	2159	Economy	11600.00
0005433925664	2159	Economy	11600.00
0005433925649	2159	Economy	11600.00
0005433925660	2159	Economy	11600.00
0005433925675	2159	Economy	11600.00
0005433037329	2159	Economy	11600.00
0005434028347	2159	Economy	11600.00
0005432231829	2159	Economy	11600.00
0005433037209	2159	Economy	11600.00
0005433925674	2159	Economy	11600.00
0005433929870	2159	Economy	11600.00
0005433925627	2159	Economy	11600.00
0005433925678	2159	Economy	11600.00
0005433925655	2159	Economy	11600.00
0005433925667	2159	Economy	11600.00
0005433925698	2159	Economy	11600.00
0005433875419	2159	Economy	11600.00
0005433037079	2159	Economy	11600.00
0005433037317	2159	Economy	11600.00
0005433925630	2159	Economy	11600.00
0005433925625	2159	Economy	11600.00
0005432231827	2159	Economy	11600.00
0005433037238	2159	Economy	11600.00
0005433037178	2159	Economy	11600.00
0005433925617	2159	Economy	11600.00
0005433925638	2159	Economy	11600.00
0005433037119	2159	Economy	11600.00
0005433925661	2159	Economy	11600.00
0005433925685	2159	Economy	11600.00
0005433925696	2159	Economy	11600.00
0005433925620	2159	Economy	11600.00
0005433037165	2159	Economy	11600.00
0005433925665	2159	Economy	11600.00
0005432231821	2159	Economy	11600.00
0005433931540	2159	Economy	11600.00
0005433929713	2159	Economy	11600.00
0005433925629	2159	Economy	11600.00
0005434028352	2159	Economy	11600.00
0005433037179	2159	Economy	11600.00
0005433925694	2159	Economy	11600.00
0005433925656	2159	Economy	11600.00
0005433925632	2159	Economy	11600.00
0005433925700	2159	Economy	12700.00
0005433037164	2159	Economy	11600.00
0005433925705	2159	Economy	12700.00
0005433037255	2159	Economy	11600.00
0005433037359	2159	Economy	11600.00
0005433925640	2159	Economy	11600.00
0005433925631	2159	Economy	12700.00
0005433037392	2159	Economy	11600.00
0005432231830	2159	Economy	11600.00
0005433925693	2159	Economy	11600.00
0005433925615	2159	Economy	11600.00
0005433925633	2159	Economy	11600.00
0005433037404	2159	Economy	11600.00
0005433925679	2159	Economy	11600.00
0005433037379	2159	Economy	11600.00
0005433925628	2159	Economy	11600.00
0005433037031	2159	Economy	11600.00
0005433037073	2159	Economy	11600.00
0005432231825	2159	Economy	11600.00
0005433037072	2159	Economy	11600.00
0005433037175	2159	Economy	11600.00
0005433925659	2159	Economy	11600.00
0005433037095	2159	Economy	11600.00
0005433925680	2159	Economy	11600.00
0005433925641	2159	Economy	11600.00
0005433037223	2159	Economy	11600.00
0005433925672	2159	Economy	11600.00
0005433931543	2159	Economy	11600.00
0005433037139	2159	Economy	11600.00
0005433925623	2159	Economy	11600.00
0005433925702	2159	Economy	11600.00
0005433037136	2159	Economy	11600.00
0005433925613	2159	Economy	11600.00
0005433037256	2159	Economy	11600.00
0005434028351	2159	Economy	11600.00
0005432749820	2159	Economy	11600.00
0005432231824	2159	Economy	11600.00
0005432231826	2159	Economy	11600.00
0005433925677	2159	Economy	11600.00
0005433929871	2159	Economy	11600.00
0005433925651	2159	Economy	11600.00
0005432231831	2159	Economy	11600.00
0005433925647	2159	Economy	11600.00
0005433931542	2159	Economy	11600.00
0005433037090	2159	Economy	11600.00
0005433925669	2159	Economy	11600.00
0005433036959	2159	Economy	11600.00
0005433037029	2159	Economy	11600.00
0005433925689	2159	Economy	11600.00
0005433037237	2159	Economy	11600.00
0005433925650	2159	Economy	11600.00
0005433925671	2159	Economy	11600.00
0005433037267	2159	Economy	11600.00
0005433037144	2159	Economy	11600.00
0005433925690	2159	Economy	11600.00
0005433925691	2159	Economy	11600.00
0005433929714	2159	Economy	11600.00
0005433929869	2159	Economy	11600.00
0005433925626	2159	Economy	11600.00
0005433925692	2159	Economy	11600.00
0005433925682	2159	Economy	11600.00
0005433925662	2159	Economy	11600.00
0005433925643	2159	Economy	11600.00
0005433925648	2159	Economy	11600.00
0005433925637	2159	Economy	11600.00
0005432044592	2159	Economy	11600.00
0005433925657	2159	Economy	11600.00
0005433925642	2159	Economy	11600.00
0005433037191	2159	Economy	11600.00
0005433036986	2159	Economy	11600.00
0005433925681	2159	Economy	11600.00
0005432231828	2159	Economy	11600.00
0005433925621	2159	Economy	11600.00
0005433037007	2159	Economy	11600.00
0005433037162	2159	Economy	11600.00
0005433925634	2159	Economy	11600.00
0005433037233	2159	Economy	11600.00
0005433925653	2159	Economy	11600.00
0005433925688	2159	Economy	11600.00
0005433036947	2159	Economy	11600.00
0005433931541	2159	Economy	11600.00
0005433037604	24090	Business	34700.00
0005433925043	24090	Business	34700.00
0005433925009	24090	Business	34700.00
0005433925301	24090	Business	34700.00
0005432206341	24090	Business	34700.00
0005433037572	24090	Business	34700.00
0005433925037	24090	Business	34700.00
0005433924944	24090	Business	34700.00
0005433925189	24090	Business	34700.00
0005433925015	24090	Business	34700.00
0005433925040	24090	Business	34700.00
0005433924926	24090	Business	34700.00
0005433931523	24090	Business	34700.00
0005433925280	24090	Business	34700.00
0005433925049	24090	Business	34700.00
0005433924769	24090	Business	34700.00
0005433924957	24090	Business	34700.00
0005433924871	24090	Business	34700.00
0005433924701	24090	Business	34700.00
0005433037617	24090	Business	34700.00
0005433037574	24090	Business	34700.00
0005433037571	24090	Business	34700.00
0005433924677	24090	Business	34700.00
0005433924756	24090	Business	34700.00
0005433925354	24090	Economy	12700.00
0005433925038	24090	Economy	12700.00
0005433924665	24090	Economy	12700.00
0005433924956	24090	Economy	12700.00
0005433924882	24090	Economy	11600.00
0005434028379	24090	Economy	11600.00
0005433924932	24090	Economy	11600.00
0005433924502	24090	Economy	11600.00
0005433925191	24090	Economy	11600.00
0005433037596	24090	Economy	11600.00
0005433924925	24090	Economy	11600.00
0005433924719	24090	Economy	11600.00
0005433924941	24090	Economy	11600.00
0005433037615	24090	Economy	11600.00
0005433037609	24090	Economy	11600.00
0005433037599	24090	Economy	11600.00
0005433924824	24090	Economy	11600.00
0005433925137	24090	Economy	11600.00
0005433037616	24090	Economy	11600.00
0005433037569	24090	Economy	11600.00
0005433924975	24090	Economy	11600.00
0005433924997	24090	Economy	11600.00
0005433037619	24090	Economy	11600.00
0005433924965	24090	Economy	11600.00
0005433924814	24090	Economy	11600.00
0005433925281	24090	Economy	11600.00
0005433925039	24090	Economy	11600.00
0005432206337	24090	Economy	11600.00
0005433037613	24090	Economy	11600.00
0005433037570	24090	Economy	11600.00
0005433925215	24090	Economy	11600.00
0005433924870	24090	Economy	11600.00
0005433924745	24090	Economy	11600.00
0005433925218	24090	Economy	11600.00
0005433925016	24090	Economy	11600.00
0005433037586	24090	Economy	11600.00
0005433037608	24090	Economy	11600.00
0005433037595	24090	Economy	11600.00
0005433037597	24090	Economy	11600.00
0005433037593	24090	Economy	11600.00
0005433924118	24090	Economy	11600.00
0005433875410	24090	Economy	11600.00
0005433037581	24090	Economy	11600.00
0005432206340	24090	Economy	11600.00
0005433925026	24090	Economy	11600.00
0005432749839	24090	Economy	11600.00
0005433925192	24090	Economy	11600.00
0005432749838	24090	Economy	11600.00
0005433924964	24090	Economy	11600.00
0005433037582	24090	Economy	11600.00
0005433924549	24090	Economy	11600.00
0005433924648	24090	Economy	11600.00
0005434028378	24090	Economy	11600.00
0005433925188	24090	Economy	11600.00
0005433925092	24090	Economy	11600.00
0005433924687	24090	Economy	11600.00
0005433037580	24090	Economy	11600.00
0005433924746	24090	Economy	11600.00
0005433924812	24090	Economy	11600.00
0005433924757	24090	Economy	11600.00
0005433924976	24090	Economy	11600.00
0005433924637	24090	Economy	11600.00
0005433924727	24090	Economy	11600.00
0005433924895	24090	Economy	11600.00
0005433924744	24090	Economy	11600.00
0005433924532	24090	Economy	11600.00
0005433925044	24090	Economy	11600.00
0005433037573	24090	Economy	11600.00
0005433925282	24090	Economy	11600.00
0005433924902	24090	Economy	11600.00
0005433924863	24090	Economy	11600.00
0005433037579	24090	Economy	11600.00
0005433924691	24090	Economy	11600.00
0005433924989	24090	Economy	11600.00
0005433037575	24090	Economy	11600.00
0005433037594	24090	Economy	11600.00
0005433924711	24090	Economy	11600.00
0005433925265	24090	Economy	11600.00
0005433925415	24090	Economy	11600.00
0005433924979	24090	Economy	11600.00
0005433924635	24090	Economy	11600.00
0005433924498	24090	Economy	11600.00
0005433037585	24090	Economy	11600.00
0005433924781	24090	Economy	11600.00
0005433924934	24090	Economy	11600.00
0005433037598	24090	Economy	11600.00
0005433875394	24090	Economy	11600.00
0005433037602	24090	Economy	11600.00
0005433037578	24090	Economy	11600.00
0005433037588	24090	Economy	12700.00
0005432206338	24090	Economy	12700.00
0005433924777	24090	Economy	11600.00
0005433925045	24090	Economy	11600.00
0005433037590	24090	Economy	11600.00
0005433925091	24090	Economy	12700.00
0005433037611	24090	Economy	11600.00
0005433037612	24090	Economy	12700.00
0005433924755	24090	Economy	11600.00
0005433925302	24090	Economy	11600.00
0005433924686	24090	Economy	11600.00
0005433924862	24090	Economy	11600.00
0005433925355	24090	Economy	11600.00
0005433925031	24090	Economy	11600.00
0005433924754	24090	Economy	11600.00
0005432207726	24090	Economy	11600.00
0005434028377	24090	Economy	11600.00
0005433924764	24090	Economy	11600.00
0005433924856	24090	Economy	11600.00
0005433925025	24090	Economy	11600.00
0005433037587	24090	Economy	11600.00
0005432206336	24090	Economy	11600.00
0005433924808	24090	Economy	11600.00
0005433924663	24090	Economy	11600.00
0005433925006	24090	Economy	11600.00
0005433037601	24090	Economy	11600.00
0005433925046	24090	Economy	11600.00
0005433037583	24090	Economy	11600.00
0005433037592	24090	Economy	11600.00
0005433037610	24090	Economy	11600.00
0005433925138	24090	Economy	11600.00
0005433924768	24090	Economy	11600.00
0005433924531	24090	Economy	11600.00
0005433931521	24090	Economy	11600.00
0005433924770	24090	Economy	11600.00
0005433924636	24090	Economy	11600.00
0005433037607	24090	Economy	11600.00
0005433037576	24090	Economy	11600.00
0005433037603	24090	Economy	11600.00
0005433925085	24090	Economy	11600.00
0005433924991	24090	Economy	11600.00
0005432207725	24090	Economy	11600.00
0005432206339	24090	Economy	11600.00
0005433924592	24090	Economy	11600.00
0005433925074	24090	Economy	11600.00
0005433925312	24090	Economy	11600.00
0005433924793	24090	Economy	11600.00
0005433037618	24090	Economy	11600.00
0005433924869	24090	Economy	11600.00
0005433924886	24090	Economy	11600.00
0005433924664	24090	Economy	11600.00
0005433037577	24090	Economy	11600.00
0005433931514	24090	Economy	11600.00
0005433924857	24090	Economy	11600.00
0005433924813	24090	Economy	11600.00
0005433037600	24090	Economy	11600.00
0005433924501	24090	Economy	11600.00
0005433037568	24090	Economy	11600.00
0005433924907	24090	Economy	11600.00
0005433037591	24090	Economy	11600.00
0005433924990	24090	Economy	11600.00
0005433037614	24090	Economy	11600.00
0005433037589	24090	Economy	11600.00
0005433924713	24090	Economy	11600.00
0005433924761	24090	Economy	11600.00
0005434028380	24090	Economy	11600.00
0005433037606	24090	Economy	11600.00
0005433037584	24090	Economy	11600.00
0005433875409	24090	Economy	11600.00
0005433924825	24090	Economy	11600.00
0005433925014	24090	Economy	11600.00
0005433924894	24090	Economy	11600.00
0005433037605	24090	Economy	11600.00
0005434728438	300	Business	83700.00
0005434728445	300	Business	83700.00
0005434728391	300	Business	83700.00
0005434728456	300	Business	83700.00
0005435142905	300	Business	83700.00
0005434728462	300	Business	83700.00
0005433235352	300	Business	83700.00
0005434728491	300	Business	83700.00
0005433235136	300	Business	83700.00
0005435142914	300	Business	83700.00
0005434728423	300	Business	83700.00
0005434728395	300	Business	83700.00
0005434728436	300	Business	83700.00
0005433235276	300	Business	83700.00
0005433235143	300	Business	83700.00
0005433234876	300	Business	83700.00
0005433235211	300	Business	83700.00
0005434552573	300	Business	83700.00
0005434728468	300	Business	83700.00
0005434552575	300	Business	83700.00
0005434728489	300	Business	83700.00
0005433126924	300	Business	83700.00
0005434552598	300	Business	83700.00
0005434552558	300	Comfort	47400.00
0005434728452	300	Comfort	47400.00
0005432278143	300	Comfort	47400.00
0005433235364	300	Comfort	47400.00
0005433235267	300	Comfort	47400.00
0005433235253	300	Comfort	47400.00
0005434728483	300	Comfort	47400.00
0005434728466	300	Comfort	47400.00
0005434032084	300	Comfort	47400.00
0005434302895	300	Comfort	47400.00
0005434032098	300	Comfort	47400.00
0005434728444	300	Comfort	47400.00
0005434728443	300	Comfort	47400.00
0005434728407	300	Comfort	47400.00
0005433235325	300	Comfort	47400.00
0005434552588	300	Comfort	47400.00
0005434552581	300	Comfort	47400.00
0005433235027	300	Comfort	47400.00
0005433181541	300	Comfort	47400.00
0005434728434	300	Comfort	47400.00
0005434552557	300	Comfort	47400.00
0005434552576	300	Comfort	47400.00
0005433181454	300	Comfort	47400.00
0005433235103	300	Comfort	47400.00
0005433289973	300	Comfort	47400.00
0005434728433	300	Comfort	47400.00
0005434728460	300	Comfort	47400.00
0005433289972	300	Comfort	47400.00
0005433235079	300	Comfort	47400.00
0005433235140	300	Comfort	47400.00
0005432278137	300	Comfort	47400.00
0005434728467	300	Comfort	47400.00
0005433235080	300	Comfort	47400.00
0005434728417	300	Comfort	47400.00
0005433235180	300	Comfort	47400.00
0005434728393	300	Comfort	47400.00
0005434552566	300	Economy	27900.00
0005432278134	300	Economy	27900.00
0005433235266	300	Economy	27900.00
0005433235451	300	Economy	27900.00
0005433181543	300	Economy	27900.00
0005433235232	300	Economy	27900.00
0005434728394	300	Economy	27900.00
0005434552555	300	Economy	27900.00
0005433234877	300	Economy	27900.00
0005434552559	300	Economy	27900.00
0005433235218	300	Economy	27900.00
0005434552590	300	Economy	27900.00
0005432278135	300	Economy	27900.00
0005435142907	300	Economy	27900.00
0005434552603	300	Economy	27900.00
0005434728461	300	Economy	27900.00
0005434552591	300	Economy	27900.00
0005433181440	300	Economy	27900.00
0005434728480	300	Economy	27900.00
0005435142911	300	Economy	27900.00
0005433131778	300	Economy	27900.00
0005433235229	300	Economy	27900.00
0005434552567	300	Economy	27900.00
0005434552584	300	Economy	27900.00
0005433289980	300	Economy	27900.00
0005433113564	300	Economy	27900.00
0005434728482	300	Economy	27900.00
0005433235309	300	Economy	27900.00
0005432278145	300	Economy	27900.00
0005434552583	300	Economy	27900.00
0005433181428	300	Economy	27900.00
0005434728426	300	Economy	27900.00
0005434728408	300	Economy	27900.00
0005434552596	300	Economy	27900.00
0005433235252	300	Economy	27900.00
0005434728422	300	Economy	27900.00
0005434728451	300	Economy	27900.00
0005434728488	300	Economy	27900.00
0005434728447	300	Economy	27900.00
0005434552574	300	Economy	27900.00
0005433235365	300	Economy	27900.00
0005433235086	300	Economy	27900.00
0005433181495	300	Economy	27900.00
0005434728464	300	Economy	27900.00
0005433235395	300	Economy	27900.00
0005434552560	300	Economy	27900.00
0005434728402	300	Economy	27900.00
0005434728476	300	Economy	27900.00
0005434728493	300	Economy	27900.00
0005434728503	300	Economy	30700.00
0005433181369	300	Economy	30700.00
0005432278139	300	Economy	27900.00
0005434552568	300	Economy	27900.00
0005434728484	300	Economy	27900.00
0005434728421	300	Economy	27900.00
0005434728419	300	Economy	30700.00
0005434552600	300	Economy	30700.00
0005433235137	300	Economy	30700.00
0005434552569	300	Economy	27900.00
0005434728406	300	Economy	27900.00
0005434728474	300	Economy	27900.00
0005434552562	300	Economy	27900.00
0005433181564	300	Economy	27900.00
0005434728411	300	Economy	27900.00
0005434728448	300	Economy	27900.00
0005433181435	300	Economy	27900.00
0005433235230	300	Economy	27900.00
0005434728424	300	Economy	27900.00
0005434728485	300	Economy	27900.00
0005434728458	300	Economy	27900.00
0005434552556	300	Economy	27900.00
0005435142908	300	Economy	27900.00
0005433235290	300	Economy	27900.00
0005434728404	300	Economy	27900.00
0005433235277	300	Economy	27900.00
0005434728470	300	Economy	27900.00
0005434552554	300	Economy	27900.00
0005434728498	300	Economy	27900.00
0005433181494	300	Economy	27900.00
0005435142909	300	Economy	27900.00
0005434552602	300	Economy	27900.00
0005434728472	300	Economy	27900.00
0005435142906	300	Economy	27900.00
0005434728430	300	Economy	27900.00
0005434728475	300	Economy	27900.00
0005434728455	300	Economy	27900.00
0005434552595	300	Economy	27900.00
0005433234948	300	Economy	27900.00
0005434728469	300	Economy	27900.00
0005434728431	300	Economy	27900.00
0005434552570	300	Economy	27900.00
0005434728459	300	Economy	27900.00
0005433181542	300	Economy	27900.00
0005434728425	300	Economy	27900.00
0005434552563	300	Economy	27900.00
0005434728428	300	Economy	27900.00
0005433181507	300	Economy	27900.00
0005434552587	300	Economy	27900.00
0005434728500	300	Economy	27900.00
0005433235161	300	Economy	27900.00
0005433289981	300	Economy	27900.00
0005433234950	300	Economy	27900.00
0005434552599	300	Economy	27900.00
0005434552571	300	Economy	27900.00
0005434728415	300	Economy	27900.00
0005434552589	300	Economy	27900.00
0005434735815	300	Economy	27900.00
0005433235135	300	Economy	27900.00
0005433235231	300	Economy	27900.00
0005434302896	300	Economy	27900.00
0005434552580	300	Economy	27900.00
0005434728492	300	Economy	27900.00
0005434552592	300	Economy	27900.00
0005434728487	300	Economy	27900.00
0005433181478	300	Economy	27900.00
0005434552593	300	Economy	27900.00
0005433113567	300	Economy	27900.00
0005434552579	300	Economy	27900.00
0005434728490	300	Economy	27900.00
0005434728479	300	Economy	27900.00
0005434728435	300	Economy	27900.00
0005433235360	300	Economy	27900.00
0005434728454	300	Economy	27900.00
0005434552582	300	Economy	27900.00
0005434728477	300	Economy	27900.00
0005433181524	300	Economy	27900.00
0005434728446	300	Economy	27900.00
0005433131762	300	Economy	27900.00
0005434735814	300	Economy	27900.00
0005434728427	300	Economy	27900.00
0005434302894	300	Economy	27900.00
0005435142913	300	Economy	27900.00
0005432278141	300	Economy	27900.00
0005433181402	300	Economy	27900.00
0005434735811	300	Economy	27900.00
0005434728399	300	Economy	27900.00
0005433289941	300	Economy	27900.00
0005434728412	300	Economy	27900.00
0005434728457	300	Economy	27900.00
0005433234758	300	Economy	27900.00
0005434728453	300	Economy	27900.00
0005434728429	300	Economy	27900.00
0005434552572	300	Economy	27900.00
0005434552585	300	Economy	27900.00
0005433181439	300	Economy	27900.00
0005434728506	300	Economy	27900.00
0005433235059	300	Economy	27900.00
0005434552594	300	Economy	27900.00
0005433235126	300	Economy	27900.00
0005434032085	300	Economy	27900.00
0005433181466	300	Economy	27900.00
0005434728416	300	Economy	27900.00
0005433235107	300	Economy	27900.00
0005434728409	300	Economy	27900.00
0005434728499	300	Economy	30700.00
0005433235310	300	Economy	30700.00
0005434552565	300	Economy	30700.00
0005434728400	300	Economy	30700.00
0005434728439	300	Economy	30700.00
0005434302565	300	Economy	30700.00
0005434728496	300	Economy	27900.00
0005433235142	300	Economy	27900.00
0005434728502	300	Economy	27900.00
0005434032087	300	Economy	27900.00
0005434728507	300	Economy	27900.00
0005434728420	300	Economy	27900.00
0005434728463	300	Economy	27900.00
0005434728486	300	Economy	27900.00
0005434728495	300	Economy	27900.00
0005434731272	300	Economy	27900.00
0005434728508	300	Economy	27900.00
0005434552601	300	Economy	27900.00
0005434728410	300	Economy	27900.00
0005435142910	300	Economy	27900.00
0005434731271	300	Economy	27900.00
0005434552597	300	Economy	27900.00
0005434728450	300	Economy	27900.00
0005434728465	300	Economy	27900.00
0005434728442	300	Economy	27900.00
0005434728501	300	Economy	27900.00
0005434728398	300	Economy	27900.00
0005433181485	300	Economy	27900.00
0005433235141	300	Economy	27900.00
0005434302566	300	Economy	27900.00
0005433235344	300	Economy	27900.00
0005433289942	300	Economy	27900.00
0005433766717	300	Economy	27900.00
0005434552604	300	Economy	27900.00
0005434552564	300	Economy	27900.00
0005434728432	300	Economy	27900.00
0005434735812	300	Economy	27900.00
0005434728418	300	Economy	27900.00
0005434728473	300	Economy	27900.00
0005433235386	300	Economy	27900.00
0005433289959	300	Economy	27900.00
0005434552586	300	Economy	27900.00
0005433181544	300	Economy	27900.00
0005433289947	300	Economy	27900.00
0005434728405	300	Economy	27900.00
0005434728449	300	Economy	27900.00
0005433234949	300	Economy	27900.00
0005432278144	300	Economy	27900.00
0005434728413	300	Economy	27900.00
0005434552578	300	Economy	27900.00
0005433181427	300	Economy	27900.00
0005434735813	300	Economy	27900.00
0005434728403	300	Economy	27900.00
0005432278136	300	Economy	27900.00
0005433289946	300	Economy	27900.00
0005433235138	300	Economy	27900.00
0005434728497	300	Economy	27900.00
0005434728396	300	Economy	27900.00
0005433235179	300	Economy	27900.00
0005433235275	300	Economy	27900.00
0005434728440	300	Economy	27900.00
0005433234958	300	Economy	27900.00
0005435142912	300	Economy	27900.00
0005433235654	300	Economy	27900.00
0005432278140	300	Economy	27900.00
0005433235306	300	Economy	27900.00
0005434728471	300	Economy	27900.00
0005434728478	300	Economy	27900.00
0005434728392	300	Economy	27900.00
0005433181465	300	Economy	27900.00
0005433181448	300	Economy	27900.00
0005433126907	300	Economy	27900.00
0005434728437	300	Economy	27900.00
0005432278142	300	Economy	27900.00
0005434728504	300	Economy	27900.00
0005433235106	300	Economy	27900.00
0005433235246	300	Economy	27900.00
0005434728494	300	Economy	27900.00
0005433289960	300	Economy	27900.00
0005433235393	300	Economy	27900.00
0005432278138	300	Economy	27900.00
0005433181497	300	Economy	27900.00
0005433181443	300	Economy	27900.00
0005433181463	300	Economy	27900.00
0005434735816	300	Economy	27900.00
0005434552561	300	Economy	27900.00
0005434552577	300	Economy	27900.00
0005433181496	300	Economy	27900.00
0005434728401	300	Economy	27900.00
0005433235178	300	Economy	27900.00
0005434728481	300	Economy	27900.00
0005434728441	300	Economy	27900.00
0005434728505	300	Economy	27900.00
0005434731270	300	Economy	27900.00
0005434728414	300	Economy	27900.00
0005433235233	300	Economy	27900.00
0005434728397	300	Economy	27900.00
0005433235274	300	Economy	27900.00
0005433235247	300	Economy	27900.00
0005434551943	9833	Business	83700.00
0005434551889	9833	Business	83700.00
0005434727692	9833	Business	83700.00
0005433235752	9833	Business	83700.00
0005434551940	9833	Business	83700.00
0005434735779	9833	Business	83700.00
0005433235729	9833	Business	83700.00
0005434551892	9833	Business	83700.00
0005434727460	9833	Business	83700.00
0005434727464	9833	Business	83700.00
0005434552021	9833	Business	83700.00
0005434551693	9833	Business	83700.00
0005435142742	9833	Business	83700.00
0005434727358	9833	Business	83700.00
0005434735744	9833	Business	83700.00
0005434726718	9833	Business	83700.00
0005433235758	9833	Business	83700.00
0005433235737	9833	Business	83700.00
0005434727351	9833	Business	83700.00
0005434727694	9833	Business	83700.00
0005434727283	9833	Business	83700.00
0005434731242	9833	Business	83700.00
0005433235768	9833	Business	83700.00
0005434731243	9833	Business	83700.00
0005433235754	9833	Business	83700.00
0005434551891	9833	Business	83700.00
0005434551690	9833	Comfort	47400.00
0005433290029	9833	Business	83700.00
0005434727194	9833	Comfort	47400.00
0005433235750	9833	Comfort	47400.00
0005434727359	9833	Comfort	47400.00
0005433235728	9833	Comfort	47400.00
0005434726999	9833	Comfort	47400.00
0005434552034	9833	Comfort	47400.00
0005434727638	9833	Comfort	47400.00
0005435142721	9833	Comfort	47400.00
0005433235755	9833	Comfort	47400.00
0005434727001	9833	Comfort	47400.00
0005434727662	9833	Comfort	47400.00
0005434727438	9833	Comfort	47400.00
0005434727497	9833	Comfort	47400.00
0005433129387	9833	Comfort	47400.00
0005433235735	9833	Comfort	47400.00
0005434726917	9833	Comfort	47400.00
0005434726804	9833	Comfort	47400.00
0005434727809	9833	Comfort	47400.00
0005433235747	9833	Comfort	47400.00
0005433235776	9833	Comfort	47400.00
0005434727215	9833	Comfort	47400.00
0005434727102	9833	Comfort	47400.00
0005433126956	9833	Comfort	47400.00
0005434552247	9833	Comfort	47400.00
0005434552097	9833	Comfort	47400.00
0005433235761	9833	Comfort	47400.00
0005434727657	9833	Comfort	47400.00
0005433235721	9833	Comfort	47400.00
0005435142756	9833	Comfort	47400.00
0005434727354	9833	Comfort	47400.00
0005434731248	9833	Comfort	47400.00
0005433235741	9833	Comfort	47400.00
0005434727506	9833	Comfort	47400.00
0005434727259	9833	Comfort	47400.00
0005433235724	9833	Comfort	47400.00
0005434726810	9833	Comfort	47400.00
0005433235739	9833	Economy	27900.00
0005434727236	9833	Economy	27900.00
0005435142757	9833	Economy	27900.00
0005434727427	9833	Economy	27900.00
0005435142728	9833	Economy	27900.00
0005434727821	9833	Economy	27900.00
0005434727428	9833	Economy	27900.00
0005434552022	9833	Economy	27900.00
0005434727294	9833	Economy	27900.00
0005434727288	9833	Economy	27900.00
0005433235773	9833	Economy	27900.00
0005434551958	9833	Economy	27900.00
0005433235769	9833	Economy	27900.00
0005433235734	9833	Economy	27900.00
0005434727390	9833	Economy	27900.00
0005433766733	9833	Economy	27900.00
0005434727626	9833	Economy	27900.00
0005434727098	9833	Economy	27900.00
0005434727218	9833	Economy	27900.00
0005434551868	9833	Economy	27900.00
0005432199418	9833	Economy	27900.00
0005434726883	9833	Economy	27900.00
0005434727245	9833	Economy	27900.00
0005434551978	9833	Economy	27900.00
0005434726864	9833	Economy	27900.00
0005434735778	9833	Economy	27900.00
0005434551973	9833	Economy	27900.00
0005434552035	9833	Economy	27900.00
0005433290026	9833	Economy	27900.00
0005434727140	9833	Economy	27900.00
0005434727413	9833	Economy	27900.00
0005434727426	9833	Economy	27900.00
0005434727366	9833	Economy	27900.00
0005433290025	9833	Economy	27900.00
0005434727232	9833	Economy	27900.00
0005434727087	9833	Economy	27900.00
0005434731230	9833	Economy	27900.00
0005433235733	9833	Economy	27900.00
0005433235717	9833	Economy	27900.00
0005434726865	9833	Economy	27900.00
0005433235746	9833	Economy	27900.00
0005434727736	9833	Economy	27900.00
0005434727141	9833	Economy	27900.00
0005434552183	9833	Economy	27900.00
0005434551847	9833	Economy	27900.00
0005433235720	9833	Economy	27900.00
0005434727510	9833	Economy	27900.00
0005434551700	9833	Economy	27900.00
0005433129388	9833	Economy	27900.00
0005434727289	9833	Economy	27900.00
0005434552055	9833	Economy	27900.00
0005434727607	9833	Economy	27900.00
0005434727456	9833	Economy	27900.00
0005433235775	9833	Economy	27900.00
0005434731250	9833	Economy	27900.00
0005434727382	9833	Economy	27900.00
0005435142738	9833	Economy	27900.00
0005434727353	9833	Economy	27900.00
0005434552145	9833	Economy	27900.00
0005434727795	9833	Economy	27900.00
0005435142741	9833	Economy	27900.00
0005434727800	9833	Economy	27900.00
0005434727505	9833	Economy	27900.00
0005434727350	9833	Economy	30700.00
0005434727395	9833	Economy	27900.00
0005434552152	9833	Economy	30700.00
0005433235774	9833	Economy	27900.00
0005433235718	9833	Economy	27900.00
0005434727534	9833	Economy	27900.00
0005435142739	9833	Economy	30700.00
0005434727410	9833	Economy	30700.00
0005434727440	9833	Economy	27900.00
0005434551942	9833	Economy	27900.00
0005434727155	9833	Economy	27900.00
0005434727422	9833	Economy	27900.00
0005433235771	9833	Economy	27900.00
0005434551849	9833	Economy	27900.00
0005434727404	9833	Economy	27900.00
0005434727213	9833	Economy	27900.00
0005434727295	9833	Economy	27900.00
0005433235744	9833	Economy	27900.00
0005434727441	9833	Economy	27900.00
0005434727186	9833	Economy	27900.00
0005434727480	9833	Economy	27900.00
0005434552041	9833	Economy	27900.00
0005434727361	9833	Economy	27900.00
0005433235723	9833	Economy	27900.00
0005434727430	9833	Economy	27900.00
0005433235765	9833	Economy	27900.00
0005434551993	9833	Economy	27900.00
0005434727183	9833	Economy	27900.00
0005435142783	9833	Economy	27900.00
0005433129386	9833	Economy	27900.00
0005434726719	9833	Economy	27900.00
0005434727814	9833	Economy	27900.00
0005434735773	9833	Economy	27900.00
0005434552131	9833	Economy	27900.00
0005434727340	9833	Economy	27900.00
0005434727538	9833	Economy	27900.00
0005434726890	9833	Economy	27900.00
0005434551907	9833	Economy	27900.00
0005434727109	9833	Economy	27900.00
0005434727421	9833	Economy	27900.00
0005433235726	9833	Economy	27900.00
0005434551888	9833	Economy	27900.00
0005434551944	9833	Economy	27900.00
0005433235767	9833	Economy	27900.00
0005434726899	9833	Economy	27900.00
0005434726882	9833	Economy	27900.00
0005434727212	9833	Economy	27900.00
0005434727286	9833	Economy	27900.00
0005434727392	9833	Economy	27900.00
0005434726927	9833	Economy	27900.00
0005434726796	9833	Economy	27900.00
0005434726806	9833	Economy	27900.00
0005434727466	9833	Economy	27900.00
0005434552101	9833	Economy	27900.00
0005435142791	9833	Economy	27900.00
0005434727646	9833	Economy	27900.00
0005434552132	9833	Economy	27900.00
0005433235764	9833	Economy	27900.00
0005434552127	9833	Economy	27900.00
0005434727244	9833	Economy	27900.00
0005434552102	9833	Economy	27900.00
0005433235742	9833	Economy	27900.00
0005433290022	9833	Economy	27900.00
0005434552054	9833	Economy	27900.00
0005434727656	9833	Economy	27900.00
0005434726933	9833	Economy	27900.00
0005433235722	9833	Economy	27900.00
0005433235751	9833	Economy	27900.00
0005435142782	9833	Economy	27900.00
0005434727647	9833	Economy	27900.00
0005434727357	9833	Economy	27900.00
0005434727400	9833	Economy	27900.00
0005434731229	9833	Economy	27900.00
0005434727778	9833	Economy	27900.00
0005434727808	9833	Economy	27900.00
0005433235748	9833	Economy	27900.00
0005434731224	9833	Economy	27900.00
0005433235745	9833	Economy	27900.00
0005433129389	9833	Economy	27900.00
0005433235716	9833	Economy	27900.00
0005434727209	9833	Economy	27900.00
0005435142804	9833	Economy	27900.00
0005434727512	9833	Economy	27900.00
0005435142781	9833	Economy	27900.00
0005434727002	9833	Economy	27900.00
0005433235719	9833	Economy	27900.00
0005433235757	9833	Economy	27900.00
0005433235740	9833	Economy	27900.00
0005433290024	9833	Economy	27900.00
0005434727555	9833	Economy	27900.00
0005433235730	9833	Economy	27900.00
0005434726811	9833	Economy	27900.00
0005433235732	9833	Economy	27900.00
0005433235727	9833	Economy	27900.00
0005434727330	9833	Economy	27900.00
0005434731249	9833	Economy	27900.00
0005434727352	9833	Economy	27900.00
0005434727758	9833	Economy	27900.00
0005435142720	9833	Economy	27900.00
0005432199419	9833	Economy	27900.00
0005433129390	9833	Economy	27900.00
0005433235772	9833	Economy	27900.00
0005434551689	9833	Economy	27900.00
0005434727193	9833	Economy	27900.00
0005434727556	9833	Economy	27900.00
0005434727952	9833	Economy	27900.00
0005434727391	9833	Economy	27900.00
0005433235759	9833	Economy	27900.00
0005434727094	9833	Economy	27900.00
0005433235760	9833	Economy	27900.00
0005434727272	9833	Economy	27900.00
0005434032139	9833	Economy	27900.00
0005435142792	9833	Economy	27900.00
0005434727417	9833	Economy	27900.00
0005434727683	9833	Economy	27900.00
0005433290030	9833	Economy	30700.00
0005433235763	9833	Economy	30700.00
0005433235738	9833	Economy	30700.00
0005434551850	9833	Economy	30700.00
0005433766735	9833	Economy	27900.00
0005434727220	9833	Economy	27900.00
0005434726944	9833	Economy	27900.00
0005434727655	9833	Economy	27900.00
0005433766734	9833	Economy	27900.00
0005434727801	9833	Economy	27900.00
0005434727258	9833	Economy	27900.00
0005434727412	9833	Economy	27900.00
0005434727813	9833	Economy	27900.00
0005434731247	9833	Economy	27900.00
0005434551848	9833	Economy	27900.00
0005434727549	9833	Economy	27900.00
0005434727093	9833	Economy	27900.00
0005434726805	9833	Economy	27900.00
0005433235762	9833	Economy	27900.00
0005433235766	9833	Economy	27900.00
0005434727266	9833	Economy	27900.00
0005434551939	9833	Economy	27900.00
0005434727528	9833	Economy	27900.00
0005434552036	9833	Economy	27900.00
0005434727320	9833	Economy	27900.00
0005433235731	9833	Economy	27900.00
0005434727322	9833	Economy	27900.00
0005434727550	9833	Economy	27900.00
0005433235743	9833	Economy	27900.00
0005433235753	9833	Economy	27900.00
0005435142805	9833	Economy	27900.00
0005434727463	9833	Economy	27900.00
0005434727309	9833	Economy	27900.00
0005434727535	9833	Economy	27900.00
0005435142753	9833	Economy	27900.00
0005434727310	9833	Economy	27900.00
0005434727191	9833	Economy	27900.00
0005434727684	9833	Economy	27900.00
0005435142750	9833	Economy	27900.00
0005434727625	9833	Economy	27900.00
0005434032138	9833	Economy	27900.00
0005434552330	9833	Economy	27900.00
0005434727608	9833	Economy	27900.00
0005433235770	9833	Economy	27900.00
0005434727401	9833	Economy	27900.00
0005434552362	9833	Economy	27900.00
0005434727951	9833	Economy	27900.00
0005434551887	9833	Economy	27900.00
0005434552139	9833	Economy	27900.00
0005434727153	9833	Economy	27900.00
0005433235756	9833	Economy	27900.00
0005434727066	9833	Economy	27900.00
0005434727523	9833	Economy	27900.00
0005434727513	9833	Economy	27900.00
0005434727661	9833	Economy	27900.00
0005434727067	9833	Economy	27900.00
0005433126957	9833	Economy	27900.00
0005434727156	9833	Economy	27900.00
0005434727267	9833	Economy	27900.00
0005433235725	9833	Economy	27900.00
0005434032137	9833	Economy	27900.00
0005434727323	9833	Economy	27900.00
0005434726918	9833	Economy	27900.00
0005434727409	9833	Economy	27900.00
0005434727439	9833	Economy	27900.00
0005434551950	9833	Economy	27900.00
0005434727425	9833	Economy	27900.00
0005434032140	9833	Economy	27900.00
0005434727522	9833	Economy	27900.00
0005434727190	9833	Economy	27900.00
0005434551886	9833	Economy	27900.00
0005434727192	9833	Economy	27900.00
0005434727585	9833	Economy	27900.00
0005434727219	9833	Economy	27900.00
0005434552144	9833	Economy	27900.00
0005433235749	9833	Economy	27900.00
0005434551931	9833	Economy	27900.00
0005434727068	9833	Economy	27900.00
0005433290027	9833	Economy	27900.00
0005433235736	9833	Economy	27900.00
0005434552059	9833	Economy	27900.00
0005433290023	9833	Economy	27900.00
0005434727498	9833	Economy	27900.00
0005434552140	9833	Economy	27900.00
0005433113589	9833	Economy	27900.00
0005434727065	9833	Economy	27900.00
0005434727076	9833	Economy	27900.00
0005434551836	9833	Economy	27900.00
0005434735762	9833	Economy	27900.00
0005434727459	9833	Economy	27900.00
0005434727565	9833	Economy	27900.00
0005432199420	9833	Economy	27900.00
0005434727101	9833	Economy	27900.00
0005434551974	9833	Economy	27900.00
0005434727578	9833	Economy	27900.00
0005433290021	9833	Economy	27900.00
0005434552146	9833	Economy	27900.00
0005433290028	9833	Economy	27900.00
0005435214671	7718	Business	42100.00
0005434069325	7718	Business	42100.00
0005432070020	7718	Business	42100.00
0005432531156	7718	Business	42100.00
0005435214755	7718	Business	42100.00
0005434069327	7718	Business	42100.00
0005434069324	7718	Business	42100.00
0005434069323	7718	Business	42100.00
0005434069303	7718	Business	42100.00
0005432537109	7718	Business	42100.00
0005434069315	7718	Business	42100.00
0005432531175	7718	Business	42100.00
0005435631027	7718	Business	42100.00
0005435214641	7718	Business	42100.00
0005435214623	7718	Business	42100.00
0005435214618	7718	Business	42100.00
0005434069332	7718	Business	42100.00
0005432531183	7718	Business	42100.00
0005434069334	7718	Business	42100.00
0005432531137	7718	Business	42100.00
0005433656705	7718	Business	42100.00
0005434069301	7718	Business	42100.00
0005435214771	7718	Business	42100.00
0005435725694	7718	Business	42100.00
0005432531252	7718	Comfort	23900.00
0005432531240	7718	Comfort	23900.00
0005435214573	7718	Comfort	23900.00
0005435214672	7718	Comfort	23900.00
0005434069292	7718	Comfort	23900.00
0005432150391	7718	Comfort	23900.00
0005432531254	7718	Comfort	23900.00
0005432531177	7718	Comfort	23900.00
0005434069326	7718	Comfort	23900.00
0005435214772	7718	Comfort	23900.00
0005432531153	7718	Comfort	23900.00
0005432531205	7718	Comfort	23900.00
0005432531255	7718	Comfort	23900.00
0005432531249	7718	Comfort	23900.00
0005432531168	7718	Comfort	23900.00
0005434069313	7718	Comfort	23900.00
0005435214362	7718	Comfort	23900.00
0005432531242	7718	Comfort	23900.00
0005434069296	7718	Comfort	23900.00
0005432531151	7718	Comfort	23900.00
0005432533362	7718	Comfort	23900.00
0005432533363	7718	Comfort	23900.00
0005432531225	7718	Comfort	23900.00
0005432531227	7718	Comfort	23900.00
0005432531238	7718	Comfort	23900.00
0005432531133	7718	Comfort	23900.00
0005434069333	7718	Comfort	23900.00
0005432531138	7718	Comfort	23900.00
0005434069288	7718	Comfort	23900.00
0005434069284	7718	Comfort	23900.00
0005434069328	7718	Comfort	23900.00
0005435214689	7718	Comfort	23900.00
0005432531213	7718	Comfort	23900.00
0005432150388	7718	Comfort	23900.00
0005432535956	7718	Comfort	23900.00
0005432070014	7718	Comfort	23900.00
0005434069329	7718	Comfort	23900.00
0005432531210	7718	Comfort	23900.00
0005432429012	7718	Comfort	23900.00
0005435214953	7718	Economy	14000.00
0005434069300	7718	Economy	14000.00
0005434069318	7718	Economy	14000.00
0005432070008	7718	Economy	14000.00
0005432531226	7718	Economy	14000.00
0005435214303	7718	Economy	14000.00
0005435214783	7718	Economy	14000.00
0005435214802	7718	Economy	14000.00
0005432070011	7718	Economy	14000.00
0005434069331	7718	Economy	14000.00
0005435214688	7718	Economy	14000.00
0005435214412	7718	Economy	14000.00
0005435214733	7718	Economy	14000.00
0005435214909	7718	Economy	14000.00
0005432531221	7718	Economy	14000.00
0005435214780	7718	Economy	14000.00
0005432531201	7718	Economy	14000.00
0005435214678	7718	Economy	14000.00
0005432531139	7718	Economy	14000.00
0005434069279	7718	Economy	14000.00
0005435214519	7718	Economy	14000.00
0005432531250	7718	Economy	14000.00
0005433656704	7718	Economy	14000.00
0005432070009	7718	Economy	14000.00
0005432070016	7718	Economy	14000.00
0005434069319	7718	Economy	14000.00
0005435214561	7718	Economy	14000.00
0005434069322	7718	Economy	14000.00
0005432531134	7718	Economy	14000.00
0005434069286	7718	Economy	14000.00
0005432531169	7718	Economy	14000.00
0005435214528	7718	Economy	14000.00
0005432070012	7718	Economy	14000.00
0005434069275	7718	Economy	14000.00
0005432531164	7718	Economy	14000.00
0005432531159	7718	Economy	14000.00
0005432531174	7718	Economy	14000.00
0005432531200	7718	Economy	14000.00
0005434069309	7718	Economy	14000.00
0005435214261	7718	Economy	14000.00
0005432150390	7718	Economy	14000.00
0005435214848	7718	Economy	14000.00
0005434069335	7718	Economy	14000.00
0005435214774	7718	Economy	14000.00
0005432531166	7718	Economy	14000.00
0005435214603	7718	Economy	14000.00
0005435214723	7718	Economy	14000.00
0005434069310	7718	Economy	14000.00
0005435214657	7718	Economy	14000.00
0005432531143	7718	Economy	14000.00
0005434069330	7718	Economy	14000.00
0005435214520	7718	Economy	14000.00
0005432531173	7718	Economy	14000.00
0005434069289	7718	Economy	14000.00
0005432429015	7718	Economy	14000.00
0005435214781	7718	Economy	15400.00
0005432531142	7718	Economy	15400.00
0005435631028	7718	Economy	14000.00
0005432531256	7718	Economy	14000.00
0005434069291	7718	Economy	14000.00
0005435214670	7718	Economy	14000.00
0005434069308	7718	Economy	15400.00
0005434069312	7718	Economy	15400.00
0005432531232	7718	Economy	14000.00
0005432531178	7718	Economy	14000.00
0005432535952	7718	Economy	14000.00
0005435214822	7718	Economy	14000.00
0005435214639	7718	Economy	14000.00
0005435214785	7718	Economy	14000.00
0005432531184	7718	Economy	14000.00
0005432531243	7718	Economy	14000.00
0005432531193	7718	Economy	14000.00
0005432531150	7718	Economy	14000.00
0005435214981	7718	Economy	14000.00
0005435214529	7718	Economy	14000.00
0005435214691	7718	Economy	14000.00
0005432531186	7718	Economy	14000.00
0005435214600	7718	Economy	14000.00
0005435214740	7718	Economy	14000.00
0005432150385	7718	Economy	14000.00
0005432531196	7718	Economy	14000.00
0005432150386	7718	Economy	14000.00
0005432535955	7718	Economy	14000.00
0005432531230	7718	Economy	14000.00
0005432537110	7718	Economy	14000.00
0005432531167	7718	Economy	14000.00
0005432070013	7718	Economy	14000.00
0005434069320	7718	Economy	14000.00
0005432531258	7718	Economy	14000.00
0005432531247	7718	Economy	14000.00
0005435214700	7718	Economy	14000.00
0005432531215	7718	Economy	14000.00
0005435214784	7718	Economy	14000.00
0005435214719	7718	Economy	14000.00
0005432531154	7718	Economy	14000.00
0005434069273	7718	Economy	14000.00
0005434069280	7718	Economy	14000.00
0005435725687	7718	Economy	14000.00
0005432150387	7718	Economy	14000.00
0005432531170	7718	Economy	14000.00
0005432531214	7718	Economy	14000.00
0005435214770	7718	Economy	14000.00
0005432429016	7718	Economy	14000.00
0005434069299	7718	Economy	14000.00
0005432531155	7718	Economy	14000.00
0005435214484	7718	Economy	14000.00
0005432070006	7718	Economy	14000.00
0005432531231	7718	Economy	14000.00
0005434069281	7718	Economy	14000.00
0005435214627	7718	Economy	14000.00
0005432531204	7718	Economy	14000.00
0005432531189	7718	Economy	14000.00
0005432531236	7718	Economy	14000.00
0005432531237	7718	Economy	14000.00
0005432531144	7718	Economy	14000.00
0005432531179	7718	Economy	14000.00
0005435214628	7718	Economy	14000.00
0005432531163	7718	Economy	14000.00
0005435214611	7718	Economy	14000.00
0005434069336	7718	Economy	14000.00
0005432531206	7718	Economy	14000.00
0005435214498	7718	Economy	14000.00
0005432531207	7718	Economy	14000.00
0005435214690	7718	Economy	14000.00
0005432531229	7718	Economy	14000.00
0005434069295	7718	Economy	14000.00
0005432535953	7718	Economy	14000.00
0005435214709	7718	Economy	14000.00
0005432531245	7718	Economy	14000.00
0005435214718	7718	Economy	14000.00
0005432070018	7718	Economy	14000.00
0005435214386	7718	Economy	14000.00
0005434069305	7718	Economy	14000.00
0005432531199	7718	Economy	14000.00
0005432150389	7718	Economy	14000.00
0005432531157	7718	Economy	14000.00
0005432531198	7718	Economy	14000.00
0005432070007	7718	Economy	14000.00
0005435214643	7718	Economy	14000.00
0005432531187	7718	Economy	14000.00
0005432531185	7718	Economy	14000.00
0005432531191	7718	Economy	14000.00
0005432531222	7718	Economy	14000.00
0005434069307	7718	Economy	14000.00
0005432531246	7718	Economy	14000.00
0005432531145	7718	Economy	14000.00
0005435214510	7718	Economy	14000.00
0005432531147	7718	Economy	14000.00
0005432531218	7718	Economy	14000.00
0005435214679	7718	Economy	14000.00
0005432531176	7718	Economy	14000.00
0005433656728	7718	Economy	14000.00
0005432531220	7718	Economy	14000.00
0005432070019	7718	Economy	14000.00
0005432531146	7718	Economy	14000.00
0005432531251	7718	Economy	14000.00
0005435214734	7718	Economy	14000.00
0005435214749	7718	Economy	14000.00
0005434069321	7718	Economy	14000.00
0005432531165	7718	Economy	14000.00
0005435214908	7718	Economy	15400.00
0005434069293	7718	Economy	15400.00
0005435214385	7718	Economy	15400.00
0005432429013	7718	Economy	15400.00
0005434069282	7718	Economy	15400.00
0005432531171	7718	Economy	14000.00
0005432531161	7718	Economy	15400.00
0005432070015	7718	Economy	14000.00
0005434069316	7718	Economy	14000.00
0005434069317	7718	Economy	14000.00
0005432070005	7718	Economy	14000.00
0005435214708	7718	Economy	14000.00
0005432070017	7718	Economy	14000.00
0005432533361	7718	Economy	14000.00
0005432531160	7718	Economy	14000.00
0005432531235	7718	Economy	14000.00
0005435214556	7718	Economy	14000.00
0005432531234	7718	Economy	14000.00
0005432531219	7718	Economy	14000.00
0005435214644	7718	Economy	14000.00
0005434069290	7718	Economy	14000.00
0005432531212	7718	Economy	14000.00
0005434069278	7718	Economy	14000.00
0005435214683	7718	Economy	14000.00
0005435214633	7718	Economy	14000.00
0005432531202	7718	Economy	14000.00
0005432531233	7718	Economy	14000.00
0005434069298	7718	Economy	14000.00
0005432531141	7718	Economy	14000.00
0005432531223	7718	Economy	14000.00
0005434069283	7718	Economy	14000.00
0005435214624	7718	Economy	14000.00
0005432531216	7718	Economy	14000.00
0005432531158	7718	Economy	14000.00
0005432531136	7718	Economy	14000.00
0005435214821	7718	Economy	14000.00
0005435214638	7718	Economy	14000.00
0005435214467	7718	Economy	14000.00
0005435214509	7718	Economy	14000.00
0005432531195	7718	Economy	14000.00
0005432150384	7718	Economy	14000.00
0005432070010	7718	Economy	14000.00
0005432429014	7718	Economy	14000.00
0005434069297	7718	Economy	14000.00
0005432531149	7718	Economy	14000.00
0005434069304	7718	Economy	14000.00
0005432531180	7718	Economy	14000.00
0005432531194	7718	Economy	14000.00
0005435214327	7718	Economy	14000.00
0005435214363	7718	Economy	14000.00
0005435214717	7718	Economy	14000.00
0005434069306	7718	Economy	14000.00
0005434069276	7718	Economy	14000.00
0005432531211	7718	Economy	14000.00
0005435725678	7718	Economy	14000.00
0005432531190	7718	Economy	14000.00
0005432531228	7718	Economy	14000.00
0005435214429	7718	Economy	14000.00
0005435214568	7718	Economy	14000.00
0005432531244	7718	Economy	14000.00
0005432531140	7718	Economy	14000.00
0005432531241	7718	Economy	14000.00
0005434069285	7718	Economy	14000.00
0005432531172	7718	Economy	14000.00
0005432531132	7718	Economy	14000.00
0005432531208	7718	Economy	14000.00
0005432531197	7718	Economy	14000.00
0005432531217	7718	Economy	14000.00
0005432531192	7718	Economy	14000.00
0005434069302	7718	Economy	14000.00
0005434069287	7718	Economy	14000.00
0005432531188	7718	Economy	14000.00
0005432531209	7718	Economy	14000.00
0005435214656	7718	Economy	14000.00
0005434069314	7718	Economy	14000.00
0005435214602	7718	Economy	14000.00
0005432531182	7718	Economy	14000.00
0005435214737	7718	Economy	14000.00
0005432531253	7718	Economy	14000.00
0005432531224	7718	Economy	14000.00
0005435214796	7718	Economy	14000.00
0005432531257	7718	Economy	14000.00
0005434069311	7718	Economy	14000.00
0005432531239	7718	Economy	14000.00
0005435214756	7718	Economy	14000.00
0005434069274	7718	Economy	14000.00
0005434069277	7718	Economy	14000.00
0005432531181	7718	Economy	14000.00
0005432531152	7718	Economy	14000.00
0005432531203	7718	Economy	14000.00
0005435214481	7718	Economy	14000.00
0005432531248	7718	Economy	14000.00
0005432531162	7718	Economy	14000.00
0005432531135	7718	Economy	14000.00
0005432531148	7718	Economy	14000.00
0005432535954	7718	Economy	14000.00
0005434069294	7718	Economy	14000.00
0005435425844	5362	Business	43100.00
0005435616433	5362	Business	43100.00
0005435616491	5362	Business	43100.00
0005434345114	5362	Business	43100.00
0005435426154	5362	Business	43100.00
0005435616441	5362	Business	43100.00
0005435490318	5362	Business	43100.00
0005435616418	5362	Business	43100.00
0005435616469	5362	Business	43100.00
0005432133579	5362	Business	43100.00
0005435302270	5362	Business	43100.00
0005435616499	5362	Business	43100.00
0005435616483	5362	Business	43100.00
0005435616496	5362	Business	43100.00
0005435616424	5362	Business	43100.00
0005435302286	5362	Business	43100.00
0005435426203	5362	Business	43100.00
0005435616458	5362	Business	43100.00
0005434345091	5362	Business	43100.00
0005434345109	5362	Business	43100.00
0005435616474	5362	Business	43100.00
0005435616465	5362	Business	43100.00
0005435425820	5362	Business	43100.00
0005435305041	5362	Business	43100.00
0005435616473	5362	Business	43100.00
0005435616435	5362	Business	43100.00
0005435616472	5362	Comfort	24400.00
0005435616420	5362	Business	43100.00
0005435425732	5362	Comfort	24400.00
0005435380392	5362	Comfort	24400.00
0005435616476	5362	Comfort	24400.00
0005435616448	5362	Comfort	24400.00
0005435426003	5362	Comfort	24400.00
0005435616506	5362	Comfort	24400.00
0005432363459	5362	Comfort	24400.00
0005435425898	5362	Comfort	24400.00
0005435426067	5362	Comfort	24400.00
0005434573699	5362	Comfort	24400.00
0005435491494	5362	Comfort	24400.00
0005434245301	5362	Comfort	24400.00
0005435616408	5362	Comfort	24400.00
0005434345095	5362	Comfort	24400.00
0005435616475	5362	Comfort	24400.00
0005435302269	5362	Comfort	24400.00
0005435616404	5362	Comfort	24400.00
0005435426113	5362	Comfort	24400.00
0005435616495	5362	Comfort	24400.00
0005435426074	5362	Comfort	24400.00
0005434245467	5362	Comfort	24400.00
0005435425880	5362	Comfort	24400.00
0005435097447	5362	Comfort	24400.00
0005435616487	5362	Comfort	24400.00
0005434245442	5362	Comfort	24400.00
0005434245431	5362	Comfort	24400.00
0005435616480	5362	Comfort	24400.00
0005434245468	5362	Comfort	24400.00
0005435616414	5362	Comfort	24400.00
0005435616482	5362	Comfort	24400.00
0005435616440	5362	Comfort	24400.00
0005434345098	5362	Comfort	24400.00
0005434245413	5362	Comfort	24400.00
0005434345101	5362	Comfort	24400.00
0005435425797	5362	Comfort	24400.00
0005435426137	5362	Comfort	24400.00
0005435426063	5362	Comfort	24400.00
0005435555419	5362	Comfort	24400.00
0005435425963	5362	Economy	14400.00
0005435425810	5362	Comfort	24400.00
0005434245490	5362	Economy	14400.00
0005434345085	5362	Economy	14400.00
0005434245455	5362	Economy	14400.00
0005435616504	5362	Economy	14400.00
0005435616501	5362	Economy	14400.00
0005432133581	5362	Economy	14400.00
0005435425801	5362	Economy	14400.00
0005435425698	5362	Economy	14400.00
0005435616412	5362	Economy	14400.00
0005435426061	5362	Economy	14400.00
0005434573693	5362	Economy	14400.00
0005435616436	5362	Economy	14400.00
0005435616477	5362	Economy	14400.00
0005435425997	5362	Economy	14400.00
0005435380350	5362	Economy	14400.00
0005435425731	5362	Economy	14400.00
0005435097450	5362	Economy	14400.00
0005435616405	5362	Economy	14400.00
0005435616505	5362	Economy	14400.00
0005434245471	5362	Economy	14400.00
0005434245446	5362	Economy	14400.00
0005434345105	5362	Economy	14400.00
0005435616439	5362	Economy	14400.00
0005435425787	5362	Economy	14400.00
0005435042897	5362	Economy	14400.00
0005435380351	5362	Economy	14400.00
0005434345103	5362	Economy	14400.00
0005435425994	5362	Economy	14400.00
0005435616431	5362	Economy	14400.00
0005434345111	5362	Economy	14400.00
0005434345097	5362	Economy	14400.00
0005433719190	5362	Economy	14400.00
0005434573701	5362	Economy	14400.00
0005435425912	5362	Economy	14400.00
0005435616460	5362	Economy	14400.00
0005435426103	5362	Economy	14400.00
0005435616502	5362	Economy	14400.00
0005435616409	5362	Economy	14400.00
0005434345106	5362	Economy	14400.00
0005433719202	5362	Economy	14400.00
0005434345092	5362	Economy	14400.00
0005435425971	5362	Economy	14400.00
0005434573696	5362	Economy	14400.00
0005434345100	5362	Economy	14400.00
0005435425798	5362	Economy	14400.00
0005435616438	5362	Economy	14400.00
0005435616456	5362	Economy	14400.00
0005432133586	5362	Economy	14400.00
0005434345108	5362	Economy	14400.00
0005435425945	5362	Economy	14400.00
0005432363464	5362	Economy	14400.00
0005434345083	5362	Economy	14400.00
0005432133578	5362	Economy	14400.00
0005435425915	5362	Economy	14400.00
0005435616488	5362	Economy	14400.00
0005434245531	5362	Economy	14400.00
0005435426095	5362	Economy	14400.00
0005435097448	5362	Economy	14400.00
0005435616449	5362	Economy	14400.00
0005435616494	5362	Economy	14400.00
0005435490319	5362	Economy	14400.00
0005435426132	5362	Economy	14400.00
0005435042888	5362	Economy	15800.00
0005432133584	5362	Economy	14400.00
0005435425870	5362	Economy	15800.00
0005435616507	5362	Economy	15800.00
0005435616447	5362	Economy	14400.00
0005433719203	5362	Economy	14400.00
0005434245264	5362	Economy	14400.00
0005435616461	5362	Economy	14400.00
0005434245362	5362	Economy	15800.00
0005435425821	5362	Economy	15800.00
0005435490317	5362	Economy	14400.00
0005434345088	5362	Economy	14400.00
0005435616413	5362	Economy	14400.00
0005435616503	5362	Economy	14400.00
0005434345084	5362	Economy	14400.00
0005435616415	5362	Economy	14400.00
0005432363474	5362	Economy	14400.00
0005435425982	5362	Economy	14400.00
0005435616457	5362	Economy	14400.00
0005435425799	5362	Economy	14400.00
0005435425899	5362	Economy	14400.00
0005432133587	5362	Economy	14400.00
0005435616445	5362	Economy	14400.00
0005434245430	5362	Economy	14400.00
0005435616406	5362	Economy	14400.00
0005435555420	5362	Economy	14400.00
0005435616470	5362	Economy	14400.00
0005435380362	5362	Economy	14400.00
0005435616423	5362	Economy	14400.00
0005434245398	5362	Economy	14400.00
0005434245488	5362	Economy	14400.00
0005435425832	5362	Economy	14400.00
0005435097455	5362	Economy	14400.00
0005435616468	5362	Economy	14400.00
0005435425962	5362	Economy	14400.00
0005435426062	5362	Economy	14400.00
0005435380356	5362	Economy	14400.00
0005434573700	5362	Economy	14400.00
0005435425825	5362	Economy	14400.00
0005435302256	5362	Economy	14400.00
0005435616422	5362	Economy	14400.00
0005435616401	5362	Economy	14400.00
0005435616454	5362	Economy	14400.00
0005435302289	5362	Economy	14400.00
0005435426104	5362	Economy	14400.00
0005432133576	5362	Economy	14400.00
0005435426142	5362	Economy	14400.00
0005435616410	5362	Economy	14400.00
0005435616421	5362	Economy	14400.00
0005435425917	5362	Economy	14400.00
0005435616500	5362	Economy	14400.00
0005435426153	5362	Economy	14400.00
0005435425791	5362	Economy	14400.00
0005432133583	5362	Economy	14400.00
0005435425652	5362	Economy	14400.00
0005434245391	5362	Economy	14400.00
0005435616402	5362	Economy	14400.00
0005434345080	5362	Economy	14400.00
0005432133575	5362	Economy	14400.00
0005435425831	5362	Economy	14400.00
0005435425871	5362	Economy	14400.00
0005435616407	5362	Economy	14400.00
0005435616425	5362	Economy	14400.00
0005435425944	5362	Economy	14400.00
0005435616411	5362	Economy	14400.00
0005435616498	5362	Economy	14400.00
0005434245525	5362	Economy	14400.00
0005432133577	5362	Economy	14400.00
0005435616464	5362	Economy	14400.00
0005434345093	5362	Economy	14400.00
0005434345087	5362	Economy	14400.00
0005435616419	5362	Economy	14400.00
0005433719201	5362	Economy	14400.00
0005435426204	5362	Economy	14400.00
0005435426161	5362	Economy	14400.00
0005435380384	5362	Economy	14400.00
0005435426004	5362	Economy	14400.00
0005435425992	5362	Economy	14400.00
0005435302287	5362	Economy	14400.00
0005435616489	5362	Economy	14400.00
0005435426100	5362	Economy	14400.00
0005434573707	5362	Economy	14400.00
0005435616484	5362	Economy	14400.00
0005435616463	5362	Economy	14400.00
0005435426160	5362	Economy	14400.00
0005435616492	5362	Economy	14400.00
0005434245361	5362	Economy	14400.00
0005435426032	5362	Economy	14400.00
0005435425996	5362	Economy	14400.00
0005432047643	5362	Economy	14400.00
0005435319652	5362	Economy	14400.00
0005435319739	5362	Economy	14400.00
0005435097453	5362	Economy	14400.00
0005435425854	5362	Economy	14400.00
0005434245500	5362	Economy	14400.00
0005435426060	5362	Economy	14400.00
0005435616451	5362	Economy	14400.00
0005434245300	5362	Economy	14400.00
0005435426167	5362	Economy	14400.00
0005434245375	5362	Economy	14400.00
0005435425772	5362	Economy	14400.00
0005435425800	5362	Economy	14400.00
0005435097451	5362	Economy	14400.00
0005434345104	5362	Economy	14400.00
0005434573704	5362	Economy	14400.00
0005435425809	5362	Economy	14400.00
0005435616455	5362	Economy	14400.00
0005432133580	5362	Economy	14400.00
0005435616479	5362	Economy	14400.00
0005434573706	5362	Economy	14400.00
0005435425855	5362	Economy	14400.00
0005435380357	5362	Economy	14400.00
0005435616481	5362	Economy	14400.00
0005435616467	5362	Economy	14400.00
0005435425865	5362	Economy	14400.00
0005435616497	5362	Economy	15800.00
0005435425751	5362	Economy	15800.00
0005435616437	5362	Economy	15800.00
0005434245299	5362	Economy	15800.00
0005435425752	5362	Economy	15800.00
0005435425987	5362	Economy	14400.00
0005435425881	5362	Economy	15800.00
0005435426013	5362	Economy	14400.00
0005435425864	5362	Economy	14400.00
0005435380358	5362	Economy	14400.00
0005434345089	5362	Economy	14400.00
0005434573705	5362	Economy	14400.00
0005435302257	5362	Economy	14400.00
0005435616466	5362	Economy	14400.00
0005434573695	5362	Economy	14400.00
0005435616490	5362	Economy	14400.00
0005435426143	5362	Economy	14400.00
0005434245456	5362	Economy	14400.00
0005435616478	5362	Economy	14400.00
0005435616417	5362	Economy	14400.00
0005432133588	5362	Economy	14400.00
0005435616400	5362	Economy	14400.00
0005434345082	5362	Economy	14400.00
0005435555418	5362	Economy	14400.00
0005435425882	5362	Economy	14400.00
0005435042886	5362	Economy	14400.00
0005435616432	5362	Economy	14400.00
0005434573698	5362	Economy	14400.00
0005435616446	5362	Economy	14400.00
0005435616443	5362	Economy	14400.00
0005434245447	5362	Economy	14400.00
0005435097449	5362	Economy	14400.00
0005434245453	5362	Economy	14400.00
0005435319753	5362	Economy	14400.00
0005434573702	5362	Economy	14400.00
0005434345107	5362	Economy	14400.00
0005435425697	5362	Economy	14400.00
0005435425830	5362	Economy	14400.00
0005435380366	5362	Economy	14400.00
0005435616444	5362	Economy	14400.00
0005435616427	5362	Economy	14400.00
0005435616430	5362	Economy	14400.00
0005434345113	5362	Economy	14400.00
0005435616442	5362	Economy	14400.00
0005435425909	5362	Economy	14400.00
0005435425978	5362	Economy	14400.00
0005434245561	5362	Economy	14400.00
0005435616486	5362	Economy	14400.00
0005435616426	5362	Economy	14400.00
0005434345112	5362	Economy	14400.00
0005434345081	5362	Economy	14400.00
0005434573694	5362	Economy	14400.00
0005432133582	5362	Economy	14400.00
0005434245360	5362	Economy	14400.00
0005434345110	5362	Economy	14400.00
0005435616462	5362	Economy	14400.00
0005435042889	5362	Economy	14400.00
0005432047644	5362	Economy	14400.00
0005435426008	5362	Economy	14400.00
0005435425635	5362	Economy	14400.00
0005434245473	5362	Economy	14400.00
0005432047642	5362	Economy	14400.00
0005434573697	5362	Economy	14400.00
0005435616434	5362	Economy	14400.00
0005435616485	5362	Economy	14400.00
0005434345094	5362	Economy	14400.00
0005435616453	5362	Economy	14400.00
0005435426195	5362	Economy	14400.00
0005434345099	5362	Economy	14400.00
0005435319701	5362	Economy	14400.00
0005435616429	5362	Economy	14400.00
0005435616459	5362	Economy	14400.00
0005435380375	5362	Economy	14400.00
0005434245470	5362	Economy	14400.00
0005435097456	5362	Economy	14400.00
0005434345096	5362	Economy	14400.00
0005435425766	5362	Economy	14400.00
0005435425653	5362	Economy	14400.00
0005435425857	5362	Economy	14400.00
0005432363465	5362	Economy	14400.00
0005432133585	5362	Economy	14400.00
0005435425666	5362	Economy	14400.00
0005435042887	5362	Economy	14400.00
0005435616416	5362	Economy	14400.00
0005435097452	5362	Economy	14400.00
0005434345102	5362	Economy	14400.00
0005435380374	5362	Economy	14400.00
0005434245265	5362	Economy	14400.00
0005435380361	5362	Economy	14400.00
0005434245489	5362	Economy	14400.00
0005435616452	5362	Economy	14400.00
0005434345090	5362	Economy	14400.00
0005432363475	5362	Economy	14400.00
0005432363467	5362	Economy	14400.00
0005434245466	5362	Economy	14400.00
0005435425977	5362	Economy	14400.00
0005435426196	5362	Economy	14400.00
0005435616428	5362	Economy	14400.00
0005434345086	5362	Economy	14400.00
0005435616450	5362	Economy	14400.00
0005435426020	5362	Economy	14400.00
0005434573703	5362	Economy	14400.00
0005435491495	5362	Economy	14400.00
0005435616403	5362	Economy	14400.00
0005435097457	5362	Economy	14400.00
0005435616493	5362	Economy	14400.00
0005435616471	5362	Economy	14400.00
0005435097454	5362	Economy	14400.00
0005435097370	10907	Business	43100.00
0005435097369	10907	Business	43100.00
0005435305059	10907	Business	43100.00
0005435615543	10907	Business	43100.00
0005434245705	10907	Business	43100.00
0005435615348	10907	Business	43100.00
0005434245712	10907	Business	43100.00
0005435615732	10907	Business	43100.00
0005435426483	10907	Business	43100.00
0005435615886	10907	Business	43100.00
0005435615625	10907	Business	43100.00
0005434245707	10907	Business	43100.00
0005435615140	10907	Business	43100.00
0005435426492	10907	Business	43100.00
0005435555394	10907	Business	43100.00
0005435097364	10907	Business	43100.00
0005435615052	10907	Business	43100.00
0005434344804	10907	Business	43100.00
0005435615098	10907	Business	43100.00
0005435615869	10907	Business	43100.00
0005435615463	10907	Business	43100.00
0005435426508	10907	Business	43100.00
0005432363496	10907	Business	43100.00
0005435491470	10907	Business	43100.00
0005432363497	10907	Business	43100.00
0005432166980	10907	Business	43100.00
0005435426507	10907	Business	43100.00
0005434344686	10907	Comfort	24400.00
0005435319795	10907	Comfort	24400.00
0005434344680	10907	Comfort	24400.00
0005435319793	10907	Comfort	24400.00
0005435426531	10907	Comfort	24400.00
0005434245700	10907	Comfort	24400.00
0005434245698	10907	Comfort	24400.00
0005435426491	10907	Comfort	24400.00
0005435615242	10907	Comfort	24400.00
0005435615592	10907	Comfort	24400.00
0005435615619	10907	Comfort	24400.00
0005435617237	10907	Comfort	24400.00
0005435426489	10907	Comfort	24400.00
0005435614917	10907	Comfort	24400.00
0005434344604	10907	Comfort	24400.00
0005435615723	10907	Comfort	24400.00
0005435615523	10907	Comfort	24400.00
0005435491475	10907	Comfort	24400.00
0005435615551	10907	Comfort	24400.00
0005435615822	10907	Comfort	24400.00
0005435426515	10907	Comfort	24400.00
0005432166982	10907	Comfort	24400.00
0005435426505	10907	Comfort	24400.00
0005435426486	10907	Comfort	24400.00
0005435426506	10907	Comfort	24400.00
0005435615596	10907	Comfort	24400.00
0005435426512	10907	Comfort	24400.00
0005435097284	10907	Comfort	24400.00
0005432841065	10907	Comfort	24400.00
0005435615478	10907	Comfort	24400.00
0005435426473	10907	Comfort	24400.00
0005435426472	10907	Comfort	24400.00
0005435305055	10907	Comfort	24400.00
0005435426487	10907	Comfort	24400.00
0005435426525	10907	Comfort	24400.00
0005435615591	10907	Comfort	24400.00
0005434573478	10907	Comfort	24400.00
0005435319791	10907	Comfort	24400.00
0005435615016	10907	Comfort	24400.00
0005435615910	10907	Comfort	24400.00
0005435097283	10907	Economy	14400.00
0005435615443	10907	Economy	14400.00
0005435615574	10907	Economy	14400.00
0005434245694	10907	Economy	14400.00
0005435614916	10907	Economy	14400.00
0005435615687	10907	Economy	14400.00
0005435615015	10907	Economy	14400.00
0005435615635	10907	Economy	14400.00
0005435615269	10907	Economy	14400.00
0005433719225	10907	Economy	14400.00
0005434573588	10907	Economy	14400.00
0005434573580	10907	Economy	14400.00
0005435426482	10907	Economy	14400.00
0005435319790	10907	Economy	14400.00
0005435426528	10907	Economy	14400.00
0005435615105	10907	Economy	14400.00
0005435426496	10907	Economy	14400.00
0005434344712	10907	Economy	14400.00
0005434344846	10907	Economy	14400.00
0005435426495	10907	Economy	14400.00
0005435426526	10907	Economy	14400.00
0005435615782	10907	Economy	14400.00
0005435615322	10907	Economy	14400.00
0005434245709	10907	Economy	14400.00
0005435319789	10907	Economy	14400.00
0005435616219	10907	Economy	14400.00
0005435426478	10907	Economy	14400.00
0005435426523	10907	Economy	14400.00
0005435426518	10907	Economy	14400.00
0005435615116	10907	Economy	14400.00
0005435615097	10907	Economy	14400.00
0005434344673	10907	Economy	14400.00
0005435615296	10907	Economy	14400.00
0005435615465	10907	Economy	14400.00
0005435615541	10907	Economy	14400.00
0005432165229	10907	Economy	14400.00
0005435042921	10907	Economy	14400.00
0005434344655	10907	Economy	14400.00
0005435305057	10907	Economy	14400.00
0005435555396	10907	Economy	14400.00
0005435491471	10907	Economy	14400.00
0005435426524	10907	Economy	14400.00
0005435615973	10907	Economy	14400.00
0005435426493	10907	Economy	14400.00
0005435097301	10907	Economy	14400.00
0005434245710	10907	Economy	14400.00
0005435615397	10907	Economy	14400.00
0005435426509	10907	Economy	14400.00
0005435615066	10907	Economy	14400.00
0005435615351	10907	Economy	14400.00
0005435304251	10907	Economy	14400.00
0005435768107	10907	Economy	14400.00
0005434245693	10907	Economy	14400.00
0005432165225	10907	Economy	14400.00
0005434245704	10907	Economy	14400.00
0005435615715	10907	Economy	14400.00
0005434573539	10907	Economy	14400.00
0005435615696	10907	Economy	14400.00
0005432165223	10907	Economy	14400.00
0005435615714	10907	Economy	14400.00
0005435555401	10907	Economy	14400.00
0005435426484	10907	Economy	15800.00
0005435380415	10907	Economy	14400.00
0005435426490	10907	Economy	15800.00
0005435042920	10907	Economy	14400.00
0005434344777	10907	Economy	15800.00
0005435615568	10907	Economy	14400.00
0005434344687	10907	Economy	14400.00
0005435426532	10907	Economy	14400.00
0005435615261	10907	Economy	15800.00
0005434573556	10907	Economy	14400.00
0005432165226	10907	Economy	14400.00
0005435426499	10907	Economy	14400.00
0005434344753	10907	Economy	14400.00
0005435615545	10907	Economy	14400.00
0005432166981	10907	Economy	14400.00
0005435319794	10907	Economy	14400.00
0005435426481	10907	Economy	14400.00
0005435615203	10907	Economy	14400.00
0005435615481	10907	Economy	14400.00
0005435615569	10907	Economy	14400.00
0005434344713	10907	Economy	14400.00
0005434344754	10907	Economy	14400.00
0005435426501	10907	Economy	14400.00
0005435426494	10907	Economy	14400.00
0005435426521	10907	Economy	14400.00
0005435615329	10907	Economy	14400.00
0005432841064	10907	Economy	14400.00
0005434245696	10907	Economy	14400.00
0005435615444	10907	Economy	14400.00
0005435615379	10907	Economy	14400.00
0005435426485	10907	Economy	14400.00
0005435426498	10907	Economy	14400.00
0005434344654	10907	Economy	14400.00
0005435304249	10907	Economy	14400.00
0005434573579	10907	Economy	14400.00
0005432165227	10907	Economy	14400.00
0005435615615	10907	Economy	14400.00
0005435491477	10907	Economy	14400.00
0005434573596	10907	Economy	14400.00
0005435615739	10907	Economy	14400.00
0005435097350	10907	Economy	14400.00
0005435426516	10907	Economy	14400.00
0005435555402	10907	Economy	14400.00
0005435768106	10907	Economy	14400.00
0005434344696	10907	Economy	14400.00
0005435615556	10907	Economy	14400.00
0005435615270	10907	Economy	14400.00
0005435426500	10907	Economy	14400.00
0005435615499	10907	Economy	14400.00
0005435615611	10907	Economy	14400.00
0005435491472	10907	Economy	14400.00
0005435426511	10907	Economy	14400.00
0005434245713	10907	Economy	14400.00
0005435614953	10907	Economy	14400.00
0005434344727	10907	Economy	14400.00
0005433719224	10907	Economy	14400.00
0005435615104	10907	Economy	14400.00
0005435614893	10907	Economy	14400.00
0005435615648	10907	Economy	14400.00
0005435426475	10907	Economy	14400.00
0005435615726	10907	Economy	14400.00
0005435490289	10907	Economy	14400.00
0005435615557	10907	Economy	14400.00
0005435555395	10907	Economy	14400.00
0005435615646	10907	Economy	14400.00
0005435614562	10907	Economy	14400.00
0005435615141	10907	Economy	14400.00
0005434344656	10907	Economy	14400.00
0005435426479	10907	Economy	14400.00
0005435614669	10907	Economy	14400.00
0005435615821	10907	Economy	14400.00
0005435490288	10907	Economy	14400.00
0005435426527	10907	Economy	14400.00
0005435304248	10907	Economy	14400.00
0005435426517	10907	Economy	14400.00
0005435615477	10907	Economy	14400.00
0005435768103	10907	Economy	14400.00
0005434344809	10907	Economy	14400.00
0005435615480	10907	Economy	14400.00
0005435615437	10907	Economy	14400.00
0005434245716	10907	Economy	14400.00
0005435319788	10907	Economy	14400.00
0005435380416	10907	Economy	14400.00
0005435615724	10907	Economy	14400.00
0005435615049	10907	Economy	14400.00
0005434245692	10907	Economy	14400.00
0005434344776	10907	Economy	14400.00
0005435426503	10907	Economy	14400.00
0005435615416	10907	Economy	14400.00
0005435097349	10907	Economy	14400.00
0005434245717	10907	Economy	14400.00
0005434573607	10907	Economy	14400.00
0005433719226	10907	Economy	14400.00
0005434245702	10907	Economy	14400.00
0005435305058	10907	Economy	14400.00
0005435615445	10907	Economy	14400.00
0005435615570	10907	Economy	14400.00
0005434344802	10907	Economy	14400.00
0005434245691	10907	Economy	14400.00
0005434344845	10907	Economy	14400.00
0005435615708	10907	Economy	14400.00
0005435615065	10907	Economy	14400.00
0005435615268	10907	Economy	14400.00
0005435615720	10907	Economy	14400.00
0005435615253	10907	Economy	15800.00
0005434245715	10907	Economy	15800.00
0005434573581	10907	Economy	15800.00
0005435426469	10907	Economy	15800.00
0005435615542	10907	Economy	15800.00
0005435615612	10907	Economy	15800.00
0005435615498	10907	Economy	14400.00
0005434245706	10907	Economy	14400.00
0005435615401	10907	Economy	14400.00
0005435615241	10907	Economy	14400.00
0005434344681	10907	Economy	14400.00
0005435615702	10907	Economy	14400.00
0005435614670	10907	Economy	14400.00
0005432165222	10907	Economy	14400.00
0005435615616	10907	Economy	14400.00
0005434573470	10907	Economy	14400.00
0005435614561	10907	Economy	14400.00
0005435042918	10907	Economy	14400.00
0005435615617	10907	Economy	14400.00
0005435615335	10907	Economy	14400.00
0005435426514	10907	Economy	14400.00
0005435615673	10907	Economy	14400.00
0005435426471	10907	Economy	14400.00
0005435615218	10907	Economy	14400.00
0005435615464	10907	Economy	14400.00
0005435426497	10907	Economy	14400.00
0005435615820	10907	Economy	14400.00
0005435617236	10907	Economy	14400.00
0005435615002	10907	Economy	14400.00
0005435042919	10907	Economy	14400.00
0005435614900	10907	Economy	14400.00
0005435426513	10907	Economy	14400.00
0005435615707	10907	Economy	14400.00
0005435426467	10907	Economy	14400.00
0005435319792	10907	Economy	14400.00
0005435426529	10907	Economy	14400.00
0005435615328	10907	Economy	14400.00
0005435615595	10907	Economy	14400.00
0005435768108	10907	Economy	14400.00
0005434344682	10907	Economy	14400.00
0005435426510	10907	Economy	14400.00
0005434344831	10907	Economy	14400.00
0005435319787	10907	Economy	14400.00
0005435426468	10907	Economy	14400.00
0005434573538	10907	Economy	14400.00
0005434344695	10907	Economy	14400.00
0005435615323	10907	Economy	14400.00
0005435768105	10907	Economy	14400.00
0005435426530	10907	Economy	14400.00
0005434344674	10907	Economy	14400.00
0005435615738	10907	Economy	14400.00
0005435426476	10907	Economy	14400.00
0005434245697	10907	Economy	14400.00
0005435490290	10907	Economy	14400.00
0005435426488	10907	Economy	14400.00
0005435426504	10907	Economy	14400.00
0005434245695	10907	Economy	14400.00
0005435615656	10907	Economy	14400.00
0005435304250	10907	Economy	14400.00
0005432165228	10907	Economy	14400.00
0005434344679	10907	Economy	14400.00
0005435305056	10907	Economy	14400.00
0005435426522	10907	Economy	14400.00
0005435615990	10907	Economy	14400.00
0005435426519	10907	Economy	14400.00
0005434573471	10907	Economy	14400.00
0005434573606	10907	Economy	14400.00
0005434344728	10907	Economy	14400.00
0005435042917	10907	Economy	14400.00
0005435097359	10907	Economy	14400.00
0005434245703	10907	Economy	14400.00
0005435614537	10907	Economy	14400.00
0005435615048	10907	Economy	14400.00
0005432165224	10907	Economy	14400.00
0005435615638	10907	Economy	14400.00
0005434344770	10907	Economy	14400.00
0005434245714	10907	Economy	14400.00
0005434344803	10907	Economy	14400.00
0005435426474	10907	Economy	14400.00
0005435426470	10907	Economy	14400.00
0005435615188	10907	Economy	14400.00
0005435426520	10907	Economy	14400.00
0005434344699	10907	Economy	14400.00
0005434245708	10907	Economy	14400.00
0005435615614	10907	Economy	14400.00
0005435426480	10907	Economy	14400.00
0005435615590	10907	Economy	14400.00
0005435615202	10907	Economy	14400.00
0005434656606	10907	Economy	14400.00
0005434344750	10907	Economy	14400.00
0005435768104	10907	Economy	14400.00
0005434245701	10907	Economy	14400.00
0005434656605	10907	Economy	14400.00
0005435615725	10907	Economy	14400.00
0005434245699	10907	Economy	14400.00
0005435304252	10907	Economy	14400.00
0005435615162	10907	Economy	14400.00
0005435426477	10907	Economy	14400.00
0005434344847	10907	Economy	14400.00
0005434344603	10907	Economy	14400.00
0005435616218	10907	Economy	14400.00
0005434245711	10907	Economy	14400.00
0005435615123	10907	Economy	14400.00
0005435615453	10907	Economy	14400.00
0005435426502	10907	Economy	14400.00
0005434344810	10907	Economy	14400.00
0005434344755	10907	Economy	14400.00
0005433507634	3279	Business	18800.00
0005432460567	3279	Business	18800.00
0005432182271	3279	Business	18800.00
0005433634666	3279	Business	18800.00
0005433507623	3279	Business	18800.00
0005433806217	3279	Business	18800.00
0005432182266	3279	Business	18800.00
0005433634660	3279	Business	18800.00
0005432182261	3279	Business	18800.00
0005432460757	3279	Business	18800.00
0005432460694	3279	Business	18800.00
0005432460821	3279	Business	18800.00
0005432460668	3279	Business	18800.00
0005433806210	3279	Business	18800.00
0005432460568	3279	Business	18800.00
0005433507636	3279	Business	18800.00
0005433507625	3279	Business	18800.00
0005433806213	3279	Business	18800.00
0005433507644	3279	Business	18800.00
0005433634668	3279	Business	18800.00
0005433806240	3279	Business	18800.00
0005432460878	3279	Business	18800.00
0005433806239	3279	Business	18800.00
0005432182276	3279	Business	18800.00
0005432182264	3279	Business	18800.00
0005433634659	3279	Business	18800.00
0005432182259	3279	Business	18800.00
0005433806244	3279	Economy	6900.00
0005433634653	3279	Business	18800.00
0005432460498	3279	Economy	6900.00
0005432182270	3279	Economy	6900.00
0005433507626	3279	Economy	6900.00
0005433507638	3279	Economy	6900.00
0005432182265	3279	Economy	6900.00
0005433806220	3279	Economy	6300.00
0005432460847	3279	Economy	6300.00
0005433634662	3279	Economy	6300.00
0005433634651	3279	Economy	6300.00
0005432460755	3279	Economy	6300.00
0005433806207	3279	Economy	6300.00
0005432460811	3279	Economy	6300.00
0005433806222	3279	Economy	6300.00
0005433806215	3279	Economy	6300.00
0005433507631	3279	Economy	6300.00
0005432460473	3279	Economy	6300.00
0005433634656	3279	Economy	6300.00
0005432182254	3279	Economy	6300.00
0005432182269	3279	Economy	6300.00
0005433806214	3279	Economy	6300.00
0005433806227	3279	Economy	6300.00
0005432460879	3279	Economy	6300.00
0005433806219	3279	Economy	6300.00
0005432460603	3279	Economy	6300.00
0005432182275	3279	Economy	6300.00
0005433634663	3279	Economy	6300.00
0005432182256	3279	Economy	6300.00
0005432182272	3279	Economy	6300.00
0005432182262	3279	Economy	6300.00
0005433806245	3279	Economy	6300.00
0005432460618	3279	Economy	6300.00
0005432460689	3279	Economy	6300.00
0005433634670	3279	Economy	6300.00
0005433806233	3279	Economy	6300.00
0005432460703	3279	Economy	6300.00
0005433507642	3279	Economy	6300.00
0005432460814	3279	Economy	6300.00
0005432460812	3279	Economy	6300.00
0005432460692	3279	Economy	6300.00
0005433634665	3279	Economy	6300.00
0005433634675	3279	Economy	6300.00
0005433806211	3279	Economy	6300.00
0005432182268	3279	Economy	6300.00
0005433507630	3279	Economy	6300.00
0005433806238	3279	Economy	6300.00
0005433634646	3279	Economy	6300.00
0005432460472	3279	Economy	6300.00
0005433806242	3279	Economy	6300.00
0005433634644	3279	Economy	6300.00
0005433806216	3279	Economy	6300.00
0005432460614	3279	Economy	6300.00
0005433806225	3279	Economy	6300.00
0005433806229	3279	Economy	6300.00
0005433634674	3279	Economy	6300.00
0005433806234	3279	Economy	6300.00
0005432460864	3279	Economy	6300.00
0005432460756	3279	Economy	6300.00
0005432460538	3279	Economy	6300.00
0005433507643	3279	Economy	6300.00
0005433634669	3279	Economy	6300.00
0005433634673	3279	Economy	6300.00
0005432460754	3279	Economy	6300.00
0005433806209	3279	Economy	6300.00
0005432182257	3279	Economy	6300.00
0005433634643	3279	Economy	6900.00
0005433507639	3279	Economy	6900.00
0005433507624	3279	Economy	6900.00
0005432460604	3279	Economy	6900.00
0005432460702	3279	Economy	6900.00
0005432182267	3279	Economy	6300.00
0005433806237	3279	Economy	6300.00
0005432182263	3279	Economy	6300.00
0005433507629	3279	Economy	6900.00
0005433806243	3279	Economy	6300.00
0005432460499	3279	Economy	6300.00
0005432460606	3279	Economy	6300.00
0005432460781	3279	Economy	6300.00
0005432460500	3279	Economy	6300.00
0005433634647	3279	Economy	6300.00
0005433806221	3279	Economy	6300.00
0005432182273	3279	Economy	6300.00
0005433634642	3279	Economy	6300.00
0005432182255	3279	Economy	6300.00
0005433634664	3279	Economy	6300.00
0005432182258	3279	Economy	6300.00
0005432182274	3279	Economy	6300.00
0005433634652	3279	Economy	6300.00
0005433806230	3279	Economy	6300.00
0005433634657	3279	Economy	6300.00
0005433507633	3279	Economy	6300.00
0005432460684	3279	Economy	6300.00
0005433806228	3279	Economy	6300.00
0005432460743	3279	Economy	6300.00
0005433806226	3279	Economy	6300.00
0005433634661	3279	Economy	6300.00
0005433634649	3279	Economy	6300.00
0005432460524	3279	Economy	6300.00
0005433634667	3279	Economy	6300.00
0005433507637	3279	Economy	6300.00
0005433634654	3279	Economy	6300.00
0005432460605	3279	Economy	6300.00
0005432460721	3279	Economy	6300.00
0005432460525	3279	Economy	6300.00
0005433806241	3279	Economy	6300.00
0005433507640	3279	Economy	6300.00
0005432460713	3279	Economy	6300.00
0005432460697	3279	Economy	6300.00
0005432460556	3279	Economy	6300.00
0005433507641	3279	Economy	6300.00
0005433634645	3279	Economy	6300.00
0005433634648	3279	Economy	6300.00
0005433634658	3279	Economy	6300.00
0005433806208	3279	Economy	6300.00
0005432460753	3279	Economy	6300.00
0005433507628	3279	Economy	6300.00
0005432460822	3279	Economy	6300.00
0005433634672	3279	Economy	6300.00
0005433634676	3279	Economy	6300.00
0005432460660	3279	Economy	6300.00
0005433634671	3279	Economy	6300.00
0005432182260	3279	Economy	6300.00
0005433806236	3279	Economy	6300.00
0005433507632	3279	Economy	6300.00
0005432460744	3279	Economy	6300.00
0005433806218	3279	Economy	6300.00
0005433507635	3279	Economy	6300.00
0005433507627	3279	Economy	6300.00
0005433806231	3279	Economy	6300.00
0005433806223	3279	Economy	6300.00
0005432460652	3279	Economy	6300.00
0005432460782	3279	Economy	6300.00
0005433806224	3279	Economy	6300.00
0005433806212	3279	Economy	6300.00
0005433634650	3279	Economy	6300.00
0005433634655	3279	Economy	6300.00
0005432460680	3279	Economy	6300.00
0005433806235	3279	Economy	6300.00
0005433806232	3279	Economy	6300.00
0005433806246	3279	Economy	6300.00
0005432460733	3279	Economy	6300.00
0005435886190	3280	Business	18800.00
0005435886072	3280	Business	18800.00
0005435886195	3280	Business	18800.00
0005435886305	3280	Business	18800.00
0005435886094	3280	Business	18800.00
0005435886002	3280	Business	18800.00
0005435885918	3280	Business	18800.00
0005435886042	3280	Business	18800.00
0005435885986	3280	Business	18800.00
0005435886149	3280	Economy	6900.00
0005435885741	3280	Economy	6900.00
0005435886240	3280	Economy	6300.00
0005435885954	3280	Economy	6300.00
0005435886080	3280	Economy	6300.00
0005435886225	3280	Economy	6300.00
0005435886071	3280	Economy	6300.00
0005435885985	3280	Economy	6300.00
0005435886025	3280	Economy	6300.00
0005435886257	3280	Economy	6300.00
0005435886125	3280	Economy	6300.00
0005435885993	3280	Economy	6300.00
0005435886220	3280	Economy	6300.00
0005435885956	3280	Economy	6300.00
0005435886144	3280	Economy	6300.00
0005435886182	3280	Economy	6900.00
0005435886262	3280	Economy	6300.00
0005435885742	3280	Economy	6300.00
0005435885948	3280	Economy	6300.00
0005435886065	3280	Economy	6300.00
0005435886226	3280	Economy	6300.00
0005435886222	3280	Economy	6300.00
0005435886054	3280	Economy	6300.00
0005435886038	3280	Economy	6300.00
0005435886198	3280	Economy	6300.00
0005435886088	3280	Economy	6300.00
0005435886223	3280	Economy	6300.00
0005435886278	3280	Economy	6300.00
0005435886303	3280	Economy	6300.00
0005435886022	3280	Economy	6300.00
0005435886191	3280	Economy	6300.00
0005435885947	3280	Economy	6300.00
0005435886079	3280	Economy	6300.00
0005435886070	3280	Economy	6300.00
0005435886221	3280	Economy	6300.00
0005432461172	8303	Business	18800.00
0005435886435	8303	Business	18800.00
0005432043057	8303	Business	18800.00
0005435886475	8303	Business	18800.00
0005432461155	8303	Business	18800.00
0005435886424	8303	Business	18800.00
0005435886438	8303	Business	18800.00
0005435886457	8303	Business	18800.00
0005435886420	8303	Business	18800.00
0005432043053	8303	Business	18800.00
0005435886454	8303	Business	18800.00
0005433507467	8303	Business	18800.00
0005434326095	8303	Business	18800.00
0005433507456	8303	Business	18800.00
0005435886458	8303	Business	18800.00
0005435886441	8303	Business	18800.00
0005432461174	8303	Business	18800.00
0005435886439	8303	Business	18800.00
0005435886431	8303	Business	18800.00
0005432461150	8303	Business	18800.00
0005433507493	8303	Business	18800.00
0005432461148	8303	Business	18800.00
0005435886453	8303	Business	18800.00
0005432043062	8303	Business	18800.00
0005432461192	8303	Business	18800.00
0005435886416	8303	Business	18800.00
0005435886427	8303	Business	18800.00
0005432461160	8303	Economy	6900.00
0005432461190	8303	Economy	6900.00
0005432461188	8303	Economy	6900.00
0005432461153	8303	Economy	6900.00
0005432461157	8303	Economy	6300.00
0005435886462	8303	Economy	6300.00
0005435886451	8303	Economy	6300.00
0005432461164	8303	Economy	6300.00
0005432461165	8303	Economy	6300.00
0005435886450	8303	Economy	6300.00
0005432043063	8303	Economy	6300.00
0005432461197	8303	Economy	6300.00
0005432461149	8303	Economy	6300.00
0005432461168	8303	Economy	6300.00
0005435886444	8303	Economy	6300.00
0005432461184	8303	Economy	6300.00
0005432461166	8303	Economy	6300.00
0005432043065	8303	Economy	6300.00
0005432043052	8303	Economy	6300.00
0005435886415	8303	Economy	6300.00
0005432043059	8303	Economy	6300.00
0005432461194	8303	Economy	6300.00
0005435886463	8303	Economy	6300.00
0005435886473	8303	Economy	6300.00
0005435886448	8303	Economy	6300.00
0005435886464	8303	Economy	6300.00
0005435142989	8303	Economy	6300.00
0005432461175	8303	Economy	6300.00
0005432461185	8303	Economy	6300.00
0005435886447	8303	Economy	6300.00
0005432043056	8303	Economy	6300.00
0005435886430	8303	Economy	6300.00
0005432461162	8303	Economy	6300.00
0005432043060	8303	Economy	6300.00
0005435886425	8303	Economy	6300.00
0005435886429	8303	Economy	6300.00
0005432461183	8303	Economy	6300.00
0005435886414	8303	Economy	6300.00
0005435886440	8303	Economy	6300.00
0005435886422	8303	Economy	6300.00
0005432461171	8303	Economy	6300.00
0005432043055	8303	Economy	6300.00
0005432461156	8303	Economy	6300.00
0005433507419	8303	Economy	6300.00
0005435886460	8303	Economy	6300.00
0005435886432	8303	Economy	6300.00
0005435886455	8303	Economy	6300.00
0005432461179	8303	Economy	6300.00
0005435886419	8303	Economy	6300.00
0005433507462	8303	Economy	6300.00
0005432461178	8303	Economy	6300.00
0005432461161	8303	Economy	6300.00
0005434326288	8303	Economy	6300.00
0005435886466	8303	Economy	6900.00
0005435886423	8303	Economy	6900.00
0005433507468	8303	Economy	6300.00
0005433507441	8303	Economy	6300.00
0005432043054	8303	Economy	6300.00
0005435886442	8303	Economy	6300.00
0005433507391	8303	Economy	6900.00
0005432461177	8303	Economy	6300.00
0005435886443	8303	Economy	6300.00
0005432043064	8303	Economy	6300.00
0005433507420	8303	Economy	6300.00
0005434312390	8303	Economy	6300.00
0005432461186	8303	Economy	6300.00
0005432461158	8303	Economy	6300.00
0005435886418	8303	Economy	6300.00
0005435886461	8303	Economy	6300.00
0005432461170	8303	Economy	6300.00
0005435886434	8303	Economy	6300.00
0005434312389	8303	Economy	6300.00
0005433507390	8303	Economy	6300.00
0005435886452	8303	Economy	6300.00
0005432461169	8303	Economy	6300.00
0005432461189	8303	Economy	6300.00
0005434312372	8303	Economy	6300.00
0005432461154	8303	Economy	6300.00
0005435886437	8303	Economy	6300.00
0005432461167	8303	Economy	6300.00
0005432461151	8303	Economy	6300.00
0005435886470	8303	Economy	6300.00
0005435886449	8303	Economy	6300.00
0005435142990	8303	Economy	6300.00
0005435886465	8303	Economy	6300.00
0005432461163	8303	Economy	6300.00
0005435886421	8303	Economy	6300.00
0005435886476	8303	Economy	6300.00
0005432461196	8303	Economy	6300.00
0005435886426	8303	Economy	6300.00
0005435886469	8303	Economy	6300.00
0005435886417	8303	Economy	6300.00
0005435886446	8303	Economy	6300.00
0005432043061	8303	Economy	6300.00
0005435886433	8303	Economy	6300.00
0005435142988	8303	Economy	6300.00
0005432043058	8303	Economy	6300.00
0005435886436	8303	Economy	6300.00
0005432461193	8303	Economy	6300.00
0005435886456	8303	Economy	6300.00
0005432461182	8303	Economy	6300.00
0005432461180	8303	Economy	6300.00
0005435886474	8303	Economy	6300.00
0005435886459	8303	Economy	6300.00
0005432461152	8303	Economy	6300.00
0005435886468	8303	Economy	6300.00
0005432461187	8303	Economy	6300.00
0005435886467	8303	Economy	6300.00
0005435886428	8303	Economy	6300.00
0005432461181	8303	Economy	6300.00
0005432461159	8303	Economy	6300.00
0005435886471	8303	Economy	6300.00
0005432461176	8303	Economy	6300.00
0005435886445	8303	Economy	6300.00
0005433507470	8303	Economy	6300.00
0005432461173	8303	Economy	6300.00
0005432461191	8303	Economy	6300.00
0005435886472	8303	Economy	6300.00
0005432461195	8303	Economy	6300.00
0005433634317	8230	Business	18800.00
0005433634269	8230	Business	18800.00
0005433634284	8230	Business	18800.00
0005433805879	8230	Business	18800.00
0005433805809	8230	Business	18800.00
0005433634318	8230	Business	18800.00
0005433805832	8230	Business	18800.00
0005435858709	8230	Business	18800.00
0005433805908	8230	Business	18800.00
0005433805836	8230	Business	18800.00
0005435858703	8230	Business	18800.00
0005435858704	8230	Business	18800.00
0005433805899	8230	Business	18800.00
0005433805927	8230	Business	18800.00
0005435858702	8230	Business	18800.00
0005435860666	8230	Business	18800.00
0005435860660	8230	Economy	6900.00
0005433805864	8230	Economy	6900.00
0005433805960	8230	Economy	6900.00
0005433805808	8230	Economy	6900.00
0005433805925	8230	Economy	6300.00
0005433805920	8230	Economy	6300.00
0005433634237	8230	Economy	6300.00
0005433634238	8230	Economy	6300.00
0005433634312	8230	Economy	6300.00
0005433634228	8230	Economy	6300.00
0005433634354	8230	Economy	6300.00
0005435860664	8230	Economy	6300.00
0005433634282	8230	Economy	6300.00
0005435860663	8230	Economy	6300.00
0005433634145	8230	Economy	6300.00
0005433805926	8230	Economy	6300.00
0005433634327	8230	Economy	6300.00
0005433634425	8230	Economy	6300.00
0005433634319	8230	Economy	6300.00
0005433805979	8230	Economy	6300.00
0005433805881	8230	Economy	6300.00
0005433805801	8230	Economy	6300.00
0005433805969	8230	Economy	6300.00
0005433634409	8230	Economy	6300.00
0005433634229	8230	Economy	6300.00
0005433805882	8230	Economy	6300.00
0005435858701	8230	Economy	6300.00
0005433805843	8230	Economy	6300.00
0005433806053	8230	Economy	6300.00
0005433805880	8230	Economy	6300.00
0005435860661	8230	Economy	6300.00
0005433634422	8230	Economy	6300.00
0005435860665	8230	Economy	6300.00
0005433805988	8230	Economy	6300.00
0005435860659	8230	Economy	6300.00
0005433634289	8230	Economy	6300.00
0005433634423	8230	Economy	6300.00
0005433634245	8230	Economy	6300.00
0005433634273	8230	Economy	6300.00
0005433805831	8230	Economy	6300.00
0005433806028	8230	Economy	6300.00
0005433634385	8230	Economy	6300.00
0005433634236	8230	Economy	6300.00
0005433806027	8230	Economy	6300.00
0005433805846	8230	Economy	6300.00
0005435858706	8230	Economy	6900.00
0005433634386	8230	Economy	6900.00
0005433634308	8230	Economy	6900.00
0005434271339	8230	Economy	6300.00
0005433805970	8230	Economy	6300.00
0005433634353	8230	Economy	6300.00
0005435858707	8230	Economy	6300.00
0005433634288	8230	Economy	6300.00
0005433634280	8230	Economy	6300.00
0005433806123	8230	Economy	6300.00
0005433805900	8230	Economy	6300.00
0005433634486	8230	Economy	6300.00
0005434143744	8230	Economy	6300.00
0005433805938	8230	Economy	6300.00
0005433805968	8230	Economy	6300.00
0005433805921	8230	Economy	6300.00
0005433805840	8230	Economy	6300.00
0005435858708	8230	Economy	6300.00
0005433805784	8230	Economy	6300.00
0005433634378	8230	Economy	6300.00
0005433805875	8230	Economy	6300.00
0005433634337	8230	Economy	6300.00
0005433805919	8230	Economy	6300.00
0005433805839	8230	Economy	6300.00
0005435858705	8230	Economy	6300.00
0005435860662	8230	Economy	6300.00
0005433634362	8230	Economy	6300.00
0005433634424	8230	Economy	6300.00
0005433805956	8230	Economy	6300.00
0005433634297	8230	Economy	6300.00
0005433805863	8230	Economy	6300.00
0005433805961	8230	Economy	6300.00
0005433634328	8230	Economy	6300.00
0005433805915	8230	Economy	6300.00
0005433805954	8230	Economy	6300.00
0005434271343	8230	Economy	6300.00
0005433805830	8230	Economy	6300.00
0005433634311	8230	Economy	6300.00
0005433634413	8230	Economy	6300.00
0005434183614	8302	Economy	6300.00
0005433453810	4577	Business	9900.00
0005432728251	4577	Business	9900.00
0005433722381	4577	Business	9900.00
0005432384153	4577	Business	9900.00
0005432384157	4577	Business	9900.00
0005432384139	4577	Business	9900.00
0005432384119	4577	Business	9900.00
0005432728242	4577	Business	9900.00
0005432728243	4577	Business	9900.00
0005433454927	4577	Economy	3300.00
0005432728240	4577	Economy	3300.00
0005432384125	4577	Economy	3300.00
0005432384131	4577	Economy	3300.00
0005433722387	4577	Economy	3300.00
0005432384128	4577	Economy	3300.00
0005432728249	4577	Economy	3300.00
0005432384155	4577	Economy	3300.00
0005432384122	4577	Economy	3600.00
0005433722383	4577	Economy	3600.00
0005432384149	4577	Economy	3600.00
0005432384160	4577	Economy	3600.00
0005432384137	4577	Economy	3300.00
0005432384134	4577	Economy	3300.00
0005432384147	4577	Economy	3300.00
0005432384133	4577	Economy	3300.00
0005432384130	4577	Economy	3300.00
0005432384124	4577	Economy	3300.00
0005432384136	4577	Economy	3300.00
0005432728247	4577	Economy	3300.00
0005432384148	4577	Economy	3300.00
0005432384156	4577	Economy	3300.00
0005432384126	4577	Economy	3300.00
0005432728252	4577	Economy	3300.00
0005432728245	4577	Economy	3300.00
0005433722380	4577	Economy	3300.00
0005432384141	4577	Economy	3300.00
0005432384121	4577	Economy	3300.00
0005432384152	4577	Economy	3300.00
0005433722382	4577	Economy	3300.00
0005432384150	4577	Economy	3300.00
0005432384158	4577	Economy	3300.00
0005432728250	4577	Economy	3300.00
0005433722385	4577	Economy	3300.00
0005432384140	4577	Economy	3300.00
0005432384123	4577	Economy	3300.00
0005432384127	4577	Economy	3300.00
0005432384144	4577	Economy	3300.00
0005432384145	4577	Economy	3300.00
0005432384135	4577	Economy	3300.00
0005432384142	4577	Economy	3300.00
0005432728248	4577	Economy	3300.00
0005433454928	4577	Economy	3300.00
0005433722386	4577	Economy	3300.00
0005432728241	4577	Economy	3300.00
0005433453811	4577	Economy	3300.00
0005432384154	4577	Economy	3300.00
0005432384138	4577	Economy	3300.00
0005432384143	4577	Economy	3300.00
0005432384129	4577	Economy	3300.00
0005432384159	4577	Economy	3300.00
0005432384117	4577	Economy	3300.00
0005433722384	4577	Economy	3300.00
0005432384132	4577	Economy	3300.00
0005433722390	4577	Economy	3300.00
0005432384146	4577	Economy	3300.00
0005432384120	4577	Economy	3300.00
0005432728244	4577	Economy	3300.00
0005433722389	4577	Economy	3300.00
0005432728246	4577	Economy	3300.00
0005432384118	4577	Economy	3300.00
0005433722388	4577	Economy	3300.00
0005432384151	4577	Economy	3300.00
0005432383705	30200	Business	9900.00
0005432728095	30200	Business	9900.00
0005432383679	30200	Business	9900.00
0005432383773	30200	Business	9900.00
0005432728134	30200	Business	9900.00
0005432383711	30200	Business	9900.00
0005432383666	30200	Business	9900.00
0005433722287	30200	Business	9900.00
0005432383611	30200	Business	9900.00
0005433451652	30200	Economy	3300.00
0005433194899	30200	Economy	3300.00
0005432383694	30200	Economy	3300.00
0005432383656	30200	Economy	3300.00
0005432383701	30200	Economy	3300.00
0005432383563	30200	Economy	3600.00
0005432383624	30200	Economy	3600.00
0005432728127	30200	Economy	3600.00
0005432383571	30200	Economy	3600.00
0005432383636	30200	Economy	3600.00
0005432383803	30200	Economy	3300.00
0005432383684	30200	Economy	3300.00
0005432728147	30200	Economy	3300.00
0005432728135	30200	Economy	3300.00
0005433722301	30200	Economy	3300.00
0005432383588	30200	Economy	3300.00
0005432383623	30200	Economy	3300.00
0005432383695	30200	Economy	3300.00
0005432383557	30200	Economy	3300.00
0005433453789	30200	Economy	3300.00
0005433722286	30200	Economy	3300.00
0005433722284	30200	Economy	3300.00
0005432383654	30200	Economy	3300.00
0005432728149	30200	Economy	3300.00
0005432728160	30200	Economy	3300.00
0005433722298	30200	Economy	3300.00
0005433453798	30200	Economy	3300.00
0005432383761	30200	Economy	3300.00
0005432383831	30200	Economy	3300.00
0005432383589	30200	Economy	3300.00
0005432383609	30200	Economy	3300.00
0005432383612	30200	Economy	3300.00
0005432383718	30200	Economy	3300.00
0005433722299	30200	Economy	3300.00
0005432383723	30200	Economy	3300.00
0005432383558	30200	Economy	3300.00
0005432728109	30200	Economy	3300.00
0005433722282	30200	Economy	3300.00
0005432383660	30200	Economy	3300.00
0005433453792	30200	Economy	3300.00
0005432383693	30200	Economy	3300.00
0005432383681	30200	Economy	3300.00
0005432728107	30200	Economy	3300.00
0005432728148	30200	Economy	3300.00
0005433453799	30200	Economy	3300.00
0005432383678	30200	Economy	3300.00
0005433453800	30200	Economy	3300.00
0005432383810	30200	Economy	3300.00
0005432383548	30200	Economy	3300.00
0005432383610	30200	Economy	3300.00
0005433722283	30200	Economy	3300.00
0005432383677	30200	Economy	3300.00
0005432383635	30200	Economy	3300.00
0005432728126	30200	Economy	3300.00
0005432728159	30200	Economy	3300.00
0005433453793	30200	Economy	3300.00
0005432728150	30200	Economy	3300.00
0005432728108	30200	Economy	3300.00
0005432383667	30200	Economy	3300.00
0005435541545	1748	Business	57200.00
0005433517124	1748	Business	57200.00
0005432294546	1748	Business	57200.00
0005435529792	1748	Business	57200.00
0005435530094	1748	Business	57200.00
0005435541540	1748	Business	57200.00
0005435529798	1748	Business	57200.00
0005435541549	1748	Economy	19100.00
0005432294547	1748	Economy	19100.00
0005435530089	1748	Economy	19100.00
0005433517123	1748	Economy	19100.00
0005435529803	1748	Economy	19100.00
0005435530087	1748	Economy	19100.00
0005435529800	1748	Economy	19100.00
0005435529802	1748	Economy	19100.00
0005435529794	1748	Economy	19100.00
0005432925111	1748	Economy	21000.00
0005432925125	1748	Economy	21000.00
0005435541547	1748	Economy	21000.00
0005432925104	1748	Economy	21000.00
0005435530088	1748	Economy	19100.00
0005435529796	1748	Economy	19100.00
0005435529801	1748	Economy	19100.00
0005433517122	1748	Economy	19100.00
0005435541551	1748	Economy	19100.00
0005435530100	1748	Economy	19100.00
0005433517121	1748	Economy	19100.00
0005435541548	1748	Economy	19100.00
0005435530099	1748	Economy	19100.00
0005435530091	1748	Economy	19100.00
0005435530093	1748	Economy	19100.00
0005435541535	1748	Economy	19100.00
0005435530092	1748	Economy	19100.00
0005435529793	1748	Economy	19100.00
0005435530085	1748	Economy	19100.00
0005432925113	1748	Economy	19100.00
0005435529797	1748	Economy	19100.00
0005435530084	1748	Economy	19100.00
0005435529804	1748	Economy	19100.00
0005435541539	1748	Economy	19100.00
0005435529788	1748	Economy	19100.00
0005435530095	1748	Economy	19100.00
0005432925109	1748	Economy	19100.00
0005435529805	1748	Economy	19100.00
0005435530097	1748	Economy	19100.00
0005435529799	1748	Economy	19100.00
0005435530098	1748	Economy	19100.00
0005433517117	1748	Economy	19100.00
0005433517114	1748	Economy	19100.00
0005435541544	1748	Economy	19100.00
0005435530101	1748	Economy	19100.00
0005435541543	1748	Economy	19100.00
0005435530090	1748	Economy	19100.00
0005435541542	1748	Economy	19100.00
0005435530086	1748	Economy	19100.00
0005433517116	1748	Economy	19100.00
0005435541534	1748	Economy	19100.00
0005435529795	1748	Economy	19100.00
0005435541541	1748	Economy	19100.00
0005435529789	1748	Economy	19100.00
0005435541546	1748	Economy	19100.00
0005435529807	1748	Economy	19100.00
0005435541538	1748	Economy	19100.00
0005435529790	1748	Economy	19100.00
0005435529791	1748	Economy	19100.00
0005433517119	1748	Economy	19100.00
0005435529806	1748	Economy	19100.00
0005435541536	1748	Economy	19100.00
0005433517120	1748	Economy	19100.00
0005435541537	1748	Economy	19100.00
0005435541550	1748	Economy	19100.00
0005435541533	1748	Economy	19100.00
0005432925112	1748	Economy	19100.00
0005435530096	1748	Economy	19100.00
0005433517118	1748	Economy	19100.00
0005433517115	1748	Economy	19100.00
0005433517051	22002	Business	57200.00
0005435518241	22002	Business	57200.00
0005432925158	22002	Business	57200.00
0005435541325	22002	Business	57200.00
0005432925155	22002	Business	57200.00
0005435541409	22002	Business	57200.00
0005435541348	22002	Business	57200.00
0005435541278	22002	Business	57200.00
0005435541338	22002	Economy	19100.00
0005435518216	22002	Economy	19100.00
0005435518194	22002	Economy	19100.00
0005435541404	22002	Economy	21000.00
0005433517005	22002	Economy	21000.00
0005432925156	22002	Economy	21000.00
0005435518145	22002	Economy	19100.00
0005435541351	22002	Economy	19100.00
0005433517017	22002	Economy	19100.00
0005435541387	22002	Economy	19100.00
0005435541410	22002	Economy	19100.00
0005435541291	22002	Economy	19100.00
0005435541337	22002	Economy	19100.00
0005435541352	22002	Economy	19100.00
0005435541379	22002	Economy	19100.00
0005433517018	22002	Economy	19100.00
0005435541322	22002	Economy	19100.00
0005435518138	22002	Economy	19100.00
0005435541321	22002	Economy	19100.00
0005435541268	22002	Economy	19100.00
0005435518202	22002	Economy	19100.00
0005435541405	22002	Economy	19100.00
0005435541386	22002	Economy	19100.00
0005435541304	22002	Economy	19100.00
0005435541383	22002	Economy	19100.00
0005432925154	22002	Economy	19100.00
0005435541324	22002	Economy	19100.00
0005433517025	22002	Economy	19100.00
0005433517052	22002	Economy	19100.00
0005435541285	22002	Economy	19100.00
0005433517072	22002	Economy	19100.00
0005435518242	22002	Economy	19100.00
0005433517067	22002	Economy	19100.00
0005435541344	22002	Economy	19100.00
0005435541300	22002	Economy	19100.00
0005435518128	22002	Economy	19100.00
0005435518208	22002	Economy	19100.00
0005432925157	22002	Economy	19100.00
0005435541301	22002	Economy	19100.00
0005435541284	22002	Economy	19100.00
0005433517073	22002	Economy	19100.00
0005435518240	22002	Economy	19100.00
0005435541354	22002	Economy	19100.00
0005432839795	7393	Business	18500.00
0005435253054	7393	Business	18500.00
0005432839805	7393	Business	18500.00
0005432839796	7393	Business	18500.00
0005435252982	7393	Business	18500.00
0005432839806	7393	Business	18500.00
0005434664994	7393	Business	18500.00
0005432841062	7393	Business	18500.00
0005435253003	7393	Business	18500.00
0005435252965	7393	Business	18500.00
0005435252980	7393	Business	18500.00
0005432839808	7393	Business	18500.00
0005435252968	7393	Economy	6200.00
0005434459320	7393	Economy	6200.00
0005432073475	7393	Economy	6200.00
0005435252898	7393	Economy	6200.00
0005434459310	7393	Economy	6200.00
0005435252983	7393	Economy	6200.00
0005432839799	7393	Economy	6200.00
0005435253031	7393	Economy	6200.00
0005435253017	7393	Economy	6200.00
0005432839801	7393	Economy	6200.00
0005432839809	7393	Economy	6800.00
0005432073474	7393	Economy	6800.00
0005432839788	7393	Economy	6800.00
0005432839802	7393	Economy	6800.00
0005434459314	7393	Economy	6800.00
0005435252987	7393	Economy	6200.00
0005434459311	7393	Economy	6200.00
0005434459317	7393	Economy	6200.00
0005435252991	7393	Economy	6200.00
0005432839804	7393	Economy	6200.00
0005432823498	7393	Economy	6200.00
0005434459312	7393	Economy	6200.00
0005435252981	7393	Economy	6200.00
0005434459325	7393	Economy	6200.00
0005432839811	7393	Economy	6200.00
0005432839784	7393	Economy	6200.00
0005432839787	7393	Economy	6200.00
0005435253033	7393	Economy	6200.00
0005435491466	7393	Economy	6200.00
0005432841061	7393	Economy	6200.00
0005435253064	7393	Economy	6200.00
0005435252985	7393	Economy	6200.00
0005432839803	7393	Economy	6200.00
0005432839785	7393	Economy	6200.00
0005434459309	7393	Economy	6200.00
0005432839810	7393	Economy	6200.00
0005434664992	7393	Economy	6200.00
0005434459319	7393	Economy	6200.00
0005432839794	7393	Economy	6200.00
0005434459316	7393	Economy	6200.00
0005432073476	7393	Economy	6200.00
0005434459308	7393	Economy	6200.00
0005432839790	7393	Economy	6200.00
0005434459327	7393	Economy	6200.00
0005434664995	7393	Economy	6200.00
0005432839792	7393	Economy	6200.00
0005435252964	7393	Economy	6200.00
0005435253002	7393	Economy	6200.00
0005435252944	7393	Economy	6200.00
0005434459313	7393	Economy	6200.00
0005435252895	7393	Economy	6200.00
0005434459324	7393	Economy	6200.00
0005434459326	7393	Economy	6200.00
0005435253022	7393	Economy	6200.00
0005435252894	7393	Economy	6200.00
0005432839791	7393	Economy	6200.00
0005432841063	7393	Economy	6200.00
0005435253021	7393	Economy	6200.00
0005432839786	7393	Economy	6200.00
0005434459321	7393	Economy	6200.00
0005435252984	7393	Economy	6200.00
0005432839798	7393	Economy	6200.00
0005432839783	7393	Economy	6200.00
0005435253000	7393	Economy	6200.00
0005435253023	7393	Economy	6200.00
0005432839793	7393	Economy	6200.00
0005434459315	7393	Economy	6200.00
0005435253028	7393	Economy	6200.00
0005432839800	7393	Economy	6200.00
0005435253016	7393	Economy	6200.00
0005432839782	7393	Economy	6200.00
0005434664996	7393	Economy	6200.00
0005435253004	7393	Economy	6200.00
0005434459318	7393	Economy	6200.00
0005432839797	7393	Economy	6200.00
0005432839789	7393	Economy	6200.00
0005434459307	7393	Economy	6200.00
0005435253001	7393	Economy	6200.00
0005435253029	7393	Economy	6200.00
0005434459322	7393	Economy	6200.00
0005435253007	7393	Economy	6200.00
0005432073477	7393	Economy	6200.00
0005434459323	7393	Economy	6200.00
0005432839807	7393	Economy	6200.00
0005435252995	7393	Economy	6200.00
0005435253143	28894	Business	18500.00
0005434459104	28894	Business	18500.00
0005435253139	28894	Business	18500.00
0005434459154	28894	Business	18500.00
0005434459084	28894	Business	18500.00
0005435253142	28894	Business	18500.00
0005432839476	28894	Business	18500.00
0005435253151	28894	Economy	6200.00
0005434459114	28894	Economy	6200.00
0005435253144	28894	Economy	6200.00
0005434665016	28894	Economy	6200.00
0005434459180	28894	Economy	6200.00
0005432839638	28894	Economy	6200.00
0005432839481	28894	Economy	6800.00
0005434459105	28894	Economy	6800.00
0005434459087	28894	Economy	6800.00
0005434459062	28894	Economy	6800.00
0005432841048	28894	Economy	6200.00
0005434459179	28894	Economy	6200.00
0005435253148	28894	Economy	6200.00
0005434459109	28894	Economy	6200.00
0005432001072	28894	Economy	6200.00
0005434459168	28894	Economy	6200.00
0005432839483	28894	Economy	6200.00
0005432839536	28894	Economy	6200.00
0005434665017	28894	Economy	6200.00
0005434665018	28894	Economy	6200.00
0005432839563	28894	Economy	6200.00
0005434459155	28894	Economy	6200.00
0005434459103	28894	Economy	6200.00
0005434459078	28894	Economy	6200.00
0005432839520	28894	Economy	6200.00
0005432839639	28894	Economy	6200.00
0005435253150	28894	Economy	6200.00
0005432839580	28894	Economy	6200.00
0005434459086	28894	Economy	6200.00
0005432839473	28894	Economy	6200.00
0005434459083	28894	Economy	6200.00
0005432839474	28894	Economy	6200.00
0005432841046	28894	Economy	6200.00
0005435253137	28894	Economy	6200.00
0005432839562	28894	Economy	6200.00
0005435253146	28894	Economy	6200.00
0005435253147	28894	Economy	6200.00
0005432839447	28894	Economy	6200.00
0005432839475	28894	Economy	6200.00
0005434459167	28894	Economy	6200.00
0005435253149	28894	Economy	6200.00
0005432839548	28894	Economy	6200.00
0005432841050	28894	Economy	6200.00
0005434459163	28894	Economy	6200.00
0005435253145	28894	Economy	6200.00
0005432839621	28894	Economy	6200.00
0005432839652	28894	Economy	6200.00
0005432839565	28894	Economy	6200.00
0005432839551	28894	Economy	6200.00
0005435491497	28894	Economy	6200.00
0005432839448	28894	Economy	6200.00
0005432839497	28894	Economy	6200.00
0005432839567	28894	Economy	6200.00
0005435253152	28894	Economy	6200.00
0005432839472	28894	Economy	6200.00
0005434459110	28894	Economy	6200.00
0005435491496	28894	Economy	6200.00
0005434459149	28894	Economy	6200.00
0005432839679	28894	Economy	6200.00
0005432839680	28894	Economy	6200.00
0005432839695	28894	Economy	6200.00
0005435253141	28894	Economy	6200.00
0005432839673	28894	Economy	6200.00
0005432839561	28894	Economy	6200.00
0005432001073	28894	Economy	6200.00
0005434459108	28894	Economy	6200.00
0005435253138	28894	Economy	6200.00
0005435253140	28894	Economy	6200.00
0005434276124	8804	Business	145300.00
0005434276123	8804	Business	145300.00
0005434276122	8804	Economy	48400.00
0005435990796	8804	Economy	48400.00
0005435990797	8804	Economy	48400.00
0005435990801	8804	Economy	48400.00
0005435990803	8804	Economy	48400.00
0005434276151	8804	Economy	48400.00
0005435990800	8804	Economy	48400.00
0005435990799	8804	Economy	48400.00
0005434276152	8804	Economy	48400.00
0005434276111	8804	Economy	48400.00
0005435990798	8804	Economy	48400.00
0005434276153	8804	Economy	48400.00
0005435990802	8804	Economy	48400.00
0005434276168	15760	Business	145300.00
0005435990724	15760	Business	145300.00
0005435990731	15760	Business	145300.00
0005434276171	15760	Business	145300.00
0005435990754	15760	Business	145300.00
0005435990751	15760	Economy	48400.00
0005435990713	15760	Economy	48400.00
0005434276170	15760	Economy	48400.00
0005435990753	15760	Economy	48400.00
0005434276166	15760	Economy	48400.00
0005435990714	15760	Economy	48400.00
0005435990723	15760	Economy	48400.00
0005435990718	15760	Economy	48400.00
0005435990771	15760	Economy	48400.00
0005434276167	15760	Economy	48400.00
0005434276169	15760	Economy	48400.00
0005435990752	15760	Economy	48400.00
0005435990719	15760	Economy	48400.00
0005435990749	15760	Economy	48400.00
0005435990712	15760	Economy	48400.00
0005435990770	15760	Economy	48400.00
0005432427192	20636	Economy	15900.00
0005433476928	20636	Economy	14500.00
0005432427195	20636	Economy	14500.00
0005432427191	20636	Economy	14500.00
0005432427196	20636	Economy	14500.00
0005433476918	20636	Economy	14500.00
0005433476917	20636	Economy	14500.00
0005432427194	20636	Economy	14500.00
0005433476927	20636	Economy	14500.00
0005432427190	20636	Economy	14500.00
0005433476939	20636	Economy	14500.00
0005433476923	20636	Economy	14500.00
0005433476926	20636	Economy	14500.00
0005433476940	20636	Economy	14500.00
0005433476925	20636	Economy	14500.00
0005433476922	20636	Economy	14500.00
0005432427193	20636	Economy	14500.00
0005432427181	30862	Economy	14500.00
0005433476942	30862	Economy	14500.00
0005432427185	30862	Economy	14500.00
0005433476944	30862	Economy	14500.00
0005433476943	30862	Economy	14500.00
0005433476945	30862	Economy	14500.00
0005433476946	30862	Economy	14500.00
0005432427171	30862	Economy	14500.00
0005432427173	30862	Economy	14500.00
0005432427172	30862	Economy	14500.00
0005432427186	30862	Economy	14500.00
0005433468450	23833	Economy	13300.00
0005433468440	23833	Economy	13300.00
0005433468519	23833	Economy	12100.00
0005432909413	23833	Economy	12100.00
0005432909416	23833	Economy	12100.00
0005432909411	23833	Economy	12100.00
0005433468452	23833	Economy	12100.00
0005432909412	23833	Economy	12100.00
0005433468439	23833	Economy	12100.00
0005433468448	23833	Economy	12100.00
0005432909409	23833	Economy	12100.00
0005433468438	23833	Economy	12100.00
0005432909415	23833	Economy	12100.00
0005432909417	23833	Economy	12100.00
0005432909418	23833	Economy	12100.00
0005433468481	23833	Economy	12100.00
0005432909419	23833	Economy	12100.00
0005432909410	23833	Economy	12100.00
0005433468479	23833	Economy	12100.00
0005433468478	23833	Economy	12100.00
0005433468491	23833	Economy	12100.00
0005433468451	23833	Economy	12100.00
0005433468462	23833	Economy	12100.00
0005433468472	23833	Economy	12100.00
0005433468485	23833	Economy	12100.00
0005433468474	23833	Economy	12100.00
0005433468410	23833	Economy	12100.00
0005433468487	23833	Economy	12100.00
0005432909414	23833	Economy	12100.00
0005432361529	6402	Business	36600.00
0005432361524	6402	Business	36600.00
0005434149960	6402	Business	36600.00
0005435490290	6402	Business	36600.00
0005432363496	6402	Business	36600.00
0005432361542	6402	Business	36600.00
0005432361538	6402	Business	36600.00
0005432336324	6402	Business	36600.00
0005432361532	6402	Business	36600.00
0005432062362	6402	Business	36600.00
0005435177608	6402	Economy	12200.00
0005435177566	6402	Economy	12200.00
0005432336325	6402	Economy	12200.00
0005434149946	6402	Economy	12200.00
0005432361558	6402	Economy	12200.00
0005432336328	6402	Economy	12200.00
0005435177495	6402	Economy	12200.00
0005432361551	6402	Economy	12200.00
0005432361531	6402	Economy	12200.00
0005432361530	6402	Economy	12200.00
0005435177498	6402	Economy	12200.00
0005432361552	6402	Economy	12200.00
0005435177569	6402	Economy	12200.00
0005432062358	6402	Economy	12200.00
0005435177610	6402	Economy	12200.00
0005435177515	6402	Economy	12200.00
0005432361534	6402	Economy	12200.00
0005435177523	6402	Economy	12200.00
0005432062360	6402	Economy	12200.00
0005432361539	6402	Economy	12200.00
0005432361560	6402	Economy	12200.00
0005432361566	6402	Economy	12200.00
0005435490289	6402	Economy	12200.00
0005435177530	6402	Economy	12200.00
0005432361555	6402	Economy	12200.00
0005435177471	6402	Economy	12200.00
0005432361541	6402	Economy	12200.00
0005435177497	6402	Economy	12200.00
0005432336329	6402	Economy	12200.00
0005432361554	6402	Economy	12200.00
0005432361540	6402	Economy	12200.00
0005435177580	6402	Economy	12200.00
0005432361525	6402	Economy	12200.00
0005432361544	6402	Economy	12200.00
0005434149945	6402	Economy	12200.00
0005432361536	6402	Economy	13400.00
0005432361556	6402	Economy	13400.00
0005432361537	6402	Economy	13400.00
0005432361559	6402	Economy	13400.00
0005432361535	6402	Economy	12200.00
0005435177522	6402	Economy	12200.00
0005432361527	6402	Economy	12200.00
0005432361528	6402	Economy	12200.00
0005432361557	6402	Economy	12200.00
0005434149927	6402	Economy	12200.00
0005432062359	6402	Economy	12200.00
0005432336327	6402	Economy	12200.00
0005435177578	6402	Economy	12200.00
0005435177531	6402	Economy	12200.00
0005435177529	6402	Economy	12200.00
0005435177642	6402	Economy	12200.00
0005432336322	6402	Economy	12200.00
0005432336332	6402	Economy	12200.00
0005432361567	6402	Economy	12200.00
0005432361553	6402	Economy	12200.00
0005432361523	6402	Economy	12200.00
0005434149944	6402	Economy	12200.00
0005432336326	6402	Economy	12200.00
0005435490288	6402	Economy	12200.00
0005435177628	6402	Economy	12200.00
0005435177548	6402	Economy	12200.00
0005435177618	6402	Economy	12200.00
0005435177621	6402	Economy	12200.00
0005432336331	6402	Economy	12200.00
0005432336333	6402	Economy	12200.00
0005432363497	6402	Economy	12200.00
0005435177597	6402	Economy	12200.00
0005432361549	6402	Economy	12200.00
0005432361564	6402	Economy	12200.00
0005432361545	6402	Economy	12200.00
0005435177549	6402	Economy	12200.00
0005435177462	6402	Economy	12200.00
0005434149926	6402	Economy	12200.00
0005435177581	6402	Economy	12200.00
0005435177524	6402	Economy	12200.00
0005432361563	6402	Economy	12200.00
0005435177500	6402	Economy	12200.00
0005432361526	6402	Economy	12200.00
0005435177360	6402	Economy	12200.00
0005432361547	6402	Economy	12200.00
0005434149930	6402	Economy	12200.00
0005432361565	6402	Economy	12200.00
0005435177678	6402	Economy	12200.00
0005435177643	6402	Economy	12200.00
0005432361548	6402	Economy	12200.00
0005432361533	6402	Economy	12200.00
0005434149925	6402	Economy	12200.00
0005432336323	6402	Economy	12200.00
0005432361550	6402	Economy	12200.00
0005435177534	6402	Economy	12200.00
0005432361546	6402	Economy	12200.00
0005432361561	6402	Economy	12200.00
0005435177579	6402	Economy	12200.00
0005432336330	6402	Economy	12200.00
0005432062361	6402	Economy	12200.00
0005435177426	6402	Economy	12200.00
0005432361543	6402	Economy	12200.00
0005432361562	6402	Economy	12200.00
0005432361013	20998	Business	36600.00
0005435177742	20998	Business	36600.00
0005434150021	20998	Business	36600.00
0005432361033	20998	Business	36600.00
0005435177766	20998	Business	36600.00
0005435177749	20998	Business	36600.00
0005432361266	20998	Business	36600.00
0005432360952	20998	Business	36600.00
0005432336196	20998	Business	36600.00
0005432360993	20998	Business	36600.00
0005435177764	20998	Business	36600.00
0005432361139	20998	Business	36600.00
0005432361206	20998	Economy	12200.00
0005432360910	20998	Economy	12200.00
0005434150017	20998	Economy	12200.00
0005432361223	20998	Economy	12200.00
0005434150019	20998	Economy	12200.00
0005432361109	20998	Economy	12200.00
0005432361081	20998	Economy	12200.00
0005435177760	20998	Economy	12200.00
0005432336211	20998	Economy	12200.00
0005432361086	20998	Economy	12200.00
0005432336229	20998	Economy	12200.00
0005432336260	20998	Economy	12200.00
0005432360986	20998	Economy	12200.00
0005435177748	20998	Economy	12200.00
0005435177756	20998	Economy	12200.00
0005432361185	20998	Economy	12200.00
0005435177763	20998	Economy	12200.00
0005432361179	20998	Economy	12200.00
0005432360994	20998	Economy	12200.00
0005432361346	20998	Economy	12200.00
0005432361291	20998	Economy	12200.00
0005432361007	20998	Economy	12200.00
0005432052821	20998	Economy	12200.00
0005432360995	20998	Economy	12200.00
0005432361104	20998	Economy	12200.00
0005432360927	20998	Economy	12200.00
0005435490320	20998	Economy	12200.00
0005432361186	20998	Economy	12200.00
0005435177741	20998	Economy	12200.00
0005432052822	20998	Economy	12200.00
0005432361129	20998	Economy	12200.00
0005435177752	20998	Economy	12200.00
0005432336200	20998	Economy	12200.00
0005432361188	20998	Economy	12200.00
0005432361169	20998	Economy	12200.00
0005434150025	20998	Economy	12200.00
0005432361055	20998	Economy	12200.00
0005435723094	20998	Economy	12200.00
0005432363466	20998	Economy	13400.00
0005435177765	20998	Economy	13400.00
0005432361098	20998	Economy	13400.00
0005434150015	20998	Economy	13400.00
0005435177751	20998	Economy	13400.00
0005435177759	20998	Economy	12200.00
0005432361006	20998	Economy	13400.00
0005432336207	20998	Economy	12200.00
0005435177750	20998	Economy	12200.00
0005432361099	20998	Economy	12200.00
0005432336197	20998	Economy	12200.00
0005435177755	20998	Economy	12200.00
0005435177761	20998	Economy	12200.00
0005432361199	20998	Economy	12200.00
0005435177746	20998	Economy	12200.00
0005432361108	20998	Economy	12200.00
0005432336235	20998	Economy	12200.00
0005434150023	20998	Economy	12200.00
0005432361292	20998	Economy	12200.00
0005435490323	20998	Economy	12200.00
0005432361012	20998	Economy	12200.00
0005434150016	20998	Economy	12200.00
0005435490322	20998	Economy	12200.00
0005432336247	20998	Economy	12200.00
0005432361054	20998	Economy	12200.00
0005435177754	20998	Economy	12200.00
0005435177743	20998	Economy	12200.00
0005432336201	20998	Economy	12200.00
0005432361119	20998	Economy	12200.00
0005432361191	20998	Economy	12200.00
0005432336246	20998	Economy	12200.00
0005432336173	20998	Economy	12200.00
0005432363477	20998	Economy	12200.00
0005435177758	20998	Economy	12200.00
0005432361044	20998	Economy	12200.00
0005432360946	20998	Economy	12200.00
0005432361262	20998	Economy	12200.00
0005435177744	20998	Economy	12200.00
0005434150020	20998	Economy	12200.00
0005432336222	20998	Economy	12200.00
0005435177745	20998	Economy	12200.00
0005434150024	20998	Economy	12200.00
0005435490321	20998	Economy	12200.00
0005432361018	20998	Economy	12200.00
0005432361195	20998	Economy	12200.00
0005432361293	20998	Economy	12200.00
0005434150018	20998	Economy	12200.00
0005432361003	20998	Economy	12200.00
0005432361153	20998	Economy	12200.00
0005432361225	20998	Economy	12200.00
0005435177762	20998	Economy	12200.00
0005435177747	20998	Economy	12200.00
0005432361235	20998	Economy	12200.00
0005432361224	20998	Economy	12200.00
0005432336195	20998	Economy	12200.00
0005435723093	20998	Economy	12200.00
0005432336284	20998	Economy	12200.00
0005432361226	20998	Economy	12200.00
0005434150022	20998	Economy	12200.00
0005432361287	20998	Economy	12200.00
0005432361210	20998	Economy	12200.00
0005432361187	20998	Economy	12200.00
0005432336210	20998	Economy	12200.00
0005432361347	20998	Economy	12200.00
0005432361286	20998	Economy	12200.00
0005432361008	20998	Economy	12200.00
0005432361111	20998	Economy	12200.00
0005435177740	20998	Economy	12200.00
0005432361080	20998	Economy	12200.00
0005435177753	20998	Economy	12200.00
0005432336198	20998	Economy	12200.00
0005435177757	20998	Economy	12200.00
0005432360987	20998	Economy	12200.00
0005432336152	20998	Economy	12200.00
0005434459092	17695	Economy	3400.00
0005434459201	17695	Economy	3400.00
0005434459172	17695	Economy	3100.00
0005434459055	17695	Economy	3100.00
0005434459164	17695	Economy	3100.00
0005434186272	17695	Economy	3100.00
0005434186271	17695	Economy	3100.00
0005434448358	17695	Economy	3100.00
0005434459066	17695	Economy	3100.00
0005434459175	17695	Economy	3100.00
0005434459093	17695	Economy	3100.00
0005434459170	17695	Economy	3100.00
0005434448380	17695	Economy	3100.00
0005434186270	17695	Economy	3100.00
0005434459174	17695	Economy	3100.00
0005434459162	17695	Economy	3100.00
0005434459094	17695	Economy	3100.00
0005434459097	17695	Economy	3100.00
0005434459106	17695	Economy	3100.00
0005434459171	17695	Economy	3100.00
0005434461678	17695	Economy	3100.00
0005434448381	17695	Economy	3100.00
0005434461681	17695	Economy	3100.00
0005434461666	17695	Economy	3100.00
0005434461684	17695	Economy	3100.00
0005434448372	17695	Economy	3100.00
0005434459183	17695	Economy	3100.00
0005434448359	17695	Economy	3100.00
0005434462841	29079	Economy	3400.00
0005434459322	29079	Economy	3400.00
0005434459310	29079	Economy	3100.00
0005434459313	29079	Economy	3100.00
0005434462840	29079	Economy	3100.00
0005434459311	29079	Economy	3100.00
0005434459319	29079	Economy	3100.00
0005434448396	29079	Economy	3100.00
0005434459326	29079	Economy	3100.00
0005434459315	29079	Economy	3100.00
0005434459308	29079	Economy	3100.00
0005434448397	29079	Economy	3100.00
0005434459323	29079	Economy	3100.00
0005434459320	29079	Economy	3100.00
0005434459321	29079	Economy	3100.00
0005434459314	29079	Economy	3100.00
0005434459307	29079	Economy	3100.00
0005434186242	29079	Economy	3100.00
0005434459324	29079	Economy	3100.00
0005434463980	29079	Economy	3100.00
0005434448398	29079	Economy	3100.00
0005434459316	29079	Economy	3100.00
0005434186238	29079	Economy	3100.00
0005434186239	29079	Economy	3100.00
0005434186236	29079	Economy	3100.00
0005434186237	29079	Economy	3100.00
0005434459318	29079	Economy	3100.00
0005434462842	29079	Economy	3100.00
0005434463981	29079	Economy	3100.00
0005434459309	29079	Economy	3100.00
0005434459312	29079	Economy	3100.00
0005434186232	29079	Economy	3100.00
0005434459317	29079	Economy	3100.00
0005434186235	29079	Economy	3100.00
0005434459327	29079	Economy	3100.00
0005434459325	29079	Economy	3100.00
0005432663098	6488	Business	185300.00
0005432661982	6488	Business	185300.00
0005432661979	6488	Business	185300.00
0005432663089	6488	Business	185300.00
0005432663087	6488	Business	185300.00
0005432664197	6488	Business	185300.00
0005432664191	6488	Business	185300.00
0005432664199	6488	Business	185300.00
0005432663090	6488	Economy	61800.00
0005432663094	6488	Economy	61800.00
0005432663096	6488	Economy	61800.00
0005432661987	6488	Economy	61800.00
0005432661975	6488	Economy	61800.00
0005432664192	6488	Economy	61800.00
0005432663100	6488	Economy	61800.00
0005432663086	6488	Economy	61800.00
0005432664195	6488	Economy	61800.00
0005432661976	6488	Economy	61800.00
0005432664189	6488	Economy	61800.00
0005432661980	6488	Economy	61800.00
0005432661977	6488	Economy	61800.00
0005432664196	6488	Economy	61800.00
0005432663093	6488	Economy	61800.00
0005432661978	6488	Economy	61800.00
0005432664190	6488	Economy	61800.00
0005432664200	6488	Economy	61800.00
0005432664193	6488	Economy	61800.00
0005432663095	6488	Economy	61800.00
0005432663088	6488	Economy	61800.00
0005432661981	6488	Economy	61800.00
0005432664194	6488	Economy	61800.00
0005432663097	6488	Economy	61800.00
0005432661988	6488	Economy	61800.00
0005432663099	6488	Economy	61800.00
0005432663091	6488	Economy	61800.00
0005432661983	6488	Economy	61800.00
0005432663092	6488	Economy	61800.00
0005432664198	6488	Economy	61800.00
0005432661985	6488	Economy	61800.00
0005432661984	6488	Economy	61800.00
0005432664188	6488	Economy	61800.00
0005432661986	6488	Economy	61800.00
0005432605279	21428	Economy	7300.00
0005432605298	21428	Economy	6600.00
0005432605269	21428	Economy	6600.00
0005432605299	21428	Economy	6600.00
0005432605296	21428	Economy	6600.00
0005432605287	21428	Economy	6600.00
0005432605290	21428	Economy	6600.00
0005432605285	21428	Economy	6600.00
0005432605281	21428	Economy	6600.00
0005432605289	21428	Economy	6600.00
0005432605276	21428	Economy	6600.00
0005432605280	21428	Economy	6600.00
0005432605292	21428	Economy	6600.00
0005432605293	21428	Economy	6600.00
0005432605291	21428	Economy	6600.00
0005432605268	21428	Economy	6600.00
0005432605282	21428	Economy	6600.00
0005432605286	21428	Economy	6600.00
0005432605273	21428	Economy	6600.00
0005432605277	21428	Economy	6600.00
0005432605271	21428	Economy	6600.00
0005432605274	21428	Economy	6600.00
0005432605288	21428	Economy	6600.00
0005432605283	21428	Economy	6600.00
0005432605272	21428	Economy	6600.00
0005432605266	21428	Economy	6600.00
0005432605270	21428	Economy	6600.00
0005432605265	21428	Economy	6600.00
0005432605284	21428	Economy	6600.00
0005432605267	21428	Economy	6600.00
0005432605278	21428	Economy	6600.00
0005432605295	21428	Economy	6600.00
0005432605275	21428	Economy	6600.00
0005432605294	21428	Economy	6600.00
0005432605297	21428	Economy	6600.00
0005432605300	21428	Economy	6600.00
0005432604963	31678	Economy	7300.00
0005432604922	31678	Economy	7300.00
0005432605014	31678	Economy	7300.00
0005432604834	31678	Economy	6600.00
0005432604940	31678	Economy	6600.00
0005432605101	31678	Economy	6600.00
0005432604885	31678	Economy	6600.00
0005432605019	31678	Economy	6600.00
0005432604975	31678	Economy	6600.00
0005432605018	31678	Economy	6600.00
0005432604907	31678	Economy	6600.00
0005432604969	31678	Economy	6600.00
0005432604870	31678	Economy	6600.00
0005432605020	31678	Economy	6600.00
0005432604974	31678	Economy	6600.00
0005432604872	31678	Economy	6600.00
0005435221079	31678	Economy	6600.00
0005432604954	31678	Economy	6600.00
0005432605070	31678	Economy	6600.00
0005432604882	31678	Economy	6600.00
0005432604821	31678	Economy	6600.00
0005432604992	31678	Economy	6600.00
0005432604886	31678	Economy	6600.00
0005435221551	31678	Economy	6600.00
0005435221078	31678	Economy	6600.00
0005432604783	31678	Economy	6600.00
0005432604968	31678	Economy	6600.00
0005432604956	31678	Economy	6600.00
0005432604955	31678	Economy	6600.00
0005432604905	31678	Economy	6600.00
0005435221552	31678	Economy	6600.00
0005432604818	31678	Economy	6600.00
0005432604797	31678	Economy	6600.00
0005432605060	31678	Economy	6600.00
0005432604869	31678	Economy	6600.00
0005432604961	31678	Economy	6600.00
0005433293335	12318	Economy	19500.00
0005433293327	12318	Economy	19500.00
0005435154658	12318	Economy	19500.00
0005433293349	12318	Economy	19500.00
0005433293322	12318	Economy	17800.00
0005433293350	12318	Economy	17800.00
0005435154656	12318	Economy	17800.00
0005435154660	12318	Economy	17800.00
0005433293330	12318	Economy	17800.00
0005433293341	12318	Economy	17800.00
0005433293323	12318	Economy	17800.00
0005433293351	12318	Economy	17800.00
0005433293314	12318	Economy	17800.00
0005433293333	12318	Economy	17800.00
0005435154659	12318	Economy	17800.00
0005435154652	12318	Economy	17800.00
0005433293316	12318	Economy	17800.00
0005435154664	12318	Economy	17800.00
0005433293328	12318	Economy	17800.00
0005435154649	12318	Economy	17800.00
0005435154663	12318	Economy	17800.00
0005433293315	12318	Economy	17800.00
0005433293359	12318	Economy	17800.00
0005433293326	12318	Economy	17800.00
0005433293336	12318	Economy	17800.00
0005435154650	12318	Economy	17800.00
0005435154661	12318	Economy	17800.00
0005433293338	12318	Economy	17800.00
0005435154665	12318	Economy	17800.00
0005435154667	12318	Economy	17800.00
0005435154651	12318	Economy	17800.00
0005435154655	12318	Economy	17800.00
0005433293332	12318	Economy	17800.00
0005433293331	12318	Economy	17800.00
0005433293329	12318	Economy	17800.00
0005435154657	12318	Economy	17800.00
0005435154666	12318	Economy	17800.00
0005435154654	12318	Economy	17800.00
0005433293317	12318	Economy	17800.00
0005435154662	12318	Economy	17800.00
0005433293334	12318	Economy	17800.00
0005435154653	12318	Economy	17800.00
0005435154648	12318	Economy	17800.00
0005433473458	23882	Economy	14000.00
0005435257358	23882	Economy	14000.00
0005435257365	23882	Economy	12700.00
0005433473395	23882	Economy	12700.00
0005435257362	23882	Economy	12700.00
0005433473353	23882	Economy	12700.00
0005435257363	23882	Economy	12700.00
0005433473387	23882	Economy	12700.00
0005433473459	23882	Economy	12700.00
0005435257357	23882	Economy	12700.00
0005435257361	23882	Economy	12700.00
0005433473403	23882	Economy	12700.00
0005433473437	23882	Economy	12700.00
0005435257366	23882	Economy	12700.00
0005433473408	23882	Economy	12700.00
0005433473404	23882	Economy	12700.00
0005435257359	23882	Economy	12700.00
0005435257360	23882	Economy	12700.00
0005433473413	23882	Economy	12700.00
0005433473383	23882	Economy	12700.00
0005435257364	23882	Economy	12700.00
0005433473414	23882	Economy	12700.00
0005434606886	18880	Economy	6600.00
0005434606884	18880	Economy	6600.00
0005434606885	18880	Economy	6600.00
0005434606883	18880	Economy	6600.00
0005434606867	18880	Economy	6600.00
0005434604984	22383	Economy	6600.00
0005434606909	22383	Economy	6600.00
0005434606908	22383	Economy	6600.00
0005434604985	22383	Economy	6600.00
0005434606910	22383	Economy	6600.00
0005434604987	22383	Economy	6600.00
0005434606911	22383	Economy	6600.00
0005435904712	22383	Economy	6600.00
0005435904713	22383	Economy	6600.00
0005434604986	22383	Economy	6600.00
0005434602961	3851	Economy	24900.00
0005434602965	3851	Economy	24900.00
0005434522538	3851	Economy	22600.00
0005435904445	3851	Economy	22600.00
0005434602963	3851	Economy	22600.00
0005434522535	3851	Economy	22600.00
0005434522540	3851	Economy	22600.00
0005434602964	3851	Economy	22600.00
0005435904435	3851	Economy	22600.00
0005434602966	3851	Economy	22600.00
0005434522539	3851	Economy	22600.00
0005434522536	3851	Economy	22600.00
0005434522534	3851	Economy	22600.00
0005434522537	3851	Economy	22600.00
0005434603023	3851	Economy	22600.00
0005434602967	3851	Economy	22600.00
0005434603021	3851	Economy	22600.00
0005434603022	3851	Economy	22600.00
0005435904448	3851	Economy	22600.00
0005434602962	3851	Economy	22600.00
0005435904447	3851	Economy	22600.00
0005434602931	19056	Economy	24900.00
0005434522511	19056	Economy	22600.00
0005434604940	19056	Economy	22600.00
0005435904464	19056	Economy	22600.00
0005434604965	19056	Economy	22600.00
0005434604946	19056	Economy	22600.00
0005434522502	19056	Economy	22600.00
0005434602936	19056	Economy	22600.00
0005434602930	19056	Economy	22600.00
0005434522507	19056	Economy	22600.00
0005435904722	19056	Economy	22600.00
0005435904487	19056	Economy	22600.00
0005434604941	19056	Economy	22600.00
0005434522503	19056	Economy	22600.00
0005434522510	19056	Economy	22600.00
0005434602929	19056	Economy	22600.00
0005434522517	19056	Economy	22600.00
0005435904488	19056	Economy	22600.00
0005434522484	19056	Economy	22600.00
0005434604945	19056	Economy	22600.00
0005435904465	19056	Economy	22600.00
0005435904466	19056	Economy	22600.00
0005434604929	19056	Economy	22600.00
0005434602938	19056	Economy	22600.00
0005435904721	19056	Economy	22600.00
0005434522512	19056	Economy	22600.00
0005434602939	19056	Economy	22600.00
0005434604928	19056	Economy	22600.00
0005435904468	19056	Economy	22600.00
0005434604951	19056	Economy	22600.00
0005435904467	19056	Economy	22600.00
0005432891270	395	Business	44500.00
0005432891394	395	Business	44500.00
0005432748487	395	Business	44500.00
0005432748506	395	Business	44500.00
0005432748494	395	Business	44500.00
0005432748497	395	Business	44500.00
0005432748503	395	Business	44500.00
0005432891317	395	Business	44500.00
0005433293365	395	Business	44500.00
0005432748492	395	Business	44500.00
0005432891211	395	Business	44500.00
0005432748495	395	Business	44500.00
0005432748484	395	Economy	14800.00
0005432753381	395	Economy	14800.00
0005432748513	395	Economy	14800.00
0005432753379	395	Economy	14800.00
0005432748498	395	Economy	14800.00
0005432891271	395	Economy	14800.00
0005432748485	395	Economy	14800.00
0005432891296	395	Economy	14800.00
0005432748480	395	Economy	14800.00
0005432748508	395	Economy	16300.00
0005432751607	395	Economy	16300.00
0005432220110	395	Economy	16300.00
0005432748483	395	Economy	16300.00
0005432748500	395	Economy	14800.00
0005433293325	395	Economy	14800.00
0005432891286	395	Economy	14800.00
0005432748493	395	Economy	14800.00
0005432753380	395	Economy	14800.00
0005432220106	395	Economy	14800.00
0005432891210	395	Economy	14800.00
0005432748486	395	Economy	14800.00
0005432748502	395	Economy	14800.00
0005432891287	395	Economy	14800.00
0005432748512	395	Economy	14800.00
0005432748499	395	Economy	14800.00
0005432891304	395	Economy	14800.00
0005432751606	395	Economy	14800.00
0005432748515	395	Economy	14800.00
0005432748509	395	Economy	14800.00
0005432748507	395	Economy	14800.00
0005432748504	395	Economy	14800.00
0005432748501	395	Economy	14800.00
0005432891371	395	Economy	14800.00
0005432749836	395	Economy	14800.00
0005432891318	395	Economy	14800.00
0005432748481	395	Economy	14800.00
0005432891393	395	Economy	14800.00
0005432751605	395	Economy	14800.00
0005432748490	395	Economy	14800.00
0005432748496	395	Economy	14800.00
0005432891212	395	Economy	14800.00
0005432891273	395	Economy	14800.00
0005433293324	395	Economy	14800.00
0005432749837	395	Economy	14800.00
0005432748491	395	Economy	14800.00
0005432748514	395	Economy	14800.00
0005432891387	395	Economy	14800.00
0005432748488	395	Economy	14800.00
0005432891297	395	Economy	14800.00
0005432220108	395	Economy	14800.00
0005432748516	395	Economy	14800.00
0005432891395	395	Economy	14800.00
0005432891342	395	Economy	14800.00
0005432748511	395	Economy	14800.00
0005432891389	395	Economy	14800.00
0005433875393	395	Economy	14800.00
0005432751604	395	Economy	14800.00
0005432891254	395	Economy	14800.00
0005432891285	395	Economy	14800.00
0005432891372	395	Economy	14800.00
0005432891295	395	Economy	14800.00
0005432748505	395	Economy	14800.00
0005432748510	395	Economy	14800.00
0005433293348	395	Economy	14800.00
0005432748478	395	Economy	14800.00
0005432220109	395	Economy	14800.00
0005432891272	395	Economy	14800.00
0005432220107	395	Economy	14800.00
0005432748479	395	Economy	14800.00
0005432748489	395	Economy	14800.00
0005432891373	395	Economy	14800.00
0005432748482	395	Economy	14800.00
0005432891250	395	Economy	14800.00
0005432891502	12090	Business	44500.00
0005432891492	12090	Business	44500.00
0005432748127	12090	Business	44500.00
0005432891505	12090	Business	44500.00
0005432748257	12090	Business	44500.00
0005432748283	12090	Business	44500.00
0005432748162	12090	Business	44500.00
0005433875422	12090	Business	44500.00
0005432748048	12090	Economy	14800.00
0005432748265	12090	Economy	14800.00
0005432891493	12090	Economy	14800.00
0005432748203	12090	Economy	14800.00
0005432748112	12090	Economy	14800.00
0005433875421	12090	Economy	14800.00
0005432756892	12090	Economy	14800.00
0005432891494	12090	Economy	16300.00
0005432748118	12090	Economy	16300.00
0005432891506	12090	Economy	16300.00
0005432891508	12090	Economy	16300.00
0005432891501	12090	Economy	14800.00
0005432756903	12090	Economy	14800.00
0005432748110	12090	Economy	14800.00
0005432753350	12090	Economy	14800.00
0005432748267	12090	Economy	14800.00
0005432214857	12090	Economy	14800.00
0005432748114	12090	Economy	14800.00
0005432891499	12090	Economy	14800.00
0005432748355	12090	Economy	14800.00
0005432753330	12090	Economy	14800.00
0005432748152	12090	Economy	14800.00
0005432748065	12090	Economy	14800.00
0005432748089	12090	Economy	14800.00
0005432748201	12090	Economy	14800.00
0005432891503	12090	Economy	14800.00
0005432748189	12090	Economy	14800.00
0005432748197	12090	Economy	14800.00
0005432748266	12090	Economy	14800.00
0005432891504	12090	Economy	14800.00
0005432891500	12090	Economy	14800.00
0005434153571	12090	Economy	14800.00
0005432891507	12090	Economy	14800.00
0005434153572	12090	Economy	14800.00
0005432748334	12090	Economy	14800.00
0005432748293	12090	Economy	14800.00
0005432748049	12090	Economy	14800.00
0005432891498	12090	Economy	14800.00
0005432748126	12090	Economy	14800.00
0005432748111	12090	Economy	14800.00
0005432891510	12090	Economy	14800.00
0005432891491	12090	Economy	14800.00
0005432753356	12090	Economy	14800.00
0005432749816	12090	Economy	14800.00
0005432748290	12090	Economy	14800.00
0005432891509	12090	Economy	14800.00
0005432891497	12090	Economy	14800.00
0005432748159	12090	Economy	14800.00
0005432214856	12090	Economy	14800.00
0005432748202	12090	Economy	14800.00
0005432753348	12090	Economy	14800.00
0005432748225	12090	Economy	14800.00
0005432891495	12090	Economy	14800.00
0005432753347	12090	Economy	14800.00
0005434153570	12090	Economy	14800.00
0005432748164	12090	Economy	14800.00
0005432748196	12090	Economy	14800.00
0005432891511	12090	Economy	14800.00
0005432756893	12090	Economy	14800.00
0005432748066	12090	Economy	14800.00
0005432748239	12090	Economy	14800.00
0005432753331	12090	Economy	14800.00
0005432748163	12090	Economy	14800.00
0005432748096	12090	Economy	14800.00
0005434152859	12090	Economy	14800.00
0005432891496	12090	Economy	14800.00
0005433525299	18956	Economy	28200.00
0005433533397	18956	Economy	28200.00
0005432928060	18956	Economy	25700.00
0005433525292	18956	Economy	25700.00
0005433525300	18956	Economy	25700.00
0005433525295	18956	Economy	25700.00
0005432928068	18956	Economy	25700.00
0005433525297	18956	Economy	25700.00
0005433531381	18956	Economy	25700.00
0005432928059	18956	Economy	25700.00
0005433531384	18956	Economy	25700.00
0005433525298	18956	Economy	25700.00
0005432928082	18956	Economy	25700.00
0005433525301	18956	Economy	25700.00
0005433525291	18956	Economy	25700.00
0005433525296	18956	Economy	25700.00
0005433533398	18956	Economy	25700.00
0005433531382	18956	Economy	25700.00
0005432928072	18956	Economy	25700.00
0005433531383	18956	Economy	25700.00
0005433525294	18956	Economy	25700.00
0005433525293	18956	Economy	25700.00
0005433525157	32504	Economy	28200.00
0005432928125	32504	Economy	28200.00
0005433525201	32504	Economy	28200.00
0005432928124	32504	Economy	25700.00
0005433525216	32504	Economy	25700.00
0005432928122	32504	Economy	25700.00
0005433525202	32504	Economy	25700.00
0005432928126	32504	Economy	25700.00
0005433531341	32504	Economy	25700.00
0005433525220	32504	Economy	25700.00
0005433525164	32504	Economy	25700.00
0005433525155	32504	Economy	25700.00
0005433531351	32504	Economy	25700.00
0005432928123	32504	Economy	25700.00
0005433525165	32504	Economy	25700.00
0005433525200	32504	Economy	25700.00
0005433525156	32504	Economy	25700.00
0005433531342	32504	Economy	25700.00
0005433525255	32504	Economy	25700.00
0005433525218	32504	Economy	25700.00
0005433525217	32504	Economy	25700.00
0005433525208	32504	Economy	25700.00
0005433531352	32504	Economy	25700.00
0005433525254	32504	Economy	25700.00
0005433525224	32504	Economy	25700.00
0005433525219	32504	Economy	25700.00
0005435374449	5259	Business	84000.00
0005434558487	5259	Business	84000.00
0005435374249	5259	Business	84000.00
0005434826676	5259	Business	84000.00
0005434828764	5259	Business	84000.00
0005434826689	5259	Business	84000.00
0005434826642	5259	Business	84000.00
0005432823483	5259	Business	84000.00
0005435374180	5259	Business	84000.00
0005435374318	5259	Business	84000.00
0005435150366	5259	Business	84000.00
0005434828762	5259	Business	84000.00
0005432121674	5259	Business	84000.00
0005435374538	5259	Business	84000.00
0005434826692	5259	Business	84000.00
0005434826744	5259	Business	84000.00
0005434826699	5259	Business	84000.00
0005435374325	5259	Business	84000.00
0005435374533	5259	Business	84000.00
0005435374343	5259	Business	84000.00
0005434826667	5259	Business	84000.00
0005434826730	5259	Comfort	47600.00
0005434826739	5259	Comfort	47600.00
0005432396338	5259	Comfort	47600.00
0005434826736	5259	Comfort	47600.00
0005435374510	5259	Comfort	47600.00
0005434826682	5259	Comfort	47600.00
0005435374369	5259	Comfort	47600.00
0005435374451	5259	Comfort	47600.00
0005435374489	5259	Comfort	47600.00
0005434826731	5259	Comfort	47600.00
0005434826638	5259	Comfort	47600.00
0005435374301	5259	Comfort	47600.00
0005435374133	5259	Comfort	47600.00
0005435374057	5259	Comfort	47600.00
0005435374364	5259	Comfort	47600.00
0005434826712	5259	Comfort	47600.00
0005434558483	5259	Comfort	47600.00
0005435374378	5259	Comfort	47600.00
0005434826678	5259	Comfort	47600.00
0005435299870	5259	Comfort	47600.00
0005434665014	5259	Comfort	47600.00
0005435374247	5259	Comfort	47600.00
0005435374557	5259	Comfort	47600.00
0005435374177	5259	Comfort	47600.00
0005435386694	5259	Comfort	47600.00
0005435150369	5259	Comfort	47600.00
0005434826737	5259	Comfort	47600.00
0005434826723	5259	Comfort	47600.00
0005435735192	5259	Comfort	47600.00
0005435374324	5259	Comfort	47600.00
0005434826686	5259	Comfort	47600.00
0005435150377	5259	Comfort	47600.00
0005434826705	5259	Comfort	47600.00
0005435299860	5259	Comfort	47600.00
0005435374109	5259	Comfort	47600.00
0005435374155	5259	Comfort	47600.00
0005435374442	5259	Comfort	47600.00
0005434826749	5259	Comfort	47600.00
0005435374398	5259	Comfort	47600.00
0005434826685	5259	Comfort	47600.00
0005432394202	5259	Economy	28000.00
0005435373948	5259	Economy	28000.00
0005434826695	5259	Economy	28000.00
0005435374268	5259	Economy	28000.00
0005434665015	5259	Economy	28000.00
0005434826643	5259	Economy	28000.00
0005432823484	5259	Economy	28000.00
0005435374112	5259	Economy	28000.00
0005434826732	5259	Economy	28000.00
0005434826639	5259	Economy	28000.00
0005434826646	5259	Economy	28000.00
0005434826641	5259	Economy	28000.00
0005432121677	5259	Economy	28000.00
0005435374250	5259	Economy	28000.00
0005432394205	5259	Economy	28000.00
0005432121676	5259	Economy	28000.00
0005434826659	5259	Economy	28000.00
0005435374341	5259	Economy	28000.00
0005434558488	5259	Economy	28000.00
0005435150376	5259	Economy	28000.00
0005434826728	5259	Economy	28000.00
0005435373942	5259	Economy	28000.00
0005435374126	5259	Economy	28000.00
0005434826707	5259	Economy	28000.00
0005435374335	5259	Economy	28000.00
0005434826710	5259	Economy	28000.00
0005435661966	5259	Economy	28000.00
0005435150371	5259	Economy	28000.00
0005434826750	5259	Economy	28000.00
0005435150372	5259	Economy	28000.00
0005434826657	5259	Economy	28000.00
0005434826719	5259	Economy	28000.00
0005435374438	5259	Economy	28000.00
0005435374308	5259	Economy	28000.00
0005432121673	5259	Economy	28000.00
0005432121685	5259	Economy	28000.00
0005434826740	5259	Economy	28000.00
0005434826748	5259	Economy	28000.00
0005435374532	5259	Economy	28000.00
0005432396341	5259	Economy	28000.00
0005434826711	5259	Economy	28000.00
0005432121681	5259	Economy	28000.00
0005435735218	5259	Economy	28000.00
0005434826725	5259	Economy	28000.00
0005435374556	5259	Economy	28000.00
0005434826660	5259	Economy	28000.00
0005434826727	5259	Economy	28000.00
0005435373917	5259	Economy	28000.00
0005435150367	5259	Economy	28000.00
0005435374344	5259	Economy	28000.00
0005434558491	5259	Economy	28000.00
0005435299854	5259	Economy	28000.00
0005435374363	5259	Economy	28000.00
0005434826635	5259	Economy	30800.00
0005434826741	5259	Economy	30800.00
0005434831263	5259	Economy	28000.00
0005434826747	5259	Economy	28000.00
0005435374426	5259	Economy	30800.00
0005435373943	5259	Economy	28000.00
0005435150373	5259	Economy	28000.00
0005434826654	5259	Economy	28000.00
0005434558489	5259	Economy	28000.00
0005435374333	5259	Economy	28000.00
0005434826675	5259	Economy	28000.00
0005434826691	5259	Economy	28000.00
0005434826733	5259	Economy	28000.00
0005434826684	5259	Economy	28000.00
0005434826697	5259	Economy	28000.00
0005435386681	5259	Economy	28000.00
0005434826651	5259	Economy	28000.00
0005435374213	5259	Economy	28000.00
0005434826633	5259	Economy	28000.00
0005435374382	5259	Economy	28000.00
0005434826661	5259	Economy	28000.00
0005435374379	5259	Economy	28000.00
0005434826672	5259	Economy	28000.00
0005434826681	5259	Economy	28000.00
0005434826658	5259	Economy	28000.00
0005434826708	5259	Economy	28000.00
0005434826679	5259	Economy	28000.00
0005434826677	5259	Economy	28000.00
0005434826706	5259	Economy	28000.00
0005435374025	5259	Economy	28000.00
0005434826714	5259	Economy	28000.00
0005434826662	5259	Economy	28000.00
0005434826664	5259	Economy	28000.00
0005435374098	5259	Economy	28000.00
0005434826668	5259	Economy	28000.00
0005434826693	5259	Economy	28000.00
0005434826716	5259	Economy	28000.00
0005435374295	5259	Economy	28000.00
0005435374427	5259	Economy	28000.00
0005435661967	5259	Economy	28000.00
0005435374303	5259	Economy	28000.00
0005434826640	5259	Economy	28000.00
0005432396339	5259	Economy	28000.00
0005435374307	5259	Economy	28000.00
0005434828765	5259	Economy	28000.00
0005434826742	5259	Economy	28000.00
0005435374511	5259	Economy	28000.00
0005434826670	5259	Economy	28000.00
0005435299853	5259	Economy	28000.00
0005434826663	5259	Economy	28000.00
0005435374450	5259	Economy	28000.00
0005432121680	5259	Economy	28000.00
0005435374056	5259	Economy	28000.00
0005435374454	5259	Economy	28000.00
0005435661976	5259	Economy	28000.00
0005434826655	5259	Economy	28000.00
0005434826698	5259	Economy	28000.00
0005435661984	5259	Economy	28000.00
0005434558484	5259	Economy	28000.00
0005434558490	5259	Economy	28000.00
0005434826703	5259	Economy	28000.00
0005434826700	5259	Economy	28000.00
0005435374455	5259	Economy	28000.00
0005434826673	5259	Economy	28000.00
0005434826650	5259	Economy	28000.00
0005434826632	5259	Economy	28000.00
0005432121678	5259	Economy	28000.00
0005435150375	5259	Economy	28000.00
0005434826729	5259	Economy	28000.00
0005434826701	5259	Economy	28000.00
0005435374235	5259	Economy	28000.00
0005435374302	5259	Economy	28000.00
0005435374385	5259	Economy	28000.00
0005434826674	5259	Economy	28000.00
0005434826713	5259	Economy	28000.00
0005435386656	5259	Economy	28000.00
0005434826709	5259	Economy	28000.00
0005435373949	5259	Economy	28000.00
0005435304238	5259	Economy	28000.00
0005435374269	5259	Economy	28000.00
0005435374306	5259	Economy	28000.00
0005435374140	5259	Economy	28000.00
0005434826688	5259	Economy	28000.00
0005434826738	5259	Economy	28000.00
0005435386693	5259	Economy	28000.00
0005435374212	5259	Economy	28000.00
0005435179009	5259	Economy	28000.00
0005434826702	5259	Economy	28000.00
0005435150368	5259	Economy	28000.00
0005432121675	5259	Economy	28000.00
0005434558486	5259	Economy	28000.00
0005435374270	5259	Economy	28000.00
0005435299861	5259	Economy	28000.00
0005432396340	5259	Economy	28000.00
0005434826724	5259	Economy	28000.00
0005432121682	5259	Economy	28000.00
0005434826721	5259	Economy	30800.00
0005434826683	5259	Economy	30800.00
0005435374443	5259	Economy	30800.00
0005434826720	5259	Economy	30800.00
0005435150374	5259	Economy	28000.00
0005435179701	5259	Economy	28000.00
0005435374534	5259	Economy	28000.00
0005435304239	5259	Economy	28000.00
0005434826743	5259	Economy	28000.00
0005434826694	5259	Economy	28000.00
0005434826690	5259	Economy	28000.00
0005435374258	5259	Economy	28000.00
0005434826746	5259	Economy	28000.00
0005432121679	5259	Economy	28000.00
0005435374342	5259	Economy	28000.00
0005434826735	5259	Economy	28000.00
0005434826704	5259	Economy	28000.00
0005434831262	5259	Economy	28000.00
0005435373986	5259	Economy	28000.00
0005435150370	5259	Economy	28000.00
0005435374104	5259	Economy	28000.00
0005435374248	5259	Economy	28000.00
0005435374537	5259	Economy	28000.00
0005434826722	5259	Economy	28000.00
0005435374154	5259	Economy	28000.00
0005434826653	5259	Economy	28000.00
0005434826715	5259	Economy	28000.00
0005435374494	5259	Economy	28000.00
0005434558481	5259	Economy	28000.00
0005435374475	5259	Economy	28000.00
0005434826647	5259	Economy	28000.00
0005435374482	5259	Economy	28000.00
0005435179006	5259	Economy	28000.00
0005434826645	5259	Economy	28000.00
0005434828766	5259	Economy	28000.00
0005435374334	5259	Economy	28000.00
0005434826637	5259	Economy	28000.00
0005435299869	5259	Economy	28000.00
0005435374386	5259	Economy	28000.00
0005434826734	5259	Economy	28000.00
0005434828763	5259	Economy	28000.00
0005435374041	5259	Economy	28000.00
0005435374178	5259	Economy	28000.00
0005434826671	5259	Economy	28000.00
0005435374476	5259	Economy	28000.00
0005435373710	5259	Economy	28000.00
0005434826634	5259	Economy	28000.00
0005434826656	5259	Economy	28000.00
0005432121684	5259	Economy	28000.00
0005435735206	5259	Economy	28000.00
0005435374483	5259	Economy	28000.00
0005434826687	5259	Economy	28000.00
0005435735205	5259	Economy	28000.00
0005435374024	5259	Economy	28000.00
0005435374141	5259	Economy	28000.00
0005434826718	5259	Economy	28000.00
0005434826726	5259	Economy	28000.00
0005434826745	5259	Economy	28000.00
0005434558485	5259	Economy	28000.00
0005435374016	5259	Economy	28000.00
0005434558482	5259	Economy	28000.00
0005435735199	5259	Economy	28000.00
0005435374294	5259	Economy	28000.00
0005435374257	5259	Economy	28000.00
0005434826680	5259	Economy	28000.00
0005434826648	5259	Economy	28000.00
0005435374319	5259	Economy	28000.00
0005434826644	5259	Economy	28000.00
0005434826669	5259	Economy	28000.00
0005434826717	5259	Economy	28000.00
0005434826649	5259	Economy	28000.00
0005432394204	5259	Economy	28000.00
0005434826652	5259	Economy	28000.00
0005432394203	5259	Economy	28000.00
0005432121686	5259	Economy	28000.00
0005434826665	5259	Economy	28000.00
0005432121683	5259	Economy	28000.00
0005435299871	5259	Economy	28000.00
0005434826636	5259	Economy	28000.00
0005434831261	5259	Economy	28000.00
0005434826666	5259	Economy	28000.00
0005434826696	5259	Economy	28000.00
0005435374865	9895	Business	84000.00
0005435735254	9895	Business	84000.00
0005434825591	9895	Business	84000.00
0005435374863	9895	Business	84000.00
0005435374878	9895	Business	84000.00
0005435374849	9895	Business	84000.00
0005434826196	9895	Business	84000.00
0005434825116	9895	Business	84000.00
0005434825941	9895	Business	84000.00
0005434825851	9895	Business	84000.00
0005434825450	9895	Business	84000.00
0005434825197	9895	Business	84000.00
0005434825716	9895	Business	84000.00
0005434825839	9895	Business	84000.00
0005435299894	9895	Business	84000.00
0005434825517	9895	Business	84000.00
0005435150234	9895	Business	84000.00
0005434825708	9895	Business	84000.00
0005434828731	9895	Business	84000.00
0005434825572	9895	Business	84000.00
0005434825466	9895	Business	84000.00
0005435374844	9895	Business	84000.00
0005435374884	9895	Comfort	47600.00
0005435374883	9895	Business	84000.00
0005435374871	9895	Comfort	47600.00
0005432203242	9895	Comfort	47600.00
0005434664993	9895	Comfort	47600.00
0005434825792	9895	Comfort	47600.00
0005434825686	9895	Comfort	47600.00
0005432203238	9895	Comfort	47600.00
0005435150274	9895	Comfort	47600.00
0005434558410	9895	Comfort	47600.00
0005434825518	9895	Comfort	47600.00
0005434825807	9895	Comfort	47600.00
0005434558418	9895	Comfort	47600.00
0005432203239	9895	Comfort	47600.00
0005434825503	9895	Comfort	47600.00
0005435374848	9895	Comfort	47600.00
0005435374881	9895	Comfort	47600.00
0005434825812	9895	Comfort	47600.00
0005434825121	9895	Comfort	47600.00
0005434825811	9895	Comfort	47600.00
0005434826370	9895	Comfort	47600.00
0005434825576	9895	Comfort	47600.00
0005434825438	9895	Comfort	47600.00
0005434825549	9895	Comfort	47600.00
0005435374851	9895	Comfort	47600.00
0005434825687	9895	Comfort	47600.00
0005435374861	9895	Comfort	47600.00
0005434825475	9895	Comfort	47600.00
0005434825389	9895	Comfort	47600.00
0005434825218	9895	Comfort	47600.00
0005435150237	9895	Comfort	47600.00
0005434825247	9895	Comfort	47600.00
0005434825508	9895	Comfort	47600.00
0005434828744	9895	Comfort	47600.00
0005434824981	9895	Comfort	47600.00
0005434825222	9895	Comfort	47600.00
0005434825696	9895	Comfort	47600.00
0005435374838	9895	Comfort	47600.00
0005434825419	9895	Economy	28000.00
0005434825365	9895	Economy	28000.00
0005434825730	9895	Economy	28000.00
0005434825775	9895	Economy	28000.00
0005435374866	9895	Economy	28000.00
0005434825956	9895	Economy	28000.00
0005434831226	9895	Economy	28000.00
0005435374854	9895	Economy	28000.00
0005434825649	9895	Economy	28000.00
0005434825985	9895	Economy	28000.00
0005434825725	9895	Economy	28000.00
0005434825418	9895	Economy	28000.00
0005434825304	9895	Economy	28000.00
0005434825926	9895	Economy	28000.00
0005434825559	9895	Economy	28000.00
0005434825025	9895	Economy	28000.00
0005435302313	9895	Economy	28000.00
0005434825357	9895	Economy	28000.00
0005434825820	9895	Economy	28000.00
0005434825410	9895	Economy	28000.00
0005434831214	9895	Economy	28000.00
0005432396307	9895	Economy	28000.00
0005435386730	9895	Economy	28000.00
0005434825486	9895	Economy	28000.00
0005435374827	9895	Economy	28000.00
0005435374889	9895	Economy	28000.00
0005434826197	9895	Economy	28000.00
0005435735255	9895	Economy	28000.00
0005434825924	9895	Economy	28000.00
0005434825432	9895	Economy	28000.00
0005434825469	9895	Economy	28000.00
0005434831223	9895	Economy	28000.00
0005435150249	9895	Economy	28000.00
0005434825408	9895	Economy	28000.00
0005434825217	9895	Economy	28000.00
0005435374858	9895	Economy	28000.00
0005435150241	9895	Economy	28000.00
0005434825353	9895	Economy	28000.00
0005434825411	9895	Economy	28000.00
0005434825406	9895	Economy	28000.00
0005435374855	9895	Economy	28000.00
0005432396308	9895	Economy	28000.00
0005435374837	9895	Economy	28000.00
0005434825521	9895	Economy	28000.00
0005434825969	9895	Economy	28000.00
0005434824979	9895	Economy	28000.00
0005432203240	9895	Economy	28000.00
0005434824987	9895	Economy	28000.00
0005434825645	9895	Economy	28000.00
0005434825465	9895	Economy	28000.00
0005432203241	9895	Economy	30800.00
0005435374842	9895	Economy	28000.00
0005435386732	9895	Economy	30800.00
0005434825178	9895	Economy	28000.00
0005435374879	9895	Economy	30800.00
0005435374860	9895	Economy	28000.00
0005434826288	9895	Economy	30800.00
0005434825485	9895	Economy	28000.00
0005434825502	9895	Economy	30800.00
0005434825358	9895	Economy	28000.00
0005435374882	9895	Economy	28000.00
0005434825219	9895	Economy	28000.00
0005435150294	9895	Economy	28000.00
0005434825840	9895	Economy	28000.00
0005434825693	9895	Economy	28000.00
0005435374862	9895	Economy	28000.00
0005432400179	9895	Economy	28000.00
0005435374857	9895	Economy	28000.00
0005434558417	9895	Economy	28000.00
0005434831245	9895	Economy	28000.00
0005434825685	9895	Economy	28000.00
0005435374832	9895	Economy	28000.00
0005435374829	9895	Economy	28000.00
0005434826198	9895	Economy	28000.00
0005434825656	9895	Economy	28000.00
0005434825871	9895	Economy	28000.00
0005435374885	9895	Economy	28000.00
0005435374869	9895	Economy	28000.00
0005434825354	9895	Economy	28000.00
0005434825513	9895	Economy	28000.00
0005434826032	9895	Economy	28000.00
0005435150240	9895	Economy	28000.00
0005435374875	9895	Economy	28000.00
0005434825797	9895	Economy	28000.00
0005432396309	9895	Economy	28000.00
0005432823500	9895	Economy	28000.00
0005434825136	9895	Economy	28000.00
0005435374840	9895	Economy	28000.00
0005435374833	9895	Economy	28000.00
0005435179710	9895	Economy	28000.00
0005435735256	9895	Economy	28000.00
0005435374880	9895	Economy	28000.00
0005435662001	9895	Economy	28000.00
0005435374830	9895	Economy	28000.00
0005434825407	9895	Economy	28000.00
0005434825423	9895	Economy	28000.00
0005435374864	9895	Economy	28000.00
0005434826371	9895	Economy	28000.00
0005435374847	9895	Economy	28000.00
0005435386728	9895	Economy	28000.00
0005434825594	9895	Economy	28000.00
0005434825634	9895	Economy	28000.00
0005435386726	9895	Economy	28000.00
0005434825724	9895	Economy	28000.00
0005435374853	9895	Economy	28000.00
0005432203244	9895	Economy	28000.00
0005432203243	9895	Economy	28000.00
0005435302316	9895	Economy	28000.00
0005435662000	9895	Economy	28000.00
0005434825940	9895	Economy	28000.00
0005434825731	9895	Economy	28000.00
0005434825383	9895	Economy	28000.00
0005434825548	9895	Economy	28000.00
0005435374850	9895	Economy	28000.00
0005434825320	9895	Economy	28000.00
0005434825335	9895	Economy	28000.00
0005434825117	9895	Economy	28000.00
0005434825099	9895	Economy	28000.00
0005434558416	9895	Economy	28000.00
0005434825334	9895	Economy	28000.00
0005434825652	9895	Economy	28000.00
0005435179419	9895	Economy	28000.00
0005434828745	9895	Economy	28000.00
0005435299890	9895	Economy	28000.00
0005434825672	9895	Economy	28000.00
0005434825894	9895	Economy	28000.00
0005434558386	9895	Economy	28000.00
0005434825507	9895	Economy	28000.00
0005434825984	9895	Economy	28000.00
0005435374859	9895	Economy	28000.00
0005435386725	9895	Economy	28000.00
0005435662002	9895	Economy	28000.00
0005435302315	9895	Economy	28000.00
0005434825618	9895	Economy	28000.00
0005434558388	9895	Economy	28000.00
0005435150263	9895	Economy	28000.00
0005435374888	9895	Economy	28000.00
0005435374828	9895	Economy	28000.00
0005434825550	9895	Economy	28000.00
0005434825821	9895	Economy	28000.00
0005434558378	9895	Economy	28000.00
0005434825707	9895	Economy	28000.00
0005435374867	9895	Economy	28000.00
0005435302314	9895	Economy	28000.00
0005434825761	9895	Economy	28000.00
0005435179418	9895	Economy	30800.00
0005435299891	9895	Economy	30800.00
0005435374886	9895	Economy	30800.00
0005434825646	9895	Economy	30800.00
0005434825575	9895	Economy	30800.00
0005434825436	9895	Economy	28000.00
0005435374856	9895	Economy	28000.00
0005434825625	9895	Economy	28000.00
0005435374873	9895	Economy	28000.00
0005435374852	9895	Economy	28000.00
0005435374845	9895	Economy	28000.00
0005434824986	9895	Economy	28000.00
0005435374887	9895	Economy	28000.00
0005434558393	9895	Economy	28000.00
0005435374834	9895	Economy	28000.00
0005435374870	9895	Economy	28000.00
0005435150155	9895	Economy	28000.00
0005434831224	9895	Economy	28000.00
0005435374890	9895	Economy	28000.00
0005435302312	9895	Economy	28000.00
0005435150193	9895	Economy	28000.00
0005434825706	9895	Economy	28000.00
0005434825310	9895	Economy	28000.00
0005434558423	9895	Economy	28000.00
0005434825694	9895	Economy	28000.00
0005435150279	9895	Economy	28000.00
0005435386729	9895	Economy	28000.00
0005434558414	9895	Economy	28000.00
0005434825872	9895	Economy	28000.00
0005435374835	9895	Economy	28000.00
0005434825961	9895	Economy	28000.00
0005434825453	9895	Economy	28000.00
0005435150278	9895	Economy	28000.00
0005435374872	9895	Economy	28000.00
0005435374876	9895	Economy	28000.00
0005434825306	9895	Economy	28000.00
0005434825424	9895	Economy	28000.00
0005435735253	9895	Economy	28000.00
0005434825332	9895	Economy	28000.00
0005434825629	9895	Economy	28000.00
0005435386727	9895	Economy	28000.00
0005434664990	9895	Economy	28000.00
0005435150248	9895	Economy	28000.00
0005435374831	9895	Economy	28000.00
0005434825409	9895	Economy	28000.00
0005435150212	9895	Economy	28000.00
0005434824980	9895	Economy	28000.00
0005435150275	9895	Economy	28000.00
0005435299893	9895	Economy	28000.00
0005435374836	9895	Economy	28000.00
0005434825808	9895	Economy	28000.00
0005435374843	9895	Economy	28000.00
0005434825435	9895	Economy	28000.00
0005434825870	9895	Economy	28000.00
0005434825245	9895	Economy	28000.00
0005434825630	9895	Economy	28000.00
0005435299892	9895	Economy	28000.00
0005434665002	9895	Economy	28000.00
0005435374874	9895	Economy	28000.00
0005435150239	9895	Economy	28000.00
0005434825620	9895	Economy	28000.00
0005434825619	9895	Economy	28000.00
0005435374868	9895	Economy	28000.00
0005432400201	9895	Economy	28000.00
0005434825467	9895	Economy	28000.00
0005434825667	9895	Economy	28000.00
0005434826275	9895	Economy	28000.00
0005434825115	9895	Economy	28000.00
0005435374839	9895	Economy	28000.00
0005434825838	9895	Economy	28000.00
0005432823499	9895	Economy	28000.00
0005434825796	9895	Economy	28000.00
0005434558387	9895	Economy	28000.00
0005434825705	9895	Economy	28000.00
0005434825809	9895	Economy	28000.00
0005435374846	9895	Economy	28000.00
0005434825727	9895	Economy	28000.00
0005434825726	9895	Economy	28000.00
0005435374877	9895	Economy	28000.00
0005435374841	9895	Economy	28000.00
0005435386731	9895	Economy	28000.00
0005432400186	9895	Economy	28000.00
0005434825596	9895	Economy	28000.00
0005434826113	9895	Economy	28000.00
0005434558354	9895	Economy	28000.00
0005434665001	9895	Economy	28000.00
0005434826289	9895	Economy	28000.00
0005434558415	9895	Economy	28000.00
0005434825569	9895	Economy	28000.00
0005435082986	7012	Economy	7400.00
0005435082987	7012	Economy	7400.00
0005435790377	7012	Economy	7400.00
0005435790379	7012	Economy	7400.00
0005435082988	7012	Economy	7400.00
0005435790378	7012	Economy	7400.00
0005435082911	25991	Economy	8200.00
0005435082882	25991	Economy	7400.00
0005435082948	25991	Economy	7400.00
0005435082902	25991	Economy	7400.00
0005435082927	25991	Economy	7400.00
0005435082913	25991	Economy	7400.00
0005435082945	25991	Economy	7400.00
0005435790359	25991	Economy	7400.00
0005435082912	25991	Economy	7400.00
0005434215340	9544	Business	32800.00
0005434215314	9544	Business	32800.00
0005434757460	9544	Business	32800.00
0005434215227	9544	Business	32800.00
0005434215267	9544	Business	32800.00
0005434757463	9544	Business	32800.00
0005434215096	9544	Business	32800.00
0005434215283	9544	Business	32800.00
0005434757471	9544	Business	32800.00
0005434215317	9544	Business	32800.00
0005434757452	9544	Business	32800.00
0005434215053	9544	Business	32800.00
0005434757433	9544	Economy	10900.00
0005434215193	9544	Economy	10900.00
0005434215140	9544	Economy	10900.00
0005434215359	9544	Economy	10900.00
0005434215326	9544	Economy	10900.00
0005434215318	9544	Economy	10900.00
0005434215278	9544	Economy	10900.00
0005434215155	9544	Economy	10900.00
0005434757456	9544	Economy	10900.00
0005434215123	9544	Economy	10900.00
0005434215194	9544	Economy	12000.00
0005434757435	9544	Economy	12000.00
0005434215212	9544	Economy	12000.00
0005434215141	9544	Economy	12000.00
0005434215335	9544	Economy	12000.00
0005434757437	9544	Economy	10900.00
0005434215258	9544	Economy	10900.00
0005434757473	9544	Economy	10900.00
0005434215254	9544	Economy	10900.00
0005434757458	9544	Economy	10900.00
0005434757469	9544	Economy	10900.00
0005434757449	9544	Economy	10900.00
0005434757468	9544	Economy	10900.00
0005434215259	9544	Economy	10900.00
0005434757457	9544	Economy	10900.00
0005434215195	9544	Economy	10900.00
0005434215270	9544	Economy	10900.00
0005434215287	9544	Economy	10900.00
0005434215286	9544	Economy	10900.00
0005434215381	9544	Economy	10900.00
0005434215209	9544	Economy	10900.00
0005434215360	9544	Economy	10900.00
0005434757467	9544	Economy	10900.00
0005434215358	9544	Economy	10900.00
0005434757466	9544	Economy	10900.00
0005434215279	9544	Economy	10900.00
0005434757440	9544	Economy	10900.00
0005434215190	9544	Economy	10900.00
0005434757447	9544	Economy	10900.00
0005434757464	9544	Economy	10900.00
0005434757453	9544	Economy	10900.00
0005434757446	9544	Economy	10900.00
0005434215054	9544	Economy	10900.00
0005434757451	9544	Economy	10900.00
0005434757442	9544	Economy	10900.00
0005434215325	9544	Economy	10900.00
0005434757443	9544	Economy	10900.00
0005434215226	9544	Economy	10900.00
0005434215328	9544	Economy	10900.00
0005434757436	9544	Economy	10900.00
0005434215334	9544	Economy	10900.00
0005434757445	9544	Economy	10900.00
0005434757441	9544	Economy	10900.00
0005434757462	9544	Economy	10900.00
0005434215357	9544	Economy	10900.00
0005434757465	9544	Economy	10900.00
0005434757470	9544	Economy	10900.00
0005434757438	9544	Economy	10900.00
0005434215387	9544	Economy	10900.00
0005434757444	9544	Economy	10900.00
0005434215260	9544	Economy	10900.00
0005434757472	9544	Economy	10900.00
0005434215149	9544	Economy	10900.00
0005434757450	9544	Economy	10900.00
0005434215176	9544	Economy	10900.00
0005434215277	9544	Economy	10900.00
0005434215210	9544	Economy	10900.00
0005434757455	9544	Economy	10900.00
0005434215284	9544	Economy	10900.00
0005434215145	9544	Economy	10900.00
0005434215303	9544	Economy	10900.00
0005434757461	9544	Economy	10900.00
0005434757448	9544	Economy	10900.00
0005434757454	9544	Economy	10900.00
0005434215356	9544	Economy	10900.00
0005434215081	9544	Economy	10900.00
0005434757434	9544	Economy	10900.00
0005434215177	9544	Economy	10900.00
0005434757459	9544	Economy	10900.00
0005434215269	9544	Economy	10900.00
0005434215301	9544	Economy	10900.00
0005434215150	9544	Economy	10900.00
0005434215192	9544	Economy	10900.00
0005434757439	9544	Economy	10900.00
0005434756873	28639	Business	32800.00
0005434215617	28639	Business	32800.00
0005434215623	28639	Business	32800.00
0005434756958	28639	Business	32800.00
0005434756995	28639	Business	32800.00
0005434757090	28639	Business	32800.00
0005434215642	28639	Business	32800.00
0005434215622	28639	Business	32800.00
0005434215619	28639	Business	32800.00
0005434215635	28639	Economy	10900.00
0005434215602	28639	Economy	10900.00
0005434215643	28639	Economy	10900.00
0005434215630	28639	Economy	10900.00
0005434215644	28639	Economy	10900.00
0005434215605	28639	Economy	10900.00
0005434756971	28639	Economy	10900.00
0005434215625	28639	Economy	12000.00
0005434756915	28639	Economy	12000.00
0005434215632	28639	Economy	12000.00
0005434757149	28639	Economy	12000.00
0005434215634	28639	Economy	12000.00
0005434215621	28639	Economy	10900.00
0005434756822	28639	Economy	10900.00
0005434215646	28639	Economy	10900.00
0005434215612	28639	Economy	10900.00
0005434215641	28639	Economy	10900.00
0005434215647	28639	Economy	10900.00
0005434756853	28639	Economy	10900.00
0005434757052	28639	Economy	10900.00
0005434756970	28639	Economy	10900.00
0005434215631	28639	Economy	10900.00
0005434215637	28639	Economy	10900.00
0005434757067	28639	Economy	10900.00
0005434757147	28639	Economy	10900.00
0005434215616	28639	Economy	10900.00
0005434756942	28639	Economy	10900.00
0005434215607	28639	Economy	10900.00
0005434757011	28639	Economy	10900.00
0005434215615	28639	Economy	10900.00
0005434757119	28639	Economy	10900.00
0005434756962	28639	Economy	10900.00
0005434215609	28639	Economy	10900.00
0005434756973	28639	Economy	10900.00
0005434215603	28639	Economy	10900.00
0005434215610	28639	Economy	10900.00
0005434215608	28639	Economy	10900.00
0005434757120	28639	Economy	10900.00
0005434757007	28639	Economy	10900.00
0005434215611	28639	Economy	10900.00
0005434757024	28639	Economy	10900.00
0005434757023	28639	Economy	10900.00
0005434756847	28639	Economy	10900.00
0005434215627	28639	Economy	10900.00
0005434215629	28639	Economy	10900.00
0005434756916	28639	Economy	10900.00
0005434215604	28639	Economy	10900.00
0005434756898	28639	Economy	10900.00
0005434215613	28639	Economy	10900.00
0005434756943	28639	Economy	10900.00
0005434756963	28639	Economy	10900.00
0005434215639	28639	Economy	10900.00
0005434756980	28639	Economy	10900.00
0005434215645	28639	Economy	10900.00
0005434215606	28639	Economy	10900.00
0005434215633	28639	Economy	10900.00
0005434215640	28639	Economy	10900.00
0005434215618	28639	Economy	10900.00
0005434757010	28639	Economy	10900.00
0005434215636	28639	Economy	10900.00
0005434215638	28639	Economy	10900.00
0005434215601	28639	Economy	10900.00
0005434756959	28639	Economy	10900.00
0005434215624	28639	Economy	10900.00
0005434756974	28639	Economy	10900.00
0005434215614	28639	Economy	10900.00
0005434215626	28639	Economy	10900.00
0005434757066	28639	Economy	10900.00
0005434756928	28639	Economy	10900.00
0005434215620	28639	Economy	10900.00
0005434215628	28639	Economy	10900.00
0005435100197	10854	Economy	8900.00
0005435100196	10854	Economy	8900.00
0005434760234	10854	Economy	8900.00
0005435100195	10854	Economy	8900.00
0005435100198	10854	Economy	8900.00
0005434760235	10854	Economy	8900.00
0005434760256	31792	Economy	9800.00
0005434760258	31792	Economy	8900.00
0005435100167	31792	Economy	8900.00
0005435100165	31792	Economy	8900.00
0005434760257	31792	Economy	8900.00
0005434639947	1993	Economy	20900.00
0005434639961	1993	Economy	20900.00
0005434639969	1993	Economy	20900.00
0005434639970	1993	Economy	20900.00
0005433202611	1993	Economy	19000.00
0005433202620	1993	Economy	19000.00
0005434639966	1993	Economy	19000.00
0005434639959	1993	Economy	19000.00
0005434639945	1993	Economy	19000.00
0005432290709	1993	Economy	19000.00
0005434639953	1993	Economy	19000.00
0005434639949	1993	Economy	19000.00
0005434639952	1993	Economy	19000.00
0005433202509	1993	Economy	19000.00
0005433202597	1993	Economy	19000.00
0005434639950	1993	Economy	19000.00
0005434639946	1993	Economy	19000.00
0005433202619	1993	Economy	19000.00
0005432290710	1993	Economy	19000.00
0005433202600	1993	Economy	19000.00
0005434639960	1993	Economy	19000.00
0005434639973	1993	Economy	19000.00
0005434639967	1993	Economy	19000.00
0005434639971	1993	Economy	19000.00
0005433202543	1993	Economy	19000.00
0005434639962	1993	Economy	19000.00
0005434639948	1993	Economy	19000.00
0005433202598	1993	Economy	19000.00
0005434639968	1993	Economy	19000.00
0005434639951	1993	Economy	19000.00
0005433202606	1993	Economy	19000.00
0005433202639	1993	Economy	19000.00
0005434639963	1993	Economy	19000.00
0005432290711	1993	Economy	19000.00
0005433202610	1993	Economy	19000.00
0005434639955	1993	Economy	19000.00
0005434639972	1993	Economy	19000.00
0005434639965	1993	Economy	19000.00
0005433202599	1993	Economy	19000.00
0005434639954	1993	Economy	19000.00
0005434639958	1993	Economy	19000.00
0005434639975	1993	Economy	19000.00
0005434639974	1993	Economy	19000.00
0005434639957	1993	Economy	19000.00
0005434639964	1993	Economy	19000.00
0005434639956	1993	Economy	19000.00
0005434639718	23251	Economy	20900.00
0005434639731	23251	Economy	20900.00
0005434639686	23251	Economy	20900.00
0005434639767	23251	Economy	19000.00
0005434639780	23251	Economy	19000.00
0005434639723	23251	Economy	19000.00
0005433202718	23251	Economy	19000.00
0005434639828	23251	Economy	19000.00
0005434639717	23251	Economy	19000.00
0005434639785	23251	Economy	19000.00
0005433202705	23251	Economy	19000.00
0005434639638	23251	Economy	19000.00
0005433202704	23251	Economy	19000.00
0005434639781	23251	Economy	19000.00
0005433202713	23251	Economy	19000.00
0005434639668	23251	Economy	19000.00
0005433202708	23251	Economy	19000.00
0005434639682	23251	Economy	19000.00
0005434639827	23251	Economy	19000.00
0005433202719	23251	Economy	19000.00
0005434639758	23251	Economy	19000.00
0005434639715	23251	Economy	19000.00
0005434639752	23251	Economy	19000.00
0005433202709	23251	Economy	19000.00
0005433202706	23251	Economy	19000.00
0005434639712	23251	Economy	19000.00
0005434639662	23251	Economy	19000.00
0005433202714	23251	Economy	19000.00
0005433202707	23251	Economy	19000.00
0005433202710	23251	Economy	19000.00
0005434639753	23251	Economy	19000.00
0005433202715	23251	Economy	19000.00
0005434639713	23251	Economy	19000.00
0005433202711	23251	Economy	19000.00
0005433202712	23251	Economy	19000.00
0005433202716	23251	Economy	19000.00
0005433202717	23251	Economy	19000.00
0005434639669	23251	Economy	19000.00
0005434639687	23251	Economy	19000.00
0005434639672	23251	Economy	19000.00
0005434639730	23251	Economy	19000.00
0005434639784	23251	Economy	19000.00
0005434601479	6074	Business	69700.00
0005433533402	6074	Business	69700.00
0005435326975	6074	Business	69700.00
0005434601481	6074	Business	69700.00
0005434601471	6074	Business	69700.00
0005435326974	6074	Business	69700.00
0005435326912	6074	Business	69700.00
0005434601465	6074	Business	69700.00
0005432111353	6074	Business	69700.00
0005434601476	6074	Economy	23200.00
0005434601483	6074	Economy	23200.00
0005435326945	6074	Economy	23200.00
0005434601460	6074	Economy	23200.00
0005435326952	6074	Economy	25600.00
0005435326959	6074	Economy	25600.00
0005433533399	6074	Economy	23200.00
0005435326976	6074	Economy	25600.00
0005433531387	6074	Economy	23200.00
0005434601477	6074	Economy	23200.00
0005434601470	6074	Economy	23200.00
0005433531386	6074	Economy	23200.00
0005434601478	6074	Economy	23200.00
0005434601472	6074	Economy	23200.00
0005435326916	6074	Economy	23200.00
0005434601461	6074	Economy	23200.00
0005432111352	6074	Economy	23200.00
0005433531385	6074	Economy	23200.00
0005434601464	6074	Economy	23200.00
0005434601474	6074	Economy	23200.00
0005435326911	6074	Economy	23200.00
0005434601482	6074	Economy	23200.00
0005434601463	6074	Economy	23200.00
0005434601475	6074	Economy	23200.00
0005434601459	6074	Economy	23200.00
0005434601466	6074	Economy	23200.00
0005433531388	6074	Economy	23200.00
0005435326946	6074	Economy	23200.00
0005435326823	6074	Economy	23200.00
0005435326982	6074	Economy	23200.00
0005435326910	6074	Economy	23200.00
0005434601462	6074	Economy	23200.00
0005434601467	6074	Economy	23200.00
0005434601484	6074	Economy	23200.00
0005433533400	6074	Economy	23200.00
0005434601468	6074	Economy	23200.00
0005433533401	6074	Economy	23200.00
0005434601480	6074	Economy	23200.00
0005435326953	6074	Economy	23200.00
0005434601473	6074	Economy	23200.00
0005434601469	6074	Economy	23200.00
0005434601319	18588	Business	69700.00
0005434601211	18588	Business	69700.00
0005434601224	18588	Business	69700.00
0005434601338	18588	Business	69700.00
0005435327087	18588	Business	69700.00
0005434601249	18588	Business	69700.00
0005434601339	18588	Economy	23200.00
0005435327081	18588	Economy	23200.00
0005433527316	18588	Economy	23200.00
0005434601228	18588	Economy	23200.00
0005435327076	18588	Economy	23200.00
0005434601269	18588	Economy	23200.00
0005435327080	18588	Economy	23200.00
0005434601254	18588	Economy	23200.00
0005434601257	18588	Economy	23200.00
0005434601235	18588	Economy	23200.00
0005434601230	18588	Economy	23200.00
0005434601232	18588	Economy	23200.00
0005434601227	18588	Economy	23200.00
0005435327086	18588	Economy	23200.00
0005434601253	18588	Economy	23200.00
0005435327084	18588	Economy	23200.00
0005434601233	18588	Economy	23200.00
0005434601171	18588	Economy	23200.00
0005435327077	18588	Economy	23200.00
0005435327078	18588	Economy	23200.00
0005434601172	18588	Economy	23200.00
0005433527299	18588	Economy	23200.00
0005435327088	18588	Economy	23200.00
0005433531344	18588	Economy	23200.00
0005435327083	18588	Economy	23200.00
0005434601231	18588	Economy	23200.00
0005434601344	18588	Economy	23200.00
0005434601303	18588	Economy	23200.00
0005434601256	18588	Economy	23200.00
0005433527313	18588	Economy	23200.00
0005435327079	18588	Economy	23200.00
0005434601210	18588	Economy	23200.00
0005435327085	18588	Economy	23200.00
0005434601236	18588	Economy	23200.00
0005435327082	18588	Economy	23200.00
0005434552513	10646	Business	9100.00
0005433181518	10646	Business	9100.00
0005434552545	10646	Business	9100.00
0005434552533	10646	Business	9100.00
0005433181547	10646	Business	9100.00
0005434552532	10646	Business	9100.00
0005434552507	10646	Business	9100.00
0005434552501	10646	Business	9100.00
0005433181538	10646	Business	9100.00
0005433181534	10646	Business	9100.00
0005434558476	10646	Business	9100.00
0005434552508	10646	Business	9100.00
0005433181489	10646	Economy	3000.00
0005434552525	10646	Economy	3000.00
0005434552540	10646	Economy	3000.00
0005434552517	10646	Economy	3000.00
0005434558480	10646	Economy	3000.00
0005434552537	10646	Economy	3000.00
0005433181486	10646	Economy	3000.00
0005434552530	10646	Economy	3000.00
0005433181511	10646	Economy	3000.00
0005434558477	10646	Economy	3000.00
0005434552503	10646	Economy	3300.00
0005434552523	10646	Economy	3300.00
0005434552515	10646	Economy	3300.00
0005433181475	10646	Economy	3300.00
0005434552534	10646	Economy	3300.00
0005434552550	10646	Economy	3000.00
0005434552546	10646	Economy	3000.00
0005434558473	10646	Economy	3000.00
0005434552505	10646	Economy	3000.00
0005433181508	10646	Economy	3000.00
0005433181460	10646	Economy	3000.00
0005434552524	10646	Economy	3000.00
0005434552514	10646	Economy	3000.00
0005433181442	10646	Economy	3000.00
0005434552535	10646	Economy	3000.00
0005434552527	10646	Economy	3000.00
0005434552552	10646	Economy	3000.00
0005433181487	10646	Economy	3000.00
0005434552531	10646	Economy	3000.00
0005433181537	10646	Economy	3000.00
0005434552512	10646	Economy	3000.00
0005434552510	10646	Economy	3000.00
0005434552538	10646	Economy	3000.00
0005434552519	10646	Economy	3000.00
0005434552529	10646	Economy	3000.00
0005434552504	10646	Economy	3000.00
0005433181492	10646	Economy	3000.00
0005434552549	10646	Economy	3000.00
0005434552547	10646	Economy	3000.00
0005434552521	10646	Economy	3000.00
0005434552542	10646	Economy	3000.00
0005434552500	10646	Economy	3000.00
0005434552502	10646	Economy	3000.00
0005434552551	10646	Economy	3000.00
0005434558475	10646	Economy	3000.00
0005433181445	10646	Economy	3000.00
0005434552511	10646	Economy	3000.00
0005434558478	10646	Economy	3000.00
0005433181531	10646	Economy	3000.00
0005434552509	10646	Economy	3000.00
0005434552499	10646	Economy	3000.00
0005433181370	10646	Economy	3000.00
0005433181446	10646	Economy	3000.00
0005434552544	10646	Economy	3000.00
0005434552520	10646	Economy	3000.00
0005434552518	10646	Economy	3000.00
0005434552543	10646	Economy	3000.00
0005434552536	10646	Economy	3000.00
0005434558479	10646	Economy	3000.00
0005433181488	10646	Economy	3000.00
0005434552526	10646	Economy	3000.00
0005434552522	10646	Economy	3000.00
0005433181474	10646	Economy	3000.00
0005434552553	10646	Economy	3000.00
0005433181371	10646	Economy	3000.00
0005434552548	10646	Economy	3000.00
0005433181372	10646	Economy	3000.00
0005434552506	10646	Economy	3000.00
0005433181600	10646	Economy	3000.00
0005434552516	10646	Economy	3000.00
0005433181444	10646	Economy	3000.00
0005434552541	10646	Economy	3000.00
0005434552539	10646	Economy	3000.00
0005434552528	10646	Economy	3000.00
0005433181561	10646	Economy	3000.00
0005433181533	10646	Economy	3000.00
0005434558474	10646	Economy	3000.00
0005434554114	10646	Economy	3000.00
0005434552264	27668	Business	9100.00
0005434552138	27668	Business	9100.00
0005434558401	27668	Business	9100.00
0005434552233	27668	Business	9100.00
0005434551961	27668	Business	9100.00
0005433181714	27668	Business	9100.00
0005434552234	27668	Business	9100.00
0005433181715	27668	Business	9100.00
0005434551898	27668	Business	9100.00
0005434554107	27668	Business	9100.00
0005434552206	27668	Business	9100.00
0005434552003	27668	Business	9100.00
0005433181728	27668	Economy	3000.00
0005433181722	27668	Economy	3000.00
0005434558399	27668	Economy	3000.00
0005433181727	27668	Economy	3000.00
0005433181713	27668	Economy	3000.00
0005434554098	27668	Economy	3000.00
0005434552172	27668	Economy	3000.00
0005433181721	27668	Economy	3300.00
0005433181726	27668	Economy	3300.00
0005434551869	27668	Economy	3300.00
0005434551885	27668	Economy	3300.00
0005434552057	27668	Economy	3300.00
0005433181719	27668	Economy	3000.00
0005433181708	27668	Economy	3000.00
0005434552109	27668	Economy	3000.00
0005433181711	27668	Economy	3000.00
0005434552154	27668	Economy	3000.00
0005433181724	27668	Economy	3000.00
0005434552084	27668	Economy	3000.00
0005434552352	27668	Economy	3000.00
0005434551894	27668	Economy	3000.00
0005434558377	27668	Economy	3000.00
0005434552306	27668	Economy	3000.00
0005434551998	27668	Economy	3000.00
0005434552112	27668	Economy	3000.00
0005434552160	27668	Economy	3000.00
0005433181718	27668	Economy	3000.00
0005434552207	27668	Economy	3000.00
0005434552111	27668	Economy	3000.00
0005433181725	27668	Economy	3000.00
0005433181716	27668	Economy	3000.00
0005434552212	27668	Economy	3000.00
0005434552107	27668	Economy	3000.00
0005434552190	27668	Economy	3000.00
0005434552155	27668	Economy	3000.00
0005433181717	27668	Economy	3000.00
0005434552205	27668	Economy	3000.00
0005434552082	27668	Economy	3000.00
0005433181710	27668	Economy	3000.00
0005433181729	27668	Economy	3000.00
0005434552222	27668	Economy	3000.00
0005434552096	27668	Economy	3000.00
0005434551970	27668	Economy	3000.00
0005433181723	27668	Economy	3000.00
0005434552170	27668	Economy	3000.00
0005434552004	27668	Economy	3000.00
0005434552173	27668	Economy	3000.00
0005433181709	27668	Economy	3000.00
0005434552161	27668	Economy	3000.00
0005434551941	27668	Economy	3000.00
0005434552110	27668	Economy	3000.00
0005434551999	27668	Economy	3000.00
0005434551871	27668	Economy	3000.00
0005434552120	27668	Economy	3000.00
0005434552204	27668	Economy	3000.00
0005433181732	27668	Economy	3000.00
0005434551997	27668	Economy	3000.00
0005433181733	27668	Economy	3000.00
0005434551987	27668	Economy	3000.00
0005434551957	27668	Economy	3000.00
0005433181730	27668	Economy	3000.00
0005433181712	27668	Economy	3000.00
0005434551975	27668	Economy	3000.00
0005434551956	27668	Economy	3000.00
0005434551870	27668	Economy	3000.00
0005434552175	27668	Economy	3000.00
0005433181720	27668	Economy	3000.00
0005434552056	27668	Economy	3000.00
0005434554097	27668	Economy	3000.00
0005434552009	27668	Economy	3000.00
0005434551893	27668	Economy	3000.00
0005433181731	27668	Economy	3000.00
0005434558409	27668	Economy	3000.00
0005434552246	27668	Economy	3000.00
0005435254511	6136	Economy	11700.00
0005433459322	6136	Economy	11700.00
0005435254510	6136	Economy	11700.00
0005435254509	6136	Economy	11700.00
0005433459323	6136	Economy	11700.00
0005433459325	6136	Economy	11700.00
0005433459324	6136	Economy	11700.00
0005433459302	19294	Economy	11700.00
0005435254530	19294	Economy	11700.00
0005433459274	19294	Economy	11700.00
0005433459282	19294	Economy	11700.00
0005435254532	19294	Economy	11700.00
0005433459281	19294	Economy	11700.00
0005435254529	19294	Economy	11700.00
0005433459283	19294	Economy	11700.00
0005433459303	19294	Economy	11700.00
0005435254531	19294	Economy	11700.00
0005433459275	19294	Economy	11700.00
0005435438364	6743	Business	51100.00
0005435438253	6743	Business	51100.00
0005435220353	6743	Business	51100.00
0005435719592	6743	Business	51100.00
0005435683158	6743	Business	51100.00
0005435683134	6743	Business	51100.00
0005435631038	6743	Business	51100.00
0005435438325	6743	Business	51100.00
0005435220360	6743	Business	51100.00
0005435683146	6743	Business	51100.00
0005435217749	6743	Business	51100.00
0005435438362	6743	Business	51100.00
0005435438331	6743	Economy	17000.00
0005435631041	6743	Economy	17000.00
0005432136290	6743	Economy	17000.00
0005435438314	6743	Economy	17000.00
0005432533335	6743	Economy	17000.00
0005435683155	6743	Economy	17000.00
0005435683148	6743	Economy	17000.00
0005435683159	6743	Economy	17000.00
0005432533333	6743	Economy	17000.00
0005435438323	6743	Economy	18700.00
0005435438451	6743	Economy	18700.00
0005432136293	6743	Economy	18700.00
0005435683135	6743	Economy	18700.00
0005435438344	6743	Economy	17000.00
0005435683124	6743	Economy	17000.00
0005435683126	6743	Economy	17000.00
0005435683118	6743	Economy	17000.00
0005435220357	6743	Economy	17000.00
0005435683131	6743	Economy	17000.00
0005435683152	6743	Economy	17000.00
0005435438324	6743	Economy	17000.00
0005432533334	6743	Economy	17000.00
0005435720159	6743	Economy	17000.00
0005435683119	6743	Economy	17000.00
0005435683137	6743	Economy	17000.00
0005435683123	6743	Economy	17000.00
0005435683133	6743	Economy	17000.00
0005435683143	6743	Economy	17000.00
0005435683130	6743	Economy	17000.00
0005435631040	6743	Economy	17000.00
0005435683147	6743	Economy	17000.00
0005435683125	6743	Economy	17000.00
0005435683142	6743	Economy	17000.00
0005432136292	6743	Economy	17000.00
0005435683141	6743	Economy	17000.00
0005435683140	6743	Economy	17000.00
0005435683157	6743	Economy	17000.00
0005435438363	6743	Economy	17000.00
0005435719594	6743	Economy	17000.00
0005432136289	6743	Economy	17000.00
0005435438254	6743	Economy	17000.00
0005435661999	6743	Economy	17000.00
0005435438294	6743	Economy	17000.00
0005435683139	6743	Economy	17000.00
0005435683150	6743	Economy	17000.00
0005435683122	6743	Economy	17000.00
0005432533332	6743	Economy	17000.00
0005435720160	6743	Economy	17000.00
0005435438343	6743	Economy	17000.00
0005435719593	6743	Economy	17000.00
0005435683154	6743	Economy	17000.00
0005435683138	6743	Economy	17000.00
0005435683129	6743	Economy	17000.00
0005435683127	6743	Economy	17000.00
0005435683132	6743	Economy	17000.00
0005435683160	6743	Economy	17000.00
0005435683144	6743	Economy	17000.00
0005435683128	6743	Economy	17000.00
0005435683151	6743	Economy	17000.00
0005435683120	6743	Economy	17000.00
0005435220362	6743	Economy	17000.00
0005435683145	6743	Economy	17000.00
0005435438355	6743	Economy	17000.00
0005435683136	6743	Economy	17000.00
0005435438330	6743	Economy	17000.00
0005435220361	6743	Economy	17000.00
0005435683149	6743	Economy	17000.00
0005435683121	6743	Economy	17000.00
0005435217751	6743	Economy	17000.00
0005435438298	6743	Economy	17000.00
0005435720161	6743	Economy	17000.00
0005435438332	6743	Economy	17000.00
0005435683156	6743	Economy	17000.00
0005432136291	6743	Economy	17000.00
0005435683153	6743	Economy	17000.00
0005435438381	6743	Economy	17000.00
0005435631039	6743	Economy	17000.00
0005432533363	24578	Business	51100.00
0005435438494	24578	Business	51100.00
0005435438487	24578	Business	51100.00
0005435682703	24578	Business	51100.00
0005435682922	24578	Business	51100.00
0005435661972	24578	Business	51100.00
0005435682969	24578	Business	51100.00
0005435682718	24578	Business	51100.00
0005435438488	24578	Business	51100.00
0005435682690	24578	Business	51100.00
0005435438505	24578	Business	51100.00
0005435682659	24578	Economy	17000.00
0005435682663	24578	Economy	17000.00
0005435438499	24578	Economy	17000.00
0005435682681	24578	Economy	17000.00
0005435682786	24578	Economy	17000.00
0005435682836	24578	Economy	17000.00
0005435682787	24578	Economy	17000.00
0005435438506	24578	Economy	17000.00
0005435682674	24578	Economy	17000.00
0005435438492	24578	Economy	17000.00
0005435682785	24578	Economy	18700.00
0005435438495	24578	Economy	18700.00
0005435682512	24578	Economy	18700.00
0005435438489	24578	Economy	18700.00
0005435682968	24578	Economy	18700.00
0005435438491	24578	Economy	17000.00
0005435631027	24578	Economy	17000.00
0005435682684	24578	Economy	17000.00
0005435682511	24578	Economy	17000.00
0005435682680	24578	Economy	17000.00
0005435682853	24578	Economy	17000.00
0005435438497	24578	Economy	17000.00
0005435682611	24578	Economy	17000.00
0005435438493	24578	Economy	17000.00
0005435682513	24578	Economy	17000.00
0005435682646	24578	Economy	17000.00
0005432533362	24578	Economy	17000.00
0005435682641	24578	Economy	17000.00
0005435682683	24578	Economy	17000.00
0005435682743	24578	Economy	17000.00
0005435438503	24578	Economy	17000.00
0005435682895	24578	Economy	17000.00
0005435682717	24578	Economy	17000.00
0005435682720	24578	Economy	17000.00
0005435682790	24578	Economy	17000.00
0005435438502	24578	Economy	17000.00
0005435682792	24578	Economy	17000.00
0005435720836	24578	Economy	17000.00
0005435438504	24578	Economy	17000.00
0005432305808	24578	Economy	17000.00
0005435682752	24578	Economy	17000.00
0005435438485	24578	Economy	17000.00
0005435438486	24578	Economy	17000.00
0005435438500	24578	Economy	17000.00
0005435631028	24578	Economy	17000.00
0005435682782	24578	Economy	17000.00
0005435682970	24578	Economy	17000.00
0005435682888	24578	Economy	17000.00
0005435720841	24578	Economy	17000.00
0005435682673	24578	Economy	17000.00
0005435682896	24578	Economy	17000.00
0005435438501	24578	Economy	17000.00
0005435682791	24578	Economy	17000.00
0005435682775	24578	Economy	17000.00
0005435682820	24578	Economy	17000.00
0005435682867	24578	Economy	17000.00
0005435438496	24578	Economy	17000.00
0005435682834	24578	Economy	17000.00
0005435682810	24578	Economy	17000.00
0005435661974	24578	Economy	17000.00
0005435682677	24578	Economy	17000.00
0005435682868	24578	Economy	17000.00
0005435682644	24578	Economy	17000.00
0005435438490	24578	Economy	17000.00
0005435682742	24578	Economy	17000.00
0005435682835	24578	Economy	17000.00
0005435682754	24578	Economy	17000.00
0005435682808	24578	Economy	17000.00
0005435682658	24578	Economy	17000.00
0005435661973	24578	Economy	17000.00
0005432305809	24578	Economy	17000.00
0005435682755	24578	Economy	17000.00
0005435682905	24578	Economy	17000.00
0005432305810	24578	Economy	17000.00
0005435682702	24578	Economy	17000.00
0005435682647	24578	Economy	17000.00
0005435682645	24578	Economy	17000.00
0005432533361	24578	Economy	17000.00
0005435438498	24578	Economy	17000.00
0005435127334	11513	Business	26400.00
0005435558128	11513	Business	26400.00
0005435127333	11513	Business	26400.00
0005435127351	11513	Business	26400.00
0005435127314	11513	Business	26400.00
0005435127327	11513	Economy	8800.00
0005435558121	11513	Economy	8800.00
0005435127337	11513	Economy	8800.00
0005435127324	11513	Economy	8800.00
0005435127325	11513	Economy	8800.00
0005435127317	11513	Economy	8800.00
0005435127330	11513	Economy	9700.00
0005435127335	11513	Economy	9700.00
0005435127316	11513	Economy	9700.00
0005435127339	11513	Economy	8800.00
0005435127343	11513	Economy	8800.00
0005435127319	11513	Economy	8800.00
0005435127348	11513	Economy	8800.00
0005435127345	11513	Economy	8800.00
0005435127323	11513	Economy	8800.00
0005435127346	11513	Economy	8800.00
0005435127315	11513	Economy	8800.00
0005435127336	11513	Economy	8800.00
0005435558129	11513	Economy	8800.00
0005435127338	11513	Economy	8800.00
0005435127313	11513	Economy	8800.00
0005435127342	11513	Economy	8800.00
0005435127328	11513	Economy	8800.00
0005435127344	11513	Economy	8800.00
0005435127312	11513	Economy	8800.00
0005435106058	11513	Economy	8800.00
0005435127331	11513	Economy	8800.00
0005435558122	11513	Economy	8800.00
0005435127350	11513	Economy	8800.00
0005435106056	11513	Economy	8800.00
0005435106057	11513	Economy	8800.00
0005435127329	11513	Economy	8800.00
0005435127326	11513	Economy	8800.00
0005435127322	11513	Economy	8800.00
0005435127320	11513	Economy	8800.00
0005435127349	11513	Economy	8800.00
0005435127321	11513	Economy	8800.00
0005435127318	11513	Economy	8800.00
0005435127347	11513	Economy	8800.00
0005435127332	11513	Economy	8800.00
0005435558123	11513	Economy	8800.00
0005435127341	11513	Economy	8800.00
0005435127340	11513	Economy	8800.00
0005435127007	31896	Business	26400.00
0005435127006	31896	Business	26400.00
0005435126921	31896	Business	26400.00
0005435127108	31896	Business	26400.00
0005435126957	31896	Business	26400.00
0005435127112	31896	Business	26400.00
0005435126890	31896	Business	26400.00
0005435127121	31896	Economy	8800.00
0005435127113	31896	Economy	8800.00
0005435127010	31896	Economy	8800.00
0005435127073	31896	Economy	8800.00
0005435126989	31896	Economy	9700.00
0005435127148	31896	Economy	8800.00
0005435126959	31896	Economy	8800.00
0005435126900	31896	Economy	8800.00
0005435106028	31896	Economy	8800.00
0005435127084	31896	Economy	8800.00
0005435558152	31896	Economy	8800.00
0005435126897	31896	Economy	8800.00
0005435127039	31896	Economy	8800.00
0005435127177	31896	Economy	8800.00
0005435127200	31896	Economy	8800.00
0005435127119	31896	Economy	8800.00
0005435126995	31896	Economy	8800.00
0005435126971	31896	Economy	8800.00
0005435127140	31896	Economy	8800.00
0005435098594	31896	Economy	8800.00
0005435127159	31896	Economy	8800.00
0005435098596	31896	Economy	8800.00
0005435127011	31896	Economy	8800.00
0005435126899	31896	Economy	8800.00
0005435127199	31896	Economy	8800.00
0005435098593	31896	Economy	8800.00
0005435126945	31896	Economy	8800.00
0005435127074	31896	Economy	8800.00
0005435127032	31896	Economy	8800.00
0005435126826	31896	Economy	8800.00
0005435098597	31896	Economy	8800.00
0005435127133	31896	Economy	8800.00
0005435127005	31896	Economy	8800.00
0005435098595	31896	Economy	8800.00
0005435127141	31896	Economy	8800.00
0005435126891	31896	Economy	8800.00
0005435126958	31896	Economy	8800.00
0005435126946	31896	Economy	8800.00
0005435127045	31896	Economy	8800.00
0005435558151	31896	Economy	8800.00
0005435127076	31896	Economy	8800.00
0005435127075	31896	Economy	8800.00
0005435098589	31896	Economy	8800.00
0005435126984	31896	Economy	8800.00
0005435127120	31896	Economy	8800.00
0005435127018	31896	Economy	8800.00
0005435127012	31896	Economy	8800.00
0005435106031	31896	Economy	8800.00
0005435127041	31896	Economy	8800.00
0005433399241	13548	Business	36600.00
0005433399249	13548	Business	36600.00
0005433399248	13548	Business	36600.00
0005435732542	13548	Business	36600.00
0005433399244	13548	Business	36600.00
0005433399250	13548	Business	36600.00
0005435732533	13548	Business	36600.00
0005433399263	13548	Business	36600.00
0005433399235	13548	Economy	12200.00
0005433399228	13548	Economy	12200.00
0005433399247	13548	Economy	12200.00
0005433399253	13548	Economy	12200.00
0005433399233	13548	Economy	12200.00
0005435732535	13548	Economy	12200.00
0005433399229	13548	Economy	13400.00
0005433399221	13548	Economy	13400.00
0005433399246	13548	Economy	13400.00
0005435732534	13548	Economy	13400.00
0005433399234	13548	Economy	13400.00
0005435732583	13548	Economy	12200.00
0005433399224	13548	Economy	12200.00
0005433399245	13548	Economy	12200.00
0005433399216	13548	Economy	12200.00
0005433399218	13548	Economy	12200.00
0005433399243	13548	Economy	12200.00
0005433399252	13548	Economy	12200.00
0005433399230	13548	Economy	12200.00
0005433399222	13548	Economy	12200.00
0005435732530	13548	Economy	12200.00
0005433399242	13548	Economy	12200.00
0005433399259	13548	Economy	12200.00
0005435732531	13548	Economy	12200.00
0005433399227	13548	Economy	12200.00
0005433399260	13548	Economy	12200.00
0005433399258	13548	Economy	12200.00
0005433399217	13548	Economy	12200.00
0005433399240	13548	Economy	12200.00
0005435732564	13548	Economy	12200.00
0005433399262	13548	Economy	12200.00
0005433399223	13548	Economy	12200.00
0005433399255	13548	Economy	12200.00
0005435732518	13548	Economy	12200.00
0005433399254	13548	Economy	12200.00
0005435732562	13548	Economy	12200.00
0005433399226	13548	Economy	12200.00
0005433399251	13548	Economy	12200.00
0005433399257	13548	Economy	12200.00
0005433399238	13548	Economy	12200.00
0005433399232	13548	Economy	12200.00
0005433399256	13548	Economy	12200.00
0005435732545	13548	Economy	12200.00
0005433399237	13548	Economy	12200.00
0005433399220	13548	Economy	12200.00
0005435732517	13548	Economy	12200.00
0005435732516	13548	Economy	12200.00
0005433399236	13548	Economy	12200.00
0005433399264	13548	Economy	12200.00
0005435732563	13548	Economy	12200.00
0005433399219	13548	Economy	12200.00
0005433399225	13548	Economy	12200.00
0005433399231	13548	Economy	12200.00
0005433399239	13548	Economy	12200.00
0005433399261	13548	Economy	12200.00
0005433398733	19403	Business	36600.00
0005433398741	19403	Business	36600.00
0005433398884	19403	Business	36600.00
0005433398660	19403	Business	36600.00
0005433398742	19403	Business	36600.00
0005433398674	19403	Business	36600.00
0005433398961	19403	Economy	12200.00
0005433398774	19403	Economy	12200.00
0005433399018	19403	Economy	12200.00
0005433398962	19403	Economy	12200.00
0005433398791	19403	Economy	12200.00
0005433399054	19403	Economy	12200.00
0005433398897	19403	Economy	12200.00
0005433398756	19403	Economy	12200.00
0005433398929	19403	Economy	12200.00
0005433398576	19403	Economy	13400.00
0005433398966	19403	Economy	13400.00
0005433398773	19403	Economy	12200.00
0005433398795	19403	Economy	12200.00
0005432297343	19403	Economy	12200.00
0005433398934	19403	Economy	12200.00
0005433398965	19403	Economy	12200.00
0005433398772	19403	Economy	12200.00
0005433398871	19403	Economy	12200.00
0005433398856	19403	Economy	12200.00
0005433398948	19403	Economy	12200.00
0005433398833	19403	Economy	12200.00
0005433398721	19403	Economy	12200.00
0005433398816	19403	Economy	12200.00
0005433398883	19403	Economy	12200.00
0005433398848	19403	Economy	12200.00
0005433398597	19403	Economy	12200.00
0005433398781	19403	Economy	12200.00
0005433398744	19403	Economy	12200.00
0005433399045	19403	Economy	12200.00
0005433398757	19403	Economy	12200.00
0005433398849	19403	Economy	12200.00
0005433398862	19403	Economy	12200.00
0005433398740	19403	Economy	12200.00
0005433399022	19403	Economy	12200.00
0005433398743	19403	Economy	12200.00
0005433398730	19403	Economy	12200.00
0005435725747	19403	Economy	12200.00
0005433398661	19403	Economy	12200.00
0005433398935	19403	Economy	12200.00
0005433398717	19403	Economy	12200.00
0005433398936	19403	Economy	12200.00
0005433399053	19403	Economy	12200.00
0005433399017	19403	Economy	12200.00
0005433398820	19403	Economy	12200.00
0005433398592	19403	Economy	12200.00
0005432297342	19403	Economy	12200.00
0005433398758	19403	Economy	12200.00
0005433398937	19403	Economy	12200.00
0005433399055	19403	Economy	12200.00
0005433398830	19403	Economy	12200.00
0005433398872	19403	Economy	12200.00
0005433398847	19403	Economy	12200.00
0005433399046	19403	Economy	12200.00
0005432297341	19403	Economy	12200.00
0005433398735	19403	Economy	12200.00
0005433398809	19403	Economy	12200.00
0005433398955	19403	Economy	12200.00
0005433398910	19403	Economy	12200.00
0005433398716	19403	Economy	12200.00
0005435725748	19403	Economy	12200.00
0005433398870	19403	Economy	12200.00
0005433398780	19403	Economy	12200.00
0005435925639	13169	Business	11300.00
0005435925636	13169	Business	11300.00
0005435069974	13169	Business	11300.00
0005435069927	13169	Business	11300.00
0005435925645	13169	Business	11300.00
0005435925643	13169	Business	11300.00
0005435070085	13169	Business	11300.00
0005435925642	13169	Business	11300.00
0005435069903	13169	Economy	3800.00
0005435925650	13169	Economy	3800.00
0005435069900	13169	Economy	3800.00
0005435069515	13169	Economy	3800.00
0005435925649	13169	Economy	3800.00
0005435925644	13169	Economy	3800.00
0005435069975	13169	Economy	3800.00
0005435069829	13169	Economy	4100.00
0005435069846	13169	Economy	4100.00
0005435925630	13169	Economy	4100.00
0005435069989	13169	Economy	3800.00
0005435069693	13169	Economy	3800.00
0005435069990	13169	Economy	3800.00
0005435069692	13169	Economy	3800.00
0005435069876	13169	Economy	3800.00
0005435069820	13169	Economy	3800.00
0005435069845	13169	Economy	3800.00
0005435069909	13169	Economy	3800.00
0005435069772	13169	Economy	3800.00
0005435069929	13169	Economy	3800.00
0005435069836	13169	Economy	3800.00
0005435070042	13169	Economy	3800.00
0005435069678	13169	Economy	3800.00
0005435069749	13169	Economy	3800.00
0005435925635	13169	Economy	3800.00
0005435069908	13169	Economy	3800.00
0005435925638	13169	Economy	3800.00
0005435069789	13169	Economy	3800.00
0005435069922	13169	Economy	3800.00
0005435069677	13169	Economy	3800.00
0005435069842	13169	Economy	3800.00
0005435069901	13169	Economy	3800.00
0005435070041	13169	Economy	3800.00
0005435069768	13169	Economy	3800.00
0005435925637	13169	Economy	3800.00
0005435925651	13169	Economy	3800.00
0005435925640	13169	Economy	3800.00
0005435925634	13169	Economy	3800.00
0005435069847	13169	Economy	3800.00
0005435069823	13169	Economy	3800.00
0005435069767	13169	Economy	3800.00
0005435925648	13169	Economy	3800.00
0005435069844	13169	Economy	3800.00
0005435069843	13169	Economy	3800.00
0005435069915	13169	Economy	3800.00
0005435069875	13169	Economy	3800.00
0005435925632	13169	Economy	3800.00
0005435069699	13169	Economy	3800.00
0005435070008	13169	Economy	3800.00
0005435069838	13169	Economy	3800.00
0005435925631	13169	Economy	3800.00
0005435069802	13169	Economy	3800.00
0005435069743	13169	Economy	3800.00
0005435925641	13169	Economy	3800.00
0005435069793	13169	Economy	3800.00
0005435069839	13169	Economy	3800.00
0005435069902	13169	Economy	3800.00
0005435069837	13169	Economy	3800.00
0005435069848	13169	Economy	3800.00
0005435925646	13169	Economy	3800.00
0005435069928	13169	Economy	3800.00
0005435069669	13169	Economy	3800.00
0005435069849	13169	Economy	3800.00
0005435925647	13169	Economy	3800.00
0005435069834	13169	Economy	3800.00
0005435925633	13169	Economy	3800.00
0005435070310	15466	Business	11300.00
0005435070302	15466	Business	11300.00
0005435925469	15466	Business	11300.00
0005435070283	15466	Business	11300.00
0005435070287	15466	Business	11300.00
0005435070308	15466	Business	11300.00
0005435925494	15466	Business	11300.00
0005435070323	15466	Business	11300.00
0005435070279	15466	Business	11300.00
0005435070316	15466	Business	11300.00
0005435070322	15466	Economy	3800.00
0005435070315	15466	Economy	3800.00
0005435925437	15466	Economy	3800.00
0005435070314	15466	Economy	3800.00
0005435070300	15466	Economy	3800.00
0005435070292	15466	Economy	4100.00
0005435070301	15466	Economy	4100.00
0005435070281	15466	Economy	4100.00
0005435925501	15466	Economy	3800.00
0005435070326	15466	Economy	3800.00
0005435070317	15466	Economy	3800.00
0005435070296	15466	Economy	3800.00
0005435925535	15466	Economy	3800.00
0005435070289	15466	Economy	3800.00
0005435070288	15466	Economy	3800.00
0005435925445	15466	Economy	3800.00
0005435070276	15466	Economy	3800.00
0005435070285	15466	Economy	3800.00
0005435070307	15466	Economy	3800.00
0005435070320	15466	Economy	3800.00
0005435070297	15466	Economy	3800.00
0005435070278	15466	Economy	3800.00
0005435070282	15466	Economy	3800.00
0005435925493	15466	Economy	3800.00
0005435070306	15466	Economy	3800.00
0005435925515	15466	Economy	3800.00
0005435070312	15466	Economy	3800.00
0005435925558	15466	Economy	3800.00
0005435925496	15466	Economy	3800.00
0005435925495	15466	Economy	3800.00
0005435070286	15466	Economy	3800.00
0005435070328	15466	Economy	3800.00
0005435070291	15466	Economy	3800.00
0005435070294	15466	Economy	3800.00
0005435070295	15466	Economy	3800.00
0005435070325	15466	Economy	3800.00
0005435925500	15466	Economy	3800.00
0005435070299	15466	Economy	3800.00
0005435070313	15466	Economy	3800.00
0005435070305	15466	Economy	3800.00
0005435070290	15466	Economy	3800.00
0005435070277	15466	Economy	3800.00
0005435070311	15466	Economy	3800.00
0005435070280	15466	Economy	3800.00
0005435070304	15466	Economy	3800.00
0005435070309	15466	Economy	3800.00
0005435925512	15466	Economy	3800.00
0005435070319	15466	Economy	3800.00
0005435070327	15466	Economy	3800.00
0005435070318	15466	Economy	3800.00
0005435070324	15466	Economy	3800.00
0005435070303	15466	Economy	3800.00
0005435925505	15466	Economy	3800.00
0005435925504	15466	Economy	3800.00
0005435925444	15466	Economy	3800.00
0005435070284	15466	Economy	3800.00
0005435070293	15466	Economy	3800.00
0005435070321	15466	Economy	3800.00
0005435070298	15466	Economy	3800.00
0005435808462	23185	Economy	27100.00
0005433407634	23185	Economy	27100.00
0005435808442	23185	Economy	27100.00
0005435808472	23185	Economy	27100.00
0005435808460	23185	Economy	24700.00
0005433407625	23185	Economy	24700.00
0005433407632	23185	Economy	24700.00
0005433407622	23185	Economy	24700.00
0005433407619	23185	Economy	24700.00
0005435808452	23185	Economy	24700.00
0005435808468	23185	Economy	24700.00
0005435808453	23185	Economy	24700.00
0005435808450	23185	Economy	24700.00
0005433407635	23185	Economy	24700.00
0005433407636	23185	Economy	24700.00
0005433407616	23185	Economy	24700.00
0005435808449	23185	Economy	24700.00
0005433407638	23185	Economy	24700.00
0005435808463	23185	Economy	24700.00
0005433407631	23185	Economy	24700.00
0005435808446	23185	Economy	24700.00
0005435808443	23185	Economy	24700.00
0005433407621	23185	Economy	24700.00
0005435808469	23185	Economy	24700.00
0005435808451	23185	Economy	24700.00
0005435808470	23185	Economy	24700.00
0005435808466	23185	Economy	24700.00
0005435808459	23185	Economy	24700.00
0005435808444	23185	Economy	24700.00
0005435808441	23185	Economy	24700.00
0005435808447	23185	Economy	24700.00
0005433407630	23185	Economy	24700.00
0005435808465	23185	Economy	24700.00
0005435808448	23185	Economy	24700.00
0005435808455	23185	Economy	24700.00
0005433407627	23185	Economy	24700.00
0005435808454	23185	Economy	24700.00
0005435808471	23185	Economy	24700.00
0005435808458	23185	Economy	24700.00
0005435808445	23185	Economy	24700.00
0005435808464	23185	Economy	24700.00
0005435808457	23185	Economy	24700.00
0005433407615	23185	Economy	24700.00
0005435808456	23185	Economy	24700.00
0005435808467	23185	Economy	24700.00
0005435808461	23185	Economy	24700.00
0005434215653	10718	Business	61300.00
0005434756845	10718	Business	61300.00
0005434757177	10718	Business	61300.00
0005434757104	10718	Business	61300.00
0005434757019	10718	Business	61300.00
0005434215658	10718	Business	61300.00
0005434215692	10718	Business	61300.00
0005434215654	10718	Business	61300.00
0005434215670	10718	Business	61300.00
0005434215685	10718	Business	61300.00
0005434757171	10718	Business	61300.00
0005434757084	10718	Business	61300.00
0005434215675	10718	Economy	20400.00
0005434215687	10718	Economy	20400.00
0005434215689	10718	Economy	20400.00
0005434757053	10718	Economy	20400.00
0005434215688	10718	Economy	20400.00
0005434215677	10718	Economy	20400.00
0005434756977	10718	Economy	20400.00
0005434757059	10718	Economy	22500.00
0005434757051	10718	Economy	22500.00
0005434756891	10718	Economy	22500.00
0005434757049	10718	Economy	22500.00
0005434215672	10718	Economy	22500.00
0005434757035	10718	Economy	20400.00
0005434756972	10718	Economy	20400.00
0005434757022	10718	Economy	20400.00
0005434215681	10718	Economy	20400.00
0005434215652	10718	Economy	20400.00
0005434757054	10718	Economy	20400.00
0005434757121	10718	Economy	20400.00
0005434757021	10718	Economy	20400.00
0005434215671	10718	Economy	20400.00
0005434756936	10718	Economy	20400.00
0005434756960	10718	Economy	20400.00
0005434756872	10718	Economy	20400.00
0005434215693	10718	Economy	20400.00
0005434215661	10718	Economy	20400.00
0005434215655	10718	Economy	20400.00
0005434215668	10718	Economy	20400.00
0005434757192	10718	Economy	20400.00
0005434215669	10718	Economy	20400.00
0005434215662	10718	Economy	20400.00
0005434756800	10718	Economy	20400.00
0005434756854	10718	Economy	20400.00
0005434757037	10718	Economy	20400.00
0005434215665	10718	Economy	20400.00
0005434757034	10718	Economy	20400.00
0005434215673	10718	Economy	20400.00
0005434215657	10718	Economy	20400.00
0005434215664	10718	Economy	20400.00
0005434756816	10718	Economy	20400.00
0005434757140	10718	Economy	20400.00
0005434757065	10718	Economy	20400.00
0005434757088	10718	Economy	20400.00
0005434215683	10718	Economy	20400.00
0005434757103	10718	Economy	20400.00
0005434215682	10718	Economy	20400.00
0005434215694	10718	Economy	20400.00
0005434215680	10718	Economy	20400.00
0005434215676	10718	Economy	20400.00
0005434757017	10718	Economy	20400.00
0005434215686	10718	Economy	20400.00
0005434757085	10718	Economy	20400.00
0005434215674	10718	Economy	20400.00
0005434757020	10718	Economy	20400.00
0005434215659	10718	Economy	20400.00
0005434756994	10718	Economy	20400.00
0005434215650	10718	Economy	20400.00
0005434756989	10718	Economy	20400.00
0005434215651	10718	Economy	20400.00
0005434215690	10718	Economy	20400.00
0005434215667	10718	Economy	20400.00
0005434215666	10718	Economy	20400.00
0005434757176	10718	Economy	20400.00
0005434215648	10718	Economy	20400.00
0005434215649	10718	Economy	20400.00
0005434756817	10718	Economy	20400.00
0005434215678	10718	Economy	20400.00
0005434215663	10718	Economy	20400.00
0005434215660	10718	Economy	20400.00
0005434215684	10718	Economy	20400.00
0005434215691	10718	Economy	20400.00
0005434215679	10718	Economy	20400.00
0005434215656	10718	Economy	20400.00
0005434757089	10718	Economy	20400.00
0005434215173	28648	Business	61300.00
0005434214898	28648	Business	61300.00
0005434757395	28648	Business	61300.00
0005434757410	28648	Business	61300.00
0005434215033	28648	Business	61300.00
0005434215252	28648	Business	61300.00
0005434215285	28648	Business	61300.00
0005434215404	28648	Business	61300.00
0005434215181	28648	Business	61300.00
0005434757385	28648	Business	61300.00
0005434757432	28648	Business	61300.00
0005434757384	28648	Business	61300.00
0005434757427	28648	Economy	20400.00
0005434215253	28648	Economy	20400.00
0005434757431	28648	Economy	20400.00
0005434215095	28648	Economy	20400.00
0005434757428	28648	Economy	20400.00
0005434757412	28648	Economy	20400.00
0005434757399	28648	Economy	20400.00
0005434757429	28648	Economy	20400.00
0005434215271	28648	Economy	20400.00
0005434757405	28648	Economy	20400.00
0005434215168	28648	Economy	22500.00
0005434215125	28648	Economy	22500.00
0005434757420	28648	Economy	22500.00
0005434757404	28648	Economy	22500.00
0005434215406	28648	Economy	22500.00
0005434757401	28648	Economy	20400.00
0005434757417	28648	Economy	20400.00
0005434757422	28648	Economy	20400.00
0005434757392	28648	Economy	20400.00
0005434757416	28648	Economy	20400.00
0005434757391	28648	Economy	20400.00
0005434757423	28648	Economy	20400.00
0005434215058	28648	Economy	20400.00
0005434215330	28648	Economy	20400.00
0005434215331	28648	Economy	20400.00
0005434757388	28648	Economy	20400.00
0005434215165	28648	Economy	20400.00
0005434757408	28648	Economy	20400.00
0005434215114	28648	Economy	20400.00
0005434757414	28648	Economy	20400.00
0005434757400	28648	Economy	20400.00
0005434214976	28648	Economy	20400.00
0005434757413	28648	Economy	20400.00
0005434215272	28648	Economy	20400.00
0005434757403	28648	Economy	20400.00
0005434215057	28648	Economy	20400.00
0005434757411	28648	Economy	20400.00
0005434757387	28648	Economy	20400.00
0005434757409	28648	Economy	20400.00
0005434215019	28648	Economy	20400.00
0005434757430	28648	Economy	20400.00
0005434215290	28648	Economy	20400.00
0005434757389	28648	Economy	20400.00
0005434757419	28648	Economy	20400.00
0005434215059	28648	Economy	20400.00
0005434215070	28648	Economy	20400.00
0005434215050	28648	Economy	20400.00
0005434215031	28648	Economy	20400.00
0005434215400	28648	Economy	20400.00
0005434757421	28648	Economy	20400.00
0005434215229	28648	Economy	20400.00
0005434757396	28648	Economy	20400.00
0005434757424	28648	Economy	20400.00
0005434757386	28648	Economy	20400.00
0005434215121	28648	Economy	20400.00
0005434757426	28648	Economy	20400.00
0005434757390	28648	Economy	20400.00
0005434215251	28648	Economy	20400.00
0005434215124	28648	Economy	20400.00
0005434215100	28648	Economy	20400.00
0005434215166	28648	Economy	20400.00
0005434215025	28648	Economy	20400.00
0005434215032	28648	Economy	20400.00
0005434214983	28648	Economy	20400.00
0005434757393	28648	Economy	20400.00
0005434215112	28648	Economy	20400.00
0005434215107	28648	Economy	20400.00
0005434215180	28648	Economy	20400.00
0005434215179	28648	Economy	20400.00
0005434757418	28648	Economy	20400.00
0005434757425	28648	Economy	20400.00
0005434757397	28648	Economy	20400.00
0005434215405	28648	Economy	20400.00
0005434215113	28648	Economy	20400.00
0005434215004	28648	Economy	20400.00
0005434215204	28648	Economy	20400.00
0005434757406	28648	Economy	20400.00
0005434757415	28648	Economy	20400.00
0005434757394	28648	Economy	20400.00
0005434215122	28648	Economy	20400.00
0005434757398	28648	Economy	20400.00
0005434215289	28648	Economy	20400.00
0005434214977	28648	Economy	20400.00
0005434757402	28648	Economy	20400.00
0005434757407	28648	Economy	20400.00
0005435041366	5457	Business	29500.00
0005434229730	5457	Business	29500.00
0005435007591	5457	Business	29500.00
0005434229696	5457	Business	29500.00
0005435042918	5457	Business	29500.00
0005435041340	5457	Business	29500.00
0005435041379	5457	Business	29500.00
0005434229732	5457	Business	29500.00
0005434229692	5457	Business	29500.00
0005435042921	5457	Business	29500.00
0005435041386	5457	Business	29500.00
0005435007594	5457	Business	29500.00
0005435007599	5457	Economy	9800.00
0005435041333	5457	Economy	9800.00
0005434229691	5457	Economy	9800.00
0005434229645	5457	Economy	9800.00
0005435041391	5457	Economy	9800.00
0005435041369	5457	Economy	9800.00
0005435007589	5457	Economy	9800.00
0005435041359	5457	Economy	9800.00
0005435007598	5457	Economy	9800.00
0005435041352	5457	Economy	9800.00
0005435041363	5457	Economy	9800.00
0005435041368	5457	Economy	9800.00
0005435041365	5457	Economy	9800.00
0005435041390	5457	Economy	9800.00
0005435041337	5457	Economy	9800.00
0005434229643	5457	Economy	9800.00
0005435041388	5457	Economy	9800.00
0005435041370	5457	Economy	9800.00
0005434229751	5457	Economy	9800.00
0005435007606	5457	Economy	9800.00
0005435041346	5457	Economy	9800.00
0005434229649	5457	Economy	9800.00
0005435041360	5457	Economy	9800.00
0005434229759	5457	Economy	9800.00
0005435041356	5457	Economy	9800.00
0005435041341	5457	Economy	9800.00
0005435041334	5457	Economy	9800.00
0005435041385	5457	Economy	9800.00
0005432125631	5457	Economy	9800.00
0005435007604	5457	Economy	9800.00
0005435041351	5457	Economy	9800.00
0005434229745	5457	Economy	9800.00
0005435041378	5457	Economy	9800.00
0005434229655	5457	Economy	9800.00
0005435041328	5457	Economy	9800.00
0005435041331	5457	Economy	9800.00
0005434229683	5457	Economy	9800.00
0005435041344	5457	Economy	9800.00
0005435041358	5457	Economy	9800.00
0005435041343	5457	Economy	9800.00
0005434229725	5457	Economy	10800.00
0005435041335	5457	Economy	10800.00
0005435041342	5457	Economy	10800.00
0005432125632	5457	Economy	10800.00
0005435042920	5457	Economy	10800.00
0005435007601	5457	Economy	10800.00
0005435041373	5457	Economy	9800.00
0005435041372	5457	Economy	9800.00
0005434229644	5457	Economy	9800.00
0005435041389	5457	Economy	9800.00
0005435041383	5457	Economy	9800.00
0005435007605	5457	Economy	9800.00
0005434229773	5457	Economy	9800.00
0005435041336	5457	Economy	9800.00
0005435007602	5457	Economy	9800.00
0005435041327	5457	Economy	9800.00
0005434229788	5457	Economy	9800.00
0005435041338	5457	Economy	9800.00
0005435041357	5457	Economy	9800.00
0005435041382	5457	Economy	9800.00
0005435041361	5457	Economy	9800.00
0005434229731	5457	Economy	9800.00
0005434229792	5457	Economy	9800.00
0005435041325	5457	Economy	9800.00
0005435041326	5457	Economy	9800.00
0005435041374	5457	Economy	9800.00
0005435041350	5457	Economy	9800.00
0005435041375	5457	Economy	9800.00
0005435041353	5457	Economy	9800.00
0005435041329	5457	Economy	9800.00
0005435041362	5457	Economy	9800.00
0005434229789	5457	Economy	9800.00
0005435041339	5457	Economy	9800.00
0005432125635	5457	Economy	9800.00
0005432125634	5457	Economy	9800.00
0005435041367	5457	Economy	9800.00
0005434229621	5457	Economy	9800.00
0005435007593	5457	Economy	9800.00
0005435041347	5457	Economy	9800.00
0005434229693	5457	Economy	9800.00
0005435007592	5457	Economy	9800.00
0005435007600	5457	Economy	9800.00
0005435041377	5457	Economy	9800.00
0005435041364	5457	Economy	9800.00
0005434229755	5457	Economy	9800.00
0005435041354	5457	Economy	9800.00
0005432125629	5457	Economy	9800.00
0005435007590	5457	Economy	9800.00
0005435041384	5457	Economy	9800.00
0005434229596	5457	Economy	9800.00
0005435007595	5457	Economy	9800.00
0005435042917	5457	Economy	9800.00
0005434229774	5457	Economy	9800.00
0005435041376	5457	Economy	9800.00
0005435041324	5457	Economy	9800.00
0005435041387	5457	Economy	9800.00
0005435041349	5457	Economy	9800.00
0005435041330	5457	Economy	9800.00
0005434229684	5457	Economy	9800.00
0005435042919	5457	Economy	9800.00
0005435041371	5457	Economy	9800.00
0005435043304	5457	Economy	9800.00
0005434229734	5457	Economy	9800.00
0005435041332	5457	Economy	9800.00
0005434229811	5457	Economy	9800.00
0005432125633	5457	Economy	9800.00
0005434229673	5457	Economy	9800.00
0005434229620	5457	Economy	9800.00
0005435041345	5457	Economy	9800.00
0005435041348	5457	Economy	9800.00
0005434229756	5457	Economy	9800.00
0005435041380	5457	Economy	9800.00
0005435041355	5457	Economy	9800.00
0005435007597	5457	Economy	9800.00
0005435041381	5457	Economy	9800.00
0005432125630	5457	Economy	9800.00
0005435007596	5457	Economy	9800.00
0005435007603	5457	Economy	9800.00
0005434229930	12951	Business	29500.00
0005435007418	12951	Business	29500.00
0005435040871	12951	Business	29500.00
0005435040874	12951	Business	29500.00
0005435040755	12951	Business	29500.00
0005435040860	12951	Business	29500.00
0005435040823	12951	Business	29500.00
0005435007370	12951	Business	29500.00
0005435040931	12951	Business	29500.00
0005435007462	12951	Business	29500.00
0005434229932	12951	Business	29500.00
0005434229920	12951	Business	29500.00
0005435007397	12951	Economy	9800.00
0005432304495	12951	Economy	9800.00
0005435041035	12951	Economy	9800.00
0005435040883	12951	Economy	9800.00
0005435041099	12951	Economy	9800.00
0005435040868	12951	Economy	9800.00
0005435040826	12951	Economy	9800.00
0005435040756	12951	Economy	9800.00
0005435040924	12951	Economy	9800.00
0005434229927	12951	Economy	9800.00
0005435040862	12951	Economy	9800.00
0005435007506	12951	Economy	9800.00
0005435040676	12951	Economy	9800.00
0005435040849	12951	Economy	9800.00
0005435041034	12951	Economy	9800.00
0005434229916	12951	Economy	9800.00
0005434229931	12951	Economy	9800.00
0005435041033	12951	Economy	9800.00
0005435041144	12951	Economy	9800.00
0005435007502	12951	Economy	9800.00
0005435040992	12951	Economy	9800.00
0005434229934	12951	Economy	9800.00
0005435040872	12951	Economy	9800.00
0005435007432	12951	Economy	9800.00
0005435040952	12951	Economy	9800.00
0005435040972	12951	Economy	9800.00
0005435007390	12951	Economy	9800.00
0005435007379	12951	Economy	9800.00
0005435040902	12951	Economy	9800.00
0005435040831	12951	Economy	9800.00
0005434229926	12951	Economy	9800.00
0005435007457	12951	Economy	9800.00
0005435040754	12951	Economy	9800.00
0005435007357	12951	Economy	9800.00
0005435040378	12951	Economy	9800.00
0005435040786	12951	Economy	9800.00
0005435040905	12951	Economy	9800.00
0005435040787	12951	Economy	9800.00
0005435040541	12951	Economy	10800.00
0005435007349	12951	Economy	10800.00
0005435040288	12951	Economy	10800.00
0005435007407	12951	Economy	10800.00
0005435040785	12951	Economy	10800.00
0005435007368	12951	Economy	10800.00
0005435040903	12951	Economy	9800.00
0005435040780	12951	Economy	9800.00
0005434229922	12951	Economy	9800.00
0005435040775	12951	Economy	9800.00
0005435040781	12951	Economy	9800.00
0005434229924	12951	Economy	9800.00
0005432304493	12951	Economy	9800.00
0005435040832	12951	Economy	9800.00
0005435040993	12951	Economy	9800.00
0005435040596	12951	Economy	9800.00
0005435040715	12951	Economy	9800.00
0005434229919	12951	Economy	9800.00
0005435040855	12951	Economy	9800.00
0005435040819	12951	Economy	9800.00
0005434229925	12951	Economy	9800.00
0005435007380	12951	Economy	9800.00
0005435040658	12951	Economy	9800.00
0005435007406	12951	Economy	9800.00
0005435040677	12951	Economy	9800.00
0005435040971	12951	Economy	9800.00
0005435040835	12951	Economy	9800.00
0005435040915	12951	Economy	9800.00
0005435040802	12951	Economy	9800.00
0005435040848	12951	Economy	9800.00
0005435040869	12951	Economy	9800.00
0005435040955	12951	Economy	9800.00
0005435007323	12951	Economy	9800.00
0005434229918	12951	Economy	9800.00
0005435040856	12951	Economy	9800.00
0005435040986	12951	Economy	9800.00
0005434229928	12951	Economy	9800.00
0005435041078	12951	Economy	9800.00
0005435040801	12951	Economy	9800.00
0005435007303	12951	Economy	9800.00
0005435041039	12951	Economy	9800.00
0005435007463	12951	Economy	9800.00
0005435040914	12951	Economy	9800.00
0005435040861	12951	Economy	9800.00
0005435040653	12951	Economy	9800.00
0005435040776	12951	Economy	9800.00
0005435040904	12951	Economy	9800.00
0005435040433	12951	Economy	9800.00
0005435040509	12951	Economy	9800.00
0005435007431	12951	Economy	9800.00
0005435040932	12951	Economy	9800.00
0005435040794	12951	Economy	9800.00
0005435040722	12951	Economy	9800.00
0005435040675	12951	Economy	9800.00
0005435007389	12951	Economy	9800.00
0005432304494	12951	Economy	9800.00
0005434229921	12951	Economy	9800.00
0005434229929	12951	Economy	9800.00
0005435040824	12951	Economy	9800.00
0005434229933	12951	Economy	9800.00
0005435040592	12951	Economy	9800.00
0005432304492	12951	Economy	9800.00
0005434229923	12951	Economy	9800.00
0005435007330	12951	Economy	9800.00
0005434229917	12951	Economy	9800.00
0005435040379	12951	Economy	9800.00
0005435040918	12951	Economy	9800.00
0005435040659	12951	Economy	9800.00
0005432304496	12951	Economy	9800.00
0005434229915	12951	Economy	9800.00
0005435040987	12951	Economy	9800.00
0005435007350	12951	Economy	9800.00
0005435040762	12951	Economy	9800.00
0005434427300	14860	Business	52900.00
0005432188686	14860	Business	52900.00
0005435902920	14860	Business	52900.00
0005435554230	14860	Business	52900.00
0005434427306	14860	Economy	17600.00
0005434427319	14860	Economy	17600.00
0005435903043	14860	Economy	17600.00
0005435902874	14860	Economy	17600.00
0005434427309	14860	Economy	17600.00
0005435903021	14860	Economy	17600.00
0005435903022	14860	Economy	17600.00
0005432188683	14860	Economy	17600.00
0005434427304	14860	Economy	19400.00
0005434427316	14860	Economy	19400.00
0005434427314	14860	Economy	19400.00
0005434427311	14860	Economy	17600.00
0005434427313	14860	Economy	17600.00
0005434427305	14860	Economy	17600.00
0005435554257	14860	Economy	17600.00
0005435554229	14860	Economy	17600.00
0005434427310	14860	Economy	17600.00
0005434427298	14860	Economy	17600.00
0005434427301	14860	Economy	17600.00
0005434427291	14860	Economy	17600.00
0005435903008	14860	Economy	17600.00
0005434427290	14860	Economy	17600.00
0005434427296	14860	Economy	17600.00
0005432188684	14860	Economy	17600.00
0005434427289	14860	Economy	17600.00
0005435902983	14860	Economy	17600.00
0005435554253	14860	Economy	17600.00
0005434427303	14860	Economy	17600.00
0005435903007	14860	Economy	17600.00
0005435554228	14860	Economy	17600.00
0005434427318	14860	Economy	17600.00
0005434427317	14860	Economy	17600.00
0005435903044	14860	Economy	17600.00
0005435902984	14860	Economy	17600.00
0005435902914	14860	Economy	17600.00
0005435903009	14860	Economy	17600.00
0005434427297	14860	Economy	17600.00
0005435554258	14860	Economy	17600.00
0005435903003	14860	Economy	17600.00
0005434427295	14860	Economy	17600.00
0005432188687	14860	Economy	17600.00
0005434427307	14860	Economy	17600.00
0005434427312	14860	Economy	17600.00
0005434411879	14860	Economy	17600.00
0005435902924	14860	Economy	17600.00
0005434427302	14860	Economy	17600.00
0005434427292	14860	Economy	17600.00
0005435903004	14860	Economy	17600.00
0005432188685	14860	Economy	17600.00
0005434427293	14860	Economy	17600.00
0005434411880	14860	Economy	17600.00
0005434427294	14860	Economy	17600.00
0005434427308	14860	Economy	17600.00
0005435902923	14860	Economy	17600.00
0005434427315	14860	Economy	17600.00
0005434427299	14860	Economy	17600.00
0005434411881	14860	Economy	17600.00
0005435903131	20237	Business	52900.00
0005434427081	20237	Business	52900.00
0005434427052	20237	Business	52900.00
0005434426929	20237	Business	52900.00
0005435903133	20237	Business	52900.00
0005434411847	20237	Business	52900.00
0005435903140	20237	Business	52900.00
0005434411852	20237	Business	52900.00
0005434427190	20237	Economy	17600.00
0005432059555	20237	Economy	17600.00
0005434427050	20237	Economy	17600.00
0005434427164	20237	Economy	17600.00
0005435554307	20237	Economy	17600.00
0005434427029	20237	Economy	17600.00
0005434427048	20237	Economy	19400.00
0005434411868	20237	Economy	19400.00
0005435903144	20237	Economy	19400.00
0005435903135	20237	Economy	19400.00
0005435903146	20237	Economy	19400.00
0005434427016	20237	Economy	17600.00
0005434427135	20237	Economy	17600.00
0005434427021	20237	Economy	17600.00
0005435554308	20237	Economy	17600.00
0005435554309	20237	Economy	17600.00
0005434426994	20237	Economy	17600.00
0005435903139	20237	Economy	17600.00
0005434427013	20237	Economy	17600.00
0005434427030	20237	Economy	17600.00
0005435903147	20237	Economy	17600.00
0005434427130	20237	Economy	17600.00
0005434427042	20237	Economy	17600.00
0005434427131	20237	Economy	17600.00
0005434411862	20237	Economy	17600.00
0005432059554	20237	Economy	17600.00
0005435903136	20237	Economy	17600.00
0005434427085	20237	Economy	17600.00
0005434427134	20237	Economy	17600.00
0005434427049	20237	Economy	17600.00
0005435903138	20237	Economy	17600.00
0005434427038	20237	Economy	17600.00
0005435903134	20237	Economy	17600.00
0005435903137	20237	Economy	17600.00
0005434427173	20237	Economy	17600.00
0005434427051	20237	Economy	17600.00
0005434426966	20237	Economy	17600.00
0005435903141	20237	Economy	17600.00
0005432059553	20237	Economy	17600.00
0005434427132	20237	Economy	17600.00
0005435903142	20237	Economy	17600.00
0005434427133	20237	Economy	17600.00
0005434427194	20237	Economy	17600.00
0005434427102	20237	Economy	17600.00
0005434427084	20237	Economy	17600.00
0005434427191	20237	Economy	17600.00
0005434426967	20237	Economy	17600.00
0005435903130	20237	Economy	17600.00
0005434427101	20237	Economy	17600.00
0005435554306	20237	Economy	17600.00
0005435903132	20237	Economy	17600.00
0005435903145	20237	Economy	17600.00
0005434427144	20237	Economy	17600.00
0005435903143	20237	Economy	17600.00
0005434411863	20237	Economy	17600.00
0005434427022	20237	Economy	17600.00
0005434411827	20237	Economy	17600.00
0005432462562	28010	Business	106800.00
0005434523801	28010	Business	106800.00
0005432462563	28010	Economy	35600.00
0005434559100	28010	Business	106800.00
0005434523807	28010	Economy	35600.00
0005434523809	28010	Economy	35600.00
0005434523794	28010	Economy	35600.00
0005432462565	28010	Economy	35600.00
0005434523808	28010	Economy	35600.00
0005434559101	28010	Economy	35600.00
0005434559104	28010	Economy	35600.00
0005434559102	28010	Economy	35600.00
0005432462561	28010	Economy	35600.00
0005434559103	28010	Economy	35600.00
0005434523810	28010	Economy	35600.00
0005432462560	28010	Economy	35600.00
0005432462567	28010	Economy	35600.00
0005432462564	28010	Economy	35600.00
0005434523793	28010	Economy	35600.00
0005434523803	28010	Economy	35600.00
0005432462566	28010	Economy	35600.00
0005434523795	28010	Economy	35600.00
0005434523805	28010	Economy	35600.00
0005434559097	28010	Economy	35600.00
0005434523833	30882	Economy	35600.00
0005434523828	30882	Economy	39200.00
0005432462543	30882	Economy	39200.00
0005434559121	30882	Economy	35600.00
0005432462544	30882	Economy	35600.00
0005434523830	30882	Economy	35600.00
0005434523834	30882	Economy	35600.00
0005434523832	30882	Economy	35600.00
0005432462549	30882	Economy	35600.00
0005432462548	30882	Economy	35600.00
0005434523829	30882	Economy	35600.00
0005434523831	30882	Economy	35600.00
0005434523835	30882	Economy	35600.00
0005434559120	30882	Economy	35600.00
0005433726143	30869	Business	91700.00
0005433726153	30869	Economy	30600.00
0005433726152	30869	Economy	30600.00
0005433726156	30869	Economy	30600.00
0005433726147	30869	Economy	30600.00
0005433726150	30869	Economy	30600.00
0005433726158	30869	Economy	33600.00
0005433726155	30869	Economy	33600.00
0005433726151	30869	Economy	30600.00
0005433726154	30869	Economy	30600.00
0005433726159	30869	Economy	30600.00
0005433726144	30869	Economy	30600.00
0005433726160	30869	Economy	30600.00
0005433726148	30869	Economy	30600.00
0005433726157	30869	Economy	30600.00
0005433726146	30869	Economy	30600.00
0005433726145	30869	Economy	30600.00
0005433726149	30869	Economy	30600.00
0005433435048	26530	Business	18500.00
0005435983374	26530	Business	18500.00
0005435983391	26530	Business	18500.00
0005435983366	26530	Business	18500.00
0005433435179	26530	Business	18500.00
0005435983382	26530	Business	18500.00
0005435983359	26530	Business	18500.00
0005435983375	26530	Business	18500.00
0005435983373	26530	Business	18500.00
0005433435134	26530	Business	18500.00
0005435983388	26530	Economy	6200.00
0005433435155	26530	Economy	6200.00
0005435983365	26530	Economy	6200.00
0005435983364	26530	Economy	6200.00
0005435983384	26530	Economy	6200.00
0005435983392	26530	Economy	6200.00
0005435983352	26530	Economy	6200.00
0005435983369	26530	Economy	6200.00
0005435983358	26530	Economy	6200.00
0005435983350	26530	Economy	6800.00
0005433435091	26530	Economy	6800.00
0005433435124	26530	Economy	6800.00
0005435983353	26530	Economy	6800.00
0005433435173	26530	Economy	6800.00
0005433435047	26530	Economy	6200.00
0005435983385	26530	Economy	6200.00
0005435983348	26530	Economy	6200.00
0005435983351	26530	Economy	6200.00
0005435983346	26530	Economy	6200.00
0005435983396	26530	Economy	6200.00
0005435983393	26530	Economy	6200.00
0005433435169	26530	Economy	6200.00
0005435983367	26530	Economy	6200.00
0005435983383	26530	Economy	6200.00
0005433435156	26530	Economy	6200.00
0005435983344	26530	Economy	6200.00
0005433435204	26530	Economy	6200.00
0005433435086	26530	Economy	6200.00
0005433434885	26530	Economy	6200.00
0005432300403	26530	Economy	6200.00
0005433435050	26530	Economy	6200.00
0005435983354	26530	Economy	6200.00
0005435983371	26530	Economy	6200.00
0005435983370	26530	Economy	6200.00
0005433435120	26530	Economy	6200.00
0005433435172	26530	Economy	6200.00
0005435983389	26530	Economy	6200.00
0005433435148	26530	Economy	6200.00
0005432300400	26530	Economy	6200.00
0005432300402	26530	Economy	6200.00
0005435983361	26530	Economy	6200.00
0005435983363	26530	Economy	6200.00
0005433435170	26530	Economy	6200.00
0005435983349	26530	Economy	6200.00
0005433435037	26530	Economy	6200.00
0005432300401	26530	Economy	6200.00
0005433434968	26530	Economy	6200.00
0005435983378	26530	Economy	6200.00
0005435983343	26530	Economy	6200.00
0005433435082	26530	Economy	6200.00
0005435983387	26530	Economy	6200.00
0005433435092	26530	Economy	6200.00
0005433434985	26530	Economy	6200.00
0005432300399	26530	Economy	6200.00
0005433435123	26530	Economy	6200.00
0005435983390	26530	Economy	6200.00
0005435983372	26530	Economy	6200.00
0005435983356	26530	Economy	6200.00
0005435983355	26530	Economy	6200.00
0005432300404	26530	Economy	6200.00
0005433435061	26530	Economy	6200.00
0005435983380	26530	Economy	6200.00
0005435983394	26530	Economy	6200.00
0005435983376	26530	Economy	6200.00
0005433434937	26530	Economy	6200.00
0005435983379	26530	Economy	6200.00
0005435983360	26530	Economy	6200.00
0005435983347	26530	Economy	6200.00
0005435983345	26530	Economy	6200.00
0005435983357	26530	Economy	6200.00
0005435983368	26530	Economy	6200.00
0005435983377	26530	Economy	6200.00
0005435983395	26530	Economy	6200.00
0005435983381	26530	Economy	6200.00
0005433435049	26530	Economy	6200.00
0005435983386	26530	Economy	6200.00
0005433435053	26530	Economy	6200.00
0005435983362	26530	Economy	6200.00
0005432051205	26708	Business	18500.00
0005435982980	26708	Business	18500.00
0005434270258	26708	Business	18500.00
0005433435368	26708	Business	18500.00
0005433435370	26708	Business	18500.00
0005433435375	26708	Business	18500.00
0005433435363	26708	Business	18500.00
0005433435380	26708	Business	18500.00
0005433435376	26708	Economy	6200.00
0005435982977	26708	Economy	6200.00
0005433435371	26708	Economy	6200.00
0005435982838	26708	Economy	6200.00
0005435982924	26708	Economy	6200.00
0005433435365	26708	Economy	6200.00
0005435982753	26708	Economy	6200.00
0005435982668	26708	Economy	6200.00
0005435982899	26708	Economy	6800.00
0005433435379	26708	Economy	6800.00
0005433435372	26708	Economy	6200.00
0005433435373	26708	Economy	6200.00
0005435982965	26708	Economy	6200.00
0005435982979	26708	Economy	6200.00
0005435982930	26708	Economy	6200.00
0005435982762	26708	Economy	6200.00
0005434271363	26708	Economy	6200.00
0005435982799	26708	Economy	6200.00
0005435982956	26708	Economy	6200.00
0005435982926	26708	Economy	6200.00
0005435982949	26708	Economy	6200.00
0005435982925	26708	Economy	6200.00
0005435982927	26708	Economy	6200.00
0005435982905	26708	Economy	6200.00
0005433435381	26708	Economy	6200.00
0005433435360	26708	Economy	6200.00
0005434269155	26708	Economy	6200.00
0005435982972	26708	Economy	6200.00
0005435982948	26708	Economy	6200.00
0005435982992	26708	Economy	6200.00
0005435982966	26708	Economy	6200.00
0005435982958	26708	Economy	6200.00
0005433435382	26708	Economy	6200.00
0005433435361	26708	Economy	6200.00
0005434269154	26708	Economy	6200.00
0005433435362	26708	Economy	6200.00
0005435982839	26708	Economy	6200.00
0005433435366	26708	Economy	6200.00
0005435982994	26708	Economy	6200.00
0005435982981	26708	Economy	6200.00
0005435982988	26708	Economy	6200.00
0005435982800	26708	Economy	6200.00
0005433435377	26708	Economy	6200.00
0005435982780	26708	Economy	6200.00
0005434271362	26708	Economy	6200.00
0005435982923	26708	Economy	6200.00
0005435982728	26708	Economy	6200.00
0005435982779	26708	Economy	6200.00
0005433435358	26708	Economy	6200.00
0005432051206	26708	Economy	6200.00
0005433435364	26708	Economy	6200.00
0005435982964	26708	Economy	6200.00
0005435982993	26708	Economy	6200.00
0005433435374	26708	Economy	6200.00
0005434271364	26708	Economy	6200.00
0005435982817	26708	Economy	6200.00
0005433435367	26708	Economy	6200.00
0005433435369	26708	Economy	6200.00
0005435982755	26708	Economy	6200.00
0005433435359	26708	Economy	6200.00
0005435982976	26708	Economy	6200.00
0005434270259	26708	Economy	6200.00
0005433435378	26708	Economy	6200.00
0005433686656	29274	Economy	21000.00
0005433686655	29274	Economy	19100.00
0005433686650	29274	Economy	19100.00
0005433689939	29274	Economy	19100.00
0005433689935	29274	Economy	19100.00
0005433689938	29274	Economy	19100.00
0005433686664	29274	Economy	19100.00
0005433686665	29274	Economy	19100.00
0005433689940	29274	Economy	19100.00
0005433689942	29274	Economy	19100.00
0005433689941	29274	Economy	19100.00
0005433686657	29274	Economy	19100.00
0005432858251	3173	Economy	11100.00
0005432584646	3173	Economy	11100.00
0005432584647	3173	Economy	11100.00
0005432858243	3173	Economy	11100.00
0005432584641	3173	Economy	10100.00
0005432584661	3173	Economy	10100.00
0005432584648	3173	Economy	10100.00
0005432584658	3173	Economy	10100.00
0005432858207	3173	Economy	10100.00
0005432584657	3173	Economy	10100.00
0005432584642	3173	Economy	10100.00
0005432858206	3173	Economy	10100.00
0005432858268	3173	Economy	10100.00
0005432858256	3173	Economy	10100.00
0005432584666	3173	Economy	10100.00
0005432584650	3173	Economy	10100.00
0005432584663	3173	Economy	10100.00
0005432858265	3173	Economy	10100.00
0005432584664	3173	Economy	10100.00
0005432858267	3173	Economy	10100.00
0005432858238	3173	Economy	10100.00
0005432858281	3173	Economy	10100.00
0005432584653	3173	Economy	10100.00
0005432584660	3173	Economy	10100.00
0005432584665	3173	Economy	10100.00
0005432584656	3173	Economy	10100.00
0005432584644	3173	Economy	10100.00
0005432216340	3173	Economy	10100.00
0005432584655	3173	Economy	10100.00
0005432858294	3173	Economy	10100.00
0005432584662	3173	Economy	10100.00
0005432216341	3173	Economy	10100.00
0005432584645	3173	Economy	10100.00
0005432584654	3173	Economy	10100.00
0005432858266	3173	Economy	10100.00
0005432584649	3173	Economy	10100.00
0005432584651	3173	Economy	10100.00
0005432584659	3173	Economy	10100.00
0005432584652	3173	Economy	10100.00
0005432584643	3173	Economy	10100.00
0005432858242	3173	Economy	10100.00
0005432584590	31471	Economy	11100.00
0005432858362	31471	Economy	11100.00
0005432584498	31471	Economy	11100.00
0005432584522	31471	Economy	10100.00
0005432584404	31471	Economy	10100.00
0005432584514	31471	Economy	10100.00
0005432584447	31471	Economy	10100.00
0005432858360	31471	Economy	10100.00
0005432584418	31471	Economy	10100.00
0005432584454	31471	Economy	10100.00
0005432858359	31471	Economy	10100.00
0005432584398	31471	Economy	10100.00
0005432584485	31471	Economy	10100.00
0005432584515	31471	Economy	10100.00
0005432584487	31471	Economy	10100.00
0005432584521	31471	Economy	10100.00
0005432584504	31471	Economy	10100.00
0005432858361	31471	Economy	10100.00
0005432858357	31471	Economy	10100.00
0005432584492	31471	Economy	10100.00
0005432584503	31471	Economy	10100.00
0005432858363	31471	Economy	10100.00
0005432858364	31471	Economy	10100.00
0005432584448	31471	Economy	10100.00
0005432584417	31471	Economy	10100.00
0005432858356	31471	Economy	10100.00
0005432858358	31471	Economy	10100.00
0005432584402	31471	Economy	10100.00
0005432858355	31471	Economy	10100.00
0005432858365	31471	Economy	10100.00
0005432584291	31471	Economy	10100.00
0005432584449	31471	Economy	10100.00
0005432584420	31471	Economy	10100.00
0005434943577	881	Economy	8300.00
0005434943574	881	Economy	8300.00
0005434943582	881	Economy	7500.00
0005433255201	881	Economy	7500.00
0005434943578	881	Economy	7500.00
0005434943581	881	Economy	7500.00
0005433255218	881	Economy	7500.00
0005434943575	881	Economy	7500.00
0005434943579	881	Economy	7500.00
0005433255208	881	Economy	7500.00
0005434943580	881	Economy	7500.00
0005433255209	881	Economy	7500.00
0005433255210	881	Economy	7500.00
0005434943576	881	Economy	7500.00
0005433255204	881	Economy	7500.00
0005433255213	881	Economy	7500.00
0005433255254	16228	Economy	7500.00
0005434943463	16228	Economy	7500.00
0005433255250	16228	Economy	7500.00
0005434943520	16228	Economy	7500.00
0005434943499	16228	Economy	7500.00
0005433255252	16228	Economy	7500.00
0005433255256	16228	Economy	7500.00
0005434943504	16228	Economy	7500.00
0005433255255	16228	Economy	7500.00
0005434943510	16228	Economy	7500.00
0005434943503	16228	Economy	7500.00
0005433255253	16228	Economy	7500.00
0005433255251	16228	Economy	7500.00
0005434943511	16228	Economy	7500.00
0005434943464	16228	Economy	7500.00
0005434943505	16228	Economy	7500.00
0005434943500	16228	Economy	7500.00
0005433654893	27615	Business	90500.00
0005433654843	27615	Business	90500.00
0005435858660	27615	Business	90500.00
0005433654894	27615	Business	90500.00
0005435858663	27615	Business	90500.00
0005433654871	27615	Economy	30200.00
0005433654896	27615	Economy	30200.00
0005435858668	27615	Economy	30200.00
0005435858664	27615	Economy	30200.00
0005435858657	27615	Economy	30200.00
0005433654881	27615	Economy	33200.00
0005433654883	27615	Economy	33200.00
0005433654882	27615	Economy	30200.00
0005433654877	27615	Economy	30200.00
0005435858666	27615	Economy	30200.00
0005433654867	27615	Economy	30200.00
0005433654875	27615	Economy	30200.00
0005433654886	27615	Economy	30200.00
0005433654847	27615	Economy	30200.00
0005433654887	27615	Economy	30200.00
0005433654842	27615	Economy	30200.00
0005435858658	27615	Economy	30200.00
0005435858662	27615	Economy	30200.00
0005433654895	27615	Economy	30200.00
0005435858665	27615	Economy	30200.00
0005435858667	27615	Economy	30200.00
0005435858659	27615	Economy	30200.00
0005433654889	27615	Economy	30200.00
0005433654888	27615	Economy	30200.00
0005433654870	27615	Economy	30200.00
0005435858661	27615	Economy	30200.00
0005435858669	27615	Economy	30200.00
0005433654814	27615	Economy	30200.00
0005433811664	14367	Economy	4400.00
0005433811657	14367	Economy	4400.00
0005433927530	14367	Economy	4400.00
0005433927529	14367	Economy	4400.00
0005435654129	21739	Business	9800.00
0005435654143	21739	Business	9800.00
0005435654115	21739	Business	9800.00
0005435654153	21739	Business	9800.00
0005435654114	21739	Business	9800.00
0005433368440	21739	Business	9800.00
0005435654109	21739	Business	9800.00
0005433368555	21739	Business	9800.00
0005433368570	21739	Business	9800.00
0005435654141	21739	Business	9800.00
0005435654112	21739	Business	9800.00
0005433368445	21739	Economy	3300.00
0005435654110	21739	Economy	3300.00
0005435654133	21739	Economy	3300.00
0005435654142	21739	Economy	3300.00
0005433368446	21739	Economy	3300.00
0005435654127	21739	Economy	3300.00
0005435654113	21739	Economy	3300.00
0005435654147	21739	Economy	3300.00
0005435654117	21739	Economy	3300.00
0005435654139	21739	Economy	3300.00
0005433368471	21739	Economy	3600.00
0005433368495	21739	Economy	3600.00
0005435654125	21739	Economy	3600.00
0005435654103	21739	Economy	3600.00
0005435654135	21739	Economy	3600.00
0005435654157	21739	Economy	3300.00
0005435654151	21739	Economy	3300.00
0005433368452	21739	Economy	3300.00
0005435654128	21739	Economy	3300.00
0005435654130	21739	Economy	3300.00
0005433368463	21739	Economy	3300.00
0005433368556	21739	Economy	3300.00
0005435654132	21739	Economy	3300.00
0005435654145	21739	Economy	3300.00
0005433368571	21739	Economy	3300.00
0005433368462	21739	Economy	3300.00
0005435654111	21739	Economy	3300.00
0005435654156	21739	Economy	3300.00
0005433368461	21739	Economy	3300.00
0005435654121	21739	Economy	3300.00
0005435654154	21739	Economy	3300.00
0005433368453	21739	Economy	3300.00
0005435654148	21739	Economy	3300.00
0005433368481	21739	Economy	3300.00
0005435654137	21739	Economy	3300.00
0005433368650	21739	Economy	3300.00
0005433368536	21739	Economy	3300.00
0005435654150	21739	Economy	3300.00
0005433368535	21739	Economy	3300.00
0005435654136	21739	Economy	3300.00
0005435654106	21739	Economy	3300.00
0005435654107	21739	Economy	3300.00
0005433368418	21739	Economy	3300.00
0005435654140	21739	Economy	3300.00
0005435654144	21739	Economy	3300.00
0005435654146	21739	Economy	3300.00
0005435654126	21739	Economy	3300.00
0005433368401	21739	Economy	3300.00
0005435654104	21739	Economy	3300.00
0005435654108	21739	Economy	3300.00
0005435654102	21739	Economy	3300.00
0005433368420	21739	Economy	3300.00
0005435654116	21739	Economy	3300.00
0005435654123	21739	Economy	3300.00
0005433368321	21739	Economy	3300.00
0005435654138	21739	Economy	3300.00
0005435654152	21739	Economy	3300.00
0005435654119	21739	Economy	3300.00
0005435654101	21739	Economy	3300.00
0005435654131	21739	Economy	3300.00
0005435654118	21739	Economy	3300.00
0005433368346	21739	Economy	3300.00
0005435654124	21739	Economy	3300.00
0005435654134	21739	Economy	3300.00
0005433368613	21739	Economy	3300.00
0005435654120	21739	Economy	3300.00
0005433368364	21739	Economy	3300.00
0005433368400	21739	Economy	3300.00
0005433368470	21739	Economy	3300.00
0005435654105	21739	Economy	3300.00
0005433368427	21739	Economy	3300.00
0005433368365	21739	Economy	3300.00
0005433368441	21739	Economy	3300.00
0005433368649	21739	Economy	3300.00
0005433368402	21739	Economy	3300.00
0005433368322	21739	Economy	3300.00
0005433368438	21739	Economy	3300.00
0005435654158	21739	Economy	3300.00
0005435654155	21739	Economy	3300.00
0005433368426	21739	Economy	3300.00
0005433368417	21739	Economy	3300.00
0005435654149	21739	Economy	3300.00
0005435654122	21739	Economy	3300.00
0005433785849	9355	Business	186200.00
0005435269814	9355	Business	186200.00
0005433806234	9355	Business	186200.00
0005433806219	9355	Business	186200.00
0005433806216	9355	Business	186200.00
0005432667505	9355	Business	186200.00
0005433785836	9355	Business	186200.00
0005433806228	9355	Business	186200.00
0005432657525	9355	Business	186200.00
0005433806214	9355	Business	186200.00
0005433785833	9355	Business	186200.00
0005433806240	9355	Business	186200.00
0005433806229	9355	Business	186200.00
0005433806227	9355	Business	186200.00
0005434171287	9355	Business	186200.00
0005432657524	9355	Business	186200.00
0005433806237	9355	Business	186200.00
0005432666439	9355	Economy	68300.00
0005433785838	9355	Economy	68300.00
0005433763565	9355	Economy	62100.00
0005433763556	9355	Economy	68300.00
0005433785857	9355	Economy	62100.00
0005433785859	9355	Economy	62100.00
0005433785834	9355	Economy	62100.00
0005434171302	9355	Economy	62100.00
0005433785823	9355	Economy	62100.00
0005433785821	9355	Economy	62100.00
0005434171257	9355	Economy	62100.00
0005432667504	9355	Economy	62100.00
0005433785850	9355	Economy	62100.00
0005433806222	9355	Economy	62100.00
0005434171304	9355	Economy	62100.00
0005434171272	9355	Economy	62100.00
0005433806245	9355	Economy	62100.00
0005433785847	9355	Economy	62100.00
0005433763555	9355	Economy	62100.00
0005433785856	9355	Economy	62100.00
0005432666440	9355	Economy	62100.00
0005433785831	9355	Economy	62100.00
0005433785824	9355	Economy	62100.00
0005434171256	9355	Economy	62100.00
0005433763562	9355	Economy	62100.00
0005434171322	9355	Economy	62100.00
0005433806236	9355	Economy	62100.00
0005433785825	9355	Economy	62100.00
0005433785819	9355	Economy	62100.00
0005433806244	9355	Economy	62100.00
0005433785822	9355	Economy	62100.00
0005432657526	9355	Economy	62100.00
0005434171300	9355	Economy	62100.00
0005433763557	9355	Economy	62100.00
0005433785844	9355	Economy	62100.00
0005433806226	9355	Economy	62100.00
0005433763558	9355	Economy	62100.00
0005433806232	9355	Economy	62100.00
0005433806213	9355	Economy	62100.00
0005432665326	9355	Economy	62100.00
0005433806208	9355	Economy	62100.00
0005434171303	9355	Economy	62100.00
0005433785848	9355	Economy	62100.00
0005433785842	9355	Economy	62100.00
0005433785830	9355	Economy	62100.00
0005433806235	9355	Economy	62100.00
0005433785852	9355	Economy	62100.00
0005434270238	9355	Economy	62100.00
0005433806238	9355	Economy	62100.00
0005434171240	9355	Economy	62100.00
0005433763566	9355	Economy	62100.00
0005433785854	9355	Economy	62100.00
0005432667507	9355	Economy	62100.00
0005433785851	9355	Economy	62100.00
0005434171307	9355	Economy	62100.00
0005433763563	9355	Economy	62100.00
0005433806239	9355	Economy	68300.00
0005433806221	9355	Economy	62100.00
0005433785846	9355	Economy	62100.00
0005433785829	9355	Economy	62100.00
0005434171323	9355	Economy	62100.00
0005433806215	9355	Economy	62100.00
0005433763559	9355	Economy	62100.00
0005433785837	9355	Economy	62100.00
0005433785828	9355	Economy	62100.00
0005433785853	9355	Economy	62100.00
0005433763567	9355	Economy	62100.00
0005434171308	9355	Economy	62100.00
0005433806223	9355	Economy	62100.00
0005433806230	9355	Economy	62100.00
0005433785827	9355	Economy	62100.00
0005433806210	9355	Economy	62100.00
0005433806225	9355	Economy	62100.00
0005433785855	9355	Economy	62100.00
0005433785835	9355	Economy	62100.00
0005433785841	9355	Economy	62100.00
0005433785826	9355	Economy	62100.00
0005433763564	9355	Economy	62100.00
0005433806224	9355	Economy	62100.00
0005433785839	9355	Economy	62100.00
0005433785820	9355	Economy	62100.00
0005435269813	9355	Economy	62100.00
0005434171349	9355	Economy	62100.00
0005433806243	9355	Economy	62100.00
0005433806211	9355	Economy	62100.00
0005434171301	9355	Economy	62100.00
0005433763561	9355	Economy	62100.00
0005433806233	9355	Economy	62100.00
0005433806231	9355	Economy	62100.00
0005433785845	9355	Economy	62100.00
0005433763560	9355	Economy	62100.00
0005433806209	9355	Economy	62100.00
0005433806207	9355	Economy	62100.00
0005433806212	9355	Economy	62100.00
0005433785832	9355	Economy	62100.00
0005433806218	9355	Economy	62100.00
0005433806220	9355	Economy	62100.00
0005432667506	9355	Economy	62100.00
0005433806217	9355	Economy	62100.00
0005433785858	9355	Economy	62100.00
0005433763568	9355	Economy	62100.00
0005433806246	9355	Economy	62100.00
0005433785840	9355	Economy	62100.00
0005434171286	9355	Economy	62100.00
0005433785843	9355	Economy	62100.00
0005433806241	9355	Economy	62100.00
0005433806242	9355	Economy	62100.00
0005434151750	9355	Economy	62100.00
0005435858702	26272	Business	186200.00
0005433805875	26272	Business	186200.00
0005435270048	26272	Business	186200.00
0005435270054	26272	Business	186200.00
0005433763384	26272	Business	186200.00
0005433805846	26272	Business	186200.00
0005434171410	26272	Business	186200.00
0005433805809	26272	Business	186200.00
0005433805832	26272	Business	186200.00
0005434151775	26272	Business	186200.00
0005435270020	26272	Business	186200.00
0005434269153	26272	Business	186200.00
0005435270045	26272	Business	186200.00
0005434151778	26272	Business	186200.00
0005433785581	26272	Business	186200.00
0005435270015	26272	Business	186200.00
0005435270059	26272	Business	186200.00
0005432666416	26272	Business	186200.00
0005435270029	26272	Business	186200.00
0005434171401	26272	Business	186200.00
0005435270032	26272	Business	186200.00
0005433805839	26272	Business	186200.00
0005433805988	26272	Business	186200.00
0005435270047	26272	Economy	68300.00
0005434171409	26272	Economy	68300.00
0005433805908	26272	Economy	68300.00
0005433785564	26272	Economy	62100.00
0005433785385	26272	Economy	62100.00
0005435270039	26272	Economy	62100.00
0005434269152	26272	Economy	62100.00
0005433785622	26272	Economy	62100.00
0005432657482	26272	Economy	62100.00
0005433785569	26272	Economy	62100.00
0005434171400	26272	Economy	62100.00
0005433806028	26272	Economy	62100.00
0005434171402	26272	Economy	62100.00
0005435858704	26272	Economy	62100.00
0005433763419	26272	Economy	62100.00
0005433805880	26272	Economy	62100.00
0005433806053	26272	Economy	62100.00
0005433805879	26272	Economy	62100.00
0005435858707	26272	Economy	62100.00
0005433805954	26272	Economy	62100.00
0005435270052	26272	Economy	62100.00
0005435270053	26272	Economy	62100.00
0005433805921	26272	Economy	62100.00
0005433785565	26272	Economy	62100.00
0005433763421	26272	Economy	62100.00
0005435270025	26272	Economy	62100.00
0005435270037	26272	Economy	62100.00
0005434270257	26272	Economy	62100.00
0005433805900	26272	Economy	62100.00
0005435270034	26272	Economy	62100.00
0005434171405	26272	Economy	62100.00
0005435858703	26272	Economy	62100.00
0005433805808	26272	Economy	62100.00
0005433805840	26272	Economy	62100.00
0005433805831	26272	Economy	62100.00
0005435270031	26272	Economy	62100.00
0005434151777	26272	Economy	62100.00
0005432663059	26272	Economy	62100.00
0005434171412	26272	Economy	62100.00
0005434171403	26272	Economy	62100.00
0005435270058	26272	Economy	62100.00
0005435270036	26272	Economy	62100.00
0005434171404	26272	Economy	62100.00
0005435858705	26272	Economy	62100.00
0005433805961	26272	Economy	62100.00
0005435270044	26272	Economy	62100.00
0005433785547	26272	Economy	62100.00
0005435270023	26272	Economy	62100.00
0005433806123	26272	Economy	62100.00
0005433806027	26272	Economy	62100.00
0005435270057	26272	Economy	62100.00
0005435270030	26272	Economy	62100.00
0005433785516	26272	Economy	62100.00
0005435270043	26272	Economy	62100.00
0005433805915	26272	Economy	62100.00
0005433805968	26272	Economy	62100.00
0005433805801	26272	Economy	62100.00
0005435270027	26272	Economy	62100.00
0005435270038	26272	Economy	62100.00
0005433763420	26272	Economy	62100.00
0005435270028	26272	Economy	62100.00
0005433805920	26272	Economy	62100.00
0005433785515	26272	Economy	62100.00
0005435270035	26272	Economy	62100.00
0005433763418	26272	Economy	62100.00
0005435270018	26272	Economy	62100.00
0005434171406	26272	Economy	62100.00
0005435858708	26272	Economy	62100.00
0005434269151	26272	Economy	62100.00
0005435270041	26272	Economy	68300.00
0005433805925	26272	Economy	62100.00
0005432657483	26272	Economy	68300.00
0005433805899	26272	Economy	68300.00
0005435270049	26272	Economy	62100.00
0005433763475	26272	Economy	62100.00
0005433805830	26272	Economy	62100.00
0005435270040	26272	Economy	62100.00
0005433763395	26272	Economy	62100.00
0005435270042	26272	Economy	62100.00
0005435270019	26272	Economy	62100.00
0005433785470	26272	Economy	62100.00
0005435270016	26272	Economy	62100.00
0005435270055	26272	Economy	62100.00
0005433785535	26272	Economy	62100.00
0005435858709	26272	Economy	62100.00
0005435270056	26272	Economy	62100.00
0005433785563	26272	Economy	62100.00
0005432657480	26272	Economy	62100.00
0005434171407	26272	Economy	62100.00
0005433805979	26272	Economy	62100.00
0005433763409	26272	Economy	62100.00
0005433805784	26272	Economy	62100.00
0005435270014	26272	Economy	62100.00
0005433805836	26272	Economy	62100.00
0005434171413	26272	Economy	62100.00
0005435270017	26272	Economy	62100.00
0005435270046	26272	Economy	62100.00
0005435270033	26272	Economy	62100.00
0005435270022	26272	Economy	62100.00
0005433805970	26272	Economy	62100.00
0005433805960	26272	Economy	62100.00
0005433785471	26272	Economy	62100.00
0005434151776	26272	Economy	62100.00
0005435858706	26272	Economy	62100.00
0005435270050	26272	Economy	62100.00
0005433805882	26272	Economy	62100.00
0005433805864	26272	Economy	62100.00
0005433805881	26272	Economy	62100.00
0005434151779	26272	Economy	62100.00
0005433763426	26272	Economy	62100.00
0005433805927	26272	Economy	62100.00
0005433805969	26272	Economy	62100.00
0005434171411	26272	Economy	62100.00
0005435270021	26272	Economy	62100.00
0005433805956	26272	Economy	62100.00
0005434171408	26272	Economy	62100.00
0005433805919	26272	Economy	62100.00
0005433785570	26272	Economy	62100.00
0005435270026	26272	Economy	62100.00
0005435270024	26272	Economy	62100.00
0005435858701	26272	Economy	62100.00
0005435270013	26272	Economy	62100.00
0005433805938	26272	Economy	62100.00
0005433805926	26272	Economy	62100.00
0005435270051	26272	Economy	62100.00
0005433805843	26272	Economy	62100.00
0005433805863	26272	Economy	62100.00
0005435929689	4930	Economy	5900.00
0005435135790	4930	Economy	5300.00
0005435929688	4930	Economy	5300.00
0005435929690	4930	Economy	5300.00
0005435929674	4930	Economy	5300.00
0005435135791	4930	Economy	5300.00
0005435135788	4930	Economy	5300.00
0005435135789	4930	Economy	5300.00
0005435929673	4930	Economy	5300.00
0005435929675	4930	Economy	5300.00
0005435929712	33012	Economy	5900.00
0005435135741	33012	Economy	5900.00
0005435929710	33012	Economy	5300.00
0005435135755	33012	Economy	5300.00
0005435135734	33012	Economy	5300.00
0005435135733	33012	Economy	5300.00
0005435929709	33012	Economy	5300.00
0005435135742	33012	Economy	5300.00
0005435929711	33012	Economy	5300.00
0005434983412	9499	Economy	19700.00
0005434218031	9499	Economy	19700.00
0005434983415	9499	Economy	19700.00
0005434983414	9499	Economy	17900.00
0005434983417	9499	Economy	17900.00
0005434218021	9499	Economy	17900.00
0005434218032	9499	Economy	17900.00
0005434983413	9499	Economy	17900.00
0005434983416	9499	Economy	17900.00
0005434218070	27388	Economy	19700.00
0005434218069	27388	Economy	17900.00
0005434983379	27388	Economy	17900.00
0005434218067	27388	Economy	17900.00
0005434983359	27388	Economy	17900.00
0005434983360	27388	Economy	17900.00
0005434983381	27388	Economy	17900.00
0005434218068	27388	Economy	17900.00
0005434983378	27388	Economy	17900.00
0005434983358	27388	Economy	17900.00
0005434983380	27388	Economy	17900.00
0005433986788	24281	Business	36400.00
0005433986734	24281	Business	36400.00
0005433961573	24281	Business	36400.00
0005433961743	24281	Business	36400.00
0005433961682	24281	Business	36400.00
0005433961832	24281	Business	36400.00
0005433986789	24281	Business	36400.00
0005433961525	24281	Business	36400.00
0005433986763	24281	Business	36400.00
0005433986796	24281	Business	36400.00
0005433961621	24281	Business	36400.00
0005433986560	24281	Business	36400.00
0005433961770	24281	Business	36400.00
0005433986731	24281	Business	36400.00
0005433961577	24281	Business	36400.00
0005433986554	24281	Business	36400.00
0005433986698	24281	Business	36400.00
0005433986555	24281	Economy	13400.00
0005433961574	24281	Economy	13400.00
0005433986727	24281	Economy	12100.00
0005433986774	24281	Economy	12100.00
0005433961701	24281	Economy	12100.00
0005433961769	24281	Economy	12100.00
0005433961779	24281	Economy	12100.00
0005433986729	24281	Economy	12100.00
0005433986802	24281	Economy	12100.00
0005433961647	24281	Economy	12100.00
0005433961592	24281	Economy	12100.00
0005433986490	24281	Economy	12100.00
0005433961576	24281	Economy	12100.00
0005433961514	24281	Economy	12100.00
0005433961646	24281	Economy	12100.00
0005433986690	24281	Economy	12100.00
0005433986738	24281	Economy	12100.00
0005433986733	24281	Economy	12100.00
0005433961784	24281	Economy	12100.00
0005433986785	24281	Economy	12100.00
0005433961677	24281	Economy	12100.00
0005433986442	24281	Economy	12100.00
0005433986699	24281	Economy	12100.00
0005433986750	24281	Economy	12100.00
0005433986732	24281	Economy	12100.00
0005433961688	24281	Economy	12100.00
0005433986784	24281	Economy	12100.00
0005433961834	24281	Economy	12100.00
0005433961748	24281	Economy	12100.00
0005433961768	24281	Economy	12100.00
0005433961651	24281	Economy	12100.00
0005433961640	24281	Economy	12100.00
0005433986562	24281	Economy	12100.00
0005433961689	24281	Economy	12100.00
0005433961813	24281	Economy	12100.00
0005433961538	24281	Economy	12100.00
0005433986709	24281	Economy	12100.00
0005433961764	24281	Economy	12100.00
0005433986795	24281	Economy	12100.00
0005433961794	24281	Economy	12100.00
0005433986680	24281	Economy	12100.00
0005433986450	24281	Economy	12100.00
0005433986714	24281	Economy	12100.00
0005433986614	24281	Economy	12100.00
0005433986689	24281	Economy	12100.00
0005433961726	24281	Economy	12100.00
0005433961370	24281	Economy	12100.00
0005433986528	24281	Economy	12100.00
0005433961747	24281	Economy	12100.00
0005433961639	24281	Economy	12100.00
0005433986717	24281	Economy	12100.00
0005433986631	24281	Economy	12100.00
0005433961620	24281	Economy	12100.00
0005433986694	24281	Economy	12100.00
0005433961645	24281	Economy	12100.00
0005433986757	24281	Economy	12100.00
0005433986681	24281	Economy	12100.00
0005433986779	24281	Economy	12100.00
0005433986583	24281	Economy	13400.00
0005433961814	24281	Economy	12100.00
0005433986530	24281	Economy	12100.00
0005433961799	24281	Economy	12100.00
0005433961532	24281	Economy	13400.00
0005433986531	24281	Economy	13400.00
0005433986840	24281	Economy	12100.00
0005433961711	24281	Economy	12100.00
0005433986711	24281	Economy	12100.00
0005433986702	24281	Economy	12100.00
0005433961633	24281	Economy	12100.00
0005433961638	24281	Economy	12100.00
0005433986529	24281	Economy	12100.00
0005433961687	24281	Economy	12100.00
0005433961598	24281	Economy	12100.00
0005433986503	24281	Economy	12100.00
0005433986590	24281	Economy	12100.00
0005433961632	24281	Economy	12100.00
0005433961810	24281	Economy	12100.00
0005433961504	24281	Economy	12100.00
0005433961706	24281	Economy	12100.00
0005433986798	24281	Economy	12100.00
0005433961691	24281	Economy	12100.00
0005433961667	24281	Economy	12100.00
0005433961635	24281	Economy	12100.00
0005433961530	24281	Economy	12100.00
0005433986780	24281	Economy	12100.00
0005433961531	24281	Economy	12100.00
0005433961612	24281	Economy	12100.00
0005433986559	24281	Economy	12100.00
0005433986703	24281	Economy	12100.00
0005433961797	24281	Economy	12100.00
0005433986728	24281	Economy	12100.00
0005433986695	24281	Economy	12100.00
0005433986760	24281	Economy	12100.00
0005433986759	24281	Economy	12100.00
0005433961591	24281	Economy	12100.00
0005433986735	24281	Economy	12100.00
0005433961522	24281	Economy	12100.00
0005433986561	24281	Economy	12100.00
0005433961771	24281	Economy	12100.00
0005433961686	24281	Economy	12100.00
0005433986756	24281	Economy	12100.00
0005433986596	24281	Economy	12100.00
0005433986558	24281	Economy	12100.00
0005433961670	24281	Economy	12100.00
0005433961669	24281	Economy	12100.00
0005433962251	25924	Business	36400.00
0005433962224	25924	Business	36400.00
0005433962234	25924	Business	36400.00
0005433987047	25924	Business	36400.00
0005433987042	25924	Business	36400.00
0005433962225	25924	Business	36400.00
0005433962219	25924	Business	36400.00
0005433962206	25924	Business	36400.00
0005433987034	25924	Business	36400.00
0005433962262	25924	Business	36400.00
0005433962231	25924	Business	36400.00
0005433962239	25924	Business	36400.00
0005433962243	25924	Business	36400.00
0005433962263	25924	Business	36400.00
0005433962253	25924	Business	36400.00
0005433987082	25924	Business	36400.00
0005433962240	25924	Business	36400.00
0005433987049	25924	Business	36400.00
0005433987070	25924	Business	36400.00
0005433987080	25924	Business	36400.00
0005433962215	25924	Economy	13400.00
0005433987071	25924	Economy	12100.00
0005433987032	25924	Economy	12100.00
0005433987085	25924	Economy	12100.00
0005433962245	25924	Economy	12100.00
0005433962250	25924	Economy	12100.00
0005433987077	25924	Economy	12100.00
0005433987040	25924	Economy	12100.00
0005433987061	25924	Economy	12100.00
0005433962265	25924	Economy	12100.00
0005433962238	25924	Economy	12100.00
0005433962207	25924	Economy	12100.00
0005433962223	25924	Economy	12100.00
0005433987051	25924	Economy	12100.00
0005433987054	25924	Economy	12100.00
0005433987086	25924	Economy	12100.00
0005433962237	25924	Economy	12100.00
0005433987038	25924	Economy	12100.00
0005433987035	25924	Economy	12100.00
0005433987074	25924	Economy	12100.00
0005433987044	25924	Economy	12100.00
0005433987057	25924	Economy	12100.00
0005433962249	25924	Economy	12100.00
0005433987059	25924	Economy	12100.00
0005433987053	25924	Economy	12100.00
0005433962255	25924	Economy	12100.00
0005433962209	25924	Economy	12100.00
0005433962228	25924	Economy	12100.00
0005433987060	25924	Economy	12100.00
0005433987062	25924	Economy	12100.00
0005433987083	25924	Economy	12100.00
0005433987084	25924	Economy	12100.00
0005433987072	25924	Economy	12100.00
0005433987045	25924	Economy	12100.00
0005433962222	25924	Economy	12100.00
0005433987063	25924	Economy	12100.00
0005433962214	25924	Economy	12100.00
0005433962218	25924	Economy	12100.00
0005433962226	25924	Economy	12100.00
0005433962212	25924	Economy	12100.00
0005433987075	25924	Economy	12100.00
0005433987036	25924	Economy	12100.00
0005433962217	25924	Economy	12100.00
0005433962220	25924	Economy	12100.00
0005433962210	25924	Economy	12100.00
0005433987033	25924	Economy	12100.00
0005433962236	25924	Economy	12100.00
0005433987041	25924	Economy	12100.00
0005433987031	25924	Economy	12100.00
0005433962233	25924	Economy	12100.00
0005433962203	25924	Economy	12100.00
0005433962248	25924	Economy	12100.00
0005433962247	25924	Economy	12100.00
0005433987069	25924	Economy	12100.00
0005433962246	25924	Economy	12100.00
0005433987037	25924	Economy	12100.00
0005433962257	25924	Economy	13400.00
0005433987068	25924	Economy	12100.00
0005433962230	25924	Economy	12100.00
0005433962261	25924	Economy	13400.00
0005433987039	25924	Economy	12100.00
0005433962227	25924	Economy	12100.00
0005433987058	25924	Economy	12100.00
0005433962259	25924	Economy	12100.00
0005433962208	25924	Economy	12100.00
0005433987067	25924	Economy	12100.00
0005433987046	25924	Economy	12100.00
0005433962235	25924	Economy	12100.00
0005433962205	25924	Economy	12100.00
0005433962242	25924	Economy	12100.00
0005433962211	25924	Economy	12100.00
0005433962204	25924	Economy	12100.00
0005433962244	25924	Economy	12100.00
0005433987073	25924	Economy	12100.00
0005433987081	25924	Economy	12100.00
0005433987048	25924	Economy	12100.00
0005433962221	25924	Economy	12100.00
0005433962260	25924	Economy	12100.00
0005433987050	25924	Economy	12100.00
0005433962252	25924	Economy	12100.00
0005433962258	25924	Economy	12100.00
0005433962213	25924	Economy	12100.00
0005433962202	25924	Economy	12100.00
0005433987055	25924	Economy	12100.00
0005433962201	25924	Economy	12100.00
0005433962216	25924	Economy	12100.00
0005433962241	25924	Economy	12100.00
0005433987076	25924	Economy	12100.00
0005433987079	25924	Economy	12100.00
0005433962232	25924	Economy	12100.00
0005433962200	25924	Economy	12100.00
0005433962256	25924	Economy	12100.00
0005433962254	25924	Economy	12100.00
0005433987064	25924	Economy	12100.00
0005433987078	25924	Economy	12100.00
0005433987056	25924	Economy	12100.00
0005433987065	25924	Economy	12100.00
0005433987066	25924	Economy	12100.00
0005433962229	25924	Economy	12100.00
0005433987043	25924	Economy	12100.00
0005433987052	25924	Economy	12100.00
0005433962264	25924	Economy	12100.00
0005432269564	960	Economy	25400.00
0005434480929	960	Economy	23100.00
0005434480933	960	Economy	23100.00
0005434480937	960	Economy	23100.00
0005434480936	960	Economy	23100.00
0005434480941	960	Economy	23100.00
0005433166121	960	Economy	23100.00
0005432269565	960	Economy	23100.00
0005434480931	960	Economy	23100.00
0005433166127	960	Economy	23100.00
0005434480943	960	Economy	23100.00
0005432269563	960	Economy	23100.00
0005434480940	960	Economy	23100.00
0005434480945	960	Economy	23100.00
0005433166083	960	Economy	23100.00
0005434480944	960	Economy	23100.00
0005433166156	960	Economy	23100.00
0005434480942	960	Economy	23100.00
0005433166183	960	Economy	23100.00
0005434480939	960	Economy	23100.00
0005434480934	960	Economy	23100.00
0005434480935	960	Economy	23100.00
0005433166184	960	Economy	23100.00
0005434480928	960	Economy	23100.00
0005434480930	960	Economy	23100.00
0005434480946	960	Economy	23100.00
0005434480932	960	Economy	23100.00
0005434480938	960	Economy	23100.00
0005434480702	16608	Economy	25400.00
0005434480712	16608	Economy	25400.00
0005434480703	16608	Economy	25400.00
0005433166229	16608	Economy	25400.00
0005434480603	16608	Economy	23100.00
0005433166218	16608	Economy	23100.00
0005434480756	16608	Economy	23100.00
0005433166225	16608	Economy	23100.00
0005433166224	16608	Economy	23100.00
0005433166219	16608	Economy	23100.00
0005434480745	16608	Economy	23100.00
0005433166221	16608	Economy	23100.00
0005434480604	16608	Economy	23100.00
0005433166223	16608	Economy	23100.00
0005433166230	16608	Economy	23100.00
0005434480674	16608	Economy	23100.00
0005434480707	16608	Economy	23100.00
0005433166216	16608	Economy	23100.00
0005434480686	16608	Economy	23100.00
0005434480691	16608	Economy	23100.00
0005434480746	16608	Economy	23100.00
0005434480701	16608	Economy	23100.00
0005433166222	16608	Economy	23100.00
0005434480675	16608	Economy	23100.00
0005433166220	16608	Economy	23100.00
0005434480692	16608	Economy	23100.00
0005433166228	16608	Economy	23100.00
0005433166217	16608	Economy	23100.00
0005434480785	16608	Economy	23100.00
0005434480786	16608	Economy	23100.00
0005434480717	16608	Economy	23100.00
0005434480690	16608	Economy	23100.00
0005433166227	16608	Economy	23100.00
0005433166226	16608	Economy	23100.00
0005435386655	10330	Economy	17000.00
0005435142894	10330	Economy	17000.00
0005435150361	10330	Economy	17000.00
0005435150363	10330	Economy	17000.00
0005435142903	10330	Economy	15400.00
0005435150354	10330	Economy	15400.00
0005435142897	10330	Economy	15400.00
0005435386658	10330	Economy	15400.00
0005435150365	10330	Economy	15400.00
0005435150362	10330	Economy	15400.00
0005435386662	10330	Economy	15400.00
0005435142892	10330	Economy	15400.00
0005435150360	10330	Economy	15400.00
0005433289963	10330	Economy	15400.00
0005433289945	10330	Economy	15400.00
0005435150357	10330	Economy	15400.00
0005433289966	10330	Economy	15400.00
0005435386660	10330	Economy	15400.00
0005435150355	10330	Economy	15400.00
0005435150356	10330	Economy	15400.00
0005435142893	10330	Economy	15400.00
0005435386688	10330	Economy	15400.00
0005435386637	10330	Economy	15400.00
0005435142899	10330	Economy	15400.00
0005435150359	10330	Economy	15400.00
0005435142898	10330	Economy	15400.00
0005435150364	10330	Economy	15400.00
0005435386661	10330	Economy	15400.00
0005435142901	10330	Economy	15400.00
0005435142891	10330	Economy	15400.00
0005435386638	10330	Economy	15400.00
0005435150353	10330	Economy	15400.00
0005435142902	10330	Economy	15400.00
0005435386657	10330	Economy	15400.00
0005435142896	10330	Economy	15400.00
0005435142895	10330	Economy	15400.00
0005435150358	10330	Economy	15400.00
0005433289958	10330	Economy	15400.00
0005435142900	10330	Economy	15400.00
0005435386659	10330	Economy	15400.00
0005435386664	10330	Economy	15400.00
0005435386674	10330	Economy	15400.00
0005433289965	10330	Economy	15400.00
0005435142904	10330	Economy	15400.00
0005435142754	21951	Economy	17000.00
0005435386731	21951	Economy	17000.00
0005435150263	21951	Economy	17000.00
0005435142800	21951	Economy	17000.00
0005433290031	21951	Economy	15400.00
0005435386729	21951	Economy	15400.00
0005435150240	21951	Economy	15400.00
0005435142762	21951	Economy	15400.00
0005435150274	21951	Economy	15400.00
0005435150279	21951	Economy	15400.00
0005435142670	21951	Economy	15400.00
0005435386727	21951	Economy	15400.00
0005435142724	21951	Economy	15400.00
0005435386732	21951	Economy	15400.00
0005435142671	21951	Economy	15400.00
0005435386726	21951	Economy	15400.00
0005433290034	21951	Economy	15400.00
0005435150275	21951	Economy	15400.00
0005435150237	21951	Economy	15400.00
0005435150241	21951	Economy	15400.00
0005435386728	21951	Economy	15400.00
0005435150248	21951	Economy	15400.00
0005435142833	21951	Economy	15400.00
0005435150249	21951	Economy	15400.00
0005435150234	21951	Economy	15400.00
0005435150278	21951	Economy	15400.00
0005435142763	21951	Economy	15400.00
0005435142715	21951	Economy	15400.00
0005435142729	21951	Economy	15400.00
0005435150212	21951	Economy	15400.00
0005435142669	21951	Economy	15400.00
0005435142799	21951	Economy	15400.00
0005435386730	21951	Economy	15400.00
0005435142761	21951	Economy	15400.00
0005435142716	21951	Economy	15400.00
0005435150193	21951	Economy	15400.00
0005433290035	21951	Economy	15400.00
0005435150294	21951	Economy	15400.00
0005435150155	21951	Economy	15400.00
0005435386725	21951	Economy	15400.00
0005433290032	21951	Economy	15400.00
0005433290033	21951	Economy	15400.00
0005435150239	21951	Economy	15400.00
0005435142835	21951	Economy	15400.00
0005435529639	11219	Business	57200.00
0005435502692	11219	Business	57200.00
0005435502618	11219	Business	57200.00
0005435502634	11219	Business	57200.00
0005435502620	11219	Business	57200.00
0005435502659	11219	Business	57200.00
0005435529592	11219	Business	57200.00
0005435319699	11219	Business	57200.00
0005434573692	11219	Economy	19100.00
0005435529640	11219	Economy	19100.00
0005435319714	11219	Economy	19100.00
0005435529501	11219	Economy	19100.00
0005435502704	11219	Economy	19100.00
0005434573685	11219	Economy	19100.00
0005434573686	11219	Economy	19100.00
0005435529567	11219	Economy	19100.00
0005435529591	11219	Economy	21000.00
0005435319729	11219	Economy	21000.00
0005435502712	11219	Economy	21000.00
0005435502693	11219	Economy	21000.00
0005434573684	11219	Economy	19100.00
0005435502700	11219	Economy	19100.00
0005434573681	11219	Economy	19100.00
0005435529525	11219	Economy	19100.00
0005434573680	11219	Economy	19100.00
0005435319730	11219	Economy	19100.00
0005434573687	11219	Economy	19100.00
0005435545872	11219	Economy	19100.00
0005435502664	11219	Economy	19100.00
0005435529526	11219	Economy	19100.00
0005435529585	11219	Economy	19100.00
0005435502711	11219	Economy	19100.00
0005435502697	11219	Economy	19100.00
0005435529632	11219	Economy	19100.00
0005435545852	11219	Economy	19100.00
0005434573679	11219	Economy	19100.00
0005435502617	11219	Economy	19100.00
0005435529584	11219	Economy	19100.00
0005435502658	11219	Economy	19100.00
0005435502694	11219	Economy	19100.00
0005434573691	11219	Economy	19100.00
0005434573682	11219	Economy	19100.00
0005435529582	11219	Economy	19100.00
0005435502719	11219	Economy	19100.00
0005435529603	11219	Economy	19100.00
0005435545873	11219	Economy	19100.00
0005435545853	11219	Economy	19100.00
0005435319697	11219	Economy	19100.00
0005435529601	11219	Economy	19100.00
0005435502691	11219	Economy	19100.00
0005435502678	11219	Economy	19100.00
0005434573689	11219	Economy	19100.00
0005435502698	11219	Economy	19100.00
0005435545871	11219	Economy	19100.00
0005435319717	11219	Economy	19100.00
0005435529611	11219	Economy	19100.00
0005435502724	11219	Economy	19100.00
0005435529609	11219	Economy	19100.00
0005435502701	11219	Economy	19100.00
0005434573688	11219	Economy	19100.00
0005435529641	11219	Economy	19100.00
0005435502576	11219	Economy	19100.00
0005435502720	11219	Economy	19100.00
0005435319678	11219	Economy	19100.00
0005435529633	11219	Economy	19100.00
0005435502575	11219	Economy	19100.00
0005435545851	11219	Economy	19100.00
0005435319716	11219	Economy	19100.00
0005435502699	11219	Economy	19100.00
0005434573683	11219	Economy	19100.00
0005435319749	11219	Economy	19100.00
0005434573690	11219	Economy	19100.00
0005435502665	11219	Economy	19100.00
0005435529580	11219	Economy	19100.00
0005435502725	11219	Economy	19100.00
0005435545874	11219	Economy	19100.00
0005435319675	11219	Economy	19100.00
0005435529568	11219	Economy	19100.00
0005435529563	11219	Economy	19100.00
0005435502829	20911	Business	57200.00
0005435518339	20911	Business	57200.00
0005435518346	20911	Business	57200.00
0005435502839	20911	Business	57200.00
0005435502831	20911	Business	57200.00
0005435319802	20911	Business	57200.00
0005434573576	20911	Business	57200.00
0005435502836	20911	Business	57200.00
0005435502828	20911	Business	57200.00
0005435518338	20911	Business	57200.00
0005434573575	20911	Business	57200.00
0005434573566	20911	Economy	19100.00
0005435508695	20911	Economy	19100.00
0005435508697	20911	Economy	19100.00
0005435518342	20911	Economy	19100.00
0005435508694	20911	Economy	19100.00
0005435508689	20911	Economy	19100.00
0005435508705	20911	Economy	19100.00
0005435319799	20911	Economy	19100.00
0005435508685	20911	Economy	19100.00
0005432291989	20911	Economy	21000.00
0005435508702	20911	Economy	21000.00
0005434573632	20911	Economy	21000.00
0005435508686	20911	Economy	21000.00
0005435508688	20911	Economy	19100.00
0005435508699	20911	Economy	19100.00
0005434573568	20911	Economy	19100.00
0005435518336	20911	Economy	19100.00
0005435319798	20911	Economy	19100.00
0005434573565	20911	Economy	19100.00
0005435518335	20911	Economy	19100.00
0005435502825	20911	Economy	19100.00
0005435502820	20911	Economy	19100.00
0005435508704	20911	Economy	19100.00
0005435508693	20911	Economy	19100.00
0005435319801	20911	Economy	19100.00
0005434573569	20911	Economy	19100.00
0005435508692	20911	Economy	19100.00
0005435508684	20911	Economy	19100.00
0005435319800	20911	Economy	19100.00
0005435508690	20911	Economy	19100.00
0005435502824	20911	Economy	19100.00
0005435502823	20911	Economy	19100.00
0005435518344	20911	Economy	19100.00
0005435508701	20911	Economy	19100.00
0005435518348	20911	Economy	19100.00
0005435502819	20911	Economy	19100.00
0005435508700	20911	Economy	19100.00
0005435502830	20911	Economy	19100.00
0005435502822	20911	Economy	19100.00
0005434573554	20911	Economy	19100.00
0005435502827	20911	Economy	19100.00
0005435502838	20911	Economy	19100.00
0005435518334	20911	Economy	19100.00
0005435502835	20911	Economy	19100.00
0005435508698	20911	Economy	19100.00
0005435319796	20911	Economy	19100.00
0005435508706	20911	Economy	19100.00
0005435518333	20911	Economy	19100.00
0005435518332	20911	Economy	19100.00
0005435502837	20911	Economy	19100.00
0005435502818	20911	Economy	19100.00
0005435508696	20911	Economy	19100.00
0005435508703	20911	Economy	19100.00
0005435502826	20911	Economy	19100.00
0005435502832	20911	Economy	19100.00
0005435518345	20911	Economy	19100.00
0005435518340	20911	Economy	19100.00
0005435518347	20911	Economy	19100.00
0005435319797	20911	Economy	19100.00
0005435508687	20911	Economy	19100.00
0005435518341	20911	Economy	19100.00
0005435518331	20911	Economy	19100.00
0005435518343	20911	Economy	19100.00
0005435518337	20911	Economy	19100.00
0005435502833	20911	Economy	19100.00
0005435508691	20911	Economy	19100.00
0005435502834	20911	Economy	19100.00
0005435502821	20911	Economy	19100.00
0005432693628	2894	Business	10300.00
0005432693533	2894	Business	10300.00
0005432693507	2894	Business	10300.00
0005432693589	2894	Business	10300.00
0005432693588	2894	Economy	3400.00
0005432693456	2894	Economy	3400.00
0005432693432	2894	Economy	3400.00
0005432693483	2894	Economy	3400.00
0005432693491	2894	Economy	3400.00
0005432693421	2894	Economy	3400.00
0005432693606	2894	Economy	3800.00
0005432693510	2894	Economy	3400.00
0005432693692	2894	Economy	3400.00
0005432693513	2894	Economy	3400.00
0005432693508	2894	Economy	3400.00
0005432693520	2894	Economy	3400.00
0005432693530	2894	Economy	3400.00
0005432693618	2894	Economy	3400.00
0005432693470	2894	Economy	3400.00
0005432693605	2894	Economy	3400.00
0005432693350	2894	Economy	3400.00
0005432693485	2894	Economy	3400.00
0005432693691	2894	Economy	3400.00
0005432693532	2894	Economy	3400.00
0005432693680	2894	Economy	3400.00
0005432693627	2894	Economy	3400.00
0005432693526	2894	Economy	3400.00
0005432693509	2894	Economy	3400.00
0005432693469	2894	Economy	3400.00
0005432693374	2894	Economy	3400.00
0005432693638	2894	Economy	3400.00
0005432693566	2894	Economy	3400.00
0005432693484	2894	Economy	3400.00
0005432693457	2894	Economy	3400.00
0005432693481	2894	Economy	3400.00
0005433124241	2899	Business	10300.00
0005432707394	2899	Business	10300.00
0005432881130	2899	Business	10300.00
0005433124222	2899	Business	10300.00
0005433124199	2899	Economy	3400.00
0005432707384	2899	Economy	3400.00
0005433124294	2899	Economy	3400.00
0005432881002	2899	Economy	3400.00
0005432707386	2899	Economy	3400.00
0005432707406	2899	Economy	3400.00
0005432707396	2899	Economy	3800.00
0005433124293	2899	Economy	3800.00
0005433124273	2899	Economy	3800.00
0005432707395	2899	Economy	3800.00
0005432707408	2899	Economy	3800.00
0005432217846	2899	Economy	3400.00
0005433124208	2899	Economy	3400.00
0005432707402	2899	Economy	3400.00
0005432881022	2899	Economy	3400.00
0005432707404	2899	Economy	3400.00
0005432707397	2899	Economy	3400.00
0005433124308	2899	Economy	3400.00
0005433124242	2899	Economy	3400.00
0005432707405	2899	Economy	3400.00
0005432707400	2899	Economy	3400.00
0005432707383	2899	Economy	3400.00
0005432707403	2899	Economy	3400.00
0005432707388	2899	Economy	3400.00
0005432707392	2899	Economy	3400.00
0005432881098	2899	Economy	3400.00
0005432707387	2899	Economy	3400.00
0005432881058	2899	Economy	3400.00
0005432707389	2899	Economy	3400.00
0005432881019	2899	Economy	3400.00
0005432881024	2899	Economy	3400.00
0005432881057	2899	Economy	3400.00
0005432707407	2899	Economy	3400.00
0005433124234	2899	Economy	3400.00
0005432707391	2899	Economy	3400.00
0005432707390	2899	Economy	3400.00
0005432707401	2899	Economy	3400.00
0005432881023	2899	Economy	3400.00
0005432881051	2899	Economy	3400.00
0005432881032	2899	Economy	3400.00
0005432881018	2899	Economy	3400.00
0005433124292	2899	Economy	3400.00
0005432881039	2899	Economy	3400.00
0005432217845	2899	Economy	3400.00
0005433124274	2899	Economy	3400.00
0005432707398	2899	Economy	3400.00
0005433124233	2899	Economy	3400.00
0005433124260	2899	Economy	3400.00
0005432881040	2899	Economy	3400.00
0005432880996	2899	Economy	3400.00
0005432707399	2899	Economy	3400.00
0005433124255	2899	Economy	3400.00
0005432707385	2899	Economy	3400.00
0005432707393	2899	Economy	3400.00
0005432881050	2899	Economy	3400.00
0005432881067	2899	Economy	3400.00
0005432707297	29908	Business	10300.00
0005432693841	29908	Business	10300.00
0005432881180	29908	Business	10300.00
0005433124413	29908	Business	10300.00
0005432707128	29908	Business	10300.00
0005432693816	29908	Business	10300.00
0005432693847	29908	Business	10300.00
0005432707256	29908	Business	10300.00
0005432693837	29908	Business	10300.00
0005432707255	29908	Business	10300.00
0005433124424	29908	Business	10300.00
0005432693839	29908	Business	10300.00
0005432881173	29908	Economy	3400.00
0005432707133	29908	Economy	3400.00
0005432881175	29908	Economy	3400.00
0005432707200	29908	Economy	3400.00
0005432707264	29908	Economy	3400.00
0005432881167	29908	Economy	3400.00
0005432693846	29908	Economy	3400.00
0005433124414	29908	Economy	3400.00
0005432693844	29908	Economy	3400.00
0005432881181	29908	Economy	3400.00
0005432707218	29908	Economy	3800.00
0005432693822	29908	Economy	3800.00
0005432693823	29908	Economy	3800.00
0005432693842	29908	Economy	3800.00
0005432881169	29908	Economy	3800.00
0005433124426	29908	Economy	3400.00
0005432693830	29908	Economy	3400.00
0005433124416	29908	Economy	3400.00
0005433124427	29908	Economy	3400.00
0005432693824	29908	Economy	3400.00
0005433124417	29908	Economy	3400.00
0005432693829	29908	Economy	3400.00
0005432707156	29908	Economy	3400.00
0005432693845	29908	Economy	3400.00
0005432707226	29908	Economy	3400.00
0005432881172	29908	Economy	3400.00
0005433124429	29908	Economy	3400.00
0005432693831	29908	Economy	3400.00
0005432881176	29908	Economy	3400.00
0005432707193	29908	Economy	3400.00
0005432693817	29908	Economy	3400.00
0005433124422	29908	Economy	3400.00
0005433124415	29908	Economy	3400.00
0005432693835	29908	Economy	3400.00
0005433124431	29908	Economy	3400.00
0005433124433	29908	Economy	3400.00
0005433124430	29908	Economy	3400.00
0005433124412	29908	Economy	3400.00
0005433124420	29908	Economy	3400.00
0005432693834	29908	Economy	3400.00
0005432881174	29908	Economy	3400.00
0005432881166	29908	Economy	3400.00
0005432693828	29908	Economy	3400.00
0005432881170	29908	Economy	3400.00
0005432693832	29908	Economy	3400.00
0005433124423	29908	Economy	3400.00
0005432881178	29908	Economy	3400.00
0005432693827	29908	Economy	3400.00
0005432707225	29908	Economy	3400.00
0005432881177	29908	Economy	3400.00
0005432693833	29908	Economy	3400.00
0005433124428	29908	Economy	3400.00
0005432693820	29908	Economy	3400.00
0005432693826	29908	Economy	3400.00
0005432707145	29908	Economy	3400.00
0005432881168	29908	Economy	3400.00
0005432707201	29908	Economy	3400.00
0005432707170	29908	Economy	3400.00
0005432707249	29908	Economy	3400.00
0005432707210	29908	Economy	3400.00
0005432707219	29908	Economy	3400.00
0005432693818	29908	Economy	3400.00
0005432693836	29908	Economy	3400.00
0005432693840	29908	Economy	3400.00
0005432707298	29908	Economy	3400.00
0005432693843	29908	Economy	3400.00
0005433124421	29908	Economy	3400.00
0005433124418	29908	Economy	3400.00
0005432707171	29908	Economy	3400.00
0005432693821	29908	Economy	3400.00
0005433124432	29908	Economy	3400.00
0005433124419	29908	Economy	3400.00
0005432707157	29908	Economy	3400.00
0005432707299	29908	Economy	3400.00
0005432707169	29908	Economy	3400.00
0005432693819	29908	Economy	3400.00
0005432693825	29908	Economy	3400.00
0005432881179	29908	Economy	3400.00
0005433124434	29908	Economy	3400.00
0005432881171	29908	Economy	3400.00
0005432693838	29908	Economy	3400.00
0005432707190	29908	Economy	3400.00
0005432707127	29908	Economy	3400.00
0005432707233	29908	Economy	3400.00
0005433124425	29908	Economy	3400.00
0005434980512	23695	Economy	4000.00
0005434980507	23695	Economy	4000.00
0005434980485	23695	Economy	4000.00
0005434980509	23695	Economy	3600.00
0005434989004	23695	Economy	3600.00
0005434980495	23695	Economy	3600.00
0005434980508	23695	Economy	3600.00
0005434980513	23695	Economy	3600.00
0005434989005	23695	Economy	3600.00
0005434989001	23695	Economy	3600.00
0005434988996	23695	Economy	3600.00
0005434988994	23695	Economy	3600.00
0005434988993	23695	Economy	3600.00
0005434988992	23695	Economy	3600.00
0005434980483	23695	Economy	3600.00
0005434980486	23695	Economy	3600.00
0005434980504	23695	Economy	3600.00
0005434980487	23695	Economy	3600.00
0005434980494	23695	Economy	3600.00
0005434980506	23695	Economy	3600.00
0005434980499	23695	Economy	3600.00
0005434980500	23695	Economy	3600.00
0005434980501	23695	Economy	3600.00
0005434988999	23695	Economy	3600.00
0005434980490	23695	Economy	3600.00
0005434980510	23695	Economy	3600.00
0005434989003	23695	Economy	3600.00
0005434980496	23695	Economy	3600.00
0005434989006	23695	Economy	3600.00
0005434980505	23695	Economy	3600.00
0005434980511	23695	Economy	3600.00
0005434980491	23695	Economy	3600.00
0005434980498	23695	Economy	3600.00
0005434988997	23695	Economy	3600.00
0005434988995	23695	Economy	3600.00
0005434980484	23695	Economy	3600.00
0005434988998	23695	Economy	3600.00
0005434980497	23695	Economy	3600.00
0005434980493	23695	Economy	3600.00
0005434980488	23695	Economy	3600.00
0005434980492	23695	Economy	3600.00
0005434980502	23695	Economy	3600.00
0005434980489	23695	Economy	3600.00
0005434980503	23695	Economy	3600.00
0005434989002	23695	Economy	3600.00
0005434989000	23695	Economy	3600.00
0005434988890	27552	Economy	4000.00
0005434980139	27552	Economy	4000.00
0005434980116	27552	Economy	3600.00
0005434988806	27552	Economy	3600.00
0005434988899	27552	Economy	3600.00
0005434980347	27552	Economy	3600.00
0005434980212	27552	Economy	3600.00
0005434988896	27552	Economy	3600.00
0005434980293	27552	Economy	3600.00
0005434980267	27552	Economy	3600.00
0005434980351	27552	Economy	3600.00
0005434980115	27552	Economy	3600.00
0005434980352	27552	Economy	3600.00
0005434988867	27552	Economy	3600.00
0005434980117	27552	Economy	3600.00
0005434980196	27552	Economy	3600.00
0005434980280	27552	Economy	3600.00
0005434988893	27552	Economy	3600.00
0005434980282	27552	Economy	3600.00
0005434980195	27552	Economy	3600.00
0005434988852	27552	Economy	3600.00
0005434988866	27552	Economy	3600.00
0005434980236	27552	Economy	3600.00
0005434980332	27552	Economy	3600.00
0005434980207	27552	Economy	3600.00
0005434988883	27552	Economy	3600.00
0005434988892	27552	Economy	3600.00
0005434980252	27552	Economy	3600.00
0005434980249	27552	Economy	3600.00
0005434988853	27552	Economy	3600.00
0005434988876	27552	Economy	3600.00
0005434988895	27552	Economy	3600.00
0005434980331	27552	Economy	3600.00
0005434980345	27552	Economy	3600.00
0005434988891	27552	Economy	3600.00
0005434980268	27552	Economy	3600.00
0005434980251	27552	Economy	3600.00
0005434980346	27552	Economy	3600.00
0005434980250	27552	Economy	3600.00
0005434980194	27552	Economy	3600.00
0005434988858	27552	Economy	3600.00
0005434302564	10293	Economy	21600.00
0005434302563	10293	Economy	21600.00
0005434302893	10293	Economy	19700.00
0005434302562	10293	Economy	19700.00
0005433113570	10293	Economy	19700.00
0005433111540	10293	Economy	19700.00
0005434302892	10293	Economy	19700.00
0005434302560	10293	Economy	19700.00
0005433113571	10293	Economy	19700.00
0005434302561	10293	Economy	19700.00
0005433113589	19629	Economy	19700.00
0005435070339	3526	Business	26900.00
0005435719089	3526	Business	26900.00
0005435925524	3526	Business	26900.00
0005435070335	3526	Business	26900.00
0005435925517	3526	Business	26900.00
0005435719086	3526	Business	26900.00
0005435070360	3526	Business	26900.00
0005435070341	3526	Business	26900.00
0005435925502	3526	Business	26900.00
0005435070349	3526	Economy	9000.00
0005435925480	3526	Economy	9000.00
0005435719088	3526	Economy	9000.00
0005435925528	3526	Economy	9000.00
0005435070351	3526	Economy	9000.00
0005435925516	3526	Economy	9000.00
0005435070357	3526	Economy	9900.00
0005435719084	3526	Economy	9900.00
0005435925526	3526	Economy	9900.00
0005435070348	3526	Economy	9900.00
0005435925513	3526	Economy	9000.00
0005435070334	3526	Economy	9000.00
0005435925465	3526	Economy	9000.00
0005435070373	3526	Economy	9000.00
0005435070329	3526	Economy	9000.00
0005435070364	3526	Economy	9000.00
0005435070336	3526	Economy	9000.00
0005435070338	3526	Economy	9000.00
0005435719087	3526	Economy	9000.00
0005435070347	3526	Economy	9000.00
0005435070369	3526	Economy	9000.00
0005435070342	3526	Economy	9000.00
0005435070355	3526	Economy	9000.00
0005435070350	3526	Economy	9000.00
0005435070374	3526	Economy	9000.00
0005435070340	3526	Economy	9000.00
0005435070377	3526	Economy	9000.00
0005435925503	3526	Economy	9000.00
0005435719090	3526	Economy	9000.00
0005435070376	3526	Economy	9000.00
0005435070368	3526	Economy	9000.00
0005435070353	3526	Economy	9000.00
0005435070362	3526	Economy	9000.00
0005435070372	3526	Economy	9000.00
0005435925527	3526	Economy	9000.00
0005435719085	3526	Economy	9000.00
0005435070367	3526	Economy	9000.00
0005435925507	3526	Economy	9000.00
0005435070363	3526	Economy	9000.00
0005435070365	3526	Economy	9000.00
0005435925506	3526	Economy	9000.00
0005435925520	3526	Economy	9000.00
0005435070346	3526	Economy	9000.00
0005435070359	3526	Economy	9000.00
0005435070361	3526	Economy	9000.00
0005435070344	3526	Economy	9000.00
0005435070354	3526	Economy	9000.00
0005435719083	3526	Economy	9000.00
0005435070343	3526	Economy	9000.00
0005435070356	3526	Economy	9000.00
0005435070331	3526	Economy	9000.00
0005435070337	3526	Economy	9000.00
0005435925479	3526	Economy	9000.00
0005435925485	3526	Economy	9000.00
0005435070370	3526	Economy	9000.00
0005435070330	3526	Economy	9000.00
0005435070358	3526	Economy	9000.00
0005435070352	3526	Economy	9000.00
0005435070366	3526	Economy	9000.00
0005435070375	3526	Economy	9000.00
0005435070345	3526	Economy	9000.00
0005435070371	3526	Economy	9000.00
0005435925514	3526	Economy	9000.00
0005435070332	3526	Economy	9000.00
0005435070333	3526	Economy	9000.00
0005435925648	15278	Business	26900.00
0005435925635	15278	Business	26900.00
0005435069515	15278	Business	26900.00
0005435069990	15278	Business	26900.00
0005435069802	15278	Business	26900.00
0005435069989	15278	Business	26900.00
0005435069909	15278	Business	26900.00
0005435069975	15278	Economy	9000.00
0005435925647	15278	Economy	9000.00
0005435925649	15278	Economy	9000.00
0005435069768	15278	Economy	9000.00
0005435069772	15278	Economy	9000.00
0005435069900	15278	Economy	9000.00
0005435070042	15278	Economy	9000.00
0005435069846	15278	Economy	9000.00
0005435069767	15278	Economy	9000.00
0005435925636	15278	Economy	9900.00
0005435069838	15278	Economy	9900.00
0005435925651	15278	Economy	9900.00
0005435925638	15278	Economy	9900.00
0005435069692	15278	Economy	9900.00
0005435069842	15278	Economy	9000.00
0005435069875	15278	Economy	9000.00
0005435069901	15278	Economy	9000.00
0005435069903	15278	Economy	9000.00
0005435069789	15278	Economy	9000.00
0005435925643	15278	Economy	9000.00
0005435069837	15278	Economy	9000.00
0005435069922	15278	Economy	9000.00
0005435069699	15278	Economy	9000.00
0005435939943	15278	Economy	9000.00
0005435070041	15278	Economy	9000.00
0005435925645	15278	Economy	9000.00
0005435069793	15278	Economy	9000.00
0005435925639	15278	Economy	9000.00
0005435070085	15278	Economy	9000.00
0005435069845	15278	Economy	9000.00
0005435069669	15278	Economy	9000.00
0005435939944	15278	Economy	9000.00
0005435939942	15278	Economy	9000.00
0005435925641	15278	Economy	9000.00
0005435069915	15278	Economy	9000.00
0005435069834	15278	Economy	9000.00
0005435069844	15278	Economy	9000.00
0005435069693	15278	Economy	9000.00
0005435069876	15278	Economy	9000.00
0005435069848	15278	Economy	9000.00
0005435925646	15278	Economy	9000.00
0005435925650	15278	Economy	9000.00
0005435939941	15278	Economy	9000.00
0005435925630	15278	Economy	9000.00
0005435069843	15278	Economy	9000.00
0005435069829	15278	Economy	9000.00
0005435925637	15278	Economy	9000.00
0005435069928	15278	Economy	9000.00
0005435069902	15278	Economy	9000.00
0005435939946	15278	Economy	9000.00
0005435925644	15278	Economy	9000.00
0005435939945	15278	Economy	9000.00
0005435939939	15278	Economy	9000.00
0005435069847	15278	Economy	9000.00
0005435069974	15278	Economy	9000.00
0005435069823	15278	Economy	9000.00
0005435925631	15278	Economy	9000.00
0005435069677	15278	Economy	9000.00
0005435069820	15278	Economy	9000.00
0005435069849	15278	Economy	9000.00
0005435925633	15278	Economy	9000.00
0005435069929	15278	Economy	9000.00
0005435925634	15278	Economy	9000.00
0005435069678	15278	Economy	9000.00
0005435069743	15278	Economy	9000.00
0005435069749	15278	Economy	9000.00
0005435939940	15278	Economy	9000.00
0005435925640	15278	Economy	9000.00
0005435069836	15278	Economy	9000.00
0005435069927	15278	Economy	9000.00
0005435925632	15278	Economy	9000.00
0005435070008	15278	Economy	9000.00
0005435925642	15278	Economy	9000.00
0005435069839	15278	Economy	9000.00
0005435069908	15278	Economy	9000.00
0005432659758	18194	Economy	5900.00
0005432659757	18194	Economy	5900.00
0005432658642	18194	Economy	5900.00
0005432660868	18194	Economy	5900.00
0005432660869	18194	Economy	5900.00
0005432658643	18194	Economy	5900.00
0005432660853	26367	Economy	5900.00
0005432660855	26367	Economy	5900.00
0005432660854	26367	Economy	5900.00
0005432660851	26367	Economy	5900.00
0005433102762	216	Business	20000.00
0005433103034	216	Business	20000.00
0005433102986	216	Business	20000.00
0005433102988	216	Business	20000.00
0005433103031	216	Business	20000.00
0005432920193	216	Business	20000.00
0005432901902	216	Business	20000.00
0005432920136	216	Business	20000.00
0005432920166	216	Business	20000.00
0005433102918	216	Business	20000.00
0005433103086	216	Business	20000.00
0005433102987	216	Business	20000.00
0005433103022	216	Business	20000.00
0005432901899	216	Business	20000.00
0005433103012	216	Business	20000.00
0005433103013	216	Economy	7300.00
0005433102923	216	Economy	7300.00
0005433103069	216	Economy	7300.00
0005433102997	216	Economy	6700.00
0005433102909	216	Economy	6700.00
0005433103021	216	Economy	6700.00
0005433103039	216	Economy	6700.00
0005433102962	216	Economy	6700.00
0005432920187	216	Economy	6700.00
0005432920106	216	Economy	6700.00
0005432901976	216	Economy	6700.00
0005432677623	216	Economy	6700.00
0005432920134	216	Economy	6700.00
0005433103040	216	Economy	6700.00
0005433103042	216	Economy	6700.00
0005433102999	216	Economy	6700.00
0005433102936	216	Economy	6700.00
0005433102939	216	Economy	6700.00
0005432901933	216	Economy	6700.00
0005432920172	216	Economy	6700.00
0005433102960	216	Economy	6700.00
0005432920154	216	Economy	6700.00
0005432920185	216	Economy	6700.00
0005433102989	216	Economy	6700.00
0005433102950	216	Economy	6700.00
0005432920190	216	Economy	6700.00
0005433103046	216	Economy	6700.00
0005433102850	216	Economy	6700.00
0005432920192	216	Economy	6700.00
0005433103085	216	Economy	6700.00
0005433103096	216	Economy	6700.00
0005433103098	216	Economy	6700.00
0005432901935	216	Economy	6700.00
0005432901926	216	Economy	6700.00
0005432901936	216	Economy	6700.00
0005433102763	216	Economy	6700.00
0005432920229	216	Economy	7300.00
0005432901990	216	Economy	7300.00
0005432901901	216	Economy	7300.00
0005433103072	216	Economy	6700.00
0005433103099	216	Economy	6700.00
0005433103000	216	Economy	6700.00
0005432677624	216	Economy	6700.00
0005432920188	216	Economy	6700.00
0005432901811	216	Economy	6700.00
0005432920135	216	Economy	6700.00
0005433102996	216	Economy	6700.00
0005433102919	216	Economy	6700.00
0005433102978	216	Economy	6700.00
0005433102998	216	Economy	6700.00
0005432901865	216	Economy	6700.00
0005433102825	216	Economy	6700.00
0005433103058	216	Economy	6700.00
0005432157539	216	Economy	6700.00
0005433102945	216	Economy	6700.00
0005433102878	216	Economy	6700.00
0005433103068	216	Economy	6700.00
0005432920153	216	Economy	6700.00
0005433103070	216	Economy	6700.00
0005432920174	216	Economy	6700.00
0005433103037	216	Economy	6700.00
0005433102952	216	Economy	6700.00
0005432901812	216	Economy	6700.00
0005433102961	216	Economy	6700.00
0005433103038	216	Economy	6700.00
0005432920173	216	Economy	6700.00
0005433102979	216	Economy	6700.00
0005433103032	216	Economy	6700.00
0005432920226	216	Economy	6700.00
0005433102951	216	Economy	6700.00
0005433102977	216	Economy	6700.00
0005433102904	216	Economy	6700.00
0005433102937	216	Economy	6700.00
0005433103047	216	Economy	6700.00
0005433103067	216	Economy	6700.00
0005433103035	216	Economy	6700.00
0005433102917	216	Economy	6700.00
0005433103074	216	Economy	6700.00
0005432901900	216	Economy	6700.00
0005433103010	216	Economy	6700.00
0005433103008	216	Economy	6700.00
0005433103097	216	Economy	6700.00
0005432920195	216	Economy	6700.00
0005433477101	215	Business	20000.00
0005432818205	215	Business	20000.00
0005432263029	215	Business	20000.00
0005433477097	215	Business	20000.00
0005432263040	215	Business	20000.00
0005432263004	215	Business	20000.00
0005432263006	215	Business	20000.00
0005432263007	215	Business	20000.00
0005433477106	215	Business	20000.00
0005432263023	215	Business	20000.00
0005433477109	215	Business	20000.00
0005432263019	215	Business	20000.00
0005432263013	215	Business	20000.00
0005432263031	215	Business	20000.00
0005432289066	215	Business	20000.00
0005434152856	215	Business	20000.00
0005432263005	215	Business	20000.00
0005433477095	215	Business	20000.00
0005433477115	215	Business	20000.00
0005432818192	215	Business	20000.00
0005432263008	215	Business	20000.00
0005432263018	215	Business	20000.00
0005432263037	215	Economy	7300.00
0005432263017	215	Economy	7300.00
0005433477092	215	Economy	7300.00
0005432756904	215	Economy	7300.00
0005432818194	215	Economy	7300.00
0005432263036	215	Economy	6700.00
0005432289067	215	Economy	6700.00
0005432818184	215	Economy	6700.00
0005432263003	215	Economy	6700.00
0005432818200	215	Economy	6700.00
0005432263014	215	Economy	6700.00
0005432818189	215	Economy	6700.00
0005432263024	215	Economy	6700.00
0005433477116	215	Economy	6700.00
0005432263042	215	Economy	6700.00
0005432818204	215	Economy	6700.00
0005433477093	215	Economy	6700.00
0005432263010	215	Economy	6700.00
0005432263033	215	Economy	6700.00
0005434152855	215	Economy	6700.00
0005434157720	215	Economy	6700.00
0005434153569	215	Economy	6700.00
0005433477119	215	Economy	6700.00
0005432818201	215	Economy	6700.00
0005433477110	215	Economy	6700.00
0005433477113	215	Economy	6700.00
0005432818197	215	Economy	6700.00
0005432263015	215	Economy	6700.00
0005432263045	215	Economy	6700.00
0005433477111	215	Economy	6700.00
0005432263034	215	Economy	6700.00
0005432756897	215	Economy	6700.00
0005432263022	215	Economy	6700.00
0005433477104	215	Economy	6700.00
0005432263032	215	Economy	6700.00
0005432263035	215	Economy	6700.00
0005433687729	215	Economy	6700.00
0005434157719	215	Economy	6700.00
0005432263038	215	Economy	6700.00
0005432818206	215	Economy	6700.00
0005432818202	215	Economy	6700.00
0005434153567	215	Economy	6700.00
0005432818185	215	Economy	6700.00
0005432818212	215	Economy	6700.00
0005432263028	215	Economy	6700.00
0005432818199	215	Economy	6700.00
0005432818209	215	Economy	6700.00
0005432289065	215	Economy	6700.00
0005433477117	215	Economy	6700.00
0005434152857	215	Economy	6700.00
0005432263027	215	Economy	6700.00
0005432263020	215	Economy	6700.00
0005432753340	215	Economy	6700.00
0005433477107	215	Economy	7300.00
0005432818207	215	Economy	6700.00
0005432818191	215	Economy	7300.00
0005433477103	215	Economy	7300.00
0005432263039	215	Economy	7300.00
0005432207722	215	Economy	7300.00
0005434157717	215	Economy	6700.00
0005433477105	215	Economy	6700.00
0005433477118	215	Economy	6700.00
0005433477102	215	Economy	7300.00
0005432756883	215	Economy	6700.00
0005432818193	215	Economy	6700.00
0005432263011	215	Economy	6700.00
0005432818196	215	Economy	6700.00
0005433477096	215	Economy	6700.00
0005433477112	215	Economy	6700.00
0005433477099	215	Economy	6700.00
0005432263012	215	Economy	6700.00
0005432263030	215	Economy	6700.00
0005432818188	215	Economy	6700.00
0005432263021	215	Economy	6700.00
0005432818203	215	Economy	6700.00
0005433477114	215	Economy	6700.00
0005432263043	215	Economy	6700.00
0005433477108	215	Economy	6700.00
0005432263044	215	Economy	6700.00
0005434152858	215	Economy	6700.00
0005433690949	215	Economy	6700.00
0005432818187	215	Economy	6700.00
0005432756896	215	Economy	6700.00
0005432818211	215	Economy	6700.00
0005434153568	215	Economy	6700.00
0005434157718	215	Economy	6700.00
0005432818210	215	Economy	6700.00
0005432818208	215	Economy	6700.00
0005433687747	215	Economy	6700.00
0005432263016	215	Economy	6700.00
0005432263026	215	Economy	6700.00
0005432289068	215	Economy	6700.00
0005432818195	215	Economy	6700.00
0005434157722	215	Economy	6700.00
0005432818198	215	Economy	6700.00
0005434157721	215	Economy	6700.00
0005433477094	215	Economy	6700.00
0005432263009	215	Economy	6700.00
0005432818186	215	Economy	6700.00
0005432207724	215	Economy	6700.00
0005432756905	215	Economy	6700.00
0005432263025	215	Economy	6700.00
0005432207723	215	Economy	6700.00
0005433477098	215	Economy	6700.00
0005432818190	215	Economy	6700.00
0005432263041	215	Economy	6700.00
0005433477100	215	Economy	6700.00
0005432020908	7974	Business	20000.00
0005432392073	7974	Business	20000.00
0005432020930	7974	Business	20000.00
0005433103471	7974	Business	20000.00
0005433103476	7974	Business	20000.00
0005432020919	7974	Business	20000.00
0005432920368	7974	Business	20000.00
0005433103474	7974	Business	20000.00
0005433103452	7974	Business	20000.00
0005433103446	7974	Business	20000.00
0005432392074	7974	Business	20000.00
0005433103456	7974	Business	20000.00
0005432677670	7974	Business	20000.00
0005432920370	7974	Business	20000.00
0005433103461	7974	Business	20000.00
0005433103473	7974	Business	20000.00
0005432020929	7974	Business	20000.00
0005432020915	7974	Business	20000.00
0005433103467	7974	Business	20000.00
0005432020906	7974	Economy	7300.00
0005432677674	7974	Economy	7300.00
0005432753383	7974	Economy	7300.00
0005433103477	7974	Economy	6700.00
0005433103483	7974	Economy	6700.00
0005432751608	7974	Economy	6700.00
0005432020921	7974	Economy	6700.00
0005432044592	7974	Economy	6700.00
0005432020913	7974	Economy	6700.00
0005433103480	7974	Economy	6700.00
0005432020922	7974	Economy	6700.00
0005433103445	7974	Economy	6700.00
0005432392075	7974	Economy	6700.00
0005432020910	7974	Economy	6700.00
0005432020924	7974	Economy	6700.00
0005432020920	7974	Economy	6700.00
0005432020912	7974	Economy	6700.00
0005433103472	7974	Economy	6700.00
0005433103486	7974	Economy	6700.00
0005432020916	7974	Economy	6700.00
0005432920374	7974	Economy	6700.00
0005433103458	7974	Economy	6700.00
0005433103462	7974	Economy	6700.00
0005432020918	7974	Economy	6700.00
0005432020923	7974	Economy	6700.00
0005432677672	7974	Economy	6700.00
0005433103468	7974	Economy	6700.00
0005432020926	7974	Economy	6700.00
0005432044593	7974	Economy	6700.00
0005432020909	7974	Economy	6700.00
0005433103448	7974	Economy	6700.00
0005432020931	7974	Economy	6700.00
0005433103469	7974	Economy	6700.00
0005432020907	7974	Economy	6700.00
0005432920373	7974	Economy	6700.00
0005433103481	7974	Economy	6700.00
0005432020928	7974	Economy	7300.00
0005432920372	7974	Economy	7300.00
0005432020914	7974	Economy	7300.00
0005433103470	7974	Economy	7300.00
0005433103466	7974	Economy	6700.00
0005433103484	7974	Economy	6700.00
0005433103482	7974	Economy	6700.00
0005432020911	7974	Economy	7300.00
0005433103485	7974	Economy	6700.00
0005432920365	7974	Economy	6700.00
0005432751609	7974	Economy	6700.00
0005433103455	7974	Economy	6700.00
0005433103465	7974	Economy	6700.00
0005432920377	7974	Economy	6700.00
0005433103453	7974	Economy	6700.00
0005433103454	7974	Economy	6700.00
0005432020917	7974	Economy	6700.00
0005432920375	7974	Economy	6700.00
0005432920371	7974	Economy	6700.00
0005432045662	7974	Economy	6700.00
0005432920361	7974	Economy	6700.00
0005432020925	7974	Economy	6700.00
0005433103449	7974	Economy	6700.00
0005433103478	7974	Economy	6700.00
0005432753382	7974	Economy	6700.00
0005432920360	7974	Economy	6700.00
0005432677671	7974	Economy	6700.00
0005433103457	7974	Economy	6700.00
0005432677673	7974	Economy	6700.00
0005433103460	7974	Economy	6700.00
0005433103447	7974	Economy	6700.00
0005432920363	7974	Economy	6700.00
0005432920359	7974	Economy	6700.00
0005432020927	7974	Economy	6700.00
0005432020905	7974	Economy	6700.00
0005433103444	7974	Economy	6700.00
0005432920364	7974	Economy	6700.00
0005432920378	7974	Economy	6700.00
0005432753384	7974	Economy	6700.00
0005433103464	7974	Economy	6700.00
0005432920367	7974	Economy	6700.00
0005433103475	7974	Economy	6700.00
0005432920369	7974	Economy	6700.00
0005432753385	7974	Economy	6700.00
0005432751610	7974	Economy	6700.00
0005433103459	7974	Economy	6700.00
0005433103451	7974	Economy	6700.00
0005432920376	7974	Economy	6700.00
0005433103479	7974	Economy	6700.00
0005433103450	7974	Economy	6700.00
0005432920362	7974	Economy	6700.00
0005433103463	7974	Economy	6700.00
0005432920366	7974	Economy	6700.00
0005432902036	7971	Business	20000.00
0005432902042	7971	Business	20000.00
0005432817827	7971	Business	20000.00
0005432902034	7971	Business	20000.00
0005432902031	7971	Business	20000.00
0005432817912	7971	Business	20000.00
0005432817913	7971	Business	20000.00
0005432002128	7971	Economy	7300.00
0005432902033	7971	Economy	6700.00
0005432002127	7971	Economy	6700.00
0005432902039	7971	Economy	6700.00
0005432817869	7971	Economy	6700.00
0005432818045	7971	Economy	6700.00
0005432902032	7971	Economy	6700.00
0005432902037	7971	Economy	6700.00
0005432817899	7971	Economy	6700.00
0005432902041	7971	Economy	6700.00
0005432818008	7971	Economy	6700.00
0005432817967	7971	Economy	6700.00
0005432818015	7971	Economy	7300.00
0005432817971	7971	Economy	6700.00
0005432817932	7971	Economy	6700.00
0005432817970	7971	Economy	6700.00
0005432817906	7971	Economy	6700.00
0005432902045	7971	Economy	6700.00
0005432818009	7971	Economy	6700.00
0005432902044	7971	Economy	6700.00
0005432817966	7971	Economy	6700.00
0005432902040	7971	Economy	6700.00
0005432817845	7971	Economy	6700.00
0005432902035	7971	Economy	6700.00
0005432817933	7971	Economy	6700.00
0005432902038	7971	Economy	6700.00
0005432902043	7971	Economy	6700.00
0005434175842	9665	Economy	6900.00
0005433870787	9665	Economy	6900.00
0005433870785	9665	Economy	6900.00
0005433870786	9665	Economy	6900.00
0005434175841	9665	Economy	6900.00
0005433870788	9665	Economy	6900.00
0005434175833	9665	Economy	6900.00
0005434175843	9665	Economy	6900.00
0005434175858	32351	Economy	6900.00
0005434175857	32351	Economy	6900.00
0005434175855	32351	Economy	6900.00
0005434175856	32351	Economy	6900.00
0005433870763	32351	Economy	6900.00
0005435626625	3464	Business	35000.00
0005432800154	3464	Business	35000.00
0005435127354	3464	Business	35000.00
0005434880535	3464	Business	35000.00
0005435127379	3464	Business	35000.00
0005435626628	3464	Business	35000.00
0005434880551	3464	Business	35000.00
0005434880582	3464	Business	35000.00
0005434880548	3464	Business	35000.00
0005435903012	3464	Business	35000.00
0005432800144	3464	Business	35000.00
0005435626631	3464	Business	35000.00
0005432613961	3464	Business	35000.00
0005434938615	3464	Business	35000.00
0005434880532	3464	Business	35000.00
0005434880589	3464	Business	35000.00
0005434938618	3464	Business	35000.00
0005432800152	3464	Comfort	19900.00
0005434880558	3464	Business	35000.00
0005434880570	3464	Comfort	19900.00
0005435913972	3464	Comfort	19900.00
0005435626632	3464	Comfort	19900.00
0005434880555	3464	Comfort	19900.00
0005434880575	3464	Comfort	19900.00
0005434880554	3464	Comfort	19900.00
0005435127369	3464	Comfort	19900.00
0005432800162	3464	Comfort	19900.00
0005432611799	3464	Comfort	19900.00
0005434880550	3464	Comfort	19900.00
0005435626638	3464	Comfort	19900.00
0005435626640	3464	Comfort	19900.00
0005435127385	3464	Comfort	19900.00
0005435127363	3464	Comfort	19900.00
0005435127378	3464	Comfort	19900.00
0005435127367	3464	Comfort	19900.00
0005435914716	3464	Comfort	19900.00
0005435841837	3464	Comfort	19900.00
0005432800147	3464	Comfort	19900.00
0005435902973	3464	Comfort	19900.00
0005432800165	3464	Comfort	19900.00
0005434880573	3464	Comfort	19900.00
0005434880505	3464	Comfort	19900.00
0005435626627	3464	Comfort	19900.00
0005435902981	3464	Comfort	19900.00
0005432800153	3464	Comfort	19900.00
0005434427332	3464	Comfort	19900.00
0005434880519	3464	Comfort	19900.00
0005434880557	3464	Economy	11700.00
0005435841836	3464	Economy	11700.00
0005434938621	3464	Economy	11700.00
0005434427329	3464	Economy	11700.00
0005434880544	3464	Economy	11700.00
0005434880568	3464	Economy	11700.00
0005434880579	3464	Economy	11700.00
0005435914710	3464	Economy	11700.00
0005434938629	3464	Economy	11700.00
0005432800166	3464	Economy	11700.00
0005434938613	3464	Economy	11700.00
0005435913974	3464	Economy	11700.00
0005434880588	3464	Economy	11700.00
0005435127387	3464	Economy	11700.00
0005434880527	3464	Economy	11700.00
0005434938617	3464	Economy	11700.00
0005432800163	3464	Economy	11700.00
0005434880578	3464	Economy	11700.00
0005432800139	3464	Economy	11700.00
0005435127380	3464	Economy	11700.00
0005432800158	3464	Economy	11700.00
0005435903066	3464	Economy	11700.00
0005434880566	3464	Economy	11700.00
0005432800155	3464	Economy	11700.00
0005434427334	3464	Economy	11700.00
0005435127391	3464	Economy	11700.00
0005434880580	3464	Economy	11700.00
0005435127360	3464	Economy	11700.00
0005434880594	3464	Economy	11700.00
0005435913973	3464	Economy	11700.00
0005435127370	3464	Economy	11700.00
0005435913961	3464	Economy	11700.00
0005434880572	3464	Economy	11700.00
0005432800161	3464	Economy	11700.00
0005434880567	3464	Economy	11700.00
0005432611801	3464	Economy	11700.00
0005435902978	3464	Economy	11700.00
0005434880529	3464	Economy	11700.00
0005435902898	3464	Economy	11700.00
0005434880587	3464	Economy	11700.00
0005434880542	3464	Economy	11700.00
0005435127362	3464	Economy	11700.00
0005432188688	3464	Economy	11700.00
0005435626639	3464	Economy	11700.00
0005435127388	3464	Economy	11700.00
0005435127365	3464	Economy	11700.00
0005434938626	3464	Economy	11700.00
0005435127371	3464	Economy	11700.00
0005432613962	3464	Economy	11700.00
0005434880561	3464	Economy	11700.00
0005435127381	3464	Economy	12800.00
0005434880503	3464	Economy	11700.00
0005434880543	3464	Economy	12800.00
0005435902925	3464	Economy	12800.00
0005435902988	3464	Economy	11700.00
0005434427333	3464	Economy	12800.00
0005434938627	3464	Economy	12800.00
0005435127382	3464	Economy	11700.00
0005434880585	3464	Economy	11700.00
0005434880571	3464	Economy	11700.00
0005432800148	3464	Economy	11700.00
0005434880512	3464	Economy	11700.00
0005435127376	3464	Economy	11700.00
0005435902957	3464	Economy	11700.00
0005434427320	3464	Economy	11700.00
0005434938611	3464	Economy	11700.00
0005435127368	3464	Economy	11700.00
0005435127393	3464	Economy	11700.00
0005435914717	3464	Economy	11700.00
0005435127390	3464	Economy	11700.00
0005432611800	3464	Economy	11700.00
0005434427330	3464	Economy	11700.00
0005435903023	3464	Economy	11700.00
0005434427344	3464	Economy	11700.00
0005434880517	3464	Economy	11700.00
0005434880523	3464	Economy	11700.00
0005434880562	3464	Economy	11700.00
0005432800141	3464	Economy	11700.00
0005435913976	3464	Economy	11700.00
0005432800157	3464	Economy	11700.00
0005435626634	3464	Economy	11700.00
0005435902976	3464	Economy	11700.00
0005434880584	3464	Economy	11700.00
0005435127389	3464	Economy	11700.00
0005434427343	3464	Economy	11700.00
0005435127366	3464	Economy	11700.00
0005434880537	3464	Economy	11700.00
0005435127357	3464	Economy	11700.00
0005435841831	3464	Economy	11700.00
0005434427327	3464	Economy	11700.00
0005434880541	3464	Economy	11700.00
0005434427336	3464	Economy	11700.00
0005435127356	3464	Economy	11700.00
0005434427339	3464	Economy	11700.00
0005434880552	3464	Economy	11700.00
0005434880577	3464	Economy	11700.00
0005434880565	3464	Economy	11700.00
0005435626623	3464	Economy	11700.00
0005434938622	3464	Economy	11700.00
0005434880508	3464	Economy	11700.00
0005434880540	3464	Economy	11700.00
0005432800159	3464	Economy	11700.00
0005434880525	3464	Economy	11700.00
0005432800142	3464	Economy	11700.00
0005435127361	3464	Economy	11700.00
0005434880583	3464	Economy	11700.00
0005434427341	3464	Economy	11700.00
0005434880522	3464	Economy	11700.00
0005435626624	3464	Economy	11700.00
0005434938616	3464	Economy	11700.00
0005435914703	3464	Economy	11700.00
0005435127359	3464	Economy	11700.00
0005435902927	3464	Economy	11700.00
0005435127358	3464	Economy	11700.00
0005434880518	3464	Economy	11700.00
0005434880521	3464	Economy	11700.00
0005432800156	3464	Economy	11700.00
0005434880524	3464	Economy	11700.00
0005434880590	3464	Economy	11700.00
0005432183520	3464	Economy	11700.00
0005434938614	3464	Economy	11700.00
0005434880545	3464	Economy	11700.00
0005435127352	3464	Economy	11700.00
0005435903016	3464	Economy	11700.00
0005434938624	3464	Economy	11700.00
0005435127364	3464	Economy	11700.00
0005435626637	3464	Economy	11700.00
0005432800143	3464	Economy	11700.00
0005435127353	3464	Economy	11700.00
0005434938612	3464	Economy	11700.00
0005435626630	3464	Economy	11700.00
0005434880531	3464	Economy	11700.00
0005435626633	3464	Economy	11700.00
0005434880581	3464	Economy	11700.00
0005434427340	3464	Economy	11700.00
0005435626626	3464	Economy	11700.00
0005434880534	3464	Economy	11700.00
0005434880530	3464	Economy	11700.00
0005434880556	3464	Economy	11700.00
0005435903024	3464	Economy	11700.00
0005435127384	3464	Economy	12800.00
0005434880549	3464	Economy	12800.00
0005435913971	3464	Economy	12800.00
0005434427342	3464	Economy	12800.00
0005434880528	3464	Economy	12800.00
0005435127373	3464	Economy	11700.00
0005434880507	3464	Economy	11700.00
0005434427345	3464	Economy	11700.00
0005434880569	3464	Economy	11700.00
0005434938625	3464	Economy	11700.00
0005434427335	3464	Economy	11700.00
0005435127386	3464	Economy	11700.00
0005434880510	3464	Economy	11700.00
0005432800140	3464	Economy	11700.00
0005434880592	3464	Economy	11700.00
0005434880564	3464	Economy	11700.00
0005434880511	3464	Economy	11700.00
0005434880526	3464	Economy	11700.00
0005434880506	3464	Economy	11700.00
0005434880520	3464	Economy	11700.00
0005432800160	3464	Economy	11700.00
0005434938623	3464	Economy	11700.00
0005434427338	3464	Economy	11700.00
0005434427325	3464	Economy	11700.00
0005434880546	3464	Economy	11700.00
0005434880502	3464	Economy	11700.00
0005435127392	3464	Economy	11700.00
0005432183522	3464	Economy	11700.00
0005434880536	3464	Economy	11700.00
0005432611798	3464	Economy	11700.00
0005435127374	3464	Economy	11700.00
0005435902975	3464	Economy	11700.00
0005434938620	3464	Economy	11700.00
0005434880547	3464	Economy	11700.00
0005432800138	3464	Economy	11700.00
0005434938619	3464	Economy	11700.00
0005434427323	3464	Economy	11700.00
0005434880563	3464	Economy	11700.00
0005435127383	3464	Economy	11700.00
0005432613964	3464	Economy	11700.00
0005434427324	3464	Economy	11700.00
0005434880538	3464	Economy	11700.00
0005434880586	3464	Economy	11700.00
0005432800146	3464	Economy	11700.00
0005434880576	3464	Economy	11700.00
0005435902980	3464	Economy	11700.00
0005432800145	3464	Economy	11700.00
0005434880553	3464	Economy	11700.00
0005434880515	3464	Economy	11700.00
0005434880533	3464	Economy	11700.00
0005435127355	3464	Economy	11700.00
0005434427322	3464	Economy	11700.00
0005432188689	3464	Economy	11700.00
0005435902977	3464	Economy	11700.00
0005432613963	3464	Economy	11700.00
0005434880514	3464	Economy	11700.00
0005435127372	3464	Economy	11700.00
0005432800150	3464	Economy	11700.00
0005434427331	3464	Economy	11700.00
0005434880504	3464	Economy	11700.00
0005435903060	3464	Economy	11700.00
0005434880516	3464	Economy	11700.00
0005435913969	3464	Economy	11700.00
0005435127375	3464	Economy	11700.00
0005434427337	3464	Economy	11700.00
0005434880591	3464	Economy	11700.00
0005432800164	3464	Economy	11700.00
0005434938628	3464	Economy	11700.00
0005435127377	3464	Economy	11700.00
0005434880539	3464	Economy	11700.00
0005435626636	3464	Economy	11700.00
0005434880559	3464	Economy	11700.00
0005435626629	3464	Economy	11700.00
0005434880513	3464	Economy	11700.00
0005434427321	3464	Economy	11700.00
0005435626635	3464	Economy	11700.00
0005432183521	3464	Economy	11700.00
0005432800151	3464	Economy	11700.00
0005432800149	3464	Economy	11700.00
0005434427328	3464	Economy	11700.00
0005434880509	3464	Economy	11700.00
0005435913975	3464	Economy	11700.00
0005434427326	3464	Economy	11700.00
0005434880574	3464	Economy	11700.00
0005434880560	3464	Economy	11700.00
0005434880593	3464	Economy	11700.00
0005435626495	14538	Business	35000.00
0005435914080	14538	Business	35000.00
0005435914089	14538	Business	35000.00
0005432799973	14538	Business	35000.00
0005434879771	14538	Business	35000.00
0005434880248	14538	Business	35000.00
0005432799819	14538	Business	35000.00
0005434938442	14538	Business	35000.00
0005435626497	14538	Business	35000.00
0005435903141	14538	Business	35000.00
0005432799813	14538	Business	35000.00
0005434879664	14538	Business	35000.00
0005434879510	14538	Business	35000.00
0005432799900	14538	Business	35000.00
0005435126947	14538	Business	35000.00
0005434879507	14538	Business	35000.00
0005434879890	14538	Business	35000.00
0005435914088	14538	Business	35000.00
0005434879362	14538	Business	35000.00
0005434879361	14538	Business	35000.00
0005435127023	14538	Comfort	19900.00
0005434427085	14538	Comfort	19900.00
0005435903134	14538	Comfort	19900.00
0005435626487	14538	Comfort	19900.00
0005432799850	14538	Comfort	19900.00
0005434879584	14538	Comfort	19900.00
0005432799974	14538	Comfort	19900.00
0005434938426	14538	Comfort	19900.00
0005435903130	14538	Comfort	19900.00
0005435127109	14538	Comfort	19900.00
0005434879472	14538	Comfort	19900.00
0005435626464	14538	Comfort	19900.00
0005434938532	14538	Comfort	19900.00
0005435903143	14538	Comfort	19900.00
0005434879467	14538	Comfort	19900.00
0005435126952	14538	Comfort	19900.00
0005432607623	14538	Comfort	19900.00
0005432799925	14538	Comfort	19900.00
0005434938499	14538	Comfort	19900.00
0005434938433	14538	Comfort	19900.00
0005432799985	14538	Comfort	19900.00
0005434879171	14538	Comfort	19900.00
0005434426929	14538	Comfort	19900.00
0005432799927	14538	Comfort	19900.00
0005434938463	14538	Comfort	19900.00
0005435626443	14538	Comfort	19900.00
0005435126889	14538	Comfort	19900.00
0005435126924	14538	Comfort	19900.00
0005435126932	14538	Comfort	19900.00
0005434879931	14538	Comfort	19900.00
0005435626481	14538	Comfort	19900.00
0005435903145	14538	Comfort	19900.00
0005435126881	14538	Comfort	19900.00
0005434427101	14538	Comfort	19900.00
0005432799812	14538	Comfort	19900.00
0005432799944	14538	Economy	11700.00
0005434427164	14538	Economy	11700.00
0005432799886	14538	Economy	11700.00
0005434427194	14538	Economy	11700.00
0005432799957	14538	Economy	11700.00
0005435126931	14538	Economy	11700.00
0005434879594	14538	Economy	11700.00
0005434427051	14538	Economy	11700.00
0005434879820	14538	Economy	11700.00
0005434879744	14538	Economy	11700.00
0005435626357	14538	Economy	11700.00
0005435914093	14538	Economy	11700.00
0005434879888	14538	Economy	11700.00
0005435626463	14538	Economy	11700.00
0005434880112	14538	Economy	11700.00
0005434427084	14538	Economy	11700.00
0005434427144	14538	Economy	11700.00
0005435626448	14538	Economy	11700.00
0005435626482	14538	Economy	11700.00
0005434427022	14538	Economy	11700.00
0005434938523	14538	Economy	11700.00
0005432799945	14538	Economy	11700.00
0005434879858	14538	Economy	11700.00
0005435914073	14538	Economy	11700.00
0005432799975	14538	Economy	11700.00
0005435903144	14538	Economy	11700.00
0005435903132	14538	Economy	11700.00
0005432800045	14538	Economy	11700.00
0005432799766	14538	Economy	11700.00
0005435914096	14538	Economy	11700.00
0005434938436	14538	Economy	11700.00
0005435914740	14538	Economy	11700.00
0005434426967	14538	Economy	11700.00
0005434880001	14538	Economy	11700.00
0005434427130	14538	Economy	11700.00
0005432059555	14538	Economy	11700.00
0005434427132	14538	Economy	11700.00
0005432799946	14538	Economy	11700.00
0005435626449	14538	Economy	11700.00
0005435126888	14538	Economy	11700.00
0005435914087	14538	Economy	11700.00
0005434879700	14538	Economy	11700.00
0005432800009	14538	Economy	11700.00
0005434427029	14538	Economy	11700.00
0005434427050	14538	Economy	11700.00
0005432059554	14538	Economy	11700.00
0005434879582	14538	Economy	11700.00
0005434879884	14538	Economy	11700.00
0005435914741	14538	Economy	11700.00
0005435626506	14538	Economy	11700.00
0005435914090	14538	Economy	11700.00
0005434879442	14538	Economy	11700.00
0005435626436	14538	Economy	12800.00
0005435914075	14538	Economy	11700.00
0005434879842	14538	Economy	12800.00
0005435903137	14538	Economy	11700.00
0005434427134	14538	Economy	12800.00
0005434938535	14538	Economy	11700.00
0005434427016	14538	Economy	11700.00
0005434879714	14538	Economy	11700.00
0005434880263	14538	Economy	12800.00
0005434879454	14538	Economy	12800.00
0005434427102	14538	Economy	11700.00
0005434938479	14538	Economy	11700.00
0005435903147	14538	Economy	11700.00
0005432611768	14538	Economy	11700.00
0005435626480	14538	Economy	11700.00
0005435126882	14538	Economy	11700.00
0005434938483	14538	Economy	11700.00
0005432607620	14538	Economy	11700.00
0005435626408	14538	Economy	11700.00
0005435127022	14538	Economy	11700.00
0005434879443	14538	Economy	11700.00
0005434879763	14538	Economy	11700.00
0005434938501	14538	Economy	11700.00
0005434879772	14538	Economy	11700.00
0005434879132	14538	Economy	11700.00
0005435914077	14538	Economy	11700.00
0005432607629	14538	Economy	11700.00
0005434427038	14538	Economy	11700.00
0005432800044	14538	Economy	11700.00
0005434879762	14538	Economy	11700.00
0005435914746	14538	Economy	11700.00
0005434879764	14538	Economy	11700.00
0005434879221	14538	Economy	11700.00
0005432799862	14538	Economy	11700.00
0005435126963	14538	Economy	11700.00
0005432607621	14538	Economy	11700.00
0005434879563	14538	Economy	11700.00
0005434427030	14538	Economy	11700.00
0005434879659	14538	Economy	11700.00
0005435126962	14538	Economy	11700.00
0005434938470	14538	Economy	11700.00
0005434426994	14538	Economy	11700.00
0005434879757	14538	Economy	11700.00
0005434427042	14538	Economy	11700.00
0005435903142	14538	Economy	11700.00
0005434879581	14538	Economy	11700.00
0005434879950	14538	Economy	11700.00
0005434879650	14538	Economy	11700.00
0005435914743	14538	Economy	11700.00
0005435626428	14538	Economy	11700.00
0005432611761	14538	Economy	11700.00
0005434879387	14538	Economy	11700.00
0005435626496	14538	Economy	11700.00
0005432799821	14538	Economy	11700.00
0005435127190	14538	Economy	11700.00
0005434880231	14538	Economy	11700.00
0005434879951	14538	Economy	11700.00
0005435626505	14538	Economy	11700.00
0005435914086	14538	Economy	11700.00
0005434880170	14538	Economy	11700.00
0005434879470	14538	Economy	11700.00
0005435914738	14538	Economy	11700.00
0005434938480	14538	Economy	11700.00
0005435626414	14538	Economy	11700.00
0005434879177	14538	Economy	11700.00
0005435903133	14538	Economy	11700.00
0005434938414	14538	Economy	11700.00
0005435914083	14538	Economy	11700.00
0005434427190	14538	Economy	11700.00
0005434879564	14538	Economy	11700.00
0005435914081	14538	Economy	11700.00
0005434880040	14538	Economy	11700.00
0005434879738	14538	Economy	11700.00
0005434427131	14538	Economy	11700.00
0005435626466	14538	Economy	11700.00
0005435126928	14538	Economy	11700.00
0005434879628	14538	Economy	11700.00
0005432611767	14538	Economy	11700.00
0005434427048	14538	Economy	11700.00
0005434938522	14538	Economy	11700.00
0005435626477	14538	Economy	11700.00
0005434879852	14538	Economy	11700.00
0005435914082	14538	Economy	11700.00
0005435626444	14538	Economy	11700.00
0005435914085	14538	Economy	11700.00
0005435903131	14538	Economy	11700.00
0005434879735	14538	Economy	11700.00
0005434879386	14538	Economy	11700.00
0005434938451	14538	Economy	11700.00
0005432607619	14538	Economy	11700.00
0005435903146	14538	Economy	12800.00
0005434938413	14538	Economy	12800.00
0005435914747	14538	Economy	12800.00
0005434879911	14538	Economy	12800.00
0005435914091	14538	Economy	11700.00
0005434879792	14538	Economy	11700.00
0005435903139	14538	Economy	11700.00
0005435626442	14538	Economy	11700.00
0005434938427	14538	Economy	11700.00
0005434879851	14538	Economy	11700.00
0005434879793	14538	Economy	11700.00
0005432799984	14538	Economy	11700.00
0005434879912	14538	Economy	11700.00
0005435914079	14538	Economy	11700.00
0005432799767	14538	Economy	11700.00
0005434879870	14538	Economy	11700.00
0005432799958	14538	Economy	11700.00
0005435127003	14538	Economy	11700.00
0005435914742	14538	Economy	11700.00
0005435626476	14538	Economy	11700.00
0005434938374	14538	Economy	11700.00
0005435127067	14538	Economy	11700.00
0005435914074	14538	Economy	11700.00
0005434879966	14538	Economy	11700.00
0005435626465	14538	Economy	11700.00
0005435903135	14538	Economy	11700.00
0005434880074	14538	Economy	11700.00
0005434879773	14538	Economy	11700.00
0005435914744	14538	Economy	11700.00
0005434879473	14538	Economy	11700.00
0005435903138	14538	Economy	11700.00
0005434879674	14538	Economy	11700.00
0005432799865	14538	Economy	11700.00
0005434879978	14538	Economy	11700.00
0005435914745	14538	Economy	11700.00
0005432611766	14538	Economy	11700.00
0005435127055	14538	Economy	11700.00
0005435127071	14538	Economy	11700.00
0005434427081	14538	Economy	11700.00
0005434938471	14538	Economy	11700.00
0005434879636	14538	Economy	11700.00
0005434879889	14538	Economy	11700.00
0005434879715	14538	Economy	11700.00
0005435626491	14538	Economy	11700.00
0005434879881	14538	Economy	11700.00
0005435903136	14538	Economy	11700.00
0005435914078	14538	Economy	11700.00
0005435914739	14538	Economy	11700.00
0005432799851	14538	Economy	11700.00
0005434427173	14538	Economy	11700.00
0005435126986	14538	Economy	11700.00
0005435914094	14538	Economy	11700.00
0005434879843	14538	Economy	11700.00
0005434879626	14538	Economy	11700.00
0005432059553	14538	Economy	11700.00
0005435126999	14538	Economy	11700.00
0005435914092	14538	Economy	11700.00
0005435126850	14538	Economy	11700.00
0005434879894	14538	Economy	11700.00
0005434879583	14538	Economy	11700.00
0005434880039	14538	Economy	11700.00
0005434879915	14538	Economy	11700.00
0005434427013	14538	Economy	11700.00
0005432607626	14538	Economy	11700.00
0005434879826	14538	Economy	11700.00
0005432607627	14538	Economy	11700.00
0005435127068	14538	Economy	11700.00
0005435126925	14538	Economy	11700.00
0005434879337	14538	Economy	11700.00
0005435126927	14538	Economy	11700.00
0005435914095	14538	Economy	11700.00
0005432799820	14538	Economy	11700.00
0005434427052	14538	Economy	11700.00
0005434879176	14538	Economy	11700.00
0005435903140	14538	Economy	11700.00
0005434879859	14538	Economy	11700.00
0005434426966	14538	Economy	11700.00
0005434879756	14538	Economy	11700.00
0005434880169	14538	Economy	11700.00
0005434427191	14538	Economy	11700.00
0005434879363	14538	Economy	11700.00
0005434427021	14538	Economy	11700.00
0005435914084	14538	Economy	11700.00
0005435626488	14538	Economy	11700.00
0005434879876	14538	Economy	11700.00
0005434427135	14538	Economy	11700.00
0005435914076	14538	Economy	11700.00
0005434427133	14538	Economy	11700.00
0005434427049	14538	Economy	11700.00
0005434325937	3619	Economy	14800.00
0005434325935	3619	Economy	14800.00
0005434325931	3619	Economy	14800.00
0005434312369	3619	Economy	14800.00
0005434325933	3619	Economy	14800.00
0005435889995	3619	Economy	14800.00
0005434325932	3619	Economy	14800.00
0005434325934	3619	Economy	14800.00
0005434312371	3619	Economy	14800.00
0005434312370	3619	Economy	14800.00
0005435889997	3619	Economy	14800.00
0005434312388	3619	Economy	14800.00
0005434325930	3619	Economy	14800.00
0005434325936	3619	Economy	14800.00
0005435890045	15624	Economy	16300.00
0005435890044	15624	Economy	16300.00
0005434325861	15624	Economy	14800.00
0005435890046	15624	Economy	14800.00
0005434325860	15624	Economy	14800.00
0005434325852	15624	Economy	14800.00
0005435890047	15624	Economy	14800.00
0005434325853	15624	Economy	14800.00
0005434325797	15624	Economy	14800.00
0005435890048	15624	Economy	14800.00
0005435890042	15624	Economy	14800.00
0005435890043	15624	Economy	14800.00
0005435958057	660	Economy	4500.00
0005433420586	660	Economy	4500.00
0005435958070	660	Economy	4100.00
0005435958068	660	Economy	4100.00
0005435958071	660	Economy	4100.00
0005435958059	660	Economy	4100.00
0005435958064	660	Economy	4100.00
0005433420558	660	Economy	4100.00
0005435958066	660	Economy	4100.00
0005435958063	660	Economy	4100.00
0005435958069	660	Economy	4100.00
0005433420573	660	Economy	4100.00
0005435958058	660	Economy	4100.00
0005433420545	660	Economy	4100.00
0005435958061	660	Economy	4100.00
0005435958065	660	Economy	4100.00
0005435958067	660	Economy	4100.00
0005433420572	660	Economy	4100.00
0005433420564	660	Economy	4100.00
0005433420587	660	Economy	4100.00
0005435958062	660	Economy	4100.00
0005433420515	660	Economy	4100.00
0005433420574	660	Economy	4100.00
0005435958060	660	Economy	4100.00
0005435958072	660	Economy	4100.00
0005433420612	15185	Economy	4500.00
0005435957994	15185	Economy	4500.00
0005433420616	15185	Economy	4500.00
0005435957975	15185	Economy	4500.00
0005435957929	15185	Economy	4100.00
0005435957974	15185	Economy	4100.00
0005435957963	15185	Economy	4100.00
0005435957991	15185	Economy	4100.00
0005435957867	15185	Economy	4100.00
0005435957943	15185	Economy	4100.00
0005433420608	15185	Economy	4100.00
0005435957951	15185	Economy	4100.00
0005435957942	15185	Economy	4100.00
0005433420615	15185	Economy	4100.00
0005433420609	15185	Economy	4100.00
0005435957928	15185	Economy	4100.00
0005435957977	15185	Economy	4100.00
0005435957956	15185	Economy	4100.00
0005435957986	15185	Economy	4100.00
0005433420614	15185	Economy	4100.00
0005435957985	15185	Economy	4100.00
0005435957961	15185	Economy	4100.00
0005435957898	15185	Economy	4100.00
0005435957895	15185	Economy	4100.00
0005435957911	15185	Economy	4100.00
0005433420613	15185	Economy	4100.00
0005435957937	15185	Economy	4100.00
0005433420611	15185	Economy	4100.00
0005435957976	15185	Economy	4100.00
0005435957908	15185	Economy	4100.00
0005435957968	15185	Economy	4100.00
0005435957850	15185	Economy	4100.00
0005433420610	15185	Economy	4100.00
0005434247199	8902	Economy	10400.00
0005434247192	8902	Economy	10400.00
0005434247177	8902	Economy	10400.00
0005435629421	16045	Economy	10400.00
0005435629427	16045	Economy	10400.00
0005434247212	16045	Economy	10400.00
0005434247211	16045	Economy	10400.00
0005435629426	16045	Economy	10400.00
0005434096755	11819	Economy	14700.00
0005434096777	11819	Economy	13400.00
0005434096756	11819	Economy	13400.00
0005434096776	11819	Economy	13400.00
0005434096767	11819	Economy	13400.00
0005434096778	11819	Economy	13400.00
0005434096775	11819	Economy	13400.00
0005434096770	11819	Economy	13400.00
0005434096793	20173	Economy	13400.00
0005434096788	20173	Economy	13400.00
0005434096792	20173	Economy	13400.00
0005434096791	20173	Economy	13400.00
0005434096790	20173	Economy	13400.00
0005434096789	20173	Economy	13400.00
0005432646205	25109	Business	87700.00
0005432646234	25109	Business	87700.00
0005432646135	25109	Business	87700.00
0005435229599	25109	Business	87700.00
0005432646262	25109	Business	87700.00
0005435229591	25109	Business	87700.00
0005435229601	25109	Economy	29200.00
0005432646208	25109	Economy	29200.00
0005432646156	25109	Economy	29200.00
0005435229598	25109	Economy	29200.00
0005432646134	25109	Economy	29200.00
0005432646163	25109	Economy	29200.00
0005432646143	25109	Economy	32200.00
0005435229595	25109	Economy	32200.00
0005435229608	25109	Economy	32200.00
0005432646133	25109	Economy	32200.00
0005432646153	25109	Economy	29200.00
0005435229588	25109	Economy	29200.00
0005432646173	25109	Economy	29200.00
0005432646150	25109	Economy	29200.00
0005435229606	25109	Economy	29200.00
0005432646092	25109	Economy	29200.00
0005432646166	25109	Economy	29200.00
0005432646147	25109	Economy	29200.00
0005435229587	25109	Economy	29200.00
0005432646165	25109	Economy	29200.00
0005435229597	25109	Economy	29200.00
0005432646216	25109	Economy	29200.00
0005432646217	25109	Economy	29200.00
0005432646181	25109	Economy	29200.00
0005435229602	25109	Economy	29200.00
0005432646209	25109	Economy	29200.00
0005435229590	25109	Economy	29200.00
0005435229592	25109	Economy	29200.00
0005435229589	25109	Economy	29200.00
0005432646233	25109	Economy	29200.00
0005435229604	25109	Economy	29200.00
0005435229594	25109	Economy	29200.00
0005432646222	25109	Economy	29200.00
0005432646221	25109	Economy	29200.00
0005432646172	25109	Economy	29200.00
0005435229593	25109	Economy	29200.00
0005432646149	25109	Economy	29200.00
0005432646179	25109	Economy	29200.00
0005432646144	25109	Economy	29200.00
0005432646232	25109	Economy	29200.00
0005432646180	25109	Economy	29200.00
0005432646109	25109	Economy	29200.00
0005435229607	25109	Economy	29200.00
0005435229605	25109	Economy	29200.00
0005435229596	25109	Economy	29200.00
0005432646220	25109	Economy	29200.00
0005432646132	25109	Economy	29200.00
0005432646145	25109	Economy	29200.00
0005435229603	25109	Economy	29200.00
0005432646116	25109	Economy	29200.00
0005435229600	25109	Economy	29200.00
0005432646159	25109	Economy	29200.00
0005432646184	25109	Economy	29200.00
0005432646164	25109	Economy	29200.00
0005435797829	2877	Business	12600.00
0005433404936	2877	Business	12600.00
0005433404899	2877	Business	12600.00
0005435797826	2877	Business	12600.00
0005435797817	2877	Economy	4600.00
0005435797830	2877	Economy	4600.00
0005435797818	2877	Economy	4200.00
0005433404916	2877	Economy	4200.00
0005435797816	2877	Economy	4200.00
0005435797819	2877	Economy	4200.00
0005435797824	2877	Economy	4200.00
0005433404914	2877	Economy	4200.00
0005435797823	2877	Economy	4200.00
0005435797820	2877	Economy	4200.00
0005435797825	2877	Economy	4200.00
0005433404932	2877	Economy	4200.00
0005435797828	2877	Economy	4200.00
0005435797821	2877	Economy	4200.00
0005433404915	2877	Economy	4200.00
0005433404900	2877	Economy	4200.00
0005435797815	2877	Economy	4200.00
0005435797822	2877	Economy	4200.00
0005433404935	2877	Economy	4200.00
0005435797827	2877	Economy	4200.00
0005435797745	29326	Business	12600.00
0005433404995	29326	Business	12600.00
0005435797780	29326	Business	12600.00
0005433404994	29326	Business	12600.00
0005435797709	29326	Economy	4200.00
0005433404990	29326	Economy	4200.00
0005435797700	29326	Economy	4200.00
0005435797746	29326	Economy	4200.00
0005433404993	29326	Economy	4200.00
0005433404996	29326	Economy	4200.00
0005435797721	29326	Economy	4200.00
0005435797768	29326	Economy	4200.00
0005435797685	29326	Economy	4200.00
0005435797670	29326	Economy	4200.00
0005435797683	29326	Economy	4200.00
0005435797781	29326	Economy	4200.00
0005433404991	29326	Economy	4200.00
0005435797686	29326	Economy	4200.00
0005433404992	29326	Economy	4200.00
0005435797687	29326	Economy	4200.00
0005435797736	29326	Economy	4200.00
0005435797726	29326	Economy	4200.00
0005435376405	5765	Economy	6800.00
0005435376402	5765	Economy	6800.00
0005435376406	5765	Economy	6800.00
0005434948222	5787	Economy	6800.00
0005434948223	5787	Economy	6800.00
0005434948221	5787	Economy	6800.00
0005434948228	5787	Economy	6800.00
0005434948220	5787	Economy	6800.00
0005434948227	5787	Economy	6800.00
0005434948226	5787	Economy	6800.00
0005434948224	5787	Economy	6800.00
0005434948225	5787	Economy	6800.00
0005435376416	16409	Economy	6800.00
0005434948164	16409	Economy	6800.00
0005434948186	16409	Economy	6800.00
0005435376418	16409	Economy	6800.00
0005434948196	16409	Economy	6800.00
0005434948172	16409	Economy	6800.00
0005434948180	16409	Economy	6800.00
0005434948185	16409	Economy	6800.00
0005434948192	16409	Economy	6800.00
0005434948147	16409	Economy	6800.00
0005434948150	16409	Economy	6800.00
0005435376417	16409	Economy	6800.00
0005433962280	6902	Business	21400.00
0005433962311	6902	Business	21400.00
0005433962272	6902	Business	21400.00
0005433962287	6902	Business	21400.00
0005433962306	6902	Business	21400.00
0005433962313	6902	Business	21400.00
0005433962296	6902	Business	21400.00
0005433962283	6902	Business	21400.00
0005433962269	6902	Business	21400.00
0005433962282	6902	Economy	7100.00
0005433962310	6902	Economy	7100.00
0005433962320	6902	Economy	7100.00
0005433962295	6902	Economy	7100.00
0005433962266	6902	Economy	7100.00
0005433962276	6902	Economy	7100.00
0005433962270	6902	Economy	7100.00
0005433962312	6902	Economy	7800.00
0005433962271	6902	Economy	7800.00
0005433962308	6902	Economy	7800.00
0005433962301	6902	Economy	7100.00
0005433962286	6902	Economy	7100.00
0005433962290	6902	Economy	7100.00
0005433962303	6902	Economy	7100.00
0005433962305	6902	Economy	7100.00
0005433962299	6902	Economy	7100.00
0005433962291	6902	Economy	7100.00
0005433962285	6902	Economy	7100.00
0005433962275	6902	Economy	7100.00
0005433962314	6902	Economy	7100.00
0005433962315	6902	Economy	7100.00
0005433962273	6902	Economy	7100.00
0005433962319	6902	Economy	7100.00
0005433962300	6902	Economy	7100.00
0005433962316	6902	Economy	7100.00
0005433962307	6902	Economy	7100.00
0005433962302	6902	Economy	7100.00
0005433962309	6902	Economy	7100.00
0005433962304	6902	Economy	7100.00
0005433962277	6902	Economy	7100.00
0005433962317	6902	Economy	7100.00
0005433962284	6902	Economy	7100.00
0005433962318	6902	Economy	7100.00
0005433962289	6902	Economy	7100.00
0005433962298	6902	Economy	7100.00
0005433962267	6902	Economy	7100.00
0005433962294	6902	Economy	7100.00
0005433962279	6902	Economy	7100.00
0005433962293	6902	Economy	7100.00
0005433962288	6902	Economy	7100.00
0005433962274	6902	Economy	7100.00
0005433962297	6902	Economy	7100.00
0005433962268	6902	Economy	7100.00
0005433962278	6902	Economy	7100.00
0005433962292	6902	Economy	7100.00
0005433962281	6902	Economy	7100.00
0005433961628	25696	Business	21400.00
0005433961466	25696	Business	21400.00
0005433961693	25696	Business	21400.00
0005433961631	25696	Business	21400.00
0005433961694	25696	Business	21400.00
0005433961634	25696	Business	21400.00
0005433961671	25696	Business	21400.00
0005433961648	25696	Economy	7100.00
0005433961588	25696	Economy	7100.00
0005433961474	25696	Economy	7100.00
0005433961605	25696	Economy	7100.00
0005433961629	25696	Economy	7100.00
0005433961490	25696	Economy	7100.00
0005433961549	25696	Economy	7800.00
0005433961589	25696	Economy	7800.00
0005433961487	25696	Economy	7800.00
0005433961624	25696	Economy	7100.00
0005433961615	25696	Economy	7100.00
0005433961702	25696	Economy	7100.00
0005433961497	25696	Economy	7100.00
0005433961587	25696	Economy	7100.00
0005433961508	25696	Economy	7100.00
0005433961527	25696	Economy	7100.00
0005433961601	25696	Economy	7100.00
0005433961498	25696	Economy	7100.00
0005433961617	25696	Economy	7100.00
0005433961684	25696	Economy	7100.00
0005433961712	25696	Economy	7100.00
0005433961649	25696	Economy	7100.00
0005433961519	25696	Economy	7100.00
0005433961609	25696	Economy	7100.00
0005433961643	25696	Economy	7100.00
0005433961528	25696	Economy	7100.00
0005433961619	25696	Economy	7100.00
0005433961489	25696	Economy	7100.00
0005433961467	25696	Economy	7100.00
0005433961610	25696	Economy	7100.00
0005433961492	25696	Economy	7100.00
0005433961685	25696	Economy	7100.00
0005433961564	25696	Economy	7100.00
0005433961672	25696	Economy	7100.00
0005433961692	25696	Economy	7100.00
0005433961644	25696	Economy	7100.00
0005433961668	25696	Economy	7100.00
0005433961614	25696	Economy	7100.00
0005433961557	25696	Economy	7100.00
0005433961655	25696	Economy	7100.00
0005433961540	25696	Economy	7100.00
0005433961518	25696	Economy	7100.00
0005433961548	25696	Economy	7100.00
0005433961315	25696	Economy	7100.00
0005433961600	25696	Economy	7100.00
0005433961465	25696	Economy	7100.00
0005435082948	24442	Economy	3900.00
0005435082882	24442	Economy	3900.00
0005435082913	24442	Economy	3900.00
0005435082902	24442	Economy	3900.00
0005435082927	24442	Economy	3900.00
0005435082911	24442	Economy	3900.00
0005435082945	24442	Economy	3900.00
0005435082912	24442	Economy	3900.00
0005435082980	26129	Economy	3900.00
0005435082984	26129	Economy	3900.00
0005435082979	26129	Economy	3900.00
0005435082983	26129	Economy	3900.00
0005435082977	26129	Economy	3900.00
0005435082985	26129	Economy	3900.00
0005435082982	26129	Economy	3900.00
0005435082981	26129	Economy	3900.00
0005435082978	26129	Economy	3900.00
0005434245713	5231	Business	18000.00
0005434245697	5231	Business	18000.00
0005434245703	5231	Business	18000.00
0005434245691	5231	Business	18000.00
0005434245710	5231	Business	18000.00
0005435286695	5231	Business	18000.00
0005435286710	5231	Business	18000.00
0005434245705	5231	Business	18000.00
0005435286716	5231	Business	18000.00
0005433534535	5231	Business	18000.00
0005434245694	5231	Economy	6600.00
0005433534536	5231	Economy	6600.00
0005435286677	5231	Economy	6000.00
0005435286713	5231	Economy	6000.00
0005434245698	5231	Economy	6000.00
0005432166982	5231	Economy	6000.00
0005434245714	5231	Economy	6000.00
0005434245699	5231	Economy	6000.00
0005433534534	5231	Economy	6000.00
0005434245704	5231	Economy	6000.00
0005434245707	5231	Economy	6000.00
0005434245702	5231	Economy	6000.00
0005434245716	5231	Economy	6000.00
0005434245709	5231	Economy	6000.00
0005434245696	5231	Economy	6600.00
0005434245692	5231	Economy	6000.00
0005434245708	5231	Economy	6000.00
0005434245711	5231	Economy	6000.00
0005434245706	5231	Economy	6000.00
0005432166980	5231	Economy	6000.00
0005434245701	5231	Economy	6000.00
0005434245715	5231	Economy	6000.00
0005434245695	5231	Economy	6000.00
0005434245717	5231	Economy	6000.00
0005432166981	5231	Economy	6000.00
0005435286711	5231	Economy	6000.00
0005434245712	5231	Economy	6000.00
0005435286686	5231	Economy	6000.00
0005435286689	5231	Economy	6000.00
0005434245700	5231	Economy	6000.00
0005434245693	5231	Economy	6000.00
0005432106749	5232	Business	18000.00
0005433616482	5232	Business	18000.00
0005433785832	5232	Business	18000.00
0005432106752	5232	Business	18000.00
0005432106765	5232	Business	18000.00
0005433785828	5232	Business	18000.00
0005433785852	5232	Business	18000.00
0005433616480	5232	Business	18000.00
0005433785853	5232	Business	18000.00
0005433785844	5232	Business	18000.00
0005433785847	5232	Business	18000.00
0005433616526	5232	Business	18000.00
0005433785831	5232	Business	18000.00
0005433616474	5232	Business	18000.00
0005433616472	5232	Business	18000.00
0005433616473	5232	Business	18000.00
0005432667505	5232	Business	18000.00
0005433616460	5232	Business	18000.00
0005433785854	5232	Business	18000.00
0005433616518	5232	Business	18000.00
0005433785841	5232	Business	18000.00
0005433785851	5232	Business	18000.00
0005433616520	5232	Business	18000.00
0005433785858	5232	Business	18000.00
0005433785823	5232	Business	18000.00
0005433616484	5232	Business	18000.00
0005433616471	5232	Business	18000.00
0005433785838	5232	Business	18000.00
0005433616496	5232	Economy	6600.00
0005433785830	5232	Economy	6600.00
0005433785839	5232	Economy	6600.00
0005433616521	5232	Economy	6600.00
0005433616464	5232	Economy	6600.00
0005433616483	5232	Economy	6600.00
0005433616498	5232	Economy	6000.00
0005433616523	5232	Economy	6000.00
0005433616456	5232	Economy	6000.00
0005432106753	5232	Economy	6000.00
0005432106740	5232	Economy	6000.00
0005432106734	5232	Economy	6000.00
0005433616504	5232	Economy	6000.00
0005433616470	5232	Economy	6000.00
0005433616475	5232	Economy	6000.00
0005432106731	5232	Economy	6000.00
0005433616505	5232	Economy	6000.00
0005433785842	5232	Economy	6000.00
0005433616503	5232	Economy	6000.00
0005432106747	5232	Economy	6000.00
0005433616508	5232	Economy	6000.00
0005432106737	5232	Economy	6000.00
0005433785857	5232	Economy	6000.00
0005432106764	5232	Economy	6000.00
0005433785848	5232	Economy	6000.00
0005433616517	5232	Economy	6000.00
0005433785819	5232	Economy	6000.00
0005432106758	5232	Economy	6000.00
0005432106738	5232	Economy	6000.00
0005433785824	5232	Economy	6000.00
0005433616514	5232	Economy	6000.00
0005433616515	5232	Economy	6000.00
0005432106728	5232	Economy	6000.00
0005432106746	5232	Economy	6000.00
0005432665326	5232	Economy	6000.00
0005432106720	5232	Economy	6000.00
0005433785840	5232	Economy	6000.00
0005433616501	5232	Economy	6000.00
0005432106722	5232	Economy	6000.00
0005433616524	5232	Economy	6000.00
0005432106754	5232	Economy	6000.00
0005433785834	5232	Economy	6000.00
0005433616469	5232	Economy	6000.00
0005433616493	5232	Economy	6000.00
0005433616478	5232	Economy	6000.00
0005432106762	5232	Economy	6000.00
0005433785859	5232	Economy	6000.00
0005433785827	5232	Economy	6000.00
0005433616507	5232	Economy	6000.00
0005432106744	5232	Economy	6000.00
0005432106748	5232	Economy	6000.00
0005432145163	5232	Economy	6000.00
0005433785835	5232	Economy	6000.00
0005433616462	5232	Economy	6000.00
0005433616492	5232	Economy	6000.00
0005432106717	5232	Economy	6000.00
0005433616522	5232	Economy	6000.00
0005432106759	5232	Economy	6000.00
0005432106756	5232	Economy	6000.00
0005432106741	5232	Economy	6000.00
0005433785845	5232	Economy	6000.00
0005433616463	5232	Economy	6000.00
0005433616476	5232	Economy	6000.00
0005432106719	5232	Economy	6000.00
0005433616490	5232	Economy	6000.00
0005432106742	5232	Economy	6000.00
0005433616479	5232	Economy	6600.00
0005433785822	5232	Economy	6600.00
0005433616459	5232	Economy	6600.00
0005433616458	5232	Economy	6600.00
0005433616489	5232	Economy	6600.00
0005433616491	5232	Economy	6000.00
0005433616487	5232	Economy	6000.00
0005433785836	5232	Economy	6600.00
0005433785820	5232	Economy	6000.00
0005432106727	5232	Economy	6000.00
0005433616510	5232	Economy	6000.00
0005432106724	5232	Economy	6000.00
0005432106735	5232	Economy	6000.00
0005433616477	5232	Economy	6000.00
0005432106750	5232	Economy	6000.00
0005433785856	5232	Economy	6000.00
0005432106726	5232	Economy	6000.00
0005433616499	5232	Economy	6000.00
0005432667507	5232	Economy	6000.00
0005433616500	5232	Economy	6000.00
0005433785846	5232	Economy	6000.00
0005433616497	5232	Economy	6000.00
0005432106736	5232	Economy	6000.00
0005433616519	5232	Economy	6000.00
0005433616465	5232	Economy	6000.00
0005432106751	5232	Economy	6000.00
0005433616488	5232	Economy	6000.00
0005432666440	5232	Economy	6000.00
0005433785849	5232	Economy	6000.00
0005433616468	5232	Economy	6000.00
0005432106730	5232	Economy	6000.00
0005433785837	5232	Economy	6000.00
0005433785825	5232	Economy	6000.00
0005433616502	5232	Economy	6000.00
0005432106732	5232	Economy	6000.00
0005432106760	5232	Economy	6000.00
0005433785850	5232	Economy	6000.00
0005432106739	5232	Economy	6000.00
0005433616467	5232	Economy	6000.00
0005433616513	5232	Economy	6000.00
0005432666439	5232	Economy	6000.00
0005433616506	5232	Economy	6000.00
0005433616486	5232	Economy	6000.00
0005433785821	5232	Economy	6000.00
0005433616494	5232	Economy	6000.00
0005433616495	5232	Economy	6000.00
0005433616466	5232	Economy	6000.00
0005433616516	5232	Economy	6000.00
0005432106718	5232	Economy	6000.00
0005433616461	5232	Economy	6000.00
0005432106725	5232	Economy	6000.00
0005432667506	5232	Economy	6000.00
0005433616457	5232	Economy	6000.00
0005433616481	5232	Economy	6000.00
0005433616525	5232	Economy	6000.00
0005432667504	5232	Economy	6000.00
0005432106755	5232	Economy	6000.00
0005432106729	5232	Economy	6000.00
0005432106757	5232	Economy	6000.00
0005432106721	5232	Economy	6000.00
0005433616512	5232	Economy	6000.00
0005433785826	5232	Economy	6000.00
0005433616485	5232	Economy	6000.00
0005433785843	5232	Economy	6000.00
0005433785855	5232	Economy	6000.00
0005432106761	5232	Economy	6000.00
0005432106745	5232	Economy	6000.00
0005433785829	5232	Economy	6000.00
0005432106733	5232	Economy	6000.00
0005433616509	5232	Economy	6000.00
0005432106743	5232	Economy	6000.00
0005433785833	5232	Economy	6000.00
0005433616511	5232	Economy	6000.00
0005432106763	5232	Economy	6000.00
0005432106723	5232	Economy	6000.00
0005435007349	5234	Business	18000.00
0005435007380	5234	Business	18000.00
0005432336200	5234	Business	18000.00
0005435007457	5234	Business	18000.00
0005433815459	5234	Business	18000.00
0005434265757	5234	Business	18000.00
0005434265764	5234	Business	18000.00
0005434229927	5234	Business	18000.00
0005432336284	5234	Business	18000.00
0005435007431	5234	Business	18000.00
0005434265767	5234	Business	18000.00
0005432336152	5234	Business	18000.00
0005435269847	5234	Business	18000.00
0005435007407	5234	Business	18000.00
0005435007462	5234	Business	18000.00
0005434265781	5234	Business	18000.00
0005434265778	5234	Business	18000.00
0005435269849	5234	Business	18000.00
0005434150016	5234	Business	18000.00
0005435007303	5234	Business	18000.00
0005435269855	5234	Economy	6600.00
0005434150023	5234	Economy	6600.00
0005435269851	5234	Economy	6600.00
0005434229920	5234	Economy	6600.00
0005433685539	5234	Economy	6000.00
0005435007390	5234	Economy	6000.00
0005434150024	5234	Economy	6000.00
0005434265760	5234	Economy	6000.00
0005432336173	5234	Economy	6000.00
0005435007389	5234	Economy	6000.00
0005434229931	5234	Economy	6000.00
0005433815479	5234	Economy	6000.00
0005434229917	5234	Economy	6000.00
0005435007502	5234	Economy	6000.00
0005434265763	5234	Economy	6000.00
0005434311256	5234	Economy	6000.00
0005433815447	5234	Economy	6000.00
0005432336211	5234	Economy	6000.00
0005432336247	5234	Economy	6000.00
0005434173620	5234	Economy	6000.00
0005432336197	5234	Economy	6000.00
0005434229921	5234	Economy	6000.00
0005432336198	5234	Economy	6000.00
0005434150025	5234	Economy	6000.00
0005434229932	5234	Economy	6000.00
0005434311255	5234	Economy	6000.00
0005434265759	5234	Economy	6000.00
0005434173618	5234	Economy	6000.00
0005435007370	5234	Economy	6000.00
0005434150021	5234	Economy	6000.00
0005434229928	5234	Economy	6000.00
0005432336222	5234	Economy	6000.00
0005435007506	5234	Economy	6000.00
0005434173646	5234	Economy	6000.00
0005434150018	5234	Economy	6000.00
0005434265777	5234	Economy	6000.00
0005434150020	5234	Economy	6000.00
0005435007330	5234	Economy	6000.00
0005434265780	5234	Economy	6000.00
0005434173617	5234	Economy	6000.00
0005432336235	5234	Economy	6000.00
0005434229934	5234	Economy	6000.00
0005432336195	5234	Economy	6000.00
0005434265779	5234	Economy	6000.00
0005434229916	5234	Economy	6000.00
0005435007368	5234	Economy	6000.00
0005434265775	5234	Economy	6000.00
0005435007350	5234	Economy	6000.00
0005434173647	5234	Economy	6000.00
0005434229924	5234	Economy	6000.00
0005435269846	5234	Economy	6000.00
0005435007397	5234	Economy	6600.00
0005434265765	5234	Economy	6600.00
0005435007463	5234	Economy	6600.00
0005434265772	5234	Economy	6000.00
0005434311247	5234	Economy	6000.00
0005434229922	5234	Economy	6000.00
0005434229933	5234	Economy	6000.00
0005432336229	5234	Economy	6000.00
0005434229929	5234	Economy	6000.00
0005435269854	5234	Economy	6000.00
0005434229923	5234	Economy	6000.00
0005434229930	5234	Economy	6000.00
0005434150022	5234	Economy	6000.00
0005433815472	5234	Economy	6000.00
0005434265776	5234	Economy	6000.00
0005434265768	5234	Economy	6000.00
0005435007418	5234	Economy	6000.00
0005434312343	5234	Economy	6000.00
0005434150015	5234	Economy	6000.00
0005434265769	5234	Economy	6000.00
0005434150017	5234	Economy	6000.00
0005434312342	5234	Economy	6000.00
0005432336210	5234	Economy	6000.00
0005434265761	5234	Economy	6000.00
0005433815446	5234	Economy	6000.00
0005435007357	5234	Economy	6000.00
0005435007432	5234	Economy	6000.00
0005434265758	5234	Economy	6000.00
0005434265756	5234	Economy	6000.00
0005434265766	5234	Economy	6000.00
0005434173645	5234	Economy	6000.00
0005433815458	5234	Economy	6000.00
0005434265762	5234	Economy	6000.00
0005434229925	5234	Economy	6000.00
0005433815471	5234	Economy	6000.00
0005435007323	5234	Economy	6000.00
0005432336207	5234	Economy	6000.00
0005432336201	5234	Economy	6000.00
0005433815473	5234	Economy	6000.00
0005434229919	5234	Economy	6000.00
0005433815457	5234	Economy	6000.00
0005434229915	5234	Economy	6000.00
0005433815480	5234	Economy	6000.00
0005434265773	5234	Economy	6000.00
0005434229918	5234	Economy	6000.00
0005435007379	5234	Economy	6000.00
0005434265771	5234	Economy	6000.00
0005434265774	5234	Economy	6000.00
0005434150019	5234	Economy	6000.00
0005435269848	5234	Economy	6000.00
0005432336260	5234	Economy	6000.00
0005435007406	5234	Economy	6000.00
0005432336196	5234	Economy	6000.00
0005434173619	5234	Economy	6000.00
0005434229926	5234	Economy	6000.00
0005434265770	5234	Economy	6000.00
0005432336246	5234	Economy	6000.00
0005435270023	8482	Business	18000.00
0005435270032	8482	Business	18000.00
0005435270048	8482	Business	18000.00
0005435270013	8482	Business	18000.00
0005434245411	8482	Business	18000.00
0005434245578	8482	Business	18000.00
0005435270030	8482	Business	18000.00
0005434245574	8482	Business	18000.00
0005434245565	8482	Business	18000.00
0005433785516	8482	Business	18000.00
0005434245293	8482	Business	18000.00
0005435270059	8482	Business	18000.00
0005434245423	8482	Business	18000.00
0005434245515	8482	Business	18000.00
0005435270041	8482	Business	18000.00
0005435270056	8482	Business	18000.00
0005434245422	8482	Business	18000.00
0005434245586	8482	Business	18000.00
0005434245652	8482	Economy	6600.00
0005435270014	8482	Economy	6600.00
0005434245485	8482	Economy	6600.00
0005433785535	8482	Economy	6600.00
0005433785565	8482	Economy	6000.00
0005435270046	8482	Economy	6000.00
0005435270025	8482	Economy	6000.00
0005434245429	8482	Economy	6000.00
0005435270042	8482	Economy	6000.00
0005434245529	8482	Economy	6000.00
0005435270047	8482	Economy	6000.00
0005434245463	8482	Economy	6000.00
0005434245596	8482	Economy	6000.00
0005435270044	8482	Economy	6000.00
0005434245562	8482	Economy	6000.00
0005435270045	8482	Economy	6000.00
0005435270035	8482	Economy	6000.00
0005435270039	8482	Economy	6000.00
0005433785622	8482	Economy	6000.00
0005434245542	8482	Economy	6000.00
0005435270019	8482	Economy	6000.00
0005434245581	8482	Economy	6000.00
0005435270050	8482	Economy	6000.00
0005433785471	8482	Economy	6000.00
0005433785581	8482	Economy	6000.00
0005433785515	8482	Economy	6000.00
0005434245540	8482	Economy	6000.00
0005434245406	8482	Economy	6000.00
0005434245464	8482	Economy	6000.00
0005434245480	8482	Economy	6000.00
0005434245419	8482	Economy	6000.00
0005434245420	8482	Economy	6000.00
0005434245426	8482	Economy	6000.00
0005435270055	8482	Economy	6000.00
0005434245368	8482	Economy	6000.00
0005434245414	8482	Economy	6000.00
0005433785385	8482	Economy	6000.00
0005432666416	8482	Economy	6000.00
0005434245363	8482	Economy	6000.00
0005433785547	8482	Economy	6000.00
0005434245428	8482	Economy	6000.00
0005434245567	8482	Economy	6000.00
0005435270040	8482	Economy	6000.00
0005435270043	8482	Economy	6000.00
0005434245595	8482	Economy	6000.00
0005433785570	8482	Economy	6600.00
0005433785563	8482	Economy	6600.00
0005434245366	8482	Economy	6600.00
0005435270024	8482	Economy	6600.00
0005434245479	8482	Economy	6000.00
0005434245537	8482	Economy	6000.00
0005435270052	8482	Economy	6600.00
0005435270036	8482	Economy	6000.00
0005434245653	8482	Economy	6000.00
0005434245651	8482	Economy	6000.00
0005434245367	8482	Economy	6000.00
0005435270054	8482	Economy	6000.00
0005434245545	8482	Economy	6000.00
0005435270020	8482	Economy	6000.00
0005433785569	8482	Economy	6000.00
0005435270031	8482	Economy	6000.00
0005435270021	8482	Economy	6000.00
0005432663059	8482	Economy	6000.00
0005435270022	8482	Economy	6000.00
0005434245465	8482	Economy	6000.00
0005435270058	8482	Economy	6000.00
0005434245292	8482	Economy	6000.00
0005434245534	8482	Economy	6000.00
0005434245503	8482	Economy	6000.00
0005435270049	8482	Economy	6000.00
0005434245580	8482	Economy	6000.00
0005435270017	8482	Economy	6000.00
0005435270037	8482	Economy	6000.00
0005434245587	8482	Economy	6000.00
0005435270018	8482	Economy	6000.00
0005434245407	8482	Economy	6000.00
0005435270028	8482	Economy	6000.00
0005435270026	8482	Economy	6000.00
0005434245387	8482	Economy	6000.00
0005434245444	8482	Economy	6000.00
0005435270029	8482	Economy	6000.00
0005435270038	8482	Economy	6000.00
0005435270033	8482	Economy	6000.00
0005435270057	8482	Economy	6000.00
0005435270034	8482	Economy	6000.00
0005435270015	8482	Economy	6000.00
0005435270051	8482	Economy	6000.00
0005435270053	8482	Economy	6000.00
0005434245556	8482	Economy	6000.00
0005433785470	8482	Economy	6000.00
0005433785564	8482	Economy	6000.00
0005435270016	8482	Economy	6000.00
0005435270027	8482	Economy	6000.00
0005433615447	8481	Business	18000.00
0005433615726	8481	Business	18000.00
0005433615346	8481	Business	18000.00
0005433615841	8481	Business	18000.00
0005433615847	8481	Business	18000.00
0005433616052	8481	Business	18000.00
0005433615692	8481	Business	18000.00
0005433615869	8481	Business	18000.00
0005433615793	8481	Business	18000.00
0005433615731	8481	Business	18000.00
0005433616041	8481	Business	18000.00
0005433616171	8481	Business	18000.00
0005433615785	8481	Business	18000.00
0005433615762	8481	Economy	6600.00
0005433615840	8481	Economy	6600.00
0005433616072	8481	Economy	6000.00
0005433615945	8481	Economy	6000.00
0005433615652	8481	Economy	6000.00
0005433615728	8481	Economy	6000.00
0005433615915	8481	Economy	6000.00
0005433615922	8481	Economy	6000.00
0005433615814	8481	Economy	6000.00
0005433615787	8481	Economy	6000.00
0005433615865	8481	Economy	6000.00
0005433615533	8481	Economy	6000.00
0005433615725	8481	Economy	6000.00
0005433615788	8481	Economy	6000.00
0005433615819	8481	Economy	6000.00
0005433615970	8481	Economy	6000.00
0005433615936	8481	Economy	6000.00
0005433615806	8481	Economy	6000.00
0005433615732	8481	Economy	6000.00
0005433616015	8481	Economy	6000.00
0005433615877	8481	Economy	6000.00
0005433615895	8481	Economy	6000.00
0005433615594	8481	Economy	6600.00
0005433615571	8481	Economy	6600.00
0005433615777	8481	Economy	6600.00
0005433616136	8481	Economy	6000.00
0005433615896	8481	Economy	6000.00
0005433615834	8481	Economy	6000.00
0005433615987	8481	Economy	6000.00
0005433615807	8481	Economy	6000.00
0005433615854	8481	Economy	6000.00
0005433615986	8481	Economy	6000.00
0005433616025	8481	Economy	6000.00
0005433615427	8481	Economy	6000.00
0005433615998	8481	Economy	6000.00
0005433616172	8481	Economy	6000.00
0005433615649	8481	Economy	6000.00
0005433615556	8481	Economy	6000.00
0005433615937	8481	Economy	6000.00
0005433615874	8481	Economy	6000.00
0005433615694	8481	Economy	6000.00
0005433616073	8481	Economy	6000.00
0005433615727	8481	Economy	6000.00
0005433615805	8481	Economy	6000.00
0005433615960	8481	Economy	6000.00
0005433616112	8481	Economy	6000.00
0005433615776	8481	Economy	6000.00
0005433615651	8481	Economy	6000.00
0005433615947	8481	Economy	6000.00
0005433615643	8481	Economy	6000.00
0005433615500	8481	Economy	6000.00
0005433615818	8481	Economy	6000.00
0005433615644	8481	Economy	6000.00
0005433615875	8481	Economy	6000.00
0005433615778	8481	Economy	6000.00
0005433615650	8481	Economy	6000.00
0005433615708	8481	Economy	6000.00
0005432336325	8480	Business	18000.00
0005432047642	8480	Business	18000.00
0005432035621	8480	Business	18000.00
0005433689962	8480	Business	18000.00
0005432336332	8480	Business	18000.00
0005434149926	8480	Business	18000.00
0005433815548	8480	Business	18000.00
0005434265685	8480	Business	18000.00
0005434265667	8480	Business	18000.00
0005432035633	8480	Business	18000.00
0005433815506	8480	Business	18000.00
0005434149930	8480	Business	18000.00
0005432035632	8480	Business	18000.00
0005432336333	8480	Business	18000.00
0005434229691	8480	Business	18000.00
0005435007604	8480	Business	18000.00
0005432035637	8480	Business	18000.00
0005434265563	8480	Business	18000.00
0005434229745	8480	Business	18000.00
0005434229621	8480	Business	18000.00
0005433815505	8480	Business	18000.00
0005434265406	8480	Business	18000.00
0005432035625	8480	Business	18000.00
0005434229751	8480	Business	18000.00
0005433815507	8480	Business	18000.00
0005432035619	8480	Business	18000.00
0005432035624	8480	Business	18000.00
0005433815504	8480	Economy	6600.00
0005432035636	8480	Economy	6600.00
0005432336322	8480	Economy	6600.00
0005435007603	8480	Economy	6600.00
0005434229643	8480	Economy	6600.00
0005432336330	8480	Economy	6600.00
0005435286760	8480	Economy	6000.00
0005432035638	8480	Economy	6000.00
0005433815545	8480	Economy	6000.00
0005435007589	8480	Economy	6000.00
0005434229696	8480	Economy	6000.00
0005434149944	8480	Economy	6000.00
0005433690975	8480	Economy	6000.00
0005432336324	8480	Economy	6000.00
0005434265596	8480	Economy	6000.00
0005434265492	8480	Economy	6000.00
0005434229732	8480	Economy	6000.00
0005433815544	8480	Economy	6000.00
0005434265476	8480	Economy	6000.00
0005435007602	8480	Economy	6000.00
0005434265616	8480	Economy	6000.00
0005434229684	8480	Economy	6000.00
0005435286759	8480	Economy	6000.00
0005434311269	8480	Economy	6000.00
0005432035620	8480	Economy	6000.00
0005434265567	8480	Economy	6000.00
0005435286758	8480	Economy	6000.00
0005433815546	8480	Economy	6000.00
0005432035629	8480	Economy	6000.00
0005434229774	8480	Economy	6000.00
0005434173578	8480	Economy	6000.00
0005434229792	8480	Economy	6000.00
0005432035640	8480	Economy	6000.00
0005434173571	8480	Economy	6000.00
0005434229692	8480	Economy	6000.00
0005435007595	8480	Economy	6000.00
0005432035628	8480	Economy	6000.00
0005434229731	8480	Economy	6000.00
0005433534550	8480	Economy	6000.00
0005434229620	8480	Economy	6000.00
0005432035635	8480	Economy	6000.00
0005435007590	8480	Economy	6000.00
0005433688861	8480	Economy	6000.00
0005434311284	8480	Economy	6000.00
0005434265510	8480	Economy	6000.00
0005432035643	8480	Economy	6000.00
0005435286764	8480	Economy	6000.00
0005434229789	8480	Economy	6000.00
0005435286762	8480	Economy	6000.00
0005432035639	8480	Economy	6000.00
0005434265573	8480	Economy	6000.00
0005434229756	8480	Economy	6000.00
0005435007591	8480	Economy	6000.00
0005432047643	8480	Economy	6000.00
0005435007601	8480	Economy	6000.00
0005432336329	8480	Economy	6000.00
0005432336328	8480	Economy	6000.00
0005432035627	8480	Economy	6000.00
0005434149925	8480	Economy	6000.00
0005435007597	8480	Economy	6000.00
0005434149960	8480	Economy	6000.00
0005432035618	8480	Economy	6000.00
0005432336327	8480	Economy	6600.00
0005435007593	8480	Economy	6600.00
0005435007599	8480	Economy	6600.00
0005432035631	8480	Economy	6600.00
0005434265493	8480	Economy	6000.00
0005434229811	8480	Economy	6000.00
0005434265641	8480	Economy	6000.00
0005432047644	8480	Economy	6000.00
0005434265572	8480	Economy	6600.00
0005434229683	8480	Economy	6000.00
0005433690976	8480	Economy	6000.00
0005434265574	8480	Economy	6000.00
0005434311285	8480	Economy	6000.00
0005432035622	8480	Economy	6000.00
0005434229644	8480	Economy	6000.00
0005434229788	8480	Economy	6000.00
0005435286761	8480	Economy	6000.00
0005435286766	8480	Economy	6000.00
0005434229730	8480	Economy	6000.00
0005432035644	8480	Economy	6000.00
0005432035626	8480	Economy	6000.00
0005434265514	8480	Economy	6000.00
0005434265447	8480	Economy	6000.00
0005434229725	8480	Economy	6000.00
0005434173590	8480	Economy	6000.00
0005434265568	8480	Economy	6000.00
0005432035642	8480	Economy	6000.00
0005432336331	8480	Economy	6000.00
0005434149946	8480	Economy	6000.00
0005432035641	8480	Economy	6000.00
0005433688862	8480	Economy	6000.00
0005433815543	8480	Economy	6000.00
0005434173577	8480	Economy	6000.00
0005432336323	8480	Economy	6000.00
0005435007605	8480	Economy	6000.00
0005434265553	8480	Economy	6000.00
0005434229673	8480	Economy	6000.00
0005434229655	8480	Economy	6000.00
0005432035634	8480	Economy	6000.00
0005435286765	8480	Economy	6000.00
0005434265615	8480	Economy	6000.00
0005434149945	8480	Economy	6000.00
0005434229734	8480	Economy	6000.00
0005434229645	8480	Economy	6000.00
0005435007592	8480	Economy	6000.00
0005434265622	8480	Economy	6000.00
0005434229693	8480	Economy	6000.00
0005434229596	8480	Economy	6000.00
0005434311270	8480	Economy	6000.00
0005434265666	8480	Economy	6000.00
0005434265554	8480	Economy	6000.00
0005432336326	8480	Economy	6000.00
0005435007596	8480	Economy	6000.00
0005433815547	8480	Economy	6000.00
0005435007594	8480	Economy	6000.00
0005434149927	8480	Economy	6000.00
0005434311268	8480	Economy	6000.00
0005434229649	8480	Economy	6000.00
0005433689963	8480	Economy	6000.00
0005434229773	8480	Economy	6000.00
0005435286763	8480	Economy	6000.00
0005434229759	8480	Economy	6000.00
0005435007600	8480	Economy	6000.00
0005433815503	8480	Economy	6000.00
0005434229755	8480	Economy	6000.00
0005434173589	8480	Economy	6000.00
0005435007606	8480	Economy	6000.00
0005435007598	8480	Economy	6000.00
0005432035630	8480	Economy	6000.00
0005432035623	8480	Economy	6000.00
0005434639678	12636	Economy	16200.00
0005434639605	12636	Economy	16200.00
0005433202721	12636	Economy	16200.00
0005434639703	12636	Economy	14800.00
0005434639684	12636	Economy	14800.00
0005434639660	12636	Economy	14800.00
0005433202722	12636	Economy	14800.00
0005433202730	12636	Economy	14800.00
0005434639746	12636	Economy	14800.00
0005434639720	12636	Economy	14800.00
0005434639604	12636	Economy	14800.00
0005434639833	12636	Economy	14800.00
0005434639732	12636	Economy	14800.00
0005433202727	12636	Economy	14800.00
0005433202728	12636	Economy	14800.00
0005434639659	12636	Economy	14800.00
0005434639706	12636	Economy	14800.00
0005434639701	12636	Economy	14800.00
0005434639716	12636	Economy	14800.00
0005433202726	12636	Economy	14800.00
0005433202731	12636	Economy	14800.00
0005433202725	12636	Economy	14800.00
0005433202729	12636	Economy	14800.00
0005434639736	12636	Economy	14800.00
0005433202724	12636	Economy	14800.00
0005434639627	12636	Economy	14800.00
0005434639745	12636	Economy	14800.00
0005433202720	12636	Economy	14800.00
0005434639688	12636	Economy	14800.00
0005433202733	12636	Economy	14800.00
0005434639705	12636	Economy	14800.00
0005434639756	12636	Economy	14800.00
0005434639674	12636	Economy	14800.00
0005434639689	12636	Economy	14800.00
0005434639842	12636	Economy	14800.00
0005434639747	12636	Economy	14800.00
0005434639700	12636	Economy	14800.00
0005433202723	12636	Economy	14800.00
0005434639834	12636	Economy	14800.00
0005434639733	12636	Economy	14800.00
0005433202732	12636	Economy	14800.00
0005432290708	23342	Economy	16200.00
0005433202533	23342	Economy	16200.00
0005434639936	23342	Economy	14800.00
0005433202532	23342	Economy	14800.00
0005434639922	23342	Economy	14800.00
0005434639938	23342	Economy	14800.00
0005434639944	23342	Economy	14800.00
0005433202636	23342	Economy	14800.00
0005434639942	23342	Economy	14800.00
0005434639927	23342	Economy	14800.00
0005433202578	23342	Economy	14800.00
0005434639920	23342	Economy	14800.00
0005434639934	23342	Economy	14800.00
0005434639940	23342	Economy	14800.00
0005434639937	23342	Economy	14800.00
0005433202607	23342	Economy	14800.00
0005434639928	23342	Economy	14800.00
0005434639925	23342	Economy	14800.00
0005434639931	23342	Economy	14800.00
0005434639929	23342	Economy	14800.00
0005434639935	23342	Economy	14800.00
0005433202545	23342	Economy	14800.00
0005434639923	23342	Economy	14800.00
0005434639930	23342	Economy	14800.00
0005434639933	23342	Economy	14800.00
0005434639939	23342	Economy	14800.00
0005434639924	23342	Economy	14800.00
0005432290706	23342	Economy	14800.00
0005432290707	23342	Economy	14800.00
0005433202637	23342	Economy	14800.00
0005434639932	23342	Economy	14800.00
0005434639919	23342	Economy	14800.00
0005434639943	23342	Economy	14800.00
0005434639941	23342	Economy	14800.00
0005434639926	23342	Economy	14800.00
0005434639921	23342	Economy	14800.00
0005432329492	21053	Business	18900.00
0005432329389	21053	Business	18900.00
0005432329522	21053	Business	18900.00
0005432383689	21053	Business	18900.00
0005432054377	21053	Business	18900.00
0005432329392	21053	Business	18900.00
0005432054379	21053	Business	18900.00
0005432329423	21053	Business	18900.00
0005432383650	21053	Business	18900.00
0005432329562	21053	Business	18900.00
0005432329454	21053	Business	18900.00
0005432329377	21053	Business	18900.00
0005432329154	21053	Economy	6300.00
0005432329231	21053	Economy	6300.00
0005432329046	21053	Economy	6300.00
0005432329449	21053	Economy	6300.00
0005432383728	21053	Economy	6300.00
0005432329523	21053	Economy	6300.00
0005432329501	21053	Economy	6300.00
0005432329450	21053	Economy	6300.00
0005432329521	21053	Economy	6300.00
0005432383781	21053	Economy	6900.00
0005432329404	21053	Economy	6900.00
0005432383767	21053	Economy	6900.00
0005432329370	21053	Economy	6900.00
0005432383704	21053	Economy	6900.00
0005432329315	21053	Economy	6300.00
0005432383828	21053	Economy	6300.00
0005432329535	21053	Economy	6300.00
0005432383690	21053	Economy	6300.00
0005432383628	21053	Economy	6300.00
0005432329194	21053	Economy	6300.00
0005432329455	21053	Economy	6300.00
0005432329401	21053	Economy	6300.00
0005432329310	21053	Economy	6300.00
0005432383753	21053	Economy	6300.00
0005432329532	21053	Economy	6300.00
0005432329393	21053	Economy	6300.00
0005432329402	21053	Economy	6300.00
0005432329361	21053	Economy	6300.00
0005432329446	21053	Economy	6300.00
0005432329255	21053	Economy	6300.00
0005432329491	21053	Economy	6300.00
0005432383572	21053	Economy	6300.00
0005432329414	21053	Economy	6300.00
0005432329533	21053	Economy	6300.00
0005432383793	21053	Economy	6300.00
0005432329563	21053	Economy	6300.00
0005432383727	21053	Economy	6300.00
0005432383758	21053	Economy	6300.00
0005432329412	21053	Economy	6300.00
0005432329415	21053	Economy	6300.00
0005432329241	21053	Economy	6300.00
0005432383651	21053	Economy	6300.00
0005432329560	21053	Economy	6300.00
0005432383702	21053	Economy	6300.00
0005432329448	21053	Economy	6300.00
0005432329406	21053	Economy	6300.00
0005432383748	21053	Economy	6300.00
0005432329368	21053	Economy	6300.00
0005432329286	21053	Economy	6300.00
0005432383824	21053	Economy	6300.00
0005432329352	21053	Economy	6300.00
0005432329200	21053	Economy	6300.00
0005432329357	21053	Economy	6300.00
0005432329534	21053	Economy	6300.00
0005432329287	21053	Economy	6300.00
0005432329275	21053	Economy	6300.00
0005432383713	21053	Economy	6300.00
0005432329280	21053	Economy	6300.00
0005432329407	21053	Economy	6300.00
0005432329405	21053	Economy	6300.00
0005432329451	21053	Economy	6300.00
0005432383620	21053	Economy	6300.00
0005432329487	21053	Economy	6300.00
0005432329486	21053	Economy	6300.00
0005432329403	21053	Economy	6300.00
0005432329561	21053	Economy	6300.00
0005432329507	21053	Economy	6300.00
0005432383712	21053	Economy	6300.00
0005432383734	21053	Economy	6300.00
0005432329413	21053	Economy	6300.00
0005432329453	21053	Economy	6300.00
0005432329371	21053	Economy	6300.00
0005432329369	21053	Economy	6300.00
0005432329447	21053	Economy	6300.00
0005432054378	21053	Economy	6300.00
0005432329452	21053	Economy	6300.00
0005432383759	21053	Economy	6300.00
0005432329462	21053	Economy	6300.00
0005432329311	21053	Economy	6300.00
0005432054376	21053	Economy	6300.00
0005432329391	21053	Economy	6300.00
0005432329500	21053	Economy	6300.00
0005432329794	31280	Business	18900.00
0005432384077	31280	Business	18900.00
0005432329772	31280	Business	18900.00
0005432384095	31280	Business	18900.00
0005432329806	31280	Business	18900.00
0005432384089	31280	Business	18900.00
0005432384094	31280	Business	18900.00
0005432287308	31280	Business	18900.00
0005432329797	31280	Business	18900.00
0005432384096	31280	Business	18900.00
0005432384093	31280	Business	18900.00
0005432384112	31280	Economy	6300.00
0005432384103	31280	Economy	6300.00
0005432384105	31280	Economy	6300.00
0005432329781	31280	Economy	6300.00
0005432287312	31280	Economy	6300.00
0005432329791	31280	Economy	6300.00
0005432384115	31280	Economy	6300.00
0005432329796	31280	Economy	6300.00
0005432329792	31280	Economy	6300.00
0005432384085	31280	Economy	6300.00
0005432384101	31280	Economy	6900.00
0005432329799	31280	Economy	6900.00
0005432384088	31280	Economy	6900.00
0005432329778	31280	Economy	6900.00
0005432384099	31280	Economy	6900.00
0005432329795	31280	Economy	6300.00
0005432329774	31280	Economy	6300.00
0005432329807	31280	Economy	6300.00
0005432384108	31280	Economy	6300.00
0005432384076	31280	Economy	6300.00
0005432329776	31280	Economy	6300.00
0005432329777	31280	Economy	6300.00
0005432329788	31280	Economy	6300.00
0005432329784	31280	Economy	6300.00
0005432384111	31280	Economy	6300.00
0005432384082	31280	Economy	6300.00
0005432329805	31280	Economy	6300.00
0005432329779	31280	Economy	6300.00
0005432384083	31280	Economy	6300.00
0005432329789	31280	Economy	6300.00
0005432384114	31280	Economy	6300.00
0005432384113	31280	Economy	6300.00
0005432384091	31280	Economy	6300.00
0005432384100	31280	Economy	6300.00
0005432384074	31280	Economy	6300.00
0005432384109	31280	Economy	6300.00
0005432329813	31280	Economy	6300.00
0005432329812	31280	Economy	6300.00
0005432384081	31280	Economy	6300.00
0005432329808	31280	Economy	6300.00
0005432384087	31280	Economy	6300.00
0005432384104	31280	Economy	6300.00
0005432329770	31280	Economy	6300.00
0005432287311	31280	Economy	6300.00
0005432287309	31280	Economy	6300.00
0005432329811	31280	Economy	6300.00
0005432329810	31280	Economy	6300.00
0005432329798	31280	Economy	6300.00
0005432329787	31280	Economy	6300.00
0005432384102	31280	Economy	6300.00
0005432329800	31280	Economy	6300.00
0005432384106	31280	Economy	6300.00
0005432384084	31280	Economy	6300.00
0005432384078	31280	Economy	6300.00
0005432329785	31280	Economy	6300.00
0005432329793	31280	Economy	6300.00
0005432329809	31280	Economy	6300.00
0005432384090	31280	Economy	6300.00
0005432329803	31280	Economy	6300.00
0005432384116	31280	Economy	6300.00
0005432329786	31280	Economy	6300.00
0005432384080	31280	Economy	6300.00
0005432329804	31280	Economy	6300.00
0005432329782	31280	Economy	6300.00
0005432848844	31280	Economy	6300.00
0005432384086	31280	Economy	6300.00
0005432329801	31280	Economy	6300.00
0005432329771	31280	Economy	6300.00
0005432287310	31280	Economy	6300.00
0005432329783	31280	Economy	6300.00
0005432384110	31280	Economy	6300.00
0005432384079	31280	Economy	6300.00
0005432329790	31280	Economy	6300.00
0005432329780	31280	Economy	6300.00
0005432384098	31280	Economy	6300.00
0005432384107	31280	Economy	6300.00
0005432384075	31280	Economy	6300.00
0005432329802	31280	Economy	6300.00
0005432329775	31280	Economy	6300.00
0005432384097	31280	Economy	6300.00
0005432384092	31280	Economy	6300.00
0005432329769	31280	Economy	6300.00
0005432329773	31280	Economy	6300.00
0005432954144	27594	Business	89600.00
0005432954137	27594	Business	89600.00
0005433642564	27594	Business	89600.00
0005433642480	27594	Business	89600.00
0005432954134	27594	Business	89600.00
0005433642520	27594	Economy	29900.00
0005433642581	27594	Economy	29900.00
0005433642590	27594	Economy	29900.00
0005433642557	27594	Economy	29900.00
0005432954141	27594	Economy	32800.00
0005433642565	27594	Economy	29900.00
0005432954147	27594	Economy	29900.00
0005433642613	27594	Economy	29900.00
0005432954143	27594	Economy	29900.00
0005433642586	27594	Economy	29900.00
0005432954135	27594	Economy	29900.00
0005433642592	27594	Economy	29900.00
0005433642504	27594	Economy	29900.00
0005432954148	27594	Economy	29900.00
0005432954136	27594	Economy	29900.00
0005433642563	27594	Economy	29900.00
0005432954138	27594	Economy	29900.00
0005433642554	27594	Economy	29900.00
0005433642510	27594	Economy	29900.00
0005433642553	27594	Economy	29900.00
0005432954145	27594	Economy	29900.00
0005433642597	27594	Economy	29900.00
0005432954146	27594	Economy	29900.00
0005433642566	27594	Economy	29900.00
0005433642606	27594	Economy	29900.00
0005432954140	27594	Economy	29900.00
0005432954142	27594	Economy	29900.00
0005433642616	27594	Economy	29900.00
0005433642617	27594	Economy	29900.00
0005432954139	27594	Economy	29900.00
0005432425614	13293	Business	12700.00
0005432425598	13293	Business	12700.00
0005432425613	13293	Business	12700.00
0005432425587	13293	Business	12700.00
0005432425610	13293	Business	12700.00
0005432425584	13293	Business	12700.00
0005432425609	13293	Economy	4200.00
0005432425593	13293	Economy	4200.00
0005432425599	13293	Economy	4200.00
0005432425589	13293	Economy	4200.00
0005432425612	13293	Economy	4200.00
0005432425607	13293	Economy	4700.00
0005432425583	13293	Economy	4700.00
0005432425585	13293	Economy	4700.00
0005432425582	13293	Economy	4200.00
0005432425578	13293	Economy	4200.00
0005432425596	13293	Economy	4200.00
0005432425594	13293	Economy	4200.00
0005432425600	13293	Economy	4200.00
0005432425590	13293	Economy	4200.00
0005432425603	13293	Economy	4200.00
0005432425579	13293	Economy	4200.00
0005432425597	13293	Economy	4200.00
0005432425608	13293	Economy	4200.00
0005432425591	13293	Economy	4200.00
0005432425618	13293	Economy	4200.00
0005432425611	13293	Economy	4200.00
0005432425617	13293	Economy	4200.00
0005432425592	13293	Economy	4200.00
0005432425605	13293	Economy	4200.00
0005432425601	13293	Economy	4200.00
0005432425616	13293	Economy	4200.00
0005432425586	13293	Economy	4200.00
0005432425619	13293	Economy	4200.00
0005432425580	13293	Economy	4200.00
0005432425604	13293	Economy	4200.00
0005432425588	13293	Economy	4200.00
0005432425606	13293	Economy	4200.00
0005432425595	13293	Economy	4200.00
0005432425602	13293	Economy	4200.00
0005432425615	13293	Economy	4200.00
0005432425581	13293	Economy	4200.00
0005432425199	30759	Business	12700.00
0005432425049	30759	Business	12700.00
0005432424982	30759	Business	12700.00
0005432425130	30759	Business	12700.00
0005432425121	30759	Business	12700.00
0005432425224	30759	Business	12700.00
0005432425119	30759	Business	12700.00
0005432425073	30759	Economy	4200.00
0005432425072	30759	Economy	4200.00
0005432424916	30759	Economy	4200.00
0005432424977	30759	Economy	4700.00
0005432425225	30759	Economy	4700.00
0005432424986	30759	Economy	4200.00
0005432425139	30759	Economy	4200.00
0005432425126	30759	Economy	4200.00
0005432425221	30759	Economy	4200.00
0005432425143	30759	Economy	4200.00
0005432425220	30759	Economy	4200.00
0005432425230	30759	Economy	4200.00
0005432425190	30759	Economy	4200.00
0005432425122	30759	Economy	4200.00
0005432425070	30759	Economy	4200.00
0005432425217	30759	Economy	4200.00
0005432425108	30759	Economy	4200.00
0005432425171	30759	Economy	4200.00
0005432425026	30759	Economy	4200.00
0005432425194	30759	Economy	4200.00
0005432425195	30759	Economy	4200.00
0005432425082	30759	Economy	4200.00
0005432425113	30759	Economy	4200.00
0005432424985	30759	Economy	4200.00
0005432425045	30759	Economy	4200.00
0005432425034	30759	Economy	4200.00
0005432425110	30759	Economy	4200.00
0005432425152	30759	Economy	4200.00
0005432425198	30759	Economy	4200.00
0005432425107	30759	Economy	4200.00
0005432425128	30759	Economy	4200.00
0005432425129	30759	Economy	4200.00
0005432425127	30759	Economy	4200.00
0005432425035	30759	Economy	4200.00
0005432424915	30759	Economy	4200.00
0005432425153	30759	Economy	4200.00
0005432425083	30759	Economy	4200.00
0005432425189	30759	Economy	4200.00
0005432425226	30759	Economy	4200.00
0005432425109	30759	Economy	4200.00
0005434157599	9578	Business	32600.00
0005432818211	9578	Business	32600.00
0005432818196	9578	Business	32600.00
0005432901898	9578	Business	32600.00
0005432818186	9578	Business	32600.00
0005432822394	9578	Business	32600.00
0005432822393	9578	Business	32600.00
0005434157619	9578	Business	32600.00
0005432818192	9578	Business	32600.00
0005434157567	9578	Economy	10900.00
0005434157618	9578	Economy	10900.00
0005432289068	9578	Economy	10900.00
0005434186249	9578	Economy	10900.00
0005434186250	9578	Economy	10900.00
0005434157627	9578	Economy	10900.00
0005432901895	9578	Economy	10900.00
0005432822389	9578	Economy	10900.00
0005432901879	9578	Economy	10900.00
0005432901871	9578	Economy	11900.00
0005432818204	9578	Economy	11900.00
0005432818195	9578	Economy	11900.00
0005432818208	9578	Economy	11900.00
0005432901932	9578	Economy	11900.00
0005432818203	9578	Economy	10900.00
0005432818207	9578	Economy	10900.00
0005432818202	9578	Economy	10900.00
0005432822395	9578	Economy	10900.00
0005434157598	9578	Economy	10900.00
0005432901853	9578	Economy	10900.00
0005432818212	9578	Economy	10900.00
0005434186255	9578	Economy	10900.00
0005434157590	9578	Economy	10900.00
0005432822392	9578	Economy	10900.00
0005432818199	9578	Economy	10900.00
0005432818187	9578	Economy	10900.00
0005432822390	9578	Economy	10900.00
0005434157604	9578	Economy	10900.00
0005432818201	9578	Economy	10900.00
0005432901846	9578	Economy	10900.00
0005432901941	9578	Economy	10900.00
0005432818197	9578	Economy	10900.00
0005432818190	9578	Economy	10900.00
0005432901872	9578	Economy	10900.00
0005434157569	9578	Economy	10900.00
0005432818189	9578	Economy	10900.00
0005434157621	9578	Economy	10900.00
0005432289065	9578	Economy	10900.00
0005432289066	9578	Economy	10900.00
0005432818193	9578	Economy	10900.00
0005434157605	9578	Economy	10900.00
0005432818206	9578	Economy	10900.00
0005434157620	9578	Economy	10900.00
0005434157625	9578	Economy	10900.00
0005432818188	9578	Economy	10900.00
0005432901870	9578	Economy	10900.00
0005432901896	9578	Economy	10900.00
0005432818185	9578	Economy	10900.00
0005432901856	9578	Economy	10900.00
0005432818209	9578	Economy	10900.00
0005434448400	9578	Economy	10900.00
0005432818210	9578	Economy	10900.00
0005432822396	9578	Economy	10900.00
0005434448399	9578	Economy	10900.00
0005434448401	9578	Economy	10900.00
0005432901880	9578	Economy	10900.00
0005432289067	9578	Economy	10900.00
0005432818194	9578	Economy	10900.00
0005432901959	9578	Economy	10900.00
0005434186254	9578	Economy	10900.00
0005432818198	9578	Economy	10900.00
0005434157568	9578	Economy	10900.00
0005432818184	9578	Economy	10900.00
0005432901864	9578	Economy	10900.00
0005432901930	9578	Economy	10900.00
0005432818200	9578	Economy	10900.00
0005432822391	9578	Economy	10900.00
0005432818205	9578	Economy	10900.00
0005432901890	9578	Economy	10900.00
0005432901942	9578	Economy	10900.00
0005432818191	9578	Economy	10900.00
0005432901931	9578	Economy	10900.00
0005432901878	9578	Economy	10900.00
0005432902044	29008	Business	32600.00
0005432822331	29008	Business	32600.00
0005432818009	29008	Business	32600.00
0005432817971	29008	Business	32600.00
0005432902039	29008	Business	32600.00
0005432822340	29008	Business	32600.00
0005434157672	29008	Business	32600.00
0005432902038	29008	Economy	10900.00
0005432817932	29008	Economy	10900.00
0005432817899	29008	Economy	10900.00
0005432817933	29008	Economy	10900.00
0005432902045	29008	Economy	10900.00
0005434186267	29008	Economy	10900.00
0005432817967	29008	Economy	10900.00
0005434157670	29008	Economy	11900.00
0005432822310	29008	Economy	11900.00
0005432818045	29008	Economy	11900.00
0005432902034	29008	Economy	10900.00
0005434186268	29008	Economy	10900.00
0005432822341	29008	Economy	10900.00
0005432818008	29008	Economy	10900.00
0005434157669	29008	Economy	10900.00
0005432902036	29008	Economy	10900.00
0005432817912	29008	Economy	10900.00
0005432822334	29008	Economy	10900.00
0005432822329	29008	Economy	10900.00
0005434448364	29008	Economy	10900.00
0005434157673	29008	Economy	10900.00
0005432817906	29008	Economy	10900.00
0005432817845	29008	Economy	10900.00
0005434157675	29008	Economy	10900.00
0005432902031	29008	Economy	10900.00
0005432822311	29008	Economy	10900.00
0005432902033	29008	Economy	10900.00
0005432902035	29008	Economy	10900.00
0005432822328	29008	Economy	10900.00
0005432902032	29008	Economy	10900.00
0005432902042	29008	Economy	10900.00
0005432902037	29008	Economy	10900.00
0005432902040	29008	Economy	10900.00
0005432817869	29008	Economy	10900.00
0005432817913	29008	Economy	10900.00
0005432822314	29008	Economy	10900.00
0005434157667	29008	Economy	10900.00
0005432902041	29008	Economy	10900.00
0005434157668	29008	Economy	10900.00
0005432818015	29008	Economy	10900.00
0005432817827	29008	Economy	10900.00
0005432002127	29008	Economy	10900.00
0005432002128	29008	Economy	10900.00
0005434186269	29008	Economy	10900.00
0005434157674	29008	Economy	10900.00
0005432817970	29008	Economy	10900.00
0005432817966	29008	Economy	10900.00
0005432902043	29008	Economy	10900.00
0005434157671	29008	Economy	10900.00
0005432613961	15139	Economy	11000.00
0005432611799	15139	Economy	11000.00
0005435841836	15139	Economy	11000.00
0005432611800	15139	Economy	11000.00
0005432611801	15139	Economy	11000.00
0005432613964	15139	Economy	11000.00
0005432613962	15139	Economy	11000.00
0005435841837	15139	Economy	11000.00
0005432613963	15139	Economy	11000.00
0005435841831	15139	Economy	11000.00
0005432611798	15139	Economy	11000.00
0005432607629	31556	Economy	11000.00
0005432611761	31556	Economy	11000.00
0005432607621	31556	Economy	11000.00
0005432611768	31556	Economy	11000.00
0005432607627	31556	Economy	11000.00
0005432607620	31556	Economy	11000.00
0005432607619	31556	Economy	11000.00
0005432611766	31556	Economy	11000.00
0005432607623	31556	Economy	11000.00
0005432611767	31556	Economy	11000.00
0005432607626	31556	Economy	11000.00
0005432949085	11876	Business	105900.00
0005432948974	11876	Business	105900.00
0005432949008	11876	Business	105900.00
0005433570542	11876	Business	105900.00
0005433570513	11876	Business	105900.00
0005433570503	11876	Business	105900.00
0005433570557	11876	Business	105900.00
0005432948909	11876	Business	105900.00
0005433570507	11876	Business	105900.00
0005432949063	11876	Business	105900.00
0005433570559	11876	Business	105900.00
0005433570504	11876	Business	105900.00
0005433570530	11876	Business	105900.00
0005432949071	11876	Business	105900.00
0005433570569	11876	Business	105900.00
0005433570560	11876	Business	105900.00
0005432948942	11876	Business	105900.00
0005433570540	11876	Business	105900.00
0005432949133	11876	Economy	35300.00
0005432948907	11876	Economy	35300.00
0005433570516	11876	Economy	35300.00
0005432949059	11876	Economy	35300.00
0005433570511	11876	Economy	35300.00
0005433570541	11876	Economy	35300.00
0005433570543	11876	Economy	35300.00
0005433570502	11876	Economy	35300.00
0005432948925	11876	Economy	35300.00
0005433570499	11876	Economy	35300.00
0005433570509	11876	Economy	35300.00
0005433570537	11876	Economy	35300.00
0005433570531	11876	Economy	35300.00
0005432949128	11876	Economy	38800.00
0005432949120	11876	Economy	38800.00
0005432949134	11876	Economy	38800.00
0005433570565	11876	Economy	38800.00
0005433570556	11876	Economy	35300.00
0005433570558	11876	Economy	35300.00
0005432948807	11876	Economy	35300.00
0005432948912	11876	Economy	35300.00
0005433570550	11876	Economy	35300.00
0005433570549	11876	Economy	35300.00
0005432949171	11876	Economy	35300.00
0005433570561	11876	Economy	35300.00
0005433570522	11876	Economy	35300.00
0005433570523	11876	Economy	35300.00
0005433570521	11876	Economy	35300.00
0005432949088	11876	Economy	35300.00
0005432948951	11876	Economy	35300.00
0005433570553	11876	Economy	35300.00
0005433570545	11876	Economy	35300.00
0005432948905	11876	Economy	35300.00
0005433570518	11876	Economy	35300.00
0005432948930	11876	Economy	35300.00
0005433570554	11876	Economy	35300.00
0005433570510	11876	Economy	35300.00
0005433570508	11876	Economy	35300.00
0005432949089	11876	Economy	35300.00
0005433570544	11876	Economy	35300.00
0005432949015	11876	Economy	35300.00
0005432949195	11876	Economy	35300.00
0005433570548	11876	Economy	35300.00
0005432949196	11876	Economy	35300.00
0005432949009	11876	Economy	35300.00
0005433570501	11876	Economy	35300.00
0005433570551	11876	Economy	35300.00
0005433570533	11876	Economy	35300.00
0005432949197	11876	Economy	35300.00
0005433570538	11876	Economy	35300.00
0005432949023	11876	Economy	35300.00
0005433570515	11876	Economy	35300.00
0005433570520	11876	Economy	35300.00
0005433570506	11876	Economy	35300.00
0005432949121	11876	Economy	35300.00
0005433570529	11876	Economy	35300.00
0005433570564	11876	Economy	35300.00
0005433570524	11876	Economy	35300.00
0005433570528	11876	Economy	35300.00
0005433570519	11876	Economy	35300.00
0005433570562	11876	Economy	35300.00
0005432948913	11876	Economy	35300.00
0005433570567	11876	Economy	35300.00
0005433570568	11876	Economy	35300.00
0005433570547	11876	Economy	35300.00
0005432948989	11876	Economy	35300.00
0005433570555	11876	Economy	35300.00
0005433570539	11876	Economy	35300.00
0005433570535	11876	Economy	35300.00
0005432949058	11876	Economy	35300.00
0005432949072	11876	Economy	35300.00
0005433570552	11876	Economy	35300.00
0005432948991	11876	Economy	35300.00
0005432949014	11876	Economy	35300.00
0005432949093	11876	Economy	35300.00
0005433570546	11876	Economy	35300.00
0005433570532	11876	Economy	35300.00
0005433570526	11876	Economy	35300.00
0005433570527	11876	Economy	35300.00
0005433570534	11876	Economy	35300.00
0005432948869	11876	Economy	35300.00
0005433570512	11876	Economy	35300.00
0005433570566	11876	Economy	35300.00
0005432949147	11876	Economy	35300.00
0005433570500	11876	Economy	35300.00
0005433570536	11876	Economy	35300.00
0005433570505	11876	Economy	35300.00
0005432949146	11876	Economy	35300.00
0005433570525	11876	Economy	35300.00
0005432948992	11876	Economy	35300.00
0005432948952	11876	Economy	35300.00
0005433570514	11876	Economy	35300.00
0005433570517	11876	Economy	35300.00
0005433570563	11876	Economy	35300.00
0005433569850	25315	Business	105900.00
0005432949488	25315	Business	105900.00
0005432949508	25315	Business	105900.00
0005433569522	25315	Business	105900.00
0005433569896	25315	Business	105900.00
0005433569751	25315	Business	105900.00
0005433569968	25315	Business	105900.00
0005432949499	25315	Business	105900.00
0005432949512	25315	Business	105900.00
0005432949502	25315	Business	105900.00
0005433569882	25315	Business	105900.00
0005433570002	25315	Business	105900.00
0005433570015	25315	Business	105900.00
0005432949481	25315	Business	105900.00
0005432949498	25315	Business	105900.00
0005432949477	25315	Business	105900.00
0005432949511	25315	Business	105900.00
0005433570001	25315	Business	105900.00
0005432949507	25315	Economy	35300.00
0005433569829	25315	Economy	35300.00
0005432949487	25315	Economy	35300.00
0005432949495	25315	Economy	35300.00
0005432949504	25315	Economy	35300.00
0005433569793	25315	Economy	35300.00
0005432949479	25315	Economy	35300.00
0005433569915	25315	Economy	35300.00
0005432949501	25315	Economy	35300.00
0005433570029	25315	Economy	35300.00
0005433569920	25315	Economy	38800.00
0005432949506	25315	Economy	38800.00
0005433570046	25315	Economy	38800.00
0005432949514	25315	Economy	38800.00
0005433569901	25315	Economy	35300.00
0005433569952	25315	Economy	35300.00
0005433569941	25315	Economy	35300.00
0005432949491	25315	Economy	35300.00
0005433570045	25315	Economy	35300.00
0005432949480	25315	Economy	35300.00
0005433569883	25315	Economy	35300.00
0005433569884	25315	Economy	35300.00
0005433569939	25315	Economy	35300.00
0005433569955	25315	Economy	35300.00
0005432949478	25315	Economy	35300.00
0005433569899	25315	Economy	35300.00
0005433569961	25315	Economy	35300.00
0005433569893	25315	Economy	35300.00
0005433569903	25315	Economy	35300.00
0005433570067	25315	Economy	35300.00
0005432949509	25315	Economy	35300.00
0005433570007	25315	Economy	35300.00
0005432949515	25315	Economy	35300.00
0005433569892	25315	Economy	35300.00
0005432949476	25315	Economy	35300.00
0005432949483	25315	Economy	35300.00
0005433569664	25315	Economy	35300.00
0005433569867	25315	Economy	35300.00
0005432949516	25315	Economy	35300.00
0005433569938	25315	Economy	35300.00
0005433569914	25315	Economy	35300.00
0005432949493	25315	Economy	35300.00
0005432949489	25315	Economy	35300.00
0005432949494	25315	Economy	35300.00
0005432949485	25315	Economy	35300.00
0005433569665	25315	Economy	35300.00
0005432949497	25315	Economy	35300.00
0005433569902	25315	Economy	35300.00
0005433569943	25315	Economy	35300.00
0005433569881	25315	Economy	35300.00
0005433569956	25315	Economy	35300.00
0005433570060	25315	Economy	35300.00
0005432949484	25315	Economy	35300.00
0005433569753	25315	Economy	35300.00
0005432949482	25315	Economy	35300.00
0005433569750	25315	Economy	35300.00
0005433569752	25315	Economy	35300.00
0005433570033	25315	Economy	35300.00
0005432949513	25315	Economy	35300.00
0005433569520	25315	Economy	35300.00
0005433569521	25315	Economy	35300.00
0005433569934	25315	Economy	35300.00
0005433570032	25315	Economy	35300.00
0005433569519	25315	Economy	35300.00
0005433570068	25315	Economy	35300.00
0005432949505	25315	Economy	35300.00
0005433569916	25315	Economy	35300.00
0005432949490	25315	Economy	35300.00
0005432949486	25315	Economy	35300.00
0005433569930	25315	Economy	35300.00
0005433569876	25315	Economy	35300.00
0005432949510	25315	Economy	35300.00
0005433570031	25315	Economy	35300.00
0005433569953	25315	Economy	35300.00
0005433569948	25315	Economy	35300.00
0005432949503	25315	Economy	35300.00
0005432949492	25315	Economy	35300.00
0005433569746	25315	Economy	35300.00
0005432949496	25315	Economy	35300.00
0005433570059	25315	Economy	35300.00
0005433569967	25315	Economy	35300.00
0005433570004	25315	Economy	35300.00
0005432949500	25315	Economy	35300.00
0005433569954	25315	Economy	35300.00
0005434655411	5404	Business	67200.00
0005434655390	5404	Business	67200.00
0005432114281	5404	Business	67200.00
0005435340478	5404	Business	67200.00
0005434655388	5404	Business	67200.00
0005434655383	5404	Business	67200.00
0005434655412	5404	Economy	22400.00
0005434655408	5404	Economy	22400.00
0005434655401	5404	Economy	22400.00
0005434655407	5404	Economy	22400.00
0005434655395	5404	Economy	24600.00
0005434655397	5404	Economy	24600.00
0005435340439	5404	Economy	24600.00
0005434655399	5404	Economy	24600.00
0005435555395	5404	Economy	24600.00
0005434655394	5404	Economy	22400.00
0005434655403	5404	Economy	22400.00
0005432114283	5404	Economy	22400.00
0005435340440	5404	Economy	22400.00
0005435340422	5404	Economy	22400.00
0005434655396	5404	Economy	22400.00
0005434655393	5404	Economy	22400.00
0005434655404	5404	Economy	22400.00
0005434655410	5404	Economy	22400.00
0005435340498	5404	Economy	22400.00
0005435555394	5404	Economy	22400.00
0005434655405	5404	Economy	22400.00
0005434655385	5404	Economy	22400.00
0005434655400	5404	Economy	22400.00
0005434655402	5404	Economy	22400.00
0005435555402	5404	Economy	22400.00
0005434656606	5404	Economy	22400.00
0005435340464	5404	Economy	22400.00
0005435340441	5404	Economy	22400.00
0005435340491	5404	Economy	22400.00
0005435555401	5404	Economy	22400.00
0005434656605	5404	Economy	22400.00
0005434655384	5404	Economy	22400.00
0005435340489	5404	Economy	22400.00
0005434655409	5404	Economy	22400.00
0005432114282	5404	Economy	22400.00
0005435555396	5404	Economy	22400.00
0005434655406	5404	Economy	22400.00
0005434655398	5404	Economy	22400.00
0005434655386	5404	Economy	22400.00
0005435340557	5404	Economy	22400.00
0005434655389	5404	Economy	22400.00
0005435340481	5404	Economy	22400.00
0005434655387	5404	Economy	22400.00
0005435340511	5404	Economy	22400.00
0005435340482	5404	Economy	22400.00
0005434655391	5404	Economy	22400.00
0005434655392	5404	Economy	22400.00
0005434655030	12545	Business	67200.00
0005434655218	12545	Business	67200.00
0005435340635	12545	Business	67200.00
0005434655226	12545	Business	67200.00
0005434655219	12545	Business	67200.00
0005434655091	12545	Business	67200.00
0005434655074	12545	Business	67200.00
0005435340631	12545	Business	67200.00
0005435340636	12545	Economy	22400.00
0005435340628	12545	Economy	22400.00
0005434655059	12545	Economy	22400.00
0005434655173	12545	Economy	22400.00
0005435555421	12545	Economy	22400.00
0005434656584	12545	Economy	24600.00
0005434655199	12545	Economy	24600.00
0005434655008	12545	Economy	24600.00
0005434655243	12545	Economy	24600.00
0005435340641	12545	Economy	24600.00
0005435340642	12545	Economy	22400.00
0005434655119	12545	Economy	22400.00
0005434655104	12545	Economy	22400.00
0005434655126	12545	Economy	22400.00
0005434655060	12545	Economy	22400.00
0005434655115	12545	Economy	22400.00
0005434655124	12545	Economy	22400.00
0005434655144	12545	Economy	22400.00
0005434655141	12545	Economy	22400.00
0005434655168	12545	Economy	22400.00
0005434655105	12545	Economy	22400.00
0005434655065	12545	Economy	22400.00
0005435340637	12545	Economy	22400.00
0005435340638	12545	Economy	22400.00
0005435340643	12545	Economy	22400.00
0005434655049	12545	Economy	22400.00
0005434655172	12545	Economy	22400.00
0005435340633	12545	Economy	22400.00
0005434655064	12545	Economy	22400.00
0005434655227	12545	Economy	22400.00
0005434655120	12545	Economy	22400.00
0005435340629	12545	Economy	22400.00
0005434655151	12545	Economy	22400.00
0005434655071	12545	Economy	22400.00
0005435340640	12545	Economy	22400.00
0005434655123	12545	Economy	22400.00
0005434655031	12545	Economy	22400.00
0005435340630	12545	Economy	22400.00
0005434655048	12545	Economy	22400.00
0005434655113	12545	Economy	22400.00
0005435340632	12545	Economy	22400.00
0005434655029	12545	Economy	22400.00
0005434655152	12545	Economy	22400.00
0005435340634	12545	Economy	22400.00
0005434655127	12545	Economy	22400.00
0005434655191	12545	Economy	22400.00
0005435340639	12545	Economy	22400.00
0005433717197	7452	Business	32000.00
0005433717209	7452	Business	32000.00
0005433717201	7452	Business	32000.00
0005433722372	7452	Business	32000.00
0005435266202	7452	Business	32000.00
0005433689961	7452	Business	32000.00
0005433722379	7452	Business	32000.00
0005433719222	7452	Business	32000.00
0005433656749	7452	Business	32000.00
0005433722371	7452	Business	32000.00
0005435266208	7452	Economy	10700.00
0005433717174	7452	Economy	10700.00
0005433717173	7452	Economy	10700.00
0005433717171	7452	Economy	10700.00
0005432428985	7452	Economy	10700.00
0005433717202	7452	Economy	10700.00
0005433656750	7452	Economy	10700.00
0005433719221	7452	Economy	10700.00
0005432428986	7452	Economy	10700.00
0005433717213	7452	Economy	10700.00
0005433717199	7452	Economy	10700.00
0005433717195	7452	Economy	10700.00
0005433717184	7452	Economy	10700.00
0005433719223	7452	Economy	10700.00
0005433717206	7452	Economy	10700.00
0005435266201	7452	Economy	10700.00
0005433717187	7452	Economy	10700.00
0005432428976	7452	Economy	10700.00
0005433717181	7452	Economy	10700.00
0005435266194	7452	Economy	10700.00
0005433717198	7452	Economy	10700.00
0005433717192	7452	Economy	10700.00
0005433717172	7452	Economy	10700.00
0005432078244	7452	Economy	10700.00
0005433717194	7452	Economy	10700.00
0005432428977	7452	Economy	10700.00
0005433717180	7452	Economy	10700.00
0005433717190	7452	Economy	10700.00
0005433722376	7452	Economy	10700.00
0005433690973	7452	Economy	11700.00
0005433717186	7452	Economy	11700.00
0005433719220	7452	Economy	11700.00
0005432078240	7452	Economy	11700.00
0005435266203	7452	Economy	11700.00
0005433717196	7452	Economy	10700.00
0005432428989	7452	Economy	10700.00
0005433717203	7452	Economy	10700.00
0005433717177	7452	Economy	10700.00
0005433690974	7452	Economy	10700.00
0005432078243	7452	Economy	10700.00
0005433717210	7452	Economy	10700.00
0005433717212	7452	Economy	10700.00
0005433717167	7452	Economy	10700.00
0005433717175	7452	Economy	10700.00
0005433717205	7452	Economy	10700.00
0005432078242	7452	Economy	10700.00
0005433717191	7452	Economy	10700.00
0005433722373	7452	Economy	10700.00
0005433717204	7452	Economy	10700.00
0005433717183	7452	Economy	10700.00
0005433717166	7452	Economy	10700.00
0005433717193	7452	Economy	10700.00
0005433717179	7452	Economy	10700.00
0005433717182	7452	Economy	10700.00
0005433717169	7452	Economy	10700.00
0005433656751	7452	Economy	10700.00
0005433688859	7452	Economy	10700.00
0005433722378	7452	Economy	10700.00
0005433688860	7452	Economy	10700.00
0005433717168	7452	Economy	10700.00
0005433722375	7452	Economy	10700.00
0005433717207	7452	Economy	10700.00
0005433717211	7452	Economy	10700.00
0005433717189	7452	Economy	10700.00
0005433717170	7452	Economy	10700.00
0005433717188	7452	Economy	10700.00
0005433717208	7452	Economy	10700.00
0005433717200	7452	Economy	10700.00
0005433722374	7452	Economy	10700.00
0005433717185	7452	Economy	10700.00
0005432078239	7452	Economy	10700.00
0005433717178	7452	Economy	10700.00
0005433717165	7452	Economy	10700.00
0005433689960	7452	Economy	10700.00
0005433722377	7452	Economy	10700.00
0005432078241	7452	Economy	10700.00
0005433717176	7452	Economy	10700.00
0005433716612	29216	Business	32000.00
0005433716933	29216	Business	32000.00
0005433716708	29216	Business	32000.00
0005433716451	29216	Business	32000.00
0005433716698	29216	Economy	10700.00
0005433716697	29216	Economy	10700.00
0005433716714	29216	Economy	10700.00
0005433716751	29216	Economy	10700.00
0005432429012	29216	Economy	10700.00
0005433716798	29216	Economy	10700.00
0005433716707	29216	Economy	10700.00
0005433716759	29216	Economy	10700.00
0005433716780	29216	Economy	10700.00
0005433716562	29216	Economy	10700.00
0005433719195	29216	Economy	10700.00
0005433722306	29216	Economy	10700.00
0005433716728	29216	Economy	10700.00
0005433716795	29216	Economy	10700.00
0005433716661	29216	Economy	10700.00
0005433716613	29216	Economy	10700.00
0005433716828	29216	Economy	10700.00
0005433716736	29216	Economy	10700.00
0005433716793	29216	Economy	10700.00
0005433716763	29216	Economy	10700.00
0005433719194	29216	Economy	10700.00
0005433722296	29216	Economy	10700.00
0005433716719	29216	Economy	10700.00
0005432006833	29216	Economy	10700.00
0005433716752	29216	Economy	10700.00
0005433719186	29216	Economy	11700.00
0005432429013	29216	Economy	11700.00
0005433716892	29216	Economy	11700.00
0005433716926	29216	Economy	11700.00
0005433716723	29216	Economy	11700.00
0005433716505	29216	Economy	10700.00
0005433716726	29216	Economy	10700.00
0005433716570	29216	Economy	10700.00
0005433716894	29216	Economy	10700.00
0005433722309	29216	Economy	10700.00
0005433716452	29216	Economy	10700.00
0005433716465	29216	Economy	10700.00
0005433716693	29216	Economy	10700.00
0005433716889	29216	Economy	10700.00
0005433716891	29216	Economy	10700.00
0005432429015	29216	Economy	10700.00
0005432006835	29216	Economy	10700.00
0005433716790	29216	Economy	10700.00
0005433716660	29216	Economy	10700.00
0005433685539	29216	Economy	10700.00
0005433716760	29216	Economy	10700.00
0005433656728	29216	Economy	10700.00
0005433716829	29216	Economy	10700.00
0005433716938	29216	Economy	10700.00
0005433656704	29216	Economy	10700.00
0005433716614	29216	Economy	10700.00
0005433716932	29216	Economy	10700.00
0005433716835	29216	Economy	10700.00
0005433716834	29216	Economy	10700.00
0005433716789	29216	Economy	10700.00
0005433719183	29216	Economy	10700.00
0005432006834	29216	Economy	10700.00
0005433716713	29216	Economy	10700.00
0005433716833	29216	Economy	10700.00
0005433719182	29216	Economy	10700.00
0005433716710	29216	Economy	10700.00
0005433656705	29216	Economy	10700.00
0005433722297	29216	Economy	10700.00
0005433716716	29216	Economy	10700.00
0005433716712	29216	Economy	10700.00
0005433716788	29216	Economy	10700.00
0005432429014	29216	Economy	10700.00
0005433716893	29216	Economy	10700.00
0005433716504	29216	Economy	10700.00
0005433716499	29216	Economy	10700.00
0005433716727	29216	Economy	10700.00
0005432429016	29216	Economy	10700.00
0005433716563	29216	Economy	10700.00
0005434095630	8657	Business	36500.00
0005434095629	8657	Business	36500.00
0005434326088	8657	Business	36500.00
0005434182417	8657	Business	36500.00
0005434184689	8657	Economy	12200.00
0005434184690	8657	Economy	12200.00
0005434095634	8657	Economy	13400.00
0005434182411	8657	Economy	13400.00
0005434095633	8657	Economy	12200.00
0005434182373	8657	Economy	12200.00
0005434326056	8657	Economy	12200.00
0005434095627	8657	Economy	12200.00
0005434095628	8657	Economy	12200.00
0005434095623	8657	Economy	12200.00
0005434095622	8657	Economy	12200.00
0005434326055	8657	Economy	12200.00
0005434182407	8657	Economy	12200.00
0005434184701	8657	Economy	12200.00
0005434182381	8657	Economy	12200.00
0005434184702	8657	Economy	12200.00
0005434182414	8657	Economy	12200.00
0005434095631	8657	Economy	12200.00
0005434182369	8657	Economy	12200.00
0005434326087	8657	Economy	12200.00
0005434095635	8657	Economy	12200.00
0005434182408	8657	Economy	12200.00
0005434182412	8657	Economy	12200.00
0005434095625	8657	Economy	12200.00
0005434182370	8657	Economy	12200.00
0005434095624	8657	Economy	12200.00
0005434182413	8657	Economy	12200.00
0005434095626	8657	Economy	12200.00
0005434095632	8657	Economy	12200.00
0005434184713	11651	Business	36500.00
0005434182483	11651	Business	36500.00
0005434095491	11651	Business	36500.00
0005434095526	11651	Business	36500.00
0005435860662	11651	Economy	12200.00
0005434095550	11651	Economy	13400.00
0005434095482	11651	Economy	13400.00
0005434184714	11651	Economy	13400.00
0005434182491	11651	Economy	13400.00
0005435860665	11651	Economy	12200.00
0005434095561	11651	Economy	12200.00
0005434095475	11651	Economy	12200.00
0005434095574	11651	Economy	12200.00
0005434182487	11651	Economy	12200.00
0005434182490	11651	Economy	12200.00
0005434184715	11651	Economy	12200.00
0005435860666	11651	Economy	12200.00
0005434095481	11651	Economy	12200.00
0005434182486	11651	Economy	12200.00
0005434095560	11651	Economy	12200.00
0005434143744	11651	Economy	12200.00
0005434095551	11651	Economy	12200.00
0005435860660	11651	Economy	12200.00
0005434182494	11651	Economy	12200.00
0005434095474	11651	Economy	12200.00
0005434095436	11651	Economy	12200.00
0005434182492	11651	Economy	12200.00
0005434095532	11651	Economy	12200.00
0005434095405	11651	Economy	12200.00
0005435860661	11651	Economy	12200.00
0005434182488	11651	Economy	12200.00
0005434182484	11651	Economy	12200.00
0005435860659	11651	Economy	12200.00
0005434182489	11651	Economy	12200.00
0005434183628	11651	Economy	12200.00
0005434182493	11651	Economy	12200.00
0005435860664	11651	Economy	12200.00
0005435860663	11651	Economy	12200.00
0005434095437	11651	Economy	12200.00
0005434182495	11651	Economy	12200.00
0005434182485	11651	Economy	12200.00
0005433398592	1468	Business	33000.00
0005435725747	1468	Business	33000.00
0005433398674	1468	Business	33000.00
0005433398757	1468	Business	33000.00
0005433398856	1468	Business	33000.00
0005433398735	1468	Business	33000.00
0005433398576	1468	Business	33000.00
0005433398862	1468	Business	33000.00
0005433398774	1468	Economy	11000.00
0005433398741	1468	Economy	11000.00
0005433398743	1468	Economy	11000.00
0005433399046	1468	Economy	11000.00
0005433398740	1468	Economy	11000.00
0005433398781	1468	Economy	11000.00
0005433457068	1468	Economy	11000.00
0005433398848	1468	Economy	11000.00
0005433398716	1468	Economy	12100.00
0005433398961	1468	Economy	12100.00
0005433398830	1468	Economy	12100.00
0005433398935	1468	Economy	12100.00
0005433398936	1468	Economy	12100.00
0005433398717	1468	Economy	11000.00
0005433398849	1468	Economy	11000.00
0005433398820	1468	Economy	11000.00
0005433398870	1468	Economy	11000.00
0005433398780	1468	Economy	11000.00
0005433398791	1468	Economy	11000.00
0005433398847	1468	Economy	11000.00
0005433398884	1468	Economy	11000.00
0005433399055	1468	Economy	11000.00
0005433398733	1468	Economy	11000.00
0005433398910	1468	Economy	11000.00
0005433399054	1468	Economy	11000.00
0005433398597	1468	Economy	11000.00
0005432297341	1468	Economy	11000.00
0005433398772	1468	Economy	11000.00
0005433398721	1468	Economy	11000.00
0005433457070	1468	Economy	11000.00
0005433398872	1468	Economy	11000.00
0005432906575	1468	Economy	11000.00
0005433457067	1468	Economy	11000.00
0005433398883	1468	Economy	11000.00
0005433398962	1468	Economy	11000.00
0005433398955	1468	Economy	11000.00
0005433398742	1468	Economy	11000.00
0005433457069	1468	Economy	11000.00
0005433398897	1468	Economy	11000.00
0005433399017	1468	Economy	11000.00
0005435725748	1468	Economy	11000.00
0005433399045	1468	Economy	11000.00
0005433398661	1468	Economy	11000.00
0005433398871	1468	Economy	11000.00
0005432297342	1468	Economy	11000.00
0005433398773	1468	Economy	11000.00
0005433398965	1468	Economy	11000.00
0005433398948	1468	Economy	11000.00
0005433398758	1468	Economy	11000.00
0005433398744	1468	Economy	11000.00
0005433398934	1468	Economy	11000.00
0005433399022	1468	Economy	11000.00
0005432906574	1468	Economy	11000.00
0005433398660	1468	Economy	11000.00
0005433398795	1468	Economy	11000.00
0005433398937	1468	Economy	11000.00
0005433398966	1468	Economy	11000.00
0005433398833	1468	Economy	11000.00
0005433398816	1468	Economy	11000.00
0005432297343	1468	Economy	11000.00
0005433399018	1468	Economy	11000.00
0005433398929	1468	Economy	11000.00
0005433398809	1468	Economy	11000.00
0005433399053	1468	Economy	11000.00
0005433398730	1468	Economy	11000.00
0005433398756	1468	Economy	11000.00
0005433399231	19243	Business	33000.00
0005435732562	19243	Business	33000.00
0005433399263	19243	Business	33000.00
0005435732535	19243	Business	33000.00
0005433399235	19243	Business	33000.00
0005433399258	19243	Business	33000.00
0005433399229	19243	Business	33000.00
0005433399216	19243	Business	33000.00
0005433457043	19243	Business	33000.00
0005435732516	19243	Business	33000.00
0005433399256	19243	Economy	11000.00
0005433457030	19243	Economy	11000.00
0005433399264	19243	Economy	11000.00
0005435732545	19243	Economy	11000.00
0005435732530	19243	Economy	11000.00
0005435732583	19243	Economy	11000.00
0005433399251	19243	Economy	11000.00
0005433399253	19243	Economy	11000.00
0005433457037	19243	Economy	11000.00
0005435732542	19243	Economy	12100.00
0005432906596	19243	Economy	12100.00
0005433399228	19243	Economy	12100.00
0005433399243	19243	Economy	11000.00
0005433399261	19243	Economy	11000.00
0005433457026	19243	Economy	11000.00
0005433399223	19243	Economy	11000.00
0005435732534	19243	Economy	11000.00
0005433399219	19243	Economy	11000.00
0005435732563	19243	Economy	11000.00
0005433399247	19243	Economy	11000.00
0005432906595	19243	Economy	11000.00
0005433399233	19243	Economy	11000.00
0005435732517	19243	Economy	11000.00
0005433399237	19243	Economy	11000.00
0005433399242	19243	Economy	11000.00
0005433457036	19243	Economy	11000.00
0005435732518	19243	Economy	11000.00
0005433399259	19243	Economy	11000.00
0005433457032	19243	Economy	11000.00
0005433399225	19243	Economy	11000.00
0005433399222	19243	Economy	11000.00
0005433399236	19243	Economy	11000.00
0005433399262	19243	Economy	11000.00
0005433399230	19243	Economy	11000.00
0005433399245	19243	Economy	11000.00
0005435732531	19243	Economy	11000.00
0005433399244	19243	Economy	11000.00
0005433399257	19243	Economy	11000.00
0005433399220	19243	Economy	11000.00
0005433399255	19243	Economy	11000.00
0005433399226	19243	Economy	11000.00
0005433399224	19243	Economy	11000.00
0005433399249	19243	Economy	11000.00
0005433399240	19243	Economy	11000.00
0005435732533	19243	Economy	11000.00
0005433399252	19243	Economy	11000.00
0005433399239	19243	Economy	11000.00
0005433399232	19243	Economy	11000.00
0005433399221	19243	Economy	11000.00
0005433399238	19243	Economy	11000.00
0005432906597	19243	Economy	11000.00
0005433399227	19243	Economy	11000.00
0005433457044	19243	Economy	11000.00
0005433457042	19243	Economy	11000.00
0005433457031	19243	Economy	11000.00
0005433399241	19243	Economy	11000.00
0005433399254	19243	Economy	11000.00
0005433399248	19243	Economy	11000.00
0005433399217	19243	Economy	11000.00
0005433457025	19243	Economy	11000.00
0005433399246	19243	Economy	11000.00
0005433399234	19243	Economy	11000.00
0005433399218	19243	Economy	11000.00
0005435732564	19243	Economy	11000.00
0005433399260	19243	Economy	11000.00
0005433399250	19243	Economy	11000.00
0005434443956	17366	Economy	15600.00
0005434443937	17366	Economy	15600.00
0005434443963	17366	Economy	14100.00
0005434443913	17366	Economy	14100.00
0005434443955	17366	Economy	14100.00
0005434443934	17366	Economy	14100.00
0005434443965	17366	Economy	14100.00
0005434443945	17366	Economy	14100.00
0005434443954	17366	Economy	14100.00
0005434443922	17366	Economy	14100.00
0005434443936	17366	Economy	14100.00
0005434443990	17366	Economy	14100.00
0005434443912	17366	Economy	14100.00
0005434444095	20556	Economy	14100.00
0005434444091	20556	Economy	14100.00
0005434444094	20556	Economy	14100.00
0005434444086	20556	Economy	14100.00
0005434444098	20556	Economy	14100.00
0005434444097	20556	Economy	14100.00
0005434444093	20556	Economy	14100.00
0005434444101	20556	Economy	14100.00
0005434444100	20556	Economy	14100.00
0005434444089	20556	Economy	14100.00
0005434444087	20556	Economy	14100.00
0005434444090	20556	Economy	14100.00
0005434444092	20556	Economy	14100.00
0005434444085	20556	Economy	14100.00
0005434444099	20556	Economy	14100.00
0005434444096	20556	Economy	14100.00
0005434444088	20556	Economy	14100.00
0005434954705	7270	Economy	5800.00
0005434954704	7270	Economy	5800.00
0005434954707	7270	Economy	5800.00
0005434954706	7270	Economy	5800.00
0005435377619	7270	Economy	5800.00
0005434954703	7270	Economy	5800.00
0005434954667	28307	Economy	5800.00
0005435377638	28307	Economy	5800.00
0005434954663	28307	Economy	5800.00
0005434954666	28307	Economy	5800.00
0005434954659	28307	Economy	5800.00
0005434954658	28307	Economy	5800.00
0005435377637	28307	Economy	5800.00
0005434954654	28307	Economy	5800.00
0005435893739	4505	Economy	15400.00
0005435893700	4505	Economy	15400.00
0005435893725	4505	Economy	14000.00
0005434352012	4505	Economy	14000.00
0005434352011	4505	Economy	14000.00
0005435893753	4505	Economy	14000.00
0005435893723	4505	Economy	14000.00
0005434352009	4505	Economy	14000.00
0005434352006	4505	Economy	14000.00
0005435893742	4505	Economy	14000.00
0005435893752	4505	Economy	14000.00
0005434352003	4505	Economy	14000.00
0005434352004	4505	Economy	14000.00
0005434326288	4505	Economy	14000.00
0005435893724	4505	Economy	14000.00
0005434352013	4505	Economy	14000.00
0005434326095	4505	Economy	14000.00
0005434352010	4505	Economy	14000.00
0005435893749	4505	Economy	14000.00
0005435893740	4505	Economy	14000.00
0005435893755	4505	Economy	14000.00
0005434352008	4505	Economy	14000.00
0005434352005	4505	Economy	14000.00
0005435893750	4505	Economy	14000.00
0005434352007	4505	Economy	14000.00
0005435893743	4505	Economy	14000.00
0005434352001	4505	Economy	14000.00
0005434183607	4505	Economy	14000.00
0005434183606	4505	Economy	14000.00
0005434352002	4505	Economy	14000.00
0005434351891	29679	Economy	15400.00
0005435893802	29679	Economy	14000.00
0005435893808	29679	Economy	14000.00
0005435893803	29679	Economy	14000.00
0005434351887	29679	Economy	14000.00
0005435893809	29679	Economy	14000.00
0005434351958	29679	Economy	14000.00
0005434351938	29679	Economy	14000.00
0005435893806	29679	Economy	14000.00
0005434351901	29679	Economy	14000.00
0005435893804	29679	Economy	14000.00
0005434351903	29679	Economy	14000.00
0005434351862	29679	Economy	14000.00
0005435893807	29679	Economy	14000.00
0005434351922	29679	Economy	14000.00
0005434351921	29679	Economy	14000.00
0005434351959	29679	Economy	14000.00
0005434351902	29679	Economy	14000.00
0005434351810	29679	Economy	14000.00
0005434351892	29679	Economy	14000.00
0005434351924	29679	Economy	14000.00
0005435893805	29679	Economy	14000.00
0005433344235	1054	Business	30600.00
0005433344432	1054	Business	30600.00
0005433344430	1054	Business	30600.00
0005433344880	1054	Business	30600.00
0005434445306	1054	Business	30600.00
0005435092317	1054	Business	30600.00
0005433344590	1054	Business	30600.00
0005433462800	1054	Business	30600.00
0005433344651	1054	Business	30600.00
0005433159350	1054	Business	30600.00
0005433344952	1054	Business	30600.00
0005433344921	1054	Business	30600.00
0005433463953	1054	Business	30600.00
0005433269778	1054	Business	30600.00
0005433344546	1054	Business	30600.00
0005433344027	1054	Business	30600.00
0005433344061	1054	Business	30600.00
0005433462799	1054	Business	30600.00
0005433344062	1054	Economy	11200.00
0005433344648	1054	Economy	10200.00
0005433344776	1054	Economy	10200.00
0005433344288	1054	Economy	10200.00
0005433344534	1054	Economy	10200.00
0005435092314	1054	Economy	10200.00
0005435092319	1054	Economy	10200.00
0005433158157	1054	Economy	10200.00
0005433344287	1054	Economy	10200.00
0005433344498	1054	Economy	10200.00
0005433344487	1054	Economy	10200.00
0005433463955	1054	Economy	10200.00
0005433344956	1054	Economy	10200.00
0005433344878	1054	Economy	10200.00
0005433344906	1054	Economy	10200.00
0005433344579	1054	Economy	10200.00
0005433344411	1054	Economy	10200.00
0005433344589	1054	Economy	10200.00
0005433344440	1054	Economy	10200.00
0005433344578	1054	Economy	10200.00
0005433344497	1054	Economy	10200.00
0005433344441	1054	Economy	10200.00
0005435092313	1054	Economy	10200.00
0005433344515	1054	Economy	10200.00
0005433344320	1054	Economy	10200.00
0005433344528	1054	Economy	10200.00
0005433344516	1054	Economy	10200.00
0005433344922	1054	Economy	10200.00
0005433344526	1054	Economy	10200.00
0005433344489	1054	Economy	10200.00
0005435092320	1054	Economy	10200.00
0005433344437	1054	Economy	10200.00
0005433344502	1054	Economy	10200.00
0005432293268	1054	Economy	10200.00
0005433344293	1054	Economy	10200.00
0005433463954	1054	Economy	10200.00
0005433344688	1054	Economy	10200.00
0005433344433	1054	Economy	10200.00
0005433269801	1054	Economy	10200.00
0005433344488	1054	Economy	10200.00
0005433345152	1054	Economy	10200.00
0005433344382	1054	Economy	10200.00
0005433344454	1054	Economy	10200.00
0005434445304	1054	Economy	10200.00
0005433344825	1054	Economy	10200.00
0005433344286	1054	Economy	10200.00
0005433344809	1054	Economy	10200.00
0005433344285	1054	Economy	10200.00
0005433344444	1054	Economy	10200.00
0005434446575	1054	Economy	10200.00
0005433344599	1054	Economy	10200.00
0005433344438	1054	Economy	10200.00
0005433344640	1054	Economy	10200.00
0005433344566	1054	Economy	10200.00
0005433344760	1054	Economy	10200.00
0005433158170	1054	Economy	10200.00
0005435092315	1054	Economy	10200.00
0005433344782	1054	Economy	10200.00
0005433344674	1054	Economy	10200.00
0005433344829	1054	Economy	10200.00
0005433344879	1054	Economy	10200.00
0005433344844	1054	Economy	10200.00
0005433344710	1054	Economy	10200.00
0005433344338	1054	Economy	10200.00
0005433269800	1054	Economy	10200.00
0005433345049	1054	Economy	10200.00
0005433344453	1054	Economy	10200.00
0005433344920	1054	Economy	10200.00
0005433344984	1054	Economy	10200.00
0005433344671	1054	Economy	10200.00
0005433344292	1054	Economy	11200.00
0005433344591	1054	Economy	10200.00
0005435092316	1054	Economy	10200.00
0005433344581	1054	Economy	11200.00
0005433345052	1054	Economy	10200.00
0005433344772	1054	Economy	11200.00
0005433344600	1054	Economy	10200.00
0005434445305	1054	Economy	10200.00
0005433344533	1054	Economy	10200.00
0005433344816	1054	Economy	10200.00
0005434445303	1054	Economy	10200.00
0005433344580	1054	Economy	10200.00
0005433344315	1054	Economy	10200.00
0005433344412	1054	Economy	10200.00
0005433345050	1054	Economy	10200.00
0005433344830	1054	Economy	10200.00
0005432293267	1054	Economy	10200.00
0005433344508	1054	Economy	10200.00
0005433344907	1054	Economy	10200.00
0005433344761	1054	Economy	10200.00
0005433344612	1054	Economy	10200.00
0005433344667	1054	Economy	10200.00
0005434446576	1054	Economy	10200.00
0005433344431	1054	Economy	10200.00
0005433158164	1054	Economy	10200.00
0005433344649	1054	Economy	10200.00
0005433344146	1054	Economy	10200.00
0005433344254	1054	Economy	10200.00
0005433344693	1054	Economy	10200.00
0005433344831	1054	Economy	10200.00
0005433158165	1054	Economy	10200.00
0005433344687	1054	Economy	10200.00
0005433344056	1054	Economy	10200.00
0005433344166	1054	Economy	10200.00
0005433344532	1054	Economy	10200.00
0005433344319	1054	Economy	10200.00
0005433344743	1054	Economy	10200.00
0005433344399	1054	Economy	10200.00
0005433344775	1054	Economy	10200.00
0005433344535	1054	Economy	10200.00
0005433344054	1054	Economy	10200.00
0005433344055	1054	Economy	10200.00
0005433344724	1054	Economy	10200.00
0005432293266	1054	Economy	10200.00
0005435092321	1054	Economy	10200.00
0005433344637	1054	Economy	10200.00
0005435092318	1054	Economy	10200.00
0005433344413	1054	Economy	10200.00
0005433344641	1054	Economy	10200.00
0005433344527	1054	Economy	10200.00
0005433344234	1054	Economy	10200.00
0005433344443	1054	Economy	10200.00
0005433344236	1054	Economy	10200.00
0005433344026	1054	Economy	10200.00
0005433344660	1054	Economy	10200.00
0005433344588	1054	Economy	10200.00
0005433344783	1054	Economy	10200.00
0005433344620	1054	Economy	10200.00
0005433344904	1054	Economy	10200.00
0005433344634	1054	Economy	10200.00
0005433345464	17052	Business	30600.00
0005433345508	17052	Business	30600.00
0005434445275	17052	Business	30600.00
0005433345501	17052	Business	30600.00
0005433269851	17052	Business	30600.00
0005433345519	17052	Business	30600.00
0005435092236	17052	Business	30600.00
0005433345487	17052	Business	30600.00
0005433345466	17052	Business	30600.00
0005433345469	17052	Business	30600.00
0005433345470	17052	Business	30600.00
0005435092234	17052	Business	30600.00
0005433345520	17052	Business	30600.00
0005433345486	17052	Business	30600.00
0005435508524	17052	Business	30600.00
0005435092226	17052	Business	30600.00
0005433345542	17052	Business	30600.00
0005433345532	17052	Business	30600.00
0005435092238	17052	Business	30600.00
0005433269852	17052	Economy	11200.00
0005433345503	17052	Economy	11200.00
0005435508568	17052	Economy	11200.00
0005433345517	17052	Economy	10200.00
0005433345483	17052	Economy	10200.00
0005435092246	17052	Economy	10200.00
0005433345460	17052	Economy	10200.00
0005433345550	17052	Economy	10200.00
0005433345539	17052	Economy	10200.00
0005433345468	17052	Economy	10200.00
0005433345480	17052	Economy	10200.00
0005433345485	17052	Economy	10200.00
0005433345528	17052	Economy	10200.00
0005433158198	17052	Economy	10200.00
0005433345479	17052	Economy	10200.00
0005433345490	17052	Economy	10200.00
0005433345474	17052	Economy	10200.00
0005433345547	17052	Economy	10200.00
0005435092231	17052	Economy	10200.00
0005433345522	17052	Economy	10200.00
0005433345499	17052	Economy	10200.00
0005433345510	17052	Economy	10200.00
0005435092244	17052	Economy	10200.00
0005433345540	17052	Economy	10200.00
0005435508571	17052	Economy	10200.00
0005433345516	17052	Economy	10200.00
0005433345496	17052	Economy	10200.00
0005433345531	17052	Economy	10200.00
0005433345488	17052	Economy	10200.00
0005433345514	17052	Economy	10200.00
0005433345462	17052	Economy	10200.00
0005434445282	17052	Economy	10200.00
0005435508570	17052	Economy	10200.00
0005433345498	17052	Economy	10200.00
0005433345489	17052	Economy	10200.00
0005433345545	17052	Economy	10200.00
0005433345481	17052	Economy	10200.00
0005433345478	17052	Economy	10200.00
0005433345535	17052	Economy	10200.00
0005433345463	17052	Economy	10200.00
0005433345538	17052	Economy	10200.00
0005435508573	17052	Economy	10200.00
0005433345537	17052	Economy	10200.00
0005433345471	17052	Economy	10200.00
0005433345506	17052	Economy	10200.00
0005433345524	17052	Economy	10200.00
0005433345467	17052	Economy	10200.00
0005434445269	17052	Economy	10200.00
0005433345509	17052	Economy	10200.00
0005433345461	17052	Economy	10200.00
0005433345543	17052	Economy	10200.00
0005433345493	17052	Economy	10200.00
0005433345533	17052	Economy	10200.00
0005433345523	17052	Economy	10200.00
0005435508472	17052	Economy	10200.00
0005433345465	17052	Economy	10200.00
0005433345549	17052	Economy	10200.00
0005433345521	17052	Economy	10200.00
0005433345502	17052	Economy	10200.00
0005435508569	17052	Economy	10200.00
0005435508532	17052	Economy	10200.00
0005433345492	17052	Economy	10200.00
0005433345500	17052	Economy	10200.00
0005433345458	17052	Economy	10200.00
0005433345472	17052	Economy	10200.00
0005435508552	17052	Economy	10200.00
0005433345512	17052	Economy	10200.00
0005435092237	17052	Economy	10200.00
0005433269850	17052	Economy	11200.00
0005433345495	17052	Economy	11200.00
0005433345505	17052	Economy	10200.00
0005433345525	17052	Economy	10200.00
0005433345477	17052	Economy	11200.00
0005433345527	17052	Economy	10200.00
0005433345511	17052	Economy	10200.00
0005435092248	17052	Economy	10200.00
0005435092235	17052	Economy	10200.00
0005433345455	17052	Economy	10200.00
0005434445283	17052	Economy	10200.00
0005435508512	17052	Economy	10200.00
0005433345452	17052	Economy	10200.00
0005433345546	17052	Economy	10200.00
0005433345513	17052	Economy	10200.00
0005435508534	17052	Economy	10200.00
0005435508537	17052	Economy	10200.00
0005433345491	17052	Economy	10200.00
0005433345473	17052	Economy	10200.00
0005433345515	17052	Economy	10200.00
0005433345530	17052	Economy	10200.00
0005435508525	17052	Economy	10200.00
0005433345475	17052	Economy	10200.00
0005433345536	17052	Economy	10200.00
0005433269853	17052	Economy	10200.00
0005433345548	17052	Economy	10200.00
0005435508572	17052	Economy	10200.00
0005433159367	17052	Economy	10200.00
0005433345494	17052	Economy	10200.00
0005433345497	17052	Economy	10200.00
0005435508533	17052	Economy	10200.00
0005433345476	17052	Economy	10200.00
0005433345526	17052	Economy	10200.00
0005433269849	17052	Economy	10200.00
0005435508574	17052	Economy	10200.00
0005433345534	17052	Economy	10200.00
0005434445277	17052	Economy	10200.00
0005433345544	17052	Economy	10200.00
0005433345529	17052	Economy	10200.00
0005433345507	17052	Economy	10200.00
0005433345484	17052	Economy	10200.00
0005433345457	17052	Economy	10200.00
0005433345482	17052	Economy	10200.00
0005435092247	17052	Economy	10200.00
0005433345541	17052	Economy	10200.00
0005433345504	17052	Economy	10200.00
0005433345454	17052	Economy	10200.00
0005435092245	17052	Economy	10200.00
0005433345456	17052	Economy	10200.00
0005433345518	17052	Economy	10200.00
0005433345453	17052	Economy	10200.00
0005435508605	17052	Economy	10200.00
0005433269848	17052	Economy	10200.00
0005433345459	17052	Economy	10200.00
0005432390431	1336	Business	101000.00
0005432390404	1336	Business	101000.00
0005432851975	1336	Business	101000.00
0005432390422	1336	Business	101000.00
0005432390426	1336	Business	101000.00
0005432390400	1336	Business	101000.00
0005432390421	1336	Business	101000.00
0005432390417	1336	Business	101000.00
0005432852031	1336	Business	101000.00
0005432852003	1336	Business	101000.00
0005432392072	1336	Business	101000.00
0005432851990	1336	Economy	33700.00
0005432392069	1336	Economy	33700.00
0005432390425	1336	Economy	33700.00
0005432851969	1336	Economy	33700.00
0005432390423	1336	Economy	33700.00
0005432390389	1336	Economy	33700.00
0005432852020	1336	Economy	33700.00
0005432390407	1336	Economy	33700.00
0005432390406	1336	Economy	33700.00
0005432390396	1336	Economy	33700.00
0005432392071	1336	Economy	37000.00
0005432390391	1336	Economy	37000.00
0005432390388	1336	Economy	37000.00
0005432392063	1336	Economy	33700.00
0005432390403	1336	Economy	37000.00
0005432390419	1336	Economy	33700.00
0005432390420	1336	Economy	33700.00
0005432390408	1336	Economy	33700.00
0005432390410	1336	Economy	33700.00
0005432390387	1336	Economy	33700.00
0005432390401	1336	Economy	33700.00
0005432852033	1336	Economy	33700.00
0005432852001	1336	Economy	33700.00
0005432392061	1336	Economy	33700.00
0005432392070	1336	Economy	33700.00
0005432390402	1336	Economy	33700.00
0005432851993	1336	Economy	33700.00
0005432390405	1336	Economy	33700.00
0005432392066	1336	Economy	33700.00
0005432390398	1336	Economy	33700.00
0005432392068	1336	Economy	33700.00
0005432852009	1336	Economy	33700.00
0005432390386	1336	Economy	33700.00
0005432390397	1336	Economy	33700.00
0005432392067	1336	Economy	33700.00
0005432390428	1336	Economy	33700.00
0005432390414	1336	Economy	33700.00
0005432390415	1336	Economy	33700.00
0005432390385	1336	Economy	33700.00
0005432852000	1336	Economy	33700.00
0005432390424	1336	Economy	33700.00
0005432390416	1336	Economy	33700.00
0005432390412	1336	Economy	33700.00
0005432392064	1336	Economy	33700.00
0005432390409	1336	Economy	33700.00
0005432390394	1336	Economy	33700.00
0005432390393	1336	Economy	33700.00
0005432390395	1336	Economy	33700.00
0005432392065	1336	Economy	33700.00
0005432390392	1336	Economy	33700.00
0005432851978	1336	Economy	33700.00
0005432852002	1336	Economy	33700.00
0005432851974	1336	Economy	33700.00
0005432392062	1336	Economy	33700.00
0005432390427	1336	Economy	33700.00
0005432390432	1336	Economy	33700.00
0005432390411	1336	Economy	33700.00
0005432390418	1336	Economy	33700.00
0005432390429	1336	Economy	33700.00
0005432390399	1336	Economy	33700.00
0005432390413	1336	Economy	33700.00
0005432390390	1336	Economy	33700.00
0005432390430	1336	Economy	33700.00
0005432392060	1336	Economy	33700.00
0005434082186	12816	Business	40300.00
0005434068086	12816	Business	40300.00
0005432433809	12816	Business	40300.00
0005433989855	12816	Business	40300.00
0005434068489	12816	Business	40300.00
0005433989841	12816	Business	40300.00
0005434026729	12816	Business	40300.00
0005434068402	12816	Business	40300.00
0005434068353	12816	Business	40300.00
0005434068689	12816	Business	40300.00
0005432159968	12816	Business	40300.00
0005434068831	12816	Business	40300.00
0005434068768	12816	Economy	13400.00
0005434068472	12816	Economy	13400.00
0005434082231	12816	Economy	13400.00
0005434068339	12816	Economy	13400.00
0005434068591	12816	Economy	13400.00
0005434068420	12816	Economy	13400.00
0005434068822	12816	Economy	13400.00
0005434068536	12816	Economy	13400.00
0005434068559	12816	Economy	13400.00
0005434068602	12816	Economy	13400.00
0005434068229	12816	Economy	13400.00
0005432159973	12816	Economy	13400.00
0005434068598	12816	Economy	13400.00
0005434068691	12816	Economy	13400.00
0005434068690	12816	Economy	13400.00
0005433989856	12816	Economy	13400.00
0005434082246	12816	Economy	13400.00
0005434068714	12816	Economy	13400.00
0005434068483	12816	Economy	13400.00
0005434068660	12816	Economy	13400.00
0005434068747	12816	Economy	13400.00
0005434082234	12816	Economy	13400.00
0005434068600	12816	Economy	13400.00
0005434068210	12816	Economy	13400.00
0005433989851	12816	Economy	13400.00
0005434068592	12816	Economy	13400.00
0005434068530	12816	Economy	13400.00
0005434068321	12816	Economy	13400.00
0005432433810	12816	Economy	13400.00
0005432161207	12816	Economy	13400.00
0005434068833	12816	Economy	13400.00
0005434068757	12816	Economy	13400.00
0005434068555	12816	Economy	13400.00
0005433812961	12816	Economy	13400.00
0005434068745	12816	Economy	13400.00
0005434068859	12816	Economy	13400.00
0005434082208	12816	Economy	13400.00
0005433989866	12816	Economy	13400.00
0005434068692	12816	Economy	13400.00
0005434068544	12816	Economy	13400.00
0005434068471	12816	Economy	14800.00
0005434068537	12816	Economy	14800.00
0005433989842	12816	Economy	14800.00
0005434082252	12816	Economy	14800.00
0005434068823	12816	Economy	14800.00
0005434068211	12816	Economy	13400.00
0005434068871	12816	Economy	14800.00
0005434068643	12816	Economy	13400.00
0005434068784	12816	Economy	13400.00
0005432433813	12816	Economy	13400.00
0005434068304	12816	Economy	13400.00
0005434082253	12816	Economy	13400.00
0005434068664	12816	Economy	13400.00
0005434068783	12816	Economy	13400.00
0005434068629	12816	Economy	13400.00
0005434068715	12816	Economy	13400.00
0005434082198	12816	Economy	13400.00
0005434068338	12816	Economy	13400.00
0005432159974	12816	Economy	13400.00
0005434068557	12816	Economy	13400.00
0005432161206	12816	Economy	13400.00
0005433812960	12816	Economy	13400.00
0005434068593	12816	Economy	13400.00
0005434068659	12816	Economy	13400.00
0005434068746	12816	Economy	13400.00
0005434068825	12816	Economy	13400.00
0005434068639	12816	Economy	13400.00
0005434068610	12816	Economy	13400.00
0005434068830	12816	Economy	13400.00
0005434068490	12816	Economy	13400.00
0005434068767	12816	Economy	13400.00
0005434068756	12816	Economy	13400.00
0005434082206	12816	Economy	13400.00
0005434068404	12816	Economy	13400.00
0005434082197	12816	Economy	13400.00
0005434068627	12816	Economy	13400.00
0005434068824	12816	Economy	13400.00
0005434068707	12816	Economy	13400.00
0005434068601	12816	Economy	13400.00
0005434068742	12816	Economy	13400.00
0005434068617	12816	Economy	13400.00
0005434068782	12816	Economy	13400.00
0005434082215	12816	Economy	13400.00
0005434068722	12816	Economy	13400.00
0005433989850	12816	Economy	13400.00
0005433812959	12816	Economy	13400.00
0005434068352	12816	Economy	13400.00
0005434068801	12816	Economy	13400.00
0005434068721	12816	Economy	13400.00
0005434068744	12816	Economy	13400.00
0005434082148	12816	Economy	13400.00
0005433989843	12816	Economy	13400.00
0005434082235	12816	Economy	13400.00
0005434082207	12816	Economy	13400.00
0005432159970	12816	Economy	13400.00
0005432159971	12816	Economy	13400.00
0005432433812	12816	Economy	13400.00
0005434068633	12816	Economy	13400.00
0005434068628	12816	Economy	13400.00
0005434068790	12816	Economy	13400.00
0005434082233	12816	Economy	13400.00
0005434068802	12816	Economy	13400.00
0005434068498	12816	Economy	13400.00
0005434082141	12816	Economy	13400.00
0005432433811	12816	Economy	13400.00
0005432161208	12816	Economy	13400.00
0005434068886	12816	Economy	13400.00
0005434068638	12816	Economy	13400.00
0005434068650	12816	Economy	13400.00
0005434068843	12816	Economy	13400.00
0005434068368	12816	Economy	13400.00
0005434068529	12816	Economy	13400.00
0005434068556	12816	Economy	13400.00
0005433989865	12816	Economy	13400.00
0005434068266	12816	Economy	13400.00
0005432159972	12816	Economy	13400.00
0005432159969	12816	Economy	13400.00
0005434068465	12816	Economy	13400.00
0005433989882	30644	Business	40300.00
0005434069247	30644	Business	40300.00
0005434069268	30644	Business	40300.00
0005434069246	30644	Business	40300.00
0005432433777	30644	Business	40300.00
0005434069258	30644	Business	40300.00
0005434069244	30644	Business	40300.00
0005434082453	30644	Business	40300.00
0005434082462	30644	Business	40300.00
0005434069217	30644	Business	40300.00
0005434082445	30644	Business	40300.00
0005434069250	30644	Business	40300.00
0005434069242	30644	Economy	13400.00
0005434082471	30644	Economy	13400.00
0005434082466	30644	Economy	13400.00
0005434069214	30644	Economy	13400.00
0005434069235	30644	Economy	13400.00
0005434069241	30644	Economy	13400.00
0005434082450	30644	Economy	13400.00
0005433989885	30644	Economy	13400.00
0005434082441	30644	Economy	13400.00
0005434069251	30644	Economy	13400.00
0005434069267	30644	Economy	13400.00
0005434069210	30644	Economy	13400.00
0005434069202	30644	Economy	13400.00
0005434082442	30644	Economy	13400.00
0005434069237	30644	Economy	13400.00
0005434069204	30644	Economy	13400.00
0005432150376	30644	Economy	13400.00
0005434069228	30644	Economy	13400.00
0005434069227	30644	Economy	13400.00
0005434069252	30644	Economy	13400.00
0005434069245	30644	Economy	13400.00
0005434082461	30644	Economy	13400.00
0005434082475	30644	Economy	13400.00
0005434069233	30644	Economy	13400.00
0005434069215	30644	Economy	13400.00
0005434069240	30644	Economy	13400.00
0005434069238	30644	Economy	13400.00
0005434069208	30644	Economy	13400.00
0005434069203	30644	Economy	13400.00
0005434069207	30644	Economy	13400.00
0005434082465	30644	Economy	13400.00
0005434082451	30644	Economy	13400.00
0005434082470	30644	Economy	13400.00
0005434082460	30644	Economy	13400.00
0005434082469	30644	Economy	13400.00
0005433989883	30644	Economy	13400.00
0005434069264	30644	Economy	13400.00
0005432186957	30644	Economy	13400.00
0005434082456	30644	Economy	13400.00
0005434069266	30644	Economy	13400.00
0005434069221	30644	Economy	14800.00
0005434069209	30644	Economy	14800.00
0005434069271	30644	Economy	14800.00
0005432433765	30644	Economy	14800.00
0005434082448	30644	Economy	14800.00
0005434069269	30644	Economy	14800.00
0005432150383	30644	Economy	13400.00
0005432150379	30644	Economy	13400.00
0005432186954	30644	Economy	13400.00
0005434069236	30644	Economy	13400.00
0005434069212	30644	Economy	13400.00
0005434082468	30644	Economy	13400.00
0005434069255	30644	Economy	13400.00
0005434082446	30644	Economy	13400.00
0005434069261	30644	Economy	13400.00
0005432186955	30644	Economy	13400.00
0005434069257	30644	Economy	13400.00
0005434069225	30644	Economy	13400.00
0005434082443	30644	Economy	13400.00
0005434069222	30644	Economy	13400.00
0005432150382	30644	Economy	13400.00
0005434069218	30644	Economy	13400.00
0005434069224	30644	Economy	13400.00
0005434082458	30644	Economy	13400.00
0005434069263	30644	Economy	13400.00
0005434082444	30644	Economy	13400.00
0005434069249	30644	Economy	13400.00
0005434069230	30644	Economy	13400.00
0005434082459	30644	Economy	13400.00
0005434082467	30644	Economy	13400.00
0005432433775	30644	Economy	13400.00
0005432186956	30644	Economy	13400.00
0005434069265	30644	Economy	13400.00
0005434069254	30644	Economy	13400.00
0005434069234	30644	Economy	13400.00
0005432150381	30644	Economy	13400.00
0005432150377	30644	Economy	13400.00
0005433989884	30644	Economy	13400.00
0005434069248	30644	Economy	13400.00
0005434069260	30644	Economy	13400.00
0005434069239	30644	Economy	13400.00
0005434082464	30644	Economy	13400.00
0005434082457	30644	Economy	13400.00
0005434069205	30644	Economy	13400.00
0005432150380	30644	Economy	13400.00
0005434069262	30644	Economy	13400.00
0005434069213	30644	Economy	13400.00
0005434069243	30644	Economy	13400.00
0005434069231	30644	Economy	13400.00
0005434082463	30644	Economy	13400.00
0005434069270	30644	Economy	13400.00
0005434082452	30644	Economy	13400.00
0005434069226	30644	Economy	13400.00
0005434082472	30644	Economy	13400.00
0005434069219	30644	Economy	13400.00
0005434069229	30644	Economy	13400.00
0005434069211	30644	Economy	13400.00
0005434082449	30644	Economy	13400.00
0005434082447	30644	Economy	13400.00
0005432433776	30644	Economy	13400.00
0005434069259	30644	Economy	13400.00
0005434069201	30644	Economy	13400.00
0005434069206	30644	Economy	13400.00
0005434069272	30644	Economy	13400.00
0005434082474	30644	Economy	13400.00
0005434069256	30644	Economy	13400.00
0005434082454	30644	Economy	13400.00
0005434082455	30644	Economy	13400.00
0005434069223	30644	Economy	13400.00
0005434069220	30644	Economy	13400.00
0005434069232	30644	Economy	13400.00
0005432150378	30644	Economy	13400.00
0005434082473	30644	Economy	13400.00
0005434069216	30644	Economy	13400.00
0005434069253	30644	Economy	13400.00
0005433686689	9040	Economy	19300.00
0005433686690	9040	Economy	17600.00
0005433687758	9040	Economy	19300.00
0005433686692	9040	Economy	17600.00
0005433686688	9040	Economy	17600.00
0005433687762	9040	Economy	17600.00
0005433685575	9040	Economy	17600.00
0005433685576	9040	Economy	17600.00
0005433685579	9040	Economy	17600.00
0005433685577	9040	Economy	17600.00
0005433686691	9040	Economy	17600.00
0005433687761	9040	Economy	17600.00
0005433685580	9040	Economy	17600.00
0005433685578	9040	Economy	17600.00
0005433687759	9040	Economy	17600.00
0005433687760	9040	Economy	17600.00
0005435767724	5508	Business	35300.00
0005435735248	5508	Business	35300.00
0005435767761	5508	Business	35300.00
0005435767738	5508	Business	35300.00
0005435767731	5508	Business	35300.00
0005434831208	5508	Business	35300.00
0005435767717	5508	Business	35300.00
0005435767713	5508	Business	35300.00
0005435725715	5508	Business	35300.00
0005434831220	5508	Business	35300.00
0005435767707	5508	Business	35300.00
0005435463000	5508	Business	35300.00
0005433529373	5508	Business	35300.00
0005435463031	5508	Business	35300.00
0005435767698	5508	Business	35300.00
0005435767715	5508	Business	35300.00
0005435767737	5508	Business	35300.00
0005435463154	5508	Business	35300.00
0005435767755	5508	Business	35300.00
0005435462960	5508	Business	35300.00
0005434265534	5508	Business	35300.00
0005435767712	5508	Business	35300.00
0005435767702	5508	Economy	12900.00
0005435735249	5508	Economy	12900.00
0005432535900	5508	Economy	12900.00
0005435767740	5508	Economy	12900.00
0005435767720	5508	Economy	11800.00
0005434265443	5508	Economy	11800.00
0005435767710	5508	Economy	11800.00
0005435463083	5508	Economy	11800.00
0005435463009	5508	Economy	11800.00
0005435463052	5508	Economy	11800.00
0005435462923	5508	Economy	11800.00
0005435462940	5508	Economy	11800.00
0005434265547	5508	Economy	11800.00
0005434265535	5508	Economy	11800.00
0005435723092	5508	Economy	11800.00
0005435767769	5508	Economy	11800.00
0005433529371	5508	Economy	11800.00
0005434265559	5508	Economy	11800.00
0005435767758	5508	Economy	11800.00
0005435767727	5508	Economy	11800.00
0005434831215	5508	Economy	11800.00
0005435767735	5508	Economy	11800.00
0005433529374	5508	Economy	11800.00
0005435767706	5508	Economy	11800.00
0005435725714	5508	Economy	11800.00
0005434265485	5508	Economy	11800.00
0005435722113	5508	Economy	11800.00
0005434265581	5508	Economy	11800.00
0005435767699	5508	Economy	11800.00
0005435767746	5508	Economy	11800.00
0005434265548	5508	Economy	11800.00
0005435767748	5508	Economy	11800.00
0005435462958	5508	Economy	11800.00
0005435463018	5508	Economy	11800.00
0005435767745	5508	Economy	11800.00
0005434265582	5508	Economy	11800.00
0005435462959	5508	Economy	11800.00
0005435767753	5508	Economy	11800.00
0005435723091	5508	Economy	11800.00
0005435767757	5508	Economy	11800.00
0005434265511	5508	Economy	11800.00
0005435767760	5508	Economy	11800.00
0005432535909	5508	Economy	11800.00
0005435462946	5508	Economy	11800.00
0005435767730	5508	Economy	11800.00
0005435767759	5508	Economy	11800.00
0005435463029	5508	Economy	11800.00
0005435463071	5508	Economy	11800.00
0005435767729	5508	Economy	11800.00
0005435767765	5508	Economy	11800.00
0005435767754	5508	Economy	11800.00
0005435735252	5508	Economy	11800.00
0005435463070	5508	Economy	11800.00
0005435767723	5508	Economy	11800.00
0005432535905	5508	Economy	11800.00
0005435725717	5508	Economy	11800.00
0005435462937	5508	Economy	11800.00
0005435767766	5508	Economy	11800.00
0005435767709	5508	Economy	11800.00
0005435462922	5508	Economy	11800.00
0005434265639	5508	Economy	11800.00
0005434265592	5508	Economy	11800.00
0005435725718	5508	Economy	11800.00
0005435767722	5508	Economy	11800.00
0005435463027	5508	Economy	11800.00
0005435767734	5508	Economy	11800.00
0005435767725	5508	Economy	11800.00
0005435462957	5508	Economy	11800.00
0005435767714	5508	Economy	11800.00
0005435767726	5508	Economy	11800.00
0005435767704	5508	Economy	11800.00
0005435462942	5508	Economy	11800.00
0005432535897	5508	Economy	11800.00
0005434265464	5508	Economy	11800.00
0005435767711	5508	Economy	11800.00
0005434265444	5508	Economy	11800.00
0005435767721	5508	Economy	11800.00
0005432140650	5508	Economy	11800.00
0005432535910	5508	Economy	11800.00
0005434265583	5508	Economy	11800.00
0005432140649	5508	Economy	11800.00
0005434265486	5508	Economy	11800.00
0005432535890	5508	Economy	11800.00
0005434265623	5508	Economy	11800.00
0005435463016	5508	Economy	11800.00
0005435767716	5508	Economy	12900.00
0005432535914	5508	Economy	12900.00
0005432140648	5508	Economy	11800.00
0005435462936	5508	Economy	11800.00
0005434265489	5508	Economy	11800.00
0005435767736	5508	Economy	12900.00
0005435720854	5508	Economy	11800.00
0005435463017	5508	Economy	11800.00
0005435767763	5508	Economy	11800.00
0005434265512	5508	Economy	11800.00
0005435463042	5508	Economy	11800.00
0005434265427	5508	Economy	11800.00
0005433527361	5508	Economy	11800.00
0005433529370	5508	Economy	11800.00
0005434265426	5508	Economy	11800.00
0005435767718	5508	Economy	11800.00
0005433529372	5508	Economy	11800.00
0005435720855	5508	Economy	11800.00
0005435720853	5508	Economy	11800.00
0005435735250	5508	Economy	11800.00
0005434265545	5508	Economy	11800.00
0005435462974	5508	Economy	11800.00
0005435463026	5508	Economy	11800.00
0005435767747	5508	Economy	11800.00
0005435767700	5508	Economy	11800.00
0005432535904	5508	Economy	11800.00
0005434265546	5508	Economy	11800.00
0005435735251	5508	Economy	11800.00
0005435767750	5508	Economy	11800.00
0005435767705	5508	Economy	11800.00
0005435463082	5508	Economy	11800.00
0005435767741	5508	Economy	11800.00
0005435767743	5508	Economy	11800.00
0005432140647	5508	Economy	11800.00
0005435462981	5508	Economy	11800.00
0005434265376	5508	Economy	11800.00
0005434265507	5508	Economy	11800.00
0005435462947	5508	Economy	11800.00
0005435767764	5508	Economy	11800.00
0005435767732	5508	Economy	11800.00
0005435725716	5508	Economy	11800.00
0005435767744	5508	Economy	11800.00
0005432140651	5508	Economy	11800.00
0005435462984	5508	Economy	11800.00
0005434831209	5508	Economy	11800.00
0005435462964	5508	Economy	11800.00
0005433527362	5508	Economy	11800.00
0005435463040	5508	Economy	11800.00
0005435767768	5508	Economy	11800.00
0005435767697	5508	Economy	11800.00
0005435767703	5508	Economy	11800.00
0005432140646	5508	Economy	11800.00
0005435767756	5508	Economy	11800.00
0005434831219	5508	Economy	11800.00
0005435767767	5508	Economy	11800.00
0005435767749	5508	Economy	11800.00
0005434265516	5508	Economy	11800.00
0005435463030	5508	Economy	11800.00
0005435767752	5508	Economy	11800.00
0005435767739	5508	Economy	11800.00
0005435767762	5508	Economy	11800.00
0005435767708	5508	Economy	11800.00
0005435767751	5508	Economy	11800.00
0005435767701	5508	Economy	11800.00
0005434265465	5508	Economy	11800.00
0005432140652	5508	Economy	11800.00
0005435722112	5508	Economy	11800.00
0005435720856	5508	Economy	11800.00
0005435767728	5508	Economy	11800.00
0005435463155	5508	Economy	11800.00
0005435767733	5508	Economy	11800.00
0005434265536	5508	Economy	11800.00
0005434265558	5508	Economy	11800.00
0005435463129	5508	Economy	11800.00
0005435767719	5508	Economy	11800.00
0005435767742	5508	Economy	11800.00
0005434265624	5508	Economy	11800.00
0005434265770	13489	Business	35300.00
0005435463359	13489	Business	35300.00
0005435767349	13489	Business	35300.00
0005435767423	13489	Business	35300.00
0005435767254	13489	Business	35300.00
0005435767102	13489	Business	35300.00
0005435767005	13489	Business	35300.00
0005435720145	13489	Business	35300.00
0005432535953	13489	Business	35300.00
0005435463348	13489	Business	35300.00
0005435720148	13489	Business	35300.00
0005435725694	13489	Business	35300.00
0005435767153	13489	Business	35300.00
0005435463349	13489	Business	35300.00
0005435767110	13489	Business	35300.00
0005435463347	13489	Business	35300.00
0005435767255	13489	Business	35300.00
0005435767212	13489	Business	35300.00
0005432535956	13489	Business	35300.00
0005435766873	13489	Business	35300.00
0005435767109	13489	Economy	12900.00
0005435767448	13489	Business	35300.00
0005435767272	13489	Economy	12900.00
0005435463361	13489	Economy	12900.00
0005435725687	13489	Economy	12900.00
0005434265767	13489	Economy	11800.00
0005435735222	13489	Economy	11800.00
0005435767106	13489	Economy	11800.00
0005435463370	13489	Economy	11800.00
0005435767237	13489	Economy	11800.00
0005435767354	13489	Economy	11800.00
0005435767171	13489	Economy	11800.00
0005435767041	13489	Economy	11800.00
0005435735203	13489	Economy	11800.00
0005434265778	13489	Economy	11800.00
0005435767353	13489	Economy	11800.00
0005434831268	13489	Economy	11800.00
0005435463369	13489	Economy	11800.00
0005435463362	13489	Economy	11800.00
0005434831265	13489	Economy	11800.00
0005432194612	13489	Economy	11800.00
0005435767240	13489	Economy	11800.00
0005435463346	13489	Economy	11800.00
0005435463344	13489	Economy	11800.00
0005435463364	13489	Economy	11800.00
0005435767358	13489	Economy	11800.00
0005434265764	13489	Economy	11800.00
0005435767120	13489	Economy	11800.00
0005435767341	13489	Economy	11800.00
0005435463351	13489	Economy	11800.00
0005435767172	13489	Economy	11800.00
0005435767188	13489	Economy	11800.00
0005435735217	13489	Economy	11800.00
0005435725678	13489	Economy	11800.00
0005435463354	13489	Economy	11800.00
0005435735201	13489	Economy	11800.00
0005435767248	13489	Economy	11800.00
0005434265780	13489	Economy	11800.00
0005435767203	13489	Economy	11800.00
0005435463355	13489	Economy	11800.00
0005435463357	13489	Economy	11800.00
0005435767154	13489	Economy	11800.00
0005435767221	13489	Economy	11800.00
0005435735216	13489	Economy	11800.00
0005435766872	13489	Economy	11800.00
0005434265773	13489	Economy	11800.00
0005435463368	13489	Economy	11800.00
0005435767416	13489	Economy	11800.00
0005434265771	13489	Economy	11800.00
0005435767236	13489	Economy	11800.00
0005434265765	13489	Economy	11800.00
0005435767036	13489	Economy	11800.00
0005434265769	13489	Economy	11800.00
0005434265774	13489	Economy	11800.00
0005435767085	13489	Economy	11800.00
0005435767086	13489	Economy	11800.00
0005435463350	13489	Economy	11800.00
0005435767492	13489	Economy	11800.00
0005435767289	13489	Economy	11800.00
0005435767051	13489	Economy	11800.00
0005435463367	13489	Economy	11800.00
0005435043304	13489	Economy	11800.00
0005435767052	13489	Economy	11800.00
0005435463374	13489	Economy	11800.00
0005435735209	13489	Economy	11800.00
0005434265776	13489	Economy	11800.00
0005435767352	13489	Economy	11800.00
0005432535954	13489	Economy	11800.00
0005434265777	13489	Economy	11800.00
0005434831266	13489	Economy	11800.00
0005435767079	13489	Economy	11800.00
0005435463353	13489	Economy	11800.00
0005435767324	13489	Economy	11800.00
0005435735214	13489	Economy	11800.00
0005435767013	13489	Economy	11800.00
0005435722092	13489	Economy	11800.00
0005435767170	13489	Economy	11800.00
0005435766951	13489	Economy	11800.00
0005434265762	13489	Economy	11800.00
0005435766950	13489	Economy	11800.00
0005435766997	13489	Economy	11800.00
0005432194613	13489	Economy	11800.00
0005435767313	13489	Economy	12900.00
0005435767189	13489	Economy	11800.00
0005434265766	13489	Economy	11800.00
0005434265761	13489	Economy	12900.00
0005435463352	13489	Economy	12900.00
0005435767125	13489	Economy	11800.00
0005434831267	13489	Economy	11800.00
0005435767022	13489	Economy	11800.00
0005435767364	13489	Economy	11800.00
0005434265756	13489	Economy	11800.00
0005435767004	13489	Economy	11800.00
0005435767103	13489	Economy	11800.00
0005435767183	13489	Economy	11800.00
0005435767355	13489	Economy	11800.00
0005432535955	13489	Economy	11800.00
0005432194614	13489	Economy	11800.00
0005435767169	13489	Economy	11800.00
0005435767074	13489	Economy	11800.00
0005435767202	13489	Economy	11800.00
0005434265758	13489	Economy	11800.00
0005435767359	13489	Economy	11800.00
0005435463345	13489	Economy	11800.00
0005435766992	13489	Economy	11800.00
0005435463373	13489	Economy	11800.00
0005435767470	13489	Economy	11800.00
0005434265772	13489	Economy	11800.00
0005434265781	13489	Economy	11800.00
0005435767124	13489	Economy	11800.00
0005435463366	13489	Economy	11800.00
0005435767029	13489	Economy	11800.00
0005435463343	13489	Economy	11800.00
0005435767271	13489	Economy	11800.00
0005434265779	13489	Economy	11800.00
0005432194611	13489	Economy	11800.00
0005435735221	13489	Economy	11800.00
0005434265759	13489	Economy	11800.00
0005435767017	13489	Economy	11800.00
0005435766990	13489	Economy	11800.00
0005435463372	13489	Economy	11800.00
0005435767246	13489	Economy	11800.00
0005435463342	13489	Economy	11800.00
0005435463356	13489	Economy	11800.00
0005434265760	13489	Economy	11800.00
0005434265768	13489	Economy	11800.00
0005435766757	13489	Economy	11800.00
0005435767186	13489	Economy	11800.00
0005435767348	13489	Economy	11800.00
0005435767424	13489	Economy	11800.00
0005432535952	13489	Economy	11800.00
0005435767252	13489	Economy	11800.00
0005434831264	13489	Economy	11800.00
0005435767035	13489	Economy	11800.00
0005435767064	13489	Economy	11800.00
0005435463358	13489	Economy	11800.00
0005435767080	13489	Economy	11800.00
0005435767415	13489	Economy	11800.00
0005435767312	13489	Economy	11800.00
0005434265763	13489	Economy	11800.00
0005435767187	13489	Economy	11800.00
0005435735208	13489	Economy	11800.00
0005435767326	13489	Economy	11800.00
0005435463363	13489	Economy	11800.00
0005435463360	13489	Economy	11800.00
0005435463371	13489	Economy	11800.00
0005435463365	13489	Economy	11800.00
0005434265757	13489	Economy	11800.00
0005435767292	13489	Economy	11800.00
0005434265775	13489	Economy	11800.00
0005435767054	13489	Economy	11800.00
0005434602934	18710	Economy	3300.00
0005434602947	18710	Economy	3300.00
0005434604946	18711	Economy	3300.00
0005434515030	18711	Economy	3300.00
0005435904488	18711	Economy	3300.00
0005434515029	18711	Economy	3300.00
0005434513643	18711	Economy	3300.00
0005434513642	18711	Economy	3300.00
0005435904721	18711	Economy	3300.00
0005434513641	18711	Economy	3300.00
0005435904487	18711	Economy	3300.00
0005434604951	18711	Economy	3300.00
0005435904722	18711	Economy	3300.00
0005434515010	19128	Economy	3300.00
0005434515017	19128	Economy	3300.00
0005434515020	19128	Economy	3300.00
0005434515009	19128	Economy	3300.00
0005432632906	4121	Business	88300.00
0005432649550	4121	Business	88300.00
0005432649547	4121	Business	88300.00
0005432632908	4121	Business	88300.00
0005432649555	4121	Business	88300.00
0005432649551	4121	Economy	29400.00
0005435846302	4121	Economy	29400.00
0005432649548	4121	Economy	29400.00
0005432632914	4121	Economy	29400.00
0005435844380	4121	Economy	29400.00
0005432632903	4121	Economy	32400.00
0005435844381	4121	Economy	32400.00
0005432649549	4121	Economy	32400.00
0005435846299	4121	Economy	32400.00
0005435844374	4121	Economy	29400.00
0005432649553	4121	Economy	29400.00
0005435846308	4121	Economy	29400.00
0005432649546	4121	Economy	29400.00
0005432632904	4121	Economy	29400.00
0005432649545	4121	Economy	29400.00
0005432632905	4121	Economy	29400.00
0005432649554	4121	Economy	29400.00
0005435844377	4121	Economy	29400.00
0005435844370	4121	Economy	29400.00
0005432632907	4121	Economy	29400.00
0005435844379	4121	Economy	29400.00
0005432632911	4121	Economy	29400.00
0005435844382	4121	Economy	29400.00
0005432632913	4121	Economy	29400.00
0005432632912	4121	Economy	29400.00
0005435846318	4121	Economy	29400.00
0005432649552	4121	Economy	29400.00
0005432632915	4121	Economy	29400.00
0005432632910	4121	Economy	29400.00
0005435846303	4121	Economy	29400.00
0005435844376	4121	Economy	29400.00
0005432632916	4121	Economy	29400.00
0005432632909	4121	Economy	29400.00
0005435846307	4121	Economy	29400.00
0005435844375	4121	Economy	29400.00
0005432649544	4121	Economy	29400.00
0005435846304	4121	Economy	29400.00
0005435844383	4121	Economy	29400.00
0005435844369	4121	Economy	29400.00
0005435846309	4121	Economy	29400.00
0005433810694	1813	Business	48700.00
0005433810693	1813	Business	48700.00
0005433009350	1813	Business	48700.00
0005433009444	1813	Business	48700.00
0005433285711	1813	Business	48700.00
0005433009443	1813	Business	48700.00
0005433009359	1813	Business	48700.00
0005433009316	1813	Business	48700.00
0005433009347	1813	Business	48700.00
0005433810688	1813	Business	48700.00
0005433285859	1813	Business	48700.00
0005433009135	1813	Economy	16200.00
0005433009409	1813	Economy	16200.00
0005433810696	1813	Economy	16200.00
0005433009348	1813	Economy	16200.00
0005433009315	1813	Economy	16200.00
0005433810684	1813	Economy	16200.00
0005433285911	1813	Economy	16200.00
0005433285752	1813	Economy	16200.00
0005433009310	1813	Economy	16200.00
0005433285808	1813	Economy	16200.00
0005433285875	1813	Economy	17900.00
0005433285678	1813	Economy	17900.00
0005433285914	1813	Economy	17900.00
0005433009195	1813	Economy	17900.00
0005433285769	1813	Economy	17900.00
0005433009455	1813	Economy	16200.00
0005433810682	1813	Economy	16200.00
0005433009279	1813	Economy	16200.00
0005433810699	1813	Economy	16200.00
0005433285745	1813	Economy	16200.00
0005433009556	1813	Economy	16200.00
0005433009280	1813	Economy	16200.00
0005433009360	1813	Economy	16200.00
0005433810700	1813	Economy	16200.00
0005433009408	1813	Economy	16200.00
0005432295944	1813	Economy	16200.00
0005433009346	1813	Economy	16200.00
0005433009473	1813	Economy	16200.00
0005433810697	1813	Economy	16200.00
0005433810680	1813	Economy	16200.00
0005433009193	1813	Economy	16200.00
0005433810683	1813	Economy	16200.00
0005433810698	1813	Economy	16200.00
0005433009474	1813	Economy	16200.00
0005433285796	1813	Economy	16200.00
0005433285867	1813	Economy	16200.00
0005433810681	1813	Economy	16200.00
0005433009288	1813	Economy	16200.00
0005433285770	1813	Economy	16200.00
0005433009501	1813	Economy	16200.00
0005433009345	1813	Economy	16200.00
0005433285822	1813	Economy	16200.00
0005433285722	1813	Economy	16200.00
0005433285866	1813	Economy	16200.00
0005433009263	1813	Economy	16200.00
0005433009433	1813	Economy	16200.00
0005433285715	1813	Economy	16200.00
0005433009349	1813	Economy	16200.00
0005433285714	1813	Economy	16200.00
0005433285857	1813	Economy	16200.00
0005433810695	1813	Economy	16200.00
0005433009248	1813	Economy	16200.00
0005432295945	1813	Economy	16200.00
0005433009353	1813	Economy	16200.00
0005433009311	1813	Economy	16200.00
0005433009317	1813	Economy	16200.00
0005433285827	1813	Economy	16200.00
0005433009510	1813	Economy	16200.00
0005433009205	1813	Economy	16200.00
0005433009418	1813	Economy	16200.00
0005433810689	1813	Economy	16200.00
0005433285650	1813	Economy	16200.00
0005433810691	1813	Economy	16200.00
0005433285795	1813	Economy	16200.00
0005433810692	1813	Economy	16200.00
0005433009407	1813	Economy	16200.00
0005433285775	1813	Economy	16200.00
0005433810679	1813	Economy	16200.00
0005433009403	1813	Economy	16200.00
0005433009206	1813	Economy	16200.00
0005433810685	1813	Economy	16200.00
0005433285907	1813	Economy	16200.00
0005433810690	1813	Economy	16200.00
0005433285917	1813	Economy	16200.00
0005433285712	1813	Economy	16200.00
0005432295943	1813	Economy	16200.00
0005433810678	1813	Economy	16200.00
0005433285955	1813	Economy	16200.00
0005433009454	1813	Economy	16200.00
0005433285716	1813	Economy	16200.00
0005433285805	1813	Economy	16200.00
0005433810687	1813	Economy	16200.00
0005433810686	1813	Economy	16200.00
0005433286036	22577	Business	48700.00
0005433286037	22577	Business	48700.00
0005433009722	22577	Business	48700.00
0005433009695	22577	Business	48700.00
0005433009714	22577	Business	48700.00
0005433286031	22577	Business	48700.00
0005433286032	22577	Business	48700.00
0005433009698	22577	Business	48700.00
0005433009710	22577	Business	48700.00
0005433286041	22577	Business	48700.00
0005433286054	22577	Business	48700.00
0005433286030	22577	Business	48700.00
0005433286028	22577	Economy	16200.00
0005433009716	22577	Economy	16200.00
0005433286045	22577	Economy	16200.00
0005433286034	22577	Economy	16200.00
0005433009678	22577	Economy	16200.00
0005433286033	22577	Economy	16200.00
0005433009686	22577	Economy	16200.00
0005433286050	22577	Economy	16200.00
0005433009717	22577	Economy	17900.00
0005433009689	22577	Economy	17900.00
0005433009709	22577	Economy	17900.00
0005433286042	22577	Economy	17900.00
0005433009712	22577	Economy	16200.00
0005433286049	22577	Economy	16200.00
0005433009681	22577	Economy	16200.00
0005433009683	22577	Economy	16200.00
0005433009704	22577	Economy	16200.00
0005433286044	22577	Economy	16200.00
0005433286043	22577	Economy	16200.00
0005433009702	22577	Economy	16200.00
0005433009690	22577	Economy	16200.00
0005433286056	22577	Economy	16200.00
0005433009719	22577	Economy	16200.00
0005433286038	22577	Economy	16200.00
0005433286039	22577	Economy	16200.00
0005433009680	22577	Economy	16200.00
0005433286035	22577	Economy	16200.00
0005433286053	22577	Economy	16200.00
0005433009705	22577	Economy	16200.00
0005433009713	22577	Economy	16200.00
0005433286057	22577	Economy	16200.00
0005433009696	22577	Economy	16200.00
0005433009701	22577	Economy	16200.00
0005433009718	22577	Economy	16200.00
0005433009715	22577	Economy	16200.00
0005433009685	22577	Economy	16200.00
0005433009684	22577	Economy	16200.00
0005433009720	22577	Economy	16200.00
0005433810591	22577	Economy	16200.00
0005433810592	22577	Economy	16200.00
0005433009707	22577	Economy	16200.00
0005433286047	22577	Economy	16200.00
0005433009694	22577	Economy	16200.00
0005433286040	22577	Economy	16200.00
0005433009682	22577	Economy	16200.00
0005433009679	22577	Economy	16200.00
0005433009706	22577	Economy	16200.00
0005433009691	22577	Economy	16200.00
0005433009721	22577	Economy	16200.00
0005433286052	22577	Economy	16200.00
0005433286046	22577	Economy	16200.00
0005433009687	22577	Economy	16200.00
0005433286051	22577	Economy	16200.00
0005433009697	22577	Economy	16200.00
0005433009711	22577	Economy	16200.00
0005433286048	22577	Economy	16200.00
0005433286029	22577	Economy	16200.00
0005433009693	22577	Economy	16200.00
0005433009708	22577	Economy	16200.00
0005433009700	22577	Economy	16200.00
0005433009688	22577	Economy	16200.00
0005433009703	22577	Economy	16200.00
0005433286055	22577	Economy	16200.00
0005433009699	22577	Economy	16200.00
0005433009692	22577	Economy	16200.00
0005433009723	22577	Economy	16200.00
0005433810589	22577	Economy	16200.00
0005433286027	22577	Economy	16200.00
0005432751578	12279	Business	83800.00
0005432751570	12279	Business	83800.00
0005432751576	12279	Business	83800.00
0005432751574	12279	Business	83800.00
0005434152842	12279	Business	83800.00
0005434151804	12279	Business	83800.00
0005434152843	12279	Business	83800.00
0005434152837	12279	Business	83800.00
0005434152836	12279	Business	83800.00
0005434152838	12279	Economy	27900.00
0005434151801	12279	Economy	27900.00
0005434152844	12279	Economy	27900.00
0005432751575	12279	Economy	30700.00
0005434151797	12279	Economy	27900.00
0005432751577	12279	Economy	27900.00
0005432755120	12279	Economy	27900.00
0005434152834	12279	Economy	27900.00
0005432755118	12279	Economy	27900.00
0005432755112	12279	Economy	27900.00
0005434152835	12279	Economy	27900.00
0005432751571	12279	Economy	27900.00
0005434151799	12279	Economy	27900.00
0005434151808	12279	Economy	27900.00
0005434151802	12279	Economy	27900.00
0005434151798	12279	Economy	27900.00
0005432755117	12279	Economy	27900.00
0005434152840	12279	Economy	27900.00
0005434151805	12279	Economy	27900.00
0005432755133	12279	Economy	27900.00
0005432755123	12279	Economy	27900.00
0005432755105	12279	Economy	27900.00
0005434152833	12279	Economy	27900.00
0005432755119	12279	Economy	27900.00
0005434151803	12279	Economy	27900.00
0005432751559	12279	Economy	27900.00
0005434151800	12279	Economy	27900.00
0005434152839	12279	Economy	27900.00
0005434151806	12279	Economy	27900.00
0005434151807	12279	Economy	27900.00
0005432755124	12279	Economy	27900.00
0005434152841	12279	Economy	27900.00
0005433815501	5607	Business	99800.00
0005433848159	5607	Business	99800.00
0005435282806	5607	Business	99800.00
0005435282887	5607	Business	99800.00
0005433848160	5607	Business	99800.00
0005435282902	5607	Business	99800.00
0005433848118	5607	Business	99800.00
0005433848151	5607	Business	99800.00
0005433848147	5607	Business	99800.00
0005433848125	5607	Business	99800.00
0005435282804	5607	Business	99800.00
0005433848127	5607	Business	99800.00
0005435282906	5607	Business	99800.00
0005433848122	5607	Business	99800.00
0005433848171	5607	Business	99800.00
0005435282938	5607	Business	99800.00
0005435282901	5607	Economy	33300.00
0005435282952	5607	Business	99800.00
0005433848153	5607	Economy	33300.00
0005433848136	5607	Economy	33300.00
0005435282894	5607	Economy	33300.00
0005433848130	5607	Economy	33300.00
0005433848161	5607	Economy	33300.00
0005433848128	5607	Economy	33300.00
0005432081669	5607	Economy	33300.00
0005433848141	5607	Economy	33300.00
0005433848157	5607	Economy	33300.00
0005433848126	5607	Economy	33300.00
0005433848135	5607	Economy	36600.00
0005433848119	5607	Economy	36600.00
0005433848140	5607	Economy	33300.00
0005434173579	5607	Economy	33300.00
0005433815542	5607	Economy	33300.00
0005433848145	5607	Economy	33300.00
0005435282958	5607	Economy	33300.00
0005433848144	5607	Economy	33300.00
0005435282805	5607	Economy	33300.00
0005433848115	5607	Economy	33300.00
0005432081671	5607	Economy	33300.00
0005433848124	5607	Economy	33300.00
0005433848163	5607	Economy	33300.00
0005433848138	5607	Economy	33300.00
0005433848134	5607	Economy	33300.00
0005433848120	5607	Economy	33300.00
0005433848142	5607	Economy	33300.00
0005433815502	5607	Economy	33300.00
0005432081670	5607	Economy	33300.00
0005433848154	5607	Economy	33300.00
0005433848152	5607	Economy	33300.00
0005432081666	5607	Economy	33300.00
0005433848167	5607	Economy	33300.00
0005435282905	5607	Economy	33300.00
0005433848168	5607	Economy	33300.00
0005435282954	5607	Economy	33300.00
0005435282953	5607	Economy	33300.00
0005435282937	5607	Economy	33300.00
0005433848123	5607	Economy	33300.00
0005435282929	5607	Economy	33300.00
0005433848132	5607	Economy	33300.00
0005433848149	5607	Economy	33300.00
0005433848131	5607	Economy	33300.00
0005435282848	5607	Economy	33300.00
0005433848165	5607	Economy	33300.00
0005433848162	5607	Economy	33300.00
0005433848143	5607	Economy	33300.00
0005435282885	5607	Economy	33300.00
0005433848155	5607	Economy	33300.00
0005433848121	5607	Economy	33300.00
0005433848169	5607	Economy	33300.00
0005433848116	5607	Economy	33300.00
0005433848158	5607	Economy	33300.00
0005433848170	5607	Economy	33300.00
0005435282888	5607	Economy	33300.00
0005433848129	5607	Economy	33300.00
0005434173582	5607	Economy	33300.00
0005433815500	5607	Economy	33300.00
0005433848148	5607	Economy	33300.00
0005435282785	5607	Economy	33300.00
0005435282916	5607	Economy	33300.00
0005433848166	5607	Economy	33300.00
0005435282904	5607	Economy	33300.00
0005433848139	5607	Economy	33300.00
0005435282827	5607	Economy	33300.00
0005433848117	5607	Economy	33300.00
0005433848137	5607	Economy	33300.00
0005435282936	5607	Economy	33300.00
0005435282791	5607	Economy	33300.00
0005433848113	5607	Economy	33300.00
0005433848146	5607	Economy	33300.00
0005432081668	5607	Economy	33300.00
0005433815499	5607	Economy	33300.00
0005433848133	5607	Economy	33300.00
0005433848114	5607	Economy	33300.00
0005432081667	5607	Economy	33300.00
0005433848156	5607	Economy	33300.00
0005433848172	5607	Economy	33300.00
0005433815498	5607	Economy	33300.00
0005433848164	5607	Economy	33300.00
0005433848150	5607	Economy	33300.00
0005435283111	13866	Business	99800.00
0005433847744	13866	Business	99800.00
0005435283103	13866	Business	99800.00
0005433847639	13866	Business	99800.00
0005433847756	13866	Business	99800.00
0005435283114	13866	Business	99800.00
0005435283118	13866	Business	99800.00
0005433847655	13866	Business	99800.00
0005434173645	13866	Business	99800.00
0005433847666	13866	Business	99800.00
0005433815471	13866	Business	99800.00
0005433847470	13866	Business	99800.00
0005435283102	13866	Business	99800.00
0005433815459	13866	Business	99800.00
0005433847542	13866	Business	99800.00
0005433847921	13866	Economy	33300.00
0005435283107	13866	Economy	33300.00
0005433847730	13866	Economy	33300.00
0005433847571	13866	Economy	33300.00
0005435283110	13866	Economy	33300.00
0005435283117	13866	Economy	33300.00
0005435283108	13866	Economy	33300.00
0005433847678	13866	Economy	33300.00
0005433847579	13866	Economy	33300.00
0005434173646	13866	Economy	33300.00
0005433847593	13866	Economy	36600.00
0005433847602	13866	Economy	36600.00
0005435283109	13866	Economy	36600.00
0005433815480	13866	Economy	33300.00
0005433847920	13866	Economy	36600.00
0005435283121	13866	Economy	33300.00
0005433847436	13866	Economy	33300.00
0005435283105	13866	Economy	33300.00
0005433847533	13866	Economy	33300.00
0005434173618	13866	Economy	33300.00
0005433847563	13866	Economy	33300.00
0005433847759	13866	Economy	33300.00
0005433815446	13866	Economy	33300.00
0005433847484	13866	Economy	33300.00
0005432003778	13866	Economy	33300.00
0005433847601	13866	Economy	33300.00
0005435283124	13866	Economy	33300.00
0005434173617	13866	Economy	33300.00
0005433847486	13866	Economy	33300.00
0005433847687	13866	Economy	33300.00
0005433847652	13866	Economy	33300.00
0005433847702	13866	Economy	33300.00
0005435283120	13866	Economy	33300.00
0005433847746	13866	Economy	33300.00
0005433847688	13866	Economy	33300.00
0005433847745	13866	Economy	33300.00
0005433847768	13866	Economy	33300.00
0005435283104	13866	Economy	33300.00
0005433815458	13866	Economy	33300.00
0005433847793	13866	Economy	33300.00
0005435283122	13866	Economy	33300.00
0005435283123	13866	Economy	33300.00
0005433847594	13866	Economy	33300.00
0005432003777	13866	Economy	33300.00
0005433847569	13866	Economy	33300.00
0005433847656	13866	Economy	33300.00
0005433815472	13866	Economy	33300.00
0005433847572	13866	Economy	33300.00
0005433815479	13866	Economy	33300.00
0005433847789	13866	Economy	33300.00
0005432003779	13866	Economy	33300.00
0005433847679	13866	Economy	33300.00
0005433847471	13866	Economy	33300.00
0005434173619	13866	Economy	33300.00
0005433847638	13866	Economy	33300.00
0005433847773	13866	Economy	33300.00
0005433815473	13866	Economy	33300.00
0005433815447	13866	Economy	33300.00
0005434173647	13866	Economy	33300.00
0005433847809	13866	Economy	33300.00
0005435283112	13866	Economy	33300.00
0005435283101	13866	Economy	33300.00
0005435283126	13866	Economy	33300.00
0005433847747	13866	Economy	33300.00
0005433847709	13866	Economy	33300.00
0005435283115	13866	Economy	33300.00
0005433847485	13866	Economy	33300.00
0005435283116	13866	Economy	33300.00
0005435283113	13866	Economy	33300.00
0005433847534	13866	Economy	33300.00
0005434173620	13866	Economy	33300.00
0005435283127	13866	Economy	33300.00
0005433847305	13866	Economy	33300.00
0005433847853	13866	Economy	33300.00
0005435283125	13866	Economy	33300.00
0005435283106	13866	Economy	33300.00
0005433815457	13866	Economy	33300.00
0005435283119	13866	Economy	33300.00
0005433847743	13866	Economy	33300.00
0005435283128	13866	Economy	33300.00
0005432112571	7839	Economy	16600.00
0005434621104	7839	Economy	16600.00
0005435332450	7839	Economy	16600.00
0005434621094	7839	Economy	16600.00
0005435332497	7839	Economy	15100.00
0005434621102	7839	Economy	15100.00
0005434621093	7839	Economy	15100.00
0005435332449	7839	Economy	15100.00
0005434621088	7839	Economy	15100.00
0005435332509	7839	Economy	15100.00
0005434621090	7839	Economy	15100.00
0005432112572	7839	Economy	15100.00
0005434621096	7839	Economy	15100.00
0005434621105	7839	Economy	15100.00
0005434621092	7839	Economy	15100.00
0005434621095	7839	Economy	15100.00
0005434621086	7839	Economy	15100.00
0005435332483	7839	Economy	15100.00
0005435332482	7839	Economy	15100.00
0005434621103	7839	Economy	15100.00
0005434621101	7839	Economy	15100.00
0005434621100	7839	Economy	15100.00
0005432112570	7839	Economy	15100.00
0005434621091	7839	Economy	15100.00
0005434621087	7839	Economy	15100.00
0005435332510	7839	Economy	15100.00
0005434621099	7839	Economy	15100.00
0005435332508	7839	Economy	15100.00
0005435332484	7839	Economy	15100.00
0005435332485	7839	Economy	15100.00
0005435332518	7839	Economy	15100.00
0005434621098	7839	Economy	15100.00
0005434621089	7839	Economy	15100.00
0005434621097	7839	Economy	15100.00
0005435332535	7839	Economy	15100.00
0005434620839	32971	Economy	16600.00
0005434620884	32971	Economy	16600.00
0005434620821	32971	Economy	15100.00
0005434620863	32971	Economy	15100.00
0005435332590	32971	Economy	15100.00
0005434620883	32971	Economy	15100.00
0005435332585	32971	Economy	15100.00
0005434620887	32971	Economy	15100.00
0005434620822	32971	Economy	15100.00
0005435332587	32971	Economy	15100.00
0005435332589	32971	Economy	15100.00
0005434620926	32971	Economy	15100.00
0005434620976	32971	Economy	15100.00
0005434620946	32971	Economy	15100.00
0005434620850	32971	Economy	15100.00
0005434620928	32971	Economy	15100.00
0005435332586	32971	Economy	15100.00
0005434620857	32971	Economy	15100.00
0005434620856	32971	Economy	15100.00
0005434620927	32971	Economy	15100.00
0005434620823	32971	Economy	15100.00
0005435332588	32971	Economy	15100.00
0005434620935	32971	Economy	15100.00
0005434620858	32971	Economy	15100.00
0005434620859	32971	Economy	15100.00
0005434620971	32971	Economy	15100.00
0005434620840	32971	Economy	15100.00
0005434620947	32971	Economy	15100.00
0005435332592	32971	Economy	15100.00
0005434620980	32971	Economy	15100.00
0005434620860	32971	Economy	15100.00
0005435332591	32971	Economy	15100.00
0005434620977	32971	Economy	15100.00
0005434994261	4297	Business	38000.00
0005434994257	4297	Business	38000.00
0005435786208	4297	Business	38000.00
0005434994258	4297	Business	38000.00
0005435786203	4297	Business	38000.00
0005435786212	4297	Business	38000.00
0005434994256	4297	Economy	12700.00
0005432190723	4297	Economy	12700.00
0005435786195	4297	Economy	12700.00
0005435786201	4297	Economy	13900.00
0005435786204	4297	Economy	13900.00
0005435786213	4297	Economy	13900.00
0005434994260	4297	Economy	13900.00
0005435786183	4297	Economy	13900.00
0005435786189	4297	Economy	12700.00
0005435786193	4297	Economy	12700.00
0005435787404	4297	Economy	12700.00
0005435786205	4297	Economy	12700.00
0005435786217	4297	Economy	12700.00
0005435786190	4297	Economy	12700.00
0005435786194	4297	Economy	12700.00
0005435786186	4297	Economy	12700.00
0005434994265	4297	Economy	12700.00
0005435937433	4297	Economy	12700.00
0005435937438	4297	Economy	12700.00
0005435786188	4297	Economy	12700.00
0005435786202	4297	Economy	12700.00
0005435786184	4297	Economy	12700.00
0005435786209	4297	Economy	12700.00
0005435918730	4297	Economy	12700.00
0005435786198	4297	Economy	12700.00
0005432190724	4297	Economy	12700.00
0005435786192	4297	Economy	12700.00
0005435786199	4297	Economy	12700.00
0005435786185	4297	Economy	12700.00
0005435786207	4297	Economy	12700.00
0005434994264	4297	Economy	12700.00
0005435937439	4297	Economy	12700.00
0005435786206	4297	Economy	12700.00
0005434994259	4297	Economy	12700.00
0005435787405	4297	Economy	12700.00
0005435786215	4297	Economy	12700.00
0005435786197	4297	Economy	12700.00
0005435786187	4297	Economy	12700.00
0005432190722	4297	Economy	12700.00
0005435786216	4297	Economy	12700.00
0005435786210	4297	Economy	12700.00
0005435786196	4297	Economy	12700.00
0005435786182	4297	Economy	12700.00
0005435786191	4297	Economy	12700.00
0005434994263	4297	Economy	12700.00
0005435786214	4297	Economy	12700.00
0005435787406	4297	Economy	12700.00
0005434994262	4297	Economy	12700.00
0005435786211	4297	Economy	12700.00
0005435918724	4297	Economy	12700.00
0005435786200	4297	Economy	12700.00
0005435785866	27298	Business	38000.00
0005435937504	27298	Business	38000.00
0005434994166	27298	Business	38000.00
0005434994183	27298	Business	38000.00
0005434994187	27298	Business	38000.00
0005435937506	27298	Business	38000.00
0005435785877	27298	Business	38000.00
0005435918770	27298	Economy	12700.00
0005435937501	27298	Economy	12700.00
0005435785792	27298	Economy	12700.00
0005435785862	27298	Economy	12700.00
0005435785775	27298	Economy	12700.00
0005435785855	27298	Economy	13900.00
0005435937512	27298	Economy	13900.00
0005434994157	27298	Economy	13900.00
0005435785951	27298	Economy	13900.00
0005434994168	27298	Economy	12700.00
0005435785874	27298	Economy	12700.00
0005434994196	27298	Economy	12700.00
0005435937511	27298	Economy	12700.00
0005432195743	27298	Economy	12700.00
0005434994184	27298	Economy	12700.00
0005435785979	27298	Economy	12700.00
0005435785774	27298	Economy	12700.00
0005435785773	27298	Economy	12700.00
0005435785638	27298	Economy	12700.00
0005435785900	27298	Economy	12700.00
0005435785753	27298	Economy	12700.00
0005435937510	27298	Economy	12700.00
0005435785939	27298	Economy	12700.00
0005435918774	27298	Economy	12700.00
0005435785641	27298	Economy	12700.00
0005432195744	27298	Economy	12700.00
0005434994165	27298	Economy	12700.00
0005435785978	27298	Economy	12700.00
0005435785662	27298	Economy	12700.00
0005435785940	27298	Economy	12700.00
0005435785642	27298	Economy	12700.00
0005434994167	27298	Economy	12700.00
0005435785867	27298	Economy	12700.00
0005435785847	27298	Economy	12700.00
0005435937509	27298	Economy	12700.00
0005435937503	27298	Economy	12700.00
0005435785836	27298	Economy	12700.00
0005434994209	27298	Economy	12700.00
0005434994210	27298	Economy	12700.00
0005435785731	27298	Economy	12700.00
0005434994174	27298	Economy	12700.00
0005435918773	27298	Economy	12700.00
0005435785856	27298	Economy	12700.00
0005435918771	27298	Economy	12700.00
0005435937502	27298	Economy	12700.00
0005435937505	27298	Economy	12700.00
0005432195745	27298	Economy	12700.00
0005435785637	27298	Economy	12700.00
0005435937508	27298	Economy	12700.00
0005435785861	27298	Economy	12700.00
0005435785903	27298	Economy	12700.00
0005435937507	27298	Economy	12700.00
0005435785899	27298	Economy	12700.00
0005435937500	27298	Economy	12700.00
0005435918772	27298	Economy	12700.00
0005434994135	27298	Economy	12700.00
0005435785752	27298	Economy	12700.00
0005435785876	27298	Economy	12700.00
0005435786008	27298	Economy	12700.00
0005435785857	27298	Economy	12700.00
0005435785663	27298	Economy	12700.00
0005432146250	19878	Economy	12800.00
0005432146249	19878	Economy	12800.00
0005432146248	19878	Economy	12800.00
0005432569128	4731	Business	40900.00
0005434082502	4731	Business	40900.00
0005432461120	4731	Business	40900.00
0005432569129	4731	Business	40900.00
0005434082489	4731	Business	40900.00
0005434082499	4731	Business	40900.00
0005432461103	4731	Business	40900.00
0005432569106	4731	Business	40900.00
0005432569114	4731	Business	40900.00
0005432461110	4731	Business	40900.00
0005432569149	4731	Business	40900.00
0005432170553	4731	Business	40900.00
0005434082479	4731	Business	40900.00
0005432569105	4731	Business	40900.00
0005432569112	4731	Business	40900.00
0005434559124	4731	Business	40900.00
0005434082491	4731	Business	40900.00
0005432569146	4731	Business	40900.00
0005432569118	4731	Business	40900.00
0005432170555	4731	Business	40900.00
0005434082486	4731	Business	40900.00
0005432569093	4731	Business	40900.00
0005432571413	4731	Business	40900.00
0005432569111	4731	Economy	15000.00
0005434082495	4731	Economy	15000.00
0005432461094	4731	Economy	15000.00
0005434082496	4731	Economy	15000.00
0005432569120	4731	Economy	13600.00
0005432461141	4731	Economy	13600.00
0005432461096	4731	Economy	13600.00
0005432571414	4731	Economy	13600.00
0005432461146	4731	Economy	13600.00
0005432569148	4731	Economy	13600.00
0005432461115	4731	Economy	13600.00
0005432569127	4731	Economy	13600.00
0005432461108	4731	Economy	13600.00
0005432461147	4731	Economy	13600.00
0005432569092	4731	Economy	13600.00
0005432461130	4731	Economy	13600.00
0005434082497	4731	Economy	13600.00
0005432461123	4731	Economy	13600.00
0005432569099	4731	Economy	13600.00
0005432170550	4731	Economy	13600.00
0005432461107	4731	Economy	13600.00
0005432461143	4731	Economy	13600.00
0005432569133	4731	Economy	13600.00
0005432461113	4731	Economy	13600.00
0005432461111	4731	Economy	13600.00
0005432461138	4731	Economy	13600.00
0005432461098	4731	Economy	13600.00
0005432569102	4731	Economy	13600.00
0005434559122	4731	Economy	13600.00
0005432569137	4731	Economy	13600.00
0005432569139	4731	Economy	13600.00
0005432461112	4731	Economy	13600.00
0005434082493	4731	Economy	13600.00
0005432461136	4731	Economy	13600.00
0005432170556	4731	Economy	13600.00
0005432571416	4731	Economy	13600.00
0005432569140	4731	Economy	13600.00
0005432569147	4731	Economy	13600.00
0005434082500	4731	Economy	13600.00
0005434559125	4731	Economy	13600.00
0005432569090	4731	Economy	13600.00
0005432569103	4731	Economy	13600.00
0005432569131	4731	Economy	13600.00
0005432569117	4731	Economy	13600.00
0005432569107	4731	Economy	13600.00
0005434082503	4731	Economy	13600.00
0005432569130	4731	Economy	13600.00
0005432461102	4731	Economy	13600.00
0005433452790	4731	Economy	13600.00
0005432461124	4731	Economy	13600.00
0005434082476	4731	Economy	13600.00
0005434082484	4731	Economy	13600.00
0005432461133	4731	Economy	13600.00
0005432170551	4731	Economy	13600.00
0005432461139	4731	Economy	13600.00
0005432461127	4731	Economy	13600.00
0005432461099	4731	Economy	13600.00
0005432186958	4731	Economy	13600.00
0005432569089	4731	Economy	13600.00
0005433451670	4731	Economy	13600.00
0005432461100	4731	Economy	13600.00
0005432571412	4731	Economy	13600.00
0005432461126	4731	Economy	13600.00
0005432461118	4731	Economy	13600.00
0005432461128	4731	Economy	13600.00
0005432170554	4731	Economy	13600.00
0005432569150	4731	Economy	13600.00
0005432569138	4731	Economy	13600.00
0005432569100	4731	Economy	13600.00
0005432461101	4731	Economy	13600.00
0005432461119	4731	Economy	13600.00
0005432569135	4731	Economy	13600.00
0005432461109	4731	Economy	13600.00
0005434082494	4731	Economy	13600.00
0005434082483	4731	Economy	13600.00
0005432569109	4731	Economy	13600.00
0005432461117	4731	Economy	13600.00
0005434082498	4731	Economy	13600.00
0005432569108	4731	Economy	13600.00
0005434082509	4731	Economy	13600.00
0005432461131	4731	Economy	13600.00
0005432461097	4731	Economy	13600.00
0005432461116	4731	Economy	13600.00
0005432569132	4731	Economy	13600.00
0005432461104	4731	Economy	13600.00
0005432569098	4731	Economy	13600.00
0005433451669	4731	Economy	15000.00
0005432569094	4731	Economy	15000.00
0005432461122	4731	Economy	13600.00
0005434559123	4731	Economy	13600.00
0005434082507	4731	Economy	13600.00
0005432461106	4731	Economy	15000.00
0005432569104	4731	Economy	13600.00
0005432569125	4731	Economy	15000.00
0005432569136	4731	Economy	13600.00
0005434082510	4731	Economy	13600.00
0005432170552	4731	Economy	13600.00
0005432569143	4731	Economy	13600.00
0005432569115	4731	Economy	13600.00
0005432569134	4731	Economy	13600.00
0005432569141	4731	Economy	13600.00
0005432569123	4731	Economy	13600.00
0005432461145	4731	Economy	13600.00
0005434082490	4731	Economy	13600.00
0005432569116	4731	Economy	13600.00
0005432569097	4731	Economy	13600.00
0005434082508	4731	Economy	13600.00
0005432461125	4731	Economy	13600.00
0005432569124	4731	Economy	13600.00
0005432571415	4731	Economy	13600.00
0005432461132	4731	Economy	13600.00
0005432186961	4731	Economy	13600.00
0005434082501	4731	Economy	13600.00
0005434082482	4731	Economy	13600.00
0005433451671	4731	Economy	13600.00
0005432170549	4731	Economy	13600.00
0005432461114	4731	Economy	13600.00
0005434082477	4731	Economy	13600.00
0005434082481	4731	Economy	13600.00
0005432461140	4731	Economy	13600.00
0005432569122	4731	Economy	13600.00
0005434082480	4731	Economy	13600.00
0005432461121	4731	Economy	13600.00
0005432461137	4731	Economy	13600.00
0005434082478	4731	Economy	13600.00
0005432186960	4731	Economy	13600.00
0005432461093	4731	Economy	13600.00
0005432186959	4731	Economy	13600.00
0005432461129	4731	Economy	13600.00
0005432461134	4731	Economy	13600.00
0005434082492	4731	Economy	13600.00
0005432461142	4731	Economy	13600.00
0005434082485	4731	Economy	13600.00
0005434559126	4731	Economy	13600.00
0005432461144	4731	Economy	13600.00
0005434082504	4731	Economy	13600.00
0005432569121	4731	Economy	13600.00
0005434082506	4731	Economy	13600.00
0005432569119	4731	Economy	13600.00
0005432569113	4731	Economy	13600.00
0005432461095	4731	Economy	13600.00
0005432569091	4731	Economy	13600.00
0005434082488	4731	Economy	13600.00
0005432569110	4731	Economy	13600.00
0005432461105	4731	Economy	13600.00
0005434082505	4731	Economy	13600.00
0005432569126	4731	Economy	13600.00
0005432569101	4731	Economy	13600.00
0005433726161	4731	Economy	13600.00
0005432569142	4731	Economy	13600.00
0005432569151	4731	Economy	13600.00
0005434082487	4731	Economy	13600.00
0005432569096	4731	Economy	13600.00
0005432569144	4731	Economy	13600.00
0005432569145	4731	Economy	13600.00
0005432569095	4731	Economy	13600.00
0005432461135	4731	Economy	13600.00
0005432460762	30528	Business	40900.00
0005432460562	30528	Business	40900.00
0005432460846	30528	Business	40900.00
0005434559104	30528	Business	40900.00
0005432460634	30528	Business	40900.00
0005432568619	30528	Business	40900.00
0005432568641	30528	Business	40900.00
0005432568520	30528	Business	40900.00
0005432568629	30528	Business	40900.00
0005432460844	30528	Business	40900.00
0005432568948	30528	Business	40900.00
0005434559100	30528	Business	40900.00
0005432460964	30528	Business	40900.00
0005432460785	30528	Business	40900.00
0005434082198	30528	Business	40900.00
0005432460553	30528	Business	40900.00
0005432571385	30528	Business	40900.00
0005432571384	30528	Business	40900.00
0005432568675	30528	Business	40900.00
0005432460561	30528	Business	40900.00
0005432460474	30528	Business	40900.00
0005434082252	30528	Business	40900.00
0005432568859	30528	Economy	15000.00
0005432460672	30528	Economy	15000.00
0005432568906	30528	Economy	13600.00
0005432568826	30528	Economy	13600.00
0005432460718	30528	Economy	13600.00
0005432568825	30528	Economy	13600.00
0005432460867	30528	Economy	13600.00
0005434082206	30528	Economy	13600.00
0005432213696	30528	Economy	13600.00
0005432460706	30528	Economy	13600.00
0005432460777	30528	Economy	13600.00
0005432568574	30528	Economy	13600.00
0005432568572	30528	Economy	13600.00
0005432568736	30528	Economy	13600.00
0005434082186	30528	Economy	13600.00
0005432460842	30528	Economy	13600.00
0005432460823	30528	Economy	13600.00
0005432568743	30528	Economy	13600.00
0005432460891	30528	Economy	13600.00
0005432568514	30528	Economy	13600.00
0005434559102	30528	Economy	13600.00
0005432568518	30528	Economy	13600.00
0005432568721	30528	Economy	13600.00
0005432460681	30528	Economy	13600.00
0005432568801	30528	Economy	13600.00
0005434082215	30528	Economy	13600.00
0005432460682	30528	Economy	13600.00
0005432568725	30528	Economy	13600.00
0005432460724	30528	Economy	13600.00
0005434082197	30528	Economy	13600.00
0005432568538	30528	Economy	13600.00
0005432571378	30528	Economy	13600.00
0005432460786	30528	Economy	13600.00
0005432568406	30528	Economy	13600.00
0005432460794	30528	Economy	13600.00
0005432568372	30528	Economy	13600.00
0005432568483	30528	Economy	13600.00
0005432460475	30528	Economy	13600.00
0005432460905	30528	Economy	13600.00
0005434082148	30528	Economy	13600.00
0005432460752	30528	Economy	13600.00
0005432568797	30528	Economy	13600.00
0005432460763	30528	Economy	13600.00
0005432568524	30528	Economy	13600.00
0005432568799	30528	Economy	13600.00
0005432460579	30528	Economy	13600.00
0005434082231	30528	Economy	13600.00
0005432568576	30528	Economy	13600.00
0005432568798	30528	Economy	13600.00
0005432460783	30528	Economy	13600.00
0005432568705	30528	Economy	13600.00
0005434559101	30528	Economy	13600.00
0005432568689	30528	Economy	13600.00
0005434082233	30528	Economy	13600.00
0005432568803	30528	Economy	13600.00
0005432460700	30528	Economy	13600.00
0005432460736	30528	Economy	13600.00
0005434082235	30528	Economy	13600.00
0005432568624	30528	Economy	13600.00
0005432460877	30528	Economy	13600.00
0005432460622	30528	Economy	13600.00
0005432460768	30528	Economy	13600.00
0005432571393	30528	Economy	15000.00
0005432568863	30528	Economy	13600.00
0005432568722	30528	Economy	15000.00
0005432460868	30528	Economy	13600.00
0005432213700	30528	Economy	13600.00
0005432568827	30528	Economy	13600.00
0005432460454	30528	Economy	13600.00
0005432568575	30528	Economy	13600.00
0005434559103	30528	Economy	13600.00
0005432161208	30528	Economy	13600.00
0005432460984	30528	Economy	13600.00
0005432460784	30528	Economy	13600.00
0005432460453	30528	Economy	13600.00
0005432460495	30528	Economy	13600.00
0005432460581	30528	Economy	13600.00
0005432568556	30528	Economy	13600.00
0005432460418	30528	Economy	13600.00
0005432568646	30528	Economy	13600.00
0005432568565	30528	Economy	13600.00
0005432568630	30528	Economy	13600.00
0005432568645	30528	Economy	13600.00
0005432568866	30528	Economy	13600.00
0005432460560	30528	Economy	13600.00
0005432568539	30528	Economy	13600.00
0005432213697	30528	Economy	13600.00
0005432460843	30528	Economy	13600.00
0005432460678	30528	Economy	13600.00
0005432460580	30528	Economy	13600.00
0005432460462	30528	Economy	13600.00
0005434559097	30528	Economy	13600.00
0005432460698	30528	Economy	13600.00
0005432460406	30528	Economy	13600.00
0005432568573	30528	Economy	13600.00
0005434082208	30528	Economy	13600.00
0005432161207	30528	Economy	13600.00
0005432460671	30528	Economy	13600.00
0005432460405	30528	Economy	13600.00
0005432568666	30528	Economy	13600.00
0005432460621	30528	Economy	13600.00
0005432568739	30528	Economy	13600.00
0005434082246	30528	Economy	13600.00
0005432568519	30528	Economy	13600.00
0005432571371	30528	Economy	13600.00
0005432460620	30528	Economy	13600.00
0005432460919	30528	Economy	13600.00
0005432213698	30528	Economy	13600.00
0005432460824	30528	Economy	13600.00
0005434082253	30528	Economy	13600.00
0005432568862	30528	Economy	13600.00
0005432161206	30528	Economy	13600.00
0005432568549	30528	Economy	13600.00
0005434082207	30528	Economy	13600.00
0005434082141	30528	Economy	13600.00
0005432213699	30528	Economy	13600.00
0005434082234	30528	Economy	13600.00
0005432571386	30528	Economy	13600.00
0005432568697	30528	Economy	13600.00
0005435720854	13588	Economy	9900.00
0005435722112	13588	Economy	9900.00
0005435720856	13588	Economy	9900.00
0005435722113	13588	Economy	9900.00
0005435720853	13588	Economy	9900.00
0005435720855	13588	Economy	9900.00
0005435720141	21145	Economy	9900.00
0005435720149	21145	Economy	9900.00
0005435722104	21145	Economy	9900.00
0005432295945	22810	Economy	9700.00
0005432295943	22810	Economy	8800.00
0005432295944	22810	Economy	8800.00
0005433345637	11128	Business	23600.00
0005433345562	11128	Business	23600.00
0005433345580	11128	Business	23600.00
0005433345574	11128	Business	23600.00
0005433345599	11128	Business	23600.00
0005435097440	11128	Business	23600.00
0005433345617	11128	Business	23600.00
0005433345634	11128	Business	23600.00
0005433345609	11128	Business	23600.00
0005435508551	11128	Business	23600.00
0005433345635	11128	Business	23600.00
0005433345638	11128	Business	23600.00
0005433345641	11128	Economy	7900.00
0005433345643	11128	Economy	7900.00
0005433345575	11128	Economy	7900.00
0005435508556	11128	Economy	7900.00
0005435097445	11128	Economy	7900.00
0005433345578	11128	Economy	7900.00
0005433345553	11128	Economy	7900.00
0005435508488	11128	Economy	7900.00
0005433345616	11128	Economy	7900.00
0005433345615	11128	Economy	7900.00
0005433345607	11128	Economy	7900.00
0005433345642	11128	Economy	7900.00
0005433345554	11128	Economy	7900.00
0005433345584	11128	Economy	7900.00
0005433345625	11128	Economy	7900.00
0005435097437	11128	Economy	7900.00
0005433345551	11128	Economy	7900.00
0005433345620	11128	Economy	7900.00
0005435380367	11128	Economy	7900.00
0005433345619	11128	Economy	7900.00
0005433345570	11128	Economy	7900.00
0005433345602	11128	Economy	7900.00
0005433345564	11128	Economy	7900.00
0005435508515	11128	Economy	7900.00
0005433345647	11128	Economy	7900.00
0005435508520	11128	Economy	7900.00
0005433345629	11128	Economy	7900.00
0005433345627	11128	Economy	7900.00
0005433345597	11128	Economy	7900.00
0005433345593	11128	Economy	7900.00
0005433345623	11128	Economy	7900.00
0005435508516	11128	Economy	7900.00
0005433345604	11128	Economy	7900.00
0005433345603	11128	Economy	7900.00
0005433345633	11128	Economy	7900.00
0005433345583	11128	Economy	7900.00
0005433345589	11128	Economy	7900.00
0005433345606	11128	Economy	7900.00
0005435508541	11128	Economy	7900.00
0005435508553	11128	Economy	8600.00
0005435097443	11128	Economy	7900.00
0005433345561	11128	Economy	8600.00
0005435097442	11128	Economy	8600.00
0005435097444	11128	Economy	8600.00
0005433345590	11128	Economy	8600.00
0005435380363	11128	Economy	8600.00
0005433345640	11128	Economy	7900.00
0005433345636	11128	Economy	7900.00
0005433345566	11128	Economy	7900.00
0005433345559	11128	Economy	7900.00
0005433345631	11128	Economy	7900.00
0005433345552	11128	Economy	7900.00
0005433345556	11128	Economy	7900.00
0005435508496	11128	Economy	7900.00
0005433345644	11128	Economy	7900.00
0005435508529	11128	Economy	7900.00
0005433345577	11128	Economy	7900.00
0005435508554	11128	Economy	7900.00
0005433345598	11128	Economy	7900.00
0005433345576	11128	Economy	7900.00
0005433345585	11128	Economy	7900.00
0005433345591	11128	Economy	7900.00
0005435508481	11128	Economy	7900.00
0005433345624	11128	Economy	7900.00
0005433345613	11128	Economy	7900.00
0005435508557	11128	Economy	7900.00
0005433345563	11128	Economy	7900.00
0005435097441	11128	Economy	7900.00
0005433345557	11128	Economy	7900.00
0005433345555	11128	Economy	7900.00
0005433345639	11128	Economy	7900.00
0005433345586	11128	Economy	7900.00
0005433345588	11128	Economy	7900.00
0005433345582	11128	Economy	7900.00
0005435508482	11128	Economy	7900.00
0005435508514	11128	Economy	7900.00
0005433345626	11128	Economy	7900.00
0005433345572	11128	Economy	7900.00
0005433345600	11128	Economy	7900.00
0005433345567	11128	Economy	7900.00
0005433345596	11128	Economy	7900.00
0005433345632	11128	Economy	7900.00
0005435380388	11128	Economy	7900.00
0005435508527	11128	Economy	7900.00
0005433345608	11128	Economy	7900.00
0005433345621	11128	Economy	7900.00
0005433345595	11128	Economy	7900.00
0005433345612	11128	Economy	7900.00
0005433345571	11128	Economy	7900.00
0005435508535	11128	Economy	7900.00
0005433345646	11128	Economy	7900.00
0005433345592	11128	Economy	7900.00
0005433345573	11128	Economy	7900.00
0005433345587	11128	Economy	7900.00
0005433345628	11128	Economy	7900.00
0005433345645	11128	Economy	7900.00
0005433345630	11128	Economy	7900.00
0005433345601	11128	Economy	7900.00
0005433345614	11128	Economy	7900.00
0005433345610	11128	Economy	7900.00
0005433345618	11128	Economy	7900.00
0005433345605	11128	Economy	7900.00
0005435097439	11128	Economy	7900.00
0005435097446	11128	Economy	7900.00
0005433345560	11128	Economy	7900.00
0005435508528	11128	Economy	7900.00
0005433345594	11128	Economy	7900.00
0005433345569	11128	Economy	7900.00
0005433345565	11128	Economy	7900.00
0005433345558	11128	Economy	7900.00
0005433345611	11128	Economy	7900.00
0005433345579	11128	Economy	7900.00
0005433345581	11128	Economy	7900.00
0005435508536	11128	Economy	7900.00
0005435508540	11128	Economy	7900.00
0005435097438	11128	Economy	7900.00
0005433345622	11128	Economy	7900.00
0005433345568	11128	Economy	7900.00
0005433344285	17103	Business	23600.00
0005433344508	17103	Business	23600.00
0005433344671	17103	Business	23600.00
0005433344444	17103	Business	23600.00
0005433344634	17103	Business	23600.00
0005433344437	17103	Business	23600.00
0005433344651	17103	Business	23600.00
0005433344146	17103	Business	23600.00
0005433344816	17103	Business	23600.00
0005433344782	17103	Business	23600.00
0005435097358	17103	Business	23600.00
0005433344432	17103	Business	23600.00
0005433344413	17103	Economy	7900.00
0005435097334	17103	Economy	7900.00
0005433344906	17103	Economy	7900.00
0005433344580	17103	Economy	7900.00
0005433344498	17103	Economy	7900.00
0005433344599	17103	Economy	7900.00
0005433344761	17103	Economy	7900.00
0005435097331	17103	Economy	7900.00
0005433344254	17103	Economy	7900.00
0005433344412	17103	Economy	7900.00
0005433344688	17103	Economy	7900.00
0005433344637	17103	Economy	7900.00
0005433344441	17103	Economy	7900.00
0005433344288	17103	Economy	7900.00
0005433344027	17103	Economy	7900.00
0005433345152	17103	Economy	7900.00
0005433344648	17103	Economy	7900.00
0005433344488	17103	Economy	7900.00
0005433344546	17103	Economy	7900.00
0005433344879	17103	Economy	7900.00
0005433344724	17103	Economy	7900.00
0005433344687	17103	Economy	7900.00
0005435097336	17103	Economy	7900.00
0005433344776	17103	Economy	7900.00
0005433344772	17103	Economy	7900.00
0005435097329	17103	Economy	7900.00
0005433344338	17103	Economy	7900.00
0005433344236	17103	Economy	7900.00
0005433345050	17103	Economy	7900.00
0005433344640	17103	Economy	7900.00
0005433344743	17103	Economy	7900.00
0005433344430	17103	Economy	7900.00
0005435097330	17103	Economy	7900.00
0005433344320	17103	Economy	7900.00
0005433344589	17103	Economy	7900.00
0005433344382	17103	Economy	7900.00
0005433344600	17103	Economy	7900.00
0005433344844	17103	Economy	7900.00
0005433344907	17103	Economy	7900.00
0005433344502	17103	Economy	7900.00
0005433344880	17103	Economy	8600.00
0005433344710	17103	Economy	8600.00
0005433344920	17103	Economy	8600.00
0005433344287	17103	Economy	8600.00
0005433344440	17103	Economy	8600.00
0005433344532	17103	Economy	8600.00
0005432293268	17103	Economy	7900.00
0005433344319	17103	Economy	7900.00
0005435097366	17103	Economy	7900.00
0005433344581	17103	Economy	7900.00
0005433344566	17103	Economy	7900.00
0005433344830	17103	Economy	7900.00
0005433344693	17103	Economy	7900.00
0005433344438	17103	Economy	7900.00
0005433344829	17103	Economy	7900.00
0005433344433	17103	Economy	7900.00
0005433344809	17103	Economy	7900.00
0005433344286	17103	Economy	7900.00
0005433344526	17103	Economy	7900.00
0005433344612	17103	Economy	7900.00
0005433344760	17103	Economy	7900.00
0005433344674	17103	Economy	7900.00
0005433344783	17103	Economy	7900.00
0005433344054	17103	Economy	7900.00
0005433344579	17103	Economy	7900.00
0005433344667	17103	Economy	7900.00
0005433344775	17103	Economy	7900.00
0005433345049	17103	Economy	7900.00
0005433345052	17103	Economy	7900.00
0005433344487	17103	Economy	7900.00
0005433344516	17103	Economy	7900.00
0005433344921	17103	Economy	7900.00
0005433344292	17103	Economy	7900.00
0005433344588	17103	Economy	7900.00
0005433344649	17103	Economy	7900.00
0005433344315	17103	Economy	7900.00
0005433344956	17103	Economy	7900.00
0005433344235	17103	Economy	7900.00
0005435097335	17103	Economy	7900.00
0005433344904	17103	Economy	7900.00
0005433344528	17103	Economy	7900.00
0005433344453	17103	Economy	7900.00
0005433344411	17103	Economy	7900.00
0005433344399	17103	Economy	7900.00
0005433344825	17103	Economy	7900.00
0005433344056	17103	Economy	7900.00
0005433344922	17103	Economy	7900.00
0005433344641	17103	Economy	7900.00
0005433344535	17103	Economy	7900.00
0005433344533	17103	Economy	7900.00
0005433344984	17103	Economy	7900.00
0005433344443	17103	Economy	7900.00
0005433344527	17103	Economy	7900.00
0005432293266	17103	Economy	7900.00
0005433344489	17103	Economy	7900.00
0005433344062	17103	Economy	7900.00
0005432293267	17103	Economy	7900.00
0005433344166	17103	Economy	7900.00
0005433344497	17103	Economy	7900.00
0005433344431	17103	Economy	7900.00
0005433344061	17103	Economy	7900.00
0005433344831	17103	Economy	7900.00
0005433344660	17103	Economy	7900.00
0005433344878	17103	Economy	7900.00
0005433344578	17103	Economy	7900.00
0005433344234	17103	Economy	7900.00
0005433344515	17103	Economy	7900.00
0005433344293	17103	Economy	7900.00
0005433344026	17103	Economy	7900.00
0005433344534	17103	Economy	7900.00
0005433344055	17103	Economy	7900.00
0005433344591	17103	Economy	7900.00
0005435097351	17103	Economy	7900.00
0005433344952	17103	Economy	7900.00
0005435097352	17103	Economy	7900.00
0005433344620	17103	Economy	7900.00
0005433344590	17103	Economy	7900.00
0005433344454	17103	Economy	7900.00
0005433507644	9081	Business	26600.00
0005433507642	9081	Business	26600.00
0005433507636	9081	Business	26600.00
0005433507625	9081	Business	26600.00
0005433477103	9081	Business	26600.00
0005433481359	9081	Business	26600.00
0005432920163	9081	Business	26600.00
0005433507634	9081	Business	26600.00
0005433481360	9081	Business	26600.00
0005433477107	9081	Business	26600.00
0005432920148	9081	Economy	8900.00
0005433507627	9081	Economy	8900.00
0005433481356	9081	Economy	8900.00
0005433477118	9081	Economy	8900.00
0005433477096	9081	Economy	8900.00
0005433477104	9081	Economy	8900.00
0005433477101	9081	Economy	8900.00
0005433477114	9081	Economy	8900.00
0005433477119	9081	Economy	8900.00
0005433507635	9081	Economy	9800.00
0005433507641	9081	Economy	9800.00
0005432920291	9081	Economy	9800.00
0005433507623	9081	Economy	8900.00
0005432920133	9081	Economy	8900.00
0005433477093	9081	Economy	8900.00
0005433507628	9081	Economy	8900.00
0005432920149	9081	Economy	8900.00
0005432920087	9081	Economy	8900.00
0005433477112	9081	Economy	8900.00
0005433477092	9081	Economy	8900.00
0005432920232	9081	Economy	8900.00
0005432920095	9081	Economy	8900.00
0005433507630	9081	Economy	8900.00
0005433477113	9081	Economy	8900.00
0005433481358	9081	Economy	8900.00
0005433477109	9081	Economy	8900.00
0005433477098	9081	Economy	8900.00
0005432920206	9081	Economy	8900.00
0005433507638	9081	Economy	8900.00
0005432920167	9081	Economy	8900.00
0005432920236	9081	Economy	8900.00
0005433477095	9081	Economy	8900.00
0005433477111	9081	Economy	8900.00
0005433477099	9081	Economy	8900.00
0005433481354	9081	Economy	8900.00
0005433477108	9081	Economy	8900.00
0005433507631	9081	Economy	8900.00
0005433481355	9081	Economy	8900.00
0005433477117	9081	Economy	8900.00
0005432920147	9081	Economy	8900.00
0005432920139	9081	Economy	8900.00
0005433507633	9081	Economy	8900.00
0005433477102	9081	Economy	8900.00
0005433507626	9081	Economy	8900.00
0005433481357	9081	Economy	8900.00
0005433477094	9081	Economy	8900.00
0005433507639	9081	Economy	8900.00
0005432920160	9081	Economy	8900.00
0005433507640	9081	Economy	8900.00
0005432920159	9081	Economy	8900.00
0005433477106	9081	Economy	8900.00
0005433507632	9081	Economy	8900.00
0005433477116	9081	Economy	8900.00
0005433507643	9081	Economy	8900.00
0005432920140	9081	Economy	8900.00
0005433477100	9081	Economy	8900.00
0005433507624	9081	Economy	8900.00
0005433507629	9081	Economy	8900.00
0005433477097	9081	Economy	8900.00
0005433477115	9081	Economy	8900.00
0005433477110	9081	Economy	8900.00
0005433477105	9081	Economy	8900.00
0005433507637	9081	Economy	8900.00
0005432920274	9081	Economy	8900.00
0005432920237	9081	Economy	8900.00
0005432920386	20447	Business	26600.00
0005432920388	20447	Business	26600.00
0005432920399	20447	Business	26600.00
0005432920380	20447	Business	26600.00
0005433507478	20447	Business	26600.00
0005433507481	20447	Business	26600.00
0005432920393	20447	Economy	8900.00
0005433507407	20447	Economy	8900.00
0005433507486	20447	Economy	8900.00
0005432920397	20447	Economy	8900.00
0005432920384	20447	Economy	8900.00
0005433507392	20447	Economy	9800.00
0005433507494	20447	Economy	9800.00
0005433507495	20447	Economy	8900.00
0005433507447	20447	Economy	8900.00
0005432920396	20447	Economy	8900.00
0005432920395	20447	Economy	8900.00
0005433507480	20447	Economy	8900.00
0005433507475	20447	Economy	8900.00
0005432920379	20447	Economy	8900.00
0005433507477	20447	Economy	8900.00
0005432920394	20447	Economy	8900.00
0005432920391	20447	Economy	8900.00
0005432920390	20447	Economy	8900.00
0005432920382	20447	Economy	8900.00
0005433507458	20447	Economy	8900.00
0005432920392	20447	Economy	8900.00
0005433507435	20447	Economy	8900.00
0005433481321	20447	Economy	8900.00
0005433507500	20447	Economy	8900.00
0005433507484	20447	Economy	8900.00
0005432920387	20447	Economy	8900.00
0005433481259	20447	Economy	8900.00
0005432920385	20447	Economy	8900.00
0005433507485	20447	Economy	8900.00
0005432920381	20447	Economy	8900.00
0005432920389	20447	Economy	8900.00
0005432920398	20447	Economy	8900.00
0005432920383	20447	Economy	8900.00
0005433507450	20447	Economy	8900.00
0005432394201	10198	Economy	5800.00
0005432396337	10198	Economy	5800.00
0005432396335	10198	Economy	5800.00
0005432396334	10198	Economy	5800.00
0005432396336	10198	Economy	5800.00
0005432394200	10198	Economy	5800.00
0005432394198	10198	Economy	5800.00
0005432394199	10198	Economy	5800.00
0005435179700	10198	Economy	5800.00
0005432400201	18306	Economy	5800.00
0005432400186	18306	Economy	5800.00
0005432396308	18306	Economy	5800.00
0005432400179	18306	Economy	5800.00
0005432396307	18306	Economy	5800.00
0005435179419	18306	Economy	5800.00
0005435179418	18306	Economy	5800.00
0005432396309	18306	Economy	5800.00
0005435179710	18306	Economy	5800.00
0005435126850	11034	Business	9500.00
0005435626496	11034	Business	9500.00
0005434928369	11034	Business	9500.00
0005435127067	11034	Business	9500.00
0005435626476	11034	Business	9500.00
0005435626466	11034	Business	9500.00
0005435626442	11034	Business	9500.00
0005435126888	11034	Economy	3200.00
0005435626465	11034	Economy	3200.00
0005435126931	11034	Economy	3200.00
0005435556730	11034	Economy	3200.00
0005435127190	11034	Economy	3200.00
0005435626488	11034	Economy	3200.00
0005434411883	11034	Economy	3200.00
0005435626487	11034	Economy	3200.00
0005435626497	11034	Economy	3200.00
0005434928370	11034	Economy	3200.00
0005435126986	11034	Economy	3500.00
0005435126947	11034	Economy	3500.00
0005435126963	11034	Economy	3500.00
0005435127023	11034	Economy	3500.00
0005435126924	11034	Economy	3200.00
0005435126962	11034	Economy	3200.00
0005435626414	11034	Economy	3200.00
0005435626491	11034	Economy	3200.00
0005434411886	11034	Economy	3200.00
0005435127003	11034	Economy	3200.00
0005435626495	11034	Economy	3200.00
0005435554256	11034	Economy	3200.00
0005435126928	11034	Economy	3200.00
0005435126925	11034	Economy	3200.00
0005435126927	11034	Economy	3200.00
0005434411884	11034	Economy	3200.00
0005434928371	11034	Economy	3200.00
0005435126889	11034	Economy	3200.00
0005434411885	11034	Economy	3200.00
0005435554263	11034	Economy	3200.00
0005435126952	11034	Economy	3200.00
0005435626482	11034	Economy	3200.00
0005435127055	11034	Economy	3200.00
0005435626408	11034	Economy	3200.00
0005435626357	11034	Economy	3200.00
0005435127109	11034	Economy	3200.00
0005435554260	11034	Economy	3200.00
0005435127071	11034	Economy	3200.00
0005435127068	11034	Economy	3200.00
0005435626449	11034	Economy	3200.00
0005435554264	11034	Economy	3200.00
0005435626480	11034	Economy	3200.00
0005435126999	11034	Economy	3200.00
0005435626463	11034	Economy	3200.00
0005435126932	11034	Economy	3200.00
0005435626436	11034	Economy	3200.00
0005435626464	11034	Economy	3200.00
0005435626481	11034	Economy	3200.00
0005435126881	11034	Economy	3200.00
0005435626477	11034	Economy	3200.00
0005435127022	11034	Economy	3200.00
0005435626448	11034	Economy	3200.00
0005435626428	11034	Economy	3200.00
0005435126882	11034	Economy	3200.00
0005435626506	11034	Economy	3200.00
0005435626443	11034	Economy	3200.00
0005435626505	11034	Economy	3200.00
0005435626444	11034	Economy	3200.00
0005434411882	11034	Economy	3200.00
0005435127369	14661	Business	9500.00
0005435127382	14661	Business	9500.00
0005435626623	14661	Business	9500.00
0005435127373	14661	Business	9500.00
0005435127358	14661	Business	9500.00
0005435127389	14661	Business	9500.00
0005435127357	14661	Business	9500.00
0005435127367	14661	Business	9500.00
0005435626629	14661	Business	9500.00
0005435626624	14661	Business	9500.00
0005435127390	14661	Economy	3200.00
0005435626634	14661	Economy	3200.00
0005435127384	14661	Economy	3200.00
0005434411848	14661	Economy	3200.00
0005435626626	14661	Economy	3200.00
0005435127386	14661	Economy	3200.00
0005435127364	14661	Economy	3200.00
0005435127392	14661	Economy	3200.00
0005435554303	14661	Economy	3200.00
0005435127393	14661	Economy	3500.00
0005435127365	14661	Economy	3500.00
0005435554305	14661	Economy	3500.00
0005435127353	14661	Economy	3500.00
0005435554304	14661	Economy	3200.00
0005435556755	14661	Economy	3200.00
0005435554300	14661	Economy	3200.00
0005435554302	14661	Economy	3200.00
0005435127355	14661	Economy	3200.00
0005435127354	14661	Economy	3200.00
0005435127356	14661	Economy	3200.00
0005435127361	14661	Economy	3200.00
0005435127359	14661	Economy	3200.00
0005434928354	14661	Economy	3200.00
0005435127363	14661	Economy	3200.00
0005434411849	14661	Economy	3200.00
0005435127387	14661	Economy	3200.00
0005434411837	14661	Economy	3200.00
0005435626639	14661	Economy	3200.00
0005434928338	14661	Economy	3200.00
0005435556757	14661	Economy	3200.00
0005435127372	14661	Economy	3200.00
0005435127379	14661	Economy	3200.00
0005435127377	14661	Economy	3200.00
0005435127370	14661	Economy	3200.00
0005435556754	14661	Economy	3200.00
0005435127383	14661	Economy	3200.00
0005435626632	14661	Economy	3200.00
0005435127385	14661	Economy	3200.00
0005435626631	14661	Economy	3200.00
0005435626635	14661	Economy	3200.00
0005435127391	14661	Economy	3200.00
0005435127371	14661	Economy	3200.00
0005435127352	14661	Economy	3200.00
0005435127368	14661	Economy	3200.00
0005434411853	14661	Economy	3200.00
0005435127378	14661	Economy	3200.00
0005435626630	14661	Economy	3200.00
0005435626638	14661	Economy	3200.00
0005435127388	14661	Economy	3200.00
0005435626640	14661	Economy	3200.00
0005435127381	14661	Economy	3200.00
0005435127375	14661	Economy	3200.00
0005435127360	14661	Economy	3200.00
0005435127380	14661	Economy	3200.00
0005435626633	14661	Economy	3200.00
0005435556756	14661	Economy	3200.00
0005435626636	14661	Economy	3200.00
0005435626627	14661	Economy	3200.00
0005435127374	14661	Economy	3200.00
0005435127362	14661	Economy	3200.00
0005435626628	14661	Economy	3200.00
0005435127376	14661	Economy	3200.00
0005435626637	14661	Economy	3200.00
0005435127366	14661	Economy	3200.00
0005435626625	14661	Economy	3200.00
0005435554301	14661	Economy	3200.00
0005435443460	7134	Business	86900.00
0005435715886	7134	Business	86900.00
0005435715897	7134	Business	86900.00
0005435443469	7134	Business	86900.00
0005435178521	7134	Business	86900.00
0005435219235	7134	Business	86900.00
0005432398285	7134	Business	86900.00
0005432398288	7134	Economy	29000.00
0005435443501	7134	Economy	29000.00
0005435443476	7134	Economy	29000.00
0005435216617	7134	Economy	29000.00
0005435443450	7134	Economy	29000.00
0005432398286	7134	Economy	31900.00
0005435178513	7134	Economy	31900.00
0005435443462	7134	Economy	31900.00
0005435216608	7134	Economy	29000.00
0005432400215	7134	Economy	29000.00
0005435443440	7134	Economy	29000.00
0005435715892	7134	Economy	29000.00
0005435715884	7134	Economy	29000.00
0005432398287	7134	Economy	29000.00
0005432400214	7134	Economy	29000.00
0005435219232	7134	Economy	29000.00
0005435715893	7134	Economy	29000.00
0005435443451	7134	Economy	29000.00
0005435443436	7134	Economy	29000.00
0005435715891	7134	Economy	29000.00
0005435443466	7134	Economy	29000.00
0005435178512	7134	Economy	29000.00
0005435443443	7134	Economy	29000.00
0005435219234	7134	Economy	29000.00
0005432398289	7134	Economy	29000.00
0005435715889	7134	Economy	29000.00
0005435715896	7134	Economy	29000.00
0005435715890	7134	Economy	29000.00
0005435715888	7134	Economy	29000.00
0005432400213	7134	Economy	29000.00
0005435715894	7134	Economy	29000.00
0005435219240	7134	Economy	29000.00
0005435443447	7134	Economy	29000.00
0005435216609	7134	Economy	29000.00
0005435443468	7134	Economy	29000.00
0005435443459	7134	Economy	29000.00
0005435715882	7134	Economy	29000.00
0005435715883	7134	Economy	29000.00
0005435715895	7134	Economy	29000.00
0005435443465	7134	Economy	29000.00
0005435443448	7134	Economy	29000.00
0005435715885	7134	Economy	29000.00
0005435443470	7134	Economy	29000.00
0005435715887	7134	Economy	29000.00
0005435179013	27063	Business	86900.00
0005435443541	27063	Business	86900.00
0005432398264	27063	Business	86900.00
0005435443544	27063	Economy	29000.00
0005435715745	27063	Economy	29000.00
0005435179012	27063	Economy	29000.00
0005432398226	27063	Economy	29000.00
0005435715781	27063	Economy	29000.00
0005435715746	27063	Economy	31900.00
0005435715738	27063	Economy	31900.00
0005435715798	27063	Economy	29000.00
0005432394176	27063	Economy	29000.00
0005435715638	27063	Economy	29000.00
0005432394177	27063	Economy	29000.00
0005435443547	27063	Economy	29000.00
0005435715791	27063	Economy	29000.00
0005435443548	27063	Economy	29000.00
0005435715790	27063	Economy	29000.00
0005435715786	27063	Economy	29000.00
0005432398263	27063	Economy	29000.00
0005435443545	27063	Economy	29000.00
0005435715739	27063	Economy	29000.00
0005435715780	27063	Economy	29000.00
0005435715676	27063	Economy	29000.00
0005432398240	27063	Economy	29000.00
0005435715769	27063	Economy	29000.00
0005435443542	27063	Economy	29000.00
0005435179014	27063	Economy	29000.00
0005435715656	27063	Economy	29000.00
0005432394159	27063	Economy	29000.00
0005435715770	27063	Economy	29000.00
0005435443549	27063	Economy	29000.00
0005435443543	27063	Economy	29000.00
0005435443546	27063	Economy	29000.00
0005434085043	2727	Economy	7700.00
0005434085045	2727	Economy	7700.00
0005434085047	2727	Economy	7700.00
0005434085046	2727	Economy	7700.00
0005434085044	2727	Economy	7700.00
0005433060461	2727	Economy	7700.00
0005434085007	28525	Economy	7700.00
0005433060479	28525	Economy	7700.00
0005434085005	28525	Economy	7700.00
0005434085002	28525	Economy	7700.00
0005434084992	28525	Economy	7700.00
0005433060480	28525	Economy	7700.00
0005434085004	28525	Economy	7700.00
0005434085014	28525	Economy	7700.00
0005432632893	25197	Economy	29000.00
0005432632896	25197	Economy	29000.00
0005432632892	25197	Economy	29000.00
0005435844378	25197	Economy	29000.00
0005432632883	25197	Economy	26400.00
0005432632882	25197	Economy	26400.00
0005435844357	25197	Economy	26400.00
0005432632886	25197	Economy	26400.00
0005432632889	25197	Economy	26400.00
0005435844364	25197	Economy	26400.00
0005435844355	25197	Economy	26400.00
0005432632900	25197	Economy	26400.00
0005432632881	25197	Economy	26400.00
0005435844371	25197	Economy	26400.00
0005435844342	25197	Economy	26400.00
0005432632891	25197	Economy	26400.00
0005432632890	25197	Economy	26400.00
0005435844372	25197	Economy	26400.00
0005432632898	25197	Economy	26400.00
0005432632899	25197	Economy	26400.00
0005432632888	25197	Economy	26400.00
0005432632884	25197	Economy	26400.00
0005432632894	25197	Economy	26400.00
0005432632885	25197	Economy	26400.00
0005432632897	25197	Economy	26400.00
0005435844368	25197	Economy	26400.00
0005435844367	25197	Economy	26400.00
0005435844373	25197	Economy	26400.00
0005432632901	25197	Economy	26400.00
0005432632895	25197	Economy	26400.00
0005435844354	25197	Economy	26400.00
0005435844365	25197	Economy	26400.00
0005432632902	25197	Economy	26400.00
0005435844338	25197	Economy	26400.00
0005432632887	25197	Economy	26400.00
0005435844419	28164	Economy	29000.00
0005435844414	28164	Economy	29000.00
0005432632811	28164	Economy	29000.00
0005432632837	28164	Economy	26400.00
0005432632816	28164	Economy	26400.00
0005432632845	28164	Economy	26400.00
0005435844409	28164	Economy	26400.00
0005432632835	28164	Economy	26400.00
0005435844411	28164	Economy	26400.00
0005432632841	28164	Economy	26400.00
0005435844418	28164	Economy	26400.00
0005435844408	28164	Economy	26400.00
0005432632834	28164	Economy	26400.00
0005432632865	28164	Economy	26400.00
0005435844417	28164	Economy	26400.00
0005435844416	28164	Economy	26400.00
0005432632823	28164	Economy	26400.00
0005435844410	28164	Economy	26400.00
0005435844415	28164	Economy	26400.00
0005432632815	28164	Economy	26400.00
0005432632873	28164	Economy	26400.00
0005432632805	28164	Economy	26400.00
0005435844413	28164	Economy	26400.00
0005432632810	28164	Economy	26400.00
0005435844412	28164	Economy	26400.00
0005432632824	28164	Economy	26400.00
0005432632808	28164	Economy	26400.00
0005432632857	28164	Economy	26400.00
0005435541320	11366	Business	20200.00
0005435541306	11366	Business	20200.00
0005435541423	11366	Business	20200.00
0005435518125	11366	Business	20200.00
0005435518178	11366	Business	20200.00
0005435541360	11366	Business	20200.00
0005435541442	11366	Business	20200.00
0005435541297	11366	Economy	6700.00
0005435518218	11366	Economy	6700.00
0005435518217	11366	Economy	6700.00
0005435541443	11366	Economy	7400.00
0005435518206	11366	Economy	7400.00
0005435541362	11366	Economy	7400.00
0005435541396	11366	Economy	6700.00
0005435518170	11366	Economy	6700.00
0005435518156	11366	Economy	6700.00
0005435518169	11366	Economy	6700.00
0005435518234	11366	Economy	6700.00
0005435518167	11366	Economy	6700.00
0005435541392	11366	Economy	6700.00
0005435518177	11366	Economy	6700.00
0005435518180	11366	Economy	6700.00
0005435518166	11366	Economy	6700.00
0005435518233	11366	Economy	6700.00
0005435518168	11366	Economy	6700.00
0005435518221	11366	Economy	6700.00
0005435541345	11366	Economy	6700.00
0005435518187	11366	Economy	6700.00
0005435541319	11366	Economy	6700.00
0005435541422	11366	Economy	6700.00
0005435541305	11366	Economy	6700.00
0005435518219	11366	Economy	6700.00
0005435541296	11366	Economy	6700.00
0005435541326	11366	Economy	6700.00
0005435518190	11366	Economy	6700.00
0005435518268	11366	Economy	6700.00
0005435518179	11366	Economy	6700.00
0005435518155	11366	Economy	6700.00
0005435541329	11366	Economy	6700.00
0005435541330	11366	Economy	6700.00
0005435518215	11366	Economy	6700.00
0005435518269	11366	Economy	6700.00
0005435518231	11366	Economy	6700.00
0005435541397	11366	Economy	6700.00
0005435529787	22244	Business	20200.00
0005435530076	22244	Business	20200.00
0005435541516	22244	Business	20200.00
0005435541520	22244	Business	20200.00
0005435541510	22244	Business	20200.00
0005435529776	22244	Business	20200.00
0005435529781	22244	Business	20200.00
0005435541526	22244	Economy	6700.00
0005435530067	22244	Economy	6700.00
0005435529766	22244	Economy	6700.00
0005435541523	22244	Economy	6700.00
0005435541517	22244	Economy	6700.00
0005435530080	22244	Economy	6700.00
0005435530069	22244	Economy	6700.00
0005435541527	22244	Economy	7400.00
0005435530071	22244	Economy	7400.00
0005435529783	22244	Economy	7400.00
0005435530077	22244	Economy	7400.00
0005435530074	22244	Economy	6700.00
0005435529784	22244	Economy	6700.00
0005435541528	22244	Economy	6700.00
0005435529777	22244	Economy	6700.00
0005435529767	22244	Economy	6700.00
0005435541524	22244	Economy	6700.00
0005435529768	22244	Economy	6700.00
0005435541525	22244	Economy	6700.00
0005435529772	22244	Economy	6700.00
0005435541512	22244	Economy	6700.00
0005435530062	22244	Economy	6700.00
0005432294545	22244	Economy	6700.00
0005435541518	22244	Economy	6700.00
0005435529778	22244	Economy	6700.00
0005435530072	22244	Economy	6700.00
0005435530083	22244	Economy	6700.00
0005435541513	22244	Economy	6700.00
0005435530065	22244	Economy	6700.00
0005435529765	22244	Economy	6700.00
0005432294544	22244	Economy	6700.00
0005435530075	22244	Economy	6700.00
0005435541529	22244	Economy	6700.00
0005435529774	22244	Economy	6700.00
0005435529779	22244	Economy	6700.00
0005435529780	22244	Economy	6700.00
0005435541515	22244	Economy	6700.00
0005435541522	22244	Economy	6700.00
0005435530082	22244	Economy	6700.00
0005435530078	22244	Economy	6700.00
0005435541530	22244	Economy	6700.00
0005435541509	22244	Economy	6700.00
0005435530066	22244	Economy	6700.00
0005435541521	22244	Economy	6700.00
0005435529771	22244	Economy	6700.00
0005435530079	22244	Economy	6700.00
0005435530063	22244	Economy	6700.00
0005435529786	22244	Economy	6700.00
0005435530081	22244	Economy	6700.00
0005435529775	22244	Economy	6700.00
0005435529785	22244	Economy	6700.00
0005435541531	22244	Economy	6700.00
0005435529782	22244	Economy	6700.00
0005435529773	22244	Economy	6700.00
0005435530073	22244	Economy	6700.00
0005435541532	22244	Economy	6700.00
0005435541514	22244	Economy	6700.00
0005435530064	22244	Economy	6700.00
0005435541519	22244	Economy	6700.00
0005435541511	22244	Economy	6700.00
0005432294543	22244	Economy	6700.00
0005435529770	22244	Economy	6700.00
0005435529769	22244	Economy	6700.00
0005435530070	22244	Economy	6700.00
0005435530068	22244	Economy	6700.00
0005434908576	2285	Business	20200.00
0005434908608	2285	Business	20200.00
0005434908585	2285	Business	20200.00
0005434908597	2285	Business	20200.00
0005434908560	2285	Business	20200.00
0005434908575	2285	Business	20200.00
0005434908603	2285	Business	20200.00
0005433252049	2285	Business	20200.00
0005434908605	2285	Business	20200.00
0005433251920	2285	Business	20200.00
0005433252044	2285	Business	20200.00
0005433252046	2285	Business	20200.00
0005434908594	2285	Economy	6700.00
0005434908573	2285	Economy	6700.00
0005433252007	2285	Economy	6700.00
0005433252006	2285	Economy	6700.00
0005434908569	2285	Economy	6700.00
0005433252028	2285	Economy	6700.00
0005434908581	2285	Economy	6700.00
0005433251919	2285	Economy	6700.00
0005434908574	2285	Economy	6700.00
0005433251945	2285	Economy	6700.00
0005434908609	2285	Economy	7400.00
0005434908598	2285	Economy	7400.00
0005434908607	2285	Economy	7400.00
0005434908562	2285	Economy	7400.00
0005433252050	2285	Economy	7400.00
0005434908604	2285	Economy	6700.00
0005434908593	2285	Economy	6700.00
0005434908563	2285	Economy	6700.00
0005433252043	2285	Economy	6700.00
0005433252011	2285	Economy	6700.00
0005434908582	2285	Economy	6700.00
0005434908590	2285	Economy	6700.00
0005434908599	2285	Economy	6700.00
0005434908606	2285	Economy	6700.00
0005434908565	2285	Economy	6700.00
0005433252097	2285	Economy	6700.00
0005434908586	2285	Economy	6700.00
0005434908568	2285	Economy	6700.00
0005434908580	2285	Economy	6700.00
0005434908567	2285	Economy	6700.00
0005434908553	2285	Economy	6700.00
0005434908588	2285	Economy	6700.00
0005434908591	2285	Economy	6700.00
0005434908559	2285	Economy	6700.00
0005433251987	2285	Economy	6700.00
0005433252055	2285	Economy	6700.00
0005434908552	2285	Economy	6700.00
0005434908584	2285	Economy	6700.00
0005433252088	2285	Economy	6700.00
0005434908557	2285	Economy	6700.00
0005434908592	2285	Economy	6700.00
0005433252056	2285	Economy	6700.00
0005433251942	2285	Economy	6700.00
0005434908554	2285	Economy	6700.00
0005434908610	2285	Economy	6700.00
0005434908561	2285	Economy	6700.00
0005434908596	2285	Economy	6700.00
0005433251963	2285	Economy	6700.00
0005434908587	2285	Economy	6700.00
0005433251886	2285	Economy	6700.00
0005433252082	2285	Economy	6700.00
0005434908555	2285	Economy	6700.00
0005434908556	2285	Economy	6700.00
0005433251904	2285	Economy	6700.00
0005433252081	2285	Economy	6700.00
0005433252047	2285	Economy	6700.00
0005433252034	2285	Economy	6700.00
0005433252051	2285	Economy	6700.00
0005433252087	2285	Economy	6700.00
0005433251903	2285	Economy	6700.00
0005434908595	2285	Economy	6700.00
0005433251940	2285	Economy	6700.00
0005434908612	2285	Economy	6700.00
0005434908572	2285	Economy	6700.00
0005433252052	2285	Economy	6700.00
0005434908551	2285	Economy	6700.00
0005434908564	2285	Economy	6700.00
0005434908570	2285	Economy	6700.00
0005433252048	2285	Economy	6700.00
0005433252132	2285	Economy	6700.00
0005434908589	2285	Economy	6700.00
0005433252057	2285	Economy	6700.00
0005434908579	2285	Economy	6700.00
0005434908583	2285	Economy	6700.00
0005434908571	2285	Economy	6700.00
0005434908601	2285	Economy	6700.00
0005434908602	2285	Economy	6700.00
0005434908578	2285	Economy	6700.00
0005434908558	2285	Economy	6700.00
0005433251964	2285	Economy	6700.00
0005434908611	2285	Economy	6700.00
0005433251941	2285	Economy	6700.00
0005434908577	2285	Economy	6700.00
0005434908600	2285	Economy	6700.00
0005434908566	2285	Economy	6700.00
0005434908094	25574	Business	20200.00
0005434908085	25574	Business	20200.00
0005434908108	25574	Business	20200.00
0005433252236	25574	Business	20200.00
0005434907934	25574	Business	20200.00
0005434908185	25574	Business	20200.00
0005434908273	25574	Business	20200.00
0005433252232	25574	Business	20200.00
0005434908063	25574	Business	20200.00
0005434908047	25574	Business	20200.00
0005433252233	25574	Business	20200.00
0005433252250	25574	Economy	6700.00
0005433252244	25574	Economy	6700.00
0005434908049	25574	Economy	6700.00
0005433252252	25574	Economy	6700.00
0005434908184	25574	Economy	6700.00
0005434908069	25574	Economy	6700.00
0005434908120	25574	Economy	6700.00
0005434908199	25574	Economy	6700.00
0005433252225	25574	Economy	6700.00
0005434908243	25574	Economy	7400.00
0005433252227	25574	Economy	7400.00
0005433252248	25574	Economy	7400.00
0005434907946	25574	Economy	7400.00
0005434908222	25574	Economy	7400.00
0005434908213	25574	Economy	6700.00
0005433401058	25574	Economy	6700.00
0005433252251	25574	Economy	6700.00
0005434908058	25574	Economy	6700.00
0005433252249	25574	Economy	6700.00
0005433252246	25574	Economy	6700.00
0005433252235	25574	Economy	6700.00
0005434908151	25574	Economy	6700.00
0005434907888	25574	Economy	6700.00
0005433401059	25574	Economy	6700.00
0005434907947	25574	Economy	6700.00
0005433252231	25574	Economy	6700.00
0005434908157	25574	Economy	6700.00
0005434907783	25574	Economy	6700.00
0005434907849	25574	Economy	6700.00
0005433252230	25574	Economy	6700.00
0005434908034	25574	Economy	6700.00
0005434908032	25574	Economy	6700.00
0005433252228	25574	Economy	6700.00
0005434907889	25574	Economy	6700.00
0005433252226	25574	Economy	6700.00
0005433401060	25574	Economy	6700.00
0005434908016	25574	Economy	6700.00
0005434908093	25574	Economy	6700.00
0005434908009	25574	Economy	6700.00
0005433401057	25574	Economy	6700.00
0005433252240	25574	Economy	6700.00
0005433252253	25574	Economy	6700.00
0005434908233	25574	Economy	6700.00
0005434908201	25574	Economy	6700.00
0005434908062	25574	Economy	6700.00
0005434907776	25574	Economy	6700.00
0005434908087	25574	Economy	6700.00
0005434908150	25574	Economy	6700.00
0005434908221	25574	Economy	6700.00
0005433252242	25574	Economy	6700.00
0005434908057	25574	Economy	6700.00
0005433252223	25574	Economy	6700.00
0005434907890	25574	Economy	6700.00
0005434908043	25574	Economy	6700.00
0005434907983	25574	Economy	6700.00
0005434908044	25574	Economy	6700.00
0005434908182	25574	Economy	6700.00
0005434908035	25574	Economy	6700.00
0005433252247	25574	Economy	6700.00
0005434908110	25574	Economy	6700.00
0005434908048	25574	Economy	6700.00
0005433252234	25574	Economy	6700.00
0005434908158	25574	Economy	6700.00
0005433252239	25574	Economy	6700.00
0005433252245	25574	Economy	6700.00
0005434908010	25574	Economy	6700.00
0005434908033	25574	Economy	6700.00
0005433252224	25574	Economy	6700.00
0005433252229	25574	Economy	6700.00
0005434907891	25574	Economy	6700.00
0005433252243	25574	Economy	6700.00
0005434908065	25574	Economy	6700.00
0005434908086	25574	Economy	6700.00
0005433252238	25574	Economy	6700.00
0005433252241	25574	Economy	6700.00
0005433252237	25574	Economy	6700.00
0005432862423	2554	Economy	13600.00
0005432621392	2554	Economy	12400.00
0005432862422	2554	Economy	12400.00
0005432621389	2554	Economy	12400.00
0005432862431	2554	Economy	12400.00
0005432621382	2554	Economy	12400.00
0005432862444	2554	Economy	12400.00
0005432621390	2554	Economy	12400.00
0005432862457	2554	Economy	12400.00
0005432621384	2554	Economy	12400.00
0005432862443	2554	Economy	12400.00
0005432621385	2554	Economy	12400.00
0005432621383	2554	Economy	12400.00
0005432621386	2554	Economy	12400.00
0005432621391	2554	Economy	12400.00
0005432862434	2554	Economy	12400.00
0005432621388	2554	Economy	12400.00
0005432621381	2554	Economy	12400.00
0005432862420	2554	Economy	12400.00
0005432862435	2554	Economy	12400.00
0005432862430	2554	Economy	12400.00
0005432862421	2554	Economy	12400.00
0005432621387	2554	Economy	12400.00
0005432862456	2554	Economy	12400.00
0005432621393	2554	Economy	12400.00
0005432621268	28059	Economy	13600.00
0005432621269	28059	Economy	13600.00
0005432621248	28059	Economy	12400.00
0005432621253	28059	Economy	12400.00
0005432862495	28059	Economy	12400.00
0005432862491	28059	Economy	12400.00
0005432862489	28059	Economy	12400.00
0005432862490	28059	Economy	12400.00
0005432621275	28059	Economy	12400.00
0005432862496	28059	Economy	12400.00
0005432621293	28059	Economy	12400.00
0005432862493	28059	Economy	12400.00
0005432621302	28059	Economy	12400.00
0005432862492	28059	Economy	12400.00
0005432621230	28059	Economy	12400.00
0005432621250	28059	Economy	12400.00
0005432621236	28059	Economy	12400.00
0005432621320	28059	Economy	12400.00
0005432621282	28059	Economy	12400.00
0005432621321	28059	Economy	12400.00
0005432862494	28059	Economy	12400.00
0005432621237	28059	Economy	12400.00
0005434097496	11765	Economy	11300.00
0005434097505	13051	Economy	11300.00
0005434097504	13051	Economy	11300.00
0005434191308	28023	Economy	29900.00
0005434191315	28023	Economy	32800.00
0005434191309	28023	Economy	29900.00
0005434191312	28023	Economy	29900.00
0005434191310	28023	Economy	29900.00
0005434191314	28023	Economy	29900.00
0005434191316	28023	Economy	29900.00
0005434191311	28023	Economy	29900.00
0005434191313	28023	Economy	29900.00
0005434191318	28023	Economy	29900.00
0005434191317	28023	Economy	29900.00
0005433452790	30979	Economy	8400.00
0005433451669	30979	Economy	8400.00
0005433451670	30979	Economy	8400.00
0005433451671	30979	Economy	8400.00
0005434142682	12012	Economy	7200.00
0005433129352	12012	Economy	7200.00
0005433134210	12012	Economy	6600.00
0005433129363	12012	Economy	6600.00
0005433129356	12012	Economy	6600.00
0005433129362	12012	Economy	6600.00
0005434326086	12012	Economy	6600.00
0005434142681	12012	Economy	6600.00
0005433134211	12012	Economy	6600.00
0005433129344	12012	Economy	6600.00
0005433129364	12012	Economy	6600.00
0005433129343	12012	Economy	6600.00
0005433129342	12012	Economy	6600.00
0005434326054	12012	Economy	6600.00
0005433129355	12012	Economy	6600.00
0005434326053	12012	Economy	6600.00
0005433131823	29849	Economy	6600.00
0005433131820	29849	Economy	6600.00
0005434183629	29849	Economy	6600.00
0005434184716	29849	Economy	6600.00
0005433131819	29849	Economy	6600.00
0005434183630	29849	Economy	6600.00
0005434142706	29849	Economy	6600.00
0005433134249	29849	Economy	6600.00
0005433134250	29849	Economy	6600.00
0005434142705	29849	Economy	6600.00
0005433131821	29849	Economy	6600.00
0005433131822	29849	Economy	6600.00
0005434142704	29849	Economy	6600.00
0005435698000	16460	Economy	19900.00
0005435698009	16460	Economy	19900.00
0005435698005	16460	Economy	18100.00
0005435697995	16460	Economy	18100.00
0005435698013	16460	Economy	18100.00
0005435698017	16460	Economy	18100.00
0005435698003	16460	Economy	18100.00
0005435697994	16460	Economy	18100.00
0005435698004	16460	Economy	18100.00
0005435697999	16460	Economy	18100.00
0005435698014	16460	Economy	18100.00
0005435698006	16460	Economy	18100.00
0005435697997	16460	Economy	18100.00
0005435935083	16460	Economy	18100.00
0005435935093	16460	Economy	18100.00
0005435698007	16460	Economy	18100.00
0005435698002	16460	Economy	18100.00
0005435935100	16460	Economy	18100.00
0005435697993	16460	Economy	18100.00
0005435698010	16460	Economy	18100.00
0005435697996	16460	Economy	18100.00
0005435698018	16460	Economy	18100.00
0005435697992	16460	Economy	18100.00
0005435698012	16460	Economy	18100.00
0005435697998	16460	Economy	18100.00
0005435698001	16460	Economy	18100.00
0005435698011	16460	Economy	18100.00
0005435698008	16460	Economy	18100.00
0005435698015	16460	Economy	18100.00
0005435698016	16460	Economy	18100.00
0005435697746	24705	Economy	19900.00
0005435697772	24705	Economy	19900.00
0005435697688	24705	Economy	19900.00
0005435697861	24705	Economy	18100.00
0005435697801	24705	Economy	18100.00
0005435697930	24705	Economy	18100.00
0005435697852	24705	Economy	18100.00
0005435935125	24705	Economy	18100.00
0005435697791	24705	Economy	18100.00
0005435697773	24705	Economy	18100.00
0005435697715	24705	Economy	18100.00
0005435697689	24705	Economy	18100.00
0005435697710	24705	Economy	18100.00
0005435935124	24705	Economy	18100.00
0005435935123	24705	Economy	18100.00
0005435697807	24705	Economy	18100.00
0005435697823	24705	Economy	18100.00
0005435933573	24705	Economy	18100.00
0005435933574	24705	Economy	18100.00
0005435697808	24705	Economy	18100.00
0005435697774	24705	Economy	18100.00
0005435697762	24705	Economy	18100.00
0005435697755	24705	Economy	18100.00
0005435697845	24705	Economy	18100.00
0005432968868	18773	Economy	4400.00
0005432968865	18773	Economy	4400.00
0005432968866	18773	Economy	4400.00
0005433724916	18773	Economy	4400.00
0005432968878	18773	Economy	4400.00
0005433724915	18773	Economy	4400.00
0005432968875	18773	Economy	4400.00
0005433724917	18773	Economy	4400.00
0005433724882	21603	Economy	4400.00
0005433724894	21603	Economy	4400.00
0005433724861	21603	Economy	4400.00
0005433724881	21603	Economy	4400.00
0005433724862	21603	Economy	4400.00
0005432968899	21603	Economy	4400.00
0005432968898	21603	Economy	4400.00
0005433724895	21603	Economy	4400.00
0005434140159	7329	Business	23100.00
0005434140170	7329	Business	23100.00
0005434140190	7329	Business	23100.00
0005434140165	7329	Business	23100.00
0005434140141	7329	Business	23100.00
0005434140171	7329	Business	23100.00
0005434140194	7329	Business	23100.00
0005434140112	7329	Business	23100.00
0005434140182	7329	Business	23100.00
0005434140148	7329	Business	23100.00
0005434140192	7329	Business	23100.00
0005434140116	7329	Business	23100.00
0005434087635	7329	Economy	7700.00
0005434140144	7329	Economy	7700.00
0005434140132	7329	Economy	7700.00
0005434140162	7329	Economy	7700.00
0005434140151	7329	Economy	7700.00
0005434140121	7329	Economy	7700.00
0005434140164	7329	Economy	7700.00
0005434140145	7329	Economy	7700.00
0005434140183	7329	Economy	7700.00
0005434140200	7329	Economy	7700.00
0005434140122	7329	Economy	8500.00
0005434140186	7329	Economy	8500.00
0005434140143	7329	Economy	8500.00
0005434140160	7329	Economy	8500.00
0005434140154	7329	Economy	8500.00
0005434140152	7329	Economy	7700.00
0005434140188	7329	Economy	7700.00
0005434140149	7329	Economy	7700.00
0005434140180	7329	Economy	7700.00
0005434140114	7329	Economy	7700.00
0005434140130	7329	Economy	7700.00
0005434140146	7329	Economy	7700.00
0005434140201	7329	Economy	7700.00
0005434140174	7329	Economy	7700.00
0005434140196	7329	Economy	7700.00
0005434140193	7329	Economy	7700.00
0005434140184	7329	Economy	7700.00
0005434140158	7329	Economy	7700.00
0005434140126	7329	Economy	7700.00
0005434140118	7329	Economy	7700.00
0005434140133	7329	Economy	7700.00
0005434140155	7329	Economy	7700.00
0005434087634	7329	Economy	7700.00
0005434140139	7329	Economy	7700.00
0005434140117	7329	Economy	7700.00
0005434140150	7329	Economy	7700.00
0005434140140	7329	Economy	7700.00
0005434140120	7329	Economy	7700.00
0005434140166	7329	Economy	7700.00
0005434140125	7329	Economy	7700.00
0005434140168	7329	Economy	7700.00
0005434140128	7329	Economy	7700.00
0005434140172	7329	Economy	7700.00
0005434140191	7329	Economy	7700.00
0005434140115	7329	Economy	7700.00
0005434140185	7329	Economy	7700.00
0005434140175	7329	Economy	7700.00
0005434140123	7329	Economy	7700.00
0005434140187	7329	Economy	7700.00
0005434140197	7329	Economy	7700.00
0005434140124	7329	Economy	7700.00
0005434140198	7329	Economy	7700.00
0005434140129	7329	Economy	7700.00
0005434140147	7329	Economy	7700.00
0005434140127	7329	Economy	7700.00
0005434140138	7329	Economy	7700.00
0005434140113	7329	Economy	7700.00
0005434140163	7329	Economy	7700.00
0005434140195	7329	Economy	7700.00
0005434140189	7329	Economy	7700.00
0005434140119	7329	Economy	7700.00
0005434140181	7329	Economy	7700.00
0005434140157	7329	Economy	7700.00
0005434140153	7329	Economy	7700.00
0005434140176	7329	Economy	7700.00
0005434140137	7329	Economy	7700.00
0005434140202	7329	Economy	7700.00
0005434087633	7329	Economy	7700.00
0005434140199	7329	Economy	7700.00
0005434140134	7329	Economy	7700.00
0005434140177	7329	Economy	7700.00
0005434140142	7329	Economy	7700.00
0005434140169	7329	Economy	7700.00
0005434140173	7329	Economy	7700.00
0005434140167	7329	Economy	7700.00
0005434140135	7329	Economy	7700.00
0005434140131	7329	Economy	7700.00
0005434140156	7329	Economy	7700.00
0005434140178	7329	Economy	7700.00
0005434140136	7329	Economy	7700.00
0005434140161	7329	Economy	7700.00
0005434140179	7329	Economy	7700.00
0005434087636	7329	Economy	7700.00
0005434139507	28548	Business	23100.00
0005434139186	28548	Business	23100.00
0005434139465	28548	Business	23100.00
0005434139457	28548	Business	23100.00
0005434139541	28548	Business	23100.00
0005434139278	28548	Business	23100.00
0005434139529	28548	Business	23100.00
0005434139377	28548	Business	23100.00
0005434139404	28548	Business	23100.00
0005434139385	28548	Economy	7700.00
0005434139366	28548	Economy	7700.00
0005434139665	28548	Economy	7700.00
0005434139655	28548	Economy	7700.00
0005434139530	28548	Economy	7700.00
0005434139510	28548	Economy	7700.00
0005434138843	28548	Economy	7700.00
0005434138985	28548	Economy	8500.00
0005434139608	28548	Economy	8500.00
0005434139511	28548	Economy	8500.00
0005434139280	28548	Economy	8500.00
0005434139508	28548	Economy	8500.00
0005434139478	28548	Economy	7700.00
0005434139378	28548	Economy	7700.00
0005434087600	28548	Economy	7700.00
0005434138842	28548	Economy	7700.00
0005434139557	28548	Economy	7700.00
0005434139075	28548	Economy	7700.00
0005434139240	28548	Economy	7700.00
0005434139654	28548	Economy	7700.00
0005434139072	28548	Economy	7700.00
0005434139460	28548	Economy	7700.00
0005434138986	28548	Economy	7700.00
0005434138970	28548	Economy	7700.00
0005434139030	28548	Economy	7700.00
0005434087620	28548	Economy	7700.00
0005434139304	28548	Economy	7700.00
0005434139074	28548	Economy	7700.00
0005434139479	28548	Economy	7700.00
0005434139572	28548	Economy	7700.00
0005434139406	28548	Economy	7700.00
0005434139383	28548	Economy	7700.00
0005434138841	28548	Economy	7700.00
0005434139660	28548	Economy	7700.00
0005434139560	28548	Economy	7700.00
0005434139176	28548	Economy	7700.00
0005434139147	28548	Economy	7700.00
0005434139609	28548	Economy	7700.00
0005434139573	28548	Economy	7700.00
0005434139308	28548	Economy	7700.00
0005434138987	28548	Economy	7700.00
0005434138732	28548	Economy	7700.00
0005434139326	28548	Economy	7700.00
0005434139497	28548	Economy	7700.00
0005434139666	28548	Economy	7700.00
0005434139384	28548	Economy	7700.00
0005434139279	28548	Economy	7700.00
0005434139365	28548	Economy	7700.00
0005434139661	28548	Economy	7700.00
0005434139509	28548	Economy	7700.00
0005434139325	28548	Economy	7700.00
0005434139031	28548	Economy	7700.00
0005434139363	28548	Economy	7700.00
0005434139262	28548	Economy	7700.00
0005434139646	28548	Economy	7700.00
0005435283559	28548	Economy	7700.00
0005435283560	28548	Economy	7700.00
0005434139381	28548	Economy	7700.00
0005434139342	28548	Economy	7700.00
0005434139498	28548	Economy	7700.00
0005434139265	28548	Economy	7700.00
0005435283558	28548	Economy	7700.00
0005434139296	28548	Economy	7700.00
0005434139459	28548	Economy	7700.00
0005434139441	28548	Economy	7700.00
0005434139601	28548	Economy	7700.00
0005434139241	28548	Economy	7700.00
0005434139664	28548	Economy	7700.00
0005434139125	28548	Economy	7700.00
0005434139731	28548	Economy	7700.00
0005434139071	28548	Economy	7700.00
0005434139656	28548	Economy	7700.00
0005434139440	28548	Economy	7700.00
0005434139528	28548	Economy	7700.00
0005434139547	28548	Economy	7700.00
0005435808478	1918	Economy	23900.00
0005435808481	1918	Economy	23900.00
0005434610320	1918	Economy	23900.00
0005433407648	1918	Economy	21700.00
0005434610318	1918	Economy	21700.00
0005433407628	1918	Economy	21700.00
0005435808476	1918	Economy	21700.00
0005435808477	1918	Economy	21700.00
0005434610317	1918	Economy	21700.00
0005433407646	1918	Economy	21700.00
0005433407652	1918	Economy	21700.00
0005433407645	1918	Economy	21700.00
0005435808480	1918	Economy	21700.00
0005433407651	1918	Economy	21700.00
0005435808473	1918	Economy	21700.00
0005435808475	1918	Economy	21700.00
0005433407649	1918	Economy	21700.00
0005435808482	1918	Economy	21700.00
0005435808479	1918	Economy	21700.00
0005434610319	1918	Economy	21700.00
0005435808474	1918	Economy	21700.00
0005434610291	23093	Economy	21700.00
0005434610293	23093	Economy	21700.00
0005434610278	23093	Economy	21700.00
0005434610292	23093	Economy	21700.00
0005434504641	16671	Economy	7600.00
0005434504830	16671	Economy	7600.00
0005434504766	16671	Economy	7600.00
0005434504845	16671	Economy	7600.00
0005434504665	16671	Economy	6900.00
0005434504691	16671	Economy	6900.00
0005434504939	16671	Economy	6900.00
0005434504857	16671	Economy	6900.00
0005434504834	16671	Economy	6900.00
0005434504707	16671	Economy	6900.00
0005434504683	16671	Economy	6900.00
0005434504859	16671	Economy	6900.00
0005434504708	16671	Economy	6900.00
0005434504770	16671	Economy	6900.00
0005434504768	16671	Economy	6900.00
0005434504889	16671	Economy	6900.00
0005434504771	16671	Economy	6900.00
0005434504862	16671	Economy	6900.00
0005434504764	16671	Economy	6900.00
0005434504820	16671	Economy	6900.00
0005434504832	16671	Economy	6900.00
0005434504772	16671	Economy	6900.00
0005434504677	16671	Economy	6900.00
0005434504569	16671	Economy	6900.00
0005434504730	16671	Economy	6900.00
0005434504676	16671	Economy	6900.00
0005434504977	16671	Economy	6900.00
0005434504767	16671	Economy	6900.00
0005434504684	16671	Economy	6900.00
0005434504769	16671	Economy	6900.00
0005434504705	16671	Economy	6900.00
0005434504893	16671	Economy	6900.00
0005434504611	16671	Economy	6900.00
0005434504831	16671	Economy	6900.00
0005434504856	16671	Economy	6900.00
0005434504763	16671	Economy	6900.00
0005434504568	16671	Economy	6900.00
0005434504782	16671	Economy	6900.00
0005434504704	16671	Economy	6900.00
0005434505089	22911	Economy	7600.00
0005434505091	22911	Economy	7600.00
0005434505087	22911	Economy	7600.00
0005434505077	22911	Economy	7600.00
0005434505090	22911	Economy	6900.00
0005434505099	22911	Economy	6900.00
0005434505098	22911	Economy	6900.00
0005434505084	22911	Economy	6900.00
0005434505108	22911	Economy	6900.00
0005434505097	22911	Economy	6900.00
0005434505101	22911	Economy	6900.00
0005434505107	22911	Economy	6900.00
0005434505083	22911	Economy	6900.00
0005434505072	22911	Economy	6900.00
0005434505075	22911	Economy	6900.00
0005434505086	22911	Economy	6900.00
0005434505073	22911	Economy	6900.00
0005434505071	22911	Economy	6900.00
0005434505081	22911	Economy	6900.00
0005434505110	22911	Economy	6900.00
0005434505109	22911	Economy	6900.00
0005434505106	22911	Economy	6900.00
0005434505092	22911	Economy	6900.00
0005434505096	22911	Economy	6900.00
0005434505095	22911	Economy	6900.00
0005434505094	22911	Economy	6900.00
0005434505078	22911	Economy	6900.00
0005434505088	22911	Economy	6900.00
0005434505079	22911	Economy	6900.00
0005434505102	22911	Economy	6900.00
0005434505105	22911	Economy	6900.00
0005434505076	22911	Economy	6900.00
0005434505085	22911	Economy	6900.00
0005434505080	22911	Economy	6900.00
0005434505082	22911	Economy	6900.00
0005434505070	22911	Economy	6900.00
0005434505093	22911	Economy	6900.00
0005434505100	22911	Economy	6900.00
0005434505104	22911	Economy	6900.00
0005434505074	22911	Economy	6900.00
0005434505103	22911	Economy	6900.00
0005433266895	2215	Economy	7700.00
0005435078728	2215	Economy	7700.00
0005433266887	2215	Economy	7700.00
0005435078730	2215	Economy	7000.00
0005433266885	2215	Economy	7000.00
0005435078718	2215	Economy	7000.00
0005435078722	2215	Economy	7000.00
0005435078719	2215	Economy	7000.00
0005433266883	2215	Economy	7000.00
0005435078731	2215	Economy	7000.00
0005433266878	2215	Economy	7000.00
0005435078724	2215	Economy	7000.00
0005435078726	2215	Economy	7000.00
0005435078717	2215	Economy	7000.00
0005435078723	2215	Economy	7000.00
0005435078727	2215	Economy	7000.00
0005435078721	2215	Economy	7000.00
0005435078725	2215	Economy	7000.00
0005435078729	2215	Economy	7000.00
0005435078720	2215	Economy	7000.00
0005433266886	2215	Economy	7000.00
0005433266879	2215	Economy	7000.00
0005435078568	24368	Economy	7700.00
0005435078662	24368	Economy	7000.00
0005433266953	24368	Economy	7000.00
0005435078656	24368	Economy	7000.00
0005433266949	24368	Economy	7000.00
0005435078585	24368	Economy	7000.00
0005435078663	24368	Economy	7000.00
0005433266957	24368	Economy	7000.00
0005433266951	24368	Economy	7000.00
0005435078584	24368	Economy	7000.00
0005435078633	24368	Economy	7000.00
0005433266948	24368	Economy	7000.00
0005433266954	24368	Economy	7000.00
0005435078569	24368	Economy	7000.00
0005435078575	24368	Economy	7000.00
0005433266956	24368	Economy	7000.00
0005433266952	24368	Economy	7000.00
0005433266950	24368	Economy	7000.00
0005435078563	24368	Economy	7000.00
0005433266955	24368	Economy	7000.00
0005434989009	6618	Economy	10800.00
0005435803333	6618	Economy	10800.00
0005434989011	6618	Economy	10800.00
0005435803335	6618	Economy	9800.00
0005434989012	6618	Economy	9800.00
0005434989019	6618	Economy	9800.00
0005434989015	6618	Economy	9800.00
0005435803334	6618	Economy	9800.00
0005435464540	6618	Economy	9800.00
0005434989018	6618	Economy	9800.00
0005435464537	6618	Economy	9800.00
0005434989010	6618	Economy	9800.00
0005435464531	6618	Economy	9800.00
0005434989007	6618	Economy	9800.00
0005434989017	6618	Economy	9800.00
0005434989016	6618	Economy	9800.00
0005434989020	6618	Economy	9800.00
0005434989014	6618	Economy	9800.00
0005435464541	6618	Economy	9800.00
0005434989013	6618	Economy	9800.00
0005434989008	6618	Economy	9800.00
0005434988886	23635	Economy	9800.00
0005435464556	23635	Economy	9800.00
0005435464558	23635	Economy	9800.00
0005434988836	23635	Economy	9800.00
0005434988837	23635	Economy	9800.00
0005434988889	23635	Economy	9800.00
0005434988888	23635	Economy	9800.00
0005434988902	23635	Economy	9800.00
0005434988920	23635	Economy	9800.00
0005435464557	23635	Economy	9800.00
0005434988907	23635	Economy	9800.00
0005434988919	23635	Economy	9800.00
0005435803313	23635	Economy	9800.00
0005434988911	23635	Economy	9800.00
0005432384122	30496	Business	9900.00
0005433450514	30496	Business	9900.00
0005433450506	30496	Business	9900.00
0005433450508	30496	Business	9900.00
0005432384139	30496	Business	9900.00
0005432384150	30496	Business	9900.00
0005432384131	30496	Business	9900.00
0005432384158	30496	Business	9900.00
0005432384147	30496	Economy	3300.00
0005433450515	30496	Economy	3300.00
0005432384146	30496	Economy	3300.00
0005433450513	30496	Economy	3300.00
0005432384160	30496	Economy	3300.00
0005432384155	30496	Economy	3300.00
0005432384127	30496	Economy	3300.00
0005433450502	30496	Economy	3300.00
0005432384145	30496	Economy	3600.00
0005432384140	30496	Economy	3600.00
0005432384148	30496	Economy	3600.00
0005432384151	30496	Economy	3300.00
0005432384120	30496	Economy	3300.00
0005432384133	30496	Economy	3300.00
0005432384137	30496	Economy	3300.00
0005432384149	30496	Economy	3300.00
0005433453810	30496	Economy	3300.00
0005432384154	30496	Economy	3300.00
0005432384123	30496	Economy	3300.00
0005432384152	30496	Economy	3300.00
0005432384142	30496	Economy	3300.00
0005433450505	30496	Economy	3300.00
0005432384141	30496	Economy	3300.00
0005433450509	30496	Economy	3300.00
0005432384119	30496	Economy	3300.00
0005432384156	30496	Economy	3300.00
0005432384153	30496	Economy	3300.00
0005433450500	30496	Economy	3300.00
0005432384138	30496	Economy	3300.00
0005432384124	30496	Economy	3300.00
0005432384130	30496	Economy	3300.00
0005433453811	30496	Economy	3300.00
0005432384117	30496	Economy	3300.00
0005432384128	30496	Economy	3300.00
0005433450516	30496	Economy	3300.00
0005433450497	30496	Economy	3300.00
0005433450503	30496	Economy	3300.00
0005433454927	30496	Economy	3300.00
0005432384126	30496	Economy	3300.00
0005433454928	30496	Economy	3300.00
0005432384157	30496	Economy	3300.00
0005433450510	30496	Economy	3300.00
0005432384135	30496	Economy	3300.00
0005432384144	30496	Economy	3300.00
0005432384125	30496	Economy	3300.00
0005432384136	30496	Economy	3300.00
0005432384132	30496	Economy	3300.00
0005432384129	30496	Economy	3300.00
0005433450507	30496	Economy	3300.00
0005433450499	30496	Economy	3300.00
0005432384134	30496	Economy	3300.00
0005432384159	30496	Economy	3300.00
0005433450512	30496	Economy	3300.00
0005433450498	30496	Economy	3300.00
0005433450501	30496	Economy	3300.00
0005433450504	30496	Economy	3300.00
0005432384143	30496	Economy	3300.00
0005432384121	30496	Economy	3300.00
0005433450517	30496	Economy	3300.00
0005432384118	30496	Economy	3300.00
0005433450511	30496	Economy	3300.00
0005433450518	30496	Economy	3300.00
0005432383533	31302	Business	9900.00
0005433450342	31302	Business	9900.00
0005432383752	31302	Business	9900.00
0005432383627	31302	Business	9900.00
0005432383802	31302	Business	9900.00
0005433450207	31302	Business	9900.00
0005432383710	31302	Business	9900.00
0005433450341	31302	Economy	3300.00
0005433450340	31302	Economy	3300.00
0005432383618	31302	Economy	3300.00
0005432383778	31302	Economy	3300.00
0005433450215	31302	Economy	3300.00
0005432383670	31302	Economy	3300.00
0005433450318	31302	Economy	3300.00
0005432383591	31302	Economy	3600.00
0005432383696	31302	Economy	3600.00
0005432383697	31302	Economy	3600.00
0005432383750	31302	Economy	3600.00
0005432383806	31302	Economy	3600.00
0005432383688	31302	Economy	3300.00
0005432383746	31302	Economy	3300.00
0005432383699	31302	Economy	3300.00
0005432383807	31302	Economy	3300.00
0005432383687	31302	Economy	3300.00
0005433450295	31302	Economy	3300.00
0005433450249	31302	Economy	3300.00
0005433453787	31302	Economy	3300.00
0005433450330	31302	Economy	3300.00
0005433450317	31302	Economy	3300.00
0005432383777	31302	Economy	3300.00
0005432383732	31302	Economy	3300.00
0005432383648	31302	Economy	3300.00
0005433450346	31302	Economy	3300.00
0005432383741	31302	Economy	3300.00
0005432383714	31302	Economy	3300.00
0005432383671	31302	Economy	3300.00
0005432383717	31302	Economy	3300.00
0005432383808	31302	Economy	3300.00
0005433450296	31302	Economy	3300.00
0005433450361	31302	Economy	3300.00
0005433450348	31302	Economy	3300.00
0005432383669	31302	Economy	3300.00
0005432383715	31302	Economy	3300.00
0005433451653	31302	Economy	3300.00
0005432383668	31302	Economy	3300.00
0005432383849	31302	Economy	3300.00
0005432383736	31302	Economy	3300.00
0005432383706	31302	Economy	3300.00
0005432383698	31302	Economy	3300.00
0005432383731	31302	Economy	3300.00
0005433451645	31302	Economy	3300.00
0005433450329	31302	Economy	3300.00
0005433450302	31302	Economy	3300.00
0005433450345	31302	Economy	3300.00
0005432383673	31302	Economy	3300.00
0005432383615	31302	Economy	3300.00
0005433450258	31302	Economy	3300.00
0005433450254	31302	Economy	3300.00
0005432383709	31302	Economy	3300.00
0005433450250	31302	Economy	3300.00
0005433450244	31302	Economy	3300.00
0005433451654	31302	Economy	3300.00
0005432383751	31302	Economy	3300.00
0005433450347	31302	Economy	3300.00
0005432383626	31302	Economy	3300.00
0005435548603	26464	Economy	26200.00
0005435548610	26464	Economy	23800.00
0005435548607	26464	Economy	23800.00
0005433788261	26464	Economy	23800.00
0005435548611	26464	Economy	23800.00
0005435548605	26464	Economy	23800.00
0005433788250	26464	Economy	23800.00
0005435548608	26464	Economy	23800.00
0005435548609	26464	Economy	23800.00
0005435548606	26464	Economy	23800.00
0005433788260	26464	Economy	23800.00
0005435548604	26464	Economy	23800.00
0005435304229	10789	Economy	17100.00
0005435304230	10789	Economy	15600.00
0005435299836	10789	Economy	15600.00
0005435304227	10789	Economy	15600.00
0005433131782	10789	Economy	15600.00
0005435304223	10789	Economy	15600.00
0005435304228	10789	Economy	15600.00
0005433131767	10789	Economy	15600.00
0005433131772	10789	Economy	15600.00
0005435299858	10789	Economy	15600.00
0005435304231	10789	Economy	15600.00
0005435304226	10789	Economy	15600.00
0005433131766	10789	Economy	15600.00
0005435304224	10789	Economy	15600.00
0005435299852	10789	Economy	15600.00
0005433126923	10789	Economy	15600.00
0005435299857	10789	Economy	15600.00
0005435299898	29728	Economy	17100.00
0005433129391	29728	Economy	17100.00
0005435302320	29728	Economy	17100.00
0005435299895	29728	Economy	15600.00
0005433129393	29728	Economy	15600.00
0005435302319	29728	Economy	15600.00
0005433129394	29728	Economy	15600.00
0005433126960	29728	Economy	15600.00
0005433129392	29728	Economy	15600.00
0005435299897	29728	Economy	15600.00
0005433126959	29728	Economy	15600.00
0005435299896	29728	Economy	15600.00
0005435302318	29728	Economy	15600.00
0005435302317	29728	Economy	15600.00
0005433126958	29728	Economy	15600.00
0005435299899	29728	Economy	15600.00
0005435299900	29728	Economy	15600.00
0005433126961	29728	Economy	15600.00
0005435302321	29728	Economy	15600.00
0005434287837	2439	Economy	17200.00
0005434287834	2439	Economy	17200.00
0005434287835	2439	Economy	15700.00
0005434287843	2439	Economy	15700.00
0005434287829	2439	Economy	15700.00
0005434287833	2439	Economy	15700.00
0005434287842	2439	Economy	15700.00
0005432264535	2439	Economy	15700.00
0005434287840	2439	Economy	15700.00
0005433110244	2439	Economy	15700.00
0005434287828	2439	Economy	15700.00
0005433110240	2439	Economy	15700.00
0005433110259	2439	Economy	15700.00
0005433110305	2439	Economy	15700.00
0005434287845	2439	Economy	15700.00
0005434287841	2439	Economy	15700.00
0005434287830	2439	Economy	15700.00
0005434287826	2439	Economy	15700.00
0005433110230	2439	Economy	15700.00
0005434287831	2439	Economy	15700.00
0005432264536	2439	Economy	15700.00
0005433110250	2439	Economy	15700.00
0005433110216	2439	Economy	15700.00
0005434287844	2439	Economy	15700.00
0005434287825	2439	Economy	15700.00
0005433110205	2439	Economy	15700.00
0005433110232	2439	Economy	15700.00
0005434287832	2439	Economy	15700.00
0005433110246	2439	Economy	15700.00
0005434287838	2439	Economy	15700.00
0005433110245	2439	Economy	15700.00
0005433110253	2439	Economy	15700.00
0005434287827	2439	Economy	15700.00
0005433110254	2439	Economy	15700.00
0005432264537	2439	Economy	15700.00
0005433110197	2439	Economy	15700.00
0005433110215	2439	Economy	15700.00
0005434287839	2439	Economy	15700.00
0005434287836	2439	Economy	15700.00
0005433110352	26828	Economy	17200.00
0005433110355	26828	Economy	15700.00
0005434287699	26828	Economy	15700.00
0005433110354	26828	Economy	15700.00
0005433110346	26828	Economy	15700.00
0005434287618	26828	Economy	15700.00
0005434287535	26828	Economy	15700.00
0005434287599	26828	Economy	15700.00
0005434287648	26828	Economy	15700.00
0005434287675	26828	Economy	15700.00
0005434287646	26828	Economy	15700.00
0005434287663	26828	Economy	15700.00
0005434287688	26828	Economy	15700.00
0005434287687	26828	Economy	15700.00
0005434287679	26828	Economy	15700.00
0005433110351	26828	Economy	15700.00
0005434287619	26828	Economy	15700.00
0005433110353	26828	Economy	15700.00
0005433110356	26828	Economy	15700.00
0005434287698	26828	Economy	15700.00
0005434287660	26828	Economy	15700.00
0005434287703	26828	Economy	15700.00
0005433110347	26828	Economy	15700.00
0005434287680	26828	Economy	15700.00
0005433110350	26828	Economy	15700.00
0005433110348	26828	Economy	15700.00
0005433110349	26828	Economy	15700.00
0005435856307	25488	Economy	25000.00
0005435856342	25488	Economy	25000.00
0005434269133	25488	Economy	22800.00
0005435856341	25488	Economy	22800.00
0005435856309	25488	Economy	22800.00
0005435856343	25488	Economy	22800.00
0005434269132	25488	Economy	22800.00
0005434269134	25488	Economy	22800.00
0005434272213	25488	Economy	22800.00
0005435856311	25488	Economy	22800.00
0005435856310	25488	Economy	22800.00
0005435856308	25488	Economy	22800.00
0005434273115	26631	Economy	22800.00
0005435856261	26631	Economy	22800.00
0005435856273	26631	Economy	22800.00
0005434272229	26631	Economy	22800.00
0005434273116	26631	Economy	22800.00
0005434272228	26631	Economy	22800.00
0005435854073	26631	Economy	22800.00
0005434272227	26631	Economy	22800.00
0005435854072	26631	Economy	22800.00
0005434520470	6112	Economy	24600.00
0005434520463	6112	Economy	24600.00
0005434520479	6112	Economy	24600.00
0005434520480	6112	Economy	24600.00
0005435314882	6112	Economy	22300.00
0005434520476	6112	Economy	22300.00
0005435314893	6112	Economy	22300.00
0005434520469	6112	Economy	22300.00
0005435314888	6112	Economy	22300.00
0005434520450	6112	Economy	22300.00
0005434520457	6112	Economy	22300.00
0005434520456	6112	Economy	22300.00
0005434520448	6112	Economy	22300.00
0005435314880	6112	Economy	22300.00
0005434520455	6112	Economy	22300.00
0005434520459	6112	Economy	22300.00
0005434520466	6112	Economy	22300.00
0005435314897	6112	Economy	22300.00
0005434520449	6112	Economy	22300.00
0005434520475	6112	Economy	22300.00
0005434520458	6112	Economy	22300.00
0005434520462	6112	Economy	22300.00
0005434520473	6112	Economy	22300.00
0005434520464	6112	Economy	22300.00
0005434520478	6112	Economy	22300.00
0005434520468	6112	Economy	22300.00
0005434520461	6112	Economy	22300.00
0005435314884	6112	Economy	22300.00
0005435314886	6112	Economy	22300.00
0005435314899	6112	Economy	22300.00
0005434520477	6112	Economy	22300.00
0005435314895	6112	Economy	22300.00
0005435314881	6112	Economy	22300.00
0005434520452	6112	Economy	22300.00
0005434520474	6112	Economy	22300.00
0005435314885	6112	Economy	22300.00
0005434520481	6112	Economy	22300.00
0005435314898	6112	Economy	22300.00
0005434520454	6112	Economy	22300.00
0005434520465	6112	Economy	22300.00
0005434520451	6112	Economy	22300.00
0005434520472	6112	Economy	22300.00
0005434520471	6112	Economy	22300.00
0005434520460	6112	Economy	22300.00
0005434520467	6112	Economy	22300.00
0005435314902	6112	Economy	22300.00
0005434520453	6112	Economy	22300.00
0005435314890	6112	Economy	22300.00
0005435314894	6112	Economy	22300.00
0005433650846	27628	Business	89800.00
0005433650960	27628	Business	89800.00
0005433650875	27628	Business	89800.00
0005435263774	27628	Business	89800.00
0005433650842	27628	Business	89800.00
0005433650888	27628	Business	89800.00
0005435263783	27628	Business	89800.00
0005435263773	27628	Business	89800.00
0005433650973	27628	Business	89800.00
0005433650898	27628	Business	89800.00
0005435263778	27628	Business	89800.00
0005433650807	27628	Business	89800.00
0005433650877	27628	Economy	29900.00
0005433650895	27628	Economy	29900.00
0005433650897	27628	Economy	29900.00
0005433650865	27628	Economy	29900.00
0005433650873	27628	Economy	29900.00
0005435263779	27628	Economy	29900.00
0005433650886	27628	Economy	29900.00
0005433650840	27628	Economy	29900.00
0005433650831	27628	Economy	29900.00
0005435263792	27628	Economy	29900.00
0005433650814	27628	Economy	32900.00
0005435263793	27628	Economy	32900.00
0005433650847	27628	Economy	32900.00
0005433650813	27628	Economy	32900.00
0005435263784	27628	Economy	32900.00
0005433650885	27628	Economy	29900.00
0005433650834	27628	Economy	29900.00
0005433650870	27628	Economy	29900.00
0005433650905	27628	Economy	29900.00
0005433650903	27628	Economy	29900.00
0005433650803	27628	Economy	29900.00
0005435263781	27628	Economy	29900.00
0005433650869	27628	Economy	29900.00
0005433650815	27628	Economy	29900.00
0005435263790	27628	Economy	29900.00
0005433650833	27628	Economy	29900.00
0005433650830	27628	Economy	29900.00
0005433650971	27628	Economy	29900.00
0005435263798	27628	Economy	29900.00
0005433650805	27628	Economy	29900.00
0005433650739	27628	Economy	29900.00
0005433650835	27628	Economy	29900.00
0005433650854	27628	Economy	29900.00
0005433650876	27628	Economy	29900.00
0005433650901	27628	Economy	29900.00
0005433650857	27628	Economy	29900.00
0005433650904	27628	Economy	29900.00
0005433650871	27628	Economy	29900.00
0005435263782	27628	Economy	29900.00
0005435263776	27628	Economy	29900.00
0005433650879	27628	Economy	29900.00
0005435263772	27628	Economy	29900.00
0005433650812	27628	Economy	29900.00
0005433650801	27628	Economy	29900.00
0005433650822	27628	Economy	29900.00
0005433650906	27628	Economy	29900.00
0005435263797	27628	Economy	29900.00
0005433650893	27628	Economy	29900.00
0005433650802	27628	Economy	29900.00
0005433650882	27628	Economy	29900.00
0005435263796	27628	Economy	29900.00
0005433650832	27628	Economy	29900.00
0005433650902	27628	Economy	29900.00
0005433650862	27628	Economy	29900.00
0005435263795	27628	Economy	29900.00
0005435263775	27628	Economy	29900.00
0005433650774	27628	Economy	29900.00
0005433650756	27628	Economy	29900.00
0005433650823	27628	Economy	29900.00
0005435263791	27628	Economy	29900.00
0005433650757	27628	Economy	29900.00
0005433650806	27628	Economy	29900.00
0005433650821	27628	Economy	29900.00
0005435263785	27628	Economy	29900.00
0005433650872	27628	Economy	29900.00
0005433650878	27628	Economy	29900.00
0005435263789	27628	Economy	29900.00
0005433650849	27628	Economy	29900.00
0005433650880	27628	Economy	29900.00
0005435263787	27628	Economy	29900.00
0005433650894	27628	Economy	29900.00
0005435263786	27628	Economy	29900.00
0005433650829	27628	Economy	29900.00
0005433650804	27628	Economy	29900.00
0005435263800	27628	Economy	29900.00
0005433650907	27628	Economy	29900.00
0005433650961	27628	Economy	29900.00
0005433650844	27628	Economy	29900.00
0005435263777	27628	Economy	29900.00
0005435263788	27628	Economy	29900.00
0005435263799	27628	Economy	29900.00
0005433650858	27628	Economy	29900.00
0005435263794	27628	Economy	29900.00
0005435263780	27628	Economy	29900.00
0005433869440	4775	Economy	19400.00
0005433869422	4775	Economy	19400.00
0005433869417	4775	Economy	19400.00
0005433869439	4775	Economy	19400.00
0005433869407	4775	Economy	17600.00
0005433869410	4775	Economy	17600.00
0005433869441	4775	Economy	17600.00
0005433869420	4775	Economy	17600.00
0005433869413	4775	Economy	17600.00
0005433869414	4775	Economy	17600.00
0005435860535	4775	Economy	17600.00
0005433869408	4775	Economy	17600.00
0005435860534	4775	Economy	17600.00
0005433869435	4775	Economy	17600.00
0005435860524	4775	Economy	17600.00
0005433869438	4775	Economy	17600.00
0005433869427	4775	Economy	17600.00
0005433869442	4775	Economy	17600.00
0005433869434	4775	Economy	17600.00
0005433869432	4775	Economy	17600.00
0005433869436	4775	Economy	17600.00
0005433869433	4775	Economy	17600.00
0005433869409	4775	Economy	17600.00
0005433869406	4775	Economy	17600.00
0005435860520	4775	Economy	17600.00
0005433869426	4775	Economy	17600.00
0005433869418	4775	Economy	17600.00
0005433869437	4775	Economy	17600.00
0005433869428	4775	Economy	17600.00
0005433869421	4775	Economy	17600.00
0005435860518	4775	Economy	17600.00
0005433869416	4775	Economy	17600.00
0005433869411	4775	Economy	17600.00
0005433869424	4775	Economy	17600.00
0005433869431	4775	Economy	17600.00
0005433869423	4775	Economy	17600.00
0005433869405	4775	Economy	17600.00
0005433869429	4775	Economy	17600.00
0005433869412	4775	Economy	17600.00
0005433869430	4775	Economy	17600.00
0005433869415	4775	Economy	17600.00
0005433869419	4775	Economy	17600.00
0005433869425	4775	Economy	17600.00
0005433869081	32599	Economy	19400.00
0005433869113	32599	Economy	19400.00
0005433869157	32599	Economy	19400.00
0005433868966	32599	Economy	19400.00
0005433869116	32599	Economy	17600.00
0005433868937	32599	Economy	17600.00
0005433868860	32599	Economy	17600.00
0005433869185	32599	Economy	17600.00
0005433869080	32599	Economy	17600.00
0005433868958	32599	Economy	17600.00
0005433868974	32599	Economy	17600.00
0005435860593	32599	Economy	17600.00
0005433868960	32599	Economy	17600.00
0005433868797	32599	Economy	17600.00
0005433869026	32599	Economy	17600.00
0005433869028	32599	Economy	17600.00
0005433869150	32599	Economy	17600.00
0005433869137	32599	Economy	17600.00
0005433869149	32599	Economy	17600.00
0005433869152	32599	Economy	17600.00
0005433869194	32599	Economy	17600.00
0005433869112	32599	Economy	17600.00
0005433868980	32599	Economy	17600.00
0005433869027	32599	Economy	17600.00
0005433869093	32599	Economy	17600.00
0005433869151	32599	Economy	17600.00
0005433868843	32599	Economy	17600.00
0005433869139	32599	Economy	17600.00
0005433869140	32599	Economy	17600.00
0005433869136	32599	Economy	17600.00
0005433868890	32599	Economy	17600.00
0005433869054	32599	Economy	17600.00
0005433868992	32599	Economy	17600.00
0005435860592	32599	Economy	17600.00
0005433868981	32599	Economy	17600.00
0005433868961	32599	Economy	17600.00
0005433868856	32599	Economy	17600.00
0005433869052	32599	Economy	17600.00
0005433869007	32599	Economy	17600.00
0005433869117	32599	Economy	17600.00
0005433869009	32599	Economy	17600.00
0005433869135	32599	Economy	17600.00
0005433868889	32599	Economy	17600.00
0005433869109	32599	Economy	17600.00
0005433869158	32599	Economy	17600.00
0005433869138	32599	Economy	17600.00
0005433868906	32599	Economy	17600.00
0005433869053	32599	Economy	17600.00
0005433868936	32599	Economy	17600.00
0005433868857	32599	Economy	17600.00
0005434663740	3413	Economy	24800.00
0005434663745	3413	Economy	24800.00
0005434663749	3413	Economy	24800.00
0005434663739	3413	Economy	22600.00
0005435911588	3413	Economy	22600.00
0005435911574	3413	Economy	22600.00
0005435911589	3413	Economy	22600.00
0005434663746	3413	Economy	22600.00
0005434663737	3413	Economy	22600.00
0005434663744	3413	Economy	22600.00
0005434461699	3413	Economy	22600.00
0005434461700	3413	Economy	22600.00
0005434663748	3413	Economy	22600.00
0005434663747	3413	Economy	22600.00
0005434663738	3413	Economy	22600.00
0005435911584	3413	Economy	22600.00
0005434663742	3413	Economy	22600.00
0005434663743	3413	Economy	22600.00
0005434461701	3413	Economy	22600.00
0005434663741	3413	Economy	22600.00
0005434663750	3413	Economy	22600.00
0005434663584	12455	Economy	24800.00
0005435911641	12455	Economy	22600.00
0005434663623	12455	Economy	22600.00
0005434663638	12455	Economy	22600.00
0005435911638	12455	Economy	22600.00
0005435911644	12455	Economy	22600.00
0005434663648	12455	Economy	22600.00
0005435911643	12455	Economy	22600.00
0005434663654	12455	Economy	22600.00
0005435911640	12455	Economy	22600.00
0005435911637	12455	Economy	22600.00
0005434663583	12455	Economy	22600.00
0005435911642	12455	Economy	22600.00
0005434663611	12455	Economy	22600.00
0005435911639	12455	Economy	22600.00
0005433869194	14531	Economy	18500.00
0005433869007	14531	Economy	18500.00
0005433868889	14531	Economy	18500.00
0005433869080	14531	Economy	18500.00
0005433869054	14531	Economy	16800.00
0005433868860	14531	Economy	16800.00
0005433868936	14531	Economy	16800.00
0005433869185	14531	Economy	16800.00
0005433869052	14531	Economy	16800.00
0005433869009	14531	Economy	16800.00
0005433868843	14531	Economy	16800.00
0005433869137	14531	Economy	16800.00
0005433869138	14531	Economy	16800.00
0005433869109	14531	Economy	16800.00
0005433869152	14531	Economy	16800.00
0005433869112	14531	Economy	16800.00
0005433868906	14531	Economy	16800.00
0005433869028	14531	Economy	16800.00
0005433869026	14531	Economy	16800.00
0005433868857	14531	Economy	16800.00
0005433869140	14531	Economy	16800.00
0005433869149	14531	Economy	16800.00
0005433868937	14531	Economy	16800.00
0005433868980	14531	Economy	16800.00
0005433869151	14531	Economy	16800.00
0005433868890	14531	Economy	16800.00
0005433869113	14531	Economy	16800.00
0005433868966	14531	Economy	16800.00
0005433868961	14531	Economy	16800.00
0005433869093	14531	Economy	16800.00
0005433869135	14531	Economy	16800.00
0005433869081	14531	Economy	16800.00
0005433869139	14531	Economy	16800.00
0005433868958	14531	Economy	16800.00
0005433869150	14531	Economy	16800.00
0005433868992	14531	Economy	16800.00
0005433869158	14531	Economy	16800.00
0005433868960	14531	Economy	16800.00
0005435860592	14531	Economy	16800.00
0005433868797	14531	Economy	16800.00
0005433869053	14531	Economy	16800.00
0005433868981	14531	Economy	16800.00
0005433869157	14531	Economy	16800.00
0005435860593	14531	Economy	16800.00
0005433869136	14531	Economy	16800.00
0005433869117	14531	Economy	16800.00
0005433869116	14531	Economy	16800.00
0005433869027	14531	Economy	16800.00
0005433868974	14531	Economy	16800.00
0005433868856	14531	Economy	16800.00
0005433869394	32650	Economy	18500.00
0005433869399	32650	Economy	18500.00
0005433869386	32650	Economy	18500.00
0005433869393	32650	Economy	16800.00
0005435860515	32650	Economy	16800.00
0005433869404	32650	Economy	16800.00
0005433869380	32650	Economy	16800.00
0005433869402	32650	Economy	16800.00
0005433869374	32650	Economy	16800.00
0005433869401	32650	Economy	16800.00
0005433869373	32650	Economy	16800.00
0005433869370	32650	Economy	16800.00
0005433869389	32650	Economy	16800.00
0005433869391	32650	Economy	16800.00
0005433869400	32650	Economy	16800.00
0005433869387	32650	Economy	16800.00
0005433869372	32650	Economy	16800.00
0005433869369	32650	Economy	16800.00
0005433869398	32650	Economy	16800.00
0005433869383	32650	Economy	16800.00
0005433869368	32650	Economy	16800.00
0005433869390	32650	Economy	16800.00
0005433869388	32650	Economy	16800.00
0005433869376	32650	Economy	16800.00
0005433869396	32650	Economy	16800.00
0005433869385	32650	Economy	16800.00
0005433869395	32650	Economy	16800.00
0005433869377	32650	Economy	16800.00
0005433869378	32650	Economy	16800.00
0005433869381	32650	Economy	16800.00
0005433869367	32650	Economy	16800.00
0005433869397	32650	Economy	16800.00
0005433869384	32650	Economy	16800.00
0005433869366	32650	Economy	16800.00
0005433869392	32650	Economy	16800.00
0005433869379	32650	Economy	16800.00
0005433869371	32650	Economy	16800.00
0005433869382	32650	Economy	16800.00
0005433869375	32650	Economy	16800.00
0005433869403	32650	Economy	16800.00
0005435860514	32650	Economy	16800.00
0005432799973	12154	Economy	4900.00
0005432799958	12154	Economy	4400.00
0005432800044	12154	Economy	4400.00
0005432799944	12154	Economy	4400.00
0005432799957	12154	Economy	4400.00
0005432799819	12154	Economy	4400.00
0005432799862	12154	Economy	4400.00
0005432799985	12154	Economy	4400.00
0005432799925	12154	Economy	4400.00
0005432799900	12154	Economy	4400.00
0005432799812	12154	Economy	4400.00
0005432800045	12154	Economy	4400.00
0005432799820	12154	Economy	4400.00
0005432799851	12154	Economy	4400.00
0005432799927	12154	Economy	4400.00
0005432799813	12154	Economy	4400.00
0005432799865	12154	Economy	4400.00
0005432799974	12154	Economy	4400.00
0005432799975	12154	Economy	4400.00
0005432799946	12154	Economy	4400.00
0005432800009	12154	Economy	4400.00
0005432799766	12154	Economy	4400.00
0005432799945	12154	Economy	4400.00
0005432799850	12154	Economy	4400.00
0005432799984	12154	Economy	4400.00
0005432799767	12154	Economy	4400.00
0005432799886	12154	Economy	4400.00
0005432799821	12154	Economy	4400.00
0005432800115	14800	Economy	4900.00
0005432800122	14800	Economy	4900.00
0005432800124	14800	Economy	4400.00
0005432800133	14800	Economy	4400.00
0005432800137	14800	Economy	4400.00
0005432800129	14800	Economy	4400.00
0005432800132	14800	Economy	4400.00
0005432800134	14800	Economy	4400.00
0005432800123	14800	Economy	4400.00
0005432800112	14800	Economy	4400.00
0005432800136	14800	Economy	4400.00
0005432800118	14800	Economy	4400.00
0005432800128	14800	Economy	4400.00
0005432800114	14800	Economy	4400.00
0005432800119	14800	Economy	4400.00
0005432800131	14800	Economy	4400.00
0005432800110	14800	Economy	4400.00
0005432800117	14800	Economy	4400.00
0005432800126	14800	Economy	4400.00
0005432800135	14800	Economy	4400.00
0005432800113	14800	Economy	4400.00
0005432800111	14800	Economy	4400.00
0005432800125	14800	Economy	4400.00
0005432800127	14800	Economy	4400.00
0005432800121	14800	Economy	4400.00
0005432800116	14800	Economy	4400.00
0005432800120	14800	Economy	4400.00
0005432800130	14800	Economy	4400.00
0005435311194	7056	Business	49100.00
0005434409341	7056	Business	49100.00
0005434300141	7056	Business	49100.00
0005434409288	7056	Business	49100.00
0005434300137	7056	Business	49100.00
0005434409303	7056	Business	49100.00
0005434300129	7056	Business	49100.00
0005435293401	7056	Business	49100.00
0005434409316	7056	Business	49100.00
0005434409298	7056	Business	49100.00
0005435311247	7056	Business	49100.00
0005434409312	7056	Business	49100.00
0005432154109	7056	Economy	16400.00
0005434409311	7056	Economy	16400.00
0005434409320	7056	Economy	16400.00
0005435311281	7056	Economy	16400.00
0005434300138	7056	Economy	16400.00
0005434300135	7056	Economy	16400.00
0005435311253	7056	Economy	16400.00
0005435311205	7056	Economy	16400.00
0005435293480	7056	Economy	16400.00
0005435311255	7056	Economy	16400.00
0005435311195	7056	Economy	16400.00
0005432154111	7056	Economy	16400.00
0005434409328	7056	Economy	16400.00
0005435311185	7056	Economy	16400.00
0005435293457	7056	Economy	16400.00
0005434409308	7056	Economy	16400.00
0005435293444	7056	Economy	16400.00
0005434409283	7056	Economy	16400.00
0005432154110	7056	Economy	16400.00
0005434409285	7056	Economy	16400.00
0005434409313	7056	Economy	16400.00
0005434409317	7056	Economy	16400.00
0005432154112	7056	Economy	16400.00
0005434409297	7056	Economy	16400.00
0005435311270	7056	Economy	16400.00
0005434409299	7056	Economy	16400.00
0005434409318	7056	Economy	16400.00
0005434409324	7056	Economy	16400.00
0005434409327	7056	Economy	16400.00
0005435311186	7056	Economy	16400.00
0005434409309	7056	Economy	16400.00
0005434300139	7056	Economy	16400.00
0005434300125	7056	Economy	16400.00
0005434409296	7056	Economy	16400.00
0005434409290	7056	Economy	16400.00
0005434409287	7056	Economy	16400.00
0005435293459	7056	Economy	16400.00
0005434409304	7056	Economy	16400.00
0005434409284	7056	Economy	16400.00
0005435293434	7056	Economy	16400.00
0005435293478	7056	Economy	18000.00
0005435311252	7056	Economy	18000.00
0005435311262	7056	Economy	18000.00
0005434300124	7056	Economy	18000.00
0005435311191	7056	Economy	18000.00
0005434409300	7056	Economy	18000.00
0005434409338	7056	Economy	16400.00
0005434409301	7056	Economy	16400.00
0005435311269	7056	Economy	16400.00
0005432108313	7056	Economy	16400.00
0005434409295	7056	Economy	16400.00
0005432108314	7056	Economy	16400.00
0005434409334	7056	Economy	16400.00
0005434300131	7056	Economy	16400.00
0005435311232	7056	Economy	16400.00
0005434409307	7056	Economy	16400.00
0005435311244	7056	Economy	16400.00
0005434409323	7056	Economy	16400.00
0005435293458	7056	Economy	16400.00
0005434300142	7056	Economy	16400.00
0005434409335	7056	Economy	16400.00
0005435311265	7056	Economy	16400.00
0005435311204	7056	Economy	16400.00
0005434409332	7056	Economy	16400.00
0005435293439	7056	Economy	16400.00
0005434409339	7056	Economy	16400.00
0005434300132	7056	Economy	16400.00
0005434409302	7056	Economy	16400.00
0005434409286	7056	Economy	16400.00
0005434409305	7056	Economy	16400.00
0005435293446	7056	Economy	16400.00
0005434409329	7056	Economy	16400.00
0005435293440	7056	Economy	16400.00
0005435311254	7056	Economy	16400.00
0005434409292	7056	Economy	16400.00
0005434409342	7056	Economy	16400.00
0005434409333	7056	Economy	16400.00
0005435293433	7056	Economy	16400.00
0005434409291	7056	Economy	16400.00
0005434300126	7056	Economy	16400.00
0005434409326	7056	Economy	16400.00
0005434409325	7056	Economy	16400.00
0005434409319	7056	Economy	16400.00
0005435293441	7056	Economy	16400.00
0005434409293	7056	Economy	16400.00
0005435311240	7056	Economy	16400.00
0005435311184	7056	Economy	16400.00
0005435293445	7056	Economy	16400.00
0005434409330	7056	Economy	16400.00
0005432154114	7056	Economy	16400.00
0005434409294	7056	Economy	16400.00
0005435311192	7056	Economy	16400.00
0005434409306	7056	Economy	16400.00
0005434409315	7056	Economy	16400.00
0005435293431	7056	Economy	16400.00
0005434409321	7056	Economy	16400.00
0005434409337	7056	Economy	16400.00
0005434300134	7056	Economy	16400.00
0005434409322	7056	Economy	16400.00
0005434300136	7056	Economy	16400.00
0005435293479	7056	Economy	16400.00
0005432154113	7056	Economy	16400.00
0005434409289	7056	Economy	16400.00
0005434409336	7056	Economy	16400.00
0005434300133	7056	Economy	16400.00
0005434409331	7056	Economy	16400.00
0005435311233	7056	Economy	16400.00
0005434300128	7056	Economy	16400.00
0005434300140	7056	Economy	16400.00
0005434409314	7056	Economy	16400.00
0005434300127	7056	Economy	16400.00
0005434300130	7056	Economy	16400.00
0005434409340	7056	Economy	16400.00
0005435311246	7056	Economy	16400.00
0005434409310	7056	Economy	16400.00
0005434299927	26904	Business	49100.00
0005434408724	26904	Business	49100.00
0005434408600	26904	Business	49100.00
0005434299944	26904	Business	49100.00
0005435293559	26904	Business	49100.00
0005434299911	26904	Business	49100.00
0005434408753	26904	Business	49100.00
0005435293560	26904	Business	49100.00
0005434408530	26904	Business	49100.00
0005434299951	26904	Business	49100.00
0005434408734	26904	Business	49100.00
0005434408731	26904	Business	49100.00
0005434408758	26904	Economy	16400.00
0005434408529	26904	Economy	16400.00
0005434300048	26904	Economy	16400.00
0005434408645	26904	Economy	16400.00
0005434408709	26904	Economy	16400.00
0005434408632	26904	Economy	16400.00
0005435311423	26904	Economy	16400.00
0005435311428	26904	Economy	16400.00
0005435293555	26904	Economy	16400.00
0005434408294	26904	Economy	16400.00
0005434299906	26904	Economy	16400.00
0005435311426	26904	Economy	16400.00
0005434408565	26904	Economy	16400.00
0005434408864	26904	Economy	16400.00
0005435293563	26904	Economy	16400.00
0005434408644	26904	Economy	16400.00
0005434408865	26904	Economy	16400.00
0005434299916	26904	Economy	16400.00
0005434408546	26904	Economy	16400.00
0005434408823	26904	Economy	16400.00
0005434408567	26904	Economy	16400.00
0005435311424	26904	Economy	16400.00
0005435293567	26904	Economy	16400.00
0005434408202	26904	Economy	16400.00
0005435293566	26904	Economy	16400.00
0005434408633	26904	Economy	16400.00
0005435311429	26904	Economy	16400.00
0005434408682	26904	Economy	16400.00
0005434408853	26904	Economy	16400.00
0005434299929	26904	Economy	16400.00
0005434408396	26904	Economy	16400.00
0005434408882	26904	Economy	16400.00
0005434408498	26904	Economy	16400.00
0005434408760	26904	Economy	16400.00
0005434408437	26904	Economy	16400.00
0005434408381	26904	Economy	16400.00
0005435293561	26904	Economy	16400.00
0005434408470	26904	Economy	16400.00
0005434408659	26904	Economy	16400.00
0005434408967	26904	Economy	16400.00
0005435311425	26904	Economy	18000.00
0005434299855	26904	Economy	18000.00
0005432058476	26904	Economy	18000.00
0005434408547	26904	Economy	18000.00
0005434408710	26904	Economy	18000.00
0005432058477	26904	Economy	18000.00
0005434408630	26904	Economy	16400.00
0005434408387	26904	Economy	16400.00
0005434300018	26904	Economy	16400.00
0005434299968	26904	Economy	16400.00
0005434299986	26904	Economy	16400.00
0005434408661	26904	Economy	16400.00
0005434299884	26904	Economy	16400.00
0005434408757	26904	Economy	16400.00
0005434299963	26904	Economy	16400.00
0005435293565	26904	Economy	16400.00
0005434408899	26904	Economy	16400.00
0005434408293	26904	Economy	16400.00
0005434408578	26904	Economy	16400.00
0005434299942	26904	Economy	16400.00
0005434299912	26904	Economy	16400.00
0005434408516	26904	Economy	16400.00
0005434408817	26904	Economy	16400.00
0005434299862	26904	Economy	16400.00
0005434408812	26904	Economy	16400.00
0005435311427	26904	Economy	16400.00
0005434299902	26904	Economy	16400.00
0005434408723	26904	Economy	16400.00
0005435293562	26904	Economy	16400.00
0005434408754	26904	Economy	16400.00
0005435293564	26904	Economy	16400.00
0005434408656	26904	Economy	16400.00
0005434408738	26904	Economy	16400.00
0005435311430	26904	Economy	16400.00
0005434408824	26904	Economy	16400.00
0005434408469	26904	Economy	16400.00
0005434408568	26904	Economy	16400.00
0005434408786	26904	Economy	16400.00
0005434408893	26904	Economy	16400.00
0005434408615	26904	Economy	16400.00
0005434408830	26904	Economy	16400.00
0005434408554	26904	Economy	16400.00
0005434408813	26904	Economy	16400.00
0005435293558	26904	Economy	16400.00
0005434408900	26904	Economy	16400.00
0005434300044	26904	Economy	16400.00
0005434408943	26904	Economy	16400.00
0005434408545	26904	Economy	16400.00
0005434408713	26904	Economy	16400.00
0005434299915	26904	Economy	16400.00
0005434408513	26904	Economy	16400.00
0005434408693	26904	Economy	16400.00
0005434299987	26904	Economy	16400.00
0005434299881	26904	Economy	16400.00
0005435311422	26904	Economy	16400.00
0005434299843	26904	Economy	16400.00
0005434299921	26904	Economy	16400.00
0005434299926	26904	Economy	16400.00
0005434299928	26904	Economy	16400.00
0005434408816	26904	Economy	16400.00
0005434300008	26904	Economy	16400.00
0005434408631	26904	Economy	16400.00
0005434408616	26904	Economy	16400.00
0005435293556	26904	Economy	16400.00
0005434408881	26904	Economy	16400.00
0005434408641	26904	Economy	16400.00
0005434408606	26904	Economy	16400.00
0005434408737	26904	Economy	16400.00
0005434408732	26904	Economy	16400.00
0005434408684	26904	Economy	16400.00
0005434299913	26904	Economy	16400.00
0005435293557	26904	Economy	16400.00
0005434408438	26904	Economy	16400.00
0005432058475	26904	Economy	16400.00
0005434408906	26904	Economy	16400.00
0005434408643	26904	Economy	16400.00
0005434299969	26904	Economy	16400.00
0005434300017	26904	Economy	16400.00
0005432605330	6458	Economy	16500.00
0005432605335	6458	Economy	16500.00
0005432605331	6458	Economy	15000.00
0005432605301	6458	Economy	15000.00
0005432605338	6458	Economy	15000.00
0005432605325	6458	Economy	15000.00
0005434512227	6458	Economy	15000.00
0005432605316	6458	Economy	15000.00
0005432605324	6458	Economy	15000.00
0005432605327	6458	Economy	15000.00
0005432605310	6458	Economy	15000.00
0005432605314	6458	Economy	15000.00
0005434512230	6458	Economy	15000.00
0005432605333	6458	Economy	15000.00
0005432605322	6458	Economy	15000.00
0005432605336	6458	Economy	15000.00
0005432605303	6458	Economy	15000.00
0005432605323	6458	Economy	15000.00
0005432605313	6458	Economy	15000.00
0005432605321	6458	Economy	15000.00
0005432605340	6458	Economy	15000.00
0005432605308	6458	Economy	15000.00
0005432605317	6458	Economy	15000.00
0005432605309	6458	Economy	15000.00
0005434512229	6458	Economy	15000.00
0005432605319	6458	Economy	15000.00
0005432605326	6458	Economy	15000.00
0005432605339	6458	Economy	15000.00
0005432605312	6458	Economy	15000.00
0005432605337	6458	Economy	15000.00
0005432605334	6458	Economy	15000.00
0005432605328	6458	Economy	15000.00
0005432605332	6458	Economy	15000.00
0005432605305	6458	Economy	15000.00
0005432605302	6458	Economy	15000.00
0005432605304	6458	Economy	15000.00
0005432605306	6458	Economy	15000.00
0005432605311	6458	Economy	15000.00
0005434512228	6458	Economy	15000.00
0005432605341	6458	Economy	15000.00
0005432605329	6458	Economy	15000.00
0005432605315	6458	Economy	15000.00
0005432605307	6458	Economy	15000.00
0005432605318	6458	Economy	15000.00
0005432605320	6458	Economy	15000.00
0005432604821	21347	Economy	16500.00
0005432604961	21347	Economy	16500.00
0005432605014	21347	Economy	16500.00
0005432604969	21347	Economy	16500.00
0005434512191	21347	Economy	15000.00
0005432604968	21347	Economy	15000.00
0005432604834	21347	Economy	15000.00
0005432604974	21347	Economy	15000.00
0005432604955	21347	Economy	15000.00
0005432604818	21347	Economy	15000.00
0005432604869	21347	Economy	15000.00
0005435312905	21347	Economy	15000.00
0005432605020	21347	Economy	15000.00
0005432604956	21347	Economy	15000.00
0005435221079	21347	Economy	15000.00
0005432604870	21347	Economy	15000.00
0005434512188	21347	Economy	15000.00
0005432604922	21347	Economy	15000.00
0005435312904	21347	Economy	15000.00
0005435221552	21347	Economy	15000.00
0005432604882	21347	Economy	15000.00
0005432604992	21347	Economy	15000.00
0005434512184	21347	Economy	15000.00
0005432604940	21347	Economy	15000.00
0005434512205	21347	Economy	15000.00
0005434512204	21347	Economy	15000.00
0005432605019	21347	Economy	15000.00
0005432604783	21347	Economy	15000.00
0005432605070	21347	Economy	15000.00
0005432604872	21347	Economy	15000.00
0005432604905	21347	Economy	15000.00
0005432605101	21347	Economy	15000.00
0005432604886	21347	Economy	15000.00
0005432604907	21347	Economy	15000.00
0005432604975	21347	Economy	15000.00
0005432604954	21347	Economy	15000.00
0005434512164	21347	Economy	15000.00
0005432604797	21347	Economy	15000.00
0005432604963	21347	Economy	15000.00
0005432605018	21347	Economy	15000.00
0005434512218	21347	Economy	15000.00
0005435221551	21347	Economy	15000.00
0005432605060	21347	Economy	15000.00
0005434512183	21347	Economy	15000.00
0005435221078	21347	Economy	15000.00
0005432604885	21347	Economy	15000.00
0005434512175	21347	Economy	15000.00
0005433252252	15027	Business	18900.00
0005434907889	15027	Business	18900.00
0005433252247	15027	Business	18900.00
0005433252234	15027	Business	18900.00
0005433252253	15027	Business	18900.00
0005434908010	15027	Business	18900.00
0005434908213	15027	Business	18900.00
0005433252224	15027	Business	18900.00
0005434908048	15027	Business	18900.00
0005434908035	15027	Business	18900.00
0005434908085	15027	Business	18900.00
0005434908184	15027	Business	18900.00
0005434908108	15027	Economy	6300.00
0005434908057	15027	Economy	6300.00
0005433252241	15027	Economy	6300.00
0005434908094	15027	Economy	6300.00
0005433252225	15027	Economy	6300.00
0005434908062	15027	Economy	6300.00
0005434908032	15027	Economy	6300.00
0005433252240	15027	Economy	6300.00
0005433252242	15027	Economy	6900.00
0005434908065	15027	Economy	6900.00
0005434908034	15027	Economy	6900.00
0005434907888	15027	Economy	6300.00
0005434908185	15027	Economy	6300.00
0005433252238	15027	Economy	6300.00
0005434907947	15027	Economy	6300.00
0005433252228	15027	Economy	6300.00
0005433252250	15027	Economy	6300.00
0005434908069	15027	Economy	6300.00
0005434908157	15027	Economy	6300.00
0005434908120	15027	Economy	6300.00
0005434908009	15027	Economy	6300.00
0005434908044	15027	Economy	6300.00
0005433252248	15027	Economy	6300.00
0005433252246	15027	Economy	6300.00
0005434908222	15027	Economy	6300.00
0005433252245	15027	Economy	6300.00
0005434908233	15027	Economy	6300.00
0005433252236	15027	Economy	6300.00
0005434908049	15027	Economy	6300.00
0005434908087	15027	Economy	6300.00
0005433252251	15027	Economy	6300.00
0005433252249	15027	Economy	6300.00
0005434908058	15027	Economy	6300.00
0005434907890	15027	Economy	6300.00
0005434907946	15027	Economy	6300.00
0005434907783	15027	Economy	6300.00
0005434908063	15027	Economy	6300.00
0005434907934	15027	Economy	6300.00
0005433252244	15027	Economy	6300.00
0005434908043	15027	Economy	6300.00
0005433252231	15027	Economy	6300.00
0005434908243	15027	Economy	6300.00
0005433252235	15027	Economy	6300.00
0005434908150	15027	Economy	6300.00
0005434908110	15027	Economy	6300.00
0005434907776	15027	Economy	6300.00
0005433252243	15027	Economy	6300.00
0005434908221	15027	Economy	6300.00
0005434908273	15027	Economy	6300.00
0005433252223	15027	Economy	6300.00
0005434908182	15027	Economy	6300.00
0005434908201	15027	Economy	6300.00
0005433252232	15027	Economy	6300.00
0005434908093	15027	Economy	6300.00
0005434908016	15027	Economy	6300.00
0005433252227	15027	Economy	6300.00
0005434908047	15027	Economy	6300.00
0005433252233	15027	Economy	6300.00
0005434908151	15027	Economy	6300.00
0005433252230	15027	Economy	6300.00
0005434908033	15027	Economy	6300.00
0005434908158	15027	Economy	6300.00
0005433252226	15027	Economy	6300.00
0005434907849	15027	Economy	6300.00
0005433252229	15027	Economy	6300.00
0005433252237	15027	Economy	6300.00
0005434907891	15027	Economy	6300.00
0005434908199	15027	Economy	6300.00
0005434908086	15027	Economy	6300.00
0005433252239	15027	Economy	6300.00
0005434907983	15027	Economy	6300.00
0005433251961	25835	Business	18900.00
0005434908514	25835	Business	18900.00
0005433251993	25835	Business	18900.00
0005434908545	25835	Business	18900.00
0005434908531	25835	Business	18900.00
0005433251918	25835	Business	18900.00
0005433251884	25835	Business	18900.00
0005433251923	25835	Business	18900.00
0005434908523	25835	Business	18900.00
0005433251962	25835	Business	18900.00
0005433251845	25835	Economy	6300.00
0005434908546	25835	Economy	6300.00
0005434908538	25835	Economy	6300.00
0005434908528	25835	Economy	6300.00
0005433251983	25835	Economy	6300.00
0005433251808	25835	Economy	6300.00
0005434908519	25835	Economy	6300.00
0005434908536	25835	Economy	6300.00
0005434908542	25835	Economy	6300.00
0005434908548	25835	Economy	6900.00
0005434908512	25835	Economy	6900.00
0005433251977	25835	Economy	6900.00
0005434908509	25835	Economy	6900.00
0005433251922	25835	Economy	6900.00
0005434908524	25835	Economy	6300.00
0005434908535	25835	Economy	6300.00
0005434908525	25835	Economy	6300.00
0005433251952	25835	Economy	6300.00
0005433251948	25835	Economy	6300.00
0005433252033	25835	Economy	6300.00
0005433251894	25835	Economy	6300.00
0005433251875	25835	Economy	6300.00
0005433252021	25835	Economy	6300.00
0005434908520	25835	Economy	6300.00
0005434908518	25835	Economy	6300.00
0005433251895	25835	Economy	6300.00
0005434908532	25835	Economy	6300.00
0005433251975	25835	Economy	6300.00
0005434908513	25835	Economy	6300.00
0005433251978	25835	Economy	6300.00
0005433251913	25835	Economy	6300.00
0005434908511	25835	Economy	6300.00
0005433252053	25835	Economy	6300.00
0005434908533	25835	Economy	6300.00
0005434908534	25835	Economy	6300.00
0005434908522	25835	Economy	6300.00
0005434908547	25835	Economy	6300.00
0005434908543	25835	Economy	6300.00
0005434908544	25835	Economy	6300.00
0005433251926	25835	Economy	6300.00
0005434908508	25835	Economy	6300.00
0005433252096	25835	Economy	6300.00
0005434908526	25835	Economy	6300.00
0005433251927	25835	Economy	6300.00
0005434908507	25835	Economy	6300.00
0005434908510	25835	Economy	6300.00
0005434908549	25835	Economy	6300.00
0005434908516	25835	Economy	6300.00
0005433251951	25835	Economy	6300.00
0005434908540	25835	Economy	6300.00
0005434908550	25835	Economy	6300.00
0005434908505	25835	Economy	6300.00
0005434908530	25835	Economy	6300.00
0005434908506	25835	Economy	6300.00
0005433252018	25835	Economy	6300.00
0005433251807	25835	Economy	6300.00
0005433251992	25835	Economy	6300.00
0005434908541	25835	Economy	6300.00
0005433251844	25835	Economy	6300.00
0005434908539	25835	Economy	6300.00
0005434908521	25835	Economy	6300.00
0005433252000	25835	Economy	6300.00
0005433251885	25835	Economy	6300.00
0005434908504	25835	Economy	6300.00
0005433251989	25835	Economy	6300.00
0005433251984	25835	Economy	6300.00
0005434908517	25835	Economy	6300.00
0005433251883	25835	Economy	6300.00
0005433251985	25835	Economy	6300.00
0005434908529	25835	Economy	6300.00
0005434908537	25835	Economy	6300.00
0005433251949	25835	Economy	6300.00
0005434908515	25835	Economy	6300.00
0005434908527	25835	Economy	6300.00
0005433009741	14167	Business	52300.00
0005433009725	14167	Business	52300.00
0005433009726	14167	Business	52300.00
0005433009734	14167	Business	52300.00
0005433009768	14167	Business	52300.00
0005433009762	14167	Business	52300.00
0005433009728	14167	Business	52300.00
0005433009744	14167	Business	52300.00
0005433009727	14167	Economy	17400.00
0005433009756	14167	Economy	17400.00
0005433009745	14167	Economy	19200.00
0005433810596	14167	Economy	19200.00
0005433009740	14167	Economy	19200.00
0005433009746	14167	Economy	19200.00
0005433009758	14167	Economy	19200.00
0005433009757	14167	Economy	17400.00
0005433009750	14167	Economy	17400.00
0005433009751	14167	Economy	17400.00
0005433009749	14167	Economy	17400.00
0005433009730	14167	Economy	17400.00
0005433009760	14167	Economy	17400.00
0005433009765	14167	Economy	17400.00
0005433009739	14167	Economy	17400.00
0005433009764	14167	Economy	17400.00
0005433009733	14167	Economy	17400.00
0005433009738	14167	Economy	17400.00
0005433009759	14167	Economy	17400.00
0005433009731	14167	Economy	17400.00
0005433009748	14167	Economy	17400.00
0005433009767	14167	Economy	17400.00
0005433009724	14167	Economy	17400.00
0005433009753	14167	Economy	17400.00
0005433009754	14167	Economy	17400.00
0005433009761	14167	Economy	17400.00
0005433009742	14167	Economy	17400.00
0005433009736	14167	Economy	17400.00
0005433810588	14167	Economy	17400.00
0005433009766	14167	Economy	17400.00
0005433009735	14167	Economy	17400.00
0005433009729	14167	Economy	17400.00
0005433009737	14167	Economy	17400.00
0005433009743	14167	Economy	17400.00
0005433810583	14167	Economy	17400.00
0005433810595	14167	Economy	17400.00
0005433009752	14167	Economy	17400.00
0005433009763	14167	Economy	17400.00
0005433810587	14167	Economy	17400.00
0005433009769	14167	Economy	17400.00
0005433009755	14167	Economy	17400.00
0005433009732	14167	Economy	17400.00
0005433009747	14167	Economy	17400.00
0005433009069	22874	Business	52300.00
0005433810672	22874	Business	52300.00
0005433009460	22874	Business	52300.00
0005433810670	22874	Economy	17400.00
0005433009440	22874	Economy	17400.00
0005433009398	22874	Economy	17400.00
0005433009419	22874	Economy	17400.00
0005433009261	22874	Economy	19200.00
0005433009253	22874	Economy	19200.00
0005433009413	22874	Economy	17400.00
0005433009086	22874	Economy	17400.00
0005433009392	22874	Economy	17400.00
0005433009235	22874	Economy	17400.00
0005433009303	22874	Economy	17400.00
0005433009441	22874	Economy	17400.00
0005433009414	22874	Economy	17400.00
0005433810673	22874	Economy	17400.00
0005433009264	22874	Economy	17400.00
0005433009189	22874	Economy	17400.00
0005433009313	22874	Economy	17400.00
0005433009404	22874	Economy	17400.00
0005433009190	22874	Economy	17400.00
0005433009201	22874	Economy	17400.00
0005433810677	22874	Economy	17400.00
0005433009209	22874	Economy	17400.00
0005433009282	22874	Economy	17400.00
0005433009406	22874	Economy	17400.00
0005433009490	22874	Economy	17400.00
0005433009422	22874	Economy	17400.00
0005433009300	22874	Economy	17400.00
0005433810674	22874	Economy	17400.00
0005433009421	22874	Economy	17400.00
0005433009319	22874	Economy	17400.00
0005433009084	22874	Economy	17400.00
0005433009085	22874	Economy	17400.00
0005433009343	22874	Economy	17400.00
0005433009260	22874	Economy	17400.00
0005433810676	22874	Economy	17400.00
0005433009344	22874	Economy	17400.00
0005433009281	22874	Economy	17400.00
0005433009202	22874	Economy	17400.00
0005433009491	22874	Economy	17400.00
0005433810671	22874	Economy	17400.00
0005433009461	22874	Economy	17400.00
0005433810675	22874	Economy	17400.00
0005433009442	22874	Economy	17400.00
0005433009462	22874	Economy	17400.00
0005433009234	22874	Economy	17400.00
0005434926113	14921	Business	22900.00
0005434926299	14921	Business	22900.00
0005434926112	14921	Business	22900.00
0005434926232	14921	Business	22900.00
0005434926242	14921	Business	22900.00
0005434926286	14921	Economy	7600.00
0005434926285	14921	Economy	7600.00
0005434926237	14921	Economy	7600.00
0005434926298	14921	Economy	7600.00
0005434926315	14921	Economy	8400.00
0005434926233	14921	Economy	8400.00
0005434926250	14921	Economy	8400.00
0005434926179	14921	Economy	7600.00
0005434926312	14921	Economy	7600.00
0005434926178	14921	Economy	7600.00
0005434926235	14921	Economy	7600.00
0005434926297	14921	Economy	7600.00
0005434926177	14921	Economy	7600.00
0005434926247	14921	Economy	7600.00
0005434926241	14921	Economy	7600.00
0005434926243	14921	Economy	7600.00
0005434926282	14921	Economy	7600.00
0005434926224	14921	Economy	7600.00
0005434926180	14921	Economy	7600.00
0005434926264	14921	Economy	7600.00
0005434926288	14921	Economy	7600.00
0005434926260	14921	Economy	7600.00
0005434926225	14921	Economy	7600.00
0005434926291	14921	Economy	7600.00
0005434926263	14921	Economy	7600.00
0005434926236	14921	Economy	7600.00
0005434926167	14921	Economy	7600.00
0005434926204	14921	Economy	7600.00
0005434926314	14921	Economy	7600.00
0005434926311	14921	Economy	7600.00
0005434926166	14921	Economy	7600.00
0005434926205	14921	Economy	7600.00
0005434926265	14921	Economy	7600.00
0005434926313	14921	Economy	7600.00
0005434926125	14921	Economy	7600.00
0005434926586	20494	Business	22900.00
0005434926556	20494	Business	22900.00
0005434926558	20494	Business	22900.00
0005434926577	20494	Business	22900.00
0005434926572	20494	Business	22900.00
0005434926588	20494	Economy	7600.00
0005434926554	20494	Economy	7600.00
0005434926587	20494	Economy	7600.00
0005434926573	20494	Economy	8400.00
0005434926581	20494	Economy	8400.00
0005434926571	20494	Economy	8400.00
0005434926561	20494	Economy	7600.00
0005434926553	20494	Economy	7600.00
0005434926578	20494	Economy	7600.00
0005434926563	20494	Economy	7600.00
0005434926582	20494	Economy	7600.00
0005434926551	20494	Economy	7600.00
0005434926568	20494	Economy	7600.00
0005434926559	20494	Economy	7600.00
0005434926584	20494	Economy	7600.00
0005434926574	20494	Economy	7600.00
0005434926579	20494	Economy	7600.00
0005434926560	20494	Economy	7600.00
0005434926564	20494	Economy	7600.00
0005434926557	20494	Economy	7600.00
0005434926580	20494	Economy	7600.00
0005434926576	20494	Economy	7600.00
0005434926555	20494	Economy	7600.00
0005434926585	20494	Economy	7600.00
0005434926567	20494	Economy	7600.00
0005434926552	20494	Economy	7600.00
0005434926569	20494	Economy	7600.00
0005434926583	20494	Economy	7600.00
0005434926570	20494	Economy	7600.00
0005434926565	20494	Economy	7600.00
0005434926575	20494	Economy	7600.00
0005434926566	20494	Economy	7600.00
0005434926562	20494	Economy	7600.00
0005435488378	15807	Economy	8900.00
0005435999540	15807	Economy	8900.00
0005435999501	15807	Economy	8900.00
0005435488383	15807	Economy	8100.00
0005435488380	15807	Economy	8100.00
0005435999520	15807	Economy	8100.00
0005435488373	15807	Economy	8100.00
0005435488379	15807	Economy	8100.00
0005435999500	15807	Economy	8100.00
0005435999446	15807	Economy	8100.00
0005435999499	15807	Economy	8100.00
0005435999532	15807	Economy	8100.00
0005435488367	15807	Economy	8100.00
0005435488364	15807	Economy	8100.00
0005435488377	15807	Economy	8100.00
0005435999511	15807	Economy	8100.00
0005435999495	15807	Economy	8100.00
0005435488369	15807	Economy	8100.00
0005435488375	15807	Economy	8100.00
0005435488362	15807	Economy	8100.00
0005435999497	15807	Economy	8100.00
0005435999543	15807	Economy	8100.00
0005435488365	15807	Economy	8100.00
0005435999504	15807	Economy	8100.00
0005435999531	15807	Economy	8100.00
0005435488381	15807	Economy	8100.00
0005435488370	15807	Economy	8100.00
0005435999489	15807	Economy	8100.00
0005435999550	15807	Economy	8100.00
0005435999447	15807	Economy	8100.00
0005435999498	15807	Economy	8100.00
0005435999507	15807	Economy	8100.00
0005435999549	15807	Economy	8100.00
0005435488374	15807	Economy	8100.00
0005435488371	15807	Economy	8100.00
0005435488382	15807	Economy	8100.00
0005435999548	15807	Economy	8100.00
0005435999494	15807	Economy	8100.00
0005435488366	15807	Economy	8100.00
0005435488368	15807	Economy	8100.00
0005435999519	15807	Economy	8100.00
0005435488376	15807	Economy	8100.00
0005435488372	15807	Economy	8100.00
0005435999518	15807	Economy	8100.00
0005435488363	15807	Economy	8100.00
0005435999694	19671	Economy	8900.00
0005435999678	19671	Economy	8900.00
0005435999676	19671	Economy	8900.00
0005435488149	19671	Economy	8900.00
0005435999692	19671	Economy	8100.00
0005435999675	19671	Economy	8100.00
0005435488053	19671	Economy	8100.00
0005435488246	19671	Economy	8100.00
0005435999685	19671	Economy	8100.00
0005435999689	19671	Economy	8100.00
0005435999671	19671	Economy	8100.00
0005435999674	19671	Economy	8100.00
0005435488147	19671	Economy	8100.00
0005435999690	19671	Economy	8100.00
0005435999684	19671	Economy	8100.00
0005435488145	19671	Economy	8100.00
0005435999687	19671	Economy	8100.00
0005435999673	19671	Economy	8100.00
0005435488140	19671	Economy	8100.00
0005435488108	19671	Economy	8100.00
0005435488157	19671	Economy	8100.00
0005435488144	19671	Economy	8100.00
0005435999681	19671	Economy	8100.00
0005435488146	19671	Economy	8100.00
0005435999696	19671	Economy	8100.00
0005435488054	19671	Economy	8100.00
0005435488107	19671	Economy	8100.00
0005435488102	19671	Economy	8100.00
0005435488115	19671	Economy	8100.00
0005435999680	19671	Economy	8100.00
0005435999695	19671	Economy	8100.00
0005435488156	19671	Economy	8100.00
0005435999682	19671	Economy	8100.00
0005435488119	19671	Economy	8100.00
0005435999686	19671	Economy	8100.00
0005435999679	19671	Economy	8100.00
0005435999672	19671	Economy	8100.00
0005435999677	19671	Economy	8100.00
0005435488218	19671	Economy	8100.00
0005435488217	19671	Economy	8100.00
0005435999693	19671	Economy	8100.00
0005435999691	19671	Economy	8100.00
0005435488148	19671	Economy	8100.00
0005435488068	19671	Economy	8100.00
0005435999697	19671	Economy	8100.00
0005435999683	19671	Economy	8100.00
0005435999688	19671	Economy	8100.00
0005435840161	5981	Business	199300.00
0005432660870	5981	Business	199300.00
0005435472997	5981	Business	199300.00
0005435473129	5981	Business	199300.00
0005435840138	5981	Business	199300.00
0005435472989	5981	Business	199300.00
0005435840157	5981	Business	199300.00
0005435473067	5981	Business	199300.00
0005435840141	5981	Business	199300.00
0005435473075	5981	Business	199300.00
0005432537097	5981	Business	199300.00
0005435840156	5981	Business	199300.00
0005435473036	5981	Business	199300.00
0005435840142	5981	Economy	66400.00
0005435840154	5981	Economy	66400.00
0005435473053	5981	Economy	66400.00
0005432660873	5981	Economy	66400.00
0005435473060	5981	Economy	66400.00
0005435840164	5981	Economy	66400.00
0005435473070	5981	Economy	73100.00
0005435472996	5981	Economy	66400.00
0005435840139	5981	Economy	73100.00
0005432537091	5981	Economy	66400.00
0005432658645	5981	Economy	66400.00
0005435617236	5981	Economy	66400.00
0005435840158	5981	Economy	66400.00
0005435840155	5981	Economy	66400.00
0005435840145	5981	Economy	66400.00
0005435840146	5981	Economy	66400.00
0005435473035	5981	Economy	66400.00
0005435473052	5981	Economy	66400.00
0005435840137	5981	Economy	66400.00
0005432659760	5981	Economy	66400.00
0005435840150	5981	Economy	66400.00
0005435473047	5981	Economy	66400.00
0005435473072	5981	Economy	66400.00
0005435473048	5981	Economy	66400.00
0005435840153	5981	Economy	66400.00
0005435840159	5981	Economy	66400.00
0005435840144	5981	Economy	66400.00
0005432142330	5981	Economy	66400.00
0005435840149	5981	Economy	66400.00
0005435840160	5981	Economy	66400.00
0005435840162	5981	Economy	66400.00
0005432659759	5981	Economy	66400.00
0005432658644	5981	Economy	66400.00
0005435840147	5981	Economy	66400.00
0005435473118	5981	Economy	66400.00
0005432142329	5981	Economy	66400.00
0005435840151	5981	Economy	66400.00
0005435840143	5981	Economy	66400.00
0005435473071	5981	Economy	66400.00
0005435840165	5981	Economy	66400.00
0005435473058	5981	Economy	66400.00
0005435473105	5981	Economy	66400.00
0005435473066	5981	Economy	66400.00
0005432660871	5981	Economy	66400.00
0005435472990	5981	Economy	66400.00
0005432660872	5981	Economy	66400.00
0005435840152	5981	Economy	66400.00
0005435840140	5981	Economy	66400.00
0005435840148	5981	Economy	66400.00
0005435617237	5981	Economy	66400.00
0005435840163	5981	Economy	66400.00
0005435839921	18060	Business	199300.00
0005432537111	18060	Business	199300.00
0005435839954	18060	Business	199300.00
0005435839956	18060	Business	199300.00
0005435473216	18060	Business	199300.00
0005432660844	18060	Business	199300.00
0005432664161	18060	Business	199300.00
0005432667481	18060	Economy	66400.00
0005435839878	18060	Economy	66400.00
0005435473208	18060	Economy	66400.00
0005435840002	18060	Economy	66400.00
0005435839839	18060	Economy	66400.00
0005432664160	18060	Economy	66400.00
0005435473217	18060	Economy	73100.00
0005435840003	18060	Economy	73100.00
0005435473211	18060	Economy	66400.00
0005435839836	18060	Economy	66400.00
0005432537113	18060	Economy	66400.00
0005435473207	18060	Economy	66400.00
0005435473215	18060	Economy	66400.00
0005432667482	18060	Economy	66400.00
0005432660845	18060	Economy	66400.00
0005435839751	18060	Economy	66400.00
0005432667484	18060	Economy	66400.00
0005435473204	18060	Economy	66400.00
0005435473205	18060	Economy	66400.00
0005435473214	18060	Economy	66400.00
0005435839838	18060	Economy	66400.00
0005432667485	18060	Economy	66400.00
0005435839930	18060	Economy	66400.00
0005435839992	18060	Economy	66400.00
0005435839986	18060	Economy	66400.00
0005435839917	18060	Economy	66400.00
0005432537112	18060	Economy	66400.00
0005435839926	18060	Economy	66400.00
0005435839918	18060	Economy	66400.00
0005435473213	18060	Economy	66400.00
0005432660850	18060	Economy	66400.00
0005435839947	18060	Economy	66400.00
0005435473210	18060	Economy	66400.00
0005435840067	18060	Economy	66400.00
0005435839938	18060	Economy	66400.00
0005435473206	18060	Economy	66400.00
0005435473212	18060	Economy	66400.00
0005435839899	18060	Economy	66400.00
0005435839939	18060	Economy	66400.00
0005435839868	18060	Economy	66400.00
0005435473209	18060	Economy	66400.00
0005433285911	22999	Business	15700.00
0005433285907	22999	Business	15700.00
0005433285827	22999	Business	15700.00
0005435104167	22999	Business	15700.00
0005433285711	22999	Business	15700.00
0005433285796	22999	Economy	5200.00
0005433285678	22999	Economy	5200.00
0005435104166	22999	Economy	5200.00
0005433285955	22999	Economy	5200.00
0005435104162	22999	Economy	5200.00
0005433285866	22999	Economy	5200.00
0005435104164	22999	Economy	5200.00
0005435104165	22999	Economy	5200.00
0005433285875	22999	Economy	5200.00
0005435104159	22999	Economy	5200.00
0005433285867	22999	Economy	5200.00
0005433285745	22999	Economy	5200.00
0005435104156	22999	Economy	5200.00
0005435104151	22999	Economy	5200.00
0005433285715	22999	Economy	5200.00
0005433285769	22999	Economy	5700.00
0005433285712	22999	Economy	5200.00
0005435104157	22999	Economy	5200.00
0005433285917	22999	Economy	5200.00
0005433285722	22999	Economy	5200.00
0005433285805	22999	Economy	5200.00
0005433285808	22999	Economy	5200.00
0005433285822	22999	Economy	5200.00
0005433285650	22999	Economy	5200.00
0005433285716	22999	Economy	5200.00
0005435104153	22999	Economy	5200.00
0005435104155	22999	Economy	5200.00
0005433285795	22999	Economy	5200.00
0005433285770	22999	Economy	5200.00
0005433285714	22999	Economy	5200.00
0005433285914	22999	Economy	5200.00
0005433285859	22999	Economy	5200.00
0005435104160	22999	Economy	5200.00
0005435104158	22999	Economy	5200.00
0005435104154	22999	Economy	5200.00
0005435104152	22999	Economy	5200.00
0005433285857	22999	Economy	5200.00
0005433285752	22999	Economy	5200.00
0005435104150	22999	Economy	5200.00
0005435104161	22999	Economy	5200.00
0005433285775	22999	Economy	5200.00
0005435104163	22999	Economy	5200.00
0005433286079	32053	Business	15700.00
0005433286076	32053	Business	15700.00
0005433286088	32053	Business	15700.00
0005433286058	32053	Business	15700.00
0005433286087	32053	Economy	5200.00
0005433286068	32053	Economy	5200.00
0005433286081	32053	Economy	5200.00
0005433286069	32053	Economy	5200.00
0005435104036	32053	Economy	5200.00
0005435104024	32053	Economy	5200.00
0005433286067	32053	Economy	5200.00
0005433286072	32053	Economy	5200.00
0005433286064	32053	Economy	5200.00
0005433286060	32053	Economy	5200.00
0005433286071	32053	Economy	5700.00
0005433286063	32053	Economy	5200.00
0005435104031	32053	Economy	5200.00
0005433286080	32053	Economy	5200.00
0005433286075	32053	Economy	5200.00
0005433286083	32053	Economy	5200.00
0005433286070	32053	Economy	5200.00
0005433286077	32053	Economy	5200.00
0005435104001	32053	Economy	5200.00
0005433286061	32053	Economy	5200.00
0005433286078	32053	Economy	5200.00
0005435104000	32053	Economy	5200.00
0005435104020	32053	Economy	5200.00
0005433286074	32053	Economy	5200.00
0005433286084	32053	Economy	5200.00
0005435104019	32053	Economy	5200.00
0005433286065	32053	Economy	5200.00
0005435104037	32053	Economy	5200.00
0005433286082	32053	Economy	5200.00
0005433286059	32053	Economy	5200.00
0005433286066	32053	Economy	5200.00
0005435104017	32053	Economy	5200.00
0005433286062	32053	Economy	5200.00
0005433286073	32053	Economy	5200.00
0005433286086	32053	Economy	5200.00
0005433286085	32053	Economy	5200.00
0005435215268	30593	Business	42100.00
0005432530564	30593	Business	42100.00
0005434068419	30593	Business	42100.00
0005434068531	30593	Business	42100.00
0005434068532	30593	Business	42100.00
0005434068570	30593	Business	42100.00
0005432530264	30593	Business	42100.00
0005434068648	30593	Business	42100.00
0005432529986	30593	Business	42100.00
0005434068518	30593	Business	42100.00
0005432529695	30593	Business	42100.00
0005434068647	30593	Business	42100.00
0005435215301	30593	Business	42100.00
0005432530425	30593	Business	42100.00
0005435215266	30593	Business	42100.00
0005435725725	30593	Business	42100.00
0005435215254	30593	Business	42100.00
0005432530111	30593	Business	42100.00
0005432530095	30593	Business	42100.00
0005434068895	30593	Business	42100.00
0005432530509	30593	Business	42100.00
0005432530221	30593	Business	42100.00
0005435215287	30593	Business	42100.00
0005432530510	30593	Business	42100.00
0005432529937	30593	Business	42100.00
0005432530437	30593	Comfort	23900.00
0005432530721	30593	Comfort	23900.00
0005434068667	30593	Comfort	23900.00
0005435215264	30593	Comfort	23900.00
0005434068696	30593	Comfort	23900.00
0005432530287	30593	Comfort	23900.00
0005432530126	30593	Comfort	23900.00
0005432531111	30593	Comfort	23900.00
0005432529598	30593	Comfort	23900.00
0005434068461	30593	Comfort	23900.00
0005435215278	30593	Comfort	23900.00
0005434068695	30593	Comfort	23900.00
0005432529335	30593	Comfort	23900.00
0005432529935	30593	Comfort	23900.00
0005432530722	30593	Comfort	23900.00
0005432530472	30593	Comfort	23900.00
0005435215269	30593	Comfort	23900.00
0005432530467	30593	Comfort	23900.00
0005435215240	30593	Comfort	23900.00
0005435215263	30593	Comfort	23900.00
0005434068773	30593	Comfort	23900.00
0005435215247	30593	Comfort	23900.00
0005432530058	30593	Comfort	23900.00
0005432530486	30593	Comfort	23900.00
0005435215298	30593	Comfort	23900.00
0005435215276	30593	Comfort	23900.00
0005434068709	30593	Comfort	23900.00
0005432530152	30593	Comfort	23900.00
0005434068870	30593	Comfort	23900.00
0005434068774	30593	Comfort	23900.00
0005435215252	30593	Comfort	23900.00
0005434068517	30593	Comfort	23900.00
0005435215238	30593	Comfort	23900.00
0005434068869	30593	Comfort	23900.00
0005432529775	30593	Comfort	23900.00
0005432529803	30593	Comfort	23900.00
0005432530397	30593	Comfort	23900.00
0005432428980	30593	Comfort	23900.00
0005432529849	30593	Comfort	23900.00
0005432529599	30593	Economy	14000.00
0005432530351	30593	Economy	14000.00
0005432529876	30593	Economy	14000.00
0005432530503	30593	Economy	14000.00
0005432530626	30593	Economy	14000.00
0005432529947	30593	Economy	14000.00
0005434068734	30593	Economy	14000.00
0005432530547	30593	Economy	14000.00
0005434068776	30593	Economy	14000.00
0005434068961	30593	Economy	14000.00
0005435215283	30593	Economy	14000.00
0005432530137	30593	Economy	14000.00
0005435215300	30593	Economy	14000.00
0005435215273	30593	Economy	14000.00
0005432530494	30593	Economy	14000.00
0005435215299	30593	Economy	14000.00
0005432530043	30593	Economy	14000.00
0005435215248	30593	Economy	14000.00
0005432529846	30593	Economy	14000.00
0005434068837	30593	Economy	14000.00
0005435215294	30593	Economy	14000.00
0005432530135	30593	Economy	14000.00
0005432535916	30593	Economy	14000.00
0005434068558	30593	Economy	14000.00
0005432530300	30593	Economy	14000.00
0005432530252	30593	Economy	14000.00
0005432530288	30593	Economy	14000.00
0005435283459	30593	Economy	14000.00
0005432530436	30593	Economy	14000.00
0005434068960	30593	Economy	14000.00
0005432530502	30593	Economy	14000.00
0005432530199	30593	Economy	14000.00
0005434068644	30593	Economy	14000.00
0005434068546	30593	Economy	14000.00
0005432530149	30593	Economy	14000.00
0005432530142	30593	Economy	14000.00
0005432530122	30593	Economy	14000.00
0005435283461	30593	Economy	14000.00
0005432530514	30593	Economy	14000.00
0005432530419	30593	Economy	14000.00
0005432530281	30593	Economy	14000.00
0005434068534	30593	Economy	14000.00
0005435215241	30593	Economy	14000.00
0005432530471	30593	Economy	14000.00
0005434068433	30593	Economy	14000.00
0005435215246	30593	Economy	14000.00
0005434068545	30593	Economy	14000.00
0005432530426	30593	Economy	14000.00
0005432530590	30593	Economy	14000.00
0005434068693	30593	Economy	14000.00
0005432211691	30593	Economy	14000.00
0005434069003	30593	Economy	15400.00
0005435215236	30593	Economy	14000.00
0005435215290	30593	Economy	15400.00
0005435215275	30593	Economy	15400.00
0005432530134	30593	Economy	15400.00
0005435215259	30593	Economy	14000.00
0005432530381	30593	Economy	15400.00
0005432530461	30593	Economy	14000.00
0005432530307	30593	Economy	14000.00
0005435215281	30593	Economy	14000.00
0005434068694	30593	Economy	14000.00
0005432529690	30593	Economy	14000.00
0005434068763	30593	Economy	14000.00
0005432529717	30593	Economy	14000.00
0005432530222	30593	Economy	14000.00
0005432530158	30593	Economy	14000.00
0005434068620	30593	Economy	14000.00
0005435215261	30593	Economy	14000.00
0005432529861	30593	Economy	14000.00
0005432428990	30593	Economy	14000.00
0005432530255	30593	Economy	14000.00
0005432530261	30593	Economy	14000.00
0005432529401	30593	Economy	14000.00
0005432530159	30593	Economy	14000.00
0005432530473	30593	Economy	14000.00
0005435215256	30593	Economy	14000.00
0005432211693	30593	Economy	14000.00
0005435215267	30593	Economy	14000.00
0005432530268	30593	Economy	14000.00
0005432530382	30593	Economy	14000.00
0005432530352	30593	Economy	14000.00
0005434068624	30593	Economy	14000.00
0005434068732	30593	Economy	14000.00
0005435215274	30593	Economy	14000.00
0005435215291	30593	Economy	14000.00
0005432530271	30593	Economy	14000.00
0005432529696	30593	Economy	14000.00
0005432530487	30593	Economy	14000.00
0005432530442	30593	Economy	14000.00
0005434068486	30593	Economy	14000.00
0005432159975	30593	Economy	14000.00
0005435215295	30593	Economy	14000.00
0005432530518	30593	Economy	14000.00
0005432159976	30593	Economy	14000.00
0005432211689	30593	Economy	14000.00
0005435215262	30593	Economy	14000.00
0005435215279	30593	Economy	14000.00
0005432529732	30593	Economy	14000.00
0005434068897	30593	Economy	14000.00
0005435215277	30593	Economy	14000.00
0005432530103	30593	Economy	14000.00
0005432529666	30593	Economy	14000.00
0005435215289	30593	Economy	14000.00
0005432211694	30593	Economy	14000.00
0005432529802	30593	Economy	14000.00
0005435215250	30593	Economy	14000.00
0005435215280	30593	Economy	14000.00
0005432529447	30593	Economy	14000.00
0005432530112	30593	Economy	14000.00
0005434068967	30593	Economy	14000.00
0005434068817	30593	Economy	14000.00
0005432530117	30593	Economy	14000.00
0005432530050	30593	Economy	14000.00
0005432530752	30593	Economy	14000.00
0005432530453	30593	Economy	14000.00
0005435215242	30593	Economy	14000.00
0005432529999	30593	Economy	14000.00
0005432529409	30593	Economy	14000.00
0005434068485	30593	Economy	14000.00
0005432530455	30593	Economy	14000.00
0005435215245	30593	Economy	14000.00
0005435215253	30593	Economy	14000.00
0005432530444	30593	Economy	14000.00
0005432529555	30593	Economy	14000.00
0005435215237	30593	Economy	14000.00
0005432211692	30593	Economy	14000.00
0005432533339	30593	Economy	14000.00
0005432530269	30593	Economy	14000.00
0005432535931	30593	Economy	14000.00
0005432530250	30593	Economy	14000.00
0005435215271	30593	Economy	14000.00
0005435283458	30593	Economy	14000.00
0005432530048	30593	Economy	14000.00
0005432535932	30593	Economy	14000.00
0005435215239	30593	Economy	14000.00
0005432530391	30593	Economy	14000.00
0005435215260	30593	Economy	14000.00
0005432530568	30593	Economy	14000.00
0005432530263	30593	Economy	14000.00
0005432530000	30593	Economy	14000.00
0005435215285	30593	Economy	14000.00
0005435215288	30593	Economy	14000.00
0005432529836	30593	Economy	14000.00
0005434068878	30593	Economy	14000.00
0005435215258	30593	Economy	14000.00
0005434068772	30593	Economy	14000.00
0005435725724	30593	Economy	14000.00
0005432530438	30593	Economy	14000.00
0005432530151	30593	Economy	14000.00
0005432535911	30593	Economy	14000.00
0005434068330	30593	Economy	14000.00
0005435215244	30593	Economy	14000.00
0005432530171	30593	Economy	14000.00
0005432530223	30593	Economy	14000.00
0005432529985	30593	Economy	14000.00
0005434068255	30593	Economy	14000.00
0005435283460	30593	Economy	14000.00
0005432530059	30593	Economy	14000.00
0005434068331	30593	Economy	14000.00
0005432530392	30593	Economy	14000.00
0005435215282	30593	Economy	14000.00
0005434068731	30593	Economy	14000.00
0005434068645	30593	Economy	14000.00
0005435215251	30593	Economy	14000.00
0005435215243	30593	Economy	15400.00
0005432530274	30593	Economy	15400.00
0005432530123	30593	Economy	15400.00
0005435215249	30593	Economy	15400.00
0005435215265	30593	Economy	15400.00
0005434068455	30593	Economy	14000.00
0005434068621	30593	Economy	14000.00
0005435631045	30593	Economy	14000.00
0005432530443	30593	Economy	14000.00
0005432529978	30593	Economy	14000.00
0005435215293	30593	Economy	14000.00
0005435215255	30593	Economy	14000.00
0005432530163	30593	Economy	14000.00
0005434068720	30593	Economy	14000.00
0005432535907	30593	Economy	14000.00
0005435215270	30593	Economy	14000.00
0005434068775	30593	Economy	14000.00
0005432159977	30593	Economy	14000.00
0005432530053	30593	Economy	14000.00
0005432529731	30593	Economy	14000.00
0005434068702	30593	Economy	14000.00
0005432529837	30593	Economy	14000.00
0005432530143	30593	Economy	14000.00
0005432428991	30593	Economy	14000.00
0005434068968	30593	Economy	14000.00
0005432530468	30593	Economy	14000.00
0005434068719	30593	Economy	14000.00
0005434068622	30593	Economy	14000.00
0005435215292	30593	Economy	14000.00
0005432211690	30593	Economy	14000.00
0005432429003	30593	Economy	14000.00
0005432535926	30593	Economy	14000.00
0005432530138	30593	Economy	14000.00
0005432529994	30593	Economy	14000.00
0005432530118	30593	Economy	14000.00
0005435215272	30593	Economy	14000.00
0005432530170	30593	Economy	14000.00
0005434068582	30593	Economy	14000.00
0005433656757	30593	Economy	14000.00
0005432530180	30593	Economy	14000.00
0005432530277	30593	Economy	14000.00
0005434068710	30593	Economy	14000.00
0005434068872	30593	Economy	14000.00
0005432530285	30593	Economy	14000.00
0005432530256	30593	Economy	14000.00
0005432530012	30593	Economy	14000.00
0005432533342	30593	Economy	14000.00
0005432537098	30593	Economy	14000.00
0005432530203	30593	Economy	14000.00
0005435215296	30593	Economy	14000.00
0005434068623	30593	Economy	14000.00
0005434068705	30593	Economy	14000.00
0005435215286	30593	Economy	14000.00
0005432529790	30593	Economy	14000.00
0005433656756	30593	Economy	14000.00
0005435215257	30593	Economy	14000.00
0005435215284	30593	Economy	14000.00
0005434068615	30593	Economy	14000.00
0005434068562	30593	Economy	14000.00
0005432535946	30593	Economy	14000.00
0005435725726	30593	Economy	14000.00
0005432535908	30593	Economy	14000.00
0005432529936	30593	Economy	14000.00
0005434068743	30593	Economy	14000.00
0005434068547	30593	Economy	14000.00
0005432530625	30593	Economy	14000.00
0005434068896	30593	Economy	14000.00
0005432530286	30593	Economy	14000.00
0005432529804	30593	Economy	14000.00
0005432530249	30593	Economy	14000.00
0005432211695	30593	Economy	14000.00
0005434068877	30593	Economy	14000.00
0005434068432	30593	Economy	14000.00
0005434068651	30593	Economy	14000.00
0005432530548	30593	Economy	14000.00
0005432530559	30593	Economy	14000.00
0005434068630	30593	Economy	14000.00
0005432530301	30593	Economy	14000.00
0005432529810	30593	Economy	14000.00
0005432530016	30593	Economy	14000.00
0005432530469	30593	Economy	14000.00
0005432530549	30593	Economy	14000.00
0005432533341	30593	Economy	14000.00
0005434068842	30593	Economy	14000.00
0005435215297	30593	Economy	14000.00
0005432529811	30593	Economy	14000.00
0005434068649	30593	Economy	14000.00
0005434068493	30593	Economy	14000.00
0005434068835	30593	Economy	14000.00
0005434068717	30593	Economy	14000.00
0005434068631	30593	Economy	14000.00
0005434068626	30593	Economy	14000.00
0005432530420	30593	Economy	14000.00
0005434068765	30593	Economy	14000.00
0005434068569	30593	Economy	14000.00
0005434069027	30593	Economy	14000.00
0005435653816	24868	Business	9800.00
0005435653596	24868	Business	9800.00
0005435653731	24868	Business	9800.00
0005435653713	24868	Business	9800.00
0005433368827	24868	Business	9800.00
0005435653609	24868	Business	9800.00
0005435653739	24868	Business	9800.00
0005435653818	24868	Business	9800.00
0005433368839	24868	Business	9800.00
0005433368836	24868	Business	9800.00
0005433368829	24868	Economy	3300.00
0005435653723	24868	Economy	3300.00
0005433368854	24868	Economy	3300.00
0005435653627	24868	Economy	3300.00
0005433368851	24868	Economy	3300.00
0005435653604	24868	Economy	3300.00
0005433368856	24868	Economy	3300.00
0005433368838	24868	Economy	3300.00
0005435653660	24868	Economy	3300.00
0005433368853	24868	Economy	3600.00
0005435653603	24868	Economy	3600.00
0005435653689	24868	Economy	3600.00
0005433368831	24868	Economy	3600.00
0005433368860	24868	Economy	3300.00
0005433368843	24868	Economy	3300.00
0005435653684	24868	Economy	3300.00
0005433368830	24868	Economy	3300.00
0005435653656	24868	Economy	3300.00
0005433368857	24868	Economy	3300.00
0005433368832	24868	Economy	3300.00
0005435653709	24868	Economy	3300.00
0005433368835	24868	Economy	3300.00
0005435653616	24868	Economy	3300.00
0005435653493	24868	Economy	3300.00
0005433368850	24868	Economy	3300.00
0005435653755	24868	Economy	3300.00
0005433368846	24868	Economy	3300.00
0005435653756	24868	Economy	3300.00
0005433368833	24868	Economy	3300.00
0005435653732	24868	Economy	3300.00
0005435653579	24868	Economy	3300.00
0005435653761	24868	Economy	3300.00
0005435653613	24868	Economy	3300.00
0005433368834	24868	Economy	3300.00
0005435653661	24868	Economy	3300.00
0005433368841	24868	Economy	3300.00
0005435653492	24868	Economy	3300.00
0005433368852	24868	Economy	3300.00
0005435653841	24868	Economy	3300.00
0005435653767	24868	Economy	3300.00
0005433368855	24868	Economy	3300.00
0005435653692	24868	Economy	3300.00
0005433368844	24868	Economy	3300.00
0005435653650	24868	Economy	3300.00
0005433368842	24868	Economy	3300.00
0005433368859	24868	Economy	3300.00
0005435653759	24868	Economy	3300.00
0005435653737	24868	Economy	3300.00
0005435653817	24868	Economy	3300.00
0005433368849	24868	Economy	3300.00
0005435653802	24868	Economy	3300.00
0005433368837	24868	Economy	3300.00
0005435653760	24868	Economy	3300.00
0005435653727	24868	Economy	3300.00
0005435653615	24868	Economy	3300.00
0005435653698	24868	Economy	3300.00
0005435653738	24868	Economy	3300.00
0005433368847	24868	Economy	3300.00
0005435653595	24868	Economy	3300.00
0005433368828	24868	Economy	3300.00
0005435653745	24868	Economy	3300.00
0005435653720	24868	Economy	3300.00
0005435653833	24868	Economy	3300.00
0005433368840	24868	Economy	3300.00
0005435653701	24868	Economy	3300.00
0005433368845	24868	Economy	3300.00
0005433368848	24868	Economy	3300.00
0005433368858	24868	Economy	3300.00
0005435949816	23305	Economy	18700.00
0005435949824	23305	Economy	18700.00
0005435949807	23305	Economy	18700.00
0005435949831	23305	Economy	18700.00
0005435949827	23305	Economy	18700.00
0005435949808	23305	Economy	18700.00
0005435949832	23305	Economy	18700.00
0005435949820	23305	Economy	18700.00
0005435949825	23305	Economy	18700.00
0005435949819	23305	Economy	18700.00
0005435949823	23305	Economy	18700.00
0005435949817	23305	Economy	18700.00
0005434980549	2014	Economy	10500.00
0005434980552	2014	Economy	10500.00
0005434980551	2014	Economy	10500.00
0005434980561	2014	Economy	10500.00
0005434980554	2014	Economy	9500.00
0005434980564	2014	Economy	9500.00
0005434980556	2014	Economy	9500.00
0005435801774	2014	Economy	9500.00
0005434980563	2014	Economy	9500.00
0005434980566	2014	Economy	9500.00
0005434980547	2014	Economy	9500.00
0005434980550	2014	Economy	9500.00
0005434980560	2014	Economy	9500.00
0005434980545	2014	Economy	9500.00
0005434980567	2014	Economy	9500.00
0005434980553	2014	Economy	9500.00
0005435801775	2014	Economy	9500.00
0005434980555	2014	Economy	9500.00
0005434980544	2014	Economy	9500.00
0005434980543	2014	Economy	9500.00
0005435801776	2014	Economy	9500.00
0005434980548	2014	Economy	9500.00
0005434980565	2014	Economy	9500.00
0005434980569	2014	Economy	9500.00
0005434980570	2014	Economy	9500.00
0005434980562	2014	Economy	9500.00
0005434980558	2014	Economy	9500.00
0005434980546	2014	Economy	9500.00
0005434980557	2014	Economy	9500.00
0005434980559	2014	Economy	9500.00
0005434980568	2014	Economy	9500.00
0005434980542	2014	Economy	9500.00
0005435801740	23549	Economy	10500.00
0005434980251	23549	Economy	10500.00
0005434980196	23549	Economy	9500.00
0005434980236	23549	Economy	9500.00
0005434980351	23549	Economy	9500.00
0005434980267	23549	Economy	9500.00
0005434980250	23549	Economy	9500.00
0005434980252	23549	Economy	9500.00
0005434980282	23549	Economy	9500.00
0005434980268	23549	Economy	9500.00
0005435801749	23549	Economy	9500.00
0005434980331	23549	Economy	9500.00
0005434980352	23549	Economy	9500.00
0005434980249	23549	Economy	9500.00
0005434980345	23549	Economy	9500.00
0005435801743	23549	Economy	9500.00
0005434980207	23549	Economy	9500.00
0005434980116	23549	Economy	9500.00
0005434980346	23549	Economy	9500.00
0005434980347	23549	Economy	9500.00
0005434980115	23549	Economy	9500.00
0005434980195	23549	Economy	9500.00
0005434980194	23549	Economy	9500.00
0005434980117	23549	Economy	9500.00
0005434980212	23549	Economy	9500.00
0005434980293	23549	Economy	9500.00
0005434980332	23549	Economy	9500.00
0005434980280	23549	Economy	9500.00
0005434980139	23549	Economy	9500.00
0005434952628	2639	Economy	5300.00
0005434952626	2639	Economy	5300.00
0005434952627	2639	Economy	5300.00
0005434952600	28196	Economy	5300.00
0005433256481	28196	Economy	5300.00
0005433256480	28196	Economy	5300.00
0005434952598	28196	Economy	5300.00
0005433256479	28196	Economy	5300.00
0005433111563	19812	Economy	8700.00
0005433111562	19812	Economy	8700.00
0005434139672	11957	Business	9700.00
0005434139879	11957	Business	9700.00
0005434139488	11957	Business	9700.00
0005434139694	11957	Business	9700.00
0005434139741	11957	Business	9700.00
0005434139719	11957	Business	9700.00
0005434139695	11957	Business	9700.00
0005434139697	11957	Business	9700.00
0005434139670	11957	Business	9700.00
0005434139593	11957	Business	9700.00
0005434139611	11957	Business	9700.00
0005434139453	11957	Economy	3200.00
0005434139621	11957	Economy	3200.00
0005434139179	11957	Economy	3200.00
0005434139671	11957	Economy	3200.00
0005434139777	11957	Economy	3200.00
0005434139706	11957	Economy	3200.00
0005434139293	11957	Economy	3200.00
0005434139607	11957	Economy	3200.00
0005434139710	11957	Economy	3200.00
0005434139602	11957	Economy	3200.00
0005434139420	11957	Economy	3500.00
0005434139839	11957	Economy	3500.00
0005434139559	11957	Economy	3500.00
0005434139737	11957	Economy	3200.00
0005434139419	11957	Economy	3200.00
0005434139344	11957	Economy	3200.00
0005434139546	11957	Economy	3200.00
0005434139473	11957	Economy	3200.00
0005434139542	11957	Economy	3200.00
0005434139620	11957	Economy	3200.00
0005434139633	11957	Economy	3200.00
0005434139636	11957	Economy	3200.00
0005434139696	11957	Economy	3200.00
0005434139603	11957	Economy	3200.00
0005434139397	11957	Economy	3200.00
0005434139470	11957	Economy	3200.00
0005434139345	11957	Economy	3200.00
0005434139598	11957	Economy	3200.00
0005434139202	11957	Economy	3200.00
0005434139543	11957	Economy	3200.00
0005434139422	11957	Economy	3200.00
0005434139389	11957	Economy	3200.00
0005434139627	11957	Economy	3200.00
0005434139392	11957	Economy	3200.00
0005434139516	11957	Economy	3200.00
0005434139281	11957	Economy	3200.00
0005434139133	11957	Economy	3200.00
0005434139862	11957	Economy	3200.00
0005434139393	11957	Economy	3200.00
0005434139237	11957	Economy	3200.00
0005434139337	11957	Economy	3200.00
0005434139628	11957	Economy	3200.00
0005434139490	11957	Economy	3200.00
0005434139650	11957	Economy	3200.00
0005434139616	11957	Economy	3200.00
0005434139353	11957	Economy	3200.00
0005434139808	11957	Economy	3200.00
0005434139669	11957	Economy	3200.00
0005434139355	11957	Economy	3200.00
0005434139489	11957	Economy	3200.00
0005434139471	11957	Economy	3200.00
0005434139563	11957	Economy	3200.00
0005434139840	11957	Economy	3200.00
0005434139203	11957	Economy	3200.00
0005434139255	11957	Economy	3200.00
0005434139579	11957	Economy	3200.00
0005434139632	11957	Economy	3200.00
0005434139545	11957	Economy	3200.00
0005434139401	11957	Economy	3200.00
0005434139454	11957	Economy	3200.00
0005434139718	11957	Economy	3200.00
0005434139180	11957	Economy	3200.00
0005434139809	11957	Economy	3200.00
0005434139861	11957	Economy	3200.00
0005434139338	11957	Economy	3200.00
0005434139359	11957	Economy	3200.00
0005434139778	11957	Economy	3200.00
0005434139770	11957	Economy	3200.00
0005434139357	11957	Economy	3200.00
0005434139354	11957	Economy	3200.00
0005434139137	11957	Economy	3200.00
0005434139544	11957	Economy	3200.00
0005434139841	11957	Economy	3200.00
0005434140136	28726	Business	9700.00
0005434140180	28726	Business	9700.00
0005434140157	28726	Business	9700.00
0005434140161	28726	Business	9700.00
0005434140194	28726	Business	9700.00
0005434140173	28726	Business	9700.00
0005434140144	28726	Business	9700.00
0005434140113	28726	Business	9700.00
0005434140159	28726	Business	9700.00
0005434140183	28726	Business	9700.00
0005434140162	28726	Economy	3200.00
0005434140150	28726	Economy	3200.00
0005434140119	28726	Economy	3200.00
0005434140121	28726	Economy	3200.00
0005434140135	28726	Economy	3200.00
0005434140129	28726	Economy	3200.00
0005434140185	28726	Economy	3200.00
0005434140154	28726	Economy	3200.00
0005434140166	28726	Economy	3200.00
0005434140146	28726	Economy	3200.00
0005434140197	28726	Economy	3500.00
0005434140139	28726	Economy	3500.00
0005434140143	28726	Economy	3500.00
0005434140130	28726	Economy	3500.00
0005434140134	28726	Economy	3500.00
0005434140187	28726	Economy	3200.00
0005434140178	28726	Economy	3200.00
0005434140174	28726	Economy	3200.00
0005434140182	28726	Economy	3200.00
0005434140198	28726	Economy	3200.00
0005434140112	28726	Economy	3200.00
0005434140126	28726	Economy	3200.00
0005434140131	28726	Economy	3200.00
0005434140165	28726	Economy	3200.00
0005434140190	28726	Economy	3200.00
0005434140168	28726	Economy	3200.00
0005434140179	28726	Economy	3200.00
0005434140171	28726	Economy	3200.00
0005434140158	28726	Economy	3200.00
0005434140138	28726	Economy	3200.00
0005434140167	28726	Economy	3200.00
0005434140125	28726	Economy	3200.00
0005434140124	28726	Economy	3200.00
0005434140123	28726	Economy	3200.00
0005434140175	28726	Economy	3200.00
0005434140193	28726	Economy	3200.00
0005434140147	28726	Economy	3200.00
0005434140191	28726	Economy	3200.00
0005434140153	28726	Economy	3200.00
0005434140176	28726	Economy	3200.00
0005434140186	28726	Economy	3200.00
0005434140116	28726	Economy	3200.00
0005434140132	28726	Economy	3200.00
0005434140192	28726	Economy	3200.00
0005434140160	28726	Economy	3200.00
0005434140202	28726	Economy	3200.00
0005434140201	28726	Economy	3200.00
0005434140163	28726	Economy	3200.00
0005434140199	28726	Economy	3200.00
0005434140118	28726	Economy	3200.00
0005434140195	28726	Economy	3200.00
0005434140184	28726	Economy	3200.00
0005434140155	28726	Economy	3200.00
0005434140152	28726	Economy	3200.00
0005434140128	28726	Economy	3200.00
0005434140142	28726	Economy	3200.00
0005434140133	28726	Economy	3200.00
0005434140172	28726	Economy	3200.00
0005434140117	28726	Economy	3200.00
0005434140145	28726	Economy	3200.00
0005434140115	28726	Economy	3200.00
0005434140140	28726	Economy	3200.00
0005434140148	28726	Economy	3200.00
0005434140151	28726	Economy	3200.00
0005434140189	28726	Economy	3200.00
0005434140170	28726	Economy	3200.00
0005434140120	28726	Economy	3200.00
0005434140141	28726	Economy	3200.00
0005434140114	28726	Economy	3200.00
0005434140127	28726	Economy	3200.00
0005434140177	28726	Economy	3200.00
0005434140122	28726	Economy	3200.00
0005434140156	28726	Economy	3200.00
0005434140196	28726	Economy	3200.00
0005434140200	28726	Economy	3200.00
0005434140137	28726	Economy	3200.00
0005434140188	28726	Economy	3200.00
0005434140169	28726	Economy	3200.00
0005434140164	28726	Economy	3200.00
0005434140149	28726	Economy	3200.00
0005434140181	28726	Economy	3200.00
0005434513620	19102	Economy	26000.00
0005434516110	19102	Economy	23600.00
0005434513625	19102	Economy	23600.00
0005434513623	19102	Economy	23600.00
0005434513633	19102	Economy	23600.00
0005434513617	19102	Economy	23600.00
0005434513614	19102	Economy	23600.00
0005434513621	19102	Economy	23600.00
0005434513622	19102	Economy	23600.00
0005434513618	19102	Economy	23600.00
0005434190458	19102	Economy	23600.00
0005434516112	19102	Economy	23600.00
0005434513634	19102	Economy	23600.00
0005434516104	19102	Economy	23600.00
0005434190459	19102	Economy	23600.00
0005434190456	19102	Economy	23600.00
0005434513624	19102	Economy	23600.00
0005434190457	19102	Economy	23600.00
0005434513619	19102	Economy	23600.00
0005434190455	19102	Economy	23600.00
0005434516111	19102	Economy	23600.00
0005433534553	6796	Economy	10900.00
0005433534552	6796	Economy	9900.00
0005433534551	6796	Economy	9900.00
0005433539091	6796	Economy	9900.00
0005433539088	6796	Economy	9900.00
0005435259841	6796	Economy	9900.00
0005433539089	6796	Economy	9900.00
0005435259843	6796	Economy	9900.00
0005433539087	6796	Economy	9900.00
0005433539093	6796	Economy	9900.00
0005435259836	6796	Economy	9900.00
0005435259842	6796	Economy	9900.00
0005433539092	6796	Economy	9900.00
0005433539090	6796	Economy	9900.00
0005435259870	25044	Economy	9900.00
0005433539007	25044	Economy	9900.00
0005433538994	25044	Economy	9900.00
0005435259869	25044	Economy	9900.00
0005435259871	25044	Economy	9900.00
0005433539026	25044	Economy	9900.00
0005433539006	25044	Economy	9900.00
0005433539031	25044	Economy	9900.00
0005433539027	25044	Economy	9900.00
0005433512163	845	Economy	14600.00
0005433512162	845	Economy	14600.00
0005432922609	845	Economy	14600.00
0005432922599	845	Economy	14600.00
0005433512161	845	Economy	14600.00
0005433512160	845	Economy	14600.00
0005433512165	845	Economy	14600.00
0005433512164	845	Economy	14600.00
0005433512159	845	Economy	14600.00
0005432922610	845	Economy	14600.00
0005432922592	845	Economy	14600.00
0005432922598	845	Economy	14600.00
0005433512140	16141	Economy	14600.00
0005433512139	16141	Economy	14600.00
0005432922631	16141	Economy	14600.00
0005432922630	16141	Economy	14600.00
0005433512059	16141	Economy	14600.00
0005432922628	16141	Economy	14600.00
0005432922629	16141	Economy	14600.00
0005433512101	16141	Economy	14600.00
0005433512084	16141	Economy	14600.00
0005433512112	16141	Economy	14600.00
0005433512133	16141	Economy	14600.00
0005433512097	16141	Economy	14600.00
0005435852603	4028	Economy	13500.00
0005435852612	4028	Economy	12300.00
0005435852608	4028	Economy	12300.00
0005435852613	4028	Economy	12300.00
0005433475813	4028	Economy	12300.00
0005435852607	4028	Economy	12300.00
0005435852628	4028	Economy	12300.00
0005435852626	4028	Economy	12300.00
0005435852629	4028	Economy	12300.00
0005435852627	4028	Economy	12300.00
0005435852618	4028	Economy	12300.00
0005433475814	4028	Economy	12300.00
0005433475815	4028	Economy	12300.00
0005433475817	4028	Economy	12300.00
0005433475819	4028	Economy	12300.00
0005433475818	4028	Economy	12300.00
0005433475816	4028	Economy	12300.00
0005435698071	3703	Economy	7900.00
0005435698072	3703	Economy	7900.00
0005435935110	3703	Economy	7900.00
0005435698070	3703	Economy	7200.00
0005435698047	3703	Economy	7200.00
0005435698045	3703	Economy	7200.00
0005435935104	3703	Economy	7200.00
0005435698052	3703	Economy	7200.00
0005435698059	3703	Economy	7200.00
0005435698065	3703	Economy	7200.00
0005435698063	3703	Economy	7200.00
0005435698056	3703	Economy	7200.00
0005435698069	3703	Economy	7200.00
0005435698053	3703	Economy	7200.00
0005434950645	3703	Economy	7200.00
0005435698061	3703	Economy	7200.00
0005435916212	3703	Economy	7200.00
0005435698066	3703	Economy	7200.00
0005435698058	3703	Economy	7200.00
0005435698060	3703	Economy	7200.00
0005435698067	3703	Economy	7200.00
0005435698048	3703	Economy	7200.00
0005435698068	3703	Economy	7200.00
0005435698050	3703	Economy	7200.00
0005435698054	3703	Economy	7200.00
0005435698057	3703	Economy	7200.00
0005435698055	3703	Economy	7200.00
0005435698046	3703	Economy	7200.00
0005435698051	3703	Economy	7200.00
0005435698062	3703	Economy	7200.00
0005434950644	3703	Economy	7200.00
0005435698049	3703	Economy	7200.00
0005435698064	3703	Economy	7200.00
0005435935105	3703	Economy	7200.00
0005435935124	16299	Economy	7900.00
0005435697808	16299	Economy	7900.00
0005435697710	16299	Economy	7900.00
0005435697755	16299	Economy	7200.00
0005435697852	16299	Economy	7200.00
0005435697774	16299	Economy	7200.00
0005435916238	16299	Economy	7200.00
0005435697715	16299	Economy	7200.00
0005435697746	16299	Economy	7200.00
0005435697689	16299	Economy	7200.00
0005435935123	16299	Economy	7200.00
0005435697801	16299	Economy	7200.00
0005435697807	16299	Economy	7200.00
0005434950599	16299	Economy	7200.00
0005435933573	16299	Economy	7200.00
0005435697772	16299	Economy	7200.00
0005435697791	16299	Economy	7200.00
0005434950630	16299	Economy	7200.00
0005435697930	16299	Economy	7200.00
0005434950611	16299	Economy	7200.00
0005435697861	16299	Economy	7200.00
0005435697688	16299	Economy	7200.00
0005435697845	16299	Economy	7200.00
0005435933574	16299	Economy	7200.00
0005434950612	16299	Economy	7200.00
0005435916239	16299	Economy	7200.00
0005435935125	16299	Economy	7200.00
0005435697762	16299	Economy	7200.00
0005435697773	16299	Economy	7200.00
0005435916240	16299	Economy	7200.00
0005435697823	16299	Economy	7200.00
0005434606921	3983	Economy	21300.00
0005434606918	3983	Economy	21300.00
0005432609838	3983	Economy	19300.00
0005435842340	3983	Economy	19300.00
0005432609835	3983	Economy	19300.00
0005435853650	3983	Economy	19300.00
0005432609837	3983	Economy	19300.00
0005434606920	3983	Economy	19300.00
0005434604992	3983	Economy	19300.00
0005434604995	3983	Economy	19300.00
0005434606916	3983	Economy	19300.00
0005432609839	3983	Economy	19300.00
0005433519576	3983	Economy	19300.00
0005432609836	3983	Economy	19300.00
0005435842341	3983	Economy	19300.00
0005434604991	3983	Economy	19300.00
0005435853647	3983	Economy	19300.00
0005432607668	3983	Economy	19300.00
0005435853637	3983	Economy	19300.00
0005434606917	3983	Economy	19300.00
0005432607669	3983	Economy	19300.00
0005434606919	3983	Economy	19300.00
0005432607671	3983	Economy	19300.00
0005433519574	3983	Economy	19300.00
0005432607670	3983	Economy	19300.00
0005434604994	3983	Economy	19300.00
0005433519575	3983	Economy	19300.00
0005434604993	3983	Economy	19300.00
0005434606883	22088	Economy	21300.00
0005434606885	22088	Economy	19300.00
0005435853658	22088	Economy	19300.00
0005433519534	22088	Economy	19300.00
0005434606886	22088	Economy	19300.00
0005435853659	22088	Economy	19300.00
0005434606867	22088	Economy	19300.00
0005433519524	22088	Economy	19300.00
0005433519538	22088	Economy	19300.00
0005434606884	22088	Economy	19300.00
0005435853660	22088	Economy	19300.00
0005435628811	784	Economy	3700.00
0005435628808	784	Economy	3700.00
0005435628810	784	Economy	3700.00
0005435628814	784	Economy	3700.00
0005435628816	784	Economy	3700.00
0005435628812	784	Economy	3700.00
0005435628809	784	Economy	3700.00
0005435628813	784	Economy	3700.00
0005433349092	784	Economy	3700.00
0005435628815	784	Economy	3700.00
0005435628799	15919	Economy	3700.00
0005433349137	15919	Economy	3700.00
0005435628774	15919	Economy	3700.00
0005433349139	15919	Economy	3700.00
0005435628773	15919	Economy	3700.00
0005433349141	15919	Economy	3700.00
0005433349138	15919	Economy	3700.00
0005433349140	15919	Economy	3700.00
0005433158164	17209	Economy	7100.00
0005434446576	17209	Economy	7100.00
0005434445304	17209	Economy	7100.00
0005434445306	17209	Economy	7100.00
0005433158170	17209	Economy	7100.00
0005434445303	17209	Economy	7100.00
0005433158157	17209	Economy	7100.00
0005434445305	17209	Economy	7100.00
0005433158165	17209	Economy	7100.00
0005434446575	17209	Economy	7100.00
0005433159350	17209	Economy	7100.00
0005433159371	17562	Economy	7100.00
0005433159372	17562	Economy	7100.00
0005434445278	17562	Economy	7100.00
0005433158200	17562	Economy	7100.00
0005433159370	17562	Economy	7100.00
0005434445274	17562	Economy	7100.00
0005433158201	17562	Economy	7100.00
0005435383212	7878	Economy	5400.00
0005435133155	7878	Economy	5400.00
0005435383253	7878	Economy	5400.00
0005435133156	7878	Economy	5400.00
0005435133158	7878	Economy	5400.00
0005435133157	7878	Economy	5400.00
0005435383240	7878	Economy	5400.00
0005435133154	7878	Economy	5400.00
0005435133151	7878	Economy	5400.00
0005435133152	7878	Economy	5400.00
0005435133150	7878	Economy	5400.00
0005435383254	7878	Economy	5400.00
0005435133153	7878	Economy	5400.00
0005435133149	7878	Economy	5400.00
0005435383239	7878	Economy	5400.00
0005435383241	7878	Economy	5400.00
0005435133059	33084	Economy	5400.00
0005435383292	33084	Economy	5400.00
0005435133079	33084	Economy	5400.00
0005435133062	33084	Economy	5400.00
0005435133054	33084	Economy	5400.00
0005435133061	33084	Economy	5400.00
0005435133070	33084	Economy	5400.00
0005435133066	33084	Economy	5400.00
0005435133047	33084	Economy	5400.00
0005435133093	33084	Economy	5400.00
0005435383289	33084	Economy	5400.00
0005435383288	33084	Economy	5400.00
0005435383290	33084	Economy	5400.00
0005435133041	33084	Economy	5400.00
0005435383291	33084	Economy	5400.00
0005435383293	33084	Economy	5400.00
0005435133092	33084	Economy	5400.00
0005435390361	7524	Economy	13800.00
0005435160594	7524	Economy	12500.00
0005435160589	7524	Economy	12500.00
0005435390359	7524	Economy	12500.00
0005435160587	7524	Economy	12500.00
0005435160591	7524	Economy	12500.00
0005435160590	7524	Economy	12500.00
0005435160586	7524	Economy	12500.00
0005435390348	7524	Economy	12500.00
0005435160588	7524	Economy	12500.00
0005435390319	7524	Economy	12500.00
0005435160593	7524	Economy	12500.00
0005435390347	7524	Economy	12500.00
0005435160592	7524	Economy	12500.00
0005435160585	7524	Economy	12500.00
0005435160503	29542	Economy	13800.00
0005435390418	29542	Economy	13800.00
0005435160490	29542	Economy	13800.00
0005435160491	29542	Economy	12500.00
0005435390416	29542	Economy	12500.00
0005435390417	29542	Economy	12500.00
0005435160539	29542	Economy	12500.00
0005435160531	29542	Economy	12500.00
0005435390422	29542	Economy	12500.00
0005435160542	29542	Economy	12500.00
0005435160470	29542	Economy	12500.00
0005435160512	29542	Economy	12500.00
0005435160530	29542	Economy	12500.00
0005435390419	29542	Economy	12500.00
0005435390420	29542	Economy	12500.00
0005435160538	29542	Economy	12500.00
0005435390421	29542	Economy	12500.00
0005435160529	29542	Economy	12500.00
0005435160473	29542	Economy	12500.00
0005435160481	29542	Economy	12500.00
0005435160493	29542	Economy	12500.00
0005435160495	29542	Economy	12500.00
0005435160564	29542	Economy	12500.00
0005435160505	29542	Economy	12500.00
0005435160525	29542	Economy	12500.00
0005432398251	18471	Economy	4900.00
0005435179016	18471	Economy	4900.00
0005435178534	18471	Economy	4900.00
0005432394162	18471	Economy	4900.00
0005435179015	18471	Economy	4900.00
0005435178535	18471	Economy	4900.00
0005432398286	27130	Economy	4900.00
0005432400213	27130	Economy	4900.00
0005432398288	27130	Economy	4900.00
0005435178521	27130	Economy	4900.00
0005432398285	27130	Economy	4900.00
0005432398289	27130	Economy	4900.00
0005435178512	27130	Economy	4900.00
0005435178513	27130	Economy	4900.00
0005432400215	27130	Economy	4900.00
0005432400214	27130	Economy	4900.00
0005432398287	27130	Economy	4900.00
0005434552891	9815	Economy	4400.00
0005434552890	9815	Economy	4400.00
0005434552895	9815	Economy	4400.00
0005434552892	9815	Economy	4400.00
0005434552893	9815	Economy	4400.00
0005434552894	9815	Economy	4400.00
0005435104181	6516	Business	48400.00
0005435104176	6516	Business	48400.00
0005435104197	6516	Business	48400.00
0005434505186	6516	Business	48400.00
0005435104184	6516	Business	48400.00
0005435104208	6516	Business	48400.00
0005434505183	6516	Business	48400.00
0005434505184	6516	Business	48400.00
0005435104179	6516	Business	48400.00
0005435104199	6516	Business	48400.00
0005435104203	6516	Economy	16100.00
0005434505164	6516	Economy	16100.00
0005434505179	6516	Economy	16100.00
0005434505161	6516	Economy	16100.00
0005435104205	6516	Economy	16100.00
0005434505177	6516	Economy	16100.00
0005434505163	6516	Economy	16100.00
0005434505153	6516	Economy	16100.00
0005434505170	6516	Economy	16100.00
0005434505158	6516	Economy	17800.00
0005434505181	6516	Economy	17800.00
0005434505165	6516	Economy	17800.00
0005434505160	6516	Economy	17800.00
0005435104209	6516	Economy	16100.00
0005435104211	6516	Economy	16100.00
0005434505156	6516	Economy	16100.00
0005435104202	6516	Economy	16100.00
0005434505167	6516	Economy	16100.00
0005434505157	6516	Economy	16100.00
0005434505180	6516	Economy	16100.00
0005435104186	6516	Economy	16100.00
0005434505168	6516	Economy	16100.00
0005435104198	6516	Economy	16100.00
0005435104177	6516	Economy	16100.00
0005434505178	6516	Economy	16100.00
0005435104196	6516	Economy	16100.00
0005435104201	6516	Economy	16100.00
0005434505166	6516	Economy	16100.00
0005435104210	6516	Economy	16100.00
0005435104193	6516	Economy	16100.00
0005434505159	6516	Economy	16100.00
0005435104188	6516	Economy	16100.00
0005435104189	6516	Economy	16100.00
0005434505182	6516	Economy	16100.00
0005435104191	6516	Economy	16100.00
0005435104185	6516	Economy	16100.00
0005435104183	6516	Economy	16100.00
0005435104182	6516	Economy	16100.00
0005435104190	6516	Economy	16100.00
0005434505173	6516	Economy	16100.00
0005435104192	6516	Economy	16100.00
0005434505169	6516	Economy	16100.00
0005434505175	6516	Economy	16100.00
0005434505185	6516	Economy	16100.00
0005434505155	6516	Economy	16100.00
0005434505172	6516	Economy	16100.00
0005434505162	6516	Economy	16100.00
0005434505176	6516	Economy	16100.00
0005435104204	6516	Economy	16100.00
0005435104194	6516	Economy	16100.00
0005435104200	6516	Economy	16100.00
0005434505171	6516	Economy	16100.00
0005435104187	6516	Economy	16100.00
0005435104195	6516	Economy	16100.00
0005434505152	6516	Economy	16100.00
0005435104180	6516	Economy	16100.00
0005434505154	6516	Economy	16100.00
0005435104206	6516	Economy	16100.00
0005435104207	6516	Economy	16100.00
0005434505174	6516	Economy	16100.00
0005435104178	6516	Economy	16100.00
0005435104020	22683	Business	48400.00
0005435104031	22683	Business	48400.00
0005434504764	22683	Business	48400.00
0005434504763	22683	Business	48400.00
0005434504834	22683	Business	48400.00
0005434504704	22683	Business	48400.00
0005434504641	22683	Economy	16100.00
0005434504767	22683	Economy	16100.00
0005434504665	22683	Economy	16100.00
0005434504889	22683	Economy	16100.00
0005434504859	22683	Economy	17800.00
0005435104036	22683	Economy	16100.00
0005435104037	22683	Economy	16100.00
0005434504705	22683	Economy	16100.00
0005434504730	22683	Economy	16100.00
0005434504857	22683	Economy	16100.00
0005434504611	22683	Economy	16100.00
0005434504832	22683	Economy	16100.00
0005434504939	22683	Economy	16100.00
0005434504770	22683	Economy	16100.00
0005435104001	22683	Economy	16100.00
0005434504820	22683	Economy	16100.00
0005434504862	22683	Economy	16100.00
0005434504893	22683	Economy	16100.00
0005434504676	22683	Economy	16100.00
0005434504708	22683	Economy	16100.00
0005434504691	22683	Economy	16100.00
0005434504569	22683	Economy	16100.00
0005435104024	22683	Economy	16100.00
0005434504856	22683	Economy	16100.00
0005434504831	22683	Economy	16100.00
0005435104017	22683	Economy	16100.00
0005434504707	22683	Economy	16100.00
0005434504568	22683	Economy	16100.00
0005434504769	22683	Economy	16100.00
0005434504830	22683	Economy	16100.00
0005435104019	22683	Economy	16100.00
0005434504977	22683	Economy	16100.00
0005434504683	22683	Economy	16100.00
0005434504684	22683	Economy	16100.00
0005434504766	22683	Economy	16100.00
0005434504782	22683	Economy	16100.00
0005434504677	22683	Economy	16100.00
0005434504772	22683	Economy	16100.00
0005434504768	22683	Economy	16100.00
0005434504771	22683	Economy	16100.00
0005434504845	22683	Economy	16100.00
0005435104000	22683	Economy	16100.00
0005435654221	1652	Business	50000.00
0005433368683	1652	Business	50000.00
0005433368604	1652	Business	50000.00
0005435654216	1652	Business	50000.00
0005433368466	1652	Business	50000.00
0005433368684	1652	Business	50000.00
0005435654234	1652	Business	50000.00
0005435654242	1652	Business	50000.00
0005435654206	1652	Business	50000.00
0005433368523	1652	Business	50000.00
0005435654244	1652	Business	50000.00
0005435654208	1652	Business	50000.00
0005435654235	1652	Economy	16700.00
0005435654225	1652	Economy	16700.00
0005433368569	1652	Economy	16700.00
0005433368514	1652	Economy	16700.00
0005433368467	1652	Economy	16700.00
0005433368647	1652	Economy	16700.00
0005433368521	1652	Economy	16700.00
0005433368551	1652	Economy	16700.00
0005435654246	1652	Economy	16700.00
0005435654239	1652	Economy	16700.00
0005435654227	1652	Economy	18300.00
0005435654231	1652	Economy	18300.00
0005435654217	1652	Economy	18300.00
0005433368543	1652	Economy	18300.00
0005435654248	1652	Economy	18300.00
0005433368451	1652	Economy	16700.00
0005433368411	1652	Economy	16700.00
0005435654249	1652	Economy	16700.00
0005435654223	1652	Economy	16700.00
0005433368596	1652	Economy	16700.00
0005433368717	1652	Economy	16700.00
0005433368629	1652	Economy	16700.00
0005435654218	1652	Economy	16700.00
0005433368561	1652	Economy	16700.00
0005435654222	1652	Economy	16700.00
0005433368620	1652	Economy	16700.00
0005435654241	1652	Economy	16700.00
0005435654219	1652	Economy	16700.00
0005435654237	1652	Economy	16700.00
0005435654210	1652	Economy	16700.00
0005433368450	1652	Economy	16700.00
0005433368690	1652	Economy	16700.00
0005435654207	1652	Economy	16700.00
0005435654245	1652	Economy	16700.00
0005435654240	1652	Economy	16700.00
0005433368622	1652	Economy	16700.00
0005433368667	1652	Economy	16700.00
0005433368522	1652	Economy	16700.00
0005433368503	1652	Economy	16700.00
0005433368520	1652	Economy	16700.00
0005435654229	1652	Economy	16700.00
0005435654214	1652	Economy	16700.00
0005435654236	1652	Economy	16700.00
0005433368621	1652	Economy	16700.00
0005435654212	1652	Economy	16700.00
0005435654213	1652	Economy	16700.00
0005433368519	1652	Economy	16700.00
0005435654209	1652	Economy	16700.00
0005435654228	1652	Economy	16700.00
0005433368479	1652	Economy	16700.00
0005433368358	1652	Economy	16700.00
0005435654247	1652	Economy	16700.00
0005433368601	1652	Economy	16700.00
0005433368716	1652	Economy	16700.00
0005435654220	1652	Economy	16700.00
0005433368577	1652	Economy	16700.00
0005435654238	1652	Economy	16700.00
0005433368513	1652	Economy	16700.00
0005433368515	1652	Economy	16700.00
0005435654232	1652	Economy	16700.00
0005433368668	1652	Economy	16700.00
0005435654233	1652	Economy	16700.00
0005433368544	1652	Economy	16700.00
0005433368641	1652	Economy	16700.00
0005433368552	1652	Economy	16700.00
0005435654226	1652	Economy	16700.00
0005435654243	1652	Economy	16700.00
0005433368583	1652	Economy	16700.00
0005433368549	1652	Economy	16700.00
0005433368628	1652	Economy	16700.00
0005433368603	1652	Economy	16700.00
0005433368439	1652	Economy	16700.00
0005433368648	1652	Economy	16700.00
0005435654215	1652	Economy	16700.00
0005433368360	1652	Economy	16700.00
0005435654211	1652	Economy	16700.00
0005433368480	1652	Economy	16700.00
0005433368407	1652	Economy	16700.00
0005435654224	1652	Economy	16700.00
0005433368359	1652	Economy	16700.00
0005435654230	1652	Economy	16700.00
0005433368563	1652	Economy	16700.00
0005433368518	1652	Economy	16700.00
0005433368666	1652	Economy	16700.00
0005433368859	21679	Business	50000.00
0005435653739	21679	Business	50000.00
0005435653698	21679	Business	50000.00
0005433368853	21679	Business	50000.00
0005433368839	21679	Business	50000.00
0005435653656	21679	Business	50000.00
0005433368828	21679	Business	50000.00
0005435653492	21679	Business	50000.00
0005435653689	21679	Business	50000.00
0005433368858	21679	Economy	16700.00
0005435653816	21679	Economy	16700.00
0005433368856	21679	Economy	16700.00
0005435653709	21679	Economy	16700.00
0005435653650	21679	Economy	16700.00
0005433368838	21679	Economy	16700.00
0005435653802	21679	Economy	16700.00
0005433368827	21679	Economy	16700.00
0005433368847	21679	Economy	16700.00
0005433368844	21679	Economy	18300.00
0005435653841	21679	Economy	18300.00
0005433368852	21679	Economy	18300.00
0005433368846	21679	Economy	18300.00
0005435653817	21679	Economy	16700.00
0005433368843	21679	Economy	16700.00
0005435653595	21679	Economy	16700.00
0005433368829	21679	Economy	16700.00
0005435653767	21679	Economy	16700.00
0005435653684	21679	Economy	16700.00
0005435653613	21679	Economy	16700.00
0005433368850	21679	Economy	16700.00
0005435653756	21679	Economy	16700.00
0005435653737	21679	Economy	16700.00
0005435653609	21679	Economy	16700.00
0005435653833	21679	Economy	16700.00
0005435653579	21679	Economy	16700.00
0005433368841	21679	Economy	16700.00
0005433368842	21679	Economy	16700.00
0005435653818	21679	Economy	16700.00
0005435653731	21679	Economy	16700.00
0005433368854	21679	Economy	16700.00
0005435653755	21679	Economy	16700.00
0005433368836	21679	Economy	16700.00
0005435653603	21679	Economy	16700.00
0005435653661	21679	Economy	16700.00
0005435653604	21679	Economy	16700.00
0005435653616	21679	Economy	16700.00
0005435653713	21679	Economy	16700.00
0005435653660	21679	Economy	16700.00
0005433368837	21679	Economy	16700.00
0005435653701	21679	Economy	16700.00
0005435653692	21679	Economy	16700.00
0005433368832	21679	Economy	16700.00
0005435653627	21679	Economy	16700.00
0005433368851	21679	Economy	16700.00
0005433368857	21679	Economy	16700.00
0005433368831	21679	Economy	16700.00
0005435653723	21679	Economy	16700.00
0005435653615	21679	Economy	16700.00
0005433368848	21679	Economy	16700.00
0005435653745	21679	Economy	16700.00
0005435653493	21679	Economy	16700.00
0005433368835	21679	Economy	16700.00
0005435653760	21679	Economy	16700.00
0005433368860	21679	Economy	16700.00
0005433368845	21679	Economy	16700.00
0005435653720	21679	Economy	16700.00
0005435653732	21679	Economy	16700.00
0005433368830	21679	Economy	16700.00
0005433368834	21679	Economy	16700.00
0005435653761	21679	Economy	16700.00
0005433368849	21679	Economy	16700.00
0005433368855	21679	Economy	16700.00
0005435653727	21679	Economy	16700.00
0005435653596	21679	Economy	16700.00
0005435653738	21679	Economy	16700.00
0005433368840	21679	Economy	16700.00
0005433368833	21679	Economy	16700.00
0005435653759	21679	Economy	16700.00
0005435627121	23770	Economy	11200.00
0005435627122	23770	Economy	11200.00
0005433987162	4187	Business	21500.00
0005433987148	4187	Business	21500.00
0005433987150	4187	Business	21500.00
0005433987155	4187	Business	21500.00
0005433987147	4187	Business	21500.00
0005433987143	4187	Business	21500.00
0005433987185	4187	Business	21500.00
0005433987184	4187	Economy	7200.00
0005433987138	4187	Economy	7200.00
0005433987157	4187	Economy	7200.00
0005433987152	4187	Economy	7200.00
0005433987159	4187	Economy	7200.00
0005433987178	4187	Economy	7900.00
0005433987172	4187	Economy	7900.00
0005433987134	4187	Economy	7900.00
0005433987182	4187	Economy	7200.00
0005433987174	4187	Economy	7200.00
0005433987141	4187	Economy	7200.00
0005435788836	4187	Economy	7200.00
0005433987151	4187	Economy	7200.00
0005433987175	4187	Economy	7200.00
0005433987149	4187	Economy	7200.00
0005433987142	4187	Economy	7200.00
0005433987154	4187	Economy	7200.00
0005433987163	4187	Economy	7200.00
0005433987177	4187	Economy	7200.00
0005433987171	4187	Economy	7200.00
0005435788837	4187	Economy	7200.00
0005433987164	4187	Economy	7200.00
0005433987173	4187	Economy	7200.00
0005433987181	4187	Economy	7200.00
0005433987169	4187	Economy	7200.00
0005433987137	4187	Economy	7200.00
0005433987168	4187	Economy	7200.00
0005433987176	4187	Economy	7200.00
0005433987188	4187	Economy	7200.00
0005433987156	4187	Economy	7200.00
0005433987186	4187	Economy	7200.00
0005433987165	4187	Economy	7200.00
0005433987170	4187	Economy	7200.00
0005433987158	4187	Economy	7200.00
0005433987144	4187	Economy	7200.00
0005433987179	4187	Economy	7200.00
0005433987136	4187	Economy	7200.00
0005433987167	4187	Economy	7200.00
0005433987146	4187	Economy	7200.00
0005433987145	4187	Economy	7200.00
0005433987180	4187	Economy	7200.00
0005433987140	4187	Economy	7200.00
0005435788838	4187	Economy	7200.00
0005433987187	4187	Economy	7200.00
0005433987160	4187	Economy	7200.00
0005433987161	4187	Economy	7200.00
0005433987139	4187	Economy	7200.00
0005433987166	4187	Economy	7200.00
0005433987153	4187	Economy	7200.00
0005433987183	4187	Economy	7200.00
0005433987135	4187	Economy	7200.00
0005433986772	25663	Business	21500.00
0005433986792	25663	Business	21500.00
0005433986838	25663	Business	21500.00
0005433986761	25663	Business	21500.00
0005433986506	25663	Business	21500.00
0005433986758	25663	Business	21500.00
0005433986744	25663	Business	21500.00
0005433986668	25663	Business	21500.00
0005435788822	25663	Economy	7200.00
0005433986839	25663	Economy	7200.00
0005435788813	25663	Economy	7200.00
0005433986677	25663	Economy	7200.00
0005433986588	25663	Economy	7200.00
0005433986627	25663	Economy	7200.00
0005433986683	25663	Economy	7200.00
0005433986762	25663	Economy	7900.00
0005433986846	25663	Economy	7900.00
0005433986655	25663	Economy	7900.00
0005433986676	25663	Economy	7200.00
0005433986513	25663	Economy	7200.00
0005433986828	25663	Economy	7200.00
0005433986814	25663	Economy	7200.00
0005433986507	25663	Economy	7200.00
0005433986837	25663	Economy	7200.00
0005433986456	25663	Economy	7200.00
0005433986470	25663	Economy	7200.00
0005433986726	25663	Economy	7200.00
0005433986457	25663	Economy	7200.00
0005433986441	25663	Economy	7200.00
0005433986666	25663	Economy	7200.00
0005433986639	25663	Economy	7200.00
0005433986778	25663	Economy	7200.00
0005433986678	25663	Economy	7200.00
0005433986718	25663	Economy	7200.00
0005433986773	25663	Economy	7200.00
0005433986587	25663	Economy	7200.00
0005433986679	25663	Economy	7200.00
0005433986628	25663	Economy	7200.00
0005435788818	25663	Economy	7200.00
0005433986783	25663	Economy	7200.00
0005433986620	25663	Economy	7200.00
0005433986810	25663	Economy	7200.00
0005433986745	25663	Economy	7200.00
0005433986621	25663	Economy	7200.00
0005433986684	25663	Economy	7200.00
0005433986650	25663	Economy	7200.00
0005433986682	25663	Economy	7200.00
0005433986825	25663	Economy	7200.00
0005433986803	25663	Economy	7200.00
0005433986597	25663	Economy	7200.00
0005433986649	25663	Economy	7200.00
0005433986643	25663	Economy	7200.00
0005433986624	25663	Economy	7200.00
0005433986809	25663	Economy	7200.00
0005433986626	25663	Economy	7200.00
0005433986589	25663	Economy	7200.00
0005433986586	25663	Economy	7200.00
0005433461630	20242	Business	201300.00
0005433460477	20242	Business	201300.00
0005433461629	20242	Business	201300.00
0005433460484	20242	Business	201300.00
0005433460481	20242	Economy	73800.00
0005433460483	20242	Economy	73800.00
0005433460488	20242	Economy	73800.00
0005433460478	20242	Economy	67100.00
0005433461643	20242	Economy	67100.00
0005433461634	20242	Economy	67100.00
0005433460486	20242	Economy	67100.00
0005433461638	20242	Economy	67100.00
0005433461641	20242	Economy	67100.00
0005433460482	20242	Economy	67100.00
0005433461635	20242	Economy	67100.00
0005433460475	20242	Economy	67100.00
0005433461640	20242	Economy	67100.00
0005433461628	20242	Economy	67100.00
0005433461632	20242	Economy	67100.00
0005433460476	20242	Economy	67100.00
0005433460487	20242	Economy	67100.00
0005433460480	20242	Economy	67100.00
0005433461633	20242	Economy	67100.00
0005433460490	20242	Economy	67100.00
0005433460485	20242	Economy	67100.00
0005433460489	20242	Economy	67100.00
0005433460479	20242	Economy	67100.00
0005433461637	20242	Economy	67100.00
0005433461639	20242	Economy	67100.00
0005433461636	20242	Economy	67100.00
0005433461631	20242	Economy	67100.00
0005433461642	20242	Economy	67100.00
0005433461627	20242	Economy	67100.00
0005435719592	24751	Economy	10400.00
0005435720161	24751	Economy	9400.00
0005435720159	24751	Economy	9400.00
0005435720160	24751	Economy	9400.00
0005435719593	24751	Economy	9400.00
0005435719594	24751	Economy	9400.00
0005433168480	21334	Economy	17000.00
0005433168477	21334	Economy	17000.00
0005434509267	21334	Economy	17000.00
0005433168481	21334	Economy	15500.00
0005433168482	21334	Economy	15500.00
0005434509301	21334	Economy	15500.00
0005433168475	21334	Economy	15500.00
0005433168474	21334	Economy	15500.00
0005433168476	21334	Economy	15500.00
0005434509256	21334	Economy	15500.00
0005434509251	21334	Economy	15500.00
0005434509283	21334	Economy	15500.00
0005433168479	21334	Economy	15500.00
0005434509282	21334	Economy	15500.00
0005433168478	21334	Economy	15500.00
0005434509268	21334	Economy	15500.00
0005434509274	21334	Economy	15500.00
0005434509302	21334	Economy	15500.00
0005434509266	21334	Economy	15500.00
0005434509269	21334	Economy	15500.00
0005434151782	17831	Business	18000.00
0005432655712	17831	Business	18000.00
0005432665308	17831	Business	18000.00
0005432869696	17831	Business	18000.00
0005434151783	17831	Economy	6000.00
0005432657495	17831	Economy	6000.00
0005432667491	17831	Economy	6000.00
0005432655738	17831	Economy	6000.00
0005432659743	17831	Economy	6600.00
0005432659740	17831	Economy	6600.00
0005432664166	17831	Economy	6600.00
0005432663062	17831	Economy	6600.00
0005432657514	17831	Economy	6000.00
0005432655725	17831	Economy	6000.00
0005432667486	17831	Economy	6000.00
0005432657497	17831	Economy	6000.00
0005432655752	17831	Economy	6000.00
0005432661958	17831	Economy	6000.00
0005432657494	17831	Economy	6000.00
0005432655735	17831	Economy	6000.00
0005432663063	17831	Economy	6000.00
0005432664172	17831	Economy	6000.00
0005432657513	17831	Economy	6000.00
0005432659735	17831	Economy	6000.00
0005434151781	17831	Economy	6000.00
0005432659744	17831	Economy	6000.00
0005432655754	17831	Economy	6000.00
0005432655724	17831	Economy	6000.00
0005432655753	17831	Economy	6000.00
0005432659741	17831	Economy	6000.00
0005432655740	17831	Economy	6000.00
0005432658622	17831	Economy	6000.00
0005432658630	17831	Economy	6000.00
0005432655751	17831	Economy	6000.00
0005432869697	17831	Economy	6000.00
0005432661947	17831	Economy	6000.00
0005432661959	17831	Economy	6000.00
0005432660846	17831	Economy	6000.00
0005434151780	17831	Economy	6000.00
0005432660856	17831	Economy	6000.00
0005432869699	17831	Economy	6000.00
0005432664168	17831	Economy	6000.00
0005432661949	17831	Economy	6000.00
0005432661948	17831	Economy	6000.00
0005432655706	17831	Economy	6000.00
0005432657512	17831	Economy	6000.00
0005432869701	17831	Economy	6000.00
0005432655755	17831	Economy	6000.00
0005432655705	17831	Economy	6000.00
0005432655736	17831	Economy	6000.00
0005432658634	17831	Economy	6000.00
0005432659738	17831	Economy	6000.00
0005432659739	17831	Economy	6000.00
0005432664167	17831	Economy	6000.00
0005432869698	17831	Economy	6000.00
0005432655737	17831	Economy	6000.00
0005432657496	17831	Economy	6000.00
0005432665307	17831	Economy	6000.00
0005432655710	17831	Economy	6000.00
0005432655730	17831	Economy	6000.00
0005432869700	17831	Economy	6000.00
0005432869702	17831	Economy	6000.00
0005432665306	17831	Economy	6000.00
0005432869628	26310	Business	18000.00
0005432655824	26310	Business	18000.00
0005432657526	26310	Business	18000.00
0005434151750	26310	Business	18000.00
0005432869627	26310	Business	18000.00
0005432667507	26310	Business	18000.00
0005432658642	26310	Economy	6000.00
0005432655817	26310	Economy	6000.00
0005432667504	26310	Economy	6600.00
0005432667506	26310	Economy	6600.00
0005432659757	26310	Economy	6000.00
0005432657524	26310	Economy	6000.00
0005432655819	26310	Economy	6000.00
0005432660869	26310	Economy	6000.00
0005432659758	26310	Economy	6000.00
0005432655818	26310	Economy	6000.00
0005432655820	26310	Economy	6000.00
0005432665326	26310	Economy	6000.00
0005432869615	26310	Economy	6000.00
0005432666439	26310	Economy	6000.00
0005432869632	26310	Economy	6000.00
0005432655823	26310	Economy	6000.00
0005432666440	26310	Economy	6000.00
0005432655826	26310	Economy	6000.00
0005432869641	26310	Economy	6000.00
0005432657525	26310	Economy	6000.00
0005432655825	26310	Economy	6000.00
0005432655821	26310	Economy	6000.00
0005432655816	26310	Economy	6000.00
0005432869633	26310	Economy	6000.00
0005432869614	26310	Economy	6000.00
0005432667505	26310	Economy	6000.00
0005432660868	26310	Economy	6000.00
0005432869640	26310	Economy	6000.00
0005432658643	26310	Economy	6000.00
0005432655822	26310	Economy	6000.00
0005432869613	26310	Economy	6000.00
0005432329884	3097	Business	16100.00
0005432329892	3097	Business	16100.00
0005432905209	3097	Business	16100.00
0005432905230	3097	Business	16100.00
0005433439057	3097	Business	16100.00
0005432329872	3097	Business	16100.00
0005432329881	3097	Business	16100.00
0005432329863	3097	Business	16100.00
0005432329858	3097	Business	16100.00
0005432329894	3097	Economy	5400.00
0005433439065	3097	Economy	5400.00
0005432905234	3097	Economy	5400.00
0005432329898	3097	Economy	5400.00
0005432329862	3097	Economy	5400.00
0005432329878	3097	Economy	5400.00
0005432329889	3097	Economy	5400.00
0005432329896	3097	Economy	5400.00
0005432329880	3097	Economy	5400.00
0005432329861	3097	Economy	5900.00
0005433439059	3097	Economy	5900.00
0005432905208	3097	Economy	5900.00
0005432329879	3097	Economy	5900.00
0005432329871	3097	Economy	5400.00
0005432329877	3097	Economy	5400.00
0005432329876	3097	Economy	5400.00
0005433439064	3097	Economy	5400.00
0005432329899	3097	Economy	5400.00
0005432329868	3097	Economy	5400.00
0005432287320	3097	Economy	5400.00
0005432329882	3097	Economy	5400.00
0005432848861	3097	Economy	5400.00
0005432905229	3097	Economy	5400.00
0005432905231	3097	Economy	5400.00
0005433439056	3097	Economy	5400.00
0005432329859	3097	Economy	5400.00
0005432848860	3097	Economy	5400.00
0005432329886	3097	Economy	5400.00
0005432329887	3097	Economy	5400.00
0005432287316	3097	Economy	5400.00
0005432329867	3097	Economy	5400.00
0005432287317	3097	Economy	5400.00
0005433439060	3097	Economy	5400.00
0005432287319	3097	Economy	5400.00
0005432329883	3097	Economy	5400.00
0005432848842	3097	Economy	5400.00
0005432329866	3097	Economy	5400.00
0005432848857	3097	Economy	5400.00
0005433439063	3097	Economy	5400.00
0005432329895	3097	Economy	5400.00
0005432329860	3097	Economy	5400.00
0005432329891	3097	Economy	5400.00
0005433439058	3097	Economy	5400.00
0005433439061	3097	Economy	5400.00
0005432329890	3097	Economy	5400.00
0005432329869	3097	Economy	5400.00
0005432329885	3097	Economy	5400.00
0005432329865	3097	Economy	5400.00
0005432329888	3097	Economy	5400.00
0005432329874	3097	Economy	5400.00
0005432329897	3097	Economy	5400.00
0005432329873	3097	Economy	5400.00
0005432905207	3097	Economy	5400.00
0005432905222	3097	Economy	5400.00
0005433439062	3097	Economy	5400.00
0005432329870	3097	Economy	5400.00
0005432329893	3097	Economy	5400.00
0005432287318	3097	Economy	5400.00
0005432329864	3097	Economy	5400.00
0005432329875	3097	Economy	5400.00
0005432287321	3097	Economy	5400.00
0005432329549	31138	Business	16100.00
0005432848890	31138	Business	16100.00
0005433439001	31138	Business	16100.00
0005432329354	31138	Business	16100.00
0005433438993	31138	Business	16100.00
0005432329418	31138	Business	16100.00
0005432329591	31138	Business	16100.00
0005432329528	31138	Business	16100.00
0005432054381	31138	Business	16100.00
0005432848894	31138	Business	16100.00
0005432329266	31138	Economy	5400.00
0005432329271	31138	Economy	5400.00
0005432329384	31138	Economy	5400.00
0005432329578	31138	Economy	5400.00
0005432848896	31138	Economy	5400.00
0005432329114	31138	Economy	5400.00
0005432054380	31138	Economy	5900.00
0005432329224	31138	Economy	5900.00
0005432329508	31138	Economy	5900.00
0005432329597	31138	Economy	5900.00
0005432848897	31138	Economy	5900.00
0005432329510	31138	Economy	5400.00
0005432848898	31138	Economy	5400.00
0005432329439	31138	Economy	5400.00
0005432329267	31138	Economy	5400.00
0005432329397	31138	Economy	5400.00
0005432329527	31138	Economy	5400.00
0005432329509	31138	Economy	5400.00
0005433438988	31138	Economy	5400.00
0005432905269	31138	Economy	5400.00
0005433438994	31138	Economy	5400.00
0005432329518	31138	Economy	5400.00
0005433439000	31138	Economy	5400.00
0005432329385	31138	Economy	5400.00
0005432848895	31138	Economy	5400.00
0005432905266	31138	Economy	5400.00
0005432329539	31138	Economy	5400.00
0005432329197	31138	Economy	5400.00
0005432329382	31138	Economy	5400.00
0005432905267	31138	Economy	5400.00
0005432329198	31138	Economy	5400.00
0005432329270	31138	Economy	5400.00
0005432329339	31138	Economy	5400.00
0005432848893	31138	Economy	5400.00
0005432329441	31138	Economy	5400.00
0005433438973	31138	Economy	5400.00
0005432329417	31138	Economy	5400.00
0005432848891	31138	Economy	5400.00
0005432329438	31138	Economy	5400.00
0005432329199	31138	Economy	5400.00
0005433438989	31138	Economy	5400.00
0005432329383	31138	Economy	5400.00
0005432329460	31138	Economy	5400.00
0005432329579	31138	Economy	5400.00
0005432905268	31138	Economy	5400.00
0005432848889	31138	Economy	5400.00
0005432848892	31138	Economy	5400.00
0005435999717	6179	Business	124600.00
0005435999740	6179	Business	124600.00
0005435488142	6179	Business	124600.00
0005435999731	6179	Business	124600.00
0005435488163	6179	Economy	41500.00
0005435999732	6179	Economy	41500.00
0005435297172	6179	Economy	41500.00
0005435999734	6179	Economy	41500.00
0005434310092	6179	Economy	41500.00
0005435999741	6179	Economy	41500.00
0005434310091	6179	Economy	41500.00
0005435999737	6179	Economy	41500.00
0005435488332	6179	Economy	41500.00
0005435488189	6179	Economy	41500.00
0005435999728	6179	Economy	41500.00
0005434310094	6179	Economy	41500.00
0005435488160	6179	Economy	41500.00
0005432146254	6179	Economy	41500.00
0005435999739	6179	Economy	41500.00
0005435297175	6179	Economy	41500.00
0005435488166	6179	Economy	41500.00
0005435488045	6179	Economy	41500.00
0005435488292	6179	Economy	41500.00
0005435488135	6179	Economy	41500.00
0005435999721	6179	Economy	41500.00
0005435999723	6179	Economy	41500.00
0005435999733	6179	Economy	41500.00
0005435488132	6179	Economy	45700.00
0005434310088	6179	Economy	45700.00
0005435488244	6179	Economy	45700.00
0005435999720	6179	Economy	41500.00
0005435488133	6179	Economy	41500.00
0005435488167	6179	Economy	41500.00
0005435999730	6179	Economy	41500.00
0005435488281	6179	Economy	41500.00
0005435999722	6179	Economy	41500.00
0005435488188	6179	Economy	41500.00
0005435488152	6179	Economy	41500.00
0005434310099	6179	Economy	41500.00
0005434310093	6179	Economy	41500.00
0005435488197	6179	Economy	41500.00
0005435999724	6179	Economy	41500.00
0005435999718	6179	Economy	41500.00
0005434310096	6179	Economy	41500.00
0005435999727	6179	Economy	41500.00
0005435488134	6179	Economy	41500.00
0005435999726	6179	Economy	41500.00
0005435999725	6179	Economy	41500.00
0005435488143	6179	Economy	41500.00
0005434310097	6179	Economy	41500.00
0005435297199	6179	Economy	41500.00
0005435999736	6179	Economy	41500.00
0005435297176	6179	Economy	41500.00
0005434310100	6179	Economy	41500.00
0005435999735	6179	Economy	41500.00
0005434310095	6179	Economy	41500.00
0005435488162	6179	Economy	41500.00
0005435488165	6179	Economy	41500.00
0005435488280	6179	Economy	41500.00
0005434310089	6179	Economy	41500.00
0005434310098	6179	Economy	41500.00
0005435999719	6179	Economy	41500.00
0005435488161	6179	Economy	41500.00
0005435488226	6179	Economy	41500.00
0005435999729	6179	Economy	41500.00
0005434310090	6179	Economy	41500.00
0005435488225	6179	Economy	41500.00
0005435999738	6179	Economy	41500.00
0005434309953	19550	Business	124600.00
0005435999495	19550	Business	124600.00
0005434309965	19550	Business	124600.00
0005435488372	19550	Business	124600.00
0005435488375	19550	Business	124600.00
0005435297235	19550	Economy	41500.00
0005435999507	19550	Economy	41500.00
0005435488363	19550	Economy	41500.00
0005435297238	19550	Economy	41500.00
0005435999531	19550	Economy	41500.00
0005435488367	19550	Economy	41500.00
0005434309946	19550	Economy	41500.00
0005435999498	19550	Economy	41500.00
0005435999549	19550	Economy	41500.00
0005435999494	19550	Economy	41500.00
0005435488383	19550	Economy	41500.00
0005434309975	19550	Economy	41500.00
0005435999518	19550	Economy	41500.00
0005435999499	19550	Economy	41500.00
0005435999550	19550	Economy	41500.00
0005435999540	19550	Economy	41500.00
0005434309952	19550	Economy	41500.00
0005435999500	19550	Economy	41500.00
0005435297239	19550	Economy	45700.00
0005435488362	19550	Economy	45700.00
0005435999446	19550	Economy	45700.00
0005435488370	19550	Economy	41500.00
0005435999497	19550	Economy	41500.00
0005434309951	19550	Economy	41500.00
0005434310017	19550	Economy	41500.00
0005435488381	19550	Economy	41500.00
0005435488379	19550	Economy	41500.00
0005435488382	19550	Economy	41500.00
0005435999504	19550	Economy	41500.00
0005435999520	19550	Economy	41500.00
0005434309960	19550	Economy	41500.00
0005435488366	19550	Economy	41500.00
0005435488380	19550	Economy	41500.00
0005435999447	19550	Economy	41500.00
0005435488371	19550	Economy	41500.00
0005435488377	19550	Economy	41500.00
0005434309974	19550	Economy	41500.00
0005434310006	19550	Economy	41500.00
0005435488364	19550	Economy	41500.00
0005435488373	19550	Economy	41500.00
0005435488368	19550	Economy	41500.00
0005435297237	19550	Economy	41500.00
0005435999511	19550	Economy	41500.00
0005435999519	19550	Economy	41500.00
0005435999501	19550	Economy	41500.00
0005434309922	19550	Economy	41500.00
0005435488376	19550	Economy	41500.00
0005435297234	19550	Economy	41500.00
0005435488365	19550	Economy	41500.00
0005435999489	19550	Economy	41500.00
0005434309945	19550	Economy	41500.00
0005435488374	19550	Economy	41500.00
0005435999548	19550	Economy	41500.00
0005434310016	19550	Economy	41500.00
0005435488369	19550	Economy	41500.00
0005435488378	19550	Economy	41500.00
0005435297236	19550	Economy	41500.00
0005435297233	19550	Economy	41500.00
0005435999532	19550	Economy	41500.00
0005435999543	19550	Economy	41500.00
0005433158184	17535	Economy	13600.00
0005433157015	17535	Economy	12300.00
0005434446552	17535	Economy	12300.00
0005433157014	17535	Economy	12300.00
0005433158185	17535	Economy	12300.00
0005433158188	17535	Economy	12300.00
0005433158189	17535	Economy	12300.00
0005433158186	17535	Economy	12300.00
0005433158187	17535	Economy	12300.00
0005433157012	17535	Economy	12300.00
0005433157011	17535	Economy	12300.00
0005433157013	17535	Economy	12300.00
0005433158190	17535	Economy	12300.00
0005433186260	1564	Business	86000.00
0005435518386	1564	Business	86000.00
0005435518367	1564	Business	86000.00
0005433186266	1564	Business	86000.00
0005435508732	1564	Business	86000.00
0005435518372	1564	Business	86000.00
0005435508742	1564	Business	86000.00
0005435518376	1564	Business	86000.00
0005433186277	1564	Business	86000.00
0005435502874	1564	Business	86000.00
0005433186267	1564	Business	86000.00
0005435502862	1564	Business	86000.00
0005435508744	1564	Economy	28700.00
0005435518370	1564	Economy	28700.00
0005435518387	1564	Economy	28700.00
0005435508729	1564	Economy	28700.00
0005434566263	1564	Economy	28700.00
0005433186272	1564	Economy	28700.00
0005435518382	1564	Economy	28700.00
0005435502865	1564	Economy	28700.00
0005435508741	1564	Economy	28700.00
0005433186273	1564	Economy	31500.00
0005434566265	1564	Economy	31500.00
0005434566264	1564	Economy	31500.00
0005435518378	1564	Economy	31500.00
0005434566267	1564	Economy	31500.00
0005435508746	1564	Economy	28700.00
0005435518368	1564	Economy	28700.00
0005435508745	1564	Economy	28700.00
0005435508730	1564	Economy	28700.00
0005435508739	1564	Economy	28700.00
0005435518384	1564	Economy	28700.00
0005435502863	1564	Economy	28700.00
0005435518385	1564	Economy	28700.00
0005435502868	1564	Economy	28700.00
0005435518383	1564	Economy	28700.00
0005435502881	1564	Economy	28700.00
0005435518379	1564	Economy	28700.00
0005435508737	1564	Economy	28700.00
0005435518375	1564	Economy	28700.00
0005435502873	1564	Economy	28700.00
0005435518369	1564	Economy	28700.00
0005433186308	1564	Economy	28700.00
0005435502870	1564	Economy	28700.00
0005435508731	1564	Economy	28700.00
0005434566266	1564	Economy	28700.00
0005435502872	1564	Economy	28700.00
0005435502875	1564	Economy	28700.00
0005434566260	1564	Economy	28700.00
0005435508736	1564	Economy	28700.00
0005435502882	1564	Economy	28700.00
0005435508728	1564	Economy	28700.00
0005434566262	1564	Economy	28700.00
0005433186274	1564	Economy	28700.00
0005435508733	1564	Economy	28700.00
0005435502869	1564	Economy	28700.00
0005435502877	1564	Economy	28700.00
0005435518373	1564	Economy	28700.00
0005435518371	1564	Economy	28700.00
0005435518380	1564	Economy	28700.00
0005433186255	1564	Economy	28700.00
0005433186268	1564	Economy	28700.00
0005433186278	1564	Economy	28700.00
0005434566258	1564	Economy	28700.00
0005435508734	1564	Economy	28700.00
0005435508738	1564	Economy	28700.00
0005435508735	1564	Economy	28700.00
0005433186244	1564	Economy	28700.00
0005435502876	1564	Economy	28700.00
0005434566261	1564	Economy	28700.00
0005434566259	1564	Economy	28700.00
0005435502864	1564	Economy	28700.00
0005435518377	1564	Economy	28700.00
0005435508740	1564	Economy	28700.00
0005435502867	1564	Economy	28700.00
0005434566257	1564	Economy	28700.00
0005433186271	1564	Economy	28700.00
0005435518374	1564	Economy	28700.00
0005435502871	1564	Economy	28700.00
0005435502880	1564	Economy	28700.00
0005435518381	1564	Economy	28700.00
0005435508747	1564	Economy	28700.00
0005435502866	1564	Economy	28700.00
0005435502878	1564	Economy	28700.00
0005434566256	1564	Economy	28700.00
0005435502879	1564	Economy	28700.00
0005435508743	1564	Economy	28700.00
0005432291994	1564	Economy	28700.00
0005434566127	20844	Business	86000.00
0005433186337	20844	Business	86000.00
0005435545853	20844	Business	86000.00
0005435529526	20844	Business	86000.00
0005435545871	20844	Business	86000.00
0005435529592	20844	Business	86000.00
0005435529641	20844	Business	86000.00
0005435529585	20844	Economy	28700.00
0005435502659	20844	Economy	28700.00
0005435529639	20844	Economy	28700.00
0005435529584	20844	Economy	28700.00
0005435529563	20844	Economy	28700.00
0005435502691	20844	Economy	28700.00
0005435502720	20844	Economy	28700.00
0005435529611	20844	Economy	31500.00
0005435545851	20844	Economy	31500.00
0005434566169	20844	Economy	31500.00
0005435529501	20844	Economy	28700.00
0005435502634	20844	Economy	28700.00
0005435502665	20844	Economy	28700.00
0005435529632	20844	Economy	28700.00
0005434566136	20844	Economy	28700.00
0005434566080	20844	Economy	28700.00
0005434566151	20844	Economy	28700.00
0005435502692	20844	Economy	28700.00
0005435502725	20844	Economy	28700.00
0005433186338	20844	Economy	28700.00
0005435529640	20844	Economy	28700.00
0005435502724	20844	Economy	28700.00
0005435545874	20844	Economy	28700.00
0005435529633	20844	Economy	28700.00
0005435529567	20844	Economy	28700.00
0005434566152	20844	Economy	28700.00
0005434566154	20844	Economy	28700.00
0005435529609	20844	Economy	28700.00
0005435502704	20844	Economy	28700.00
0005435502693	20844	Economy	28700.00
0005435502699	20844	Economy	28700.00
0005434566168	20844	Economy	28700.00
0005435529525	20844	Economy	28700.00
0005435502698	20844	Economy	28700.00
0005435545852	20844	Economy	28700.00
0005435502711	20844	Economy	28700.00
0005435529568	20844	Economy	28700.00
0005435502701	20844	Economy	28700.00
0005435502664	20844	Economy	28700.00
0005435545872	20844	Economy	28700.00
0005433186336	20844	Economy	28700.00
0005435502576	20844	Economy	28700.00
0005435502697	20844	Economy	28700.00
0005435502658	20844	Economy	28700.00
0005433186341	20844	Economy	28700.00
0005435502694	20844	Economy	28700.00
0005434566170	20844	Economy	28700.00
0005435529580	20844	Economy	28700.00
0005435529603	20844	Economy	28700.00
0005433186339	20844	Economy	28700.00
0005434566110	20844	Economy	28700.00
0005435529582	20844	Economy	28700.00
0005435529601	20844	Economy	28700.00
0005433186340	20844	Economy	28700.00
0005435502575	20844	Economy	28700.00
0005435502719	20844	Economy	28700.00
0005435502617	20844	Economy	28700.00
0005435529591	20844	Economy	28700.00
0005433186342	20844	Economy	28700.00
0005435502700	20844	Economy	28700.00
0005435545873	20844	Economy	28700.00
0005435502618	20844	Economy	28700.00
0005435502678	20844	Economy	28700.00
0005434566140	20844	Economy	28700.00
0005435502712	20844	Economy	28700.00
0005435502620	20844	Economy	28700.00
0005435142988	3927	Economy	21600.00
0005435931667	3927	Economy	19700.00
0005435142989	3927	Economy	19700.00
0005435153911	3927	Economy	19700.00
0005435142990	3927	Economy	19700.00
0005435153913	3927	Economy	19700.00
0005435153915	3927	Economy	19700.00
0005435153914	3927	Economy	19700.00
0005435931668	3927	Economy	19700.00
0005435153916	3927	Economy	19700.00
0005435153912	3927	Economy	19700.00
0005435931697	21889	Economy	19700.00
0005435931699	21889	Economy	19700.00
0005435153849	21889	Economy	19700.00
0005435931698	21889	Economy	19700.00
0005435931700	21889	Economy	19700.00
0005435153871	21889	Economy	19700.00
0005432629228	7217	Economy	14300.00
0005435225734	7217	Economy	13000.00
0005432629229	7217	Economy	13000.00
0005432629235	7217	Economy	13000.00
0005432629223	7217	Economy	13000.00
0005435225700	7217	Economy	13000.00
0005432629224	7217	Economy	13000.00
0005432629227	7217	Economy	13000.00
0005432629236	7217	Economy	13000.00
0005435225718	7217	Economy	13000.00
0005432629226	7217	Economy	13000.00
0005435225725	7217	Economy	13000.00
0005435225699	7217	Economy	13000.00
0005432629222	7217	Economy	13000.00
0005432629232	7217	Economy	13000.00
0005432629234	7217	Economy	13000.00
0005435225719	7217	Economy	13000.00
0005432629230	7217	Economy	13000.00
0005435225701	7217	Economy	13000.00
0005432629233	7217	Economy	13000.00
0005432629231	7217	Economy	13000.00
0005432629225	7217	Economy	13000.00
0005435225735	7217	Economy	13000.00
0005435225786	28106	Economy	13000.00
0005432629143	28106	Economy	13000.00
0005432629087	28106	Economy	13000.00
0005432629094	28106	Economy	13000.00
0005432629093	28106	Economy	13000.00
0005432629114	28106	Economy	13000.00
0005432629116	28106	Economy	13000.00
0005432629185	28106	Economy	13000.00
0005432629160	28106	Economy	13000.00
0005432629135	28106	Economy	13000.00
0005435225785	28106	Economy	13000.00
0005435225789	28106	Economy	13000.00
0005435225792	28106	Economy	13000.00
0005435225788	28106	Economy	13000.00
0005432629115	28106	Economy	13000.00
0005435225790	28106	Economy	13000.00
0005435225787	28106	Economy	13000.00
0005432629112	28106	Economy	13000.00
0005432629083	28106	Economy	13000.00
0005435225791	28106	Economy	13000.00
0005432629158	28106	Economy	13000.00
0005435960151	8756	Economy	10500.00
0005435960148	8756	Economy	10500.00
0005434267991	8756	Economy	10500.00
0005434268011	8756	Economy	10500.00
0005435960150	8756	Economy	10500.00
0005435960149	8756	Economy	10500.00
0005435960110	15234	Economy	10500.00
0005434268048	15234	Economy	10500.00
0005434268047	15234	Economy	10500.00
0005434268049	15234	Economy	10500.00
0005435960111	15234	Economy	10500.00
0005432693838	1210	Business	115000.00
0005432675524	1210	Business	115000.00
0005432693822	1210	Business	115000.00
0005432873426	1210	Business	115000.00
0005432693840	1210	Business	115000.00
0005432693831	1210	Business	115000.00
0005432675522	1210	Business	115000.00
0005432693828	1210	Business	115000.00
0005432693832	1210	Business	115000.00
0005432675520	1210	Business	115000.00
0005432693826	1210	Business	115000.00
0005432675521	1210	Business	115000.00
0005432675526	1210	Business	115000.00
0005432675531	1210	Economy	38300.00
0005432693819	1210	Economy	38300.00
0005432675528	1210	Economy	38300.00
0005432693817	1210	Economy	38300.00
0005432677670	1210	Economy	38300.00
0005432675519	1210	Economy	38300.00
0005432675518	1210	Economy	38300.00
0005432693816	1210	Economy	38300.00
0005432693835	1210	Economy	38300.00
0005432693836	1210	Economy	42200.00
0005432693825	1210	Economy	42200.00
0005432873420	1210	Economy	38300.00
0005432693829	1210	Economy	38300.00
0005432677673	1210	Economy	38300.00
0005432693846	1210	Economy	38300.00
0005432675516	1210	Economy	38300.00
0005432693845	1210	Economy	38300.00
0005432873405	1210	Economy	38300.00
0005432693842	1210	Economy	38300.00
0005432693847	1210	Economy	38300.00
0005432675529	1210	Economy	38300.00
0005432693830	1210	Economy	38300.00
0005432873421	1210	Economy	38300.00
0005432693833	1210	Economy	38300.00
0005432677671	1210	Economy	38300.00
0005432693837	1210	Economy	38300.00
0005432693843	1210	Economy	38300.00
0005432693820	1210	Economy	38300.00
0005432693824	1210	Economy	38300.00
0005432693823	1210	Economy	38300.00
0005432675525	1210	Economy	38300.00
0005432693844	1210	Economy	38300.00
0005432677674	1210	Economy	38300.00
0005432693821	1210	Economy	38300.00
0005432693841	1210	Economy	38300.00
0005432675527	1210	Economy	38300.00
0005432693834	1210	Economy	38300.00
0005432873399	1210	Economy	38300.00
0005432675517	1210	Economy	38300.00
0005432675523	1210	Economy	38300.00
0005432675530	1210	Economy	38300.00
0005432693839	1210	Economy	38300.00
0005432693818	1210	Economy	38300.00
0005432693827	1210	Economy	38300.00
0005432677672	1210	Economy	38300.00
0005432677647	17473	Business	115000.00
0005432693739	17473	Business	115000.00
0005432675338	17473	Business	115000.00
0005432693587	17473	Business	115000.00
0005432693449	17473	Business	115000.00
0005432693448	17473	Business	115000.00
0005432693600	17473	Business	115000.00
0005432693740	17473	Business	115000.00
0005432873476	17473	Business	115000.00
0005432693493	17473	Business	115000.00
0005432693471	17473	Business	115000.00
0005432675342	17473	Business	115000.00
0005432693603	17473	Economy	38300.00
0005432675424	17473	Economy	38300.00
0005432675438	17473	Economy	38300.00
0005432693629	17473	Economy	38300.00
0005432693604	17473	Economy	42200.00
0005432693472	17473	Economy	42200.00
0005432677627	17473	Economy	42200.00
0005432677628	17473	Economy	38300.00
0005432675413	17473	Economy	38300.00
0005432677640	17473	Economy	38300.00
0005432675361	17473	Economy	38300.00
0005432677641	17473	Economy	38300.00
0005432675432	17473	Economy	38300.00
0005432677626	17473	Economy	38300.00
0005432675437	17473	Economy	38300.00
0005432675427	17473	Economy	38300.00
0005432693612	17473	Economy	38300.00
0005432693492	17473	Economy	38300.00
0005432693729	17473	Economy	38300.00
0005432677639	17473	Economy	38300.00
0005432693580	17473	Economy	38300.00
0005432675420	17473	Economy	38300.00
0005432677629	17473	Economy	38300.00
0005432693515	17473	Economy	38300.00
0005432693529	17473	Economy	38300.00
0005432873474	17473	Economy	38300.00
0005432873477	17473	Economy	38300.00
0005432693400	17473	Economy	38300.00
0005432693611	17473	Economy	38300.00
0005432873475	17473	Economy	38300.00
0005432675331	17473	Economy	38300.00
0005432693645	17473	Economy	38300.00
0005432873473	17473	Economy	38300.00
0005432677646	17473	Economy	38300.00
0005432693630	17473	Economy	38300.00
0005432693581	17473	Economy	38300.00
0005432873478	17473	Economy	38300.00
0005432675445	17473	Economy	38300.00
0005432693569	17473	Economy	38300.00
0005432693665	17473	Economy	38300.00
0005432693447	17473	Economy	38300.00
0005432693504	17473	Economy	38300.00
0005432675423	17473	Economy	38300.00
0005432693487	17473	Economy	38300.00
0005432693730	17473	Economy	38300.00
0005432693488	17473	Economy	38300.00
0005434435585	1139	Economy	15200.00
0005434435579	1139	Economy	13900.00
0005434435578	1139	Economy	13900.00
0005434435572	1139	Economy	13900.00
0005434435582	1139	Economy	13900.00
0005434435574	1139	Economy	13900.00
0005434435580	1139	Economy	13900.00
0005434435576	1139	Economy	13900.00
0005433156893	1139	Economy	13900.00
0005434435586	1139	Economy	13900.00
0005434435573	1139	Economy	13900.00
0005434435583	1139	Economy	13900.00
0005434435575	1139	Economy	13900.00
0005434435577	1139	Economy	13900.00
0005433156924	1139	Economy	13900.00
0005434435584	1139	Economy	13900.00
0005434435581	1139	Economy	13900.00
0005434435449	17305	Economy	15200.00
0005433156976	17305	Economy	15200.00
0005434435457	17305	Economy	13900.00
0005433156977	17305	Economy	13900.00
0005434435435	17305	Economy	13900.00
0005433156973	17305	Economy	13900.00
0005434435400	17305	Economy	13900.00
0005434435380	17305	Economy	13900.00
0005434435442	17305	Economy	13900.00
0005434435437	17305	Economy	13900.00
0005434435441	17305	Economy	13900.00
0005434435468	17305	Economy	13900.00
0005434435476	17305	Economy	13900.00
0005433156975	17305	Economy	13900.00
0005433156972	17305	Economy	13900.00
0005434435475	17305	Economy	13900.00
0005433156970	17305	Economy	13900.00
0005434435448	17305	Economy	13900.00
0005434435440	17305	Economy	13900.00
0005433156969	17305	Economy	13900.00
0005434435451	17305	Economy	13900.00
0005434435379	17305	Economy	13900.00
0005434435456	17305	Economy	13900.00
0005433156971	17305	Economy	13900.00
0005433156974	17305	Economy	13900.00
0005434435502	17305	Economy	13900.00
0005434435409	17305	Economy	13900.00
0005435928227	4068	Economy	7500.00
0005435087027	4068	Economy	7500.00
0005435928229	4068	Economy	7500.00
0005435928223	4068	Economy	7500.00
0005435928232	4068	Economy	7500.00
0005435928228	4068	Economy	7500.00
0005435087026	4068	Economy	7500.00
0005435087029	4068	Economy	7500.00
0005435928222	4068	Economy	7500.00
0005435087028	4068	Economy	7500.00
0005435928218	4068	Economy	7500.00
0005435086990	24413	Economy	8200.00
0005435086923	24413	Economy	7500.00
0005435928265	24413	Economy	7500.00
0005435086989	24413	Economy	7500.00
0005435928269	24413	Economy	7500.00
0005435086957	24413	Economy	7500.00
0005435928267	24413	Economy	7500.00
0005435086954	24413	Economy	7500.00
0005435086978	24413	Economy	7500.00
0005435928266	24413	Economy	7500.00
0005435086977	24413	Economy	7500.00
0005435928268	24413	Economy	7500.00
0005435086955	24413	Economy	7500.00
0005435086922	24413	Economy	7500.00
0005435098605	17008	Business	144300.00
0005435098610	17008	Business	144300.00
0005435098606	17008	Business	144300.00
0005435551743	17008	Business	144300.00
0005435551736	17008	Business	144300.00
0005435551739	17008	Economy	48100.00
0005435098609	17008	Economy	48100.00
0005435654508	17008	Economy	48100.00
0005435551726	17008	Economy	48100.00
0005435551734	17008	Economy	48100.00
0005435551731	17008	Economy	48100.00
0005435551744	17008	Economy	48100.00
0005435551735	17008	Economy	48100.00
0005435098608	17008	Economy	48100.00
0005435551738	17008	Economy	48100.00
0005435654506	17008	Economy	48100.00
0005435551745	17008	Economy	48100.00
0005435551728	17008	Economy	48100.00
0005435551725	17008	Economy	48100.00
0005435098611	17008	Economy	48100.00
0005435098607	17008	Economy	48100.00
0005435654511	17008	Economy	48100.00
0005435551729	17008	Economy	52900.00
0005435551747	17008	Economy	48100.00
0005435551748	17008	Economy	48100.00
0005435654510	17008	Economy	48100.00
0005435551742	17008	Economy	48100.00
0005435551737	17008	Economy	48100.00
0005435551740	17008	Economy	48100.00
0005435551732	17008	Economy	48100.00
0005435654505	17008	Economy	48100.00
0005435654507	17008	Economy	48100.00
0005435551730	17008	Economy	48100.00
0005435654509	17008	Economy	48100.00
0005435551733	17008	Economy	48100.00
0005435654504	17008	Economy	48100.00
0005435551727	17008	Economy	48100.00
0005435551741	17008	Economy	48100.00
0005435551746	17008	Economy	48100.00
0005434626208	4864	Business	44200.00
0005434626207	4864	Business	44200.00
0005434626204	4864	Business	44200.00
0005435907581	4864	Business	44200.00
0005435907594	4864	Economy	14700.00
0005434626203	4864	Economy	14700.00
0005434626202	4864	Economy	14700.00
0005435907591	4864	Economy	14700.00
0005434626210	4864	Economy	14700.00
0005434626205	4864	Economy	14700.00
0005434626206	4864	Economy	14700.00
0005435907590	4864	Economy	14700.00
0005434626209	4864	Economy	14700.00
0005433194939	32878	Business	44200.00
0005434626161	32878	Business	44200.00
0005433194946	32878	Business	44200.00
0005433194929	32878	Business	44200.00
0005433194933	32878	Business	44200.00
0005434626109	32878	Business	44200.00
0005433194930	32878	Economy	14700.00
0005433194931	32878	Economy	14700.00
0005435907632	32878	Economy	14700.00
0005435907634	32878	Economy	14700.00
0005433194935	32878	Economy	14700.00
0005433194943	32878	Economy	14700.00
0005433194934	32878	Economy	14700.00
0005433194938	32878	Economy	14700.00
0005434626101	32878	Economy	14700.00
0005434626163	32878	Economy	14700.00
0005433194941	32878	Economy	14700.00
0005433194936	32878	Economy	14700.00
0005434626168	32878	Economy	14700.00
0005435907633	32878	Economy	14700.00
0005433194945	32878	Economy	14700.00
0005435907635	32878	Economy	14700.00
0005435907637	32878	Economy	14700.00
0005433194942	32878	Economy	14700.00
0005433194940	32878	Economy	14700.00
0005433194937	32878	Economy	14700.00
0005434626162	32878	Economy	14700.00
0005434626142	32878	Economy	14700.00
0005434626143	32878	Economy	14700.00
0005433194944	32878	Economy	14700.00
0005434626118	32878	Economy	14700.00
0005433194932	32878	Economy	14700.00
0005435907636	32878	Economy	14700.00
0005435785904	13758	Economy	3400.00
0005435785943	13758	Economy	3400.00
0005435785833	13758	Economy	3400.00
0005435785846	13758	Economy	3400.00
0005435785730	13758	Economy	3100.00
0005435785895	13758	Economy	3100.00
0005435785821	13758	Economy	3100.00
0005435785808	13758	Economy	3100.00
0005435785718	13758	Economy	3100.00
0005435785834	13758	Economy	3100.00
0005435785770	13758	Economy	3100.00
0005435785905	13758	Economy	3100.00
0005435785818	13758	Economy	3100.00
0005435785881	13758	Economy	3100.00
0005435785987	13758	Economy	3100.00
0005435785837	13758	Economy	3100.00
0005435785991	13758	Economy	3100.00
0005435785882	13758	Economy	3100.00
0005435786072	13758	Economy	3100.00
0005435785961	13758	Economy	3100.00
0005435785819	13758	Economy	3100.00
0005432195749	13758	Economy	3100.00
0005435785719	13758	Economy	3100.00
0005435785946	13758	Economy	3100.00
0005435785944	13758	Economy	3100.00
0005435785982	13758	Economy	3100.00
0005435785917	13758	Economy	3100.00
0005435786020	13758	Economy	3100.00
0005435785906	13758	Economy	3100.00
0005435785901	13758	Economy	3100.00
0005435785945	13758	Economy	3100.00
0005435785920	13758	Economy	3100.00
0005435785911	13758	Economy	3100.00
0005435785988	13758	Economy	3100.00
0005435785769	13758	Economy	3100.00
0005435785889	13758	Economy	3100.00
0005435785887	13758	Economy	3100.00
0005435785723	13758	Economy	3100.00
0005435785888	13758	Economy	3100.00
0005435785960	13758	Economy	3100.00
0005435785912	13758	Economy	3100.00
0005435785894	13758	Economy	3100.00
0005432195750	13758	Economy	3100.00
0005435785832	13758	Economy	3100.00
0005435785729	13758	Economy	3100.00
0005435785893	13758	Economy	3100.00
0005435785820	13758	Economy	3100.00
0005435785880	13758	Economy	3100.00
0005435785962	13758	Economy	3100.00
0005435785902	13758	Economy	3100.00
0005435787406	27433	Economy	3400.00
0005435787404	27433	Economy	3400.00
0005435786200	27433	Economy	3400.00
0005432190724	27433	Economy	3100.00
0005435786208	27433	Economy	3100.00
0005432190723	27433	Economy	3100.00
0005435786199	27433	Economy	3100.00
0005435786185	27433	Economy	3100.00
0005435786192	27433	Economy	3100.00
0005435786215	27433	Economy	3100.00
0005435786189	27433	Economy	3100.00
0005435786186	27433	Economy	3100.00
0005435786213	27433	Economy	3100.00
0005435786187	27433	Economy	3100.00
0005435786206	27433	Economy	3100.00
0005435786203	27433	Economy	3100.00
0005435786216	27433	Economy	3100.00
0005435786183	27433	Economy	3100.00
0005435786188	27433	Economy	3100.00
0005435786211	27433	Economy	3100.00
0005435937433	27433	Economy	3100.00
0005435786202	27433	Economy	3100.00
0005435786193	27433	Economy	3100.00
0005435786205	27433	Economy	3100.00
0005435786182	27433	Economy	3100.00
0005435786201	27433	Economy	3100.00
0005435786207	27433	Economy	3100.00
0005435786184	27433	Economy	3100.00
0005435786217	27433	Economy	3100.00
0005435786197	27433	Economy	3100.00
0005435937439	27433	Economy	3100.00
0005435786204	27433	Economy	3100.00
0005435937438	27433	Economy	3100.00
0005435786196	27433	Economy	3100.00
0005435786191	27433	Economy	3100.00
0005435786194	27433	Economy	3100.00
0005432190722	27433	Economy	3100.00
0005435786195	27433	Economy	3100.00
0005435787405	27433	Economy	3100.00
0005435786212	27433	Economy	3100.00
0005435786209	27433	Economy	3100.00
0005435786210	27433	Economy	3100.00
0005435786198	27433	Economy	3100.00
0005435786190	27433	Economy	3100.00
0005435786214	27433	Economy	3100.00
0005434408965	20275	Business	12000.00
0005434408657	20275	Business	12000.00
0005435311454	20275	Business	12000.00
0005434408879	20275	Business	12000.00
0005434408620	20275	Business	12000.00
0005435311460	20275	Business	12000.00
0005435311461	20275	Business	12000.00
0005435311466	20275	Business	12000.00
0005434408791	20275	Business	12000.00
0005434409087	20275	Business	12000.00
0005434408788	20275	Business	12000.00
0005434408897	20275	Economy	4000.00
0005435311462	20275	Economy	4000.00
0005434409098	20275	Economy	4000.00
0005434409025	20275	Economy	4000.00
0005435311463	20275	Economy	4000.00
0005432058483	20275	Economy	4000.00
0005434408944	20275	Economy	4000.00
0005434408512	20275	Economy	4000.00
0005435311464	20275	Economy	4000.00
0005434408787	20275	Economy	4000.00
0005434408784	20275	Economy	4400.00
0005435311451	20275	Economy	4400.00
0005434408795	20275	Economy	4400.00
0005434408783	20275	Economy	4400.00
0005435311449	20275	Economy	4400.00
0005432058485	20275	Economy	4000.00
0005432058482	20275	Economy	4000.00
0005434408968	20275	Economy	4000.00
0005434408798	20275	Economy	4000.00
0005434408714	20275	Economy	4000.00
0005432058484	20275	Economy	4000.00
0005434408590	20275	Economy	4000.00
0005434408909	20275	Economy	4000.00
0005435311452	20275	Economy	4000.00
0005435311450	20275	Economy	4000.00
0005435311447	20275	Economy	4000.00
0005434408764	20275	Economy	4000.00
0005434408987	20275	Economy	4000.00
0005434409016	20275	Economy	4000.00
0005435311446	20275	Economy	4000.00
0005432058486	20275	Economy	4000.00
0005434409015	20275	Economy	4000.00
0005434408782	20275	Economy	4000.00
0005435311453	20275	Economy	4000.00
0005434408767	20275	Economy	4000.00
0005434409088	20275	Economy	4000.00
0005434408831	20275	Economy	4000.00
0005434408766	20275	Economy	4000.00
0005434409099	20275	Economy	4000.00
0005434408763	20275	Economy	4000.00
0005435311455	20275	Economy	4000.00
0005434409196	20275	Economy	4000.00
0005434408891	20275	Economy	4000.00
0005434408797	20275	Economy	4000.00
0005435311457	20275	Economy	4000.00
0005435311459	20275	Economy	4000.00
0005434408739	20275	Economy	4000.00
0005435311448	20275	Economy	4000.00
0005435311458	20275	Economy	4000.00
0005434408981	20275	Economy	4000.00
0005434408888	20275	Economy	4000.00
0005434408969	20275	Economy	4000.00
0005434408681	20275	Economy	4000.00
0005434408841	20275	Economy	4000.00
0005435311445	20275	Economy	4000.00
0005435311465	20275	Economy	4000.00
0005434409097	20275	Economy	4000.00
0005434408814	20275	Economy	4000.00
0005434408838	20275	Economy	4000.00
0005434408822	20275	Economy	4000.00
0005434408719	20275	Economy	4000.00
0005434408821	20275	Economy	4000.00
0005434408453	20275	Economy	4000.00
0005435311456	20275	Economy	4000.00
0005434408931	20275	Economy	4000.00
0005434408685	20275	Economy	4000.00
0005434408777	20275	Economy	4000.00
0005434409193	20275	Economy	4000.00
0005434408810	20275	Economy	4000.00
0005434408680	20275	Economy	4000.00
0005432058487	20275	Economy	4000.00
0005434408887	20275	Economy	4000.00
0005434409192	20275	Economy	4000.00
0005434408619	20275	Economy	4000.00
0005434409355	26997	Business	12000.00
0005432154118	26997	Business	12000.00
0005434409347	26997	Business	12000.00
0005434409404	26997	Business	12000.00
0005435311258	26997	Business	12000.00
0005434409401	26997	Business	12000.00
0005434409361	26997	Business	12000.00
0005434409343	26997	Business	12000.00
0005434409350	26997	Business	12000.00
0005434409383	26997	Business	12000.00
0005434409382	26997	Business	12000.00
0005434409391	26997	Business	12000.00
0005434409399	26997	Economy	4000.00
0005432154115	26997	Economy	4000.00
0005435311242	26997	Economy	4000.00
0005434409375	26997	Economy	4000.00
0005434409388	26997	Economy	4000.00
0005434409377	26997	Economy	4000.00
0005434409384	26997	Economy	4000.00
0005434409365	26997	Economy	4000.00
0005434409358	26997	Economy	4000.00
0005435311238	26997	Economy	4400.00
0005434409352	26997	Economy	4400.00
0005435311271	26997	Economy	4400.00
0005435311257	26997	Economy	4400.00
0005434409344	26997	Economy	4400.00
0005434409392	26997	Economy	4000.00
0005434409395	26997	Economy	4000.00
0005435311259	26997	Economy	4000.00
0005434409397	26997	Economy	4000.00
0005432154120	26997	Economy	4000.00
0005434409357	26997	Economy	4000.00
0005434409379	26997	Economy	4000.00
0005432154122	26997	Economy	4000.00
0005432154116	26997	Economy	4000.00
0005434409370	26997	Economy	4000.00
0005434409345	26997	Economy	4000.00
0005434409374	26997	Economy	4000.00
0005434409372	26997	Economy	4000.00
0005432154117	26997	Economy	4000.00
0005434409387	26997	Economy	4000.00
0005434409386	26997	Economy	4000.00
0005434409369	26997	Economy	4000.00
0005434409394	26997	Economy	4000.00
0005434409400	26997	Economy	4000.00
0005434409396	26997	Economy	4000.00
0005434409356	26997	Economy	4000.00
0005434409346	26997	Economy	4000.00
0005434409398	26997	Economy	4000.00
0005434409371	26997	Economy	4000.00
0005434409381	26997	Economy	4000.00
0005434409359	26997	Economy	4000.00
0005434409368	26997	Economy	4000.00
0005434409351	26997	Economy	4000.00
0005434409378	26997	Economy	4000.00
0005435311239	26997	Economy	4000.00
0005434409380	26997	Economy	4000.00
0005432154121	26997	Economy	4000.00
0005434409390	26997	Economy	4000.00
0005434409376	26997	Economy	4000.00
0005434409402	26997	Economy	4000.00
0005432154119	26997	Economy	4000.00
0005434409389	26997	Economy	4000.00
0005435311237	26997	Economy	4000.00
0005434409367	26997	Economy	4000.00
0005434409363	26997	Economy	4000.00
0005434409403	26997	Economy	4000.00
0005434409373	26997	Economy	4000.00
0005434409385	26997	Economy	4000.00
0005434409353	26997	Economy	4000.00
0005434409364	26997	Economy	4000.00
0005435311289	26997	Economy	4000.00
0005435311221	26997	Economy	4000.00
0005434409348	26997	Economy	4000.00
0005434409360	26997	Economy	4000.00
0005435311200	26997	Economy	4000.00
0005435311201	26997	Economy	4000.00
0005434409362	26997	Economy	4000.00
0005435311213	26997	Economy	4000.00
0005435311245	26997	Economy	4000.00
0005434409366	26997	Economy	4000.00
0005434409349	26997	Economy	4000.00
0005434409393	26997	Economy	4000.00
0005434409354	26997	Economy	4000.00
0005433124246	5687	Business	43300.00
0005434319766	5687	Business	43300.00
0005434319764	5687	Business	43300.00
0005433124334	5687	Business	43300.00
0005433124236	5687	Business	43300.00
0005434311286	5687	Business	43300.00
0005434319760	5687	Economy	14400.00
0005433124363	5687	Economy	14400.00
0005434319770	5687	Economy	14400.00
0005433124265	5687	Economy	14400.00
0005434319752	5687	Economy	14400.00
0005434319750	5687	Economy	15900.00
0005432109774	5687	Economy	15900.00
0005434319758	5687	Economy	15900.00
0005432109775	5687	Economy	15900.00
0005434319755	5687	Economy	14400.00
0005433124181	5687	Economy	14400.00
0005434319771	5687	Economy	14400.00
0005433124250	5687	Economy	14400.00
0005434319763	5687	Economy	14400.00
0005434319757	5687	Economy	14400.00
0005434311287	5687	Economy	14400.00
0005433124309	5687	Economy	14400.00
0005434319751	5687	Economy	14400.00
0005433124264	5687	Economy	14400.00
0005433124268	5687	Economy	14400.00
0005434311271	5687	Economy	14400.00
0005433124325	5687	Economy	14400.00
0005434319765	5687	Economy	14400.00
0005434319759	5687	Economy	14400.00
0005433124364	5687	Economy	14400.00
0005433124235	5687	Economy	14400.00
0005433124298	5687	Economy	14400.00
0005433124239	5687	Economy	14400.00
0005433124288	5687	Economy	14400.00
0005433124283	5687	Economy	14400.00
0005433124269	5687	Economy	14400.00
0005434319753	5687	Economy	14400.00
0005432109773	5687	Economy	14400.00
0005434319769	5687	Economy	14400.00
0005434319754	5687	Economy	14400.00
0005434319761	5687	Economy	14400.00
0005434319762	5687	Economy	14400.00
0005433124326	5687	Economy	14400.00
0005434319756	5687	Economy	14400.00
0005433124284	5687	Economy	14400.00
0005434319767	5687	Economy	14400.00
0005433124252	5687	Economy	14400.00
0005433124357	5687	Economy	14400.00
0005434319768	5687	Economy	14400.00
0005433124275	5687	Economy	14400.00
0005433124452	15688	Business	43300.00
0005433124459	15688	Business	43300.00
0005433124446	15688	Business	43300.00
0005433124457	15688	Business	43300.00
0005434319620	15688	Business	43300.00
0005434312352	15688	Economy	14400.00
0005433124456	15688	Economy	14400.00
0005433124458	15688	Economy	14400.00
0005433124463	15688	Economy	14400.00
0005433124451	15688	Economy	14400.00
0005433124464	15688	Economy	14400.00
0005433124445	15688	Economy	14400.00
0005434312353	15688	Economy	14400.00
0005434312346	15688	Economy	14400.00
0005434319619	15688	Economy	14400.00
0005433124453	15688	Economy	14400.00
0005433124448	15688	Economy	14400.00
0005434312347	15688	Economy	14400.00
0005433124449	15688	Economy	14400.00
0005434319617	15688	Economy	14400.00
0005433124447	15688	Economy	14400.00
0005433124461	15688	Economy	14400.00
0005433124462	15688	Economy	14400.00
0005433124454	15688	Economy	14400.00
0005433124465	15688	Economy	14400.00
0005433124450	15688	Economy	14400.00
0005433124455	15688	Economy	14400.00
0005434311260	15688	Economy	14400.00
0005433124460	15688	Economy	14400.00
0005433124466	15688	Economy	14400.00
0005434319618	15688	Economy	14400.00
0005433124444	15688	Economy	14400.00
0005435220373	31747	Economy	17100.00
0005435219256	31747	Economy	15500.00
0005435219252	31747	Economy	15500.00
0005435220513	31747	Economy	15500.00
0005435220516	31747	Economy	15500.00
0005435219251	31747	Economy	15500.00
0005435219254	31747	Economy	15500.00
0005435220371	31747	Economy	15500.00
0005435220514	31747	Economy	15500.00
0005435220515	31747	Economy	15500.00
0005435220372	31747	Economy	15500.00
0005435220370	31747	Economy	15500.00
0005435219255	31747	Economy	15500.00
0005435220375	31747	Economy	15500.00
0005435219253	31747	Economy	15500.00
0005435220374	31747	Economy	15500.00
0005434189309	8984	Economy	24900.00
0005434189291	8984	Economy	24900.00
0005434484518	8984	Economy	24900.00
0005434189308	8984	Economy	24900.00
0005434484517	8984	Economy	24900.00
0005434189279	8984	Economy	24900.00
0005434189247	8984	Economy	24900.00
0005434484519	8984	Economy	24900.00
0005434189266	8984	Economy	24900.00
0005434484515	8984	Economy	24900.00
0005434484516	8984	Economy	24900.00
0005434484520	8984	Economy	24900.00
0005434189290	8984	Economy	24900.00
0005434189328	16645	Economy	24900.00
0005434484440	16645	Economy	24900.00
0005434484447	16645	Economy	24900.00
0005434189325	16645	Economy	24900.00
0005434189326	16645	Economy	24900.00
0005434189324	16645	Economy	24900.00
0005434484487	16645	Economy	24900.00
0005434189323	16645	Economy	24900.00
0005434484469	16645	Economy	24900.00
0005434189327	16645	Economy	24900.00
0005434484441	16645	Economy	24900.00
0005434189329	16645	Economy	24900.00
0005434484463	16645	Economy	24900.00
0005434484444	16645	Economy	24900.00
0005434484446	16645	Economy	24900.00
0005434484467	16645	Economy	24900.00
0005434484445	16645	Economy	24900.00
0005434484468	16645	Economy	24900.00
0005433124459	7538	Business	11100.00
0005433124454	7538	Business	11100.00
0005433124463	7538	Business	11100.00
0005433124461	7538	Business	11100.00
0005433124465	7538	Business	11100.00
0005433124460	7538	Economy	3700.00
0005433722311	7538	Economy	3700.00
0005433722329	7538	Economy	3700.00
0005433722314	7538	Economy	3700.00
0005433124448	7538	Economy	4100.00
0005433722325	7538	Economy	4100.00
0005433124444	7538	Economy	3700.00
0005433124458	7538	Economy	3700.00
0005433124462	7538	Economy	3700.00
0005433722328	7538	Economy	3700.00
0005433124450	7538	Economy	3700.00
0005433124445	7538	Economy	3700.00
0005433722315	7538	Economy	3700.00
0005433124456	7538	Economy	3700.00
0005433124451	7538	Economy	3700.00
0005433124447	7538	Economy	3700.00
0005433124453	7538	Economy	3700.00
0005433722313	7538	Economy	3700.00
0005433124449	7538	Economy	3700.00
0005433124466	7538	Economy	3700.00
0005433124457	7538	Economy	3700.00
0005433124452	7538	Economy	3700.00
0005433722327	7538	Economy	3700.00
0005433722310	7538	Economy	3700.00
0005433124464	7538	Economy	3700.00
0005433124455	7538	Economy	3700.00
0005433124446	7538	Economy	3700.00
0005433450530	7537	Business	11100.00
0005432721587	7537	Business	11100.00
0005433450528	7537	Business	11100.00
0005432693870	7537	Business	11100.00
0005432693864	7537	Business	11100.00
0005432693848	7537	Business	11100.00
0005433450537	7537	Business	11100.00
0005432721595	7537	Business	11100.00
0005432721585	7537	Business	11100.00
0005432721605	7537	Business	11100.00
0005432721604	7537	Economy	3700.00
0005432721601	7537	Economy	3700.00
0005433450534	7537	Economy	3700.00
0005432693859	7537	Economy	3700.00
0005433450538	7537	Economy	3700.00
0005432693875	7537	Economy	3700.00
0005432693851	7537	Economy	3700.00
0005432721586	7537	Economy	3700.00
0005432693867	7537	Economy	3700.00
0005433450522	7537	Economy	4100.00
0005432721597	7537	Economy	4100.00
0005432721584	7537	Economy	4100.00
0005432721592	7537	Economy	3700.00
0005432071649	7537	Economy	3700.00
0005433450536	7537	Economy	3700.00
0005432693872	7537	Economy	3700.00
0005432693871	7537	Economy	3700.00
0005432721589	7537	Economy	3700.00
0005432721598	7537	Economy	3700.00
0005432721608	7537	Economy	3700.00
0005433450521	7537	Economy	3700.00
0005432693855	7537	Economy	3700.00
0005433450539	7537	Economy	3700.00
0005432721596	7537	Economy	3700.00
0005433450529	7537	Economy	3700.00
0005432693857	7537	Economy	3700.00
0005432693860	7537	Economy	3700.00
0005432693863	7537	Economy	3700.00
0005433450526	7537	Economy	3700.00
0005432693849	7537	Economy	3700.00
0005432721599	7537	Economy	3700.00
0005432721600	7537	Economy	3700.00
0005433450527	7537	Economy	3700.00
0005433450535	7537	Economy	3700.00
0005432693865	7537	Economy	3700.00
0005433450533	7537	Economy	3700.00
0005433450525	7537	Economy	3700.00
0005433450520	7537	Economy	3700.00
0005432693869	7537	Economy	3700.00
0005432693850	7537	Economy	3700.00
0005432693866	7537	Economy	3700.00
0005433450531	7537	Economy	3700.00
0005432721594	7537	Economy	3700.00
0005432693862	7537	Economy	3700.00
0005433450532	7537	Economy	3700.00
0005432721583	7537	Economy	3700.00
0005432693856	7537	Economy	3700.00
0005432721606	7537	Economy	3700.00
0005432721593	7537	Economy	3700.00
0005433450519	7537	Economy	3700.00
0005432721588	7537	Economy	3700.00
0005432693874	7537	Economy	3700.00
0005433450524	7537	Economy	3700.00
0005432721602	7537	Economy	3700.00
0005432693868	7537	Economy	3700.00
0005432721603	7537	Economy	3700.00
0005432693858	7537	Economy	3700.00
0005432693853	7537	Economy	3700.00
0005433450523	7537	Economy	3700.00
0005432693854	7537	Economy	3700.00
0005432721590	7537	Economy	3700.00
0005432721607	7537	Economy	3700.00
0005432721591	7537	Economy	3700.00
0005432693852	7537	Economy	3700.00
0005432693873	7537	Economy	3700.00
0005432071650	7537	Economy	3700.00
0005432693861	7537	Economy	3700.00
0005432071651	7537	Economy	3700.00
0005433450349	30420	Business	11100.00
0005433450404	30420	Business	11100.00
0005433450339	30420	Business	11100.00
0005432693449	30420	Business	11100.00
0005433450380	30420	Business	11100.00
0005432693729	30420	Business	11100.00
0005432693488	30420	Economy	3700.00
0005433450321	30420	Economy	3700.00
0005432693493	30420	Economy	3700.00
0005433450403	30420	Economy	3700.00
0005432693630	30420	Economy	3700.00
0005432693569	30420	Economy	3700.00
0005433450239	30420	Economy	4100.00
0005433450307	30420	Economy	4100.00
0005433450323	30420	Economy	3700.00
0005432693580	30420	Economy	3700.00
0005433450369	30420	Economy	3700.00
0005432693400	30420	Economy	3700.00
0005433450392	30420	Economy	3700.00
0005432693529	30420	Economy	3700.00
0005433450290	30420	Economy	3700.00
0005432693730	30420	Economy	3700.00
0005432693603	30420	Economy	3700.00
0005432693629	30420	Economy	3700.00
0005433450351	30420	Economy	3700.00
0005432693740	30420	Economy	3700.00
0005433450320	30420	Economy	3700.00
0005433450350	30420	Economy	3700.00
0005432693612	30420	Economy	3700.00
0005432693581	30420	Economy	3700.00
0005432693739	30420	Economy	3700.00
0005432693447	30420	Economy	3700.00
0005432693645	30420	Economy	3700.00
0005432693515	30420	Economy	3700.00
0005433450298	30420	Economy	3700.00
0005432693611	30420	Economy	3700.00
0005433450402	30420	Economy	3700.00
0005432693665	30420	Economy	3700.00
0005433450372	30420	Economy	3700.00
0005433450373	30420	Economy	3700.00
0005433450331	30420	Economy	3700.00
0005432693492	30420	Economy	3700.00
0005432693600	30420	Economy	3700.00
0005432693604	30420	Economy	3700.00
0005432693471	30420	Economy	3700.00
0005433450324	30420	Economy	3700.00
0005433450332	30420	Economy	3700.00
0005433450326	30420	Economy	3700.00
0005433450297	30420	Economy	3700.00
0005432693472	30420	Economy	3700.00
0005433450217	30420	Economy	3700.00
0005432693448	30420	Economy	3700.00
0005433450216	30420	Economy	3700.00
0005433450400	30420	Economy	3700.00
0005433450387	30420	Economy	3700.00
0005432693504	30420	Economy	3700.00
0005433450325	30420	Economy	3700.00
0005433450401	30420	Economy	3700.00
0005432693587	30420	Economy	3700.00
0005432693487	30420	Economy	3700.00
0005433124246	30419	Business	11100.00
0005433722408	30419	Business	11100.00
0005433722406	30419	Business	11100.00
0005433124236	30419	Business	11100.00
0005432721405	30419	Business	11100.00
0005432721408	30419	Business	11100.00
0005432721329	30419	Business	11100.00
0005432721366	30419	Business	11100.00
0005433124325	30419	Business	11100.00
0005433722409	30419	Business	11100.00
0005432721486	30419	Business	11100.00
0005432721363	30419	Business	11100.00
0005432721466	30419	Economy	3700.00
0005433124288	30419	Economy	3700.00
0005433722394	30419	Economy	3700.00
0005433722403	30419	Economy	3700.00
0005433124250	30419	Economy	3700.00
0005433124239	30419	Economy	3700.00
0005433124309	30419	Economy	3700.00
0005432721380	30419	Economy	3700.00
0005432721426	30419	Economy	4100.00
0005433722395	30419	Economy	4100.00
0005433124268	30419	Economy	4100.00
0005432721412	30419	Economy	3700.00
0005433124284	30419	Economy	3700.00
0005432721411	30419	Economy	3700.00
0005433722402	30419	Economy	3700.00
0005432721365	30419	Economy	3700.00
0005433124275	30419	Economy	3700.00
0005433124326	30419	Economy	3700.00
0005432721384	30419	Economy	3700.00
0005433722398	30419	Economy	3700.00
0005433124265	30419	Economy	3700.00
0005432721376	30419	Economy	3700.00
0005432721349	30419	Economy	3700.00
0005433124235	30419	Economy	3700.00
0005432721338	30419	Economy	3700.00
0005433722396	30419	Economy	3700.00
0005433722397	30419	Economy	3700.00
0005433124334	30419	Economy	3700.00
0005433722392	30419	Economy	3700.00
0005433722393	30419	Economy	3700.00
0005432721387	30419	Economy	3700.00
0005432721330	30419	Economy	3700.00
0005433124181	30419	Economy	3700.00
0005432721375	30419	Economy	3700.00
0005433722391	30419	Economy	3700.00
0005433124283	30419	Economy	3700.00
0005432721407	30419	Economy	3700.00
0005433722399	30419	Economy	3700.00
0005433124252	30419	Economy	3700.00
0005432721433	30419	Economy	3700.00
0005432721399	30419	Economy	3700.00
0005432721413	30419	Economy	3700.00
0005433722407	30419	Economy	3700.00
0005433124264	30419	Economy	3700.00
0005433124298	30419	Economy	3700.00
0005433722400	30419	Economy	3700.00
0005433722405	30419	Economy	3700.00
0005433124269	30419	Economy	3700.00
0005433124363	30419	Economy	3700.00
0005433124357	30419	Economy	3700.00
0005432721432	30419	Economy	3700.00
0005432721364	30419	Economy	3700.00
0005432721379	30419	Economy	3700.00
0005433124364	30419	Economy	3700.00
0005433722401	30419	Economy	3700.00
0005433722404	30419	Economy	3700.00
0005432721406	30419	Economy	3700.00
0005434587276	1382	Business	70400.00
0005434587270	1382	Business	70400.00
0005433525323	1382	Business	70400.00
0005433193320	1382	Business	70400.00
0005432928089	1382	Business	70400.00
0005434587277	1382	Business	70400.00
0005433525322	1382	Business	70400.00
0005433525320	1382	Business	70400.00
0005434587282	1382	Business	70400.00
0005433724924	1382	Economy	23500.00
0005433525325	1382	Economy	23500.00
0005432928070	1382	Economy	23500.00
0005433193321	1382	Economy	25800.00
0005434587275	1382	Economy	25800.00
0005434587263	1382	Economy	23500.00
0005434587274	1382	Economy	23500.00
0005434587261	1382	Economy	23500.00
0005433525319	1382	Economy	23500.00
0005433193249	1382	Economy	23500.00
0005433525317	1382	Economy	23500.00
0005434515036	1382	Economy	23500.00
0005434513648	1382	Economy	23500.00
0005434587273	1382	Economy	23500.00
0005434587281	1382	Economy	23500.00
0005433525324	1382	Economy	23500.00
0005433525318	1382	Economy	23500.00
0005433193311	1382	Economy	23500.00
0005434587260	1382	Economy	23500.00
0005434587262	1382	Economy	23500.00
0005432271077	1382	Economy	23500.00
0005434587269	1382	Economy	23500.00
0005432928100	1382	Economy	23500.00
0005433724923	1382	Economy	23500.00
0005433193267	1382	Economy	23500.00
0005433525321	1382	Economy	23500.00
0005433193248	1382	Economy	23500.00
0005434587272	1382	Economy	23500.00
0005433193257	1382	Economy	23500.00
0005434513647	1382	Economy	23500.00
0005434587271	1382	Economy	23500.00
0005433193338	1382	Economy	23500.00
0005433193327	1382	Economy	23500.00
0005434587283	1382	Economy	23500.00
0005434587268	1382	Economy	23500.00
0005432928090	1382	Economy	23500.00
0005434587265	1382	Economy	23500.00
0005434587279	1382	Economy	23500.00
0005434587264	1382	Economy	23500.00
0005434587259	1382	Economy	23500.00
0005434587267	1382	Economy	23500.00
0005433525315	1382	Economy	23500.00
0005433525316	1382	Economy	23500.00
0005434513646	1382	Economy	23500.00
0005434587266	1382	Economy	23500.00
0005434513649	1382	Economy	23500.00
0005434587280	1382	Economy	23500.00
0005434587278	1382	Economy	23500.00
0005432928088	1382	Economy	23500.00
0005433525255	18508	Business	70400.00
0005433525155	18508	Business	70400.00
0005434587062	18508	Business	70400.00
0005434515009	18508	Business	70400.00
0005433525208	18508	Business	70400.00
0005433193388	18508	Business	70400.00
0005433525216	18508	Business	70400.00
0005433193385	18508	Business	70400.00
0005433724861	18508	Business	70400.00
0005434587002	18508	Business	70400.00
0005433724894	18508	Economy	23500.00
0005434587095	18508	Economy	23500.00
0005434587082	18508	Economy	23500.00
0005433525165	18508	Economy	23500.00
0005434515010	18508	Economy	23500.00
0005433525219	18508	Economy	23500.00
0005433193382	18508	Economy	23500.00
0005434587088	18508	Economy	25800.00
0005434587069	18508	Economy	25800.00
0005433193392	18508	Economy	25800.00
0005433525201	18508	Economy	25800.00
0005433525254	18508	Economy	25800.00
0005433193384	18508	Economy	23500.00
0005433724882	18508	Economy	23500.00
0005433525157	18508	Economy	23500.00
0005434587120	18508	Economy	23500.00
0005432928123	18508	Economy	23500.00
0005434587112	18508	Economy	23500.00
0005432928126	18508	Economy	23500.00
0005434587065	18508	Economy	23500.00
0005432968899	18508	Economy	23500.00
0005433525202	18508	Economy	23500.00
0005434587107	18508	Economy	23500.00
0005432968898	18508	Economy	23500.00
0005433525217	18508	Economy	23500.00
0005433724862	18508	Economy	23500.00
0005432928122	18508	Economy	23500.00
0005434587113	18508	Economy	23500.00
0005433525220	18508	Economy	23500.00
0005433193390	18508	Economy	23500.00
0005433525164	18508	Economy	23500.00
0005433525200	18508	Economy	23500.00
0005433193383	18508	Economy	23500.00
0005433193394	18508	Economy	23500.00
0005432928124	18508	Economy	23500.00
0005434587063	18508	Economy	23500.00
0005433724881	18508	Economy	23500.00
0005434587026	18508	Economy	23500.00
0005434587090	18508	Economy	23500.00
0005434587099	18508	Economy	23500.00
0005433525156	18508	Economy	23500.00
0005434587068	18508	Economy	23500.00
0005433193391	18508	Economy	23500.00
0005434587091	18508	Economy	23500.00
0005434587151	18508	Economy	23500.00
0005434587066	18508	Economy	23500.00
0005434587121	18508	Economy	23500.00
0005434587096	18508	Economy	23500.00
0005433193387	18508	Economy	23500.00
0005433724895	18508	Economy	23500.00
0005434587094	18508	Economy	23500.00
0005433193393	18508	Economy	23500.00
0005434515017	18508	Economy	23500.00
0005433525218	18508	Economy	23500.00
0005434587092	18508	Economy	23500.00
0005434586920	18508	Economy	23500.00
0005433193389	18508	Economy	23500.00
0005434587150	18508	Economy	23500.00
0005433193395	18508	Economy	23500.00
0005434587056	18508	Economy	23500.00
0005434587044	18508	Economy	23500.00
0005434587114	18508	Economy	23500.00
0005433525224	18508	Economy	23500.00
0005432928125	18508	Economy	23500.00
0005433193386	18508	Economy	23500.00
0005434587101	18508	Economy	23500.00
0005434515020	18508	Economy	23500.00
0005434345112	11470	Economy	4300.00
0005435302289	11470	Economy	4300.00
0005434345114	11470	Economy	4300.00
0005434345083	11470	Economy	4300.00
0005434345111	11470	Economy	4000.00
0005434345103	11470	Economy	4000.00
0005434345108	11470	Economy	4000.00
0005434345097	11470	Economy	4000.00
0005435302269	11470	Economy	4000.00
0005434345104	11470	Economy	4000.00
0005435302287	11470	Economy	4000.00
0005434345091	11470	Economy	4000.00
0005434345102	11470	Economy	4000.00
0005434345105	11470	Economy	4000.00
0005434345109	11470	Economy	4000.00
0005434345088	11470	Economy	4000.00
0005434345085	11470	Economy	4000.00
0005434345095	11470	Economy	4000.00
0005434345096	11470	Economy	4000.00
0005434345107	11470	Economy	4000.00
0005434345110	11470	Economy	4000.00
0005434345101	11470	Economy	4000.00
0005434345084	11470	Economy	4000.00
0005435305041	11470	Economy	4000.00
0005434345090	11470	Economy	4000.00
0005434142714	11470	Economy	4000.00
0005434142713	11470	Economy	4000.00
0005434345080	11470	Economy	4000.00
0005435302256	11470	Economy	4000.00
0005434345092	11470	Economy	4000.00
0005434345081	11470	Economy	4000.00
0005434345099	11470	Economy	4000.00
0005434345113	11470	Economy	4000.00
0005434345106	11470	Economy	4000.00
0005435302270	11470	Economy	4000.00
0005434345093	11470	Economy	4000.00
0005434345087	11470	Economy	4000.00
0005435302286	11470	Economy	4000.00
0005435302257	11470	Economy	4000.00
0005434345086	11470	Economy	4000.00
0005434345094	11470	Economy	4000.00
0005434345082	11470	Economy	4000.00
0005434345089	11470	Economy	4000.00
0005434345100	11470	Economy	4000.00
0005434345098	11470	Economy	4000.00
0005434344903	29805	Economy	4300.00
0005435304259	29805	Economy	4300.00
0005434344650	29805	Economy	4300.00
0005434142682	29805	Economy	4000.00
0005435305066	29805	Economy	4000.00
0005434344787	29805	Economy	4000.00
0005434344824	29805	Economy	4000.00
0005435305065	29805	Economy	4000.00
0005434344715	29805	Economy	4000.00
0005434344733	29805	Economy	4000.00
0005435305063	29805	Economy	4000.00
0005435304258	29805	Economy	4000.00
0005434142681	29805	Economy	4000.00
0005434344734	29805	Economy	4000.00
0005434344916	29805	Economy	4000.00
0005434344539	29805	Economy	4000.00
0005434344833	29805	Economy	4000.00
0005434344714	29805	Economy	4000.00
0005435305067	29805	Economy	4000.00
0005434344838	29805	Economy	4000.00
0005435305064	29805	Economy	4000.00
0005435304262	29805	Economy	4000.00
0005435304261	29805	Economy	4000.00
0005434344748	29805	Economy	4000.00
0005434344657	29805	Economy	4000.00
0005434344917	29805	Economy	4000.00
0005434344918	29805	Economy	4000.00
0005434344834	29805	Economy	4000.00
0005434344698	29805	Economy	4000.00
0005434344697	29805	Economy	4000.00
0005434344729	29805	Economy	4000.00
0005434344788	29805	Economy	4000.00
0005434344633	29805	Economy	4000.00
0005434344849	29805	Economy	4000.00
0005434344735	29805	Economy	4000.00
0005434344749	29805	Economy	4000.00
0005434344730	29805	Economy	4000.00
0005434344850	29805	Economy	4000.00
0005434344711	29805	Economy	4000.00
0005435304260	29805	Economy	4000.00
0005433415877	1275	Business	199800.00
0005433415959	1275	Business	199800.00
0005435825306	1275	Business	199800.00
0005433415946	1275	Business	199800.00
0005433415919	1275	Business	199800.00
0005435825305	1275	Business	199800.00
0005435825310	1275	Economy	66600.00
0005435825322	1275	Economy	66600.00
0005435825324	1275	Economy	66600.00
0005433415979	1275	Economy	66600.00
0005433416039	1275	Economy	66600.00
0005433415962	1275	Economy	66600.00
0005435825320	1275	Economy	66600.00
0005435825309	1275	Economy	66600.00
0005433415974	1275	Economy	73200.00
0005432284635	1275	Economy	66600.00
0005435825316	1275	Economy	66600.00
0005435825314	1275	Economy	66600.00
0005432284634	1275	Economy	66600.00
0005435825318	1275	Economy	66600.00
0005435825317	1275	Economy	66600.00
0005435825304	1275	Economy	66600.00
0005433416038	1275	Economy	66600.00
0005435825311	1275	Economy	66600.00
0005435825327	1275	Economy	66600.00
0005433415920	1275	Economy	66600.00
0005435825308	1275	Economy	66600.00
0005435825312	1275	Economy	66600.00
0005435825326	1275	Economy	66600.00
0005435825328	1275	Economy	66600.00
0005433415939	1275	Economy	66600.00
0005433415879	1275	Economy	66600.00
0005435825325	1275	Economy	66600.00
0005432284636	1275	Economy	66600.00
0005433415961	1275	Economy	66600.00
0005435825319	1275	Economy	66600.00
0005433415947	1275	Economy	66600.00
0005435825313	1275	Economy	66600.00
0005435825315	1275	Economy	66600.00
0005435825321	1275	Economy	66600.00
0005435825307	1275	Economy	66600.00
0005433415878	1275	Economy	66600.00
0005432284633	1275	Economy	66600.00
0005433415880	1275	Economy	66600.00
0005435825323	1275	Economy	66600.00
0005435825123	17999	Business	199800.00
0005435825087	17999	Business	199800.00
0005435825135	17999	Business	199800.00
0005435825268	17999	Business	199800.00
0005435825068	17999	Business	199800.00
0005433416070	17999	Business	199800.00
0005433416065	17999	Business	199800.00
0005433416074	17999	Business	199800.00
0005435825049	17999	Business	199800.00
0005435825203	17999	Economy	66600.00
0005435824978	17999	Economy	66600.00
0005433416073	17999	Economy	66600.00
0005435825110	17999	Economy	66600.00
0005435825095	17999	Economy	66600.00
0005433416069	17999	Economy	66600.00
0005435825144	17999	Economy	73200.00
0005435825077	17999	Economy	66600.00
0005435825158	17999	Economy	66600.00
0005433416071	17999	Economy	66600.00
0005435825091	17999	Economy	66600.00
0005435825114	17999	Economy	66600.00
0005435825118	17999	Economy	66600.00
0005433416066	17999	Economy	66600.00
0005433416064	17999	Economy	66600.00
0005433416063	17999	Economy	66600.00
0005435825115	17999	Economy	66600.00
0005435825150	17999	Economy	66600.00
0005433416077	17999	Economy	66600.00
0005435825100	17999	Economy	66600.00
0005435825050	17999	Economy	66600.00
0005435824990	17999	Economy	66600.00
0005435825126	17999	Economy	66600.00
0005435825134	17999	Economy	66600.00
0005435825183	17999	Economy	66600.00
0005433416075	17999	Economy	66600.00
0005435825111	17999	Economy	66600.00
0005435825080	17999	Economy	66600.00
0005433416072	17999	Economy	66600.00
0005433416067	17999	Economy	66600.00
0005435825184	17999	Economy	66600.00
0005433416076	17999	Economy	66600.00
0005435825149	17999	Economy	66600.00
0005433416068	17999	Economy	66600.00
0005435825099	17999	Economy	66600.00
0005435825112	17999	Economy	66600.00
0005432785148	5629	Business	27800.00
0005432144072	5629	Business	27800.00
0005435476850	5629	Business	27800.00
0005435243271	5629	Business	27800.00
0005435476858	5629	Business	27800.00
0005435243240	5629	Business	27800.00
0005432785180	5629	Business	27800.00
0005432785176	5629	Business	27800.00
0005435243311	5629	Business	27800.00
0005435476879	5629	Business	27800.00
0005435243287	5629	Business	27800.00
0005432785177	5629	Economy	9300.00
0005432785159	5629	Economy	9300.00
0005435243218	5629	Economy	9300.00
0005432785184	5629	Economy	9300.00
0005435243307	5629	Economy	9300.00
0005432785192	5629	Economy	9300.00
0005432785186	5629	Economy	9300.00
0005432785167	5629	Economy	9300.00
0005432785172	5629	Economy	9300.00
0005432785151	5629	Economy	10200.00
0005435243346	5629	Economy	10200.00
0005432785161	5629	Economy	10200.00
0005432785156	5629	Economy	10200.00
0005435243270	5629	Economy	10200.00
0005432785178	5629	Economy	9300.00
0005432785153	5629	Economy	9300.00
0005432785158	5629	Economy	9300.00
0005435243250	5629	Economy	9300.00
0005435243241	5629	Economy	9300.00
0005435243242	5629	Economy	9300.00
0005432785174	5629	Economy	9300.00
0005432785175	5629	Economy	9300.00
0005435243217	5629	Economy	9300.00
0005435243263	5629	Economy	9300.00
0005432785182	5629	Economy	9300.00
0005432785169	5629	Economy	9300.00
0005435243305	5629	Economy	9300.00
0005435476869	5629	Economy	9300.00
0005432785152	5629	Economy	9300.00
0005432785157	5629	Economy	9300.00
0005435476883	5629	Economy	9300.00
0005432785155	5629	Economy	9300.00
0005435476870	5629	Economy	9300.00
0005432785164	5629	Economy	9300.00
0005432785191	5629	Economy	9300.00
0005432785154	5629	Economy	9300.00
0005432785179	5629	Economy	9300.00
0005432785173	5629	Economy	9300.00
0005435243304	5629	Economy	9300.00
0005435476885	5629	Economy	9300.00
0005435243254	5629	Economy	9300.00
0005435243206	5629	Economy	9300.00
0005432785181	5629	Economy	9300.00
0005432785163	5629	Economy	9300.00
0005432785187	5629	Economy	9300.00
0005432785162	5629	Economy	9300.00
0005435243310	5629	Economy	9300.00
0005432785149	5629	Economy	9300.00
0005432785165	5629	Economy	9300.00
0005432785171	5629	Economy	9300.00
0005435243352	5629	Economy	9300.00
0005432785193	5629	Economy	9300.00
0005435243269	5629	Economy	9300.00
0005435476851	5629	Economy	9300.00
0005432785183	5629	Economy	9300.00
0005435476880	5629	Economy	9300.00
0005435243251	5629	Economy	9300.00
0005435476886	5629	Economy	9300.00
0005435243262	5629	Economy	9300.00
0005432785168	5629	Economy	9300.00
0005432785150	5629	Economy	9300.00
0005432785188	5629	Economy	9300.00
0005432785170	5629	Economy	9300.00
0005432144070	5629	Economy	9300.00
0005435476852	5629	Economy	9300.00
0005435243219	5629	Economy	9300.00
0005432785190	5629	Economy	9300.00
0005435243231	5629	Economy	9300.00
0005435243339	5629	Economy	9300.00
0005432785189	5629	Economy	9300.00
0005432785195	5629	Economy	9300.00
0005435243351	5629	Economy	9300.00
0005435243259	5629	Economy	9300.00
0005432144071	5629	Economy	9300.00
0005432785166	5629	Economy	9300.00
0005432785160	5629	Economy	9300.00
0005432785185	5629	Economy	9300.00
0005435243249	5629	Economy	9300.00
0005432785194	5629	Economy	9300.00
0005432785147	5629	Economy	9300.00
0005435243530	15364	Business	27800.00
0005432784670	15364	Business	27800.00
0005435243526	15364	Business	27800.00
0005435626881	15364	Business	27800.00
0005435476960	15364	Business	27800.00
0005435476955	15364	Business	27800.00
0005435243528	15364	Business	27800.00
0005432784637	15364	Business	27800.00
0005432784867	15364	Business	27800.00
0005432784638	15364	Business	27800.00
0005432784735	15364	Business	27800.00
0005435476954	15364	Business	27800.00
0005435243515	15364	Economy	9300.00
0005435243533	15364	Economy	9300.00
0005432784786	15364	Economy	9300.00
0005435243513	15364	Economy	9300.00
0005435243523	15364	Economy	9300.00
0005435476956	15364	Economy	9300.00
0005435243514	15364	Economy	9300.00
0005432784675	15364	Economy	9300.00
0005435243511	15364	Economy	9300.00
0005435476958	15364	Economy	9300.00
0005432784860	15364	Economy	10200.00
0005432784934	15364	Economy	10200.00
0005435476949	15364	Economy	10200.00
0005435243532	15364	Economy	10200.00
0005435476959	15364	Economy	10200.00
0005432784772	15364	Economy	9300.00
0005435626880	15364	Economy	9300.00
0005432784506	15364	Economy	9300.00
0005432784812	15364	Economy	9300.00
0005435243524	15364	Economy	9300.00
0005432784507	15364	Economy	9300.00
0005432784509	15364	Economy	9300.00
0005432784694	15364	Economy	9300.00
0005432784933	15364	Economy	9300.00
0005432784613	15364	Economy	9300.00
0005435476951	15364	Economy	9300.00
0005432784443	15364	Economy	9300.00
0005432784708	15364	Economy	9300.00
0005432784697	15364	Economy	9300.00
0005435243536	15364	Economy	9300.00
0005432784616	15364	Economy	9300.00
0005435476957	15364	Economy	9300.00
0005432784695	15364	Economy	9300.00
0005435243535	15364	Economy	9300.00
0005432784314	15364	Economy	9300.00
0005435476953	15364	Economy	9300.00
0005435243522	15364	Economy	9300.00
0005432784946	15364	Economy	9300.00
0005432784665	15364	Economy	9300.00
0005432784848	15364	Economy	9300.00
0005435476952	15364	Economy	9300.00
0005432784766	15364	Economy	9300.00
0005432784847	15364	Economy	9300.00
0005435243521	15364	Economy	9300.00
0005432784784	15364	Economy	9300.00
0005432784935	15364	Economy	9300.00
0005432784611	15364	Economy	9300.00
0005432784612	15364	Economy	9300.00
0005432784557	15364	Economy	9300.00
0005435243518	15364	Economy	9300.00
0005432784849	15364	Economy	9300.00
0005432784660	15364	Economy	9300.00
0005435243517	15364	Economy	9300.00
0005432784681	15364	Economy	9300.00
0005435243516	15364	Economy	9300.00
0005432784773	15364	Economy	9300.00
0005432784666	15364	Economy	9300.00
0005435243520	15364	Economy	9300.00
0005435476948	15364	Economy	9300.00
0005435243525	15364	Economy	9300.00
0005435626883	15364	Economy	9300.00
0005432784947	15364	Economy	9300.00
0005432784816	15364	Economy	9300.00
0005432784636	15364	Economy	9300.00
0005435243537	15364	Economy	9300.00
0005432784859	15364	Economy	9300.00
0005435243534	15364	Economy	9300.00
0005432784676	15364	Economy	9300.00
0005435476950	15364	Economy	9300.00
0005432784785	15364	Economy	9300.00
0005435626882	15364	Economy	9300.00
0005435243512	15364	Economy	9300.00
0005435243527	15364	Economy	9300.00
0005435243539	15364	Economy	9300.00
0005435243538	15364	Economy	9300.00
0005432784804	15364	Economy	9300.00
0005432784508	15364	Economy	9300.00
0005432784698	15364	Economy	9300.00
0005432784571	15364	Economy	9300.00
0005435243529	15364	Economy	9300.00
0005435243519	15364	Economy	9300.00
0005435243531	15364	Economy	9300.00
0005432784914	15364	Economy	9300.00
0005432784674	15364	Economy	9300.00
0005435851060	4373	Economy	7000.00
0005435851070	4373	Economy	6300.00
0005435851054	4373	Economy	6300.00
0005432848688	4373	Economy	6300.00
0005434462845	4373	Economy	6300.00
0005432848684	4373	Economy	6300.00
0005435851069	4373	Economy	6300.00
0005432848683	4373	Economy	6300.00
0005432848681	4373	Economy	6300.00
0005435851059	4373	Economy	6300.00
0005434462846	4373	Economy	6300.00
0005432848685	4373	Economy	6300.00
0005435851087	4373	Economy	6300.00
0005432848680	4373	Economy	6300.00
0005432848682	4373	Economy	6300.00
0005432848691	4373	Economy	6300.00
0005432848686	4373	Economy	6300.00
0005432848679	4373	Economy	6300.00
0005432848677	4373	Economy	6300.00
0005432848687	4373	Economy	6300.00
0005435851078	4373	Economy	6300.00
0005432848689	4373	Economy	6300.00
0005432848678	4373	Economy	6300.00
0005435851055	4373	Economy	6300.00
0005432848690	4373	Economy	6300.00
0005434461678	28876	Economy	7000.00
0005432848596	28876	Economy	6300.00
0005432848597	28876	Economy	6300.00
0005432848513	28876	Economy	6300.00
0005432848546	28876	Economy	6300.00
0005434461684	28876	Economy	6300.00
0005432848605	28876	Economy	6300.00
0005432848561	28876	Economy	6300.00
0005432848573	28876	Economy	6300.00
0005435851147	28876	Economy	6300.00
0005435851141	28876	Economy	6300.00
0005432848542	28876	Economy	6300.00
0005435851144	28876	Economy	6300.00
0005432848572	28876	Economy	6300.00
0005432848575	28876	Economy	6300.00
0005435851142	28876	Economy	6300.00
0005435851145	28876	Economy	6300.00
0005435851143	28876	Economy	6300.00
0005434461666	28876	Economy	6300.00
0005435851148	28876	Economy	6300.00
0005432848576	28876	Economy	6300.00
0005434461681	28876	Economy	6300.00
0005435851146	28876	Economy	6300.00
0005433497784	6308	Business	11900.00
0005434926655	6308	Business	11900.00
0005433497772	6308	Business	11900.00
0005433497773	6308	Business	11900.00
0005433497766	6308	Business	11900.00
0005434444121	6308	Business	11900.00
0005434926635	6308	Business	11900.00
0005433497769	6308	Business	11900.00
0005433497760	6308	Business	11900.00
0005434926629	6308	Business	11900.00
0005434444128	6308	Economy	4000.00
0005434444123	6308	Economy	4000.00
0005433497780	6308	Economy	4000.00
0005434926645	6308	Economy	4000.00
0005434926640	6308	Economy	4000.00
0005434444119	6308	Economy	4000.00
0005434926633	6308	Economy	4000.00
0005433497778	6308	Economy	4000.00
0005433497770	6308	Economy	4400.00
0005434926648	6308	Economy	4400.00
0005434926644	6308	Economy	4400.00
0005434444122	6308	Economy	4400.00
0005434444126	6308	Economy	4000.00
0005434926639	6308	Economy	4000.00
0005433497774	6308	Economy	4000.00
0005433497765	6308	Economy	4000.00
0005434444120	6308	Economy	4000.00
0005433497762	6308	Economy	4000.00
0005433497777	6308	Economy	4000.00
0005433497771	6308	Economy	4000.00
0005433497761	6308	Economy	4000.00
0005434926631	6308	Economy	4000.00
0005434926643	6308	Economy	4000.00
0005434926626	6308	Economy	4000.00
0005433497776	6308	Economy	4000.00
0005432075317	6308	Economy	4000.00
0005434926641	6308	Economy	4000.00
0005434926657	6308	Economy	4000.00
0005433497786	6308	Economy	4000.00
0005434444118	6308	Economy	4000.00
0005434926653	6308	Economy	4000.00
0005433497779	6308	Economy	4000.00
0005432075319	6308	Economy	4000.00
0005433497785	6308	Economy	4000.00
0005434444125	6308	Economy	4000.00
0005433497764	6308	Economy	4000.00
0005433497775	6308	Economy	4000.00
0005434926642	6308	Economy	4000.00
0005434926649	6308	Economy	4000.00
0005434926646	6308	Economy	4000.00
0005433497783	6308	Economy	4000.00
0005434926636	6308	Economy	4000.00
0005434926628	6308	Economy	4000.00
0005434926632	6308	Economy	4000.00
0005434926630	6308	Economy	4000.00
0005434926637	6308	Economy	4000.00
0005434444129	6308	Economy	4000.00
0005434926634	6308	Economy	4000.00
0005433497768	6308	Economy	4000.00
0005433497763	6308	Economy	4000.00
0005434926652	6308	Economy	4000.00
0005434926638	6308	Economy	4000.00
0005434926650	6308	Economy	4000.00
0005432075316	6308	Economy	4000.00
0005434926651	6308	Economy	4000.00
0005434444117	6308	Economy	4000.00
0005434926656	6308	Economy	4000.00
0005433497787	6308	Economy	4000.00
0005434444127	6308	Economy	4000.00
0005433497767	6308	Economy	4000.00
0005434444130	6308	Economy	4000.00
0005434926658	6308	Economy	4000.00
0005434444124	6308	Economy	4000.00
0005434926654	6308	Economy	4000.00
0005434926647	6308	Economy	4000.00
0005432075318	6308	Economy	4000.00
0005434926627	6308	Economy	4000.00
0005433497781	6308	Economy	4000.00
0005433497782	6308	Economy	4000.00
0005435257481	20332	Business	11900.00
0005435257483	20332	Business	11900.00
0005435257489	20332	Business	11900.00
0005435257490	20332	Economy	4000.00
0005435257480	20332	Economy	4000.00
0005435257491	20332	Economy	4000.00
0005435257487	20332	Economy	4000.00
0005435257488	20332	Economy	4000.00
0005435257484	20332	Economy	4000.00
0005435257486	20332	Economy	4000.00
0005435257494	20332	Economy	4000.00
0005435257482	20332	Economy	4000.00
0005435257485	20332	Economy	4000.00
0005435257493	20332	Economy	4000.00
0005435257492	20332	Economy	4000.00
0005433497610	20337	Business	11900.00
0005434926308	20337	Business	11900.00
0005434443967	20337	Business	11900.00
0005433497631	20337	Business	11900.00
0005434926310	20337	Business	11900.00
0005433497535	20337	Business	11900.00
0005434443970	20337	Business	11900.00
0005433497547	20337	Business	11900.00
0005434926128	20337	Business	11900.00
0005434926257	20337	Business	11900.00
0005434926227	20337	Business	11900.00
0005434926234	20337	Economy	4000.00
0005433497633	20337	Economy	4000.00
0005433497582	20337	Economy	4000.00
0005433497528	20337	Economy	4000.00
0005433497523	20337	Economy	4000.00
0005434926271	20337	Economy	4000.00
0005434926258	20337	Economy	4000.00
0005434443960	20337	Economy	4000.00
0005434443925	20337	Economy	4400.00
0005434444008	20337	Economy	4400.00
0005434926279	20337	Economy	4400.00
0005434926259	20337	Economy	4000.00
0005434926275	20337	Economy	4000.00
0005434443923	20337	Economy	4000.00
0005433497626	20337	Economy	4000.00
0005434443994	20337	Economy	4000.00
0005434443962	20337	Economy	4000.00
0005433497476	20337	Economy	4000.00
0005434443944	20337	Economy	4000.00
0005434444023	20337	Economy	4000.00
0005434443926	20337	Economy	4000.00
0005434444024	20337	Economy	4000.00
0005434443950	20337	Economy	4000.00
0005434443997	20337	Economy	4000.00
0005434926223	20337	Economy	4000.00
0005434443987	20337	Economy	4000.00
0005433497629	20337	Economy	4000.00
0005434444027	20337	Economy	4000.00
0005433497525	20337	Economy	4000.00
0005433497575	20337	Economy	4000.00
0005434926295	20337	Economy	4000.00
0005434444028	20337	Economy	4000.00
0005434443980	20337	Economy	4000.00
0005434926266	20337	Economy	4000.00
0005433497636	20337	Economy	4000.00
0005433497478	20337	Economy	4000.00
0005434443998	20337	Economy	4000.00
0005433497477	20337	Economy	4000.00
0005434926307	20337	Economy	4000.00
0005434444025	20337	Economy	4000.00
0005434926280	20337	Economy	4000.00
0005433497501	20337	Economy	4000.00
0005433497625	20337	Economy	4000.00
0005433497585	20337	Economy	4000.00
0005434444044	20337	Economy	4000.00
0005434926309	20337	Economy	4000.00
0005434926278	20337	Economy	4000.00
0005434443981	20337	Economy	4000.00
0005433497536	20337	Economy	4000.00
0005433497541	20337	Economy	4000.00
0005434926222	20337	Economy	4000.00
0005434443951	20337	Economy	4000.00
0005434926187	20337	Economy	4000.00
0005433497634	20337	Economy	4000.00
0005433497567	20337	Economy	4000.00
0005433497597	20337	Economy	4000.00
0005434926129	20337	Economy	4000.00
0005434443961	20337	Economy	4000.00
0005433497568	20337	Economy	4000.00
0005434926300	20337	Economy	4000.00
0005434443924	20337	Economy	4000.00
0005434443968	20337	Economy	4000.00
0005434926302	20337	Economy	4000.00
0005434443979	20337	Economy	4000.00
0005433497457	20337	Economy	4000.00
0005433497552	20337	Economy	4000.00
0005433497544	20337	Economy	4000.00
0005434926130	20337	Economy	4000.00
0005433497630	20337	Economy	4000.00
0005433497693	20337	Economy	4000.00
0005434926228	20337	Economy	4000.00
0005434926301	20337	Economy	4000.00
0005433497589	20337	Economy	4000.00
0005433497569	20337	Economy	4000.00
0005432784702	12204	Business	41200.00
0005432784793	12204	Business	41200.00
0005432784582	12204	Business	41200.00
0005435243554	12204	Business	41200.00
0005435243551	12204	Business	41200.00
0005432784727	12204	Business	41200.00
0005435243558	12204	Business	41200.00
0005432784863	12204	Business	41200.00
0005435243557	12204	Business	41200.00
0005435243552	12204	Economy	13700.00
0005432784911	12204	Economy	13700.00
0005432784771	12204	Economy	13700.00
0005432784623	12204	Economy	13700.00
0005432784904	12204	Economy	13700.00
0005432784770	12204	Economy	13700.00
0005432784853	12204	Economy	13700.00
0005432784600	12204	Economy	13700.00
0005432784779	12204	Economy	13700.00
0005432784746	12204	Economy	15100.00
0005432784644	12204	Economy	15100.00
0005435243560	12204	Economy	15100.00
0005432784806	12204	Economy	15100.00
0005435243547	12204	Economy	15100.00
0005432784778	12204	Economy	13700.00
0005432784769	12204	Economy	13700.00
0005432784983	12204	Economy	13700.00
0005432784581	12204	Economy	13700.00
0005432784852	12204	Economy	13700.00
0005432784985	12204	Economy	13700.00
0005432784576	12204	Economy	13700.00
0005432784984	12204	Economy	13700.00
0005435243544	12204	Economy	13700.00
0005435243553	12204	Economy	13700.00
0005435243540	12204	Economy	13700.00
0005435243546	12204	Economy	13700.00
0005435243549	12204	Economy	13700.00
0005432784910	12204	Economy	13700.00
0005435243545	12204	Economy	13700.00
0005432784878	12204	Economy	13700.00
0005435243559	12204	Economy	13700.00
0005432784909	12204	Economy	13700.00
0005435243542	12204	Economy	13700.00
0005435243548	12204	Economy	13700.00
0005432784814	12204	Economy	13700.00
0005432784518	12204	Economy	13700.00
0005435243555	12204	Economy	13700.00
0005432784745	12204	Economy	13700.00
0005432784519	12204	Economy	13700.00
0005435243550	12204	Economy	13700.00
0005432784768	12204	Economy	13700.00
0005435243541	12204	Economy	13700.00
0005432784586	12204	Economy	13700.00
0005435243543	12204	Economy	13700.00
0005435243562	12204	Economy	13700.00
0005432784879	12204	Economy	13700.00
0005432784520	12204	Economy	13700.00
0005432784620	12204	Economy	13700.00
0005432784624	12204	Economy	13700.00
0005432784869	12204	Economy	13700.00
0005435243564	12204	Economy	13700.00
0005432784841	12204	Economy	13700.00
0005432784912	12204	Economy	13700.00
0005432784599	12204	Economy	13700.00
0005432784736	12204	Economy	13700.00
0005432784517	12204	Economy	13700.00
0005435243556	12204	Economy	13700.00
0005432784565	12204	Economy	13700.00
0005432784619	12204	Economy	13700.00
0005432784705	12204	Economy	13700.00
0005432784585	12204	Economy	13700.00
0005435243563	12204	Economy	13700.00
0005435243561	12204	Economy	13700.00
0005432784758	12204	Economy	13700.00
0005432784513	12204	Economy	13700.00
0005432784797	12204	Economy	13700.00
0005432784577	12204	Economy	13700.00
0005432785108	15451	Business	41200.00
0005432785104	15451	Business	41200.00
0005435243347	15451	Business	41200.00
0005435243224	15451	Business	41200.00
0005432785100	15451	Business	41200.00
0005432785116	15451	Business	41200.00
0005432785143	15451	Business	41200.00
0005432785145	15451	Business	41200.00
0005432785117	15451	Business	41200.00
0005435243291	15451	Business	41200.00
0005432785124	15451	Business	41200.00
0005435243202	15451	Business	41200.00
0005432785105	15451	Economy	13700.00
0005432785118	15451	Economy	13700.00
0005435243298	15451	Economy	13700.00
0005432785133	15451	Economy	13700.00
0005435243223	15451	Economy	13700.00
0005432785113	15451	Economy	13700.00
0005435243191	15451	Economy	13700.00
0005432785144	15451	Economy	15100.00
0005432785111	15451	Economy	15100.00
0005432785115	15451	Economy	15100.00
0005432785114	15451	Economy	15100.00
0005432785102	15451	Economy	13700.00
0005432785122	15451	Economy	13700.00
0005432785098	15451	Economy	13700.00
0005435243372	15451	Economy	13700.00
0005432785093	15451	Economy	13700.00
0005432785142	15451	Economy	13700.00
0005432785121	15451	Economy	13700.00
0005435243192	15451	Economy	13700.00
0005432785101	15451	Economy	13700.00
0005432785140	15451	Economy	13700.00
0005435243277	15451	Economy	13700.00
0005435243324	15451	Economy	13700.00
0005435243314	15451	Economy	13700.00
0005432785106	15451	Economy	13700.00
0005432785120	15451	Economy	13700.00
0005432785107	15451	Economy	13700.00
0005432785109	15451	Economy	13700.00
0005432785131	15451	Economy	13700.00
0005435243151	15451	Economy	13700.00
0005432785123	15451	Economy	13700.00
0005435243274	15451	Economy	13700.00
0005432785141	15451	Economy	13700.00
0005432785094	15451	Economy	13700.00
0005432785132	15451	Economy	13700.00
0005435243273	15451	Economy	13700.00
0005432785092	15451	Economy	13700.00
0005435243363	15451	Economy	13700.00
0005432785139	15451	Economy	13700.00
0005435243216	15451	Economy	13700.00
0005432785110	15451	Economy	13700.00
0005432785138	15451	Economy	13700.00
0005432785103	15451	Economy	13700.00
0005435243323	15451	Economy	13700.00
0005435243194	15451	Economy	13700.00
0005435243341	15451	Economy	13700.00
0005432785130	15451	Economy	13700.00
0005435243244	15451	Economy	13700.00
0005432785126	15451	Economy	13700.00
0005432785095	15451	Economy	13700.00
0005435243221	15451	Economy	13700.00
0005435243340	15451	Economy	13700.00
0005435243289	15451	Economy	13700.00
0005435243239	15451	Economy	13700.00
0005435243248	15451	Economy	13700.00
0005432785099	15451	Economy	13700.00
0005435243200	15451	Economy	13700.00
0005432785127	15451	Economy	13700.00
0005432785096	15451	Economy	13700.00
0005435243243	15451	Economy	13700.00
0005432785136	15451	Economy	13700.00
0005432785146	15451	Economy	13700.00
0005435243373	15451	Economy	13700.00
0005435243247	15451	Economy	13700.00
0005435243204	15451	Economy	13700.00
0005432785112	15451	Economy	13700.00
0005435243222	15451	Economy	13700.00
0005435243203	15451	Economy	13700.00
0005432785097	15451	Economy	13700.00
0005432785134	15451	Economy	13700.00
0005432785128	15451	Economy	13700.00
0005432785129	15451	Economy	13700.00
0005432785125	15451	Economy	13700.00
0005435243199	15451	Economy	13700.00
0005435243345	15451	Economy	13700.00
0005435243152	15451	Economy	13700.00
0005432785137	15451	Economy	13700.00
0005432785119	15451	Economy	13700.00
0005432785135	15451	Economy	13700.00
0005434879541	10067	Business	49700.00
0005434879449	10067	Business	49700.00
0005434879917	10067	Business	49700.00
0005434910173	10067	Business	49700.00
0005434879887	10067	Business	49700.00
0005434879554	10067	Business	49700.00
0005434879737	10067	Business	49700.00
0005434879687	10067	Business	49700.00
0005434879957	10067	Business	49700.00
0005434879986	10067	Business	49700.00
0005434879645	10067	Business	49700.00
0005434880101	10067	Business	49700.00
0005434879566	10067	Business	49700.00
0005434879592	10067	Business	49700.00
0005434879706	10067	Business	49700.00
0005434879450	10067	Business	49700.00
0005435914106	10067	Business	49700.00
0005434879930	10067	Business	49700.00
0005434879934	10067	Business	49700.00
0005435914099	10067	Business	49700.00
0005435914109	10067	Economy	16600.00
0005434879787	10067	Economy	16600.00
0005434879817	10067	Economy	16600.00
0005434879984	10067	Economy	16600.00
0005434880083	10067	Economy	16600.00
0005434880157	10067	Economy	16600.00
0005435914101	10067	Economy	16600.00
0005434910172	10067	Economy	16600.00
0005434879755	10067	Economy	16600.00
0005434880082	10067	Economy	16600.00
0005434879750	10067	Economy	16600.00
0005434879896	10067	Economy	16600.00
0005434880186	10067	Economy	16600.00
0005435914111	10067	Economy	18200.00
0005434879786	10067	Economy	18200.00
0005435914110	10067	Economy	18200.00
0005434879585	10067	Economy	18200.00
0005434879222	10067	Economy	16600.00
0005434879785	10067	Economy	16600.00
0005434880089	10067	Economy	16600.00
0005434880090	10067	Economy	16600.00
0005434879908	10067	Economy	16600.00
0005434880093	10067	Economy	16600.00
0005434879614	10067	Economy	16600.00
0005435914112	10067	Economy	16600.00
0005434879866	10067	Economy	16600.00
0005434880167	10067	Economy	16600.00
0005434879672	10067	Economy	16600.00
0005434879452	10067	Economy	16600.00
0005434879770	10067	Economy	16600.00
0005434758927	10067	Economy	16600.00
0005435914097	10067	Economy	16600.00
0005434879875	10067	Economy	16600.00
0005434880187	10067	Economy	16600.00
0005434879816	10067	Economy	16600.00
0005434879885	10067	Economy	16600.00
0005434879801	10067	Economy	16600.00
0005434879451	10067	Economy	16600.00
0005434879416	10067	Economy	16600.00
0005434880048	10067	Economy	16600.00
0005434879909	10067	Economy	16600.00
0005434879969	10067	Economy	16600.00
0005434879745	10067	Economy	16600.00
0005434879332	10067	Economy	16600.00
0005434879944	10067	Economy	16600.00
0005434880004	10067	Economy	16600.00
0005434879542	10067	Economy	16600.00
0005434879754	10067	Economy	16600.00
0005434879423	10067	Economy	16600.00
0005434879444	10067	Economy	16600.00
0005434880102	10067	Economy	16600.00
0005434879829	10067	Economy	16600.00
0005434880166	10067	Economy	16600.00
0005434879776	10067	Economy	16600.00
0005434879918	10067	Economy	16600.00
0005435914105	10067	Economy	16600.00
0005434879761	10067	Economy	16600.00
0005434879960	10067	Economy	16600.00
0005434880134	10067	Economy	16600.00
0005434879788	10067	Economy	16600.00
0005434880005	10067	Economy	16600.00
0005434879873	10067	Economy	16600.00
0005434879686	10067	Economy	16600.00
0005434879886	10067	Economy	16600.00
0005435914104	10067	Economy	16600.00
0005435914107	10067	Economy	16600.00
0005434880100	10067	Economy	16600.00
0005434879768	10067	Economy	16600.00
0005434879899	10067	Economy	16600.00
0005434879945	10067	Economy	16600.00
0005434879831	10067	Economy	16600.00
0005434879769	10067	Economy	16600.00
0005435914102	10067	Economy	16600.00
0005434879613	10067	Economy	16600.00
0005434879565	10067	Economy	16600.00
0005435914103	10067	Economy	16600.00
0005434879874	10067	Economy	16600.00
0005434879943	10067	Economy	16600.00
0005434879358	10067	Economy	16600.00
0005434879893	10067	Economy	16600.00
0005434879567	10067	Economy	16600.00
0005435914100	10067	Economy	16600.00
0005434879646	10067	Economy	16600.00
0005434879929	10067	Economy	16600.00
0005434879688	10067	Economy	16600.00
0005434879555	10067	Economy	16600.00
0005434879612	10067	Economy	16600.00
0005434879388	10067	Economy	16600.00
0005434880185	10067	Economy	16600.00
0005434879830	10067	Economy	16600.00
0005434910174	10067	Economy	16600.00
0005434879910	10067	Economy	16600.00
0005435914098	10067	Economy	16600.00
0005435914108	10067	Economy	16600.00
0005434879808	10067	Economy	16600.00
0005434880642	14620	Business	49700.00
0005434880615	14620	Business	49700.00
0005434880608	14620	Business	49700.00
0005434880603	14620	Business	49700.00
0005434880651	14620	Business	49700.00
0005434880607	14620	Business	49700.00
0005434880600	14620	Business	49700.00
0005434880614	14620	Business	49700.00
0005434880625	14620	Business	49700.00
0005434880631	14620	Business	49700.00
0005434880667	14620	Business	49700.00
0005434880624	14620	Business	49700.00
0005434880661	14620	Business	49700.00
0005434880628	14620	Business	49700.00
0005434880612	14620	Business	49700.00
0005434880643	14620	Economy	16600.00
0005434880610	14620	Business	49700.00
0005434880616	14620	Economy	16600.00
0005434880599	14620	Economy	16600.00
0005434880662	14620	Economy	16600.00
0005434880664	14620	Economy	16600.00
0005434880652	14620	Economy	16600.00
0005434880622	14620	Economy	16600.00
0005434880650	14620	Economy	16600.00
0005434880654	14620	Economy	16600.00
0005434880626	14620	Economy	16600.00
0005434880678	14620	Economy	16600.00
0005434880676	14620	Economy	18200.00
0005434880657	14620	Economy	18200.00
0005434880675	14620	Economy	18200.00
0005434880597	14620	Economy	18200.00
0005434880606	14620	Economy	16600.00
0005434880611	14620	Economy	16600.00
0005434880637	14620	Economy	16600.00
0005435913985	14620	Economy	16600.00
0005434880601	14620	Economy	16600.00
0005434880672	14620	Economy	16600.00
0005434880665	14620	Economy	16600.00
0005434880635	14620	Economy	16600.00
0005434880629	14620	Economy	16600.00
0005434880602	14620	Economy	16600.00
0005434880648	14620	Economy	16600.00
0005434880674	14620	Economy	16600.00
0005434880679	14620	Economy	16600.00
0005434880671	14620	Economy	16600.00
0005434880620	14620	Economy	16600.00
0005434880639	14620	Economy	16600.00
0005434880623	14620	Economy	16600.00
0005434880617	14620	Economy	16600.00
0005434880663	14620	Economy	16600.00
0005434880634	14620	Economy	16600.00
0005434758953	14620	Economy	16600.00
0005434880666	14620	Economy	16600.00
0005434880644	14620	Economy	16600.00
0005434880609	14620	Economy	16600.00
0005434880647	14620	Economy	16600.00
0005434880638	14620	Economy	16600.00
0005434880645	14620	Economy	16600.00
0005435913986	14620	Economy	16600.00
0005434758954	14620	Economy	16600.00
0005434880655	14620	Economy	16600.00
0005435913995	14620	Economy	16600.00
0005434880598	14620	Economy	16600.00
0005434880627	14620	Economy	16600.00
0005435913991	14620	Economy	16600.00
0005434880649	14620	Economy	16600.00
0005434880641	14620	Economy	16600.00
0005434880636	14620	Economy	16600.00
0005434880669	14620	Economy	16600.00
0005434880595	14620	Economy	16600.00
0005434880632	14620	Economy	16600.00
0005434880673	14620	Economy	16600.00
0005434880668	14620	Economy	16600.00
0005434880646	14620	Economy	16600.00
0005434880630	14620	Economy	16600.00
0005435913987	14620	Economy	16600.00
0005434880640	14620	Economy	16600.00
0005434880670	14620	Economy	16600.00
0005434880618	14620	Economy	16600.00
0005434880605	14620	Economy	16600.00
0005434880682	14620	Economy	16600.00
0005434880680	14620	Economy	16600.00
0005434880681	14620	Economy	16600.00
0005434880613	14620	Economy	16600.00
0005434880677	14620	Economy	16600.00
0005434880621	14620	Economy	16600.00
0005434880619	14620	Economy	16600.00
0005434880596	14620	Economy	16600.00
0005434880659	14620	Economy	16600.00
0005434880604	14620	Economy	16600.00
0005434880656	14620	Economy	16600.00
0005435913984	14620	Economy	16600.00
0005434880633	14620	Economy	16600.00
0005434880660	14620	Economy	16600.00
0005434880658	14620	Economy	16600.00
0005434880653	14620	Economy	16600.00
0005435913989	14620	Economy	16600.00
0005434252129	9229	Economy	22400.00
0005434252130	9229	Economy	20300.00
0005435660424	9229	Economy	20300.00
0005434252132	9229	Economy	20300.00
0005434252090	9229	Economy	20300.00
0005435660425	9229	Economy	20300.00
0005435660423	9229	Economy	20300.00
0005435660419	9229	Economy	20300.00
0005435660427	9229	Economy	20300.00
0005434252135	9229	Economy	20300.00
0005435660420	9229	Economy	20300.00
0005434252111	9229	Economy	20300.00
0005435660422	9229	Economy	20300.00
0005435660421	9229	Economy	20300.00
0005434252136	9229	Economy	20300.00
0005435660426	9229	Economy	20300.00
0005434252164	9229	Economy	20300.00
0005434252210	24645	Economy	22400.00
0005435660318	24645	Economy	22400.00
0005434252212	24645	Economy	22400.00
0005435660320	24645	Economy	20300.00
0005435660317	24645	Economy	20300.00
0005435660373	24645	Economy	20300.00
0005435660322	24645	Economy	20300.00
0005434252211	24645	Economy	20300.00
0005435660280	24645	Economy	20300.00
0005434252208	24645	Economy	20300.00
0005434252205	24645	Economy	20300.00
0005434252213	24645	Economy	20300.00
0005435660319	24645	Economy	20300.00
0005435660374	24645	Economy	20300.00
0005434252209	24645	Economy	20300.00
0005435660336	24645	Economy	20300.00
0005435660335	24645	Economy	20300.00
0005435660345	24645	Economy	20300.00
0005434252207	24645	Economy	20300.00
0005435660323	24645	Economy	20300.00
0005435660339	24645	Economy	20300.00
0005435660331	24645	Economy	20300.00
0005435660279	24645	Economy	20300.00
0005435660346	24645	Economy	20300.00
0005435660324	24645	Economy	20300.00
0005434252206	24645	Economy	20300.00
0005432967351	2768	Business	33000.00
0005433681766	2768	Business	33000.00
0005432222916	2768	Business	33000.00
0005433681777	2768	Business	33000.00
0005433681765	2768	Business	33000.00
0005432967330	2768	Business	33000.00
0005433681780	2768	Business	33000.00
0005433681774	2768	Business	33000.00
0005432967380	2768	Business	33000.00
0005433681775	2768	Business	33000.00
0005433681784	2768	Business	33000.00
0005433681793	2768	Economy	11000.00
0005433681768	2768	Economy	11000.00
0005433681785	2768	Economy	11000.00
0005432222918	2768	Economy	11000.00
0005433681790	2768	Economy	11000.00
0005432967335	2768	Economy	11000.00
0005432967317	2768	Economy	11000.00
0005433681762	2768	Economy	12100.00
0005433681761	2768	Economy	12100.00
0005433681792	2768	Economy	12100.00
0005433681767	2768	Economy	12100.00
0005432967350	2768	Economy	11000.00
0005432967543	2768	Economy	11000.00
0005433681783	2768	Economy	11000.00
0005432967366	2768	Economy	11000.00
0005432967372	2768	Economy	11000.00
0005432222915	2768	Economy	11000.00
0005433681782	2768	Economy	11000.00
0005433681796	2768	Economy	11000.00
0005432967381	2768	Economy	11000.00
0005433681764	2768	Economy	11000.00
0005433681771	2768	Economy	11000.00
0005432967367	2768	Economy	11000.00
0005433681799	2768	Economy	11000.00
0005433684471	2768	Economy	11000.00
0005432222917	2768	Economy	11000.00
0005432967424	2768	Economy	11000.00
0005432967478	2768	Economy	11000.00
0005433681760	2768	Economy	11000.00
0005433681779	2768	Economy	11000.00
0005432967355	2768	Economy	11000.00
0005433681786	2768	Economy	11000.00
0005432967318	2768	Economy	11000.00
0005433681781	2768	Economy	11000.00
0005433681776	2768	Economy	11000.00
0005433681798	2768	Economy	11000.00
0005433681758	2768	Economy	11000.00
0005433681800	2768	Economy	11000.00
0005432967402	2768	Economy	11000.00
0005433681778	2768	Economy	11000.00
0005433681769	2768	Economy	11000.00
0005432967419	2768	Economy	11000.00
0005432967425	2768	Economy	11000.00
0005433681763	2768	Economy	11000.00
0005433681788	2768	Economy	11000.00
0005432967383	2768	Economy	11000.00
0005433681772	2768	Economy	11000.00
0005432967336	2768	Economy	11000.00
0005432967390	2768	Economy	11000.00
0005433681791	2768	Economy	11000.00
0005433681795	2768	Economy	11000.00
0005432967354	2768	Economy	11000.00
0005432967391	2768	Economy	11000.00
0005433681787	2768	Economy	11000.00
0005432967423	2768	Economy	11000.00
0005433681794	2768	Economy	11000.00
0005433681789	2768	Economy	11000.00
0005432967440	2768	Economy	11000.00
0005433681773	2768	Economy	11000.00
0005433681770	2768	Economy	11000.00
0005432222920	2768	Economy	11000.00
0005432222919	2768	Economy	11000.00
0005433681759	2768	Economy	11000.00
0005433681797	2768	Economy	11000.00
0005432967454	2768	Economy	11000.00
0005433681593	29165	Business	33000.00
0005432967582	29165	Business	33000.00
0005433681293	29165	Business	33000.00
0005432005286	29165	Business	33000.00
0005433681331	29165	Business	33000.00
0005432967598	29165	Business	33000.00
0005432005285	29165	Business	33000.00
0005433681384	29165	Business	33000.00
0005432967593	29165	Economy	11000.00
0005433681390	29165	Economy	11000.00
0005432967585	29165	Economy	11000.00
0005432967576	29165	Economy	11000.00
0005433681563	29165	Economy	11000.00
0005432967594	29165	Economy	11000.00
0005433690953	29165	Economy	11000.00
0005432967595	29165	Economy	12100.00
0005432967589	29165	Economy	12100.00
0005433681377	29165	Economy	12100.00
0005432967583	29165	Economy	12100.00
0005433681211	29165	Economy	11000.00
0005433681457	29165	Economy	11000.00
0005432967575	29165	Economy	11000.00
0005433681549	29165	Economy	11000.00
0005433690957	29165	Economy	11000.00
0005432967581	29165	Economy	11000.00
0005433681332	29165	Economy	11000.00
0005433687741	29165	Economy	11000.00
0005432967578	29165	Economy	11000.00
0005432967592	29165	Economy	11000.00
0005432967587	29165	Economy	11000.00
0005433681313	29165	Economy	11000.00
0005433681359	29165	Economy	11000.00
0005432967579	29165	Economy	11000.00
0005433681413	29165	Economy	11000.00
0005433681294	29165	Economy	11000.00
0005433681376	29165	Economy	11000.00
0005433681430	29165	Economy	11000.00
0005433681517	29165	Economy	11000.00
0005433681463	29165	Economy	11000.00
0005433681592	29165	Economy	11000.00
0005433681364	29165	Economy	11000.00
0005433681226	29165	Economy	11000.00
0005433681399	29165	Economy	11000.00
0005433681550	29165	Economy	11000.00
0005433687744	29165	Economy	11000.00
0005433681436	29165	Economy	11000.00
0005432967596	29165	Economy	11000.00
0005433681360	29165	Economy	11000.00
0005432967591	29165	Economy	11000.00
0005432967580	29165	Economy	11000.00
0005433690955	29165	Economy	11000.00
0005432967588	29165	Economy	11000.00
0005433687740	29165	Economy	11000.00
0005433681429	29165	Economy	11000.00
0005433681329	29165	Economy	11000.00
0005432967586	29165	Economy	11000.00
0005433681120	29165	Economy	11000.00
0005433681239	29165	Economy	11000.00
0005433681516	29165	Economy	11000.00
0005433681320	29165	Economy	11000.00
0005433681121	29165	Economy	11000.00
0005432967577	29165	Economy	11000.00
0005433681416	29165	Economy	11000.00
0005433681431	29165	Economy	11000.00
0005433681462	29165	Economy	11000.00
0005432005287	29165	Economy	11000.00
0005433681321	29165	Economy	11000.00
0005433681209	29165	Economy	11000.00
0005433681374	29165	Economy	11000.00
0005432967597	29165	Economy	11000.00
0005433681383	29165	Economy	11000.00
0005432967590	29165	Economy	11000.00
0005433681358	29165	Economy	11000.00
0005433681365	29165	Economy	11000.00
0005432967574	29165	Economy	11000.00
0005432967584	29165	Economy	11000.00
0005433681190	29165	Economy	11000.00
0005434163784	9322	Business	132900.00
0005433616511	9322	Business	132900.00
0005433578156	9322	Business	132900.00
0005434163729	9322	Business	132900.00
0005433616518	9322	Business	132900.00
0005433616459	9322	Business	132900.00
0005433616470	9322	Business	132900.00
0005434163765	9322	Business	132900.00
0005433616477	9322	Business	132900.00
0005433616485	9322	Business	132900.00
0005433616496	9322	Business	132900.00
0005433616519	9322	Business	132900.00
0005433578153	9322	Business	132900.00
0005433616526	9322	Business	132900.00
0005433634645	9322	Business	132900.00
0005433578152	9322	Business	132900.00
0005433616497	9322	Business	132900.00
0005433616474	9322	Business	132900.00
0005434163810	9322	Business	132900.00
0005433578157	9322	Business	132900.00
0005433634661	9322	Business	132900.00
0005433634669	9322	Business	132900.00
0005433578147	9322	Business	132900.00
0005433616487	9322	Economy	48700.00
0005433634646	9322	Economy	48700.00
0005433634653	9322	Economy	48700.00
0005432756929	9322	Economy	48700.00
0005433616465	9322	Economy	44300.00
0005433634643	9322	Economy	44300.00
0005433616491	9322	Economy	44300.00
0005433634649	9322	Economy	44300.00
0005433616507	9322	Economy	44300.00
0005433616471	9322	Economy	44300.00
0005433634656	9322	Economy	44300.00
0005433634670	9322	Economy	44300.00
0005433578158	9322	Economy	44300.00
0005433616513	9322	Economy	44300.00
0005433634652	9322	Economy	44300.00
0005433634674	9322	Economy	44300.00
0005432755161	9322	Economy	44300.00
0005433616500	9322	Economy	44300.00
0005433616456	9322	Economy	44300.00
0005433616482	9322	Economy	44300.00
0005433616495	9322	Economy	44300.00
0005433616476	9322	Economy	44300.00
0005433616493	9322	Economy	44300.00
0005434269130	9322	Economy	44300.00
0005433616516	9322	Economy	44300.00
0005434163757	9322	Economy	44300.00
0005433616523	9322	Economy	44300.00
0005433616514	9322	Economy	44300.00
0005433634664	9322	Economy	44300.00
0005434163783	9322	Economy	44300.00
0005433616475	9322	Economy	44300.00
0005434153550	9322	Economy	44300.00
0005432756930	9322	Economy	44300.00
0005433616483	9322	Economy	44300.00
0005432145163	9322	Economy	44300.00
0005433616512	9322	Economy	44300.00
0005434153557	9322	Economy	44300.00
0005434153556	9322	Economy	44300.00
0005433634676	9322	Economy	44300.00
0005433634667	9322	Economy	44300.00
0005433634642	9322	Economy	44300.00
0005433578155	9322	Economy	44300.00
0005433578154	9322	Economy	44300.00
0005433616501	9322	Economy	44300.00
0005433634662	9322	Economy	44300.00
0005433616489	9322	Economy	44300.00
0005433578149	9322	Economy	44300.00
0005433616486	9322	Economy	44300.00
0005433616463	9322	Economy	44300.00
0005433634663	9322	Economy	44300.00
0005433634650	9322	Economy	44300.00
0005433634648	9322	Economy	44300.00
0005433616509	9322	Economy	44300.00
0005433616466	9322	Economy	44300.00
0005433616506	9322	Economy	44300.00
0005433616498	9322	Economy	44300.00
0005433634651	9322	Economy	44300.00
0005433616481	9322	Economy	44300.00
0005433634675	9322	Economy	44300.00
0005433616524	9322	Economy	48700.00
0005433616503	9322	Economy	48700.00
0005433616510	9322	Economy	48700.00
0005433634655	9322	Economy	48700.00
0005433616504	9322	Economy	44300.00
0005433616479	9322	Economy	44300.00
0005433616458	9322	Economy	44300.00
0005434163756	9322	Economy	48700.00
0005433616462	9322	Economy	44300.00
0005432755160	9322	Economy	44300.00
0005433616478	9322	Economy	44300.00
0005433616484	9322	Economy	44300.00
0005433616492	9322	Economy	44300.00
0005433634654	9322	Economy	44300.00
0005433616502	9322	Economy	44300.00
0005433634659	9322	Economy	44300.00
0005433616494	9322	Economy	44300.00
0005433634644	9322	Economy	44300.00
0005433616488	9322	Economy	44300.00
0005433616521	9322	Economy	44300.00
0005434163811	9322	Economy	44300.00
0005433616522	9322	Economy	44300.00
0005433616525	9322	Economy	44300.00
0005433616473	9322	Economy	44300.00
0005433616457	9322	Economy	44300.00
0005433616472	9322	Economy	44300.00
0005433634647	9322	Economy	44300.00
0005433616469	9322	Economy	44300.00
0005432756931	9322	Economy	44300.00
0005433578146	9322	Economy	44300.00
0005433616505	9322	Economy	44300.00
0005433616508	9322	Economy	44300.00
0005433616461	9322	Economy	44300.00
0005433616520	9322	Economy	44300.00
0005433634666	9322	Economy	44300.00
0005433616490	9322	Economy	44300.00
0005434163812	9322	Economy	44300.00
0005434152814	9322	Economy	44300.00
0005433634671	9322	Economy	44300.00
0005433616499	9322	Economy	44300.00
0005434269139	9322	Economy	44300.00
0005433578148	9322	Economy	44300.00
0005433634665	9322	Economy	44300.00
0005433578150	9322	Economy	44300.00
0005433616467	9322	Economy	44300.00
0005433634673	9322	Economy	44300.00
0005434152821	9322	Economy	44300.00
0005433634657	9322	Economy	44300.00
0005433578151	9322	Economy	44300.00
0005433634660	9322	Economy	44300.00
0005433616515	9322	Economy	44300.00
0005433616464	9322	Economy	44300.00
0005433616468	9322	Economy	44300.00
0005433634668	9322	Economy	44300.00
0005433616517	9322	Economy	44300.00
0005433616460	9322	Economy	44300.00
0005433616480	9322	Economy	44300.00
0005433634658	9322	Economy	44300.00
0005434153548	9322	Economy	44300.00
0005433634672	9322	Economy	44300.00
0005433634371	25228	Business	132900.00
0005433634428	25228	Business	132900.00
0005433634427	25228	Business	132900.00
0005433616075	25228	Business	132900.00
0005434151803	25228	Business	132900.00
0005433634347	25228	Business	132900.00
0005433615718	25228	Business	132900.00
0005433616225	25228	Business	132900.00
0005434151805	25228	Business	132900.00
0005433615967	25228	Business	132900.00
0005434152833	25228	Business	132900.00
0005434152844	25228	Business	132900.00
0005433615974	25228	Business	132900.00
0005434152840	25228	Business	132900.00
0005433615940	25228	Business	132900.00
0005433634388	25228	Business	132900.00
0005433578001	25228	Business	132900.00
0005433616135	25228	Business	132900.00
0005433616040	25228	Business	132900.00
0005432755124	25228	Business	132900.00
0005433616045	25228	Business	132900.00
0005434163844	25228	Business	132900.00
0005433615672	25228	Business	132900.00
0005433615823	25228	Business	132900.00
0005433616020	25228	Business	132900.00
0005433615715	25228	Business	132900.00
0005433615717	25228	Economy	48700.00
0005434152834	25228	Business	132900.00
0005433634572	25228	Economy	48700.00
0005433615749	25228	Economy	48700.00
0005433616046	25228	Economy	48700.00
0005433615826	25228	Economy	48700.00
0005433616148	25228	Economy	48700.00
0005433634372	25228	Economy	44300.00
0005432751559	25228	Economy	44300.00
0005433634343	25228	Economy	44300.00
0005434163843	25228	Economy	44300.00
0005433615962	25228	Economy	44300.00
0005433615716	25228	Economy	44300.00
0005434163841	25228	Economy	44300.00
0005433634272	25228	Economy	44300.00
0005434151804	25228	Economy	44300.00
0005434151798	25228	Economy	44300.00
0005434272228	25228	Economy	44300.00
0005433615745	25228	Economy	44300.00
0005433615493	25228	Economy	44300.00
0005433615830	25228	Economy	44300.00
0005433616029	25228	Economy	44300.00
0005432751574	25228	Economy	44300.00
0005434152835	25228	Economy	44300.00
0005432755123	25228	Economy	44300.00
0005433615949	25228	Economy	44300.00
0005434152838	25228	Economy	44300.00
0005432751575	25228	Economy	44300.00
0005433615673	25228	Economy	44300.00
0005433634570	25228	Economy	44300.00
0005434152842	25228	Economy	44300.00
0005433615929	25228	Economy	44300.00
0005434163847	25228	Economy	44300.00
0005433616108	25228	Economy	44300.00
0005433615618	25228	Economy	44300.00
0005434151806	25228	Economy	44300.00
0005432751577	25228	Economy	44300.00
0005433615802	25228	Economy	44300.00
0005433578018	25228	Economy	44300.00
0005433615751	25228	Economy	44300.00
0005433634480	25228	Economy	44300.00
0005434163849	25228	Economy	44300.00
0005433615690	25228	Economy	44300.00
0005433615913	25228	Economy	44300.00
0005434163850	25228	Economy	44300.00
0005433615827	25228	Economy	44300.00
0005434152836	25228	Economy	44300.00
0005434151801	25228	Economy	44300.00
0005432755119	25228	Economy	44300.00
0005433634446	25228	Economy	44300.00
0005433615714	25228	Economy	44300.00
0005433615930	25228	Economy	44300.00
0005433615957	25228	Economy	44300.00
0005433634348	25228	Economy	44300.00
0005433615881	25228	Economy	44300.00
0005433616223	25228	Economy	44300.00
0005432755118	25228	Economy	44300.00
0005434151797	25228	Economy	44300.00
0005433615870	25228	Economy	44300.00
0005433616226	25228	Economy	44300.00
0005433616059	25228	Economy	44300.00
0005433634346	25228	Economy	44300.00
0005432755112	25228	Economy	44300.00
0005434273115	25228	Economy	44300.00
0005434152843	25228	Economy	48700.00
0005433615810	25228	Economy	48700.00
0005432755133	25228	Economy	48700.00
0005433634445	25228	Economy	48700.00
0005433616076	25228	Economy	48700.00
0005433634361	25228	Economy	44300.00
0005433616005	25228	Economy	44300.00
0005433578026	25228	Economy	44300.00
0005434272227	25228	Economy	44300.00
0005433634396	25228	Economy	48700.00
0005434152839	25228	Economy	44300.00
0005433615912	25228	Economy	44300.00
0005433615941	25228	Economy	44300.00
0005433616060	25228	Economy	44300.00
0005434273116	25228	Economy	44300.00
0005433578060	25228	Economy	44300.00
0005434151808	25228	Economy	44300.00
0005433634275	25228	Economy	44300.00
0005433578068	25228	Economy	44300.00
0005434152837	25228	Economy	44300.00
0005433615780	25228	Economy	44300.00
0005433634313	25228	Economy	44300.00
0005432751570	25228	Economy	44300.00
0005433615628	25228	Economy	44300.00
0005432755117	25228	Economy	44300.00
0005433578031	25228	Economy	44300.00
0005434272229	25228	Economy	44300.00
0005433615872	25228	Economy	44300.00
0005433615963	25228	Economy	44300.00
0005432751571	25228	Economy	44300.00
0005433615790	25228	Economy	44300.00
0005433616017	25228	Economy	44300.00
0005433615597	25228	Economy	44300.00
0005433615742	25228	Economy	44300.00
0005433578067	25228	Economy	44300.00
0005433615914	25228	Economy	44300.00
0005433634426	25228	Economy	44300.00
0005434151802	25228	Economy	44300.00
0005434163842	25228	Economy	44300.00
0005434151800	25228	Economy	44300.00
0005433615864	25228	Economy	44300.00
0005433616105	25228	Economy	44300.00
0005433615682	25228	Economy	44300.00
0005433615955	25228	Economy	44300.00
0005433615713	25228	Economy	44300.00
0005433615750	25228	Economy	44300.00
0005433615956	25228	Economy	44300.00
0005433634271	25228	Economy	44300.00
0005433615976	25228	Economy	44300.00
0005434163846	25228	Economy	44300.00
0005433615629	25228	Economy	44300.00
0005433578002	25228	Economy	44300.00
0005433616016	25228	Economy	44300.00
0005432751578	25228	Economy	44300.00
0005433615829	25228	Economy	44300.00
0005433615744	25228	Economy	44300.00
0005432755120	25228	Economy	44300.00
0005433634571	25228	Economy	44300.00
0005433615741	25228	Economy	44300.00
0005433616104	25228	Economy	44300.00
0005434163845	25228	Economy	44300.00
0005433634360	25228	Economy	44300.00
0005434152841	25228	Economy	44300.00
0005433616224	25228	Economy	44300.00
0005434163848	25228	Economy	44300.00
0005433634276	25228	Economy	44300.00
0005432755105	25228	Economy	44300.00
0005434151799	25228	Economy	44300.00
0005433578070	25228	Economy	44300.00
0005433615901	25228	Economy	44300.00
0005434151807	25228	Economy	44300.00
0005432751576	25228	Economy	44300.00
0005435986979	4232	Business	193100.00
0005432185022	4232	Business	193100.00
0005435787380	4232	Business	193100.00
0005435986987	4232	Business	193100.00
0005435986975	4232	Business	193100.00
0005435986984	4232	Business	193100.00
0005435986997	4232	Business	193100.00
0005435947530	4232	Business	193100.00
0005435986991	4232	Economy	64400.00
0005435986977	4232	Economy	64400.00
0005435986995	4232	Economy	64400.00
0005432571393	4232	Economy	64400.00
0005432571385	4232	Economy	64400.00
0005435986986	4232	Economy	64400.00
0005435856269	4232	Economy	64400.00
0005435986976	4232	Economy	64400.00
0005432185023	4232	Economy	64400.00
0005434271343	4232	Economy	64400.00
0005435986980	4232	Economy	64400.00
0005435986992	4232	Economy	64400.00
0005432571371	4232	Economy	64400.00
0005435787390	4232	Economy	64400.00
0005435787388	4232	Economy	64400.00
0005435986982	4232	Economy	64400.00
0005432571378	4232	Economy	64400.00
0005435947534	4232	Economy	64400.00
0005435986973	4232	Economy	64400.00
0005432185024	4232	Economy	64400.00
0005434271339	4232	Economy	64400.00
0005435986988	4232	Economy	64400.00
0005435986985	4232	Economy	64400.00
0005435986994	4232	Economy	64400.00
0005432571384	4232	Economy	64400.00
0005435787381	4232	Economy	64400.00
0005435986989	4232	Economy	64400.00
0005435787387	4232	Economy	64400.00
0005435986974	4232	Economy	64400.00
0005432571386	4232	Economy	64400.00
0005435947497	4232	Economy	64400.00
0005435947531	4232	Economy	64400.00
0005435986981	4232	Economy	64400.00
0005435856292	4232	Economy	64400.00
0005435986993	4232	Economy	64400.00
0005435986978	4232	Economy	64400.00
0005435986983	4232	Economy	64400.00
0005435787389	4232	Economy	64400.00
0005435787376	4232	Economy	64400.00
0005435947539	4232	Economy	64400.00
0005435986996	4232	Economy	64400.00
0005435986990	4232	Economy	64400.00
0005435856270	4232	Economy	64400.00
0005432571422	26601	Business	193100.00
0005432571423	26601	Business	193100.00
0005435947628	26601	Business	193100.00
0005435787410	26601	Business	193100.00
0005435856345	26601	Business	193100.00
0005432571420	26601	Economy	70800.00
0005435787411	26601	Economy	64400.00
0005435947629	26601	Economy	64400.00
0005435986826	26601	Economy	64400.00
0005435947634	26601	Economy	64400.00
0005435947631	26601	Economy	64400.00
0005432571421	26601	Economy	64400.00
0005435947625	26601	Economy	64400.00
0005435947623	26601	Economy	64400.00
0005435947627	26601	Economy	64400.00
0005435856347	26601	Economy	64400.00
0005435947635	26601	Economy	64400.00
0005435947633	26601	Economy	64400.00
0005435856344	26601	Economy	64400.00
0005435856346	26601	Economy	64400.00
0005435947632	26601	Economy	64400.00
0005435856312	26601	Economy	64400.00
0005435947630	26601	Economy	64400.00
0005435947624	26601	Economy	64400.00
0005435856313	26601	Economy	64400.00
0005435856314	26601	Economy	64400.00
0005435947626	26601	Economy	64400.00
0005435947636	26601	Economy	64400.00
0005433075100	319	Business	21500.00
0005432948982	319	Business	21500.00
0005432949081	319	Business	21500.00
0005432949217	319	Business	21500.00
0005433570659	319	Business	21500.00
0005432949001	319	Business	21500.00
0005433075151	319	Business	21500.00
0005433570685	319	Business	21500.00
0005433570656	319	Business	21500.00
0005433075244	319	Business	21500.00
0005432949265	319	Business	21500.00
0005433570636	319	Business	21500.00
0005433570639	319	Business	21500.00
0005432949283	319	Business	21500.00
0005433075023	319	Business	21500.00
0005433075301	319	Business	21500.00
0005432239093	319	Business	21500.00
0005432239092	319	Business	21500.00
0005433075178	319	Business	21500.00
0005432948957	319	Business	21500.00
0005433570667	319	Business	21500.00
0005433570679	319	Business	21500.00
0005433570665	319	Business	21500.00
0005432949115	319	Business	21500.00
0005432949124	319	Business	21500.00
0005432949201	319	Business	21500.00
0005432949129	319	Business	21500.00
0005432949213	319	Business	21500.00
0005433075035	319	Economy	7900.00
0005433570644	319	Economy	7900.00
0005433570635	319	Economy	7900.00
0005432949055	319	Economy	7900.00
0005432949106	319	Economy	7900.00
0005432949056	319	Economy	7200.00
0005433075193	319	Economy	7200.00
0005433075248	319	Economy	7200.00
0005433570653	319	Economy	7200.00
0005433075223	319	Economy	7200.00
0005433570642	319	Economy	7200.00
0005433570638	319	Economy	7200.00
0005433570673	319	Economy	7200.00
0005433570669	319	Economy	7200.00
0005433075131	319	Economy	7200.00
0005432949165	319	Economy	7200.00
0005432949212	319	Economy	7200.00
0005433570674	319	Economy	7200.00
0005433570666	319	Economy	7200.00
0005433570678	319	Economy	7200.00
0005433570675	319	Economy	7200.00
0005432949189	319	Economy	7200.00
0005432949037	319	Economy	7200.00
0005433075137	319	Economy	7200.00
0005432949233	319	Economy	7200.00
0005433570650	319	Economy	7200.00
0005432949020	319	Economy	7200.00
0005432949182	319	Economy	7200.00
0005432949102	319	Economy	7200.00
0005433570677	319	Economy	7200.00
0005433075228	319	Economy	7200.00
0005432949161	319	Economy	7200.00
0005432949172	319	Economy	7200.00
0005432949258	319	Economy	7200.00
0005433129325	319	Economy	7200.00
0005433570643	319	Economy	7200.00
0005432949123	319	Economy	7200.00
0005432949264	319	Economy	7200.00
0005432949164	319	Economy	7200.00
0005432949079	319	Economy	7200.00
0005433570651	319	Economy	7200.00
0005432949175	319	Economy	7200.00
0005433570654	319	Economy	7200.00
0005432948955	319	Economy	7200.00
0005433570681	319	Economy	7200.00
0005432949116	319	Economy	7200.00
0005433570661	319	Economy	7200.00
0005433075147	319	Economy	7200.00
0005433570660	319	Economy	7200.00
0005432949069	319	Economy	7200.00
0005433570668	319	Economy	7200.00
0005432948923	319	Economy	7200.00
0005433570646	319	Economy	7200.00
0005432949188	319	Economy	7200.00
0005432239095	319	Economy	7200.00
0005432948956	319	Economy	7200.00
0005433570658	319	Economy	7200.00
0005432239091	319	Economy	7200.00
0005433570670	319	Economy	7200.00
0005432948971	319	Economy	7200.00
0005433570652	319	Economy	7200.00
0005433075279	319	Economy	7900.00
0005433570676	319	Economy	7900.00
0005433075177	319	Economy	7900.00
0005433075146	319	Economy	7900.00
0005433075207	319	Economy	7900.00
0005432239096	319	Economy	7200.00
0005432949162	319	Economy	7200.00
0005432949215	319	Economy	7200.00
0005433570655	319	Economy	7200.00
0005433570649	319	Economy	7900.00
0005432949080	319	Economy	7200.00
0005432949053	319	Economy	7200.00
0005433134202	319	Economy	7200.00
0005432948961	319	Economy	7200.00
0005433134234	319	Economy	7200.00
0005433570682	319	Economy	7200.00
0005432239094	319	Economy	7200.00
0005433075099	319	Economy	7200.00
0005433570647	319	Economy	7200.00
0005433570672	319	Economy	7200.00
0005432949095	319	Economy	7200.00
0005432239090	319	Economy	7200.00
0005432949154	319	Economy	7200.00
0005433075154	319	Economy	7200.00
0005433075150	319	Economy	7200.00
0005433570637	319	Economy	7200.00
0005432949202	319	Economy	7200.00
0005432949130	319	Economy	7200.00
0005432949060	319	Economy	7200.00
0005432949238	319	Economy	7200.00
0005433570662	319	Economy	7200.00
0005433075249	319	Economy	7200.00
0005432949002	319	Economy	7200.00
0005432949225	319	Economy	7200.00
0005433570641	319	Economy	7200.00
0005432949090	319	Economy	7200.00
0005432949181	319	Economy	7200.00
0005433075136	319	Economy	7200.00
0005433570657	319	Economy	7200.00
0005433570663	319	Economy	7200.00
0005432949054	319	Economy	7200.00
0005432949105	319	Economy	7200.00
0005433570648	319	Economy	7200.00
0005433075245	319	Economy	7200.00
0005433570664	319	Economy	7200.00
0005432239097	319	Economy	7200.00
0005432949107	319	Economy	7200.00
0005433075176	319	Economy	7200.00
0005433075156	319	Economy	7200.00
0005433129326	319	Economy	7200.00
0005433570645	319	Economy	7200.00
0005433570683	319	Economy	7200.00
0005433570671	319	Economy	7200.00
0005432949113	319	Economy	7200.00
0005432949007	319	Economy	7200.00
0005432948973	319	Economy	7200.00
0005433075132	319	Economy	7200.00
0005432949031	319	Economy	7200.00
0005433570684	319	Economy	7200.00
0005432949216	319	Economy	7200.00
0005433075153	319	Economy	7200.00
0005433075194	319	Economy	7200.00
0005433570680	319	Economy	7200.00
0005432949234	319	Economy	7200.00
0005432949127	319	Economy	7200.00
0005432949114	319	Economy	7200.00
0005433129327	319	Economy	7200.00
0005432948972	319	Economy	7200.00
0005433570640	319	Economy	7200.00
0005433569903	11609	Business	21500.00
0005433075440	11609	Business	21500.00
0005433569750	11609	Business	21500.00
0005432192402	11609	Business	21500.00
0005432949512	11609	Business	21500.00
0005433569952	11609	Business	21500.00
0005433570004	11609	Business	21500.00
0005433570060	11609	Business	21500.00
0005432949486	11609	Business	21500.00
0005433929873	11609	Business	21500.00
0005433569938	11609	Business	21500.00
0005433075439	11609	Business	21500.00
0005433570015	11609	Business	21500.00
0005433075428	11609	Business	21500.00
0005433569829	11609	Business	21500.00
0005433075438	11609	Business	21500.00
0005433075442	11609	Business	21500.00
0005432949502	11609	Business	21500.00
0005433569968	11609	Business	21500.00
0005432949488	11609	Business	21500.00
0005433569956	11609	Business	21500.00
0005433075431	11609	Business	21500.00
0005433569746	11609	Economy	7900.00
0005433570001	11609	Business	21500.00
0005433569793	11609	Economy	7900.00
0005433569941	11609	Economy	7900.00
0005433569967	11609	Economy	7900.00
0005433569664	11609	Economy	7900.00
0005432949514	11609	Economy	7900.00
0005432949493	11609	Economy	7200.00
0005433570031	11609	Economy	7200.00
0005433569914	11609	Economy	7200.00
0005433570029	11609	Economy	7200.00
0005433075443	11609	Economy	7200.00
0005432192400	11609	Economy	7200.00
0005433569901	11609	Economy	7200.00
0005433570046	11609	Economy	7200.00
0005433075420	11609	Economy	7200.00
0005432949479	11609	Economy	7200.00
0005433929874	11609	Economy	7200.00
0005433134252	11609	Economy	7200.00
0005432949481	11609	Economy	7200.00
0005433075434	11609	Economy	7200.00
0005433929872	11609	Economy	7200.00
0005433569943	11609	Economy	7200.00
0005433075436	11609	Economy	7200.00
0005432949497	11609	Economy	7200.00
0005433570045	11609	Economy	7200.00
0005433570033	11609	Economy	7200.00
0005433075435	11609	Economy	7200.00
0005433569520	11609	Economy	7200.00
0005433075427	11609	Economy	7200.00
0005432949500	11609	Economy	7200.00
0005433569954	11609	Economy	7200.00
0005432949489	11609	Economy	7200.00
0005433075430	11609	Economy	7200.00
0005433569934	11609	Economy	7200.00
0005433569876	11609	Economy	7200.00
0005433570002	11609	Economy	7200.00
0005432949515	11609	Economy	7200.00
0005433569948	11609	Economy	7200.00
0005432949504	11609	Economy	7200.00
0005432949513	11609	Economy	7200.00
0005432949480	11609	Economy	7200.00
0005433569753	11609	Economy	7200.00
0005433131824	11609	Economy	7200.00
0005433075424	11609	Economy	7200.00
0005433569920	11609	Economy	7200.00
0005432949492	11609	Economy	7200.00
0005432949503	11609	Economy	7200.00
0005433569930	11609	Economy	7200.00
0005433570059	11609	Economy	7200.00
0005433570007	11609	Economy	7200.00
0005433075419	11609	Economy	7200.00
0005433569893	11609	Economy	7200.00
0005432949505	11609	Economy	7200.00
0005433570032	11609	Economy	7200.00
0005432949506	11609	Economy	7200.00
0005432949485	11609	Economy	7200.00
0005433569521	11609	Economy	7900.00
0005433569939	11609	Economy	7900.00
0005433075425	11609	Economy	7900.00
0005433569882	11609	Economy	7900.00
0005433569955	11609	Economy	7900.00
0005432949478	11609	Economy	7200.00
0005432949482	11609	Economy	7200.00
0005433569961	11609	Economy	7900.00
0005433075437	11609	Economy	7200.00
0005433134251	11609	Economy	7200.00
0005433569519	11609	Economy	7200.00
0005433569522	11609	Economy	7200.00
0005432949490	11609	Economy	7200.00
0005432949501	11609	Economy	7200.00
0005432192401	11609	Economy	7200.00
0005433131825	11609	Economy	7200.00
0005432949516	11609	Economy	7200.00
0005433075421	11609	Economy	7200.00
0005433569916	11609	Economy	7200.00
0005433569867	11609	Economy	7200.00
0005433570067	11609	Economy	7200.00
0005432949509	11609	Economy	7200.00
0005433075433	11609	Economy	7200.00
0005433075422	11609	Economy	7200.00
0005433569883	11609	Economy	7200.00
0005432949499	11609	Economy	7200.00
0005433570068	11609	Economy	7200.00
0005433929875	11609	Economy	7200.00
0005433569915	11609	Economy	7200.00
0005433569884	11609	Economy	7200.00
0005433569881	11609	Economy	7200.00
0005432949487	11609	Economy	7200.00
0005432949494	11609	Economy	7200.00
0005433075432	11609	Economy	7200.00
0005432949495	11609	Economy	7200.00
0005433569892	11609	Economy	7200.00
0005433131826	11609	Economy	7200.00
0005433075441	11609	Economy	7200.00
0005433569902	11609	Economy	7200.00
0005433569896	11609	Economy	7200.00
0005432949498	11609	Economy	7200.00
0005432949476	11609	Economy	7200.00
0005432949511	11609	Economy	7200.00
0005432949483	11609	Economy	7200.00
0005432949477	11609	Economy	7200.00
0005432949507	11609	Economy	7200.00
0005432949491	11609	Economy	7200.00
0005433075429	11609	Economy	7200.00
0005432949510	11609	Economy	7200.00
0005433569665	11609	Economy	7200.00
0005433075426	11609	Economy	7200.00
0005432949496	11609	Economy	7200.00
0005432949508	11609	Economy	7200.00
0005433075423	11609	Economy	7200.00
0005433569850	11609	Economy	7200.00
0005433569751	11609	Economy	7200.00
0005433569752	11609	Economy	7200.00
0005433569953	11609	Economy	7200.00
0005433569899	11609	Economy	7200.00
0005432949484	11609	Economy	7200.00
0005434733058	9985	Economy	6300.00
0005434733059	9985	Economy	6300.00
0005433817566	9985	Economy	6300.00
0005434733043	9985	Economy	6300.00
0005434733054	9985	Economy	6300.00
0005433817538	13907	Economy	6300.00
0005434733072	13907	Economy	6300.00
0005433817531	13907	Economy	6300.00
0005433817544	13907	Economy	6300.00
0005433817519	13907	Economy	6300.00
0005434733071	13907	Economy	6300.00
0005434733073	13907	Economy	6300.00
0005433817546	13907	Economy	6300.00
0005433817545	13907	Economy	6300.00
0005433817509	13907	Economy	6300.00
0005435983482	2340	Business	184500.00
0005433435249	2340	Business	184500.00
0005433435110	2340	Business	184500.00
0005432655839	2340	Business	184500.00
0005433755657	2340	Business	184500.00
0005433435318	2340	Business	184500.00
0005433766738	2340	Business	184500.00
0005435983479	2340	Business	184500.00
0005435983494	2340	Business	184500.00
0005433435078	2340	Business	184500.00
0005435983484	2340	Business	184500.00
0005432985626	2340	Business	184500.00
0005432985685	2340	Business	184500.00
0005432226218	2340	Business	184500.00
0005434731241	2340	Business	184500.00
0005433755636	2340	Business	184500.00
0005432655844	2340	Business	184500.00
0005435983467	2340	Business	184500.00
0005435983464	2340	Business	184500.00
0005432985488	2340	Business	184500.00
0005432655846	2340	Business	184500.00
0005433755676	2340	Business	184500.00
0005433755643	2340	Business	184500.00
0005432985633	2340	Business	184500.00
0005433755686	2340	Business	184500.00
0005433435115	2340	Business	184500.00
0005432655848	2340	Business	184500.00
0005433435030	2340	Business	184500.00
0005432985707	2340	Economy	67700.00
0005433435191	2340	Economy	67700.00
0005435983468	2340	Economy	67700.00
0005434731245	2340	Economy	61500.00
0005432985546	2340	Economy	61500.00
0005435983466	2340	Economy	61500.00
0005433764733	2340	Economy	61500.00
0005433755685	2340	Economy	61500.00
0005435983450	2340	Economy	61500.00
0005433755659	2340	Economy	61500.00
0005432985716	2340	Economy	61500.00
0005435983488	2340	Economy	61500.00
0005432985695	2340	Economy	61500.00
0005432985725	2340	Economy	61500.00
0005433755661	2340	Economy	61500.00
0005435983449	2340	Economy	61500.00
0005433435153	2340	Economy	61500.00
0005433435109	2340	Economy	61500.00
0005432869608	2340	Economy	61500.00
0005433755632	2340	Economy	61500.00
0005435983497	2340	Economy	61500.00
0005432226217	2340	Economy	61500.00
0005435983489	2340	Economy	61500.00
0005432869647	2340	Economy	61500.00
0005433755667	2340	Economy	61500.00
0005432655851	2340	Economy	61500.00
0005432300413	2340	Economy	61500.00
0005432985677	2340	Economy	61500.00
0005435983491	2340	Economy	61500.00
0005435983474	2340	Economy	61500.00
0005432985678	2340	Economy	61500.00
0005433755687	2340	Economy	61500.00
0005432226213	2340	Economy	61500.00
0005432985686	2340	Economy	61500.00
0005433755674	2340	Economy	61500.00
0005432985504	2340	Economy	61500.00
0005433755650	2340	Economy	61500.00
0005432655845	2340	Economy	61500.00
0005432985638	2340	Economy	61500.00
0005435983465	2340	Economy	61500.00
0005435983458	2340	Economy	61500.00
0005433755641	2340	Economy	61500.00
0005433755666	2340	Economy	61500.00
0005432655849	2340	Economy	61500.00
0005433755680	2340	Economy	61500.00
0005433755663	2340	Economy	61500.00
0005435983459	2340	Economy	61500.00
0005433755644	2340	Economy	61500.00
0005435983495	2340	Economy	61500.00
0005433755639	2340	Economy	61500.00
0005435983490	2340	Economy	61500.00
0005433755684	2340	Economy	61500.00
0005435983456	2340	Economy	61500.00
0005432869634	2340	Economy	61500.00
0005433755637	2340	Economy	61500.00
0005435983476	2340	Economy	61500.00
0005435983462	2340	Economy	61500.00
0005433755679	2340	Economy	61500.00
0005432226216	2340	Economy	61500.00
0005433435138	2340	Economy	61500.00
0005433755642	2340	Economy	61500.00
0005433755635	2340	Economy	61500.00
0005433435248	2340	Economy	61500.00
0005433755670	2340	Economy	61500.00
0005433435154	2340	Economy	61500.00
0005432869609	2340	Economy	61500.00
0005433755645	2340	Economy	61500.00
0005432655842	2340	Economy	61500.00
0005433755656	2340	Economy	61500.00
0005433435233	2340	Economy	61500.00
0005433435263	2340	Economy	61500.00
0005435983475	2340	Economy	61500.00
0005432300412	2340	Economy	61500.00
0005435983463	2340	Economy	61500.00
0005432985790	2340	Economy	61500.00
0005433755655	2340	Economy	61500.00
0005432655840	2340	Economy	61500.00
0005435983481	2340	Economy	61500.00
0005432869623	2340	Economy	61500.00
0005435983452	2340	Economy	61500.00
0005432985590	2340	Economy	61500.00
0005432985706	2340	Economy	61500.00
0005433755652	2340	Economy	61500.00
0005432985690	2340	Economy	61500.00
0005435983478	2340	Economy	61500.00
0005432869624	2340	Economy	61500.00
0005435983472	2340	Economy	61500.00
0005433435164	2340	Economy	61500.00
0005433755677	2340	Economy	61500.00
0005432985726	2340	Economy	61500.00
0005435983471	2340	Economy	61500.00
0005433766737	2340	Economy	61500.00
0005433755683	2340	Economy	61500.00
0005433755633	2340	Economy	61500.00
0005432985647	2340	Economy	61500.00
0005432985570	2340	Economy	61500.00
0005433755672	2340	Economy	61500.00
0005435983483	2340	Economy	67700.00
0005432869625	2340	Economy	67700.00
0005435983487	2340	Economy	61500.00
0005435983451	2340	Economy	61500.00
0005432985503	2340	Economy	67700.00
0005433755682	2340	Economy	67700.00
0005435983457	2340	Economy	61500.00
0005435983486	2340	Economy	61500.00
0005435983496	2340	Economy	61500.00
0005433755669	2340	Economy	61500.00
0005433755648	2340	Economy	61500.00
0005432985571	2340	Economy	61500.00
0005433755660	2340	Economy	61500.00
0005432985696	2340	Economy	61500.00
0005433755653	2340	Economy	61500.00
0005435983470	2340	Economy	61500.00
0005433755647	2340	Economy	61500.00
0005432655847	2340	Economy	61500.00
0005433755673	2340	Economy	61500.00
0005433434961	2340	Economy	61500.00
0005432985682	2340	Economy	61500.00
0005435983469	2340	Economy	61500.00
0005432985574	2340	Economy	61500.00
0005433755671	2340	Economy	61500.00
0005434731258	2340	Economy	61500.00
0005433435234	2340	Economy	61500.00
0005432985754	2340	Economy	61500.00
0005433435190	2340	Economy	61500.00
0005433755631	2340	Economy	61500.00
0005433435079	2340	Economy	61500.00
0005433435029	2340	Economy	61500.00
0005435983461	2340	Economy	61500.00
0005432985505	2340	Economy	61500.00
0005435983455	2340	Economy	61500.00
0005432869660	2340	Economy	61500.00
0005432985554	2340	Economy	61500.00
0005435983485	2340	Economy	61500.00
0005433755665	2340	Economy	61500.00
0005435983493	2340	Economy	61500.00
0005435983477	2340	Economy	61500.00
0005435983460	2340	Economy	61500.00
0005433764732	2340	Economy	61500.00
0005433755651	2340	Economy	61500.00
0005432869626	2340	Economy	61500.00
0005432985568	2340	Economy	61500.00
0005435983454	2340	Economy	61500.00
0005433755668	2340	Economy	61500.00
0005434731246	2340	Economy	61500.00
0005433755664	2340	Economy	61500.00
0005433755662	2340	Economy	61500.00
0005432985612	2340	Economy	61500.00
0005433755658	2340	Economy	61500.00
0005432985506	2340	Economy	61500.00
0005433755675	2340	Economy	61500.00
0005432655843	2340	Economy	61500.00
0005432226215	2340	Economy	61500.00
0005432985634	2340	Economy	61500.00
0005433755649	2340	Economy	61500.00
0005433755646	2340	Economy	61500.00
0005432985579	2340	Economy	61500.00
0005432985569	2340	Economy	61500.00
0005433755681	2340	Economy	61500.00
0005435983473	2340	Economy	61500.00
0005433755638	2340	Economy	61500.00
0005432869607	2340	Economy	61500.00
0005432985648	2340	Economy	61500.00
0005433755654	2340	Economy	61500.00
0005432300414	2340	Economy	61500.00
0005432869653	2340	Economy	61500.00
0005433755640	2340	Economy	61500.00
0005432655850	2340	Economy	61500.00
0005433435099	2340	Economy	61500.00
0005432985639	2340	Economy	61500.00
0005432226214	2340	Economy	61500.00
0005433755634	2340	Economy	61500.00
0005432869646	2340	Economy	61500.00
0005433766736	2340	Economy	61500.00
0005435983480	2340	Economy	61500.00
0005432985753	2340	Economy	61500.00
0005435983453	2340	Economy	61500.00
0005433435131	2340	Economy	61500.00
0005432655841	2340	Economy	61500.00
0005433755678	2340	Economy	61500.00
0005435983492	2340	Economy	61500.00
0005433755157	26176	Business	184500.00
0005433755368	26176	Business	184500.00
0005435983139	26176	Business	184500.00
0005434731280	26176	Business	184500.00
0005433755123	26176	Business	184500.00
0005432869689	26176	Business	184500.00
0005433755018	26176	Business	184500.00
0005435982893	26176	Business	184500.00
0005435983191	26176	Business	184500.00
0005433766706	26176	Business	184500.00
0005432869693	26176	Business	184500.00
0005433754873	26176	Business	184500.00
0005433754987	26176	Business	184500.00
0005432985905	26176	Business	184500.00
0005433755002	26176	Business	184500.00
0005433435404	26176	Business	184500.00
0005432051208	26176	Business	184500.00
0005435982975	26176	Business	184500.00
0005435982935	26176	Business	184500.00
0005435982922	26176	Business	184500.00
0005432985906	26176	Business	184500.00
0005433755215	26176	Business	184500.00
0005433435383	26176	Business	184500.00
0005435982963	26176	Business	184500.00
0005432985890	26176	Business	184500.00
0005433755100	26176	Business	184500.00
0005433755189	26176	Business	184500.00
0005432985915	26176	Economy	67700.00
0005432985904	26176	Economy	67700.00
0005435983094	26176	Economy	67700.00
0005435983044	26176	Economy	67700.00
0005433755162	26176	Economy	61500.00
0005435982844	26176	Economy	61500.00
0005435983071	26176	Economy	61500.00
0005435983132	26176	Economy	61500.00
0005433766695	26176	Economy	61500.00
0005433435388	26176	Economy	61500.00
0005435983146	26176	Economy	61500.00
0005433435402	26176	Economy	61500.00
0005433766705	26176	Economy	61500.00
0005435983051	26176	Economy	61500.00
0005435983053	26176	Economy	61500.00
0005433755042	26176	Economy	61500.00
0005433435384	26176	Economy	61500.00
0005432985891	26176	Economy	61500.00
0005432985901	26176	Economy	61500.00
0005433755226	26176	Economy	61500.00
0005433754951	26176	Economy	61500.00
0005433435390	26176	Economy	61500.00
0005433764715	26176	Economy	61500.00
0005433755190	26176	Economy	61500.00
0005433435389	26176	Economy	61500.00
0005435982971	26176	Economy	61500.00
0005433755181	26176	Economy	61500.00
0005435982654	26176	Economy	61500.00
0005432655732	26176	Economy	61500.00
0005432985894	26176	Economy	61500.00
0005435983022	26176	Economy	61500.00
0005435983048	26176	Economy	61500.00
0005432985899	26176	Economy	61500.00
0005433755225	26176	Economy	61500.00
0005433435385	26176	Economy	61500.00
0005432655714	26176	Economy	61500.00
0005432985919	26176	Economy	61500.00
0005433435403	26176	Economy	61500.00
0005433755245	26176	Economy	61500.00
0005433755211	26176	Economy	61500.00
0005435983102	26176	Economy	61500.00
0005432985892	26176	Economy	61500.00
0005433755019	26176	Economy	61500.00
0005435983023	26176	Economy	61500.00
0005433755007	26176	Economy	61500.00
0005432655684	26176	Economy	61500.00
0005433435391	26176	Economy	61500.00
0005433435398	26176	Economy	61500.00
0005435983141	26176	Economy	61500.00
0005432985911	26176	Economy	61500.00
0005433755290	26176	Economy	61500.00
0005433755064	26176	Economy	61500.00
0005432985909	26176	Economy	61500.00
0005432049556	26176	Economy	61500.00
0005433755191	26176	Economy	61500.00
0005432869691	26176	Economy	61500.00
0005432985893	26176	Economy	61500.00
0005434731278	26176	Economy	61500.00
0005434731281	26176	Economy	61500.00
0005435983006	26176	Economy	61500.00
0005432985916	26176	Economy	61500.00
0005432655708	26176	Economy	61500.00
0005432985914	26176	Economy	61500.00
0005433755291	26176	Economy	61500.00
0005435983026	26176	Economy	61500.00
0005433435387	26176	Economy	61500.00
0005433754949	26176	Economy	61500.00
0005435982859	26176	Economy	61500.00
0005433755257	26176	Economy	61500.00
0005435983074	26176	Economy	61500.00
0005433766703	26176	Economy	61500.00
0005433755418	26176	Economy	61500.00
0005435983161	26176	Economy	61500.00
0005435983046	26176	Economy	61500.00
0005435983037	26176	Economy	61500.00
0005435983073	26176	Economy	61500.00
0005433755099	26176	Economy	61500.00
0005432985908	26176	Economy	61500.00
0005435983027	26176	Economy	61500.00
0005435983052	26176	Economy	61500.00
0005432655733	26176	Economy	61500.00
0005433435394	26176	Economy	61500.00
0005433766702	26176	Economy	61500.00
0005432655743	26176	Economy	61500.00
0005432869692	26176	Economy	61500.00
0005433754956	26176	Economy	61500.00
0005435982970	26176	Economy	61500.00
0005435982909	26176	Economy	61500.00
0005433435393	26176	Economy	61500.00
0005433435400	26176	Economy	61500.00
0005435983045	26176	Economy	61500.00
0005433755081	26176	Economy	61500.00
0005435983032	26176	Economy	61500.00
0005433435386	26176	Economy	61500.00
0005435983040	26176	Economy	61500.00
0005435982910	26176	Economy	61500.00
0005433755216	26176	Economy	61500.00
0005435983028	26176	Economy	61500.00
0005435982791	26176	Economy	61500.00
0005434731282	26176	Economy	67700.00
0005433435399	26176	Economy	67700.00
0005432985910	26176	Economy	61500.00
0005432985912	26176	Economy	61500.00
0005433755441	26176	Economy	61500.00
0005432655718	26176	Economy	67700.00
0005432985897	26176	Economy	67700.00
0005435982880	26176	Economy	61500.00
0005433755264	26176	Economy	61500.00
0005435982887	26176	Economy	61500.00
0005433754950	26176	Economy	61500.00
0005435983041	26176	Economy	61500.00
0005433755504	26176	Economy	61500.00
0005433755078	26176	Economy	61500.00
0005433755251	26176	Economy	61500.00
0005432655713	26176	Economy	61500.00
0005432985902	26176	Economy	61500.00
0005433755252	26176	Economy	61500.00
0005433755163	26176	Economy	61500.00
0005433435395	26176	Economy	61500.00
0005433755419	26176	Economy	61500.00
0005433435405	26176	Economy	61500.00
0005433755160	26176	Economy	61500.00
0005432869694	26176	Economy	61500.00
0005435983092	26176	Economy	61500.00
0005432985918	26176	Economy	61500.00
0005432049557	26176	Economy	61500.00
0005433755212	26176	Economy	61500.00
0005432985907	26176	Economy	61500.00
0005435983108	26176	Economy	61500.00
0005432985917	26176	Economy	61500.00
0005433755180	26176	Economy	61500.00
0005435982851	26176	Economy	61500.00
0005433435396	26176	Economy	61500.00
0005435983029	26176	Economy	61500.00
0005433435392	26176	Economy	61500.00
0005433754874	26176	Economy	61500.00
0005433755214	26176	Economy	61500.00
0005432655731	26176	Economy	61500.00
0005433755401	26176	Economy	61500.00
0005433755159	26176	Economy	61500.00
0005435983126	26176	Economy	61500.00
0005432985920	26176	Economy	61500.00
0005433755253	26176	Economy	61500.00
0005432985895	26176	Economy	61500.00
0005433755128	26176	Economy	61500.00
0005435983030	26176	Economy	61500.00
0005435983066	26176	Economy	61500.00
0005432869690	26176	Economy	61500.00
0005432985903	26176	Economy	61500.00
0005433755120	26176	Economy	61500.00
0005435983075	26176	Economy	61500.00
0005435982888	26176	Economy	61500.00
0005433755145	26176	Economy	61500.00
0005433755063	26176	Economy	61500.00
0005432869695	26176	Economy	61500.00
0005432051207	26176	Economy	61500.00
0005432985921	26176	Economy	61500.00
0005433755292	26176	Economy	61500.00
0005432985898	26176	Economy	61500.00
0005433755440	26176	Economy	61500.00
0005432985913	26176	Economy	61500.00
0005433755139	26176	Economy	61500.00
0005435983140	26176	Economy	61500.00
0005433435406	26176	Economy	61500.00
0005432985900	26176	Economy	61500.00
0005433755205	26176	Economy	61500.00
0005432049555	26176	Economy	61500.00
0005433754975	26176	Economy	61500.00
0005433755217	26176	Economy	61500.00
0005433766696	26176	Economy	61500.00
0005433435401	26176	Economy	61500.00
0005433755200	26176	Economy	61500.00
0005433754986	26176	Economy	61500.00
0005433435408	26176	Economy	61500.00
0005432985896	26176	Economy	61500.00
0005434731279	26176	Economy	61500.00
0005435983131	26176	Economy	61500.00
0005433435397	26176	Economy	61500.00
0005435983093	26176	Economy	61500.00
0005433764711	26176	Economy	61500.00
0005432051209	26176	Economy	61500.00
0005433435407	26176	Economy	61500.00
0005434375812	1533	Business	38900.00
0005434375826	1533	Business	38900.00
0005433152085	1533	Business	38900.00
0005434375816	1533	Business	38900.00
0005434375811	1533	Business	38900.00
0005433151924	1533	Business	38900.00
0005432268068	1533	Business	38900.00
0005434375833	1533	Business	38900.00
0005434375831	1533	Business	38900.00
0005433152069	1533	Business	38900.00
0005432268069	1533	Business	38900.00
0005433151967	1533	Business	38900.00
0005434375819	1533	Economy	13000.00
0005434375852	1533	Economy	13000.00
0005433151999	1533	Economy	13000.00
0005434375815	1533	Economy	13000.00
0005432268064	1533	Economy	13000.00
0005433764704	1533	Economy	13000.00
0005434375835	1533	Economy	13000.00
0005433151923	1533	Economy	13000.00
0005433152089	1533	Economy	13000.00
0005434375856	1533	Economy	13000.00
0005433151952	1533	Economy	13000.00
0005434375827	1533	Economy	13000.00
0005433151919	1533	Economy	13000.00
0005433460491	1533	Economy	13000.00
0005433151946	1533	Economy	13000.00
0005433151997	1533	Economy	13000.00
0005434375837	1533	Economy	13000.00
0005434375832	1533	Economy	13000.00
0005433931523	1533	Economy	13000.00
0005434029700	1533	Economy	13000.00
0005433152028	1533	Economy	13000.00
0005433151968	1533	Economy	13000.00
0005434375825	1533	Economy	13000.00
0005434375814	1533	Economy	13000.00
0005434375840	1533	Economy	13000.00
0005434375810	1533	Economy	13000.00
0005434375847	1533	Economy	13000.00
0005434375820	1533	Economy	13000.00
0005434375855	1533	Economy	13000.00
0005433152090	1533	Economy	13000.00
0005433151990	1533	Economy	14300.00
0005433152044	1533	Economy	14300.00
0005432268067	1533	Economy	14300.00
0005434375818	1533	Economy	14300.00
0005434029694	1533	Economy	13000.00
0005434375844	1533	Economy	13000.00
0005433152068	1533	Economy	13000.00
0005433460492	1533	Economy	13000.00
0005432268071	1533	Economy	13000.00
0005434375853	1533	Economy	13000.00
0005434375817	1533	Economy	13000.00
0005434375850	1533	Economy	13000.00
0005434375839	1533	Economy	13000.00
0005434375841	1533	Economy	13000.00
0005434375836	1533	Economy	13000.00
0005434375822	1533	Economy	13000.00
0005434375828	1533	Economy	13000.00
0005434029698	1533	Economy	13000.00
0005433151989	1533	Economy	13000.00
0005434375830	1533	Economy	13000.00
0005433461645	1533	Economy	13000.00
0005432268066	1533	Economy	13000.00
0005433152033	1533	Economy	13000.00
0005434375821	1533	Economy	13000.00
0005433152036	1533	Economy	13000.00
0005433764714	1533	Economy	13000.00
0005433151918	1533	Economy	13000.00
0005432268070	1533	Economy	13000.00
0005433152061	1533	Economy	13000.00
0005434375843	1533	Economy	13000.00
0005434375834	1533	Economy	13000.00
0005433764723	1533	Economy	13000.00
0005432268065	1533	Economy	13000.00
0005434375851	1533	Economy	13000.00
0005434375823	1533	Economy	13000.00
0005433152155	1533	Economy	13000.00
0005433152046	1533	Economy	13000.00
0005434029685	1533	Economy	13000.00
0005434375854	1533	Economy	13000.00
0005433931521	1533	Economy	13000.00
0005434375849	1533	Economy	13000.00
0005434375829	1533	Economy	13000.00
0005433152091	1533	Economy	13000.00
0005433152045	1533	Economy	13000.00
0005433152001	1533	Economy	13000.00
0005433152022	1533	Economy	13000.00
0005433151951	1533	Economy	13000.00
0005433152021	1533	Economy	13000.00
0005433152029	1533	Economy	13000.00
0005434375838	1533	Economy	13000.00
0005433931514	1533	Economy	13000.00
0005433764706	1533	Economy	13000.00
0005434375848	1533	Economy	13000.00
0005434375813	1533	Economy	13000.00
0005434375842	1533	Economy	13000.00
0005433152067	1533	Economy	13000.00
0005434375824	1533	Economy	13000.00
0005433152017	1533	Economy	13000.00
0005434029699	1533	Economy	13000.00
0005433461644	1533	Economy	13000.00
0005434375845	1533	Economy	13000.00
0005433764705	1533	Economy	13000.00
0005433151896	1533	Economy	13000.00
0005433151993	1533	Economy	13000.00
0005434375846	1533	Economy	13000.00
0005433931544	20103	Business	38900.00
0005433152282	20103	Business	38900.00
0005433152285	20103	Business	38900.00
0005433152279	20103	Business	38900.00
0005434029722	20103	Business	38900.00
0005433152271	20103	Business	38900.00
0005434375496	20103	Business	38900.00
0005434375473	20103	Business	38900.00
0005433152297	20103	Business	38900.00
0005433152272	20103	Business	38900.00
0005433152270	20103	Economy	13000.00
0005433152286	20103	Economy	13000.00
0005434375325	20103	Economy	13000.00
0005434375530	20103	Economy	13000.00
0005433152281	20103	Economy	13000.00
0005434375255	20103	Economy	13000.00
0005433152288	20103	Economy	13000.00
0005434375541	20103	Economy	13000.00
0005434375445	20103	Economy	13000.00
0005433152269	20103	Economy	13000.00
0005433152296	20103	Economy	13000.00
0005434375384	20103	Economy	13000.00
0005433152278	20103	Economy	13000.00
0005433152273	20103	Economy	13000.00
0005434375242	20103	Economy	13000.00
0005433152301	20103	Economy	13000.00
0005433152291	20103	Economy	13000.00
0005433152298	20103	Economy	13000.00
0005434375254	20103	Economy	13000.00
0005434375540	20103	Economy	13000.00
0005433931546	20103	Economy	13000.00
0005433152287	20103	Economy	13000.00
0005434375387	20103	Economy	13000.00
0005434375341	20103	Economy	13000.00
0005434375468	20103	Economy	13000.00
0005434375385	20103	Economy	14300.00
0005432056395	20103	Economy	14300.00
0005432056396	20103	Economy	14300.00
0005433152275	20103	Economy	14300.00
0005434375505	20103	Economy	13000.00
0005433152280	20103	Economy	13000.00
0005434375443	20103	Economy	13000.00
0005433152277	20103	Economy	13000.00
0005432056398	20103	Economy	13000.00
0005433152299	20103	Economy	13000.00
0005434375315	20103	Economy	13000.00
0005434375631	20103	Economy	13000.00
0005434375260	20103	Economy	13000.00
0005434375545	20103	Economy	13000.00
0005434375415	20103	Economy	13000.00
0005433152283	20103	Economy	13000.00
0005434375359	20103	Economy	13000.00
0005434029720	20103	Economy	13000.00
0005434375544	20103	Economy	13000.00
0005433931547	20103	Economy	13000.00
0005433152290	20103	Economy	13000.00
0005433152294	20103	Economy	13000.00
0005434375389	20103	Economy	13000.00
0005434375212	20103	Economy	13000.00
0005432056397	20103	Economy	13000.00
0005434375261	20103	Economy	13000.00
0005433152284	20103	Economy	13000.00
0005433152268	20103	Economy	13000.00
0005433152276	20103	Economy	13000.00
0005433764733	20103	Economy	13000.00
0005433152274	20103	Economy	13000.00
0005434375211	20103	Economy	13000.00
0005434375552	20103	Economy	13000.00
0005433152295	20103	Economy	13000.00
0005434375247	20103	Economy	13000.00
0005433764732	20103	Economy	13000.00
0005433152292	20103	Economy	13000.00
0005434375390	20103	Economy	13000.00
0005433931545	20103	Economy	13000.00
0005434375417	20103	Economy	13000.00
0005434375581	20103	Economy	13000.00
0005433152300	20103	Economy	13000.00
0005434375303	20103	Economy	13000.00
0005434375408	20103	Economy	13000.00
0005434375282	20103	Economy	13000.00
0005434375500	20103	Economy	13000.00
0005434375256	20103	Economy	13000.00
0005434375393	20103	Economy	13000.00
0005434375455	20103	Economy	13000.00
0005434029721	20103	Economy	13000.00
0005434375396	20103	Economy	13000.00
0005434375283	20103	Economy	13000.00
0005434375479	20103	Economy	13000.00
0005434375526	20103	Economy	13000.00
0005434375493	20103	Economy	13000.00
0005433152293	20103	Economy	13000.00
0005434375594	20103	Economy	13000.00
0005433152289	20103	Economy	13000.00
0005432283047	552	Business	27500.00
0005432425670	552	Business	27500.00
0005432425703	552	Business	27500.00
0005432425694	552	Business	27500.00
0005432283043	552	Business	27500.00
0005432425677	552	Business	27500.00
0005432425709	552	Business	27500.00
0005432425666	552	Business	27500.00
0005432425686	552	Economy	10100.00
0005432425692	552	Economy	10100.00
0005432425704	552	Economy	9200.00
0005432425695	552	Economy	9200.00
0005432425674	552	Economy	9200.00
0005432425683	552	Economy	9200.00
0005432425696	552	Economy	9200.00
0005432425680	552	Economy	9200.00
0005432283044	552	Economy	9200.00
0005432425664	552	Economy	9200.00
0005432425665	552	Economy	9200.00
0005432425678	552	Economy	9200.00
0005432425697	552	Economy	9200.00
0005432425706	552	Economy	9200.00
0005432425684	552	Economy	9200.00
0005432425688	552	Economy	9200.00
0005432425675	552	Economy	9200.00
0005432283046	552	Economy	9200.00
0005432425689	552	Economy	9200.00
0005432283045	552	Economy	9200.00
0005432425669	552	Economy	9200.00
0005432425679	552	Economy	9200.00
0005432425662	552	Economy	9200.00
0005432425702	552	Economy	9200.00
0005432425707	552	Economy	10100.00
0005432283042	552	Economy	9200.00
0005432425682	552	Economy	9200.00
0005432425690	552	Economy	9200.00
0005432425693	552	Economy	9200.00
0005432425667	552	Economy	9200.00
0005432425681	552	Economy	9200.00
0005432425676	552	Economy	9200.00
0005432425663	552	Economy	9200.00
0005432425701	552	Economy	9200.00
0005432425673	552	Economy	9200.00
0005432425687	552	Economy	9200.00
0005432425671	552	Economy	9200.00
0005432425710	552	Economy	9200.00
0005432425685	552	Economy	9200.00
0005432425672	552	Economy	9200.00
0005432425668	552	Economy	9200.00
0005432425711	552	Economy	9200.00
0005432425661	552	Economy	9200.00
0005432425700	552	Economy	9200.00
0005432425698	552	Economy	9200.00
0005432425708	552	Economy	9200.00
0005432425699	552	Economy	9200.00
0005432425705	552	Economy	9200.00
0005432425691	552	Economy	9200.00
0005433157013	12902	Business	27500.00
0005433261929	12902	Business	27500.00
0005433261941	12902	Business	27500.00
0005433158184	12902	Economy	10100.00
0005432302428	12902	Economy	9200.00
0005433261932	12902	Economy	9200.00
0005433261930	12902	Economy	9200.00
0005433261937	12902	Economy	9200.00
0005433261925	12902	Economy	9200.00
0005432302427	12902	Economy	9200.00
0005433261936	12902	Economy	9200.00
0005433157012	12902	Economy	9200.00
0005433261943	12902	Economy	9200.00
0005433261926	12902	Economy	9200.00
0005433261942	12902	Economy	9200.00
0005433261939	12902	Economy	9200.00
0005433261940	12902	Economy	9200.00
0005433261924	12902	Economy	9200.00
0005433158186	12902	Economy	9200.00
0005433157015	12902	Economy	10100.00
0005433261935	12902	Economy	10100.00
0005432302426	12902	Economy	10100.00
0005433261938	12902	Economy	9200.00
0005433261927	12902	Economy	9200.00
0005433261933	12902	Economy	9200.00
0005432302429	12902	Economy	9200.00
0005433261928	12902	Economy	9200.00
0005434446552	12902	Economy	9200.00
0005433157011	12902	Economy	9200.00
0005433158189	12902	Economy	9200.00
0005433158185	12902	Economy	9200.00
0005433158187	12902	Economy	9200.00
0005433261934	12902	Economy	9200.00
0005433261931	12902	Economy	9200.00
0005433158190	12902	Economy	9200.00
0005433157014	12902	Economy	9200.00
0005433158188	12902	Economy	9200.00
0005432425029	12925	Business	27500.00
0005432425184	12925	Business	27500.00
0005432425252	12925	Business	27500.00
0005432425060	12925	Business	27500.00
0005432425234	12925	Business	27500.00
0005432425241	12925	Business	27500.00
0005432425264	12925	Economy	10100.00
0005432425242	12925	Economy	10100.00
0005432425210	12925	Economy	9200.00
0005432424947	12925	Economy	9200.00
0005432425118	12925	Economy	9200.00
0005432425232	12925	Economy	9200.00
0005432425183	12925	Economy	9200.00
0005432425025	12925	Economy	9200.00
0005432425259	12925	Economy	9200.00
0005432425161	12925	Economy	9200.00
0005432425277	12925	Economy	9200.00
0005432425265	12925	Economy	9200.00
0005432425200	12925	Economy	9200.00
0005432425098	12925	Economy	9200.00
0005432425105	12925	Economy	9200.00
0005432425233	12925	Economy	9200.00
0005432425258	12925	Economy	9200.00
0005432425243	12925	Economy	9200.00
0005432425209	12925	Economy	9200.00
0005432425061	12925	Economy	9200.00
0005432425211	12925	Economy	9200.00
0005432425155	12925	Economy	9200.00
0005432425185	12925	Economy	10100.00
0005432425215	12925	Economy	10100.00
0005432425235	12925	Economy	10100.00
0005432425174	12925	Economy	10100.00
0005432425227	12925	Economy	9200.00
0005432425204	12925	Economy	9200.00
0005432425193	12925	Economy	10100.00
0005432425240	12925	Economy	9200.00
0005432425274	12925	Economy	9200.00
0005432425188	12925	Economy	9200.00
0005432425282	12925	Economy	9200.00
0005432425099	12925	Economy	9200.00
0005432425281	12925	Economy	9200.00
0005432425219	12925	Economy	9200.00
0005432425154	12925	Economy	9200.00
0005432425095	12925	Economy	9200.00
0005432425239	12925	Economy	9200.00
0005432425283	12925	Economy	9200.00
0005432425216	12925	Economy	9200.00
0005432425162	12925	Economy	9200.00
0005432425266	12925	Economy	9200.00
0005432425071	12925	Economy	9200.00
0005432425273	12925	Economy	9200.00
0005432425030	12925	Economy	9200.00
0005432425182	12925	Economy	9200.00
0005432425120	12925	Economy	9200.00
0005432425187	12925	Economy	9200.00
0005432425014	12925	Economy	9200.00
0005432425203	12925	Economy	9200.00
0005432425228	12925	Economy	9200.00
0005432425208	12925	Economy	9200.00
0005434028379	463	Business	24500.00
0005434025430	463	Business	24500.00
0005434025412	463	Business	24500.00
0005434025453	463	Business	24500.00
0005434029717	463	Business	24500.00
0005434025414	463	Business	24500.00
0005434025437	463	Business	24500.00
0005434025439	463	Business	24500.00
0005433058540	463	Business	24500.00
0005433058626	463	Business	24500.00
0005433058612	463	Business	24500.00
0005434025420	463	Business	24500.00
0005433058586	463	Business	24500.00
0005434025465	463	Business	24500.00
0005434735744	463	Business	24500.00
0005434025436	463	Business	24500.00
0005434735773	463	Business	24500.00
0005432045662	463	Business	24500.00
0005434025444	463	Business	24500.00
0005434735778	463	Business	24500.00
0005432235830	463	Business	24500.00
0005434025419	463	Economy	9000.00
0005433058500	463	Economy	9000.00
0005434025466	463	Economy	8200.00
0005434735762	463	Economy	8200.00
0005434025458	463	Economy	8200.00
0005434025421	463	Economy	8200.00
0005433058614	463	Economy	8200.00
0005434025445	463	Economy	8200.00
0005433058499	463	Economy	8200.00
0005434025456	463	Economy	8200.00
0005434025433	463	Economy	8200.00
0005434025429	463	Economy	8200.00
0005434735779	463	Economy	8200.00
0005434025454	463	Economy	8200.00
0005434025462	463	Economy	8200.00
0005434025457	463	Economy	8200.00
0005433058623	463	Economy	8200.00
0005433058636	463	Economy	8200.00
0005433058671	463	Economy	8200.00
0005433684450	463	Economy	8200.00
0005433058549	463	Economy	8200.00
0005434025463	463	Economy	8200.00
0005433058628	463	Economy	8200.00
0005433058491	463	Economy	8200.00
0005434025448	463	Economy	8200.00
0005434025422	463	Economy	8200.00
0005433058509	463	Economy	8200.00
0005434032138	463	Economy	8200.00
0005433058551	463	Economy	8200.00
0005433058687	463	Economy	8200.00
0005433058688	463	Economy	8200.00
0005433058702	463	Economy	8200.00
0005434025438	463	Economy	8200.00
0005433058535	463	Economy	8200.00
0005434025449	463	Economy	8200.00
0005433058277	463	Economy	8200.00
0005433058542	463	Economy	8200.00
0005433058597	463	Economy	8200.00
0005434025423	463	Economy	8200.00
0005434025464	463	Economy	8200.00
0005434025417	463	Economy	8200.00
0005434028380	463	Economy	8200.00
0005434032139	463	Economy	8200.00
0005433058484	463	Economy	8200.00
0005433058666	463	Economy	8200.00
0005434032137	463	Economy	8200.00
0005434029719	463	Economy	8200.00
0005434025426	463	Economy	8200.00
0005434025461	463	Economy	8200.00
0005434025472	463	Economy	8200.00
0005434025413	463	Economy	8200.00
0005434025416	463	Economy	8200.00
0005432235833	463	Economy	8200.00
0005434025432	463	Economy	8200.00
0005434028378	463	Economy	8200.00
0005434025446	463	Economy	8200.00
0005434025469	463	Economy	8200.00
0005434025473	463	Economy	8200.00
0005434025410	463	Economy	8200.00
0005434025459	463	Economy	8200.00
0005433058512	463	Economy	8200.00
0005434025431	463	Economy	8200.00
0005434025418	463	Economy	8200.00
0005433058544	463	Economy	8200.00
0005433058510	463	Economy	9000.00
0005433058541	463	Economy	9000.00
0005434025451	463	Economy	8200.00
0005433058635	463	Economy	8200.00
0005434025441	463	Economy	8200.00
0005433058395	463	Economy	8200.00
0005434025442	463	Economy	8200.00
0005434025425	463	Economy	8200.00
0005434025411	463	Economy	8200.00
0005434025467	463	Economy	8200.00
0005432235831	463	Economy	8200.00
0005434025434	463	Economy	8200.00
0005434025408	463	Economy	8200.00
0005434025470	463	Economy	8200.00
0005434025460	463	Economy	8200.00
0005433058670	463	Economy	8200.00
0005434032140	463	Economy	8200.00
0005434025471	463	Economy	8200.00
0005434025427	463	Economy	8200.00
0005433058567	463	Economy	8200.00
0005433058656	463	Economy	8200.00
0005433058620	463	Economy	8200.00
0005433058543	463	Economy	8200.00
0005433058492	463	Economy	8200.00
0005432235828	463	Economy	8200.00
0005433058396	463	Economy	8200.00
0005433058566	463	Economy	8200.00
0005434028377	463	Economy	8200.00
0005434025450	463	Economy	8200.00
0005434025452	463	Economy	8200.00
0005434025468	463	Economy	8200.00
0005432235832	463	Economy	8200.00
0005433058629	463	Economy	8200.00
0005433058624	463	Economy	8200.00
0005434025424	463	Economy	8200.00
0005434029718	463	Economy	8200.00
0005434025455	463	Economy	8200.00
0005433058630	463	Economy	8200.00
0005434025415	463	Economy	8200.00
0005434025435	463	Economy	8200.00
0005434025443	463	Economy	8200.00
0005434025440	463	Economy	8200.00
0005434025447	463	Economy	8200.00
0005432235829	463	Economy	8200.00
0005433058550	463	Economy	8200.00
0005433058763	463	Economy	8200.00
0005434025409	463	Economy	8200.00
0005434025428	463	Economy	8200.00
0005434024952	12683	Business	24500.00
0005433058910	12683	Business	24500.00
0005434024795	12683	Business	24500.00
0005434024922	12683	Business	24500.00
0005434024926	12683	Business	24500.00
0005434024861	12683	Business	24500.00
0005434024813	12683	Business	24500.00
0005434024884	12683	Business	24500.00
0005433058893	12683	Business	24500.00
0005434735824	12683	Business	24500.00
0005434024901	12683	Business	24500.00
0005434025044	12683	Business	24500.00
0005433058908	12683	Business	24500.00
0005434024918	12683	Business	24500.00
0005434032092	12683	Business	24500.00
0005434024570	12683	Business	24500.00
0005434028362	12683	Business	24500.00
0005434024648	12683	Business	24500.00
0005433058917	12683	Business	24500.00
0005434024619	12683	Business	24500.00
0005434024889	12683	Business	24500.00
0005434025088	12683	Business	24500.00
0005433058922	12683	Business	24500.00
0005434025151	12683	Economy	9000.00
0005433058912	12683	Business	24500.00
0005434024862	12683	Economy	9000.00
0005432157540	12683	Economy	9000.00
0005433058899	12683	Economy	8200.00
0005433058920	12683	Economy	8200.00
0005433058909	12683	Economy	8200.00
0005434024814	12683	Economy	8200.00
0005433058902	12683	Economy	8200.00
0005434024829	12683	Economy	8200.00
0005434025002	12683	Economy	8200.00
0005434024721	12683	Economy	8200.00
0005434024720	12683	Economy	8200.00
0005434032110	12683	Economy	8200.00
0005434024925	12683	Economy	8200.00
0005434025001	12683	Economy	8200.00
0005434025058	12683	Economy	8200.00
0005432156480	12683	Economy	8200.00
0005434024799	12683	Economy	8200.00
0005434735822	12683	Economy	8200.00
0005433058903	12683	Economy	8200.00
0005434028342	12683	Economy	8200.00
0005433058924	12683	Economy	8200.00
0005434032089	12683	Economy	8200.00
0005434025097	12683	Economy	8200.00
0005434024977	12683	Economy	8200.00
0005434024791	12683	Economy	8200.00
0005434024719	12683	Economy	8200.00
0005433058897	12683	Economy	8200.00
0005434024900	12683	Economy	8200.00
0005433058914	12683	Economy	8200.00
0005434024920	12683	Economy	8200.00
0005432156479	12683	Economy	8200.00
0005434024692	12683	Economy	8200.00
0005434024676	12683	Economy	8200.00
0005434024779	12683	Economy	8200.00
0005433058913	12683	Economy	8200.00
0005433058898	12683	Economy	8200.00
0005434024715	12683	Economy	8200.00
0005434029694	12683	Economy	8200.00
0005434024617	12683	Economy	8200.00
0005433058904	12683	Economy	8200.00
0005433058907	12683	Economy	8200.00
0005434029699	12683	Economy	8200.00
0005434024681	12683	Economy	8200.00
0005433058906	12683	Economy	8200.00
0005434028363	12683	Economy	8200.00
0005434024890	12683	Economy	8200.00
0005434024693	12683	Economy	8200.00
0005433058927	12683	Economy	8200.00
0005433058923	12683	Economy	8200.00
0005433058926	12683	Economy	8200.00
0005434032102	12683	Economy	8200.00
0005434032093	12683	Economy	8200.00
0005434029700	12683	Economy	8200.00
0005433058915	12683	Economy	8200.00
0005433058928	12683	Economy	8200.00
0005434024794	12683	Economy	8200.00
0005434032120	12683	Economy	8200.00
0005434025036	12683	Economy	8200.00
0005434024730	12683	Economy	8200.00
0005434024855	12683	Economy	8200.00
0005434024520	12683	Economy	8200.00
0005434024680	12683	Economy	8200.00
0005434024944	12683	Economy	8200.00
0005434024975	12683	Economy	8200.00
0005434024941	12683	Economy	8200.00
0005433684472	12683	Economy	8200.00
0005434024661	12683	Economy	8200.00
0005433058919	12683	Economy	8200.00
0005434024728	12683	Economy	9000.00
0005434024727	12683	Economy	8200.00
0005434025022	12683	Economy	8200.00
0005433058905	12683	Economy	8200.00
0005434024722	12683	Economy	8200.00
0005434024487	12683	Economy	8200.00
0005433058901	12683	Economy	8200.00
0005434024962	12683	Economy	8200.00
0005433058911	12683	Economy	8200.00
0005433058896	12683	Economy	8200.00
0005434024976	12683	Economy	8200.00
0005434032091	12683	Economy	8200.00
0005434028339	12683	Economy	8200.00
0005434024934	12683	Economy	8200.00
0005434029685	12683	Economy	8200.00
0005432156478	12683	Economy	8200.00
0005434024914	12683	Economy	8200.00
0005434025006	12683	Economy	8200.00
0005434024817	12683	Economy	8200.00
0005434024682	12683	Economy	8200.00
0005434024649	12683	Economy	8200.00
0005434024870	12683	Economy	8200.00
0005433058894	12683	Economy	8200.00
0005434735823	12683	Economy	8200.00
0005434028338	12683	Economy	8200.00
0005433058900	12683	Economy	8200.00
0005434025096	12683	Economy	8200.00
0005434024895	12683	Economy	8200.00
0005434735825	12683	Economy	8200.00
0005434032101	12683	Economy	8200.00
0005432157541	12683	Economy	8200.00
0005433058921	12683	Economy	8200.00
0005434024880	12683	Economy	8200.00
0005433058895	12683	Economy	8200.00
0005433684473	12683	Economy	8200.00
0005434024871	12683	Economy	8200.00
0005434024945	12683	Economy	8200.00
0005434024792	12683	Economy	8200.00
0005434029698	12683	Economy	8200.00
0005434032096	12683	Economy	8200.00
0005434028364	12683	Economy	8200.00
0005434024866	12683	Economy	8200.00
0005433058918	12683	Economy	8200.00
0005434024917	12683	Economy	8200.00
0005434024963	12683	Economy	8200.00
0005434025021	12683	Economy	8200.00
0005434024968	12683	Economy	8200.00
0005433058916	12683	Economy	8200.00
0005433058925	12683	Economy	8200.00
0005434024856	12683	Economy	8200.00
0005433527359	13820	Business	111600.00
0005433527358	13820	Business	111600.00
0005433529358	13820	Business	111600.00
0005433529371	13820	Business	111600.00
0005433527357	13820	Business	111600.00
0005433529364	13820	Business	111600.00
0005433527349	13820	Business	111600.00
0005433529365	13820	Business	111600.00
0005433527348	13820	Business	111600.00
0005433529370	13820	Economy	37200.00
0005433529367	13820	Economy	37200.00
0005433529360	13820	Economy	37200.00
0005433527355	13820	Economy	37200.00
0005433527360	13820	Economy	37200.00
0005433527356	13820	Economy	37200.00
0005433529359	13820	Economy	37200.00
0005433529361	13820	Economy	37200.00
0005433529368	13820	Economy	37200.00
0005433527347	13820	Economy	37200.00
0005433529363	13820	Economy	37200.00
0005433529372	13820	Economy	37200.00
0005433527353	13820	Economy	37200.00
0005433527352	13820	Economy	37200.00
0005433529366	13820	Economy	37200.00
0005433527354	13820	Economy	37200.00
0005433527350	13820	Economy	37200.00
0005433529373	13820	Economy	37200.00
0005433527361	13820	Economy	37200.00
0005433529374	13820	Economy	37200.00
0005433529369	13820	Economy	37200.00
0005433527351	13820	Economy	37200.00
0005433527362	13820	Economy	37200.00
0005433529362	13820	Economy	37200.00
0005433533376	32456	Business	111600.00
0005433529331	32456	Business	111600.00
0005433533334	32456	Business	111600.00
0005433533365	32456	Business	111600.00
0005433533382	32456	Economy	37200.00
0005433533349	32456	Economy	37200.00
0005433533357	32456	Economy	40900.00
0005433533374	32456	Economy	40900.00
0005433529321	32456	Economy	37200.00
0005433533358	32456	Economy	37200.00
0005433529327	32456	Economy	37200.00
0005433533369	32456	Economy	37200.00
0005433529330	32456	Economy	37200.00
0005433533335	32456	Economy	37200.00
0005433529335	32456	Economy	37200.00
0005433533370	32456	Economy	37200.00
0005433533383	32456	Economy	37200.00
0005433533354	32456	Economy	37200.00
0005433529328	32456	Economy	37200.00
0005433529345	32456	Economy	37200.00
0005433529312	32456	Economy	37200.00
0005433533378	32456	Economy	37200.00
0005433529334	32456	Economy	37200.00
0005433533373	32456	Economy	37200.00
0005433533359	32456	Economy	37200.00
0005433529341	32456	Economy	37200.00
0005433529313	32456	Economy	37200.00
0005433533366	32456	Economy	37200.00
0005433533377	32456	Economy	37200.00
0005433533368	32456	Economy	37200.00
0005433529346	32456	Economy	37200.00
0005433529314	32456	Economy	37200.00
0005433529329	32456	Economy	37200.00
0005433533379	32456	Economy	37200.00
0005433036935	2164	Business	34700.00
0005433037240	2164	Business	34700.00
0005433925779	2164	Business	34700.00
0005433925759	2164	Business	34700.00
0005433037273	2164	Business	34700.00
0005433037042	2164	Business	34700.00
0005433925721	2164	Business	34700.00
0005433925775	2164	Business	34700.00
0005433925709	2164	Business	34700.00
0005433925749	2164	Business	34700.00
0005433925752	2164	Business	34700.00
0005433037241	2164	Business	34700.00
0005433037088	2164	Business	34700.00
0005433925781	2164	Business	34700.00
0005433925741	2164	Business	34700.00
0005433037290	2164	Business	34700.00
0005434028338	2164	Business	34700.00
0005433925797	2164	Business	34700.00
0005433925764	2164	Business	34700.00
0005433925761	2164	Business	34700.00
0005433925789	2164	Business	34700.00
0005433925717	2164	Business	34700.00
0005433037250	2164	Business	34700.00
0005433925716	2164	Business	34700.00
0005433925776	2164	Business	34700.00
0005433925796	2164	Economy	12700.00
0005433925732	2164	Economy	12700.00
0005432044594	2164	Economy	12700.00
0005433037349	2164	Economy	11600.00
0005433925754	2164	Economy	11600.00
0005433925748	2164	Economy	11600.00
0005433037348	2164	Economy	11600.00
0005433925777	2164	Economy	11600.00
0005433037051	2164	Economy	11600.00
0005433037092	2164	Economy	11600.00
0005433925712	2164	Economy	11600.00
0005433925746	2164	Economy	11600.00
0005433925780	2164	Economy	11600.00
0005433037043	2164	Economy	11600.00
0005433925729	2164	Economy	11600.00
0005433925783	2164	Economy	11600.00
0005433931546	2164	Economy	11600.00
0005432231836	2164	Economy	11600.00
0005432231841	2164	Economy	11600.00
0005433037137	2164	Economy	11600.00
0005433925778	2164	Economy	11600.00
0005433037158	2164	Economy	11600.00
0005433925785	2164	Economy	11600.00
0005433925767	2164	Economy	11600.00
0005433037207	2164	Economy	11600.00
0005433925794	2164	Economy	11600.00
0005433037264	2164	Economy	11600.00
0005433037341	2164	Economy	11600.00
0005433037033	2164	Economy	11600.00
0005433925791	2164	Economy	11600.00
0005433037196	2164	Economy	11600.00
0005433925782	2164	Economy	11600.00
0005433037129	2164	Economy	11600.00
0005433037034	2164	Economy	11600.00
0005433925772	2164	Economy	11600.00
0005433925765	2164	Economy	11600.00
0005434028339	2164	Economy	11600.00
0005433037130	2164	Economy	11600.00
0005433037286	2164	Economy	11600.00
0005433037371	2164	Economy	11600.00
0005432044596	2164	Economy	11600.00
0005433925713	2164	Economy	11600.00
0005433925750	2164	Economy	11600.00
0005433037160	2164	Economy	11600.00
0005433925758	2164	Economy	11600.00
0005433037257	2164	Economy	11600.00
0005433925786	2164	Economy	11600.00
0005433925723	2164	Economy	11600.00
0005433925769	2164	Economy	11600.00
0005432231834	2164	Economy	11600.00
0005433925784	2164	Economy	11600.00
0005433931544	2164	Economy	11600.00
0005433925736	2164	Economy	11600.00
0005433925744	2164	Economy	11600.00
0005433037390	2164	Economy	11600.00
0005433925787	2164	Economy	11600.00
0005433925798	2164	Economy	11600.00
0005433037198	2164	Economy	11600.00
0005433037128	2164	Economy	11600.00
0005433925757	2164	Economy	11600.00
0005433925747	2164	Economy	11600.00
0005433925710	2164	Economy	11600.00
0005433037228	2164	Economy	11600.00
0005433037278	2164	Economy	11600.00
0005433037099	2164	Economy	11600.00
0005433925760	2164	Economy	11600.00
0005433037131	2164	Economy	11600.00
0005432231832	2164	Economy	11600.00
0005433875422	2164	Economy	11600.00
0005433925730	2164	Economy	11600.00
0005433925766	2164	Economy	11600.00
0005433925751	2164	Economy	11600.00
0005432231837	2164	Economy	11600.00
0005433925720	2164	Economy	11600.00
0005433925728	2164	Economy	11600.00
0005433037022	2164	Economy	11600.00
0005433925742	2164	Economy	11600.00
0005433925755	2164	Economy	11600.00
0005433925773	2164	Economy	11600.00
0005433925734	2164	Economy	11600.00
0005432231840	2164	Economy	11600.00
0005433037283	2164	Economy	11600.00
0005433925792	2164	Economy	11600.00
0005433925762	2164	Economy	11600.00
0005433925719	2164	Economy	12700.00
0005433925745	2164	Economy	11600.00
0005433925768	2164	Economy	11600.00
0005433875421	2164	Economy	11600.00
0005434028362	2164	Economy	12700.00
0005434028363	2164	Economy	11600.00
0005433925739	2164	Economy	11600.00
0005433925718	2164	Economy	11600.00
0005433037259	2164	Economy	11600.00
0005433037251	2164	Economy	11600.00
0005432231838	2164	Economy	11600.00
0005433925722	2164	Economy	11600.00
0005433925727	2164	Economy	11600.00
0005433925799	2164	Economy	11600.00
0005433925731	2164	Economy	11600.00
0005433925774	2164	Economy	11600.00
0005433925743	2164	Economy	11600.00
0005432231839	2164	Economy	11600.00
0005433925753	2164	Economy	11600.00
0005432231833	2164	Economy	11600.00
0005433036976	2164	Economy	11600.00
0005433037265	2164	Economy	11600.00
0005434028364	2164	Economy	11600.00
0005433037182	2164	Economy	11600.00
0005433925733	2164	Economy	11600.00
0005433925800	2164	Economy	11600.00
0005433037313	2164	Economy	11600.00
0005433037201	2164	Economy	11600.00
0005433037037	2164	Economy	11600.00
0005432231835	2164	Economy	11600.00
0005433037159	2164	Economy	11600.00
0005433925740	2164	Economy	11600.00
0005433925790	2164	Economy	11600.00
0005433037372	2164	Economy	11600.00
0005433925711	2164	Economy	11600.00
0005433925726	2164	Economy	11600.00
0005433925738	2164	Economy	11600.00
0005433037268	2164	Economy	11600.00
0005433925735	2164	Economy	11600.00
0005433037183	2164	Economy	11600.00
0005433925801	2164	Economy	11600.00
0005433037138	2164	Economy	11600.00
0005433925771	2164	Economy	11600.00
0005433037220	2164	Economy	11600.00
0005433925795	2164	Economy	11600.00
0005433925737	2164	Economy	11600.00
0005433037284	2164	Economy	11600.00
0005433931545	2164	Economy	11600.00
0005433925724	2164	Economy	11600.00
0005433931547	2164	Economy	11600.00
0005433925715	2164	Economy	11600.00
0005434028342	2164	Economy	11600.00
0005433925770	2164	Economy	11600.00
0005433037206	2164	Economy	11600.00
0005433037258	2164	Economy	11600.00
0005433925763	2164	Economy	11600.00
0005433037113	2164	Economy	11600.00
0005433037197	2164	Economy	11600.00
0005433925725	2164	Economy	11600.00
0005433037052	2164	Economy	11600.00
0005432044595	2164	Economy	11600.00
0005433925793	2164	Economy	11600.00
0005433925714	2164	Economy	11600.00
0005433037403	2164	Economy	11600.00
0005433037087	2164	Economy	11600.00
0005432749816	2164	Economy	11600.00
0005433925788	2164	Economy	11600.00
0005433036973	2164	Economy	11600.00
0005433037157	2164	Economy	11600.00
0005433036929	2164	Economy	11600.00
0005433925756	2164	Economy	11600.00
0005433925117	24134	Business	34700.00
0005433037660	24134	Business	34700.00
0005433929686	24134	Business	34700.00
0005433037628	24134	Business	34700.00
0005433924860	24134	Business	34700.00
0005433037637	24134	Business	34700.00
0005432206342	24134	Business	34700.00
0005433925128	24134	Business	34700.00
0005433931515	24134	Business	34700.00
0005433924794	24134	Business	34700.00
0005433929684	24134	Business	34700.00
0005433925021	24134	Business	34700.00
0005433925177	24134	Business	34700.00
0005433925127	24134	Business	34700.00
0005433037647	24134	Business	34700.00
0005433037653	24134	Business	34700.00
0005433924915	24134	Business	34700.00
0005432206345	24134	Business	34700.00
0005433924643	24134	Business	34700.00
0005433925226	24134	Business	34700.00
0005432206343	24134	Business	34700.00
0005433925204	24134	Business	34700.00
0005433925090	24134	Business	34700.00
0005433037667	24134	Economy	12700.00
0005433037668	24134	Economy	12700.00
0005434028383	24134	Economy	12700.00
0005433925275	24134	Economy	12700.00
0005433924689	24134	Economy	11600.00
0005433924874	24134	Economy	11600.00
0005433925033	24134	Economy	11600.00
0005433924748	24134	Economy	11600.00
0005433924740	24134	Economy	11600.00
0005433929680	24134	Economy	11600.00
0005433037633	24134	Economy	11600.00
0005432206347	24134	Economy	11600.00
0005433037622	24134	Economy	11600.00
0005432206344	24134	Economy	11600.00
0005433925082	24134	Economy	11600.00
0005433037655	24134	Economy	11600.00
0005433925088	24134	Economy	11600.00
0005433037636	24134	Economy	11600.00
0005433924901	24134	Economy	11600.00
0005433925216	24134	Economy	11600.00
0005433037639	24134	Economy	11600.00
0005433925089	24134	Economy	11600.00
0005433925032	24134	Economy	11600.00
0005433924703	24134	Economy	11600.00
0005433037624	24134	Economy	11600.00
0005433924973	24134	Economy	11600.00
0005433924736	24134	Economy	11600.00
0005433037632	24134	Economy	11600.00
0005433925048	24134	Economy	11600.00
0005433925132	24134	Economy	11600.00
0005433924880	24134	Economy	11600.00
0005433037656	24134	Economy	11600.00
0005434028381	24134	Economy	11600.00
0005433924988	24134	Economy	11600.00
0005434028384	24134	Economy	11600.00
0005433924998	24134	Economy	11600.00
0005433931517	24134	Economy	11600.00
0005433929687	24134	Economy	11600.00
0005432207730	24134	Economy	11600.00
0005433924836	24134	Economy	11600.00
0005433925296	24134	Economy	11600.00
0005433925120	24134	Economy	11600.00
0005433924924	24134	Economy	11600.00
0005433924947	24134	Economy	11600.00
0005433924858	24134	Economy	11600.00
0005433037644	24134	Economy	11600.00
0005433037648	24134	Economy	11600.00
0005433925290	24134	Economy	11600.00
0005433924974	24134	Economy	11600.00
0005433925142	24134	Economy	11600.00
0005432206346	24134	Economy	11600.00
0005433037620	24134	Economy	11600.00
0005433037626	24134	Economy	11600.00
0005433924644	24134	Economy	11600.00
0005433929683	24134	Economy	11600.00
0005433037625	24134	Economy	11600.00
0005433924946	24134	Economy	11600.00
0005433924890	24134	Economy	11600.00
0005433925176	24134	Economy	11600.00
0005433924938	24134	Economy	11600.00
0005433037646	24134	Economy	11600.00
0005433924735	24134	Economy	11600.00
0005433931518	24134	Economy	11600.00
0005433925203	24134	Economy	11600.00
0005433037635	24134	Economy	11600.00
0005433924805	24134	Economy	11600.00
0005433037621	24134	Economy	11600.00
0005433925133	24134	Economy	11600.00
0005433037652	24134	Economy	11600.00
0005433924852	24134	Economy	11600.00
0005432207728	24134	Economy	11600.00
0005433037665	24134	Economy	11600.00
0005433037641	24134	Economy	11600.00
0005433037659	24134	Economy	11600.00
0005433037661	24134	Economy	11600.00
0005433924820	24134	Economy	11600.00
0005433037662	24134	Economy	11600.00
0005433037638	24134	Economy	11600.00
0005433037657	24134	Economy	11600.00
0005432206348	24134	Economy	11600.00
0005433925047	24134	Economy	11600.00
0005433037627	24134	Economy	11600.00
0005432749841	24134	Economy	11600.00
0005433924995	24134	Economy	12700.00
0005433037631	24134	Economy	11600.00
0005433924632	24134	Economy	11600.00
0005433037629	24134	Economy	11600.00
0005433925011	24134	Economy	12700.00
0005433925217	24134	Economy	11600.00
0005433924945	24134	Economy	11600.00
0005433037623	24134	Economy	11600.00
0005433924910	24134	Economy	11600.00
0005433037650	24134	Economy	11600.00
0005433037642	24134	Economy	11600.00
0005433925126	24134	Economy	11600.00
0005432207727	24134	Economy	11600.00
0005433929681	24134	Economy	11600.00
0005433924672	24134	Economy	11600.00
0005433929678	24134	Economy	11600.00
0005433925149	24134	Economy	11600.00
0005433037651	24134	Economy	11600.00
0005433037654	24134	Economy	11600.00
0005433925116	24134	Economy	11600.00
0005433925019	24134	Economy	11600.00
0005433924742	24134	Economy	11600.00
0005433037645	24134	Economy	11600.00
0005433924590	24134	Economy	11600.00
0005433929682	24134	Economy	11600.00
0005433925087	24134	Economy	11600.00
0005433875404	24134	Economy	11600.00
0005433924835	24134	Economy	11600.00
0005433924773	24134	Economy	11600.00
0005433929685	24134	Economy	11600.00
0005433925148	24134	Economy	11600.00
0005433925315	24134	Economy	11600.00
0005433037634	24134	Economy	11600.00
0005433924987	24134	Economy	11600.00
0005433925007	24134	Economy	11600.00
0005433925419	24134	Economy	11600.00
0005433924688	24134	Economy	11600.00
0005434028382	24134	Economy	11600.00
0005433037643	24134	Economy	11600.00
0005433037630	24134	Economy	11600.00
0005433037649	24134	Economy	11600.00
0005432749840	24134	Economy	11600.00
0005433924803	24134	Economy	11600.00
0005433925010	24134	Economy	11600.00
0005433925083	24134	Economy	11600.00
0005433037640	24134	Economy	11600.00
0005433037666	24134	Economy	11600.00
0005433037663	24134	Economy	11600.00
0005433037658	24134	Economy	11600.00
0005433925020	24134	Economy	11600.00
0005433925115	24134	Economy	11600.00
0005433924642	24134	Economy	11600.00
0005433931516	24134	Economy	11600.00
0005433925276	24134	Economy	11600.00
0005433924837	24134	Economy	11600.00
0005433924806	24134	Economy	11600.00
0005433925291	24134	Economy	11600.00
0005433924861	24134	Economy	11600.00
0005432207729	24134	Economy	11600.00
0005433037664	24134	Economy	11600.00
0005433925075	24134	Economy	11600.00
0005433925370	24134	Economy	11600.00
0005433925297	24134	Economy	11600.00
0005433925121	24134	Economy	11600.00
0005433924916	24134	Economy	11600.00
0005433924743	24134	Economy	11600.00
0005433924948	24134	Economy	11600.00
0005433924914	24134	Economy	11600.00
0005433235449	256	Business	83700.00
0005433235295	256	Business	83700.00
0005434728596	256	Business	83700.00
0005432278156	256	Business	83700.00
0005434728522	256	Business	83700.00
0005433235262	256	Business	83700.00
0005434552659	256	Business	83700.00
0005433235350	256	Business	83700.00
0005434728527	256	Business	83700.00
0005434731274	256	Business	83700.00
0005433235503	256	Business	83700.00
0005434552648	256	Business	83700.00
0005434728511	256	Business	83700.00
0005433235169	256	Business	83700.00
0005433181644	256	Business	83700.00
0005433289990	256	Business	83700.00
0005434728510	256	Business	83700.00
0005434552644	256	Business	83700.00
0005434552637	256	Business	83700.00
0005433126908	256	Business	83700.00
0005434728613	256	Business	83700.00
0005434302568	256	Business	83700.00
0005433234945	256	Business	83700.00
0005433235114	256	Comfort	47400.00
0005433235349	256	Comfort	47400.00
0005434728583	256	Comfort	47400.00
0005434728556	256	Comfort	47400.00
0005434731275	256	Comfort	47400.00
0005434552632	256	Comfort	47400.00
0005434552653	256	Comfort	47400.00
0005433235373	256	Comfort	47400.00
0005433234828	256	Comfort	47400.00
0005433181545	256	Comfort	47400.00
0005432278151	256	Comfort	47400.00
0005433235182	256	Comfort	47400.00
0005434552642	256	Comfort	47400.00
0005435142921	256	Comfort	47400.00
0005433181482	256	Comfort	47400.00
0005434728585	256	Comfort	47400.00
0005433235445	256	Comfort	47400.00
0005434552611	256	Comfort	47400.00
0005433234963	256	Comfort	47400.00
0005434728595	256	Comfort	47400.00
0005433235402	256	Comfort	47400.00
0005434552621	256	Comfort	47400.00
0005434552652	256	Comfort	47400.00
0005434728525	256	Comfort	47400.00
0005434728540	256	Comfort	47400.00
0005434552625	256	Comfort	47400.00
0005433126915	256	Comfort	47400.00
0005434728539	256	Comfort	47400.00
0005433235094	256	Comfort	47400.00
0005434552628	256	Comfort	47400.00
0005434728591	256	Comfort	47400.00
0005433289978	256	Comfort	47400.00
0005433181530	256	Comfort	47400.00
0005433126919	256	Comfort	47400.00
0005433289994	256	Comfort	47400.00
0005433181563	256	Economy	27900.00
0005433234824	256	Economy	27900.00
0005434728548	256	Economy	27900.00
0005434552647	256	Economy	27900.00
0005434728599	256	Economy	27900.00
0005433235100	256	Economy	27900.00
0005434728602	256	Economy	27900.00
0005434728586	256	Economy	27900.00
0005434728609	256	Economy	27900.00
0005433235208	256	Economy	27900.00
0005433235111	256	Economy	27900.00
0005434728534	256	Economy	27900.00
0005434728582	256	Economy	27900.00
0005434735817	256	Economy	27900.00
0005433235273	256	Economy	27900.00
0005435142915	256	Economy	27900.00
0005433235181	256	Economy	27900.00
0005434728542	256	Economy	27900.00
0005433181590	256	Economy	27900.00
0005433235427	256	Economy	27900.00
0005433235250	256	Economy	27900.00
0005434728512	256	Economy	27900.00
0005433181560	256	Economy	27900.00
0005434728563	256	Economy	27900.00
0005434728561	256	Economy	27900.00
0005433126917	256	Economy	27900.00
0005434728607	256	Economy	27900.00
0005433235207	256	Economy	27900.00
0005433131789	256	Economy	27900.00
0005434728516	256	Economy	27900.00
0005433235093	256	Economy	27900.00
0005434728543	256	Economy	27900.00
0005434552656	256	Economy	27900.00
0005434728601	256	Economy	27900.00
0005434728517	256	Economy	27900.00
0005433181549	256	Economy	27900.00
0005434728513	256	Economy	27900.00
0005434728615	256	Economy	27900.00
0005433181491	256	Economy	27900.00
0005434731277	256	Economy	27900.00
0005433235234	256	Economy	27900.00
0005434731276	256	Economy	27900.00
0005432278155	256	Economy	27900.00
0005434552645	256	Economy	27900.00
0005434552616	256	Economy	27900.00
0005434552614	256	Economy	27900.00
0005434728526	256	Economy	27900.00
0005432278146	256	Economy	27900.00
0005434728606	256	Economy	27900.00
0005433235104	256	Economy	27900.00
0005434728605	256	Economy	27900.00
0005433181400	256	Economy	27900.00
0005434552636	256	Economy	27900.00
0005433235251	256	Economy	27900.00
0005433235400	256	Economy	27900.00
0005434552610	256	Economy	27900.00
0005435142923	256	Economy	27900.00
0005433235041	256	Economy	30700.00
0005433234850	256	Economy	30700.00
0005434552651	256	Economy	27900.00
0005434552634	256	Economy	27900.00
0005434728617	256	Economy	27900.00
0005434728578	256	Economy	27900.00
0005434552629	256	Economy	30700.00
0005433235147	256	Economy	30700.00
0005434728531	256	Economy	30700.00
0005434552639	256	Economy	27900.00
0005434728544	256	Economy	27900.00
0005434552612	256	Economy	27900.00
0005433181512	256	Economy	27900.00
0005434728538	256	Economy	27900.00
0005433234947	256	Economy	27900.00
0005433235243	256	Economy	27900.00
0005433235294	256	Economy	27900.00
0005433289962	256	Economy	27900.00
0005434728524	256	Economy	27900.00
0005434552607	256	Economy	27900.00
0005434032112	256	Economy	27900.00
0005433235235	256	Economy	27900.00
0005434728611	256	Economy	27900.00
0005433126926	256	Economy	27900.00
0005434552630	256	Economy	27900.00
0005433235317	256	Economy	27900.00
0005433181550	256	Economy	27900.00
0005433181499	256	Economy	27900.00
0005432278148	256	Economy	27900.00
0005434728549	256	Economy	27900.00
0005434728571	256	Economy	27900.00
0005434728530	256	Economy	27900.00
0005433235383	256	Economy	27900.00
0005433181554	256	Economy	27900.00
0005434728536	256	Economy	27900.00
0005434728587	256	Economy	27900.00
0005435142920	256	Economy	27900.00
0005433235339	256	Economy	27900.00
0005434552618	256	Economy	27900.00
0005434728567	256	Economy	27900.00
0005434735820	256	Economy	27900.00
0005433235394	256	Economy	27900.00
0005434552617	256	Economy	27900.00
0005433235316	256	Economy	27900.00
0005434728565	256	Economy	27900.00
0005433235127	256	Economy	27900.00
0005435142918	256	Economy	27900.00
0005435142922	256	Economy	27900.00
0005434728612	256	Economy	27900.00
0005434728568	256	Economy	27900.00
0005433181562	256	Economy	27900.00
0005432278150	256	Economy	27900.00
0005433766708	256	Economy	27900.00
0005434728550	256	Economy	27900.00
0005433235355	256	Economy	27900.00
0005433126935	256	Economy	27900.00
0005433181514	256	Economy	27900.00
0005434728590	256	Economy	27900.00
0005432278154	256	Economy	27900.00
0005434735821	256	Economy	27900.00
0005434728589	256	Economy	27900.00
0005433181643	256	Economy	27900.00
0005434728533	256	Economy	27900.00
0005434552605	256	Economy	27900.00
0005434552649	256	Economy	27900.00
0005433290008	256	Economy	27900.00
0005434728584	256	Economy	27900.00
0005434552615	256	Economy	27900.00
0005432278153	256	Economy	27900.00
0005434728616	256	Economy	27900.00
0005434728559	256	Economy	27900.00
0005433235429	256	Economy	27900.00
0005434728523	256	Economy	27900.00
0005433234962	256	Economy	27900.00
0005434552623	256	Economy	27900.00
0005433290007	256	Economy	27900.00
0005434552620	256	Economy	27900.00
0005434728555	256	Economy	27900.00
0005434728514	256	Economy	27900.00
0005434552622	256	Economy	27900.00
0005434302569	256	Economy	27900.00
0005434552658	256	Economy	27900.00
0005434728600	256	Economy	27900.00
0005434728532	256	Economy	27900.00
0005434552654	256	Economy	27900.00
0005434728614	256	Economy	27900.00
0005434728537	256	Economy	27900.00
0005432278152	256	Economy	27900.00
0005434728553	256	Economy	27900.00
0005434728519	256	Economy	27900.00
0005434728552	256	Economy	27900.00
0005434552638	256	Economy	27900.00
0005433235458	256	Economy	27900.00
0005433181509	256	Economy	27900.00
0005434728562	256	Economy	27900.00
0005434728518	256	Economy	27900.00
0005434728592	256	Economy	27900.00
0005432278147	256	Economy	27900.00
0005433126918	256	Economy	27900.00
0005434728560	256	Economy	27900.00
0005433235272	256	Economy	27900.00
0005433235446	256	Economy	27900.00
0005434728528	256	Economy	27900.00
0005434552619	256	Economy	27900.00
0005433235171	256	Economy	27900.00
0005434728541	256	Economy	27900.00
0005434728579	256	Economy	27900.00
0005434728551	256	Economy	27900.00
0005433235472	256	Economy	30700.00
0005434552624	256	Economy	30700.00
0005434552650	256	Economy	30700.00
0005434728547	256	Economy	30700.00
0005434552627	256	Economy	30700.00
0005434728557	256	Economy	30700.00
0005434728535	256	Economy	27900.00
0005434728577	256	Economy	27900.00
0005434728564	256	Economy	27900.00
0005434552646	256	Economy	27900.00
0005433235477	256	Economy	27900.00
0005433234825	256	Economy	27900.00
0005434552635	256	Economy	27900.00
0005433234946	256	Economy	27900.00
0005433126916	256	Economy	27900.00
0005434552633	256	Economy	27900.00
0005433235471	256	Economy	27900.00
0005434728558	256	Economy	27900.00
0005433235305	256	Economy	27900.00
0005434728580	256	Economy	27900.00
0005434728594	256	Economy	27900.00
0005433235298	256	Economy	27900.00
0005434728598	256	Economy	27900.00
0005433235374	256	Economy	27900.00
0005433181565	256	Economy	27900.00
0005433235237	256	Economy	27900.00
0005434552640	256	Economy	27900.00
0005434552626	256	Economy	27900.00
0005434728554	256	Economy	27900.00
0005434728520	256	Economy	27900.00
0005433111542	256	Economy	27900.00
0005434728509	256	Economy	27900.00
0005433289979	256	Economy	27900.00
0005435142919	256	Economy	27900.00
0005433234926	256	Economy	27900.00
0005433181513	256	Economy	27900.00
0005433181399	256	Economy	27900.00
0005434728593	256	Economy	27900.00
0005433235428	256	Economy	27900.00
0005434728588	256	Economy	27900.00
0005434728608	256	Economy	27900.00
0005434552606	256	Economy	27900.00
0005434731273	256	Economy	27900.00
0005434552631	256	Economy	27900.00
0005435142916	256	Economy	27900.00
0005434728618	256	Economy	27900.00
0005434728573	256	Economy	27900.00
0005433235187	256	Economy	27900.00
0005433181504	256	Economy	27900.00
0005433766712	256	Economy	27900.00
0005434728546	256	Economy	27900.00
0005434302567	256	Economy	27900.00
0005433181628	256	Economy	27900.00
0005434728575	256	Economy	27900.00
0005433111541	256	Economy	27900.00
0005433235338	256	Economy	27900.00
0005434552657	256	Economy	27900.00
0005433289967	256	Economy	27900.00
0005434552613	256	Economy	27900.00
0005433181510	256	Economy	27900.00
0005434728576	256	Economy	27900.00
0005433235113	256	Economy	27900.00
0005434735819	256	Economy	27900.00
0005433766694	256	Economy	27900.00
0005434728521	256	Economy	27900.00
0005434032090	256	Economy	27900.00
0005434728545	256	Economy	27900.00
0005434552609	256	Economy	27900.00
0005434728572	256	Economy	27900.00
0005433235369	256	Economy	27900.00
0005433126930	256	Economy	27900.00
0005433235459	256	Economy	27900.00
0005434728569	256	Economy	27900.00
0005434032113	256	Economy	27900.00
0005433181476	256	Economy	27900.00
0005434728515	256	Economy	27900.00
0005433234829	256	Economy	27900.00
0005434728570	256	Economy	27900.00
0005433235170	256	Economy	27900.00
0005434728597	256	Economy	27900.00
0005434728604	256	Economy	27900.00
0005433181500	256	Economy	27900.00
0005433235112	256	Economy	27900.00
0005434728610	256	Economy	27900.00
0005433766707	256	Economy	27900.00
0005433131784	256	Economy	27900.00
0005434552641	256	Economy	27900.00
0005434728566	256	Economy	27900.00
0005434552608	256	Economy	27900.00
0005433766709	256	Economy	27900.00
0005435142917	256	Economy	27900.00
0005434735818	256	Economy	27900.00
0005433131770	256	Economy	27900.00
0005433181426	256	Economy	27900.00
0005433131783	256	Economy	27900.00
0005434728529	256	Economy	27900.00
0005432278149	256	Economy	27900.00
0005434552655	256	Economy	27900.00
0005433235368	256	Economy	27900.00
0005434728603	256	Economy	27900.00
0005433126925	256	Economy	27900.00
0005434728581	256	Economy	27900.00
0005434552643	256	Economy	27900.00
0005433766704	256	Economy	27900.00
0005433235221	256	Economy	27900.00
0005433181546	256	Economy	27900.00
0005434728574	256	Economy	27900.00
0005433181449	256	Economy	27900.00
0005434302523	9840	Business	83700.00
0005434727364	9840	Business	83700.00
0005434727906	9840	Business	83700.00
0005434032142	9840	Business	83700.00
0005433181728	9840	Business	83700.00
0005434726730	9840	Business	83700.00
0005433235828	9840	Business	83700.00
0005434551941	9840	Business	83700.00
0005435142716	9840	Business	83700.00
0005434552138	9840	Business	83700.00
0005433235820	9840	Business	83700.00
0005435142762	9840	Business	83700.00
0005434552190	9840	Business	83700.00
0005433181754	9840	Business	83700.00
0005434552107	9840	Business	83700.00
0005434727892	9840	Business	83700.00
0005433181737	9840	Business	83700.00
0005434727403	9840	Business	83700.00
0005434552306	9840	Business	83700.00
0005434551975	9840	Business	83700.00
0005433235817	9840	Business	83700.00
0005433235800	9840	Business	83700.00
0005433235831	9840	Business	83700.00
0005434727544	9840	Business	83700.00
0005433235830	9840	Business	83700.00
0005433235798	9840	Business	83700.00
0005434727447	9840	Business	83700.00
0005434727399	9840	Comfort	47400.00
0005433181733	9840	Business	83700.00
0005434727992	9840	Comfort	47400.00
0005433235782	9840	Comfort	47400.00
0005433181747	9840	Comfort	47400.00
0005433235818	9840	Comfort	47400.00
0005433235791	9840	Comfort	47400.00
0005434727849	9840	Comfort	47400.00
0005434552205	9840	Comfort	47400.00
0005434727389	9840	Comfort	47400.00
0005433181717	9840	Comfort	47400.00
0005433235801	9840	Comfort	47400.00
0005433235832	9840	Comfort	47400.00
0005433181727	9840	Comfort	47400.00
0005434727007	9840	Comfort	47400.00
0005434727759	9840	Comfort	47400.00
0005433181743	9840	Comfort	47400.00
0005433181738	9840	Comfort	47400.00
0005433235797	9840	Comfort	47400.00
0005434727402	9840	Comfort	47400.00
0005434551970	9840	Comfort	47400.00
0005433235813	9840	Comfort	47400.00
0005433181715	9840	Comfort	47400.00
0005433235821	9840	Comfort	47400.00
0005434552246	9840	Comfort	47400.00
0005434032144	9840	Comfort	47400.00
0005434552233	9840	Comfort	47400.00
0005433181748	9840	Comfort	47400.00
0005433181740	9840	Comfort	47400.00
0005434032143	9840	Comfort	47400.00
0005433181752	9840	Comfort	47400.00
0005432199423	9840	Comfort	47400.00
0005434552207	9840	Comfort	47400.00
0005433235805	9840	Comfort	47400.00
0005434727942	9840	Comfort	47400.00
0005433235781	9840	Comfort	47400.00
0005433181724	9840	Comfort	47400.00
0005434735771	9840	Comfort	47400.00
0005434727928	9840	Comfort	47400.00
0005433181708	9840	Comfort	47400.00
0005433235806	9840	Comfort	47400.00
0005432199422	9840	Comfort	47400.00
0005434552204	9840	Economy	27900.00
0005434552206	9840	Economy	27900.00
0005433113591	9840	Economy	27900.00
0005434727383	9840	Economy	27900.00
0005433181723	9840	Economy	27900.00
0005433235810	9840	Economy	27900.00
0005435142724	9840	Economy	27900.00
0005433290034	9840	Economy	27900.00
0005434727508	9840	Economy	27900.00
0005434552120	9840	Economy	27900.00
0005434552082	9840	Economy	27900.00
0005433181712	9840	Economy	27900.00
0005433235824	9840	Economy	27900.00
0005433181721	9840	Economy	27900.00
0005434727296	9840	Economy	27900.00
0005433181710	9840	Economy	27900.00
0005433181744	9840	Economy	27900.00
0005434735769	9840	Economy	27900.00
0005434302524	9840	Economy	27900.00
0005434727614	9840	Economy	27900.00
0005433181753	9840	Economy	27900.00
0005434552004	9840	Economy	27900.00
0005433181746	9840	Economy	27900.00
0005434727881	9840	Economy	27900.00
0005433235822	9840	Economy	27900.00
0005434727278	9840	Economy	27900.00
0005434551869	9840	Economy	27900.00
0005433235793	9840	Economy	27900.00
0005433235825	9840	Economy	27900.00
0005434728012	9840	Economy	27900.00
0005433181720	9840	Economy	27900.00
0005434552173	9840	Economy	27900.00
0005434727509	9840	Economy	27900.00
0005433181757	9840	Economy	27900.00
0005434727914	9840	Economy	27900.00
0005434552160	9840	Economy	27900.00
0005432199425	9840	Economy	27900.00
0005434727652	9840	Economy	27900.00
0005434727424	9840	Economy	27900.00
0005433235792	9840	Economy	27900.00
0005434552009	9840	Economy	27900.00
0005434727507	9840	Economy	27900.00
0005433235784	9840	Economy	27900.00
0005434551999	9840	Economy	27900.00
0005432199426	9840	Economy	27900.00
0005433129394	9840	Economy	27900.00
0005434727769	9840	Economy	27900.00
0005434727913	9840	Economy	27900.00
0005434735775	9840	Economy	27900.00
0005434727739	9840	Economy	27900.00
0005434552264	9840	Economy	27900.00
0005434727651	9840	Economy	27900.00
0005435142729	9840	Economy	27900.00
0005433181726	9840	Economy	27900.00
0005435142800	9840	Economy	27900.00
0005434726900	9840	Economy	27900.00
0005435142754	9840	Economy	30700.00
0005434727738	9840	Economy	30700.00
0005434551885	9840	Economy	30700.00
0005434727363	9840	Economy	27900.00
0005433235816	9840	Economy	27900.00
0005435142761	9840	Economy	30700.00
0005434727710	9840	Economy	27900.00
0005434727730	9840	Economy	30700.00
0005434727465	9840	Economy	30700.00
0005434727865	9840	Economy	27900.00
0005433235823	9840	Economy	27900.00
0005432199424	9840	Economy	27900.00
0005433290031	9840	Economy	27900.00
0005434552057	9840	Economy	27900.00
0005434727136	9840	Economy	27900.00
0005433235780	9840	Economy	27900.00
0005433181736	9840	Economy	27900.00
0005434551893	9840	Economy	27900.00
0005434727798	9840	Economy	27900.00
0005433235835	9840	Economy	27900.00
0005433235814	9840	Economy	27900.00
0005434735786	9840	Economy	27900.00
0005434032145	9840	Economy	27900.00
0005434727669	9840	Economy	27900.00
0005434552161	9840	Economy	27900.00
0005434552172	9840	Economy	27900.00
0005434727241	9840	Economy	27900.00
0005433235834	9840	Economy	27900.00
0005433235811	9840	Economy	27900.00
0005434727681	9840	Economy	27900.00
0005433181713	9840	Economy	27900.00
0005434551957	9840	Economy	27900.00
0005434551961	9840	Economy	27900.00
0005433181722	9840	Economy	27900.00
0005433235785	9840	Economy	27900.00
0005433113592	9840	Economy	27900.00
0005433181751	9840	Economy	27900.00
0005434551894	9840	Economy	27900.00
0005434728073	9840	Economy	27900.00
0005433181756	9840	Economy	27900.00
0005434552112	9840	Economy	27900.00
0005434727334	9840	Economy	27900.00
0005433235826	9840	Economy	27900.00
0005433766738	9840	Economy	27900.00
0005434727542	9840	Economy	27900.00
0005435142671	9840	Economy	27900.00
0005434551997	9840	Economy	27900.00
0005434552084	9840	Economy	27900.00
0005434727335	9840	Economy	27900.00
0005434727384	9840	Economy	27900.00
0005433766737	9840	Economy	27900.00
0005433235819	9840	Economy	27900.00
0005433181709	9840	Economy	27900.00
0005433181716	9840	Economy	27900.00
0005434552056	9840	Economy	27900.00
0005434727691	9840	Economy	27900.00
0005434735770	9840	Economy	27900.00
0005433235789	9840	Economy	27900.00
0005433290033	9840	Economy	27900.00
0005434552111	9840	Economy	27900.00
0005434727741	9840	Economy	27900.00
0005434552003	9840	Economy	27900.00
0005433181730	9840	Economy	27900.00
0005435142670	9840	Economy	27900.00
0005434727577	9840	Economy	27900.00
0005434727882	9840	Economy	27900.00
0005433235802	9840	Economy	27900.00
0005433129391	9840	Economy	27900.00
0005434726731	9840	Economy	27900.00
0005435142799	9840	Economy	27900.00
0005433126960	9840	Economy	27900.00
0005433235799	9840	Economy	27900.00
0005434727492	9840	Economy	27900.00
0005433235794	9840	Economy	27900.00
0005433181725	9840	Economy	27900.00
0005434552155	9840	Economy	27900.00
0005434727137	9840	Economy	27900.00
0005434728011	9840	Economy	27900.00
0005434727765	9840	Economy	27900.00
0005434727198	9840	Economy	27900.00
0005434727041	9840	Economy	27900.00
0005434727659	9840	Economy	27900.00
0005435142669	9840	Economy	27900.00
0005434727595	9840	Economy	27900.00
0005434727848	9840	Economy	27900.00
0005433181742	9840	Economy	27900.00
0005434727868	9840	Economy	27900.00
0005434302532	9840	Economy	27900.00
0005433181741	9840	Economy	27900.00
0005434727240	9840	Economy	27900.00
0005433181745	9840	Economy	27900.00
0005433181749	9840	Economy	27900.00
0005434552212	9840	Economy	27900.00
0005434727008	9840	Economy	27900.00
0005434727471	9840	Economy	27900.00
0005434727561	9840	Economy	27900.00
0005433181750	9840	Economy	27900.00
0005434731241	9840	Economy	30700.00
0005434727941	9840	Economy	27900.00
0005434727930	9840	Economy	30700.00
0005433235809	9840	Economy	30700.00
0005434727342	9840	Economy	30700.00
0005433181731	9840	Economy	30700.00
0005434552170	9840	Economy	30700.00
0005434727699	9840	Economy	27900.00
0005434552110	9840	Economy	27900.00
0005434731258	9840	Economy	27900.00
0005434727540	9840	Economy	27900.00
0005433181719	9840	Economy	27900.00
0005433235815	9840	Economy	27900.00
0005435142715	9840	Economy	27900.00
0005434731246	9840	Economy	27900.00
0005433126961	9840	Economy	27900.00
0005434727893	9840	Economy	27900.00
0005434727511	9840	Economy	27900.00
0005433181714	9840	Economy	27900.00
0005434551987	9840	Economy	27900.00
0005434552096	9840	Economy	27900.00
0005433235837	9840	Economy	27900.00
0005434727429	9840	Economy	27900.00
0005433235788	9840	Economy	27900.00
0005434731245	9840	Economy	27900.00
0005434727663	9840	Economy	27900.00
0005434727927	9840	Economy	27900.00
0005434727279	9840	Economy	27900.00
0005434727618	9840	Economy	27900.00
0005432199421	9840	Economy	27900.00
0005434727113	9840	Economy	27900.00
0005434735774	9840	Economy	27900.00
0005433235795	9840	Economy	27900.00
0005433235808	9840	Economy	27900.00
0005434551998	9840	Economy	27900.00
0005434727090	9840	Economy	27900.00
0005433235783	9840	Economy	27900.00
0005434552234	9840	Economy	27900.00
0005433181732	9840	Economy	27900.00
0005434727386	9840	Economy	27900.00
0005434302531	9840	Economy	27900.00
0005433235833	9840	Economy	27900.00
0005434727828	9840	Economy	27900.00
0005434551898	9840	Economy	27900.00
0005434735776	9840	Economy	27900.00
0005434727516	9840	Economy	27900.00
0005434728096	9840	Economy	27900.00
0005434727711	9840	Economy	27900.00
0005434727246	9840	Economy	27900.00
0005433766736	9840	Economy	27900.00
0005433235777	9840	Economy	27900.00
0005434727680	9840	Economy	27900.00
0005434727436	9840	Economy	27900.00
0005434552154	9840	Economy	27900.00
0005433126959	9840	Economy	27900.00
0005435142835	9840	Economy	27900.00
0005434727541	9840	Economy	27900.00
0005433181735	9840	Economy	27900.00
0005433181729	9840	Economy	27900.00
0005434032141	9840	Economy	27900.00
0005434727917	9840	Economy	27900.00
0005433113590	9840	Economy	27900.00
0005433235827	9840	Economy	27900.00
0005434727929	9840	Economy	27900.00
0005433181734	9840	Economy	27900.00
0005433181739	9840	Economy	27900.00
0005435142763	9840	Economy	27900.00
0005433235787	9840	Economy	27900.00
0005433126958	9840	Economy	27900.00
0005434735772	9840	Economy	27900.00
0005433235786	9840	Economy	27900.00
0005433181755	9840	Economy	27900.00
0005434552222	9840	Economy	27900.00
0005434727147	9840	Economy	27900.00
0005433129393	9840	Economy	27900.00
0005434551870	9840	Economy	27900.00
0005433235836	9840	Economy	27900.00
0005433129392	9840	Economy	27900.00
0005433235804	9840	Economy	27900.00
0005434552175	9840	Economy	27900.00
0005434727242	9840	Economy	27900.00
0005433235796	9840	Economy	27900.00
0005435142833	9840	Economy	27900.00
0005433235779	9840	Economy	27900.00
0005434551956	9840	Economy	27900.00
0005433235790	9840	Economy	27900.00
0005433235807	9840	Economy	27900.00
0005434727668	9840	Economy	27900.00
0005434551871	9840	Economy	27900.00
0005434727249	9840	Economy	27900.00
0005433235829	9840	Economy	27900.00
0005433235812	9840	Economy	27900.00
0005434727495	9840	Economy	27900.00
0005434727770	9840	Economy	27900.00
0005433290032	9840	Economy	27900.00
0005433181718	9840	Economy	27900.00
0005434728013	9840	Economy	27900.00
0005433181711	9840	Economy	27900.00
0005433235803	9840	Economy	27900.00
0005434552109	9840	Economy	27900.00
0005434727135	9840	Economy	27900.00
0005433235778	9840	Economy	27900.00
0005433290035	9840	Economy	27900.00
0005434727596	9840	Economy	27900.00
0005434552352	9840	Economy	27900.00
0005435214460	7754	Business	42100.00
0005435214581	7754	Business	42100.00
0005432070022	7754	Business	42100.00
0005434069352	7754	Business	42100.00
0005432535958	7754	Business	42100.00
0005434069338	7754	Business	42100.00
0005435214886	7754	Business	42100.00
0005435631011	7754	Business	42100.00
0005435214555	7754	Business	42100.00
0005432150392	7754	Business	42100.00
0005434069381	7754	Business	42100.00
0005432531292	7754	Business	42100.00
0005435214705	7754	Business	42100.00
0005434069355	7754	Business	42100.00
0005434069370	7754	Business	42100.00
0005432531373	7754	Business	42100.00
0005435214763	7754	Business	42100.00
0005434069354	7754	Business	42100.00
0005432531322	7754	Business	42100.00
0005433656741	7754	Business	42100.00
0005434069377	7754	Business	42100.00
0005432531346	7754	Business	42100.00
0005434069379	7754	Business	42100.00
0005432531267	7754	Business	42100.00
0005432070034	7754	Comfort	23900.00
0005432531351	7754	Comfort	23900.00
0005432531377	7754	Comfort	23900.00
0005435214727	7754	Comfort	23900.00
0005432531340	7754	Comfort	23900.00
0005432531319	7754	Comfort	23900.00
0005432531273	7754	Comfort	23900.00
0005435214835	7754	Comfort	23900.00
0005435214773	7754	Comfort	23900.00
0005435214521	7754	Comfort	23900.00
0005432531374	7754	Comfort	23900.00
0005432531370	7754	Comfort	23900.00
0005435214548	7754	Comfort	23900.00
0005435214494	7754	Comfort	23900.00
0005435725669	7754	Comfort	23900.00
0005432531348	7754	Comfort	23900.00
0005435214729	7754	Comfort	23900.00
0005432531375	7754	Comfort	23900.00
0005432531360	7754	Comfort	23900.00
0005435725695	7754	Comfort	23900.00
0005432070024	7754	Comfort	23900.00
0005432531329	7754	Comfort	23900.00
0005434069395	7754	Comfort	23900.00
0005432531287	7754	Comfort	23900.00
0005432531277	7754	Comfort	23900.00
0005432531274	7754	Comfort	23900.00
0005435214916	7754	Comfort	23900.00
0005433656707	7754	Comfort	23900.00
0005432531286	7754	Comfort	23900.00
0005435214636	7754	Comfort	23900.00
0005432531291	7754	Comfort	23900.00
0005432531306	7754	Comfort	23900.00
0005432531301	7754	Comfort	23900.00
0005435214400	7754	Comfort	23900.00
0005432531315	7754	Comfort	23900.00
0005432531342	7754	Comfort	23900.00
0005432531299	7754	Economy	14000.00
0005435214582	7754	Economy	14000.00
0005432531310	7754	Comfort	23900.00
0005434069340	7754	Economy	14000.00
0005432531372	7754	Economy	14000.00
0005435214726	7754	Economy	14000.00
0005435214450	7754	Economy	14000.00
0005434069399	7754	Economy	14000.00
0005432070025	7754	Economy	14000.00
0005434069358	7754	Economy	14000.00
0005435214677	7754	Economy	14000.00
0005434069384	7754	Economy	14000.00
0005432531281	7754	Economy	14000.00
0005435214703	7754	Economy	14000.00
0005432535960	7754	Economy	14000.00
0005435214523	7754	Economy	14000.00
0005432531321	7754	Economy	14000.00
0005432531270	7754	Economy	14000.00
0005435214863	7754	Economy	14000.00
0005434069385	7754	Economy	14000.00
0005432531261	7754	Economy	14000.00
0005432531312	7754	Economy	14000.00
0005432535957	7754	Economy	14000.00
0005434069356	7754	Economy	14000.00
0005432531381	7754	Economy	14000.00
0005434069362	7754	Economy	14000.00
0005434069375	7754	Economy	14000.00
0005434069342	7754	Economy	14000.00
0005434069337	7754	Economy	14000.00
0005435214870	7754	Economy	14000.00
0005434069365	7754	Economy	14000.00
0005434069353	7754	Economy	14000.00
0005434069390	7754	Economy	14000.00
0005435214360	7754	Economy	14000.00
0005432531380	7754	Economy	14000.00
0005432531350	7754	Economy	14000.00
0005432531259	7754	Economy	14000.00
0005432531328	7754	Economy	14000.00
0005432531376	7754	Economy	14000.00
0005432531313	7754	Economy	14000.00
0005434069346	7754	Economy	14000.00
0005432531282	7754	Economy	14000.00
0005435214862	7754	Economy	14000.00
0005435214417	7754	Economy	14000.00
0005432531268	7754	Economy	14000.00
0005432531363	7754	Economy	14000.00
0005432531343	7754	Economy	14000.00
0005432531260	7754	Economy	14000.00
0005432531367	7754	Economy	14000.00
0005432531359	7754	Economy	14000.00
0005432531279	7754	Economy	14000.00
0005432533366	7754	Economy	14000.00
0005432070027	7754	Economy	14000.00
0005432531271	7754	Economy	14000.00
0005432150398	7754	Economy	14000.00
0005434069383	7754	Economy	14000.00
0005432531278	7754	Economy	14000.00
0005435283418	7754	Economy	14000.00
0005435214810	7754	Economy	14000.00
0005434069347	7754	Economy	15400.00
0005435631012	7754	Economy	14000.00
0005432531330	7754	Economy	15400.00
0005435214799	7754	Economy	14000.00
0005432535961	7754	Economy	15400.00
0005432070026	7754	Economy	15400.00
0005434069363	7754	Economy	14000.00
0005432531344	7754	Economy	15400.00
0005432150396	7754	Economy	14000.00
0005435214807	7754	Economy	14000.00
0005432531337	7754	Economy	14000.00
0005433656742	7754	Economy	14000.00
0005434069364	7754	Economy	14000.00
0005432531339	7754	Economy	14000.00
0005434069368	7754	Economy	14000.00
0005435214704	7754	Economy	14000.00
0005435214793	7754	Economy	14000.00
0005432070028	7754	Economy	14000.00
0005435214758	7754	Economy	14000.00
0005435214492	7754	Economy	14000.00
0005435214493	7754	Economy	14000.00
0005434069350	7754	Economy	14000.00
0005432531334	7754	Economy	14000.00
0005435214645	7754	Economy	14000.00
0005435214790	7754	Economy	14000.00
0005434069382	7754	Economy	14000.00
0005435214621	7754	Economy	14000.00
0005432531325	7754	Economy	14000.00
0005432531269	7754	Economy	14000.00
0005434069397	7754	Economy	14000.00
0005432531335	7754	Economy	14000.00
0005435725691	7754	Economy	14000.00
0005435631020	7754	Economy	14000.00
0005432070030	7754	Economy	14000.00
0005435214701	7754	Economy	14000.00
0005434069373	7754	Economy	14000.00
0005435725696	7754	Economy	14000.00
0005432531266	7754	Economy	14000.00
0005434069360	7754	Economy	14000.00
0005434069391	7754	Economy	14000.00
0005432531264	7754	Economy	14000.00
0005432531284	7754	Economy	14000.00
0005434069372	7754	Economy	14000.00
0005435214361	7754	Economy	14000.00
0005435214637	7754	Economy	14000.00
0005432531361	7754	Economy	14000.00
0005435214988	7754	Economy	14000.00
0005434069366	7754	Economy	14000.00
0005434069343	7754	Economy	14000.00
0005434069349	7754	Economy	14000.00
0005434069398	7754	Economy	14000.00
0005432537112	7754	Economy	14000.00
0005432531326	7754	Economy	14000.00
0005432531303	7754	Economy	14000.00
0005435283414	7754	Economy	14000.00
0005434069357	7754	Economy	14000.00
0005432531378	7754	Economy	14000.00
0005434069400	7754	Economy	14000.00
0005434069393	7754	Economy	14000.00
0005432531341	7754	Economy	14000.00
0005435214987	7754	Economy	14000.00
0005432531382	7754	Economy	14000.00
0005434069389	7754	Economy	14000.00
0005432531317	7754	Economy	14000.00
0005434069378	7754	Economy	14000.00
0005432531333	7754	Economy	14000.00
0005432531369	7754	Economy	14000.00
0005434069380	7754	Economy	14000.00
0005435725672	7754	Economy	14000.00
0005434069376	7754	Economy	14000.00
0005432531332	7754	Economy	14000.00
0005432070023	7754	Economy	14000.00
0005432531314	7754	Economy	14000.00
0005432531311	7754	Economy	14000.00
0005432531323	7754	Economy	14000.00
0005432531355	7754	Economy	14000.00
0005432531379	7754	Economy	14000.00
0005434069374	7754	Economy	14000.00
0005435214675	7754	Economy	14000.00
0005432531272	7754	Economy	14000.00
0005432531320	7754	Economy	14000.00
0005435214399	7754	Economy	14000.00
0005432531265	7754	Economy	14000.00
0005432531318	7754	Economy	14000.00
0005432531305	7754	Economy	14000.00
0005432531280	7754	Economy	14000.00
0005432531354	7754	Economy	14000.00
0005432531347	7754	Economy	14000.00
0005432531316	7754	Economy	14000.00
0005432533364	7754	Economy	14000.00
0005435214676	7754	Economy	14000.00
0005432535959	7754	Economy	14000.00
0005432070031	7754	Economy	14000.00
0005432531336	7754	Economy	14000.00
0005434069387	7754	Economy	14000.00
0005435631019	7754	Economy	14000.00
0005432531296	7754	Economy	14000.00
0005435214617	7754	Economy	14000.00
0005435214695	7754	Economy	15400.00
0005432150395	7754	Economy	15400.00
0005432531358	7754	Economy	15400.00
0005435214917	7754	Economy	15400.00
0005432531300	7754	Economy	15400.00
0005432533365	7754	Economy	14000.00
0005434069386	7754	Economy	14000.00
0005432531338	7754	Economy	14000.00
0005434069359	7754	Economy	14000.00
0005435214681	7754	Economy	14000.00
0005432070029	7754	Economy	14000.00
0005434069351	7754	Economy	14000.00
0005435214751	7754	Economy	14000.00
0005432531307	7754	Economy	14000.00
0005434069394	7754	Economy	14000.00
0005432531283	7754	Economy	14000.00
0005432150394	7754	Economy	14000.00
0005435214418	7754	Economy	14000.00
0005432531345	7754	Economy	14000.00
0005432531263	7754	Economy	14000.00
0005435214794	7754	Economy	14000.00
0005432531324	7754	Economy	14000.00
0005435214560	7754	Economy	14000.00
0005435725683	7754	Economy	14000.00
0005432531288	7754	Economy	14000.00
0005435214713	7754	Economy	14000.00
0005433656740	7754	Economy	14000.00
0005432531262	7754	Economy	14000.00
0005432531365	7754	Economy	14000.00
0005435214421	7754	Economy	14000.00
0005432537111	7754	Economy	14000.00
0005432070032	7754	Economy	14000.00
0005432531308	7754	Economy	14000.00
0005432070035	7754	Economy	14000.00
0005434069348	7754	Economy	14000.00
0005432531276	7754	Economy	14000.00
0005432531275	7754	Economy	14000.00
0005435214861	7754	Economy	14000.00
0005432531357	7754	Economy	14000.00
0005434069361	7754	Economy	14000.00
0005432531293	7754	Economy	14000.00
0005432531294	7754	Economy	14000.00
0005435214411	7754	Economy	14000.00
0005432531290	7754	Economy	14000.00
0005435214782	7754	Economy	14000.00
0005434069371	7754	Economy	14000.00
0005434069344	7754	Economy	14000.00
0005435725679	7754	Economy	14000.00
0005432531349	7754	Economy	14000.00
0005432531309	7754	Economy	14000.00
0005434069369	7754	Economy	14000.00
0005434069341	7754	Economy	14000.00
0005432531371	7754	Economy	14000.00
0005435214834	7754	Economy	14000.00
0005432429017	7754	Economy	14000.00
0005434069345	7754	Economy	14000.00
0005432531327	7754	Economy	14000.00
0005432531304	7754	Economy	14000.00
0005432531352	7754	Economy	14000.00
0005435214722	7754	Economy	14000.00
0005432531362	7754	Economy	14000.00
0005435631018	7754	Economy	14000.00
0005432531353	7754	Economy	14000.00
0005435214646	7754	Economy	14000.00
0005435214579	7754	Economy	14000.00
0005432531289	7754	Economy	14000.00
0005432150397	7754	Economy	14000.00
0005432531295	7754	Economy	14000.00
0005432150393	7754	Economy	14000.00
0005432070021	7754	Economy	14000.00
0005432531356	7754	Economy	14000.00
0005435214806	7754	Economy	14000.00
0005435214764	7754	Economy	14000.00
0005432531285	7754	Economy	14000.00
0005435214620	7754	Economy	14000.00
0005435725684	7754	Economy	14000.00
0005435725680	7754	Economy	14000.00
0005435214674	7754	Economy	14000.00
0005432531331	7754	Economy	14000.00
0005432531297	7754	Economy	14000.00
0005432150399	7754	Economy	14000.00
0005432531368	7754	Economy	14000.00
0005435214572	7754	Economy	14000.00
0005435214761	7754	Economy	14000.00
0005434069367	7754	Economy	14000.00
0005433656708	7754	Economy	14000.00
0005434069339	7754	Economy	14000.00
0005432531298	7754	Economy	14000.00
0005432070033	7754	Economy	14000.00
0005432531364	7754	Economy	14000.00
0005434069396	7754	Economy	14000.00
0005435214682	7754	Economy	14000.00
0005432537113	7754	Economy	14000.00
0005434069392	7754	Economy	14000.00
0005432531302	7754	Economy	14000.00
0005434069388	7754	Economy	14000.00
0005435214765	7754	Economy	14000.00
0005433656743	7754	Economy	14000.00
0005432531366	7754	Economy	14000.00
0005435426242	5306	Business	43100.00
0005434573719	5306	Business	43100.00
0005434245529	5306	Business	43100.00
0005435616521	5306	Business	43100.00
0005435097459	5306	Business	43100.00
0005435426148	5306	Business	43100.00
0005435097458	5306	Business	43100.00
0005434245596	5306	Business	43100.00
0005435616559	5306	Business	43100.00
0005435426093	5306	Business	43100.00
0005434245651	5306	Business	43100.00
0005434345145	5306	Business	43100.00
0005435616560	5306	Business	43100.00
0005435555421	5306	Business	43100.00
0005435616515	5306	Business	43100.00
0005435616555	5306	Business	43100.00
0005435426466	5306	Business	43100.00
0005434345125	5306	Business	43100.00
0005435426041	5306	Business	43100.00
0005435426311	5306	Business	43100.00
0005435319713	5306	Business	43100.00
0005435616524	5306	Business	43100.00
0005434245480	5306	Business	43100.00
0005434573713	5306	Business	43100.00
0005435097465	5306	Comfort	24400.00
0005435616539	5306	Comfort	24400.00
0005435426244	5306	Comfort	24400.00
0005432841046	5306	Comfort	24400.00
0005435425774	5306	Comfort	24400.00
0005435097461	5306	Comfort	24400.00
0005435425777	5306	Comfort	24400.00
0005435425989	5306	Comfort	24400.00
0005435616570	5306	Comfort	24400.00
0005435426047	5306	Comfort	24400.00
0005434245578	5306	Comfort	24400.00
0005435616589	5306	Comfort	24400.00
0005432133601	5306	Comfort	24400.00
0005432047648	5306	Comfort	24400.00
0005435426046	5306	Comfort	24400.00
0005432133590	5306	Comfort	24400.00
0005435426086	5306	Comfort	24400.00
0005434345120	5306	Comfort	24400.00
0005435616510	5306	Comfort	24400.00
0005435616565	5306	Comfort	24400.00
0005435426230	5306	Comfort	24400.00
0005434573712	5306	Comfort	24400.00
0005434245363	5306	Comfort	24400.00
0005434573718	5306	Comfort	24400.00
0005434345146	5306	Comfort	24400.00
0005434573711	5306	Comfort	24400.00
0005435426007	5306	Comfort	24400.00
0005434345143	5306	Comfort	24400.00
0005434573721	5306	Comfort	24400.00
0005432133598	5306	Comfort	24400.00
0005435616578	5306	Comfort	24400.00
0005435425939	5306	Comfort	24400.00
0005434345133	5306	Comfort	24400.00
0005435319721	5306	Comfort	24400.00
0005434245420	5306	Comfort	24400.00
0005435616563	5306	Comfort	24400.00
0005435426055	5306	Comfort	24400.00
0005435616508	5306	Comfort	24400.00
0005435616540	5306	Comfort	24400.00
0005435616533	5306	Comfort	24400.00
0005435616596	5306	Comfort	24400.00
0005432133602	5306	Comfort	24400.00
0005435426283	5306	Economy	14400.00
0005435616567	5306	Comfort	24400.00
0005435425919	5306	Economy	14400.00
0005435616509	5306	Economy	14400.00
0005433719182	5306	Economy	14400.00
0005435097468	5306	Economy	14400.00
0005435616512	5306	Economy	14400.00
0005434573717	5306	Economy	14400.00
0005435426105	5306	Economy	14400.00
0005435616546	5306	Economy	14400.00
0005434245485	5306	Economy	14400.00
0005434245419	5306	Economy	14400.00
0005435426291	5306	Economy	14400.00
0005435380381	5306	Economy	14400.00
0005435616561	5306	Economy	14400.00
0005435616586	5306	Economy	14400.00
0005435616528	5306	Economy	14400.00
0005434345116	5306	Economy	14400.00
0005432133589	5306	Economy	14400.00
0005435616574	5306	Economy	14400.00
0005435426237	5306	Economy	14400.00
0005435097467	5306	Economy	14400.00
0005434245537	5306	Economy	14400.00
0005434245429	5306	Economy	14400.00
0005435426117	5306	Economy	14400.00
0005435616600	5306	Economy	14400.00
0005435426033	5306	Economy	14400.00
0005435491497	5306	Economy	14400.00
0005435616588	5306	Economy	14400.00
0005434245581	5306	Economy	14400.00
0005434345140	5306	Economy	14400.00
0005432841050	5306	Economy	14400.00
0005434245587	5306	Economy	14400.00
0005435616564	5306	Economy	14400.00
0005434345151	5306	Economy	14400.00
0005435616543	5306	Economy	14400.00
0005435097464	5306	Economy	14400.00
0005435426262	5306	Economy	14400.00
0005435616584	5306	Economy	14400.00
0005435380353	5306	Economy	14400.00
0005435616522	5306	Economy	14400.00
0005435490322	5306	Economy	14400.00
0005432133596	5306	Economy	14400.00
0005432133603	5306	Economy	14400.00
0005435426240	5306	Economy	14400.00
0005435097463	5306	Economy	14400.00
0005435616550	5306	Economy	14400.00
0005435425686	5306	Economy	14400.00
0005432363477	5306	Economy	14400.00
0005435426164	5306	Economy	14400.00
0005435426149	5306	Economy	14400.00
0005435616592	5306	Economy	14400.00
0005435616577	5306	Economy	14400.00
0005435426000	5306	Economy	14400.00
0005433719194	5306	Economy	14400.00
0005435616513	5306	Economy	14400.00
0005435616527	5306	Economy	14400.00
0005435426359	5306	Economy	14400.00
0005434245503	5306	Economy	14400.00
0005434245595	5306	Economy	14400.00
0005435426376	5306	Economy	14400.00
0005434245534	5306	Economy	14400.00
0005435302274	5306	Economy	14400.00
0005435380405	5306	Economy	14400.00
0005435426263	5306	Economy	14400.00
0005434245387	5306	Economy	14400.00
0005435616579	5306	Economy	15800.00
0005434345150	5306	Economy	15800.00
0005435426056	5306	Economy	15800.00
0005435319712	5306	Economy	14400.00
0005435425685	5306	Economy	14400.00
0005434573720	5306	Economy	15800.00
0005435426312	5306	Economy	14400.00
0005435616597	5306	Economy	15800.00
0005435426301	5306	Economy	14400.00
0005435616593	5306	Economy	14400.00
0005434345129	5306	Economy	14400.00
0005434345138	5306	Economy	14400.00
0005434245292	5306	Economy	14400.00
0005435426290	5306	Economy	14400.00
0005435425929	5306	Economy	14400.00
0005434245368	5306	Economy	14400.00
0005434245407	5306	Economy	14400.00
0005435616595	5306	Economy	14400.00
0005432363466	5306	Economy	14400.00
0005435616572	5306	Economy	14400.00
0005435616523	5306	Economy	14400.00
0005435616514	5306	Economy	14400.00
0005435616581	5306	Economy	14400.00
0005435426375	5306	Economy	14400.00
0005434245423	5306	Economy	14400.00
0005435490323	5306	Economy	14400.00
0005435426174	5306	Economy	14400.00
0005435426232	5306	Economy	14400.00
0005435616566	5306	Economy	14400.00
0005435616547	5306	Economy	14400.00
0005435616571	5306	Economy	14400.00
0005435425954	5306	Economy	14400.00
0005433719183	5306	Economy	14400.00
0005434345117	5306	Economy	14400.00
0005434245406	5306	Economy	14400.00
0005435302267	5306	Economy	14400.00
0005434245366	5306	Economy	14400.00
0005434245653	5306	Economy	14400.00
0005432133593	5306	Economy	14400.00
0005435302297	5306	Economy	14400.00
0005435425976	5306	Economy	14400.00
0005434656584	5306	Economy	14400.00
0005435616542	5306	Economy	14400.00
0005434245463	5306	Economy	14400.00
0005435616587	5306	Economy	14400.00
0005434573716	5306	Economy	14400.00
0005434345131	5306	Economy	14400.00
0005434345123	5306	Economy	14400.00
0005435426276	5306	Economy	14400.00
0005435426034	5306	Economy	14400.00
0005435616526	5306	Economy	14400.00
0005435616544	5306	Economy	14400.00
0005435426277	5306	Economy	14400.00
0005432133599	5306	Economy	14400.00
0005435426236	5306	Economy	14400.00
0005435616582	5306	Economy	14400.00
0005435491496	5306	Economy	14400.00
0005435616530	5306	Economy	14400.00
0005435490320	5306	Economy	14400.00
0005435616517	5306	Economy	14400.00
0005434245464	5306	Economy	14400.00
0005435616516	5306	Economy	14400.00
0005434573710	5306	Economy	14400.00
0005434345149	5306	Economy	14400.00
0005435425983	5306	Economy	14400.00
0005433719195	5306	Economy	14400.00
0005435616518	5306	Economy	14400.00
0005435616531	5306	Economy	14400.00
0005432047645	5306	Economy	14400.00
0005435490321	5306	Economy	14400.00
0005434345126	5306	Economy	14400.00
0005435616532	5306	Economy	14400.00
0005435319732	5306	Economy	14400.00
0005435426243	5306	Economy	14400.00
0005435616576	5306	Economy	14400.00
0005435097462	5306	Economy	14400.00
0005435426238	5306	Economy	14400.00
0005435425947	5306	Economy	14400.00
0005435616538	5306	Economy	14400.00
0005435425974	5306	Economy	14400.00
0005435425973	5306	Economy	14400.00
0005434345152	5306	Economy	14400.00
0005435616552	5306	Economy	14400.00
0005435426314	5306	Economy	14400.00
0005435616519	5306	Economy	14400.00
0005434245567	5306	Economy	14400.00
0005434245562	5306	Economy	14400.00
0005435616553	5306	Economy	14400.00
0005434245428	5306	Economy	14400.00
0005434345128	5306	Economy	14400.00
0005435616594	5306	Economy	14400.00
0005434245414	5306	Economy	14400.00
0005434345134	5306	Economy	14400.00
0005435616534	5306	Economy	14400.00
0005435425886	5306	Economy	14400.00
0005434573715	5306	Economy	14400.00
0005434345124	5306	Economy	14400.00
0005432133592	5306	Economy	14400.00
0005434245540	5306	Economy	14400.00
0005434345122	5306	Economy	14400.00
0005435426162	5306	Economy	14400.00
0005434345141	5306	Economy	14400.00
0005435319722	5306	Economy	14400.00
0005434245580	5306	Economy	14400.00
0005435425658	5306	Economy	14400.00
0005434245411	5306	Economy	14400.00
0005435616545	5306	Economy	14400.00
0005435616585	5306	Economy	14400.00
0005435426231	5306	Economy	14400.00
0005434245515	5306	Economy	14400.00
0005434345136	5306	Economy	14400.00
0005434245545	5306	Economy	14400.00
0005432133595	5306	Economy	15800.00
0005435426051	5306	Economy	14400.00
0005435616529	5306	Economy	15800.00
0005435426239	5306	Economy	15800.00
0005434245565	5306	Economy	15800.00
0005432133594	5306	Economy	14400.00
0005434245367	5306	Economy	14400.00
0005432047649	5306	Economy	14400.00
0005434245444	5306	Economy	14400.00
0005435426163	5306	Economy	14400.00
0005434345147	5306	Economy	14400.00
0005435616536	5306	Economy	14400.00
0005435616601	5306	Economy	14400.00
0005435426001	5306	Economy	14400.00
0005435616535	5306	Economy	14400.00
0005434573709	5306	Economy	14400.00
0005435426464	5306	Economy	14400.00
0005432841048	5306	Economy	14400.00
0005435616549	5306	Economy	14400.00
0005432047646	5306	Economy	14400.00
0005434245586	5306	Economy	14400.00
0005434345127	5306	Economy	14400.00
0005434345142	5306	Economy	14400.00
0005435616599	5306	Economy	14400.00
0005434245465	5306	Economy	14400.00
0005432133600	5306	Economy	14400.00
0005432047647	5306	Economy	14400.00
0005434245574	5306	Economy	14400.00
0005435616569	5306	Economy	14400.00
0005435097460	5306	Economy	14400.00
0005435616583	5306	Economy	14400.00
0005434245479	5306	Economy	14400.00
0005435426360	5306	Economy	14400.00
0005434345121	5306	Economy	14400.00
0005434245422	5306	Economy	14400.00
0005435426465	5306	Economy	14400.00
0005435616556	5306	Economy	14400.00
0005435616558	5306	Economy	14400.00
0005434245293	5306	Economy	14400.00
0005435426403	5306	Economy	14400.00
0005435425861	5306	Economy	14400.00
0005435425948	5306	Economy	14400.00
0005435426109	5306	Economy	14400.00
0005435380380	5306	Economy	14400.00
0005435616568	5306	Economy	14400.00
0005435426377	5306	Economy	14400.00
0005435097466	5306	Economy	14400.00
0005435426166	5306	Economy	14400.00
0005435426014	5306	Economy	14400.00
0005434345118	5306	Economy	14400.00
0005434245542	5306	Economy	14400.00
0005434245556	5306	Economy	14400.00
0005435616551	5306	Economy	14400.00
0005434345144	5306	Economy	14400.00
0005434245652	5306	Economy	14400.00
0005435425885	5306	Economy	14400.00
0005435616525	5306	Economy	14400.00
0005435302296	5306	Economy	14400.00
0005435302259	5306	Economy	14400.00
0005435616554	5306	Economy	14400.00
0005434345132	5306	Economy	14400.00
0005434573714	5306	Economy	14400.00
0005435426247	5306	Economy	14400.00
0005435426092	5306	Economy	14400.00
0005434345130	5306	Economy	14400.00
0005433719186	5306	Economy	14400.00
0005435616548	5306	Economy	14400.00
0005435425975	5306	Economy	14400.00
0005435426168	5306	Economy	14400.00
0005435616537	5306	Economy	14400.00
0005434245426	5306	Economy	14400.00
0005435616511	5306	Economy	14400.00
0005435426027	5306	Economy	14400.00
0005435616580	5306	Economy	14400.00
0005432133591	5306	Economy	14400.00
0005435426110	5306	Economy	14400.00
0005435616575	5306	Economy	14400.00
0005435616562	5306	Economy	14400.00
0005435319757	5306	Economy	14400.00
0005435319733	5306	Economy	14400.00
0005434345148	5306	Economy	14400.00
0005435425884	5306	Economy	14400.00
0005435616590	5306	Economy	14400.00
0005435616541	5306	Economy	14400.00
0005434345119	5306	Economy	14400.00
0005435425990	5306	Economy	14400.00
0005435616557	5306	Economy	14400.00
0005435426052	5306	Economy	14400.00
0005435425904	5306	Economy	14400.00
0005432133597	5306	Economy	14400.00
0005435616591	5306	Economy	14400.00
0005435616520	5306	Economy	14400.00
0005435616598	5306	Economy	14400.00
0005435425928	5306	Economy	14400.00
0005434345139	5306	Economy	14400.00
0005434345115	5306	Economy	14400.00
0005434345135	5306	Economy	14400.00
0005435426036	5306	Economy	14400.00
0005435426087	5306	Economy	14400.00
0005434573708	5306	Economy	14400.00
0005434345137	5306	Economy	14400.00
0005435616573	5306	Economy	14400.00
0005435426197	5306	Economy	14400.00
0005435615798	10894	Business	43100.00
0005432363500	10894	Business	43100.00
0005435615631	10894	Business	43100.00
0005435426542	10894	Business	43100.00
0005435426561	10894	Business	43100.00
0005435615567	10894	Business	43100.00
0005434344784	10894	Business	43100.00
0005435615472	10894	Business	43100.00
0005435615651	10894	Business	43100.00
0005435615562	10894	Business	43100.00
0005435615410	10894	Business	43100.00
0005435615664	10894	Business	43100.00
0005435615358	10894	Business	43100.00
0005432166984	10894	Business	43100.00
0005434573632	10894	Business	43100.00
0005435555406	10894	Business	43100.00
0005435615657	10894	Business	43100.00
0005435615300	10894	Business	43100.00
0005435615770	10894	Business	43100.00
0005434245735	10894	Business	43100.00
0005435615589	10894	Business	43100.00
0005432166983	10894	Business	43100.00
0005435097351	10894	Business	43100.00
0005434344700	10894	Business	43100.00
0005435426597	10894	Comfort	24400.00
0005433719230	10894	Comfort	24400.00
0005435615566	10894	Comfort	24400.00
0005435615641	10894	Comfort	24400.00
0005435304256	10894	Comfort	24400.00
0005434245732	10894	Comfort	24400.00
0005434344707	10894	Comfort	24400.00
0005434245731	10894	Comfort	24400.00
0005435615799	10894	Comfort	24400.00
0005435426550	10894	Comfort	24400.00
0005435097336	10894	Comfort	24400.00
0005432165230	10894	Comfort	24400.00
0005432841066	10894	Comfort	24400.00
0005435426540	10894	Comfort	24400.00
0005435615801	10894	Comfort	24400.00
0005435426572	10894	Comfort	24400.00
0005435615174	10894	Comfort	24400.00
0005434245740	10894	Comfort	24400.00
0005435426546	10894	Comfort	24400.00
0005432363499	10894	Comfort	24400.00
0005435615701	10894	Comfort	24400.00
0005435319798	10894	Comfort	24400.00
0005435615327	10894	Comfort	24400.00
0005435426545	10894	Comfort	24400.00
0005434656607	10894	Comfort	24400.00
0005435426557	10894	Comfort	24400.00
0005434344648	10894	Comfort	24400.00
0005435615796	10894	Comfort	24400.00
0005435615578	10894	Comfort	24400.00
0005435615455	10894	Comfort	24400.00
0005435615354	10894	Comfort	24400.00
0005435615150	10894	Comfort	24400.00
0005435614677	10894	Comfort	24400.00
0005435426534	10894	Comfort	24400.00
0005435615668	10894	Comfort	24400.00
0005435615044	10894	Comfort	24400.00
0005435426552	10894	Comfort	24400.00
0005434344781	10894	Comfort	24400.00
0005435426573	10894	Comfort	24400.00
0005435426556	10894	Economy	14400.00
0005435097335	10894	Comfort	24400.00
0005435426585	10894	Economy	14400.00
0005435426575	10894	Economy	14400.00
0005435615700	10894	Economy	14400.00
0005434573568	10894	Economy	14400.00
0005432165235	10894	Economy	14400.00
0005435615294	10894	Economy	14400.00
0005435426587	10894	Economy	14400.00
0005435615515	10894	Economy	14400.00
0005435426548	10894	Economy	14400.00
0005435426565	10894	Economy	14400.00
0005435615669	10894	Economy	14400.00
0005435615815	10894	Economy	14400.00
0005435426594	10894	Economy	14400.00
0005435490284	10894	Economy	14400.00
0005435615540	10894	Economy	14400.00
0005435426596	10894	Economy	14400.00
0005434656609	10894	Economy	14400.00
0005434573576	10894	Economy	14400.00
0005435426562	10894	Economy	14400.00
0005435426567	10894	Economy	14400.00
0005434245734	10894	Economy	14400.00
0005435426543	10894	Economy	14400.00
0005435319800	10894	Economy	14400.00
0005435491476	10894	Economy	14400.00
0005434344843	10894	Economy	14400.00
0005435615896	10894	Economy	14400.00
0005432165231	10894	Economy	14400.00
0005434245721	10894	Economy	14400.00
0005435555405	10894	Economy	14400.00
0005435615317	10894	Economy	14400.00
0005435615582	10894	Economy	14400.00
0005435615632	10894	Economy	14400.00
0005435615734	10894	Economy	14400.00
0005435615838	10894	Economy	14400.00
0005435426569	10894	Economy	14400.00
0005435615263	10894	Economy	14400.00
0005435615357	10894	Economy	14400.00
0005432166985	10894	Economy	14400.00
0005435615649	10894	Economy	14400.00
0005434245729	10894	Economy	14400.00
0005435615640	10894	Economy	14400.00
0005435426536	10894	Economy	14400.00
0005435615760	10894	Economy	14400.00
0005434344822	10894	Economy	14400.00
0005435616129	10894	Economy	14400.00
0005435615579	10894	Economy	14400.00
0005434245737	10894	Economy	14400.00
0005435042923	10894	Economy	14400.00
0005432165237	10894	Economy	14400.00
0005432166986	10894	Economy	14400.00
0005434344771	10894	Economy	14400.00
0005435426541	10894	Economy	14400.00
0005435615581	10894	Economy	14400.00
0005435426602	10894	Economy	14400.00
0005435615278	10894	Economy	14400.00
0005434344740	10894	Economy	14400.00
0005435615205	10894	Economy	14400.00
0005435615639	10894	Economy	15800.00
0005435615220	10894	Economy	15800.00
0005435615374	10894	Economy	14400.00
0005435616234	10894	Economy	15800.00
0005435614918	10894	Economy	14400.00
0005435426589	10894	Economy	15800.00
0005435615762	10894	Economy	14400.00
0005435305061	10894	Economy	14400.00
0005435615928	10894	Economy	14400.00
0005435304254	10894	Economy	14400.00
0005435097352	10894	Economy	14400.00
0005435615788	10894	Economy	14400.00
0005435615318	10894	Economy	14400.00
0005435426554	10894	Economy	14400.00
0005435615895	10894	Economy	14400.00
0005435304255	10894	Economy	14400.00
0005435426537	10894	Economy	14400.00
0005434344739	10894	Economy	14400.00
0005435426588	10894	Economy	14400.00
0005435426564	10894	Economy	14400.00
0005435555404	10894	Economy	14400.00
0005434245725	10894	Economy	14400.00
0005434344790	10894	Economy	14400.00
0005435615381	10894	Economy	14400.00
0005435615491	10894	Economy	14400.00
0005435426570	10894	Economy	14400.00
0005434344708	10894	Economy	14400.00
0005434245727	10894	Economy	14400.00
0005435305062	10894	Economy	14400.00
0005435615780	10894	Economy	14400.00
0005435319796	10894	Economy	14400.00
0005434344791	10894	Economy	14400.00
0005435426581	10894	Economy	14400.00
0005435615500	10894	Economy	14400.00
0005435426535	10894	Economy	14400.00
0005435426533	10894	Economy	14400.00
0005435615043	10894	Economy	14400.00
0005434344561	10894	Economy	14400.00
0005435305060	10894	Economy	14400.00
0005435491480	10894	Economy	14400.00
0005435615650	10894	Economy	14400.00
0005435615148	10894	Economy	14400.00
0005435615771	10894	Economy	14400.00
0005435304253	10894	Economy	14400.00
0005435426560	10894	Economy	14400.00
0005435426555	10894	Economy	14400.00
0005435615456	10894	Economy	14400.00
0005435615524	10894	Economy	14400.00
0005432841067	10894	Economy	14400.00
0005435615652	10894	Economy	14400.00
0005434245718	10894	Economy	14400.00
0005435615887	10894	Economy	14400.00
0005435616128	10894	Economy	14400.00
0005435319801	10894	Economy	14400.00
0005435615473	10894	Economy	14400.00
0005435615778	10894	Economy	14400.00
0005435426566	10894	Economy	14400.00
0005435097366	10894	Economy	14400.00
0005435426593	10894	Economy	14400.00
0005435097331	10894	Economy	14400.00
0005435097358	10894	Economy	14400.00
0005435615580	10894	Economy	14400.00
0005432841068	10894	Economy	14400.00
0005434344783	10894	Economy	14400.00
0005435426577	10894	Economy	14400.00
0005435426586	10894	Economy	14400.00
0005434245724	10894	Economy	14400.00
0005434344778	10894	Economy	14400.00
0005435426553	10894	Economy	14400.00
0005435615811	10894	Economy	14400.00
0005434344649	10894	Economy	14400.00
0005432363502	10894	Economy	14400.00
0005435615200	10894	Economy	14400.00
0005434245742	10894	Economy	14400.00
0005435615519	10894	Economy	14400.00
0005434245741	10894	Economy	14400.00
0005435615075	10894	Economy	14400.00
0005435615493	10894	Economy	14400.00
0005435615216	10894	Economy	14400.00
0005435615960	10894	Economy	14400.00
0005435615608	10894	Economy	14400.00
0005434245726	10894	Economy	14400.00
0005435615451	10894	Economy	14400.00
0005435615492	10894	Economy	14400.00
0005435426584	10894	Economy	14400.00
0005434344752	10894	Economy	14400.00
0005435615565	10894	Economy	14400.00
0005435426559	10894	Economy	14400.00
0005435426539	10894	Economy	14400.00
0005435097334	10894	Economy	14400.00
0005435426547	10894	Economy	14400.00
0005435426595	10894	Economy	14400.00
0005435615606	10894	Economy	14400.00
0005435042924	10894	Economy	14400.00
0005434573575	10894	Economy	14400.00
0005434245723	10894	Economy	14400.00
0005434344821	10894	Economy	14400.00
0005435097330	10894	Economy	14400.00
0005435304257	10894	Economy	14400.00
0005434344772	10894	Economy	14400.00
0005435615307	10894	Economy	14400.00
0005435426551	10894	Economy	14400.00
0005433719228	10894	Economy	14400.00
0005433719229	10894	Economy	14400.00
0005435426582	10894	Economy	14400.00
0005435426571	10894	Economy	15800.00
0005432363503	10894	Economy	15800.00
0005435615204	10894	Economy	15800.00
0005435615629	10894	Economy	15800.00
0005434245736	10894	Economy	14400.00
0005435615525	10894	Economy	14400.00
0005432363498	10894	Economy	14400.00
0005435615279	10894	Economy	14400.00
0005434656608	10894	Economy	14400.00
0005435319799	10894	Economy	14400.00
0005434245733	10894	Economy	14400.00
0005435615262	10894	Economy	14400.00
0005435615740	10894	Economy	14400.00
0005435426592	10894	Economy	14400.00
0005435615680	10894	Economy	14400.00
0005435615076	10894	Economy	14400.00
0005435615217	10894	Economy	14400.00
0005435426538	10894	Economy	14400.00
0005434344842	10894	Economy	14400.00
0005434344814	10894	Economy	14400.00
0005434344732	10894	Economy	14400.00
0005435319802	10894	Economy	14400.00
0005435426544	10894	Economy	14400.00
0005435615550	10894	Economy	14400.00
0005434245739	10894	Economy	14400.00
0005435615800	10894	Economy	14400.00
0005435426590	10894	Economy	14400.00
0005435615398	10894	Economy	14400.00
0005435319797	10894	Economy	14400.00
0005435555407	10894	Economy	14400.00
0005435426599	10894	Economy	14400.00
0005434344780	10894	Economy	14400.00
0005435615488	10894	Economy	14400.00
0005432363501	10894	Economy	14400.00
0005435426558	10894	Economy	14400.00
0005435615292	10894	Economy	14400.00
0005435426598	10894	Economy	14400.00
0005435615393	10894	Economy	14400.00
0005435615489	10894	Economy	14400.00
0005435615337	10894	Economy	14400.00
0005434245719	10894	Economy	14400.00
0005435615871	10894	Economy	14400.00
0005433719227	10894	Economy	14400.00
0005435615779	10894	Economy	14400.00
0005435615704	10894	Economy	14400.00
0005435426591	10894	Economy	14400.00
0005434245728	10894	Economy	14400.00
0005435615139	10894	Economy	14400.00
0005434344844	10894	Economy	14400.00
0005434245730	10894	Economy	14400.00
0005432165233	10894	Economy	14400.00
0005434344605	10894	Economy	14400.00
0005435615201	10894	Economy	14400.00
0005434245738	10894	Economy	14400.00
0005435426579	10894	Economy	14400.00
0005434245720	10894	Economy	14400.00
0005435615490	10894	Economy	14400.00
0005435615326	10894	Economy	14400.00
0005434344756	10894	Economy	14400.00
0005434245722	10894	Economy	14400.00
0005432165236	10894	Economy	14400.00
0005434573569	10894	Economy	14400.00
0005434245743	10894	Economy	14400.00
0005435426583	10894	Economy	14400.00
0005435615605	10894	Economy	14400.00
0005435042922	10894	Economy	14400.00
0005435615594	10894	Economy	14400.00
0005435426578	10894	Economy	14400.00
0005434573554	10894	Economy	14400.00
0005435615151	10894	Economy	14400.00
0005434573565	10894	Economy	14400.00
0005434573566	10894	Economy	14400.00
0005435616008	10894	Economy	14400.00
0005434344747	10894	Economy	14400.00
0005432165234	10894	Economy	14400.00
0005435426574	10894	Economy	14400.00
0005435615518	10894	Economy	14400.00
0005434344653	10894	Economy	14400.00
0005435615476	10894	Economy	14400.00
0005435615149	10894	Economy	14400.00
0005435615658	10894	Economy	14400.00
0005432165232	10894	Economy	14400.00
0005435615573	10894	Economy	14400.00
0005434344779	10894	Economy	14400.00
0005435615727	10894	Economy	14400.00
0005435426549	10894	Economy	14400.00
0005435615316	10894	Economy	14400.00
0005434344798	10894	Economy	14400.00
0005435426601	10894	Economy	14400.00
0005435426600	10894	Economy	14400.00
0005435426563	10894	Economy	14400.00
0005435097329	10894	Economy	14400.00
0005435426576	10894	Economy	14400.00
0005435615338	10894	Economy	14400.00
0005434344820	10894	Economy	14400.00
0005434344731	10894	Economy	14400.00
0005435426580	10894	Economy	14400.00
0005435426568	10894	Economy	14400.00
0005434344832	10894	Economy	14400.00
0005432460418	3368	Business	18800.00
0005432460698	3368	Business	18800.00
0005432182279	3368	Business	18800.00
0005433806272	3368	Business	18800.00
0005433507649	3368	Business	18800.00
0005432460768	3368	Business	18800.00
0005433806254	3368	Business	18800.00
0005433634677	3368	Business	18800.00
0005433806261	3368	Business	18800.00
0005433806264	3368	Business	18800.00
0005433634690	3368	Business	18800.00
0005433634704	3368	Business	18800.00
0005432460406	3368	Business	18800.00
0005433634691	3368	Business	18800.00
0005432182282	3368	Business	18800.00
0005433634700	3368	Business	18800.00
0005433634687	3368	Business	18800.00
0005433507656	3368	Business	18800.00
0005432182292	3368	Business	18800.00
0005433806269	3368	Business	18800.00
0005432460877	3368	Business	18800.00
0005432182283	3368	Business	18800.00
0005432182290	3368	Business	18800.00
0005432460777	3368	Business	18800.00
0005433634710	3368	Business	18800.00
0005432460453	3368	Business	18800.00
0005432182280	3368	Business	18800.00
0005433806258	3368	Business	18800.00
0005433634695	3368	Economy	6900.00
0005433806280	3368	Economy	6900.00
0005432460581	3368	Economy	6900.00
0005433507651	3368	Economy	6900.00
0005432460868	3368	Economy	6900.00
0005433507647	3368	Economy	6900.00
0005433806251	3368	Economy	6300.00
0005433634683	3368	Economy	6300.00
0005433507646	3368	Economy	6300.00
0005432460634	3368	Economy	6300.00
0005433507645	3368	Economy	6300.00
0005433634696	3368	Economy	6300.00
0005432460984	3368	Economy	6300.00
0005432460700	3368	Economy	6300.00
0005432182294	3368	Economy	6300.00
0005433634680	3368	Economy	6300.00
0005432460560	3368	Economy	6300.00
0005433507650	3368	Economy	6300.00
0005432182281	3368	Economy	6300.00
0005433634694	3368	Economy	6300.00
0005432460718	3368	Economy	6300.00
0005432460964	3368	Economy	6300.00
0005432182296	3368	Economy	6300.00
0005432460844	3368	Economy	6300.00
0005433634701	3368	Economy	6300.00
0005432460905	3368	Economy	6300.00
0005433806278	3368	Economy	6300.00
0005433634685	3368	Economy	6300.00
0005433634684	3368	Economy	6300.00
0005432460763	3368	Economy	6300.00
0005432182277	3368	Economy	6300.00
0005432182285	3368	Economy	6300.00
0005432182291	3368	Economy	6300.00
0005432460553	3368	Economy	6300.00
0005433806257	3368	Economy	6300.00
0005432460762	3368	Economy	6300.00
0005433634703	3368	Economy	6300.00
0005432460561	3368	Economy	6300.00
0005433806247	3368	Economy	6300.00
0005433806255	3368	Economy	6300.00
0005433634689	3368	Economy	6300.00
0005433806274	3368	Economy	6300.00
0005432460622	3368	Economy	6300.00
0005433806260	3368	Economy	6300.00
0005432460474	3368	Economy	6300.00
0005433634709	3368	Economy	6300.00
0005432460495	3368	Economy	6300.00
0005433806263	3368	Economy	6300.00
0005433806267	3368	Economy	6300.00
0005433634698	3368	Economy	6300.00
0005432460823	3368	Economy	6300.00
0005433806259	3368	Economy	6300.00
0005432460405	3368	Economy	6300.00
0005433806271	3368	Economy	6300.00
0005432460562	3368	Economy	6300.00
0005432182286	3368	Economy	6300.00
0005433634708	3368	Economy	6300.00
0005433507659	3368	Economy	6300.00
0005433507652	3368	Economy	6300.00
0005433806273	3368	Economy	6300.00
0005432460794	3368	Economy	6300.00
0005432460681	3368	Economy	6300.00
0005433634711	3368	Economy	6300.00
0005432460454	3368	Economy	6300.00
0005432460846	3368	Economy	6300.00
0005433806277	3368	Economy	6300.00
0005432182288	3368	Economy	6900.00
0005432460462	3368	Economy	6900.00
0005432460842	3368	Economy	6900.00
0005433634679	3368	Economy	6900.00
0005432460475	3368	Economy	6300.00
0005433634682	3368	Economy	6300.00
0005433806252	3368	Economy	6300.00
0005432182278	3368	Economy	6300.00
0005432460783	3368	Economy	6900.00
0005433507661	3368	Economy	6300.00
0005433634697	3368	Economy	6300.00
0005432460843	3368	Economy	6300.00
0005433634706	3368	Economy	6300.00
0005433634688	3368	Economy	6300.00
0005433806283	3368	Economy	6300.00
0005432460579	3368	Economy	6300.00
0005432460671	3368	Economy	6300.00
0005433806265	3368	Economy	6300.00
0005432460672	3368	Economy	6300.00
0005433806281	3368	Economy	6300.00
0005433634686	3368	Economy	6300.00
0005433806276	3368	Economy	6300.00
0005432460891	3368	Economy	6300.00
0005432460724	3368	Economy	6300.00
0005433634702	3368	Economy	6300.00
0005432460678	3368	Economy	6300.00
0005433806248	3368	Economy	6300.00
0005433634707	3368	Economy	6300.00
0005433507657	3368	Economy	6300.00
0005433806284	3368	Economy	6300.00
0005432182289	3368	Economy	6300.00
0005432460621	3368	Economy	6300.00
0005432460752	3368	Economy	6300.00
0005433507660	3368	Economy	6300.00
0005433806270	3368	Economy	6300.00
0005433806262	3368	Economy	6300.00
0005433806249	3368	Economy	6300.00
0005433806266	3368	Economy	6300.00
0005433507654	3368	Economy	6300.00
0005432182284	3368	Economy	6300.00
0005433806279	3368	Economy	6300.00
0005432460620	3368	Economy	6300.00
0005432182287	3368	Economy	6300.00
0005433806275	3368	Economy	6300.00
0005432460736	3368	Economy	6300.00
0005433507653	3368	Economy	6300.00
0005432182295	3368	Economy	6300.00
0005432460824	3368	Economy	6300.00
0005433806285	3368	Economy	6300.00
0005434143753	3368	Economy	6300.00
0005433806268	3368	Economy	6300.00
0005432460706	3368	Economy	6300.00
0005433634678	3368	Economy	6300.00
0005432460784	3368	Economy	6300.00
0005432460919	3368	Economy	6300.00
0005433634699	3368	Economy	6300.00
0005432460785	3368	Economy	6300.00
0005432460786	3368	Economy	6300.00
0005433806256	3368	Economy	6300.00
0005433806282	3368	Economy	6300.00
0005433634693	3368	Economy	6300.00
0005433507658	3368	Economy	6300.00
0005432460580	3368	Economy	6300.00
0005433507655	3368	Economy	6300.00
0005433634692	3368	Economy	6300.00
0005433634705	3368	Economy	6300.00
0005433634681	3368	Economy	6300.00
0005432460682	3368	Economy	6300.00
0005433806250	3368	Economy	6300.00
0005433507648	3368	Economy	6300.00
0005432460867	3368	Economy	6300.00
0005433806253	3368	Economy	6300.00
0005432182293	3368	Economy	6300.00
0005435886052	3372	Business	18800.00
0005435886215	3372	Business	18800.00
0005435886201	3372	Business	18800.00
0005435886030	3372	Business	18800.00
0005435886056	3372	Business	18800.00
0005435885962	3372	Business	18800.00
0005435886210	3372	Business	18800.00
0005435886121	3372	Business	18800.00
0005435886147	3372	Business	18800.00
0005435885968	3372	Economy	6900.00
0005435886068	3372	Economy	6300.00
0005435886317	3372	Economy	6300.00
0005435886160	3372	Economy	6300.00
0005435885959	3372	Economy	6300.00
0005435886244	3372	Economy	6300.00
0005435885967	3372	Economy	6300.00
0005435886055	3372	Economy	6300.00
0005435886263	3372	Economy	6300.00
0005435886316	3372	Economy	6300.00
0005435886267	3372	Economy	6300.00
0005435886141	3372	Economy	6300.00
0005435886114	3372	Economy	6300.00
0005435886391	3372	Economy	6300.00
0005435886246	3372	Economy	6300.00
0005435886186	3372	Economy	6300.00
0005435886258	3372	Economy	6300.00
0005435886135	3372	Economy	6300.00
0005435886185	3372	Economy	6900.00
0005435886259	3372	Economy	6900.00
0005435886119	3372	Economy	6300.00
0005435885969	3372	Economy	6300.00
0005435886142	3372	Economy	6300.00
0005435886270	3372	Economy	6300.00
0005435886260	3372	Economy	6300.00
0005435886245	3372	Economy	6300.00
0005435886120	3372	Economy	6300.00
0005435886159	3372	Economy	6300.00
0005435885963	3372	Economy	6300.00
0005435886118	3372	Economy	6300.00
0005435886140	3372	Economy	6300.00
0005435886127	3372	Economy	6300.00
0005435886354	3372	Economy	6300.00
0005435886124	3372	Economy	6300.00
0005435886115	3372	Economy	6300.00
0005435886501	8308	Business	18800.00
0005432461238	8308	Business	18800.00
0005432461217	8308	Business	18800.00
0005433507477	8308	Business	18800.00
0005432461242	8308	Business	18800.00
0005432461220	8308	Business	18800.00
0005432461229	8308	Business	18800.00
0005432043071	8308	Business	18800.00
0005433507450	8308	Business	18800.00
0005435886500	8308	Business	18800.00
0005432461241	8308	Business	18800.00
0005434312373	8308	Business	18800.00
0005435886482	8308	Business	18800.00
0005432461240	8308	Business	18800.00
0005432461224	8308	Business	18800.00
0005433507392	8308	Business	18800.00
0005435886499	8308	Business	18800.00
0005432043077	8308	Business	18800.00
0005435886492	8308	Business	18800.00
0005432461211	8308	Business	18800.00
0005435886497	8308	Economy	6900.00
0005435886479	8308	Economy	6900.00
0005435886514	8308	Economy	6900.00
0005432461207	8308	Economy	6900.00
0005433507484	8308	Economy	6900.00
0005435886489	8308	Economy	6300.00
0005435886505	8308	Economy	6300.00
0005433507500	8308	Economy	6300.00
0005432043075	8308	Economy	6300.00
0005435886477	8308	Economy	6300.00
0005432043067	8308	Economy	6300.00
0005435886513	8308	Economy	6300.00
0005432461203	8308	Economy	6300.00
0005432043079	8308	Economy	6300.00
0005434312391	8308	Economy	6300.00
0005432461245	8308	Economy	6300.00
0005433507494	8308	Economy	6300.00
0005435886504	8308	Economy	6300.00
0005435886508	8308	Economy	6300.00
0005435886495	8308	Economy	6300.00
0005432461232	8308	Economy	6300.00
0005432461198	8308	Economy	6300.00
0005435142994	8308	Economy	6300.00
0005433507475	8308	Economy	6300.00
0005432043068	8308	Economy	6300.00
0005435886509	8308	Economy	6300.00
0005433507495	8308	Economy	6300.00
0005435886481	8308	Economy	6300.00
0005435886503	8308	Economy	6300.00
0005432461206	8308	Economy	6300.00
0005435886491	8308	Economy	6300.00
0005432461228	8308	Economy	6300.00
0005435886518	8308	Economy	6300.00
0005432461209	8308	Economy	6300.00
0005435886483	8308	Economy	6300.00
0005432043074	8308	Economy	6300.00
0005434326097	8308	Economy	6300.00
0005432461239	8308	Economy	6300.00
0005432043076	8308	Economy	6300.00
0005435886515	8308	Economy	6300.00
0005432043078	8308	Economy	6300.00
0005432461221	8308	Economy	6300.00
0005432461212	8308	Economy	6300.00
0005432043072	8308	Economy	6300.00
0005432043069	8308	Economy	6300.00
0005432461231	8308	Economy	6300.00
0005432461216	8308	Economy	6300.00
0005432461227	8308	Economy	6300.00
0005433507447	8308	Economy	6300.00
0005432461201	8308	Economy	6300.00
0005433507435	8308	Economy	6300.00
0005432461219	8308	Economy	6300.00
0005432043070	8308	Economy	6300.00
0005435886487	8308	Economy	6300.00
0005433507407	8308	Economy	6300.00
0005433507485	8308	Economy	6300.00
0005433507480	8308	Economy	6300.00
0005434326098	8308	Economy	6300.00
0005435886498	8308	Economy	6900.00
0005435142993	8308	Economy	6900.00
0005435886485	8308	Economy	6900.00
0005432461213	8308	Economy	6900.00
0005432461235	8308	Economy	6900.00
0005432461223	8308	Economy	6300.00
0005432461218	8308	Economy	6300.00
0005432461200	8308	Economy	6300.00
0005434326290	8308	Economy	6300.00
0005432461205	8308	Economy	6900.00
0005432461243	8308	Economy	6300.00
0005432461215	8308	Economy	6300.00
0005435886511	8308	Economy	6300.00
0005434326096	8308	Economy	6300.00
0005432461237	8308	Economy	6300.00
0005435142992	8308	Economy	6300.00
0005432461214	8308	Economy	6300.00
0005432461208	8308	Economy	6300.00
0005434326289	8308	Economy	6300.00
0005432461230	8308	Economy	6300.00
0005435886490	8308	Economy	6300.00
0005434312392	8308	Economy	6300.00
0005432461204	8308	Economy	6300.00
0005432461244	8308	Economy	6300.00
0005432461247	8308	Economy	6300.00
0005432461234	8308	Economy	6300.00
0005432461222	8308	Economy	6300.00
0005433507481	8308	Economy	6300.00
0005435886516	8308	Economy	6300.00
0005432461236	8308	Economy	6300.00
0005434326292	8308	Economy	6300.00
0005434326291	8308	Economy	6300.00
0005432043066	8308	Economy	6300.00
0005435886507	8308	Economy	6300.00
0005432461246	8308	Economy	6300.00
0005432461199	8308	Economy	6300.00
0005435142995	8308	Economy	6300.00
0005435886488	8308	Economy	6300.00
0005435886496	8308	Economy	6300.00
0005435886517	8308	Economy	6300.00
0005435886486	8308	Economy	6300.00
0005435886480	8308	Economy	6300.00
0005432461210	8308	Economy	6300.00
0005432461248	8308	Economy	6300.00
0005432461202	8308	Economy	6300.00
0005432461252	8308	Economy	6300.00
0005435886478	8308	Economy	6300.00
0005435886484	8308	Economy	6300.00
0005435886519	8308	Economy	6300.00
0005432461233	8308	Economy	6300.00
0005432461226	8308	Economy	6300.00
0005432043073	8308	Economy	6300.00
0005435886493	8308	Economy	6300.00
0005435886512	8308	Economy	6300.00
0005435886510	8308	Economy	6300.00
0005435886502	8308	Economy	6300.00
0005435886494	8308	Economy	6300.00
0005434312375	8308	Economy	6300.00
0005435886506	8308	Economy	6300.00
0005434312374	8308	Economy	6300.00
0005432461225	8308	Economy	6300.00
0005432461249	8308	Economy	6300.00
0005432461251	8308	Economy	6300.00
0005432461250	8308	Economy	6300.00
0005433507486	8308	Economy	6300.00
0005435142991	8308	Economy	6300.00
0005433507478	8308	Economy	6300.00
0005433507458	8308	Economy	6300.00
0005433806017	8291	Business	18800.00
0005433805973	8291	Business	18800.00
0005433806082	8291	Business	18800.00
0005433634446	8291	Business	18800.00
0005433634360	8291	Business	18800.00
0005433634272	8291	Business	18800.00
0005433805957	8291	Business	18800.00
0005433634347	8291	Business	18800.00
0005434271347	8291	Business	18800.00
0005433805759	8291	Business	18800.00
0005433805950	8291	Business	18800.00
0005433805948	8291	Economy	6900.00
0005433634371	8291	Economy	6900.00
0005433805952	8291	Economy	6300.00
0005435860673	8291	Economy	6300.00
0005433634348	8291	Economy	6300.00
0005433634343	8291	Economy	6300.00
0005435860669	8291	Economy	6300.00
0005433634276	8291	Economy	6300.00
0005433805848	8291	Economy	6300.00
0005433806066	8291	Economy	6300.00
0005433634445	8291	Economy	6300.00
0005433634480	8291	Economy	6300.00
0005433806003	8291	Economy	6300.00
0005433634427	8291	Economy	6300.00
0005435860668	8291	Economy	6300.00
0005434143746	8291	Economy	6300.00
0005433634426	8291	Economy	6300.00
0005435860677	8291	Economy	6300.00
0005434143745	8291	Economy	6300.00
0005433634570	8291	Economy	6300.00
0005433805949	8291	Economy	6300.00
0005435860670	8291	Economy	6300.00
0005433634346	8291	Economy	6300.00
0005433806016	8291	Economy	6300.00
0005433806002	8291	Economy	6300.00
0005433805943	8291	Economy	6900.00
0005433805860	8291	Economy	6300.00
0005435860678	8291	Economy	6300.00
0005433806052	8291	Economy	6300.00
0005435860675	8291	Economy	6300.00
0005435860671	8291	Economy	6300.00
0005435860674	8291	Economy	6300.00
0005433805794	8291	Economy	6300.00
0005433806038	8291	Economy	6300.00
0005435860679	8291	Economy	6300.00
0005433634396	8291	Economy	6300.00
0005435860667	8291	Economy	6300.00
0005433634361	8291	Economy	6300.00
0005433805758	8291	Economy	6300.00
0005433806065	8291	Economy	6300.00
0005433634313	8291	Economy	6300.00
0005433806029	8291	Economy	6300.00
0005433634572	8291	Economy	6300.00
0005433805861	8291	Economy	6300.00
0005435860672	8291	Economy	6300.00
0005433634271	8291	Economy	6300.00
0005433634571	8291	Economy	6300.00
0005433634428	8291	Economy	6300.00
0005433805901	8291	Economy	6300.00
0005433805795	8291	Economy	6300.00
0005435860676	8291	Economy	6300.00
0005433806018	8291	Economy	6300.00
0005433634372	8291	Economy	6300.00
0005433634388	8291	Economy	6300.00
0005433805953	8291	Economy	6300.00
0005433634275	8291	Economy	6300.00
0005434183610	8286	Economy	6300.00
0005432384196	4626	Business	9900.00
0005433722405	4626	Business	9900.00
0005433722407	4626	Business	9900.00
0005433722398	4626	Business	9900.00
0005432384182	4626	Business	9900.00
0005432384193	4626	Business	9900.00
0005433453812	4626	Business	9900.00
0005432384180	4626	Business	9900.00
0005433722391	4626	Economy	3300.00
0005432384167	4626	Economy	3300.00
0005432728264	4626	Economy	3300.00
0005433722401	4626	Economy	3300.00
0005433722396	4626	Economy	3300.00
0005433722392	4626	Economy	3300.00
0005433722408	4626	Economy	3300.00
0005433722403	4626	Economy	3300.00
0005432384187	4626	Economy	3600.00
0005432384165	4626	Economy	3600.00
0005432384174	4626	Economy	3600.00
0005433722406	4626	Economy	3600.00
0005432384176	4626	Economy	3300.00
0005432384185	4626	Economy	3300.00
0005432728257	4626	Economy	3300.00
0005433722404	4626	Economy	3300.00
0005432384177	4626	Economy	3300.00
0005432384166	4626	Economy	3300.00
0005433722393	4626	Economy	3300.00
0005432384178	4626	Economy	3300.00
0005433722402	4626	Economy	3300.00
0005433453813	4626	Economy	3300.00
0005433722400	4626	Economy	3300.00
0005432728259	4626	Economy	3300.00
0005432384170	4626	Economy	3300.00
0005432384169	4626	Economy	3300.00
0005432384184	4626	Economy	3300.00
0005432728258	4626	Economy	3300.00
0005432728254	4626	Economy	3300.00
0005432384186	4626	Economy	3300.00
0005432384183	4626	Economy	3300.00
0005433454929	4626	Economy	3300.00
0005432384191	4626	Economy	3300.00
0005432728262	4626	Economy	3300.00
0005432728255	4626	Economy	3300.00
0005432728261	4626	Economy	3300.00
0005432728260	4626	Economy	3300.00
0005432384172	4626	Economy	3300.00
0005432384181	4626	Economy	3300.00
0005432384195	4626	Economy	3300.00
0005433722399	4626	Economy	3300.00
0005432384163	4626	Economy	3300.00
0005432728263	4626	Economy	3300.00
0005432384173	4626	Economy	3300.00
0005432384175	4626	Economy	3300.00
0005432384164	4626	Economy	3300.00
0005432384190	4626	Economy	3300.00
0005432384188	4626	Economy	3300.00
0005432384197	4626	Economy	3300.00
0005432728256	4626	Economy	3300.00
0005432384161	4626	Economy	3300.00
0005432384189	4626	Economy	3300.00
0005432384179	4626	Economy	3300.00
0005433722395	4626	Economy	3300.00
0005432384162	4626	Economy	3300.00
0005432384192	4626	Economy	3300.00
0005433722409	4626	Economy	3300.00
0005432384168	4626	Economy	3300.00
0005432384194	4626	Economy	3300.00
0005433722394	4626	Economy	3300.00
0005432384171	4626	Economy	3300.00
0005433722397	4626	Economy	3300.00
0005432728253	4626	Economy	3300.00
0005432383688	30157	Business	9900.00
0005433722306	30157	Business	9900.00
0005432728170	30157	Business	9900.00
0005432383778	30157	Business	9900.00
0005432728171	30157	Business	9900.00
0005432383736	30157	Business	9900.00
0005432728173	30157	Business	9900.00
0005432383741	30157	Economy	3300.00
0005432383673	30157	Economy	3300.00
0005432383746	30157	Economy	3300.00
0005432383806	30157	Economy	3300.00
0005432383802	30157	Economy	3300.00
0005432728145	30157	Economy	3300.00
0005432728174	30157	Economy	3300.00
0005432728144	30157	Economy	3300.00
0005432383715	30157	Economy	3600.00
0005432383591	30157	Economy	3600.00
0005432383618	30157	Economy	3600.00
0005432383807	30157	Economy	3600.00
0005432383808	30157	Economy	3300.00
0005433451653	30157	Economy	3300.00
0005432383669	30157	Economy	3300.00
0005432383627	30157	Economy	3300.00
0005432383714	30157	Economy	3300.00
0005432383687	30157	Economy	3300.00
0005433722297	30157	Economy	3300.00
0005432383777	30157	Economy	3300.00
0005432383671	30157	Economy	3300.00
0005432728137	30157	Economy	3300.00
0005432728195	30157	Economy	3300.00
0005432383699	30157	Economy	3300.00
0005432728179	30157	Economy	3300.00
0005432383698	30157	Economy	3300.00
0005432383697	30157	Economy	3300.00
0005432383615	30157	Economy	3300.00
0005432383752	30157	Economy	3300.00
0005432383710	30157	Economy	3300.00
0005432383849	30157	Economy	3300.00
0005432383668	30157	Economy	3300.00
0005432728180	30157	Economy	3300.00
0005432383751	30157	Economy	3300.00
0005432383709	30157	Economy	3300.00
0005432383706	30157	Economy	3300.00
0005432383750	30157	Economy	3300.00
0005432728153	30157	Economy	3300.00
0005432728162	30157	Economy	3300.00
0005432728172	30157	Economy	3300.00
0005432728128	30157	Economy	3300.00
0005432383670	30157	Economy	3300.00
0005433451645	30157	Economy	3300.00
0005433722296	30157	Economy	3300.00
0005433451654	30157	Economy	3300.00
0005432383717	30157	Economy	3300.00
0005433453787	30157	Economy	3300.00
0005432728169	30157	Economy	3300.00
0005432383648	30157	Economy	3300.00
0005433722309	30157	Economy	3300.00
0005432383732	30157	Economy	3300.00
0005432728168	30157	Economy	3300.00
0005432383696	30157	Economy	3300.00
0005432728152	30157	Economy	3300.00
0005432383626	30157	Economy	3300.00
0005432728146	30157	Economy	3300.00
0005432383533	30157	Economy	3300.00
0005432383731	30157	Economy	3300.00
0005435529820	1730	Business	57200.00
0005435529809	1730	Business	57200.00
0005435541562	1730	Business	57200.00
0005435530114	1730	Business	57200.00
0005433517128	1730	Business	57200.00
0005435541566	1730	Business	57200.00
0005435541552	1730	Business	57200.00
0005435529810	1730	Business	57200.00
0005435541553	1730	Economy	19100.00
0005435541557	1730	Economy	19100.00
0005433517129	1730	Economy	19100.00
0005432925130	1730	Economy	19100.00
0005435530109	1730	Economy	19100.00
0005435541560	1730	Economy	19100.00
0005433517133	1730	Economy	19100.00
0005435541570	1730	Economy	19100.00
0005432925105	1730	Economy	21000.00
0005435529826	1730	Economy	21000.00
0005435530104	1730	Economy	21000.00
0005435530115	1730	Economy	21000.00
0005433517127	1730	Economy	19100.00
0005435530118	1730	Economy	19100.00
0005435529813	1730	Economy	19100.00
0005432294549	1730	Economy	19100.00
0005435541561	1730	Economy	19100.00
0005435530105	1730	Economy	19100.00
0005432294548	1730	Economy	19100.00
0005435529818	1730	Economy	19100.00
0005435529822	1730	Economy	19100.00
0005435530106	1730	Economy	19100.00
0005435530108	1730	Economy	19100.00
0005435529814	1730	Economy	19100.00
0005435541564	1730	Economy	19100.00
0005432294550	1730	Economy	19100.00
0005433517131	1730	Economy	19100.00
0005435529817	1730	Economy	19100.00
0005435541572	1730	Economy	19100.00
0005435529827	1730	Economy	19100.00
0005435530112	1730	Economy	19100.00
0005435529824	1730	Economy	19100.00
0005435541559	1730	Economy	19100.00
0005435541565	1730	Economy	19100.00
0005435529808	1730	Economy	19100.00
0005435541563	1730	Economy	19100.00
0005435529823	1730	Economy	19100.00
0005435530111	1730	Economy	19100.00
0005435530116	1730	Economy	19100.00
0005435530103	1730	Economy	19100.00
0005435529815	1730	Economy	19100.00
0005435541571	1730	Economy	19100.00
0005435530110	1730	Economy	19100.00
0005435530113	1730	Economy	19100.00
0005435529819	1730	Economy	19100.00
0005435529811	1730	Economy	19100.00
0005433517130	1730	Economy	19100.00
0005435529816	1730	Economy	19100.00
0005435529812	1730	Economy	19100.00
0005435541554	1730	Economy	19100.00
0005433517126	1730	Economy	19100.00
0005435541569	1730	Economy	19100.00
0005435529821	1730	Economy	19100.00
0005432925107	1730	Economy	19100.00
0005435541555	1730	Economy	19100.00
0005432925118	1730	Economy	19100.00
0005435530107	1730	Economy	19100.00
0005435529825	1730	Economy	19100.00
0005435541567	1730	Economy	19100.00
0005435541558	1730	Economy	19100.00
0005435541568	1730	Economy	19100.00
0005435530117	1730	Economy	19100.00
0005433517125	1730	Economy	19100.00
0005435530102	1730	Economy	19100.00
0005432925106	1730	Economy	19100.00
0005433517132	1730	Economy	19100.00
0005432925117	1730	Economy	19100.00
0005435541556	1730	Economy	19100.00
0005433517060	21975	Business	57200.00
0005435518218	21975	Business	57200.00
0005432925159	21975	Business	57200.00
0005435518269	21975	Business	57200.00
0005435541442	21975	Business	57200.00
0005435541396	21975	Business	57200.00
0005435518215	21975	Business	57200.00
0005435541422	21975	Economy	19100.00
0005435518221	21975	Economy	19100.00
0005435541326	21975	Economy	19100.00
0005433517103	21975	Economy	19100.00
0005435518179	21975	Economy	19100.00
0005432925161	21975	Economy	19100.00
0005435518234	21975	Economy	19100.00
0005435518156	21975	Economy	21000.00
0005435518206	21975	Economy	21000.00
0005435541330	21975	Economy	19100.00
0005435518187	21975	Economy	19100.00
0005433517101	21975	Economy	19100.00
0005435518166	21975	Economy	19100.00
0005435518217	21975	Economy	19100.00
0005435518168	21975	Economy	19100.00
0005435541319	21975	Economy	19100.00
0005435518170	21975	Economy	19100.00
0005435518125	21975	Economy	19100.00
0005435541360	21975	Economy	19100.00
0005435541423	21975	Economy	19100.00
0005435541362	21975	Economy	19100.00
0005433517039	21975	Economy	19100.00
0005435541329	21975	Economy	19100.00
0005435541345	21975	Economy	19100.00
0005435518167	21975	Economy	19100.00
0005433517061	21975	Economy	19100.00
0005435518178	21975	Economy	19100.00
0005435541297	21975	Economy	19100.00
0005433517062	21975	Economy	19100.00
0005435518180	21975	Economy	19100.00
0005435541392	21975	Economy	19100.00
0005435518231	21975	Economy	19100.00
0005435518219	21975	Economy	19100.00
0005435518233	21975	Economy	19100.00
0005435518155	21975	Economy	19100.00
0005435518177	21975	Economy	19100.00
0005433517059	21975	Economy	19100.00
0005432925160	21975	Economy	19100.00
0005435518190	21975	Economy	19100.00
0005435541320	21975	Economy	19100.00
0005435541296	21975	Economy	19100.00
0005435541443	21975	Economy	19100.00
0005435518169	21975	Economy	19100.00
0005435541305	21975	Economy	19100.00
0005433517102	21975	Economy	19100.00
0005435541306	21975	Economy	19100.00
0005435518268	21975	Economy	19100.00
0005433517058	21975	Economy	19100.00
0005435541397	21975	Economy	19100.00
0005432839815	7369	Business	18500.00
0005434664990	7369	Business	18500.00
0005435253051	7369	Business	18500.00
0005435491471	7369	Business	18500.00
0005432073480	7369	Business	18500.00
0005432839813	7369	Business	18500.00
0005434459345	7369	Business	18500.00
0005432839832	7369	Business	18500.00
0005435253072	7369	Business	18500.00
0005432839830	7369	Business	18500.00
0005435252978	7369	Economy	6200.00
0005432839835	7369	Economy	6200.00
0005435491477	7369	Economy	6200.00
0005435491470	7369	Economy	6200.00
0005432839826	7369	Economy	6200.00
0005432839827	7369	Economy	6200.00
0005432073479	7369	Economy	6200.00
0005432839825	7369	Economy	6200.00
0005432823499	7369	Economy	6800.00
0005432073478	7369	Economy	6800.00
0005432073482	7369	Economy	6800.00
0005434459335	7369	Economy	6800.00
0005434459336	7369	Economy	6200.00
0005434459328	7369	Economy	6200.00
0005435252934	7369	Economy	6200.00
0005434459340	7369	Economy	6200.00
0005432841064	7369	Economy	6200.00
0005434459333	7369	Economy	6200.00
0005435252842	7369	Economy	6200.00
0005432839837	7369	Economy	6200.00
0005432839836	7369	Economy	6200.00
0005432839818	7369	Economy	6200.00
0005432073481	7369	Economy	6200.00
0005434459332	7369	Economy	6200.00
0005434664993	7369	Economy	6200.00
0005432841065	7369	Economy	6200.00
0005435253013	7369	Economy	6200.00
0005434459334	7369	Economy	6200.00
0005434459337	7369	Economy	6200.00
0005435253071	7369	Economy	6200.00
0005435252957	7369	Economy	6200.00
0005432839834	7369	Economy	6200.00
0005435252990	7369	Economy	6200.00
0005434459341	7369	Economy	6200.00
0005432839838	7369	Economy	6200.00
0005432839819	7369	Economy	6200.00
0005435253076	7369	Economy	6200.00
0005432839814	7369	Economy	6200.00
0005434459338	7369	Economy	6200.00
0005432839829	7369	Economy	6200.00
0005435253077	7369	Economy	6200.00
0005434459344	7369	Economy	6200.00
0005434459329	7369	Economy	6200.00
0005434459331	7369	Economy	6200.00
0005435253032	7369	Economy	6200.00
0005432839824	7369	Economy	6200.00
0005435253074	7369	Economy	6200.00
0005432839812	7369	Economy	6200.00
0005432839822	7369	Economy	6200.00
0005434665002	7369	Economy	6200.00
0005432839839	7369	Economy	6200.00
0005435252967	7369	Economy	6200.00
0005432839817	7369	Economy	6200.00
0005432839820	7369	Economy	6200.00
0005435253053	7369	Economy	6200.00
0005435253052	7369	Economy	6200.00
0005432839823	7369	Economy	6200.00
0005434665001	7369	Economy	6200.00
0005432839833	7369	Economy	6200.00
0005435252989	7369	Economy	6200.00
0005432839816	7369	Economy	6200.00
0005434459330	7369	Economy	6200.00
0005432839831	7369	Economy	6200.00
0005432839828	7369	Economy	6200.00
0005435491472	7369	Economy	6200.00
0005432839821	7369	Economy	6200.00
0005434459343	7369	Economy	6200.00
0005435253075	7369	Economy	6200.00
0005434459339	7369	Economy	6200.00
0005432823500	7369	Economy	6200.00
0005434459342	7369	Economy	6200.00
0005435491475	7369	Economy	6200.00
0005434459346	7369	Economy	6200.00
0005434459164	28908	Business	18500.00
0005432823480	28908	Business	18500.00
0005432839653	28908	Business	18500.00
0005435253157	28908	Business	18500.00
0005434665020	28908	Business	18500.00
0005434459097	28908	Business	18500.00
0005432841045	28908	Business	18500.00
0005434459174	28908	Business	18500.00
0005434459055	28908	Business	18500.00
0005435253162	28908	Business	18500.00
0005432839533	28908	Business	18500.00
0005432839547	28908	Economy	6200.00
0005435491500	28908	Economy	6200.00
0005434459170	28908	Economy	6200.00
0005434459093	28908	Economy	6200.00
0005435253159	28908	Economy	6200.00
0005432839682	28908	Economy	6200.00
0005435253165	28908	Economy	6200.00
0005434459172	28908	Economy	6200.00
0005432839687	28908	Economy	6200.00
0005435253156	28908	Economy	6800.00
0005432841057	28908	Economy	6800.00
0005432823488	28908	Economy	6200.00
0005432839535	28908	Economy	6200.00
0005432839590	28908	Economy	6200.00
0005432839540	28908	Economy	6200.00
0005432823489	28908	Economy	6200.00
0005435253160	28908	Economy	6200.00
0005432839518	28908	Economy	6200.00
0005435253154	28908	Economy	6200.00
0005432839774	28908	Economy	6200.00
0005432839519	28908	Economy	6200.00
0005432839617	28908	Economy	6200.00
0005432839534	28908	Economy	6200.00
0005434459094	28908	Economy	6200.00
0005435253164	28908	Economy	6200.00
0005432839614	28908	Economy	6200.00
0005435253158	28908	Economy	6200.00
0005432839588	28908	Economy	6200.00
0005435253161	28908	Economy	6200.00
0005432839541	28908	Economy	6200.00
0005434459183	28908	Economy	6200.00
0005435491498	28908	Economy	6200.00
0005434459162	28908	Economy	6200.00
0005432839566	28908	Economy	6200.00
0005434459106	28908	Economy	6200.00
0005432839775	28908	Economy	6200.00
0005432839615	28908	Economy	6200.00
0005434459201	28908	Economy	6200.00
0005432839616	28908	Economy	6200.00
0005432841052	28908	Economy	6200.00
0005434459171	28908	Economy	6200.00
0005432839577	28908	Economy	6200.00
0005435491499	28908	Economy	6200.00
0005434665019	28908	Economy	6200.00
0005432841049	28908	Economy	6200.00
0005434459066	28908	Economy	6200.00
0005432839578	28908	Economy	6200.00
0005432839634	28908	Economy	6200.00
0005432839595	28908	Economy	6200.00
0005432839627	28908	Economy	6200.00
0005432839589	28908	Economy	6200.00
0005432001074	28908	Economy	6200.00
0005432839553	28908	Economy	6200.00
0005432839556	28908	Economy	6200.00
0005432841051	28908	Economy	6200.00
0005435253163	28908	Economy	6200.00
0005432839543	28908	Economy	6200.00
0005434459092	28908	Economy	6200.00
0005432001075	28908	Economy	6200.00
0005434459175	28908	Economy	6200.00
0005432839693	28908	Economy	6200.00
0005435253155	28908	Economy	6200.00
0005432839685	28908	Economy	6200.00
0005432839552	28908	Economy	6200.00
0005435253153	28908	Economy	6200.00
0005432839602	28908	Economy	6200.00
0005432839579	28908	Economy	6200.00
0005434276131	8792	Business	145300.00
0005434276145	8792	Business	145300.00
0005434276097	8792	Economy	48400.00
0005435990805	8792	Economy	48400.00
0005434276130	8792	Economy	48400.00
0005434276098	8792	Economy	48400.00
0005435990808	8792	Economy	48400.00
0005435990807	8792	Economy	48400.00
0005435990804	8792	Economy	48400.00
0005434276106	8792	Economy	48400.00
0005434276126	8792	Economy	48400.00
0005434276125	8792	Economy	48400.00
0005435990809	8792	Economy	48400.00
0005435990806	8792	Economy	48400.00
0005435990735	15717	Business	145300.00
0005435990737	15717	Economy	48400.00
0005435990763	15717	Economy	48400.00
0005435990729	15717	Economy	48400.00
0005435990728	15717	Economy	48400.00
0005434276172	15717	Economy	48400.00
0005435990742	15717	Economy	48400.00
0005434276174	15717	Economy	48400.00
0005434276175	15717	Economy	48400.00
0005435990745	15717	Economy	48400.00
0005434276173	15717	Economy	48400.00
0005435990736	15717	Economy	48400.00
0005435990777	15717	Economy	48400.00
0005435990746	15717	Economy	48400.00
0005435990734	15717	Economy	48400.00
0005433468567	2078	Economy	13300.00
0005432909396	2078	Economy	13300.00
0005432909357	2078	Economy	13300.00
0005432909385	2078	Economy	12100.00
0005432909356	2078	Economy	12100.00
0005432909377	2078	Economy	12100.00
0005433468561	2078	Economy	12100.00
0005433468558	2078	Economy	12100.00
0005432909375	2078	Economy	12100.00
0005433468565	2078	Economy	12100.00
0005433468566	2078	Economy	12100.00
0005432909376	2078	Economy	12100.00
0005433468557	2078	Economy	12100.00
0005432909371	2078	Economy	12100.00
0005433468555	2078	Economy	12100.00
0005433468570	2078	Economy	12100.00
0005433468554	2078	Economy	12100.00
0005433468559	2078	Economy	12100.00
0005433468563	2078	Economy	12100.00
0005433468553	2078	Economy	12100.00
0005433468564	2078	Economy	12100.00
0005432909370	2078	Economy	12100.00
0005432909374	2078	Economy	12100.00
0005433468569	2078	Economy	12100.00
0005433468562	2078	Economy	12100.00
0005433468560	2078	Economy	12100.00
0005432909378	2078	Economy	12100.00
0005432909372	2078	Economy	12100.00
0005433468568	2078	Economy	12100.00
0005433468556	2078	Economy	12100.00
0005432909364	2078	Economy	12100.00
0005435177584	6405	Business	36600.00
0005432361574	6405	Business	36600.00
0005432361590	6405	Business	36600.00
0005432361591	6405	Business	36600.00
0005432361569	6405	Business	36600.00
0005435177464	6405	Business	36600.00
0005432361589	6405	Business	36600.00
0005435177585	6405	Business	36600.00
0005435177631	6405	Business	36600.00
0005432361581	6405	Business	36600.00
0005432361600	6405	Economy	12200.00
0005432361577	6405	Economy	12200.00
0005432336336	6405	Economy	12200.00
0005435490284	6405	Economy	12200.00
0005432062364	6405	Economy	12200.00
0005434149914	6405	Economy	12200.00
0005435177525	6405	Economy	12200.00
0005435177526	6405	Economy	12200.00
0005435177583	6405	Economy	12200.00
0005432336345	6405	Economy	12200.00
0005432363501	6405	Economy	12200.00
0005434149963	6405	Economy	12200.00
0005435177632	6405	Economy	12200.00
0005432336338	6405	Economy	12200.00
0005432361607	6405	Economy	12200.00
0005432336343	6405	Economy	12200.00
0005432361601	6405	Economy	12200.00
0005435177490	6405	Economy	12200.00
0005432361602	6405	Economy	12200.00
0005432363499	6405	Economy	12200.00
0005434149943	6405	Economy	12200.00
0005435177594	6405	Economy	12200.00
0005432361579	6405	Economy	12200.00
0005432361573	6405	Economy	12200.00
0005434149964	6405	Economy	12200.00
0005432361578	6405	Economy	12200.00
0005432336341	6405	Economy	12200.00
0005432062363	6405	Economy	12200.00
0005432361599	6405	Economy	12200.00
0005432361605	6405	Economy	12200.00
0005435177586	6405	Economy	12200.00
0005432361584	6405	Economy	12200.00
0005435177516	6405	Economy	12200.00
0005432363498	6405	Economy	12200.00
0005435177470	6405	Economy	12200.00
0005432361575	6405	Economy	12200.00
0005435177593	6405	Economy	13400.00
0005434149956	6405	Economy	13400.00
0005435177587	6405	Economy	13400.00
0005434149975	6405	Economy	13400.00
0005432361583	6405	Economy	12200.00
0005432062366	6405	Economy	12200.00
0005432361604	6405	Economy	12200.00
0005434149947	6405	Economy	12200.00
0005432361597	6405	Economy	12200.00
0005432361608	6405	Economy	12200.00
0005432361594	6405	Economy	12200.00
0005432336342	6405	Economy	12200.00
0005432361576	6405	Economy	12200.00
0005435177467	6405	Economy	12200.00
0005432062365	6405	Economy	12200.00
0005435177477	6405	Economy	12200.00
0005432336340	6405	Economy	12200.00
0005432363500	6405	Economy	12200.00
0005432336344	6405	Economy	12200.00
0005434149934	6405	Economy	12200.00
0005432361611	6405	Economy	12200.00
0005432361572	6405	Economy	12200.00
0005432361570	6405	Economy	12200.00
0005432361580	6405	Economy	12200.00
0005432361568	6405	Economy	12200.00
0005432361598	6405	Economy	12200.00
0005432361586	6405	Economy	12200.00
0005434149936	6405	Economy	12200.00
0005434149950	6405	Economy	12200.00
0005435177465	6405	Economy	12200.00
0005432336334	6405	Economy	12200.00
0005432336335	6405	Economy	12200.00
0005435177600	6405	Economy	12200.00
0005434149948	6405	Economy	12200.00
0005432363503	6405	Economy	12200.00
0005432361585	6405	Economy	12200.00
0005435177517	6405	Economy	12200.00
0005432361588	6405	Economy	12200.00
0005432336339	6405	Economy	12200.00
0005432336337	6405	Economy	12200.00
0005432361587	6405	Economy	12200.00
0005432361606	6405	Economy	12200.00
0005432361603	6405	Economy	12200.00
0005435177469	6405	Economy	12200.00
0005435177489	6405	Economy	12200.00
0005432361609	6405	Economy	12200.00
0005435723072	6405	Economy	12200.00
0005432361571	6405	Economy	12200.00
0005432361593	6405	Economy	12200.00
0005432361592	6405	Economy	12200.00
0005432062367	6405	Economy	12200.00
0005435177588	6405	Economy	12200.00
0005432361596	6405	Economy	12200.00
0005435177466	6405	Economy	12200.00
0005432363502	6405	Economy	12200.00
0005432361610	6405	Economy	12200.00
0005432361595	6405	Economy	12200.00
0005434149942	6405	Economy	12200.00
0005432361582	6405	Economy	12200.00
0005434149955	6405	Economy	12200.00
0005435177638	6405	Economy	12200.00
0005435723073	6405	Economy	12200.00
0005432336240	21030	Business	36600.00
0005435177777	21030	Business	36600.00
0005435177774	21030	Business	36600.00
0005432361335	21030	Business	36600.00
0005435177767	21030	Business	36600.00
0005432361120	21030	Business	36600.00
0005434150038	21030	Business	36600.00
0005432361209	21030	Business	36600.00
0005432361261	21030	Business	36600.00
0005435177782	21030	Business	36600.00
0005435177783	21030	Business	36600.00
0005432361408	21030	Economy	12200.00
0005432361028	21030	Economy	12200.00
0005432336216	21030	Economy	12200.00
0005435177773	21030	Economy	12200.00
0005432361023	21030	Economy	12200.00
0005432361240	21030	Economy	12200.00
0005435723096	21030	Economy	12200.00
0005432361298	21030	Economy	12200.00
0005432361203	21030	Economy	12200.00
0005432363470	21030	Economy	12200.00
0005435177785	21030	Economy	12200.00
0005432361230	21030	Economy	12200.00
0005435177784	21030	Economy	12200.00
0005432363473	21030	Economy	12200.00
0005432361140	21030	Economy	12200.00
0005432363483	21030	Economy	12200.00
0005435490325	21030	Economy	12200.00
0005434150036	21030	Economy	12200.00
0005432361340	21030	Economy	12200.00
0005435177779	21030	Economy	12200.00
0005435490326	21030	Economy	12200.00
0005432361264	21030	Economy	12200.00
0005435490324	21030	Economy	12200.00
0005432361242	21030	Economy	12200.00
0005432336223	21030	Economy	12200.00
0005432361157	21030	Economy	12200.00
0005434150026	21030	Economy	12200.00
0005432361297	21030	Economy	12200.00
0005432361082	21030	Economy	12200.00
0005434150035	21030	Economy	12200.00
0005432361333	21030	Economy	12200.00
0005432360963	21030	Economy	12200.00
0005434150032	21030	Economy	13400.00
0005432361312	21030	Economy	12200.00
0005432336273	21030	Economy	13400.00
0005435177770	21030	Economy	13400.00
0005432361127	21030	Economy	13400.00
0005432361260	21030	Economy	13400.00
0005435177772	21030	Economy	12200.00
0005432361083	21030	Economy	12200.00
0005434150029	21030	Economy	12200.00
0005432336203	21030	Economy	12200.00
0005432361141	21030	Economy	12200.00
0005432363471	21030	Economy	12200.00
0005432361158	21030	Economy	12200.00
0005432361156	21030	Economy	12200.00
0005434150031	21030	Economy	12200.00
0005432336272	21030	Economy	12200.00
0005434150027	21030	Economy	12200.00
0005432336215	21030	Economy	12200.00
0005435177780	21030	Economy	12200.00
0005432361084	21030	Economy	12200.00
0005432336230	21030	Economy	12200.00
0005432361075	21030	Economy	12200.00
0005435177786	21030	Economy	12200.00
0005432336257	21030	Economy	12200.00
0005432336233	21030	Economy	12200.00
0005432336309	21030	Economy	12200.00
0005435723098	21030	Economy	12200.00
0005434150037	21030	Economy	12200.00
0005435177769	21030	Economy	12200.00
0005432361097	21030	Economy	12200.00
0005432361232	21030	Economy	12200.00
0005432361446	21030	Economy	12200.00
0005435177781	21030	Economy	12200.00
0005435177771	21030	Economy	12200.00
0005432361334	21030	Economy	12200.00
0005432361265	21030	Economy	12200.00
0005432361197	21030	Economy	12200.00
0005435177776	21030	Economy	12200.00
0005432361178	21030	Economy	12200.00
0005432363468	21030	Economy	12200.00
0005432336228	21030	Economy	12200.00
0005435177778	21030	Economy	12200.00
0005435177787	21030	Economy	12200.00
0005432363469	21030	Economy	12200.00
0005432361257	21030	Economy	12200.00
0005432361146	21030	Economy	12200.00
0005432052823	21030	Economy	12200.00
0005432361198	21030	Economy	12200.00
0005432363484	21030	Economy	12200.00
0005434150033	21030	Economy	12200.00
0005432361245	21030	Economy	12200.00
0005435723095	21030	Economy	12200.00
0005432336208	21030	Economy	12200.00
0005432361380	21030	Economy	12200.00
0005435177768	21030	Economy	12200.00
0005432361177	21030	Economy	12200.00
0005432361202	21030	Economy	12200.00
0005432336271	21030	Economy	12200.00
0005432336234	21030	Economy	12200.00
0005434150028	21030	Economy	12200.00
0005432361102	21030	Economy	12200.00
0005432361189	21030	Economy	12200.00
0005432052824	21030	Economy	12200.00
0005432361231	21030	Economy	12200.00
0005434150030	21030	Economy	12200.00
0005432363485	21030	Economy	12200.00
0005432052825	21030	Economy	12200.00
0005432361241	21030	Economy	12200.00
0005432361196	21030	Economy	12200.00
0005435723097	21030	Economy	12200.00
0005435177775	21030	Economy	12200.00
0005434150034	21030	Economy	12200.00
0005432361114	21030	Economy	12200.00
0005434459157	17724	Economy	3400.00
0005434459152	17724	Economy	3100.00
0005434459211	17724	Economy	3100.00
0005434186274	17724	Economy	3100.00
0005434459185	17724	Economy	3100.00
0005434459230	17724	Economy	3100.00
0005434459186	17724	Economy	3100.00
0005434448373	17724	Economy	3100.00
0005434459122	17724	Economy	3100.00
0005434459150	17724	Economy	3100.00
0005434448374	17724	Economy	3100.00
0005434459253	17724	Economy	3100.00
0005434186275	17724	Economy	3100.00
0005434459133	17724	Economy	3100.00
0005434459231	17724	Economy	3100.00
0005434459153	17724	Economy	3100.00
0005434459200	17724	Economy	3100.00
0005434459156	17724	Economy	3100.00
0005434186273	17724	Economy	3100.00
0005434459254	17724	Economy	3100.00
0005434459337	29132	Economy	3400.00
0005434448400	29132	Economy	3100.00
0005434459330	29132	Economy	3100.00
0005434459332	29132	Economy	3100.00
0005434459333	29132	Economy	3100.00
0005434459331	29132	Economy	3100.00
0005434448401	29132	Economy	3100.00
0005434186250	29132	Economy	3100.00
0005434459346	29132	Economy	3100.00
0005434462843	29132	Economy	3100.00
0005434459328	29132	Economy	3100.00
0005434186255	29132	Economy	3100.00
0005434459339	29132	Economy	3100.00
0005434459329	29132	Economy	3100.00
0005434459336	29132	Economy	3100.00
0005434459345	29132	Economy	3100.00
0005434459344	29132	Economy	3100.00
0005434463985	29132	Economy	3100.00
0005434448399	29132	Economy	3100.00
0005434459335	29132	Economy	3100.00
0005434186249	29132	Economy	3100.00
0005434459343	29132	Economy	3100.00
0005434462844	29132	Economy	3100.00
0005434463984	29132	Economy	3100.00
0005434459342	29132	Economy	3100.00
0005434463983	29132	Economy	3100.00
0005434463982	29132	Economy	3100.00
0005434459338	29132	Economy	3100.00
0005434459340	29132	Economy	3100.00
0005434459341	29132	Economy	3100.00
0005434186254	29132	Economy	3100.00
0005434459334	29132	Economy	3100.00
0005432605329	21419	Economy	7300.00
0005432605308	21419	Economy	7300.00
0005432605333	21419	Economy	6600.00
0005432605332	21419	Economy	6600.00
0005432605309	21419	Economy	6600.00
0005432605311	21419	Economy	6600.00
0005432605319	21419	Economy	6600.00
0005432605339	21419	Economy	6600.00
0005432605303	21419	Economy	6600.00
0005432605304	21419	Economy	6600.00
0005432605302	21419	Economy	6600.00
0005432605316	21419	Economy	6600.00
0005432605337	21419	Economy	6600.00
0005432605318	21419	Economy	6600.00
0005432605313	21419	Economy	6600.00
0005432605338	21419	Economy	6600.00
0005432605327	21419	Economy	6600.00
0005432605322	21419	Economy	6600.00
0005432605331	21419	Economy	6600.00
0005432605341	21419	Economy	6600.00
0005432605324	21419	Economy	6600.00
0005432605320	21419	Economy	6600.00
0005432605314	21419	Economy	6600.00
0005432605340	21419	Economy	6600.00
0005432605328	21419	Economy	6600.00
0005432605306	21419	Economy	6600.00
0005432605325	21419	Economy	6600.00
0005432605321	21419	Economy	6600.00
0005432605326	21419	Economy	6600.00
0005432605312	21419	Economy	6600.00
0005432605317	21419	Economy	6600.00
0005432605301	21419	Economy	6600.00
0005432605330	21419	Economy	6600.00
0005432605323	21419	Economy	6600.00
0005432605336	21419	Economy	6600.00
0005432605335	21419	Economy	6600.00
0005432605334	21419	Economy	6600.00
0005432605310	21419	Economy	6600.00
0005432605305	21419	Economy	6600.00
0005432605307	21419	Economy	6600.00
0005432605315	21419	Economy	6600.00
0005435221532	31672	Economy	7300.00
0005432605023	31672	Economy	7300.00
0005432604863	31672	Economy	7300.00
0005432605069	31672	Economy	7300.00
0005435221080	31672	Economy	6600.00
0005432604981	31672	Economy	6600.00
0005432605133	31672	Economy	6600.00
0005432605024	31672	Economy	6600.00
0005432604989	31672	Economy	6600.00
0005432605243	31672	Economy	6600.00
0005432605010	31672	Economy	6600.00
0005432604879	31672	Economy	6600.00
0005432605027	31672	Economy	6600.00
0005432604853	31672	Economy	6600.00
0005432604892	31672	Economy	6600.00
0005432605004	31672	Economy	6600.00
0005432605242	31672	Economy	6600.00
0005432604982	31672	Economy	6600.00
0005432605058	31672	Economy	6600.00
0005432605011	31672	Economy	6600.00
0005432604986	31672	Economy	6600.00
0005432604944	31672	Economy	6600.00
0005432604880	31672	Economy	6600.00
0005432605057	31672	Economy	6600.00
0005432604976	31672	Economy	6600.00
0005432604862	31672	Economy	6600.00
0005432604900	31672	Economy	6600.00
0005432604987	31672	Economy	6600.00
0005432604967	31672	Economy	6600.00
0005432604991	31672	Economy	6600.00
0005432604933	31672	Economy	6600.00
0005432604901	31672	Economy	6600.00
0005432604998	31672	Economy	6600.00
0005432605026	31672	Economy	6600.00
0005432604958	31672	Economy	6600.00
0005432604988	31672	Economy	6600.00
0005432604917	31672	Economy	6600.00
0005432604883	31672	Economy	6600.00
0005435221553	31672	Economy	6600.00
0005432605040	31672	Economy	6600.00
0005432605050	31672	Economy	6600.00
0005432605073	31672	Economy	6600.00
0005432605049	31672	Economy	6600.00
0005432604916	31672	Economy	6600.00
0005432604979	31672	Economy	6600.00
0005432604990	31672	Economy	6600.00
0005432605051	31672	Economy	6600.00
0005433293415	29597	Economy	19500.00
0005433293407	29597	Economy	19500.00
0005433293401	29597	Economy	19500.00
0005435154619	29597	Economy	17800.00
0005433293412	29597	Economy	17800.00
0005433293400	29597	Economy	17800.00
0005433293406	29597	Economy	17800.00
0005435154612	29597	Economy	17800.00
0005433293414	29597	Economy	17800.00
0005435154615	29597	Economy	17800.00
0005433293408	29597	Economy	17800.00
0005433293417	29597	Economy	17800.00
0005435154613	29597	Economy	17800.00
0005433293405	29597	Economy	17800.00
0005433293410	29597	Economy	17800.00
0005435154618	29597	Economy	17800.00
0005435154620	29597	Economy	17800.00
0005433293418	29597	Economy	17800.00
0005433293403	29597	Economy	17800.00
0005435154602	29597	Economy	17800.00
0005433293416	29597	Economy	17800.00
0005433293411	29597	Economy	17800.00
0005433293404	29597	Economy	17800.00
0005433293413	29597	Economy	17800.00
0005433293409	29597	Economy	17800.00
0005433293402	29597	Economy	17800.00
0005435154609	29597	Economy	17800.00
0005435154616	29597	Economy	17800.00
0005435154617	29597	Economy	17800.00
0005433473497	6694	Economy	14000.00
0005433473486	6694	Economy	14000.00
0005433473506	6694	Economy	14000.00
0005435257310	6694	Economy	14000.00
0005435257324	6694	Economy	12700.00
0005433473487	6694	Economy	12700.00
0005433473484	6694	Economy	12700.00
0005433473503	6694	Economy	12700.00
0005435257311	6694	Economy	12700.00
0005435257313	6694	Economy	12700.00
0005435257318	6694	Economy	12700.00
0005433473491	6694	Economy	12700.00
0005435257307	6694	Economy	12700.00
0005433473483	6694	Economy	12700.00
0005433473507	6694	Economy	12700.00
0005435257300	6694	Economy	12700.00
0005433473488	6694	Economy	12700.00
0005435257308	6694	Economy	12700.00
0005433473496	6694	Economy	12700.00
0005433473489	6694	Economy	12700.00
0005435257322	6694	Economy	12700.00
0005433473482	6694	Economy	12700.00
0005435257319	6694	Economy	12700.00
0005433473495	6694	Economy	12700.00
0005435257312	6694	Economy	12700.00
0005435257301	6694	Economy	12700.00
0005435257326	6694	Economy	12700.00
0005433473485	6694	Economy	12700.00
0005435257325	6694	Economy	12700.00
0005435257309	6694	Economy	12700.00
0005435257317	6694	Economy	12700.00
0005433473494	6694	Economy	12700.00
0005435257327	6694	Economy	12700.00
0005433473502	6694	Economy	12700.00
0005433473490	6694	Economy	12700.00
0005433473504	6694	Economy	12700.00
0005433473481	6694	Economy	12700.00
0005435257332	6694	Economy	12700.00
0005433473505	6694	Economy	12700.00
0005435257315	6694	Economy	12700.00
0005433473492	6694	Economy	12700.00
0005435257333	6694	Economy	12700.00
0005433473501	6694	Economy	12700.00
0005433473499	6694	Economy	12700.00
0005433473493	6694	Economy	12700.00
0005433473500	6694	Economy	12700.00
0005435257314	6694	Economy	12700.00
0005433473498	6694	Economy	12700.00
0005434606912	22354	Economy	6600.00
0005434604988	22354	Economy	6600.00
0005434606913	22354	Economy	6600.00
0005434604990	22354	Economy	6600.00
0005434606914	22354	Economy	6600.00
0005434606915	22354	Economy	6600.00
0005434604989	22354	Economy	6600.00
0005432748534	420	Business	44500.00
0005432751609	420	Business	44500.00
0005432891448	420	Business	44500.00
0005432748532	420	Business	44500.00
0005432891335	420	Business	44500.00
0005432891320	420	Business	44500.00
0005433875394	420	Business	44500.00
0005432748545	420	Business	44500.00
0005435154668	420	Business	44500.00
0005432748547	420	Business	44500.00
0005432748544	420	Business	44500.00
0005432748523	420	Economy	14800.00
0005432748527	420	Economy	14800.00
0005432748538	420	Economy	14800.00
0005432749838	420	Economy	14800.00
0005433293369	420	Economy	14800.00
0005432748530	420	Economy	14800.00
0005435154672	420	Economy	14800.00
0005432749839	420	Economy	14800.00
0005432748539	420	Economy	14800.00
0005432748528	420	Economy	14800.00
0005435154673	420	Economy	16300.00
0005432748531	420	Economy	16300.00
0005432753382	420	Economy	14800.00
0005432748555	420	Economy	14800.00
0005432748553	420	Economy	14800.00
0005432891352	420	Economy	14800.00
0005432751608	420	Economy	14800.00
0005432748537	420	Economy	14800.00
0005435154669	420	Economy	14800.00
0005432748551	420	Economy	14800.00
0005432748525	420	Economy	14800.00
0005432891386	420	Economy	14800.00
0005432748524	420	Economy	14800.00
0005435154670	420	Economy	14800.00
0005432220113	420	Economy	14800.00
0005432748550	420	Economy	14800.00
0005433875409	420	Economy	14800.00
0005432748543	420	Economy	14800.00
0005432891449	420	Economy	14800.00
0005432220112	420	Economy	14800.00
0005432748540	420	Economy	14800.00
0005432748546	420	Economy	14800.00
0005433293362	420	Economy	14800.00
0005432891419	420	Economy	14800.00
0005432748529	420	Economy	14800.00
0005435154671	420	Economy	14800.00
0005435154674	420	Economy	14800.00
0005433293361	420	Economy	14800.00
0005432748552	420	Economy	14800.00
0005432753385	420	Economy	14800.00
0005433293370	420	Economy	14800.00
0005432748522	420	Economy	14800.00
0005432748535	420	Economy	14800.00
0005432220111	420	Economy	14800.00
0005433875410	420	Economy	14800.00
0005432891290	420	Economy	14800.00
0005432748517	420	Economy	14800.00
0005432891361	420	Economy	14800.00
0005433293360	420	Economy	14800.00
0005432891334	420	Economy	14800.00
0005432748521	420	Economy	14800.00
0005433293363	420	Economy	14800.00
0005432891376	420	Economy	14800.00
0005432748536	420	Economy	14800.00
0005432748554	420	Economy	14800.00
0005432891284	420	Economy	14800.00
0005432748548	420	Economy	14800.00
0005432891244	420	Economy	14800.00
0005432891243	420	Economy	14800.00
0005432748526	420	Economy	14800.00
0005432748519	420	Economy	14800.00
0005432748549	420	Economy	14800.00
0005432753383	420	Economy	14800.00
0005433293347	420	Economy	14800.00
0005432891351	420	Economy	14800.00
0005432748518	420	Economy	14800.00
0005432748541	420	Economy	14800.00
0005432891418	420	Economy	14800.00
0005432748542	420	Economy	14800.00
0005432748520	420	Economy	14800.00
0005432753384	420	Economy	14800.00
0005432891362	420	Economy	14800.00
0005432891400	420	Economy	14800.00
0005432751610	420	Economy	14800.00
0005432748533	420	Economy	14800.00
0005432748346	12057	Business	44500.00
0005432748216	12057	Business	44500.00
0005432748438	12057	Business	44500.00
0005432891525	12057	Business	44500.00
0005434153574	12057	Business	44500.00
0005432748168	12057	Business	44500.00
0005432748235	12057	Business	44500.00
0005432756887	12057	Business	44500.00
0005432748156	12057	Business	44500.00
0005432748276	12057	Business	44500.00
0005432748217	12057	Economy	14800.00
0005432748172	12057	Economy	14800.00
0005432748215	12057	Economy	14800.00
0005432748146	12057	Economy	14800.00
0005432748258	12057	Economy	14800.00
0005432756899	12057	Economy	14800.00
0005434153573	12057	Economy	14800.00
0005432748178	12057	Economy	16300.00
0005432748270	12057	Economy	16300.00
0005432891516	12057	Economy	16300.00
0005432214859	12057	Economy	16300.00
0005432748345	12057	Economy	16300.00
0005432214858	12057	Economy	14800.00
0005432748275	12057	Economy	14800.00
0005432748148	12057	Economy	14800.00
0005432891517	12057	Economy	14800.00
0005432748298	12057	Economy	14800.00
0005432748254	12057	Economy	14800.00
0005432891524	12057	Economy	14800.00
0005433875423	12057	Economy	14800.00
0005432891513	12057	Economy	14800.00
0005432891521	12057	Economy	14800.00
0005432748177	12057	Economy	14800.00
0005432891520	12057	Economy	14800.00
0005432891527	12057	Economy	14800.00
0005432748188	12057	Economy	14800.00
0005432748171	12057	Economy	14800.00
0005432753364	12057	Economy	14800.00
0005432748437	12057	Economy	14800.00
0005435627121	12057	Economy	14800.00
0005432891523	12057	Economy	14800.00
0005432749819	12057	Economy	14800.00
0005432749823	12057	Economy	14800.00
0005432891518	12057	Economy	14800.00
0005432748274	12057	Economy	14800.00
0005432748169	12057	Economy	14800.00
0005432891515	12057	Economy	14800.00
0005432753366	12057	Economy	14800.00
0005432891514	12057	Economy	14800.00
0005433875424	12057	Economy	14800.00
0005432748193	12057	Economy	14800.00
0005434152861	12057	Economy	14800.00
0005432748167	12057	Economy	14800.00
0005432891519	12057	Economy	14800.00
0005432748179	12057	Economy	14800.00
0005432748236	12057	Economy	14800.00
0005432891512	12057	Economy	14800.00
0005432748232	12057	Economy	14800.00
0005432748222	12057	Economy	14800.00
0005432748292	12057	Economy	14800.00
0005432748425	12057	Economy	14800.00
0005432749824	12057	Economy	14800.00
0005432748140	12057	Economy	14800.00
0005432748141	12057	Economy	14800.00
0005432748306	12057	Economy	14800.00
0005435627122	12057	Economy	14800.00
0005432891526	12057	Economy	14800.00
0005432748255	12057	Economy	14800.00
0005432748352	12057	Economy	14800.00
0005432891522	12057	Economy	14800.00
0005432748192	12057	Economy	14800.00
0005432748271	12057	Economy	14800.00
0005432756898	12057	Economy	14800.00
0005434152860	12057	Economy	14800.00
0005432748170	12057	Economy	14800.00
0005432753365	12057	Economy	14800.00
0005433525309	18992	Economy	28200.00
0005433525312	18992	Economy	28200.00
0005433531387	18992	Economy	25700.00
0005433525304	18992	Economy	25700.00
0005433525303	18992	Economy	25700.00
0005432928073	18992	Economy	25700.00
0005433533399	18992	Economy	25700.00
0005433525311	18992	Economy	25700.00
0005432928071	18992	Economy	25700.00
0005433531388	18992	Economy	25700.00
0005433525305	18992	Economy	25700.00
0005433525314	18992	Economy	25700.00
0005432928087	18992	Economy	25700.00
0005433525302	18992	Economy	25700.00
0005433525313	18992	Economy	25700.00
0005433525310	18992	Economy	25700.00
0005433531385	18992	Economy	25700.00
0005433525307	18992	Economy	25700.00
0005432928091	18992	Economy	25700.00
0005433525306	18992	Economy	25700.00
0005433533402	18992	Economy	25700.00
0005433525308	18992	Economy	25700.00
0005433531386	18992	Economy	25700.00
0005433533401	18992	Economy	25700.00
0005433533400	18992	Economy	25700.00
0005433525248	32490	Economy	28200.00
0005433525260	32490	Economy	25700.00
0005433525235	32490	Economy	25700.00
0005433527310	32490	Economy	25700.00
0005433525233	32490	Economy	25700.00
0005433525250	32490	Economy	25700.00
0005433525247	32490	Economy	25700.00
0005433527326	32490	Economy	25700.00
0005432928128	32490	Economy	25700.00
0005433527327	32490	Economy	25700.00
0005432928127	32490	Economy	25700.00
0005433525259	32490	Economy	25700.00
0005432928129	32490	Economy	25700.00
0005433525258	32490	Economy	25700.00
0005433525234	32490	Economy	25700.00
0005433525231	32490	Economy	25700.00
0005432928130	32490	Economy	25700.00
0005433531369	32490	Economy	25700.00
0005433525176	32490	Economy	25700.00
0005433525251	32490	Economy	25700.00
0005433531353	32490	Economy	25700.00
0005433527311	32490	Economy	25700.00
0005433531370	32490	Economy	25700.00
0005433525246	32490	Economy	25700.00
0005434826782	5298	Business	84000.00
0005434826813	5298	Business	84000.00
0005434826780	5298	Business	84000.00
0005434826832	5298	Business	84000.00
0005434826854	5298	Business	84000.00
0005435735203	5298	Business	84000.00
0005435374618	5298	Business	84000.00
0005435386701	5298	Business	84000.00
0005432394208	5298	Business	84000.00
0005435374561	5298	Business	84000.00
0005435374371	5298	Business	84000.00
0005434826779	5298	Business	84000.00
0005435386654	5298	Business	84000.00
0005434826856	5298	Business	84000.00
0005434558496	5298	Business	84000.00
0005432121692	5298	Business	84000.00
0005434826801	5298	Business	84000.00
0005435374349	5298	Business	84000.00
0005434826851	5298	Business	84000.00
0005435374355	5298	Business	84000.00
0005434826786	5298	Business	84000.00
0005435386663	5298	Comfort	47600.00
0005435299849	5298	Comfort	47600.00
0005434826802	5298	Comfort	47600.00
0005435374554	5298	Comfort	47600.00
0005435374553	5298	Comfort	47600.00
0005434826774	5298	Comfort	47600.00
0005434826761	5298	Comfort	47600.00
0005435374359	5298	Comfort	47600.00
0005435150380	5298	Comfort	47600.00
0005434826763	5298	Comfort	47600.00
0005435735222	5298	Comfort	47600.00
0005434826843	5298	Comfort	47600.00
0005432121697	5298	Comfort	47600.00
0005435735214	5298	Comfort	47600.00
0005434831264	5298	Comfort	47600.00
0005434826756	5298	Comfort	47600.00
0005435373983	5298	Comfort	47600.00
0005434826765	5298	Comfort	47600.00
0005434558494	5298	Comfort	47600.00
0005435374473	5298	Comfort	47600.00
0005434826823	5298	Comfort	47600.00
0005435374299	5298	Comfort	47600.00
0005435386711	5298	Comfort	47600.00
0005434826816	5298	Comfort	47600.00
0005432121687	5298	Comfort	47600.00
0005435374208	5298	Comfort	47600.00
0005435386706	5298	Comfort	47600.00
0005434826817	5298	Comfort	47600.00
0005434826788	5298	Comfort	47600.00
0005434826758	5298	Comfort	47600.00
0005432394206	5298	Comfort	47600.00
0005435374312	5298	Economy	28000.00
0005434665018	5298	Comfort	47600.00
0005432394209	5298	Economy	28000.00
0005435374412	5298	Economy	28000.00
0005435374472	5298	Economy	28000.00
0005435374372	5298	Economy	28000.00
0005434826840	5298	Economy	28000.00
0005435374274	5298	Economy	28000.00
0005435374182	5298	Economy	28000.00
0005434826794	5298	Economy	28000.00
0005435386653	5298	Economy	28000.00
0005434826796	5298	Economy	28000.00
0005434826812	5298	Economy	28000.00
0005432121693	5298	Economy	28000.00
0005432396342	5298	Economy	28000.00
0005434826850	5298	Economy	28000.00
0005434826777	5298	Economy	28000.00
0005434826836	5298	Economy	28000.00
0005434826829	5298	Economy	28000.00
0005435386705	5298	Economy	28000.00
0005435374586	5298	Economy	28000.00
0005434826789	5298	Economy	28000.00
0005434826815	5298	Economy	28000.00
0005434826819	5298	Economy	28000.00
0005432396343	5298	Economy	28000.00
0005434826751	5298	Economy	28000.00
0005434826846	5298	Economy	28000.00
0005435374271	5298	Economy	28000.00
0005435374273	5298	Economy	28000.00
0005435304235	5298	Economy	28000.00
0005434826841	5298	Economy	28000.00
0005435735216	5298	Economy	28000.00
0005435150383	5298	Economy	28000.00
0005434826771	5298	Economy	28000.00
0005434826821	5298	Economy	28000.00
0005434826833	5298	Economy	28000.00
0005434826755	5298	Economy	28000.00
0005435374502	5298	Economy	28000.00
0005435374009	5298	Economy	28000.00
0005434826848	5298	Economy	28000.00
0005435374601	5298	Economy	28000.00
0005435374272	5298	Economy	28000.00
0005435150389	5298	Economy	28000.00
0005435299859	5298	Economy	28000.00
0005435150379	5298	Economy	28000.00
0005435374546	5298	Economy	30800.00
0005434831265	5298	Economy	30800.00
0005434826814	5298	Economy	28000.00
0005435374160	5298	Economy	28000.00
0005434665016	5298	Economy	30800.00
0005434826798	5298	Economy	30800.00
0005434826764	5298	Economy	28000.00
0005435735217	5298	Economy	28000.00
0005434826828	5298	Economy	28000.00
0005434831266	5298	Economy	28000.00
0005434826792	5298	Economy	28000.00
0005435735208	5298	Economy	28000.00
0005434826804	5298	Economy	28000.00
0005434826783	5298	Economy	28000.00
0005434826855	5298	Economy	28000.00
0005434826787	5298	Economy	28000.00
0005434831267	5298	Economy	28000.00
0005434826772	5298	Economy	28000.00
0005434826778	5298	Economy	28000.00
0005435374300	5298	Economy	28000.00
0005435374384	5298	Economy	28000.00
0005435304236	5298	Economy	28000.00
0005434826766	5298	Economy	28000.00
0005434826858	5298	Economy	28000.00
0005435374132	5298	Economy	28000.00
0005435661972	5298	Economy	28000.00
0005434826785	5298	Economy	28000.00
0005435374161	5298	Economy	28000.00
0005435374585	5298	Economy	28000.00
0005435374305	5298	Economy	28000.00
0005432121690	5298	Economy	28000.00
0005434826811	5298	Economy	28000.00
0005435374709	5298	Economy	28000.00
0005434826845	5298	Economy	28000.00
0005435304237	5298	Economy	28000.00
0005434826805	5298	Economy	28000.00
0005434826844	5298	Economy	28000.00
0005432121691	5298	Economy	28000.00
0005435386665	5298	Economy	28000.00
0005434826852	5298	Economy	28000.00
0005434826799	5298	Economy	28000.00
0005432121694	5298	Economy	28000.00
0005435374242	5298	Economy	28000.00
0005434826826	5298	Economy	28000.00
0005435374600	5298	Economy	28000.00
0005434826862	5298	Economy	28000.00
0005434826790	5298	Economy	28000.00
0005434826835	5298	Economy	28000.00
0005434826831	5298	Economy	28000.00
0005434826759	5298	Economy	28000.00
0005435374304	5298	Economy	28000.00
0005435150378	5298	Economy	28000.00
0005435150388	5298	Economy	28000.00
0005435661974	5298	Economy	28000.00
0005434826795	5298	Economy	28000.00
0005434831268	5298	Economy	28000.00
0005434826860	5298	Economy	28000.00
0005435374629	5298	Economy	28000.00
0005435374311	5298	Economy	28000.00
0005435374545	5298	Economy	28000.00
0005435150387	5298	Economy	28000.00
0005435374642	5298	Economy	28000.00
0005435374251	5298	Economy	28000.00
0005434826762	5298	Economy	28000.00
0005434826754	5298	Economy	28000.00
0005434826849	5298	Economy	28000.00
0005435374356	5298	Economy	28000.00
0005434826838	5298	Economy	28000.00
0005435374289	5298	Economy	28000.00
0005434826752	5298	Economy	28000.00
0005434558495	5298	Economy	28000.00
0005434558492	5298	Economy	28000.00
0005435374357	5298	Economy	28000.00
0005434826753	5298	Economy	28000.00
0005434826773	5298	Economy	28000.00
0005435735221	5298	Economy	28000.00
0005434826757	5298	Economy	28000.00
0005434826825	5298	Economy	30800.00
0005434826806	5298	Economy	30800.00
0005434826807	5298	Economy	30800.00
0005434826768	5298	Economy	30800.00
0005434826784	5298	Economy	28000.00
0005434826781	5298	Economy	28000.00
0005435150382	5298	Economy	28000.00
0005432121688	5298	Economy	28000.00
0005435735201	5298	Economy	28000.00
0005435304234	5298	Economy	28000.00
0005434826818	5298	Economy	28000.00
0005434826847	5298	Economy	28000.00
0005435374237	5298	Economy	28000.00
0005435374404	5298	Economy	28000.00
0005434826834	5298	Economy	28000.00
0005435374613	5298	Economy	28000.00
0005435374348	5298	Economy	28000.00
0005434665017	5298	Economy	28000.00
0005434826776	5298	Economy	28000.00
0005434826760	5298	Economy	28000.00
0005435386684	5298	Economy	28000.00
0005435374402	5298	Economy	28000.00
0005435150385	5298	Economy	28000.00
0005434826793	5298	Economy	28000.00
0005435374209	5298	Economy	28000.00
0005432121695	5298	Economy	28000.00
0005434826859	5298	Economy	28000.00
0005435374290	5298	Economy	28000.00
0005432396344	5298	Economy	28000.00
0005435374612	5298	Economy	28000.00
0005435150384	5298	Economy	28000.00
0005434826770	5298	Economy	28000.00
0005434826820	5298	Economy	28000.00
0005432121699	5298	Economy	28000.00
0005434826830	5298	Economy	28000.00
0005435150386	5298	Economy	28000.00
0005435374540	5298	Economy	28000.00
0005435661973	5298	Economy	28000.00
0005434826824	5298	Economy	28000.00
0005434826803	5298	Economy	28000.00
0005434826809	5298	Economy	28000.00
0005435374607	5298	Economy	28000.00
0005435304233	5298	Economy	28000.00
0005434826769	5298	Economy	28000.00
0005434826767	5298	Economy	28000.00
0005434826861	5298	Economy	28000.00
0005435150381	5298	Economy	28000.00
0005432121689	5298	Economy	28000.00
0005435386666	5298	Economy	28000.00
0005434826797	5298	Economy	28000.00
0005434826775	5298	Economy	28000.00
0005434826800	5298	Economy	28000.00
0005434826839	5298	Economy	28000.00
0005434826791	5298	Economy	28000.00
0005434826810	5298	Economy	28000.00
0005432396345	5298	Economy	28000.00
0005434826837	5298	Economy	28000.00
0005435374435	5298	Economy	28000.00
0005435386700	5298	Economy	28000.00
0005432394207	5298	Economy	28000.00
0005435374320	5298	Economy	28000.00
0005435374281	5298	Economy	28000.00
0005432121696	5298	Economy	28000.00
0005434826822	5298	Economy	28000.00
0005435299864	5298	Economy	28000.00
0005434826857	5298	Economy	28000.00
0005435374328	5298	Economy	28000.00
0005434826808	5298	Economy	28000.00
0005435179705	5298	Economy	28000.00
0005432121698	5298	Economy	28000.00
0005434826827	5298	Economy	28000.00
0005434826842	5298	Economy	28000.00
0005434826853	5298	Economy	28000.00
0005435735209	5298	Economy	28000.00
0005435374246	5298	Economy	28000.00
0005434558497	5298	Economy	28000.00
0005435374549	5298	Economy	28000.00
0005434558493	5298	Economy	28000.00
0005435374896	9916	Business	84000.00
0005435315048	9916	Business	84000.00
0005435150264	9916	Business	84000.00
0005435374897	9916	Business	84000.00
0005435315049	9916	Business	84000.00
0005435299898	9916	Business	84000.00
0005434828752	9916	Business	84000.00
0005434825733	9916	Business	84000.00
0005434826172	9916	Business	84000.00
0005434825341	9916	Business	84000.00
0005435150198	9916	Business	84000.00
0005434825850	9916	Business	84000.00
0005435315038	9916	Business	84000.00
0005435299896	9916	Business	84000.00
0005434825323	9916	Business	84000.00
0005434826061	9916	Business	84000.00
0005434825771	9916	Business	84000.00
0005435386735	9916	Business	84000.00
0005435374935	9916	Comfort	47600.00
0005435374948	9916	Business	84000.00
0005435374899	9916	Comfort	47600.00
0005434825512	9916	Comfort	47600.00
0005435374894	9916	Comfort	47600.00
0005435374937	9916	Comfort	47600.00
0005432396311	9916	Comfort	47600.00
0005434825773	9916	Comfort	47600.00
0005435299900	9916	Comfort	47600.00
0005434825774	9916	Comfort	47600.00
0005435315043	9916	Comfort	47600.00
0005434825468	9916	Comfort	47600.00
0005435315035	9916	Comfort	47600.00
0005434825477	9916	Comfort	47600.00
0005435735260	9916	Comfort	47600.00
0005435315054	9916	Comfort	47600.00
0005434826073	9916	Comfort	47600.00
0005435374900	9916	Comfort	47600.00
0005434825613	9916	Comfort	47600.00
0005435374892	9916	Comfort	47600.00
0005434825995	9916	Comfort	47600.00
0005434825597	9916	Comfort	47600.00
0005435735257	9916	Comfort	47600.00
0005435315059	9916	Comfort	47600.00
0005434825670	9916	Comfort	47600.00
0005434825293	9916	Comfort	47600.00
0005435374951	9916	Comfort	47600.00
0005434825998	9916	Comfort	47600.00
0005434825903	9916	Comfort	47600.00
0005435150180	9916	Comfort	47600.00
0005434825497	9916	Comfort	47600.00
0005435735259	9916	Comfort	47600.00
0005435374910	9916	Comfort	47600.00
0005434825328	9916	Economy	28000.00
0005435315057	9916	Economy	28000.00
0005435374913	9916	Economy	28000.00
0005434825612	9916	Economy	28000.00
0005435374914	9916	Economy	28000.00
0005435374928	9916	Economy	28000.00
0005432400187	9916	Economy	28000.00
0005434558401	9916	Economy	28000.00
0005432203251	9916	Economy	28000.00
0005435374926	9916	Economy	28000.00
0005435315055	9916	Economy	28000.00
0005434825994	9916	Economy	28000.00
0005435315052	9916	Economy	28000.00
0005434825925	9916	Economy	28000.00
0005435374934	9916	Economy	28000.00
0005434825231	9916	Economy	28000.00
0005435315050	9916	Economy	28000.00
0005434831230	9916	Economy	28000.00
0005435374932	9916	Economy	28000.00
0005434826367	9916	Economy	28000.00
0005435374945	9916	Economy	28000.00
0005434825600	9916	Economy	28000.00
0005435374938	9916	Economy	28000.00
0005435299895	9916	Economy	28000.00
0005435150297	9916	Economy	28000.00
0005434826035	9916	Economy	28000.00
0005432203245	9916	Economy	28000.00
0005435150238	9916	Economy	28000.00
0005434825671	9916	Economy	28000.00
0005434825992	9916	Economy	28000.00
0005435299899	9916	Economy	28000.00
0005435374921	9916	Economy	28000.00
0005434825785	9916	Economy	28000.00
0005435299897	9916	Economy	28000.00
0005432203249	9916	Economy	28000.00
0005435179421	9916	Economy	28000.00
0005435662004	9916	Economy	28000.00
0005434825745	9916	Economy	28000.00
0005434825869	9916	Economy	28000.00
0005435315040	9916	Economy	28000.00
0005434824942	9916	Economy	28000.00
0005435374922	9916	Economy	28000.00
0005435315046	9916	Economy	28000.00
0005432203250	9916	Economy	28000.00
0005435386733	9916	Economy	28000.00
0005434825607	9916	Economy	28000.00
0005434825778	9916	Economy	28000.00
0005435374940	9916	Economy	28000.00
0005435374918	9916	Economy	30800.00
0005434825347	9916	Economy	30800.00
0005435374912	9916	Economy	30800.00
0005432396305	9916	Economy	28000.00
0005435315045	9916	Economy	28000.00
0005434828750	9916	Economy	28000.00
0005435179713	9916	Economy	28000.00
0005435374943	9916	Economy	28000.00
0005435386736	9916	Economy	28000.00
0005435374946	9916	Economy	28000.00
0005434826114	9916	Economy	28000.00
0005434824966	9916	Economy	28000.00
0005434826081	9916	Economy	28000.00
0005434825937	9916	Economy	28000.00
0005434825359	9916	Economy	28000.00
0005435302319	9916	Economy	28000.00
0005435315037	9916	Economy	28000.00
0005432823501	9916	Economy	28000.00
0005434825563	9916	Economy	28000.00
0005435150323	9916	Economy	28000.00
0005434825100	9916	Economy	28000.00
0005434826123	9916	Economy	28000.00
0005434826090	9916	Economy	28000.00
0005435374904	9916	Economy	28000.00
0005435302321	9916	Economy	28000.00
0005434825772	9916	Economy	28000.00
0005434825484	9916	Economy	28000.00
0005434825960	9916	Economy	28000.00
0005435374908	9916	Economy	28000.00
0005434828749	9916	Economy	28000.00
0005432400176	9916	Economy	28000.00
0005434831210	9916	Economy	28000.00
0005434826051	9916	Economy	28000.00
0005435315042	9916	Economy	28000.00
0005434825783	9916	Economy	28000.00
0005434825698	9916	Economy	28000.00
0005434825079	9916	Economy	28000.00
0005435735258	9916	Economy	28000.00
0005434825478	9916	Economy	28000.00
0005435315058	9916	Economy	28000.00
0005434826106	9916	Economy	28000.00
0005435150298	9916	Economy	28000.00
0005434825540	9916	Economy	28000.00
0005434825849	9916	Economy	28000.00
0005434831231	9916	Economy	28000.00
0005435374933	9916	Economy	28000.00
0005435374929	9916	Economy	28000.00
0005435150256	9916	Economy	28000.00
0005434826452	9916	Economy	28000.00
0005435374927	9916	Economy	28000.00
0005435374949	9916	Economy	28000.00
0005435374901	9916	Economy	28000.00
0005435374953	9916	Economy	28000.00
0005434825427	9916	Economy	28000.00
0005435374942	9916	Economy	28000.00
0005434826143	9916	Economy	28000.00
0005435315060	9916	Economy	28000.00
0005435374915	9916	Economy	28000.00
0005434825414	9916	Economy	28000.00
0005432400202	9916	Economy	28000.00
0005434825801	9916	Economy	28000.00
0005434826060	9916	Economy	28000.00
0005434825742	9916	Economy	28000.00
0005432203247	9916	Economy	28000.00
0005434825292	9916	Economy	28000.00
0005435374916	9916	Economy	28000.00
0005435374924	9916	Economy	28000.00
0005435150199	9916	Economy	28000.00
0005434825415	9916	Economy	28000.00
0005435315039	9916	Economy	28000.00
0005434826055	9916	Economy	28000.00
0005434825967	9916	Economy	28000.00
0005435302317	9916	Economy	28000.00
0005435374923	9916	Economy	28000.00
0005434825284	9916	Economy	28000.00
0005435315044	9916	Economy	28000.00
0005434825942	9916	Economy	28000.00
0005434825697	9916	Economy	28000.00
0005435374906	9916	Economy	28000.00
0005435150277	9916	Economy	28000.00
0005434825608	9916	Economy	28000.00
0005432203246	9916	Economy	28000.00
0005435374893	9916	Economy	28000.00
0005435374909	9916	Economy	28000.00
0005434558377	9916	Economy	28000.00
0005435179711	9916	Economy	28000.00
0005434825915	9916	Economy	28000.00
0005435374950	9916	Economy	28000.00
0005435662005	9916	Economy	28000.00
0005435374925	9916	Economy	28000.00
0005435315051	9916	Economy	28000.00
0005434826011	9916	Economy	28000.00
0005434825754	9916	Economy	28000.00
0005434825755	9916	Economy	28000.00
0005435374944	9916	Economy	28000.00
0005435374919	9916	Economy	30800.00
0005434825700	9916	Economy	30800.00
0005435386737	9916	Economy	28000.00
0005434825496	9916	Economy	28000.00
0005434825635	9916	Economy	28000.00
0005435179422	9916	Economy	28000.00
0005435374903	9916	Economy	28000.00
0005435374920	9916	Economy	28000.00
0005435374907	9916	Economy	28000.00
0005434826285	9916	Economy	28000.00
0005435386734	9916	Economy	28000.00
0005435374947	9916	Economy	28000.00
0005435150218	9916	Economy	28000.00
0005434558399	9916	Economy	28000.00
0005434825654	9916	Economy	28000.00
0005435374902	9916	Economy	28000.00
0005434826028	9916	Economy	28000.00
0005434825125	9916	Economy	28000.00
0005435150257	9916	Economy	28000.00
0005434824943	9916	Economy	28000.00
0005434826080	9916	Economy	28000.00
0005434825283	9916	Economy	28000.00
0005434825968	9916	Economy	28000.00
0005434825883	9916	Economy	28000.00
0005435315056	9916	Economy	28000.00
0005435662003	9916	Economy	28000.00
0005434825405	9916	Economy	28000.00
0005435150268	9916	Economy	28000.00
0005435150200	9916	Economy	28000.00
0005434825769	9916	Economy	28000.00
0005435315036	9916	Economy	28000.00
0005434825943	9916	Economy	28000.00
0005434825981	9916	Economy	28000.00
0005434825483	9916	Economy	28000.00
0005432823502	9916	Economy	28000.00
0005435374898	9916	Economy	28000.00
0005432203248	9916	Economy	28000.00
0005435315047	9916	Economy	28000.00
0005434558409	9916	Economy	28000.00
0005435374939	9916	Economy	28000.00
0005434825951	9916	Economy	28000.00
0005435374930	9916	Economy	28000.00
0005434825442	9916	Economy	28000.00
0005435374911	9916	Economy	28000.00
0005435374936	9916	Economy	28000.00
0005435374917	9916	Economy	28000.00
0005434825598	9916	Economy	28000.00
0005435374941	9916	Economy	28000.00
0005435374931	9916	Economy	28000.00
0005435374891	9916	Economy	28000.00
0005434825776	9916	Economy	28000.00
0005434825982	9916	Economy	28000.00
0005435374895	9916	Economy	28000.00
0005434826122	9916	Economy	28000.00
0005434825387	9916	Economy	28000.00
0005434825848	9916	Economy	28000.00
0005432396312	9916	Economy	28000.00
0005434825078	9916	Economy	28000.00
0005435315041	9916	Economy	28000.00
0005434826072	9916	Economy	28000.00
0005434825653	9916	Economy	28000.00
0005434825509	9916	Economy	28000.00
0005434825991	9916	Economy	28000.00
0005434825823	9916	Economy	28000.00
0005435150222	9916	Economy	28000.00
0005435302318	9916	Economy	28000.00
0005434826453	9916	Economy	28000.00
0005434825664	9916	Economy	28000.00
0005435179420	9916	Economy	28000.00
0005434825784	9916	Economy	28000.00
0005434825800	9916	Economy	28000.00
0005435374905	9916	Economy	28000.00
0005434825822	9916	Economy	28000.00
0005434825564	9916	Economy	28000.00
0005435315053	9916	Economy	28000.00
0005434825606	9916	Economy	28000.00
0005435374952	9916	Economy	28000.00
0005434825993	9916	Economy	28000.00
0005435179712	9916	Economy	28000.00
0005435302320	9916	Economy	28000.00
0005434825177	9916	Economy	28000.00
0005434825802	9916	Economy	28000.00
0005435082992	7008	Economy	7400.00
0005435790382	7008	Economy	7400.00
0005435082996	7008	Economy	7400.00
0005435790380	7008	Economy	7400.00
0005435082989	7008	Economy	7400.00
0005435082991	7008	Economy	7400.00
0005435790381	7008	Economy	7400.00
0005435082994	7008	Economy	7400.00
0005435790383	7008	Economy	7400.00
0005435082990	7008	Economy	7400.00
0005435082995	7008	Economy	7400.00
0005435082993	7008	Economy	7400.00
0005435377992	26019	Economy	7400.00
0005435790364	26019	Economy	7400.00
0005435790360	26019	Economy	7400.00
0005435377991	26019	Economy	7400.00
0005435082921	26019	Economy	7400.00
0005435082920	26019	Economy	7400.00
0005435082932	26019	Economy	7400.00
0005435082928	26019	Economy	7400.00
0005435790358	26019	Economy	7400.00
0005435377993	26019	Economy	7400.00
0005435082936	26019	Economy	7400.00
0005435790365	26019	Economy	7400.00
0005434757478	9536	Business	32800.00
0005434757474	9536	Business	32800.00
0005434757518	9536	Business	32800.00
0005434757492	9536	Business	32800.00
0005434757484	9536	Business	32800.00
0005434757482	9536	Business	32800.00
0005434757516	9536	Business	32800.00
0005434215332	9536	Business	32800.00
0005434215366	9536	Business	32800.00
0005434757511	9536	Business	32800.00
0005434215156	9536	Business	32800.00
0005434215131	9536	Economy	10900.00
0005434215276	9536	Economy	10900.00
0005434215501	9536	Economy	10900.00
0005434215256	9536	Economy	10900.00
0005434757498	9536	Economy	10900.00
0005434215273	9536	Economy	10900.00
0005434215445	9536	Economy	10900.00
0005434215308	9536	Economy	10900.00
0005434757477	9536	Economy	10900.00
0005434757509	9536	Economy	12000.00
0005434215469	9536	Economy	12000.00
0005434215282	9536	Economy	12000.00
0005434215281	9536	Economy	12000.00
0005434215092	9536	Economy	12000.00
0005434215307	9536	Economy	10900.00
0005434215274	9536	Economy	10900.00
0005434215371	9536	Economy	10900.00
0005434757486	9536	Economy	10900.00
0005434757503	9536	Economy	10900.00
0005434757507	9536	Economy	10900.00
0005434215377	9536	Economy	10900.00
0005434757490	9536	Economy	10900.00
0005434757475	9536	Economy	10900.00
0005434757517	9536	Economy	10900.00
0005434215118	9536	Economy	10900.00
0005434215128	9536	Economy	10900.00
0005434757502	9536	Economy	10900.00
0005434215291	9536	Economy	10900.00
0005434757481	9536	Economy	10900.00
0005434757504	9536	Economy	10900.00
0005434215257	9536	Economy	10900.00
0005434757508	9536	Economy	10900.00
0005434215336	9536	Economy	10900.00
0005434757512	9536	Economy	10900.00
0005434757488	9536	Economy	10900.00
0005434757520	9536	Economy	10900.00
0005434757506	9536	Economy	10900.00
0005434757510	9536	Economy	10900.00
0005434215238	9536	Economy	10900.00
0005434757500	9536	Economy	10900.00
0005434757513	9536	Economy	10900.00
0005434215444	9536	Economy	10900.00
0005434757496	9536	Economy	10900.00
0005434215157	9536	Economy	10900.00
0005434757505	9536	Economy	10900.00
0005434215453	9536	Economy	10900.00
0005434215299	9536	Economy	10900.00
0005434757497	9536	Economy	10900.00
0005434757515	9536	Economy	10900.00
0005434757501	9536	Economy	10900.00
0005434215319	9536	Economy	10900.00
0005434757487	9536	Economy	10900.00
0005434757499	9536	Economy	10900.00
0005434757485	9536	Economy	10900.00
0005434757495	9536	Economy	10900.00
0005434757491	9536	Economy	10900.00
0005434215187	9536	Economy	10900.00
0005434757493	9536	Economy	10900.00
0005434215091	9536	Economy	10900.00
0005434215189	9536	Economy	10900.00
0005434757479	9536	Economy	10900.00
0005434215148	9536	Economy	10900.00
0005434757494	9536	Economy	10900.00
0005434215410	9536	Economy	10900.00
0005434215167	9536	Economy	10900.00
0005434757476	9536	Economy	10900.00
0005434215228	9536	Economy	10900.00
0005434215136	9536	Economy	10900.00
0005434215213	9536	Economy	10900.00
0005434215188	9536	Economy	10900.00
0005434215086	9536	Economy	10900.00
0005434215440	9536	Economy	10900.00
0005434757519	9536	Economy	10900.00
0005434757483	9536	Economy	10900.00
0005434757514	9536	Economy	10900.00
0005434757489	9536	Economy	10900.00
0005434757480	9536	Economy	10900.00
0005434215457	9536	Economy	10900.00
0005434215306	9536	Economy	10900.00
0005434215691	28611	Business	32800.00
0005434215652	28611	Business	32800.00
0005434757019	28611	Business	32800.00
0005434215648	28611	Business	32800.00
0005434215677	28611	Business	32800.00
0005434215692	28611	Business	32800.00
0005434215676	28611	Business	32800.00
0005434756891	28611	Business	32800.00
0005434215663	28611	Business	32800.00
0005434757022	28611	Business	32800.00
0005434756936	28611	Business	32800.00
0005434757017	28611	Economy	10900.00
0005434757176	28611	Economy	10900.00
0005434215693	28611	Economy	10900.00
0005434757035	28611	Economy	10900.00
0005434757085	28611	Economy	10900.00
0005434215671	28611	Economy	10900.00
0005434215685	28611	Economy	10900.00
0005434757140	28611	Economy	10900.00
0005434756994	28611	Economy	10900.00
0005434215649	28611	Economy	12000.00
0005434756817	28611	Economy	12000.00
0005434215665	28611	Economy	12000.00
0005434215674	28611	Economy	12000.00
0005434215682	28611	Economy	10900.00
0005434215672	28611	Economy	10900.00
0005434215651	28611	Economy	10900.00
0005434215690	28611	Economy	10900.00
0005434215689	28611	Economy	10900.00
0005434757121	28611	Economy	10900.00
0005434215675	28611	Economy	10900.00
0005434757065	28611	Economy	10900.00
0005434757020	28611	Economy	10900.00
0005434215683	28611	Economy	10900.00
0005434215684	28611	Economy	10900.00
0005434215678	28611	Economy	10900.00
0005434757088	28611	Economy	10900.00
0005434215658	28611	Economy	10900.00
0005434215653	28611	Economy	10900.00
0005434757171	28611	Economy	10900.00
0005434756960	28611	Economy	10900.00
0005434757103	28611	Economy	10900.00
0005434215687	28611	Economy	10900.00
0005434756972	28611	Economy	10900.00
0005434215655	28611	Economy	10900.00
0005434757049	28611	Economy	10900.00
0005434756872	28611	Economy	10900.00
0005434757021	28611	Economy	10900.00
0005434757054	28611	Economy	10900.00
0005434757177	28611	Economy	10900.00
0005434757104	28611	Economy	10900.00
0005434215688	28611	Economy	10900.00
0005434756989	28611	Economy	10900.00
0005434756845	28611	Economy	10900.00
0005434757051	28611	Economy	10900.00
0005434215681	28611	Economy	10900.00
0005434215662	28611	Economy	10900.00
0005434757053	28611	Economy	10900.00
0005434215664	28611	Economy	10900.00
0005434215650	28611	Economy	10900.00
0005434757034	28611	Economy	10900.00
0005434215666	28611	Economy	10900.00
0005434215660	28611	Economy	10900.00
0005434757037	28611	Economy	10900.00
0005434756977	28611	Economy	10900.00
0005434215656	28611	Economy	10900.00
0005434215657	28611	Economy	10900.00
0005434757089	28611	Economy	10900.00
0005434215680	28611	Economy	10900.00
0005434756854	28611	Economy	10900.00
0005434215661	28611	Economy	10900.00
0005434215670	28611	Economy	10900.00
0005434215673	28611	Economy	10900.00
0005434757192	28611	Economy	10900.00
0005434215668	28611	Economy	10900.00
0005434215659	28611	Economy	10900.00
0005434757059	28611	Economy	10900.00
0005434215694	28611	Economy	10900.00
0005434757084	28611	Economy	10900.00
0005434215679	28611	Economy	10900.00
0005434215654	28611	Economy	10900.00
0005434756800	28611	Economy	10900.00
0005434215669	28611	Economy	10900.00
0005434215667	28611	Economy	10900.00
0005434756816	28611	Economy	10900.00
0005434215686	28611	Economy	10900.00
0005435100200	10848	Economy	9800.00
0005434760219	10848	Economy	8900.00
0005434760238	10848	Economy	8900.00
0005435100199	10848	Economy	8900.00
0005434760260	31834	Economy	8900.00
0005434760261	31834	Economy	8900.00
0005434760259	31834	Economy	8900.00
0005435100172	31834	Economy	8900.00
0005435100173	31834	Economy	8900.00
0005434639989	2004	Economy	20900.00
0005434639996	2004	Economy	20900.00
0005433202548	2004	Economy	20900.00
0005433202584	2004	Economy	20900.00
0005433202585	2004	Economy	19000.00
0005432290712	2004	Economy	19000.00
0005433202648	2004	Economy	19000.00
0005434639990	2004	Economy	19000.00
0005432290713	2004	Economy	19000.00
0005433202531	2004	Economy	19000.00
0005434639983	2004	Economy	19000.00
0005434639987	2004	Economy	19000.00
0005433202558	2004	Economy	19000.00
0005434639984	2004	Economy	19000.00
0005433202615	2004	Economy	19000.00
0005433202603	2004	Economy	19000.00
0005434639991	2004	Economy	19000.00
0005433202530	2004	Economy	19000.00
0005434639982	2004	Economy	19000.00
0005434639998	2004	Economy	19000.00
0005433202614	2004	Economy	19000.00
0005433202604	2004	Economy	19000.00
0005434639978	2004	Economy	19000.00
0005434639977	2004	Economy	19000.00
0005434639976	2004	Economy	19000.00
0005434639992	2004	Economy	19000.00
0005434639986	2004	Economy	19000.00
0005433202542	2004	Economy	19000.00
0005434639997	2004	Economy	19000.00
0005434639981	2004	Economy	19000.00
0005433202583	2004	Economy	19000.00
0005434639993	2004	Economy	19000.00
0005433202557	2004	Economy	19000.00
0005432290714	2004	Economy	19000.00
0005433202624	2004	Economy	19000.00
0005433202613	2004	Economy	19000.00
0005433202588	2004	Economy	19000.00
0005434639979	2004	Economy	19000.00
0005433202556	2004	Economy	19000.00
0005434639988	2004	Economy	19000.00
0005434639985	2004	Economy	19000.00
0005434639994	2004	Economy	19000.00
0005433202616	2004	Economy	19000.00
0005433202601	2004	Economy	19000.00
0005433202567	2004	Economy	19000.00
0005433202566	2004	Economy	19000.00
0005434639995	2004	Economy	19000.00
0005433202602	2004	Economy	19000.00
0005434639980	2004	Economy	19000.00
0005433202623	2004	Economy	19000.00
0005434639834	23274	Economy	20900.00
0005433202732	23274	Economy	20900.00
0005434639746	23274	Economy	20900.00
0005434639703	23274	Economy	20900.00
0005433202724	23274	Economy	19000.00
0005435948348	23274	Economy	19000.00
0005434639678	23274	Economy	19000.00
0005433202731	23274	Economy	19000.00
0005434639720	23274	Economy	19000.00
0005434639627	23274	Economy	19000.00
0005433202729	23274	Economy	19000.00
0005434639688	23274	Economy	19000.00
0005434639842	23274	Economy	19000.00
0005434639701	23274	Economy	19000.00
0005434639732	23274	Economy	19000.00
0005433202730	23274	Economy	19000.00
0005433202726	23274	Economy	19000.00
0005433202727	23274	Economy	19000.00
0005434639745	23274	Economy	19000.00
0005434639756	23274	Economy	19000.00
0005434639716	23274	Economy	19000.00
0005433202723	23274	Economy	19000.00
0005435948341	23274	Economy	19000.00
0005434639689	23274	Economy	19000.00
0005434639684	23274	Economy	19000.00
0005434639659	23274	Economy	19000.00
0005433202733	23274	Economy	19000.00
0005433202720	23274	Economy	19000.00
0005434639833	23274	Economy	19000.00
0005434639736	23274	Economy	19000.00
0005434639700	23274	Economy	19000.00
0005434639674	23274	Economy	19000.00
0005433202721	23274	Economy	19000.00
0005434639605	23274	Economy	19000.00
0005435948347	23274	Economy	19000.00
0005434639705	23274	Economy	19000.00
0005435948339	23274	Economy	19000.00
0005434639747	23274	Economy	19000.00
0005435948340	23274	Economy	19000.00
0005434639604	23274	Economy	19000.00
0005434639660	23274	Economy	19000.00
0005434639733	23274	Economy	19000.00
0005434639706	23274	Economy	19000.00
0005433202725	23274	Economy	19000.00
0005435948343	23274	Economy	19000.00
0005433202722	23274	Economy	19000.00
0005433202728	23274	Economy	19000.00
0005435327004	6064	Business	69700.00
0005433531389	6064	Business	69700.00
0005433533406	6064	Business	69700.00
0005434601490	6064	Business	69700.00
0005435326970	6064	Business	69700.00
0005434601498	6064	Economy	23200.00
0005433533405	6064	Economy	23200.00
0005432111354	6064	Economy	23200.00
0005434601486	6064	Economy	23200.00
0005435326951	6064	Economy	23200.00
0005435327005	6064	Economy	25600.00
0005433531391	6064	Economy	25600.00
0005434601503	6064	Economy	23200.00
0005432111355	6064	Economy	23200.00
0005433531390	6064	Economy	23200.00
0005435326999	6064	Economy	23200.00
0005434601487	6064	Economy	23200.00
0005434601489	6064	Economy	23200.00
0005434601495	6064	Economy	23200.00
0005435327000	6064	Economy	23200.00
0005434601494	6064	Economy	23200.00
0005435326971	6064	Economy	23200.00
0005434601492	6064	Economy	23200.00
0005435326947	6064	Economy	23200.00
0005434601501	6064	Economy	23200.00
0005435326933	6064	Economy	23200.00
0005434601485	6064	Economy	23200.00
0005434601497	6064	Economy	23200.00
0005434601493	6064	Economy	23200.00
0005435326980	6064	Economy	23200.00
0005435326950	6064	Economy	23200.00
0005435326969	6064	Economy	23200.00
0005434601500	6064	Economy	23200.00
0005434601488	6064	Economy	23200.00
0005434601504	6064	Economy	23200.00
0005435326949	6064	Economy	23200.00
0005435326922	6064	Economy	23200.00
0005435326925	6064	Economy	23200.00
0005434601499	6064	Economy	23200.00
0005435326972	6064	Economy	23200.00
0005435327029	6064	Economy	23200.00
0005432111356	6064	Economy	23200.00
0005435326923	6064	Economy	23200.00
0005433533403	6064	Economy	23200.00
0005433533404	6064	Economy	23200.00
0005434601491	6064	Economy	23200.00
0005433531392	6064	Economy	23200.00
0005435326932	6064	Economy	23200.00
0005434601502	6064	Economy	23200.00
0005434601496	6064	Economy	23200.00
0005434601282	18615	Business	69700.00
0005434601333	18615	Business	69700.00
0005434601241	18615	Business	69700.00
0005434601281	18615	Business	69700.00
0005435327095	18615	Business	69700.00
0005434601220	18615	Economy	23200.00
0005435327100	18615	Economy	23200.00
0005435327101	18615	Economy	23200.00
0005433531342	18615	Economy	23200.00
0005435327099	18615	Economy	23200.00
0005434601244	18615	Economy	23200.00
0005435327090	18615	Economy	25600.00
0005434601328	18615	Economy	25600.00
0005434601299	18615	Economy	25600.00
0005433531352	18615	Economy	25600.00
0005434601243	18615	Economy	23200.00
0005434601273	18615	Economy	23200.00
0005434601311	18615	Economy	23200.00
0005434601280	18615	Economy	23200.00
0005433531341	18615	Economy	23200.00
0005434601391	18615	Economy	23200.00
0005434601260	18615	Economy	23200.00
0005435327098	18615	Economy	23200.00
0005435327092	18615	Economy	23200.00
0005434601219	18615	Economy	23200.00
0005434601334	18615	Economy	23200.00
0005434601392	18615	Economy	23200.00
0005434601242	18615	Economy	23200.00
0005434601300	18615	Economy	23200.00
0005434601272	18615	Economy	23200.00
0005434601271	18615	Economy	23200.00
0005435327094	18615	Economy	23200.00
0005434601259	18615	Economy	23200.00
0005434601218	18615	Economy	23200.00
0005435327093	18615	Economy	23200.00
0005434601247	18615	Economy	23200.00
0005434601390	18615	Economy	23200.00
0005435327097	18615	Economy	23200.00
0005435327091	18615	Economy	23200.00
0005433531351	18615	Economy	23200.00
0005434601389	18615	Economy	23200.00
0005434601329	18615	Economy	23200.00
0005435327089	18615	Economy	23200.00
0005434601369	18615	Economy	23200.00
0005434601337	18615	Economy	23200.00
0005434601142	18615	Economy	23200.00
0005435327096	18615	Economy	23200.00
0005434601245	18615	Economy	23200.00
0005433181485	10576	Business	9100.00
0005433181497	10576	Business	9100.00
0005433181463	10576	Business	9100.00
0005433181494	10576	Business	9100.00
0005433181495	10576	Business	9100.00
0005434552563	10576	Business	9100.00
0005434552581	10576	Business	9100.00
0005434552596	10576	Business	9100.00
0005434552602	10576	Business	9100.00
0005434552586	10576	Business	9100.00
0005433181466	10576	Economy	3000.00
0005433181465	10576	Economy	3000.00
0005434552569	10576	Economy	3000.00
0005434558487	10576	Economy	3000.00
0005433181524	10576	Economy	3000.00
0005434552588	10576	Economy	3000.00
0005433181427	10576	Economy	3000.00
0005433181435	10576	Economy	3000.00
0005433181440	10576	Economy	3000.00
0005434552574	10576	Economy	3000.00
0005434552587	10576	Economy	3300.00
0005434558484	10576	Economy	3300.00
0005433181564	10576	Economy	3300.00
0005434552583	10576	Economy	3000.00
0005433181541	10576	Economy	3000.00
0005434552556	10576	Economy	3000.00
0005433181496	10576	Economy	3000.00
0005434552557	10576	Economy	3000.00
0005433181439	10576	Economy	3000.00
0005434558486	10576	Economy	3000.00
0005434552560	10576	Economy	3000.00
0005434552604	10576	Economy	3000.00
0005434552594	10576	Economy	3000.00
0005434552603	10576	Economy	3000.00
0005434552564	10576	Economy	3000.00
0005434558485	10576	Economy	3000.00
0005434552590	10576	Economy	3000.00
0005434558483	10576	Economy	3000.00
0005434558488	10576	Economy	3000.00
0005434552601	10576	Economy	3000.00
0005433181478	10576	Economy	3000.00
0005434552573	10576	Economy	3000.00
0005434552592	10576	Economy	3000.00
0005434552575	10576	Economy	3000.00
0005434558491	10576	Economy	3000.00
0005434552593	10576	Economy	3000.00
0005434558489	10576	Economy	3000.00
0005433181443	10576	Economy	3000.00
0005433181428	10576	Economy	3000.00
0005434552568	10576	Economy	3000.00
0005434552598	10576	Economy	3000.00
0005434552572	10576	Economy	3000.00
0005434552579	10576	Economy	3000.00
0005433181454	10576	Economy	3000.00
0005433181542	10576	Economy	3000.00
0005434552585	10576	Economy	3000.00
0005434552600	10576	Economy	3000.00
0005434552582	10576	Economy	3000.00
0005434554115	10576	Economy	3000.00
0005434552554	10576	Economy	3000.00
0005434552597	10576	Economy	3000.00
0005434552571	10576	Economy	3000.00
0005434558481	10576	Economy	3000.00
0005434558482	10576	Economy	3000.00
0005434552577	10576	Economy	3000.00
0005434552584	10576	Economy	3000.00
0005434552591	10576	Economy	3000.00
0005434552599	10576	Economy	3000.00
0005433181543	10576	Economy	3000.00
0005433181507	10576	Economy	3000.00
0005434552576	10576	Economy	3000.00
0005434552561	10576	Economy	3000.00
0005434552580	10576	Economy	3000.00
0005433181369	10576	Economy	3000.00
0005434558490	10576	Economy	3000.00
0005434552562	10576	Economy	3000.00
0005434552555	10576	Economy	3000.00
0005434552570	10576	Economy	3000.00
0005434552559	10576	Economy	3000.00
0005433181544	10576	Economy	3000.00
0005433181402	10576	Economy	3000.00
0005434552589	10576	Economy	3000.00
0005434552565	10576	Economy	3000.00
0005434552595	10576	Economy	3000.00
0005433181448	10576	Economy	3000.00
0005434552566	10576	Economy	3000.00
0005434552567	10576	Economy	3000.00
0005434552558	10576	Economy	3000.00
0005434552578	10576	Economy	3000.00
0005435315037	27698	Business	9100.00
0005433181745	27698	Business	9100.00
0005435315057	27698	Business	9100.00
0005435315055	27698	Business	9100.00
0005433181737	27698	Business	9100.00
0005435315048	27698	Business	9100.00
0005433181740	27698	Business	9100.00
0005435315044	27698	Economy	3000.00
0005435315047	27698	Economy	3000.00
0005433181736	27698	Economy	3000.00
0005433181741	27698	Economy	3000.00
0005433181748	27698	Economy	3000.00
0005435315046	27698	Economy	3000.00
0005435315052	27698	Economy	3300.00
0005435315058	27698	Economy	3300.00
0005433181753	27698	Economy	3300.00
0005433181757	27698	Economy	3300.00
0005433181744	27698	Economy	3000.00
0005433181739	27698	Economy	3000.00
0005435315035	27698	Economy	3000.00
0005433181754	27698	Economy	3000.00
0005433181742	27698	Economy	3000.00
0005435315053	27698	Economy	3000.00
0005433181746	27698	Economy	3000.00
0005435315056	27698	Economy	3000.00
0005435315060	27698	Economy	3000.00
0005435315042	27698	Economy	3000.00
0005435315054	27698	Economy	3000.00
0005433181734	27698	Economy	3000.00
0005435315050	27698	Economy	3000.00
0005433181743	27698	Economy	3000.00
0005435315039	27698	Economy	3000.00
0005433181756	27698	Economy	3000.00
0005434757703	27698	Economy	3000.00
0005435315045	27698	Economy	3000.00
0005434757702	27698	Economy	3000.00
0005435315059	27698	Economy	3000.00
0005435315038	27698	Economy	3000.00
0005435315043	27698	Economy	3000.00
0005435315040	27698	Economy	3000.00
0005434757701	27698	Economy	3000.00
0005435315049	27698	Economy	3000.00
0005433181750	27698	Economy	3000.00
0005433181755	27698	Economy	3000.00
0005433181738	27698	Economy	3000.00
0005433181735	27698	Economy	3000.00
0005433181749	27698	Economy	3000.00
0005435315041	27698	Economy	3000.00
0005433181752	27698	Economy	3000.00
0005433181747	27698	Economy	3000.00
0005434757704	27698	Economy	3000.00
0005433181751	27698	Economy	3000.00
0005435315036	27698	Economy	3000.00
0005435315051	27698	Economy	3000.00
0005434552115	27717	Business	9100.00
0005434552037	27717	Business	9100.00
0005434551980	27717	Business	9100.00
0005434552219	27717	Business	9100.00
0005434551915	27717	Business	9100.00
0005434552018	27717	Business	9100.00
0005434552134	27717	Business	9100.00
0005434552068	27717	Business	9100.00
0005434552202	27717	Business	9100.00
0005434558371	27717	Business	9100.00
0005434552135	27717	Economy	3000.00
0005434558402	27717	Economy	3000.00
0005434552328	27717	Economy	3000.00
0005434552298	27717	Economy	3000.00
0005434552016	27717	Economy	3000.00
0005434552226	27717	Economy	3000.00
0005434552227	27717	Economy	3000.00
0005434552137	27717	Economy	3000.00
0005434551851	27717	Economy	3300.00
0005434558426	27717	Economy	3300.00
0005434552242	27717	Economy	3000.00
0005434552000	27717	Economy	3000.00
0005434552297	27717	Economy	3000.00
0005434552199	27717	Economy	3000.00
0005434552223	27717	Economy	3000.00
0005434552198	27717	Economy	3000.00
0005434552149	27717	Economy	3000.00
0005434551976	27717	Economy	3000.00
0005434552269	27717	Economy	3000.00
0005434552241	27717	Economy	3000.00
0005434552188	27717	Economy	3000.00
0005434552293	27717	Economy	3000.00
0005434558384	27717	Economy	3000.00
0005434552327	27717	Economy	3000.00
0005434552239	27717	Economy	3000.00
0005434552201	27717	Economy	3000.00
0005434552383	27717	Economy	3000.00
0005434552186	27717	Economy	3000.00
0005434552052	27717	Economy	3000.00
0005434552224	27717	Economy	3000.00
0005434558419	27717	Economy	3000.00
0005434552185	27717	Economy	3000.00
0005434552017	27717	Economy	3000.00
0005434551916	27717	Economy	3000.00
0005434552079	27717	Economy	3000.00
0005434552303	27717	Economy	3000.00
0005434552025	27717	Economy	3000.00
0005434552085	27717	Economy	3000.00
0005434558427	27717	Economy	3000.00
0005434552130	27717	Economy	3000.00
0005434552136	27717	Economy	3000.00
0005434552187	27717	Economy	3000.00
0005434552326	27717	Economy	3000.00
0005434558413	27717	Economy	3000.00
0005434552114	27717	Economy	3000.00
0005434552086	27717	Economy	3000.00
0005434552128	27717	Economy	3000.00
0005434551823	27717	Economy	3000.00
0005434552024	27717	Economy	3000.00
0005434552078	27717	Economy	3000.00
0005434552129	27717	Economy	3000.00
0005434551977	27717	Economy	3000.00
0005434552200	27717	Economy	3000.00
0005434558400	27717	Economy	3000.00
0005434552143	27717	Economy	3000.00
0005434552240	27717	Economy	3000.00
0005434552077	27717	Economy	3000.00
0005434552177	27717	Economy	3000.00
0005434552197	27717	Economy	3000.00
0005434558420	27717	Economy	3000.00
0005434552150	27717	Economy	3000.00
0005433459327	6114	Economy	11700.00
0005433459328	6114	Economy	11700.00
0005433459330	6114	Economy	11700.00
0005433459326	6114	Economy	11700.00
0005435254506	6114	Economy	11700.00
0005435254505	6114	Economy	11700.00
0005433459329	6114	Economy	11700.00
0005433459291	19311	Economy	11700.00
0005435254534	19311	Economy	11700.00
0005435254535	19311	Economy	11700.00
0005433459271	19311	Economy	11700.00
0005435254533	19311	Economy	11700.00
0005433459272	19311	Economy	11700.00
0005433459292	19311	Economy	11700.00
0005435683190	6753	Business	51100.00
0005435438395	6753	Business	51100.00
0005435662000	6753	Business	51100.00
0005434828744	6753	Business	51100.00
0005432136294	6753	Business	51100.00
0005435438283	6753	Business	51100.00
0005432136296	6753	Business	51100.00
0005435438301	6753	Business	51100.00
0005435438334	6753	Business	51100.00
0005435217750	6753	Business	51100.00
0005435683161	6753	Business	51100.00
0005435683178	6753	Economy	17000.00
0005435683189	6753	Economy	17000.00
0005435438237	6753	Economy	17000.00
0005435438422	6753	Economy	17000.00
0005435683173	6753	Economy	17000.00
0005435438309	6753	Economy	17000.00
0005435683197	6753	Economy	17000.00
0005435438471	6753	Economy	17000.00
0005435662002	6753	Economy	18700.00
0005435720162	6753	Economy	18700.00
0005435683183	6753	Economy	18700.00
0005435683176	6753	Economy	18700.00
0005435683182	6753	Economy	17000.00
0005435683165	6753	Economy	17000.00
0005434828731	6753	Economy	17000.00
0005435683179	6753	Economy	17000.00
0005435683191	6753	Economy	17000.00
0005432136298	6753	Economy	17000.00
0005435683172	6753	Economy	17000.00
0005435683169	6753	Economy	17000.00
0005434828745	6753	Economy	17000.00
0005435438394	6753	Economy	17000.00
0005435438349	6753	Economy	17000.00
0005435683188	6753	Economy	17000.00
0005435438313	6753	Economy	17000.00
0005435438302	6753	Economy	17000.00
0005435438348	6753	Economy	17000.00
0005435683162	6753	Economy	17000.00
0005435631043	6753	Economy	17000.00
0005435438284	6753	Economy	17000.00
0005435631042	6753	Economy	17000.00
0005435438312	6753	Economy	17000.00
0005435683175	6753	Economy	17000.00
0005435438329	6753	Economy	17000.00
0005435438382	6753	Economy	17000.00
0005435683185	6753	Economy	17000.00
0005435683164	6753	Economy	17000.00
0005435438351	6753	Economy	17000.00
0005435438457	6753	Economy	17000.00
0005435438347	6753	Economy	17000.00
0005435683195	6753	Economy	17000.00
0005435683177	6753	Economy	17000.00
0005432136295	6753	Economy	17000.00
0005435438311	6753	Economy	17000.00
0005435683193	6753	Economy	17000.00
0005435683196	6753	Economy	17000.00
0005435683168	6753	Economy	17000.00
0005435683184	6753	Economy	17000.00
0005435438472	6753	Economy	17000.00
0005432533343	6753	Economy	17000.00
0005435683163	6753	Economy	17000.00
0005435683181	6753	Economy	17000.00
0005435438236	6753	Economy	17000.00
0005435683180	6753	Economy	17000.00
0005435683166	6753	Economy	17000.00
0005435438350	6753	Economy	17000.00
0005435438401	6753	Economy	17000.00
0005435719596	6753	Economy	17000.00
0005435438359	6753	Economy	17000.00
0005435662001	6753	Economy	17000.00
0005435683174	6753	Economy	17000.00
0005432136297	6753	Economy	17000.00
0005435683170	6753	Economy	17000.00
0005435683194	6753	Economy	17000.00
0005435683187	6753	Economy	17000.00
0005435438402	6753	Economy	17000.00
0005435631044	6753	Economy	17000.00
0005435719595	6753	Economy	17000.00
0005435683198	6753	Economy	17000.00
0005435683192	6753	Economy	17000.00
0005435438447	6753	Economy	17000.00
0005435683171	6753	Economy	17000.00
0005435683167	6753	Economy	17000.00
0005435438383	6753	Economy	17000.00
0005435683186	6753	Economy	17000.00
0005435438413	6753	Economy	17000.00
0005435438340	6753	Economy	17000.00
0005435719581	24563	Business	51100.00
0005435438517	24563	Business	51100.00
0005435682794	24563	Business	51100.00
0005435682772	24563	Business	51100.00
0005435682873	24563	Business	51100.00
0005432305811	24563	Business	51100.00
0005435682788	24563	Business	51100.00
0005435661965	24563	Business	51100.00
0005435682793	24563	Business	51100.00
0005435438514	24563	Economy	17000.00
0005435438513	24563	Economy	17000.00
0005435438507	24563	Economy	17000.00
0005435631020	24563	Economy	17000.00
0005435682826	24563	Economy	17000.00
0005435682931	24563	Economy	17000.00
0005435682697	24563	Economy	17000.00
0005435438519	24563	Economy	17000.00
0005435682588	24563	Economy	18700.00
0005435683068	24563	Economy	18700.00
0005435682862	24563	Economy	18700.00
0005435682741	24563	Economy	18700.00
0005435682688	24563	Economy	18700.00
0005435438523	24563	Economy	17000.00
0005435682881	24563	Economy	17000.00
0005435682851	24563	Economy	17000.00
0005435682648	24563	Economy	17000.00
0005435682721	24563	Economy	17000.00
0005435438515	24563	Economy	17000.00
0005435438509	24563	Economy	17000.00
0005435719575	24563	Economy	17000.00
0005435682825	24563	Economy	17000.00
0005432533365	24563	Economy	17000.00
0005435682833	24563	Economy	17000.00
0005435438508	24563	Economy	17000.00
0005435438521	24563	Economy	17000.00
0005435438512	24563	Economy	17000.00
0005435438518	24563	Economy	17000.00
0005435682698	24563	Economy	17000.00
0005434828767	24563	Economy	17000.00
0005435682689	24563	Economy	17000.00
0005435631012	24563	Economy	17000.00
0005435682699	24563	Economy	17000.00
0005435682722	24563	Economy	17000.00
0005435682912	24563	Economy	17000.00
0005435438516	24563	Economy	17000.00
0005432533364	24563	Economy	17000.00
0005432533366	24563	Economy	17000.00
0005435682753	24563	Economy	17000.00
0005435631018	24563	Economy	17000.00
0005434828770	24563	Economy	17000.00
0005435682740	24563	Economy	17000.00
0005435682800	24563	Economy	17000.00
0005435438511	24563	Economy	17000.00
0005435719576	24563	Economy	17000.00
0005435682937	24563	Economy	17000.00
0005435438510	24563	Economy	17000.00
0005435719577	24563	Economy	17000.00
0005435682938	24563	Economy	17000.00
0005435682852	24563	Economy	17000.00
0005435631011	24563	Economy	17000.00
0005435438522	24563	Economy	17000.00
0005435682802	24563	Economy	17000.00
0005435682747	24563	Economy	17000.00
0005435682849	24563	Economy	17000.00
0005435682932	24563	Economy	17000.00
0005434828769	24563	Economy	17000.00
0005435682771	24563	Economy	17000.00
0005435682832	24563	Economy	17000.00
0005435682643	24563	Economy	17000.00
0005435682906	24563	Economy	17000.00
0005435438520	24563	Economy	17000.00
0005435682780	24563	Economy	17000.00
0005435682781	24563	Economy	17000.00
0005435682801	24563	Economy	17000.00
0005434828768	24563	Economy	17000.00
0005435682779	24563	Economy	17000.00
0005435682589	24563	Economy	17000.00
0005435631019	24563	Economy	17000.00
0005435127365	11511	Business	26400.00
0005435127362	11511	Business	26400.00
0005435127378	11511	Business	26400.00
0005435127389	11511	Business	26400.00
0005435127368	11511	Business	26400.00
0005435127382	11511	Business	26400.00
0005435127355	11511	Business	26400.00
0005435127361	11511	Economy	8800.00
0005435558124	11511	Economy	8800.00
0005435127360	11511	Economy	8800.00
0005435127388	11511	Economy	9700.00
0005435106061	11511	Economy	9700.00
0005435558130	11511	Economy	8800.00
0005435106060	11511	Economy	8800.00
0005435127374	11511	Economy	8800.00
0005435127369	11511	Economy	8800.00
0005435127390	11511	Economy	8800.00
0005435558134	11511	Economy	8800.00
0005435127364	11511	Economy	8800.00
0005435127357	11511	Economy	8800.00
0005435127375	11511	Economy	8800.00
0005435127381	11511	Economy	8800.00
0005435127380	11511	Economy	8800.00
0005435127371	11511	Economy	8800.00
0005435127370	11511	Economy	8800.00
0005435127386	11511	Economy	8800.00
0005435127354	11511	Economy	8800.00
0005435127358	11511	Economy	8800.00
0005435127363	11511	Economy	8800.00
0005435127387	11511	Economy	8800.00
0005435127379	11511	Economy	8800.00
0005435127385	11511	Economy	8800.00
0005435127393	11511	Economy	8800.00
0005435127376	11511	Economy	8800.00
0005435127377	11511	Economy	8800.00
0005435106062	11511	Economy	8800.00
0005435127367	11511	Economy	8800.00
0005435127356	11511	Economy	8800.00
0005435127384	11511	Economy	8800.00
0005435558125	11511	Economy	8800.00
0005435127352	11511	Economy	8800.00
0005435127373	11511	Economy	8800.00
0005435127372	11511	Economy	8800.00
0005435127353	11511	Economy	8800.00
0005435127366	11511	Economy	8800.00
0005435127392	11511	Economy	8800.00
0005435127391	11511	Economy	8800.00
0005435106059	11511	Economy	8800.00
0005435127359	11511	Economy	8800.00
0005435127383	11511	Economy	8800.00
0005435126941	31886	Business	26400.00
0005435127021	31886	Business	26400.00
0005435127001	31886	Economy	8800.00
0005435127070	31886	Economy	8800.00
0005435126876	31886	Economy	8800.00
0005435126875	31886	Economy	8800.00
0005435127000	31886	Economy	8800.00
0005435127094	31886	Economy	8800.00
0005435126917	31886	Economy	9700.00
0005435098577	31886	Economy	9700.00
0005435126951	31886	Economy	8800.00
0005435127167	31886	Economy	8800.00
0005435127047	31886	Economy	8800.00
0005435098588	31886	Economy	8800.00
0005435126918	31886	Economy	8800.00
0005435126961	31886	Economy	8800.00
0005435127098	31886	Economy	8800.00
0005435127083	31886	Economy	8800.00
0005435127040	31886	Economy	8800.00
0005435098587	31886	Economy	8800.00
0005435106042	31886	Economy	8800.00
0005435127008	31886	Economy	8800.00
0005435127202	31886	Economy	8800.00
0005435106047	31886	Economy	8800.00
0005435126824	31886	Economy	8800.00
0005435127028	31886	Economy	8800.00
0005435558153	31886	Economy	8800.00
0005435127089	31886	Economy	8800.00
0005435126940	31886	Economy	8800.00
0005435558154	31886	Economy	8800.00
0005435127171	31886	Economy	8800.00
0005435127066	31886	Economy	8800.00
0005435127069	31886	Economy	8800.00
0005435106043	31886	Economy	8800.00
0005435127046	31886	Economy	8800.00
0005435127166	31886	Economy	8800.00
0005435127093	31886	Economy	8800.00
0005435098576	31886	Economy	8800.00
0005435106052	31886	Economy	8800.00
0005435127095	31886	Economy	8800.00
0005435127170	31886	Economy	8800.00
0005435126955	31886	Economy	8800.00
0005435127152	31886	Economy	8800.00
0005435127295	31886	Economy	8800.00
0005435127102	31886	Economy	8800.00
0005435126960	31886	Economy	8800.00
0005435126922	31886	Economy	8800.00
0005435126923	31886	Economy	8800.00
0005435127142	31886	Economy	8800.00
0005435127088	31886	Economy	8800.00
0005435126877	31886	Economy	8800.00
0005435732587	13525	Business	36600.00
0005435732528	13525	Business	36600.00
0005433399302	13525	Business	36600.00
0005433399301	13525	Business	36600.00
0005435732567	13525	Business	36600.00
0005433399303	13525	Business	36600.00
0005433399278	13525	Business	36600.00
0005433399275	13525	Business	36600.00
0005435732594	13525	Business	36600.00
0005433399304	13525	Economy	12200.00
0005433399291	13525	Economy	12200.00
0005433399289	13525	Economy	12200.00
0005433399266	13525	Economy	12200.00
0005433399300	13525	Economy	12200.00
0005433399270	13525	Economy	13400.00
0005433399305	13525	Economy	13400.00
0005433399294	13525	Economy	13400.00
0005433399306	13525	Economy	12200.00
0005435732548	13525	Economy	12200.00
0005433399296	13525	Economy	12200.00
0005433399267	13525	Economy	12200.00
0005433399287	13525	Economy	12200.00
0005433399280	13525	Economy	12200.00
0005433399265	13525	Economy	12200.00
0005435732615	13525	Economy	12200.00
0005433399292	13525	Economy	12200.00
0005433399307	13525	Economy	12200.00
0005433399295	13525	Economy	12200.00
0005433399288	13525	Economy	12200.00
0005433399276	13525	Economy	12200.00
0005433399285	13525	Economy	12200.00
0005435732529	13525	Economy	12200.00
0005433399272	13525	Economy	12200.00
0005433399298	13525	Economy	12200.00
0005433399284	13525	Economy	12200.00
0005433399273	13525	Economy	12200.00
0005433399271	13525	Economy	12200.00
0005433399277	13525	Economy	12200.00
0005433399282	13525	Economy	12200.00
0005435732544	13525	Economy	12200.00
0005433399286	13525	Economy	12200.00
0005433399274	13525	Economy	12200.00
0005433399297	13525	Economy	12200.00
0005435732586	13525	Economy	12200.00
0005433399268	13525	Economy	12200.00
0005433399299	13525	Economy	12200.00
0005433399293	13525	Economy	12200.00
0005435732555	13525	Economy	12200.00
0005435732614	13525	Economy	12200.00
0005433399281	13525	Economy	12200.00
0005433399279	13525	Economy	12200.00
0005433399269	13525	Economy	12200.00
0005433399283	13525	Economy	12200.00
0005435732515	13525	Economy	12200.00
0005433399290	13525	Economy	12200.00
0005433399101	19412	Business	36600.00
0005433398778	19412	Business	36600.00
0005433399100	19412	Business	36600.00
0005435732650	19412	Business	36600.00
0005435732648	19412	Business	36600.00
0005435732642	19412	Business	36600.00
0005433398903	19412	Business	36600.00
0005433399059	19412	Business	36600.00
0005435732639	19412	Business	36600.00
0005433398938	19412	Business	36600.00
0005435725749	19412	Business	36600.00
0005435732649	19412	Economy	12200.00
0005433398789	19412	Economy	12200.00
0005435732644	19412	Economy	12200.00
0005433398868	19412	Economy	12200.00
0005435725751	19412	Economy	12200.00
0005433398723	19412	Economy	12200.00
0005435732643	19412	Economy	12200.00
0005433398861	19412	Economy	13400.00
0005435732646	19412	Economy	13400.00
0005433398972	19412	Economy	13400.00
0005433398681	19412	Economy	12200.00
0005433398900	19412	Economy	12200.00
0005433398885	19412	Economy	12200.00
0005433398984	19412	Economy	12200.00
0005433398724	19412	Economy	12200.00
0005433398737	19412	Economy	12200.00
0005435732647	19412	Economy	12200.00
0005433398899	19412	Economy	12200.00
0005433398683	19412	Economy	12200.00
0005433398826	19412	Economy	12200.00
0005433398682	19412	Economy	12200.00
0005432297345	19412	Economy	12200.00
0005433398803	19412	Economy	12200.00
0005433398895	19412	Economy	12200.00
0005435725750	19412	Economy	12200.00
0005433398852	19412	Economy	12200.00
0005433398950	19412	Economy	12200.00
0005435732645	19412	Economy	12200.00
0005433398759	19412	Economy	12200.00
0005435732641	19412	Economy	12200.00
0005433398902	19412	Economy	12200.00
0005433399058	19412	Economy	12200.00
0005433398901	19412	Economy	12200.00
0005435732638	19412	Economy	12200.00
0005433398973	19412	Economy	12200.00
0005435732640	19412	Economy	12200.00
0005433398779	19412	Economy	12200.00
0005433399065	19412	Economy	12200.00
0005433398684	19412	Economy	12200.00
0005433398887	19412	Economy	12200.00
0005433398793	19412	Economy	12200.00
0005433398864	19412	Economy	12200.00
0005433398951	19412	Economy	12200.00
0005433398854	19412	Economy	12200.00
0005433399102	19412	Economy	12200.00
0005433398993	19412	Economy	12200.00
0005433398855	19412	Economy	12200.00
0005433398831	19412	Economy	12200.00
0005433398792	19412	Economy	12200.00
0005433398974	19412	Economy	12200.00
0005432297344	19412	Economy	12200.00
0005433398924	19412	Economy	12200.00
0005433398906	19412	Economy	12200.00
0005435732637	19412	Economy	12200.00
0005433398851	19412	Economy	12200.00
0005433398915	19412	Economy	12200.00
0005433398840	19412	Economy	12200.00
0005433398907	19412	Economy	12200.00
0005435069564	13187	Business	11300.00
0005435069897	13187	Business	11300.00
0005435070114	13187	Business	11300.00
0005435069727	13187	Business	11300.00
0005435069765	13187	Business	11300.00
0005435069936	13187	Business	11300.00
0005435069786	13187	Business	11300.00
0005435069951	13187	Economy	3800.00
0005435069904	13187	Economy	3800.00
0005435069855	13187	Economy	3800.00
0005435069764	13187	Economy	3800.00
0005435069756	13187	Economy	3800.00
0005435069961	13187	Economy	3800.00
0005435070111	13187	Economy	3800.00
0005435069788	13187	Economy	3800.00
0005435069891	13187	Economy	3800.00
0005435069920	13187	Economy	4100.00
0005435069866	13187	Economy	4100.00
0005435069856	13187	Economy	4100.00
0005435070115	13187	Economy	4100.00
0005435069950	13187	Economy	3800.00
0005435069755	13187	Economy	3800.00
0005435069867	13187	Economy	3800.00
0005435925655	13187	Economy	3800.00
0005435069962	13187	Economy	3800.00
0005435069744	13187	Economy	3800.00
0005435069959	13187	Economy	3800.00
0005435925656	13187	Economy	3800.00
0005435070108	13187	Economy	3800.00
0005435069885	13187	Economy	3800.00
0005435069871	13187	Economy	3800.00
0005435069935	13187	Economy	3800.00
0005435069732	13187	Economy	3800.00
0005435070155	13187	Economy	3800.00
0005435070052	13187	Economy	3800.00
0005435070154	13187	Economy	3800.00
0005435069817	13187	Economy	3800.00
0005435069948	13187	Economy	3800.00
0005435069949	13187	Economy	3800.00
0005435069890	13187	Economy	3800.00
0005435069863	13187	Economy	3800.00
0005435070127	13187	Economy	3800.00
0005435070040	13187	Economy	3800.00
0005435069819	13187	Economy	3800.00
0005435069807	13187	Economy	3800.00
0005435069731	13187	Economy	3800.00
0005435069565	13187	Economy	3800.00
0005435070011	13187	Economy	3800.00
0005435925653	13187	Economy	3800.00
0005435070070	13187	Economy	3800.00
0005435069728	13187	Economy	3800.00
0005435925652	13187	Economy	3800.00
0005435069691	13187	Economy	3800.00
0005435070010	13187	Economy	3800.00
0005435070053	13187	Economy	3800.00
0005435069914	13187	Economy	3800.00
0005435069886	13187	Economy	3800.00
0005435069841	13187	Economy	3800.00
0005435069745	13187	Economy	3800.00
0005435069887	13187	Economy	3800.00
0005435069991	13187	Economy	3800.00
0005435069952	13187	Economy	3800.00
0005435070084	13187	Economy	3800.00
0005435069566	13187	Economy	3800.00
0005435069995	13187	Economy	3800.00
0005435069818	13187	Economy	3800.00
0005435925654	13187	Economy	3800.00
0005435069726	13187	Economy	3800.00
0005435069916	13187	Economy	3800.00
0005435069850	13187	Economy	3800.00
0005435069787	13187	Economy	3800.00
0005435070153	13187	Economy	3800.00
0005435070330	15477	Business	11300.00
0005435070353	15477	Business	11300.00
0005435070374	15477	Business	11300.00
0005435070344	15477	Business	11300.00
0005435070354	15477	Business	11300.00
0005435925516	15477	Business	11300.00
0005435070357	15477	Business	11300.00
0005435925513	15477	Business	11300.00
0005435070364	15477	Business	11300.00
0005435070343	15477	Economy	3800.00
0005435070339	15477	Economy	3800.00
0005435925506	15477	Economy	3800.00
0005435925517	15477	Economy	3800.00
0005435070363	15477	Economy	3800.00
0005435925480	15477	Economy	3800.00
0005435070340	15477	Economy	3800.00
0005435070372	15477	Economy	4100.00
0005435070370	15477	Economy	4100.00
0005435925502	15477	Economy	4100.00
0005435070377	15477	Economy	4100.00
0005435070347	15477	Economy	4100.00
0005435070337	15477	Economy	3800.00
0005435070355	15477	Economy	3800.00
0005435070352	15477	Economy	3800.00
0005435070358	15477	Economy	3800.00
0005435070341	15477	Economy	3800.00
0005435070332	15477	Economy	3800.00
0005435925526	15477	Economy	3800.00
0005435070375	15477	Economy	3800.00
0005435070366	15477	Economy	3800.00
0005435070371	15477	Economy	3800.00
0005435070336	15477	Economy	3800.00
0005435070338	15477	Economy	3800.00
0005435070334	15477	Economy	3800.00
0005435925465	15477	Economy	3800.00
0005435070342	15477	Economy	3800.00
0005435070331	15477	Economy	3800.00
0005435070356	15477	Economy	3800.00
0005435070333	15477	Economy	3800.00
0005435925527	15477	Economy	3800.00
0005435070348	15477	Economy	3800.00
0005435070360	15477	Economy	3800.00
0005435925503	15477	Economy	3800.00
0005435070365	15477	Economy	3800.00
0005435070362	15477	Economy	3800.00
0005435070349	15477	Economy	3800.00
0005435070367	15477	Economy	3800.00
0005435070368	15477	Economy	3800.00
0005435925524	15477	Economy	3800.00
0005435925479	15477	Economy	3800.00
0005435070335	15477	Economy	3800.00
0005435070369	15477	Economy	3800.00
0005435925485	15477	Economy	3800.00
0005435925520	15477	Economy	3800.00
0005435070329	15477	Economy	3800.00
0005435925507	15477	Economy	3800.00
0005435070351	15477	Economy	3800.00
0005435070376	15477	Economy	3800.00
0005435070373	15477	Economy	3800.00
0005435925514	15477	Economy	3800.00
0005435070346	15477	Economy	3800.00
0005435070359	15477	Economy	3800.00
0005435070350	15477	Economy	3800.00
0005435070361	15477	Economy	3800.00
0005435070345	15477	Economy	3800.00
0005435925528	15477	Economy	3800.00
0005433407693	29478	Economy	27100.00
0005435808386	29478	Economy	27100.00
0005433407686	29478	Economy	27100.00
0005433407692	29478	Economy	27100.00
0005433407698	29478	Economy	24700.00
0005433407689	29478	Economy	24700.00
0005435808394	29478	Economy	24700.00
0005433407687	29478	Economy	24700.00
0005435808377	29478	Economy	24700.00
0005435808365	29478	Economy	24700.00
0005435808388	29478	Economy	24700.00
0005433407694	29478	Economy	24700.00
0005435808369	29478	Economy	24700.00
0005435808370	29478	Economy	24700.00
0005433407684	29478	Economy	24700.00
0005435808338	29478	Economy	24700.00
0005435808345	29478	Economy	24700.00
0005435808323	29478	Economy	24700.00
0005435808395	29478	Economy	24700.00
0005435808373	29478	Economy	24700.00
0005435808367	29478	Economy	24700.00
0005433407697	29478	Economy	24700.00
0005435808391	29478	Economy	24700.00
0005435808346	29478	Economy	24700.00
0005435808378	29478	Economy	24700.00
0005433407691	29478	Economy	24700.00
0005435808368	29478	Economy	24700.00
0005435808371	29478	Economy	24700.00
0005433407690	29478	Economy	24700.00
0005435808374	29478	Economy	24700.00
0005435808364	29478	Economy	24700.00
0005433407688	29478	Economy	24700.00
0005435808372	29478	Economy	24700.00
0005435808329	29478	Economy	24700.00
0005435808347	29478	Economy	24700.00
0005435808396	29478	Economy	24700.00
0005433407685	29478	Economy	24700.00
0005435808344	29478	Economy	24700.00
0005435808397	29478	Economy	24700.00
0005435808362	29478	Economy	24700.00
0005435808385	29478	Economy	24700.00
0005435808363	29478	Economy	24700.00
0005435808387	29478	Economy	24700.00
0005433407695	29478	Economy	24700.00
0005433407700	29478	Economy	24700.00
0005433407699	29478	Economy	24700.00
0005435808375	29478	Economy	24700.00
0005433407696	29478	Economy	24700.00
0005435808389	29478	Economy	24700.00
0005434215717	10740	Business	61300.00
0005434757061	10740	Business	61300.00
0005434215700	10740	Business	61300.00
0005434215707	10740	Business	61300.00
0005434757015	10740	Business	61300.00
0005434215727	10740	Business	61300.00
0005434215704	10740	Business	61300.00
0005434757039	10740	Business	61300.00
0005434215701	10740	Business	61300.00
0005434757014	10740	Business	61300.00
0005434757018	10740	Economy	20400.00
0005434215724	10740	Economy	20400.00
0005434757058	10740	Economy	20400.00
0005434215723	10740	Economy	20400.00
0005434757126	10740	Economy	20400.00
0005434757030	10740	Economy	20400.00
0005434756969	10740	Economy	20400.00
0005434215713	10740	Economy	20400.00
0005434215721	10740	Economy	20400.00
0005434757068	10740	Economy	20400.00
0005434215722	10740	Economy	22500.00
0005434215736	10740	Economy	22500.00
0005434756964	10740	Economy	22500.00
0005434757078	10740	Economy	20400.00
0005434757127	10740	Economy	20400.00
0005434215709	10740	Economy	20400.00
0005434215712	10740	Economy	20400.00
0005434756952	10740	Economy	20400.00
0005434215728	10740	Economy	20400.00
0005434757042	10740	Economy	20400.00
0005434215733	10740	Economy	20400.00
0005434757092	10740	Economy	20400.00
0005434757057	10740	Economy	20400.00
0005434215699	10740	Economy	20400.00
0005434215732	10740	Economy	20400.00
0005434215711	10740	Economy	20400.00
0005434757043	10740	Economy	20400.00
0005434215734	10740	Economy	20400.00
0005434215730	10740	Economy	20400.00
0005434215737	10740	Economy	20400.00
0005434757108	10740	Economy	20400.00
0005434757060	10740	Economy	20400.00
0005434757064	10740	Economy	20400.00
0005434757091	10740	Economy	20400.00
0005434215719	10740	Economy	20400.00
0005434757038	10740	Economy	20400.00
0005434215715	10740	Economy	20400.00
0005434215695	10740	Economy	20400.00
0005434215718	10740	Economy	20400.00
0005434757069	10740	Economy	20400.00
0005434215698	10740	Economy	20400.00
0005434757016	10740	Economy	20400.00
0005434215708	10740	Economy	20400.00
0005434215726	10740	Economy	20400.00
0005434756905	10740	Economy	20400.00
0005434757115	10740	Economy	20400.00
0005434756911	10740	Economy	20400.00
0005434757031	10740	Economy	20400.00
0005434215735	10740	Economy	20400.00
0005434215696	10740	Economy	20400.00
0005434215720	10740	Economy	20400.00
0005434756951	10740	Economy	20400.00
0005434215697	10740	Economy	20400.00
0005434756876	10740	Economy	20400.00
0005434215710	10740	Economy	20400.00
0005434757013	10740	Economy	20400.00
0005434215703	10740	Economy	20400.00
0005434215729	10740	Economy	20400.00
0005434757093	10740	Economy	20400.00
0005434215716	10740	Economy	20400.00
0005434757025	10740	Economy	20400.00
0005434756875	10740	Economy	20400.00
0005434215705	10740	Economy	20400.00
0005434756851	10740	Economy	20400.00
0005434757081	10740	Economy	20400.00
0005434757094	10740	Economy	20400.00
0005434215706	10740	Economy	20400.00
0005434215731	10740	Economy	20400.00
0005434756874	10740	Economy	20400.00
0005434215702	10740	Economy	20400.00
0005434757102	10740	Economy	20400.00
0005434215725	10740	Economy	20400.00
0005434757107	10740	Economy	20400.00
0005434215714	10740	Economy	20400.00
0005434215278	28672	Business	61300.00
0005434215054	28672	Business	61300.00
0005434757441	28672	Business	61300.00
0005434757459	28672	Business	61300.00
0005434757450	28672	Business	61300.00
0005434215177	28672	Business	61300.00
0005434757443	28672	Business	61300.00
0005434757465	28672	Business	61300.00
0005434757454	28672	Business	61300.00
0005434757445	28672	Business	61300.00
0005434215141	28672	Business	61300.00
0005434757436	28672	Business	61300.00
0005434215210	28672	Economy	20400.00
0005434757456	28672	Economy	20400.00
0005434215254	28672	Economy	20400.00
0005434757435	28672	Economy	20400.00
0005434215212	28672	Economy	20400.00
0005434215387	28672	Economy	20400.00
0005434757446	28672	Economy	20400.00
0005434215360	28672	Economy	20400.00
0005434215277	28672	Economy	20400.00
0005434215286	28672	Economy	20400.00
0005434215318	28672	Economy	22500.00
0005434215317	28672	Economy	22500.00
0005434757469	28672	Economy	22500.00
0005434757438	28672	Economy	22500.00
0005434757466	28672	Economy	22500.00
0005434757439	28672	Economy	20400.00
0005434215270	28672	Economy	20400.00
0005434757437	28672	Economy	20400.00
0005434757473	28672	Economy	20400.00
0005434215334	28672	Economy	20400.00
0005434215192	28672	Economy	20400.00
0005434215195	28672	Economy	20400.00
0005434215301	28672	Economy	20400.00
0005434757451	28672	Economy	20400.00
0005434215279	28672	Economy	20400.00
0005434215267	28672	Economy	20400.00
0005434757467	28672	Economy	20400.00
0005434215149	28672	Economy	20400.00
0005434757464	28672	Economy	20400.00
0005434215258	28672	Economy	20400.00
0005434215096	28672	Economy	20400.00
0005434215287	28672	Economy	20400.00
0005434215194	28672	Economy	20400.00
0005434757449	28672	Economy	20400.00
0005434215145	28672	Economy	20400.00
0005434757471	28672	Economy	20400.00
0005434215358	28672	Economy	20400.00
0005434215123	28672	Economy	20400.00
0005434757447	28672	Economy	20400.00
0005434215081	28672	Economy	20400.00
0005434757444	28672	Economy	20400.00
0005434215053	28672	Economy	20400.00
0005434757461	28672	Economy	20400.00
0005434215209	28672	Economy	20400.00
0005434215176	28672	Economy	20400.00
0005434757434	28672	Economy	20400.00
0005434215325	28672	Economy	20400.00
0005434215357	28672	Economy	20400.00
0005434757452	28672	Economy	20400.00
0005434215283	28672	Economy	20400.00
0005434215260	28672	Economy	20400.00
0005434215269	28672	Economy	20400.00
0005434215340	28672	Economy	20400.00
0005434757462	28672	Economy	20400.00
0005434215190	28672	Economy	20400.00
0005434215150	28672	Economy	20400.00
0005434757455	28672	Economy	20400.00
0005434757448	28672	Economy	20400.00
0005434757458	28672	Economy	20400.00
0005434757468	28672	Economy	20400.00
0005434215193	28672	Economy	20400.00
0005434757472	28672	Economy	20400.00
0005434215359	28672	Economy	20400.00
0005434215356	28672	Economy	20400.00
0005434215314	28672	Economy	20400.00
0005434215381	28672	Economy	20400.00
0005434215303	28672	Economy	20400.00
0005434215328	28672	Economy	20400.00
0005434757440	28672	Economy	20400.00
0005434215284	28672	Economy	20400.00
0005434757470	28672	Economy	20400.00
0005434215140	28672	Economy	20400.00
0005434215155	28672	Economy	20400.00
0005434757453	28672	Economy	20400.00
0005434757457	28672	Economy	20400.00
0005434215326	28672	Economy	20400.00
0005434215335	28672	Economy	20400.00
0005434757463	28672	Economy	20400.00
0005434757442	28672	Economy	20400.00
0005434757460	28672	Economy	20400.00
0005434215259	28672	Economy	20400.00
0005434215227	28672	Economy	20400.00
0005434215226	28672	Economy	20400.00
0005434757433	28672	Economy	20400.00
0005435007623	5443	Business	29500.00
0005432125636	5443	Business	29500.00
0005434229568	5443	Business	29500.00
0005435007621	5443	Business	29500.00
0005434229822	5443	Business	29500.00
0005435041421	5443	Business	29500.00
0005435041399	5443	Business	29500.00
0005434229740	5443	Business	29500.00
0005435007629	5443	Business	29500.00
0005435041433	5443	Business	29500.00
0005434229824	5443	Business	29500.00
0005435007615	5443	Business	29500.00
0005435007631	5443	Economy	9800.00
0005435041401	5443	Economy	9800.00
0005435041439	5443	Economy	9800.00
0005435041392	5443	Economy	9800.00
0005435041415	5443	Economy	9800.00
0005435007613	5443	Economy	9800.00
0005435007626	5443	Economy	9800.00
0005435007619	5443	Economy	9800.00
0005435041430	5443	Economy	9800.00
0005435041447	5443	Economy	9800.00
0005434229713	5443	Economy	9800.00
0005435041457	5443	Economy	9800.00
0005435041441	5443	Economy	9800.00
0005435007627	5443	Economy	9800.00
0005435041438	5443	Economy	9800.00
0005435007609	5443	Economy	9800.00
0005434229658	5443	Economy	9800.00
0005435041429	5443	Economy	9800.00
0005435041434	5443	Economy	9800.00
0005435041452	5443	Economy	9800.00
0005435041431	5443	Economy	9800.00
0005435041454	5443	Economy	9800.00
0005435041404	5443	Economy	9800.00
0005435041426	5443	Economy	9800.00
0005435041397	5443	Economy	9800.00
0005435041402	5443	Economy	9800.00
0005434229827	5443	Economy	9800.00
0005435041435	5443	Economy	9800.00
0005434229833	5443	Economy	9800.00
0005435041403	5443	Economy	9800.00
0005432125641	5443	Economy	9800.00
0005435007610	5443	Economy	9800.00
0005435041442	5443	Economy	9800.00
0005434229798	5443	Economy	9800.00
0005435007628	5443	Economy	9800.00
0005435041400	5443	Economy	9800.00
0005435041424	5443	Economy	9800.00
0005435007617	5443	Economy	9800.00
0005435007630	5443	Economy	9800.00
0005435041416	5443	Economy	9800.00
0005432125637	5443	Economy	10800.00
0005435007611	5443	Economy	10800.00
0005434229729	5443	Economy	10800.00
0005435007616	5443	Economy	10800.00
0005434229800	5443	Economy	10800.00
0005434229742	5443	Economy	10800.00
0005435041396	5443	Economy	9800.00
0005434229787	5443	Economy	9800.00
0005435041450	5443	Economy	9800.00
0005435041432	5443	Economy	9800.00
0005435042922	5443	Economy	9800.00
0005434229714	5443	Economy	9800.00
0005435041448	5443	Economy	9800.00
0005432125642	5443	Economy	9800.00
0005435007607	5443	Economy	9800.00
0005435007612	5443	Economy	9800.00
0005435041412	5443	Economy	9800.00
0005435041443	5443	Economy	9800.00
0005435041436	5443	Economy	9800.00
0005435041425	5443	Economy	9800.00
0005435041455	5443	Economy	9800.00
0005435041437	5443	Economy	9800.00
0005435007608	5443	Economy	9800.00
0005435041419	5443	Economy	9800.00
0005435041440	5443	Economy	9800.00
0005435041427	5443	Economy	9800.00
0005434229569	5443	Economy	9800.00
0005435041408	5443	Economy	9800.00
0005434229682	5443	Economy	9800.00
0005435041409	5443	Economy	9800.00
0005435041393	5443	Economy	9800.00
0005435041422	5443	Economy	9800.00
0005434229834	5443	Economy	9800.00
0005432125638	5443	Economy	9800.00
0005435041413	5443	Economy	9800.00
0005435041451	5443	Economy	9800.00
0005435041446	5443	Economy	9800.00
0005434229754	5443	Economy	9800.00
0005432125639	5443	Economy	9800.00
0005435042923	5443	Economy	9800.00
0005435041398	5443	Economy	9800.00
0005435041394	5443	Economy	9800.00
0005435041406	5443	Economy	9800.00
0005434229737	5443	Economy	9800.00
0005435007624	5443	Economy	9800.00
0005434229672	5443	Economy	9800.00
0005434229712	5443	Economy	9800.00
0005435007625	5443	Economy	9800.00
0005435041456	5443	Economy	9800.00
0005435041418	5443	Economy	9800.00
0005435041453	5443	Economy	9800.00
0005435041410	5443	Economy	9800.00
0005435007620	5443	Economy	9800.00
0005435041420	5443	Economy	9800.00
0005434229809	5443	Economy	9800.00
0005435041407	5443	Economy	9800.00
0005435041405	5443	Economy	9800.00
0005435041417	5443	Economy	9800.00
0005435007622	5443	Economy	9800.00
0005434229741	5443	Economy	9800.00
0005435041423	5443	Economy	9800.00
0005434229739	5443	Economy	9800.00
0005435007618	5443	Economy	9800.00
0005435041395	5443	Economy	9800.00
0005435041414	5443	Economy	9800.00
0005435041411	5443	Economy	9800.00
0005435041445	5443	Economy	9800.00
0005435007614	5443	Economy	9800.00
0005434229823	5443	Economy	9800.00
0005435041449	5443	Economy	9800.00
0005434229799	5443	Economy	9800.00
0005435041428	5443	Economy	9800.00
0005434229753	5443	Economy	9800.00
0005435042924	5443	Economy	9800.00
0005432125643	5443	Economy	9800.00
0005432125640	5443	Economy	9800.00
0005435041444	5443	Economy	9800.00
0005434229810	5443	Economy	9800.00
0005435040707	13004	Business	29500.00
0005434229938	13004	Business	29500.00
0005435007375	13004	Business	29500.00
0005435041041	13004	Business	29500.00
0005435040840	13004	Business	29500.00
0005435007458	13004	Business	29500.00
0005435040770	13004	Business	29500.00
0005435040896	13004	Business	29500.00
0005435007416	13004	Business	29500.00
0005435040907	13004	Business	29500.00
0005435040706	13004	Business	29500.00
0005435007443	13004	Business	29500.00
0005435040811	13004	Economy	9800.00
0005435040893	13004	Economy	9800.00
0005435040920	13004	Economy	9800.00
0005434229948	13004	Economy	9800.00
0005435040809	13004	Economy	9800.00
0005435040923	13004	Economy	9800.00
0005435041012	13004	Economy	9800.00
0005435040959	13004	Economy	9800.00
0005432304500	13004	Economy	9800.00
0005435007427	13004	Economy	9800.00
0005435007438	13004	Economy	9800.00
0005435040867	13004	Economy	9800.00
0005435041009	13004	Economy	9800.00
0005435040761	13004	Economy	9800.00
0005435040998	13004	Economy	9800.00
0005432304501	13004	Economy	9800.00
0005434229942	13004	Economy	9800.00
0005435040773	13004	Economy	9800.00
0005435007335	13004	Economy	9800.00
0005434229935	13004	Economy	9800.00
0005435007424	13004	Economy	9800.00
0005435007391	13004	Economy	9800.00
0005435007415	13004	Economy	9800.00
0005435007402	13004	Economy	9800.00
0005434229941	13004	Economy	9800.00
0005435040669	13004	Economy	9800.00
0005435040881	13004	Economy	9800.00
0005435040953	13004	Economy	9800.00
0005435007426	13004	Economy	9800.00
0005435041016	13004	Economy	9800.00
0005435040829	13004	Economy	9800.00
0005435040956	13004	Economy	9800.00
0005435040760	13004	Economy	9800.00
0005435007460	13004	Economy	9800.00
0005434229953	13004	Economy	9800.00
0005435040670	13004	Economy	9800.00
0005435007459	13004	Economy	9800.00
0005435040866	13004	Economy	9800.00
0005435040463	13004	Economy	10800.00
0005435007451	13004	Economy	10800.00
0005432304497	13004	Economy	10800.00
0005435040882	13004	Economy	10800.00
0005435041053	13004	Economy	10800.00
0005435007480	13004	Economy	10800.00
0005435040934	13004	Economy	9800.00
0005435007461	13004	Economy	9800.00
0005435041014	13004	Economy	9800.00
0005435040697	13004	Economy	9800.00
0005435007417	13004	Economy	9800.00
0005435040774	13004	Economy	9800.00
0005435040897	13004	Economy	9800.00
0005434229940	13004	Economy	9800.00
0005435041024	13004	Economy	9800.00
0005435040922	13004	Economy	9800.00
0005435040627	13004	Economy	9800.00
0005435040937	13004	Economy	9800.00
0005435041082	13004	Economy	9800.00
0005435040828	13004	Economy	9800.00
0005435041091	13004	Economy	9800.00
0005435007358	13004	Economy	9800.00
0005435040921	13004	Economy	9800.00
0005435041028	13004	Economy	9800.00
0005434229945	13004	Economy	9800.00
0005435041309	13004	Economy	9800.00
0005435040673	13004	Economy	9800.00
0005435040997	13004	Economy	9800.00
0005435040890	13004	Economy	9800.00
0005435041029	13004	Economy	9800.00
0005435040759	13004	Economy	9800.00
0005435040863	13004	Economy	9800.00
0005435040674	13004	Economy	9800.00
0005435041127	13004	Economy	9800.00
0005435040699	13004	Economy	9800.00
0005435040768	13004	Economy	9800.00
0005435040682	13004	Economy	9800.00
0005432304498	13004	Economy	9800.00
0005435040933	13004	Economy	9800.00
0005435040718	13004	Economy	9800.00
0005435007405	13004	Economy	9800.00
0005435040808	13004	Economy	9800.00
0005434229946	13004	Economy	9800.00
0005435040769	13004	Economy	9800.00
0005434229939	13004	Economy	9800.00
0005435040650	13004	Economy	9800.00
0005434229947	13004	Economy	9800.00
0005434229944	13004	Economy	9800.00
0005435007444	13004	Economy	9800.00
0005435040838	13004	Economy	9800.00
0005434229937	13004	Economy	9800.00
0005435007423	13004	Economy	9800.00
0005435007398	13004	Economy	9800.00
0005432304499	13004	Economy	9800.00
0005434229943	13004	Economy	9800.00
0005435040999	13004	Economy	9800.00
0005435007425	13004	Economy	9800.00
0005435041083	13004	Economy	9800.00
0005435040714	13004	Economy	9800.00
0005435007452	13004	Economy	9800.00
0005435040758	13004	Economy	9800.00
0005434229952	13004	Economy	9800.00
0005435040985	13004	Economy	9800.00
0005435041025	13004	Economy	9800.00
0005434229936	13004	Economy	9800.00
0005435040839	13004	Economy	9800.00
0005435040713	13004	Economy	9800.00
0005434229951	13004	Economy	9800.00
0005434229949	13004	Economy	9800.00
0005435007403	13004	Economy	9800.00
0005435040908	13004	Economy	9800.00
0005435040698	13004	Economy	9800.00
0005434229950	13004	Economy	9800.00
0005435040846	13004	Economy	9800.00
0005434229954	13004	Economy	9800.00
0005435040717	13004	Economy	9800.00
0005434427334	14872	Business	52900.00
0005434427345	14872	Business	52900.00
0005434427330	14872	Business	52900.00
0005434427335	14872	Business	52900.00
0005435903024	14872	Business	52900.00
0005435554264	14872	Business	52900.00
0005435902925	14872	Business	52900.00
0005435902898	14872	Economy	17600.00
0005432188688	14872	Economy	17600.00
0005434427336	14872	Economy	17600.00
0005435902927	14872	Economy	17600.00
0005434427331	14872	Economy	17600.00
0005434427338	14872	Economy	19400.00
0005435903066	14872	Economy	17600.00
0005434427341	14872	Economy	17600.00
0005435554260	14872	Economy	17600.00
0005435903012	14872	Economy	17600.00
0005434427326	14872	Economy	17600.00
0005434427342	14872	Economy	17600.00
0005434427332	14872	Economy	17600.00
0005435554263	14872	Economy	17600.00
0005435903023	14872	Economy	17600.00
0005434427333	14872	Economy	17600.00
0005434427344	14872	Economy	17600.00
0005434427339	14872	Economy	17600.00
0005435902988	14872	Economy	17600.00
0005435902975	14872	Economy	17600.00
0005434427340	14872	Economy	17600.00
0005434427323	14872	Economy	17600.00
0005434427322	14872	Economy	17600.00
0005435902973	14872	Economy	17600.00
0005435903016	14872	Economy	17600.00
0005434427321	14872	Economy	17600.00
0005434427320	14872	Economy	17600.00
0005434427325	14872	Economy	17600.00
0005434411883	14872	Economy	17600.00
0005435902981	14872	Economy	17600.00
0005434411885	14872	Economy	17600.00
0005434411886	14872	Economy	17600.00
0005434427337	14872	Economy	17600.00
0005434411882	14872	Economy	17600.00
0005434427343	14872	Economy	17600.00
0005435902978	14872	Economy	17600.00
0005434427324	14872	Economy	17600.00
0005435902977	14872	Economy	17600.00
0005435554256	14872	Economy	17600.00
0005435902980	14872	Economy	17600.00
0005435902976	14872	Economy	17600.00
0005432188689	14872	Economy	17600.00
0005435902957	14872	Economy	17600.00
0005434427329	14872	Economy	17600.00
0005434427327	14872	Economy	17600.00
0005434427328	14872	Economy	17600.00
0005435903060	14872	Economy	17600.00
0005434411884	14872	Economy	17600.00
0005434411857	20197	Business	52900.00
0005434427031	20197	Business	52900.00
0005435903152	20197	Business	52900.00
0005435903157	20197	Business	52900.00
0005434427175	20197	Business	52900.00
0005434411859	20197	Business	52900.00
0005434427206	20197	Economy	17600.00
0005434427064	20197	Economy	17600.00
0005434426952	20197	Economy	17600.00
0005434427142	20197	Economy	17600.00
0005435903156	20197	Economy	17600.00
0005434427106	20197	Economy	17600.00
0005435903160	20197	Economy	17600.00
0005434411856	20197	Economy	19400.00
0005435903155	20197	Economy	19400.00
0005435903162	20197	Economy	19400.00
0005435903154	20197	Economy	17600.00
0005435903151	20197	Economy	17600.00
0005435554310	20197	Economy	17600.00
0005434427065	20197	Economy	17600.00
0005434427139	20197	Economy	17600.00
0005434427188	20197	Economy	17600.00
0005434427033	20197	Economy	17600.00
0005435903158	20197	Economy	17600.00
0005435554312	20197	Economy	17600.00
0005434427181	20197	Economy	17600.00
0005434427104	20197	Economy	17600.00
0005434427179	20197	Economy	17600.00
0005434427207	20197	Economy	17600.00
0005435554311	20197	Economy	17600.00
0005435903150	20197	Economy	17600.00
0005434427103	20197	Economy	17600.00
0005434427189	20197	Economy	17600.00
0005434427153	20197	Economy	17600.00
0005435903161	20197	Economy	17600.00
0005435903149	20197	Economy	17600.00
0005432059556	20197	Economy	17600.00
0005434427176	20197	Economy	17600.00
0005434427032	20197	Economy	17600.00
0005435554313	20197	Economy	17600.00
0005434427143	20197	Economy	17600.00
0005434427105	20197	Economy	17600.00
0005435903163	20197	Economy	17600.00
0005435903153	20197	Economy	17600.00
0005435903165	20197	Economy	17600.00
0005434427182	20197	Economy	17600.00
0005435903148	20197	Economy	17600.00
0005435903159	20197	Economy	17600.00
0005435903164	20197	Economy	17600.00
0005435983444	26539	Business	18500.00
0005435983436	26539	Business	18500.00
0005433435112	26539	Business	18500.00
0005433435113	26539	Business	18500.00
0005433435178	26539	Business	18500.00
0005435983397	26539	Business	18500.00
0005435983422	26539	Business	18500.00
0005435983432	26539	Business	18500.00
0005433435182	26539	Business	18500.00
0005435983414	26539	Business	18500.00
0005432300411	26539	Economy	6200.00
0005435983434	26539	Economy	6200.00
0005435983445	26539	Economy	6200.00
0005432300406	26539	Economy	6200.00
0005432300405	26539	Economy	6200.00
0005435983441	26539	Economy	6200.00
0005433435227	26539	Economy	6200.00
0005433435174	26539	Economy	6200.00
0005433435095	26539	Economy	6200.00
0005432300408	26539	Economy	6200.00
0005435983416	26539	Economy	6800.00
0005435983402	26539	Economy	6800.00
0005435983424	26539	Economy	6800.00
0005433435161	26539	Economy	6800.00
0005434270238	26539	Economy	6800.00
0005435983411	26539	Economy	6200.00
0005435983428	26539	Economy	6200.00
0005435983405	26539	Economy	6200.00
0005435983443	26539	Economy	6200.00
0005435983426	26539	Economy	6200.00
0005435983400	26539	Economy	6200.00
0005433435160	26539	Economy	6200.00
0005432300409	26539	Economy	6200.00
0005435983438	26539	Economy	6200.00
0005435983413	26539	Economy	6200.00
0005433435195	26539	Economy	6200.00
0005435983448	26539	Economy	6200.00
0005435983437	26539	Economy	6200.00
0005435983399	26539	Economy	6200.00
0005435983417	26539	Economy	6200.00
0005435983408	26539	Economy	6200.00
0005435983403	26539	Economy	6200.00
0005435983420	26539	Economy	6200.00
0005435983446	26539	Economy	6200.00
0005435983435	26539	Economy	6200.00
0005435983406	26539	Economy	6200.00
0005435983398	26539	Economy	6200.00
0005433435194	26539	Economy	6200.00
0005435983442	26539	Economy	6200.00
0005433435118	26539	Economy	6200.00
0005433435177	26539	Economy	6200.00
0005433435187	26539	Economy	6200.00
0005433435074	26539	Economy	6200.00
0005435983429	26539	Economy	6200.00
0005435983410	26539	Economy	6200.00
0005435983425	26539	Economy	6200.00
0005435983423	26539	Economy	6200.00
0005433435122	26539	Economy	6200.00
0005433435105	26539	Economy	6200.00
0005435983440	26539	Economy	6200.00
0005433435159	26539	Economy	6200.00
0005435983415	26539	Economy	6200.00
0005435983412	26539	Economy	6200.00
0005435983404	26539	Economy	6200.00
0005433435186	26539	Economy	6200.00
0005433435096	26539	Economy	6200.00
0005433435106	26539	Economy	6200.00
0005435983418	26539	Economy	6200.00
0005433434997	26539	Economy	6200.00
0005433435065	26539	Economy	6200.00
0005435983427	26539	Economy	6200.00
0005435983439	26539	Economy	6200.00
0005433435203	26539	Economy	6200.00
0005435983421	26539	Economy	6200.00
0005433435064	26539	Economy	6200.00
0005433434998	26539	Economy	6200.00
0005432300407	26539	Economy	6200.00
0005433435158	26539	Economy	6200.00
0005435983430	26539	Economy	6200.00
0005435983447	26539	Economy	6200.00
0005435983407	26539	Economy	6200.00
0005435983409	26539	Economy	6200.00
0005435983401	26539	Economy	6200.00
0005435983419	26539	Economy	6200.00
0005433435087	26539	Economy	6200.00
0005435983433	26539	Economy	6200.00
0005435983431	26539	Economy	6200.00
0005432300410	26539	Economy	6200.00
0005433435181	26539	Economy	6200.00
0005435982851	26704	Business	18500.00
0005435983094	26704	Business	18500.00
0005435983146	26704	Business	18500.00
0005435982909	26704	Business	18500.00
0005435983191	26704	Business	18500.00
0005435983093	26704	Business	18500.00
0005435983161	26704	Business	18500.00
0005433435404	26704	Business	18500.00
0005433435384	26704	Business	18500.00
0005434270260	26704	Business	18500.00
0005433435396	26704	Business	18500.00
0005433435393	26704	Economy	6200.00
0005435983051	26704	Economy	6200.00
0005435983074	26704	Economy	6200.00
0005433435392	26704	Economy	6200.00
0005435983066	26704	Economy	6200.00
0005433435405	26704	Economy	6200.00
0005433435387	26704	Economy	6200.00
0005435983026	26704	Economy	6200.00
0005435983006	26704	Economy	6200.00
0005433435400	26704	Economy	6200.00
0005435983041	26704	Economy	6800.00
0005435982880	26704	Economy	6800.00
0005435983131	26704	Economy	6800.00
0005435983022	26704	Economy	6800.00
0005435983140	26704	Economy	6200.00
0005433435394	26704	Economy	6200.00
0005435982791	26704	Economy	6200.00
0005435982963	26704	Economy	6200.00
0005433435402	26704	Economy	6200.00
0005435982887	26704	Economy	6200.00
0005435982970	26704	Economy	6200.00
0005433435391	26704	Economy	6200.00
0005435982922	26704	Economy	6200.00
0005435983023	26704	Economy	6200.00
0005435982654	26704	Economy	6200.00
0005434271366	26704	Economy	6200.00
0005435983037	26704	Economy	6200.00
0005435982971	26704	Economy	6200.00
0005435983032	26704	Economy	6200.00
0005435982910	26704	Economy	6200.00
0005433435397	26704	Economy	6200.00
0005435983139	26704	Economy	6200.00
0005435983044	26704	Economy	6200.00
0005435983048	26704	Economy	6200.00
0005435983029	26704	Economy	6200.00
0005435983126	26704	Economy	6200.00
0005432051208	26704	Economy	6200.00
0005435983027	26704	Economy	6200.00
0005434269156	26704	Economy	6200.00
0005433435406	26704	Economy	6200.00
0005435983028	26704	Economy	6200.00
0005433435408	26704	Economy	6200.00
0005433435389	26704	Economy	6200.00
0005435982859	26704	Economy	6200.00
0005433435390	26704	Economy	6200.00
0005433435398	26704	Economy	6200.00
0005435983073	26704	Economy	6200.00
0005435983132	26704	Economy	6200.00
0005435982975	26704	Economy	6200.00
0005435983046	26704	Economy	6200.00
0005433435386	26704	Economy	6200.00
0005433435401	26704	Economy	6200.00
0005433435388	26704	Economy	6200.00
0005435982935	26704	Economy	6200.00
0005433435385	26704	Economy	6200.00
0005435982888	26704	Economy	6200.00
0005435983102	26704	Economy	6200.00
0005435983071	26704	Economy	6200.00
0005432051209	26704	Economy	6200.00
0005435982844	26704	Economy	6200.00
0005435983075	26704	Economy	6200.00
0005434271367	26704	Economy	6200.00
0005435983030	26704	Economy	6200.00
0005433435407	26704	Economy	6200.00
0005435983053	26704	Economy	6200.00
0005434270261	26704	Economy	6200.00
0005433435399	26704	Economy	6200.00
0005435983141	26704	Economy	6200.00
0005432051207	26704	Economy	6200.00
0005433435395	26704	Economy	6200.00
0005433435383	26704	Economy	6200.00
0005435983045	26704	Economy	6200.00
0005435983092	26704	Economy	6200.00
0005435983108	26704	Economy	6200.00
0005434271365	26704	Economy	6200.00
0005435983052	26704	Economy	6200.00
0005435983040	26704	Economy	6200.00
0005433435403	26704	Economy	6200.00
0005435982893	26704	Economy	6200.00
0005433687753	19514	Economy	21000.00
0005433687755	19514	Economy	21000.00
0005433686690	19514	Economy	21000.00
0005433685578	19514	Economy	21000.00
0005433687762	19514	Economy	19100.00
0005433685579	19514	Economy	19100.00
0005433686679	19514	Economy	19100.00
0005433687748	19514	Economy	19100.00
0005433687758	19514	Economy	19100.00
0005433685569	19514	Economy	19100.00
0005433686692	19514	Economy	19100.00
0005433687760	19514	Economy	19100.00
0005433685570	19514	Economy	19100.00
0005433685568	19514	Economy	19100.00
0005433685574	19514	Economy	19100.00
0005433687761	19514	Economy	19100.00
0005433687749	19514	Economy	19100.00
0005433686684	19514	Economy	19100.00
0005433685572	19514	Economy	19100.00
0005433687759	19514	Economy	19100.00
0005433685571	19514	Economy	19100.00
0005433685573	19514	Economy	19100.00
0005433685577	19514	Economy	19100.00
0005433687756	19514	Economy	19100.00
0005433685566	19514	Economy	19100.00
0005433686682	19514	Economy	19100.00
0005433685575	19514	Economy	19100.00
0005433686688	19514	Economy	19100.00
0005433685567	19514	Economy	19100.00
0005433686685	19514	Economy	19100.00
0005433687754	19514	Economy	19100.00
0005433687757	19514	Economy	19100.00
0005433686681	19514	Economy	19100.00
0005433686687	19514	Economy	19100.00
0005433686689	19514	Economy	19100.00
0005433686691	19514	Economy	19100.00
0005433685576	19514	Economy	19100.00
0005433686683	19514	Economy	19100.00
0005433685580	19514	Economy	19100.00
0005433686686	19514	Economy	19100.00
0005433687750	19514	Economy	19100.00
0005433687751	19514	Economy	19100.00
0005433686678	19514	Economy	19100.00
0005433687752	19514	Economy	19100.00
0005433686680	19514	Economy	19100.00
0005432584678	3169	Economy	11100.00
0005432858290	3169	Economy	11100.00
0005432584680	3169	Economy	10100.00
0005432584682	3169	Economy	10100.00
0005432858264	3169	Economy	10100.00
0005432584687	3169	Economy	10100.00
0005432584686	3169	Economy	10100.00
0005432858253	3169	Economy	10100.00
0005432584668	3169	Economy	10100.00
0005432584674	3169	Economy	10100.00
0005432858231	3169	Economy	10100.00
0005432858225	3169	Economy	10100.00
0005432584667	3169	Economy	10100.00
0005432858299	3169	Economy	10100.00
0005432584683	3169	Economy	10100.00
0005432858289	3169	Economy	10100.00
0005432584669	3169	Economy	10100.00
0005432858227	3169	Economy	10100.00
0005432584676	3169	Economy	10100.00
0005432216342	3169	Economy	10100.00
0005432584672	3169	Economy	10100.00
0005432584671	3169	Economy	10100.00
0005432584673	3169	Economy	10100.00
0005432584681	3169	Economy	10100.00
0005432584679	3169	Economy	10100.00
0005432858272	3169	Economy	10100.00
0005432584685	3169	Economy	10100.00
0005432584677	3169	Economy	10100.00
0005432584684	3169	Economy	10100.00
0005432584670	3169	Economy	10100.00
0005432858226	3169	Economy	10100.00
0005432584688	3169	Economy	10100.00
0005432584675	3169	Economy	10100.00
0005432858318	3169	Economy	10100.00
0005432584481	31505	Economy	11100.00
0005432584488	31505	Economy	11100.00
0005432858368	31505	Economy	11100.00
0005432584425	31505	Economy	11100.00
0005432858367	31505	Economy	10100.00
0005432584549	31505	Economy	10100.00
0005432584459	31505	Economy	10100.00
0005432858370	31505	Economy	10100.00
0005432584523	31505	Economy	10100.00
0005432858369	31505	Economy	10100.00
0005432584463	31505	Economy	10100.00
0005432858375	31505	Economy	10100.00
0005432584472	31505	Economy	10100.00
0005432584424	31505	Economy	10100.00
0005432584495	31505	Economy	10100.00
0005432584406	31505	Economy	10100.00
0005432584468	31505	Economy	10100.00
0005432584460	31505	Economy	10100.00
0005432584506	31505	Economy	10100.00
0005432584436	31505	Economy	10100.00
0005432584393	31505	Economy	10100.00
0005432584528	31505	Economy	10100.00
0005432584596	31505	Economy	10100.00
0005432584473	31505	Economy	10100.00
0005432584422	31505	Economy	10100.00
0005432858372	31505	Economy	10100.00
0005432584471	31505	Economy	10100.00
0005432858374	31505	Economy	10100.00
0005432584524	31505	Economy	10100.00
0005432584444	31505	Economy	10100.00
0005432858371	31505	Economy	10100.00
0005432584394	31505	Economy	10100.00
0005432584507	31505	Economy	10100.00
0005432584539	31505	Economy	10100.00
0005432858373	31505	Economy	10100.00
0005432858366	31505	Economy	10100.00
0005432584435	31505	Economy	10100.00
0005432584469	31505	Economy	10100.00
0005432584409	31505	Economy	10100.00
0005434943584	872	Economy	7500.00
0005434943590	872	Economy	7500.00
0005434943591	872	Economy	7500.00
0005433255221	872	Economy	7500.00
0005434943592	872	Economy	7500.00
0005433255197	872	Economy	7500.00
0005434943589	872	Economy	7500.00
0005434943587	872	Economy	7500.00
0005434943583	872	Economy	7500.00
0005433255196	872	Economy	7500.00
0005434943588	872	Economy	7500.00
0005434943585	872	Economy	7500.00
0005434943586	872	Economy	7500.00
0005433255259	16193	Economy	8300.00
0005434943564	16193	Economy	7500.00
0005434943537	16193	Economy	7500.00
0005434943475	16193	Economy	7500.00
0005434943563	16193	Economy	7500.00
0005433255257	16193	Economy	7500.00
0005434943551	16193	Economy	7500.00
0005434943541	16193	Economy	7500.00
0005434943509	16193	Economy	7500.00
0005434943513	16193	Economy	7500.00
0005434943527	16193	Economy	7500.00
0005434943516	16193	Economy	7500.00
0005433255258	16193	Economy	7500.00
0005434943522	16193	Economy	7500.00
0005435858627	4333	Business	90500.00
0005433654963	4333	Business	90500.00
0005435858612	4333	Business	90500.00
0005433654957	4333	Business	90500.00
0005433654966	4333	Business	90500.00
0005433654955	4333	Business	90500.00
0005433654958	4333	Business	90500.00
0005433654965	4333	Economy	30200.00
0005435858634	4333	Economy	30200.00
0005433654952	4333	Economy	30200.00
0005435858623	4333	Economy	30200.00
0005433654968	4333	Economy	30200.00
0005435858609	4333	Economy	30200.00
0005435858622	4333	Economy	30200.00
0005435858639	4333	Economy	30200.00
0005433654953	4333	Economy	30200.00
0005433654954	4333	Economy	30200.00
0005433654950	4333	Economy	30200.00
0005435858616	4333	Economy	30200.00
0005435858625	4333	Economy	30200.00
0005435858628	4333	Economy	30200.00
0005435858635	4333	Economy	30200.00
0005433654967	4333	Economy	30200.00
0005435858600	4333	Economy	30200.00
0005433654964	4333	Economy	30200.00
0005433654960	4333	Economy	30200.00
0005433654961	4333	Economy	30200.00
0005433654956	4333	Economy	30200.00
0005433654962	4333	Economy	30200.00
0005433654948	4333	Economy	30200.00
0005433654951	4333	Economy	30200.00
0005433654949	4333	Economy	30200.00
0005433654959	4333	Economy	30200.00
0005433927531	14420	Economy	4400.00
0005433811663	14420	Economy	4400.00
0005433811669	27901	Economy	4400.00
0005433811679	27901	Economy	4400.00
0005433811676	27901	Economy	4400.00
0005433811672	27901	Economy	4400.00
0005433811678	27901	Economy	4400.00
0005433811673	27901	Economy	4400.00
0005433811677	27901	Economy	4400.00
0005433811671	27901	Economy	4400.00
0005433811675	27901	Economy	4400.00
0005433811674	27901	Economy	4400.00
0005433811670	27901	Economy	4400.00
0005433368384	21779	Business	9800.00
0005433368316	21779	Business	9800.00
0005435654198	21779	Business	9800.00
0005435654171	21779	Business	9800.00
0005433368393	21779	Business	9800.00
0005435654184	21779	Business	9800.00
0005433368435	21779	Business	9800.00
0005435654189	21779	Business	9800.00
0005435654205	21779	Business	9800.00
0005435654169	21779	Business	9800.00
0005435654181	21779	Business	9800.00
0005435654173	21779	Economy	3300.00
0005433368434	21779	Economy	3300.00
0005435654194	21779	Economy	3300.00
0005435654167	21779	Economy	3300.00
0005435654162	21779	Economy	3300.00
0005435654187	21779	Economy	3300.00
0005435654159	21779	Economy	3300.00
0005435654165	21779	Economy	3300.00
0005435654166	21779	Economy	3300.00
0005435654172	21779	Economy	3300.00
0005435654180	21779	Economy	3600.00
0005435654197	21779	Economy	3600.00
0005433368591	21779	Economy	3600.00
0005433368464	21779	Economy	3600.00
0005433368491	21779	Economy	3600.00
0005435654188	21779	Economy	3300.00
0005435654160	21779	Economy	3300.00
0005433368355	21779	Economy	3300.00
0005433368382	21779	Economy	3300.00
0005435654175	21779	Economy	3300.00
0005435654204	21779	Economy	3300.00
0005435654203	21779	Economy	3300.00
0005435654168	21779	Economy	3300.00
0005433368497	21779	Economy	3300.00
0005435654186	21779	Economy	3300.00
0005435654161	21779	Economy	3300.00
0005433368547	21779	Economy	3300.00
0005433368545	21779	Economy	3300.00
0005433368664	21779	Economy	3300.00
0005433368546	21779	Economy	3300.00
0005433368456	21779	Economy	3300.00
0005435654174	21779	Economy	3300.00
0005433368361	21779	Economy	3300.00
0005433368692	21779	Economy	3300.00
0005433368489	21779	Economy	3300.00
0005433368557	21779	Economy	3300.00
0005435654190	21779	Economy	3300.00
0005433368469	21779	Economy	3300.00
0005433368582	21779	Economy	3300.00
0005433368465	21779	Economy	3300.00
0005433368486	21779	Economy	3300.00
0005435654182	21779	Economy	3300.00
0005433368592	21779	Economy	3300.00
0005433368383	21779	Economy	3300.00
0005433368500	21779	Economy	3300.00
0005433368454	21779	Economy	3300.00
0005433368381	21779	Economy	3300.00
0005435654192	21779	Economy	3300.00
0005433368554	21779	Economy	3300.00
0005435654200	21779	Economy	3300.00
0005433368455	21779	Economy	3300.00
0005435654191	21779	Economy	3300.00
0005435654176	21779	Economy	3300.00
0005435654177	21779	Economy	3300.00
0005435654178	21779	Economy	3300.00
0005433368413	21779	Economy	3300.00
0005435654193	21779	Economy	3300.00
0005433368474	21779	Economy	3300.00
0005435654196	21779	Economy	3300.00
0005435654183	21779	Economy	3300.00
0005435654163	21779	Economy	3300.00
0005435654170	21779	Economy	3300.00
0005435654195	21779	Economy	3300.00
0005435654164	21779	Economy	3300.00
0005433368529	21779	Economy	3300.00
0005435654201	21779	Economy	3300.00
0005435654202	21779	Economy	3300.00
0005433368484	21779	Economy	3300.00
0005435654199	21779	Economy	3300.00
0005433368674	21779	Economy	3300.00
0005433368485	21779	Economy	3300.00
0005433368673	21779	Economy	3300.00
0005435654185	21779	Economy	3300.00
0005433368504	21779	Economy	3300.00
0005433368473	21779	Economy	3300.00
0005433368605	21779	Economy	3300.00
0005433368585	21779	Economy	3300.00
0005433368505	21779	Economy	3300.00
0005433368490	21779	Economy	3300.00
0005435654179	21779	Economy	3300.00
0005433368693	21779	Economy	3300.00
0005433763575	9351	Business	186200.00
0005435269846	9351	Business	186200.00
0005433785877	9351	Business	186200.00
0005433785868	9351	Business	186200.00
0005434171333	9351	Business	186200.00
0005434171297	9351	Business	186200.00
0005432666441	9351	Business	186200.00
0005433763580	9351	Business	186200.00
0005433763579	9351	Business	186200.00
0005433806271	9351	Business	186200.00
0005433806259	9351	Business	186200.00
0005432657529	9351	Business	186200.00
0005433806268	9351	Business	186200.00
0005433785903	9351	Business	186200.00
0005434171312	9351	Business	186200.00
0005433785873	9351	Business	186200.00
0005435269854	9351	Business	186200.00
0005433806270	9351	Business	186200.00
0005433785872	9351	Business	186200.00
0005433806277	9351	Business	186200.00
0005432667508	9351	Business	186200.00
0005433785869	9351	Economy	68300.00
0005433806284	9351	Economy	68300.00
0005433785880	9351	Economy	68300.00
0005434171298	9351	Economy	68300.00
0005433785894	9351	Economy	62100.00
0005434171345	9351	Economy	62100.00
0005435269847	9351	Economy	62100.00
0005433785861	9351	Economy	62100.00
0005433785874	9351	Economy	62100.00
0005433806265	9351	Economy	62100.00
0005433785901	9351	Economy	62100.00
0005433763583	9351	Economy	62100.00
0005433763582	9351	Economy	62100.00
0005435269851	9351	Economy	62100.00
0005433806256	9351	Economy	62100.00
0005433806249	9351	Economy	62100.00
0005433785875	9351	Economy	62100.00
0005433806258	9351	Economy	62100.00
0005433785862	9351	Economy	62100.00
0005433806267	9351	Economy	62100.00
0005434171336	9351	Economy	62100.00
0005433763573	9351	Economy	62100.00
0005433785913	9351	Economy	62100.00
0005434171311	9351	Economy	62100.00
0005433806252	9351	Economy	62100.00
0005434171223	9351	Economy	62100.00
0005433785892	9351	Economy	62100.00
0005433785898	9351	Economy	62100.00
0005433806285	9351	Economy	62100.00
0005433785863	9351	Economy	62100.00
0005433806250	9351	Economy	62100.00
0005433806248	9351	Economy	62100.00
0005433806253	9351	Economy	62100.00
0005433785870	9351	Economy	62100.00
0005432657527	9351	Economy	62100.00
0005433806281	9351	Economy	62100.00
0005434151758	9351	Economy	62100.00
0005433763576	9351	Economy	62100.00
0005433806257	9351	Economy	62100.00
0005434273107	9351	Economy	62100.00
0005434171335	9351	Economy	62100.00
0005433785883	9351	Economy	62100.00
0005433785889	9351	Economy	62100.00
0005433806266	9351	Economy	62100.00
0005433785876	9351	Economy	62100.00
0005433785914	9351	Economy	62100.00
0005433763581	9351	Economy	62100.00
0005433806282	9351	Economy	62100.00
0005433806261	9351	Economy	62100.00
0005433806251	9351	Economy	62100.00
0005433785905	9351	Economy	62100.00
0005433785890	9351	Economy	62100.00
0005433785911	9351	Economy	62100.00
0005435269855	9351	Economy	62100.00
0005433806278	9351	Economy	62100.00
0005434273106	9351	Economy	62100.00
0005433806273	9351	Economy	62100.00
0005433763574	9351	Economy	62100.00
0005433785886	9351	Economy	62100.00
0005433785888	9351	Economy	62100.00
0005433806274	9351	Economy	62100.00
0005433806260	9351	Economy	62100.00
0005433806279	9351	Economy	62100.00
0005433785882	9351	Economy	62100.00
0005433785895	9351	Economy	62100.00
0005433763571	9351	Economy	62100.00
0005433785902	9351	Economy	62100.00
0005434171347	9351	Economy	62100.00
0005434151759	9351	Economy	62100.00
0005433806263	9351	Economy	68300.00
0005433806272	9351	Economy	68300.00
0005433763584	9351	Economy	62100.00
0005433806283	9351	Economy	62100.00
0005433806275	9351	Economy	62100.00
0005433785864	9351	Economy	68300.00
0005433785910	9351	Economy	62100.00
0005433785907	9351	Economy	62100.00
0005433806276	9351	Economy	62100.00
0005433785866	9351	Economy	62100.00
0005433806262	9351	Economy	62100.00
0005433785860	9351	Economy	62100.00
0005433785867	9351	Economy	62100.00
0005433806280	9351	Economy	62100.00
0005433785887	9351	Economy	62100.00
0005433763569	9351	Economy	62100.00
0005433785891	9351	Economy	62100.00
0005433785881	9351	Economy	62100.00
0005433806255	9351	Economy	62100.00
0005433763578	9351	Economy	62100.00
0005433785908	9351	Economy	62100.00
0005433785912	9351	Economy	62100.00
0005433806269	9351	Economy	62100.00
0005433806247	9351	Economy	62100.00
0005434273101	9351	Economy	62100.00
0005434151760	9351	Economy	62100.00
0005433785865	9351	Economy	62100.00
0005435269849	9351	Economy	62100.00
0005433763577	9351	Economy	62100.00
0005433785900	9351	Economy	62100.00
0005432665327	9351	Economy	62100.00
0005433785904	9351	Economy	62100.00
0005434171334	9351	Economy	62100.00
0005433763570	9351	Economy	62100.00
0005433785871	9351	Economy	62100.00
0005434171332	9351	Economy	62100.00
0005433785896	9351	Economy	62100.00
0005433806264	9351	Economy	62100.00
0005433785899	9351	Economy	62100.00
0005433785897	9351	Economy	62100.00
0005433785885	9351	Economy	62100.00
0005433785884	9351	Economy	62100.00
0005433763572	9351	Economy	62100.00
0005433806254	9351	Economy	62100.00
0005433785906	9351	Economy	62100.00
0005433785909	9351	Economy	62100.00
0005434171338	9351	Economy	62100.00
0005433785893	9351	Economy	62100.00
0005432657528	9351	Economy	62100.00
0005433785879	9351	Economy	62100.00
0005434151757	9351	Economy	62100.00
0005434171363	9351	Economy	62100.00
0005435269848	9351	Economy	62100.00
0005433785878	9351	Economy	62100.00
0005433785457	26236	Business	186200.00
0005435270076	26236	Business	186200.00
0005433806066	26236	Business	186200.00
0005433805943	26236	Business	186200.00
0005433806016	26236	Business	186200.00
0005433806003	26236	Business	186200.00
0005433785415	26236	Business	186200.00
0005434171421	26236	Business	186200.00
0005435270084	26236	Business	186200.00
0005434171425	26236	Business	186200.00
0005435270078	26236	Business	186200.00
0005435270082	26236	Business	186200.00
0005433763446	26236	Business	186200.00
0005433785533	26236	Business	186200.00
0005434270259	26236	Business	186200.00
0005433763458	26236	Business	186200.00
0005433785619	26236	Business	186200.00
0005435270085	26236	Economy	68300.00
0005433805950	26236	Economy	68300.00
0005433785643	26236	Economy	68300.00
0005434171427	26236	Economy	62100.00
0005433785474	26236	Economy	62100.00
0005434171422	26236	Economy	62100.00
0005435270087	26236	Economy	62100.00
0005433785542	26236	Economy	62100.00
0005433763494	26236	Economy	62100.00
0005433805794	26236	Economy	62100.00
0005433763460	26236	Economy	62100.00
0005433785400	26236	Economy	62100.00
0005434171416	26236	Economy	62100.00
0005433805949	26236	Economy	62100.00
0005432657503	26236	Economy	62100.00
0005433763493	26236	Economy	62100.00
0005433785592	26236	Economy	62100.00
0005432663069	26236	Economy	62100.00
0005433763490	26236	Economy	62100.00
0005433785398	26236	Economy	62100.00
0005432663060	26236	Economy	62100.00
0005433785699	26236	Economy	62100.00
0005433763478	26236	Economy	62100.00
0005433785609	26236	Economy	62100.00
0005432666425	26236	Economy	62100.00
0005434271362	26236	Economy	62100.00
0005434269154	26236	Economy	62100.00
0005434171419	26236	Economy	62100.00
0005433785399	26236	Economy	62100.00
0005435270081	26236	Economy	62100.00
0005433785606	26236	Economy	62100.00
0005435270083	26236	Economy	62100.00
0005433806065	26236	Economy	62100.00
0005433785463	26236	Economy	62100.00
0005433805901	26236	Economy	62100.00
0005435270062	26236	Economy	62100.00
0005433763450	26236	Economy	62100.00
0005432657505	26236	Economy	62100.00
0005433785654	26236	Economy	62100.00
0005435270074	26236	Economy	62100.00
0005433763481	26236	Economy	62100.00
0005435270072	26236	Economy	62100.00
0005435270080	26236	Economy	62100.00
0005433805848	26236	Economy	62100.00
0005433805953	26236	Economy	62100.00
0005435270073	26236	Economy	62100.00
0005433785504	26236	Economy	62100.00
0005435270069	26236	Economy	62100.00
0005433763442	26236	Economy	62100.00
0005433763459	26236	Economy	62100.00
0005433763448	26236	Economy	62100.00
0005433805795	26236	Economy	62100.00
0005434171420	26236	Economy	62100.00
0005434269155	26236	Economy	62100.00
0005435270067	26236	Economy	62100.00
0005433785557	26236	Economy	62100.00
0005433806002	26236	Economy	62100.00
0005434171418	26236	Economy	62100.00
0005433785560	26236	Economy	62100.00
0005435270075	26236	Economy	62100.00
0005433763436	26236	Economy	62100.00
0005433785467	26236	Economy	62100.00
0005434171414	26236	Economy	62100.00
0005433785644	26236	Economy	62100.00
0005433805973	26236	Economy	62100.00
0005435270060	26236	Economy	62100.00
0005435270070	26236	Economy	62100.00
0005433785531	26236	Economy	68300.00
0005434271364	26236	Economy	62100.00
0005434171417	26236	Economy	62100.00
0005433763455	26236	Economy	68300.00
0005434271363	26236	Economy	62100.00
0005433763465	26236	Economy	68300.00
0005433806082	26236	Economy	62100.00
0005433805758	26236	Economy	62100.00
0005433785695	26236	Economy	62100.00
0005433806038	26236	Economy	62100.00
0005433763435	26236	Economy	62100.00
0005435270061	26236	Economy	62100.00
0005433806017	26236	Economy	62100.00
0005433785488	26236	Economy	62100.00
0005433806018	26236	Economy	62100.00
0005433805952	26236	Economy	62100.00
0005433785694	26236	Economy	62100.00
0005435270066	26236	Economy	62100.00
0005432663070	26236	Economy	62100.00
0005434171423	26236	Economy	62100.00
0005433785543	26236	Economy	62100.00
0005435270065	26236	Economy	62100.00
0005433785532	26236	Economy	62100.00
0005435270086	26236	Economy	62100.00
0005433806052	26236	Economy	62100.00
0005433785655	26236	Economy	62100.00
0005432657504	26236	Economy	62100.00
0005433785586	26236	Economy	62100.00
0005433785454	26236	Economy	62100.00
0005435270064	26236	Economy	62100.00
0005434171424	26236	Economy	62100.00
0005433763449	26236	Economy	62100.00
0005433785458	26236	Economy	62100.00
0005433785660	26236	Economy	62100.00
0005434270258	26236	Economy	62100.00
0005433805860	26236	Economy	62100.00
0005433785718	26236	Economy	62100.00
0005432666426	26236	Economy	62100.00
0005433785610	26236	Economy	62100.00
0005434171415	26236	Economy	62100.00
0005433805957	26236	Economy	62100.00
0005433785491	26236	Economy	62100.00
0005433785587	26236	Economy	62100.00
0005433806029	26236	Economy	62100.00
0005435270071	26236	Economy	62100.00
0005433785591	26236	Economy	62100.00
0005435270068	26236	Economy	62100.00
0005433805759	26236	Economy	62100.00
0005433785510	26236	Economy	62100.00
0005432666424	26236	Economy	62100.00
0005433763477	26236	Economy	62100.00
0005435270077	26236	Economy	62100.00
0005433785593	26236	Economy	62100.00
0005434171426	26236	Economy	62100.00
0005433805861	26236	Economy	62100.00
0005433785460	26236	Economy	62100.00
0005435270079	26236	Economy	62100.00
0005435270063	26236	Economy	62100.00
0005433805948	26236	Economy	62100.00
0005435929685	4917	Economy	5900.00
0005435135796	4917	Economy	5300.00
0005435135794	4917	Economy	5300.00
0005435135793	4917	Economy	5300.00
0005435135795	4917	Economy	5300.00
0005435135792	4917	Economy	5300.00
0005435929715	33027	Economy	5900.00
0005435135766	33027	Economy	5300.00
0005435135764	33027	Economy	5300.00
0005435929713	33027	Economy	5300.00
0005435135745	33027	Economy	5300.00
0005435135744	33027	Economy	5300.00
0005435929714	33027	Economy	5300.00
0005435135754	33027	Economy	5300.00
0005434218030	9507	Economy	19700.00
0005434983420	9507	Economy	17900.00
0005434218044	9507	Economy	17900.00
0005434983418	9507	Economy	17900.00
0005434218043	9507	Economy	17900.00
0005434218042	9507	Economy	17900.00
0005434983419	9507	Economy	17900.00
0005434983372	27384	Economy	19700.00
0005434983390	27384	Economy	17900.00
0005434218072	27384	Economy	17900.00
0005434218073	27384	Economy	17900.00
0005434983354	27384	Economy	17900.00
0005434218071	27384	Economy	17900.00
0005434983377	27384	Economy	17900.00
0005434983355	27384	Economy	17900.00
0005434983383	27384	Economy	17900.00
0005434218074	27384	Economy	17900.00
0005433961676	24276	Business	36400.00
0005433961798	24276	Business	36400.00
0005433961664	24276	Business	36400.00
0005433961697	24276	Business	36400.00
0005433961713	24276	Business	36400.00
0005433986679	24276	Business	36400.00
0005433986758	24276	Business	36400.00
0005433986597	24276	Business	36400.00
0005433986441	24276	Business	36400.00
0005433961761	24276	Business	36400.00
0005433961817	24276	Business	36400.00
0005433961762	24276	Business	36400.00
0005433986718	24276	Business	36400.00
0005433986762	24276	Business	36400.00
0005433961801	24276	Economy	13400.00
0005433961630	24276	Economy	13400.00
0005433961679	24276	Economy	12100.00
0005433986744	24276	Economy	12100.00
0005433961734	24276	Economy	12100.00
0005433986778	24276	Economy	12100.00
0005433961658	24276	Economy	12100.00
0005433986649	24276	Economy	12100.00
0005433986772	24276	Economy	12100.00
0005433986627	24276	Economy	12100.00
0005433986773	24276	Economy	12100.00
0005433961776	24276	Economy	12100.00
0005433961696	24276	Economy	12100.00
0005433986643	24276	Economy	12100.00
0005433961750	24276	Economy	12100.00
0005433961827	24276	Economy	12100.00
0005433986620	24276	Economy	12100.00
0005433961546	24276	Economy	12100.00
0005433986507	24276	Economy	12100.00
0005433961662	24276	Economy	12100.00
0005433961842	24276	Economy	12100.00
0005433961652	24276	Economy	12100.00
0005433961594	24276	Economy	12100.00
0005433986761	24276	Economy	12100.00
0005433986456	24276	Economy	12100.00
0005433961678	24276	Economy	12100.00
0005433986726	24276	Economy	12100.00
0005433961790	24276	Economy	12100.00
0005433986470	24276	Economy	12100.00
0005433986588	24276	Economy	12100.00
0005433961740	24276	Economy	12100.00
0005433961661	24276	Economy	12100.00
0005433986666	24276	Economy	12100.00
0005433986678	24276	Economy	12100.00
0005433986668	24276	Economy	12100.00
0005433961751	24276	Economy	12100.00
0005433986684	24276	Economy	12100.00
0005433961699	24276	Economy	12100.00
0005433986639	24276	Economy	12100.00
0005433961843	24276	Economy	12100.00
0005433986621	24276	Economy	12100.00
0005433986745	24276	Economy	12100.00
0005433961835	24276	Economy	12100.00
0005433986513	24276	Economy	12100.00
0005433986624	24276	Economy	12100.00
0005433986677	24276	Economy	12100.00
0005433961837	24276	Economy	12100.00
0005433961618	24276	Economy	12100.00
0005433986814	24276	Economy	12100.00
0005433986809	24276	Economy	12100.00
0005433961791	24276	Economy	12100.00
0005433986628	24276	Economy	12100.00
0005433961683	24276	Economy	12100.00
0005433986457	24276	Economy	12100.00
0005433961733	24276	Economy	12100.00
0005433961695	24276	Economy	12100.00
0005433961805	24276	Economy	13400.00
0005433961642	24276	Economy	13400.00
0005433961792	24276	Economy	12100.00
0005433986792	24276	Economy	12100.00
0005433961593	24276	Economy	13400.00
0005433986828	24276	Economy	12100.00
0005433986838	24276	Economy	12100.00
0005433961690	24276	Economy	12100.00
0005433986626	24276	Economy	12100.00
0005433961516	24276	Economy	12100.00
0005433961657	24276	Economy	12100.00
0005433986683	24276	Economy	12100.00
0005433986676	24276	Economy	12100.00
0005433961729	24276	Economy	12100.00
0005433986825	24276	Economy	12100.00
0005433986506	24276	Economy	12100.00
0005433986837	24276	Economy	12100.00
0005433961727	24276	Economy	12100.00
0005433961722	24276	Economy	12100.00
0005433986682	24276	Economy	12100.00
0005433961698	24276	Economy	12100.00
0005433961590	24276	Economy	12100.00
0005433986810	24276	Economy	12100.00
0005433961641	24276	Economy	12100.00
0005433986783	24276	Economy	12100.00
0005433986587	24276	Economy	12100.00
0005433961622	24276	Economy	12100.00
0005433986589	24276	Economy	12100.00
0005433961785	24276	Economy	12100.00
0005433961841	24276	Economy	12100.00
0005433961775	24276	Economy	12100.00
0005433961732	24276	Economy	12100.00
0005433986586	24276	Economy	12100.00
0005433986650	24276	Economy	12100.00
0005433961707	24276	Economy	12100.00
0005433961583	24276	Economy	12100.00
0005433961720	24276	Economy	12100.00
0005433986803	24276	Economy	12100.00
0005433961680	24276	Economy	12100.00
0005433961721	24276	Economy	12100.00
0005433986655	24276	Economy	12100.00
0005433961818	24276	Economy	12100.00
0005433961793	24276	Economy	12100.00
0005433961623	24276	Economy	12100.00
0005433961765	24276	Economy	12100.00
0005433986839	24276	Economy	12100.00
0005433986846	24276	Economy	12100.00
0005433987103	25919	Business	36400.00
0005433987116	25919	Business	36400.00
0005433962317	25919	Business	36400.00
0005433962311	25919	Business	36400.00
0005433987133	25919	Business	36400.00
0005433962309	25919	Business	36400.00
0005433987095	25919	Business	36400.00
0005433987104	25919	Business	36400.00
0005433962296	25919	Business	36400.00
0005433962297	25919	Business	36400.00
0005433962315	25919	Business	36400.00
0005433962267	25919	Business	36400.00
0005433962280	25919	Business	36400.00
0005433987089	25919	Business	36400.00
0005433962271	25919	Business	36400.00
0005433987111	25919	Business	36400.00
0005433962294	25919	Business	36400.00
0005433987094	25919	Business	36400.00
0005433962313	25919	Economy	12100.00
0005433962282	25919	Economy	12100.00
0005433962291	25919	Economy	12100.00
0005433962316	25919	Economy	12100.00
0005433987096	25919	Economy	12100.00
0005433987124	25919	Economy	12100.00
0005433987120	25919	Economy	12100.00
0005433962293	25919	Economy	12100.00
0005433987092	25919	Economy	12100.00
0005433987088	25919	Economy	12100.00
0005433987118	25919	Economy	12100.00
0005433987106	25919	Economy	12100.00
0005433987093	25919	Economy	12100.00
0005433962292	25919	Economy	12100.00
0005433987113	25919	Economy	12100.00
0005433962312	25919	Economy	12100.00
0005433987091	25919	Economy	12100.00
0005433962276	25919	Economy	12100.00
0005433962314	25919	Economy	12100.00
0005433987102	25919	Economy	12100.00
0005433962308	25919	Economy	12100.00
0005433962303	25919	Economy	12100.00
0005433987101	25919	Economy	12100.00
0005433962285	25919	Economy	12100.00
0005433962290	25919	Economy	12100.00
0005433987115	25919	Economy	12100.00
0005433962274	25919	Economy	12100.00
0005433962286	25919	Economy	12100.00
0005433962299	25919	Economy	12100.00
0005433962281	25919	Economy	12100.00
0005433987100	25919	Economy	12100.00
0005433962319	25919	Economy	12100.00
0005433962268	25919	Economy	12100.00
0005433987122	25919	Economy	12100.00
0005433987129	25919	Economy	12100.00
0005433987097	25919	Economy	12100.00
0005433987087	25919	Economy	12100.00
0005433962288	25919	Economy	12100.00
0005433987123	25919	Economy	12100.00
0005433987090	25919	Economy	12100.00
0005433962320	25919	Economy	12100.00
0005433987119	25919	Economy	12100.00
0005433962278	25919	Economy	12100.00
0005433987128	25919	Economy	13400.00
0005433962284	25919	Economy	13400.00
0005433987112	25919	Economy	12100.00
0005433987099	25919	Economy	12100.00
0005433962275	25919	Economy	13400.00
0005433962301	25919	Economy	13400.00
0005433962273	25919	Economy	12100.00
0005433987110	25919	Economy	12100.00
0005433962304	25919	Economy	12100.00
0005433987108	25919	Economy	12100.00
0005433962306	25919	Economy	12100.00
0005433962277	25919	Economy	12100.00
0005433962307	25919	Economy	12100.00
0005433987127	25919	Economy	12100.00
0005433987107	25919	Economy	12100.00
0005433962302	25919	Economy	12100.00
0005433962300	25919	Economy	12100.00
0005433962295	25919	Economy	12100.00
0005433962305	25919	Economy	12100.00
0005433962287	25919	Economy	12100.00
0005433987098	25919	Economy	12100.00
0005433987121	25919	Economy	12100.00
0005433962272	25919	Economy	12100.00
0005433987130	25919	Economy	12100.00
0005433987114	25919	Economy	12100.00
0005433987126	25919	Economy	12100.00
0005433962270	25919	Economy	12100.00
0005433987125	25919	Economy	12100.00
0005433987131	25919	Economy	12100.00
0005433962283	25919	Economy	12100.00
0005433962266	25919	Economy	12100.00
0005433987105	25919	Economy	12100.00
0005433987132	25919	Economy	12100.00
0005433962310	25919	Economy	12100.00
0005433962318	25919	Economy	12100.00
0005433987117	25919	Economy	12100.00
0005433962298	25919	Economy	12100.00
0005433962279	25919	Economy	12100.00
0005433962269	25919	Economy	12100.00
0005433987109	25919	Economy	12100.00
0005433962289	25919	Economy	12100.00
0005434480969	973	Economy	25400.00
0005434480953	973	Economy	25400.00
0005434480947	973	Economy	25400.00
0005432269567	973	Economy	23100.00
0005434480968	973	Economy	23100.00
0005433166046	973	Economy	23100.00
0005434480959	973	Economy	23100.00
0005434480963	973	Economy	23100.00
0005433166098	973	Economy	23100.00
0005434480970	973	Economy	23100.00
0005434480952	973	Economy	23100.00
0005433166059	973	Economy	23100.00
0005433166047	973	Economy	23100.00
0005434480955	973	Economy	23100.00
0005433166071	973	Economy	23100.00
0005433166096	973	Economy	23100.00
0005434480960	973	Economy	23100.00
0005434480967	973	Economy	23100.00
0005434480965	973	Economy	23100.00
0005433166143	973	Economy	23100.00
0005434480971	973	Economy	23100.00
0005433166058	973	Economy	23100.00
0005434480964	973	Economy	23100.00
0005434480957	973	Economy	23100.00
0005433166095	973	Economy	23100.00
0005434480948	973	Economy	23100.00
0005434480951	973	Economy	23100.00
0005434480949	973	Economy	23100.00
0005433166072	973	Economy	23100.00
0005433166142	973	Economy	23100.00
0005433166063	973	Economy	23100.00
0005434480961	973	Economy	23100.00
0005434480956	973	Economy	23100.00
0005433166116	973	Economy	23100.00
0005434480958	973	Economy	23100.00
0005434480950	973	Economy	23100.00
0005433166112	973	Economy	23100.00
0005434480966	973	Economy	23100.00
0005434480954	973	Economy	23100.00
0005433166154	973	Economy	23100.00
0005433166060	973	Economy	23100.00
0005434480962	973	Economy	23100.00
0005432269566	973	Economy	23100.00
0005433166134	973	Economy	23100.00
0005433166157	973	Economy	23100.00
0005433166231	16596	Economy	25400.00
0005434480869	16596	Economy	25400.00
0005434480724	16596	Economy	25400.00
0005434480753	16596	Economy	23100.00
0005433166242	16596	Economy	23100.00
0005433166236	16596	Economy	23100.00
0005433166234	16596	Economy	23100.00
0005434480647	16596	Economy	23100.00
0005434480842	16596	Economy	23100.00
0005434480822	16596	Economy	23100.00
0005434480742	16596	Economy	23100.00
0005434480663	16596	Economy	23100.00
0005434480744	16596	Economy	23100.00
0005434480819	16596	Economy	23100.00
0005434480740	16596	Economy	23100.00
0005434480820	16596	Economy	23100.00
0005434480672	16596	Economy	23100.00
0005434480766	16596	Economy	23100.00
0005433166233	16596	Economy	23100.00
0005433166235	16596	Economy	23100.00
0005434480776	16596	Economy	23100.00
0005433166232	16596	Economy	23100.00
0005434480821	16596	Economy	23100.00
0005433166237	16596	Economy	23100.00
0005433166241	16596	Economy	23100.00
0005434480868	16596	Economy	23100.00
0005434480743	16596	Economy	23100.00
0005433166239	16596	Economy	23100.00
0005433166240	16596	Economy	23100.00
0005434480710	16596	Economy	23100.00
0005434480706	16596	Economy	23100.00
0005433166238	16596	Economy	23100.00
0005434480795	16596	Economy	23100.00
0005434480741	16596	Economy	23100.00
0005434480755	16596	Economy	23100.00
0005434480757	16596	Economy	23100.00
0005434480747	16596	Economy	23100.00
0005434480779	16596	Economy	23100.00
0005434480698	16596	Economy	23100.00
0005433872572	3205	Economy	19000.00
0005433872566	3205	Economy	17200.00
0005433872568	3205	Economy	17200.00
0005433872567	3205	Economy	17200.00
0005433872565	3205	Economy	17200.00
0005433872571	3205	Economy	17200.00
0005433872564	3205	Economy	17200.00
0005433872570	3205	Economy	17200.00
0005433872573	3205	Economy	17200.00
0005433872569	3205	Economy	17200.00
0005433872551	32557	Economy	17200.00
0005433872533	32557	Economy	17200.00
0005433872538	32557	Economy	17200.00
0005433872542	32557	Economy	17200.00
0005433872521	32557	Economy	17200.00
0005433872543	32557	Economy	17200.00
0005433872519	32557	Economy	17200.00
0005433872529	32557	Economy	17200.00
0005433872547	32557	Economy	17200.00
0005433872548	32557	Economy	17200.00
0005433872535	32557	Economy	17200.00
0005433872532	32557	Economy	17200.00
0005433872539	32557	Economy	17200.00
0005433872537	32557	Economy	17200.00
0005433872544	32557	Economy	17200.00
0005433872549	32557	Economy	17200.00
0005433872536	32557	Economy	17200.00
0005433872546	32557	Economy	17200.00
0005433872520	32557	Economy	17200.00
0005433872545	32557	Economy	17200.00
0005433872540	32557	Economy	17200.00
0005433872541	32557	Economy	17200.00
0005435142908	10367	Economy	17000.00
0005435150370	10367	Economy	17000.00
0005433289946	10367	Economy	17000.00
0005435150366	10367	Economy	15400.00
0005435386693	10367	Economy	15400.00
0005435150376	10367	Economy	15400.00
0005435150373	10367	Economy	15400.00
0005435142906	10367	Economy	15400.00
0005435142905	10367	Economy	15400.00
0005435142912	10367	Economy	15400.00
0005433289941	10367	Economy	15400.00
0005435150375	10367	Economy	15400.00
0005435150369	10367	Economy	15400.00
0005433289959	10367	Economy	15400.00
0005435386694	10367	Economy	15400.00
0005435150368	10367	Economy	15400.00
0005435142911	10367	Economy	15400.00
0005433289972	10367	Economy	15400.00
0005435150377	10367	Economy	15400.00
0005433289947	10367	Economy	15400.00
0005435150372	10367	Economy	15400.00
0005435142913	10367	Economy	15400.00
0005433289960	10367	Economy	15400.00
0005435142909	10367	Economy	15400.00
0005433289973	10367	Economy	15400.00
0005435142910	10367	Economy	15400.00
0005435142914	10367	Economy	15400.00
0005435386681	10367	Economy	15400.00
0005435386656	10367	Economy	15400.00
0005435142907	10367	Economy	15400.00
0005435150371	10367	Economy	15400.00
0005435150367	10367	Economy	15400.00
0005435150374	10367	Economy	15400.00
0005433289942	10367	Economy	15400.00
0005433289981	10367	Economy	15400.00
0005433289980	10367	Economy	15400.00
0005435150238	21920	Economy	17000.00
0005435150180	21920	Economy	17000.00
0005435142801	21920	Economy	17000.00
0005435386734	21920	Economy	17000.00
0005433290036	21920	Economy	15400.00
0005435150200	21920	Economy	15400.00
0005435386737	21920	Economy	15400.00
0005435142767	21920	Economy	15400.00
0005435142731	21920	Economy	15400.00
0005435150218	21920	Economy	15400.00
0005435386733	21920	Economy	15400.00
0005433290039	21920	Economy	15400.00
0005435150199	21920	Economy	15400.00
0005435142758	21920	Economy	15400.00
0005435150323	21920	Economy	15400.00
0005435150297	21920	Economy	15400.00
0005435150268	21920	Economy	15400.00
0005435150222	21920	Economy	15400.00
0005435142787	21920	Economy	15400.00
0005435142772	21920	Economy	15400.00
0005435142819	21920	Economy	15400.00
0005435142775	21920	Economy	15400.00
0005435150198	21920	Economy	15400.00
0005435142766	21920	Economy	15400.00
0005433290037	21920	Economy	15400.00
0005435150256	21920	Economy	15400.00
0005435142785	21920	Economy	15400.00
0005435386736	21920	Economy	15400.00
0005435150277	21920	Economy	15400.00
0005435142795	21920	Economy	15400.00
0005435150298	21920	Economy	15400.00
0005435386735	21920	Economy	15400.00
0005435142786	21920	Economy	15400.00
0005433290040	21920	Economy	15400.00
0005435150257	21920	Economy	15400.00
0005435142784	21920	Economy	15400.00
0005433290038	21920	Economy	15400.00
0005435142773	21920	Economy	15400.00
0005435150264	21920	Economy	15400.00
0005435142778	21920	Economy	15400.00
0005435529679	11193	Business	57200.00
0005434573694	11193	Business	57200.00
0005434573698	11193	Business	57200.00
0005435545864	11193	Business	57200.00
0005435502635	11193	Business	57200.00
0005435502641	11193	Business	57200.00
0005435529653	11193	Business	57200.00
0005434573693	11193	Business	57200.00
0005435529596	11193	Business	57200.00
0005435319753	11193	Business	57200.00
0005434573704	11193	Economy	19100.00
0005434573700	11193	Economy	19100.00
0005435545883	11193	Economy	19100.00
0005435502684	11193	Economy	19100.00
0005434573703	11193	Economy	19100.00
0005435502721	11193	Economy	21000.00
0005434573706	11193	Economy	21000.00
0005435502619	11193	Economy	21000.00
0005435502652	11193	Economy	19100.00
0005435502747	11193	Economy	19100.00
0005435545850	11193	Economy	19100.00
0005435502685	11193	Economy	19100.00
0005435502614	11193	Economy	19100.00
0005435529682	11193	Economy	19100.00
0005435529599	11193	Economy	19100.00
0005434573695	11193	Economy	19100.00
0005434573696	11193	Economy	19100.00
0005435529577	11193	Economy	19100.00
0005435502630	11193	Economy	19100.00
0005435529615	11193	Economy	19100.00
0005435502615	11193	Economy	19100.00
0005435502745	11193	Economy	19100.00
0005434573702	11193	Economy	19100.00
0005435529667	11193	Economy	19100.00
0005435529587	11193	Economy	19100.00
0005435502775	11193	Economy	19100.00
0005435319701	11193	Economy	19100.00
0005434573701	11193	Economy	19100.00
0005435545844	11193	Economy	19100.00
0005435545876	11193	Economy	19100.00
0005434573699	11193	Economy	19100.00
0005435529628	11193	Economy	19100.00
0005434573705	11193	Economy	19100.00
0005435545859	11193	Economy	19100.00
0005435529598	11193	Economy	19100.00
0005434573707	11193	Economy	19100.00
0005435502723	11193	Economy	19100.00
0005435319739	11193	Economy	19100.00
0005435545861	11193	Economy	19100.00
0005434573697	11193	Economy	19100.00
0005435545860	11193	Economy	19100.00
0005435529583	11193	Economy	19100.00
0005435502686	11193	Economy	19100.00
0005435319652	11193	Economy	19100.00
0005432291990	20956	Business	57200.00
0005435508720	20956	Business	57200.00
0005435508710	20956	Business	57200.00
0005435319805	20956	Business	57200.00
0005435508722	20956	Business	57200.00
0005435508711	20956	Business	57200.00
0005435502860	20956	Business	57200.00
0005434573535	20956	Business	57200.00
0005435508707	20956	Business	57200.00
0005435502842	20956	Business	57200.00
0005435502850	20956	Business	57200.00
0005434573533	20956	Economy	19100.00
0005435508713	20956	Economy	19100.00
0005434573540	20956	Economy	19100.00
0005435518363	20956	Economy	19100.00
0005435518361	20956	Economy	19100.00
0005435508717	20956	Economy	19100.00
0005435508712	20956	Economy	21000.00
0005435508716	20956	Economy	21000.00
0005435518355	20956	Economy	21000.00
0005435518366	20956	Economy	21000.00
0005435518362	20956	Economy	21000.00
0005435502851	20956	Economy	19100.00
0005435518349	20956	Economy	19100.00
0005435502845	20956	Economy	19100.00
0005435518364	20956	Economy	19100.00
0005435508726	20956	Economy	19100.00
0005432291993	20956	Economy	19100.00
0005435319809	20956	Economy	19100.00
0005435518357	20956	Economy	19100.00
0005435508721	20956	Economy	19100.00
0005435502847	20956	Economy	19100.00
0005434573567	20956	Economy	19100.00
0005434573550	20956	Economy	19100.00
0005435319804	20956	Economy	19100.00
0005434573532	20956	Economy	19100.00
0005435518359	20956	Economy	19100.00
0005435502858	20956	Economy	19100.00
0005432291991	20956	Economy	19100.00
0005435518360	20956	Economy	19100.00
0005435508727	20956	Economy	19100.00
0005435508723	20956	Economy	19100.00
0005435518352	20956	Economy	19100.00
0005435502840	20956	Economy	19100.00
0005435508709	20956	Economy	19100.00
0005435508715	20956	Economy	19100.00
0005435502846	20956	Economy	19100.00
0005435319803	20956	Economy	19100.00
0005435502854	20956	Economy	19100.00
0005435319807	20956	Economy	19100.00
0005435502857	20956	Economy	19100.00
0005435502855	20956	Economy	19100.00
0005434573551	20956	Economy	19100.00
0005435502843	20956	Economy	19100.00
0005435319808	20956	Economy	19100.00
0005435502853	20956	Economy	19100.00
0005435508714	20956	Economy	19100.00
0005435502859	20956	Economy	19100.00
0005435518353	20956	Economy	19100.00
0005435518351	20956	Economy	19100.00
0005432291992	20956	Economy	19100.00
0005435508719	20956	Economy	19100.00
0005435518350	20956	Economy	19100.00
0005435502849	20956	Economy	19100.00
0005435508718	20956	Economy	19100.00
0005435502841	20956	Economy	19100.00
0005435502848	20956	Economy	19100.00
0005435508724	20956	Economy	19100.00
0005435502856	20956	Economy	19100.00
0005434573577	20956	Economy	19100.00
0005435518358	20956	Economy	19100.00
0005434573534	20956	Economy	19100.00
0005435502861	20956	Economy	19100.00
0005435518354	20956	Economy	19100.00
0005435518356	20956	Economy	19100.00
0005435508708	20956	Economy	19100.00
0005434573586	20956	Economy	19100.00
0005435502852	20956	Economy	19100.00
0005435508725	20956	Economy	19100.00
0005435319806	20956	Economy	19100.00
0005435518365	20956	Economy	19100.00
0005435502844	20956	Economy	19100.00
0005433683403	24301	Economy	17100.00
0005433927487	24301	Economy	17100.00
0005433927473	24301	Economy	17100.00
0005433683399	24301	Economy	17100.00
0005433683405	24301	Economy	17100.00
0005433683401	24301	Economy	17100.00
0005433927474	24301	Economy	17100.00
0005433683402	24301	Economy	17100.00
0005433927480	24301	Economy	17100.00
0005433927485	24301	Economy	17100.00
0005433683398	24301	Economy	17100.00
0005433683407	24301	Economy	17100.00
0005433927479	24301	Economy	17100.00
0005433927476	24301	Economy	17100.00
0005433927478	24301	Economy	17100.00
0005433927488	24301	Economy	17100.00
0005433683406	24301	Economy	17100.00
0005433683400	24301	Economy	17100.00
0005433927475	24301	Economy	17100.00
0005433683408	24301	Economy	17100.00
0005433927486	24301	Economy	17100.00
0005433683404	24301	Economy	17100.00
0005433683373	29290	Economy	18800.00
0005433683360	29290	Economy	17100.00
0005433927502	29290	Economy	17100.00
0005433683372	29290	Economy	17100.00
0005433927506	29290	Economy	17100.00
0005433927500	29290	Economy	17100.00
0005433927503	29290	Economy	17100.00
0005433683369	29290	Economy	17100.00
0005433927501	29290	Economy	17100.00
0005433683385	29290	Economy	17100.00
0005433683374	29290	Economy	17100.00
0005433927508	29290	Economy	17100.00
0005433927507	29290	Economy	17100.00
0005433683365	29290	Economy	17100.00
0005433927509	29290	Economy	17100.00
0005433683371	29290	Economy	17100.00
0005433927505	29290	Economy	17100.00
0005433683386	29290	Economy	17100.00
0005433683370	29290	Economy	17100.00
0005433927504	29290	Economy	17100.00
0005433683382	29290	Economy	17100.00
0005433683380	29290	Economy	17100.00
0005433683364	29290	Economy	17100.00
0005433683368	29290	Economy	17100.00
0005432693529	2928	Business	10300.00
0005432693448	2928	Business	10300.00
0005432693400	2928	Business	10300.00
0005432693449	2928	Business	10300.00
0005432693729	2928	Economy	3400.00
0005432693665	2928	Economy	3400.00
0005432693471	2928	Economy	3400.00
0005432693515	2928	Economy	3800.00
0005432693630	2928	Economy	3800.00
0005432693587	2928	Economy	3800.00
0005432693739	2928	Economy	3400.00
0005432693645	2928	Economy	3400.00
0005432693504	2928	Economy	3400.00
0005432693487	2928	Economy	3400.00
0005432693447	2928	Economy	3400.00
0005432693569	2928	Economy	3400.00
0005432693612	2928	Economy	3400.00
0005432693581	2928	Economy	3400.00
0005432693493	2928	Economy	3400.00
0005432693604	2928	Economy	3400.00
0005432693611	2928	Economy	3400.00
0005432693492	2928	Economy	3400.00
0005432693740	2928	Economy	3400.00
0005432693603	2928	Economy	3400.00
0005432693629	2928	Economy	3400.00
0005432693580	2928	Economy	3400.00
0005432693600	2928	Economy	3400.00
0005432693472	2928	Economy	3400.00
0005432693488	2928	Economy	3400.00
0005432693730	2928	Economy	3400.00
0005432881026	2929	Business	10300.00
0005432881052	2929	Business	10300.00
0005432707410	2929	Business	10300.00
0005432217848	2929	Business	10300.00
0005433194895	2929	Business	10300.00
0005433124284	2929	Business	10300.00
0005432707420	2929	Business	10300.00
0005432707423	2929	Economy	3400.00
0005433124334	2929	Economy	3400.00
0005432881088	2929	Economy	3400.00
0005432217847	2929	Economy	3400.00
0005432881082	2929	Economy	3400.00
0005432880988	2929	Economy	3400.00
0005432881053	2929	Economy	3400.00
0005432881083	2929	Economy	3400.00
0005433124275	2929	Economy	3800.00
0005433194904	2929	Economy	3800.00
0005433124181	2929	Economy	3800.00
0005433124250	2929	Economy	3800.00
0005432707427	2929	Economy	3800.00
0005433124326	2929	Economy	3400.00
0005433124239	2929	Economy	3400.00
0005433124288	2929	Economy	3400.00
0005433124309	2929	Economy	3400.00
0005432881054	2929	Economy	3400.00
0005432881016	2929	Economy	3400.00
0005432707421	2929	Economy	3400.00
0005432881119	2929	Economy	3400.00
0005432707426	2929	Economy	3400.00
0005432707430	2929	Economy	3400.00
0005432707431	2929	Economy	3400.00
0005432707413	2929	Economy	3400.00
0005433124298	2929	Economy	3400.00
0005432707412	2929	Economy	3400.00
0005432707409	2929	Economy	3400.00
0005432881075	2929	Economy	3400.00
0005433124283	2929	Economy	3400.00
0005433124364	2929	Economy	3400.00
0005433194913	2929	Economy	3400.00
0005433124357	2929	Economy	3400.00
0005433124363	2929	Economy	3400.00
0005432707425	2929	Economy	3400.00
0005433124246	2929	Economy	3400.00
0005433124269	2929	Economy	3400.00
0005432707429	2929	Economy	3400.00
0005433124325	2929	Economy	3400.00
0005432707418	2929	Economy	3400.00
0005432217849	2929	Economy	3400.00
0005432707414	2929	Economy	3400.00
0005433124235	2929	Economy	3400.00
0005432707411	2929	Economy	3400.00
0005432881028	2929	Economy	3400.00
0005432707415	2929	Economy	3400.00
0005433124236	2929	Economy	3400.00
0005433124268	2929	Economy	3400.00
0005432881121	2929	Economy	3400.00
0005433124252	2929	Economy	3400.00
0005432881084	2929	Economy	3400.00
0005432707416	2929	Economy	3400.00
0005433124264	2929	Economy	3400.00
0005432707428	2929	Economy	3400.00
0005432881120	2929	Economy	3400.00
0005432707417	2929	Economy	3400.00
0005432707422	2929	Economy	3400.00
0005433124265	2929	Economy	3400.00
0005432707424	2929	Economy	3400.00
0005432707419	2929	Economy	3400.00
0005432707253	30055	Business	10300.00
0005432693858	30055	Business	10300.00
0005432693874	30055	Business	10300.00
0005433124435	30055	Business	10300.00
0005432693864	30055	Business	10300.00
0005432707274	30055	Business	10300.00
0005432881184	30055	Business	10300.00
0005432693870	30055	Business	10300.00
0005432707154	30055	Business	10300.00
0005432707181	30055	Business	10300.00
0005432693854	30055	Business	10300.00
0005432707229	30055	Economy	3400.00
0005432881190	30055	Economy	3400.00
0005432881183	30055	Economy	3400.00
0005432707236	30055	Economy	3400.00
0005432707117	30055	Economy	3400.00
0005432707186	30055	Economy	3400.00
0005432881188	30055	Economy	3400.00
0005432707182	30055	Economy	3400.00
0005433124439	30055	Economy	3400.00
0005432707273	30055	Economy	3400.00
0005432693865	30055	Economy	3800.00
0005432707312	30055	Economy	3800.00
0005432693868	30055	Economy	3800.00
0005432881191	30055	Economy	3800.00
0005432707155	30055	Economy	3800.00
0005432707205	30055	Economy	3400.00
0005432693859	30055	Economy	3400.00
0005432707174	30055	Economy	3400.00
0005432707167	30055	Economy	3400.00
0005432707173	30055	Economy	3400.00
0005432693866	30055	Economy	3400.00
0005432707367	30055	Economy	3400.00
0005432707116	30055	Economy	3400.00
0005432707243	30055	Economy	3400.00
0005432693867	30055	Economy	3400.00
0005432881185	30055	Economy	3400.00
0005432707268	30055	Economy	3400.00
0005432707068	30055	Economy	3400.00
0005432693852	30055	Economy	3400.00
0005432693875	30055	Economy	3400.00
0005432693863	30055	Economy	3400.00
0005432707178	30055	Economy	3400.00
0005433124440	30055	Economy	3400.00
0005432707257	30055	Economy	3400.00
0005432693851	30055	Economy	3400.00
0005432693848	30055	Economy	3400.00
0005432707175	30055	Economy	3400.00
0005432707230	30055	Economy	3400.00
0005432707269	30055	Economy	3400.00
0005432707278	30055	Economy	3400.00
0005432707166	30055	Economy	3400.00
0005432881194	30055	Economy	3400.00
0005432707224	30055	Economy	3400.00
0005433124441	30055	Economy	3400.00
0005432707308	30055	Economy	3400.00
0005433124436	30055	Economy	3400.00
0005432707306	30055	Economy	3400.00
0005432881182	30055	Economy	3400.00
0005432881192	30055	Economy	3400.00
0005433124438	30055	Economy	3400.00
0005432707216	30055	Economy	3400.00
0005432707152	30055	Economy	3400.00
0005432693861	30055	Economy	3400.00
0005432881193	30055	Economy	3400.00
0005432693860	30055	Economy	3400.00
0005432707366	30055	Economy	3400.00
0005433124437	30055	Economy	3400.00
0005432707118	30055	Economy	3400.00
0005432707217	30055	Economy	3400.00
0005432693872	30055	Economy	3400.00
0005432693873	30055	Economy	3400.00
0005432881186	30055	Economy	3400.00
0005432707179	30055	Economy	3400.00
0005432693850	30055	Economy	3400.00
0005432707263	30055	Economy	3400.00
0005432693849	30055	Economy	3400.00
0005432693869	30055	Economy	3400.00
0005432707223	30055	Economy	3400.00
0005432707244	30055	Economy	3400.00
0005432881187	30055	Economy	3400.00
0005433124442	30055	Economy	3400.00
0005432707206	30055	Economy	3400.00
0005432881189	30055	Economy	3400.00
0005432693857	30055	Economy	3400.00
0005432693856	30055	Economy	3400.00
0005432693855	30055	Economy	3400.00
0005432693871	30055	Economy	3400.00
0005432707153	30055	Economy	3400.00
0005433124443	30055	Economy	3400.00
0005432693862	30055	Economy	3400.00
0005432707307	30055	Economy	3400.00
0005432707309	30055	Economy	3400.00
0005432707275	30055	Economy	3400.00
0005432707215	30055	Economy	3400.00
0005432693853	30055	Economy	3400.00
0005434980530	23656	Economy	4000.00
0005434989020	23656	Economy	4000.00
0005434980523	23656	Economy	3600.00
0005434989013	23656	Economy	3600.00
0005434980529	23656	Economy	3600.00
0005434980514	23656	Economy	3600.00
0005434980526	23656	Economy	3600.00
0005434980538	23656	Economy	3600.00
0005434989009	23656	Economy	3600.00
0005434980531	23656	Economy	3600.00
0005434980516	23656	Economy	3600.00
0005434980528	23656	Economy	3600.00
0005434980539	23656	Economy	3600.00
0005434989019	23656	Economy	3600.00
0005434989014	23656	Economy	3600.00
0005434989012	23656	Economy	3600.00
0005434989018	23656	Economy	3600.00
0005434980525	23656	Economy	3600.00
0005434980535	23656	Economy	3600.00
0005434980521	23656	Economy	3600.00
0005434980536	23656	Economy	3600.00
0005434989008	23656	Economy	3600.00
0005434980520	23656	Economy	3600.00
0005434980524	23656	Economy	3600.00
0005434989011	23656	Economy	3600.00
0005434980537	23656	Economy	3600.00
0005434980519	23656	Economy	3600.00
0005434980534	23656	Economy	3600.00
0005434980522	23656	Economy	3600.00
0005434980540	23656	Economy	3600.00
0005434989007	23656	Economy	3600.00
0005434980515	23656	Economy	3600.00
0005434989010	23656	Economy	3600.00
0005434980518	23656	Economy	3600.00
0005434980517	23656	Economy	3600.00
0005434989016	23656	Economy	3600.00
0005434989017	23656	Economy	3600.00
0005434980532	23656	Economy	3600.00
0005434980527	23656	Economy	3600.00
0005434980533	23656	Economy	3600.00
0005434980541	23656	Economy	3600.00
0005434989015	23656	Economy	3600.00
0005434980254	27522	Economy	4000.00
0005434980069	27522	Economy	4000.00
0005434980198	27522	Economy	4000.00
0005434980224	27522	Economy	3600.00
0005434980313	27522	Economy	3600.00
0005434980264	27522	Economy	3600.00
0005434988903	27522	Economy	3600.00
0005434980223	27522	Economy	3600.00
0005434980356	27522	Economy	3600.00
0005434988901	27522	Economy	3600.00
0005434980197	27522	Economy	3600.00
0005434980333	27522	Economy	3600.00
0005434988917	27522	Economy	3600.00
0005434980164	27522	Economy	3600.00
0005434988908	27522	Economy	3600.00
0005434980226	27522	Economy	3600.00
0005434988910	27522	Economy	3600.00
0005434980322	27522	Economy	3600.00
0005434980225	27522	Economy	3600.00
0005434988909	27522	Economy	3600.00
0005434980121	27522	Economy	3600.00
0005434988900	27522	Economy	3600.00
0005434980306	27522	Economy	3600.00
0005434980403	27522	Economy	3600.00
0005434980256	27522	Economy	3600.00
0005434980199	27522	Economy	3600.00
0005434988905	27522	Economy	3600.00
0005434980178	27522	Economy	3600.00
0005434980245	27522	Economy	3600.00
0005434980279	27522	Economy	3600.00
0005434980246	27522	Economy	3600.00
0005434980253	27522	Economy	3600.00
0005434980263	27522	Economy	3600.00
0005434980315	27522	Economy	3600.00
0005434988906	27522	Economy	3600.00
0005434980320	27522	Economy	3600.00
0005434980298	27522	Economy	3600.00
0005434980390	27522	Economy	3600.00
0005434988918	27522	Economy	3600.00
0005434980314	27522	Economy	3600.00
0005434980316	27522	Economy	3600.00
0005433113564	10288	Economy	19700.00
0005433113567	10288	Economy	19700.00
0005434302895	10288	Economy	19700.00
0005434302894	10288	Economy	19700.00
0005434302565	10288	Economy	19700.00
0005434302566	10288	Economy	19700.00
0005434302896	10288	Economy	19700.00
0005434302532	19608	Economy	21600.00
0005433113590	19608	Economy	19700.00
0005434302523	19608	Economy	19700.00
0005434302531	19608	Economy	19700.00
0005433113592	19608	Economy	19700.00
0005433113591	19608	Economy	19700.00
0005434302524	19608	Economy	19700.00
0005435070414	3560	Business	26900.00
0005435925542	3560	Business	26900.00
0005435070387	3560	Business	26900.00
0005435070389	3560	Business	26900.00
0005435070386	3560	Business	26900.00
0005435070390	3560	Business	26900.00
0005435070400	3560	Business	26900.00
0005435070419	3560	Business	26900.00
0005435719097	3560	Economy	9000.00
0005435925521	3560	Economy	9000.00
0005435070422	3560	Economy	9000.00
0005435070382	3560	Economy	9000.00
0005435925552	3560	Economy	9000.00
0005435070409	3560	Economy	9000.00
0005435070420	3560	Economy	9900.00
0005435925560	3560	Economy	9900.00
0005435070423	3560	Economy	9900.00
0005435070396	3560	Economy	9900.00
0005435925486	3560	Economy	9000.00
0005435070407	3560	Economy	9000.00
0005435070392	3560	Economy	9000.00
0005435070398	3560	Economy	9000.00
0005435925487	3560	Economy	9000.00
0005435070421	3560	Economy	9000.00
0005435925523	3560	Economy	9000.00
0005435070383	3560	Economy	9000.00
0005435719095	3560	Economy	9000.00
0005435070416	3560	Economy	9000.00
0005435070380	3560	Economy	9000.00
0005435070406	3560	Economy	9000.00
0005435070412	3560	Economy	9000.00
0005435070413	3560	Economy	9000.00
0005435070388	3560	Economy	9000.00
0005435070410	3560	Economy	9000.00
0005435070401	3560	Economy	9000.00
0005435070394	3560	Economy	9000.00
0005435070405	3560	Economy	9000.00
0005435070404	3560	Economy	9000.00
0005435719092	3560	Economy	9000.00
0005435070408	3560	Economy	9000.00
0005435719094	3560	Economy	9000.00
0005435070402	3560	Economy	9000.00
0005435070381	3560	Economy	9000.00
0005435719096	3560	Economy	9000.00
0005435070403	3560	Economy	9000.00
0005435070379	3560	Economy	9000.00
0005435070418	3560	Economy	9000.00
0005435939910	3560	Economy	9000.00
0005435925544	3560	Economy	9000.00
0005435070399	3560	Economy	9000.00
0005435070384	3560	Economy	9000.00
0005435070378	3560	Economy	9000.00
0005435925508	3560	Economy	9000.00
0005435925426	3560	Economy	9000.00
0005435925509	3560	Economy	9000.00
0005435070425	3560	Economy	9000.00
0005435070415	3560	Economy	9000.00
0005435925543	3560	Economy	9000.00
0005435719093	3560	Economy	9000.00
0005435719091	3560	Economy	9000.00
0005435070397	3560	Economy	9000.00
0005435070391	3560	Economy	9000.00
0005435070424	3560	Economy	9000.00
0005435070411	3560	Economy	9000.00
0005435070393	3560	Economy	9000.00
0005435070395	3560	Economy	9000.00
0005435070417	3560	Economy	9000.00
0005435070385	3560	Economy	9000.00
0005435069566	15300	Business	26900.00
0005435069890	15300	Business	26900.00
0005435069744	15300	Business	26900.00
0005435069886	15300	Business	26900.00
0005435069850	15300	Business	26900.00
0005435069995	15300	Business	26900.00
0005435069855	15300	Business	26900.00
0005435069786	15300	Business	26900.00
0005435070154	15300	Business	26900.00
0005435069936	15300	Economy	9000.00
0005435069891	15300	Economy	9000.00
0005435925652	15300	Economy	9000.00
0005435069727	15300	Economy	9000.00
0005435070108	15300	Economy	9000.00
0005435069904	15300	Economy	9000.00
0005435069731	15300	Economy	9000.00
0005435069871	15300	Economy	9000.00
0005435069961	15300	Economy	9900.00
0005435069914	15300	Economy	9900.00
0005435070153	15300	Economy	9900.00
0005435069991	15300	Economy	9900.00
0005435069564	15300	Economy	9900.00
0005435069745	15300	Economy	9000.00
0005435069819	15300	Economy	9000.00
0005435070070	15300	Economy	9000.00
0005435925656	15300	Economy	9000.00
0005435069565	15300	Economy	9000.00
0005435070115	15300	Economy	9000.00
0005435069764	15300	Economy	9000.00
0005435925655	15300	Economy	9000.00
0005435070155	15300	Economy	9000.00
0005435069920	15300	Economy	9000.00
0005435070127	15300	Economy	9000.00
0005435069726	15300	Economy	9000.00
0005435925653	15300	Economy	9000.00
0005435069952	15300	Economy	9000.00
0005435069787	15300	Economy	9000.00
0005435069866	15300	Economy	9000.00
0005435070010	15300	Economy	9000.00
0005435069807	15300	Economy	9000.00
0005435069887	15300	Economy	9000.00
0005435070111	15300	Economy	9000.00
0005435070114	15300	Economy	9000.00
0005435069818	15300	Economy	9000.00
0005435069691	15300	Economy	9000.00
0005435069817	15300	Economy	9000.00
0005435069756	15300	Economy	9000.00
0005435069867	15300	Economy	9000.00
0005435070053	15300	Economy	9000.00
0005435069863	15300	Economy	9000.00
0005435069935	15300	Economy	9000.00
0005435069732	15300	Economy	9000.00
0005435069950	15300	Economy	9000.00
0005435069728	15300	Economy	9000.00
0005435069948	15300	Economy	9000.00
0005435069755	15300	Economy	9000.00
0005435069951	15300	Economy	9000.00
0005435069949	15300	Economy	9000.00
0005435069856	15300	Economy	9000.00
0005435069841	15300	Economy	9000.00
0005435069959	15300	Economy	9000.00
0005435070011	15300	Economy	9000.00
0005435070040	15300	Economy	9000.00
0005435925654	15300	Economy	9000.00
0005435069788	15300	Economy	9000.00
0005435070052	15300	Economy	9000.00
0005435069885	15300	Economy	9000.00
0005435069962	15300	Economy	9000.00
0005435069916	15300	Economy	9000.00
0005435069765	15300	Economy	9000.00
0005435069897	15300	Economy	9000.00
0005435070084	15300	Economy	9000.00
0005432658645	18231	Economy	5900.00
0005432660871	18231	Economy	5900.00
0005432660872	18231	Economy	5900.00
0005432660870	18231	Economy	5900.00
0005432659759	18231	Economy	5900.00
0005432659760	18231	Economy	5900.00
0005432660873	18231	Economy	5900.00
0005432658644	18231	Economy	5900.00
0005432660842	26432	Economy	5900.00
0005432667478	26432	Economy	5900.00
0005432664169	26432	Economy	5900.00
0005432667494	26432	Economy	5900.00
0005432667487	26432	Economy	5900.00
0005432664158	26432	Economy	5900.00
0005432664170	26432	Economy	5900.00
0005432667493	26432	Economy	5900.00
0005432667483	26432	Economy	5900.00
0005432660843	26432	Economy	5900.00
0005432667492	26432	Economy	5900.00
0005432664159	26432	Economy	5900.00
0005432392019	119	Business	20000.00
0005432920240	119	Business	20000.00
0005432901917	119	Business	20000.00
0005433103051	119	Business	20000.00
0005432920196	119	Business	20000.00
0005432920310	119	Business	20000.00
0005432392047	119	Business	20000.00
0005433103025	119	Business	20000.00
0005433102947	119	Business	20000.00
0005433103016	119	Business	20000.00
0005433102982	119	Business	20000.00
0005432920131	119	Business	20000.00
0005432920197	119	Business	20000.00
0005432920222	119	Business	20000.00
0005432901914	119	Business	20000.00
0005432392028	119	Business	20000.00
0005432677639	119	Business	20000.00
0005432392037	119	Business	20000.00
0005432901965	119	Business	20000.00
0005433103017	119	Business	20000.00
0005432920287	119	Business	20000.00
0005433102993	119	Business	20000.00
0005432901934	119	Economy	7300.00
0005433102890	119	Economy	7300.00
0005433103018	119	Economy	7300.00
0005433103090	119	Economy	7300.00
0005432920162	119	Economy	7300.00
0005433103078	119	Economy	7300.00
0005432901908	119	Economy	6700.00
0005432901882	119	Economy	6700.00
0005433102885	119	Economy	6700.00
0005432677626	119	Economy	6700.00
0005432677647	119	Economy	6700.00
0005433102883	119	Economy	6700.00
0005433102940	119	Economy	6700.00
0005432157541	119	Economy	6700.00
0005433102994	119	Economy	6700.00
0005433102942	119	Economy	6700.00
0005432901945	119	Economy	6700.00
0005432920204	119	Economy	6700.00
0005432920130	119	Economy	6700.00
0005433102941	119	Economy	6700.00
0005432392049	119	Economy	6700.00
0005432901835	119	Economy	6700.00
0005432920186	119	Economy	6700.00
0005432901944	119	Economy	6700.00
0005432920165	119	Economy	6700.00
0005432920161	119	Economy	6700.00
0005433103054	119	Economy	6700.00
0005432901946	119	Economy	6700.00
0005432677641	119	Economy	6700.00
0005433103036	119	Economy	6700.00
0005433103089	119	Economy	6700.00
0005433102995	119	Economy	6700.00
0005433103050	119	Economy	6700.00
0005433103053	119	Economy	6700.00
0005432920210	119	Economy	6700.00
0005433103101	119	Economy	6700.00
0005432677629	119	Economy	6700.00
0005432920239	119	Economy	6700.00
0005432392020	119	Economy	6700.00
0005433102811	119	Economy	6700.00
0005432392040	119	Economy	6700.00
0005433102810	119	Economy	6700.00
0005433102992	119	Economy	6700.00
0005432677646	119	Economy	6700.00
0005433103041	119	Economy	6700.00
0005432920308	119	Economy	6700.00
0005432677627	119	Economy	6700.00
0005432920164	119	Economy	6700.00
0005433102862	119	Economy	6700.00
0005433102971	119	Economy	7300.00
0005433102882	119	Economy	7300.00
0005432392048	119	Economy	7300.00
0005433102946	119	Economy	6700.00
0005432677628	119	Economy	6700.00
0005433102884	119	Economy	6700.00
0005432677640	119	Economy	6700.00
0005433103055	119	Economy	7300.00
0005432392042	119	Economy	6700.00
0005433102823	119	Economy	6700.00
0005433102963	119	Economy	6700.00
0005432920288	119	Economy	6700.00
0005433102913	119	Economy	6700.00
0005432901881	119	Economy	6700.00
0005432392041	119	Economy	6700.00
0005433103100	119	Economy	6700.00
0005433103026	119	Economy	6700.00
0005432920203	119	Economy	6700.00
0005432920205	119	Economy	6700.00
0005433102938	119	Economy	6700.00
0005432920275	119	Economy	6700.00
0005432901943	119	Economy	6700.00
0005433102889	119	Economy	6700.00
0005432901991	119	Economy	6700.00
0005433102891	119	Economy	6700.00
0005432920251	119	Economy	6700.00
0005433102907	119	Economy	6700.00
0005432901862	119	Economy	6700.00
0005432901915	119	Economy	6700.00
0005432901906	119	Economy	6700.00
0005433103020	119	Economy	6700.00
0005433102972	119	Economy	6700.00
0005432157540	119	Economy	6700.00
0005433103002	119	Economy	6700.00
0005432392045	119	Economy	6700.00
0005433103001	119	Economy	6700.00
0005432901909	119	Economy	6700.00
0005432392046	119	Economy	6700.00
0005432920289	119	Economy	6700.00
0005433103094	119	Economy	6700.00
0005432901863	119	Economy	6700.00
0005432920225	119	Economy	6700.00
0005433102822	119	Economy	6700.00
0005433102973	119	Economy	6700.00
0005433103052	119	Economy	6700.00
0005432818213	117	Business	20000.00
0005432263055	117	Business	20000.00
0005432818237	117	Business	20000.00
0005433477156	117	Business	20000.00
0005432263076	117	Business	20000.00
0005432263086	117	Business	20000.00
0005432263052	117	Business	20000.00
0005432818222	117	Business	20000.00
0005433690948	117	Business	20000.00
0005432289072	117	Business	20000.00
0005432263063	117	Business	20000.00
0005432818221	117	Business	20000.00
0005432289070	117	Business	20000.00
0005432263058	117	Business	20000.00
0005433477131	117	Business	20000.00
0005433477136	117	Business	20000.00
0005432818224	117	Business	20000.00
0005434153570	117	Business	20000.00
0005433477138	117	Business	20000.00
0005432263049	117	Business	20000.00
0005432263069	117	Economy	7300.00
0005433477154	117	Economy	7300.00
0005432289069	117	Economy	7300.00
0005433477123	117	Economy	7300.00
0005433477121	117	Economy	7300.00
0005432263048	117	Economy	6700.00
0005433477125	117	Economy	6700.00
0005433477130	117	Economy	6700.00
0005433477126	117	Economy	6700.00
0005433477141	117	Economy	6700.00
0005432263066	117	Economy	6700.00
0005432263087	117	Economy	6700.00
0005432818228	117	Economy	6700.00
0005432263071	117	Economy	6700.00
0005433477153	117	Economy	6700.00
0005432756892	117	Economy	6700.00
0005432818232	117	Economy	6700.00
0005433477143	117	Economy	6700.00
0005432263079	117	Economy	6700.00
0005432263065	117	Economy	6700.00
0005434157727	117	Economy	6700.00
0005433477155	117	Economy	6700.00
0005432263083	117	Economy	6700.00
0005432753348	117	Economy	6700.00
0005432818229	117	Economy	6700.00
0005433477120	117	Economy	6700.00
0005432818223	117	Economy	6700.00
0005432263064	117	Economy	6700.00
0005432263051	117	Economy	6700.00
0005434157724	117	Economy	6700.00
0005433477124	117	Economy	6700.00
0005432263080	117	Economy	6700.00
0005432756893	117	Economy	6700.00
0005433477146	117	Economy	6700.00
0005432263050	117	Economy	6700.00
0005432263060	117	Economy	6700.00
0005433477129	117	Economy	6700.00
0005432263082	117	Economy	6700.00
0005434157723	117	Economy	6700.00
0005432818231	117	Economy	6700.00
0005433477142	117	Economy	6700.00
0005433477134	117	Economy	6700.00
0005432753347	117	Economy	6700.00
0005432289071	117	Economy	6700.00
0005432753331	117	Economy	6700.00
0005432263068	117	Economy	6700.00
0005433477144	117	Economy	6700.00
0005433477145	117	Economy	6700.00
0005432263057	117	Economy	6700.00
0005432263059	117	Economy	6700.00
0005432263072	117	Economy	6700.00
0005432818217	117	Economy	6700.00
0005433477135	117	Economy	7300.00
0005432263054	117	Economy	7300.00
0005432756903	117	Economy	7300.00
0005432818235	117	Economy	7300.00
0005432263053	117	Economy	6700.00
0005433477139	117	Economy	6700.00
0005432263046	117	Economy	7300.00
0005432207725	117	Economy	6700.00
0005432207726	117	Economy	6700.00
0005433477148	117	Economy	6700.00
0005432753330	117	Economy	6700.00
0005432818216	117	Economy	6700.00
0005433477122	117	Economy	6700.00
0005434153572	117	Economy	6700.00
0005434153571	117	Economy	6700.00
0005434157726	117	Economy	6700.00
0005432263085	117	Economy	6700.00
0005432263074	117	Economy	6700.00
0005432263067	117	Economy	6700.00
0005432818219	117	Economy	6700.00
0005432818215	117	Economy	6700.00
0005432263047	117	Economy	6700.00
0005432818225	117	Economy	6700.00
0005432818233	117	Economy	6700.00
0005433477147	117	Economy	6700.00
0005433477149	117	Economy	6700.00
0005433477137	117	Economy	6700.00
0005432263084	117	Economy	6700.00
0005432818227	117	Economy	6700.00
0005433477132	117	Economy	6700.00
0005434157725	117	Economy	6700.00
0005433477151	117	Economy	6700.00
0005433477133	117	Economy	6700.00
0005434152859	117	Economy	6700.00
0005432263075	117	Economy	6700.00
0005432263073	117	Economy	6700.00
0005432263088	117	Economy	6700.00
0005433477140	117	Economy	6700.00
0005432263077	117	Economy	6700.00
0005433477157	117	Economy	6700.00
0005432818214	117	Economy	6700.00
0005432263081	117	Economy	6700.00
0005433477127	117	Economy	6700.00
0005432818236	117	Economy	6700.00
0005433477150	117	Economy	6700.00
0005432263078	117	Economy	6700.00
0005432818226	117	Economy	6700.00
0005433477152	117	Economy	6700.00
0005432263056	117	Economy	6700.00
0005432818220	117	Economy	6700.00
0005432263070	117	Economy	6700.00
0005433477128	117	Economy	6700.00
0005432263061	117	Economy	6700.00
0005432818230	117	Economy	6700.00
0005432263062	117	Economy	6700.00
0005432818218	117	Economy	6700.00
0005432818234	117	Economy	6700.00
0005432753350	117	Economy	6700.00
0005432753356	117	Economy	6700.00
0005433103487	8028	Business	20000.00
0005433103504	8028	Business	20000.00
0005433103517	8028	Business	20000.00
0005433103493	8028	Business	20000.00
0005432045663	8028	Business	20000.00
0005432920389	8028	Business	20000.00
0005432920384	8028	Business	20000.00
0005432920380	8028	Business	20000.00
0005433103529	8028	Business	20000.00
0005433103506	8028	Business	20000.00
0005432920387	8028	Business	20000.00
0005432920379	8028	Business	20000.00
0005432020957	8028	Business	20000.00
0005432920386	8028	Business	20000.00
0005433103525	8028	Business	20000.00
0005433103491	8028	Business	20000.00
0005433103520	8028	Business	20000.00
0005432020956	8028	Business	20000.00
0005432392076	8028	Business	20000.00
0005433103522	8028	Business	20000.00
0005432751613	8028	Business	20000.00
0005433103513	8028	Business	20000.00
0005432751612	8028	Business	20000.00
0005432392077	8028	Business	20000.00
0005433103490	8028	Economy	7300.00
0005433103498	8028	Economy	7300.00
0005432020932	8028	Economy	7300.00
0005433103507	8028	Economy	7300.00
0005433103536	8028	Economy	7300.00
0005432020950	8028	Economy	6700.00
0005433103535	8028	Economy	6700.00
0005432920388	8028	Economy	6700.00
0005432020934	8028	Economy	6700.00
0005433103503	8028	Economy	6700.00
0005432020955	8028	Economy	6700.00
0005432044595	8028	Economy	6700.00
0005433103540	8028	Economy	6700.00
0005432920391	8028	Economy	6700.00
0005433103495	8028	Economy	6700.00
0005432753388	8028	Economy	6700.00
0005433103515	8028	Economy	6700.00
0005433103488	8028	Economy	6700.00
0005432920396	8028	Economy	6700.00
0005433103514	8028	Economy	6700.00
0005433103501	8028	Economy	6700.00
0005433103492	8028	Economy	6700.00
0005433103494	8028	Economy	6700.00
0005432920393	8028	Economy	6700.00
0005432020946	8028	Economy	6700.00
0005432020940	8028	Economy	6700.00
0005433103531	8028	Economy	6700.00
0005432020951	8028	Economy	6700.00
0005433103518	8028	Economy	6700.00
0005432920395	8028	Economy	6700.00
0005432020937	8028	Economy	6700.00
0005432020945	8028	Economy	6700.00
0005433103511	8028	Economy	6700.00
0005432020935	8028	Economy	6700.00
0005433103526	8028	Economy	6700.00
0005433103497	8028	Economy	6700.00
0005432020938	8028	Economy	6700.00
0005432020944	8028	Economy	6700.00
0005432020952	8028	Economy	6700.00
0005432020942	8028	Economy	6700.00
0005432044594	8028	Economy	6700.00
0005433103537	8028	Economy	6700.00
0005432045664	8028	Economy	6700.00
0005433103516	8028	Economy	6700.00
0005433103509	8028	Economy	6700.00
0005432677675	8028	Economy	6700.00
0005433103521	8028	Economy	6700.00
0005432751611	8028	Economy	6700.00
0005432920399	8028	Economy	7300.00
0005433103502	8028	Economy	7300.00
0005433103505	8028	Economy	7300.00
0005433103524	8028	Economy	6700.00
0005433103512	8028	Economy	6700.00
0005432020939	8028	Economy	6700.00
0005433103533	8028	Economy	7300.00
0005433103523	8028	Economy	6700.00
0005433103519	8028	Economy	6700.00
0005433103539	8028	Economy	6700.00
0005432044596	8028	Economy	6700.00
0005432020948	8028	Economy	6700.00
0005432020933	8028	Economy	6700.00
0005432920392	8028	Economy	6700.00
0005432920397	8028	Economy	6700.00
0005432020953	8028	Economy	6700.00
0005432920385	8028	Economy	6700.00
0005433103538	8028	Economy	6700.00
0005433103489	8028	Economy	6700.00
0005432920383	8028	Economy	6700.00
0005433103510	8028	Economy	6700.00
0005432920390	8028	Economy	6700.00
0005432753387	8028	Economy	6700.00
0005433103530	8028	Economy	6700.00
0005433103508	8028	Economy	6700.00
0005433103499	8028	Economy	6700.00
0005432020947	8028	Economy	6700.00
0005432020954	8028	Economy	6700.00
0005432020943	8028	Economy	6700.00
0005432920394	8028	Economy	6700.00
0005432392079	8028	Economy	6700.00
0005432920398	8028	Economy	6700.00
0005433103532	8028	Economy	6700.00
0005432020949	8028	Economy	6700.00
0005432020936	8028	Economy	6700.00
0005432920382	8028	Economy	6700.00
0005432677676	8028	Economy	6700.00
0005432677677	8028	Economy	6700.00
0005432020941	8028	Economy	6700.00
0005433103528	8028	Economy	6700.00
0005433103527	8028	Economy	6700.00
0005432392078	8028	Economy	6700.00
0005432753386	8028	Economy	6700.00
0005433103500	8028	Economy	6700.00
0005432920381	8028	Economy	6700.00
0005433103496	8028	Economy	6700.00
0005433103534	8028	Economy	6700.00
0005432818081	8032	Business	20000.00
0005432818001	8032	Business	20000.00
0005432818004	8032	Business	20000.00
0005432902050	8032	Business	20000.00
0005432002129	8032	Business	20000.00
0005434513623	8032	Business	20000.00
0005432818003	8032	Business	20000.00
0005432902048	8032	Business	20000.00
0005434513633	8032	Business	20000.00
0005432902049	8032	Business	20000.00
0005434513614	8032	Business	20000.00
0005432817747	8032	Economy	7300.00
0005432818036	8032	Economy	7300.00
0005434513618	8032	Economy	6700.00
0005432902054	8032	Economy	6700.00
0005432817891	8032	Economy	6700.00
0005432818002	8032	Economy	6700.00
0005432902052	8032	Economy	6700.00
0005432818080	8032	Economy	6700.00
0005432817994	8032	Economy	6700.00
0005432817886	8032	Economy	6700.00
0005432902060	8032	Economy	6700.00
0005432818040	8032	Economy	6700.00
0005434513617	8032	Economy	6700.00
0005434513620	8032	Economy	6700.00
0005432817991	8032	Economy	6700.00
0005434513634	8032	Economy	6700.00
0005432817877	8032	Economy	6700.00
0005432902051	8032	Economy	6700.00
0005434513621	8032	Economy	6700.00
0005432902056	8032	Economy	6700.00
0005434513625	8032	Economy	7300.00
0005432902047	8032	Economy	6700.00
0005432818083	8032	Economy	6700.00
0005434513622	8032	Economy	7300.00
0005432817917	8032	Economy	6700.00
0005432817987	8032	Economy	6700.00
0005432817959	8032	Economy	6700.00
0005432817984	8032	Economy	6700.00
0005434513624	8032	Economy	6700.00
0005432817878	8032	Economy	6700.00
0005432902059	8032	Economy	6700.00
0005432817902	8032	Economy	6700.00
0005432818000	8032	Economy	6700.00
0005432902058	8032	Economy	6700.00
0005432902046	8032	Economy	6700.00
0005432902057	8032	Economy	6700.00
0005432817907	8032	Economy	6700.00
0005432902053	8032	Economy	6700.00
0005432818039	8032	Economy	6700.00
0005434513619	8032	Economy	6700.00
0005432817911	8032	Economy	6700.00
0005432817908	8032	Economy	6700.00
0005432902061	8032	Economy	6700.00
0005432902055	8032	Economy	6700.00
0005434175821	9676	Economy	6900.00
0005434175822	9676	Economy	6900.00
0005434175861	32373	Economy	6900.00
0005433870772	32373	Economy	6900.00
0005434175862	32373	Economy	6900.00
0005433870752	32373	Economy	6900.00
0005434175859	32373	Economy	6900.00
0005433870762	32373	Economy	6900.00
0005434175860	32373	Economy	6900.00
0005433870764	32373	Economy	6900.00
0005433870776	32373	Economy	6900.00
0005434175863	32373	Economy	6900.00
0005435902956	3498	Business	35000.00
0005435913995	3498	Business	35000.00
0005434427348	3498	Business	35000.00
0005435841104	3498	Business	35000.00
0005432800182	3498	Business	35000.00
0005434880654	3498	Business	35000.00
0005434880656	3498	Business	35000.00
0005435626641	3498	Business	35000.00
0005435626659	3498	Business	35000.00
0005434880682	3498	Business	35000.00
0005434880659	3498	Business	35000.00
0005434938638	3498	Business	35000.00
0005434880667	3498	Business	35000.00
0005435913985	3498	Business	35000.00
0005434880609	3498	Business	35000.00
0005434880620	3498	Business	35000.00
0005435902950	3498	Business	35000.00
0005434880651	3498	Business	35000.00
0005432800176	3498	Business	35000.00
0005434880665	3498	Business	35000.00
0005434427352	3498	Business	35000.00
0005435127415	3498	Comfort	19900.00
0005435127408	3498	Comfort	19900.00
0005434880663	3498	Comfort	19900.00
0005434427359	3498	Comfort	19900.00
0005432800167	3498	Comfort	19900.00
0005435127416	3498	Comfort	19900.00
0005434880596	3498	Comfort	19900.00
0005434880626	3498	Comfort	19900.00
0005434880601	3498	Comfort	19900.00
0005435127406	3498	Comfort	19900.00
0005432188691	3498	Comfort	19900.00
0005435626642	3498	Comfort	19900.00
0005435626655	3498	Comfort	19900.00
0005434880637	3498	Comfort	19900.00
0005434880638	3498	Comfort	19900.00
0005435127398	3498	Comfort	19900.00
0005434880639	3498	Comfort	19900.00
0005435127401	3498	Comfort	19900.00
0005435127422	3498	Comfort	19900.00
0005432613965	3498	Comfort	19900.00
0005434880630	3498	Comfort	19900.00
0005434880624	3498	Comfort	19900.00
0005435626660	3498	Comfort	19900.00
0005435913984	3498	Comfort	19900.00
0005434427346	3498	Comfort	19900.00
0005435626647	3498	Comfort	19900.00
0005434880647	3498	Comfort	19900.00
0005434880676	3498	Comfort	19900.00
0005434427366	3498	Comfort	19900.00
0005434880650	3498	Comfort	19900.00
0005434938631	3498	Comfort	19900.00
0005435127412	3498	Economy	11700.00
0005434938634	3498	Economy	11700.00
0005434880619	3498	Economy	11700.00
0005434880652	3498	Economy	11700.00
0005432800171	3498	Economy	11700.00
0005434880681	3498	Economy	11700.00
0005434938637	3498	Economy	11700.00
0005434880606	3498	Economy	11700.00
0005434427362	3498	Economy	11700.00
0005434880653	3498	Economy	11700.00
0005432800193	3498	Economy	11700.00
0005434880649	3498	Economy	11700.00
0005435127424	3498	Economy	11700.00
0005435903011	3498	Economy	11700.00
0005434880618	3498	Economy	11700.00
0005434880636	3498	Economy	11700.00
0005435127417	3498	Economy	11700.00
0005434880625	3498	Economy	11700.00
0005435903010	3498	Economy	11700.00
0005434427347	3498	Economy	11700.00
0005434880671	3498	Economy	11700.00
0005434880622	3498	Economy	11700.00
0005434880645	3498	Economy	11700.00
0005434880617	3498	Economy	11700.00
0005432800169	3498	Economy	11700.00
0005432800186	3498	Economy	11700.00
0005434938639	3498	Economy	11700.00
0005434427370	3498	Economy	11700.00
0005435127421	3498	Economy	11700.00
0005434880660	3498	Economy	11700.00
0005434880646	3498	Economy	11700.00
0005434880614	3498	Economy	11700.00
0005434880674	3498	Economy	11700.00
0005432800172	3498	Economy	11700.00
0005432800179	3498	Economy	11700.00
0005432188690	3498	Economy	11700.00
0005434938636	3498	Economy	11700.00
0005435127423	3498	Economy	11700.00
0005434880668	3498	Economy	11700.00
0005435127394	3498	Economy	11700.00
0005435626645	3498	Economy	11700.00
0005432800189	3498	Economy	11700.00
0005432800177	3498	Economy	11700.00
0005434938646	3498	Economy	11700.00
0005434880598	3498	Economy	12800.00
0005435127409	3498	Economy	12800.00
0005434427364	3498	Economy	11700.00
0005434880672	3498	Economy	12800.00
0005434427368	3498	Economy	11700.00
0005435626663	3498	Economy	11700.00
0005434880662	3498	Economy	12800.00
0005432800192	3498	Economy	12800.00
0005435914713	3498	Economy	12800.00
0005434427360	3498	Economy	11700.00
0005432800174	3498	Economy	11700.00
0005435127395	3498	Economy	11700.00
0005434880604	3498	Economy	11700.00
0005434880599	3498	Economy	11700.00
0005432800168	3498	Economy	11700.00
0005434880600	3498	Economy	11700.00
0005432800190	3498	Economy	11700.00
0005435913987	3498	Economy	11700.00
0005435626649	3498	Economy	11700.00
0005435626653	3498	Economy	11700.00
0005434880677	3498	Economy	11700.00
0005434880640	3498	Economy	11700.00
0005432800191	3498	Economy	11700.00
0005435127425	3498	Economy	11700.00
0005434427357	3498	Economy	11700.00
0005434880675	3498	Economy	11700.00
0005434880633	3498	Economy	11700.00
0005434938643	3498	Economy	11700.00
0005434880611	3498	Economy	11700.00
0005435626651	3498	Economy	11700.00
0005434427369	3498	Economy	11700.00
0005435127420	3498	Economy	11700.00
0005434427354	3498	Economy	11700.00
0005432613968	3498	Economy	11700.00
0005434880648	3498	Economy	11700.00
0005435127400	3498	Economy	11700.00
0005435127426	3498	Economy	11700.00
0005435127404	3498	Economy	11700.00
0005434880605	3498	Economy	11700.00
0005434427372	3498	Economy	11700.00
0005435914711	3498	Economy	11700.00
0005434938632	3498	Economy	11700.00
0005435902962	3498	Economy	11700.00
0005435903045	3498	Economy	11700.00
0005432800184	3498	Economy	11700.00
0005434427373	3498	Economy	11700.00
0005434880657	3498	Economy	11700.00
0005434427365	3498	Economy	11700.00
0005435902982	3498	Economy	11700.00
0005432800185	3498	Economy	11700.00
0005435626656	3498	Economy	11700.00
0005435913991	3498	Economy	11700.00
0005434880603	3498	Economy	11700.00
0005434880680	3498	Economy	11700.00
0005434880661	3498	Economy	11700.00
0005435626644	3498	Economy	11700.00
0005434938645	3498	Economy	11700.00
0005434880669	3498	Economy	11700.00
0005434880616	3498	Economy	11700.00
0005434880635	3498	Economy	11700.00
0005434427363	3498	Economy	11700.00
0005432800175	3498	Economy	11700.00
0005435626662	3498	Economy	11700.00
0005434880670	3498	Economy	11700.00
0005434880643	3498	Economy	11700.00
0005434880678	3498	Economy	11700.00
0005434938640	3498	Economy	11700.00
0005435127410	3498	Economy	11700.00
0005435127413	3498	Economy	11700.00
0005434880629	3498	Economy	11700.00
0005435626657	3498	Economy	11700.00
0005435914712	3498	Economy	11700.00
0005434880631	3498	Economy	11700.00
0005434880612	3498	Economy	11700.00
0005432183523	3498	Economy	11700.00
0005434880613	3498	Economy	11700.00
0005435913989	3498	Economy	11700.00
0005434880679	3498	Economy	11700.00
0005435626654	3498	Economy	11700.00
0005435841117	3498	Economy	11700.00
0005434938644	3498	Economy	12800.00
0005434427361	3498	Economy	11700.00
0005432613969	3498	Economy	12800.00
0005434427367	3498	Economy	11700.00
0005434427349	3498	Economy	11700.00
0005435127397	3498	Economy	11700.00
0005434427356	3498	Economy	11700.00
0005434880658	3498	Economy	11700.00
0005434880623	3498	Economy	11700.00
0005435127427	3498	Economy	11700.00
0005434880602	3498	Economy	11700.00
0005432800194	3498	Economy	11700.00
0005434880615	3498	Economy	11700.00
0005434880673	3498	Economy	11700.00
0005435127407	3498	Economy	11700.00
0005432800178	3498	Economy	11700.00
0005432188692	3498	Economy	11700.00
0005435127399	3498	Economy	11700.00
0005435127419	3498	Economy	11700.00
0005435626658	3498	Economy	11700.00
0005434880632	3498	Economy	11700.00
0005435626648	3498	Economy	11700.00
0005434938649	3498	Economy	11700.00
0005435626652	3498	Economy	11700.00
0005434427350	3498	Economy	11700.00
0005434880664	3498	Economy	11700.00
0005435902963	3498	Economy	11700.00
0005435127403	3498	Economy	11700.00
0005434427351	3498	Economy	11700.00
0005434880628	3498	Economy	11700.00
0005435127418	3498	Economy	11700.00
0005434427355	3498	Economy	11700.00
0005434427353	3498	Economy	11700.00
0005434938635	3498	Economy	11700.00
0005435127396	3498	Economy	11700.00
0005435626643	3498	Economy	11700.00
0005435127411	3498	Economy	11700.00
0005434880642	3498	Economy	11700.00
0005434880644	3498	Economy	11700.00
0005435902951	3498	Economy	11700.00
0005434427371	3498	Economy	11700.00
0005434938642	3498	Economy	11700.00
0005434880595	3498	Economy	11700.00
0005432800188	3498	Economy	11700.00
0005432800181	3498	Economy	11700.00
0005435127402	3498	Economy	11700.00
0005434938630	3498	Economy	11700.00
0005432613966	3498	Economy	11700.00
0005435902964	3498	Economy	11700.00
0005432800187	3498	Economy	11700.00
0005434880608	3498	Economy	11700.00
0005435902999	3498	Economy	11700.00
0005434938633	3498	Economy	11700.00
0005432611802	3498	Economy	11700.00
0005434880597	3498	Economy	11700.00
0005432800183	3498	Economy	11700.00
0005434880627	3498	Economy	11700.00
0005434938641	3498	Economy	11700.00
0005435626661	3498	Economy	11700.00
0005435913986	3498	Economy	11700.00
0005432800180	3498	Economy	11700.00
0005435127414	3498	Economy	11700.00
0005434880621	3498	Economy	11700.00
0005435902947	3498	Economy	11700.00
0005434880666	3498	Economy	11700.00
0005435626665	3498	Economy	11700.00
0005434938648	3498	Economy	11700.00
0005434880641	3498	Economy	11700.00
0005434880610	3498	Economy	11700.00
0005435626650	3498	Economy	11700.00
0005434880634	3498	Economy	11700.00
0005434880655	3498	Economy	11700.00
0005435626664	3498	Economy	11700.00
0005434427358	3498	Economy	11700.00
0005432613967	3498	Economy	11700.00
0005434938647	3498	Economy	11700.00
0005432800170	3498	Economy	11700.00
0005435127405	3498	Economy	11700.00
0005434880607	3498	Economy	11700.00
0005432800173	3498	Economy	11700.00
0005435626646	3498	Economy	11700.00
0005435902955	3498	Economy	11700.00
0005434879908	14558	Business	35000.00
0005434879875	14558	Business	35000.00
0005434880004	14558	Business	35000.00
0005434426952	14558	Business	35000.00
0005432799920	14558	Business	35000.00
0005432799921	14558	Business	35000.00
0005432800163	14558	Business	35000.00
0005434427206	14558	Business	35000.00
0005434879332	14558	Business	35000.00
0005434879770	14558	Business	35000.00
0005434880167	14558	Business	35000.00
0005434879565	14558	Business	35000.00
0005435914753	14558	Business	35000.00
0005432799893	14558	Business	35000.00
0005434879808	14558	Business	35000.00
0005435127076	14558	Business	35000.00
0005432799828	14558	Business	35000.00
0005435126958	14558	Business	35000.00
0005435914103	14558	Business	35000.00
0005435903152	14558	Business	35000.00
0005432799960	14558	Business	35000.00
0005435903163	14558	Business	35000.00
0005432607618	14558	Business	35000.00
0005434879918	14558	Business	35000.00
0005434879930	14558	Comfort	19900.00
0005435626434	14558	Comfort	19900.00
0005435914110	14558	Comfort	19900.00
0005432611770	14558	Comfort	19900.00
0005435914107	14558	Comfort	19900.00
0005432799918	14558	Comfort	19900.00
0005435903156	14558	Comfort	19900.00
0005435914108	14558	Comfort	19900.00
0005432799830	14558	Comfort	19900.00
0005432607636	14558	Comfort	19900.00
0005434879566	14558	Comfort	19900.00
0005434879769	14558	Comfort	19900.00
0005435903148	14558	Comfort	19900.00
0005434427033	14558	Comfort	19900.00
0005434879449	14558	Comfort	19900.00
0005434427031	14558	Comfort	19900.00
0005435127005	14558	Comfort	19900.00
0005434938434	14558	Comfort	19900.00
0005434879452	14558	Comfort	19900.00
0005435841846	14558	Comfort	19900.00
0005435626440	14558	Comfort	19900.00
0005434879934	14558	Comfort	19900.00
0005434879909	14558	Comfort	19900.00
0005435903150	14558	Comfort	19900.00
0005434879893	14558	Comfort	19900.00
0005435914748	14558	Comfort	19900.00
0005435626437	14558	Comfort	19900.00
0005434879646	14558	Comfort	19900.00
0005434427065	14558	Comfort	19900.00
0005434879567	14558	Comfort	19900.00
0005435914100	14558	Comfort	19900.00
0005434880186	14558	Comfort	19900.00
0005434879768	14558	Comfort	19900.00
0005435127074	14558	Comfort	19900.00
0005434938519	14558	Comfort	19900.00
0005434938488	14558	Economy	11700.00
0005434879785	14558	Economy	11700.00
0005434879786	14558	Economy	11700.00
0005434880093	14558	Economy	11700.00
0005432611776	14558	Economy	11700.00
0005434879222	14558	Economy	11700.00
0005435903153	14558	Economy	11700.00
0005434879612	14558	Economy	11700.00
0005434879960	14558	Economy	11700.00
0005435127041	14558	Economy	11700.00
0005432799929	14558	Economy	11700.00
0005435126945	14558	Economy	11700.00
0005434879416	14558	Economy	11700.00
0005434879944	14558	Economy	11700.00
0005435626459	14558	Economy	11700.00
0005432607612	14558	Economy	11700.00
0005434938494	14558	Economy	11700.00
0005432799917	14558	Economy	11700.00
0005435914112	14558	Economy	11700.00
0005434879554	14558	Economy	11700.00
0005434879541	14558	Economy	11700.00
0005435903157	14558	Economy	11700.00
0005435914106	14558	Economy	11700.00
0005432799877	14558	Economy	11700.00
0005434938495	14558	Economy	11700.00
0005435626439	14558	Economy	11700.00
0005435127073	14558	Economy	11700.00
0005435914098	14558	Economy	11700.00
0005432799931	14558	Economy	11700.00
0005435914105	14558	Economy	11700.00
0005432800031	14558	Economy	11700.00
0005435903164	14558	Economy	11700.00
0005435626474	14558	Economy	11700.00
0005432799892	14558	Economy	11700.00
0005435914104	14558	Economy	11700.00
0005434879688	14558	Economy	11700.00
0005435626460	14558	Economy	11700.00
0005435626450	14558	Economy	11700.00
0005434879755	14558	Economy	11700.00
0005434427181	14558	Economy	11700.00
0005434880101	14558	Economy	11700.00
0005435127032	14558	Economy	11700.00
0005434879873	14558	Economy	11700.00
0005434879969	14558	Economy	11700.00
0005432799919	14558	Economy	11700.00
0005434879945	14558	Economy	11700.00
0005434938509	14558	Economy	11700.00
0005434938554	14558	Economy	11700.00
0005435127112	14558	Economy	11700.00
0005435914111	14558	Economy	11700.00
0005434880157	14558	Economy	11700.00
0005434880083	14558	Economy	11700.00
0005434879917	14558	Economy	11700.00
0005434427153	14558	Economy	11700.00
0005435127010	14558	Economy	11700.00
0005435914752	14558	Economy	11700.00
0005435127177	14558	Economy	11700.00
0005434879555	14558	Economy	12800.00
0005435903149	14558	Economy	12800.00
0005434879986	14558	Economy	11700.00
0005435626457	14558	Economy	11700.00
0005434879788	14558	Economy	11700.00
0005434879829	14558	Economy	12800.00
0005434880090	14558	Economy	12800.00
0005434879957	14558	Economy	11700.00
0005435126995	14558	Economy	11700.00
0005435127140	14558	Economy	11700.00
0005434879929	14558	Economy	11700.00
0005434879745	14558	Economy	11700.00
0005435626478	14558	Economy	11700.00
0005435127119	14558	Economy	11700.00
0005434879886	14558	Economy	11700.00
0005434427105	14558	Economy	11700.00
0005434879585	14558	Economy	11700.00
0005435126900	14558	Economy	11700.00
0005434427207	14558	Economy	11700.00
0005435126891	14558	Economy	11700.00
0005435127200	14558	Economy	11700.00
0005434879614	14558	Economy	11700.00
0005432607634	14558	Economy	11700.00
0005432799827	14558	Economy	11700.00
0005434879444	14558	Economy	11700.00
0005432607632	14558	Economy	11700.00
0005434879761	14558	Economy	11700.00
0005432799891	14558	Economy	11700.00
0005434879885	14558	Economy	11700.00
0005434938484	14558	Economy	11700.00
0005432799898	14558	Economy	11700.00
0005434879943	14558	Economy	11700.00
0005432607633	14558	Economy	11700.00
0005432607635	14558	Economy	11700.00
0005435126890	14558	Economy	11700.00
0005434879817	14558	Economy	11700.00
0005435903159	14558	Economy	11700.00
0005434879358	14558	Economy	11700.00
0005434938537	14558	Economy	11700.00
0005435126826	14558	Economy	11700.00
0005435914097	14558	Economy	11700.00
0005435914101	14558	Economy	11700.00
0005435127007	14558	Economy	11700.00
0005435903154	14558	Economy	11700.00
0005435914099	14558	Economy	11700.00
0005434427182	14558	Economy	11700.00
0005435127141	14558	Economy	11700.00
0005435626451	14558	Economy	11700.00
0005432799897	14558	Economy	11700.00
0005432799988	14558	Economy	11700.00
0005435127120	14558	Economy	11700.00
0005434427189	14558	Economy	11700.00
0005434879451	14558	Economy	11700.00
0005435626472	14558	Economy	11700.00
0005432799928	14558	Economy	11700.00
0005434427104	14558	Economy	11700.00
0005435127159	14558	Economy	11700.00
0005435914109	14558	Economy	11700.00
0005434880185	14558	Economy	11700.00
0005435126957	14558	Economy	11700.00
0005432611769	14558	Economy	11700.00
0005434879423	14558	Economy	11700.00
0005434879450	14558	Economy	11700.00
0005435626435	14558	Economy	11700.00
0005434879388	14558	Economy	11700.00
0005434879984	14558	Economy	11700.00
0005434880048	14558	Economy	11700.00
0005432799951	14558	Economy	11700.00
0005434880082	14558	Economy	11700.00
0005434427106	14558	Economy	11700.00
0005434879706	14558	Economy	11700.00
0005434427139	14558	Economy	11700.00
0005432799798	14558	Economy	11700.00
0005434879831	14558	Economy	11700.00
0005434880100	14558	Economy	11700.00
0005435127039	14558	Economy	11700.00
0005434879816	14558	Economy	11700.00
0005434427064	14558	Economy	11700.00
0005434879687	14558	Economy	11700.00
0005434879737	14558	Economy	11700.00
0005435126984	14558	Economy	11700.00
0005434938589	14558	Economy	11700.00
0005435127199	14558	Economy	11700.00
0005432607637	14558	Economy	11700.00
0005434427103	14558	Economy	11700.00
0005435127012	14558	Economy	11700.00
0005432799950	14558	Economy	11700.00
0005435903151	14558	Economy	11700.00
0005434879787	14558	Economy	11700.00
0005435126899	14558	Economy	11700.00
0005435626438	14558	Economy	11700.00
0005434938590	14558	Economy	12800.00
0005435626458	14558	Economy	12800.00
0005434879686	14558	Economy	12800.00
0005435127084	14558	Economy	12800.00
0005435914102	14558	Economy	11700.00
0005434938419	14558	Economy	11700.00
0005434879874	14558	Economy	11700.00
0005435127121	14558	Economy	11700.00
0005435127011	14558	Economy	11700.00
0005435914751	14558	Economy	11700.00
0005434880187	14558	Economy	11700.00
0005435626469	14558	Economy	11700.00
0005434879910	14558	Economy	11700.00
0005432799926	14558	Economy	11700.00
0005434879887	14558	Economy	11700.00
0005434879613	14558	Economy	11700.00
0005435127018	14558	Economy	11700.00
0005435127006	14558	Economy	11700.00
0005435903161	14558	Economy	11700.00
0005434879896	14558	Economy	11700.00
0005432799930	14558	Economy	11700.00
0005434879754	14558	Economy	11700.00
0005434880134	14558	Economy	11700.00
0005435626452	14558	Economy	11700.00
0005432799959	14558	Economy	11700.00
0005434427188	14558	Economy	11700.00
0005434938510	14558	Economy	11700.00
0005434879645	14558	Economy	11700.00
0005435127148	14558	Economy	11700.00
0005434879866	14558	Economy	11700.00
0005435903155	14558	Economy	11700.00
0005435626441	14558	Economy	11700.00
0005434427032	14558	Economy	11700.00
0005432799993	14558	Economy	11700.00
0005434879672	14558	Economy	11700.00
0005434427143	14558	Economy	11700.00
0005435903158	14558	Economy	11700.00
0005432799923	14558	Economy	11700.00
0005434880005	14558	Economy	11700.00
0005434427175	14558	Economy	11700.00
0005435127075	14558	Economy	11700.00
0005434879542	14558	Economy	11700.00
0005435903162	14558	Economy	11700.00
0005435903165	14558	Economy	11700.00
0005434879750	14558	Economy	11700.00
0005434879801	14558	Economy	11700.00
0005434427179	14558	Economy	11700.00
0005434880089	14558	Economy	11700.00
0005435126971	14558	Economy	11700.00
0005434879830	14558	Economy	11700.00
0005432799934	14558	Economy	11700.00
0005435127133	14558	Economy	11700.00
0005432799864	14558	Economy	11700.00
0005434880166	14558	Economy	11700.00
0005434938496	14558	Economy	11700.00
0005435914749	14558	Economy	11700.00
0005435126959	14558	Economy	11700.00
0005435127108	14558	Economy	11700.00
0005435126921	14558	Economy	11700.00
0005435127113	14558	Economy	11700.00
0005434880102	14558	Economy	11700.00
0005432799831	14558	Economy	11700.00
0005435126897	14558	Economy	11700.00
0005435127045	14558	Economy	11700.00
0005434879592	14558	Economy	11700.00
0005434938458	14558	Economy	11700.00
0005434938435	14558	Economy	11700.00
0005435914750	14558	Economy	11700.00
0005435126946	14558	Economy	11700.00
0005434879899	14558	Economy	11700.00
0005432799989	14558	Economy	11700.00
0005434938489	14558	Economy	11700.00
0005432059556	14558	Economy	11700.00
0005434938500	14558	Economy	11700.00
0005434879776	14558	Economy	11700.00
0005434938518	14558	Economy	11700.00
0005435126989	14558	Economy	11700.00
0005434427176	14558	Economy	11700.00
0005435903160	14558	Economy	11700.00
0005434938454	14558	Economy	11700.00
0005434427142	14558	Economy	11700.00
0005434325947	3603	Economy	16300.00
0005434325944	3603	Economy	14800.00
0005434325943	3603	Economy	14800.00
0005434325946	3603	Economy	14800.00
0005435889996	3603	Economy	14800.00
0005435889969	3603	Economy	14800.00
0005435889961	3603	Economy	14800.00
0005434325942	3603	Economy	14800.00
0005434312372	3603	Economy	14800.00
0005434325940	3603	Economy	14800.00
0005434325945	3603	Economy	14800.00
0005435889962	3603	Economy	14800.00
0005434325938	3603	Economy	14800.00
0005434312389	3603	Economy	14800.00
0005435890002	3603	Economy	14800.00
0005435889970	3603	Economy	14800.00
0005434312390	3603	Economy	14800.00
0005435889999	3603	Economy	14800.00
0005434325941	3603	Economy	14800.00
0005434325939	3603	Economy	14800.00
0005435890049	15592	Economy	16300.00
0005435890054	15592	Economy	16300.00
0005434325906	15592	Economy	14800.00
0005434325828	15592	Economy	14800.00
0005435890052	15592	Economy	14800.00
0005435890051	15592	Economy	14800.00
0005435890050	15592	Economy	14800.00
0005434325829	15592	Economy	14800.00
0005434325888	15592	Economy	14800.00
0005434325849	15592	Economy	14800.00
0005435890053	15592	Economy	14800.00
0005434325855	15592	Economy	14800.00
0005434325845	15592	Economy	14800.00
0005434325907	15592	Economy	14800.00
0005434325859	15592	Economy	14800.00
0005434325887	15592	Economy	14800.00
0005434325844	15592	Economy	14800.00
0005434325857	15592	Economy	14800.00
0005435958080	664	Economy	4100.00
0005433420531	664	Economy	4100.00
0005435958077	664	Economy	4100.00
0005433420507	664	Economy	4100.00
0005433420521	664	Economy	4100.00
0005433420569	664	Economy	4100.00
0005435958076	664	Economy	4100.00
0005435958074	664	Economy	4100.00
0005433420538	664	Economy	4100.00
0005435958073	664	Economy	4100.00
0005435958084	664	Economy	4100.00
0005435958079	664	Economy	4100.00
0005433420530	664	Economy	4100.00
0005435958083	664	Economy	4100.00
0005435958078	664	Economy	4100.00
0005433420520	664	Economy	4100.00
0005433420544	664	Economy	4100.00
0005433420543	664	Economy	4100.00
0005435958075	664	Economy	4100.00
0005435958081	664	Economy	4100.00
0005435958082	664	Economy	4100.00
0005435957936	15205	Economy	4500.00
0005435957910	15205	Economy	4500.00
0005435957878	15205	Economy	4500.00
0005435957939	15205	Economy	4100.00
0005435957949	15205	Economy	4100.00
0005433420623	15205	Economy	4100.00
0005433420622	15205	Economy	4100.00
0005433420621	15205	Economy	4100.00
0005433420617	15205	Economy	4100.00
0005435957966	15205	Economy	4100.00
0005435957957	15205	Economy	4100.00
0005435957940	15205	Economy	4100.00
0005435957967	15205	Economy	4100.00
0005435957868	15205	Economy	4100.00
0005435957896	15205	Economy	4100.00
0005433420619	15205	Economy	4100.00
0005433420620	15205	Economy	4100.00
0005435957950	15205	Economy	4100.00
0005435957941	15205	Economy	4100.00
0005433420618	15205	Economy	4100.00
0005435957971	15205	Economy	4100.00
0005435957965	15205	Economy	4100.00
0005435957897	15205	Economy	4100.00
0005435219234	27269	Economy	28100.00
0005435219232	27269	Economy	28100.00
0005435221068	27269	Economy	28100.00
0005435219231	27269	Economy	25500.00
0005435216608	27269	Economy	25500.00
0005435219221	27269	Economy	25500.00
0005435216620	27269	Economy	25500.00
0005435216614	27269	Economy	25500.00
0005435219240	27269	Economy	25500.00
0005435219222	27269	Economy	25500.00
0005435219235	27269	Economy	25500.00
0005435219224	27269	Economy	25500.00
0005435216616	27269	Economy	25500.00
0005435216609	27269	Economy	25500.00
0005435216617	27269	Economy	25500.00
0005435216615	27269	Economy	25500.00
0005435219236	27269	Economy	25500.00
0005435219233	27269	Economy	25500.00
0005435216610	27269	Economy	25500.00
0005435217762	31781	Economy	28100.00
0005435217763	31781	Economy	28100.00
0005435216637	31781	Economy	25500.00
0005435216642	31781	Economy	25500.00
0005435217768	31781	Economy	25500.00
0005435217765	31781	Economy	25500.00
0005435217766	31781	Economy	25500.00
0005435216638	31781	Economy	25500.00
0005435216643	31781	Economy	25500.00
0005435216644	31781	Economy	25500.00
0005435218140	31781	Economy	25500.00
0005435217761	31781	Economy	25500.00
0005435218134	31781	Economy	25500.00
0005435218141	31781	Economy	25500.00
0005435218135	31781	Economy	25500.00
0005435216640	31781	Economy	25500.00
0005435217769	31781	Economy	25500.00
0005435218138	31781	Economy	25500.00
0005435217767	31781	Economy	25500.00
0005435216641	31781	Economy	25500.00
0005435217764	31781	Economy	25500.00
0005435218137	31781	Economy	25500.00
0005435216639	31781	Economy	25500.00
0005435218139	31781	Economy	25500.00
0005435218136	31781	Economy	25500.00
0005435216636	31781	Economy	25500.00
0005435629439	8877	Economy	10400.00
0005434247191	8877	Economy	10400.00
0005435629441	8877	Economy	10400.00
0005434247181	8877	Economy	10400.00
0005435629440	8877	Economy	10400.00
0005435629435	16111	Economy	10400.00
0005434247213	16111	Economy	10400.00
0005435629432	16111	Economy	10400.00
0005434247215	16111	Economy	10400.00
0005435629436	16111	Economy	10400.00
0005434247214	16111	Economy	10400.00
0005434467817	4017	Economy	21200.00
0005434467819	4017	Economy	21200.00
0005434467823	4017	Economy	21200.00
0005434467822	4017	Economy	21200.00
0005434467821	4017	Economy	21200.00
0005434467816	4017	Economy	21200.00
0005434467820	4017	Economy	21200.00
0005434467815	4017	Economy	21200.00
0005434467818	4017	Economy	21200.00
0005434467796	23217	Economy	23400.00
0005434467803	23217	Economy	23400.00
0005434467791	23217	Economy	21200.00
0005434467794	23217	Economy	21200.00
0005434467789	23217	Economy	21200.00
0005434467793	23217	Economy	21200.00
0005434467795	23217	Economy	21200.00
0005434467797	23217	Economy	21200.00
0005434467804	23217	Economy	21200.00
0005435163368	4431	Economy	13400.00
0005435163355	4431	Economy	12200.00
0005435933508	4431	Economy	12200.00
0005435163362	4431	Economy	12200.00
0005435933503	4431	Economy	12200.00
0005435163358	4431	Economy	12200.00
0005435163360	4431	Economy	12200.00
0005435163359	4431	Economy	12200.00
0005435163354	4431	Economy	12200.00
0005435163361	4431	Economy	12200.00
0005435163365	4431	Economy	12200.00
0005435163366	4431	Economy	12200.00
0005435163363	4431	Economy	12200.00
0005435933499	4431	Economy	12200.00
0005435933498	4431	Economy	12200.00
0005435163356	4431	Economy	12200.00
0005435163364	4431	Economy	12200.00
0005435163369	4431	Economy	12200.00
0005435163357	4431	Economy	12200.00
0005435933509	4431	Economy	12200.00
0005435163367	4431	Economy	12200.00
0005435163318	29520	Economy	13400.00
0005435163313	29520	Economy	13400.00
0005435933545	29520	Economy	13400.00
0005435163314	29520	Economy	12200.00
0005435933547	29520	Economy	12200.00
0005435163312	29520	Economy	12200.00
0005435163300	29520	Economy	12200.00
0005435163310	29520	Economy	12200.00
0005435933540	29520	Economy	12200.00
0005435933543	29520	Economy	12200.00
0005435163325	29520	Economy	12200.00
0005435163301	29520	Economy	12200.00
0005435163327	29520	Economy	12200.00
0005435163340	29520	Economy	12200.00
0005435933541	29520	Economy	12200.00
0005435933542	29520	Economy	12200.00
0005435933539	29520	Economy	12200.00
0005435933546	29520	Economy	12200.00
0005435933544	29520	Economy	12200.00
0005432646319	6836	Business	87700.00
0005432646297	6836	Business	87700.00
0005432646324	6836	Business	87700.00
0005435229530	6836	Business	87700.00
0005432646292	6836	Business	87700.00
0005432646310	6836	Business	87700.00
0005435229531	6836	Business	87700.00
0005435229550	6836	Business	87700.00
0005432646290	6836	Business	87700.00
0005432646293	6836	Business	87700.00
0005432646316	6836	Business	87700.00
0005432646312	6836	Business	87700.00
0005435229557	6836	Economy	29200.00
0005435229497	6836	Economy	29200.00
0005435229549	6836	Economy	29200.00
0005432646286	6836	Economy	29200.00
0005432646291	6836	Economy	29200.00
0005432646295	6836	Economy	29200.00
0005432646325	6836	Economy	29200.00
0005432646304	6836	Economy	29200.00
0005432646331	6836	Economy	29200.00
0005435229548	6836	Economy	29200.00
0005435229523	6836	Economy	32200.00
0005435229520	6836	Economy	32200.00
0005432646296	6836	Economy	32200.00
0005432646323	6836	Economy	32200.00
0005432646289	6836	Economy	32200.00
0005435229513	6836	Economy	29200.00
0005435229553	6836	Economy	29200.00
0005432646303	6836	Economy	29200.00
0005435229526	6836	Economy	29200.00
0005432646327	6836	Economy	29200.00
0005435229541	6836	Economy	29200.00
0005432646329	6836	Economy	29200.00
0005435229492	6836	Economy	29200.00
0005432646288	6836	Economy	29200.00
0005432646300	6836	Economy	29200.00
0005432646283	6836	Economy	29200.00
0005432646314	6836	Economy	29200.00
0005432646326	6836	Economy	29200.00
0005432646298	6836	Economy	29200.00
0005432646285	6836	Economy	29200.00
0005432646282	6836	Economy	29200.00
0005435229535	6836	Economy	29200.00
0005432646317	6836	Economy	29200.00
0005432646311	6836	Economy	29200.00
0005432646287	6836	Economy	29200.00
0005432646294	6836	Economy	29200.00
0005432646308	6836	Economy	29200.00
0005432646307	6836	Economy	29200.00
0005432646309	6836	Economy	29200.00
0005432646302	6836	Economy	29200.00
0005432646284	6836	Economy	29200.00
0005435229552	6836	Economy	29200.00
0005435229529	6836	Economy	29200.00
0005432646318	6836	Economy	29200.00
0005432646313	6836	Economy	29200.00
0005432646281	6836	Economy	29200.00
0005435229536	6836	Economy	29200.00
0005435229532	6836	Economy	29200.00
0005432646306	6836	Economy	29200.00
0005432646321	6836	Economy	29200.00
0005432646332	6836	Economy	29200.00
0005432646328	6836	Economy	29200.00
0005435229533	6836	Economy	29200.00
0005432646322	6836	Economy	29200.00
0005435229511	6836	Economy	29200.00
0005432646301	6836	Economy	29200.00
0005432646305	6836	Economy	29200.00
0005432646320	6836	Economy	29200.00
0005435229543	6836	Economy	29200.00
0005435229560	6836	Economy	29200.00
0005435229571	6836	Economy	29200.00
0005435229554	6836	Economy	29200.00
0005435229521	6836	Economy	29200.00
0005432646315	6836	Economy	29200.00
0005432646280	6836	Economy	29200.00
0005435229527	6836	Economy	29200.00
0005435229528	6836	Economy	29200.00
0005435229540	6836	Economy	29200.00
0005432646330	6836	Economy	29200.00
0005435229522	6836	Economy	29200.00
0005435229542	6836	Economy	29200.00
0005432646299	6836	Economy	29200.00
0005435797843	2860	Business	12600.00
0005435797838	2860	Economy	4200.00
0005435797841	2860	Economy	4200.00
0005435797831	2860	Economy	4200.00
0005435797834	2860	Economy	4200.00
0005435797842	2860	Economy	4200.00
0005433404959	2860	Economy	4200.00
0005435797835	2860	Economy	4200.00
0005435797836	2860	Economy	4200.00
0005433404933	2860	Economy	4200.00
0005435797839	2860	Economy	4200.00
0005433404922	2860	Economy	4200.00
0005435797832	2860	Economy	4200.00
0005433404926	2860	Economy	4200.00
0005435797837	2860	Economy	4200.00
0005435797833	2860	Economy	4200.00
0005435797840	2860	Economy	4200.00
0005433404925	2860	Economy	4200.00
0005433404924	2860	Economy	4200.00
0005435797692	29322	Business	12600.00
0005433404998	29322	Business	12600.00
0005435797750	29322	Economy	4200.00
0005433405000	29322	Economy	4200.00
0005435797710	29322	Economy	4200.00
0005433405002	29322	Economy	4200.00
0005433404999	29322	Economy	4200.00
0005435797715	29322	Economy	4200.00
0005435797714	29322	Economy	4200.00
0005435797743	29322	Economy	4200.00
0005435797749	29322	Economy	4200.00
0005433405001	29322	Economy	4200.00
0005433404997	29322	Economy	4200.00
0005435376395	5768	Economy	6800.00
0005435376398	5768	Economy	6800.00
0005434948230	5782	Economy	6800.00
0005434948229	5782	Economy	6800.00
0005434948233	5782	Economy	6800.00
0005434948238	5782	Economy	6800.00
0005434948237	5782	Economy	6800.00
0005434948232	5782	Economy	6800.00
0005434948234	5782	Economy	6800.00
0005434948231	5782	Economy	6800.00
0005434948239	5782	Economy	6800.00
0005434948236	5782	Economy	6800.00
0005434948235	5782	Economy	6800.00
0005434948146	16391	Economy	6800.00
0005434948145	16391	Economy	6800.00
0005434948135	16391	Economy	6800.00
0005434948134	16391	Economy	6800.00
0005434948143	16391	Economy	6800.00
0005434948133	16391	Economy	6800.00
0005434948163	16391	Economy	6800.00
0005434948161	16391	Economy	6800.00
0005434948160	16391	Economy	6800.00
0005434948159	16391	Economy	6800.00
0005434948162	16391	Economy	6800.00
0005434948144	16391	Economy	6800.00
0005433962337	6897	Business	21400.00
0005433962359	6897	Business	21400.00
0005433962347	6897	Business	21400.00
0005433962363	6897	Business	21400.00
0005433962355	6897	Business	21400.00
0005433962364	6897	Business	21400.00
0005433962325	6897	Business	21400.00
0005433962321	6897	Business	21400.00
0005433962323	6897	Economy	7100.00
0005433962331	6897	Economy	7100.00
0005433962344	6897	Economy	7100.00
0005433962349	6897	Economy	7100.00
0005433962333	6897	Economy	7100.00
0005433962365	6897	Economy	7100.00
0005433962373	6897	Economy	7100.00
0005433962329	6897	Economy	7100.00
0005433962377	6897	Economy	7800.00
0005433962330	6897	Economy	7800.00
0005433962345	6897	Economy	7100.00
0005433962357	6897	Economy	7100.00
0005433962381	6897	Economy	7100.00
0005433962367	6897	Economy	7100.00
0005433962380	6897	Economy	7100.00
0005433962328	6897	Economy	7100.00
0005433962369	6897	Economy	7100.00
0005433962339	6897	Economy	7100.00
0005433962378	6897	Economy	7100.00
0005433962326	6897	Economy	7100.00
0005433962376	6897	Economy	7100.00
0005433962322	6897	Economy	7100.00
0005433962336	6897	Economy	7100.00
0005433962334	6897	Economy	7100.00
0005433962351	6897	Economy	7100.00
0005433962370	6897	Economy	7100.00
0005433962358	6897	Economy	7100.00
0005433962379	6897	Economy	7100.00
0005433962360	6897	Economy	7100.00
0005433962340	6897	Economy	7100.00
0005433962368	6897	Economy	7100.00
0005433962375	6897	Economy	7100.00
0005433962353	6897	Economy	7100.00
0005433962342	6897	Economy	7100.00
0005433962324	6897	Economy	7100.00
0005433962332	6897	Economy	7100.00
0005433962371	6897	Economy	7100.00
0005433962374	6897	Economy	7100.00
0005433962361	6897	Economy	7100.00
0005433962350	6897	Economy	7100.00
0005433962335	6897	Economy	7100.00
0005433962341	6897	Economy	7100.00
0005433962343	6897	Economy	7100.00
0005433962346	6897	Economy	7100.00
0005433962348	6897	Economy	7100.00
0005433962352	6897	Economy	7100.00
0005433962327	6897	Economy	7100.00
0005433962366	6897	Economy	7100.00
0005433962372	6897	Economy	7100.00
0005433962338	6897	Economy	7100.00
0005433962356	6897	Economy	7100.00
0005433962354	6897	Economy	7100.00
0005433962362	6897	Economy	7100.00
0005433961646	25815	Business	21400.00
0005433961711	25815	Business	21400.00
0005433961691	25815	Business	21400.00
0005433961784	25815	Business	21400.00
0005433961747	25815	Business	21400.00
0005433961530	25815	Business	21400.00
0005433961689	25815	Business	21400.00
0005433961832	25815	Business	21400.00
0005433961670	25815	Business	21400.00
0005433961598	25815	Economy	7100.00
0005433961522	25815	Economy	7100.00
0005433961748	25815	Economy	7100.00
0005433961770	25815	Economy	7100.00
0005433961612	25815	Economy	7100.00
0005433961687	25815	Economy	7800.00
0005433961370	25815	Economy	7800.00
0005433961726	25815	Economy	7800.00
0005433961514	25815	Economy	7800.00
0005433961525	25815	Economy	7100.00
0005433961834	25815	Economy	7100.00
0005433961638	25815	Economy	7100.00
0005433961645	25815	Economy	7100.00
0005433961667	25815	Economy	7100.00
0005433961621	25815	Economy	7100.00
0005433961810	25815	Economy	7100.00
0005433961577	25815	Economy	7100.00
0005433961764	25815	Economy	7100.00
0005433961620	25815	Economy	7100.00
0005433961771	25815	Economy	7100.00
0005433961813	25815	Economy	7100.00
0005433961797	25815	Economy	7100.00
0005433961574	25815	Economy	7100.00
0005433961639	25815	Economy	7100.00
0005433961682	25815	Economy	7100.00
0005433961647	25815	Economy	7100.00
0005433961632	25815	Economy	7100.00
0005433961576	25815	Economy	7100.00
0005433961799	25815	Economy	7100.00
0005433961701	25815	Economy	7100.00
0005433961686	25815	Economy	7100.00
0005433961591	25815	Economy	7100.00
0005433961669	25815	Economy	7100.00
0005433961743	25815	Economy	7100.00
0005433961573	25815	Economy	7100.00
0005433961779	25815	Economy	7100.00
0005433961651	25815	Economy	7100.00
0005433961592	25815	Economy	7100.00
0005433961794	25815	Economy	7100.00
0005433961531	25815	Economy	7100.00
0005433961635	25815	Economy	7100.00
0005433961633	25815	Economy	7100.00
0005433961677	25815	Economy	7100.00
0005433961640	25815	Economy	7100.00
0005433961538	25815	Economy	7100.00
0005433961532	25815	Economy	7100.00
0005433961769	25815	Economy	7100.00
0005433961814	25815	Economy	7100.00
0005433961504	25815	Economy	7100.00
0005433961688	25815	Economy	7100.00
0005433961768	25815	Economy	7100.00
0005433961706	25815	Economy	7100.00
0005435377991	24480	Economy	3900.00
0005435082920	24480	Economy	3900.00
0005435082932	24480	Economy	3900.00
0005435082921	24480	Economy	3900.00
0005435377992	24480	Economy	3900.00
0005435377993	24480	Economy	3900.00
0005435082928	24480	Economy	3900.00
0005435082936	24480	Economy	3900.00
0005435082988	26140	Economy	3900.00
0005435082986	26140	Economy	3900.00
0005435082987	26140	Economy	3900.00
0005434245727	5172	Business	18000.00
0005434245725	5172	Business	18000.00
0005432166986	5172	Business	18000.00
0005432166985	5172	Business	18000.00
0005435286722	5172	Business	18000.00
0005435286717	5172	Economy	6600.00
0005434245740	5172	Economy	6000.00
0005434245724	5172	Economy	6000.00
0005434245731	5172	Economy	6000.00
0005435286730	5172	Economy	6000.00
0005434245718	5172	Economy	6000.00
0005434245739	5172	Economy	6000.00
0005434245732	5172	Economy	6000.00
0005434245719	5172	Economy	6000.00
0005432166983	5172	Economy	6000.00
0005434245738	5172	Economy	6000.00
0005435286726	5172	Economy	6000.00
0005434245743	5172	Economy	6000.00
0005434245733	5172	Economy	6000.00
0005434245735	5172	Economy	6000.00
0005434245737	5172	Economy	6000.00
0005435286693	5172	Economy	6000.00
0005432166984	5172	Economy	6000.00
0005434245734	5172	Economy	6000.00
0005434245726	5172	Economy	6600.00
0005435286729	5172	Economy	6600.00
0005435286725	5172	Economy	6000.00
0005434245730	5172	Economy	6000.00
0005435286721	5172	Economy	6000.00
0005435286724	5172	Economy	6000.00
0005434245723	5172	Economy	6000.00
0005434245728	5172	Economy	6000.00
0005434245722	5172	Economy	6000.00
0005434245721	5172	Economy	6000.00
0005435286723	5172	Economy	6000.00
0005434245736	5172	Economy	6000.00
0005434245742	5172	Economy	6000.00
0005434245720	5172	Economy	6000.00
0005435286728	5172	Economy	6000.00
0005434245741	5172	Economy	6000.00
0005435286682	5172	Economy	6000.00
0005434245729	5172	Economy	6000.00
0005435286692	5172	Economy	6000.00
0005432106784	5178	Business	18000.00
0005432106781	5178	Business	18000.00
0005433616574	5178	Business	18000.00
0005433616555	5178	Business	18000.00
0005433616577	5178	Business	18000.00
0005433616560	5178	Business	18000.00
0005432665327	5178	Business	18000.00
0005433616590	5178	Business	18000.00
0005433616544	5178	Business	18000.00
0005433785892	5178	Business	18000.00
0005433785878	5178	Business	18000.00
0005433616569	5178	Business	18000.00
0005433616548	5178	Business	18000.00
0005432106793	5178	Business	18000.00
0005433616587	5178	Business	18000.00
0005433785863	5178	Business	18000.00
0005432106782	5178	Business	18000.00
0005433785897	5178	Business	18000.00
0005432106767	5178	Business	18000.00
0005433785877	5178	Business	18000.00
0005433616546	5178	Business	18000.00
0005432106770	5178	Business	18000.00
0005433785900	5178	Business	18000.00
0005432106772	5178	Business	18000.00
0005433616592	5178	Business	18000.00
0005433616598	5178	Business	18000.00
0005433785864	5178	Economy	6600.00
0005433616534	5178	Business	18000.00
0005433785870	5178	Economy	6600.00
0005433785869	5178	Economy	6600.00
0005433785885	5178	Economy	6600.00
0005433785879	5178	Economy	6600.00
0005433785891	5178	Economy	6600.00
0005433785867	5178	Economy	6000.00
0005433616558	5178	Economy	6000.00
0005432106800	5178	Economy	6000.00
0005433616576	5178	Economy	6000.00
0005432106773	5178	Economy	6000.00
0005433785907	5178	Economy	6000.00
0005433785875	5178	Economy	6000.00
0005433616532	5178	Economy	6000.00
0005433616552	5178	Economy	6000.00
0005433785876	5178	Economy	6000.00
0005432106766	5178	Economy	6000.00
0005432106796	5178	Economy	6000.00
0005433616581	5178	Economy	6000.00
0005433785860	5178	Economy	6000.00
0005433616554	5178	Economy	6000.00
0005433616530	5178	Economy	6000.00
0005433616557	5178	Economy	6000.00
0005433616531	5178	Economy	6000.00
0005432106769	5178	Economy	6000.00
0005432106803	5178	Economy	6000.00
0005433616578	5178	Economy	6000.00
0005432666441	5178	Economy	6000.00
0005433785908	5178	Economy	6000.00
0005432106774	5178	Economy	6000.00
0005433785865	5178	Economy	6000.00
0005433616591	5178	Economy	6000.00
0005433785904	5178	Economy	6000.00
0005433616568	5178	Economy	6000.00
0005433785871	5178	Economy	6000.00
0005433785905	5178	Economy	6000.00
0005433616573	5178	Economy	6000.00
0005433785896	5178	Economy	6000.00
0005433616565	5178	Economy	6000.00
0005433785901	5178	Economy	6000.00
0005432106799	5178	Economy	6000.00
0005433616529	5178	Economy	6000.00
0005433616597	5178	Economy	6000.00
0005433616593	5178	Economy	6000.00
0005433785868	5178	Economy	6000.00
0005433785890	5178	Economy	6000.00
0005433616549	5178	Economy	6000.00
0005432106771	5178	Economy	6000.00
0005433616596	5178	Economy	6000.00
0005433785887	5178	Economy	6000.00
0005433616595	5178	Economy	6000.00
0005433785884	5178	Economy	6000.00
0005432106798	5178	Economy	6000.00
0005433616537	5178	Economy	6000.00
0005433616561	5178	Economy	6000.00
0005433616535	5178	Economy	6000.00
0005433616542	5178	Economy	6000.00
0005433785886	5178	Economy	6000.00
0005433785861	5178	Economy	6000.00
0005433616559	5178	Economy	6000.00
0005432106776	5178	Economy	6000.00
0005433616564	5178	Economy	6000.00
0005433616582	5178	Economy	6000.00
0005432106795	5178	Economy	6000.00
0005433785895	5178	Economy	6000.00
0005432106783	5178	Economy	6000.00
0005433785906	5178	Economy	6600.00
0005433616536	5178	Economy	6600.00
0005433785914	5178	Economy	6600.00
0005432106777	5178	Economy	6600.00
0005433785873	5178	Economy	6600.00
0005433785898	5178	Economy	6000.00
0005432106790	5178	Economy	6000.00
0005432106786	5178	Economy	6000.00
0005433616527	5178	Economy	6000.00
0005433616528	5178	Economy	6600.00
0005433616579	5178	Economy	6000.00
0005433785893	5178	Economy	6000.00
0005432106791	5178	Economy	6000.00
0005433616570	5178	Economy	6000.00
0005433616545	5178	Economy	6000.00
0005432106789	5178	Economy	6000.00
0005433616575	5178	Economy	6000.00
0005432667508	5178	Economy	6000.00
0005433616566	5178	Economy	6000.00
0005432106779	5178	Economy	6000.00
0005432106804	5178	Economy	6000.00
0005433785874	5178	Economy	6000.00
0005433616571	5178	Economy	6000.00
0005432106785	5178	Economy	6000.00
0005433785913	5178	Economy	6000.00
0005433616594	5178	Economy	6000.00
0005432106768	5178	Economy	6000.00
0005433616550	5178	Economy	6000.00
0005433785912	5178	Economy	6000.00
0005433616538	5178	Economy	6000.00
0005433785888	5178	Economy	6000.00
0005433616556	5178	Economy	6000.00
0005432106802	5178	Economy	6000.00
0005432106797	5178	Economy	6000.00
0005433616567	5178	Economy	6000.00
0005433616589	5178	Economy	6000.00
0005433616580	5178	Economy	6000.00
0005432106801	5178	Economy	6000.00
0005432106778	5178	Economy	6000.00
0005433785909	5178	Economy	6000.00
0005433616533	5178	Economy	6000.00
0005433785872	5178	Economy	6000.00
0005433785911	5178	Economy	6000.00
0005432106794	5178	Economy	6000.00
0005432106780	5178	Economy	6000.00
0005433616588	5178	Economy	6000.00
0005433616585	5178	Economy	6000.00
0005433616539	5178	Economy	6000.00
0005432106788	5178	Economy	6000.00
0005433785903	5178	Economy	6000.00
0005432106787	5178	Economy	6000.00
0005433785910	5178	Economy	6000.00
0005433616541	5178	Economy	6000.00
0005433616583	5178	Economy	6000.00
0005433616551	5178	Economy	6000.00
0005433785902	5178	Economy	6000.00
0005433785866	5178	Economy	6000.00
0005433616543	5178	Economy	6000.00
0005433616540	5178	Economy	6000.00
0005433616547	5178	Economy	6000.00
0005432106775	5178	Economy	6000.00
0005433616563	5178	Economy	6000.00
0005433785882	5178	Economy	6000.00
0005433785899	5178	Economy	6000.00
0005433785894	5178	Economy	6000.00
0005433785862	5178	Economy	6000.00
0005432106792	5178	Economy	6000.00
0005433616584	5178	Economy	6000.00
0005433785881	5178	Economy	6000.00
0005433616586	5178	Economy	6000.00
0005433616553	5178	Economy	6000.00
0005433616572	5178	Economy	6000.00
0005433785880	5178	Economy	6000.00
0005433785889	5178	Economy	6000.00
0005433616562	5178	Economy	6000.00
0005433785883	5178	Economy	6000.00
0005434229936	5228	Business	18000.00
0005435007423	5228	Business	18000.00
0005435269874	5228	Business	18000.00
0005434150028	5228	Business	18000.00
0005434229953	5228	Business	18000.00
0005434312353	5228	Business	18000.00
0005434265803	5228	Business	18000.00
0005434229937	5228	Business	18000.00
0005435269823	5228	Business	18000.00
0005435269884	5228	Business	18000.00
0005434173624	5228	Business	18000.00
0005432336230	5228	Business	18000.00
0005434150035	5228	Business	18000.00
0005435007398	5228	Business	18000.00
0005434150033	5228	Business	18000.00
0005432336216	5228	Business	18000.00
0005434150036	5228	Business	18000.00
0005434150038	5228	Business	18000.00
0005434229943	5228	Business	18000.00
0005434229935	5228	Business	18000.00
0005432336234	5228	Business	18000.00
0005434150026	5228	Business	18000.00
0005432336203	5228	Economy	6600.00
0005434265801	5228	Economy	6600.00
0005434265797	5228	Economy	6600.00
0005435007443	5228	Economy	6000.00
0005432336240	5228	Economy	6000.00
0005434265791	5228	Economy	6000.00
0005434229941	5228	Economy	6000.00
0005434265784	5228	Economy	6000.00
0005434173648	5228	Economy	6000.00
0005434265804	5228	Economy	6000.00
0005432336228	5228	Economy	6000.00
0005435007460	5228	Economy	6000.00
0005435007424	5228	Economy	6000.00
0005434265790	5228	Economy	6000.00
0005435007444	5228	Economy	6000.00
0005434229945	5228	Economy	6000.00
0005435007358	5228	Economy	6000.00
0005434265799	5228	Economy	6000.00
0005434229954	5228	Economy	6000.00
0005434229949	5228	Economy	6000.00
0005434229938	5228	Economy	6000.00
0005434173650	5228	Economy	6000.00
0005435007459	5228	Economy	6000.00
0005434265800	5228	Economy	6000.00
0005435269866	5228	Economy	6000.00
0005435007391	5228	Economy	6000.00
0005434173649	5228	Economy	6000.00
0005434265807	5228	Economy	6000.00
0005435007452	5228	Economy	6000.00
0005435007458	5228	Economy	6000.00
0005434265789	5228	Economy	6000.00
0005434150027	5228	Economy	6000.00
0005434265795	5228	Economy	6000.00
0005435007416	5228	Economy	6000.00
0005434173623	5228	Economy	6000.00
0005434229946	5228	Economy	6000.00
0005435007451	5228	Economy	6000.00
0005434229948	5228	Economy	6000.00
0005433815464	5228	Economy	6000.00
0005434311260	5228	Economy	6000.00
0005432336309	5228	Economy	6000.00
0005433685560	5228	Economy	6000.00
0005434173621	5228	Economy	6000.00
0005434312347	5228	Economy	6000.00
0005435269873	5228	Economy	6000.00
0005434265788	5228	Economy	6000.00
0005434229950	5228	Economy	6000.00
0005435007375	5228	Economy	6600.00
0005434265787	5228	Economy	6600.00
0005434312346	5228	Economy	6600.00
0005434265783	5228	Economy	6000.00
0005434265796	5228	Economy	6000.00
0005434229944	5228	Economy	6000.00
0005434265798	5228	Economy	6600.00
0005432336271	5228	Economy	6000.00
0005434265793	5228	Economy	6000.00
0005434229951	5228	Economy	6000.00
0005435269879	5228	Economy	6000.00
0005434150030	5228	Economy	6000.00
0005434229939	5228	Economy	6000.00
0005434229947	5228	Economy	6000.00
0005435007427	5228	Economy	6000.00
0005432336208	5228	Economy	6000.00
0005435007417	5228	Economy	6000.00
0005434265782	5228	Economy	6000.00
0005434229952	5228	Economy	6000.00
0005434173651	5228	Economy	6000.00
0005434265792	5228	Economy	6000.00
0005434265785	5228	Economy	6000.00
0005435269882	5228	Economy	6000.00
0005435007426	5228	Economy	6000.00
0005434150031	5228	Economy	6000.00
0005434265786	5228	Economy	6000.00
0005434150037	5228	Economy	6000.00
0005432336223	5228	Economy	6000.00
0005435007425	5228	Economy	6000.00
0005432336233	5228	Economy	6000.00
0005435007415	5228	Economy	6000.00
0005434265802	5228	Economy	6000.00
0005433685561	5228	Economy	6000.00
0005432336257	5228	Economy	6000.00
0005435007438	5228	Economy	6000.00
0005434150034	5228	Economy	6000.00
0005435007403	5228	Economy	6000.00
0005434150029	5228	Economy	6000.00
0005434150032	5228	Economy	6000.00
0005434173622	5228	Economy	6000.00
0005434265806	5228	Economy	6000.00
0005435007461	5228	Economy	6000.00
0005434265794	5228	Economy	6000.00
0005433815462	5228	Economy	6000.00
0005432336215	5228	Economy	6000.00
0005434229942	5228	Economy	6000.00
0005435007335	5228	Economy	6000.00
0005435007402	5228	Economy	6000.00
0005434265805	5228	Economy	6000.00
0005434229940	5228	Economy	6000.00
0005434173652	5228	Economy	6000.00
0005432336273	5228	Economy	6000.00
0005432336272	5228	Economy	6000.00
0005434312352	5228	Economy	6000.00
0005435007405	5228	Economy	6000.00
0005435007480	5228	Economy	6000.00
0005434245435	8346	Business	18000.00
0005435270081	8346	Business	18000.00
0005433785557	8346	Business	18000.00
0005434245461	8346	Business	18000.00
0005433785592	8346	Business	18000.00
0005433785644	8346	Business	18000.00
0005433785610	8346	Business	18000.00
0005434245498	8346	Business	18000.00
0005434245438	8346	Business	18000.00
0005435270078	8346	Business	18000.00
0005435270087	8346	Business	18000.00
0005434245536	8346	Business	18000.00
0005435270086	8346	Business	18000.00
0005434245434	8346	Business	18000.00
0005435270061	8346	Business	18000.00
0005433785699	8346	Business	18000.00
0005435270067	8346	Business	18000.00
0005435270065	8346	Business	18000.00
0005433785643	8346	Economy	6600.00
0005433785467	8346	Economy	6600.00
0005433785560	8346	Economy	6600.00
0005435270079	8346	Economy	6000.00
0005434245502	8346	Economy	6000.00
0005433785655	8346	Economy	6000.00
0005434245650	8346	Economy	6000.00
0005433785543	8346	Economy	6000.00
0005433785398	8346	Economy	6000.00
0005433785542	8346	Economy	6000.00
0005434245555	8346	Economy	6000.00
0005434245631	8346	Economy	6000.00
0005433785458	8346	Economy	6000.00
0005433785399	8346	Economy	6000.00
0005433785400	8346	Economy	6000.00
0005433785454	8346	Economy	6000.00
0005434245370	8346	Economy	6000.00
0005432666426	8346	Economy	6000.00
0005432666425	8346	Economy	6000.00
0005435270063	8346	Economy	6000.00
0005433785654	8346	Economy	6000.00
0005435270069	8346	Economy	6000.00
0005434245517	8346	Economy	6000.00
0005433785587	8346	Economy	6000.00
0005433785586	8346	Economy	6000.00
0005434245389	8346	Economy	6000.00
0005435270072	8346	Economy	6000.00
0005434245501	8346	Economy	6000.00
0005433785463	8346	Economy	6000.00
0005435270070	8346	Economy	6000.00
0005435270085	8346	Economy	6000.00
0005435270071	8346	Economy	6000.00
0005434245388	8346	Economy	6000.00
0005432663070	8346	Economy	6000.00
0005433785504	8346	Economy	6000.00
0005433785531	8346	Economy	6000.00
0005433785460	8346	Economy	6000.00
0005434245530	8346	Economy	6000.00
0005435270060	8346	Economy	6000.00
0005435270080	8346	Economy	6600.00
0005433785474	8346	Economy	6000.00
0005435270077	8346	Economy	6000.00
0005435270074	8346	Economy	6000.00
0005434245481	8346	Economy	6000.00
0005434245482	8346	Economy	6000.00
0005433785660	8346	Economy	6000.00
0005435270062	8346	Economy	6000.00
0005433785532	8346	Economy	6000.00
0005435270084	8346	Economy	6000.00
0005433785718	8346	Economy	6000.00
0005434245615	8346	Economy	6000.00
0005435270066	8346	Economy	6000.00
0005432663060	8346	Economy	6000.00
0005432666424	8346	Economy	6000.00
0005433785457	8346	Economy	6000.00
0005434245462	8346	Economy	6000.00
0005434245425	8346	Economy	6000.00
0005435270076	8346	Economy	6000.00
0005435270064	8346	Economy	6000.00
0005433785491	8346	Economy	6000.00
0005434245557	8346	Economy	6000.00
0005434245632	8346	Economy	6000.00
0005434245533	8346	Economy	6000.00
0005434245424	8346	Economy	6000.00
0005435270082	8346	Economy	6000.00
0005434245649	8346	Economy	6000.00
0005435270073	8346	Economy	6000.00
0005433785606	8346	Economy	6000.00
0005433785510	8346	Economy	6000.00
0005433785694	8346	Economy	6000.00
0005432663069	8346	Economy	6000.00
0005434245460	8346	Economy	6000.00
0005433785591	8346	Economy	6000.00
0005433785609	8346	Economy	6000.00
0005433785415	8346	Economy	6000.00
0005434245497	8346	Economy	6000.00
0005433785619	8346	Economy	6000.00
0005433785695	8346	Economy	6000.00
0005433785533	8346	Economy	6000.00
0005433785488	8346	Economy	6000.00
0005435270075	8346	Economy	6000.00
0005434245541	8346	Economy	6000.00
0005433785593	8346	Economy	6000.00
0005435270083	8346	Economy	6000.00
0005435270068	8346	Economy	6000.00
0005434245516	8346	Economy	6000.00
0005433616223	8350	Business	18000.00
0005433615912	8350	Business	18000.00
0005433616225	8350	Business	18000.00
0005433615628	8350	Business	18000.00
0005433616059	8350	Business	18000.00
0005433615962	8350	Business	18000.00
0005433615974	8350	Business	18000.00
0005433615881	8350	Business	18000.00
0005433615718	8350	Business	18000.00
0005433615629	8350	Business	18000.00
0005433615717	8350	Economy	6600.00
0005433615956	8350	Economy	6600.00
0005433616076	8350	Economy	6000.00
0005433615870	8350	Economy	6000.00
0005433615930	8350	Economy	6000.00
0005433616029	8350	Economy	6000.00
0005433615976	8350	Economy	6000.00
0005433615802	8350	Economy	6000.00
0005433615690	8350	Economy	6000.00
0005433615826	8350	Economy	6000.00
0005433615901	8350	Economy	6000.00
0005433615929	8350	Economy	6000.00
0005433616005	8350	Economy	6000.00
0005433615493	8350	Economy	6000.00
0005433615744	8350	Economy	6000.00
0005433615967	8350	Economy	6000.00
0005433616020	8350	Economy	6000.00
0005433615745	8350	Economy	6000.00
0005433615780	8350	Economy	6000.00
0005433616148	8350	Economy	6000.00
0005433615913	8350	Economy	6000.00
0005433615713	8350	Economy	6000.00
0005433615955	8350	Economy	6000.00
0005433615716	8350	Economy	6000.00
0005433615827	8350	Economy	6000.00
0005433616046	8350	Economy	6000.00
0005433615714	8350	Economy	6000.00
0005433615957	8350	Economy	6000.00
0005433615741	8350	Economy	6000.00
0005433615830	8350	Economy	6000.00
0005433616226	8350	Economy	6000.00
0005433615790	8350	Economy	6600.00
0005433615749	8350	Economy	6000.00
0005433616105	8350	Economy	6000.00
0005433615963	8350	Economy	6000.00
0005433615618	8350	Economy	6000.00
0005433615872	8350	Economy	6000.00
0005433616060	8350	Economy	6000.00
0005433615949	8350	Economy	6000.00
0005433615750	8350	Economy	6000.00
0005433616040	8350	Economy	6000.00
0005433615829	8350	Economy	6000.00
0005433615597	8350	Economy	6000.00
0005433615914	8350	Economy	6000.00
0005433616135	8350	Economy	6000.00
0005433615672	8350	Economy	6000.00
0005433615682	8350	Economy	6000.00
0005433615742	8350	Economy	6000.00
0005433616016	8350	Economy	6000.00
0005433616108	8350	Economy	6000.00
0005433616045	8350	Economy	6000.00
0005433615940	8350	Economy	6000.00
0005433615823	8350	Economy	6000.00
0005433615810	8350	Economy	6000.00
0005433616075	8350	Economy	6000.00
0005433615673	8350	Economy	6000.00
0005433616017	8350	Economy	6000.00
0005433615715	8350	Economy	6000.00
0005433616104	8350	Economy	6000.00
0005433615941	8350	Economy	6000.00
0005433616224	8350	Economy	6000.00
0005433615864	8350	Economy	6000.00
0005433615751	8350	Economy	6000.00
0005433815508	8352	Business	18000.00
0005434265588	8352	Business	18000.00
0005434149948	8352	Business	18000.00
0005434229672	8352	Business	18000.00
0005434149963	8352	Business	18000.00
0005434149964	8352	Business	18000.00
0005432035667	8352	Business	18000.00
0005432336339	8352	Business	18000.00
0005434229834	8352	Business	18000.00
0005435007620	8352	Business	18000.00
0005435007619	8352	Business	18000.00
0005434265675	8352	Business	18000.00
0005432336341	8352	Business	18000.00
0005433815510	8352	Business	18000.00
0005434229823	8352	Business	18000.00
0005432336343	8352	Business	18000.00
0005434173583	8352	Business	18000.00
0005432035668	8352	Business	18000.00
0005432047648	8352	Business	18000.00
0005434229833	8352	Business	18000.00
0005434265569	8352	Business	18000.00
0005432035651	8352	Business	18000.00
0005434311271	8352	Business	18000.00
0005435286772	8352	Business	18000.00
0005433815511	8352	Business	18000.00
0005433689965	8352	Business	18000.00
0005434229712	8352	Economy	6600.00
0005432035662	8352	Economy	6600.00
0005434229827	8352	Economy	6600.00
0005432047649	8352	Economy	6600.00
0005432035660	8352	Economy	6600.00
0005435007622	8352	Economy	6600.00
0005435007611	8352	Economy	6000.00
0005435007613	8352	Economy	6000.00
0005434265637	8352	Economy	6000.00
0005434149934	8352	Economy	6000.00
0005433690978	8352	Economy	6000.00
0005434149943	8352	Economy	6000.00
0005434265626	8352	Economy	6000.00
0005435007630	8352	Economy	6000.00
0005433688863	8352	Economy	6000.00
0005434149975	8352	Economy	6000.00
0005432035657	8352	Economy	6000.00
0005432035665	8352	Economy	6000.00
0005433689964	8352	Economy	6000.00
0005434229742	8352	Economy	6000.00
0005432336334	8352	Economy	6000.00
0005434229809	8352	Economy	6000.00
0005434265497	8352	Economy	6000.00
0005433815512	8352	Economy	6000.00
0005435007627	8352	Economy	6000.00
0005433815509	8352	Economy	6000.00
0005432035647	8352	Economy	6000.00
0005434229658	8352	Economy	6000.00
0005434149947	8352	Economy	6000.00
0005432035653	8352	Economy	6000.00
0005434311286	8352	Economy	6000.00
0005434265610	8352	Economy	6000.00
0005434229714	8352	Economy	6000.00
0005432336345	8352	Economy	6000.00
0005434149936	8352	Economy	6000.00
0005435007625	8352	Economy	6000.00
0005435007629	8352	Economy	6000.00
0005434265662	8352	Economy	6000.00
0005432035646	8352	Economy	6000.00
0005435007614	8352	Economy	6000.00
0005434229810	8352	Economy	6000.00
0005432336337	8352	Economy	6000.00
0005432035658	8352	Economy	6000.00
0005434229729	8352	Economy	6000.00
0005432035655	8352	Economy	6000.00
0005433534553	8352	Economy	6000.00
0005435007624	8352	Economy	6000.00
0005435007615	8352	Economy	6000.00
0005433534552	8352	Economy	6000.00
0005435007626	8352	Economy	6000.00
0005432035661	8352	Economy	6000.00
0005434149955	8352	Economy	6000.00
0005433690977	8352	Economy	6000.00
0005434229824	8352	Economy	6000.00
0005434265454	8352	Economy	6000.00
0005434229754	8352	Economy	6000.00
0005435286773	8352	Economy	6000.00
0005435007608	8352	Economy	6000.00
0005434311287	8352	Economy	6000.00
0005432035652	8352	Economy	6000.00
0005434265542	8352	Economy	6000.00
0005434229739	8352	Economy	6000.00
0005435007610	8352	Economy	6000.00
0005434229568	8352	Economy	6000.00
0005434229800	8352	Economy	6600.00
0005435007631	8352	Economy	6600.00
0005435007607	8352	Economy	6600.00
0005434149956	8352	Economy	6600.00
0005432047647	8352	Economy	6600.00
0005434229798	8352	Economy	6000.00
0005434229822	8352	Economy	6000.00
0005432047645	8352	Economy	6000.00
0005432035654	8352	Economy	6000.00
0005433815550	8352	Economy	6600.00
0005433534551	8352	Economy	6000.00
0005434149942	8352	Economy	6000.00
0005435007612	8352	Economy	6000.00
0005434265518	8352	Economy	6000.00
0005434265455	8352	Economy	6000.00
0005435007623	8352	Economy	6000.00
0005434265506	8352	Economy	6000.00
0005432336344	8352	Economy	6000.00
0005434229713	8352	Economy	6000.00
0005435007609	8352	Economy	6000.00
0005435007628	8352	Economy	6000.00
0005434265609	8352	Economy	6000.00
0005434265466	8352	Economy	6000.00
0005432336338	8352	Economy	6000.00
0005434229787	8352	Economy	6000.00
0005434229682	8352	Economy	6000.00
0005435007621	8352	Economy	6000.00
0005435286770	8352	Economy	6000.00
0005432035664	8352	Economy	6000.00
0005434265505	8352	Economy	6000.00
0005432035650	8352	Economy	6000.00
0005433815551	8352	Economy	6000.00
0005434149950	8352	Economy	6000.00
0005435286769	8352	Economy	6000.00
0005435007618	8352	Economy	6000.00
0005434229741	8352	Economy	6000.00
0005433688864	8352	Economy	6000.00
0005434265555	8352	Economy	6000.00
0005434265556	8352	Economy	6000.00
0005433815549	8352	Economy	6000.00
0005435007616	8352	Economy	6000.00
0005434265543	8352	Economy	6000.00
0005435286771	8352	Economy	6000.00
0005434229799	8352	Economy	6000.00
0005432336335	8352	Economy	6000.00
0005434265453	8352	Economy	6000.00
0005432035669	8352	Economy	6000.00
0005434229740	8352	Economy	6000.00
0005434265557	8352	Economy	6000.00
0005434265633	8352	Economy	6000.00
0005432035649	8352	Economy	6000.00
0005435007617	8352	Economy	6000.00
0005432047646	8352	Economy	6000.00
0005434265632	8352	Economy	6000.00
0005434173570	8352	Economy	6000.00
0005434265469	8352	Economy	6000.00
0005432035656	8352	Economy	6000.00
0005434265663	8352	Economy	6000.00
0005435286768	8352	Economy	6000.00
0005432035648	8352	Economy	6000.00
0005432035663	8352	Economy	6000.00
0005434229737	8352	Economy	6000.00
0005434265504	8352	Economy	6000.00
0005432336336	8352	Economy	6000.00
0005434229569	8352	Economy	6000.00
0005432336342	8352	Economy	6000.00
0005434149914	8352	Economy	6000.00
0005434229753	8352	Economy	6000.00
0005432035666	8352	Economy	6000.00
0005435286767	8352	Economy	6000.00
0005434265630	8352	Economy	6000.00
0005432336340	8352	Economy	6000.00
0005432035645	8352	Economy	6000.00
0005432035659	8352	Economy	6000.00
0005433202744	12604	Economy	16200.00
0005433202746	12604	Economy	16200.00
0005434639859	12604	Economy	16200.00
0005433202748	12604	Economy	16200.00
0005433202736	12604	Economy	14800.00
0005434639724	12604	Economy	14800.00
0005433202740	12604	Economy	14800.00
0005433202737	12604	Economy	14800.00
0005433202735	12604	Economy	14800.00
0005434639799	12604	Economy	14800.00
0005434639628	12604	Economy	14800.00
0005433202738	12604	Economy	14800.00
0005434639797	12604	Economy	14800.00
0005434639737	12604	Economy	14800.00
0005434639714	12604	Economy	14800.00
0005433202741	12604	Economy	14800.00
0005434639741	12604	Economy	14800.00
0005434639778	12604	Economy	14800.00
0005434639676	12604	Economy	14800.00
0005433202739	12604	Economy	14800.00
0005434639607	12604	Economy	14800.00
0005434639794	12604	Economy	14800.00
0005434639908	12604	Economy	14800.00
0005433202745	12604	Economy	14800.00
0005434639793	12604	Economy	14800.00
0005434639790	12604	Economy	14800.00
0005434639725	12604	Economy	14800.00
0005434639830	12604	Economy	14800.00
0005434639860	12604	Economy	14800.00
0005434639722	12604	Economy	14800.00
0005434639792	12604	Economy	14800.00
0005434639909	12604	Economy	14800.00
0005434639789	12604	Economy	14800.00
0005433202742	12604	Economy	14800.00
0005434639774	12604	Economy	14800.00
0005434639653	12604	Economy	14800.00
0005433202743	12604	Economy	14800.00
0005434639791	12604	Economy	14800.00
0005434639742	12604	Economy	14800.00
0005434639787	12604	Economy	14800.00
0005433202747	12604	Economy	14800.00
0005434639654	12604	Economy	14800.00
0005433202734	12604	Economy	14800.00
0005433202606	23379	Economy	16200.00
0005433202598	23379	Economy	16200.00
0005433202619	23379	Economy	16200.00
0005433202610	23379	Economy	16200.00
0005434639971	23379	Economy	14800.00
0005434639962	23379	Economy	14800.00
0005434639956	23379	Economy	14800.00
0005434639957	23379	Economy	14800.00
0005434639959	23379	Economy	14800.00
0005434639945	23379	Economy	14800.00
0005434639968	23379	Economy	14800.00
0005434639964	23379	Economy	14800.00
0005434639948	23379	Economy	14800.00
0005432290710	23379	Economy	14800.00
0005434639973	23379	Economy	14800.00
0005433202543	23379	Economy	14800.00
0005434639970	23379	Economy	14800.00
0005434639972	23379	Economy	14800.00
0005434639969	23379	Economy	14800.00
0005434639952	23379	Economy	14800.00
0005434639955	23379	Economy	14800.00
0005434639975	23379	Economy	14800.00
0005433202620	23379	Economy	14800.00
0005433202600	23379	Economy	14800.00
0005434639953	23379	Economy	14800.00
0005433202597	23379	Economy	14800.00
0005433202611	23379	Economy	14800.00
0005434639965	23379	Economy	14800.00
0005432290709	23379	Economy	14800.00
0005433202599	23379	Economy	14800.00
0005434639949	23379	Economy	14800.00
0005433202639	23379	Economy	14800.00
0005434639974	23379	Economy	14800.00
0005434639947	23379	Economy	14800.00
0005434639967	23379	Economy	14800.00
0005434639950	23379	Economy	14800.00
0005434639951	23379	Economy	14800.00
0005434639966	23379	Economy	14800.00
0005434639954	23379	Economy	14800.00
0005434639958	23379	Economy	14800.00
0005434639963	23379	Economy	14800.00
0005432290711	23379	Economy	14800.00
0005433202509	23379	Economy	14800.00
0005434639960	23379	Economy	14800.00
0005434639946	23379	Economy	14800.00
0005434639961	23379	Economy	14800.00
0005432329597	21093	Business	18900.00
0005432383760	21093	Business	18900.00
0005432329528	21093	Business	18900.00
0005432383742	21093	Business	18900.00
0005432383804	21093	Business	18900.00
0005432383783	21093	Business	18900.00
0005432383805	21093	Business	18900.00
0005432329199	21093	Business	18900.00
0005432848898	21093	Business	18900.00
0005432383903	21093	Business	18900.00
0005432383580	21093	Business	18900.00
0005432329439	21093	Business	18900.00
0005432383888	21093	Economy	6300.00
0005432383815	21093	Economy	6300.00
0005432383868	21093	Economy	6300.00
0005432383652	21093	Economy	6300.00
0005432383641	21093	Economy	6300.00
0005432384013	21093	Economy	6300.00
0005432329417	21093	Economy	6300.00
0005432383822	21093	Economy	6300.00
0005432383708	21093	Economy	6300.00
0005432383869	21093	Economy	6300.00
0005432383819	21093	Economy	6900.00
0005432329197	21093	Economy	6900.00
0005432383720	21093	Economy	6900.00
0005432329509	21093	Economy	6900.00
0005432329397	21093	Economy	6900.00
0005432383645	21093	Economy	6300.00
0005432329460	21093	Economy	6300.00
0005432383653	21093	Economy	6300.00
0005432383799	21093	Economy	6300.00
0005432329579	21093	Economy	6300.00
0005432383721	21093	Economy	6300.00
0005432329385	21093	Economy	6300.00
0005432329383	21093	Economy	6300.00
0005432383982	21093	Economy	6300.00
0005432383834	21093	Economy	6300.00
0005432329510	21093	Economy	6300.00
0005432329198	21093	Economy	6300.00
0005432383835	21093	Economy	6300.00
0005432329339	21093	Economy	6300.00
0005432848890	21093	Economy	6300.00
0005432329418	21093	Economy	6300.00
0005432329224	21093	Economy	6300.00
0005432383771	21093	Economy	6300.00
0005432383784	21093	Economy	6300.00
0005432054380	21093	Economy	6300.00
0005432848889	21093	Economy	6300.00
0005432329267	21093	Economy	6300.00
0005432383887	21093	Economy	6300.00
0005432329441	21093	Economy	6300.00
0005432383785	21093	Economy	6300.00
0005432383743	21093	Economy	6300.00
0005432329438	21093	Economy	6300.00
0005432383644	21093	Economy	6300.00
0005432848892	21093	Economy	6300.00
0005432329578	21093	Economy	6300.00
0005432383811	21093	Economy	6300.00
0005432383776	21093	Economy	6300.00
0005432383659	21093	Economy	6300.00
0005432383579	21093	Economy	6300.00
0005432329266	21093	Economy	6300.00
0005432383657	21093	Economy	6300.00
0005432848891	21093	Economy	6300.00
0005432329384	21093	Economy	6300.00
0005432383744	21093	Economy	6300.00
0005432329382	21093	Economy	6300.00
0005432848897	21093	Economy	6300.00
0005432383766	21093	Economy	6300.00
0005432383853	21093	Economy	6300.00
0005432383820	21093	Economy	6300.00
0005432848896	21093	Economy	6300.00
0005432329271	21093	Economy	6300.00
0005432383782	21093	Economy	6300.00
0005432329270	21093	Economy	6300.00
0005432329508	21093	Economy	6300.00
0005432329527	21093	Economy	6300.00
0005432383691	21093	Economy	6300.00
0005432383722	21093	Economy	6300.00
0005432383814	21093	Economy	6300.00
0005432383983	21093	Economy	6300.00
0005432383658	21093	Economy	6300.00
0005432329518	21093	Economy	6300.00
0005432329539	21093	Economy	6300.00
0005432329591	21093	Economy	6300.00
0005432383794	21093	Economy	6300.00
0005432054381	21093	Economy	6300.00
0005432329354	21093	Economy	6300.00
0005432329549	21093	Economy	6300.00
0005432848895	21093	Economy	6300.00
0005432329114	21093	Economy	6300.00
0005432383852	21093	Economy	6300.00
0005432848894	21093	Economy	6300.00
0005432848893	21093	Economy	6300.00
0005432383647	21093	Economy	6300.00
0005432383772	21093	Economy	6300.00
0005432329837	31251	Business	18900.00
0005432329854	31251	Business	18900.00
0005432384153	31251	Business	18900.00
0005432329824	31251	Business	18900.00
0005432329839	31251	Business	18900.00
0005432329816	31251	Business	18900.00
0005432287314	31251	Business	18900.00
0005432329846	31251	Business	18900.00
0005432329845	31251	Business	18900.00
0005432384117	31251	Business	18900.00
0005432384138	31251	Business	18900.00
0005432848846	31251	Business	18900.00
0005432329833	31251	Economy	6300.00
0005432384160	31251	Economy	6300.00
0005432384148	31251	Economy	6300.00
0005432384155	31251	Economy	6300.00
0005432329836	31251	Economy	6300.00
0005432384136	31251	Economy	6300.00
0005432329835	31251	Economy	6300.00
0005432329817	31251	Economy	6300.00
0005432384132	31251	Economy	6300.00
0005432329825	31251	Economy	6300.00
0005432329831	31251	Economy	6900.00
0005432384133	31251	Economy	6900.00
0005432384151	31251	Economy	6900.00
0005432384149	31251	Economy	6900.00
0005432384144	31251	Economy	6300.00
0005432329820	31251	Economy	6300.00
0005432329826	31251	Economy	6300.00
0005432384118	31251	Economy	6300.00
0005432329823	31251	Economy	6300.00
0005432384130	31251	Economy	6300.00
0005432329856	31251	Economy	6300.00
0005432384154	31251	Economy	6300.00
0005432329847	31251	Economy	6300.00
0005432287315	31251	Economy	6300.00
0005432384125	31251	Economy	6300.00
0005432329841	31251	Economy	6300.00
0005432329814	31251	Economy	6300.00
0005432384140	31251	Economy	6300.00
0005432329818	31251	Economy	6300.00
0005432384152	31251	Economy	6300.00
0005432384134	31251	Economy	6300.00
0005432287313	31251	Economy	6300.00
0005432329843	31251	Economy	6300.00
0005432384146	31251	Economy	6300.00
0005432384127	31251	Economy	6300.00
0005432329848	31251	Economy	6300.00
0005432384131	31251	Economy	6300.00
0005432384139	31251	Economy	6300.00
0005432329853	31251	Economy	6300.00
0005432384124	31251	Economy	6300.00
0005432329844	31251	Economy	6300.00
0005432329829	31251	Economy	6300.00
0005432384143	31251	Economy	6300.00
0005432329840	31251	Economy	6300.00
0005432384126	31251	Economy	6300.00
0005432384158	31251	Economy	6300.00
0005432329851	31251	Economy	6300.00
0005432384150	31251	Economy	6300.00
0005432384142	31251	Economy	6300.00
0005432848849	31251	Economy	6300.00
0005432329819	31251	Economy	6300.00
0005432329855	31251	Economy	6300.00
0005432329857	31251	Economy	6300.00
0005432384147	31251	Economy	6300.00
0005432384156	31251	Economy	6300.00
0005432329830	31251	Economy	6300.00
0005432329852	31251	Economy	6300.00
0005432384135	31251	Economy	6300.00
0005432848851	31251	Economy	6300.00
0005432329850	31251	Economy	6300.00
0005432329822	31251	Economy	6300.00
0005432384121	31251	Economy	6300.00
0005432329849	31251	Economy	6300.00
0005432384119	31251	Economy	6300.00
0005432329842	31251	Economy	6300.00
0005432329828	31251	Economy	6300.00
0005432384123	31251	Economy	6300.00
0005432329838	31251	Economy	6300.00
0005432384137	31251	Economy	6300.00
0005432329827	31251	Economy	6300.00
0005432329832	31251	Economy	6300.00
0005432384141	31251	Economy	6300.00
0005432384122	31251	Economy	6300.00
0005432384159	31251	Economy	6300.00
0005432848843	31251	Economy	6300.00
0005432384157	31251	Economy	6300.00
0005432384145	31251	Economy	6300.00
0005432329815	31251	Economy	6300.00
0005432384129	31251	Economy	6300.00
0005432329834	31251	Economy	6300.00
0005432384128	31251	Economy	6300.00
0005432384120	31251	Economy	6300.00
0005432329821	31251	Economy	6300.00
0005433642690	2474	Business	89600.00
0005432954042	2474	Business	89600.00
0005433642725	2474	Business	89600.00
0005432954090	2474	Business	89600.00
0005433642701	2474	Business	89600.00
0005432954070	2474	Business	89600.00
0005433642694	2474	Business	89600.00
0005433642702	2474	Business	89600.00
0005433642720	2474	Business	89600.00
0005432954052	2474	Business	89600.00
0005432954109	2474	Economy	29900.00
0005433642729	2474	Economy	29900.00
0005433642710	2474	Economy	29900.00
0005432954080	2474	Economy	29900.00
0005433642696	2474	Economy	29900.00
0005433642711	2474	Economy	32800.00
0005433642713	2474	Economy	32800.00
0005433642723	2474	Economy	32800.00
0005432954055	2474	Economy	32800.00
0005433642706	2474	Economy	29900.00
0005433642718	2474	Economy	29900.00
0005433642731	2474	Economy	29900.00
0005433642715	2474	Economy	29900.00
0005433642697	2474	Economy	29900.00
0005433642714	2474	Economy	29900.00
0005432954069	2474	Economy	29900.00
0005432954094	2474	Economy	29900.00
0005433642705	2474	Economy	29900.00
0005433642708	2474	Economy	29900.00
0005433642727	2474	Economy	29900.00
0005432954024	2474	Economy	29900.00
0005432954029	2474	Economy	29900.00
0005432954083	2474	Economy	29900.00
0005433642704	2474	Economy	29900.00
0005432954033	2474	Economy	29900.00
0005433642728	2474	Economy	29900.00
0005433642700	2474	Economy	29900.00
0005433642707	2474	Economy	29900.00
0005432954068	2474	Economy	29900.00
0005432954051	2474	Economy	29900.00
0005433642691	2474	Economy	29900.00
0005432954089	2474	Economy	29900.00
0005433642730	2474	Economy	29900.00
0005433642721	2474	Economy	29900.00
0005433642719	2474	Economy	29900.00
0005433642726	2474	Economy	29900.00
0005433642695	2474	Economy	29900.00
0005432954056	2474	Economy	29900.00
0005433642716	2474	Economy	29900.00
0005432954076	2474	Economy	29900.00
0005433642733	2474	Economy	29900.00
0005432954102	2474	Economy	29900.00
0005433642717	2474	Economy	29900.00
0005433642699	2474	Economy	29900.00
0005433642712	2474	Economy	29900.00
0005433642692	2474	Economy	29900.00
0005433642732	2474	Economy	29900.00
0005433642724	2474	Economy	29900.00
0005433642722	2474	Economy	29900.00
0005432954044	2474	Economy	29900.00
0005432954093	2474	Economy	29900.00
0005433642703	2474	Economy	29900.00
0005432954103	2474	Economy	29900.00
0005433642698	2474	Economy	29900.00
0005433642689	2474	Economy	29900.00
0005432954025	2474	Economy	29900.00
0005432954060	2474	Economy	29900.00
0005432954041	2474	Economy	29900.00
0005432954078	2474	Economy	29900.00
0005433642709	2474	Economy	29900.00
0005433642693	2474	Economy	29900.00
0005432954032	2474	Economy	29900.00
0005432425657	13266	Business	12700.00
0005432425635	13266	Business	12700.00
0005432425636	13266	Business	12700.00
0005432425641	13266	Business	12700.00
0005432425646	13266	Business	12700.00
0005432425633	13266	Business	12700.00
0005432425634	13266	Economy	4200.00
0005432425656	13266	Economy	4200.00
0005432425651	13266	Economy	4200.00
0005432425643	13266	Economy	4200.00
0005432425650	13266	Economy	4200.00
0005432425630	13266	Economy	4200.00
0005432425626	13266	Economy	4200.00
0005432425624	13266	Economy	4700.00
0005432425631	13266	Economy	4700.00
0005432425625	13266	Economy	4700.00
0005432425660	13266	Economy	4200.00
0005432425644	13266	Economy	4200.00
0005432425622	13266	Economy	4200.00
0005432425654	13266	Economy	4200.00
0005432425620	13266	Economy	4200.00
0005432425639	13266	Economy	4200.00
0005432425623	13266	Economy	4200.00
0005432425629	13266	Economy	4200.00
0005432425638	13266	Economy	4200.00
0005432425632	13266	Economy	4200.00
0005432425621	13266	Economy	4200.00
0005432425647	13266	Economy	4200.00
0005432425637	13266	Economy	4200.00
0005432425652	13266	Economy	4200.00
0005432425653	13266	Economy	4200.00
0005432425627	13266	Economy	4200.00
0005432425655	13266	Economy	4200.00
0005432425642	13266	Economy	4200.00
0005432425645	13266	Economy	4200.00
0005432425658	13266	Economy	4200.00
0005432425648	13266	Economy	4200.00
0005432425628	13266	Economy	4200.00
0005432425649	13266	Economy	4200.00
0005432425640	13266	Economy	4200.00
0005432425659	13266	Economy	4200.00
0005432425240	30717	Business	12700.00
0005432425239	30717	Business	12700.00
0005432425274	30717	Business	12700.00
0005432425185	30717	Business	12700.00
0005432425210	30717	Business	12700.00
0005432425215	30717	Business	12700.00
0005432425060	30717	Business	12700.00
0005432425208	30717	Economy	4200.00
0005432425282	30717	Economy	4200.00
0005432425277	30717	Economy	4200.00
0005432425162	30717	Economy	4200.00
0005432425184	30717	Economy	4200.00
0005432425258	30717	Economy	4200.00
0005432425265	30717	Economy	4700.00
0005432425235	30717	Economy	4700.00
0005432425029	30717	Economy	4200.00
0005432425183	30717	Economy	4200.00
0005432425259	30717	Economy	4200.00
0005432425187	30717	Economy	4200.00
0005432425098	30717	Economy	4200.00
0005432425233	30717	Economy	4200.00
0005432425118	30717	Economy	4200.00
0005432425264	30717	Economy	4200.00
0005432425155	30717	Economy	4200.00
0005432425182	30717	Economy	4200.00
0005432425283	30717	Economy	4200.00
0005432425216	30717	Economy	4200.00
0005432425105	30717	Economy	4200.00
0005432425099	30717	Economy	4200.00
0005432425193	30717	Economy	4200.00
0005432424947	30717	Economy	4200.00
0005432425219	30717	Economy	4200.00
0005432425200	30717	Economy	4200.00
0005432425161	30717	Economy	4200.00
0005432425014	30717	Economy	4200.00
0005432425242	30717	Economy	4200.00
0005432425266	30717	Economy	4200.00
0005432425071	30717	Economy	4200.00
0005432425273	30717	Economy	4200.00
0005432425252	30717	Economy	4200.00
0005432425209	30717	Economy	4200.00
0005432425095	30717	Economy	4200.00
0005432425228	30717	Economy	4200.00
0005432425025	30717	Economy	4200.00
0005432425211	30717	Economy	4200.00
0005432425204	30717	Economy	4200.00
0005432425174	30717	Economy	4200.00
0005432425030	30717	Economy	4200.00
0005432425061	30717	Economy	4200.00
0005432425188	30717	Economy	4200.00
0005432425281	30717	Economy	4200.00
0005432425227	30717	Economy	4200.00
0005432425234	30717	Economy	4200.00
0005432425243	30717	Economy	4200.00
0005432425120	30717	Economy	4200.00
0005432425203	30717	Economy	4200.00
0005432425241	30717	Economy	4200.00
0005432425232	30717	Economy	4200.00
0005432425154	30717	Economy	4200.00
0005434157614	9584	Business	32600.00
0005432822399	9584	Business	32600.00
0005434157632	9584	Business	32600.00
0005432818214	9584	Business	32600.00
0005432818229	9584	Business	32600.00
0005432818226	9584	Business	32600.00
0005434157574	9584	Business	32600.00
0005432901935	9584	Business	32600.00
0005432901926	9584	Economy	10900.00
0005434157610	9584	Economy	10900.00
0005432289072	9584	Economy	10900.00
0005432818236	9584	Economy	10900.00
0005432289070	9584	Economy	10900.00
0005432818232	9584	Economy	11900.00
0005434157575	9584	Economy	11900.00
0005434448402	9584	Economy	11900.00
0005434448404	9584	Economy	11900.00
0005432818237	9584	Economy	10900.00
0005432818235	9584	Economy	10900.00
0005434157609	9584	Economy	10900.00
0005432818216	9584	Economy	10900.00
0005434157629	9584	Economy	10900.00
0005432901900	9584	Economy	10900.00
0005434448405	9584	Economy	10900.00
0005434157576	9584	Economy	10900.00
0005434448403	9584	Economy	10900.00
0005432818217	9584	Economy	10900.00
0005432901933	9584	Economy	10900.00
0005432822403	9584	Economy	10900.00
0005432289069	9584	Economy	10900.00
0005432818220	9584	Economy	10900.00
0005432818231	9584	Economy	10900.00
0005432818224	9584	Economy	10900.00
0005432901865	9584	Economy	10900.00
0005432901901	9584	Economy	10900.00
0005432822400	9584	Economy	10900.00
0005432818234	9584	Economy	10900.00
0005432901976	9584	Economy	10900.00
0005434186248	9584	Economy	10900.00
0005432818223	9584	Economy	10900.00
0005432818227	9584	Economy	10900.00
0005432822401	9584	Economy	10900.00
0005434157611	9584	Economy	10900.00
0005432818219	9584	Economy	10900.00
0005432822397	9584	Economy	10900.00
0005434157603	9584	Economy	10900.00
0005432818233	9584	Economy	10900.00
0005432901990	9584	Economy	10900.00
0005434157643	9584	Economy	10900.00
0005432822402	9584	Economy	10900.00
0005432818218	9584	Economy	10900.00
0005434186253	9584	Economy	10900.00
0005432901936	9584	Economy	10900.00
0005432822398	9584	Economy	10900.00
0005432818213	9584	Economy	10900.00
0005432901899	9584	Economy	10900.00
0005434186252	9584	Economy	10900.00
0005432901812	9584	Economy	10900.00
0005432818225	9584	Economy	10900.00
0005432818221	9584	Economy	10900.00
0005434157630	9584	Economy	10900.00
0005432818230	9584	Economy	10900.00
0005432901811	9584	Economy	10900.00
0005432901902	9584	Economy	10900.00
0005432818228	9584	Economy	10900.00
0005432818222	9584	Economy	10900.00
0005434186251	9584	Economy	10900.00
0005432818215	9584	Economy	10900.00
0005432289071	9584	Economy	10900.00
0005434157628	9584	Economy	10900.00
0005432822330	29003	Business	32600.00
0005434448380	29003	Business	32600.00
0005432902059	29003	Business	32600.00
0005432902054	29003	Business	32600.00
0005432822324	29003	Business	32600.00
0005432817878	29003	Business	32600.00
0005432817902	29003	Business	32600.00
0005432002129	29003	Economy	10900.00
0005432902060	29003	Economy	10900.00
0005432902057	29003	Economy	10900.00
0005432817747	29003	Economy	10900.00
0005432817917	29003	Economy	10900.00
0005434157680	29003	Economy	10900.00
0005432902052	29003	Economy	10900.00
0005432818036	29003	Economy	10900.00
0005432817991	29003	Economy	11900.00
0005432817911	29003	Economy	11900.00
0005432902061	29003	Economy	11900.00
0005434186271	29003	Economy	10900.00
0005432902058	29003	Economy	10900.00
0005434157676	29003	Economy	10900.00
0005432817959	29003	Economy	10900.00
0005434448359	29003	Economy	10900.00
0005432817908	29003	Economy	10900.00
0005432818081	29003	Economy	10900.00
0005432817877	29003	Economy	10900.00
0005432902046	29003	Economy	10900.00
0005434157679	29003	Economy	10900.00
0005432902055	29003	Economy	10900.00
0005434157681	29003	Economy	10900.00
0005434448372	29003	Economy	10900.00
0005432822356	29003	Economy	10900.00
0005434157677	29003	Economy	10900.00
0005432818080	29003	Economy	10900.00
0005432818000	29003	Economy	10900.00
0005432818003	29003	Economy	10900.00
0005432817987	29003	Economy	10900.00
0005432822342	29003	Economy	10900.00
0005432822352	29003	Economy	10900.00
0005432902047	29003	Economy	10900.00
0005432902050	29003	Economy	10900.00
0005432817886	29003	Economy	10900.00
0005434157683	29003	Economy	10900.00
0005434157678	29003	Economy	10900.00
0005434186270	29003	Economy	10900.00
0005432818001	29003	Economy	10900.00
0005432817994	29003	Economy	10900.00
0005432818040	29003	Economy	10900.00
0005432822325	29003	Economy	10900.00
0005434448381	29003	Economy	10900.00
0005434157682	29003	Economy	10900.00
0005432822326	29003	Economy	10900.00
0005432902051	29003	Economy	10900.00
0005432818083	29003	Economy	10900.00
0005434448358	29003	Economy	10900.00
0005432818004	29003	Economy	10900.00
0005432902049	29003	Economy	10900.00
0005432902048	29003	Economy	10900.00
0005432818002	29003	Economy	10900.00
0005432817984	29003	Economy	10900.00
0005432817891	29003	Economy	10900.00
0005432817907	29003	Economy	10900.00
0005432902053	29003	Economy	10900.00
0005432818039	29003	Economy	10900.00
0005434186272	29003	Economy	10900.00
0005432902056	29003	Economy	10900.00
0005432611802	15150	Economy	11000.00
0005435841104	15150	Economy	11000.00
0005432613967	15150	Economy	11000.00
0005432613968	15150	Economy	11000.00
0005432613966	15150	Economy	11000.00
0005432613969	15150	Economy	11000.00
0005435841117	15150	Economy	11000.00
0005432613965	15150	Economy	11000.00
0005432607612	31639	Economy	11000.00
0005432607634	31639	Economy	11000.00
0005432611770	31639	Economy	11000.00
0005432607633	31639	Economy	11000.00
0005435841846	31639	Economy	11000.00
0005432607618	31639	Economy	11000.00
0005432607632	31639	Economy	11000.00
0005432611769	31639	Economy	11000.00
0005432607636	31639	Economy	11000.00
0005432607635	31639	Economy	11000.00
0005432611776	31639	Economy	11000.00
0005432607637	31639	Economy	11000.00
0005433570626	11852	Business	105900.00
0005433570597	11852	Business	105900.00
0005432949033	11852	Business	105900.00
0005433570578	11852	Business	105900.00
0005433570625	11852	Business	105900.00
0005433570606	11852	Business	105900.00
0005433570573	11852	Business	105900.00
0005433570624	11852	Business	105900.00
0005433570595	11852	Business	105900.00
0005433570596	11852	Business	105900.00
0005432949064	11852	Business	105900.00
0005433570571	11852	Business	105900.00
0005432949048	11852	Business	105900.00
0005432949118	11852	Business	105900.00
0005433570617	11852	Business	105900.00
0005433570572	11852	Business	105900.00
0005433570600	11852	Business	105900.00
0005433570621	11852	Business	105900.00
0005432948980	11852	Business	105900.00
0005433570570	11852	Business	105900.00
0005433570585	11852	Economy	35300.00
0005433570575	11852	Economy	35300.00
0005432949137	11852	Economy	35300.00
0005433570619	11852	Economy	35300.00
0005433570582	11852	Economy	35300.00
0005433570607	11852	Economy	35300.00
0005433570576	11852	Economy	35300.00
0005433570628	11852	Economy	35300.00
0005432948901	11852	Economy	35300.00
0005432949062	11852	Economy	35300.00
0005432948918	11852	Economy	35300.00
0005433570620	11852	Economy	35300.00
0005432949183	11852	Economy	35300.00
0005432948967	11852	Economy	38800.00
0005432949047	11852	Economy	38800.00
0005433570591	11852	Economy	38800.00
0005433570632	11852	Economy	38800.00
0005432949203	11852	Economy	35300.00
0005433570599	11852	Economy	35300.00
0005432948900	11852	Economy	35300.00
0005433570611	11852	Economy	35300.00
0005432949013	11852	Economy	35300.00
0005433570622	11852	Economy	35300.00
0005433570592	11852	Economy	35300.00
0005432949261	11852	Economy	35300.00
0005433570583	11852	Economy	35300.00
0005432948968	11852	Economy	35300.00
0005432949293	11852	Economy	35300.00
0005433570598	11852	Economy	35300.00
0005432949032	11852	Economy	35300.00
0005432949061	11852	Economy	35300.00
0005432949148	11852	Economy	35300.00
0005433570590	11852	Economy	35300.00
0005432949012	11852	Economy	35300.00
0005432949051	11852	Economy	35300.00
0005432949112	11852	Economy	35300.00
0005432949292	11852	Economy	35300.00
0005433570630	11852	Economy	35300.00
0005433570587	11852	Economy	35300.00
0005433570577	11852	Economy	35300.00
0005432949136	11852	Economy	35300.00
0005432949266	11852	Economy	35300.00
0005432949111	11852	Economy	35300.00
0005432949034	11852	Economy	35300.00
0005433570586	11852	Economy	35300.00
0005432949125	11852	Economy	35300.00
0005432949298	11852	Economy	35300.00
0005433570584	11852	Economy	35300.00
0005432949191	11852	Economy	35300.00
0005433570608	11852	Economy	35300.00
0005433570612	11852	Economy	35300.00
0005433570633	11852	Economy	35300.00
0005432949138	11852	Economy	35300.00
0005433570601	11852	Economy	35300.00
0005433570580	11852	Economy	35300.00
0005433570613	11852	Economy	35300.00
0005433570605	11852	Economy	35300.00
0005433570602	11852	Economy	35300.00
0005432948979	11852	Economy	35300.00
0005432949204	11852	Economy	35300.00
0005432949180	11852	Economy	35300.00
0005432949170	11852	Economy	35300.00
0005432949163	11852	Economy	35300.00
0005433570603	11852	Economy	35300.00
0005433570615	11852	Economy	35300.00
0005433570614	11852	Economy	35300.00
0005432949052	11852	Economy	35300.00
0005433570594	11852	Economy	35300.00
0005433570579	11852	Economy	35300.00
0005432949167	11852	Economy	35300.00
0005433570618	11852	Economy	35300.00
0005433570581	11852	Economy	35300.00
0005433570589	11852	Economy	35300.00
0005433570634	11852	Economy	35300.00
0005433570588	11852	Economy	35300.00
0005432949126	11852	Economy	35300.00
0005433570574	11852	Economy	35300.00
0005433570616	11852	Economy	35300.00
0005432949262	11852	Economy	35300.00
0005432949221	11852	Economy	35300.00
0005433570593	11852	Economy	35300.00
0005432949139	11852	Economy	35300.00
0005432949018	11852	Economy	35300.00
0005432948960	11852	Economy	35300.00
0005432949267	11852	Economy	35300.00
0005433570609	11852	Economy	35300.00
0005433570631	11852	Economy	35300.00
0005432949149	11852	Economy	35300.00
0005433570623	11852	Economy	35300.00
0005433570627	11852	Economy	35300.00
0005432949192	11852	Economy	35300.00
0005432949135	11852	Economy	35300.00
0005433570610	11852	Economy	35300.00
0005433570629	11852	Economy	35300.00
0005433570604	11852	Economy	35300.00
0005433569957	25280	Business	105900.00
0005433570146	25280	Business	105900.00
0005432949545	25280	Business	105900.00
0005433569670	25280	Business	105900.00
0005433569984	25280	Business	105900.00
0005432949526	25280	Business	105900.00
0005432949547	25280	Business	105900.00
0005432949529	25280	Business	105900.00
0005433570023	25280	Business	105900.00
0005432949535	25280	Business	105900.00
0005432949531	25280	Business	105900.00
0005433569843	25280	Business	105900.00
0005432949546	25280	Business	105900.00
0005432949517	25280	Business	105900.00
0005433569796	25280	Business	105900.00
0005433569989	25280	Business	105900.00
0005432949541	25280	Business	105900.00
0005432949543	25280	Business	105900.00
0005433569834	25280	Business	105900.00
0005432949542	25280	Economy	35300.00
0005433570093	25280	Business	105900.00
0005432949544	25280	Economy	35300.00
0005432949549	25280	Economy	35300.00
0005433570078	25280	Economy	35300.00
0005433569976	25280	Economy	35300.00
0005433569776	25280	Economy	35300.00
0005433570217	25280	Economy	35300.00
0005433570099	25280	Economy	35300.00
0005433570148	25280	Economy	35300.00
0005432949553	25280	Economy	35300.00
0005433569830	25280	Economy	35300.00
0005433570021	25280	Economy	35300.00
0005433570145	25280	Economy	38800.00
0005433570243	25280	Economy	38800.00
0005433569797	25280	Economy	38800.00
0005432949525	25280	Economy	38800.00
0005433569985	25280	Economy	35300.00
0005433570169	25280	Economy	35300.00
0005433570126	25280	Economy	35300.00
0005433569835	25280	Economy	35300.00
0005433570250	25280	Economy	35300.00
0005433569918	25280	Economy	35300.00
0005433570108	25280	Economy	35300.00
0005432949518	25280	Economy	35300.00
0005433569773	25280	Economy	35300.00
0005432949519	25280	Economy	35300.00
0005432949552	25280	Economy	35300.00
0005433570127	25280	Economy	35300.00
0005433569798	25280	Economy	35300.00
0005432949539	25280	Economy	35300.00
0005432949524	25280	Economy	35300.00
0005432949520	25280	Economy	35300.00
0005432949532	25280	Economy	35300.00
0005432949540	25280	Economy	35300.00
0005432949522	25280	Economy	35300.00
0005433570056	25280	Economy	35300.00
0005432949521	25280	Economy	35300.00
0005433570036	25280	Economy	35300.00
0005433570010	25280	Economy	35300.00
0005433570058	25280	Economy	35300.00
0005433570063	25280	Economy	35300.00
0005433570194	25280	Economy	35300.00
0005433570135	25280	Economy	35300.00
0005433570156	25280	Economy	35300.00
0005432949554	25280	Economy	35300.00
0005433570022	25280	Economy	35300.00
0005433570115	25280	Economy	35300.00
0005432949534	25280	Economy	35300.00
0005432949550	25280	Economy	35300.00
0005433570064	25280	Economy	35300.00
0005433569978	25280	Economy	35300.00
0005433570103	25280	Economy	35300.00
0005433570264	25280	Economy	35300.00
0005433570101	25280	Economy	35300.00
0005433569986	25280	Economy	35300.00
0005433569995	25280	Economy	35300.00
0005433569940	25280	Economy	35300.00
0005432949523	25280	Economy	35300.00
0005433569873	25280	Economy	35300.00
0005433570130	25280	Economy	35300.00
0005433570231	25280	Economy	35300.00
0005433570245	25280	Economy	35300.00
0005433570157	25280	Economy	35300.00
0005433569975	25280	Economy	35300.00
0005432949536	25280	Economy	35300.00
0005433569799	25280	Economy	35300.00
0005433570208	25280	Economy	35300.00
0005432949548	25280	Economy	35300.00
0005433569754	25280	Economy	35300.00
0005433570092	25280	Economy	35300.00
0005433569906	25280	Economy	35300.00
0005433570107	25280	Economy	35300.00
0005432949551	25280	Economy	35300.00
0005433570057	25280	Economy	35300.00
0005433570102	25280	Economy	35300.00
0005432949533	25280	Economy	35300.00
0005433569812	25280	Economy	35300.00
0005433569983	25280	Economy	35300.00
0005433569977	25280	Economy	35300.00
0005432949538	25280	Economy	35300.00
0005433569905	25280	Economy	35300.00
0005433570009	25280	Economy	35300.00
0005432949530	25280	Economy	35300.00
0005433569959	25280	Economy	35300.00
0005433569958	25280	Economy	35300.00
0005432949537	25280	Economy	35300.00
0005432949527	25280	Economy	35300.00
0005433570244	25280	Economy	35300.00
0005432949528	25280	Economy	35300.00
0005433570149	25280	Economy	35300.00
0005433569919	25280	Economy	35300.00
0005432430956	14456	Business	117400.00
0005432430953	14456	Business	117400.00
0005432430954	14456	Business	117400.00
0005434026753	14456	Business	117400.00
0005433808453	14456	Business	117400.00
0005433808422	14456	Economy	39100.00
0005432430960	14456	Economy	39100.00
0005433812934	14456	Economy	39100.00
0005432430951	14456	Economy	39100.00
0005432430958	14456	Economy	43000.00
0005434026751	14456	Economy	39100.00
0005432430962	14456	Economy	39100.00
0005432430961	14456	Economy	39100.00
0005434026756	14456	Economy	39100.00
0005432430952	14456	Economy	39100.00
0005434026754	14456	Economy	39100.00
0005434026755	14456	Economy	39100.00
0005433808423	14456	Economy	39100.00
0005433812926	14456	Economy	39100.00
0005432430955	14456	Economy	39100.00
0005433808454	14456	Economy	39100.00
0005433808440	14456	Economy	39100.00
0005432430957	14456	Economy	39100.00
0005432430959	14456	Economy	39100.00
0005434026752	14456	Economy	39100.00
0005434026732	30825	Business	117400.00
0005432430934	30825	Business	117400.00
0005433812958	30825	Business	117400.00
0005433808466	30825	Business	117400.00
0005432430916	30825	Business	117400.00
0005434026724	30825	Business	117400.00
0005432430899	30825	Business	117400.00
0005432430926	30825	Business	117400.00
0005433812953	30825	Business	117400.00
0005433808470	30825	Business	117400.00
0005433812957	30825	Economy	39100.00
0005433812954	30825	Economy	39100.00
0005433808464	30825	Economy	39100.00
0005433808472	30825	Economy	39100.00
0005433808477	30825	Economy	39100.00
0005434026729	30825	Economy	39100.00
0005433808462	30825	Economy	39100.00
0005432430925	30825	Economy	39100.00
0005432430915	30825	Economy	39100.00
0005432430909	30825	Economy	39100.00
0005433812960	30825	Economy	39100.00
0005434026730	30825	Economy	39100.00
0005433808473	30825	Economy	39100.00
0005433812959	30825	Economy	39100.00
0005432430904	30825	Economy	39100.00
0005432430918	30825	Economy	39100.00
0005433812955	30825	Economy	39100.00
0005433808469	30825	Economy	39100.00
0005433808468	30825	Economy	39100.00
0005434026726	30825	Economy	39100.00
0005433812952	30825	Economy	39100.00
0005433812961	30825	Economy	39100.00
0005433808463	30825	Economy	39100.00
0005433808474	30825	Economy	39100.00
0005432430929	30825	Economy	39100.00
0005433808467	30825	Economy	39100.00
0005433808471	30825	Economy	39100.00
0005434026733	30825	Economy	39100.00
0005433812956	30825	Economy	39100.00
0005432430930	30825	Economy	39100.00
0005432430905	30825	Economy	39100.00
0005433808476	30825	Economy	39100.00
0005433808465	30825	Economy	39100.00
0005433808475	30825	Economy	39100.00
0005433808461	30825	Economy	39100.00
0005434655421	5419	Business	67200.00
0005434656609	5419	Business	67200.00
0005435340492	5419	Business	67200.00
0005435340512	5419	Business	67200.00
0005434655418	5419	Economy	22400.00
0005435555404	5419	Economy	22400.00
0005434655434	5419	Economy	22400.00
0005435340546	5419	Economy	22400.00
0005435555407	5419	Economy	22400.00
0005435340539	5419	Economy	24600.00
0005434655437	5419	Economy	24600.00
0005432114285	5419	Economy	22400.00
0005434655413	5419	Economy	22400.00
0005434655425	5419	Economy	22400.00
0005435340509	5419	Economy	22400.00
0005435340527	5419	Economy	22400.00
0005435340485	5419	Economy	22400.00
0005434655423	5419	Economy	22400.00
0005434655427	5419	Economy	22400.00
0005434655420	5419	Economy	22400.00
0005435340508	5419	Economy	22400.00
0005434655438	5419	Economy	22400.00
0005434655424	5419	Economy	22400.00
0005434656607	5419	Economy	22400.00
0005435340542	5419	Economy	22400.00
0005435340459	5419	Economy	22400.00
0005432114287	5419	Economy	22400.00
0005434655416	5419	Economy	22400.00
0005434655429	5419	Economy	22400.00
0005434655433	5419	Economy	22400.00
0005435340460	5419	Economy	22400.00
0005434655431	5419	Economy	22400.00
0005434655419	5419	Economy	22400.00
0005435340534	5419	Economy	22400.00
0005432114284	5419	Economy	22400.00
0005434655417	5419	Economy	22400.00
0005432114286	5419	Economy	22400.00
0005434655415	5419	Economy	22400.00
0005435555406	5419	Economy	22400.00
0005434655428	5419	Economy	22400.00
0005434655414	5419	Economy	22400.00
0005435555405	5419	Economy	22400.00
0005434655422	5419	Economy	22400.00
0005434655435	5419	Economy	22400.00
0005434655436	5419	Economy	22400.00
0005434655432	5419	Economy	22400.00
0005434655426	5419	Economy	22400.00
0005434656608	5419	Economy	22400.00
0005434655430	5419	Economy	22400.00
0005434655271	12531	Business	67200.00
0005434655225	12531	Business	67200.00
0005435340650	12531	Business	67200.00
0005434655137	12531	Business	67200.00
0005434655089	12531	Business	67200.00
0005434655103	12531	Business	67200.00
0005434655278	12531	Business	67200.00
0005435340644	12531	Economy	22400.00
0005435340645	12531	Economy	22400.00
0005434655266	12531	Economy	22400.00
0005435340649	12531	Economy	24600.00
0005435340657	12531	Economy	24600.00
0005434656591	12531	Economy	22400.00
0005434655114	12531	Economy	22400.00
0005434655102	12531	Economy	22400.00
0005434655135	12531	Economy	22400.00
0005434655213	12531	Economy	22400.00
0005434655090	12531	Economy	22400.00
0005435555423	12531	Economy	22400.00
0005434655224	12531	Economy	22400.00
0005435340653	12531	Economy	22400.00
0005434655267	12531	Economy	22400.00
0005435555422	12531	Economy	22400.00
0005434655184	12531	Economy	22400.00
0005434655147	12531	Economy	22400.00
0005435340658	12531	Economy	22400.00
0005434655134	12531	Economy	22400.00
0005435340655	12531	Economy	22400.00
0005435340648	12531	Economy	22400.00
0005435340656	12531	Economy	22400.00
0005434656587	12531	Economy	22400.00
0005434655185	12531	Economy	22400.00
0005435340654	12531	Economy	22400.00
0005434655265	12531	Economy	22400.00
0005435340651	12531	Economy	22400.00
0005434655195	12531	Economy	22400.00
0005434655146	12531	Economy	22400.00
0005435340647	12531	Economy	22400.00
0005435340646	12531	Economy	22400.00
0005434655212	12531	Economy	22400.00
0005434655187	12531	Economy	22400.00
0005434655194	12531	Economy	22400.00
0005435340652	12531	Economy	22400.00
0005434655136	12531	Economy	22400.00
0005433688861	7444	Business	32000.00
0005433722383	7444	Business	32000.00
0005433689962	7444	Business	32000.00
0005433722388	7444	Business	32000.00
0005433690976	7444	Economy	10700.00
0005433717228	7444	Economy	10700.00
0005433717240	7444	Economy	10700.00
0005433722382	7444	Economy	10700.00
0005433717214	7444	Economy	10700.00
0005433656753	7444	Economy	10700.00
0005433717230	7444	Economy	10700.00
0005433717246	7444	Economy	10700.00
0005433656755	7444	Economy	10700.00
0005433722385	7444	Economy	10700.00
0005433717253	7444	Economy	10700.00
0005433717234	7444	Economy	10700.00
0005433717236	7444	Economy	10700.00
0005433717222	7444	Economy	10700.00
0005433717216	7444	Economy	10700.00
0005432078245	7444	Economy	10700.00
0005432078247	7444	Economy	10700.00
0005433690975	7444	Economy	10700.00
0005433722384	7444	Economy	10700.00
0005433717237	7444	Economy	10700.00
0005435266206	7444	Economy	10700.00
0005435266218	7444	Economy	10700.00
0005433717217	7444	Economy	10700.00
0005433722381	7444	Economy	10700.00
0005435266210	7444	Economy	10700.00
0005433717221	7444	Economy	10700.00
0005433717255	7444	Economy	10700.00
0005433717238	7444	Economy	10700.00
0005432078246	7444	Economy	10700.00
0005433688862	7444	Economy	10700.00
0005433717241	7444	Economy	11700.00
0005433719225	7444	Economy	11700.00
0005433717218	7444	Economy	11700.00
0005433717244	7444	Economy	11700.00
0005432429002	7444	Economy	11700.00
0005435266209	7444	Economy	10700.00
0005433717239	7444	Economy	10700.00
0005433717232	7444	Economy	10700.00
0005433717220	7444	Economy	10700.00
0005433717226	7444	Economy	10700.00
0005433717233	7444	Economy	10700.00
0005433722386	7444	Economy	10700.00
0005433722389	7444	Economy	10700.00
0005433722390	7444	Economy	10700.00
0005433656752	7444	Economy	10700.00
0005433717215	7444	Economy	10700.00
0005432428978	7444	Economy	10700.00
0005435266217	7444	Economy	10700.00
0005433689963	7444	Economy	10700.00
0005433717251	7444	Economy	10700.00
0005433717242	7444	Economy	10700.00
0005433717249	7444	Economy	10700.00
0005432428979	7444	Economy	10700.00
0005432078249	7444	Economy	10700.00
0005433722380	7444	Economy	10700.00
0005433717235	7444	Economy	10700.00
0005433717247	7444	Economy	10700.00
0005433722387	7444	Economy	10700.00
0005435266216	7444	Economy	10700.00
0005432428982	7444	Economy	10700.00
0005432078250	7444	Economy	10700.00
0005433717225	7444	Economy	10700.00
0005433717229	7444	Economy	10700.00
0005433717223	7444	Economy	10700.00
0005433719224	7444	Economy	10700.00
0005433656754	7444	Economy	10700.00
0005433717254	7444	Economy	10700.00
0005435266215	7444	Economy	10700.00
0005432078248	7444	Economy	10700.00
0005433717243	7444	Economy	10700.00
0005435266214	7444	Economy	10700.00
0005433717224	7444	Economy	10700.00
0005433717219	7444	Economy	10700.00
0005433719226	7444	Economy	10700.00
0005433717245	7444	Economy	10700.00
0005435266219	7444	Economy	10700.00
0005433717231	7444	Economy	10700.00
0005433717248	7444	Economy	10700.00
0005433717252	7444	Economy	10700.00
0005433717227	7444	Economy	10700.00
0005433717250	7444	Economy	10700.00
0005435266207	7444	Economy	10700.00
0005433716734	29227	Business	32000.00
0005435266307	29227	Business	32000.00
0005433716900	29227	Business	32000.00
0005435266308	29227	Business	32000.00
0005433722315	29227	Business	32000.00
0005433716526	29227	Business	32000.00
0005433716934	29227	Business	32000.00
0005435266314	29227	Economy	10700.00
0005433716888	29227	Economy	10700.00
0005435266302	29227	Economy	10700.00
0005435266303	29227	Economy	10700.00
0005435266306	29227	Economy	10700.00
0005433656742	29227	Economy	10700.00
0005432006836	29227	Economy	10700.00
0005433716737	29227	Economy	10700.00
0005433722328	29227	Economy	10700.00
0005433716407	29227	Economy	10700.00
0005435266304	29227	Economy	10700.00
0005435266299	29227	Economy	10700.00
0005433716527	29227	Economy	10700.00
0005433722314	29227	Economy	10700.00
0005433716801	29227	Economy	10700.00
0005433722329	29227	Economy	10700.00
0005435266309	29227	Economy	10700.00
0005433656741	29227	Economy	10700.00
0005433716408	29227	Economy	10700.00
0005433716816	29227	Economy	10700.00
0005432429017	29227	Economy	10700.00
0005435266298	29227	Economy	10700.00
0005435266296	29227	Economy	10700.00
0005433722325	29227	Economy	10700.00
0005433722327	29227	Economy	11700.00
0005435266312	29227	Economy	11700.00
0005433716875	29227	Economy	11700.00
0005433716603	29227	Economy	11700.00
0005433716815	29227	Economy	10700.00
0005432006837	29227	Economy	11700.00
0005435266305	29227	Economy	10700.00
0005433722310	29227	Economy	10700.00
0005433716826	29227	Economy	10700.00
0005435266297	29227	Economy	10700.00
0005433716709	29227	Economy	10700.00
0005433716817	29227	Economy	10700.00
0005433716949	29227	Economy	10700.00
0005433722311	29227	Economy	10700.00
0005433656743	29227	Economy	10700.00
0005433716986	29227	Economy	10700.00
0005435266295	29227	Economy	10700.00
0005435266310	29227	Economy	10700.00
0005433716950	29227	Economy	10700.00
0005433716741	29227	Economy	10700.00
0005435266301	29227	Economy	10700.00
0005433716868	29227	Economy	10700.00
0005433685561	29227	Economy	10700.00
0005433716890	29227	Economy	10700.00
0005435266294	29227	Economy	10700.00
0005435266300	29227	Economy	10700.00
0005433722313	29227	Economy	10700.00
0005433656707	29227	Economy	10700.00
0005433716910	29227	Economy	10700.00
0005433716794	29227	Economy	10700.00
0005435266315	29227	Economy	10700.00
0005433716887	29227	Economy	10700.00
0005433656708	29227	Economy	10700.00
0005435266313	29227	Economy	10700.00
0005433685560	29227	Economy	10700.00
0005433719193	29227	Economy	10700.00
0005435266316	29227	Economy	10700.00
0005433716740	29227	Economy	10700.00
0005433716669	29227	Economy	10700.00
0005435266317	29227	Economy	10700.00
0005433716861	29227	Economy	10700.00
0005433716836	29227	Economy	10700.00
0005435266311	29227	Economy	10700.00
0005433716778	29227	Economy	10700.00
0005433656740	29227	Economy	10700.00
0005434095647	8683	Business	36500.00
0005434095646	8683	Business	36500.00
0005434184691	8683	Business	36500.00
0005434182422	8683	Economy	12200.00
0005434095642	8683	Economy	12200.00
0005434095648	8683	Economy	12200.00
0005434095637	8683	Economy	12200.00
0005434182439	8683	Economy	13400.00
0005434095643	8683	Economy	12200.00
0005434182433	8683	Economy	12200.00
0005434182434	8683	Economy	12200.00
0005434182418	8683	Economy	12200.00
0005434095644	8683	Economy	12200.00
0005434182426	8683	Economy	12200.00
0005434182440	8683	Economy	12200.00
0005434184693	8683	Economy	12200.00
0005434182391	8683	Economy	12200.00
0005434182427	8683	Economy	12200.00
0005434095639	8683	Economy	12200.00
0005434184700	8683	Economy	12200.00
0005434095638	8683	Economy	12200.00
0005434143753	8683	Economy	12200.00
0005434095645	8683	Economy	12200.00
0005434095640	8683	Economy	12200.00
0005434095636	8683	Economy	12200.00
0005434182432	8683	Economy	12200.00
0005434182401	8683	Economy	12200.00
0005434182419	8683	Economy	12200.00
0005434095641	8683	Economy	12200.00
0005435860671	11680	Business	36500.00
0005434182501	11680	Business	36500.00
0005434095509	11680	Business	36500.00
0005434182498	11680	Business	36500.00
0005434095512	11680	Economy	12200.00
0005435860674	11680	Economy	12200.00
0005434183630	11680	Economy	12200.00
0005434182502	11680	Economy	12200.00
0005435860677	11680	Economy	12200.00
0005435860669	11680	Economy	12200.00
0005434184716	11680	Economy	12200.00
0005434095529	11680	Economy	12200.00
0005434095530	11680	Economy	12200.00
0005434182500	11680	Economy	12200.00
0005434095556	11680	Economy	12200.00
0005434183629	11680	Economy	12200.00
0005435860667	11680	Economy	12200.00
0005435860673	11680	Economy	12200.00
0005434095499	11680	Economy	12200.00
0005434182504	11680	Economy	12200.00
0005435860670	11680	Economy	12200.00
0005434095498	11680	Economy	12200.00
0005435860676	11680	Economy	12200.00
0005434182506	11680	Economy	12200.00
0005434095476	11680	Economy	12200.00
0005434143745	11680	Economy	12200.00
0005434095531	11680	Economy	12200.00
0005435860678	11680	Economy	12200.00
0005434182507	11680	Economy	12200.00
0005434182497	11680	Economy	12200.00
0005435860672	11680	Economy	12200.00
0005435860679	11680	Economy	12200.00
0005434182496	11680	Economy	12200.00
0005434182503	11680	Economy	12200.00
0005435860675	11680	Economy	12200.00
0005434095497	11680	Economy	12200.00
0005434182505	11680	Economy	12200.00
0005434143746	11680	Economy	12200.00
0005435860668	11680	Economy	12200.00
0005434182499	11680	Economy	12200.00
0005435732637	1465	Business	33000.00
0005433399102	1465	Business	33000.00
0005432297345	1465	Business	33000.00
0005433399058	1465	Business	33000.00
0005433398684	1465	Business	33000.00
0005435725750	1465	Business	33000.00
0005433398852	1465	Business	33000.00
0005433398950	1465	Economy	11000.00
0005433398906	1465	Economy	11000.00
0005433398938	1465	Economy	11000.00
0005435732639	1465	Economy	11000.00
0005435732645	1465	Economy	11000.00
0005435732646	1465	Economy	11000.00
0005433398792	1465	Economy	11000.00
0005433398907	1465	Economy	11000.00
0005433398973	1465	Economy	12100.00
0005433399100	1465	Economy	12100.00
0005433398887	1465	Economy	12100.00
0005435725751	1465	Economy	12100.00
0005433398984	1465	Economy	11000.00
0005435732643	1465	Economy	11000.00
0005433398789	1465	Economy	11000.00
0005435732650	1465	Economy	11000.00
0005433398778	1465	Economy	11000.00
0005432297344	1465	Economy	11000.00
0005433398793	1465	Economy	11000.00
0005435732644	1465	Economy	11000.00
0005433398826	1465	Economy	11000.00
0005433398864	1465	Economy	11000.00
0005433398868	1465	Economy	11000.00
0005433457073	1465	Economy	11000.00
0005432906576	1465	Economy	11000.00
0005433398951	1465	Economy	11000.00
0005433398895	1465	Economy	11000.00
0005433398854	1465	Economy	11000.00
0005433398779	1465	Economy	11000.00
0005433398724	1465	Economy	11000.00
0005433398900	1465	Economy	11000.00
0005433398924	1465	Economy	11000.00
0005435732642	1465	Economy	11000.00
0005433398723	1465	Economy	11000.00
0005433457072	1465	Economy	11000.00
0005432906577	1465	Economy	11000.00
0005433399059	1465	Economy	11000.00
0005435725749	1465	Economy	11000.00
0005433457074	1465	Economy	11000.00
0005433398972	1465	Economy	11000.00
0005433398903	1465	Economy	11000.00
0005435732641	1465	Economy	11000.00
0005433399101	1465	Economy	11000.00
0005433398840	1465	Economy	11000.00
0005433398682	1465	Economy	11000.00
0005433398915	1465	Economy	11000.00
0005433398803	1465	Economy	11000.00
0005435732648	1465	Economy	11000.00
0005433398902	1465	Economy	11000.00
0005433398737	1465	Economy	11000.00
0005433398899	1465	Economy	11000.00
0005435732640	1465	Economy	11000.00
0005433398851	1465	Economy	11000.00
0005433398683	1465	Economy	11000.00
0005433398901	1465	Economy	11000.00
0005433398885	1465	Economy	11000.00
0005433457071	1465	Economy	11000.00
0005433398759	1465	Economy	11000.00
0005433398993	1465	Economy	11000.00
0005433398861	1465	Economy	11000.00
0005433398681	1465	Economy	11000.00
0005435732638	1465	Economy	11000.00
0005433398831	1465	Economy	11000.00
0005433399065	1465	Economy	11000.00
0005433398974	1465	Economy	11000.00
0005432906578	1465	Economy	11000.00
0005435732647	1465	Economy	11000.00
0005433398855	1465	Economy	11000.00
0005435732649	1465	Economy	11000.00
0005433399279	19280	Business	33000.00
0005433399269	19280	Business	33000.00
0005433399288	19280	Business	33000.00
0005433399300	19280	Business	33000.00
0005433399307	19280	Business	33000.00
0005433399289	19280	Economy	11000.00
0005433399265	19280	Economy	11000.00
0005435732529	19280	Economy	11000.00
0005433399285	19280	Economy	11000.00
0005433457047	19280	Economy	11000.00
0005433457041	19280	Economy	11000.00
0005433399280	19280	Economy	11000.00
0005433399301	19280	Economy	12100.00
0005435732555	19280	Economy	12100.00
0005433399270	19280	Economy	12100.00
0005433399298	19280	Economy	12100.00
0005433399306	19280	Economy	12100.00
0005433399272	19280	Economy	11000.00
0005433399290	19280	Economy	11000.00
0005433399267	19280	Economy	11000.00
0005433457040	19280	Economy	11000.00
0005433399293	19280	Economy	11000.00
0005433399276	19280	Economy	11000.00
0005433399304	19280	Economy	11000.00
0005435732528	19280	Economy	11000.00
0005433399277	19280	Economy	11000.00
0005433399295	19280	Economy	11000.00
0005435732515	19280	Economy	11000.00
0005433399303	19280	Economy	11000.00
0005435732614	19280	Economy	11000.00
0005433399278	19280	Economy	11000.00
0005433399266	19280	Economy	11000.00
0005435732544	19280	Economy	11000.00
0005435732594	19280	Economy	11000.00
0005433399292	19280	Economy	11000.00
0005433399283	19280	Economy	11000.00
0005433457048	19280	Economy	11000.00
0005433399297	19280	Economy	11000.00
0005433457023	19280	Economy	11000.00
0005433399291	19280	Economy	11000.00
0005435732615	19280	Economy	11000.00
0005433399287	19280	Economy	11000.00
0005435732567	19280	Economy	11000.00
0005433399274	19280	Economy	11000.00
0005433399284	19280	Economy	11000.00
0005433399302	19280	Economy	11000.00
0005432906598	19280	Economy	11000.00
0005433399271	19280	Economy	11000.00
0005433399305	19280	Economy	11000.00
0005435732586	19280	Economy	11000.00
0005433399294	19280	Economy	11000.00
0005433399296	19280	Economy	11000.00
0005433399286	19280	Economy	11000.00
0005433399273	19280	Economy	11000.00
0005433399275	19280	Economy	11000.00
0005432906599	19280	Economy	11000.00
0005435732587	19280	Economy	11000.00
0005435732548	19280	Economy	11000.00
0005433399281	19280	Economy	11000.00
0005433399268	19280	Economy	11000.00
0005433399282	19280	Economy	11000.00
0005433399299	19280	Economy	11000.00
0005434443924	17371	Economy	15600.00
0005434444023	17371	Economy	15600.00
0005434443961	17371	Economy	15600.00
0005434444025	17371	Economy	14100.00
0005434443968	17371	Economy	14100.00
0005434443970	17371	Economy	14100.00
0005434444044	17371	Economy	14100.00
0005434443987	17371	Economy	14100.00
0005434443925	17371	Economy	14100.00
0005434443926	17371	Economy	14100.00
0005434444027	17371	Economy	14100.00
0005434443997	17371	Economy	14100.00
0005434443979	17371	Economy	14100.00
0005434443994	17371	Economy	14100.00
0005434443962	17371	Economy	14100.00
0005434443944	17371	Economy	14100.00
0005434444028	17371	Economy	14100.00
0005434443951	17371	Economy	14100.00
0005434444008	17371	Economy	14100.00
0005434444024	17371	Economy	14100.00
0005434443923	17371	Economy	14100.00
0005434443967	17371	Economy	14100.00
0005434443950	17371	Economy	14100.00
0005434443981	17371	Economy	14100.00
0005434443960	17371	Economy	14100.00
0005434443998	17371	Economy	14100.00
0005434443980	17371	Economy	14100.00
0005434444113	20590	Economy	15600.00
0005434444116	20590	Economy	14100.00
0005434444112	20590	Economy	14100.00
0005434444103	20590	Economy	14100.00
0005434444115	20590	Economy	14100.00
0005434444114	20590	Economy	14100.00
0005434444109	20590	Economy	14100.00
0005434444102	20590	Economy	14100.00
0005434444111	20590	Economy	14100.00
0005434444104	20590	Economy	14100.00
0005434444108	20590	Economy	14100.00
0005434444106	20590	Economy	14100.00
0005434444110	20590	Economy	14100.00
0005434444107	20590	Economy	14100.00
0005434444105	20590	Economy	14100.00
0005434954708	7243	Economy	5800.00
0005435377625	7243	Economy	5800.00
0005435377626	7243	Economy	5800.00
0005435377620	7243	Economy	5800.00
0005435377621	7243	Economy	5800.00
0005435377623	7243	Economy	5800.00
0005434954670	28333	Economy	5800.00
0005434954671	28333	Economy	5800.00
0005434954682	28333	Economy	5800.00
0005434954672	28333	Economy	5800.00
0005435377639	28333	Economy	5800.00
0005435377640	28333	Economy	5800.00
0005435893737	4503	Economy	15400.00
0005434326289	4503	Economy	15400.00
0005435893766	4503	Economy	14000.00
0005434183614	4503	Economy	14000.00
0005435893748	4503	Economy	14000.00
0005434352027	4503	Economy	14000.00
0005434352019	4503	Economy	14000.00
0005434352025	4503	Economy	14000.00
0005435893770	4503	Economy	14000.00
0005435893778	4503	Economy	14000.00
0005435893738	4503	Economy	14000.00
0005434326098	4503	Economy	14000.00
0005435893747	4503	Economy	14000.00
0005434352021	4503	Economy	14000.00
0005435893771	4503	Economy	14000.00
0005434326290	4503	Economy	14000.00
0005434326097	4503	Economy	14000.00
0005434352017	4503	Economy	14000.00
0005434352026	4503	Economy	14000.00
0005434352018	4503	Economy	14000.00
0005435893769	4503	Economy	14000.00
0005434352023	4503	Economy	14000.00
0005434326292	4503	Economy	14000.00
0005434326291	4503	Economy	14000.00
0005434352014	4503	Economy	14000.00
0005434352020	4503	Economy	14000.00
0005434352024	4503	Economy	14000.00
0005435893754	4503	Economy	14000.00
0005434352016	4503	Economy	14000.00
0005434352022	4503	Economy	14000.00
0005434352015	4503	Economy	14000.00
0005435893741	4503	Economy	14000.00
0005435893779	4503	Economy	14000.00
0005434326096	4503	Economy	14000.00
0005434351907	29662	Economy	15400.00
0005434351925	29662	Economy	15400.00
0005435893812	29662	Economy	14000.00
0005435893814	29662	Economy	14000.00
0005434351933	29662	Economy	14000.00
0005434351876	29662	Economy	14000.00
0005434351910	29662	Economy	14000.00
0005434351928	29662	Economy	14000.00
0005435893813	29662	Economy	14000.00
0005434351957	29662	Economy	14000.00
0005434351927	29662	Economy	14000.00
0005434351926	29662	Economy	14000.00
0005434351975	29662	Economy	14000.00
0005434351904	29662	Economy	14000.00
0005435893810	29662	Economy	14000.00
0005434351856	29662	Economy	14000.00
0005435893811	29662	Economy	14000.00
0005435893815	29662	Economy	14000.00
0005434351981	29662	Economy	14000.00
0005433269809	1084	Business	30600.00
0005435545923	1084	Business	30600.00
0005433344712	1084	Business	30600.00
0005433344933	1084	Business	30600.00
0005433344592	1084	Business	30600.00
0005433344668	1084	Business	30600.00
0005433344638	1084	Business	30600.00
0005433345258	1084	Business	30600.00
0005434446577	1084	Business	30600.00
0005433344763	1084	Business	30600.00
0005433344663	1084	Business	30600.00
0005433344423	1084	Business	30600.00
0005432293269	1084	Business	30600.00
0005433344948	1084	Business	30600.00
0005433344684	1084	Business	30600.00
0005433344664	1084	Business	30600.00
0005433344617	1084	Business	30600.00
0005433344755	1084	Business	30600.00
0005435545919	1084	Business	30600.00
0005433344642	1084	Business	30600.00
0005433345012	1084	Business	30600.00
0005433344179	1084	Business	30600.00
0005435545921	1084	Business	30600.00
0005433345257	1084	Business	30600.00
0005433344428	1084	Economy	11200.00
0005435545927	1084	Economy	11200.00
0005433345142	1084	Economy	10200.00
0005435545913	1084	Economy	10200.00
0005433344702	1084	Economy	10200.00
0005433344771	1084	Economy	10200.00
0005433344976	1084	Economy	10200.00
0005435092324	1084	Economy	10200.00
0005433344219	1084	Economy	10200.00
0005435092329	1084	Economy	10200.00
0005433344738	1084	Economy	10200.00
0005433344820	1084	Economy	10200.00
0005433344883	1084	Economy	10200.00
0005435545922	1084	Economy	10200.00
0005433344180	1084	Economy	10200.00
0005433344345	1084	Economy	10200.00
0005433344691	1084	Economy	10200.00
0005433344655	1084	Economy	10200.00
0005433344818	1084	Economy	10200.00
0005433344584	1084	Economy	10200.00
0005433345055	1084	Economy	10200.00
0005433344708	1084	Economy	10200.00
0005433344951	1084	Economy	10200.00
0005433344803	1084	Economy	10200.00
0005433344218	1084	Economy	10200.00
0005435545916	1084	Economy	10200.00
0005433269810	1084	Economy	10200.00
0005433344764	1084	Economy	10200.00
0005433344709	1084	Economy	10200.00
0005433344804	1084	Economy	10200.00
0005433269819	1084	Economy	10200.00
0005432293270	1084	Economy	10200.00
0005435545912	1084	Economy	10200.00
0005433344884	1084	Economy	10200.00
0005433269807	1084	Economy	10200.00
0005435092330	1084	Economy	10200.00
0005433269799	1084	Economy	10200.00
0005433345054	1084	Economy	10200.00
0005433345079	1084	Economy	10200.00
0005433345031	1084	Economy	10200.00
0005433345030	1084	Economy	10200.00
0005435545918	1084	Economy	10200.00
0005433344815	1084	Economy	10200.00
0005435092326	1084	Economy	10200.00
0005433344936	1084	Economy	10200.00
0005433345141	1084	Economy	10200.00
0005433159351	1084	Economy	10200.00
0005435545920	1084	Economy	10200.00
0005435545915	1084	Economy	10200.00
0005433462802	1084	Economy	10200.00
0005435092328	1084	Economy	10200.00
0005434446579	1084	Economy	10200.00
0005433344828	1084	Economy	10200.00
0005435545924	1084	Economy	10200.00
0005433344826	1084	Economy	10200.00
0005435092327	1084	Economy	10200.00
0005433344595	1084	Economy	10200.00
0005433269812	1084	Economy	10200.00
0005433344750	1084	Economy	10200.00
0005433344794	1084	Economy	10200.00
0005435545925	1084	Economy	10200.00
0005433463957	1084	Economy	10200.00
0005433344749	1084	Economy	10200.00
0005433345068	1084	Economy	10200.00
0005433345014	1084	Economy	10200.00
0005433463956	1084	Economy	10200.00
0005433345344	1084	Economy	10200.00
0005433462801	1084	Economy	10200.00
0005433344616	1084	Economy	11200.00
0005434446578	1084	Economy	11200.00
0005433344865	1084	Economy	11200.00
0005435545914	1084	Economy	10200.00
0005433344447	1084	Economy	10200.00
0005433344863	1084	Economy	10200.00
0005433344834	1084	Economy	10200.00
0005433344514	1084	Economy	10200.00
0005434445307	1084	Economy	10200.00
0005433344989	1084	Economy	10200.00
0005433344941	1084	Economy	10200.00
0005433344646	1084	Economy	10200.00
0005433344587	1084	Economy	10200.00
0005435092322	1084	Economy	10200.00
0005433345029	1084	Economy	10200.00
0005433344643	1084	Economy	10200.00
0005433344885	1084	Economy	10200.00
0005433345069	1084	Economy	10200.00
0005433344756	1084	Economy	10200.00
0005433344840	1084	Economy	10200.00
0005433344302	1084	Economy	10200.00
0005432293271	1084	Economy	10200.00
0005433344924	1084	Economy	10200.00
0005433344586	1084	Economy	10200.00
0005433344767	1084	Economy	10200.00
0005434445308	1084	Economy	10200.00
0005433344585	1084	Economy	10200.00
0005433344950	1084	Economy	10200.00
0005433344690	1084	Economy	10200.00
0005433344819	1084	Economy	10200.00
0005433344669	1084	Economy	10200.00
0005433344653	1084	Economy	10200.00
0005433344662	1084	Economy	10200.00
0005433344232	1084	Economy	10200.00
0005433344644	1084	Economy	10200.00
0005433344457	1084	Economy	10200.00
0005433344923	1084	Economy	10200.00
0005433344569	1084	Economy	10200.00
0005433344890	1084	Economy	10200.00
0005433159352	1084	Economy	10200.00
0005433344891	1084	Economy	10200.00
0005435545926	1084	Economy	10200.00
0005433344725	1084	Economy	10200.00
0005435545917	1084	Economy	10200.00
0005433344814	1084	Economy	10200.00
0005433344769	1084	Economy	10200.00
0005433344301	1084	Economy	10200.00
0005433344458	1084	Economy	10200.00
0005433344770	1084	Economy	10200.00
0005435092323	1084	Economy	10200.00
0005435092325	1084	Economy	10200.00
0005433269798	1084	Economy	10200.00
0005433344611	1084	Economy	10200.00
0005435092331	1084	Economy	10200.00
0005433345554	17073	Business	30600.00
0005435508488	17073	Business	30600.00
0005433345644	17073	Business	30600.00
0005433345617	17073	Business	30600.00
0005433345614	17073	Business	30600.00
0005433345560	17073	Business	30600.00
0005433345566	17073	Business	30600.00
0005433345593	17073	Business	30600.00
0005433345567	17073	Business	30600.00
0005433345641	17073	Business	30600.00
0005433345643	17073	Business	30600.00
0005433345621	17073	Business	30600.00
0005433345625	17073	Business	30600.00
0005433345568	17073	Business	30600.00
0005433269856	17073	Business	30600.00
0005433345637	17073	Business	30600.00
0005433345629	17073	Business	30600.00
0005433345610	17073	Business	30600.00
0005435092213	17073	Economy	11200.00
0005433345555	17073	Economy	11200.00
0005433345639	17073	Economy	10200.00
0005433345573	17073	Economy	10200.00
0005433345575	17073	Economy	10200.00
0005433345553	17073	Economy	10200.00
0005435092218	17073	Economy	10200.00
0005433345557	17073	Economy	10200.00
0005433345597	17073	Economy	10200.00
0005433345642	17073	Economy	10200.00
0005433345624	17073	Economy	10200.00
0005433345603	17073	Economy	10200.00
0005433345583	17073	Economy	10200.00
0005433345599	17073	Economy	10200.00
0005433345630	17073	Economy	10200.00
0005433345635	17073	Economy	10200.00
0005433345647	17073	Economy	10200.00
0005433345585	17073	Economy	10200.00
0005435508529	17073	Economy	10200.00
0005435092276	17073	Economy	10200.00
0005433345586	17073	Economy	10200.00
0005434445276	17073	Economy	10200.00
0005435508557	17073	Economy	10200.00
0005435508514	17073	Economy	10200.00
0005435092306	17073	Economy	10200.00
0005433345558	17073	Economy	10200.00
0005433345569	17073	Economy	10200.00
0005433345616	17073	Economy	10200.00
0005434445291	17073	Economy	10200.00
0005433345565	17073	Economy	10200.00
0005433345636	17073	Economy	10200.00
0005433345628	17073	Economy	10200.00
0005433345582	17073	Economy	10200.00
0005435508541	17073	Economy	10200.00
0005435508528	17073	Economy	10200.00
0005433345578	17073	Economy	10200.00
0005433345580	17073	Economy	10200.00
0005433345611	17073	Economy	10200.00
0005433345605	17073	Economy	10200.00
0005433345562	17073	Economy	10200.00
0005435508556	17073	Economy	10200.00
0005433345551	17073	Economy	10200.00
0005433345613	17073	Economy	10200.00
0005433345571	17073	Economy	10200.00
0005435508496	17073	Economy	10200.00
0005435508535	17073	Economy	10200.00
0005433159369	17073	Economy	10200.00
0005433345608	17073	Economy	10200.00
0005433345600	17073	Economy	10200.00
0005433345589	17073	Economy	10200.00
0005433345559	17073	Economy	10200.00
0005433269854	17073	Economy	10200.00
0005433345590	17073	Economy	10200.00
0005433345601	17073	Economy	10200.00
0005433345612	17073	Economy	10200.00
0005435508540	17073	Economy	10200.00
0005433345591	17073	Economy	10200.00
0005433345632	17073	Economy	10200.00
0005433345572	17073	Economy	10200.00
0005433269857	17073	Economy	10200.00
0005433345588	17073	Economy	10200.00
0005435508515	17073	Economy	10200.00
0005433345581	17073	Economy	10200.00
0005433345595	17073	Economy	10200.00
0005433345633	17073	Economy	10200.00
0005433345596	17073	Economy	10200.00
0005433345607	17073	Economy	11200.00
0005433345640	17073	Economy	11200.00
0005433345627	17073	Economy	10200.00
0005433345623	17073	Economy	10200.00
0005435508527	17073	Economy	10200.00
0005435508554	17073	Economy	10200.00
0005433345615	17073	Economy	10200.00
0005435092265	17073	Economy	10200.00
0005433345602	17073	Economy	10200.00
0005433345618	17073	Economy	10200.00
0005433345584	17073	Economy	10200.00
0005433345564	17073	Economy	10200.00
0005433345556	17073	Economy	10200.00
0005435092281	17073	Economy	10200.00
0005433345598	17073	Economy	10200.00
0005433345626	17073	Economy	10200.00
0005435508516	17073	Economy	10200.00
0005433345561	17073	Economy	10200.00
0005435508536	17073	Economy	10200.00
0005433345576	17073	Economy	10200.00
0005433345634	17073	Economy	10200.00
0005433345622	17073	Economy	10200.00
0005433345638	17073	Economy	10200.00
0005433345620	17073	Economy	10200.00
0005433345577	17073	Economy	10200.00
0005435092243	17073	Economy	10200.00
0005435508520	17073	Economy	10200.00
0005433345646	17073	Economy	10200.00
0005433345609	17073	Economy	10200.00
0005433269855	17073	Economy	10200.00
0005433345587	17073	Economy	10200.00
0005433345570	17073	Economy	10200.00
0005435092269	17073	Economy	10200.00
0005433345552	17073	Economy	10200.00
0005435092254	17073	Economy	10200.00
0005433345606	17073	Economy	10200.00
0005433345563	17073	Economy	10200.00
0005435508553	17073	Economy	10200.00
0005435092240	17073	Economy	10200.00
0005435092253	17073	Economy	10200.00
0005433345631	17073	Economy	10200.00
0005433345619	17073	Economy	10200.00
0005433345579	17073	Economy	10200.00
0005435092242	17073	Economy	10200.00
0005433158199	17073	Economy	10200.00
0005433345594	17073	Economy	10200.00
0005433345645	17073	Economy	10200.00
0005435508481	17073	Economy	10200.00
0005433269858	17073	Economy	10200.00
0005433345604	17073	Economy	10200.00
0005433159368	17073	Economy	10200.00
0005435508482	17073	Economy	10200.00
0005433345574	17073	Economy	10200.00
0005433345592	17073	Economy	10200.00
0005435092252	17073	Economy	10200.00
0005435508551	17073	Economy	10200.00
0005432852072	18271	Business	101000.00
0005432390346	18271	Business	101000.00
0005432852062	18271	Business	101000.00
0005432392046	18271	Business	101000.00
0005432390292	18271	Business	101000.00
0005432390377	18271	Business	101000.00
0005432852055	18271	Business	101000.00
0005432852066	18271	Business	101000.00
0005432390344	18271	Business	101000.00
0005432852063	18271	Business	101000.00
0005432852073	18271	Business	101000.00
0005432390288	18271	Business	101000.00
0005432390313	18271	Business	101000.00
0005432390320	18271	Business	101000.00
0005432390330	18271	Business	101000.00
0005432390342	18271	Business	101000.00
0005432392042	18271	Business	101000.00
0005432390233	18271	Economy	33700.00
0005432390298	18271	Economy	33700.00
0005432390275	18271	Economy	33700.00
0005432390290	18271	Economy	33700.00
0005432390338	18271	Economy	33700.00
0005432852068	18271	Economy	33700.00
0005432390268	18271	Economy	33700.00
0005432390300	18271	Economy	33700.00
0005432390336	18271	Economy	33700.00
0005432390307	18271	Economy	33700.00
0005432390232	18271	Economy	33700.00
0005432392028	18271	Economy	33700.00
0005432852059	18271	Economy	33700.00
0005432390318	18271	Economy	37000.00
0005432390243	18271	Economy	37000.00
0005432390242	18271	Economy	37000.00
0005432390296	18271	Economy	37000.00
0005432390337	18271	Economy	33700.00
0005432390278	18271	Economy	33700.00
0005432390351	18271	Economy	33700.00
0005432852060	18271	Economy	33700.00
0005432852065	18271	Economy	33700.00
0005432390285	18271	Economy	33700.00
0005432390293	18271	Economy	33700.00
0005432390244	18271	Economy	33700.00
0005432390353	18271	Economy	33700.00
0005432392041	18271	Economy	33700.00
0005432390295	18271	Economy	33700.00
0005432390245	18271	Economy	33700.00
0005432390280	18271	Economy	33700.00
0005432390321	18271	Economy	33700.00
0005432392047	18271	Economy	33700.00
0005432392020	18271	Economy	33700.00
0005432390299	18271	Economy	33700.00
0005432390354	18271	Economy	33700.00
0005432392048	18271	Economy	33700.00
0005432852067	18271	Economy	33700.00
0005432390341	18271	Economy	33700.00
0005432390257	18271	Economy	33700.00
0005432392040	18271	Economy	33700.00
0005432390314	18271	Economy	33700.00
0005432390272	18271	Economy	33700.00
0005432390256	18271	Economy	33700.00
0005432390345	18271	Economy	33700.00
0005432852061	18271	Economy	33700.00
0005432390258	18271	Economy	33700.00
0005432390276	18271	Economy	33700.00
0005432390301	18271	Economy	33700.00
0005432852071	18271	Economy	33700.00
0005432852064	18271	Economy	33700.00
0005432390309	18271	Economy	33700.00
0005432390281	18271	Economy	33700.00
0005432390310	18271	Economy	33700.00
0005432390312	18271	Economy	33700.00
0005432852070	18271	Economy	33700.00
0005432390360	18271	Economy	33700.00
0005432392045	18271	Economy	33700.00
0005432390279	18271	Economy	33700.00
0005432852056	18271	Economy	33700.00
0005432390218	18271	Economy	33700.00
0005432390286	18271	Economy	33700.00
0005432390339	18271	Economy	33700.00
0005432390271	18271	Economy	33700.00
0005432390319	18271	Economy	33700.00
0005432390376	18271	Economy	33700.00
0005432390343	18271	Economy	33700.00
0005432390219	18271	Economy	33700.00
0005432390357	18271	Economy	33700.00
0005432390253	18271	Economy	33700.00
0005432852057	18271	Economy	33700.00
0005432852074	18271	Economy	33700.00
0005432390347	18271	Economy	33700.00
0005432390317	18271	Economy	33700.00
0005432392049	18271	Economy	33700.00
0005432390311	18271	Economy	33700.00
0005432390294	18271	Economy	33700.00
0005432852058	18271	Economy	33700.00
0005432390291	18271	Economy	33700.00
0005432392019	18271	Economy	33700.00
0005432390269	18271	Economy	33700.00
0005432392037	18271	Economy	33700.00
0005432390308	18271	Economy	33700.00
0005432852069	18271	Economy	33700.00
0005434068743	12808	Business	40300.00
0005434068547	12808	Business	40300.00
0005434068776	12808	Business	40300.00
0005434082155	12808	Business	40300.00
0005434068695	12808	Business	40300.00
0005434068649	12808	Business	40300.00
0005434082218	12808	Business	40300.00
0005434068485	12808	Business	40300.00
0005434068461	12808	Business	40300.00
0005434082300	12808	Business	40300.00
0005434082272	12808	Business	40300.00
0005433989832	12808	Business	40300.00
0005435283460	12808	Economy	13400.00
0005434068455	12808	Economy	13400.00
0005434068702	12808	Economy	13400.00
0005434068518	12808	Economy	13400.00
0005434082175	12808	Economy	13400.00
0005434068531	12808	Economy	13400.00
0005434068763	12808	Economy	13400.00
0005433989829	12808	Economy	13400.00
0005434068870	12808	Economy	13400.00
0005434082345	12808	Economy	13400.00
0005432433819	12808	Economy	13400.00
0005434068626	12808	Economy	13400.00
0005434068419	12808	Economy	13400.00
0005434068877	12808	Economy	13400.00
0005434068717	12808	Economy	13400.00
0005434068255	12808	Economy	13400.00
0005434068693	12808	Economy	13400.00
0005434068895	12808	Economy	13400.00
0005434068624	12808	Economy	13400.00
0005434068648	12808	Economy	13400.00
0005433989862	12808	Economy	13400.00
0005434082283	12808	Economy	13400.00
0005434068546	12808	Economy	13400.00
0005434068545	12808	Economy	13400.00
0005434082227	12808	Economy	13400.00
0005432433815	12808	Economy	13400.00
0005434068647	12808	Economy	13400.00
0005434068582	12808	Economy	13400.00
0005432161210	12808	Economy	13400.00
0005434068645	12808	Economy	13400.00
0005434068842	12808	Economy	13400.00
0005435283461	12808	Economy	13400.00
0005433989861	12808	Economy	13400.00
0005434082306	12808	Economy	13400.00
0005434068773	12808	Economy	13400.00
0005432433817	12808	Economy	13400.00
0005434082221	12808	Economy	13400.00
0005434082304	12808	Economy	13400.00
0005434068331	12808	Economy	13400.00
0005434068731	12808	Economy	14800.00
0005434068835	12808	Economy	14800.00
0005435283459	12808	Economy	14800.00
0005434068817	12808	Economy	14800.00
0005434068720	12808	Economy	14800.00
0005434068621	12808	Economy	13400.00
0005434082331	12808	Economy	13400.00
0005434082297	12808	Economy	13400.00
0005434068432	12808	Economy	13400.00
0005434068569	12808	Economy	13400.00
0005434068493	12808	Economy	13400.00
0005434068532	12808	Economy	13400.00
0005434068896	12808	Economy	13400.00
0005434068734	12808	Economy	13400.00
0005434026734	12808	Economy	13400.00
0005434068558	12808	Economy	13400.00
0005434068719	12808	Economy	13400.00
0005434069027	12808	Economy	13400.00
0005434068775	12808	Economy	13400.00
0005434082301	12808	Economy	13400.00
0005434082352	12808	Economy	13400.00
0005434068644	12808	Economy	13400.00
0005432159976	12808	Economy	13400.00
0005434068330	12808	Economy	13400.00
0005434082323	12808	Economy	13400.00
0005434068486	12808	Economy	13400.00
0005432433816	12808	Economy	13400.00
0005434068872	12808	Economy	13400.00
0005434068961	12808	Economy	13400.00
0005434068623	12808	Economy	13400.00
0005434068517	12808	Economy	13400.00
0005434068772	12808	Economy	13400.00
0005433989831	12808	Economy	13400.00
0005434068878	12808	Economy	13400.00
0005434068620	12808	Economy	13400.00
0005434068631	12808	Economy	13400.00
0005434068765	12808	Economy	13400.00
0005434082170	12808	Economy	13400.00
0005434068710	12808	Economy	13400.00
0005432161209	12808	Economy	13400.00
0005434082299	12808	Economy	13400.00
0005433812962	12808	Economy	13400.00
0005432433818	12808	Economy	13400.00
0005434068667	12808	Economy	13400.00
0005434068534	12808	Economy	13400.00
0005434082332	12808	Economy	13400.00
0005434068651	12808	Economy	13400.00
0005434068622	12808	Economy	13400.00
0005434068967	12808	Economy	13400.00
0005434068732	12808	Economy	13400.00
0005434068696	12808	Economy	13400.00
0005435283458	12808	Economy	13400.00
0005434082219	12808	Economy	13400.00
0005432159977	12808	Economy	13400.00
0005434068968	12808	Economy	13400.00
0005434068705	12808	Economy	13400.00
0005434068774	12808	Economy	13400.00
0005434068869	12808	Economy	13400.00
0005434068960	12808	Economy	13400.00
0005434082276	12808	Economy	13400.00
0005434068433	12808	Economy	13400.00
0005434068570	12808	Economy	13400.00
0005434069003	12808	Economy	13400.00
0005434082307	12808	Economy	13400.00
0005434068709	12808	Economy	13400.00
0005433989833	12808	Economy	13400.00
0005434068615	12808	Economy	13400.00
0005434068837	12808	Economy	13400.00
0005432159975	12808	Economy	13400.00
0005434068562	12808	Economy	13400.00
0005434068897	12808	Economy	13400.00
0005434068630	12808	Economy	13400.00
0005434068694	12808	Economy	13400.00
0005432433814	12808	Economy	13400.00
0005434082220	12808	Economy	13400.00
0005434069325	30642	Business	40300.00
0005434069297	30642	Business	40300.00
0005434069299	30642	Business	40300.00
0005432150387	30642	Business	40300.00
0005434082477	30642	Business	40300.00
0005434069276	30642	Business	40300.00
0005434082478	30642	Business	40300.00
0005433989889	30642	Business	40300.00
0005432186961	30642	Business	40300.00
0005434069314	30642	Business	40300.00
0005434069313	30642	Business	40300.00
0005434069300	30642	Economy	13400.00
0005434069284	30642	Economy	13400.00
0005434069279	30642	Economy	13400.00
0005434069309	30642	Economy	13400.00
0005432150391	30642	Economy	13400.00
0005434082488	30642	Economy	13400.00
0005434082501	30642	Economy	13400.00
0005434082507	30642	Economy	13400.00
0005432150388	30642	Economy	13400.00
0005434082504	30642	Economy	13400.00
0005433989887	30642	Economy	13400.00
0005434069320	30642	Economy	13400.00
0005434069291	30642	Economy	13400.00
0005434069321	30642	Economy	13400.00
0005434069273	30642	Economy	13400.00
0005434069293	30642	Economy	13400.00
0005434082508	30642	Economy	13400.00
0005434069312	30642	Economy	13400.00
0005434082502	30642	Economy	13400.00
0005432150390	30642	Economy	13400.00
0005434082479	30642	Economy	13400.00
0005434069306	30642	Economy	13400.00
0005434069323	30642	Economy	13400.00
0005434069296	30642	Economy	13400.00
0005434069280	30642	Economy	13400.00
0005434069333	30642	Economy	13400.00
0005434069328	30642	Economy	13400.00
0005434069327	30642	Economy	13400.00
0005434082485	30642	Economy	13400.00
0005434082497	30642	Economy	13400.00
0005432433747	30642	Economy	13400.00
0005432433771	30642	Economy	13400.00
0005434082486	30642	Economy	13400.00
0005434069317	30642	Economy	13400.00
0005432433780	30642	Economy	13400.00
0005432150384	30642	Economy	13400.00
0005434069324	30642	Economy	13400.00
0005434082491	30642	Economy	13400.00
0005432150386	30642	Economy	13400.00
0005432186960	30642	Economy	14800.00
0005434082481	30642	Economy	14800.00
0005434082498	30642	Economy	14800.00
0005434069310	30642	Economy	14800.00
0005432186958	30642	Economy	14800.00
0005434069287	30642	Economy	14800.00
0005434069298	30642	Economy	13400.00
0005434069294	30642	Economy	13400.00
0005432150389	30642	Economy	13400.00
0005433989888	30642	Economy	13400.00
0005434069336	30642	Economy	13400.00
0005434082484	30642	Economy	13400.00
0005434069290	30642	Economy	13400.00
0005432433782	30642	Economy	13400.00
0005434069289	30642	Economy	13400.00
0005434082503	30642	Economy	13400.00
0005434069285	30642	Economy	13400.00
0005434069283	30642	Economy	13400.00
0005434069315	30642	Economy	13400.00
0005434069274	30642	Economy	13400.00
0005434082482	30642	Economy	13400.00
0005434082505	30642	Economy	13400.00
0005434082499	30642	Economy	13400.00
0005434069277	30642	Economy	13400.00
0005434082476	30642	Economy	13400.00
0005432433792	30642	Economy	13400.00
0005432433781	30642	Economy	13400.00
0005434069302	30642	Economy	13400.00
0005432186959	30642	Economy	13400.00
0005434082510	30642	Economy	13400.00
0005434069335	30642	Economy	13400.00
0005434069319	30642	Economy	13400.00
0005434082490	30642	Economy	13400.00
0005434069301	30642	Economy	13400.00
0005434082493	30642	Economy	13400.00
0005434082483	30642	Economy	13400.00
0005432150385	30642	Economy	13400.00
0005434082495	30642	Economy	13400.00
0005434069308	30642	Economy	13400.00
0005434069275	30642	Economy	13400.00
0005434069311	30642	Economy	13400.00
0005434069332	30642	Economy	13400.00
0005432433790	30642	Economy	13400.00
0005434082500	30642	Economy	13400.00
0005434069331	30642	Economy	13400.00
0005434069278	30642	Economy	13400.00
0005434069318	30642	Economy	13400.00
0005434069295	30642	Economy	13400.00
0005434069303	30642	Economy	13400.00
0005434069305	30642	Economy	13400.00
0005434082494	30642	Economy	13400.00
0005434082509	30642	Economy	13400.00
0005434082492	30642	Economy	13400.00
0005434082506	30642	Economy	13400.00
0005434069282	30642	Economy	13400.00
0005434069329	30642	Economy	13400.00
0005434082496	30642	Economy	13400.00
0005434069330	30642	Economy	13400.00
0005434069304	30642	Economy	13400.00
0005433989886	30642	Economy	13400.00
0005434069307	30642	Economy	13400.00
0005434082480	30642	Economy	13400.00
0005434082487	30642	Economy	13400.00
0005432433791	30642	Economy	13400.00
0005434069292	30642	Economy	13400.00
0005434069326	30642	Economy	13400.00
0005434082489	30642	Economy	13400.00
0005434069334	30642	Economy	13400.00
0005434069281	30642	Economy	13400.00
0005434069286	30642	Economy	13400.00
0005434069322	30642	Economy	13400.00
0005434069288	30642	Economy	13400.00
0005434069316	30642	Economy	13400.00
0005433686655	19350	Economy	17600.00
0005433686664	19350	Economy	17600.00
0005433686656	19350	Economy	17600.00
0005433689939	19350	Economy	17600.00
0005433689938	19350	Economy	17600.00
0005433689940	19350	Economy	17600.00
0005433686650	19350	Economy	17600.00
0005433689935	19350	Economy	17600.00
0005433686665	19350	Economy	17600.00
0005433686657	19350	Economy	17600.00
0005433689941	19350	Economy	17600.00
0005433689942	19350	Economy	17600.00
0005435463159	5535	Business	35300.00
0005435463001	5535	Business	35300.00
0005434265685	5535	Business	35300.00
0005435462908	5535	Business	35300.00
0005432140653	5535	Business	35300.00
0005435767770	5535	Business	35300.00
0005435767790	5535	Business	35300.00
0005435768105	5535	Business	35300.00
0005432140660	5535	Business	35300.00
0005435463022	5535	Business	35300.00
0005435463134	5535	Business	35300.00
0005435735253	5535	Business	35300.00
0005435767829	5535	Business	35300.00
0005435462991	5535	Business	35300.00
0005434265567	5535	Business	35300.00
0005435463020	5535	Business	35300.00
0005433529375	5535	Business	35300.00
0005435767798	5535	Business	35300.00
0005435767819	5535	Business	35300.00
0005435767827	5535	Business	35300.00
0005433529377	5535	Business	35300.00
0005435768106	5535	Business	35300.00
0005435767836	5535	Business	35300.00
0005435463117	5535	Business	35300.00
0005435725720	5535	Business	35300.00
0005432140658	5535	Business	35300.00
0005434265493	5535	Economy	12900.00
0005435767782	5535	Economy	12900.00
0005435767800	5535	Economy	12900.00
0005435735256	5535	Economy	11800.00
0005435767812	5535	Economy	11800.00
0005434265622	5535	Economy	11800.00
0005435463045	5535	Economy	11800.00
0005434265666	5535	Economy	11800.00
0005435767818	5535	Economy	11800.00
0005435767834	5535	Economy	11800.00
0005434265616	5535	Economy	11800.00
0005432140656	5535	Economy	11800.00
0005435767774	5535	Economy	11800.00
0005435767807	5535	Economy	11800.00
0005435767789	5535	Economy	11800.00
0005435767773	5535	Economy	11800.00
0005435463013	5535	Economy	11800.00
0005435463104	5535	Economy	11800.00
0005435767786	5535	Economy	11800.00
0005435767831	5535	Economy	11800.00
0005435767830	5535	Economy	11800.00
0005434831226	5535	Economy	11800.00
0005435463158	5535	Economy	11800.00
0005435767822	5535	Economy	11800.00
0005435463163	5535	Economy	11800.00
0005435463153	5535	Economy	11800.00
0005435463107	5535	Economy	11800.00
0005435767793	5535	Economy	11800.00
0005435767833	5535	Economy	11800.00
0005435462980	5535	Economy	11800.00
0005435767824	5535	Economy	11800.00
0005435768104	5535	Economy	11800.00
0005435767816	5535	Economy	11800.00
0005435463035	5535	Economy	11800.00
0005435767815	5535	Economy	11800.00
0005435767810	5535	Economy	11800.00
0005435463073	5535	Economy	11800.00
0005435767794	5535	Economy	11800.00
0005435767796	5535	Economy	11800.00
0005434265563	5535	Economy	11800.00
0005435767803	5535	Economy	11800.00
0005435463034	5535	Economy	11800.00
0005435463174	5535	Economy	11800.00
0005434831223	5535	Economy	11800.00
0005435767779	5535	Economy	11800.00
0005435767837	5535	Economy	11800.00
0005435767775	5535	Economy	11800.00
0005435463127	5535	Economy	11800.00
0005435463099	5535	Economy	11800.00
0005432140655	5535	Economy	11800.00
0005435768108	5535	Economy	11800.00
0005435767783	5535	Economy	11800.00
0005434265554	5535	Economy	11800.00
0005435767776	5535	Economy	11800.00
0005433529376	5535	Economy	11800.00
0005435722114	5535	Economy	11800.00
0005435463105	5535	Economy	11800.00
0005434831245	5535	Economy	11800.00
0005434265447	5535	Economy	11800.00
0005435767799	5535	Economy	11800.00
0005434265568	5535	Economy	11800.00
0005434265406	5535	Economy	11800.00
0005435767781	5535	Economy	11800.00
0005435463033	5535	Economy	11800.00
0005435462992	5535	Economy	11800.00
0005435723094	5535	Economy	11800.00
0005435767811	5535	Economy	11800.00
0005435725721	5535	Economy	11800.00
0005435767813	5535	Economy	11800.00
0005435767777	5535	Economy	11800.00
0005432140654	5535	Economy	11800.00
0005435767814	5535	Economy	11800.00
0005432140659	5535	Economy	11800.00
0005433527364	5535	Economy	11800.00
0005435767821	5535	Economy	11800.00
0005434265514	5535	Economy	11800.00
0005435462966	5535	Economy	11800.00
0005435767772	5535	Economy	11800.00
0005435463224	5535	Economy	11800.00
0005435767785	5535	Economy	11800.00
0005435767805	5535	Economy	12900.00
0005434265476	5535	Economy	12900.00
0005435463132	5535	Economy	11800.00
0005435463100	5535	Economy	11800.00
0005435767808	5535	Economy	12900.00
0005433527363	5535	Economy	12900.00
0005435767825	5535	Economy	11800.00
0005435463024	5535	Economy	11800.00
0005435767788	5535	Economy	11800.00
0005435767778	5535	Economy	11800.00
0005435768103	5535	Economy	11800.00
0005435463126	5535	Economy	11800.00
0005435463053	5535	Economy	11800.00
0005435767771	5535	Economy	11800.00
0005435463072	5535	Economy	11800.00
0005435462970	5535	Economy	11800.00
0005435767802	5535	Economy	11800.00
0005435463044	5535	Economy	11800.00
0005435463118	5535	Economy	11800.00
0005435767817	5535	Economy	11800.00
0005434831224	5535	Economy	11800.00
0005435767806	5535	Economy	11800.00
0005435735255	5535	Economy	11800.00
0005435725722	5535	Economy	11800.00
0005435767820	5535	Economy	11800.00
0005435722115	5535	Economy	11800.00
0005434265667	5535	Economy	11800.00
0005434265553	5535	Economy	11800.00
0005435767797	5535	Economy	11800.00
0005435723093	5535	Economy	11800.00
0005434265572	5535	Economy	11800.00
0005435767784	5535	Economy	11800.00
0005432140661	5535	Economy	11800.00
0005435768107	5535	Economy	11800.00
0005434831214	5535	Economy	11800.00
0005435767809	5535	Economy	11800.00
0005435767792	5535	Economy	11800.00
0005435767828	5535	Economy	11800.00
0005434265510	5535	Economy	11800.00
0005435767823	5535	Economy	11800.00
0005435767804	5535	Economy	11800.00
0005435767795	5535	Economy	11800.00
0005434265573	5535	Economy	11800.00
0005435463135	5535	Economy	11800.00
0005435463041	5535	Economy	11800.00
0005435462979	5535	Economy	11800.00
0005435767780	5535	Economy	11800.00
0005435767835	5535	Economy	11800.00
0005435463047	5535	Economy	11800.00
0005435767832	5535	Economy	11800.00
0005435462975	5535	Economy	11800.00
0005435463019	5535	Economy	11800.00
0005434265596	5535	Economy	11800.00
0005435735254	5535	Economy	11800.00
0005435767801	5535	Economy	11800.00
0005434265615	5535	Economy	11800.00
0005434265492	5535	Economy	11800.00
0005435725723	5535	Economy	11800.00
0005435463145	5535	Economy	11800.00
0005435767791	5535	Economy	11800.00
0005435767787	5535	Economy	11800.00
0005435462925	5535	Economy	11800.00
0005435767826	5535	Economy	11800.00
0005434265574	5535	Economy	11800.00
0005435463179	5535	Economy	11800.00
0005435463149	5535	Economy	11800.00
0005435725719	5535	Economy	11800.00
0005432140657	5535	Economy	11800.00
0005434265641	5535	Economy	11800.00
0005435463146	5535	Economy	11800.00
0005435767471	13479	Business	35300.00
0005435767469	13479	Business	35300.00
0005435767265	13479	Business	35300.00
0005435463379	13479	Business	35300.00
0005435767166	13479	Business	35300.00
0005435767219	13479	Business	35300.00
0005435767227	13479	Business	35300.00
0005434265790	13479	Business	35300.00
0005435463391	13479	Business	35300.00
0005435767305	13479	Business	35300.00
0005435767040	13479	Business	35300.00
0005435767224	13479	Business	35300.00
0005434265803	13479	Business	35300.00
0005434265794	13479	Business	35300.00
0005432194619	13479	Business	35300.00
0005434265793	13479	Business	35300.00
0005435766900	13479	Business	35300.00
0005434265792	13479	Business	35300.00
0005435720149	13479	Business	35300.00
0005435767599	13479	Business	35300.00
0005435725683	13479	Economy	12900.00
0005435463380	13479	Economy	12900.00
0005432535961	13479	Economy	12900.00
0005435767075	13479	Economy	12900.00
0005435767317	13479	Economy	11800.00
0005435767229	13479	Economy	11800.00
0005434831271	13479	Economy	11800.00
0005435767600	13479	Economy	11800.00
0005435767264	13479	Economy	11800.00
0005434265786	13479	Economy	11800.00
0005435463404	13479	Economy	11800.00
0005434265804	13479	Economy	11800.00
0005434265800	13479	Economy	11800.00
0005435767409	13479	Economy	11800.00
0005435767283	13479	Economy	11800.00
0005435767181	13479	Economy	11800.00
0005435767141	13479	Economy	11800.00
0005435463382	13479	Economy	11800.00
0005434265782	13479	Economy	11800.00
0005435767262	13479	Economy	11800.00
0005435725696	13479	Economy	11800.00
0005432535959	13479	Economy	11800.00
0005435617188	13479	Economy	11800.00
0005435767472	13479	Economy	11800.00
0005435767113	13479	Economy	11800.00
0005434265784	13479	Economy	11800.00
0005435767173	13479	Economy	11800.00
0005432535960	13479	Economy	11800.00
0005435767274	13479	Economy	11800.00
0005435723072	13479	Economy	11800.00
0005434265801	13479	Economy	11800.00
0005434265806	13479	Economy	11800.00
0005435463393	13479	Economy	11800.00
0005435767077	13479	Economy	11800.00
0005434831272	13479	Economy	11800.00
0005435722104	13479	Economy	11800.00
0005434265802	13479	Economy	11800.00
0005435720141	13479	Economy	11800.00
0005435767481	13479	Economy	11800.00
0005435725669	13479	Economy	11800.00
0005435767333	13479	Economy	11800.00
0005435767178	13479	Economy	11800.00
0005435463395	13479	Economy	11800.00
0005434265788	13479	Economy	11800.00
0005435767251	13479	Economy	11800.00
0005435767436	13479	Economy	11800.00
0005435767238	13479	Economy	11800.00
0005435766822	13479	Economy	11800.00
0005435767180	13479	Economy	11800.00
0005435767327	13479	Economy	11800.00
0005435767222	13479	Economy	11800.00
0005435767270	13479	Economy	11800.00
0005435463390	13479	Economy	11800.00
0005434831270	13479	Economy	11800.00
0005435463394	13479	Economy	11800.00
0005435767394	13479	Economy	11800.00
0005435767232	13479	Economy	11800.00
0005435463388	13479	Economy	11800.00
0005434265797	13479	Economy	11800.00
0005435617186	13479	Economy	11800.00
0005435767195	13479	Economy	11800.00
0005435767362	13479	Economy	11800.00
0005435463389	13479	Economy	11800.00
0005432194615	13479	Economy	11800.00
0005432194617	13479	Economy	11800.00
0005435725695	13479	Economy	11800.00
0005435463377	13479	Economy	11800.00
0005435767275	13479	Economy	11800.00
0005435463405	13479	Economy	11800.00
0005434831269	13479	Economy	11800.00
0005435463392	13479	Economy	11800.00
0005434265807	13479	Economy	11800.00
0005435767095	13479	Economy	11800.00
0005435617187	13479	Economy	11800.00
0005435767393	13479	Economy	11800.00
0005434265795	13479	Economy	11800.00
0005435767295	13479	Economy	11800.00
0005432535958	13479	Economy	11800.00
0005435767070	13479	Economy	11800.00
0005435463387	13479	Economy	11800.00
0005435463403	13479	Economy	12900.00
0005435767177	13479	Economy	11800.00
0005435463401	13479	Economy	12900.00
0005435767104	13479	Economy	11800.00
0005435767308	13479	Economy	11800.00
0005435767482	13479	Economy	12900.00
0005435767218	13479	Economy	12900.00
0005435767257	13479	Economy	11800.00
0005432535957	13479	Economy	11800.00
0005435767263	13479	Economy	11800.00
0005435767408	13479	Economy	11800.00
0005435767279	13479	Economy	11800.00
0005435723073	13479	Economy	11800.00
0005435463384	13479	Economy	11800.00
0005434265783	13479	Economy	11800.00
0005435767228	13479	Economy	11800.00
0005435725679	13479	Economy	11800.00
0005435767473	13479	Economy	11800.00
0005435463385	13479	Economy	11800.00
0005434265799	13479	Economy	11800.00
0005435767160	13479	Economy	11800.00
0005434265798	13479	Economy	11800.00
0005435617185	13479	Economy	11800.00
0005435767208	13479	Economy	11800.00
0005434265787	13479	Economy	11800.00
0005435463397	13479	Economy	11800.00
0005435767223	13479	Economy	11800.00
0005435725680	13479	Economy	11800.00
0005435767159	13479	Economy	11800.00
0005435463386	13479	Economy	11800.00
0005435463402	13479	Economy	11800.00
0005435463400	13479	Economy	11800.00
0005435767140	13479	Economy	11800.00
0005435767266	13479	Economy	11800.00
0005435463398	13479	Economy	11800.00
0005435463399	13479	Economy	11800.00
0005434265805	13479	Economy	11800.00
0005432194616	13479	Economy	11800.00
0005435767250	13479	Economy	11800.00
0005435463378	13479	Economy	11800.00
0005435725672	13479	Economy	11800.00
0005435463406	13479	Economy	11800.00
0005434265785	13479	Economy	11800.00
0005435725691	13479	Economy	11800.00
0005435767357	13479	Economy	11800.00
0005435767012	13479	Economy	11800.00
0005435463383	13479	Economy	11800.00
0005435463376	13479	Economy	11800.00
0005434265791	13479	Economy	11800.00
0005435767231	13479	Economy	11800.00
0005435767176	13479	Economy	11800.00
0005435463396	13479	Economy	11800.00
0005435767321	13479	Economy	11800.00
0005434265796	13479	Economy	11800.00
0005435725684	13479	Economy	11800.00
0005435767139	13479	Economy	11800.00
0005435767282	13479	Economy	11800.00
0005435767213	13479	Economy	11800.00
0005435767071	13479	Economy	11800.00
0005435463375	13479	Economy	11800.00
0005432194618	13479	Economy	11800.00
0005435767078	13479	Economy	11800.00
0005435767556	13479	Economy	11800.00
0005435767320	13479	Economy	11800.00
0005435463381	13479	Economy	11800.00
0005434265789	13479	Economy	11800.00
0005434602943	18666	Economy	3300.00
0005434602940	18666	Economy	3300.00
0005434602948	18666	Economy	3300.00
0005434602935	18666	Economy	3300.00
0005434515034	18665	Economy	3300.00
0005434604956	18665	Economy	3300.00
0005434515035	18665	Economy	3300.00
0005434513644	18665	Economy	3300.00
0005434515032	18665	Economy	3300.00
0005434604955	18665	Economy	3300.00
0005434513645	18665	Economy	3300.00
0005434604948	18665	Economy	3300.00
0005434604954	18665	Economy	3300.00
0005434604939	18665	Economy	3300.00
0005434515033	18665	Economy	3300.00
0005434515031	18665	Economy	3300.00
0005434602965	19187	Economy	3300.00
0005434602966	19187	Economy	3300.00
0005434602967	19187	Economy	3300.00
0005434602963	19187	Economy	3300.00
0005434603022	19187	Economy	3300.00
0005434515006	19187	Economy	3300.00
0005434602962	19187	Economy	3300.00
0005434603023	19187	Economy	3300.00
0005434602961	19187	Economy	3300.00
0005434603021	19187	Economy	3300.00
0005434602964	19187	Economy	3300.00
0005435846342	25100	Business	88300.00
0005435844411	25100	Business	88300.00
0005435846341	25100	Business	88300.00
0005435844408	25100	Business	88300.00
0005432649494	25100	Business	88300.00
0005432649500	25100	Business	88300.00
0005432649503	25100	Business	88300.00
0005435844417	25100	Economy	29400.00
0005435846345	25100	Economy	29400.00
0005432632837	25100	Economy	29400.00
0005432649502	25100	Economy	29400.00
0005435846346	25100	Economy	32400.00
0005435844416	25100	Economy	32400.00
0005432649493	25100	Economy	32400.00
0005432632873	25100	Economy	29400.00
0005432632865	25100	Economy	29400.00
0005432632815	25100	Economy	29400.00
0005435844412	25100	Economy	29400.00
0005432649505	25100	Economy	29400.00
0005432649461	25100	Economy	29400.00
0005432649474	25100	Economy	29400.00
0005432632808	25100	Economy	29400.00
0005435846344	25100	Economy	29400.00
0005432649488	25100	Economy	29400.00
0005432632845	25100	Economy	29400.00
0005432649478	25100	Economy	29400.00
0005432649484	25100	Economy	29400.00
0005432649487	25100	Economy	29400.00
0005432632834	25100	Economy	29400.00
0005435844415	25100	Economy	29400.00
0005432632811	25100	Economy	29400.00
0005432649485	25100	Economy	29400.00
0005435844413	25100	Economy	29400.00
0005435846340	25100	Economy	29400.00
0005432632816	25100	Economy	29400.00
0005432632835	25100	Economy	29400.00
0005432649496	25100	Economy	29400.00
0005432649495	25100	Economy	29400.00
0005432649491	25100	Economy	29400.00
0005435844410	25100	Economy	29400.00
0005435844419	25100	Economy	29400.00
0005432632857	25100	Economy	29400.00
0005432649501	25100	Economy	29400.00
0005432632841	25100	Economy	29400.00
0005432649504	25100	Economy	29400.00
0005435844414	25100	Economy	29400.00
0005432632810	25100	Economy	29400.00
0005432632805	25100	Economy	29400.00
0005435844418	25100	Economy	29400.00
0005435846343	25100	Economy	29400.00
0005432632824	25100	Economy	29400.00
0005432649499	25100	Economy	29400.00
0005435846347	25100	Economy	29400.00
0005432649486	25100	Economy	29400.00
0005432632823	25100	Economy	29400.00
0005435844409	25100	Economy	29400.00
0005433009356	1887	Business	48700.00
0005433810702	1887	Business	48700.00
0005433285798	1887	Business	48700.00
0005433009265	1887	Business	48700.00
0005433285944	1887	Business	48700.00
0005433009401	1887	Business	48700.00
0005433285797	1887	Business	48700.00
0005433009405	1887	Business	48700.00
0005433009453	1887	Business	48700.00
0005433009369	1887	Business	48700.00
0005433285845	1887	Business	48700.00
0005432295948	1887	Business	48700.00
0005433285823	1887	Economy	16200.00
0005433009370	1887	Economy	16200.00
0005433285838	1887	Economy	16200.00
0005433285778	1887	Economy	16200.00
0005433285840	1887	Economy	16200.00
0005433009426	1887	Economy	16200.00
0005433285832	1887	Economy	16200.00
0005433009361	1887	Economy	16200.00
0005433285852	1887	Economy	16200.00
0005433009383	1887	Economy	16200.00
0005433009498	1887	Economy	17900.00
0005432295946	1887	Economy	17900.00
0005433009554	1887	Economy	17900.00
0005433285802	1887	Economy	17900.00
0005433285819	1887	Economy	17900.00
0005433285925	1887	Economy	16200.00
0005433285847	1887	Economy	16200.00
0005433009262	1887	Economy	16200.00
0005433285884	1887	Economy	16200.00
0005433009334	1887	Economy	16200.00
0005433009362	1887	Economy	16200.00
0005433285743	1887	Economy	16200.00
0005433285855	1887	Economy	16200.00
0005433285956	1887	Economy	16200.00
0005433285846	1887	Economy	16200.00
0005433285777	1887	Economy	16200.00
0005433810701	1887	Economy	16200.00
0005433009427	1887	Economy	16200.00
0005433285799	1887	Economy	16200.00
0005433009553	1887	Economy	16200.00
0005433285760	1887	Economy	16200.00
0005433285839	1887	Economy	16200.00
0005433009436	1887	Economy	16200.00
0005433009412	1887	Economy	16200.00
0005433009357	1887	Economy	16200.00
0005433009272	1887	Economy	16200.00
0005433009269	1887	Economy	16200.00
0005433285824	1887	Economy	16200.00
0005433009481	1887	Economy	16200.00
0005433009333	1887	Economy	16200.00
0005433009267	1887	Economy	16200.00
0005433285831	1887	Economy	16200.00
0005433009277	1887	Economy	16200.00
0005433009387	1887	Economy	16200.00
0005433285957	1887	Economy	16200.00
0005433009557	1887	Economy	16200.00
0005433009479	1887	Economy	16200.00
0005433009402	1887	Economy	16200.00
0005433009289	1887	Economy	16200.00
0005433009499	1887	Economy	16200.00
0005433285883	1887	Economy	16200.00
0005433009500	1887	Economy	16200.00
0005433285653	1887	Economy	16200.00
0005433009512	1887	Economy	16200.00
0005433285820	1887	Economy	16200.00
0005433285830	1887	Economy	16200.00
0005433009524	1887	Economy	16200.00
0005433009273	1887	Economy	16200.00
0005433285924	1887	Economy	16200.00
0005433285818	1887	Economy	16200.00
0005433810703	1887	Economy	16200.00
0005433810704	1887	Economy	16200.00
0005433285833	1887	Economy	16200.00
0005433009336	1887	Economy	16200.00
0005433009332	1887	Economy	16200.00
0005433009568	1887	Economy	16200.00
0005433009437	1887	Economy	16200.00
0005433009424	1887	Economy	16200.00
0005433009211	1887	Economy	16200.00
0005433285968	1887	Economy	16200.00
0005433285844	1887	Economy	16200.00
0005433009468	1887	Economy	16200.00
0005433009312	1887	Economy	16200.00
0005432295947	1887	Economy	16200.00
0005433285782	1887	Economy	16200.00
0005433009382	1887	Economy	16200.00
0005433285817	1887	Economy	16200.00
0005433009378	1887	Economy	16200.00
0005433285748	1887	Economy	16200.00
0005433009290	1887	Economy	16200.00
0005433009268	1887	Economy	16200.00
0005433285927	1887	Economy	16200.00
0005433285877	1887	Economy	16200.00
0005433810588	22620	Business	48700.00
0005433009736	22620	Business	48700.00
0005433009755	22620	Business	48700.00
0005433286064	22620	Business	48700.00
0005433009732	22620	Business	48700.00
0005433286063	22620	Business	48700.00
0005433009756	22620	Business	48700.00
0005433810596	22620	Business	48700.00
0005433009753	22620	Business	48700.00
0005433009724	22620	Business	48700.00
0005433009743	22620	Business	48700.00
0005433009766	22620	Business	48700.00
0005433286076	22620	Economy	16200.00
0005433009752	22620	Economy	16200.00
0005433286078	22620	Economy	16200.00
0005433286066	22620	Economy	16200.00
0005433009725	22620	Economy	16200.00
0005433009768	22620	Economy	16200.00
0005433286071	22620	Economy	16200.00
0005433286079	22620	Economy	17900.00
0005433009733	22620	Economy	17900.00
0005433009728	22620	Economy	17900.00
0005433286068	22620	Economy	17900.00
0005433009730	22620	Economy	16200.00
0005433286082	22620	Economy	16200.00
0005433009764	22620	Economy	16200.00
0005433286075	22620	Economy	16200.00
0005433009737	22620	Economy	16200.00
0005433009749	22620	Economy	16200.00
0005433286085	22620	Economy	16200.00
0005433009741	22620	Economy	16200.00
0005433009740	22620	Economy	16200.00
0005433286070	22620	Economy	16200.00
0005433009760	22620	Economy	16200.00
0005433009762	22620	Economy	16200.00
0005433286067	22620	Economy	16200.00
0005433009765	22620	Economy	16200.00
0005433286084	22620	Economy	16200.00
0005433286069	22620	Economy	16200.00
0005433286086	22620	Economy	16200.00
0005433009754	22620	Economy	16200.00
0005433286077	22620	Economy	16200.00
0005433009767	22620	Economy	16200.00
0005433009744	22620	Economy	16200.00
0005433009726	22620	Economy	16200.00
0005433810595	22620	Economy	16200.00
0005433009739	22620	Economy	16200.00
0005433009748	22620	Economy	16200.00
0005433009735	22620	Economy	16200.00
0005433286088	22620	Economy	16200.00
0005433810587	22620	Economy	16200.00
0005433009745	22620	Economy	16200.00
0005433009729	22620	Economy	16200.00
0005433286072	22620	Economy	16200.00
0005433009747	22620	Economy	16200.00
0005433286074	22620	Economy	16200.00
0005433286059	22620	Economy	16200.00
0005433009758	22620	Economy	16200.00
0005433009734	22620	Economy	16200.00
0005433009763	22620	Economy	16200.00
0005433286060	22620	Economy	16200.00
0005433286083	22620	Economy	16200.00
0005433009746	22620	Economy	16200.00
0005433286081	22620	Economy	16200.00
0005433009761	22620	Economy	16200.00
0005433009738	22620	Economy	16200.00
0005433009757	22620	Economy	16200.00
0005433286061	22620	Economy	16200.00
0005433286080	22620	Economy	16200.00
0005433286087	22620	Economy	16200.00
0005433286065	22620	Economy	16200.00
0005433009769	22620	Economy	16200.00
0005433286058	22620	Economy	16200.00
0005433009727	22620	Economy	16200.00
0005433810583	22620	Economy	16200.00
0005433286073	22620	Economy	16200.00
0005433009751	22620	Economy	16200.00
0005433286062	22620	Economy	16200.00
0005433009731	22620	Economy	16200.00
0005433009742	22620	Economy	16200.00
0005433009759	22620	Economy	16200.00
0005433009750	22620	Economy	16200.00
0005434153553	25343	Business	83800.00
0005432755146	25343	Business	83800.00
0005432756924	25343	Economy	27900.00
0005432756926	25343	Economy	30700.00
0005432755152	25343	Economy	30700.00
0005434153549	25343	Economy	30700.00
0005434152806	25343	Economy	27900.00
0005432756918	25343	Economy	27900.00
0005432755148	25343	Economy	27900.00
0005432755151	25343	Economy	27900.00
0005432756927	25343	Economy	27900.00
0005434152817	25343	Economy	27900.00
0005432755154	25343	Economy	27900.00
0005432755158	25343	Economy	27900.00
0005432756923	25343	Economy	27900.00
0005434152822	25343	Economy	27900.00
0005432756919	25343	Economy	27900.00
0005432755147	25343	Economy	27900.00
0005432756928	25343	Economy	27900.00
0005432755155	25343	Economy	27900.00
0005434152820	25343	Economy	27900.00
0005432756917	25343	Economy	27900.00
0005432755159	25343	Economy	27900.00
0005434152823	25343	Economy	27900.00
0005434152783	25343	Economy	27900.00
0005432756925	25343	Economy	27900.00
0005432755145	25343	Economy	27900.00
0005434153542	25343	Economy	27900.00
0005432755157	25343	Economy	27900.00
0005434153552	25343	Economy	27900.00
0005434153547	25343	Economy	27900.00
0005432756921	25343	Economy	27900.00
0005434152816	25343	Economy	27900.00
0005434152819	25343	Economy	27900.00
0005432756920	25343	Economy	27900.00
0005432755149	25343	Economy	27900.00
0005432756922	25343	Economy	27900.00
0005434152803	25343	Economy	27900.00
0005432755156	25343	Economy	27900.00
0005434152818	25343	Economy	27900.00
0005432755150	25343	Economy	27900.00
0005432755153	25343	Economy	27900.00
0005433848199	5578	Business	99800.00
0005433815503	5578	Business	99800.00
0005435282823	5578	Business	99800.00
0005433848214	5578	Business	99800.00
0005433848181	5578	Business	99800.00
0005433848211	5578	Business	99800.00
0005435282992	5578	Business	99800.00
0005433848180	5578	Business	99800.00
0005433848174	5578	Business	99800.00
0005433815506	5578	Business	99800.00
0005433815546	5578	Business	99800.00
0005433848225	5578	Business	99800.00
0005435282895	5578	Business	99800.00
0005435282820	5578	Business	99800.00
0005433848184	5578	Business	99800.00
0005433848208	5578	Business	99800.00
0005433848189	5578	Economy	33300.00
0005434173589	5578	Economy	33300.00
0005435282974	5578	Economy	33300.00
0005435282867	5578	Economy	33300.00
0005435282832	5578	Economy	33300.00
0005433848209	5578	Economy	33300.00
0005434173577	5578	Economy	33300.00
0005433848222	5578	Economy	33300.00
0005433848223	5578	Economy	33300.00
0005433848202	5578	Economy	33300.00
0005433815544	5578	Economy	33300.00
0005433848188	5578	Economy	36600.00
0005435283082	5578	Economy	36600.00
0005433815505	5578	Economy	36600.00
0005433848224	5578	Economy	36600.00
0005433848190	5578	Economy	33300.00
0005433848196	5578	Economy	33300.00
0005435282909	5578	Economy	33300.00
0005433848206	5578	Economy	33300.00
0005433848197	5578	Economy	33300.00
0005432081673	5578	Economy	33300.00
0005433848216	5578	Economy	33300.00
0005433848179	5578	Economy	33300.00
0005433848186	5578	Economy	33300.00
0005433848198	5578	Economy	33300.00
0005433848183	5578	Economy	33300.00
0005433848173	5578	Economy	33300.00
0005435282908	5578	Economy	33300.00
0005433848203	5578	Economy	33300.00
0005433848201	5578	Economy	33300.00
0005435282993	5578	Economy	33300.00
0005432081676	5578	Economy	33300.00
0005433848212	5578	Economy	33300.00
0005433848226	5578	Economy	33300.00
0005432081678	5578	Economy	33300.00
0005433848177	5578	Economy	33300.00
0005433848218	5578	Economy	33300.00
0005433848182	5578	Economy	33300.00
0005433848192	5578	Economy	33300.00
0005435282975	5578	Economy	33300.00
0005433848227	5578	Economy	33300.00
0005433815545	5578	Economy	33300.00
0005433848187	5578	Economy	33300.00
0005433848205	5578	Economy	33300.00
0005435283045	5578	Economy	33300.00
0005435282999	5578	Economy	33300.00
0005432081672	5578	Economy	33300.00
0005433848204	5578	Economy	33300.00
0005433848185	5578	Economy	33300.00
0005433848213	5578	Economy	33300.00
0005433848195	5578	Economy	33300.00
0005435282814	5578	Economy	33300.00
0005433848215	5578	Economy	33300.00
0005433848210	5578	Economy	33300.00
0005433848207	5578	Economy	33300.00
0005435282991	5578	Economy	33300.00
0005433815507	5578	Economy	33300.00
0005433848178	5578	Economy	33300.00
0005433848175	5578	Economy	33300.00
0005435283004	5578	Economy	33300.00
0005432081679	5578	Economy	33300.00
0005433848221	5578	Economy	33300.00
0005435282924	5578	Economy	33300.00
0005435283005	5578	Economy	33300.00
0005432081675	5578	Economy	33300.00
0005433815543	5578	Economy	33300.00
0005432081674	5578	Economy	33300.00
0005435282896	5578	Economy	33300.00
0005433815504	5578	Economy	33300.00
0005435282813	5578	Economy	33300.00
0005433848191	5578	Economy	33300.00
0005435282833	5578	Economy	33300.00
0005433848193	5578	Economy	33300.00
0005434173571	5578	Economy	33300.00
0005433848220	5578	Economy	33300.00
0005432081677	5578	Economy	33300.00
0005434173578	5578	Economy	33300.00
0005434173590	5578	Economy	33300.00
0005433815548	5578	Economy	33300.00
0005433848200	5578	Economy	33300.00
0005433815547	5578	Economy	33300.00
0005433848217	5578	Economy	33300.00
0005433848176	5578	Economy	33300.00
0005433848194	5578	Economy	33300.00
0005435282831	5578	Economy	33300.00
0005435282945	5578	Economy	33300.00
0005433848219	5578	Economy	33300.00
0005433847611	13827	Business	99800.00
0005433847748	13827	Business	99800.00
0005434173622	13827	Business	99800.00
0005433847849	13827	Business	99800.00
0005433847646	13827	Business	99800.00
0005433847733	13827	Business	99800.00
0005433847708	13827	Business	99800.00
0005433847521	13827	Business	99800.00
0005434173623	13827	Business	99800.00
0005433847616	13827	Business	99800.00
0005434173652	13827	Business	99800.00
0005435283142	13827	Business	99800.00
0005433847727	13827	Business	99800.00
0005435283135	13827	Business	99800.00
0005435283133	13827	Business	99800.00
0005433847524	13827	Business	99800.00
0005433847577	13827	Business	99800.00
0005433847856	13827	Business	99800.00
0005432003782	13827	Business	99800.00
0005433847585	13827	Business	99800.00
0005435283139	13827	Economy	33300.00
0005433847633	13827	Economy	33300.00
0005433847632	13827	Economy	33300.00
0005433847651	13827	Economy	33300.00
0005435283145	13827	Economy	33300.00
0005433847654	13827	Economy	33300.00
0005435283138	13827	Economy	33300.00
0005435283130	13827	Economy	33300.00
0005435283140	13827	Economy	33300.00
0005435283147	13827	Economy	33300.00
0005433847691	13827	Economy	33300.00
0005433847764	13827	Economy	33300.00
0005433847637	13827	Economy	36600.00
0005433847724	13827	Economy	36600.00
0005433847911	13827	Economy	36600.00
0005433815462	13827	Economy	33300.00
0005433847717	13827	Economy	36600.00
0005434173621	13827	Economy	33300.00
0005433847697	13827	Economy	33300.00
0005433847725	13827	Economy	33300.00
0005434173649	13827	Economy	33300.00
0005435283141	13827	Economy	33300.00
0005433847726	13827	Economy	33300.00
0005433847781	13827	Economy	33300.00
0005433847780	13827	Economy	33300.00
0005433847937	13827	Economy	33300.00
0005433847641	13827	Economy	33300.00
0005433847763	13827	Economy	33300.00
0005435283144	13827	Economy	33300.00
0005433847983	13827	Economy	33300.00
0005433847518	13827	Economy	33300.00
0005433847665	13827	Economy	33300.00
0005435283146	13827	Economy	33300.00
0005433847527	13827	Economy	33300.00
0005433847757	13827	Economy	33300.00
0005433847787	13827	Economy	33300.00
0005433847597	13827	Economy	33300.00
0005433847765	13827	Economy	33300.00
0005432003780	13827	Economy	33300.00
0005434173624	13827	Economy	33300.00
0005433847499	13827	Economy	33300.00
0005433847905	13827	Economy	33300.00
0005432003781	13827	Economy	33300.00
0005433847963	13827	Economy	33300.00
0005433847653	13827	Economy	33300.00
0005433847612	13827	Economy	33300.00
0005433847850	13827	Economy	33300.00
0005433847622	13827	Economy	33300.00
0005435283150	13827	Economy	33300.00
0005433847596	13827	Economy	33300.00
0005434173651	13827	Economy	33300.00
0005434173648	13827	Economy	33300.00
0005433847700	13827	Economy	33300.00
0005433847613	13827	Economy	33300.00
0005433847692	13827	Economy	33300.00
0005433847770	13827	Economy	33300.00
0005433847647	13827	Economy	33300.00
0005435283137	13827	Economy	33300.00
0005433847901	13827	Economy	33300.00
0005433847643	13827	Economy	33300.00
0005432003783	13827	Economy	33300.00
0005433847718	13827	Economy	33300.00
0005433847617	13827	Economy	33300.00
0005435283129	13827	Economy	33300.00
0005433847723	13827	Economy	33300.00
0005433847740	13827	Economy	33300.00
0005435283149	13827	Economy	33300.00
0005433847578	13827	Economy	33300.00
0005433847642	13827	Economy	33300.00
0005433847466	13827	Economy	33300.00
0005435283143	13827	Economy	33300.00
0005435283132	13827	Economy	33300.00
0005433847910	13827	Economy	33300.00
0005435283134	13827	Economy	33300.00
0005434173650	13827	Economy	33300.00
0005433847514	13827	Economy	33300.00
0005433847796	13827	Economy	33300.00
0005433847749	13827	Economy	33300.00
0005435283131	13827	Economy	33300.00
0005435283148	13827	Economy	33300.00
0005433847515	13827	Economy	33300.00
0005433847767	13827	Economy	33300.00
0005433847650	13827	Economy	33300.00
0005433847634	13827	Economy	33300.00
0005433847769	13827	Economy	33300.00
0005433847842	13827	Economy	33300.00
0005433847528	13827	Economy	33300.00
0005435283136	13827	Economy	33300.00
0005433815464	13827	Economy	33300.00
0005433847516	13827	Economy	33300.00
0005433847685	13827	Economy	33300.00
0005433847635	13827	Economy	33300.00
0005435332481	7842	Economy	16600.00
0005434621120	7842	Economy	16600.00
0005435332541	7842	Economy	16600.00
0005435332515	7842	Economy	16600.00
0005434621123	7842	Economy	15100.00
0005435332556	7842	Economy	15100.00
0005434621113	7842	Economy	15100.00
0005434621111	7842	Economy	15100.00
0005432112574	7842	Economy	15100.00
0005435332553	7842	Economy	15100.00
0005434621119	7842	Economy	15100.00
0005434621107	7842	Economy	15100.00
0005435332527	7842	Economy	15100.00
0005434621106	7842	Economy	15100.00
0005434621118	7842	Economy	15100.00
0005434621108	7842	Economy	15100.00
0005434621122	7842	Economy	15100.00
0005434621110	7842	Economy	15100.00
0005434621116	7842	Economy	15100.00
0005434621112	7842	Economy	15100.00
0005434621114	7842	Economy	15100.00
0005435332435	7842	Economy	15100.00
0005435332531	7842	Economy	15100.00
0005434621115	7842	Economy	15100.00
0005434621117	7842	Economy	15100.00
0005435332554	7842	Economy	15100.00
0005434621121	7842	Economy	15100.00
0005435332516	7842	Economy	15100.00
0005434621109	7842	Economy	15100.00
0005432112573	7842	Economy	15100.00
0005435332604	32943	Economy	16600.00
0005434621008	32943	Economy	16600.00
0005434620864	32943	Economy	16600.00
0005434620895	32943	Economy	15100.00
0005434620955	32943	Economy	15100.00
0005435332599	32943	Economy	15100.00
0005435332597	32943	Economy	15100.00
0005435332601	32943	Economy	15100.00
0005435332593	32943	Economy	15100.00
0005434620896	32943	Economy	15100.00
0005435332595	32943	Economy	15100.00
0005434621009	32943	Economy	15100.00
0005434620879	32943	Economy	15100.00
0005434620952	32943	Economy	15100.00
0005434620969	32943	Economy	15100.00
0005434620932	32943	Economy	15100.00
0005434620931	32943	Economy	15100.00
0005434620878	32943	Economy	15100.00
0005434620880	32943	Economy	15100.00
0005434620911	32943	Economy	15100.00
0005434620897	32943	Economy	15100.00
0005435332594	32943	Economy	15100.00
0005435332596	32943	Economy	15100.00
0005434620951	32943	Economy	15100.00
0005435332600	32943	Economy	15100.00
0005434620974	32943	Economy	15100.00
0005434620906	32943	Economy	15100.00
0005434620958	32943	Economy	15100.00
0005434620979	32943	Economy	15100.00
0005434620973	32943	Economy	15100.00
0005435332602	32943	Economy	15100.00
0005434620984	32943	Economy	15100.00
0005434620874	32943	Economy	15100.00
0005435332603	32943	Economy	15100.00
0005434620983	32943	Economy	15100.00
0005434620981	32943	Economy	15100.00
0005434620930	32943	Economy	15100.00
0005434620956	32943	Economy	15100.00
0005434620912	32943	Economy	15100.00
0005435332598	32943	Economy	15100.00
0005435786224	4295	Business	38000.00
0005434994273	4295	Business	38000.00
0005435786221	4295	Business	38000.00
0005432190725	4295	Business	38000.00
0005435786247	4295	Business	38000.00
0005435786231	4295	Business	38000.00
0005435937454	4295	Business	38000.00
0005435786239	4295	Economy	12700.00
0005435786243	4295	Economy	12700.00
0005435786222	4295	Economy	12700.00
0005435937447	4295	Economy	12700.00
0005435937446	4295	Economy	12700.00
0005434994272	4295	Economy	13900.00
0005434994269	4295	Economy	13900.00
0005435786236	4295	Economy	13900.00
0005432190726	4295	Economy	13900.00
0005432190728	4295	Economy	12700.00
0005435786232	4295	Economy	12700.00
0005435918749	4295	Economy	12700.00
0005435786240	4295	Economy	12700.00
0005432190727	4295	Economy	12700.00
0005435786226	4295	Economy	12700.00
0005435937453	4295	Economy	12700.00
0005434994271	4295	Economy	12700.00
0005435786223	4295	Economy	12700.00
0005434994266	4295	Economy	12700.00
0005435786225	4295	Economy	12700.00
0005435937445	4295	Economy	12700.00
0005435786230	4295	Economy	12700.00
0005435786245	4295	Economy	12700.00
0005434994268	4295	Economy	12700.00
0005435786238	4295	Economy	12700.00
0005435786229	4295	Economy	12700.00
0005434994270	4295	Economy	12700.00
0005435918715	4295	Economy	12700.00
0005435786233	4295	Economy	12700.00
0005435786219	4295	Economy	12700.00
0005435787407	4295	Economy	12700.00
0005435786220	4295	Economy	12700.00
0005435787409	4295	Economy	12700.00
0005435786227	4295	Economy	12700.00
0005435918750	4295	Economy	12700.00
0005435786241	4295	Economy	12700.00
0005435918742	4295	Economy	12700.00
0005435786244	4295	Economy	12700.00
0005435786234	4295	Economy	12700.00
0005434994267	4295	Economy	12700.00
0005435786228	4295	Economy	12700.00
0005435786246	4295	Economy	12700.00
0005435786218	4295	Economy	12700.00
0005435786235	4295	Economy	12700.00
0005434994274	4295	Economy	12700.00
0005435918714	4295	Economy	12700.00
0005435937452	4295	Economy	12700.00
0005435786242	4295	Economy	12700.00
0005435786248	4295	Economy	12700.00
0005435786237	4295	Economy	12700.00
0005435787408	4295	Economy	12700.00
0005435785744	27333	Business	38000.00
0005435937522	27333	Business	38000.00
0005435785803	27333	Business	38000.00
0005435937519	27333	Business	38000.00
0005434994163	27333	Business	38000.00
0005435918779	27333	Business	38000.00
0005434994186	27333	Business	38000.00
0005434994205	27333	Business	38000.00
0005434994219	27333	Business	38000.00
0005435937525	27333	Business	38000.00
0005435785923	27333	Economy	12700.00
0005435785758	27333	Economy	12700.00
0005435785823	27333	Economy	12700.00
0005435937523	27333	Economy	12700.00
0005435787381	27333	Economy	12700.00
0005435785977	27333	Economy	12700.00
0005435937526	27333	Economy	12700.00
0005435937514	27333	Economy	12700.00
0005435785913	27333	Economy	13900.00
0005434994152	27333	Economy	13900.00
0005435918775	27333	Economy	13900.00
0005435785989	27333	Economy	12700.00
0005435787390	27333	Economy	12700.00
0005435785922	27333	Economy	12700.00
0005435787380	27333	Economy	12700.00
0005435785964	27333	Economy	12700.00
0005435785898	27333	Economy	12700.00
0005434994217	27333	Economy	12700.00
0005434994220	27333	Economy	12700.00
0005435937515	27333	Economy	12700.00
0005435937521	27333	Economy	12700.00
0005435785790	27333	Economy	12700.00
0005434994164	27333	Economy	12700.00
0005435787376	27333	Economy	12700.00
0005435785742	27333	Economy	12700.00
0005432195748	27333	Economy	12700.00
0005435937524	27333	Economy	12700.00
0005435918777	27333	Economy	12700.00
0005435937527	27333	Economy	12700.00
0005435937520	27333	Economy	12700.00
0005435785759	27333	Economy	12700.00
0005432195746	27333	Economy	12700.00
0005435937528	27333	Economy	12700.00
0005435785814	27333	Economy	12700.00
0005435937513	27333	Economy	12700.00
0005435787389	27333	Economy	12700.00
0005435937517	27333	Economy	12700.00
0005435785794	27333	Economy	12700.00
0005435937529	27333	Economy	12700.00
0005435785875	27333	Economy	12700.00
0005435785865	27333	Economy	12700.00
0005435937518	27333	Economy	12700.00
0005435785864	27333	Economy	12700.00
0005435785807	27333	Economy	12700.00
0005435785762	27333	Economy	12700.00
0005435785822	27333	Economy	12700.00
0005434994214	27333	Economy	12700.00
0005435787387	27333	Economy	12700.00
0005435787388	27333	Economy	12700.00
0005435937516	27333	Economy	12700.00
0005432195747	27333	Economy	12700.00
0005434994197	27333	Economy	12700.00
0005435785795	27333	Economy	12700.00
0005435918776	27333	Economy	12700.00
0005435918778	27333	Economy	12700.00
0005432146251	19855	Economy	12800.00
0005432146253	19855	Economy	12800.00
0005432146252	19855	Economy	12800.00
0005432569197	4745	Business	40900.00
0005432461180	4745	Business	40900.00
0005432569171	4745	Business	40900.00
0005432461181	4745	Business	40900.00
0005434082511	4745	Business	40900.00
0005435840388	4745	Business	40900.00
0005432461163	4745	Business	40900.00
0005434082537	4745	Business	40900.00
0005432569180	4745	Business	40900.00
0005432569185	4745	Business	40900.00
0005432569183	4745	Business	40900.00
0005432461190	4745	Business	40900.00
0005432186963	4745	Business	40900.00
0005434082514	4745	Business	40900.00
0005432569186	4745	Business	40900.00
0005435840363	4745	Business	40900.00
0005434082530	4745	Business	40900.00
0005432569206	4745	Business	40900.00
0005434082533	4745	Business	40900.00
0005432186962	4745	Business	40900.00
0005434082519	4745	Business	40900.00
0005432569168	4745	Business	40900.00
0005432461177	4745	Economy	15000.00
0005434559127	4745	Economy	15000.00
0005432461172	4745	Economy	15000.00
0005432461173	4745	Economy	13600.00
0005432569160	4745	Economy	13600.00
0005434559134	4745	Economy	13600.00
0005434082523	4745	Economy	13600.00
0005432569169	4745	Economy	13600.00
0005432461188	4745	Economy	13600.00
0005434082536	4745	Economy	13600.00
0005434082518	4745	Economy	13600.00
0005432569161	4745	Economy	13600.00
0005432569165	4745	Economy	13600.00
0005432461165	4745	Economy	13600.00
0005434559136	4745	Economy	13600.00
0005434559128	4745	Economy	13600.00
0005434082532	4745	Economy	13600.00
0005432461157	4745	Economy	13600.00
0005432569164	4745	Economy	13600.00
0005432461159	4745	Economy	13600.00
0005432569194	4745	Economy	13600.00
0005432461170	4745	Economy	13600.00
0005432461176	4745	Economy	13600.00
0005434082527	4745	Economy	13600.00
0005432461148	4745	Economy	13600.00
0005432461189	4745	Economy	13600.00
0005433726162	4745	Economy	13600.00
0005432569159	4745	Economy	13600.00
0005432569166	4745	Economy	13600.00
0005432569156	4745	Economy	13600.00
0005432569201	4745	Economy	13600.00
0005432569178	4745	Economy	13600.00
0005432461169	4745	Economy	13600.00
0005432569189	4745	Economy	13600.00
0005432461175	4745	Economy	13600.00
0005432569202	4745	Economy	13600.00
0005432461174	4745	Economy	13600.00
0005434082531	4745	Economy	13600.00
0005432461154	4745	Economy	13600.00
0005432569182	4745	Economy	13600.00
0005434559135	4745	Economy	13600.00
0005432461183	4745	Economy	13600.00
0005432569162	4745	Economy	13600.00
0005432569204	4745	Economy	13600.00
0005432461153	4745	Economy	13600.00
0005433726163	4745	Economy	13600.00
0005432569176	4745	Economy	13600.00
0005434082529	4745	Economy	13600.00
0005432569198	4745	Economy	13600.00
0005434082522	4745	Economy	13600.00
0005434082516	4745	Economy	13600.00
0005432461193	4745	Economy	13600.00
0005432569210	4745	Economy	13600.00
0005432569154	4745	Economy	13600.00
0005434082513	4745	Economy	13600.00
0005432170558	4745	Economy	13600.00
0005434082521	4745	Economy	13600.00
0005432461184	4745	Economy	13600.00
0005432569153	4745	Economy	13600.00
0005432569163	4745	Economy	13600.00
0005434559131	4745	Economy	13600.00
0005432461171	4745	Economy	13600.00
0005432461179	4745	Economy	13600.00
0005432569174	4745	Economy	13600.00
0005432569209	4745	Economy	13600.00
0005434082534	4745	Economy	13600.00
0005432461166	4745	Economy	13600.00
0005434082515	4745	Economy	13600.00
0005432461167	4745	Economy	13600.00
0005434082512	4745	Economy	13600.00
0005432569203	4745	Economy	13600.00
0005432569170	4745	Economy	13600.00
0005432461194	4745	Economy	13600.00
0005432461192	4745	Economy	15000.00
0005432569196	4745	Economy	13600.00
0005432461168	4745	Economy	13600.00
0005432571417	4745	Economy	13600.00
0005432569177	4745	Economy	15000.00
0005432569191	4745	Economy	15000.00
0005432170560	4745	Economy	13600.00
0005432461195	4745	Economy	13600.00
0005432569208	4745	Economy	13600.00
0005432569167	4745	Economy	13600.00
0005432569152	4745	Economy	13600.00
0005432569175	4745	Economy	13600.00
0005434082517	4745	Economy	13600.00
0005432461150	4745	Economy	13600.00
0005432170559	4745	Economy	13600.00
0005432461162	4745	Economy	13600.00
0005432461149	4745	Economy	13600.00
0005432569179	4745	Economy	13600.00
0005432461182	4745	Economy	13600.00
0005432569157	4745	Economy	13600.00
0005432569195	4745	Economy	13600.00
0005432569205	4745	Economy	13600.00
0005434559130	4745	Economy	13600.00
0005432461185	4745	Economy	13600.00
0005432569172	4745	Economy	13600.00
0005432569192	4745	Economy	13600.00
0005434082520	4745	Economy	13600.00
0005434559133	4745	Economy	13600.00
0005432571419	4745	Economy	13600.00
0005434082525	4745	Economy	13600.00
0005432461158	4745	Economy	13600.00
0005432569193	4745	Economy	13600.00
0005432461187	4745	Economy	13600.00
0005432569155	4745	Economy	13600.00
0005434559129	4745	Economy	13600.00
0005432461151	4745	Economy	13600.00
0005432461160	4745	Economy	13600.00
0005434082526	4745	Economy	13600.00
0005432461178	4745	Economy	13600.00
0005432461156	4745	Economy	13600.00
0005432569190	4745	Economy	13600.00
0005432461186	4745	Economy	13600.00
0005432569207	4745	Economy	13600.00
0005432461191	4745	Economy	13600.00
0005432571418	4745	Economy	13600.00
0005432461155	4745	Economy	13600.00
0005432461161	4745	Economy	13600.00
0005432170557	4745	Economy	13600.00
0005434559132	4745	Economy	13600.00
0005435840360	4745	Economy	13600.00
0005432569173	4745	Economy	13600.00
0005434082528	4745	Economy	13600.00
0005434559137	4745	Economy	13600.00
0005432569199	4745	Economy	13600.00
0005432569212	4745	Economy	13600.00
0005432461152	4745	Economy	13600.00
0005434082524	4745	Economy	13600.00
0005432569158	4745	Economy	13600.00
0005432569188	4745	Economy	13600.00
0005432461164	4745	Economy	13600.00
0005432569200	4745	Economy	13600.00
0005432461197	4745	Economy	13600.00
0005432569187	4745	Economy	13600.00
0005432569184	4745	Economy	13600.00
0005432461196	4745	Economy	13600.00
0005432569181	4745	Economy	13600.00
0005432569211	4745	Economy	13600.00
0005434082535	4745	Economy	13600.00
0005434082299	30535	Business	40900.00
0005432568566	30535	Business	40900.00
0005432460797	30535	Business	40900.00
0005434082297	30535	Business	40900.00
0005432460808	30535	Business	40900.00
0005435840436	30535	Business	40900.00
0005434082155	30535	Business	40900.00
0005434082221	30535	Business	40900.00
0005434082170	30535	Business	40900.00
0005435840438	30535	Business	40900.00
0005435840431	30535	Business	40900.00
0005432568764	30535	Business	40900.00
0005432568835	30535	Business	40900.00
0005432568452	30535	Business	40900.00
0005432460978	30535	Business	40900.00
0005432460656	30535	Business	40900.00
0005432568719	30535	Business	40900.00
0005432460738	30535	Business	40900.00
0005432460421	30535	Business	40900.00
0005432460651	30535	Business	40900.00
0005435840440	30535	Business	40900.00
0005432460676	30535	Business	40900.00
0005432460839	30535	Business	40900.00
0005435840432	30535	Business	40900.00
0005432568665	30535	Economy	15000.00
0005434082219	30535	Economy	15000.00
0005432460596	30535	Economy	15000.00
0005432460715	30535	Economy	15000.00
0005435840435	30535	Economy	13600.00
0005435840442	30535	Economy	13600.00
0005432568563	30535	Economy	13600.00
0005432568865	30535	Economy	13600.00
0005432460914	30535	Economy	13600.00
0005433452766	30535	Economy	13600.00
0005432568990	30535	Economy	13600.00
0005432460597	30535	Economy	13600.00
0005432568558	30535	Economy	13600.00
0005432568476	30535	Economy	13600.00
0005432460771	30535	Economy	13600.00
0005432460611	30535	Economy	13600.00
0005432568652	30535	Economy	13600.00
0005432460805	30535	Economy	13600.00
0005432571396	30535	Economy	13600.00
0005432460666	30535	Economy	13600.00
0005432568772	30535	Economy	13600.00
0005434082218	30535	Economy	13600.00
0005434082345	30535	Economy	13600.00
0005432568622	30535	Economy	13600.00
0005432568745	30535	Economy	13600.00
0005432460570	30535	Economy	13600.00
0005432161210	30535	Economy	13600.00
0005434082304	30535	Economy	13600.00
0005432568401	30535	Economy	13600.00
0005432568667	30535	Economy	13600.00
0005432460723	30535	Economy	13600.00
0005433452771	30535	Economy	13600.00
0005432568928	30535	Economy	13600.00
0005432568744	30535	Economy	13600.00
0005435840437	30535	Economy	13600.00
0005432568617	30535	Economy	13600.00
0005432568776	30535	Economy	13600.00
0005433452776	30535	Economy	13600.00
0005432460810	30535	Economy	13600.00
0005432568800	30535	Economy	13600.00
0005434082301	30535	Economy	13600.00
0005432568701	30535	Economy	13600.00
0005432460780	30535	Economy	13600.00
0005432161209	30535	Economy	13600.00
0005432568792	30535	Economy	13600.00
0005432568765	30535	Economy	13600.00
0005433452780	30535	Economy	13600.00
0005432568698	30535	Economy	13600.00
0005432460788	30535	Economy	13600.00
0005432460961	30535	Economy	13600.00
0005432568699	30535	Economy	13600.00
0005432460709	30535	Economy	13600.00
0005433452772	30535	Economy	13600.00
0005434082300	30535	Economy	13600.00
0005434082283	30535	Economy	13600.00
0005432568868	30535	Economy	13600.00
0005432460840	30535	Economy	13600.00
0005432571395	30535	Economy	13600.00
0005432460804	30535	Economy	13600.00
0005432460913	30535	Economy	13600.00
0005432460827	30535	Economy	13600.00
0005432460770	30535	Economy	13600.00
0005432460773	30535	Economy	13600.00
0005434082276	30535	Economy	13600.00
0005432568627	30535	Economy	13600.00
0005432568535	30535	Economy	13600.00
0005432568607	30535	Economy	13600.00
0005432460764	30535	Economy	13600.00
0005432568838	30535	Economy	13600.00
0005432460791	30535	Economy	13600.00
0005432460806	30535	Economy	13600.00
0005432460772	30535	Economy	13600.00
0005434082307	30535	Economy	13600.00
0005432568726	30535	Economy	13600.00
0005432568608	30535	Economy	13600.00
0005432568751	30535	Economy	13600.00
0005432568738	30535	Economy	13600.00
0005432568548	30535	Economy	13600.00
0005432568849	30535	Economy	13600.00
0005432568528	30535	Economy	13600.00
0005432460908	30535	Economy	13600.00
0005432568720	30535	Economy	13600.00
0005435840428	30535	Economy	13600.00
0005432460899	30535	Economy	13600.00
0005432568473	30535	Economy	13600.00
0005432568564	30535	Economy	15000.00
0005432568592	30535	Economy	15000.00
0005432461020	30535	Economy	13600.00
0005432460644	30535	Economy	13600.00
0005432460591	30535	Economy	13600.00
0005432568618	30535	Economy	15000.00
0005432460708	30535	Economy	15000.00
0005433452777	30535	Economy	13600.00
0005435840433	30535	Economy	13600.00
0005432460673	30535	Economy	13600.00
0005435840434	30535	Economy	13600.00
0005432568750	30535	Economy	13600.00
0005432568989	30535	Economy	13600.00
0005432568402	30535	Economy	13600.00
0005433454907	30535	Economy	13600.00
0005432460590	30535	Economy	13600.00
0005433452775	30535	Economy	13600.00
0005434082272	30535	Economy	13600.00
0005432568633	30535	Economy	13600.00
0005432568658	30535	Economy	13600.00
0005433452765	30535	Economy	13600.00
0005432568988	30535	Economy	13600.00
0005435840439	30535	Economy	13600.00
0005432460716	30535	Economy	13600.00
0005434082332	30535	Economy	13600.00
0005432461006	30535	Economy	13600.00
0005432460714	30535	Economy	13600.00
0005432460422	30535	Economy	13600.00
0005432568830	30535	Economy	13600.00
0005432568623	30535	Economy	13600.00
0005432460962	30535	Economy	13600.00
0005434082306	30535	Economy	13600.00
0005432460639	30535	Economy	13600.00
0005432568910	30535	Economy	13600.00
0005432568656	30535	Economy	13600.00
0005432213703	30535	Economy	13600.00
0005432568766	30535	Economy	13600.00
0005432568713	30535	Economy	13600.00
0005432568737	30535	Economy	13600.00
0005432568786	30535	Economy	13600.00
0005435840441	30535	Economy	13600.00
0005432460838	30535	Economy	13600.00
0005432568655	30535	Economy	13600.00
0005434082220	30535	Economy	13600.00
0005432460807	30535	Economy	13600.00
0005432569025	30535	Economy	13600.00
0005432213702	30535	Economy	13600.00
0005435840430	30535	Economy	13600.00
0005432460765	30535	Economy	13600.00
0005432568823	30535	Economy	13600.00
0005434082175	30535	Economy	13600.00
0005432460717	30535	Economy	13600.00
0005435840443	30535	Economy	13600.00
0005434082227	30535	Economy	13600.00
0005432568542	30535	Economy	13600.00
0005434082323	30535	Economy	13600.00
0005432460569	30535	Economy	13600.00
0005432568773	30535	Economy	13600.00
0005435840429	30535	Economy	13600.00
0005432568747	30535	Economy	13600.00
0005432460790	30535	Economy	13600.00
0005434082352	30535	Economy	13600.00
0005432213701	30535	Economy	13600.00
0005434082331	30535	Economy	13600.00
0005432569002	30535	Economy	13600.00
0005432460813	30535	Economy	13600.00
0005432568920	30535	Economy	13600.00
0005432571394	30535	Economy	13600.00
0005435722114	13675	Economy	9900.00
0005435722115	13675	Economy	9900.00
0005435720152	21152	Economy	9900.00
0005435722095	21152	Economy	9900.00
0005435720153	21152	Economy	9900.00
0005435722094	21152	Economy	9900.00
0005432295946	22763	Economy	8800.00
0005432295948	22763	Economy	8800.00
0005432295947	22763	Economy	8800.00
0005433345703	11100	Business	23600.00
0005433345650	11100	Business	23600.00
0005433345687	11100	Business	23600.00
0005433345672	11100	Business	23600.00
0005433345732	11100	Business	23600.00
0005433345683	11100	Business	23600.00
0005435097453	11100	Business	23600.00
0005433345666	11100	Business	23600.00
0005433345661	11100	Business	23600.00
0005433345669	11100	Business	23600.00
0005433345738	11100	Business	23600.00
0005433345664	11100	Economy	7900.00
0005433345660	11100	Economy	7900.00
0005435380361	11100	Economy	7900.00
0005433345654	11100	Economy	7900.00
0005433345671	11100	Economy	7900.00
0005435508580	11100	Economy	7900.00
0005435508585	11100	Economy	7900.00
0005435380356	11100	Economy	7900.00
0005433345670	11100	Economy	7900.00
0005433345709	11100	Economy	7900.00
0005433345685	11100	Economy	7900.00
0005433345677	11100	Economy	7900.00
0005433345724	11100	Economy	7900.00
0005435508513	11100	Economy	7900.00
0005435508587	11100	Economy	7900.00
0005433345725	11100	Economy	7900.00
0005433345726	11100	Economy	7900.00
0005433345649	11100	Economy	7900.00
0005433345673	11100	Economy	7900.00
0005433345699	11100	Economy	7900.00
0005433345688	11100	Economy	7900.00
0005433345689	11100	Economy	7900.00
0005435508586	11100	Economy	7900.00
0005435380384	11100	Economy	7900.00
0005433345707	11100	Economy	7900.00
0005433345727	11100	Economy	7900.00
0005433345721	11100	Economy	7900.00
0005433345722	11100	Economy	7900.00
0005433345706	11100	Economy	7900.00
0005433345733	11100	Economy	7900.00
0005435380350	11100	Economy	7900.00
0005433345665	11100	Economy	7900.00
0005435508558	11100	Economy	7900.00
0005433345648	11100	Economy	7900.00
0005435097457	11100	Economy	7900.00
0005435097455	11100	Economy	7900.00
0005433345659	11100	Economy	7900.00
0005433345656	11100	Economy	7900.00
0005433345681	11100	Economy	7900.00
0005435380374	11100	Economy	7900.00
0005433345674	11100	Economy	8600.00
0005433345734	11100	Economy	8600.00
0005435380366	11100	Economy	8600.00
0005435508547	11100	Economy	8600.00
0005433345651	11100	Economy	8600.00
0005435097454	11100	Economy	8600.00
0005435380362	11100	Economy	7900.00
0005433345715	11100	Economy	7900.00
0005433345720	11100	Economy	7900.00
0005433345662	11100	Economy	7900.00
0005433345716	11100	Economy	7900.00
0005435097456	11100	Economy	7900.00
0005433345668	11100	Economy	7900.00
0005435097448	11100	Economy	7900.00
0005433345658	11100	Economy	7900.00
0005433345655	11100	Economy	7900.00
0005433345657	11100	Economy	7900.00
0005433345667	11100	Economy	7900.00
0005433345694	11100	Economy	7900.00
0005433345676	11100	Economy	7900.00
0005433345710	11100	Economy	7900.00
0005433345652	11100	Economy	7900.00
0005433345686	11100	Economy	7900.00
0005435380351	11100	Economy	7900.00
0005435097449	11100	Economy	7900.00
0005433345736	11100	Economy	7900.00
0005433345663	11100	Economy	7900.00
0005433345739	11100	Economy	7900.00
0005433345680	11100	Economy	7900.00
0005433345691	11100	Economy	7900.00
0005433345675	11100	Economy	7900.00
0005433345717	11100	Economy	7900.00
0005433345653	11100	Economy	7900.00
0005435508531	11100	Economy	7900.00
0005433345708	11100	Economy	7900.00
0005435097452	11100	Economy	7900.00
0005433345718	11100	Economy	7900.00
0005433345714	11100	Economy	7900.00
0005435508530	11100	Economy	7900.00
0005433345711	11100	Economy	7900.00
0005435508492	11100	Economy	7900.00
0005433345692	11100	Economy	7900.00
0005435097450	11100	Economy	7900.00
0005433345712	11100	Economy	7900.00
0005433345735	11100	Economy	7900.00
0005433345728	11100	Economy	7900.00
0005433345730	11100	Economy	7900.00
0005433345693	11100	Economy	7900.00
0005435508566	11100	Economy	7900.00
0005433345701	11100	Economy	7900.00
0005435097447	11100	Economy	7900.00
0005433345719	11100	Economy	7900.00
0005433345723	11100	Economy	7900.00
0005433345697	11100	Economy	7900.00
0005435380392	11100	Economy	7900.00
0005433345700	11100	Economy	7900.00
0005433345695	11100	Economy	7900.00
0005433345698	11100	Economy	7900.00
0005435380357	11100	Economy	7900.00
0005433345690	11100	Economy	7900.00
0005433345713	11100	Economy	7900.00
0005433345696	11100	Economy	7900.00
0005433345684	11100	Economy	7900.00
0005435508577	11100	Economy	7900.00
0005435097451	11100	Economy	7900.00
0005433345679	11100	Economy	7900.00
0005433345678	11100	Economy	7900.00
0005433345729	11100	Economy	7900.00
0005433345682	11100	Economy	7900.00
0005433345704	11100	Economy	7900.00
0005435380358	11100	Economy	7900.00
0005433345705	11100	Economy	7900.00
0005435380375	11100	Economy	7900.00
0005433345702	11100	Economy	7900.00
0005435508546	11100	Economy	7900.00
0005433345737	11100	Economy	7900.00
0005433345731	11100	Economy	7900.00
0005433344933	17088	Business	23600.00
0005433344989	17088	Business	23600.00
0005433345079	17088	Business	23600.00
0005433344891	17088	Business	23600.00
0005433344763	17088	Business	23600.00
0005433345068	17088	Business	23600.00
0005433345257	17088	Business	23600.00
0005435097357	17088	Business	23600.00
0005433345258	17088	Business	23600.00
0005433344702	17088	Business	23600.00
0005435380419	17088	Business	23600.00
0005435545925	17088	Business	23600.00
0005433344834	17088	Economy	7900.00
0005433344180	17088	Economy	7900.00
0005435545918	17088	Economy	7900.00
0005433344691	17088	Economy	7900.00
0005433344584	17088	Economy	7900.00
0005433344447	17088	Economy	7900.00
0005433344690	17088	Economy	7900.00
0005433344767	17088	Economy	7900.00
0005433345142	17088	Economy	7900.00
0005433344770	17088	Economy	7900.00
0005433344586	17088	Economy	7900.00
0005432293270	17088	Economy	7900.00
0005433344617	17088	Economy	7900.00
0005433344709	17088	Economy	7900.00
0005435545923	17088	Economy	7900.00
0005435380418	17088	Economy	7900.00
0005433344819	17088	Economy	7900.00
0005433344585	17088	Economy	7900.00
0005433344771	17088	Economy	7900.00
0005433344738	17088	Economy	7900.00
0005433344936	17088	Economy	7900.00
0005433344219	17088	Economy	7900.00
0005433344592	17088	Economy	7900.00
0005433344769	17088	Economy	7900.00
0005433344664	17088	Economy	7900.00
0005435380417	17088	Economy	7900.00
0005433345012	17088	Economy	7900.00
0005433345054	17088	Economy	7900.00
0005433344345	17088	Economy	7900.00
0005433344828	17088	Economy	7900.00
0005433344662	17088	Economy	7900.00
0005433344804	17088	Economy	7900.00
0005433344941	17088	Economy	7900.00
0005435097376	17088	Economy	7900.00
0005433344818	17088	Economy	7900.00
0005433344428	17088	Economy	7900.00
0005433344923	17088	Economy	7900.00
0005435545915	17088	Economy	7900.00
0005433344458	17088	Economy	7900.00
0005433344457	17088	Economy	7900.00
0005435545920	17088	Economy	8600.00
0005433344890	17088	Economy	8600.00
0005433344948	17088	Economy	8600.00
0005433344764	17088	Economy	8600.00
0005433344595	17088	Economy	8600.00
0005433344883	17088	Economy	8600.00
0005433344587	17088	Economy	7900.00
0005435545922	17088	Economy	7900.00
0005433344749	17088	Economy	7900.00
0005435097377	17088	Economy	7900.00
0005435545927	17088	Economy	7900.00
0005435545917	17088	Economy	7900.00
0005433344611	17088	Economy	7900.00
0005433344708	17088	Economy	7900.00
0005433344815	17088	Economy	7900.00
0005433345014	17088	Economy	7900.00
0005435545919	17088	Economy	7900.00
0005433344756	17088	Economy	7900.00
0005435545924	17088	Economy	7900.00
0005435545912	17088	Economy	7900.00
0005433344826	17088	Economy	7900.00
0005433344863	17088	Economy	7900.00
0005433344301	17088	Economy	7900.00
0005433344976	17088	Economy	7900.00
0005433344669	17088	Economy	7900.00
0005433344653	17088	Economy	7900.00
0005435097361	17088	Economy	7900.00
0005433344179	17088	Economy	7900.00
0005433344794	17088	Economy	7900.00
0005433344643	17088	Economy	7900.00
0005432293271	17088	Economy	7900.00
0005433345031	17088	Economy	7900.00
0005432293269	17088	Economy	7900.00
0005433345141	17088	Economy	7900.00
0005433344803	17088	Economy	7900.00
0005435545914	17088	Economy	7900.00
0005435380420	17088	Economy	7900.00
0005433344924	17088	Economy	7900.00
0005433344638	17088	Economy	7900.00
0005433345344	17088	Economy	7900.00
0005433344951	17088	Economy	7900.00
0005433344668	17088	Economy	7900.00
0005433345069	17088	Economy	7900.00
0005433344646	17088	Economy	7900.00
0005433345055	17088	Economy	7900.00
0005433344616	17088	Economy	7900.00
0005433344884	17088	Economy	7900.00
0005433344712	17088	Economy	7900.00
0005435545913	17088	Economy	7900.00
0005433344644	17088	Economy	7900.00
0005435097353	17088	Economy	7900.00
0005433344950	17088	Economy	7900.00
0005435380421	17088	Economy	7900.00
0005435097378	17088	Economy	7900.00
0005435380422	17088	Economy	7900.00
0005433344218	17088	Economy	7900.00
0005433344423	17088	Economy	7900.00
0005433345030	17088	Economy	7900.00
0005433344755	17088	Economy	7900.00
0005435545926	17088	Economy	7900.00
0005433344750	17088	Economy	7900.00
0005433344814	17088	Economy	7900.00
0005433344655	17088	Economy	7900.00
0005435545916	17088	Economy	7900.00
0005433345029	17088	Economy	7900.00
0005433344820	17088	Economy	7900.00
0005433344840	17088	Economy	7900.00
0005433344514	17088	Economy	7900.00
0005433344885	17088	Economy	7900.00
0005435545921	17088	Economy	7900.00
0005433344725	17088	Economy	7900.00
0005433344642	17088	Economy	7900.00
0005433344663	17088	Economy	7900.00
0005433344569	17088	Economy	7900.00
0005433344232	17088	Economy	7900.00
0005433344865	17088	Economy	7900.00
0005433344684	17088	Economy	7900.00
0005433344302	17088	Economy	7900.00
0005432920153	9060	Business	26600.00
0005433477133	9060	Business	26600.00
0005432920173	9060	Business	26600.00
0005433507651	9060	Business	26600.00
0005433477131	9060	Business	26600.00
0005433477139	9060	Business	26600.00
0005433477141	9060	Business	26600.00
0005433477126	9060	Business	26600.00
0005433477122	9060	Business	26600.00
0005432920226	9060	Business	26600.00
0005433507654	9060	Business	26600.00
0005433507647	9060	Economy	8900.00
0005433477150	9060	Economy	8900.00
0005433481363	9060	Economy	8900.00
0005432920229	9060	Economy	8900.00
0005432920136	9060	Economy	8900.00
0005433477123	9060	Economy	8900.00
0005433477154	9060	Economy	9800.00
0005433477132	9060	Economy	9800.00
0005433507646	9060	Economy	9800.00
0005433477148	9060	Economy	9800.00
0005433477155	9060	Economy	8900.00
0005433477144	9060	Economy	8900.00
0005433477145	9060	Economy	8900.00
0005433507653	9060	Economy	8900.00
0005432920188	9060	Economy	8900.00
0005433477121	9060	Economy	8900.00
0005433477129	9060	Economy	8900.00
0005433477125	9060	Economy	8900.00
0005432920174	9060	Economy	8900.00
0005433481362	9060	Economy	8900.00
0005433477147	9060	Economy	8900.00
0005433507645	9060	Economy	8900.00
0005433477134	9060	Economy	8900.00
0005433481367	9060	Economy	8900.00
0005432920192	9060	Economy	8900.00
0005433477135	9060	Economy	8900.00
0005432920154	9060	Economy	8900.00
0005433481365	9060	Economy	8900.00
0005432920187	9060	Economy	8900.00
0005433477130	9060	Economy	8900.00
0005433477137	9060	Economy	8900.00
0005432920172	9060	Economy	8900.00
0005433507652	9060	Economy	8900.00
0005433477156	9060	Economy	8900.00
0005433477143	9060	Economy	8900.00
0005433477142	9060	Economy	8900.00
0005433477127	9060	Economy	8900.00
0005433507649	9060	Economy	8900.00
0005433481364	9060	Economy	8900.00
0005433507655	9060	Economy	8900.00
0005432920190	9060	Economy	8900.00
0005433507661	9060	Economy	8900.00
0005433481368	9060	Economy	8900.00
0005433477149	9060	Economy	8900.00
0005433477152	9060	Economy	8900.00
0005433477157	9060	Economy	8900.00
0005433477140	9060	Economy	8900.00
0005433477128	9060	Economy	8900.00
0005433507648	9060	Economy	8900.00
0005433507656	9060	Economy	8900.00
0005433507659	9060	Economy	8900.00
0005433477151	9060	Economy	8900.00
0005432920193	9060	Economy	8900.00
0005433477146	9060	Economy	8900.00
0005432920134	9060	Economy	8900.00
0005433481366	9060	Economy	8900.00
0005433507660	9060	Economy	8900.00
0005433477124	9060	Economy	8900.00
0005432920135	9060	Economy	8900.00
0005433481361	9060	Economy	8900.00
0005433507657	9060	Economy	8900.00
0005432920185	9060	Economy	8900.00
0005433481369	9060	Economy	8900.00
0005432920166	9060	Economy	8900.00
0005432920195	9060	Economy	8900.00
0005433507658	9060	Economy	8900.00
0005433477138	9060	Economy	8900.00
0005433477136	9060	Economy	8900.00
0005432920106	9060	Economy	8900.00
0005433477120	9060	Economy	8900.00
0005433507650	9060	Economy	8900.00
0005433477153	9060	Economy	8900.00
0005434159041	20441	Business	26600.00
0005432920408	20441	Business	26600.00
0005433481322	20441	Business	26600.00
0005433481303	20441	Business	26600.00
0005433507512	20441	Business	26600.00
0005433507476	20441	Business	26600.00
0005433507540	20441	Economy	8900.00
0005432920412	20441	Economy	8900.00
0005434159040	20441	Economy	8900.00
0005433507643	20441	Economy	8900.00
0005433507526	20441	Economy	9800.00
0005433481271	20441	Economy	9800.00
0005433507518	20441	Economy	9800.00
0005432920406	20441	Economy	9800.00
0005433481324	20441	Economy	8900.00
0005433481323	20441	Economy	8900.00
0005434159044	20441	Economy	8900.00
0005433507587	20441	Economy	8900.00
0005434159042	20441	Economy	8900.00
0005434159038	20441	Economy	8900.00
0005432920404	20441	Economy	8900.00
0005432920409	20441	Economy	8900.00
0005433507519	20441	Economy	8900.00
0005433481326	20441	Economy	8900.00
0005433481286	20441	Economy	8900.00
0005433507553	20441	Economy	8900.00
0005432920403	20441	Economy	8900.00
0005432920411	20441	Economy	8900.00
0005433507515	20441	Economy	8900.00
0005432920401	20441	Economy	8900.00
0005433507449	20441	Economy	8900.00
0005433507555	20441	Economy	8900.00
0005432920415	20441	Economy	8900.00
0005434159039	20441	Economy	8900.00
0005434159043	20441	Economy	8900.00
0005433507589	20441	Economy	8900.00
0005432920413	20441	Economy	8900.00
0005433481329	20441	Economy	8900.00
0005433507465	20441	Economy	8900.00
0005432920410	20441	Economy	8900.00
0005433507448	20441	Economy	8900.00
0005433507492	20441	Economy	8900.00
0005433481295	20441	Economy	8900.00
0005432920414	20441	Economy	8900.00
0005432920407	20441	Economy	8900.00
0005432920405	20441	Economy	8900.00
0005433507534	20441	Economy	8900.00
0005433507507	20441	Economy	8900.00
0005433507644	20441	Economy	8900.00
0005432920402	20441	Economy	8900.00
0005433481300	20441	Economy	8900.00
0005433507552	20441	Economy	8900.00
0005432920400	20441	Economy	8900.00
0005433507440	20441	Economy	8900.00
0005433481296	20441	Economy	8900.00
0005433481274	20441	Economy	8900.00
0005432396338	10123	Economy	5800.00
0005435179701	10123	Economy	5800.00
0005432394203	10123	Economy	5800.00
0005432396339	10123	Economy	5800.00
0005432394202	10123	Economy	5800.00
0005435179006	10123	Economy	5800.00
0005435179009	10123	Economy	5800.00
0005432394204	10123	Economy	5800.00
0005432394205	10123	Economy	5800.00
0005432396340	10123	Economy	5800.00
0005432396341	10123	Economy	5800.00
0005435179712	18317	Economy	5800.00
0005432396305	18317	Economy	5800.00
0005432400202	18317	Economy	5800.00
0005435179420	18317	Economy	5800.00
0005435179713	18317	Economy	5800.00
0005435179422	18317	Economy	5800.00
0005432400176	18317	Economy	5800.00
0005432400187	18317	Economy	5800.00
0005432396312	18317	Economy	5800.00
0005435179711	18317	Economy	5800.00
0005435179421	18317	Economy	5800.00
0005432396311	18317	Economy	5800.00
0005435127199	11021	Business	9500.00
0005435626435	11021	Business	9500.00
0005435127012	11021	Business	9500.00
0005434411887	11021	Business	9500.00
0005435127121	11021	Business	9500.00
0005435127005	11021	Business	9500.00
0005434928372	11021	Business	9500.00
0005435554275	11021	Business	9500.00
0005435127011	11021	Business	9500.00
0005435127141	11021	Business	9500.00
0005435626434	11021	Business	9500.00
0005435626451	11021	Economy	3200.00
0005435126946	11021	Economy	3200.00
0005435126921	11021	Economy	3200.00
0005435127073	11021	Economy	3200.00
0005435126958	11021	Economy	3200.00
0005435126891	11021	Economy	3500.00
0005434411888	11021	Economy	3500.00
0005435127108	11021	Economy	3200.00
0005434928374	11021	Economy	3200.00
0005435127200	11021	Economy	3200.00
0005435626437	11021	Economy	3200.00
0005435126989	11021	Economy	3200.00
0005435626438	11021	Economy	3200.00
0005435626474	11021	Economy	3200.00
0005435126957	11021	Economy	3200.00
0005435127018	11021	Economy	3200.00
0005434411890	11021	Economy	3200.00
0005435127041	11021	Economy	3200.00
0005435127133	11021	Economy	3200.00
0005435127007	11021	Economy	3200.00
0005435126897	11021	Economy	3200.00
0005435127074	11021	Economy	3200.00
0005435127032	11021	Economy	3200.00
0005435626459	11021	Economy	3200.00
0005435126971	11021	Economy	3200.00
0005435626440	11021	Economy	3200.00
0005435126995	11021	Economy	3200.00
0005435127010	11021	Economy	3200.00
0005435626450	11021	Economy	3200.00
0005435626478	11021	Economy	3200.00
0005435556736	11021	Economy	3200.00
0005435127113	11021	Economy	3200.00
0005434411889	11021	Economy	3200.00
0005435626439	11021	Economy	3200.00
0005435126900	11021	Economy	3200.00
0005435127119	11021	Economy	3200.00
0005435126899	11021	Economy	3200.00
0005435127112	11021	Economy	3200.00
0005435126945	11021	Economy	3200.00
0005435127045	11021	Economy	3200.00
0005435127006	11021	Economy	3200.00
0005435626452	11021	Economy	3200.00
0005435127177	11021	Economy	3200.00
0005435126826	11021	Economy	3200.00
0005435127120	11021	Economy	3200.00
0005435127159	11021	Economy	3200.00
0005435127075	11021	Economy	3200.00
0005435126890	11021	Economy	3200.00
0005435626441	11021	Economy	3200.00
0005435626458	11021	Economy	3200.00
0005435126984	11021	Economy	3200.00
0005435554259	11021	Economy	3200.00
0005435127084	11021	Economy	3200.00
0005435626460	11021	Economy	3200.00
0005435626472	11021	Economy	3200.00
0005435127148	11021	Economy	3200.00
0005434928373	11021	Economy	3200.00
0005435126959	11021	Economy	3200.00
0005435626457	11021	Economy	3200.00
0005435127039	11021	Economy	3200.00
0005435626469	11021	Economy	3200.00
0005435127140	11021	Economy	3200.00
0005435127076	11021	Economy	3200.00
0005435127407	14665	Business	9500.00
0005435626645	14665	Business	9500.00
0005434411868	14665	Business	9500.00
0005434411847	14665	Business	9500.00
0005435127425	14665	Business	9500.00
0005435127415	14665	Business	9500.00
0005435127408	14665	Business	9500.00
0005435626646	14665	Business	9500.00
0005434928342	14665	Business	9500.00
0005435127412	14665	Business	9500.00
0005434411862	14665	Economy	3200.00
0005435554306	14665	Economy	3200.00
0005435127424	14665	Economy	3200.00
0005435626644	14665	Economy	3200.00
0005435127401	14665	Economy	3200.00
0005435626663	14665	Economy	3200.00
0005435626658	14665	Economy	3500.00
0005435626654	14665	Economy	3500.00
0005435127419	14665	Economy	3500.00
0005435626665	14665	Economy	3500.00
0005435127406	14665	Economy	3500.00
0005434928357	14665	Economy	3200.00
0005435127394	14665	Economy	3200.00
0005435127416	14665	Economy	3200.00
0005435127402	14665	Economy	3200.00
0005435127395	14665	Economy	3200.00
0005435626660	14665	Economy	3200.00
0005435127427	14665	Economy	3200.00
0005435554308	14665	Economy	3200.00
0005435626657	14665	Economy	3200.00
0005435626662	14665	Economy	3200.00
0005434411852	14665	Economy	3200.00
0005435626648	14665	Economy	3200.00
0005435127411	14665	Economy	3200.00
0005435127409	14665	Economy	3200.00
0005435626653	14665	Economy	3200.00
0005435626649	14665	Economy	3200.00
0005435127400	14665	Economy	3200.00
0005435127426	14665	Economy	3200.00
0005434411827	14665	Economy	3200.00
0005435127420	14665	Economy	3200.00
0005435127399	14665	Economy	3200.00
0005435127405	14665	Economy	3200.00
0005435626647	14665	Economy	3200.00
0005435626642	14665	Economy	3200.00
0005435554309	14665	Economy	3200.00
0005434928356	14665	Economy	3200.00
0005435127397	14665	Economy	3200.00
0005435127396	14665	Economy	3200.00
0005435626659	14665	Economy	3200.00
0005435127410	14665	Economy	3200.00
0005435127403	14665	Economy	3200.00
0005434928343	14665	Economy	3200.00
0005435626655	14665	Economy	3200.00
0005435626650	14665	Economy	3200.00
0005435127404	14665	Economy	3200.00
0005435554307	14665	Economy	3200.00
0005435127418	14665	Economy	3200.00
0005435626643	14665	Economy	3200.00
0005435626656	14665	Economy	3200.00
0005435127422	14665	Economy	3200.00
0005434411863	14665	Economy	3200.00
0005435127421	14665	Economy	3200.00
0005435127414	14665	Economy	3200.00
0005435626641	14665	Economy	3200.00
0005435626664	14665	Economy	3200.00
0005435127417	14665	Economy	3200.00
0005435127413	14665	Economy	3200.00
0005435626661	14665	Economy	3200.00
0005435127398	14665	Economy	3200.00
0005435626652	14665	Economy	3200.00
0005435127423	14665	Economy	3200.00
0005435626651	14665	Economy	3200.00
0005435443473	7097	Business	86900.00
0005435443500	7097	Business	86900.00
0005435715914	7097	Business	86900.00
0005435715912	7097	Business	86900.00
0005435179413	7097	Business	86900.00
0005435715913	7097	Business	86900.00
0005435715903	7097	Economy	29000.00
0005435443524	7097	Economy	29000.00
0005435443471	7097	Economy	29000.00
0005435179409	7097	Economy	29000.00
0005435443490	7097	Economy	29000.00
0005435715906	7097	Economy	29000.00
0005435221068	7097	Economy	31900.00
0005435178519	7097	Economy	29000.00
0005435443477	7097	Economy	29000.00
0005432398290	7097	Economy	29000.00
0005435443478	7097	Economy	29000.00
0005432400216	7097	Economy	29000.00
0005435715900	7097	Economy	29000.00
0005435443479	7097	Economy	29000.00
0005435715905	7097	Economy	29000.00
0005435715909	7097	Economy	29000.00
0005435715902	7097	Economy	29000.00
0005435715910	7097	Economy	29000.00
0005435443444	7097	Economy	29000.00
0005435443472	7097	Economy	29000.00
0005435715904	7097	Economy	29000.00
0005435179407	7097	Economy	29000.00
0005435219221	7097	Economy	29000.00
0005435715911	7097	Economy	29000.00
0005435715907	7097	Economy	29000.00
0005435715901	7097	Economy	29000.00
0005435715898	7097	Economy	29000.00
0005435443525	7097	Economy	29000.00
0005435219224	7097	Economy	29000.00
0005435443474	7097	Economy	29000.00
0005435443495	7097	Economy	29000.00
0005435715899	7097	Economy	29000.00
0005435219222	7097	Economy	29000.00
0005435715908	7097	Economy	29000.00
0005435443461	7097	Economy	29000.00
0005435443551	27089	Business	86900.00
0005432394169	27089	Business	86900.00
0005435715732	27089	Business	86900.00
0005435715782	27089	Business	86900.00
0005432394175	27089	Business	86900.00
0005435443554	27089	Business	86900.00
0005432394178	27089	Economy	29000.00
0005435443555	27089	Economy	29000.00
0005435715783	27089	Economy	29000.00
0005432394155	27089	Economy	31900.00
0005435715754	27089	Economy	31900.00
0005432394181	27089	Economy	31900.00
0005435715854	27089	Economy	29000.00
0005432394165	27089	Economy	29000.00
0005435715731	27089	Economy	29000.00
0005435443556	27089	Economy	29000.00
0005435715806	27089	Economy	29000.00
0005432394167	27089	Economy	29000.00
0005435443552	27089	Economy	29000.00
0005435443558	27089	Economy	29000.00
0005435715747	27089	Economy	29000.00
0005435715646	27089	Economy	29000.00
0005435443550	27089	Economy	29000.00
0005432394173	27089	Economy	29000.00
0005435443557	27089	Economy	29000.00
0005435715772	27089	Economy	29000.00
0005435715776	27089	Economy	29000.00
0005435715830	27089	Economy	29000.00
0005432394172	27089	Economy	29000.00
0005432394182	27089	Economy	29000.00
0005435715748	27089	Economy	29000.00
0005435715777	27089	Economy	29000.00
0005435443553	27089	Economy	29000.00
0005432394170	27089	Economy	29000.00
0005432394174	27089	Economy	29000.00
0005433060467	2759	Economy	7700.00
0005434085050	2759	Economy	7700.00
0005434085049	2759	Economy	7700.00
0005434085048	2759	Economy	7700.00
0005433060450	2759	Economy	7700.00
0005433060483	28513	Economy	7700.00
0005434085020	28513	Economy	7700.00
0005433060481	28513	Economy	7700.00
0005434085015	28513	Economy	7700.00
0005434084994	28513	Economy	7700.00
0005434084995	28513	Economy	7700.00
0005433060482	28513	Economy	7700.00
0005435541356	11407	Business	20200.00
0005435541295	11407	Business	20200.00
0005435541367	11407	Business	20200.00
0005435518229	11407	Business	20200.00
0005435541482	11407	Business	20200.00
0005435541485	11407	Business	20200.00
0005435541311	11407	Economy	6700.00
0005435541358	11407	Economy	6700.00
0005435541244	11407	Economy	6700.00
0005435541391	11407	Economy	6700.00
0005435518251	11407	Economy	7400.00
0005435518252	11407	Economy	7400.00
0005435518199	11407	Economy	6700.00
0005435518210	11407	Economy	6700.00
0005435518150	11407	Economy	6700.00
0005435518204	11407	Economy	6700.00
0005435518200	11407	Economy	6700.00
0005435518203	11407	Economy	6700.00
0005435541294	11407	Economy	6700.00
0005435541430	11407	Economy	6700.00
0005435518243	11407	Economy	6700.00
0005435518222	11407	Economy	6700.00
0005435541377	11407	Economy	6700.00
0005435541421	11407	Economy	6700.00
0005435518209	11407	Economy	6700.00
0005435541433	11407	Economy	6700.00
0005435541355	11407	Economy	6700.00
0005435541378	11407	Economy	6700.00
0005435518161	11407	Economy	6700.00
0005435518284	11407	Economy	6700.00
0005435541331	11407	Economy	6700.00
0005435541245	11407	Economy	6700.00
0005435541312	11407	Economy	6700.00
0005435541536	22241	Business	20200.00
0005435529801	22241	Business	20200.00
0005435529794	22241	Business	20200.00
0005435529800	22241	Business	20200.00
0005435529806	22241	Business	20200.00
0005435541548	22241	Business	20200.00
0005435530094	22241	Business	20200.00
0005435529797	22241	Business	20200.00
0005435530089	22241	Business	20200.00
0005435529793	22241	Economy	6700.00
0005435530091	22241	Economy	6700.00
0005432294547	22241	Economy	6700.00
0005435541547	22241	Economy	6700.00
0005435529790	22241	Economy	6700.00
0005435541545	22241	Economy	7400.00
0005435529789	22241	Economy	7400.00
0005435530088	22241	Economy	7400.00
0005435530101	22241	Economy	7400.00
0005435529792	22241	Economy	6700.00
0005435529802	22241	Economy	6700.00
0005435541534	22241	Economy	6700.00
0005435541546	22241	Economy	6700.00
0005435541540	22241	Economy	6700.00
0005435530086	22241	Economy	6700.00
0005435530095	22241	Economy	6700.00
0005435530092	22241	Economy	6700.00
0005435529796	22241	Economy	6700.00
0005435529798	22241	Economy	6700.00
0005435529795	22241	Economy	6700.00
0005435541533	22241	Economy	6700.00
0005435529791	22241	Economy	6700.00
0005435541539	22241	Economy	6700.00
0005435530098	22241	Economy	6700.00
0005435530090	22241	Economy	6700.00
0005435530097	22241	Economy	6700.00
0005435529807	22241	Economy	6700.00
0005435530085	22241	Economy	6700.00
0005432294546	22241	Economy	6700.00
0005435541535	22241	Economy	6700.00
0005435529805	22241	Economy	6700.00
0005435541550	22241	Economy	6700.00
0005435541549	22241	Economy	6700.00
0005435529804	22241	Economy	6700.00
0005435529803	22241	Economy	6700.00
0005435541551	22241	Economy	6700.00
0005435530087	22241	Economy	6700.00
0005435529799	22241	Economy	6700.00
0005435530100	22241	Economy	6700.00
0005435530084	22241	Economy	6700.00
0005435530099	22241	Economy	6700.00
0005435530093	22241	Economy	6700.00
0005435541541	22241	Economy	6700.00
0005435541543	22241	Economy	6700.00
0005435530096	22241	Economy	6700.00
0005435541542	22241	Economy	6700.00
0005435529788	22241	Economy	6700.00
0005435541544	22241	Economy	6700.00
0005435541537	22241	Economy	6700.00
0005435541538	22241	Economy	6700.00
0005433401035	2279	Business	20200.00
0005433251880	2279	Business	20200.00
0005433251931	2279	Business	20200.00
0005433251970	2279	Business	20200.00
0005434908665	2279	Business	20200.00
0005434908616	2279	Business	20200.00
0005434908639	2279	Business	20200.00
0005433401049	2279	Business	20200.00
0005434908668	2279	Business	20200.00
0005434908631	2279	Business	20200.00
0005434908627	2279	Business	20200.00
0005434908671	2279	Business	20200.00
0005434908654	2279	Economy	6700.00
0005433251960	2279	Economy	6700.00
0005434908651	2279	Economy	6700.00
0005433401032	2279	Economy	6700.00
0005433252077	2279	Economy	6700.00
0005434908643	2279	Economy	6700.00
0005433251910	2279	Economy	6700.00
0005433251909	2279	Economy	6700.00
0005434908649	2279	Economy	6700.00
0005434908661	2279	Economy	6700.00
0005433252085	2279	Economy	7400.00
0005433401033	2279	Economy	7400.00
0005434908669	2279	Economy	7400.00
0005434908645	2279	Economy	7400.00
0005434908660	2279	Economy	7400.00
0005434908657	2279	Economy	6700.00
0005433401034	2279	Economy	6700.00
0005434908633	2279	Economy	6700.00
0005434908628	2279	Economy	6700.00
0005433251943	2279	Economy	6700.00
0005434908637	2279	Economy	6700.00
0005434908630	2279	Economy	6700.00
0005434908673	2279	Economy	6700.00
0005434908655	2279	Economy	6700.00
0005433251974	2279	Economy	6700.00
0005434908650	2279	Economy	6700.00
0005433252038	2279	Economy	6700.00
0005434908672	2279	Economy	6700.00
0005433252125	2279	Economy	6700.00
0005433251860	2279	Economy	6700.00
0005434908647	2279	Economy	6700.00
0005433401048	2279	Economy	6700.00
0005434908626	2279	Economy	6700.00
0005433251969	2279	Economy	6700.00
0005433252059	2279	Economy	6700.00
0005434908652	2279	Economy	6700.00
0005434908634	2279	Economy	6700.00
0005434908613	2279	Economy	6700.00
0005433251958	2279	Economy	6700.00
0005433252131	2279	Economy	6700.00
0005433252041	2279	Economy	6700.00
0005434908663	2279	Economy	6700.00
0005433251862	2279	Economy	6700.00
0005434908635	2279	Economy	6700.00
0005434908659	2279	Economy	6700.00
0005434908625	2279	Economy	6700.00
0005434908658	2279	Economy	6700.00
0005434908653	2279	Economy	6700.00
0005434908642	2279	Economy	6700.00
0005434908670	2279	Economy	6700.00
0005434908644	2279	Economy	6700.00
0005434908617	2279	Economy	6700.00
0005434908656	2279	Economy	6700.00
0005434908615	2279	Economy	6700.00
0005434908629	2279	Economy	6700.00
0005434908620	2279	Economy	6700.00
0005434908632	2279	Economy	6700.00
0005433251953	2279	Economy	6700.00
0005433251936	2279	Economy	6700.00
0005433251937	2279	Economy	6700.00
0005434908623	2279	Economy	6700.00
0005434908640	2279	Economy	6700.00
0005434908641	2279	Economy	6700.00
0005433252001	2279	Economy	6700.00
0005434908618	2279	Economy	6700.00
0005434908619	2279	Economy	6700.00
0005433252037	2279	Economy	6700.00
0005434908621	2279	Economy	6700.00
0005434908666	2279	Economy	6700.00
0005433252036	2279	Economy	6700.00
0005433251930	2279	Economy	6700.00
0005433251911	2279	Economy	6700.00
0005434908614	2279	Economy	6700.00
0005434908667	2279	Economy	6700.00
0005433251861	2279	Economy	6700.00
0005433401047	2279	Economy	6700.00
0005434908636	2279	Economy	6700.00
0005434908638	2279	Economy	6700.00
0005434908624	2279	Economy	6700.00
0005434908662	2279	Economy	6700.00
0005434908622	2279	Economy	6700.00
0005434908664	2279	Economy	6700.00
0005433252042	2279	Economy	6700.00
0005434908648	2279	Economy	6700.00
0005434908646	2279	Economy	6700.00
0005433401061	25600	Business	20200.00
0005433252261	25600	Business	20200.00
0005433252271	25600	Business	20200.00
0005433252265	25600	Business	20200.00
0005434907797	25600	Business	20200.00
0005433252282	25600	Business	20200.00
0005434907832	25600	Business	20200.00
0005434908165	25600	Business	20200.00
0005433252269	25600	Business	20200.00
0005434908255	25600	Business	20200.00
0005433252257	25600	Business	20200.00
0005434908141	25600	Economy	6700.00
0005434908038	25600	Economy	6700.00
0005433252277	25600	Economy	6700.00
0005434908011	25600	Economy	6700.00
0005434908152	25600	Economy	6700.00
0005434908219	25600	Economy	6700.00
0005434908259	25600	Economy	6700.00
0005433252258	25600	Economy	6700.00
0005434908200	25600	Economy	6700.00
0005434908029	25600	Economy	6700.00
0005434908142	25600	Economy	7400.00
0005433252262	25600	Economy	7400.00
0005434908252	25600	Economy	7400.00
0005434908172	25600	Economy	7400.00
0005434907949	25600	Economy	6700.00
0005433252272	25600	Economy	6700.00
0005433252259	25600	Economy	6700.00
0005433252268	25600	Economy	6700.00
0005434908149	25600	Economy	6700.00
0005433252281	25600	Economy	6700.00
0005434908097	25600	Economy	6700.00
0005434908073	25600	Economy	6700.00
0005434908112	25600	Economy	6700.00
0005434907969	25600	Economy	6700.00
0005434908135	25600	Economy	6700.00
0005434908056	25600	Economy	6700.00
0005434908111	25600	Economy	6700.00
0005433252266	25600	Economy	6700.00
0005433252279	25600	Economy	6700.00
0005433252274	25600	Economy	6700.00
0005434908253	25600	Economy	6700.00
0005434908130	25600	Economy	6700.00
0005434908256	25600	Economy	6700.00
0005434908209	25600	Economy	6700.00
0005434908131	25600	Economy	6700.00
0005434907995	25600	Economy	6700.00
0005433252275	25600	Economy	6700.00
0005434908179	25600	Economy	6700.00
0005434908031	25600	Economy	6700.00
0005433252270	25600	Economy	6700.00
0005434908077	25600	Economy	6700.00
0005434908156	25600	Economy	6700.00
0005434908006	25600	Economy	6700.00
0005433252263	25600	Economy	6700.00
0005434908005	25600	Economy	6700.00
0005433252280	25600	Economy	6700.00
0005434907997	25600	Economy	6700.00
0005434908055	25600	Economy	6700.00
0005434907967	25600	Economy	6700.00
0005433252255	25600	Economy	6700.00
0005434908129	25600	Economy	6700.00
0005434907966	25600	Economy	6700.00
0005433401062	25600	Economy	6700.00
0005433252278	25600	Economy	6700.00
0005434908079	25600	Economy	6700.00
0005434908100	25600	Economy	6700.00
0005433252273	25600	Economy	6700.00
0005434908050	25600	Economy	6700.00
0005433252254	25600	Economy	6700.00
0005434908083	25600	Economy	6700.00
0005434908166	25600	Economy	6700.00
0005433252256	25600	Economy	6700.00
0005434908254	25600	Economy	6700.00
0005433252264	25600	Economy	6700.00
0005434908030	25600	Economy	6700.00
0005434908012	25600	Economy	6700.00
0005433252276	25600	Economy	6700.00
0005434908148	25600	Economy	6700.00
0005433252283	25600	Economy	6700.00
0005434908066	25600	Economy	6700.00
0005434908076	25600	Economy	6700.00
0005434907996	25600	Economy	6700.00
0005433252260	25600	Economy	6700.00
0005434907994	25600	Economy	6700.00
0005433252267	25600	Economy	6700.00
0005434908258	25600	Economy	6700.00
0005434908098	25600	Economy	6700.00
0005432621400	2551	Economy	13600.00
0005432862437	2551	Economy	13600.00
0005432862460	2551	Economy	13600.00
0005432862439	2551	Economy	12400.00
0005432621398	2551	Economy	12400.00
0005432621405	2551	Economy	12400.00
0005432621394	2551	Economy	12400.00
0005432621403	2551	Economy	12400.00
0005432621404	2551	Economy	12400.00
0005432862419	2551	Economy	12400.00
0005432862452	2551	Economy	12400.00
0005432621406	2551	Economy	12400.00
0005432621402	2551	Economy	12400.00
0005432862438	2551	Economy	12400.00
0005432862462	2551	Economy	12400.00
0005432621407	2551	Economy	12400.00
0005432621396	2551	Economy	12400.00
0005432862463	2551	Economy	12400.00
0005432621401	2551	Economy	12400.00
0005432621397	2551	Economy	12400.00
0005432621399	2551	Economy	12400.00
0005432621395	2551	Economy	12400.00
0005432862436	2551	Economy	12400.00
0005432862451	2551	Economy	12400.00
0005432621279	28062	Economy	13600.00
0005432621256	28062	Economy	12400.00
0005432621286	28062	Economy	12400.00
0005432862498	28062	Economy	12400.00
0005432621289	28062	Economy	12400.00
0005432862503	28062	Economy	12400.00
0005432621257	28062	Economy	12400.00
0005432621290	28062	Economy	12400.00
0005432862501	28062	Economy	12400.00
0005432862502	28062	Economy	12400.00
0005432862497	28062	Economy	12400.00
0005432621254	28062	Economy	12400.00
0005432862504	28062	Economy	12400.00
0005432862499	28062	Economy	12400.00
0005432621278	28062	Economy	12400.00
0005432621291	28062	Economy	12400.00
0005432862500	28062	Economy	12400.00
0005432621255	28062	Economy	12400.00
0005432621258	28062	Economy	12400.00
0005432621303	28062	Economy	12400.00
0005434097497	11778	Economy	11300.00
0005434097506	13075	Economy	11300.00
0005434191300	32872	Business	89600.00
0005434552886	32872	Business	89600.00
0005434552869	32872	Business	89600.00
0005434552883	32872	Economy	29900.00
0005434552871	32872	Economy	29900.00
0005434191285	32872	Economy	29900.00
0005434552875	32872	Economy	32800.00
0005434191294	32872	Economy	32800.00
0005434191303	32872	Economy	32800.00
0005434191301	32872	Economy	29900.00
0005434552881	32872	Economy	29900.00
0005434552882	32872	Economy	29900.00
0005434552878	32872	Economy	29900.00
0005434552880	32872	Economy	29900.00
0005434191302	32872	Economy	29900.00
0005434191286	32872	Economy	29900.00
0005434191291	32872	Economy	29900.00
0005434191289	32872	Economy	29900.00
0005434552873	32872	Economy	29900.00
0005434552887	32872	Economy	29900.00
0005434191307	32872	Economy	29900.00
0005434552885	32872	Economy	29900.00
0005434191287	32872	Economy	29900.00
0005434552888	32872	Economy	29900.00
0005434552884	32872	Economy	29900.00
0005434191297	32872	Economy	29900.00
0005434191306	32872	Economy	29900.00
0005434552877	32872	Economy	29900.00
0005434552879	32872	Economy	29900.00
0005434552872	32872	Economy	29900.00
0005434191288	32872	Economy	29900.00
0005434552870	32872	Economy	29900.00
0005434552876	32872	Economy	29900.00
0005434552874	32872	Economy	29900.00
0005434552889	32872	Economy	29900.00
0005433452766	31384	Economy	8400.00
0005433452775	31384	Economy	8400.00
0005433452777	31384	Economy	8400.00
0005433452780	31384	Economy	8400.00
0005433452776	31384	Economy	8400.00
0005433452772	31384	Economy	8400.00
0005433452765	31384	Economy	8400.00
0005433452771	31384	Economy	8400.00
0005433454907	31384	Economy	8400.00
0005434326088	11972	Economy	6600.00
0005434184702	11972	Economy	6600.00
0005434142678	11972	Economy	6600.00
0005434184690	11972	Economy	6600.00
0005433129325	11972	Economy	6600.00
0005434184689	11972	Economy	6600.00
0005433129327	11972	Economy	6600.00
0005434326056	11972	Economy	6600.00
0005433134202	11972	Economy	6600.00
0005434184701	11972	Economy	6600.00
0005433129326	11972	Economy	6600.00
0005433134234	11972	Economy	6600.00
0005434326087	11972	Economy	6600.00
0005434326055	11972	Economy	6600.00
0005434142709	29853	Economy	7200.00
0005434183632	29853	Economy	6600.00
0005434142707	29853	Economy	6600.00
0005433134252	29853	Economy	6600.00
0005434183631	29853	Economy	6600.00
0005434142708	29853	Economy	6600.00
0005433134251	29853	Economy	6600.00
0005434184717	29853	Economy	6600.00
0005434184718	29853	Economy	6600.00
0005433131825	29853	Economy	6600.00
0005433131824	29853	Economy	6600.00
0005434142711	29853	Economy	6600.00
0005433131826	29853	Economy	6600.00
0005434183633	29853	Economy	6600.00
0005434142710	29853	Economy	6600.00
0005434142712	29853	Economy	6600.00
0005435799004	1607	Economy	17200.00
0005435798998	1607	Economy	15700.00
0005435798995	1607	Economy	15700.00
0005435798994	1607	Economy	15700.00
0005435798992	1607	Economy	15700.00
0005435799008	1607	Economy	15700.00
0005435798999	1607	Economy	15700.00
0005435799001	1607	Economy	15700.00
0005435799007	1607	Economy	15700.00
0005435798993	1607	Economy	15700.00
0005435799002	1607	Economy	15700.00
0005435798996	1607	Economy	15700.00
0005435799006	1607	Economy	15700.00
0005435799005	1607	Economy	15700.00
0005435799003	1607	Economy	15700.00
0005435798997	1607	Economy	15700.00
0005435799000	1607	Economy	15700.00
0005435698033	16465	Economy	19900.00
0005435698020	16465	Economy	19900.00
0005435698032	16465	Economy	18100.00
0005435698036	16465	Economy	18100.00
0005435698023	16465	Economy	18100.00
0005435698040	16465	Economy	18100.00
0005435935092	16465	Economy	18100.00
0005435698026	16465	Economy	18100.00
0005435698021	16465	Economy	18100.00
0005435698027	16465	Economy	18100.00
0005435698042	16465	Economy	18100.00
0005435698043	16465	Economy	18100.00
0005435698044	16465	Economy	18100.00
0005435698035	16465	Economy	18100.00
0005435698022	16465	Economy	18100.00
0005435698037	16465	Economy	18100.00
0005435698030	16465	Economy	18100.00
0005435698039	16465	Economy	18100.00
0005435698034	16465	Economy	18100.00
0005435698029	16465	Economy	18100.00
0005435698025	16465	Economy	18100.00
0005435698038	16465	Economy	18100.00
0005435698019	16465	Economy	18100.00
0005435698024	16465	Economy	18100.00
0005435698028	16465	Economy	18100.00
0005435935091	16465	Economy	18100.00
0005435698031	16465	Economy	18100.00
0005435935094	16465	Economy	18100.00
0005435698041	16465	Economy	18100.00
0005435697890	24697	Economy	19900.00
0005435697723	24697	Economy	19900.00
0005435697825	24697	Economy	19900.00
0005435697927	24697	Economy	19900.00
0005435697764	24697	Economy	18100.00
0005435933576	24697	Economy	18100.00
0005435697707	24697	Economy	18100.00
0005435697911	24697	Economy	18100.00
0005435697893	24697	Economy	18100.00
0005435697883	24697	Economy	18100.00
0005435697870	24697	Economy	18100.00
0005435697886	24697	Economy	18100.00
0005435697824	24697	Economy	18100.00
0005435697767	24697	Economy	18100.00
0005435697737	24697	Economy	18100.00
0005435697887	24697	Economy	18100.00
0005435697722	24697	Economy	18100.00
0005435933575	24697	Economy	18100.00
0005435697986	24697	Economy	18100.00
0005435697708	24697	Economy	18100.00
0005435697752	24697	Economy	18100.00
0005435697779	24697	Economy	18100.00
0005435697724	24697	Economy	18100.00
0005435697763	24697	Economy	18100.00
0005435697987	24697	Economy	18100.00
0005435935126	24697	Economy	18100.00
0005435697889	24697	Economy	18100.00
0005435697709	24697	Economy	18100.00
0005435933577	24697	Economy	18100.00
0005435697828	24697	Economy	18100.00
0005435697836	24697	Economy	18100.00
0005435697827	24697	Economy	18100.00
0005435697816	24697	Economy	18100.00
0005435697848	24697	Economy	18100.00
0005435697787	24697	Economy	18100.00
0005435697979	24697	Economy	18100.00
0005435697738	24697	Economy	18100.00
0005432968883	18803	Economy	4400.00
0005433724918	18803	Economy	4400.00
0005433724919	18803	Economy	4400.00
0005432968884	18803	Economy	4400.00
0005432968879	18803	Economy	4400.00
0005432968885	18803	Economy	4400.00
0005433724922	18803	Economy	4400.00
0005432968877	18803	Economy	4400.00
0005433724920	18803	Economy	4400.00
0005433724921	18803	Economy	4400.00
0005432968903	21639	Economy	4400.00
0005433724893	21639	Economy	4400.00
0005432968900	21639	Economy	4400.00
0005433724880	21639	Economy	4400.00
0005432968902	21639	Economy	4400.00
0005433724864	21639	Economy	4400.00
0005433724873	21639	Economy	4400.00
0005432968901	21639	Economy	4400.00
0005433724872	21639	Economy	4400.00
0005434140203	7334	Business	23100.00
0005434140223	7334	Business	23100.00
0005434140262	7334	Business	23100.00
0005434140260	7334	Business	23100.00
0005434140214	7334	Business	23100.00
0005434140253	7334	Business	23100.00
0005434140226	7334	Business	23100.00
0005434140220	7334	Business	23100.00
0005434140228	7334	Business	23100.00
0005434140250	7334	Business	23100.00
0005434140267	7334	Business	23100.00
0005434140213	7334	Business	23100.00
0005434140255	7334	Economy	7700.00
0005434140247	7334	Economy	7700.00
0005434140270	7334	Economy	7700.00
0005434140284	7334	Economy	7700.00
0005434140205	7334	Economy	7700.00
0005434140272	7334	Economy	7700.00
0005434140280	7334	Economy	7700.00
0005434140206	7334	Economy	7700.00
0005434140235	7334	Economy	7700.00
0005434140258	7334	Economy	7700.00
0005434140229	7334	Economy	8500.00
0005434140289	7334	Economy	8500.00
0005434140287	7334	Economy	8500.00
0005434140212	7334	Economy	8500.00
0005434140273	7334	Economy	8500.00
0005434140239	7334	Economy	7700.00
0005434140271	7334	Economy	7700.00
0005434140230	7334	Economy	7700.00
0005434140231	7334	Economy	7700.00
0005434140238	7334	Economy	7700.00
0005434140282	7334	Economy	7700.00
0005434140263	7334	Economy	7700.00
0005434140290	7334	Economy	7700.00
0005434087637	7334	Economy	7700.00
0005434140216	7334	Economy	7700.00
0005434140257	7334	Economy	7700.00
0005434140244	7334	Economy	7700.00
0005434140274	7334	Economy	7700.00
0005434140286	7334	Economy	7700.00
0005434140227	7334	Economy	7700.00
0005434140268	7334	Economy	7700.00
0005434140204	7334	Economy	7700.00
0005434140219	7334	Economy	7700.00
0005434140241	7334	Economy	7700.00
0005434140233	7334	Economy	7700.00
0005434140256	7334	Economy	7700.00
0005434140217	7334	Economy	7700.00
0005434140211	7334	Economy	7700.00
0005434140218	7334	Economy	7700.00
0005434140209	7334	Economy	7700.00
0005434140208	7334	Economy	7700.00
0005434140221	7334	Economy	7700.00
0005434140210	7334	Economy	7700.00
0005434140243	7334	Economy	7700.00
0005434140242	7334	Economy	7700.00
0005434140276	7334	Economy	7700.00
0005434140266	7334	Economy	7700.00
0005434140234	7334	Economy	7700.00
0005434140245	7334	Economy	7700.00
0005434140261	7334	Economy	7700.00
0005434087638	7334	Economy	7700.00
0005434140285	7334	Economy	7700.00
0005434087639	7334	Economy	7700.00
0005434140288	7334	Economy	7700.00
0005434140246	7334	Economy	7700.00
0005434140222	7334	Economy	7700.00
0005434140224	7334	Economy	7700.00
0005434140278	7334	Economy	7700.00
0005434140236	7334	Economy	7700.00
0005434140283	7334	Economy	7700.00
0005434140291	7334	Economy	7700.00
0005434140232	7334	Economy	7700.00
0005434140248	7334	Economy	7700.00
0005434140294	7334	Economy	7700.00
0005434140252	7334	Economy	7700.00
0005434140293	7334	Economy	7700.00
0005434140292	7334	Economy	7700.00
0005434140215	7334	Economy	7700.00
0005434140277	7334	Economy	7700.00
0005434140251	7334	Economy	7700.00
0005434140259	7334	Economy	7700.00
0005434140269	7334	Economy	7700.00
0005434140249	7334	Economy	7700.00
0005434140237	7334	Economy	7700.00
0005434140240	7334	Economy	7700.00
0005434140264	7334	Economy	7700.00
0005434140254	7334	Economy	7700.00
0005434140265	7334	Economy	7700.00
0005434087640	7334	Economy	7700.00
0005434140225	7334	Economy	7700.00
0005434140281	7334	Economy	7700.00
0005434140207	7334	Economy	7700.00
0005434087641	7334	Economy	7700.00
0005434140275	7334	Economy	7700.00
0005434140279	7334	Economy	7700.00
0005434139307	28564	Business	23100.00
0005434139521	28564	Business	23100.00
0005434087583	28564	Business	23100.00
0005434139195	28564	Business	23100.00
0005434139323	28564	Business	23100.00
0005434139295	28564	Business	23100.00
0005434139231	28564	Business	23100.00
0005434139229	28564	Business	23100.00
0005434139339	28564	Business	23100.00
0005434139236	28564	Business	23100.00
0005434139348	28564	Business	23100.00
0005434139527	28564	Business	23100.00
0005434139434	28564	Economy	7700.00
0005434139595	28564	Economy	7700.00
0005434139351	28564	Economy	7700.00
0005434139413	28564	Economy	7700.00
0005434139589	28564	Economy	7700.00
0005434139233	28564	Economy	7700.00
0005434139463	28564	Economy	7700.00
0005434139444	28564	Economy	7700.00
0005434087623	28564	Economy	7700.00
0005434139300	28564	Economy	7700.00
0005434139235	28564	Economy	8500.00
0005434087593	28564	Economy	8500.00
0005434139462	28564	Economy	8500.00
0005434139301	28564	Economy	8500.00
0005434139132	28564	Economy	8500.00
0005434139592	28564	Economy	7700.00
0005434139321	28564	Economy	7700.00
0005434139500	28564	Economy	7700.00
0005434139320	28564	Economy	7700.00
0005434139426	28564	Economy	7700.00
0005434139247	28564	Economy	7700.00
0005434138781	28564	Economy	7700.00
0005434139246	28564	Economy	7700.00
0005434139346	28564	Economy	7700.00
0005434139350	28564	Economy	7700.00
0005434139399	28564	Economy	7700.00
0005434139318	28564	Economy	7700.00
0005434139302	28564	Economy	7700.00
0005434139450	28564	Economy	7700.00
0005434139477	28564	Economy	7700.00
0005434139328	28564	Economy	7700.00
0005434139591	28564	Economy	7700.00
0005434139499	28564	Economy	7700.00
0005434139319	28564	Economy	7700.00
0005434139327	28564	Economy	7700.00
0005434139423	28564	Economy	7700.00
0005434139329	28564	Economy	7700.00
0005434139522	28564	Economy	7700.00
0005434139294	28564	Economy	7700.00
0005434139232	28564	Economy	7700.00
0005434139446	28564	Economy	7700.00
0005434139130	28564	Economy	7700.00
0005434139439	28564	Economy	7700.00
0005434139427	28564	Economy	7700.00
0005434139330	28564	Economy	7700.00
0005434139418	28564	Economy	7700.00
0005434139230	28564	Economy	7700.00
0005434139409	28564	Economy	7700.00
0005434087594	28564	Economy	7700.00
0005434139526	28564	Economy	7700.00
0005434139539	28564	Economy	7700.00
0005434139431	28564	Economy	7700.00
0005434139398	28564	Economy	7700.00
0005434139590	28564	Economy	7700.00
0005434139466	28564	Economy	7700.00
0005434139234	28564	Economy	7700.00
0005434139513	28564	Economy	7700.00
0005434139437	28564	Economy	7700.00
0005434139449	28564	Economy	7700.00
0005434139514	28564	Economy	7700.00
0005434139596	28564	Economy	7700.00
0005434139257	28564	Economy	7700.00
0005434139433	28564	Economy	7700.00
0005434139217	28564	Economy	7700.00
0005434139519	28564	Economy	7700.00
0005434139520	28564	Economy	7700.00
0005434139540	28564	Economy	7700.00
0005434139456	28564	Economy	7700.00
0005434139496	28564	Economy	7700.00
0005434139438	28564	Economy	7700.00
0005434139548	28564	Economy	7700.00
0005434139408	28564	Economy	7700.00
0005434139412	28564	Economy	7700.00
0005434139407	28564	Economy	7700.00
0005434139093	28564	Economy	7700.00
0005434139315	28564	Economy	7700.00
0005434139194	28564	Economy	7700.00
0005434139448	28564	Economy	7700.00
0005434087578	28564	Economy	7700.00
0005434139467	28564	Economy	7700.00
0005434610325	1946	Economy	23900.00
0005434610324	1946	Economy	23900.00
0005434610321	1946	Economy	21700.00
0005433407629	1946	Economy	21700.00
0005433407643	1946	Economy	21700.00
0005435808486	1946	Economy	21700.00
0005433407637	1946	Economy	21700.00
0005433407663	1946	Economy	21700.00
0005434610323	1946	Economy	21700.00
0005435808487	1946	Economy	21700.00
0005435808483	1946	Economy	21700.00
0005435808492	1946	Economy	21700.00
0005433407639	1946	Economy	21700.00
0005433407640	1946	Economy	21700.00
0005433407664	1946	Economy	21700.00
0005435808489	1946	Economy	21700.00
0005435808485	1946	Economy	21700.00
0005435808484	1946	Economy	21700.00
0005434610322	1946	Economy	21700.00
0005433407650	1946	Economy	21700.00
0005435808488	1946	Economy	21700.00
0005433407626	1946	Economy	21700.00
0005435808490	1946	Economy	21700.00
0005433407644	1946	Economy	21700.00
0005435808491	1946	Economy	21700.00
0005434610298	23076	Economy	21700.00
0005434610295	23076	Economy	21700.00
0005434610296	23076	Economy	21700.00
0005434610299	23076	Economy	21700.00
0005434504833	16715	Economy	7600.00
0005434504886	16715	Economy	7600.00
0005434504788	16715	Economy	7600.00
0005434505012	16715	Economy	7600.00
0005434504752	16715	Economy	6900.00
0005434504695	16715	Economy	6900.00
0005434504744	16715	Economy	6900.00
0005434504874	16715	Economy	6900.00
0005434504669	16715	Economy	6900.00
0005434504812	16715	Economy	6900.00
0005434504937	16715	Economy	6900.00
0005434504791	16715	Economy	6900.00
0005434504811	16715	Economy	6900.00
0005434504783	16715	Economy	6900.00
0005434504887	16715	Economy	6900.00
0005434504880	16715	Economy	6900.00
0005434504750	16715	Economy	6900.00
0005434504615	16715	Economy	6900.00
0005434504839	16715	Economy	6900.00
0005434504742	16715	Economy	6900.00
0005434504840	16715	Economy	6900.00
0005434504810	16715	Economy	6900.00
0005434504861	16715	Economy	6900.00
0005434504778	16715	Economy	6900.00
0005434504860	16715	Economy	6900.00
0005434504823	16715	Economy	6900.00
0005434504981	16715	Economy	6900.00
0005434504854	16715	Economy	6900.00
0005434504853	16715	Economy	6900.00
0005434504729	16715	Economy	6900.00
0005434504983	16715	Economy	6900.00
0005434504754	16715	Economy	6900.00
0005434504899	16715	Economy	6900.00
0005434504751	16715	Economy	6900.00
0005434504784	16715	Economy	6900.00
0005434504851	16715	Economy	6900.00
0005434504852	16715	Economy	6900.00
0005434505011	16715	Economy	6900.00
0005434504753	16715	Economy	6900.00
0005434504680	16715	Economy	6900.00
0005434504663	16715	Economy	6900.00
0005434504982	16715	Economy	6900.00
0005434504546	16715	Economy	6900.00
0005434504873	16715	Economy	6900.00
0005434505112	22926	Economy	7600.00
0005434505132	22926	Economy	7600.00
0005434505150	22926	Economy	7600.00
0005434505138	22926	Economy	6900.00
0005434505123	22926	Economy	6900.00
0005434505124	22926	Economy	6900.00
0005434505114	22926	Economy	6900.00
0005434505128	22926	Economy	6900.00
0005434505127	22926	Economy	6900.00
0005434505145	22926	Economy	6900.00
0005434505143	22926	Economy	6900.00
0005434505146	22926	Economy	6900.00
0005434505144	22926	Economy	6900.00
0005434505148	22926	Economy	6900.00
0005434505137	22926	Economy	6900.00
0005434505134	22926	Economy	6900.00
0005434505113	22926	Economy	6900.00
0005434505147	22926	Economy	6900.00
0005434505149	22926	Economy	6900.00
0005434505136	22926	Economy	6900.00
0005434505121	22926	Economy	6900.00
0005434505111	22926	Economy	6900.00
0005434505122	22926	Economy	6900.00
0005434505126	22926	Economy	6900.00
0005434505141	22926	Economy	6900.00
0005434505140	22926	Economy	6900.00
0005434505125	22926	Economy	6900.00
0005434505129	22926	Economy	6900.00
0005434505130	22926	Economy	6900.00
0005434505131	22926	Economy	6900.00
0005434505118	22926	Economy	6900.00
0005434505135	22926	Economy	6900.00
0005434505120	22926	Economy	6900.00
0005434505139	22926	Economy	6900.00
0005434505151	22926	Economy	6900.00
0005434505117	22926	Economy	6900.00
0005434505115	22926	Economy	6900.00
0005434505142	22926	Economy	6900.00
0005434505119	22926	Economy	6900.00
0005434505133	22926	Economy	6900.00
0005434505116	22926	Economy	6900.00
0005434608397	6498	Economy	19100.00
0005434608383	6498	Economy	17300.00
0005434608380	6498	Economy	17300.00
0005434608386	6498	Economy	17300.00
0005434608394	6498	Economy	17300.00
0005434608384	6498	Economy	17300.00
0005434608392	6498	Economy	17300.00
0005434608388	6498	Economy	17300.00
0005434608385	6498	Economy	17300.00
0005434608391	6498	Economy	17300.00
0005434608378	6498	Economy	17300.00
0005434608389	6498	Economy	17300.00
0005434608395	6498	Economy	17300.00
0005434608382	6498	Economy	17300.00
0005434608379	6498	Economy	17300.00
0005434608381	6498	Economy	17300.00
0005434608387	6498	Economy	17300.00
0005434608393	6498	Economy	17300.00
0005434608390	6498	Economy	17300.00
0005434608396	6498	Economy	17300.00
0005434608355	22494	Economy	19100.00
0005434608359	22494	Economy	19100.00
0005434608365	22494	Economy	17300.00
0005434608349	22494	Economy	17300.00
0005434608351	22494	Economy	17300.00
0005434608364	22494	Economy	17300.00
0005434608345	22494	Economy	17300.00
0005434608354	22494	Economy	17300.00
0005434608348	22494	Economy	17300.00
0005434608346	22494	Economy	17300.00
0005434608372	22494	Economy	17300.00
0005434608353	22494	Economy	17300.00
0005434608358	22494	Economy	17300.00
0005434608347	22494	Economy	17300.00
0005434608356	22494	Economy	17300.00
0005434608339	22494	Economy	17300.00
0005435078742	2198	Economy	7700.00
0005433266893	2198	Economy	7700.00
0005435078739	2198	Economy	7000.00
0005433266918	2198	Economy	7000.00
0005433266907	2198	Economy	7000.00
0005433266904	2198	Economy	7000.00
0005433266916	2198	Economy	7000.00
0005433266897	2198	Economy	7000.00
0005435078737	2198	Economy	7000.00
0005435078740	2198	Economy	7000.00
0005435078732	2198	Economy	7000.00
0005433266909	2198	Economy	7000.00
0005435078734	2198	Economy	7000.00
0005435078736	2198	Economy	7000.00
0005433266911	2198	Economy	7000.00
0005433266898	2198	Economy	7000.00
0005435078743	2198	Economy	7000.00
0005433266882	2198	Economy	7000.00
0005435078744	2198	Economy	7000.00
0005435078738	2198	Economy	7000.00
0005433266903	2198	Economy	7000.00
0005435078733	2198	Economy	7000.00
0005433266864	2198	Economy	7000.00
0005435078741	2198	Economy	7000.00
0005435078735	2198	Economy	7000.00
0005435078602	24320	Economy	7700.00
0005433266960	24320	Economy	7000.00
0005433266959	24320	Economy	7000.00
0005433266961	24320	Economy	7000.00
0005435078653	24320	Economy	7000.00
0005433266965	24320	Economy	7000.00
0005435078667	24320	Economy	7000.00
0005435078668	24320	Economy	7000.00
0005433266963	24320	Economy	7000.00
0005433266958	24320	Economy	7000.00
0005435078574	24320	Economy	7000.00
0005435078595	24320	Economy	7000.00
0005435078664	24320	Economy	7000.00
0005433266964	24320	Economy	7000.00
0005435078577	24320	Economy	7000.00
0005435078603	24320	Economy	7000.00
0005435078604	24320	Economy	7000.00
0005435078590	24320	Economy	7000.00
0005433266962	24320	Economy	7000.00
0005433266966	24320	Economy	7000.00
0005435078698	24320	Economy	7000.00
0005435078576	24320	Economy	7000.00
0005435078665	24320	Economy	7000.00
0005434989028	6639	Economy	10800.00
0005434989024	6639	Economy	10800.00
0005434989026	6639	Economy	9800.00
0005434989023	6639	Economy	9800.00
0005434989027	6639	Economy	9800.00
0005435803336	6639	Economy	9800.00
0005434989022	6639	Economy	9800.00
0005434989021	6639	Economy	9800.00
0005435803337	6639	Economy	9800.00
0005434989025	6639	Economy	9800.00
0005434989029	6639	Economy	9800.00
0005434989031	6639	Economy	9800.00
0005434989030	6639	Economy	9800.00
0005435803338	6639	Economy	9800.00
0005434988895	23641	Economy	10800.00
0005434988852	23641	Economy	10800.00
0005434988866	23641	Economy	9800.00
0005435464559	23641	Economy	9800.00
0005434988853	23641	Economy	9800.00
0005434988892	23641	Economy	9800.00
0005434988891	23641	Economy	9800.00
0005434988876	23641	Economy	9800.00
0005434988867	23641	Economy	9800.00
0005434988806	23641	Economy	9800.00
0005434988893	23641	Economy	9800.00
0005435803306	23641	Economy	9800.00
0005434988890	23641	Economy	9800.00
0005434988899	23641	Economy	9800.00
0005434988883	23641	Economy	9800.00
0005434988858	23641	Economy	9800.00
0005435803305	23641	Economy	9800.00
0005435803309	23641	Economy	9800.00
0005434988896	23641	Economy	9800.00
0005432384168	30483	Business	9900.00
0005432384181	30483	Business	9900.00
0005432384162	30483	Business	9900.00
0005433450522	30483	Business	9900.00
0005433450526	30483	Business	9900.00
0005433450534	30483	Business	9900.00
0005432384166	30483	Business	9900.00
0005432384192	30483	Business	9900.00
0005433450519	30483	Business	9900.00
0005432384180	30483	Economy	3300.00
0005433450520	30483	Economy	3300.00
0005432384175	30483	Economy	3300.00
0005433450525	30483	Economy	3300.00
0005433450530	30483	Economy	3300.00
0005432384164	30483	Economy	3300.00
0005433450527	30483	Economy	3600.00
0005432384191	30483	Economy	3600.00
0005433450521	30483	Economy	3600.00
0005432384171	30483	Economy	3300.00
0005433450533	30483	Economy	3300.00
0005433453813	30483	Economy	3300.00
0005433450528	30483	Economy	3300.00
0005433450532	30483	Economy	3300.00
0005432384193	30483	Economy	3300.00
0005432384169	30483	Economy	3300.00
0005432384165	30483	Economy	3300.00
0005432384194	30483	Economy	3300.00
0005432384167	30483	Economy	3300.00
0005432384177	30483	Economy	3300.00
0005432384189	30483	Economy	3300.00
0005432384174	30483	Economy	3300.00
0005432384178	30483	Economy	3300.00
0005432384163	30483	Economy	3300.00
0005432384179	30483	Economy	3300.00
0005433450531	30483	Economy	3300.00
0005432384185	30483	Economy	3300.00
0005432384188	30483	Economy	3300.00
0005432384184	30483	Economy	3300.00
0005433450539	30483	Economy	3300.00
0005433450538	30483	Economy	3300.00
0005433450523	30483	Economy	3300.00
0005432384161	30483	Economy	3300.00
0005432384170	30483	Economy	3300.00
0005432384173	30483	Economy	3300.00
0005432384187	30483	Economy	3300.00
0005432384196	30483	Economy	3300.00
0005432384176	30483	Economy	3300.00
0005432384197	30483	Economy	3300.00
0005433450535	30483	Economy	3300.00
0005433453812	30483	Economy	3300.00
0005433450529	30483	Economy	3300.00
0005433450524	30483	Economy	3300.00
0005433450537	30483	Economy	3300.00
0005433450536	30483	Economy	3300.00
0005432384195	30483	Economy	3300.00
0005432384172	30483	Economy	3300.00
0005432384182	30483	Economy	3300.00
0005432384186	30483	Economy	3300.00
0005432384183	30483	Economy	3300.00
0005432384190	30483	Economy	3300.00
0005433454929	30483	Economy	3300.00
0005432383620	31284	Business	9900.00
0005433450373	31284	Business	9900.00
0005432383824	31284	Business	9900.00
0005432383650	31284	Business	9900.00
0005433450331	31284	Business	9900.00
0005433450350	31284	Economy	3300.00
0005432383704	31284	Economy	3300.00
0005432383734	31284	Economy	3300.00
0005433450349	31284	Economy	3300.00
0005432383690	31284	Economy	3300.00
0005432383758	31284	Economy	3300.00
0005433451648	31284	Economy	3300.00
0005432383781	31284	Economy	3600.00
0005433450372	31284	Economy	3600.00
0005433450403	31284	Economy	3600.00
0005432383793	31284	Economy	3600.00
0005432383759	31284	Economy	3300.00
0005432383572	31284	Economy	3300.00
0005432383651	31284	Economy	3300.00
0005433453795	31284	Economy	3300.00
0005433451649	31284	Economy	3300.00
0005433450216	31284	Economy	3300.00
0005432383748	31284	Economy	3300.00
0005433450401	31284	Economy	3300.00
0005433450351	31284	Economy	3300.00
0005432383628	31284	Economy	3300.00
0005432383767	31284	Economy	3300.00
0005433450369	31284	Economy	3300.00
0005433450326	31284	Economy	3300.00
0005433450404	31284	Economy	3300.00
0005433451647	31284	Economy	3300.00
0005433450320	31284	Economy	3300.00
0005433450400	31284	Economy	3300.00
0005433453794	31284	Economy	3300.00
0005432383753	31284	Economy	3300.00
0005432383713	31284	Economy	3300.00
0005433450298	31284	Economy	3300.00
0005433450290	31284	Economy	3300.00
0005433450321	31284	Economy	3300.00
0005433450217	31284	Economy	3300.00
0005433450323	31284	Economy	3300.00
0005432383728	31284	Economy	3300.00
0005433450239	31284	Economy	3300.00
0005433450380	31284	Economy	3300.00
0005432383702	31284	Economy	3300.00
0005432383712	31284	Economy	3300.00
0005433450339	31284	Economy	3300.00
0005433450324	31284	Economy	3300.00
0005433451651	31284	Economy	3300.00
0005433450332	31284	Economy	3300.00
0005433450307	31284	Economy	3300.00
0005433450325	31284	Economy	3300.00
0005432383689	31284	Economy	3300.00
0005432383828	31284	Economy	3300.00
0005433450297	31284	Economy	3300.00
0005433450387	31284	Economy	3300.00
0005433450392	31284	Economy	3300.00
0005433450402	31284	Economy	3300.00
0005432383727	31284	Economy	3300.00
0005435548539	20811	Economy	26200.00
0005433788298	20811	Economy	26200.00
0005435548568	20811	Economy	23800.00
0005433788297	20811	Economy	23800.00
0005435548541	20811	Economy	23800.00
0005435548552	20811	Economy	23800.00
0005435548553	20811	Economy	23800.00
0005433788302	20811	Economy	23800.00
0005435548570	20811	Economy	23800.00
0005435548567	20811	Economy	23800.00
0005433788301	20811	Economy	23800.00
0005433788304	20811	Economy	23800.00
0005435548558	20811	Economy	23800.00
0005433788300	20811	Economy	23800.00
0005435548551	20811	Economy	23800.00
0005435548540	20811	Economy	23800.00
0005433788294	20811	Economy	23800.00
0005435548543	20811	Economy	23800.00
0005433788299	20811	Economy	23800.00
0005433788296	20811	Economy	23800.00
0005435548538	20811	Economy	23800.00
0005433788303	20811	Economy	23800.00
0005435548544	20811	Economy	23800.00
0005435548532	20811	Economy	23800.00
0005435548542	20811	Economy	23800.00
0005435548569	20811	Economy	23800.00
0005435548522	20811	Economy	23800.00
0005433788295	20811	Economy	23800.00
0005435299854	10756	Economy	17100.00
0005435304238	10756	Economy	15600.00
0005435299870	10756	Economy	15600.00
0005433126907	10756	Economy	15600.00
0005435299869	10756	Economy	15600.00
0005435299861	10756	Economy	15600.00
0005433131778	10756	Economy	15600.00
0005433131762	10756	Economy	15600.00
0005435304239	10756	Economy	15600.00
0005435299853	10756	Economy	15600.00
0005435299871	10756	Economy	15600.00
0005435299860	10756	Economy	15600.00
0005433126924	10756	Economy	15600.00
0005433126965	29694	Economy	17100.00
0005433126964	29694	Economy	15600.00
0005433126963	29694	Economy	15600.00
0005435302322	29694	Economy	15600.00
0005435302326	29694	Economy	15600.00
0005433129395	29694	Economy	15600.00
0005435302324	29694	Economy	15600.00
0005435299904	29694	Economy	15600.00
0005435302325	29694	Economy	15600.00
0005435299901	29694	Economy	15600.00
0005435302323	29694	Economy	15600.00
0005435299905	29694	Economy	15600.00
0005433126966	29694	Economy	15600.00
0005433129397	29694	Economy	15600.00
0005435299902	29694	Economy	15600.00
0005433129396	29694	Economy	15600.00
0005433129398	29694	Economy	15600.00
0005433126962	29694	Economy	15600.00
0005435299903	29694	Economy	15600.00
0005434287867	2425	Economy	17200.00
0005434287864	2425	Economy	17200.00
0005433110206	2425	Economy	15700.00
0005434287851	2425	Economy	15700.00
0005434287866	2425	Economy	15700.00
0005434287860	2425	Economy	15700.00
0005434287857	2425	Economy	15700.00
0005433110286	2425	Economy	15700.00
0005433110252	2425	Economy	15700.00
0005434287863	2425	Economy	15700.00
0005433110281	2425	Economy	15700.00
0005434287859	2425	Economy	15700.00
0005434287865	2425	Economy	15700.00
0005433110247	2425	Economy	15700.00
0005433110285	2425	Economy	15700.00
0005434287852	2425	Economy	15700.00
0005433110306	2425	Economy	15700.00
0005433110262	2425	Economy	15700.00
0005433110282	2425	Economy	15700.00
0005433110292	2425	Economy	15700.00
0005432264539	2425	Economy	15700.00
0005434287847	2425	Economy	15700.00
0005434287853	2425	Economy	15700.00
0005432264538	2425	Economy	15700.00
0005434287848	2425	Economy	15700.00
0005433110323	2425	Economy	15700.00
0005433110263	2425	Economy	15700.00
0005434287850	2425	Economy	15700.00
0005434287849	2425	Economy	15700.00
0005433110256	2425	Economy	15700.00
0005434287861	2425	Economy	15700.00
0005433110324	2425	Economy	15700.00
0005433110280	2425	Economy	15700.00
0005434287858	2425	Economy	15700.00
0005434287855	2425	Economy	15700.00
0005434287862	2425	Economy	15700.00
0005434287846	2425	Economy	15700.00
0005433110251	2425	Economy	15700.00
0005433110257	2425	Economy	15700.00
0005434287856	2425	Economy	15700.00
0005434287854	2425	Economy	15700.00
0005434287685	26866	Economy	17200.00
0005434287580	26866	Economy	17200.00
0005433110365	26866	Economy	17200.00
0005434287771	26866	Economy	15700.00
0005433110357	26866	Economy	15700.00
0005434287708	26866	Economy	15700.00
0005434287752	26866	Economy	15700.00
0005434287616	26866	Economy	15700.00
0005434287709	26866	Economy	15700.00
0005434287651	26866	Economy	15700.00
0005433110367	26866	Economy	15700.00
0005433110360	26866	Economy	15700.00
0005434287684	26866	Economy	15700.00
0005434287713	26866	Economy	15700.00
0005433110364	26866	Economy	15700.00
0005433110363	26866	Economy	15700.00
0005434287591	26866	Economy	15700.00
0005433110361	26866	Economy	15700.00
0005434287786	26866	Economy	15700.00
0005434287705	26866	Economy	15700.00
0005434287638	26866	Economy	15700.00
0005434287590	26866	Economy	15700.00
0005434287787	26866	Economy	15700.00
0005434287710	26866	Economy	15700.00
0005434287652	26866	Economy	15700.00
0005433110362	26866	Economy	15700.00
0005434287611	26866	Economy	15700.00
0005434287637	26866	Economy	15700.00
0005434287610	26866	Economy	15700.00
0005433110359	26866	Economy	15700.00
0005434287661	26866	Economy	15700.00
0005433110358	26866	Economy	15700.00
0005434287630	26866	Economy	15700.00
0005433110366	26866	Economy	15700.00
0005435856346	25472	Economy	25000.00
0005435856313	25472	Economy	25000.00
0005435856347	25472	Economy	22800.00
0005435856345	25472	Economy	22800.00
0005435856314	25472	Economy	22800.00
0005434269135	25472	Economy	22800.00
0005435856312	25472	Economy	22800.00
0005434269137	25472	Economy	22800.00
0005435856344	25472	Economy	22800.00
0005434269136	25472	Economy	22800.00
0005435856263	26669	Economy	22800.00
0005434273118	26669	Economy	22800.00
0005434273119	26669	Economy	22800.00
0005435856264	26669	Economy	22800.00
0005434273117	26669	Economy	22800.00
0005434272230	26669	Economy	22800.00
0005435856267	26669	Economy	22800.00
0005435856271	26669	Economy	22800.00
0005435856262	26669	Economy	22800.00
0005434273131	26669	Economy	22800.00
0005435856272	26669	Economy	22800.00
0005435856277	26669	Economy	22800.00
0005434273132	26669	Economy	22800.00
0005435856276	26669	Economy	22800.00
0005434520420	19084	Economy	24600.00
0005435314943	19084	Economy	24600.00
0005434520406	19084	Economy	22300.00
0005434520371	19084	Economy	22300.00
0005435314936	19084	Economy	22300.00
0005434520383	19084	Economy	22300.00
0005434520358	19084	Economy	22300.00
0005434520372	19084	Economy	22300.00
0005434520379	19084	Economy	22300.00
0005434520368	19084	Economy	22300.00
0005435314942	19084	Economy	22300.00
0005434520393	19084	Economy	22300.00
0005435314931	19084	Economy	22300.00
0005435314935	19084	Economy	22300.00
0005435314939	19084	Economy	22300.00
0005435314932	19084	Economy	22300.00
0005434520407	19084	Economy	22300.00
0005435314940	19084	Economy	22300.00
0005434520405	19084	Economy	22300.00
0005435314937	19084	Economy	22300.00
0005435314944	19084	Economy	22300.00
0005434520391	19084	Economy	22300.00
0005434520409	19084	Economy	22300.00
0005434520445	19084	Economy	22300.00
0005435314941	19084	Economy	22300.00
0005434520440	19084	Economy	22300.00
0005434520410	19084	Economy	22300.00
0005434520418	19084	Economy	22300.00
0005434520402	19084	Economy	22300.00
0005434520444	19084	Economy	22300.00
0005435314933	19084	Economy	22300.00
0005435314938	19084	Economy	22300.00
0005434520390	19084	Economy	22300.00
0005435314934	19084	Economy	22300.00
0005434520413	19084	Economy	22300.00
0005433874445	7787	Economy	17400.00
0005433874441	7787	Economy	17400.00
0005433874444	7787	Economy	17400.00
0005433874443	7787	Economy	17400.00
0005433874446	7787	Economy	17400.00
0005433874442	7787	Economy	17400.00
0005433874437	7787	Economy	17400.00
0005433874436	7787	Economy	17400.00
0005433874439	7787	Economy	17400.00
0005433874438	7787	Economy	17400.00
0005433874440	7787	Economy	17400.00
0005433874447	7787	Economy	17400.00
0005433874404	32630	Economy	19200.00
0005433874398	32630	Economy	19200.00
0005433874405	32630	Economy	17400.00
0005433874399	32630	Economy	17400.00
0005433874414	32630	Economy	17400.00
0005433874400	32630	Economy	17400.00
0005433874419	32630	Economy	17400.00
0005433869453	4760	Economy	19400.00
0005433869456	4760	Economy	19400.00
0005433869476	4760	Economy	19400.00
0005433869444	4760	Economy	19400.00
0005435860533	4760	Economy	17600.00
0005433869447	4760	Economy	17600.00
0005435860538	4760	Economy	17600.00
0005433869462	4760	Economy	17600.00
0005433869474	4760	Economy	17600.00
0005435860546	4760	Economy	17600.00
0005435860536	4760	Economy	17600.00
0005433869452	4760	Economy	17600.00
0005433869460	4760	Economy	17600.00
0005433869470	4760	Economy	17600.00
0005433869475	4760	Economy	17600.00
0005433869443	4760	Economy	17600.00
0005433869455	4760	Economy	17600.00
0005435860537	4760	Economy	17600.00
0005433869465	4760	Economy	17600.00
0005433869484	4760	Economy	17600.00
0005433869472	4760	Economy	17600.00
0005433869469	4760	Economy	17600.00
0005433869457	4760	Economy	17600.00
0005435860550	4760	Economy	17600.00
0005433869481	4760	Economy	17600.00
0005433869448	4760	Economy	17600.00
0005433869446	4760	Economy	17600.00
0005435860539	4760	Economy	17600.00
0005433869445	4760	Economy	17600.00
0005433869473	4760	Economy	17600.00
0005433869468	4760	Economy	17600.00
0005433869479	4760	Economy	17600.00
0005433869471	4760	Economy	17600.00
0005433869459	4760	Economy	17600.00
0005433869458	4760	Economy	17600.00
0005433869482	4760	Economy	17600.00
0005435860549	4760	Economy	17600.00
0005433869466	4760	Economy	17600.00
0005433869483	4760	Economy	17600.00
0005433869478	4760	Economy	17600.00
0005433869467	4760	Economy	17600.00
0005433869454	4760	Economy	17600.00
0005433869463	4760	Economy	17600.00
0005433869450	4760	Economy	17600.00
0005433869449	4760	Economy	17600.00
0005433869451	4760	Economy	17600.00
0005433869480	4760	Economy	17600.00
0005433869461	4760	Economy	17600.00
0005433869464	4760	Economy	17600.00
0005433869477	4760	Economy	17600.00
0005433869177	32584	Economy	19400.00
0005433869010	32584	Economy	19400.00
0005433869090	32584	Economy	19400.00
0005433869004	32584	Economy	19400.00
0005433868995	32584	Economy	17600.00
0005433869108	32584	Economy	17600.00
0005433868886	32584	Economy	17600.00
0005433869178	32584	Economy	17600.00
0005433868965	32584	Economy	17600.00
0005433868884	32584	Economy	17600.00
0005433868967	32584	Economy	17600.00
0005433869347	32584	Economy	17600.00
0005433869278	32584	Economy	17600.00
0005433869042	32584	Economy	17600.00
0005433869066	32584	Economy	17600.00
0005433868963	32584	Economy	17600.00
0005433868885	32584	Economy	17600.00
0005433869129	32584	Economy	17600.00
0005433869002	32584	Economy	17600.00
0005433868863	32584	Economy	17600.00
0005435860598	32584	Economy	17600.00
0005433869070	32584	Economy	17600.00
0005433869006	32584	Economy	17600.00
0005435860597	32584	Economy	17600.00
0005435860595	32584	Economy	17600.00
0005433868994	32584	Economy	17600.00
0005435860594	32584	Economy	17600.00
0005433869277	32584	Economy	17600.00
0005433869123	32584	Economy	17600.00
0005433868864	32584	Economy	17600.00
0005433869086	32584	Economy	17600.00
0005433869111	32584	Economy	17600.00
0005433869011	32584	Economy	17600.00
0005433869049	32584	Economy	17600.00
0005433869050	32584	Economy	17600.00
0005435860596	32584	Economy	17600.00
0005433869094	32584	Economy	17600.00
0005433868964	32584	Economy	17600.00
0005433869143	32584	Economy	17600.00
0005433869089	32584	Economy	17600.00
0005433869159	32584	Economy	17600.00
0005433869142	32584	Economy	17600.00
0005433869055	32584	Economy	17600.00
0005433869067	32584	Economy	17600.00
0005433868962	32584	Economy	17600.00
0005433869095	32584	Economy	17600.00
0005433869206	32584	Economy	17600.00
0005433869085	32584	Economy	17600.00
0005433868865	32584	Economy	17600.00
0005434460562	3422	Economy	24800.00
0005435911613	3422	Economy	22600.00
0005435911612	3422	Economy	22600.00
0005434663761	3422	Economy	22600.00
0005434663751	3422	Economy	22600.00
0005434461703	3422	Economy	22600.00
0005434461702	3422	Economy	22600.00
0005434460560	3422	Economy	22600.00
0005435911549	3422	Economy	22600.00
0005435911573	3422	Economy	22600.00
0005435911607	3422	Economy	22600.00
0005434460561	3422	Economy	22600.00
0005435911566	3422	Economy	22600.00
0005434663762	3422	Economy	22600.00
0005435911582	3422	Economy	22600.00
0005434663757	3422	Economy	22600.00
0005434663759	3422	Economy	22600.00
0005435911550	3422	Economy	22600.00
0005435911580	3422	Economy	22600.00
0005435911593	3422	Economy	22600.00
0005434663756	3422	Economy	22600.00
0005435911581	3422	Economy	22600.00
0005434663752	3422	Economy	22600.00
0005435911558	3422	Economy	22600.00
0005434663754	3422	Economy	22600.00
0005434663758	3422	Economy	22600.00
0005434663753	3422	Economy	22600.00
0005434663755	3422	Economy	22600.00
0005434663760	3422	Economy	22600.00
0005434663639	12491	Economy	24800.00
0005434460532	12491	Economy	24800.00
0005434663681	12491	Economy	22600.00
0005435911648	12491	Economy	22600.00
0005434663666	12491	Economy	22600.00
0005434663629	12491	Economy	22600.00
0005435911647	12491	Economy	22600.00
0005434663660	12491	Economy	22600.00
0005434460538	12491	Economy	22600.00
0005434663653	12491	Economy	22600.00
0005434460531	12491	Economy	22600.00
0005435911646	12491	Economy	22600.00
0005434460545	12491	Economy	22600.00
0005434663628	12491	Economy	22600.00
0005434663652	12491	Economy	22600.00
0005434663659	12491	Economy	22600.00
0005435911645	12491	Economy	22600.00
0005434663601	12491	Economy	22600.00
0005434663600	12491	Economy	22600.00
0005434663616	12491	Economy	22600.00
0005434460534	12491	Economy	22600.00
0005434460539	12491	Economy	22600.00
0005434663631	12491	Economy	22600.00
0005434663630	12491	Economy	22600.00
0005434460546	12491	Economy	22600.00
0005433869067	14495	Economy	18500.00
0005433869055	14495	Economy	18500.00
0005435860595	14495	Economy	18500.00
0005433868963	14495	Economy	18500.00
0005433869177	14495	Economy	16800.00
0005433869002	14495	Economy	16800.00
0005433868965	14495	Economy	16800.00
0005433868994	14495	Economy	16800.00
0005433869050	14495	Economy	16800.00
0005433869086	14495	Economy	16800.00
0005433869347	14495	Economy	16800.00
0005433869066	14495	Economy	16800.00
0005433869129	14495	Economy	16800.00
0005433869042	14495	Economy	16800.00
0005433869278	14495	Economy	16800.00
0005433869142	14495	Economy	16800.00
0005433868962	14495	Economy	16800.00
0005433868884	14495	Economy	16800.00
0005433869004	14495	Economy	16800.00
0005435860596	14495	Economy	16800.00
0005433869143	14495	Economy	16800.00
0005433868863	14495	Economy	16800.00
0005435860597	14495	Economy	16800.00
0005433868995	14495	Economy	16800.00
0005433869090	14495	Economy	16800.00
0005433869049	14495	Economy	16800.00
0005433869095	14495	Economy	16800.00
0005433868885	14495	Economy	16800.00
0005433868886	14495	Economy	16800.00
0005433869010	14495	Economy	16800.00
0005433868865	14495	Economy	16800.00
0005433869070	14495	Economy	16800.00
0005433869277	14495	Economy	16800.00
0005435860594	14495	Economy	16800.00
0005433869108	14495	Economy	16800.00
0005433869011	14495	Economy	16800.00
0005433869085	14495	Economy	16800.00
0005433869094	14495	Economy	16800.00
0005433869206	14495	Economy	16800.00
0005433869123	14495	Economy	16800.00
0005433869178	14495	Economy	16800.00
0005433869111	14495	Economy	16800.00
0005433869006	14495	Economy	16800.00
0005433868964	14495	Economy	16800.00
0005435860598	14495	Economy	16800.00
0005433868967	14495	Economy	16800.00
0005433869159	14495	Economy	16800.00
0005433868864	14495	Economy	16800.00
0005433869089	14495	Economy	16800.00
0005433869433	32659	Economy	18500.00
0005433869423	32659	Economy	18500.00
0005435860534	32659	Economy	18500.00
0005433869439	32659	Economy	18500.00
0005433869411	32659	Economy	16800.00
0005433869438	32659	Economy	16800.00
0005435860520	32659	Economy	16800.00
0005435860535	32659	Economy	16800.00
0005433869408	32659	Economy	16800.00
0005433869442	32659	Economy	16800.00
0005433869413	32659	Economy	16800.00
0005433869406	32659	Economy	16800.00
0005433869410	32659	Economy	16800.00
0005433869407	32659	Economy	16800.00
0005433869424	32659	Economy	16800.00
0005433869417	32659	Economy	16800.00
0005433869412	32659	Economy	16800.00
0005433869421	32659	Economy	16800.00
0005433869428	32659	Economy	16800.00
0005433869418	32659	Economy	16800.00
0005433869437	32659	Economy	16800.00
0005433869427	32659	Economy	16800.00
0005433869431	32659	Economy	16800.00
0005433869432	32659	Economy	16800.00
0005433869414	32659	Economy	16800.00
0005433869440	32659	Economy	16800.00
0005433869425	32659	Economy	16800.00
0005433869436	32659	Economy	16800.00
0005433869435	32659	Economy	16800.00
0005433869441	32659	Economy	16800.00
0005433869419	32659	Economy	16800.00
0005433869434	32659	Economy	16800.00
0005435860518	32659	Economy	16800.00
0005433869405	32659	Economy	16800.00
0005433869420	32659	Economy	16800.00
0005433869426	32659	Economy	16800.00
0005433869416	32659	Economy	16800.00
0005435860524	32659	Economy	16800.00
0005433869430	32659	Economy	16800.00
0005433869409	32659	Economy	16800.00
0005433869422	32659	Economy	16800.00
0005433869429	32659	Economy	16800.00
0005433869415	32659	Economy	16800.00
0005432799828	12111	Economy	4900.00
0005432799988	12111	Economy	4900.00
0005432799897	12111	Economy	4400.00
0005432799929	12111	Economy	4400.00
0005432799798	12111	Economy	4400.00
0005432799830	12111	Economy	4400.00
0005432800031	12111	Economy	4400.00
0005432799898	12111	Economy	4400.00
0005432799920	12111	Economy	4400.00
0005432799931	12111	Economy	4400.00
0005432799921	12111	Economy	4400.00
0005432799893	12111	Economy	4400.00
0005432800163	12111	Economy	4400.00
0005432799960	12111	Economy	4400.00
0005432799917	12111	Economy	4400.00
0005432799993	12111	Economy	4400.00
0005432799827	12111	Economy	4400.00
0005432799950	12111	Economy	4400.00
0005432799959	12111	Economy	4400.00
0005432799934	12111	Economy	4400.00
0005432799918	12111	Economy	4400.00
0005432799877	12111	Economy	4400.00
0005432799951	12111	Economy	4400.00
0005432799928	12111	Economy	4400.00
0005432799864	12111	Economy	4400.00
0005432799923	12111	Economy	4400.00
0005432799926	12111	Economy	4400.00
0005432799831	12111	Economy	4400.00
0005432799892	12111	Economy	4400.00
0005432799891	12111	Economy	4400.00
0005432799989	12111	Economy	4400.00
0005432799930	12111	Economy	4400.00
0005432799919	12111	Economy	4400.00
0005432800154	14829	Economy	4900.00
0005432800157	14829	Economy	4900.00
0005432800141	14829	Economy	4400.00
0005432800156	14829	Economy	4400.00
0005432800159	14829	Economy	4400.00
0005432800163	14829	Economy	4400.00
0005432800142	14829	Economy	4400.00
0005432800164	14829	Economy	4400.00
0005432800144	14829	Economy	4400.00
0005432800158	14829	Economy	4400.00
0005432800152	14829	Economy	4400.00
0005432800155	14829	Economy	4400.00
0005432800153	14829	Economy	4400.00
0005432800139	14829	Economy	4400.00
0005432800145	14829	Economy	4400.00
0005432800140	14829	Economy	4400.00
0005432800165	14829	Economy	4400.00
0005432800162	14829	Economy	4400.00
0005432800160	14829	Economy	4400.00
0005432800149	14829	Economy	4400.00
0005432800148	14829	Economy	4400.00
0005432800150	14829	Economy	4400.00
0005432800147	14829	Economy	4400.00
0005432800161	14829	Economy	4400.00
0005432800166	14829	Economy	4400.00
0005432800146	14829	Economy	4400.00
0005432800138	14829	Economy	4400.00
0005432800151	14829	Economy	4400.00
0005432800143	14829	Economy	4400.00
0005435293448	7047	Business	49100.00
0005434409349	7047	Business	49100.00
0005435311213	7047	Business	49100.00
0005435311258	7047	Business	49100.00
0005432154122	7047	Business	49100.00
0005434409391	7047	Business	49100.00
0005432154120	7047	Business	49100.00
0005434300156	7047	Economy	16400.00
0005434409379	7047	Economy	16400.00
0005434409359	7047	Economy	16400.00
0005432154119	7047	Economy	16400.00
0005434409374	7047	Economy	16400.00
0005434409346	7047	Economy	16400.00
0005434300145	7047	Economy	16400.00
0005434409351	7047	Economy	16400.00
0005434409353	7047	Economy	16400.00
0005432154115	7047	Economy	16400.00
0005434300149	7047	Economy	16400.00
0005432154121	7047	Economy	16400.00
0005434300144	7047	Economy	16400.00
0005434409386	7047	Economy	16400.00
0005432154118	7047	Economy	16400.00
0005434409393	7047	Economy	16400.00
0005434409350	7047	Economy	16400.00
0005434300143	7047	Economy	16400.00
0005434409403	7047	Economy	16400.00
0005434409381	7047	Economy	16400.00
0005434409396	7047	Economy	16400.00
0005434409373	7047	Economy	16400.00
0005435311271	7047	Economy	16400.00
0005435293474	7047	Economy	16400.00
0005435293494	7047	Economy	16400.00
0005435293482	7047	Economy	16400.00
0005434409385	7047	Economy	16400.00
0005435293454	7047	Economy	16400.00
0005434409344	7047	Economy	16400.00
0005434300151	7047	Economy	16400.00
0005434409357	7047	Economy	16400.00
0005434409394	7047	Economy	16400.00
0005434300152	7047	Economy	16400.00
0005435311257	7047	Economy	16400.00
0005434409369	7047	Economy	16400.00
0005434409361	7047	Economy	16400.00
0005434409384	7047	Economy	16400.00
0005435293481	7047	Economy	16400.00
0005434409388	7047	Economy	16400.00
0005434409345	7047	Economy	18000.00
0005434409368	7047	Economy	18000.00
0005434300148	7047	Economy	18000.00
0005434409399	7047	Economy	18000.00
0005434409366	7047	Economy	18000.00
0005435311245	7047	Economy	18000.00
0005434409343	7047	Economy	16400.00
0005435311259	7047	Economy	16400.00
0005435311242	7047	Economy	16400.00
0005434300146	7047	Economy	16400.00
0005434409389	7047	Economy	16400.00
0005435293488	7047	Economy	16400.00
0005434409347	7047	Economy	16400.00
0005434409363	7047	Economy	16400.00
0005434409402	7047	Economy	16400.00
0005434409372	7047	Economy	16400.00
0005434409348	7047	Economy	16400.00
0005434409376	7047	Economy	16400.00
0005434409365	7047	Economy	16400.00
0005435311201	7047	Economy	16400.00
0005434409383	7047	Economy	16400.00
0005434409362	7047	Economy	16400.00
0005432108316	7047	Economy	16400.00
0005434409356	7047	Economy	16400.00
0005434409400	7047	Economy	16400.00
0005435311200	7047	Economy	16400.00
0005435293470	7047	Economy	16400.00
0005434409358	7047	Economy	16400.00
0005435293493	7047	Economy	16400.00
0005434300155	7047	Economy	16400.00
0005434409354	7047	Economy	16400.00
0005432108315	7047	Economy	16400.00
0005434409367	7047	Economy	16400.00
0005435311238	7047	Economy	16400.00
0005435293464	7047	Economy	16400.00
0005434409401	7047	Economy	16400.00
0005434409382	7047	Economy	16400.00
0005435311289	7047	Economy	16400.00
0005435311239	7047	Economy	16400.00
0005434409360	7047	Economy	16400.00
0005432108317	7047	Economy	16400.00
0005434409392	7047	Economy	16400.00
0005434300147	7047	Economy	16400.00
0005434409387	7047	Economy	16400.00
0005434409352	7047	Economy	16400.00
0005434409397	7047	Economy	16400.00
0005434409375	7047	Economy	16400.00
0005432154117	7047	Economy	16400.00
0005434409355	7047	Economy	16400.00
0005434409398	7047	Economy	16400.00
0005435293463	7047	Economy	16400.00
0005434300154	7047	Economy	16400.00
0005435293393	7047	Economy	16400.00
0005434409364	7047	Economy	16400.00
0005435311221	7047	Economy	16400.00
0005435311237	7047	Economy	16400.00
0005434409404	7047	Economy	16400.00
0005434300153	7047	Economy	16400.00
0005434409378	7047	Economy	16400.00
0005434409377	7047	Economy	16400.00
0005434409371	7047	Economy	16400.00
0005434409370	7047	Economy	16400.00
0005435293489	7047	Economy	16400.00
0005434300150	7047	Economy	16400.00
0005434409395	7047	Economy	16400.00
0005434409390	7047	Economy	16400.00
0005434300157	7047	Economy	16400.00
0005434409380	7047	Economy	16400.00
0005435293432	7047	Economy	16400.00
0005432154116	7047	Economy	16400.00
0005435311438	26897	Business	49100.00
0005434408828	26897	Business	49100.00
0005435293571	26897	Business	49100.00
0005434408694	26897	Business	49100.00
0005434300003	26897	Business	49100.00
0005434300009	26897	Business	49100.00
0005434299995	26897	Business	49100.00
0005435311436	26897	Business	49100.00
0005434408647	26897	Business	49100.00
0005435293579	26897	Business	49100.00
0005435293572	26897	Business	49100.00
0005435311440	26897	Business	49100.00
0005434408857	26897	Economy	16400.00
0005434408961	26897	Economy	16400.00
0005434300007	26897	Economy	16400.00
0005434300002	26897	Economy	16400.00
0005435293580	26897	Economy	16400.00
0005434408976	26897	Economy	16400.00
0005434299889	26897	Economy	16400.00
0005434299964	26897	Economy	16400.00
0005434409004	26897	Economy	16400.00
0005434408717	26897	Economy	16400.00
0005435311431	26897	Economy	16400.00
0005435311432	26897	Economy	16400.00
0005434299994	26897	Economy	16400.00
0005434408746	26897	Economy	16400.00
0005432058480	26897	Economy	16400.00
0005435311443	26897	Economy	16400.00
0005434299917	26897	Economy	16400.00
0005434408977	26897	Economy	16400.00
0005434300057	26897	Economy	16400.00
0005434408718	26897	Economy	16400.00
0005435293574	26897	Economy	16400.00
0005434408774	26897	Economy	16400.00
0005434300004	26897	Economy	16400.00
0005434408477	26897	Economy	16400.00
0005434408555	26897	Economy	16400.00
0005434408720	26897	Economy	16400.00
0005434408801	26897	Economy	16400.00
0005434408771	26897	Economy	16400.00
0005434408898	26897	Economy	16400.00
0005435311442	26897	Economy	16400.00
0005432058479	26897	Economy	16400.00
0005434408708	26897	Economy	16400.00
0005434408672	26897	Economy	16400.00
0005432058481	26897	Economy	16400.00
0005434299950	26897	Economy	16400.00
0005434300072	26897	Economy	16400.00
0005434408712	26897	Economy	16400.00
0005434299898	26897	Economy	16400.00
0005434408826	26897	Economy	16400.00
0005434299941	26897	Economy	16400.00
0005434408854	26897	Economy	18000.00
0005434408664	26897	Economy	18000.00
0005435293576	26897	Economy	18000.00
0005435293568	26897	Economy	18000.00
0005434408960	26897	Economy	18000.00
0005434408707	26897	Economy	18000.00
0005434408716	26897	Economy	16400.00
0005434408613	26897	Economy	16400.00
0005434408935	26897	Economy	16400.00
0005434408662	26897	Economy	16400.00
0005434408827	26897	Economy	16400.00
0005434299993	26897	Economy	16400.00
0005434408566	26897	Economy	16400.00
0005435311437	26897	Economy	16400.00
0005434408715	26897	Economy	16400.00
0005434408721	26897	Economy	16400.00
0005435293569	26897	Economy	16400.00
0005434408836	26897	Economy	16400.00
0005434408653	26897	Economy	16400.00
0005434408775	26897	Economy	16400.00
0005434408582	26897	Economy	16400.00
0005434408769	26897	Economy	16400.00
0005434300060	26897	Economy	16400.00
0005434408907	26897	Economy	16400.00
0005434300074	26897	Economy	16400.00
0005434299970	26897	Economy	16400.00
0005434408725	26897	Economy	16400.00
0005435311433	26897	Economy	16400.00
0005434408699	26897	Economy	16400.00
0005434408866	26897	Economy	16400.00
0005434299918	26897	Economy	16400.00
0005435293578	26897	Economy	16400.00
0005434299965	26897	Economy	16400.00
0005434408809	26897	Economy	16400.00
0005434299976	26897	Economy	16400.00
0005434408855	26897	Economy	16400.00
0005435311441	26897	Economy	16400.00
0005434299890	26897	Economy	16400.00
0005435293575	26897	Economy	16400.00
0005434408696	26897	Economy	16400.00
0005434408937	26897	Economy	16400.00
0005432058478	26897	Economy	16400.00
0005434408755	26897	Economy	16400.00
0005435293573	26897	Economy	16400.00
0005434408765	26897	Economy	16400.00
0005434408964	26897	Economy	16400.00
0005435311439	26897	Economy	16400.00
0005434300030	26897	Economy	16400.00
0005434408537	26897	Economy	16400.00
0005434408663	26897	Economy	16400.00
0005434408762	26897	Economy	16400.00
0005434408874	26897	Economy	16400.00
0005435311434	26897	Economy	16400.00
0005434408614	26897	Economy	16400.00
0005434408773	26897	Economy	16400.00
0005434408790	26897	Economy	16400.00
0005434409005	26897	Economy	16400.00
0005434408711	26897	Economy	16400.00
0005435311435	26897	Economy	16400.00
0005435293577	26897	Economy	16400.00
0005435293570	26897	Economy	16400.00
0005434408789	26897	Economy	16400.00
0005434408722	26897	Economy	16400.00
0005434408811	26897	Economy	16400.00
0005434408858	26897	Economy	16400.00
0005434408825	26897	Economy	16400.00
0005434408697	26897	Economy	16400.00
0005434408660	26897	Economy	16400.00
0005434408962	26897	Economy	16400.00
0005434408776	26897	Economy	16400.00
0005434408975	26897	Economy	16400.00
0005435311444	26897	Economy	16400.00
0005434408873	26897	Economy	16400.00
0005434408583	26897	Economy	16400.00
0005434299940	26897	Economy	16400.00
0005434408936	26897	Economy	16400.00
0005434408867	26897	Economy	16400.00
0005434408756	26897	Economy	16400.00
0005432605372	6473	Economy	16500.00
0005432605345	6473	Economy	16500.00
0005432605342	6473	Economy	16500.00
0005435220494	6473	Economy	16500.00
0005432605354	6473	Economy	15000.00
0005432605357	6473	Economy	15000.00
0005432605358	6473	Economy	15000.00
0005432605370	6473	Economy	15000.00
0005432605367	6473	Economy	15000.00
0005432605364	6473	Economy	15000.00
0005432605344	6473	Economy	15000.00
0005432605371	6473	Economy	15000.00
0005434512231	6473	Economy	15000.00
0005435312897	6473	Economy	15000.00
0005432605346	6473	Economy	15000.00
0005435220496	6473	Economy	15000.00
0005432605373	6473	Economy	15000.00
0005432605348	6473	Economy	15000.00
0005432605359	6473	Economy	15000.00
0005432605356	6473	Economy	15000.00
0005434512233	6473	Economy	15000.00
0005432605365	6473	Economy	15000.00
0005432605363	6473	Economy	15000.00
0005432605351	6473	Economy	15000.00
0005432605353	6473	Economy	15000.00
0005432605352	6473	Economy	15000.00
0005432605350	6473	Economy	15000.00
0005432605355	6473	Economy	15000.00
0005432605362	6473	Economy	15000.00
0005432605368	6473	Economy	15000.00
0005435220493	6473	Economy	15000.00
0005435220502	6473	Economy	15000.00
0005432605343	6473	Economy	15000.00
0005432605349	6473	Economy	15000.00
0005432605369	6473	Economy	15000.00
0005432605361	6473	Economy	15000.00
0005435220501	6473	Economy	15000.00
0005432605347	6473	Economy	15000.00
0005434512232	6473	Economy	15000.00
0005432605366	6473	Economy	15000.00
0005432605360	6473	Economy	15000.00
0005434512208	21351	Economy	16500.00
0005432604883	21351	Economy	16500.00
0005432605027	21351	Economy	16500.00
0005432604976	21351	Economy	16500.00
0005432604987	21351	Economy	15000.00
0005432605040	21351	Economy	15000.00
0005432604990	21351	Economy	15000.00
0005432604967	21351	Economy	15000.00
0005432604901	21351	Economy	15000.00
0005432605133	21351	Economy	15000.00
0005432605004	21351	Economy	15000.00
0005432604862	21351	Economy	15000.00
0005432604979	21351	Economy	15000.00
0005432604900	21351	Economy	15000.00
0005432605242	21351	Economy	15000.00
0005432605024	21351	Economy	15000.00
0005432604982	21351	Economy	15000.00
0005432604917	21351	Economy	15000.00
0005432605058	21351	Economy	15000.00
0005432605011	21351	Economy	15000.00
0005434512209	21351	Economy	15000.00
0005435221080	21351	Economy	15000.00
0005432605050	21351	Economy	15000.00
0005432604892	21351	Economy	15000.00
0005432604880	21351	Economy	15000.00
0005432605069	21351	Economy	15000.00
0005432604989	21351	Economy	15000.00
0005432604863	21351	Economy	15000.00
0005432605049	21351	Economy	15000.00
0005432604981	21351	Economy	15000.00
0005432605073	21351	Economy	15000.00
0005432604991	21351	Economy	15000.00
0005432604988	21351	Economy	15000.00
0005432604916	21351	Economy	15000.00
0005435221532	21351	Economy	15000.00
0005435221553	21351	Economy	15000.00
0005432604998	21351	Economy	15000.00
0005432604853	21351	Economy	15000.00
0005432605010	21351	Economy	15000.00
0005432605243	21351	Economy	15000.00
0005432604933	21351	Economy	15000.00
0005432604958	21351	Economy	15000.00
0005432605057	21351	Economy	15000.00
0005432605051	21351	Economy	15000.00
0005432604879	21351	Economy	15000.00
0005432604986	21351	Economy	15000.00
0005434512185	21351	Economy	15000.00
0005432604944	21351	Economy	15000.00
0005432605023	21351	Economy	15000.00
0005432605026	21351	Economy	15000.00
0005434908079	15016	Business	18900.00
0005434907967	15016	Business	18900.00
0005433252281	15016	Business	18900.00
0005434908152	15016	Business	18900.00
0005434908055	15016	Business	18900.00
0005433252257	15016	Business	18900.00
0005434908165	15016	Business	18900.00
0005433252266	15016	Business	18900.00
0005434908253	15016	Business	18900.00
0005434908031	15016	Business	18900.00
0005434907997	15016	Economy	6300.00
0005434908129	15016	Economy	6300.00
0005434907994	15016	Economy	6300.00
0005433252265	15016	Economy	6300.00
0005433252268	15016	Economy	6300.00
0005434908156	15016	Economy	6300.00
0005434908135	15016	Economy	6300.00
0005434908012	15016	Economy	6300.00
0005433252279	15016	Economy	6900.00
0005434908029	15016	Economy	6900.00
0005434907966	15016	Economy	6900.00
0005434908172	15016	Economy	6900.00
0005433252273	15016	Economy	6300.00
0005433252256	15016	Economy	6300.00
0005434908255	15016	Economy	6300.00
0005434908100	15016	Economy	6300.00
0005434907969	15016	Economy	6300.00
0005434908166	15016	Economy	6300.00
0005433252275	15016	Economy	6300.00
0005434908200	15016	Economy	6300.00
0005434908142	15016	Economy	6300.00
0005434908038	15016	Economy	6300.00
0005434908179	15016	Economy	6300.00
0005434908005	15016	Economy	6300.00
0005434908149	15016	Economy	6300.00
0005433252264	15016	Economy	6300.00
0005433252277	15016	Economy	6300.00
0005434908077	15016	Economy	6300.00
0005434907949	15016	Economy	6300.00
0005433252254	15016	Economy	6300.00
0005434908130	15016	Economy	6300.00
0005434908030	15016	Economy	6300.00
0005434908252	15016	Economy	6300.00
0005433252270	15016	Economy	6300.00
0005434908011	15016	Economy	6300.00
0005433252267	15016	Economy	6300.00
0005434908112	15016	Economy	6300.00
0005433252262	15016	Economy	6300.00
0005434907797	15016	Economy	6300.00
0005433252282	15016	Economy	6300.00
0005434908111	15016	Economy	6300.00
0005434908209	15016	Economy	6300.00
0005433252261	15016	Economy	6300.00
0005434908131	15016	Economy	6300.00
0005434908050	15016	Economy	6300.00
0005434908006	15016	Economy	6300.00
0005433252283	15016	Economy	6300.00
0005433252258	15016	Economy	6300.00
0005433252260	15016	Economy	6300.00
0005434908056	15016	Economy	6300.00
0005434908076	15016	Economy	6300.00
0005434908259	15016	Economy	6300.00
0005434908098	15016	Economy	6300.00
0005433252276	15016	Economy	6300.00
0005433252272	15016	Economy	6300.00
0005433252255	15016	Economy	6300.00
0005434908097	15016	Economy	6300.00
0005434908083	15016	Economy	6300.00
0005433252263	15016	Economy	6300.00
0005433252280	15016	Economy	6300.00
0005434908141	15016	Economy	6300.00
0005434908073	15016	Economy	6300.00
0005433252271	15016	Economy	6300.00
0005434908254	15016	Economy	6300.00
0005434908148	15016	Economy	6300.00
0005434908256	15016	Economy	6300.00
0005433252278	15016	Economy	6300.00
0005434908219	15016	Economy	6300.00
0005434907996	15016	Economy	6300.00
0005434907995	15016	Economy	6300.00
0005434907832	15016	Economy	6300.00
0005434908066	15016	Economy	6300.00
0005434908258	15016	Economy	6300.00
0005433252259	15016	Economy	6300.00
0005433252274	15016	Economy	6300.00
0005433252269	15016	Economy	6300.00
0005434908568	25827	Business	18900.00
0005434908563	25827	Business	18900.00
0005434908567	25827	Business	18900.00
0005434908560	25827	Business	18900.00
0005433252056	25827	Business	18900.00
0005434908576	25827	Business	18900.00
0005434908599	25827	Business	18900.00
0005433252006	25827	Business	18900.00
0005434908552	25827	Business	18900.00
0005433251963	25827	Business	18900.00
0005434908594	25827	Business	18900.00
0005434908553	25827	Business	18900.00
0005433251941	25827	Economy	6300.00
0005434908600	25827	Economy	6300.00
0005433252049	25827	Economy	6300.00
0005434908612	25827	Economy	6300.00
0005434908605	25827	Economy	6300.00
0005434908596	25827	Economy	6300.00
0005434908603	25827	Economy	6300.00
0005433251920	25827	Economy	6300.00
0005434908555	25827	Economy	6300.00
0005433252028	25827	Economy	6300.00
0005433252011	25827	Economy	6900.00
0005434908580	25827	Economy	6900.00
0005434908565	25827	Economy	6900.00
0005433252050	25827	Economy	6900.00
0005434908591	25827	Economy	6900.00
0005434908592	25827	Economy	6300.00
0005433251964	25827	Economy	6300.00
0005434908597	25827	Economy	6300.00
0005434908593	25827	Economy	6300.00
0005434908609	25827	Economy	6300.00
0005433251942	25827	Economy	6300.00
0005433251987	25827	Economy	6300.00
0005433251945	25827	Economy	6300.00
0005434908586	25827	Economy	6300.00
0005434908583	25827	Economy	6300.00
0005434908571	25827	Economy	6300.00
0005433252087	25827	Economy	6300.00
0005433251904	25827	Economy	6300.00
0005433252047	25827	Economy	6300.00
0005434908575	25827	Economy	6300.00
0005433251940	25827	Economy	6300.00
0005434908551	25827	Economy	6300.00
0005433252052	25827	Economy	6300.00
0005433252081	25827	Economy	6300.00
0005434908570	25827	Economy	6300.00
0005434908566	25827	Economy	6300.00
0005434908564	25827	Economy	6300.00
0005434908558	25827	Economy	6300.00
0005433252043	25827	Economy	6300.00
0005434908611	25827	Economy	6300.00
0005434908574	25827	Economy	6300.00
0005434908588	25827	Economy	6300.00
0005433252034	25827	Economy	6300.00
0005434908569	25827	Economy	6300.00
0005434908589	25827	Economy	6300.00
0005434908584	25827	Economy	6300.00
0005433252048	25827	Economy	6300.00
0005433252057	25827	Economy	6300.00
0005434908604	25827	Economy	6300.00
0005434908585	25827	Economy	6300.00
0005433252082	25827	Economy	6300.00
0005434908601	25827	Economy	6300.00
0005433251903	25827	Economy	6300.00
0005433252132	25827	Economy	6300.00
0005433252046	25827	Economy	6300.00
0005433251886	25827	Economy	6300.00
0005434908559	25827	Economy	6300.00
0005434908587	25827	Economy	6300.00
0005434908598	25827	Economy	6300.00
0005434908607	25827	Economy	6300.00
0005434908590	25827	Economy	6300.00
0005434908579	25827	Economy	6300.00
0005433252007	25827	Economy	6300.00
0005434908573	25827	Economy	6300.00
0005433251919	25827	Economy	6300.00
0005434908577	25827	Economy	6300.00
0005433252051	25827	Economy	6300.00
0005433252088	25827	Economy	6300.00
0005434908582	25827	Economy	6300.00
0005434908610	25827	Economy	6300.00
0005434908578	25827	Economy	6300.00
0005434908608	25827	Economy	6300.00
0005434908554	25827	Economy	6300.00
0005434908562	25827	Economy	6300.00
0005434908602	25827	Economy	6300.00
0005433252055	25827	Economy	6300.00
0005434908581	25827	Economy	6300.00
0005434908561	25827	Economy	6300.00
0005434908556	25827	Economy	6300.00
0005434908606	25827	Economy	6300.00
0005434908595	25827	Economy	6300.00
0005433252097	25827	Economy	6300.00
0005434908557	25827	Economy	6300.00
0005433252044	25827	Economy	6300.00
0005434908572	25827	Economy	6300.00
0005432607653	22483	Economy	16400.00
0005432607663	22483	Economy	16400.00
0005432609830	22483	Economy	16400.00
0005432607655	22483	Economy	14900.00
0005435842337	22483	Economy	14900.00
0005432609820	22483	Economy	14900.00
0005435841478	22483	Economy	14900.00
0005432609827	22483	Economy	14900.00
0005432607665	22483	Economy	14900.00
0005432607657	22483	Economy	14900.00
0005432607666	22483	Economy	14900.00
0005432607660	22483	Economy	14900.00
0005432609826	22483	Economy	14900.00
0005435842334	22483	Economy	14900.00
0005432609833	22483	Economy	14900.00
0005432609832	22483	Economy	14900.00
0005435841480	22483	Economy	14900.00
0005432609824	22483	Economy	14900.00
0005432609834	22483	Economy	14900.00
0005435841477	22483	Economy	14900.00
0005432607664	22483	Economy	14900.00
0005432607661	22483	Economy	14900.00
0005432609819	22483	Economy	14900.00
0005432607662	22483	Economy	14900.00
0005432609823	22483	Economy	14900.00
0005432609831	22483	Economy	14900.00
0005435841485	22483	Economy	14900.00
0005432607654	22483	Economy	14900.00
0005432609829	22483	Economy	14900.00
0005435842338	22483	Economy	14900.00
0005432609822	22483	Economy	14900.00
0005432609821	22483	Economy	14900.00
0005435842331	22483	Economy	14900.00
0005432609825	22483	Economy	14900.00
0005432607659	22483	Economy	14900.00
0005432607667	22483	Economy	14900.00
0005432607656	22483	Economy	14900.00
0005432607658	22483	Economy	14900.00
0005432609828	22483	Economy	14900.00
0005432609797	31732	Economy	16400.00
0005432613901	31732	Economy	16400.00
0005432609814	31732	Economy	16400.00
0005432613925	31732	Economy	16400.00
0005432613931	31732	Economy	14900.00
0005432609801	31732	Economy	14900.00
0005432613918	31732	Economy	14900.00
0005432609803	31732	Economy	14900.00
0005432613919	31732	Economy	14900.00
0005432613923	31732	Economy	14900.00
0005432613933	31732	Economy	14900.00
0005432613926	31732	Economy	14900.00
0005432609788	31732	Economy	14900.00
0005432613935	31732	Economy	14900.00
0005432609791	31732	Economy	14900.00
0005432613921	31732	Economy	14900.00
0005432613924	31732	Economy	14900.00
0005432609798	31732	Economy	14900.00
0005432609780	31732	Economy	14900.00
0005432609792	31732	Economy	14900.00
0005432609772	31732	Economy	14900.00
0005432613920	31732	Economy	14900.00
0005432613909	31732	Economy	14900.00
0005432609804	31732	Economy	14900.00
0005432613917	31732	Economy	14900.00
0005432609779	31732	Economy	14900.00
0005432609805	31732	Economy	14900.00
0005432613937	31732	Economy	14900.00
0005432609781	31732	Economy	14900.00
0005432609790	31732	Economy	14900.00
0005432609802	31732	Economy	14900.00
0005432609815	31732	Economy	14900.00
0005432613902	31732	Economy	14900.00
0005432613916	31732	Economy	14900.00
0005432613932	31732	Economy	14900.00
0005432609762	31732	Economy	14900.00
0005432613930	31732	Economy	14900.00
0005432609767	31732	Economy	14900.00
0005432613908	31732	Economy	14900.00
0005432613936	31732	Economy	14900.00
0005432609785	31732	Economy	14900.00
0005432613945	31732	Economy	14900.00
0005432613922	31732	Economy	14900.00
0005432609784	31732	Economy	14900.00
0005433009778	14163	Business	52300.00
0005433009814	14163	Business	52300.00
0005433009810	14163	Business	52300.00
0005433009775	14163	Business	52300.00
0005433009779	14163	Business	52300.00
0005433009807	14163	Business	52300.00
0005433009815	14163	Economy	17400.00
0005433009811	14163	Economy	17400.00
0005433009805	14163	Economy	17400.00
0005433810590	14163	Economy	17400.00
0005433009803	14163	Economy	19200.00
0005433009796	14163	Economy	19200.00
0005433009770	14163	Economy	17400.00
0005433009809	14163	Economy	17400.00
0005433009804	14163	Economy	17400.00
0005433009786	14163	Economy	17400.00
0005433009800	14163	Economy	17400.00
0005433009788	14163	Economy	17400.00
0005433009777	14163	Economy	17400.00
0005433009785	14163	Economy	17400.00
0005433009799	14163	Economy	17400.00
0005433009791	14163	Economy	17400.00
0005433009808	14163	Economy	17400.00
0005433810609	14163	Economy	17400.00
0005433009780	14163	Economy	17400.00
0005433009771	14163	Economy	17400.00
0005433009784	14163	Economy	17400.00
0005433009795	14163	Economy	17400.00
0005433009772	14163	Economy	17400.00
0005433009794	14163	Economy	17400.00
0005433009776	14163	Economy	17400.00
0005433009773	14163	Economy	17400.00
0005433009797	14163	Economy	17400.00
0005433009781	14163	Economy	17400.00
0005433009782	14163	Economy	17400.00
0005433810606	14163	Economy	17400.00
0005433009783	14163	Economy	17400.00
0005433009793	14163	Economy	17400.00
0005433009789	14163	Economy	17400.00
0005433009801	14163	Economy	17400.00
0005433009816	14163	Economy	17400.00
0005433009787	14163	Economy	17400.00
0005433009792	14163	Economy	17400.00
0005433009812	14163	Economy	17400.00
0005433009813	14163	Economy	17400.00
0005433009790	14163	Economy	17400.00
0005433009774	14163	Economy	17400.00
0005433009798	14163	Economy	17400.00
0005433009806	14163	Economy	17400.00
0005433009802	14163	Economy	17400.00
0005433009455	22863	Business	52300.00
0005433009350	22863	Business	52300.00
0005433810687	22863	Business	52300.00
0005433810678	22863	Business	52300.00
0005433009345	22863	Business	52300.00
0005433810688	22863	Business	52300.00
0005433009348	22863	Business	52300.00
0005433009360	22863	Business	52300.00
0005433009263	22863	Business	52300.00
0005433810681	22863	Economy	17400.00
0005433810682	22863	Economy	17400.00
0005433810696	22863	Economy	17400.00
0005433810685	22863	Economy	17400.00
0005433009443	22863	Economy	17400.00
0005433009407	22863	Economy	17400.00
0005433810686	22863	Economy	19200.00
0005433009317	22863	Economy	17400.00
0005433810692	22863	Economy	17400.00
0005433009433	22863	Economy	17400.00
0005433810683	22863	Economy	17400.00
0005433009353	22863	Economy	17400.00
0005433009454	22863	Economy	17400.00
0005433009409	22863	Economy	17400.00
0005433009403	22863	Economy	17400.00
0005433009359	22863	Economy	17400.00
0005433009556	22863	Economy	17400.00
0005433009501	22863	Economy	17400.00
0005433009418	22863	Economy	17400.00
0005433810695	22863	Economy	17400.00
0005433009280	22863	Economy	17400.00
0005433810693	22863	Economy	17400.00
0005433009288	22863	Economy	17400.00
0005433009347	22863	Economy	17400.00
0005433009279	22863	Economy	17400.00
0005433009510	22863	Economy	17400.00
0005433009474	22863	Economy	17400.00
0005433810690	22863	Economy	17400.00
0005433009311	22863	Economy	17400.00
0005433009206	22863	Economy	17400.00
0005433810689	22863	Economy	17400.00
0005433810684	22863	Economy	17400.00
0005433810679	22863	Economy	17400.00
0005433009195	22863	Economy	17400.00
0005433009205	22863	Economy	17400.00
0005433810694	22863	Economy	17400.00
0005433009408	22863	Economy	17400.00
0005433810699	22863	Economy	17400.00
0005433810698	22863	Economy	17400.00
0005433810697	22863	Economy	17400.00
0005433810691	22863	Economy	17400.00
0005433810680	22863	Economy	17400.00
0005433009444	22863	Economy	17400.00
0005433009473	22863	Economy	17400.00
0005433009316	22863	Economy	17400.00
0005433009193	22863	Economy	17400.00
0005433009248	22863	Economy	17400.00
0005433009349	22863	Economy	17400.00
0005433009346	22863	Economy	17400.00
0005433810700	22863	Economy	17400.00
0005433009310	22863	Economy	17400.00
0005433009315	22863	Economy	17400.00
0005433009135	22863	Economy	17400.00
0005434926307	14946	Business	22900.00
0005434926128	14946	Business	22900.00
0005434926129	14946	Business	22900.00
0005434926222	14946	Economy	7600.00
0005434926278	14946	Economy	7600.00
0005434926310	14946	Economy	8400.00
0005434926228	14946	Economy	8400.00
0005434926259	14946	Economy	7600.00
0005434926275	14946	Economy	7600.00
0005434926266	14946	Economy	7600.00
0005434926309	14946	Economy	7600.00
0005434926227	14946	Economy	7600.00
0005434926258	14946	Economy	7600.00
0005434926301	14946	Economy	7600.00
0005434926308	14946	Economy	7600.00
0005434926300	14946	Economy	7600.00
0005434926279	14946	Economy	7600.00
0005434926187	14946	Economy	7600.00
0005434926280	14946	Economy	7600.00
0005434926302	14946	Economy	7600.00
0005434926234	14946	Economy	7600.00
0005434926257	14946	Economy	7600.00
0005434926271	14946	Economy	7600.00
0005434926295	14946	Economy	7600.00
0005434926223	14946	Economy	7600.00
0005434926130	14946	Economy	7600.00
0005434926603	20521	Business	22900.00
0005434926606	20521	Business	22900.00
0005434926615	20521	Business	22900.00
0005434926617	20521	Business	22900.00
0005434926612	20521	Business	22900.00
0005434926594	20521	Economy	7600.00
0005434926621	20521	Economy	7600.00
0005434926618	20521	Economy	7600.00
0005434926602	20521	Economy	7600.00
0005434926597	20521	Economy	7600.00
0005434926599	20521	Economy	8400.00
0005434926600	20521	Economy	8400.00
0005434926620	20521	Economy	8400.00
0005434926609	20521	Economy	7600.00
0005434926624	20521	Economy	7600.00
0005434926595	20521	Economy	7600.00
0005434926598	20521	Economy	7600.00
0005434926591	20521	Economy	7600.00
0005434926589	20521	Economy	7600.00
0005434926622	20521	Economy	7600.00
0005434926611	20521	Economy	7600.00
0005434926607	20521	Economy	7600.00
0005434926596	20521	Economy	7600.00
0005434926625	20521	Economy	7600.00
0005434926608	20521	Economy	7600.00
0005434926601	20521	Economy	7600.00
0005434926592	20521	Economy	7600.00
0005434926616	20521	Economy	7600.00
0005434926613	20521	Economy	7600.00
0005434926605	20521	Economy	7600.00
0005434926610	20521	Economy	7600.00
0005434926604	20521	Economy	7600.00
0005434926619	20521	Economy	7600.00
0005434926614	20521	Economy	7600.00
0005434926593	20521	Economy	7600.00
0005434926623	20521	Economy	7600.00
0005434926590	20521	Economy	7600.00
0005435488401	15820	Economy	8900.00
0005435488397	15820	Economy	8900.00
0005435999547	15820	Economy	8900.00
0005435488400	15820	Economy	8900.00
0005435999556	15820	Economy	8100.00
0005435999508	15820	Economy	8100.00
0005435488386	15820	Economy	8100.00
0005435488396	15820	Economy	8100.00
0005435488392	15820	Economy	8100.00
0005435999523	15820	Economy	8100.00
0005435999430	15820	Economy	8100.00
0005435488387	15820	Economy	8100.00
0005435999538	15820	Economy	8100.00
0005435488391	15820	Economy	8100.00
0005435488388	15820	Economy	8100.00
0005435488389	15820	Economy	8100.00
0005435488398	15820	Economy	8100.00
0005435999542	15820	Economy	8100.00
0005435999515	15820	Economy	8100.00
0005435999429	15820	Economy	8100.00
0005435999563	15820	Economy	8100.00
0005435488390	15820	Economy	8100.00
0005435999570	15820	Economy	8100.00
0005435488402	15820	Economy	8100.00
0005435488384	15820	Economy	8100.00
0005435999544	15820	Economy	8100.00
0005435999516	15820	Economy	8100.00
0005435999537	15820	Economy	8100.00
0005435999564	15820	Economy	8100.00
0005435488395	15820	Economy	8100.00
0005435488403	15820	Economy	8100.00
0005435999509	15820	Economy	8100.00
0005435488393	15820	Economy	8100.00
0005435999568	15820	Economy	8100.00
0005435488399	15820	Economy	8100.00
0005435488394	15820	Economy	8100.00
0005435999428	15820	Economy	8100.00
0005435488385	15820	Economy	8100.00
0005435999541	15820	Economy	8100.00
0005435999514	15820	Economy	8100.00
0005435999545	15820	Economy	8100.00
0005435999512	15820	Economy	8100.00
0005435999558	15820	Economy	8100.00
0005435999546	15820	Economy	8100.00
0005435999567	15820	Economy	8100.00
0005435999513	15820	Economy	8100.00
0005435488202	19701	Economy	8900.00
0005435488219	19701	Economy	8900.00
0005435488129	19701	Economy	8900.00
0005435488125	19701	Economy	8900.00
0005435999715	19701	Economy	8100.00
0005435488154	19701	Economy	8100.00
0005435488260	19701	Economy	8100.00
0005435999712	19701	Economy	8100.00
0005435488155	19701	Economy	8100.00
0005435488103	19701	Economy	8100.00
0005435488124	19701	Economy	8100.00
0005435488118	19701	Economy	8100.00
0005435488058	19701	Economy	8100.00
0005435488122	19701	Economy	8100.00
0005435488231	19701	Economy	8100.00
0005435999706	19701	Economy	8100.00
0005435488130	19701	Economy	8100.00
0005435488177	19701	Economy	8100.00
0005435999702	19701	Economy	8100.00
0005435999707	19701	Economy	8100.00
0005435999711	19701	Economy	8100.00
0005435488078	19701	Economy	8100.00
0005435999713	19701	Economy	8100.00
0005435488123	19701	Economy	8100.00
0005435999710	19701	Economy	8100.00
0005435999701	19701	Economy	8100.00
0005435488117	19701	Economy	8100.00
0005435488104	19701	Economy	8100.00
0005435488187	19701	Economy	8100.00
0005435488077	19701	Economy	8100.00
0005435488057	19701	Economy	8100.00
0005435999709	19701	Economy	8100.00
0005435999699	19701	Economy	8100.00
0005435488170	19701	Economy	8100.00
0005435999705	19701	Economy	8100.00
0005435999703	19701	Economy	8100.00
0005435488229	19701	Economy	8100.00
0005435999698	19701	Economy	8100.00
0005435999704	19701	Economy	8100.00
0005435999714	19701	Economy	8100.00
0005435999708	19701	Economy	8100.00
0005435488082	19701	Economy	8100.00
0005435999700	19701	Economy	8100.00
0005435488230	19701	Economy	8100.00
0005435999716	19701	Economy	8100.00
0005435488116	19701	Economy	8100.00
0005435488110	19701	Economy	8100.00
0005435840189	6033	Business	199300.00
0005435840190	6033	Business	199300.00
0005435840191	6033	Business	199300.00
0005435840180	6033	Business	199300.00
0005435840181	6033	Business	199300.00
0005435473051	6033	Business	199300.00
0005432142333	6033	Business	199300.00
0005435473032	6033	Business	199300.00
0005435840166	6033	Business	199300.00
0005435840184	6033	Business	199300.00
0005435840178	6033	Economy	66400.00
0005435840167	6033	Economy	66400.00
0005435840186	6033	Economy	66400.00
0005435840175	6033	Economy	66400.00
0005435840188	6033	Economy	73100.00
0005435840179	6033	Economy	66400.00
0005435473099	6033	Economy	66400.00
0005432658647	6033	Economy	66400.00
0005435840187	6033	Economy	66400.00
0005435473082	6033	Economy	66400.00
0005435473059	6033	Economy	66400.00
0005435840168	6033	Economy	66400.00
0005435840172	6033	Economy	66400.00
0005432142331	6033	Economy	66400.00
0005435840170	6033	Economy	66400.00
0005435840185	6033	Economy	66400.00
0005432658646	6033	Economy	66400.00
0005435473084	6033	Economy	66400.00
0005435473100	6033	Economy	66400.00
0005435473149	6033	Economy	66400.00
0005435473073	6033	Economy	66400.00
0005435840171	6033	Economy	66400.00
0005432659762	6033	Economy	66400.00
0005435473085	6033	Economy	66400.00
0005435840182	6033	Economy	66400.00
0005432659763	6033	Economy	66400.00
0005435840176	6033	Economy	66400.00
0005435473150	6033	Economy	66400.00
0005432659761	6033	Economy	66400.00
0005435473117	6033	Economy	66400.00
0005435473074	6033	Economy	66400.00
0005435473102	6033	Economy	66400.00
0005432142332	6033	Economy	66400.00
0005435473098	6033	Economy	66400.00
0005435840177	6033	Economy	66400.00
0005435473097	6033	Economy	66400.00
0005435473083	6033	Economy	66400.00
0005435473116	6033	Economy	66400.00
0005435840173	6033	Economy	66400.00
0005435840183	6033	Economy	66400.00
0005435840174	6033	Economy	66400.00
0005435840169	6033	Economy	66400.00
0005435617241	18036	Business	199300.00
0005435473222	18036	Business	199300.00
0005435839898	18036	Business	199300.00
0005435473220	18036	Business	199300.00
0005435839953	18036	Business	199300.00
0005432660851	18036	Business	199300.00
0005435473231	18036	Business	199300.00
0005432660853	18036	Business	199300.00
0005435839962	18036	Business	199300.00
0005435839988	18036	Business	199300.00
0005435839940	18036	Economy	66400.00
0005432660854	18036	Economy	66400.00
0005435840006	18036	Economy	66400.00
0005435839916	18036	Economy	66400.00
0005432537115	18036	Economy	73100.00
0005435840000	18036	Economy	73100.00
0005435840046	18036	Economy	66400.00
0005435839895	18036	Economy	66400.00
0005435839934	18036	Economy	66400.00
0005435473232	18036	Economy	66400.00
0005432537114	18036	Economy	66400.00
0005435473227	18036	Economy	66400.00
0005435839978	18036	Economy	66400.00
0005435473226	18036	Economy	66400.00
0005435840007	18036	Economy	66400.00
0005435840030	18036	Economy	66400.00
0005435840012	18036	Economy	66400.00
0005435839965	18036	Economy	66400.00
0005435840005	18036	Economy	66400.00
0005435840013	18036	Economy	66400.00
0005435473229	18036	Economy	66400.00
0005435473233	18036	Economy	66400.00
0005432660855	18036	Economy	66400.00
0005435840029	18036	Economy	66400.00
0005435839873	18036	Economy	66400.00
0005435839825	18036	Economy	66400.00
0005435473221	18036	Economy	66400.00
0005435839891	18036	Economy	66400.00
0005435473223	18036	Economy	66400.00
0005435839837	18036	Economy	66400.00
0005435839999	18036	Economy	66400.00
0005435473230	18036	Economy	66400.00
0005435839894	18036	Economy	66400.00
0005435839853	18036	Economy	66400.00
0005435473228	18036	Economy	66400.00
0005435473224	18036	Economy	66400.00
0005435473218	18036	Economy	66400.00
0005435839860	18036	Economy	66400.00
0005435839859	18036	Economy	66400.00
0005435839914	18036	Economy	66400.00
0005435840047	18036	Economy	66400.00
0005435473219	18036	Economy	66400.00
0005435840028	18036	Economy	66400.00
0005435473225	18036	Economy	66400.00
0005433463948	17270	Business	146400.00
0005433463957	17270	Business	146400.00
0005433463956	17270	Business	146400.00
0005433463952	17270	Business	146400.00
0005433462800	17270	Business	146400.00
0005433463946	17270	Business	146400.00
0005433462798	17270	Economy	48800.00
0005433462789	17270	Economy	48800.00
0005433462802	17270	Economy	48800.00
0005433462799	17270	Economy	48800.00
0005433463954	17270	Economy	48800.00
0005433462796	17270	Economy	48800.00
0005433463949	17270	Economy	48800.00
0005433463947	17270	Economy	48800.00
0005433463944	17270	Economy	48800.00
0005433463955	17270	Economy	48800.00
0005433462792	17270	Economy	48800.00
0005433463953	17270	Economy	48800.00
0005433462793	17270	Economy	48800.00
0005433463950	17270	Economy	48800.00
0005433462788	17270	Economy	48800.00
0005433463943	17270	Economy	48800.00
0005433462801	17270	Economy	53700.00
0005433462795	17270	Economy	48800.00
0005433462790	17270	Economy	48800.00
0005433463951	17270	Economy	48800.00
0005433463945	17270	Economy	48800.00
0005433462797	17270	Economy	48800.00
0005433462791	17270	Economy	48800.00
0005433463942	17270	Economy	48800.00
0005433462794	17270	Economy	48800.00
0005433285818	23058	Business	15700.00
0005433285855	23058	Business	15700.00
0005435104173	23058	Business	15700.00
0005433285799	23058	Business	15700.00
0005433285797	23058	Economy	5200.00
0005435104170	23058	Economy	5200.00
0005435104168	23058	Economy	5200.00
0005433285823	23058	Economy	5200.00
0005433285839	23058	Economy	5200.00
0005433285846	23058	Economy	5200.00
0005435104172	23058	Economy	5200.00
0005433285957	23058	Economy	5200.00
0005433285653	23058	Economy	5200.00
0005433285782	23058	Economy	5200.00
0005433285824	23058	Economy	5200.00
0005433285924	23058	Economy	5200.00
0005433285927	23058	Economy	5200.00
0005433285802	23058	Economy	5200.00
0005433285883	23058	Economy	5200.00
0005435104174	23058	Economy	5200.00
0005433285832	23058	Economy	5200.00
0005435104175	23058	Economy	5200.00
0005433285820	23058	Economy	5200.00
0005433285830	23058	Economy	5200.00
0005433285819	23058	Economy	5200.00
0005433285777	23058	Economy	5200.00
0005435104169	23058	Economy	5200.00
0005433285944	23058	Economy	5200.00
0005433285852	23058	Economy	5200.00
0005433285968	23058	Economy	5200.00
0005433285845	23058	Economy	5200.00
0005433285743	23058	Economy	5200.00
0005433285847	23058	Economy	5200.00
0005433285798	23058	Economy	5200.00
0005433285778	23058	Economy	5200.00
0005433285877	23058	Economy	5200.00
0005433285838	23058	Economy	5200.00
0005433285817	23058	Economy	5200.00
0005433285844	23058	Economy	5200.00
0005433285833	23058	Economy	5200.00
0005433285760	23058	Economy	5200.00
0005433285884	23058	Economy	5200.00
0005435104171	23058	Economy	5200.00
0005433285956	23058	Economy	5200.00
0005433285925	23058	Economy	5200.00
0005433285840	23058	Economy	5200.00
0005433285831	23058	Economy	5200.00
0005433285748	23058	Economy	5200.00
0005433286101	32050	Business	15700.00
0005435104005	32050	Business	15700.00
0005433286114	32050	Business	15700.00
0005433286092	32050	Business	15700.00
0005433286113	32050	Business	15700.00
0005433286109	32050	Business	15700.00
0005435104057	32050	Economy	5200.00
0005433286090	32050	Economy	5200.00
0005433286105	32050	Economy	5200.00
0005433286100	32050	Economy	5200.00
0005433286111	32050	Economy	5200.00
0005433286115	32050	Economy	5200.00
0005433286110	32050	Economy	5200.00
0005435104033	32050	Economy	5200.00
0005435104048	32050	Economy	5200.00
0005433286106	32050	Economy	5200.00
0005433286104	32050	Economy	5200.00
0005433286103	32050	Economy	5200.00
0005435104053	32050	Economy	5200.00
0005433286094	32050	Economy	5200.00
0005435104011	32050	Economy	5200.00
0005433286091	32050	Economy	5200.00
0005435104040	32050	Economy	5200.00
0005433286093	32050	Economy	5200.00
0005433286099	32050	Economy	5200.00
0005433286095	32050	Economy	5200.00
0005435104055	32050	Economy	5200.00
0005433286108	32050	Economy	5200.00
0005435104034	32050	Economy	5200.00
0005435104056	32050	Economy	5200.00
0005435104004	32050	Economy	5200.00
0005433286096	32050	Economy	5200.00
0005433286102	32050	Economy	5200.00
0005435104035	32050	Economy	5200.00
0005433286112	32050	Economy	5200.00
0005433286089	32050	Economy	5200.00
0005433286098	32050	Economy	5200.00
0005433286097	32050	Economy	5200.00
0005435104012	32050	Economy	5200.00
0005435104013	32050	Economy	5200.00
0005433286107	32050	Economy	5200.00
0005434068393	30575	Business	42100.00
0005432211699	30575	Business	42100.00
0005432530332	30575	Business	42100.00
0005435215310	30575	Business	42100.00
0005432211701	30575	Business	42100.00
0005435215342	30575	Business	42100.00
0005432530523	30575	Business	42100.00
0005432530802	30575	Business	42100.00
0005435283476	30575	Business	42100.00
0005435215319	30575	Business	42100.00
0005434069113	30575	Business	42100.00
0005432530534	30575	Business	42100.00
0005432535915	30575	Business	42100.00
0005433656759	30575	Business	42100.00
0005435283473	30575	Business	42100.00
0005432530662	30575	Business	42100.00
0005435215323	30575	Business	42100.00
0005432530429	30575	Business	42100.00
0005435215313	30575	Business	42100.00
0005432530191	30575	Business	42100.00
0005432530331	30575	Business	42100.00
0005434068800	30575	Business	42100.00
0005432529402	30575	Comfort	23900.00
0005434068809	30575	Business	42100.00
0005432530140	30575	Comfort	23900.00
0005432530105	30575	Comfort	23900.00
0005432530459	30575	Comfort	23900.00
0005432529953	30575	Comfort	23900.00
0005435215331	30575	Comfort	23900.00
0005432529857	30575	Comfort	23900.00
0005432530259	30575	Comfort	23900.00
0005432529192	30575	Comfort	23900.00
0005435283472	30575	Comfort	23900.00
0005434068672	30575	Comfort	23900.00
0005435215341	30575	Comfort	23900.00
0005435283466	30575	Comfort	23900.00
0005435215325	30575	Comfort	23900.00
0005435283468	30575	Comfort	23900.00
0005432429001	30575	Comfort	23900.00
0005432530124	30575	Comfort	23900.00
0005434068676	30575	Comfort	23900.00
0005432530329	30575	Comfort	23900.00
0005432530983	30575	Comfort	23900.00
0005432535925	30575	Comfort	23900.00
0005432530602	30575	Comfort	23900.00
0005432530060	30575	Comfort	23900.00
0005432530730	30575	Comfort	23900.00
0005432529900	30575	Comfort	23900.00
0005434068725	30575	Comfort	23900.00
0005432530254	30575	Comfort	23900.00
0005432530845	30575	Comfort	23900.00
0005432530224	30575	Comfort	23900.00
0005435215324	30575	Comfort	23900.00
0005432530531	30575	Comfort	23900.00
0005435215317	30575	Comfort	23900.00
0005434068779	30575	Comfort	23900.00
0005435215321	30575	Comfort	23900.00
0005432530303	30575	Comfort	23900.00
0005432530779	30575	Comfort	23900.00
0005435215316	30575	Comfort	23900.00
0005435215320	30575	Comfort	23900.00
0005432530139	30575	Comfort	23900.00
0005434068795	30575	Comfort	23900.00
0005432530338	30575	Economy	14000.00
0005435215359	30575	Economy	14000.00
0005434068845	30575	Economy	14000.00
0005432530211	30575	Economy	14000.00
0005432530073	30575	Economy	14000.00
0005432530275	30575	Economy	14000.00
0005432530832	30575	Economy	14000.00
0005432530362	30575	Economy	14000.00
0005432530987	30575	Economy	14000.00
0005432530753	30575	Economy	14000.00
0005432530495	30575	Economy	14000.00
0005432529689	30575	Economy	14000.00
0005435283465	30575	Economy	14000.00
0005435283474	30575	Economy	14000.00
0005435283471	30575	Economy	14000.00
0005434068994	30575	Economy	14000.00
0005435215311	30575	Economy	14000.00
0005432530457	30575	Economy	14000.00
0005434068706	30575	Economy	14000.00
0005435283478	30575	Economy	14000.00
0005434068389	30575	Economy	14000.00
0005432530566	30575	Economy	14000.00
0005432530324	30575	Economy	14000.00
0005432159982	30575	Economy	14000.00
0005434068916	30575	Economy	14000.00
0005435215336	30575	Economy	14000.00
0005432530020	30575	Economy	14000.00
0005432530569	30575	Economy	14000.00
0005432529781	30575	Economy	14000.00
0005432530213	30575	Economy	14000.00
0005435283480	30575	Economy	14000.00
0005435215337	30575	Economy	14000.00
0005435215329	30575	Economy	14000.00
0005435215332	30575	Economy	14000.00
0005432530015	30575	Economy	14000.00
0005432530413	30575	Economy	14000.00
0005432530660	30575	Economy	14000.00
0005435215350	30575	Economy	14000.00
0005435283482	30575	Economy	14000.00
0005435215315	30575	Economy	14000.00
0005435283485	30575	Economy	14000.00
0005432530844	30575	Economy	14000.00
0005432530176	30575	Economy	14000.00
0005432530492	30575	Economy	14000.00
0005432533345	30575	Economy	14000.00
0005435283470	30575	Economy	14000.00
0005435215357	30575	Economy	14000.00
0005435215356	30575	Economy	14000.00
0005432531186	30575	Economy	14000.00
0005432530661	30575	Economy	14000.00
0005435215322	30575	Economy	14000.00
0005432530414	30575	Economy	14000.00
0005432537090	30575	Economy	14000.00
0005434068988	30575	Economy	15400.00
0005435215349	30575	Economy	14000.00
0005435215339	30575	Economy	14000.00
0005432529998	30575	Economy	14000.00
0005432530433	30575	Economy	14000.00
0005432211702	30575	Economy	15400.00
0005432530574	30575	Economy	15400.00
0005432530228	30575	Economy	15400.00
0005432529967	30575	Economy	14000.00
0005432159980	30575	Economy	14000.00
0005432530270	30575	Economy	14000.00
0005432530404	30575	Economy	14000.00
0005432530465	30575	Economy	14000.00
0005433656761	30575	Economy	14000.00
0005432530641	30575	Economy	14000.00
0005432531183	30575	Economy	14000.00
0005432530532	30575	Economy	14000.00
0005434068876	30575	Economy	14000.00
0005432530632	30575	Economy	14000.00
0005434068739	30575	Economy	14000.00
0005434068516	30575	Economy	14000.00
0005434068682	30575	Economy	14000.00
0005432530096	30575	Economy	14000.00
0005435215330	30575	Economy	14000.00
0005432530226	30575	Economy	14000.00
0005435215327	30575	Economy	14000.00
0005432530428	30575	Economy	14000.00
0005435283462	30575	Economy	14000.00
0005432529766	30575	Economy	14000.00
0005432159978	30575	Economy	14000.00
0005432530624	30575	Economy	14000.00
0005434068523	30575	Economy	14000.00
0005435215343	30575	Economy	14000.00
0005432530781	30575	Economy	14000.00
0005435215328	30575	Economy	14000.00
0005432530463	30575	Economy	14000.00
0005435283475	30575	Economy	14000.00
0005432530545	30575	Economy	14000.00
0005434068943	30575	Economy	14000.00
0005432530790	30575	Economy	14000.00
0005435215345	30575	Economy	14000.00
0005432530373	30575	Economy	14000.00
0005434068770	30575	Economy	14000.00
0005432530370	30575	Economy	14000.00
0005434069225	30575	Economy	14000.00
0005432530633	30575	Economy	14000.00
0005435283464	30575	Economy	14000.00
0005434068685	30575	Economy	14000.00
0005434068829	30575	Economy	14000.00
0005434068883	30575	Economy	14000.00
0005435631046	30575	Economy	14000.00
0005435215307	30575	Economy	14000.00
0005432530055	30575	Economy	14000.00
0005434068726	30575	Economy	14000.00
0005435215354	30575	Economy	14000.00
0005432530089	30575	Economy	14000.00
0005434068679	30575	Economy	14000.00
0005434068998	30575	Economy	14000.00
0005432530349	30575	Economy	14000.00
0005432530335	30575	Economy	14000.00
0005434068587	30575	Economy	14000.00
0005435283469	30575	Economy	14000.00
0005432530339	30575	Economy	14000.00
0005434068724	30575	Economy	14000.00
0005434068778	30575	Economy	14000.00
0005434068675	30575	Economy	14000.00
0005435215344	30575	Economy	14000.00
0005433656762	30575	Economy	14000.00
0005435215309	30575	Economy	14000.00
0005434068787	30575	Economy	14000.00
0005432530066	30575	Economy	14000.00
0005432429000	30575	Economy	14000.00
0005434068893	30575	Economy	14000.00
0005432159981	30575	Economy	14000.00
0005434068844	30575	Economy	14000.00
0005435215340	30575	Economy	14000.00
0005432530563	30575	Economy	14000.00
0005434068658	30575	Economy	14000.00
0005434068678	30575	Economy	14000.00
0005435215347	30575	Economy	14000.00
0005434068839	30575	Economy	14000.00
0005435215303	30575	Economy	14000.00
0005432159979	30575	Economy	14000.00
0005434068669	30575	Economy	14000.00
0005435215352	30575	Economy	14000.00
0005434068764	30575	Economy	14000.00
0005434068828	30575	Economy	14000.00
0005435215306	30575	Economy	14000.00
0005434069013	30575	Economy	14000.00
0005432530562	30575	Economy	14000.00
0005432530374	30575	Economy	14000.00
0005435283463	30575	Economy	14000.00
0005434068388	30575	Economy	14000.00
0005432530107	30575	Economy	14000.00
0005432530334	30575	Economy	14000.00
0005432531190	30575	Economy	14000.00
0005432530253	30575	Economy	14000.00
0005432529997	30575	Economy	14000.00
0005434068989	30575	Economy	14000.00
0005434068884	30575	Economy	14000.00
0005432529576	30575	Economy	14000.00
0005432530464	30575	Economy	14000.00
0005432529684	30575	Economy	15400.00
0005432530525	30575	Economy	15400.00
0005432530177	30575	Economy	15400.00
0005432211700	30575	Economy	15400.00
0005434068687	30575	Economy	14000.00
0005432530225	30575	Economy	14000.00
0005432530106	30575	Economy	14000.00
0005432530323	30575	Economy	14000.00
0005432535920	30575	Economy	14000.00
0005435215318	30575	Economy	14000.00
0005434068749	30575	Economy	14000.00
0005434068860	30575	Economy	14000.00
0005432530394	30575	Economy	14000.00
0005432533340	30575	Economy	14000.00
0005435215314	30575	Economy	14000.00
0005435215308	30575	Economy	14000.00
0005432537099	30575	Economy	14000.00
0005435725727	30575	Economy	14000.00
0005435283483	30575	Economy	14000.00
0005433656763	30575	Economy	14000.00
0005435215305	30575	Economy	14000.00
0005434068398	30575	Economy	14000.00
0005435215353	30575	Economy	14000.00
0005435725730	30575	Economy	14000.00
0005435215326	30575	Economy	14000.00
0005432529952	30575	Economy	14000.00
0005432533344	30575	Economy	14000.00
0005435215355	30575	Economy	14000.00
0005432530395	30575	Economy	14000.00
0005432530540	30575	Economy	14000.00
0005435215335	30575	Economy	14000.00
0005432530567	30575	Economy	14000.00
0005432530575	30575	Economy	14000.00
0005432530215	30575	Economy	14000.00
0005432530645	30575	Economy	14000.00
0005434068522	30575	Economy	14000.00
0005432530396	30575	Economy	14000.00
0005432530427	30575	Economy	14000.00
0005434068761	30575	Economy	14000.00
0005434068832	30575	Economy	14000.00
0005432530375	30575	Economy	14000.00
0005432530227	30575	Economy	14000.00
0005435215358	30575	Economy	14000.00
0005435215334	30575	Economy	14000.00
0005433656760	30575	Economy	14000.00
0005432529885	30575	Economy	14000.00
0005432530167	30575	Economy	14000.00
0005432211696	30575	Economy	14000.00
0005432530214	30575	Economy	14000.00
0005435215333	30575	Economy	14000.00
0005435283477	30575	Economy	14000.00
0005432530659	30575	Economy	14000.00
0005434068808	30575	Economy	14000.00
0005435215346	30575	Economy	14000.00
0005435283467	30575	Economy	14000.00
0005432530524	30575	Economy	14000.00
0005432530711	30575	Economy	14000.00
0005435725729	30575	Economy	14000.00
0005434069224	30575	Economy	14000.00
0005432530241	30575	Economy	14000.00
0005435215351	30575	Economy	14000.00
0005432530546	30575	Economy	14000.00
0005432530584	30575	Economy	14000.00
0005435725728	30575	Economy	14000.00
0005434068748	30575	Economy	14000.00
0005432530727	30575	Economy	14000.00
0005432530585	30575	Economy	14000.00
0005432530212	30575	Economy	14000.00
0005435215312	30575	Economy	14000.00
0005432530210	30575	Economy	14000.00
0005435283479	30575	Economy	14000.00
0005435283481	30575	Economy	14000.00
0005432530533	30575	Economy	14000.00
0005432530355	30575	Economy	14000.00
0005435215304	30575	Economy	14000.00
0005432530350	30575	Economy	14000.00
0005432530178	30575	Economy	14000.00
0005432530346	30575	Economy	14000.00
0005435283484	30575	Economy	14000.00
0005432530024	30575	Economy	14000.00
0005434068688	30575	Economy	14000.00
0005432529932	30575	Economy	14000.00
0005432530021	30575	Economy	14000.00
0005432530831	30575	Economy	14000.00
0005434068723	30575	Economy	14000.00
0005432530258	30575	Economy	14000.00
0005432530019	30575	Economy	14000.00
0005432530481	30575	Economy	14000.00
0005432530340	30575	Economy	14000.00
0005432211698	30575	Economy	14000.00
0005435215302	30575	Economy	14000.00
0005435631047	30575	Economy	14000.00
0005432211697	30575	Economy	14000.00
0005435215338	30575	Economy	14000.00
0005435215348	30575	Economy	14000.00
0005432530458	30575	Economy	14000.00
0005432537089	30575	Economy	14000.00
0005433656758	30575	Economy	14000.00
0005433368887	24853	Business	9800.00
0005435653736	24853	Business	9800.00
0005433368867	24853	Business	9800.00
0005433368864	24853	Business	9800.00
0005435653944	24853	Business	9800.00
0005435653746	24853	Business	9800.00
0005433368881	24853	Business	9800.00
0005433368866	24853	Business	9800.00
0005433368875	24853	Business	9800.00
0005435653772	24853	Economy	3300.00
0005435653695	24853	Economy	3300.00
0005435653873	24853	Economy	3300.00
0005435653773	24853	Economy	3300.00
0005435653690	24853	Economy	3300.00
0005435653768	24853	Economy	3300.00
0005435653789	24853	Economy	3300.00
0005433368879	24853	Economy	3300.00
0005435653863	24853	Economy	3600.00
0005433368863	24853	Economy	3600.00
0005433368883	24853	Economy	3600.00
0005435653856	24853	Economy	3600.00
0005435653758	24853	Economy	3300.00
0005433368861	24853	Economy	3300.00
0005433368889	24853	Economy	3300.00
0005433368868	24853	Economy	3300.00
0005435653694	24853	Economy	3300.00
0005435653829	24853	Economy	3300.00
0005433368880	24853	Economy	3300.00
0005433368872	24853	Economy	3300.00
0005435653585	24853	Economy	3300.00
0005435653938	24853	Economy	3300.00
0005435653753	24853	Economy	3300.00
0005433368886	24853	Economy	3300.00
0005435653792	24853	Economy	3300.00
0005435653857	24853	Economy	3300.00
0005435653715	24853	Economy	3300.00
0005433368882	24853	Economy	3300.00
0005435653845	24853	Economy	3300.00
0005435653791	24853	Economy	3300.00
0005435653702	24853	Economy	3300.00
0005435653779	24853	Economy	3300.00
0005435653793	24853	Economy	3300.00
0005435653612	24853	Economy	3300.00
0005435653898	24853	Economy	3300.00
0005435653703	24853	Economy	3300.00
0005433368888	24853	Economy	3300.00
0005435653836	24853	Economy	3300.00
0005433368885	24853	Economy	3300.00
0005433368873	24853	Economy	3300.00
0005435653887	24853	Economy	3300.00
0005433368890	24853	Economy	3300.00
0005433368876	24853	Economy	3300.00
0005435653714	24853	Economy	3300.00
0005433368877	24853	Economy	3300.00
0005435653939	24853	Economy	3300.00
0005435653911	24853	Economy	3300.00
0005433368874	24853	Economy	3300.00
0005433368894	24853	Economy	3300.00
0005433368871	24853	Economy	3300.00
0005435653790	24853	Economy	3300.00
0005433368869	24853	Economy	3300.00
0005433368884	24853	Economy	3300.00
0005433368891	24853	Economy	3300.00
0005433368870	24853	Economy	3300.00
0005435653744	24853	Economy	3300.00
0005435653888	24853	Economy	3300.00
0005435653801	24853	Economy	3300.00
0005435653598	24853	Economy	3300.00
0005433368878	24853	Economy	3300.00
0005433368892	24853	Economy	3300.00
0005435653599	24853	Economy	3300.00
0005435653691	24853	Economy	3300.00
0005435653910	24853	Economy	3300.00
0005433368865	24853	Economy	3300.00
0005433368893	24853	Economy	3300.00
0005435653872	24853	Economy	3300.00
0005435653862	24853	Economy	3300.00
0005435653769	24853	Economy	3300.00
0005435653721	24853	Economy	3300.00
0005433368862	24853	Economy	3300.00
0005434980584	2063	Economy	10500.00
0005434980581	2063	Economy	10500.00
0005434980585	2063	Economy	10500.00
0005434980583	2063	Economy	9500.00
0005434980571	2063	Economy	9500.00
0005434980590	2063	Economy	9500.00
0005434980575	2063	Economy	9500.00
0005434980577	2063	Economy	9500.00
0005434980589	2063	Economy	9500.00
0005434980574	2063	Economy	9500.00
0005435801778	2063	Economy	9500.00
0005434980582	2063	Economy	9500.00
0005434980572	2063	Economy	9500.00
0005434980593	2063	Economy	9500.00
0005434980588	2063	Economy	9500.00
0005434980580	2063	Economy	9500.00
0005434980591	2063	Economy	9500.00
0005434980579	2063	Economy	9500.00
0005435801777	2063	Economy	9500.00
0005434980578	2063	Economy	9500.00
0005434980576	2063	Economy	9500.00
0005434980592	2063	Economy	9500.00
0005434980573	2063	Economy	9500.00
0005434980586	2063	Economy	9500.00
0005434980587	2063	Economy	9500.00
0005434980316	23544	Economy	10500.00
0005434980197	23544	Economy	10500.00
0005434980246	23544	Economy	9500.00
0005434980315	23544	Economy	9500.00
0005434980298	23544	Economy	9500.00
0005434980223	23544	Economy	9500.00
0005435801738	23544	Economy	9500.00
0005434980253	23544	Economy	9500.00
0005434980224	23544	Economy	9500.00
0005434980279	23544	Economy	9500.00
0005434980264	23544	Economy	9500.00
0005434980226	23544	Economy	9500.00
0005434980403	23544	Economy	9500.00
0005434980069	23544	Economy	9500.00
0005434980256	23544	Economy	9500.00
0005434980306	23544	Economy	9500.00
0005434980314	23544	Economy	9500.00
0005435801750	23544	Economy	9500.00
0005434980199	23544	Economy	9500.00
0005434980322	23544	Economy	9500.00
0005434980254	23544	Economy	9500.00
0005434980320	23544	Economy	9500.00
0005434980178	23544	Economy	9500.00
0005434980245	23544	Economy	9500.00
0005435801737	23544	Economy	9500.00
0005435801765	23544	Economy	9500.00
0005434980356	23544	Economy	9500.00
0005434980121	23544	Economy	9500.00
0005435801760	23544	Economy	9500.00
0005435801766	23544	Economy	9500.00
0005434980263	23544	Economy	9500.00
0005434980390	23544	Economy	9500.00
0005434980164	23544	Economy	9500.00
0005434980225	23544	Economy	9500.00
0005434980198	23544	Economy	9500.00
0005434980333	23544	Economy	9500.00
0005434980313	23544	Economy	9500.00
0005434952631	2576	Economy	5300.00
0005434952629	2576	Economy	5300.00
0005434952630	2576	Economy	5300.00
0005433256467	2583	Economy	5300.00
0005433256461	2583	Economy	5300.00
0005433256460	2583	Economy	5300.00
0005434952597	28243	Economy	5300.00
0005433256483	28243	Economy	5300.00
0005433256482	28243	Economy	5300.00
0005434952607	28243	Economy	5300.00
0005434952605	28243	Economy	5300.00
0005434952596	28243	Economy	5300.00
0005434952599	28243	Economy	5300.00
0005433112418	19784	Economy	8700.00
0005433111564	19784	Economy	8700.00
0005434139566	11963	Business	9700.00
0005434139625	11963	Business	9700.00
0005434139799	11963	Business	9700.00
0005434139772	11963	Business	9700.00
0005434139798	11963	Business	9700.00
0005434139451	11963	Business	9700.00
0005434139740	11963	Business	9700.00
0005434139635	11963	Business	9700.00
0005434139556	11963	Business	9700.00
0005434139825	11963	Business	9700.00
0005434139606	11963	Economy	3200.00
0005434139604	11963	Economy	3200.00
0005434139643	11963	Economy	3200.00
0005434139618	11963	Economy	3200.00
0005434139807	11963	Economy	3200.00
0005434139531	11963	Economy	3500.00
0005434139405	11963	Economy	3500.00
0005434139480	11963	Economy	3500.00
0005434139482	11963	Economy	3500.00
0005434139756	11963	Economy	3500.00
0005434139689	11963	Economy	3200.00
0005434139735	11963	Economy	3200.00
0005434139458	11963	Economy	3200.00
0005434139617	11963	Economy	3200.00
0005434139688	11963	Economy	3200.00
0005434139481	11963	Economy	3200.00
0005434139435	11963	Economy	3200.00
0005434139668	11963	Economy	3200.00
0005434139649	11963	Economy	3200.00
0005434139744	11963	Economy	3200.00
0005434139380	11963	Economy	3200.00
0005434139681	11963	Economy	3200.00
0005434139533	11963	Economy	3200.00
0005434139517	11963	Economy	3200.00
0005434139149	11963	Economy	3200.00
0005434139743	11963	Economy	3200.00
0005434139597	11963	Economy	3200.00
0005434139550	11963	Economy	3200.00
0005434139708	11963	Economy	3200.00
0005434139773	11963	Economy	3200.00
0005434139682	11963	Economy	3200.00
0005434139562	11963	Economy	3200.00
0005434139455	11963	Economy	3200.00
0005434139379	11963	Economy	3200.00
0005434139417	11963	Economy	3200.00
0005434139676	11963	Economy	3200.00
0005434139585	11963	Economy	3200.00
0005434139581	11963	Economy	3200.00
0005434139806	11963	Economy	3200.00
0005434139651	11963	Economy	3200.00
0005434139709	11963	Economy	3200.00
0005434139584	11963	Economy	3200.00
0005434139580	11963	Economy	3200.00
0005434139677	11963	Economy	3200.00
0005434139534	11963	Economy	3200.00
0005434139551	11963	Economy	3200.00
0005434139485	11963	Economy	3200.00
0005434139558	11963	Economy	3200.00
0005434139765	11963	Economy	3200.00
0005434139391	11963	Economy	3200.00
0005434139145	11963	Economy	3200.00
0005434139745	11963	Economy	3200.00
0005434139561	11963	Economy	3200.00
0005434139452	11963	Economy	3200.00
0005434139764	11963	Economy	3200.00
0005434139769	11963	Economy	3200.00
0005434139582	11963	Economy	3200.00
0005434139565	11963	Economy	3200.00
0005434139679	11963	Economy	3200.00
0005434139605	11963	Economy	3200.00
0005434139707	11963	Economy	3200.00
0005434139739	11963	Economy	3200.00
0005434139742	11963	Economy	3200.00
0005434139757	11963	Economy	3200.00
0005434139774	11963	Economy	3200.00
0005434139736	11963	Economy	3200.00
0005434139486	11963	Economy	3200.00
0005434139583	11963	Economy	3200.00
0005434139475	11963	Economy	3200.00
0005434139487	11963	Economy	3200.00
0005434139800	11963	Economy	3200.00
0005434139421	11963	Economy	3200.00
0005434139564	11963	Economy	3200.00
0005434139512	11963	Economy	3200.00
0005434140241	28748	Business	9700.00
0005434140203	28748	Business	9700.00
0005434140285	28748	Business	9700.00
0005434140267	28748	Business	9700.00
0005434140274	28748	Business	9700.00
0005434140256	28748	Business	9700.00
0005434140266	28748	Business	9700.00
0005434140228	28748	Business	9700.00
0005434140257	28748	Business	9700.00
0005434140251	28748	Business	9700.00
0005434140214	28748	Business	9700.00
0005434140239	28748	Economy	3200.00
0005434140283	28748	Economy	3200.00
0005434140208	28748	Economy	3200.00
0005434140273	28748	Economy	3200.00
0005434140231	28748	Economy	3200.00
0005434140222	28748	Economy	3200.00
0005434140275	28748	Economy	3200.00
0005434140246	28748	Economy	3200.00
0005434140290	28748	Economy	3200.00
0005434140269	28748	Economy	3500.00
0005434140263	28748	Economy	3500.00
0005434140205	28748	Economy	3500.00
0005434140279	28748	Economy	3500.00
0005434140217	28748	Economy	3200.00
0005434140247	28748	Economy	3200.00
0005434140281	28748	Economy	3200.00
0005434140261	28748	Economy	3200.00
0005434140277	28748	Economy	3200.00
0005434140260	28748	Economy	3200.00
0005434140264	28748	Economy	3200.00
0005434140233	28748	Economy	3200.00
0005434140234	28748	Economy	3200.00
0005434140289	28748	Economy	3200.00
0005434140272	28748	Economy	3200.00
0005434140293	28748	Economy	3200.00
0005434140243	28748	Economy	3200.00
0005434140230	28748	Economy	3200.00
0005434140209	28748	Economy	3200.00
0005434140282	28748	Economy	3200.00
0005434140252	28748	Economy	3200.00
0005434140288	28748	Economy	3200.00
0005434140271	28748	Economy	3200.00
0005434140245	28748	Economy	3200.00
0005434140210	28748	Economy	3200.00
0005434140225	28748	Economy	3200.00
0005434140259	28748	Economy	3200.00
0005434140278	28748	Economy	3200.00
0005434140242	28748	Economy	3200.00
0005434140229	28748	Economy	3200.00
0005434140223	28748	Economy	3200.00
0005434140253	28748	Economy	3200.00
0005434140224	28748	Economy	3200.00
0005434140254	28748	Economy	3200.00
0005434140206	28748	Economy	3200.00
0005434140258	28748	Economy	3200.00
0005434140255	28748	Economy	3200.00
0005434140212	28748	Economy	3200.00
0005434140292	28748	Economy	3200.00
0005434140232	28748	Economy	3200.00
0005434140238	28748	Economy	3200.00
0005434140280	28748	Economy	3200.00
0005434140215	28748	Economy	3200.00
0005434140213	28748	Economy	3200.00
0005434140219	28748	Economy	3200.00
0005434140248	28748	Economy	3200.00
0005434140220	28748	Economy	3200.00
0005434140287	28748	Economy	3200.00
0005434140270	28748	Economy	3200.00
0005434140216	28748	Economy	3200.00
0005434140204	28748	Economy	3200.00
0005434140276	28748	Economy	3200.00
0005434140294	28748	Economy	3200.00
0005434140227	28748	Economy	3200.00
0005434140207	28748	Economy	3200.00
0005434140262	28748	Economy	3200.00
0005434140250	28748	Economy	3200.00
0005434140221	28748	Economy	3200.00
0005434140249	28748	Economy	3200.00
0005434140235	28748	Economy	3200.00
0005434140236	28748	Economy	3200.00
0005434140268	28748	Economy	3200.00
0005434140226	28748	Economy	3200.00
0005434140286	28748	Economy	3200.00
0005434140237	28748	Economy	3200.00
0005434140284	28748	Economy	3200.00
0005434140265	28748	Economy	3200.00
0005434140211	28748	Economy	3200.00
0005434140291	28748	Economy	3200.00
0005434140218	28748	Economy	3200.00
0005434140244	28748	Economy	3200.00
0005434140240	28748	Economy	3200.00
0005433534555	6801	Economy	9900.00
0005433534554	6801	Economy	9900.00
0005433539096	6801	Economy	9900.00
0005435259824	6801	Economy	9900.00
0005435259837	6801	Economy	9900.00
0005433539094	6801	Economy	9900.00
0005433539097	6801	Economy	9900.00
0005433539095	6801	Economy	9900.00
0005435259838	6801	Economy	9900.00
0005435259844	6801	Economy	9900.00
0005433538993	25023	Economy	9900.00
0005433534530	25023	Economy	9900.00
0005433539044	25023	Economy	9900.00
0005433539013	25023	Economy	9900.00
0005433539028	25023	Economy	9900.00
0005435259875	25023	Economy	9900.00
0005433539016	25023	Economy	9900.00
0005433539029	25023	Economy	9900.00
0005433539012	25023	Economy	9900.00
0005435259876	25023	Economy	9900.00
0005435259872	25023	Economy	9900.00
0005435259873	25023	Economy	9900.00
0005435259874	25023	Economy	9900.00
0005433539009	25023	Economy	9900.00
0005432922605	854	Economy	16100.00
0005433512174	854	Economy	16100.00
0005433512166	854	Economy	16100.00
0005432922606	854	Economy	14600.00
0005433512175	854	Economy	14600.00
0005433512173	854	Economy	14600.00
0005433512170	854	Economy	14600.00
0005433512168	854	Economy	14600.00
0005432922607	854	Economy	14600.00
0005432922614	854	Economy	14600.00
0005432922603	854	Economy	14600.00
0005433512167	854	Economy	14600.00
0005432922595	854	Economy	14600.00
0005432922608	854	Economy	14600.00
0005433512172	854	Economy	14600.00
0005433512171	854	Economy	14600.00
0005433512169	854	Economy	14600.00
0005432922632	16142	Economy	16100.00
0005433512136	16142	Economy	14600.00
0005432922633	16142	Economy	14600.00
0005433512115	16142	Economy	14600.00
0005433512088	16142	Economy	14600.00
0005433512087	16142	Economy	14600.00
0005433512095	16142	Economy	14600.00
0005435698086	3655	Economy	7900.00
0005435698077	3655	Economy	7900.00
0005435698074	3655	Economy	7900.00
0005435698088	3655	Economy	7900.00
0005434950646	3655	Economy	7200.00
0005435698075	3655	Economy	7200.00
0005435698083	3655	Economy	7200.00
0005435698085	3655	Economy	7200.00
0005435698084	3655	Economy	7200.00
0005435698092	3655	Economy	7200.00
0005435698080	3655	Economy	7200.00
0005435935120	3655	Economy	7200.00
0005435698098	3655	Economy	7200.00
0005435698089	3655	Economy	7200.00
0005435698093	3655	Economy	7200.00
0005434950648	3655	Economy	7200.00
0005435698078	3655	Economy	7200.00
0005435698091	3655	Economy	7200.00
0005435698095	3655	Economy	7200.00
0005435698097	3655	Economy	7200.00
0005435698096	3655	Economy	7200.00
0005435698081	3655	Economy	7200.00
0005435916224	3655	Economy	7200.00
0005435935089	3655	Economy	7200.00
0005435698090	3655	Economy	7200.00
0005435698079	3655	Economy	7200.00
0005435698076	3655	Economy	7200.00
0005435935095	3655	Economy	7200.00
0005435698082	3655	Economy	7200.00
0005435698087	3655	Economy	7200.00
0005435935119	3655	Economy	7200.00
0005435698099	3655	Economy	7200.00
0005435698094	3655	Economy	7200.00
0005435935088	3655	Economy	7200.00
0005435698073	3655	Economy	7200.00
0005434950647	3655	Economy	7200.00
0005435935090	3655	Economy	7200.00
0005435697987	16295	Economy	7900.00
0005435935126	16295	Economy	7900.00
0005435933577	16295	Economy	7200.00
0005435933575	16295	Economy	7200.00
0005435697893	16295	Economy	7200.00
0005435697828	16295	Economy	7200.00
0005435697767	16295	Economy	7200.00
0005435697708	16295	Economy	7200.00
0005435697707	16295	Economy	7200.00
0005435697986	16295	Economy	7200.00
0005435697763	16295	Economy	7200.00
0005435697848	16295	Economy	7200.00
0005435697927	16295	Economy	7200.00
0005435697979	16295	Economy	7200.00
0005435697827	16295	Economy	7200.00
0005435697870	16295	Economy	7200.00
0005435916241	16295	Economy	7200.00
0005435697723	16295	Economy	7200.00
0005435697890	16295	Economy	7200.00
0005435697836	16295	Economy	7200.00
0005435697911	16295	Economy	7200.00
0005435697886	16295	Economy	7200.00
0005435697824	16295	Economy	7200.00
0005435697724	16295	Economy	7200.00
0005435697737	16295	Economy	7200.00
0005435697887	16295	Economy	7200.00
0005435697764	16295	Economy	7200.00
0005435697816	16295	Economy	7200.00
0005435697825	16295	Economy	7200.00
0005435697738	16295	Economy	7200.00
0005435697779	16295	Economy	7200.00
0005435697752	16295	Economy	7200.00
0005435916242	16295	Economy	7200.00
0005435697883	16295	Economy	7200.00
0005435933576	16295	Economy	7200.00
0005435697709	16295	Economy	7200.00
0005434950613	16295	Economy	7200.00
0005435697722	16295	Economy	7200.00
0005435697787	16295	Economy	7200.00
0005435697889	16295	Economy	7200.00
0005435841486	3985	Economy	21300.00
0005435904905	3985	Economy	21300.00
0005432609840	3985	Economy	21300.00
0005433519578	3985	Economy	19300.00
0005432607672	3985	Economy	19300.00
0005432609841	3985	Economy	19300.00
0005433519581	3985	Economy	19300.00
0005435841484	3985	Economy	19300.00
0005432607675	3985	Economy	19300.00
0005435841483	3985	Economy	19300.00
0005433519580	3985	Economy	19300.00
0005435841481	3985	Economy	19300.00
0005435904904	3985	Economy	19300.00
0005435853651	3985	Economy	19300.00
0005432609842	3985	Economy	19300.00
0005434606923	3985	Economy	19300.00
0005434604998	3985	Economy	19300.00
0005434606924	3985	Economy	19300.00
0005433519577	3985	Economy	19300.00
0005433519579	3985	Economy	19300.00
0005432607674	3985	Economy	19300.00
0005435842339	3985	Economy	19300.00
0005434604997	3985	Economy	19300.00
0005435841487	3985	Economy	19300.00
0005434604996	3985	Economy	19300.00
0005434604999	3985	Economy	19300.00
0005432607673	3985	Economy	19300.00
0005434606922	3985	Economy	19300.00
0005432613916	22084	Economy	21300.00
0005432613917	22084	Economy	21300.00
0005433519544	22084	Economy	21300.00
0005432613924	22084	Economy	21300.00
0005432609803	22084	Economy	19300.00
0005432613935	22084	Economy	19300.00
0005432613922	22084	Economy	19300.00
0005432609784	22084	Economy	19300.00
0005432609785	22084	Economy	19300.00
0005432613932	22084	Economy	19300.00
0005432609815	22084	Economy	19300.00
0005432613931	22084	Economy	19300.00
0005432609788	22084	Economy	19300.00
0005432613925	22084	Economy	19300.00
0005433519536	22084	Economy	19300.00
0005432609797	22084	Economy	19300.00
0005432613926	22084	Economy	19300.00
0005432613930	22084	Economy	19300.00
0005432609780	22084	Economy	19300.00
0005432609802	22084	Economy	19300.00
0005432613902	22084	Economy	19300.00
0005432613919	22084	Economy	19300.00
0005432609814	22084	Economy	19300.00
0005432613937	22084	Economy	19300.00
0005432609781	22084	Economy	19300.00
0005432613901	22084	Economy	19300.00
0005432609762	22084	Economy	19300.00
0005432609767	22084	Economy	19300.00
0005432609804	22084	Economy	19300.00
0005432613936	22084	Economy	19300.00
0005432609801	22084	Economy	19300.00
0005433519535	22084	Economy	19300.00
0005432609790	22084	Economy	19300.00
0005432613923	22084	Economy	19300.00
0005433519554	22084	Economy	19300.00
0005432609779	22084	Economy	19300.00
0005432609792	22084	Economy	19300.00
0005433519549	22084	Economy	19300.00
0005432613918	22084	Economy	19300.00
0005432613945	22084	Economy	19300.00
0005432613933	22084	Economy	19300.00
0005432609798	22084	Economy	19300.00
0005432613921	22084	Economy	19300.00
0005432613908	22084	Economy	19300.00
0005432609805	22084	Economy	19300.00
0005432609791	22084	Economy	19300.00
0005432613920	22084	Economy	19300.00
0005432609772	22084	Economy	19300.00
0005432613909	22084	Economy	19300.00
0005433519531	22084	Economy	19300.00
0005433349050	699	Economy	3700.00
0005433349101	699	Economy	3700.00
0005433349083	699	Economy	3700.00
0005433349104	699	Economy	3700.00
0005433349117	699	Economy	3700.00
0005433349112	699	Economy	3700.00
0005435628817	699	Economy	3700.00
0005433349105	699	Economy	3700.00
0005433349084	699	Economy	3700.00
0005433349103	699	Economy	3700.00
0005433349121	699	Economy	3700.00
0005435628791	15901	Economy	3700.00
0005433349146	15901	Economy	3700.00
0005433349144	15901	Economy	3700.00
0005433349145	15901	Economy	3700.00
0005433349143	15901	Economy	3700.00
0005435628779	15901	Economy	3700.00
0005433349147	15901	Economy	3700.00
0005433349142	15901	Economy	3700.00
0005435628788	15901	Economy	3700.00
0005433349148	15901	Economy	3700.00
0005435628781	15901	Economy	3700.00
0005433159351	17142	Economy	7100.00
0005434446578	17142	Economy	7100.00
0005433159352	17142	Economy	7100.00
0005434445307	17142	Economy	7100.00
0005434446579	17142	Economy	7100.00
0005434446577	17142	Economy	7100.00
0005434445308	17142	Economy	7100.00
0005434445294	17631	Economy	7100.00
0005433159373	17631	Economy	7100.00
0005434445280	17631	Economy	7100.00
0005433158203	17631	Economy	7100.00
0005433158202	17631	Economy	7100.00
0005434445281	17631	Economy	7100.00
0005434445287	17631	Economy	7100.00
0005434445288	17631	Economy	7100.00
0005435383230	7857	Economy	5900.00
0005435383229	7857	Economy	5900.00
0005435133164	7857	Economy	5400.00
0005435133165	7857	Economy	5400.00
0005435383245	7857	Economy	5400.00
0005435383231	7857	Economy	5400.00
0005435133163	7857	Economy	5400.00
0005435133161	7857	Economy	5400.00
0005435133162	7857	Economy	5400.00
0005435133159	7857	Economy	5400.00
0005435133160	7857	Economy	5400.00
0005435383244	7857	Economy	5400.00
0005435383258	7857	Economy	5400.00
0005435133167	7857	Economy	5400.00
0005435133166	7857	Economy	5400.00
0005435133080	33106	Economy	5900.00
0005435133106	33106	Economy	5900.00
0005435133034	33106	Economy	5400.00
0005435133105	33106	Economy	5400.00
0005435133060	33106	Economy	5400.00
0005435133064	33106	Economy	5400.00
0005435133089	33106	Economy	5400.00
0005435133035	33106	Economy	5400.00
0005435133065	33106	Economy	5400.00
0005435133100	33106	Economy	5400.00
0005435133112	33106	Economy	5400.00
0005435133138	33106	Economy	5400.00
0005435383294	33106	Economy	5400.00
0005435383295	33106	Economy	5400.00
0005435383297	33106	Economy	5400.00
0005435383296	33106	Economy	5400.00
0005435811208	4408	Business	133200.00
0005435811207	4408	Business	133200.00
0005435811209	4408	Economy	44400.00
0005435811204	4408	Economy	44400.00
0005435938927	4408	Economy	48800.00
0005435938922	4408	Economy	44400.00
0005435811205	4408	Economy	44400.00
0005435811214	4408	Economy	44400.00
0005435938937	4408	Economy	44400.00
0005435811210	4408	Economy	44400.00
0005435811206	4408	Economy	44400.00
0005435811212	4408	Economy	44400.00
0005435811211	4408	Economy	44400.00
0005435811213	4408	Economy	44400.00
0005435811165	29437	Business	133200.00
0005435938955	29437	Business	133200.00
0005435811169	29437	Economy	44400.00
0005435938956	29437	Economy	44400.00
0005435938957	29437	Economy	44400.00
0005435811168	29437	Economy	44400.00
0005435811159	29437	Economy	44400.00
0005435938958	29437	Economy	44400.00
0005435811178	29437	Economy	44400.00
0005435811177	29437	Economy	44400.00
0005435811167	29437	Economy	44400.00
0005435390346	7529	Economy	13800.00
0005435390352	7529	Economy	13800.00
0005435160598	7529	Economy	12500.00
0005435390337	7529	Economy	12500.00
0005435160601	7529	Economy	12500.00
0005435160597	7529	Economy	12500.00
0005435160602	7529	Economy	12500.00
0005435160599	7529	Economy	12500.00
0005435160595	7529	Economy	12500.00
0005435160600	7529	Economy	12500.00
0005435390360	7529	Economy	12500.00
0005435390333	7529	Economy	12500.00
0005435390353	7529	Economy	12500.00
0005435160596	7529	Economy	12500.00
0005435390332	7529	Economy	12500.00
0005435160485	29570	Economy	12500.00
0005435160524	29570	Economy	12500.00
0005435160544	29570	Economy	12500.00
0005435160497	29570	Economy	12500.00
0005435160521	29570	Economy	12500.00
0005435160515	29570	Economy	12500.00
0005435160509	29570	Economy	12500.00
0005435160523	29570	Economy	12500.00
0005435390424	29570	Economy	12500.00
0005435390426	29570	Economy	12500.00
0005435160520	29570	Economy	12500.00
0005435160546	29570	Economy	12500.00
0005435160480	29570	Economy	12500.00
0005435160482	29570	Economy	12500.00
0005435160517	29570	Economy	12500.00
0005435160516	29570	Economy	12500.00
0005435390423	29570	Economy	12500.00
0005435160545	29570	Economy	12500.00
0005435160496	29570	Economy	12500.00
0005435390425	29570	Economy	12500.00
0005435179018	18428	Economy	4900.00
0005432398266	18428	Economy	4900.00
0005435178536	18428	Economy	4900.00
0005432398269	18428	Economy	4900.00
0005435178537	18428	Economy	4900.00
0005432398260	18428	Economy	4900.00
0005435179017	18428	Economy	4900.00
0005432398270	18428	Economy	4900.00
0005435179407	27133	Economy	4900.00
0005435178519	27133	Economy	4900.00
0005432400216	27133	Economy	4900.00
0005435179413	27133	Economy	4900.00
0005432398290	27133	Economy	4900.00
0005435179409	27133	Economy	4900.00
0005434552898	9723	Economy	4400.00
0005434552896	9723	Economy	4400.00
0005434191314	9723	Economy	4400.00
0005434552897	9723	Economy	4400.00
0005434505209	6506	Business	48400.00
0005434505208	6506	Business	48400.00
0005434505188	6506	Business	48400.00
0005434505200	6506	Business	48400.00
0005434505197	6506	Business	48400.00
0005434505206	6506	Business	48400.00
0005435104224	6506	Business	48400.00
0005434505196	6506	Economy	16100.00
0005434505214	6506	Economy	16100.00
0005435104232	6506	Economy	16100.00
0005434505205	6506	Economy	16100.00
0005435104238	6506	Economy	16100.00
0005434505218	6506	Economy	16100.00
0005434505215	6506	Economy	16100.00
0005434505190	6506	Economy	17800.00
0005435104236	6506	Economy	17800.00
0005434505198	6506	Economy	17800.00
0005435104237	6506	Economy	16100.00
0005435104218	6506	Economy	16100.00
0005434505204	6506	Economy	16100.00
0005435104221	6506	Economy	16100.00
0005434505189	6506	Economy	16100.00
0005435104234	6506	Economy	16100.00
0005435104215	6506	Economy	16100.00
0005434505211	6506	Economy	16100.00
0005434505212	6506	Economy	16100.00
0005434505207	6506	Economy	16100.00
0005435104217	6506	Economy	16100.00
0005434505199	6506	Economy	16100.00
0005435104229	6506	Economy	16100.00
0005435104213	6506	Economy	16100.00
0005435104223	6506	Economy	16100.00
0005435104216	6506	Economy	16100.00
0005434505221	6506	Economy	16100.00
0005434505222	6506	Economy	16100.00
0005434505219	6506	Economy	16100.00
0005435104228	6506	Economy	16100.00
0005434505210	6506	Economy	16100.00
0005434505217	6506	Economy	16100.00
0005435104227	6506	Economy	16100.00
0005434505194	6506	Economy	16100.00
0005434505201	6506	Economy	16100.00
0005434505192	6506	Economy	16100.00
0005434505193	6506	Economy	16100.00
0005434505213	6506	Economy	16100.00
0005434505216	6506	Economy	16100.00
0005434505195	6506	Economy	16100.00
0005435104233	6506	Economy	16100.00
0005435104226	6506	Economy	16100.00
0005435104219	6506	Economy	16100.00
0005435104222	6506	Economy	16100.00
0005435104220	6506	Economy	16100.00
0005434505187	6506	Economy	16100.00
0005435104225	6506	Economy	16100.00
0005434505203	6506	Economy	16100.00
0005435104235	6506	Economy	16100.00
0005434505202	6506	Economy	16100.00
0005435104231	6506	Economy	16100.00
0005434505220	6506	Economy	16100.00
0005435104230	6506	Economy	16100.00
0005434505191	6506	Economy	16100.00
0005435104212	6506	Economy	16100.00
0005435104214	6506	Economy	16100.00
0005434505011	22652	Business	48400.00
0005435104057	22652	Business	48400.00
0005434504861	22652	Business	48400.00
0005435104011	22652	Business	48400.00
0005434504851	22652	Business	48400.00
0005434504983	22652	Economy	16100.00
0005434504783	22652	Economy	16100.00
0005434504742	22652	Economy	16100.00
0005434504680	22652	Economy	16100.00
0005434504663	22652	Economy	17800.00
0005435104056	22652	Economy	17800.00
0005434504937	22652	Economy	17800.00
0005434504669	22652	Economy	16100.00
0005434504873	22652	Economy	16100.00
0005434504982	22652	Economy	16100.00
0005434504823	22652	Economy	16100.00
0005434504615	22652	Economy	16100.00
0005434504695	22652	Economy	16100.00
0005434504860	22652	Economy	16100.00
0005435104005	22652	Economy	16100.00
0005434504752	22652	Economy	16100.00
0005435104013	22652	Economy	16100.00
0005434504754	22652	Economy	16100.00
0005434504750	22652	Economy	16100.00
0005434504852	22652	Economy	16100.00
0005435104012	22652	Economy	16100.00
0005434504840	22652	Economy	16100.00
0005435104034	22652	Economy	16100.00
0005435104053	22652	Economy	16100.00
0005434504753	22652	Economy	16100.00
0005434504880	22652	Economy	16100.00
0005434504788	22652	Economy	16100.00
0005434504811	22652	Economy	16100.00
0005434504744	22652	Economy	16100.00
0005434504887	22652	Economy	16100.00
0005435104048	22652	Economy	16100.00
0005434504899	22652	Economy	16100.00
0005434504839	22652	Economy	16100.00
0005434504810	22652	Economy	16100.00
0005435104033	22652	Economy	16100.00
0005435104040	22652	Economy	16100.00
0005435104035	22652	Economy	16100.00
0005434504833	22652	Economy	16100.00
0005434504751	22652	Economy	16100.00
0005434504874	22652	Economy	16100.00
0005435104004	22652	Economy	16100.00
0005434505012	22652	Economy	16100.00
0005434504546	22652	Economy	16100.00
0005434504853	22652	Economy	16100.00
0005434504812	22652	Economy	16100.00
0005434504854	22652	Economy	16100.00
0005434504791	22652	Economy	16100.00
0005434504886	22652	Economy	16100.00
0005434504729	22652	Economy	16100.00
0005434504778	22652	Economy	16100.00
0005434504981	22652	Economy	16100.00
0005434504784	22652	Economy	16100.00
0005435104055	22652	Economy	16100.00
0005435800132	21306	Economy	16800.00
0005435800131	21306	Economy	16800.00
0005435800129	21306	Economy	15300.00
0005435800134	21306	Economy	15300.00
0005435800137	21306	Economy	15300.00
0005435800133	21306	Economy	15300.00
0005435800144	21306	Economy	15300.00
0005435800142	21306	Economy	15300.00
0005435800140	21306	Economy	15300.00
0005435800149	21306	Economy	15300.00
0005435800141	21306	Economy	15300.00
0005435800143	21306	Economy	15300.00
0005435800135	21306	Economy	15300.00
0005435800136	21306	Economy	15300.00
0005433368579	1666	Business	50000.00
0005435654274	1666	Business	50000.00
0005435654296	1666	Business	50000.00
0005435654275	1666	Business	50000.00
0005435654261	1666	Business	50000.00
0005435654286	1666	Business	50000.00
0005433368559	1666	Business	50000.00
0005433368639	1666	Business	50000.00
0005433368537	1666	Business	50000.00
0005433368527	1666	Business	50000.00
0005433368663	1666	Business	50000.00
0005435654253	1666	Business	50000.00
0005433368652	1666	Economy	16700.00
0005433368457	1666	Economy	16700.00
0005435654250	1666	Economy	16700.00
0005435654257	1666	Economy	16700.00
0005435654294	1666	Economy	16700.00
0005435654278	1666	Economy	16700.00
0005433368644	1666	Economy	16700.00
0005435654254	1666	Economy	16700.00
0005433368701	1666	Economy	16700.00
0005435654277	1666	Economy	16700.00
0005435654292	1666	Economy	18300.00
0005433368498	1666	Economy	18300.00
0005433368509	1666	Economy	18300.00
0005433368658	1666	Economy	18300.00
0005435654266	1666	Economy	18300.00
0005435654276	1666	Economy	16700.00
0005433368578	1666	Economy	16700.00
0005433368696	1666	Economy	16700.00
0005433368512	1666	Economy	16700.00
0005435654271	1666	Economy	16700.00
0005433368499	1666	Economy	16700.00
0005433368593	1666	Economy	16700.00
0005435654260	1666	Economy	16700.00
0005435654284	1666	Economy	16700.00
0005435654291	1666	Economy	16700.00
0005435654281	1666	Economy	16700.00
0005433368737	1666	Economy	16700.00
0005435654287	1666	Economy	16700.00
0005435654299	1666	Economy	16700.00
0005435654269	1666	Economy	16700.00
0005435654290	1666	Economy	16700.00
0005435654285	1666	Economy	16700.00
0005433368542	1666	Economy	16700.00
0005435654293	1666	Economy	16700.00
0005435654272	1666	Economy	16700.00
0005435654295	1666	Economy	16700.00
0005433368615	1666	Economy	16700.00
0005435654282	1666	Economy	16700.00
0005435654267	1666	Economy	16700.00
0005435654273	1666	Economy	16700.00
0005435654288	1666	Economy	16700.00
0005435654283	1666	Economy	16700.00
0005435654263	1666	Economy	16700.00
0005433368669	1666	Economy	16700.00
0005433368659	1666	Economy	16700.00
0005435654258	1666	Economy	16700.00
0005433368525	1666	Economy	16700.00
0005433368511	1666	Economy	16700.00
0005435654255	1666	Economy	16700.00
0005435654264	1666	Economy	16700.00
0005435654251	1666	Economy	16700.00
0005433368493	1666	Economy	16700.00
0005433368695	1666	Economy	16700.00
0005435654289	1666	Economy	16700.00
0005433368654	1666	Economy	16700.00
0005435654252	1666	Economy	16700.00
0005435654279	1666	Economy	16700.00
0005433368494	1666	Economy	16700.00
0005433368614	1666	Economy	16700.00
0005435654297	1666	Economy	16700.00
0005435654259	1666	Economy	16700.00
0005433368643	1666	Economy	16700.00
0005433368702	1666	Economy	16700.00
0005433368431	1666	Economy	16700.00
0005433368526	1666	Economy	16700.00
0005433368541	1666	Economy	16700.00
0005435654298	1666	Economy	16700.00
0005433368560	1666	Economy	16700.00
0005435654265	1666	Economy	16700.00
0005433368657	1666	Economy	16700.00
0005435654256	1666	Economy	16700.00
0005435654270	1666	Economy	16700.00
0005433368653	1666	Economy	16700.00
0005433368524	1666	Economy	16700.00
0005435654262	1666	Economy	16700.00
0005433368396	1666	Economy	16700.00
0005433368694	1666	Economy	16700.00
0005433368510	1666	Economy	16700.00
0005435654268	1666	Economy	16700.00
0005433368458	1666	Economy	16700.00
0005433368540	1666	Economy	16700.00
0005435654280	1666	Economy	16700.00
0005433368397	1666	Economy	16700.00
0005433368565	1666	Economy	16700.00
0005433368468	1666	Economy	16700.00
0005435653793	21701	Business	50000.00
0005433368894	21701	Business	50000.00
0005435653887	21701	Business	50000.00
0005435653599	21701	Business	50000.00
0005435653944	21701	Business	50000.00
0005433368884	21701	Business	50000.00
0005433368872	21701	Business	50000.00
0005433368887	21701	Business	50000.00
0005435653856	21701	Business	50000.00
0005433368864	21701	Business	50000.00
0005433368886	21701	Economy	16700.00
0005433368889	21701	Economy	16700.00
0005435653910	21701	Economy	16700.00
0005435653714	21701	Economy	16700.00
0005435653769	21701	Economy	16700.00
0005435653702	21701	Economy	16700.00
0005435653773	21701	Economy	16700.00
0005433368880	21701	Economy	16700.00
0005435653779	21701	Economy	18300.00
0005435653836	21701	Economy	18300.00
0005433368893	21701	Economy	18300.00
0005435653772	21701	Economy	18300.00
0005433368865	21701	Economy	16700.00
0005435653690	21701	Economy	16700.00
0005435653695	21701	Economy	16700.00
0005433368885	21701	Economy	16700.00
0005433368867	21701	Economy	16700.00
0005433368874	21701	Economy	16700.00
0005435653736	21701	Economy	16700.00
0005435653715	21701	Economy	16700.00
0005435653888	21701	Economy	16700.00
0005435653703	21701	Economy	16700.00
0005433368882	21701	Economy	16700.00
0005435653898	21701	Economy	16700.00
0005435653872	21701	Economy	16700.00
0005435653939	21701	Economy	16700.00
0005435653744	21701	Economy	16700.00
0005435653845	21701	Economy	16700.00
0005433368876	21701	Economy	16700.00
0005433368881	21701	Economy	16700.00
0005433368871	21701	Economy	16700.00
0005433368879	21701	Economy	16700.00
0005433368891	21701	Economy	16700.00
0005435653829	21701	Economy	16700.00
0005435653753	21701	Economy	16700.00
0005435653801	21701	Economy	16700.00
0005435653694	21701	Economy	16700.00
0005433368890	21701	Economy	16700.00
0005433368869	21701	Economy	16700.00
0005435653792	21701	Economy	16700.00
0005433368866	21701	Economy	16700.00
0005435653938	21701	Economy	16700.00
0005435653721	21701	Economy	16700.00
0005435653791	21701	Economy	16700.00
0005435653598	21701	Economy	16700.00
0005433368888	21701	Economy	16700.00
0005433368863	21701	Economy	16700.00
0005435653789	21701	Economy	16700.00
0005433368861	21701	Economy	16700.00
0005433368878	21701	Economy	16700.00
0005433368862	21701	Economy	16700.00
0005435653790	21701	Economy	16700.00
0005433368868	21701	Economy	16700.00
0005435653863	21701	Economy	16700.00
0005435653585	21701	Economy	16700.00
0005433368892	21701	Economy	16700.00
0005433368883	21701	Economy	16700.00
0005435653862	21701	Economy	16700.00
0005435653911	21701	Economy	16700.00
0005435653612	21701	Economy	16700.00
0005435653857	21701	Economy	16700.00
0005435653768	21701	Economy	16700.00
0005435653691	21701	Economy	16700.00
0005433368870	21701	Economy	16700.00
0005433368877	21701	Economy	16700.00
0005433368873	21701	Economy	16700.00
0005435653746	21701	Economy	16700.00
0005433368875	21701	Economy	16700.00
0005435653758	21701	Economy	16700.00
0005435653873	21701	Economy	16700.00
0005433987231	4170	Business	21500.00
0005433987204	4170	Business	21500.00
0005433987203	4170	Business	21500.00
0005433987214	4170	Business	21500.00
0005433987226	4170	Business	21500.00
0005433987235	4170	Business	21500.00
0005433987222	4170	Economy	7200.00
0005433987196	4170	Economy	7200.00
0005433987238	4170	Economy	7200.00
0005433987205	4170	Economy	7200.00
0005433987240	4170	Economy	7900.00
0005433987218	4170	Economy	7900.00
0005433987227	4170	Economy	7900.00
0005433987236	4170	Economy	7200.00
0005433987194	4170	Economy	7200.00
0005433987206	4170	Economy	7200.00
0005433987210	4170	Economy	7200.00
0005433987202	4170	Economy	7200.00
0005433987215	4170	Economy	7200.00
0005433987208	4170	Economy	7200.00
0005433987223	4170	Economy	7200.00
0005433987234	4170	Economy	7200.00
0005433987211	4170	Economy	7200.00
0005433987233	4170	Economy	7200.00
0005433987189	4170	Economy	7200.00
0005433987225	4170	Economy	7200.00
0005433987217	4170	Economy	7200.00
0005435788840	4170	Economy	7200.00
0005433987220	4170	Economy	7200.00
0005433987221	4170	Economy	7200.00
0005433987191	4170	Economy	7200.00
0005433987239	4170	Economy	7200.00
0005433987232	4170	Economy	7200.00
0005433987229	4170	Economy	7200.00
0005433987197	4170	Economy	7200.00
0005433987224	4170	Economy	7200.00
0005433987219	4170	Economy	7200.00
0005433987237	4170	Economy	7200.00
0005433987228	4170	Economy	7200.00
0005433987199	4170	Economy	7200.00
0005433987216	4170	Economy	7200.00
0005435788841	4170	Economy	7200.00
0005433987195	4170	Economy	7200.00
0005433987213	4170	Economy	7200.00
0005433987198	4170	Economy	7200.00
0005435788839	4170	Economy	7200.00
0005433987193	4170	Economy	7200.00
0005433987212	4170	Economy	7200.00
0005433987200	4170	Economy	7200.00
0005433987209	4170	Economy	7200.00
0005433987201	4170	Economy	7200.00
0005433987192	4170	Economy	7200.00
0005433987230	4170	Economy	7200.00
0005433987207	4170	Economy	7200.00
0005433987190	4170	Economy	7200.00
0005433986748	25679	Business	21500.00
0005433986657	25679	Business	21500.00
0005433986752	25679	Business	21500.00
0005433986740	25679	Economy	7200.00
0005433986743	25679	Economy	7900.00
0005433986640	25679	Economy	7900.00
0005433986781	25679	Economy	7900.00
0005435788812	25679	Economy	7200.00
0005433986599	25679	Economy	7200.00
0005433986658	25679	Economy	7200.00
0005433986557	25679	Economy	7200.00
0005433986478	25679	Economy	7200.00
0005433986722	25679	Economy	7200.00
0005433986629	25679	Economy	7200.00
0005433986721	25679	Economy	7200.00
0005433986635	25679	Economy	7200.00
0005433986706	25679	Economy	7200.00
0005433986642	25679	Economy	7200.00
0005433986654	25679	Economy	7200.00
0005433986645	25679	Economy	7200.00
0005433986477	25679	Economy	7200.00
0005433986739	25679	Economy	7200.00
0005433986697	25679	Economy	7200.00
0005433986637	25679	Economy	7200.00
0005433986696	25679	Economy	7200.00
0005433986460	25679	Economy	7200.00
0005433986476	25679	Economy	7200.00
0005433986741	25679	Economy	7200.00
0005433986664	25679	Economy	7200.00
0005433986705	25679	Economy	7200.00
0005433986751	25679	Economy	7200.00
0005433986665	25679	Economy	7200.00
0005433986653	25679	Economy	7200.00
0005433986641	25679	Economy	7200.00
0005435720846	21239	Economy	9400.00
0005435720845	21239	Economy	9400.00
0005435720162	24801	Economy	9400.00
0005435719595	24801	Economy	9400.00
0005435719596	24801	Economy	9400.00
0005433168460	1630	Economy	17000.00
0005433168437	1630	Economy	17000.00
0005434509355	1630	Economy	15500.00
0005434509358	1630	Economy	15500.00
0005434509356	1630	Economy	15500.00
0005433168451	1630	Economy	15500.00
0005434509349	1630	Economy	15500.00
0005434509352	1630	Economy	15500.00
0005434509357	1630	Economy	15500.00
0005433168433	1630	Economy	15500.00
0005433168445	1630	Economy	15500.00
0005434509353	1630	Economy	15500.00
0005433168435	1630	Economy	15500.00
0005434509345	1630	Economy	15500.00
0005434509346	1630	Economy	15500.00
0005434509347	1630	Economy	15500.00
0005434509354	1630	Economy	15500.00
0005434509351	1630	Economy	15500.00
0005434509350	1630	Economy	15500.00
0005434509344	1630	Economy	15500.00
0005433168440	1630	Economy	15500.00
0005434509343	1630	Economy	15500.00
0005434509348	1630	Economy	15500.00
0005434509359	1630	Economy	15500.00
0005433168459	1630	Economy	15500.00
0005432665319	17860	Business	18000.00
0005432661961	17860	Business	18000.00
0005432655759	17860	Business	18000.00
0005432667490	17860	Business	18000.00
0005432659747	17860	Business	18000.00
0005434151785	17860	Business	18000.00
0005432869706	17860	Economy	6000.00
0005432660858	17860	Economy	6000.00
0005432665315	17860	Economy	6000.00
0005432869704	17860	Economy	6000.00
0005432657510	17860	Economy	6000.00
0005432657500	17860	Economy	6000.00
0005432657509	17860	Economy	6000.00
0005432655773	17860	Economy	6600.00
0005434151786	17860	Economy	6600.00
0005432658621	17860	Economy	6600.00
0005432664163	17860	Economy	6000.00
0005432666422	17860	Economy	6000.00
0005432655739	17860	Economy	6000.00
0005432665314	17860	Economy	6000.00
0005432655804	17860	Economy	6000.00
0005432869703	17860	Economy	6000.00
0005432655721	17860	Economy	6000.00
0005432655768	17860	Economy	6000.00
0005432660861	17860	Economy	6000.00
0005432655776	17860	Economy	6000.00
0005432655699	17860	Economy	6000.00
0005432869705	17860	Economy	6000.00
0005432660852	17860	Economy	6000.00
0005432658618	17860	Economy	6000.00
0005432663067	17860	Economy	6000.00
0005432665310	17860	Economy	6000.00
0005432664162	17860	Economy	6000.00
0005432661966	17860	Economy	6000.00
0005432666418	17860	Economy	6000.00
0005432655720	17860	Economy	6000.00
0005432655734	17860	Economy	6000.00
0005432660860	17860	Economy	6000.00
0005432661970	17860	Economy	6000.00
0005432664187	17860	Economy	6000.00
0005432661956	17860	Economy	6000.00
0005432665309	17860	Economy	6000.00
0005432666417	17860	Economy	6000.00
0005432659742	17860	Economy	6000.00
0005432658620	17860	Economy	6000.00
0005434151784	17860	Economy	6000.00
0005432657506	17860	Economy	6000.00
0005432666428	17860	Economy	6000.00
0005432658619	17860	Economy	6000.00
0005432665312	17860	Economy	6000.00
0005432659745	17860	Economy	6000.00
0005432657498	17860	Economy	6000.00
0005432666427	17860	Economy	6000.00
0005432657499	17860	Economy	6000.00
0005432869601	26331	Business	18000.00
0005432655838	26331	Business	18000.00
0005432660873	26331	Business	18000.00
0005432869639	26331	Business	18000.00
0005432655833	26331	Business	18000.00
0005432665327	26331	Economy	6000.00
0005432655834	26331	Economy	6000.00
0005432660872	26331	Economy	6000.00
0005434151758	26331	Economy	6600.00
0005432869621	26331	Economy	6000.00
0005432660870	26331	Economy	6000.00
0005432655835	26331	Economy	6000.00
0005432869636	26331	Economy	6000.00
0005432869610	26331	Economy	6000.00
0005432869603	26331	Economy	6000.00
0005432657527	26331	Economy	6000.00
0005432655828	26331	Economy	6000.00
0005432657529	26331	Economy	6000.00
0005432869602	26331	Economy	6000.00
0005432655837	26331	Economy	6000.00
0005432659760	26331	Economy	6000.00
0005432655827	26331	Economy	6000.00
0005432655830	26331	Economy	6000.00
0005432869611	26331	Economy	6000.00
0005434151759	26331	Economy	6000.00
0005432655832	26331	Economy	6000.00
0005432869635	26331	Economy	6000.00
0005432655829	26331	Economy	6000.00
0005432667508	26331	Economy	6000.00
0005432658644	26331	Economy	6000.00
0005432657528	26331	Economy	6000.00
0005432655836	26331	Economy	6000.00
0005432660871	26331	Economy	6000.00
0005432869638	26331	Economy	6000.00
0005434151757	26331	Economy	6000.00
0005432655831	26331	Economy	6000.00
0005432659759	26331	Economy	6000.00
0005432658645	26331	Economy	6000.00
0005432666441	26331	Economy	6000.00
0005434151760	26331	Economy	6000.00
0005432639396	25066	Business	87300.00
0005432639330	25066	Business	87300.00
0005432866205	25066	Business	87300.00
0005432639395	25066	Business	87300.00
0005432866201	25066	Economy	29100.00
0005432639351	25066	Economy	29100.00
0005432639416	25066	Economy	29100.00
0005432639404	25066	Economy	32000.00
0005432639371	25066	Economy	29100.00
0005432639354	25066	Economy	29100.00
0005432639313	25066	Economy	29100.00
0005432639403	25066	Economy	29100.00
0005432866195	25066	Economy	29100.00
0005432639281	25066	Economy	29100.00
0005432866200	25066	Economy	29100.00
0005432866203	25066	Economy	29100.00
0005432639397	25066	Economy	29100.00
0005432639314	25066	Economy	29100.00
0005432866198	25066	Economy	29100.00
0005432639359	25066	Economy	29100.00
0005432639376	25066	Economy	29100.00
0005432639336	25066	Economy	29100.00
0005432639369	25066	Economy	29100.00
0005432639272	25066	Economy	29100.00
0005432639385	25066	Economy	29100.00
0005432639358	25066	Economy	29100.00
0005432866196	25066	Economy	29100.00
0005432866194	25066	Economy	29100.00
0005432639352	25066	Economy	29100.00
0005432639312	25066	Economy	29100.00
0005432639355	25066	Economy	29100.00
0005432866197	25066	Economy	29100.00
0005432639304	25066	Economy	29100.00
0005432639277	25066	Economy	29100.00
0005432639386	25066	Economy	29100.00
0005432866202	25066	Economy	29100.00
0005432639381	25066	Economy	29100.00
0005432639329	25066	Economy	29100.00
0005432639278	25066	Economy	29100.00
0005432639375	25066	Economy	29100.00
0005432639382	25066	Economy	29100.00
0005432866199	25066	Economy	29100.00
0005432866204	25066	Economy	29100.00
0005432639350	25066	Economy	29100.00
0005432639353	25066	Economy	29100.00
0005432329939	3110	Business	16100.00
0005432329925	3110	Business	16100.00
0005432329909	3110	Business	16100.00
0005432848856	3110	Business	16100.00
0005432329907	3110	Business	16100.00
0005432329921	3110	Business	16100.00
0005432329917	3110	Business	16100.00
0005432287324	3110	Business	16100.00
0005433439068	3110	Business	16100.00
0005432848863	3110	Economy	5400.00
0005433439072	3110	Economy	5400.00
0005432329924	3110	Economy	5400.00
0005432329915	3110	Economy	5400.00
0005432905225	3110	Economy	5400.00
0005432329930	3110	Economy	5400.00
0005432329933	3110	Economy	5400.00
0005432329913	3110	Economy	5400.00
0005432329935	3110	Economy	5900.00
0005432329900	3110	Economy	5900.00
0005433439074	3110	Economy	5900.00
0005433439077	3110	Economy	5900.00
0005432329920	3110	Economy	5400.00
0005432329938	3110	Economy	5400.00
0005432848847	3110	Economy	5400.00
0005432848852	3110	Economy	5400.00
0005432905243	3110	Economy	5400.00
0005432905248	3110	Economy	5400.00
0005432287327	3110	Economy	5400.00
0005432329934	3110	Economy	5400.00
0005432905250	3110	Economy	5400.00
0005432905233	3110	Economy	5400.00
0005432329910	3110	Economy	5400.00
0005432329926	3110	Economy	5400.00
0005432848854	3110	Economy	5400.00
0005432329912	3110	Economy	5400.00
0005432329928	3110	Economy	5400.00
0005432329922	3110	Economy	5400.00
0005432329937	3110	Economy	5400.00
0005432848862	3110	Economy	5400.00
0005432329908	3110	Economy	5400.00
0005432848848	3110	Economy	5400.00
0005432848850	3110	Economy	5400.00
0005432329929	3110	Economy	5400.00
0005433439070	3110	Economy	5400.00
0005432329919	3110	Economy	5400.00
0005433439076	3110	Economy	5400.00
0005433439073	3110	Economy	5400.00
0005432329906	3110	Economy	5400.00
0005432329903	3110	Economy	5400.00
0005432329914	3110	Economy	5400.00
0005432329904	3110	Economy	5400.00
0005432329936	3110	Economy	5400.00
0005432329931	3110	Economy	5400.00
0005432329916	3110	Economy	5400.00
0005432905224	3110	Economy	5400.00
0005432329923	3110	Economy	5400.00
0005433439067	3110	Economy	5400.00
0005432287323	3110	Economy	5400.00
0005432905262	3110	Economy	5400.00
0005432329932	3110	Economy	5400.00
0005432329911	3110	Economy	5400.00
0005432848855	3110	Economy	5400.00
0005433439071	3110	Economy	5400.00
0005432329918	3110	Economy	5400.00
0005432905263	3110	Economy	5400.00
0005432905232	3110	Economy	5400.00
0005433439069	3110	Economy	5400.00
0005432287326	3110	Economy	5400.00
0005432329905	3110	Economy	5400.00
0005432287325	3110	Economy	5400.00
0005432329902	3110	Economy	5400.00
0005433439066	3110	Economy	5400.00
0005432329927	3110	Economy	5400.00
0005432848853	3110	Economy	5400.00
0005433439075	3110	Economy	5400.00
0005432287322	3110	Economy	5400.00
0005432905226	3110	Economy	5400.00
0005432329901	3110	Economy	5400.00
0005432329623	31105	Business	16100.00
0005432329613	31105	Business	16100.00
0005432329436	31105	Business	16100.00
0005432329356	31105	Business	16100.00
0005432329349	31105	Business	16100.00
0005432329529	31105	Business	16100.00
0005432329466	31105	Business	16100.00
0005432329470	31105	Business	16100.00
0005433438997	31105	Business	16100.00
0005433438977	31105	Economy	5400.00
0005432329566	31105	Economy	5400.00
0005432329309	31105	Economy	5400.00
0005433438976	31105	Economy	5400.00
0005432054385	31105	Economy	5400.00
0005432905274	31105	Economy	5400.00
0005432329546	31105	Economy	5400.00
0005432329358	31105	Economy	5900.00
0005432329457	31105	Economy	5900.00
0005432329571	31105	Economy	5900.00
0005432329435	31105	Economy	5900.00
0005432329602	31105	Economy	5900.00
0005432329342	31105	Economy	5400.00
0005432329634	31105	Economy	5400.00
0005433438987	31105	Economy	5400.00
0005432905270	31105	Economy	5400.00
0005432329434	31105	Economy	5400.00
0005432905271	31105	Economy	5400.00
0005432329350	31105	Economy	5400.00
0005432329633	31105	Economy	5400.00
0005432329471	31105	Economy	5400.00
0005432329482	31105	Economy	5400.00
0005432054383	31105	Economy	5400.00
0005432329323	31105	Economy	5400.00
0005432329744	31105	Economy	5400.00
0005432329411	31105	Economy	5400.00
0005432905272	31105	Economy	5400.00
0005432329496	31105	Economy	5400.00
0005432329318	31105	Economy	5400.00
0005433438983	31105	Economy	5400.00
0005432329461	31105	Economy	5400.00
0005433438982	31105	Economy	5400.00
0005432329497	31105	Economy	5400.00
0005433438992	31105	Economy	5400.00
0005432905273	31105	Economy	5400.00
0005432054384	31105	Economy	5400.00
0005432329572	31105	Economy	5400.00
0005432329329	31105	Economy	5400.00
0005433438995	31105	Economy	5400.00
0005432329465	31105	Economy	5400.00
0005432329558	31105	Economy	5400.00
0005433438981	31105	Economy	5400.00
0005432329301	31105	Economy	5400.00
0005433439010	31105	Economy	5400.00
0005432329691	31105	Economy	5400.00
0005432329635	31105	Economy	5400.00
0005432329705	31105	Economy	5400.00
0005432329565	31105	Economy	5400.00
0005432329410	31105	Economy	5400.00
0005432329378	31105	Economy	5400.00
0005432329464	31105	Economy	5400.00
0005432329359	31105	Economy	5400.00
0005432054382	31105	Economy	5400.00
0005432329548	31105	Economy	5400.00
0005432329700	31105	Economy	5400.00
0005433438980	31105	Economy	5400.00
0005432329547	31105	Economy	5400.00
0005432329481	31105	Economy	5400.00
0005432905275	31105	Economy	5400.00
0005432329432	31105	Economy	5400.00
0005432329681	31105	Economy	5400.00
0005435999770	6234	Business	124600.00
0005435999765	6234	Business	124600.00
0005434310105	6234	Business	124600.00
0005435999759	6234	Business	124600.00
0005435297187	6234	Economy	41500.00
0005435297177	6234	Economy	41500.00
0005435999747	6234	Economy	41500.00
0005435488208	6234	Economy	41500.00
0005435999772	6234	Economy	41500.00
0005435999773	6234	Economy	41500.00
0005435999749	6234	Economy	41500.00
0005435999767	6234	Economy	41500.00
0005435297178	6234	Economy	41500.00
0005435999761	6234	Economy	41500.00
0005435999774	6234	Economy	41500.00
0005435488186	6234	Economy	41500.00
0005435488325	6234	Economy	41500.00
0005434310103	6234	Economy	41500.00
0005435999742	6234	Economy	41500.00
0005435488164	6234	Economy	41500.00
0005434310101	6234	Economy	41500.00
0005435999746	6234	Economy	41500.00
0005435999768	6234	Economy	41500.00
0005434310110	6234	Economy	41500.00
0005435999764	6234	Economy	45700.00
0005435488200	6234	Economy	41500.00
0005435999757	6234	Economy	45700.00
0005435297129	6234	Economy	41500.00
0005435488290	6234	Economy	41500.00
0005435999756	6234	Economy	41500.00
0005435488326	6234	Economy	41500.00
0005435488191	6234	Economy	41500.00
0005435488242	6234	Economy	41500.00
0005435999758	6234	Economy	41500.00
0005435999751	6234	Economy	41500.00
0005435999750	6234	Economy	41500.00
0005435999763	6234	Economy	41500.00
0005435999771	6234	Economy	41500.00
0005435999769	6234	Economy	41500.00
0005435999744	6234	Economy	41500.00
0005434310104	6234	Economy	41500.00
0005435999755	6234	Economy	41500.00
0005432146255	6234	Economy	41500.00
0005434310109	6234	Economy	41500.00
0005435999754	6234	Economy	41500.00
0005434310107	6234	Economy	41500.00
0005435488212	6234	Economy	41500.00
0005435999760	6234	Economy	41500.00
0005435488303	6234	Economy	41500.00
0005435999745	6234	Economy	41500.00
0005435999753	6234	Economy	41500.00
0005435488255	6234	Economy	41500.00
0005435488209	6234	Economy	41500.00
0005435999748	6234	Economy	41500.00
0005435999752	6234	Economy	41500.00
0005434310102	6234	Economy	41500.00
0005435999762	6234	Economy	41500.00
0005435297183	6234	Economy	41500.00
0005434310106	6234	Economy	41500.00
0005434310108	6234	Economy	41500.00
0005435999775	6234	Economy	41500.00
0005435999766	6234	Economy	41500.00
0005435297185	6234	Economy	41500.00
0005435999743	6234	Economy	41500.00
0005435297179	6234	Economy	41500.00
0005435488190	6234	Economy	41500.00
0005435999544	19547	Business	124600.00
0005434309950	19547	Business	124600.00
0005435488388	19547	Business	124600.00
0005434309963	19547	Business	124600.00
0005435999428	19547	Business	124600.00
0005435999563	19547	Business	124600.00
0005435488385	19547	Business	124600.00
0005435297243	19547	Business	124600.00
0005435297240	19547	Business	124600.00
0005435488390	19547	Economy	41500.00
0005435297244	19547	Economy	41500.00
0005435999515	19547	Economy	41500.00
0005435488398	19547	Economy	41500.00
0005435999512	19547	Economy	41500.00
0005434309973	19547	Economy	41500.00
0005434309912	19547	Economy	41500.00
0005435999542	19547	Economy	41500.00
0005435999514	19547	Economy	41500.00
0005434309964	19547	Economy	41500.00
0005435297246	19547	Economy	41500.00
0005435488393	19547	Economy	41500.00
0005435999558	19547	Economy	41500.00
0005435297245	19547	Economy	41500.00
0005434310069	19547	Economy	41500.00
0005435999538	19547	Economy	41500.00
0005435488395	19547	Economy	41500.00
0005435999541	19547	Economy	41500.00
0005434309949	19547	Economy	45700.00
0005435488403	19547	Economy	45700.00
0005435999570	19547	Economy	41500.00
0005435999523	19547	Economy	41500.00
0005435297241	19547	Economy	41500.00
0005434310070	19547	Economy	41500.00
0005435999509	19547	Economy	41500.00
0005434310003	19547	Economy	41500.00
0005434310010	19547	Economy	41500.00
0005435488386	19547	Economy	41500.00
0005434310009	19547	Economy	41500.00
0005435999516	19547	Economy	41500.00
0005435999545	19547	Economy	41500.00
0005435999430	19547	Economy	41500.00
0005435488401	19547	Economy	41500.00
0005434310032	19547	Economy	41500.00
0005435488384	19547	Economy	41500.00
0005435999508	19547	Economy	41500.00
0005435488392	19547	Economy	41500.00
0005435488400	19547	Economy	41500.00
0005434309987	19547	Economy	41500.00
0005434309911	19547	Economy	41500.00
0005434310068	19547	Economy	41500.00
0005434309966	19547	Economy	41500.00
0005434309892	19547	Economy	41500.00
0005435999537	19547	Economy	41500.00
0005435999568	19547	Economy	41500.00
0005435488394	19547	Economy	41500.00
0005435488391	19547	Economy	41500.00
0005434309893	19547	Economy	41500.00
0005435999564	19547	Economy	41500.00
0005435488396	19547	Economy	41500.00
0005435999513	19547	Economy	41500.00
0005435488389	19547	Economy	41500.00
0005435488387	19547	Economy	41500.00
0005435999546	19547	Economy	41500.00
0005435297242	19547	Economy	41500.00
0005435488402	19547	Economy	41500.00
0005435488399	19547	Economy	41500.00
0005435999567	19547	Economy	41500.00
0005435999547	19547	Economy	41500.00
0005435999556	19547	Economy	41500.00
0005435488397	19547	Economy	41500.00
0005435999429	19547	Economy	41500.00
0005435518393	1598	Business	86000.00
0005432291995	1598	Business	86000.00
0005435518388	1598	Business	86000.00
0005434566270	1598	Business	86000.00
0005435502896	1598	Business	86000.00
0005435502893	1598	Business	86000.00
0005435508751	1598	Business	86000.00
0005434566274	1598	Business	86000.00
0005434566279	1598	Business	86000.00
0005435508759	1598	Business	86000.00
0005435508765	1598	Business	86000.00
0005434566278	1598	Business	86000.00
0005435502898	1598	Economy	28700.00
0005435508752	1598	Economy	28700.00
0005435518391	1598	Economy	28700.00
0005435502889	1598	Economy	28700.00
0005432291996	1598	Economy	28700.00
0005435502892	1598	Economy	28700.00
0005434566269	1598	Economy	28700.00
0005435518395	1598	Economy	28700.00
0005435518392	1598	Economy	31500.00
0005435518399	1598	Economy	31500.00
0005435502890	1598	Economy	31500.00
0005435502900	1598	Economy	31500.00
0005433186298	1598	Economy	31500.00
0005435508766	1598	Economy	28700.00
0005434566273	1598	Economy	28700.00
0005434566275	1598	Economy	28700.00
0005435518389	1598	Economy	28700.00
0005433186297	1598	Economy	28700.00
0005435508763	1598	Economy	28700.00
0005435508760	1598	Economy	28700.00
0005435518402	1598	Economy	28700.00
0005434566271	1598	Economy	28700.00
0005435508767	1598	Economy	28700.00
0005435508750	1598	Economy	28700.00
0005435508757	1598	Economy	28700.00
0005435518404	1598	Economy	28700.00
0005435508758	1598	Economy	28700.00
0005435508756	1598	Economy	28700.00
0005435508755	1598	Economy	28700.00
0005435518390	1598	Economy	28700.00
0005434566276	1598	Economy	28700.00
0005435508764	1598	Economy	28700.00
0005435508749	1598	Economy	28700.00
0005435518403	1598	Economy	28700.00
0005435508753	1598	Economy	28700.00
0005435502894	1598	Economy	28700.00
0005433186323	1598	Economy	28700.00
0005435518400	1598	Economy	28700.00
0005434566272	1598	Economy	28700.00
0005434566280	1598	Economy	28700.00
0005435518407	1598	Economy	28700.00
0005435502897	1598	Economy	28700.00
0005435518394	1598	Economy	28700.00
0005435518401	1598	Economy	28700.00
0005434566268	1598	Economy	28700.00
0005435508761	1598	Economy	28700.00
0005435508768	1598	Economy	28700.00
0005435518408	1598	Economy	28700.00
0005435518396	1598	Economy	28700.00
0005435518398	1598	Economy	28700.00
0005435508769	1598	Economy	28700.00
0005435508771	1598	Economy	28700.00
0005435508770	1598	Economy	28700.00
0005435508754	1598	Economy	28700.00
0005435518397	1598	Economy	28700.00
0005435502883	1598	Economy	28700.00
0005435518405	1598	Economy	28700.00
0005435502902	1598	Economy	28700.00
0005435502887	1598	Economy	28700.00
0005435518406	1598	Economy	28700.00
0005435502888	1598	Economy	28700.00
0005435502903	1598	Economy	28700.00
0005435502891	1598	Economy	28700.00
0005435502899	1598	Economy	28700.00
0005435502885	1598	Economy	28700.00
0005434566277	1598	Economy	28700.00
0005435508762	1598	Economy	28700.00
0005435502886	1598	Economy	28700.00
0005435508748	1598	Economy	28700.00
0005435502895	1598	Economy	28700.00
0005435502901	1598	Economy	28700.00
0005435502884	1598	Economy	28700.00
0005433186347	20870	Business	86000.00
0005435502685	20870	Business	86000.00
0005435529682	20870	Business	86000.00
0005433186345	20870	Business	86000.00
0005435502721	20870	Business	86000.00
0005435502630	20870	Economy	28700.00
0005434566177	20870	Economy	28700.00
0005434566160	20870	Economy	28700.00
0005434566185	20870	Economy	28700.00
0005433186349	20870	Economy	28700.00
0005435502652	20870	Economy	28700.00
0005433186350	20870	Economy	31500.00
0005435529628	20870	Economy	31500.00
0005435529577	20870	Economy	28700.00
0005434566078	20870	Economy	28700.00
0005435529598	20870	Economy	28700.00
0005434566133	20870	Economy	28700.00
0005435545850	20870	Economy	28700.00
0005435502641	20870	Economy	28700.00
0005434566157	20870	Economy	28700.00
0005435502723	20870	Economy	28700.00
0005435545883	20870	Economy	28700.00
0005434566148	20870	Economy	28700.00
0005435529596	20870	Economy	28700.00
0005435545864	20870	Economy	28700.00
0005435502684	20870	Economy	28700.00
0005435529587	20870	Economy	28700.00
0005433186346	20870	Economy	28700.00
0005435502747	20870	Economy	28700.00
0005434566156	20870	Economy	28700.00
0005435502745	20870	Economy	28700.00
0005435529679	20870	Economy	28700.00
0005435502615	20870	Economy	28700.00
0005435529599	20870	Economy	28700.00
0005435529615	20870	Economy	28700.00
0005435545860	20870	Economy	28700.00
0005433186344	20870	Economy	28700.00
0005435529653	20870	Economy	28700.00
0005433186348	20870	Economy	28700.00
0005435545861	20870	Economy	28700.00
0005435502614	20870	Economy	28700.00
0005435545859	20870	Economy	28700.00
0005434566132	20870	Economy	28700.00
0005433186343	20870	Economy	28700.00
0005435502635	20870	Economy	28700.00
0005435545844	20870	Economy	28700.00
0005434566158	20870	Economy	28700.00
0005435545876	20870	Economy	28700.00
0005435529667	20870	Economy	28700.00
0005434566159	20870	Economy	28700.00
0005435502686	20870	Economy	28700.00
0005434566198	20870	Economy	28700.00
0005433186351	20870	Economy	28700.00
0005434566087	20870	Economy	28700.00
0005435502775	20870	Economy	28700.00
0005435502619	20870	Economy	28700.00
0005435529583	20870	Economy	28700.00
0005435153922	3908	Economy	19700.00
0005435142993	3908	Economy	19700.00
0005435153919	3908	Economy	19700.00
0005435142994	3908	Economy	19700.00
0005435142991	3908	Economy	19700.00
0005435142992	3908	Economy	19700.00
0005435153917	3908	Economy	19700.00
0005435153920	3908	Economy	19700.00
0005435153921	3908	Economy	19700.00
0005435142995	3908	Economy	19700.00
0005435153918	3908	Economy	19700.00
0005435153877	21890	Economy	19700.00
0005435931701	21890	Economy	19700.00
0005435931702	21890	Economy	19700.00
0005435153861	21890	Economy	19700.00
0005435153858	21890	Economy	19700.00
0005435153854	21890	Economy	19700.00
0005435153859	21890	Economy	19700.00
0005435153823	21890	Economy	19700.00
0005435153855	21890	Economy	19700.00
0005435153857	21890	Economy	19700.00
0005435153866	21890	Economy	19700.00
0005435153878	21890	Economy	19700.00
0005435225703	7198	Economy	14300.00
0005432629240	7198	Economy	13000.00
0005432629244	7198	Economy	13000.00
0005432629247	7198	Economy	13000.00
0005435225740	7198	Economy	13000.00
0005432629245	7198	Economy	13000.00
0005432629238	7198	Economy	13000.00
0005432629241	7198	Economy	13000.00
0005432629239	7198	Economy	13000.00
0005435225722	7198	Economy	13000.00
0005432629246	7198	Economy	13000.00
0005435225726	7198	Economy	13000.00
0005432629243	7198	Economy	13000.00
0005435225702	7198	Economy	13000.00
0005432629237	7198	Economy	13000.00
0005435225716	7198	Economy	13000.00
0005435225715	7198	Economy	13000.00
0005435225721	7198	Economy	13000.00
0005432629248	7198	Economy	13000.00
0005435225717	7198	Economy	13000.00
0005432629242	7198	Economy	13000.00
0005432629104	28127	Economy	14300.00
0005435225796	28127	Economy	14300.00
0005435225794	28127	Economy	13000.00
0005435225798	28127	Economy	13000.00
0005432629172	28127	Economy	13000.00
0005432629171	28127	Economy	13000.00
0005435225795	28127	Economy	13000.00
0005432629137	28127	Economy	13000.00
0005432629105	28127	Economy	13000.00
0005432629117	28127	Economy	13000.00
0005432629138	28127	Economy	13000.00
0005435225797	28127	Economy	13000.00
0005435225793	28127	Economy	13000.00
0005435960153	8717	Economy	10500.00
0005435960152	8717	Economy	10500.00
0005434268023	8717	Economy	10500.00
0005434268018	8717	Economy	10500.00
0005434268013	8717	Economy	10500.00
0005434268024	8717	Economy	10500.00
0005435960154	8717	Economy	10500.00
0005434268053	15248	Economy	11500.00
0005435960119	15248	Economy	11500.00
0005434268051	15248	Economy	10500.00
0005434268052	15248	Economy	10500.00
0005435960127	15248	Economy	10500.00
0005435960120	15248	Economy	10500.00
0005435960122	15248	Economy	10500.00
0005435960128	15248	Economy	10500.00
0005435960130	15248	Economy	10500.00
0005434268050	15248	Economy	10500.00
0005435960121	15248	Economy	10500.00
0005432873448	1206	Business	115000.00
0005432693850	1206	Business	115000.00
0005432693859	1206	Business	115000.00
0005432693874	1206	Business	115000.00
0005432693873	1206	Business	115000.00
0005432675534	1206	Business	115000.00
0005432675543	1206	Business	115000.00
0005432873414	1206	Business	115000.00
0005432675532	1206	Economy	38300.00
0005432693867	1206	Economy	38300.00
0005432693871	1206	Economy	38300.00
0005432873439	1206	Economy	38300.00
0005432677676	1206	Economy	38300.00
0005432693855	1206	Economy	42200.00
0005432675540	1206	Economy	38300.00
0005432693863	1206	Economy	38300.00
0005432693865	1206	Economy	38300.00
0005432675542	1206	Economy	38300.00
0005432693848	1206	Economy	38300.00
0005432693852	1206	Economy	38300.00
0005432693857	1206	Economy	38300.00
0005432693851	1206	Economy	38300.00
0005432873438	1206	Economy	38300.00
0005432675538	1206	Economy	38300.00
0005432693870	1206	Economy	38300.00
0005432693849	1206	Economy	38300.00
0005432693872	1206	Economy	38300.00
0005432693853	1206	Economy	38300.00
0005432693858	1206	Economy	38300.00
0005432675535	1206	Economy	38300.00
0005432693869	1206	Economy	38300.00
0005432675533	1206	Economy	38300.00
0005432675541	1206	Economy	38300.00
0005432677675	1206	Economy	38300.00
0005432693856	1206	Economy	38300.00
0005432675536	1206	Economy	38300.00
0005432873415	1206	Economy	38300.00
0005432873427	1206	Economy	38300.00
0005432693875	1206	Economy	38300.00
0005432693861	1206	Economy	38300.00
0005432693854	1206	Economy	38300.00
0005432675537	1206	Economy	38300.00
0005432693862	1206	Economy	38300.00
0005432693860	1206	Economy	38300.00
0005432693868	1206	Economy	38300.00
0005432873424	1206	Economy	38300.00
0005432693866	1206	Economy	38300.00
0005432675539	1206	Economy	38300.00
0005432677677	1206	Economy	38300.00
0005432873419	1206	Economy	38300.00
0005432693864	1206	Economy	38300.00
0005432675408	17457	Business	115000.00
0005432677645	17457	Business	115000.00
0005432873479	17457	Business	115000.00
0005432693562	17457	Business	115000.00
0005432693541	17457	Business	115000.00
0005432693551	17457	Business	115000.00
0005432677643	17457	Business	115000.00
0005432675403	17457	Business	115000.00
0005432873481	17457	Business	115000.00
0005432693649	17457	Business	115000.00
0005432693490	17457	Economy	38300.00
0005432693525	17457	Economy	38300.00
0005432677655	17457	Economy	38300.00
0005432693598	17457	Economy	38300.00
0005432675465	17457	Economy	38300.00
0005432675442	17457	Economy	38300.00
0005432675477	17457	Economy	42200.00
0005432675450	17457	Economy	38300.00
0005432693556	17457	Economy	38300.00
0005432693539	17457	Economy	38300.00
0005432675387	17457	Economy	38300.00
0005432693679	17457	Economy	38300.00
0005432677644	17457	Economy	38300.00
0005432675409	17457	Economy	38300.00
0005432693545	17457	Economy	38300.00
0005432693654	17457	Economy	38300.00
0005432693578	17457	Economy	38300.00
0005432693599	17457	Economy	38300.00
0005432693553	17457	Economy	38300.00
0005432675431	17457	Economy	38300.00
0005432693552	17457	Economy	38300.00
0005432693540	17457	Economy	38300.00
0005432677654	17457	Economy	38300.00
0005432693647	17457	Economy	38300.00
0005432873480	17457	Economy	38300.00
0005432693705	17457	Economy	38300.00
0005432693579	17457	Economy	38300.00
0005432693546	17457	Economy	38300.00
0005432693555	17457	Economy	38300.00
0005432873482	17457	Economy	38300.00
0005432693489	17457	Economy	38300.00
0005432675382	17457	Economy	38300.00
0005432677642	17457	Economy	38300.00
0005432693641	17457	Economy	38300.00
0005432677660	17457	Economy	38300.00
0005432693615	17457	Economy	38300.00
0005432693524	17457	Economy	38300.00
0005432693648	17457	Economy	38300.00
0005432873483	17457	Economy	38300.00
0005432693661	17457	Economy	38300.00
0005432675401	17457	Economy	38300.00
0005432675381	17457	Economy	38300.00
0005432693635	17457	Economy	38300.00
0005432693573	17457	Economy	38300.00
0005432693563	17457	Economy	38300.00
0005432693678	17457	Economy	38300.00
0005434435595	1135	Economy	15200.00
0005434435596	1135	Economy	15200.00
0005433156926	1135	Economy	13900.00
0005433156906	1135	Economy	13900.00
0005434435587	1135	Economy	13900.00
0005434435594	1135	Economy	13900.00
0005433156927	1135	Economy	13900.00
0005434435589	1135	Economy	13900.00
0005434435590	1135	Economy	13900.00
0005433156922	1135	Economy	13900.00
0005433156910	1135	Economy	13900.00
0005434435591	1135	Economy	13900.00
0005433156937	1135	Economy	13900.00
0005433156905	1135	Economy	13900.00
0005434435600	1135	Economy	13900.00
0005433156956	1135	Economy	13900.00
0005433156957	1135	Economy	13900.00
0005433156912	1135	Economy	13900.00
0005434435597	1135	Economy	13900.00
0005434435598	1135	Economy	13900.00
0005434435592	1135	Economy	13900.00
0005434435599	1135	Economy	13900.00
0005434435593	1135	Economy	13900.00
0005434435588	1135	Economy	13900.00
0005433156932	1135	Economy	13900.00
0005433156907	1135	Economy	13900.00
0005434435455	17274	Economy	15200.00
0005433156982	17274	Economy	15200.00
0005434435485	17274	Economy	15200.00
0005434435461	17274	Economy	13900.00
0005434435423	17274	Economy	13900.00
0005434435445	17274	Economy	13900.00
0005434435469	17274	Economy	13900.00
0005433156980	17274	Economy	13900.00
0005433156985	17274	Economy	13900.00
0005433156981	17274	Economy	13900.00
0005434435483	17274	Economy	13900.00
0005434435459	17274	Economy	13900.00
0005434435446	17274	Economy	13900.00
0005434435436	17274	Economy	13900.00
0005434435460	17274	Economy	13900.00
0005433156978	17274	Economy	13900.00
0005434435421	17274	Economy	13900.00
0005434435473	17274	Economy	13900.00
0005434435512	17274	Economy	13900.00
0005433156983	17274	Economy	13900.00
0005434435482	17274	Economy	13900.00
0005434435474	17274	Economy	13900.00
0005434435472	17274	Economy	13900.00
0005433156984	17274	Economy	13900.00
0005434435422	17274	Economy	13900.00
0005434435458	17274	Economy	13900.00
0005433156979	17274	Economy	13900.00
0005434435444	17274	Economy	13900.00
0005435087034	4073	Economy	7500.00
0005435928207	4073	Economy	7500.00
0005435928248	4073	Economy	7500.00
0005435928234	4073	Economy	7500.00
0005435087036	4073	Economy	7500.00
0005435087031	4073	Economy	7500.00
0005435087033	4073	Economy	7500.00
0005435928230	4073	Economy	7500.00
0005435928231	4073	Economy	7500.00
0005435087035	4073	Economy	7500.00
0005435928233	4073	Economy	7500.00
0005435928209	4073	Economy	7500.00
0005435087030	4073	Economy	7500.00
0005435087032	4073	Economy	7500.00
0005435928273	24403	Economy	8200.00
0005435086968	24403	Economy	7500.00
0005435086997	24403	Economy	7500.00
0005435086930	24403	Economy	7500.00
0005435086929	24403	Economy	7500.00
0005435928272	24403	Economy	7500.00
0005435928274	24403	Economy	7500.00
0005435928271	24403	Economy	7500.00
0005435086967	24403	Economy	7500.00
0005435086971	24403	Economy	7500.00
0005435086996	24403	Economy	7500.00
0005435086956	24403	Economy	7500.00
0005435928270	24403	Economy	7500.00
0005434964720	1327	Business	203300.00
0005434964745	1327	Business	203300.00
0005434964718	1327	Business	203300.00
0005434964736	1327	Business	203300.00
0005433261755	1327	Business	203300.00
0005433261731	1327	Business	203300.00
0005434964711	1327	Economy	74500.00
0005434964722	1327	Economy	74500.00
0005434964731	1327	Economy	67800.00
0005433261720	1327	Economy	67800.00
0005433261770	1327	Economy	67800.00
0005434964725	1327	Economy	67800.00
0005432279328	1327	Economy	67800.00
0005434964712	1327	Economy	67800.00
0005432279332	1327	Economy	67800.00
0005434964742	1327	Economy	67800.00
0005434964737	1327	Economy	67800.00
0005434964726	1327	Economy	67800.00
0005433261719	1327	Economy	67800.00
0005434964735	1327	Economy	67800.00
0005434964739	1327	Economy	67800.00
0005434964732	1327	Economy	67800.00
0005434964723	1327	Economy	67800.00
0005432279330	1327	Economy	67800.00
0005434964746	1327	Economy	67800.00
0005434964727	1327	Economy	67800.00
0005433261771	1327	Economy	67800.00
0005434964710	1327	Economy	67800.00
0005434964740	1327	Economy	67800.00
0005433261733	1327	Economy	67800.00
0005433261735	1327	Economy	67800.00
0005434964719	1327	Economy	67800.00
0005434964734	1327	Economy	67800.00
0005434964730	1327	Economy	67800.00
0005434964733	1327	Economy	67800.00
0005433261756	1327	Economy	67800.00
0005434964715	1327	Economy	67800.00
0005433261722	1327	Economy	67800.00
0005433261721	1327	Economy	67800.00
0005434964741	1327	Economy	67800.00
0005434964743	1327	Economy	67800.00
0005433261718	1327	Economy	67800.00
0005434964744	1327	Economy	67800.00
0005434964738	1327	Economy	67800.00
0005434964729	1327	Economy	67800.00
0005434964713	1327	Economy	67800.00
0005434964724	1327	Economy	67800.00
0005433261754	1327	Economy	67800.00
0005432279329	1327	Economy	67800.00
0005434964721	1327	Economy	67800.00
0005432279331	1327	Economy	67800.00
0005433261751	1327	Economy	67800.00
0005434964714	1327	Economy	67800.00
0005434964716	1327	Economy	67800.00
0005434964728	1327	Economy	67800.00
0005434964717	1327	Economy	67800.00
0005433261828	18238	Business	203300.00
0005434964592	18238	Business	203300.00
0005434964543	18238	Business	203300.00
0005434964494	18238	Business	203300.00
0005434964514	18238	Business	203300.00
0005434964565	18238	Business	203300.00
0005434964542	18238	Business	203300.00
0005434964666	18238	Economy	74500.00
0005434964555	18238	Economy	67800.00
0005433261836	18238	Economy	67800.00
0005434964503	18238	Economy	67800.00
0005434964675	18238	Economy	67800.00
0005434964557	18238	Economy	67800.00
0005433261839	18238	Economy	67800.00
0005434964530	18238	Economy	67800.00
0005434964502	18238	Economy	67800.00
0005434964511	18238	Economy	67800.00
0005433261831	18238	Economy	67800.00
0005434964674	18238	Economy	67800.00
0005434964609	18238	Economy	67800.00
0005434964500	18238	Economy	67800.00
0005433261834	18238	Economy	67800.00
0005434964584	18238	Economy	67800.00
0005433261826	18238	Economy	67800.00
0005434964610	18238	Economy	67800.00
0005434964513	18238	Economy	67800.00
0005434964529	18238	Economy	67800.00
0005434964493	18238	Economy	67800.00
0005434964547	18238	Economy	67800.00
0005434964561	18238	Economy	67800.00
0005434964552	18238	Economy	67800.00
0005433261830	18238	Economy	67800.00
0005433261838	18238	Economy	67800.00
0005434964465	18238	Economy	67800.00
0005434964615	18238	Economy	67800.00
0005433261829	18238	Economy	67800.00
0005434964556	18238	Economy	67800.00
0005434964515	18238	Economy	67800.00
0005434964512	18238	Economy	67800.00
0005433261837	18238	Economy	67800.00
0005434964490	18238	Economy	67800.00
0005433261827	18238	Economy	67800.00
0005434964603	18238	Economy	67800.00
0005434964507	18238	Economy	67800.00
0005434964522	18238	Economy	67800.00
0005434964501	18238	Economy	67800.00
0005434964558	18238	Economy	67800.00
0005434964665	18238	Economy	67800.00
0005433261825	18238	Economy	67800.00
0005434964546	18238	Economy	67800.00
0005434964497	18238	Economy	67800.00
0005433261832	18238	Economy	67800.00
0005433261840	18238	Economy	67800.00
0005434964545	18238	Economy	67800.00
0005433261833	18238	Economy	67800.00
0005434964516	18238	Economy	67800.00
0005433261835	18238	Economy	67800.00
0005434964554	18238	Economy	67800.00
0005434964508	18238	Economy	67800.00
0005434964562	18238	Economy	67800.00
0005434626211	4850	Business	44200.00
0005434626219	4850	Business	44200.00
0005434626217	4850	Economy	14700.00
0005435907595	4850	Economy	14700.00
0005433194895	4850	Economy	16200.00
0005435907604	4850	Economy	16200.00
0005434626215	4850	Economy	14700.00
0005434626212	4850	Economy	14700.00
0005435907606	4850	Economy	14700.00
0005434626213	4850	Economy	14700.00
0005435907605	4850	Economy	14700.00
0005434626218	4850	Economy	14700.00
0005434626214	4850	Economy	14700.00
0005434626216	4850	Economy	14700.00
0005433194904	4850	Economy	14700.00
0005435907601	4850	Economy	14700.00
0005433194913	4850	Economy	14700.00
0005435907640	32924	Business	44200.00
0005434626154	32924	Economy	14700.00
0005434626129	32924	Economy	14700.00
0005434626115	32924	Economy	14700.00
0005433194954	32924	Economy	14700.00
0005433194949	32924	Economy	16200.00
0005434626116	32924	Economy	16200.00
0005434626131	32924	Economy	14700.00
0005434626152	32924	Economy	14700.00
0005434626133	32924	Economy	14700.00
0005433194960	32924	Economy	14700.00
0005434626134	32924	Economy	14700.00
0005433194951	32924	Economy	14700.00
0005433194952	32924	Economy	14700.00
0005433194957	32924	Economy	14700.00
0005434626130	32924	Economy	14700.00
0005433194959	32924	Economy	14700.00
0005434626148	32924	Economy	14700.00
0005433194947	32924	Economy	14700.00
0005435907641	32924	Economy	14700.00
0005434626132	32924	Economy	14700.00
0005434626155	32924	Economy	14700.00
0005434626144	32924	Economy	14700.00
0005433194953	32924	Economy	14700.00
0005433194956	32924	Economy	14700.00
0005435907638	32924	Economy	14700.00
0005434626097	32924	Economy	14700.00
0005433194948	32924	Economy	14700.00
0005433194955	32924	Economy	14700.00
0005433194958	32924	Economy	14700.00
0005433194950	32924	Economy	14700.00
0005434626135	32924	Economy	14700.00
0005435907639	32924	Economy	14700.00
0005435786010	13764	Economy	3400.00
0005435785851	13764	Economy	3400.00
0005435785957	13764	Economy	3400.00
0005435937530	13764	Economy	3400.00
0005435785981	13764	Economy	3100.00
0005435785828	13764	Economy	3100.00
0005435785947	13764	Economy	3100.00
0005435937532	13764	Economy	3100.00
0005435937538	13764	Economy	3100.00
0005435937537	13764	Economy	3100.00
0005435786009	13764	Economy	3100.00
0005435937540	13764	Economy	3100.00
0005435785948	13764	Economy	3100.00
0005435937533	13764	Economy	3100.00
0005435785850	13764	Economy	3100.00
0005435937534	13764	Economy	3100.00
0005435786033	13764	Economy	3100.00
0005435785936	13764	Economy	3100.00
0005435786011	13764	Economy	3100.00
0005435787383	13764	Economy	3100.00
0005435785721	13764	Economy	3100.00
0005435937531	13764	Economy	3100.00
0005435785779	13764	Economy	3100.00
0005432195751	13764	Economy	3100.00
0005435785942	13764	Economy	3100.00
0005435785720	13764	Economy	3100.00
0005435785829	13764	Economy	3100.00
0005435785722	13764	Economy	3100.00
0005435786067	13764	Economy	3100.00
0005435785968	13764	Economy	3100.00
0005435786015	13764	Economy	3100.00
0005435937539	13764	Economy	3100.00
0005435786021	13764	Economy	3100.00
0005435786032	13764	Economy	3100.00
0005435937536	13764	Economy	3100.00
0005435785976	13764	Economy	3100.00
0005435786058	13764	Economy	3100.00
0005435787384	13764	Economy	3100.00
0005435787382	13764	Economy	3100.00
0005435786057	13764	Economy	3100.00
0005435785907	13764	Economy	3100.00
0005435937541	13764	Economy	3100.00
0005435937535	13764	Economy	3100.00
0005435785918	13764	Economy	3100.00
0005435785791	13764	Economy	3100.00
0005435785980	13764	Economy	3100.00
0005435785956	13764	Economy	3100.00
0005435785975	13764	Economy	3100.00
0005435785860	13764	Economy	3100.00
0005435786027	13764	Economy	3100.00
0005435786247	27413	Economy	3400.00
0005435786229	27413	Economy	3400.00
0005435937447	27413	Economy	3400.00
0005435786232	27413	Economy	3400.00
0005435786237	27413	Economy	3100.00
0005435786219	27413	Economy	3100.00
0005435786223	27413	Economy	3100.00
0005435786246	27413	Economy	3100.00
0005435786224	27413	Economy	3100.00
0005435937446	27413	Economy	3100.00
0005435786220	27413	Economy	3100.00
0005435787409	27413	Economy	3100.00
0005435786245	27413	Economy	3100.00
0005435786227	27413	Economy	3100.00
0005435786225	27413	Economy	3100.00
0005435786243	27413	Economy	3100.00
0005435786221	27413	Economy	3100.00
0005435786231	27413	Economy	3100.00
0005435786241	27413	Economy	3100.00
0005435786235	27413	Economy	3100.00
0005432190728	27413	Economy	3100.00
0005435786236	27413	Economy	3100.00
0005435787408	27413	Economy	3100.00
0005435786233	27413	Economy	3100.00
0005435937452	27413	Economy	3100.00
0005435786226	27413	Economy	3100.00
0005432190727	27413	Economy	3100.00
0005435786244	27413	Economy	3100.00
0005435786218	27413	Economy	3100.00
0005435786248	27413	Economy	3100.00
0005435937454	27413	Economy	3100.00
0005435937445	27413	Economy	3100.00
0005435786222	27413	Economy	3100.00
0005435786238	27413	Economy	3100.00
0005432190725	27413	Economy	3100.00
0005435786228	27413	Economy	3100.00
0005435786234	27413	Economy	3100.00
0005435786242	27413	Economy	3100.00
0005435786240	27413	Economy	3100.00
0005435937453	27413	Economy	3100.00
0005432190726	27413	Economy	3100.00
0005435787407	27413	Economy	3100.00
0005435786230	27413	Economy	3100.00
0005435786239	27413	Economy	3100.00
0005435311475	20297	Business	12000.00
0005434408467	20297	Business	12000.00
0005434408778	20297	Business	12000.00
0005434408847	20297	Business	12000.00
0005434408910	20297	Business	12000.00
0005434408926	20297	Business	12000.00
0005435311470	20297	Business	12000.00
0005434408833	20297	Business	12000.00
0005435311468	20297	Business	12000.00
0005434409039	20297	Business	12000.00
0005434408997	20297	Business	12000.00
0005434408861	20297	Business	12000.00
0005434409093	20297	Economy	4000.00
0005434408794	20297	Economy	4000.00
0005434409094	20297	Economy	4000.00
0005434408772	20297	Economy	4000.00
0005434408489	20297	Economy	4000.00
0005434409003	20297	Economy	4000.00
0005434409086	20297	Economy	4000.00
0005434409054	20297	Economy	4000.00
0005434408922	20297	Economy	4000.00
0005434408860	20297	Economy	4400.00
0005434408806	20297	Economy	4400.00
0005434408859	20297	Economy	4400.00
0005434408871	20297	Economy	4400.00
0005434409040	20297	Economy	4000.00
0005435311473	20297	Economy	4000.00
0005434409107	20297	Economy	4000.00
0005434408880	20297	Economy	4000.00
0005434409076	20297	Economy	4000.00
0005434408911	20297	Economy	4000.00
0005435311471	20297	Economy	4000.00
0005434409026	20297	Economy	4000.00
0005434408752	20297	Economy	4000.00
0005434408675	20297	Economy	4000.00
0005434408837	20297	Economy	4000.00
0005434408966	20297	Economy	4000.00
0005434409008	20297	Economy	4000.00
0005434408947	20297	Economy	4000.00
0005434409053	20297	Economy	4000.00
0005434408979	20297	Economy	4000.00
0005435311474	20297	Economy	4000.00
0005434408908	20297	Economy	4000.00
0005434408890	20297	Economy	4000.00
0005434408674	20297	Economy	4000.00
0005434408949	20297	Economy	4000.00
0005434408646	20297	Economy	4000.00
0005434409041	20297	Economy	4000.00
0005434409085	20297	Economy	4000.00
0005432058489	20297	Economy	4000.00
0005434408832	20297	Economy	4000.00
0005434408959	20297	Economy	4000.00
0005434408751	20297	Economy	4000.00
0005434409096	20297	Economy	4000.00
0005435311469	20297	Economy	4000.00
0005434408736	20297	Economy	4000.00
0005434409064	20297	Economy	4000.00
0005434408862	20297	Economy	4000.00
0005434408945	20297	Economy	4000.00
0005434408779	20297	Economy	4000.00
0005434409052	20297	Economy	4000.00
0005434408488	20297	Economy	4000.00
0005434408671	20297	Economy	4000.00
0005434408932	20297	Economy	4000.00
0005434409077	20297	Economy	4000.00
0005434409190	20297	Economy	4000.00
0005434409014	20297	Economy	4000.00
0005435311472	20297	Economy	4000.00
0005434408796	20297	Economy	4000.00
0005434408848	20297	Economy	4000.00
0005434409188	20297	Economy	4000.00
0005434408872	20297	Economy	4000.00
0005434408843	20297	Economy	4000.00
0005434408466	20297	Economy	4000.00
0005434408780	20297	Economy	4000.00
0005434408863	20297	Economy	4000.00
0005434409189	20297	Economy	4000.00
0005434408849	20297	Economy	4000.00
0005434408665	20297	Economy	4000.00
0005434408870	20297	Economy	4000.00
0005432058488	20297	Economy	4000.00
0005435311476	20297	Economy	4000.00
0005434409065	20297	Economy	4000.00
0005434408834	20297	Economy	4000.00
0005434408978	20297	Economy	4000.00
0005434408793	20297	Economy	4000.00
0005435311467	20297	Economy	4000.00
0005434408912	20297	Economy	4000.00
0005434409063	20297	Economy	4000.00
0005434409432	26963	Business	12000.00
0005434409442	26963	Business	12000.00
0005434409418	26963	Business	12000.00
0005434409435	26963	Business	12000.00
0005434409408	26963	Business	12000.00
0005434409416	26963	Business	12000.00
0005435311311	26963	Business	12000.00
0005434409439	26963	Business	12000.00
0005434409422	26963	Economy	4000.00
0005434409456	26963	Economy	4000.00
0005435311161	26963	Economy	4000.00
0005434409443	26963	Economy	4000.00
0005434409411	26963	Economy	4000.00
0005434409459	26963	Economy	4000.00
0005434409453	26963	Economy	4000.00
0005434409436	26963	Economy	4000.00
0005434409427	26963	Economy	4000.00
0005434409451	26963	Economy	4000.00
0005435311264	26963	Economy	4400.00
0005434409425	26963	Economy	4400.00
0005434409433	26963	Economy	4400.00
0005434409419	26963	Economy	4400.00
0005434409448	26963	Economy	4400.00
0005434409412	26963	Economy	4000.00
0005434409424	26963	Economy	4000.00
0005434409455	26963	Economy	4000.00
0005434409429	26963	Economy	4000.00
0005432154123	26963	Economy	4000.00
0005434409407	26963	Economy	4000.00
0005434409438	26963	Economy	4000.00
0005435311274	26963	Economy	4000.00
0005434409434	26963	Economy	4000.00
0005434409437	26963	Economy	4000.00
0005435311292	26963	Economy	4000.00
0005435311300	26963	Economy	4000.00
0005435311280	26963	Economy	4000.00
0005432154126	26963	Economy	4000.00
0005434409413	26963	Economy	4000.00
0005435311322	26963	Economy	4000.00
0005434409423	26963	Economy	4000.00
0005434409450	26963	Economy	4000.00
0005435311251	26963	Economy	4000.00
0005432154125	26963	Economy	4000.00
0005434409447	26963	Economy	4000.00
0005435311286	26963	Economy	4000.00
0005434409417	26963	Economy	4000.00
0005435311383	26963	Economy	4000.00
0005434409454	26963	Economy	4000.00
0005434409458	26963	Economy	4000.00
0005434409415	26963	Economy	4000.00
0005434409405	26963	Economy	4000.00
0005435311248	26963	Economy	4000.00
0005434409445	26963	Economy	4000.00
0005434409409	26963	Economy	4000.00
0005435311263	26963	Economy	4000.00
0005434409440	26963	Economy	4000.00
0005434409430	26963	Economy	4000.00
0005432154127	26963	Economy	4000.00
0005435311340	26963	Economy	4000.00
0005434409414	26963	Economy	4000.00
0005434409452	26963	Economy	4000.00
0005434409410	26963	Economy	4000.00
0005434409420	26963	Economy	4000.00
0005434409428	26963	Economy	4000.00
0005435311335	26963	Economy	4000.00
0005435311277	26963	Economy	4000.00
0005434409446	26963	Economy	4000.00
0005434409441	26963	Economy	4000.00
0005432154124	26963	Economy	4000.00
0005434409444	26963	Economy	4000.00
0005434409449	26963	Economy	4000.00
0005434409431	26963	Economy	4000.00
0005434409406	26963	Economy	4000.00
0005435311288	26963	Economy	4000.00
0005434409457	26963	Economy	4000.00
0005435311310	26963	Economy	4000.00
0005434409421	26963	Economy	4000.00
0005434409426	26963	Economy	4000.00
0005434319784	5697	Business	43300.00
0005434319780	5697	Business	43300.00
0005434319779	5697	Business	43300.00
0005434319781	5697	Business	43300.00
0005433124383	5697	Economy	14400.00
0005433124290	5697	Economy	14400.00
0005433124361	5697	Economy	14400.00
0005433124303	5697	Economy	14400.00
0005432109777	5697	Economy	14400.00
0005433124240	5697	Economy	14400.00
0005433124300	5697	Economy	14400.00
0005433124320	5697	Economy	15900.00
0005433124296	5697	Economy	15900.00
0005433124282	5697	Economy	14400.00
0005433124295	5697	Economy	14400.00
0005434319782	5697	Economy	14400.00
0005433124301	5697	Economy	14400.00
0005434311288	5697	Economy	14400.00
0005433124226	5697	Economy	14400.00
0005434319785	5697	Economy	14400.00
0005434319776	5697	Economy	14400.00
0005434319777	5697	Economy	14400.00
0005434319773	5697	Economy	14400.00
0005433124205	5697	Economy	14400.00
0005433124243	5697	Economy	14400.00
0005433124304	5697	Economy	14400.00
0005434319783	5697	Economy	14400.00
0005433124217	5697	Economy	14400.00
0005433124266	5697	Economy	14400.00
0005433124289	5697	Economy	14400.00
0005434311273	5697	Economy	14400.00
0005434319772	5697	Economy	14400.00
0005432109778	5697	Economy	14400.00
0005433124291	5697	Economy	14400.00
0005433124360	5697	Economy	14400.00
0005433124281	5697	Economy	14400.00
0005433124216	5697	Economy	14400.00
0005433124319	5697	Economy	14400.00
0005434319775	5697	Economy	14400.00
0005433124227	5697	Economy	14400.00
0005433124384	5697	Economy	14400.00
0005434311272	5697	Economy	14400.00
0005433124278	5697	Economy	14400.00
0005432109776	5697	Economy	14400.00
0005433124225	5697	Economy	14400.00
0005433124180	5697	Economy	14400.00
0005434311274	5697	Economy	14400.00
0005433124305	5697	Economy	14400.00
0005434319778	5697	Economy	14400.00
0005434319774	5697	Economy	14400.00
0005433124486	15670	Business	43300.00
0005433124471	15670	Business	43300.00
0005434319702	15670	Business	43300.00
0005433124488	15670	Business	43300.00
0005435297369	15670	Business	43300.00
0005433124467	15670	Business	43300.00
0005433124475	15670	Business	43300.00
0005435297366	15670	Economy	14400.00
0005434319678	15670	Economy	14400.00
0005434311258	15670	Economy	14400.00
0005434312357	15670	Economy	14400.00
0005433124483	15670	Economy	14400.00
0005433124470	15670	Economy	14400.00
0005434319613	15670	Economy	14400.00
0005434311261	15670	Economy	14400.00
0005433124481	15670	Economy	15900.00
0005433124473	15670	Economy	14400.00
0005435297371	15670	Economy	14400.00
0005435297368	15670	Economy	14400.00
0005434319628	15670	Economy	14400.00
0005434319634	15670	Economy	14400.00
0005433124479	15670	Economy	14400.00
0005434319645	15670	Economy	14400.00
0005435297364	15670	Economy	14400.00
0005433124485	15670	Economy	14400.00
0005434319663	15670	Economy	14400.00
0005435297370	15670	Economy	14400.00
0005435297374	15670	Economy	14400.00
0005434319633	15670	Economy	14400.00
0005435297372	15670	Economy	14400.00
0005434319626	15670	Economy	14400.00
0005434319612	15670	Economy	14400.00
0005433124477	15670	Economy	14400.00
0005434319679	15670	Economy	14400.00
0005433124476	15670	Economy	14400.00
0005434319677	15670	Economy	14400.00
0005435297367	15670	Economy	14400.00
0005433124474	15670	Economy	14400.00
0005433124480	15670	Economy	14400.00
0005433124478	15670	Economy	14400.00
0005433124487	15670	Economy	14400.00
0005433124482	15670	Economy	14400.00
0005435297373	15670	Economy	14400.00
0005433124489	15670	Economy	14400.00
0005433124469	15670	Economy	14400.00
0005435297365	15670	Economy	14400.00
0005433124472	15670	Economy	14400.00
0005434319651	15670	Economy	14400.00
0005433124484	15670	Economy	14400.00
0005433124468	15670	Economy	14400.00
0005434319644	15670	Economy	14400.00
0005435220357	24983	Economy	15500.00
0005435220353	24983	Economy	15500.00
0005435217750	24983	Economy	15500.00
0005435217749	24983	Economy	15500.00
0005435220360	24983	Economy	15500.00
0005435220362	24983	Economy	15500.00
0005435217751	24983	Economy	15500.00
0005435220361	24983	Economy	15500.00
0005434484525	8955	Economy	27400.00
0005434484524	8955	Economy	24900.00
0005434484523	8955	Economy	24900.00
0005434189296	8955	Economy	24900.00
0005434484521	8955	Economy	24900.00
0005434189280	8955	Economy	24900.00
0005434484522	8955	Economy	24900.00
0005434189292	8955	Economy	24900.00
0005434189306	8955	Economy	24900.00
0005434484448	16609	Economy	24900.00
0005434189330	16609	Economy	24900.00
0005434484482	16609	Economy	24900.00
0005434484449	16609	Economy	24900.00
0005434484452	16609	Economy	24900.00
0005434189331	16609	Economy	24900.00
0005434484453	16609	Economy	24900.00
0005433124478	7560	Business	11100.00
0005433124468	7560	Business	11100.00
0005433722335	7560	Business	11100.00
0005433124476	7560	Business	11100.00
0005433124475	7560	Business	11100.00
0005433124485	7560	Business	11100.00
0005433722321	7560	Business	11100.00
0005433124470	7560	Economy	3700.00
0005433124486	7560	Economy	3700.00
0005433124472	7560	Economy	3700.00
0005433722316	7560	Economy	3700.00
0005433124467	7560	Economy	3700.00
0005433124483	7560	Economy	3700.00
0005433124479	7560	Economy	3700.00
0005433124488	7560	Economy	3700.00
0005433124489	7560	Economy	3700.00
0005433124474	7560	Economy	3700.00
0005433722336	7560	Economy	3700.00
0005433124482	7560	Economy	3700.00
0005433124484	7560	Economy	3700.00
0005433124477	7560	Economy	3700.00
0005433124480	7560	Economy	3700.00
0005433124471	7560	Economy	3700.00
0005433124469	7560	Economy	3700.00
0005433124473	7560	Economy	3700.00
0005433124481	7560	Economy	3700.00
0005433124487	7560	Economy	3700.00
0005432693887	7554	Business	11100.00
0005432721613	7554	Business	11100.00
0005433450553	7554	Business	11100.00
0005432721616	7554	Business	11100.00
0005432721609	7554	Business	11100.00
0005432721623	7554	Business	11100.00
0005432693898	7554	Business	11100.00
0005432693888	7554	Business	11100.00
0005432721619	7554	Business	11100.00
0005432721611	7554	Economy	3700.00
0005432721625	7554	Economy	3700.00
0005432693896	7554	Economy	3700.00
0005433450555	7554	Economy	3700.00
0005432721618	7554	Economy	3700.00
0005432071652	7554	Economy	3700.00
0005433450545	7554	Economy	4100.00
0005432693876	7554	Economy	4100.00
0005433450557	7554	Economy	4100.00
0005432721615	7554	Economy	3700.00
0005432693886	7554	Economy	3700.00
0005432721620	7554	Economy	3700.00
0005432693891	7554	Economy	3700.00
0005432693884	7554	Economy	3700.00
0005432721621	7554	Economy	3700.00
0005433450540	7554	Economy	3700.00
0005432693892	7554	Economy	3700.00
0005432693901	7554	Economy	3700.00
0005432693890	7554	Economy	3700.00
0005433450541	7554	Economy	3700.00
0005433450544	7554	Economy	3700.00
0005432721626	7554	Economy	3700.00
0005432693895	7554	Economy	3700.00
0005432693883	7554	Economy	3700.00
0005432721617	7554	Economy	3700.00
0005432693878	7554	Economy	3700.00
0005433450547	7554	Economy	3700.00
0005432693893	7554	Economy	3700.00
0005432693885	7554	Economy	3700.00
0005432721622	7554	Economy	3700.00
0005433450550	7554	Economy	3700.00
0005432693899	7554	Economy	3700.00
0005432693879	7554	Economy	3700.00
0005432693894	7554	Economy	3700.00
0005433450548	7554	Economy	3700.00
0005432693897	7554	Economy	3700.00
0005432693889	7554	Economy	3700.00
0005432693877	7554	Economy	3700.00
0005433450549	7554	Economy	3700.00
0005433450554	7554	Economy	3700.00
0005432721612	7554	Economy	3700.00
0005432693881	7554	Economy	3700.00
0005432693902	7554	Economy	3700.00
0005433450556	7554	Economy	3700.00
0005432693880	7554	Economy	3700.00
0005432693882	7554	Economy	3700.00
0005433450551	7554	Economy	3700.00
0005432693900	7554	Economy	3700.00
0005433450546	7554	Economy	3700.00
0005432721614	7554	Economy	3700.00
0005433450542	7554	Economy	3700.00
0005433450543	7554	Economy	3700.00
0005432071653	7554	Economy	3700.00
0005432721610	7554	Economy	3700.00
0005433450552	7554	Economy	3700.00
0005432721624	7554	Economy	3700.00
0005433450417	30398	Business	11100.00
0005433450356	30398	Business	11100.00
0005432693641	30398	Business	11100.00
0005433450378	30398	Business	11100.00
0005432693546	30398	Business	11100.00
0005433450414	30398	Business	11100.00
0005432693540	30398	Business	11100.00
0005432693679	30398	Economy	3700.00
0005433450406	30398	Economy	3700.00
0005432693647	30398	Economy	3700.00
0005432693541	30398	Economy	3700.00
0005432693539	30398	Economy	3700.00
0005433450486	30398	Economy	3700.00
0005433450233	30398	Economy	3700.00
0005432693578	30398	Economy	3700.00
0005432693552	30398	Economy	3700.00
0005433450322	30398	Economy	3700.00
0005432693551	30398	Economy	3700.00
0005432693490	30398	Economy	3700.00
0005433450379	30398	Economy	3700.00
0005433450446	30398	Economy	3700.00
0005433450281	30398	Economy	3700.00
0005432693678	30398	Economy	3700.00
0005433450424	30398	Economy	3700.00
0005433450280	30398	Economy	3700.00
0005432693654	30398	Economy	3700.00
0005433450444	30398	Economy	3700.00
0005433450354	30398	Economy	3700.00
0005433450423	30398	Economy	3700.00
0005433450278	30398	Economy	3700.00
0005432693555	30398	Economy	3700.00
0005433450358	30398	Economy	3700.00
0005433450319	30398	Economy	3700.00
0005432693705	30398	Economy	3700.00
0005432693579	30398	Economy	3700.00
0005432693525	30398	Economy	3700.00
0005433450405	30398	Economy	3700.00
0005433450277	30398	Economy	3700.00
0005432693524	30398	Economy	3700.00
0005432693573	30398	Economy	3700.00
0005432693489	30398	Economy	3700.00
0005433450415	30398	Economy	3700.00
0005433450441	30398	Economy	3700.00
0005432693615	30398	Economy	3700.00
0005432693563	30398	Economy	3700.00
0005432693553	30398	Economy	3700.00
0005433450355	30398	Economy	3700.00
0005432693649	30398	Economy	3700.00
0005432693648	30398	Economy	3700.00
0005433450425	30398	Economy	3700.00
0005432693661	30398	Economy	3700.00
0005433450416	30398	Economy	3700.00
0005432693556	30398	Economy	3700.00
0005432693598	30398	Economy	3700.00
0005432693562	30398	Economy	3700.00
0005432693545	30398	Economy	3700.00
0005432693599	30398	Economy	3700.00
0005433450276	30398	Economy	3700.00
0005432693635	30398	Economy	3700.00
0005432721300	30397	Business	11100.00
0005433124225	30397	Business	11100.00
0005432721393	30397	Business	11100.00
0005432721394	30397	Business	11100.00
0005432721423	30397	Business	11100.00
0005433124281	30397	Business	11100.00
0005433124300	30397	Business	11100.00
0005433722412	30397	Business	11100.00
0005432721415	30397	Business	11100.00
0005433124296	30397	Economy	3700.00
0005433124361	30397	Economy	3700.00
0005432721461	30397	Economy	3700.00
0005433722425	30397	Economy	3700.00
0005432721346	30397	Economy	4100.00
0005433124291	30397	Economy	4100.00
0005432721424	30397	Economy	4100.00
0005432721462	30397	Economy	4100.00
0005433124243	30397	Economy	4100.00
0005433124320	30397	Economy	3700.00
0005433124360	30397	Economy	3700.00
0005433722417	30397	Economy	3700.00
0005433722420	30397	Economy	3700.00
0005433124240	30397	Economy	3700.00
0005432721434	30397	Economy	3700.00
0005432721464	30397	Economy	3700.00
0005433124295	30397	Economy	3700.00
0005433722418	30397	Economy	3700.00
0005432721422	30397	Economy	3700.00
0005433124227	30397	Economy	3700.00
0005433124305	30397	Economy	3700.00
0005433124303	30397	Economy	3700.00
0005433722414	30397	Economy	3700.00
0005433722415	30397	Economy	3700.00
0005433124289	30397	Economy	3700.00
0005433722424	30397	Economy	3700.00
0005432721395	30397	Economy	3700.00
0005432721271	30397	Economy	3700.00
0005433124384	30397	Economy	3700.00
0005433124217	30397	Economy	3700.00
0005433124319	30397	Economy	3700.00
0005433722413	30397	Economy	3700.00
0005433124290	30397	Economy	3700.00
0005432721391	30397	Economy	3700.00
0005433722422	30397	Economy	3700.00
0005432721498	30397	Economy	3700.00
0005433124301	30397	Economy	3700.00
0005433124383	30397	Economy	3700.00
0005432721453	30397	Economy	3700.00
0005433124266	30397	Economy	3700.00
0005433124278	30397	Economy	3700.00
0005433722419	30397	Economy	3700.00
0005433124180	30397	Economy	3700.00
0005433124226	30397	Economy	3700.00
0005433722421	30397	Economy	3700.00
0005433124304	30397	Economy	3700.00
0005433124205	30397	Economy	3700.00
0005432721452	30397	Economy	3700.00
0005433722426	30397	Economy	3700.00
0005433722410	30397	Economy	3700.00
0005433722416	30397	Economy	3700.00
0005433722423	30397	Economy	3700.00
0005433124216	30397	Economy	3700.00
0005433722411	30397	Economy	3700.00
0005433124282	30397	Economy	3700.00
0005434587289	1404	Business	70400.00
0005433525326	1404	Business	70400.00
0005433525332	1404	Business	70400.00
0005434587302	1404	Business	70400.00
0005432928078	1404	Business	70400.00
0005433193274	1404	Business	70400.00
0005434587300	1404	Business	70400.00
0005433193265	1404	Business	70400.00
0005434587290	1404	Business	70400.00
0005434587304	1404	Economy	23500.00
0005433525330	1404	Economy	23500.00
0005434587292	1404	Economy	23500.00
0005434515038	1404	Economy	23500.00
0005432928069	1404	Economy	23500.00
0005434587305	1404	Economy	23500.00
0005433193301	1404	Economy	25800.00
0005433525333	1404	Economy	25800.00
0005433193313	1404	Economy	25800.00
0005434587288	1404	Economy	23500.00
0005432928101	1404	Economy	23500.00
0005433525331	1404	Economy	23500.00
0005434587291	1404	Economy	23500.00
0005434587306	1404	Economy	23500.00
0005433724926	1404	Economy	23500.00
0005433525334	1404	Economy	23500.00
0005434515040	1404	Economy	23500.00
0005434587286	1404	Economy	23500.00
0005434515037	1404	Economy	23500.00
0005434587295	1404	Economy	23500.00
0005433193259	1404	Economy	23500.00
0005433193312	1404	Economy	23500.00
0005433724927	1404	Economy	23500.00
0005434587284	1404	Economy	23500.00
0005433525327	1404	Economy	23500.00
0005432968872	1404	Economy	23500.00
0005433525329	1404	Economy	23500.00
0005433193303	1404	Economy	23500.00
0005434587287	1404	Economy	23500.00
0005433193302	1404	Economy	23500.00
0005433193305	1404	Economy	23500.00
0005434587297	1404	Economy	23500.00
0005433193297	1404	Economy	23500.00
0005434587303	1404	Economy	23500.00
0005432928083	1404	Economy	23500.00
0005434513650	1404	Economy	23500.00
0005433193314	1404	Economy	23500.00
0005433193300	1404	Economy	23500.00
0005434515039	1404	Economy	23500.00
0005432968880	1404	Economy	23500.00
0005432271078	1404	Economy	23500.00
0005434587294	1404	Economy	23500.00
0005433193287	1404	Economy	23500.00
0005433193288	1404	Economy	23500.00
0005433525328	1404	Economy	23500.00
0005434587296	1404	Economy	23500.00
0005434587298	1404	Economy	23500.00
0005433724925	1404	Economy	23500.00
0005434587307	1404	Economy	23500.00
0005434587301	1404	Economy	23500.00
0005432928079	1404	Economy	23500.00
0005432928077	1404	Economy	23500.00
0005434587299	1404	Economy	23500.00
0005434587285	1404	Economy	23500.00
0005434587293	1404	Economy	23500.00
0005433193324	1404	Economy	23500.00
0005432928098	1404	Economy	23500.00
0005433193283	1404	Economy	23500.00
0005433193325	1404	Economy	23500.00
0005432271079	1404	Economy	23500.00
0005433193306	1404	Economy	23500.00
0005432968901	18517	Business	70400.00
0005433525176	18517	Business	70400.00
0005434587186	18517	Business	70400.00
0005432968903	18517	Business	70400.00
0005433525251	18517	Business	70400.00
0005434515006	18517	Business	70400.00
0005432928129	18517	Business	70400.00
0005432928128	18517	Economy	23500.00
0005433724873	18517	Economy	23500.00
0005433525250	18517	Economy	23500.00
0005433193396	18517	Economy	23500.00
0005433193402	18517	Economy	23500.00
0005434587004	18517	Economy	25800.00
0005433525234	18517	Economy	25800.00
0005433724893	18517	Economy	25800.00
0005433193398	18517	Economy	25800.00
0005433193400	18517	Economy	25800.00
0005434587084	18517	Economy	23500.00
0005433525235	18517	Economy	23500.00
0005433525233	18517	Economy	23500.00
0005432968902	18517	Economy	23500.00
0005433193401	18517	Economy	23500.00
0005433193403	18517	Economy	23500.00
0005434587137	18517	Economy	23500.00
0005434587117	18517	Economy	23500.00
0005434587118	18517	Economy	23500.00
0005433525260	18517	Economy	23500.00
0005432928130	18517	Economy	23500.00
0005433525247	18517	Economy	23500.00
0005434587005	18517	Economy	23500.00
0005434587139	18517	Economy	23500.00
0005433525259	18517	Economy	23500.00
0005434587042	18517	Economy	23500.00
0005434587093	18517	Economy	23500.00
0005434587116	18517	Economy	23500.00
0005433193397	18517	Economy	23500.00
0005433525246	18517	Economy	23500.00
0005433724864	18517	Economy	23500.00
0005433193399	18517	Economy	23500.00
0005433724880	18517	Economy	23500.00
0005434587014	18517	Economy	23500.00
0005433525231	18517	Economy	23500.00
0005434586987	18517	Economy	23500.00
0005432968900	18517	Economy	23500.00
0005432928127	18517	Economy	23500.00
0005434587013	18517	Economy	23500.00
0005433724872	18517	Economy	23500.00
0005433525248	18517	Economy	23500.00
0005433525258	18517	Economy	23500.00
0005434586995	18517	Economy	23500.00
0005434345135	11446	Economy	4300.00
0005434345116	11446	Economy	4300.00
0005434345133	11446	Economy	4300.00
0005435302296	11446	Economy	4300.00
0005435302297	11446	Economy	4000.00
0005434345134	11446	Economy	4000.00
0005434345152	11446	Economy	4000.00
0005434142718	11446	Economy	4000.00
0005434345117	11446	Economy	4000.00
0005434345151	11446	Economy	4000.00
0005434345148	11446	Economy	4000.00
0005434345141	11446	Economy	4000.00
0005434345123	11446	Economy	4000.00
0005434345129	11446	Economy	4000.00
0005434345143	11446	Economy	4000.00
0005434142717	11446	Economy	4000.00
0005434345137	11446	Economy	4000.00
0005434345142	11446	Economy	4000.00
0005434142715	11446	Economy	4000.00
0005434345139	11446	Economy	4000.00
0005434345122	11446	Economy	4000.00
0005434345140	11446	Economy	4000.00
0005435302274	11446	Economy	4000.00
0005434345132	11446	Economy	4000.00
0005434345144	11446	Economy	4000.00
0005434345126	11446	Economy	4000.00
0005434345125	11446	Economy	4000.00
0005435302259	11446	Economy	4000.00
0005434345136	11446	Economy	4000.00
0005435302267	11446	Economy	4000.00
0005434345149	11446	Economy	4000.00
0005434345118	11446	Economy	4000.00
0005434345146	11446	Economy	4000.00
0005434345150	11446	Economy	4000.00
0005434345128	11446	Economy	4000.00
0005434345127	11446	Economy	4000.00
0005434345124	11446	Economy	4000.00
0005434345147	11446	Economy	4000.00
0005434345138	11446	Economy	4000.00
0005434142716	11446	Economy	4000.00
0005434345119	11446	Economy	4000.00
0005434345130	11446	Economy	4000.00
0005434345121	11446	Economy	4000.00
0005434345115	11446	Economy	4000.00
0005434345120	11446	Economy	4000.00
0005434345145	11446	Economy	4000.00
0005434345131	11446	Economy	4000.00
0005434344895	29767	Economy	4300.00
0005434344785	29767	Economy	4300.00
0005434344805	29767	Economy	4300.00
0005434344954	29767	Economy	4000.00
0005434142678	29767	Economy	4000.00
0005434345030	29767	Economy	4000.00
0005434344896	29767	Economy	4000.00
0005434344795	29767	Economy	4000.00
0005434344953	29767	Economy	4000.00
0005434344864	29767	Economy	4000.00
0005434344724	29767	Economy	4000.00
0005434344955	29767	Economy	4000.00
0005434344866	29767	Economy	4000.00
0005434344678	29767	Economy	4000.00
0005434344985	29767	Economy	4000.00
0005434344853	29767	Economy	4000.00
0005434344670	29767	Economy	4000.00
0005434344677	29767	Economy	4000.00
0005434344819	29767	Economy	4000.00
0005434344894	29767	Economy	4000.00
0005434344671	29767	Economy	4000.00
0005434344859	29767	Economy	4000.00
0005434344852	29767	Economy	4000.00
0005434344957	29767	Economy	4000.00
0005434344786	29767	Economy	4000.00
0005435304263	29767	Economy	4000.00
0005434344941	29767	Economy	4000.00
0005435305070	29767	Economy	4000.00
0005434344818	29767	Economy	4000.00
0005434344829	29767	Economy	4000.00
0005434344741	29767	Economy	4000.00
0005435305068	29767	Economy	4000.00
0005434344871	29767	Economy	4000.00
0005434344886	29767	Economy	4000.00
0005435304264	29767	Economy	4000.00
0005434344624	29767	Economy	4000.00
0005435305069	29767	Economy	4000.00
0005434344796	29767	Economy	4000.00
0005434344942	29767	Economy	4000.00
0005434344870	29767	Economy	4000.00
0005434344865	29767	Economy	4000.00
0005435825351	1256	Business	199800.00
0005435825334	1256	Business	199800.00
0005433415948	1256	Business	199800.00
0005433415981	1256	Business	199800.00
0005435825347	1256	Business	199800.00
0005435825340	1256	Business	199800.00
0005435825331	1256	Business	199800.00
0005435825342	1256	Business	199800.00
0005433415989	1256	Economy	66600.00
0005435825349	1256	Economy	66600.00
0005435825330	1256	Economy	66600.00
0005435825332	1256	Economy	66600.00
0005435825353	1256	Economy	66600.00
0005435825350	1256	Economy	73200.00
0005433415922	1256	Economy	73200.00
0005435825329	1256	Economy	66600.00
0005435825337	1256	Economy	66600.00
0005435825355	1256	Economy	66600.00
0005433415943	1256	Economy	66600.00
0005432284637	1256	Economy	66600.00
0005435825339	1256	Economy	66600.00
0005435825344	1256	Economy	66600.00
0005435825345	1256	Economy	66600.00
0005433416021	1256	Economy	66600.00
0005433415980	1256	Economy	66600.00
0005435825348	1256	Economy	66600.00
0005435825346	1256	Economy	66600.00
0005433415991	1256	Economy	66600.00
0005435825338	1256	Economy	66600.00
0005433416022	1256	Economy	66600.00
0005435825333	1256	Economy	66600.00
0005435825335	1256	Economy	66600.00
0005435825341	1256	Economy	66600.00
0005435825336	1256	Economy	66600.00
0005435825354	1256	Economy	66600.00
0005435825343	1256	Economy	66600.00
0005433416020	1256	Economy	66600.00
0005433415937	1256	Economy	66600.00
0005433415944	1256	Economy	66600.00
0005435825352	1256	Economy	66600.00
0005435825127	17998	Business	199800.00
0005435825081	17998	Business	199800.00
0005435825076	17998	Business	199800.00
0005435825210	17998	Business	199800.00
0005435825143	17998	Business	199800.00
0005433416094	17998	Business	199800.00
0005433416089	17998	Economy	66600.00
0005435825094	17998	Economy	66600.00
0005433416092	17998	Economy	66600.00
0005433416093	17998	Economy	66600.00
0005435825164	17998	Economy	66600.00
0005433416081	17998	Economy	66600.00
0005435825136	17998	Economy	66600.00
0005433416083	17998	Economy	73200.00
0005433416082	17998	Economy	66600.00
0005435825142	17998	Economy	66600.00
0005433416085	17998	Economy	66600.00
0005433416090	17998	Economy	66600.00
0005435825067	17998	Economy	66600.00
0005433416079	17998	Economy	66600.00
0005435825174	17998	Economy	66600.00
0005435825079	17998	Economy	66600.00
0005433416084	17998	Economy	66600.00
0005435825163	17998	Economy	66600.00
0005435825092	17998	Economy	66600.00
0005435825093	17998	Economy	66600.00
0005435825165	17998	Economy	66600.00
0005435825151	17998	Economy	66600.00
0005435825066	17998	Economy	66600.00
0005435825176	17998	Economy	66600.00
0005433416088	17998	Economy	66600.00
0005433416087	17998	Economy	66600.00
0005435825175	17998	Economy	66600.00
0005435825221	17998	Economy	66600.00
0005435825117	17998	Economy	66600.00
0005435825096	17998	Economy	66600.00
0005433416080	17998	Economy	66600.00
0005435825137	17998	Economy	66600.00
0005435825047	17998	Economy	66600.00
0005435825048	17998	Economy	66600.00
0005433416086	17998	Economy	66600.00
0005435825012	17998	Economy	66600.00
0005433416091	17998	Economy	66600.00
0005433416078	17998	Economy	66600.00
0005434460558	12567	Economy	14800.00
0005434460562	12567	Economy	14800.00
0005434461703	12567	Economy	13500.00
0005434461702	12567	Economy	13500.00
0005434460561	12567	Economy	13500.00
0005434460557	12567	Economy	13500.00
0005434461700	12567	Economy	13500.00
0005434461699	12567	Economy	13500.00
0005434460559	12567	Economy	13500.00
0005434460560	12567	Economy	13500.00
0005434461698	12567	Economy	13500.00
0005434461701	12567	Economy	13500.00
0005434461697	12567	Economy	13500.00
0005435243279	5644	Business	27800.00
0005432144075	5644	Business	27800.00
0005435243313	5644	Business	27800.00
0005435243447	5644	Business	27800.00
0005435243332	5644	Business	27800.00
0005432785198	5644	Business	27800.00
0005432785208	5644	Business	27800.00
0005435243398	5644	Business	27800.00
0005435476887	5644	Business	27800.00
0005435476865	5644	Business	27800.00
0005432785228	5644	Business	27800.00
0005432785231	5644	Business	27800.00
0005432785218	5644	Economy	9300.00
0005432785217	5644	Economy	9300.00
0005432785221	5644	Economy	9300.00
0005435476900	5644	Economy	9300.00
0005435243331	5644	Economy	9300.00
0005432785216	5644	Economy	9300.00
0005435243236	5644	Economy	9300.00
0005432785238	5644	Economy	9300.00
0005435949984	5644	Economy	9300.00
0005435243142	5644	Economy	10200.00
0005432785203	5644	Economy	10200.00
0005435243210	5644	Economy	10200.00
0005432785207	5644	Economy	10200.00
0005432785227	5644	Economy	10200.00
0005435476893	5644	Economy	9300.00
0005435243235	5644	Economy	9300.00
0005435243294	5644	Economy	9300.00
0005435476921	5644	Economy	9300.00
0005435243256	5644	Economy	9300.00
0005435949985	5644	Economy	9300.00
0005435243143	5644	Economy	9300.00
0005432785233	5644	Economy	9300.00
0005435949983	5644	Economy	9300.00
0005432785239	5644	Economy	9300.00
0005435476899	5644	Economy	9300.00
0005432785224	5644	Economy	9300.00
0005435243446	5644	Economy	9300.00
0005432785211	5644	Economy	9300.00
0005435949980	5644	Economy	9300.00
0005432785237	5644	Economy	9300.00
0005432785230	5644	Economy	9300.00
0005432785225	5644	Economy	9300.00
0005435243343	5644	Economy	9300.00
0005432785204	5644	Economy	9300.00
0005432785213	5644	Economy	9300.00
0005432785197	5644	Economy	9300.00
0005432785210	5644	Economy	9300.00
0005435243255	5644	Economy	9300.00
0005432144074	5644	Economy	9300.00
0005432785201	5644	Economy	9300.00
0005432785226	5644	Economy	9300.00
0005432785229	5644	Economy	9300.00
0005435243326	5644	Economy	9300.00
0005432785235	5644	Economy	9300.00
0005435243211	5644	Economy	9300.00
0005435243395	5644	Economy	9300.00
0005432785219	5644	Economy	9300.00
0005432785196	5644	Economy	9300.00
0005435243325	5644	Economy	9300.00
0005435243386	5644	Economy	9300.00
0005432785202	5644	Economy	9300.00
0005435243295	5644	Economy	9300.00
0005435243333	5644	Economy	9300.00
0005432785220	5644	Economy	9300.00
0005432785212	5644	Economy	9300.00
0005432785214	5644	Economy	9300.00
0005435243278	5644	Economy	9300.00
0005432785222	5644	Economy	9300.00
0005432785234	5644	Economy	9300.00
0005432785205	5644	Economy	9300.00
0005432785199	5644	Economy	9300.00
0005432785215	5644	Economy	9300.00
0005432785232	5644	Economy	9300.00
0005432144073	5644	Economy	9300.00
0005435243385	5644	Economy	9300.00
0005435949981	5644	Economy	9300.00
0005435476884	5644	Economy	9300.00
0005432785206	5644	Economy	9300.00
0005435243212	5644	Economy	9300.00
0005435243237	5644	Economy	9300.00
0005435243284	5644	Economy	9300.00
0005435243342	5644	Economy	9300.00
0005435243312	5644	Economy	9300.00
0005435243285	5644	Economy	9300.00
0005432785209	5644	Economy	9300.00
0005435243328	5644	Economy	9300.00
0005432785200	5644	Economy	9300.00
0005435476860	5644	Economy	9300.00
0005435949982	5644	Economy	9300.00
0005435243296	5644	Economy	9300.00
0005435243394	5644	Economy	9300.00
0005432785223	5644	Economy	9300.00
0005435476861	5644	Economy	9300.00
0005432785236	5644	Economy	9300.00
0005432784581	15354	Business	27800.00
0005432784852	15354	Business	27800.00
0005432784513	15354	Business	27800.00
0005432784985	15354	Business	27800.00
0005435243560	15354	Business	27800.00
0005432784577	15354	Business	27800.00
0005435243554	15354	Business	27800.00
0005432784797	15354	Business	27800.00
0005435243541	15354	Business	27800.00
0005432784911	15354	Business	27800.00
0005432784758	15354	Business	27800.00
0005435476963	15354	Economy	9300.00
0005435243546	15354	Economy	9300.00
0005435243549	15354	Economy	9300.00
0005435243550	15354	Economy	9300.00
0005432784620	15354	Economy	9300.00
0005435476968	15354	Economy	9300.00
0005435243547	15354	Economy	9300.00
0005435243551	15354	Economy	9300.00
0005432784778	15354	Economy	9300.00
0005432784702	15354	Economy	10200.00
0005432784793	15354	Economy	10200.00
0005435243542	15354	Economy	10200.00
0005435243544	15354	Economy	10200.00
0005432784619	15354	Economy	9300.00
0005432784582	15354	Economy	9300.00
0005432784904	15354	Economy	9300.00
0005432784878	15354	Economy	9300.00
0005435243553	15354	Economy	9300.00
0005432784768	15354	Economy	9300.00
0005432784727	15354	Economy	9300.00
0005435476962	15354	Economy	9300.00
0005432784806	15354	Economy	9300.00
0005435476964	15354	Economy	9300.00
0005435476965	15354	Economy	9300.00
0005435243555	15354	Economy	9300.00
0005432784909	15354	Economy	9300.00
0005435476961	15354	Economy	9300.00
0005432784770	15354	Economy	9300.00
0005435243561	15354	Economy	9300.00
0005432784869	15354	Economy	9300.00
0005435476970	15354	Economy	9300.00
0005432784771	15354	Economy	9300.00
0005432784746	15354	Economy	9300.00
0005432784586	15354	Economy	9300.00
0005435243543	15354	Economy	9300.00
0005432784519	15354	Economy	9300.00
0005432784565	15354	Economy	9300.00
0005435243558	15354	Economy	9300.00
0005435243548	15354	Economy	9300.00
0005432784736	15354	Economy	9300.00
0005432784520	15354	Economy	9300.00
0005435243562	15354	Economy	9300.00
0005432784705	15354	Economy	9300.00
0005432784814	15354	Economy	9300.00
0005435243559	15354	Economy	9300.00
0005435476971	15354	Economy	9300.00
0005432784576	15354	Economy	9300.00
0005432784644	15354	Economy	9300.00
0005435476969	15354	Economy	9300.00
0005435476967	15354	Economy	9300.00
0005435243556	15354	Economy	9300.00
0005432784984	15354	Economy	9300.00
0005432784517	15354	Economy	9300.00
0005435243552	15354	Economy	9300.00
0005435243557	15354	Economy	9300.00
0005435476966	15354	Economy	9300.00
0005432784983	15354	Economy	9300.00
0005432784841	15354	Economy	9300.00
0005432784600	15354	Economy	9300.00
0005432784910	15354	Economy	9300.00
0005432784624	15354	Economy	9300.00
0005432784585	15354	Economy	9300.00
0005432784912	15354	Economy	9300.00
0005432784623	15354	Economy	9300.00
0005435243563	15354	Economy	9300.00
0005432784518	15354	Economy	9300.00
0005432784779	15354	Economy	9300.00
0005432784599	15354	Economy	9300.00
0005435243540	15354	Economy	9300.00
0005432784879	15354	Economy	9300.00
0005432784863	15354	Economy	9300.00
0005432784745	15354	Economy	9300.00
0005432784853	15354	Economy	9300.00
0005432784769	15354	Economy	9300.00
0005435243545	15354	Economy	9300.00
0005435243564	15354	Economy	9300.00
0005434463987	4348	Economy	7000.00
0005435851102	4348	Economy	6300.00
0005435851064	4348	Economy	6300.00
0005435851109	4348	Economy	6300.00
0005432848696	4348	Economy	6300.00
0005435851127	4348	Economy	6300.00
0005432848694	4348	Economy	6300.00
0005432848692	4348	Economy	6300.00
0005432848700	4348	Economy	6300.00
0005434463988	4348	Economy	6300.00
0005435851076	4348	Economy	6300.00
0005432848702	4348	Economy	6300.00
0005432848693	4348	Economy	6300.00
0005434462848	4348	Economy	6300.00
0005434463986	4348	Economy	6300.00
0005432848697	4348	Economy	6300.00
0005432848698	4348	Economy	6300.00
0005435851098	4348	Economy	6300.00
0005434462847	4348	Economy	6300.00
0005435851097	4348	Economy	6300.00
0005435851077	4348	Economy	6300.00
0005432848699	4348	Economy	6300.00
0005432848701	4348	Economy	6300.00
0005432848695	4348	Economy	6300.00
0005432848531	28849	Economy	7000.00
0005432848588	28849	Economy	7000.00
0005432848532	28849	Economy	7000.00
0005432848582	28849	Economy	6300.00
0005432848632	28849	Economy	6300.00
0005432848608	28849	Economy	6300.00
0005432848534	28849	Economy	6300.00
0005432848535	28849	Economy	6300.00
0005432848545	28849	Economy	6300.00
0005432848511	28849	Economy	6300.00
0005432848522	28849	Economy	6300.00
0005432848609	28849	Economy	6300.00
0005432848564	28849	Economy	6300.00
0005432848633	28849	Economy	6300.00
0005435851149	28849	Economy	6300.00
0005432848627	28849	Economy	6300.00
0005435851151	28849	Economy	6300.00
0005435851152	28849	Economy	6300.00
0005432848512	28849	Economy	6300.00
0005432848544	28849	Economy	6300.00
0005435851150	28849	Economy	6300.00
0005432848559	28849	Economy	6300.00
0005433497801	6265	Business	11900.00
0005435257405	6265	Business	11900.00
0005433497793	6265	Business	11900.00
0005434926667	6265	Business	11900.00
0005434444135	6265	Business	11900.00
0005434926703	6265	Business	11900.00
0005434444136	6265	Business	11900.00
0005433497792	6265	Business	11900.00
0005433497803	6265	Business	11900.00
0005435257392	6265	Business	11900.00
0005434926668	6265	Business	11900.00
0005434926683	6265	Economy	4000.00
0005433497791	6265	Economy	4000.00
0005434444132	6265	Economy	4000.00
0005434926676	6265	Economy	4000.00
0005434926699	6265	Economy	4000.00
0005434926687	6265	Economy	4000.00
0005434444133	6265	Economy	4000.00
0005434926705	6265	Economy	4000.00
0005434926673	6265	Economy	4000.00
0005433497811	6265	Economy	4000.00
0005433497789	6265	Economy	4400.00
0005434444139	6265	Economy	4400.00
0005434926696	6265	Economy	4400.00
0005433497804	6265	Economy	4400.00
0005434926664	6265	Economy	4400.00
0005434926685	6265	Economy	4000.00
0005435257403	6265	Economy	4000.00
0005434926662	6265	Economy	4000.00
0005434926674	6265	Economy	4000.00
0005434926661	6265	Economy	4000.00
0005433497797	6265	Economy	4000.00
0005434926671	6265	Economy	4000.00
0005434926677	6265	Economy	4000.00
0005433497807	6265	Economy	4000.00
0005434926679	6265	Economy	4000.00
0005433497794	6265	Economy	4000.00
0005434926704	6265	Economy	4000.00
0005433497813	6265	Economy	4000.00
0005434926666	6265	Economy	4000.00
0005433497802	6265	Economy	4000.00
0005435257408	6265	Economy	4000.00
0005433497805	6265	Economy	4000.00
0005434926694	6265	Economy	4000.00
0005433497806	6265	Economy	4000.00
0005433497795	6265	Economy	4000.00
0005434444131	6265	Economy	4000.00
0005434926695	6265	Economy	4000.00
0005434444134	6265	Economy	4000.00
0005433497808	6265	Economy	4000.00
0005433497809	6265	Economy	4000.00
0005434926686	6265	Economy	4000.00
0005434926669	6265	Economy	4000.00
0005433497788	6265	Economy	4000.00
0005434926684	6265	Economy	4000.00
0005433497810	6265	Economy	4000.00
0005434926692	6265	Economy	4000.00
0005433497796	6265	Economy	4000.00
0005434926670	6265	Economy	4000.00
0005434444138	6265	Economy	4000.00
0005434444140	6265	Economy	4000.00
0005434926663	6265	Economy	4000.00
0005434926659	6265	Economy	4000.00
0005435257395	6265	Economy	4000.00
0005434926690	6265	Economy	4000.00
0005434926697	6265	Economy	4000.00
0005434926688	6265	Economy	4000.00
0005434926678	6265	Economy	4000.00
0005434926689	6265	Economy	4000.00
0005434926682	6265	Economy	4000.00
0005433497790	6265	Economy	4000.00
0005433497812	6265	Economy	4000.00
0005433497800	6265	Economy	4000.00
0005434926698	6265	Economy	4000.00
0005433497798	6265	Economy	4000.00
0005434926700	6265	Economy	4000.00
0005435257391	6265	Economy	4000.00
0005433497799	6265	Economy	4000.00
0005434444137	6265	Economy	4000.00
0005434926701	6265	Economy	4000.00
0005435257406	6265	Economy	4000.00
0005434926672	6265	Economy	4000.00
0005434926681	6265	Economy	4000.00
0005435257393	6265	Economy	4000.00
0005432075320	6265	Economy	4000.00
0005434926660	6265	Economy	4000.00
0005434926693	6265	Economy	4000.00
0005434926702	6265	Economy	4000.00
0005434926665	6265	Economy	4000.00
0005434926691	6265	Economy	4000.00
0005435257394	6265	Economy	4000.00
0005434926680	6265	Economy	4000.00
0005434926675	6265	Economy	4000.00
0005435257495	20356	Business	11900.00
0005435257506	20356	Business	11900.00
0005435257502	20356	Business	11900.00
0005435257504	20356	Economy	4400.00
0005435257507	20356	Economy	4000.00
0005435257496	20356	Economy	4000.00
0005435257508	20356	Economy	4000.00
0005435257499	20356	Economy	4000.00
0005435257501	20356	Economy	4000.00
0005435257503	20356	Economy	4000.00
0005435257498	20356	Economy	4000.00
0005435257509	20356	Economy	4000.00
0005435257505	20356	Economy	4000.00
0005435257500	20356	Economy	4000.00
0005435257497	20356	Economy	4000.00
0005434443886	20377	Business	11900.00
0005434443988	20377	Business	11900.00
0005434926363	20377	Business	11900.00
0005433497452	20377	Business	11900.00
0005433497562	20377	Business	11900.00
0005433497494	20377	Business	11900.00
0005433497627	20377	Business	11900.00
0005434926333	20377	Business	11900.00
0005434444004	20377	Business	11900.00
0005434926199	20377	Business	11900.00
0005434443975	20377	Economy	4000.00
0005434443993	20377	Economy	4000.00
0005434926358	20377	Economy	4000.00
0005433497521	20377	Economy	4000.00
0005434926337	20377	Economy	4000.00
0005434926339	20377	Economy	4000.00
0005434926304	20377	Economy	4000.00
0005433497613	20377	Economy	4000.00
0005433497517	20377	Economy	4000.00
0005434926332	20377	Economy	4000.00
0005434443989	20377	Economy	4400.00
0005434443986	20377	Economy	4400.00
0005434444005	20377	Economy	4400.00
0005434926336	20377	Economy	4400.00
0005434926319	20377	Economy	4000.00
0005434926344	20377	Economy	4000.00
0005433497519	20377	Economy	4000.00
0005433497588	20377	Economy	4000.00
0005433497712	20377	Economy	4000.00
0005434926325	20377	Economy	4000.00
0005434444029	20377	Economy	4000.00
0005434926349	20377	Economy	4000.00
0005433497698	20377	Economy	4000.00
0005434926289	20377	Economy	4000.00
0005434926287	20377	Economy	4000.00
0005434926200	20377	Economy	4000.00
0005433497451	20377	Economy	4000.00
0005433497638	20377	Economy	4000.00
0005434443995	20377	Economy	4000.00
0005433497649	20377	Economy	4000.00
0005433497468	20377	Economy	4000.00
0005433497639	20377	Economy	4000.00
0005434926362	20377	Economy	4000.00
0005434926137	20377	Economy	4000.00
0005433497605	20377	Economy	4000.00
0005433497725	20377	Economy	4000.00
0005434444006	20377	Economy	4000.00
0005433497713	20377	Economy	4000.00
0005434926323	20377	Economy	4000.00
0005433497500	20377	Economy	4000.00
0005433497606	20377	Economy	4000.00
0005434926351	20377	Economy	4000.00
0005433497574	20377	Economy	4000.00
0005434926345	20377	Economy	4000.00
0005433497448	20377	Economy	4000.00
0005433497637	20377	Economy	4000.00
0005434443999	20377	Economy	4000.00
0005433497607	20377	Economy	4000.00
0005433497655	20377	Economy	4000.00
0005433497628	20377	Economy	4000.00
0005434443941	20377	Economy	4000.00
0005433497469	20377	Economy	4000.00
0005434926342	20377	Economy	4000.00
0005434926318	20377	Economy	4000.00
0005434926296	20377	Economy	4000.00
0005433497559	20377	Economy	4000.00
0005434443870	20377	Economy	4000.00
0005434443976	20377	Economy	4000.00
0005434926324	20377	Economy	4000.00
0005433497645	20377	Economy	4000.00
0005434443978	20377	Economy	4000.00
0005434926219	20377	Economy	4000.00
0005433497540	20377	Economy	4000.00
0005433497551	20377	Economy	4000.00
0005433497518	20377	Economy	4000.00
0005434926357	20377	Economy	4000.00
0005433497608	20377	Economy	4000.00
0005433497612	20377	Economy	4000.00
0005434926290	20377	Economy	4000.00
0005434443977	20377	Economy	4000.00
0005434443969	20377	Economy	4000.00
0005433497539	20377	Economy	4000.00
0005434444007	20377	Economy	4000.00
0005433497491	20377	Economy	4000.00
0005434926303	20377	Economy	4000.00
0005434926330	20377	Economy	4000.00
0005433497561	20377	Economy	4000.00
0005434926306	20377	Economy	4000.00
0005432784846	12202	Business	41200.00
0005432784865	12202	Business	41200.00
0005435243574	12202	Business	41200.00
0005432784678	12202	Business	41200.00
0005432784714	12202	Business	41200.00
0005432784767	12202	Business	41200.00
0005432784810	12202	Business	41200.00
0005432784756	12202	Business	41200.00
0005432784689	12202	Business	41200.00
0005432784757	12202	Business	41200.00
0005432784762	12202	Business	41200.00
0005432784842	12202	Economy	13700.00
0005435243572	12202	Economy	13700.00
0005432784791	12202	Economy	13700.00
0005432784922	12202	Economy	13700.00
0005432784788	12202	Economy	13700.00
0005435243586	12202	Economy	13700.00
0005435243580	12202	Economy	13700.00
0005432784973	12202	Economy	13700.00
0005432784892	12202	Economy	13700.00
0005435243569	12202	Economy	13700.00
0005432784722	12202	Economy	15100.00
0005435243571	12202	Economy	15100.00
0005432784880	12202	Economy	15100.00
0005432784891	12202	Economy	15100.00
0005432784602	12202	Economy	13700.00
0005432784656	12202	Economy	13700.00
0005432784744	12202	Economy	13700.00
0005435243567	12202	Economy	13700.00
0005432784972	12202	Economy	13700.00
0005435243585	12202	Economy	13700.00
0005432784868	12202	Economy	13700.00
0005432784682	12202	Economy	13700.00
0005432784754	12202	Economy	13700.00
0005432784601	12202	Economy	13700.00
0005432784782	12202	Economy	13700.00
0005432784737	12202	Economy	13700.00
0005435243578	12202	Economy	13700.00
0005432784845	12202	Economy	13700.00
0005435243568	12202	Economy	13700.00
0005432784673	12202	Economy	13700.00
0005435243565	12202	Economy	13700.00
0005435243582	12202	Economy	13700.00
0005432784671	12202	Economy	13700.00
0005432784790	12202	Economy	13700.00
0005432784683	12202	Economy	13700.00
0005435243573	12202	Economy	13700.00
0005432784834	12202	Economy	13700.00
0005432784747	12202	Economy	13700.00
0005432784657	12202	Economy	13700.00
0005435243577	12202	Economy	13700.00
0005435243588	12202	Economy	13700.00
0005432784748	12202	Economy	13700.00
0005432784994	12202	Economy	13700.00
0005432784976	12202	Economy	13700.00
0005435243575	12202	Economy	13700.00
0005432784809	12202	Economy	13700.00
0005435243579	12202	Economy	13700.00
0005432785041	12202	Economy	13700.00
0005432784743	12202	Economy	13700.00
0005432784672	12202	Economy	13700.00
0005432784857	12202	Economy	13700.00
0005432784864	12202	Economy	13700.00
0005432784900	12202	Economy	13700.00
0005432784755	12202	Economy	13700.00
0005432784753	12202	Economy	13700.00
0005432784742	12202	Economy	13700.00
0005435243584	12202	Economy	13700.00
0005435243570	12202	Economy	13700.00
0005432784774	12202	Economy	13700.00
0005435243587	12202	Economy	13700.00
0005432784871	12202	Economy	13700.00
0005432784921	12202	Economy	13700.00
0005432784989	12202	Economy	13700.00
0005435243566	12202	Economy	13700.00
0005435243583	12202	Economy	13700.00
0005432784824	12202	Economy	13700.00
0005435243576	12202	Economy	13700.00
0005432784496	12202	Economy	13700.00
0005432784775	12202	Economy	13700.00
0005432784707	12202	Economy	13700.00
0005432784800	12202	Economy	13700.00
0005432784832	12202	Economy	13700.00
0005432784690	12202	Economy	13700.00
0005432784688	12202	Economy	13700.00
0005435243581	12202	Economy	13700.00
0005432784677	12202	Economy	13700.00
0005432784820	12202	Economy	13700.00
0005432784858	12202	Economy	13700.00
0005432784715	12202	Economy	13700.00
0005432784835	12202	Economy	13700.00
0005432784716	12202	Economy	13700.00
0005432785160	15449	Business	41200.00
0005432785189	15449	Business	41200.00
0005432785165	15449	Business	41200.00
0005432785147	15449	Business	41200.00
0005432785153	15449	Business	41200.00
0005435243310	15449	Business	41200.00
0005432785152	15449	Business	41200.00
0005435243241	15449	Business	41200.00
0005432785176	15449	Business	41200.00
0005435243339	15449	Business	41200.00
0005435243311	15449	Business	41200.00
0005432785151	15449	Economy	13700.00
0005432785192	15449	Economy	13700.00
0005435243259	15449	Economy	13700.00
0005432785177	15449	Economy	13700.00
0005435243304	15449	Economy	13700.00
0005432785161	15449	Economy	13700.00
0005432785184	15449	Economy	13700.00
0005435243269	15449	Economy	13700.00
0005432785174	15449	Economy	13700.00
0005432785163	15449	Economy	15100.00
0005432785181	15449	Economy	15100.00
0005432785169	15449	Economy	15100.00
0005435243249	15449	Economy	15100.00
0005432785185	15449	Economy	13700.00
0005435243231	15449	Economy	13700.00
0005435243287	15449	Economy	13700.00
0005432785167	15449	Economy	13700.00
0005435243206	15449	Economy	13700.00
0005435243242	15449	Economy	13700.00
0005432785162	15449	Economy	13700.00
0005435243250	15449	Economy	13700.00
0005432785173	15449	Economy	13700.00
0005432785182	15449	Economy	13700.00
0005435243263	15449	Economy	13700.00
0005435243351	15449	Economy	13700.00
0005432785150	15449	Economy	13700.00
0005435243251	15449	Economy	13700.00
0005432785154	15449	Economy	13700.00
0005432785187	15449	Economy	13700.00
0005435243352	15449	Economy	13700.00
0005432785179	15449	Economy	13700.00
0005432785183	15449	Economy	13700.00
0005432785178	15449	Economy	13700.00
0005435243270	15449	Economy	13700.00
0005432785191	15449	Economy	13700.00
0005432785168	15449	Economy	13700.00
0005432785195	15449	Economy	13700.00
0005432785172	15449	Economy	13700.00
0005432785164	15449	Economy	13700.00
0005432785188	15449	Economy	13700.00
0005432785180	15449	Economy	13700.00
0005435243254	15449	Economy	13700.00
0005432785194	15449	Economy	13700.00
0005432785171	15449	Economy	13700.00
0005432785166	15449	Economy	13700.00
0005432785175	15449	Economy	13700.00
0005432785170	15449	Economy	13700.00
0005432785186	15449	Economy	13700.00
0005432785155	15449	Economy	13700.00
0005435243218	15449	Economy	13700.00
0005435243219	15449	Economy	13700.00
0005432785190	15449	Economy	13700.00
0005435243262	15449	Economy	13700.00
0005432785156	15449	Economy	13700.00
0005435243217	15449	Economy	13700.00
0005435243240	15449	Economy	13700.00
0005435243271	15449	Economy	13700.00
0005432785159	15449	Economy	13700.00
0005432785158	15449	Economy	13700.00
0005432785157	15449	Economy	13700.00
0005435243307	15449	Economy	13700.00
0005435243346	15449	Economy	13700.00
0005435243305	15449	Economy	13700.00
0005432785193	15449	Economy	13700.00
0005432785149	15449	Economy	13700.00
0005432785148	15449	Economy	13700.00
0005434879676	10100	Business	49700.00
0005434880060	10100	Business	49700.00
0005434879942	10100	Business	49700.00
0005434879658	10100	Business	49700.00
0005435914114	10100	Business	49700.00
0005434879903	10100	Business	49700.00
0005434880182	10100	Business	49700.00
0005434880179	10100	Business	49700.00
0005434880279	10100	Business	49700.00
0005434879878	10100	Business	49700.00
0005434758942	10100	Business	49700.00
0005434879733	10100	Business	49700.00
0005434880151	10100	Business	49700.00
0005434879837	10100	Business	49700.00
0005434879703	10100	Business	49700.00
0005434880054	10100	Business	49700.00
0005434879840	10100	Business	49700.00
0005434879949	10100	Business	49700.00
0005434880015	10100	Business	49700.00
0005434879933	10100	Business	49700.00
0005434879749	10100	Economy	16600.00
0005434880080	10100	Economy	16600.00
0005434880153	10100	Economy	16600.00
0005434879835	10100	Economy	16600.00
0005434880030	10100	Economy	16600.00
0005434880152	10100	Economy	16600.00
0005434879868	10100	Economy	16600.00
0005434879728	10100	Economy	16600.00
0005434880194	10100	Economy	16600.00
0005434880065	10100	Economy	16600.00
0005434880066	10100	Economy	16600.00
0005434880154	10100	Economy	16600.00
0005434910176	10100	Economy	18200.00
0005434879704	10100	Economy	16600.00
0005434879961	10100	Economy	18200.00
0005434880069	10100	Economy	18200.00
0005434879997	10100	Economy	18200.00
0005434879702	10100	Economy	16600.00
0005434880016	10100	Economy	16600.00
0005434880050	10100	Economy	16600.00
0005434879146	10100	Economy	16600.00
0005434879989	10100	Economy	16600.00
0005434879545	10100	Economy	16600.00
0005434880061	10100	Economy	16600.00
0005434879904	10100	Economy	16600.00
0005434880026	10100	Economy	16600.00
0005434879544	10100	Economy	16600.00
0005434879683	10100	Economy	16600.00
0005434879709	10100	Economy	16600.00
0005434880108	10100	Economy	16600.00
0005434880124	10100	Economy	16600.00
0005434879992	10100	Economy	16600.00
0005434880053	10100	Economy	16600.00
0005434880146	10100	Economy	16600.00
0005434879922	10100	Economy	16600.00
0005434880086	10100	Economy	16600.00
0005434880193	10100	Economy	16600.00
0005434880037	10100	Economy	16600.00
0005434879948	10100	Economy	16600.00
0005434879990	10100	Economy	16600.00
0005434879877	10100	Economy	16600.00
0005434879491	10100	Economy	16600.00
0005434880113	10100	Economy	16600.00
0005434879838	10100	Economy	16600.00
0005434879988	10100	Economy	16600.00
0005434879791	10100	Economy	16600.00
0005434879962	10100	Economy	16600.00
0005434879974	10100	Economy	16600.00
0005434879963	10100	Economy	16600.00
0005434879897	10100	Economy	16600.00
0005434879436	10100	Economy	16600.00
0005434879734	10100	Economy	16600.00
0005434879661	10100	Economy	16600.00
0005434879993	10100	Economy	16600.00
0005434879923	10100	Economy	16600.00
0005434879638	10100	Economy	16600.00
0005434880111	10100	Economy	16600.00
0005434879836	10100	Economy	16600.00
0005434879901	10100	Economy	16600.00
0005434880155	10100	Economy	16600.00
0005434880147	10100	Economy	16600.00
0005434880088	10100	Economy	16600.00
0005434880012	10100	Economy	16600.00
0005434879919	10100	Economy	16600.00
0005434879869	10100	Economy	16600.00
0005434880032	10100	Economy	16600.00
0005434879637	10100	Economy	16600.00
0005434879662	10100	Economy	16600.00
0005434880027	10100	Economy	16600.00
0005434879751	10100	Economy	16600.00
0005434880211	10100	Economy	16600.00
0005434879732	10100	Economy	16600.00
0005434880038	10100	Economy	16600.00
0005434879862	10100	Economy	16600.00
0005434879790	10100	Economy	16600.00
0005434880057	10100	Economy	16600.00
0005434880150	10100	Economy	16600.00
0005434880087	10100	Economy	16600.00
0005434879865	10100	Economy	16600.00
0005434880110	10100	Economy	16600.00
0005434879748	10100	Economy	16600.00
0005434879675	10100	Economy	16600.00
0005434880109	10100	Economy	16600.00
0005434880049	10100	Economy	16600.00
0005434879576	10100	Economy	16600.00
0005434879920	10100	Economy	16600.00
0005435914113	10100	Economy	16600.00
0005434879657	10100	Economy	16600.00
0005434879883	10100	Economy	16600.00
0005435914115	10100	Economy	16600.00
0005434879998	10100	Economy	16600.00
0005434880184	10100	Economy	16600.00
0005434910175	10100	Economy	16600.00
0005434879976	10100	Economy	16600.00
0005434880059	10100	Economy	16600.00
0005434758943	10100	Economy	16600.00
0005434880765	14619	Business	49700.00
0005434880731	14619	Business	49700.00
0005434880757	14619	Business	49700.00
0005434880739	14619	Business	49700.00
0005434880740	14619	Business	49700.00
0005434880683	14619	Business	49700.00
0005434880735	14619	Business	49700.00
0005434880746	14619	Business	49700.00
0005434880699	14619	Business	49700.00
0005434880761	14619	Business	49700.00
0005434880745	14619	Business	49700.00
0005434880692	14619	Business	49700.00
0005434880717	14619	Business	49700.00
0005434880685	14619	Business	49700.00
0005434880709	14619	Business	49700.00
0005434880705	14619	Business	49700.00
0005434880766	14619	Business	49700.00
0005434880758	14619	Economy	16600.00
0005434758957	14619	Economy	16600.00
0005435913993	14619	Economy	16600.00
0005434880752	14619	Economy	16600.00
0005434880719	14619	Economy	16600.00
0005434880686	14619	Economy	16600.00
0005435913997	14619	Economy	16600.00
0005434880687	14619	Economy	16600.00
0005434880736	14619	Economy	16600.00
0005434880753	14619	Economy	18200.00
0005434880725	14619	Economy	16600.00
0005434880738	14619	Economy	18200.00
0005434880691	14619	Economy	18200.00
0005434880724	14619	Economy	16600.00
0005434880689	14619	Economy	18200.00
0005434880690	14619	Economy	16600.00
0005434880749	14619	Economy	16600.00
0005434880695	14619	Economy	16600.00
0005434880743	14619	Economy	16600.00
0005434880706	14619	Economy	16600.00
0005434880750	14619	Economy	16600.00
0005434880701	14619	Economy	16600.00
0005434880715	14619	Economy	16600.00
0005434880723	14619	Economy	16600.00
0005434880711	14619	Economy	16600.00
0005434880693	14619	Economy	16600.00
0005434880688	14619	Economy	16600.00
0005434880698	14619	Economy	16600.00
0005434758956	14619	Economy	16600.00
0005434880704	14619	Economy	16600.00
0005434880744	14619	Economy	16600.00
0005434880763	14619	Economy	16600.00
0005434880700	14619	Economy	16600.00
0005434880684	14619	Economy	16600.00
0005434880716	14619	Economy	16600.00
0005434880696	14619	Economy	16600.00
0005434880756	14619	Economy	16600.00
0005434880721	14619	Economy	16600.00
0005434910151	14619	Economy	16600.00
0005434880702	14619	Economy	16600.00
0005434880728	14619	Economy	16600.00
0005434880726	14619	Economy	16600.00
0005434880762	14619	Economy	16600.00
0005434880755	14619	Economy	16600.00
0005434880759	14619	Economy	16600.00
0005434880714	14619	Economy	16600.00
0005434880708	14619	Economy	16600.00
0005434880694	14619	Economy	16600.00
0005434880747	14619	Economy	16600.00
0005434880707	14619	Economy	16600.00
0005435913999	14619	Economy	16600.00
0005434880748	14619	Economy	16600.00
0005434880737	14619	Economy	16600.00
0005435914000	14619	Economy	16600.00
0005434880742	14619	Economy	16600.00
0005435913996	14619	Economy	16600.00
0005434880754	14619	Economy	16600.00
0005435913966	14619	Economy	16600.00
0005434880697	14619	Economy	16600.00
0005435913994	14619	Economy	16600.00
0005434880734	14619	Economy	16600.00
0005434880733	14619	Economy	16600.00
0005434880720	14619	Economy	16600.00
0005434880713	14619	Economy	16600.00
0005434880712	14619	Economy	16600.00
0005434758955	14619	Economy	16600.00
0005435913982	14619	Economy	16600.00
0005434880751	14619	Economy	16600.00
0005434880727	14619	Economy	16600.00
0005434880710	14619	Economy	16600.00
0005434880722	14619	Economy	16600.00
0005434880729	14619	Economy	16600.00
0005434880760	14619	Economy	16600.00
0005434880741	14619	Economy	16600.00
0005434880718	14619	Economy	16600.00
0005434880732	14619	Economy	16600.00
0005434880764	14619	Economy	16600.00
0005434880730	14619	Economy	16600.00
0005435913979	14619	Economy	16600.00
0005434880703	14619	Economy	16600.00
0005435660433	9221	Economy	22400.00
0005435660438	9221	Economy	22400.00
0005434252149	9221	Economy	20300.00
0005434252131	9221	Economy	20300.00
0005434252162	9221	Economy	20300.00
0005434252133	9221	Economy	20300.00
0005434252148	9221	Economy	20300.00
0005435660435	9221	Economy	20300.00
0005435660434	9221	Economy	20300.00
0005435660436	9221	Economy	20300.00
0005435660429	9221	Economy	20300.00
0005434252134	9221	Economy	20300.00
0005434252080	9221	Economy	20300.00
0005434252146	9221	Economy	20300.00
0005434252155	9221	Economy	20300.00
0005435660428	9221	Economy	20300.00
0005435660431	9221	Economy	20300.00
0005434252147	9221	Economy	20300.00
0005434252106	9221	Economy	20300.00
0005434252163	9221	Economy	20300.00
0005435660430	9221	Economy	20300.00
0005434252157	9221	Economy	20300.00
0005434252154	9221	Economy	20300.00
0005434252107	9221	Economy	20300.00
0005435660432	9221	Economy	20300.00
0005434252142	9221	Economy	20300.00
0005435660437	9221	Economy	20300.00
0005435660330	24667	Economy	22400.00
0005435660332	24667	Economy	20300.00
0005435660384	24667	Economy	20300.00
0005434252215	24667	Economy	20300.00
0005434252214	24667	Economy	20300.00
0005435660309	24667	Economy	20300.00
0005434252221	24667	Economy	20300.00
0005434252217	24667	Economy	20300.00
0005435660333	24667	Economy	20300.00
0005434252222	24667	Economy	20300.00
0005435660275	24667	Economy	20300.00
0005434252219	24667	Economy	20300.00
0005435660276	24667	Economy	20300.00
0005434252218	24667	Economy	20300.00
0005435660365	24667	Economy	20300.00
0005435660390	24667	Economy	20300.00
0005435660383	24667	Economy	20300.00
0005434252216	24667	Economy	20300.00
0005434252220	24667	Economy	20300.00
0005435660340	24667	Economy	20300.00
0005432222921	2812	Business	33000.00
0005433681806	2812	Business	33000.00
0005433681807	2812	Business	33000.00
0005432967371	2812	Business	33000.00
0005433681813	2812	Business	33000.00
0005432967348	2812	Business	33000.00
0005433681844	2812	Business	33000.00
0005433681824	2812	Business	33000.00
0005433681833	2812	Economy	11000.00
0005432967422	2812	Economy	11000.00
0005433681839	2812	Economy	11000.00
0005433681832	2812	Economy	11000.00
0005433681822	2812	Economy	11000.00
0005433681803	2812	Economy	11000.00
0005433681820	2812	Economy	12100.00
0005433681805	2812	Economy	12100.00
0005433681830	2812	Economy	11000.00
0005433681825	2812	Economy	11000.00
0005433681811	2812	Economy	11000.00
0005433681829	2812	Economy	11000.00
0005433681802	2812	Economy	11000.00
0005433684472	2812	Economy	11000.00
0005433681808	2812	Economy	11000.00
0005433681836	2812	Economy	11000.00
0005433681841	2812	Economy	11000.00
0005433681823	2812	Economy	11000.00
0005432222922	2812	Economy	11000.00
0005433681815	2812	Economy	11000.00
0005432967417	2812	Economy	11000.00
0005433681818	2812	Economy	11000.00
0005432967407	2812	Economy	11000.00
0005433681826	2812	Economy	11000.00
0005432967462	2812	Economy	11000.00
0005432967357	2812	Economy	11000.00
0005432967356	2812	Economy	11000.00
0005433681804	2812	Economy	11000.00
0005433681809	2812	Economy	11000.00
0005433681834	2812	Economy	11000.00
0005432967395	2812	Economy	11000.00
0005433681817	2812	Economy	11000.00
0005432967376	2812	Economy	11000.00
0005432967400	2812	Economy	11000.00
0005433681840	2812	Economy	11000.00
0005432967327	2812	Economy	11000.00
0005433684473	2812	Economy	11000.00
0005433681837	2812	Economy	11000.00
0005432967443	2812	Economy	11000.00
0005432967430	2812	Economy	11000.00
0005432967476	2812	Economy	11000.00
0005433681843	2812	Economy	11000.00
0005433681828	2812	Economy	11000.00
0005432967396	2812	Economy	11000.00
0005433681835	2812	Economy	11000.00
0005432222923	2812	Economy	11000.00
0005433681814	2812	Economy	11000.00
0005432967439	2812	Economy	11000.00
0005433681842	2812	Economy	11000.00
0005432967418	2812	Economy	11000.00
0005433681812	2812	Economy	11000.00
0005433681819	2812	Economy	11000.00
0005433681827	2812	Economy	11000.00
0005433681810	2812	Economy	11000.00
0005433681801	2812	Economy	11000.00
0005432967375	2812	Economy	11000.00
0005433681821	2812	Economy	11000.00
0005433681816	2812	Economy	11000.00
0005433681838	2812	Economy	11000.00
0005432967475	2812	Economy	11000.00
0005433681831	2812	Economy	11000.00
0005432967607	29171	Business	33000.00
0005433681468	29171	Business	33000.00
0005433681275	29171	Business	33000.00
0005433681488	29171	Business	33000.00
0005433681485	29171	Business	33000.00
0005433681576	29171	Business	33000.00
0005433687742	29171	Business	33000.00
0005432967605	29171	Economy	11000.00
0005433684454	29171	Economy	11000.00
0005433681372	29171	Economy	11000.00
0005433681274	29171	Economy	11000.00
0005433681530	29171	Economy	11000.00
0005433681659	29171	Economy	11000.00
0005433681489	29171	Economy	12100.00
0005432967617	29171	Economy	11000.00
0005433681426	29171	Economy	11000.00
0005432967610	29171	Economy	11000.00
0005432967601	29171	Economy	11000.00
0005432005289	29171	Economy	11000.00
0005433681433	29171	Economy	11000.00
0005432967613	29171	Economy	11000.00
0005433681432	29171	Economy	11000.00
0005433681513	29171	Economy	11000.00
0005433681551	29171	Economy	11000.00
0005433681560	29171	Economy	11000.00
0005433681322	29171	Economy	11000.00
0005432967615	29171	Economy	11000.00
0005432967611	29171	Economy	11000.00
0005433681371	29171	Economy	11000.00
0005433687736	29171	Economy	11000.00
0005433681577	29171	Economy	11000.00
0005432967602	29171	Economy	11000.00
0005432967608	29171	Economy	11000.00
0005433681486	29171	Economy	11000.00
0005432967600	29171	Economy	11000.00
0005433687743	29171	Economy	11000.00
0005432967599	29171	Economy	11000.00
0005433687738	29171	Economy	11000.00
0005432967616	29171	Economy	11000.00
0005433681660	29171	Economy	11000.00
0005433687735	29171	Economy	11000.00
0005433681646	29171	Economy	11000.00
0005433681373	29171	Economy	11000.00
0005432967606	29171	Economy	11000.00
0005432967604	29171	Economy	11000.00
0005432967609	29171	Economy	11000.00
0005433681398	29171	Economy	11000.00
0005433681442	29171	Economy	11000.00
0005433681443	29171	Economy	11000.00
0005432967614	29171	Economy	11000.00
0005433681650	29171	Economy	11000.00
0005432967603	29171	Economy	11000.00
0005433681204	29171	Economy	11000.00
0005432005288	29171	Economy	11000.00
0005432967612	29171	Economy	11000.00
0005433681469	29171	Economy	11000.00
0005433681608	29171	Economy	11000.00
0005433681596	29171	Economy	11000.00
0005433687739	29171	Economy	11000.00
0005433681467	29171	Economy	11000.00
0005433681487	29171	Economy	11000.00
0005433681651	29171	Economy	11000.00
0005433578170	9296	Business	132900.00
0005434163795	9296	Business	132900.00
0005433578162	9296	Business	132900.00
0005433578163	9296	Business	132900.00
0005433616573	9296	Business	132900.00
0005433616574	9296	Business	132900.00
0005433616533	9296	Business	132900.00
0005433616570	9296	Business	132900.00
0005433578169	9296	Business	132900.00
0005433616582	9296	Business	132900.00
0005433616580	9296	Business	132900.00
0005433616591	9296	Business	132900.00
0005433616576	9296	Business	132900.00
0005433616597	9296	Business	132900.00
0005433578167	9296	Business	132900.00
0005433634687	9296	Business	132900.00
0005433616560	9296	Business	132900.00
0005433616554	9296	Business	132900.00
0005434163771	9296	Business	132900.00
0005433634684	9296	Business	132900.00
0005434163787	9296	Business	132900.00
0005433634710	9296	Business	132900.00
0005433616585	9296	Business	132900.00
0005433616552	9296	Business	132900.00
0005433616586	9296	Business	132900.00
0005433616535	9296	Business	132900.00
0005433634695	9296	Business	132900.00
0005433634683	9296	Economy	48700.00
0005433634708	9296	Economy	48700.00
0005434163796	9296	Economy	48700.00
0005433616537	9296	Economy	48700.00
0005434163728	9296	Economy	48700.00
0005433578161	9296	Economy	44300.00
0005433616564	9296	Economy	44300.00
0005433616548	9296	Economy	44300.00
0005433634700	9296	Economy	44300.00
0005433616590	9296	Economy	44300.00
0005433616572	9296	Economy	44300.00
0005433616577	9296	Economy	44300.00
0005433634677	9296	Economy	44300.00
0005433616545	9296	Economy	44300.00
0005433616567	9296	Economy	44300.00
0005433634693	9296	Economy	44300.00
0005433634711	9296	Economy	44300.00
0005434163762	9296	Economy	44300.00
0005433616534	9296	Economy	44300.00
0005432755166	9296	Economy	44300.00
0005433616581	9296	Economy	44300.00
0005433616557	9296	Economy	44300.00
0005433634691	9296	Economy	44300.00
0005433616531	9296	Economy	44300.00
0005433578164	9296	Economy	44300.00
0005433616549	9296	Economy	44300.00
0005433616538	9296	Economy	44300.00
0005433634699	9296	Economy	44300.00
0005433634689	9296	Economy	44300.00
0005433616559	9296	Economy	44300.00
0005433578168	9296	Economy	44300.00
0005433634690	9296	Economy	44300.00
0005433616569	9296	Economy	44300.00
0005433616532	9296	Economy	44300.00
0005433616566	9296	Economy	44300.00
0005433634696	9296	Economy	44300.00
0005433616551	9296	Economy	44300.00
0005433634682	9296	Economy	44300.00
0005433634703	9296	Economy	44300.00
0005433616595	9296	Economy	44300.00
0005433616550	9296	Economy	44300.00
0005433616592	9296	Economy	44300.00
0005434163785	9296	Economy	44300.00
0005433634706	9296	Economy	44300.00
0005433634685	9296	Economy	44300.00
0005434272218	9296	Economy	44300.00
0005433616579	9296	Economy	44300.00
0005433578160	9296	Economy	44300.00
0005433634701	9296	Economy	44300.00
0005434163767	9296	Economy	44300.00
0005432755165	9296	Economy	44300.00
0005433616543	9296	Economy	44300.00
0005433616530	9296	Economy	44300.00
0005433634688	9296	Economy	48700.00
0005433616562	9296	Economy	48700.00
0005433616544	9296	Economy	48700.00
0005434163794	9296	Economy	48700.00
0005433616568	9296	Economy	48700.00
0005433616555	9296	Economy	44300.00
0005432755162	9296	Economy	44300.00
0005433616588	9296	Economy	44300.00
0005433616553	9296	Economy	44300.00
0005433578159	9296	Economy	48700.00
0005432755163	9296	Economy	44300.00
0005433616571	9296	Economy	44300.00
0005433616541	9296	Economy	44300.00
0005433616584	9296	Economy	44300.00
0005433616578	9296	Economy	44300.00
0005434152824	9296	Economy	44300.00
0005433634680	9296	Economy	44300.00
0005433616540	9296	Economy	44300.00
0005433634692	9296	Economy	44300.00
0005433634704	9296	Economy	44300.00
0005434272219	9296	Economy	44300.00
0005432756933	9296	Economy	44300.00
0005432755164	9296	Economy	44300.00
0005433616528	9296	Economy	44300.00
0005434272220	9296	Economy	44300.00
0005433634681	9296	Economy	44300.00
0005433578166	9296	Economy	44300.00
0005433616527	9296	Economy	44300.00
0005433578165	9296	Economy	44300.00
0005433634709	9296	Economy	44300.00
0005432756932	9296	Economy	44300.00
0005433616542	9296	Economy	44300.00
0005433616565	9296	Economy	44300.00
0005433616598	9296	Economy	44300.00
0005433616536	9296	Economy	44300.00
0005433634694	9296	Economy	44300.00
0005433616546	9296	Economy	44300.00
0005433616539	9296	Economy	44300.00
0005433616575	9296	Economy	44300.00
0005433634697	9296	Economy	44300.00
0005433634698	9296	Economy	44300.00
0005433616594	9296	Economy	44300.00
0005433616561	9296	Economy	44300.00
0005433616596	9296	Economy	44300.00
0005433616563	9296	Economy	44300.00
0005433634678	9296	Economy	44300.00
0005433634705	9296	Economy	44300.00
0005433616583	9296	Economy	44300.00
0005433634707	9296	Economy	44300.00
0005433616529	9296	Economy	44300.00
0005433616587	9296	Economy	44300.00
0005433616547	9296	Economy	44300.00
0005434163766	9296	Economy	44300.00
0005433616593	9296	Economy	44300.00
0005433634686	9296	Economy	44300.00
0005433634702	9296	Economy	44300.00
0005433634679	9296	Economy	44300.00
0005433616558	9296	Economy	44300.00
0005433616556	9296	Economy	44300.00
0005433616589	9296	Economy	44300.00
0005433616103	25243	Business	132900.00
0005433616169	25243	Business	132900.00
0005433615856	25243	Business	132900.00
0005433616132	25243	Business	132900.00
0005433616131	25243	Business	132900.00
0005433615904	25243	Business	132900.00
0005433615797	25243	Business	132900.00
0005433615754	25243	Business	132900.00
0005434163852	25243	Business	132900.00
0005433616130	25243	Business	132900.00
0005433634270	25243	Business	132900.00
0005433616278	25243	Business	132900.00
0005433615770	25243	Business	132900.00
0005433634408	25243	Business	132900.00
0005433615921	25243	Business	132900.00
0005433634359	25243	Business	132900.00
0005435854080	25243	Business	132900.00
0005433615824	25243	Business	132900.00
0005433615795	25243	Business	132900.00
0005433634447	25243	Business	132900.00
0005433615964	25243	Business	132900.00
0005433616134	25243	Business	132900.00
0005433634553	25243	Business	132900.00
0005433634463	25243	Business	132900.00
0005433615984	25243	Business	132900.00
0005433634526	25243	Economy	48700.00
0005433616096	25243	Economy	48700.00
0005435854079	25243	Economy	48700.00
0005434273118	25243	Economy	48700.00
0005433615756	25243	Economy	44300.00
0005433616331	25243	Economy	48700.00
0005433634365	25243	Economy	44300.00
0005433615442	25243	Economy	44300.00
0005435854089	25243	Economy	44300.00
0005433615696	25243	Economy	44300.00
0005433634458	25243	Economy	44300.00
0005434273117	25243	Economy	44300.00
0005434163854	25243	Economy	44300.00
0005434273131	25243	Economy	44300.00
0005434272230	25243	Economy	44300.00
0005433634380	25243	Economy	44300.00
0005434163851	25243	Economy	44300.00
0005433615771	25243	Economy	44300.00
0005433615966	25243	Economy	44300.00
0005433634456	25243	Economy	44300.00
0005433615598	25243	Economy	44300.00
0005433634400	25243	Economy	44300.00
0005433615796	25243	Economy	44300.00
0005433615968	25243	Economy	44300.00
0005433634552	25243	Economy	44300.00
0005433615779	25243	Economy	44300.00
0005433615996	25243	Economy	44300.00
0005433578080	25243	Economy	44300.00
0005433615833	25243	Economy	44300.00
0005433634448	25243	Economy	44300.00
0005433615938	25243	Economy	44300.00
0005435854083	25243	Economy	44300.00
0005434163860	25243	Economy	44300.00
0005434163857	25243	Economy	44300.00
0005433616006	25243	Economy	44300.00
0005435854082	25243	Economy	44300.00
0005433615933	25243	Economy	44300.00
0005433634373	25243	Economy	44300.00
0005433615958	25243	Economy	44300.00
0005433634374	25243	Economy	44300.00
0005433578113	25243	Economy	44300.00
0005433615983	25243	Economy	44300.00
0005433578112	25243	Economy	44300.00
0005433615951	25243	Economy	44300.00
0005433615804	25243	Economy	44300.00
0005433634439	25243	Economy	44300.00
0005433616155	25243	Economy	44300.00
0005433578079	25243	Economy	44300.00
0005433616074	25243	Economy	44300.00
0005433615772	25243	Economy	44300.00
0005433634451	25243	Economy	44300.00
0005433615820	25243	Economy	44300.00
0005433634455	25243	Economy	44300.00
0005433634506	25243	Economy	48700.00
0005434163858	25243	Economy	48700.00
0005433615697	25243	Economy	44300.00
0005433578066	25243	Economy	44300.00
0005433615593	25243	Economy	44300.00
0005433634418	25243	Economy	48700.00
0005433615965	25243	Economy	44300.00
0005433615811	25243	Economy	44300.00
0005433616034	25243	Economy	44300.00
0005433616033	25243	Economy	44300.00
0005434273119	25243	Economy	44300.00
0005435854078	25243	Economy	44300.00
0005433615934	25243	Economy	44300.00
0005433615880	25243	Economy	44300.00
0005433616170	25243	Economy	44300.00
0005433616133	25243	Economy	44300.00
0005434163853	25243	Economy	44300.00
0005433615753	25243	Economy	44300.00
0005433615761	25243	Economy	44300.00
0005433615882	25243	Economy	44300.00
0005433578036	25243	Economy	44300.00
0005433615860	25243	Economy	44300.00
0005433634524	25243	Economy	44300.00
0005433634336	25243	Economy	44300.00
0005433616125	25243	Economy	44300.00
0005433634246	25243	Economy	44300.00
0005433616330	25243	Economy	44300.00
0005433634484	25243	Economy	44300.00
0005433615878	25243	Economy	44300.00
0005433615920	25243	Economy	44300.00
0005435854081	25243	Economy	44300.00
0005433634432	25243	Economy	44300.00
0005433616056	25243	Economy	44300.00
0005433615961	25243	Economy	44300.00
0005433634433	25243	Economy	44300.00
0005434163855	25243	Economy	44300.00
0005433616141	25243	Economy	44300.00
0005433634431	25243	Economy	44300.00
0005433634322	25243	Economy	44300.00
0005433615908	25243	Economy	44300.00
0005433634462	25243	Economy	44300.00
0005433634434	25243	Economy	44300.00
0005433615661	25243	Economy	44300.00
0005433615794	25243	Economy	44300.00
0005434163859	25243	Economy	44300.00
0005433615907	25243	Economy	44300.00
0005435854088	25243	Economy	44300.00
0005433634435	25243	Economy	44300.00
0005433615932	25243	Economy	44300.00
0005433634564	25243	Economy	44300.00
0005435854090	25243	Economy	44300.00
0005434163856	25243	Economy	44300.00
0005433615969	25243	Economy	44300.00
0005433616030	25243	Economy	44300.00
0005433634440	25243	Economy	44300.00
0005433578114	25243	Economy	44300.00
0005433615755	25243	Economy	44300.00
0005434163861	25243	Economy	44300.00
0005434273132	25243	Economy	44300.00
0005433578037	25243	Economy	44300.00
0005433615798	25243	Economy	44300.00
0005433615752	25243	Economy	44300.00
0005433615906	25243	Economy	44300.00
0005433634452	25243	Economy	44300.00
0005435947527	4246	Business	193100.00
0005435947526	4246	Business	193100.00
0005435854070	4246	Business	193100.00
0005435947493	4246	Economy	70800.00
0005432571394	4246	Economy	64400.00
0005432185026	4246	Economy	64400.00
0005435947540	4246	Economy	64400.00
0005435947511	4246	Economy	64400.00
0005435856278	4246	Economy	64400.00
0005435947494	4246	Economy	64400.00
0005435947491	4246	Economy	64400.00
0005435947529	4246	Economy	64400.00
0005435947525	4246	Economy	64400.00
0005435947484	4246	Economy	64400.00
0005435947510	4246	Economy	64400.00
0005435856283	4246	Economy	64400.00
0005432185025	4246	Economy	64400.00
0005435947492	4246	Economy	64400.00
0005432571395	4246	Economy	64400.00
0005435947488	4246	Economy	64400.00
0005435947521	4246	Economy	64400.00
0005435856279	4246	Economy	64400.00
0005435947524	4246	Economy	64400.00
0005435947432	4246	Economy	64400.00
0005432571396	4246	Economy	64400.00
0005434271347	4246	Economy	64400.00
0005435947573	4246	Economy	64400.00
0005435947574	4246	Economy	64400.00
0005435856284	4246	Economy	64400.00
0005435854069	4246	Economy	64400.00
0005435947570	4246	Economy	64400.00
0005435947505	4246	Economy	64400.00
0005432185027	4246	Economy	64400.00
0005435947449	4246	Economy	64400.00
0005435947523	4246	Economy	64400.00
0005435947571	4246	Economy	64400.00
0005435947495	4246	Economy	64400.00
0005435947490	4246	Economy	64400.00
0005435986913	26580	Business	193100.00
0005435856318	26580	Business	193100.00
0005435856351	26580	Business	193100.00
0005435986911	26580	Business	193100.00
0005435986912	26580	Economy	64400.00
0005435947639	26580	Economy	64400.00
0005435856348	26580	Economy	64400.00
0005435986898	26580	Economy	64400.00
0005435986896	26580	Economy	64400.00
0005435856349	26580	Economy	64400.00
0005435856317	26580	Economy	64400.00
0005435986902	26580	Economy	64400.00
0005432571425	26580	Economy	64400.00
0005435947646	26580	Economy	64400.00
0005435986889	26580	Economy	64400.00
0005435947641	26580	Economy	64400.00
0005435986884	26580	Economy	64400.00
0005435947647	26580	Economy	64400.00
0005432571424	26580	Economy	64400.00
0005435856316	26580	Economy	64400.00
0005435856315	26580	Economy	64400.00
0005435947642	26580	Economy	64400.00
0005435856319	26580	Economy	64400.00
0005435856352	26580	Economy	64400.00
0005435947637	26580	Economy	64400.00
0005435947643	26580	Economy	64400.00
0005435986897	26580	Economy	64400.00
0005435986883	26580	Economy	64400.00
0005435947638	26580	Economy	64400.00
0005435986867	26580	Economy	64400.00
0005432571426	26580	Economy	64400.00
0005435856350	26580	Economy	64400.00
0005435947648	26580	Economy	64400.00
0005435947645	26580	Economy	64400.00
0005435947644	26580	Economy	64400.00
0005435947640	26580	Economy	64400.00
0005433570756	318	Business	21500.00
0005433075387	318	Business	21500.00
0005432949143	318	Business	21500.00
0005433075204	318	Business	21500.00
0005433570741	318	Business	21500.00
0005433570738	318	Business	21500.00
0005433570709	318	Business	21500.00
0005433570719	318	Business	21500.00
0005433570760	318	Business	21500.00
0005433570722	318	Business	21500.00
0005433570714	318	Business	21500.00
0005432949100	318	Business	21500.00
0005433570739	318	Business	21500.00
0005432949158	318	Business	21500.00
0005432949334	318	Business	21500.00
0005433570696	318	Business	21500.00
0005432949141	318	Business	21500.00
0005432239100	318	Business	21500.00
0005432949075	318	Business	21500.00
0005433075347	318	Business	21500.00
0005432949104	318	Business	21500.00
0005432949142	318	Business	21500.00
0005432949103	318	Business	21500.00
0005433570691	318	Business	21500.00
0005432949101	318	Business	21500.00
0005433570699	318	Business	21500.00
0005433570761	318	Economy	7900.00
0005432949166	318	Economy	7900.00
0005433570711	318	Economy	7900.00
0005433075344	318	Economy	7900.00
0005433570735	318	Economy	7900.00
0005433570726	318	Economy	7900.00
0005432949119	318	Economy	7200.00
0005433570708	318	Economy	7200.00
0005433570707	318	Economy	7200.00
0005433570728	318	Economy	7200.00
0005433570740	318	Economy	7200.00
0005432949333	318	Economy	7200.00
0005432949214	318	Economy	7200.00
0005432949110	318	Economy	7200.00
0005432239101	318	Economy	7200.00
0005432949305	318	Economy	7200.00
0005433570737	318	Economy	7200.00
0005432949198	318	Economy	7200.00
0005433570704	318	Economy	7200.00
0005432949218	318	Economy	7200.00
0005433570700	318	Economy	7200.00
0005432949304	318	Economy	7200.00
0005433570695	318	Economy	7200.00
0005432949311	318	Economy	7200.00
0005433570727	318	Economy	7200.00
0005433570736	318	Economy	7200.00
0005433570697	318	Economy	7200.00
0005433570743	318	Economy	7200.00
0005432239099	318	Economy	7200.00
0005432239098	318	Economy	7200.00
0005433570745	318	Economy	7200.00
0005433075355	318	Economy	7200.00
0005433134223	318	Economy	7200.00
0005433570754	318	Economy	7200.00
0005433075265	318	Economy	7200.00
0005433134222	318	Economy	7200.00
0005433570748	318	Economy	7200.00
0005433570701	318	Economy	7200.00
0005433075262	318	Economy	7200.00
0005432949168	318	Economy	7200.00
0005432239102	318	Economy	7200.00
0005433570692	318	Economy	7200.00
0005433134224	318	Economy	7200.00
0005432948932	318	Economy	7200.00
0005433570758	318	Economy	7200.00
0005433570721	318	Economy	7200.00
0005433570725	318	Economy	7200.00
0005433570710	318	Economy	7200.00
0005433075226	318	Economy	7200.00
0005433570706	318	Economy	7200.00
0005432949109	318	Economy	7200.00
0005433075278	318	Economy	7200.00
0005432949250	318	Economy	7200.00
0005433570753	318	Economy	7200.00
0005433075252	318	Economy	7200.00
0005433570757	318	Economy	7200.00
0005432949026	318	Economy	7200.00
0005433570732	318	Economy	7200.00
0005433075161	318	Economy	7200.00
0005432949017	318	Economy	7200.00
0005433570730	318	Economy	7200.00
0005433075215	318	Economy	7200.00
0005433570687	318	Economy	7900.00
0005433075175	318	Economy	7900.00
0005433075261	318	Economy	7900.00
0005433570694	318	Economy	7900.00
0005433570752	318	Economy	7900.00
0005432949245	318	Economy	7200.00
0005432949016	318	Economy	7200.00
0005432949291	318	Economy	7200.00
0005433570720	318	Economy	7200.00
0005434087927	318	Economy	7900.00
0005433570703	318	Economy	7200.00
0005433570690	318	Economy	7200.00
0005433570751	318	Economy	7200.00
0005433075246	318	Economy	7200.00
0005433570713	318	Economy	7200.00
0005433570717	318	Economy	7200.00
0005433075203	318	Economy	7200.00
0005433075219	318	Economy	7200.00
0005433570688	318	Economy	7200.00
0005433570723	318	Economy	7200.00
0005432949077	318	Economy	7200.00
0005433075179	318	Economy	7200.00
0005434087926	318	Economy	7200.00
0005433075174	318	Economy	7200.00
0005433570747	318	Economy	7200.00
0005433570718	318	Economy	7200.00
0005433570755	318	Economy	7200.00
0005433570744	318	Economy	7200.00
0005433075160	318	Economy	7200.00
0005433075162	318	Economy	7200.00
0005433134240	318	Economy	7200.00
0005433075173	318	Economy	7200.00
0005433075277	318	Economy	7200.00
0005433570705	318	Economy	7200.00
0005433570716	318	Economy	7200.00
0005433570724	318	Economy	7200.00
0005433129367	318	Economy	7200.00
0005433075251	318	Economy	7200.00
0005433570733	318	Economy	7200.00
0005432949249	318	Economy	7200.00
0005433570749	318	Economy	7200.00
0005433129366	318	Economy	7200.00
0005433570689	318	Economy	7200.00
0005433075227	318	Economy	7200.00
0005434087928	318	Economy	7200.00
0005433134194	318	Economy	7200.00
0005432949084	318	Economy	7200.00
0005432949157	318	Economy	7200.00
0005432949281	318	Economy	7200.00
0005433570731	318	Economy	7200.00
0005433570702	318	Economy	7200.00
0005433134241	318	Economy	7200.00
0005432949010	318	Economy	7200.00
0005433570693	318	Economy	7200.00
0005433570686	318	Economy	7200.00
0005432949140	318	Economy	7200.00
0005433570715	318	Economy	7200.00
0005433570759	318	Economy	7200.00
0005433570698	318	Economy	7200.00
0005432948933	318	Economy	7200.00
0005432949251	318	Economy	7200.00
0005432949011	318	Economy	7200.00
0005433570734	318	Economy	7200.00
0005433570750	318	Economy	7200.00
0005433570729	318	Economy	7200.00
0005433570762	318	Economy	7200.00
0005433570712	318	Economy	7200.00
0005433075354	318	Economy	7200.00
0005433134212	318	Economy	7200.00
0005433075216	318	Economy	7200.00
0005433570746	318	Economy	7200.00
0005433075260	318	Economy	7200.00
0005433570742	318	Economy	7200.00
0005433129369	318	Economy	7200.00
0005434087929	318	Economy	7200.00
0005433569754	11617	Business	21500.00
0005432949518	11617	Business	21500.00
0005433569773	11617	Business	21500.00
0005432949529	11617	Business	21500.00
0005433570148	11617	Business	21500.00
0005432949536	11617	Business	21500.00
0005433570244	11617	Business	21500.00
0005432949519	11617	Business	21500.00
0005432949553	11617	Business	21500.00
0005433570157	11617	Business	21500.00
0005433570056	11617	Business	21500.00
0005433569983	11617	Business	21500.00
0005433075459	11617	Business	21500.00
0005433570103	11617	Business	21500.00
0005433570156	11617	Business	21500.00
0005433075454	11617	Business	21500.00
0005433570102	11617	Business	21500.00
0005433569986	11617	Business	21500.00
0005433075464	11617	Business	21500.00
0005433569905	11617	Business	21500.00
0005433570093	11617	Business	21500.00
0005433075447	11617	Business	21500.00
0005433570101	11617	Business	21500.00
0005433570064	11617	Business	21500.00
0005433570243	11617	Economy	7900.00
0005433134256	11617	Economy	7900.00
0005432949545	11617	Economy	7900.00
0005433570115	11617	Economy	7900.00
0005432192403	11617	Economy	7900.00
0005432949539	11617	Economy	7200.00
0005433075460	11617	Economy	7200.00
0005433570245	11617	Economy	7200.00
0005433570023	11617	Economy	7200.00
0005432949548	11617	Economy	7200.00
0005433131828	11617	Economy	7200.00
0005433569989	11617	Economy	7200.00
0005432949541	11617	Economy	7200.00
0005433569906	11617	Economy	7200.00
0005432949532	11617	Economy	7200.00
0005433570146	11617	Economy	7200.00
0005433929877	11617	Economy	7200.00
0005433570145	11617	Economy	7200.00
0005433570078	11617	Economy	7200.00
0005433075467	11617	Economy	7200.00
0005433570126	11617	Economy	7200.00
0005432949530	11617	Economy	7200.00
0005433569835	11617	Economy	7200.00
0005432949526	11617	Economy	7200.00
0005432949537	11617	Economy	7200.00
0005433569975	11617	Economy	7200.00
0005433570021	11617	Economy	7200.00
0005433569670	11617	Economy	7200.00
0005433570231	11617	Economy	7200.00
0005433569843	11617	Economy	7200.00
0005433569796	11617	Economy	7200.00
0005433570149	11617	Economy	7200.00
0005432192405	11617	Economy	7200.00
0005433131827	11617	Economy	7200.00
0005433570208	11617	Economy	7200.00
0005433570058	11617	Economy	7200.00
0005433134254	11617	Economy	7200.00
0005433569799	11617	Economy	7200.00
0005432949528	11617	Economy	7200.00
0005433570130	11617	Economy	7200.00
0005433570036	11617	Economy	7200.00
0005433570217	11617	Economy	7200.00
0005433569830	11617	Economy	7200.00
0005433075452	11617	Economy	7200.00
0005432949552	11617	Economy	7200.00
0005433075449	11617	Economy	7200.00
0005433569812	11617	Economy	7200.00
0005433570250	11617	Economy	7200.00
0005432949554	11617	Economy	7200.00
0005433075455	11617	Economy	7200.00
0005432949525	11617	Economy	7200.00
0005433569976	11617	Economy	7200.00
0005433570135	11617	Economy	7200.00
0005432949546	11617	Economy	7200.00
0005432949550	11617	Economy	7200.00
0005433075448	11617	Economy	7200.00
0005432949522	11617	Economy	7200.00
0005433131829	11617	Economy	7200.00
0005433569873	11617	Economy	7200.00
0005432949517	11617	Economy	7200.00
0005432192404	11617	Economy	7900.00
0005433569985	11617	Economy	7900.00
0005433929876	11617	Economy	7900.00
0005433569977	11617	Economy	7900.00
0005433569940	11617	Economy	7200.00
0005433075456	11617	Economy	7200.00
0005432949535	11617	Economy	7200.00
0005433570022	11617	Economy	7900.00
0005433131830	11617	Economy	7200.00
0005433569919	11617	Economy	7200.00
0005432949523	11617	Economy	7200.00
0005432949549	11617	Economy	7200.00
0005433134255	11617	Economy	7200.00
0005433075445	11617	Economy	7200.00
0005433569798	11617	Economy	7200.00
0005432949543	11617	Economy	7200.00
0005433075461	11617	Economy	7200.00
0005432949524	11617	Economy	7200.00
0005433570010	11617	Economy	7200.00
0005433569957	11617	Economy	7200.00
0005432949551	11617	Economy	7200.00
0005433075453	11617	Economy	7200.00
0005433569984	11617	Economy	7200.00
0005433075463	11617	Economy	7200.00
0005433075451	11617	Economy	7200.00
0005433075444	11617	Economy	7200.00
0005433570169	11617	Economy	7200.00
0005432949547	11617	Economy	7200.00
0005433570092	11617	Economy	7200.00
0005433569958	11617	Economy	7200.00
0005432949534	11617	Economy	7200.00
0005433075458	11617	Economy	7200.00
0005432949527	11617	Economy	7200.00
0005432949538	11617	Economy	7200.00
0005432949540	11617	Economy	7200.00
0005433570194	11617	Economy	7200.00
0005433569797	11617	Economy	7200.00
0005433570127	11617	Economy	7200.00
0005433075450	11617	Economy	7200.00
0005432949520	11617	Economy	7200.00
0005432949544	11617	Economy	7200.00
0005432949533	11617	Economy	7200.00
0005433134253	11617	Economy	7200.00
0005433569776	11617	Economy	7200.00
0005433570063	11617	Economy	7200.00
0005433570108	11617	Economy	7200.00
0005433570099	11617	Economy	7200.00
0005432949542	11617	Economy	7200.00
0005433075466	11617	Economy	7200.00
0005433075457	11617	Economy	7200.00
0005433075446	11617	Economy	7200.00
0005433570057	11617	Economy	7200.00
0005433075462	11617	Economy	7200.00
0005433570107	11617	Economy	7200.00
0005433569834	11617	Economy	7200.00
0005433569995	11617	Economy	7200.00
0005433570264	11617	Economy	7200.00
0005432949521	11617	Economy	7200.00
0005433570009	11617	Economy	7200.00
0005432949531	11617	Economy	7200.00
0005433075465	11617	Economy	7200.00
0005433929878	11617	Economy	7200.00
0005433569959	11617	Economy	7200.00
0005433569918	11617	Economy	7200.00
0005433569978	11617	Economy	7200.00
0005433817570	9967	Economy	6300.00
0005433817571	9967	Economy	6300.00
0005433817568	9967	Economy	6300.00
0005433817567	9967	Economy	6300.00
0005433817569	9967	Economy	6300.00
0005434733074	13975	Economy	6300.00
0005434733076	13975	Economy	6300.00
0005433817540	13975	Economy	6300.00
0005434733075	13975	Economy	6300.00
0005433817533	13975	Economy	6300.00
0005432985722	2375	Business	184500.00
0005433755727	2375	Business	184500.00
0005435983533	2375	Business	184500.00
0005432226220	2375	Business	184500.00
0005432300420	2375	Business	184500.00
0005435983525	2375	Business	184500.00
0005432655859	2375	Business	184500.00
0005432985635	2375	Business	184500.00
0005435983539	2375	Business	184500.00
0005432655855	2375	Business	184500.00
0005433435261	2375	Business	184500.00
0005433435189	2375	Business	184500.00
0005435983513	2375	Business	184500.00
0005432985793	2375	Business	184500.00
0005433755702	2375	Business	184500.00
0005433755713	2375	Business	184500.00
0005435983499	2375	Business	184500.00
0005435983542	2375	Business	184500.00
0005432655854	2375	Business	184500.00
0005434731232	2375	Business	184500.00
0005434731235	2375	Business	184500.00
0005433435282	2375	Business	184500.00
0005433755723	2375	Business	184500.00
0005432869637	2375	Business	184500.00
0005435983518	2375	Business	184500.00
0005433435202	2375	Business	184500.00
0005432985708	2375	Business	184500.00
0005433755722	2375	Business	184500.00
0005432985399	2375	Economy	67700.00
0005433755691	2375	Economy	67700.00
0005433755728	2375	Economy	67700.00
0005433435066	2375	Economy	67700.00
0005433755706	2375	Economy	61500.00
0005432985766	2375	Economy	61500.00
0005435983530	2375	Economy	61500.00
0005434731252	2375	Economy	61500.00
0005433755711	2375	Economy	61500.00
0005433755694	2375	Economy	61500.00
0005433435045	2375	Economy	61500.00
0005433755689	2375	Economy	61500.00
0005432226221	2375	Economy	61500.00
0005433435243	2375	Economy	61500.00
0005435983528	2375	Economy	61500.00
0005435983506	2375	Economy	61500.00
0005433435260	2375	Economy	61500.00
0005432985662	2375	Economy	61500.00
0005433755715	2375	Economy	61500.00
0005433755704	2375	Economy	61500.00
0005433435218	2375	Economy	61500.00
0005432869655	2375	Economy	61500.00
0005432985740	2375	Economy	61500.00
0005432985600	2375	Economy	61500.00
0005432985631	2375	Economy	61500.00
0005433435152	2375	Economy	61500.00
0005435983507	2375	Economy	61500.00
0005432655858	2375	Economy	61500.00
0005432226219	2375	Economy	61500.00
0005435983502	2375	Economy	61500.00
0005432985580	2375	Economy	61500.00
0005433764734	2375	Economy	61500.00
0005434731251	2375	Economy	61500.00
0005432985621	2375	Economy	61500.00
0005435983545	2375	Economy	61500.00
0005433435240	2375	Economy	61500.00
0005435983517	2375	Economy	61500.00
0005433755725	2375	Economy	61500.00
0005432985794	2375	Economy	61500.00
0005433766740	2375	Economy	61500.00
0005433755699	2375	Economy	61500.00
0005433755712	2375	Economy	61500.00
0005433755701	2375	Economy	61500.00
0005433755724	2375	Economy	61500.00
0005433755697	2375	Economy	61500.00
0005433755703	2375	Economy	61500.00
0005432985681	2375	Economy	61500.00
0005432985490	2375	Economy	61500.00
0005433755700	2375	Economy	61500.00
0005435983512	2375	Economy	61500.00
0005435983524	2375	Economy	61500.00
0005432300418	2375	Economy	61500.00
0005433755717	2375	Economy	61500.00
0005435983500	2375	Economy	61500.00
0005433766741	2375	Economy	61500.00
0005432655853	2375	Economy	61500.00
0005433435151	2375	Economy	61500.00
0005435983541	2375	Economy	61500.00
0005435983504	2375	Economy	61500.00
0005433755693	2375	Economy	61500.00
0005433755731	2375	Economy	61500.00
0005432300416	2375	Economy	61500.00
0005435983527	2375	Economy	61500.00
0005435983535	2375	Economy	61500.00
0005433435142	2375	Economy	61500.00
0005432985491	2375	Economy	61500.00
0005432985710	2375	Economy	61500.00
0005433755718	2375	Economy	61500.00
0005432869652	2375	Economy	61500.00
0005433435217	2375	Economy	61500.00
0005433755708	2375	Economy	61500.00
0005433435143	2375	Economy	61500.00
0005433755714	2375	Economy	61500.00
0005433755688	2375	Economy	61500.00
0005435983516	2375	Economy	61500.00
0005432985721	2375	Economy	61500.00
0005432869620	2375	Economy	61500.00
0005433435281	2375	Economy	61500.00
0005432985739	2375	Economy	61500.00
0005434731234	2375	Economy	61500.00
0005435983498	2375	Economy	61500.00
0005434731244	2375	Economy	61500.00
0005432985684	2375	Economy	61500.00
0005433766739	2375	Economy	61500.00
0005432655852	2375	Economy	61500.00
0005435983522	2375	Economy	61500.00
0005432985737	2375	Economy	61500.00
0005433755720	2375	Economy	61500.00
0005432985717	2375	Economy	61500.00
0005432985623	2375	Economy	61500.00
0005435983519	2375	Economy	61500.00
0005433435163	2375	Economy	61500.00
0005433755709	2375	Economy	61500.00
0005433755696	2375	Economy	61500.00
0005433755705	2375	Economy	61500.00
0005432300419	2375	Economy	61500.00
0005433766761	2375	Economy	61500.00
0005432985756	2375	Economy	67700.00
0005432226222	2375	Economy	67700.00
0005432985797	2375	Economy	61500.00
0005435983503	2375	Economy	61500.00
0005433435044	2375	Economy	61500.00
0005435983540	2375	Economy	67700.00
0005435983515	2375	Economy	67700.00
0005432869619	2375	Economy	61500.00
0005432300417	2375	Economy	61500.00
0005434731240	2375	Economy	61500.00
0005433755710	2375	Economy	61500.00
0005433755719	2375	Economy	61500.00
0005435983508	2375	Economy	61500.00
0005432985680	2375	Economy	61500.00
0005432869622	2375	Economy	61500.00
0005433435144	2375	Economy	61500.00
0005432655856	2375	Economy	61500.00
0005433766742	2375	Economy	61500.00
0005432985661	2375	Economy	61500.00
0005433435242	2375	Economy	61500.00
0005433755726	2375	Economy	61500.00
0005433435286	2375	Economy	61500.00
0005433755707	2375	Economy	61500.00
0005433435185	2375	Economy	61500.00
0005432985798	2375	Economy	61500.00
0005435983520	2375	Economy	61500.00
0005435983538	2375	Economy	61500.00
0005433755730	2375	Economy	61500.00
0005435983501	2375	Economy	61500.00
0005434731233	2375	Economy	61500.00
0005433755695	2375	Economy	61500.00
0005432985800	2375	Economy	61500.00
0005432985683	2375	Economy	61500.00
0005435983505	2375	Economy	61500.00
0005433435231	2375	Economy	61500.00
0005432985801	2375	Economy	61500.00
0005433755692	2375	Economy	61500.00
0005432985624	2375	Economy	61500.00
0005432985632	2375	Economy	61500.00
0005432869656	2375	Economy	61500.00
0005432869630	2375	Economy	61500.00
0005432985671	2375	Economy	61500.00
0005432300415	2375	Economy	61500.00
0005435983534	2375	Economy	61500.00
0005435983537	2375	Economy	61500.00
0005433435239	2375	Economy	61500.00
0005435983543	2375	Economy	61500.00
0005432985581	2375	Economy	61500.00
0005435983510	2375	Economy	61500.00
0005433435241	2375	Economy	61500.00
0005435983523	2375	Economy	61500.00
0005432985652	2375	Economy	61500.00
0005435983514	2375	Economy	61500.00
0005435983544	2375	Economy	61500.00
0005432985622	2375	Economy	61500.00
0005433755698	2375	Economy	61500.00
0005435983526	2375	Economy	61500.00
0005435983511	2375	Economy	61500.00
0005433435197	2375	Economy	61500.00
0005433755690	2375	Economy	61500.00
0005433435232	2375	Economy	61500.00
0005433755721	2375	Economy	61500.00
0005432655857	2375	Economy	61500.00
0005432985675	2375	Economy	61500.00
0005432985664	2375	Economy	61500.00
0005435983529	2375	Economy	61500.00
0005434731239	2375	Economy	61500.00
0005433435098	2375	Economy	61500.00
0005432985400	2375	Economy	61500.00
0005435983509	2375	Economy	61500.00
0005433435196	2375	Economy	61500.00
0005433435162	2375	Economy	61500.00
0005432985718	2375	Economy	61500.00
0005433435226	2375	Economy	61500.00
0005435983521	2375	Economy	61500.00
0005433755716	2375	Economy	61500.00
0005435983532	2375	Economy	61500.00
0005435983536	2375	Economy	61500.00
0005432985663	2375	Economy	61500.00
0005434731231	2375	Economy	61500.00
0005432869629	2375	Economy	61500.00
0005433755729	2375	Economy	61500.00
0005435983531	2375	Economy	61500.00
0005433755014	26180	Business	184500.00
0005433755308	26180	Business	184500.00
0005432985932	26180	Business	184500.00
0005432985934	26180	Business	184500.00
0005433435428	26180	Business	184500.00
0005433755005	26180	Business	184500.00
0005432985940	26180	Business	184500.00
0005433435427	26180	Business	184500.00
0005433766687	26180	Business	184500.00
0005433755406	26180	Business	184500.00
0005433755378	26180	Business	184500.00
0005433435416	26180	Business	184500.00
0005435982982	26180	Business	184500.00
0005432655705	26180	Business	184500.00
0005432655755	26180	Business	184500.00
0005435983170	26180	Business	184500.00
0005433435426	26180	Business	184500.00
0005433755224	26180	Business	184500.00
0005433766697	26180	Business	184500.00
0005435983069	26180	Business	184500.00
0005433435417	26180	Business	184500.00
0005433755422	26180	Business	184500.00
0005432051211	26180	Business	184500.00
0005433755317	26180	Business	184500.00
0005432655724	26180	Business	184500.00
0005433755105	26180	Business	184500.00
0005433755024	26180	Business	184500.00
0005433766727	26180	Business	184500.00
0005432655738	26180	Economy	67700.00
0005435983112	26180	Economy	67700.00
0005433755247	26180	Economy	67700.00
0005433435433	26180	Economy	67700.00
0005433755350	26180	Economy	61500.00
0005432985929	26180	Economy	61500.00
0005433435425	26180	Economy	61500.00
0005433755379	26180	Economy	61500.00
0005432985939	26180	Economy	61500.00
0005432051210	26180	Economy	61500.00
0005435983219	26180	Economy	61500.00
0005432985926	26180	Economy	61500.00
0005433755421	26180	Economy	61500.00
0005432655752	26180	Economy	61500.00
0005435983096	26180	Economy	61500.00
0005435983168	26180	Economy	61500.00
0005433755505	26180	Economy	61500.00
0005432985931	26180	Economy	61500.00
0005432985937	26180	Economy	61500.00
0005433435431	26180	Economy	61500.00
0005432985928	26180	Economy	61500.00
0005433755305	26180	Economy	61500.00
0005435983054	26180	Economy	61500.00
0005435983087	26180	Economy	61500.00
0005433435412	26180	Economy	61500.00
0005433435434	26180	Economy	61500.00
0005433755407	26180	Economy	61500.00
0005435982818	26180	Economy	61500.00
0005435983034	26180	Economy	61500.00
0005433435414	26180	Economy	61500.00
0005432049559	26180	Economy	61500.00
0005435983274	26180	Economy	61500.00
0005433755408	26180	Economy	61500.00
0005435983197	26180	Economy	61500.00
0005433755434	26180	Economy	61500.00
0005435983068	26180	Economy	61500.00
0005433755299	26180	Economy	61500.00
0005433755363	26180	Economy	61500.00
0005433755192	26180	Economy	61500.00
0005432985925	26180	Economy	61500.00
0005433755231	26180	Economy	61500.00
0005432655754	26180	Economy	61500.00
0005433755142	26180	Economy	61500.00
0005433435430	26180	Economy	61500.00
0005433755134	26180	Economy	61500.00
0005433755385	26180	Economy	61500.00
0005433755090	26180	Economy	61500.00
0005435982950	26180	Economy	61500.00
0005433435429	26180	Economy	61500.00
0005435983198	26180	Economy	61500.00
0005433755445	26180	Economy	61500.00
0005433766720	26180	Economy	61500.00
0005433755235	26180	Economy	61500.00
0005433755302	26180	Economy	61500.00
0005435983152	26180	Economy	61500.00
0005433755144	26180	Economy	61500.00
0005435983182	26180	Economy	61500.00
0005433766725	26180	Economy	61500.00
0005435983105	26180	Economy	61500.00
0005432655712	26180	Economy	61500.00
0005433435423	26180	Economy	61500.00
0005435983012	26180	Economy	61500.00
0005433435424	26180	Economy	61500.00
0005433755420	26180	Economy	61500.00
0005432655735	26180	Economy	61500.00
0005433766716	26180	Economy	61500.00
0005433755262	26180	Economy	61500.00
0005433435410	26180	Economy	61500.00
0005432655737	26180	Economy	61500.00
0005435983085	26180	Economy	61500.00
0005433764716	26180	Economy	61500.00
0005432655740	26180	Economy	61500.00
0005432869702	26180	Economy	61500.00
0005435983145	26180	Economy	61500.00
0005433755015	26180	Economy	61500.00
0005432985938	26180	Economy	61500.00
0005432985924	26180	Economy	61500.00
0005433435413	26180	Economy	61500.00
0005433755161	26180	Economy	61500.00
0005433755301	26180	Economy	61500.00
0005433435415	26180	Economy	61500.00
0005432985930	26180	Economy	61500.00
0005435983258	26180	Economy	61500.00
0005432985941	26180	Economy	61500.00
0005433755230	26180	Economy	61500.00
0005435983261	26180	Economy	61500.00
0005432985936	26180	Economy	61500.00
0005433755218	26180	Economy	61500.00
0005432869698	26180	Economy	61500.00
0005433755352	26180	Economy	61500.00
0005433755263	26180	Economy	61500.00
0005433755201	26180	Economy	61500.00
0005432869701	26180	Economy	61500.00
0005432869696	26180	Economy	61500.00
0005433755250	26180	Economy	61500.00
0005433755306	26180	Economy	61500.00
0005433755261	26180	Economy	61500.00
0005433435432	26180	Economy	61500.00
0005433755435	26180	Economy	61500.00
0005432869700	26180	Economy	61500.00
0005433754980	26180	Economy	67700.00
0005433435420	26180	Economy	61500.00
0005432869697	26180	Economy	67700.00
0005435983064	26180	Economy	61500.00
0005433755240	26180	Economy	61500.00
0005435982946	26180	Economy	61500.00
0005433755199	26180	Economy	67700.00
0005433766698	26180	Economy	67700.00
0005435983106	26180	Economy	61500.00
0005433435418	26180	Economy	61500.00
0005433755274	26180	Economy	61500.00
0005435983260	26180	Economy	61500.00
0005432985922	26180	Economy	61500.00
0005432049560	26180	Economy	61500.00
0005433755315	26180	Economy	61500.00
0005432655753	26180	Economy	61500.00
0005435983035	26180	Economy	61500.00
0005435983144	26180	Economy	61500.00
0005432655725	26180	Economy	61500.00
0005435983259	26180	Economy	61500.00
0005432655710	26180	Economy	61500.00
0005435982819	26180	Economy	61500.00
0005435983220	26180	Economy	61500.00
0005435982945	26180	Economy	61500.00
0005433755314	26180	Economy	61500.00
0005435983070	26180	Economy	61500.00
0005432655706	26180	Economy	61500.00
0005435983127	26180	Economy	61500.00
0005432985927	26180	Economy	61500.00
0005432869699	26180	Economy	61500.00
0005432985942	26180	Economy	61500.00
0005435983039	26180	Economy	61500.00
0005433755232	26180	Economy	61500.00
0005433755206	26180	Economy	61500.00
0005434376162	26180	Economy	61500.00
0005434731284	26180	Economy	61500.00
0005435983086	26180	Economy	61500.00
0005434376163	26180	Economy	61500.00
0005433764717	26180	Economy	61500.00
0005432655730	26180	Economy	61500.00
0005435983142	26180	Economy	61500.00
0005433766699	26180	Economy	61500.00
0005435982974	26180	Economy	61500.00
0005434731283	26180	Economy	61500.00
0005433755241	26180	Economy	61500.00
0005433435411	26180	Economy	61500.00
0005433755381	26180	Economy	61500.00
0005433435419	26180	Economy	61500.00
0005432985923	26180	Economy	61500.00
0005435983135	26180	Economy	61500.00
0005435983147	26180	Economy	61500.00
0005432655751	26180	Economy	61500.00
0005433435409	26180	Economy	61500.00
0005435983169	26180	Economy	61500.00
0005432985935	26180	Economy	61500.00
0005435983116	26180	Economy	61500.00
0005435983062	26180	Economy	61500.00
0005433435421	26180	Economy	61500.00
0005435983181	26180	Economy	61500.00
0005435983063	26180	Economy	61500.00
0005433755219	26180	Economy	61500.00
0005434731285	26180	Economy	61500.00
0005433766726	26180	Economy	61500.00
0005435983095	26180	Economy	61500.00
0005432051212	26180	Economy	61500.00
0005433755136	26180	Economy	61500.00
0005433755104	26180	Economy	61500.00
0005435982997	26180	Economy	61500.00
0005432985933	26180	Economy	61500.00
0005433435422	26180	Economy	61500.00
0005435982960	26180	Economy	61500.00
0005435983115	26180	Economy	61500.00
0005433755135	26180	Economy	61500.00
0005433755313	26180	Economy	61500.00
0005433755300	26180	Economy	61500.00
0005435983163	26180	Economy	61500.00
0005433755307	26180	Economy	61500.00
0005433755351	26180	Economy	61500.00
0005432655736	26180	Economy	61500.00
0005432049558	26180	Economy	61500.00
0005435983214	26180	Economy	61500.00
0005435983213	26180	Economy	61500.00
0005434375901	1513	Business	38900.00
0005434375903	1513	Business	38900.00
0005434375867	1513	Business	38900.00
0005434375904	1513	Business	38900.00
0005433461647	1513	Business	38900.00
0005433931516	1513	Business	38900.00
0005433152151	1513	Business	38900.00
0005432268074	1513	Business	38900.00
0005434375865	1513	Business	38900.00
0005434375882	1513	Business	38900.00
0005434375880	1513	Business	38900.00
0005434375874	1513	Economy	13000.00
0005434375908	1513	Economy	13000.00
0005433151927	1513	Economy	13000.00
0005433151934	1513	Economy	13000.00
0005432268073	1513	Economy	13000.00
0005433931517	1513	Economy	13000.00
0005434375881	1513	Economy	13000.00
0005433152150	1513	Economy	13000.00
0005434029705	1513	Economy	13000.00
0005433764715	1513	Economy	13000.00
0005434375893	1513	Economy	13000.00
0005434375886	1513	Economy	13000.00
0005433152060	1513	Economy	13000.00
0005432268076	1513	Economy	13000.00
0005433152133	1513	Economy	13000.00
0005433151995	1513	Economy	13000.00
0005434375902	1513	Economy	13000.00
0005434375876	1513	Economy	13000.00
0005434375862	1513	Economy	13000.00
0005434375906	1513	Economy	13000.00
0005434375868	1513	Economy	13000.00
0005433152078	1513	Economy	13000.00
0005434375890	1513	Economy	13000.00
0005433151998	1513	Economy	13000.00
0005433152125	1513	Economy	13000.00
0005433151791	1513	Economy	13000.00
0005434375885	1513	Economy	13000.00
0005434375894	1513	Economy	13000.00
0005434375878	1513	Economy	13000.00
0005433151994	1513	Economy	13000.00
0005434375909	1513	Economy	13000.00
0005433151966	1513	Economy	13000.00
0005434375863	1513	Economy	13000.00
0005434375899	1513	Economy	14300.00
0005434375860	1513	Economy	14300.00
0005434375872	1513	Economy	14300.00
0005433152187	1513	Economy	14300.00
0005434375871	1513	Economy	14300.00
0005434375859	1513	Economy	13000.00
0005433152042	1513	Economy	13000.00
0005432268077	1513	Economy	13000.00
0005434375891	1513	Economy	13000.00
0005434375895	1513	Economy	13000.00
0005432268075	1513	Economy	13000.00
0005433152023	1513	Economy	13000.00
0005433152153	1513	Economy	13000.00
0005433931515	1513	Economy	13000.00
0005433152172	1513	Economy	13000.00
0005432268072	1513	Economy	13000.00
0005433152059	1513	Economy	13000.00
0005433152154	1513	Economy	13000.00
0005433460493	1513	Economy	13000.00
0005434375866	1513	Economy	13000.00
0005433764711	1513	Economy	13000.00
0005434375879	1513	Economy	13000.00
0005433152132	1513	Economy	13000.00
0005434375870	1513	Economy	13000.00
0005434375896	1513	Economy	13000.00
0005433461646	1513	Economy	13000.00
0005434375861	1513	Economy	13000.00
0005433151957	1513	Economy	13000.00
0005434375884	1513	Economy	13000.00
0005434375857	1513	Economy	13000.00
0005434375875	1513	Economy	13000.00
0005434375907	1513	Economy	13000.00
0005434375892	1513	Economy	13000.00
0005434375864	1513	Economy	13000.00
0005434375877	1513	Economy	13000.00
0005434375873	1513	Economy	13000.00
0005434375905	1513	Economy	13000.00
0005433152152	1513	Economy	13000.00
0005433152182	1513	Economy	13000.00
0005434375889	1513	Economy	13000.00
0005434375900	1513	Economy	13000.00
0005434375888	1513	Economy	13000.00
0005433931518	1513	Economy	13000.00
0005433151936	1513	Economy	13000.00
0005434375883	1513	Economy	13000.00
0005433152127	1513	Economy	13000.00
0005433152140	1513	Economy	13000.00
0005434375869	1513	Economy	13000.00
0005434375887	1513	Economy	13000.00
0005433152049	1513	Economy	13000.00
0005434375858	1513	Economy	13000.00
0005434375897	1513	Economy	13000.00
0005433151975	1513	Economy	13000.00
0005434375898	1513	Economy	13000.00
0005433151965	1513	Economy	13000.00
0005433152173	1513	Economy	13000.00
0005433152136	1513	Economy	13000.00
0005433152320	20102	Business	38900.00
0005433152316	20102	Business	38900.00
0005433152303	20102	Business	38900.00
0005434375439	20102	Business	38900.00
0005434029723	20102	Business	38900.00
0005434375718	20102	Business	38900.00
0005434375397	20102	Business	38900.00
0005434375517	20102	Business	38900.00
0005434375363	20102	Business	38900.00
0005433931548	20102	Business	38900.00
0005434375516	20102	Economy	13000.00
0005434375376	20102	Economy	13000.00
0005434375428	20102	Economy	13000.00
0005434375410	20102	Economy	13000.00
0005434375442	20102	Economy	13000.00
0005434375644	20102	Economy	13000.00
0005433152315	20102	Economy	13000.00
0005433152322	20102	Economy	13000.00
0005434375657	20102	Economy	13000.00
0005433152330	20102	Economy	13000.00
0005434375486	20102	Economy	13000.00
0005433152311	20102	Economy	13000.00
0005434375429	20102	Economy	13000.00
0005433764734	20102	Economy	13000.00
0005434375441	20102	Economy	13000.00
0005433152306	20102	Economy	13000.00
0005434375427	20102	Economy	13000.00
0005434375463	20102	Economy	13000.00
0005434375538	20102	Economy	13000.00
0005434375539	20102	Economy	13000.00
0005433152329	20102	Economy	13000.00
0005434375481	20102	Economy	13000.00
0005434375400	20102	Economy	13000.00
0005433152321	20102	Economy	13000.00
0005433152313	20102	Economy	13000.00
0005433152304	20102	Economy	13000.00
0005434375509	20102	Economy	13000.00
0005434375520	20102	Economy	13000.00
0005434375645	20102	Economy	13000.00
0005434375418	20102	Economy	14300.00
0005434375345	20102	Economy	14300.00
0005433152317	20102	Economy	14300.00
0005433152305	20102	Economy	14300.00
0005432056399	20102	Economy	13000.00
0005433152323	20102	Economy	13000.00
0005433931550	20102	Economy	13000.00
0005434375542	20102	Economy	13000.00
0005434375430	20102	Economy	13000.00
0005434375474	20102	Economy	13000.00
0005433931549	20102	Economy	13000.00
0005434375480	20102	Economy	13000.00
0005433152310	20102	Economy	13000.00
0005434375451	20102	Economy	13000.00
0005433152314	20102	Economy	13000.00
0005433152319	20102	Economy	13000.00
0005434375421	20102	Economy	13000.00
0005433152309	20102	Economy	13000.00
0005433152325	20102	Economy	13000.00
0005433152326	20102	Economy	13000.00
0005434375491	20102	Economy	13000.00
0005434375602	20102	Economy	13000.00
0005433152308	20102	Economy	13000.00
0005434375426	20102	Economy	13000.00
0005434375501	20102	Economy	13000.00
0005433152328	20102	Economy	13000.00
0005434375643	20102	Economy	13000.00
0005434375527	20102	Economy	13000.00
0005433152302	20102	Economy	13000.00
0005433152318	20102	Economy	13000.00
0005433152307	20102	Economy	13000.00
0005434375485	20102	Economy	13000.00
0005432056401	20102	Economy	13000.00
0005433152324	20102	Economy	13000.00
0005434375543	20102	Economy	13000.00
0005434375492	20102	Economy	13000.00
0005433152327	20102	Economy	13000.00
0005434375281	20102	Economy	13000.00
0005434375536	20102	Economy	13000.00
0005434375450	20102	Economy	13000.00
0005434375462	20102	Economy	13000.00
0005434375461	20102	Economy	13000.00
0005432056400	20102	Economy	13000.00
0005434029724	20102	Economy	13000.00
0005434375171	20102	Economy	13000.00
0005434375596	20102	Economy	13000.00
0005434375440	20102	Economy	13000.00
0005434375357	20102	Economy	13000.00
0005434375294	20102	Economy	13000.00
0005434375431	20102	Economy	13000.00
0005433152312	20102	Economy	13000.00
0005434375419	20102	Economy	13000.00
0005432425749	506	Business	27500.00
0005432425737	506	Business	27500.00
0005432425733	506	Business	27500.00
0005432425727	506	Business	27500.00
0005432283052	506	Economy	10100.00
0005432425732	506	Economy	10100.00
0005432425730	506	Economy	9200.00
0005432425748	506	Economy	9200.00
0005432425735	506	Economy	9200.00
0005432425717	506	Economy	9200.00
0005432425731	506	Economy	9200.00
0005432425719	506	Economy	9200.00
0005432425716	506	Economy	9200.00
0005432425718	506	Economy	9200.00
0005432425744	506	Economy	9200.00
0005432425743	506	Economy	9200.00
0005432425746	506	Economy	9200.00
0005432425740	506	Economy	9200.00
0005432425728	506	Economy	9200.00
0005432425725	506	Economy	9200.00
0005432425739	506	Economy	9200.00
0005432283048	506	Economy	9200.00
0005432425729	506	Economy	9200.00
0005432425753	506	Economy	9200.00
0005432283053	506	Economy	9200.00
0005432425726	506	Economy	9200.00
0005432425713	506	Economy	9200.00
0005432425742	506	Economy	9200.00
0005432425721	506	Economy	10100.00
0005432425738	506	Economy	10100.00
0005432425714	506	Economy	10100.00
0005432425715	506	Economy	9200.00
0005432425712	506	Economy	9200.00
0005432283049	506	Economy	9200.00
0005432425754	506	Economy	9200.00
0005432425741	506	Economy	9200.00
0005432425724	506	Economy	9200.00
0005432425734	506	Economy	9200.00
0005432283050	506	Economy	9200.00
0005432425722	506	Economy	9200.00
0005432425723	506	Economy	9200.00
0005432425720	506	Economy	9200.00
0005432283051	506	Economy	9200.00
0005432425750	506	Economy	9200.00
0005432425752	506	Economy	9200.00
0005432425736	506	Economy	9200.00
0005432425745	506	Economy	9200.00
0005432425751	506	Economy	9200.00
0005432425747	506	Economy	9200.00
0005432302433	12827	Business	27500.00
0005433261962	12827	Business	27500.00
0005433261946	12827	Business	27500.00
0005433766761	12827	Economy	10100.00
0005433261957	12827	Economy	10100.00
0005433261965	12827	Economy	10100.00
0005432302430	12827	Economy	9200.00
0005432302434	12827	Economy	9200.00
0005433261964	12827	Economy	9200.00
0005432302431	12827	Economy	9200.00
0005432302432	12827	Economy	9200.00
0005433261945	12827	Economy	9200.00
0005433261963	12827	Economy	9200.00
0005433261949	12827	Economy	10100.00
0005433261955	12827	Economy	10100.00
0005433261956	12827	Economy	9200.00
0005433261948	12827	Economy	10100.00
0005433261947	12827	Economy	9200.00
0005433261959	12827	Economy	9200.00
0005433261944	12827	Economy	9200.00
0005433261954	12827	Economy	9200.00
0005433261960	12827	Economy	9200.00
0005433261951	12827	Economy	9200.00
0005433261966	12827	Economy	9200.00
0005433261950	12827	Economy	9200.00
0005433261953	12827	Economy	9200.00
0005433261958	12827	Economy	9200.00
0005433261961	12827	Economy	9200.00
0005433261952	12827	Economy	9200.00
0005432425314	12851	Business	27500.00
0005432425031	12851	Business	27500.00
0005432425212	12851	Business	27500.00
0005432425319	12851	Business	27500.00
0005432425032	12851	Business	27500.00
0005432425307	12851	Business	27500.00
0005432425238	12851	Business	27500.00
0005432425138	12851	Economy	10100.00
0005432425325	12851	Economy	9200.00
0005432425315	12851	Economy	9200.00
0005432425214	12851	Economy	9200.00
0005432425318	12851	Economy	9200.00
0005432425310	12851	Economy	9200.00
0005432425267	12851	Economy	9200.00
0005432425263	12851	Economy	9200.00
0005432425157	12851	Economy	9200.00
0005432425326	12851	Economy	9200.00
0005432425254	12851	Economy	9200.00
0005432425268	12851	Economy	9200.00
0005432425287	12851	Economy	9200.00
0005432425260	12851	Economy	9200.00
0005432425278	12851	Economy	9200.00
0005432425237	12851	Economy	9200.00
0005432425309	12851	Economy	9200.00
0005432425306	12851	Economy	9200.00
0005432425205	12851	Economy	9200.00
0005432425289	12851	Economy	9200.00
0005432425333	12851	Economy	9200.00
0005432425335	12851	Economy	9200.00
0005432425334	12851	Economy	9200.00
0005432425192	12851	Economy	10100.00
0005432425279	12851	Economy	9200.00
0005432425158	12851	Economy	9200.00
0005432425311	12851	Economy	9200.00
0005432425332	12851	Economy	9200.00
0005432425320	12851	Economy	9200.00
0005432425213	12851	Economy	9200.00
0005432425285	12851	Economy	9200.00
0005432425261	12851	Economy	9200.00
0005432425207	12851	Economy	9200.00
0005432425156	12851	Economy	9200.00
0005432425291	12851	Economy	9200.00
0005432425206	12851	Economy	9200.00
0005432425247	12851	Economy	9200.00
0005432425324	12851	Economy	9200.00
0005432425280	12851	Economy	9200.00
0005432425312	12851	Economy	9200.00
0005432425284	12851	Economy	9200.00
0005432425308	12851	Economy	9200.00
0005432425286	12851	Economy	9200.00
0005433058649	472	Business	24500.00
0005434025489	472	Business	24500.00
0005432235841	472	Business	24500.00
0005434025503	472	Business	24500.00
0005434032143	472	Business	24500.00
0005432235836	472	Business	24500.00
0005433929678	472	Business	24500.00
0005434025533	472	Business	24500.00
0005434025523	472	Business	24500.00
0005434735776	472	Business	24500.00
0005434025513	472	Business	24500.00
0005434025500	472	Business	24500.00
0005434025481	472	Business	24500.00
0005434025478	472	Business	24500.00
0005434735774	472	Business	24500.00
0005434025506	472	Business	24500.00
0005434025479	472	Business	24500.00
0005434025527	472	Business	24500.00
0005433058755	472	Business	24500.00
0005433058643	472	Business	24500.00
0005434025517	472	Business	24500.00
0005434025507	472	Business	24500.00
0005432235835	472	Business	24500.00
0005433929684	472	Economy	9000.00
0005434025521	472	Economy	8200.00
0005433058490	472	Economy	8200.00
0005433058722	472	Economy	8200.00
0005434025480	472	Economy	8200.00
0005434735775	472	Economy	8200.00
0005434025504	472	Economy	8200.00
0005434025474	472	Economy	8200.00
0005433058654	472	Economy	8200.00
0005434025495	472	Economy	8200.00
0005434025519	472	Economy	8200.00
0005434025499	472	Economy	8200.00
0005433929680	472	Economy	8200.00
0005434025512	472	Economy	8200.00
0005433058668	472	Economy	8200.00
0005434735786	472	Economy	8200.00
0005433929683	472	Economy	8200.00
0005433058642	472	Economy	8200.00
0005434025511	472	Economy	8200.00
0005433058721	472	Economy	8200.00
0005434025524	472	Economy	8200.00
0005433058554	472	Economy	8200.00
0005433058842	472	Economy	8200.00
0005434032141	472	Economy	8200.00
0005434025530	472	Economy	8200.00
0005434028381	472	Economy	8200.00
0005434025536	472	Economy	8200.00
0005434025522	472	Economy	8200.00
0005432235839	472	Economy	8200.00
0005432045663	472	Economy	8200.00
0005434025494	472	Economy	8200.00
0005433929687	472	Economy	8200.00
0005434025516	472	Economy	8200.00
0005434025528	472	Economy	8200.00
0005433058587	472	Economy	8200.00
0005434025505	472	Economy	8200.00
0005433058686	472	Economy	8200.00
0005434735771	472	Economy	8200.00
0005434025526	472	Economy	8200.00
0005434025487	472	Economy	8200.00
0005434735769	472	Economy	8200.00
0005434025518	472	Economy	8200.00
0005433058841	472	Economy	8200.00
0005434025483	472	Economy	8200.00
0005434025510	472	Economy	8200.00
0005433058528	472	Economy	8200.00
0005434025509	472	Economy	8200.00
0005433058553	472	Economy	8200.00
0005434029720	472	Economy	8200.00
0005434025525	472	Economy	8200.00
0005434029722	472	Economy	8200.00
0005434025498	472	Economy	8200.00
0005434025485	472	Economy	8200.00
0005434735770	472	Economy	8200.00
0005433058602	472	Economy	8200.00
0005434025492	472	Economy	8200.00
0005434025508	472	Economy	8200.00
0005434025515	472	Economy	8200.00
0005433058594	472	Economy	8200.00
0005433929681	472	Economy	8200.00
0005433929686	472	Economy	8200.00
0005433058695	472	Economy	8200.00
0005434028384	472	Economy	8200.00
0005433058682	472	Economy	8200.00
0005432235840	472	Economy	8200.00
0005433058892	472	Economy	8200.00
0005433058742	472	Economy	8200.00
0005434025531	472	Economy	8200.00
0005434025491	472	Economy	8200.00
0005434032144	472	Economy	8200.00
0005433058890	472	Economy	8200.00
0005433929685	472	Economy	8200.00
0005433058653	472	Economy	9000.00
0005434025486	472	Economy	8200.00
0005433058579	472	Economy	8200.00
0005434025539	472	Economy	8200.00
0005434025496	472	Economy	9000.00
0005434025488	472	Economy	8200.00
0005434735772	472	Economy	8200.00
0005433058891	472	Economy	8200.00
0005434025501	472	Economy	8200.00
0005434028383	472	Economy	8200.00
0005433058580	472	Economy	8200.00
0005434032145	472	Economy	8200.00
0005434025482	472	Economy	8200.00
0005434025502	472	Economy	8200.00
0005434025497	472	Economy	8200.00
0005433058696	472	Economy	8200.00
0005432235842	472	Economy	8200.00
0005434025476	472	Economy	8200.00
0005433058677	472	Economy	8200.00
0005433058667	472	Economy	8200.00
0005433058593	472	Economy	8200.00
0005434025475	472	Economy	8200.00
0005434025520	472	Economy	8200.00
0005433058557	472	Economy	8200.00
0005434025535	472	Economy	8200.00
0005433058716	472	Economy	8200.00
0005433929682	472	Economy	8200.00
0005433058650	472	Economy	8200.00
0005434025493	472	Economy	8200.00
0005433058639	472	Economy	8200.00
0005434025514	472	Economy	8200.00
0005433058756	472	Economy	8200.00
0005432235837	472	Economy	8200.00
0005433058835	472	Economy	8200.00
0005434028382	472	Economy	8200.00
0005434029721	472	Economy	8200.00
0005432235834	472	Economy	8200.00
0005434025538	472	Economy	8200.00
0005434025532	472	Economy	8200.00
0005434025490	472	Economy	8200.00
0005432235838	472	Economy	8200.00
0005434025534	472	Economy	8200.00
0005433058578	472	Economy	8200.00
0005433058701	472	Economy	8200.00
0005432045664	472	Economy	8200.00
0005434025537	472	Economy	8200.00
0005433058529	472	Economy	8200.00
0005434025477	472	Economy	8200.00
0005434032142	472	Economy	8200.00
0005433058711	472	Economy	8200.00
0005433058743	472	Economy	8200.00
0005434025484	472	Economy	8200.00
0005433058644	472	Economy	8200.00
0005434025529	472	Economy	8200.00
0005432157544	12695	Business	24500.00
0005433058940	12695	Business	24500.00
0005432156483	12695	Business	24500.00
0005433058959	12695	Business	24500.00
0005433058949	12695	Business	24500.00
0005433058947	12695	Business	24500.00
0005432157543	12695	Business	24500.00
0005432156484	12695	Business	24500.00
0005434025178	12695	Business	24500.00
0005434025047	12695	Business	24500.00
0005434025000	12695	Business	24500.00
0005434032119	12695	Business	24500.00
0005434025199	12695	Business	24500.00
0005433058934	12695	Business	24500.00
0005433058936	12695	Economy	9000.00
0005433058944	12695	Economy	9000.00
0005434024850	12695	Economy	8200.00
0005433058941	12695	Economy	8200.00
0005434024831	12695	Economy	8200.00
0005434024832	12695	Economy	8200.00
0005434024663	12695	Economy	8200.00
0005433058955	12695	Economy	8200.00
0005434024775	12695	Economy	8200.00
0005434032086	12695	Economy	8200.00
0005434024708	12695	Economy	8200.00
0005434025049	12695	Economy	8200.00
0005434024776	12695	Economy	8200.00
0005433684476	12695	Economy	8200.00
0005434024980	12695	Economy	8200.00
0005434024960	12695	Economy	8200.00
0005434025046	12695	Economy	8200.00
0005434032124	12695	Economy	8200.00
0005433684475	12695	Economy	8200.00
0005433058930	12695	Economy	8200.00
0005434025266	12695	Economy	8200.00
0005434024892	12695	Economy	8200.00
0005433058943	12695	Economy	8200.00
0005433058951	12695	Economy	8200.00
0005433058962	12695	Economy	8200.00
0005434735829	12695	Economy	8200.00
0005434025011	12695	Economy	8200.00
0005433058958	12695	Economy	8200.00
0005432156481	12695	Economy	8200.00
0005432157542	12695	Economy	8200.00
0005433058939	12695	Economy	8200.00
0005434025074	12695	Economy	8200.00
0005434024761	12695	Economy	8200.00
0005434024816	12695	Economy	8200.00
0005434024899	12695	Economy	8200.00
0005434032104	12695	Economy	8200.00
0005433058952	12695	Economy	8200.00
0005433058948	12695	Economy	8200.00
0005434024997	12695	Economy	8200.00
0005434024869	12695	Economy	8200.00
0005434024961	12695	Economy	8200.00
0005433058960	12695	Economy	8200.00
0005433058957	12695	Economy	8200.00
0005434735831	12695	Economy	8200.00
0005434024991	12695	Economy	8200.00
0005434024988	12695	Economy	8200.00
0005433058956	12695	Economy	8200.00
0005434735830	12695	Economy	8200.00
0005434024744	12695	Economy	8200.00
0005433058942	12695	Economy	8200.00
0005434024743	12695	Economy	8200.00
0005434025027	12695	Economy	8200.00
0005434024964	12695	Economy	8200.00
0005434024762	12695	Economy	8200.00
0005434024863	12695	Economy	8200.00
0005434032095	12695	Economy	8200.00
0005433058963	12695	Economy	8200.00
0005434024979	12695	Economy	8200.00
0005434024760	12695	Economy	8200.00
0005434029705	12695	Economy	8200.00
0005434024911	12695	Economy	8200.00
0005434024849	12695	Economy	8200.00
0005434735828	12695	Economy	9000.00
0005433058946	12695	Economy	9000.00
0005434735827	12695	Economy	8200.00
0005434025035	12695	Economy	8200.00
0005434024999	12695	Economy	8200.00
0005433929718	12695	Economy	8200.00
0005434024790	12695	Economy	8200.00
0005434024835	12695	Economy	8200.00
0005433058933	12695	Economy	8200.00
0005434024664	12695	Economy	8200.00
0005434024973	12695	Economy	8200.00
0005434025066	12695	Economy	8200.00
0005433058938	12695	Economy	8200.00
0005433058929	12695	Economy	8200.00
0005434024965	12695	Economy	8200.00
0005433058954	12695	Economy	8200.00
0005433684474	12695	Economy	8200.00
0005433929719	12695	Economy	8200.00
0005434025165	12695	Economy	8200.00
0005433058950	12695	Economy	8200.00
0005434024916	12695	Economy	8200.00
0005434025045	12695	Economy	8200.00
0005433058953	12695	Economy	8200.00
0005434024602	12695	Economy	8200.00
0005434024729	12695	Economy	8200.00
0005434025111	12695	Economy	8200.00
0005434024818	12695	Economy	8200.00
0005433058932	12695	Economy	8200.00
0005433058931	12695	Economy	8200.00
0005434028328	12695	Economy	8200.00
0005434024774	12695	Economy	8200.00
0005434025010	12695	Economy	8200.00
0005434024833	12695	Economy	8200.00
0005433058961	12695	Economy	8200.00
0005433058945	12695	Economy	8200.00
0005434024830	12695	Economy	8200.00
0005434024989	12695	Economy	8200.00
0005432156482	12695	Economy	8200.00
0005433929720	12695	Economy	8200.00
0005434025048	12695	Economy	8200.00
0005433058937	12695	Economy	8200.00
0005433058935	12695	Economy	8200.00
0005434735826	12695	Economy	8200.00
0005433925813	2136	Business	34700.00
0005433925828	2136	Business	34700.00
0005433037279	2136	Business	34700.00
0005433037106	2136	Business	34700.00
0005432231847	2136	Business	34700.00
0005433925856	2136	Business	34700.00
0005433037565	2136	Business	34700.00
0005433929718	2136	Business	34700.00
0005433037270	2136	Business	34700.00
0005433037412	2136	Business	34700.00
0005433925834	2136	Business	34700.00
0005433925809	2136	Business	34700.00
0005433037332	2136	Business	34700.00
0005433925850	2136	Business	34700.00
0005433925869	2136	Business	34700.00
0005433037272	2136	Business	34700.00
0005433925880	2136	Business	34700.00
0005433925858	2136	Business	34700.00
0005433931550	2136	Business	34700.00
0005433925835	2136	Business	34700.00
0005432231843	2136	Business	34700.00
0005433925889	2136	Business	34700.00
0005433925868	2136	Business	34700.00
0005433925866	2136	Business	34700.00
0005433925821	2136	Economy	12700.00
0005433037437	2136	Economy	12700.00
0005433929720	2136	Economy	12700.00
0005433037385	2136	Economy	11600.00
0005433037091	2136	Economy	12700.00
0005433925885	2136	Economy	11600.00
0005433929875	2136	Economy	11600.00
0005432231853	2136	Economy	11600.00
0005433925864	2136	Economy	11600.00
0005433037082	2136	Economy	11600.00
0005433925840	2136	Economy	11600.00
0005433925888	2136	Economy	11600.00
0005433037409	2136	Economy	11600.00
0005433037347	2136	Economy	11600.00
0005433037084	2136	Economy	11600.00
0005433037105	2136	Economy	11600.00
0005433037293	2136	Economy	11600.00
0005433925808	2136	Economy	11600.00
0005433925870	2136	Economy	11600.00
0005433037114	2136	Economy	11600.00
0005433925867	2136	Economy	11600.00
0005433925837	2136	Economy	11600.00
0005433037205	2136	Economy	11600.00
0005433037075	2136	Economy	11600.00
0005433925859	2136	Economy	11600.00
0005433925846	2136	Economy	11600.00
0005433037289	2136	Economy	11600.00
0005433929719	2136	Economy	11600.00
0005433925816	2136	Economy	11600.00
0005433925863	2136	Economy	11600.00
0005432044599	2136	Economy	11600.00
0005433925883	2136	Economy	11600.00
0005433931549	2136	Economy	11600.00
0005433037116	2136	Economy	11600.00
0005432231848	2136	Economy	11600.00
0005433925802	2136	Economy	11600.00
0005433925891	2136	Economy	11600.00
0005433925857	2136	Economy	11600.00
0005433037146	2136	Economy	11600.00
0005433925843	2136	Economy	11600.00
0005433037194	2136	Economy	11600.00
0005433925829	2136	Economy	11600.00
0005433929873	2136	Economy	11600.00
0005433925830	2136	Economy	11600.00
0005433925836	2136	Economy	11600.00
0005432231850	2136	Economy	11600.00
0005433925876	2136	Economy	11600.00
0005433037521	2136	Economy	11600.00
0005433037393	2136	Economy	11600.00
0005433925803	2136	Economy	11600.00
0005433037215	2136	Economy	11600.00
0005433037323	2136	Economy	11600.00
0005433925817	2136	Economy	11600.00
0005433925854	2136	Economy	11600.00
0005433037335	2136	Economy	11600.00
0005433925818	2136	Economy	11600.00
0005432231842	2136	Economy	11600.00
0005433037459	2136	Economy	11600.00
0005433037453	2136	Economy	11600.00
0005433925892	2136	Economy	11600.00
0005433925806	2136	Economy	11600.00
0005433037153	2136	Economy	11600.00
0005433925845	2136	Economy	11600.00
0005433925833	2136	Economy	11600.00
0005433925825	2136	Economy	11600.00
0005433925811	2136	Economy	11600.00
0005433037094	2136	Economy	11600.00
0005433037460	2136	Economy	11600.00
0005433037495	2136	Economy	11600.00
0005433875423	2136	Economy	11600.00
0005433925839	2136	Economy	11600.00
0005433925852	2136	Economy	11600.00
0005433925853	2136	Economy	11600.00
0005433037163	2136	Economy	11600.00
0005432231846	2136	Economy	11600.00
0005433036937	2136	Economy	11600.00
0005433925831	2136	Economy	11600.00
0005433925810	2136	Economy	11600.00
0005433037336	2136	Economy	11600.00
0005432231844	2136	Economy	11600.00
0005433925832	2136	Economy	11600.00
0005432749823	2136	Economy	11600.00
0005433925849	2136	Economy	11600.00
0005433875424	2136	Economy	11600.00
0005433037411	2136	Economy	11600.00
0005433037302	2136	Economy	12700.00
0005433925820	2136	Economy	12700.00
0005433037355	2136	Economy	11600.00
0005433929874	2136	Economy	11600.00
0005433929872	2136	Economy	11600.00
0005433925847	2136	Economy	12700.00
0005433037288	2136	Economy	12700.00
0005433925848	2136	Economy	11600.00
0005433037230	2136	Economy	11600.00
0005433925824	2136	Economy	11600.00
0005433925879	2136	Economy	11600.00
0005433925887	2136	Economy	11600.00
0005433925878	2136	Economy	11600.00
0005433925890	2136	Economy	11600.00
0005433925838	2136	Economy	11600.00
0005432044600	2136	Economy	11600.00
0005433925812	2136	Economy	11600.00
0005433925804	2136	Economy	11600.00
0005433925872	2136	Economy	11600.00
0005433925886	2136	Economy	11600.00
0005433925882	2136	Economy	11600.00
0005433037432	2136	Economy	11600.00
0005433037154	2136	Economy	11600.00
0005433037271	2136	Economy	11600.00
0005433925855	2136	Economy	11600.00
0005433925827	2136	Economy	11600.00
0005433925815	2136	Economy	11600.00
0005433037386	2136	Economy	11600.00
0005433925861	2136	Economy	11600.00
0005432044598	2136	Economy	11600.00
0005433925851	2136	Economy	11600.00
0005433925877	2136	Economy	11600.00
0005433037152	2136	Economy	11600.00
0005433925860	2136	Economy	11600.00
0005433925844	2136	Economy	11600.00
0005433925814	2136	Economy	11600.00
0005433925884	2136	Economy	11600.00
0005433925875	2136	Economy	11600.00
0005433037104	2136	Economy	11600.00
0005433037424	2136	Economy	11600.00
0005433925842	2136	Economy	11600.00
0005433037145	2136	Economy	11600.00
0005433036936	2136	Economy	11600.00
0005432231851	2136	Economy	11600.00
0005432231845	2136	Economy	11600.00
0005433037331	2136	Economy	11600.00
0005433925862	2136	Economy	11600.00
0005433925805	2136	Economy	11600.00
0005433037115	2136	Economy	11600.00
0005433925874	2136	Economy	11600.00
0005433925822	2136	Economy	11600.00
0005432231849	2136	Economy	11600.00
0005433037354	2136	Economy	11600.00
0005433925871	2136	Economy	11600.00
0005432044597	2136	Economy	11600.00
0005433925826	2136	Economy	11600.00
0005433037423	2136	Economy	11600.00
0005433037229	2136	Economy	11600.00
0005434028328	2136	Economy	11600.00
0005432231852	2136	Economy	11600.00
0005433925873	2136	Economy	11600.00
0005433037333	2136	Economy	11600.00
0005433925807	2136	Economy	11600.00
0005433037103	2136	Economy	11600.00
0005433037303	2136	Economy	11600.00
0005432749824	2136	Economy	11600.00
0005433931548	2136	Economy	11600.00
0005433925823	2136	Economy	11600.00
0005433925841	2136	Economy	11600.00
0005433925819	2136	Economy	11600.00
0005433037322	2136	Economy	11600.00
0005433037496	2136	Economy	11600.00
0005433037433	2136	Economy	11600.00
0005433925865	2136	Economy	11600.00
0005432749819	2136	Economy	11600.00
0005433925881	2136	Economy	11600.00
0005433037702	24112	Business	34700.00
0005433925305	24112	Business	34700.00
0005433924579	24112	Business	34700.00
0005433037682	24112	Business	34700.00
0005433924883	24112	Business	34700.00
0005433924577	24112	Business	34700.00
0005433925396	24112	Business	34700.00
0005433924195	24112	Business	34700.00
0005433875405	24112	Business	34700.00
0005433924845	24112	Business	34700.00
0005433037673	24112	Business	34700.00
0005433924939	24112	Business	34700.00
0005433875407	24112	Business	34700.00
0005433037699	24112	Business	34700.00
0005433924650	24112	Business	34700.00
0005433037688	24112	Business	34700.00
0005433925135	24112	Business	34700.00
0005433924776	24112	Business	34700.00
0005433924561	24112	Business	34700.00
0005433924661	24112	Business	34700.00
0005433037692	24112	Business	34700.00
0005433924662	24112	Business	34700.00
0005432206351	24112	Economy	12700.00
0005434376179	24112	Economy	12700.00
0005433929862	24112	Economy	12700.00
0005433037705	24112	Economy	11600.00
0005433924787	24112	Economy	11600.00
0005433924652	24112	Economy	11600.00
0005433924554	24112	Economy	11600.00
0005433037691	24112	Economy	11600.00
0005434376181	24112	Economy	11600.00
0005433925119	24112	Economy	11600.00
0005433925136	24112	Economy	11600.00
0005433037669	24112	Economy	11600.00
0005433925346	24112	Economy	11600.00
0005433037711	24112	Economy	11600.00
0005433924779	24112	Economy	11600.00
0005433925287	24112	Economy	11600.00
0005433925001	24112	Economy	11600.00
0005433037703	24112	Economy	11600.00
0005433925286	24112	Economy	11600.00
0005433924981	24112	Economy	11600.00
0005433925094	24112	Economy	11600.00
0005433929692	24112	Economy	11600.00
0005433925345	24112	Economy	11600.00
0005432207732	24112	Economy	11600.00
0005433924801	24112	Economy	11600.00
0005433037693	24112	Economy	11600.00
0005433037689	24112	Economy	11600.00
0005433925103	24112	Economy	11600.00
0005433924714	24112	Economy	11600.00
0005432206354	24112	Economy	11600.00
0005433925167	24112	Economy	11600.00
0005432206349	24112	Economy	11600.00
0005433037675	24112	Economy	11600.00
0005433924889	24112	Economy	11600.00
0005433037694	24112	Economy	11600.00
0005433037708	24112	Economy	11600.00
0005433037700	24112	Economy	11600.00
0005433925036	24112	Economy	11600.00
0005432749842	24112	Economy	11600.00
0005433875406	24112	Economy	11600.00
0005433037709	24112	Economy	11600.00
0005433037713	24112	Economy	11600.00
0005433037676	24112	Economy	11600.00
0005433925093	24112	Economy	11600.00
0005433924859	24112	Economy	11600.00
0005433925008	24112	Economy	11600.00
0005433924684	24112	Economy	11600.00
0005433925262	24112	Economy	11600.00
0005434028385	24112	Economy	11600.00
0005432206350	24112	Economy	11600.00
0005433924780	24112	Economy	11600.00
0005433925196	24112	Economy	11600.00
0005433037677	24112	Economy	11600.00
0005433925035	24112	Economy	11600.00
0005433924963	24112	Economy	11600.00
0005433924782	24112	Economy	11600.00
0005433925179	24112	Economy	11600.00
0005433037695	24112	Economy	11600.00
0005433037704	24112	Economy	11600.00
0005433924774	24112	Economy	11600.00
0005433925395	24112	Economy	11600.00
0005433037684	24112	Economy	11600.00
0005433037707	24112	Economy	11600.00
0005433925304	24112	Economy	11600.00
0005433925096	24112	Economy	11600.00
0005432206352	24112	Economy	11600.00
0005433925030	24112	Economy	11600.00
0005433924864	24112	Economy	11600.00
0005433037712	24112	Economy	11600.00
0005433925371	24112	Economy	11600.00
0005433925394	24112	Economy	11600.00
0005433929679	24112	Economy	11600.00
0005433925055	24112	Economy	11600.00
0005433925168	24112	Economy	11600.00
0005433924962	24112	Economy	11600.00
0005433924718	24112	Economy	11600.00
0005434028387	24112	Economy	11600.00
0005433924775	24112	Economy	12700.00
0005433875397	24112	Economy	12700.00
0005433037714	24112	Economy	11600.00
0005433037670	24112	Economy	11600.00
0005433925129	24112	Economy	11600.00
0005433037687	24112	Economy	11600.00
0005433925080	24112	Economy	11600.00
0005433924952	24112	Economy	11600.00
0005433037685	24112	Economy	11600.00
0005433924555	24112	Economy	11600.00
0005433924807	24112	Economy	11600.00
0005433929861	24112	Economy	11600.00
0005433925095	24112	Economy	11600.00
0005433924553	24112	Economy	11600.00
0005433037706	24112	Economy	11600.00
0005433037672	24112	Economy	11600.00
0005433037671	24112	Economy	11600.00
0005433925134	24112	Economy	11600.00
0005433925372	24112	Economy	11600.00
0005433924778	24112	Economy	11600.00
0005433929860	24112	Economy	11600.00
0005433924884	24112	Economy	11600.00
0005433037690	24112	Economy	11600.00
0005433925298	24112	Economy	11600.00
0005433037715	24112	Economy	11600.00
0005434376180	24112	Economy	11600.00
0005433924971	24112	Economy	11600.00
0005433037696	24112	Economy	11600.00
0005433925348	24112	Economy	11600.00
0005433929859	24112	Economy	11600.00
0005434028386	24112	Economy	11600.00
0005433037686	24112	Economy	11600.00
0005433924578	24112	Economy	11600.00
0005433924423	24112	Economy	11600.00
0005433925263	24112	Economy	11600.00
0005433037701	24112	Economy	11600.00
0005433929676	24112	Economy	11600.00
0005433037680	24112	Economy	11600.00
0005433924846	24112	Economy	11600.00
0005434376178	24112	Economy	11600.00
0005432206353	24112	Economy	11600.00
0005433925243	24112	Economy	11600.00
0005433037681	24112	Economy	11600.00
0005433037697	24112	Economy	11600.00
0005433037683	24112	Economy	11600.00
0005433924980	24112	Economy	11600.00
0005433924838	24112	Economy	11600.00
0005433037679	24112	Economy	11600.00
0005433037674	24112	Economy	11600.00
0005433925211	24112	Economy	11600.00
0005433037698	24112	Economy	11600.00
0005432207731	24112	Economy	11600.00
0005432749843	24112	Economy	11600.00
0005433925118	24112	Economy	11600.00
0005433037678	24112	Economy	11600.00
0005433924888	24112	Economy	11600.00
0005433037710	24112	Economy	11600.00
0005434728677	274	Business	83700.00
0005435142932	274	Business	83700.00
0005433181480	274	Business	83700.00
0005434728660	274	Business	83700.00
0005433235519	274	Business	83700.00
0005434728626	274	Business	83700.00
0005433235357	274	Business	83700.00
0005433234904	274	Business	83700.00
0005433126932	274	Business	83700.00
0005433235125	274	Business	83700.00
0005433289987	274	Business	83700.00
0005434728715	274	Business	83700.00
0005433131787	274	Business	83700.00
0005434302900	274	Business	83700.00
0005433181453	274	Business	83700.00
0005434728633	274	Business	83700.00
0005433235485	274	Business	83700.00
0005434552696	274	Business	83700.00
0005433181582	274	Business	83700.00
0005434552684	274	Business	83700.00
0005433235307	274	Business	83700.00
0005434728623	274	Business	83700.00
0005433235225	274	Business	83700.00
0005434728695	274	Business	83700.00
0005433235162	274	Business	83700.00
0005433235031	274	Comfort	47400.00
0005433289996	274	Comfort	47400.00
0005434728659	274	Comfort	47400.00
0005433235280	274	Comfort	47400.00
0005434728632	274	Comfort	47400.00
0005433235738	274	Comfort	47400.00
0005434728690	274	Comfort	47400.00
0005435142925	274	Comfort	47400.00
0005434728700	274	Comfort	47400.00
0005434032120	274	Comfort	47400.00
0005434728674	274	Comfort	47400.00
0005433235145	274	Comfort	47400.00
0005433235258	274	Comfort	47400.00
0005434552698	274	Comfort	47400.00
0005434552707	274	Comfort	47400.00
0005433181521	274	Comfort	47400.00
0005434728685	274	Comfort	47400.00
0005434552694	274	Comfort	47400.00
0005433766702	274	Comfort	47400.00
0005433235203	274	Comfort	47400.00
0005434728641	274	Comfort	47400.00
0005433235165	274	Comfort	47400.00
0005432278162	274	Comfort	47400.00
0005434552693	274	Comfort	47400.00
0005433235148	274	Comfort	47400.00
0005434552672	274	Comfort	47400.00
0005434728636	274	Comfort	47400.00
0005434735823	274	Comfort	47400.00
0005434728694	274	Comfort	47400.00
0005435142926	274	Comfort	47400.00
0005433235281	274	Comfort	47400.00
0005434728661	274	Comfort	47400.00
0005433126931	274	Comfort	47400.00
0005434728649	274	Comfort	47400.00
0005434728619	274	Comfort	47400.00
0005432278157	274	Comfort	47400.00
0005433131798	274	Comfort	47400.00
0005433131802	274	Comfort	47400.00
0005434032101	274	Comfort	47400.00
0005434728710	274	Economy	27900.00
0005434728698	274	Comfort	47400.00
0005434728708	274	Economy	27900.00
0005433181580	274	Economy	27900.00
0005434728653	274	Economy	27900.00
0005434728699	274	Economy	27900.00
0005434728666	274	Economy	27900.00
0005434731278	274	Economy	27900.00
0005433235030	274	Economy	27900.00
0005433235520	274	Economy	27900.00
0005434552710	274	Economy	27900.00
0005433235320	274	Economy	27900.00
0005434728703	274	Economy	27900.00
0005434728717	274	Economy	27900.00
0005433131790	274	Economy	27900.00
0005433131773	274	Economy	27900.00
0005434552669	274	Economy	27900.00
0005434728682	274	Economy	27900.00
0005434728630	274	Economy	27900.00
0005434728620	274	Economy	27900.00
0005434728684	274	Economy	27900.00
0005434552688	274	Economy	27900.00
0005432278158	274	Economy	27900.00
0005433766695	274	Economy	27900.00
0005434728704	274	Economy	27900.00
0005433126940	274	Economy	27900.00
0005433289974	274	Economy	27900.00
0005434552662	274	Economy	27900.00
0005434728681	274	Economy	27900.00
0005434552667	274	Economy	27900.00
0005434552701	274	Economy	27900.00
0005434728640	274	Economy	27900.00
0005434731279	274	Economy	27900.00
0005434728689	274	Economy	27900.00
0005433181575	274	Economy	27900.00
0005433235611	274	Economy	27900.00
0005434552665	274	Economy	27900.00
0005434728627	274	Economy	27900.00
0005434728631	274	Economy	27900.00
0005433131806	274	Economy	27900.00
0005433235484	274	Economy	27900.00
0005434552712	274	Economy	27900.00
0005433235163	274	Economy	27900.00
0005433766705	274	Economy	27900.00
0005434302572	274	Economy	27900.00
0005432278159	274	Economy	27900.00
0005433234990	274	Economy	27900.00
0005433289970	274	Economy	27900.00
0005434728638	274	Economy	27900.00
0005434552670	274	Economy	27900.00
0005433181479	274	Economy	27900.00
0005433235515	274	Economy	27900.00
0005434552711	274	Economy	27900.00
0005434552664	274	Economy	27900.00
0005433235265	274	Economy	27900.00
0005434728650	274	Economy	27900.00
0005434731281	274	Economy	27900.00
0005433235299	274	Economy	27900.00
0005435142927	274	Economy	27900.00
0005434728669	274	Economy	27900.00
0005433181462	274	Economy	27900.00
0005433235340	274	Economy	27900.00
0005434552703	274	Economy	27900.00
0005434728654	274	Economy	27900.00
0005434552661	274	Economy	27900.00
0005433235521	274	Economy	30700.00
0005433126939	274	Economy	30700.00
0005433235324	274	Economy	30700.00
0005433181506	274	Economy	27900.00
0005434552668	274	Economy	27900.00
0005433235423	274	Economy	27900.00
0005434552714	274	Economy	27900.00
0005434731280	274	Economy	30700.00
0005433289957	274	Economy	30700.00
0005434728688	274	Economy	30700.00
0005434735825	274	Economy	27900.00
0005433131807	274	Economy	27900.00
0005434728691	274	Economy	27900.00
0005433235149	274	Economy	27900.00
0005434728657	274	Economy	27900.00
0005434728706	274	Economy	27900.00
0005434728679	274	Economy	27900.00
0005433235556	274	Economy	27900.00
0005434552695	274	Economy	27900.00
0005434728686	274	Economy	27900.00
0005434728701	274	Economy	27900.00
0005433235240	274	Economy	27900.00
0005434728629	274	Economy	27900.00
0005434552673	274	Economy	27900.00
0005433235351	274	Economy	27900.00
0005434728652	274	Economy	27900.00
0005433289982	274	Economy	27900.00
0005434552692	274	Economy	27900.00
0005434032093	274	Economy	27900.00
0005434728643	274	Economy	27900.00
0005434728644	274	Economy	27900.00
0005434728702	274	Economy	27900.00
0005434728628	274	Economy	27900.00
0005434552689	274	Economy	27900.00
0005433126920	274	Economy	27900.00
0005432278164	274	Economy	27900.00
0005434728711	274	Economy	27900.00
0005434728675	274	Economy	27900.00
0005434552686	274	Economy	27900.00
0005433289953	274	Economy	27900.00
0005433235045	274	Economy	27900.00
0005432278165	274	Economy	27900.00
0005434728642	274	Economy	27900.00
0005433235156	274	Economy	27900.00
0005434728716	274	Economy	27900.00
0005434552681	274	Economy	27900.00
0005434302571	274	Economy	27900.00
0005433126914	274	Economy	27900.00
0005434728693	274	Economy	27900.00
0005434728625	274	Economy	27900.00
0005434728676	274	Economy	27900.00
0005434728673	274	Economy	27900.00
0005434728648	274	Economy	27900.00
0005433235470	274	Economy	27900.00
0005433181535	274	Economy	27900.00
0005434552690	274	Economy	27900.00
0005434552682	274	Economy	27900.00
0005434552705	274	Economy	27900.00
0005434728651	274	Economy	27900.00
0005434552697	274	Economy	27900.00
0005433126913	274	Economy	27900.00
0005435142929	274	Economy	27900.00
0005434302898	274	Economy	27900.00
0005434728665	274	Economy	27900.00
0005433235308	274	Economy	27900.00
0005433126929	274	Economy	27900.00
0005434552676	274	Economy	27900.00
0005434302899	274	Economy	27900.00
0005434552704	274	Economy	27900.00
0005434728663	274	Economy	27900.00
0005432278166	274	Economy	27900.00
0005434552691	274	Economy	27900.00
0005434728622	274	Economy	27900.00
0005433235238	274	Economy	27900.00
0005433235239	274	Economy	27900.00
0005433235526	274	Economy	27900.00
0005433235448	274	Economy	27900.00
0005434552678	274	Economy	27900.00
0005434728680	274	Economy	27900.00
0005433235403	274	Economy	27900.00
0005433235447	274	Economy	27900.00
0005434552706	274	Economy	27900.00
0005433235315	274	Economy	27900.00
0005434728639	274	Economy	27900.00
0005433181468	274	Economy	27900.00
0005434032089	274	Economy	27900.00
0005434728718	274	Economy	27900.00
0005433235478	274	Economy	27900.00
0005434728621	274	Economy	27900.00
0005433181638	274	Economy	27900.00
0005433766706	274	Economy	27900.00
0005434032102	274	Economy	27900.00
0005434302897	274	Economy	27900.00
0005433181581	274	Economy	27900.00
0005434728656	274	Economy	27900.00
0005434032110	274	Economy	27900.00
0005434728634	274	Economy	27900.00
0005432278160	274	Economy	27900.00
0005433181526	274	Economy	27900.00
0005434728645	274	Economy	27900.00
0005433126933	274	Economy	27900.00
0005433181574	274	Economy	27900.00
0005434552709	274	Economy	27900.00
0005434728667	274	Economy	27900.00
0005434552660	274	Economy	27900.00
0005433235155	274	Economy	27900.00
0005434552687	274	Economy	30700.00
0005433181637	274	Economy	27900.00
0005432278163	274	Economy	30700.00
0005434552671	274	Economy	30700.00
0005434735822	274	Economy	30700.00
0005434728712	274	Economy	30700.00
0005434728697	274	Economy	30700.00
0005433235255	274	Economy	27900.00
0005434728713	274	Economy	27900.00
0005433181481	274	Economy	27900.00
0005433181659	274	Economy	27900.00
0005433235337	274	Economy	27900.00
0005433289971	274	Economy	27900.00
0005433235254	274	Economy	27900.00
0005434728637	274	Economy	27900.00
0005434728714	274	Economy	27900.00
0005434552666	274	Economy	27900.00
0005434552679	274	Economy	27900.00
0005433766703	274	Economy	27900.00
0005433289956	274	Economy	27900.00
0005433235319	274	Economy	27900.00
0005434728670	274	Economy	27900.00
0005433235296	274	Economy	27900.00
0005433235439	274	Economy	27900.00
0005433235264	274	Economy	27900.00
0005434032096	274	Economy	27900.00
0005435142931	274	Economy	27900.00
0005434552663	274	Economy	27900.00
0005433766696	274	Economy	27900.00
0005434032091	274	Economy	27900.00
0005434552685	274	Economy	27900.00
0005433131775	274	Economy	27900.00
0005433234952	274	Economy	27900.00
0005434552699	274	Economy	27900.00
0005434731282	274	Economy	27900.00
0005434728692	274	Economy	27900.00
0005434302570	274	Economy	27900.00
0005433235514	274	Economy	27900.00
0005434728624	274	Economy	27900.00
0005434728672	274	Economy	27900.00
0005433131774	274	Economy	27900.00
0005434728664	274	Economy	27900.00
0005434728683	274	Economy	27900.00
0005433289964	274	Economy	27900.00
0005434552683	274	Economy	27900.00
0005434552700	274	Economy	27900.00
0005434728655	274	Economy	27900.00
0005434728696	274	Economy	27900.00
0005433235404	274	Economy	27900.00
0005433126928	274	Economy	27900.00
0005434552713	274	Economy	27900.00
0005434728646	274	Economy	27900.00
0005434552708	274	Economy	27900.00
0005433235376	274	Economy	27900.00
0005432278161	274	Economy	27900.00
0005434728678	274	Economy	27900.00
0005433235367	274	Economy	27900.00
0005433235241	274	Economy	27900.00
0005434728668	274	Economy	27900.00
0005435142933	274	Economy	27900.00
0005434552677	274	Economy	27900.00
0005433181583	274	Economy	27900.00
0005433289986	274	Economy	27900.00
0005434552675	274	Economy	27900.00
0005434728687	274	Economy	27900.00
0005433235257	274	Economy	27900.00
0005434728671	274	Economy	27900.00
0005434728707	274	Economy	27900.00
0005433235495	274	Economy	27900.00
0005433181536	274	Economy	27900.00
0005435142928	274	Economy	27900.00
0005434728719	274	Economy	27900.00
0005434552702	274	Economy	27900.00
0005433235256	274	Economy	27900.00
0005434728647	274	Economy	27900.00
0005434032092	274	Economy	27900.00
0005433181527	274	Economy	27900.00
0005434728635	274	Economy	27900.00
0005434728705	274	Economy	27900.00
0005434552680	274	Economy	27900.00
0005434735824	274	Economy	27900.00
0005434728662	274	Economy	27900.00
0005433289948	274	Economy	27900.00
0005433235072	274	Economy	27900.00
0005433235099	274	Economy	27900.00
0005434552674	274	Economy	27900.00
0005433235582	274	Economy	27900.00
0005434728709	274	Economy	27900.00
0005435142930	274	Economy	27900.00
0005434728658	274	Economy	27900.00
0005433181467	274	Economy	27900.00
0005435142924	274	Economy	27900.00
0005434727111	9859	Business	83700.00
0005434552000	9859	Business	83700.00
0005434552241	9859	Business	83700.00
0005434552115	9859	Business	83700.00
0005433129398	9859	Business	83700.00
0005434552177	9859	Business	83700.00
0005433290037	9859	Business	83700.00
0005434302527	9859	Business	83700.00
0005433235875	9859	Business	83700.00
0005434727478	9859	Business	83700.00
0005434727728	9859	Business	83700.00
0005434552327	9859	Business	83700.00
0005434552017	9859	Business	83700.00
0005434727553	9859	Business	83700.00
0005434552077	9859	Business	83700.00
0005434727876	9859	Business	83700.00
0005434727853	9859	Business	83700.00
0005434302526	9859	Business	83700.00
0005433235873	9859	Business	83700.00
0005433235881	9859	Comfort	47400.00
0005434727697	9859	Comfort	47400.00
0005432199429	9859	Comfort	47400.00
0005434727724	9859	Comfort	47400.00
0005434726981	9859	Comfort	47400.00
0005434728202	9859	Comfort	47400.00
0005433126962	9859	Comfort	47400.00
0005434727003	9859	Comfort	47400.00
0005433235877	9859	Comfort	47400.00
0005435142786	9859	Comfort	47400.00
0005434727481	9859	Comfort	47400.00
0005434551977	9859	Comfort	47400.00
0005434552383	9859	Comfort	47400.00
0005434552201	9859	Comfort	47400.00
0005434727961	9859	Comfort	47400.00
0005433235867	9859	Comfort	47400.00
0005434727648	9859	Comfort	47400.00
0005434552128	9859	Comfort	47400.00
0005434727884	9859	Comfort	47400.00
0005434727525	9859	Comfort	47400.00
0005433235862	9859	Comfort	47400.00
0005433235844	9859	Comfort	47400.00
0005433181761	9859	Comfort	47400.00
0005433235885	9859	Comfort	47400.00
0005434727563	9859	Comfort	47400.00
0005434552037	9859	Comfort	47400.00
0005433235843	9859	Comfort	47400.00
0005433235864	9859	Comfort	47400.00
0005434727946	9859	Comfort	47400.00
0005434727696	9859	Comfort	47400.00
0005433235863	9859	Comfort	47400.00
0005433235845	9859	Comfort	47400.00
0005434552226	9859	Comfort	47400.00
0005434735784	9859	Comfort	47400.00
0005434727705	9859	Comfort	47400.00
0005434727572	9859	Comfort	47400.00
0005433235859	9859	Economy	27900.00
0005433235872	9859	Economy	27900.00
0005434731233	9859	Economy	27900.00
0005433181758	9859	Economy	27900.00
0005434727567	9859	Economy	27900.00
0005434727735	9859	Economy	27900.00
0005434727740	9859	Economy	27900.00
0005434727852	9859	Economy	27900.00
0005434552149	9859	Economy	27900.00
0005434727376	9859	Economy	27900.00
0005434727885	9859	Economy	27900.00
0005434552129	9859	Economy	27900.00
0005434728084	9859	Economy	27900.00
0005433181763	9859	Economy	27900.00
0005433181772	9859	Economy	27900.00
0005433235840	9859	Economy	27900.00
0005433235853	9859	Economy	27900.00
0005434727945	9859	Economy	27900.00
0005434731239	9859	Economy	27900.00
0005432199427	9859	Economy	27900.00
0005434552219	9859	Economy	27900.00
0005433290040	9859	Economy	27900.00
0005434552202	9859	Economy	27900.00
0005434727763	9859	Economy	27900.00
0005434727810	9859	Economy	27900.00
0005434728127	9859	Economy	27900.00
0005435142787	9859	Economy	27900.00
0005433181759	9859	Economy	27900.00
0005434552326	9859	Economy	27900.00
0005435142819	9859	Economy	27900.00
0005434552199	9859	Economy	27900.00
0005433235851	9859	Economy	27900.00
0005432199428	9859	Economy	27900.00
0005434727473	9859	Economy	27900.00
0005434728104	9859	Economy	27900.00
0005433181768	9859	Economy	27900.00
0005434728007	9859	Economy	27900.00
0005434552143	9859	Economy	27900.00
0005434727894	9859	Economy	27900.00
0005434727806	9859	Economy	27900.00
0005433113593	9859	Economy	27900.00
0005434552150	9859	Economy	27900.00
0005433181769	9859	Economy	27900.00
0005433766741	9859	Economy	27900.00
0005433129396	9859	Economy	27900.00
0005433235871	9859	Economy	27900.00
0005434727526	9859	Economy	27900.00
0005434551916	9859	Economy	27900.00
0005433235852	9859	Economy	27900.00
0005433235868	9859	Economy	27900.00
0005433235838	9859	Economy	27900.00
0005433290036	9859	Economy	30700.00
0005433181777	9859	Economy	27900.00
0005434728211	9859	Economy	27900.00
0005434552068	9859	Economy	27900.00
0005433126966	9859	Economy	27900.00
0005434727606	9859	Economy	30700.00
0005433181771	9859	Economy	30700.00
0005434552224	9859	Economy	27900.00
0005435142772	9859	Economy	27900.00
0005433235882	9859	Economy	27900.00
0005434727799	9859	Economy	27900.00
0005433129395	9859	Economy	27900.00
0005433126964	9859	Economy	27900.00
0005435142731	9859	Economy	27900.00
0005434552303	9859	Economy	27900.00
0005434727867	9859	Economy	27900.00
0005434552079	9859	Economy	27900.00
0005434552188	9859	Economy	27900.00
0005433235849	9859	Economy	27900.00
0005433181770	9859	Economy	27900.00
0005434552239	9859	Economy	27900.00
0005433235842	9859	Economy	27900.00
0005434032147	9859	Economy	27900.00
0005435142778	9859	Economy	27900.00
0005434727620	9859	Economy	27900.00
0005435142775	9859	Economy	27900.00
0005433235846	9859	Economy	27900.00
0005434727474	9859	Economy	27900.00
0005434728203	9859	Economy	27900.00
0005434552186	9859	Economy	27900.00
0005434727482	9859	Economy	27900.00
0005434727527	9859	Economy	27900.00
0005434727863	9859	Economy	27900.00
0005434727605	9859	Economy	27900.00
0005434552137	9859	Economy	27900.00
0005434552187	9859	Economy	27900.00
0005434727554	9859	Economy	27900.00
0005435142773	9859	Economy	27900.00
0005433235870	9859	Economy	27900.00
0005433181776	9859	Economy	27900.00
0005433126965	9859	Economy	27900.00
0005434727864	9859	Economy	27900.00
0005434551915	9859	Economy	27900.00
0005433181764	9859	Economy	27900.00
0005434727600	9859	Economy	27900.00
0005434727900	9859	Economy	27900.00
0005434552293	9859	Economy	27900.00
0005434727630	9859	Economy	27900.00
0005434727974	9859	Economy	27900.00
0005434735785	9859	Economy	27900.00
0005434731232	9859	Economy	27900.00
0005433126963	9859	Economy	27900.00
0005434552240	9859	Economy	27900.00
0005433235858	9859	Economy	27900.00
0005434727695	9859	Economy	27900.00
0005434727700	9859	Economy	27900.00
0005434727962	9859	Economy	27900.00
0005434731251	9859	Economy	27900.00
0005434032146	9859	Economy	27900.00
0005433235841	9859	Economy	27900.00
0005434727579	9859	Economy	27900.00
0005434552018	9859	Economy	27900.00
0005434552135	9859	Economy	27900.00
0005434552297	9859	Economy	27900.00
0005433235855	9859	Economy	27900.00
0005434727858	9859	Economy	27900.00
0005434552197	9859	Economy	27900.00
0005434727910	9859	Economy	27900.00
0005433235857	9859	Economy	27900.00
0005433290038	9859	Economy	27900.00
0005434552298	9859	Economy	27900.00
0005434032148	9859	Economy	27900.00
0005434727273	9859	Economy	27900.00
0005433235883	9859	Economy	27900.00
0005434727755	9859	Economy	27900.00
0005434727571	9859	Economy	27900.00
0005434552185	9859	Economy	27900.00
0005434727423	9859	Economy	27900.00
0005434728128	9859	Economy	27900.00
0005434727576	9859	Economy	27900.00
0005434552078	9859	Economy	27900.00
0005434727564	9859	Economy	27900.00
0005433181765	9859	Economy	27900.00
0005433235878	9859	Economy	27900.00
0005434727282	9859	Economy	27900.00
0005434731234	9859	Economy	27900.00
0005435142795	9859	Economy	27900.00
0005435142785	9859	Economy	27900.00
0005434727532	9859	Economy	27900.00
0005434727854	9859	Economy	27900.00
0005434727458	9859	Economy	27900.00
0005434728003	9859	Economy	27900.00
0005434302525	9859	Economy	27900.00
0005434727975	9859	Economy	27900.00
0005433235860	9859	Economy	27900.00
0005434552328	9859	Economy	27900.00
0005434727727	9859	Economy	27900.00
0005434731244	9859	Economy	27900.00
0005433766739	9859	Economy	27900.00
0005433235865	9859	Economy	27900.00
0005433113594	9859	Economy	27900.00
0005434727582	9859	Economy	30700.00
0005434727472	9859	Economy	27900.00
0005434552200	9859	Economy	30700.00
0005434727720	9859	Economy	30700.00
0005434727533	9859	Economy	30700.00
0005434727944	9859	Economy	30700.00
0005435142784	9859	Economy	30700.00
0005434727161	9859	Economy	27900.00
0005433235861	9859	Economy	27900.00
0005434727281	9859	Economy	27900.00
0005434552085	9859	Economy	27900.00
0005434727793	9859	Economy	27900.00
0005434727943	9859	Economy	27900.00
0005434552134	9859	Economy	27900.00
0005433235866	9859	Economy	27900.00
0005433181762	9859	Economy	27900.00
0005434551980	9859	Economy	27900.00
0005434727704	9859	Economy	27900.00
0005433181774	9859	Economy	27900.00
0005434552136	9859	Economy	27900.00
0005434727524	9859	Economy	27900.00
0005434552198	9859	Economy	27900.00
0005434552052	9859	Economy	27900.00
0005434731235	9859	Economy	27900.00
0005434551851	9859	Economy	27900.00
0005434728089	9859	Economy	27900.00
0005433181767	9859	Economy	27900.00
0005434727531	9859	Economy	27900.00
0005434727721	9859	Economy	27900.00
0005433235850	9859	Economy	27900.00
0005434731252	9859	Economy	27900.00
0005433129397	9859	Economy	27900.00
0005434727857	9859	Economy	27900.00
0005433235847	9859	Economy	27900.00
0005434552016	9859	Economy	27900.00
0005433181773	9859	Economy	27900.00
0005434728006	9859	Economy	27900.00
0005433235880	9859	Economy	27900.00
0005434728118	9859	Economy	27900.00
0005433235879	9859	Economy	27900.00
0005434727303	9859	Economy	27900.00
0005433235839	9859	Economy	27900.00
0005433235869	9859	Economy	27900.00
0005433181766	9859	Economy	27900.00
0005434727501	9859	Economy	27900.00
0005433290039	9859	Economy	27900.00
0005434727202	9859	Economy	27900.00
0005434727056	9859	Economy	27900.00
0005433181775	9859	Economy	27900.00
0005433235854	9859	Economy	27900.00
0005434552130	9859	Economy	27900.00
0005434552086	9859	Economy	27900.00
0005433235848	9859	Economy	27900.00
0005434727483	9859	Economy	27900.00
0005434735798	9859	Economy	27900.00
0005433235876	9859	Economy	27900.00
0005434551823	9859	Economy	27900.00
0005435142766	9859	Economy	27900.00
0005434727257	9859	Economy	27900.00
0005434552269	9859	Economy	27900.00
0005434731231	9859	Economy	27900.00
0005434551976	9859	Economy	27900.00
0005434727292	9859	Economy	27900.00
0005434552024	9859	Economy	27900.00
0005434728204	9859	Economy	27900.00
0005434727734	9859	Economy	27900.00
0005433235884	9859	Economy	27900.00
0005434727477	9859	Economy	27900.00
0005433235856	9859	Economy	27900.00
0005434552242	9859	Economy	27900.00
0005434727619	9859	Economy	27900.00
0005434727767	9859	Economy	27900.00
0005434552227	9859	Economy	27900.00
0005434727261	9859	Economy	27900.00
0005434727631	9859	Economy	27900.00
0005434552114	9859	Economy	27900.00
0005435142758	9859	Economy	27900.00
0005435142767	9859	Economy	27900.00
0005433235874	9859	Economy	27900.00
0005434731240	9859	Economy	27900.00
0005434727617	9859	Economy	27900.00
0005434552025	9859	Economy	27900.00
0005434727461	9859	Economy	27900.00
0005433766742	9859	Economy	27900.00
0005434552223	9859	Economy	27900.00
0005433766740	9859	Economy	27900.00
0005433181760	9859	Economy	27900.00
0005434727336	9859	Economy	27900.00
0005434727562	9859	Economy	27900.00
0005434727457	9859	Economy	27900.00
0005434727629	9859	Economy	27900.00
0005434727203	9859	Economy	27900.00
0005435142801	9859	Economy	27900.00
0005434727566	9859	Economy	27900.00
0005432150403	7747	Business	42100.00
0005434069437	7747	Business	42100.00
0005432531486	7747	Business	42100.00
0005432531435	7747	Business	42100.00
0005432531482	7747	Business	42100.00
0005434069431	7747	Business	42100.00
0005432531459	7747	Business	42100.00
0005432531456	7747	Business	42100.00
0005435214963	7747	Business	42100.00
0005432531502	7747	Business	42100.00
0005434069457	7747	Business	42100.00
0005432531393	7747	Business	42100.00
0005432531451	7747	Business	42100.00
0005435283413	7747	Business	42100.00
0005432531483	7747	Business	42100.00
0005432531386	7747	Business	42100.00
0005432531401	7747	Business	42100.00
0005435214975	7747	Business	42100.00
0005432531421	7747	Business	42100.00
0005432531436	7747	Business	42100.00
0005435214406	7747	Business	42100.00
0005434069453	7747	Business	42100.00
0005434069460	7747	Comfort	23900.00
0005435214381	7747	Comfort	23900.00
0005434069456	7747	Comfort	23900.00
0005434069441	7747	Comfort	23900.00
0005435214422	7747	Comfort	23900.00
0005434069412	7747	Comfort	23900.00
0005435214505	7747	Comfort	23900.00
0005435214808	7747	Comfort	23900.00
0005434069419	7747	Comfort	23900.00
0005432531439	7747	Comfort	23900.00
0005434069445	7747	Comfort	23900.00
0005435215021	7747	Comfort	23900.00
0005432531412	7747	Comfort	23900.00
0005432531425	7747	Comfort	23900.00
0005432531417	7747	Comfort	23900.00
0005432531398	7747	Comfort	23900.00
0005435214663	7747	Comfort	23900.00
0005435214673	7747	Comfort	23900.00
0005434069463	7747	Comfort	23900.00
0005434069428	7747	Comfort	23900.00
0005432150407	7747	Comfort	23900.00
0005432531440	7747	Comfort	23900.00
0005432531453	7747	Comfort	23900.00
0005432531445	7747	Comfort	23900.00
0005432531406	7747	Comfort	23900.00
0005434069421	7747	Comfort	23900.00
0005435214730	7747	Comfort	23900.00
0005435214826	7747	Comfort	23900.00
0005432531469	7747	Comfort	23900.00
0005432531407	7747	Comfort	23900.00
0005432531493	7747	Comfort	23900.00
0005435214625	7747	Comfort	23900.00
0005432531419	7747	Comfort	23900.00
0005432531410	7747	Comfort	23900.00
0005432531487	7747	Comfort	23900.00
0005435214961	7747	Comfort	23900.00
0005435214608	7747	Comfort	23900.00
0005435214767	7747	Comfort	23900.00
0005432531478	7747	Economy	14000.00
0005435214754	7747	Economy	14000.00
0005435283412	7747	Economy	14000.00
0005432531494	7747	Economy	14000.00
0005432531460	7747	Economy	14000.00
0005435214962	7747	Economy	14000.00
0005432535965	7747	Economy	14000.00
0005435725688	7747	Economy	14000.00
0005432531420	7747	Economy	14000.00
0005434069454	7747	Economy	14000.00
0005432429020	7747	Economy	14000.00
0005434069426	7747	Economy	14000.00
0005434069417	7747	Economy	14000.00
0005432537114	7747	Economy	14000.00
0005432531457	7747	Economy	14000.00
0005435214486	7747	Economy	14000.00
0005432070047	7747	Economy	14000.00
0005432531422	7747	Economy	14000.00
0005435214990	7747	Economy	14000.00
0005432531471	7747	Economy	14000.00
0005432531485	7747	Economy	14000.00
0005434069403	7747	Economy	14000.00
0005432070038	7747	Economy	14000.00
0005434069427	7747	Economy	14000.00
0005435214666	7747	Economy	14000.00
0005432535964	7747	Economy	14000.00
0005434069432	7747	Economy	14000.00
0005435214653	7747	Economy	14000.00
0005432531481	7747	Economy	14000.00
0005434069459	7747	Economy	14000.00
0005432531489	7747	Economy	14000.00
0005432531443	7747	Economy	14000.00
0005432070046	7747	Economy	14000.00
0005432531501	7747	Economy	14000.00
0005434069409	7747	Economy	14000.00
0005432531490	7747	Economy	14000.00
0005435214664	7747	Economy	14000.00
0005432531452	7747	Economy	14000.00
0005434069429	7747	Economy	14000.00
0005432531433	7747	Economy	14000.00
0005434069422	7747	Economy	14000.00
0005432070044	7747	Economy	14000.00
0005432531467	7747	Economy	14000.00
0005435214684	7747	Economy	14000.00
0005432531505	7747	Economy	14000.00
0005435214791	7747	Economy	14000.00
0005434069423	7747	Economy	14000.00
0005433656719	7747	Economy	14000.00
0005432150404	7747	Economy	14000.00
0005434069446	7747	Economy	14000.00
0005434069404	7747	Economy	14000.00
0005432531388	7747	Economy	14000.00
0005434069416	7747	Economy	14000.00
0005432531408	7747	Economy	14000.00
0005432537115	7747	Economy	14000.00
0005432531444	7747	Economy	15400.00
0005435725685	7747	Economy	14000.00
0005434069451	7747	Economy	15400.00
0005432531383	7747	Economy	15400.00
0005432531492	7747	Economy	14000.00
0005432531391	7747	Economy	14000.00
0005435214979	7747	Economy	14000.00
0005432070040	7747	Economy	14000.00
0005432531464	7747	Economy	15400.00
0005435214721	7747	Economy	14000.00
0005432531437	7747	Economy	15400.00
0005432531465	7747	Economy	14000.00
0005435215156	7747	Economy	14000.00
0005432531468	7747	Economy	14000.00
0005432531441	7747	Economy	14000.00
0005432531450	7747	Economy	14000.00
0005435214485	7747	Economy	14000.00
0005432531394	7747	Economy	14000.00
0005432531504	7747	Economy	14000.00
0005432150402	7747	Economy	14000.00
0005432531434	7747	Economy	14000.00
0005432531431	7747	Economy	14000.00
0005435214500	7747	Economy	14000.00
0005432429019	7747	Economy	14000.00
0005434069406	7747	Economy	14000.00
0005432531461	7747	Economy	14000.00
0005432531397	7747	Economy	14000.00
0005435214787	7747	Economy	14000.00
0005435215025	7747	Economy	14000.00
0005432150406	7747	Economy	14000.00
0005435214775	7747	Economy	14000.00
0005435214788	7747	Economy	14000.00
0005435214978	7747	Economy	14000.00
0005433656724	7747	Economy	14000.00
0005435214591	7747	Economy	14000.00
0005434069447	7747	Economy	14000.00
0005432531446	7747	Economy	14000.00
0005432535962	7747	Economy	14000.00
0005434069436	7747	Economy	14000.00
0005432070037	7747	Economy	14000.00
0005434069448	7747	Economy	14000.00
0005435214562	7747	Economy	14000.00
0005432531384	7747	Economy	14000.00
0005434069408	7747	Economy	14000.00
0005432531403	7747	Economy	14000.00
0005432531387	7747	Economy	14000.00
0005435215016	7747	Economy	14000.00
0005432531413	7747	Economy	14000.00
0005435214590	7747	Economy	14000.00
0005434069464	7747	Economy	14000.00
0005434069439	7747	Economy	14000.00
0005435215015	7747	Economy	14000.00
0005434069407	7747	Economy	14000.00
0005432531496	7747	Economy	14000.00
0005432150405	7747	Economy	14000.00
0005434069442	7747	Economy	14000.00
0005435214571	7747	Economy	14000.00
0005435214910	7747	Economy	14000.00
0005434069424	7747	Economy	14000.00
0005435214741	7747	Economy	14000.00
0005435214570	7747	Economy	14000.00
0005433656715	7747	Economy	14000.00
0005432531458	7747	Economy	14000.00
0005432531463	7747	Economy	14000.00
0005435214746	7747	Economy	14000.00
0005435214954	7747	Economy	14000.00
0005434069440	7747	Economy	14000.00
0005434069462	7747	Economy	14000.00
0005432531484	7747	Economy	14000.00
0005432531432	7747	Economy	14000.00
0005432531399	7747	Economy	14000.00
0005434069415	7747	Economy	14000.00
0005432531477	7747	Economy	14000.00
0005435214989	7747	Economy	14000.00
0005435631015	7747	Economy	14000.00
0005432531442	7747	Economy	14000.00
0005432531447	7747	Economy	14000.00
0005432533367	7747	Economy	14000.00
0005435631014	7747	Economy	14000.00
0005435214829	7747	Economy	14000.00
0005435283417	7747	Economy	14000.00
0005434069414	7747	Economy	14000.00
0005432531480	7747	Economy	14000.00
0005435214592	7747	Economy	14000.00
0005435214825	7747	Economy	14000.00
0005432070036	7747	Economy	14000.00
0005433656714	7747	Economy	14000.00
0005434069455	7747	Economy	14000.00
0005434069405	7747	Economy	14000.00
0005432429018	7747	Economy	14000.00
0005435283420	7747	Economy	14000.00
0005432150401	7747	Economy	14000.00
0005432531385	7747	Economy	14000.00
0005432531497	7747	Economy	14000.00
0005434069449	7747	Economy	14000.00
0005435214947	7747	Economy	14000.00
0005432070041	7747	Economy	14000.00
0005435214792	7747	Economy	14000.00
0005434069411	7747	Economy	14000.00
0005434069420	7747	Economy	14000.00
0005432531474	7747	Economy	14000.00
0005432531472	7747	Economy	14000.00
0005434069401	7747	Economy	14000.00
0005432070042	7747	Economy	14000.00
0005432531448	7747	Economy	14000.00
0005432531405	7747	Economy	14000.00
0005432531503	7747	Economy	14000.00
0005434069435	7747	Economy	15400.00
0005432535966	7747	Economy	15400.00
0005432531466	7747	Economy	15400.00
0005432531498	7747	Economy	15400.00
0005435214742	7747	Economy	15400.00
0005434069430	7747	Economy	14000.00
0005434069444	7747	Economy	14000.00
0005432531429	7747	Economy	14000.00
0005435214974	7747	Economy	14000.00
0005432531404	7747	Economy	14000.00
0005435214632	7747	Economy	14000.00
0005435214747	7747	Economy	14000.00
0005435214626	7747	Economy	14000.00
0005432531411	7747	Economy	14000.00
0005434069413	7747	Economy	14000.00
0005434069433	7747	Economy	14000.00
0005432531418	7747	Economy	14000.00
0005435214619	7747	Economy	14000.00
0005432531392	7747	Economy	14000.00
0005435214777	7747	Economy	14000.00
0005432531409	7747	Economy	14000.00
0005435214668	7747	Economy	14000.00
0005432531424	7747	Economy	14000.00
0005432150400	7747	Economy	14000.00
0005435214805	7747	Economy	14000.00
0005432070039	7747	Economy	14000.00
0005435214631	7747	Economy	14000.00
0005435214655	7747	Economy	14000.00
0005435214667	7747	Economy	14000.00
0005432531400	7747	Economy	14000.00
0005435214714	7747	Economy	14000.00
0005432531389	7747	Economy	14000.00
0005432531416	7747	Economy	14000.00
0005432531414	7747	Economy	14000.00
0005432531395	7747	Economy	14000.00
0005432531495	7747	Economy	14000.00
0005434069410	7747	Economy	14000.00
0005432531454	7747	Economy	14000.00
0005435214964	7747	Economy	14000.00
0005432531396	7747	Economy	14000.00
0005435214405	7747	Economy	14000.00
0005432531475	7747	Economy	14000.00
0005432531491	7747	Economy	14000.00
0005432070045	7747	Economy	14000.00
0005434069458	7747	Economy	14000.00
0005432531470	7747	Economy	14000.00
0005432531423	7747	Economy	14000.00
0005435214803	7747	Economy	14000.00
0005435214880	7747	Economy	14000.00
0005435214685	7747	Economy	14000.00
0005434069452	7747	Economy	14000.00
0005434069418	7747	Economy	14000.00
0005435214967	7747	Economy	14000.00
0005432531499	7747	Economy	14000.00
0005432531473	7747	Economy	14000.00
0005434069425	7747	Economy	14000.00
0005432531500	7747	Economy	14000.00
0005435214654	7747	Economy	14000.00
0005434069402	7747	Economy	14000.00
0005435214786	7747	Economy	14000.00
0005435215073	7747	Economy	14000.00
0005432531428	7747	Economy	14000.00
0005432531449	7747	Economy	14000.00
0005435214609	7747	Economy	14000.00
0005434069434	7747	Economy	14000.00
0005435283416	7747	Economy	14000.00
0005434069443	7747	Economy	14000.00
0005435214946	7747	Economy	14000.00
0005432531390	7747	Economy	14000.00
0005432531426	7747	Economy	14000.00
0005432070043	7747	Economy	14000.00
0005432150408	7747	Economy	14000.00
0005435214712	7747	Economy	14000.00
0005432531476	7747	Economy	14000.00
0005433656725	7747	Economy	14000.00
0005432531479	7747	Economy	14000.00
0005435215072	7747	Economy	14000.00
0005432531427	7747	Economy	14000.00
0005435283421	7747	Economy	14000.00
0005432531430	7747	Economy	14000.00
0005434069438	7747	Economy	14000.00
0005435283422	7747	Economy	14000.00
0005432531488	7747	Economy	14000.00
0005435214720	7747	Economy	14000.00
0005434069450	7747	Economy	14000.00
0005435214809	7747	Economy	14000.00
0005432535963	7747	Economy	14000.00
0005432531402	7747	Economy	14000.00
0005432531462	7747	Economy	14000.00
0005432531438	7747	Economy	14000.00
0005432531415	7747	Economy	14000.00
0005434069461	7747	Economy	14000.00
0005432531455	7747	Economy	14000.00
0005435616675	5339	Business	43100.00
0005435097478	5339	Business	43100.00
0005435319747	5339	Business	43100.00
0005435616658	5339	Business	43100.00
0005435616697	5339	Business	43100.00
0005435616610	5339	Business	43100.00
0005434245541	5339	Business	43100.00
0005435616715	5339	Business	43100.00
0005435425961	5339	Business	43100.00
0005432363469	5339	Business	43100.00
0005434573722	5339	Business	43100.00
0005434345167	5339	Business	43100.00
0005434245517	5339	Business	43100.00
0005435426134	5339	Business	43100.00
0005434345160	5339	Business	43100.00
0005435616677	5339	Business	43100.00
0005435616703	5339	Business	43100.00
0005435425932	5339	Business	43100.00
0005435616621	5339	Business	43100.00
0005432133618	5339	Business	43100.00
0005434345154	5339	Business	43100.00
0005435616704	5339	Business	43100.00
0005435616694	5339	Business	43100.00
0005435426133	5339	Business	43100.00
0005435616626	5339	Business	43100.00
0005435616638	5339	Business	43100.00
0005435616668	5339	Business	43100.00
0005435616616	5339	Comfort	24400.00
0005435616602	5339	Business	43100.00
0005435425771	5339	Comfort	24400.00
0005435616666	5339	Comfort	24400.00
0005435616664	5339	Comfort	24400.00
0005432841051	5339	Comfort	24400.00
0005434345175	5339	Comfort	24400.00
0005435616648	5339	Comfort	24400.00
0005434345156	5339	Comfort	24400.00
0005434245650	5339	Comfort	24400.00
0005435616701	5339	Comfort	24400.00
0005435426119	5339	Comfort	24400.00
0005434245536	5339	Comfort	24400.00
0005435616712	5339	Comfort	24400.00
0005435426069	5339	Comfort	24400.00
0005435426118	5339	Comfort	24400.00
0005435616699	5339	Comfort	24400.00
0005434345165	5339	Comfort	24400.00
0005435426260	5339	Comfort	24400.00
0005434245557	5339	Comfort	24400.00
0005435426389	5339	Comfort	24400.00
0005435616667	5339	Comfort	24400.00
0005435555422	5339	Comfort	24400.00
0005434573729	5339	Comfort	24400.00
0005434245389	5339	Comfort	24400.00
0005434345170	5339	Comfort	24400.00
0005435425862	5339	Comfort	24400.00
0005435426210	5339	Comfort	24400.00
0005435426388	5339	Comfort	24400.00
0005435616631	5339	Comfort	24400.00
0005435380397	5339	Comfort	24400.00
0005435616607	5339	Comfort	24400.00
0005435097472	5339	Comfort	24400.00
0005432363473	5339	Comfort	24400.00
0005435616619	5339	Comfort	24400.00
0005434245502	5339	Economy	14400.00
0005435616639	5339	Comfort	24400.00
0005434245481	5339	Economy	14400.00
0005435319746	5339	Economy	14400.00
0005435616702	5339	Economy	14400.00
0005432133613	5339	Economy	14400.00
0005435616707	5339	Economy	14400.00
0005434345177	5339	Economy	14400.00
0005432133611	5339	Economy	14400.00
0005432133607	5339	Economy	14400.00
0005435616662	5339	Economy	14400.00
0005434245460	5339	Economy	14400.00
0005435426272	5339	Economy	14400.00
0005435616622	5339	Economy	14400.00
0005435616682	5339	Economy	14400.00
0005434245434	5339	Economy	14400.00
0005435616618	5339	Economy	14400.00
0005434245533	5339	Economy	14400.00
0005435425937	5339	Economy	14400.00
0005435616643	5339	Economy	14400.00
0005435616625	5339	Economy	14400.00
0005435616634	5339	Economy	14400.00
0005435616708	5339	Economy	14400.00
0005435426147	5339	Economy	14400.00
0005435616614	5339	Economy	14400.00
0005434245425	5339	Economy	14400.00
0005435426084	5339	Economy	14400.00
0005435425733	5339	Economy	14400.00
0005434573724	5339	Economy	14400.00
0005434345168	5339	Economy	14400.00
0005435616660	5339	Economy	14400.00
0005435425923	5339	Economy	14400.00
0005434573726	5339	Economy	14400.00
0005435491499	5339	Economy	14400.00
0005435616678	5339	Economy	14400.00
0005435426254	5339	Economy	14400.00
0005435616670	5339	Economy	14400.00
0005435616655	5339	Economy	14400.00
0005435426255	5339	Economy	14400.00
0005432133616	5339	Economy	14400.00
0005434245482	5339	Economy	14400.00
0005435426002	5339	Economy	14400.00
0005434345172	5339	Economy	14400.00
0005434345161	5339	Economy	14400.00
0005435616608	5339	Economy	14400.00
0005435616685	5339	Economy	14400.00
0005432133609	5339	Economy	14400.00
0005435425933	5339	Economy	14400.00
0005434345181	5339	Economy	14400.00
0005435426175	5339	Economy	14400.00
0005435616698	5339	Economy	14400.00
0005434345155	5339	Economy	14400.00
0005435426094	5339	Economy	14400.00
0005432363470	5339	Economy	14400.00
0005434345174	5339	Economy	14400.00
0005435616623	5339	Economy	14400.00
0005435426380	5339	Economy	14400.00
0005435617187	5339	Economy	14400.00
0005435426108	5339	Economy	14400.00
0005435616716	5339	Economy	14400.00
0005435616644	5339	Economy	14400.00
0005435616688	5339	Economy	14400.00
0005435097473	5339	Economy	14400.00
0005435425936	5339	Economy	15800.00
0005434345173	5339	Economy	14400.00
0005435616613	5339	Economy	15800.00
0005432133617	5339	Economy	14400.00
0005435616611	5339	Economy	15800.00
0005435425922	5339	Economy	14400.00
0005435616603	5339	Economy	14400.00
0005434345180	5339	Economy	15800.00
0005435616680	5339	Economy	14400.00
0005435616713	5339	Economy	15800.00
0005435426177	5339	Economy	15800.00
0005434245632	5339	Economy	14400.00
0005435319731	5339	Economy	14400.00
0005435319748	5339	Economy	14400.00
0005435616605	5339	Economy	14400.00
0005434656591	5339	Economy	14400.00
0005434345171	5339	Economy	14400.00
0005435616659	5339	Economy	14400.00
0005435616649	5339	Economy	14400.00
0005435616617	5339	Economy	14400.00
0005434573725	5339	Economy	14400.00
0005435616615	5339	Economy	14400.00
0005435426071	5339	Economy	14400.00
0005435616693	5339	Economy	14400.00
0005435426379	5339	Economy	14400.00
0005434345166	5339	Economy	14400.00
0005432841045	5339	Economy	14400.00
0005432133605	5339	Economy	14400.00
0005435425931	5339	Economy	14400.00
0005435616642	5339	Economy	14400.00
0005434245388	5339	Economy	14400.00
0005432363484	5339	Economy	14400.00
0005435426053	5339	Economy	14400.00
0005435616645	5339	Economy	14400.00
0005435616646	5339	Economy	14400.00
0005435626880	5339	Economy	14400.00
0005435616695	5339	Economy	14400.00
0005434245501	5339	Economy	14400.00
0005435319783	5339	Economy	14400.00
0005435425906	5339	Economy	14400.00
0005435616606	5339	Economy	14400.00
0005432047650	5339	Economy	14400.00
0005435426114	5339	Economy	14400.00
0005435380409	5339	Economy	14400.00
0005432841057	5339	Economy	14400.00
0005435097476	5339	Economy	14400.00
0005435097475	5339	Economy	14400.00
0005435426054	5339	Economy	14400.00
0005435426249	5339	Economy	14400.00
0005434573731	5339	Economy	14400.00
0005435616629	5339	Economy	14400.00
0005434245498	5339	Economy	14400.00
0005435616653	5339	Economy	14400.00
0005435426338	5339	Economy	14400.00
0005435426039	5339	Economy	14400.00
0005434245438	5339	Economy	14400.00
0005435426522	5339	Economy	14400.00
0005435616630	5339	Economy	14400.00
0005435380382	5339	Economy	14400.00
0005435426180	5339	Economy	14400.00
0005434245631	5339	Economy	14400.00
0005435616652	5339	Economy	14400.00
0005434573723	5339	Economy	14400.00
0005435426190	5339	Economy	14400.00
0005435319761	5339	Economy	14400.00
0005435616706	5339	Economy	14400.00
0005435302276	5339	Economy	14400.00
0005435616636	5339	Economy	14400.00
0005432841052	5339	Economy	14400.00
0005435425842	5339	Economy	14400.00
0005435097470	5339	Economy	14400.00
0005435425913	5339	Economy	14400.00
0005435616665	5339	Economy	14400.00
0005435305044	5339	Economy	14400.00
0005435616657	5339	Economy	14400.00
0005435097471	5339	Economy	14400.00
0005435616612	5339	Economy	14400.00
0005435616650	5339	Economy	14400.00
0005435426076	5339	Economy	14400.00
0005435616633	5339	Economy	14400.00
0005435380379	5339	Economy	14400.00
0005435616687	5339	Economy	14400.00
0005435490326	5339	Economy	14400.00
0005435426208	5339	Economy	14400.00
0005435616661	5339	Economy	14400.00
0005435380394	5339	Economy	14400.00
0005435616671	5339	Economy	14400.00
0005435616679	5339	Economy	14400.00
0005435616640	5339	Economy	14400.00
0005435616686	5339	Economy	14400.00
0005435425905	5339	Economy	14400.00
0005435302277	5339	Economy	14400.00
0005434345182	5339	Economy	14400.00
0005435426468	5339	Economy	14400.00
0005434573728	5339	Economy	14400.00
0005435616681	5339	Economy	14400.00
0005435626882	5339	Economy	14400.00
0005434345176	5339	Economy	14400.00
0005434345159	5339	Economy	14400.00
0005435616663	5339	Economy	14400.00
0005435616689	5339	Economy	14400.00
0005435097469	5339	Economy	14400.00
0005435426321	5339	Economy	14400.00
0005435426467	5339	Economy	14400.00
0005434245497	5339	Economy	14400.00
0005434345158	5339	Economy	14400.00
0005434345169	5339	Economy	14400.00
0005435426191	5339	Economy	14400.00
0005435425924	5339	Economy	14400.00
0005434345153	5339	Economy	14400.00
0005435426313	5339	Economy	14400.00
0005435616692	5339	Economy	15800.00
0005435616714	5339	Economy	15800.00
0005434245555	5339	Economy	15800.00
0005432841049	5339	Economy	15800.00
0005432363483	5339	Economy	15800.00
0005433719193	5339	Economy	15800.00
0005435425860	5339	Economy	14400.00
0005435616604	5339	Economy	14400.00
0005435426122	5339	Economy	14400.00
0005435616709	5339	Economy	14400.00
0005435426120	5339	Economy	14400.00
0005435490325	5339	Economy	14400.00
0005435616683	5339	Economy	14400.00
0005435616710	5339	Economy	14400.00
0005435426214	5339	Economy	14400.00
0005432363471	5339	Economy	14400.00
0005435616676	5339	Economy	14400.00
0005435426381	5339	Economy	14400.00
0005435617188	5339	Economy	14400.00
0005435617185	5339	Economy	14400.00
0005435380346	5339	Economy	14400.00
0005432133608	5339	Economy	14400.00
0005434345162	5339	Economy	14400.00
0005435616690	5339	Economy	14400.00
0005432363468	5339	Economy	14400.00
0005435491498	5339	Economy	14400.00
0005435616705	5339	Economy	14400.00
0005435302275	5339	Economy	14400.00
0005435616691	5339	Economy	14400.00
0005435426280	5339	Economy	14400.00
0005434345163	5339	Economy	14400.00
0005435426292	5339	Economy	14400.00
0005435302268	5339	Economy	14400.00
0005434245516	5339	Economy	14400.00
0005435426526	5339	Economy	14400.00
0005435616632	5339	Economy	14400.00
0005434345157	5339	Economy	14400.00
0005434573730	5339	Economy	14400.00
0005435616620	5339	Economy	14400.00
0005435616637	5339	Economy	14400.00
0005435616651	5339	Economy	14400.00
0005435426050	5339	Economy	14400.00
0005435616684	5339	Economy	14400.00
0005435425866	5339	Economy	14400.00
0005434245424	5339	Economy	14400.00
0005434345179	5339	Economy	14400.00
0005435380376	5339	Economy	14400.00
0005434245435	5339	Economy	14400.00
0005434245461	5339	Economy	14400.00
0005435616627	5339	Economy	14400.00
0005432047651	5339	Economy	14400.00
0005435426189	5339	Economy	14400.00
0005435617241	5339	Economy	14400.00
0005432133614	5339	Economy	14400.00
0005435425940	5339	Economy	14400.00
0005434345178	5339	Economy	14400.00
0005435616654	5339	Economy	14400.00
0005432133612	5339	Economy	14400.00
0005435426075	5339	Economy	14400.00
0005435302298	5339	Economy	14400.00
0005434573727	5339	Economy	14400.00
0005435319760	5339	Economy	14400.00
0005435617186	5339	Economy	14400.00
0005432133604	5339	Economy	14400.00
0005434656587	5339	Economy	14400.00
0005435097474	5339	Economy	14400.00
0005432133615	5339	Economy	14400.00
0005432133606	5339	Economy	14400.00
0005435616674	5339	Economy	14400.00
0005435555423	5339	Economy	14400.00
0005432133610	5339	Economy	14400.00
0005435426248	5339	Economy	14400.00
0005435616628	5339	Economy	14400.00
0005435626883	5339	Economy	14400.00
0005435616700	5339	Economy	14400.00
0005434245615	5339	Economy	14400.00
0005435097477	5339	Economy	14400.00
0005435616635	5339	Economy	14400.00
0005435616711	5339	Economy	14400.00
0005435616647	5339	Economy	14400.00
0005435616609	5339	Economy	14400.00
0005434245370	5339	Economy	14400.00
0005434245649	5339	Economy	14400.00
0005435380383	5339	Economy	14400.00
0005435616672	5339	Economy	14400.00
0005434345164	5339	Economy	14400.00
0005435626881	5339	Economy	14400.00
0005435616624	5339	Economy	14400.00
0005435426181	5339	Economy	14400.00
0005435616696	5339	Economy	14400.00
0005435616656	5339	Economy	14400.00
0005432363485	5339	Economy	14400.00
0005435616669	5339	Economy	14400.00
0005435426322	5339	Economy	14400.00
0005435319691	5339	Economy	14400.00
0005435426070	5339	Economy	14400.00
0005435616641	5339	Economy	14400.00
0005435616673	5339	Economy	14400.00
0005434245462	5339	Economy	14400.00
0005434245530	5339	Economy	14400.00
0005435491500	5339	Economy	14400.00
0005435426029	5339	Economy	14400.00
0005435490324	5339	Economy	14400.00
0005435426624	10879	Business	43100.00
0005435426652	10879	Business	43100.00
0005435615987	10879	Business	43100.00
0005435615644	10879	Business	43100.00
0005434344903	10879	Business	43100.00
0005435614892	10879	Business	43100.00
0005432841069	10879	Business	43100.00
0005435319806	10879	Business	43100.00
0005435380419	10879	Business	43100.00
0005434656610	10879	Business	43100.00
0005435615661	10879	Business	43100.00
0005435615999	10879	Business	43100.00
0005435615593	10879	Business	43100.00
0005435426614	10879	Business	43100.00
0005435490294	10879	Business	43100.00
0005435304261	10879	Comfort	24400.00
0005435615285	10879	Comfort	24400.00
0005435426627	10879	Comfort	24400.00
0005435615786	10879	Comfort	24400.00
0005434344714	10879	Comfort	24400.00
0005435490286	10879	Comfort	24400.00
0005434245764	10879	Comfort	24400.00
0005434245747	10879	Comfort	24400.00
0005435615284	10879	Comfort	24400.00
0005435426634	10879	Comfort	24400.00
0005435617183	10879	Comfort	24400.00
0005434344650	10879	Comfort	24400.00
0005434245753	10879	Comfort	24400.00
0005435616130	10879	Comfort	24400.00
0005435615897	10879	Comfort	24400.00
0005434344849	10879	Comfort	24400.00
0005435426612	10879	Comfort	24400.00
0005435426606	10879	Comfort	24400.00
0005435615695	10879	Comfort	24400.00
0005435654510	10879	Comfort	24400.00
0005435305067	10879	Comfort	24400.00
0005435615283	10879	Comfort	24400.00
0005434245749	10879	Comfort	24400.00
0005435426632	10879	Comfort	24400.00
0005435097377	10879	Comfort	24400.00
0005434344824	10879	Comfort	24400.00
0005435615835	10879	Comfort	24400.00
0005434245765	10879	Comfort	24400.00
0005432165245	10879	Comfort	24400.00
0005435304262	10879	Comfort	24400.00
0005434344633	10879	Comfort	24400.00
0005435042928	10879	Comfort	24400.00
0005435426650	10879	Comfort	24400.00
0005435615555	10879	Comfort	24400.00
0005435654511	10879	Comfort	24400.00
0005435426611	10879	Comfort	24400.00
0005435426658	10879	Economy	14400.00
0005435615663	10879	Economy	14400.00
0005435616006	10879	Economy	14400.00
0005435426644	10879	Economy	14400.00
0005435426638	10879	Economy	14400.00
0005435426646	10879	Economy	14400.00
0005435491474	10879	Economy	14400.00
0005435426616	10879	Economy	14400.00
0005435615667	10879	Economy	14400.00
0005434573532	10879	Economy	14400.00
0005435304258	10879	Economy	14400.00
0005435615633	10879	Economy	14400.00
0005432166988	10879	Economy	14400.00
0005435616024	10879	Economy	14400.00
0005435426620	10879	Economy	14400.00
0005435615946	10879	Economy	14400.00
0005434344657	10879	Economy	14400.00
0005435617174	10879	Economy	14400.00
0005434344918	10879	Economy	14400.00
0005434245759	10879	Economy	14400.00
0005435042927	10879	Economy	14400.00
0005435555408	10879	Economy	14400.00
0005435615944	10879	Economy	14400.00
0005434344729	10879	Economy	14400.00
0005435615911	10879	Economy	14400.00
0005434245760	10879	Economy	14400.00
0005435615880	10879	Economy	14400.00
0005435615694	10879	Economy	14400.00
0005435654504	10879	Economy	14400.00
0005434245758	10879	Economy	14400.00
0005434245757	10879	Economy	14400.00
0005435304260	10879	Economy	14400.00
0005434344749	10879	Economy	14400.00
0005435491479	10879	Economy	14400.00
0005435615872	10879	Economy	14400.00
0005435615745	10879	Economy	14400.00
0005435426643	10879	Economy	14400.00
0005435305063	10879	Economy	14400.00
0005434344711	10879	Economy	14400.00
0005435426631	10879	Economy	14400.00
0005435097357	10879	Economy	14400.00
0005434344850	10879	Economy	14400.00
0005435426654	10879	Economy	14400.00
0005434344917	10879	Economy	14400.00
0005435426607	10879	Economy	14400.00
0005435615587	10879	Economy	14400.00
0005435319807	10879	Economy	14400.00
0005435097378	10879	Economy	15800.00
0005435768111	10879	Economy	15800.00
0005434245762	10879	Economy	14400.00
0005435654506	10879	Economy	15800.00
0005435615553	10879	Economy	14400.00
0005434245766	10879	Economy	14400.00
0005434573535	10879	Economy	15800.00
0005435490293	10879	Economy	14400.00
0005435615868	10879	Economy	15800.00
0005435616113	10879	Economy	15800.00
0005435426656	10879	Economy	14400.00
0005435426641	10879	Economy	14400.00
0005434344838	10879	Economy	14400.00
0005435380422	10879	Economy	14400.00
0005435380420	10879	Economy	14400.00
0005435615829	10879	Economy	14400.00
0005434245756	10879	Economy	14400.00
0005435305065	10879	Economy	14400.00
0005435615637	10879	Economy	14400.00
0005435654505	10879	Economy	14400.00
0005435380421	10879	Economy	14400.00
0005434245750	10879	Economy	14400.00
0005432165241	10879	Economy	14400.00
0005435426621	10879	Economy	14400.00
0005435305066	10879	Economy	14400.00
0005435426623	10879	Economy	14400.00
0005435426619	10879	Economy	14400.00
0005435615905	10879	Economy	14400.00
0005434344834	10879	Economy	14400.00
0005435319805	10879	Economy	14400.00
0005435615588	10879	Economy	14400.00
0005432165239	10879	Economy	14400.00
0005435426626	10879	Economy	14400.00
0005435615360	10879	Economy	14400.00
0005435426628	10879	Economy	14400.00
0005435654508	10879	Economy	14400.00
0005435426613	10879	Economy	14400.00
0005435426651	10879	Economy	14400.00
0005435616002	10879	Economy	14400.00
0005435426640	10879	Economy	14400.00
0005434344539	10879	Economy	14400.00
0005435042925	10879	Economy	14400.00
0005434245748	10879	Economy	14400.00
0005434245754	10879	Economy	14400.00
0005435615516	10879	Economy	14400.00
0005435426642	10879	Economy	14400.00
0005435615583	10879	Economy	14400.00
0005434344735	10879	Economy	14400.00
0005435615645	10879	Economy	14400.00
0005435426637	10879	Economy	14400.00
0005435615602	10879	Economy	14400.00
0005434245745	10879	Economy	14400.00
0005435768112	10879	Economy	14400.00
0005435616099	10879	Economy	14400.00
0005435615560	10879	Economy	14400.00
0005435615618	10879	Economy	14400.00
0005434573567	10879	Economy	14400.00
0005435097376	10879	Economy	14400.00
0005435615554	10879	Economy	14400.00
0005434344698	10879	Economy	14400.00
0005432165242	10879	Economy	14400.00
0005432165240	10879	Economy	14400.00
0005434245761	10879	Economy	14400.00
0005435426655	10879	Economy	14400.00
0005433719231	10879	Economy	14400.00
0005435616180	10879	Economy	14400.00
0005432165244	10879	Economy	14400.00
0005434344733	10879	Economy	14400.00
0005435426618	10879	Economy	14400.00
0005435615736	10879	Economy	14400.00
0005435615342	10879	Economy	14400.00
0005435616389	10879	Economy	14400.00
0005435615286	10879	Economy	14400.00
0005435616226	10879	Economy	14400.00
0005435615743	10879	Economy	14400.00
0005435426648	10879	Economy	14400.00
0005435615623	10879	Economy	14400.00
0005435615834	10879	Economy	14400.00
0005432165243	10879	Economy	14400.00
0005435615636	10879	Economy	14400.00
0005435616179	10879	Economy	14400.00
0005434344787	10879	Economy	14400.00
0005435615660	10879	Economy	14400.00
0005434245752	10879	Economy	14400.00
0005435617175	10879	Economy	14400.00
0005435491473	10879	Economy	14400.00
0005435426639	10879	Economy	14400.00
0005435615830	10879	Economy	14400.00
0005434245751	10879	Economy	14400.00
0005435615934	10879	Economy	14400.00
0005434573534	10879	Economy	14400.00
0005434344697	10879	Economy	14400.00
0005435615173	10879	Economy	14400.00
0005432166987	10879	Economy	14400.00
0005434245746	10879	Economy	14400.00
0005434573586	10879	Economy	14400.00
0005435617182	10879	Economy	14400.00
0005435426617	10879	Economy	14400.00
0005434573533	10879	Economy	15800.00
0005435615549	10879	Economy	14400.00
0005435616022	10879	Economy	15800.00
0005435426622	10879	Economy	15800.00
0005435615819	10879	Economy	15800.00
0005435615643	10879	Economy	14400.00
0005435426645	10879	Economy	15800.00
0005435426633	10879	Economy	14400.00
0005435654509	10879	Economy	14400.00
0005435616023	10879	Economy	14400.00
0005432363504	10879	Economy	14400.00
0005435426605	10879	Economy	14400.00
0005434573540	10879	Economy	14400.00
0005435615781	10879	Economy	14400.00
0005435768110	10879	Economy	14400.00
0005435768109	10879	Economy	14400.00
0005435426604	10879	Economy	14400.00
0005435615659	10879	Economy	14400.00
0005435615399	10879	Economy	14400.00
0005435426657	10879	Economy	14400.00
0005435555403	10879	Economy	14400.00
0005435615512	10879	Economy	14400.00
0005435426636	10879	Economy	14400.00
0005435555410	10879	Economy	14400.00
0005435615904	10879	Economy	14400.00
0005435319808	10879	Economy	14400.00
0005434344788	10879	Economy	14400.00
0005434573551	10879	Economy	14400.00
0005435615730	10879	Economy	14400.00
0005435304259	10879	Economy	14400.00
0005435319803	10879	Economy	14400.00
0005435615945	10879	Economy	14400.00
0005434245755	10879	Economy	14400.00
0005432165238	10879	Economy	14400.00
0005434245744	10879	Economy	14400.00
0005435615980	10879	Economy	14400.00
0005435097353	10879	Economy	14400.00
0005435616016	10879	Economy	14400.00
0005435319804	10879	Economy	14400.00
0005435319809	10879	Economy	14400.00
0005435615359	10879	Economy	14400.00
0005435615511	10879	Economy	14400.00
0005434344833	10879	Economy	14400.00
0005435616112	10879	Economy	14400.00
0005435615561	10879	Economy	14400.00
0005435097361	10879	Economy	14400.00
0005435380418	10879	Economy	14400.00
0005435426630	10879	Economy	14400.00
0005434344748	10879	Economy	14400.00
0005435654507	10879	Economy	14400.00
0005435616222	10879	Economy	14400.00
0005435426629	10879	Economy	14400.00
0005435615111	10879	Economy	14400.00
0005435616074	10879	Economy	14400.00
0005434344730	10879	Economy	14400.00
0005435555409	10879	Economy	14400.00
0005435615735	10879	Economy	14400.00
0005435426615	10879	Economy	14400.00
0005435426635	10879	Economy	14400.00
0005435615795	10879	Economy	14400.00
0005435617177	10879	Economy	14400.00
0005435615883	10879	Economy	14400.00
0005435615332	10879	Economy	14400.00
0005434656611	10879	Economy	14400.00
0005435615763	10879	Economy	14400.00
0005435615584	10879	Economy	14400.00
0005435615368	10879	Economy	14400.00
0005434245767	10879	Economy	14400.00
0005435305064	10879	Economy	14400.00
0005434344715	10879	Economy	14400.00
0005434344916	10879	Economy	14400.00
0005435616100	10879	Economy	14400.00
0005435042926	10879	Economy	14400.00
0005435615613	10879	Economy	14400.00
0005435615733	10879	Economy	14400.00
0005435615624	10879	Economy	14400.00
0005435426609	10879	Economy	14400.00
0005435426610	10879	Economy	14400.00
0005434573550	10879	Economy	14400.00
0005435426603	10879	Economy	14400.00
0005435615312	10879	Economy	14400.00
0005435426625	10879	Economy	14400.00
0005435615933	10879	Economy	14400.00
0005434344734	10879	Economy	14400.00
0005435615475	10879	Economy	14400.00
0005435426608	10879	Economy	14400.00
0005435380417	10879	Economy	14400.00
0005435615405	10879	Economy	14400.00
0005435426653	10879	Economy	14400.00
0005434573577	10879	Economy	14400.00
0005435615627	10879	Economy	14400.00
0005435426649	10879	Economy	14400.00
0005434245763	10879	Economy	14400.00
0005435426647	10879	Economy	14400.00
0005433806318	3364	Business	18800.00
0005433806290	3364	Business	18800.00
0005433806288	3364	Business	18800.00
0005433806321	3364	Business	18800.00
0005432460715	3364	Business	18800.00
0005433806298	3364	Business	18800.00
0005432182315	3364	Business	18800.00
0005434143761	3364	Business	18800.00
0005432460709	3364	Business	18800.00
0005432460791	3364	Business	18800.00
0005432182304	3364	Business	18800.00
0005432460908	3364	Business	18800.00
0005432460708	3364	Business	18800.00
0005432460596	3364	Business	18800.00
0005434143756	3364	Business	18800.00
0005433806306	3364	Business	18800.00
0005433634730	3364	Business	18800.00
0005433806310	3364	Business	18800.00
0005432460914	3364	Business	18800.00
0005433634726	3364	Business	18800.00
0005432460978	3364	Business	18800.00
0005432182297	3364	Business	18800.00
0005433507673	3364	Business	18800.00
0005432460651	3364	Business	18800.00
0005433507677	3364	Business	18800.00
0005433806317	3364	Business	18800.00
0005432182309	3364	Business	18800.00
0005433634718	3364	Business	18800.00
0005434143766	3364	Economy	6900.00
0005432460913	3364	Economy	6900.00
0005433806300	3364	Economy	6900.00
0005433806304	3364	Economy	6900.00
0005433806291	3364	Economy	6900.00
0005433634738	3364	Economy	6300.00
0005432182298	3364	Economy	6300.00
0005433634717	3364	Economy	6300.00
0005433507662	3364	Economy	6300.00
0005434143755	3364	Economy	6300.00
0005432182303	3364	Economy	6300.00
0005433507675	3364	Economy	6300.00
0005432460569	3364	Economy	6300.00
0005433507663	3364	Economy	6300.00
0005433806307	3364	Economy	6300.00
0005432461020	3364	Economy	6300.00
0005432182306	3364	Economy	6300.00
0005433507665	3364	Economy	6300.00
0005433507676	3364	Economy	6300.00
0005432460788	3364	Economy	6300.00
0005432460714	3364	Economy	6300.00
0005433634721	3364	Economy	6300.00
0005434143764	3364	Economy	6300.00
0005434143757	3364	Economy	6300.00
0005432460421	3364	Economy	6300.00
0005433634736	3364	Economy	6300.00
0005433634714	3364	Economy	6300.00
0005432460827	3364	Economy	6300.00
0005433806302	3364	Economy	6300.00
0005432460611	3364	Economy	6300.00
0005432460676	3364	Economy	6300.00
0005432460962	3364	Economy	6300.00
0005432460738	3364	Economy	6300.00
0005432182307	3364	Economy	6300.00
0005432460813	3364	Economy	6300.00
0005433806299	3364	Economy	6300.00
0005433634728	3364	Economy	6300.00
0005433806303	3364	Economy	6300.00
0005432182305	3364	Economy	6300.00
0005432182301	3364	Economy	6300.00
0005433634722	3364	Economy	6300.00
0005433806289	3364	Economy	6300.00
0005433634724	3364	Economy	6300.00
0005432182302	3364	Economy	6300.00
0005433507672	3364	Economy	6300.00
0005432460570	3364	Economy	6300.00
0005433806292	3364	Economy	6300.00
0005433806315	3364	Economy	6300.00
0005433806322	3364	Economy	6300.00
0005434143759	3364	Economy	6300.00
0005432460810	3364	Economy	6300.00
0005432461006	3364	Economy	6300.00
0005432182312	3364	Economy	6300.00
0005433634712	3364	Economy	6300.00
0005432460807	3364	Economy	6300.00
0005432460422	3364	Economy	6300.00
0005433507670	3364	Economy	6300.00
0005433507669	3364	Economy	6300.00
0005432460838	3364	Economy	6300.00
0005433806314	3364	Economy	6300.00
0005433634720	3364	Economy	6300.00
0005432460804	3364	Economy	6300.00
0005432182308	3364	Economy	6300.00
0005433507671	3364	Economy	6900.00
0005433806309	3364	Economy	6900.00
0005433634713	3364	Economy	6900.00
0005432460597	3364	Economy	6900.00
0005433634732	3364	Economy	6900.00
0005433634725	3364	Economy	6300.00
0005432460840	3364	Economy	6300.00
0005433806297	3364	Economy	6300.00
0005433806320	3364	Economy	6300.00
0005433634734	3364	Economy	6900.00
0005432460780	3364	Economy	6300.00
0005432460764	3364	Economy	6300.00
0005434143758	3364	Economy	6300.00
0005433634716	3364	Economy	6300.00
0005432460805	3364	Economy	6300.00
0005433806293	3364	Economy	6300.00
0005432460771	3364	Economy	6300.00
0005433507667	3364	Economy	6300.00
0005432460899	3364	Economy	6300.00
0005434143762	3364	Economy	6300.00
0005433806305	3364	Economy	6300.00
0005433806296	3364	Economy	6300.00
0005432460790	3364	Economy	6300.00
0005432460644	3364	Economy	6300.00
0005433806287	3364	Economy	6300.00
0005434143760	3364	Economy	6300.00
0005433634727	3364	Economy	6300.00
0005432460673	3364	Economy	6300.00
0005433806319	3364	Economy	6300.00
0005433806316	3364	Economy	6300.00
0005432460839	3364	Economy	6300.00
0005433806286	3364	Economy	6300.00
0005433634733	3364	Economy	6300.00
0005432460656	3364	Economy	6300.00
0005433634715	3364	Economy	6300.00
0005433634737	3364	Economy	6300.00
0005432460770	3364	Economy	6300.00
0005432182311	3364	Economy	6300.00
0005432182314	3364	Economy	6300.00
0005433507674	3364	Economy	6300.00
0005433806301	3364	Economy	6300.00
0005433634723	3364	Economy	6300.00
0005432460639	3364	Economy	6300.00
0005432460806	3364	Economy	6300.00
0005432460961	3364	Economy	6300.00
0005434143754	3364	Economy	6300.00
0005432460797	3364	Economy	6300.00
0005432460716	3364	Economy	6300.00
0005432182300	3364	Economy	6300.00
0005433507668	3364	Economy	6300.00
0005433507666	3364	Economy	6300.00
0005432182313	3364	Economy	6300.00
0005433806311	3364	Economy	6300.00
0005432460590	3364	Economy	6300.00
0005432460808	3364	Economy	6300.00
0005433806308	3364	Economy	6300.00
0005432460717	3364	Economy	6300.00
0005432460591	3364	Economy	6300.00
0005432182299	3364	Economy	6300.00
0005432460666	3364	Economy	6300.00
0005433634735	3364	Economy	6300.00
0005432460723	3364	Economy	6300.00
0005432182310	3364	Economy	6300.00
0005433806312	3364	Economy	6300.00
0005433507664	3364	Economy	6300.00
0005434143763	3364	Economy	6300.00
0005433634731	3364	Economy	6300.00
0005433806294	3364	Economy	6300.00
0005432460772	3364	Economy	6300.00
0005433806295	3364	Economy	6300.00
0005434143765	3364	Economy	6300.00
0005432460765	3364	Economy	6300.00
0005433634729	3364	Economy	6300.00
0005432460773	3364	Economy	6300.00
0005433634719	3364	Economy	6300.00
0005433806313	3364	Economy	6300.00
0005435886375	3363	Business	18800.00
0005435886148	3363	Business	18800.00
0005435886082	3363	Business	18800.00
0005435886269	3363	Business	18800.00
0005435886150	3363	Business	18800.00
0005435886084	3363	Business	18800.00
0005435886376	3363	Business	18800.00
0005435886081	3363	Economy	6900.00
0005435886289	3363	Economy	6900.00
0005435886057	3363	Economy	6300.00
0005435886229	3363	Economy	6300.00
0005435886046	3363	Economy	6300.00
0005435886180	3363	Economy	6300.00
0005435886275	3363	Economy	6300.00
0005435886243	3363	Economy	6300.00
0005435886283	3363	Economy	6300.00
0005435886268	3363	Economy	6300.00
0005435886336	3363	Economy	6300.00
0005435886014	3363	Economy	6300.00
0005435886015	3363	Economy	6300.00
0005435886051	3363	Economy	6300.00
0005435886276	3363	Economy	6300.00
0005435886251	3363	Economy	6300.00
0005435886252	3363	Economy	6900.00
0005435886136	3363	Economy	6300.00
0005435885992	3363	Economy	6300.00
0005435886151	3363	Economy	6300.00
0005435886073	3363	Economy	6300.00
0005435886272	3363	Economy	6300.00
0005435886050	3363	Economy	6300.00
0005435886315	3363	Economy	6300.00
0005435886205	3363	Economy	6300.00
0005435886091	3363	Economy	6300.00
0005435886178	3363	Economy	6300.00
0005435886049	3363	Economy	6300.00
0005435886045	3363	Economy	6300.00
0005435886179	3363	Economy	6300.00
0005435886306	3363	Economy	6300.00
0005435886066	3363	Economy	6300.00
0005435886152	3363	Economy	6300.00
0005435886531	8243	Business	18800.00
0005435886574	8243	Business	18800.00
0005433507553	8243	Business	18800.00
0005432461283	8243	Business	18800.00
0005432461287	8243	Business	18800.00
0005435886532	8243	Business	18800.00
0005432461267	8243	Business	18800.00
0005432461274	8243	Business	18800.00
0005432043080	8243	Business	18800.00
0005432461281	8243	Business	18800.00
0005435886520	8243	Business	18800.00
0005432043090	8243	Business	18800.00
0005435886569	8243	Business	18800.00
0005432461276	8243	Business	18800.00
0005433507526	8243	Business	18800.00
0005432461284	8243	Business	18800.00
0005433507552	8243	Business	18800.00
0005434312376	8243	Business	18800.00
0005435886554	8243	Business	18800.00
0005432461277	8243	Business	18800.00
0005433507534	8243	Business	18800.00
0005435886537	8243	Business	18800.00
0005433507449	8243	Business	18800.00
0005432461264	8243	Economy	6900.00
0005435886529	8243	Economy	6900.00
0005435886552	8243	Economy	6900.00
0005432461260	8243	Economy	6900.00
0005435886534	8243	Economy	6300.00
0005433507540	8243	Economy	6300.00
0005432461282	8243	Economy	6300.00
0005432461279	8243	Economy	6300.00
0005434326099	8243	Economy	6300.00
0005433507589	8243	Economy	6300.00
0005433507512	8243	Economy	6300.00
0005435886567	8243	Economy	6300.00
0005435886586	8243	Economy	6300.00
0005433507492	8243	Economy	6300.00
0005433507555	8243	Economy	6300.00
0005435886530	8243	Economy	6300.00
0005435886571	8243	Economy	6300.00
0005435886558	8243	Economy	6300.00
0005435142997	8243	Economy	6300.00
0005433507587	8243	Economy	6300.00
0005435886550	8243	Economy	6300.00
0005432043082	8243	Economy	6300.00
0005435886563	8243	Economy	6300.00
0005435886576	8243	Economy	6300.00
0005432461290	8243	Economy	6300.00
0005433507643	8243	Economy	6300.00
0005435886562	8243	Economy	6300.00
0005434326100	8243	Economy	6300.00
0005432461271	8243	Economy	6300.00
0005432461275	8243	Economy	6300.00
0005432043088	8243	Economy	6300.00
0005435886528	8243	Economy	6300.00
0005432461292	8243	Economy	6300.00
0005432461285	8243	Economy	6300.00
0005433507644	8243	Economy	6300.00
0005435886555	8243	Economy	6300.00
0005435886547	8243	Economy	6300.00
0005432043085	8243	Economy	6300.00
0005435886527	8243	Economy	6300.00
0005435886543	8243	Economy	6300.00
0005432461269	8243	Economy	6300.00
0005435886578	8243	Economy	6300.00
0005435886540	8243	Economy	6300.00
0005432461255	8243	Economy	6300.00
0005435886584	8243	Economy	6300.00
0005432461261	8243	Economy	6300.00
0005435886583	8243	Economy	6300.00
0005432461257	8243	Economy	6300.00
0005435886575	8243	Economy	6300.00
0005432461278	8243	Economy	6300.00
0005433507519	8243	Economy	6300.00
0005432461272	8243	Economy	6300.00
0005435886538	8243	Economy	6300.00
0005435886572	8243	Economy	6300.00
0005435886546	8243	Economy	6300.00
0005435886557	8243	Economy	6300.00
0005435886580	8243	Economy	6900.00
0005435886587	8243	Economy	6900.00
0005435886533	8243	Economy	6900.00
0005435886544	8243	Economy	6900.00
0005432461273	8243	Economy	6900.00
0005432461253	8243	Economy	6300.00
0005435886526	8243	Economy	6300.00
0005435886541	8243	Economy	6300.00
0005435886568	8243	Economy	6300.00
0005435886573	8243	Economy	6900.00
0005432461262	8243	Economy	6300.00
0005432461259	8243	Economy	6300.00
0005435886523	8243	Economy	6300.00
0005435886565	8243	Economy	6300.00
0005433507507	8243	Economy	6300.00
0005435886522	8243	Economy	6300.00
0005435886551	8243	Economy	6300.00
0005432461270	8243	Economy	6300.00
0005432461294	8243	Economy	6300.00
0005435886553	8243	Economy	6300.00
0005435886579	8243	Economy	6300.00
0005432461254	8243	Economy	6300.00
0005435886561	8243	Economy	6300.00
0005433507465	8243	Economy	6300.00
0005432461266	8243	Economy	6300.00
0005432461280	8243	Economy	6300.00
0005432461263	8243	Economy	6300.00
0005435886548	8243	Economy	6300.00
0005435886585	8243	Economy	6300.00
0005432461256	8243	Economy	6300.00
0005435886535	8243	Economy	6300.00
0005432461268	8243	Economy	6300.00
0005432461293	8243	Economy	6300.00
0005435886577	8243	Economy	6300.00
0005435886581	8243	Economy	6300.00
0005435886556	8243	Economy	6300.00
0005432043089	8243	Economy	6300.00
0005435886524	8243	Economy	6300.00
0005432461265	8243	Economy	6300.00
0005432043084	8243	Economy	6300.00
0005432461295	8243	Economy	6300.00
0005432043086	8243	Economy	6300.00
0005432461291	8243	Economy	6300.00
0005435886536	8243	Economy	6300.00
0005432043087	8243	Economy	6300.00
0005435886566	8243	Economy	6300.00
0005435886521	8243	Economy	6300.00
0005435886539	8243	Economy	6300.00
0005432461258	8243	Economy	6300.00
0005435886525	8243	Economy	6300.00
0005432461286	8243	Economy	6300.00
0005435886582	8243	Economy	6300.00
0005433507476	8243	Economy	6300.00
0005435886542	8243	Economy	6300.00
0005434326101	8243	Economy	6300.00
0005435142996	8243	Economy	6300.00
0005432461288	8243	Economy	6300.00
0005435886564	8243	Economy	6300.00
0005435886545	8243	Economy	6300.00
0005435886570	8243	Economy	6300.00
0005432043083	8243	Economy	6300.00
0005432043081	8243	Economy	6300.00
0005433507515	8243	Economy	6300.00
0005435886560	8243	Economy	6300.00
0005433507448	8243	Economy	6300.00
0005435886559	8243	Economy	6300.00
0005433507518	8243	Economy	6300.00
0005433507440	8243	Economy	6300.00
0005435886549	8243	Economy	6300.00
0005432461289	8243	Economy	6300.00
0005433805963	8222	Business	18800.00
0005433634246	8222	Business	18800.00
0005433634418	8222	Business	18800.00
0005433805906	8222	Business	18800.00
0005433805886	8222	Business	18800.00
0005433805981	8222	Business	18800.00
0005433634452	8222	Business	18800.00
0005433806072	8222	Business	18800.00
0005433805985	8222	Business	18800.00
0005433634524	8222	Business	18800.00
0005433634553	8222	Business	18800.00
0005433805885	8222	Business	18800.00
0005433806088	8222	Business	18800.00
0005433634526	8222	Business	18800.00
0005433806071	8222	Economy	6900.00
0005433805958	8222	Economy	6900.00
0005433806031	8222	Economy	6900.00
0005433634365	8222	Economy	6900.00
0005433805984	8222	Economy	6300.00
0005433634439	8222	Economy	6300.00
0005435854081	8222	Economy	6300.00
0005435854090	8222	Economy	6300.00
0005433805987	8222	Economy	6300.00
0005433634458	8222	Economy	6300.00
0005433634564	8222	Economy	6300.00
0005433806061	8222	Economy	6300.00
0005433806119	8222	Economy	6300.00
0005433806033	8222	Economy	6300.00
0005433806118	8222	Economy	6300.00
0005433634322	8222	Economy	6300.00
0005433634380	8222	Economy	6300.00
0005433634440	8222	Economy	6300.00
0005433634432	8222	Economy	6300.00
0005435854082	8222	Economy	6300.00
0005433634400	8222	Economy	6300.00
0005433806010	8222	Economy	6300.00
0005433805962	8222	Economy	6300.00
0005433805993	8222	Economy	6300.00
0005433634462	8222	Economy	6300.00
0005433805872	8222	Economy	6300.00
0005433634374	8222	Economy	6300.00
0005433805800	8222	Economy	6300.00
0005433805983	8222	Economy	6300.00
0005433806032	8222	Economy	6300.00
0005433806034	8222	Economy	6300.00
0005433806076	8222	Economy	6300.00
0005433634447	8222	Economy	6300.00
0005433634456	8222	Economy	6300.00
0005433634434	8222	Economy	6900.00
0005433634463	8222	Economy	6900.00
0005433634451	8222	Economy	6900.00
0005433805890	8222	Economy	6300.00
0005433634506	8222	Economy	6300.00
0005433805992	8222	Economy	6900.00
0005433634408	8222	Economy	6300.00
0005435854079	8222	Economy	6300.00
0005433805986	8222	Economy	6300.00
0005433806120	8222	Economy	6300.00
0005434143750	8222	Economy	6300.00
0005433634484	8222	Economy	6300.00
0005435854078	8222	Economy	6300.00
0005435854083	8222	Economy	6300.00
0005433806008	8222	Economy	6300.00
0005433806069	8222	Economy	6300.00
0005433806068	8222	Economy	6300.00
0005433806075	8222	Economy	6300.00
0005433634359	8222	Economy	6300.00
0005434143749	8222	Economy	6300.00
0005435854089	8222	Economy	6300.00
0005433805982	8222	Economy	6300.00
0005433634435	8222	Economy	6300.00
0005433634455	8222	Economy	6300.00
0005433806000	8222	Economy	6300.00
0005433805905	8222	Economy	6300.00
0005435854088	8222	Economy	6300.00
0005433634552	8222	Economy	6300.00
0005433806070	8222	Economy	6300.00
0005435860680	8222	Economy	6300.00
0005433806117	8222	Economy	6300.00
0005434271349	8222	Economy	6300.00
0005433634270	8222	Economy	6300.00
0005434271350	8222	Economy	6300.00
0005433805959	8222	Economy	6300.00
0005433634373	8222	Economy	6300.00
0005433806044	8222	Economy	6300.00
0005433634433	8222	Economy	6300.00
0005433805928	8222	Economy	6300.00
0005435854080	8222	Economy	6300.00
0005433634431	8222	Economy	6300.00
0005433806060	8222	Economy	6300.00
0005433634336	8222	Economy	6300.00
0005433806007	8222	Economy	6300.00
0005433805978	8222	Economy	6300.00
0005433634448	8222	Economy	6300.00
0005434183605	8212	Economy	6300.00
0005434183616	8212	Economy	6300.00
0005434183611	8212	Economy	6300.00
0005434183617	8212	Economy	6300.00
0005432384227	4593	Business	9900.00
0005433194943	4593	Business	9900.00
0005432728265	4593	Business	9900.00
0005432384216	4593	Business	9900.00
0005432384218	4593	Business	9900.00
0005432384204	4593	Business	9900.00
0005432384217	4593	Business	9900.00
0005432384205	4593	Business	9900.00
0005432384223	4593	Business	9900.00
0005433722417	4593	Business	9900.00
0005433722418	4593	Business	9900.00
0005433194933	4593	Economy	3300.00
0005433722423	4593	Economy	3300.00
0005432384208	4593	Economy	3300.00
0005433194935	4593	Economy	3300.00
0005433454930	4593	Economy	3300.00
0005433194944	4593	Economy	3300.00
0005433194939	4593	Economy	3300.00
0005433194930	4593	Economy	3300.00
0005432384221	4593	Economy	3300.00
0005433194941	4593	Economy	3600.00
0005432384224	4593	Economy	3600.00
0005433722412	4593	Economy	3600.00
0005432728268	4593	Economy	3600.00
0005433722422	4593	Economy	3600.00
0005432384232	4593	Economy	3300.00
0005432384198	4593	Economy	3300.00
0005432384201	4593	Economy	3300.00
0005432384213	4593	Economy	3300.00
0005433453815	4593	Economy	3300.00
0005433194946	4593	Economy	3300.00
0005432384225	4593	Economy	3300.00
0005433722425	4593	Economy	3300.00
0005433722420	4593	Economy	3300.00
0005432384215	4593	Economy	3300.00
0005433722426	4593	Economy	3300.00
0005432728269	4593	Economy	3300.00
0005432384214	4593	Economy	3300.00
0005432384202	4593	Economy	3300.00
0005432728270	4593	Economy	3300.00
0005432384220	4593	Economy	3300.00
0005432384203	4593	Economy	3300.00
0005433453814	4593	Economy	3300.00
0005433194945	4593	Economy	3300.00
0005433722419	4593	Economy	3300.00
0005433194937	4593	Economy	3300.00
0005433722421	4593	Economy	3300.00
0005432384219	4593	Economy	3300.00
0005433194942	4593	Economy	3300.00
0005433453816	4593	Economy	3300.00
0005432384207	4593	Economy	3300.00
0005433454931	4593	Economy	3300.00
0005432384228	4593	Economy	3300.00
0005433194940	4593	Economy	3300.00
0005433194938	4593	Economy	3300.00
0005433722414	4593	Economy	3300.00
0005433194932	4593	Economy	3300.00
0005432728266	4593	Economy	3300.00
0005432728267	4593	Economy	3300.00
0005432384222	4593	Economy	3300.00
0005433722424	4593	Economy	3300.00
0005433722411	4593	Economy	3300.00
0005433194936	4593	Economy	3300.00
0005433722413	4593	Economy	3300.00
0005432384212	4593	Economy	3300.00
0005432384200	4593	Economy	3300.00
0005432384199	4593	Economy	3300.00
0005432384230	4593	Economy	3300.00
0005432384229	4593	Economy	3300.00
0005432384233	4593	Economy	3300.00
0005433722415	4593	Economy	3300.00
0005433722416	4593	Economy	3300.00
0005433194929	4593	Economy	3300.00
0005433194934	4593	Economy	3300.00
0005432384209	4593	Economy	3300.00
0005433722410	4593	Economy	3300.00
0005432384210	4593	Economy	3300.00
0005433194931	4593	Economy	3300.00
0005432384226	4593	Economy	3300.00
0005432384231	4593	Economy	3300.00
0005433453817	4593	Economy	3300.00
0005432384206	4593	Economy	3300.00
0005432384211	4593	Economy	3300.00
0005432728123	30123	Business	9900.00
0005432383651	30123	Business	9900.00
0005432383728	30123	Business	9900.00
0005433194904	30123	Business	9900.00
0005433451647	30123	Business	9900.00
0005432383734	30123	Business	9900.00
0005432383824	30123	Economy	3300.00
0005432728186	30123	Economy	3300.00
0005433453795	30123	Economy	3300.00
0005433722311	30123	Economy	3300.00
0005432383793	30123	Economy	3300.00
0005433722325	30123	Economy	3300.00
0005433722328	30123	Economy	3300.00
0005432383759	30123	Economy	3300.00
0005432728151	30123	Economy	3600.00
0005432383781	30123	Economy	3600.00
0005432728193	30123	Economy	3600.00
0005432383572	30123	Economy	3300.00
0005433451651	30123	Economy	3300.00
0005432383713	30123	Economy	3300.00
0005432383712	30123	Economy	3300.00
0005432383704	30123	Economy	3300.00
0005432383727	30123	Economy	3300.00
0005432383758	30123	Economy	3300.00
0005433451649	30123	Economy	3300.00
0005432383689	30123	Economy	3300.00
0005433722315	30123	Economy	3300.00
0005433194913	30123	Economy	3300.00
0005432383753	30123	Economy	3300.00
0005432383828	30123	Economy	3300.00
0005433453794	30123	Economy	3300.00
0005432383620	30123	Economy	3300.00
0005433451648	30123	Economy	3300.00
0005432728124	30123	Economy	3300.00
0005433722327	30123	Economy	3300.00
0005432383767	30123	Economy	3300.00
0005433722310	30123	Economy	3300.00
0005432728187	30123	Economy	3300.00
0005433722313	30123	Economy	3300.00
0005433722329	30123	Economy	3300.00
0005432728125	30123	Economy	3300.00
0005432383702	30123	Economy	3300.00
0005432383628	30123	Economy	3300.00
0005432728225	30123	Economy	3300.00
0005433722314	30123	Economy	3300.00
0005433194895	30123	Economy	3300.00
0005432728181	30123	Economy	3300.00
0005432383690	30123	Economy	3300.00
0005432383748	30123	Economy	3300.00
0005432728115	30123	Economy	3300.00
0005432383650	30123	Economy	3300.00
0005433517138	1737	Business	57200.00
0005432925121	1737	Business	57200.00
0005435541580	1737	Business	57200.00
0005435530128	1737	Business	57200.00
0005435529837	1737	Business	57200.00
0005435541583	1737	Business	57200.00
0005435541577	1737	Business	57200.00
0005433517139	1737	Business	57200.00
0005435529838	1737	Business	57200.00
0005435541582	1737	Economy	19100.00
0005435530129	1737	Economy	19100.00
0005435530130	1737	Economy	19100.00
0005435530126	1737	Economy	19100.00
0005435541576	1737	Economy	19100.00
0005435530121	1737	Economy	19100.00
0005435529830	1737	Economy	19100.00
0005435530137	1737	Economy	19100.00
0005432925120	1737	Economy	19100.00
0005435529833	1737	Economy	19100.00
0005435529829	1737	Economy	21000.00
0005435529843	1737	Economy	21000.00
0005435530119	1737	Economy	21000.00
0005435529840	1737	Economy	19100.00
0005435530127	1737	Economy	19100.00
0005435529841	1737	Economy	19100.00
0005433517134	1737	Economy	19100.00
0005433517141	1737	Economy	19100.00
0005435529832	1737	Economy	19100.00
0005435529831	1737	Economy	19100.00
0005435530136	1737	Economy	19100.00
0005432294551	1737	Economy	19100.00
0005433517135	1737	Economy	19100.00
0005433517137	1737	Economy	19100.00
0005435541586	1737	Economy	19100.00
0005435529835	1737	Economy	19100.00
0005435530139	1737	Economy	19100.00
0005432925139	1737	Economy	19100.00
0005433517140	1737	Economy	19100.00
0005435529845	1737	Economy	19100.00
0005432925108	1737	Economy	19100.00
0005435541588	1737	Economy	19100.00
0005435541578	1737	Economy	19100.00
0005435530124	1737	Economy	19100.00
0005435530125	1737	Economy	19100.00
0005432294552	1737	Economy	19100.00
0005432925093	1737	Economy	19100.00
0005435541584	1737	Economy	19100.00
0005435541591	1737	Economy	19100.00
0005435530123	1737	Economy	19100.00
0005435529839	1737	Economy	19100.00
0005435541575	1737	Economy	19100.00
0005435529842	1737	Economy	19100.00
0005435541574	1737	Economy	19100.00
0005435530132	1737	Economy	19100.00
0005435541579	1737	Economy	19100.00
0005435530131	1737	Economy	19100.00
0005435529828	1737	Economy	19100.00
0005435529844	1737	Economy	19100.00
0005435529836	1737	Economy	19100.00
0005432925138	1737	Economy	19100.00
0005435541590	1737	Economy	19100.00
0005435530135	1737	Economy	19100.00
0005435530122	1737	Economy	19100.00
0005435541589	1737	Economy	19100.00
0005435530134	1737	Economy	19100.00
0005435541587	1737	Economy	19100.00
0005433517136	1737	Economy	19100.00
0005435541573	1737	Economy	19100.00
0005435541585	1737	Economy	19100.00
0005435530133	1737	Economy	19100.00
0005435529834	1737	Economy	19100.00
0005435530138	1737	Economy	19100.00
0005435530120	1737	Economy	19100.00
0005435541581	1737	Economy	19100.00
0005435518199	22012	Business	57200.00
0005435518284	22012	Business	57200.00
0005435541295	22012	Business	57200.00
0005435518203	22012	Economy	19100.00
0005432925163	22012	Economy	19100.00
0005433517050	22012	Economy	19100.00
0005432925162	22012	Economy	21000.00
0005435541485	22012	Economy	19100.00
0005435541358	22012	Economy	19100.00
0005433517036	22012	Economy	19100.00
0005435518222	22012	Economy	19100.00
0005435541311	22012	Economy	19100.00
0005432925164	22012	Economy	19100.00
0005435541377	22012	Economy	19100.00
0005435541367	22012	Economy	19100.00
0005433517055	22012	Economy	19100.00
0005435541421	22012	Economy	19100.00
0005433517056	22012	Economy	19100.00
0005435541356	22012	Economy	19100.00
0005435518209	22012	Economy	19100.00
0005433517109	22012	Economy	19100.00
0005435518204	22012	Economy	19100.00
0005435541312	22012	Economy	19100.00
0005435541430	22012	Economy	19100.00
0005435518200	22012	Economy	19100.00
0005435541331	22012	Economy	19100.00
0005435541482	22012	Economy	19100.00
0005435541378	22012	Economy	19100.00
0005433517049	22012	Economy	19100.00
0005435541391	22012	Economy	19100.00
0005435518229	22012	Economy	19100.00
0005435541245	22012	Economy	19100.00
0005435518210	22012	Economy	19100.00
0005435541244	22012	Economy	19100.00
0005435541294	22012	Economy	19100.00
0005435541433	22012	Economy	19100.00
0005435541355	22012	Economy	19100.00
0005433517075	22012	Economy	19100.00
0005435518251	22012	Economy	19100.00
0005435518243	22012	Economy	19100.00
0005433517047	22012	Economy	19100.00
0005435518161	22012	Economy	19100.00
0005433517057	22012	Economy	19100.00
0005435518150	22012	Economy	19100.00
0005435518252	22012	Economy	19100.00
0005434459347	7410	Business	18500.00
0005432839867	7410	Business	18500.00
0005434459355	7410	Business	18500.00
0005432839853	7410	Business	18500.00
0005435253030	7410	Business	18500.00
0005434459352	7410	Business	18500.00
0005432839855	7410	Business	18500.00
0005434459366	7410	Business	18500.00
0005432839843	7410	Business	18500.00
0005435252910	7410	Economy	6200.00
0005432839860	7410	Economy	6200.00
0005432839842	7410	Economy	6200.00
0005432839866	7410	Economy	6200.00
0005435253008	7410	Economy	6200.00
0005434459354	7410	Economy	6200.00
0005432839847	7410	Economy	6200.00
0005432839851	7410	Economy	6200.00
0005435491480	7410	Economy	6800.00
0005435491476	7410	Economy	6800.00
0005435253010	7410	Economy	6800.00
0005432073483	7410	Economy	6800.00
0005434459367	7410	Economy	6800.00
0005432839864	7410	Economy	6200.00
0005434459362	7410	Economy	6200.00
0005434459364	7410	Economy	6200.00
0005432839849	7410	Economy	6200.00
0005432839848	7410	Economy	6200.00
0005432823501	7410	Economy	6200.00
0005434459353	7410	Economy	6200.00
0005434459361	7410	Economy	6200.00
0005435253060	7410	Economy	6200.00
0005435253042	7410	Economy	6200.00
0005432841066	7410	Economy	6200.00
0005435253089	7410	Economy	6200.00
0005434459357	7410	Economy	6200.00
0005432839858	7410	Economy	6200.00
0005432839844	7410	Economy	6200.00
0005435253012	7410	Economy	6200.00
0005435253044	7410	Economy	6200.00
0005432839865	7410	Economy	6200.00
0005432839852	7410	Economy	6200.00
0005432839856	7410	Economy	6200.00
0005435253011	7410	Economy	6200.00
0005435252962	7410	Economy	6200.00
0005434459351	7410	Economy	6200.00
0005434459363	7410	Economy	6200.00
0005435252972	7410	Economy	6200.00
0005435252994	7410	Economy	6200.00
0005432839861	7410	Economy	6200.00
0005432839854	7410	Economy	6200.00
0005432839859	7410	Economy	6200.00
0005435253094	7410	Economy	6200.00
0005432839857	7410	Economy	6200.00
0005435253019	7410	Economy	6200.00
0005434459356	7410	Economy	6200.00
0005432839868	7410	Economy	6200.00
0005432839863	7410	Economy	6200.00
0005432839850	7410	Economy	6200.00
0005434459365	7410	Economy	6200.00
0005432841067	7410	Economy	6200.00
0005435253043	7410	Economy	6200.00
0005435253061	7410	Economy	6200.00
0005434459358	7410	Economy	6200.00
0005432839841	7410	Economy	6200.00
0005432839840	7410	Economy	6200.00
0005432839862	7410	Economy	6200.00
0005432823502	7410	Economy	6200.00
0005432839845	7410	Economy	6200.00
0005432073484	7410	Economy	6200.00
0005434459349	7410	Economy	6200.00
0005432841068	7410	Economy	6200.00
0005432839846	7410	Economy	6200.00
0005435253006	7410	Economy	6200.00
0005434459348	7410	Economy	6200.00
0005434459350	7410	Economy	6200.00
0005432839869	7410	Economy	6200.00
0005434459359	7410	Economy	6200.00
0005434459360	7410	Economy	6200.00
0005435253009	7410	Economy	6200.00
0005432839569	28952	Business	18500.00
0005435253166	28952	Business	18500.00
0005432839635	28952	Business	18500.00
0005435253173	28952	Business	18500.00
0005434459211	28952	Business	18500.00
0005434459150	28952	Business	18500.00
0005435253177	28952	Business	18500.00
0005435253171	28952	Economy	6200.00
0005432839513	28952	Economy	6200.00
0005434459186	28952	Economy	6200.00
0005434459230	28952	Economy	6200.00
0005435253179	28952	Economy	6200.00
0005432839610	28952	Economy	6800.00
0005432839591	28952	Economy	6800.00
0005435253174	28952	Economy	6800.00
0005432839676	28952	Economy	6200.00
0005434459254	28952	Economy	6200.00
0005432839674	28952	Economy	6200.00
0005434459122	28952	Economy	6200.00
0005434459152	28952	Economy	6200.00
0005432839604	28952	Economy	6200.00
0005432839657	28952	Economy	6200.00
0005435253180	28952	Economy	6200.00
0005434459153	28952	Economy	6200.00
0005434459133	28952	Economy	6200.00
0005434459200	28952	Economy	6200.00
0005432839600	28952	Economy	6200.00
0005432839655	28952	Economy	6200.00
0005432839612	28952	Economy	6200.00
0005435253176	28952	Economy	6200.00
0005432823486	28952	Economy	6200.00
0005434459156	28952	Economy	6200.00
0005435253181	28952	Economy	6200.00
0005435253175	28952	Economy	6200.00
0005435253169	28952	Economy	6200.00
0005432841058	28952	Economy	6200.00
0005435253170	28952	Economy	6200.00
0005432839514	28952	Economy	6200.00
0005432839544	28952	Economy	6200.00
0005434459185	28952	Economy	6200.00
0005435253168	28952	Economy	6200.00
0005432823490	28952	Economy	6200.00
0005432841053	28952	Economy	6200.00
0005432841054	28952	Economy	6200.00
0005435253178	28952	Economy	6200.00
0005435253167	28952	Economy	6200.00
0005434665021	28952	Economy	6200.00
0005432839427	28952	Economy	6200.00
0005432839654	28952	Economy	6200.00
0005434459157	28952	Economy	6200.00
0005434459253	28952	Economy	6200.00
0005432839611	28952	Economy	6200.00
0005432839428	28952	Economy	6200.00
0005435491501	28952	Economy	6200.00
0005432841055	28952	Economy	6200.00
0005432839675	28952	Economy	6200.00
0005432839656	28952	Economy	6200.00
0005432839756	28952	Economy	6200.00
0005432823487	28952	Economy	6200.00
0005435253172	28952	Economy	6200.00
0005432839651	28952	Economy	6200.00
0005434459231	28952	Economy	6200.00
0005432839568	28952	Economy	6200.00
0005435990811	8774	Business	145300.00
0005434276146	8774	Business	145300.00
0005435990814	8774	Business	145300.00
0005435990810	8774	Economy	48400.00
0005435990815	8774	Economy	53300.00
0005434276120	8774	Economy	48400.00
0005434276127	8774	Economy	48400.00
0005434276128	8774	Economy	48400.00
0005434276129	8774	Economy	48400.00
0005434276112	8774	Economy	48400.00
0005434276134	8774	Economy	48400.00
0005435990816	8774	Economy	48400.00
0005434276115	8774	Economy	48400.00
0005434276121	8774	Economy	48400.00
0005434276133	8774	Economy	48400.00
0005434276159	8774	Economy	48400.00
0005434276132	8774	Economy	48400.00
0005434276165	8774	Economy	48400.00
0005434276164	8774	Economy	48400.00
0005434276163	8774	Economy	48400.00
0005434276114	8774	Economy	48400.00
0005435990813	8774	Economy	48400.00
0005435990812	8774	Economy	48400.00
0005435990744	15744	Business	145300.00
0005434276178	15744	Business	145300.00
0005434276179	15744	Business	145300.00
0005434276177	15744	Business	145300.00
0005435990739	15744	Economy	48400.00
0005435990766	15744	Economy	53300.00
0005434276176	15744	Economy	48400.00
0005434276181	15744	Economy	48400.00
0005434276180	15744	Economy	48400.00
0005435990741	15744	Economy	48400.00
0005435990740	15744	Economy	48400.00
0005435990765	15744	Economy	48400.00
0005432427198	20621	Economy	15900.00
0005433476938	20621	Economy	14500.00
0005433476924	20621	Economy	14500.00
0005433476921	20621	Economy	14500.00
0005432427199	20621	Economy	14500.00
0005432427197	20621	Economy	14500.00
0005432427200	20621	Economy	14500.00
0005433476949	30837	Economy	14500.00
0005432427182	30837	Economy	14500.00
0005433476947	30837	Economy	14500.00
0005432427174	30837	Economy	14500.00
0005432427183	30837	Economy	14500.00
0005433476948	30837	Economy	14500.00
0005432427184	30837	Economy	14500.00
0005432361644	6392	Business	36600.00
0005435177674	6392	Business	36600.00
0005432361643	6392	Business	36600.00
0005435177502	6392	Business	36600.00
0005432361634	6392	Business	36600.00
0005432361625	6392	Business	36600.00
0005434149957	6392	Business	36600.00
0005435490294	6392	Business	36600.00
0005432361627	6392	Economy	12200.00
0005432336350	6392	Economy	12200.00
0005432361633	6392	Economy	12200.00
0005432361631	6392	Economy	12200.00
0005432361638	6392	Economy	12200.00
0005435177568	6392	Economy	12200.00
0005435177572	6392	Economy	12200.00
0005435177664	6392	Economy	12200.00
0005434149958	6392	Economy	12200.00
0005432361612	6392	Economy	12200.00
0005432062373	6392	Economy	12200.00
0005434149972	6392	Economy	12200.00
0005435723081	6392	Economy	12200.00
0005432361623	6392	Economy	12200.00
0005435177540	6392	Economy	12200.00
0005432361628	6392	Economy	12200.00
0005432336348	6392	Economy	12200.00
0005432336353	6392	Economy	12200.00
0005432336357	6392	Economy	12200.00
0005432361630	6392	Economy	12200.00
0005432361647	6392	Economy	12200.00
0005435490286	6392	Economy	12200.00
0005432361648	6392	Economy	12200.00
0005434149990	6392	Economy	12200.00
0005432361639	6392	Economy	12200.00
0005432062371	6392	Economy	12200.00
0005432361618	6392	Economy	12200.00
0005435177505	6392	Economy	12200.00
0005435177527	6392	Economy	12200.00
0005434149907	6392	Economy	12200.00
0005432361624	6392	Economy	12200.00
0005432361621	6392	Economy	13400.00
0005432361640	6392	Economy	13400.00
0005432361615	6392	Economy	13400.00
0005432062369	6392	Economy	13400.00
0005434149973	6392	Economy	13400.00
0005432361632	6392	Economy	13400.00
0005432361641	6392	Economy	12200.00
0005432062368	6392	Economy	12200.00
0005435490293	6392	Economy	12200.00
0005435177503	6392	Economy	12200.00
0005432062372	6392	Economy	12200.00
0005432336347	6392	Economy	12200.00
0005432361635	6392	Economy	12200.00
0005434149989	6392	Economy	12200.00
0005432336356	6392	Economy	12200.00
0005435177625	6392	Economy	12200.00
0005434149991	6392	Economy	12200.00
0005435177567	6392	Economy	12200.00
0005435177604	6392	Economy	12200.00
0005432336351	6392	Economy	12200.00
0005432361645	6392	Economy	12200.00
0005435177582	6392	Economy	12200.00
0005432363504	6392	Economy	12200.00
0005432336349	6392	Economy	12200.00
0005432361613	6392	Economy	12200.00
0005432361646	6392	Economy	12200.00
0005432361616	6392	Economy	12200.00
0005432336352	6392	Economy	12200.00
0005432361622	6392	Economy	12200.00
0005435177670	6392	Economy	12200.00
0005434149992	6392	Economy	12200.00
0005432361619	6392	Economy	12200.00
0005432361636	6392	Economy	12200.00
0005435723071	6392	Economy	12200.00
0005432361620	6392	Economy	12200.00
0005434149912	6392	Economy	12200.00
0005432336346	6392	Economy	12200.00
0005432062370	6392	Economy	12200.00
0005435177506	6392	Economy	12200.00
0005435177592	6392	Economy	12200.00
0005435177541	6392	Economy	12200.00
0005432361626	6392	Economy	12200.00
0005435177596	6392	Economy	12200.00
0005435177528	6392	Economy	12200.00
0005435177573	6392	Economy	12200.00
0005432361642	6392	Economy	12200.00
0005432361637	6392	Economy	12200.00
0005434149913	6392	Economy	12200.00
0005435177546	6392	Economy	12200.00
0005435177644	6392	Economy	12200.00
0005434149965	6392	Economy	12200.00
0005432361617	6392	Economy	12200.00
0005435177547	6392	Economy	12200.00
0005432336355	6392	Economy	12200.00
0005435177684	6392	Economy	12200.00
0005435177605	6392	Economy	12200.00
0005435177562	6392	Economy	12200.00
0005432336354	6392	Economy	12200.00
0005432361614	6392	Economy	12200.00
0005432361629	6392	Economy	12200.00
0005432361279	21017	Business	36600.00
0005434150041	21017	Business	36600.00
0005432361289	21017	Business	36600.00
0005435177805	21017	Business	36600.00
0005432363456	21017	Business	36600.00
0005435177788	21017	Business	36600.00
0005432361219	21017	Economy	12200.00
0005432336239	21017	Economy	12200.00
0005432336285	21017	Economy	12200.00
0005432336237	21017	Economy	12200.00
0005435177798	21017	Economy	12200.00
0005434150042	21017	Economy	12200.00
0005432336252	21017	Economy	12200.00
0005435490329	21017	Economy	12200.00
0005435177807	21017	Economy	12200.00
0005432363455	21017	Economy	12200.00
0005435177797	21017	Economy	12200.00
0005435177790	21017	Economy	12200.00
0005432361113	21017	Economy	12200.00
0005432361173	21017	Economy	12200.00
0005434150046	21017	Economy	12200.00
0005432361338	21017	Economy	12200.00
0005434150049	21017	Economy	12200.00
0005432336213	21017	Economy	12200.00
0005435177795	21017	Economy	12200.00
0005432336278	21017	Economy	12200.00
0005432361170	21017	Economy	12200.00
0005435177808	21017	Economy	12200.00
0005432336281	21017	Economy	12200.00
0005432336254	21017	Economy	13400.00
0005435490328	21017	Economy	13400.00
0005432361372	21017	Economy	13400.00
0005432361237	21017	Economy	12200.00
0005432336253	21017	Economy	12200.00
0005435177789	21017	Economy	12200.00
0005434150047	21017	Economy	12200.00
0005435177804	21017	Economy	12200.00
0005432336225	21017	Economy	12200.00
0005435177802	21017	Economy	12200.00
0005435177803	21017	Economy	12200.00
0005432361152	21017	Economy	12200.00
0005434150043	21017	Economy	12200.00
0005432336226	21017	Economy	12200.00
0005435177791	21017	Economy	12200.00
0005432361174	21017	Economy	12200.00
0005432336227	21017	Economy	12200.00
0005434150044	21017	Economy	12200.00
0005435177796	21017	Economy	12200.00
0005432361123	21017	Economy	12200.00
0005432361308	21017	Economy	12200.00
0005434150040	21017	Economy	12200.00
0005435490327	21017	Economy	12200.00
0005432052827	21017	Economy	12200.00
0005432361182	21017	Economy	12200.00
0005432363462	21017	Economy	12200.00
0005434150048	21017	Economy	12200.00
0005435177792	21017	Economy	12200.00
0005434150045	21017	Economy	12200.00
0005435177793	21017	Economy	12200.00
0005432336243	21017	Economy	12200.00
0005432336274	21017	Economy	12200.00
0005432361280	21017	Economy	12200.00
0005435177801	21017	Economy	12200.00
0005432336279	21017	Economy	12200.00
0005432361384	21017	Economy	12200.00
0005432363479	21017	Economy	12200.00
0005435177799	21017	Economy	12200.00
0005434150039	21017	Economy	12200.00
0005435177794	21017	Economy	12200.00
0005432336262	21017	Economy	12200.00
0005435177806	21017	Economy	12200.00
0005432052826	21017	Economy	12200.00
0005432361248	21017	Economy	12200.00
0005432360989	21017	Economy	12200.00
0005432361218	21017	Economy	12200.00
0005432361388	21017	Economy	12200.00
0005432361390	21017	Economy	12200.00
0005432336214	21017	Economy	12200.00
0005435177800	21017	Economy	12200.00
0005432336280	21017	Economy	12200.00
0005432363457	21017	Economy	12200.00
0005432361164	21017	Economy	12200.00
0005432361386	21017	Economy	12200.00
0005434459101	17716	Economy	3400.00
0005434459199	17716	Economy	3400.00
0005434448395	17716	Economy	3400.00
0005434459196	17716	Economy	3100.00
0005434448376	17716	Economy	3100.00
0005434459235	17716	Economy	3100.00
0005434459227	17716	Economy	3100.00
0005434186276	17716	Economy	3100.00
0005434459100	17716	Economy	3100.00
0005434459192	17716	Economy	3100.00
0005434459177	17716	Economy	3100.00
0005434459210	17716	Economy	3100.00
0005434461689	17716	Economy	3100.00
0005434459130	17716	Economy	3100.00
0005434459166	17716	Economy	3100.00
0005434459232	17716	Economy	3100.00
0005434461677	17716	Economy	3100.00
0005434448378	17716	Economy	3100.00
0005434448394	17716	Economy	3100.00
0005434448368	17716	Economy	3100.00
0005434459165	17716	Economy	3100.00
0005434459158	17716	Economy	3100.00
0005434459198	17716	Economy	3100.00
0005434459141	17716	Economy	3100.00
0005434459131	17716	Economy	3100.00
0005434463958	17716	Economy	3100.00
0005434459188	17716	Economy	3100.00
0005434459159	17716	Economy	3100.00
0005434459189	17716	Economy	3100.00
0005434459195	17716	Economy	3100.00
0005434459140	17716	Economy	3100.00
0005434448377	17716	Economy	3100.00
0005434186278	17716	Economy	3100.00
0005434186277	17716	Economy	3100.00
0005434459363	29108	Economy	3400.00
0005434459353	29108	Economy	3400.00
0005434459354	29108	Economy	3100.00
0005434459356	29108	Economy	3100.00
0005434448404	29108	Economy	3100.00
0005434459349	29108	Economy	3100.00
0005434459351	29108	Economy	3100.00
0005434459362	29108	Economy	3100.00
0005434462845	29108	Economy	3100.00
0005434459365	29108	Economy	3100.00
0005434186251	29108	Economy	3100.00
0005434459360	29108	Economy	3100.00
0005434459358	29108	Economy	3100.00
0005434186248	29108	Economy	3100.00
0005434186253	29108	Economy	3100.00
0005434448402	29108	Economy	3100.00
0005434459361	29108	Economy	3100.00
0005434459355	29108	Economy	3100.00
0005434448403	29108	Economy	3100.00
0005434186252	29108	Economy	3100.00
0005434448405	29108	Economy	3100.00
0005434459350	29108	Economy	3100.00
0005434459348	29108	Economy	3100.00
0005434459357	29108	Economy	3100.00
0005434462846	29108	Economy	3100.00
0005434459367	29108	Economy	3100.00
0005434459364	29108	Economy	3100.00
0005434459359	29108	Economy	3100.00
0005434459352	29108	Economy	3100.00
0005434459347	29108	Economy	3100.00
0005434459366	29108	Economy	3100.00
0005435220502	21409	Economy	7300.00
0005432605343	21409	Economy	7300.00
0005432605351	21409	Economy	7300.00
0005432605370	21409	Economy	7300.00
0005432605342	21409	Economy	6600.00
0005432605348	21409	Economy	6600.00
0005432605359	21409	Economy	6600.00
0005432605357	21409	Economy	6600.00
0005432605368	21409	Economy	6600.00
0005432605366	21409	Economy	6600.00
0005432605355	21409	Economy	6600.00
0005435220494	21409	Economy	6600.00
0005432605356	21409	Economy	6600.00
0005432605349	21409	Economy	6600.00
0005432605369	21409	Economy	6600.00
0005432605365	21409	Economy	6600.00
0005432605367	21409	Economy	6600.00
0005432605350	21409	Economy	6600.00
0005432605352	21409	Economy	6600.00
0005432605345	21409	Economy	6600.00
0005435220496	21409	Economy	6600.00
0005432605346	21409	Economy	6600.00
0005432605364	21409	Economy	6600.00
0005432605371	21409	Economy	6600.00
0005432605360	21409	Economy	6600.00
0005432605373	21409	Economy	6600.00
0005435220493	21409	Economy	6600.00
0005432605362	21409	Economy	6600.00
0005432605361	21409	Economy	6600.00
0005432605344	21409	Economy	6600.00
0005435220501	21409	Economy	6600.00
0005432605353	21409	Economy	6600.00
0005432605358	21409	Economy	6600.00
0005432605363	21409	Economy	6600.00
0005432605347	21409	Economy	6600.00
0005432605354	21409	Economy	6600.00
0005432605372	21409	Economy	6600.00
0005432604770	31702	Economy	7300.00
0005432605048	31702	Economy	7300.00
0005432605132	31702	Economy	7300.00
0005432605080	31702	Economy	6600.00
0005432605034	31702	Economy	6600.00
0005432605093	31702	Economy	6600.00
0005432604959	31702	Economy	6600.00
0005432604851	31702	Economy	6600.00
0005432605061	31702	Economy	6600.00
0005432605001	31702	Economy	6600.00
0005432604984	31702	Economy	6600.00
0005432605071	31702	Economy	6600.00
0005432604970	31702	Economy	6600.00
0005432604999	31702	Economy	6600.00
0005435221555	31702	Economy	6600.00
0005432605072	31702	Economy	6600.00
0005432605000	31702	Economy	6600.00
0005435221533	31702	Economy	6600.00
0005432605009	31702	Economy	6600.00
0005432604887	31702	Economy	6600.00
0005432604949	31702	Economy	6600.00
0005432605128	31702	Economy	6600.00
0005432604771	31702	Economy	6600.00
0005432605107	31702	Economy	6600.00
0005435221534	31702	Economy	6600.00
0005432604888	31702	Economy	6600.00
0005432604997	31702	Economy	6600.00
0005432604831	31702	Economy	6600.00
0005432605082	31702	Economy	6600.00
0005432605013	31702	Economy	6600.00
0005432604867	31702	Economy	6600.00
0005432604983	31702	Economy	6600.00
0005432604832	31702	Economy	6600.00
0005432605081	31702	Economy	6600.00
0005435221554	31702	Economy	6600.00
0005432605156	31702	Economy	6600.00
0005432605012	31702	Economy	6600.00
0005432605092	31702	Economy	6600.00
0005433293362	12307	Economy	17800.00
0005435154673	12307	Economy	17800.00
0005435154668	12307	Economy	17800.00
0005433293365	12307	Economy	17800.00
0005433293325	12307	Economy	17800.00
0005433293348	12307	Economy	17800.00
0005435154672	12307	Economy	17800.00
0005433293347	12307	Economy	17800.00
0005433293324	12307	Economy	17800.00
0005433293361	12307	Economy	17800.00
0005435154669	12307	Economy	17800.00
0005433293363	12307	Economy	17800.00
0005435154671	12307	Economy	17800.00
0005435154674	12307	Economy	17800.00
0005433293360	12307	Economy	17800.00
0005433293369	12307	Economy	17800.00
0005433293370	12307	Economy	17800.00
0005435154670	12307	Economy	17800.00
0005435904909	18837	Economy	6600.00
0005434606888	18837	Economy	6600.00
0005434606881	18837	Economy	6600.00
0005434606895	18837	Economy	6600.00
0005434606887	18837	Economy	6600.00
0005434604994	22338	Economy	6600.00
0005434606920	22338	Economy	6600.00
0005434604991	22338	Economy	6600.00
0005434604995	22338	Economy	6600.00
0005434606916	22338	Economy	6600.00
0005434604993	22338	Economy	6600.00
0005434606919	22338	Economy	6600.00
0005434606917	22338	Economy	6600.00
0005434606921	22338	Economy	6600.00
0005434604992	22338	Economy	6600.00
0005434606918	22338	Economy	6600.00
0005432748575	417	Business	44500.00
0005435154684	417	Business	44500.00
0005433875404	417	Business	44500.00
0005435154686	417	Business	44500.00
0005432748570	417	Business	44500.00
0005432748557	417	Business	44500.00
0005432891385	417	Business	44500.00
0005432748584	417	Business	44500.00
0005435154675	417	Business	44500.00
0005432748565	417	Business	44500.00
0005432220114	417	Business	44500.00
0005432749840	417	Business	44500.00
0005432220117	417	Economy	14800.00
0005435154677	417	Economy	14800.00
0005435154682	417	Economy	14800.00
0005433293308	417	Economy	14800.00
0005432891311	417	Economy	14800.00
0005432748571	417	Economy	14800.00
0005435154681	417	Economy	14800.00
0005432751613	417	Economy	14800.00
0005432891425	417	Economy	14800.00
0005435154685	417	Economy	14800.00
0005432748562	417	Economy	16300.00
0005432891379	417	Economy	16300.00
0005435154679	417	Economy	16300.00
0005432748558	417	Economy	16300.00
0005432748564	417	Economy	14800.00
0005432753387	417	Economy	14800.00
0005432748566	417	Economy	14800.00
0005432891426	417	Economy	14800.00
0005432748569	417	Economy	14800.00
0005432220118	417	Economy	14800.00
0005432220116	417	Economy	14800.00
0005432748579	417	Economy	14800.00
0005432891397	417	Economy	14800.00
0005433293342	417	Economy	14800.00
0005433293366	417	Economy	14800.00
0005432748581	417	Economy	14800.00
0005432891404	417	Economy	14800.00
0005433293346	417	Economy	14800.00
0005432753386	417	Economy	14800.00
0005432748556	417	Economy	14800.00
0005432748568	417	Economy	14800.00
0005435627128	417	Economy	14800.00
0005432220115	417	Economy	14800.00
0005432748583	417	Economy	14800.00
0005432751611	417	Economy	14800.00
0005432753388	417	Economy	14800.00
0005432749841	417	Economy	14800.00
0005433293345	417	Economy	14800.00
0005433293367	417	Economy	14800.00
0005432891274	417	Economy	14800.00
0005432891402	417	Economy	14800.00
0005435627129	417	Economy	14800.00
0005432891406	417	Economy	14800.00
0005432891289	417	Economy	14800.00
0005432891414	417	Economy	14800.00
0005432891366	417	Economy	14800.00
0005432748560	417	Economy	14800.00
0005432748563	417	Economy	14800.00
0005435154683	417	Economy	14800.00
0005435154678	417	Economy	14800.00
0005432891345	417	Economy	14800.00
0005432748580	417	Economy	14800.00
0005432748578	417	Economy	14800.00
0005432891421	417	Economy	14800.00
0005435154676	417	Economy	14800.00
0005432891384	417	Economy	14800.00
0005432748572	417	Economy	14800.00
0005432748561	417	Economy	14800.00
0005432748577	417	Economy	14800.00
0005432891312	417	Economy	14800.00
0005432891359	417	Economy	14800.00
0005432891411	417	Economy	14800.00
0005432891424	417	Economy	14800.00
0005432748582	417	Economy	14800.00
0005432891365	417	Economy	14800.00
0005432891377	417	Economy	14800.00
0005432891313	417	Economy	14800.00
0005432891405	417	Economy	14800.00
0005432748559	417	Economy	14800.00
0005435154680	417	Economy	14800.00
0005432748573	417	Economy	14800.00
0005432748585	417	Economy	14800.00
0005432748576	417	Economy	14800.00
0005432751612	417	Economy	14800.00
0005432748574	417	Economy	14800.00
0005432891280	417	Economy	14800.00
0005432891360	417	Economy	14800.00
0005432891288	417	Economy	14800.00
0005432891401	417	Economy	14800.00
0005432748567	417	Economy	14800.00
0005433293378	417	Economy	14800.00
0005435154618	12069	Business	44500.00
0005432748149	12069	Business	44500.00
0005434152863	12069	Business	44500.00
0005434153577	12069	Business	44500.00
0005434153575	12069	Business	44500.00
0005433293403	12069	Business	44500.00
0005432756906	12069	Business	44500.00
0005432748150	12069	Business	44500.00
0005432756907	12069	Business	44500.00
0005432748284	12069	Business	44500.00
0005435154617	12069	Business	44500.00
0005432748342	12069	Business	44500.00
0005433293416	12069	Economy	14800.00
0005432748237	12069	Economy	14800.00
0005435154619	12069	Economy	14800.00
0005432748318	12069	Economy	14800.00
0005432748289	12069	Economy	14800.00
0005435154612	12069	Economy	14800.00
0005432891544	12069	Economy	14800.00
0005432749817	12069	Economy	14800.00
0005432753357	12069	Economy	14800.00
0005432891531	12069	Economy	14800.00
0005432748277	12069	Economy	16300.00
0005432891532	12069	Economy	16300.00
0005432891541	12069	Economy	16300.00
0005432748341	12069	Economy	16300.00
0005433293409	12069	Economy	16300.00
0005435154615	12069	Economy	14800.00
0005433875425	12069	Economy	14800.00
0005432748323	12069	Economy	14800.00
0005432748208	12069	Economy	14800.00
0005434153576	12069	Economy	14800.00
0005432891540	12069	Economy	14800.00
0005433293418	12069	Economy	14800.00
0005433293411	12069	Economy	14800.00
0005433293415	12069	Economy	14800.00
0005432891546	12069	Economy	14800.00
0005432748259	12069	Economy	14800.00
0005433293412	12069	Economy	14800.00
0005432753358	12069	Economy	14800.00
0005433293404	12069	Economy	14800.00
0005432748327	12069	Economy	14800.00
0005435154602	12069	Economy	14800.00
0005432748340	12069	Economy	14800.00
0005432748269	12069	Economy	14800.00
0005435154613	12069	Economy	14800.00
0005434152864	12069	Economy	14800.00
0005432891547	12069	Economy	14800.00
0005433293407	12069	Economy	14800.00
0005432748370	12069	Economy	14800.00
0005432748412	12069	Economy	14800.00
0005433875426	12069	Economy	14800.00
0005432748489	12069	Economy	14800.00
0005432748369	12069	Economy	14800.00
0005433293400	12069	Economy	14800.00
0005435154616	12069	Economy	14800.00
0005432748313	12069	Economy	14800.00
0005432748326	12069	Economy	14800.00
0005432748285	12069	Economy	14800.00
0005433293410	12069	Economy	14800.00
0005432753362	12069	Economy	14800.00
0005435154620	12069	Economy	14800.00
0005432891529	12069	Economy	14800.00
0005433293405	12069	Economy	14800.00
0005432891536	12069	Economy	14800.00
0005432756901	12069	Economy	14800.00
0005432748195	12069	Economy	14800.00
0005432891537	12069	Economy	14800.00
0005432748344	12069	Economy	14800.00
0005432748224	12069	Economy	14800.00
0005433293402	12069	Economy	14800.00
0005432214861	12069	Economy	14800.00
0005432891542	12069	Economy	14800.00
0005432748218	12069	Economy	14800.00
0005434152862	12069	Economy	14800.00
0005432214860	12069	Economy	14800.00
0005432891533	12069	Economy	14800.00
0005433293417	12069	Economy	14800.00
0005432748198	12069	Economy	14800.00
0005432891538	12069	Economy	14800.00
0005435154609	12069	Economy	14800.00
0005432891543	12069	Economy	14800.00
0005433293414	12069	Economy	14800.00
0005433293401	12069	Economy	14800.00
0005432891528	12069	Economy	14800.00
0005432891534	12069	Economy	14800.00
0005433293406	12069	Economy	14800.00
0005432891535	12069	Economy	14800.00
0005432891545	12069	Economy	14800.00
0005432891539	12069	Economy	14800.00
0005433293408	12069	Economy	14800.00
0005432891530	12069	Economy	14800.00
0005432748209	12069	Economy	14800.00
0005432748312	12069	Economy	14800.00
0005432748288	12069	Economy	14800.00
0005432748278	12069	Economy	14800.00
0005433293413	12069	Economy	14800.00
0005433525319	18948	Economy	28200.00
0005433525320	18948	Economy	25700.00
0005432928070	18948	Economy	25700.00
0005433525322	18948	Economy	25700.00
0005433531390	18948	Economy	25700.00
0005433531391	18948	Economy	25700.00
0005433533405	18948	Economy	25700.00
0005432928088	18948	Economy	25700.00
0005433525315	18948	Economy	25700.00
0005432928089	18948	Economy	25700.00
0005433531389	18948	Economy	25700.00
0005433525316	18948	Economy	25700.00
0005433525317	18948	Economy	25700.00
0005433533404	18948	Economy	25700.00
0005432928090	18948	Economy	25700.00
0005433533403	18948	Economy	25700.00
0005433525323	18948	Economy	25700.00
0005433525321	18948	Economy	25700.00
0005432928100	18948	Economy	25700.00
0005433525318	18948	Economy	25700.00
0005433533406	18948	Economy	25700.00
0005433531392	18948	Economy	25700.00
0005433525324	18948	Economy	25700.00
0005433525325	18948	Economy	25700.00
0005433531358	32509	Economy	28200.00
0005432928132	32509	Economy	28200.00
0005433527324	32509	Economy	25700.00
0005433531356	32509	Economy	25700.00
0005433531354	32509	Economy	25700.00
0005433525279	32509	Economy	25700.00
0005433527321	32509	Economy	25700.00
0005433527319	32509	Economy	25700.00
0005433525228	32509	Economy	25700.00
0005433525232	32509	Economy	25700.00
0005433525257	32509	Economy	25700.00
0005433525221	32509	Economy	25700.00
0005433531355	32509	Economy	25700.00
0005433527320	32509	Economy	25700.00
0005433531343	32509	Economy	25700.00
0005432928133	32509	Economy	25700.00
0005433527304	32509	Economy	25700.00
0005433527303	32509	Economy	25700.00
0005433525207	32509	Economy	25700.00
0005433527335	32509	Economy	25700.00
0005432928131	32509	Economy	25700.00
0005433527322	32509	Economy	25700.00
0005433525283	32509	Economy	25700.00
0005433525206	32509	Economy	25700.00
0005433525284	32509	Economy	25700.00
0005433525278	32509	Economy	25700.00
0005433525203	32509	Economy	25700.00
0005433525256	32509	Economy	25700.00
0005433525188	32509	Economy	25700.00
0005433525280	32509	Economy	25700.00
0005433525227	32509	Economy	25700.00
0005433525205	32509	Economy	25700.00
0005435150393	5295	Business	84000.00
0005435374575	5295	Business	84000.00
0005434826937	5295	Business	84000.00
0005435304232	5295	Business	84000.00
0005434826887	5295	Business	84000.00
0005434826878	5295	Business	84000.00
0005434826882	5295	Business	84000.00
0005434826922	5295	Business	84000.00
0005434828767	5295	Business	84000.00
0005434826890	5295	Business	84000.00
0005434826964	5295	Business	84000.00
0005434826898	5295	Business	84000.00
0005435374513	5295	Business	84000.00
0005434826947	5295	Business	84000.00
0005435374288	5295	Business	84000.00
0005434826884	5295	Business	84000.00
0005434831269	5295	Business	84000.00
0005432823480	5295	Business	84000.00
0005435374496	5295	Comfort	47600.00
0005434826905	5295	Comfort	47600.00
0005435386718	5295	Comfort	47600.00
0005435150396	5295	Comfort	47600.00
0005434826901	5295	Comfort	47600.00
0005434826959	5295	Comfort	47600.00
0005434826925	5295	Comfort	47600.00
0005434558509	5295	Comfort	47600.00
0005434826868	5295	Comfort	47600.00
0005434828770	5295	Comfort	47600.00
0005434826895	5295	Comfort	47600.00
0005434826866	5295	Comfort	47600.00
0005435386686	5295	Comfort	47600.00
0005434826913	5295	Comfort	47600.00
0005432396347	5295	Comfort	47600.00
0005434826885	5295	Comfort	47600.00
0005434665019	5295	Comfort	47600.00
0005435150397	5295	Comfort	47600.00
0005434826908	5295	Comfort	47600.00
0005434826911	5295	Comfort	47600.00
0005434826879	5295	Comfort	47600.00
0005435299865	5295	Comfort	47600.00
0005435374506	5295	Comfort	47600.00
0005434826907	5295	Comfort	47600.00
0005434831270	5295	Comfort	47600.00
0005432121705	5295	Comfort	47600.00
0005434826955	5295	Economy	28000.00
0005435374466	5295	Comfort	47600.00
0005434558512	5295	Economy	28000.00
0005434831272	5295	Economy	28000.00
0005434826873	5295	Economy	28000.00
0005435374654	5295	Economy	28000.00
0005434826958	5295	Economy	28000.00
0005435179004	5295	Economy	28000.00
0005432121711	5295	Economy	28000.00
0005435150391	5295	Economy	28000.00
0005435374411	5295	Economy	28000.00
0005435374377	5295	Economy	28000.00
0005434826971	5295	Economy	28000.00
0005434826930	5295	Economy	28000.00
0005435374465	5295	Economy	28000.00
0005434826938	5295	Economy	28000.00
0005434826886	5295	Economy	28000.00
0005435374380	5295	Economy	28000.00
0005434826864	5295	Economy	28000.00
0005435374284	5295	Economy	28000.00
0005435374254	5295	Economy	28000.00
0005434826899	5295	Economy	28000.00
0005434558500	5295	Economy	28000.00
0005434826967	5295	Economy	28000.00
0005434558513	5295	Economy	28000.00
0005434558499	5295	Economy	28000.00
0005434826906	5295	Economy	28000.00
0005435150395	5295	Economy	28000.00
0005435374105	5295	Economy	28000.00
0005434826928	5295	Economy	28000.00
0005432121703	5295	Economy	28000.00
0005432394211	5295	Economy	28000.00
0005434828769	5295	Economy	28000.00
0005434826948	5295	Economy	28000.00
0005435150399	5295	Economy	28000.00
0005434826893	5295	Economy	28000.00
0005435374381	5295	Economy	28000.00
0005435374275	5295	Economy	28000.00
0005435374403	5295	Economy	28000.00
0005432396348	5295	Economy	28000.00
0005434826891	5295	Economy	28000.00
0005434826915	5295	Economy	28000.00
0005435374505	5295	Economy	28000.00
0005432121707	5295	Economy	28000.00
0005435299866	5295	Economy	28000.00
0005432121700	5295	Economy	28000.00
0005434826943	5295	Economy	28000.00
0005432823489	5295	Economy	28000.00
0005434826952	5295	Economy	28000.00
0005434558504	5295	Economy	30800.00
0005435374552	5295	Economy	28000.00
0005434826939	5295	Economy	28000.00
0005435150400	5295	Economy	30800.00
0005432121713	5295	Economy	28000.00
0005435150401	5295	Economy	30800.00
0005434826877	5295	Economy	28000.00
0005435374666	5295	Economy	28000.00
0005434826894	5295	Economy	28000.00
0005435374481	5295	Economy	28000.00
0005432121704	5295	Economy	28000.00
0005434826944	5295	Economy	28000.00
0005434558502	5295	Economy	28000.00
0005435299855	5295	Economy	28000.00
0005432121712	5295	Economy	28000.00
0005435374456	5295	Economy	28000.00
0005435374158	5295	Economy	28000.00
0005435386685	5295	Economy	28000.00
0005434826935	5295	Economy	28000.00
0005435386667	5295	Economy	28000.00
0005434826923	5295	Economy	28000.00
0005435374441	5295	Economy	28000.00
0005435374460	5295	Economy	28000.00
0005435299883	5295	Economy	28000.00
0005434826957	5295	Economy	28000.00
0005434826961	5295	Economy	28000.00
0005435179702	5295	Economy	28000.00
0005434826942	5295	Economy	28000.00
0005432121709	5295	Economy	28000.00
0005432121701	5295	Economy	28000.00
0005434826956	5295	Economy	28000.00
0005434826867	5295	Economy	28000.00
0005434558505	5295	Economy	28000.00
0005434558510	5295	Economy	28000.00
0005434826960	5295	Economy	28000.00
0005435374405	5295	Economy	28000.00
0005434558508	5295	Economy	28000.00
0005434558498	5295	Economy	28000.00
0005432396346	5295	Economy	28000.00
0005432121706	5295	Economy	28000.00
0005435374367	5295	Economy	28000.00
0005434826912	5295	Economy	28000.00
0005435374559	5295	Economy	28000.00
0005434826962	5295	Economy	28000.00
0005434826933	5295	Economy	28000.00
0005434831271	5295	Economy	28000.00
0005435374516	5295	Economy	28000.00
0005434826918	5295	Economy	28000.00
0005434826920	5295	Economy	28000.00
0005434826970	5295	Economy	28000.00
0005435374368	5295	Economy	28000.00
0005434826927	5295	Economy	28000.00
0005434826902	5295	Economy	28000.00
0005434826896	5295	Economy	28000.00
0005435150398	5295	Economy	28000.00
0005432121708	5295	Economy	28000.00
0005435374408	5295	Economy	28000.00
0005434826965	5295	Economy	28000.00
0005434826875	5295	Economy	28000.00
0005434826870	5295	Economy	28000.00
0005434826904	5295	Economy	28000.00
0005435374310	5295	Economy	28000.00
0005434665020	5295	Economy	28000.00
0005435386683	5295	Economy	28000.00
0005434826963	5295	Economy	28000.00
0005434826924	5295	Economy	28000.00
0005434826951	5295	Economy	28000.00
0005434826949	5295	Economy	28000.00
0005435374550	5295	Economy	28000.00
0005435374401	5295	Economy	28000.00
0005434826863	5295	Economy	28000.00
0005434826968	5295	Economy	28000.00
0005435150392	5295	Economy	28000.00
0005435150394	5295	Economy	28000.00
0005434826941	5295	Economy	28000.00
0005434826892	5295	Economy	28000.00
0005434826969	5295	Economy	28000.00
0005434826926	5295	Economy	28000.00
0005434826889	5295	Economy	28000.00
0005435374291	5295	Economy	28000.00
0005434826946	5295	Economy	28000.00
0005434826919	5295	Economy	30800.00
0005434826909	5295	Economy	30800.00
0005434826954	5295	Economy	30800.00
0005434826883	5295	Economy	28000.00
0005434826953	5295	Economy	28000.00
0005434826921	5295	Economy	28000.00
0005434826876	5295	Economy	28000.00
0005434826910	5295	Economy	28000.00
0005434826914	5295	Economy	28000.00
0005434826950	5295	Economy	28000.00
0005435374749	5295	Economy	28000.00
0005435373902	5295	Economy	28000.00
0005435374391	5295	Economy	28000.00
0005434826931	5295	Economy	28000.00
0005435374340	5295	Economy	28000.00
0005434826966	5295	Economy	28000.00
0005434826917	5295	Economy	28000.00
0005435150390	5295	Economy	28000.00
0005435374339	5295	Economy	28000.00
0005434826888	5295	Economy	28000.00
0005435374609	5295	Economy	28000.00
0005432394210	5295	Economy	28000.00
0005434826869	5295	Economy	28000.00
0005435661965	5295	Economy	28000.00
0005432121710	5295	Economy	28000.00
0005432823488	5295	Economy	28000.00
0005435179703	5295	Economy	28000.00
0005434558511	5295	Economy	28000.00
0005434826880	5295	Economy	28000.00
0005434826865	5295	Economy	28000.00
0005435374352	5295	Economy	28000.00
0005432121702	5295	Economy	28000.00
0005434826874	5295	Economy	28000.00
0005435374507	5295	Economy	28000.00
0005434558503	5295	Economy	28000.00
0005434826932	5295	Economy	28000.00
0005434826872	5295	Economy	28000.00
0005435374608	5295	Economy	28000.00
0005435374424	5295	Economy	28000.00
0005434826940	5295	Economy	28000.00
0005435374159	5295	Economy	28000.00
0005434826936	5295	Economy	28000.00
0005434826897	5295	Economy	28000.00
0005435374238	5295	Economy	28000.00
0005435374560	5295	Economy	28000.00
0005434558507	5295	Economy	28000.00
0005435374551	5295	Economy	28000.00
0005434558506	5295	Economy	28000.00
0005434828768	5295	Economy	28000.00
0005435374407	5295	Economy	28000.00
0005434826945	5295	Economy	28000.00
0005435374655	5295	Economy	28000.00
0005434826881	5295	Economy	28000.00
0005434826916	5295	Economy	28000.00
0005435374406	5295	Economy	28000.00
0005434826903	5295	Economy	28000.00
0005432394212	5295	Economy	28000.00
0005434826929	5295	Economy	28000.00
0005435374394	5295	Economy	28000.00
0005434826871	5295	Economy	28000.00
0005434826934	5295	Economy	28000.00
0005434558501	5295	Economy	28000.00
0005434826900	5295	Economy	28000.00
0005432396313	9919	Business	84000.00
0005434825978	9919	Business	84000.00
0005435374988	9919	Business	84000.00
0005432400203	9919	Business	84000.00
0005435299902	9919	Business	84000.00
0005435374996	9919	Business	84000.00
0005434826069	9919	Business	84000.00
0005432203256	9919	Business	84000.00
0005435302322	9919	Business	84000.00
0005434825906	9919	Business	84000.00
0005434826039	9919	Business	84000.00
0005435374954	9919	Business	84000.00
0005434826240	9919	Business	84000.00
0005432203253	9919	Business	84000.00
0005435662007	9919	Business	84000.00
0005434825462	9919	Business	84000.00
0005434665003	9919	Business	84000.00
0005432396304	9919	Business	84000.00
0005435315064	9919	Business	84000.00
0005434825740	9919	Business	84000.00
0005435315078	9919	Comfort	47600.00
0005434826132	9919	Comfort	47600.00
0005435375010	9919	Comfort	47600.00
0005434826023	9919	Comfort	47600.00
0005434825377	9919	Comfort	47600.00
0005435374964	9919	Comfort	47600.00
0005435150246	9919	Comfort	47600.00
0005435374968	9919	Comfort	47600.00
0005434826174	9919	Comfort	47600.00
0005434664987	9919	Comfort	47600.00
0005434825900	9919	Comfort	47600.00
0005434825810	9919	Comfort	47600.00
0005435315069	9919	Comfort	47600.00
0005435386740	9919	Comfort	47600.00
0005434826092	9919	Comfort	47600.00
0005434831229	9919	Comfort	47600.00
0005435302324	9919	Comfort	47600.00
0005435150228	9919	Comfort	47600.00
0005435374993	9919	Comfort	47600.00
0005434825571	9919	Comfort	47600.00
0005435735263	9919	Comfort	47600.00
0005434825655	9919	Comfort	47600.00
0005434826208	9919	Comfort	47600.00
0005434826139	9919	Comfort	47600.00
0005432203257	9919	Comfort	47600.00
0005434826195	9919	Comfort	47600.00
0005434825623	9919	Comfort	47600.00
0005434825719	9919	Comfort	47600.00
0005435315067	9919	Comfort	47600.00
0005434825546	9919	Comfort	47600.00
0005435374973	9919	Economy	28000.00
0005434825537	9919	Economy	28000.00
0005435150291	9919	Economy	28000.00
0005435315065	9919	Economy	28000.00
0005434664988	9919	Economy	28000.00
0005434825827	9919	Economy	28000.00
0005434825624	9919	Economy	28000.00
0005435302325	9919	Economy	28000.00
0005434831244	9919	Economy	28000.00
0005435315072	9919	Economy	28000.00
0005434825877	9919	Economy	28000.00
0005434826163	9919	Economy	28000.00
0005434825688	9919	Economy	28000.00
0005435374982	9919	Economy	28000.00
0005435375012	9919	Economy	28000.00
0005435150327	9919	Economy	28000.00
0005434825889	9919	Economy	28000.00
0005435299903	9919	Economy	28000.00
0005435150171	9919	Economy	28000.00
0005434826026	9919	Economy	28000.00
0005435374957	9919	Economy	28000.00
0005435374984	9919	Economy	28000.00
0005434826131	9919	Economy	28000.00
0005435374990	9919	Economy	28000.00
0005432400185	9919	Economy	28000.00
0005434826162	9919	Economy	28000.00
0005435374960	9919	Economy	28000.00
0005434825782	9919	Economy	28000.00
0005435374992	9919	Economy	28000.00
0005435374983	9919	Economy	28000.00
0005435374958	9919	Economy	28000.00
0005434825920	9919	Economy	28000.00
0005435386738	9919	Economy	28000.00
0005435375008	9919	Economy	28000.00
0005434558402	9919	Economy	28000.00
0005434824998	9919	Economy	28000.00
0005434826355	9919	Economy	28000.00
0005435374999	9919	Economy	28000.00
0005435374966	9919	Economy	28000.00
0005435374972	9919	Economy	28000.00
0005435315070	9919	Economy	28000.00
0005434826160	9919	Economy	28000.00
0005434825214	9919	Economy	28000.00
0005435375006	9919	Economy	28000.00
0005434825542	9919	Economy	28000.00
0005435179423	9919	Economy	28000.00
0005435374997	9919	Economy	28000.00
0005435374991	9919	Economy	28000.00
0005435374965	9919	Economy	30800.00
0005434825528	9919	Economy	28000.00
0005434825804	9919	Economy	30800.00
0005434825379	9919	Economy	28000.00
0005432203252	9919	Economy	28000.00
0005434826010	9919	Economy	30800.00
0005435374971	9919	Economy	30800.00
0005434825374	9919	Economy	28000.00
0005432400204	9919	Economy	28000.00
0005434826412	9919	Economy	28000.00
0005434825721	9919	Economy	28000.00
0005435375001	9919	Economy	28000.00
0005435662006	9919	Economy	28000.00
0005434826085	9919	Economy	28000.00
0005434825421	9919	Economy	28000.00
0005435150243	9919	Economy	28000.00
0005435374995	9919	Economy	28000.00
0005435150290	9919	Economy	28000.00
0005432203259	9919	Economy	28000.00
0005434825541	9919	Economy	28000.00
0005432203258	9919	Economy	28000.00
0005432823504	9919	Economy	28000.00
0005435374985	9919	Economy	28000.00
0005434825744	9919	Economy	28000.00
0005434826364	9919	Economy	28000.00
0005434826029	9919	Economy	28000.00
0005434826265	9919	Economy	28000.00
0005435374961	9919	Economy	28000.00
0005435150229	9919	Economy	28000.00
0005435315068	9919	Economy	28000.00
0005434558413	9919	Economy	28000.00
0005435375009	9919	Economy	28000.00
0005434831213	9919	Economy	28000.00
0005434825570	9919	Economy	28000.00
0005434825552	9919	Economy	28000.00
0005434825650	9919	Economy	28000.00
0005434825974	9919	Economy	28000.00
0005434826626	9919	Economy	28000.00
0005435375002	9919	Economy	28000.00
0005434825739	9919	Economy	28000.00
0005435299901	9919	Economy	28000.00
0005435299905	9919	Economy	28000.00
0005435374979	9919	Economy	28000.00
0005435315077	9919	Economy	28000.00
0005434558371	9919	Economy	28000.00
0005434826625	9919	Economy	28000.00
0005435315076	9919	Economy	28000.00
0005434826070	9919	Economy	28000.00
0005435374975	9919	Economy	28000.00
0005435374963	9919	Economy	28000.00
0005434826497	9919	Economy	28000.00
0005434825370	9919	Economy	28000.00
0005434825834	9919	Economy	28000.00
0005434825330	9919	Economy	28000.00
0005434826052	9919	Economy	28000.00
0005435374956	9919	Economy	28000.00
0005434826071	9919	Economy	28000.00
0005434825795	9919	Economy	28000.00
0005434825948	9919	Economy	28000.00
0005435374981	9919	Economy	28000.00
0005434825799	9919	Economy	28000.00
0005435150170	9919	Economy	28000.00
0005434558427	9919	Economy	28000.00
0005435375000	9919	Economy	28000.00
0005434825376	9919	Economy	28000.00
0005435302326	9919	Economy	28000.00
0005434824997	9919	Economy	28000.00
0005434825963	9919	Economy	28000.00
0005434826363	9919	Economy	28000.00
0005432203254	9919	Economy	28000.00
0005435150285	9919	Economy	28000.00
0005434558426	9919	Economy	28000.00
0005434825621	9919	Economy	28000.00
0005434825794	9919	Economy	28000.00
0005434826264	9919	Economy	28000.00
0005434825803	9919	Economy	28000.00
0005435374976	9919	Economy	28000.00
0005435150225	9919	Economy	28000.00
0005435375011	9919	Economy	28000.00
0005435315061	9919	Economy	28000.00
0005435150334	9919	Economy	28000.00
0005434825651	9919	Economy	28000.00
0005434825918	9919	Economy	28000.00
0005434826105	9919	Economy	28000.00
0005435299904	9919	Economy	28000.00
0005434558420	9919	Economy	28000.00
0005434825505	9919	Economy	28000.00
0005434831225	9919	Economy	28000.00
0005434826115	9919	Economy	28000.00
0005435374987	9919	Economy	28000.00
0005434826135	9919	Economy	28000.00
0005435315073	9919	Economy	30800.00
0005434826256	9919	Economy	30800.00
0005434826091	9919	Economy	30800.00
0005434826161	9919	Economy	30800.00
0005435315075	9919	Economy	30800.00
0005434825798	9919	Economy	28000.00
0005434831218	9919	Economy	28000.00
0005434825999	9919	Economy	28000.00
0005434825781	9919	Economy	28000.00
0005435374989	9919	Economy	28000.00
0005435375007	9919	Economy	28000.00
0005434825128	9919	Economy	28000.00
0005435375003	9919	Economy	28000.00
0005434826606	9919	Economy	28000.00
0005434558384	9919	Economy	28000.00
0005434825921	9919	Economy	28000.00
0005434826027	9919	Economy	28000.00
0005434558400	9919	Economy	28000.00
0005434825852	9919	Economy	28000.00
0005435735262	9919	Economy	28000.00
0005435662008	9919	Economy	28000.00
0005434825622	9919	Economy	28000.00
0005434825643	9919	Economy	28000.00
0005435315074	9919	Economy	28000.00
0005435374998	9919	Economy	28000.00
0005435315066	9919	Economy	28000.00
0005435374959	9919	Economy	28000.00
0005432823503	9919	Economy	28000.00
0005434831222	9919	Economy	28000.00
0005434826255	9919	Economy	28000.00
0005434825743	9919	Economy	28000.00
0005434825917	9919	Economy	28000.00
0005435315063	9919	Economy	28000.00
0005434558419	9919	Economy	28000.00
0005434825489	9919	Economy	28000.00
0005434831243	9919	Economy	28000.00
0005434825504	9919	Economy	28000.00
0005435735261	9919	Economy	28000.00
0005434825876	9919	Economy	28000.00
0005434825501	9919	Economy	28000.00
0005435386739	9919	Economy	28000.00
0005435374978	9919	Economy	28000.00
0005434826607	9919	Economy	28000.00
0005434826173	9919	Economy	28000.00
0005435374967	9919	Economy	28000.00
0005434825216	9919	Economy	28000.00
0005435374974	9919	Economy	28000.00
0005432203255	9919	Economy	28000.00
0005434825977	9919	Economy	28000.00
0005434826047	9919	Economy	28000.00
0005434825663	9919	Economy	28000.00
0005434831237	9919	Economy	28000.00
0005435150215	9919	Economy	28000.00
0005435374980	9919	Economy	28000.00
0005434825964	9919	Economy	28000.00
0005434825958	9919	Economy	28000.00
0005435150216	9919	Economy	28000.00
0005434825532	9919	Economy	28000.00
0005434826048	9919	Economy	28000.00
0005434825919	9919	Economy	28000.00
0005435375005	9919	Economy	28000.00
0005434825916	9919	Economy	28000.00
0005435374969	9919	Economy	28000.00
0005435374955	9919	Economy	28000.00
0005435375004	9919	Economy	28000.00
0005434665004	9919	Economy	28000.00
0005435386741	9919	Economy	28000.00
0005435374994	9919	Economy	28000.00
0005435315062	9919	Economy	28000.00
0005435315071	9919	Economy	28000.00
0005434826138	9919	Economy	28000.00
0005434825215	9919	Economy	28000.00
0005435374986	9919	Economy	28000.00
0005435315079	9919	Economy	28000.00
0005435150226	9919	Economy	28000.00
0005434825829	9919	Economy	28000.00
0005434826209	9919	Economy	28000.00
0005434826086	9919	Economy	28000.00
0005435150335	9919	Economy	28000.00
0005434825207	9919	Economy	28000.00
0005435374970	9919	Economy	28000.00
0005435179424	9919	Economy	28000.00
0005435150330	9919	Economy	28000.00
0005434825923	9919	Economy	28000.00
0005435150242	9919	Economy	28000.00
0005434826352	9919	Economy	28000.00
0005434825533	9919	Economy	28000.00
0005434825479	9919	Economy	28000.00
0005434825830	9919	Economy	28000.00
0005435302323	9919	Economy	28000.00
0005434828736	9919	Economy	28000.00
0005435374977	9919	Economy	28000.00
0005435374962	9919	Economy	28000.00
0005434826211	9919	Economy	28000.00
0005435790385	7018	Economy	8200.00
0005435083005	7018	Economy	7400.00
0005435083001	7018	Economy	7400.00
0005435082998	7018	Economy	7400.00
0005435083007	7018	Economy	7400.00
0005435083002	7018	Economy	7400.00
0005435790384	7018	Economy	7400.00
0005435083003	7018	Economy	7400.00
0005435083000	7018	Economy	7400.00
0005435083004	7018	Economy	7400.00
0005435082997	7018	Economy	7400.00
0005435083006	7018	Economy	7400.00
0005435082999	7018	Economy	7400.00
0005435082925	26000	Economy	8200.00
0005435082906	26000	Economy	8200.00
0005435082941	26000	Economy	7400.00
0005435082908	26000	Economy	7400.00
0005435082926	26000	Economy	7400.00
0005435790366	26000	Economy	7400.00
0005435790361	26000	Economy	7400.00
0005435082931	26000	Economy	7400.00
0005435082910	26000	Economy	7400.00
0005435082901	26000	Economy	7400.00
0005435082940	26000	Economy	7400.00
0005435082929	26000	Economy	7400.00
0005435082907	26000	Economy	7400.00
0005434215342	9527	Business	32800.00
0005434215447	9527	Business	32800.00
0005434215435	9527	Business	32800.00
0005434757521	9527	Business	32800.00
0005434757523	9527	Business	32800.00
0005434757546	9527	Business	32800.00
0005434215225	9527	Business	32800.00
0005434757535	9527	Business	32800.00
0005434757555	9527	Economy	10900.00
0005434757556	9527	Economy	10900.00
0005434757564	9527	Economy	10900.00
0005434215432	9527	Economy	10900.00
0005434757553	9527	Economy	10900.00
0005434215233	9527	Economy	10900.00
0005434215232	9527	Economy	10900.00
0005434757561	9527	Economy	10900.00
0005434757532	9527	Economy	10900.00
0005434757557	9527	Economy	12000.00
0005434757542	9527	Economy	12000.00
0005434215344	9527	Economy	12000.00
0005434757524	9527	Economy	12000.00
0005434757533	9527	Economy	10900.00
0005434757536	9527	Economy	10900.00
0005434215329	9527	Economy	10900.00
0005434215461	9527	Economy	10900.00
0005434215490	9527	Economy	10900.00
0005434215170	9527	Economy	10900.00
0005434757562	9527	Economy	10900.00
0005434215393	9527	Economy	10900.00
0005434757537	9527	Economy	10900.00
0005434757531	9527	Economy	10900.00
0005434757554	9527	Economy	10900.00
0005434215346	9527	Economy	10900.00
0005434215171	9527	Economy	10900.00
0005434757526	9527	Economy	10900.00
0005434757527	9527	Economy	10900.00
0005434757545	9527	Economy	10900.00
0005434215231	9527	Economy	10900.00
0005434757559	9527	Economy	10900.00
0005434757540	9527	Economy	10900.00
0005434215224	9527	Economy	10900.00
0005434757544	9527	Economy	10900.00
0005434757538	9527	Economy	10900.00
0005434215343	9527	Economy	10900.00
0005434757543	9527	Economy	10900.00
0005434757549	9527	Economy	10900.00
0005434215191	9527	Economy	10900.00
0005434757528	9527	Economy	10900.00
0005434215458	9527	Economy	10900.00
0005434757552	9527	Economy	10900.00
0005434215202	9527	Economy	10900.00
0005434215239	9527	Economy	10900.00
0005434215316	9527	Economy	10900.00
0005434757541	9527	Economy	10900.00
0005434757563	9527	Economy	10900.00
0005434215462	9527	Economy	10900.00
0005434757539	9527	Economy	10900.00
0005434757551	9527	Economy	10900.00
0005434215446	9527	Economy	10900.00
0005434215431	9527	Economy	10900.00
0005434757550	9527	Economy	10900.00
0005434215411	9527	Economy	10900.00
0005434757522	9527	Economy	10900.00
0005434215533	9527	Economy	10900.00
0005434757534	9527	Economy	10900.00
0005434757565	9527	Economy	10900.00
0005434757558	9527	Economy	10900.00
0005434757529	9527	Economy	10900.00
0005434757525	9527	Economy	10900.00
0005434215223	9527	Economy	10900.00
0005434215261	9527	Economy	10900.00
0005434215434	9527	Economy	10900.00
0005434757530	9527	Economy	10900.00
0005434215230	9527	Economy	10900.00
0005434757560	9527	Economy	10900.00
0005434757548	9527	Economy	10900.00
0005434757547	9527	Economy	10900.00
0005434757092	28629	Business	32800.00
0005434756876	28629	Business	32800.00
0005434215705	28629	Business	32800.00
0005434215723	28629	Business	32800.00
0005434215711	28629	Business	32800.00
0005434757031	28629	Business	32800.00
0005434215729	28629	Business	32800.00
0005434215722	28629	Business	32800.00
0005434215736	28629	Business	32800.00
0005434215721	28629	Business	32800.00
0005434757094	28629	Business	32800.00
0005434215717	28629	Economy	10900.00
0005434215697	28629	Economy	10900.00
0005434757093	28629	Economy	10900.00
0005434757016	28629	Economy	10900.00
0005434757058	28629	Economy	10900.00
0005434215695	28629	Economy	10900.00
0005434215713	28629	Economy	10900.00
0005434756911	28629	Economy	10900.00
0005434215730	28629	Economy	12000.00
0005434757108	28629	Economy	12000.00
0005434757057	28629	Economy	12000.00
0005434756951	28629	Economy	12000.00
0005434757064	28629	Economy	10900.00
0005434215716	28629	Economy	10900.00
0005434215718	28629	Economy	10900.00
0005434215735	28629	Economy	10900.00
0005434215696	28629	Economy	10900.00
0005434215724	28629	Economy	10900.00
0005434215698	28629	Economy	10900.00
0005434757025	28629	Economy	10900.00
0005434215715	28629	Economy	10900.00
0005434757015	28629	Economy	10900.00
0005434757042	28629	Economy	10900.00
0005434757039	28629	Economy	10900.00
0005434756905	28629	Economy	10900.00
0005434215700	28629	Economy	10900.00
0005434757030	28629	Economy	10900.00
0005434215733	28629	Economy	10900.00
0005434757107	28629	Economy	10900.00
0005434757127	28629	Economy	10900.00
0005434757081	28629	Economy	10900.00
0005434215737	28629	Economy	10900.00
0005434757018	28629	Economy	10900.00
0005434215728	28629	Economy	10900.00
0005434757126	28629	Economy	10900.00
0005434215707	28629	Economy	10900.00
0005434757091	28629	Economy	10900.00
0005434757115	28629	Economy	10900.00
0005434215701	28629	Economy	10900.00
0005434215732	28629	Economy	10900.00
0005434215702	28629	Economy	10900.00
0005434756952	28629	Economy	10900.00
0005434215734	28629	Economy	10900.00
0005434757060	28629	Economy	10900.00
0005434215708	28629	Economy	10900.00
0005434215725	28629	Economy	10900.00
0005434215719	28629	Economy	10900.00
0005434215706	28629	Economy	10900.00
0005434757061	28629	Economy	10900.00
0005434756874	28629	Economy	10900.00
0005434215699	28629	Economy	10900.00
0005434215709	28629	Economy	10900.00
0005434757038	28629	Economy	10900.00
0005434756964	28629	Economy	10900.00
0005434757068	28629	Economy	10900.00
0005434756875	28629	Economy	10900.00
0005434215703	28629	Economy	10900.00
0005434757069	28629	Economy	10900.00
0005434215720	28629	Economy	10900.00
0005434215712	28629	Economy	10900.00
0005434215704	28629	Economy	10900.00
0005434757013	28629	Economy	10900.00
0005434215726	28629	Economy	10900.00
0005434757102	28629	Economy	10900.00
0005434757043	28629	Economy	10900.00
0005434757014	28629	Economy	10900.00
0005434756969	28629	Economy	10900.00
0005434756851	28629	Economy	10900.00
0005434215731	28629	Economy	10900.00
0005434215710	28629	Economy	10900.00
0005434215727	28629	Economy	10900.00
0005434215714	28629	Economy	10900.00
0005434757078	28629	Economy	10900.00
0005435100202	10832	Economy	8900.00
0005435100201	10832	Economy	8900.00
0005434760236	10832	Economy	8900.00
0005435100203	10832	Economy	8900.00
0005434760262	31824	Economy	9800.00
0005435100175	31824	Economy	8900.00
0005434760263	31824	Economy	8900.00
0005435100174	31824	Economy	8900.00
0005434640006	1960	Economy	20900.00
0005435948358	1960	Economy	20900.00
0005434640001	1960	Economy	20900.00
0005433202574	1960	Economy	19000.00
0005434640021	1960	Economy	19000.00
0005434640018	1960	Economy	19000.00
0005434640013	1960	Economy	19000.00
0005433202612	1960	Economy	19000.00
0005434640005	1960	Economy	19000.00
0005433202654	1960	Economy	19000.00
0005434640008	1960	Economy	19000.00
0005434640010	1960	Economy	19000.00
0005432290716	1960	Economy	19000.00
0005433202674	1960	Economy	19000.00
0005434640004	1960	Economy	19000.00
0005433202575	1960	Economy	19000.00
0005435948357	1960	Economy	19000.00
0005433202656	1960	Economy	19000.00
0005433202590	1960	Economy	19000.00
0005434640000	1960	Economy	19000.00
0005433202632	1960	Economy	19000.00
0005433202555	1960	Economy	19000.00
0005433202591	1960	Economy	19000.00
0005433202559	1960	Economy	19000.00
0005434640007	1960	Economy	19000.00
0005435948359	1960	Economy	19000.00
0005432290715	1960	Economy	19000.00
0005433202560	1960	Economy	19000.00
0005434640002	1960	Economy	19000.00
0005434640016	1960	Economy	19000.00
0005434639999	1960	Economy	19000.00
0005434640011	1960	Economy	19000.00
0005434640012	1960	Economy	19000.00
0005434640014	1960	Economy	19000.00
0005434640017	1960	Economy	19000.00
0005434640015	1960	Economy	19000.00
0005434640003	1960	Economy	19000.00
0005433202618	1960	Economy	19000.00
0005434640019	1960	Economy	19000.00
0005434640009	1960	Economy	19000.00
0005433202673	1960	Economy	19000.00
0005433202655	1960	Economy	19000.00
0005434640020	1960	Economy	19000.00
0005434639714	23297	Economy	20900.00
0005433202741	23297	Economy	20900.00
0005434639778	23297	Economy	20900.00
0005433202744	23297	Economy	20900.00
0005434639794	23297	Economy	19000.00
0005433202746	23297	Economy	19000.00
0005433202735	23297	Economy	19000.00
0005433202736	23297	Economy	19000.00
0005433202743	23297	Economy	19000.00
0005434639799	23297	Economy	19000.00
0005434639797	23297	Economy	19000.00
0005433202740	23297	Economy	19000.00
0005434639859	23297	Economy	19000.00
0005434639793	23297	Economy	19000.00
0005434639607	23297	Economy	19000.00
0005433202738	23297	Economy	19000.00
0005433202747	23297	Economy	19000.00
0005434639724	23297	Economy	19000.00
0005434639742	23297	Economy	19000.00
0005434639830	23297	Economy	19000.00
0005433202734	23297	Economy	19000.00
0005434639653	23297	Economy	19000.00
0005433202737	23297	Economy	19000.00
0005434639737	23297	Economy	19000.00
0005434639908	23297	Economy	19000.00
0005434639741	23297	Economy	19000.00
0005434639725	23297	Economy	19000.00
0005433202745	23297	Economy	19000.00
0005434639790	23297	Economy	19000.00
0005434639789	23297	Economy	19000.00
0005434639654	23297	Economy	19000.00
0005434639791	23297	Economy	19000.00
0005433202748	23297	Economy	19000.00
0005434639628	23297	Economy	19000.00
0005433202742	23297	Economy	19000.00
0005434639909	23297	Economy	19000.00
0005434639792	23297	Economy	19000.00
0005434639787	23297	Economy	19000.00
0005434639722	23297	Economy	19000.00
0005434639676	23297	Economy	19000.00
0005434639774	23297	Economy	19000.00
0005434639860	23297	Economy	19000.00
0005433202739	23297	Economy	19000.00
0005435327010	6039	Business	69700.00
0005433533410	6039	Business	69700.00
0005432111357	6039	Business	69700.00
0005435327009	6039	Business	69700.00
0005435326956	6039	Business	69700.00
0005432111358	6039	Business	69700.00
0005433531395	6039	Business	69700.00
0005434601511	6039	Economy	23200.00
0005435327034	6039	Economy	23200.00
0005434601514	6039	Economy	23200.00
0005434601519	6039	Economy	25600.00
0005434601509	6039	Economy	25600.00
0005434601508	6039	Economy	23200.00
0005435326981	6039	Economy	23200.00
0005435326966	6039	Economy	23200.00
0005433531394	6039	Economy	23200.00
0005434601510	6039	Economy	23200.00
0005434601520	6039	Economy	23200.00
0005434601516	6039	Economy	23200.00
0005434601515	6039	Economy	23200.00
0005434601522	6039	Economy	23200.00
0005434601517	6039	Economy	23200.00
0005433531398	6039	Economy	23200.00
0005434601513	6039	Economy	23200.00
0005433533407	6039	Economy	23200.00
0005433533409	6039	Economy	23200.00
0005433531393	6039	Economy	23200.00
0005433531397	6039	Economy	23200.00
0005435326954	6039	Economy	23200.00
0005435327040	6039	Economy	23200.00
0005434601518	6039	Economy	23200.00
0005435327024	6039	Economy	23200.00
0005434601506	6039	Economy	23200.00
0005434601505	6039	Economy	23200.00
0005435327032	6039	Economy	23200.00
0005434601521	6039	Economy	23200.00
0005435327018	6039	Economy	23200.00
0005432111359	6039	Economy	23200.00
0005432111360	6039	Economy	23200.00
0005435327033	6039	Economy	23200.00
0005435326955	6039	Economy	23200.00
0005433531396	6039	Economy	23200.00
0005434601507	6039	Economy	23200.00
0005433533408	6039	Economy	23200.00
0005434601512	6039	Economy	23200.00
0005435326993	6039	Economy	23200.00
0005435327019	6039	Economy	23200.00
0005434601309	18596	Business	69700.00
0005434601295	18596	Business	69700.00
0005434601314	18596	Business	69700.00
0005434601283	18596	Business	69700.00
0005434601239	18596	Business	69700.00
0005434601331	18596	Economy	23200.00
0005434601367	18596	Economy	23200.00
0005435327111	18596	Economy	23200.00
0005434601366	18596	Economy	23200.00
0005435327107	18596	Economy	23200.00
0005434601360	18596	Economy	25600.00
0005434601265	18596	Economy	25600.00
0005435327105	18596	Economy	25600.00
0005435327104	18596	Economy	25600.00
0005434601302	18596	Economy	23200.00
0005434601198	18596	Economy	23200.00
0005435327103	18596	Economy	23200.00
0005434601199	18596	Economy	23200.00
0005434601197	18596	Economy	23200.00
0005434601330	18596	Economy	23200.00
0005433531370	18596	Economy	23200.00
0005435327113	18596	Economy	23200.00
0005435327108	18596	Economy	23200.00
0005433531369	18596	Economy	23200.00
0005435327112	18596	Economy	23200.00
0005434601371	18596	Economy	23200.00
0005434601301	18596	Economy	23200.00
0005434601284	18596	Economy	23200.00
0005435327106	18596	Economy	23200.00
0005434601275	18596	Economy	23200.00
0005435327110	18596	Economy	23200.00
0005433527326	18596	Economy	23200.00
0005434601266	18596	Economy	23200.00
0005434601315	18596	Economy	23200.00
0005433531353	18596	Economy	23200.00
0005435327109	18596	Economy	23200.00
0005434601374	18596	Economy	23200.00
0005435327102	18596	Economy	23200.00
0005435327114	18596	Economy	23200.00
0005433527311	18596	Economy	23200.00
0005434601214	18596	Economy	23200.00
0005434601361	18596	Economy	23200.00
0005433527327	18596	Economy	23200.00
0005434601332	18596	Economy	23200.00
0005433527310	18596	Economy	23200.00
0005433181550	10641	Business	9100.00
0005433181399	10641	Business	9100.00
0005433181500	10641	Business	9100.00
0005434552647	10641	Business	9100.00
0005434552625	10641	Business	9100.00
0005434552620	10641	Business	9100.00
0005434552631	10641	Business	9100.00
0005434552636	10641	Business	9100.00
0005434552632	10641	Business	9100.00
0005434552639	10641	Business	9100.00
0005434552616	10641	Business	9100.00
0005434552605	10641	Business	9100.00
0005433181504	10641	Economy	3000.00
0005433181546	10641	Economy	3000.00
0005434552619	10641	Economy	3000.00
0005434552606	10641	Economy	3000.00
0005434552623	10641	Economy	3000.00
0005433181628	10641	Economy	3000.00
0005434558496	10641	Economy	3000.00
0005434552653	10641	Economy	3000.00
0005433181449	10641	Economy	3000.00
0005434554119	10641	Economy	3000.00
0005434552609	10641	Economy	3300.00
0005434552652	10641	Economy	3300.00
0005433181562	10641	Economy	3300.00
0005434552641	10641	Economy	3300.00
0005434552621	10641	Economy	3000.00
0005433181530	10641	Economy	3000.00
0005434554116	10641	Economy	3000.00
0005433181510	10641	Economy	3000.00
0005434552607	10641	Economy	3000.00
0005433181554	10641	Economy	3000.00
0005434558492	10641	Economy	3000.00
0005433181563	10641	Economy	3000.00
0005434552656	10641	Economy	3000.00
0005434552627	10641	Economy	3000.00
0005433181643	10641	Economy	3000.00
0005434558493	10641	Economy	3000.00
0005434552651	10641	Economy	3000.00
0005434554120	10641	Economy	3000.00
0005434552657	10641	Economy	3000.00
0005434552618	10641	Economy	3000.00
0005434552611	10641	Economy	3000.00
0005433181426	10641	Economy	3000.00
0005434552630	10641	Economy	3000.00
0005434552645	10641	Economy	3000.00
0005433181509	10641	Economy	3000.00
0005434552654	10641	Economy	3000.00
0005434552628	10641	Economy	3000.00
0005434552633	10641	Economy	3000.00
0005434552622	10641	Economy	3000.00
0005434552614	10641	Economy	3000.00
0005434552613	10641	Economy	3000.00
0005434552658	10641	Economy	3000.00
0005434552608	10641	Economy	3000.00
0005433181512	10641	Economy	3000.00
0005434552635	10641	Economy	3000.00
0005434552612	10641	Economy	3000.00
0005434558495	10641	Economy	3000.00
0005433181590	10641	Economy	3000.00
0005434554117	10641	Economy	3000.00
0005434552655	10641	Economy	3000.00
0005434554118	10641	Economy	3000.00
0005434552659	10641	Economy	3000.00
0005433181400	10641	Economy	3000.00
0005434552626	10641	Economy	3000.00
0005433181644	10641	Economy	3000.00
0005434552650	10641	Economy	3000.00
0005434552640	10641	Economy	3000.00
0005434552615	10641	Economy	3000.00
0005434552629	10641	Economy	3000.00
0005433181482	10641	Economy	3000.00
0005434552646	10641	Economy	3000.00
0005433181499	10641	Economy	3000.00
0005433181565	10641	Economy	3000.00
0005434558494	10641	Economy	3000.00
0005434552643	10641	Economy	3000.00
0005433181560	10641	Economy	3000.00
0005434552644	10641	Economy	3000.00
0005433181549	10641	Economy	3000.00
0005434558497	10641	Economy	3000.00
0005433181513	10641	Economy	3000.00
0005434552610	10641	Economy	3000.00
0005434552637	10641	Economy	3000.00
0005433181545	10641	Economy	3000.00
0005434552649	10641	Economy	3000.00
0005433181514	10641	Economy	3000.00
0005434552624	10641	Economy	3000.00
0005433181476	10641	Economy	3000.00
0005434552642	10641	Economy	3000.00
0005434552617	10641	Economy	3000.00
0005434552638	10641	Economy	3000.00
0005434552634	10641	Economy	3000.00
0005434552648	10641	Economy	3000.00
0005433181491	10641	Economy	3000.00
0005434757705	27670	Business	9100.00
0005433181758	27670	Business	9100.00
0005435315066	27670	Business	9100.00
0005435315071	27670	Economy	3000.00
0005433181765	27670	Economy	3000.00
0005433181772	27670	Economy	3000.00
0005435315067	27670	Economy	3000.00
0005433181773	27670	Economy	3000.00
0005435315077	27670	Economy	3000.00
0005435315064	27670	Economy	3300.00
0005435315073	27670	Economy	3300.00
0005435315068	27670	Economy	3300.00
0005433181761	27670	Economy	3000.00
0005433181763	27670	Economy	3000.00
0005435315070	27670	Economy	3000.00
0005435315074	27670	Economy	3000.00
0005435315075	27670	Economy	3000.00
0005435315069	27670	Economy	3000.00
0005435315065	27670	Economy	3000.00
0005433181760	27670	Economy	3000.00
0005435315072	27670	Economy	3000.00
0005433181776	27670	Economy	3000.00
0005433181759	27670	Economy	3000.00
0005435315079	27670	Economy	3000.00
0005435315063	27670	Economy	3000.00
0005433181762	27670	Economy	3000.00
0005435315062	27670	Economy	3000.00
0005435315061	27670	Economy	3000.00
0005433181766	27670	Economy	3000.00
0005433181764	27670	Economy	3000.00
0005433181771	27670	Economy	3000.00
0005433181769	27670	Economy	3000.00
0005433181774	27670	Economy	3000.00
0005433181770	27670	Economy	3000.00
0005433181768	27670	Economy	3000.00
0005435315076	27670	Economy	3000.00
0005435315078	27670	Economy	3000.00
0005433181767	27670	Economy	3000.00
0005433181775	27670	Economy	3000.00
0005433181777	27670	Economy	3000.00
0005434552180	27671	Business	9100.00
0005434552167	27671	Business	9100.00
0005434552106	27671	Business	9100.00
0005434551856	27671	Business	9100.00
0005434552344	27671	Business	9100.00
0005434552215	27671	Business	9100.00
0005434552268	27671	Economy	3000.00
0005434554101	27671	Economy	3000.00
0005434558424	27671	Economy	3000.00
0005434552290	27671	Economy	3000.00
0005434552122	27671	Economy	3000.00
0005434558421	27671	Economy	3300.00
0005434552457	27671	Economy	3300.00
0005434552225	27671	Economy	3300.00
0005434552121	27671	Economy	3300.00
0005434552371	27671	Economy	3300.00
0005434552265	27671	Economy	3000.00
0005434552153	27671	Economy	3000.00
0005434552179	27671	Economy	3000.00
0005434552126	27671	Economy	3000.00
0005434552095	27671	Economy	3000.00
0005434552133	27671	Economy	3000.00
0005434554104	27671	Economy	3000.00
0005434558422	27671	Economy	3000.00
0005434552123	27671	Economy	3000.00
0005434552267	27671	Economy	3000.00
0005434554103	27671	Economy	3000.00
0005434552372	27671	Economy	3000.00
0005434551935	27671	Economy	3000.00
0005434552181	27671	Economy	3000.00
0005434552067	27671	Economy	3000.00
0005434558392	27671	Economy	3000.00
0005434552184	27671	Economy	3000.00
0005434552319	27671	Economy	3000.00
0005434552166	27671	Economy	3000.00
0005434552094	27671	Economy	3000.00
0005434552277	27671	Economy	3000.00
0005434552345	27671	Economy	3000.00
0005434558391	27671	Economy	3000.00
0005434552439	27671	Economy	3000.00
0005434552238	27671	Economy	3000.00
0005434552320	27671	Economy	3000.00
0005434552165	27671	Economy	3000.00
0005434552276	27671	Economy	3000.00
0005434552304	27671	Economy	3000.00
0005434552294	27671	Economy	3000.00
0005434552376	27671	Economy	3000.00
0005434552390	27671	Economy	3000.00
0005434552266	27671	Economy	3000.00
0005434552158	27671	Economy	3000.00
0005434558412	27671	Economy	3000.00
0005434551934	27671	Economy	3000.00
0005434552071	27671	Economy	3000.00
0005434552316	27671	Economy	3000.00
0005434552221	27671	Economy	3000.00
0005434552156	27671	Economy	3000.00
0005434554102	27671	Economy	3000.00
0005434552105	27671	Economy	3000.00
0005434552395	27671	Economy	3000.00
0005434552208	27671	Economy	3000.00
0005434552157	27671	Economy	3000.00
0005434552375	27671	Economy	3000.00
0005434552317	27671	Economy	3000.00
0005434552020	27671	Economy	3000.00
0005434552318	27671	Economy	3000.00
0005434558425	27671	Economy	3000.00
0005434552458	27671	Economy	3000.00
0005434552374	27671	Economy	3000.00
0005433459331	6157	Economy	11700.00
0005435254518	6157	Economy	11700.00
0005433459332	6157	Economy	11700.00
0005433459333	6157	Economy	11700.00
0005433459304	19296	Economy	11700.00
0005435254536	19296	Economy	11700.00
0005433459295	19296	Economy	11700.00
0005433459286	19296	Economy	11700.00
0005433459285	19296	Economy	11700.00
0005433459287	19296	Economy	11700.00
0005433459296	19296	Economy	11700.00
0005435683228	6742	Business	51100.00
0005435654509	6742	Business	51100.00
0005435438356	6742	Business	51100.00
0005435683225	6742	Business	51100.00
0005435654510	6742	Business	51100.00
0005432533339	6742	Business	51100.00
0005435683221	6742	Business	51100.00
0005435683213	6742	Business	51100.00
0005435683232	6742	Business	51100.00
0005435217742	6742	Business	51100.00
0005432136302	6742	Business	51100.00
0005435683220	6742	Business	51100.00
0005435683204	6742	Economy	17000.00
0005435683226	6742	Economy	17000.00
0005435220351	6742	Economy	17000.00
0005435438375	6742	Economy	17000.00
0005435654506	6742	Economy	17000.00
0005435438315	6742	Economy	17000.00
0005435438367	6742	Economy	17000.00
0005435683200	6742	Economy	17000.00
0005435719599	6742	Economy	17000.00
0005435217754	6742	Economy	18700.00
0005435438416	6742	Economy	18700.00
0005432136300	6742	Economy	18700.00
0005435438366	6742	Economy	18700.00
0005435220354	6742	Economy	18700.00
0005435438387	6742	Economy	17000.00
0005435683219	6742	Economy	17000.00
0005435662004	6742	Economy	17000.00
0005435438377	6742	Economy	17000.00
0005432533341	6742	Economy	17000.00
0005435438415	6742	Economy	17000.00
0005435683208	6742	Economy	17000.00
0005435654505	6742	Economy	17000.00
0005435438289	6742	Economy	17000.00
0005435683222	6742	Economy	17000.00
0005435683215	6742	Economy	17000.00
0005435683209	6742	Economy	17000.00
0005435719598	6742	Economy	17000.00
0005435683238	6742	Economy	17000.00
0005435720163	6742	Economy	17000.00
0005435683214	6742	Economy	17000.00
0005435683210	6742	Economy	17000.00
0005435683236	6742	Economy	17000.00
0005435683229	6742	Economy	17000.00
0005435438399	6742	Economy	17000.00
0005435683207	6742	Economy	17000.00
0005435217758	6742	Economy	17000.00
0005435662003	6742	Economy	17000.00
0005434828750	6742	Economy	17000.00
0005435719597	6742	Economy	17000.00
0005435683235	6742	Economy	17000.00
0005435438378	6742	Economy	17000.00
0005435683199	6742	Economy	17000.00
0005434828749	6742	Economy	17000.00
0005435438388	6742	Economy	17000.00
0005435683201	6742	Economy	17000.00
0005435438322	6742	Economy	17000.00
0005435683202	6742	Economy	17000.00
0005435654511	6742	Economy	17000.00
0005435220350	6742	Economy	17000.00
0005435654504	6742	Economy	17000.00
0005435683206	6742	Economy	17000.00
0005435654507	6742	Economy	17000.00
0005435683227	6742	Economy	17000.00
0005435683211	6742	Economy	17000.00
0005435683216	6742	Economy	17000.00
0005435683231	6742	Economy	17000.00
0005435438365	6742	Economy	17000.00
0005435683223	6742	Economy	17000.00
0005432533342	6742	Economy	17000.00
0005435654508	6742	Economy	17000.00
0005432136301	6742	Economy	17000.00
0005432136299	6742	Economy	17000.00
0005435631045	6742	Economy	17000.00
0005435683234	6742	Economy	17000.00
0005435438386	6742	Economy	17000.00
0005435683230	6742	Economy	17000.00
0005435662005	6742	Economy	17000.00
0005435683217	6742	Economy	17000.00
0005435438321	6742	Economy	17000.00
0005435683233	6742	Economy	17000.00
0005435683205	6742	Economy	17000.00
0005435683218	6742	Economy	17000.00
0005435683212	6742	Economy	17000.00
0005435683237	6742	Economy	17000.00
0005435683203	6742	Economy	17000.00
0005435438368	6742	Economy	17000.00
0005434828752	6742	Economy	17000.00
0005435438454	6742	Economy	17000.00
0005435438316	6742	Economy	17000.00
0005435683224	6742	Economy	17000.00
0005435682893	24582	Business	51100.00
0005435682940	24582	Business	51100.00
0005435683006	24582	Business	51100.00
0005435219256	24582	Business	51100.00
0005435682964	24582	Business	51100.00
0005435682723	24582	Business	51100.00
0005435682636	24582	Business	51100.00
0005435438531	24582	Business	51100.00
0005435438529	24582	Business	51100.00
0005435682768	24582	Business	51100.00
0005435682875	24582	Economy	17000.00
0005435682909	24582	Economy	17000.00
0005435682958	24582	Economy	17000.00
0005435683005	24582	Economy	17000.00
0005435682880	24582	Economy	17000.00
0005435438539	24582	Economy	17000.00
0005435438526	24582	Economy	17000.00
0005435438533	24582	Economy	17000.00
0005435220373	24582	Economy	17000.00
0005435682805	24582	Economy	18700.00
0005435682883	24582	Economy	18700.00
0005435682846	24582	Economy	18700.00
0005435219253	24582	Economy	18700.00
0005435438536	24582	Economy	17000.00
0005435682885	24582	Economy	17000.00
0005435219251	24582	Economy	17000.00
0005435682971	24582	Economy	17000.00
0005435682676	24582	Economy	17000.00
0005435682879	24582	Economy	17000.00
0005435682892	24582	Economy	17000.00
0005435220513	24582	Economy	17000.00
0005435631014	24582	Economy	17000.00
0005435220515	24582	Economy	17000.00
0005432305812	24582	Economy	17000.00
0005435219254	24582	Economy	17000.00
0005435682731	24582	Economy	17000.00
0005435220372	24582	Economy	17000.00
0005435682876	24582	Economy	17000.00
0005435682911	24582	Economy	17000.00
0005435438538	24582	Economy	17000.00
0005435682878	24582	Economy	17000.00
0005435682831	24582	Economy	17000.00
0005435219255	24582	Economy	17000.00
0005435438530	24582	Economy	17000.00
0005435682884	24582	Economy	17000.00
0005435438532	24582	Economy	17000.00
0005435220370	24582	Economy	17000.00
0005435682882	24582	Economy	17000.00
0005435682751	24582	Economy	17000.00
0005435220375	24582	Economy	17000.00
0005435438525	24582	Economy	17000.00
0005435682946	24582	Economy	17000.00
0005435682769	24582	Economy	17000.00
0005435438540	24582	Economy	17000.00
0005435682965	24582	Economy	17000.00
0005435438528	24582	Economy	17000.00
0005435682957	24582	Economy	17000.00
0005435682886	24582	Economy	17000.00
0005432305814	24582	Economy	17000.00
0005435661970	24582	Economy	17000.00
0005435220374	24582	Economy	17000.00
0005435682784	24582	Economy	17000.00
0005435682877	24582	Economy	17000.00
0005435682635	24582	Economy	17000.00
0005435682874	24582	Economy	17000.00
0005432533367	24582	Economy	17000.00
0005435438534	24582	Economy	17000.00
0005435438527	24582	Economy	17000.00
0005435682913	24582	Economy	17000.00
0005435682923	24582	Economy	17000.00
0005435682806	24582	Economy	17000.00
0005435438524	24582	Economy	17000.00
0005435682910	24582	Economy	17000.00
0005435682941	24582	Economy	17000.00
0005435438537	24582	Economy	17000.00
0005435220371	24582	Economy	17000.00
0005435220514	24582	Economy	17000.00
0005435631015	24582	Economy	17000.00
0005435219252	24582	Economy	17000.00
0005435438541	24582	Economy	17000.00
0005435220516	24582	Economy	17000.00
0005432305813	24582	Economy	17000.00
0005435438535	24582	Economy	17000.00
0005435683007	24582	Economy	17000.00
0005435682945	24582	Economy	17000.00
0005435127408	11558	Business	26400.00
0005435127424	11558	Business	26400.00
0005435127418	11558	Business	26400.00
0005435127426	11558	Business	26400.00
0005435098611	11558	Business	26400.00
0005435127419	11558	Business	26400.00
0005435127395	11558	Economy	8800.00
0005435127399	11558	Economy	8800.00
0005435127420	11558	Economy	8800.00
0005435098610	11558	Economy	8800.00
0005435127405	11558	Economy	8800.00
0005435127396	11558	Economy	8800.00
0005435127398	11558	Economy	9700.00
0005435127415	11558	Economy	8800.00
0005435098607	11558	Economy	8800.00
0005435127401	11558	Economy	8800.00
0005435127403	11558	Economy	8800.00
0005435127414	11558	Economy	8800.00
0005435558132	11558	Economy	8800.00
0005435127417	11558	Economy	8800.00
0005435098608	11558	Economy	8800.00
0005435127394	11558	Economy	8800.00
0005435127411	11558	Economy	8800.00
0005435106063	11558	Economy	8800.00
0005435127406	11558	Economy	8800.00
0005435127400	11558	Economy	8800.00
0005435558140	11558	Economy	8800.00
0005435127425	11558	Economy	8800.00
0005435127407	11558	Economy	8800.00
0005435127402	11558	Economy	8800.00
0005435558145	11558	Economy	8800.00
0005435558137	11558	Economy	8800.00
0005435127413	11558	Economy	8800.00
0005435127422	11558	Economy	8800.00
0005435127404	11558	Economy	8800.00
0005435098606	11558	Economy	8800.00
0005435098605	11558	Economy	8800.00
0005435127397	11558	Economy	8800.00
0005435127412	11558	Economy	8800.00
0005435127423	11558	Economy	8800.00
0005435098609	11558	Economy	8800.00
0005435127410	11558	Economy	8800.00
0005435127409	11558	Economy	8800.00
0005435127416	11558	Economy	8800.00
0005435127427	11558	Economy	8800.00
0005435127421	11558	Economy	8800.00
0005435127086	31895	Business	26400.00
0005435127248	31895	Business	26400.00
0005435126994	31895	Business	26400.00
0005435127301	31895	Business	26400.00
0005435127168	31895	Business	26400.00
0005435127126	31895	Economy	8800.00
0005435127230	31895	Economy	8800.00
0005435127042	31895	Economy	9700.00
0005435127087	31895	Economy	9700.00
0005435127058	31895	Economy	9700.00
0005435127236	31895	Economy	8800.00
0005435127300	31895	Economy	8800.00
0005435106055	31895	Economy	8800.00
0005435127034	31895	Economy	8800.00
0005435127065	31895	Economy	8800.00
0005435127162	31895	Economy	8800.00
0005435558156	31895	Economy	8800.00
0005435127127	31895	Economy	8800.00
0005435127163	31895	Economy	8800.00
0005435126993	31895	Economy	8800.00
0005435558157	31895	Economy	8800.00
0005435127061	31895	Economy	8800.00
0005435127056	31895	Economy	8800.00
0005435127116	31895	Economy	8800.00
0005435127035	31895	Economy	8800.00
0005435127064	31895	Economy	8800.00
0005435127196	31895	Economy	8800.00
0005435127107	31895	Economy	8800.00
0005435127258	31895	Economy	8800.00
0005435127249	31895	Economy	8800.00
0005435127143	31895	Economy	8800.00
0005435127154	31895	Economy	8800.00
0005435127232	31895	Economy	8800.00
0005435127231	31895	Economy	8800.00
0005435558155	31895	Economy	8800.00
0005435127099	31895	Economy	8800.00
0005435106046	31895	Economy	8800.00
0005435106045	31895	Economy	8800.00
0005435126992	31895	Economy	8800.00
0005435106041	31895	Economy	8800.00
0005435732537	13536	Business	36600.00
0005435732570	13536	Business	36600.00
0005435732600	13536	Business	36600.00
0005433399308	13536	Business	36600.00
0005433399322	13536	Business	36600.00
0005435732536	13536	Business	36600.00
0005435732510	13536	Business	36600.00
0005433399318	13536	Business	36600.00
0005433399337	13536	Economy	12200.00
0005435732509	13536	Economy	12200.00
0005433399326	13536	Economy	12200.00
0005433399316	13536	Economy	12200.00
0005435732571	13536	Economy	13400.00
0005433399335	13536	Economy	13400.00
0005435732565	13536	Economy	13400.00
0005433399333	13536	Economy	13400.00
0005433399339	13536	Economy	12200.00
0005435732580	13536	Economy	12200.00
0005435732566	13536	Economy	12200.00
0005433399315	13536	Economy	12200.00
0005433399338	13536	Economy	12200.00
0005433399334	13536	Economy	12200.00
0005433399330	13536	Economy	12200.00
0005433399323	13536	Economy	12200.00
0005433399319	13536	Economy	12200.00
0005433399320	13536	Economy	12200.00
0005433399310	13536	Economy	12200.00
0005433399317	13536	Economy	12200.00
0005433399311	13536	Economy	12200.00
0005435732554	13536	Economy	12200.00
0005433399336	13536	Economy	12200.00
0005433399321	13536	Economy	12200.00
0005433399324	13536	Economy	12200.00
0005433399314	13536	Economy	12200.00
0005433399313	13536	Economy	12200.00
0005433399327	13536	Economy	12200.00
0005433399328	13536	Economy	12200.00
0005435732559	13536	Economy	12200.00
0005435732558	13536	Economy	12200.00
0005435732553	13536	Economy	12200.00
0005433399309	13536	Economy	12200.00
0005433399331	13536	Economy	12200.00
0005433399325	13536	Economy	12200.00
0005433399332	13536	Economy	12200.00
0005435732581	13536	Economy	12200.00
0005435732560	13536	Economy	12200.00
0005433399312	13536	Economy	12200.00
0005435732572	13536	Economy	12200.00
0005433399329	13536	Economy	12200.00
0005433398867	19373	Business	36600.00
0005435732666	19373	Business	36600.00
0005435732656	19373	Business	36600.00
0005433398893	19373	Business	36600.00
0005435732659	19373	Business	36600.00
0005433398697	19373	Business	36600.00
0005433398835	19373	Business	36600.00
0005433399117	19373	Business	36600.00
0005433399039	19373	Business	36600.00
0005435725755	19373	Economy	12200.00
0005432297346	19373	Economy	12200.00
0005433398983	19373	Economy	12200.00
0005433398894	19373	Economy	12200.00
0005433398753	19373	Economy	12200.00
0005433398888	19373	Economy	12200.00
0005433398876	19373	Economy	12200.00
0005433399033	19373	Economy	13400.00
0005435732658	19373	Economy	13400.00
0005435732652	19373	Economy	13400.00
0005433398912	19373	Economy	13400.00
0005433398925	19373	Economy	12200.00
0005435732661	19373	Economy	12200.00
0005433398967	19373	Economy	12200.00
0005435725756	19373	Economy	12200.00
0005433398939	19373	Economy	12200.00
0005433398952	19373	Economy	12200.00
0005435725754	19373	Economy	12200.00
0005433399013	19373	Economy	12200.00
0005435732662	19373	Economy	12200.00
0005433399032	19373	Economy	12200.00
0005433398834	19373	Economy	12200.00
0005435732655	19373	Economy	12200.00
0005435725757	19373	Economy	12200.00
0005432297348	19373	Economy	12200.00
0005435732669	19373	Economy	12200.00
0005433399129	19373	Economy	12200.00
0005435732654	19373	Economy	12200.00
0005433398832	19373	Economy	12200.00
0005435732660	19373	Economy	12200.00
0005433398911	19373	Economy	12200.00
0005435732664	19373	Economy	12200.00
0005435725753	19373	Economy	12200.00
0005433398945	19373	Economy	12200.00
0005433398875	19373	Economy	12200.00
0005433398760	19373	Economy	12200.00
0005433398827	19373	Economy	12200.00
0005433398705	19373	Economy	12200.00
0005433398946	19373	Economy	12200.00
0005435732663	19373	Economy	12200.00
0005433398953	19373	Economy	12200.00
0005435732667	19373	Economy	12200.00
0005433398949	19373	Economy	12200.00
0005433398817	19373	Economy	12200.00
0005433398846	19373	Economy	12200.00
0005433398751	19373	Economy	12200.00
0005433398754	19373	Economy	12200.00
0005433398805	19373	Economy	12200.00
0005435732653	19373	Economy	12200.00
0005435732668	19373	Economy	12200.00
0005433398845	19373	Economy	12200.00
0005433398850	19373	Economy	12200.00
0005435732651	19373	Economy	12200.00
0005433398838	19373	Economy	12200.00
0005433398947	19373	Economy	12200.00
0005432297347	19373	Economy	12200.00
0005435732665	19373	Economy	12200.00
0005433398696	19373	Economy	12200.00
0005433398818	19373	Economy	12200.00
0005433398777	19373	Economy	12200.00
0005435725752	19373	Economy	12200.00
0005433398889	19373	Economy	12200.00
0005435732657	19373	Economy	12200.00
0005433399130	19373	Economy	12200.00
0005433398662	19373	Economy	12200.00
0005435069941	13130	Business	11300.00
0005435069861	13130	Business	11300.00
0005435069785	13130	Business	11300.00
0005435069859	13130	Business	11300.00
0005435069918	13130	Business	11300.00
0005435925658	13130	Business	11300.00
0005435070063	13130	Business	11300.00
0005435069982	13130	Economy	3800.00
0005435925661	13130	Economy	3800.00
0005435069803	13130	Economy	3800.00
0005435070061	13130	Economy	3800.00
0005435069987	13130	Economy	3800.00
0005435069984	13130	Economy	4100.00
0005435069945	13130	Economy	4100.00
0005435069774	13130	Economy	4100.00
0005435069882	13130	Economy	4100.00
0005435070139	13130	Economy	3800.00
0005435925664	13130	Economy	3800.00
0005435925663	13130	Economy	3800.00
0005435069781	13130	Economy	3800.00
0005435925666	13130	Economy	3800.00
0005435925669	13130	Economy	3800.00
0005435925667	13130	Economy	3800.00
0005435070161	13130	Economy	3800.00
0005435069965	13130	Economy	3800.00
0005435069944	13130	Economy	3800.00
0005435070023	13130	Economy	3800.00
0005435069933	13130	Economy	3800.00
0005435069858	13130	Economy	3800.00
0005435070037	13130	Economy	3800.00
0005435069910	13130	Economy	3800.00
0005435925662	13130	Economy	3800.00
0005435069734	13130	Economy	3800.00
0005435069979	13130	Economy	3800.00
0005435925668	13130	Economy	3800.00
0005435070149	13130	Economy	3800.00
0005435925659	13130	Economy	3800.00
0005435069622	13130	Economy	3800.00
0005435069750	13130	Economy	3800.00
0005435069917	13130	Economy	3800.00
0005435069932	13130	Economy	3800.00
0005435069860	13130	Economy	3800.00
0005435069911	13130	Economy	3800.00
0005435069966	13130	Economy	3800.00
0005435069809	13130	Economy	3800.00
0005435069988	13130	Economy	3800.00
0005435069923	13130	Economy	3800.00
0005435070024	13130	Economy	3800.00
0005435070158	13130	Economy	3800.00
0005435069898	13130	Economy	3800.00
0005435925660	13130	Economy	3800.00
0005435069751	13130	Economy	3800.00
0005435069773	13130	Economy	3800.00
0005435069857	13130	Economy	3800.00
0005435070219	13130	Economy	3800.00
0005435070062	13130	Economy	3800.00
0005435069978	13130	Economy	3800.00
0005435069985	13130	Economy	3800.00
0005435925665	13130	Economy	3800.00
0005435925657	13130	Economy	3800.00
0005435069960	13130	Economy	3800.00
0005435070079	13130	Economy	3800.00
0005435069804	13130	Economy	3800.00
0005435070080	13130	Economy	3800.00
0005435069870	13130	Economy	3800.00
0005435069776	13130	Economy	3800.00
0005435069873	13130	Economy	3800.00
0005435070102	13130	Economy	3800.00
0005435925544	15493	Business	11300.00
0005435070421	15493	Business	11300.00
0005435070384	15493	Business	11300.00
0005435925508	15493	Business	11300.00
0005435070392	15493	Business	11300.00
0005435070407	15493	Business	11300.00
0005435070423	15493	Business	11300.00
0005435070406	15493	Economy	3800.00
0005435070405	15493	Economy	3800.00
0005435070388	15493	Economy	3800.00
0005435070412	15493	Economy	3800.00
0005435070393	15493	Economy	3800.00
0005435925542	15493	Economy	3800.00
0005435070400	15493	Economy	3800.00
0005435070390	15493	Economy	4100.00
0005435070414	15493	Economy	4100.00
0005435070401	15493	Economy	4100.00
0005435070404	15493	Economy	4100.00
0005435070416	15493	Economy	4100.00
0005435070397	15493	Economy	3800.00
0005435070415	15493	Economy	3800.00
0005435070386	15493	Economy	3800.00
0005435070425	15493	Economy	3800.00
0005435070420	15493	Economy	3800.00
0005435070417	15493	Economy	3800.00
0005435070383	15493	Economy	3800.00
0005435925543	15493	Economy	3800.00
0005435070389	15493	Economy	3800.00
0005435070411	15493	Economy	3800.00
0005435070403	15493	Economy	3800.00
0005435925509	15493	Economy	3800.00
0005435925552	15493	Economy	3800.00
0005435070391	15493	Economy	3800.00
0005435070424	15493	Economy	3800.00
0005435070396	15493	Economy	3800.00
0005435070394	15493	Economy	3800.00
0005435070413	15493	Economy	3800.00
0005435070381	15493	Economy	3800.00
0005435070419	15493	Economy	3800.00
0005435070408	15493	Economy	3800.00
0005435925560	15493	Economy	3800.00
0005435070385	15493	Economy	3800.00
0005435070399	15493	Economy	3800.00
0005435070418	15493	Economy	3800.00
0005435070382	15493	Economy	3800.00
0005435070379	15493	Economy	3800.00
0005435070378	15493	Economy	3800.00
0005435925486	15493	Economy	3800.00
0005435070380	15493	Economy	3800.00
0005435070387	15493	Economy	3800.00
0005435070395	15493	Economy	3800.00
0005435925523	15493	Economy	3800.00
0005435070398	15493	Economy	3800.00
0005435925487	15493	Economy	3800.00
0005435070410	15493	Economy	3800.00
0005435070422	15493	Economy	3800.00
0005435925521	15493	Economy	3800.00
0005435070402	15493	Economy	3800.00
0005435925426	15493	Economy	3800.00
0005435070409	15493	Economy	3800.00
0005435808479	23198	Economy	27100.00
0005433407629	23198	Economy	27100.00
0005435808485	23198	Economy	27100.00
0005433407643	23198	Economy	24700.00
0005433407640	23198	Economy	24700.00
0005435808474	23198	Economy	24700.00
0005435808487	23198	Economy	24700.00
0005433407646	23198	Economy	24700.00
0005435808486	23198	Economy	24700.00
0005435808478	23198	Economy	24700.00
0005435808489	23198	Economy	24700.00
0005435808492	23198	Economy	24700.00
0005433407649	23198	Economy	24700.00
0005435808482	23198	Economy	24700.00
0005435808475	23198	Economy	24700.00
0005433407637	23198	Economy	24700.00
0005435808484	23198	Economy	24700.00
0005435808490	23198	Economy	24700.00
0005433407652	23198	Economy	24700.00
0005433407626	23198	Economy	24700.00
0005435808481	23198	Economy	24700.00
0005433407651	23198	Economy	24700.00
0005433407650	23198	Economy	24700.00
0005435808473	23198	Economy	24700.00
0005435808480	23198	Economy	24700.00
0005433407628	23198	Economy	24700.00
0005433407648	23198	Economy	24700.00
0005433407645	23198	Economy	24700.00
0005433407639	23198	Economy	24700.00
0005433407644	23198	Economy	24700.00
0005435808476	23198	Economy	24700.00
0005433407664	23198	Economy	24700.00
0005435808491	23198	Economy	24700.00
0005435808488	23198	Economy	24700.00
0005435808477	23198	Economy	24700.00
0005435808483	23198	Economy	24700.00
0005433407663	23198	Economy	24700.00
0005434215751	10716	Business	61300.00
0005434757172	10716	Business	61300.00
0005434215768	10716	Business	61300.00
0005434215764	10716	Business	61300.00
0005434215762	10716	Business	61300.00
0005434757077	10716	Business	61300.00
0005434215749	10716	Business	61300.00
0005434215774	10716	Business	61300.00
0005434215759	10716	Business	61300.00
0005434215754	10716	Business	61300.00
0005434215763	10716	Business	61300.00
0005434215738	10716	Economy	20400.00
0005434757146	10716	Economy	20400.00
0005434215760	10716	Economy	20400.00
0005434215756	10716	Economy	20400.00
0005434757075	10716	Economy	20400.00
0005434757153	10716	Economy	20400.00
0005434215747	10716	Economy	20400.00
0005434757009	10716	Economy	20400.00
0005434757156	10716	Economy	20400.00
0005434215742	10716	Economy	22500.00
0005434215772	10716	Economy	22500.00
0005434757138	10716	Economy	22500.00
0005434757225	10716	Economy	22500.00
0005434215757	10716	Economy	22500.00
0005434757128	10716	Economy	20400.00
0005434215743	10716	Economy	20400.00
0005434757132	10716	Economy	20400.00
0005434215753	10716	Economy	20400.00
0005434757099	10716	Economy	20400.00
0005434757152	10716	Economy	20400.00
0005434757186	10716	Economy	20400.00
0005434757145	10716	Economy	20400.00
0005434215766	10716	Economy	20400.00
0005434215746	10716	Economy	20400.00
0005434757135	10716	Economy	20400.00
0005434757167	10716	Economy	20400.00
0005434215752	10716	Economy	20400.00
0005434757163	10716	Economy	20400.00
0005434215755	10716	Economy	20400.00
0005434215750	10716	Economy	20400.00
0005434757106	10716	Economy	20400.00
0005434757133	10716	Economy	20400.00
0005434757250	10716	Economy	20400.00
0005434757112	10716	Economy	20400.00
0005434757125	10716	Economy	20400.00
0005434215758	10716	Economy	20400.00
0005434757129	10716	Economy	20400.00
0005434757131	10716	Economy	20400.00
0005434215740	10716	Economy	20400.00
0005434215773	10716	Economy	20400.00
0005434756900	10716	Economy	20400.00
0005434757005	10716	Economy	20400.00
0005434757194	10716	Economy	20400.00
0005434215765	10716	Economy	20400.00
0005434215744	10716	Economy	20400.00
0005434757224	10716	Economy	20400.00
0005434757134	10716	Economy	20400.00
0005434215767	10716	Economy	20400.00
0005434757151	10716	Economy	20400.00
0005434757158	10716	Economy	20400.00
0005434215739	10716	Economy	20400.00
0005434757155	10716	Economy	20400.00
0005434757116	10716	Economy	20400.00
0005434757076	10716	Economy	20400.00
0005434757212	10716	Economy	20400.00
0005434215745	10716	Economy	20400.00
0005434757096	10716	Economy	20400.00
0005434757086	10716	Economy	20400.00
0005434215769	10716	Economy	20400.00
0005434757168	10716	Economy	20400.00
0005434757105	10716	Economy	20400.00
0005434757095	10716	Economy	20400.00
0005434757087	10716	Economy	20400.00
0005434215748	10716	Economy	20400.00
0005434215770	10716	Economy	20400.00
0005434757004	10716	Economy	20400.00
0005434757179	10716	Economy	20400.00
0005434757181	10716	Economy	20400.00
0005434756899	10716	Economy	20400.00
0005434757123	10716	Economy	20400.00
0005434757074	10716	Economy	20400.00
0005434757159	10716	Economy	20400.00
0005434215771	10716	Economy	20400.00
0005434757203	10716	Economy	20400.00
0005434757122	10716	Economy	20400.00
0005434757211	10716	Economy	20400.00
0005434757006	10716	Economy	20400.00
0005434215761	10716	Economy	20400.00
0005434215741	10716	Economy	20400.00
0005434757499	28692	Business	61300.00
0005434215306	28692	Business	61300.00
0005434215371	28692	Business	61300.00
0005434757489	28692	Business	61300.00
0005434757506	28692	Business	61300.00
0005434757510	28692	Business	61300.00
0005434757482	28692	Business	61300.00
0005434757485	28692	Business	61300.00
0005434215440	28692	Business	61300.00
0005434757517	28692	Business	61300.00
0005434757486	28692	Business	61300.00
0005434215189	28692	Business	61300.00
0005434757477	28692	Economy	20400.00
0005434215276	28692	Economy	20400.00
0005434757474	28692	Economy	20400.00
0005434215336	28692	Economy	20400.00
0005434215377	28692	Economy	20400.00
0005434757481	28692	Economy	20400.00
0005434215091	28692	Economy	20400.00
0005434215273	28692	Economy	20400.00
0005434757480	28692	Economy	20400.00
0005434757518	28692	Economy	20400.00
0005434757490	28692	Economy	22500.00
0005434757515	28692	Economy	22500.00
0005434757487	28692	Economy	22500.00
0005434215256	28692	Economy	22500.00
0005434215282	28692	Economy	20400.00
0005434757505	28692	Economy	20400.00
0005434757520	28692	Economy	20400.00
0005434757497	28692	Economy	20400.00
0005434757488	28692	Economy	20400.00
0005434757496	28692	Economy	20400.00
0005434215187	28692	Economy	20400.00
0005434215307	28692	Economy	20400.00
0005434757494	28692	Economy	20400.00
0005434215445	28692	Economy	20400.00
0005434215469	28692	Economy	20400.00
0005434757501	28692	Economy	20400.00
0005434215238	28692	Economy	20400.00
0005434757476	28692	Economy	20400.00
0005434757491	28692	Economy	20400.00
0005434215156	28692	Economy	20400.00
0005434757519	28692	Economy	20400.00
0005434757508	28692	Economy	20400.00
0005434215092	28692	Economy	20400.00
0005434757495	28692	Economy	20400.00
0005434757492	28692	Economy	20400.00
0005434757500	28692	Economy	20400.00
0005434215188	28692	Economy	20400.00
0005434215453	28692	Economy	20400.00
0005434215501	28692	Economy	20400.00
0005434215444	28692	Economy	20400.00
0005434215128	28692	Economy	20400.00
0005434215118	28692	Economy	20400.00
0005434215167	28692	Economy	20400.00
0005434215131	28692	Economy	20400.00
0005434757493	28692	Economy	20400.00
0005434757512	28692	Economy	20400.00
0005434757503	28692	Economy	20400.00
0005434757479	28692	Economy	20400.00
0005434757475	28692	Economy	20400.00
0005434757483	28692	Economy	20400.00
0005434215148	28692	Economy	20400.00
0005434757516	28692	Economy	20400.00
0005434215086	28692	Economy	20400.00
0005434757504	28692	Economy	20400.00
0005434215257	28692	Economy	20400.00
0005434215410	28692	Economy	20400.00
0005434757511	28692	Economy	20400.00
0005434757502	28692	Economy	20400.00
0005434757513	28692	Economy	20400.00
0005434757478	28692	Economy	20400.00
0005434215319	28692	Economy	20400.00
0005434757484	28692	Economy	20400.00
0005434215274	28692	Economy	20400.00
0005434757509	28692	Economy	20400.00
0005434215228	28692	Economy	20400.00
0005434215136	28692	Economy	20400.00
0005434757507	28692	Economy	20400.00
0005434215332	28692	Economy	20400.00
0005434215366	28692	Economy	20400.00
0005434215291	28692	Economy	20400.00
0005434757514	28692	Economy	20400.00
0005434215213	28692	Economy	20400.00
0005434215299	28692	Economy	20400.00
0005434215457	28692	Economy	20400.00
0005434215157	28692	Economy	20400.00
0005434215308	28692	Economy	20400.00
0005434215281	28692	Economy	20400.00
0005434757498	28692	Economy	20400.00
0005435041508	5451	Business	29500.00
0005432125645	5451	Business	29500.00
0005435041467	5451	Business	29500.00
0005435041473	5451	Business	29500.00
0005435007632	5451	Business	29500.00
0005434229746	5451	Business	29500.00
0005435042925	5451	Business	29500.00
0005434229761	5451	Business	29500.00
0005435041499	5451	Business	29500.00
0005435041468	5451	Business	29500.00
0005435041466	5451	Business	29500.00
0005435041504	5451	Business	29500.00
0005434229758	5451	Economy	9800.00
0005435007634	5451	Economy	9800.00
0005435007652	5451	Economy	9800.00
0005435041502	5451	Economy	9800.00
0005435041518	5451	Economy	9800.00
0005435041464	5451	Economy	9800.00
0005435041475	5451	Economy	9800.00
0005435041521	5451	Economy	9800.00
0005434229801	5451	Economy	9800.00
0005434229736	5451	Economy	9800.00
0005434229842	5451	Economy	9800.00
0005432125647	5451	Economy	9800.00
0005435041483	5451	Economy	9800.00
0005435041517	5451	Economy	9800.00
0005434229704	5451	Economy	9800.00
0005435041516	5451	Economy	9800.00
0005435041512	5451	Economy	9800.00
0005435041482	5451	Economy	9800.00
0005435041501	5451	Economy	9800.00
0005434229757	5451	Economy	9800.00
0005435041492	5451	Economy	9800.00
0005434229802	5451	Economy	9800.00
0005435041513	5451	Economy	9800.00
0005435007640	5451	Economy	9800.00
0005435041506	5451	Economy	9800.00
0005434229733	5451	Economy	9800.00
0005435041469	5451	Economy	9800.00
0005435007639	5451	Economy	9800.00
0005435042927	5451	Economy	9800.00
0005434229709	5451	Economy	9800.00
0005435041470	5451	Economy	9800.00
0005434229830	5451	Economy	9800.00
0005434229763	5451	Economy	9800.00
0005435007635	5451	Economy	9800.00
0005434229747	5451	Economy	9800.00
0005435041486	5451	Economy	9800.00
0005435042926	5451	Economy	9800.00
0005435041472	5451	Economy	9800.00
0005435041471	5451	Economy	9800.00
0005434229803	5451	Economy	10800.00
0005435041481	5451	Economy	10800.00
0005435007651	5451	Economy	10800.00
0005435041490	5451	Economy	10800.00
0005435041520	5451	Economy	10800.00
0005434229791	5451	Economy	10800.00
0005435041487	5451	Economy	9800.00
0005435041480	5451	Economy	9800.00
0005434229752	5451	Economy	9800.00
0005435041462	5451	Economy	9800.00
0005435041463	5451	Economy	9800.00
0005435041478	5451	Economy	9800.00
0005435007642	5451	Economy	9800.00
0005435041503	5451	Economy	9800.00
0005434229790	5451	Economy	9800.00
0005435041484	5451	Economy	9800.00
0005435041488	5451	Economy	9800.00
0005435007641	5451	Economy	9800.00
0005435041489	5451	Economy	9800.00
0005435041460	5451	Economy	9800.00
0005435041476	5451	Economy	9800.00
0005434229765	5451	Economy	9800.00
0005435007653	5451	Economy	9800.00
0005435041498	5451	Economy	9800.00
0005435041461	5451	Economy	9800.00
0005435041511	5451	Economy	9800.00
0005435007638	5451	Economy	9800.00
0005435041495	5451	Economy	9800.00
0005435007637	5451	Economy	9800.00
0005435007633	5451	Economy	9800.00
0005435041500	5451	Economy	9800.00
0005432125646	5451	Economy	9800.00
0005435007655	5451	Economy	9800.00
0005435007645	5451	Economy	9800.00
0005434229701	5451	Economy	9800.00
0005435041505	5451	Economy	9800.00
0005435007647	5451	Economy	9800.00
0005435041510	5451	Economy	9800.00
0005435041509	5451	Economy	9800.00
0005434229867	5451	Economy	9800.00
0005435007644	5451	Economy	9800.00
0005434229710	5451	Economy	9800.00
0005435041493	5451	Economy	9800.00
0005435007646	5451	Economy	9800.00
0005435041485	5451	Economy	9800.00
0005435007648	5451	Economy	9800.00
0005435041458	5451	Economy	9800.00
0005435041515	5451	Economy	9800.00
0005435041519	5451	Economy	9800.00
0005435041494	5451	Economy	9800.00
0005435041491	5451	Economy	9800.00
0005435007654	5451	Economy	9800.00
0005435041497	5451	Economy	9800.00
0005435043305	5451	Economy	9800.00
0005435041465	5451	Economy	9800.00
0005435007643	5451	Economy	9800.00
0005434229703	5451	Economy	9800.00
0005435042928	5451	Economy	9800.00
0005435007649	5451	Economy	9800.00
0005434229764	5451	Economy	9800.00
0005435041522	5451	Economy	9800.00
0005435041479	5451	Economy	9800.00
0005435041477	5451	Economy	9800.00
0005435007636	5451	Economy	9800.00
0005434229708	5451	Economy	9800.00
0005432125644	5451	Economy	9800.00
0005435041507	5451	Economy	9800.00
0005434229702	5451	Economy	9800.00
0005435041459	5451	Economy	9800.00
0005435007650	5451	Economy	9800.00
0005434229760	5451	Economy	9800.00
0005435041474	5451	Economy	9800.00
0005434229829	5451	Economy	9800.00
0005432125648	5451	Economy	9800.00
0005435041514	5451	Economy	9800.00
0005434229697	5451	Economy	9800.00
0005435041496	5451	Economy	9800.00
0005435007492	12997	Business	29500.00
0005435007295	12997	Business	29500.00
0005435040572	12997	Business	29500.00
0005435040546	12997	Business	29500.00
0005435040945	12997	Business	29500.00
0005434229962	12997	Business	29500.00
0005435040975	12997	Business	29500.00
0005435040857	12997	Business	29500.00
0005435042891	12997	Business	29500.00
0005435007361	12997	Business	29500.00
0005435040692	12997	Business	29500.00
0005435040795	12997	Business	29500.00
0005435041011	12997	Economy	9800.00
0005435007490	12997	Economy	9800.00
0005435040942	12997	Economy	9800.00
0005434229958	12997	Economy	9800.00
0005435007434	12997	Economy	9800.00
0005435007294	12997	Economy	9800.00
0005435007360	12997	Economy	9800.00
0005435377927	12997	Economy	9800.00
0005434229976	12997	Economy	9800.00
0005435040978	12997	Economy	9800.00
0005435007419	12997	Economy	9800.00
0005434229968	12997	Economy	9800.00
0005435007384	12997	Economy	9800.00
0005435377926	12997	Economy	9800.00
0005435007442	12997	Economy	9800.00
0005435040693	12997	Economy	9800.00
0005435041032	12997	Economy	9800.00
0005435040798	12997	Economy	9800.00
0005434229961	12997	Economy	9800.00
0005435040799	12997	Economy	9800.00
0005435042901	12997	Economy	9800.00
0005435007453	12997	Economy	9800.00
0005434229956	12997	Economy	9800.00
0005435041224	12997	Economy	9800.00
0005435040853	12997	Economy	9800.00
0005434229967	12997	Economy	9800.00
0005434229965	12997	Economy	9800.00
0005435007272	12997	Economy	9800.00
0005435040737	12997	Economy	9800.00
0005434229977	12997	Economy	9800.00
0005435007486	12997	Economy	9800.00
0005435007387	12997	Economy	9800.00
0005434229975	12997	Economy	9800.00
0005435040818	12997	Economy	9800.00
0005435040865	12997	Economy	9800.00
0005434229974	12997	Economy	9800.00
0005435007441	12997	Economy	9800.00
0005434229973	12997	Economy	9800.00
0005435040782	12997	Economy	9800.00
0005435040982	12997	Economy	9800.00
0005435040996	12997	Economy	10800.00
0005435041225	12997	Economy	10800.00
0005435040977	12997	Economy	10800.00
0005434229970	12997	Economy	10800.00
0005435040974	12997	Economy	10800.00
0005435007296	12997	Economy	10800.00
0005435040864	12997	Economy	9800.00
0005434229955	12997	Economy	9800.00
0005435040906	12997	Economy	9800.00
0005435041052	12997	Economy	9800.00
0005435040946	12997	Economy	9800.00
0005435007475	12997	Economy	9800.00
0005435040573	12997	Economy	9800.00
0005435377934	12997	Economy	9800.00
0005435007454	12997	Economy	9800.00
0005435007433	12997	Economy	9800.00
0005435040748	12997	Economy	9800.00
0005435040574	12997	Economy	9800.00
0005435377936	12997	Economy	9800.00
0005435007474	12997	Economy	9800.00
0005435040909	12997	Economy	9800.00
0005435040877	12997	Economy	9800.00
0005435007388	12997	Economy	9800.00
0005435377933	12997	Economy	9800.00
0005435041196	12997	Economy	9800.00
0005434229966	12997	Economy	9800.00
0005435041089	12997	Economy	9800.00
0005435040851	12997	Economy	9800.00
0005435041026	12997	Economy	9800.00
0005435042890	12997	Economy	9800.00
0005435040940	12997	Economy	9800.00
0005435041081	12997	Economy	9800.00
0005434229964	12997	Economy	9800.00
0005434229971	12997	Economy	9800.00
0005435040672	12997	Economy	9800.00
0005435041051	12997	Economy	9800.00
0005435007491	12997	Economy	9800.00
0005435040547	12997	Economy	9800.00
0005435040671	12997	Economy	9800.00
0005432304503	12997	Economy	9800.00
0005435377928	12997	Economy	9800.00
0005435007522	12997	Economy	9800.00
0005434229957	12997	Economy	9800.00
0005435041090	12997	Economy	9800.00
0005435007385	12997	Economy	9800.00
0005435377931	12997	Economy	9800.00
0005435040723	12997	Economy	9800.00
0005435040691	12997	Economy	9800.00
0005435040983	12997	Economy	9800.00
0005435377930	12997	Economy	9800.00
0005435040825	12997	Economy	9800.00
0005435007412	12997	Economy	9800.00
0005435007411	12997	Economy	9800.00
0005435377937	12997	Economy	9800.00
0005435040834	12997	Economy	9800.00
0005435007440	12997	Economy	9800.00
0005432304502	12997	Economy	9800.00
0005434229959	12997	Economy	9800.00
0005434229960	12997	Economy	9800.00
0005435377929	12997	Economy	9800.00
0005435040783	12997	Economy	9800.00
0005435007435	12997	Economy	9800.00
0005434229972	12997	Economy	9800.00
0005435040817	12997	Economy	9800.00
0005435040738	12997	Economy	9800.00
0005435377932	12997	Economy	9800.00
0005434229969	12997	Economy	9800.00
0005435040858	12997	Economy	9800.00
0005435377935	12997	Economy	9800.00
0005435040621	12997	Economy	9800.00
0005435040694	12997	Economy	9800.00
0005434229963	12997	Economy	9800.00
0005435041038	12997	Economy	9800.00
0005435007487	12997	Economy	9800.00
0005434427353	14867	Business	52900.00
0005434427364	14867	Business	52900.00
0005434411888	14867	Business	52900.00
0005434427359	14867	Business	52900.00
0005435902950	14867	Business	52900.00
0005434427349	14867	Business	52900.00
0005434427372	14867	Business	52900.00
0005434427365	14867	Economy	17600.00
0005435902962	14867	Economy	17600.00
0005434427371	14867	Economy	17600.00
0005434427355	14867	Economy	17600.00
0005434427350	14867	Economy	17600.00
0005434427352	14867	Economy	19400.00
0005434427358	14867	Economy	19400.00
0005432188690	14867	Economy	19400.00
0005434427368	14867	Economy	19400.00
0005435903010	14867	Economy	17600.00
0005435902956	14867	Economy	17600.00
0005434427370	14867	Economy	17600.00
0005434427357	14867	Economy	17600.00
0005434427361	14867	Economy	17600.00
0005434427346	14867	Economy	17600.00
0005434427348	14867	Economy	17600.00
0005434427367	14867	Economy	17600.00
0005434411887	14867	Economy	17600.00
0005434427354	14867	Economy	17600.00
0005435903045	14867	Economy	17600.00
0005435554259	14867	Economy	17600.00
0005435902951	14867	Economy	17600.00
0005432188691	14867	Economy	17600.00
0005435903011	14867	Economy	17600.00
0005435902964	14867	Economy	17600.00
0005434427363	14867	Economy	17600.00
0005434427362	14867	Economy	17600.00
0005434427360	14867	Economy	17600.00
0005435902947	14867	Economy	17600.00
0005432188692	14867	Economy	17600.00
0005435554275	14867	Economy	17600.00
0005434427369	14867	Economy	17600.00
0005435902963	14867	Economy	17600.00
0005434427373	14867	Economy	17600.00
0005435902955	14867	Economy	17600.00
0005434427356	14867	Economy	17600.00
0005435902982	14867	Economy	17600.00
0005434411890	14867	Economy	17600.00
0005434427347	14867	Economy	17600.00
0005434411889	14867	Economy	17600.00
0005434427366	14867	Economy	17600.00
0005434427351	14867	Economy	17600.00
0005435902999	14867	Economy	17600.00
0005434427226	20215	Business	52900.00
0005434427020	20215	Business	52900.00
0005432059559	20215	Business	52900.00
0005434411869	20215	Business	52900.00
0005434427083	20215	Business	52900.00
0005434427109	20215	Business	52900.00
0005434427087	20215	Business	52900.00
0005435903172	20215	Business	52900.00
0005435903175	20215	Business	52900.00
0005434427171	20215	Economy	17600.00
0005435554314	20215	Economy	17600.00
0005435903174	20215	Economy	17600.00
0005434427195	20215	Economy	17600.00
0005435554315	20215	Economy	17600.00
0005434426978	20215	Economy	17600.00
0005435903168	20215	Economy	17600.00
0005435903178	20215	Economy	17600.00
0005434427196	20215	Economy	19400.00
0005434427034	20215	Economy	19400.00
0005434427138	20215	Economy	17600.00
0005435903169	20215	Economy	17600.00
0005434427128	20215	Economy	17600.00
0005434411870	20215	Economy	17600.00
0005434427098	20215	Economy	17600.00
0005434427100	20215	Economy	17600.00
0005434427137	20215	Economy	17600.00
0005434427027	20215	Economy	17600.00
0005434427080	20215	Economy	17600.00
0005434427078	20215	Economy	17600.00
0005434427185	20215	Economy	17600.00
0005434427136	20215	Economy	17600.00
0005434427193	20215	Economy	17600.00
0005434427219	20215	Economy	17600.00
0005434411864	20215	Economy	17600.00
0005434427254	20215	Economy	17600.00
0005434427107	20215	Economy	17600.00
0005434427099	20215	Economy	17600.00
0005434427149	20215	Economy	17600.00
0005435903177	20215	Economy	17600.00
0005434427028	20215	Economy	17600.00
0005434411858	20215	Economy	17600.00
0005434427192	20215	Economy	17600.00
0005434427140	20215	Economy	17600.00
0005435903171	20215	Economy	17600.00
0005435903176	20215	Economy	17600.00
0005435903167	20215	Economy	17600.00
0005434427079	20215	Economy	17600.00
0005435903173	20215	Economy	17600.00
0005435903170	20215	Economy	17600.00
0005434411843	20215	Economy	17600.00
0005434427225	20215	Economy	17600.00
0005432059557	20215	Economy	17600.00
0005434427019	20215	Economy	17600.00
0005434427199	20215	Economy	17600.00
0005434427298	20215	Economy	17600.00
0005432059558	20215	Economy	17600.00
0005434427285	20215	Economy	17600.00
0005435903166	20215	Economy	17600.00
0005435903179	20215	Economy	17600.00
0005434427126	20215	Economy	17600.00
0005433726113	21659	Business	91700.00
0005433726128	21659	Economy	30600.00
0005433726125	21659	Economy	30600.00
0005433726122	21659	Economy	30600.00
0005433726123	21659	Economy	33600.00
0005433726127	21659	Economy	30600.00
0005433726124	21659	Economy	30600.00
0005433726129	21659	Economy	30600.00
0005433726112	21659	Economy	30600.00
0005433726116	21659	Economy	30600.00
0005433726126	21659	Economy	30600.00
0005433726136	21659	Economy	30600.00
0005433726130	21659	Economy	30600.00
0005433726118	21659	Economy	30600.00
0005433726138	21659	Economy	30600.00
0005433726117	21659	Economy	30600.00
0005433726135	21659	Economy	30600.00
0005435983467	26554	Business	18500.00
0005435983496	26554	Business	18500.00
0005435983459	26554	Business	18500.00
0005435983492	26554	Business	18500.00
0005433435115	26554	Business	18500.00
0005435983476	26554	Business	18500.00
0005433434961	26554	Business	18500.00
0005435983454	26554	Business	18500.00
0005433435164	26554	Business	18500.00
0005435983457	26554	Business	18500.00
0005433435154	26554	Business	18500.00
0005432300412	26554	Economy	6200.00
0005435983486	26554	Economy	6200.00
0005435983483	26554	Economy	6200.00
0005435983497	26554	Economy	6200.00
0005433435153	26554	Economy	6200.00
0005433435078	26554	Economy	6200.00
0005435983452	26554	Economy	6800.00
0005433435131	26554	Economy	6800.00
0005435983460	26554	Economy	6200.00
0005435983475	26554	Economy	6200.00
0005435983472	26554	Economy	6200.00
0005435983484	26554	Economy	6200.00
0005432300414	26554	Economy	6200.00
0005435983458	26554	Economy	6200.00
0005433435138	26554	Economy	6200.00
0005435983465	26554	Economy	6200.00
0005435983473	26554	Economy	6200.00
0005433435029	26554	Economy	6200.00
0005435983487	26554	Economy	6200.00
0005435983463	26554	Economy	6200.00
0005435983491	26554	Economy	6200.00
0005433435079	26554	Economy	6200.00
0005433435249	26554	Economy	6200.00
0005432300413	26554	Economy	6200.00
0005433435099	26554	Economy	6200.00
0005435983482	26554	Economy	6200.00
0005435983489	26554	Economy	6200.00
0005435983455	26554	Economy	6200.00
0005435983469	26554	Economy	6200.00
0005435983462	26554	Economy	6200.00
0005435983449	26554	Economy	6200.00
0005435983488	26554	Economy	6200.00
0005434273101	26554	Economy	6200.00
0005433435234	26554	Economy	6200.00
0005433435263	26554	Economy	6200.00
0005435983470	26554	Economy	6200.00
0005435983477	26554	Economy	6200.00
0005435983493	26554	Economy	6200.00
0005435983453	26554	Economy	6200.00
0005435983471	26554	Economy	6200.00
0005435983461	26554	Economy	6200.00
0005433435030	26554	Economy	6200.00
0005435983481	26554	Economy	6200.00
0005435983490	26554	Economy	6200.00
0005433435109	26554	Economy	6200.00
0005435983474	26554	Economy	6200.00
0005435983456	26554	Economy	6200.00
0005435983464	26554	Economy	6200.00
0005435983468	26554	Economy	6200.00
0005434273107	26554	Economy	6200.00
0005435983480	26554	Economy	6200.00
0005433435191	26554	Economy	6200.00
0005435983450	26554	Economy	6200.00
0005433435110	26554	Economy	6200.00
0005435983495	26554	Economy	6200.00
0005435983485	26554	Economy	6200.00
0005434273106	26554	Economy	6200.00
0005433435318	26554	Economy	6200.00
0005435983479	26554	Economy	6200.00
0005433435233	26554	Economy	6200.00
0005435983451	26554	Economy	6200.00
0005435983494	26554	Economy	6200.00
0005435983466	26554	Economy	6200.00
0005435983478	26554	Economy	6200.00
0005433435248	26554	Economy	6200.00
0005433435190	26554	Economy	6200.00
0005433435431	26690	Business	18500.00
0005435983105	26690	Business	18500.00
0005435983063	26690	Business	18500.00
0005433435409	26690	Business	18500.00
0005435982997	26690	Business	18500.00
0005435983034	26690	Business	18500.00
0005435982819	26690	Business	18500.00
0005435983181	26690	Business	18500.00
0005434269157	26690	Business	18500.00
0005433435423	26690	Business	18500.00
0005433435410	26690	Economy	6200.00
0005435983096	26690	Economy	6200.00
0005433435411	26690	Economy	6200.00
0005433435425	26690	Economy	6200.00
0005432051211	26690	Economy	6200.00
0005435983127	26690	Economy	6200.00
0005435982982	26690	Economy	6200.00
0005435983062	26690	Economy	6200.00
0005435983012	26690	Economy	6800.00
0005435983259	26690	Economy	6800.00
0005435983142	26690	Economy	6800.00
0005435983068	26690	Economy	6800.00
0005435983106	26690	Economy	6800.00
0005433435416	26690	Economy	6200.00
0005433435424	26690	Economy	6200.00
0005435983220	26690	Economy	6200.00
0005435983112	26690	Economy	6200.00
0005435983085	26690	Economy	6200.00
0005434269158	26690	Economy	6200.00
0005433435421	26690	Economy	6200.00
0005433435412	26690	Economy	6200.00
0005433435426	26690	Economy	6200.00
0005435983145	26690	Economy	6200.00
0005434270262	26690	Economy	6200.00
0005435983144	26690	Economy	6200.00
0005435983039	26690	Economy	6200.00
0005433435434	26690	Economy	6200.00
0005433435427	26690	Economy	6200.00
0005435983135	26690	Economy	6200.00
0005433435415	26690	Economy	6200.00
0005433435413	26690	Economy	6200.00
0005435982974	26690	Economy	6200.00
0005435983219	26690	Economy	6200.00
0005435983168	26690	Economy	6200.00
0005433435433	26690	Economy	6200.00
0005435983258	26690	Economy	6200.00
0005433435432	26690	Economy	6200.00
0005435983095	26690	Economy	6200.00
0005435983214	26690	Economy	6200.00
0005433435428	26690	Economy	6200.00
0005434270264	26690	Economy	6200.00
0005435983213	26690	Economy	6200.00
0005435983260	26690	Economy	6200.00
0005435983261	26690	Economy	6200.00
0005435983152	26690	Economy	6200.00
0005435983169	26690	Economy	6200.00
0005435983116	26690	Economy	6200.00
0005435983197	26690	Economy	6200.00
0005435983147	26690	Economy	6200.00
0005435983069	26690	Economy	6200.00
0005435983274	26690	Economy	6200.00
0005433435418	26690	Economy	6200.00
0005435983198	26690	Economy	6200.00
0005435983064	26690	Economy	6200.00
0005433435414	26690	Economy	6200.00
0005435983163	26690	Economy	6200.00
0005435983035	26690	Economy	6200.00
0005432051212	26690	Economy	6200.00
0005433435422	26690	Economy	6200.00
0005432051210	26690	Economy	6200.00
0005435982946	26690	Economy	6200.00
0005435982960	26690	Economy	6200.00
0005433435429	26690	Economy	6200.00
0005434270263	26690	Economy	6200.00
0005435983086	26690	Economy	6200.00
0005435982818	26690	Economy	6200.00
0005433435417	26690	Economy	6200.00
0005435983170	26690	Economy	6200.00
0005433435430	26690	Economy	6200.00
0005435982945	26690	Economy	6200.00
0005435983054	26690	Economy	6200.00
0005434271368	26690	Economy	6200.00
0005435982950	26690	Economy	6200.00
0005435983070	26690	Economy	6200.00
0005433435420	26690	Economy	6200.00
0005435983087	26690	Economy	6200.00
0005435983115	26690	Economy	6200.00
0005433435419	26690	Economy	6200.00
0005435983182	26690	Economy	6200.00
0005432216345	3142	Economy	11100.00
0005432858273	3142	Economy	11100.00
0005432858284	3142	Economy	11100.00
0005432858269	3142	Economy	11100.00
0005432584692	3142	Economy	10100.00
0005432584698	3142	Economy	10100.00
0005432216346	3142	Economy	10100.00
0005432858287	3142	Economy	10100.00
0005432858263	3142	Economy	10100.00
0005432584710	3142	Economy	10100.00
0005432858276	3142	Economy	10100.00
0005432584697	3142	Economy	10100.00
0005432584708	3142	Economy	10100.00
0005432584705	3142	Economy	10100.00
0005432584701	3142	Economy	10100.00
0005432584695	3142	Economy	10100.00
0005432858278	3142	Economy	10100.00
0005432584702	3142	Economy	10100.00
0005432584690	3142	Economy	10100.00
0005432858279	3142	Economy	10100.00
0005432584699	3142	Economy	10100.00
0005432858249	3142	Economy	10100.00
0005432858277	3142	Economy	10100.00
0005432584694	3142	Economy	10100.00
0005432216343	3142	Economy	10100.00
0005432584711	3142	Economy	10100.00
0005432858285	3142	Economy	10100.00
0005432584696	3142	Economy	10100.00
0005432584689	3142	Economy	10100.00
0005432584707	3142	Economy	10100.00
0005432858286	3142	Economy	10100.00
0005432858260	3142	Economy	10100.00
0005432858295	3142	Economy	10100.00
0005432584709	3142	Economy	10100.00
0005432858297	3142	Economy	10100.00
0005432584691	3142	Economy	10100.00
0005432584706	3142	Economy	10100.00
0005432858262	3142	Economy	10100.00
0005432858296	3142	Economy	10100.00
0005432584700	3142	Economy	10100.00
0005432216344	3142	Economy	10100.00
0005432858271	3142	Economy	10100.00
0005432858252	3142	Economy	10100.00
0005432858270	3142	Economy	10100.00
0005432584704	3142	Economy	10100.00
0005432858254	3142	Economy	10100.00
0005432584693	3142	Economy	10100.00
0005432584703	3142	Economy	10100.00
0005432858377	31498	Economy	11100.00
0005432584490	31498	Economy	11100.00
0005432584411	31498	Economy	11100.00
0005432584458	31498	Economy	10100.00
0005432858384	31498	Economy	10100.00
0005432584571	31498	Economy	10100.00
0005432584464	31498	Economy	10100.00
0005432858380	31498	Economy	10100.00
0005432584548	31498	Economy	10100.00
0005432858382	31498	Economy	10100.00
0005432584540	31498	Economy	10100.00
0005432584511	31498	Economy	10100.00
0005432584410	31498	Economy	10100.00
0005432584474	31498	Economy	10100.00
0005432858383	31498	Economy	10100.00
0005432858379	31498	Economy	10100.00
0005432584598	31498	Economy	10100.00
0005432858385	31498	Economy	10100.00
0005432584554	31498	Economy	10100.00
0005432584467	31498	Economy	10100.00
0005432584512	31498	Economy	10100.00
0005432584546	31498	Economy	10100.00
0005432584386	31498	Economy	10100.00
0005432584387	31498	Economy	10100.00
0005432858386	31498	Economy	10100.00
0005432584547	31498	Economy	10100.00
0005432858378	31498	Economy	10100.00
0005432858381	31498	Economy	10100.00
0005432584500	31498	Economy	10100.00
0005432584388	31498	Economy	10100.00
0005432584572	31498	Economy	10100.00
0005432584599	31498	Economy	10100.00
0005432584527	31498	Economy	10100.00
0005432584499	31498	Economy	10100.00
0005432858376	31498	Economy	10100.00
0005432584483	31498	Economy	10100.00
0005432584603	31498	Economy	10100.00
0005432584535	31498	Economy	10100.00
0005433255233	884	Economy	8300.00
0005434943593	884	Economy	8300.00
0005434943595	884	Economy	7500.00
0005433255194	884	Economy	7500.00
0005434943596	884	Economy	7500.00
0005433255222	884	Economy	7500.00
0005433255206	884	Economy	7500.00
0005433255220	884	Economy	7500.00
0005433255195	884	Economy	7500.00
0005433255214	884	Economy	7500.00
0005433255219	884	Economy	7500.00
0005434943594	884	Economy	7500.00
0005433255207	884	Economy	7500.00
0005433255261	16204	Economy	7500.00
0005433255260	16204	Economy	7500.00
0005434943550	16204	Economy	7500.00
0005434943526	16204	Economy	7500.00
0005433255262	16204	Economy	7500.00
0005434943538	16204	Economy	7500.00
0005434943539	16204	Economy	7500.00
0005433927533	14421	Economy	4400.00
0005433927532	14421	Economy	4400.00
0005435654221	21783	Business	9800.00
0005435654223	21783	Business	9800.00
0005435654242	21783	Business	9800.00
0005433368549	21783	Business	9800.00
0005433368551	21783	Business	9800.00
0005435654206	21783	Business	9800.00
0005435654248	21783	Business	9800.00
0005433368479	21783	Business	9800.00
0005435654207	21783	Business	9800.00
0005433368621	21783	Business	9800.00
0005433368359	21783	Business	9800.00
0005433368622	21783	Business	9800.00
0005433368503	21783	Economy	3300.00
0005435654244	21783	Economy	3300.00
0005435654210	21783	Economy	3300.00
0005435654214	21783	Economy	3300.00
0005433368467	21783	Economy	3300.00
0005433368518	21783	Economy	3300.00
0005433368523	21783	Economy	3300.00
0005435654209	21783	Economy	3300.00
0005433368561	21783	Economy	3300.00
0005433368521	21783	Economy	3300.00
0005433368514	21783	Economy	3600.00
0005435654246	21783	Economy	3600.00
0005433368601	21783	Economy	3600.00
0005433368519	21783	Economy	3600.00
0005435654216	21783	Economy	3600.00
0005433368569	21783	Economy	3300.00
0005435654213	21783	Economy	3300.00
0005433368690	21783	Economy	3300.00
0005433368520	21783	Economy	3300.00
0005433368515	21783	Economy	3300.00
0005435654212	21783	Economy	3300.00
0005435654240	21783	Economy	3300.00
0005435654230	21783	Economy	3300.00
0005435654215	21783	Economy	3300.00
0005435654222	21783	Economy	3300.00
0005435654245	21783	Economy	3300.00
0005433368522	21783	Economy	3300.00
0005435654225	21783	Economy	3300.00
0005433368583	21783	Economy	3300.00
0005433368543	21783	Economy	3300.00
0005433368620	21783	Economy	3300.00
0005433368411	21783	Economy	3300.00
0005435654217	21783	Economy	3300.00
0005433368552	21783	Economy	3300.00
0005435654237	21783	Economy	3300.00
0005435654235	21783	Economy	3300.00
0005435654224	21783	Economy	3300.00
0005435654227	21783	Economy	3300.00
0005433368603	21783	Economy	3300.00
0005435654241	21783	Economy	3300.00
0005435654233	21783	Economy	3300.00
0005435654218	21783	Economy	3300.00
0005435654238	21783	Economy	3300.00
0005433368480	21783	Economy	3300.00
0005435654234	21783	Economy	3300.00
0005433368450	21783	Economy	3300.00
0005433368544	21783	Economy	3300.00
0005433368683	21783	Economy	3300.00
0005433368666	21783	Economy	3300.00
0005433368717	21783	Economy	3300.00
0005433368667	21783	Economy	3300.00
0005433368466	21783	Economy	3300.00
0005433368451	21783	Economy	3300.00
0005435654211	21783	Economy	3300.00
0005435654231	21783	Economy	3300.00
0005433368604	21783	Economy	3300.00
0005435654236	21783	Economy	3300.00
0005435654243	21783	Economy	3300.00
0005435654239	21783	Economy	3300.00
0005433368439	21783	Economy	3300.00
0005435654229	21783	Economy	3300.00
0005433368596	21783	Economy	3300.00
0005435654228	21783	Economy	3300.00
0005433368563	21783	Economy	3300.00
0005435654232	21783	Economy	3300.00
0005435654249	21783	Economy	3300.00
0005433368716	21783	Economy	3300.00
0005435654219	21783	Economy	3300.00
0005433368513	21783	Economy	3300.00
0005433368641	21783	Economy	3300.00
0005433368648	21783	Economy	3300.00
0005435654247	21783	Economy	3300.00
0005433368684	21783	Economy	3300.00
0005433368358	21783	Economy	3300.00
0005435654220	21783	Economy	3300.00
0005433368628	21783	Economy	3300.00
0005433368360	21783	Economy	3300.00
0005433368577	21783	Economy	3300.00
0005433368668	21783	Economy	3300.00
0005433368407	21783	Economy	3300.00
0005435654208	21783	Economy	3300.00
0005433368629	21783	Economy	3300.00
0005433368647	21783	Economy	3300.00
0005435654226	21783	Economy	3300.00
0005433785979	9363	Business	186200.00
0005434171330	9363	Business	186200.00
0005433806314	9363	Business	186200.00
0005432666443	9363	Business	186200.00
0005433785920	9363	Business	186200.00
0005433785967	9363	Business	186200.00
0005433806289	9363	Business	186200.00
0005432665328	9363	Business	186200.00
0005433806303	9363	Business	186200.00
0005433785955	9363	Business	186200.00
0005433785953	9363	Business	186200.00
0005433785959	9363	Business	186200.00
0005433806299	9363	Business	186200.00
0005433785949	9363	Business	186200.00
0005433763595	9363	Business	186200.00
0005433785970	9363	Business	186200.00
0005434171365	9363	Business	186200.00
0005433785973	9363	Business	186200.00
0005434171285	9363	Business	186200.00
0005435269884	9363	Business	186200.00
0005433785938	9363	Business	186200.00
0005433785980	9363	Economy	68300.00
0005433806321	9363	Economy	68300.00
0005433806297	9363	Economy	62100.00
0005433785918	9363	Economy	62100.00
0005434171261	9363	Economy	62100.00
0005433806304	9363	Economy	62100.00
0005433806288	9363	Economy	62100.00
0005433806292	9363	Economy	62100.00
0005433806310	9363	Economy	62100.00
0005433806307	9363	Economy	62100.00
0005433785940	9363	Economy	62100.00
0005433763590	9363	Economy	62100.00
0005434171262	9363	Economy	62100.00
0005434171266	9363	Economy	62100.00
0005434171329	9363	Economy	62100.00
0005433785963	9363	Economy	62100.00
0005433785961	9363	Economy	62100.00
0005433806311	9363	Economy	62100.00
0005433806295	9363	Economy	62100.00
0005433806291	9363	Economy	62100.00
0005433785927	9363	Economy	62100.00
0005433785956	9363	Economy	62100.00
0005434273102	9363	Economy	62100.00
0005433785932	9363	Economy	62100.00
0005434270249	9363	Economy	62100.00
0005433785962	9363	Economy	62100.00
0005434151764	9363	Economy	62100.00
0005433806296	9363	Economy	62100.00
0005433785943	9363	Economy	62100.00
0005433785966	9363	Economy	62100.00
0005433785969	9363	Economy	62100.00
0005433806319	9363	Economy	62100.00
0005433806302	9363	Economy	62100.00
0005433785978	9363	Economy	62100.00
0005433785937	9363	Economy	62100.00
0005434151754	9363	Economy	62100.00
0005433806305	9363	Economy	62100.00
0005434151767	9363	Economy	62100.00
0005433785917	9363	Economy	62100.00
0005433785939	9363	Economy	62100.00
0005433806316	9363	Economy	62100.00
0005434171321	9363	Economy	62100.00
0005434171295	9363	Economy	62100.00
0005433806294	9363	Economy	62100.00
0005434151765	9363	Economy	62100.00
0005432665330	9363	Economy	62100.00
0005433785936	9363	Economy	62100.00
0005434171366	9363	Economy	62100.00
0005433785945	9363	Economy	62100.00
0005434151763	9363	Economy	62100.00
0005432665329	9363	Economy	62100.00
0005434171367	9363	Economy	62100.00
0005434273108	9363	Economy	62100.00
0005434171354	9363	Economy	62100.00
0005433785915	9363	Economy	62100.00
0005433785977	9363	Economy	62100.00
0005435269874	9363	Economy	62100.00
0005433785971	9363	Economy	62100.00
0005433806317	9363	Economy	62100.00
0005434151766	9363	Economy	62100.00
0005435269879	9363	Economy	62100.00
0005433785930	9363	Economy	62100.00
0005433806290	9363	Economy	62100.00
0005434171368	9363	Economy	62100.00
0005433785931	9363	Economy	62100.00
0005434171296	9363	Economy	62100.00
0005433785921	9363	Economy	62100.00
0005433763591	9363	Economy	62100.00
0005433785934	9363	Economy	62100.00
0005432657532	9363	Economy	62100.00
0005433785942	9363	Economy	62100.00
0005433785952	9363	Economy	62100.00
0005433785944	9363	Economy	62100.00
0005433806293	9363	Economy	68300.00
0005433763594	9363	Economy	68300.00
0005433763589	9363	Economy	62100.00
0005434171320	9363	Economy	62100.00
0005433785965	9363	Economy	62100.00
0005433806322	9363	Economy	68300.00
0005433785929	9363	Economy	68300.00
0005433806309	9363	Economy	62100.00
0005433763585	9363	Economy	62100.00
0005432667509	9363	Economy	62100.00
0005433785958	9363	Economy	62100.00
0005433785968	9363	Economy	62100.00
0005433785954	9363	Economy	62100.00
0005433785916	9363	Economy	62100.00
0005433763587	9363	Economy	62100.00
0005433785919	9363	Economy	62100.00
0005433785946	9363	Economy	62100.00
0005433763588	9363	Economy	62100.00
0005433785923	9363	Economy	62100.00
0005433763593	9363	Economy	62100.00
0005435269873	9363	Economy	62100.00
0005433785951	9363	Economy	62100.00
0005434171313	9363	Economy	62100.00
0005433785922	9363	Economy	62100.00
0005433785941	9363	Economy	62100.00
0005433806308	9363	Economy	62100.00
0005434273103	9363	Economy	62100.00
0005433785924	9363	Economy	62100.00
0005433785928	9363	Economy	62100.00
0005433785957	9363	Economy	62100.00
0005435269823	9363	Economy	62100.00
0005433806298	9363	Economy	62100.00
0005433763586	9363	Economy	62100.00
0005433785974	9363	Economy	62100.00
0005433806300	9363	Economy	62100.00
0005433806320	9363	Economy	62100.00
0005434171331	9363	Economy	62100.00
0005433806313	9363	Economy	62100.00
0005434171305	9363	Economy	62100.00
0005432666442	9363	Economy	62100.00
0005433806306	9363	Economy	62100.00
0005433763592	9363	Economy	62100.00
0005434270250	9363	Economy	62100.00
0005433785975	9363	Economy	62100.00
0005433806318	9363	Economy	62100.00
0005433785935	9363	Economy	62100.00
0005433785925	9363	Economy	62100.00
0005433785950	9363	Economy	62100.00
0005433806301	9363	Economy	62100.00
0005433785976	9363	Economy	62100.00
0005433785933	9363	Economy	62100.00
0005432667510	9363	Economy	62100.00
0005433785948	9363	Economy	62100.00
0005432657531	9363	Economy	62100.00
0005434171299	9363	Economy	62100.00
0005435269882	9363	Economy	62100.00
0005433785960	9363	Economy	62100.00
0005435269866	9363	Economy	62100.00
0005433785947	9363	Economy	62100.00
0005433806312	9363	Economy	62100.00
0005433806287	9363	Economy	62100.00
0005433785926	9363	Economy	62100.00
0005433785964	9363	Economy	62100.00
0005433806315	9363	Economy	62100.00
0005434171314	9363	Economy	62100.00
0005433806286	9363	Economy	62100.00
0005433785972	9363	Economy	62100.00
0005432657530	9363	Economy	62100.00
0005435270089	26248	Business	186200.00
0005433763470	26248	Business	186200.00
0005433806044	26248	Business	186200.00
0005433763463	26248	Business	186200.00
0005433805987	26248	Business	186200.00
0005435270102	26248	Business	186200.00
0005433785615	26248	Business	186200.00
0005433806070	26248	Business	186200.00
0005433785518	26248	Business	186200.00
0005434171434	26248	Business	186200.00
0005432657512	26248	Business	186200.00
0005433806008	26248	Business	186200.00
0005433763467	26248	Business	186200.00
0005432659740	26248	Business	186200.00
0005433785524	26248	Business	186200.00
0005433785528	26248	Business	186200.00
0005435270090	26248	Business	186200.00
0005433806032	26248	Business	186200.00
0005433785526	26248	Business	186200.00
0005434171436	26248	Business	186200.00
0005433785462	26248	Business	186200.00
0005432657497	26248	Business	186200.00
0005433785700	26248	Business	186200.00
0005433763440	26248	Business	186200.00
0005433806088	26248	Business	186200.00
0005433763519	26248	Economy	68300.00
0005433785497	26248	Economy	68300.00
0005433805982	26248	Economy	62100.00
0005433806071	26248	Economy	62100.00
0005433806119	26248	Economy	62100.00
0005433785582	26248	Economy	62100.00
0005433806010	26248	Economy	62100.00
0005434171431	26248	Economy	62100.00
0005433785436	26248	Economy	62100.00
0005434171430	26248	Economy	62100.00
0005435270088	26248	Economy	62100.00
0005433785566	26248	Economy	62100.00
0005433785525	26248	Economy	62100.00
0005432659735	26248	Economy	62100.00
0005433785421	26248	Economy	62100.00
0005432659741	26248	Economy	62100.00
0005434171433	26248	Economy	62100.00
0005432657513	26248	Economy	62100.00
0005433785451	26248	Economy	62100.00
0005433785676	26248	Economy	62100.00
0005433785567	26248	Economy	62100.00
0005434271365	26248	Economy	62100.00
0005432659743	26248	Economy	62100.00
0005433763443	26248	Economy	62100.00
0005433785450	26248	Economy	62100.00
0005433805978	26248	Economy	62100.00
0005433785748	26248	Economy	62100.00
0005433763462	26248	Economy	62100.00
0005433806120	26248	Economy	62100.00
0005433785616	26248	Economy	62100.00
0005435270100	26248	Economy	62100.00
0005435270099	26248	Economy	62100.00
0005433785701	26248	Economy	62100.00
0005433785418	26248	Economy	62100.00
0005433785472	26248	Economy	62100.00
0005433805885	26248	Economy	62100.00
0005433806076	26248	Economy	62100.00
0005435270098	26248	Economy	62100.00
0005433785496	26248	Economy	62100.00
0005434151783	26248	Economy	62100.00
0005435270107	26248	Economy	62100.00
0005434270261	26248	Economy	62100.00
0005434171432	26248	Economy	62100.00
0005433763461	26248	Economy	62100.00
0005433785583	26248	Economy	62100.00
0005435270105	26248	Economy	62100.00
0005433805984	26248	Economy	62100.00
0005433805886	26248	Economy	62100.00
0005433805983	26248	Economy	62100.00
0005433763473	26248	Economy	62100.00
0005433785413	26248	Economy	62100.00
0005433785594	26248	Economy	62100.00
0005433763503	26248	Economy	62100.00
0005433805992	26248	Economy	62100.00
0005432657495	26248	Economy	62100.00
0005433806033	26248	Economy	62100.00
0005433805993	26248	Economy	62100.00
0005433763469	26248	Economy	62100.00
0005434151780	26248	Economy	62100.00
0005433763439	26248	Economy	62100.00
0005433785653	26248	Economy	62100.00
0005433785529	26248	Economy	62100.00
0005433785568	26248	Economy	62100.00
0005433806034	26248	Economy	62100.00
0005433805890	26248	Economy	62100.00
0005433763500	26248	Economy	62100.00
0005433805872	26248	Economy	62100.00
0005433805906	26248	Economy	62100.00
0005433785414	26248	Economy	62100.00
0005434171428	26248	Economy	62100.00
0005433785726	26248	Economy	62100.00
0005432663063	26248	Economy	62100.00
0005435270094	26248	Economy	62100.00
0005433785573	26248	Economy	62100.00
0005435270101	26248	Economy	62100.00
0005433806000	26248	Economy	62100.00
0005433805959	26248	Economy	62100.00
0005433763444	26248	Economy	62100.00
0005434171429	26248	Economy	62100.00
0005432659739	26248	Economy	62100.00
0005433785527	26248	Economy	62100.00
0005435270095	26248	Economy	62100.00
0005433785677	26248	Economy	62100.00
0005433805986	26248	Economy	62100.00
0005434269156	26248	Economy	68300.00
0005435270092	26248	Economy	62100.00
0005435270097	26248	Economy	68300.00
0005435270091	26248	Economy	62100.00
0005433785579	26248	Economy	62100.00
0005433785630	26248	Economy	68300.00
0005433785671	26248	Economy	68300.00
0005433806069	26248	Economy	62100.00
0005432657514	26248	Economy	62100.00
0005435270106	26248	Economy	62100.00
0005433806118	26248	Economy	62100.00
0005433785725	26248	Economy	62100.00
0005433805958	26248	Economy	62100.00
0005433763499	26248	Economy	62100.00
0005433785749	26248	Economy	62100.00
0005434151782	26248	Economy	62100.00
0005433785420	26248	Economy	62100.00
0005433785678	26248	Economy	62100.00
0005433805905	26248	Economy	62100.00
0005435270096	26248	Economy	62100.00
0005433806061	26248	Economy	62100.00
0005433785608	26248	Economy	62100.00
0005433806007	26248	Economy	62100.00
0005433785602	26248	Economy	62100.00
0005433806117	26248	Economy	62100.00
0005433785437	26248	Economy	62100.00
0005433806068	26248	Economy	62100.00
0005433785631	26248	Economy	62100.00
0005432663062	26248	Economy	62100.00
0005433785473	26248	Economy	62100.00
0005432657494	26248	Economy	62100.00
0005434151781	26248	Economy	62100.00
0005432657496	26248	Economy	62100.00
0005433785541	26248	Economy	62100.00
0005433785647	26248	Economy	62100.00
0005433763486	26248	Economy	62100.00
0005433785511	26248	Economy	62100.00
0005433763445	26248	Economy	62100.00
0005433805963	26248	Economy	62100.00
0005433785523	26248	Economy	62100.00
0005435270104	26248	Economy	62100.00
0005434271366	26248	Economy	62100.00
0005432659744	26248	Economy	62100.00
0005434271367	26248	Economy	62100.00
0005435270103	26248	Economy	62100.00
0005433785656	26248	Economy	62100.00
0005434270260	26248	Economy	62100.00
0005433805928	26248	Economy	62100.00
0005433785652	26248	Economy	62100.00
0005434171437	26248	Economy	62100.00
0005433805981	26248	Economy	62100.00
0005433785546	26248	Economy	62100.00
0005433805985	26248	Economy	62100.00
0005433805800	26248	Economy	62100.00
0005433785578	26248	Economy	62100.00
0005433785419	26248	Economy	62100.00
0005434171435	26248	Economy	62100.00
0005433806031	26248	Economy	62100.00
0005432659738	26248	Economy	62100.00
0005433806072	26248	Economy	62100.00
0005433785495	26248	Economy	62100.00
0005433785559	26248	Economy	62100.00
0005435270093	26248	Economy	62100.00
0005433763474	26248	Economy	62100.00
0005433806060	26248	Economy	62100.00
0005433805962	26248	Economy	62100.00
0005433806075	26248	Economy	62100.00
0005435135797	4876	Economy	5300.00
0005435929694	4876	Economy	5300.00
0005435929678	4876	Economy	5300.00
0005435929693	4876	Economy	5300.00
0005435135798	4876	Economy	5300.00
0005435929679	4876	Economy	5300.00
0005435929716	33017	Economy	5300.00
0005435135773	33017	Economy	5300.00
0005435929717	33017	Economy	5300.00
0005434218036	9478	Economy	17900.00
0005434218037	9478	Economy	17900.00
0005434218053	9478	Economy	17900.00
0005434218052	9478	Economy	17900.00
0005434983421	9478	Economy	17900.00
0005434983424	9478	Economy	17900.00
0005434983422	9478	Economy	17900.00
0005434983423	9478	Economy	17900.00
0005434218035	9478	Economy	17900.00
0005434218075	27381	Economy	19700.00
0005434218078	27381	Economy	17900.00
0005434983398	27381	Economy	17900.00
0005434983384	27381	Economy	17900.00
0005434218079	27381	Economy	17900.00
0005434983394	27381	Economy	17900.00
0005434218076	27381	Economy	17900.00
0005434983382	27381	Economy	17900.00
0005434218077	27381	Economy	17900.00
0005433961777	24285	Business	36400.00
0005433986706	24285	Business	36400.00
0005433986743	24285	Business	36400.00
0005433961554	24285	Business	36400.00
0005433961789	24285	Business	36400.00
0005433986478	24285	Business	36400.00
0005433961616	24285	Business	36400.00
0005433986635	24285	Business	36400.00
0005433986476	24285	Business	36400.00
0005433961803	24285	Business	36400.00
0005433961767	24285	Business	36400.00
0005433986637	24285	Business	36400.00
0005433961760	24285	Economy	13400.00
0005433961737	24285	Economy	12100.00
0005433986781	24285	Economy	12100.00
0005433961829	24285	Economy	12100.00
0005433961523	24285	Economy	12100.00
0005433961723	24285	Economy	12100.00
0005433986665	24285	Economy	12100.00
0005433986642	24285	Economy	12100.00
0005433961431	24285	Economy	12100.00
0005433961826	24285	Economy	12100.00
0005433961838	24285	Economy	12100.00
0005433961650	24285	Economy	12100.00
0005433986740	24285	Economy	12100.00
0005433961830	24285	Economy	12100.00
0005433986629	24285	Economy	12100.00
0005433986640	24285	Economy	12100.00
0005433986697	24285	Economy	12100.00
0005433986477	24285	Economy	12100.00
0005433961787	24285	Economy	12100.00
0005433986654	24285	Economy	12100.00
0005433961603	24285	Economy	12100.00
0005433961788	24285	Economy	12100.00
0005433961807	24285	Economy	12100.00
0005433986653	24285	Economy	12100.00
0005433961808	24285	Economy	12100.00
0005433961710	24285	Economy	12100.00
0005433961806	24285	Economy	12100.00
0005433961736	24285	Economy	12100.00
0005433961663	24285	Economy	12100.00
0005433961716	24285	Economy	12100.00
0005433961738	24285	Economy	12100.00
0005433961753	24285	Economy	12100.00
0005433961524	24285	Economy	12100.00
0005433961637	24285	Economy	12100.00
0005433961636	24285	Economy	12100.00
0005433986460	24285	Economy	12100.00
0005433986658	24285	Economy	12100.00
0005433961578	24285	Economy	12100.00
0005433986657	24285	Economy	12100.00
0005433961602	24285	Economy	12100.00
0005433986739	24285	Economy	12100.00
0005433986751	24285	Economy	12100.00
0005433986721	24285	Economy	12100.00
0005433961739	24285	Economy	12100.00
0005433961704	24285	Economy	12100.00
0005433986705	24285	Economy	12100.00
0005433961728	24285	Economy	12100.00
0005433961802	24285	Economy	13400.00
0005433961673	24285	Economy	13400.00
0005433961766	24285	Economy	12100.00
0005433961786	24285	Economy	12100.00
0005433961804	24285	Economy	13400.00
0005433986741	24285	Economy	12100.00
0005433961709	24285	Economy	12100.00
0005433986599	24285	Economy	12100.00
0005433961533	24285	Economy	12100.00
0005433986752	24285	Economy	12100.00
0005433961836	24285	Economy	12100.00
0005433961705	24285	Economy	12100.00
0005433961665	24285	Economy	12100.00
0005433986664	24285	Economy	12100.00
0005433961816	24285	Economy	12100.00
0005433961844	24285	Economy	12100.00
0005433986748	24285	Economy	12100.00
0005433961754	24285	Economy	12100.00
0005433961845	24285	Economy	12100.00
0005433961534	24285	Economy	12100.00
0005433986641	24285	Economy	12100.00
0005433961535	24285	Economy	12100.00
0005433961815	24285	Economy	12100.00
0005433986557	24285	Economy	12100.00
0005433961719	24285	Economy	12100.00
0005433961735	24285	Economy	12100.00
0005433961759	24285	Economy	12100.00
0005433961556	24285	Economy	12100.00
0005433961809	24285	Economy	12100.00
0005433986645	24285	Economy	12100.00
0005433961758	24285	Economy	12100.00
0005433986696	24285	Economy	12100.00
0005433961555	24285	Economy	12100.00
0005433961681	24285	Economy	12100.00
0005433961708	24285	Economy	12100.00
0005433986722	24285	Economy	12100.00
0005433962365	25950	Business	36400.00
0005433962374	25950	Business	36400.00
0005433987140	25950	Business	36400.00
0005433987167	25950	Business	36400.00
0005433962347	25950	Business	36400.00
0005433987146	25950	Business	36400.00
0005433962361	25950	Business	36400.00
0005433987179	25950	Business	36400.00
0005433987160	25950	Business	36400.00
0005433962373	25950	Business	36400.00
0005433962338	25950	Business	36400.00
0005433962380	25950	Business	36400.00
0005433962353	25950	Business	36400.00
0005433987155	25950	Business	36400.00
0005433987183	25950	Business	36400.00
0005433962335	25950	Business	36400.00
0005433962372	25950	Economy	13400.00
0005433987142	25950	Economy	13400.00
0005433962331	25950	Economy	12100.00
0005433962349	25950	Economy	12100.00
0005433987178	25950	Economy	12100.00
0005433987159	25950	Economy	12100.00
0005433962377	25950	Economy	12100.00
0005433962348	25950	Economy	12100.00
0005433987144	25950	Economy	12100.00
0005433962344	25950	Economy	12100.00
0005433962358	25950	Economy	12100.00
0005433987176	25950	Economy	12100.00
0005433962360	25950	Economy	12100.00
0005433962345	25950	Economy	12100.00
0005433962376	25950	Economy	12100.00
0005433987148	25950	Economy	12100.00
0005433987173	25950	Economy	12100.00
0005433987162	25950	Economy	12100.00
0005433987157	25950	Economy	12100.00
0005433987177	25950	Economy	12100.00
0005433987139	25950	Economy	12100.00
0005433987149	25950	Economy	12100.00
0005433987188	25950	Economy	12100.00
0005433962352	25950	Economy	12100.00
0005433962375	25950	Economy	12100.00
0005433962334	25950	Economy	12100.00
0005433987172	25950	Economy	12100.00
0005433987184	25950	Economy	12100.00
0005433962357	25950	Economy	12100.00
0005433962346	25950	Economy	12100.00
0005433987166	25950	Economy	12100.00
0005433987163	25950	Economy	12100.00
0005433987186	25950	Economy	12100.00
0005433962363	25950	Economy	12100.00
0005433962351	25950	Economy	12100.00
0005433962354	25950	Economy	12100.00
0005433962337	25950	Economy	12100.00
0005433987164	25950	Economy	12100.00
0005433962370	25950	Economy	12100.00
0005433987136	25950	Economy	12100.00
0005433962323	25950	Economy	12100.00
0005433987134	25950	Economy	12100.00
0005433962329	25950	Economy	12100.00
0005433962359	25950	Economy	12100.00
0005433962367	25950	Economy	12100.00
0005433962364	25950	Economy	12100.00
0005433987152	25950	Economy	12100.00
0005433987150	25950	Economy	12100.00
0005433962330	25950	Economy	12100.00
0005433987154	25950	Economy	12100.00
0005433987175	25950	Economy	12100.00
0005433987171	25950	Economy	12100.00
0005433962339	25950	Economy	12100.00
0005433987182	25950	Economy	12100.00
0005433962321	25950	Economy	12100.00
0005433962381	25950	Economy	12100.00
0005433962371	25950	Economy	12100.00
0005433987158	25950	Economy	12100.00
0005433962369	25950	Economy	12100.00
0005433962379	25950	Economy	13400.00
0005433962366	25950	Economy	12100.00
0005433987187	25950	Economy	12100.00
0005433987143	25950	Economy	12100.00
0005433987185	25950	Economy	12100.00
0005433987165	25950	Economy	12100.00
0005433962324	25950	Economy	12100.00
0005433962368	25950	Economy	12100.00
0005433987168	25950	Economy	12100.00
0005433962336	25950	Economy	12100.00
0005433987170	25950	Economy	12100.00
0005433962332	25950	Economy	12100.00
0005433962342	25950	Economy	12100.00
0005433962340	25950	Economy	12100.00
0005433987151	25950	Economy	12100.00
0005433962327	25950	Economy	12100.00
0005433987135	25950	Economy	12100.00
0005433987141	25950	Economy	12100.00
0005433962343	25950	Economy	12100.00
0005433962356	25950	Economy	12100.00
0005433962333	25950	Economy	12100.00
0005433962325	25950	Economy	12100.00
0005433987137	25950	Economy	12100.00
0005433987181	25950	Economy	12100.00
0005433962328	25950	Economy	12100.00
0005433962341	25950	Economy	12100.00
0005433962350	25950	Economy	12100.00
0005433962322	25950	Economy	12100.00
0005433987153	25950	Economy	12100.00
0005433987174	25950	Economy	12100.00
0005433962326	25950	Economy	12100.00
0005433987138	25950	Economy	12100.00
0005433962378	25950	Economy	12100.00
0005433987161	25950	Economy	12100.00
0005433962362	25950	Economy	12100.00
0005433987147	25950	Economy	12100.00
0005433987145	25950	Economy	12100.00
0005433987180	25950	Economy	12100.00
0005433987169	25950	Economy	12100.00
0005433962355	25950	Economy	12100.00
0005433987156	25950	Economy	12100.00
0005434480990	968	Economy	25400.00
0005433166109	968	Economy	25400.00
0005434480984	968	Economy	25400.00
0005433166187	968	Economy	25400.00
0005434480974	968	Economy	23100.00
0005434480983	968	Economy	23100.00
0005432269568	968	Economy	23100.00
0005434480976	968	Economy	23100.00
0005434480991	968	Economy	23100.00
0005433166139	968	Economy	23100.00
0005434480992	968	Economy	23100.00
0005434480987	968	Economy	23100.00
0005433166138	968	Economy	23100.00
0005432269569	968	Economy	23100.00
0005433166163	968	Economy	23100.00
0005434480982	968	Economy	23100.00
0005433166188	968	Economy	23100.00
0005434480978	968	Economy	23100.00
0005434480973	968	Economy	23100.00
0005433166124	968	Economy	23100.00
0005434480986	968	Economy	23100.00
0005433166123	968	Economy	23100.00
0005433166110	968	Economy	23100.00
0005434480981	968	Economy	23100.00
0005433166114	968	Economy	23100.00
0005434480975	968	Economy	23100.00
0005434480989	968	Economy	23100.00
0005434480980	968	Economy	23100.00
0005434480979	968	Economy	23100.00
0005434480972	968	Economy	23100.00
0005433166111	968	Economy	23100.00
0005434480985	968	Economy	23100.00
0005433166164	968	Economy	23100.00
0005433166122	968	Economy	23100.00
0005433166189	968	Economy	23100.00
0005433166113	968	Economy	23100.00
0005433166155	968	Economy	23100.00
0005434480977	968	Economy	23100.00
0005434480988	968	Economy	23100.00
0005433166128	968	Economy	23100.00
0005434480817	16565	Economy	25400.00
0005433166249	16565	Economy	25400.00
0005433166247	16565	Economy	23100.00
0005434480835	16565	Economy	23100.00
0005434480723	16565	Economy	23100.00
0005434480763	16565	Economy	23100.00
0005434480843	16565	Economy	23100.00
0005434480844	16565	Economy	23100.00
0005434480732	16565	Economy	23100.00
0005433166252	16565	Economy	23100.00
0005434480777	16565	Economy	23100.00
0005433166246	16565	Economy	23100.00
0005433166248	16565	Economy	23100.00
0005434480739	16565	Economy	23100.00
0005434480761	16565	Economy	23100.00
0005433166250	16565	Economy	23100.00
0005434480708	16565	Economy	23100.00
0005434480759	16565	Economy	23100.00
0005434480778	16565	Economy	23100.00
0005433166251	16565	Economy	23100.00
0005434480733	16565	Economy	23100.00
0005434480709	16565	Economy	23100.00
0005434480830	16565	Economy	23100.00
0005434480767	16565	Economy	23100.00
0005434480818	16565	Economy	23100.00
0005434480831	16565	Economy	23100.00
0005433166245	16565	Economy	23100.00
0005434480754	16565	Economy	23100.00
0005433166244	16565	Economy	23100.00
0005433166253	16565	Economy	23100.00
0005434480734	16565	Economy	23100.00
0005433166243	16565	Economy	23100.00
0005434480758	16565	Economy	23100.00
0005434480762	16565	Economy	23100.00
0005434480749	16565	Economy	23100.00
0005434480811	16565	Economy	23100.00
0005435142923	10360	Economy	17000.00
0005435150388	10360	Economy	17000.00
0005435150386	10360	Economy	17000.00
0005433289967	10360	Economy	17000.00
0005435386705	10360	Economy	15400.00
0005435150387	10360	Economy	15400.00
0005435150381	10360	Economy	15400.00
0005435386706	10360	Economy	15400.00
0005435386700	10360	Economy	15400.00
0005435142917	10360	Economy	15400.00
0005435150380	10360	Economy	15400.00
0005435142922	10360	Economy	15400.00
0005435150383	10360	Economy	15400.00
0005435386653	10360	Economy	15400.00
0005435386665	10360	Economy	15400.00
0005435150385	10360	Economy	15400.00
0005433290007	10360	Economy	15400.00
0005435150378	10360	Economy	15400.00
0005433289990	10360	Economy	15400.00
0005435386663	10360	Economy	15400.00
0005435386711	10360	Economy	15400.00
0005435142918	10360	Economy	15400.00
0005435386684	10360	Economy	15400.00
0005435142920	10360	Economy	15400.00
0005435150382	10360	Economy	15400.00
0005433290008	10360	Economy	15400.00
0005435142916	10360	Economy	15400.00
0005435142921	10360	Economy	15400.00
0005435150389	10360	Economy	15400.00
0005433289962	10360	Economy	15400.00
0005435386666	10360	Economy	15400.00
0005433289978	10360	Economy	15400.00
0005433289979	10360	Economy	15400.00
0005435386701	10360	Economy	15400.00
0005435142919	10360	Economy	15400.00
0005433289994	10360	Economy	15400.00
0005435142915	10360	Economy	15400.00
0005435150379	10360	Economy	15400.00
0005435386654	10360	Economy	15400.00
0005435150384	10360	Economy	15400.00
0005435142802	21922	Economy	17000.00
0005435150330	21922	Economy	17000.00
0005435142803	21922	Economy	17000.00
0005435386740	21922	Economy	17000.00
0005433290043	21922	Economy	15400.00
0005435386738	21922	Economy	15400.00
0005435142821	21922	Economy	15400.00
0005435150225	21922	Economy	15400.00
0005433290041	21922	Economy	15400.00
0005435150229	21922	Economy	15400.00
0005435386741	21922	Economy	15400.00
0005435150226	21922	Economy	15400.00
0005435150327	21922	Economy	15400.00
0005433290046	21922	Economy	15400.00
0005435150291	21922	Economy	15400.00
0005435150335	21922	Economy	15400.00
0005435150246	21922	Economy	15400.00
0005435150334	21922	Economy	15400.00
0005435150242	21922	Economy	15400.00
0005435142797	21922	Economy	15400.00
0005435150170	21922	Economy	15400.00
0005435150285	21922	Economy	15400.00
0005433290047	21922	Economy	15400.00
0005435386739	21922	Economy	15400.00
0005435142798	21922	Economy	15400.00
0005435150228	21922	Economy	15400.00
0005435150171	21922	Economy	15400.00
0005435150215	21922	Economy	15400.00
0005433290048	21922	Economy	15400.00
0005435142822	21922	Economy	15400.00
0005433290044	21922	Economy	15400.00
0005433290045	21922	Economy	15400.00
0005435142796	21922	Economy	15400.00
0005435150243	21922	Economy	15400.00
0005435142820	21922	Economy	15400.00
0005435150216	21922	Economy	15400.00
0005435150290	21922	Economy	15400.00
0005433290042	21922	Economy	15400.00
0005435142779	21922	Economy	15400.00
0005435529617	11200	Business	57200.00
0005435319757	11200	Business	57200.00
0005434573708	11200	Business	57200.00
0005435502751	11200	Business	57200.00
0005435502728	11200	Business	57200.00
0005435529637	11200	Business	57200.00
0005435502717	11200	Business	57200.00
0005435502730	11200	Business	57200.00
0005435502660	11200	Business	57200.00
0005435319712	11200	Business	57200.00
0005435545854	11200	Business	57200.00
0005435502736	11200	Business	57200.00
0005435545862	11200	Economy	19100.00
0005434573710	11200	Economy	19100.00
0005435529697	11200	Economy	19100.00
0005434573714	11200	Economy	19100.00
0005435529643	11200	Economy	19100.00
0005435529619	11200	Economy	19100.00
0005435545856	11200	Economy	19100.00
0005435502671	11200	Economy	19100.00
0005435529564	11200	Economy	19100.00
0005435529613	11200	Economy	21000.00
0005435319713	11200	Economy	21000.00
0005435529655	11200	Economy	21000.00
0005435529529	11200	Economy	21000.00
0005435502764	11200	Economy	21000.00
0005435529630	11200	Economy	19100.00
0005435502831	11200	Economy	19100.00
0005435545863	11200	Economy	19100.00
0005435545866	11200	Economy	19100.00
0005435529678	11200	Economy	19100.00
0005435502713	11200	Economy	19100.00
0005435529612	11200	Economy	19100.00
0005434573721	11200	Economy	19100.00
0005435529709	11200	Economy	19100.00
0005435502672	11200	Economy	19100.00
0005434573718	11200	Economy	19100.00
0005435529631	11200	Economy	19100.00
0005435502714	11200	Economy	19100.00
0005435545858	11200	Economy	19100.00
0005435529537	11200	Economy	19100.00
0005435529725	11200	Economy	19100.00
0005435529658	11200	Economy	19100.00
0005434573709	11200	Economy	19100.00
0005434573720	11200	Economy	19100.00
0005435502771	11200	Economy	19100.00
0005434573711	11200	Economy	19100.00
0005434573717	11200	Economy	19100.00
0005435319733	11200	Economy	19100.00
0005435502682	11200	Economy	19100.00
0005435545857	11200	Economy	19100.00
0005435502741	11200	Economy	19100.00
0005435529610	11200	Economy	19100.00
0005435502765	11200	Economy	19100.00
0005435529618	11200	Economy	19100.00
0005435529677	11200	Economy	19100.00
0005435529528	11200	Economy	19100.00
0005435502667	11200	Economy	19100.00
0005434573716	11200	Economy	19100.00
0005435502750	11200	Economy	19100.00
0005435529590	11200	Economy	19100.00
0005435529636	11200	Economy	19100.00
0005435319732	11200	Economy	19100.00
0005435529530	11200	Economy	19100.00
0005435502716	11200	Economy	19100.00
0005435502668	11200	Economy	19100.00
0005435319722	11200	Economy	19100.00
0005435529663	11200	Economy	19100.00
0005434573713	11200	Economy	19100.00
0005434573719	11200	Economy	19100.00
0005435502729	11200	Economy	19100.00
0005435529536	11200	Economy	19100.00
0005435319721	11200	Economy	19100.00
0005435529588	11200	Economy	19100.00
0005435529589	11200	Economy	19100.00
0005435529676	11200	Economy	19100.00
0005435529600	11200	Economy	19100.00
0005435529672	11200	Economy	19100.00
0005435545855	11200	Economy	19100.00
0005435502681	11200	Economy	19100.00
0005435529644	11200	Economy	19100.00
0005435529527	11200	Economy	19100.00
0005435545849	11200	Economy	19100.00
0005435502715	11200	Economy	19100.00
0005435502625	11200	Economy	19100.00
0005435529602	11200	Economy	19100.00
0005435529703	11200	Economy	19100.00
0005435529645	11200	Economy	19100.00
0005434573712	11200	Economy	19100.00
0005435529671	11200	Economy	19100.00
0005434573715	11200	Economy	19100.00
0005435529710	11200	Economy	19100.00
0005435529586	11200	Economy	19100.00
0005435502871	20933	Business	57200.00
0005435502875	20933	Business	57200.00
0005435518375	20933	Business	57200.00
0005435502876	20933	Business	57200.00
0005434573553	20933	Business	57200.00
0005434573593	20933	Business	57200.00
0005434573542	20933	Business	57200.00
0005434573616	20933	Business	57200.00
0005435319812	20933	Business	57200.00
0005435508733	20933	Business	57200.00
0005435508745	20933	Business	57200.00
0005435518368	20933	Economy	19100.00
0005435518372	20933	Economy	19100.00
0005435518384	20933	Economy	19100.00
0005434573587	20933	Economy	19100.00
0005435508742	20933	Economy	19100.00
0005434573572	20933	Economy	19100.00
0005435518369	20933	Economy	19100.00
0005435502882	20933	Economy	19100.00
0005435518383	20933	Economy	19100.00
0005435502862	20933	Economy	19100.00
0005434573594	20933	Economy	21000.00
0005435518385	20933	Economy	21000.00
0005435502880	20933	Economy	21000.00
0005435502870	20933	Economy	21000.00
0005434573605	20933	Economy	19100.00
0005434573613	20933	Economy	19100.00
0005435319813	20933	Economy	19100.00
0005435502872	20933	Economy	19100.00
0005435502868	20933	Economy	19100.00
0005435502881	20933	Economy	19100.00
0005435518371	20933	Economy	19100.00
0005435518379	20933	Economy	19100.00
0005435502864	20933	Economy	19100.00
0005435502873	20933	Economy	19100.00
0005435508730	20933	Economy	19100.00
0005435518367	20933	Economy	19100.00
0005435518378	20933	Economy	19100.00
0005435518374	20933	Economy	19100.00
0005435319816	20933	Economy	19100.00
0005434573486	20933	Economy	19100.00
0005435502869	20933	Economy	19100.00
0005435508737	20933	Economy	19100.00
0005434573610	20933	Economy	19100.00
0005434573583	20933	Economy	19100.00
0005435508740	20933	Economy	19100.00
0005434573552	20933	Economy	19100.00
0005435319815	20933	Economy	19100.00
0005435508743	20933	Economy	19100.00
0005435319810	20933	Economy	19100.00
0005435508729	20933	Economy	19100.00
0005434573617	20933	Economy	19100.00
0005435518376	20933	Economy	19100.00
0005435508747	20933	Economy	19100.00
0005434573608	20933	Economy	19100.00
0005435508736	20933	Economy	19100.00
0005435502866	20933	Economy	19100.00
0005435518377	20933	Economy	19100.00
0005434573618	20933	Economy	19100.00
0005435502865	20933	Economy	19100.00
0005435508731	20933	Economy	19100.00
0005435508728	20933	Economy	19100.00
0005435502863	20933	Economy	19100.00
0005435518373	20933	Economy	19100.00
0005435502878	20933	Economy	19100.00
0005435502879	20933	Economy	19100.00
0005435508746	20933	Economy	19100.00
0005435319814	20933	Economy	19100.00
0005435508741	20933	Economy	19100.00
0005435518381	20933	Economy	19100.00
0005434573612	20933	Economy	19100.00
0005435518380	20933	Economy	19100.00
0005434573543	20933	Economy	19100.00
0005435319811	20933	Economy	19100.00
0005435508738	20933	Economy	19100.00
0005435502867	20933	Economy	19100.00
0005435508734	20933	Economy	19100.00
0005435508744	20933	Economy	19100.00
0005435508739	20933	Economy	19100.00
0005435518370	20933	Economy	19100.00
0005435502874	20933	Economy	19100.00
0005435508732	20933	Economy	19100.00
0005435518387	20933	Economy	19100.00
0005435508735	20933	Economy	19100.00
0005432291994	20933	Economy	19100.00
0005435502877	20933	Economy	19100.00
0005434573604	20933	Economy	19100.00
0005434573609	20933	Economy	19100.00
0005435518386	20933	Economy	19100.00
0005434573639	20933	Economy	19100.00
0005435518382	20933	Economy	19100.00
0005432693705	2991	Business	10300.00
0005432693545	2991	Business	10300.00
0005432693635	2991	Business	10300.00
0005432693599	2991	Economy	3400.00
0005432693648	2991	Economy	3400.00
0005432693654	2991	Economy	3400.00
0005432693553	2991	Economy	3800.00
0005432693556	2991	Economy	3400.00
0005432693562	2991	Economy	3400.00
0005432693649	2991	Economy	3400.00
0005432693541	2991	Economy	3400.00
0005432693578	2991	Economy	3400.00
0005432693615	2991	Economy	3400.00
0005432693489	2991	Economy	3400.00
0005432693525	2991	Economy	3400.00
0005432693598	2991	Economy	3400.00
0005432693573	2991	Economy	3400.00
0005432693641	2991	Economy	3400.00
0005432693546	2991	Economy	3400.00
0005432693661	2991	Economy	3400.00
0005432693563	2991	Economy	3400.00
0005432693540	2991	Economy	3400.00
0005432693490	2991	Economy	3400.00
0005432693679	2991	Economy	3400.00
0005432693678	2991	Economy	3400.00
0005432693647	2991	Economy	3400.00
0005432693579	2991	Economy	3400.00
0005432693524	2991	Economy	3400.00
0005432693551	2991	Economy	3400.00
0005432693552	2991	Economy	3400.00
0005432693555	2991	Economy	3400.00
0005432693539	2991	Economy	3400.00
0005432881070	2993	Business	10300.00
0005433194892	2993	Business	10300.00
0005433124282	2993	Business	10300.00
0005432881037	2993	Business	10300.00
0005433124225	2993	Business	10300.00
0005433124301	2993	Business	10300.00
0005432217852	2993	Business	10300.00
0005432707434	2993	Business	10300.00
0005432707444	2993	Economy	3400.00
0005433194893	2993	Economy	3400.00
0005433124305	2993	Economy	3400.00
0005433124290	2993	Economy	3400.00
0005433124300	2993	Economy	3400.00
0005432881080	2993	Economy	3400.00
0005432707449	2993	Economy	3400.00
0005432881042	2993	Economy	3800.00
0005433124227	2993	Economy	3800.00
0005433124205	2993	Economy	3800.00
0005433124319	2993	Economy	3800.00
0005432707450	2993	Economy	3800.00
0005432707446	2993	Economy	3400.00
0005432881036	2993	Economy	3400.00
0005432707448	2993	Economy	3400.00
0005432707441	2993	Economy	3400.00
0005432707438	2993	Economy	3400.00
0005432881035	2993	Economy	3400.00
0005432881041	2993	Economy	3400.00
0005432881081	2993	Economy	3400.00
0005432217850	2993	Economy	3400.00
0005432217851	2993	Economy	3400.00
0005432707445	2993	Economy	3400.00
0005432707432	2993	Economy	3400.00
0005432707451	2993	Economy	3400.00
0005433124291	2993	Economy	3400.00
0005433194901	2993	Economy	3400.00
0005432707443	2993	Economy	3400.00
0005433194900	2993	Economy	3400.00
0005433124384	2993	Economy	3400.00
0005433124278	2993	Economy	3400.00
0005432707439	2993	Economy	3400.00
0005433194898	2993	Economy	3400.00
0005432881056	2993	Economy	3400.00
0005432707433	2993	Economy	3400.00
0005432707440	2993	Economy	3400.00
0005432881025	2993	Economy	3400.00
0005433124217	2993	Economy	3400.00
0005433124304	2993	Economy	3400.00
0005432881046	2993	Economy	3400.00
0005433124296	2993	Economy	3400.00
0005433124281	2993	Economy	3400.00
0005433124180	2993	Economy	3400.00
0005433124320	2993	Economy	3400.00
0005433124383	2993	Economy	3400.00
0005432881078	2993	Economy	3400.00
0005432881079	2993	Economy	3400.00
0005433124289	2993	Economy	3400.00
0005433124361	2993	Economy	3400.00
0005433124360	2993	Economy	3400.00
0005433124266	2993	Economy	3400.00
0005432881111	2993	Economy	3400.00
0005432881076	2993	Economy	3400.00
0005433194902	2993	Economy	3400.00
0005432707436	2993	Economy	3400.00
0005432707435	2993	Economy	3400.00
0005432881045	2993	Economy	3400.00
0005433124216	2993	Economy	3400.00
0005432881077	2993	Economy	3400.00
0005433124226	2993	Economy	3400.00
0005432881096	2993	Economy	3400.00
0005432707447	2993	Economy	3400.00
0005432881071	2993	Economy	3400.00
0005432881113	2993	Economy	3400.00
0005432707437	2993	Economy	3400.00
0005433124295	2993	Economy	3400.00
0005433124243	2993	Economy	3400.00
0005432881112	2993	Economy	3400.00
0005432881114	2993	Economy	3400.00
0005433124303	2993	Economy	3400.00
0005432881038	2993	Economy	3400.00
0005433124240	2993	Economy	3400.00
0005432707442	2993	Economy	3400.00
0005432693897	30078	Business	10300.00
0005432693883	30078	Business	10300.00
0005432693895	30078	Business	10300.00
0005432707203	30078	Business	10300.00
0005433124462	30078	Business	10300.00
0005433124445	30078	Business	10300.00
0005432707235	30078	Business	10300.00
0005432693886	30078	Business	10300.00
0005433124451	30078	Business	10300.00
0005432693901	30078	Business	10300.00
0005432693880	30078	Business	10300.00
0005432881205	30078	Business	10300.00
0005433124456	30078	Economy	3400.00
0005432693885	30078	Economy	3400.00
0005433124455	30078	Economy	3400.00
0005433194934	30078	Economy	3400.00
0005433124465	30078	Economy	3400.00
0005433194931	30078	Economy	3400.00
0005433194937	30078	Economy	3400.00
0005433124449	30078	Economy	3400.00
0005432707262	30078	Economy	3400.00
0005432693877	30078	Economy	3800.00
0005433124454	30078	Economy	3400.00
0005432693889	30078	Economy	3800.00
0005432693892	30078	Economy	3800.00
0005433194940	30078	Economy	3800.00
0005432881197	30078	Economy	3400.00
0005432707238	30078	Economy	3400.00
0005432693900	30078	Economy	3400.00
0005433124464	30078	Economy	3400.00
0005433194929	30078	Economy	3400.00
0005433194932	30078	Economy	3400.00
0005433194935	30078	Economy	3400.00
0005432707260	30078	Economy	3400.00
0005432693896	30078	Economy	3400.00
0005432693884	30078	Economy	3400.00
0005433124463	30078	Economy	3400.00
0005432707237	30078	Economy	3400.00
0005433124453	30078	Economy	3400.00
0005432881203	30078	Economy	3400.00
0005433124459	30078	Economy	3400.00
0005432707234	30078	Economy	3400.00
0005433194946	30078	Economy	3400.00
0005432693888	30078	Economy	3400.00
0005433194933	30078	Economy	3400.00
0005432693893	30078	Economy	3400.00
0005432707313	30078	Economy	3400.00
0005433194930	30078	Economy	3400.00
0005433124460	30078	Economy	3400.00
0005432707267	30078	Economy	3400.00
0005432693902	30078	Economy	3400.00
0005432881199	30078	Economy	3400.00
0005432693891	30078	Economy	3400.00
0005432707134	30078	Economy	3400.00
0005433194945	30078	Economy	3400.00
0005432693882	30078	Economy	3400.00
0005432693876	30078	Economy	3400.00
0005433194942	30078	Economy	3400.00
0005433194943	30078	Economy	3400.00
0005433124448	30078	Economy	3400.00
0005433124466	30078	Economy	3400.00
0005432881198	30078	Economy	3400.00
0005432693894	30078	Economy	3400.00
0005432881202	30078	Economy	3400.00
0005432707375	30078	Economy	3400.00
0005433124446	30078	Economy	3400.00
0005433194939	30078	Economy	3400.00
0005432693890	30078	Economy	3400.00
0005432881204	30078	Economy	3400.00
0005432693899	30078	Economy	3400.00
0005432693898	30078	Economy	3400.00
0005433124452	30078	Economy	3400.00
0005433124450	30078	Economy	3400.00
0005432707303	30078	Economy	3400.00
0005433194944	30078	Economy	3400.00
0005432707202	30078	Economy	3400.00
0005432707241	30078	Economy	3400.00
0005432693879	30078	Economy	3400.00
0005432707240	30078	Economy	3400.00
0005432693887	30078	Economy	3400.00
0005433194941	30078	Economy	3400.00
0005433124447	30078	Economy	3400.00
0005433124444	30078	Economy	3400.00
0005432881201	30078	Economy	3400.00
0005432881195	30078	Economy	3400.00
0005433194936	30078	Economy	3400.00
0005433124461	30078	Economy	3400.00
0005432881200	30078	Economy	3400.00
0005432693878	30078	Economy	3400.00
0005432707374	30078	Economy	3400.00
0005432693881	30078	Economy	3400.00
0005432707259	30078	Economy	3400.00
0005433194938	30078	Economy	3400.00
0005433124458	30078	Economy	3400.00
0005433124457	30078	Economy	3400.00
0005432881196	30078	Economy	3400.00
0005434980567	23688	Economy	4000.00
0005434980568	23688	Economy	4000.00
0005434980563	23688	Economy	4000.00
0005434989025	23688	Economy	4000.00
0005434980546	23688	Economy	3600.00
0005434980551	23688	Economy	3600.00
0005434989029	23688	Economy	3600.00
0005434980555	23688	Economy	3600.00
0005434980549	23688	Economy	3600.00
0005434989028	23688	Economy	3600.00
0005434980550	23688	Economy	3600.00
0005434980562	23688	Economy	3600.00
0005434980566	23688	Economy	3600.00
0005434980559	23688	Economy	3600.00
0005434989021	23688	Economy	3600.00
0005434980548	23688	Economy	3600.00
0005434980558	23688	Economy	3600.00
0005434980569	23688	Economy	3600.00
0005434980565	23688	Economy	3600.00
0005434989023	23688	Economy	3600.00
0005434980553	23688	Economy	3600.00
0005434989026	23688	Economy	3600.00
0005434980545	23688	Economy	3600.00
0005434989022	23688	Economy	3600.00
0005434980542	23688	Economy	3600.00
0005434980552	23688	Economy	3600.00
0005434980557	23688	Economy	3600.00
0005434989027	23688	Economy	3600.00
0005434980544	23688	Economy	3600.00
0005434980547	23688	Economy	3600.00
0005434980570	23688	Economy	3600.00
0005434980543	23688	Economy	3600.00
0005434980560	23688	Economy	3600.00
0005434980554	23688	Economy	3600.00
0005434989031	23688	Economy	3600.00
0005434989030	23688	Economy	3600.00
0005434980561	23688	Economy	3600.00
0005434980564	23688	Economy	3600.00
0005434980556	23688	Economy	3600.00
0005434989024	23688	Economy	3600.00
0005434980272	27529	Economy	4000.00
0005434980305	27529	Economy	4000.00
0005434980265	27529	Economy	4000.00
0005434980364	27529	Economy	4000.00
0005434980276	27529	Economy	3600.00
0005434980290	27529	Economy	3600.00
0005434988872	27529	Economy	3600.00
0005434988873	27529	Economy	3600.00
0005434980241	27529	Economy	3600.00
0005434980336	27529	Economy	3600.00
0005434980399	27529	Economy	3600.00
0005434980261	27529	Economy	3600.00
0005434980285	27529	Economy	3600.00
0005434980409	27529	Economy	3600.00
0005434980275	27529	Economy	3600.00
0005434980266	27529	Economy	3600.00
0005434980220	27529	Economy	3600.00
0005434980450	27529	Economy	3600.00
0005434980323	27529	Economy	3600.00
0005434980259	27529	Economy	3600.00
0005434980289	27529	Economy	3600.00
0005434980234	27529	Economy	3600.00
0005434980365	27529	Economy	3600.00
0005434980240	27529	Economy	3600.00
0005434980270	27529	Economy	3600.00
0005434980271	27529	Economy	3600.00
0005434988874	27529	Economy	3600.00
0005434980274	27529	Economy	3600.00
0005434980296	27529	Economy	3600.00
0005434980260	27529	Economy	3600.00
0005434980188	27529	Economy	3600.00
0005434980235	27529	Economy	3600.00
0005434980358	27529	Economy	3600.00
0005434980297	27529	Economy	3600.00
0005434980303	27529	Economy	3600.00
0005434980286	27529	Economy	3600.00
0005434980230	27529	Economy	3600.00
0005434980269	27529	Economy	3600.00
0005434980273	27529	Economy	3600.00
0005434980324	27529	Economy	3600.00
0005434980304	27529	Economy	3600.00
0005434980410	27529	Economy	3600.00
0005434980167	27529	Economy	3600.00
0005434302569	10291	Economy	21600.00
0005434302567	10291	Economy	19700.00
0005433111542	10291	Economy	19700.00
0005434302568	10291	Economy	19700.00
0005433111541	10291	Economy	19700.00
0005434302525	19594	Economy	21600.00
0005433113593	19594	Economy	19700.00
0005433113594	19594	Economy	19700.00
0005434302526	19594	Economy	19700.00
0005434302527	19594	Economy	19700.00
0005435925530	3568	Business	26900.00
0005435950306	3568	Business	26900.00
0005435070440	3568	Business	26900.00
0005435950303	3568	Business	26900.00
0005435070436	3568	Business	26900.00
0005435925499	3568	Business	26900.00
0005435939917	3568	Business	26900.00
0005435070457	3568	Business	26900.00
0005435070441	3568	Business	26900.00
0005435925511	3568	Business	26900.00
0005435070449	3568	Business	26900.00
0005435950298	3568	Economy	9000.00
0005435719099	3568	Economy	9000.00
0005435925554	3568	Economy	9000.00
0005435939916	3568	Economy	9000.00
0005435719104	3568	Economy	9000.00
0005435070461	3568	Economy	9000.00
0005435070464	3568	Economy	9000.00
0005435070430	3568	Economy	9000.00
0005435925553	3568	Economy	9900.00
0005435925545	3568	Economy	9900.00
0005435070426	3568	Economy	9900.00
0005435925518	3568	Economy	9900.00
0005435950307	3568	Economy	9900.00
0005435950299	3568	Economy	9000.00
0005435070454	3568	Economy	9000.00
0005435925556	3568	Economy	9000.00
0005435070429	3568	Economy	9000.00
0005435719103	3568	Economy	9000.00
0005435070444	3568	Economy	9000.00
0005435719101	3568	Economy	9000.00
0005435925519	3568	Economy	9000.00
0005435925510	3568	Economy	9000.00
0005435925576	3568	Economy	9000.00
0005435925529	3568	Economy	9000.00
0005435925565	3568	Economy	9000.00
0005435950305	3568	Economy	9000.00
0005435719102	3568	Economy	9000.00
0005435070427	3568	Economy	9000.00
0005435070446	3568	Economy	9000.00
0005435070448	3568	Economy	9000.00
0005435070432	3568	Economy	9000.00
0005435070435	3568	Economy	9000.00
0005435070456	3568	Economy	9000.00
0005435925548	3568	Economy	9000.00
0005435070462	3568	Economy	9000.00
0005435939918	3568	Economy	9000.00
0005435070463	3568	Economy	9000.00
0005435070439	3568	Economy	9000.00
0005435719100	3568	Economy	9000.00
0005435070447	3568	Economy	9000.00
0005435070451	3568	Economy	9000.00
0005435070437	3568	Economy	9000.00
0005435950301	3568	Economy	9000.00
0005435070428	3568	Economy	9000.00
0005435070434	3568	Economy	9000.00
0005435719098	3568	Economy	9000.00
0005435070431	3568	Economy	9000.00
0005435950300	3568	Economy	9000.00
0005435925522	3568	Economy	9000.00
0005435070453	3568	Economy	9000.00
0005435070442	3568	Economy	9000.00
0005435939915	3568	Economy	9000.00
0005435070455	3568	Economy	9000.00
0005435070452	3568	Economy	9000.00
0005435070438	3568	Economy	9000.00
0005435950304	3568	Economy	9000.00
0005435925555	3568	Economy	9000.00
0005435070433	3568	Economy	9000.00
0005435925549	3568	Economy	9000.00
0005435950302	3568	Economy	9000.00
0005435925564	3568	Economy	9000.00
0005435070443	3568	Economy	9000.00
0005435070460	3568	Economy	9000.00
0005435925541	3568	Economy	9000.00
0005435070459	3568	Economy	9000.00
0005435925540	3568	Economy	9000.00
0005435925557	3568	Economy	9000.00
0005435939912	3568	Economy	9000.00
0005435070458	3568	Economy	9000.00
0005435070450	3568	Economy	9000.00
0005435070445	3568	Economy	9000.00
0005435070219	15316	Business	26900.00
0005435069979	15316	Business	26900.00
0005435070062	15316	Business	26900.00
0005435069960	15316	Business	26900.00
0005435069882	15316	Business	26900.00
0005435069622	15316	Business	26900.00
0005435069857	15316	Business	26900.00
0005435069923	15316	Business	26900.00
0005435069803	15316	Business	26900.00
0005435070102	15316	Economy	9000.00
0005435069898	15316	Economy	9000.00
0005435070161	15316	Economy	9000.00
0005435925664	15316	Economy	9000.00
0005435069918	15316	Economy	9000.00
0005435069750	15316	Economy	9000.00
0005435069773	15316	Economy	9000.00
0005435925660	15316	Economy	9000.00
0005435925663	15316	Economy	9000.00
0005435070037	15316	Economy	9900.00
0005435070080	15316	Economy	9900.00
0005435069870	15316	Economy	9900.00
0005435069944	15316	Economy	9900.00
0005435925669	15316	Economy	9000.00
0005435070061	15316	Economy	9000.00
0005435069873	15316	Economy	9000.00
0005435070149	15316	Economy	9000.00
0005435069781	15316	Economy	9000.00
0005435925657	15316	Economy	9000.00
0005435069785	15316	Economy	9000.00
0005435069987	15316	Economy	9000.00
0005435069861	15316	Economy	9000.00
0005435069804	15316	Economy	9000.00
0005435070079	15316	Economy	9000.00
0005435069982	15316	Economy	9000.00
0005435069933	15316	Economy	9000.00
0005435070024	15316	Economy	9000.00
0005435069984	15316	Economy	9000.00
0005435925659	15316	Economy	9000.00
0005435925665	15316	Economy	9000.00
0005435069917	15316	Economy	9000.00
0005435069859	15316	Economy	9000.00
0005435069751	15316	Economy	9000.00
0005435939952	15316	Economy	9000.00
0005435069860	15316	Economy	9000.00
0005435925668	15316	Economy	9000.00
0005435070063	15316	Economy	9000.00
0005435925666	15316	Economy	9000.00
0005435069966	15316	Economy	9000.00
0005435925658	15316	Economy	9000.00
0005435939949	15316	Economy	9000.00
0005435069965	15316	Economy	9000.00
0005435069774	15316	Economy	9000.00
0005435069858	15316	Economy	9000.00
0005435925661	15316	Economy	9000.00
0005435069941	15316	Economy	9000.00
0005435069932	15316	Economy	9000.00
0005435069978	15316	Economy	9000.00
0005435939950	15316	Economy	9000.00
0005435925667	15316	Economy	9000.00
0005435069911	15316	Economy	9000.00
0005435925662	15316	Economy	9000.00
0005435070139	15316	Economy	9000.00
0005435070023	15316	Economy	9000.00
0005435069809	15316	Economy	9000.00
0005435069988	15316	Economy	9000.00
0005435069945	15316	Economy	9000.00
0005435069734	15316	Economy	9000.00
0005435069776	15316	Economy	9000.00
0005435069910	15316	Economy	9000.00
0005435939948	15316	Economy	9000.00
0005435069985	15316	Economy	9000.00
0005435939947	15316	Economy	9000.00
0005435939951	15316	Economy	9000.00
0005435070158	15316	Economy	9000.00
0005432659761	18172	Economy	5900.00
0005432658647	18172	Economy	5900.00
0005432659763	18172	Economy	5900.00
0005432658646	18172	Economy	5900.00
0005432659762	18172	Economy	5900.00
0005432664172	26437	Economy	5900.00
0005432664168	26437	Economy	5900.00
0005432667491	26437	Economy	5900.00
0005432667486	26437	Economy	5900.00
0005432660856	26437	Economy	5900.00
0005432664166	26437	Economy	5900.00
0005432664167	26437	Economy	5900.00
0005432660846	26437	Economy	5900.00
0005433102955	149	Business	20000.00
0005432901971	149	Business	20000.00
0005433103186	149	Business	20000.00
0005433103172	149	Business	20000.00
0005432901948	149	Business	20000.00
0005432901953	149	Business	20000.00
0005432901970	149	Business	20000.00
0005433103084	149	Business	20000.00
0005432677660	149	Business	20000.00
0005433103175	149	Business	20000.00
0005433102967	149	Business	20000.00
0005433103149	149	Business	20000.00
0005432677654	149	Business	20000.00
0005433103007	149	Business	20000.00
0005432901905	149	Business	20000.00
0005433103005	149	Business	20000.00
0005433103110	149	Economy	6700.00
0005433102933	149	Economy	7300.00
0005433103027	149	Economy	6700.00
0005432677643	149	Economy	6700.00
0005432157544	149	Economy	6700.00
0005433103202	149	Economy	6700.00
0005433103129	149	Economy	6700.00
0005432677644	149	Economy	6700.00
0005433103064	149	Economy	6700.00
0005433102975	149	Economy	6700.00
0005433103150	149	Economy	6700.00
0005432920255	149	Economy	6700.00
0005432901851	149	Economy	6700.00
0005433103073	149	Economy	6700.00
0005432901955	149	Economy	6700.00
0005432901954	149	Economy	6700.00
0005432901956	149	Economy	6700.00
0005433102855	149	Economy	6700.00
0005433103009	149	Economy	6700.00
0005432901889	149	Economy	6700.00
0005433102968	149	Economy	6700.00
0005433103132	149	Economy	6700.00
0005433103155	149	Economy	6700.00
0005433103104	149	Economy	6700.00
0005433102929	149	Economy	6700.00
0005433103065	149	Economy	6700.00
0005433103124	149	Economy	6700.00
0005432901966	149	Economy	6700.00
0005433103029	149	Economy	6700.00
0005433103173	149	Economy	6700.00
0005432901957	149	Economy	6700.00
0005433102956	149	Economy	7300.00
0005433103023	149	Economy	7300.00
0005432157543	149	Economy	6700.00
0005433103187	149	Economy	7300.00
0005432920349	149	Economy	6700.00
0005432920199	149	Economy	6700.00
0005432901958	149	Economy	7300.00
0005433103083	149	Economy	6700.00
0005432920202	149	Economy	6700.00
0005433103125	149	Economy	6700.00
0005432920224	149	Economy	6700.00
0005432901972	149	Economy	6700.00
0005432920265	149	Economy	6700.00
0005433103103	149	Economy	6700.00
0005433103127	149	Economy	6700.00
0005432157542	149	Economy	6700.00
0005433103030	149	Economy	6700.00
0005433103191	149	Economy	6700.00
0005432677645	149	Economy	6700.00
0005433103177	149	Economy	6700.00
0005432920248	149	Economy	6700.00
0005432677655	149	Economy	6700.00
0005432677642	149	Economy	6700.00
0005432901888	149	Economy	6700.00
0005433103201	149	Economy	6700.00
0005433103171	149	Economy	6700.00
0005433102930	149	Economy	6700.00
0005432901967	149	Economy	6700.00
0005433103137	149	Economy	6700.00
0005433103102	149	Economy	6700.00
0005433102959	149	Economy	6700.00
0005433103066	149	Economy	6700.00
0005432901897	149	Economy	6700.00
0005432901947	149	Economy	6700.00
0005432920201	149	Economy	6700.00
0005432920272	149	Economy	6700.00
0005433103028	149	Economy	6700.00
0005433103079	149	Economy	6700.00
0005432920242	149	Economy	6700.00
0005432920230	149	Economy	6700.00
0005433103131	149	Economy	6700.00
0005432901979	149	Economy	6700.00
0005433102928	149	Economy	6700.00
0005433103185	149	Economy	6700.00
0005433103024	149	Economy	6700.00
0005432818249	150	Business	20000.00
0005432263096	150	Business	20000.00
0005433687744	150	Business	20000.00
0005432263112	150	Business	20000.00
0005432818266	150	Business	20000.00
0005432818243	150	Business	20000.00
0005433477162	150	Business	20000.00
0005432263092	150	Business	20000.00
0005432289073	150	Business	20000.00
0005432263090	150	Business	20000.00
0005433477178	150	Business	20000.00
0005433477184	150	Business	20000.00
0005432753365	150	Business	20000.00
0005432263113	150	Business	20000.00
0005434152861	150	Business	20000.00
0005432818241	150	Business	20000.00
0005433687741	150	Business	20000.00
0005432818262	150	Business	20000.00
0005432263121	150	Business	20000.00
0005432753364	150	Business	20000.00
0005433477187	150	Business	20000.00
0005432263122	150	Business	20000.00
0005432818261	150	Economy	7300.00
0005433477168	150	Business	20000.00
0005433477193	150	Economy	7300.00
0005433477192	150	Economy	7300.00
0005433477183	150	Economy	7300.00
0005433477169	150	Economy	6700.00
0005432818246	150	Economy	6700.00
0005434157729	150	Economy	6700.00
0005432753366	150	Economy	6700.00
0005432207727	150	Economy	6700.00
0005432818256	150	Economy	6700.00
0005432263119	150	Economy	6700.00
0005432818240	150	Economy	6700.00
0005432263101	150	Economy	6700.00
0005432263100	150	Economy	6700.00
0005432263103	150	Economy	6700.00
0005432818252	150	Economy	6700.00
0005432263104	150	Economy	6700.00
0005432207728	150	Economy	6700.00
0005432263114	150	Economy	6700.00
0005432263089	150	Economy	6700.00
0005432263095	150	Economy	6700.00
0005432263097	150	Economy	6700.00
0005432263109	150	Economy	6700.00
0005432263125	150	Economy	6700.00
0005433477158	150	Economy	6700.00
0005432818257	150	Economy	6700.00
0005433477189	150	Economy	6700.00
0005432263123	150	Economy	6700.00
0005432818255	150	Economy	6700.00
0005432263111	150	Economy	6700.00
0005432818258	150	Economy	6700.00
0005432207729	150	Economy	6700.00
0005433690957	150	Economy	6700.00
0005433477170	150	Economy	6700.00
0005432818248	150	Economy	6700.00
0005433477165	150	Economy	6700.00
0005432263115	150	Economy	6700.00
0005433477159	150	Economy	6700.00
0005433477167	150	Economy	6700.00
0005432818247	150	Economy	6700.00
0005432263106	150	Economy	6700.00
0005432263110	150	Economy	6700.00
0005433690953	150	Economy	6700.00
0005434157728	150	Economy	6700.00
0005433477174	150	Economy	6700.00
0005433477180	150	Economy	7300.00
0005432818239	150	Economy	6700.00
0005432263094	150	Economy	7300.00
0005433477172	150	Economy	7300.00
0005432263117	150	Economy	7300.00
0005433477188	150	Economy	6700.00
0005432207730	150	Economy	6700.00
0005432818242	150	Economy	7300.00
0005432263102	150	Economy	6700.00
0005433477179	150	Economy	6700.00
0005433477163	150	Economy	6700.00
0005433477190	150	Economy	6700.00
0005433477186	150	Economy	6700.00
0005433477164	150	Economy	6700.00
0005432263091	150	Economy	6700.00
0005433687740	150	Economy	6700.00
0005432263105	150	Economy	6700.00
0005433477185	150	Economy	6700.00
0005432818263	150	Economy	6700.00
0005433477182	150	Economy	6700.00
0005433477173	150	Economy	6700.00
0005434152860	150	Economy	6700.00
0005432818250	150	Economy	6700.00
0005433477171	150	Economy	6700.00
0005433477175	150	Economy	6700.00
0005433477191	150	Economy	6700.00
0005432263116	150	Economy	6700.00
0005433477161	150	Economy	6700.00
0005433477194	150	Economy	6700.00
0005432818260	150	Economy	6700.00
0005432818265	150	Economy	6700.00
0005432263099	150	Economy	6700.00
0005432263124	150	Economy	6700.00
0005432818251	150	Economy	6700.00
0005432756898	150	Economy	6700.00
0005432263118	150	Economy	6700.00
0005432263108	150	Economy	6700.00
0005433477177	150	Economy	6700.00
0005432818264	150	Economy	6700.00
0005432818238	150	Economy	6700.00
0005432263093	150	Economy	6700.00
0005432263098	150	Economy	6700.00
0005434157730	150	Economy	6700.00
0005434153574	150	Economy	6700.00
0005434153573	150	Economy	6700.00
0005432263107	150	Economy	6700.00
0005433477160	150	Economy	6700.00
0005432818254	150	Economy	6700.00
0005432818253	150	Economy	6700.00
0005432818259	150	Economy	6700.00
0005432818244	150	Economy	6700.00
0005432263120	150	Economy	6700.00
0005433477166	150	Economy	6700.00
0005433690955	150	Economy	6700.00
0005432756899	150	Economy	6700.00
0005433477176	150	Economy	6700.00
0005432756887	150	Economy	6700.00
0005433477181	150	Economy	6700.00
0005432818245	150	Economy	6700.00
0005432045666	8067	Business	20000.00
0005432020977	8067	Business	20000.00
0005433103554	8067	Business	20000.00
0005433103556	8067	Business	20000.00
0005433103584	8067	Business	20000.00
0005432753390	8067	Business	20000.00
0005432920401	8067	Business	20000.00
0005432920415	8067	Business	20000.00
0005432753392	8067	Business	20000.00
0005432020967	8067	Business	20000.00
0005432020972	8067	Business	20000.00
0005432020961	8067	Business	20000.00
0005432920404	8067	Business	20000.00
0005432020963	8067	Business	20000.00
0005433103548	8067	Business	20000.00
0005433103550	8067	Business	20000.00
0005433103589	8067	Business	20000.00
0005432920411	8067	Business	20000.00
0005432920408	8067	Business	20000.00
0005432020979	8067	Business	20000.00
0005432020965	8067	Business	20000.00
0005432020974	8067	Economy	7300.00
0005433103601	8067	Economy	7300.00
0005433103579	8067	Economy	7300.00
0005433103551	8067	Economy	7300.00
0005432020981	8067	Economy	6700.00
0005432920409	8067	Economy	6700.00
0005432020969	8067	Economy	6700.00
0005432020970	8067	Economy	6700.00
0005432392081	8067	Economy	6700.00
0005433103560	8067	Economy	6700.00
0005433103592	8067	Economy	6700.00
0005432045665	8067	Economy	6700.00
0005432751614	8067	Economy	6700.00
0005432920412	8067	Economy	6700.00
0005433103607	8067	Economy	6700.00
0005433103573	8067	Economy	6700.00
0005432751616	8067	Economy	6700.00
0005432920407	8067	Economy	6700.00
0005433103558	8067	Economy	6700.00
0005432920402	8067	Economy	6700.00
0005433103552	8067	Economy	6700.00
0005433103546	8067	Economy	6700.00
0005433103604	8067	Economy	6700.00
0005433103541	8067	Economy	6700.00
0005433103570	8067	Economy	6700.00
0005433103587	8067	Economy	6700.00
0005432020973	8067	Economy	6700.00
0005433103561	8067	Economy	6700.00
0005432920410	8067	Economy	6700.00
0005433103580	8067	Economy	6700.00
0005433103574	8067	Economy	6700.00
0005433103586	8067	Economy	6700.00
0005433103545	8067	Economy	6700.00
0005433103602	8067	Economy	6700.00
0005432677679	8067	Economy	6700.00
0005433103610	8067	Economy	6700.00
0005432020960	8067	Economy	6700.00
0005432020975	8067	Economy	6700.00
0005432392080	8067	Economy	6700.00
0005432020966	8067	Economy	6700.00
0005432020982	8067	Economy	6700.00
0005433103568	8067	Economy	6700.00
0005433103609	8067	Economy	6700.00
0005433103555	8067	Economy	6700.00
0005433103596	8067	Economy	6700.00
0005433103575	8067	Economy	6700.00
0005433103562	8067	Economy	6700.00
0005432920403	8067	Economy	6700.00
0005432020959	8067	Economy	6700.00
0005433103588	8067	Economy	6700.00
0005433103563	8067	Economy	7300.00
0005433103557	8067	Economy	6700.00
0005433103593	8067	Economy	7300.00
0005433103572	8067	Economy	7300.00
0005432753391	8067	Economy	7300.00
0005432920405	8067	Economy	7300.00
0005433103606	8067	Economy	6700.00
0005433103585	8067	Economy	6700.00
0005433103543	8067	Economy	7300.00
0005433103605	8067	Economy	6700.00
0005432020958	8067	Economy	6700.00
0005433103578	8067	Economy	6700.00
0005433103582	8067	Economy	6700.00
0005433103559	8067	Economy	6700.00
0005433103576	8067	Economy	6700.00
0005433103567	8067	Economy	6700.00
0005433103595	8067	Economy	6700.00
0005433103577	8067	Economy	6700.00
0005432920406	8067	Economy	6700.00
0005433103600	8067	Economy	6700.00
0005433103566	8067	Economy	6700.00
0005433103591	8067	Economy	6700.00
0005432677680	8067	Economy	6700.00
0005432020968	8067	Economy	6700.00
0005432044598	8067	Economy	6700.00
0005432044597	8067	Economy	6700.00
0005433103603	8067	Economy	6700.00
0005433103598	8067	Economy	6700.00
0005432044599	8067	Economy	6700.00
0005433103608	8067	Economy	6700.00
0005433103542	8067	Economy	6700.00
0005433103590	8067	Economy	6700.00
0005433103544	8067	Economy	6700.00
0005433103569	8067	Economy	6700.00
0005433103564	8067	Economy	6700.00
0005433103581	8067	Economy	6700.00
0005432920414	8067	Economy	6700.00
0005432044600	8067	Economy	6700.00
0005433103611	8067	Economy	6700.00
0005433103571	8067	Economy	6700.00
0005433103597	8067	Economy	6700.00
0005433103583	8067	Economy	6700.00
0005432020971	8067	Economy	6700.00
0005433103553	8067	Economy	6700.00
0005432020962	8067	Economy	6700.00
0005433103594	8067	Economy	6700.00
0005433103599	8067	Economy	6700.00
0005432020983	8067	Economy	6700.00
0005432020964	8067	Economy	6700.00
0005432751615	8067	Economy	6700.00
0005433103547	8067	Economy	6700.00
0005432753389	8067	Economy	6700.00
0005432920413	8067	Economy	6700.00
0005432020980	8067	Economy	6700.00
0005433103549	8067	Economy	6700.00
0005432677678	8067	Economy	6700.00
0005432020978	8067	Economy	6700.00
0005432920400	8067	Economy	6700.00
0005433103565	8067	Economy	6700.00
0005432751617	8067	Economy	6700.00
0005432020976	8067	Economy	6700.00
0005432817848	8075	Business	20000.00
0005432902066	8075	Business	20000.00
0005432902063	8075	Business	20000.00
0005432817852	8075	Business	20000.00
0005432818100	8075	Business	20000.00
0005432817973	8075	Business	20000.00
0005432818090	8075	Business	20000.00
0005432902071	8075	Business	20000.00
0005432902062	8075	Business	20000.00
0005432817954	8075	Business	20000.00
0005432902067	8075	Business	20000.00
0005432902070	8075	Economy	7300.00
0005432817926	8075	Economy	7300.00
0005432902076	8075	Economy	6700.00
0005432002130	8075	Economy	6700.00
0005432817975	8075	Economy	6700.00
0005432817997	8075	Economy	6700.00
0005432818099	8075	Economy	6700.00
0005432902074	8075	Economy	6700.00
0005432817963	8075	Economy	6700.00
0005432902065	8075	Economy	6700.00
0005432902072	8075	Economy	6700.00
0005432902073	8075	Economy	6700.00
0005432817964	8075	Economy	6700.00
0005432817925	8075	Economy	6700.00
0005432818057	8075	Economy	6700.00
0005432818048	8075	Economy	6700.00
0005432902064	8075	Economy	6700.00
0005432817849	8075	Economy	6700.00
0005432902075	8075	Economy	6700.00
0005432818086	8075	Economy	6700.00
0005432002131	8075	Economy	7300.00
0005432817958	8075	Economy	6700.00
0005432817969	8075	Economy	6700.00
0005432818042	8075	Economy	6700.00
0005432818114	8075	Economy	6700.00
0005432818019	8075	Economy	6700.00
0005432818046	8075	Economy	6700.00
0005432902068	8075	Economy	6700.00
0005432902077	8075	Economy	6700.00
0005432902069	8075	Economy	6700.00
0005432817953	8075	Economy	6700.00
0005432817914	8075	Economy	6700.00
0005432818018	8075	Economy	6700.00
0005432818044	8075	Economy	6700.00
0005432817934	8075	Economy	6700.00
0005432817965	8075	Economy	6700.00
0005432817978	8075	Economy	6700.00
0005433870790	9635	Economy	6900.00
0005433870792	9635	Economy	6900.00
0005434175830	9635	Economy	6900.00
0005434175836	9635	Economy	6900.00
0005434175828	9635	Economy	6900.00
0005434175825	9635	Economy	6900.00
0005434175837	9635	Economy	6900.00
0005434175824	9635	Economy	6900.00
0005433870791	9635	Economy	6900.00
0005433870789	9635	Economy	6900.00
0005433870766	32361	Economy	6900.00
0005434175864	32361	Economy	6900.00
0005434175866	32361	Economy	6900.00
0005434175865	32361	Economy	6900.00
0005433870770	32361	Economy	6900.00
0005434427396	3471	Business	35000.00
0005434880752	3471	Business	35000.00
0005435127459	3471	Business	35000.00
0005434880758	3471	Business	35000.00
0005435127434	3471	Business	35000.00
0005435626676	3471	Business	35000.00
0005435626667	3471	Business	35000.00
0005434427393	3471	Business	35000.00
0005435127458	3471	Business	35000.00
0005435903014	3471	Business	35000.00
0005432800200	3471	Business	35000.00
0005434427397	3471	Business	35000.00
0005434880728	3471	Business	35000.00
0005434880725	3471	Business	35000.00
0005434880686	3471	Business	35000.00
0005435626671	3471	Business	35000.00
0005432800203	3471	Business	35000.00
0005432800196	3471	Business	35000.00
0005434880726	3471	Business	35000.00
0005434880733	3471	Business	35000.00
0005434427402	3471	Comfort	19900.00
0005435626683	3471	Comfort	19900.00
0005434880691	3471	Comfort	19900.00
0005435127432	3471	Comfort	19900.00
0005435913994	3471	Comfort	19900.00
0005434880742	3471	Comfort	19900.00
0005435626672	3471	Comfort	19900.00
0005434427380	3471	Comfort	19900.00
0005434938650	3471	Comfort	19900.00
0005434880709	3471	Comfort	19900.00
0005434880764	3471	Comfort	19900.00
0005435626687	3471	Comfort	19900.00
0005435127436	3471	Comfort	19900.00
0005435127448	3471	Comfort	19900.00
0005434880753	3471	Comfort	19900.00
0005434880701	3471	Comfort	19900.00
0005434880702	3471	Comfort	19900.00
0005435903017	3471	Comfort	19900.00
0005434880704	3471	Comfort	19900.00
0005434938659	3471	Comfort	19900.00
0005435914715	3471	Comfort	19900.00
0005432800213	3471	Comfort	19900.00
0005432800198	3471	Comfort	19900.00
0005434880692	3471	Comfort	19900.00
0005432188694	3471	Comfort	19900.00
0005434880750	3471	Comfort	19900.00
0005432800207	3471	Comfort	19900.00
0005435913996	3471	Comfort	19900.00
0005432611805	3471	Comfort	19900.00
0005434880722	3471	Economy	11700.00
0005434880738	3471	Economy	11700.00
0005435913966	3471	Economy	11700.00
0005434880695	3471	Economy	11700.00
0005434880765	3471	Economy	11700.00
0005432188698	3471	Economy	11700.00
0005434880735	3471	Economy	11700.00
0005435913979	3471	Economy	11700.00
0005434427390	3471	Economy	11700.00
0005435903057	3471	Economy	11700.00
0005434427379	3471	Economy	11700.00
0005434880705	3471	Economy	11700.00
0005435903071	3471	Economy	11700.00
0005435903062	3471	Economy	11700.00
0005435903018	3471	Economy	11700.00
0005435127460	3471	Economy	11700.00
0005435913999	3471	Economy	11700.00
0005434880708	3471	Economy	11700.00
0005434880693	3471	Economy	11700.00
0005434880729	3471	Economy	11700.00
0005432800195	3471	Economy	11700.00
0005435626678	3471	Economy	11700.00
0005434880763	3471	Economy	11700.00
0005435127456	3471	Economy	11700.00
0005435127466	3471	Economy	11700.00
0005435127455	3471	Economy	11700.00
0005434880689	3471	Economy	11700.00
0005434938655	3471	Economy	11700.00
0005434880707	3471	Economy	11700.00
0005435127451	3471	Economy	11700.00
0005432800209	3471	Economy	11700.00
0005435626669	3471	Economy	11700.00
0005435127446	3471	Economy	11700.00
0005435914728	3471	Economy	11700.00
0005435914714	3471	Economy	11700.00
0005432188696	3471	Economy	11700.00
0005435626679	3471	Economy	11700.00
0005434427386	3471	Economy	11700.00
0005432611804	3471	Economy	11700.00
0005434880710	3471	Economy	11700.00
0005434938668	3471	Economy	11700.00
0005435903002	3471	Economy	11700.00
0005432800211	3471	Economy	11700.00
0005435903058	3471	Economy	11700.00
0005435913982	3471	Economy	12800.00
0005435127429	3471	Economy	11700.00
0005432800210	3471	Economy	12800.00
0005434880760	3471	Economy	11700.00
0005435913997	3471	Economy	12800.00
0005434938653	3471	Economy	11700.00
0005435903015	3471	Economy	12800.00
0005434880698	3471	Economy	11700.00
0005435903019	3471	Economy	11700.00
0005434427382	3471	Economy	11700.00
0005434427381	3471	Economy	11700.00
0005434938661	3471	Economy	11700.00
0005434880715	3471	Economy	11700.00
0005432800216	3471	Economy	11700.00
0005432800201	3471	Economy	11700.00
0005434880741	3471	Economy	11700.00
0005435626684	3471	Economy	11700.00
0005432800212	3471	Economy	11700.00
0005435626681	3471	Economy	11700.00
0005435127465	3471	Economy	11700.00
0005435127437	3471	Economy	11700.00
0005434880747	3471	Economy	11700.00
0005434880757	3471	Economy	11700.00
0005434880720	3471	Economy	11700.00
0005434880762	3471	Economy	11700.00
0005435127438	3471	Economy	11700.00
0005435127430	3471	Economy	11700.00
0005434880730	3471	Economy	11700.00
0005434880755	3471	Economy	11700.00
0005434880727	3471	Economy	11700.00
0005434880712	3471	Economy	11700.00
0005435626670	3471	Economy	11700.00
0005435127440	3471	Economy	11700.00
0005435127439	3471	Economy	11700.00
0005435626666	3471	Economy	11700.00
0005434880706	3471	Economy	11700.00
0005434880745	3471	Economy	11700.00
0005434938652	3471	Economy	11700.00
0005434880734	3471	Economy	11700.00
0005435127457	3471	Economy	11700.00
0005434880756	3471	Economy	11700.00
0005435127441	3471	Economy	11700.00
0005432611806	3471	Economy	11700.00
0005435127433	3471	Economy	11700.00
0005434427401	3471	Economy	11700.00
0005434938651	3471	Economy	11700.00
0005434427376	3471	Economy	11700.00
0005434427375	3471	Economy	11700.00
0005434880751	3471	Economy	11700.00
0005434880703	3471	Economy	11700.00
0005432800205	3471	Economy	11700.00
0005434880697	3471	Economy	11700.00
0005435127444	3471	Economy	11700.00
0005435626689	3471	Economy	11700.00
0005435626677	3471	Economy	11700.00
0005434880746	3471	Economy	11700.00
0005434880740	3471	Economy	11700.00
0005434880721	3471	Economy	11700.00
0005432611803	3471	Economy	11700.00
0005434427403	3471	Economy	11700.00
0005435127449	3471	Economy	11700.00
0005434880694	3471	Economy	11700.00
0005435626668	3471	Economy	11700.00
0005434880717	3471	Economy	11700.00
0005434880685	3471	Economy	11700.00
0005435127442	3471	Economy	11700.00
0005434938663	3471	Economy	11700.00
0005435626673	3471	Economy	11700.00
0005432613971	3471	Economy	11700.00
0005432188697	3471	Economy	11700.00
0005434427389	3471	Economy	11700.00
0005435127443	3471	Economy	11700.00
0005434880716	3471	Economy	11700.00
0005432613970	3471	Economy	11700.00
0005435127462	3471	Economy	11700.00
0005435127450	3471	Economy	11700.00
0005434880687	3471	Economy	11700.00
0005434880699	3471	Economy	11700.00
0005435127447	3471	Economy	11700.00
0005432800214	3471	Economy	11700.00
0005434427387	3471	Economy	11700.00
0005434880714	3471	Economy	11700.00
0005434427400	3471	Economy	11700.00
0005434938662	3471	Economy	11700.00
0005434880743	3471	Economy	11700.00
0005435626674	3471	Economy	12800.00
0005434880684	3471	Economy	12800.00
0005435841108	3471	Economy	12800.00
0005435902994	3471	Economy	12800.00
0005434880732	3471	Economy	12800.00
0005432800202	3471	Economy	11700.00
0005435913993	3471	Economy	11700.00
0005434880711	3471	Economy	11700.00
0005434938667	3471	Economy	11700.00
0005434938660	3471	Economy	11700.00
0005434427395	3471	Economy	11700.00
0005435127463	3471	Economy	11700.00
0005434880754	3471	Economy	11700.00
0005435903001	3471	Economy	11700.00
0005434880683	3471	Economy	11700.00
0005434880744	3471	Economy	11700.00
0005432800197	3471	Economy	11700.00
0005434938656	3471	Economy	11700.00
0005432188695	3471	Economy	11700.00
0005435914000	3471	Economy	11700.00
0005434938665	3471	Economy	11700.00
0005435127453	3471	Economy	11700.00
0005435903070	3471	Economy	11700.00
0005435127435	3471	Economy	11700.00
0005432800208	3471	Economy	11700.00
0005435127467	3471	Economy	11700.00
0005435127464	3471	Economy	11700.00
0005434880766	3471	Economy	11700.00
0005434427374	3471	Economy	11700.00
0005434880688	3471	Economy	11700.00
0005435841109	3471	Economy	11700.00
0005435841110	3471	Economy	11700.00
0005434880736	3471	Economy	11700.00
0005432800215	3471	Economy	11700.00
0005435902935	3471	Economy	11700.00
0005435626675	3471	Economy	11700.00
0005435626686	3471	Economy	11700.00
0005434938654	3471	Economy	11700.00
0005434880761	3471	Economy	11700.00
0005435902987	3471	Economy	11700.00
0005434880737	3471	Economy	11700.00
0005434427377	3471	Economy	11700.00
0005434880724	3471	Economy	11700.00
0005434938658	3471	Economy	11700.00
0005434427383	3471	Economy	11700.00
0005434427392	3471	Economy	11700.00
0005434880723	3471	Economy	11700.00
0005435127431	3471	Economy	11700.00
0005434880719	3471	Economy	11700.00
0005434427394	3471	Economy	11700.00
0005434938664	3471	Economy	11700.00
0005435127454	3471	Economy	11700.00
0005434880759	3471	Economy	11700.00
0005434427388	3471	Economy	11700.00
0005434880749	3471	Economy	11700.00
0005432800206	3471	Economy	11700.00
0005434880696	3471	Economy	11700.00
0005434427391	3471	Economy	11700.00
0005434880739	3471	Economy	11700.00
0005435902969	3471	Economy	11700.00
0005435127452	3471	Economy	11700.00
0005434427378	3471	Economy	11700.00
0005435626682	3471	Economy	11700.00
0005432183524	3471	Economy	11700.00
0005432188693	3471	Economy	11700.00
0005434880713	3471	Economy	11700.00
0005432800199	3471	Economy	11700.00
0005434880690	3471	Economy	11700.00
0005435127461	3471	Economy	11700.00
0005435626688	3471	Economy	11700.00
0005434880731	3471	Economy	11700.00
0005434427398	3471	Economy	11700.00
0005434880748	3471	Economy	11700.00
0005435841834	3471	Economy	11700.00
0005435127445	3471	Economy	11700.00
0005434938657	3471	Economy	11700.00
0005434427385	3471	Economy	11700.00
0005434427384	3471	Economy	11700.00
0005434938666	3471	Economy	11700.00
0005435626680	3471	Economy	11700.00
0005434880700	3471	Economy	11700.00
0005435127428	3471	Economy	11700.00
0005434427399	3471	Economy	11700.00
0005435626685	3471	Economy	11700.00
0005432800204	3471	Economy	11700.00
0005434880718	3471	Economy	11700.00
0005435626528	14545	Business	35000.00
0005432607624	14545	Business	35000.00
0005434879704	14545	Business	35000.00
0005434938570	14545	Business	35000.00
0005435127089	14545	Business	35000.00
0005434880211	14545	Business	35000.00
0005432799966	14545	Business	35000.00
0005435126875	14545	Business	35000.00
0005434427196	14545	Business	35000.00
0005435914114	14545	Business	35000.00
0005434879961	14545	Business	35000.00
0005434880088	14545	Business	35000.00
0005432800028	14545	Business	35000.00
0005434427225	14545	Business	35000.00
0005434938517	14545	Business	35000.00
0005434880066	14545	Business	35000.00
0005432799874	14545	Business	35000.00
0005434879709	14545	Comfort	19900.00
0005432800069	14545	Comfort	19900.00
0005434938527	14545	Comfort	19900.00
0005434880124	14545	Comfort	19900.00
0005434880087	14545	Comfort	19900.00
0005432800000	14545	Comfort	19900.00
0005435903175	14545	Comfort	19900.00
0005435126941	14545	Comfort	19900.00
0005435127093	14545	Comfort	19900.00
0005435626433	14545	Comfort	19900.00
0005434426978	14545	Comfort	19900.00
0005434879683	14545	Comfort	19900.00
0005434879791	14545	Comfort	19900.00
0005434880053	14545	Comfort	19900.00
0005434427109	14545	Comfort	19900.00
0005434938473	14545	Comfort	19900.00
0005435903166	14545	Comfort	19900.00
0005434879675	14545	Comfort	19900.00
0005434879637	14545	Comfort	19900.00
0005434938468	14545	Comfort	19900.00
0005434938571	14545	Comfort	19900.00
0005434879702	14545	Comfort	19900.00
0005434938516	14545	Comfort	19900.00
0005435626526	14545	Comfort	19900.00
0005434427138	14545	Comfort	19900.00
0005434938432	14545	Comfort	19900.00
0005435127021	14545	Comfort	19900.00
0005434879878	14545	Comfort	19900.00
0005434427219	14545	Comfort	19900.00
0005435126918	14545	Comfort	19900.00
0005434427128	14545	Comfort	19900.00
0005432059559	14545	Comfort	19900.00
0005435127046	14545	Comfort	19900.00
0005434880152	14545	Comfort	19900.00
0005434427100	14545	Economy	11700.00
0005432607625	14545	Economy	11700.00
0005434880086	14545	Economy	11700.00
0005434938524	14545	Economy	11700.00
0005434879976	14545	Economy	11700.00
0005434938459	14545	Economy	11700.00
0005435126955	14545	Economy	11700.00
0005434938465	14545	Economy	11700.00
0005435127083	14545	Economy	11700.00
0005432800073	14545	Economy	11700.00
0005434938574	14545	Economy	11700.00
0005434880279	14545	Economy	11700.00
0005432611775	14545	Economy	11700.00
0005435127008	14545	Economy	11700.00
0005434879545	14545	Economy	11700.00
0005435126877	14545	Economy	11700.00
0005434880057	14545	Economy	11700.00
0005434938482	14545	Economy	11700.00
0005435127070	14545	Economy	11700.00
0005435126824	14545	Economy	11700.00
0005432799924	14545	Economy	11700.00
0005434879933	14545	Economy	11700.00
0005434880012	14545	Economy	11700.00
0005432800071	14545	Economy	11700.00
0005434880038	14545	Economy	11700.00
0005434880061	14545	Economy	11700.00
0005434880193	14545	Economy	11700.00
0005434880179	14545	Economy	11700.00
0005434938505	14545	Economy	11700.00
0005432607641	14545	Economy	11700.00
0005435903179	14545	Economy	11700.00
0005434427083	14545	Economy	11700.00
0005432800018	14545	Economy	11700.00
0005435126960	14545	Economy	11700.00
0005435127098	14545	Economy	11700.00
0005434879661	14545	Economy	11700.00
0005434427087	14545	Economy	11700.00
0005434938572	14545	Economy	11700.00
0005434938469	14545	Economy	11700.00
0005434880065	14545	Economy	11700.00
0005434427193	14545	Economy	11700.00
0005434938561	14545	Economy	11700.00
0005435126917	14545	Economy	11700.00
0005434879837	14545	Economy	11700.00
0005432800023	14545	Economy	11700.00
0005434427171	14545	Economy	11700.00
0005432799977	14545	Economy	11700.00
0005434938576	14545	Economy	11700.00
0005432059557	14545	Economy	11700.00
0005435903173	14545	Economy	12800.00
0005434938460	14545	Economy	12800.00
0005434427136	14545	Economy	11700.00
0005435903170	14545	Economy	12800.00
0005434879733	14545	Economy	11700.00
0005434879868	14545	Economy	11700.00
0005434879877	14545	Economy	11700.00
0005432799996	14545	Economy	12800.00
0005432800003	14545	Economy	11700.00
0005434879658	14545	Economy	11700.00
0005434879728	14545	Economy	11700.00
0005434879576	14545	Economy	11700.00
0005434938629	14545	Economy	11700.00
0005434427298	14545	Economy	11700.00
0005434879904	14545	Economy	11700.00
0005434427107	14545	Economy	11700.00
0005434880194	14545	Economy	11700.00
0005435127202	14545	Economy	11700.00
0005435903171	14545	Economy	11700.00
0005434879734	14545	Economy	11700.00
0005434879676	14545	Economy	11700.00
0005435626499	14545	Economy	11700.00
0005435127028	14545	Economy	11700.00
0005434427226	14545	Economy	11700.00
0005432607647	14545	Economy	11700.00
0005434879998	14545	Economy	11700.00
0005434879923	14545	Economy	11700.00
0005432611781	14545	Economy	11700.00
0005434879963	14545	Economy	11700.00
0005434880016	14545	Economy	11700.00
0005434879922	14545	Economy	11700.00
0005432799932	14545	Economy	11700.00
0005432800072	14545	Economy	11700.00
0005435126876	14545	Economy	11700.00
0005434938462	14545	Economy	11700.00
0005434880153	14545	Economy	11700.00
0005434427195	14545	Economy	11700.00
0005434880184	14545	Economy	11700.00
0005434427285	14545	Economy	11700.00
0005432799965	14545	Economy	11700.00
0005435903169	14545	Economy	11700.00
0005434879919	14545	Economy	11700.00
0005435903174	14545	Economy	11700.00
0005435626479	14545	Economy	11700.00
0005434879948	14545	Economy	11700.00
0005434880182	14545	Economy	11700.00
0005434880080	14545	Economy	11700.00
0005434427199	14545	Economy	11700.00
0005434880037	14545	Economy	11700.00
0005432607639	14545	Economy	11700.00
0005434427099	14545	Economy	11700.00
0005434879732	14545	Economy	11700.00
0005435127166	14545	Economy	11700.00
0005434880026	14545	Economy	11700.00
0005434880150	14545	Economy	11700.00
0005434880069	14545	Economy	11700.00
0005435127069	14545	Economy	11700.00
0005434938474	14545	Economy	11700.00
0005434427019	14545	Economy	11700.00
0005434427034	14545	Economy	11700.00
0005432800017	14545	Economy	11700.00
0005434938540	14545	Economy	11700.00
0005434880027	14545	Economy	11700.00
0005432611782	14545	Economy	11700.00
0005434879657	14545	Economy	11700.00
0005432799875	14545	Economy	11700.00
0005434938573	14545	Economy	11700.00
0005434879862	14545	Economy	11700.00
0005434879962	14545	Economy	11700.00
0005434938457	14545	Economy	11700.00
0005434427098	14545	Economy	11700.00
0005434879544	14545	Economy	11700.00
0005434427149	14545	Economy	11700.00
0005435127094	14545	Economy	11700.00
0005434427078	14545	Economy	11700.00
0005434879988	14545	Economy	11700.00
0005434879790	14545	Economy	11700.00
0005434427079	14545	Economy	11700.00
0005435626486	14545	Economy	11700.00
0005434880032	14545	Economy	11700.00
0005435127095	14545	Economy	11700.00
0005434427028	14545	Economy	11700.00
0005434880109	14545	Economy	11700.00
0005434880154	14545	Economy	11700.00
0005434880155	14545	Economy	11700.00
0005434879835	14545	Economy	11700.00
0005434938431	14545	Economy	11700.00
0005434879997	14545	Economy	11700.00
0005434880049	14545	Economy	11700.00
0005434879840	14545	Economy	11700.00
0005434427254	14545	Economy	11700.00
0005434427140	14545	Economy	11700.00
0005432799949	14545	Economy	11700.00
0005435127066	14545	Economy	11700.00
0005434880060	14545	Economy	11700.00
0005434879949	14545	Economy	11700.00
0005435127040	14545	Economy	11700.00
0005435127167	14545	Economy	11700.00
0005432800010	14545	Economy	11700.00
0005435903178	14545	Economy	11700.00
0005434879903	14545	Economy	11700.00
0005434879491	14545	Economy	12800.00
0005434427080	14545	Economy	12800.00
0005434938467	14545	Economy	12800.00
0005432800046	14545	Economy	11700.00
0005434879942	14545	Economy	11700.00
0005435127152	14545	Economy	11700.00
0005435126940	14545	Economy	11700.00
0005434879865	14545	Economy	11700.00
0005434879897	14545	Economy	11700.00
0005435903167	14545	Economy	11700.00
0005434879662	14545	Economy	11700.00
0005434880110	14545	Economy	11700.00
0005432607640	14545	Economy	11700.00
0005435914115	14545	Economy	11700.00
0005434880113	14545	Economy	11700.00
0005434880151	14545	Economy	11700.00
0005434879436	14545	Economy	11700.00
0005432611783	14545	Economy	11700.00
0005434880015	14545	Economy	11700.00
0005435626502	14545	Economy	11700.00
0005435626527	14545	Economy	11700.00
0005434427027	14545	Economy	11700.00
0005432799671	14545	Economy	11700.00
0005435127142	14545	Economy	11700.00
0005435903176	14545	Economy	11700.00
0005435626507	14545	Economy	11700.00
0005432607642	14545	Economy	11700.00
0005434879749	14545	Economy	11700.00
0005435903168	14545	Economy	11700.00
0005435626470	14545	Economy	11700.00
0005434879883	14545	Economy	11700.00
0005432059558	14545	Economy	11700.00
0005434427020	14545	Economy	11700.00
0005434938569	14545	Economy	11700.00
0005435127102	14545	Economy	11700.00
0005432799905	14545	Economy	11700.00
0005435127295	14545	Economy	11700.00
0005434427137	14545	Economy	11700.00
0005435127000	14545	Economy	11700.00
0005435903172	14545	Economy	11700.00
0005434880050	14545	Economy	11700.00
0005434879920	14545	Economy	11700.00
0005434879974	14545	Economy	11700.00
0005434879638	14545	Economy	11700.00
0005435127001	14545	Economy	11700.00
0005432799887	14545	Economy	11700.00
0005435127171	14545	Economy	11700.00
0005434938526	14545	Economy	11700.00
0005434427126	14545	Economy	11700.00
0005434880146	14545	Economy	11700.00
0005434879869	14545	Economy	11700.00
0005434879146	14545	Economy	11700.00
0005435126922	14545	Economy	11700.00
0005434880054	14545	Economy	11700.00
0005434879993	14545	Economy	11700.00
0005435903177	14545	Economy	11700.00
0005434880059	14545	Economy	11700.00
0005434879901	14545	Economy	11700.00
0005435126923	14545	Economy	11700.00
0005434879751	14545	Economy	11700.00
0005435914113	14545	Economy	11700.00
0005434879703	14545	Economy	11700.00
0005432799997	14545	Economy	11700.00
0005434879836	14545	Economy	11700.00
0005432800022	14545	Economy	11700.00
0005434879748	14545	Economy	11700.00
0005434879990	14545	Economy	11700.00
0005434880111	14545	Economy	11700.00
0005434880147	14545	Economy	11700.00
0005434938475	14545	Economy	11700.00
0005435126951	14545	Economy	11700.00
0005435127088	14545	Economy	11700.00
0005435127170	14545	Economy	11700.00
0005432607613	14545	Economy	11700.00
0005434427192	14545	Economy	11700.00
0005434880030	14545	Economy	11700.00
0005434879989	14545	Economy	11700.00
0005432800029	14545	Economy	11700.00
0005434879992	14545	Economy	11700.00
0005434879838	14545	Economy	11700.00
0005435127047	14545	Economy	11700.00
0005435126961	14545	Economy	11700.00
0005434938455	14545	Economy	11700.00
0005434880108	14545	Economy	11700.00
0005434427185	14545	Economy	11700.00
0005435890014	3626	Economy	16300.00
0005434325956	3626	Economy	16300.00
0005435889981	3626	Economy	14800.00
0005435890005	3626	Economy	14800.00
0005434312373	3626	Economy	14800.00
0005435890006	3626	Economy	14800.00
0005435889983	3626	Economy	14800.00
0005435890029	3626	Economy	14800.00
0005434312374	3626	Economy	14800.00
0005435890009	3626	Economy	14800.00
0005434325950	3626	Economy	14800.00
0005434325949	3626	Economy	14800.00
0005435889982	3626	Economy	14800.00
0005435890011	3626	Economy	14800.00
0005434325948	3626	Economy	14800.00
0005434312392	3626	Economy	14800.00
0005434312391	3626	Economy	14800.00
0005434325954	3626	Economy	14800.00
0005435890015	3626	Economy	14800.00
0005434325955	3626	Economy	14800.00
0005434325953	3626	Economy	14800.00
0005434325951	3626	Economy	14800.00
0005434325952	3626	Economy	14800.00
0005434325957	3626	Economy	14800.00
0005434312375	3626	Economy	14800.00
0005435890004	3626	Economy	14800.00
0005434325811	15628	Economy	16300.00
0005434325822	15628	Economy	14800.00
0005435890055	15628	Economy	14800.00
0005434325835	15628	Economy	14800.00
0005434325834	15628	Economy	14800.00
0005434325894	15628	Economy	14800.00
0005435890058	15628	Economy	14800.00
0005434325868	15628	Economy	14800.00
0005435890056	15628	Economy	14800.00
0005435890057	15628	Economy	14800.00
0005435890059	15628	Economy	14800.00
0005434325821	15628	Economy	14800.00
0005434325836	15628	Economy	14800.00
0005434325840	15628	Economy	14800.00
0005434325866	15628	Economy	14800.00
0005434325869	15628	Economy	14800.00
0005435958086	621	Economy	4500.00
0005433420589	621	Economy	4500.00
0005433420551	621	Economy	4100.00
0005435958095	621	Economy	4100.00
0005433420537	621	Economy	4100.00
0005433420570	621	Economy	4100.00
0005435958097	621	Economy	4100.00
0005435958090	621	Economy	4100.00
0005435958091	621	Economy	4100.00
0005433420588	621	Economy	4100.00
0005433420550	621	Economy	4100.00
0005435958088	621	Economy	4100.00
0005435958094	621	Economy	4100.00
0005435958089	621	Economy	4100.00
0005435958093	621	Economy	4100.00
0005435958096	621	Economy	4100.00
0005433420560	621	Economy	4100.00
0005435958098	621	Economy	4100.00
0005435958092	621	Economy	4100.00
0005433420567	621	Economy	4100.00
0005433420552	621	Economy	4100.00
0005433420577	621	Economy	4100.00
0005435958085	621	Economy	4100.00
0005433420571	621	Economy	4100.00
0005435958087	621	Economy	4100.00
0005433420553	621	Economy	4100.00
0005435957915	15162	Economy	4500.00
0005433420627	15162	Economy	4100.00
0005433420629	15162	Economy	4100.00
0005435958003	15162	Economy	4100.00
0005435958005	15162	Economy	4100.00
0005435958033	15162	Economy	4100.00
0005435957995	15162	Economy	4100.00
0005435957902	15162	Economy	4100.00
0005433420624	15162	Economy	4100.00
0005435958031	15162	Economy	4100.00
0005435958013	15162	Economy	4100.00
0005435957916	15162	Economy	4100.00
0005435958032	15162	Economy	4100.00
0005433420625	15162	Economy	4100.00
0005433420626	15162	Economy	4100.00
0005435958004	15162	Economy	4100.00
0005435957960	15162	Economy	4100.00
0005435958020	15162	Economy	4100.00
0005433420628	15162	Economy	4100.00
0005435957978	15162	Economy	4100.00
0005434995329	24001	Business	94000.00
0005434995332	24001	Business	94000.00
0005434995331	24001	Economy	31300.00
0005434995319	24001	Economy	31300.00
0005434995334	24001	Economy	34500.00
0005434995333	24001	Economy	31300.00
0005434995338	24001	Economy	31300.00
0005434995328	24001	Economy	31300.00
0005434995326	24001	Economy	31300.00
0005434995320	24001	Economy	31300.00
0005434995330	24001	Economy	31300.00
0005434995327	24001	Economy	31300.00
0005434995321	24001	Economy	31300.00
0005434247189	8843	Economy	10400.00
0005435629443	8843	Economy	10400.00
0005435629444	8843	Economy	10400.00
0005435629442	8843	Economy	10400.00
0005434247183	8843	Economy	10400.00
0005434247196	8843	Economy	10400.00
0005435629428	16037	Economy	10400.00
0005435629425	16037	Economy	10400.00
0005434247216	16037	Economy	10400.00
0005435797849	2842	Business	12600.00
0005435797859	2842	Business	12600.00
0005435797850	2842	Business	12600.00
0005435797856	2842	Business	12600.00
0005435797855	2842	Economy	4200.00
0005435797857	2842	Economy	4200.00
0005433404974	2842	Economy	4200.00
0005435797847	2842	Economy	4200.00
0005435797844	2842	Economy	4200.00
0005435797852	2842	Economy	4200.00
0005435797858	2842	Economy	4200.00
0005435797848	2842	Economy	4200.00
0005433404945	2842	Economy	4200.00
0005435797845	2842	Economy	4200.00
0005433404942	2842	Economy	4200.00
0005433404929	2842	Economy	4200.00
0005433404956	2842	Economy	4200.00
0005433404941	2842	Economy	4200.00
0005433404917	2842	Economy	4200.00
0005433404973	2842	Economy	4200.00
0005435797846	2842	Economy	4200.00
0005435797853	2842	Economy	4200.00
0005435797854	2842	Economy	4200.00
0005433404940	2842	Economy	4200.00
0005435797851	2842	Economy	4200.00
0005433405009	29298	Business	12600.00
0005435797756	29298	Business	12600.00
0005433405005	29298	Business	12600.00
0005435797759	29298	Economy	4200.00
0005433405004	29298	Economy	4200.00
0005433405003	29298	Economy	4600.00
0005435797760	29298	Economy	4600.00
0005435797757	29298	Economy	4600.00
0005433405006	29298	Economy	4200.00
0005433405008	29298	Economy	4200.00
0005433405007	29298	Economy	4200.00
0005433405010	29298	Economy	4200.00
0005435797711	29298	Economy	4200.00
0005435797740	29298	Economy	4200.00
0005435797701	29298	Economy	4200.00
0005435376392	5813	Economy	6800.00
0005435376403	5813	Economy	6800.00
0005435376404	5813	Economy	6800.00
0005434948241	5773	Economy	6800.00
0005434948244	5773	Economy	6800.00
0005434948243	5773	Economy	6800.00
0005434948240	5773	Economy	6800.00
0005434948242	5773	Economy	6800.00
0005434948245	5773	Economy	6800.00
0005435376419	16369	Economy	6800.00
0005434948153	16369	Economy	6800.00
0005434948181	16369	Economy	6800.00
0005434948184	16369	Economy	6800.00
0005434948189	16369	Economy	6800.00
0005434948154	16369	Economy	6800.00
0005434948156	16369	Economy	6800.00
0005434948155	16369	Economy	6800.00
0005434948152	16369	Economy	6800.00
0005434948173	16369	Economy	6800.00
0005434948149	16369	Economy	6800.00
0005434948188	16369	Economy	6800.00
0005433962433	6870	Business	21400.00
0005433962419	6870	Business	21400.00
0005433962387	6870	Business	21400.00
0005433962432	6870	Business	21400.00
0005433962440	6870	Business	21400.00
0005433962405	6870	Business	21400.00
0005433962438	6870	Business	21400.00
0005433962408	6870	Business	21400.00
0005433962455	6870	Economy	7100.00
0005433962398	6870	Economy	7100.00
0005433962388	6870	Economy	7100.00
0005433962452	6870	Economy	7100.00
0005433962428	6870	Economy	7100.00
0005433962399	6870	Economy	7100.00
0005433962404	6870	Economy	7100.00
0005433962443	6870	Economy	7100.00
0005433962445	6870	Economy	7800.00
0005433962410	6870	Economy	7800.00
0005433962401	6870	Economy	7800.00
0005433962415	6870	Economy	7800.00
0005433962424	6870	Economy	7800.00
0005433962403	6870	Economy	7100.00
0005433962422	6870	Economy	7100.00
0005433962450	6870	Economy	7100.00
0005433962437	6870	Economy	7100.00
0005433962441	6870	Economy	7100.00
0005433962407	6870	Economy	7100.00
0005433962412	6870	Economy	7100.00
0005433962421	6870	Economy	7100.00
0005433962414	6870	Economy	7100.00
0005433962413	6870	Economy	7100.00
0005433962400	6870	Economy	7100.00
0005433962429	6870	Economy	7100.00
0005433962449	6870	Economy	7100.00
0005433962418	6870	Economy	7100.00
0005433962447	6870	Economy	7100.00
0005433962451	6870	Economy	7100.00
0005433962386	6870	Economy	7100.00
0005433962394	6870	Economy	7100.00
0005433962396	6870	Economy	7100.00
0005433962397	6870	Economy	7100.00
0005433962382	6870	Economy	7100.00
0005433962453	6870	Economy	7100.00
0005433962420	6870	Economy	7100.00
0005433962436	6870	Economy	7100.00
0005433962439	6870	Economy	7100.00
0005433962383	6870	Economy	7100.00
0005433962430	6870	Economy	7100.00
0005433962425	6870	Economy	7100.00
0005433962431	6870	Economy	7100.00
0005433962446	6870	Economy	7100.00
0005433962393	6870	Economy	7100.00
0005433962427	6870	Economy	7100.00
0005433962391	6870	Economy	7100.00
0005433962389	6870	Economy	7100.00
0005433962434	6870	Economy	7100.00
0005433962392	6870	Economy	7100.00
0005433962448	6870	Economy	7100.00
0005433962442	6870	Economy	7100.00
0005433962411	6870	Economy	7100.00
0005433962454	6870	Economy	7100.00
0005433962417	6870	Economy	7100.00
0005433962426	6870	Economy	7100.00
0005433962395	6870	Economy	7100.00
0005433962402	6870	Economy	7100.00
0005433962435	6870	Economy	7100.00
0005433962409	6870	Economy	7100.00
0005433962384	6870	Economy	7100.00
0005433962423	6870	Economy	7100.00
0005433962385	6870	Economy	7100.00
0005433962406	6870	Economy	7100.00
0005433962444	6870	Economy	7100.00
0005433962390	6870	Economy	7100.00
0005433962416	6870	Economy	7100.00
0005433961835	25719	Business	21400.00
0005433961695	25719	Business	21400.00
0005433961733	25719	Business	21400.00
0005433961664	25719	Business	21400.00
0005433961698	25719	Business	21400.00
0005433961590	25719	Business	21400.00
0005433961740	25719	Business	21400.00
0005433961727	25719	Business	21400.00
0005433961722	25719	Economy	7100.00
0005433961683	25719	Economy	7100.00
0005433961801	25719	Economy	7100.00
0005433961817	25719	Economy	7100.00
0005433961676	25719	Economy	7100.00
0005433961751	25719	Economy	7800.00
0005433961791	25719	Economy	7800.00
0005433961805	25719	Economy	7800.00
0005433961841	25719	Economy	7800.00
0005433961776	25719	Economy	7800.00
0005433961792	25719	Economy	7100.00
0005433961690	25719	Economy	7100.00
0005433961618	25719	Economy	7100.00
0005433961762	25719	Economy	7100.00
0005433961630	25719	Economy	7100.00
0005433961696	25719	Economy	7100.00
0005433961593	25719	Economy	7100.00
0005433961842	25719	Economy	7100.00
0005433961793	25719	Economy	7100.00
0005433961707	25719	Economy	7100.00
0005433961594	25719	Economy	7100.00
0005433961679	25719	Economy	7100.00
0005433961697	25719	Economy	7100.00
0005433961734	25719	Economy	7100.00
0005433961642	25719	Economy	7100.00
0005433961827	25719	Economy	7100.00
0005433961622	25719	Economy	7100.00
0005433961798	25719	Economy	7100.00
0005433961713	25719	Economy	7100.00
0005433961658	25719	Economy	7100.00
0005433961623	25719	Economy	7100.00
0005433961641	25719	Economy	7100.00
0005433961678	25719	Economy	7100.00
0005433961837	25719	Economy	7100.00
0005433961729	25719	Economy	7100.00
0005433961546	25719	Economy	7100.00
0005433961516	25719	Economy	7100.00
0005433961699	25719	Economy	7100.00
0005433961785	25719	Economy	7100.00
0005433961790	25719	Economy	7100.00
0005433961720	25719	Economy	7100.00
0005433961680	25719	Economy	7100.00
0005433961732	25719	Economy	7100.00
0005433961750	25719	Economy	7100.00
0005433961662	25719	Economy	7100.00
0005433961775	25719	Economy	7100.00
0005433961843	25719	Economy	7100.00
0005433961657	25719	Economy	7100.00
0005433961721	25719	Economy	7100.00
0005433961661	25719	Economy	7100.00
0005433961652	25719	Economy	7100.00
0005433961583	25719	Economy	7100.00
0005433961761	25719	Economy	7100.00
0005433961818	25719	Economy	7100.00
0005433961765	25719	Economy	7100.00
0005435082910	24446	Economy	3900.00
0005435082926	24446	Economy	3900.00
0005435082925	24446	Economy	3900.00
0005435082929	24446	Economy	3900.00
0005435082901	24446	Economy	3900.00
0005435082908	24446	Economy	3900.00
0005435082931	24446	Economy	3900.00
0005435082907	24446	Economy	3900.00
0005435082906	24446	Economy	3900.00
0005435082941	24446	Economy	3900.00
0005435082940	24446	Economy	3900.00
0005435082993	26040	Economy	3900.00
0005435082990	26040	Economy	3900.00
0005435082994	26040	Economy	3900.00
0005435082996	26040	Economy	3900.00
0005435082989	26040	Economy	3900.00
0005435082991	26040	Economy	3900.00
0005435082995	26040	Economy	3900.00
0005435082992	26040	Economy	3900.00
0005434245757	5024	Business	18000.00
0005434245756	5024	Business	18000.00
0005433534530	5024	Business	18000.00
0005435286707	5024	Business	18000.00
0005435286733	5024	Business	18000.00
0005434245764	5024	Economy	6600.00
0005432166988	5024	Economy	6600.00
0005434245744	5024	Economy	6000.00
0005434245749	5024	Economy	6000.00
0005435286734	5024	Economy	6000.00
0005434245753	5024	Economy	6000.00
0005434245761	5024	Economy	6000.00
0005434245754	5024	Economy	6000.00
0005434245747	5024	Economy	6000.00
0005434245752	5024	Economy	6000.00
0005434245765	5024	Economy	6000.00
0005432166987	5024	Economy	6000.00
0005434245748	5024	Economy	6000.00
0005434245755	5024	Economy	6000.00
0005434245746	5024	Economy	6000.00
0005434245750	5024	Economy	6000.00
0005434245763	5024	Economy	6600.00
0005434245751	5024	Economy	6000.00
0005434245758	5024	Economy	6000.00
0005435286694	5024	Economy	6000.00
0005434245762	5024	Economy	6000.00
0005434245767	5024	Economy	6000.00
0005434245766	5024	Economy	6000.00
0005434245745	5024	Economy	6000.00
0005434245760	5024	Economy	6000.00
0005434245759	5024	Economy	6000.00
0005435286712	5024	Economy	6000.00
0005433616618	5032	Business	18000.00
0005433785952	5032	Business	18000.00
0005432106820	5032	Business	18000.00
0005433616630	5032	Business	18000.00
0005433785942	5032	Business	18000.00
0005433616644	5032	Business	18000.00
0005433785961	5032	Business	18000.00
0005432106810	5032	Business	18000.00
0005433616635	5032	Business	18000.00
0005433616656	5032	Business	18000.00
0005433616651	5032	Business	18000.00
0005433616622	5032	Business	18000.00
0005433616602	5032	Business	18000.00
0005433616632	5032	Business	18000.00
0005433616617	5032	Business	18000.00
0005432106811	5032	Business	18000.00
0005433616601	5032	Business	18000.00
0005433785968	5032	Business	18000.00
0005433785970	5032	Business	18000.00
0005433785923	5032	Business	18000.00
0005433785956	5032	Business	18000.00
0005433785969	5032	Business	18000.00
0005432106835	5032	Business	18000.00
0005433785977	5032	Business	18000.00
0005433785966	5032	Business	18000.00
0005433785963	5032	Business	18000.00
0005433616611	5032	Business	18000.00
0005433785975	5032	Business	18000.00
0005432106823	5032	Economy	6600.00
0005433785964	5032	Economy	6600.00
0005432106831	5032	Economy	6600.00
0005433785940	5032	Economy	6600.00
0005433616637	5032	Economy	6600.00
0005432106827	5032	Economy	6600.00
0005433616610	5032	Economy	6000.00
0005433785967	5032	Economy	6000.00
0005433616603	5032	Economy	6000.00
0005433616655	5032	Economy	6000.00
0005433785979	5032	Economy	6000.00
0005433616642	5032	Economy	6000.00
0005433785973	5032	Economy	6000.00
0005433785921	5032	Economy	6000.00
0005432145165	5032	Economy	6000.00
0005433785919	5032	Economy	6000.00
0005433785915	5032	Economy	6000.00
0005432106805	5032	Economy	6000.00
0005432106830	5032	Economy	6000.00
0005432106834	5032	Economy	6000.00
0005433616620	5032	Economy	6000.00
0005433616631	5032	Economy	6000.00
0005433616609	5032	Economy	6000.00
0005432106817	5032	Economy	6000.00
0005433785960	5032	Economy	6000.00
0005433785925	5032	Economy	6000.00
0005433616628	5032	Economy	6000.00
0005433785949	5032	Economy	6000.00
0005433616616	5032	Economy	6000.00
0005432106808	5032	Economy	6000.00
0005432106832	5032	Economy	6000.00
0005433616613	5032	Economy	6000.00
0005433785943	5032	Economy	6000.00
0005433616650	5032	Economy	6000.00
0005433785976	5032	Economy	6000.00
0005432106812	5032	Economy	6000.00
0005433616605	5032	Economy	6000.00
0005432106839	5032	Economy	6000.00
0005433785920	5032	Economy	6000.00
0005433785929	5032	Economy	6000.00
0005433785936	5032	Economy	6000.00
0005433616658	5032	Economy	6000.00
0005432106822	5032	Economy	6000.00
0005433785935	5032	Economy	6000.00
0005433785978	5032	Economy	6000.00
0005432106813	5032	Economy	6000.00
0005432667509	5032	Economy	6000.00
0005433616599	5032	Economy	6000.00
0005433785934	5032	Economy	6000.00
0005432667510	5032	Economy	6000.00
0005433616652	5032	Economy	6000.00
0005433785916	5032	Economy	6000.00
0005433785937	5032	Economy	6000.00
0005433616612	5032	Economy	6000.00
0005433616640	5032	Economy	6000.00
0005433616641	5032	Economy	6000.00
0005432106816	5032	Economy	6000.00
0005433785927	5032	Economy	6000.00
0005433616646	5032	Economy	6000.00
0005432106807	5032	Economy	6000.00
0005432106829	5032	Economy	6000.00
0005433616653	5032	Economy	6000.00
0005433616633	5032	Economy	6000.00
0005433785972	5032	Economy	6000.00
0005433785954	5032	Economy	6000.00
0005433616643	5032	Economy	6000.00
0005432106828	5032	Economy	6600.00
0005433785965	5032	Economy	6600.00
0005433785933	5032	Economy	6600.00
0005433785958	5032	Economy	6600.00
0005433785957	5032	Economy	6600.00
0005432106838	5032	Economy	6000.00
0005433785922	5032	Economy	6000.00
0005433616623	5032	Economy	6000.00
0005432106821	5032	Economy	6000.00
0005433616647	5032	Economy	6600.00
0005433785948	5032	Economy	6000.00
0005432106836	5032	Economy	6000.00
0005433785932	5032	Economy	6000.00
0005432106833	5032	Economy	6000.00
0005433785951	5032	Economy	6000.00
0005433616648	5032	Economy	6000.00
0005433616624	5032	Economy	6000.00
0005433785974	5032	Economy	6000.00
0005432106814	5032	Economy	6000.00
0005433616608	5032	Economy	6000.00
0005433616621	5032	Economy	6000.00
0005432106837	5032	Economy	6000.00
0005432106826	5032	Economy	6000.00
0005433785947	5032	Economy	6000.00
0005433785928	5032	Economy	6000.00
0005432145164	5032	Economy	6000.00
0005432106819	5032	Economy	6000.00
0005432106824	5032	Economy	6000.00
0005432665330	5032	Economy	6000.00
0005433785931	5032	Economy	6000.00
0005432106815	5032	Economy	6000.00
0005433616649	5032	Economy	6000.00
0005433616645	5032	Economy	6000.00
0005433616619	5032	Economy	6000.00
0005433785938	5032	Economy	6000.00
0005433785971	5032	Economy	6000.00
0005433785918	5032	Economy	6000.00
0005433785945	5032	Economy	6000.00
0005433785980	5032	Economy	6000.00
0005432106806	5032	Economy	6000.00
0005433785950	5032	Economy	6000.00
0005433616654	5032	Economy	6000.00
0005433616657	5032	Economy	6000.00
0005433616614	5032	Economy	6000.00
0005433785946	5032	Economy	6000.00
0005433616638	5032	Economy	6000.00
0005433616625	5032	Economy	6000.00
0005432106809	5032	Economy	6000.00
0005433616607	5032	Economy	6000.00
0005433616639	5032	Economy	6000.00
0005432106818	5032	Economy	6000.00
0005433616606	5032	Economy	6000.00
0005433785955	5032	Economy	6000.00
0005432106825	5032	Economy	6000.00
0005433785944	5032	Economy	6000.00
0005433785953	5032	Economy	6000.00
0005432665328	5032	Economy	6000.00
0005433616626	5032	Economy	6000.00
0005433785930	5032	Economy	6000.00
0005433616600	5032	Economy	6000.00
0005433616604	5032	Economy	6000.00
0005433616615	5032	Economy	6000.00
0005432666442	5032	Economy	6000.00
0005433785959	5032	Economy	6000.00
0005433785939	5032	Economy	6000.00
0005433785917	5032	Economy	6000.00
0005432665329	5032	Economy	6000.00
0005433785941	5032	Economy	6000.00
0005432666443	5032	Economy	6000.00
0005433785924	5032	Economy	6000.00
0005433616627	5032	Economy	6000.00
0005433785926	5032	Economy	6000.00
0005433616629	5032	Economy	6000.00
0005433616636	5032	Economy	6000.00
0005433785962	5032	Economy	6000.00
0005433616634	5032	Economy	6000.00
0005434229956	5039	Business	18000.00
0005434312357	5039	Business	18000.00
0005435007442	5039	Business	18000.00
0005434265819	5039	Business	18000.00
0005434265822	5039	Business	18000.00
0005432336239	5039	Business	18000.00
0005434265814	5039	Business	18000.00
0005433815467	5039	Business	18000.00
0005434229971	5039	Business	18000.00
0005434229961	5039	Business	18000.00
0005433688834	5039	Business	18000.00
0005434265818	5039	Business	18000.00
0005432336279	5039	Business	18000.00
0005433685563	5039	Business	18000.00
0005434265825	5039	Business	18000.00
0005435007435	5039	Business	18000.00
0005434265812	5039	Business	18000.00
0005434229965	5039	Business	18000.00
0005433815468	5039	Business	18000.00
0005434150049	5039	Economy	6600.00
0005432336243	5039	Business	18000.00
0005435007419	5039	Economy	6600.00
0005435007295	5039	Economy	6600.00
0005434265810	5039	Economy	6600.00
0005432336262	5039	Economy	6000.00
0005435007412	5039	Economy	6000.00
0005435007474	5039	Economy	6000.00
0005435007475	5039	Economy	6000.00
0005434150046	5039	Economy	6000.00
0005432336226	5039	Economy	6000.00
0005434229969	5039	Economy	6000.00
0005434265813	5039	Economy	6000.00
0005434229968	5039	Economy	6000.00
0005434150048	5039	Economy	6000.00
0005432336252	5039	Economy	6000.00
0005434229955	5039	Economy	6000.00
0005435007490	5039	Economy	6000.00
0005434150042	5039	Economy	6000.00
0005434229964	5039	Economy	6000.00
0005435007388	5039	Economy	6000.00
0005433815475	5039	Economy	6000.00
0005433685562	5039	Economy	6000.00
0005434265820	5039	Economy	6000.00
0005434229975	5039	Economy	6000.00
0005434229966	5039	Economy	6000.00
0005434173655	5039	Economy	6000.00
0005434229963	5039	Economy	6000.00
0005434229967	5039	Economy	6000.00
0005435007296	5039	Economy	6000.00
0005435007492	5039	Economy	6000.00
0005435007360	5039	Economy	6000.00
0005434229974	5039	Economy	6000.00
0005432336281	5039	Economy	6000.00
0005434229960	5039	Economy	6000.00
0005434150039	5039	Economy	6000.00
0005435007440	5039	Economy	6000.00
0005433815474	5039	Economy	6000.00
0005434265823	5039	Economy	6000.00
0005434150045	5039	Economy	6000.00
0005434150040	5039	Economy	6000.00
0005435007491	5039	Economy	6000.00
0005434311261	5039	Economy	6000.00
0005432336214	5039	Economy	6000.00
0005434229976	5039	Economy	6000.00
0005433815470	5039	Economy	6000.00
0005434173625	5039	Economy	6600.00
0005434229959	5039	Economy	6600.00
0005433815469	5039	Economy	6600.00
0005434173653	5039	Economy	6600.00
0005434265826	5039	Economy	6000.00
0005434150044	5039	Economy	6000.00
0005434229973	5039	Economy	6000.00
0005434150043	5039	Economy	6600.00
0005435007522	5039	Economy	6000.00
0005434229962	5039	Economy	6000.00
0005435007433	5039	Economy	6000.00
0005435007486	5039	Economy	6000.00
0005434229958	5039	Economy	6000.00
0005434265816	5039	Economy	6000.00
0005435007411	5039	Economy	6000.00
0005434265808	5039	Economy	6000.00
0005434265815	5039	Economy	6000.00
0005434150047	5039	Economy	6000.00
0005434265809	5039	Economy	6000.00
0005432336278	5039	Economy	6000.00
0005435007441	5039	Economy	6000.00
0005432336227	5039	Economy	6000.00
0005435007454	5039	Economy	6000.00
0005434229972	5039	Economy	6000.00
0005432336280	5039	Economy	6000.00
0005434150041	5039	Economy	6000.00
0005432336225	5039	Economy	6000.00
0005435007361	5039	Economy	6000.00
0005432336254	5039	Economy	6000.00
0005434265824	5039	Economy	6000.00
0005434229957	5039	Economy	6000.00
0005434265828	5039	Economy	6000.00
0005434265811	5039	Economy	6000.00
0005435007453	5039	Economy	6000.00
0005434173627	5039	Economy	6000.00
0005432336274	5039	Economy	6000.00
0005432336213	5039	Economy	6000.00
0005435007272	5039	Economy	6000.00
0005434229970	5039	Economy	6000.00
0005434265821	5039	Economy	6000.00
0005435007434	5039	Economy	6000.00
0005434229977	5039	Economy	6000.00
0005434265827	5039	Economy	6000.00
0005432336237	5039	Economy	6000.00
0005433685564	5039	Economy	6000.00
0005433688835	5039	Economy	6000.00
0005432336253	5039	Economy	6000.00
0005435007294	5039	Economy	6000.00
0005432336285	5039	Economy	6000.00
0005434311258	5039	Economy	6000.00
0005434173626	5039	Economy	6000.00
0005435007385	5039	Economy	6000.00
0005435007487	5039	Economy	6000.00
0005434265817	5039	Economy	6000.00
0005434173654	5039	Economy	6000.00
0005435007387	5039	Economy	6000.00
0005434173628	5039	Economy	6000.00
0005435007384	5039	Economy	6000.00
0005434245477	8425	Business	18000.00
0005432659741	8425	Business	18000.00
0005435270094	8425	Business	18000.00
0005433785413	8425	Business	18000.00
0005434245476	8425	Business	18000.00
0005433785630	8425	Business	18000.00
0005433785700	8425	Business	18000.00
0005433785656	8425	Business	18000.00
0005433785653	8425	Business	18000.00
0005433785414	8425	Business	18000.00
0005433785472	8425	Business	18000.00
0005435270096	8425	Business	18000.00
0005434245548	8425	Business	18000.00
0005433785497	8425	Business	18000.00
0005433785602	8425	Business	18000.00
0005435270100	8425	Business	18000.00
0005433785523	8425	Economy	6600.00
0005434245519	8425	Economy	6600.00
0005435270102	8425	Economy	6600.00
0005432663063	8425	Economy	6600.00
0005435270097	8425	Economy	6000.00
0005434245577	8425	Economy	6000.00
0005434245418	8425	Economy	6000.00
0005433785676	8425	Economy	6000.00
0005433785726	8425	Economy	6000.00
0005435270104	8425	Economy	6000.00
0005435270106	8425	Economy	6000.00
0005433785495	8425	Economy	6000.00
0005433785420	8425	Economy	6000.00
0005433785419	8425	Economy	6000.00
0005433785451	8425	Economy	6000.00
0005434245620	8425	Economy	6000.00
0005434245454	8425	Economy	6000.00
0005433785436	8425	Economy	6000.00
0005433785450	8425	Economy	6000.00
0005433785418	8425	Economy	6000.00
0005433785524	8425	Economy	6000.00
0005433785518	8425	Economy	6000.00
0005433785568	8425	Economy	6000.00
0005433785616	8425	Economy	6000.00
0005433785566	8425	Economy	6000.00
0005433785647	8425	Economy	6000.00
0005435270093	8425	Economy	6000.00
0005433785559	8425	Economy	6000.00
0005433785671	8425	Economy	6000.00
0005434245521	8425	Economy	6000.00
0005434245518	8425	Economy	6000.00
0005435270099	8425	Economy	6000.00
0005433785473	8425	Economy	6000.00
0005434245549	8425	Economy	6000.00
0005435270089	8425	Economy	6000.00
0005432659739	8425	Economy	6000.00
0005433785578	8425	Economy	6000.00
0005435270090	8425	Economy	6000.00
0005433785677	8425	Economy	6600.00
0005433785546	8425	Economy	6600.00
0005433785615	8425	Economy	6600.00
0005433785496	8425	Economy	6000.00
0005435270092	8425	Economy	6000.00
0005433785526	8425	Economy	6000.00
0005434245607	8425	Economy	6000.00
0005435270105	8425	Economy	6000.00
0005433785579	8425	Economy	6000.00
0005433785748	8425	Economy	6000.00
0005434245421	8425	Economy	6000.00
0005433785527	8425	Economy	6000.00
0005434245520	8425	Economy	6000.00
0005435270101	8425	Economy	6000.00
0005432659735	8425	Economy	6000.00
0005432659743	8425	Economy	6000.00
0005433785749	8425	Economy	6000.00
0005435270088	8425	Economy	6000.00
0005433785421	8425	Economy	6000.00
0005433785608	8425	Economy	6000.00
0005433785541	8425	Economy	6000.00
0005433785528	8425	Economy	6000.00
0005433785678	8425	Economy	6000.00
0005433785582	8425	Economy	6000.00
0005432663062	8425	Economy	6000.00
0005433785567	8425	Economy	6000.00
0005435270098	8425	Economy	6000.00
0005433785529	8425	Economy	6000.00
0005433785594	8425	Economy	6000.00
0005435270103	8425	Economy	6000.00
0005435270107	8425	Economy	6000.00
0005433785725	8425	Economy	6000.00
0005433785511	8425	Economy	6000.00
0005432659738	8425	Economy	6000.00
0005433785462	8425	Economy	6000.00
0005433785437	8425	Economy	6000.00
0005432659744	8425	Economy	6000.00
0005433785573	8425	Economy	6000.00
0005433785583	8425	Economy	6000.00
0005432659740	8425	Economy	6000.00
0005433785652	8425	Economy	6000.00
0005433785631	8425	Economy	6000.00
0005435270091	8425	Economy	6000.00
0005433785525	8425	Economy	6000.00
0005435270095	8425	Economy	6000.00
0005433785701	8425	Economy	6000.00
0005434245568	8425	Economy	6000.00
0005433615753	8426	Business	18000.00
0005433615797	8426	Business	18000.00
0005433615442	8426	Business	18000.00
0005433616169	8426	Business	18000.00
0005433616006	8426	Business	18000.00
0005433615820	8426	Business	18000.00
0005433616133	8426	Business	18000.00
0005433615593	8426	Business	18000.00
0005433615880	8426	Business	18000.00
0005433615968	8426	Business	18000.00
0005433615966	8426	Business	18000.00
0005433616141	8426	Economy	6600.00
0005433615961	8426	Economy	6600.00
0005433615752	8426	Economy	6600.00
0005433616132	8426	Economy	6000.00
0005433615908	8426	Economy	6000.00
0005433615772	8426	Economy	6000.00
0005433615598	8426	Economy	6000.00
0005433615964	8426	Economy	6000.00
0005433616030	8426	Economy	6000.00
0005433615824	8426	Economy	6000.00
0005433615661	8426	Economy	6000.00
0005433615996	8426	Economy	6000.00
0005433615856	8426	Economy	6000.00
0005433615771	8426	Economy	6000.00
0005433615804	8426	Economy	6000.00
0005433615756	8426	Economy	6000.00
0005433616103	8426	Economy	6000.00
0005433616074	8426	Economy	6000.00
0005433615920	8426	Economy	6000.00
0005433616130	8426	Economy	6000.00
0005433616331	8426	Economy	6000.00
0005433616155	8426	Economy	6000.00
0005433616278	8426	Economy	6000.00
0005433615904	8426	Economy	6000.00
0005433615833	8426	Economy	6000.00
0005433615779	8426	Economy	6000.00
0005433616125	8426	Economy	6000.00
0005433615795	8426	Economy	6000.00
0005433615907	8426	Economy	6000.00
0005433615770	8426	Economy	6000.00
0005433616056	8426	Economy	6000.00
0005433616170	8426	Economy	6000.00
0005433615755	8426	Economy	6000.00
0005433615938	8426	Economy	6600.00
0005433615951	8426	Economy	6600.00
0005433615811	8426	Economy	6600.00
0005433615794	8426	Economy	6000.00
0005433616134	8426	Economy	6000.00
0005433615906	8426	Economy	6000.00
0005433615958	8426	Economy	6000.00
0005433615882	8426	Economy	6000.00
0005433615860	8426	Economy	6000.00
0005433616330	8426	Economy	6000.00
0005433615798	8426	Economy	6000.00
0005433616096	8426	Economy	6000.00
0005433615697	8426	Economy	6000.00
0005433615921	8426	Economy	6000.00
0005433615984	8426	Economy	6000.00
0005433615965	8426	Economy	6000.00
0005433616131	8426	Economy	6000.00
0005433615969	8426	Economy	6000.00
0005433616034	8426	Economy	6000.00
0005433615983	8426	Economy	6000.00
0005433615796	8426	Economy	6000.00
0005433615932	8426	Economy	6000.00
0005433615754	8426	Economy	6000.00
0005433615933	8426	Economy	6000.00
0005433615934	8426	Economy	6000.00
0005433615878	8426	Economy	6000.00
0005433615761	8426	Economy	6000.00
0005433615696	8426	Economy	6000.00
0005433616033	8426	Economy	6000.00
0005432336347	8427	Business	18000.00
0005435286789	8427	Business	18000.00
0005435286781	8427	Business	18000.00
0005432035680	8427	Business	18000.00
0005434229802	8427	Business	18000.00
0005434265607	8427	Business	18000.00
0005434265564	8427	Business	18000.00
0005434311288	8427	Business	18000.00
0005435007635	8427	Business	18000.00
0005434265591	8427	Business	18000.00
0005432035689	8427	Business	18000.00
0005435007647	8427	Business	18000.00
0005432035691	8427	Business	18000.00
0005434229761	8427	Business	18000.00
0005434229764	8427	Business	18000.00
0005435007634	8427	Business	18000.00
0005434149990	8427	Business	18000.00
0005434229791	8427	Business	18000.00
0005434265671	8427	Business	18000.00
0005432336351	8427	Business	18000.00
0005435007649	8427	Business	18000.00
0005432336355	8427	Business	18000.00
0005432035678	8427	Business	18000.00
0005435007642	8427	Business	18000.00
0005434229790	8427	Business	18000.00
0005435007652	8427	Business	18000.00
0005434229829	8427	Business	18000.00
0005434229830	8427	Business	18000.00
0005435286779	8427	Economy	6600.00
0005432035672	8427	Economy	6600.00
0005434149912	8427	Economy	6600.00
0005434265606	8427	Economy	6600.00
0005435286776	8427	Economy	6600.00
0005434149992	8427	Economy	6600.00
0005432336346	8427	Economy	6000.00
0005432336353	8427	Economy	6000.00
0005433534554	8427	Economy	6000.00
0005434149965	8427	Economy	6000.00
0005434265599	8427	Economy	6000.00
0005434265695	8427	Economy	6000.00
0005435007636	8427	Economy	6000.00
0005435007648	8427	Economy	6000.00
0005434229747	8427	Economy	6000.00
0005434229710	8427	Economy	6000.00
0005435286791	8427	Economy	6000.00
0005432336354	8427	Economy	6000.00
0005432336357	8427	Economy	6000.00
0005435007650	8427	Economy	6000.00
0005433690979	8427	Economy	6000.00
0005435286784	8427	Economy	6000.00
0005434229867	8427	Economy	6000.00
0005434265477	8427	Economy	6000.00
0005433690980	8427	Economy	6000.00
0005433689966	8427	Economy	6000.00
0005432035677	8427	Economy	6000.00
0005434149907	8427	Economy	6000.00
0005435007653	8427	Economy	6000.00
0005435286790	8427	Economy	6000.00
0005432336352	8427	Economy	6000.00
0005432035682	8427	Economy	6000.00
0005434173573	8427	Economy	6000.00
0005434265523	8427	Economy	6000.00
0005435286777	8427	Economy	6000.00
0005434229842	8427	Economy	6000.00
0005432035673	8427	Economy	6000.00
0005433815554	8427	Economy	6000.00
0005432035692	8427	Economy	6000.00
0005434265694	8427	Economy	6000.00
0005434173588	8427	Economy	6000.00
0005435007640	8427	Economy	6000.00
0005434265670	8427	Economy	6000.00
0005434311273	8427	Economy	6000.00
0005435007646	8427	Economy	6000.00
0005434265513	8427	Economy	6000.00
0005432047651	8427	Economy	6000.00
0005434265600	8427	Economy	6000.00
0005432035693	8427	Economy	6000.00
0005434311272	8427	Economy	6000.00
0005434229701	8427	Economy	6000.00
0005435286778	8427	Economy	6000.00
0005434149973	8427	Economy	6000.00
0005435007654	8427	Economy	6000.00
0005433815514	8427	Economy	6000.00
0005435007651	8427	Economy	6000.00
0005434265530	8427	Economy	6000.00
0005434229733	8427	Economy	6000.00
0005434229763	8427	Economy	6000.00
0005435007655	8427	Economy	6000.00
0005432336349	8427	Economy	6000.00
0005432035684	8427	Economy	6000.00
0005432035685	8427	Economy	6000.00
0005434149991	8427	Economy	6000.00
0005432035676	8427	Economy	6000.00
0005432336348	8427	Economy	6000.00
0005434229697	8427	Economy	6600.00
0005435286775	8427	Economy	6600.00
0005432035690	8427	Economy	6600.00
0005435007643	8427	Economy	6600.00
0005434229758	8427	Economy	6600.00
0005435286774	8427	Economy	6000.00
0005434229704	8427	Economy	6000.00
0005434229752	8427	Economy	6000.00
0005435286787	8427	Economy	6000.00
0005433815513	8427	Economy	6600.00
0005435286782	8427	Economy	6000.00
0005432035688	8427	Economy	6000.00
0005434229708	8427	Economy	6000.00
0005434265625	8427	Economy	6000.00
0005434229746	8427	Economy	6000.00
0005435286788	8427	Economy	6000.00
0005434265580	8427	Economy	6000.00
0005434265537	8427	Economy	6000.00
0005434229757	8427	Economy	6000.00
0005432035687	8427	Economy	6000.00
0005432035683	8427	Economy	6000.00
0005434149957	8427	Economy	6000.00
0005435007644	8427	Economy	6000.00
0005435007633	8427	Economy	6000.00
0005434265579	8427	Economy	6000.00
0005435286780	8427	Economy	6000.00
0005434265665	8427	Economy	6000.00
0005435007637	8427	Economy	6000.00
0005435007639	8427	Economy	6000.00
0005434229702	8427	Economy	6000.00
0005434173586	8427	Economy	6000.00
0005433815553	8427	Economy	6000.00
0005434265525	8427	Economy	6000.00
0005434311274	8427	Economy	6000.00
0005435286792	8427	Economy	6000.00
0005434229803	8427	Economy	6000.00
0005434229760	8427	Economy	6000.00
0005432035679	8427	Economy	6000.00
0005433815555	8427	Economy	6000.00
0005432035674	8427	Economy	6000.00
0005434229801	8427	Economy	6000.00
0005434265522	8427	Economy	6000.00
0005432035675	8427	Economy	6000.00
0005435286785	8427	Economy	6000.00
0005435007632	8427	Economy	6000.00
0005434229709	8427	Economy	6000.00
0005435007641	8427	Economy	6000.00
0005435286786	8427	Economy	6000.00
0005432035686	8427	Economy	6000.00
0005432336350	8427	Economy	6000.00
0005435286793	8427	Economy	6000.00
0005433534555	8427	Economy	6000.00
0005434149972	8427	Economy	6000.00
0005434265655	8427	Economy	6000.00
0005432336356	8427	Economy	6000.00
0005434265538	8427	Economy	6000.00
0005433815552	8427	Economy	6000.00
0005434265524	8427	Economy	6000.00
0005435007638	8427	Economy	6000.00
0005434149958	8427	Economy	6000.00
0005432035681	8427	Economy	6000.00
0005432035671	8427	Economy	6000.00
0005434229703	8427	Economy	6000.00
0005434265634	8427	Economy	6000.00
0005434229765	8427	Economy	6000.00
0005432047650	8427	Economy	6000.00
0005434149989	8427	Economy	6000.00
0005435286783	8427	Economy	6000.00
0005434229736	8427	Economy	6000.00
0005434149913	8427	Economy	6000.00
0005435007645	8427	Economy	6000.00
0005432035670	8427	Economy	6000.00
0005434639709	12593	Economy	16200.00
0005434639810	12593	Economy	16200.00
0005434639786	12593	Economy	16200.00
0005434639818	12593	Economy	16200.00
0005434639806	12593	Economy	14800.00
0005434639867	12593	Economy	14800.00
0005433202756	12593	Economy	14800.00
0005434639831	12593	Economy	14800.00
0005434639761	12593	Economy	14800.00
0005434639760	12593	Economy	14800.00
0005434639825	12593	Economy	14800.00
0005434639873	12593	Economy	14800.00
0005434639826	12593	Economy	14800.00
0005433202752	12593	Economy	14800.00
0005434639868	12593	Economy	14800.00
0005434639816	12593	Economy	14800.00
0005433202749	12593	Economy	14800.00
0005434639691	12593	Economy	14800.00
0005433202754	12593	Economy	14800.00
0005434639858	12593	Economy	14800.00
0005434639819	12593	Economy	14800.00
0005434639838	12593	Economy	14800.00
0005434639812	12593	Economy	14800.00
0005434639765	12593	Economy	14800.00
0005434639773	12593	Economy	14800.00
0005434639762	12593	Economy	14800.00
0005434639817	12593	Economy	14800.00
0005434639801	12593	Economy	14800.00
0005434639836	12593	Economy	14800.00
0005434639881	12593	Economy	14800.00
0005433202755	12593	Economy	14800.00
0005434639805	12593	Economy	14800.00
0005433202751	12593	Economy	14800.00
0005434639766	12593	Economy	14800.00
0005434639837	12593	Economy	14800.00
0005434639708	12593	Economy	14800.00
0005434639880	12593	Economy	14800.00
0005434639759	12593	Economy	14800.00
0005434639811	12593	Economy	14800.00
0005434639796	12593	Economy	14800.00
0005433202750	12593	Economy	14800.00
0005434639824	12593	Economy	14800.00
0005433202758	12593	Economy	14800.00
0005434639804	12593	Economy	14800.00
0005433202753	12593	Economy	14800.00
0005433202757	12593	Economy	14800.00
0005434639813	12593	Economy	14800.00
0005434639696	12593	Economy	14800.00
0005434639832	12593	Economy	14800.00
0005434639987	23357	Economy	16200.00
0005433202585	23357	Economy	16200.00
0005433202566	23357	Economy	16200.00
0005433202603	23357	Economy	16200.00
0005433202558	23357	Economy	14800.00
0005434639991	23357	Economy	14800.00
0005434639998	23357	Economy	14800.00
0005434639984	23357	Economy	14800.00
0005434639995	23357	Economy	14800.00
0005433202583	23357	Economy	14800.00
0005433202602	23357	Economy	14800.00
0005434639992	23357	Economy	14800.00
0005433202624	23357	Economy	14800.00
0005433202530	23357	Economy	14800.00
0005434639981	23357	Economy	14800.00
0005434639993	23357	Economy	14800.00
0005433202588	23357	Economy	14800.00
0005434639989	23357	Economy	14800.00
0005434639980	23357	Economy	14800.00
0005433202556	23357	Economy	14800.00
0005433202548	23357	Economy	14800.00
0005433202616	23357	Economy	14800.00
0005434639988	23357	Economy	14800.00
0005432290712	23357	Economy	14800.00
0005434639996	23357	Economy	14800.00
0005434639986	23357	Economy	14800.00
0005432290714	23357	Economy	14800.00
0005434639994	23357	Economy	14800.00
0005434639990	23357	Economy	14800.00
0005433202601	23357	Economy	14800.00
0005433202531	23357	Economy	14800.00
0005434639997	23357	Economy	14800.00
0005433202613	23357	Economy	14800.00
0005433202557	23357	Economy	14800.00
0005433202623	23357	Economy	14800.00
0005433202615	23357	Economy	14800.00
0005434639976	23357	Economy	14800.00
0005433202542	23357	Economy	14800.00
0005434639985	23357	Economy	14800.00
0005433202567	23357	Economy	14800.00
0005433202614	23357	Economy	14800.00
0005434639983	23357	Economy	14800.00
0005434639977	23357	Economy	14800.00
0005434639979	23357	Economy	14800.00
0005433202604	23357	Economy	14800.00
0005432290713	23357	Economy	14800.00
0005433202584	23357	Economy	14800.00
0005433202648	23357	Economy	14800.00
0005434639978	23357	Economy	14800.00
0005434639982	23357	Economy	14800.00
0005432329496	21059	Business	18900.00
0005432383901	21059	Business	18900.00
0005432329378	21059	Business	18900.00
0005432329461	21059	Business	18900.00
0005432383840	21059	Business	18900.00
0005432383726	21059	Business	18900.00
0005432329410	21059	Business	18900.00
0005432383875	21059	Business	18900.00
0005432329350	21059	Business	18900.00
0005432054385	21059	Business	18900.00
0005432329571	21059	Business	18900.00
0005432329457	21059	Business	18900.00
0005432329301	21059	Economy	6300.00
0005432329558	21059	Economy	6300.00
0005432329329	21059	Economy	6300.00
0005432329547	21059	Economy	6300.00
0005432054382	21059	Economy	6300.00
0005432329434	21059	Economy	6300.00
0005432383890	21059	Economy	6300.00
0005432383749	21059	Economy	6300.00
0005432383801	21059	Economy	6300.00
0005432383724	21059	Economy	6300.00
0005432383757	21059	Economy	6900.00
0005432329482	21059	Economy	6900.00
0005432329691	21059	Economy	6900.00
0005432383889	21059	Economy	6900.00
0005432383837	21059	Economy	6900.00
0005432329634	21059	Economy	6300.00
0005432329566	21059	Economy	6300.00
0005432383884	21059	Economy	6300.00
0005432383646	21059	Economy	6300.00
0005432383839	21059	Economy	6300.00
0005432383780	21059	Economy	6300.00
0005432383891	21059	Economy	6300.00
0005432329623	21059	Economy	6300.00
0005432329681	21059	Economy	6300.00
0005432329342	21059	Economy	6300.00
0005432383973	21059	Economy	6300.00
0005432329705	21059	Economy	6300.00
0005432383845	21059	Economy	6300.00
0005432383798	21059	Economy	6300.00
0005432383725	21059	Economy	6300.00
0005432329700	21059	Economy	6300.00
0005432329470	21059	Economy	6300.00
0005432383740	21059	Economy	6300.00
0005432329565	21059	Economy	6300.00
0005432383800	21059	Economy	6300.00
0005432329572	21059	Economy	6300.00
0005432383686	21059	Economy	6300.00
0005432383876	21059	Economy	6300.00
0005432383763	21059	Economy	6300.00
0005432383902	21059	Economy	6300.00
0005432329356	21059	Economy	6300.00
0005432054384	21059	Economy	6300.00
0005432383894	21059	Economy	6300.00
0005432329432	21059	Economy	6300.00
0005432383882	21059	Economy	6300.00
0005432383809	21059	Economy	6300.00
0005432329435	21059	Economy	6300.00
0005432329464	21059	Economy	6300.00
0005432329318	21059	Economy	6300.00
0005432329466	21059	Economy	6300.00
0005432329411	21059	Economy	6300.00
0005432383933	21059	Economy	6300.00
0005432383910	21059	Economy	6300.00
0005432329465	21059	Economy	6300.00
0005432383739	21059	Economy	6300.00
0005432383932	21059	Economy	6300.00
0005432329359	21059	Economy	6300.00
0005432054383	21059	Economy	6300.00
0005432329548	21059	Economy	6300.00
0005432329436	21059	Economy	6300.00
0005432329633	21059	Economy	6300.00
0005432383929	21059	Economy	6300.00
0005432383813	21059	Economy	6300.00
0005432383812	21059	Economy	6300.00
0005432329635	21059	Economy	6300.00
0005432329323	21059	Economy	6300.00
0005432383846	21059	Economy	6300.00
0005432383916	21059	Economy	6300.00
0005432383930	21059	Economy	6300.00
0005432383877	21059	Economy	6300.00
0005432383762	21059	Economy	6300.00
0005432329602	21059	Economy	6300.00
0005432329497	21059	Economy	6300.00
0005432329309	21059	Economy	6300.00
0005432329349	21059	Economy	6300.00
0005432329358	21059	Economy	6300.00
0005432329546	21059	Economy	6300.00
0005432329481	21059	Economy	6300.00
0005432383883	21059	Economy	6300.00
0005432329529	21059	Economy	6300.00
0005432383895	21059	Economy	6300.00
0005432329744	21059	Economy	6300.00
0005432329613	21059	Economy	6300.00
0005432383838	21059	Economy	6300.00
0005432329471	21059	Economy	6300.00
0005432329883	31223	Business	18900.00
0005432329875	31223	Business	18900.00
0005432384188	31223	Business	18900.00
0005432329868	31223	Business	18900.00
0005432329861	31223	Business	18900.00
0005432329859	31223	Business	18900.00
0005432384190	31223	Business	18900.00
0005432329871	31223	Business	18900.00
0005432329876	31223	Business	18900.00
0005432384191	31223	Business	18900.00
0005432287319	31223	Business	18900.00
0005432329858	31223	Economy	6300.00
0005432384170	31223	Economy	6300.00
0005432329863	31223	Economy	6300.00
0005432287316	31223	Economy	6300.00
0005432384178	31223	Economy	6300.00
0005432329889	31223	Economy	6300.00
0005432384182	31223	Economy	6300.00
0005432384173	31223	Economy	6300.00
0005432384179	31223	Economy	6300.00
0005432329864	31223	Economy	6300.00
0005432384177	31223	Economy	6900.00
0005432384175	31223	Economy	6900.00
0005432329899	31223	Economy	6900.00
0005432384169	31223	Economy	6900.00
0005432329891	31223	Economy	6300.00
0005432329862	31223	Economy	6300.00
0005432329874	31223	Economy	6300.00
0005432329873	31223	Economy	6300.00
0005432848860	31223	Economy	6300.00
0005432384184	31223	Economy	6300.00
0005432384167	31223	Economy	6300.00
0005432329860	31223	Economy	6300.00
0005432329896	31223	Economy	6300.00
0005432329877	31223	Economy	6300.00
0005432329867	31223	Economy	6300.00
0005432384162	31223	Economy	6300.00
0005432329898	31223	Economy	6300.00
0005432384165	31223	Economy	6300.00
0005432329866	31223	Economy	6300.00
0005432287321	31223	Economy	6300.00
0005432384195	31223	Economy	6300.00
0005432848857	31223	Economy	6300.00
0005432848842	31223	Economy	6300.00
0005432329881	31223	Economy	6300.00
0005432384192	31223	Economy	6300.00
0005432329893	31223	Economy	6300.00
0005432329872	31223	Economy	6300.00
0005432329887	31223	Economy	6300.00
0005432329886	31223	Economy	6300.00
0005432384176	31223	Economy	6300.00
0005432384163	31223	Economy	6300.00
0005432384172	31223	Economy	6300.00
0005432329892	31223	Economy	6300.00
0005432384193	31223	Economy	6300.00
0005432384166	31223	Economy	6300.00
0005432287318	31223	Economy	6300.00
0005432329890	31223	Economy	6300.00
0005432329888	31223	Economy	6300.00
0005432384168	31223	Economy	6300.00
0005432384187	31223	Economy	6300.00
0005432329884	31223	Economy	6300.00
0005432848861	31223	Economy	6300.00
0005432384180	31223	Economy	6300.00
0005432329895	31223	Economy	6300.00
0005432384189	31223	Economy	6300.00
0005432287320	31223	Economy	6300.00
0005432329885	31223	Economy	6300.00
0005432384183	31223	Economy	6300.00
0005432329879	31223	Economy	6300.00
0005432384185	31223	Economy	6300.00
0005432329897	31223	Economy	6300.00
0005432329869	31223	Economy	6300.00
0005432329878	31223	Economy	6300.00
0005432329870	31223	Economy	6300.00
0005432329882	31223	Economy	6300.00
0005432384171	31223	Economy	6300.00
0005432384197	31223	Economy	6300.00
0005432384174	31223	Economy	6300.00
0005432329865	31223	Economy	6300.00
0005432287317	31223	Economy	6300.00
0005432384186	31223	Economy	6300.00
0005432329894	31223	Economy	6300.00
0005432384164	31223	Economy	6300.00
0005432384161	31223	Economy	6300.00
0005432384194	31223	Economy	6300.00
0005432384181	31223	Economy	6300.00
0005432384196	31223	Economy	6300.00
0005432329880	31223	Economy	6300.00
0005432425689	13278	Business	12700.00
0005432425672	13278	Business	12700.00
0005432425682	13278	Business	12700.00
0005432425665	13278	Business	12700.00
0005432425685	13278	Business	12700.00
0005432425708	13278	Business	12700.00
0005432425687	13278	Business	12700.00
0005432425702	13278	Business	12700.00
0005432425675	13278	Business	12700.00
0005432425669	13278	Business	12700.00
0005432425684	13278	Business	12700.00
0005432425678	13278	Economy	4200.00
0005432425701	13278	Economy	4200.00
0005432425676	13278	Economy	4200.00
0005432425703	13278	Economy	4200.00
0005432425696	13278	Economy	4200.00
0005432425705	13278	Economy	4700.00
0005432425711	13278	Economy	4700.00
0005432425690	13278	Economy	4200.00
0005432425692	13278	Economy	4200.00
0005432425680	13278	Economy	4200.00
0005432425697	13278	Economy	4200.00
0005432425686	13278	Economy	4200.00
0005432425707	13278	Economy	4200.00
0005432425695	13278	Economy	4200.00
0005432425700	13278	Economy	4200.00
0005432425662	13278	Economy	4200.00
0005432425706	13278	Economy	4200.00
0005432425666	13278	Economy	4200.00
0005432425710	13278	Economy	4200.00
0005432425704	13278	Economy	4200.00
0005432425670	13278	Economy	4200.00
0005432425679	13278	Economy	4200.00
0005432425664	13278	Economy	4200.00
0005432425694	13278	Economy	4200.00
0005432425709	13278	Economy	4200.00
0005432425663	13278	Economy	4200.00
0005432425671	13278	Economy	4200.00
0005432425667	13278	Economy	4200.00
0005432425674	13278	Economy	4200.00
0005432425673	13278	Economy	4200.00
0005432425688	13278	Economy	4200.00
0005432425698	13278	Economy	4200.00
0005432425661	13278	Economy	4200.00
0005432425699	13278	Economy	4200.00
0005432425668	13278	Economy	4200.00
0005432425683	13278	Economy	4200.00
0005432425693	13278	Economy	4200.00
0005432425677	13278	Economy	4200.00
0005432425681	13278	Economy	4200.00
0005432425691	13278	Economy	4200.00
0005432425307	30747	Business	12700.00
0005432425192	30747	Business	12700.00
0005432425279	30747	Business	12700.00
0005432425324	30747	Business	12700.00
0005432425207	30747	Business	12700.00
0005432425268	30747	Business	12700.00
0005432425157	30747	Business	12700.00
0005432425278	30747	Economy	4200.00
0005432425318	30747	Economy	4200.00
0005432425325	30747	Economy	4200.00
0005432425291	30747	Economy	4200.00
0005432425138	30747	Economy	4200.00
0005432425312	30747	Economy	4200.00
0005432425334	30747	Economy	4200.00
0005432425333	30747	Economy	4700.00
0005432425335	30747	Economy	4200.00
0005432425031	30747	Economy	4200.00
0005432425314	30747	Economy	4200.00
0005432425289	30747	Economy	4200.00
0005432425332	30747	Economy	4200.00
0005432425286	30747	Economy	4200.00
0005432425309	30747	Economy	4200.00
0005432425285	30747	Economy	4200.00
0005432425237	30747	Economy	4200.00
0005432425247	30747	Economy	4200.00
0005432425320	30747	Economy	4200.00
0005432425280	30747	Economy	4200.00
0005432425260	30747	Economy	4200.00
0005432425308	30747	Economy	4200.00
0005432425032	30747	Economy	4200.00
0005432425311	30747	Economy	4200.00
0005432425156	30747	Economy	4200.00
0005432425306	30747	Economy	4200.00
0005432425238	30747	Economy	4200.00
0005432425310	30747	Economy	4200.00
0005432425287	30747	Economy	4200.00
0005432425263	30747	Economy	4200.00
0005432425261	30747	Economy	4200.00
0005432425254	30747	Economy	4200.00
0005432425214	30747	Economy	4200.00
0005432425284	30747	Economy	4200.00
0005432425267	30747	Economy	4200.00
0005432425315	30747	Economy	4200.00
0005432425206	30747	Economy	4200.00
0005432425212	30747	Economy	4200.00
0005432425319	30747	Economy	4200.00
0005432425326	30747	Economy	4200.00
0005432425213	30747	Economy	4200.00
0005432425205	30747	Economy	4200.00
0005432425158	30747	Economy	4200.00
0005432818247	9625	Business	32600.00
0005432901943	9625	Business	32600.00
0005434186243	9625	Business	32600.00
0005432901991	9625	Business	32600.00
0005432822411	9625	Business	32600.00
0005432822412	9625	Business	32600.00
0005432818252	9625	Business	32600.00
0005432818243	9625	Business	32600.00
0005432822409	9625	Economy	10900.00
0005432901906	9625	Economy	10900.00
0005432818264	9625	Economy	10900.00
0005432901881	9625	Economy	10900.00
0005432818239	9625	Economy	10900.00
0005432818259	9625	Economy	10900.00
0005432818258	9625	Economy	10900.00
0005434448408	9625	Economy	10900.00
0005432901909	9625	Economy	11900.00
0005432822404	9625	Economy	11900.00
0005432818250	9625	Economy	11900.00
0005432818245	9625	Economy	11900.00
0005432901882	9625	Economy	11900.00
0005432901908	9625	Economy	10900.00
0005432901915	9625	Economy	10900.00
0005432818254	9625	Economy	10900.00
0005432818244	9625	Economy	10900.00
0005432818238	9625	Economy	10900.00
0005434448407	9625	Economy	10900.00
0005432818266	9625	Economy	10900.00
0005432901965	9625	Economy	10900.00
0005432822406	9625	Economy	10900.00
0005432818251	9625	Economy	10900.00
0005432901835	9625	Economy	10900.00
0005432822405	9625	Economy	10900.00
0005432818240	9625	Economy	10900.00
0005432901914	9625	Economy	10900.00
0005432901917	9625	Economy	10900.00
0005432822407	9625	Economy	10900.00
0005432822408	9625	Economy	10900.00
0005432818248	9625	Economy	10900.00
0005432822410	9625	Economy	10900.00
0005432818246	9625	Economy	10900.00
0005434186247	9625	Economy	10900.00
0005434448406	9625	Economy	10900.00
0005434186241	9625	Economy	10900.00
0005432818265	9625	Economy	10900.00
0005432818262	9625	Economy	10900.00
0005432901862	9625	Economy	10900.00
0005432818256	9625	Economy	10900.00
0005432901863	9625	Economy	10900.00
0005432818242	9625	Economy	10900.00
0005432818257	9625	Economy	10900.00
0005432289073	9625	Economy	10900.00
0005434186246	9625	Economy	10900.00
0005432818261	9625	Economy	10900.00
0005432818255	9625	Economy	10900.00
0005434186245	9625	Economy	10900.00
0005434186261	9625	Economy	10900.00
0005432818241	9625	Economy	10900.00
0005432901945	9625	Economy	10900.00
0005432818263	9625	Economy	10900.00
0005432901934	9625	Economy	10900.00
0005432818249	9625	Economy	10900.00
0005432818253	9625	Economy	10900.00
0005432818260	9625	Economy	10900.00
0005432901946	9625	Economy	10900.00
0005432901944	9625	Economy	10900.00
0005432902066	28954	Business	32600.00
0005432818114	28954	Business	32600.00
0005432822318	28954	Business	32600.00
0005432818048	28954	Business	32600.00
0005432902063	28954	Business	32600.00
0005432818046	28954	Economy	10900.00
0005432902069	28954	Economy	10900.00
0005432817934	28954	Economy	10900.00
0005432818042	28954	Economy	10900.00
0005432822332	28954	Economy	10900.00
0005432817953	28954	Economy	10900.00
0005434157686	28954	Economy	10900.00
0005432902075	28954	Economy	10900.00
0005432817964	28954	Economy	10900.00
0005432822355	28954	Economy	11900.00
0005432002130	28954	Economy	11900.00
0005432818019	28954	Economy	11900.00
0005432902064	28954	Economy	10900.00
0005432902062	28954	Economy	10900.00
0005432902072	28954	Economy	10900.00
0005432818018	28954	Economy	10900.00
0005432818100	28954	Economy	10900.00
0005432817969	28954	Economy	10900.00
0005432902070	28954	Economy	10900.00
0005432817926	28954	Economy	10900.00
0005432822360	28954	Economy	10900.00
0005432817958	28954	Economy	10900.00
0005432817849	28954	Economy	10900.00
0005434186273	28954	Economy	10900.00
0005432818057	28954	Economy	10900.00
0005432902068	28954	Economy	10900.00
0005434448373	28954	Economy	10900.00
0005432818044	28954	Economy	10900.00
0005432902074	28954	Economy	10900.00
0005432817997	28954	Economy	10900.00
0005432817965	28954	Economy	10900.00
0005432902067	28954	Economy	10900.00
0005432818090	28954	Economy	10900.00
0005432902076	28954	Economy	10900.00
0005432822333	28954	Economy	10900.00
0005434157685	28954	Economy	10900.00
0005432817973	28954	Economy	10900.00
0005432902065	28954	Economy	10900.00
0005434157689	28954	Economy	10900.00
0005432817963	28954	Economy	10900.00
0005432817925	28954	Economy	10900.00
0005432822361	28954	Economy	10900.00
0005432902073	28954	Economy	10900.00
0005432817954	28954	Economy	10900.00
0005432902077	28954	Economy	10900.00
0005432902071	28954	Economy	10900.00
0005434448374	28954	Economy	10900.00
0005432817978	28954	Economy	10900.00
0005432817914	28954	Economy	10900.00
0005432817848	28954	Economy	10900.00
0005432822367	28954	Economy	10900.00
0005434186274	28954	Economy	10900.00
0005432002131	28954	Economy	10900.00
0005434186275	28954	Economy	10900.00
0005434157684	28954	Economy	10900.00
0005432817975	28954	Economy	10900.00
0005434157688	28954	Economy	10900.00
0005432817852	28954	Economy	10900.00
0005432818099	28954	Economy	10900.00
0005434157687	28954	Economy	10900.00
0005432818086	28954	Economy	10900.00
0005432613971	15100	Economy	11000.00
0005432611805	15100	Economy	11000.00
0005432613970	15100	Economy	11000.00
0005432611806	15100	Economy	11000.00
0005432611804	15100	Economy	11000.00
0005435841834	15100	Economy	11000.00
0005435841109	15100	Economy	11000.00
0005432611803	15100	Economy	11000.00
0005435841108	15100	Economy	11000.00
0005435841110	15100	Economy	11000.00
0005432607613	31558	Economy	11000.00
0005432607640	31558	Economy	11000.00
0005432607641	31558	Economy	11000.00
0005432607642	31558	Economy	11000.00
0005432611783	31558	Economy	11000.00
0005432611775	31558	Economy	11000.00
0005432611782	31558	Economy	11000.00
0005432607624	31558	Economy	11000.00
0005432607625	31558	Economy	11000.00
0005432611781	31558	Economy	11000.00
0005432607639	31558	Economy	11000.00
0005432607647	31558	Economy	11000.00
0005433570645	11890	Business	105900.00
0005432949090	11890	Business	105900.00
0005432949130	11890	Business	105900.00
0005432949212	11890	Business	105900.00
0005432949113	11890	Business	105900.00
0005433570649	11890	Business	105900.00
0005432949201	11890	Business	105900.00
0005432949107	11890	Business	105900.00
0005432948957	11890	Business	105900.00
0005432949217	11890	Business	105900.00
0005432949124	11890	Business	105900.00
0005432949175	11890	Business	105900.00
0005433570665	11890	Business	105900.00
0005432949258	11890	Business	105900.00
0005432949079	11890	Business	105900.00
0005432949080	11890	Business	105900.00
0005432949283	11890	Business	105900.00
0005432949081	11890	Business	105900.00
0005433570671	11890	Business	105900.00
0005432949056	11890	Business	105900.00
0005432949188	11890	Economy	35300.00
0005433570668	11890	Economy	35300.00
0005432949215	11890	Economy	35300.00
0005433570662	11890	Economy	35300.00
0005432949069	11890	Economy	35300.00
0005433570680	11890	Economy	35300.00
0005433570679	11890	Economy	35300.00
0005433570636	11890	Economy	35300.00
0005432948982	11890	Economy	35300.00
0005432949054	11890	Economy	35300.00
0005432949106	11890	Economy	35300.00
0005433570666	11890	Economy	35300.00
0005433570676	11890	Economy	35300.00
0005433570667	11890	Economy	38800.00
0005433570678	11890	Economy	38800.00
0005432949265	11890	Economy	38800.00
0005433570681	11890	Economy	38800.00
0005432949095	11890	Economy	35300.00
0005433570647	11890	Economy	35300.00
0005433570674	11890	Economy	35300.00
0005433570656	11890	Economy	35300.00
0005432949037	11890	Economy	35300.00
0005432949116	11890	Economy	35300.00
0005432948923	11890	Economy	35300.00
0005433570658	11890	Economy	35300.00
0005432948972	11890	Economy	35300.00
0005432949129	11890	Economy	35300.00
0005432949182	11890	Economy	35300.00
0005433570683	11890	Economy	35300.00
0005432949162	11890	Economy	35300.00
0005432948961	11890	Economy	35300.00
0005433570675	11890	Economy	35300.00
0005432949225	11890	Economy	35300.00
0005433570637	11890	Economy	35300.00
0005433570641	11890	Economy	35300.00
0005433570661	11890	Economy	35300.00
0005432949165	11890	Economy	35300.00
0005433570639	11890	Economy	35300.00
0005432949060	11890	Economy	35300.00
0005433570655	11890	Economy	35300.00
0005432949189	11890	Economy	35300.00
0005433570685	11890	Economy	35300.00
0005432949007	11890	Economy	35300.00
0005432949234	11890	Economy	35300.00
0005433570640	11890	Economy	35300.00
0005433570673	11890	Economy	35300.00
0005432949233	11890	Economy	35300.00
0005432948973	11890	Economy	35300.00
0005432949105	11890	Economy	35300.00
0005433570642	11890	Economy	35300.00
0005432949213	11890	Economy	35300.00
0005432949115	11890	Economy	35300.00
0005432949154	11890	Economy	35300.00
0005433570657	11890	Economy	35300.00
0005432949172	11890	Economy	35300.00
0005433570646	11890	Economy	35300.00
0005432949181	11890	Economy	35300.00
0005432949238	11890	Economy	35300.00
0005432949264	11890	Economy	35300.00
0005432949055	11890	Economy	35300.00
0005432949001	11890	Economy	35300.00
0005432949114	11890	Economy	35300.00
0005433570663	11890	Economy	35300.00
0005433570653	11890	Economy	35300.00
0005433570643	11890	Economy	35300.00
0005432948955	11890	Economy	35300.00
0005433570670	11890	Economy	35300.00
0005432949202	11890	Economy	35300.00
0005432949216	11890	Economy	35300.00
0005432949020	11890	Economy	35300.00
0005432949053	11890	Economy	35300.00
0005432949102	11890	Economy	35300.00
0005433570684	11890	Economy	35300.00
0005432949127	11890	Economy	35300.00
0005432949161	11890	Economy	35300.00
0005433570669	11890	Economy	35300.00
0005433570659	11890	Economy	35300.00
0005433570635	11890	Economy	35300.00
0005432948956	11890	Economy	35300.00
0005433570664	11890	Economy	35300.00
0005433570651	11890	Economy	35300.00
0005433570677	11890	Economy	35300.00
0005432949002	11890	Economy	35300.00
0005432948971	11890	Economy	35300.00
0005432949123	11890	Economy	35300.00
0005433570644	11890	Economy	35300.00
0005433570648	11890	Economy	35300.00
0005433570682	11890	Economy	35300.00
0005433570652	11890	Economy	35300.00
0005433570672	11890	Economy	35300.00
0005433570638	11890	Economy	35300.00
0005433570650	11890	Economy	35300.00
0005432949031	11890	Economy	35300.00
0005432949164	11890	Economy	35300.00
0005433570660	11890	Economy	35300.00
0005433570654	11890	Economy	35300.00
0005433570213	25287	Business	105900.00
0005433570143	25287	Business	105900.00
0005433570116	25287	Business	105900.00
0005433569981	25287	Business	105900.00
0005432949562	25287	Business	105900.00
0005433570073	25287	Business	105900.00
0005433570342	25287	Business	105900.00
0005433570066	25287	Business	105900.00
0005432949579	25287	Business	105900.00
0005433570048	25287	Business	105900.00
0005432949564	25287	Business	105900.00
0005433570034	25287	Business	105900.00
0005433570005	25287	Business	105900.00
0005433570136	25287	Business	105900.00
0005433570047	25287	Business	105900.00
0005433570144	25287	Business	105900.00
0005433569946	25287	Business	105900.00
0005432949580	25287	Business	105900.00
0005432949561	25287	Economy	35300.00
0005433570154	25287	Economy	35300.00
0005433570088	25287	Economy	35300.00
0005433570070	25287	Economy	35300.00
0005432949557	25287	Economy	35300.00
0005433569998	25287	Economy	35300.00
0005433570234	25287	Economy	35300.00
0005432949577	25287	Economy	35300.00
0005432949567	25287	Economy	35300.00
0005433570069	25287	Economy	38800.00
0005432949583	25287	Economy	38800.00
0005433569778	25287	Economy	38800.00
0005432949570	25287	Economy	38800.00
0005432949556	25287	Economy	35300.00
0005433570142	25287	Economy	35300.00
0005432949572	25287	Economy	35300.00
0005433569980	25287	Economy	35300.00
0005433570177	25287	Economy	35300.00
0005433570024	25287	Economy	35300.00
0005433570039	25287	Economy	35300.00
0005433570071	25287	Economy	35300.00
0005433569973	25287	Economy	35300.00
0005433570040	25287	Economy	35300.00
0005432949555	25287	Economy	35300.00
0005432949566	25287	Economy	35300.00
0005433569994	25287	Economy	35300.00
0005432949582	25287	Economy	35300.00
0005433570109	25287	Economy	35300.00
0005433570089	25287	Economy	35300.00
0005433570117	25287	Economy	35300.00
0005432949568	25287	Economy	35300.00
0005433570013	25287	Economy	35300.00
0005433570184	25287	Economy	35300.00
0005432949585	25287	Economy	35300.00
0005433570076	25287	Economy	35300.00
0005433569932	25287	Economy	35300.00
0005433569982	25287	Economy	35300.00
0005433570094	25287	Economy	35300.00
0005433570289	25287	Economy	35300.00
0005433569933	25287	Economy	35300.00
0005433570141	25287	Economy	35300.00
0005433570014	25287	Economy	35300.00
0005433570153	25287	Economy	35300.00
0005433570349	25287	Economy	35300.00
0005432949563	25287	Economy	35300.00
0005432949560	25287	Economy	35300.00
0005433569911	25287	Economy	35300.00
0005432949569	25287	Economy	35300.00
0005432949571	25287	Economy	35300.00
0005433569912	25287	Economy	35300.00
0005432949573	25287	Economy	35300.00
0005433570214	25287	Economy	35300.00
0005433570186	25287	Economy	35300.00
0005432949565	25287	Economy	35300.00
0005432949575	25287	Economy	35300.00
0005433570424	25287	Economy	35300.00
0005433570297	25287	Economy	35300.00
0005433569945	25287	Economy	35300.00
0005433570369	25287	Economy	35300.00
0005433570124	25287	Economy	35300.00
0005432949558	25287	Economy	35300.00
0005433570203	25287	Economy	35300.00
0005432949576	25287	Economy	35300.00
0005432949578	25287	Economy	35300.00
0005432949559	25287	Economy	35300.00
0005433570204	25287	Economy	35300.00
0005433570201	25287	Economy	35300.00
0005432949581	25287	Economy	35300.00
0005433570236	25287	Economy	35300.00
0005432949574	25287	Economy	35300.00
0005433570547	25287	Economy	35300.00
0005433569913	25287	Economy	35300.00
0005433569841	25287	Economy	35300.00
0005433570348	25287	Economy	35300.00
0005432949584	25287	Economy	35300.00
0005433570098	25287	Economy	35300.00
0005433570215	25287	Economy	35300.00
0005433570185	25287	Economy	35300.00
0005433927518	27943	Business	105400.00
0005433927533	27943	Business	105400.00
0005433811649	27943	Business	105400.00
0005433927527	27943	Economy	35100.00
0005433927530	27943	Economy	35100.00
0005433927526	27943	Economy	35100.00
0005433927523	27943	Economy	35100.00
0005433927522	27943	Economy	35100.00
0005433811650	27943	Economy	35100.00
0005433927528	27943	Economy	35100.00
0005433811664	27943	Economy	35100.00
0005433811645	27943	Economy	35100.00
0005433927531	27943	Economy	35100.00
0005433927525	27943	Economy	35100.00
0005433811663	27943	Economy	35100.00
0005433927532	27943	Economy	35100.00
0005433927520	27943	Economy	35100.00
0005433811651	27943	Economy	35100.00
0005433927529	27943	Economy	35100.00
0005433927521	27943	Economy	35100.00
0005433811653	27943	Economy	35100.00
0005433811657	27943	Economy	35100.00
0005433927519	27943	Economy	35100.00
0005433927524	27943	Economy	35100.00
0005435340517	5377	Business	67200.00
0005434655441	5377	Business	67200.00
0005434655442	5377	Business	67200.00
0005432114288	5377	Business	67200.00
0005434655453	5377	Business	67200.00
0005434655443	5377	Business	67200.00
0005435340537	5377	Economy	22400.00
0005434655446	5377	Economy	22400.00
0005434655455	5377	Economy	22400.00
0005435340562	5377	Economy	22400.00
0005434655449	5377	Economy	24600.00
0005434656610	5377	Economy	24600.00
0005434655451	5377	Economy	22400.00
0005435340529	5377	Economy	22400.00
0005435555403	5377	Economy	22400.00
0005435555408	5377	Economy	22400.00
0005435555409	5377	Economy	22400.00
0005435340506	5377	Economy	22400.00
0005434655439	5377	Economy	22400.00
0005434655444	5377	Economy	22400.00
0005434655464	5377	Economy	22400.00
0005435340516	5377	Economy	22400.00
0005434655461	5377	Economy	22400.00
0005435340518	5377	Economy	22400.00
0005435340545	5377	Economy	22400.00
0005435340555	5377	Economy	22400.00
0005434655463	5377	Economy	22400.00
0005434656611	5377	Economy	22400.00
0005435555410	5377	Economy	22400.00
0005434655440	5377	Economy	22400.00
0005434655457	5377	Economy	22400.00
0005434655452	5377	Economy	22400.00
0005434655454	5377	Economy	22400.00
0005434655450	5377	Economy	22400.00
0005434655456	5377	Economy	22400.00
0005434655447	5377	Economy	22400.00
0005434655462	5377	Economy	22400.00
0005434655459	5377	Economy	22400.00
0005435340581	5377	Economy	22400.00
0005432114289	5377	Economy	22400.00
0005435340559	5377	Economy	22400.00
0005434655445	5377	Economy	22400.00
0005434655460	5377	Economy	22400.00
0005434655448	5377	Economy	22400.00
0005434655458	5377	Economy	22400.00
0005435340554	5377	Economy	22400.00
0005435340667	12561	Business	67200.00
0005434656586	12561	Business	67200.00
0005434655082	12561	Business	67200.00
0005435340671	12561	Business	67200.00
0005434655145	12561	Economy	22400.00
0005434655188	12561	Economy	22400.00
0005434656585	12561	Economy	22400.00
0005434655075	12561	Economy	22400.00
0005435340661	12561	Economy	22400.00
0005434655371	12561	Economy	24600.00
0005435340664	12561	Economy	24600.00
0005434655133	12561	Economy	22400.00
0005435340670	12561	Economy	22400.00
0005434656595	12561	Economy	22400.00
0005435340665	12561	Economy	22400.00
0005435340662	12561	Economy	22400.00
0005434655163	12561	Economy	22400.00
0005434655237	12561	Economy	22400.00
0005435555424	12561	Economy	22400.00
0005435340669	12561	Economy	22400.00
0005434655316	12561	Economy	22400.00
0005434655290	12561	Economy	22400.00
0005434655223	12561	Economy	22400.00
0005435340663	12561	Economy	22400.00
0005434656594	12561	Economy	22400.00
0005435340659	12561	Economy	22400.00
0005434655302	12561	Economy	22400.00
0005435340668	12561	Economy	22400.00
0005434655162	12561	Economy	22400.00
0005435340666	12561	Economy	22400.00
0005435340672	12561	Economy	22400.00
0005434655311	12561	Economy	22400.00
0005434655252	12561	Economy	22400.00
0005434655238	12561	Economy	22400.00
0005434655274	12561	Economy	22400.00
0005435340660	12561	Economy	22400.00
0005433717296	7472	Business	32000.00
0005433717297	7472	Business	32000.00
0005433717283	7472	Business	32000.00
0005433722391	7472	Business	32000.00
0005433717301	7472	Business	32000.00
0005433717264	7472	Business	32000.00
0005433719230	7472	Business	32000.00
0005433688864	7472	Economy	10700.00
0005433722396	7472	Economy	10700.00
0005433722408	7472	Economy	10700.00
0005433722401	7472	Economy	10700.00
0005433717294	7472	Economy	10700.00
0005433717298	7472	Economy	10700.00
0005432428991	7472	Economy	10700.00
0005433656757	7472	Economy	10700.00
0005433717284	7472	Economy	10700.00
0005433717292	7472	Economy	10700.00
0005435266225	7472	Economy	10700.00
0005433722406	7472	Economy	10700.00
0005433717278	7472	Economy	10700.00
0005433717256	7472	Economy	10700.00
0005433717277	7472	Economy	10700.00
0005433722402	7472	Economy	10700.00
0005433719229	7472	Economy	10700.00
0005433717273	7472	Economy	10700.00
0005433722394	7472	Economy	10700.00
0005433717282	7472	Economy	10700.00
0005433717291	7472	Economy	10700.00
0005433722399	7472	Economy	10700.00
0005433717287	7472	Economy	10700.00
0005433717286	7472	Economy	10700.00
0005433717272	7472	Economy	10700.00
0005433722400	7472	Economy	10700.00
0005435266199	7472	Economy	10700.00
0005433689965	7472	Economy	10700.00
0005435266224	7472	Economy	10700.00
0005433722403	7472	Economy	10700.00
0005433722393	7472	Economy	11700.00
0005435266248	7472	Economy	11700.00
0005433717293	7472	Economy	11700.00
0005435266234	7472	Economy	11700.00
0005435266227	7472	Economy	11700.00
0005433722407	7472	Economy	10700.00
0005433717259	7472	Economy	10700.00
0005433717300	7472	Economy	10700.00
0005432078252	7472	Economy	10700.00
0005433717258	7472	Economy	10700.00
0005433717288	7472	Economy	10700.00
0005433722398	7472	Economy	10700.00
0005433656756	7472	Economy	10700.00
0005433717262	7472	Economy	10700.00
0005433722409	7472	Economy	10700.00
0005433717263	7472	Economy	10700.00
0005432428990	7472	Economy	10700.00
0005433717275	7472	Economy	10700.00
0005432429003	7472	Economy	10700.00
0005432428980	7472	Economy	10700.00
0005433717267	7472	Economy	10700.00
0005433717261	7472	Economy	10700.00
0005433717289	7472	Economy	10700.00
0005433717280	7472	Economy	10700.00
0005433717285	7472	Economy	10700.00
0005433722405	7472	Economy	10700.00
0005433688863	7472	Economy	10700.00
0005433717260	7472	Economy	10700.00
0005433717290	7472	Economy	10700.00
0005433722392	7472	Economy	10700.00
0005433717295	7472	Economy	10700.00
0005432078253	7472	Economy	10700.00
0005433717271	7472	Economy	10700.00
0005433719228	7472	Economy	10700.00
0005433717257	7472	Economy	10700.00
0005433717268	7472	Economy	10700.00
0005433717269	7472	Economy	10700.00
0005432078251	7472	Economy	10700.00
0005435266235	7472	Economy	10700.00
0005433717266	7472	Economy	10700.00
0005433719227	7472	Economy	10700.00
0005433717270	7472	Economy	10700.00
0005433717274	7472	Economy	10700.00
0005433717276	7472	Economy	10700.00
0005433690977	7472	Economy	10700.00
0005433689964	7472	Economy	10700.00
0005435266251	7472	Economy	10700.00
0005433717281	7472	Economy	10700.00
0005433717279	7472	Economy	10700.00
0005435266223	7472	Economy	10700.00
0005433717265	7472	Economy	10700.00
0005433722395	7472	Economy	10700.00
0005433722397	7472	Economy	10700.00
0005433690978	7472	Economy	10700.00
0005433717299	7472	Economy	10700.00
0005433722404	7472	Economy	10700.00
0005433716796	29254	Business	32000.00
0005433716787	29254	Business	32000.00
0005433716825	29254	Business	32000.00
0005433716876	29254	Business	32000.00
0005433656724	29254	Business	32000.00
0005433716776	29254	Business	32000.00
0005433716948	29254	Business	32000.00
0005435266318	29254	Business	32000.00
0005433716958	29254	Economy	10700.00
0005433719206	29254	Economy	10700.00
0005432006840	29254	Economy	10700.00
0005433716879	29254	Economy	10700.00
0005433716799	29254	Economy	10700.00
0005433716957	29254	Economy	10700.00
0005433717113	29254	Economy	10700.00
0005433717027	29254	Economy	10700.00
0005433716945	29254	Economy	10700.00
0005433716936	29254	Economy	10700.00
0005433656719	29254	Economy	10700.00
0005433716969	29254	Economy	10700.00
0005433722316	29254	Economy	10700.00
0005433722321	29254	Economy	10700.00
0005433716869	29254	Economy	10700.00
0005433716862	29254	Economy	10700.00
0005433716779	29254	Economy	10700.00
0005433722336	29254	Economy	10700.00
0005433716813	29254	Economy	10700.00
0005433685563	29254	Economy	10700.00
0005433717021	29254	Economy	10700.00
0005433719199	29254	Economy	10700.00
0005433719200	29254	Economy	10700.00
0005433719187	29254	Economy	10700.00
0005433716608	29254	Economy	10700.00
0005433716720	29254	Economy	10700.00
0005433716911	29254	Economy	10700.00
0005433685562	29254	Economy	10700.00
0005432429018	29254	Economy	11700.00
0005433716970	29254	Economy	11700.00
0005433716821	29254	Economy	11700.00
0005432429020	29254	Economy	10700.00
0005433716691	29254	Economy	10700.00
0005433717028	29254	Economy	10700.00
0005433656725	29254	Economy	10700.00
0005433716773	29254	Economy	10700.00
0005433719192	29254	Economy	10700.00
0005433716831	29254	Economy	10700.00
0005433716857	29254	Economy	10700.00
0005433716632	29254	Economy	10700.00
0005433716814	29254	Economy	10700.00
0005433716824	29254	Economy	10700.00
0005433717006	29254	Economy	10700.00
0005433656714	29254	Economy	10700.00
0005433716690	29254	Economy	10700.00
0005433716791	29254	Economy	10700.00
0005433716895	29254	Economy	10700.00
0005433685564	29254	Economy	10700.00
0005433719212	29254	Economy	10700.00
0005433716886	29254	Economy	10700.00
0005435266319	29254	Economy	10700.00
0005433716859	29254	Economy	10700.00
0005433688835	29254	Economy	10700.00
0005433716797	29254	Economy	10700.00
0005433716792	29254	Economy	10700.00
0005433716980	29254	Economy	10700.00
0005435266320	29254	Economy	10700.00
0005433716863	29254	Economy	10700.00
0005433722335	29254	Economy	10700.00
0005433716510	29254	Economy	10700.00
0005433716975	29254	Economy	10700.00
0005433716777	29254	Economy	10700.00
0005433716800	29254	Economy	10700.00
0005432006838	29254	Economy	10700.00
0005432006839	29254	Economy	10700.00
0005433716743	29254	Economy	10700.00
0005433688834	29254	Economy	10700.00
0005433716755	29254	Economy	10700.00
0005433716775	29254	Economy	10700.00
0005433716922	29254	Economy	10700.00
0005433717029	29254	Economy	10700.00
0005433716774	29254	Economy	10700.00
0005433716729	29254	Economy	10700.00
0005432429019	29254	Economy	10700.00
0005433656715	29254	Economy	10700.00
0005434143758	8664	Business	36500.00
0005434326059	8664	Business	36500.00
0005434143762	8664	Business	36500.00
0005434182443	8664	Business	36500.00
0005434095660	8664	Business	36500.00
0005434143759	8664	Economy	12200.00
0005434143754	8664	Economy	12200.00
0005434143755	8664	Economy	12200.00
0005434095659	8664	Economy	12200.00
0005434095651	8664	Economy	13400.00
0005434326057	8664	Economy	13400.00
0005434143756	8664	Economy	12200.00
0005434095649	8664	Economy	12200.00
0005434095654	8664	Economy	12200.00
0005434143757	8664	Economy	12200.00
0005434182383	8664	Economy	12200.00
0005434143766	8664	Economy	12200.00
0005434143765	8664	Economy	12200.00
0005434095662	8664	Economy	12200.00
0005434095657	8664	Economy	12200.00
0005434095655	8664	Economy	12200.00
0005434095652	8664	Economy	12200.00
0005434143763	8664	Economy	12200.00
0005434326058	8664	Economy	12200.00
0005434143760	8664	Economy	12200.00
0005434095653	8664	Economy	12200.00
0005434095650	8664	Economy	12200.00
0005434182400	8664	Economy	12200.00
0005434095658	8664	Economy	12200.00
0005434095656	8664	Economy	12200.00
0005434143764	8664	Economy	12200.00
0005434182399	8664	Economy	12200.00
0005434182456	8664	Economy	12200.00
0005434143761	8664	Economy	12200.00
0005434095661	8664	Economy	12200.00
0005435860680	11633	Business	36500.00
0005434095507	11633	Business	36500.00
0005434184717	11633	Business	36500.00
0005434182515	11633	Business	36500.00
0005434095517	11633	Business	36500.00
0005434183632	11633	Economy	12200.00
0005434182508	11633	Economy	12200.00
0005434095601	11633	Economy	13400.00
0005434095506	11633	Economy	13400.00
0005434182514	11633	Economy	13400.00
0005434182517	11633	Economy	12200.00
0005434183633	11633	Economy	12200.00
0005434182509	11633	Economy	12200.00
0005434095546	11633	Economy	12200.00
0005434143750	11633	Economy	12200.00
0005434182510	11633	Economy	12200.00
0005434095580	11633	Economy	12200.00
0005434095473	11633	Economy	12200.00
0005434095535	11633	Economy	12200.00
0005434095514	11633	Economy	12200.00
0005434095600	11633	Economy	12200.00
0005434095511	11633	Economy	12200.00
0005434095549	11633	Economy	12200.00
0005434095510	11633	Economy	12200.00
0005434182518	11633	Economy	12200.00
0005434095518	11633	Economy	12200.00
0005434182511	11633	Economy	12200.00
0005434183631	11633	Economy	12200.00
0005434143749	11633	Economy	12200.00
0005434095545	11633	Economy	12200.00
0005434182512	11633	Economy	12200.00
0005434095569	11633	Economy	12200.00
0005434182516	11633	Economy	12200.00
0005434095524	11633	Economy	12200.00
0005434184718	11633	Economy	12200.00
0005434095533	11633	Economy	12200.00
0005434095495	11633	Economy	12200.00
0005434182513	11633	Economy	12200.00
0005433399033	1422	Business	33000.00
0005433398817	1422	Business	33000.00
0005433398947	1422	Business	33000.00
0005435725755	1422	Business	33000.00
0005435732660	1422	Business	33000.00
0005435732653	1422	Business	33000.00
0005433398835	1422	Business	33000.00
0005433398838	1422	Business	33000.00
0005433398953	1422	Business	33000.00
0005433398754	1422	Economy	11000.00
0005433398911	1422	Economy	11000.00
0005433457078	1422	Economy	11000.00
0005432297348	1422	Economy	11000.00
0005433399117	1422	Economy	11000.00
0005432297347	1422	Economy	11000.00
0005433399032	1422	Economy	11000.00
0005433398945	1422	Economy	11000.00
0005433457075	1422	Economy	12100.00
0005433398697	1422	Economy	12100.00
0005435732658	1422	Economy	12100.00
0005433398827	1422	Economy	12100.00
0005433457076	1422	Economy	11000.00
0005435725753	1422	Economy	11000.00
0005433399130	1422	Economy	11000.00
0005433398751	1422	Economy	11000.00
0005435732654	1422	Economy	11000.00
0005433398967	1422	Economy	11000.00
0005433398846	1422	Economy	11000.00
0005435732657	1422	Economy	11000.00
0005433398888	1422	Economy	11000.00
0005435732655	1422	Economy	11000.00
0005435725757	1422	Economy	11000.00
0005433398696	1422	Economy	11000.00
0005432906583	1422	Economy	11000.00
0005433399039	1422	Economy	11000.00
0005435732668	1422	Economy	11000.00
0005435725752	1422	Economy	11000.00
0005435732669	1422	Economy	11000.00
0005433398818	1422	Economy	11000.00
0005435732663	1422	Economy	11000.00
0005435732667	1422	Economy	11000.00
0005433398939	1422	Economy	11000.00
0005433398867	1422	Economy	11000.00
0005433457077	1422	Economy	11000.00
0005435732661	1422	Economy	11000.00
0005435732665	1422	Economy	11000.00
0005433398777	1422	Economy	11000.00
0005433398912	1422	Economy	11000.00
0005432906562	1422	Economy	11000.00
0005433398894	1422	Economy	11000.00
0005433398832	1422	Economy	11000.00
0005433399013	1422	Economy	11000.00
0005433398949	1422	Economy	11000.00
0005435732664	1422	Economy	11000.00
0005433398875	1422	Economy	11000.00
0005433398662	1422	Economy	11000.00
0005435732652	1422	Economy	11000.00
0005433398893	1422	Economy	11000.00
0005435725756	1422	Economy	11000.00
0005435732659	1422	Economy	11000.00
0005433398705	1422	Economy	11000.00
0005433398876	1422	Economy	11000.00
0005433398946	1422	Economy	11000.00
0005433398925	1422	Economy	11000.00
0005433398760	1422	Economy	11000.00
0005433398983	1422	Economy	11000.00
0005435725754	1422	Economy	11000.00
0005433398845	1422	Economy	11000.00
0005433399129	1422	Economy	11000.00
0005433398850	1422	Economy	11000.00
0005435732656	1422	Economy	11000.00
0005433398834	1422	Economy	11000.00
0005432297346	1422	Economy	11000.00
0005433457079	1422	Economy	11000.00
0005435732662	1422	Economy	11000.00
0005433398805	1422	Economy	11000.00
0005433398952	1422	Economy	11000.00
0005435732651	1422	Economy	11000.00
0005435732666	1422	Economy	11000.00
0005433398753	1422	Economy	11000.00
0005433398889	1422	Economy	11000.00
0005433399329	19249	Business	33000.00
0005432906601	19249	Business	33000.00
0005435732581	19249	Business	33000.00
0005433399310	19249	Business	33000.00
0005433399333	19249	Business	33000.00
0005433399317	19249	Economy	11000.00
0005433399316	19249	Economy	11000.00
0005433399322	19249	Economy	11000.00
0005433399323	19249	Economy	11000.00
0005433399332	19249	Economy	11000.00
0005433399335	19249	Economy	12100.00
0005433399318	19249	Economy	12100.00
0005433399334	19249	Economy	11000.00
0005433399336	19249	Economy	11000.00
0005433399337	19249	Economy	11000.00
0005433399328	19249	Economy	11000.00
0005433399325	19249	Economy	11000.00
0005433399326	19249	Economy	11000.00
0005433399311	19249	Economy	11000.00
0005435732558	19249	Economy	11000.00
0005433399331	19249	Economy	11000.00
0005433399339	19249	Economy	11000.00
0005433399312	19249	Economy	11000.00
0005435732600	19249	Economy	11000.00
0005433399314	19249	Economy	11000.00
0005435732537	19249	Economy	11000.00
0005435732553	19249	Economy	11000.00
0005432906602	19249	Economy	11000.00
0005433399324	19249	Economy	11000.00
0005435732554	19249	Economy	11000.00
0005433399315	19249	Economy	11000.00
0005435732566	19249	Economy	11000.00
0005433399330	19249	Economy	11000.00
0005433399320	19249	Economy	11000.00
0005435732565	19249	Economy	11000.00
0005433399313	19249	Economy	11000.00
0005435732560	19249	Economy	11000.00
0005433399319	19249	Economy	11000.00
0005435732572	19249	Economy	11000.00
0005433399321	19249	Economy	11000.00
0005433399338	19249	Economy	11000.00
0005435732509	19249	Economy	11000.00
0005435732510	19249	Economy	11000.00
0005433399327	19249	Economy	11000.00
0005433399308	19249	Economy	11000.00
0005435732536	19249	Economy	11000.00
0005432906600	19249	Economy	11000.00
0005435732570	19249	Economy	11000.00
0005435732580	19249	Economy	11000.00
0005433399309	19249	Economy	11000.00
0005435732571	19249	Economy	11000.00
0005435732559	19249	Economy	11000.00
0005434444029	17374	Economy	15600.00
0005434443988	17374	Economy	14100.00
0005434443886	17374	Economy	14100.00
0005434444005	17374	Economy	14100.00
0005434443975	17374	Economy	14100.00
0005434443976	17374	Economy	14100.00
0005434443969	17374	Economy	14100.00
0005434444004	17374	Economy	14100.00
0005434443999	17374	Economy	14100.00
0005434443989	17374	Economy	14100.00
0005434443986	17374	Economy	14100.00
0005434443941	17374	Economy	14100.00
0005434444007	17374	Economy	14100.00
0005434443995	17374	Economy	14100.00
0005434443977	17374	Economy	14100.00
0005434443978	17374	Economy	14100.00
0005434443993	17374	Economy	14100.00
0005434444006	17374	Economy	14100.00
0005434443870	17374	Economy	14100.00
0005434444125	20560	Economy	15600.00
0005434444127	20560	Economy	14100.00
0005434444121	20560	Economy	14100.00
0005434444117	20560	Economy	14100.00
0005434444118	20560	Economy	14100.00
0005434444119	20560	Economy	14100.00
0005434444128	20560	Economy	14100.00
0005434444130	20560	Economy	14100.00
0005434444120	20560	Economy	14100.00
0005434444124	20560	Economy	14100.00
0005434444123	20560	Economy	14100.00
0005434444129	20560	Economy	14100.00
0005434444122	20560	Economy	14100.00
0005434444126	20560	Economy	14100.00
0005434954713	7289	Economy	5800.00
0005434954709	7289	Economy	5800.00
0005435377622	7289	Economy	5800.00
0005434954711	7289	Economy	5800.00
0005435377629	7289	Economy	5800.00
0005435377630	7289	Economy	5800.00
0005434954714	7289	Economy	5800.00
0005434954712	7289	Economy	5800.00
0005434954710	7289	Economy	5800.00
0005434954651	28345	Economy	5800.00
0005434954652	28345	Economy	5800.00
0005434954686	28345	Economy	5800.00
0005434954675	28345	Economy	5800.00
0005434954681	28345	Economy	5800.00
0005435377643	28345	Economy	5800.00
0005435377641	28345	Economy	5800.00
0005434954685	28345	Economy	5800.00
0005435377642	28345	Economy	5800.00
0005434352030	4467	Economy	15400.00
0005435893761	4467	Economy	15400.00
0005434326100	4467	Economy	14000.00
0005435893759	4467	Economy	14000.00
0005435893762	4467	Economy	14000.00
0005435893746	4467	Economy	14000.00
0005434352033	4467	Economy	14000.00
0005434326099	4467	Economy	14000.00
0005434183610	4467	Economy	14000.00
0005435893763	4467	Economy	14000.00
0005434326101	4467	Economy	14000.00
0005435893764	4467	Economy	14000.00
0005434352035	4467	Economy	14000.00
0005434352031	4467	Economy	14000.00
0005434352028	4467	Economy	14000.00
0005434352034	4467	Economy	14000.00
0005435893760	4467	Economy	14000.00
0005434352032	4467	Economy	14000.00
0005434352036	4467	Economy	14000.00
0005434352029	4467	Economy	14000.00
0005435893816	29642	Economy	15400.00
0005435893817	29642	Economy	15400.00
0005434351923	29642	Economy	14000.00
0005435893821	29642	Economy	14000.00
0005434351912	29642	Economy	14000.00
0005435893818	29642	Economy	14000.00
0005434351979	29642	Economy	14000.00
0005434351920	29642	Economy	14000.00
0005434351954	29642	Economy	14000.00
0005434351911	29642	Economy	14000.00
0005435893820	29642	Economy	14000.00
0005435893819	29642	Economy	14000.00
0005434351998	29642	Economy	14000.00
0005435893822	29642	Economy	14000.00
0005435092332	1039	Business	30600.00
0005435092334	1039	Business	30600.00
0005433159369	1039	Business	30600.00
0005433345081	1039	Business	30600.00
0005433269817	1039	Business	30600.00
0005435545938	1039	Business	30600.00
0005434445309	1039	Business	30600.00
0005433269821	1039	Business	30600.00
0005433345041	1039	Business	30600.00
0005433344808	1039	Business	30600.00
0005433344243	1039	Business	30600.00
0005433345017	1039	Business	30600.00
0005433344633	1039	Business	30600.00
0005433344759	1039	Business	30600.00
0005434446581	1039	Business	30600.00
0005433345110	1039	Business	30600.00
0005434445311	1039	Business	30600.00
0005433344902	1039	Economy	11200.00
0005435545935	1039	Economy	11200.00
0005435545932	1039	Economy	10200.00
0005433344241	1039	Economy	10200.00
0005433269793	1039	Economy	10200.00
0005433344583	1039	Economy	10200.00
0005433344242	1039	Economy	10200.00
0005433345187	1039	Economy	10200.00
0005433344473	1039	Economy	10200.00
0005435545984	1039	Economy	10200.00
0005433344384	1039	Economy	10200.00
0005433344925	1039	Economy	10200.00
0005435092336	1039	Economy	10200.00
0005435545987	1039	Economy	10200.00
0005433345271	1039	Economy	10200.00
0005433269785	1039	Economy	10200.00
0005433345042	1039	Economy	10200.00
0005433345298	1039	Economy	10200.00
0005433158171	1039	Economy	10200.00
0005433344817	1039	Economy	10200.00
0005433344861	1039	Economy	10200.00
0005435545943	1039	Economy	10200.00
0005433269822	1039	Economy	10200.00
0005433344892	1039	Economy	10200.00
0005435545929	1039	Economy	10200.00
0005435545930	1039	Economy	10200.00
0005435092337	1039	Economy	10200.00
0005433344582	1039	Economy	10200.00
0005435545982	1039	Economy	10200.00
0005433344934	1039	Economy	10200.00
0005435545939	1039	Economy	10200.00
0005433344672	1039	Economy	10200.00
0005435092339	1039	Economy	10200.00
0005433344665	1039	Economy	10200.00
0005433344893	1039	Economy	10200.00
0005433463958	1039	Economy	10200.00
0005435092333	1039	Economy	10200.00
0005433344849	1039	Economy	10200.00
0005433344807	1039	Economy	10200.00
0005433345016	1039	Economy	10200.00
0005433345022	1039	Economy	10200.00
0005433344999	1039	Economy	10200.00
0005433344681	1039	Economy	10200.00
0005433345070	1039	Economy	10200.00
0005433269823	1039	Economy	10200.00
0005433345023	1039	Economy	10200.00
0005433463959	1039	Economy	10200.00
0005435545940	1039	Economy	10200.00
0005433345100	1039	Economy	10200.00
0005433345010	1039	Economy	10200.00
0005433344935	1039	Economy	10200.00
0005433344916	1039	Economy	10200.00
0005433269786	1039	Economy	10200.00
0005433344543	1039	Economy	10200.00
0005433344910	1039	Economy	10200.00
0005435545931	1039	Economy	10200.00
0005433344574	1039	Economy	10200.00
0005435092335	1039	Economy	10200.00
0005433344886	1039	Economy	10200.00
0005433344635	1039	Economy	10200.00
0005433344889	1039	Economy	10200.00
0005434445312	1039	Economy	10200.00
0005433344459	1039	Economy	10200.00
0005433344401	1039	Economy	10200.00
0005433344331	1039	Economy	10200.00
0005433344385	1039	Economy	10200.00
0005433345034	1039	Economy	10200.00
0005433344913	1039	Economy	10200.00
0005433345011	1039	Economy	10200.00
0005435545944	1039	Economy	10200.00
0005433344610	1039	Economy	10200.00
0005433269787	1039	Economy	10200.00
0005433344474	1039	Economy	11200.00
0005433345114	1039	Economy	11200.00
0005433345200	1039	Economy	10200.00
0005433344730	1039	Economy	10200.00
0005433345065	1039	Economy	10200.00
0005432293272	1039	Economy	10200.00
0005435545936	1039	Economy	10200.00
0005433345021	1039	Economy	10200.00
0005433345006	1039	Economy	10200.00
0005433269833	1039	Economy	10200.00
0005435545985	1039	Economy	10200.00
0005435545986	1039	Economy	10200.00
0005433344860	1039	Economy	10200.00
0005433345026	1039	Economy	10200.00
0005433345018	1039	Economy	10200.00
0005435545941	1039	Economy	10200.00
0005433345212	1039	Economy	10200.00
0005433345101	1039	Economy	10200.00
0005435545934	1039	Economy	10200.00
0005433344848	1039	Economy	10200.00
0005433344905	1039	Economy	10200.00
0005435545945	1039	Economy	10200.00
0005433344836	1039	Economy	10200.00
0005433344793	1039	Economy	10200.00
0005433345270	1039	Economy	10200.00
0005435545937	1039	Economy	10200.00
0005433344355	1039	Economy	10200.00
0005433345112	1039	Economy	10200.00
0005433344729	1039	Economy	10200.00
0005433344911	1039	Economy	10200.00
0005433345043	1039	Economy	10200.00
0005433344857	1039	Economy	10200.00
0005434445310	1039	Economy	10200.00
0005433344856	1039	Economy	10200.00
0005433344673	1039	Economy	10200.00
0005435545933	1039	Economy	10200.00
0005433463960	1039	Economy	10200.00
0005433345115	1039	Economy	10200.00
0005435545983	1039	Economy	10200.00
0005435092338	1039	Economy	10200.00
0005433345007	1039	Economy	10200.00
0005433344837	1039	Economy	10200.00
0005435545942	1039	Economy	10200.00
0005434446580	1039	Economy	10200.00
0005434446582	1039	Economy	10200.00
0005433345020	1039	Economy	10200.00
0005433344894	1039	Economy	10200.00
0005433344785	1039	Economy	10200.00
0005433344542	1039	Economy	10200.00
0005433345113	1039	Economy	10200.00
0005433269818	1039	Economy	10200.00
0005433344685	1039	Economy	10200.00
0005433159368	1039	Economy	10200.00
0005434445313	1039	Economy	10200.00
0005433344682	1039	Economy	10200.00
0005433344859	1039	Economy	10200.00
0005433269820	1039	Economy	10200.00
0005433344666	1039	Economy	10200.00
0005433158176	1039	Economy	10200.00
0005433345064	1039	Economy	10200.00
0005432293273	1039	Economy	10200.00
0005435545928	1039	Economy	10200.00
0005435092340	1039	Economy	10200.00
0005433345717	17041	Business	30600.00
0005433345739	17041	Business	30600.00
0005433345720	17041	Business	30600.00
0005433345737	17041	Business	30600.00
0005435508586	17041	Business	30600.00
0005433345682	17041	Business	30600.00
0005433345719	17041	Business	30600.00
0005433345687	17041	Business	30600.00
0005434445278	17041	Business	30600.00
0005433345664	17041	Business	30600.00
0005433158201	17041	Business	30600.00
0005433345673	17041	Business	30600.00
0005435092264	17041	Business	30600.00
0005433345670	17041	Business	30600.00
0005435092223	17041	Business	30600.00
0005433345725	17041	Business	30600.00
0005435092262	17041	Economy	11200.00
0005433345709	17041	Economy	11200.00
0005433345676	17041	Economy	10200.00
0005435092299	17041	Economy	10200.00
0005433345658	17041	Economy	10200.00
0005433345705	17041	Economy	10200.00
0005433345698	17041	Economy	10200.00
0005433345675	17041	Economy	10200.00
0005433345714	17041	Economy	10200.00
0005435508585	17041	Economy	10200.00
0005435092224	17041	Economy	10200.00
0005435508546	17041	Economy	10200.00
0005433345678	17041	Economy	10200.00
0005433345689	17041	Economy	10200.00
0005435092274	17041	Economy	10200.00
0005433345667	17041	Economy	10200.00
0005433345680	17041	Economy	10200.00
0005433345701	17041	Economy	10200.00
0005433345651	17041	Economy	10200.00
0005435508492	17041	Economy	10200.00
0005433345721	17041	Economy	10200.00
0005433345724	17041	Economy	10200.00
0005433345694	17041	Economy	10200.00
0005433345674	17041	Economy	10200.00
0005433159371	17041	Economy	10200.00
0005433345703	17041	Economy	10200.00
0005433345669	17041	Economy	10200.00
0005433345650	17041	Economy	10200.00
0005433345653	17041	Economy	10200.00
0005433345657	17041	Economy	10200.00
0005433345659	17041	Economy	10200.00
0005435092291	17041	Economy	10200.00
0005433345736	17041	Economy	10200.00
0005433345706	17041	Economy	10200.00
0005433345655	17041	Economy	10200.00
0005433345686	17041	Economy	10200.00
0005433345715	17041	Economy	10200.00
0005433269863	17041	Economy	10200.00
0005433345713	17041	Economy	10200.00
0005433345665	17041	Economy	10200.00
0005433345654	17041	Economy	10200.00
0005433345697	17041	Economy	10200.00
0005435508558	17041	Economy	10200.00
0005435508580	17041	Economy	10200.00
0005433345727	17041	Economy	10200.00
0005435092292	17041	Economy	10200.00
0005433345735	17041	Economy	10200.00
0005433345691	17041	Economy	10200.00
0005435092285	17041	Economy	10200.00
0005433345648	17041	Economy	10200.00
0005433159372	17041	Economy	10200.00
0005433158200	17041	Economy	10200.00
0005433345696	17041	Economy	10200.00
0005433345692	17041	Economy	10200.00
0005433345672	17041	Economy	10200.00
0005433345660	17041	Economy	10200.00
0005435092225	17041	Economy	10200.00
0005433345734	17041	Economy	10200.00
0005433345731	17041	Economy	10200.00
0005433345695	17041	Economy	10200.00
0005433269861	17041	Economy	10200.00
0005435092249	17041	Economy	11200.00
0005433159370	17041	Economy	10200.00
0005433345679	17041	Economy	10200.00
0005433345729	17041	Economy	10200.00
0005433345683	17041	Economy	10200.00
0005433345700	17041	Economy	10200.00
0005433345677	17041	Economy	10200.00
0005435508577	17041	Economy	10200.00
0005433345685	17041	Economy	10200.00
0005433345693	17041	Economy	10200.00
0005433345699	17041	Economy	10200.00
0005433345711	17041	Economy	10200.00
0005433345666	17041	Economy	10200.00
0005435508587	17041	Economy	10200.00
0005433345723	17041	Economy	10200.00
0005435508531	17041	Economy	10200.00
0005433269860	17041	Economy	10200.00
0005433345684	17041	Economy	10200.00
0005433345726	17041	Economy	10200.00
0005433345662	17041	Economy	10200.00
0005433345663	17041	Economy	10200.00
0005433345738	17041	Economy	10200.00
0005433345668	17041	Economy	10200.00
0005435508513	17041	Economy	10200.00
0005433269859	17041	Economy	10200.00
0005433345733	17041	Economy	10200.00
0005435508547	17041	Economy	10200.00
0005435092217	17041	Economy	10200.00
0005433345661	17041	Economy	10200.00
0005435508530	17041	Economy	10200.00
0005433345716	17041	Economy	10200.00
0005433345649	17041	Economy	10200.00
0005433345732	17041	Economy	10200.00
0005433345707	17041	Economy	10200.00
0005433345728	17041	Economy	10200.00
0005433345690	17041	Economy	10200.00
0005433269862	17041	Economy	10200.00
0005433345730	17041	Economy	10200.00
0005433345671	17041	Economy	10200.00
0005434445274	17041	Economy	10200.00
0005435092216	17041	Economy	10200.00
0005433345688	17041	Economy	10200.00
0005433345710	17041	Economy	10200.00
0005433345652	17041	Economy	10200.00
0005433345708	17041	Economy	10200.00
0005435508566	17041	Economy	10200.00
0005433345704	17041	Economy	10200.00
0005433345656	17041	Economy	10200.00
0005433345712	17041	Economy	10200.00
0005435092263	17041	Economy	10200.00
0005433345718	17041	Economy	10200.00
0005433345702	17041	Economy	10200.00
0005433345722	17041	Economy	10200.00
0005433345681	17041	Economy	10200.00
0005432159981	12764	Business	40300.00
0005434082205	12764	Business	40300.00
0005434068839	12764	Business	40300.00
0005434068884	12764	Business	40300.00
0005434068393	12764	Business	40300.00
0005434026739	12764	Business	40300.00
0005432161212	12764	Business	40300.00
0005434068723	12764	Business	40300.00
0005435283475	12764	Business	40300.00
0005434068398	12764	Business	40300.00
0005434068787	12764	Business	40300.00
0005435283481	12764	Business	40300.00
0005434082264	12764	Economy	13400.00
0005434068682	12764	Economy	13400.00
0005435283477	12764	Economy	13400.00
0005434068764	12764	Economy	13400.00
0005435283471	12764	Economy	13400.00
0005435283467	12764	Economy	13400.00
0005434068845	12764	Economy	13400.00
0005434068726	12764	Economy	13400.00
0005432159980	12764	Economy	13400.00
0005434068989	12764	Economy	13400.00
0005434068676	12764	Economy	13400.00
0005434068800	12764	Economy	13400.00
0005434068389	12764	Economy	13400.00
0005433989824	12764	Economy	13400.00
0005434082296	12764	Economy	13400.00
0005434068748	12764	Economy	13400.00
0005434068809	12764	Economy	13400.00
0005432159978	12764	Economy	13400.00
0005434068516	12764	Economy	13400.00
0005434068943	12764	Economy	13400.00
0005434026741	12764	Economy	13400.00
0005434069013	12764	Economy	13400.00
0005434068916	12764	Economy	13400.00
0005435283465	12764	Economy	13400.00
0005434068860	12764	Economy	13400.00
0005434068829	12764	Economy	13400.00
0005434068388	12764	Economy	13400.00
0005434082145	12764	Economy	13400.00
0005434082248	12764	Economy	13400.00
0005434068832	12764	Economy	13400.00
0005434082263	12764	Economy	13400.00
0005434082239	12764	Economy	13400.00
0005435283479	12764	Economy	13400.00
0005434068679	12764	Economy	13400.00
0005434069224	12764	Economy	13400.00
0005434082410	12764	Economy	13400.00
0005434068844	12764	Economy	13400.00
0005435283478	12764	Economy	13400.00
0005434068770	12764	Economy	13400.00
0005434082380	12764	Economy	14800.00
0005434068688	12764	Economy	14800.00
0005434068658	12764	Economy	14800.00
0005432161213	12764	Economy	14800.00
0005433989823	12764	Economy	14800.00
0005435283468	12764	Economy	14800.00
0005434082294	12764	Economy	13400.00
0005434068988	12764	Economy	13400.00
0005434069113	12764	Economy	13400.00
0005434068994	12764	Economy	13400.00
0005432433823	12764	Economy	13400.00
0005435283476	12764	Economy	13400.00
0005433989854	12764	Economy	13400.00
0005434068724	12764	Economy	13400.00
0005434068883	12764	Economy	13400.00
0005434082265	12764	Economy	13400.00
0005434068876	12764	Economy	13400.00
0005435283473	12764	Economy	13400.00
0005435283472	12764	Economy	13400.00
0005434069225	12764	Economy	13400.00
0005433989853	12764	Economy	13400.00
0005434082295	12764	Economy	13400.00
0005434068828	12764	Economy	13400.00
0005434068749	12764	Economy	13400.00
0005434082302	12764	Economy	13400.00
0005432161211	12764	Economy	13400.00
0005432159979	12764	Economy	13400.00
0005434068779	12764	Economy	13400.00
0005435283464	12764	Economy	13400.00
0005434068739	12764	Economy	13400.00
0005435283482	12764	Economy	13400.00
0005434068687	12764	Economy	13400.00
0005435283484	12764	Economy	13400.00
0005432433821	12764	Economy	13400.00
0005434082337	12764	Economy	13400.00
0005433989844	12764	Economy	13400.00
0005435283469	12764	Economy	13400.00
0005434082249	12764	Economy	13400.00
0005432433820	12764	Economy	13400.00
0005434068998	12764	Economy	13400.00
0005434068675	12764	Economy	13400.00
0005434082293	12764	Economy	13400.00
0005434068678	12764	Economy	13400.00
0005434068706	12764	Economy	13400.00
0005434082338	12764	Economy	13400.00
0005435283474	12764	Economy	13400.00
0005432159982	12764	Economy	13400.00
0005435283480	12764	Economy	13400.00
0005434068685	12764	Economy	13400.00
0005434068523	12764	Economy	13400.00
0005434068669	12764	Economy	13400.00
0005435283466	12764	Economy	13400.00
0005432433822	12764	Economy	13400.00
0005434082273	12764	Economy	13400.00
0005435283463	12764	Economy	13400.00
0005435283462	12764	Economy	13400.00
0005433989825	12764	Economy	13400.00
0005434068761	12764	Economy	13400.00
0005435283485	12764	Economy	13400.00
0005435283483	12764	Economy	13400.00
0005434068795	12764	Economy	13400.00
0005434082327	12764	Economy	13400.00
0005434068522	12764	Economy	13400.00
0005434068808	12764	Economy	13400.00
0005434068778	12764	Economy	13400.00
0005434026742	12764	Economy	13400.00
0005434068672	12764	Economy	13400.00
0005435283470	12764	Economy	13400.00
0005434068725	12764	Economy	13400.00
0005434068587	12764	Economy	13400.00
0005433989860	12764	Economy	13400.00
0005434068893	12764	Economy	13400.00
0005434069369	30682	Business	40300.00
0005434069353	30682	Business	40300.00
0005434026753	30682	Business	40300.00
0005434082531	30682	Business	40300.00
0005434082536	30682	Business	40300.00
0005434069343	30682	Business	40300.00
0005433812926	30682	Business	40300.00
0005434082519	30682	Business	40300.00
0005434069358	30682	Business	40300.00
0005434069384	30682	Business	40300.00
0005434082523	30682	Economy	13400.00
0005434069352	30682	Economy	13400.00
0005434069394	30682	Economy	13400.00
0005434069347	30682	Economy	13400.00
0005434069392	30682	Economy	13400.00
0005434069341	30682	Economy	13400.00
0005434082530	30682	Economy	13400.00
0005434069338	30682	Economy	13400.00
0005434069365	30682	Economy	13400.00
0005434082526	30682	Economy	13400.00
0005434069356	30682	Economy	13400.00
0005434082513	30682	Economy	13400.00
0005434069378	30682	Economy	13400.00
0005434069395	30682	Economy	13400.00
0005434069375	30682	Economy	13400.00
0005434069380	30682	Economy	13400.00
0005434082532	30682	Economy	13400.00
0005432150398	30682	Economy	13400.00
0005434069396	30682	Economy	13400.00
0005434069362	30682	Economy	13400.00
0005432433787	30682	Economy	13400.00
0005433989894	30682	Economy	13400.00
0005434069344	30682	Economy	13400.00
0005434069350	30682	Economy	13400.00
0005433989890	30682	Economy	13400.00
0005434069337	30682	Economy	13400.00
0005434069391	30682	Economy	13400.00
0005434069389	30682	Economy	13400.00
0005434069388	30682	Economy	13400.00
0005434082517	30682	Economy	13400.00
0005432150396	30682	Economy	13400.00
0005434082515	30682	Economy	13400.00
0005434069399	30682	Economy	13400.00
0005434069357	30682	Economy	13400.00
0005434026754	30682	Economy	13400.00
0005432150393	30682	Economy	13400.00
0005434082511	30682	Economy	13400.00
0005435283418	30682	Economy	14800.00
0005434082521	30682	Economy	14800.00
0005432433766	30682	Economy	14800.00
0005434082520	30682	Economy	14800.00
0005434082528	30682	Economy	14800.00
0005434069363	30682	Economy	14800.00
0005433989892	30682	Economy	13400.00
0005434082512	30682	Economy	13400.00
0005434082527	30682	Economy	13400.00
0005434069370	30682	Economy	13400.00
0005434026756	30682	Economy	13400.00
0005434069379	30682	Economy	13400.00
0005432433753	30682	Economy	13400.00
0005433812934	30682	Economy	13400.00
0005434069355	30682	Economy	13400.00
0005434069400	30682	Economy	13400.00
0005433989891	30682	Economy	13400.00
0005434026751	30682	Economy	13400.00
0005432150394	30682	Economy	13400.00
0005434082516	30682	Economy	13400.00
0005434069398	30682	Economy	13400.00
0005433989893	30682	Economy	13400.00
0005434082534	30682	Economy	13400.00
0005434069349	30682	Economy	13400.00
0005434026755	30682	Economy	13400.00
0005434069342	30682	Economy	13400.00
0005434082522	30682	Economy	13400.00
0005434069397	30682	Economy	13400.00
0005434069348	30682	Economy	13400.00
0005432186963	30682	Economy	13400.00
0005434082535	30682	Economy	13400.00
0005434069377	30682	Economy	13400.00
0005434069376	30682	Economy	13400.00
0005434069340	30682	Economy	13400.00
0005434069366	30682	Economy	13400.00
0005434069360	30682	Economy	13400.00
0005434069387	30682	Economy	13400.00
0005432150392	30682	Economy	13400.00
0005434069368	30682	Economy	13400.00
0005434069371	30682	Economy	13400.00
0005434082533	30682	Economy	13400.00
0005434069345	30682	Economy	13400.00
0005434069374	30682	Economy	13400.00
0005434069382	30682	Economy	13400.00
0005434082524	30682	Economy	13400.00
0005434069385	30682	Economy	13400.00
0005434082514	30682	Economy	13400.00
0005434069354	30682	Economy	13400.00
0005432150395	30682	Economy	13400.00
0005434082529	30682	Economy	13400.00
0005434026752	30682	Economy	13400.00
0005434069359	30682	Economy	13400.00
0005434069381	30682	Economy	13400.00
0005434082525	30682	Economy	13400.00
0005434069383	30682	Economy	13400.00
0005432150399	30682	Economy	13400.00
0005434069339	30682	Economy	13400.00
0005434069364	30682	Economy	13400.00
0005434069361	30682	Economy	13400.00
0005434069351	30682	Economy	13400.00
0005434069372	30682	Economy	13400.00
0005434069393	30682	Economy	13400.00
0005434069346	30682	Economy	13400.00
0005434069390	30682	Economy	13400.00
0005432150397	30682	Economy	13400.00
0005434069373	30682	Economy	13400.00
0005434082537	30682	Economy	13400.00
0005434069367	30682	Economy	13400.00
0005434082518	30682	Economy	13400.00
0005434069386	30682	Economy	13400.00
0005432186962	30682	Economy	13400.00
0005435283414	30682	Economy	13400.00
0005435767855	5522	Business	35300.00
0005435463113	5522	Business	35300.00
0005434265663	5522	Business	35300.00
0005435725726	5522	Business	35300.00
0005435767862	5522	Business	35300.00
0005435767880	5522	Business	35300.00
0005435462951	5522	Business	35300.00
0005435767890	5522	Business	35300.00
0005435767856	5522	Business	35300.00
0005433527367	5522	Business	35300.00
0005435463184	5522	Business	35300.00
0005434265633	5522	Business	35300.00
0005435767839	5522	Business	35300.00
0005435723095	5522	Business	35300.00
0005435720858	5522	Business	35300.00
0005434265469	5522	Business	35300.00
0005435767842	5522	Business	35300.00
0005435463203	5522	Business	35300.00
0005435767838	5522	Business	35300.00
0005434265662	5522	Business	35300.00
0005435463166	5522	Business	35300.00
0005435463005	5522	Business	35300.00
0005435767896	5522	Economy	12900.00
0005435723097	5522	Economy	12900.00
0005435767879	5522	Economy	12900.00
0005432140664	5522	Economy	12900.00
0005435767873	5522	Economy	11800.00
0005435720857	5522	Economy	11800.00
0005432535911	5522	Economy	11800.00
0005432535932	5522	Economy	11800.00
0005435463133	5522	Economy	11800.00
0005435767858	5522	Economy	11800.00
0005435767853	5522	Economy	11800.00
0005434265588	5522	Economy	11800.00
0005435767872	5522	Economy	11800.00
0005434265675	5522	Economy	11800.00
0005435463216	5522	Economy	11800.00
0005435722119	5522	Economy	11800.00
0005435463178	5522	Economy	11800.00
0005434265555	5522	Economy	11800.00
0005435463143	5522	Economy	11800.00
0005435767892	5522	Economy	11800.00
0005435767861	5522	Economy	11800.00
0005434265632	5522	Economy	11800.00
0005435735260	5522	Economy	11800.00
0005433527365	5522	Economy	11800.00
0005435767886	5522	Economy	11800.00
0005435463245	5522	Economy	11800.00
0005435463128	5522	Economy	11800.00
0005435462952	5522	Economy	11800.00
0005435463015	5522	Economy	11800.00
0005435767847	5522	Economy	11800.00
0005435463233	5522	Economy	11800.00
0005435767868	5522	Economy	11800.00
0005435767870	5522	Economy	11800.00
0005435463189	5522	Economy	11800.00
0005435463103	5522	Economy	11800.00
0005434265497	5522	Economy	11800.00
0005435463217	5522	Economy	11800.00
0005435767878	5522	Economy	11800.00
0005433529379	5522	Economy	11800.00
0005435463209	5522	Economy	11800.00
0005432535946	5522	Economy	11800.00
0005434265455	5522	Economy	11800.00
0005433527366	5522	Economy	11800.00
0005435767877	5522	Economy	11800.00
0005435463272	5522	Economy	11800.00
0005435463080	5522	Economy	11800.00
0005432140665	5522	Economy	11800.00
0005434265543	5522	Economy	11800.00
0005435767895	5522	Economy	11800.00
0005435462895	5522	Economy	11800.00
0005435767852	5522	Economy	11800.00
0005435463202	5522	Economy	11800.00
0005435767891	5522	Economy	11800.00
0005434265630	5522	Economy	11800.00
0005435463144	5522	Economy	11800.00
0005435463092	5522	Economy	11800.00
0005435767843	5522	Economy	11800.00
0005435723096	5522	Economy	11800.00
0005435767849	5522	Economy	11800.00
0005435767874	5522	Economy	11800.00
0005435767866	5522	Economy	11800.00
0005435463112	5522	Economy	11800.00
0005432535931	5522	Economy	11800.00
0005435767851	5522	Economy	11800.00
0005435767841	5522	Economy	11800.00
0005433529378	5522	Economy	11800.00
0005435463061	5522	Economy	11800.00
0005435462933	5522	Economy	11800.00
0005435463301	5522	Economy	11800.00
0005435463142	5522	Economy	11800.00
0005434265626	5522	Economy	11800.00
0005432535926	5522	Economy	11800.00
0005435722116	5522	Economy	11800.00
0005435463200	5522	Economy	11800.00
0005435767845	5522	Economy	11800.00
0005433527369	5522	Economy	11800.00
0005435767860	5522	Economy	11800.00
0005435767871	5522	Economy	11800.00
0005435767857	5522	Economy	11800.00
0005435767869	5522	Economy	11800.00
0005435463137	5522	Economy	11800.00
0005433527368	5522	Economy	12900.00
0005435767883	5522	Economy	11800.00
0005435463049	5522	Economy	12900.00
0005435767867	5522	Economy	11800.00
0005435463081	5522	Economy	11800.00
0005435767844	5522	Economy	11800.00
0005435463039	5522	Economy	12900.00
0005434265466	5522	Economy	11800.00
0005435767865	5522	Economy	12900.00
0005434265637	5522	Economy	11800.00
0005435725725	5522	Economy	11800.00
0005435462950	5522	Economy	11800.00
0005435767897	5522	Economy	11800.00
0005435767881	5522	Economy	11800.00
0005435767889	5522	Economy	11800.00
0005435767876	5522	Economy	11800.00
0005435767864	5522	Economy	11800.00
0005434831231	5522	Economy	11800.00
0005435767893	5522	Economy	11800.00
0005434265454	5522	Economy	11800.00
0005435463208	5522	Economy	11800.00
0005434265569	5522	Economy	11800.00
0005434265504	5522	Economy	11800.00
0005434265518	5522	Economy	11800.00
0005434265610	5522	Economy	11800.00
0005435463095	5522	Economy	11800.00
0005434265609	5522	Economy	11800.00
0005434265453	5522	Economy	11800.00
0005432140662	5522	Economy	11800.00
0005435767887	5522	Economy	11800.00
0005435463246	5522	Economy	11800.00
0005435725724	5522	Economy	11800.00
0005435767894	5522	Economy	11800.00
0005435463062	5522	Economy	11800.00
0005434831210	5522	Economy	11800.00
0005435463195	5522	Economy	11800.00
0005435463093	5522	Economy	11800.00
0005432535907	5522	Economy	11800.00
0005435463210	5522	Economy	11800.00
0005435722118	5522	Economy	11800.00
0005435767854	5522	Economy	11800.00
0005432535916	5522	Economy	11800.00
0005435463167	5522	Economy	11800.00
0005434265557	5522	Economy	11800.00
0005432535908	5522	Economy	11800.00
0005434831230	5522	Economy	11800.00
0005435735258	5522	Economy	11800.00
0005435767888	5522	Economy	11800.00
0005435735257	5522	Economy	11800.00
0005435463176	5522	Economy	11800.00
0005435735259	5522	Economy	11800.00
0005435767875	5522	Economy	11800.00
0005432140663	5522	Economy	11800.00
0005435722117	5522	Economy	11800.00
0005435723098	5522	Economy	11800.00
0005435767846	5522	Economy	11800.00
0005434265505	5522	Economy	11800.00
0005435463201	5522	Economy	11800.00
0005435462973	5522	Economy	11800.00
0005435767859	5522	Economy	11800.00
0005434265556	5522	Economy	11800.00
0005435767848	5522	Economy	11800.00
0005434265542	5522	Economy	11800.00
0005435767840	5522	Economy	11800.00
0005435767885	5522	Economy	11800.00
0005435767882	5522	Economy	11800.00
0005435463079	5522	Economy	11800.00
0005435767884	5522	Economy	11800.00
0005435463204	5522	Economy	11800.00
0005435463046	5522	Economy	11800.00
0005435767863	5522	Economy	11800.00
0005435463165	5522	Economy	11800.00
0005435767850	5522	Economy	11800.00
0005434265506	5522	Economy	11800.00
0005435463194	5522	Economy	11800.00
0005435767429	13455	Business	35300.00
0005434265811	13455	Business	35300.00
0005435767146	13455	Business	35300.00
0005433529328	13455	Business	35300.00
0005435767206	13455	Business	35300.00
0005435767360	13455	Business	35300.00
0005433533357	13455	Business	35300.00
0005435767165	13455	Business	35300.00
0005435735229	13455	Business	35300.00
0005435463410	13455	Business	35300.00
0005435463426	13455	Business	35300.00
0005433533366	13455	Business	35300.00
0005435463442	13455	Business	35300.00
0005435767204	13455	Business	35300.00
0005435767411	13455	Business	35300.00
0005433533376	13455	Business	35300.00
0005435767338	13455	Business	35300.00
0005433529331	13455	Business	35300.00
0005433533373	13455	Business	35300.00
0005434265812	13455	Business	35300.00
0005434265810	13455	Business	35300.00
0005435725688	13455	Business	35300.00
0005435463429	13455	Business	35300.00
0005435463415	13455	Business	35300.00
0005435767325	13455	Business	35300.00
0005433533378	13455	Business	35300.00
0005435463440	13455	Economy	12900.00
0005435767061	13455	Economy	12900.00
0005435720152	13455	Economy	12900.00
0005435767316	13455	Economy	12900.00
0005435767207	13455	Economy	11800.00
0005435463409	13455	Economy	11800.00
0005435767182	13455	Economy	11800.00
0005435766892	13455	Economy	11800.00
0005434265821	13455	Economy	11800.00
0005435767220	13455	Economy	11800.00
0005435767383	13455	Economy	11800.00
0005435463408	13455	Economy	11800.00
0005432194623	13455	Economy	11800.00
0005434265814	13455	Economy	11800.00
0005435463441	13455	Economy	11800.00
0005434831277	13455	Economy	11800.00
0005435767294	13455	Economy	11800.00
0005432194620	13455	Economy	11800.00
0005435767293	13455	Economy	11800.00
0005435767345	13455	Economy	11800.00
0005434265809	13455	Economy	11800.00
0005435767184	13455	Economy	11800.00
0005433533334	13455	Economy	11800.00
0005433529314	13455	Economy	11800.00
0005433533349	13455	Economy	11800.00
0005435767072	13455	Economy	11800.00
0005433529346	13455	Economy	11800.00
0005435735219	13455	Economy	11800.00
0005435767430	13455	Economy	11800.00
0005432535963	13455	Economy	11800.00
0005435766993	13455	Economy	11800.00
0005433533377	13455	Economy	11800.00
0005433529329	13455	Economy	11800.00
0005435463416	13455	Economy	11800.00
0005435463420	13455	Economy	11800.00
0005435767205	13455	Economy	11800.00
0005434265826	13455	Economy	11800.00
0005435463412	13455	Economy	11800.00
0005435463430	13455	Economy	11800.00
0005435767062	13455	Economy	11800.00
0005435463437	13455	Economy	11800.00
0005433529334	13455	Economy	11800.00
0005434265818	13455	Economy	11800.00
0005435043305	13455	Economy	11800.00
0005435723081	13455	Economy	11800.00
0005435463425	13455	Economy	11800.00
0005433529345	13455	Economy	11800.00
0005435617189	13455	Economy	11800.00
0005435767425	13455	Economy	11800.00
0005435767168	13455	Economy	11800.00
0005434265828	13455	Economy	11800.00
0005433533354	13455	Economy	11800.00
0005432535966	13455	Economy	11800.00
0005433533379	13455	Economy	11800.00
0005434265819	13455	Economy	11800.00
0005435617192	13455	Economy	11800.00
0005435463431	13455	Economy	11800.00
0005435617191	13455	Economy	11800.00
0005435723071	13455	Economy	11800.00
0005432194622	13455	Economy	11800.00
0005432535965	13455	Economy	11800.00
0005435720153	13455	Economy	11800.00
0005435767344	13455	Economy	11800.00
0005435767337	13455	Economy	11800.00
0005435767119	13455	Economy	11800.00
0005434265813	13455	Economy	11800.00
0005435463428	13455	Economy	11800.00
0005435463422	13455	Economy	11800.00
0005434265824	13455	Economy	11800.00
0005433533383	13455	Economy	11800.00
0005435463427	13455	Economy	11800.00
0005435767162	13455	Economy	11800.00
0005435722095	13455	Economy	11800.00
0005435767111	13455	Economy	11800.00
0005435767225	13455	Economy	11800.00
0005435767399	13455	Economy	11800.00
0005435463411	13455	Economy	11800.00
0005435767043	13455	Economy	11800.00
0005435463435	13455	Economy	11800.00
0005435767398	13455	Economy	11800.00
0005435767192	13455	Economy	11800.00
0005432535962	13455	Economy	11800.00
0005435463436	13455	Economy	11800.00
0005434831274	13455	Economy	11800.00
0005435463424	13455	Economy	12900.00
0005433533382	13455	Economy	11800.00
0005433533358	13455	Economy	12900.00
0005435767302	13455	Economy	11800.00
0005435767397	13455	Economy	11800.00
0005434265820	13455	Economy	12900.00
0005435767418	13455	Economy	11800.00
0005435767158	13455	Economy	11800.00
0005434265817	13455	Economy	11800.00
0005435767372	13455	Economy	11800.00
0005433529312	13455	Economy	11800.00
0005434831273	13455	Economy	11800.00
0005433529327	13455	Economy	11800.00
0005433533368	13455	Economy	11800.00
0005435463438	13455	Economy	11800.00
0005435463423	13455	Economy	11800.00
0005434265823	13455	Economy	11800.00
0005435463421	13455	Economy	11800.00
0005435463444	13455	Economy	11800.00
0005435767336	13455	Economy	11800.00
0005435767073	13455	Economy	11800.00
0005435617190	13455	Economy	11800.00
0005432194621	13455	Economy	11800.00
0005435463419	13455	Economy	11800.00
0005435722094	13455	Economy	11800.00
0005435463432	13455	Economy	11800.00
0005433533369	13455	Economy	11800.00
0005435767319	13455	Economy	11800.00
0005435767131	13455	Economy	11800.00
0005434265827	13455	Economy	11800.00
0005435463443	13455	Economy	11800.00
0005435767193	13455	Economy	11800.00
0005433529321	13455	Economy	11800.00
0005435767330	13455	Economy	11800.00
0005435463445	13455	Economy	11800.00
0005435767382	13455	Economy	11800.00
0005434831275	13455	Economy	11800.00
0005435767241	13455	Economy	11800.00
0005435463414	13455	Economy	11800.00
0005435725685	13455	Economy	11800.00
0005435767410	13455	Economy	11800.00
0005433533370	13455	Economy	11800.00
0005434265825	13455	Economy	11800.00
0005434265816	13455	Economy	11800.00
0005434831276	13455	Economy	11800.00
0005433529341	13455	Economy	11800.00
0005435767417	13455	Economy	11800.00
0005433533365	13455	Economy	11800.00
0005435767122	13455	Economy	11800.00
0005434265822	13455	Economy	11800.00
0005435463434	13455	Economy	11800.00
0005435463433	13455	Economy	11800.00
0005433533359	13455	Economy	11800.00
0005435463418	13455	Economy	11800.00
0005435463417	13455	Economy	11800.00
0005434265815	13455	Economy	11800.00
0005433533335	13455	Economy	11800.00
0005435766893	13455	Economy	11800.00
0005435767404	13455	Economy	11800.00
0005433529313	13455	Economy	11800.00
0005432535964	13455	Economy	11800.00
0005435463413	13455	Economy	11800.00
0005435767123	13455	Economy	11800.00
0005433529330	13455	Economy	11800.00
0005433533374	13455	Economy	11800.00
0005434265808	13455	Economy	11800.00
0005435463407	13455	Economy	11800.00
0005435463439	13455	Economy	11800.00
0005435767157	13455	Economy	11800.00
0005433529335	13455	Economy	11800.00
0005435767242	13455	Economy	11800.00
0005434602941	18674	Economy	3300.00
0005434602942	18674	Economy	3300.00
0005434602956	18674	Economy	3300.00
0005434513648	18678	Economy	3300.00
0005434604957	18678	Economy	3300.00
0005434513649	18678	Economy	3300.00
0005434515036	18678	Economy	3300.00
0005434604953	18678	Economy	3300.00
0005434513646	18678	Economy	3300.00
0005434604950	18678	Economy	3300.00
0005434604963	18678	Economy	3300.00
0005434513647	18678	Economy	3300.00
0005434604958	18678	Economy	3300.00
0005432632920	4113	Business	88300.00
0005432632918	4113	Business	88300.00
0005432649565	4113	Business	88300.00
0005435844391	4113	Business	88300.00
0005435844363	4113	Business	88300.00
0005432632926	4113	Business	88300.00
0005435844362	4113	Business	88300.00
0005432649560	4113	Business	88300.00
0005432632924	4113	Economy	29400.00
0005435846288	4113	Economy	29400.00
0005432632925	4113	Economy	29400.00
0005432632928	4113	Economy	29400.00
0005432632922	4113	Economy	32400.00
0005432649564	4113	Economy	32400.00
0005432649558	4113	Economy	32400.00
0005435846296	4113	Economy	29400.00
0005432632921	4113	Economy	29400.00
0005432649556	4113	Economy	29400.00
0005432649561	4113	Economy	29400.00
0005432649562	4113	Economy	29400.00
0005432632923	4113	Economy	29400.00
0005432649566	4113	Economy	29400.00
0005435844392	4113	Economy	29400.00
0005435844385	4113	Economy	29400.00
0005435846295	4113	Economy	29400.00
0005435846306	4113	Economy	29400.00
0005435846325	4113	Economy	29400.00
0005432632919	4113	Economy	29400.00
0005435846305	4113	Economy	29400.00
0005432632930	4113	Economy	29400.00
0005432649563	4113	Economy	29400.00
0005435846294	4113	Economy	29400.00
0005432632929	4113	Economy	29400.00
0005432632927	4113	Economy	29400.00
0005432649559	4113	Economy	29400.00
0005432649557	4113	Economy	29400.00
0005432632917	4113	Economy	29400.00
0005433285964	1774	Business	48700.00
0005433810714	1774	Business	48700.00
0005433810718	1774	Business	48700.00
0005433285843	1774	Business	48700.00
0005433285943	1774	Business	48700.00
0005433285983	1774	Business	48700.00
0005433009435	1774	Business	48700.00
0005433009522	1774	Business	48700.00
0005433009393	1774	Business	48700.00
0005433009420	1774	Business	48700.00
0005433285954	1774	Business	48700.00
0005432295949	1774	Business	48700.00
0005433009519	1774	Economy	16200.00
0005433009417	1774	Economy	16200.00
0005433009307	1774	Economy	16200.00
0005433009740	1774	Economy	16200.00
0005433009385	1774	Economy	16200.00
0005433285891	1774	Economy	16200.00
0005433285992	1774	Economy	16200.00
0005433009514	1774	Economy	16200.00
0005433285834	1774	Economy	16200.00
0005433009432	1774	Economy	16200.00
0005433009467	1774	Economy	17900.00
0005433009373	1774	Economy	17900.00
0005433285732	1774	Economy	17900.00
0005433009466	1774	Economy	17900.00
0005433009593	1774	Economy	17900.00
0005433810708	1774	Economy	16200.00
0005433009587	1774	Economy	16200.00
0005433009448	1774	Economy	16200.00
0005433009597	1774	Economy	16200.00
0005433285963	1774	Economy	16200.00
0005433810716	1774	Economy	16200.00
0005433009331	1774	Economy	16200.00
0005433285871	1774	Economy	16200.00
0005433009415	1774	Economy	16200.00
0005433285841	1774	Economy	16200.00
0005432295950	1774	Economy	16200.00
0005433810713	1774	Economy	16200.00
0005433285870	1774	Economy	16200.00
0005433810706	1774	Economy	16200.00
0005433285828	1774	Economy	16200.00
0005433009384	1774	Economy	16200.00
0005433810711	1774	Economy	16200.00
0005433810709	1774	Economy	16200.00
0005433009484	1774	Economy	16200.00
0005433285726	1774	Economy	16200.00
0005433009446	1774	Economy	16200.00
0005433009386	1774	Economy	16200.00
0005433009530	1774	Economy	16200.00
0005433009400	1774	Economy	16200.00
0005433009447	1774	Economy	16200.00
0005433285886	1774	Economy	16200.00
0005433810710	1774	Economy	16200.00
0005433009233	1774	Economy	16200.00
0005433009249	1774	Economy	16200.00
0005433285733	1774	Economy	16200.00
0005433285960	1774	Economy	16200.00
0005433009321	1774	Economy	16200.00
0005433009647	1774	Economy	16200.00
0005433810715	1774	Economy	16200.00
0005433009388	1774	Economy	16200.00
0005433810707	1774	Economy	16200.00
0005433009529	1774	Economy	16200.00
0005433285926	1774	Economy	16200.00
0005433009394	1774	Economy	16200.00
0005433285734	1774	Economy	16200.00
0005433009592	1774	Economy	16200.00
0005433810705	1774	Economy	16200.00
0005433810717	1774	Economy	16200.00
0005433009439	1774	Economy	16200.00
0005433009492	1774	Economy	16200.00
0005433285835	1774	Economy	16200.00
0005433285874	1774	Economy	16200.00
0005433009596	1774	Economy	16200.00
0005433009351	1774	Economy	16200.00
0005433285872	1774	Economy	16200.00
0005433285881	1774	Economy	16200.00
0005433285753	1774	Economy	16200.00
0005433009363	1774	Economy	16200.00
0005433286000	1774	Economy	16200.00
0005433285727	1774	Economy	16200.00
0005433810712	1774	Economy	16200.00
0005433009591	1774	Economy	16200.00
0005433009337	1774	Economy	16200.00
0005433009352	1774	Economy	16200.00
0005433009416	1774	Economy	16200.00
0005433285880	1774	Economy	16200.00
0005433285941	1774	Economy	16200.00
0005433009434	1774	Economy	16200.00
0005433009338	1774	Economy	16200.00
0005433285829	1774	Economy	16200.00
0005433810719	1774	Economy	16200.00
0005433285887	1774	Economy	16200.00
0005433009513	1774	Economy	16200.00
0005433285965	1774	Economy	16200.00
0005433009806	22630	Business	48700.00
0005433009789	22630	Business	48700.00
0005433286113	22630	Business	48700.00
0005433009795	22630	Business	48700.00
0005433009812	22630	Business	48700.00
0005433286097	22630	Business	48700.00
0005433009814	22630	Business	48700.00
0005433286106	22630	Business	48700.00
0005433286101	22630	Business	48700.00
0005433009771	22630	Business	48700.00
0005433009778	22630	Business	48700.00
0005433009803	22630	Economy	16200.00
0005433286095	22630	Economy	16200.00
0005433286098	22630	Economy	16200.00
0005433009792	22630	Economy	16200.00
0005433286102	22630	Economy	16200.00
0005433009800	22630	Economy	16200.00
0005433286090	22630	Economy	16200.00
0005433009776	22630	Economy	16200.00
0005433009785	22630	Economy	16200.00
0005433286089	22630	Economy	17900.00
0005433009810	22630	Economy	17900.00
0005433009797	22630	Economy	17900.00
0005433009772	22630	Economy	16200.00
0005433810590	22630	Economy	16200.00
0005433286100	22630	Economy	16200.00
0005433009815	22630	Economy	16200.00
0005433009770	22630	Economy	16200.00
0005433009781	22630	Economy	16200.00
0005433286096	22630	Economy	16200.00
0005433286109	22630	Economy	16200.00
0005433286091	22630	Economy	16200.00
0005433286115	22630	Economy	16200.00
0005433009816	22630	Economy	16200.00
0005433286104	22630	Economy	16200.00
0005433286107	22630	Economy	16200.00
0005433009775	22630	Economy	16200.00
0005433286111	22630	Economy	16200.00
0005433009808	22630	Economy	16200.00
0005433009784	22630	Economy	16200.00
0005433009813	22630	Economy	16200.00
0005433009780	22630	Economy	16200.00
0005433009790	22630	Economy	16200.00
0005433286093	22630	Economy	16200.00
0005433009804	22630	Economy	16200.00
0005433286103	22630	Economy	16200.00
0005433009794	22630	Economy	16200.00
0005433009779	22630	Economy	16200.00
0005433286112	22630	Economy	16200.00
0005433810609	22630	Economy	16200.00
0005433286099	22630	Economy	16200.00
0005433009798	22630	Economy	16200.00
0005433009801	22630	Economy	16200.00
0005433009787	22630	Economy	16200.00
0005433009773	22630	Economy	16200.00
0005433009783	22630	Economy	16200.00
0005433009774	22630	Economy	16200.00
0005433009805	22630	Economy	16200.00
0005433286108	22630	Economy	16200.00
0005433286094	22630	Economy	16200.00
0005433009811	22630	Economy	16200.00
0005433286110	22630	Economy	16200.00
0005433009777	22630	Economy	16200.00
0005433009782	22630	Economy	16200.00
0005433009796	22630	Economy	16200.00
0005433009802	22630	Economy	16200.00
0005433286105	22630	Economy	16200.00
0005433009809	22630	Economy	16200.00
0005433009799	22630	Economy	16200.00
0005433286114	22630	Economy	16200.00
0005433009788	22630	Economy	16200.00
0005433009807	22630	Economy	16200.00
0005433810606	22630	Economy	16200.00
0005433009793	22630	Economy	16200.00
0005433286092	22630	Economy	16200.00
0005433009786	22630	Economy	16200.00
0005433009791	22630	Economy	16200.00
0005433815508	5589	Business	99800.00
0005433848235	5589	Business	99800.00
0005433848252	5589	Business	99800.00
0005433848259	5589	Business	99800.00
0005435283044	5589	Business	99800.00
0005433848236	5589	Business	99800.00
0005433848246	5589	Business	99800.00
0005433848278	5589	Business	99800.00
0005433848279	5589	Business	99800.00
0005433848276	5589	Business	99800.00
0005433848254	5589	Business	99800.00
0005435283023	5589	Business	99800.00
0005433848260	5589	Business	99800.00
0005432081682	5589	Business	99800.00
0005433848250	5589	Business	99800.00
0005435282932	5589	Economy	33300.00
0005433815512	5589	Economy	33300.00
0005433848253	5589	Economy	33300.00
0005433848268	5589	Economy	33300.00
0005435283024	5589	Economy	33300.00
0005435282892	5589	Economy	33300.00
0005435282997	5589	Economy	33300.00
0005435282955	5589	Economy	33300.00
0005435282891	5589	Economy	33300.00
0005433848231	5589	Economy	33300.00
0005433848229	5589	Economy	33300.00
0005433848240	5589	Economy	33300.00
0005433848243	5589	Economy	36600.00
0005433848267	5589	Economy	36600.00
0005433848275	5589	Economy	36600.00
0005433848248	5589	Economy	36600.00
0005435282998	5589	Economy	33300.00
0005433815551	5589	Economy	33300.00
0005433848255	5589	Economy	33300.00
0005433848247	5589	Economy	33300.00
0005432081683	5589	Economy	33300.00
0005433848238	5589	Economy	33300.00
0005433848245	5589	Economy	33300.00
0005435282907	5589	Economy	33300.00
0005433848237	5589	Economy	33300.00
0005433848273	5589	Economy	33300.00
0005435282829	5589	Economy	33300.00
0005433848241	5589	Economy	33300.00
0005433815511	5589	Economy	33300.00
0005433848274	5589	Economy	33300.00
0005433848228	5589	Economy	33300.00
0005435282890	5589	Economy	33300.00
0005433848262	5589	Economy	33300.00
0005433848280	5589	Economy	33300.00
0005434173583	5589	Economy	33300.00
0005435282881	5589	Economy	33300.00
0005433848249	5589	Economy	33300.00
0005435282990	5589	Economy	33300.00
0005433815510	5589	Economy	33300.00
0005433848263	5589	Economy	33300.00
0005433848239	5589	Economy	33300.00
0005435282880	5589	Economy	33300.00
0005433848265	5589	Economy	33300.00
0005433848251	5589	Economy	33300.00
0005433848244	5589	Economy	33300.00
0005435282845	5589	Economy	33300.00
0005433848230	5589	Economy	33300.00
0005435282944	5589	Economy	33300.00
0005435282931	5589	Economy	33300.00
0005433848261	5589	Economy	33300.00
0005435283000	5589	Economy	33300.00
0005435282836	5589	Economy	33300.00
0005433848264	5589	Economy	33300.00
0005432081681	5589	Economy	33300.00
0005435283022	5589	Economy	33300.00
0005433848281	5589	Economy	33300.00
0005433848272	5589	Economy	33300.00
0005433848258	5589	Economy	33300.00
0005433848266	5589	Economy	33300.00
0005435283021	5589	Economy	33300.00
0005433815509	5589	Economy	33300.00
0005435282835	5589	Economy	33300.00
0005435283043	5589	Economy	33300.00
0005433848270	5589	Economy	33300.00
0005433848271	5589	Economy	33300.00
0005433848277	5589	Economy	33300.00
0005432081680	5589	Economy	33300.00
0005435283019	5589	Economy	33300.00
0005433848242	5589	Economy	33300.00
0005433848269	5589	Economy	33300.00
0005433848257	5589	Economy	33300.00
0005433848256	5589	Economy	33300.00
0005433815549	5589	Economy	33300.00
0005433848233	5589	Economy	33300.00
0005433848232	5589	Economy	33300.00
0005435283020	5589	Economy	33300.00
0005435282984	5589	Economy	33300.00
0005434173570	5589	Economy	33300.00
0005433815550	5589	Economy	33300.00
0005433848234	5589	Economy	33300.00
0005435283152	13834	Business	99800.00
0005433847511	13834	Business	99800.00
0005433847681	13834	Business	99800.00
0005435283166	13834	Business	99800.00
0005435283171	13834	Business	99800.00
0005433847870	13834	Business	99800.00
0005433815475	13834	Business	99800.00
0005433847797	13834	Business	99800.00
0005435283163	13834	Business	99800.00
0005434173654	13834	Business	99800.00
0005435283162	13834	Business	99800.00
0005435283155	13834	Business	99800.00
0005433847786	13834	Business	99800.00
0005432003784	13834	Business	99800.00
0005434173653	13834	Business	99800.00
0005433847565	13834	Business	99800.00
0005433847618	13834	Business	99800.00
0005435283170	13834	Economy	33300.00
0005433847860	13834	Economy	33300.00
0005435283172	13834	Economy	33300.00
0005435283154	13834	Economy	33300.00
0005433847532	13834	Economy	33300.00
0005434173627	13834	Economy	33300.00
0005433847930	13834	Economy	33300.00
0005433815468	13834	Economy	33300.00
0005434173626	13834	Economy	33300.00
0005433847592	13834	Economy	33300.00
0005433847875	13834	Economy	36600.00
0005433847798	13834	Economy	36600.00
0005433847874	13834	Economy	36600.00
0005435283165	13834	Economy	33300.00
0005433847940	13834	Economy	33300.00
0005433847823	13834	Economy	33300.00
0005433847907	13834	Economy	33300.00
0005435283175	13834	Economy	33300.00
0005433847846	13834	Economy	33300.00
0005433847928	13834	Economy	33300.00
0005433847791	13834	Economy	33300.00
0005435283161	13834	Economy	33300.00
0005433847557	13834	Economy	33300.00
0005433847581	13834	Economy	33300.00
0005435283157	13834	Economy	33300.00
0005433847810	13834	Economy	33300.00
0005433815474	13834	Economy	33300.00
0005433847660	13834	Economy	33300.00
0005435283159	13834	Economy	33300.00
0005433847712	13834	Economy	33300.00
0005435283177	13834	Economy	33300.00
0005435283151	13834	Economy	33300.00
0005433815467	13834	Economy	33300.00
0005433847831	13834	Economy	33300.00
0005433847785	13834	Economy	33300.00
0005435283176	13834	Economy	33300.00
0005435283158	13834	Economy	33300.00
0005433847752	13834	Economy	33300.00
0005433847929	13834	Economy	33300.00
0005433847695	13834	Economy	33300.00
0005433847965	13834	Economy	33300.00
0005432003785	13834	Economy	33300.00
0005433847568	13834	Economy	33300.00
0005433847918	13834	Economy	33300.00
0005435283173	13834	Economy	33300.00
0005435283169	13834	Economy	33300.00
0005434173625	13834	Economy	33300.00
0005433847883	13834	Economy	33300.00
0005433847626	13834	Economy	33300.00
0005433847964	13834	Economy	33300.00
0005433847976	13834	Economy	33300.00
0005433847873	13834	Economy	33300.00
0005433847575	13834	Economy	33300.00
0005433815470	13834	Economy	33300.00
0005434173655	13834	Economy	33300.00
0005433847751	13834	Economy	33300.00
0005433847564	13834	Economy	33300.00
0005433847591	13834	Economy	33300.00
0005433847788	13834	Economy	33300.00
0005435283174	13834	Economy	33300.00
0005433847771	13834	Economy	33300.00
0005433847576	13834	Economy	33300.00
0005433847753	13834	Economy	33300.00
0005435283153	13834	Economy	33300.00
0005433847686	13834	Economy	33300.00
0005435283160	13834	Economy	33300.00
0005435283156	13834	Economy	33300.00
0005433847835	13834	Economy	33300.00
0005433847824	13834	Economy	33300.00
0005435283168	13834	Economy	33300.00
0005433847774	13834	Economy	33300.00
0005433847631	13834	Economy	33300.00
0005433847713	13834	Economy	33300.00
0005433847919	13834	Economy	33300.00
0005434173628	13834	Economy	33300.00
0005435283167	13834	Economy	33300.00
0005433847894	13834	Economy	33300.00
0005433847941	13834	Economy	33300.00
0005435283164	13834	Economy	33300.00
0005433847917	13834	Economy	33300.00
0005433815469	13834	Economy	33300.00
0005433847836	13834	Economy	33300.00
0005435332537	7854	Economy	16600.00
0005434621126	7854	Economy	15100.00
0005434621136	7854	Economy	15100.00
0005435332546	7854	Economy	15100.00
0005434621138	7854	Economy	15100.00
0005434621127	7854	Economy	15100.00
0005434621137	7854	Economy	15100.00
0005434621129	7854	Economy	15100.00
0005434621133	7854	Economy	15100.00
0005434621134	7854	Economy	15100.00
0005435332564	7854	Economy	15100.00
0005434621130	7854	Economy	15100.00
0005435332548	7854	Economy	15100.00
0005435332565	7854	Economy	15100.00
0005434621125	7854	Economy	15100.00
0005435332567	7854	Economy	15100.00
0005434621132	7854	Economy	15100.00
0005435332561	7854	Economy	15100.00
0005435332539	7854	Economy	15100.00
0005435332543	7854	Economy	15100.00
0005435332513	7854	Economy	15100.00
0005435332560	7854	Economy	15100.00
0005435332540	7854	Economy	15100.00
0005434621124	7854	Economy	15100.00
0005435332514	7854	Economy	15100.00
0005435332542	7854	Economy	15100.00
0005434621139	7854	Economy	15100.00
0005435332498	7854	Economy	15100.00
0005435332547	7854	Economy	15100.00
0005434621135	7854	Economy	15100.00
0005435332566	7854	Economy	15100.00
0005434621131	7854	Economy	15100.00
0005432112575	7854	Economy	15100.00
0005435332512	7854	Economy	15100.00
0005434621128	7854	Economy	15100.00
0005435332549	7854	Economy	15100.00
0005434620959	32941	Economy	16600.00
0005435332609	32941	Economy	15100.00
0005434620905	32941	Economy	15100.00
0005435332612	32941	Economy	15100.00
0005434620948	32941	Economy	15100.00
0005434621011	32941	Economy	15100.00
0005434620913	32941	Economy	15100.00
0005434620962	32941	Economy	15100.00
0005434620925	32941	Economy	15100.00
0005435332610	32941	Economy	15100.00
0005435332607	32941	Economy	15100.00
0005435332608	32941	Economy	15100.00
0005434620914	32941	Economy	15100.00
0005434620901	32941	Economy	15100.00
0005435332605	32941	Economy	15100.00
0005434620902	32941	Economy	15100.00
0005434621003	32941	Economy	15100.00
0005434620957	32941	Economy	15100.00
0005434621002	32941	Economy	15100.00
0005434620990	32941	Economy	15100.00
0005434620963	32941	Economy	15100.00
0005434620964	32941	Economy	15100.00
0005434620929	32941	Economy	15100.00
0005435332611	32941	Economy	15100.00
0005434620945	32941	Economy	15100.00
0005434620965	32941	Economy	15100.00
0005434620940	32941	Economy	15100.00
0005434620904	32941	Economy	15100.00
0005434620939	32941	Economy	15100.00
0005434620941	32941	Economy	15100.00
0005435332613	32941	Economy	15100.00
0005435332606	32941	Economy	15100.00
0005434620942	32941	Economy	15100.00
0005434620943	32941	Economy	15100.00
0005434620933	32941	Economy	15100.00
0005435937456	4258	Business	38000.00
0005435918746	4258	Business	38000.00
0005435786256	4258	Business	38000.00
0005434994279	4258	Business	38000.00
0005435786268	4258	Business	38000.00
0005435918751	4258	Business	38000.00
0005435918736	4258	Business	38000.00
0005435787411	4258	Business	38000.00
0005432190731	4258	Economy	12700.00
0005434994277	4258	Economy	12700.00
0005435786260	4258	Economy	12700.00
0005435937455	4258	Economy	12700.00
0005435786253	4258	Economy	12700.00
0005435786257	4258	Economy	13900.00
0005435786279	4258	Economy	13900.00
0005432190730	4258	Economy	13900.00
0005434994281	4258	Economy	13900.00
0005435786263	4258	Economy	13900.00
0005435786250	4258	Economy	12700.00
0005435786271	4258	Economy	12700.00
0005435786270	4258	Economy	12700.00
0005435937448	4258	Economy	12700.00
0005435786264	4258	Economy	12700.00
0005435786269	4258	Economy	12700.00
0005434994278	4258	Economy	12700.00
0005435786262	4258	Economy	12700.00
0005435786251	4258	Economy	12700.00
0005435918752	4258	Economy	12700.00
0005435786275	4258	Economy	12700.00
0005435786276	4258	Economy	12700.00
0005435786255	4258	Economy	12700.00
0005434994282	4258	Economy	12700.00
0005435786265	4258	Economy	12700.00
0005432190732	4258	Economy	12700.00
0005435786274	4258	Economy	12700.00
0005435786252	4258	Economy	12700.00
0005435786258	4258	Economy	12700.00
0005435786273	4258	Economy	12700.00
0005434994275	4258	Economy	12700.00
0005435786259	4258	Economy	12700.00
0005435937481	4258	Economy	12700.00
0005435786254	4258	Economy	12700.00
0005435786249	4258	Economy	12700.00
0005432190729	4258	Economy	12700.00
0005435786281	4258	Economy	12700.00
0005434994276	4258	Economy	12700.00
0005435786261	4258	Economy	12700.00
0005435786280	4258	Economy	12700.00
0005435786278	4258	Economy	12700.00
0005435786267	4258	Economy	12700.00
0005435787410	4258	Economy	12700.00
0005434994283	4258	Economy	12700.00
0005434994284	4258	Economy	12700.00
0005435786277	4258	Economy	12700.00
0005434994280	4258	Economy	12700.00
0005435786272	4258	Economy	12700.00
0005435786266	4258	Economy	12700.00
0005434994211	27276	Business	38000.00
0005435918780	27276	Business	38000.00
0005435918782	27276	Business	38000.00
0005435785987	27276	Business	38000.00
0005435786020	27276	Business	38000.00
0005435785945	27276	Business	38000.00
0005435785846	27276	Business	38000.00
0005435785818	27276	Economy	12700.00
0005435785723	27276	Economy	12700.00
0005435785718	27276	Economy	12700.00
0005435785895	27276	Economy	12700.00
0005435785808	27276	Economy	12700.00
0005435785820	27276	Economy	12700.00
0005434994203	27276	Economy	12700.00
0005435785882	27276	Economy	12700.00
0005435785880	27276	Economy	12700.00
0005435785943	27276	Economy	13900.00
0005435785991	27276	Economy	13900.00
0005434994195	27276	Economy	13900.00
0005432195750	27276	Economy	13900.00
0005435785911	27276	Economy	12700.00
0005435785819	27276	Economy	12700.00
0005435785912	27276	Economy	12700.00
0005435786072	27276	Economy	12700.00
0005434994161	27276	Economy	12700.00
0005435785946	27276	Economy	12700.00
0005434994258	27276	Economy	12700.00
0005435785887	27276	Economy	12700.00
0005434994204	27276	Economy	12700.00
0005435785821	27276	Economy	12700.00
0005435785888	27276	Economy	12700.00
0005435785770	27276	Economy	12700.00
0005435785905	27276	Economy	12700.00
0005435785729	27276	Economy	12700.00
0005434994221	27276	Economy	12700.00
0005435785917	27276	Economy	12700.00
0005434994194	27276	Economy	12700.00
0005434994115	27276	Economy	12700.00
0005435785881	27276	Economy	12700.00
0005435785988	27276	Economy	12700.00
0005435785901	27276	Economy	12700.00
0005434994212	27276	Economy	12700.00
0005435785920	27276	Economy	12700.00
0005434994159	27276	Economy	12700.00
0005435785832	27276	Economy	12700.00
0005434994155	27276	Economy	12700.00
0005434994182	27276	Economy	12700.00
0005435785906	27276	Economy	12700.00
0005435785962	27276	Economy	12700.00
0005435785960	27276	Economy	12700.00
0005434994169	27276	Economy	12700.00
0005435918783	27276	Economy	12700.00
0005434994160	27276	Economy	12700.00
0005435785769	27276	Economy	12700.00
0005435785893	27276	Economy	12700.00
0005435785894	27276	Economy	12700.00
0005432195749	27276	Economy	12700.00
0005435785719	27276	Economy	12700.00
0005435785889	27276	Economy	12700.00
0005435785944	27276	Economy	12700.00
0005434994230	27276	Economy	12700.00
0005435785982	27276	Economy	12700.00
0005435785837	27276	Economy	12700.00
0005435785833	27276	Economy	12700.00
0005434994213	27276	Economy	12700.00
0005435918781	27276	Economy	12700.00
0005434994156	27276	Economy	12700.00
0005435785961	27276	Economy	12700.00
0005435785904	27276	Economy	12700.00
0005435785834	27276	Economy	12700.00
0005435785902	27276	Economy	12700.00
0005435785730	27276	Economy	12700.00
0005432146254	19906	Economy	12800.00
0005432461230	4702	Business	40900.00
0005434082554	4702	Business	40900.00
0005434082558	4702	Business	40900.00
0005434082553	4702	Business	40900.00
0005434559149	4702	Business	40900.00
0005432569238	4702	Business	40900.00
0005434559148	4702	Business	40900.00
0005432461242	4702	Business	40900.00
0005434082546	4702	Business	40900.00
0005432569244	4702	Business	40900.00
0005432569247	4702	Business	40900.00
0005432569252	4702	Business	40900.00
0005432569241	4702	Business	40900.00
0005432461215	4702	Business	40900.00
0005432461250	4702	Business	40900.00
0005432461209	4702	Business	40900.00
0005432461247	4702	Business	40900.00
0005432461231	4702	Business	40900.00
0005434559139	4702	Business	40900.00
0005434559147	4702	Business	40900.00
0005432569224	4702	Economy	15000.00
0005432461205	4702	Economy	15000.00
0005432569243	4702	Economy	13600.00
0005432569249	4702	Economy	13600.00
0005432461241	4702	Economy	13600.00
0005434082547	4702	Economy	13600.00
0005432569255	4702	Economy	13600.00
0005432569222	4702	Economy	13600.00
0005432461243	4702	Economy	13600.00
0005432461244	4702	Economy	13600.00
0005432569221	4702	Economy	13600.00
0005434559138	4702	Economy	13600.00
0005434559145	4702	Economy	13600.00
0005432569258	4702	Economy	13600.00
0005432569248	4702	Economy	13600.00
0005432569228	4702	Economy	13600.00
0005434082556	4702	Economy	13600.00
0005434082561	4702	Economy	13600.00
0005432461217	4702	Economy	13600.00
0005434559152	4702	Economy	13600.00
0005432569257	4702	Economy	13600.00
0005432569237	4702	Economy	13600.00
0005434082542	4702	Economy	13600.00
0005432461225	4702	Economy	13600.00
0005434082563	4702	Economy	13600.00
0005432569220	4702	Economy	13600.00
0005432170563	4702	Economy	13600.00
0005432461237	4702	Economy	13600.00
0005434082543	4702	Economy	13600.00
0005432461219	4702	Economy	13600.00
0005434082544	4702	Economy	13600.00
0005432461229	4702	Economy	13600.00
0005434082548	4702	Economy	13600.00
0005432569230	4702	Economy	13600.00
0005434082555	4702	Economy	13600.00
0005432461232	4702	Economy	13600.00
0005432571423	4702	Economy	13600.00
0005432569217	4702	Economy	13600.00
0005432461210	4702	Economy	13600.00
0005432571420	4702	Economy	13600.00
0005432569253	4702	Economy	13600.00
0005432569233	4702	Economy	13600.00
0005432569225	4702	Economy	13600.00
0005434082538	4702	Economy	13600.00
0005434082551	4702	Economy	13600.00
0005433726164	4702	Economy	13600.00
0005432461240	4702	Economy	13600.00
0005432569214	4702	Economy	13600.00
0005432461248	4702	Economy	13600.00
0005432569246	4702	Economy	13600.00
0005432569242	4702	Economy	13600.00
0005434559151	4702	Economy	13600.00
0005432461221	4702	Economy	13600.00
0005432461239	4702	Economy	13600.00
0005432569251	4702	Economy	13600.00
0005434082564	4702	Economy	13600.00
0005434082562	4702	Economy	13600.00
0005432461212	4702	Economy	13600.00
0005432569229	4702	Economy	13600.00
0005434559143	4702	Economy	13600.00
0005432569231	4702	Economy	13600.00
0005432569256	4702	Economy	13600.00
0005432461207	4702	Economy	13600.00
0005432461226	4702	Economy	13600.00
0005434082552	4702	Economy	13600.00
0005434082560	4702	Economy	13600.00
0005432461238	4702	Economy	13600.00
0005432569219	4702	Economy	13600.00
0005434559146	4702	Economy	13600.00
0005432461214	4702	Economy	13600.00
0005432569239	4702	Economy	13600.00
0005432461211	4702	Economy	13600.00
0005432461234	4702	Economy	13600.00
0005432461200	4702	Economy	13600.00
0005432461223	4702	Economy	13600.00
0005432571421	4702	Economy	13600.00
0005432461236	4702	Economy	13600.00
0005432186964	4702	Economy	13600.00
0005432461246	4702	Economy	13600.00
0005432569250	4702	Economy	13600.00
0005432170562	4702	Economy	13600.00
0005432461220	4702	Economy	13600.00
0005434559153	4702	Economy	13600.00
0005432461218	4702	Economy	15000.00
0005434082557	4702	Economy	15000.00
0005432461222	4702	Economy	13600.00
0005434559144	4702	Economy	15000.00
0005434082566	4702	Economy	13600.00
0005434559150	4702	Economy	13600.00
0005432569234	4702	Economy	13600.00
0005434559142	4702	Economy	13600.00
0005433451672	4702	Economy	13600.00
0005432170561	4702	Economy	13600.00
0005432461208	4702	Economy	13600.00
0005434082549	4702	Economy	13600.00
0005432569235	4702	Economy	13600.00
0005432186968	4702	Economy	13600.00
0005432461235	4702	Economy	13600.00
0005432461198	4702	Economy	13600.00
0005434082565	4702	Economy	13600.00
0005432461202	4702	Economy	13600.00
0005432461213	4702	Economy	13600.00
0005432186966	4702	Economy	13600.00
0005434082541	4702	Economy	13600.00
0005432569216	4702	Economy	13600.00
0005434082559	4702	Economy	13600.00
0005432461233	4702	Economy	13600.00
0005434082545	4702	Economy	13600.00
0005432461224	4702	Economy	13600.00
0005432569245	4702	Economy	13600.00
0005434082550	4702	Economy	13600.00
0005432569240	4702	Economy	13600.00
0005432461216	4702	Economy	13600.00
0005432569236	4702	Economy	13600.00
0005434082540	4702	Economy	13600.00
0005432569260	4702	Economy	13600.00
0005434082539	4702	Economy	13600.00
0005432186967	4702	Economy	13600.00
0005432569226	4702	Economy	13600.00
0005434559140	4702	Economy	13600.00
0005432569213	4702	Economy	13600.00
0005432461203	4702	Economy	13600.00
0005432461251	4702	Economy	13600.00
0005432569259	4702	Economy	13600.00
0005433726165	4702	Economy	13600.00
0005432569223	4702	Economy	13600.00
0005432461252	4702	Economy	13600.00
0005432461201	4702	Economy	13600.00
0005432461245	4702	Economy	13600.00
0005432461227	4702	Economy	13600.00
0005432461199	4702	Economy	13600.00
0005432461206	4702	Economy	13600.00
0005432461228	4702	Economy	13600.00
0005432569254	4702	Economy	13600.00
0005434559141	4702	Economy	13600.00
0005432569218	4702	Economy	13600.00
0005432569232	4702	Economy	13600.00
0005432569227	4702	Economy	13600.00
0005433452791	4702	Economy	13600.00
0005432186965	4702	Economy	13600.00
0005432461204	4702	Economy	13600.00
0005432571422	4702	Economy	13600.00
0005432461249	4702	Economy	13600.00
0005432170564	4702	Economy	13600.00
0005432569215	4702	Economy	13600.00
0005432568708	30539	Business	40900.00
0005435840470	30539	Business	40900.00
0005432460995	30539	Business	40900.00
0005432460637	30539	Business	40900.00
0005432161213	30539	Business	40900.00
0005432568795	30539	Business	40900.00
0005432460861	30539	Business	40900.00
0005432568793	30539	Business	40900.00
0005432460829	30539	Business	40900.00
0005432568905	30539	Business	40900.00
0005432161212	30539	Business	40900.00
0005432568937	30539	Business	40900.00
0005432568930	30539	Business	40900.00
0005432460779	30539	Business	40900.00
0005432460792	30539	Business	40900.00
0005432460748	30539	Business	40900.00
0005432568552	30539	Business	40900.00
0005434082295	30539	Business	40900.00
0005435840462	30539	Business	40900.00
0005434082249	30539	Business	40900.00
0005432460793	30539	Business	40900.00
0005432460860	30539	Business	40900.00
0005432568885	30539	Business	40900.00
0005432568916	30539	Business	40900.00
0005432568728	30539	Business	40900.00
0005432568787	30539	Economy	15000.00
0005432568854	30539	Economy	15000.00
0005432568677	30539	Economy	15000.00
0005435840458	30539	Economy	15000.00
0005435840447	30539	Economy	13600.00
0005432460800	30539	Economy	13600.00
0005432568614	30539	Economy	13600.00
0005434082239	30539	Economy	13600.00
0005432568813	30539	Economy	13600.00
0005435840467	30539	Economy	13600.00
0005435840459	30539	Economy	13600.00
0005432568678	30539	Economy	13600.00
0005432460774	30539	Economy	13600.00
0005432568952	30539	Economy	13600.00
0005434082327	30539	Economy	13600.00
0005435840476	30539	Economy	13600.00
0005435840451	30539	Economy	13600.00
0005432568904	30539	Economy	13600.00
0005435840456	30539	Economy	13600.00
0005435840473	30539	Economy	13600.00
0005434082145	30539	Economy	13600.00
0005432568806	30539	Economy	13600.00
0005432568770	30539	Economy	13600.00
0005432568784	30539	Economy	13600.00
0005435840463	30539	Economy	13600.00
0005432460638	30539	Economy	13600.00
0005435840452	30539	Economy	13600.00
0005434082337	30539	Economy	13600.00
0005435840474	30539	Economy	13600.00
0005434082264	30539	Economy	13600.00
0005432461087	30539	Economy	13600.00
0005432460789	30539	Economy	13600.00
0005432568616	30539	Economy	13600.00
0005432568727	30539	Economy	13600.00
0005435840445	30539	Economy	13600.00
0005432568807	30539	Economy	13600.00
0005434082273	30539	Economy	13600.00
0005434082265	30539	Economy	13600.00
0005432460624	30539	Economy	13600.00
0005432568821	30539	Economy	13600.00
0005432460722	30539	Economy	13600.00
0005432460965	30539	Economy	13600.00
0005432461116	30539	Economy	13600.00
0005435840460	30539	Economy	13600.00
0005435840464	30539	Economy	13600.00
0005432568899	30539	Economy	13600.00
0005435840446	30539	Economy	13600.00
0005432569102	30539	Economy	13600.00
0005432460760	30539	Economy	13600.00
0005434082296	30539	Economy	13600.00
0005432460747	30539	Economy	13600.00
0005434082248	30539	Economy	13600.00
0005432460732	30539	Economy	13600.00
0005432460830	30539	Economy	13600.00
0005434082294	30539	Economy	13600.00
0005435840472	30539	Economy	13600.00
0005435840448	30539	Economy	13600.00
0005432568900	30539	Economy	13600.00
0005432460707	30539	Economy	13600.00
0005432568723	30539	Economy	13600.00
0005432568642	30539	Economy	13600.00
0005432568598	30539	Economy	13600.00
0005435840454	30539	Economy	13600.00
0005432568896	30539	Economy	13600.00
0005432460859	30539	Economy	13600.00
0005432568481	30539	Economy	13600.00
0005435840468	30539	Economy	13600.00
0005432461085	30539	Economy	13600.00
0005434082293	30539	Economy	13600.00
0005434082338	30539	Economy	13600.00
0005432213704	30539	Economy	13600.00
0005432460801	30539	Economy	13600.00
0005432460874	30539	Economy	13600.00
0005432460873	30539	Economy	13600.00
0005432460727	30539	Economy	13600.00
0005432460858	30539	Economy	13600.00
0005432460769	30539	Economy	13600.00
0005432460817	30539	Economy	13600.00
0005435840444	30539	Economy	13600.00
0005432568661	30539	Economy	13600.00
0005432568783	30539	Economy	13600.00
0005435840461	30539	Economy	13600.00
0005432568696	30539	Economy	13600.00
0005432460993	30539	Economy	15000.00
0005432568796	30539	Economy	13600.00
0005435840450	30539	Economy	13600.00
0005432460767	30539	Economy	15000.00
0005432568777	30539	Economy	13600.00
0005435840466	30539	Economy	13600.00
0005432460971	30539	Economy	13600.00
0005432460633	30539	Economy	13600.00
0005432568927	30539	Economy	13600.00
0005435840457	30539	Economy	13600.00
0005432568810	30539	Economy	13600.00
0005432460795	30539	Economy	13600.00
0005435840475	30539	Economy	13600.00
0005432568855	30539	Economy	13600.00
0005432568634	30539	Economy	13600.00
0005432460778	30539	Economy	13600.00
0005432460759	30539	Economy	13600.00
0005432568814	30539	Economy	13600.00
0005435840471	30539	Economy	13600.00
0005432460871	30539	Economy	13600.00
0005434082263	30539	Economy	13600.00
0005432461065	30539	Economy	13600.00
0005432568581	30539	Economy	13600.00
0005432460931	30539	Economy	13600.00
0005432161211	30539	Economy	13600.00
0005435840449	30539	Economy	13600.00
0005432568879	30539	Economy	13600.00
0005433454902	30539	Economy	13600.00
0005435840469	30539	Economy	13600.00
0005434082302	30539	Economy	13600.00
0005432460655	30539	Economy	13600.00
0005432460796	30539	Economy	13600.00
0005432568397	30539	Economy	13600.00
0005432568693	30539	Economy	13600.00
0005435840465	30539	Economy	13600.00
0005432461036	30539	Economy	13600.00
0005432568724	30539	Economy	13600.00
0005432568929	30539	Economy	13600.00
0005432568753	30539	Economy	13600.00
0005432460851	30539	Economy	13600.00
0005432568780	30539	Economy	13600.00
0005432460994	30539	Economy	13600.00
0005432460831	30539	Economy	13600.00
0005435840455	30539	Economy	13600.00
0005432460635	30539	Economy	13600.00
0005432461086	30539	Economy	13600.00
0005435840453	30539	Economy	13600.00
0005432460761	30539	Economy	13600.00
0005432568926	30539	Economy	13600.00
0005432460850	30539	Economy	13600.00
0005434082380	30539	Economy	13600.00
0005432568878	30539	Economy	13600.00
0005432568917	30539	Economy	13600.00
0005432568640	30539	Economy	13600.00
0005432568936	30539	Economy	13600.00
0005432568771	30539	Economy	13600.00
0005432461066	30539	Economy	13600.00
0005432460912	30539	Economy	13600.00
0005432460658	30539	Economy	13600.00
0005434082410	30539	Economy	13600.00
0005432568551	30539	Economy	13600.00
0005432568615	30539	Economy	13600.00
0005434082205	30539	Economy	13600.00
0005432460636	30539	Economy	13600.00
0005432460976	30539	Economy	13600.00
0005435722117	13586	Economy	9900.00
0005435722119	13586	Economy	9900.00
0005435720857	13586	Economy	9900.00
0005435720858	13586	Economy	9900.00
0005435722118	13586	Economy	9900.00
0005435722116	13586	Economy	9900.00
0005435722100	21197	Economy	9900.00
0005435720151	21197	Economy	9900.00
0005435722099	21197	Economy	9900.00
0005435720147	21197	Economy	9900.00
0005435722093	21197	Economy	9900.00
0005432295949	22768	Economy	8800.00
0005432295950	22768	Economy	8800.00
0005433345795	11099	Business	23600.00
0005433345756	11099	Business	23600.00
0005435529991	11099	Business	23600.00
0005435380381	11099	Business	23600.00
0005433345781	11099	Business	23600.00
0005435508601	11099	Business	23600.00
0005433345773	11099	Business	23600.00
0005435529988	11099	Business	23600.00
0005435508561	11099	Business	23600.00
0005435508538	11099	Business	23600.00
0005433345775	11099	Business	23600.00
0005435508667	11099	Business	23600.00
0005433345760	11099	Economy	7900.00
0005433345807	11099	Economy	7900.00
0005433345749	11099	Economy	7900.00
0005433345748	11099	Economy	7900.00
0005435508521	11099	Economy	7900.00
0005433345743	11099	Economy	7900.00
0005433345741	11099	Economy	7900.00
0005433345746	11099	Economy	7900.00
0005433345752	11099	Economy	7900.00
0005433345780	11099	Economy	7900.00
0005433345794	11099	Economy	7900.00
0005433345777	11099	Economy	7900.00
0005433345755	11099	Economy	7900.00
0005435097466	11099	Economy	7900.00
0005433345742	11099	Economy	7900.00
0005433345768	11099	Economy	7900.00
0005433345764	11099	Economy	7900.00
0005433345758	11099	Economy	7900.00
0005435529989	11099	Economy	7900.00
0005435508526	11099	Economy	7900.00
0005435508522	11099	Economy	7900.00
0005433345826	11099	Economy	7900.00
0005435097463	11099	Economy	7900.00
0005433345823	11099	Economy	7900.00
0005433345799	11099	Economy	7900.00
0005433345803	11099	Economy	7900.00
0005433345805	11099	Economy	7900.00
0005433345778	11099	Economy	7900.00
0005435508647	11099	Economy	7900.00
0005433345763	11099	Economy	7900.00
0005433345816	11099	Economy	7900.00
0005435529985	11099	Economy	7900.00
0005435097468	11099	Economy	7900.00
0005433345814	11099	Economy	7900.00
0005435529986	11099	Economy	7900.00
0005433345793	11099	Economy	7900.00
0005435508592	11099	Economy	7900.00
0005435529975	11099	Economy	7900.00
0005435097462	11099	Economy	7900.00
0005433345812	11099	Economy	7900.00
0005435097458	11099	Economy	8600.00
0005433345772	11099	Economy	8600.00
0005433345784	11099	Economy	8600.00
0005433345779	11099	Economy	8600.00
0005433345782	11099	Economy	8600.00
0005433345821	11099	Economy	7900.00
0005435380405	11099	Economy	8600.00
0005435097459	11099	Economy	7900.00
0005433345824	11099	Economy	7900.00
0005433345792	11099	Economy	7900.00
0005435097460	11099	Economy	7900.00
0005435097467	11099	Economy	7900.00
0005433345808	11099	Economy	7900.00
0005433345761	11099	Economy	7900.00
0005433345796	11099	Economy	7900.00
0005435508555	11099	Economy	7900.00
0005433345774	11099	Economy	7900.00
0005433345769	11099	Economy	7900.00
0005433345804	11099	Economy	7900.00
0005433345800	11099	Economy	7900.00
0005433345770	11099	Economy	7900.00
0005433345767	11099	Economy	7900.00
0005433345801	11099	Economy	7900.00
0005433345789	11099	Economy	7900.00
0005433345787	11099	Economy	7900.00
0005435508591	11099	Economy	7900.00
0005433345791	11099	Economy	7900.00
0005433345771	11099	Economy	7900.00
0005433345811	11099	Economy	7900.00
0005435097465	11099	Economy	7900.00
0005433345757	11099	Economy	7900.00
0005435380353	11099	Economy	7900.00
0005435508642	11099	Economy	7900.00
0005433345802	11099	Economy	7900.00
0005433345790	11099	Economy	7900.00
0005435508576	11099	Economy	7900.00
0005433345751	11099	Economy	7900.00
0005433345813	11099	Economy	7900.00
0005435097464	11099	Economy	7900.00
0005433345753	11099	Economy	7900.00
0005435380380	11099	Economy	7900.00
0005433345786	11099	Economy	7900.00
0005433345817	11099	Economy	7900.00
0005433345759	11099	Economy	7900.00
0005433345818	11099	Economy	7900.00
0005433345809	11099	Economy	7900.00
0005433345806	11099	Economy	7900.00
0005433345822	11099	Economy	7900.00
0005435508648	11099	Economy	7900.00
0005435508607	11099	Economy	7900.00
0005435508567	11099	Economy	7900.00
0005433345798	11099	Economy	7900.00
0005433345797	11099	Economy	7900.00
0005433345754	11099	Economy	7900.00
0005433345825	11099	Economy	7900.00
0005435529990	11099	Economy	7900.00
0005433345750	11099	Economy	7900.00
0005433345815	11099	Economy	7900.00
0005435508606	11099	Economy	7900.00
0005433345747	11099	Economy	7900.00
0005433345740	11099	Economy	7900.00
0005433345744	11099	Economy	7900.00
0005433345820	11099	Economy	7900.00
0005433345766	11099	Economy	7900.00
0005433345745	11099	Economy	7900.00
0005433345765	11099	Economy	7900.00
0005435508539	11099	Economy	7900.00
0005433345785	11099	Economy	7900.00
0005433345788	11099	Economy	7900.00
0005433345810	11099	Economy	7900.00
0005433345783	11099	Economy	7900.00
0005433345762	11099	Economy	7900.00
0005435097461	11099	Economy	7900.00
0005433345776	11099	Economy	7900.00
0005435529977	11099	Economy	7900.00
0005435529976	11099	Economy	7900.00
0005433345819	11099	Economy	7900.00
0005435508523	11099	Economy	7900.00
0005433344893	17082	Business	23600.00
0005433345006	17082	Business	23600.00
0005433344886	17082	Business	23600.00
0005433344543	17082	Business	23600.00
0005433344905	17082	Business	23600.00
0005433344935	17082	Business	23600.00
0005433345100	17082	Business	23600.00
0005433345113	17082	Business	23600.00
0005432293272	17082	Business	23600.00
0005433345007	17082	Business	23600.00
0005433344681	17082	Business	23600.00
0005433345187	17082	Business	23600.00
0005435545983	17082	Economy	7900.00
0005433345270	17082	Economy	7900.00
0005433344860	17082	Economy	7900.00
0005433344730	17082	Economy	7900.00
0005433345017	17082	Economy	7900.00
0005435097338	17082	Economy	7900.00
0005435545982	17082	Economy	7900.00
0005435380425	17082	Economy	7900.00
0005435545943	17082	Economy	7900.00
0005435380423	17082	Economy	7900.00
0005433344583	17082	Economy	7900.00
0005433344685	17082	Economy	7900.00
0005433344925	17082	Economy	7900.00
0005433344633	17082	Economy	7900.00
0005433345011	17082	Economy	7900.00
0005435545938	17082	Economy	7900.00
0005435545941	17082	Economy	7900.00
0005435545928	17082	Economy	7900.00
0005435545986	17082	Economy	7900.00
0005432293273	17082	Economy	7900.00
0005435097382	17082	Economy	7900.00
0005433344807	17082	Economy	7900.00
0005433344401	17082	Economy	7900.00
0005433344635	17082	Economy	7900.00
0005433345065	17082	Economy	7900.00
0005433345023	17082	Economy	7900.00
0005433344808	17082	Economy	7900.00
0005433344837	17082	Economy	7900.00
0005435545944	17082	Economy	7900.00
0005435545984	17082	Economy	7900.00
0005433344793	17082	Economy	7900.00
0005435545936	17082	Economy	7900.00
0005435545940	17082	Economy	7900.00
0005433344848	17082	Economy	7900.00
0005435097424	17082	Economy	7900.00
0005433345016	17082	Economy	7900.00
0005433345064	17082	Economy	7900.00
0005433344849	17082	Economy	7900.00
0005435545932	17082	Economy	7900.00
0005433344672	17082	Economy	7900.00
0005433344331	17082	Economy	8600.00
0005433345022	17082	Economy	8600.00
0005433344574	17082	Economy	8600.00
0005433345271	17082	Economy	8600.00
0005433345034	17082	Economy	8600.00
0005433345115	17082	Economy	8600.00
0005435545929	17082	Economy	7900.00
0005433344673	17082	Economy	7900.00
0005433345081	17082	Economy	7900.00
0005433344817	17082	Economy	7900.00
0005433344384	17082	Economy	7900.00
0005435545942	17082	Economy	7900.00
0005433345212	17082	Economy	7900.00
0005433344856	17082	Economy	7900.00
0005433345200	17082	Economy	7900.00
0005435545931	17082	Economy	7900.00
0005433344610	17082	Economy	7900.00
0005433344999	17082	Economy	7900.00
0005433344913	17082	Economy	7900.00
0005433345114	17082	Economy	7900.00
0005433344857	17082	Economy	7900.00
0005435545987	17082	Economy	7900.00
0005433344889	17082	Economy	7900.00
0005433345101	17082	Economy	7900.00
0005433345070	17082	Economy	7900.00
0005435380424	17082	Economy	7900.00
0005435545939	17082	Economy	7900.00
0005433344892	17082	Economy	7900.00
0005433344355	17082	Economy	7900.00
0005435097404	17082	Economy	7900.00
0005435380427	17082	Economy	7900.00
0005433345026	17082	Economy	7900.00
0005433344243	17082	Economy	7900.00
0005433344861	17082	Economy	7900.00
0005433344665	17082	Economy	7900.00
0005435380426	17082	Economy	7900.00
0005433345043	17082	Economy	7900.00
0005433344902	17082	Economy	7900.00
0005433344836	17082	Economy	7900.00
0005433344666	17082	Economy	7900.00
0005435545933	17082	Economy	7900.00
0005433345112	17082	Economy	7900.00
0005433344473	17082	Economy	7900.00
0005433344859	17082	Economy	7900.00
0005433345020	17082	Economy	7900.00
0005435545985	17082	Economy	7900.00
0005435097381	17082	Economy	7900.00
0005433344729	17082	Economy	7900.00
0005433344916	17082	Economy	7900.00
0005433344385	17082	Economy	7900.00
0005435545930	17082	Economy	7900.00
0005435545934	17082	Economy	7900.00
0005433344911	17082	Economy	7900.00
0005433345110	17082	Economy	7900.00
0005433344894	17082	Economy	7900.00
0005433345041	17082	Economy	7900.00
0005433345018	17082	Economy	7900.00
0005435097337	17082	Economy	7900.00
0005433345010	17082	Economy	7900.00
0005435545935	17082	Economy	7900.00
0005433345298	17082	Economy	7900.00
0005435545937	17082	Economy	7900.00
0005433344682	17082	Economy	7900.00
0005433344459	17082	Economy	7900.00
0005433344910	17082	Economy	7900.00
0005433344582	17082	Economy	7900.00
0005433344542	17082	Economy	7900.00
0005433345021	17082	Economy	7900.00
0005433344785	17082	Economy	7900.00
0005433345042	17082	Economy	7900.00
0005435545945	17082	Economy	7900.00
0005435097380	17082	Economy	7900.00
0005433344241	17082	Economy	7900.00
0005433344242	17082	Economy	7900.00
0005433344934	17082	Economy	7900.00
0005433344474	17082	Economy	7900.00
0005433344759	17082	Economy	7900.00
0005433477193	9086	Business	26600.00
0005433477181	9086	Business	26600.00
0005433477171	9086	Business	26600.00
0005433477169	9086	Business	26600.00
0005433477163	9086	Business	26600.00
0005433477165	9086	Business	26600.00
0005433477191	9086	Business	26600.00
0005433477190	9086	Business	26600.00
0005433481371	9086	Business	26600.00
0005432920239	9086	Business	26600.00
0005432920164	9086	Business	26600.00
0005432920310	9086	Economy	8900.00
0005433507677	9086	Economy	8900.00
0005433477183	9086	Economy	8900.00
0005433507663	9086	Economy	8900.00
0005433477159	9086	Economy	8900.00
0005433477189	9086	Economy	8900.00
0005433507670	9086	Economy	8900.00
0005433477182	9086	Economy	8900.00
0005433477184	9086	Economy	9800.00
0005433477185	9086	Economy	9800.00
0005432920240	9086	Economy	9800.00
0005433477188	9086	Economy	9800.00
0005432920203	9086	Economy	8900.00
0005432920288	9086	Economy	8900.00
0005433477175	9086	Economy	8900.00
0005432920222	9086	Economy	8900.00
0005433481370	9086	Economy	8900.00
0005434159018	9086	Economy	8900.00
0005432920275	9086	Economy	8900.00
0005433477178	9086	Economy	8900.00
0005433477186	9086	Economy	8900.00
0005432920131	9086	Economy	8900.00
0005433477176	9086	Economy	8900.00
0005432920225	9086	Economy	8900.00
0005433477174	9086	Economy	8900.00
0005433477161	9086	Economy	8900.00
0005433507675	9086	Economy	8900.00
0005432920186	9086	Economy	8900.00
0005433507673	9086	Economy	8900.00
0005432920251	9086	Economy	8900.00
0005433507674	9086	Economy	8900.00
0005432920165	9086	Economy	8900.00
0005433481372	9086	Economy	8900.00
0005432920130	9086	Economy	8900.00
0005432920161	9086	Economy	8900.00
0005433507667	9086	Economy	8900.00
0005433477170	9086	Economy	8900.00
0005433477172	9086	Economy	8900.00
0005432920196	9086	Economy	8900.00
0005432920308	9086	Economy	8900.00
0005433477160	9086	Economy	8900.00
0005432920162	9086	Economy	8900.00
0005433477162	9086	Economy	8900.00
0005433481375	9086	Economy	8900.00
0005433507671	9086	Economy	8900.00
0005433477164	9086	Economy	8900.00
0005433477167	9086	Economy	8900.00
0005432920205	9086	Economy	8900.00
0005433481374	9086	Economy	8900.00
0005432920287	9086	Economy	8900.00
0005432920197	9086	Economy	8900.00
0005433507669	9086	Economy	8900.00
0005433477180	9086	Economy	8900.00
0005434159034	9086	Economy	8900.00
0005433507676	9086	Economy	8900.00
0005433477166	9086	Economy	8900.00
0005433507666	9086	Economy	8900.00
0005433477177	9086	Economy	8900.00
0005433507668	9086	Economy	8900.00
0005433477187	9086	Economy	8900.00
0005432920204	9086	Economy	8900.00
0005433507664	9086	Economy	8900.00
0005433477168	9086	Economy	8900.00
0005433507665	9086	Economy	8900.00
0005432920210	9086	Economy	8900.00
0005433477173	9086	Economy	8900.00
0005433477192	9086	Economy	8900.00
0005433507662	9086	Economy	8900.00
0005433477179	9086	Economy	8900.00
0005433507672	9086	Economy	8900.00
0005433477194	9086	Economy	8900.00
0005433481373	9086	Economy	8900.00
0005432920289	9086	Economy	8900.00
0005433477158	9086	Economy	8900.00
0005432920428	20461	Business	26600.00
0005433481288	20461	Business	26600.00
0005434159049	20461	Business	26600.00
0005433507455	20461	Business	26600.00
0005433481314	20461	Economy	8900.00
0005432920431	20461	Economy	8900.00
0005433507505	20461	Economy	8900.00
0005433507569	20461	Economy	8900.00
0005433507615	20461	Economy	8900.00
0005432920420	20461	Economy	9800.00
0005432920434	20461	Economy	9800.00
0005432920417	20461	Economy	8900.00
0005433507438	20461	Economy	8900.00
0005433507488	20461	Economy	8900.00
0005432920435	20461	Economy	8900.00
0005432920426	20461	Economy	8900.00
0005434159045	20461	Economy	8900.00
0005433507551	20461	Economy	8900.00
0005433507607	20461	Economy	8900.00
0005433507489	20461	Economy	8900.00
0005432920433	20461	Economy	8900.00
0005433481351	20461	Economy	8900.00
0005433481313	20461	Economy	8900.00
0005432920427	20461	Economy	8900.00
0005432920421	20461	Economy	8900.00
0005432920418	20461	Economy	8900.00
0005434159048	20461	Economy	8900.00
0005433507537	20461	Economy	8900.00
0005432920430	20461	Economy	8900.00
0005433507546	20461	Economy	8900.00
0005433507538	20461	Economy	8900.00
0005433507535	20461	Economy	8900.00
0005433507502	20461	Economy	8900.00
0005432920416	20461	Economy	8900.00
0005433507513	20461	Economy	8900.00
0005433481325	20461	Economy	8900.00
0005432920423	20461	Economy	8900.00
0005433481273	20461	Economy	8900.00
0005433507545	20461	Economy	8900.00
0005433507496	20461	Economy	8900.00
0005432920432	20461	Economy	8900.00
0005432920425	20461	Economy	8900.00
0005434159047	20461	Economy	8900.00
0005433507525	20461	Economy	8900.00
0005433507501	20461	Economy	8900.00
0005433507439	20461	Economy	8900.00
0005434159046	20461	Economy	8900.00
0005433507497	20461	Economy	8900.00
0005432920424	20461	Economy	8900.00
0005433507597	20461	Economy	8900.00
0005433507596	20461	Economy	8900.00
0005432920422	20461	Economy	8900.00
0005432920419	20461	Economy	8900.00
0005433507437	20461	Economy	8900.00
0005433507570	20461	Economy	8900.00
0005433507568	20461	Economy	8900.00
0005432920429	20461	Economy	8900.00
0005432394206	10243	Economy	5800.00
0005432396343	10243	Economy	5800.00
0005432396344	10243	Economy	5800.00
0005432394208	10243	Economy	5800.00
0005432396342	10243	Economy	5800.00
0005432396345	10243	Economy	5800.00
0005432394209	10243	Economy	5800.00
0005435179705	10243	Economy	5800.00
0005432394207	10243	Economy	5800.00
0005432400204	18341	Economy	5800.00
0005432396304	18341	Economy	5800.00
0005432400185	18341	Economy	5800.00
0005435179424	18341	Economy	5800.00
0005435179423	18341	Economy	5800.00
0005432400203	18341	Economy	5800.00
0005432396313	18341	Economy	5800.00
0005435626502	10954	Business	9500.00
0005435127202	10954	Business	9500.00
0005435127069	10954	Business	9500.00
0005435127021	10954	Business	9500.00
0005435127152	10954	Business	9500.00
0005435127000	10954	Business	9500.00
0005435626433	10954	Business	9500.00
0005435127171	10954	Business	9500.00
0005435554269	10954	Economy	3200.00
0005435127295	10954	Economy	3200.00
0005435626486	10954	Economy	3200.00
0005435127095	10954	Economy	3200.00
0005435126918	10954	Economy	3200.00
0005435127102	10954	Economy	3200.00
0005435127040	10954	Economy	3200.00
0005435127046	10954	Economy	3500.00
0005434928375	10954	Economy	3500.00
0005435127070	10954	Economy	3500.00
0005435126940	10954	Economy	3200.00
0005435127001	10954	Economy	3200.00
0005434411891	10954	Economy	3200.00
0005435556741	10954	Economy	3200.00
0005435127094	10954	Economy	3200.00
0005435626479	10954	Economy	3200.00
0005435626507	10954	Economy	3200.00
0005435556732	10954	Economy	3200.00
0005435126951	10954	Economy	3200.00
0005435554281	10954	Economy	3200.00
0005435127142	10954	Economy	3200.00
0005434928377	10954	Economy	3200.00
0005435126960	10954	Economy	3200.00
0005435127167	10954	Economy	3200.00
0005435127083	10954	Economy	3200.00
0005435556742	10954	Economy	3200.00
0005435554251	10954	Economy	3200.00
0005435554272	10954	Economy	3200.00
0005435626526	10954	Economy	3200.00
0005435554279	10954	Economy	3200.00
0005435127066	10954	Economy	3200.00
0005435626528	10954	Economy	3200.00
0005434411892	10954	Economy	3200.00
0005435626470	10954	Economy	3200.00
0005435127088	10954	Economy	3200.00
0005435127047	10954	Economy	3200.00
0005435127008	10954	Economy	3200.00
0005435126876	10954	Economy	3200.00
0005435126923	10954	Economy	3200.00
0005435126824	10954	Economy	3200.00
0005435626499	10954	Economy	3200.00
0005434928376	10954	Economy	3200.00
0005435554280	10954	Economy	3200.00
0005435127093	10954	Economy	3200.00
0005435626527	10954	Economy	3200.00
0005435127170	10954	Economy	3200.00
0005435127098	10954	Economy	3200.00
0005434411893	10954	Economy	3200.00
0005435126877	10954	Economy	3200.00
0005435556734	10954	Economy	3200.00
0005435556733	10954	Economy	3200.00
0005435126922	10954	Economy	3200.00
0005435126961	10954	Economy	3200.00
0005435126955	10954	Economy	3200.00
0005435126875	10954	Economy	3200.00
0005435127166	10954	Economy	3200.00
0005435554273	10954	Economy	3200.00
0005435126917	10954	Economy	3200.00
0005435127028	10954	Economy	3200.00
0005435126941	10954	Economy	3200.00
0005435127089	10954	Economy	3200.00
0005435626683	14753	Business	9500.00
0005435626675	14753	Business	9500.00
0005434928358	14753	Business	9500.00
0005435127452	14753	Business	9500.00
0005435554311	14753	Business	9500.00
0005435626679	14753	Business	9500.00
0005435127443	14753	Business	9500.00
0005435127438	14753	Business	9500.00
0005435626687	14753	Business	9500.00
0005435127441	14753	Economy	3200.00
0005435626673	14753	Economy	3200.00
0005435127435	14753	Economy	3200.00
0005435127442	14753	Economy	3200.00
0005435127463	14753	Economy	3200.00
0005434928361	14753	Economy	3200.00
0005435127456	14753	Economy	3200.00
0005435626669	14753	Economy	3200.00
0005435127453	14753	Economy	3500.00
0005435626672	14753	Economy	3500.00
0005435626666	14753	Economy	3500.00
0005435554312	14753	Economy	3500.00
0005435626688	14753	Economy	3500.00
0005435626670	14753	Economy	3200.00
0005435127461	14753	Economy	3200.00
0005435127431	14753	Economy	3200.00
0005435626682	14753	Economy	3200.00
0005435127428	14753	Economy	3200.00
0005434928349	14753	Economy	3200.00
0005435127446	14753	Economy	3200.00
0005435626680	14753	Economy	3200.00
0005435127460	14753	Economy	3200.00
0005435626685	14753	Economy	3200.00
0005434411857	14753	Economy	3200.00
0005435127464	14753	Economy	3200.00
0005435127457	14753	Economy	3200.00
0005435127448	14753	Economy	3200.00
0005435127436	14753	Economy	3200.00
0005435127459	14753	Economy	3200.00
0005435127447	14753	Economy	3200.00
0005435127465	14753	Economy	3200.00
0005435127451	14753	Economy	3200.00
0005435556759	14753	Economy	3200.00
0005434411859	14753	Economy	3200.00
0005435626678	14753	Economy	3200.00
0005435127449	14753	Economy	3200.00
0005435626686	14753	Economy	3200.00
0005435127434	14753	Economy	3200.00
0005435127455	14753	Economy	3200.00
0005435127467	14753	Economy	3200.00
0005434928360	14753	Economy	3200.00
0005435626668	14753	Economy	3200.00
0005435127429	14753	Economy	3200.00
0005435626676	14753	Economy	3200.00
0005435127439	14753	Economy	3200.00
0005435127444	14753	Economy	3200.00
0005435127432	14753	Economy	3200.00
0005435556760	14753	Economy	3200.00
0005435626689	14753	Economy	3200.00
0005435626671	14753	Economy	3200.00
0005435556758	14753	Economy	3200.00
0005435127437	14753	Economy	3200.00
0005435626677	14753	Economy	3200.00
0005435127454	14753	Economy	3200.00
0005435127450	14753	Economy	3200.00
0005434928355	14753	Economy	3200.00
0005435127433	14753	Economy	3200.00
0005435127440	14753	Economy	3200.00
0005434928359	14753	Economy	3200.00
0005435127462	14753	Economy	3200.00
0005435127430	14753	Economy	3200.00
0005435554313	14753	Economy	3200.00
0005435127445	14753	Economy	3200.00
0005435626684	14753	Economy	3200.00
0005435626681	14753	Economy	3200.00
0005435626674	14753	Economy	3200.00
0005435554310	14753	Economy	3200.00
0005435127466	14753	Economy	3200.00
0005435127458	14753	Economy	3200.00
0005434411856	14753	Economy	3200.00
0005435626667	14753	Economy	3200.00
0005435715917	7142	Business	86900.00
0005435715918	7142	Business	86900.00
0005435443516	7142	Business	86900.00
0005435443509	7142	Business	86900.00
0005435443508	7142	Economy	29000.00
0005435178526	7142	Economy	29000.00
0005435715921	7142	Economy	31900.00
0005435179408	7142	Economy	31900.00
0005435443492	7142	Economy	29000.00
0005435715919	7142	Economy	29000.00
0005435443491	7142	Economy	29000.00
0005435216628	7142	Economy	29000.00
0005435715922	7142	Economy	29000.00
0005435443486	7142	Economy	29000.00
0005435715915	7142	Economy	29000.00
0005432398293	7142	Economy	29000.00
0005435221066	7142	Economy	29000.00
0005435221070	7142	Economy	29000.00
0005435219230	7142	Economy	29000.00
0005435443515	7142	Economy	29000.00
0005432398292	7142	Economy	29000.00
0005435715924	7142	Economy	29000.00
0005435715916	7142	Economy	29000.00
0005435715920	7142	Economy	29000.00
0005435178524	7142	Economy	29000.00
0005435221069	7142	Economy	29000.00
0005435715925	7142	Economy	29000.00
0005432398291	7142	Economy	29000.00
0005435443485	7142	Economy	29000.00
0005435443475	7142	Economy	29000.00
0005435443517	7142	Economy	29000.00
0005435715927	7142	Economy	29000.00
0005435715928	7142	Economy	29000.00
0005435715926	7142	Economy	29000.00
0005435715923	7142	Economy	29000.00
0005435443439	7142	Economy	29000.00
0005435217763	27071	Business	86900.00
0005435715802	27071	Business	86900.00
0005435218141	27071	Business	86900.00
0005435443564	27071	Business	86900.00
0005435179015	27071	Business	86900.00
0005435443565	27071	Business	86900.00
0005435218134	27071	Business	86900.00
0005435217762	27071	Economy	29000.00
0005435443560	27071	Economy	29000.00
0005435715774	27071	Economy	29000.00
0005435715733	27071	Economy	29000.00
0005435715839	27071	Economy	29000.00
0005435217767	27071	Economy	29000.00
0005435715801	27071	Economy	29000.00
0005435218138	27071	Economy	31900.00
0005432398251	27071	Economy	31900.00
0005435715730	27071	Economy	31900.00
0005435715812	27071	Economy	31900.00
0005435715775	27071	Economy	31900.00
0005435715722	27071	Economy	29000.00
0005435715834	27071	Economy	29000.00
0005435443561	27071	Economy	29000.00
0005435216642	27071	Economy	29000.00
0005435218136	27071	Economy	29000.00
0005435217768	27071	Economy	29000.00
0005435178534	27071	Economy	29000.00
0005435715723	27071	Economy	29000.00
0005435217764	27071	Economy	29000.00
0005435179016	27071	Economy	29000.00
0005435443566	27071	Economy	29000.00
0005435715819	27071	Economy	29000.00
0005435178535	27071	Economy	29000.00
0005435216641	27071	Economy	29000.00
0005435217761	27071	Economy	29000.00
0005435217766	27071	Economy	29000.00
0005435216638	27071	Economy	29000.00
0005435217769	27071	Economy	29000.00
0005435218139	27071	Economy	29000.00
0005435216637	27071	Economy	29000.00
0005435216636	27071	Economy	29000.00
0005432394162	27071	Economy	29000.00
0005435218140	27071	Economy	29000.00
0005435715793	27071	Economy	29000.00
0005435216643	27071	Economy	29000.00
0005435216640	27071	Economy	29000.00
0005435443559	27071	Economy	29000.00
0005435217765	27071	Economy	29000.00
0005435218135	27071	Economy	29000.00
0005435443563	27071	Economy	29000.00
0005435216639	27071	Economy	29000.00
0005435715799	27071	Economy	29000.00
0005435216644	27071	Economy	29000.00
0005435443562	27071	Economy	29000.00
0005435218137	27071	Economy	29000.00
0005434085052	2714	Economy	7700.00
0005434085054	2714	Economy	7700.00
0005433060468	2714	Economy	7700.00
0005434085053	2714	Economy	7700.00
0005434085051	2714	Economy	7700.00
0005433060465	2714	Economy	7700.00
0005434085055	2714	Economy	7700.00
0005433060469	2714	Economy	7700.00
0005433060459	2714	Economy	7700.00
0005433060457	2714	Economy	7700.00
0005433060456	2714	Economy	7700.00
0005433060484	28465	Economy	7700.00
0005433060485	28465	Economy	7700.00
0005434085030	28465	Economy	7700.00
0005434085012	28465	Economy	7700.00
0005434085031	28465	Economy	7700.00
0005434085013	28465	Economy	7700.00
0005434085003	28465	Economy	7700.00
0005434085016	28465	Economy	7700.00
0005434085018	28465	Economy	7700.00
0005434084993	28465	Economy	7700.00
0005434085032	28465	Economy	7700.00
0005433788311	11161	Economy	27100.00
0005433788308	11161	Economy	24600.00
0005435548557	11161	Economy	24600.00
0005433788315	11161	Economy	24600.00
0005435548571	11161	Economy	24600.00
0005435548545	11161	Economy	24600.00
0005433788320	11161	Economy	24600.00
0005433788319	11161	Economy	24600.00
0005435548565	11161	Economy	24600.00
0005435548572	11161	Economy	24600.00
0005433788316	11161	Economy	24600.00
0005435548573	11161	Economy	24600.00
0005435548550	11161	Economy	24600.00
0005433788313	11161	Economy	24600.00
0005433788314	11161	Economy	24600.00
0005433788310	11161	Economy	24600.00
0005433788305	11161	Economy	24600.00
0005435548562	11161	Economy	24600.00
0005435548549	11161	Economy	24600.00
0005435548574	11161	Economy	24600.00
0005435548546	11161	Economy	24600.00
0005433788312	11161	Economy	24600.00
0005435548564	11161	Economy	24600.00
0005433788317	11161	Economy	24600.00
0005433788307	11161	Economy	24600.00
0005435548575	11161	Economy	24600.00
0005433788306	11161	Economy	24600.00
0005433788318	11161	Economy	24600.00
0005433788309	11161	Economy	24600.00
0005435548563	11161	Economy	24600.00
0005435548554	11161	Economy	24600.00
0005435548611	20680	Economy	27100.00
0005435548603	20680	Economy	24600.00
0005435548606	20680	Economy	24600.00
0005435548605	20680	Economy	24600.00
0005433788261	20680	Economy	24600.00
0005435548604	20680	Economy	24600.00
0005435548607	20680	Economy	24600.00
0005435548610	20680	Economy	24600.00
0005435548608	20680	Economy	24600.00
0005435548609	20680	Economy	24600.00
0005433788260	20680	Economy	24600.00
0005433788250	20680	Economy	24600.00
0005435541425	11362	Business	20200.00
0005435541460	11362	Business	20200.00
0005435541415	11362	Business	20200.00
0005435541487	11362	Economy	6700.00
0005435541402	11362	Economy	6700.00
0005435518201	11362	Economy	6700.00
0005435541461	11362	Economy	6700.00
0005435541357	11362	Economy	6700.00
0005435518250	11362	Economy	6700.00
0005435541401	11362	Economy	6700.00
0005435541426	11362	Economy	7400.00
0005435518297	11362	Economy	7400.00
0005435541340	11362	Economy	6700.00
0005435541434	11362	Economy	6700.00
0005435518298	11362	Economy	6700.00
0005435518224	11362	Economy	6700.00
0005435518244	11362	Economy	6700.00
0005435541395	11362	Economy	6700.00
0005435541419	11362	Economy	6700.00
0005435518165	11362	Economy	6700.00
0005435518245	11362	Economy	6700.00
0005435518164	11362	Economy	6700.00
0005435541462	11362	Economy	6700.00
0005435541369	11362	Economy	6700.00
0005435518188	11362	Economy	6700.00
0005435518214	11362	Economy	6700.00
0005435518123	11362	Economy	6700.00
0005435518213	11362	Economy	6700.00
0005435518220	11362	Economy	6700.00
0005435518254	11362	Economy	6700.00
0005435541427	11362	Economy	6700.00
0005435541435	11362	Economy	6700.00
0005435541463	11362	Economy	6700.00
0005435541399	11362	Economy	6700.00
0005435541476	11362	Economy	6700.00
0005435518163	11362	Economy	6700.00
0005435518279	11362	Economy	6700.00
0005435541398	11362	Economy	6700.00
0005435541418	11362	Economy	6700.00
0005435541346	11362	Economy	6700.00
0005435541368	11362	Economy	6700.00
0005435530104	22238	Business	20200.00
0005435530106	22238	Business	20200.00
0005435529816	22238	Business	20200.00
0005435541570	22238	Business	20200.00
0005435529826	22238	Business	20200.00
0005435541553	22238	Business	20200.00
0005435530113	22238	Business	20200.00
0005435530118	22238	Business	20200.00
0005435541567	22238	Economy	6700.00
0005435541556	22238	Economy	6700.00
0005435529827	22238	Economy	6700.00
0005435541563	22238	Economy	6700.00
0005435529823	22238	Economy	6700.00
0005435530110	22238	Economy	7400.00
0005435541552	22238	Economy	7400.00
0005435541572	22238	Economy	7400.00
0005435529821	22238	Economy	6700.00
0005435530115	22238	Economy	6700.00
0005435529818	22238	Economy	6700.00
0005435541568	22238	Economy	6700.00
0005435541569	22238	Economy	6700.00
0005435529810	22238	Economy	6700.00
0005435541557	22238	Economy	6700.00
0005435541555	22238	Economy	6700.00
0005435529811	22238	Economy	6700.00
0005435530111	22238	Economy	6700.00
0005435541561	22238	Economy	6700.00
0005435530117	22238	Economy	6700.00
0005435529822	22238	Economy	6700.00
0005435530102	22238	Economy	6700.00
0005435541566	22238	Economy	6700.00
0005435541558	22238	Economy	6700.00
0005435529812	22238	Economy	6700.00
0005432294548	22238	Economy	6700.00
0005435529817	22238	Economy	6700.00
0005435541564	22238	Economy	6700.00
0005435541554	22238	Economy	6700.00
0005435530112	22238	Economy	6700.00
0005435529819	22238	Economy	6700.00
0005435541571	22238	Economy	6700.00
0005435529820	22238	Economy	6700.00
0005435529815	22238	Economy	6700.00
0005435529824	22238	Economy	6700.00
0005432294550	22238	Economy	6700.00
0005435530105	22238	Economy	6700.00
0005435529809	22238	Economy	6700.00
0005435530109	22238	Economy	6700.00
0005435541565	22238	Economy	6700.00
0005435529825	22238	Economy	6700.00
0005435541562	22238	Economy	6700.00
0005435529814	22238	Economy	6700.00
0005435541559	22238	Economy	6700.00
0005435541560	22238	Economy	6700.00
0005435530114	22238	Economy	6700.00
0005435530116	22238	Economy	6700.00
0005435530107	22238	Economy	6700.00
0005435530103	22238	Economy	6700.00
0005435530108	22238	Economy	6700.00
0005435529813	22238	Economy	6700.00
0005432294549	22238	Economy	6700.00
0005435529808	22238	Economy	6700.00
0005434908688	2292	Business	20200.00
0005433252074	2292	Business	20200.00
0005434908722	2292	Business	20200.00
0005434908712	2292	Business	20200.00
0005434908715	2292	Business	20200.00
0005434908682	2292	Business	20200.00
0005434908684	2292	Business	20200.00
0005434908699	2292	Business	20200.00
0005433252121	2292	Business	20200.00
0005434908674	2292	Business	20200.00
0005433252186	2292	Business	20200.00
0005434908719	2292	Business	20200.00
0005433251981	2292	Economy	6700.00
0005434908693	2292	Economy	6700.00
0005434908687	2292	Economy	6700.00
0005433252075	2292	Economy	6700.00
0005433252145	2292	Economy	6700.00
0005433252086	2292	Economy	6700.00
0005434908685	2292	Economy	6700.00
0005433252113	2292	Economy	6700.00
0005433251908	2292	Economy	6700.00
0005434908730	2292	Economy	6700.00
0005433252092	2292	Economy	7400.00
0005434908710	2292	Economy	7400.00
0005433252083	2292	Economy	7400.00
0005434908695	2292	Economy	7400.00
0005433251998	2292	Economy	7400.00
0005433252015	2292	Economy	6700.00
0005433252054	2292	Economy	6700.00
0005434908723	2292	Economy	6700.00
0005434908724	2292	Economy	6700.00
0005434908725	2292	Economy	6700.00
0005433401043	2292	Economy	6700.00
0005434908727	2292	Economy	6700.00
0005434908718	2292	Economy	6700.00
0005433252060	2292	Economy	6700.00
0005434908700	2292	Economy	6700.00
0005434908720	2292	Economy	6700.00
0005434908708	2292	Economy	6700.00
0005434908726	2292	Economy	6700.00
0005434908706	2292	Economy	6700.00
0005434908691	2292	Economy	6700.00
0005434908704	2292	Economy	6700.00
0005433252211	2292	Economy	6700.00
0005433251997	2292	Economy	6700.00
0005433252063	2292	Economy	6700.00
0005434908697	2292	Economy	6700.00
0005433252143	2292	Economy	6700.00
0005434908729	2292	Economy	6700.00
0005434908714	2292	Economy	6700.00
0005433252144	2292	Economy	6700.00
0005434908689	2292	Economy	6700.00
0005434908692	2292	Economy	6700.00
0005434908702	2292	Economy	6700.00
0005434908696	2292	Economy	6700.00
0005433252222	2292	Economy	6700.00
0005433252002	2292	Economy	6700.00
0005434908721	2292	Economy	6700.00
0005434908731	2292	Economy	6700.00
0005433252112	2292	Economy	6700.00
0005433252187	2292	Economy	6700.00
0005433252210	2292	Economy	6700.00
0005433251907	2292	Economy	6700.00
0005434908677	2292	Economy	6700.00
0005434908703	2292	Economy	6700.00
0005434908711	2292	Economy	6700.00
0005434908686	2292	Economy	6700.00
0005433252105	2292	Economy	6700.00
0005434908705	2292	Economy	6700.00
0005434908732	2292	Economy	6700.00
0005434908701	2292	Economy	6700.00
0005433252072	2292	Economy	6700.00
0005434908678	2292	Economy	6700.00
0005434908681	2292	Economy	6700.00
0005433252084	2292	Economy	6700.00
0005434908675	2292	Economy	6700.00
0005434908716	2292	Economy	6700.00
0005434908713	2292	Economy	6700.00
0005434908694	2292	Economy	6700.00
0005434908709	2292	Economy	6700.00
0005433252104	2292	Economy	6700.00
0005433252016	2292	Economy	6700.00
0005434908680	2292	Economy	6700.00
0005434908734	2292	Economy	6700.00
0005433252040	2292	Economy	6700.00
0005434908717	2292	Economy	6700.00
0005434908707	2292	Economy	6700.00
0005433252026	2292	Economy	6700.00
0005434908679	2292	Economy	6700.00
0005434908683	2292	Economy	6700.00
0005434908733	2292	Economy	6700.00
0005434908728	2292	Economy	6700.00
0005433252039	2292	Economy	6700.00
0005433401026	2292	Economy	6700.00
0005434908698	2292	Economy	6700.00
0005434908690	2292	Economy	6700.00
0005434908676	2292	Economy	6700.00
0005434908280	25613	Business	20200.00
0005434907984	25613	Business	20200.00
0005434908160	25613	Business	20200.00
0005434908178	25613	Business	20200.00
0005433252298	25613	Business	20200.00
0005434908067	25613	Business	20200.00
0005434907908	25613	Business	20200.00
0005434908173	25613	Business	20200.00
0005433252312	25613	Business	20200.00
0005433252307	25613	Business	20200.00
0005434908068	25613	Business	20200.00
0005434908072	25613	Economy	6700.00
0005434908117	25613	Economy	6700.00
0005434908203	25613	Economy	6700.00
0005433252301	25613	Economy	6700.00
0005433401065	25613	Economy	6700.00
0005433401063	25613	Economy	6700.00
0005434908291	25613	Economy	6700.00
0005434908125	25613	Economy	6700.00
0005433252290	25613	Economy	6700.00
0005433401064	25613	Economy	7400.00
0005434908279	25613	Economy	7400.00
0005434908071	25613	Economy	7400.00
0005434908214	25613	Economy	7400.00
0005434908263	25613	Economy	6700.00
0005434908207	25613	Economy	6700.00
0005433252297	25613	Economy	6700.00
0005434908052	25613	Economy	6700.00
0005433252309	25613	Economy	6700.00
0005433252303	25613	Economy	6700.00
0005434908134	25613	Economy	6700.00
0005434908155	25613	Economy	6700.00
0005434908236	25613	Economy	6700.00
0005433252289	25613	Economy	6700.00
0005434908246	25613	Economy	6700.00
0005433252306	25613	Economy	6700.00
0005433252305	25613	Economy	6700.00
0005434908262	25613	Economy	6700.00
0005434908159	25613	Economy	6700.00
0005433252294	25613	Economy	6700.00
0005433252300	25613	Economy	6700.00
0005434907985	25613	Economy	6700.00
0005433252286	25613	Economy	6700.00
0005434907978	25613	Economy	6700.00
0005434908127	25613	Economy	6700.00
0005434908115	25613	Economy	6700.00
0005434908075	25613	Economy	6700.00
0005434908133	25613	Economy	6700.00
0005434908101	25613	Economy	6700.00
0005434908283	25613	Economy	6700.00
0005433252291	25613	Economy	6700.00
0005433252302	25613	Economy	6700.00
0005434908143	25613	Economy	6700.00
0005433252293	25613	Economy	6700.00
0005434908268	25613	Economy	6700.00
0005433252304	25613	Economy	6700.00
0005433252292	25613	Economy	6700.00
0005434908153	25613	Economy	6700.00
0005434908064	25613	Economy	6700.00
0005434908284	25613	Economy	6700.00
0005434908264	25613	Economy	6700.00
0005433252308	25613	Economy	6700.00
0005434908267	25613	Economy	6700.00
0005434908116	25613	Economy	6700.00
0005433252288	25613	Economy	6700.00
0005433252285	25613	Economy	6700.00
0005434908285	25613	Economy	6700.00
0005434908206	25613	Economy	6700.00
0005433252284	25613	Economy	6700.00
0005434908144	25613	Economy	6700.00
0005434908305	25613	Economy	6700.00
0005433252296	25613	Economy	6700.00
0005434908104	25613	Economy	6700.00
0005434908266	25613	Economy	6700.00
0005434908041	25613	Economy	6700.00
0005434908202	25613	Economy	6700.00
0005433252310	25613	Economy	6700.00
0005434908216	25613	Economy	6700.00
0005433252299	25613	Economy	6700.00
0005433252295	25613	Economy	6700.00
0005434907909	25613	Economy	6700.00
0005434908140	25613	Economy	6700.00
0005434908022	25613	Economy	6700.00
0005433252311	25613	Economy	6700.00
0005434908128	25613	Economy	6700.00
0005434907959	25613	Economy	6700.00
0005433252287	25613	Economy	6700.00
0005434908215	25613	Economy	6700.00
0005434908183	25613	Economy	6700.00
0005432621419	2519	Economy	12400.00
0005432621409	2519	Economy	12400.00
0005432862416	2519	Economy	12400.00
0005432621414	2519	Economy	12400.00
0005432862415	2519	Economy	12400.00
0005432621418	2519	Economy	12400.00
0005432621420	2519	Economy	12400.00
0005432621411	2519	Economy	12400.00
0005432862455	2519	Economy	12400.00
0005432862414	2519	Economy	12400.00
0005432621412	2519	Economy	12400.00
0005432862427	2519	Economy	12400.00
0005432621416	2519	Economy	12400.00
0005432621413	2519	Economy	12400.00
0005432621417	2519	Economy	12400.00
0005432621421	2519	Economy	12400.00
0005432862489	2519	Economy	12400.00
0005432621410	2519	Economy	12400.00
0005432621415	2519	Economy	12400.00
0005432621408	2519	Economy	12400.00
0005432862441	2519	Economy	12400.00
0005432862454	2519	Economy	12400.00
0005432862512	28040	Economy	13600.00
0005432621271	28040	Economy	13600.00
0005432862505	28040	Economy	12400.00
0005432862510	28040	Economy	12400.00
0005432621313	28040	Economy	12400.00
0005432621263	28040	Economy	12400.00
0005432862508	28040	Economy	12400.00
0005432862507	28040	Economy	12400.00
0005432621266	28040	Economy	12400.00
0005432862511	28040	Economy	12400.00
0005432621300	28040	Economy	12400.00
0005432862506	28040	Economy	12400.00
0005432621307	28040	Economy	12400.00
0005432621311	28040	Economy	12400.00
0005432621277	28040	Economy	12400.00
0005432621310	28040	Economy	12400.00
0005432621312	28040	Economy	12400.00
0005432862509	28040	Economy	12400.00
0005432621285	28040	Economy	12400.00
0005432621306	28040	Economy	12400.00
0005434097507	13087	Economy	11300.00
0005434097508	13087	Economy	11300.00
0005434097509	13087	Economy	11300.00
0005433451672	31050	Economy	8400.00
0005433452791	31050	Economy	8400.00
0005433454902	31377	Economy	8400.00
0005434142686	11985	Economy	7200.00
0005433134222	11985	Economy	7200.00
0005434184700	11985	Economy	7200.00
0005434184693	11985	Economy	6600.00
0005433129367	11985	Economy	6600.00
0005433134224	11985	Economy	6600.00
0005433134212	11985	Economy	6600.00
0005434142698	11985	Economy	6600.00
0005434142697	11985	Economy	6600.00
0005434142690	11985	Economy	6600.00
0005433134240	11985	Economy	6600.00
0005434142691	11985	Economy	6600.00
0005433134241	11985	Economy	6600.00
0005434184691	11985	Economy	6600.00
0005433129366	11985	Economy	6600.00
0005433134223	11985	Economy	6600.00
0005433129369	11985	Economy	6600.00
0005433134194	11985	Economy	6600.00
0005433134254	29827	Economy	7200.00
0005433134253	29827	Economy	6600.00
0005433134255	29827	Economy	6600.00
0005434142713	29827	Economy	6600.00
0005433131830	29827	Economy	6600.00
0005433131828	29827	Economy	6600.00
0005434183634	29827	Economy	6600.00
0005434184719	29827	Economy	6600.00
0005433131829	29827	Economy	6600.00
0005433134256	29827	Economy	6600.00
0005434142714	29827	Economy	6600.00
0005433131827	29827	Economy	6600.00
0005434184720	29827	Economy	6600.00
0005435798962	21300	Economy	15700.00
0005435798985	21300	Economy	15700.00
0005435798961	21300	Economy	15700.00
0005435798980	21300	Economy	15700.00
0005435798972	21300	Economy	15700.00
0005435798984	21300	Economy	15700.00
0005435798973	21300	Economy	15700.00
0005435798988	21300	Economy	15700.00
0005435798964	21300	Economy	15700.00
0005435798965	21300	Economy	15700.00
0005435798986	21300	Economy	15700.00
0005435798968	21300	Economy	15700.00
0005435798971	21300	Economy	15700.00
0005435798967	21300	Economy	15700.00
0005435798978	21300	Economy	15700.00
0005435698062	16487	Economy	19900.00
0005435698066	16487	Economy	18100.00
0005435698057	16487	Economy	18100.00
0005435698063	16487	Economy	18100.00
0005435935105	16487	Economy	18100.00
0005435935104	16487	Economy	18100.00
0005435698068	16487	Economy	18100.00
0005435698047	16487	Economy	18100.00
0005435698067	16487	Economy	18100.00
0005435698058	16487	Economy	18100.00
0005435698046	16487	Economy	18100.00
0005435698070	16487	Economy	18100.00
0005435698048	16487	Economy	18100.00
0005435698065	16487	Economy	18100.00
0005435698071	16487	Economy	18100.00
0005435698050	16487	Economy	18100.00
0005435698054	16487	Economy	18100.00
0005435698069	16487	Economy	18100.00
0005435698049	16487	Economy	18100.00
0005435698061	16487	Economy	18100.00
0005435698055	16487	Economy	18100.00
0005435698064	16487	Economy	18100.00
0005435698072	16487	Economy	18100.00
0005435698045	16487	Economy	18100.00
0005435698052	16487	Economy	18100.00
0005435698060	16487	Economy	18100.00
0005435698059	16487	Economy	18100.00
0005435698051	16487	Economy	18100.00
0005435698053	16487	Economy	18100.00
0005435935110	16487	Economy	18100.00
0005435698056	16487	Economy	18100.00
0005435697789	24713	Economy	19900.00
0005435697910	24713	Economy	18100.00
0005435933578	24713	Economy	18100.00
0005435933581	24713	Economy	18100.00
0005435697837	24713	Economy	18100.00
0005435697920	24713	Economy	18100.00
0005435697919	24713	Economy	18100.00
0005435697765	24713	Economy	18100.00
0005435697830	24713	Economy	18100.00
0005435935127	24713	Economy	18100.00
0005435935128	24713	Economy	18100.00
0005435697878	24713	Economy	18100.00
0005435697915	24713	Economy	18100.00
0005435697810	24713	Economy	18100.00
0005435697864	24713	Economy	18100.00
0005435697881	24713	Economy	18100.00
0005435697901	24713	Economy	18100.00
0005435697863	24713	Economy	18100.00
0005435697839	24713	Economy	18100.00
0005435697811	24713	Economy	18100.00
0005435933579	24713	Economy	18100.00
0005435933580	24713	Economy	18100.00
0005435697902	24713	Economy	18100.00
0005435697885	24713	Economy	18100.00
0005435697809	24713	Economy	18100.00
0005435935129	24713	Economy	18100.00
0005435697884	24713	Economy	18100.00
0005435697880	24713	Economy	18100.00
0005433724923	18768	Economy	4400.00
0005433724924	18768	Economy	4400.00
0005433724876	21631	Economy	4400.00
0005432968904	21631	Economy	4400.00
0005433724885	21631	Economy	4400.00
0005433724890	21631	Economy	4400.00
0005433724865	21631	Economy	4400.00
0005433724891	21631	Economy	4400.00
0005433724896	21631	Economy	4400.00
0005434140304	7290	Business	23100.00
0005434140372	7290	Business	23100.00
0005434140309	7290	Business	23100.00
0005434140324	7290	Business	23100.00
0005434140336	7290	Business	23100.00
0005434140356	7290	Business	23100.00
0005434140345	7290	Business	23100.00
0005434140315	7290	Business	23100.00
0005434140367	7290	Business	23100.00
0005434140369	7290	Business	23100.00
0005434140351	7290	Business	23100.00
0005434140321	7290	Business	23100.00
0005434140357	7290	Economy	7700.00
0005434140320	7290	Economy	7700.00
0005434087642	7290	Economy	7700.00
0005434140295	7290	Economy	7700.00
0005434140354	7290	Economy	7700.00
0005434140335	7290	Economy	7700.00
0005434140348	7290	Economy	7700.00
0005434140299	7290	Economy	7700.00
0005435283557	7290	Economy	7700.00
0005434140371	7290	Economy	7700.00
0005434140311	7290	Economy	8500.00
0005434140319	7290	Economy	8500.00
0005434087644	7290	Economy	8500.00
0005434140355	7290	Economy	8500.00
0005434140359	7290	Economy	8500.00
0005434140373	7290	Economy	7700.00
0005434140308	7290	Economy	7700.00
0005434140305	7290	Economy	7700.00
0005434140374	7290	Economy	7700.00
0005434140343	7290	Economy	7700.00
0005434140339	7290	Economy	7700.00
0005434140346	7290	Economy	7700.00
0005434140314	7290	Economy	7700.00
0005434140370	7290	Economy	7700.00
0005434140350	7290	Economy	7700.00
0005434087643	7290	Economy	7700.00
0005434140349	7290	Economy	7700.00
0005434140318	7290	Economy	7700.00
0005434140300	7290	Economy	7700.00
0005434140362	7290	Economy	7700.00
0005434140307	7290	Economy	7700.00
0005434140323	7290	Economy	7700.00
0005434140365	7290	Economy	7700.00
0005434140347	7290	Economy	7700.00
0005434140331	7290	Economy	7700.00
0005434140330	7290	Economy	7700.00
0005434140326	7290	Economy	7700.00
0005434140358	7290	Economy	7700.00
0005434140352	7290	Economy	7700.00
0005434140341	7290	Economy	7700.00
0005434140298	7290	Economy	7700.00
0005434140301	7290	Economy	7700.00
0005434140313	7290	Economy	7700.00
0005434140361	7290	Economy	7700.00
0005434140332	7290	Economy	7700.00
0005435283555	7290	Economy	7700.00
0005434140333	7290	Economy	7700.00
0005434140312	7290	Economy	7700.00
0005434140329	7290	Economy	7700.00
0005434140338	7290	Economy	7700.00
0005434140366	7290	Economy	7700.00
0005434140303	7290	Economy	7700.00
0005434140334	7290	Economy	7700.00
0005434140340	7290	Economy	7700.00
0005434140317	7290	Economy	7700.00
0005434140342	7290	Economy	7700.00
0005434140325	7290	Economy	7700.00
0005434140364	7290	Economy	7700.00
0005434140302	7290	Economy	7700.00
0005434140344	7290	Economy	7700.00
0005434140316	7290	Economy	7700.00
0005434140363	7290	Economy	7700.00
0005434140310	7290	Economy	7700.00
0005434140327	7290	Economy	7700.00
0005434140328	7290	Economy	7700.00
0005434140360	7290	Economy	7700.00
0005434140353	7290	Economy	7700.00
0005434140368	7290	Economy	7700.00
0005434140322	7290	Economy	7700.00
0005435283556	7290	Economy	7700.00
0005434140375	7290	Economy	7700.00
0005434140297	7290	Economy	7700.00
0005434140296	7290	Economy	7700.00
0005434140306	7290	Economy	7700.00
0005434140337	7290	Economy	7700.00
0005434139719	28577	Business	23100.00
0005434139778	28577	Business	23100.00
0005434139180	28577	Business	23100.00
0005434139808	28577	Business	23100.00
0005434139354	28577	Business	23100.00
0005434139809	28577	Business	23100.00
0005434139337	28577	Business	23100.00
0005434139672	28577	Business	23100.00
0005434139607	28577	Business	23100.00
0005434139471	28577	Business	23100.00
0005434139420	28577	Business	23100.00
0005434139603	28577	Economy	7700.00
0005434139545	28577	Economy	7700.00
0005434139359	28577	Economy	7700.00
0005434139489	28577	Economy	7700.00
0005434087608	28577	Economy	7700.00
0005434139706	28577	Economy	7700.00
0005434139671	28577	Economy	7700.00
0005434139490	28577	Economy	7700.00
0005434139627	28577	Economy	7700.00
0005434139133	28577	Economy	8500.00
0005434139710	28577	Economy	8500.00
0005434139697	28577	Economy	8500.00
0005434139422	28577	Economy	8500.00
0005434139488	28577	Economy	7700.00
0005434139389	28577	Economy	7700.00
0005434139357	28577	Economy	7700.00
0005434139544	28577	Economy	7700.00
0005434139598	28577	Economy	7700.00
0005434139353	28577	Economy	7700.00
0005434139611	28577	Economy	7700.00
0005434139616	28577	Economy	7700.00
0005434139563	28577	Economy	7700.00
0005434139392	28577	Economy	7700.00
0005434139879	28577	Economy	7700.00
0005434139393	28577	Economy	7700.00
0005434139632	28577	Economy	7700.00
0005434139621	28577	Economy	7700.00
0005434139741	28577	Economy	7700.00
0005434139839	28577	Economy	7700.00
0005434139543	28577	Economy	7700.00
0005434139237	28577	Economy	7700.00
0005434087609	28577	Economy	7700.00
0005434139338	28577	Economy	7700.00
0005434139636	28577	Economy	7700.00
0005434139137	28577	Economy	7700.00
0005434139293	28577	Economy	7700.00
0005434139202	28577	Economy	7700.00
0005434139401	28577	Economy	7700.00
0005434139419	28577	Economy	7700.00
0005434139255	28577	Economy	7700.00
0005434139695	28577	Economy	7700.00
0005434139546	28577	Economy	7700.00
0005434139718	28577	Economy	7700.00
0005434139770	28577	Economy	7700.00
0005434139694	28577	Economy	7700.00
0005434139777	28577	Economy	7700.00
0005434139696	28577	Economy	7700.00
0005434139470	28577	Economy	7700.00
0005434139628	28577	Economy	7700.00
0005434139203	28577	Economy	7700.00
0005434139355	28577	Economy	7700.00
0005434139861	28577	Economy	7700.00
0005434139593	28577	Economy	7700.00
0005434139542	28577	Economy	7700.00
0005434139453	28577	Economy	7700.00
0005434139620	28577	Economy	7700.00
0005434139516	28577	Economy	7700.00
0005434139737	28577	Economy	7700.00
0005434139840	28577	Economy	7700.00
0005434139669	28577	Economy	7700.00
0005434139345	28577	Economy	7700.00
0005434139602	28577	Economy	7700.00
0005434139281	28577	Economy	7700.00
0005434139397	28577	Economy	7700.00
0005434087613	28577	Economy	7700.00
0005434139650	28577	Economy	7700.00
0005434139179	28577	Economy	7700.00
0005434087612	28577	Economy	7700.00
0005434139454	28577	Economy	7700.00
0005434139473	28577	Economy	7700.00
0005434139633	28577	Economy	7700.00
0005434139579	28577	Economy	7700.00
0005434139559	28577	Economy	7700.00
0005434139862	28577	Economy	7700.00
0005434139670	28577	Economy	7700.00
0005434139841	28577	Economy	7700.00
0005434139344	28577	Economy	7700.00
0005435808497	1920	Economy	23900.00
0005435808496	1920	Economy	23900.00
0005433407673	1920	Economy	21700.00
0005435808499	1920	Economy	21700.00
0005435808498	1920	Economy	21700.00
0005433407674	1920	Economy	21700.00
0005435808495	1920	Economy	21700.00
0005435808493	1920	Economy	21700.00
0005434610326	1920	Economy	21700.00
0005435808500	1920	Economy	21700.00
0005434610327	1920	Economy	21700.00
0005435808494	1920	Economy	21700.00
0005434610328	1920	Economy	21700.00
0005435808501	1920	Economy	21700.00
0005435808391	23089	Economy	23900.00
0005435808365	23089	Economy	23900.00
0005435808345	23089	Economy	23900.00
0005435808370	23089	Economy	23900.00
0005435808389	23089	Economy	21700.00
0005435808368	23089	Economy	21700.00
0005435808347	23089	Economy	21700.00
0005433407687	23089	Economy	21700.00
0005435808378	23089	Economy	21700.00
0005433407685	23089	Economy	21700.00
0005435808344	23089	Economy	21700.00
0005433407686	23089	Economy	21700.00
0005435808375	23089	Economy	21700.00
0005435808371	23089	Economy	21700.00
0005435808363	23089	Economy	21700.00
0005433407689	23089	Economy	21700.00
0005435808364	23089	Economy	21700.00
0005433407688	23089	Economy	21700.00
0005433407698	23089	Economy	21700.00
0005435808373	23089	Economy	21700.00
0005435808329	23089	Economy	21700.00
0005433407696	23089	Economy	21700.00
0005435808367	23089	Economy	21700.00
0005435808346	23089	Economy	21700.00
0005435808377	23089	Economy	21700.00
0005433407700	23089	Economy	21700.00
0005433407697	23089	Economy	21700.00
0005435808396	23089	Economy	21700.00
0005435808386	23089	Economy	21700.00
0005435808388	23089	Economy	21700.00
0005435808395	23089	Economy	21700.00
0005434610300	23089	Economy	21700.00
0005435808372	23089	Economy	21700.00
0005433407699	23089	Economy	21700.00
0005433407691	23089	Economy	21700.00
0005433407684	23089	Economy	21700.00
0005433407692	23089	Economy	21700.00
0005435808387	23089	Economy	21700.00
0005435808369	23089	Economy	21700.00
0005433407695	23089	Economy	21700.00
0005435808338	23089	Economy	21700.00
0005433407690	23089	Economy	21700.00
0005435808397	23089	Economy	21700.00
0005433407693	23089	Economy	21700.00
0005435808323	23089	Economy	21700.00
0005435808385	23089	Economy	21700.00
0005435808394	23089	Economy	21700.00
0005435808374	23089	Economy	21700.00
0005435808362	23089	Economy	21700.00
0005433407694	23089	Economy	21700.00
0005434504798	16728	Economy	7600.00
0005434504946	16728	Economy	7600.00
0005434504793	16728	Economy	7600.00
0005434504711	16728	Economy	6900.00
0005434504794	16728	Economy	6900.00
0005434504945	16728	Economy	6900.00
0005434504797	16728	Economy	6900.00
0005434504865	16728	Economy	6900.00
0005434504664	16728	Economy	6900.00
0005434504668	16728	Economy	6900.00
0005434504938	16728	Economy	6900.00
0005434504749	16728	Economy	6900.00
0005434504623	16728	Economy	6900.00
0005434504897	16728	Economy	6900.00
0005434504868	16728	Economy	6900.00
0005434504667	16728	Economy	6900.00
0005434504745	16728	Economy	6900.00
0005434504827	16728	Economy	6900.00
0005434504666	16728	Economy	6900.00
0005434504734	16728	Economy	6900.00
0005434504836	16728	Economy	6900.00
0005434504935	16728	Economy	6900.00
0005434504896	16728	Economy	6900.00
0005434504731	16728	Economy	6900.00
0005434504864	16728	Economy	6900.00
0005434504690	16728	Economy	6900.00
0005434504866	16728	Economy	6900.00
0005434504816	16728	Economy	6900.00
0005434504838	16728	Economy	6900.00
0005434504826	16728	Economy	6900.00
0005434504689	16728	Economy	6900.00
0005434504936	16728	Economy	6900.00
0005434504802	16728	Economy	6900.00
0005434504624	16728	Economy	6900.00
0005434504883	16728	Economy	6900.00
0005434504978	16728	Economy	6900.00
0005434504733	16728	Economy	6900.00
0005434504957	16728	Economy	6900.00
0005434504841	16728	Economy	6900.00
0005434505176	22920	Economy	7600.00
0005434505182	22920	Economy	7600.00
0005434505174	22920	Economy	6900.00
0005434505156	22920	Economy	6900.00
0005434505168	22920	Economy	6900.00
0005434505171	22920	Economy	6900.00
0005434505152	22920	Economy	6900.00
0005434505169	22920	Economy	6900.00
0005434505181	22920	Economy	6900.00
0005434505180	22920	Economy	6900.00
0005434505175	22920	Economy	6900.00
0005434505161	22920	Economy	6900.00
0005434505166	22920	Economy	6900.00
0005434505167	22920	Economy	6900.00
0005434505157	22920	Economy	6900.00
0005434505162	22920	Economy	6900.00
0005434505158	22920	Economy	6900.00
0005434505185	22920	Economy	6900.00
0005434505179	22920	Economy	6900.00
0005434505163	22920	Economy	6900.00
0005434505177	22920	Economy	6900.00
0005434505153	22920	Economy	6900.00
0005434505172	22920	Economy	6900.00
0005434505159	22920	Economy	6900.00
0005434505186	22920	Economy	6900.00
0005434505170	22920	Economy	6900.00
0005434505160	22920	Economy	6900.00
0005434505164	22920	Economy	6900.00
0005434505155	22920	Economy	6900.00
0005434505165	22920	Economy	6900.00
0005434505178	22920	Economy	6900.00
0005434505183	22920	Economy	6900.00
0005434505154	22920	Economy	6900.00
0005434505173	22920	Economy	6900.00
0005434505184	22920	Economy	6900.00
0005435078750	2210	Economy	7700.00
0005435078753	2210	Economy	7700.00
0005435078748	2210	Economy	7700.00
0005433266900	2210	Economy	7000.00
0005435078745	2210	Economy	7000.00
0005435078747	2210	Economy	7000.00
0005433266865	2210	Economy	7000.00
0005435078754	2210	Economy	7000.00
0005433266889	2210	Economy	7000.00
0005433266871	2210	Economy	7000.00
0005435078749	2210	Economy	7000.00
0005433266888	2210	Economy	7000.00
0005435078751	2210	Economy	7000.00
0005435078746	2210	Economy	7000.00
0005435078752	2210	Economy	7000.00
0005433266970	24321	Economy	7700.00
0005435078638	24321	Economy	7700.00
0005433266969	24321	Economy	7000.00
0005435078581	24321	Economy	7000.00
0005433266968	24321	Economy	7000.00
0005435078612	24321	Economy	7000.00
0005433266967	24321	Economy	7000.00
0005435078652	24321	Economy	7000.00
0005435078641	24321	Economy	7000.00
0005435078659	24321	Economy	7000.00
0005435078623	24321	Economy	7000.00
0005433266972	24321	Economy	7000.00
0005433266973	24321	Economy	7000.00
0005435078676	24321	Economy	7000.00
0005435078624	24321	Economy	7000.00
0005435078670	24321	Economy	7000.00
0005433266974	24321	Economy	7000.00
0005435078635	24321	Economy	7000.00
0005435078567	24321	Economy	7000.00
0005435078620	24321	Economy	7000.00
0005433266971	24321	Economy	7000.00
0005435078579	24321	Economy	7000.00
0005435078649	24321	Economy	7000.00
0005435464539	6632	Economy	9800.00
0005434989032	6632	Economy	9800.00
0005434989043	6632	Economy	9800.00
0005434989042	6632	Economy	9800.00
0005435464538	6632	Economy	9800.00
0005434989039	6632	Economy	9800.00
0005434989037	6632	Economy	9800.00
0005434989046	6632	Economy	9800.00
0005435803340	6632	Economy	9800.00
0005434989038	6632	Economy	9800.00
0005434989033	6632	Economy	9800.00
0005434989040	6632	Economy	9800.00
0005434989047	6632	Economy	9800.00
0005435803342	6632	Economy	9800.00
0005435803339	6632	Economy	9800.00
0005434989036	6632	Economy	9800.00
0005434989035	6632	Economy	9800.00
0005435803341	6632	Economy	9800.00
0005434989044	6632	Economy	9800.00
0005434989034	6632	Economy	9800.00
0005434989045	6632	Economy	9800.00
0005434989041	6632	Economy	9800.00
0005434988905	23640	Economy	10800.00
0005434988903	23640	Economy	9800.00
0005434988906	23640	Economy	9800.00
0005434988908	23640	Economy	9800.00
0005435803318	23640	Economy	9800.00
0005435803310	23640	Economy	9800.00
0005434988918	23640	Economy	9800.00
0005434988917	23640	Economy	9800.00
0005435464561	23640	Economy	9800.00
0005435803317	23640	Economy	9800.00
0005434988909	23640	Economy	9800.00
0005435803324	23640	Economy	9800.00
0005434988901	23640	Economy	9800.00
0005434988900	23640	Economy	9800.00
0005434988910	23640	Economy	9800.00
0005435464560	23640	Economy	9800.00
0005435803312	23640	Economy	9800.00
0005433450543	30454	Business	9900.00
0005432384225	30454	Business	9900.00
0005433453814	30454	Business	9900.00
0005432384227	30454	Business	9900.00
0005432384224	30454	Business	9900.00
0005433450542	30454	Business	9900.00
0005433450554	30454	Business	9900.00
0005432384226	30454	Economy	3300.00
0005432384223	30454	Economy	3300.00
0005433450541	30454	Economy	3300.00
0005432384211	30454	Economy	3300.00
0005433450552	30454	Economy	3300.00
0005432384207	30454	Economy	3300.00
0005432384219	30454	Economy	3600.00
0005433450553	30454	Economy	3600.00
0005432384200	30454	Economy	3600.00
0005433450555	30454	Economy	3600.00
0005432384206	30454	Economy	3300.00
0005433453816	30454	Economy	3300.00
0005432384229	30454	Economy	3300.00
0005432384230	30454	Economy	3300.00
0005432384204	30454	Economy	3300.00
0005433450551	30454	Economy	3300.00
0005432384208	30454	Economy	3300.00
0005433450556	30454	Economy	3300.00
0005432384205	30454	Economy	3300.00
0005432384202	30454	Economy	3300.00
0005433450548	30454	Economy	3300.00
0005433450550	30454	Economy	3300.00
0005432384213	30454	Economy	3300.00
0005432384221	30454	Economy	3300.00
0005432384198	30454	Economy	3300.00
0005432384228	30454	Economy	3300.00
0005432384210	30454	Economy	3300.00
0005433450546	30454	Economy	3300.00
0005432384217	30454	Economy	3300.00
0005433450544	30454	Economy	3300.00
0005433450547	30454	Economy	3300.00
0005432384201	30454	Economy	3300.00
0005433450557	30454	Economy	3300.00
0005432384222	30454	Economy	3300.00
0005433450540	30454	Economy	3300.00
0005432384212	30454	Economy	3300.00
0005433454931	30454	Economy	3300.00
0005433453815	30454	Economy	3300.00
0005433450549	30454	Economy	3300.00
0005432384203	30454	Economy	3300.00
0005432384232	30454	Economy	3300.00
0005432384214	30454	Economy	3300.00
0005432384216	30454	Economy	3300.00
0005433450545	30454	Economy	3300.00
0005433454930	30454	Economy	3300.00
0005432384218	30454	Economy	3300.00
0005433453817	30454	Economy	3300.00
0005432384199	30454	Economy	3300.00
0005432384231	30454	Economy	3300.00
0005432384233	30454	Economy	3300.00
0005432384215	30454	Economy	3300.00
0005432384220	30454	Economy	3300.00
0005432384209	30454	Economy	3300.00
0005433450424	31314	Business	9900.00
0005432383887	31314	Business	9900.00
0005433450355	31314	Business	9900.00
0005432383785	31314	Business	9900.00
0005433450425	31314	Business	9900.00
0005432383784	31314	Business	9900.00
0005433450405	31314	Business	9900.00
0005433450379	31314	Business	9900.00
0005433450378	31314	Business	9900.00
0005432383868	31314	Business	9900.00
0005432383783	31314	Economy	3300.00
0005433450278	31314	Economy	3300.00
0005432383760	31314	Economy	3300.00
0005433450277	31314	Economy	3300.00
0005432383852	31314	Economy	3300.00
0005432383657	31314	Economy	3300.00
0005432383782	31314	Economy	3600.00
0005432383804	31314	Economy	3600.00
0005432383691	31314	Economy	3600.00
0005432383653	31314	Economy	3600.00
0005432383652	31314	Economy	3600.00
0005432383722	31314	Economy	3300.00
0005433450414	31314	Economy	3300.00
0005432383811	31314	Economy	3300.00
0005432383708	31314	Economy	3300.00
0005432383720	31314	Economy	3300.00
0005432383814	31314	Economy	3300.00
0005432383834	31314	Economy	3300.00
0005433450486	31314	Economy	3300.00
0005432383645	31314	Economy	3300.00
0005432383794	31314	Economy	3300.00
0005432383819	31314	Economy	3300.00
0005432383853	31314	Economy	3300.00
0005432383658	31314	Economy	3300.00
0005432383822	31314	Economy	3300.00
0005433450416	31314	Economy	3300.00
0005432383644	31314	Economy	3300.00
0005433450358	31314	Economy	3300.00
0005432383820	31314	Economy	3300.00
0005433450276	31314	Economy	3300.00
0005433450444	31314	Economy	3300.00
0005433450417	31314	Economy	3300.00
0005432383776	31314	Economy	3300.00
0005432383982	31314	Economy	3300.00
0005433450322	31314	Economy	3300.00
0005432383641	31314	Economy	3300.00
0005433450281	31314	Economy	3300.00
0005432383772	31314	Economy	3300.00
0005432383742	31314	Economy	3300.00
0005432383799	31314	Economy	3300.00
0005433450406	31314	Economy	3300.00
0005432383579	31314	Economy	3300.00
0005433450233	31314	Economy	3300.00
0005433450354	31314	Economy	3300.00
0005432383903	31314	Economy	3300.00
0005433450356	31314	Economy	3300.00
0005432383805	31314	Economy	3300.00
0005432383743	31314	Economy	3300.00
0005433450415	31314	Economy	3300.00
0005432383647	31314	Economy	3300.00
0005433450446	31314	Economy	3300.00
0005432383815	31314	Economy	3300.00
0005432383888	31314	Economy	3300.00
0005432383983	31314	Economy	3300.00
0005432383869	31314	Economy	3300.00
0005433450423	31314	Economy	3300.00
0005433450441	31314	Economy	3300.00
0005432383744	31314	Economy	3300.00
0005432383659	31314	Economy	3300.00
0005432383771	31314	Economy	3300.00
0005432383580	31314	Economy	3300.00
0005432383721	31314	Economy	3300.00
0005433450319	31314	Economy	3300.00
0005432383766	31314	Economy	3300.00
0005432384013	31314	Economy	3300.00
0005432383835	31314	Economy	3300.00
0005433450280	31314	Economy	3300.00
0005435299864	10763	Economy	17100.00
0005435304233	10763	Economy	17100.00
0005433131770	10763	Economy	15600.00
0005433126908	10763	Economy	15600.00
0005433126915	10763	Economy	15600.00
0005433126919	10763	Economy	15600.00
0005433126917	10763	Economy	15600.00
0005433131784	10763	Economy	15600.00
0005433126930	10763	Economy	15600.00
0005435304237	10763	Economy	15600.00
0005433126916	10763	Economy	15600.00
0005433126925	10763	Economy	15600.00
0005433126918	10763	Economy	15600.00
0005433131789	10763	Economy	15600.00
0005435304236	10763	Economy	15600.00
0005433126926	10763	Economy	15600.00
0005433126935	10763	Economy	15600.00
0005435304234	10763	Economy	15600.00
0005433131783	10763	Economy	15600.00
0005435299849	10763	Economy	15600.00
0005435299859	10763	Economy	15600.00
0005435304235	10763	Economy	15600.00
0005435299907	29718	Economy	17100.00
0005435302328	29718	Economy	17100.00
0005433126968	29718	Economy	15600.00
0005433126971	29718	Economy	15600.00
0005435299908	29718	Economy	15600.00
0005435302329	29718	Economy	15600.00
0005433129401	29718	Economy	15600.00
0005435299909	29718	Economy	15600.00
0005433126969	29718	Economy	15600.00
0005433129400	29718	Economy	15600.00
0005433126967	29718	Economy	15600.00
0005435299910	29718	Economy	15600.00
0005433129399	29718	Economy	15600.00
0005433126970	29718	Economy	15600.00
0005435299906	29718	Economy	15600.00
0005435302327	29718	Economy	15600.00
0005432264541	2386	Economy	17200.00
0005434287868	2386	Economy	15700.00
0005433110287	2386	Economy	15700.00
0005434287872	2386	Economy	15700.00
0005433110301	2386	Economy	15700.00
0005434287881	2386	Economy	15700.00
0005433110266	2386	Economy	15700.00
0005433110261	2386	Economy	15700.00
0005434287870	2386	Economy	15700.00
0005433110303	2386	Economy	15700.00
0005434287873	2386	Economy	15700.00
0005434287876	2386	Economy	15700.00
0005434287869	2386	Economy	15700.00
0005434287879	2386	Economy	15700.00
0005433110267	2386	Economy	15700.00
0005433110283	2386	Economy	15700.00
0005433110268	2386	Economy	15700.00
0005433110274	2386	Economy	15700.00
0005433110260	2386	Economy	15700.00
0005434287874	2386	Economy	15700.00
0005433110288	2386	Economy	15700.00
0005432264542	2386	Economy	15700.00
0005434287880	2386	Economy	15700.00
0005433110269	2386	Economy	15700.00
0005434287877	2386	Economy	15700.00
0005434287882	2386	Economy	15700.00
0005434287871	2386	Economy	15700.00
0005432264540	2386	Economy	15700.00
0005433110264	2386	Economy	15700.00
0005434287875	2386	Economy	15700.00
0005433110265	2386	Economy	15700.00
0005434287878	2386	Economy	15700.00
0005433110289	2386	Economy	15700.00
0005433110273	2386	Economy	15700.00
0005433110373	26864	Economy	17200.00
0005434287738	26864	Economy	17200.00
0005433110376	26864	Economy	17200.00
0005434287745	26864	Economy	15700.00
0005433110377	26864	Economy	15700.00
0005434287733	26864	Economy	15700.00
0005434287615	26864	Economy	15700.00
0005433110372	26864	Economy	15700.00
0005434287700	26864	Economy	15700.00
0005434287739	26864	Economy	15700.00
0005434287772	26864	Economy	15700.00
0005434287719	26864	Economy	15700.00
0005434287737	26864	Economy	15700.00
0005433110370	26864	Economy	15700.00
0005434287633	26864	Economy	15700.00
0005434287720	26864	Economy	15700.00
0005434287682	26864	Economy	15700.00
0005434287744	26864	Economy	15700.00
0005433110368	26864	Economy	15700.00
0005434287747	26864	Economy	15700.00
0005433110369	26864	Economy	15700.00
0005433110371	26864	Economy	15700.00
0005434287670	26864	Economy	15700.00
0005433110374	26864	Economy	15700.00
0005434287681	26864	Economy	15700.00
0005433110375	26864	Economy	15700.00
0005434287662	26864	Economy	15700.00
0005434287746	26864	Economy	15700.00
0005434287650	26864	Economy	15700.00
0005435856316	25497	Economy	22800.00
0005435856318	25497	Economy	22800.00
0005435856351	25497	Economy	22800.00
0005435856352	25497	Economy	22800.00
0005435856315	25497	Economy	22800.00
0005435856348	25497	Economy	22800.00
0005435856319	25497	Economy	22800.00
0005435856317	25497	Economy	22800.00
0005435856349	25497	Economy	22800.00
0005434269130	25497	Economy	22800.00
0005435856350	25497	Economy	22800.00
0005434269139	25497	Economy	22800.00
0005434272231	26668	Economy	22800.00
0005435856275	26668	Economy	22800.00
0005434272232	26668	Economy	22800.00
0005435856253	26668	Economy	22800.00
0005435856268	26668	Economy	22800.00
0005435856248	26668	Economy	22800.00
0005435856247	26668	Economy	22800.00
0005434273120	26668	Economy	22800.00
0005435856281	26668	Economy	22800.00
0005435856255	26668	Economy	22800.00
0005434272233	26668	Economy	22800.00
0005435856246	26668	Economy	22800.00
0005435860529	4813	Economy	19400.00
0005433869514	4813	Economy	19400.00
0005433869499	4813	Economy	19400.00
0005435860525	4813	Economy	19400.00
0005433869500	4813	Economy	17600.00
0005433869510	4813	Economy	17600.00
0005433869496	4813	Economy	17600.00
0005433869498	4813	Economy	17600.00
0005433869515	4813	Economy	17600.00
0005433869497	4813	Economy	17600.00
0005433869495	4813	Economy	17600.00
0005433869501	4813	Economy	17600.00
0005433869490	4813	Economy	17600.00
0005433869503	4813	Economy	17600.00
0005435860553	4813	Economy	17600.00
0005433869504	4813	Economy	17600.00
0005433869491	4813	Economy	17600.00
0005433869518	4813	Economy	17600.00
0005433869486	4813	Economy	17600.00
0005433869511	4813	Economy	17600.00
0005433869516	4813	Economy	17600.00
0005435860554	4813	Economy	17600.00
0005433869513	4813	Economy	17600.00
0005433869494	4813	Economy	17600.00
0005433869492	4813	Economy	17600.00
0005433869502	4813	Economy	17600.00
0005433869488	4813	Economy	17600.00
0005433869522	4813	Economy	17600.00
0005435860545	4813	Economy	17600.00
0005435860543	4813	Economy	17600.00
0005433869487	4813	Economy	17600.00
0005433869508	4813	Economy	17600.00
0005433869512	4813	Economy	17600.00
0005433869509	4813	Economy	17600.00
0005433869493	4813	Economy	17600.00
0005433869519	4813	Economy	17600.00
0005433869489	4813	Economy	17600.00
0005435860557	4813	Economy	17600.00
0005433869506	4813	Economy	17600.00
0005433869517	4813	Economy	17600.00
0005435860526	4813	Economy	17600.00
0005433869520	4813	Economy	17600.00
0005433869507	4813	Economy	17600.00
0005433869505	4813	Economy	17600.00
0005433869521	4813	Economy	17600.00
0005433869485	4813	Economy	17600.00
0005435860527	4813	Economy	17600.00
0005435860542	4813	Economy	17600.00
0005433869001	32589	Economy	19400.00
0005433868993	32589	Economy	19400.00
0005433869000	32589	Economy	19400.00
0005433869240	32589	Economy	19400.00
0005435860599	32589	Economy	17600.00
0005433869182	32589	Economy	17600.00
0005433869046	32589	Economy	17600.00
0005433869025	32589	Economy	17600.00
0005433868914	32589	Economy	17600.00
0005433869317	32589	Economy	17600.00
0005433869147	32589	Economy	17600.00
0005433869193	32589	Economy	17600.00
0005433869266	32589	Economy	17600.00
0005433869210	32589	Economy	17600.00
0005433869174	32589	Economy	17600.00
0005433869224	32589	Economy	17600.00
0005433869155	32589	Economy	17600.00
0005435860603	32589	Economy	17600.00
0005435860602	32589	Economy	17600.00
0005433869051	32589	Economy	17600.00
0005433869097	32589	Economy	17600.00
0005433869175	32589	Economy	17600.00
0005433869037	32589	Economy	17600.00
0005433869096	32589	Economy	17600.00
0005433869036	32589	Economy	17600.00
0005433869148	32589	Economy	17600.00
0005433869197	32589	Economy	17600.00
0005433869257	32589	Economy	17600.00
0005433868959	32589	Economy	17600.00
0005433869127	32589	Economy	17600.00
0005433868915	32589	Economy	17600.00
0005433868956	32589	Economy	17600.00
0005433869255	32589	Economy	17600.00
0005433869211	32589	Economy	17600.00
0005433869183	32589	Economy	17600.00
0005433869099	32589	Economy	17600.00
0005433868925	32589	Economy	17600.00
0005433869258	32589	Economy	17600.00
0005433869122	32589	Economy	17600.00
0005433869236	32589	Economy	17600.00
0005435860601	32589	Economy	17600.00
0005433869196	32589	Economy	17600.00
0005433869199	32589	Economy	17600.00
0005433869146	32589	Economy	17600.00
0005435860600	32589	Economy	17600.00
0005433869126	32589	Economy	17600.00
0005433868957	32589	Economy	17600.00
0005433869186	32589	Economy	17600.00
0005433869198	32589	Economy	17600.00
0005433868999	32589	Economy	17600.00
0005434461704	3448	Economy	24800.00
0005434663774	3448	Economy	24800.00
0005434663766	3448	Economy	22600.00
0005434460563	3448	Economy	22600.00
0005434663773	3448	Economy	22600.00
0005434663772	3448	Economy	22600.00
0005434663764	3448	Economy	22600.00
0005435911587	3448	Economy	22600.00
0005434663765	3448	Economy	22600.00
0005434663767	3448	Economy	22600.00
0005435911586	3448	Economy	22600.00
0005434663768	3448	Economy	22600.00
0005434460564	3448	Economy	22600.00
0005435911585	3448	Economy	22600.00
0005434663763	3448	Economy	22600.00
0005434663771	3448	Economy	22600.00
0005434663769	3448	Economy	22600.00
0005434663770	3448	Economy	22600.00
0005435911600	3448	Economy	22600.00
0005435911618	3448	Economy	22600.00
0005435911619	3448	Economy	22600.00
0005434461705	3448	Economy	22600.00
0005434663668	12487	Economy	24800.00
0005434663590	12487	Economy	24800.00
0005434663634	12487	Economy	22600.00
0005434663635	12487	Economy	22600.00
0005434663655	12487	Economy	22600.00
0005435911651	12487	Economy	22600.00
0005434663710	12487	Economy	22600.00
0005434663624	12487	Economy	22600.00
0005434663711	12487	Economy	22600.00
0005435911649	12487	Economy	22600.00
0005434663665	12487	Economy	22600.00
0005434663662	12487	Economy	22600.00
0005434663702	12487	Economy	22600.00
0005435911652	12487	Economy	22600.00
0005434663646	12487	Economy	22600.00
0005434663625	12487	Economy	22600.00
0005435911653	12487	Economy	22600.00
0005434663715	12487	Economy	22600.00
0005435911650	12487	Economy	22600.00
0005434663661	12487	Economy	22600.00
0005434663647	12487	Economy	22600.00
0005435911654	12487	Economy	22600.00
0005435860602	14480	Economy	18500.00
0005433869257	14480	Economy	18500.00
0005433869036	14480	Economy	18500.00
0005435860599	14480	Economy	18500.00
0005433869266	14480	Economy	16800.00
0005433869182	14480	Economy	16800.00
0005433869210	14480	Economy	16800.00
0005433869025	14480	Economy	16800.00
0005433869037	14480	Economy	16800.00
0005433869148	14480	Economy	16800.00
0005433869146	14480	Economy	16800.00
0005433869255	14480	Economy	16800.00
0005433869197	14480	Economy	16800.00
0005433869051	14480	Economy	16800.00
0005433869155	14480	Economy	16800.00
0005433869099	14480	Economy	16800.00
0005433869147	14480	Economy	16800.00
0005433869196	14480	Economy	16800.00
0005433869174	14480	Economy	16800.00
0005433869096	14480	Economy	16800.00
0005435860601	14480	Economy	16800.00
0005433869127	14480	Economy	16800.00
0005433869097	14480	Economy	16800.00
0005433868956	14480	Economy	16800.00
0005435860600	14480	Economy	16800.00
0005433869258	14480	Economy	16800.00
0005433869198	14480	Economy	16800.00
0005433869122	14480	Economy	16800.00
0005433868925	14480	Economy	16800.00
0005433869186	14480	Economy	16800.00
0005433868999	14480	Economy	16800.00
0005433869183	14480	Economy	16800.00
0005433868915	14480	Economy	16800.00
0005433868914	14480	Economy	16800.00
0005433868993	14480	Economy	16800.00
0005433869126	14480	Economy	16800.00
0005433869001	14480	Economy	16800.00
0005433869046	14480	Economy	16800.00
0005433869199	14480	Economy	16800.00
0005433869236	14480	Economy	16800.00
0005433869175	14480	Economy	16800.00
0005433869211	14480	Economy	16800.00
0005433869240	14480	Economy	16800.00
0005435860603	14480	Economy	16800.00
0005433869193	14480	Economy	16800.00
0005433868957	14480	Economy	16800.00
0005433869224	14480	Economy	16800.00
0005433869317	14480	Economy	16800.00
0005433869000	14480	Economy	16800.00
0005433868959	14480	Economy	16800.00
0005433869481	32682	Economy	18500.00
0005433869444	32682	Economy	18500.00
0005433869459	32682	Economy	18500.00
0005433869450	32682	Economy	18500.00
0005433869470	32682	Economy	16800.00
0005433869466	32682	Economy	16800.00
0005433869455	32682	Economy	16800.00
0005433869453	32682	Economy	16800.00
0005433869443	32682	Economy	16800.00
0005433869468	32682	Economy	16800.00
0005435860536	32682	Economy	16800.00
0005435860539	32682	Economy	16800.00
0005435860546	32682	Economy	16800.00
0005433869451	32682	Economy	16800.00
0005433869462	32682	Economy	16800.00
0005433869478	32682	Economy	16800.00
0005433869469	32682	Economy	16800.00
0005433869456	32682	Economy	16800.00
0005433869454	32682	Economy	16800.00
0005433869448	32682	Economy	16800.00
0005435860549	32682	Economy	16800.00
0005433869467	32682	Economy	16800.00
0005433869452	32682	Economy	16800.00
0005433869476	32682	Economy	16800.00
0005433869447	32682	Economy	16800.00
0005433869446	32682	Economy	16800.00
0005433869483	32682	Economy	16800.00
0005433869482	32682	Economy	16800.00
0005433869484	32682	Economy	16800.00
0005433869473	32682	Economy	16800.00
0005433869480	32682	Economy	16800.00
0005433869461	32682	Economy	16800.00
0005435860550	32682	Economy	16800.00
0005433869458	32682	Economy	16800.00
0005433869475	32682	Economy	16800.00
0005433869464	32682	Economy	16800.00
0005435860533	32682	Economy	16800.00
0005433869449	32682	Economy	16800.00
0005433869457	32682	Economy	16800.00
0005433869465	32682	Economy	16800.00
0005433869463	32682	Economy	16800.00
0005433869445	32682	Economy	16800.00
0005433869472	32682	Economy	16800.00
0005433869471	32682	Economy	16800.00
0005435860537	32682	Economy	16800.00
0005433869479	32682	Economy	16800.00
0005433869474	32682	Economy	16800.00
0005433869477	32682	Economy	16800.00
0005435860538	32682	Economy	16800.00
0005433869460	32682	Economy	16800.00
0005432799671	12124	Economy	4900.00
0005432800073	12124	Economy	4900.00
0005432799949	12124	Economy	4900.00
0005432800018	12124	Economy	4900.00
0005432799905	12124	Economy	4400.00
0005432799932	12124	Economy	4400.00
0005432800017	12124	Economy	4400.00
0005432799997	12124	Economy	4400.00
0005432799924	12124	Economy	4400.00
0005432799887	12124	Economy	4400.00
0005432799875	12124	Economy	4400.00
0005432800000	12124	Economy	4400.00
0005432799965	12124	Economy	4400.00
0005432800029	12124	Economy	4400.00
0005432800023	12124	Economy	4400.00
0005432800003	12124	Economy	4400.00
0005432800022	12124	Economy	4400.00
0005432800010	12124	Economy	4400.00
0005432800069	12124	Economy	4400.00
0005432800046	12124	Economy	4400.00
0005432799966	12124	Economy	4400.00
0005432800028	12124	Economy	4400.00
0005432799874	12124	Economy	4400.00
0005432799996	12124	Economy	4400.00
0005432800071	12124	Economy	4400.00
0005432799977	12124	Economy	4400.00
0005432800072	12124	Economy	4400.00
0005432800188	14785	Economy	4900.00
0005432800183	14785	Economy	4900.00
0005432800171	14785	Economy	4400.00
0005432800176	14785	Economy	4400.00
0005432800175	14785	Economy	4400.00
0005432800173	14785	Economy	4400.00
0005432800189	14785	Economy	4400.00
0005432800191	14785	Economy	4400.00
0005432800194	14785	Economy	4400.00
0005432800186	14785	Economy	4400.00
0005432800192	14785	Economy	4400.00
0005432800190	14785	Economy	4400.00
0005432800180	14785	Economy	4400.00
0005432800181	14785	Economy	4400.00
0005432800177	14785	Economy	4400.00
0005432800170	14785	Economy	4400.00
0005432800168	14785	Economy	4400.00
0005432800172	14785	Economy	4400.00
0005432800167	14785	Economy	4400.00
0005432800184	14785	Economy	4400.00
0005432800187	14785	Economy	4400.00
0005432800185	14785	Economy	4400.00
0005432800178	14785	Economy	4400.00
0005432800179	14785	Economy	4400.00
0005432800182	14785	Economy	4400.00
0005432800169	14785	Economy	4400.00
0005432800174	14785	Economy	4400.00
0005432800193	14785	Economy	4400.00
0005435311161	7081	Business	49100.00
0005435311263	7081	Business	49100.00
0005434409407	7081	Business	49100.00
0005435311248	7081	Business	49100.00
0005435311300	7081	Business	49100.00
0005434409418	7081	Business	49100.00
0005434300177	7081	Business	49100.00
0005434409458	7081	Business	49100.00
0005434300161	7081	Business	49100.00
0005434409447	7081	Business	49100.00
0005434409455	7081	Economy	16400.00
0005434300171	7081	Economy	16400.00
0005435293509	7081	Economy	16400.00
0005435311383	7081	Economy	16400.00
0005435293529	7081	Economy	16400.00
0005434409410	7081	Economy	16400.00
0005434409414	7081	Economy	16400.00
0005435293453	7081	Economy	16400.00
0005435311251	7081	Economy	16400.00
0005434300175	7081	Economy	16400.00
0005435311340	7081	Economy	16400.00
0005434409439	7081	Economy	16400.00
0005432154126	7081	Economy	16400.00
0005434409454	7081	Economy	16400.00
0005434409425	7081	Economy	16400.00
0005434409430	7081	Economy	16400.00
0005434409415	7081	Economy	16400.00
0005435311322	7081	Economy	16400.00
0005435311286	7081	Economy	16400.00
0005432154123	7081	Economy	16400.00
0005434300168	7081	Economy	16400.00
0005434409446	7081	Economy	16400.00
0005434409456	7081	Economy	16400.00
0005434300178	7081	Economy	16400.00
0005434300172	7081	Economy	16400.00
0005432154127	7081	Economy	16400.00
0005434409417	7081	Economy	16400.00
0005434409431	7081	Economy	16400.00
0005435293476	7081	Economy	16400.00
0005434409452	7081	Economy	16400.00
0005434409444	7081	Economy	16400.00
0005434409408	7081	Economy	18000.00
0005434409438	7081	Economy	18000.00
0005434300169	7081	Economy	18000.00
0005434300170	7081	Economy	18000.00
0005434409433	7081	Economy	18000.00
0005435311277	7081	Economy	16400.00
0005434409448	7081	Economy	16400.00
0005434300166	7081	Economy	16400.00
0005435311264	7081	Economy	16400.00
0005434409449	7081	Economy	16400.00
0005435311311	7081	Economy	16400.00
0005434409459	7081	Economy	16400.00
0005435311274	7081	Economy	16400.00
0005435293515	7081	Economy	16400.00
0005434409420	7081	Economy	16400.00
0005434409422	7081	Economy	16400.00
0005434409428	7081	Economy	16400.00
0005434409429	7081	Economy	16400.00
0005434409416	7081	Economy	16400.00
0005434409435	7081	Economy	16400.00
0005434409427	7081	Economy	16400.00
0005434409443	7081	Economy	16400.00
0005435311335	7081	Economy	16400.00
0005435293483	7081	Economy	16400.00
0005434300158	7081	Economy	16400.00
0005434409451	7081	Economy	16400.00
0005434409421	7081	Economy	16400.00
0005435293530	7081	Economy	16400.00
0005434300173	7081	Economy	16400.00
0005434409411	7081	Economy	16400.00
0005434409413	7081	Economy	16400.00
0005434300176	7081	Economy	16400.00
0005434409432	7081	Economy	16400.00
0005434300159	7081	Economy	16400.00
0005434409424	7081	Economy	16400.00
0005432108318	7081	Economy	16400.00
0005435311280	7081	Economy	16400.00
0005434409406	7081	Economy	16400.00
0005435293490	7081	Economy	16400.00
0005434409405	7081	Economy	16400.00
0005434409437	7081	Economy	16400.00
0005434300164	7081	Economy	16400.00
0005434300174	7081	Economy	16400.00
0005434409434	7081	Economy	16400.00
0005434409440	7081	Economy	16400.00
0005435311292	7081	Economy	16400.00
0005434409412	7081	Economy	16400.00
0005434409423	7081	Economy	16400.00
0005435311310	7081	Economy	16400.00
0005434300162	7081	Economy	16400.00
0005434300167	7081	Economy	16400.00
0005434409426	7081	Economy	16400.00
0005434409436	7081	Economy	16400.00
0005434300160	7081	Economy	16400.00
0005434409453	7081	Economy	16400.00
0005434409450	7081	Economy	16400.00
0005434300163	7081	Economy	16400.00
0005434409409	7081	Economy	16400.00
0005434409442	7081	Economy	16400.00
0005435311288	7081	Economy	16400.00
0005434300165	7081	Economy	16400.00
0005435293522	7081	Economy	16400.00
0005432154124	7081	Economy	16400.00
0005434409457	7081	Economy	16400.00
0005434409419	7081	Economy	16400.00
0005434409441	7081	Economy	16400.00
0005435293521	7081	Economy	16400.00
0005432154125	7081	Economy	16400.00
0005434409445	7081	Economy	16400.00
0005434299979	26894	Business	49100.00
0005434408841	26894	Business	49100.00
0005435311460	26894	Business	49100.00
0005434408909	26894	Business	49100.00
0005434299971	26894	Business	49100.00
0005434408969	26894	Business	49100.00
0005435311462	26894	Business	49100.00
0005435311465	26894	Business	49100.00
0005435293587	26894	Business	49100.00
0005435311464	26894	Business	49100.00
0005435311459	26894	Business	49100.00
0005434408831	26894	Business	49100.00
0005434408822	26894	Economy	16400.00
0005434408838	26894	Economy	16400.00
0005434299947	26894	Economy	16400.00
0005434299891	26894	Economy	16400.00
0005434409193	26894	Economy	16400.00
0005434299923	26894	Economy	16400.00
0005434300037	26894	Economy	16400.00
0005432058483	26894	Economy	16400.00
0005435293584	26894	Economy	16400.00
0005434408810	26894	Economy	16400.00
0005434409192	26894	Economy	16400.00
0005435293592	26894	Economy	16400.00
0005435311461	26894	Economy	16400.00
0005435311458	26894	Economy	16400.00
0005435293586	26894	Economy	16400.00
0005432058484	26894	Economy	16400.00
0005435311449	26894	Economy	16400.00
0005434299988	26894	Economy	16400.00
0005434409087	26894	Economy	16400.00
0005434299960	26894	Economy	16400.00
0005434409088	26894	Economy	16400.00
0005435293585	26894	Economy	16400.00
0005434408795	26894	Economy	16400.00
0005434299914	26894	Economy	16400.00
0005435293594	26894	Economy	16400.00
0005435293582	26894	Economy	16400.00
0005434408739	26894	Economy	16400.00
0005434408987	26894	Economy	16400.00
0005434408968	26894	Economy	16400.00
0005435311447	26894	Economy	16400.00
0005434408685	26894	Economy	16400.00
0005434300046	26894	Economy	16400.00
0005434408763	26894	Economy	16400.00
0005434409025	26894	Economy	16400.00
0005434408797	26894	Economy	16400.00
0005434408777	26894	Economy	16400.00
0005434408767	26894	Economy	16400.00
0005434408965	26894	Economy	16400.00
0005434408981	26894	Economy	16400.00
0005434299910	26894	Economy	16400.00
0005432058486	26894	Economy	18000.00
0005434408619	26894	Economy	18000.00
0005434408931	26894	Economy	18000.00
0005434299955	26894	Economy	18000.00
0005434408788	26894	Economy	18000.00
0005434300062	26894	Economy	16400.00
0005435293583	26894	Economy	18000.00
0005434299997	26894	Economy	16400.00
0005434408782	26894	Economy	16400.00
0005435311457	26894	Economy	16400.00
0005434408798	26894	Economy	16400.00
0005434408791	26894	Economy	16400.00
0005434408620	26894	Economy	16400.00
0005435311446	26894	Economy	16400.00
0005434409015	26894	Economy	16400.00
0005434300038	26894	Economy	16400.00
0005435293590	26894	Economy	16400.00
0005435311452	26894	Economy	16400.00
0005435293581	26894	Economy	16400.00
0005435293593	26894	Economy	16400.00
0005435311454	26894	Economy	16400.00
0005434409099	26894	Economy	16400.00
0005435311455	26894	Economy	16400.00
0005434300045	26894	Economy	16400.00
0005435311445	26894	Economy	16400.00
0005434408784	26894	Economy	16400.00
0005434408681	26894	Economy	16400.00
0005435293589	26894	Economy	16400.00
0005435311453	26894	Economy	16400.00
0005434408764	26894	Economy	16400.00
0005434408657	26894	Economy	16400.00
0005435311466	26894	Economy	16400.00
0005435311450	26894	Economy	16400.00
0005434300006	26894	Economy	16400.00
0005434300035	26894	Economy	16400.00
0005434299922	26894	Economy	16400.00
0005434408887	26894	Economy	16400.00
0005435293588	26894	Economy	16400.00
0005434408888	26894	Economy	16400.00
0005434409097	26894	Economy	16400.00
0005434408879	26894	Economy	16400.00
0005434408512	26894	Economy	16400.00
0005434408714	26894	Economy	16400.00
0005434299998	26894	Economy	16400.00
0005434408453	26894	Economy	16400.00
0005434408719	26894	Economy	16400.00
0005434408680	26894	Economy	16400.00
0005434408783	26894	Economy	16400.00
0005432058487	26894	Economy	16400.00
0005435311448	26894	Economy	16400.00
0005434408787	26894	Economy	16400.00
0005434299934	26894	Economy	16400.00
0005434299996	26894	Economy	16400.00
0005434299972	26894	Economy	16400.00
0005434300039	26894	Economy	16400.00
0005434408891	26894	Economy	16400.00
0005434408766	26894	Economy	16400.00
0005432058485	26894	Economy	16400.00
0005434300005	26894	Economy	16400.00
0005435311451	26894	Economy	16400.00
0005434408821	26894	Economy	16400.00
0005434300047	26894	Economy	16400.00
0005434299935	26894	Economy	16400.00
0005434409196	26894	Economy	16400.00
0005435311463	26894	Economy	16400.00
0005434408897	26894	Economy	16400.00
0005434409016	26894	Economy	16400.00
0005434408590	26894	Economy	16400.00
0005434299962	26894	Economy	16400.00
0005434408814	26894	Economy	16400.00
0005434408944	26894	Economy	16400.00
0005432058482	26894	Economy	16400.00
0005434299973	26894	Economy	16400.00
0005435293591	26894	Economy	16400.00
0005434300026	26894	Economy	16400.00
0005435311456	26894	Economy	16400.00
0005434409098	26894	Economy	16400.00
0005434300016	26894	Economy	16400.00
0005432605376	6437	Economy	16500.00
0005432605378	6437	Economy	16500.00
0005432605402	6437	Economy	15000.00
0005432605380	6437	Economy	15000.00
0005432605374	6437	Economy	15000.00
0005432605382	6437	Economy	15000.00
0005432605397	6437	Economy	15000.00
0005432605375	6437	Economy	15000.00
0005432605391	6437	Economy	15000.00
0005432605398	6437	Economy	15000.00
0005432605387	6437	Economy	15000.00
0005432605384	6437	Economy	15000.00
0005432605395	6437	Economy	15000.00
0005432605383	6437	Economy	15000.00
0005434512237	6437	Economy	15000.00
0005435312903	6437	Economy	15000.00
0005432605393	6437	Economy	15000.00
0005432605401	6437	Economy	15000.00
0005432605386	6437	Economy	15000.00
0005434512234	6437	Economy	15000.00
0005432605377	6437	Economy	15000.00
0005434512235	6437	Economy	15000.00
0005434512236	6437	Economy	15000.00
0005432605400	6437	Economy	15000.00
0005432605388	6437	Economy	15000.00
0005432605379	6437	Economy	15000.00
0005432605396	6437	Economy	15000.00
0005432605399	6437	Economy	15000.00
0005432605381	6437	Economy	15000.00
0005432605392	6437	Economy	15000.00
0005432605389	6437	Economy	15000.00
0005432605385	6437	Economy	15000.00
0005435221547	6437	Economy	15000.00
0005432605390	6437	Economy	15000.00
0005432605394	6437	Economy	15000.00
0005432605132	21370	Economy	16500.00
0005434512211	21370	Economy	16500.00
0005432604984	21370	Economy	16500.00
0005432605093	21370	Economy	16500.00
0005432605009	21370	Economy	15000.00
0005432605001	21370	Economy	15000.00
0005435221533	21370	Economy	15000.00
0005434512210	21370	Economy	15000.00
0005432605082	21370	Economy	15000.00
0005432604851	21370	Economy	15000.00
0005432604831	21370	Economy	15000.00
0005432605080	21370	Economy	15000.00
0005432604888	21370	Economy	15000.00
0005432605013	21370	Economy	15000.00
0005432604970	21370	Economy	15000.00
0005434512206	21370	Economy	15000.00
0005432604832	21370	Economy	15000.00
0005432605071	21370	Economy	15000.00
0005434512216	21370	Economy	15000.00
0005432604771	21370	Economy	15000.00
0005435312907	21370	Economy	15000.00
0005432604770	21370	Economy	15000.00
0005432605081	21370	Economy	15000.00
0005432604959	21370	Economy	15000.00
0005432605156	21370	Economy	15000.00
0005432604999	21370	Economy	15000.00
0005432604867	21370	Economy	15000.00
0005432604997	21370	Economy	15000.00
0005432605000	21370	Economy	15000.00
0005434512199	21370	Economy	15000.00
0005432604887	21370	Economy	15000.00
0005432605072	21370	Economy	15000.00
0005435312906	21370	Economy	15000.00
0005435221555	21370	Economy	15000.00
0005434512212	21370	Economy	15000.00
0005432604983	21370	Economy	15000.00
0005432605034	21370	Economy	15000.00
0005434512192	21370	Economy	15000.00
0005435221534	21370	Economy	15000.00
0005432605107	21370	Economy	15000.00
0005432604949	21370	Economy	15000.00
0005432605012	21370	Economy	15000.00
0005435221554	21370	Economy	15000.00
0005432605128	21370	Economy	15000.00
0005432605061	21370	Economy	15000.00
0005432605048	21370	Economy	15000.00
0005432605092	21370	Economy	15000.00
0005434908207	15003	Business	18900.00
0005434908267	15003	Business	18900.00
0005434908104	15003	Business	18900.00
0005433252312	15003	Business	18900.00
0005434908264	15003	Business	18900.00
0005434908268	15003	Business	18900.00
0005434908133	15003	Business	18900.00
0005433252309	15003	Business	18900.00
0005433252292	15003	Business	18900.00
0005433252285	15003	Business	18900.00
0005433252301	15003	Business	18900.00
0005434908071	15003	Economy	6300.00
0005434908125	15003	Economy	6300.00
0005434908214	15003	Economy	6300.00
0005434907908	15003	Economy	6300.00
0005434908285	15003	Economy	6300.00
0005434908203	15003	Economy	6300.00
0005434908143	15003	Economy	6300.00
0005434908155	15003	Economy	6300.00
0005434908173	15003	Economy	6900.00
0005434908283	15003	Economy	6900.00
0005434908280	15003	Economy	6900.00
0005434907985	15003	Economy	6900.00
0005434908262	15003	Economy	6900.00
0005433252304	15003	Economy	6300.00
0005433252305	15003	Economy	6300.00
0005433252299	15003	Economy	6300.00
0005433252296	15003	Economy	6300.00
0005434908279	15003	Economy	6300.00
0005433252302	15003	Economy	6300.00
0005433252303	15003	Economy	6300.00
0005434908067	15003	Economy	6300.00
0005434908215	15003	Economy	6300.00
0005433252306	15003	Economy	6300.00
0005434908284	15003	Economy	6300.00
0005433252295	15003	Economy	6300.00
0005434908263	15003	Economy	6300.00
0005434908052	15003	Economy	6300.00
0005434908305	15003	Economy	6300.00
0005434908291	15003	Economy	6300.00
0005433252290	15003	Economy	6300.00
0005434908206	15003	Economy	6300.00
0005434908144	15003	Economy	6300.00
0005434907978	15003	Economy	6300.00
0005433252291	15003	Economy	6300.00
0005433252298	15003	Economy	6300.00
0005434908134	15003	Economy	6300.00
0005433252297	15003	Economy	6300.00
0005433252286	15003	Economy	6300.00
0005434908178	15003	Economy	6300.00
0005434908153	15003	Economy	6300.00
0005434907909	15003	Economy	6300.00
0005434907959	15003	Economy	6300.00
0005434908117	15003	Economy	6300.00
0005433252289	15003	Economy	6300.00
0005434908041	15003	Economy	6300.00
0005433252287	15003	Economy	6300.00
0005434908160	15003	Economy	6300.00
0005433252294	15003	Economy	6300.00
0005433252300	15003	Economy	6300.00
0005434908127	15003	Economy	6300.00
0005433252288	15003	Economy	6300.00
0005434907984	15003	Economy	6300.00
0005433252308	15003	Economy	6300.00
0005434908101	15003	Economy	6300.00
0005434908115	15003	Economy	6300.00
0005433252310	15003	Economy	6300.00
0005434908075	15003	Economy	6300.00
0005434908183	15003	Economy	6300.00
0005434908072	15003	Economy	6300.00
0005433252293	15003	Economy	6300.00
0005434908202	15003	Economy	6300.00
0005434908022	15003	Economy	6300.00
0005434908266	15003	Economy	6300.00
0005433252307	15003	Economy	6300.00
0005434908140	15003	Economy	6300.00
0005434908236	15003	Economy	6300.00
0005434908064	15003	Economy	6300.00
0005433252311	15003	Economy	6300.00
0005434908068	15003	Economy	6300.00
0005434908246	15003	Economy	6300.00
0005434908116	15003	Economy	6300.00
0005434908128	15003	Economy	6300.00
0005433252284	15003	Economy	6300.00
0005434908159	15003	Economy	6300.00
0005434908216	15003	Economy	6300.00
0005434908616	25855	Business	18900.00
0005434908649	25855	Business	18900.00
0005434908618	25855	Business	18900.00
0005433251969	25855	Business	18900.00
0005434908667	25855	Business	18900.00
0005434908637	25855	Business	18900.00
0005434908630	25855	Business	18900.00
0005434908659	25855	Business	18900.00
0005433252037	25855	Business	18900.00
0005433251910	25855	Business	18900.00
0005434908654	25855	Business	18900.00
0005433251936	25855	Business	18900.00
0005434908656	25855	Economy	6300.00
0005433251974	25855	Economy	6300.00
0005433251862	25855	Economy	6300.00
0005434908643	25855	Economy	6300.00
0005434908647	25855	Economy	6300.00
0005433251930	25855	Economy	6300.00
0005434908660	25855	Economy	6300.00
0005433252059	25855	Economy	6300.00
0005434908620	25855	Economy	6300.00
0005434908666	25855	Economy	6300.00
0005433251970	25855	Economy	6900.00
0005434908631	25855	Economy	6900.00
0005433252036	25855	Economy	6900.00
0005434908623	25855	Economy	6900.00
0005434908661	25855	Economy	6300.00
0005434908653	25855	Economy	6300.00
0005434908664	25855	Economy	6300.00
0005434908671	25855	Economy	6300.00
0005434908669	25855	Economy	6300.00
0005434908646	25855	Economy	6300.00
0005433251861	25855	Economy	6300.00
0005434908638	25855	Economy	6300.00
0005434908662	25855	Economy	6300.00
0005434908640	25855	Economy	6300.00
0005434908628	25855	Economy	6300.00
0005434908665	25855	Economy	6300.00
0005434908627	25855	Economy	6300.00
0005434908632	25855	Economy	6300.00
0005433252038	25855	Economy	6300.00
0005434908651	25855	Economy	6300.00
0005433252041	25855	Economy	6300.00
0005434908635	25855	Economy	6300.00
0005434908613	25855	Economy	6300.00
0005434908639	25855	Economy	6300.00
0005433252131	25855	Economy	6300.00
0005434908624	25855	Economy	6300.00
0005433251960	25855	Economy	6300.00
0005434908650	25855	Economy	6300.00
0005434908644	25855	Economy	6300.00
0005433251909	25855	Economy	6300.00
0005434908614	25855	Economy	6300.00
0005433252042	25855	Economy	6300.00
0005434908670	25855	Economy	6300.00
0005434908636	25855	Economy	6300.00
0005434908652	25855	Economy	6300.00
0005434908645	25855	Economy	6300.00
0005434908634	25855	Economy	6300.00
0005433251953	25855	Economy	6300.00
0005434908648	25855	Economy	6300.00
0005434908621	25855	Economy	6300.00
0005433252085	25855	Economy	6300.00
0005434908622	25855	Economy	6300.00
0005434908672	25855	Economy	6300.00
0005434908629	25855	Economy	6300.00
0005433251937	25855	Economy	6300.00
0005434908625	25855	Economy	6300.00
0005434908658	25855	Economy	6300.00
0005434908642	25855	Economy	6300.00
0005433251880	25855	Economy	6300.00
0005434908673	25855	Economy	6300.00
0005433252001	25855	Economy	6300.00
0005433251931	25855	Economy	6300.00
0005434908657	25855	Economy	6300.00
0005433251958	25855	Economy	6300.00
0005434908668	25855	Economy	6300.00
0005434908633	25855	Economy	6300.00
0005434908663	25855	Economy	6300.00
0005434908615	25855	Economy	6300.00
0005434908617	25855	Economy	6300.00
0005434908619	25855	Economy	6300.00
0005434908641	25855	Economy	6300.00
0005433252125	25855	Economy	6300.00
0005433251860	25855	Economy	6300.00
0005433251943	25855	Economy	6300.00
0005433251911	25855	Economy	6300.00
0005434908626	25855	Economy	6300.00
0005433252077	25855	Economy	6300.00
0005434908655	25855	Economy	6300.00
0005433810612	14171	Business	52300.00
0005433009830	14171	Business	52300.00
0005433009846	14171	Business	52300.00
0005433009824	14171	Business	52300.00
0005433009822	14171	Business	52300.00
0005433810593	14171	Business	52300.00
0005433009842	14171	Economy	17400.00
0005433810598	14171	Economy	17400.00
0005433009847	14171	Economy	17400.00
0005433009844	14171	Economy	17400.00
0005433009838	14171	Economy	19200.00
0005433009832	14171	Economy	19200.00
0005433009821	14171	Economy	19200.00
0005433009823	14171	Economy	17400.00
0005433009827	14171	Economy	17400.00
0005433810613	14171	Economy	17400.00
0005433810610	14171	Economy	17400.00
0005433009840	14171	Economy	17400.00
0005433009837	14171	Economy	17400.00
0005433009825	14171	Economy	17400.00
0005433810594	14171	Economy	17400.00
0005433009835	14171	Economy	17400.00
0005433009818	14171	Economy	17400.00
0005433009831	14171	Economy	17400.00
0005433009839	14171	Economy	17400.00
0005433009843	14171	Economy	17400.00
0005433009836	14171	Economy	17400.00
0005433009820	14171	Economy	17400.00
0005433810599	14171	Economy	17400.00
0005433009829	14171	Economy	17400.00
0005433009817	14171	Economy	17400.00
0005433009841	14171	Economy	17400.00
0005433009819	14171	Economy	17400.00
0005433009833	14171	Economy	17400.00
0005433009834	14171	Economy	17400.00
0005433009845	14171	Economy	17400.00
0005433810611	14171	Economy	17400.00
0005433009826	14171	Economy	17400.00
0005433810608	14171	Economy	17400.00
0005433009828	14171	Economy	17400.00
0005433009524	22867	Business	52300.00
0005433009356	22867	Business	52300.00
0005433009424	22867	Business	52300.00
0005433009378	22867	Economy	17400.00
0005433009512	22867	Economy	17400.00
0005433810701	22867	Economy	17400.00
0005433009405	22867	Economy	17400.00
0005433810702	22867	Economy	17400.00
0005433009481	22867	Economy	17400.00
0005433009427	22867	Economy	19200.00
0005433009334	22867	Economy	19200.00
0005433009500	22867	Economy	19200.00
0005433009383	22867	Economy	17400.00
0005433009267	22867	Economy	17400.00
0005433009269	22867	Economy	17400.00
0005433810704	22867	Economy	17400.00
0005433009436	22867	Economy	17400.00
0005433009265	22867	Economy	17400.00
0005433009370	22867	Economy	17400.00
0005433009262	22867	Economy	17400.00
0005433009361	22867	Economy	17400.00
0005433009362	22867	Economy	17400.00
0005433009468	22867	Economy	17400.00
0005433009369	22867	Economy	17400.00
0005433009426	22867	Economy	17400.00
0005433810703	22867	Economy	17400.00
0005433009289	22867	Economy	17400.00
0005433009557	22867	Economy	17400.00
0005433009568	22867	Economy	17400.00
0005433009268	22867	Economy	17400.00
0005433009387	22867	Economy	17400.00
0005433009332	22867	Economy	17400.00
0005433009554	22867	Economy	17400.00
0005433009333	22867	Economy	17400.00
0005433009412	22867	Economy	17400.00
0005433009357	22867	Economy	17400.00
0005433009312	22867	Economy	17400.00
0005433009272	22867	Economy	17400.00
0005433009211	22867	Economy	17400.00
0005433009273	22867	Economy	17400.00
0005433009437	22867	Economy	17400.00
0005433009277	22867	Economy	17400.00
0005433009336	22867	Economy	17400.00
0005433009553	22867	Economy	17400.00
0005433009382	22867	Economy	17400.00
0005433009499	22867	Economy	17400.00
0005433009498	22867	Economy	17400.00
0005433009453	22867	Economy	17400.00
0005433009402	22867	Economy	17400.00
0005433009479	22867	Economy	17400.00
0005433009401	22867	Economy	17400.00
0005433009290	22867	Economy	17400.00
0005435719063	15522	Business	85200.00
0005435719078	15522	Business	85200.00
0005435719083	15522	Business	85200.00
0005435719095	15522	Business	85200.00
0005435719080	15522	Business	85200.00
0005435719087	15522	Business	85200.00
0005435719075	15522	Economy	28400.00
0005435719059	15522	Economy	28400.00
0005435719088	15522	Economy	28400.00
0005435719071	15522	Economy	28400.00
0005435719057	15522	Economy	28400.00
0005435719053	15522	Economy	28400.00
0005435719056	15522	Economy	31200.00
0005435719051	15522	Economy	31200.00
0005435719067	15522	Economy	31200.00
0005435719086	15522	Economy	31200.00
0005435719058	15522	Economy	28400.00
0005435719043	15522	Economy	28400.00
0005435719090	15522	Economy	28400.00
0005435719093	15522	Economy	28400.00
0005435719072	15522	Economy	28400.00
0005435719052	15522	Economy	28400.00
0005435719044	15522	Economy	28400.00
0005435719055	15522	Economy	28400.00
0005435719060	15522	Economy	28400.00
0005435719084	15522	Economy	28400.00
0005435719077	15522	Economy	28400.00
0005435719064	15522	Economy	28400.00
0005435719076	15522	Economy	28400.00
0005435719097	15522	Economy	28400.00
0005435719066	15522	Economy	28400.00
0005435719082	15522	Economy	28400.00
0005435719061	15522	Economy	28400.00
0005435719073	15522	Economy	28400.00
0005435719085	15522	Economy	28400.00
0005435719096	15522	Economy	28400.00
0005435719062	15522	Economy	28400.00
0005435719074	15522	Economy	28400.00
0005435719069	15522	Economy	28400.00
0005435719068	15522	Economy	28400.00
0005435719070	15522	Economy	28400.00
0005435719042	15522	Economy	28400.00
0005435719092	15522	Economy	28400.00
0005435719091	15522	Economy	28400.00
0005435719054	15522	Economy	28400.00
0005435719048	15522	Economy	28400.00
0005435719050	15522	Economy	28400.00
0005435719081	15522	Economy	28400.00
0005435719047	15522	Economy	28400.00
0005435719046	15522	Economy	28400.00
0005435719045	15522	Economy	28400.00
0005435719094	15522	Economy	28400.00
0005435719049	15522	Economy	28400.00
0005435719079	15522	Economy	28400.00
0005435719065	15522	Economy	28400.00
0005435719089	15522	Economy	28400.00
0005434926323	14967	Business	22900.00
0005434926362	14967	Business	22900.00
0005434926319	14967	Business	22900.00
0005434926349	14967	Business	22900.00
0005434926337	14967	Business	22900.00
0005434926306	14967	Business	22900.00
0005434926137	14967	Economy	7600.00
0005434926345	14967	Economy	7600.00
0005434926199	14967	Economy	7600.00
0005434926344	14967	Economy	7600.00
0005434926200	14967	Economy	8400.00
0005434926357	14967	Economy	8400.00
0005434926303	14967	Economy	7600.00
0005434926330	14967	Economy	7600.00
0005434926290	14967	Economy	7600.00
0005434926325	14967	Economy	7600.00
0005434926287	14967	Economy	7600.00
0005434926336	14967	Economy	7600.00
0005434926324	14967	Economy	7600.00
0005434926332	14967	Economy	7600.00
0005434926219	14967	Economy	7600.00
0005434926333	14967	Economy	7600.00
0005434926296	14967	Economy	7600.00
0005434926342	14967	Economy	7600.00
0005434926304	14967	Economy	7600.00
0005434926351	14967	Economy	7600.00
0005434926318	14967	Economy	7600.00
0005434926289	14967	Economy	7600.00
0005434926363	14967	Economy	7600.00
0005434926339	14967	Economy	7600.00
0005434926358	14967	Economy	7600.00
0005434926628	20541	Business	22900.00
0005434926654	20541	Business	22900.00
0005434926629	20541	Business	22900.00
0005434926642	20541	Business	22900.00
0005434926653	20541	Business	22900.00
0005434926652	20541	Business	22900.00
0005434926639	20541	Business	22900.00
0005434926647	20541	Economy	7600.00
0005434926635	20541	Economy	7600.00
0005434926650	20541	Economy	7600.00
0005434926649	20541	Economy	8400.00
0005434926644	20541	Economy	8400.00
0005434926648	20541	Economy	7600.00
0005434926657	20541	Economy	7600.00
0005434926627	20541	Economy	7600.00
0005434926632	20541	Economy	7600.00
0005434926636	20541	Economy	7600.00
0005434926634	20541	Economy	7600.00
0005434926640	20541	Economy	7600.00
0005434926630	20541	Economy	7600.00
0005434926645	20541	Economy	7600.00
0005434926658	20541	Economy	7600.00
0005434926626	20541	Economy	7600.00
0005434926637	20541	Economy	7600.00
0005434926641	20541	Economy	7600.00
0005434926646	20541	Economy	7600.00
0005434926643	20541	Economy	7600.00
0005434926631	20541	Economy	7600.00
0005434926655	20541	Economy	7600.00
0005434926633	20541	Economy	7600.00
0005434926651	20541	Economy	7600.00
0005434926656	20541	Economy	7600.00
0005434926638	20541	Economy	7600.00
0005435488409	15831	Economy	8900.00
0005435999505	15831	Economy	8900.00
0005435488415	15831	Economy	8900.00
0005435488419	15831	Economy	8900.00
0005435488422	15831	Economy	8100.00
0005435999575	15831	Economy	8100.00
0005435488412	15831	Economy	8100.00
0005435999554	15831	Economy	8100.00
0005435999530	15831	Economy	8100.00
0005435999582	15831	Economy	8100.00
0005435999480	15831	Economy	8100.00
0005435999579	15831	Economy	8100.00
0005435488407	15831	Economy	8100.00
0005435488406	15831	Economy	8100.00
0005435999561	15831	Economy	8100.00
0005435488410	15831	Economy	8100.00
0005435488423	15831	Economy	8100.00
0005435488417	15831	Economy	8100.00
0005435999577	15831	Economy	8100.00
0005435999552	15831	Economy	8100.00
0005435488421	15831	Economy	8100.00
0005435488418	15831	Economy	8100.00
0005435488408	15831	Economy	8100.00
0005435488413	15831	Economy	8100.00
0005435488404	15831	Economy	8100.00
0005435999566	15831	Economy	8100.00
0005435488405	15831	Economy	8100.00
0005435488414	15831	Economy	8100.00
0005435488411	15831	Economy	8100.00
0005435999574	15831	Economy	8100.00
0005435999581	15831	Economy	8100.00
0005435488416	15831	Economy	8100.00
0005435999458	15831	Economy	8100.00
0005435999536	15831	Economy	8100.00
0005435999521	15831	Economy	8100.00
0005435999481	15831	Economy	8100.00
0005435999578	15831	Economy	8100.00
0005435999535	15831	Economy	8100.00
0005435999457	15831	Economy	8100.00
0005435999580	15831	Economy	8100.00
0005435999539	15831	Economy	8100.00
0005435488420	15831	Economy	8100.00
0005435488292	19684	Economy	8900.00
0005435999739	19684	Economy	8900.00
0005435488160	19684	Economy	8900.00
0005435999740	19684	Economy	8900.00
0005435999725	19684	Economy	8100.00
0005435488133	19684	Economy	8100.00
0005435488045	19684	Economy	8100.00
0005435488225	19684	Economy	8100.00
0005435999721	19684	Economy	8100.00
0005435488152	19684	Economy	8100.00
0005435999731	19684	Economy	8100.00
0005435999723	19684	Economy	8100.00
0005435488244	19684	Economy	8100.00
0005435999722	19684	Economy	8100.00
0005435999730	19684	Economy	8100.00
0005435488188	19684	Economy	8100.00
0005435999728	19684	Economy	8100.00
0005435488162	19684	Economy	8100.00
0005435999733	19684	Economy	8100.00
0005435999738	19684	Economy	8100.00
0005435488135	19684	Economy	8100.00
0005435488332	19684	Economy	8100.00
0005435999724	19684	Economy	8100.00
0005435488226	19684	Economy	8100.00
0005435999726	19684	Economy	8100.00
0005435488161	19684	Economy	8100.00
0005435999741	19684	Economy	8100.00
0005435488167	19684	Economy	8100.00
0005435488142	19684	Economy	8100.00
0005435999735	19684	Economy	8100.00
0005435488197	19684	Economy	8100.00
0005435488134	19684	Economy	8100.00
0005435999719	19684	Economy	8100.00
0005435999732	19684	Economy	8100.00
0005435999737	19684	Economy	8100.00
0005435488163	19684	Economy	8100.00
0005435999736	19684	Economy	8100.00
0005435999734	19684	Economy	8100.00
0005435999729	19684	Economy	8100.00
0005435488166	19684	Economy	8100.00
0005435999720	19684	Economy	8100.00
0005435488189	19684	Economy	8100.00
0005435488280	19684	Economy	8100.00
0005435999717	19684	Economy	8100.00
0005435999718	19684	Economy	8100.00
0005435488132	19684	Economy	8100.00
0005435488143	19684	Economy	8100.00
0005435488281	19684	Economy	8100.00
0005435999727	19684	Economy	8100.00
0005435488165	19684	Economy	8100.00
0005435840210	6014	Business	199300.00
0005432659764	6014	Business	199300.00
0005435840214	6014	Business	199300.00
0005435473093	6014	Business	199300.00
0005435840199	6014	Business	199300.00
0005432660876	6014	Business	199300.00
0005432537098	6014	Business	199300.00
0005435473135	6014	Business	199300.00
0005435840212	6014	Economy	66400.00
0005435473101	6014	Economy	66400.00
0005435840207	6014	Economy	66400.00
0005435840200	6014	Economy	66400.00
0005435840194	6014	Economy	73100.00
0005435473119	6014	Economy	73100.00
0005432660875	6014	Economy	66400.00
0005435840206	6014	Economy	66400.00
0005435840198	6014	Economy	66400.00
0005435840201	6014	Economy	66400.00
0005432660874	6014	Economy	66400.00
0005432658648	6014	Economy	66400.00
0005432142336	6014	Economy	66400.00
0005432142337	6014	Economy	66400.00
0005435840211	6014	Economy	66400.00
0005435840208	6014	Economy	66400.00
0005432142334	6014	Economy	66400.00
0005435840196	6014	Economy	66400.00
0005435840204	6014	Economy	66400.00
0005435473128	6014	Economy	66400.00
0005435840203	6014	Economy	66400.00
0005435840205	6014	Economy	66400.00
0005435840213	6014	Economy	66400.00
0005435840193	6014	Economy	66400.00
0005435473086	6014	Economy	66400.00
0005435473145	6014	Economy	66400.00
0005435473184	6014	Economy	66400.00
0005432658649	6014	Economy	66400.00
0005435840197	6014	Economy	66400.00
0005435840195	6014	Economy	66400.00
0005435473029	6014	Economy	66400.00
0005435473146	6014	Economy	66400.00
0005432142335	6014	Economy	66400.00
0005435840209	6014	Economy	66400.00
0005435473143	6014	Economy	66400.00
0005435840192	6014	Economy	66400.00
0005435840202	6014	Economy	66400.00
0005435473235	18070	Business	199300.00
0005435839924	18070	Business	199300.00
0005435473246	18070	Business	199300.00
0005435839874	18070	Business	199300.00
0005435617242	18070	Business	199300.00
0005435473245	18070	Business	199300.00
0005435840053	18070	Business	199300.00
0005435473242	18070	Economy	66400.00
0005432667483	18070	Economy	66400.00
0005432667493	18070	Economy	66400.00
0005435617243	18070	Economy	66400.00
0005435839968	18070	Economy	66400.00
0005435839910	18070	Economy	73100.00
0005435839909	18070	Economy	73100.00
0005432664158	18070	Economy	66400.00
0005432667487	18070	Economy	66400.00
0005435840054	18070	Economy	66400.00
0005435473247	18070	Economy	66400.00
0005435839923	18070	Economy	66400.00
0005432667492	18070	Economy	66400.00
0005435473236	18070	Economy	66400.00
0005432660843	18070	Economy	66400.00
0005435840017	18070	Economy	66400.00
0005432537117	18070	Economy	66400.00
0005435473239	18070	Economy	66400.00
0005435839961	18070	Economy	66400.00
0005435473241	18070	Economy	66400.00
0005432537116	18070	Economy	66400.00
0005435839977	18070	Economy	66400.00
0005435839925	18070	Economy	66400.00
0005435839908	18070	Economy	66400.00
0005435840059	18070	Economy	66400.00
0005435840055	18070	Economy	66400.00
0005435473244	18070	Economy	66400.00
0005435839936	18070	Economy	66400.00
0005432667478	18070	Economy	66400.00
0005435839982	18070	Economy	66400.00
0005435839935	18070	Economy	66400.00
0005432664159	18070	Economy	66400.00
0005435839974	18070	Economy	66400.00
0005435839967	18070	Economy	66400.00
0005432667494	18070	Economy	66400.00
0005432664170	18070	Economy	66400.00
0005435473243	18070	Economy	66400.00
0005432660842	18070	Economy	66400.00
0005435473237	18070	Economy	66400.00
0005435473234	18070	Economy	66400.00
0005435473248	18070	Economy	66400.00
0005435839879	18070	Economy	66400.00
0005435839911	18070	Economy	66400.00
0005435840050	18070	Economy	66400.00
0005435473240	18070	Economy	66400.00
0005435473238	18070	Economy	66400.00
0005435839897	18070	Economy	66400.00
0005432664169	18070	Economy	66400.00
0005435839820	18070	Economy	66400.00
0005435839973	18070	Economy	66400.00
0005435839937	18070	Economy	66400.00
0005435839875	18070	Economy	66400.00
0005435104201	23023	Business	15700.00
0005435104182	23023	Business	15700.00
0005435104180	23023	Business	15700.00
0005433285992	23023	Business	15700.00
0005435104207	23023	Business	15700.00
0005435104193	23023	Business	15700.00
0005435104196	23023	Business	15700.00
0005433285891	23023	Business	15700.00
0005435104204	23023	Economy	5200.00
0005433285732	23023	Economy	5200.00
0005435104177	23023	Economy	5200.00
0005433285926	23023	Economy	5200.00
0005433285733	23023	Economy	5200.00
0005433285726	23023	Economy	5200.00
0005435104176	23023	Economy	5200.00
0005433285727	23023	Economy	5200.00
0005435104199	23023	Economy	5200.00
0005435104190	23023	Economy	5200.00
0005435104187	23023	Economy	5200.00
0005435104191	23023	Economy	5200.00
0005435104178	23023	Economy	5200.00
0005433285753	23023	Economy	5200.00
0005435104210	23023	Economy	5200.00
0005433285870	23023	Economy	5200.00
0005433285941	23023	Economy	5200.00
0005435104192	23023	Economy	5200.00
0005435104186	23023	Economy	5200.00
0005433285734	23023	Economy	5200.00
0005433285874	23023	Economy	5200.00
0005433285841	23023	Economy	5200.00
0005433285829	23023	Economy	5700.00
0005433285964	23023	Economy	5700.00
0005435104179	23023	Economy	5700.00
0005435104198	23023	Economy	5700.00
0005433285963	23023	Economy	5200.00
0005433285843	23023	Economy	5200.00
0005435104181	23023	Economy	5200.00
0005435104206	23023	Economy	5200.00
0005433285983	23023	Economy	5200.00
0005435104189	23023	Economy	5200.00
0005435104203	23023	Economy	5200.00
0005435104202	23023	Economy	5200.00
0005433285880	23023	Economy	5200.00
0005433285828	23023	Economy	5200.00
0005435104184	23023	Economy	5200.00
0005433285881	23023	Economy	5200.00
0005435104200	23023	Economy	5200.00
0005435104208	23023	Economy	5200.00
0005435104197	23023	Economy	5200.00
0005433285871	23023	Economy	5200.00
0005433285965	23023	Economy	5200.00
0005433285872	23023	Economy	5200.00
0005433285835	23023	Economy	5200.00
0005435104205	23023	Economy	5200.00
0005435104185	23023	Economy	5200.00
0005433285886	23023	Economy	5200.00
0005435104188	23023	Economy	5200.00
0005433286000	23023	Economy	5200.00
0005433285960	23023	Economy	5200.00
0005433285943	23023	Economy	5200.00
0005435104183	23023	Economy	5200.00
0005435104195	23023	Economy	5200.00
0005435104211	23023	Economy	5200.00
0005433285954	23023	Economy	5200.00
0005435104209	23023	Economy	5200.00
0005435104194	23023	Economy	5200.00
0005433285834	23023	Economy	5200.00
0005433285887	23023	Economy	5200.00
0005433286134	32051	Economy	5200.00
0005433286140	32051	Economy	5200.00
0005433286127	32051	Economy	5200.00
0005435104059	32051	Economy	5200.00
0005435104063	32051	Economy	5200.00
0005435104028	32051	Economy	5200.00
0005433286136	32051	Economy	5200.00
0005435104049	32051	Economy	5200.00
0005433286133	32051	Economy	5200.00
0005435104029	32051	Economy	5200.00
0005433286132	32051	Economy	5200.00
0005435104018	32051	Economy	5200.00
0005435104032	32051	Economy	5200.00
0005433286117	32051	Economy	5200.00
0005433286116	32051	Economy	5200.00
0005435104065	32051	Economy	5200.00
0005433286137	32051	Economy	5200.00
0005435104038	32051	Economy	5700.00
0005433286143	32051	Economy	5700.00
0005433286135	32051	Economy	5700.00
0005433286131	32051	Economy	5200.00
0005435104039	32051	Economy	5200.00
0005433286142	32051	Economy	5200.00
0005435104058	32051	Economy	5200.00
0005435104062	32051	Economy	5200.00
0005433286129	32051	Economy	5200.00
0005435104060	32051	Economy	5200.00
0005433286138	32051	Economy	5200.00
0005433286124	32051	Economy	5200.00
0005433286126	32051	Economy	5200.00
0005435104064	32051	Economy	5200.00
0005433286125	32051	Economy	5200.00
0005433286120	32051	Economy	5200.00
0005433286122	32051	Economy	5200.00
0005433286139	32051	Economy	5200.00
0005433286130	32051	Economy	5200.00
0005433286118	32051	Economy	5200.00
0005433286128	32051	Economy	5200.00
0005433286123	32051	Economy	5200.00
0005433286121	32051	Economy	5200.00
0005433286119	32051	Economy	5200.00
0005435104050	32051	Economy	5200.00
0005433286141	32051	Economy	5200.00
0005432802620	1473	Business	150400.00
0005432802604	1473	Business	150400.00
0005432802626	1473	Business	150400.00
0005433112390	1473	Business	150400.00
0005433112407	1473	Business	150400.00
0005432802595	1473	Business	150400.00
0005432892791	1473	Business	150400.00
0005432892790	1473	Business	150400.00
0005433112406	1473	Business	150400.00
0005433112391	1473	Business	150400.00
0005432802609	1473	Economy	50100.00
0005432892793	1473	Economy	50100.00
0005432892805	1473	Economy	50100.00
0005433112388	1473	Economy	50100.00
0005432802615	1473	Economy	50100.00
0005432802598	1473	Economy	50100.00
0005432892789	1473	Economy	50100.00
0005432802599	1473	Economy	50100.00
0005432892792	1473	Economy	50100.00
0005432892807	1473	Economy	50100.00
0005432802607	1473	Economy	55200.00
0005432802602	1473	Economy	55200.00
0005432892803	1473	Economy	50100.00
0005432802616	1473	Economy	50100.00
0005432892787	1473	Economy	50100.00
0005432802600	1473	Economy	50100.00
0005432802614	1473	Economy	50100.00
0005433113618	1473	Economy	50100.00
0005432802621	1473	Economy	50100.00
0005432802597	1473	Economy	50100.00
0005433112389	1473	Economy	50100.00
0005432802608	1473	Economy	50100.00
0005433112385	1473	Economy	50100.00
0005432892786	1473	Economy	50100.00
0005432892798	1473	Economy	50100.00
0005432892776	1473	Economy	50100.00
0005432802619	1473	Economy	50100.00
0005432892794	1473	Economy	50100.00
0005432802603	1473	Economy	50100.00
0005432802624	1473	Economy	50100.00
0005432802622	1473	Economy	50100.00
0005432802613	1473	Economy	50100.00
0005432802596	1473	Economy	50100.00
0005432802618	1473	Economy	50100.00
0005432892804	1473	Economy	50100.00
0005432802611	1473	Economy	50100.00
0005432892788	1473	Economy	50100.00
0005432892806	1473	Economy	50100.00
0005432802617	1473	Economy	50100.00
0005432802605	1473	Economy	50100.00
0005432892777	1473	Economy	50100.00
0005432892781	1473	Economy	50100.00
0005432802623	1473	Economy	50100.00
0005433112386	1473	Economy	50100.00
0005433112384	1473	Economy	50100.00
0005433112399	1473	Economy	50100.00
0005432802610	1473	Economy	50100.00
0005433112392	1473	Economy	50100.00
0005432802625	1473	Economy	50100.00
0005432802606	1473	Economy	50100.00
0005432892802	1473	Economy	50100.00
0005432802612	1473	Economy	50100.00
0005432802601	1473	Economy	50100.00
0005435852647	23871	Economy	13500.00
0005433475789	23871	Economy	13500.00
0005435852645	23871	Economy	12300.00
0005433475783	23871	Economy	12300.00
0005435852643	23871	Economy	12300.00
0005435852644	23871	Economy	12300.00
0005433475786	23871	Economy	12300.00
0005433475777	23871	Economy	12300.00
0005433475773	23871	Economy	12300.00
0005435852649	23871	Economy	12300.00
0005435852646	23871	Economy	12300.00
0005433475788	23871	Economy	12300.00
0005435852650	23871	Economy	12300.00
0005433475785	23871	Economy	12300.00
0005433475774	23871	Economy	12300.00
0005433475796	23871	Economy	12300.00
0005435852648	23871	Economy	12300.00
0005432530022	30607	Business	42100.00
0005432530698	30607	Business	42100.00
0005432428984	30607	Business	42100.00
0005434068759	30607	Business	42100.00
0005432428995	30607	Business	42100.00
0005432531029	30607	Business	42100.00
0005434068513	30607	Business	42100.00
0005432530049	30607	Business	42100.00
0005432159985	30607	Business	42100.00
0005434069135	30607	Business	42100.00
0005434068469	30607	Business	42100.00
0005432529865	30607	Business	42100.00
0005432530479	30607	Business	42100.00
0005432211710	30607	Business	42100.00
0005432530040	30607	Business	42100.00
0005432535944	30607	Business	42100.00
0005435215360	30607	Business	42100.00
0005435215371	30607	Business	42100.00
0005435215367	30607	Business	42100.00
0005434068632	30607	Business	42100.00
0005432530380	30607	Business	42100.00
0005435283486	30607	Business	42100.00
0005434068581	30607	Business	42100.00
0005435725735	30607	Comfort	23900.00
0005432530432	30607	Business	42100.00
0005434068922	30607	Comfort	23900.00
0005432530887	30607	Comfort	23900.00
0005435215394	30607	Comfort	23900.00
0005435215379	30607	Comfort	23900.00
0005432533348	30607	Comfort	23900.00
0005432530822	30607	Comfort	23900.00
0005432530205	30607	Comfort	23900.00
0005432211706	30607	Comfort	23900.00
0005432211709	30607	Comfort	23900.00
0005432529758	30607	Comfort	23900.00
0005435215388	30607	Comfort	23900.00
0005432537101	30607	Comfort	23900.00
0005432530642	30607	Comfort	23900.00
0005432529000	30607	Comfort	23900.00
0005434068798	30607	Comfort	23900.00
0005434069111	30607	Comfort	23900.00
0005435215376	30607	Comfort	23900.00
0005432530648	30607	Comfort	23900.00
0005432428999	30607	Comfort	23900.00
0005432530751	30607	Comfort	23900.00
0005432530179	30607	Comfort	23900.00
0005435215370	30607	Comfort	23900.00
0005432530190	30607	Comfort	23900.00
0005432428998	30607	Comfort	23900.00
0005432530359	30607	Comfort	23900.00
0005432530835	30607	Comfort	23900.00
0005434068788	30607	Comfort	23900.00
0005434068657	30607	Comfort	23900.00
0005432530202	30607	Comfort	23900.00
0005432535919	30607	Comfort	23900.00
0005434068977	30607	Comfort	23900.00
0005434069043	30607	Economy	14000.00
0005434068625	30607	Economy	14000.00
0005434068921	30607	Economy	14000.00
0005434068752	30607	Economy	14000.00
0005432531122	30607	Economy	14000.00
0005432530591	30607	Economy	14000.00
0005432530309	30607	Economy	14000.00
0005432530156	30607	Economy	14000.00
0005435725731	30607	Economy	14000.00
0005434068797	30607	Economy	14000.00
0005432530907	30607	Economy	14000.00
0005435215400	30607	Economy	14000.00
0005435215363	30607	Economy	14000.00
0005432529774	30607	Economy	14000.00
0005434068580	30607	Economy	14000.00
0005434068841	30607	Economy	14000.00
0005435215398	30607	Economy	14000.00
0005434069042	30607	Economy	14000.00
0005432530299	30607	Economy	14000.00
0005432530599	30607	Economy	14000.00
0005435215365	30607	Economy	14000.00
0005435631049	30607	Economy	14000.00
0005434069082	30607	Economy	14000.00
0005432530615	30607	Economy	14000.00
0005432530695	30607	Economy	14000.00
0005432530422	30607	Economy	14000.00
0005434068751	30607	Economy	14000.00
0005434069216	30607	Economy	14000.00
0005432533347	30607	Economy	14000.00
0005434068856	30607	Economy	14000.00
0005432530240	30607	Economy	14000.00
0005435215391	30607	Economy	14000.00
0005435631048	30607	Economy	14000.00
0005434068619	30607	Economy	14000.00
0005434068803	30607	Economy	14000.00
0005432530099	30607	Economy	14000.00
0005432530041	30607	Economy	14000.00
0005432528999	30607	Economy	14000.00
0005432428988	30607	Economy	14000.00
0005432530218	30607	Economy	14000.00
0005435215381	30607	Economy	14000.00
0005432211705	30607	Economy	14000.00
0005435215378	30607	Economy	14000.00
0005432537102	30607	Economy	14000.00
0005432535918	30607	Economy	14000.00
0005434068892	30607	Economy	14000.00
0005432530245	30607	Economy	14000.00
0005434069083	30607	Economy	14000.00
0005432530239	30607	Economy	14000.00
0005432535924	30607	Economy	14000.00
0005434068840	30607	Economy	15400.00
0005434068947	30607	Economy	14000.00
0005435215402	30607	Economy	15400.00
0005432530507	30607	Economy	15400.00
0005432535945	30607	Economy	14000.00
0005432530116	30607	Economy	14000.00
0005435215369	30607	Economy	14000.00
0005432530336	30607	Economy	14000.00
0005434068935	30607	Economy	15400.00
0005432530676	30607	Economy	15400.00
0005432529961	30607	Economy	15400.00
0005435215361	30607	Economy	14000.00
0005434068735	30607	Economy	14000.00
0005432159986	30607	Economy	14000.00
0005432530791	30607	Economy	14000.00
0005433656765	30607	Economy	14000.00
0005434068985	30607	Economy	14000.00
0005432530505	30607	Economy	14000.00
0005432530304	30607	Economy	14000.00
0005432530578	30607	Economy	14000.00
0005432530209	30607	Economy	14000.00
0005432530246	30607	Economy	14000.00
0005435215397	30607	Economy	14000.00
0005432530098	30607	Economy	14000.00
0005432530972	30607	Economy	14000.00
0005434069049	30607	Economy	14000.00
0005432530792	30607	Economy	14000.00
0005432530322	30607	Economy	14000.00
0005435215385	30607	Economy	14000.00
0005432535927	30607	Economy	14000.00
0005434069156	30607	Economy	14000.00
0005434068857	30607	Economy	14000.00
0005434068608	30607	Economy	14000.00
0005432530023	30607	Economy	14000.00
0005432535923	30607	Economy	14000.00
0005434068799	30607	Economy	14000.00
0005432530771	30607	Economy	14000.00
0005432530675	30607	Economy	14000.00
0005435215403	30607	Economy	14000.00
0005434068975	30607	Economy	14000.00
0005434069157	30607	Economy	14000.00
0005435215368	30607	Economy	14000.00
0005432530581	30607	Economy	14000.00
0005435215382	30607	Economy	14000.00
0005435215375	30607	Economy	14000.00
0005434068976	30607	Economy	14000.00
0005432530431	30607	Economy	14000.00
0005432530663	30607	Economy	14000.00
0005435215395	30607	Economy	14000.00
0005434069022	30607	Economy	14000.00
0005432530409	30607	Economy	14000.00
0005432529969	30607	Economy	14000.00
0005435725733	30607	Economy	14000.00
0005434068754	30607	Economy	14000.00
0005432530412	30607	Economy	14000.00
0005432530687	30607	Economy	14000.00
0005435215396	30607	Economy	14000.00
0005432530888	30607	Economy	14000.00
0005432530643	30607	Economy	14000.00
0005432530729	30607	Economy	14000.00
0005432529889	30607	Economy	14000.00
0005434069184	30607	Economy	14000.00
0005432530056	30607	Economy	14000.00
0005432429014	30607	Economy	14000.00
0005432530688	30607	Economy	14000.00
0005432211703	30607	Economy	14000.00
0005435215392	30607	Economy	14000.00
0005434068766	30607	Economy	14000.00
0005432530561	30607	Economy	14000.00
0005432530697	30607	Economy	14000.00
0005434068730	30607	Economy	14000.00
0005434068873	30607	Economy	14000.00
0005434068753	30607	Economy	14000.00
0005434068729	30607	Economy	14000.00
0005434068597	30607	Economy	14000.00
0005432530794	30607	Economy	14000.00
0005432530385	30607	Economy	14000.00
0005432530501	30607	Economy	14000.00
0005432530985	30607	Economy	14000.00
0005434069176	30607	Economy	14000.00
0005434069040	30607	Economy	14000.00
0005434069217	30607	Economy	14000.00
0005435215364	30607	Economy	14000.00
0005435215399	30607	Economy	14000.00
0005432529866	30607	Economy	14000.00
0005435283487	30607	Economy	14000.00
0005435215380	30607	Economy	14000.00
0005432530823	30607	Economy	14000.00
0005432530908	30607	Economy	14000.00
0005432530598	30607	Economy	14000.00
0005432531373	30607	Economy	15400.00
0005434068920	30607	Economy	15400.00
0005432530824	30607	Economy	15400.00
0005432529569	30607	Economy	15400.00
0005434069023	30607	Economy	15400.00
0005432530696	30607	Economy	14000.00
0005435725734	30607	Economy	14000.00
0005434068656	30607	Economy	14000.00
0005432211707	30607	Economy	14000.00
0005432530825	30607	Economy	14000.00
0005432530408	30607	Economy	14000.00
0005432531047	30607	Economy	14000.00
0005435215384	30607	Economy	14000.00
0005432530500	30607	Economy	14000.00
0005432429016	30607	Economy	14000.00
0005434068919	30607	Economy	14000.00
0005435215401	30607	Economy	14000.00
0005432211708	30607	Economy	14000.00
0005432530310	30607	Economy	14000.00
0005432535922	30607	Economy	14000.00
0005435215393	30607	Economy	14000.00
0005432530508	30607	Economy	14000.00
0005432535928	30607	Economy	14000.00
0005434068946	30607	Economy	14000.00
0005432530230	30607	Economy	14000.00
0005432530478	30607	Economy	14000.00
0005432428997	30607	Economy	14000.00
0005432531121	30607	Economy	14000.00
0005432159984	30607	Economy	14000.00
0005435215389	30607	Economy	14000.00
0005435283489	30607	Economy	14000.00
0005432530485	30607	Economy	14000.00
0005432530257	30607	Economy	14000.00
0005432529854	30607	Economy	14000.00
0005432537087	30607	Economy	14000.00
0005435215373	30607	Economy	14000.00
0005432428996	30607	Economy	14000.00
0005434068850	30607	Economy	14000.00
0005432530704	30607	Economy	14000.00
0005434068891	30607	Economy	14000.00
0005434068834	30607	Economy	14000.00
0005432211704	30607	Economy	14000.00
0005435215387	30607	Economy	14000.00
0005432530513	30607	Economy	14000.00
0005432529867	30607	Economy	14000.00
0005434068737	30607	Economy	14000.00
0005435215366	30607	Economy	14000.00
0005432530999	30607	Economy	14000.00
0005432529660	30607	Economy	14000.00
0005432530132	30607	Economy	14000.00
0005434068755	30607	Economy	14000.00
0005435215390	30607	Economy	14000.00
0005432535921	30607	Economy	14000.00
0005432537088	30607	Economy	14000.00
0005432530114	30607	Economy	14000.00
0005435283488	30607	Economy	14000.00
0005434068750	30607	Economy	14000.00
0005435725736	30607	Economy	14000.00
0005432530087	30607	Economy	14000.00
0005432530789	30607	Economy	14000.00
0005432530379	30607	Economy	14000.00
0005435725732	30607	Economy	14000.00
0005435215377	30607	Economy	14000.00
0005434069134	30607	Economy	14000.00
0005434068875	30607	Economy	14000.00
0005434068944	30607	Economy	14000.00
0005432159983	30607	Economy	14000.00
0005432530201	30607	Economy	14000.00
0005432535917	30607	Economy	14000.00
0005434068791	30607	Economy	14000.00
0005434069048	30607	Economy	14000.00
0005432537094	30607	Economy	14000.00
0005435215383	30607	Economy	14000.00
0005435215372	30607	Economy	14000.00
0005432529966	30607	Economy	14000.00
0005434068789	30607	Economy	14000.00
0005432530311	30607	Economy	14000.00
0005432530146	30607	Economy	14000.00
0005432530795	30607	Economy	14000.00
0005432530882	30607	Economy	14000.00
0005434068758	30607	Economy	14000.00
0005433656764	30607	Economy	14000.00
0005432530793	30607	Economy	14000.00
0005432529970	30607	Economy	14000.00
0005435215374	30607	Economy	14000.00
0005432529757	30607	Economy	14000.00
0005432530115	30607	Economy	14000.00
0005435215386	30607	Economy	14000.00
0005432530133	30607	Economy	14000.00
0005432530217	30607	Economy	14000.00
0005432530906	30607	Economy	14000.00
0005432530506	30607	Economy	14000.00
0005432537093	30607	Economy	14000.00
0005432530674	30607	Economy	14000.00
0005435215362	30607	Economy	14000.00
0005432429015	30607	Economy	14000.00
0005435653657	24874	Business	9800.00
0005435653633	24874	Business	9800.00
0005435653967	24874	Business	9800.00
0005435653854	24874	Business	9800.00
0005435653890	24874	Business	9800.00
0005433368911	24874	Business	9800.00
0005435653788	24874	Business	9800.00
0005435653762	24874	Economy	3300.00
0005433368905	24874	Economy	3300.00
0005433368914	24874	Economy	3300.00
0005435653917	24874	Economy	3300.00
0005435653871	24874	Economy	3300.00
0005435653882	24874	Economy	3300.00
0005435653928	24874	Economy	3300.00
0005435653894	24874	Economy	3300.00
0005435653948	24874	Economy	3300.00
0005435653981	24874	Economy	3300.00
0005433368904	24874	Economy	3600.00
0005433368903	24874	Economy	3600.00
0005433368906	24874	Economy	3600.00
0005435653895	24874	Economy	3600.00
0005435653783	24874	Economy	3300.00
0005435653923	24874	Economy	3300.00
0005435653749	24874	Economy	3300.00
0005435653896	24874	Economy	3300.00
0005435653929	24874	Economy	3300.00
0005435653763	24874	Economy	3300.00
0005435653942	24874	Economy	3300.00
0005435653969	24874	Economy	3300.00
0005435653832	24874	Economy	3300.00
0005435653780	24874	Economy	3300.00
0005435653980	24874	Economy	3300.00
0005435653955	24874	Economy	3300.00
0005435653784	24874	Economy	3300.00
0005433368902	24874	Economy	3300.00
0005435653916	24874	Economy	3300.00
0005435653728	24874	Economy	3300.00
0005433368900	24874	Economy	3300.00
0005435653812	24874	Economy	3300.00
0005435653979	24874	Economy	3300.00
0005435653704	24874	Economy	3300.00
0005433368907	24874	Economy	3300.00
0005433368908	24874	Economy	3300.00
0005433368909	24874	Economy	3300.00
0005435653658	24874	Economy	3300.00
0005433368915	24874	Economy	3300.00
0005435653884	24874	Economy	3300.00
0005433368910	24874	Economy	3300.00
0005435653811	24874	Economy	3300.00
0005435653949	24874	Economy	3300.00
0005435653905	24874	Economy	3300.00
0005435653831	24874	Economy	3300.00
0005435653925	24874	Economy	3300.00
0005433368901	24874	Economy	3300.00
0005435653954	24874	Economy	3300.00
0005433368896	24874	Economy	3300.00
0005433368913	24874	Economy	3300.00
0005435653787	24874	Economy	3300.00
0005433368898	24874	Economy	3300.00
0005435653764	24874	Economy	3300.00
0005435653724	24874	Economy	3300.00
0005433368899	24874	Economy	3300.00
0005435653685	24874	Economy	3300.00
0005435653837	24874	Economy	3300.00
0005435653950	24874	Economy	3300.00
0005435653931	24874	Economy	3300.00
0005433368912	24874	Economy	3300.00
0005433368897	24874	Economy	3300.00
0005435653880	24874	Economy	3300.00
0005433368895	24874	Economy	3300.00
0005435653659	24874	Economy	3300.00
0005435653956	24874	Economy	3300.00
0005435653859	24874	Economy	3300.00
0005435653970	24874	Economy	3300.00
0005435653889	24874	Economy	3300.00
0005435653883	24874	Economy	3300.00
0005435653930	24874	Economy	3300.00
0005435653966	24874	Economy	3300.00
0005435653874	24874	Economy	3300.00
0005434980606	2041	Economy	10500.00
0005434980613	2041	Economy	10500.00
0005434980609	2041	Economy	10500.00
0005434980601	2041	Economy	9500.00
0005434980608	2041	Economy	9500.00
0005434980598	2041	Economy	9500.00
0005434980616	2041	Economy	9500.00
0005434980604	2041	Economy	9500.00
0005434980595	2041	Economy	9500.00
0005434980597	2041	Economy	9500.00
0005434980599	2041	Economy	9500.00
0005434980605	2041	Economy	9500.00
0005434980615	2041	Economy	9500.00
0005434980614	2041	Economy	9500.00
0005434980612	2041	Economy	9500.00
0005434980594	2041	Economy	9500.00
0005434980602	2041	Economy	9500.00
0005434980596	2041	Economy	9500.00
0005434980603	2041	Economy	9500.00
0005434980607	2041	Economy	9500.00
0005434980611	2041	Economy	9500.00
0005434980600	2041	Economy	9500.00
0005434980617	2041	Economy	9500.00
0005434980610	2041	Economy	9500.00
0005434980304	23525	Economy	10500.00
0005434980336	23525	Economy	10500.00
0005434980220	23525	Economy	10500.00
0005434980260	23525	Economy	9500.00
0005434980410	23525	Economy	9500.00
0005434980358	23525	Economy	9500.00
0005434980289	23525	Economy	9500.00
0005434980275	23525	Economy	9500.00
0005434980167	23525	Economy	9500.00
0005434980399	23525	Economy	9500.00
0005434980188	23525	Economy	9500.00
0005434980365	23525	Economy	9500.00
0005434980274	23525	Economy	9500.00
0005434980323	23525	Economy	9500.00
0005434980230	23525	Economy	9500.00
0005434980234	23525	Economy	9500.00
0005434980265	23525	Economy	9500.00
0005434980261	23525	Economy	9500.00
0005434980290	23525	Economy	9500.00
0005434980271	23525	Economy	9500.00
0005434980259	23525	Economy	9500.00
0005434980266	23525	Economy	9500.00
0005434980450	23525	Economy	9500.00
0005434980364	23525	Economy	9500.00
0005434980305	23525	Economy	9500.00
0005434980241	23525	Economy	9500.00
0005434980324	23525	Economy	9500.00
0005434980409	23525	Economy	9500.00
0005434980303	23525	Economy	9500.00
0005434980269	23525	Economy	9500.00
0005434980286	23525	Economy	9500.00
0005434980240	23525	Economy	9500.00
0005434980276	23525	Economy	9500.00
0005434980297	23525	Economy	9500.00
0005434980273	23525	Economy	9500.00
0005434980285	23525	Economy	9500.00
0005434980235	23525	Economy	9500.00
0005434980296	23525	Economy	9500.00
0005434980270	23525	Economy	9500.00
0005434980272	23525	Economy	9500.00
0005434952632	2581	Economy	5300.00
0005434952633	2581	Economy	5300.00
0005433256473	2568	Economy	5300.00
0005433256474	2568	Economy	5300.00
0005433256484	28248	Economy	5300.00
0005434952609	28248	Economy	5300.00
0005433256486	28248	Economy	5300.00
0005433256485	28248	Economy	5300.00
0005433256487	28248	Economy	5300.00
0005433111566	19762	Economy	8700.00
0005433111565	19762	Economy	8700.00
0005433112386	20070	Economy	8700.00
0005433112385	20070	Economy	8700.00
0005433112391	20070	Economy	8700.00
0005433112407	20070	Economy	8700.00
0005433112399	20070	Economy	8700.00
0005433113618	20070	Economy	8700.00
0005433112406	20070	Economy	8700.00
0005433112388	20070	Economy	8700.00
0005433112392	20070	Economy	8700.00
0005433112384	20070	Economy	8700.00
0005433112389	20070	Economy	8700.00
0005433112390	20070	Economy	8700.00
0005434139642	11923	Business	9700.00
0005434139587	11923	Business	9700.00
0005434139889	11923	Business	9700.00
0005434139567	11923	Business	9700.00
0005434139574	11923	Business	9700.00
0005434139753	11923	Business	9700.00
0005434139918	11923	Business	9700.00
0005434139386	11923	Business	9700.00
0005434139749	11923	Business	9700.00
0005434139788	11923	Business	9700.00
0005434139358	11923	Business	9700.00
0005434139588	11923	Economy	3200.00
0005434139820	11923	Economy	3200.00
0005434139921	11923	Economy	3200.00
0005434139722	11923	Economy	3200.00
0005434139751	11923	Economy	3200.00
0005434139758	11923	Economy	3200.00
0005434139701	11923	Economy	3200.00
0005434139586	11923	Economy	3200.00
0005434139725	11923	Economy	3200.00
0005434139856	11923	Economy	3500.00
0005434139641	11923	Economy	3500.00
0005434139575	11923	Economy	3500.00
0005435283570	11923	Economy	3500.00
0005434139915	11923	Economy	3500.00
0005434139890	11923	Economy	3200.00
0005434139303	11923	Economy	3200.00
0005434139752	11923	Economy	3200.00
0005434139863	11923	Economy	3200.00
0005434139504	11923	Economy	3200.00
0005434139535	11923	Economy	3200.00
0005434139791	11923	Economy	3200.00
0005434139692	11923	Economy	3200.00
0005434139888	11923	Economy	3200.00
0005434139659	11923	Economy	3200.00
0005434139474	11923	Economy	3200.00
0005434139645	11923	Economy	3200.00
0005435283569	11923	Economy	3200.00
0005434139700	11923	Economy	3200.00
0005434139569	11923	Economy	3200.00
0005434139933	11923	Economy	3200.00
0005434140086	11923	Economy	3200.00
0005434139713	11923	Economy	3200.00
0005434139568	11923	Economy	3200.00
0005434139673	11923	Economy	3200.00
0005434139732	11923	Economy	3200.00
0005434139629	11923	Economy	3200.00
0005434139652	11923	Economy	3200.00
0005434139647	11923	Economy	3200.00
0005434139667	11923	Economy	3200.00
0005434139699	11923	Economy	3200.00
0005434139835	11923	Economy	3200.00
0005434139768	11923	Economy	3200.00
0005434139716	11923	Economy	3200.00
0005434139630	11923	Economy	3200.00
0005434139746	11923	Economy	3200.00
0005434139720	11923	Economy	3200.00
0005434139724	11923	Economy	3200.00
0005434139930	11923	Economy	3200.00
0005434139754	11923	Economy	3200.00
0005434139464	11923	Economy	3200.00
0005434139648	11923	Economy	3200.00
0005434140178	11923	Economy	3200.00
0005434139775	11923	Economy	3200.00
0005434139721	11923	Economy	3200.00
0005434139515	11923	Economy	3200.00
0005434139842	11923	Economy	3200.00
0005434139776	11923	Economy	3200.00
0005434139924	11923	Economy	3200.00
0005434139906	11923	Economy	3200.00
0005434139843	11923	Economy	3200.00
0005434139923	11923	Economy	3200.00
0005434139717	11923	Economy	3200.00
0005434139926	11923	Economy	3200.00
0005434140270	11923	Economy	3200.00
0005434139288	11923	Economy	3200.00
0005434139916	11923	Economy	3200.00
0005434139693	11923	Economy	3200.00
0005434139624	11923	Economy	3200.00
0005434139644	11923	Economy	3200.00
0005434139951	11923	Economy	3200.00
0005434139256	11923	Economy	3200.00
0005434139983	11923	Economy	3200.00
0005434139723	11923	Economy	3200.00
0005434140326	28758	Business	9700.00
0005434140335	28758	Business	9700.00
0005434140359	28758	Business	9700.00
0005434140304	28758	Business	9700.00
0005434140363	28758	Business	9700.00
0005434140333	28758	Business	9700.00
0005434140337	28758	Business	9700.00
0005434140297	28758	Business	9700.00
0005434140303	28758	Business	9700.00
0005434140344	28758	Business	9700.00
0005434140312	28758	Economy	3200.00
0005434140367	28758	Economy	3200.00
0005434140325	28758	Economy	3200.00
0005434140323	28758	Economy	3200.00
0005434140346	28758	Economy	3200.00
0005434140295	28758	Economy	3200.00
0005434140311	28758	Economy	3200.00
0005434140374	28758	Economy	3200.00
0005434140355	28758	Economy	3200.00
0005434140329	28758	Economy	3200.00
0005434140349	28758	Economy	3500.00
0005434140328	28758	Economy	3500.00
0005434140360	28758	Economy	3500.00
0005434140324	28758	Economy	3200.00
0005434140353	28758	Economy	3200.00
0005434140372	28758	Economy	3200.00
0005434140375	28758	Economy	3200.00
0005434140354	28758	Economy	3200.00
0005434140341	28758	Economy	3200.00
0005434140350	28758	Economy	3200.00
0005434140373	28758	Economy	3200.00
0005434140345	28758	Economy	3200.00
0005434140299	28758	Economy	3200.00
0005434140370	28758	Economy	3200.00
0005434140368	28758	Economy	3200.00
0005434140348	28758	Economy	3200.00
0005434140336	28758	Economy	3200.00
0005434140339	28758	Economy	3200.00
0005434140364	28758	Economy	3200.00
0005434140307	28758	Economy	3200.00
0005434140309	28758	Economy	3200.00
0005434140331	28758	Economy	3200.00
0005434140319	28758	Economy	3200.00
0005434140321	28758	Economy	3200.00
0005434140300	28758	Economy	3200.00
0005434140330	28758	Economy	3200.00
0005434140305	28758	Economy	3200.00
0005434140316	28758	Economy	3200.00
0005434140327	28758	Economy	3200.00
0005434140352	28758	Economy	3200.00
0005434140308	28758	Economy	3200.00
0005434140369	28758	Economy	3200.00
0005434140358	28758	Economy	3200.00
0005434140361	28758	Economy	3200.00
0005434140366	28758	Economy	3200.00
0005434140362	28758	Economy	3200.00
0005434140301	28758	Economy	3200.00
0005434140322	28758	Economy	3200.00
0005434140313	28758	Economy	3200.00
0005434140342	28758	Economy	3200.00
0005434140310	28758	Economy	3200.00
0005434140334	28758	Economy	3200.00
0005434140338	28758	Economy	3200.00
0005434140314	28758	Economy	3200.00
0005434140318	28758	Economy	3200.00
0005434140340	28758	Economy	3200.00
0005434140298	28758	Economy	3200.00
0005434140356	28758	Economy	3200.00
0005434140371	28758	Economy	3200.00
0005434140357	28758	Economy	3200.00
0005434140347	28758	Economy	3200.00
0005434140365	28758	Economy	3200.00
0005434140296	28758	Economy	3200.00
0005434140320	28758	Economy	3200.00
0005434140306	28758	Economy	3200.00
0005434140343	28758	Economy	3200.00
0005434140315	28758	Economy	3200.00
0005434140317	28758	Economy	3200.00
0005434140332	28758	Economy	3200.00
0005434140351	28758	Economy	3200.00
0005434140302	28758	Economy	3200.00
0005434466584	6570	Economy	23000.00
0005435312851	6570	Economy	20900.00
0005434466595	6570	Economy	20900.00
0005434466587	6570	Economy	20900.00
0005434466590	6570	Economy	20900.00
0005435312850	6570	Economy	20900.00
0005434466596	6570	Economy	20900.00
0005435312857	6570	Economy	20900.00
0005435312847	6570	Economy	20900.00
0005434466589	6570	Economy	20900.00
0005434466594	6570	Economy	20900.00
0005434466583	6570	Economy	20900.00
0005434466588	6570	Economy	20900.00
0005434466597	6570	Economy	20900.00
0005434466593	6570	Economy	20900.00
0005434466586	6570	Economy	20900.00
0005435312854	6570	Economy	20900.00
0005435312848	6570	Economy	20900.00
0005434466592	6570	Economy	20900.00
0005434466598	6570	Economy	20900.00
0005434466585	6570	Economy	20900.00
0005435312856	6570	Economy	20900.00
0005435312855	6570	Economy	20900.00
0005434466591	6570	Economy	20900.00
0005433539103	6779	Economy	10900.00
0005433539100	6779	Economy	10900.00
0005433539102	6779	Economy	9900.00
0005435259839	6779	Economy	9900.00
0005435259849	6779	Economy	9900.00
0005433534558	6779	Economy	9900.00
0005433539105	6779	Economy	9900.00
0005433539101	6779	Economy	9900.00
0005435259840	6779	Economy	9900.00
0005433539098	6779	Economy	9900.00
0005433534556	6779	Economy	9900.00
0005433539104	6779	Economy	9900.00
0005433539099	6779	Economy	9900.00
0005433534557	6779	Economy	9900.00
0005433539045	25038	Economy	10900.00
0005433539030	25038	Economy	9900.00
0005433539059	25038	Economy	9900.00
0005433534540	25038	Economy	9900.00
0005433539015	25038	Economy	9900.00
0005435259877	25038	Economy	9900.00
0005433539075	25038	Economy	9900.00
0005433539043	25038	Economy	9900.00
0005435259878	25038	Economy	9900.00
0005435259879	25038	Economy	9900.00
0005433534539	25038	Economy	9900.00
0005433539014	25038	Economy	9900.00
0005433534543	25038	Economy	9900.00
0005433534538	25038	Economy	9900.00
0005433539020	25038	Economy	9900.00
0005433539046	25038	Economy	9900.00
0005433539065	25038	Economy	9900.00
0005433512178	804	Economy	14600.00
0005433512177	804	Economy	14600.00
0005433512176	804	Economy	14600.00
0005432922615	804	Economy	14600.00
0005433512179	804	Economy	14600.00
0005433512092	16129	Economy	16100.00
0005433512124	16129	Economy	14600.00
0005432922635	16129	Economy	14600.00
0005433512091	16129	Economy	14600.00
0005433512157	16129	Economy	14600.00
0005432922634	16129	Economy	14600.00
0005433512158	16129	Economy	14600.00
0005433512125	16129	Economy	14600.00
0005433512102	16129	Economy	14600.00
0005435852616	4034	Economy	13500.00
0005435852640	4034	Economy	12300.00
0005433475823	4034	Economy	12300.00
0005433475821	4034	Economy	12300.00
0005435852615	4034	Economy	12300.00
0005433475825	4034	Economy	12300.00
0005433475824	4034	Economy	12300.00
0005435852636	4034	Economy	12300.00
0005435852635	4034	Economy	12300.00
0005435852634	4034	Economy	12300.00
0005433475820	4034	Economy	12300.00
0005433475822	4034	Economy	12300.00
0005435698117	3657	Economy	7900.00
0005435935097	3657	Economy	7900.00
0005435698122	3657	Economy	7200.00
0005435698125	3657	Economy	7200.00
0005435698120	3657	Economy	7200.00
0005434950650	3657	Economy	7200.00
0005435698100	3657	Economy	7200.00
0005435698102	3657	Economy	7200.00
0005435935102	3657	Economy	7200.00
0005435935101	3657	Economy	7200.00
0005435698123	3657	Economy	7200.00
0005435698106	3657	Economy	7200.00
0005435698111	3657	Economy	7200.00
0005435916211	3657	Economy	7200.00
0005435698105	3657	Economy	7200.00
0005435698113	3657	Economy	7200.00
0005435698107	3657	Economy	7200.00
0005435916220	3657	Economy	7200.00
0005435698124	3657	Economy	7200.00
0005435698116	3657	Economy	7200.00
0005435935096	3657	Economy	7200.00
0005435698114	3657	Economy	7200.00
0005435698108	3657	Economy	7200.00
0005435698103	3657	Economy	7200.00
0005435916219	3657	Economy	7200.00
0005435698104	3657	Economy	7200.00
0005434950651	3657	Economy	7200.00
0005435698121	3657	Economy	7200.00
0005435698119	3657	Economy	7200.00
0005435698115	3657	Economy	7200.00
0005435698101	3657	Economy	7200.00
0005435698109	3657	Economy	7200.00
0005435935106	3657	Economy	7200.00
0005435698112	3657	Economy	7200.00
0005435698118	3657	Economy	7200.00
0005435698110	3657	Economy	7200.00
0005435935107	3657	Economy	7200.00
0005434950649	3657	Economy	7200.00
0005435916243	16268	Economy	7900.00
0005435697881	16268	Economy	7900.00
0005435916246	16268	Economy	7900.00
0005435697902	16268	Economy	7200.00
0005435697880	16268	Economy	7200.00
0005435697920	16268	Economy	7200.00
0005435697810	16268	Economy	7200.00
0005435697789	16268	Economy	7200.00
0005435697915	16268	Economy	7200.00
0005435933578	16268	Economy	7200.00
0005434950621	16268	Economy	7200.00
0005435935128	16268	Economy	7200.00
0005435697885	16268	Economy	7200.00
0005434950620	16268	Economy	7200.00
0005435697809	16268	Economy	7200.00
0005435935129	16268	Economy	7200.00
0005435933579	16268	Economy	7200.00
0005435935127	16268	Economy	7200.00
0005434950602	16268	Economy	7200.00
0005434950610	16268	Economy	7200.00
0005435697863	16268	Economy	7200.00
0005435697811	16268	Economy	7200.00
0005435916244	16268	Economy	7200.00
0005435697864	16268	Economy	7200.00
0005434950616	16268	Economy	7200.00
0005435697837	16268	Economy	7200.00
0005434950617	16268	Economy	7200.00
0005435697878	16268	Economy	7200.00
0005435933580	16268	Economy	7200.00
0005435933581	16268	Economy	7200.00
0005435697901	16268	Economy	7200.00
0005435697884	16268	Economy	7200.00
0005435697839	16268	Economy	7200.00
0005435697830	16268	Economy	7200.00
0005435697919	16268	Economy	7200.00
0005435916245	16268	Economy	7200.00
0005435697765	16268	Economy	7200.00
0005435697910	16268	Economy	7200.00
0005434606927	3955	Economy	21300.00
0005435904714	3955	Economy	21300.00
0005432609843	3955	Economy	19300.00
0005432609844	3955	Economy	19300.00
0005433519582	3955	Economy	19300.00
0005434606926	3955	Economy	19300.00
0005433519584	3955	Economy	19300.00
0005433519583	3955	Economy	19300.00
0005434605001	3955	Economy	19300.00
0005432607677	3955	Economy	19300.00
0005432607676	3955	Economy	19300.00
0005432607678	3955	Economy	19300.00
0005435842344	3955	Economy	19300.00
0005434605000	3955	Economy	19300.00
0005434606925	3955	Economy	19300.00
0005432607679	3955	Economy	19300.00
0005434605002	3955	Economy	19300.00
0005435853645	3955	Economy	19300.00
0005435853646	3955	Economy	19300.00
0005434606881	22034	Economy	21300.00
0005434606887	22034	Economy	19300.00
0005434606895	22034	Economy	19300.00
0005435853662	22034	Economy	19300.00
0005434606888	22034	Economy	19300.00
0005435853661	22034	Economy	19300.00
0005435904909	22034	Economy	19300.00
0005433519550	22034	Economy	19300.00
0005433349085	710	Economy	3700.00
0005433349106	710	Economy	3700.00
0005433349097	710	Economy	3700.00
0005433349119	710	Economy	3700.00
0005433349120	710	Economy	3700.00
0005433349096	710	Economy	3700.00
0005433349074	710	Economy	3700.00
0005433349098	710	Economy	3700.00
0005433349123	710	Economy	3700.00
0005433349100	710	Economy	3700.00
0005433349090	710	Economy	3700.00
0005433349111	710	Economy	3700.00
0005435628793	15883	Economy	3700.00
0005435628789	15883	Economy	3700.00
0005433349151	15883	Economy	3700.00
0005435628794	15883	Economy	3700.00
0005435628784	15883	Economy	3700.00
0005433349150	15883	Economy	3700.00
0005435628795	15883	Economy	3700.00
0005433349152	15883	Economy	3700.00
0005435628790	15883	Economy	3700.00
0005433349149	15883	Economy	3700.00
0005434445313	17251	Economy	7100.00
0005434445312	17251	Economy	7100.00
0005434445309	17251	Economy	7100.00
0005433158171	17251	Economy	7100.00
0005434445311	17251	Economy	7100.00
0005434446582	17251	Economy	7100.00
0005434445310	17251	Economy	7100.00
0005433158176	17251	Economy	7100.00
0005433159369	17251	Economy	7100.00
0005434446581	17251	Economy	7100.00
0005434446580	17251	Economy	7100.00
0005433159368	17251	Economy	7100.00
0005433158204	17663	Economy	7100.00
0005434445284	17663	Economy	7100.00
0005434445289	17663	Economy	7100.00
0005433159375	17663	Economy	7100.00
0005433158205	17663	Economy	7100.00
0005433159374	17663	Economy	7100.00
0005434445279	17663	Economy	7100.00
0005435133168	7910	Economy	5900.00
0005435133177	7910	Economy	5900.00
0005435133172	7910	Economy	5400.00
0005435383246	7910	Economy	5400.00
0005435383232	7910	Economy	5400.00
0005435133169	7910	Economy	5400.00
0005435133176	7910	Economy	5400.00
0005435383247	7910	Economy	5400.00
0005435383267	7910	Economy	5400.00
0005435133171	7910	Economy	5400.00
0005435133175	7910	Economy	5400.00
0005435133170	7910	Economy	5400.00
0005435133174	7910	Economy	5400.00
0005435133173	7910	Economy	5400.00
0005435383261	7910	Economy	5400.00
0005435383274	7910	Economy	5400.00
0005435133086	33104	Economy	5400.00
0005435133087	33104	Economy	5400.00
0005435133102	33104	Economy	5400.00
0005435133131	33104	Economy	5400.00
0005435383298	33104	Economy	5400.00
0005435383300	33104	Economy	5400.00
0005435133118	33104	Economy	5400.00
0005435133040	33104	Economy	5400.00
0005435133081	33104	Economy	5400.00
0005435133111	33104	Economy	5400.00
0005435133109	33104	Economy	5400.00
0005435133082	33104	Economy	5400.00
0005435383299	33104	Economy	5400.00
0005435160604	7498	Economy	13800.00
0005435390386	7498	Economy	13800.00
0005435160606	7498	Economy	13800.00
0005435390385	7498	Economy	12500.00
0005435160607	7498	Economy	12500.00
0005435390367	7498	Economy	12500.00
0005435390397	7498	Economy	12500.00
0005435160609	7498	Economy	12500.00
0005435160603	7498	Economy	12500.00
0005435160608	7498	Economy	12500.00
0005435390398	7498	Economy	12500.00
0005435160605	7498	Economy	12500.00
0005435390356	7498	Economy	12500.00
0005435390433	29547	Economy	13800.00
0005435160511	29547	Economy	13800.00
0005435160571	29547	Economy	12500.00
0005435160502	29547	Economy	12500.00
0005435390431	29547	Economy	12500.00
0005435390434	29547	Economy	12500.00
0005435160510	29547	Economy	12500.00
0005435390429	29547	Economy	12500.00
0005435160558	29547	Economy	12500.00
0005435160557	29547	Economy	12500.00
0005435390432	29547	Economy	12500.00
0005435160570	29547	Economy	12500.00
0005435390430	29547	Economy	12500.00
0005435160541	29547	Economy	12500.00
0005435160489	29547	Economy	12500.00
0005435160569	29547	Economy	12500.00
0005435390428	29547	Economy	12500.00
0005435390427	29547	Economy	12500.00
0005432394161	18473	Economy	4900.00
0005432398258	18473	Economy	4900.00
0005435179019	18473	Economy	4900.00
0005432394160	18473	Economy	4900.00
0005435179020	18473	Economy	4900.00
0005435178538	18473	Economy	4900.00
0005432398259	18473	Economy	4900.00
0005432398291	27136	Economy	4900.00
0005435178526	27136	Economy	4900.00
0005432398292	27136	Economy	4900.00
0005435179408	27136	Economy	4900.00
0005435178524	27136	Economy	4900.00
0005432398293	27136	Economy	4900.00
0005432639451	2257	Business	87300.00
0005432866137	2257	Business	87300.00
0005432866129	2257	Business	87300.00
0005432639462	2257	Business	87300.00
0005432866127	2257	Economy	29100.00
0005432639471	2257	Economy	29100.00
0005432639452	2257	Economy	29100.00
0005432639460	2257	Economy	29100.00
0005432866125	2257	Economy	29100.00
0005432866135	2257	Economy	29100.00
0005432639473	2257	Economy	32000.00
0005432866111	2257	Economy	32000.00
0005432639470	2257	Economy	32000.00
0005432639457	2257	Economy	29100.00
0005432639475	2257	Economy	29100.00
0005432866162	2257	Economy	29100.00
0005432639454	2257	Economy	29100.00
0005432639458	2257	Economy	29100.00
0005432866138	2257	Economy	29100.00
0005432866126	2257	Economy	29100.00
0005432639469	2257	Economy	29100.00
0005432639472	2257	Economy	29100.00
0005432866155	2257	Economy	29100.00
0005432639474	2257	Economy	29100.00
0005432866175	2257	Economy	29100.00
0005432639455	2257	Economy	29100.00
0005432866109	2257	Economy	29100.00
0005432639461	2257	Economy	29100.00
0005432866139	2257	Economy	29100.00
0005432866128	2257	Economy	29100.00
0005432866110	2257	Economy	29100.00
0005432639456	2257	Economy	29100.00
0005432866081	2257	Economy	29100.00
0005432866136	2257	Economy	29100.00
0005432866134	2257	Economy	29100.00
0005432866133	2257	Economy	29100.00
0005432639468	2257	Economy	29100.00
0005432866151	2257	Economy	29100.00
0005432639464	2257	Economy	29100.00
0005432639466	2257	Economy	29100.00
0005432639449	2257	Economy	29100.00
0005432866157	2257	Economy	29100.00
0005432639465	2257	Economy	29100.00
0005432866143	2257	Economy	29100.00
0005432866174	2257	Economy	29100.00
0005432639459	2257	Economy	29100.00
0005432639453	2257	Economy	29100.00
0005432866152	2257	Economy	29100.00
0005432639463	2257	Economy	29100.00
0005432639450	2257	Economy	29100.00
0005432639467	2257	Economy	29100.00
0005434191299	9747	Economy	4400.00
0005434552902	9747	Economy	4400.00
0005434552903	9747	Economy	4400.00
0005434552900	9747	Economy	4400.00
0005434552899	9747	Economy	4400.00
0005434191298	9747	Economy	4400.00
0005434191305	9747	Economy	4400.00
0005434552901	9747	Economy	4400.00
0005435104264	6555	Business	48400.00
0005435104276	6555	Business	48400.00
0005434505238	6555	Business	48400.00
0005434505232	6555	Business	48400.00
0005434505226	6555	Business	48400.00
0005434505245	6555	Business	48400.00
0005434505229	6555	Business	48400.00
0005434505228	6555	Business	48400.00
0005435104269	6555	Economy	16100.00
0005435104271	6555	Economy	16100.00
0005435104261	6555	Economy	16100.00
0005434505224	6555	Economy	16100.00
0005435104242	6555	Economy	16100.00
0005434505227	6555	Economy	16100.00
0005435104241	6555	Economy	16100.00
0005435104266	6555	Economy	17800.00
0005435104245	6555	Economy	17800.00
0005435104253	6555	Economy	17800.00
0005435104250	6555	Economy	16100.00
0005435104240	6555	Economy	16100.00
0005435104281	6555	Economy	16100.00
0005435104272	6555	Economy	16100.00
0005435104247	6555	Economy	16100.00
0005435104277	6555	Economy	16100.00
0005435104263	6555	Economy	16100.00
0005434505231	6555	Economy	16100.00
0005434505241	6555	Economy	16100.00
0005434505230	6555	Economy	16100.00
0005435104267	6555	Economy	16100.00
0005434505242	6555	Economy	16100.00
0005435104275	6555	Economy	16100.00
0005434505239	6555	Economy	16100.00
0005435104257	6555	Economy	16100.00
0005435104248	6555	Economy	16100.00
0005434505235	6555	Economy	16100.00
0005435104265	6555	Economy	16100.00
0005435104274	6555	Economy	16100.00
0005435104239	6555	Economy	16100.00
0005434505233	6555	Economy	16100.00
0005434505236	6555	Economy	16100.00
0005434505223	6555	Economy	16100.00
0005435104280	6555	Economy	16100.00
0005435104255	6555	Economy	16100.00
0005434505237	6555	Economy	16100.00
0005435104262	6555	Economy	16100.00
0005435104256	6555	Economy	16100.00
0005435104252	6555	Economy	16100.00
0005435104243	6555	Economy	16100.00
0005435104244	6555	Economy	16100.00
0005434505243	6555	Economy	16100.00
0005435104279	6555	Economy	16100.00
0005435104260	6555	Economy	16100.00
0005435104270	6555	Economy	16100.00
0005435104249	6555	Economy	16100.00
0005435104259	6555	Economy	16100.00
0005435104268	6555	Economy	16100.00
0005435104273	6555	Economy	16100.00
0005435104251	6555	Economy	16100.00
0005435104278	6555	Economy	16100.00
0005434505225	6555	Economy	16100.00
0005435104246	6555	Economy	16100.00
0005434505246	6555	Economy	16100.00
0005434505240	6555	Economy	16100.00
0005435104258	6555	Economy	16100.00
0005435104254	6555	Economy	16100.00
0005434505234	6555	Economy	16100.00
0005434505244	6555	Economy	16100.00
0005434504836	22642	Business	48400.00
0005435104062	22642	Business	48400.00
0005435104032	22642	Business	48400.00
0005434504935	22642	Business	48400.00
0005435104050	22642	Business	48400.00
0005434504868	22642	Business	48400.00
0005434504816	22642	Business	48400.00
0005434504668	22642	Economy	16100.00
0005434504946	22642	Economy	16100.00
0005435104018	22642	Economy	16100.00
0005435104059	22642	Economy	16100.00
0005435104060	22642	Economy	16100.00
0005434504827	22642	Economy	17800.00
0005434504733	22642	Economy	17800.00
0005434504945	22642	Economy	17800.00
0005434504624	22642	Economy	16100.00
0005434504865	22642	Economy	16100.00
0005434504866	22642	Economy	16100.00
0005434504802	22642	Economy	16100.00
0005434504667	22642	Economy	16100.00
0005434504664	22642	Economy	16100.00
0005434504745	22642	Economy	16100.00
0005434504957	22642	Economy	16100.00
0005434504978	22642	Economy	16100.00
0005434504841	22642	Economy	16100.00
0005434504711	22642	Economy	16100.00
0005434504623	22642	Economy	16100.00
0005434504731	22642	Economy	16100.00
0005435104028	22642	Economy	16100.00
0005434504689	22642	Economy	16100.00
0005435104049	22642	Economy	16100.00
0005434504793	22642	Economy	16100.00
0005435104038	22642	Economy	16100.00
0005434504838	22642	Economy	16100.00
0005434504826	22642	Economy	16100.00
0005435104039	22642	Economy	16100.00
0005435104029	22642	Economy	16100.00
0005434504864	22642	Economy	16100.00
0005434504883	22642	Economy	16100.00
0005434504936	22642	Economy	16100.00
0005435104065	22642	Economy	16100.00
0005435104064	22642	Economy	16100.00
0005434504794	22642	Economy	16100.00
0005434504666	22642	Economy	16100.00
0005434504690	22642	Economy	16100.00
0005434504797	22642	Economy	16100.00
0005434504798	22642	Economy	16100.00
0005434504938	22642	Economy	16100.00
0005434504897	22642	Economy	16100.00
0005434504749	22642	Economy	16100.00
0005435104063	22642	Economy	16100.00
0005434504896	22642	Economy	16100.00
0005434504734	22642	Economy	16100.00
0005435104058	22642	Economy	16100.00
0005435800169	6418	Economy	15300.00
0005435800171	6418	Economy	15300.00
0005435800168	6418	Economy	15300.00
0005435800167	6418	Economy	15300.00
0005435800164	6418	Economy	15300.00
0005435800163	6418	Economy	15300.00
0005435800166	6418	Economy	15300.00
0005435800162	6418	Economy	15300.00
0005435800174	6418	Economy	15300.00
0005435800170	6418	Economy	15300.00
0005435800172	6418	Economy	15300.00
0005435800161	6418	Economy	15300.00
0005435800165	6418	Economy	15300.00
0005435800173	6418	Economy	15300.00
0005433368688	1659	Business	50000.00
0005435654323	1659	Business	50000.00
0005435654302	1659	Business	50000.00
0005435654326	1659	Business	50000.00
0005435654320	1659	Business	50000.00
0005433368726	1659	Business	50000.00
0005435654325	1659	Business	50000.00
0005435654307	1659	Business	50000.00
0005435654351	1659	Business	50000.00
0005435654310	1659	Business	50000.00
0005435654338	1659	Business	50000.00
0005435654347	1659	Business	50000.00
0005435654301	1659	Economy	16700.00
0005435654342	1659	Economy	16700.00
0005435790407	1659	Economy	16700.00
0005433368534	1659	Economy	16700.00
0005435654331	1659	Economy	16700.00
0005435654352	1659	Economy	16700.00
0005433368425	1659	Economy	16700.00
0005435654300	1659	Economy	16700.00
0005435654353	1659	Economy	16700.00
0005433368550	1659	Economy	18300.00
0005435654317	1659	Economy	18300.00
0005435654312	1659	Economy	18300.00
0005435654314	1659	Economy	18300.00
0005435654315	1659	Economy	16700.00
0005435654340	1659	Economy	16700.00
0005433368587	1659	Economy	16700.00
0005435654337	1659	Economy	16700.00
0005435654334	1659	Economy	16700.00
0005435654327	1659	Economy	16700.00
0005435654339	1659	Economy	16700.00
0005433368586	1659	Economy	16700.00
0005433368589	1659	Economy	16700.00
0005433368602	1659	Economy	16700.00
0005435654354	1659	Economy	16700.00
0005435790406	1659	Economy	16700.00
0005435654328	1659	Economy	16700.00
0005435654332	1659	Economy	16700.00
0005435654348	1659	Economy	16700.00
0005435654335	1659	Economy	16700.00
0005433368572	1659	Economy	16700.00
0005435654303	1659	Economy	16700.00
0005433368729	1659	Economy	16700.00
0005435654322	1659	Economy	16700.00
0005433368568	1659	Economy	16700.00
0005435654345	1659	Economy	16700.00
0005435654330	1659	Economy	16700.00
0005435654304	1659	Economy	16700.00
0005435654349	1659	Economy	16700.00
0005435654311	1659	Economy	16700.00
0005435654306	1659	Economy	16700.00
0005435654350	1659	Economy	16700.00
0005433368623	1659	Economy	16700.00
0005433368599	1659	Economy	16700.00
0005435654344	1659	Economy	16700.00
0005433368627	1659	Economy	16700.00
0005435654343	1659	Economy	16700.00
0005435654319	1659	Economy	16700.00
0005435654324	1659	Economy	16700.00
0005435654346	1659	Economy	16700.00
0005433368678	1659	Economy	16700.00
0005433368492	1659	Economy	16700.00
0005435654333	1659	Economy	16700.00
0005435654309	1659	Economy	16700.00
0005433368758	1659	Economy	16700.00
0005435654318	1659	Economy	16700.00
0005435654341	1659	Economy	16700.00
0005433368804	1659	Economy	16700.00
0005433368741	1659	Economy	16700.00
0005435654336	1659	Economy	16700.00
0005433368553	1659	Economy	16700.00
0005435654313	1659	Economy	16700.00
0005435654321	1659	Economy	16700.00
0005433368447	1659	Economy	16700.00
0005433368687	1659	Economy	16700.00
0005433368598	1659	Economy	16700.00
0005435654305	1659	Economy	16700.00
0005435654316	1659	Economy	16700.00
0005433368590	1659	Economy	16700.00
0005435654329	1659	Economy	16700.00
0005435790405	1659	Economy	16700.00
0005435654308	1659	Economy	16700.00
0005435653930	21721	Business	50000.00
0005433368910	21721	Business	50000.00
0005435653967	21721	Business	50000.00
0005433368912	21721	Business	50000.00
0005435653931	21721	Business	50000.00
0005435653942	21721	Business	50000.00
0005435653728	21721	Business	50000.00
0005433368902	21721	Business	50000.00
0005435653916	21721	Business	50000.00
0005433368901	21721	Business	50000.00
0005435653874	21721	Economy	16700.00
0005435653923	21721	Economy	16700.00
0005435653762	21721	Economy	16700.00
0005435653657	21721	Economy	16700.00
0005435653787	21721	Economy	16700.00
0005435653724	21721	Economy	16700.00
0005435653884	21721	Economy	16700.00
0005435653979	21721	Economy	16700.00
0005435653871	21721	Economy	16700.00
0005435653780	21721	Economy	18300.00
0005435653956	21721	Economy	18300.00
0005435653950	21721	Economy	18300.00
0005435653917	21721	Economy	16700.00
0005435653749	21721	Economy	16700.00
0005435653704	21721	Economy	16700.00
0005435653895	21721	Economy	16700.00
0005435653970	21721	Economy	16700.00
0005435653811	21721	Economy	16700.00
0005433368905	21721	Economy	16700.00
0005433368896	21721	Economy	16700.00
0005433368900	21721	Economy	16700.00
0005435653633	21721	Economy	16700.00
0005435653883	21721	Economy	16700.00
0005435653880	21721	Economy	16700.00
0005435653831	21721	Economy	16700.00
0005435653954	21721	Economy	16700.00
0005433368898	21721	Economy	16700.00
0005433368903	21721	Economy	16700.00
0005435653955	21721	Economy	16700.00
0005435653658	21721	Economy	16700.00
0005435653882	21721	Economy	16700.00
0005435653896	21721	Economy	16700.00
0005433368897	21721	Economy	16700.00
0005435653812	21721	Economy	16700.00
0005433368899	21721	Economy	16700.00
0005435653784	21721	Economy	16700.00
0005435653929	21721	Economy	16700.00
0005433368895	21721	Economy	16700.00
0005435653859	21721	Economy	16700.00
0005435653837	21721	Economy	16700.00
0005435653889	21721	Economy	16700.00
0005435653788	21721	Economy	16700.00
0005435653928	21721	Economy	16700.00
0005433368915	21721	Economy	16700.00
0005435653948	21721	Economy	16700.00
0005435653966	21721	Economy	16700.00
0005433368913	21721	Economy	16700.00
0005433368911	21721	Economy	16700.00
0005435653969	21721	Economy	16700.00
0005435653685	21721	Economy	16700.00
0005433368914	21721	Economy	16700.00
0005435653764	21721	Economy	16700.00
0005435653854	21721	Economy	16700.00
0005433368904	21721	Economy	16700.00
0005435653659	21721	Economy	16700.00
0005435653981	21721	Economy	16700.00
0005435653783	21721	Economy	16700.00
0005435653763	21721	Economy	16700.00
0005435653949	21721	Economy	16700.00
0005435653890	21721	Economy	16700.00
0005435653894	21721	Economy	16700.00
0005433368906	21721	Economy	16700.00
0005435653905	21721	Economy	16700.00
0005433368909	21721	Economy	16700.00
0005433368908	21721	Economy	16700.00
0005433368907	21721	Economy	16700.00
0005435653925	21721	Economy	16700.00
0005435653832	21721	Economy	16700.00
0005435653980	21721	Economy	16700.00
0005435627128	12269	Economy	11200.00
0005435627129	12269	Economy	11200.00
0005435627125	23795	Economy	11200.00
0005435312868	23226	Economy	20900.00
0005435312870	23226	Economy	20900.00
0005434466546	23226	Economy	20900.00
0005434466555	23226	Economy	20900.00
0005434466532	23226	Economy	20900.00
0005434466566	23226	Economy	20900.00
0005434466526	23226	Economy	20900.00
0005434466561	23226	Economy	20900.00
0005435312869	23226	Economy	20900.00
0005434466556	23226	Economy	20900.00
0005434466541	23226	Economy	20900.00
0005434466540	23226	Economy	20900.00
0005435312871	23226	Economy	20900.00
0005434466554	23226	Economy	20900.00
0005434466547	23226	Economy	20900.00
0005435312872	23226	Economy	20900.00
0005435312873	23226	Economy	20900.00
0005434466559	23226	Economy	20900.00
0005433987243	4185	Business	21500.00
0005433987256	4185	Business	21500.00
0005433987259	4185	Business	21500.00
0005433987253	4185	Business	21500.00
0005433987276	4185	Business	21500.00
0005433987246	4185	Economy	7200.00
0005433987265	4185	Economy	7200.00
0005433987278	4185	Economy	7200.00
0005433987258	4185	Economy	7200.00
0005433987242	4185	Economy	7200.00
0005433987261	4185	Economy	7200.00
0005433987248	4185	Economy	7900.00
0005433987267	4185	Economy	7200.00
0005433987257	4185	Economy	7200.00
0005433987244	4185	Economy	7200.00
0005433987247	4185	Economy	7200.00
0005433987264	4185	Economy	7200.00
0005433987274	4185	Economy	7200.00
0005433987270	4185	Economy	7200.00
0005433987249	4185	Economy	7200.00
0005433987245	4185	Economy	7200.00
0005433987260	4185	Economy	7200.00
0005433987263	4185	Economy	7200.00
0005433987262	4185	Economy	7200.00
0005433987250	4185	Economy	7200.00
0005433987275	4185	Economy	7200.00
0005433987266	4185	Economy	7200.00
0005433987273	4185	Economy	7200.00
0005433987255	4185	Economy	7200.00
0005433987271	4185	Economy	7200.00
0005433987272	4185	Economy	7200.00
0005433987251	4185	Economy	7200.00
0005433987268	4185	Economy	7200.00
0005433987241	4185	Economy	7200.00
0005433987269	4185	Economy	7200.00
0005433987252	4185	Economy	7200.00
0005433987254	4185	Economy	7200.00
0005433987277	4185	Economy	7200.00
0005435788810	25674	Business	21500.00
0005433986765	25674	Business	21500.00
0005433986813	25674	Business	21500.00
0005433986831	25674	Business	21500.00
0005433986807	25674	Business	21500.00
0005433986753	25674	Business	21500.00
0005433986742	25674	Business	21500.00
0005433986656	25674	Business	21500.00
0005433986808	25674	Business	21500.00
0005433986799	25674	Economy	7200.00
0005433986701	25674	Economy	7200.00
0005433986830	25674	Economy	7200.00
0005433986708	25674	Economy	7900.00
0005433986755	25674	Economy	7900.00
0005433986832	25674	Economy	7200.00
0005433986821	25674	Economy	7200.00
0005433986805	25674	Economy	7200.00
0005433986746	25674	Economy	7200.00
0005433986651	25674	Economy	7200.00
0005433986612	25674	Economy	7200.00
0005433986688	25674	Economy	7200.00
0005433986611	25674	Economy	7200.00
0005433986801	25674	Economy	7200.00
0005435788806	25674	Economy	7200.00
0005433986820	25674	Economy	7200.00
0005435788805	25674	Economy	7200.00
0005433986764	25674	Economy	7200.00
0005433986674	25674	Economy	7200.00
0005433986806	25674	Economy	7200.00
0005433986659	25674	Economy	7200.00
0005433986790	25674	Economy	7200.00
0005433986747	25674	Economy	7200.00
0005433986471	25674	Economy	7200.00
0005435788819	25674	Economy	7200.00
0005433986673	25674	Economy	7200.00
0005433986730	25674	Economy	7200.00
0005433986815	25674	Economy	7200.00
0005433986719	25674	Economy	7200.00
0005433986652	25674	Economy	7200.00
0005433986687	25674	Economy	7200.00
0005433986766	25674	Economy	7200.00
0005433986800	25674	Economy	7200.00
0005433986754	25674	Economy	7200.00
0005433986720	25674	Economy	7200.00
0005433986675	25674	Economy	7200.00
0005435719574	21261	Economy	10400.00
0005435719573	21261	Economy	9400.00
0005435719582	21261	Economy	9400.00
0005435719598	24785	Economy	10400.00
0005435719597	24785	Economy	9400.00
0005435720163	24785	Economy	9400.00
0005435719599	24785	Economy	9400.00
0005434509278	21321	Economy	17000.00
0005434509323	21321	Economy	15500.00
0005433168488	21321	Economy	15500.00
0005434509318	21321	Economy	15500.00
0005433168484	21321	Economy	15500.00
0005434509276	21321	Economy	15500.00
0005433168491	21321	Economy	15500.00
0005434509322	21321	Economy	15500.00
0005433168489	21321	Economy	15500.00
0005433168486	21321	Economy	15500.00
0005434509285	21321	Economy	15500.00
0005434509290	21321	Economy	15500.00
0005434509265	21321	Economy	15500.00
0005434509317	21321	Economy	15500.00
0005434509284	21321	Economy	15500.00
0005434509288	21321	Economy	15500.00
0005433168487	21321	Economy	15500.00
0005433168485	21321	Economy	15500.00
0005434509309	21321	Economy	15500.00
0005433168483	21321	Economy	15500.00
0005433168490	21321	Economy	15500.00
0005432655770	17855	Business	18000.00
0005432869712	17855	Business	18000.00
0005432667496	17855	Business	18000.00
0005434151788	17855	Business	18000.00
0005432664178	17855	Business	18000.00
0005432661963	17855	Business	18000.00
0005432655748	17855	Economy	6000.00
0005432659736	17855	Economy	6000.00
0005432655790	17855	Economy	6000.00
0005432666436	17855	Economy	6600.00
0005432869707	17855	Economy	6000.00
0005432664177	17855	Economy	6000.00
0005432658640	17855	Economy	6000.00
0005434151787	17855	Economy	6000.00
0005432664176	17855	Economy	6000.00
0005432655769	17855	Economy	6000.00
0005432657521	17855	Economy	6000.00
0005432658636	17855	Economy	6000.00
0005432655747	17855	Economy	6000.00
0005432664182	17855	Economy	6000.00
0005432869711	17855	Economy	6000.00
0005432869709	17855	Economy	6000.00
0005432667488	17855	Economy	6000.00
0005432655774	17855	Economy	6000.00
0005432869708	17855	Economy	6000.00
0005432655791	17855	Economy	6000.00
0005432667497	17855	Economy	6000.00
0005432869710	17855	Economy	6000.00
0005432655785	17855	Economy	6000.00
0005432655775	17855	Economy	6000.00
0005432655813	17855	Economy	6000.00
0005432658635	17855	Economy	6000.00
0005432661964	17855	Economy	6000.00
0005432661957	17855	Economy	6000.00
0005432657511	17855	Economy	6000.00
0005432658629	17855	Economy	6000.00
0005432666442	26304	Business	18000.00
0005432655847	26304	Business	18000.00
0005432869625	26304	Business	18000.00
0005432869607	26304	Business	18000.00
0005432655839	26304	Business	18000.00
0005434151754	26304	Economy	6000.00
0005432655843	26304	Economy	6000.00
0005432655848	26304	Economy	6000.00
0005432655851	26304	Economy	6000.00
0005432659762	26304	Economy	6000.00
0005434151765	26304	Economy	6000.00
0005432657530	26304	Economy	6000.00
0005432657531	26304	Economy	6600.00
0005432869624	26304	Economy	6600.00
0005432869626	26304	Economy	6600.00
0005432869608	26304	Economy	6600.00
0005432655849	26304	Economy	6000.00
0005432658647	26304	Economy	6000.00
0005432657532	26304	Economy	6000.00
0005432655846	26304	Economy	6000.00
0005434151767	26304	Economy	6000.00
0005432666443	26304	Economy	6000.00
0005434151764	26304	Economy	6000.00
0005432659761	26304	Economy	6000.00
0005432665330	26304	Economy	6000.00
0005432655845	26304	Economy	6000.00
0005432869646	26304	Economy	6000.00
0005432655844	26304	Economy	6000.00
0005432869634	26304	Economy	6000.00
0005432659763	26304	Economy	6000.00
0005432658646	26304	Economy	6000.00
0005432655841	26304	Economy	6000.00
0005432667510	26304	Economy	6000.00
0005432655842	26304	Economy	6000.00
0005432667509	26304	Economy	6000.00
0005432655840	26304	Economy	6000.00
0005432665328	26304	Economy	6000.00
0005432869623	26304	Economy	6000.00
0005432869609	26304	Economy	6000.00
0005434151766	26304	Economy	6000.00
0005434151763	26304	Economy	6000.00
0005432869647	26304	Economy	6000.00
0005432665329	26304	Economy	6000.00
0005432655850	26304	Economy	6000.00
0005432869653	26304	Economy	6000.00
0005432869660	26304	Economy	6000.00
0005433439080	3089	Business	16100.00
0005432905216	3089	Business	16100.00
0005432329956	3089	Business	16100.00
0005432329953	3089	Business	16100.00
0005432329946	3089	Business	16100.00
0005432329960	3089	Business	16100.00
0005432905252	3089	Economy	5400.00
0005432329940	3089	Economy	5400.00
0005432329961	3089	Economy	5400.00
0005432329951	3089	Economy	5400.00
0005432287329	3089	Economy	5400.00
0005432329970	3089	Economy	5400.00
0005432329943	3089	Economy	5900.00
0005432848881	3089	Economy	5900.00
0005432329942	3089	Economy	5400.00
0005432329952	3089	Economy	5400.00
0005433439081	3089	Economy	5400.00
0005433439085	3089	Economy	5400.00
0005432848880	3089	Economy	5400.00
0005432329944	3089	Economy	5400.00
0005432905251	3089	Economy	5400.00
0005432329955	3089	Economy	5400.00
0005432329962	3089	Economy	5400.00
0005432329968	3089	Economy	5400.00
0005432329941	3089	Economy	5400.00
0005432329967	3089	Economy	5400.00
0005433439078	3089	Economy	5400.00
0005432329959	3089	Economy	5400.00
0005432329947	3089	Economy	5400.00
0005432329949	3089	Economy	5400.00
0005432287330	3089	Economy	5400.00
0005432329963	3089	Economy	5400.00
0005432329965	3089	Economy	5400.00
0005432329954	3089	Economy	5400.00
0005433439084	3089	Economy	5400.00
0005432329973	3089	Economy	5400.00
0005432329964	3089	Economy	5400.00
0005433439079	3089	Economy	5400.00
0005432287328	3089	Economy	5400.00
0005432848858	3089	Economy	5400.00
0005432329958	3089	Economy	5400.00
0005432329945	3089	Economy	5400.00
0005432329966	3089	Economy	5400.00
0005433439083	3089	Economy	5400.00
0005432848866	3089	Economy	5400.00
0005433439082	3089	Economy	5400.00
0005432848859	3089	Economy	5400.00
0005432329971	3089	Economy	5400.00
0005432329972	3089	Economy	5400.00
0005432329950	3089	Economy	5400.00
0005432905265	3089	Economy	5400.00
0005432329948	3089	Economy	5400.00
0005432329969	3089	Economy	5400.00
0005432329957	3089	Economy	5400.00
0005432329648	31134	Business	16100.00
0005432054386	31134	Business	16100.00
0005432329559	31134	Business	16100.00
0005432329593	31134	Business	16100.00
0005432329619	31134	Business	16100.00
0005432329555	31134	Business	16100.00
0005432329551	31134	Business	16100.00
0005432848905	31134	Economy	5400.00
0005432848901	31134	Economy	5400.00
0005432905278	31134	Economy	5400.00
0005432905282	31134	Economy	5400.00
0005432329327	31134	Economy	5400.00
0005432329484	31134	Economy	5400.00
0005432329540	31134	Economy	5900.00
0005432329569	31134	Economy	5900.00
0005432329483	31134	Economy	5400.00
0005433439007	31134	Economy	5400.00
0005433439006	31134	Economy	5400.00
0005432905277	31134	Economy	5400.00
0005432329488	31134	Economy	5400.00
0005432329489	31134	Economy	5400.00
0005432329426	31134	Economy	5400.00
0005432329573	31134	Economy	5400.00
0005432848906	31134	Economy	5400.00
0005432329589	31134	Economy	5400.00
0005432054387	31134	Economy	5400.00
0005432848900	31134	Economy	5400.00
0005432329621	31134	Economy	5400.00
0005432329615	31134	Economy	5400.00
0005432848904	31134	Economy	5400.00
0005432329614	31134	Economy	5400.00
0005433438985	31134	Economy	5400.00
0005432329459	31134	Economy	5400.00
0005432905281	31134	Economy	5400.00
0005432329490	31134	Economy	5400.00
0005432329374	31134	Economy	5400.00
0005432329554	31134	Economy	5400.00
0005432905279	31134	Economy	5400.00
0005432848902	31134	Economy	5400.00
0005432848903	31134	Economy	5400.00
0005432329654	31134	Economy	5400.00
0005432905276	31134	Economy	5400.00
0005433439008	31134	Economy	5400.00
0005432329616	31134	Economy	5400.00
0005432329590	31134	Economy	5400.00
0005432848899	31134	Economy	5400.00
0005432329552	31134	Economy	5400.00
0005432329720	31134	Economy	5400.00
0005432329575	31134	Economy	5400.00
0005432329502	31134	Economy	5400.00
0005432329574	31134	Economy	5400.00
0005433438986	31134	Economy	5400.00
0005432905280	31134	Economy	5400.00
0005432329655	31134	Economy	5400.00
0005432329458	31134	Economy	5400.00
0005432329485	31134	Economy	5400.00
0005433438991	31134	Economy	5400.00
0005433439036	31134	Economy	5400.00
0005432329544	31134	Economy	5400.00
0005432329556	31134	Economy	5400.00
0005432329649	31134	Economy	5400.00
0005432329570	31134	Economy	5400.00
0005435488199	6178	Business	124600.00
0005435488250	6178	Business	124600.00
0005435999778	6178	Business	124600.00
0005435999792	6178	Business	124600.00
0005435488210	6178	Business	124600.00
0005435297184	6178	Business	124600.00
0005435488227	6178	Business	124600.00
0005434310113	6178	Business	124600.00
0005434310112	6178	Business	124600.00
0005435488099	6178	Economy	41500.00
0005435999788	6178	Economy	41500.00
0005435488251	6178	Economy	41500.00
0005435488307	6178	Economy	41500.00
0005435488238	6178	Economy	41500.00
0005435488252	6178	Economy	41500.00
0005435488204	6178	Economy	41500.00
0005435488220	6178	Economy	41500.00
0005435999781	6178	Economy	41500.00
0005435999789	6178	Economy	41500.00
0005435297193	6178	Economy	41500.00
0005435999793	6178	Economy	41500.00
0005435488241	6178	Economy	41500.00
0005435488270	6178	Economy	41500.00
0005435999786	6178	Economy	41500.00
0005435999780	6178	Economy	41500.00
0005435999790	6178	Economy	41500.00
0005435488269	6178	Economy	41500.00
0005432146257	6178	Economy	41500.00
0005434310115	6178	Economy	41500.00
0005435488240	6178	Economy	41500.00
0005435488316	6178	Economy	41500.00
0005435488261	6178	Economy	41500.00
0005434310116	6178	Economy	41500.00
0005435488222	6178	Economy	41500.00
0005435999785	6178	Economy	41500.00
0005435488308	6178	Economy	41500.00
0005434310114	6178	Economy	41500.00
0005435488201	6178	Economy	41500.00
0005434310118	6178	Economy	41500.00
0005434310111	6178	Economy	41500.00
0005434310120	6178	Economy	41500.00
0005435999777	6178	Economy	41500.00
0005435999787	6178	Economy	41500.00
0005435297201	6178	Economy	41500.00
0005435488258	6178	Economy	41500.00
0005435999783	6178	Economy	41500.00
0005435488336	6178	Economy	41500.00
0005432146256	6178	Economy	41500.00
0005434310117	6178	Economy	41500.00
0005435488235	6178	Economy	41500.00
0005434310121	6178	Economy	41500.00
0005435999779	6178	Economy	41500.00
0005435297182	6178	Economy	41500.00
0005435488256	6178	Economy	41500.00
0005435488228	6178	Economy	41500.00
0005435999794	6178	Economy	41500.00
0005435999784	6178	Economy	41500.00
0005435488288	6178	Economy	41500.00
0005435488216	6178	Economy	41500.00
0005435488207	6178	Economy	41500.00
0005435488221	6178	Economy	41500.00
0005435488264	6178	Economy	41500.00
0005435999791	6178	Economy	41500.00
0005435999782	6178	Economy	41500.00
0005435999776	6178	Economy	41500.00
0005434310119	6178	Economy	41500.00
0005434310122	6178	Economy	41500.00
0005435297200	6178	Economy	41500.00
0005435488423	19538	Business	124600.00
0005435297251	19538	Business	124600.00
0005435297250	19538	Business	124600.00
0005435999535	19538	Business	124600.00
0005434310024	19538	Business	124600.00
0005435488404	19538	Business	124600.00
0005434310027	19538	Business	124600.00
0005435999580	19538	Economy	41500.00
0005435488412	19538	Economy	41500.00
0005435488421	19538	Economy	41500.00
0005435488407	19538	Economy	41500.00
0005434310041	19538	Economy	41500.00
0005435297247	19538	Economy	41500.00
0005435999554	19538	Economy	41500.00
0005435999574	19538	Economy	41500.00
0005435999582	19538	Economy	41500.00
0005435297249	19538	Economy	41500.00
0005435999536	19538	Economy	41500.00
0005434309978	19538	Economy	41500.00
0005435488413	19538	Economy	41500.00
0005435999579	19538	Economy	41500.00
0005435999552	19538	Economy	41500.00
0005435999481	19538	Economy	41500.00
0005435488415	19538	Economy	41500.00
0005435488406	19538	Economy	41500.00
0005434310008	19538	Economy	41500.00
0005434310007	19538	Economy	41500.00
0005435999575	19538	Economy	41500.00
0005434309997	19538	Economy	41500.00
0005435999480	19538	Economy	41500.00
0005435488414	19538	Economy	41500.00
0005435999457	19538	Economy	45700.00
0005434309998	19538	Economy	45700.00
0005435999505	19538	Economy	45700.00
0005435488419	19538	Economy	41500.00
0005434309985	19538	Economy	41500.00
0005435999566	19538	Economy	41500.00
0005435297248	19538	Economy	41500.00
0005434310019	19538	Economy	41500.00
0005435488416	19538	Economy	41500.00
0005434310030	19538	Economy	41500.00
0005435488411	19538	Economy	41500.00
0005434310034	19538	Economy	41500.00
0005435488410	19538	Economy	41500.00
0005435999539	19538	Economy	41500.00
0005434309932	19538	Economy	41500.00
0005434310062	19538	Economy	41500.00
0005435999581	19538	Economy	41500.00
0005435999577	19538	Economy	41500.00
0005435488408	19538	Economy	41500.00
0005434309986	19538	Economy	41500.00
0005435488409	19538	Economy	41500.00
0005435999521	19538	Economy	41500.00
0005435488417	19538	Economy	41500.00
0005435999530	19538	Economy	41500.00
0005435488405	19538	Economy	41500.00
0005435999578	19538	Economy	41500.00
0005434309980	19538	Economy	41500.00
0005435488420	19538	Economy	41500.00
0005435488418	19538	Economy	41500.00
0005434309954	19538	Economy	41500.00
0005434310023	19538	Economy	41500.00
0005435488422	19538	Economy	41500.00
0005435999561	19538	Economy	41500.00
0005435999458	19538	Economy	41500.00
0005433158192	17553	Economy	13600.00
0005434446560	17553	Economy	12300.00
0005434446563	17553	Economy	12300.00
0005434446557	17553	Economy	12300.00
0005434446555	17553	Economy	12300.00
0005433157016	17553	Economy	12300.00
0005434446564	17553	Economy	12300.00
0005433157017	17553	Economy	12300.00
0005433158194	17553	Economy	12300.00
0005433158193	17553	Economy	12300.00
0005434446559	17553	Economy	12300.00
0005434446562	17553	Economy	12300.00
0005433157018	17553	Economy	12300.00
0005433158191	17553	Economy	12300.00
0005434446556	17553	Economy	12300.00
0005433186254	1588	Business	86000.00
0005433186295	1588	Business	86000.00
0005435518414	1588	Business	86000.00
0005434566281	1588	Business	86000.00
0005435518412	1588	Business	86000.00
0005435502911	1588	Economy	28700.00
0005435518419	1588	Economy	28700.00
0005433186286	1588	Economy	28700.00
0005435508777	1588	Economy	28700.00
0005435502916	1588	Economy	28700.00
0005434566288	1588	Economy	28700.00
0005435502915	1588	Economy	28700.00
0005435508785	1588	Economy	28700.00
0005434566286	1588	Economy	31500.00
0005435518413	1588	Economy	31500.00
0005435518422	1588	Economy	31500.00
0005435502906	1588	Economy	31500.00
0005435518417	1588	Economy	28700.00
0005435508779	1588	Economy	28700.00
0005435518415	1588	Economy	28700.00
0005435502912	1588	Economy	28700.00
0005435508784	1588	Economy	28700.00
0005434566283	1588	Economy	28700.00
0005434566282	1588	Economy	28700.00
0005435502920	1588	Economy	28700.00
0005435518410	1588	Economy	28700.00
0005435502913	1588	Economy	28700.00
0005434566287	1588	Economy	28700.00
0005435502905	1588	Economy	28700.00
0005435508780	1588	Economy	28700.00
0005435508775	1588	Economy	28700.00
0005435508781	1588	Economy	28700.00
0005435508776	1588	Economy	28700.00
0005435518418	1588	Economy	28700.00
0005435502908	1588	Economy	28700.00
0005435518420	1588	Economy	28700.00
0005435502904	1588	Economy	28700.00
0005435508774	1588	Economy	28700.00
0005434566285	1588	Economy	28700.00
0005435502909	1588	Economy	28700.00
0005435502919	1588	Economy	28700.00
0005432291997	1588	Economy	28700.00
0005435508772	1588	Economy	28700.00
0005433186287	1588	Economy	28700.00
0005434566284	1588	Economy	28700.00
0005435518411	1588	Economy	28700.00
0005435502907	1588	Economy	28700.00
0005435518421	1588	Economy	28700.00
0005435508778	1588	Economy	28700.00
0005432291998	1588	Economy	28700.00
0005433186285	1588	Economy	28700.00
0005435502914	1588	Economy	28700.00
0005435508782	1588	Economy	28700.00
0005435508787	1588	Economy	28700.00
0005435518409	1588	Economy	28700.00
0005435508773	1588	Economy	28700.00
0005435502922	1588	Economy	28700.00
0005435502921	1588	Economy	28700.00
0005435502918	1588	Economy	28700.00
0005435502910	1588	Economy	28700.00
0005435502917	1588	Economy	28700.00
0005435508786	1588	Economy	28700.00
0005435518416	1588	Economy	28700.00
0005435508783	1588	Economy	28700.00
0005434566208	20890	Business	86000.00
0005435502736	20890	Business	86000.00
0005435529710	20890	Business	86000.00
0005435545863	20890	Business	86000.00
0005435529645	20890	Business	86000.00
0005435502715	20890	Business	86000.00
0005435502660	20890	Business	86000.00
0005435529677	20890	Business	86000.00
0005435529529	20890	Business	86000.00
0005435502714	20890	Business	86000.00
0005435529658	20890	Business	86000.00
0005435502672	20890	Economy	28700.00
0005434566230	20890	Economy	28700.00
0005435502764	20890	Economy	28700.00
0005433186355	20890	Economy	28700.00
0005435529671	20890	Economy	28700.00
0005435529618	20890	Economy	28700.00
0005435529678	20890	Economy	28700.00
0005435529655	20890	Economy	28700.00
0005435502681	20890	Economy	28700.00
0005435502671	20890	Economy	28700.00
0005435529527	20890	Economy	31500.00
0005434566162	20890	Economy	31500.00
0005435502716	20890	Economy	31500.00
0005435529537	20890	Economy	31500.00
0005435529610	20890	Economy	31500.00
0005435502750	20890	Economy	28700.00
0005434566167	20890	Economy	28700.00
0005435529612	20890	Economy	28700.00
0005434566146	20890	Economy	28700.00
0005435502668	20890	Economy	28700.00
0005435529590	20890	Economy	28700.00
0005435529676	20890	Economy	28700.00
0005435545858	20890	Economy	28700.00
0005435529602	20890	Economy	28700.00
0005433186354	20890	Economy	28700.00
0005433186356	20890	Economy	28700.00
0005435529631	20890	Economy	28700.00
0005435529589	20890	Economy	28700.00
0005435529636	20890	Economy	28700.00
0005435529643	20890	Economy	28700.00
0005435502728	20890	Economy	28700.00
0005434566200	20890	Economy	28700.00
0005435529703	20890	Economy	28700.00
0005435529564	20890	Economy	28700.00
0005435529528	20890	Economy	28700.00
0005434566176	20890	Economy	28700.00
0005435529725	20890	Economy	28700.00
0005433186353	20890	Economy	28700.00
0005435502765	20890	Economy	28700.00
0005435529637	20890	Economy	28700.00
0005435502831	20890	Economy	28700.00
0005435529709	20890	Economy	28700.00
0005435502717	20890	Economy	28700.00
0005435529630	20890	Economy	28700.00
0005433186357	20890	Economy	28700.00
0005435502625	20890	Economy	28700.00
0005435545857	20890	Economy	28700.00
0005434566145	20890	Economy	28700.00
0005435502682	20890	Economy	28700.00
0005434566141	20890	Economy	28700.00
0005435545862	20890	Economy	28700.00
0005435545849	20890	Economy	28700.00
0005434566204	20890	Economy	28700.00
0005433186352	20890	Economy	28700.00
0005435529613	20890	Economy	28700.00
0005435529663	20890	Economy	28700.00
0005435529644	20890	Economy	28700.00
0005435545856	20890	Economy	28700.00
0005435529672	20890	Economy	28700.00
0005435502741	20890	Economy	28700.00
0005435502667	20890	Economy	28700.00
0005435529617	20890	Economy	28700.00
0005434566184	20890	Economy	28700.00
0005435529586	20890	Economy	28700.00
0005435545866	20890	Economy	28700.00
0005435529619	20890	Economy	28700.00
0005435545854	20890	Economy	28700.00
0005435545855	20890	Economy	28700.00
0005435529530	20890	Economy	28700.00
0005435502729	20890	Economy	28700.00
0005435529588	20890	Economy	28700.00
0005435529697	20890	Economy	28700.00
0005435502730	20890	Economy	28700.00
0005435529536	20890	Economy	28700.00
0005435502713	20890	Economy	28700.00
0005435502771	20890	Economy	28700.00
0005435502751	20890	Economy	28700.00
0005435529600	20890	Economy	28700.00
0005435153928	3878	Economy	19700.00
0005435153925	3878	Economy	19700.00
0005435931654	3878	Economy	19700.00
0005435142996	3878	Economy	19700.00
0005435153927	3878	Economy	19700.00
0005435142997	3878	Economy	19700.00
0005435153924	3878	Economy	19700.00
0005435153926	3878	Economy	19700.00
0005435153923	3878	Economy	19700.00
0005435153865	21891	Economy	21600.00
0005435931704	21891	Economy	21600.00
0005435153888	21891	Economy	19700.00
0005435153846	21891	Economy	19700.00
0005435931703	21891	Economy	19700.00
0005435931706	21891	Economy	19700.00
0005435931705	21891	Economy	19700.00
0005435153879	21891	Economy	19700.00
0005435153850	21891	Economy	19700.00
0005435153852	21891	Economy	19700.00
0005435153876	21891	Economy	19700.00
0005435153893	21891	Economy	19700.00
0005435153851	21891	Economy	19700.00
0005432629256	7219	Economy	14300.00
0005435225727	7219	Economy	14300.00
0005435225739	7219	Economy	13000.00
0005435225736	7219	Economy	13000.00
0005435225741	7219	Economy	13000.00
0005432629255	7219	Economy	13000.00
0005432629254	7219	Economy	13000.00
0005435225771	7219	Economy	13000.00
0005432629253	7219	Economy	13000.00
0005435225728	7219	Economy	13000.00
0005435225742	7219	Economy	13000.00
0005432629250	7219	Economy	13000.00
0005432629249	7219	Economy	13000.00
0005435225762	7219	Economy	13000.00
0005432629251	7219	Economy	13000.00
0005435225729	7219	Economy	13000.00
0005432629257	7219	Economy	13000.00
0005432629252	7219	Economy	13000.00
0005435225761	7219	Economy	13000.00
0005435225749	7219	Economy	13000.00
0005432629258	7219	Economy	13000.00
0005435225748	7219	Economy	13000.00
0005435225746	7219	Economy	13000.00
0005435225747	7219	Economy	13000.00
0005435225804	28122	Economy	14300.00
0005432629127	28122	Economy	13000.00
0005432629110	28122	Economy	13000.00
0005432629169	28122	Economy	13000.00
0005432629139	28122	Economy	13000.00
0005432629168	28122	Economy	13000.00
0005435225803	28122	Economy	13000.00
0005435225802	28122	Economy	13000.00
0005432629113	28122	Economy	13000.00
0005432629154	28122	Economy	13000.00
0005435225799	28122	Economy	13000.00
0005432629120	28122	Economy	13000.00
0005432629071	28122	Economy	13000.00
0005435225801	28122	Economy	13000.00
0005432629164	28122	Economy	13000.00
0005432629129	28122	Economy	13000.00
0005435225800	28122	Economy	13000.00
0005432629218	28122	Economy	13000.00
0005432629153	28122	Economy	13000.00
0005434268027	8757	Economy	10500.00
0005434268019	8757	Economy	10500.00
0005434268012	8757	Economy	10500.00
0005434268020	8757	Economy	10500.00
0005434268028	8757	Economy	10500.00
0005435960155	8757	Economy	10500.00
0005434268030	8757	Economy	10500.00
0005434268055	15232	Economy	10500.00
0005435960136	15232	Economy	10500.00
0005435960129	15232	Economy	10500.00
0005435960124	15232	Economy	10500.00
0005434268054	15232	Economy	10500.00
0005432693896	1163	Business	115000.00
0005432677678	1163	Business	115000.00
0005432693893	1163	Business	115000.00
0005432693898	1163	Business	115000.00
0005432873412	1163	Business	115000.00
0005432693895	1163	Business	115000.00
0005432873456	1163	Economy	38300.00
0005432873430	1163	Economy	38300.00
0005432675556	1163	Economy	38300.00
0005432693877	1163	Economy	38300.00
0005432693881	1163	Economy	38300.00
0005432693876	1163	Economy	38300.00
0005432693884	1163	Economy	38300.00
0005432873422	1163	Economy	38300.00
0005432693885	1163	Economy	42200.00
0005432693902	1163	Economy	38300.00
0005432675546	1163	Economy	38300.00
0005432677679	1163	Economy	38300.00
0005432693894	1163	Economy	38300.00
0005432693879	1163	Economy	38300.00
0005432693897	1163	Economy	38300.00
0005432873409	1163	Economy	38300.00
0005432675544	1163	Economy	38300.00
0005432693886	1163	Economy	38300.00
0005432693878	1163	Economy	38300.00
0005432693880	1163	Economy	38300.00
0005432693890	1163	Economy	38300.00
0005432873450	1163	Economy	38300.00
0005432675547	1163	Economy	38300.00
0005432693887	1163	Economy	38300.00
0005432693883	1163	Economy	38300.00
0005432675555	1163	Economy	38300.00
0005432675552	1163	Economy	38300.00
0005432693882	1163	Economy	38300.00
0005432693891	1163	Economy	38300.00
0005432677680	1163	Economy	38300.00
0005432675553	1163	Economy	38300.00
0005432693901	1163	Economy	38300.00
0005432675545	1163	Economy	38300.00
0005432693888	1163	Economy	38300.00
0005432873413	1163	Economy	38300.00
0005432675550	1163	Economy	38300.00
0005432693889	1163	Economy	38300.00
0005432675549	1163	Economy	38300.00
0005432675548	1163	Economy	38300.00
0005432693900	1163	Economy	38300.00
0005432693899	1163	Economy	38300.00
0005432873455	1163	Economy	38300.00
0005432675554	1163	Economy	38300.00
0005432675551	1163	Economy	38300.00
0005432873431	1163	Economy	38300.00
0005432693892	1163	Economy	38300.00
0005432873486	17507	Business	115000.00
0005432675416	17507	Business	115000.00
0005432675440	17507	Business	115000.00
0005432675496	17507	Business	115000.00
0005432693631	17507	Business	115000.00
0005432693582	17507	Business	115000.00
0005432693757	17507	Business	115000.00
0005432675419	17507	Business	115000.00
0005432693651	17507	Business	115000.00
0005432693608	17507	Business	115000.00
0005432677651	17507	Business	115000.00
0005432693684	17507	Business	115000.00
0005432693624	17507	Economy	38300.00
0005432693576	17507	Economy	38300.00
0005432693667	17507	Economy	38300.00
0005432677662	17507	Economy	38300.00
0005432693617	17507	Economy	38300.00
0005432873487	17507	Economy	38300.00
0005432675495	17507	Economy	38300.00
0005432677663	17507	Economy	38300.00
0005432675441	17507	Economy	38300.00
0005432675399	17507	Economy	42200.00
0005432693444	17507	Economy	42200.00
0005432693711	17507	Economy	42200.00
0005432693653	17507	Economy	38300.00
0005432693675	17507	Economy	38300.00
0005432675429	17507	Economy	38300.00
0005432693693	17507	Economy	38300.00
0005432675404	17507	Economy	38300.00
0005432693521	17507	Economy	38300.00
0005432675430	17507	Economy	38300.00
0005432693584	17507	Economy	38300.00
0005432675359	17507	Economy	38300.00
0005432675398	17507	Economy	38300.00
0005432693538	17507	Economy	38300.00
0005432693760	17507	Economy	38300.00
0005432693591	17507	Economy	38300.00
0005432693445	17507	Economy	38300.00
0005432693750	17507	Economy	38300.00
0005432873485	17507	Economy	38300.00
0005432693666	17507	Economy	38300.00
0005432693632	17507	Economy	38300.00
0005432693655	17507	Economy	38300.00
0005432693577	17507	Economy	38300.00
0005432693660	17507	Economy	38300.00
0005432693716	17507	Economy	38300.00
0005432693683	17507	Economy	38300.00
0005432693650	17507	Economy	38300.00
0005432693717	17507	Economy	38300.00
0005432693446	17507	Economy	38300.00
0005432675481	17507	Economy	38300.00
0005432693607	17507	Economy	38300.00
0005432693659	17507	Economy	38300.00
0005432693656	17507	Economy	38300.00
0005432693522	17507	Economy	38300.00
0005432675482	17507	Economy	38300.00
0005432693756	17507	Economy	38300.00
0005432675497	17507	Economy	38300.00
0005432675468	17507	Economy	38300.00
0005432693554	17507	Economy	38300.00
0005432675439	17507	Economy	38300.00
0005432675434	17507	Economy	38300.00
0005432675433	17507	Economy	38300.00
0005432693694	17507	Economy	38300.00
0005432693687	17507	Economy	38300.00
0005432675435	17507	Economy	38300.00
0005432675436	17507	Economy	38300.00
0005432677656	17507	Economy	38300.00
0005432675412	17507	Economy	38300.00
0005432675428	17507	Economy	38300.00
0005432675358	17507	Economy	38300.00
0005432873484	17507	Economy	38300.00
0005434435603	1102	Economy	15200.00
0005434435602	1102	Economy	15200.00
0005433156916	1102	Economy	13900.00
0005433156931	1102	Economy	13900.00
0005434435612	1102	Economy	13900.00
0005434435610	1102	Economy	13900.00
0005434435604	1102	Economy	13900.00
0005433156917	1102	Economy	13900.00
0005434435608	1102	Economy	13900.00
0005434435607	1102	Economy	13900.00
0005434435611	1102	Economy	13900.00
0005434435613	1102	Economy	13900.00
0005433156951	1102	Economy	13900.00
0005434435601	1102	Economy	13900.00
0005434435605	1102	Economy	13900.00
0005434435606	1102	Economy	13900.00
0005434435609	1102	Economy	13900.00
0005433156950	1102	Economy	13900.00
0005433156986	17294	Economy	15200.00
0005434435481	17294	Economy	15200.00
0005433156994	17294	Economy	13900.00
0005434435494	17294	Economy	13900.00
0005434435509	17294	Economy	13900.00
0005434435492	17294	Economy	13900.00
0005434435488	17294	Economy	13900.00
0005434435495	17294	Economy	13900.00
0005434435508	17294	Economy	13900.00
0005433156987	17294	Economy	13900.00
0005433156992	17294	Economy	13900.00
0005433156993	17294	Economy	13900.00
0005434435465	17294	Economy	13900.00
0005434435418	17294	Economy	13900.00
0005434435489	17294	Economy	13900.00
0005433156990	17294	Economy	13900.00
0005433156989	17294	Economy	13900.00
0005434435466	17294	Economy	13900.00
0005434435484	17294	Economy	13900.00
0005434435507	17294	Economy	13900.00
0005433156988	17294	Economy	13900.00
0005433156991	17294	Economy	13900.00
0005435087037	4059	Economy	8200.00
0005435928221	4059	Economy	8200.00
0005435928245	4059	Economy	7500.00
0005435087039	4059	Economy	7500.00
0005435087040	4059	Economy	7500.00
0005435087042	4059	Economy	7500.00
0005435087044	4059	Economy	7500.00
0005435928238	4059	Economy	7500.00
0005435087043	4059	Economy	7500.00
0005435928220	4059	Economy	7500.00
0005435087038	4059	Economy	7500.00
0005435087041	4059	Economy	7500.00
0005435086951	24382	Economy	7500.00
0005435928275	24382	Economy	7500.00
0005435086985	24382	Economy	7500.00
0005435928278	24382	Economy	7500.00
0005435086982	24382	Economy	7500.00
0005435928279	24382	Economy	7500.00
0005435086986	24382	Economy	7500.00
0005435086987	24382	Economy	7500.00
0005435087004	24382	Economy	7500.00
0005435928277	24382	Economy	7500.00
0005435928276	24382	Economy	7500.00
0005433373662	2452	Business	86800.00
0005435706832	2452	Business	86800.00
0005435706837	2452	Business	86800.00
0005433373715	2452	Business	86800.00
0005433373690	2452	Business	86800.00
0005433373698	2452	Business	86800.00
0005435706817	2452	Business	86800.00
0005435706826	2452	Business	86800.00
0005435706836	2452	Economy	28900.00
0005433373701	2452	Economy	28900.00
0005435706810	2452	Economy	28900.00
0005435706829	2452	Economy	28900.00
0005435706842	2452	Economy	28900.00
0005433373664	2452	Economy	28900.00
0005435706821	2452	Economy	28900.00
0005433373692	2452	Economy	31800.00
0005435706840	2452	Economy	31800.00
0005435706812	2452	Economy	31800.00
0005435706803	2452	Economy	31800.00
0005433373700	2452	Economy	31800.00
0005435706844	2452	Economy	28900.00
0005433373676	2452	Economy	28900.00
0005433373655	2452	Economy	28900.00
0005433373693	2452	Economy	28900.00
0005433373719	2452	Economy	28900.00
0005435706834	2452	Economy	28900.00
0005435706824	2452	Economy	28900.00
0005433373708	2452	Economy	28900.00
0005435706838	2452	Economy	28900.00
0005433373705	2452	Economy	28900.00
0005435706828	2452	Economy	28900.00
0005435706827	2452	Economy	28900.00
0005435706807	2452	Economy	28900.00
0005435706804	2452	Economy	28900.00
0005435706802	2452	Economy	28900.00
0005433373707	2452	Economy	28900.00
0005435706843	2452	Economy	28900.00
0005433373699	2452	Economy	28900.00
0005435706805	2452	Economy	28900.00
0005435706815	2452	Economy	28900.00
0005435706822	2452	Economy	28900.00
0005433373726	2452	Economy	28900.00
0005435706833	2452	Economy	28900.00
0005435706808	2452	Economy	28900.00
0005435706811	2452	Economy	28900.00
0005433373677	2452	Economy	28900.00
0005435706830	2452	Economy	28900.00
0005435706839	2452	Economy	28900.00
0005435706841	2452	Economy	28900.00
0005433373704	2452	Economy	28900.00
0005433373722	2452	Economy	28900.00
0005435706806	2452	Economy	28900.00
0005435706809	2452	Economy	28900.00
0005435706825	2452	Economy	28900.00
0005435706831	2452	Economy	28900.00
0005435706819	2452	Economy	28900.00
0005435706820	2452	Economy	28900.00
0005433373729	2452	Economy	28900.00
0005435706813	2452	Economy	28900.00
0005435706816	2452	Economy	28900.00
0005435706835	2452	Economy	28900.00
0005435706818	2452	Economy	28900.00
0005433373653	2452	Economy	28900.00
0005435706814	2452	Economy	28900.00
0005433373643	2452	Economy	28900.00
0005435706823	2452	Economy	28900.00
0005433373697	2452	Economy	28900.00
0005435706801	2452	Economy	28900.00
0005433373780	27023	Business	86800.00
0005435706678	27023	Business	86800.00
0005435706689	27023	Business	86800.00
0005435706716	27023	Business	86800.00
0005435706693	27023	Business	86800.00
0005435706749	27023	Business	86800.00
0005435706661	27023	Business	86800.00
0005435706618	27023	Business	86800.00
0005435706756	27023	Business	86800.00
0005435706634	27023	Economy	28900.00
0005435706619	27023	Economy	28900.00
0005435706673	27023	Economy	28900.00
0005435706635	27023	Economy	28900.00
0005435706748	27023	Economy	28900.00
0005435706683	27023	Economy	28900.00
0005433373786	27023	Economy	28900.00
0005435706643	27023	Economy	28900.00
0005433373777	27023	Economy	31800.00
0005433373766	27023	Economy	31800.00
0005435706715	27023	Economy	31800.00
0005435706688	27023	Economy	31800.00
0005433373779	27023	Economy	28900.00
0005433373773	27023	Economy	28900.00
0005435706662	27023	Economy	28900.00
0005435706654	27023	Economy	28900.00
0005433373776	27023	Economy	28900.00
0005435706658	27023	Economy	28900.00
0005433373782	27023	Economy	28900.00
0005435706641	27023	Economy	28900.00
0005433373769	27023	Economy	28900.00
0005435706660	27023	Economy	28900.00
0005435706685	27023	Economy	28900.00
0005435706655	27023	Economy	28900.00
0005433373781	27023	Economy	28900.00
0005435706628	27023	Economy	28900.00
0005433373767	27023	Economy	28900.00
0005435706725	27023	Economy	28900.00
0005435706627	27023	Economy	28900.00
0005433373787	27023	Economy	28900.00
0005433373772	27023	Economy	28900.00
0005435706701	27023	Economy	28900.00
0005435706750	27023	Economy	28900.00
0005435706617	27023	Economy	28900.00
0005435706679	27023	Economy	28900.00
0005435706703	27023	Economy	28900.00
0005433373784	27023	Economy	28900.00
0005433373771	27023	Economy	28900.00
0005435706659	27023	Economy	28900.00
0005435706657	27023	Economy	28900.00
0005433373774	27023	Economy	28900.00
0005435706645	27023	Economy	28900.00
0005435706656	27023	Economy	28900.00
0005435706682	27023	Economy	28900.00
0005435706704	27023	Economy	28900.00
0005433373770	27023	Economy	28900.00
0005433373778	27023	Economy	28900.00
0005435706691	27023	Economy	28900.00
0005433373785	27023	Economy	28900.00
0005435706646	27023	Economy	28900.00
0005435706644	27023	Economy	28900.00
0005433373783	27023	Economy	28900.00
0005435706757	27023	Economy	28900.00
0005433373768	27023	Economy	28900.00
0005433373775	27023	Economy	28900.00
0005435706670	27023	Economy	28900.00
0005435706714	27023	Economy	28900.00
0005435706642	27023	Economy	28900.00
0005435706727	27023	Economy	28900.00
0005435907599	4863	Business	44200.00
0005435907602	4863	Business	44200.00
0005433194893	4863	Economy	14700.00
0005434626221	4863	Economy	14700.00
0005435907615	4863	Economy	16200.00
0005434626225	4863	Economy	14700.00
0005434626222	4863	Economy	14700.00
0005435907600	4863	Economy	14700.00
0005433194900	4863	Economy	14700.00
0005434626224	4863	Economy	14700.00
0005433194892	4863	Economy	14700.00
0005434626220	4863	Economy	14700.00
0005433194898	4863	Economy	14700.00
0005433194901	4863	Economy	14700.00
0005434626223	4863	Economy	14700.00
0005433194902	4863	Economy	14700.00
0005434626153	32889	Business	44200.00
0005434626145	32889	Business	44200.00
0005435907642	32889	Business	44200.00
0005433194966	32889	Economy	14700.00
0005433194968	32889	Economy	14700.00
0005434626140	32889	Economy	14700.00
0005433194972	32889	Economy	16200.00
0005433194969	32889	Economy	16200.00
0005435907643	32889	Economy	16200.00
0005433194967	32889	Economy	14700.00
0005433194973	32889	Economy	14700.00
0005433194965	32889	Economy	14700.00
0005434626175	32889	Economy	14700.00
0005435907645	32889	Economy	14700.00
0005433194964	32889	Economy	14700.00
0005433194961	32889	Economy	14700.00
0005434626141	32889	Economy	14700.00
0005433194971	32889	Economy	14700.00
0005433194963	32889	Economy	14700.00
0005435907644	32889	Economy	14700.00
0005433194962	32889	Economy	14700.00
0005433194970	32889	Economy	14700.00
0005434626123	32889	Economy	14700.00
0005434626124	32889	Economy	14700.00
0005433194974	32889	Economy	14700.00
0005433194975	32889	Economy	14700.00
0005432195752	13771	Economy	3400.00
0005435786014	13771	Economy	3400.00
0005435937542	13771	Economy	3400.00
0005435786099	13771	Economy	3400.00
0005435937543	13771	Economy	3100.00
0005435786003	13771	Economy	3100.00
0005435785952	13771	Economy	3100.00
0005435785935	13771	Economy	3100.00
0005435785972	13771	Economy	3100.00
0005435787392	13771	Economy	3100.00
0005435937544	13771	Economy	3100.00
0005435786004	13771	Economy	3100.00
0005435786023	13771	Economy	3100.00
0005435786012	13771	Economy	3100.00
0005435785995	13771	Economy	3100.00
0005435785985	13771	Economy	3100.00
0005435785869	13771	Economy	3100.00
0005435785993	13771	Economy	3100.00
0005435785870	13771	Economy	3100.00
0005435785954	13771	Economy	3100.00
0005435937547	13771	Economy	3100.00
0005432195753	13771	Economy	3100.00
0005435785986	13771	Economy	3100.00
0005435785772	13771	Economy	3100.00
0005435786013	13771	Economy	3100.00
0005435786100	13771	Economy	3100.00
0005435937546	13771	Economy	3100.00
0005435785955	13771	Economy	3100.00
0005435786101	13771	Economy	3100.00
0005435785868	13771	Economy	3100.00
0005435937545	13771	Economy	3100.00
0005435785885	13771	Economy	3100.00
0005435785916	13771	Economy	3100.00
0005435937548	13771	Economy	3100.00
0005435785842	13771	Economy	3100.00
0005435785915	13771	Economy	3100.00
0005435786025	13771	Economy	3100.00
0005435785910	13771	Economy	3100.00
0005435786024	13771	Economy	3100.00
0005435785841	13771	Economy	3100.00
0005435785953	13771	Economy	3100.00
0005435786255	27435	Economy	3400.00
0005432190729	27435	Economy	3400.00
0005435786279	27435	Economy	3400.00
0005435937448	27435	Economy	3400.00
0005435786277	27435	Economy	3100.00
0005435937455	27435	Economy	3100.00
0005435786265	27435	Economy	3100.00
0005435786269	27435	Economy	3100.00
0005435786268	27435	Economy	3100.00
0005435786251	27435	Economy	3100.00
0005435786274	27435	Economy	3100.00
0005435786278	27435	Economy	3100.00
0005435786253	27435	Economy	3100.00
0005435787411	27435	Economy	3100.00
0005435786267	27435	Economy	3100.00
0005435786275	27435	Economy	3100.00
0005435786249	27435	Economy	3100.00
0005435786264	27435	Economy	3100.00
0005435937481	27435	Economy	3100.00
0005435786262	27435	Economy	3100.00
0005432190730	27435	Economy	3100.00
0005435786271	27435	Economy	3100.00
0005435786256	27435	Economy	3100.00
0005435786250	27435	Economy	3100.00
0005435937456	27435	Economy	3100.00
0005435786273	27435	Economy	3100.00
0005435786257	27435	Economy	3100.00
0005435787410	27435	Economy	3100.00
0005432190732	27435	Economy	3100.00
0005435786261	27435	Economy	3100.00
0005435786252	27435	Economy	3100.00
0005435786254	27435	Economy	3100.00
0005435786260	27435	Economy	3100.00
0005432190731	27435	Economy	3100.00
0005435786259	27435	Economy	3100.00
0005435786280	27435	Economy	3100.00
0005435786276	27435	Economy	3100.00
0005435786266	27435	Economy	3100.00
0005435786258	27435	Economy	3100.00
0005435786281	27435	Economy	3100.00
0005435786263	27435	Economy	3100.00
0005435786270	27435	Economy	3100.00
0005435786272	27435	Economy	3100.00
0005434408904	20263	Business	12000.00
0005434408840	20263	Business	12000.00
0005434409033	20263	Business	12000.00
0005434408820	20263	Business	12000.00
0005435311484	20263	Business	12000.00
0005435311503	20263	Business	12000.00
0005434409055	20263	Business	12000.00
0005434409135	20263	Business	12000.00
0005434409151	20263	Business	12000.00
0005435311491	20263	Business	12000.00
0005435311498	20263	Business	12000.00
0005434408520	20263	Business	12000.00
0005434409152	20263	Economy	4000.00
0005434409153	20263	Economy	4000.00
0005434408939	20263	Economy	4000.00
0005432058491	20263	Economy	4000.00
0005432058490	20263	Economy	4000.00
0005435311487	20263	Economy	4000.00
0005434409091	20263	Economy	4000.00
0005434409007	20263	Economy	4000.00
0005434409141	20263	Economy	4000.00
0005434408956	20263	Economy	4000.00
0005434409056	20263	Economy	4400.00
0005435311489	20263	Economy	4400.00
0005435311494	20263	Economy	4400.00
0005434408902	20263	Economy	4400.00
0005434409120	20263	Economy	4000.00
0005435311493	20263	Economy	4000.00
0005434408618	20263	Economy	4000.00
0005435311477	20263	Economy	4000.00
0005434408807	20263	Economy	4000.00
0005434409147	20263	Economy	4000.00
0005434409302	20263	Economy	4000.00
0005434409018	20263	Economy	4000.00
0005434408677	20263	Economy	4000.00
0005434409125	20263	Economy	4000.00
0005435311496	20263	Economy	4000.00
0005434408929	20263	Economy	4000.00
0005435311488	20263	Economy	4000.00
0005435311485	20263	Economy	4000.00
0005434409090	20263	Economy	4000.00
0005434409034	20263	Economy	4000.00
0005434409148	20263	Economy	4000.00
0005435311480	20263	Economy	4000.00
0005435311486	20263	Economy	4000.00
0005434408920	20263	Economy	4000.00
0005435311482	20263	Economy	4000.00
0005434408850	20263	Economy	4000.00
0005434408678	20263	Economy	4000.00
0005434408903	20263	Economy	4000.00
0005434408617	20263	Economy	4000.00
0005434409241	20263	Economy	4000.00
0005434408819	20263	Economy	4000.00
0005435311502	20263	Economy	4000.00
0005434408916	20263	Economy	4000.00
0005434408948	20263	Economy	4000.00
0005435311497	20263	Economy	4000.00
0005434408875	20263	Economy	4000.00
0005435311501	20263	Economy	4000.00
0005435311500	20263	Economy	4000.00
0005434408917	20263	Economy	4000.00
0005432058492	20263	Economy	4000.00
0005435311479	20263	Economy	4000.00
0005435311481	20263	Economy	4000.00
0005435311478	20263	Economy	4000.00
0005434409162	20263	Economy	4000.00
0005435311499	20263	Economy	4000.00
0005434408785	20263	Economy	4000.00
0005434408892	20263	Economy	4000.00
0005434408930	20263	Economy	4000.00
0005432058493	20263	Economy	4000.00
0005434409119	20263	Economy	4000.00
0005434409011	20263	Economy	4000.00
0005435311483	20263	Economy	4000.00
0005435311492	20263	Economy	4000.00
0005434408876	20263	Economy	4000.00
0005434408941	20263	Economy	4000.00
0005434408983	20263	Economy	4000.00
0005434408808	20263	Economy	4000.00
0005434409057	20263	Economy	4000.00
0005435311490	20263	Economy	4000.00
0005434409161	20263	Economy	4000.00
0005434408938	20263	Economy	4000.00
0005434408839	20263	Economy	4000.00
0005434408701	20263	Economy	4000.00
0005434408856	20263	Economy	4000.00
0005435311495	20263	Economy	4000.00
0005434409006	20263	Economy	4000.00
0005434409165	20263	Economy	4000.00
0005434409019	20263	Economy	4000.00
0005434409010	20263	Economy	4000.00
0005434408835	20263	Economy	4000.00
0005434409496	26979	Business	12000.00
0005434409488	26979	Business	12000.00
0005435311296	26979	Business	12000.00
0005435311282	26979	Business	12000.00
0005434409465	26979	Business	12000.00
0005435311319	26979	Business	12000.00
0005435311413	26979	Business	12000.00
0005434409489	26979	Business	12000.00
0005435311261	26979	Economy	4000.00
0005434409501	26979	Economy	4000.00
0005434409479	26979	Economy	4000.00
0005434409478	26979	Economy	4000.00
0005434409490	26979	Economy	4000.00
0005434409486	26979	Economy	4000.00
0005435311273	26979	Economy	4000.00
0005435311287	26979	Economy	4000.00
0005434409483	26979	Economy	4000.00
0005434409468	26979	Economy	4400.00
0005434409480	26979	Economy	4400.00
0005435311291	26979	Economy	4400.00
0005435311330	26979	Economy	4400.00
0005435311256	26979	Economy	4000.00
0005434409461	26979	Economy	4000.00
0005435311312	26979	Economy	4000.00
0005434409497	26979	Economy	4000.00
0005435311260	26979	Economy	4000.00
0005434409492	26979	Economy	4000.00
0005434409460	26979	Economy	4000.00
0005432154132	26979	Economy	4000.00
0005434409476	26979	Economy	4000.00
0005435311275	26979	Economy	4000.00
0005435311365	26979	Economy	4000.00
0005434409484	26979	Economy	4000.00
0005432154128	26979	Economy	4000.00
0005435311272	26979	Economy	4000.00
0005434409487	26979	Economy	4000.00
0005434409471	26979	Economy	4000.00
0005435311250	26979	Economy	4000.00
0005434409472	26979	Economy	4000.00
0005434409482	26979	Economy	4000.00
0005432154130	26979	Economy	4000.00
0005434409463	26979	Economy	4000.00
0005435311243	26979	Economy	4000.00
0005434409475	26979	Economy	4000.00
0005434409474	26979	Economy	4000.00
0005434409470	26979	Economy	4000.00
0005434409477	26979	Economy	4000.00
0005435311412	26979	Economy	4000.00
0005434409493	26979	Economy	4000.00
0005434409495	26979	Economy	4000.00
0005434409462	26979	Economy	4000.00
0005434409498	26979	Economy	4000.00
0005434409473	26979	Economy	4000.00
0005434409467	26979	Economy	4000.00
0005435311290	26979	Economy	4000.00
0005434409500	26979	Economy	4000.00
0005434409485	26979	Economy	4000.00
0005432154129	26979	Economy	4000.00
0005434409481	26979	Economy	4000.00
0005434409499	26979	Economy	4000.00
0005434409491	26979	Economy	4000.00
0005435311374	26979	Economy	4000.00
0005435311241	26979	Economy	4000.00
0005435311283	26979	Economy	4000.00
0005435311336	26979	Economy	4000.00
0005435311266	26979	Economy	4000.00
0005434409469	26979	Economy	4000.00
0005434409464	26979	Economy	4000.00
0005435311267	26979	Economy	4000.00
0005435311318	26979	Economy	4000.00
0005434409494	26979	Economy	4000.00
0005432154131	26979	Economy	4000.00
0005434409466	26979	Economy	4000.00
0005435311314	26979	Economy	4000.00
0005433124299	5707	Business	43300.00
0005434319794	5707	Business	43300.00
0005433124330	5707	Business	43300.00
0005432109779	5707	Business	43300.00
0005434319796	5707	Business	43300.00
0005433124307	5707	Business	43300.00
0005434311275	5707	Business	43300.00
0005434319798	5707	Business	43300.00
0005433124328	5707	Business	43300.00
0005434319801	5707	Economy	14400.00
0005434319804	5707	Economy	14400.00
0005433124316	5707	Economy	14400.00
0005433124262	5707	Economy	14400.00
0005434319787	5707	Economy	14400.00
0005434319806	5707	Economy	15900.00
0005434319791	5707	Economy	15900.00
0005433124317	5707	Economy	15900.00
0005435297353	5707	Economy	15900.00
0005434319800	5707	Economy	14400.00
0005434319786	5707	Economy	14400.00
0005433124247	5707	Economy	14400.00
0005434319805	5707	Economy	14400.00
0005434319792	5707	Economy	14400.00
0005433124344	5707	Economy	14400.00
0005433124231	5707	Economy	14400.00
0005434319789	5707	Economy	14400.00
0005433124306	5707	Economy	14400.00
0005435297362	5707	Economy	14400.00
0005433124261	5707	Economy	14400.00
0005433124311	5707	Economy	14400.00
0005433124245	5707	Economy	14400.00
0005434319793	5707	Economy	14400.00
0005433124375	5707	Economy	14400.00
0005434319797	5707	Economy	14400.00
0005434319799	5707	Economy	14400.00
0005433124310	5707	Economy	14400.00
0005433124297	5707	Economy	14400.00
0005433124259	5707	Economy	14400.00
0005433124232	5707	Economy	14400.00
0005433124329	5707	Economy	14400.00
0005434319795	5707	Economy	14400.00
0005433124338	5707	Economy	14400.00
0005434319803	5707	Economy	14400.00
0005434319802	5707	Economy	14400.00
0005433124244	5707	Economy	14400.00
0005435297352	5707	Economy	14400.00
0005434319807	5707	Economy	14400.00
0005434319790	5707	Economy	14400.00
0005434319788	5707	Economy	14400.00
0005435297380	15665	Business	43300.00
0005434319711	15665	Business	43300.00
0005434319640	15665	Business	43300.00
0005434319667	15665	Business	43300.00
0005434312356	15665	Business	43300.00
0005434319598	15665	Business	43300.00
0005435297375	15665	Economy	14400.00
0005433124501	15665	Economy	14400.00
0005435297378	15665	Economy	14400.00
0005434319621	15665	Economy	14400.00
0005434319717	15665	Economy	14400.00
0005433124500	15665	Economy	14400.00
0005434319700	15665	Economy	15900.00
0005433124494	15665	Economy	15900.00
0005435297376	15665	Economy	15900.00
0005434319665	15665	Economy	14400.00
0005433124490	15665	Economy	14400.00
0005434319650	15665	Economy	14400.00
0005434319631	15665	Economy	14400.00
0005435297383	15665	Economy	14400.00
0005435297386	15665	Economy	14400.00
0005434319710	15665	Economy	14400.00
0005434319670	15665	Economy	14400.00
0005433124493	15665	Economy	14400.00
0005433124499	15665	Economy	14400.00
0005433124506	15665	Economy	14400.00
0005433124497	15665	Economy	14400.00
0005434319666	15665	Economy	14400.00
0005434319647	15665	Economy	14400.00
0005434319668	15665	Economy	14400.00
0005434319623	15665	Economy	14400.00
0005434319659	15665	Economy	14400.00
0005433124504	15665	Economy	14400.00
0005434319669	15665	Economy	14400.00
0005435297385	15665	Economy	14400.00
0005434312363	15665	Economy	14400.00
0005433124496	15665	Economy	14400.00
0005433124492	15665	Economy	14400.00
0005434319597	15665	Economy	14400.00
0005435297379	15665	Economy	14400.00
0005433124502	15665	Economy	14400.00
0005434319641	15665	Economy	14400.00
0005433124491	15665	Economy	14400.00
0005433124507	15665	Economy	14400.00
0005433124505	15665	Economy	14400.00
0005433124503	15665	Economy	14400.00
0005434311254	15665	Economy	14400.00
0005433124495	15665	Economy	14400.00
0005434319622	15665	Economy	14400.00
0005434319662	15665	Economy	14400.00
0005433124498	15665	Economy	14400.00
0005435297384	15665	Economy	14400.00
0005435297381	15665	Economy	14400.00
0005434319627	15665	Economy	14400.00
0005435297382	15665	Economy	14400.00
0005434319660	15665	Economy	14400.00
0005435297377	15665	Economy	14400.00
0005435220380	31756	Economy	17100.00
0005435219257	31756	Economy	17100.00
0005435219260	31756	Economy	15500.00
0005435220518	31756	Economy	15500.00
0005435220519	31756	Economy	15500.00
0005435220376	31756	Economy	15500.00
0005435219259	31756	Economy	15500.00
0005435220517	31756	Economy	15500.00
0005435220378	31756	Economy	15500.00
0005435219258	31756	Economy	15500.00
0005435220377	31756	Economy	15500.00
0005435220379	31756	Economy	15500.00
0005434189302	9011	Economy	27400.00
0005434189303	9011	Economy	24900.00
0005434484526	9011	Economy	24900.00
0005434189304	9011	Economy	24900.00
0005434189301	9011	Economy	24900.00
0005434189287	9011	Economy	24900.00
0005434484530	9011	Economy	24900.00
0005434484527	9011	Economy	24900.00
0005434189288	9011	Economy	24900.00
0005434484529	9011	Economy	24900.00
0005434484528	9011	Economy	24900.00
0005434189267	9011	Economy	24900.00
0005434484481	16652	Economy	27400.00
0005434189334	16652	Economy	24900.00
0005434484478	16652	Economy	24900.00
0005434189332	16652	Economy	24900.00
0005434189333	16652	Economy	24900.00
0005434484484	16652	Economy	24900.00
0005434484480	16652	Economy	24900.00
0005434484499	16652	Economy	24900.00
0005434484457	16652	Economy	24900.00
0005434189335	16652	Economy	24900.00
0005434484498	16652	Economy	24900.00
0005434484477	16652	Economy	24900.00
0005434484466	16652	Economy	24900.00
0005433124505	7700	Business	11100.00
0005433722340	7700	Business	11100.00
0005433124504	7700	Business	11100.00
0005433722330	7700	Business	11100.00
0005433124490	7700	Business	11100.00
0005433722318	7700	Business	11100.00
0005433124493	7700	Economy	3700.00
0005433124507	7700	Economy	3700.00
0005433722341	7700	Economy	3700.00
0005433124500	7700	Economy	3700.00
0005433124496	7700	Economy	3700.00
0005433124497	7700	Economy	3700.00
0005433124491	7700	Economy	3700.00
0005433124494	7700	Economy	3700.00
0005433722312	7700	Economy	3700.00
0005433124499	7700	Economy	3700.00
0005433722317	7700	Economy	3700.00
0005433722323	7700	Economy	3700.00
0005433722322	7700	Economy	3700.00
0005433124492	7700	Economy	3700.00
0005433124495	7700	Economy	3700.00
0005433124501	7700	Economy	3700.00
0005433722334	7700	Economy	3700.00
0005433124502	7700	Economy	3700.00
0005433124506	7700	Economy	3700.00
0005433124498	7700	Economy	3700.00
0005433124503	7700	Economy	3700.00
0005432693920	7701	Business	11100.00
0005432071655	7701	Business	11100.00
0005433450569	7701	Business	11100.00
0005432071654	7701	Business	11100.00
0005432721628	7701	Business	11100.00
0005432071656	7701	Business	11100.00
0005432693907	7701	Business	11100.00
0005433450568	7701	Business	11100.00
0005432721630	7701	Economy	3700.00
0005432693919	7701	Economy	3700.00
0005432693909	7701	Economy	3700.00
0005432721641	7701	Economy	3700.00
0005433450567	7701	Economy	3700.00
0005433450572	7701	Economy	3700.00
0005432693908	7701	Economy	3700.00
0005433450565	7701	Economy	4100.00
0005433450563	7701	Economy	4100.00
0005432693912	7701	Economy	4100.00
0005432721639	7701	Economy	4100.00
0005432693918	7701	Economy	3700.00
0005432693924	7701	Economy	3700.00
0005432721629	7701	Economy	3700.00
0005432721640	7701	Economy	3700.00
0005432721633	7701	Economy	3700.00
0005432693921	7701	Economy	3700.00
0005432693917	7701	Economy	3700.00
0005432721632	7701	Economy	3700.00
0005432721638	7701	Economy	3700.00
0005432721636	7701	Economy	3700.00
0005433450564	7701	Economy	3700.00
0005433450558	7701	Economy	3700.00
0005432721637	7701	Economy	3700.00
0005433450566	7701	Economy	3700.00
0005432693903	7701	Economy	3700.00
0005432693904	7701	Economy	3700.00
0005433450573	7701	Economy	3700.00
0005432693913	7701	Economy	3700.00
0005432721642	7701	Economy	3700.00
0005432721634	7701	Economy	3700.00
0005433450562	7701	Economy	3700.00
0005432693914	7701	Economy	3700.00
0005432693923	7701	Economy	3700.00
0005432721631	7701	Economy	3700.00
0005432693916	7701	Economy	3700.00
0005433450570	7701	Economy	3700.00
0005432693910	7701	Economy	3700.00
0005432693911	7701	Economy	3700.00
0005432693905	7701	Economy	3700.00
0005432721635	7701	Economy	3700.00
0005432693922	7701	Economy	3700.00
0005433450560	7701	Economy	3700.00
0005432693906	7701	Economy	3700.00
0005433450571	7701	Economy	3700.00
0005433450561	7701	Economy	3700.00
0005433450559	7701	Economy	3700.00
0005432693915	7701	Economy	3700.00
0005432721627	7701	Economy	3700.00
0005432693608	30379	Business	11100.00
0005432693667	30379	Business	11100.00
0005433450282	30379	Business	11100.00
0005432693444	30379	Business	11100.00
0005432693656	30379	Business	11100.00
0005432693554	30379	Business	11100.00
0005433450456	30379	Business	11100.00
0005433450385	30379	Business	11100.00
0005432693655	30379	Economy	3700.00
0005433450299	30379	Economy	3700.00
0005433450445	30379	Economy	3700.00
0005432693650	30379	Economy	3700.00
0005433450391	30379	Economy	3700.00
0005432693631	30379	Economy	3700.00
0005432693716	30379	Economy	3700.00
0005432693624	30379	Economy	3700.00
0005432693651	30379	Economy	4100.00
0005432693582	30379	Economy	4100.00
0005433450435	30379	Economy	4100.00
0005432693693	30379	Economy	3700.00
0005433450467	30379	Economy	3700.00
0005432693694	30379	Economy	3700.00
0005432693666	30379	Economy	3700.00
0005433450384	30379	Economy	3700.00
0005433450344	30379	Economy	3700.00
0005433450364	30379	Economy	3700.00
0005433450300	30379	Economy	3700.00
0005432693675	30379	Economy	3700.00
0005432693445	30379	Economy	3700.00
0005432693717	30379	Economy	3700.00
0005433450363	30379	Economy	3700.00
0005432693576	30379	Economy	3700.00
0005433450458	30379	Economy	3700.00
0005432693653	30379	Economy	3700.00
0005433450367	30379	Economy	3700.00
0005432693687	30379	Economy	3700.00
0005432693683	30379	Economy	3700.00
0005432693660	30379	Economy	3700.00
0005433450409	30379	Economy	3700.00
0005432693522	30379	Economy	3700.00
0005433450382	30379	Economy	3700.00
0005432693760	30379	Economy	3700.00
0005433450434	30379	Economy	3700.00
0005433450457	30379	Economy	3700.00
0005433450466	30379	Economy	3700.00
0005432693538	30379	Economy	3700.00
0005432693521	30379	Economy	3700.00
0005433450301	30379	Economy	3700.00
0005432693584	30379	Economy	3700.00
0005432693577	30379	Economy	3700.00
0005432693757	30379	Economy	3700.00
0005432693617	30379	Economy	3700.00
0005432693756	30379	Economy	3700.00
0005432693591	30379	Economy	3700.00
0005433450431	30379	Economy	3700.00
0005433450395	30379	Economy	3700.00
0005432693607	30379	Economy	3700.00
0005433450368	30379	Economy	3700.00
0005433450343	30379	Economy	3700.00
0005432693684	30379	Economy	3700.00
0005432693659	30379	Economy	3700.00
0005432693446	30379	Economy	3700.00
0005433450383	30379	Economy	3700.00
0005432693632	30379	Economy	3700.00
0005432693750	30379	Economy	3700.00
0005432693711	30379	Economy	3700.00
0005433722439	30378	Business	11100.00
0005432721528	30378	Business	11100.00
0005432721390	30378	Business	11100.00
0005433722441	30378	Business	11100.00
0005433722446	30378	Business	11100.00
0005433124297	30378	Business	11100.00
0005433722428	30378	Business	11100.00
0005433722432	30378	Business	11100.00
0005433722430	30378	Economy	3700.00
0005432721522	30378	Economy	3700.00
0005433124231	30378	Economy	3700.00
0005433124338	30378	Economy	3700.00
0005433124317	30378	Economy	3700.00
0005432721440	30378	Economy	4100.00
0005433124245	30378	Economy	4100.00
0005433722435	30378	Economy	4100.00
0005433722444	30378	Economy	4100.00
0005432721425	30378	Economy	3700.00
0005432721510	30378	Economy	3700.00
0005433124244	30378	Economy	3700.00
0005433124299	30378	Economy	3700.00
0005433722442	30378	Economy	3700.00
0005433124306	30378	Economy	3700.00
0005433124344	30378	Economy	3700.00
0005432721446	30378	Economy	3700.00
0005433124329	30378	Economy	3700.00
0005433722436	30378	Economy	3700.00
0005433124310	30378	Economy	3700.00
0005433124375	30378	Economy	3700.00
0005433722445	30378	Economy	3700.00
0005433124328	30378	Economy	3700.00
0005433124316	30378	Economy	3700.00
0005432721429	30378	Economy	3700.00
0005433124262	30378	Economy	3700.00
0005433722431	30378	Economy	3700.00
0005433722437	30378	Economy	3700.00
0005433124311	30378	Economy	3700.00
0005432721441	30378	Economy	3700.00
0005433722443	30378	Economy	3700.00
0005433722447	30378	Economy	3700.00
0005433124232	30378	Economy	3700.00
0005433722434	30378	Economy	3700.00
0005433722427	30378	Economy	3700.00
0005433722429	30378	Economy	3700.00
0005432721457	30378	Economy	3700.00
0005433124330	30378	Economy	3700.00
0005433124261	30378	Economy	3700.00
0005433124247	30378	Economy	3700.00
0005432721389	30378	Economy	3700.00
0005433722440	30378	Economy	3700.00
0005433124259	30378	Economy	3700.00
0005433722448	30378	Economy	3700.00
0005433124307	30378	Economy	3700.00
0005432721383	30378	Economy	3700.00
0005433722438	30378	Economy	3700.00
0005432721388	30378	Economy	3700.00
0005433722433	30378	Economy	3700.00
0005433724928	1366	Business	70400.00
0005432928108	1366	Business	70400.00
0005432968881	1366	Business	70400.00
0005432968882	1366	Business	70400.00
0005434587314	1366	Business	70400.00
0005433525342	1366	Business	70400.00
0005433525341	1366	Business	70400.00
0005434587319	1366	Economy	23500.00
0005433193317	1366	Economy	23500.00
0005433193350	1366	Economy	23500.00
0005434587317	1366	Economy	23500.00
0005434513652	1366	Economy	23500.00
0005433724931	1366	Economy	25800.00
0005433193347	1366	Economy	25800.00
0005433193368	1366	Economy	25800.00
0005434587318	1366	Economy	25800.00
0005434513651	1366	Economy	23500.00
0005434587312	1366	Economy	23500.00
0005433193370	1366	Economy	23500.00
0005434587308	1366	Economy	23500.00
0005433193365	1366	Economy	23500.00
0005433525338	1366	Economy	23500.00
0005433193348	1366	Economy	23500.00
0005433193278	1366	Economy	23500.00
0005433525339	1366	Economy	23500.00
0005434587313	1366	Economy	23500.00
0005434587315	1366	Economy	23500.00
0005433193340	1366	Economy	23500.00
0005433193299	1366	Economy	23500.00
0005434587310	1366	Economy	23500.00
0005432928093	1366	Economy	23500.00
0005433724929	1366	Economy	23500.00
0005433193298	1366	Economy	23500.00
0005433193371	1366	Economy	23500.00
0005434587316	1366	Economy	23500.00
0005432968890	1366	Economy	23500.00
0005433193353	1366	Economy	23500.00
0005434515041	1366	Economy	23500.00
0005433525336	1366	Economy	23500.00
0005432271080	1366	Economy	23500.00
0005433525337	1366	Economy	23500.00
0005434513653	1366	Economy	23500.00
0005434587311	1366	Economy	23500.00
0005434587309	1366	Economy	23500.00
0005432271082	1366	Economy	23500.00
0005433525340	1366	Economy	23500.00
0005432271081	1366	Economy	23500.00
0005433525335	1366	Economy	23500.00
0005432928109	1366	Economy	23500.00
0005433724930	1366	Economy	23500.00
0005433193333	1366	Economy	23500.00
0005433525256	18516	Business	70400.00
0005434587126	18516	Business	70400.00
0005433193413	18516	Business	70400.00
0005433193410	18516	Business	70400.00
0005434587040	18516	Business	70400.00
0005433525280	18516	Business	70400.00
0005433525188	18516	Business	70400.00
0005434587207	18516	Business	70400.00
0005433525205	18516	Business	70400.00
0005433724865	18516	Business	70400.00
0005433525279	18516	Business	70400.00
0005434587140	18516	Economy	23500.00
0005433525284	18516	Economy	23500.00
0005432928132	18516	Economy	23500.00
0005434587138	18516	Economy	23500.00
0005433193416	18516	Economy	23500.00
0005434587161	18516	Economy	23500.00
0005434587127	18516	Economy	25800.00
0005433724891	18516	Economy	25800.00
0005433525206	18516	Economy	23500.00
0005434587017	18516	Economy	23500.00
0005434587032	18516	Economy	23500.00
0005433193417	18516	Economy	23500.00
0005434587115	18516	Economy	23500.00
0005432928131	18516	Economy	23500.00
0005434587106	18516	Economy	23500.00
0005433193404	18516	Economy	23500.00
0005434587146	18516	Economy	23500.00
0005433193412	18516	Economy	23500.00
0005433525221	18516	Economy	23500.00
0005432928133	18516	Economy	23500.00
0005433193409	18516	Economy	23500.00
0005434587105	18516	Economy	23500.00
0005433193415	18516	Economy	23500.00
0005433193405	18516	Economy	23500.00
0005434587081	18516	Economy	23500.00
0005433525283	18516	Economy	23500.00
0005433193411	18516	Economy	23500.00
0005434587033	18516	Economy	23500.00
0005434587057	18516	Economy	23500.00
0005434587039	18516	Economy	23500.00
0005434587141	18516	Economy	23500.00
0005434587024	18516	Economy	23500.00
0005433193414	18516	Economy	23500.00
0005434587162	18516	Economy	23500.00
0005434587172	18516	Economy	23500.00
0005433525228	18516	Economy	23500.00
0005433525257	18516	Economy	23500.00
0005433193408	18516	Economy	23500.00
0005434586925	18516	Economy	23500.00
0005433525207	18516	Economy	23500.00
0005433525232	18516	Economy	23500.00
0005433724890	18516	Economy	23500.00
0005433525203	18516	Economy	23500.00
0005433193406	18516	Economy	23500.00
0005433525227	18516	Economy	23500.00
0005434587041	18516	Economy	23500.00
0005434587147	18516	Economy	23500.00
0005434587163	18516	Economy	23500.00
0005433525278	18516	Economy	23500.00
0005433724876	18516	Economy	23500.00
0005433724885	18516	Economy	23500.00
0005432968904	18516	Economy	23500.00
0005433724896	18516	Economy	23500.00
0005433193407	18516	Economy	23500.00
0005434345154	11475	Economy	4300.00
0005434345155	11475	Economy	4300.00
0005434345163	11475	Economy	4300.00
0005435302275	11475	Economy	4000.00
0005434345164	11475	Economy	4000.00
0005434345173	11475	Economy	4000.00
0005434142721	11475	Economy	4000.00
0005434345162	11475	Economy	4000.00
0005434345167	11475	Economy	4000.00
0005435302298	11475	Economy	4000.00
0005434345166	11475	Economy	4000.00
0005434345168	11475	Economy	4000.00
0005434345179	11475	Economy	4000.00
0005434345171	11475	Economy	4000.00
0005434345174	11475	Economy	4000.00
0005434345153	11475	Economy	4000.00
0005434345156	11475	Economy	4000.00
0005434345175	11475	Economy	4000.00
0005434142720	11475	Economy	4000.00
0005434142719	11475	Economy	4000.00
0005434345169	11475	Economy	4000.00
0005434345159	11475	Economy	4000.00
0005435302276	11475	Economy	4000.00
0005434345161	11475	Economy	4000.00
0005434345176	11475	Economy	4000.00
0005434142722	11475	Economy	4000.00
0005435302268	11475	Economy	4000.00
0005434345181	11475	Economy	4000.00
0005434345178	11475	Economy	4000.00
0005435302277	11475	Economy	4000.00
0005434345158	11475	Economy	4000.00
0005434345165	11475	Economy	4000.00
0005434345160	11475	Economy	4000.00
0005434345177	11475	Economy	4000.00
0005434345157	11475	Economy	4000.00
0005434345172	11475	Economy	4000.00
0005434345182	11475	Economy	4000.00
0005434345170	11475	Economy	4000.00
0005435305044	11475	Economy	4000.00
0005434345180	11475	Economy	4000.00
0005434344875	29781	Economy	4300.00
0005434344968	29781	Economy	4300.00
0005434344912	29781	Economy	4300.00
0005434344775	29781	Economy	4300.00
0005434344823	29781	Economy	4000.00
0005434344761	29781	Economy	4000.00
0005434142686	29781	Economy	4000.00
0005434344928	29781	Economy	4000.00
0005435305074	29781	Economy	4000.00
0005434344881	29781	Economy	4000.00
0005434344789	29781	Economy	4000.00
0005434344807	29781	Economy	4000.00
0005434344799	29781	Economy	4000.00
0005434142690	29781	Economy	4000.00
0005434142691	29781	Economy	4000.00
0005434344666	29781	Economy	4000.00
0005434344759	29781	Economy	4000.00
0005434344763	29781	Economy	4000.00
0005434344808	29781	Economy	4000.00
0005434344793	29781	Economy	4000.00
0005434344995	29781	Economy	4000.00
0005434344913	29781	Economy	4000.00
0005434344848	29781	Economy	4000.00
0005434344813	29781	Economy	4000.00
0005434344815	29781	Economy	4000.00
0005434344929	29781	Economy	4000.00
0005434344902	29781	Economy	4000.00
0005434344906	29781	Economy	4000.00
0005434344800	29781	Economy	4000.00
0005434344792	29781	Economy	4000.00
0005434344980	29781	Economy	4000.00
0005434142697	29781	Economy	4000.00
0005434344854	29781	Economy	4000.00
0005434344931	29781	Economy	4000.00
0005435304266	29781	Economy	4000.00
0005434344806	29781	Economy	4000.00
0005434344762	29781	Economy	4000.00
0005435305072	29781	Economy	4000.00
0005434344760	29781	Economy	4000.00
0005434344812	29781	Economy	4000.00
0005434344872	29781	Economy	4000.00
0005435305071	29781	Economy	4000.00
0005435305073	29781	Economy	4000.00
0005434142698	29781	Economy	4000.00
0005435304265	29781	Economy	4000.00
0005434344811	29781	Economy	4000.00
0005434344930	29781	Economy	4000.00
0005434344946	29781	Economy	4000.00
0005435304267	29781	Economy	4000.00
0005434344967	29781	Economy	4000.00
0005433415949	1271	Business	199800.00
0005433416010	1271	Business	199800.00
0005435825375	1271	Business	199800.00
0005435825358	1271	Business	199800.00
0005435825357	1271	Business	199800.00
0005435825360	1271	Economy	66600.00
0005435825367	1271	Economy	66600.00
0005433415942	1271	Economy	66600.00
0005435825356	1271	Economy	66600.00
0005433415988	1271	Economy	66600.00
0005435825372	1271	Economy	66600.00
0005433416040	1271	Economy	66600.00
0005433415972	1271	Economy	66600.00
0005435825359	1271	Economy	66600.00
0005435825378	1271	Economy	66600.00
0005433416005	1271	Economy	66600.00
0005432284638	1271	Economy	66600.00
0005435825361	1271	Economy	66600.00
0005435825362	1271	Economy	66600.00
0005435825374	1271	Economy	66600.00
0005435825366	1271	Economy	66600.00
0005435825370	1271	Economy	66600.00
0005435825365	1271	Economy	66600.00
0005433415973	1271	Economy	66600.00
0005435825369	1271	Economy	66600.00
0005435825373	1271	Economy	66600.00
0005433416011	1271	Economy	66600.00
0005433416004	1271	Economy	66600.00
0005435825371	1271	Economy	66600.00
0005435825368	1271	Economy	66600.00
0005432284639	1271	Economy	66600.00
0005432284640	1271	Economy	66600.00
0005435825363	1271	Economy	66600.00
0005432284641	1271	Economy	66600.00
0005433415990	1271	Economy	66600.00
0005435825364	1271	Economy	66600.00
0005435825376	1271	Economy	66600.00
0005435825377	1271	Economy	66600.00
0005433416102	18008	Business	199800.00
0005433416103	18008	Business	199800.00
0005433416101	18008	Business	199800.00
0005433416104	18008	Business	199800.00
0005433416099	18008	Business	199800.00
0005435825124	18008	Business	199800.00
0005435825129	18008	Economy	66600.00
0005435825125	18008	Economy	66600.00
0005433416096	18008	Economy	66600.00
0005433416095	18008	Economy	73200.00
0005435825108	18008	Economy	73200.00
0005435825119	18008	Economy	73200.00
0005435825213	18008	Economy	66600.00
0005435825185	18008	Economy	66600.00
0005433416100	18008	Economy	66600.00
0005435825122	18008	Economy	66600.00
0005435825162	18008	Economy	66600.00
0005435825121	18008	Economy	66600.00
0005435825152	18008	Economy	66600.00
0005435825153	18008	Economy	66600.00
0005435825159	18008	Economy	66600.00
0005435825072	18008	Economy	66600.00
0005433416105	18008	Economy	66600.00
0005435825109	18008	Economy	66600.00
0005435825146	18008	Economy	66600.00
0005435825215	18008	Economy	66600.00
0005435824983	18008	Economy	66600.00
0005433416098	18008	Economy	66600.00
0005433416106	18008	Economy	66600.00
0005433416097	18008	Economy	66600.00
0005435825019	18008	Economy	66600.00
0005435949993	5632	Business	27800.00
0005432785274	5632	Business	27800.00
0005432144076	5632	Business	27800.00
0005435949988	5632	Business	27800.00
0005432785251	5632	Business	27800.00
0005432785269	5632	Business	27800.00
0005432144078	5632	Business	27800.00
0005432144079	5632	Business	27800.00
0005432144080	5632	Business	27800.00
0005432785275	5632	Business	27800.00
0005435476898	5632	Business	27800.00
0005432785263	5632	Business	27800.00
0005432785276	5632	Economy	9300.00
0005432785245	5632	Economy	9300.00
0005435243317	5632	Economy	9300.00
0005432785244	5632	Economy	9300.00
0005432785282	5632	Economy	9300.00
0005435949992	5632	Economy	9300.00
0005432144077	5632	Economy	9300.00
0005432785256	5632	Economy	9300.00
0005435476895	5632	Economy	9300.00
0005435476853	5632	Economy	10200.00
0005435243258	5632	Economy	10200.00
0005435243246	5632	Economy	10200.00
0005432785259	5632	Economy	10200.00
0005435476892	5632	Economy	10200.00
0005432785271	5632	Economy	9300.00
0005435949987	5632	Economy	9300.00
0005435243377	5632	Economy	9300.00
0005432785240	5632	Economy	9300.00
0005432785284	5632	Economy	9300.00
0005432785280	5632	Economy	9300.00
0005435243336	5632	Economy	9300.00
0005435476914	5632	Economy	9300.00
0005432785257	5632	Economy	9300.00
0005432785253	5632	Economy	9300.00
0005432785247	5632	Economy	9300.00
0005435476891	5632	Economy	9300.00
0005435243390	5632	Economy	9300.00
0005435949991	5632	Economy	9300.00
0005432785261	5632	Economy	9300.00
0005435243384	5632	Economy	9300.00
0005435243337	5632	Economy	9300.00
0005432785252	5632	Economy	9300.00
0005432785265	5632	Economy	9300.00
0005432785264	5632	Economy	9300.00
0005432785242	5632	Economy	9300.00
0005435476890	5632	Economy	9300.00
0005432785249	5632	Economy	9300.00
0005432785281	5632	Economy	9300.00
0005432785241	5632	Economy	9300.00
0005435476913	5632	Economy	9300.00
0005435243383	5632	Economy	9300.00
0005435243366	5632	Economy	9300.00
0005435243303	5632	Economy	9300.00
0005432785283	5632	Economy	9300.00
0005432785279	5632	Economy	9300.00
0005435243315	5632	Economy	9300.00
0005435243302	5632	Economy	9300.00
0005435243297	5632	Economy	9300.00
0005432785258	5632	Economy	9300.00
0005435949986	5632	Economy	9300.00
0005432785243	5632	Economy	9300.00
0005435949994	5632	Economy	9300.00
0005432785266	5632	Economy	9300.00
0005432785248	5632	Economy	9300.00
0005432785268	5632	Economy	9300.00
0005432785250	5632	Economy	9300.00
0005432785272	5632	Economy	9300.00
0005432785255	5632	Economy	9300.00
0005432785270	5632	Economy	9300.00
0005435243456	5632	Economy	9300.00
0005435243344	5632	Economy	9300.00
0005435476897	5632	Economy	9300.00
0005432785277	5632	Economy	9300.00
0005435476896	5632	Economy	9300.00
0005432785278	5632	Economy	9300.00
0005432785267	5632	Economy	9300.00
0005432785262	5632	Economy	9300.00
0005435243338	5632	Economy	9300.00
0005432785246	5632	Economy	9300.00
0005435243293	5632	Economy	9300.00
0005435243367	5632	Economy	9300.00
0005432785273	5632	Economy	9300.00
0005432785260	5632	Economy	9300.00
0005435949989	5632	Economy	9300.00
0005435949990	5632	Economy	9300.00
0005432785254	5632	Economy	9300.00
0005435243316	5632	Economy	9300.00
0005435243245	5632	Economy	9300.00
0005435243582	15341	Business	27800.00
0005432784775	15341	Business	27800.00
0005435476975	15341	Business	27800.00
0005435243573	15341	Business	27800.00
0005432784790	15341	Business	27800.00
0005435243588	15341	Business	27800.00
0005432784871	15341	Business	27800.00
0005432784900	15341	Business	27800.00
0005432784972	15341	Business	27800.00
0005435243565	15341	Business	27800.00
0005435476976	15341	Business	27800.00
0005432784755	15341	Business	27800.00
0005432784922	15341	Economy	9300.00
0005435243585	15341	Economy	9300.00
0005435243575	15341	Economy	9300.00
0005432784788	15341	Economy	9300.00
0005435476972	15341	Economy	9300.00
0005432784673	15341	Economy	9300.00
0005432784496	15341	Economy	9300.00
0005432784842	15341	Economy	9300.00
0005432784864	15341	Economy	9300.00
0005432784976	15341	Economy	9300.00
0005432784756	15341	Economy	10200.00
0005432784683	15341	Economy	10200.00
0005432784707	15341	Economy	10200.00
0005432784722	15341	Economy	10200.00
0005432784800	15341	Economy	10200.00
0005432784744	15341	Economy	9300.00
0005432784820	15341	Economy	9300.00
0005432784767	15341	Economy	9300.00
0005435243586	15341	Economy	9300.00
0005435243579	15341	Economy	9300.00
0005435243577	15341	Economy	9300.00
0005432784865	15341	Economy	9300.00
0005435243583	15341	Economy	9300.00
0005432784672	15341	Economy	9300.00
0005432784973	15341	Economy	9300.00
0005432784601	15341	Economy	9300.00
0005432784782	15341	Economy	9300.00
0005432784743	15341	Economy	9300.00
0005432784857	15341	Economy	9300.00
0005432784774	15341	Economy	9300.00
0005432784688	15341	Economy	9300.00
0005435476974	15341	Economy	9300.00
0005432784657	15341	Economy	9300.00
0005432784891	15341	Economy	9300.00
0005432784832	15341	Economy	9300.00
0005432784747	15341	Economy	9300.00
0005432784715	15341	Economy	9300.00
0005432784994	15341	Economy	9300.00
0005435476973	15341	Economy	9300.00
0005432784921	15341	Economy	9300.00
0005432784845	15341	Economy	9300.00
0005435243587	15341	Economy	9300.00
0005432784737	15341	Economy	9300.00
0005432784810	15341	Economy	9300.00
0005432784742	15341	Economy	9300.00
0005435243578	15341	Economy	9300.00
0005432784677	15341	Economy	9300.00
0005432784678	15341	Economy	9300.00
0005432784757	15341	Economy	9300.00
0005435243570	15341	Economy	9300.00
0005432784753	15341	Economy	9300.00
0005435243581	15341	Economy	9300.00
0005432784989	15341	Economy	9300.00
0005432784689	15341	Economy	9300.00
0005432784809	15341	Economy	9300.00
0005432784671	15341	Economy	9300.00
0005432784690	15341	Economy	9300.00
0005432784834	15341	Economy	9300.00
0005435243566	15341	Economy	9300.00
0005435243569	15341	Economy	9300.00
0005432784716	15341	Economy	9300.00
0005432784824	15341	Economy	9300.00
0005435243576	15341	Economy	9300.00
0005432784880	15341	Economy	9300.00
0005432784602	15341	Economy	9300.00
0005432784682	15341	Economy	9300.00
0005432784892	15341	Economy	9300.00
0005432784656	15341	Economy	9300.00
0005435243584	15341	Economy	9300.00
0005432785041	15341	Economy	9300.00
0005432784868	15341	Economy	9300.00
0005435243567	15341	Economy	9300.00
0005432784791	15341	Economy	9300.00
0005432784762	15341	Economy	9300.00
0005432784754	15341	Economy	9300.00
0005435243580	15341	Economy	9300.00
0005435243574	15341	Economy	9300.00
0005432784858	15341	Economy	9300.00
0005432784714	15341	Economy	9300.00
0005432784835	15341	Economy	9300.00
0005432784846	15341	Economy	9300.00
0005432784748	15341	Economy	9300.00
0005435243571	15341	Economy	9300.00
0005435243572	15341	Economy	9300.00
0005435243568	15341	Economy	9300.00
0005432848707	4362	Economy	7000.00
0005435851075	4362	Economy	7000.00
0005432848706	4362	Economy	6300.00
0005432848710	4362	Economy	6300.00
0005434462850	4362	Economy	6300.00
0005435851086	4362	Economy	6300.00
0005432848703	4362	Economy	6300.00
0005432848709	4362	Economy	6300.00
0005432848711	4362	Economy	6300.00
0005435851085	4362	Economy	6300.00
0005434463989	4362	Economy	6300.00
0005432848708	4362	Economy	6300.00
0005434462849	4362	Economy	6300.00
0005434463990	4362	Economy	6300.00
0005435851104	4362	Economy	6300.00
0005432848704	4362	Economy	6300.00
0005432848705	4362	Economy	6300.00
0005435851160	28850	Economy	7000.00
0005435851154	28850	Economy	7000.00
0005432848594	28850	Economy	6300.00
0005432848607	28850	Economy	6300.00
0005432848565	28850	Economy	6300.00
0005435851155	28850	Economy	6300.00
0005432848616	28850	Economy	6300.00
0005434461689	28850	Economy	6300.00
0005432848621	28850	Economy	6300.00
0005435851153	28850	Economy	6300.00
0005432848592	28850	Economy	6300.00
0005435851159	28850	Economy	6300.00
0005432848551	28850	Economy	6300.00
0005432848566	28850	Economy	6300.00
0005435851158	28850	Economy	6300.00
0005432848529	28850	Economy	6300.00
0005432848530	28850	Economy	6300.00
0005432848589	28850	Economy	6300.00
0005432848591	28850	Economy	6300.00
0005432848593	28850	Economy	6300.00
0005435851157	28850	Economy	6300.00
0005434461677	28850	Economy	6300.00
0005434463958	28850	Economy	6300.00
0005432848681	28850	Economy	6300.00
0005432848550	28850	Economy	6300.00
0005432848615	28850	Economy	6300.00
0005432848590	28850	Economy	6300.00
0005435851156	28850	Economy	6300.00
0005432848606	28850	Economy	6300.00
0005433497836	6335	Business	11900.00
0005434926718	6335	Business	11900.00
0005434926726	6335	Business	11900.00
0005434444148	6335	Business	11900.00
0005435257415	6335	Business	11900.00
0005434926717	6335	Business	11900.00
0005434926722	6335	Business	11900.00
0005433497825	6335	Business	11900.00
0005434444144	6335	Business	11900.00
0005433497814	6335	Business	11900.00
0005434926723	6335	Business	11900.00
0005433497820	6335	Economy	4000.00
0005434444149	6335	Economy	4000.00
0005433497816	6335	Economy	4000.00
0005434926724	6335	Economy	4000.00
0005434926714	6335	Economy	4000.00
0005434926713	6335	Economy	4000.00
0005433497818	6335	Economy	4000.00
0005434444150	6335	Economy	4000.00
0005435257399	6335	Economy	4000.00
0005434926734	6335	Economy	4000.00
0005435257401	6335	Economy	4400.00
0005434926740	6335	Economy	4400.00
0005435257398	6335	Economy	4400.00
0005433497817	6335	Economy	4400.00
0005434926750	6335	Economy	4400.00
0005434926730	6335	Economy	4000.00
0005433497829	6335	Economy	4000.00
0005433497834	6335	Economy	4000.00
0005434926745	6335	Economy	4000.00
0005434926746	6335	Economy	4000.00
0005433497819	6335	Economy	4000.00
0005433497824	6335	Economy	4000.00
0005435257417	6335	Economy	4000.00
0005434444151	6335	Economy	4000.00
0005434926712	6335	Economy	4000.00
0005434926747	6335	Economy	4000.00
0005434926735	6335	Economy	4000.00
0005433497832	6335	Economy	4000.00
0005433497822	6335	Economy	4000.00
0005434926742	6335	Economy	4000.00
0005433497823	6335	Economy	4000.00
0005434926733	6335	Economy	4000.00
0005434926744	6335	Economy	4000.00
0005434926708	6335	Economy	4000.00
0005434926736	6335	Economy	4000.00
0005434926719	6335	Economy	4000.00
0005434926732	6335	Economy	4000.00
0005434926728	6335	Economy	4000.00
0005433497827	6335	Economy	4000.00
0005434926738	6335	Economy	4000.00
0005434444142	6335	Economy	4000.00
0005433497833	6335	Economy	4000.00
0005435257400	6335	Economy	4000.00
0005433497828	6335	Economy	4000.00
0005434926706	6335	Economy	4000.00
0005434444153	6335	Economy	4000.00
0005434926743	6335	Economy	4000.00
0005433497826	6335	Economy	4000.00
0005434444147	6335	Economy	4000.00
0005434926727	6335	Economy	4000.00
0005433497821	6335	Economy	4000.00
0005434926710	6335	Economy	4000.00
0005434926720	6335	Economy	4000.00
0005434444152	6335	Economy	4000.00
0005434926709	6335	Economy	4000.00
0005435257402	6335	Economy	4000.00
0005434926725	6335	Economy	4000.00
0005434926731	6335	Economy	4000.00
0005434444146	6335	Economy	4000.00
0005435257404	6335	Economy	4000.00
0005433497835	6335	Economy	4000.00
0005434444145	6335	Economy	4000.00
0005433497830	6335	Economy	4000.00
0005435257396	6335	Economy	4000.00
0005434926721	6335	Economy	4000.00
0005434926741	6335	Economy	4000.00
0005434926752	6335	Economy	4000.00
0005434926751	6335	Economy	4000.00
0005434926739	6335	Economy	4000.00
0005434926748	6335	Economy	4000.00
0005433497815	6335	Economy	4000.00
0005434444143	6335	Economy	4000.00
0005434926729	6335	Economy	4000.00
0005434926737	6335	Economy	4000.00
0005432075321	6335	Economy	4000.00
0005435257418	6335	Economy	4000.00
0005434926707	6335	Economy	4000.00
0005433497831	6335	Economy	4000.00
0005434926715	6335	Economy	4000.00
0005434926711	6335	Economy	4000.00
0005434926716	6335	Economy	4000.00
0005434444141	6335	Economy	4000.00
0005434926749	6335	Economy	4000.00
0005435257515	20378	Business	11900.00
0005435257517	20378	Business	11900.00
0005435257510	20378	Business	11900.00
0005435257516	20378	Economy	4000.00
0005435257518	20378	Economy	4400.00
0005435257512	20378	Economy	4400.00
0005435257519	20378	Economy	4000.00
0005435257521	20378	Economy	4000.00
0005435257514	20378	Economy	4000.00
0005435257511	20378	Economy	4000.00
0005435257513	20378	Economy	4000.00
0005435257520	20378	Economy	4000.00
0005435311563	20379	Business	11900.00
0005434926367	20379	Business	11900.00
0005433497623	20379	Business	11900.00
0005433497740	20379	Business	11900.00
0005434926253	20379	Business	11900.00
0005434444069	20379	Business	11900.00
0005434926419	20379	Business	11900.00
0005435375180	20379	Business	11900.00
0005434926463	20379	Business	11900.00
0005434926226	20379	Business	11900.00
0005434926420	20379	Economy	4000.00
0005434926490	20379	Economy	4000.00
0005434926582	20379	Economy	4000.00
0005434926317	20379	Economy	4000.00
0005434926397	20379	Economy	4000.00
0005434926346	20379	Economy	4000.00
0005434926276	20379	Economy	4000.00
0005434926305	20379	Economy	4000.00
0005434444026	20379	Economy	4400.00
0005433497632	20379	Economy	4400.00
0005434926398	20379	Economy	4400.00
0005434444019	20379	Economy	4000.00
0005434926375	20379	Economy	4000.00
0005434926320	20379	Economy	4000.00
0005434926274	20379	Economy	4000.00
0005434926322	20379	Economy	4000.00
0005433497615	20379	Economy	4000.00
0005434926340	20379	Economy	4000.00
0005434926409	20379	Economy	4000.00
0005434443971	20379	Economy	4000.00
0005433497635	20379	Economy	4000.00
0005433497614	20379	Economy	4000.00
0005433497684	20379	Economy	4000.00
0005434926370	20379	Economy	4000.00
0005434926361	20379	Economy	4000.00
0005433497435	20379	Economy	4000.00
0005434444031	20379	Economy	4000.00
0005434926489	20379	Economy	4000.00
0005435311564	20379	Economy	4000.00
0005433497739	20379	Economy	4000.00
0005434926355	20379	Economy	4000.00
0005434444020	20379	Economy	4000.00
0005434926254	20379	Economy	4000.00
0005434926372	20379	Economy	4000.00
0005434926338	20379	Economy	4000.00
0005434926270	20379	Economy	4000.00
0005435311565	20379	Economy	4000.00
0005434926326	20379	Economy	4000.00
0005434926352	20379	Economy	4000.00
0005434926321	20379	Economy	4000.00
0005434926379	20379	Economy	4000.00
0005434926399	20379	Economy	4000.00
0005433497599	20379	Economy	4000.00
0005433497502	20379	Economy	4000.00
0005434926316	20379	Economy	4000.00
0005434926360	20379	Economy	4000.00
0005434926440	20379	Economy	4000.00
0005433497660	20379	Economy	4000.00
0005433497556	20379	Economy	4000.00
0005434926477	20379	Economy	4000.00
0005434926273	20379	Economy	4000.00
0005434444036	20379	Economy	4000.00
0005433497548	20379	Economy	4000.00
0005434926441	20379	Economy	4000.00
0005434926403	20379	Economy	4000.00
0005434926393	20379	Economy	4000.00
0005435311567	20379	Economy	4000.00
0005434926464	20379	Economy	4000.00
0005434443964	20379	Economy	4000.00
0005434444035	20379	Economy	4000.00
0005434926448	20379	Economy	4000.00
0005434926373	20379	Economy	4000.00
0005433497598	20379	Economy	4000.00
0005433497580	20379	Economy	4000.00
0005433497668	20379	Economy	4000.00
0005433497694	20379	Economy	4000.00
0005435311566	20379	Economy	4000.00
0005432785108	12158	Business	41200.00
0005432785138	12158	Business	41200.00
0005432785136	12158	Business	41200.00
0005435243608	12158	Business	41200.00
0005432784825	12158	Business	41200.00
0005432784950	12158	Business	41200.00
0005432784885	12158	Business	41200.00
0005432784963	12158	Business	41200.00
0005432784685	12158	Business	41200.00
0005435243592	12158	Business	41200.00
0005432784801	12158	Economy	13700.00
0005432784761	12158	Economy	13700.00
0005435243598	12158	Economy	13700.00
0005432784830	12158	Economy	13700.00
0005432784630	12158	Economy	13700.00
0005435243609	12158	Economy	13700.00
0005432784807	12158	Economy	13700.00
0005432784913	12158	Economy	15100.00
0005435243600	12158	Economy	15100.00
0005432784831	12158	Economy	15100.00
0005435243603	12158	Economy	15100.00
0005432784862	12158	Economy	13700.00
0005432784740	12158	Economy	13700.00
0005432784971	12158	Economy	13700.00
0005435243591	12158	Economy	13700.00
0005435243596	12158	Economy	13700.00
0005432784631	12158	Economy	13700.00
0005435243599	12158	Economy	13700.00
0005432784861	12158	Economy	13700.00
0005435243606	12158	Economy	13700.00
0005432785109	12158	Economy	13700.00
0005432784667	12158	Economy	13700.00
0005435243604	12158	Economy	13700.00
0005432785134	12158	Economy	13700.00
0005432784855	12158	Economy	13700.00
0005435243610	12158	Economy	13700.00
0005432784942	12158	Economy	13700.00
0005432784584	12158	Economy	13700.00
0005432784741	12158	Economy	13700.00
0005432784703	12158	Economy	13700.00
0005432784645	12158	Economy	13700.00
0005435243611	12158	Economy	13700.00
0005432784776	12158	Economy	13700.00
0005435243607	12158	Economy	13700.00
0005435243601	12158	Economy	13700.00
0005432785135	12158	Economy	13700.00
0005432784583	12158	Economy	13700.00
0005432784687	12158	Economy	13700.00
0005435243589	12158	Economy	13700.00
0005435243594	12158	Economy	13700.00
0005432784924	12158	Economy	13700.00
0005435243597	12158	Economy	13700.00
0005435243590	12158	Economy	13700.00
0005432784888	12158	Economy	13700.00
0005435243595	12158	Economy	13700.00
0005432784854	12158	Economy	13700.00
0005435243593	12158	Economy	13700.00
0005432784944	12158	Economy	13700.00
0005432784884	12158	Economy	13700.00
0005432784870	12158	Economy	13700.00
0005432784925	12158	Economy	13700.00
0005435243605	12158	Economy	13700.00
0005435243602	12158	Economy	13700.00
0005432784951	12158	Economy	13700.00
0005435243143	15446	Business	41200.00
0005435243255	15446	Business	41200.00
0005435243295	15446	Business	41200.00
0005435243446	15446	Business	41200.00
0005432785209	15446	Business	41200.00
0005432785237	15446	Business	41200.00
0005432785228	15446	Economy	13700.00
0005435243394	15446	Economy	13700.00
0005432785220	15446	Economy	13700.00
0005432785218	15446	Economy	13700.00
0005432785211	15446	Economy	13700.00
0005432785212	15446	Economy	13700.00
0005432785234	15446	Economy	13700.00
0005435243395	15446	Economy	13700.00
0005435243211	15446	Economy	15100.00
0005432785230	15446	Economy	15100.00
0005432785223	15446	Economy	15100.00
0005435243284	15446	Economy	15100.00
0005432785213	15446	Economy	15100.00
0005432785239	15446	Economy	13700.00
0005435243212	15446	Economy	13700.00
0005432785219	15446	Economy	13700.00
0005435243210	15446	Economy	13700.00
0005435243331	15446	Economy	13700.00
0005432785197	15446	Economy	13700.00
0005435243313	15446	Economy	13700.00
0005435243333	15446	Economy	13700.00
0005432785203	15446	Economy	13700.00
0005432785238	15446	Economy	13700.00
0005435243398	15446	Economy	13700.00
0005435243447	15446	Economy	13700.00
0005435243342	15446	Economy	13700.00
0005432785205	15446	Economy	13700.00
0005435243325	15446	Economy	13700.00
0005435243278	15446	Economy	13700.00
0005432785206	15446	Economy	13700.00
0005432785221	15446	Economy	13700.00
0005432785214	15446	Economy	13700.00
0005432785216	15446	Economy	13700.00
0005432785217	15446	Economy	13700.00
0005435243385	15446	Economy	13700.00
0005435243328	15446	Economy	13700.00
0005435243332	15446	Economy	13700.00
0005432785200	15446	Economy	13700.00
0005435243343	15446	Economy	13700.00
0005435243294	15446	Economy	13700.00
0005432785202	15446	Economy	13700.00
0005435243296	15446	Economy	13700.00
0005432785198	15446	Economy	13700.00
0005435243237	15446	Economy	13700.00
0005432785201	15446	Economy	13700.00
0005432785222	15446	Economy	13700.00
0005432785208	15446	Economy	13700.00
0005432785210	15446	Economy	13700.00
0005435243236	15446	Economy	13700.00
0005432785204	15446	Economy	13700.00
0005435243326	15446	Economy	13700.00
0005432785231	15446	Economy	13700.00
0005435243235	15446	Economy	13700.00
0005432785196	15446	Economy	13700.00
0005432785229	15446	Economy	13700.00
0005432785226	15446	Economy	13700.00
0005435243256	15446	Economy	13700.00
0005435243285	15446	Economy	13700.00
0005435243312	15446	Economy	13700.00
0005435243279	15446	Economy	13700.00
0005435243386	15446	Economy	13700.00
0005432785215	15446	Economy	13700.00
0005435243142	15446	Economy	13700.00
0005432785232	15446	Economy	13700.00
0005432785199	15446	Economy	13700.00
0005432785224	15446	Economy	13700.00
0005432785233	15446	Economy	13700.00
0005432785227	15446	Economy	13700.00
0005432785225	15446	Economy	13700.00
0005432785236	15446	Economy	13700.00
0005432785235	15446	Economy	13700.00
0005432785207	15446	Economy	13700.00
0005434879818	10102	Business	49700.00
0005434880344	10102	Business	49700.00
0005435914128	10102	Business	49700.00
0005435914126	10102	Business	49700.00
0005434758939	10102	Business	49700.00
0005434879401	10102	Business	49700.00
0005434879845	10102	Business	49700.00
0005434879968	10102	Business	49700.00
0005434879652	10102	Business	49700.00
0005434879936	10102	Business	49700.00
0005434758938	10102	Business	49700.00
0005434879952	10102	Business	49700.00
0005434879935	10102	Business	49700.00
0005434880011	10102	Business	49700.00
0005434880008	10102	Business	49700.00
0005434880064	10102	Business	49700.00
0005435914125	10102	Business	49700.00
0005434880007	10102	Business	49700.00
0005434879819	10102	Economy	16600.00
0005435914142	10102	Economy	16600.00
0005434879925	10102	Economy	16600.00
0005434880028	10102	Economy	16600.00
0005435914132	10102	Economy	16600.00
0005435914122	10102	Economy	16600.00
0005435914134	10102	Economy	16600.00
0005435914129	10102	Economy	16600.00
0005435914120	10102	Economy	16600.00
0005434880345	10102	Economy	16600.00
0005434879743	10102	Economy	16600.00
0005434879689	10102	Economy	16600.00
0005434880034	10102	Economy	18200.00
0005434879921	10102	Economy	18200.00
0005435914137	10102	Economy	18200.00
0005435914143	10102	Economy	18200.00
0005434880457	10102	Economy	16600.00
0005434879758	10102	Economy	16600.00
0005434879760	10102	Economy	16600.00
0005435914151	10102	Economy	16600.00
0005434880159	10102	Economy	16600.00
0005435914118	10102	Economy	16600.00
0005435914147	10102	Economy	16600.00
0005435914123	10102	Economy	16600.00
0005434880239	10102	Economy	16600.00
0005435914144	10102	Economy	16600.00
0005434879941	10102	Economy	16600.00
0005435914141	10102	Economy	16600.00
0005434880024	10102	Economy	16600.00
0005434879991	10102	Economy	16600.00
0005435914136	10102	Economy	16600.00
0005434879400	10102	Economy	16600.00
0005434879690	10102	Economy	16600.00
0005434879863	10102	Economy	16600.00
0005434880241	10102	Economy	16600.00
0005435914149	10102	Economy	16600.00
0005434880267	10102	Economy	16600.00
0005435914130	10102	Economy	16600.00
0005435914135	10102	Economy	16600.00
0005434879759	10102	Economy	16600.00
0005434880458	10102	Economy	16600.00
0005434880149	10102	Economy	16600.00
0005434880142	10102	Economy	16600.00
0005434879641	10102	Economy	16600.00
0005434910178	10102	Economy	16600.00
0005435914127	10102	Economy	16600.00
0005434880456	10102	Economy	16600.00
0005434879924	10102	Economy	16600.00
0005434879864	10102	Economy	16600.00
0005435914117	10102	Economy	16600.00
0005434880348	10102	Economy	16600.00
0005434880381	10102	Economy	16600.00
0005434879577	10102	Economy	16600.00
0005434879850	10102	Economy	16600.00
0005435914133	10102	Economy	16600.00
0005434879834	10102	Economy	16600.00
0005434880254	10102	Economy	16600.00
0005434880411	10102	Economy	16600.00
0005434879651	10102	Economy	16600.00
0005434880042	10102	Economy	16600.00
0005434758931	10102	Economy	16600.00
0005435914148	10102	Economy	16600.00
0005435914150	10102	Economy	16600.00
0005434880094	10102	Economy	16600.00
0005434879953	10102	Economy	16600.00
0005434880160	10102	Economy	16600.00
0005434880009	10102	Economy	16600.00
0005435914138	10102	Economy	16600.00
0005435914131	10102	Economy	16600.00
0005435914124	10102	Economy	16600.00
0005434880010	10102	Economy	16600.00
0005434879665	10102	Economy	16600.00
0005434879926	10102	Economy	16600.00
0005435914139	10102	Economy	16600.00
0005435914121	10102	Economy	16600.00
0005434879946	10102	Economy	16600.00
0005434910177	10102	Economy	16600.00
0005434880402	10102	Economy	16600.00
0005434880220	10102	Economy	16600.00
0005435914145	10102	Economy	16600.00
0005434879940	10102	Economy	16600.00
0005435914116	10102	Economy	16600.00
0005435914119	10102	Economy	16600.00
0005434880056	10102	Economy	16600.00
0005435914140	10102	Economy	16600.00
0005434880266	10102	Economy	16600.00
0005434879932	10102	Economy	16600.00
0005434879742	10102	Economy	16600.00
0005434880297	10102	Economy	16600.00
0005434879844	10102	Economy	16600.00
0005434880135	10102	Economy	16600.00
0005435914146	10102	Economy	16600.00
0005434880290	10102	Economy	16600.00
0005435913977	14605	Business	49700.00
0005434880782	14605	Business	49700.00
0005434880771	14605	Business	49700.00
0005434880776	14605	Business	49700.00
0005435913990	14605	Business	49700.00
0005434880786	14605	Business	49700.00
0005434880817	14605	Business	49700.00
0005434880767	14605	Business	49700.00
0005434758958	14605	Business	49700.00
0005434880831	14605	Business	49700.00
0005434880790	14605	Business	49700.00
0005434880774	14605	Economy	16600.00
0005435914023	14605	Economy	16600.00
0005434880812	14605	Economy	16600.00
0005434880796	14605	Economy	16600.00
0005434880808	14605	Economy	16600.00
0005434880784	14605	Economy	16600.00
0005434880795	14605	Economy	16600.00
0005434880824	14605	Economy	16600.00
0005434880815	14605	Economy	16600.00
0005434880772	14605	Economy	18200.00
0005434880811	14605	Economy	18200.00
0005434880806	14605	Economy	18200.00
0005434880813	14605	Economy	16600.00
0005434880819	14605	Economy	18200.00
0005434880804	14605	Economy	16600.00
0005434880823	14605	Economy	16600.00
0005434880820	14605	Economy	16600.00
0005434880781	14605	Economy	16600.00
0005434880830	14605	Economy	16600.00
0005435914012	14605	Economy	16600.00
0005434880780	14605	Economy	16600.00
0005434880773	14605	Economy	16600.00
0005434880818	14605	Economy	16600.00
0005434880810	14605	Economy	16600.00
0005434880821	14605	Economy	16600.00
0005434880768	14605	Economy	16600.00
0005434880825	14605	Economy	16600.00
0005434880822	14605	Economy	16600.00
0005434880816	14605	Economy	16600.00
0005434880775	14605	Economy	16600.00
0005434880801	14605	Economy	16600.00
0005434880797	14605	Economy	16600.00
0005434880789	14605	Economy	16600.00
0005434880798	14605	Economy	16600.00
0005434880800	14605	Economy	16600.00
0005434880802	14605	Economy	16600.00
0005434880788	14605	Economy	16600.00
0005434880778	14605	Economy	16600.00
0005434880777	14605	Economy	16600.00
0005434880785	14605	Economy	16600.00
0005434880791	14605	Economy	16600.00
0005434880807	14605	Economy	16600.00
0005434880794	14605	Economy	16600.00
0005434880792	14605	Economy	16600.00
0005434880829	14605	Economy	16600.00
0005434880835	14605	Economy	16600.00
0005434880836	14605	Economy	16600.00
0005435914007	14605	Economy	16600.00
0005434880826	14605	Economy	16600.00
0005434880799	14605	Economy	16600.00
0005434880814	14605	Economy	16600.00
0005434880827	14605	Economy	16600.00
0005435914005	14605	Economy	16600.00
0005435914006	14605	Economy	16600.00
0005434880805	14605	Economy	16600.00
0005434880787	14605	Economy	16600.00
0005434880834	14605	Economy	16600.00
0005434880769	14605	Economy	16600.00
0005434880832	14605	Economy	16600.00
0005434880770	14605	Economy	16600.00
0005434880828	14605	Economy	16600.00
0005434880783	14605	Economy	16600.00
0005434880779	14605	Economy	16600.00
0005435914024	14605	Economy	16600.00
0005434880833	14605	Economy	16600.00
0005434880809	14605	Economy	16600.00
0005434880793	14605	Economy	16600.00
0005434880803	14605	Economy	16600.00
0005434252184	9241	Economy	20300.00
0005435660439	9241	Economy	20300.00
0005435660441	9241	Economy	20300.00
0005434252118	9241	Economy	20300.00
0005434252141	9241	Economy	20300.00
0005435660445	9241	Economy	20300.00
0005435660446	9241	Economy	20300.00
0005434252123	9241	Economy	20300.00
0005434252176	9241	Economy	20300.00
0005434252159	9241	Economy	20300.00
0005434252117	9241	Economy	20300.00
0005435660444	9241	Economy	20300.00
0005434252121	9241	Economy	20300.00
0005434252140	9241	Economy	20300.00
0005435660442	9241	Economy	20300.00
0005435660443	9241	Economy	20300.00
0005435660440	9241	Economy	20300.00
0005434252152	9241	Economy	20300.00
0005435660447	9241	Economy	20300.00
0005434252160	9241	Economy	20300.00
0005434252175	9241	Economy	20300.00
0005434252119	9241	Economy	20300.00
0005434252150	9241	Economy	20300.00
0005434252151	9241	Economy	20300.00
0005434252230	24629	Economy	22400.00
0005435660282	24629	Economy	22400.00
0005435660350	24629	Economy	22400.00
0005435660371	24629	Economy	22400.00
0005435660315	24629	Economy	20300.00
0005435660342	24629	Economy	20300.00
0005434252226	24629	Economy	20300.00
0005434252224	24629	Economy	20300.00
0005435660370	24629	Economy	20300.00
0005435660314	24629	Economy	20300.00
0005434252228	24629	Economy	20300.00
0005434252225	24629	Economy	20300.00
0005434252231	24629	Economy	20300.00
0005434252229	24629	Economy	20300.00
0005435660341	24629	Economy	20300.00
0005434252227	24629	Economy	20300.00
0005435660366	24629	Economy	20300.00
0005435660356	24629	Economy	20300.00
0005435660357	24629	Economy	20300.00
0005435660378	24629	Economy	20300.00
0005434252223	24629	Economy	20300.00
0005433681861	2820	Business	33000.00
0005433681880	2820	Business	33000.00
0005432967445	2820	Business	33000.00
0005433681848	2820	Business	33000.00
0005433681855	2820	Business	33000.00
0005433681870	2820	Business	33000.00
0005432222928	2820	Business	33000.00
0005433684475	2820	Business	33000.00
0005433681865	2820	Business	33000.00
0005433681878	2820	Business	33000.00
0005433681868	2820	Business	33000.00
0005432967450	2820	Economy	11000.00
0005433681869	2820	Economy	11000.00
0005433681849	2820	Economy	11000.00
0005433681866	2820	Economy	11000.00
0005432967377	2820	Economy	11000.00
0005433681852	2820	Economy	11000.00
0005432222929	2820	Economy	11000.00
0005433681873	2820	Economy	11000.00
0005432967273	2820	Economy	12100.00
0005433681867	2820	Economy	12100.00
0005433681847	2820	Economy	12100.00
0005432222924	2820	Economy	12100.00
0005433681884	2820	Economy	11000.00
0005432967338	2820	Economy	11000.00
0005432967393	2820	Economy	11000.00
0005433681871	2820	Economy	11000.00
0005432967460	2820	Economy	11000.00
0005433681885	2820	Economy	11000.00
0005433681881	2820	Economy	11000.00
0005432967387	2820	Economy	11000.00
0005432967541	2820	Economy	11000.00
0005432967415	2820	Economy	11000.00
0005433681860	2820	Economy	11000.00
0005432967461	2820	Economy	11000.00
0005433681883	2820	Economy	11000.00
0005432967432	2820	Economy	11000.00
0005432967408	2820	Economy	11000.00
0005433681854	2820	Economy	11000.00
0005432967444	2820	Economy	11000.00
0005433681850	2820	Economy	11000.00
0005433681857	2820	Economy	11000.00
0005433681845	2820	Economy	11000.00
0005433681853	2820	Economy	11000.00
0005433681872	2820	Economy	11000.00
0005432222926	2820	Economy	11000.00
0005433681882	2820	Economy	11000.00
0005433681851	2820	Economy	11000.00
0005432222925	2820	Economy	11000.00
0005433681859	2820	Economy	11000.00
0005433684474	2820	Economy	11000.00
0005433681864	2820	Economy	11000.00
0005433681846	2820	Economy	11000.00
0005433681856	2820	Economy	11000.00
0005432967416	2820	Economy	11000.00
0005432967384	2820	Economy	11000.00
0005433681862	2820	Economy	11000.00
0005432967434	2820	Economy	11000.00
0005433681876	2820	Economy	11000.00
0005432222927	2820	Economy	11000.00
0005432967505	2820	Economy	11000.00
0005432967431	2820	Economy	11000.00
0005432967510	2820	Economy	11000.00
0005433681858	2820	Economy	11000.00
0005432967503	2820	Economy	11000.00
0005432967453	2820	Economy	11000.00
0005433681877	2820	Economy	11000.00
0005433681874	2820	Economy	11000.00
0005433681879	2820	Economy	11000.00
0005432967427	2820	Economy	11000.00
0005433681863	2820	Economy	11000.00
0005433681875	2820	Economy	11000.00
0005432967274	2820	Economy	11000.00
0005432967426	2820	Economy	11000.00
0005432967312	2820	Economy	11000.00
0005433684476	2820	Economy	11000.00
0005432967433	2820	Economy	11000.00
0005432967639	29143	Business	33000.00
0005432005290	29143	Business	33000.00
0005432005291	29143	Business	33000.00
0005433681671	29143	Business	33000.00
0005433681451	29143	Business	33000.00
0005433681544	29143	Business	33000.00
0005433687745	29143	Business	33000.00
0005433681450	29143	Business	33000.00
0005433681525	29143	Business	33000.00
0005433681520	29143	Business	33000.00
0005433681396	29143	Business	33000.00
0005433681657	29143	Business	33000.00
0005433681573	29143	Economy	11000.00
0005433681395	29143	Economy	11000.00
0005432967628	29143	Economy	11000.00
0005433681571	29143	Economy	11000.00
0005433681541	29143	Economy	11000.00
0005433681439	29143	Economy	11000.00
0005433681612	29143	Economy	11000.00
0005433681393	29143	Economy	11000.00
0005433681559	29143	Economy	11000.00
0005433681557	29143	Economy	12100.00
0005432967637	29143	Economy	12100.00
0005432967622	29143	Economy	12100.00
0005433681716	29143	Economy	12100.00
0005433681407	29143	Economy	12100.00
0005433681588	29143	Economy	11000.00
0005433681290	29143	Economy	11000.00
0005433681411	29143	Economy	11000.00
0005433684461	29143	Economy	11000.00
0005433681422	29143	Economy	11000.00
0005433684452	29143	Economy	11000.00
0005433681542	29143	Economy	11000.00
0005432967618	29143	Economy	11000.00
0005433681778	29143	Economy	11000.00
0005432967630	29143	Economy	11000.00
0005432967632	29143	Economy	11000.00
0005433681404	29143	Economy	11000.00
0005432967633	29143	Economy	11000.00
0005433681567	29143	Economy	11000.00
0005433681603	29143	Economy	11000.00
0005432967634	29143	Economy	11000.00
0005433681412	29143	Economy	11000.00
0005433684453	29143	Economy	11000.00
0005433681490	29143	Economy	11000.00
0005432967624	29143	Economy	11000.00
0005433681556	29143	Economy	11000.00
0005433681561	29143	Economy	11000.00
0005433681382	29143	Economy	11000.00
0005432967619	29143	Economy	11000.00
0005433681354	29143	Economy	11000.00
0005433681565	29143	Economy	11000.00
0005433681717	29143	Economy	11000.00
0005433681423	29143	Economy	11000.00
0005433690973	29143	Economy	11000.00
0005432967638	29143	Economy	11000.00
0005433681361	29143	Economy	11000.00
0005433681529	29143	Economy	11000.00
0005433681759	29143	Economy	11000.00
0005432967621	29143	Economy	11000.00
0005433681381	29143	Economy	11000.00
0005433684459	29143	Economy	11000.00
0005432967635	29143	Economy	11000.00
0005433681610	29143	Economy	11000.00
0005433681289	29143	Economy	11000.00
0005432967636	29143	Economy	11000.00
0005432967631	29143	Economy	11000.00
0005432967620	29143	Economy	11000.00
0005432967627	29143	Economy	11000.00
0005432967626	29143	Economy	11000.00
0005433681553	29143	Economy	11000.00
0005433681547	29143	Economy	11000.00
0005433681641	29143	Economy	11000.00
0005433681508	29143	Economy	11000.00
0005432967629	29143	Economy	11000.00
0005433681640	29143	Economy	11000.00
0005433681569	29143	Economy	11000.00
0005433681570	29143	Economy	11000.00
0005432967625	29143	Economy	11000.00
0005433681310	29143	Economy	11000.00
0005433681474	29143	Economy	11000.00
0005433681566	29143	Economy	11000.00
0005433684460	29143	Economy	11000.00
0005433681526	29143	Economy	11000.00
0005433681519	29143	Economy	11000.00
0005433681475	29143	Economy	11000.00
0005432967623	29143	Economy	11000.00
0005433681403	29143	Economy	11000.00
0005433616638	9279	Business	132900.00
0005433634737	9279	Business	132900.00
0005434163815	9279	Business	132900.00
0005433634734	9279	Business	132900.00
0005433634730	9279	Business	132900.00
0005433634735	9279	Business	132900.00
0005433616608	9279	Business	132900.00
0005433616625	9279	Business	132900.00
0005433578178	9279	Business	132900.00
0005433578179	9279	Business	132900.00
0005433634726	9279	Business	132900.00
0005433616615	9279	Business	132900.00
0005433616613	9279	Business	132900.00
0005433616632	9279	Business	132900.00
0005433616653	9279	Business	132900.00
0005434269141	9279	Business	132900.00
0005433616620	9279	Business	132900.00
0005433634725	9279	Business	132900.00
0005434163802	9279	Business	132900.00
0005434269142	9279	Economy	48700.00
0005433616646	9279	Economy	48700.00
0005433616631	9279	Economy	48700.00
0005433634719	9279	Economy	48700.00
0005433616650	9279	Economy	44300.00
0005433616621	9279	Economy	44300.00
0005433616648	9279	Economy	44300.00
0005434153551	9279	Economy	44300.00
0005433578171	9279	Economy	44300.00
0005433578175	9279	Economy	44300.00
0005433578176	9279	Economy	44300.00
0005433578173	9279	Economy	44300.00
0005433634718	9279	Economy	44300.00
0005433616652	9279	Economy	44300.00
0005433616633	9279	Economy	44300.00
0005433616640	9279	Economy	44300.00
0005433634723	9279	Economy	44300.00
0005433616606	9279	Economy	44300.00
0005432756935	9279	Economy	44300.00
0005433616605	9279	Economy	44300.00
0005432756934	9279	Economy	44300.00
0005434153561	9279	Economy	44300.00
0005433616629	9279	Economy	44300.00
0005433634722	9279	Economy	44300.00
0005433616626	9279	Economy	44300.00
0005434153558	9279	Economy	44300.00
0005433578177	9279	Economy	44300.00
0005433616623	9279	Economy	44300.00
0005433616607	9279	Economy	44300.00
0005433616604	9279	Economy	44300.00
0005433616634	9279	Economy	44300.00
0005434153562	9279	Economy	44300.00
0005433634712	9279	Economy	44300.00
0005433634733	9279	Economy	44300.00
0005433616622	9279	Economy	44300.00
0005433616616	9279	Economy	44300.00
0005433616654	9279	Economy	44300.00
0005433616600	9279	Economy	44300.00
0005433616612	9279	Economy	44300.00
0005433634729	9279	Economy	44300.00
0005433578172	9279	Economy	44300.00
0005433616619	9279	Economy	44300.00
0005433616647	9279	Economy	44300.00
0005433616618	9279	Economy	44300.00
0005434153563	9279	Economy	48700.00
0005433616649	9279	Economy	48700.00
0005434269138	9279	Economy	48700.00
0005434163797	9279	Economy	48700.00
0005433578181	9279	Economy	44300.00
0005433634714	9279	Economy	44300.00
0005433634727	9279	Economy	44300.00
0005433634716	9279	Economy	48700.00
0005433616642	9279	Economy	44300.00
0005433634738	9279	Economy	44300.00
0005433578180	9279	Economy	44300.00
0005433616603	9279	Economy	44300.00
0005432145165	9279	Economy	44300.00
0005434153555	9279	Economy	44300.00
0005433616614	9279	Economy	44300.00
0005433616611	9279	Economy	44300.00
0005433616630	9279	Economy	44300.00
0005433616657	9279	Economy	44300.00
0005432145164	9279	Economy	44300.00
0005433616644	9279	Economy	44300.00
0005433634728	9279	Economy	44300.00
0005433634713	9279	Economy	44300.00
0005433616636	9279	Economy	44300.00
0005433578174	9279	Economy	44300.00
0005433616651	9279	Economy	44300.00
0005433616601	9279	Economy	44300.00
0005433616635	9279	Economy	44300.00
0005433616658	9279	Economy	44300.00
0005433616624	9279	Economy	44300.00
0005433634720	9279	Economy	44300.00
0005433634736	9279	Economy	44300.00
0005433616627	9279	Economy	44300.00
0005433616628	9279	Economy	44300.00
0005433616610	9279	Economy	44300.00
0005433616602	9279	Economy	44300.00
0005433634724	9279	Economy	44300.00
0005433616599	9279	Economy	44300.00
0005434163788	9279	Economy	44300.00
0005433616645	9279	Economy	44300.00
0005433634721	9279	Economy	44300.00
0005433616643	9279	Economy	44300.00
0005433634732	9279	Economy	44300.00
0005432755167	9279	Economy	44300.00
0005433616641	9279	Economy	44300.00
0005433634717	9279	Economy	44300.00
0005433634731	9279	Economy	44300.00
0005433616655	9279	Economy	44300.00
0005433616609	9279	Economy	44300.00
0005433616639	9279	Economy	44300.00
0005433634715	9279	Economy	44300.00
0005433616637	9279	Economy	44300.00
0005433616617	9279	Economy	44300.00
0005433616656	9279	Economy	44300.00
0005433634438	25221	Business	132900.00
0005433634527	25221	Business	132900.00
0005433634403	25221	Business	132900.00
0005433578016	25221	Business	132900.00
0005433616326	25221	Business	132900.00
0005433616181	25221	Business	132900.00
0005433578081	25221	Business	132900.00
0005433634465	25221	Business	132900.00
0005433615863	25221	Business	132900.00
0005433616247	25221	Business	132900.00
0005433634384	25221	Business	132900.00
0005433616173	25221	Business	132900.00
0005433634376	25221	Business	132900.00
0005433615995	25221	Business	132900.00
0005433634286	25221	Business	132900.00
0005433578121	25221	Business	132900.00
0005433634479	25221	Business	132900.00
0005433616128	25221	Business	132900.00
0005433616217	25221	Business	132900.00
0005434163862	25221	Business	132900.00
0005433615419	25221	Business	132900.00
0005433577983	25221	Business	132900.00
0005433616003	25221	Business	132900.00
0005433615954	25221	Economy	48700.00
0005434272233	25221	Economy	48700.00
0005433616114	25221	Economy	48700.00
0005433634302	25221	Economy	48700.00
0005433615902	25221	Economy	48700.00
0005433616369	25221	Economy	44300.00
0005433615916	25221	Economy	44300.00
0005433616174	25221	Economy	44300.00
0005433634469	25221	Economy	44300.00
0005433634402	25221	Economy	44300.00
0005433615884	25221	Economy	44300.00
0005433615903	25221	Economy	44300.00
0005433616218	25221	Economy	44300.00
0005433634430	25221	Economy	44300.00
0005434163865	25221	Economy	44300.00
0005433616271	25221	Economy	44300.00
0005433615991	25221	Economy	44300.00
0005433616012	25221	Economy	44300.00
0005433616120	25221	Economy	44300.00
0005433578050	25221	Economy	44300.00
0005433616198	25221	Economy	44300.00
0005433616118	25221	Economy	44300.00
0005433634457	25221	Economy	44300.00
0005433634370	25221	Economy	44300.00
0005433634235	25221	Economy	44300.00
0005433634410	25221	Economy	44300.00
0005433615654	25221	Economy	44300.00
0005433615653	25221	Economy	44300.00
0005433616101	25221	Economy	44300.00
0005433616004	25221	Economy	44300.00
0005433615928	25221	Economy	44300.00
0005433634349	25221	Economy	44300.00
0005433616370	25221	Economy	44300.00
0005433578106	25221	Economy	44300.00
0005433616129	25221	Economy	44300.00
0005433634459	25221	Economy	44300.00
0005433616196	25221	Economy	44300.00
0005433634352	25221	Economy	44300.00
0005433634490	25221	Economy	44300.00
0005433615975	25221	Economy	44300.00
0005433616038	25221	Economy	44300.00
0005433578084	25221	Economy	44300.00
0005433578028	25221	Economy	44300.00
0005433615828	25221	Economy	44300.00
0005433616036	25221	Economy	44300.00
0005433634461	25221	Economy	44300.00
0005433634477	25221	Economy	44300.00
0005433634377	25221	Economy	44300.00
0005433634443	25221	Economy	44300.00
0005433634379	25221	Economy	44300.00
0005434272232	25221	Economy	44300.00
0005433578038	25221	Economy	44300.00
0005433616248	25221	Economy	44300.00
0005433634303	25221	Economy	44300.00
0005433578120	25221	Economy	44300.00
0005433616182	25221	Economy	48700.00
0005433634375	25221	Economy	44300.00
0005433615985	25221	Economy	48700.00
0005433616283	25221	Economy	48700.00
0005433634437	25221	Economy	48700.00
0005433615905	25221	Economy	44300.00
0005434163863	25221	Economy	44300.00
0005433615862	25221	Economy	44300.00
0005434272231	25221	Economy	44300.00
0005433616119	25221	Economy	48700.00
0005433615885	25221	Economy	44300.00
0005434163866	25221	Economy	44300.00
0005433615990	25221	Economy	44300.00
0005433634298	25221	Economy	44300.00
0005433634436	25221	Economy	44300.00
0005433616186	25221	Economy	44300.00
0005433615879	25221	Economy	44300.00
0005433616265	25221	Economy	44300.00
0005433634476	25221	Economy	44300.00
0005433615711	25221	Economy	44300.00
0005433634305	25221	Economy	44300.00
0005433615883	25221	Economy	44300.00
0005433634299	25221	Economy	44300.00
0005433634491	25221	Economy	44300.00
0005433634478	25221	Economy	44300.00
0005433634497	25221	Economy	44300.00
0005433634444	25221	Economy	44300.00
0005433578023	25221	Economy	44300.00
0005433634412	25221	Economy	44300.00
0005433578015	25221	Economy	44300.00
0005433634521	25221	Economy	44300.00
0005433616099	25221	Economy	44300.00
0005433634429	25221	Economy	44300.00
0005433616037	25221	Economy	44300.00
0005433615994	25221	Economy	44300.00
0005433634287	25221	Economy	44300.00
0005433578087	25221	Economy	44300.00
0005433634304	25221	Economy	44300.00
0005433616121	25221	Economy	44300.00
0005433615803	25221	Economy	44300.00
0005433616011	25221	Economy	44300.00
0005433615876	25221	Economy	44300.00
0005433616013	25221	Economy	44300.00
0005433615709	25221	Economy	44300.00
0005433616098	25221	Economy	44300.00
0005433578088	25221	Economy	44300.00
0005433615842	25221	Economy	44300.00
0005433616220	25221	Economy	44300.00
0005433616097	25221	Economy	44300.00
0005433616117	25221	Economy	44300.00
0005433634321	25221	Economy	44300.00
0005433616237	25221	Economy	44300.00
0005433634350	25221	Economy	44300.00
0005433616192	25221	Economy	44300.00
0005433616295	25221	Economy	44300.00
0005433616290	25221	Economy	44300.00
0005433616100	25221	Economy	44300.00
0005434163864	25221	Economy	44300.00
0005434163867	25221	Economy	44300.00
0005433634466	25221	Economy	44300.00
0005433616275	25221	Economy	44300.00
0005433615888	25221	Economy	44300.00
0005433634344	25221	Economy	44300.00
0005433615861	25221	Economy	44300.00
0005434273120	25221	Economy	44300.00
0005433616193	25221	Economy	44300.00
0005435987014	4250	Business	193100.00
0005435947599	4250	Business	193100.00
0005434271349	4250	Business	193100.00
0005435987002	4250	Economy	64400.00
0005435947512	4250	Economy	64400.00
0005435987012	4250	Economy	64400.00
0005435987003	4250	Economy	64400.00
0005435947508	4250	Economy	64400.00
0005435987009	4250	Economy	64400.00
0005435947533	4250	Economy	64400.00
0005435986998	4250	Economy	64400.00
0005435787383	4250	Economy	64400.00
0005435987010	4250	Economy	64400.00
0005435947513	4250	Economy	64400.00
0005435854066	4250	Economy	64400.00
0005435987017	4250	Economy	64400.00
0005432185030	4250	Economy	64400.00
0005432185029	4250	Economy	64400.00
0005435987018	4250	Economy	64400.00
0005435787382	4250	Economy	64400.00
0005435947507	4250	Economy	64400.00
0005435987001	4250	Economy	64400.00
0005435787384	4250	Economy	64400.00
0005435947561	4250	Economy	64400.00
0005435947598	4250	Economy	64400.00
0005435856286	4250	Economy	64400.00
0005435947518	4250	Economy	64400.00
0005435987000	4250	Economy	64400.00
0005435987005	4250	Economy	64400.00
0005435947532	4250	Economy	64400.00
0005435947475	4250	Economy	64400.00
0005435856274	4250	Economy	64400.00
0005435947544	4250	Economy	64400.00
0005432185028	4250	Economy	64400.00
0005435987016	4250	Economy	64400.00
0005435987011	4250	Economy	64400.00
0005435947562	4250	Economy	70800.00
0005435947514	4250	Economy	64400.00
0005435987004	4250	Economy	64400.00
0005435947536	4250	Economy	64400.00
0005434271350	4250	Economy	64400.00
0005435947509	4250	Economy	64400.00
0005435947575	4250	Economy	64400.00
0005435986999	4250	Economy	64400.00
0005435856287	4250	Economy	64400.00
0005435856285	4250	Economy	64400.00
0005435987008	4250	Economy	64400.00
0005435854068	4250	Economy	64400.00
0005435947543	4250	Economy	64400.00
0005435987007	4250	Economy	64400.00
0005435987013	4250	Economy	64400.00
0005435987015	4250	Economy	64400.00
0005435947581	4250	Economy	64400.00
0005435987006	4250	Economy	64400.00
0005435854067	4250	Economy	64400.00
0005435947459	4250	Economy	64400.00
0005435856288	4250	Economy	64400.00
0005435856321	26571	Business	193100.00
0005435947649	26571	Business	193100.00
0005435947659	26571	Business	193100.00
0005435947653	26571	Business	193100.00
0005435787412	26571	Business	193100.00
0005435986939	26571	Economy	70800.00
0005435986901	26571	Economy	64400.00
0005435947654	26571	Economy	64400.00
0005435856354	26571	Economy	64400.00
0005435986887	26571	Economy	64400.00
0005435986903	26571	Economy	64400.00
0005435986900	26571	Economy	64400.00
0005432571429	26571	Economy	64400.00
0005435986875	26571	Economy	64400.00
0005435856355	26571	Economy	64400.00
0005435856322	26571	Economy	64400.00
0005435986892	26571	Economy	64400.00
0005435986893	26571	Economy	64400.00
0005435947651	26571	Economy	64400.00
0005435986868	26571	Economy	64400.00
0005435986886	26571	Economy	64400.00
0005435856320	26571	Economy	64400.00
0005432571428	26571	Economy	64400.00
0005435947655	26571	Economy	64400.00
0005435986890	26571	Economy	64400.00
0005435986906	26571	Economy	64400.00
0005435986907	26571	Economy	64400.00
0005435856323	26571	Economy	64400.00
0005435947656	26571	Economy	64400.00
0005435856356	26571	Economy	64400.00
0005435947657	26571	Economy	64400.00
0005435986891	26571	Economy	64400.00
0005435986905	26571	Economy	64400.00
0005435856353	26571	Economy	64400.00
0005435947650	26571	Economy	64400.00
0005435947652	26571	Economy	64400.00
0005432571427	26571	Economy	64400.00
0005435986882	26571	Economy	64400.00
0005435947660	26571	Economy	64400.00
0005435986874	26571	Economy	64400.00
0005435947658	26571	Economy	64400.00
0005434087958	334	Business	21500.00
0005433570790	334	Business	21500.00
0005433075141	334	Business	21500.00
0005432949352	334	Business	21500.00
0005433570783	334	Business	21500.00
0005433075189	334	Business	21500.00
0005432949253	334	Business	21500.00
0005433570768	334	Business	21500.00
0005434087948	334	Business	21500.00
0005433075236	334	Business	21500.00
0005432949209	334	Business	21500.00
0005433570765	334	Business	21500.00
0005433570818	334	Business	21500.00
0005433075379	334	Business	21500.00
0005433570791	334	Business	21500.00
0005434087957	334	Business	21500.00
0005433570796	334	Business	21500.00
0005433570824	334	Business	21500.00
0005434087942	334	Business	21500.00
0005433075307	334	Business	21500.00
0005432949380	334	Business	21500.00
0005433075237	334	Business	21500.00
0005433075166	334	Business	21500.00
0005433075213	334	Business	21500.00
0005432949402	334	Business	21500.00
0005433075320	334	Business	21500.00
0005433929860	334	Business	21500.00
0005432949232	334	Economy	7900.00
0005433075321	334	Economy	7900.00
0005433570815	334	Economy	7900.00
0005433570769	334	Economy	7900.00
0005434087940	334	Economy	7900.00
0005433129348	334	Economy	7900.00
0005433570810	334	Economy	7200.00
0005433134225	334	Economy	7200.00
0005433129349	334	Economy	7200.00
0005434087949	334	Economy	7200.00
0005433570764	334	Economy	7200.00
0005433075353	334	Economy	7200.00
0005432949200	334	Economy	7200.00
0005433929859	334	Economy	7200.00
0005432239105	334	Economy	7200.00
0005433075281	334	Economy	7200.00
0005433075292	334	Economy	7200.00
0005434087939	334	Economy	7200.00
0005434087953	334	Economy	7200.00
0005432949270	334	Economy	7200.00
0005432949403	334	Economy	7200.00
0005433570803	334	Economy	7200.00
0005433570813	334	Economy	7200.00
0005433075391	334	Economy	7200.00
0005434087960	334	Economy	7200.00
0005434087934	334	Economy	7200.00
0005433570797	334	Economy	7200.00
0005433075142	334	Economy	7200.00
0005434087941	334	Economy	7200.00
0005433570816	334	Economy	7200.00
0005433570802	334	Economy	7200.00
0005433570784	334	Economy	7200.00
0005433570782	334	Economy	7200.00
0005432949306	334	Economy	7200.00
0005433075390	334	Economy	7200.00
0005433570826	334	Economy	7200.00
0005434087935	334	Economy	7200.00
0005433570827	334	Economy	7200.00
0005433929861	334	Economy	7200.00
0005433570817	334	Economy	7200.00
0005433570787	334	Economy	7200.00
0005433570812	334	Economy	7200.00
0005434087961	334	Economy	7200.00
0005433570776	334	Economy	7200.00
0005434087932	334	Economy	7200.00
0005433570808	334	Economy	7200.00
0005433570771	334	Economy	7200.00
0005434087945	334	Economy	7200.00
0005433075148	334	Economy	7200.00
0005433075385	334	Economy	7200.00
0005434087959	334	Economy	7200.00
0005433075392	334	Economy	7200.00
0005433570806	334	Economy	7200.00
0005433075171	334	Economy	7200.00
0005434087951	334	Economy	7200.00
0005433134214	334	Economy	7200.00
0005432239106	334	Economy	7200.00
0005433075339	334	Economy	7200.00
0005432949302	334	Economy	7200.00
0005433075188	334	Economy	7200.00
0005433075172	334	Economy	7200.00
0005434087930	334	Economy	7200.00
0005433570793	334	Economy	7200.00
0005433075220	334	Economy	7200.00
0005433075322	334	Economy	7200.00
0005433570778	334	Economy	7200.00
0005434087955	334	Economy	7900.00
0005433570799	334	Economy	7900.00
0005434087933	334	Economy	7900.00
0005432949269	334	Economy	7900.00
0005433570821	334	Economy	7900.00
0005432949151	334	Economy	7200.00
0005433075293	334	Economy	7200.00
0005434087944	334	Economy	7200.00
0005432949381	334	Economy	7200.00
0005434087946	334	Economy	7900.00
0005433570772	334	Economy	7200.00
0005433129358	334	Economy	7200.00
0005432949277	334	Economy	7200.00
0005433075190	334	Economy	7200.00
0005432239104	334	Economy	7200.00
0005433570794	334	Economy	7200.00
0005432949208	334	Economy	7200.00
0005434087947	334	Economy	7200.00
0005432949278	334	Economy	7200.00
0005433075318	334	Economy	7200.00
0005433570777	334	Economy	7200.00
0005434087956	334	Economy	7200.00
0005433570819	334	Economy	7200.00
0005433570767	334	Economy	7200.00
0005433570781	334	Economy	7200.00
0005434087950	334	Economy	7200.00
0005434087943	334	Economy	7200.00
0005433075384	334	Economy	7200.00
0005433570825	334	Economy	7200.00
0005434087937	334	Economy	7200.00
0005433570798	334	Economy	7200.00
0005433570795	334	Economy	7200.00
0005433570775	334	Economy	7200.00
0005433570773	334	Economy	7200.00
0005433075195	334	Economy	7200.00
0005433570770	334	Economy	7200.00
0005433570804	334	Economy	7200.00
0005432949307	334	Economy	7200.00
0005434087938	334	Economy	7200.00
0005433570766	334	Economy	7200.00
0005433134213	334	Economy	7200.00
0005432239103	334	Economy	7200.00
0005433075280	334	Economy	7200.00
0005433570785	334	Economy	7200.00
0005433075165	334	Economy	7200.00
0005433570822	334	Economy	7200.00
0005433075311	334	Economy	7200.00
0005433570823	334	Economy	7200.00
0005434087931	334	Economy	7200.00
0005433570786	334	Economy	7200.00
0005434087954	334	Economy	7200.00
0005432949299	334	Economy	7200.00
0005433929862	334	Economy	7200.00
0005433075337	334	Economy	7200.00
0005433570800	334	Economy	7200.00
0005433570788	334	Economy	7200.00
0005433570811	334	Economy	7200.00
0005433075317	334	Economy	7200.00
0005433570789	334	Economy	7200.00
0005433075338	334	Economy	7200.00
0005433570814	334	Economy	7200.00
0005433570780	334	Economy	7200.00
0005434087952	334	Economy	7200.00
0005432949431	334	Economy	7200.00
0005433570801	334	Economy	7200.00
0005432949351	334	Economy	7200.00
0005433570763	334	Economy	7200.00
0005433570774	334	Economy	7200.00
0005433570820	334	Economy	7200.00
0005433570807	334	Economy	7200.00
0005433570792	334	Economy	7200.00
0005434087936	334	Economy	7200.00
0005433570779	334	Economy	7200.00
0005433570809	334	Economy	7200.00
0005433570805	334	Economy	7200.00
0005432949150	334	Economy	7200.00
0005433075482	11622	Business	21500.00
0005432949572	11622	Business	21500.00
0005432949575	11622	Business	21500.00
0005433570186	11622	Business	21500.00
0005433570098	11622	Business	21500.00
0005433569841	11622	Business	21500.00
0005432949570	11622	Business	21500.00
0005432949584	11622	Business	21500.00
0005433569932	11622	Business	21500.00
0005433570201	11622	Business	21500.00
0005433075478	11622	Business	21500.00
0005433569973	11622	Business	21500.00
0005433570215	11622	Business	21500.00
0005433570076	11622	Business	21500.00
0005433570005	11622	Business	21500.00
0005432949578	11622	Business	21500.00
0005433570154	11622	Business	21500.00
0005433569913	11622	Business	21500.00
0005433570048	11622	Business	21500.00
0005433929880	11622	Business	21500.00
0005433570424	11622	Business	21500.00
0005433570124	11622	Business	21500.00
0005433570144	11622	Business	21500.00
0005432949574	11622	Economy	7900.00
0005433570024	11622	Business	21500.00
0005433570204	11622	Economy	7900.00
0005432949567	11622	Economy	7900.00
0005433570184	11622	Economy	7900.00
0005432949557	11622	Economy	7900.00
0005433570034	11622	Economy	7200.00
0005433570069	11622	Economy	7200.00
0005433570089	11622	Economy	7200.00
0005432949569	11622	Economy	7200.00
0005433570349	11622	Economy	7200.00
0005433570117	11622	Economy	7200.00
0005433570297	11622	Economy	7200.00
0005432949565	11622	Economy	7200.00
0005433075472	11622	Economy	7200.00
0005433075476	11622	Economy	7200.00
0005432949579	11622	Economy	7200.00
0005433075479	11622	Economy	7200.00
0005433570236	11622	Economy	7200.00
0005433570143	11622	Economy	7200.00
0005433570073	11622	Economy	7200.00
0005433075468	11622	Economy	7200.00
0005433075495	11622	Economy	7200.00
0005433134257	11622	Economy	7200.00
0005432949583	11622	Economy	7200.00
0005432949571	11622	Economy	7200.00
0005432949585	11622	Economy	7200.00
0005432949562	11622	Economy	7200.00
0005433075484	11622	Economy	7200.00
0005433134258	11622	Economy	7200.00
0005432949556	11622	Economy	7200.00
0005433075481	11622	Economy	7200.00
0005433075485	11622	Economy	7200.00
0005433131831	11622	Economy	7200.00
0005433569981	11622	Economy	7200.00
0005433570071	11622	Economy	7200.00
0005433075471	11622	Economy	7200.00
0005432949576	11622	Economy	7200.00
0005433570547	11622	Economy	7200.00
0005433075474	11622	Economy	7200.00
0005433075469	11622	Economy	7200.00
0005433570289	11622	Economy	7200.00
0005433075488	11622	Economy	7200.00
0005432949568	11622	Economy	7200.00
0005432192406	11622	Economy	7200.00
0005433075490	11622	Economy	7200.00
0005433570214	11622	Economy	7200.00
0005433570153	11622	Economy	7200.00
0005432949564	11622	Economy	7200.00
0005433570039	11622	Economy	7200.00
0005433570141	11622	Economy	7200.00
0005433570136	11622	Economy	7900.00
0005433570185	11622	Economy	7900.00
0005433569998	11622	Economy	7900.00
0005433569994	11622	Economy	7900.00
0005433569933	11622	Economy	7200.00
0005432949555	11622	Economy	7200.00
0005432949563	11622	Economy	7900.00
0005433075491	11622	Economy	7200.00
0005432949558	11622	Economy	7200.00
0005433570234	11622	Economy	7200.00
0005432949580	11622	Economy	7200.00
0005433569911	11622	Economy	7200.00
0005433570094	11622	Economy	7200.00
0005433075480	11622	Economy	7200.00
0005433075493	11622	Economy	7200.00
0005432949582	11622	Economy	7200.00
0005433570142	11622	Economy	7200.00
0005433569912	11622	Economy	7200.00
0005433570040	11622	Economy	7200.00
0005433570070	11622	Economy	7200.00
0005432949581	11622	Economy	7200.00
0005433570177	11622	Economy	7200.00
0005432949573	11622	Economy	7200.00
0005433570116	11622	Economy	7200.00
0005432949560	11622	Economy	7200.00
0005433570109	11622	Economy	7200.00
0005433569980	11622	Economy	7200.00
0005432949577	11622	Economy	7200.00
0005432949561	11622	Economy	7200.00
0005433570213	11622	Economy	7200.00
0005433570013	11622	Economy	7200.00
0005433570342	11622	Economy	7200.00
0005433929882	11622	Economy	7200.00
0005433569982	11622	Economy	7200.00
0005433569778	11622	Economy	7200.00
0005433075477	11622	Economy	7200.00
0005433075494	11622	Economy	7200.00
0005433570066	11622	Economy	7200.00
0005433075470	11622	Economy	7200.00
0005433570014	11622	Economy	7200.00
0005433929879	11622	Economy	7200.00
0005433075483	11622	Economy	7200.00
0005432192407	11622	Economy	7200.00
0005433569946	11622	Economy	7200.00
0005433569945	11622	Economy	7200.00
0005433570369	11622	Economy	7200.00
0005433570203	11622	Economy	7200.00
0005433075475	11622	Economy	7200.00
0005433075492	11622	Economy	7200.00
0005433929881	11622	Economy	7200.00
0005433570047	11622	Economy	7200.00
0005432949566	11622	Economy	7200.00
0005432949559	11622	Economy	7200.00
0005433075489	11622	Economy	7200.00
0005433570348	11622	Economy	7200.00
0005433075487	11622	Economy	7200.00
0005433570088	11622	Economy	7200.00
0005433075486	11622	Economy	7200.00
0005433075473	11622	Economy	7200.00
0005434733053	9941	Economy	6300.00
0005434733052	9941	Economy	6300.00
0005434733046	9941	Economy	6300.00
0005433817572	9941	Economy	6300.00
0005434733079	13976	Economy	6300.00
0005434733077	13976	Economy	6300.00
0005434733080	13976	Economy	6300.00
0005433817535	13976	Economy	6300.00
0005434733078	13976	Economy	6300.00
0005433817566	13976	Economy	6300.00
0005433817534	13976	Economy	6300.00
0005433817539	13976	Economy	6300.00
0005433435176	2334	Business	184500.00
0005433755751	2334	Business	184500.00
0005435983554	2334	Business	184500.00
0005432985687	2334	Business	184500.00
0005433755772	2334	Business	184500.00
0005432300422	2334	Business	184500.00
0005435983560	2334	Business	184500.00
0005432985703	2334	Business	184500.00
0005433755735	2334	Business	184500.00
0005432985743	2334	Business	184500.00
0005433766743	2334	Business	184500.00
0005433435166	2334	Business	184500.00
0005433755738	2334	Business	184500.00
0005433755755	2334	Business	184500.00
0005432226225	2334	Business	184500.00
0005435983552	2334	Business	184500.00
0005435983549	2334	Business	184500.00
0005435983571	2334	Business	184500.00
0005433435317	2334	Business	184500.00
0005433435137	2334	Business	184500.00
0005433435236	2334	Business	184500.00
0005435983562	2334	Economy	67700.00
0005433755765	2334	Economy	67700.00
0005433755766	2334	Economy	67700.00
0005432985547	2334	Economy	67700.00
0005432655868	2334	Economy	61500.00
0005432985674	2334	Economy	61500.00
0005433435319	2334	Economy	61500.00
0005432655864	2334	Economy	61500.00
0005432985598	2334	Economy	61500.00
0005433755761	2334	Economy	61500.00
0005435983553	2334	Economy	61500.00
0005433755744	2334	Economy	61500.00
0005433755736	2334	Economy	61500.00
0005433435206	2334	Economy	61500.00
0005432655863	2334	Economy	61500.00
0005433755748	2334	Economy	61500.00
0005433766762	2334	Economy	61500.00
0005433755745	2334	Economy	61500.00
0005432226228	2334	Economy	61500.00
0005433755749	2334	Economy	61500.00
0005433755763	2334	Economy	61500.00
0005433755737	2334	Economy	61500.00
0005432985698	2334	Economy	61500.00
0005433435251	2334	Economy	61500.00
0005433755756	2334	Economy	61500.00
0005435983551	2334	Economy	61500.00
0005433755767	2334	Economy	61500.00
0005435983564	2334	Economy	61500.00
0005435983575	2334	Economy	61500.00
0005433755759	2334	Economy	61500.00
0005432985672	2334	Economy	61500.00
0005433435323	2334	Economy	61500.00
0005432655860	2334	Economy	61500.00
0005435983561	2334	Economy	61500.00
0005433435214	2334	Economy	61500.00
0005433435136	2334	Economy	61500.00
0005435983577	2334	Economy	61500.00
0005433755740	2334	Economy	61500.00
0005433435271	2334	Economy	61500.00
0005432655865	2334	Economy	61500.00
0005432869631	2334	Economy	61500.00
0005433435272	2334	Economy	61500.00
0005435983555	2334	Economy	61500.00
0005435983547	2334	Economy	61500.00
0005433435273	2334	Economy	61500.00
0005433435250	2334	Economy	61500.00
0005435983559	2334	Economy	61500.00
0005433755762	2334	Economy	61500.00
0005432985667	2334	Economy	61500.00
0005432655867	2334	Economy	61500.00
0005433435229	2334	Economy	61500.00
0005432985697	2334	Economy	61500.00
0005433435235	2334	Economy	61500.00
0005435983550	2334	Economy	61500.00
0005433755758	2334	Economy	61500.00
0005432985700	2334	Economy	61500.00
0005433435244	2334	Economy	61500.00
0005432985644	2334	Economy	61500.00
0005433755747	2334	Economy	61500.00
0005433435090	2334	Economy	61500.00
0005435983565	2334	Economy	61500.00
0005433755771	2334	Economy	61500.00
0005432300424	2334	Economy	61500.00
0005433764735	2334	Economy	61500.00
0005432300423	2334	Economy	61500.00
0005435983568	2334	Economy	61500.00
0005433435213	2334	Economy	61500.00
0005435983548	2334	Economy	61500.00
0005432985629	2334	Economy	61500.00
0005433755732	2334	Economy	61500.00
0005433435167	2334	Economy	61500.00
0005433435265	2334	Economy	61500.00
0005432300425	2334	Economy	61500.00
0005435983576	2334	Economy	61500.00
0005433755757	2334	Economy	61500.00
0005433435165	2334	Economy	67700.00
0005433435255	2334	Economy	61500.00
0005433435088	2334	Economy	61500.00
0005433755739	2334	Economy	61500.00
0005433755742	2334	Economy	67700.00
0005433755741	2334	Economy	61500.00
0005435983572	2334	Economy	61500.00
0005433435247	2334	Economy	61500.00
0005435983557	2334	Economy	61500.00
0005432985630	2334	Economy	61500.00
0005432226227	2334	Economy	61500.00
0005432985755	2334	Economy	61500.00
0005433755770	2334	Economy	61500.00
0005432985732	2334	Economy	61500.00
0005435983570	2334	Economy	61500.00
0005435983558	2334	Economy	61500.00
0005433755754	2334	Economy	61500.00
0005432300421	2334	Economy	61500.00
0005432985744	2334	Economy	61500.00
0005433435228	2334	Economy	61500.00
0005433755752	2334	Economy	61500.00
0005433755764	2334	Economy	61500.00
0005432985760	2334	Economy	61500.00
0005432655861	2334	Economy	61500.00
0005432226224	2334	Economy	61500.00
0005435983567	2334	Economy	61500.00
0005435983569	2334	Economy	61500.00
0005433435307	2334	Economy	61500.00
0005432655866	2334	Economy	61500.00
0005432985759	2334	Economy	61500.00
0005433755769	2334	Economy	61500.00
0005433766744	2334	Economy	61500.00
0005432655862	2334	Economy	61500.00
0005433755750	2334	Economy	61500.00
0005435983563	2334	Economy	61500.00
0005432985660	2334	Economy	61500.00
0005432985741	2334	Economy	61500.00
0005432985702	2334	Economy	61500.00
0005433755733	2334	Economy	61500.00
0005435983556	2334	Economy	61500.00
0005433755743	2334	Economy	61500.00
0005432985643	2334	Economy	61500.00
0005435983546	2334	Economy	61500.00
0005433755760	2334	Economy	61500.00
0005432985733	2334	Economy	61500.00
0005435983574	2334	Economy	61500.00
0005432655869	2334	Economy	61500.00
0005435983566	2334	Economy	61500.00
0005432985742	2334	Economy	61500.00
0005435983573	2334	Economy	61500.00
0005433435322	2334	Economy	61500.00
0005433435168	2334	Economy	61500.00
0005435983580	2334	Economy	61500.00
0005432226223	2334	Economy	61500.00
0005432985758	2334	Economy	61500.00
0005433755734	2334	Economy	61500.00
0005432985751	2334	Economy	61500.00
0005432300426	2334	Economy	61500.00
0005432226226	2334	Economy	61500.00
0005433755746	2334	Economy	61500.00
0005433435293	2334	Economy	61500.00
0005433435089	2334	Economy	61500.00
0005432985625	2334	Economy	61500.00
0005433755768	2334	Economy	61500.00
0005433766763	2334	Economy	61500.00
0005432985701	2334	Economy	61500.00
0005432985599	2334	Economy	61500.00
0005435983578	2334	Economy	61500.00
0005433755753	2334	Economy	61500.00
0005432985609	2334	Economy	61500.00
0005435983579	2334	Economy	61500.00
0005432655699	26159	Business	184500.00
0005435983038	26159	Business	184500.00
0005433755150	26159	Business	184500.00
0005435983130	26159	Business	184500.00
0005432985951	26159	Business	184500.00
0005433755395	26159	Business	184500.00
0005433755546	26159	Business	184500.00
0005432985963	26159	Business	184500.00
0005434731289	26159	Business	184500.00
0005435983117	26159	Business	184500.00
0005432985959	26159	Business	184500.00
0005433435451	26159	Business	184500.00
0005433755312	26159	Business	184500.00
0005433755437	26159	Business	184500.00
0005435983151	26159	Business	184500.00
0005433755354	26159	Business	184500.00
0005432869706	26159	Business	184500.00
0005433435438	26159	Business	184500.00
0005435982989	26159	Economy	67700.00
0005433755269	26159	Economy	67700.00
0005433764710	26159	Economy	67700.00
0005433755303	26159	Economy	61500.00
0005435983162	26159	Economy	61500.00
0005432985957	26159	Economy	61500.00
0005432985949	26159	Economy	61500.00
0005432051216	26159	Economy	61500.00
0005432655720	26159	Economy	61500.00
0005433755279	26159	Economy	61500.00
0005432985948	26159	Economy	61500.00
0005432655739	26159	Economy	61500.00
0005433755436	26159	Economy	61500.00
0005433755493	26159	Economy	61500.00
0005433435449	26159	Economy	61500.00
0005432985960	26159	Economy	61500.00
0005432051215	26159	Economy	61500.00
0005432985961	26159	Economy	61500.00
0005433755153	26159	Economy	61500.00
0005433766731	26159	Economy	61500.00
0005433755394	26159	Economy	61500.00
0005433755346	26159	Economy	61500.00
0005432869704	26159	Economy	61500.00
0005434376165	26159	Economy	61500.00
0005435983061	26159	Economy	61500.00
0005433755132	26159	Economy	61500.00
0005432051213	26159	Economy	61500.00
0005433755501	26159	Economy	61500.00
0005433435441	26159	Economy	61500.00
0005433755234	26159	Economy	61500.00
0005433755037	26159	Economy	61500.00
0005433755500	26159	Economy	61500.00
0005433755246	26159	Economy	61500.00
0005432655734	26159	Economy	61500.00
0005435982990	26159	Economy	61500.00
0005435983060	26159	Economy	61500.00
0005432985954	26159	Economy	61500.00
0005433766711	26159	Economy	61500.00
0005432049561	26159	Economy	61500.00
0005432985950	26159	Economy	61500.00
0005433764718	26159	Economy	61500.00
0005433764709	26159	Economy	61500.00
0005433435447	26159	Economy	61500.00
0005433754923	26159	Economy	61500.00
0005435983008	26159	Economy	61500.00
0005435983033	26159	Economy	61500.00
0005435983080	26159	Economy	61500.00
0005433755275	26159	Economy	61500.00
0005434731288	26159	Economy	61500.00
0005432985946	26159	Economy	61500.00
0005432869703	26159	Economy	61500.00
0005433435450	26159	Economy	61500.00
0005433755267	26159	Economy	61500.00
0005433755209	26159	Economy	61500.00
0005433755195	26159	Economy	61500.00
0005434376164	26159	Economy	61500.00
0005434731286	26159	Economy	61500.00
0005433755208	26159	Economy	61500.00
0005433755260	26159	Economy	61500.00
0005433755316	26159	Economy	61500.00
0005433755266	26159	Economy	61500.00
0005432985956	26159	Economy	61500.00
0005432985953	26159	Economy	61500.00
0005435983043	26159	Economy	61500.00
0005433755254	26159	Economy	61500.00
0005433435448	26159	Economy	61500.00
0005435983271	26159	Economy	61500.00
0005433755433	26159	Economy	61500.00
0005433766718	26159	Economy	61500.00
0005435983007	26159	Economy	61500.00
0005433435444	26159	Economy	61500.00
0005433435437	26159	Economy	61500.00
0005433755474	26159	Economy	61500.00
0005433435439	26159	Economy	67700.00
0005433755522	26159	Economy	67700.00
0005433755020	26159	Economy	61500.00
0005433435435	26159	Economy	61500.00
0005432655773	26159	Economy	67700.00
0005432985952	26159	Economy	67700.00
0005433755280	26159	Economy	61500.00
0005433435442	26159	Economy	61500.00
0005434731287	26159	Economy	61500.00
0005432051214	26159	Economy	61500.00
0005433755233	26159	Economy	61500.00
0005433755475	26159	Economy	61500.00
0005435982955	26159	Economy	61500.00
0005432985955	26159	Economy	61500.00
0005433435445	26159	Economy	61500.00
0005433766713	26159	Economy	61500.00
0005432655759	26159	Economy	61500.00
0005433755249	26159	Economy	61500.00
0005433755179	26159	Economy	61500.00
0005435983183	26159	Economy	61500.00
0005432655804	26159	Economy	61500.00
0005433766732	26159	Economy	61500.00
0005433755149	26159	Economy	61500.00
0005433755103	26159	Economy	61500.00
0005435983241	26159	Economy	61500.00
0005433755188	26159	Economy	61500.00
0005433766719	26159	Economy	61500.00
0005433755361	26159	Economy	61500.00
0005433755158	26159	Economy	61500.00
0005433755194	26159	Economy	61500.00
0005433755268	26159	Economy	61500.00
0005432655776	26159	Economy	61500.00
0005432655721	26159	Economy	61500.00
0005433435446	26159	Economy	61500.00
0005433755038	26159	Economy	61500.00
0005435982973	26159	Economy	61500.00
0005435983160	26159	Economy	61500.00
0005432985944	26159	Economy	61500.00
0005433755213	26159	Economy	61500.00
0005433755344	26159	Economy	61500.00
0005433435440	26159	Economy	61500.00
0005435983067	26159	Economy	61500.00
0005433755380	26159	Economy	61500.00
0005433755265	26159	Economy	61500.00
0005433755547	26159	Economy	61500.00
0005435983081	26159	Economy	61500.00
0005432869705	26159	Economy	61500.00
0005433755355	26159	Economy	61500.00
0005433435436	26159	Economy	61500.00
0005432655768	26159	Economy	61500.00
0005433435443	26159	Economy	61500.00
0005432049562	26159	Economy	61500.00
0005432985962	26159	Economy	61500.00
0005432985947	26159	Economy	61500.00
0005432985943	26159	Economy	61500.00
0005432985958	26159	Economy	61500.00
0005432985945	26159	Economy	61500.00
0005433755141	26159	Economy	61500.00
0005435983079	26159	Economy	61500.00
0005434375935	1505	Business	38900.00
0005434375944	1505	Business	38900.00
0005434375921	1505	Business	38900.00
0005434375947	1505	Business	38900.00
0005434029696	1505	Business	38900.00
0005434375915	1505	Business	38900.00
0005434375922	1505	Business	38900.00
0005433151977	1505	Business	38900.00
0005433152123	1505	Business	38900.00
0005434375952	1505	Economy	13000.00
0005434375912	1505	Economy	13000.00
0005433152050	1505	Economy	13000.00
0005434375938	1505	Economy	13000.00
0005434375954	1505	Economy	13000.00
0005433151972	1505	Economy	13000.00
0005434375932	1505	Economy	13000.00
0005433461649	1505	Economy	13000.00
0005434376162	1505	Economy	13000.00
0005434375956	1505	Economy	13000.00
0005434375955	1505	Economy	13000.00
0005434375923	1505	Economy	13000.00
0005433764716	1505	Economy	13000.00
0005434375937	1505	Economy	13000.00
0005434029697	1505	Economy	13000.00
0005434375941	1505	Economy	13000.00
0005434375951	1505	Economy	13000.00
0005433152032	1505	Economy	13000.00
0005434376232	1505	Economy	13000.00
0005433152148	1505	Economy	13000.00
0005434376163	1505	Economy	13000.00
0005434375949	1505	Economy	13000.00
0005434375929	1505	Economy	13000.00
0005434375911	1505	Economy	13000.00
0005433152164	1505	Economy	13000.00
0005434375940	1505	Economy	13000.00
0005434375936	1505	Economy	13000.00
0005433152131	1505	Economy	13000.00
0005433461648	1505	Economy	13000.00
0005433460494	1505	Economy	13000.00
0005434375926	1505	Economy	13000.00
0005434376234	1505	Economy	14300.00
0005432268082	1505	Economy	14300.00
0005433152097	1505	Economy	13000.00
0005433152124	1505	Economy	14300.00
0005433152054	1505	Economy	13000.00
0005433460496	1505	Economy	13000.00
0005433152074	1505	Economy	13000.00
0005433152167	1505	Economy	13000.00
0005432268079	1505	Economy	13000.00
0005434029703	1505	Economy	13000.00
0005434375939	1505	Economy	13000.00
0005433152122	1505	Economy	13000.00
0005434375953	1505	Economy	13000.00
0005433460495	1505	Economy	13000.00
0005433152053	1505	Economy	13000.00
0005434375924	1505	Economy	13000.00
0005433152098	1505	Economy	13000.00
0005434375945	1505	Economy	13000.00
0005432268080	1505	Economy	13000.00
0005434375950	1505	Economy	13000.00
0005433764717	1505	Economy	13000.00
0005434375928	1505	Economy	13000.00
0005434376178	1505	Economy	13000.00
0005434375943	1505	Economy	13000.00
0005433152163	1505	Economy	13000.00
0005434375914	1505	Economy	13000.00
0005434029695	1505	Economy	13000.00
0005434375933	1505	Economy	13000.00
0005434375918	1505	Economy	13000.00
0005434375946	1505	Economy	13000.00
0005433152082	1505	Economy	13000.00
0005434375917	1505	Economy	13000.00
0005433152016	1505	Economy	13000.00
0005434375920	1505	Economy	13000.00
0005434376181	1505	Economy	13000.00
0005433152126	1505	Economy	13000.00
0005434376231	1505	Economy	13000.00
0005433152075	1505	Economy	13000.00
0005433152047	1505	Economy	13000.00
0005432268078	1505	Economy	13000.00
0005434376180	1505	Economy	13000.00
0005433152141	1505	Economy	13000.00
0005432268081	1505	Economy	13000.00
0005434375927	1505	Economy	13000.00
0005433152144	1505	Economy	13000.00
0005434375916	1505	Economy	13000.00
0005433152149	1505	Economy	13000.00
0005434375910	1505	Economy	13000.00
0005433152071	1505	Economy	13000.00
0005434029701	1505	Economy	13000.00
0005434375934	1505	Economy	13000.00
0005434375930	1505	Economy	13000.00
0005434029702	1505	Economy	13000.00
0005434375919	1505	Economy	13000.00
0005434376233	1505	Economy	13000.00
0005433152161	1505	Economy	13000.00
0005434375925	1505	Economy	13000.00
0005434375931	1505	Economy	13000.00
0005434375913	1505	Economy	13000.00
0005434376179	1505	Economy	13000.00
0005434375948	1505	Economy	13000.00
0005434375942	1505	Economy	13000.00
0005433152118	1505	Economy	13000.00
0005433152350	20130	Business	38900.00
0005434375374	20130	Business	38900.00
0005434375615	20130	Business	38900.00
0005434375548	20130	Business	38900.00
0005433152356	20130	Business	38900.00
0005434375414	20130	Business	38900.00
0005434375404	20130	Business	38900.00
0005434375609	20130	Business	38900.00
0005433931552	20130	Business	38900.00
0005434375482	20130	Business	38900.00
0005434375367	20130	Economy	13000.00
0005433152347	20130	Economy	13000.00
0005434375470	20130	Economy	13000.00
0005434375555	20130	Economy	13000.00
0005434375375	20130	Economy	13000.00
0005433152345	20130	Economy	13000.00
0005433152359	20130	Economy	13000.00
0005434375475	20130	Economy	13000.00
0005434375633	20130	Economy	13000.00
0005434375613	20130	Economy	13000.00
0005433152353	20130	Economy	13000.00
0005434375477	20130	Economy	13000.00
0005434375580	20130	Economy	13000.00
0005434375469	20130	Economy	13000.00
0005432056402	20130	Economy	13000.00
0005433152346	20130	Economy	13000.00
0005434375595	20130	Economy	13000.00
0005433152344	20130	Economy	13000.00
0005434375383	20130	Economy	13000.00
0005434375489	20130	Economy	13000.00
0005434375444	20130	Economy	13000.00
0005433764735	20130	Economy	13000.00
0005434375302	20130	Economy	13000.00
0005434375528	20130	Economy	13000.00
0005434375738	20130	Economy	13000.00
0005434375670	20130	Economy	13000.00
0005434375669	20130	Economy	13000.00
0005434375557	20130	Economy	13000.00
0005433152343	20130	Economy	13000.00
0005434375582	20130	Economy	13000.00
0005434375732	20130	Economy	13000.00
0005434375784	20130	Economy	14300.00
0005434375382	20130	Economy	14300.00
0005434375556	20130	Economy	14300.00
0005434375529	20130	Economy	14300.00
0005433152340	20130	Economy	14300.00
0005434375476	20130	Economy	14300.00
0005434375614	20130	Economy	13000.00
0005433152331	20130	Economy	13000.00
0005433152351	20130	Economy	13000.00
0005433152336	20130	Economy	13000.00
0005434375378	20130	Economy	13000.00
0005433152339	20130	Economy	13000.00
0005433152354	20130	Economy	13000.00
0005433152338	20130	Economy	13000.00
0005433152337	20130	Economy	13000.00
0005433152342	20130	Economy	13000.00
0005434375452	20130	Economy	13000.00
0005433152348	20130	Economy	13000.00
0005434375388	20130	Economy	13000.00
0005434375490	20130	Economy	13000.00
0005434375577	20130	Economy	13000.00
0005433152332	20130	Economy	13000.00
0005434375460	20130	Economy	13000.00
0005433152357	20130	Economy	13000.00
0005434375508	20130	Economy	13000.00
0005434375412	20130	Economy	13000.00
0005434375407	20130	Economy	13000.00
0005434375416	20130	Economy	13000.00
0005434029725	20130	Economy	13000.00
0005433152352	20130	Economy	13000.00
0005434375495	20130	Economy	13000.00
0005433152358	20130	Economy	13000.00
0005434375636	20130	Economy	13000.00
0005434375290	20130	Economy	13000.00
0005434375464	20130	Economy	13000.00
0005434375478	20130	Economy	13000.00
0005433152349	20130	Economy	13000.00
0005433152334	20130	Economy	13000.00
0005433152333	20130	Economy	13000.00
0005434375571	20130	Economy	13000.00
0005433152360	20130	Economy	13000.00
0005433931551	20130	Economy	13000.00
0005433152341	20130	Economy	13000.00
0005434375454	20130	Economy	13000.00
0005434375785	20130	Economy	13000.00
0005434375413	20130	Economy	13000.00
0005434375406	20130	Economy	13000.00
0005434375572	20130	Economy	13000.00
0005433152335	20130	Economy	13000.00
0005433152355	20130	Economy	13000.00
0005434375377	20130	Economy	13000.00
0005434375642	20130	Economy	13000.00
0005434375699	20130	Economy	13000.00
0005432425771	575	Business	27500.00
0005432425799	575	Business	27500.00
0005432425805	575	Business	27500.00
0005432425811	575	Business	27500.00
0005432425797	575	Business	27500.00
0005432425757	575	Business	27500.00
0005432425789	575	Business	27500.00
0005432425807	575	Business	27500.00
0005432425781	575	Business	27500.00
0005432425816	575	Business	27500.00
0005432425796	575	Business	27500.00
0005432425776	575	Business	27500.00
0005432283056	575	Business	27500.00
0005432425787	575	Economy	10100.00
0005432425772	575	Economy	10100.00
0005432425774	575	Economy	10100.00
0005432425791	575	Economy	9200.00
0005432425785	575	Economy	9200.00
0005432425775	575	Economy	9200.00
0005432425820	575	Economy	9200.00
0005432425766	575	Economy	9200.00
0005432425786	575	Economy	9200.00
0005432425765	575	Economy	9200.00
0005432425814	575	Economy	9200.00
0005432283055	575	Economy	9200.00
0005432425756	575	Economy	9200.00
0005432425802	575	Economy	9200.00
0005432425792	575	Economy	9200.00
0005432425794	575	Economy	9200.00
0005432425790	575	Economy	9200.00
0005432425821	575	Economy	9200.00
0005432425819	575	Economy	9200.00
0005432425758	575	Economy	9200.00
0005432425784	575	Economy	9200.00
0005432425808	575	Economy	9200.00
0005432425803	575	Economy	9200.00
0005432425763	575	Economy	9200.00
0005432425761	575	Economy	9200.00
0005432425768	575	Economy	10100.00
0005432425804	575	Economy	10100.00
0005432425788	575	Economy	10100.00
0005432425798	575	Economy	9200.00
0005432425773	575	Economy	9200.00
0005432425769	575	Economy	10100.00
0005432425770	575	Economy	9200.00
0005432425780	575	Economy	9200.00
0005432425813	575	Economy	9200.00
0005432283054	575	Economy	9200.00
0005432425777	575	Economy	9200.00
0005432425806	575	Economy	9200.00
0005432425809	575	Economy	9200.00
0005432425759	575	Economy	9200.00
0005432425793	575	Economy	9200.00
0005432425779	575	Economy	9200.00
0005432425764	575	Economy	9200.00
0005432425782	575	Economy	9200.00
0005432283057	575	Economy	9200.00
0005432425815	575	Economy	9200.00
0005432425767	575	Economy	9200.00
0005432425818	575	Economy	9200.00
0005432425817	575	Economy	9200.00
0005432425755	575	Economy	9200.00
0005432425795	575	Economy	9200.00
0005432425801	575	Economy	9200.00
0005432425812	575	Economy	9200.00
0005432425778	575	Economy	9200.00
0005432425760	575	Economy	9200.00
0005432425762	575	Economy	9200.00
0005432425810	575	Economy	9200.00
0005432425783	575	Economy	9200.00
0005432425800	575	Economy	9200.00
0005433261981	12837	Business	27500.00
0005434446557	12837	Business	27500.00
0005433261984	12837	Business	27500.00
0005432302436	12837	Business	27500.00
0005433158191	12837	Business	27500.00
0005432302435	12837	Business	27500.00
0005433261979	12837	Business	27500.00
0005433261971	12837	Business	27500.00
0005433261988	12837	Economy	10100.00
0005433261993	12837	Economy	10100.00
0005433261975	12837	Economy	10100.00
0005433157016	12837	Economy	10100.00
0005434446563	12837	Economy	9200.00
0005433766762	12837	Economy	9200.00
0005433261989	12837	Economy	9200.00
0005433261986	12837	Economy	9200.00
0005433261983	12837	Economy	9200.00
0005433261992	12837	Economy	9200.00
0005434446564	12837	Economy	9200.00
0005433261977	12837	Economy	9200.00
0005433766763	12837	Economy	9200.00
0005433157018	12837	Economy	9200.00
0005433261973	12837	Economy	9200.00
0005433261991	12837	Economy	9200.00
0005433261994	12837	Economy	9200.00
0005434446556	12837	Economy	9200.00
0005434446555	12837	Economy	9200.00
0005434446560	12837	Economy	9200.00
0005434446559	12837	Economy	10100.00
0005433261985	12837	Economy	10100.00
0005433261995	12837	Economy	9200.00
0005433261969	12837	Economy	9200.00
0005433261987	12837	Economy	9200.00
0005433261990	12837	Economy	9200.00
0005433261968	12837	Economy	9200.00
0005433157017	12837	Economy	9200.00
0005433158194	12837	Economy	9200.00
0005433261978	12837	Economy	9200.00
0005433261976	12837	Economy	9200.00
0005433261982	12837	Economy	9200.00
0005433158192	12837	Economy	9200.00
0005433158193	12837	Economy	9200.00
0005433261980	12837	Economy	9200.00
0005434446562	12837	Economy	9200.00
0005433261970	12837	Economy	9200.00
0005433261967	12837	Economy	9200.00
0005433261972	12837	Economy	9200.00
0005433261974	12837	Economy	9200.00
0005432425103	12848	Business	27500.00
0005432425369	12848	Business	27500.00
0005432425250	12848	Business	27500.00
0005432425296	12848	Business	27500.00
0005432425345	12848	Business	27500.00
0005432425377	12848	Business	27500.00
0005432425202	12848	Business	27500.00
0005432425372	12848	Economy	10100.00
0005432425299	12848	Economy	9200.00
0005432425358	12848	Economy	9200.00
0005432425179	12848	Economy	9200.00
0005432425327	12848	Economy	9200.00
0005432425353	12848	Economy	9200.00
0005432425178	12848	Economy	9200.00
0005432425272	12848	Economy	9200.00
0005432425222	12848	Economy	9200.00
0005432425303	12848	Economy	9200.00
0005432425244	12848	Economy	9200.00
0005432425201	12848	Economy	9200.00
0005432425356	12848	Economy	9200.00
0005432425352	12848	Economy	9200.00
0005432425292	12848	Economy	9200.00
0005432425360	12848	Economy	9200.00
0005432425365	12848	Economy	9200.00
0005432425180	12848	Economy	9200.00
0005432425344	12848	Economy	9200.00
0005432425351	12848	Economy	10100.00
0005432425249	12848	Economy	9200.00
0005432425245	12848	Economy	9200.00
0005432425374	12848	Economy	9200.00
0005432425270	12848	Economy	9200.00
0005432425366	12848	Economy	9200.00
0005432425251	12848	Economy	9200.00
0005432425373	12848	Economy	9200.00
0005432425330	12848	Economy	9200.00
0005432425357	12848	Economy	9200.00
0005432425253	12848	Economy	9200.00
0005432425246	12848	Economy	9200.00
0005432425181	12848	Economy	9200.00
0005432425248	12848	Economy	9200.00
0005432425354	12848	Economy	9200.00
0005432425255	12848	Economy	9200.00
0005432425256	12848	Economy	9200.00
0005432425223	12848	Economy	9200.00
0005432425262	12848	Economy	9200.00
0005432425297	12848	Economy	9200.00
0005432425257	12848	Economy	9200.00
0005432425104	12848	Economy	9200.00
0005432425271	12848	Economy	9200.00
0005432425231	12848	Economy	9200.00
0005434025576	485	Business	24500.00
0005434028387	485	Business	24500.00
0005433058658	485	Business	24500.00
0005433058607	485	Business	24500.00
0005433058807	485	Business	24500.00
0005434025550	485	Business	24500.00
0005432235847	485	Business	24500.00
0005434735784	485	Business	24500.00
0005433058689	485	Business	24500.00
0005434025580	485	Business	24500.00
0005433058684	485	Business	24500.00
0005433058680	485	Business	24500.00
0005433929679	485	Business	24500.00
0005434025562	485	Economy	9000.00
0005434025556	485	Economy	9000.00
0005433058759	485	Economy	8200.00
0005432045666	485	Economy	9000.00
0005434025540	485	Economy	8200.00
0005434025575	485	Economy	8200.00
0005433058808	485	Economy	8200.00
0005433058442	485	Economy	8200.00
0005434025553	485	Economy	8200.00
0005434025558	485	Economy	8200.00
0005433058605	485	Economy	8200.00
0005434025543	485	Economy	8200.00
0005432235846	485	Economy	8200.00
0005433058851	485	Economy	8200.00
0005433058760	485	Economy	8200.00
0005433058761	485	Economy	8200.00
0005433058621	485	Economy	8200.00
0005434025561	485	Economy	8200.00
0005432235845	485	Economy	8200.00
0005434025565	485	Economy	8200.00
0005433058606	485	Economy	8200.00
0005433058576	485	Economy	8200.00
0005434025557	485	Economy	8200.00
0005433058810	485	Economy	8200.00
0005433058733	485	Economy	8200.00
0005434025566	485	Economy	8200.00
0005432235843	485	Economy	8200.00
0005434032147	485	Economy	8200.00
0005433058494	485	Economy	8200.00
0005433058724	485	Economy	8200.00
0005434025568	485	Economy	8200.00
0005432045665	485	Economy	8200.00
0005434029723	485	Economy	8200.00
0005433058685	485	Economy	8200.00
0005433684454	485	Economy	8200.00
0005433058497	485	Economy	8200.00
0005434025547	485	Economy	8200.00
0005433058769	485	Economy	8200.00
0005434025559	485	Economy	8200.00
0005433058731	485	Economy	8200.00
0005433058659	485	Economy	8200.00
0005433058661	485	Economy	8200.00
0005433058681	485	Economy	8200.00
0005434025545	485	Economy	8200.00
0005433058809	485	Economy	8200.00
0005434028386	485	Economy	8200.00
0005434735785	485	Economy	8200.00
0005434025560	485	Economy	8200.00
0005433058496	485	Economy	8200.00
0005433058665	485	Economy	8200.00
0005433058575	485	Economy	8200.00
0005433058732	485	Economy	9000.00
0005434025554	485	Economy	8200.00
0005433058678	485	Economy	9000.00
0005434025548	485	Economy	9000.00
0005434025551	485	Economy	8200.00
0005433058739	485	Economy	8200.00
0005434025555	485	Economy	8200.00
0005434025571	485	Economy	8200.00
0005434025574	485	Economy	8200.00
0005433058574	485	Economy	8200.00
0005433058837	485	Economy	8200.00
0005433058627	485	Economy	8200.00
0005434025552	485	Economy	8200.00
0005434025549	485	Economy	8200.00
0005433058660	485	Economy	8200.00
0005433058827	485	Economy	8200.00
0005433058770	485	Economy	8200.00
0005434032148	485	Economy	8200.00
0005433058690	485	Economy	8200.00
0005433058577	485	Economy	8200.00
0005434028385	485	Economy	8200.00
0005434032146	485	Economy	8200.00
0005433058622	485	Economy	8200.00
0005434025570	485	Economy	8200.00
0005434025569	485	Economy	8200.00
0005434025542	485	Economy	8200.00
0005434025541	485	Economy	8200.00
0005433058723	485	Economy	8200.00
0005433929676	485	Economy	8200.00
0005434025567	485	Economy	8200.00
0005434025572	485	Economy	8200.00
0005434025581	485	Economy	8200.00
0005434025577	485	Economy	8200.00
0005433929692	485	Economy	8200.00
0005434025578	485	Economy	8200.00
0005432235844	485	Economy	8200.00
0005434735798	485	Economy	8200.00
0005434025564	485	Economy	8200.00
0005432235848	485	Economy	8200.00
0005434025546	485	Economy	8200.00
0005434025573	485	Economy	8200.00
0005434025563	485	Economy	8200.00
0005434025579	485	Economy	8200.00
0005433058708	485	Economy	8200.00
0005433058573	485	Economy	8200.00
0005434029724	485	Economy	8200.00
0005434025544	485	Economy	8200.00
0005433058836	485	Economy	8200.00
0005434025127	12664	Business	24500.00
0005434025191	12664	Business	24500.00
0005433058967	12664	Business	24500.00
0005433058977	12664	Business	24500.00
0005434024820	12664	Business	24500.00
0005433929721	12664	Business	24500.00
0005433058975	12664	Business	24500.00
0005434025126	12664	Business	24500.00
0005434024929	12664	Business	24500.00
0005434024984	12664	Business	24500.00
0005432156485	12664	Business	24500.00
0005434032125	12664	Business	24500.00
0005434024853	12664	Business	24500.00
0005433058992	12664	Business	24500.00
0005434028361	12664	Business	24500.00
0005434025012	12664	Business	24500.00
0005434024992	12664	Business	24500.00
0005434029702	12664	Economy	9000.00
0005433058972	12664	Economy	9000.00
0005434025007	12664	Economy	8200.00
0005434025131	12664	Economy	8200.00
0005434024939	12664	Economy	8200.00
0005434032107	12664	Economy	8200.00
0005434025103	12664	Economy	8200.00
0005434025051	12664	Economy	8200.00
0005433058973	12664	Economy	8200.00
0005434024930	12664	Economy	8200.00
0005434025166	12664	Economy	8200.00
0005434735832	12664	Economy	8200.00
0005433058969	12664	Economy	8200.00
0005433058985	12664	Economy	8200.00
0005434025052	12664	Economy	8200.00
0005433058964	12664	Economy	8200.00
0005434025189	12664	Economy	8200.00
0005433058966	12664	Economy	8200.00
0005433058994	12664	Economy	8200.00
0005434024819	12664	Economy	8200.00
0005434024986	12664	Economy	8200.00
0005433058986	12664	Economy	8200.00
0005434024808	12664	Economy	8200.00
0005434024956	12664	Economy	8200.00
0005432156486	12664	Economy	8200.00
0005434024987	12664	Economy	8200.00
0005434025013	12664	Economy	8200.00
0005434024805	12664	Economy	8200.00
0005434024887	12664	Economy	8200.00
0005434025029	12664	Economy	8200.00
0005434024954	12664	Economy	8200.00
0005434024893	12664	Economy	8200.00
0005434024933	12664	Economy	8200.00
0005433684477	12664	Economy	8200.00
0005434025132	12664	Economy	8200.00
0005433058990	12664	Economy	8200.00
0005434025129	12664	Economy	8200.00
0005434024888	12664	Economy	8200.00
0005434028371	12664	Economy	8200.00
0005434376231	12664	Economy	8200.00
0005434735833	12664	Economy	8200.00
0005434024807	12664	Economy	8200.00
0005433058984	12664	Economy	8200.00
0005434025130	12664	Economy	8200.00
0005433058968	12664	Economy	8200.00
0005434025004	12664	Economy	8200.00
0005434025150	12664	Economy	8200.00
0005433058989	12664	Economy	8200.00
0005434024806	12664	Economy	8200.00
0005434025283	12664	Economy	8200.00
0005434025244	12664	Economy	8200.00
0005433058988	12664	Economy	8200.00
0005434024736	12664	Economy	8200.00
0005434024904	12664	Economy	8200.00
0005434025125	12664	Economy	8200.00
0005434024908	12664	Economy	8200.00
0005433058982	12664	Economy	8200.00
0005434032103	12664	Economy	8200.00
0005434024996	12664	Economy	8200.00
0005434376233	12664	Economy	8200.00
0005433058971	12664	Economy	8200.00
0005433058978	12664	Economy	8200.00
0005434029695	12664	Economy	8200.00
0005434028370	12664	Economy	8200.00
0005434025124	12664	Economy	8200.00
0005434025190	12664	Economy	8200.00
0005434024927	12664	Economy	8200.00
0005434024751	12664	Economy	9000.00
0005433058974	12664	Economy	8200.00
0005434024821	12664	Economy	8200.00
0005434376232	12664	Economy	9000.00
0005434028358	12664	Economy	8200.00
0005434376234	12664	Economy	8200.00
0005433929724	12664	Economy	8200.00
0005434032108	12664	Economy	8200.00
0005433058993	12664	Economy	8200.00
0005434024955	12664	Economy	8200.00
0005433929723	12664	Economy	8200.00
0005434024854	12664	Economy	8200.00
0005433058981	12664	Economy	8200.00
0005434024400	12664	Economy	8200.00
0005433058970	12664	Economy	8200.00
0005434025038	12664	Economy	8200.00
0005433684478	12664	Economy	8200.00
0005434025114	12664	Economy	8200.00
0005434735834	12664	Economy	8200.00
0005434029701	12664	Economy	8200.00
0005434025207	12664	Economy	8200.00
0005434032126	12664	Economy	8200.00
0005434032106	12664	Economy	8200.00
0005433058987	12664	Economy	8200.00
0005434024966	12664	Economy	8200.00
0005434025037	12664	Economy	8200.00
0005433058991	12664	Economy	8200.00
0005433929722	12664	Economy	8200.00
0005434029696	12664	Economy	8200.00
0005434024857	12664	Economy	8200.00
0005434029703	12664	Economy	8200.00
0005433058976	12664	Economy	8200.00
0005434025225	12664	Economy	8200.00
0005434025159	12664	Economy	8200.00
0005434025112	12664	Economy	8200.00
0005434028353	12664	Economy	8200.00
0005434028354	12664	Economy	8200.00
0005433058980	12664	Economy	8200.00
0005434024919	12664	Economy	8200.00
0005434024633	12664	Economy	8200.00
0005434024902	12664	Economy	8200.00
0005434025067	12664	Economy	8200.00
0005433058965	12664	Economy	8200.00
0005434028355	12664	Economy	8200.00
0005434025158	12664	Economy	8200.00
0005434025113	12664	Economy	8200.00
0005434029697	12664	Economy	8200.00
0005434025160	12664	Economy	8200.00
0005434024921	12664	Economy	8200.00
0005433058979	12664	Economy	8200.00
0005434032105	12664	Economy	8200.00
0005433058983	12664	Economy	8200.00
0005433037485	2141	Business	34700.00
0005433925946	2141	Business	34700.00
0005433925938	2141	Business	34700.00
0005432044603	2141	Business	34700.00
0005433037108	2141	Business	34700.00
0005433925928	2141	Business	34700.00
0005433037501	2141	Business	34700.00
0005433037188	2141	Business	34700.00
0005433931552	2141	Business	34700.00
0005433925936	2141	Business	34700.00
0005433929878	2141	Business	34700.00
0005432231855	2141	Business	34700.00
0005433925908	2141	Business	34700.00
0005432749817	2141	Business	34700.00
0005434028354	2141	Business	34700.00
0005433925918	2141	Business	34700.00
0005433037217	2141	Business	34700.00
0005433925921	2141	Business	34700.00
0005433925911	2141	Business	34700.00
0005433929723	2141	Economy	12700.00
0005433037443	2141	Economy	12700.00
0005433037384	2141	Economy	12700.00
0005433925956	2141	Economy	11600.00
0005433037170	2141	Economy	11600.00
0005433037297	2141	Economy	11600.00
0005433037127	2141	Economy	11600.00
0005433037112	2141	Economy	11600.00
0005432231854	2141	Economy	11600.00
0005433925904	2141	Economy	11600.00
0005433925942	2141	Economy	11600.00
0005433925952	2141	Economy	11600.00
0005433925930	2141	Economy	11600.00
0005433925958	2141	Economy	11600.00
0005434028361	2141	Economy	11600.00
0005433925917	2141	Economy	11600.00
0005433925925	2141	Economy	11600.00
0005432231856	2141	Economy	11600.00
0005433036987	2141	Economy	11600.00
0005433925910	2141	Economy	11600.00
0005433925899	2141	Economy	11600.00
0005433929724	2141	Economy	11600.00
0005433925900	2141	Economy	11600.00
0005432044602	2141	Economy	11600.00
0005433037292	2141	Economy	11600.00
0005434028353	2141	Economy	11600.00
0005433925939	2141	Economy	11600.00
0005433925941	2141	Economy	11600.00
0005433925937	2141	Economy	11600.00
0005433925953	2141	Economy	11600.00
0005433037214	2141	Economy	11600.00
0005433925944	2141	Economy	11600.00
0005433037176	2141	Economy	11600.00
0005433929877	2141	Economy	11600.00
0005433925948	2141	Economy	11600.00
0005433925960	2141	Economy	11600.00
0005433037111	2141	Economy	11600.00
0005433037227	2141	Economy	11600.00
0005433037243	2141	Economy	11600.00
0005433925906	2141	Economy	11600.00
0005433037344	2141	Economy	11600.00
0005433037213	2141	Economy	11600.00
0005433925901	2141	Economy	11600.00
0005433037370	2141	Economy	11600.00
0005433929722	2141	Economy	11600.00
0005433925940	2141	Economy	11600.00
0005433925916	2141	Economy	11600.00
0005432231858	2141	Economy	11600.00
0005433037141	2141	Economy	11600.00
0005433037242	2141	Economy	11600.00
0005432231857	2141	Economy	11600.00
0005433925914	2141	Economy	11600.00
0005433925896	2141	Economy	11600.00
0005433925947	2141	Economy	11600.00
0005432044601	2141	Economy	11600.00
0005433925907	2141	Economy	11600.00
0005433037147	2141	Economy	11600.00
0005433037249	2141	Economy	11600.00
0005433925903	2141	Economy	11600.00
0005433925897	2141	Economy	11600.00
0005433925935	2141	Economy	11600.00
0005433925959	2141	Economy	11600.00
0005433037172	2141	Economy	11600.00
0005433037192	2141	Economy	11600.00
0005433037291	2141	Economy	12700.00
0005433037260	2141	Economy	11600.00
0005433929876	2141	Economy	11600.00
0005433925931	2141	Economy	11600.00
0005434028358	2141	Economy	12700.00
0005433925932	2141	Economy	12700.00
0005433925943	2141	Economy	11600.00
0005433925913	2141	Economy	11600.00
0005433037171	2141	Economy	11600.00
0005433925905	2141	Economy	11600.00
0005433925954	2141	Economy	11600.00
0005433037126	2141	Economy	11600.00
0005433037564	2141	Economy	11600.00
0005433037458	2141	Economy	11600.00
0005433925902	2141	Economy	11600.00
0005433925926	2141	Economy	11600.00
0005433929721	2141	Economy	11600.00
0005433925920	2141	Economy	11600.00
0005433925912	2141	Economy	11600.00
0005433037380	2141	Economy	11600.00
0005433925949	2141	Economy	11600.00
0005433925951	2141	Economy	11600.00
0005433037234	2141	Economy	11600.00
0005433925934	2141	Economy	11600.00
0005434028370	2141	Economy	11600.00
0005433925909	2141	Economy	11600.00
0005434028371	2141	Economy	11600.00
0005433037457	2141	Economy	11600.00
0005433925957	2141	Economy	11600.00
0005433925923	2141	Economy	11600.00
0005434028355	2141	Economy	11600.00
0005433925929	2141	Economy	11600.00
0005433925927	2141	Economy	11600.00
0005433037107	2141	Economy	11600.00
0005433925895	2141	Economy	11600.00
0005433037369	2141	Economy	11600.00
0005433925945	2141	Economy	11600.00
0005433925919	2141	Economy	11600.00
0005433931551	2141	Economy	11600.00
0005433037391	2141	Economy	11600.00
0005433925924	2141	Economy	11600.00
0005433925893	2141	Economy	11600.00
0005433037216	2141	Economy	11600.00
0005433925950	2141	Economy	11600.00
0005433037438	2141	Economy	11600.00
0005433925894	2141	Economy	11600.00
0005433925933	2141	Economy	11600.00
0005433037497	2141	Economy	11600.00
0005433875426	2141	Economy	11600.00
0005433037471	2141	Economy	11600.00
0005433037142	2141	Economy	11600.00
0005433875425	2141	Economy	11600.00
0005433925915	2141	Economy	11600.00
0005433925955	2141	Economy	11600.00
0005433925922	2141	Economy	11600.00
0005433037193	2141	Economy	11600.00
0005433925898	2141	Economy	11600.00
0005433924899	24097	Business	34700.00
0005434376182	24097	Business	34700.00
0005433925071	24097	Business	34700.00
0005433037752	24097	Business	34700.00
0005433037750	24097	Business	34700.00
0005433925310	24097	Business	34700.00
0005433925569	24097	Business	34700.00
0005433037717	24097	Business	34700.00
0005433925347	24097	Business	34700.00
0005433037744	24097	Business	34700.00
0005433925311	24097	Business	34700.00
0005433925053	24097	Business	34700.00
0005433925326	24097	Business	34700.00
0005433037721	24097	Business	34700.00
0005433037718	24097	Business	34700.00
0005433925084	24097	Business	34700.00
0005433925111	24097	Business	34700.00
0005433925017	24097	Business	34700.00
0005433925052	24097	Business	34700.00
0005433037743	24097	Business	34700.00
0005433925024	24097	Business	34700.00
0005433924819	24097	Business	34700.00
0005433037755	24097	Economy	12700.00
0005433924900	24097	Economy	12700.00
0005433929863	24097	Economy	12700.00
0005433037735	24097	Economy	11600.00
0005433925002	24097	Economy	12700.00
0005433925068	24097	Economy	11600.00
0005433925066	24097	Economy	11600.00
0005433925568	24097	Economy	11600.00
0005434376184	24097	Economy	11600.00
0005433037722	24097	Economy	11600.00
0005433925514	24097	Economy	11600.00
0005433037737	24097	Economy	11600.00
0005433925054	24097	Economy	11600.00
0005433924855	24097	Economy	11600.00
0005433037730	24097	Economy	11600.00
0005432749845	24097	Economy	11600.00
0005432207734	24097	Economy	11600.00
0005433875412	24097	Economy	11600.00
0005433925205	24097	Economy	11600.00
0005433037724	24097	Economy	11600.00
0005433924920	24097	Economy	11600.00
0005433925122	24097	Economy	11600.00
0005433037738	24097	Economy	11600.00
0005433037751	24097	Economy	11600.00
0005432206355	24097	Economy	11600.00
0005433925027	24097	Economy	11600.00
0005433925042	24097	Economy	11600.00
0005433924928	24097	Economy	11600.00
0005433925406	24097	Economy	11600.00
0005433037732	24097	Economy	11600.00
0005433037726	24097	Economy	11600.00
0005433925067	24097	Economy	11600.00
0005433925409	24097	Economy	11600.00
0005433037728	24097	Economy	11600.00
0005433925303	24097	Economy	11600.00
0005433924670	24097	Economy	11600.00
0005433925070	24097	Economy	11600.00
0005433037736	24097	Economy	11600.00
0005433925222	24097	Economy	11600.00
0005433037720	24097	Economy	11600.00
0005434028388	24097	Economy	11600.00
0005433924911	24097	Economy	11600.00
0005433924463	24097	Economy	11600.00
0005433924935	24097	Economy	11600.00
0005433924465	24097	Economy	11600.00
0005433925502	24097	Economy	11600.00
0005433925004	24097	Economy	11600.00
0005433037742	24097	Economy	11600.00
0005433924766	24097	Economy	11600.00
0005433925228	24097	Economy	11600.00
0005433924949	24097	Economy	11600.00
0005433924559	24097	Economy	11600.00
0005433924982	24097	Economy	11600.00
0005433037727	24097	Economy	11600.00
0005433037741	24097	Economy	11600.00
0005433925233	24097	Economy	11600.00
0005433037729	24097	Economy	11600.00
0005433925448	24097	Economy	11600.00
0005433925180	24097	Economy	11600.00
0005433925072	24097	Economy	11600.00
0005433929691	24097	Economy	11600.00
0005434028389	24097	Economy	11600.00
0005433924716	24097	Economy	11600.00
0005433037719	24097	Economy	11600.00
0005433037740	24097	Economy	11600.00
0005434028390	24097	Economy	11600.00
0005433924717	24097	Economy	11600.00
0005433925234	24097	Economy	11600.00
0005432749844	24097	Economy	11600.00
0005433925162	24097	Economy	11600.00
0005433925018	24097	Economy	11600.00
0005434028391	24097	Economy	11600.00
0005433037723	24097	Economy	11600.00
0005433925069	24097	Economy	12700.00
0005432207733	24097	Economy	12700.00
0005433925078	24097	Economy	11600.00
0005434376183	24097	Economy	12700.00
0005433925255	24097	Economy	12700.00
0005433037725	24097	Economy	11600.00
0005433925223	24097	Economy	11600.00
0005433929668	24097	Economy	11600.00
0005433924933	24097	Economy	11600.00
0005433925307	24097	Economy	11600.00
0005433037733	24097	Economy	11600.00
0005433931527	24097	Economy	11600.00
0005433925005	24097	Economy	11600.00
0005433924715	24097	Economy	11600.00
0005433924929	24097	Economy	11600.00
0005433037747	24097	Economy	11600.00
0005433037746	24097	Economy	11600.00
0005433924464	24097	Economy	11600.00
0005433925501	24097	Economy	11600.00
0005433925306	24097	Economy	11600.00
0005433925329	24097	Economy	11600.00
0005433925061	24097	Economy	11600.00
0005433925500	24097	Economy	11600.00
0005433924558	24097	Economy	11600.00
0005433925357	24097	Economy	11600.00
0005433925076	24097	Economy	11600.00
0005433924927	24097	Economy	11600.00
0005433931519	24097	Economy	11600.00
0005433924921	24097	Economy	11600.00
0005433925139	24097	Economy	11600.00
0005433925041	24097	Economy	11600.00
0005433925350	24097	Economy	11600.00
0005433925114	24097	Economy	11600.00
0005433925325	24097	Economy	11600.00
0005433037734	24097	Economy	11600.00
0005433929864	24097	Economy	11600.00
0005433924898	24097	Economy	11600.00
0005433037745	24097	Economy	11600.00
0005433924853	24097	Economy	11600.00
0005433037731	24097	Economy	11600.00
0005433037748	24097	Economy	11600.00
0005433925219	24097	Economy	11600.00
0005433925567	24097	Economy	11600.00
0005433037754	24097	Economy	11600.00
0005433037753	24097	Economy	11600.00
0005433037749	24097	Economy	11600.00
0005433925229	24097	Economy	11600.00
0005433925171	24097	Economy	11600.00
0005433925261	24097	Economy	11600.00
0005433925173	24097	Economy	11600.00
0005433037739	24097	Economy	11600.00
0005433925463	24097	Economy	11600.00
0005433037716	24097	Economy	11600.00
0005433925330	24097	Economy	11600.00
0005433181556	293	Business	83700.00
0005434552752	293	Business	83700.00
0005434728759	293	Business	83700.00
0005433181477	293	Business	83700.00
0005434552749	293	Business	83700.00
0005434728785	293	Business	83700.00
0005434728810	293	Business	83700.00
0005434728786	293	Business	83700.00
0005434728773	293	Business	83700.00
0005432278176	293	Business	83700.00
0005434728815	293	Business	83700.00
0005434735831	293	Business	83700.00
0005434728797	293	Business	83700.00
0005435142935	293	Business	83700.00
0005434302901	293	Business	83700.00
0005435142941	293	Business	83700.00
0005434728735	293	Business	83700.00
0005433181680	293	Business	83700.00
0005434552730	293	Business	83700.00
0005434728769	293	Business	83700.00
0005433235444	293	Business	83700.00
0005434728804	293	Business	83700.00
0005433235647	293	Business	83700.00
0005434728789	293	Business	83700.00
0005433235457	293	Comfort	47400.00
0005433766725	293	Comfort	47400.00
0005433235645	293	Comfort	47400.00
0005432278178	293	Comfort	47400.00
0005434728771	293	Comfort	47400.00
0005433181540	293	Comfort	47400.00
0005433766697	293	Comfort	47400.00
0005434728753	293	Comfort	47400.00
0005433235420	293	Comfort	47400.00
0005433235648	293	Comfort	47400.00
0005434552744	293	Comfort	47400.00
0005434302576	293	Comfort	47400.00
0005434728806	293	Comfort	47400.00
0005434735829	293	Comfort	47400.00
0005434032104	293	Comfort	47400.00
0005434728726	293	Comfort	47400.00
0005433181585	293	Comfort	47400.00
0005434552717	293	Comfort	47400.00
0005434728767	293	Comfort	47400.00
0005434728747	293	Comfort	47400.00
0005434728720	293	Comfort	47400.00
0005434552720	293	Comfort	47400.00
0005433235622	293	Comfort	47400.00
0005434728817	293	Comfort	47400.00
0005434728787	293	Comfort	47400.00
0005434728724	293	Comfort	47400.00
0005434552748	293	Comfort	47400.00
0005434728766	293	Comfort	47400.00
0005433235105	293	Comfort	47400.00
0005434728725	293	Comfort	47400.00
0005434032124	293	Comfort	47400.00
0005432278170	293	Comfort	47400.00
0005434302903	293	Comfort	47400.00
0005435142938	293	Comfort	47400.00
0005434728792	293	Comfort	47400.00
0005434728795	293	Comfort	47400.00
0005434552746	293	Comfort	47400.00
0005433766720	293	Economy	27900.00
0005432278180	293	Comfort	47400.00
0005434728732	293	Economy	27900.00
0005434728782	293	Economy	27900.00
0005434728778	293	Economy	27900.00
0005434032095	293	Economy	27900.00
0005435142934	293	Economy	27900.00
0005432278168	293	Economy	27900.00
0005434552722	293	Economy	27900.00
0005433235453	293	Economy	27900.00
0005434728816	293	Economy	27900.00
0005433235285	293	Economy	27900.00
0005434552734	293	Economy	27900.00
0005434552737	293	Economy	27900.00
0005434731285	293	Economy	27900.00
0005434728777	293	Economy	27900.00
0005434728783	293	Economy	27900.00
0005432278177	293	Economy	27900.00
0005433181642	293	Economy	27900.00
0005434735830	293	Economy	27900.00
0005433235617	293	Economy	27900.00
0005434552739	293	Economy	27900.00
0005434728808	293	Economy	27900.00
0005434728776	293	Economy	27900.00
0005433235722	293	Economy	27900.00
0005434552723	293	Economy	27900.00
0005434735827	293	Economy	27900.00
0005433181520	293	Economy	27900.00
0005433235131	293	Economy	27900.00
0005434552715	293	Economy	27900.00
0005433766687	293	Economy	27900.00
0005434728739	293	Economy	27900.00
0005434728775	293	Economy	27900.00
0005433181558	293	Economy	27900.00
0005434728798	293	Economy	27900.00
0005434728762	293	Economy	27900.00
0005433181603	293	Economy	27900.00
0005433181578	293	Economy	27900.00
0005433181567	293	Economy	27900.00
0005434728765	293	Economy	27900.00
0005434728750	293	Economy	27900.00
0005433131792	293	Economy	27900.00
0005434552751	293	Economy	27900.00
0005433235377	293	Economy	27900.00
0005433181566	293	Economy	27900.00
0005433113573	293	Economy	27900.00
0005434728770	293	Economy	27900.00
0005434552733	293	Economy	27900.00
0005434728774	293	Economy	27900.00
0005433766716	293	Economy	27900.00
0005433181602	293	Economy	27900.00
0005434552741	293	Economy	27900.00
0005434728781	293	Economy	27900.00
0005434728821	293	Economy	27900.00
0005433235407	293	Economy	30700.00
0005434728761	293	Economy	27900.00
0005434728756	293	Economy	30700.00
0005433235371	293	Economy	27900.00
0005433235542	293	Economy	27900.00
0005433235399	293	Economy	30700.00
0005433235130	293	Economy	27900.00
0005434728803	293	Economy	30700.00
0005434552735	293	Economy	27900.00
0005434728812	293	Economy	30700.00
0005434735828	293	Economy	27900.00
0005435142937	293	Economy	27900.00
0005434552716	293	Economy	27900.00
0005434728809	293	Economy	27900.00
0005433235433	293	Economy	27900.00
0005434728721	293	Economy	27900.00
0005434728801	293	Economy	27900.00
0005433235144	293	Economy	27900.00
0005434728746	293	Economy	27900.00
0005434728723	293	Economy	27900.00
0005433181647	293	Economy	27900.00
0005433181557	293	Economy	27900.00
0005433181629	293	Economy	27900.00
0005434728764	293	Economy	27900.00
0005433766727	293	Economy	27900.00
0005433126947	293	Economy	27900.00
0005434728807	293	Economy	27900.00
0005433181519	293	Economy	27900.00
0005434728754	293	Economy	27900.00
0005434552753	293	Economy	27900.00
0005433235223	293	Economy	27900.00
0005433235537	293	Economy	27900.00
0005434552736	293	Economy	27900.00
0005433235192	293	Economy	27900.00
0005433235372	293	Economy	27900.00
0005434728751	293	Economy	27900.00
0005434728742	293	Economy	27900.00
0005434728819	293	Economy	27900.00
0005434552740	293	Economy	27900.00
0005434728740	293	Economy	27900.00
0005434552745	293	Economy	27900.00
0005433181579	293	Economy	27900.00
0005433235438	293	Economy	27900.00
0005434728791	293	Economy	27900.00
0005434728768	293	Economy	27900.00
0005433766698	293	Economy	27900.00
0005434731283	293	Economy	27900.00
0005433181503	293	Economy	27900.00
0005434552743	293	Economy	27900.00
0005434728737	293	Economy	27900.00
0005433181678	293	Economy	27900.00
0005434735826	293	Economy	27900.00
0005433181677	293	Economy	27900.00
0005433235327	293	Economy	27900.00
0005435142942	293	Economy	27900.00
0005434728805	293	Economy	27900.00
0005434728813	293	Economy	27900.00
0005434728748	293	Economy	27900.00
0005433235191	293	Economy	27900.00
0005434552721	293	Economy	27900.00
0005432278167	293	Economy	27900.00
0005433289993	293	Economy	27900.00
0005434302573	293	Economy	27900.00
0005433181502	293	Economy	27900.00
0005432278169	293	Economy	27900.00
0005434728727	293	Economy	27900.00
0005433235379	293	Economy	27900.00
0005433181559	293	Economy	27900.00
0005433181619	293	Economy	27900.00
0005433131793	293	Economy	27900.00
0005434728730	293	Economy	27900.00
0005434552726	293	Economy	27900.00
0005434302574	293	Economy	27900.00
0005434728745	293	Economy	27900.00
0005434552729	293	Economy	27900.00
0005435142939	293	Economy	27900.00
0005434552750	293	Economy	27900.00
0005434728741	293	Economy	27900.00
0005433235175	293	Economy	27900.00
0005434728802	293	Economy	27900.00
0005434728734	293	Economy	27900.00
0005433181587	293	Economy	27900.00
0005434728784	293	Economy	27900.00
0005434728757	293	Economy	27900.00
0005433235153	293	Economy	27900.00
0005433111543	293	Economy	27900.00
0005434728820	293	Economy	27900.00
0005434728793	293	Economy	27900.00
0005433113574	293	Economy	27900.00
0005433235292	293	Economy	27900.00
0005434728728	293	Economy	27900.00
0005434728749	293	Economy	27900.00
0005433181673	293	Economy	27900.00
0005433235469	293	Economy	27900.00
0005433235543	293	Economy	27900.00
0005434552742	293	Economy	27900.00
0005434552725	293	Economy	27900.00
0005434728760	293	Economy	27900.00
0005433111535	293	Economy	27900.00
0005433235768	293	Economy	27900.00
0005433181501	293	Economy	27900.00
0005434552724	293	Economy	30700.00
0005434728763	293	Economy	30700.00
0005434728729	293	Economy	30700.00
0005433235415	293	Economy	30700.00
0005433131788	293	Economy	30700.00
0005434728733	293	Economy	27900.00
0005433131794	293	Economy	27900.00
0005432278175	293	Economy	27900.00
0005434728722	293	Economy	27900.00
0005433235409	293	Economy	27900.00
0005434731284	293	Economy	27900.00
0005432278172	293	Economy	27900.00
0005433113576	293	Economy	27900.00
0005434728818	293	Economy	27900.00
0005434728752	293	Economy	27900.00
0005433235269	293	Economy	27900.00
0005433235341	293	Economy	27900.00
0005434728780	293	Economy	27900.00
0005434552728	293	Economy	27900.00
0005434728779	293	Economy	27900.00
0005433181641	293	Economy	27900.00
0005433181719	293	Economy	27900.00
0005434728736	293	Economy	27900.00
0005434552719	293	Economy	27900.00
0005433766699	293	Economy	27900.00
0005434552731	293	Economy	27900.00
0005434728800	293	Economy	27900.00
0005433113580	293	Economy	27900.00
0005434728788	293	Economy	27900.00
0005434728799	293	Economy	27900.00
0005433289992	293	Economy	27900.00
0005435142940	293	Economy	27900.00
0005433235432	293	Economy	27900.00
0005432278174	293	Economy	27900.00
0005433235286	293	Economy	27900.00
0005433131785	293	Economy	27900.00
0005434552732	293	Economy	27900.00
0005433235224	293	Economy	27900.00
0005433766726	293	Economy	27900.00
0005432278171	293	Economy	27900.00
0005434728758	293	Economy	27900.00
0005434728796	293	Economy	27900.00
0005434728790	293	Economy	27900.00
0005433235401	293	Economy	27900.00
0005434032119	293	Economy	27900.00
0005433235282	293	Economy	27900.00
0005434728738	293	Economy	27900.00
0005435142936	293	Economy	27900.00
0005432278181	293	Economy	27900.00
0005433235303	293	Economy	27900.00
0005434552727	293	Economy	27900.00
0005433181672	293	Economy	27900.00
0005433181555	293	Economy	27900.00
0005433235304	293	Economy	27900.00
0005433181679	293	Economy	27900.00
0005432278179	293	Economy	27900.00
0005434302575	293	Economy	27900.00
0005434552738	293	Economy	27900.00
0005434552718	293	Economy	27900.00
0005434728772	293	Economy	27900.00
0005433126948	293	Economy	27900.00
0005434728755	293	Economy	27900.00
0005433181539	293	Economy	27900.00
0005433181666	293	Economy	27900.00
0005434728731	293	Economy	27900.00
0005433235345	293	Economy	27900.00
0005433235618	293	Economy	27900.00
0005434728811	293	Economy	27900.00
0005433181586	293	Economy	27900.00
0005433235261	293	Economy	27900.00
0005432278173	293	Economy	27900.00
0005434302902	293	Economy	27900.00
0005434728814	293	Economy	27900.00
0005433235199	293	Economy	27900.00
0005433181515	293	Economy	27900.00
0005433235346	293	Economy	27900.00
0005433181667	293	Economy	27900.00
0005433235378	293	Economy	27900.00
0005434728794	293	Economy	27900.00
0005433131808	293	Economy	27900.00
0005434728744	293	Economy	27900.00
0005434728743	293	Economy	27900.00
0005433235598	293	Economy	27900.00
0005434032086	293	Economy	27900.00
0005433181368	293	Economy	27900.00
0005434552747	293	Economy	27900.00
0005434552133	9857	Business	83700.00
0005432199432	9857	Business	83700.00
0005433235909	9857	Business	83700.00
0005434728131	9857	Business	83700.00
0005434727776	9857	Business	83700.00
0005434727713	9857	Business	83700.00
0005433235917	9857	Business	83700.00
0005434727783	9857	Business	83700.00
0005434727889	9857	Business	83700.00
0005433235910	9857	Business	83700.00
0005434727673	9857	Business	83700.00
0005433235925	9857	Business	83700.00
0005434552121	9857	Business	83700.00
0005434727791	9857	Business	83700.00
0005434552158	9857	Business	83700.00
0005434727664	9857	Business	83700.00
0005433181790	9857	Business	83700.00
0005434727394	9857	Business	83700.00
0005434727827	9857	Business	83700.00
0005434727702	9857	Business	83700.00
0005434727817	9857	Business	83700.00
0005434727843	9857	Business	83700.00
0005434727761	9857	Comfort	47400.00
0005434728272	9857	Business	83700.00
0005433235899	9857	Comfort	47400.00
0005434552179	9857	Comfort	47400.00
0005434552267	9857	Comfort	47400.00
0005434728155	9857	Comfort	47400.00
0005433290041	9857	Comfort	47400.00
0005434552094	9857	Comfort	47400.00
0005434727701	9857	Comfort	47400.00
0005434552156	9857	Comfort	47400.00
0005434552225	9857	Comfort	47400.00
0005434727883	9857	Comfort	47400.00
0005435142796	9857	Comfort	47400.00
0005434552371	9857	Comfort	47400.00
0005434727622	9857	Comfort	47400.00
0005434728081	9857	Comfort	47400.00
0005433126967	9857	Comfort	47400.00
0005433235897	9857	Comfort	47400.00
0005434727643	9857	Comfort	47400.00
0005434552122	9857	Comfort	47400.00
0005434552290	9857	Comfort	47400.00
0005434727829	9857	Comfort	47400.00
0005433129400	9857	Comfort	47400.00
0005434727228	9857	Comfort	47400.00
0005433235892	9857	Comfort	47400.00
0005433181779	9857	Comfort	47400.00
0005434728066	9857	Comfort	47400.00
0005434727811	9857	Comfort	47400.00
0005434727949	9857	Economy	27900.00
0005434727678	9857	Economy	27900.00
0005433290044	9857	Economy	27900.00
0005434552344	9857	Economy	27900.00
0005433235914	9857	Economy	27900.00
0005433235891	9857	Economy	27900.00
0005434727420	9857	Economy	27900.00
0005434727672	9857	Economy	27900.00
0005434552266	9857	Economy	27900.00
0005434728093	9857	Economy	27900.00
0005434728042	9857	Economy	27900.00
0005434727703	9857	Economy	27900.00
0005433181797	9857	Economy	27900.00
0005434727972	9857	Economy	27900.00
0005435142797	9857	Economy	27900.00
0005433181781	9857	Economy	27900.00
0005434552221	9857	Economy	27900.00
0005433235907	9857	Economy	27900.00
0005434727604	9857	Economy	27900.00
0005434032152	9857	Economy	27900.00
0005434728154	9857	Economy	27900.00
0005434727311	9857	Economy	27900.00
0005434727819	9857	Economy	27900.00
0005434552304	9857	Economy	27900.00
0005433181789	9857	Economy	27900.00
0005434302534	9857	Economy	27900.00
0005434552165	9857	Economy	27900.00
0005434551934	9857	Economy	27900.00
0005433129401	9857	Economy	27900.00
0005434552395	9857	Economy	27900.00
0005434735789	9857	Economy	27900.00
0005434727406	9857	Economy	27900.00
0005433235901	9857	Economy	27900.00
0005434552457	9857	Economy	27900.00
0005433235911	9857	Economy	27900.00
0005434727676	9857	Economy	27900.00
0005434552071	9857	Economy	27900.00
0005434552265	9857	Economy	27900.00
0005434552268	9857	Economy	27900.00
0005434727586	9857	Economy	27900.00
0005434727993	9857	Economy	27900.00
0005433181778	9857	Economy	27900.00
0005434727405	9857	Economy	27900.00
0005434552390	9857	Economy	27900.00
0005434735783	9857	Economy	27900.00
0005434552153	9857	Economy	27900.00
0005434727385	9857	Economy	27900.00
0005434727207	9857	Economy	27900.00
0005434727870	9857	Economy	27900.00
0005434727470	9857	Economy	27900.00
0005434727712	9857	Economy	27900.00
0005433766743	9857	Economy	27900.00
0005433235915	9857	Economy	27900.00
0005433235889	9857	Economy	27900.00
0005434552375	9857	Economy	27900.00
0005433129399	9857	Economy	27900.00
0005434728038	9857	Economy	27900.00
0005434728082	9857	Economy	27900.00
0005434727476	9857	Economy	30700.00
0005433235887	9857	Economy	27900.00
0005434728041	9857	Economy	30700.00
0005432199433	9857	Economy	27900.00
0005433235923	9857	Economy	30700.00
0005434302521	9857	Economy	27900.00
0005434552374	9857	Economy	30700.00
0005434728153	9857	Economy	30700.00
0005434728053	9857	Economy	30700.00
0005433235922	9857	Economy	27900.00
0005434727688	9857	Economy	27900.00
0005434727178	9857	Economy	27900.00
0005434727641	9857	Economy	27900.00
0005433235920	9857	Economy	27900.00
0005433235919	9857	Economy	27900.00
0005434727792	9857	Economy	27900.00
0005434727551	9857	Economy	27900.00
0005434551935	9857	Economy	27900.00
0005434552376	9857	Economy	27900.00
0005434552106	9857	Economy	27900.00
0005433181791	9857	Economy	27900.00
0005434552184	9857	Economy	27900.00
0005434552181	9857	Economy	27900.00
0005434727777	9857	Economy	27900.00
0005435142822	9857	Economy	27900.00
0005433766744	9857	Economy	27900.00
0005434302533	9857	Economy	27900.00
0005433235902	9857	Economy	27900.00
0005434727665	9857	Economy	27900.00
0005433181780	9857	Economy	27900.00
0005435142803	9857	Economy	27900.00
0005433126968	9857	Economy	27900.00
0005434727717	9857	Economy	27900.00
0005434728337	9857	Economy	27900.00
0005433290043	9857	Economy	27900.00
0005434727377	9857	Economy	27900.00
0005434552208	9857	Economy	27900.00
0005434727812	9857	Economy	27900.00
0005434728102	9857	Economy	27900.00
0005432199431	9857	Economy	27900.00
0005434727493	9857	Economy	27900.00
0005434552277	9857	Economy	27900.00
0005434552317	9857	Economy	27900.00
0005434552123	9857	Economy	27900.00
0005434728324	9857	Economy	27900.00
0005434552294	9857	Economy	27900.00
0005433290042	9857	Economy	27900.00
0005433290048	9857	Economy	27900.00
0005434727762	9857	Economy	27900.00
0005434727060	9857	Economy	27900.00
0005433235894	9857	Economy	27900.00
0005434727816	9857	Economy	27900.00
0005434727689	9857	Economy	27900.00
0005434727757	9857	Economy	27900.00
0005434727888	9857	Economy	27900.00
0005433235893	9857	Economy	27900.00
0005434552095	9857	Economy	27900.00
0005434728087	9857	Economy	27900.00
0005434032150	9857	Economy	27900.00
0005433235926	9857	Economy	27900.00
0005434552345	9857	Economy	27900.00
0005434552319	9857	Economy	27900.00
0005434728092	9857	Economy	27900.00
0005433181785	9857	Economy	27900.00
0005433181787	9857	Economy	27900.00
0005434302522	9857	Economy	27900.00
0005435142779	9857	Economy	27900.00
0005434552238	9857	Economy	27900.00
0005433235904	9857	Economy	27900.00
0005433235898	9857	Economy	27900.00
0005434727177	9857	Economy	27900.00
0005433235905	9857	Economy	27900.00
0005434552320	9857	Economy	27900.00
0005434727790	9857	Economy	27900.00
0005434302536	9857	Economy	27900.00
0005433235916	9857	Economy	27900.00
0005434728056	9857	Economy	27900.00
0005433126969	9857	Economy	27900.00
0005434552372	9857	Economy	27900.00
0005434727971	9857	Economy	27900.00
0005434728020	9857	Economy	27900.00
0005434727731	9857	Economy	27900.00
0005434727061	9857	Economy	27900.00
0005434728199	9857	Economy	27900.00
0005434727726	9857	Economy	27900.00
0005434728198	9857	Economy	27900.00
0005434727254	9857	Economy	27900.00
0005433235903	9857	Economy	27900.00
0005434727677	9857	Economy	27900.00
0005434727297	9857	Economy	30700.00
0005433235900	9857	Economy	30700.00
0005434727502	9857	Economy	30700.00
0005434552180	9857	Economy	27900.00
0005434728052	9857	Economy	27900.00
0005433235924	9857	Economy	27900.00
0005434552067	9857	Economy	27900.00
0005433126971	9857	Economy	27900.00
0005433235913	9857	Economy	27900.00
0005434727754	9857	Economy	27900.00
0005433181792	9857	Economy	27900.00
0005434727844	9857	Economy	27900.00
0005434727637	9857	Economy	27900.00
0005434728702	9857	Economy	27900.00
0005434727642	9857	Economy	27900.00
0005433181784	9857	Economy	27900.00
0005433235888	9857	Economy	27900.00
0005433290045	9857	Economy	27900.00
0005434302548	9857	Economy	27900.00
0005433181795	9857	Economy	27900.00
0005434727732	9857	Economy	27900.00
0005433235890	9857	Economy	27900.00
0005434727984	9857	Economy	27900.00
0005434728036	9857	Economy	27900.00
0005434552458	9857	Economy	27900.00
0005434552167	9857	Economy	27900.00
0005433181793	9857	Economy	27900.00
0005434728238	9857	Economy	27900.00
0005434727869	9857	Economy	27900.00
0005435142821	9857	Economy	27900.00
0005434727584	9857	Economy	27900.00
0005434302535	9857	Economy	27900.00
0005433235908	9857	Economy	27900.00
0005434552166	9857	Economy	27900.00
0005434727756	9857	Economy	27900.00
0005434727603	9857	Economy	27900.00
0005434735753	9857	Economy	27900.00
0005434728086	9857	Economy	27900.00
0005433181788	9857	Economy	27900.00
0005434727901	9857	Economy	27900.00
0005434727837	9857	Economy	27900.00
0005434032151	9857	Economy	27900.00
0005434728703	9857	Economy	27900.00
0005435142802	9857	Economy	27900.00
0005433235886	9857	Economy	27900.00
0005433235895	9857	Economy	27900.00
0005434727170	9857	Economy	27900.00
0005433235896	9857	Economy	27900.00
0005433235918	9857	Economy	27900.00
0005434552215	9857	Economy	27900.00
0005434552276	9857	Economy	27900.00
0005433181786	9857	Economy	27900.00
0005434552105	9857	Economy	27900.00
0005433181800	9857	Economy	27900.00
0005433181798	9857	Economy	27900.00
0005434727610	9857	Economy	27900.00
0005433290047	9857	Economy	27900.00
0005433181783	9857	Economy	27900.00
0005434552126	9857	Economy	27900.00
0005434032149	9857	Economy	27900.00
0005435142820	9857	Economy	27900.00
0005433181796	9857	Economy	27900.00
0005433235921	9857	Economy	27900.00
0005434552157	9857	Economy	27900.00
0005434727834	9857	Economy	27900.00
0005434728338	9857	Economy	27900.00
0005434727675	9857	Economy	27900.00
0005433181782	9857	Economy	27900.00
0005434728105	9857	Economy	27900.00
0005434552020	9857	Economy	27900.00
0005434552439	9857	Economy	27900.00
0005433235906	9857	Economy	27900.00
0005432199430	9857	Economy	27900.00
0005433235912	9857	Economy	27900.00
0005434727583	9857	Economy	27900.00
0005434552318	9857	Economy	27900.00
0005435142798	9857	Economy	27900.00
0005434727842	9857	Economy	27900.00
0005433290046	9857	Economy	27900.00
0005434727715	9857	Economy	27900.00
0005434727716	9857	Economy	27900.00
0005434727552	9857	Economy	27900.00
0005433126970	9857	Economy	27900.00
0005434727729	9857	Economy	27900.00
0005434551856	9857	Economy	27900.00
0005433181799	9857	Economy	27900.00
0005434552316	9857	Economy	27900.00
0005433181794	9857	Economy	27900.00
0005432070050	7730	Business	42100.00
0005432531590	7730	Business	42100.00
0005435214888	7730	Business	42100.00
0005433656732	7730	Business	42100.00
0005432531561	7730	Business	42100.00
0005432070049	7730	Business	42100.00
0005432150409	7730	Business	42100.00
0005434069490	7730	Business	42100.00
0005432531510	7730	Business	42100.00
0005435214885	7730	Business	42100.00
0005434069484	7730	Business	42100.00
0005435214598	7730	Business	42100.00
0005433656717	7730	Business	42100.00
0005432531538	7730	Business	42100.00
0005435214871	7730	Business	42100.00
0005435214902	7730	Business	42100.00
0005434069467	7730	Business	42100.00
0005435214898	7730	Business	42100.00
0005434069523	7730	Business	42100.00
0005432531586	7730	Business	42100.00
0005434069519	7730	Business	42100.00
0005432531547	7730	Comfort	23900.00
0005432531507	7730	Comfort	23900.00
0005434069470	7730	Comfort	23900.00
0005435283423	7730	Comfort	23900.00
0005432531581	7730	Comfort	23900.00
0005434069505	7730	Comfort	23900.00
0005434069504	7730	Comfort	23900.00
0005435283424	7730	Comfort	23900.00
0005435214960	7730	Comfort	23900.00
0005435214872	7730	Comfort	23900.00
0005432531567	7730	Comfort	23900.00
0005432531512	7730	Comfort	23900.00
0005432531520	7730	Comfort	23900.00
0005434069516	7730	Comfort	23900.00
0005432531536	7730	Comfort	23900.00
0005432531514	7730	Comfort	23900.00
0005432531515	7730	Comfort	23900.00
0005432531574	7730	Comfort	23900.00
0005435214851	7730	Comfort	23900.00
0005435214665	7730	Comfort	23900.00
0005435214948	7730	Comfort	23900.00
0005433656739	7730	Comfort	23900.00
0005432531556	7730	Comfort	23900.00
0005435214698	7730	Comfort	23900.00
0005432531575	7730	Comfort	23900.00
0005432150411	7730	Comfort	23900.00
0005434069469	7730	Comfort	23900.00
0005432531601	7730	Comfort	23900.00
0005434069488	7730	Comfort	23900.00
0005434069476	7730	Comfort	23900.00
0005434069498	7730	Economy	14000.00
0005434069509	7730	Economy	14000.00
0005432531534	7730	Economy	14000.00
0005432531544	7730	Economy	14000.00
0005432531557	7730	Economy	14000.00
0005434069500	7730	Economy	14000.00
0005435214991	7730	Economy	14000.00
0005432531582	7730	Economy	14000.00
0005432531595	7730	Economy	14000.00
0005435631017	7730	Economy	14000.00
0005435631009	7730	Economy	14000.00
0005434069524	7730	Economy	14000.00
0005432531579	7730	Economy	14000.00
0005432150416	7730	Economy	14000.00
0005435214867	7730	Economy	14000.00
0005432531588	7730	Economy	14000.00
0005434069497	7730	Economy	14000.00
0005434069479	7730	Economy	14000.00
0005432531541	7730	Economy	14000.00
0005432070053	7730	Economy	14000.00
0005434069477	7730	Economy	14000.00
0005432531551	7730	Economy	14000.00
0005432531583	7730	Economy	14000.00
0005434069485	7730	Economy	14000.00
0005432531565	7730	Economy	14000.00
0005432531604	7730	Economy	14000.00
0005432531549	7730	Economy	14000.00
0005435214795	7730	Economy	14000.00
0005432531603	7730	Economy	14000.00
0005434069502	7730	Economy	14000.00
0005434069491	7730	Economy	14000.00
0005435214849	7730	Economy	14000.00
0005435214739	7730	Economy	14000.00
0005434069473	7730	Economy	14000.00
0005432531562	7730	Economy	14000.00
0005435214864	7730	Economy	14000.00
0005432531599	7730	Economy	14000.00
0005435214743	7730	Economy	14000.00
0005434069514	7730	Economy	14000.00
0005434069520	7730	Economy	14000.00
0005432531602	7730	Economy	14000.00
0005432531563	7730	Economy	14000.00
0005432531528	7730	Economy	14000.00
0005434069486	7730	Economy	14000.00
0005434069478	7730	Economy	14000.00
0005432531596	7730	Economy	14000.00
0005435214901	7730	Economy	14000.00
0005435214501	7730	Economy	15400.00
0005435214464	7730	Economy	14000.00
0005435214936	7730	Economy	14000.00
0005432070056	7730	Economy	14000.00
0005435631013	7730	Economy	14000.00
0005432531577	7730	Economy	15400.00
0005434069508	7730	Economy	15400.00
0005432531546	7730	Economy	14000.00
0005434069475	7730	Economy	15400.00
0005432531535	7730	Economy	14000.00
0005432533368	7730	Economy	14000.00
0005432531606	7730	Economy	14000.00
0005432531568	7730	Economy	14000.00
0005434069513	7730	Economy	14000.00
0005435214937	7730	Economy	14000.00
0005435214798	7730	Economy	14000.00
0005434069472	7730	Economy	14000.00
0005432531543	7730	Economy	14000.00
0005435283411	7730	Economy	14000.00
0005434069489	7730	Economy	14000.00
0005435214819	7730	Economy	14000.00
0005435214692	7730	Economy	14000.00
0005435214558	7730	Economy	14000.00
0005432531566	7730	Economy	14000.00
0005434069465	7730	Economy	14000.00
0005432531605	7730	Economy	14000.00
0005435214850	7730	Economy	14000.00
0005432070055	7730	Economy	14000.00
0005432531564	7730	Economy	14000.00
0005432531527	7730	Economy	14000.00
0005434069466	7730	Economy	14000.00
0005432531522	7730	Economy	14000.00
0005435214732	7730	Economy	14000.00
0005432531592	7730	Economy	14000.00
0005432535970	7730	Economy	14000.00
0005435631021	7730	Economy	14000.00
0005432531506	7730	Economy	14000.00
0005432531558	7730	Economy	14000.00
0005432531518	7730	Economy	14000.00
0005434069481	7730	Economy	14000.00
0005434069482	7730	Economy	14000.00
0005435214951	7730	Economy	14000.00
0005432531532	7730	Economy	14000.00
0005435214738	7730	Economy	14000.00
0005434069521	7730	Economy	14000.00
0005432531591	7730	Economy	14000.00
0005435214820	7730	Economy	14000.00
0005435215007	7730	Economy	14000.00
0005432531529	7730	Economy	14000.00
0005435214797	7730	Economy	14000.00
0005435215165	7730	Economy	14000.00
0005435214889	7730	Economy	14000.00
0005434069517	7730	Economy	14000.00
0005432531523	7730	Economy	14000.00
0005434069494	7730	Economy	14000.00
0005434069471	7730	Economy	14000.00
0005432531552	7730	Economy	14000.00
0005432531584	7730	Economy	14000.00
0005432429024	7730	Economy	14000.00
0005432533369	7730	Economy	14000.00
0005432070051	7730	Economy	14000.00
0005435283425	7730	Economy	14000.00
0005432531521	7730	Economy	14000.00
0005432531587	7730	Economy	14000.00
0005434069506	7730	Economy	14000.00
0005432531530	7730	Economy	14000.00
0005434069512	7730	Economy	14000.00
0005435214957	7730	Economy	14000.00
0005434069496	7730	Economy	14000.00
0005435214551	7730	Economy	14000.00
0005435215164	7730	Economy	14000.00
0005432531545	7730	Economy	14000.00
0005435214827	7730	Economy	14000.00
0005434069492	7730	Economy	14000.00
0005435214839	7730	Economy	14000.00
0005432531555	7730	Economy	14000.00
0005432150412	7730	Economy	14000.00
0005435214599	7730	Economy	14000.00
0005432531580	7730	Economy	14000.00
0005432535969	7730	Economy	14000.00
0005432070048	7730	Economy	14000.00
0005432531542	7730	Economy	14000.00
0005432531600	7730	Economy	14000.00
0005432531525	7730	Economy	14000.00
0005432531540	7730	Economy	14000.00
0005434069515	7730	Economy	14000.00
0005432537117	7730	Economy	14000.00
0005432531598	7730	Economy	14000.00
0005432531594	7730	Economy	14000.00
0005432535968	7730	Economy	14000.00
0005432150414	7730	Economy	14000.00
0005434069495	7730	Economy	14000.00
0005435214859	7730	Economy	14000.00
0005434069511	7730	Economy	14000.00
0005433656718	7730	Economy	14000.00
0005432531517	7730	Economy	14000.00
0005432531578	7730	Economy	14000.00
0005434069510	7730	Economy	15400.00
0005435214894	7730	Economy	15400.00
0005432531548	7730	Economy	15400.00
0005432531571	7730	Economy	15400.00
0005432531573	7730	Economy	14000.00
0005435214873	7730	Economy	14000.00
0005435214694	7730	Economy	14000.00
0005434069503	7730	Economy	14000.00
0005432531539	7730	Economy	14000.00
0005434069487	7730	Economy	14000.00
0005432531537	7730	Economy	14000.00
0005434069501	7730	Economy	14000.00
0005432070054	7730	Economy	14000.00
0005434069493	7730	Economy	14000.00
0005435631016	7730	Economy	14000.00
0005435214887	7730	Economy	14000.00
0005435214818	7730	Economy	14000.00
0005432429021	7730	Economy	14000.00
0005432429022	7730	Economy	14000.00
0005435631022	7730	Economy	14000.00
0005432429023	7730	Economy	14000.00
0005432150413	7730	Economy	14000.00
0005432531593	7730	Economy	14000.00
0005432150410	7730	Economy	14000.00
0005435631026	7730	Economy	14000.00
0005432531569	7730	Economy	14000.00
0005435214789	7730	Economy	14000.00
0005434069483	7730	Economy	14000.00
0005435214844	7730	Economy	14000.00
0005435214958	7730	Economy	14000.00
0005435214699	7730	Economy	14000.00
0005432531508	7730	Economy	14000.00
0005434069499	7730	Economy	14000.00
0005435214828	7730	Economy	14000.00
0005435214744	7730	Economy	14000.00
0005432531589	7730	Economy	14000.00
0005432070057	7730	Economy	14000.00
0005433656733	7730	Economy	14000.00
0005434069522	7730	Economy	14000.00
0005435214865	7730	Economy	14000.00
0005432531519	7730	Economy	14000.00
0005434069518	7730	Economy	14000.00
0005434069507	7730	Economy	14000.00
0005432531576	7730	Economy	14000.00
0005434069474	7730	Economy	14000.00
0005435214919	7730	Economy	14000.00
0005435214893	7730	Economy	14000.00
0005432531513	7730	Economy	14000.00
0005435215119	7730	Economy	14000.00
0005432531509	7730	Economy	14000.00
0005432531554	7730	Economy	14000.00
0005432535967	7730	Economy	14000.00
0005432531524	7730	Economy	14000.00
0005432070052	7730	Economy	14000.00
0005435214812	7730	Economy	14000.00
0005432531597	7730	Economy	14000.00
0005435215006	7730	Economy	14000.00
0005435214860	7730	Economy	14000.00
0005432531533	7730	Economy	14000.00
0005432531553	7730	Economy	14000.00
0005432531572	7730	Economy	14000.00
0005432531531	7730	Economy	14000.00
0005432531585	7730	Economy	14000.00
0005432531559	7730	Economy	14000.00
0005434069468	7730	Economy	14000.00
0005432150415	7730	Economy	14000.00
0005432531570	7730	Economy	14000.00
0005432537116	7730	Economy	14000.00
0005432531516	7730	Economy	14000.00
0005435214693	7730	Economy	14000.00
0005432531526	7730	Economy	14000.00
0005434069480	7730	Economy	14000.00
0005435214497	7730	Economy	14000.00
0005435214899	7730	Economy	14000.00
0005432531560	7730	Economy	14000.00
0005432531511	7730	Economy	14000.00
0005432531550	7730	Economy	14000.00
0005435616779	5327	Business	43100.00
0005435616807	5327	Business	43100.00
0005435616823	5327	Business	43100.00
0005435616767	5327	Business	43100.00
0005435616742	5327	Business	43100.00
0005434245549	5327	Business	43100.00
0005435616800	5327	Business	43100.00
0005434245520	5327	Business	43100.00
0005434345207	5327	Business	43100.00
0005435426215	5327	Business	43100.00
0005434345205	5327	Business	43100.00
0005435616814	5327	Business	43100.00
0005434573739	5327	Business	43100.00
0005435097483	5327	Business	43100.00
0005435616752	5327	Business	43100.00
0005434345203	5327	Business	43100.00
0005434245568	5327	Business	43100.00
0005433719192	5327	Business	43100.00
0005435616746	5327	Business	43100.00
0005435426211	5327	Business	43100.00
0005435380385	5327	Business	43100.00
0005435302303	5327	Comfort	24400.00
0005435616723	5327	Business	43100.00
0005435426139	5327	Comfort	24400.00
0005435426362	5327	Comfort	24400.00
0005435380368	5327	Comfort	24400.00
0005432841055	5327	Comfort	24400.00
0005432133624	5327	Comfort	24400.00
0005435616749	5327	Comfort	24400.00
0005434345189	5327	Comfort	24400.00
0005435380389	5327	Comfort	24400.00
0005435616722	5327	Comfort	24400.00
0005435616790	5327	Comfort	24400.00
0005435616794	5327	Comfort	24400.00
0005435616748	5327	Comfort	24400.00
0005435426183	5327	Comfort	24400.00
0005435380391	5327	Comfort	24400.00
0005435097482	5327	Comfort	24400.00
0005435617243	5327	Comfort	24400.00
0005432363457	5327	Comfort	24400.00
0005435616741	5327	Comfort	24400.00
0005432133621	5327	Comfort	24400.00
0005435616737	5327	Comfort	24400.00
0005435616788	5327	Comfort	24400.00
0005435426285	5327	Comfort	24400.00
0005435380406	5327	Comfort	24400.00
0005434345200	5327	Comfort	24400.00
0005435426220	5327	Comfort	24400.00
0005435616753	5327	Comfort	24400.00
0005435616815	5327	Comfort	24400.00
0005435616822	5327	Comfort	24400.00
0005435616771	5327	Comfort	24400.00
0005435616806	5327	Comfort	24400.00
0005435616725	5327	Comfort	24400.00
0005435302281	5327	Comfort	24400.00
0005435042891	5327	Comfort	24400.00
0005435617191	5327	Comfort	24400.00
0005435426490	5327	Comfort	24400.00
0005435616730	5327	Comfort	24400.00
0005435426271	5327	Comfort	24400.00
0005435426422	5327	Comfort	24400.00
0005434656595	5327	Comfort	24400.00
0005435616733	5327	Economy	14400.00
0005435616732	5327	Economy	14400.00
0005435617192	5327	Economy	14400.00
0005435616782	5327	Economy	14400.00
0005435616756	5327	Economy	14400.00
0005435426073	5327	Economy	14400.00
0005435491501	5327	Economy	14400.00
0005434573733	5327	Economy	14400.00
0005435319741	5327	Economy	14400.00
0005434245418	5327	Economy	14400.00
0005435426088	5327	Economy	14400.00
0005434345206	5327	Economy	14400.00
0005434245521	5327	Economy	14400.00
0005435425981	5327	Economy	14400.00
0005435426107	5327	Economy	14400.00
0005435380386	5327	Economy	14400.00
0005434345183	5327	Economy	14400.00
0005435319743	5327	Economy	14400.00
0005435616770	5327	Economy	14400.00
0005435616744	5327	Economy	14400.00
0005435616754	5327	Economy	14400.00
0005435097479	5327	Economy	14400.00
0005435616761	5327	Economy	14400.00
0005433719200	5327	Economy	14400.00
0005435490329	5327	Economy	14400.00
0005435616728	5327	Economy	14400.00
0005434245519	5327	Economy	14400.00
0005435425818	5327	Economy	14400.00
0005435319735	5327	Economy	14400.00
0005435616727	5327	Economy	14400.00
0005435616801	5327	Economy	14400.00
0005435426288	5327	Economy	14400.00
0005435616805	5327	Economy	14400.00
0005434345185	5327	Economy	14400.00
0005435616777	5327	Economy	14400.00
0005435097481	5327	Economy	14400.00
0005435616765	5327	Economy	14400.00
0005435616797	5327	Economy	14400.00
0005435426140	5327	Economy	14400.00
0005435616736	5327	Economy	14400.00
0005435616773	5327	Economy	14400.00
0005435616726	5327	Economy	14400.00
0005435616769	5327	Economy	14400.00
0005435616820	5327	Economy	14400.00
0005435616817	5327	Economy	14400.00
0005434345194	5327	Economy	14400.00
0005435302290	5327	Economy	14400.00
0005435616824	5327	Economy	14400.00
0005435426030	5327	Economy	14400.00
0005432047653	5327	Economy	14400.00
0005435380402	5327	Economy	14400.00
0005435302280	5327	Economy	14400.00
0005434573735	5327	Economy	14400.00
0005434573736	5327	Economy	14400.00
0005435426212	5327	Economy	14400.00
0005432841053	5327	Economy	14400.00
0005435426106	5327	Economy	15800.00
0005435616813	5327	Economy	15800.00
0005435097486	5327	Economy	14400.00
0005435380369	5327	Economy	14400.00
0005435617190	5327	Economy	14400.00
0005435426373	5327	Economy	14400.00
0005435426259	5327	Economy	15800.00
0005435097485	5327	Economy	15800.00
0005435319724	5327	Economy	14400.00
0005432133626	5327	Economy	14400.00
0005435616743	5327	Economy	14400.00
0005434345186	5327	Economy	14400.00
0005434245607	5327	Economy	14400.00
0005434245620	5327	Economy	14400.00
0005434345197	5327	Economy	14400.00
0005434345193	5327	Economy	14400.00
0005435426245	5327	Economy	14400.00
0005435319750	5327	Economy	14400.00
0005435426080	5327	Economy	14400.00
0005432363479	5327	Economy	14400.00
0005435616740	5327	Economy	14400.00
0005435616785	5327	Economy	14400.00
0005432133627	5327	Economy	14400.00
0005435616747	5327	Economy	14400.00
0005434656586	5327	Economy	14400.00
0005435426441	5327	Economy	14400.00
0005434245421	5327	Economy	14400.00
0005435425985	5327	Economy	14400.00
0005435616729	5327	Economy	14400.00
0005435425728	5327	Economy	14400.00
0005435426309	5327	Economy	14400.00
0005435616791	5327	Economy	14400.00
0005435426131	5327	Economy	14400.00
0005435302302	5327	Economy	14400.00
0005432133620	5327	Economy	14400.00
0005435616825	5327	Economy	14400.00
0005435616762	5327	Economy	14400.00
0005434245454	5327	Economy	14400.00
0005435616759	5327	Economy	14400.00
0005435616795	5327	Economy	14400.00
0005435425897	5327	Economy	14400.00
0005435616798	5327	Economy	14400.00
0005435380390	5327	Economy	14400.00
0005433719206	5327	Economy	14400.00
0005434345196	5327	Economy	14400.00
0005435616796	5327	Economy	14400.00
0005435616718	5327	Economy	14400.00
0005434345191	5327	Economy	14400.00
0005435097480	5327	Economy	14400.00
0005435426015	5327	Economy	14400.00
0005435302288	5327	Economy	14400.00
0005434345192	5327	Economy	14400.00
0005435426048	5327	Economy	14400.00
0005435616719	5327	Economy	14400.00
0005435616738	5327	Economy	14400.00
0005435426316	5327	Economy	14400.00
0005434573740	5327	Economy	14400.00
0005435616780	5327	Economy	14400.00
0005435616804	5327	Economy	14400.00
0005435426031	5327	Economy	14400.00
0005435616810	5327	Economy	14400.00
0005433719187	5327	Economy	14400.00
0005432363462	5327	Economy	14400.00
0005434345198	5327	Economy	14400.00
0005435426038	5327	Economy	14400.00
0005435490327	5327	Economy	14400.00
0005435616763	5327	Economy	14400.00
0005435616717	5327	Economy	14400.00
0005433719199	5327	Economy	14400.00
0005435426318	5327	Economy	14400.00
0005432133625	5327	Economy	14400.00
0005435426010	5327	Economy	14400.00
0005435616776	5327	Economy	14400.00
0005434345211	5327	Economy	14400.00
0005435319751	5327	Economy	14400.00
0005435616734	5327	Economy	14400.00
0005435616812	5327	Economy	14400.00
0005435380387	5327	Economy	14400.00
0005434345209	5327	Economy	14400.00
0005435426066	5327	Economy	14400.00
0005434656585	5327	Economy	14400.00
0005432133623	5327	Economy	14400.00
0005435616811	5327	Economy	14400.00
0005434573744	5327	Economy	14400.00
0005435616760	5327	Economy	14400.00
0005435555424	5327	Economy	14400.00
0005434573734	5327	Economy	14400.00
0005435616793	5327	Economy	14400.00
0005435302304	5327	Economy	14400.00
0005435426006	5327	Economy	14400.00
0005435616751	5327	Economy	14400.00
0005435380400	5327	Economy	14400.00
0005435425984	5327	Economy	14400.00
0005435616787	5327	Economy	14400.00
0005435319742	5327	Economy	14400.00
0005435616735	5327	Economy	14400.00
0005434345188	5327	Economy	14400.00
0005435616786	5327	Economy	14400.00
0005435616799	5327	Economy	15800.00
0005435426065	5327	Economy	14400.00
0005435426091	5327	Economy	15800.00
0005435426146	5327	Economy	15800.00
0005435490328	5327	Economy	15800.00
0005435616808	5327	Economy	14400.00
0005434345201	5327	Economy	14400.00
0005435097484	5327	Economy	14400.00
0005435426251	5327	Economy	14400.00
0005435319736	5327	Economy	14400.00
0005435319734	5327	Economy	14400.00
0005435426090	5327	Economy	14400.00
0005435426216	5327	Economy	14400.00
0005435426182	5327	Economy	14400.00
0005435616757	5327	Economy	14400.00
0005435319752	5327	Economy	14400.00
0005435425817	5327	Economy	14400.00
0005432133619	5327	Economy	14400.00
0005433719212	5327	Economy	14400.00
0005435616792	5327	Economy	14400.00
0005434345184	5327	Economy	14400.00
0005435302299	5327	Economy	14400.00
0005435616772	5327	Economy	14400.00
0005434656594	5327	Economy	14400.00
0005434345199	5327	Economy	14400.00
0005435616803	5327	Economy	14400.00
0005435616819	5327	Economy	14400.00
0005435616755	5327	Economy	14400.00
0005434573741	5327	Economy	14400.00
0005434573743	5327	Economy	14400.00
0005435616764	5327	Economy	14400.00
0005432133622	5327	Economy	14400.00
0005435426049	5327	Economy	14400.00
0005434345195	5327	Economy	14400.00
0005435380396	5327	Economy	14400.00
0005434345210	5327	Economy	14400.00
0005435616724	5327	Economy	14400.00
0005435319723	5327	Economy	14400.00
0005435616766	5327	Economy	14400.00
0005434345204	5327	Economy	14400.00
0005434245477	5327	Economy	14400.00
0005435616721	5327	Economy	14400.00
0005435425935	5327	Economy	14400.00
0005435302295	5327	Economy	14400.00
0005435616783	5327	Economy	14400.00
0005435616809	5327	Economy	14400.00
0005434345202	5327	Economy	14400.00
0005434245518	5327	Economy	14400.00
0005434345187	5327	Economy	14400.00
0005435426158	5327	Economy	14400.00
0005435426374	5327	Economy	14400.00
0005435426209	5327	Economy	14400.00
0005435616731	5327	Economy	14400.00
0005434245548	5327	Economy	14400.00
0005435617189	5327	Economy	14400.00
0005435616816	5327	Economy	14400.00
0005435426072	5327	Economy	14400.00
0005432363456	5327	Economy	14400.00
0005435616775	5327	Economy	14400.00
0005434345208	5327	Economy	14400.00
0005435616774	5327	Economy	14400.00
0005435616784	5327	Economy	14400.00
0005435426037	5327	Economy	14400.00
0005434573732	5327	Economy	14400.00
0005434573738	5327	Economy	14400.00
0005435042890	5327	Economy	14400.00
0005435616821	5327	Economy	14400.00
0005435426165	5327	Economy	14400.00
0005435426141	5327	Economy	14400.00
0005432841054	5327	Economy	14400.00
0005435426098	5327	Economy	14400.00
0005435616789	5327	Economy	14400.00
0005435616745	5327	Economy	14400.00
0005435426081	5327	Economy	14400.00
0005435617242	5327	Economy	14400.00
0005435616758	5327	Economy	14400.00
0005435616739	5327	Economy	14400.00
0005435616781	5327	Economy	14400.00
0005434573737	5327	Economy	14400.00
0005435616778	5327	Economy	14400.00
0005434245577	5327	Economy	14400.00
0005435616802	5327	Economy	14400.00
0005435616720	5327	Economy	14400.00
0005435616818	5327	Economy	14400.00
0005434245476	5327	Economy	14400.00
0005434345190	5327	Economy	14400.00
0005432047652	5327	Economy	14400.00
0005435380395	5327	Economy	14400.00
0005435042901	5327	Economy	14400.00
0005435425979	5327	Economy	14400.00
0005434573742	5327	Economy	14400.00
0005432841058	5327	Economy	14400.00
0005435616750	5327	Economy	14400.00
0005432363455	5327	Economy	14400.00
0005435302294	5327	Economy	14400.00
0005435616768	5327	Economy	14400.00
0005435426138	5327	Economy	14400.00
0005435319759	5327	Economy	14400.00
0005435425980	5327	Economy	14400.00
0005435616198	10918	Business	43100.00
0005435097381	10918	Business	43100.00
0005434573609	10918	Business	43100.00
0005432363507	10918	Business	43100.00
0005435615737	10918	Business	43100.00
0005435615752	10918	Business	43100.00
0005434344852	10918	Business	43100.00
0005435616163	10918	Business	43100.00
0005435615870	10918	Business	43100.00
0005432165251	10918	Business	43100.00
0005434344795	10918	Business	43100.00
0005435615797	10918	Business	43100.00
0005434245773	10918	Business	43100.00
0005434245772	10918	Business	43100.00
0005435615984	10918	Business	43100.00
0005435304264	10918	Business	43100.00
0005435616202	10918	Business	43100.00
0005434573587	10918	Business	43100.00
0005435426684	10918	Business	43100.00
0005434344818	10918	Comfort	24400.00
0005435426690	10918	Comfort	24400.00
0005434245791	10918	Comfort	24400.00
0005435615809	10918	Comfort	24400.00
0005435615806	10918	Comfort	24400.00
0005435615459	10918	Comfort	24400.00
0005434345030	10918	Comfort	24400.00
0005435426660	10918	Comfort	24400.00
0005435615692	10918	Comfort	24400.00
0005435615502	10918	Comfort	24400.00
0005435615761	10918	Comfort	24400.00
0005435615468	10918	Comfort	24400.00
0005434245785	10918	Comfort	24400.00
0005435426670	10918	Comfort	24400.00
0005435380425	10918	Comfort	24400.00
0005435616039	10918	Comfort	24400.00
0005435615571	10918	Comfort	24400.00
0005435426675	10918	Comfort	24400.00
0005434344865	10918	Comfort	24400.00
0005435426678	10918	Comfort	24400.00
0005434245775	10918	Comfort	24400.00
0005434245776	10918	Comfort	24400.00
0005432363508	10918	Comfort	24400.00
0005435615939	10918	Comfort	24400.00
0005435426674	10918	Comfort	24400.00
0005435615706	10918	Comfort	24400.00
0005435615070	10918	Comfort	24400.00
0005435380427	10918	Comfort	24400.00
0005434573543	10918	Comfort	24400.00
0005434344796	10918	Comfort	24400.00
0005435616094	10918	Comfort	24400.00
0005432363505	10918	Comfort	24400.00
0005435426679	10918	Comfort	24400.00
0005435426699	10918	Comfort	24400.00
0005435768117	10918	Comfort	24400.00
0005434573605	10918	Economy	14400.00
0005434344624	10918	Comfort	24400.00
0005435305068	10918	Economy	14400.00
0005432841070	10918	Economy	14400.00
0005435097404	10918	Economy	14400.00
0005435615909	10918	Economy	14400.00
0005435615757	10918	Economy	14400.00
0005435426661	10918	Economy	14400.00
0005435615705	10918	Economy	14400.00
0005435426688	10918	Economy	14400.00
0005435305069	10918	Economy	14400.00
0005435616164	10918	Economy	14400.00
0005435491492	10918	Economy	14400.00
0005434573553	10918	Economy	14400.00
0005435615507	10918	Economy	14400.00
0005435426666	10918	Economy	14400.00
0005434344941	10918	Economy	14400.00
0005434344819	10918	Economy	14400.00
0005435615277	10918	Economy	14400.00
0005435615892	10918	Economy	14400.00
0005435615528	10918	Economy	14400.00
0005434573616	10918	Economy	14400.00
0005435426686	10918	Economy	14400.00
0005435319815	10918	Economy	14400.00
0005435319814	10918	Economy	14400.00
0005435615509	10918	Economy	14400.00
0005435615460	10918	Economy	14400.00
0005435615572	10918	Economy	14400.00
0005435616095	10918	Economy	14400.00
0005435426676	10918	Economy	14400.00
0005434344895	10918	Economy	14400.00
0005435616600	10918	Economy	14400.00
0005435426687	10918	Economy	14400.00
0005435426692	10918	Economy	14400.00
0005435768118	10918	Economy	14400.00
0005435426665	10918	Economy	14400.00
0005435616102	10918	Economy	14400.00
0005434344866	10918	Economy	14400.00
0005434573593	10918	Economy	14400.00
0005435615875	10918	Economy	14400.00
0005434344894	10918	Economy	14400.00
0005434344954	10918	Economy	14400.00
0005435426668	10918	Economy	14400.00
0005435615918	10918	Economy	14400.00
0005435615940	10918	Economy	14400.00
0005435615842	10918	Economy	14400.00
0005435615598	10918	Economy	14400.00
0005435426693	10918	Economy	14400.00
0005434573608	10918	Economy	14400.00
0005434245792	10918	Economy	14400.00
0005435426683	10918	Economy	14400.00
0005435615529	10918	Economy	14400.00
0005435426707	10918	Economy	14400.00
0005435426700	10918	Economy	14400.00
0005432363506	10918	Economy	14400.00
0005435615709	10918	Economy	15800.00
0005434344829	10918	Economy	15800.00
0005435615350	10918	Economy	14400.00
0005434245771	10918	Economy	14400.00
0005434344670	10918	Economy	14400.00
0005435615563	10918	Economy	15800.00
0005434245781	10918	Economy	15800.00
0005432165247	10918	Economy	14400.00
0005434573618	10918	Economy	14400.00
0005435426697	10918	Economy	14400.00
0005434573639	10918	Economy	14400.00
0005434344886	10918	Economy	14400.00
0005435616038	10918	Economy	14400.00
0005435615626	10918	Economy	14400.00
0005435426663	10918	Economy	14400.00
0005435768113	10918	Economy	14400.00
0005435615941	10918	Economy	14400.00
0005435042931	10918	Economy	14400.00
0005434344785	10918	Economy	14400.00
0005435319810	10918	Economy	14400.00
0005434344853	10918	Economy	14400.00
0005435615537	10918	Economy	14400.00
0005435615758	10918	Economy	14400.00
0005435615888	10918	Economy	14400.00
0005434344859	10918	Economy	14400.00
0005435426694	10918	Economy	14400.00
0005434344678	10918	Economy	14400.00
0005435426681	10918	Economy	14400.00
0005435768116	10918	Economy	14400.00
0005435042932	10918	Economy	14400.00
0005435615503	10918	Economy	14400.00
0005435768115	10918	Economy	14400.00
0005435426672	10918	Economy	14400.00
0005435615759	10918	Economy	14400.00
0005433719234	10918	Economy	14400.00
0005435615982	10918	Economy	14400.00
0005435615069	10918	Economy	14400.00
0005435616049	10918	Economy	14400.00
0005434245783	10918	Economy	14400.00
0005434245779	10918	Economy	14400.00
0005435426703	10918	Economy	14400.00
0005434344953	10918	Economy	14400.00
0005435615676	10918	Economy	14400.00
0005435616210	10918	Economy	14400.00
0005435616048	10918	Economy	14400.00
0005434344942	10918	Economy	14400.00
0005435615972	10918	Economy	14400.00
0005435319816	10918	Economy	14400.00
0005434573617	10918	Economy	14400.00
0005434245789	10918	Economy	14400.00
0005434245769	10918	Economy	14400.00
0005435615712	10918	Economy	14400.00
0005435097380	10918	Economy	14400.00
0005435615693	10918	Economy	14400.00
0005434245770	10918	Economy	14400.00
0005435616063	10918	Economy	14400.00
0005434245778	10918	Economy	14400.00
0005435615836	10918	Economy	14400.00
0005435097424	10918	Economy	14400.00
0005435426689	10918	Economy	14400.00
0005432165250	10918	Economy	14400.00
0005434344896	10918	Economy	14400.00
0005435615711	10918	Economy	14400.00
0005434344957	10918	Economy	14400.00
0005435616205	10918	Economy	14400.00
0005434344671	10918	Economy	14400.00
0005434344786	10918	Economy	14400.00
0005435426664	10918	Economy	14400.00
0005435426662	10918	Economy	14400.00
0005435616096	10918	Economy	14400.00
0005434245774	10918	Economy	14400.00
0005435426682	10918	Economy	14400.00
0005435490283	10918	Economy	14400.00
0005434573610	10918	Economy	14400.00
0005434245790	10918	Economy	14400.00
0005435426701	10918	Economy	14400.00
0005435616211	10918	Economy	14400.00
0005435615534	10918	Economy	14400.00
0005435615908	10918	Economy	14400.00
0005434245768	10918	Economy	14400.00
0005435426695	10918	Economy	14400.00
0005435616275	10918	Economy	14400.00
0005435319812	10918	Economy	14400.00
0005435426669	10918	Economy	14400.00
0005435615810	10918	Economy	14400.00
0005434344741	10918	Economy	14400.00
0005435426698	10918	Economy	14400.00
0005434344871	10918	Economy	14400.00
0005434573604	10918	Economy	14400.00
0005435490316	10918	Economy	14400.00
0005434573612	10918	Economy	14400.00
0005435490315	10918	Economy	14400.00
0005435615731	10918	Economy	14400.00
0005435042929	10918	Economy	14400.00
0005434344955	10918	Economy	14400.00
0005435426685	10918	Economy	14400.00
0005435491488	10918	Economy	14400.00
0005435615248	10918	Economy	15800.00
0005435304263	10918	Economy	15800.00
0005435426677	10918	Economy	15800.00
0005435097337	10918	Economy	15800.00
0005434344870	10918	Economy	14400.00
0005435615804	10918	Economy	14400.00
0005435426704	10918	Economy	14400.00
0005434573594	10918	Economy	14400.00
0005435615306	10918	Economy	14400.00
0005435615749	10918	Economy	14400.00
0005434245787	10918	Economy	14400.00
0005435615585	10918	Economy	14400.00
0005435615877	10918	Economy	14400.00
0005435426696	10918	Economy	14400.00
0005435615978	10918	Economy	14400.00
0005435491478	10918	Economy	14400.00
0005435097338	10918	Economy	14400.00
0005435615746	10918	Economy	14400.00
0005435615710	10918	Economy	14400.00
0005435426680	10918	Economy	14400.00
0005434245782	10918	Economy	14400.00
0005435380423	10918	Economy	14400.00
0005435615330	10918	Economy	14400.00
0005434573486	10918	Economy	14400.00
0005435615678	10918	Economy	14400.00
0005435615514	10918	Economy	14400.00
0005434656612	10918	Economy	14400.00
0005435615179	10918	Economy	14400.00
0005434245788	10918	Economy	14400.00
0005435491493	10918	Economy	14400.00
0005435426705	10918	Economy	14400.00
0005434573613	10918	Economy	14400.00
0005434344864	10918	Economy	14400.00
0005435426671	10918	Economy	14400.00
0005435042933	10918	Economy	14400.00
0005434344805	10918	Economy	14400.00
0005435768114	10918	Economy	14400.00
0005434573542	10918	Economy	14400.00
0005435615747	10918	Economy	14400.00
0005435097382	10918	Economy	14400.00
0005435615501	10918	Economy	14400.00
0005435305070	10918	Economy	14400.00
0005435615855	10918	Economy	14400.00
0005435615601	10918	Economy	14400.00
0005435616276	10918	Economy	14400.00
0005435615748	10918	Economy	14400.00
0005435615679	10918	Economy	14400.00
0005432165246	10918	Economy	14400.00
0005435615891	10918	Economy	14400.00
0005435615848	10918	Economy	14400.00
0005435319811	10918	Economy	14400.00
0005435615586	10918	Economy	14400.00
0005432165248	10918	Economy	14400.00
0005435615927	10918	Economy	14400.00
0005435426659	10918	Economy	14400.00
0005435615907	10918	Economy	14400.00
0005435615983	10918	Economy	14400.00
0005435615807	10918	Economy	14400.00
0005435426673	10918	Economy	14400.00
0005432165249	10918	Economy	14400.00
0005435616372	10918	Economy	14400.00
0005434573572	10918	Economy	14400.00
0005435616190	10918	Economy	14400.00
0005435042930	10918	Economy	14400.00
0005435616040	10918	Economy	14400.00
0005435616199	10918	Economy	14400.00
0005434344724	10918	Economy	14400.00
0005435615721	10918	Economy	14400.00
0005435616181	10918	Economy	14400.00
0005432841072	10918	Economy	14400.00
0005434245784	10918	Economy	14400.00
0005435426706	10918	Economy	14400.00
0005435615722	10918	Economy	14400.00
0005435615597	10918	Economy	14400.00
0005434245780	10918	Economy	14400.00
0005435615689	10918	Economy	14400.00
0005435380424	10918	Economy	14400.00
0005435615467	10918	Economy	14400.00
0005435615751	10918	Economy	14400.00
0005434245777	10918	Economy	14400.00
0005434344677	10918	Economy	14400.00
0005435615713	10918	Economy	14400.00
0005435319813	10918	Economy	14400.00
0005434573552	10918	Economy	14400.00
0005435615610	10918	Economy	14400.00
0005435491482	10918	Economy	14400.00
0005433719233	10918	Economy	14400.00
0005434573583	10918	Economy	14400.00
0005435615331	10918	Economy	14400.00
0005435615719	10918	Economy	14400.00
0005435426667	10918	Economy	14400.00
0005435380426	10918	Economy	14400.00
0005434344985	10918	Economy	14400.00
0005433719232	10918	Economy	14400.00
0005434245786	10918	Economy	14400.00
0005435426702	10918	Economy	14400.00
0005432841071	10918	Economy	14400.00
0005435615856	10918	Economy	14400.00
0005435615675	10918	Economy	14400.00
0005435426691	10918	Economy	14400.00
0005435615508	10918	Economy	14400.00
0005433507684	3313	Business	18800.00
0005432182333	3313	Business	18800.00
0005432460801	3313	Business	18800.00
0005433634743	3313	Business	18800.00
0005432182319	3313	Business	18800.00
0005432182332	3313	Business	18800.00
0005433806336	3313	Business	18800.00
0005433507687	3313	Business	18800.00
0005433634740	3313	Business	18800.00
0005433634757	3313	Business	18800.00
0005432460732	3313	Business	18800.00
0005432182327	3313	Business	18800.00
0005433806344	3313	Business	18800.00
0005432460993	3313	Business	18800.00
0005433806328	3313	Business	18800.00
0005434143778	3313	Business	18800.00
0005434143785	3313	Business	18800.00
0005432182321	3313	Business	18800.00
0005433507681	3313	Business	18800.00
0005433806346	3313	Business	18800.00
0005432460727	3313	Business	18800.00
0005433806339	3313	Business	18800.00
0005433634754	3313	Business	18800.00
0005434143775	3313	Business	18800.00
0005433806343	3313	Business	18800.00
0005432460722	3313	Business	18800.00
0005433806333	3313	Business	18800.00
0005433634752	3313	Business	18800.00
0005434143786	3313	Economy	6900.00
0005432460769	3313	Economy	6900.00
0005434143788	3313	Economy	6900.00
0005432460635	3313	Economy	6900.00
0005432461087	3313	Economy	6900.00
0005433507685	3313	Economy	6900.00
0005434143782	3313	Economy	6300.00
0005432460859	3313	Economy	6300.00
0005433507678	3313	Economy	6300.00
0005433634755	3313	Economy	6300.00
0005432461085	3313	Economy	6300.00
0005432460976	3313	Economy	6300.00
0005434143787	3313	Economy	6300.00
0005433507683	3313	Economy	6300.00
0005432182316	3313	Economy	6300.00
0005432460861	3313	Economy	6300.00
0005432460995	3313	Economy	6300.00
0005433634760	3313	Economy	6300.00
0005432182329	3313	Economy	6300.00
0005432182334	3313	Economy	6300.00
0005432182330	3313	Economy	6300.00
0005432182324	3313	Economy	6300.00
0005432182323	3313	Economy	6300.00
0005434143769	3313	Economy	6300.00
0005432460931	3313	Economy	6300.00
0005434143783	3313	Economy	6300.00
0005433806349	3313	Economy	6300.00
0005432460831	3313	Economy	6300.00
0005432182326	3313	Economy	6300.00
0005433806351	3313	Economy	6300.00
0005433806331	3313	Economy	6300.00
0005434143770	3313	Economy	6300.00
0005433634764	3313	Economy	6300.00
0005432460971	3313	Economy	6300.00
0005432460793	3313	Economy	6300.00
0005434143784	3313	Economy	6300.00
0005433634753	3313	Economy	6300.00
0005432460795	3313	Economy	6300.00
0005432182331	3313	Economy	6300.00
0005432182328	3313	Economy	6300.00
0005434143771	3313	Economy	6300.00
0005432460830	3313	Economy	6300.00
0005433634749	3313	Economy	6300.00
0005432460774	3313	Economy	6300.00
0005433806345	3313	Economy	6300.00
0005433507680	3313	Economy	6300.00
0005434143773	3313	Economy	6300.00
0005433634744	3313	Economy	6300.00
0005432461036	3313	Economy	6300.00
0005434143772	3313	Economy	6300.00
0005432460633	3313	Economy	6300.00
0005434143774	3313	Economy	6300.00
0005433507679	3313	Economy	6300.00
0005432460796	3313	Economy	6300.00
0005433634759	3313	Economy	6300.00
0005432460778	3313	Economy	6300.00
0005432461086	3313	Economy	6300.00
0005432460789	3313	Economy	6300.00
0005432460800	3313	Economy	6300.00
0005432460638	3313	Economy	6300.00
0005433806326	3313	Economy	6300.00
0005433634741	3313	Economy	6300.00
0005432460779	3313	Economy	6300.00
0005432460747	3313	Economy	6300.00
0005433806329	3313	Economy	6300.00
0005433806324	3313	Economy	6900.00
0005433806332	3313	Economy	6300.00
0005434143779	3313	Economy	6900.00
0005433507688	3313	Economy	6900.00
0005433806337	3313	Economy	6900.00
0005433634745	3313	Economy	6900.00
0005432182317	3313	Economy	6300.00
0005434143777	3313	Economy	6300.00
0005432460748	3313	Economy	6300.00
0005432460858	3313	Economy	6300.00
0005434143780	3313	Economy	6900.00
0005432461066	3313	Economy	6300.00
0005432460636	3313	Economy	6300.00
0005433806340	3313	Economy	6300.00
0005432460860	3313	Economy	6300.00
0005432460760	3313	Economy	6300.00
0005433806338	3313	Economy	6300.00
0005433634756	3313	Economy	6300.00
0005433806330	3313	Economy	6300.00
0005432460829	3313	Economy	6300.00
0005433634750	3313	Economy	6300.00
0005433806347	3313	Economy	6300.00
0005434143790	3313	Economy	6300.00
0005432460767	3313	Economy	6300.00
0005432460871	3313	Economy	6300.00
0005432460874	3313	Economy	6300.00
0005433634739	3313	Economy	6300.00
0005433634751	3313	Economy	6300.00
0005433634763	3313	Economy	6300.00
0005433634762	3313	Economy	6300.00
0005432460965	3313	Economy	6300.00
0005432460817	3313	Economy	6300.00
0005432461065	3313	Economy	6300.00
0005434143781	3313	Economy	6300.00
0005433806350	3313	Economy	6300.00
0005432182322	3313	Economy	6300.00
0005433634747	3313	Economy	6300.00
0005434143767	3313	Economy	6300.00
0005432460707	3313	Economy	6300.00
0005433634748	3313	Economy	6300.00
0005433634742	3313	Economy	6300.00
0005433806352	3313	Economy	6300.00
0005432460912	3313	Economy	6300.00
0005432460873	3313	Economy	6300.00
0005432460850	3313	Economy	6300.00
0005432460655	3313	Economy	6300.00
0005433507682	3313	Economy	6300.00
0005433634761	3313	Economy	6300.00
0005432461116	3313	Economy	6300.00
0005433806341	3313	Economy	6300.00
0005433634758	3313	Economy	6300.00
0005433634746	3313	Economy	6300.00
0005432460759	3313	Economy	6300.00
0005432460658	3313	Economy	6300.00
0005432460792	3313	Economy	6300.00
0005434143789	3313	Economy	6300.00
0005432460624	3313	Economy	6300.00
0005432460994	3313	Economy	6300.00
0005434143768	3313	Economy	6300.00
0005432182325	3313	Economy	6300.00
0005434143776	3313	Economy	6300.00
0005433634766	3313	Economy	6300.00
0005433806325	3313	Economy	6300.00
0005433634765	3313	Economy	6300.00
0005432182318	3313	Economy	6300.00
0005433806335	3313	Economy	6300.00
0005434143791	3313	Economy	6300.00
0005432460637	3313	Economy	6300.00
0005433806327	3313	Economy	6300.00
0005432182320	3313	Economy	6300.00
0005432460851	3313	Economy	6300.00
0005433806342	3313	Economy	6300.00
0005433806323	3313	Economy	6300.00
0005433806334	3313	Economy	6300.00
0005432460761	3313	Economy	6300.00
0005433507686	3313	Economy	6300.00
0005433806348	3313	Economy	6300.00
0005435886234	3312	Business	18800.00
0005435886132	3312	Business	18800.00
0005435886076	3312	Business	18800.00
0005435886218	3312	Business	18800.00
0005435886077	3312	Business	18800.00
0005435886334	3312	Business	18800.00
0005435886188	3312	Economy	6300.00
0005435886339	3312	Economy	6300.00
0005435886211	3312	Economy	6300.00
0005435886123	3312	Economy	6300.00
0005435886217	3312	Economy	6300.00
0005435886167	3312	Economy	6300.00
0005435886113	3312	Economy	6300.00
0005435886291	3312	Economy	6300.00
0005435886207	3312	Economy	6300.00
0005435886128	3312	Economy	6300.00
0005435886122	3312	Economy	6300.00
0005435886116	3312	Economy	6300.00
0005435886493	3312	Economy	6900.00
0005435886112	3312	Economy	6900.00
0005435886348	3312	Economy	6300.00
0005435886241	3312	Economy	6300.00
0005435886175	3312	Economy	6300.00
0005435886130	3312	Economy	6300.00
0005435886494	3312	Economy	6300.00
0005435885937	3312	Economy	6300.00
0005435886129	3312	Economy	6300.00
0005435886382	3312	Economy	6300.00
0005435886212	3312	Economy	6300.00
0005435886335	3312	Economy	6300.00
0005435886181	3312	Economy	6300.00
0005435886279	3312	Economy	6300.00
0005435886168	3312	Economy	6300.00
0005435886219	3312	Economy	6300.00
0005435886174	3312	Economy	6300.00
0005435886165	3312	Economy	6300.00
0005435886075	3312	Economy	6300.00
0005435886162	3312	Economy	6300.00
0005435886287	3312	Economy	6300.00
0005435886059	3312	Economy	6300.00
0005435886133	3312	Economy	6300.00
0005435886362	3312	Economy	6300.00
0005435886166	3312	Economy	6300.00
0005435886060	3312	Economy	6300.00
0005435886409	3312	Economy	6300.00
0005435886292	3312	Economy	6300.00
0005435886288	3312	Economy	6300.00
0005435886383	3312	Economy	6300.00
0005432461319	8293	Business	18800.00
0005432461300	8293	Business	18800.00
0005432461304	8293	Business	18800.00
0005435886624	8293	Business	18800.00
0005435886651	8293	Business	18800.00
0005435886617	8293	Business	18800.00
0005435886632	8293	Business	18800.00
0005435886654	8293	Business	18800.00
0005435886636	8293	Business	18800.00
0005432461310	8293	Business	18800.00
0005432043096	8293	Business	18800.00
0005435886665	8293	Business	18800.00
0005435886655	8293	Business	18800.00
0005435886653	8293	Business	18800.00
0005435886595	8293	Business	18800.00
0005435886615	8293	Business	18800.00
0005432461328	8293	Business	18800.00
0005435142999	8293	Business	18800.00
0005435886644	8293	Business	18800.00
0005435886594	8293	Business	18800.00
0005432461311	8293	Business	18800.00
0005432461321	8293	Business	18800.00
0005435886605	8293	Business	18800.00
0005433507513	8293	Business	18800.00
0005432461296	8293	Business	18800.00
0005435886647	8293	Business	18800.00
0005433507502	8293	Business	18800.00
0005433507607	8293	Business	18800.00
0005432461322	8293	Economy	6900.00
0005435886588	8293	Economy	6900.00
0005435886661	8293	Economy	6900.00
0005432461314	8293	Economy	6900.00
0005435886657	8293	Economy	6900.00
0005435886602	8293	Economy	6900.00
0005435886596	8293	Economy	6300.00
0005432461318	8293	Economy	6300.00
0005435886606	8293	Economy	6300.00
0005432461327	8293	Economy	6300.00
0005435886623	8293	Economy	6300.00
0005435886618	8293	Economy	6300.00
0005435886609	8293	Economy	6300.00
0005433507568	8293	Economy	6300.00
0005434326294	8293	Economy	6300.00
0005432461323	8293	Economy	6300.00
0005432461326	8293	Economy	6300.00
0005433507489	8293	Economy	6300.00
0005432461298	8293	Economy	6300.00
0005433507496	8293	Economy	6300.00
0005432043100	8293	Economy	6300.00
0005435886626	8293	Economy	6300.00
0005435886621	8293	Economy	6300.00
0005433507551	8293	Economy	6300.00
0005435886630	8293	Economy	6300.00
0005435886608	8293	Economy	6300.00
0005435886631	8293	Economy	6300.00
0005435886641	8293	Economy	6300.00
0005432461329	8293	Economy	6300.00
0005432043094	8293	Economy	6300.00
0005435886604	8293	Economy	6300.00
0005434312377	8293	Economy	6300.00
0005435886597	8293	Economy	6300.00
0005432461309	8293	Economy	6300.00
0005432461301	8293	Economy	6300.00
0005433507538	8293	Economy	6300.00
0005435886634	8293	Economy	6300.00
0005433507497	8293	Economy	6300.00
0005435142998	8293	Economy	6300.00
0005435886598	8293	Economy	6300.00
0005435886662	8293	Economy	6300.00
0005435886613	8293	Economy	6300.00
0005432461299	8293	Economy	6300.00
0005435886648	8293	Economy	6300.00
0005432461325	8293	Economy	6300.00
0005432461297	8293	Economy	6300.00
0005435886639	8293	Economy	6300.00
0005435886593	8293	Economy	6300.00
0005435886637	8293	Economy	6300.00
0005432461317	8293	Economy	6300.00
0005435886599	8293	Economy	6300.00
0005434312393	8293	Economy	6300.00
0005432461306	8293	Economy	6300.00
0005432043097	8293	Economy	6300.00
0005435886627	8293	Economy	6300.00
0005435886622	8293	Economy	6300.00
0005433507545	8293	Economy	6300.00
0005435886664	8293	Economy	6300.00
0005432461303	8293	Economy	6300.00
0005435886638	8293	Economy	6300.00
0005432461312	8293	Economy	6300.00
0005433507505	8293	Economy	6900.00
0005434312378	8293	Economy	6900.00
0005433507501	8293	Economy	6900.00
0005433507570	8293	Economy	6900.00
0005432043092	8293	Economy	6900.00
0005434312394	8293	Economy	6300.00
0005435886658	8293	Economy	6300.00
0005435886610	8293	Economy	6300.00
0005435886652	8293	Economy	6300.00
0005433507537	8293	Economy	6300.00
0005432461316	8293	Economy	6900.00
0005435886640	8293	Economy	6300.00
0005435886611	8293	Economy	6300.00
0005435886612	8293	Economy	6300.00
0005432461308	8293	Economy	6300.00
0005433507546	8293	Economy	6300.00
0005435886625	8293	Economy	6300.00
0005435886645	8293	Economy	6300.00
0005435143000	8293	Economy	6300.00
0005435886656	8293	Economy	6300.00
0005435886592	8293	Economy	6300.00
0005432461324	8293	Economy	6300.00
0005433507437	8293	Economy	6300.00
0005434326295	8293	Economy	6300.00
0005433507525	8293	Economy	6300.00
0005435886620	8293	Economy	6300.00
0005432043095	8293	Economy	6300.00
0005432461320	8293	Economy	6300.00
0005433507455	8293	Economy	6300.00
0005435886614	8293	Economy	6300.00
0005432043091	8293	Economy	6300.00
0005433507535	8293	Economy	6300.00
0005432043098	8293	Economy	6300.00
0005435886603	8293	Economy	6300.00
0005435886660	8293	Economy	6300.00
0005433507615	8293	Economy	6300.00
0005435886601	8293	Economy	6300.00
0005435886666	8293	Economy	6300.00
0005435886616	8293	Economy	6300.00
0005435886629	8293	Economy	6300.00
0005433507438	8293	Economy	6300.00
0005435886646	8293	Economy	6300.00
0005435886590	8293	Economy	6300.00
0005432043099	8293	Economy	6300.00
0005432043101	8293	Economy	6300.00
0005435886589	8293	Economy	6300.00
0005433507439	8293	Economy	6300.00
0005435886643	8293	Economy	6300.00
0005433507597	8293	Economy	6300.00
0005432461302	8293	Economy	6300.00
0005433507596	8293	Economy	6300.00
0005433507569	8293	Economy	6300.00
0005432461305	8293	Economy	6300.00
0005435886628	8293	Economy	6300.00
0005435886635	8293	Economy	6300.00
0005432461315	8293	Economy	6300.00
0005432043093	8293	Economy	6300.00
0005435886619	8293	Economy	6300.00
0005435886633	8293	Economy	6300.00
0005435886663	8293	Economy	6300.00
0005435886607	8293	Economy	6300.00
0005435886649	8293	Economy	6300.00
0005433507488	8293	Economy	6300.00
0005435886600	8293	Economy	6300.00
0005435886650	8293	Economy	6300.00
0005435886642	8293	Economy	6300.00
0005435886591	8293	Economy	6300.00
0005432461307	8293	Economy	6300.00
0005435886659	8293	Economy	6300.00
0005432461313	8293	Economy	6300.00
0005432461330	8293	Economy	6300.00
0005434326293	8293	Economy	6300.00
0005435860687	8240	Business	18800.00
0005433634352	8240	Business	18800.00
0005433805852	8240	Business	18800.00
0005433805853	8240	Business	18800.00
0005433805975	8240	Business	18800.00
0005433634370	8240	Business	18800.00
0005435860681	8240	Business	18800.00
0005433634478	8240	Business	18800.00
0005433634521	8240	Business	18800.00
0005435860689	8240	Business	18800.00
0005433805856	8240	Business	18800.00
0005433634465	8240	Business	18800.00
0005433634403	8240	Economy	6900.00
0005433634304	8240	Economy	6900.00
0005433806113	8240	Economy	6900.00
0005433634459	8240	Economy	6300.00
0005433806024	8240	Economy	6300.00
0005433805851	8240	Economy	6300.00
0005433806197	8240	Economy	6300.00
0005433806006	8240	Economy	6300.00
0005433806101	8240	Economy	6300.00
0005433634497	8240	Economy	6300.00
0005433634402	8240	Economy	6300.00
0005433634321	8240	Economy	6300.00
0005433634438	8240	Economy	6300.00
0005433805995	8240	Economy	6300.00
0005433634437	8240	Economy	6300.00
0005433634444	8240	Economy	6300.00
0005433634479	8240	Economy	6300.00
0005433806116	8240	Economy	6300.00
0005433805914	8240	Economy	6300.00
0005433634287	8240	Economy	6300.00
0005433805967	8240	Economy	6300.00
0005433634477	8240	Economy	6300.00
0005435860683	8240	Economy	6300.00
0005433634412	8240	Economy	6300.00
0005433634476	8240	Economy	6300.00
0005433634461	8240	Economy	6300.00
0005433805898	8240	Economy	6300.00
0005435860692	8240	Economy	6300.00
0005435860694	8240	Economy	6300.00
0005435860682	8240	Economy	6300.00
0005433634490	8240	Economy	6300.00
0005435860688	8240	Economy	6300.00
0005433634344	8240	Economy	6300.00
0005433634375	8240	Economy	6900.00
0005433634299	8240	Economy	6900.00
0005433634377	8240	Economy	6900.00
0005433806045	8240	Economy	6900.00
0005433634527	8240	Economy	6300.00
0005433634443	8240	Economy	6300.00
0005433634410	8240	Economy	6300.00
0005435860686	8240	Economy	6300.00
0005435860690	8240	Economy	6300.00
0005435860684	8240	Economy	6300.00
0005434271357	8240	Economy	6300.00
0005435860693	8240	Economy	6300.00
0005433806009	8240	Economy	6300.00
0005433634376	8240	Economy	6300.00
0005433634379	8240	Economy	6300.00
0005434143752	8240	Economy	6300.00
0005433805974	8240	Economy	6300.00
0005433806013	8240	Economy	6300.00
0005435860685	8240	Economy	6300.00
0005433634436	8240	Economy	6300.00
0005433634349	8240	Economy	6300.00
0005433806112	8240	Economy	6300.00
0005433634286	8240	Economy	6300.00
0005433806143	8240	Economy	6300.00
0005433805994	8240	Economy	6300.00
0005433634469	8240	Economy	6300.00
0005433805855	8240	Economy	6300.00
0005433634457	8240	Economy	6300.00
0005435860691	8240	Economy	6300.00
0005433806114	8240	Economy	6300.00
0005433634384	8240	Economy	6300.00
0005433634298	8240	Economy	6300.00
0005433634350	8240	Economy	6300.00
0005433634305	8240	Economy	6300.00
0005433634466	8240	Economy	6300.00
0005433634303	8240	Economy	6300.00
0005433634235	8240	Economy	6300.00
0005433806026	8240	Economy	6300.00
0005433634491	8240	Economy	6300.00
0005433634430	8240	Economy	6300.00
0005433805966	8240	Economy	6300.00
0005433634302	8240	Economy	6300.00
0005433634429	8240	Economy	6300.00
0005433806198	8240	Economy	6300.00
0005433806094	8240	Economy	6300.00
0005433805951	8240	Economy	6300.00
0005434183615	8314	Economy	6900.00
0005434183620	8314	Economy	6300.00
0005432384252	4637	Business	9900.00
0005433722448	4637	Business	9900.00
0005433722444	4637	Business	9900.00
0005433722440	4637	Business	9900.00
0005432384234	4637	Business	9900.00
0005433722435	4637	Business	9900.00
0005432384268	4637	Business	9900.00
0005432384256	4637	Business	9900.00
0005432728278	4637	Business	9900.00
0005432384240	4637	Business	9900.00
0005433722438	4637	Business	9900.00
0005432384247	4637	Economy	3300.00
0005433722437	4637	Economy	3300.00
0005432384261	4637	Economy	3300.00
0005432728271	4637	Economy	3300.00
0005432384250	4637	Economy	3300.00
0005433194955	4637	Economy	3300.00
0005432384266	4637	Economy	3300.00
0005433194947	4637	Economy	3300.00
0005432384237	4637	Economy	3600.00
0005433722433	4637	Economy	3600.00
0005433194948	4637	Economy	3300.00
0005433722432	4637	Economy	3300.00
0005433194952	4637	Economy	3300.00
0005432728276	4637	Economy	3300.00
0005432384257	4637	Economy	3300.00
0005432728274	4637	Economy	3300.00
0005432384245	4637	Economy	3300.00
0005433722431	4637	Economy	3300.00
0005432384264	4637	Economy	3300.00
0005433194951	4637	Economy	3300.00
0005433722436	4637	Economy	3300.00
0005433194954	4637	Economy	3300.00
0005433194960	4637	Economy	3300.00
0005433194959	4637	Economy	3300.00
0005432384262	4637	Economy	3300.00
0005433722430	4637	Economy	3300.00
0005433722446	4637	Economy	3300.00
0005432384242	4637	Economy	3300.00
0005432728273	4637	Economy	3300.00
0005432384235	4637	Economy	3300.00
0005432384246	4637	Economy	3300.00
0005432384267	4637	Economy	3300.00
0005432384239	4637	Economy	3300.00
0005432384255	4637	Economy	3300.00
0005432384263	4637	Economy	3300.00
0005432384265	4637	Economy	3300.00
0005432384238	4637	Economy	3300.00
0005433194950	4637	Economy	3300.00
0005433722442	4637	Economy	3300.00
0005432384253	4637	Economy	3300.00
0005432384259	4637	Economy	3300.00
0005433722443	4637	Economy	3300.00
0005432384243	4637	Economy	3300.00
0005432384249	4637	Economy	3300.00
0005433194956	4637	Economy	3300.00
0005432384236	4637	Economy	3300.00
0005433722427	4637	Economy	3300.00
0005433194953	4637	Economy	3300.00
0005432384248	4637	Economy	3300.00
0005432728275	4637	Economy	3300.00
0005433722447	4637	Economy	3300.00
0005433453818	4637	Economy	3300.00
0005432384251	4637	Economy	3300.00
0005432384244	4637	Economy	3300.00
0005432384260	4637	Economy	3300.00
0005432728272	4637	Economy	3300.00
0005432728277	4637	Economy	3300.00
0005433194949	4637	Economy	3300.00
0005433722439	4637	Economy	3300.00
0005433194957	4637	Economy	3300.00
0005433722429	4637	Economy	3300.00
0005432384241	4637	Economy	3300.00
0005433722434	4637	Economy	3300.00
0005433722441	4637	Economy	3300.00
0005432384254	4637	Economy	3300.00
0005433722428	4637	Economy	3300.00
0005433194958	4637	Economy	3300.00
0005433722445	4637	Economy	3300.00
0005432384258	4637	Economy	3300.00
0005432728205	30193	Business	9900.00
0005432383742	30193	Business	9900.00
0005432383869	30193	Business	9900.00
0005432383903	30193	Business	9900.00
0005432728200	30193	Business	9900.00
0005432383772	30193	Business	9900.00
0005433722321	30193	Business	9900.00
0005432383868	30193	Business	9900.00
0005432383720	30193	Business	9900.00
0005432383982	30193	Business	9900.00
0005432383814	30193	Economy	3300.00
0005432383834	30193	Economy	3300.00
0005432383783	30193	Economy	3300.00
0005432383811	30193	Economy	3300.00
0005433194900	30193	Economy	3300.00
0005432383659	30193	Economy	3300.00
0005432383819	30193	Economy	3300.00
0005432383820	30193	Economy	3300.00
0005433194901	30193	Economy	3600.00
0005432383887	30193	Economy	3600.00
0005432383579	30193	Economy	3600.00
0005432383721	30193	Economy	3300.00
0005432383580	30193	Economy	3300.00
0005433194893	30193	Economy	3300.00
0005432383743	30193	Economy	3300.00
0005432383657	30193	Economy	3300.00
0005432383983	30193	Economy	3300.00
0005432383760	30193	Economy	3300.00
0005432383691	30193	Economy	3300.00
0005433722336	30193	Economy	3300.00
0005432728182	30193	Economy	3300.00
0005433722335	30193	Economy	3300.00
0005432383766	30193	Economy	3300.00
0005432383708	30193	Economy	3300.00
0005432383888	30193	Economy	3300.00
0005432383653	30193	Economy	3300.00
0005432383835	30193	Economy	3300.00
0005432384013	30193	Economy	3300.00
0005432383776	30193	Economy	3300.00
0005432383785	30193	Economy	3300.00
0005432728129	30193	Economy	3300.00
0005432728100	30193	Economy	3300.00
0005432383644	30193	Economy	3300.00
0005432383744	30193	Economy	3300.00
0005432383652	30193	Economy	3300.00
0005433194898	30193	Economy	3300.00
0005432383658	30193	Economy	3300.00
0005432728130	30193	Economy	3300.00
0005432728101	30193	Economy	3300.00
0005433194892	30193	Economy	3300.00
0005432728201	30193	Economy	3300.00
0005432383722	30193	Economy	3300.00
0005432383771	30193	Economy	3300.00
0005432383794	30193	Economy	3300.00
0005433722316	30193	Economy	3300.00
0005432383784	30193	Economy	3300.00
0005432383799	30193	Economy	3300.00
0005432383782	30193	Economy	3300.00
0005432383641	30193	Economy	3300.00
0005432728194	30193	Economy	3300.00
0005432383853	30193	Economy	3300.00
0005432383822	30193	Economy	3300.00
0005432383804	30193	Economy	3300.00
0005432383815	30193	Economy	3300.00
0005432383805	30193	Economy	3300.00
0005432728102	30193	Economy	3300.00
0005432383645	30193	Economy	3300.00
0005433194902	30193	Economy	3300.00
0005432728202	30193	Economy	3300.00
0005432383647	30193	Economy	3300.00
0005432383852	30193	Economy	3300.00
0005433517149	1766	Business	57200.00
0005433517142	1766	Business	57200.00
0005435530140	1766	Business	57200.00
0005435541599	1766	Business	57200.00
0005435529852	1766	Business	57200.00
0005432925122	1766	Business	57200.00
0005435530151	1766	Business	57200.00
0005433517145	1766	Business	57200.00
0005435541595	1766	Economy	19100.00
0005432294553	1766	Economy	19100.00
0005435529856	1766	Economy	19100.00
0005435530152	1766	Economy	19100.00
0005435530143	1766	Economy	19100.00
0005432294555	1766	Economy	19100.00
0005435529858	1766	Economy	21000.00
0005432925131	1766	Economy	21000.00
0005435529861	1766	Economy	21000.00
0005435529850	1766	Economy	21000.00
0005435541592	1766	Economy	21000.00
0005435530146	1766	Economy	19100.00
0005432925123	1766	Economy	19100.00
0005435530149	1766	Economy	19100.00
0005435541602	1766	Economy	19100.00
0005435530148	1766	Economy	19100.00
0005433517148	1766	Economy	19100.00
0005433517144	1766	Economy	19100.00
0005435541605	1766	Economy	19100.00
0005435530150	1766	Economy	19100.00
0005433517147	1766	Economy	19100.00
0005435541598	1766	Economy	19100.00
0005435541594	1766	Economy	19100.00
0005435530141	1766	Economy	19100.00
0005435530155	1766	Economy	19100.00
0005435530145	1766	Economy	19100.00
0005435530142	1766	Economy	19100.00
0005432925132	1766	Economy	19100.00
0005435529857	1766	Economy	19100.00
0005435530154	1766	Economy	19100.00
0005435541600	1766	Economy	19100.00
0005435529846	1766	Economy	19100.00
0005435529849	1766	Economy	19100.00
0005435529860	1766	Economy	19100.00
0005433517151	1766	Economy	19100.00
0005433517150	1766	Economy	19100.00
0005435529851	1766	Economy	19100.00
0005432925124	1766	Economy	19100.00
0005435530153	1766	Economy	19100.00
0005435541593	1766	Economy	19100.00
0005435529859	1766	Economy	19100.00
0005435541596	1766	Economy	19100.00
0005435530144	1766	Economy	19100.00
0005433517143	1766	Economy	19100.00
0005435529854	1766	Economy	19100.00
0005432925133	1766	Economy	19100.00
0005435529853	1766	Economy	19100.00
0005435529855	1766	Economy	19100.00
0005435541601	1766	Economy	19100.00
0005435541597	1766	Economy	19100.00
0005435530156	1766	Economy	19100.00
0005435530147	1766	Economy	19100.00
0005433517146	1766	Economy	19100.00
0005435541603	1766	Economy	19100.00
0005435541604	1766	Economy	19100.00
0005435529847	1766	Economy	19100.00
0005432294554	1766	Economy	19100.00
0005435529848	1766	Economy	19100.00
0005432925166	22029	Business	57200.00
0005435541425	22029	Business	57200.00
0005435518164	22029	Business	57200.00
0005433517054	22029	Business	57200.00
0005432925169	22029	Business	57200.00
0005435541402	22029	Business	57200.00
0005435518214	22029	Economy	19100.00
0005432925165	22029	Economy	19100.00
0005435518224	22029	Economy	19100.00
0005435541463	22029	Economy	19100.00
0005435518163	22029	Economy	19100.00
0005435518244	22029	Economy	21000.00
0005433517053	22029	Economy	21000.00
0005435541435	22029	Economy	21000.00
0005432925167	22029	Economy	19100.00
0005435518220	22029	Economy	19100.00
0005435541487	22029	Economy	19100.00
0005435518250	22029	Economy	19100.00
0005435541398	22029	Economy	19100.00
0005433517095	22029	Economy	19100.00
0005435541462	22029	Economy	19100.00
0005435541460	22029	Economy	19100.00
0005435518188	22029	Economy	19100.00
0005435541346	22029	Economy	19100.00
0005435541427	22029	Economy	19100.00
0005435518254	22029	Economy	19100.00
0005435541369	22029	Economy	19100.00
0005435518279	22029	Economy	19100.00
0005435518201	22029	Economy	19100.00
0005432925168	22029	Economy	19100.00
0005435541434	22029	Economy	19100.00
0005435518298	22029	Economy	19100.00
0005435518213	22029	Economy	19100.00
0005435541461	22029	Economy	19100.00
0005435518165	22029	Economy	19100.00
0005435541476	22029	Economy	19100.00
0005435541395	22029	Economy	19100.00
0005435541401	22029	Economy	19100.00
0005435518245	22029	Economy	19100.00
0005435541426	22029	Economy	19100.00
0005435518123	22029	Economy	19100.00
0005435541357	22029	Economy	19100.00
0005435541340	22029	Economy	19100.00
0005435541399	22029	Economy	19100.00
0005435541368	22029	Economy	19100.00
0005433517094	22029	Economy	19100.00
0005435541419	22029	Economy	19100.00
0005435541415	22029	Economy	19100.00
0005435541418	22029	Economy	19100.00
0005435518297	22029	Economy	19100.00
0005434459382	7375	Business	18500.00
0005432839880	7375	Business	18500.00
0005435253055	7375	Business	18500.00
0005432073486	7375	Business	18500.00
0005435253014	7375	Business	18500.00
0005432839884	7375	Business	18500.00
0005434459385	7375	Business	18500.00
0005435253091	7375	Business	18500.00
0005432839870	7375	Business	18500.00
0005435253034	7375	Economy	6200.00
0005432839877	7375	Economy	6200.00
0005434459372	7375	Economy	6200.00
0005435253090	7375	Economy	6200.00
0005434459377	7375	Economy	6200.00
0005432839874	7375	Economy	6200.00
0005434665003	7375	Economy	6200.00
0005432841069	7375	Economy	6200.00
0005434459374	7375	Economy	6800.00
0005434459383	7375	Economy	6800.00
0005434459370	7375	Economy	6800.00
0005432839872	7375	Economy	6200.00
0005434459371	7375	Economy	6200.00
0005432839885	7375	Economy	6200.00
0005434665004	7375	Economy	6200.00
0005435253078	7375	Economy	6200.00
0005432839886	7375	Economy	6200.00
0005434459380	7375	Economy	6200.00
0005432839881	7375	Economy	6200.00
0005434459379	7375	Economy	6200.00
0005435252997	7375	Economy	6200.00
0005435253018	7375	Economy	6200.00
0005432839890	7375	Economy	6200.00
0005432839888	7375	Economy	6200.00
0005435253045	7375	Economy	6200.00
0005435253049	7375	Economy	6200.00
0005434459373	7375	Economy	6200.00
0005435491474	7375	Economy	6200.00
0005432839878	7375	Economy	6200.00
0005435253036	7375	Economy	6200.00
0005432839887	7375	Economy	6200.00
0005435253035	7375	Economy	6200.00
0005434459378	7375	Economy	6200.00
0005434459376	7375	Economy	6200.00
0005432073485	7375	Economy	6200.00
0005432839883	7375	Economy	6200.00
0005434459381	7375	Economy	6200.00
0005432839876	7375	Economy	6200.00
0005435253047	7375	Economy	6200.00
0005434664988	7375	Economy	6200.00
0005434459384	7375	Economy	6200.00
0005435491473	7375	Economy	6200.00
0005435253104	7375	Economy	6200.00
0005435253067	7375	Economy	6200.00
0005434459375	7375	Economy	6200.00
0005434459369	7375	Economy	6200.00
0005434459368	7375	Economy	6200.00
0005435252903	7375	Economy	6200.00
0005435253103	7375	Economy	6200.00
0005435253048	7375	Economy	6200.00
0005435253079	7375	Economy	6200.00
0005432839882	7375	Economy	6200.00
0005432839871	7375	Economy	6200.00
0005432839875	7375	Economy	6200.00
0005434664987	7375	Economy	6200.00
0005435252953	7375	Economy	6200.00
0005432839879	7375	Economy	6200.00
0005432823504	7375	Economy	6200.00
0005432839873	7375	Economy	6200.00
0005432839889	7375	Economy	6200.00
0005432823503	7375	Economy	6200.00
0005435491479	7375	Economy	6200.00
0005435253183	28945	Business	18500.00
0005432839662	28945	Business	18500.00
0005432839559	28945	Business	18500.00
0005432839716	28945	Business	18500.00
0005432839713	28945	Business	18500.00
0005434459192	28945	Business	18500.00
0005432839570	28945	Business	18500.00
0005435253187	28945	Business	18500.00
0005432839572	28945	Business	18500.00
0005434459196	28945	Business	18500.00
0005432001079	28945	Business	18500.00
0005435253190	28945	Business	18500.00
0005434459210	28945	Economy	6200.00
0005432839684	28945	Economy	6200.00
0005432839555	28945	Economy	6200.00
0005435253197	28945	Economy	6200.00
0005432839601	28945	Economy	6200.00
0005432001078	28945	Economy	6200.00
0005434459100	28945	Economy	6200.00
0005432839668	28945	Economy	6800.00
0005432839725	28945	Economy	6800.00
0005435253196	28945	Economy	6800.00
0005432839585	28945	Economy	6800.00
0005434459232	28945	Economy	6200.00
0005432841047	28945	Economy	6200.00
0005434459165	28945	Economy	6200.00
0005432841042	28945	Economy	6200.00
0005432839576	28945	Economy	6200.00
0005435491502	28945	Economy	6200.00
0005432839560	28945	Economy	6200.00
0005432839711	28945	Economy	6200.00
0005432839671	28945	Economy	6200.00
0005432839669	28945	Economy	6200.00
0005434459130	28945	Economy	6200.00
0005434459131	28945	Economy	6200.00
0005432839644	28945	Economy	6200.00
0005434665022	28945	Economy	6200.00
0005435253192	28945	Economy	6200.00
0005435253182	28945	Economy	6200.00
0005432839646	28945	Economy	6200.00
0005432001076	28945	Economy	6200.00
0005435253185	28945	Economy	6200.00
0005432839764	28945	Economy	6200.00
0005434459159	28945	Economy	6200.00
0005435253186	28945	Economy	6200.00
0005434459177	28945	Economy	6200.00
0005435253184	28945	Economy	6200.00
0005432839593	28945	Economy	6200.00
0005434459227	28945	Economy	6200.00
0005432839632	28945	Economy	6200.00
0005432839592	28945	Economy	6200.00
0005432839608	28945	Economy	6200.00
0005434459235	28945	Economy	6200.00
0005432839575	28945	Economy	6200.00
0005432839677	28945	Economy	6200.00
0005432001077	28945	Economy	6200.00
0005432823481	28945	Economy	6200.00
0005435253189	28945	Economy	6200.00
0005432839643	28945	Economy	6200.00
0005432839686	28945	Economy	6200.00
0005432839558	28945	Economy	6200.00
0005434459141	28945	Economy	6200.00
0005432839765	28945	Economy	6200.00
0005432839703	28945	Economy	6200.00
0005435253191	28945	Economy	6200.00
0005435253188	28945	Economy	6200.00
0005434459195	28945	Economy	6200.00
0005435253194	28945	Economy	6200.00
0005435253193	28945	Economy	6200.00
0005432839723	28945	Economy	6200.00
0005434459158	28945	Economy	6200.00
0005432839670	28945	Economy	6200.00
0005434459189	28945	Economy	6200.00
0005432839571	28945	Economy	6200.00
0005434459166	28945	Economy	6200.00
0005434459101	28945	Economy	6200.00
0005432839648	28945	Economy	6200.00
0005432839620	28945	Economy	6200.00
0005434459140	28945	Economy	6200.00
0005432839607	28945	Economy	6200.00
0005432839714	28945	Economy	6200.00
0005432839554	28945	Economy	6200.00
0005434459188	28945	Economy	6200.00
0005434459198	28945	Economy	6200.00
0005432839574	28945	Economy	6200.00
0005435253195	28945	Economy	6200.00
0005432839715	28945	Economy	6200.00
0005432839564	28945	Economy	6200.00
0005432823485	28945	Economy	6200.00
0005434459199	28945	Economy	6200.00
0005435990819	8803	Business	145300.00
0005434276170	8803	Business	145300.00
0005435990818	8803	Economy	48400.00
0005435990820	8803	Economy	48400.00
0005435990817	8803	Economy	48400.00
0005434276142	8803	Economy	48400.00
0005435990759	15714	Business	145300.00
0005435990743	15714	Economy	48400.00
0005434276188	15714	Economy	53300.00
0005435990786	15714	Economy	48400.00
0005435990733	15714	Economy	48400.00
0005434276184	15714	Economy	48400.00
0005434276186	15714	Economy	48400.00
0005435990732	15714	Economy	48400.00
0005434276185	15714	Economy	48400.00
0005434276183	15714	Economy	48400.00
0005435990787	15714	Economy	48400.00
0005435990788	15714	Economy	48400.00
0005435990768	15714	Economy	48400.00
0005434276187	15714	Economy	48400.00
0005435990762	15714	Economy	48400.00
0005434276182	15714	Economy	48400.00
0005435990758	15714	Economy	48400.00
0005435990767	15714	Economy	48400.00
0005433468573	2090	Economy	13300.00
0005433468581	2090	Economy	13300.00
0005433468583	2090	Economy	12100.00
0005432909343	2090	Economy	12100.00
0005432909344	2090	Economy	12100.00
0005433468584	2090	Economy	12100.00
0005433468577	2090	Economy	12100.00
0005433468580	2090	Economy	12100.00
0005432909397	2090	Economy	12100.00
0005433468576	2090	Economy	12100.00
0005433468572	2090	Economy	12100.00
0005433468578	2090	Economy	12100.00
0005433468582	2090	Economy	12100.00
0005433468575	2090	Economy	12100.00
0005433468585	2090	Economy	12100.00
0005432909401	2090	Economy	12100.00
0005432909373	2090	Economy	12100.00
0005432909367	2090	Economy	12100.00
0005433468574	2090	Economy	12100.00
0005433468579	2090	Economy	12100.00
0005433468571	2090	Economy	12100.00
0005433468586	2090	Economy	12100.00
0005433468475	23836	Economy	13300.00
0005433468466	23836	Economy	13300.00
0005432909423	23836	Economy	13300.00
0005433468476	23836	Economy	13300.00
0005433468501	23836	Economy	12100.00
0005432909420	23836	Economy	12100.00
0005432909431	23836	Economy	12100.00
0005433468492	23836	Economy	12100.00
0005433468486	23836	Economy	12100.00
0005433468498	23836	Economy	12100.00
0005433468482	23836	Economy	12100.00
0005433468515	23836	Economy	12100.00
0005433468502	23836	Economy	12100.00
0005433468471	23836	Economy	12100.00
0005432909424	23836	Economy	12100.00
0005432909427	23836	Economy	12100.00
0005432909428	23836	Economy	12100.00
0005433468480	23836	Economy	12100.00
0005432909425	23836	Economy	12100.00
0005433468497	23836	Economy	12100.00
0005432909422	23836	Economy	12100.00
0005432909426	23836	Economy	12100.00
0005432909421	23836	Economy	12100.00
0005433468517	23836	Economy	12100.00
0005433468483	23836	Economy	12100.00
0005433468499	23836	Economy	12100.00
0005433468524	23836	Economy	12100.00
0005433468525	23836	Economy	12100.00
0005433468426	23836	Economy	12100.00
0005433468488	23836	Economy	12100.00
0005432909430	23836	Economy	12100.00
0005433468484	23836	Economy	12100.00
0005433468470	23836	Economy	12100.00
0005432909429	23836	Economy	12100.00
0005433468449	23836	Economy	12100.00
0005433468496	23836	Economy	12100.00
0005433468427	23836	Economy	12100.00
0005433468495	23836	Economy	12100.00
0005434149928	6369	Business	36600.00
0005432363506	6369	Business	36600.00
0005434149962	6369	Business	36600.00
0005434149966	6369	Business	36600.00
0005432361661	6369	Business	36600.00
0005435177575	6369	Business	36600.00
0005432336364	6369	Business	36600.00
0005432062378	6369	Business	36600.00
0005435177553	6369	Business	36600.00
0005435177695	6369	Business	36600.00
0005432361665	6369	Economy	12200.00
0005432361662	6369	Economy	12200.00
0005432361685	6369	Economy	12200.00
0005432361652	6369	Economy	12200.00
0005432361670	6369	Economy	12200.00
0005432361655	6369	Economy	12200.00
0005435490316	6369	Economy	12200.00
0005432361657	6369	Economy	12200.00
0005432062376	6369	Economy	12200.00
0005432363505	6369	Economy	12200.00
0005432361684	6369	Economy	12200.00
0005432336367	6369	Economy	12200.00
0005432062377	6369	Economy	12200.00
0005432361682	6369	Economy	12200.00
0005435177565	6369	Economy	12200.00
0005435177557	6369	Economy	12200.00
0005432361681	6369	Economy	12200.00
0005435177742	6369	Economy	12200.00
0005435177601	6369	Economy	12200.00
0005434149952	6369	Economy	12200.00
0005434149951	6369	Economy	12200.00
0005432361676	6369	Economy	12200.00
0005435490283	6369	Economy	12200.00
0005432361654	6369	Economy	12200.00
0005432361649	6369	Economy	12200.00
0005435177563	6369	Economy	12200.00
0005435177677	6369	Economy	12200.00
0005432361672	6369	Economy	12200.00
0005432361653	6369	Economy	12200.00
0005432361667	6369	Economy	13400.00
0005432363507	6369	Economy	13400.00
0005432336362	6369	Economy	13400.00
0005432062375	6369	Economy	13400.00
0005432336366	6369	Economy	12200.00
0005435723075	6369	Economy	13400.00
0005432361651	6369	Economy	12200.00
0005432361656	6369	Economy	12200.00
0005434149929	6369	Economy	12200.00
0005432361675	6369	Economy	12200.00
0005435177494	6369	Economy	12200.00
0005432361663	6369	Economy	12200.00
0005432361660	6369	Economy	12200.00
0005432062374	6369	Economy	12200.00
0005434149920	6369	Economy	12200.00
0005434149967	6369	Economy	12200.00
0005432361669	6369	Economy	12200.00
0005432361679	6369	Economy	12200.00
0005432361674	6369	Economy	12200.00
0005435177603	6369	Economy	12200.00
0005432336368	6369	Economy	12200.00
0005432361668	6369	Economy	12200.00
0005432336359	6369	Economy	12200.00
0005435177624	6369	Economy	12200.00
0005435177623	6369	Economy	12200.00
0005435177556	6369	Economy	12200.00
0005432361680	6369	Economy	12200.00
0005432336360	6369	Economy	12200.00
0005434150008	6369	Economy	12200.00
0005432361664	6369	Economy	12200.00
0005435177635	6369	Economy	12200.00
0005432336363	6369	Economy	12200.00
0005432363508	6369	Economy	12200.00
0005432361650	6369	Economy	12200.00
0005432336361	6369	Economy	12200.00
0005432361678	6369	Economy	12200.00
0005432361677	6369	Economy	12200.00
0005432361673	6369	Economy	12200.00
0005435177602	6369	Economy	12200.00
0005435490315	6369	Economy	12200.00
0005432336358	6369	Economy	12200.00
0005432361666	6369	Economy	12200.00
0005432361658	6369	Economy	12200.00
0005432336365	6369	Economy	12200.00
0005434149993	6369	Economy	12200.00
0005435177659	6369	Economy	12200.00
0005435177741	6369	Economy	12200.00
0005432361683	6369	Economy	12200.00
0005435177595	6369	Economy	12200.00
0005435177634	6369	Economy	12200.00
0005432361659	6369	Economy	12200.00
0005434149961	6369	Economy	12200.00
0005432361671	6369	Economy	12200.00
0005432361176	20985	Business	36600.00
0005432336330	20985	Business	36600.00
0005432336202	20985	Business	36600.00
0005432361363	20985	Business	36600.00
0005435177828	20985	Business	36600.00
0005434150055	20985	Business	36600.00
0005432336250	20985	Business	36600.00
0005432361252	20985	Business	36600.00
0005434150050	20985	Business	36600.00
0005432336265	20985	Business	36600.00
0005432361302	20985	Economy	12200.00
0005432361303	20985	Economy	12200.00
0005432336204	20985	Economy	12200.00
0005434150057	20985	Economy	12200.00
0005435490331	20985	Economy	12200.00
0005435177824	20985	Economy	12200.00
0005432361085	20985	Economy	12200.00
0005432336259	20985	Economy	12200.00
0005435177812	20985	Economy	12200.00
0005432361389	20985	Economy	12200.00
0005432336224	20985	Economy	12200.00
0005435177820	20985	Economy	12200.00
0005432052828	20985	Economy	12200.00
0005432361132	20985	Economy	12200.00
0005435177818	20985	Economy	12200.00
0005432361284	20985	Economy	12200.00
0005432361147	20985	Economy	12200.00
0005432361089	20985	Economy	12200.00
0005432361269	20985	Economy	12200.00
0005435177823	20985	Economy	12200.00
0005435723099	20985	Economy	12200.00
0005435177815	20985	Economy	12200.00
0005432361416	20985	Economy	12200.00
0005434150051	20985	Economy	12200.00
0005432336219	20985	Economy	12200.00
0005432361350	20985	Economy	12200.00
0005435177822	20985	Economy	12200.00
0005432361381	20985	Economy	12200.00
0005432361405	20985	Economy	12200.00
0005435177811	20985	Economy	12200.00
0005435177810	20985	Economy	12200.00
0005432336277	20985	Economy	13400.00
0005432336249	20985	Economy	13400.00
0005435177809	20985	Economy	13400.00
0005435177821	20985	Economy	13400.00
0005432361133	20985	Economy	13400.00
0005432361366	20985	Economy	13400.00
0005432052830	20985	Economy	12200.00
0005432361299	20985	Economy	12200.00
0005432361092	20985	Economy	12200.00
0005432361300	20985	Economy	12200.00
0005432363491	20985	Economy	12200.00
0005432361263	20985	Economy	12200.00
0005432361367	20985	Economy	12200.00
0005432336220	20985	Economy	12200.00
0005432336283	20985	Economy	12200.00
0005435177827	20985	Economy	12200.00
0005432363482	20985	Economy	12200.00
0005432361294	20985	Economy	12200.00
0005434150058	20985	Economy	12200.00
0005435177814	20985	Economy	12200.00
0005432052829	20985	Economy	12200.00
0005435177817	20985	Economy	12200.00
0005435177819	20985	Economy	12200.00
0005432336267	20985	Economy	12200.00
0005432361192	20985	Economy	12200.00
0005432361321	20985	Economy	12200.00
0005434150053	20985	Economy	12200.00
0005435723100	20985	Economy	12200.00
0005432361181	20985	Economy	12200.00
0005435177829	20985	Economy	12200.00
0005435177816	20985	Economy	12200.00
0005434150052	20985	Economy	12200.00
0005435177826	20985	Economy	12200.00
0005432361320	20985	Economy	12200.00
0005432361247	20985	Economy	12200.00
0005432361193	20985	Economy	12200.00
0005434150056	20985	Economy	12200.00
0005432361093	20985	Economy	12200.00
0005435177813	20985	Economy	12200.00
0005432361283	20985	Economy	12200.00
0005432361030	20985	Economy	12200.00
0005432336289	20985	Economy	12200.00
0005435490330	20985	Economy	12200.00
0005432361319	20985	Economy	12200.00
0005432361180	20985	Economy	12200.00
0005435723101	20985	Economy	12200.00
0005432361351	20985	Economy	12200.00
0005435177825	20985	Economy	12200.00
0005432336308	20985	Economy	12200.00
0005434150059	20985	Economy	12200.00
0005432361029	20985	Economy	12200.00
0005432361227	20985	Economy	12200.00
0005434150054	20985	Economy	12200.00
0005432361330	20985	Economy	12200.00
0005432361134	20985	Economy	12200.00
0005434448393	17709	Economy	3400.00
0005434459145	17709	Economy	3100.00
0005434459239	17709	Economy	3100.00
0005434459274	17709	Economy	3100.00
0005434459255	17709	Economy	3100.00
0005434463977	17709	Economy	3100.00
0005434459194	17709	Economy	3100.00
0005434463963	17709	Economy	3100.00
0005434459240	17709	Economy	3100.00
0005434459193	17709	Economy	3100.00
0005434459275	17709	Economy	3100.00
0005434448387	17709	Economy	3100.00
0005434463979	17709	Economy	3100.00
0005434459204	17709	Economy	3100.00
0005434459221	17709	Economy	3100.00
0005434463978	17709	Economy	3100.00
0005434459218	17709	Economy	3100.00
0005434463969	17709	Economy	3100.00
0005434463964	17709	Economy	3100.00
0005434459216	17709	Economy	3100.00
0005434459217	17709	Economy	3100.00
0005434459203	17709	Economy	3100.00
0005434463968	17709	Economy	3100.00
0005434459219	17709	Economy	3100.00
0005434186279	17709	Economy	3100.00
0005434459233	17709	Economy	3100.00
0005434186280	17709	Economy	3100.00
0005434459176	17709	Economy	3100.00
0005434459259	17709	Economy	3100.00
0005434459132	17709	Economy	3100.00
0005434459369	29128	Economy	3400.00
0005434459377	29128	Economy	3400.00
0005434186261	29128	Economy	3400.00
0005434448406	29128	Economy	3100.00
0005434459374	29128	Economy	3100.00
0005434462847	29128	Economy	3100.00
0005434448407	29128	Economy	3100.00
0005434459380	29128	Economy	3100.00
0005434186245	29128	Economy	3100.00
0005434459372	29128	Economy	3100.00
0005434186247	29128	Economy	3100.00
0005434459383	29128	Economy	3100.00
0005434186243	29128	Economy	3100.00
0005434459384	29128	Economy	3100.00
0005434186246	29128	Economy	3100.00
0005434459376	29128	Economy	3100.00
0005434459379	29128	Economy	3100.00
0005434462848	29128	Economy	3100.00
0005434463987	29128	Economy	3100.00
0005434459373	29128	Economy	3100.00
0005434459371	29128	Economy	3100.00
0005434459378	29128	Economy	3100.00
0005434459370	29128	Economy	3100.00
0005434463986	29128	Economy	3100.00
0005434459385	29128	Economy	3100.00
0005434459381	29128	Economy	3100.00
0005434459375	29128	Economy	3100.00
0005434448408	29128	Economy	3100.00
0005434459368	29128	Economy	3100.00
0005434463988	29128	Economy	3100.00
0005434186241	29128	Economy	3100.00
0005434459382	29128	Economy	3100.00
0005432605381	21465	Economy	7300.00
0005432605374	21465	Economy	7300.00
0005432605382	21465	Economy	6600.00
0005432605401	21465	Economy	6600.00
0005432605399	21465	Economy	6600.00
0005432605383	21465	Economy	6600.00
0005432605394	21465	Economy	6600.00
0005432605376	21465	Economy	6600.00
0005432605387	21465	Economy	6600.00
0005435221547	21465	Economy	6600.00
0005432605400	21465	Economy	6600.00
0005432605390	21465	Economy	6600.00
0005432605402	21465	Economy	6600.00
0005432605395	21465	Economy	6600.00
0005432605393	21465	Economy	6600.00
0005432605389	21465	Economy	6600.00
0005432605392	21465	Economy	6600.00
0005432605386	21465	Economy	6600.00
0005432605398	21465	Economy	6600.00
0005432605375	21465	Economy	6600.00
0005432605380	21465	Economy	6600.00
0005432605391	21465	Economy	6600.00
0005432605377	21465	Economy	6600.00
0005432605385	21465	Economy	6600.00
0005432605388	21465	Economy	6600.00
0005432605396	21465	Economy	6600.00
0005432605397	21465	Economy	6600.00
0005432605378	21465	Economy	6600.00
0005432605384	21465	Economy	6600.00
0005432605379	21465	Economy	6600.00
0005432604780	31700	Economy	7300.00
0005432605028	31700	Economy	7300.00
0005432604948	31700	Economy	7300.00
0005432605025	31700	Economy	6600.00
0005432605216	31700	Economy	6600.00
0005432605105	31700	Economy	6600.00
0005432605235	31700	Economy	6600.00
0005432605003	31700	Economy	6600.00
0005432605150	31700	Economy	6600.00
0005432605059	31700	Economy	6600.00
0005432605103	31700	Economy	6600.00
0005432605171	31700	Economy	6600.00
0005432605234	31700	Economy	6600.00
0005432604994	31700	Economy	6600.00
0005432605106	31700	Economy	6600.00
0005432605098	31700	Economy	6600.00
0005432605041	31700	Economy	6600.00
0005432605044	31700	Economy	6600.00
0005432604973	31700	Economy	6600.00
0005432605104	31700	Economy	6600.00
0005432604962	31700	Economy	6600.00
0005432604957	31700	Economy	6600.00
0005432605149	31700	Economy	6600.00
0005432605126	31700	Economy	6600.00
0005432604978	31700	Economy	6600.00
0005432605151	31700	Economy	6600.00
0005432605008	31700	Economy	6600.00
0005432605099	31700	Economy	6600.00
0005432605002	31700	Economy	6600.00
0005432605086	31700	Economy	6600.00
0005432604861	31700	Economy	6600.00
0005432605125	31700	Economy	6600.00
0005432605203	31700	Economy	6600.00
0005432605108	31700	Economy	6600.00
0005432604993	31700	Economy	6600.00
0005432605033	31700	Economy	6600.00
0005432605157	31700	Economy	6600.00
0005432604995	31700	Economy	6600.00
0005432604996	31700	Economy	6600.00
0005432605233	31700	Economy	6600.00
0005432604860	31700	Economy	6600.00
0005435154623	29600	Economy	19500.00
0005433293422	29600	Economy	19500.00
0005435154628	29600	Economy	17800.00
0005435154630	29600	Economy	17800.00
0005435154626	29600	Economy	17800.00
0005433293426	29600	Economy	17800.00
0005433293425	29600	Economy	17800.00
0005433293430	29600	Economy	17800.00
0005433293420	29600	Economy	17800.00
0005433293428	29600	Economy	17800.00
0005433293427	29600	Economy	17800.00
0005433293424	29600	Economy	17800.00
0005435154627	29600	Economy	17800.00
0005433293429	29600	Economy	17800.00
0005435154625	29600	Economy	17800.00
0005433293423	29600	Economy	17800.00
0005433293419	29600	Economy	17800.00
0005433293431	29600	Economy	17800.00
0005433293421	29600	Economy	17800.00
0005433473514	6673	Economy	14000.00
0005433473520	6673	Economy	14000.00
0005433473511	6673	Economy	14000.00
0005433473521	6673	Economy	12700.00
0005435257339	6673	Economy	12700.00
0005433473522	6673	Economy	12700.00
0005435257331	6673	Economy	12700.00
0005435257305	6673	Economy	12700.00
0005433473510	6673	Economy	12700.00
0005433473517	6673	Economy	12700.00
0005433473512	6673	Economy	12700.00
0005435257341	6673	Economy	12700.00
0005433473519	6673	Economy	12700.00
0005433473513	6673	Economy	12700.00
0005433473523	6673	Economy	12700.00
0005433473508	6673	Economy	12700.00
0005433473515	6673	Economy	12700.00
0005435257340	6673	Economy	12700.00
0005433473516	6673	Economy	12700.00
0005433473509	6673	Economy	12700.00
0005433473518	6673	Economy	12700.00
0005435257371	23903	Economy	14000.00
0005433473438	23903	Economy	14000.00
0005433473436	23903	Economy	14000.00
0005435257375	23903	Economy	14000.00
0005433473419	23903	Economy	12700.00
0005433473445	23903	Economy	12700.00
0005433473461	23903	Economy	12700.00
0005435257372	23903	Economy	12700.00
0005433473399	23903	Economy	12700.00
0005433473429	23903	Economy	12700.00
0005433473480	23903	Economy	12700.00
0005433473440	23903	Economy	12700.00
0005435257369	23903	Economy	12700.00
0005433473415	23903	Economy	12700.00
0005433473451	23903	Economy	12700.00
0005433473410	23903	Economy	12700.00
0005433473432	23903	Economy	12700.00
0005433473447	23903	Economy	12700.00
0005433473457	23903	Economy	12700.00
0005433473421	23903	Economy	12700.00
0005433473398	23903	Economy	12700.00
0005435257376	23903	Economy	12700.00
0005433473409	23903	Economy	12700.00
0005435257368	23903	Economy	12700.00
0005433473441	23903	Economy	12700.00
0005433473427	23903	Economy	12700.00
0005433473354	23903	Economy	12700.00
0005433473443	23903	Economy	12700.00
0005435257374	23903	Economy	12700.00
0005433473363	23903	Economy	12700.00
0005433473417	23903	Economy	12700.00
0005433473448	23903	Economy	12700.00
0005433473456	23903	Economy	12700.00
0005433473460	23903	Economy	12700.00
0005433473428	23903	Economy	12700.00
0005435257367	23903	Economy	12700.00
0005433473420	23903	Economy	12700.00
0005433473442	23903	Economy	12700.00
0005435257370	23903	Economy	12700.00
0005433473446	23903	Economy	12700.00
0005435257373	23903	Economy	12700.00
0005433473430	23903	Economy	12700.00
0005433473449	23903	Economy	12700.00
0005433473466	23903	Economy	12700.00
0005433473464	23903	Economy	12700.00
0005433473435	23903	Economy	12700.00
0005433473439	23903	Economy	12700.00
0005433473418	23903	Economy	12700.00
0005433473465	23903	Economy	12700.00
0005435904910	18826	Economy	6600.00
0005435904911	18826	Economy	6600.00
0005434606891	18826	Economy	6600.00
0005434606890	18826	Economy	6600.00
0005435904724	18826	Economy	6600.00
0005435904725	18826	Economy	6600.00
0005434606889	18826	Economy	6600.00
0005435904912	18826	Economy	6600.00
0005434606923	22319	Economy	6600.00
0005434606924	22319	Economy	6600.00
0005435904905	22319	Economy	6600.00
0005434604998	22319	Economy	6600.00
0005434604999	22319	Economy	6600.00
0005435904904	22319	Economy	6600.00
0005434606922	22319	Economy	6600.00
0005434604997	22319	Economy	6600.00
0005434604996	22319	Economy	6600.00
0005434602971	3854	Economy	24900.00
0005434522546	3854	Economy	22600.00
0005434522545	3854	Economy	22600.00
0005434602969	3854	Economy	22600.00
0005434522548	3854	Economy	22600.00
0005434522542	3854	Economy	22600.00
0005434602974	3854	Economy	22600.00
0005435904446	3854	Economy	22600.00
0005434522550	3854	Economy	22600.00
0005434602972	3854	Economy	22600.00
0005435904449	3854	Economy	22600.00
0005434602968	3854	Economy	22600.00
0005434602970	3854	Economy	22600.00
0005434522549	3854	Economy	22600.00
0005435904433	3854	Economy	22600.00
0005434522547	3854	Economy	22600.00
0005434522541	3854	Economy	22600.00
0005434602973	3854	Economy	22600.00
0005435904434	3854	Economy	22600.00
0005435904450	3854	Economy	22600.00
0005434522544	3854	Economy	22600.00
0005434522543	3854	Economy	22600.00
0005434522528	19049	Economy	24900.00
0005434602941	19049	Economy	24900.00
0005434604957	19049	Economy	24900.00
0005434602940	19049	Economy	24900.00
0005434522509	19049	Economy	22600.00
0005435904473	19049	Economy	22600.00
0005434604948	19049	Economy	22600.00
0005434522531	19049	Economy	22600.00
0005434602942	19049	Economy	22600.00
0005434602935	19049	Economy	22600.00
0005434604939	19049	Economy	22600.00
0005434604956	19049	Economy	22600.00
0005434522526	19049	Economy	22600.00
0005434522518	19049	Economy	22600.00
0005435904469	19049	Economy	22600.00
0005435904472	19049	Economy	22600.00
0005434522489	19049	Economy	22600.00
0005435904470	19049	Economy	22600.00
0005434604950	19049	Economy	22600.00
0005434602948	19049	Economy	22600.00
0005434604958	19049	Economy	22600.00
0005434522530	19049	Economy	22600.00
0005434602956	19049	Economy	22600.00
0005434522500	19049	Economy	22600.00
0005434604963	19049	Economy	22600.00
0005434522516	19049	Economy	22600.00
0005434522513	19049	Economy	22600.00
0005434604961	19049	Economy	22600.00
0005434604967	19049	Economy	22600.00
0005434604959	19049	Economy	22600.00
0005434522499	19049	Economy	22600.00
0005434602943	19049	Economy	22600.00
0005434602934	19049	Economy	22600.00
0005434604955	19049	Economy	22600.00
0005435904471	19049	Economy	22600.00
0005434604953	19049	Economy	22600.00
0005434522521	19049	Economy	22600.00
0005435904474	19049	Economy	22600.00
0005434522519	19049	Economy	22600.00
0005434602947	19049	Economy	22600.00
0005434522522	19049	Economy	22600.00
0005434604960	19049	Economy	22600.00
0005434604954	19049	Economy	22600.00
0005434522495	19049	Economy	22600.00
0005434522524	19049	Economy	22600.00
0005434522508	19049	Economy	22600.00
0005434604947	19049	Economy	22600.00
0005432751615	401	Business	44500.00
0005433875407	401	Business	44500.00
0005432748604	401	Business	44500.00
0005432891343	401	Business	44500.00
0005432751617	401	Business	44500.00
0005432748606	401	Business	44500.00
0005435154688	401	Business	44500.00
0005432748600	401	Economy	14800.00
0005432751614	401	Economy	14800.00
0005435154690	401	Economy	14800.00
0005432891344	401	Economy	14800.00
0005432753389	401	Economy	14800.00
0005432220119	401	Economy	14800.00
0005432748587	401	Economy	16300.00
0005432748592	401	Economy	16300.00
0005432748597	401	Economy	14800.00
0005432753391	401	Economy	14800.00
0005435154687	401	Economy	14800.00
0005433875397	401	Economy	14800.00
0005432751616	401	Economy	14800.00
0005433875406	401	Economy	14800.00
0005433293339	401	Economy	14800.00
0005432748588	401	Economy	14800.00
0005433875405	401	Economy	14800.00
0005432748603	401	Economy	14800.00
0005432748601	401	Economy	14800.00
0005435627130	401	Economy	14800.00
0005432753390	401	Economy	14800.00
0005435154689	401	Economy	14800.00
0005432748599	401	Economy	14800.00
0005433293358	401	Economy	14800.00
0005432748594	401	Economy	14800.00
0005433293340	401	Economy	14800.00
0005432891459	401	Economy	14800.00
0005432748605	401	Economy	14800.00
0005432749842	401	Economy	14800.00
0005432748591	401	Economy	14800.00
0005432748589	401	Economy	14800.00
0005432748598	401	Economy	14800.00
0005432891307	401	Economy	14800.00
0005432220120	401	Economy	14800.00
0005432220121	401	Economy	14800.00
0005433293357	401	Economy	14800.00
0005433293337	401	Economy	14800.00
0005433293364	401	Economy	14800.00
0005432220122	401	Economy	14800.00
0005432748602	401	Economy	14800.00
0005432748586	401	Economy	14800.00
0005432748608	401	Economy	14800.00
0005432748595	401	Economy	14800.00
0005432748607	401	Economy	14800.00
0005432753392	401	Economy	14800.00
0005432748596	401	Economy	14800.00
0005432749843	401	Economy	14800.00
0005432891403	401	Economy	14800.00
0005432748590	401	Economy	14800.00
0005432748593	401	Economy	14800.00
0005434152865	12039	Business	44500.00
0005432748117	12039	Business	44500.00
0005432748477	12039	Business	44500.00
0005432891553	12039	Business	44500.00
0005432748324	12039	Business	44500.00
0005432753360	12039	Business	44500.00
0005432891558	12039	Business	44500.00
0005434153580	12039	Business	44500.00
0005432748462	12039	Business	44500.00
0005432748231	12039	Business	44500.00
0005432748391	12039	Business	44500.00
0005432748409	12039	Business	44500.00
0005432748328	12039	Economy	14800.00
0005432748291	12039	Economy	14800.00
0005432748368	12039	Economy	14800.00
0005432891554	12039	Economy	14800.00
0005432748364	12039	Economy	14800.00
0005432748410	12039	Economy	14800.00
0005432748264	12039	Economy	14800.00
0005434152866	12039	Economy	14800.00
0005432214864	12039	Economy	14800.00
0005432749827	12039	Economy	16300.00
0005432891551	12039	Economy	16300.00
0005432748263	12039	Economy	16300.00
0005432748182	12039	Economy	16300.00
0005432753361	12039	Economy	16300.00
0005432891555	12039	Economy	14800.00
0005432753363	12039	Economy	14800.00
0005432748230	12039	Economy	14800.00
0005432891550	12039	Economy	14800.00
0005432748322	12039	Economy	14800.00
0005432748365	12039	Economy	14800.00
0005432748310	12039	Economy	14800.00
0005432748457	12039	Economy	14800.00
0005432891549	12039	Economy	14800.00
0005432748501	12039	Economy	14800.00
0005432748359	12039	Economy	14800.00
0005432748305	12039	Economy	14800.00
0005432891556	12039	Economy	14800.00
0005432748367	12039	Economy	14800.00
0005432748458	12039	Economy	14800.00
0005432891552	12039	Economy	14800.00
0005432748183	12039	Economy	14800.00
0005432748221	12039	Economy	14800.00
0005432748446	12039	Economy	14800.00
0005432748260	12039	Economy	14800.00
0005432748212	12039	Economy	14800.00
0005432748333	12039	Economy	14800.00
0005432748476	12039	Economy	14800.00
0005432748349	12039	Economy	14800.00
0005434153579	12039	Economy	14800.00
0005432748130	12039	Economy	14800.00
0005432891557	12039	Economy	14800.00
0005432748211	12039	Economy	14800.00
0005432748210	12039	Economy	14800.00
0005432748261	12039	Economy	14800.00
0005432748466	12039	Economy	14800.00
0005432748219	12039	Economy	14800.00
0005432748129	12039	Economy	14800.00
0005432748241	12039	Economy	14800.00
0005435627125	12039	Economy	14800.00
0005432214863	12039	Economy	14800.00
0005432748220	12039	Economy	14800.00
0005432748256	12039	Economy	14800.00
0005432748287	12039	Economy	14800.00
0005432748280	12039	Economy	14800.00
0005432891559	12039	Economy	14800.00
0005432748445	12039	Economy	14800.00
0005432756894	12039	Economy	14800.00
0005432748181	12039	Economy	14800.00
0005434153578	12039	Economy	14800.00
0005432748444	12039	Economy	14800.00
0005432748411	12039	Economy	14800.00
0005432748155	12039	Economy	14800.00
0005432748297	12039	Economy	14800.00
0005432756915	12039	Economy	14800.00
0005432748294	12039	Economy	14800.00
0005432891548	12039	Economy	14800.00
0005432748383	12039	Economy	14800.00
0005432748229	12039	Economy	14800.00
0005432748158	12039	Economy	14800.00
0005432748433	12039	Economy	14800.00
0005432748262	12039	Economy	14800.00
0005432748325	12039	Economy	14800.00
0005432214862	12039	Economy	14800.00
0005433533407	18966	Economy	28200.00
0005433533409	18966	Economy	25700.00
0005432928101	18966	Economy	25700.00
0005433525327	18966	Economy	25700.00
0005432928078	18966	Economy	25700.00
0005433525326	18966	Economy	25700.00
0005433533410	18966	Economy	25700.00
0005433525332	18966	Economy	25700.00
0005433533408	18966	Economy	25700.00
0005433531394	18966	Economy	25700.00
0005433525334	18966	Economy	25700.00
0005433531397	18966	Economy	25700.00
0005433525333	18966	Economy	25700.00
0005433525329	18966	Economy	25700.00
0005433525328	18966	Economy	25700.00
0005433531398	18966	Economy	25700.00
0005432928077	18966	Economy	25700.00
0005432928098	18966	Economy	25700.00
0005433525330	18966	Economy	25700.00
0005433531396	18966	Economy	25700.00
0005432928083	18966	Economy	25700.00
0005432928079	18966	Economy	25700.00
0005433531393	18966	Economy	25700.00
0005433531395	18966	Economy	25700.00
0005433525331	18966	Economy	25700.00
0005432928069	18966	Economy	25700.00
0005433531371	32471	Economy	28200.00
0005433525244	32471	Economy	28200.00
0005433527346	32471	Economy	25700.00
0005432928134	32471	Economy	25700.00
0005433531348	32471	Economy	25700.00
0005433531372	32471	Economy	25700.00
0005433527329	32471	Economy	25700.00
0005433531359	32471	Economy	25700.00
0005433527333	32471	Economy	25700.00
0005433527331	32471	Economy	25700.00
0005433527332	32471	Economy	25700.00
0005433531376	32471	Economy	25700.00
0005433527330	32471	Economy	25700.00
0005433531365	32471	Economy	25700.00
0005433531366	32471	Economy	25700.00
0005433531363	32471	Economy	25700.00
0005432928135	32471	Economy	25700.00
0005433531364	32471	Economy	25700.00
0005433531347	32471	Economy	25700.00
0005433525261	32471	Economy	25700.00
0005433527337	32471	Economy	25700.00
0005433525272	32471	Economy	25700.00
0005433527315	32471	Economy	25700.00
0005434826979	5294	Business	84000.00
0005434826976	5294	Business	84000.00
0005435374729	5294	Business	84000.00
0005435179005	5294	Business	84000.00
0005434827062	5294	Business	84000.00
0005435374673	5294	Business	84000.00
0005435374504	5294	Business	84000.00
0005434826978	5294	Business	84000.00
0005435374464	5294	Business	84000.00
0005435374667	5294	Business	84000.00
0005435374431	5294	Business	84000.00
0005434827050	5294	Business	84000.00
0005434827053	5294	Business	84000.00
0005434827057	5294	Business	84000.00
0005435374675	5294	Business	84000.00
0005434826981	5294	Business	84000.00
0005434827024	5294	Business	84000.00
0005432121722	5294	Business	84000.00
0005434826989	5294	Business	84000.00
0005434827028	5294	Business	84000.00
0005432121721	5294	Business	84000.00
0005432823487	5294	Comfort	47600.00
0005434827032	5294	Comfort	47600.00
0005434827031	5294	Comfort	47600.00
0005435374711	5294	Comfort	47600.00
0005435374583	5294	Comfort	47600.00
0005434827001	5294	Comfort	47600.00
0005434827045	5294	Comfort	47600.00
0005434827039	5294	Comfort	47600.00
0005434827013	5294	Comfort	47600.00
0005434826985	5294	Comfort	47600.00
0005434826987	5294	Comfort	47600.00
0005432823486	5294	Comfort	47600.00
0005432121715	5294	Comfort	47600.00
0005435374413	5294	Comfort	47600.00
0005434827066	5294	Comfort	47600.00
0005432396349	5294	Comfort	47600.00
0005434827065	5294	Comfort	47600.00
0005434826993	5294	Comfort	47600.00
0005435374361	5294	Comfort	47600.00
0005435374621	5294	Comfort	47600.00
0005435374652	5294	Comfort	47600.00
0005435374418	5294	Comfort	47600.00
0005435374597	5294	Comfort	47600.00
0005435374414	5294	Comfort	47600.00
0005435299868	5294	Comfort	47600.00
0005432121720	5294	Comfort	47600.00
0005434558520	5294	Comfort	47600.00
0005435299850	5294	Comfort	47600.00
0005435374416	5294	Comfort	47600.00
0005434827041	5294	Economy	28000.00
0005435150408	5294	Economy	28000.00
0005434827063	5294	Economy	28000.00
0005434827068	5294	Economy	28000.00
0005434826973	5294	Economy	28000.00
0005434827003	5294	Economy	28000.00
0005435150402	5294	Economy	28000.00
0005434826996	5294	Economy	28000.00
0005434827067	5294	Economy	28000.00
0005435299874	5294	Economy	28000.00
0005434558516	5294	Economy	28000.00
0005435374500	5294	Economy	28000.00
0005435374396	5294	Economy	28000.00
0005435150405	5294	Economy	28000.00
0005434827055	5294	Economy	28000.00
0005435386702	5294	Economy	28000.00
0005434831275	5294	Economy	28000.00
0005435386699	5294	Economy	28000.00
0005435374444	5294	Economy	28000.00
0005435374337	5294	Economy	28000.00
0005434827052	5294	Economy	28000.00
0005434827054	5294	Economy	28000.00
0005435150411	5294	Economy	28000.00
0005434558522	5294	Economy	28000.00
0005434826992	5294	Economy	28000.00
0005434827044	5294	Economy	28000.00
0005434827058	5294	Economy	28000.00
0005434826997	5294	Economy	28000.00
0005434831273	5294	Economy	28000.00
0005434558526	5294	Economy	28000.00
0005435374728	5294	Economy	28000.00
0005434826980	5294	Economy	28000.00
0005434558523	5294	Economy	28000.00
0005435374692	5294	Economy	28000.00
0005435374580	5294	Economy	28000.00
0005435150403	5294	Economy	28000.00
0005432121718	5294	Economy	28000.00
0005434827008	5294	Economy	28000.00
0005435374360	5294	Economy	28000.00
0005434826988	5294	Economy	28000.00
0005434827023	5294	Economy	28000.00
0005434827056	5294	Economy	30800.00
0005435374336	5294	Economy	28000.00
0005434827046	5294	Economy	28000.00
0005432396350	5294	Economy	28000.00
0005434827021	5294	Economy	28000.00
0005435374448	5294	Economy	30800.00
0005432121714	5294	Economy	30800.00
0005434558524	5294	Economy	28000.00
0005435374693	5294	Economy	28000.00
0005434827029	5294	Economy	28000.00
0005434558525	5294	Economy	28000.00
0005434827061	5294	Economy	28000.00
0005434827069	5294	Economy	28000.00
0005434827059	5294	Economy	28000.00
0005434826972	5294	Economy	28000.00
0005434827010	5294	Economy	28000.00
0005434827022	5294	Economy	28000.00
0005434827018	5294	Economy	28000.00
0005434827026	5294	Economy	28000.00
0005435374157	5294	Economy	28000.00
0005435150406	5294	Economy	28000.00
0005434827037	5294	Economy	28000.00
0005434831277	5294	Economy	28000.00
0005435374584	5294	Economy	28000.00
0005434826984	5294	Economy	28000.00
0005434826990	5294	Economy	28000.00
0005434558518	5294	Economy	28000.00
0005434827004	5294	Economy	28000.00
0005435374488	5294	Economy	28000.00
0005435735219	5294	Economy	28000.00
0005435150409	5294	Economy	28000.00
0005435386696	5294	Economy	28000.00
0005435374457	5294	Economy	28000.00
0005434827027	5294	Economy	28000.00
0005434827064	5294	Economy	28000.00
0005435150407	5294	Economy	28000.00
0005434827033	5294	Economy	28000.00
0005432823490	5294	Economy	28000.00
0005432121724	5294	Economy	28000.00
0005435374395	5294	Economy	28000.00
0005435374425	5294	Economy	28000.00
0005434558521	5294	Economy	28000.00
0005435374173	5294	Economy	28000.00
0005432394213	5294	Economy	28000.00
0005434558517	5294	Economy	28000.00
0005434827020	5294	Economy	28000.00
0005435374582	5294	Economy	28000.00
0005434827049	5294	Economy	28000.00
0005432121717	5294	Economy	28000.00
0005434826975	5294	Economy	28000.00
0005432121719	5294	Economy	28000.00
0005435374432	5294	Economy	28000.00
0005434827012	5294	Economy	28000.00
0005435374622	5294	Economy	28000.00
0005435386675	5294	Economy	28000.00
0005434827011	5294	Economy	28000.00
0005435374415	5294	Economy	28000.00
0005435374536	5294	Economy	28000.00
0005434827042	5294	Economy	28000.00
0005435374501	5294	Economy	28000.00
0005434826995	5294	Economy	28000.00
0005435374529	5294	Economy	28000.00
0005434827017	5294	Economy	28000.00
0005434826982	5294	Economy	28000.00
0005435374614	5294	Economy	28000.00
0005434558515	5294	Economy	28000.00
0005434827060	5294	Economy	28000.00
0005434826986	5294	Economy	28000.00
0005435299873	5294	Economy	28000.00
0005435374899	5294	Economy	28000.00
0005434827043	5294	Economy	28000.00
0005434826974	5294	Economy	28000.00
0005435374900	5294	Economy	28000.00
0005434826991	5294	Economy	28000.00
0005435374808	5294	Economy	28000.00
0005435374541	5294	Economy	28000.00
0005434827051	5294	Economy	28000.00
0005435374362	5294	Economy	30800.00
0005434827047	5294	Economy	30800.00
0005434827040	5294	Economy	28000.00
0005435150412	5294	Economy	28000.00
0005435374807	5294	Economy	28000.00
0005434827019	5294	Economy	28000.00
0005435374428	5294	Economy	28000.00
0005435386689	5294	Economy	28000.00
0005434827007	5294	Economy	28000.00
0005435386712	5294	Economy	28000.00
0005435386692	5294	Economy	28000.00
0005434826998	5294	Economy	28000.00
0005434826999	5294	Economy	28000.00
0005434831276	5294	Economy	28000.00
0005435374156	5294	Economy	28000.00
0005434827030	5294	Economy	28000.00
0005432396351	5294	Economy	28000.00
0005435735229	5294	Economy	28000.00
0005435150410	5294	Economy	28000.00
0005435150404	5294	Economy	28000.00
0005434665021	5294	Economy	28000.00
0005434827016	5294	Economy	28000.00
0005432121716	5294	Economy	28000.00
0005435374694	5294	Economy	28000.00
0005434826994	5294	Economy	28000.00
0005432394214	5294	Economy	28000.00
0005435150413	5294	Economy	28000.00
0005434826977	5294	Economy	28000.00
0005435179008	5294	Economy	28000.00
0005432394215	5294	Economy	28000.00
0005434831274	5294	Economy	28000.00
0005434827035	5294	Economy	28000.00
0005435386682	5294	Economy	28000.00
0005432121723	5294	Economy	28000.00
0005435386695	5294	Economy	28000.00
0005435374296	5294	Economy	28000.00
0005434558514	5294	Economy	28000.00
0005434826983	5294	Economy	28000.00
0005434827002	5294	Economy	28000.00
0005435304247	5294	Economy	28000.00
0005435374898	5294	Economy	28000.00
0005434827005	5294	Economy	28000.00
0005435374323	5294	Economy	28000.00
0005434827048	5294	Economy	28000.00
0005434827025	5294	Economy	28000.00
0005434827036	5294	Economy	28000.00
0005434827000	5294	Economy	28000.00
0005434827014	5294	Economy	28000.00
0005435374535	5294	Economy	28000.00
0005435661970	5294	Economy	28000.00
0005435374689	5294	Economy	28000.00
0005434827038	5294	Economy	28000.00
0005435304246	5294	Economy	28000.00
0005435374615	5294	Economy	28000.00
0005435374487	5294	Economy	28000.00
0005434558519	5294	Economy	28000.00
0005435374447	5294	Economy	28000.00
0005434827009	5294	Economy	28000.00
0005434827034	5294	Economy	28000.00
0005435374417	5294	Economy	28000.00
0005434827006	5294	Economy	28000.00
0005435374598	5294	Economy	28000.00
0005434827015	5294	Economy	28000.00
0005435315093	9898	Business	84000.00
0005434825983	9898	Business	84000.00
0005434825551	9898	Business	84000.00
0005435375062	9898	Business	84000.00
0005434826409	9898	Business	84000.00
0005432823505	9898	Business	84000.00
0005435150272	9898	Business	84000.00
0005435150253	9898	Business	84000.00
0005435150271	9898	Business	84000.00
0005434826022	9898	Business	84000.00
0005434825954	9898	Business	84000.00
0005434825593	9898	Business	84000.00
0005434558424	9898	Business	84000.00
0005435150318	9898	Business	84000.00
0005434558412	9898	Business	84000.00
0005435315094	9898	Comfort	47600.00
0005434826178	9898	Business	84000.00
0005435375054	9898	Comfort	47600.00
0005432400182	9898	Comfort	47600.00
0005432203262	9898	Comfort	47600.00
0005434826334	9898	Comfort	47600.00
0005435386746	9898	Comfort	47600.00
0005434825767	9898	Comfort	47600.00
0005434826137	9898	Comfort	47600.00
0005434826167	9898	Comfort	47600.00
0005434825585	9898	Comfort	47600.00
0005434825642	9898	Comfort	47600.00
0005435375059	9898	Comfort	47600.00
0005435302328	9898	Comfort	47600.00
0005434826033	9898	Comfort	47600.00
0005434825878	9898	Comfort	47600.00
0005435375019	9898	Comfort	47600.00
0005435315088	9898	Comfort	47600.00
0005435375050	9898	Comfort	47600.00
0005434826168	9898	Comfort	47600.00
0005434826127	9898	Comfort	47600.00
0005434826522	9898	Comfort	47600.00
0005432823506	9898	Comfort	47600.00
0005435386742	9898	Comfort	47600.00
0005435150296	9898	Comfort	47600.00
0005434825717	9898	Comfort	47600.00
0005434825979	9898	Comfort	47600.00
0005435375042	9898	Comfort	47600.00
0005434825679	9898	Comfort	47600.00
0005434825760	9898	Comfort	47600.00
0005434826034	9898	Comfort	47600.00
0005434825857	9898	Comfort	47600.00
0005434825837	9898	Comfort	47600.00
0005435375064	9898	Economy	28000.00
0005434825763	9898	Comfort	47600.00
0005434825818	9898	Economy	28000.00
0005434825831	9898	Economy	28000.00
0005435375055	9898	Economy	28000.00
0005432400211	9898	Economy	28000.00
0005435375017	9898	Economy	28000.00
0005434826126	9898	Economy	28000.00
0005434825614	9898	Economy	28000.00
0005434826064	9898	Economy	28000.00
0005434825828	9898	Economy	28000.00
0005435386743	9898	Economy	28000.00
0005435375029	9898	Economy	28000.00
0005434825615	9898	Economy	28000.00
0005434826065	9898	Economy	28000.00
0005434826166	9898	Economy	28000.00
0005434826221	9898	Economy	28000.00
0005434826014	9898	Economy	28000.00
0005435375025	9898	Economy	28000.00
0005435150254	9898	Economy	28000.00
0005435386744	9898	Economy	28000.00
0005432400212	9898	Economy	28000.00
0005435315091	9898	Economy	28000.00
0005434825938	9898	Economy	28000.00
0005434825880	9898	Economy	28000.00
0005435375013	9898	Economy	28000.00
0005434825574	9898	Economy	28000.00
0005434825835	9898	Economy	28000.00
0005434826031	9898	Economy	28000.00
0005434825690	9898	Economy	28000.00
0005435375060	9898	Economy	28000.00
0005434825946	9898	Economy	28000.00
0005434825766	9898	Economy	28000.00
0005434826157	9898	Economy	28000.00
0005435375041	9898	Economy	28000.00
0005434826036	9898	Economy	28000.00
0005434825858	9898	Economy	28000.00
0005435179715	9898	Economy	28000.00
0005434825480	9898	Economy	28000.00
0005434665005	9898	Economy	28000.00
0005435315081	9898	Economy	28000.00
0005435375038	9898	Economy	28000.00
0005435150326	9898	Economy	28000.00
0005434826199	9898	Economy	28000.00
0005435150266	9898	Economy	28000.00
0005435315087	9898	Economy	28000.00
0005435375057	9898	Economy	28000.00
0005434825539	9898	Economy	28000.00
0005434826037	9898	Economy	28000.00
0005435375036	9898	Economy	28000.00
0005434825786	9898	Economy	28000.00
0005434826177	9898	Economy	28000.00
0005434826015	9898	Economy	28000.00
0005434826210	9898	Economy	28000.00
0005435299910	9898	Economy	30800.00
0005435315084	9898	Economy	30800.00
0005434826377	9898	Economy	30800.00
0005434825429	9898	Economy	28000.00
0005434825394	9898	Economy	28000.00
0005435375045	9898	Economy	30800.00
0005434825832	9898	Economy	30800.00
0005435375058	9898	Economy	28000.00
0005435299907	9898	Economy	28000.00
0005434826053	9898	Economy	28000.00
0005434826480	9898	Economy	28000.00
0005434831232	9898	Economy	28000.00
0005435662011	9898	Economy	28000.00
0005434558392	9898	Economy	28000.00
0005435375032	9898	Economy	28000.00
0005434825863	9898	Economy	28000.00
0005435375026	9898	Economy	28000.00
0005435662009	9898	Economy	28000.00
0005434826076	9898	Economy	28000.00
0005434825841	9898	Economy	28000.00
0005434825888	9898	Economy	28000.00
0005432203263	9898	Economy	28000.00
0005432400181	9898	Economy	28000.00
0005435735268	9898	Economy	28000.00
0005434558421	9898	Economy	28000.00
0005434825842	9898	Economy	28000.00
0005434825573	9898	Economy	28000.00
0005434825939	9898	Economy	28000.00
0005434826350	9898	Economy	28000.00
0005435315089	9898	Economy	28000.00
0005434825768	9898	Economy	28000.00
0005434826146	9898	Economy	28000.00
0005434825748	9898	Economy	28000.00
0005435302327	9898	Economy	28000.00
0005434825953	9898	Economy	28000.00
0005435375024	9898	Economy	28000.00
0005434831221	9898	Economy	28000.00
0005435735267	9898	Economy	28000.00
0005435735265	9898	Economy	28000.00
0005434558391	9898	Economy	28000.00
0005434825813	9898	Economy	28000.00
0005435375027	9898	Economy	28000.00
0005435315090	9898	Economy	28000.00
0005434665007	9898	Economy	28000.00
0005435375056	9898	Economy	28000.00
0005435375044	9898	Economy	28000.00
0005435150259	9898	Economy	28000.00
0005435375049	9898	Economy	28000.00
0005435375053	9898	Economy	28000.00
0005434826378	9898	Economy	28000.00
0005434826016	9898	Economy	28000.00
0005434826302	9898	Economy	28000.00
0005434831233	9898	Economy	28000.00
0005434826698	9898	Economy	28000.00
0005434826189	9898	Economy	28000.00
0005435315080	9898	Economy	28000.00
0005435375063	9898	Economy	28000.00
0005434831238	9898	Economy	28000.00
0005434825910	9898	Economy	28000.00
0005434826407	9898	Economy	28000.00
0005434825914	9898	Economy	28000.00
0005434825752	9898	Economy	28000.00
0005434826077	9898	Economy	28000.00
0005434825899	9898	Economy	28000.00
0005435315086	9898	Economy	28000.00
0005434825886	9898	Economy	28000.00
0005434826159	9898	Economy	28000.00
0005434825456	9898	Economy	28000.00
0005434826361	9898	Economy	28000.00
0005434825861	9898	Economy	28000.00
0005434825764	9898	Economy	28000.00
0005434826697	9898	Economy	28000.00
0005434825959	9898	Economy	28000.00
0005435299908	9898	Economy	28000.00
0005435315083	9898	Economy	28000.00
0005434825913	9898	Economy	28000.00
0005435375035	9898	Economy	28000.00
0005434825678	9898	Economy	28000.00
0005434665006	9898	Economy	28000.00
0005434826335	9898	Economy	28000.00
0005434825901	9898	Economy	28000.00
0005434825777	9898	Economy	28000.00
0005432396319	9898	Economy	28000.00
0005435375023	9898	Economy	28000.00
0005435375021	9898	Economy	28000.00
0005435375061	9898	Economy	28000.00
0005435375040	9898	Economy	28000.00
0005434825879	9898	Economy	28000.00
0005434826239	9898	Economy	28000.00
0005434826044	9898	Economy	28000.00
0005434826153	9898	Economy	28000.00
0005435150273	9898	Economy	28000.00
0005434826349	9898	Economy	28000.00
0005434826179	9898	Economy	28000.00
0005434826188	9898	Economy	28000.00
0005432203264	9898	Economy	28000.00
0005434826470	9898	Economy	28000.00
0005435386745	9898	Economy	28000.00
0005434825648	9898	Economy	28000.00
0005435150265	9898	Economy	28000.00
0005434825862	9898	Economy	28000.00
0005435375014	9898	Economy	30800.00
0005434826045	9898	Economy	30800.00
0005434825702	9898	Economy	30800.00
0005434826180	9898	Economy	28000.00
0005434825616	9898	Economy	28000.00
0005435179716	9898	Economy	28000.00
0005435315092	9898	Economy	28000.00
0005434826170	9898	Economy	28000.00
0005434826351	9898	Economy	28000.00
0005432396315	9898	Economy	28000.00
0005434826242	9898	Economy	28000.00
0005435375028	9898	Economy	28000.00
0005435375022	9898	Economy	28000.00
0005434558422	9898	Economy	28000.00
0005435375051	9898	Economy	28000.00
0005434826341	9898	Economy	28000.00
0005435299909	9898	Economy	28000.00
0005434826682	9898	Economy	28000.00
0005435375016	9898	Economy	28000.00
0005434825952	9898	Economy	28000.00
0005434825728	9898	Economy	28000.00
0005435375033	9898	Economy	28000.00
0005434825814	9898	Economy	28000.00
0005435375047	9898	Economy	28000.00
0005435150236	9898	Economy	28000.00
0005434825647	9898	Economy	28000.00
0005435375030	9898	Economy	28000.00
0005435302329	9898	Economy	28000.00
0005435315085	9898	Economy	28000.00
0005434826020	9898	Economy	28000.00
0005434826194	9898	Economy	28000.00
0005434825753	9898	Economy	28000.00
0005434825855	9898	Economy	28000.00
0005435375046	9898	Economy	28000.00
0005432396318	9898	Economy	28000.00
0005434826100	9898	Economy	28000.00
0005434825676	9898	Economy	28000.00
0005435375052	9898	Economy	28000.00
0005435299906	9898	Economy	28000.00
0005434826254	9898	Economy	28000.00
0005435150255	9898	Economy	28000.00
0005434826336	9898	Economy	28000.00
0005434831239	9898	Economy	28000.00
0005435375020	9898	Economy	28000.00
0005432203261	9898	Economy	28000.00
0005434826021	9898	Economy	28000.00
0005434825592	9898	Economy	28000.00
0005434826246	9898	Economy	28000.00
0005435150322	9898	Economy	28000.00
0005434826290	9898	Economy	28000.00
0005432396314	9898	Economy	28000.00
0005435315095	9898	Economy	28000.00
0005434825905	9898	Economy	28000.00
0005434558425	9898	Economy	28000.00
0005435375048	9898	Economy	28000.00
0005435375039	9898	Economy	28000.00
0005434825397	9898	Economy	28000.00
0005434826303	9898	Economy	28000.00
0005435315097	9898	Economy	28000.00
0005435375015	9898	Economy	28000.00
0005434825902	9898	Economy	28000.00
0005434826066	9898	Economy	28000.00
0005435315096	9898	Economy	28000.00
0005435150300	9898	Economy	28000.00
0005432203260	9898	Economy	28000.00
0005435375037	9898	Economy	28000.00
0005434825765	9898	Economy	28000.00
0005435375031	9898	Economy	28000.00
0005435375034	9898	Economy	28000.00
0005435375043	9898	Economy	28000.00
0005434826243	9898	Economy	28000.00
0005434825684	9898	Economy	28000.00
0005435375018	9898	Economy	28000.00
0005435735266	9898	Economy	28000.00
0005434828748	9898	Economy	28000.00
0005434825689	9898	Economy	28000.00
0005434826054	9898	Economy	28000.00
0005435179714	9898	Economy	28000.00
0005434826245	9898	Economy	28000.00
0005434825718	9898	Economy	28000.00
0005435150301	9898	Economy	28000.00
0005435375065	9898	Economy	28000.00
0005434825817	9898	Economy	28000.00
0005434825677	9898	Economy	28000.00
0005435735264	9898	Economy	28000.00
0005434825455	9898	Economy	28000.00
0005434826466	9898	Economy	28000.00
0005434828743	9898	Economy	28000.00
0005435662010	9898	Economy	28000.00
0005435315082	9898	Economy	28000.00
0005432203265	9898	Economy	28000.00
0005434825747	9898	Economy	28000.00
0005435083010	7027	Economy	8200.00
0005435083012	7027	Economy	7400.00
0005435083014	7027	Economy	7400.00
0005435083011	7027	Economy	7400.00
0005435790386	7027	Economy	7400.00
0005435083009	7027	Economy	7400.00
0005435083013	7027	Economy	7400.00
0005435083008	7027	Economy	7400.00
0005435083015	7027	Economy	7400.00
0005435082922	25976	Economy	7400.00
0005435082939	25976	Economy	7400.00
0005435082917	25976	Economy	7400.00
0005435082949	25976	Economy	7400.00
0005435790353	25976	Economy	7400.00
0005435082937	25976	Economy	7400.00
0005435082938	25976	Economy	7400.00
0005435790382	25976	Economy	7400.00
0005435790383	25976	Economy	7400.00
0005435082886	25976	Economy	7400.00
0005435082903	25976	Economy	7400.00
0005435082916	25976	Economy	7400.00
0005435082923	25976	Economy	7400.00
0005435790356	25976	Economy	7400.00
0005435082909	25976	Economy	7400.00
0005434215464	9537	Business	32800.00
0005434757585	9537	Business	32800.00
0005434215339	9537	Business	32800.00
0005434215373	9537	Business	32800.00
0005434757582	9537	Business	32800.00
0005434215337	9537	Business	32800.00
0005434757569	9537	Business	32800.00
0005434757574	9537	Business	32800.00
0005434215378	9537	Economy	10900.00
0005434757590	9537	Economy	10900.00
0005434215517	9537	Economy	10900.00
0005434215234	9537	Economy	10900.00
0005434757576	9537	Economy	10900.00
0005434757568	9537	Economy	10900.00
0005434757573	9537	Economy	10900.00
0005434757593	9537	Economy	10900.00
0005434757578	9537	Economy	12000.00
0005434215450	9537	Economy	12000.00
0005434215185	9537	Economy	12000.00
0005434215265	9537	Economy	12000.00
0005434215338	9537	Economy	10900.00
0005434757587	9537	Economy	10900.00
0005434215280	9537	Economy	10900.00
0005434215376	9537	Economy	10900.00
0005434215442	9537	Economy	10900.00
0005434757594	9537	Economy	10900.00
0005434757575	9537	Economy	10900.00
0005434215418	9537	Economy	10900.00
0005434215441	9537	Economy	10900.00
0005434215407	9537	Economy	10900.00
0005434757586	9537	Economy	10900.00
0005434215506	9537	Economy	10900.00
0005434757570	9537	Economy	10900.00
0005434215437	9537	Economy	10900.00
0005434215311	9537	Economy	10900.00
0005434215372	9537	Economy	10900.00
0005434215443	9537	Economy	10900.00
0005434757589	9537	Economy	10900.00
0005434215417	9537	Economy	10900.00
0005434215255	9537	Economy	10900.00
0005434215409	9537	Economy	10900.00
0005434757584	9537	Economy	10900.00
0005434215250	9537	Economy	10900.00
0005434215635	9537	Economy	10900.00
0005434757591	9537	Economy	10900.00
0005434215355	9537	Economy	10900.00
0005434215351	9537	Economy	10900.00
0005434757572	9537	Economy	10900.00
0005434757577	9537	Economy	10900.00
0005434215412	9537	Economy	10900.00
0005434215438	9537	Economy	10900.00
0005434215320	9537	Economy	10900.00
0005434757595	9537	Economy	10900.00
0005434215634	9537	Economy	10900.00
0005434215408	9537	Economy	10900.00
0005434215379	9537	Economy	10900.00
0005434215350	9537	Economy	10900.00
0005434215430	9537	Economy	10900.00
0005434215388	9537	Economy	10900.00
0005434215456	9537	Economy	10900.00
0005434757571	9537	Economy	10900.00
0005434215505	9537	Economy	10900.00
0005434757581	9537	Economy	10900.00
0005434215455	9537	Economy	10900.00
0005434215312	9537	Economy	10900.00
0005434215298	9537	Economy	10900.00
0005434757588	9537	Economy	10900.00
0005434757567	9537	Economy	10900.00
0005434215468	9537	Economy	10900.00
0005434215297	9537	Economy	10900.00
0005434757583	9537	Economy	10900.00
0005434757579	9537	Economy	10900.00
0005434215558	9537	Economy	10900.00
0005434757566	9537	Economy	10900.00
0005434757592	9537	Economy	10900.00
0005434757580	9537	Economy	10900.00
0005434215439	9537	Economy	10900.00
0005434757224	28604	Business	32800.00
0005434757131	28604	Business	32800.00
0005434757168	28604	Business	32800.00
0005434757099	28604	Business	32800.00
0005434215742	28604	Business	32800.00
0005434756899	28604	Business	32800.00
0005434757152	28604	Business	32800.00
0005434757122	28604	Business	32800.00
0005434757074	28604	Business	32800.00
0005434757096	28604	Business	32800.00
0005434215748	28604	Business	32800.00
0005434757172	28604	Economy	10900.00
0005434215752	28604	Economy	10900.00
0005434757106	28604	Economy	10900.00
0005434215770	28604	Economy	10900.00
0005434215759	28604	Economy	10900.00
0005434215754	28604	Economy	10900.00
0005434215771	28604	Economy	10900.00
0005434757151	28604	Economy	10900.00
0005434757006	28604	Economy	10900.00
0005434757181	28604	Economy	12000.00
0005434215762	28604	Economy	12000.00
0005434757250	28604	Economy	12000.00
0005434215755	28604	Economy	12000.00
0005434757163	28604	Economy	10900.00
0005434215751	28604	Economy	10900.00
0005434757212	28604	Economy	10900.00
0005434757129	28604	Economy	10900.00
0005434756900	28604	Economy	10900.00
0005434215764	28604	Economy	10900.00
0005434215756	28604	Economy	10900.00
0005434757009	28604	Economy	10900.00
0005434215763	28604	Economy	10900.00
0005434215774	28604	Economy	10900.00
0005434215753	28604	Economy	10900.00
0005434757134	28604	Economy	10900.00
0005434215743	28604	Economy	10900.00
0005434757004	28604	Economy	10900.00
0005434215740	28604	Economy	10900.00
0005434215739	28604	Economy	10900.00
0005434215746	28604	Economy	10900.00
0005434215760	28604	Economy	10900.00
0005434757138	28604	Economy	10900.00
0005434215761	28604	Economy	10900.00
0005434757105	28604	Economy	10900.00
0005434757087	28604	Economy	10900.00
0005434757167	28604	Economy	10900.00
0005434757135	28604	Economy	10900.00
0005434757153	28604	Economy	10900.00
0005434215772	28604	Economy	10900.00
0005434215738	28604	Economy	10900.00
0005434757005	28604	Economy	10900.00
0005434757077	28604	Economy	10900.00
0005434215768	28604	Economy	10900.00
0005434757186	28604	Economy	10900.00
0005434757155	28604	Economy	10900.00
0005434757159	28604	Economy	10900.00
0005434757095	28604	Economy	10900.00
0005434757133	28604	Economy	10900.00
0005434757116	28604	Economy	10900.00
0005434757132	28604	Economy	10900.00
0005434215765	28604	Economy	10900.00
0005434757076	28604	Economy	10900.00
0005434215767	28604	Economy	10900.00
0005434757128	28604	Economy	10900.00
0005434215773	28604	Economy	10900.00
0005434757225	28604	Economy	10900.00
0005434757086	28604	Economy	10900.00
0005434757146	28604	Economy	10900.00
0005434757123	28604	Economy	10900.00
0005434757211	28604	Economy	10900.00
0005434215758	28604	Economy	10900.00
0005434757112	28604	Economy	10900.00
0005434215749	28604	Economy	10900.00
0005434215744	28604	Economy	10900.00
0005434757179	28604	Economy	10900.00
0005434757194	28604	Economy	10900.00
0005434215750	28604	Economy	10900.00
0005434757156	28604	Economy	10900.00
0005434215745	28604	Economy	10900.00
0005434757203	28604	Economy	10900.00
0005434215766	28604	Economy	10900.00
0005434757075	28604	Economy	10900.00
0005434215769	28604	Economy	10900.00
0005434757125	28604	Economy	10900.00
0005434215757	28604	Economy	10900.00
0005434757145	28604	Economy	10900.00
0005434215741	28604	Economy	10900.00
0005434757158	28604	Economy	10900.00
0005434215747	28604	Economy	10900.00
0005435100204	10827	Economy	9800.00
0005434760264	31796	Economy	9800.00
0005435100180	31796	Economy	9800.00
0005434760265	31796	Economy	8900.00
0005434640024	1968	Economy	20900.00
0005432290719	1968	Economy	20900.00
0005433202634	1968	Economy	20900.00
0005433202666	1968	Economy	20900.00
0005433202668	1968	Economy	19000.00
0005434640033	1968	Economy	19000.00
0005433202640	1968	Economy	19000.00
0005433202609	1968	Economy	19000.00
0005435948360	1968	Economy	19000.00
0005434640026	1968	Economy	19000.00
0005434640036	1968	Economy	19000.00
0005434640039	1968	Economy	19000.00
0005433202701	1968	Economy	19000.00
0005434640025	1968	Economy	19000.00
0005434640046	1968	Economy	19000.00
0005433202641	1968	Economy	19000.00
0005434640027	1968	Economy	19000.00
0005434640023	1968	Economy	19000.00
0005434640035	1968	Economy	19000.00
0005433202662	1968	Economy	19000.00
0005434640047	1968	Economy	19000.00
0005434640043	1968	Economy	19000.00
0005434640022	1968	Economy	19000.00
0005433202679	1968	Economy	19000.00
0005433202653	1968	Economy	19000.00
0005433202577	1968	Economy	19000.00
0005433202621	1968	Economy	19000.00
0005433202635	1968	Economy	19000.00
0005434640042	1968	Economy	19000.00
0005434640034	1968	Economy	19000.00
0005434640048	1968	Economy	19000.00
0005433202678	1968	Economy	19000.00
0005432290718	1968	Economy	19000.00
0005434640037	1968	Economy	19000.00
0005433202643	1968	Economy	19000.00
0005434640044	1968	Economy	19000.00
0005432290717	1968	Economy	19000.00
0005434640031	1968	Economy	19000.00
0005434640038	1968	Economy	19000.00
0005434640032	1968	Economy	19000.00
0005434640030	1968	Economy	19000.00
0005434640041	1968	Economy	19000.00
0005434640029	1968	Economy	19000.00
0005434640028	1968	Economy	19000.00
0005433202576	1968	Economy	19000.00
0005434640040	1968	Economy	19000.00
0005434640045	1968	Economy	19000.00
0005434639761	23285	Economy	20900.00
0005434639762	23285	Economy	20900.00
0005434639709	23285	Economy	20900.00
0005434639867	23285	Economy	20900.00
0005434639831	23285	Economy	19000.00
0005434639801	23285	Economy	19000.00
0005434639812	23285	Economy	19000.00
0005434639819	23285	Economy	19000.00
0005434639811	23285	Economy	19000.00
0005434639837	23285	Economy	19000.00
0005433202755	23285	Economy	19000.00
0005434639817	23285	Economy	19000.00
0005434639858	23285	Economy	19000.00
0005434639760	23285	Economy	19000.00
0005434639873	23285	Economy	19000.00
0005434639786	23285	Economy	19000.00
0005434639824	23285	Economy	19000.00
0005434639881	23285	Economy	19000.00
0005434639836	23285	Economy	19000.00
0005434639810	23285	Economy	19000.00
0005434639826	23285	Economy	19000.00
0005433202756	23285	Economy	19000.00
0005433202757	23285	Economy	19000.00
0005434639691	23285	Economy	19000.00
0005433202753	23285	Economy	19000.00
0005433202754	23285	Economy	19000.00
0005434639838	23285	Economy	19000.00
0005434639806	23285	Economy	19000.00
0005434639818	23285	Economy	19000.00
0005434639804	23285	Economy	19000.00
0005433202750	23285	Economy	19000.00
0005433202758	23285	Economy	19000.00
0005434639880	23285	Economy	19000.00
0005434639805	23285	Economy	19000.00
0005434639759	23285	Economy	19000.00
0005434639773	23285	Economy	19000.00
0005434639765	23285	Economy	19000.00
0005434639813	23285	Economy	19000.00
0005434639832	23285	Economy	19000.00
0005434639796	23285	Economy	19000.00
0005434639868	23285	Economy	19000.00
0005433202749	23285	Economy	19000.00
0005433202751	23285	Economy	19000.00
0005434639816	23285	Economy	19000.00
0005434639766	23285	Economy	19000.00
0005434639696	23285	Economy	19000.00
0005434639825	23285	Economy	19000.00
0005434639708	23285	Economy	19000.00
0005433202752	23285	Economy	19000.00
0005435327041	6042	Business	69700.00
0005433531399	6042	Business	69700.00
0005434601528	6042	Business	69700.00
0005433533411	6042	Business	69700.00
0005435326996	6042	Business	69700.00
0005434601534	6042	Economy	23200.00
0005433533414	6042	Economy	23200.00
0005435326968	6042	Economy	23200.00
0005433533412	6042	Economy	25600.00
0005434601547	6042	Economy	25600.00
0005434601526	6042	Economy	25600.00
0005434601536	6042	Economy	25600.00
0005434601538	6042	Economy	23200.00
0005434601533	6042	Economy	23200.00
0005434601531	6042	Economy	23200.00
0005434601544	6042	Economy	23200.00
0005432111361	6042	Economy	23200.00
0005435327047	6042	Economy	23200.00
0005435327013	6042	Economy	23200.00
0005434601545	6042	Economy	23200.00
0005434601540	6042	Economy	23200.00
0005435327012	6042	Economy	23200.00
0005434601537	6042	Economy	23200.00
0005434601525	6042	Economy	23200.00
0005434601529	6042	Economy	23200.00
0005434601527	6042	Economy	23200.00
0005435326967	6042	Economy	23200.00
0005434601530	6042	Economy	23200.00
0005435327020	6042	Economy	23200.00
0005434601546	6042	Economy	23200.00
0005433533413	6042	Economy	23200.00
0005434601548	6042	Economy	23200.00
0005435327042	6042	Economy	23200.00
0005434601532	6042	Economy	23200.00
0005434601524	6042	Economy	23200.00
0005435327011	6042	Economy	23200.00
0005435327001	6042	Economy	23200.00
0005434601543	6042	Economy	23200.00
0005433533415	6042	Economy	23200.00
0005434601523	6042	Economy	23200.00
0005434601542	6042	Economy	23200.00
0005434601539	6042	Economy	23200.00
0005435327021	6042	Economy	23200.00
0005434601535	6042	Economy	23200.00
0005434601541	6042	Economy	23200.00
0005433531400	6042	Economy	23200.00
0005432111362	6042	Economy	23200.00
0005434601202	18574	Business	69700.00
0005435327120	18574	Business	69700.00
0005433527322	18574	Business	69700.00
0005434601363	18574	Business	69700.00
0005434601362	18574	Business	69700.00
0005434601441	18574	Business	69700.00
0005434601399	18574	Business	69700.00
0005433527320	18574	Business	69700.00
0005435327122	18574	Economy	23200.00
0005433527304	18574	Economy	23200.00
0005435327123	18574	Economy	23200.00
0005434601203	18574	Economy	23200.00
0005433527321	18574	Economy	23200.00
0005434601365	18574	Economy	25600.00
0005434601292	18574	Economy	25600.00
0005435327115	18574	Economy	25600.00
0005434601345	18574	Economy	23200.00
0005434601307	18574	Economy	23200.00
0005433527303	18574	Economy	23200.00
0005434601453	18574	Economy	23200.00
0005433531355	18574	Economy	23200.00
0005435327124	18574	Economy	23200.00
0005434601310	18574	Economy	23200.00
0005433531354	18574	Economy	23200.00
0005434601294	18574	Economy	23200.00
0005434601438	18574	Economy	23200.00
0005435327116	18574	Economy	23200.00
0005433531343	18574	Economy	23200.00
0005434601267	18574	Economy	23200.00
0005434601352	18574	Economy	23200.00
0005435327118	18574	Economy	23200.00
0005434601317	18574	Economy	23200.00
0005434601308	18574	Economy	23200.00
0005435327119	18574	Economy	23200.00
0005434601318	18574	Economy	23200.00
0005434601293	18574	Economy	23200.00
0005434601289	18574	Economy	23200.00
0005433527324	18574	Economy	23200.00
0005434601268	18574	Economy	23200.00
0005434601306	18574	Economy	23200.00
0005433531358	18574	Economy	23200.00
0005434601388	18574	Economy	23200.00
0005434601291	18574	Economy	23200.00
0005434601335	18574	Economy	23200.00
0005433527319	18574	Economy	23200.00
0005434601420	18574	Economy	23200.00
0005433527335	18574	Economy	23200.00
0005434601439	18574	Economy	23200.00
0005434601255	18574	Economy	23200.00
0005435327117	18574	Economy	23200.00
0005434601316	18574	Economy	23200.00
0005434601248	18574	Economy	23200.00
0005434601428	18574	Economy	23200.00
0005433531356	18574	Economy	23200.00
0005434601340	18574	Economy	23200.00
0005435327121	18574	Economy	23200.00
0005434601454	18574	Economy	23200.00
0005433181453	10638	Business	9100.00
0005433181468	10638	Business	9100.00
0005433181638	10638	Business	9100.00
0005434552668	10638	Business	9100.00
0005434552685	10638	Business	9100.00
0005434552676	10638	Business	9100.00
0005434558509	10638	Business	9100.00
0005433181582	10638	Business	9100.00
0005434552665	10638	Business	9100.00
0005434552697	10638	Business	9100.00
0005434552703	10638	Economy	3000.00
0005434552699	10638	Economy	3000.00
0005434552662	10638	Economy	3000.00
0005434558500	10638	Economy	3000.00
0005434552682	10638	Economy	3000.00
0005434552711	10638	Economy	3000.00
0005434552694	10638	Economy	3000.00
0005433181535	10638	Economy	3000.00
0005434552673	10638	Economy	3000.00
0005434552706	10638	Economy	3000.00
0005434558507	10638	Economy	3300.00
0005434552669	10638	Economy	3300.00
0005434552709	10638	Economy	3300.00
0005433181481	10638	Economy	3300.00
0005434552713	10638	Economy	3300.00
0005434552664	10638	Economy	3000.00
0005434552710	10638	Economy	3000.00
0005433181479	10638	Economy	3000.00
0005434558504	10638	Economy	3000.00
0005434552687	10638	Economy	3000.00
0005434552707	10638	Economy	3000.00
0005434552693	10638	Economy	3000.00
0005434558501	10638	Economy	3000.00
0005434552701	10638	Economy	3000.00
0005434552678	10638	Economy	3000.00
0005433181527	10638	Economy	3000.00
0005434552684	10638	Economy	3000.00
0005434552700	10638	Economy	3000.00
0005434552708	10638	Economy	3000.00
0005434552672	10638	Economy	3000.00
0005433181506	10638	Economy	3000.00
0005434558511	10638	Economy	3000.00
0005434552690	10638	Economy	3000.00
0005433181659	10638	Economy	3000.00
0005434552671	10638	Economy	3000.00
0005434558508	10638	Economy	3000.00
0005433181467	10638	Economy	3000.00
0005434552704	10638	Economy	3000.00
0005434552686	10638	Economy	3000.00
0005434552695	10638	Economy	3000.00
0005434552660	10638	Economy	3000.00
0005434552692	10638	Economy	3000.00
0005434552691	10638	Economy	3000.00
0005433181575	10638	Economy	3000.00
0005433181574	10638	Economy	3000.00
0005434558499	10638	Economy	3000.00
0005434552675	10638	Economy	3000.00
0005433181580	10638	Economy	3000.00
0005434552712	10638	Economy	3000.00
0005434552661	10638	Economy	3000.00
0005434558512	10638	Economy	3000.00
0005434552680	10638	Economy	3000.00
0005434552677	10638	Economy	3000.00
0005433181583	10638	Economy	3000.00
0005433181480	10638	Economy	3000.00
0005434552705	10638	Economy	3000.00
0005434558498	10638	Economy	3000.00
0005433181526	10638	Economy	3000.00
0005434552688	10638	Economy	3000.00
0005434558510	10638	Economy	3000.00
0005434552698	10638	Economy	3000.00
0005434552663	10638	Economy	3000.00
0005434552667	10638	Economy	3000.00
0005434552714	10638	Economy	3000.00
0005434552674	10638	Economy	3000.00
0005434558513	10638	Economy	3000.00
0005434552696	10638	Economy	3000.00
0005433181581	10638	Economy	3000.00
0005434558502	10638	Economy	3000.00
0005434552683	10638	Economy	3000.00
0005434552702	10638	Economy	3000.00
0005434552681	10638	Economy	3000.00
0005433181637	10638	Economy	3000.00
0005434558506	10638	Economy	3000.00
0005434552689	10638	Economy	3000.00
0005433181536	10638	Economy	3000.00
0005434558505	10638	Economy	3000.00
0005434552666	10638	Economy	3000.00
0005433181521	10638	Economy	3000.00
0005434552679	10638	Economy	3000.00
0005434558503	10638	Economy	3000.00
0005433181462	10638	Economy	3000.00
0005434552670	10638	Economy	3000.00
0005433181797	27700	Business	9100.00
0005433181778	27700	Business	9100.00
0005435315096	27700	Business	9100.00
0005433181787	27700	Business	9100.00
0005435315093	27700	Business	9100.00
0005435315090	27700	Economy	3000.00
0005435315095	27700	Economy	3000.00
0005433181794	27700	Economy	3000.00
0005433181798	27700	Economy	3000.00
0005433181796	27700	Economy	3000.00
0005434757708	27700	Economy	3000.00
0005434757707	27700	Economy	3300.00
0005433181782	27700	Economy	3300.00
0005433181793	27700	Economy	3000.00
0005433181779	27700	Economy	3000.00
0005434757706	27700	Economy	3000.00
0005433181783	27700	Economy	3000.00
0005433181784	27700	Economy	3000.00
0005435315097	27700	Economy	3000.00
0005435315091	27700	Economy	3000.00
0005433181790	27700	Economy	3000.00
0005433181800	27700	Economy	3000.00
0005433181781	27700	Economy	3000.00
0005433181788	27700	Economy	3000.00
0005435315084	27700	Economy	3000.00
0005433181799	27700	Economy	3000.00
0005435315085	27700	Economy	3000.00
0005433181795	27700	Economy	3000.00
0005435315086	27700	Economy	3000.00
0005433181786	27700	Economy	3000.00
0005435315094	27700	Economy	3000.00
0005433181785	27700	Economy	3000.00
0005435315080	27700	Economy	3000.00
0005435315088	27700	Economy	3000.00
0005433181791	27700	Economy	3000.00
0005435315089	27700	Economy	3000.00
0005435315082	27700	Economy	3000.00
0005435315087	27700	Economy	3000.00
0005433181789	27700	Economy	3000.00
0005435315083	27700	Economy	3000.00
0005435315081	27700	Economy	3000.00
0005433181780	27700	Economy	3000.00
0005435315092	27700	Economy	3000.00
0005433181792	27700	Economy	3000.00
0005434552284	27699	Business	9100.00
0005434552334	27699	Business	9100.00
0005434552299	27699	Business	9100.00
0005434552195	27699	Business	9100.00
0005434551896	27699	Business	9100.00
0005434552489	27699	Business	9100.00
0005434552472	27699	Business	9100.00
0005434552147	27699	Business	9100.00
0005434552194	27699	Business	9100.00
0005434552118	27699	Economy	3000.00
0005434552087	27699	Economy	3000.00
0005434552471	27699	Economy	3000.00
0005434552209	27699	Economy	3000.00
0005434552168	27699	Economy	3300.00
0005434552069	27699	Economy	3300.00
0005434552336	27699	Economy	3300.00
0005434552382	27699	Economy	3000.00
0005434551897	27699	Economy	3000.00
0005434552335	27699	Economy	3000.00
0005434552273	27699	Economy	3000.00
0005434551937	27699	Economy	3000.00
0005434554100	27699	Economy	3000.00
0005434552285	27699	Economy	3000.00
0005434552295	27699	Economy	3000.00
0005434552083	27699	Economy	3000.00
0005434552329	27699	Economy	3000.00
0005434552461	27699	Economy	3000.00
0005434552092	27699	Economy	3000.00
0005434552462	27699	Economy	3000.00
0005434552291	27699	Economy	3000.00
0005434552422	27699	Economy	3000.00
0005434552080	27699	Economy	3000.00
0005434558433	27699	Economy	3000.00
0005434552148	27699	Economy	3000.00
0005434552404	27699	Economy	3000.00
0005434552300	27699	Economy	3000.00
0005434552015	27699	Economy	3000.00
0005434552307	27699	Economy	3000.00
0005434552117	27699	Economy	3000.00
0005434552169	27699	Economy	3000.00
0005434552260	27699	Economy	3000.00
0005434552014	27699	Economy	3000.00
0005434554099	27699	Economy	3000.00
0005434552423	27699	Economy	3000.00
0005434552070	27699	Economy	3000.00
0005434552479	27699	Economy	3000.00
0005434552282	27699	Economy	3000.00
0005434552311	27699	Economy	3000.00
0005434552081	27699	Economy	3000.00
0005434552261	27699	Economy	3000.00
0005434558432	27699	Economy	3000.00
0005434552162	27699	Economy	3000.00
0005434552488	27699	Economy	3000.00
0005434552292	27699	Economy	3000.00
0005434552196	27699	Economy	3000.00
0005434552091	27699	Economy	3000.00
0005434552164	27699	Economy	3000.00
0005434552119	27699	Economy	3000.00
0005434552460	27699	Economy	3000.00
0005434552337	27699	Economy	3000.00
0005434552392	27699	Economy	3000.00
0005434552312	27699	Economy	3000.00
0005435254514	6162	Economy	11700.00
0005433459334	6162	Economy	11700.00
0005435254520	6162	Economy	11700.00
0005433459307	19312	Economy	11700.00
0005435254537	19312	Economy	11700.00
0005433459301	19312	Economy	11700.00
0005433459299	19312	Economy	11700.00
0005435254540	19312	Economy	11700.00
0005435254538	19312	Economy	11700.00
0005433459305	19312	Economy	11700.00
0005433459294	19312	Economy	11700.00
0005433459293	19312	Economy	11700.00
0005433459306	19312	Economy	11700.00
0005435254539	19312	Economy	11700.00
0005435683252	6726	Business	51100.00
0005435683268	6726	Business	51100.00
0005435683267	6726	Business	51100.00
0005435438467	6726	Business	51100.00
0005435217743	6726	Business	51100.00
0005435683246	6726	Business	51100.00
0005435438374	6726	Business	51100.00
0005435683248	6726	Economy	17000.00
0005434828736	6726	Economy	17000.00
0005435683255	6726	Economy	17000.00
0005432533340	6726	Economy	17000.00
0005435683270	6726	Economy	17000.00
0005435438419	6726	Economy	17000.00
0005435719600	6726	Economy	18700.00
0005435683245	6726	Economy	18700.00
0005432136305	6726	Economy	18700.00
0005435662007	6726	Economy	18700.00
0005435683262	6726	Economy	18700.00
0005435438469	6726	Economy	17000.00
0005435220346	6726	Economy	17000.00
0005435683242	6726	Economy	17000.00
0005435438438	6726	Economy	17000.00
0005435438459	6726	Economy	17000.00
0005432136303	6726	Economy	17000.00
0005435220348	6726	Economy	17000.00
0005435683271	6726	Economy	17000.00
0005435438372	6726	Economy	17000.00
0005435438371	6726	Economy	17000.00
0005435683239	6726	Economy	17000.00
0005435662008	6726	Economy	17000.00
0005432136304	6726	Economy	17000.00
0005435438460	6726	Economy	17000.00
0005435683254	6726	Economy	17000.00
0005435683258	6726	Economy	17000.00
0005435720164	6726	Economy	17000.00
0005435438439	6726	Economy	17000.00
0005435719601	6726	Economy	17000.00
0005435683257	6726	Economy	17000.00
0005435438398	6726	Economy	17000.00
0005435683249	6726	Economy	17000.00
0005435438468	6726	Economy	17000.00
0005435683244	6726	Economy	17000.00
0005435438310	6726	Economy	17000.00
0005435683243	6726	Economy	17000.00
0005432533344	6726	Economy	17000.00
0005435720165	6726	Economy	17000.00
0005435683269	6726	Economy	17000.00
0005435683261	6726	Economy	17000.00
0005435683264	6726	Economy	17000.00
0005435683266	6726	Economy	17000.00
0005435683263	6726	Economy	17000.00
0005435683240	6726	Economy	17000.00
0005435438358	6726	Economy	17000.00
0005435438373	6726	Economy	17000.00
0005435662006	6726	Economy	17000.00
0005435683241	6726	Economy	17000.00
0005435438333	6726	Economy	17000.00
0005435438361	6726	Economy	17000.00
0005435683253	6726	Economy	17000.00
0005435438346	6726	Economy	17000.00
0005435683251	6726	Economy	17000.00
0005432533345	6726	Economy	17000.00
0005435683250	6726	Economy	17000.00
0005435220347	6726	Economy	17000.00
0005435683247	6726	Economy	17000.00
0005435683259	6726	Economy	17000.00
0005435683265	6726	Economy	17000.00
0005435683260	6726	Economy	17000.00
0005435438345	6726	Economy	17000.00
0005435438417	6726	Economy	17000.00
0005435438319	6726	Economy	17000.00
0005435683256	6726	Economy	17000.00
0005435438414	6726	Economy	17000.00
0005435631047	6726	Economy	17000.00
0005435631046	6726	Economy	17000.00
0005435661985	24601	Business	51100.00
0005435438546	24601	Business	51100.00
0005435631026	24601	Business	51100.00
0005435438556	24601	Business	51100.00
0005435682863	24601	Business	51100.00
0005435683009	24601	Business	51100.00
0005435682908	24601	Business	51100.00
0005435682819	24601	Business	51100.00
0005435631016	24601	Business	51100.00
0005435683054	24601	Business	51100.00
0005435438552	24601	Business	51100.00
0005435661988	24601	Economy	17000.00
0005435661983	24601	Economy	17000.00
0005435661987	24601	Economy	17000.00
0005435661982	24601	Economy	17000.00
0005435682954	24601	Economy	17000.00
0005435682956	24601	Economy	17000.00
0005435661992	24601	Economy	17000.00
0005435438554	24601	Economy	17000.00
0005435683010	24601	Economy	17000.00
0005435682924	24601	Economy	17000.00
0005435683021	24601	Economy	18700.00
0005435720846	24601	Economy	18700.00
0005435438560	24601	Economy	18700.00
0005435682756	24601	Economy	18700.00
0005435682866	24601	Economy	18700.00
0005435661993	24601	Economy	17000.00
0005432305815	24601	Economy	17000.00
0005435438543	24601	Economy	17000.00
0005435438559	24601	Economy	17000.00
0005435682729	24601	Economy	17000.00
0005435682981	24601	Economy	17000.00
0005434828771	24601	Economy	17000.00
0005435682978	24601	Economy	17000.00
0005435682603	24601	Economy	17000.00
0005435682818	24601	Economy	17000.00
0005435683022	24601	Economy	17000.00
0005435438542	24601	Economy	17000.00
0005435631013	24601	Economy	17000.00
0005435682847	24601	Economy	17000.00
0005435682759	24601	Economy	17000.00
0005435720845	24601	Economy	17000.00
0005435682823	24601	Economy	17000.00
0005435682735	24601	Economy	17000.00
0005435682809	24601	Economy	17000.00
0005435682778	24601	Economy	17000.00
0005435438544	24601	Economy	17000.00
0005435682773	24601	Economy	17000.00
0005435683008	24601	Economy	17000.00
0005435438545	24601	Economy	17000.00
0005435683114	24601	Economy	17000.00
0005435438550	24601	Economy	17000.00
0005435631017	24601	Economy	17000.00
0005432533369	24601	Economy	17000.00
0005435682887	24601	Economy	17000.00
0005435682850	24601	Economy	17000.00
0005435682977	24601	Economy	17000.00
0005435682855	24601	Economy	17000.00
0005435631021	24601	Economy	17000.00
0005435682903	24601	Economy	17000.00
0005435438555	24601	Economy	17000.00
0005435438553	24601	Economy	17000.00
0005435438548	24601	Economy	17000.00
0005435682865	24601	Economy	17000.00
0005434828772	24601	Economy	17000.00
0005435682955	24601	Economy	17000.00
0005435438557	24601	Economy	17000.00
0005432533368	24601	Economy	17000.00
0005435438551	24601	Economy	17000.00
0005435682822	24601	Economy	17000.00
0005435683051	24601	Economy	17000.00
0005435682860	24601	Economy	17000.00
0005435438547	24601	Economy	17000.00
0005435683023	24601	Economy	17000.00
0005435631022	24601	Economy	17000.00
0005435682746	24601	Economy	17000.00
0005435682696	24601	Economy	17000.00
0005435438561	24601	Economy	17000.00
0005435682914	24601	Economy	17000.00
0005435683067	24601	Economy	17000.00
0005435682907	24601	Economy	17000.00
0005435682864	24601	Economy	17000.00
0005435438558	24601	Economy	17000.00
0005432305816	24601	Economy	17000.00
0005435438549	24601	Economy	17000.00
0005435683049	24601	Economy	17000.00
0005435631009	24601	Economy	17000.00
0005435682915	24601	Economy	17000.00
0005435683050	24601	Economy	17000.00
0005435682734	24601	Economy	17000.00
0005435682856	24601	Economy	17000.00
0005435127461	11516	Business	26400.00
0005435127454	11516	Business	26400.00
0005435127452	11516	Business	26400.00
0005435127443	11516	Business	26400.00
0005435106064	11516	Economy	8800.00
0005435127433	11516	Economy	8800.00
0005435558141	11516	Economy	8800.00
0005435127460	11516	Economy	8800.00
0005435127459	11516	Economy	8800.00
0005435127429	11516	Economy	9700.00
0005435127447	11516	Economy	9700.00
0005435127444	11516	Economy	8800.00
0005435106065	11516	Economy	8800.00
0005435127449	11516	Economy	8800.00
0005435127441	11516	Economy	8800.00
0005435558131	11516	Economy	8800.00
0005435127465	11516	Economy	8800.00
0005435127467	11516	Economy	8800.00
0005435127453	11516	Economy	8800.00
0005435127438	11516	Economy	8800.00
0005435127442	11516	Economy	8800.00
0005435127455	11516	Economy	8800.00
0005435127451	11516	Economy	8800.00
0005435127431	11516	Economy	8800.00
0005435558143	11516	Economy	8800.00
0005435127448	11516	Economy	8800.00
0005435558133	11516	Economy	8800.00
0005435127439	11516	Economy	8800.00
0005435127440	11516	Economy	8800.00
0005435127462	11516	Economy	8800.00
0005435127430	11516	Economy	8800.00
0005435127434	11516	Economy	8800.00
0005435106066	11516	Economy	8800.00
0005435127457	11516	Economy	8800.00
0005435127428	11516	Economy	8800.00
0005435106067	11516	Economy	8800.00
0005435127435	11516	Economy	8800.00
0005435127436	11516	Economy	8800.00
0005435127466	11516	Economy	8800.00
0005435127450	11516	Economy	8800.00
0005435127437	11516	Economy	8800.00
0005435127432	11516	Economy	8800.00
0005435127445	11516	Economy	8800.00
0005435127463	11516	Economy	8800.00
0005435127464	11516	Economy	8800.00
0005435558142	11516	Economy	8800.00
0005435127456	11516	Economy	8800.00
0005435127446	11516	Economy	8800.00
0005435127458	11516	Economy	8800.00
0005435558139	11516	Economy	8800.00
0005435558158	31856	Business	26400.00
0005435127182	31856	Business	26400.00
0005435126985	31856	Business	26400.00
0005435127103	31856	Business	26400.00
0005435127217	31856	Business	26400.00
0005435127063	31856	Business	26400.00
0005435127218	31856	Business	26400.00
0005435127138	31856	Economy	8800.00
0005435558161	31856	Economy	8800.00
0005435127205	31856	Economy	8800.00
0005435127114	31856	Economy	8800.00
0005435558159	31856	Economy	8800.00
0005435127233	31856	Economy	8800.00
0005435127173	31856	Economy	8800.00
0005435127238	31856	Economy	8800.00
0005435127036	31856	Economy	8800.00
0005435127385	31856	Economy	8800.00
0005435127207	31856	Economy	9700.00
0005435127229	31856	Economy	9700.00
0005435127174	31856	Economy	9700.00
0005435127134	31856	Economy	9700.00
0005435127085	31856	Economy	9700.00
0005435127188	31856	Economy	8800.00
0005435127078	31856	Economy	8800.00
0005435127104	31856	Economy	8800.00
0005435126934	31856	Economy	8800.00
0005435127137	31856	Economy	8800.00
0005435127187	31856	Economy	8800.00
0005435127092	31856	Economy	8800.00
0005435127172	31856	Economy	8800.00
0005435127105	31856	Economy	8800.00
0005435127043	31856	Economy	8800.00
0005435127153	31856	Economy	8800.00
0005435558162	31856	Economy	8800.00
0005435558163	31856	Economy	8800.00
0005435126911	31856	Economy	8800.00
0005435127189	31856	Economy	8800.00
0005435127139	31856	Economy	8800.00
0005435127206	31856	Economy	8800.00
0005435106039	31856	Economy	8800.00
0005435127037	31856	Economy	8800.00
0005435127267	31856	Economy	8800.00
0005435127080	31856	Economy	8800.00
0005435127264	31856	Economy	8800.00
0005435127033	31856	Economy	8800.00
0005435127082	31856	Economy	8800.00
0005435126987	31856	Economy	8800.00
0005435127181	31856	Economy	8800.00
0005435558160	31856	Economy	8800.00
0005435126913	31856	Economy	8800.00
0005435127184	31856	Economy	8800.00
0005435127220	31856	Economy	8800.00
0005435127081	31856	Economy	8800.00
0005435127216	31856	Economy	8800.00
0005435127237	31856	Economy	8800.00
0005435127343	31856	Economy	8800.00
0005435127165	31856	Economy	8800.00
0005435127136	31856	Economy	8800.00
0005435126988	31856	Economy	8800.00
0005435127124	31856	Economy	8800.00
0005435127091	31856	Economy	8800.00
0005435127342	31856	Economy	8800.00
0005435127150	31856	Economy	8800.00
0005435127270	31856	Economy	8800.00
0005435127180	31856	Economy	8800.00
0005435127239	31856	Economy	8800.00
0005435126935	31856	Economy	8800.00
0005435127185	31856	Economy	8800.00
0005435127263	31856	Economy	8800.00
0005435127186	31856	Economy	8800.00
0005435127251	31856	Economy	8800.00
0005435127234	31856	Economy	8800.00
0005433399369	13518	Business	36600.00
0005435732605	13518	Business	36600.00
0005435732597	13518	Business	36600.00
0005433399347	13518	Business	36600.00
0005433399364	13518	Business	36600.00
0005433399373	13518	Economy	12200.00
0005433399365	13518	Economy	12200.00
0005435732584	13518	Economy	12200.00
0005433399342	13518	Economy	12200.00
0005433399346	13518	Economy	13400.00
0005433399340	13518	Economy	13400.00
0005433399352	13518	Economy	12200.00
0005433399367	13518	Economy	12200.00
0005435732598	13518	Economy	12200.00
0005433399357	13518	Economy	12200.00
0005433399348	13518	Economy	12200.00
0005433399370	13518	Economy	12200.00
0005433399378	13518	Economy	12200.00
0005433399343	13518	Economy	12200.00
0005435732568	13518	Economy	12200.00
0005433399366	13518	Economy	12200.00
0005433399354	13518	Economy	12200.00
0005433399359	13518	Economy	12200.00
0005433399358	13518	Economy	12200.00
0005433399356	13518	Economy	12200.00
0005433399355	13518	Economy	12200.00
0005433399361	13518	Economy	12200.00
0005433399380	13518	Economy	12200.00
0005433399376	13518	Economy	12200.00
0005433399363	13518	Economy	12200.00
0005433399371	13518	Economy	12200.00
0005435732604	13518	Economy	12200.00
0005433399362	13518	Economy	12200.00
0005433399379	13518	Economy	12200.00
0005433399341	13518	Economy	12200.00
0005433399345	13518	Economy	12200.00
0005433399372	13518	Economy	12200.00
0005433399344	13518	Economy	12200.00
0005433399377	13518	Economy	12200.00
0005433399351	13518	Economy	12200.00
0005435732585	13518	Economy	12200.00
0005435732547	13518	Economy	12200.00
0005433399360	13518	Economy	12200.00
0005433399349	13518	Economy	12200.00
0005433399350	13518	Economy	12200.00
0005433399375	13518	Economy	12200.00
0005433399353	13518	Economy	12200.00
0005435732538	13518	Economy	12200.00
0005433399374	13518	Economy	12200.00
0005433399368	13518	Economy	12200.00
0005435732546	13518	Economy	12200.00
0005435732569	13518	Economy	12200.00
0005435732671	19410	Business	36600.00
0005433398905	19410	Business	36600.00
0005433398771	19410	Business	36600.00
0005433399116	19410	Business	36600.00
0005433398785	19410	Business	36600.00
0005435732684	19410	Business	36600.00
0005433399025	19410	Business	36600.00
0005435732680	19410	Business	36600.00
0005433399086	19410	Business	36600.00
0005433399014	19410	Business	36600.00
0005435732686	19410	Economy	12200.00
0005433399165	19410	Economy	12200.00
0005433399092	19410	Economy	12200.00
0005432297349	19410	Economy	12200.00
0005435732685	19410	Economy	13400.00
0005435732681	19410	Economy	13400.00
0005435732677	19410	Economy	13400.00
0005433399098	19410	Economy	13400.00
0005433398968	19410	Economy	12200.00
0005433398923	19410	Economy	12200.00
0005433399160	19410	Economy	12200.00
0005433398932	19410	Economy	12200.00
0005435732676	19410	Economy	12200.00
0005435725758	19410	Economy	12200.00
0005433398931	19410	Economy	12200.00
0005433398770	19410	Economy	12200.00
0005435732678	19410	Economy	12200.00
0005433399093	19410	Economy	12200.00
0005435732673	19410	Economy	12200.00
0005433399048	19410	Economy	12200.00
0005433399024	19410	Economy	12200.00
0005433398797	19410	Economy	12200.00
0005433398990	19410	Economy	12200.00
0005433398881	19410	Economy	12200.00
0005433399185	19410	Economy	12200.00
0005433398882	19410	Economy	12200.00
0005433399041	19410	Economy	12200.00
0005433399030	19410	Economy	12200.00
0005433398930	19410	Economy	12200.00
0005433399040	19410	Economy	12200.00
0005433398904	19410	Economy	12200.00
0005435732672	19410	Economy	12200.00
0005435732675	19410	Economy	12200.00
0005433398796	19410	Economy	12200.00
0005433399159	19410	Economy	12200.00
0005435725760	19410	Economy	12200.00
0005433399158	19410	Economy	12200.00
0005435732670	19410	Economy	12200.00
0005433399141	19410	Economy	12200.00
0005435732682	19410	Economy	12200.00
0005435725759	19410	Economy	12200.00
0005433398969	19410	Economy	12200.00
0005435725761	19410	Economy	12200.00
0005433399026	19410	Economy	12200.00
0005433398909	19410	Economy	12200.00
0005435732674	19410	Economy	12200.00
0005433399027	19410	Economy	12200.00
0005433398880	19410	Economy	12200.00
0005435732683	19410	Economy	12200.00
0005433399152	19410	Economy	12200.00
0005433398991	19410	Economy	12200.00
0005435732679	19410	Economy	12200.00
0005433399105	19410	Economy	12200.00
0005433399031	19410	Economy	12200.00
0005433399001	19410	Economy	12200.00
0005433398992	19410	Economy	12200.00
0005433398933	19410	Economy	12200.00
0005433398786	19410	Economy	12200.00
0005433399006	19410	Economy	12200.00
0005435925689	13157	Business	11300.00
0005435070092	13157	Business	11300.00
0005435070243	13157	Business	11300.00
0005435069854	13157	Business	11300.00
0005435070002	13157	Business	11300.00
0005435925674	13157	Business	11300.00
0005435070021	13157	Business	11300.00
0005435069992	13157	Economy	3800.00
0005435069899	13157	Economy	3800.00
0005435069880	13157	Economy	3800.00
0005435925675	13157	Economy	3800.00
0005435925685	13157	Economy	3800.00
0005435069853	13157	Economy	4100.00
0005435070001	13157	Economy	4100.00
0005435069648	13157	Economy	4100.00
0005435069931	13157	Economy	4100.00
0005435070093	13157	Economy	3800.00
0005435925688	13157	Economy	3800.00
0005435069813	13157	Economy	3800.00
0005435925680	13157	Economy	3800.00
0005435070141	13157	Economy	3800.00
0005435070034	13157	Economy	3800.00
0005435925673	13157	Economy	3800.00
0005435925686	13157	Economy	3800.00
0005435925672	13157	Economy	3800.00
0005435925676	13157	Economy	3800.00
0005435925684	13157	Economy	3800.00
0005435070022	13157	Economy	3800.00
0005435070140	13157	Economy	3800.00
0005435069973	13157	Economy	3800.00
0005435070020	13157	Economy	3800.00
0005435925678	13157	Economy	3800.00
0005435069938	13157	Economy	3800.00
0005435069868	13157	Economy	3800.00
0005435925687	13157	Economy	3800.00
0005435925677	13157	Economy	3800.00
0005435070129	13157	Economy	3800.00
0005435069967	13157	Economy	3800.00
0005435925679	13157	Economy	3800.00
0005435069969	13157	Economy	3800.00
0005435925671	13157	Economy	3800.00
0005435069840	13157	Economy	3800.00
0005435925682	13157	Economy	3800.00
0005435069895	13157	Economy	3800.00
0005435925670	13157	Economy	3800.00
0005435069955	13157	Economy	3800.00
0005435925690	13157	Economy	3800.00
0005435069986	13157	Economy	3800.00
0005435070016	13157	Economy	3800.00
0005435069881	13157	Economy	3800.00
0005435070056	13157	Economy	3800.00
0005435925683	13157	Economy	3800.00
0005435069999	13157	Economy	3800.00
0005435069937	13157	Economy	3800.00
0005435069968	13157	Economy	3800.00
0005435070003	13157	Economy	3800.00
0005435070057	13157	Economy	3800.00
0005435070128	13157	Economy	3800.00
0005435070025	13157	Economy	3800.00
0005435925681	13157	Economy	3800.00
0005435069647	13157	Economy	3800.00
0005435070263	13157	Economy	3800.00
0005435069894	13157	Economy	3800.00
0005435070048	13157	Economy	3800.00
0005435069717	13157	Economy	3800.00
0005435070105	13157	Economy	3800.00
0005435069814	13157	Economy	3800.00
0005435070439	15510	Business	11300.00
0005435070442	15510	Business	11300.00
0005435070434	15510	Business	11300.00
0005435070437	15510	Business	11300.00
0005435925557	15510	Business	11300.00
0005435070449	15510	Business	11300.00
0005435925518	15510	Business	11300.00
0005435925554	15510	Business	11300.00
0005435925576	15510	Business	11300.00
0005435925519	15510	Economy	3800.00
0005435070448	15510	Economy	3800.00
0005435925556	15510	Economy	3800.00
0005435925541	15510	Economy	3800.00
0005435070454	15510	Economy	3800.00
0005435070426	15510	Economy	3800.00
0005435925564	15510	Economy	3800.00
0005435925529	15510	Economy	3800.00
0005435070427	15510	Economy	4100.00
0005435070463	15510	Economy	4100.00
0005435925545	15510	Economy	4100.00
0005435070447	15510	Economy	3800.00
0005435070440	15510	Economy	3800.00
0005435070455	15510	Economy	3800.00
0005435925548	15510	Economy	3800.00
0005435070436	15510	Economy	3800.00
0005435070450	15510	Economy	3800.00
0005435070457	15510	Economy	3800.00
0005435925549	15510	Economy	3800.00
0005435070453	15510	Economy	3800.00
0005435070429	15510	Economy	3800.00
0005435070438	15510	Economy	3800.00
0005435070433	15510	Economy	3800.00
0005435070435	15510	Economy	3800.00
0005435925499	15510	Economy	3800.00
0005435925530	15510	Economy	3800.00
0005435070460	15510	Economy	3800.00
0005435925522	15510	Economy	3800.00
0005435070444	15510	Economy	3800.00
0005435925565	15510	Economy	3800.00
0005435925510	15510	Economy	3800.00
0005435070452	15510	Economy	3800.00
0005435070459	15510	Economy	3800.00
0005435070464	15510	Economy	3800.00
0005435925511	15510	Economy	3800.00
0005435070441	15510	Economy	3800.00
0005435070461	15510	Economy	3800.00
0005435925540	15510	Economy	3800.00
0005435070456	15510	Economy	3800.00
0005435070451	15510	Economy	3800.00
0005435070462	15510	Economy	3800.00
0005435070443	15510	Economy	3800.00
0005435070431	15510	Economy	3800.00
0005435070458	15510	Economy	3800.00
0005435925553	15510	Economy	3800.00
0005435070445	15510	Economy	3800.00
0005435925555	15510	Economy	3800.00
0005435070446	15510	Economy	3800.00
0005435070432	15510	Economy	3800.00
0005435070428	15510	Economy	3800.00
0005435070430	15510	Economy	3800.00
0005433407702	29498	Economy	27100.00
0005435808409	29498	Economy	27100.00
0005435808415	29498	Economy	24700.00
0005433407705	29498	Economy	24700.00
0005433407703	29498	Economy	24700.00
0005433407706	29498	Economy	24700.00
0005435808408	29498	Economy	24700.00
0005435808393	29498	Economy	24700.00
0005435808399	29498	Economy	24700.00
0005435808401	29498	Economy	24700.00
0005435808426	29498	Economy	24700.00
0005435808407	29498	Economy	24700.00
0005435808427	29498	Economy	24700.00
0005435808440	29498	Economy	24700.00
0005433407704	29498	Economy	24700.00
0005435808417	29498	Economy	24700.00
0005435808361	29498	Economy	24700.00
0005435808398	29498	Economy	24700.00
0005435808416	29498	Economy	24700.00
0005435808404	29498	Economy	24700.00
0005433407701	29498	Economy	24700.00
0005435808402	29498	Economy	24700.00
0005435808439	29498	Economy	24700.00
0005435808400	29498	Economy	24700.00
0005434756993	10733	Business	61300.00
0005434757243	10733	Business	61300.00
0005434757174	10733	Business	61300.00
0005434215798	10733	Business	61300.00
0005434757164	10733	Business	61300.00
0005434215808	10733	Business	61300.00
0005434757428	10733	Business	61300.00
0005434757098	10733	Business	61300.00
0005434757196	10733	Business	61300.00
0005434215809	10733	Business	61300.00
0005434215811	10733	Business	61300.00
0005434215799	10733	Business	61300.00
0005434215784	10733	Economy	20400.00
0005434757189	10733	Economy	20400.00
0005434757234	10733	Economy	20400.00
0005434757249	10733	Economy	20400.00
0005434757190	10733	Economy	20400.00
0005434215795	10733	Economy	20400.00
0005434215803	10733	Economy	20400.00
0005434757210	10733	Economy	20400.00
0005434215804	10733	Economy	22500.00
0005434757261	10733	Economy	22500.00
0005434215812	10733	Economy	22500.00
0005434757142	10733	Economy	22500.00
0005434215792	10733	Economy	20400.00
0005434757328	10733	Economy	20400.00
0005434215807	10733	Economy	20400.00
0005434215786	10733	Economy	20400.00
0005434756979	10733	Economy	20400.00
0005434215785	10733	Economy	20400.00
0005434756992	10733	Economy	20400.00
0005434215779	10733	Economy	20400.00
0005434757148	10733	Economy	20400.00
0005434215791	10733	Economy	20400.00
0005434757312	10733	Economy	20400.00
0005434757188	10733	Economy	20400.00
0005434757201	10733	Economy	20400.00
0005434215782	10733	Economy	20400.00
0005434215801	10733	Economy	20400.00
0005434215793	10733	Economy	20400.00
0005434215783	10733	Economy	20400.00
0005434215796	10733	Economy	20400.00
0005434757231	10733	Economy	20400.00
0005434215788	10733	Economy	20400.00
0005434215806	10733	Economy	20400.00
0005434215787	10733	Economy	20400.00
0005434215776	10733	Economy	20400.00
0005434215790	10733	Economy	20400.00
0005434757139	10733	Economy	20400.00
0005434757230	10733	Economy	20400.00
0005434757080	10733	Economy	20400.00
0005434757175	10733	Economy	20400.00
0005434757198	10733	Economy	20400.00
0005434215777	10733	Economy	20400.00
0005434757200	10733	Economy	20400.00
0005434215802	10733	Economy	20400.00
0005434215775	10733	Economy	20400.00
0005434215810	10733	Economy	20400.00
0005434215778	10733	Economy	20400.00
0005434757187	10733	Economy	20400.00
0005434215789	10733	Economy	20400.00
0005434757047	10733	Economy	20400.00
0005434757408	10733	Economy	20400.00
0005434757361	10733	Economy	20400.00
0005434215781	10733	Economy	20400.00
0005434215805	10733	Economy	20400.00
0005434215780	10733	Economy	20400.00
0005434757199	10733	Economy	20400.00
0005434757290	10733	Economy	20400.00
0005434757046	10733	Economy	20400.00
0005434215794	10733	Economy	20400.00
0005434757143	10733	Economy	20400.00
0005434757260	10733	Economy	20400.00
0005434757233	10733	Economy	20400.00
0005434757271	10733	Economy	20400.00
0005434757327	10733	Economy	20400.00
0005434757079	10733	Economy	20400.00
0005434215800	10733	Economy	20400.00
0005434757209	10733	Economy	20400.00
0005434215797	10733	Economy	20400.00
0005434757554	28657	Business	61300.00
0005434215316	28657	Business	61300.00
0005434215458	28657	Business	61300.00
0005434757546	28657	Business	61300.00
0005434215224	28657	Business	61300.00
0005434215344	28657	Business	61300.00
0005434215431	28657	Business	61300.00
0005434757562	28657	Business	61300.00
0005434757551	28657	Business	61300.00
0005434757558	28657	Business	61300.00
0005434757528	28657	Economy	20400.00
0005434215329	28657	Economy	20400.00
0005434757536	28657	Economy	20400.00
0005434757555	28657	Economy	20400.00
0005434215171	28657	Economy	20400.00
0005434215342	28657	Economy	20400.00
0005434215170	28657	Economy	20400.00
0005434757557	28657	Economy	20400.00
0005434757544	28657	Economy	20400.00
0005434215223	28657	Economy	20400.00
0005434757530	28657	Economy	22500.00
0005434757541	28657	Economy	22500.00
0005434215232	28657	Economy	22500.00
0005434215191	28657	Economy	20400.00
0005434215462	28657	Economy	20400.00
0005434757537	28657	Economy	20400.00
0005434757552	28657	Economy	20400.00
0005434757526	28657	Economy	20400.00
0005434757564	28657	Economy	20400.00
0005434215346	28657	Economy	20400.00
0005434215447	28657	Economy	20400.00
0005434757538	28657	Economy	20400.00
0005434757532	28657	Economy	20400.00
0005434215490	28657	Economy	20400.00
0005434757561	28657	Economy	20400.00
0005434757539	28657	Economy	20400.00
0005434215233	28657	Economy	20400.00
0005434757521	28657	Economy	20400.00
0005434757542	28657	Economy	20400.00
0005434215432	28657	Economy	20400.00
0005434757565	28657	Economy	20400.00
0005434757533	28657	Economy	20400.00
0005434757543	28657	Economy	20400.00
0005434215461	28657	Economy	20400.00
0005434757535	28657	Economy	20400.00
0005434757553	28657	Economy	20400.00
0005434757560	28657	Economy	20400.00
0005434215435	28657	Economy	20400.00
0005434757563	28657	Economy	20400.00
0005434757524	28657	Economy	20400.00
0005434757550	28657	Economy	20400.00
0005434757549	28657	Economy	20400.00
0005434215225	28657	Economy	20400.00
0005434757525	28657	Economy	20400.00
0005434215230	28657	Economy	20400.00
0005434757547	28657	Economy	20400.00
0005434215411	28657	Economy	20400.00
0005434215393	28657	Economy	20400.00
0005434757545	28657	Economy	20400.00
0005434757523	28657	Economy	20400.00
0005434757522	28657	Economy	20400.00
0005434757527	28657	Economy	20400.00
0005434215533	28657	Economy	20400.00
0005434757531	28657	Economy	20400.00
0005434215231	28657	Economy	20400.00
0005434757529	28657	Economy	20400.00
0005434215434	28657	Economy	20400.00
0005434215446	28657	Economy	20400.00
0005434215261	28657	Economy	20400.00
0005434215343	28657	Economy	20400.00
0005434757534	28657	Economy	20400.00
0005434215202	28657	Economy	20400.00
0005434757540	28657	Economy	20400.00
0005434757548	28657	Economy	20400.00
0005434215239	28657	Economy	20400.00
0005434757556	28657	Economy	20400.00
0005434757559	28657	Economy	20400.00
0005435041541	5433	Business	29500.00
0005435041526	5433	Business	29500.00
0005435041564	5433	Business	29500.00
0005435041527	5433	Business	29500.00
0005432125650	5433	Business	29500.00
0005435041538	5433	Business	29500.00
0005434229778	5433	Business	29500.00
0005434229850	5433	Business	29500.00
0005434229889	5433	Business	29500.00
0005434229895	5433	Economy	9800.00
0005435041523	5433	Economy	9800.00
0005435041546	5433	Economy	9800.00
0005435377910	5433	Economy	9800.00
0005434229767	5433	Economy	9800.00
0005435043307	5433	Economy	9800.00
0005435007668	5433	Economy	9800.00
0005435041568	5433	Economy	9800.00
0005434229883	5433	Economy	9800.00
0005435377909	5433	Economy	9800.00
0005435007671	5433	Economy	9800.00
0005434229775	5433	Economy	9800.00
0005435007659	5433	Economy	9800.00
0005435041559	5433	Economy	9800.00
0005435377906	5433	Economy	9800.00
0005435041576	5433	Economy	9800.00
0005435041550	5433	Economy	9800.00
0005435041574	5433	Economy	9800.00
0005435041531	5433	Economy	9800.00
0005434229856	5433	Economy	9800.00
0005435007665	5433	Economy	9800.00
0005435041553	5433	Economy	9800.00
0005435041530	5433	Economy	9800.00
0005435041552	5433	Economy	9800.00
0005434229662	5433	Economy	9800.00
0005435041575	5433	Economy	9800.00
0005435007660	5433	Economy	9800.00
0005435377914	5433	Economy	9800.00
0005435377911	5433	Economy	9800.00
0005435041557	5433	Economy	9800.00
0005435043306	5433	Economy	9800.00
0005434229700	5433	Economy	9800.00
0005435041545	5433	Economy	9800.00
0005435377919	5433	Economy	9800.00
0005435041528	5433	Economy	9800.00
0005435042929	5433	Economy	9800.00
0005435041558	5433	Economy	9800.00
0005435041547	5433	Economy	9800.00
0005435041571	5433	Economy	10800.00
0005432125651	5433	Economy	10800.00
0005435041543	5433	Economy	10800.00
0005434229894	5433	Economy	10800.00
0005435041549	5433	Economy	10800.00
0005435007667	5433	Economy	10800.00
0005435041548	5433	Economy	9800.00
0005432125652	5433	Economy	9800.00
0005435041562	5433	Economy	9800.00
0005434229717	5433	Economy	9800.00
0005435041573	5433	Economy	9800.00
0005435041534	5433	Economy	9800.00
0005435041532	5433	Economy	9800.00
0005434229718	5433	Economy	9800.00
0005435041537	5433	Economy	9800.00
0005435007657	5433	Economy	9800.00
0005435041556	5433	Economy	9800.00
0005435007674	5433	Economy	9800.00
0005435041572	5433	Economy	9800.00
0005435377918	5433	Economy	9800.00
0005434229744	5433	Economy	9800.00
0005435007664	5433	Economy	9800.00
0005435007666	5433	Economy	9800.00
0005435041567	5433	Economy	9800.00
0005435007675	5433	Economy	9800.00
0005435007658	5433	Economy	9800.00
0005435007663	5433	Economy	9800.00
0005432125653	5433	Economy	9800.00
0005435041563	5433	Economy	9800.00
0005435041525	5433	Economy	9800.00
0005434229699	5433	Economy	9800.00
0005435041569	5433	Economy	9800.00
0005432125649	5433	Economy	9800.00
0005435041529	5433	Economy	9800.00
0005435041539	5433	Economy	9800.00
0005435007669	5433	Economy	9800.00
0005435007656	5433	Economy	9800.00
0005435041565	5433	Economy	9800.00
0005435041542	5433	Economy	9800.00
0005434229784	5433	Economy	9800.00
0005435041570	5433	Economy	9800.00
0005435041524	5433	Economy	9800.00
0005435042932	5433	Economy	9800.00
0005435007672	5433	Economy	9800.00
0005435007661	5433	Economy	9800.00
0005435042933	5433	Economy	9800.00
0005434229695	5433	Economy	9800.00
0005434229766	5433	Economy	9800.00
0005435041535	5433	Economy	9800.00
0005435041544	5433	Economy	9800.00
0005434229838	5433	Economy	9800.00
0005435041555	5433	Economy	9800.00
0005435042930	5433	Economy	9800.00
0005435007673	5433	Economy	9800.00
0005434229721	5433	Economy	9800.00
0005435042931	5433	Economy	9800.00
0005434229743	5433	Economy	9800.00
0005434229777	5433	Economy	9800.00
0005435041551	5433	Economy	9800.00
0005435043308	5433	Economy	9800.00
0005435041554	5433	Economy	9800.00
0005434229832	5433	Economy	9800.00
0005435041561	5433	Economy	9800.00
0005434229807	5433	Economy	9800.00
0005435041536	5433	Economy	9800.00
0005435377907	5433	Economy	9800.00
0005435041560	5433	Economy	9800.00
0005434229776	5433	Economy	9800.00
0005435377908	5433	Economy	9800.00
0005435041566	5433	Economy	9800.00
0005434229873	5433	Economy	9800.00
0005435007670	5433	Economy	9800.00
0005435041533	5433	Economy	9800.00
0005435041540	5433	Economy	9800.00
0005435007662	5433	Economy	9800.00
0005435041006	12959	Business	29500.00
0005435041043	12959	Business	29500.00
0005435040950	12959	Business	29500.00
0005432304505	12959	Business	29500.00
0005435041154	12959	Business	29500.00
0005435041108	12959	Business	29500.00
0005435040980	12959	Business	29500.00
0005435007341	12959	Business	29500.00
0005435041115	12959	Business	29500.00
0005435041057	12959	Business	29500.00
0005435007572	12959	Business	29500.00
0005435041111	12959	Business	29500.00
0005434229989	12959	Economy	9800.00
0005435007500	12959	Economy	9800.00
0005435007476	12959	Economy	9800.00
0005434229991	12959	Economy	9800.00
0005434229985	12959	Economy	9800.00
0005435040830	12959	Economy	9800.00
0005435040954	12959	Economy	9800.00
0005435041300	12959	Economy	9800.00
0005432304506	12959	Economy	9800.00
0005435041155	12959	Economy	9800.00
0005435041093	12959	Economy	9800.00
0005435007447	12959	Economy	9800.00
0005434229983	12959	Economy	9800.00
0005435040630	12959	Economy	9800.00
0005435007373	12959	Economy	9800.00
0005435041094	12959	Economy	9800.00
0005435040791	12959	Economy	9800.00
0005435040779	12959	Economy	9800.00
0005434229979	12959	Economy	9800.00
0005435007512	12959	Economy	9800.00
0005434229994	12959	Economy	9800.00
0005435041266	12959	Economy	9800.00
0005435040951	12959	Economy	9800.00
0005435041396	12959	Economy	9800.00
0005435007465	12959	Economy	9800.00
0005435041022	12959	Economy	9800.00
0005435007449	12959	Economy	9800.00
0005435007552	12959	Economy	9800.00
0005435007501	12959	Economy	9800.00
0005435040941	12959	Economy	9800.00
0005435042893	12959	Economy	9800.00
0005435041110	12959	Economy	9800.00
0005435007342	12959	Economy	9800.00
0005435041036	12959	Economy	9800.00
0005435007541	12959	Economy	9800.00
0005435007362	12959	Economy	9800.00
0005434229993	12959	Economy	9800.00
0005435040976	12959	Economy	9800.00
0005435041238	12959	Economy	9800.00
0005435040744	12959	Economy	10800.00
0005435007421	12959	Economy	10800.00
0005435041297	12959	Economy	10800.00
0005435040726	12959	Economy	10800.00
0005435007516	12959	Economy	10800.00
0005434229981	12959	Economy	9800.00
0005435007505	12959	Economy	9800.00
0005434229980	12959	Economy	9800.00
0005435041040	12959	Economy	9800.00
0005435040841	12959	Economy	9800.00
0005435041059	12959	Economy	9800.00
0005434229988	12959	Economy	9800.00
0005435041189	12959	Economy	9800.00
0005435041114	12959	Economy	9800.00
0005435041058	12959	Economy	9800.00
0005434229992	12959	Economy	9800.00
0005434229978	12959	Economy	9800.00
0005435041372	12959	Economy	9800.00
0005435007374	12959	Economy	9800.00
0005435041128	12959	Economy	9800.00
0005435007559	12959	Economy	9800.00
0005435040964	12959	Economy	9800.00
0005435007477	12959	Economy	9800.00
0005434229990	12959	Economy	9800.00
0005435040961	12959	Economy	9800.00
0005435041060	12959	Economy	9800.00
0005434229982	12959	Economy	9800.00
0005435040989	12959	Economy	9800.00
0005435040944	12959	Economy	9800.00
0005435040833	12959	Economy	9800.00
0005435041042	12959	Economy	9800.00
0005435007363	12959	Economy	9800.00
0005435041086	12959	Economy	9800.00
0005435041188	12959	Economy	9800.00
0005435041138	12959	Economy	9800.00
0005435041267	12959	Economy	9800.00
0005435007542	12959	Economy	9800.00
0005435041019	12959	Economy	9800.00
0005435043297	12959	Economy	9800.00
0005435040790	12959	Economy	9800.00
0005435041066	12959	Economy	9800.00
0005435041237	12959	Economy	9800.00
0005435040879	12959	Economy	9800.00
0005434229987	12959	Economy	9800.00
0005435041236	12959	Economy	9800.00
0005435040960	12959	Economy	9800.00
0005435007551	12959	Economy	9800.00
0005435040873	12959	Economy	9800.00
0005435042892	12959	Economy	9800.00
0005434229986	12959	Economy	9800.00
0005435007466	12959	Economy	9800.00
0005434229984	12959	Economy	9800.00
0005435040939	12959	Economy	9800.00
0005435040878	12959	Economy	9800.00
0005435040880	12959	Economy	9800.00
0005435041037	12959	Economy	9800.00
0005435007456	12959	Economy	9800.00
0005435041186	12959	Economy	9800.00
0005435041010	12959	Economy	9800.00
0005432304504	12959	Economy	9800.00
0005435007485	12959	Economy	9800.00
0005435042894	12959	Economy	9800.00
0005435041129	12959	Economy	9800.00
0005435041355	12959	Economy	9800.00
0005435041007	12959	Economy	9800.00
0005435041005	12959	Economy	9800.00
0005435040784	12959	Economy	9800.00
0005435007455	12959	Economy	9800.00
0005435007557	12959	Economy	9800.00
0005435007408	12959	Economy	9800.00
0005435041018	12959	Economy	9800.00
0005435041030	12959	Economy	9800.00
0005435040842	12959	Economy	9800.00
0005434411893	14907	Business	52900.00
0005435902994	14907	Business	52900.00
0005435903062	14907	Business	52900.00
0005434427392	14907	Business	52900.00
0005432188695	14907	Business	52900.00
0005434427400	14907	Business	52900.00
0005435554273	14907	Business	52900.00
0005434411891	14907	Business	52900.00
0005434427399	14907	Economy	17600.00
0005434427383	14907	Economy	17600.00
0005434427381	14907	Economy	17600.00
0005434427378	14907	Economy	17600.00
0005435554281	14907	Economy	17600.00
0005434427380	14907	Economy	19400.00
0005434427374	14907	Economy	19400.00
0005435554280	14907	Economy	17600.00
0005434427391	14907	Economy	17600.00
0005434427384	14907	Economy	17600.00
0005432188698	14907	Economy	17600.00
0005435554251	14907	Economy	17600.00
0005435903057	14907	Economy	17600.00
0005434427402	14907	Economy	17600.00
0005434427403	14907	Economy	17600.00
0005434427398	14907	Economy	17600.00
0005435903014	14907	Economy	17600.00
0005435903070	14907	Economy	17600.00
0005435903071	14907	Economy	17600.00
0005434427388	14907	Economy	17600.00
0005432188697	14907	Economy	17600.00
0005435902987	14907	Economy	17600.00
0005435903001	14907	Economy	17600.00
0005435902969	14907	Economy	17600.00
0005434427375	14907	Economy	17600.00
0005435903018	14907	Economy	17600.00
0005434427389	14907	Economy	17600.00
0005434427382	14907	Economy	17600.00
0005434427393	14907	Economy	17600.00
0005435903019	14907	Economy	17600.00
0005434427395	14907	Economy	17600.00
0005432188694	14907	Economy	17600.00
0005435902935	14907	Economy	17600.00
0005434427377	14907	Economy	17600.00
0005434411892	14907	Economy	17600.00
0005434427401	14907	Economy	17600.00
0005435554269	14907	Economy	17600.00
0005432188693	14907	Economy	17600.00
0005435903002	14907	Economy	17600.00
0005435903058	14907	Economy	17600.00
0005434427397	14907	Economy	17600.00
0005435903015	14907	Economy	17600.00
0005435903017	14907	Economy	17600.00
0005434427387	14907	Economy	17600.00
0005434427385	14907	Economy	17600.00
0005432188696	14907	Economy	17600.00
0005434427396	14907	Economy	17600.00
0005434427379	14907	Economy	17600.00
0005434427390	14907	Economy	17600.00
0005434427386	14907	Economy	17600.00
0005434427376	14907	Economy	17600.00
0005435554279	14907	Economy	17600.00
0005435554272	14907	Economy	17600.00
0005434427394	14907	Economy	17600.00
0005434427150	20194	Business	52900.00
0005434427056	20194	Business	52900.00
0005435903185	20194	Business	52900.00
0005435903187	20194	Business	52900.00
0005435554316	20194	Business	52900.00
0005434427155	20194	Business	52900.00
0005434427202	20194	Business	52900.00
0005434427094	20194	Business	52900.00
0005434427141	20194	Business	52900.00
0005434427156	20194	Economy	17600.00
0005434427012	20194	Economy	17600.00
0005435554319	20194	Economy	17600.00
0005435903195	20194	Economy	17600.00
0005435903183	20194	Economy	19400.00
0005434427154	20194	Economy	19400.00
0005435903184	20194	Economy	17600.00
0005434427249	20194	Economy	17600.00
0005434427115	20194	Economy	17600.00
0005434427053	20194	Economy	17600.00
0005434427151	20194	Economy	17600.00
0005434427270	20194	Economy	17600.00
0005435903190	20194	Economy	17600.00
0005434427054	20194	Economy	17600.00
0005435554318	20194	Economy	17600.00
0005435903192	20194	Economy	17600.00
0005434411854	20194	Economy	17600.00
0005435903191	20194	Economy	17600.00
0005434427057	20194	Economy	17600.00
0005432059560	20194	Economy	17600.00
0005434427203	20194	Economy	17600.00
0005434427224	20194	Economy	17600.00
0005435903193	20194	Economy	17600.00
0005435903186	20194	Economy	17600.00
0005435903180	20194	Economy	17600.00
0005434427114	20194	Economy	17600.00
0005435903182	20194	Economy	17600.00
0005434427093	20194	Economy	17600.00
0005434426989	20194	Economy	17600.00
0005434427209	20194	Economy	17600.00
0005435903189	20194	Economy	17600.00
0005435903188	20194	Economy	17600.00
0005435903181	20194	Economy	17600.00
0005434427208	20194	Economy	17600.00
0005434427011	20194	Economy	17600.00
0005434427248	20194	Economy	17600.00
0005435554317	20194	Economy	17600.00
0005435903194	20194	Economy	17600.00
0005434523815	28014	Economy	35600.00
0005432462569	28014	Economy	35600.00
0005432462571	28014	Economy	35600.00
0005434523816	28014	Economy	35600.00
0005434523820	28014	Economy	35600.00
0005434523806	28014	Economy	35600.00
0005432462572	28014	Economy	35600.00
0005434523823	28014	Economy	35600.00
0005434523821	28014	Economy	35600.00
0005434523822	28014	Economy	35600.00
0005432462573	28014	Economy	35600.00
0005432462570	28014	Economy	35600.00
0005432462568	28014	Economy	35600.00
0005434523814	28014	Economy	35600.00
0005433435282	26546	Business	18500.00
0005433435144	26546	Business	18500.00
0005433435242	26546	Business	18500.00
0005435983524	26546	Business	18500.00
0005435983516	26546	Business	18500.00
0005433435163	26546	Business	18500.00
0005435983507	26546	Business	18500.00
0005433435066	26546	Business	18500.00
0005435983534	26546	Business	18500.00
0005434273103	26546	Business	18500.00
0005433435261	26546	Economy	6200.00
0005432300415	26546	Economy	6200.00
0005433435231	26546	Economy	6200.00
0005432300419	26546	Economy	6200.00
0005435983545	26546	Economy	6200.00
0005435983537	26546	Economy	6200.00
0005433435151	26546	Economy	6200.00
0005434270249	26546	Economy	6200.00
0005432300416	26546	Economy	6200.00
0005433435260	26546	Economy	6800.00
0005433435143	26546	Economy	6800.00
0005433435218	26546	Economy	6800.00
0005434273108	26546	Economy	6800.00
0005433435197	26546	Economy	6800.00
0005435983505	26546	Economy	6200.00
0005435983499	26546	Economy	6200.00
0005433435142	26546	Economy	6200.00
0005434270250	26546	Economy	6200.00
0005433435286	26546	Economy	6200.00
0005433435185	26546	Economy	6200.00
0005435983538	26546	Economy	6200.00
0005435983511	26546	Economy	6200.00
0005433435243	26546	Economy	6200.00
0005435983502	26546	Economy	6200.00
0005435983503	26546	Economy	6200.00
0005433435239	26546	Economy	6200.00
0005433435217	26546	Economy	6200.00
0005435983512	26546	Economy	6200.00
0005435983508	26546	Economy	6200.00
0005435983526	26546	Economy	6200.00
0005435983539	26546	Economy	6200.00
0005435983515	26546	Economy	6200.00
0005435983540	26546	Economy	6200.00
0005435983543	26546	Economy	6200.00
0005435983519	26546	Economy	6200.00
0005435983544	26546	Economy	6200.00
0005433435162	26546	Economy	6200.00
0005435983514	26546	Economy	6200.00
0005433435189	26546	Economy	6200.00
0005435983501	26546	Economy	6200.00
0005435983504	26546	Economy	6200.00
0005435983500	26546	Economy	6200.00
0005435983536	26546	Economy	6200.00
0005435983535	26546	Economy	6200.00
0005435983522	26546	Economy	6200.00
0005433435152	26546	Economy	6200.00
0005435983521	26546	Economy	6200.00
0005435983523	26546	Economy	6200.00
0005435983530	26546	Economy	6200.00
0005435983525	26546	Economy	6200.00
0005435983532	26546	Economy	6200.00
0005434273102	26546	Economy	6200.00
0005433435045	26546	Economy	6200.00
0005435983509	26546	Economy	6200.00
0005435983513	26546	Economy	6200.00
0005435983531	26546	Economy	6200.00
0005435983520	26546	Economy	6200.00
0005432300420	26546	Economy	6200.00
0005435983517	26546	Economy	6200.00
0005433435202	26546	Economy	6200.00
0005433435232	26546	Economy	6200.00
0005433435240	26546	Economy	6200.00
0005433435044	26546	Economy	6200.00
0005435983498	26546	Economy	6200.00
0005432300417	26546	Economy	6200.00
0005433435226	26546	Economy	6200.00
0005435983510	26546	Economy	6200.00
0005433435196	26546	Economy	6200.00
0005435983542	26546	Economy	6200.00
0005435983527	26546	Economy	6200.00
0005435983518	26546	Economy	6200.00
0005435983528	26546	Economy	6200.00
0005435983533	26546	Economy	6200.00
0005433435241	26546	Economy	6200.00
0005433435281	26546	Economy	6200.00
0005432300418	26546	Economy	6200.00
0005435983541	26546	Economy	6200.00
0005433435098	26546	Economy	6200.00
0005435983529	26546	Economy	6200.00
0005435983506	26546	Economy	6200.00
0005433435449	26683	Business	18500.00
0005432051213	26683	Business	18500.00
0005435983130	26683	Business	18500.00
0005435983151	26683	Business	18500.00
0005435982973	26683	Business	18500.00
0005432051215	26683	Business	18500.00
0005433435448	26683	Business	18500.00
0005435983038	26683	Economy	6200.00
0005433435446	26683	Economy	6200.00
0005435983067	26683	Economy	6200.00
0005435983117	26683	Economy	6200.00
0005432051216	26683	Economy	6800.00
0005435983271	26683	Economy	6800.00
0005434269160	26683	Economy	6200.00
0005433435440	26683	Economy	6200.00
0005435983160	26683	Economy	6200.00
0005433435444	26683	Economy	6200.00
0005435983061	26683	Economy	6200.00
0005433435443	26683	Economy	6200.00
0005435983060	26683	Economy	6200.00
0005433435436	26683	Economy	6200.00
0005432051214	26683	Economy	6200.00
0005433435445	26683	Economy	6200.00
0005435982955	26683	Economy	6200.00
0005433435442	26683	Economy	6200.00
0005434269159	26683	Economy	6200.00
0005435982989	26683	Economy	6200.00
0005435983043	26683	Economy	6200.00
0005435983033	26683	Economy	6200.00
0005433435439	26683	Economy	6200.00
0005435983080	26683	Economy	6200.00
0005433435438	26683	Economy	6200.00
0005433435441	26683	Economy	6200.00
0005433435437	26683	Economy	6200.00
0005435983183	26683	Economy	6200.00
0005435983007	26683	Economy	6200.00
0005434271370	26683	Economy	6200.00
0005435983162	26683	Economy	6200.00
0005435982990	26683	Economy	6200.00
0005435983241	26683	Economy	6200.00
0005435983081	26683	Economy	6200.00
0005433435435	26683	Economy	6200.00
0005433435450	26683	Economy	6200.00
0005433435447	26683	Economy	6200.00
0005435983008	26683	Economy	6200.00
0005434271369	26683	Economy	6200.00
0005433435451	26683	Economy	6200.00
0005435983079	26683	Economy	6200.00
0005433686670	29267	Economy	21000.00
0005433686667	29267	Economy	21000.00
0005433686675	29267	Economy	19100.00
0005433689943	29267	Economy	19100.00
0005433689953	29267	Economy	19100.00
0005433686674	29267	Economy	19100.00
0005433689950	29267	Economy	19100.00
0005433689948	29267	Economy	19100.00
0005433686666	29267	Economy	19100.00
0005433686668	29267	Economy	19100.00
0005433686671	29267	Economy	19100.00
0005433689947	29267	Economy	19100.00
0005433686672	29267	Economy	19100.00
0005433686663	29267	Economy	19100.00
0005433689949	29267	Economy	19100.00
0005433689946	29267	Economy	19100.00
0005433686673	29267	Economy	19100.00
0005433689944	29267	Economy	19100.00
0005432858334	3166	Economy	11100.00
0005432858347	3166	Economy	11100.00
0005432584714	3166	Economy	11100.00
0005432584716	3166	Economy	10100.00
0005432584732	3166	Economy	10100.00
0005432216347	3166	Economy	10100.00
0005432584725	3166	Economy	10100.00
0005432216348	3166	Economy	10100.00
0005432858323	3166	Economy	10100.00
0005432216349	3166	Economy	10100.00
0005432858283	3166	Economy	10100.00
0005432584721	3166	Economy	10100.00
0005432858298	3166	Economy	10100.00
0005432216350	3166	Economy	10100.00
0005432584728	3166	Economy	10100.00
0005432584730	3166	Economy	10100.00
0005432584723	3166	Economy	10100.00
0005432584720	3166	Economy	10100.00
0005432858310	3166	Economy	10100.00
0005432858346	3166	Economy	10100.00
0005432584731	3166	Economy	10100.00
0005432584726	3166	Economy	10100.00
0005432584727	3166	Economy	10100.00
0005432584715	3166	Economy	10100.00
0005432584729	3166	Economy	10100.00
0005432858293	3166	Economy	10100.00
0005432858280	3166	Economy	10100.00
0005432584724	3166	Economy	10100.00
0005432584713	3166	Economy	10100.00
0005432584717	3166	Economy	10100.00
0005432584719	3166	Economy	10100.00
0005432584718	3166	Economy	10100.00
0005432584712	3166	Economy	10100.00
0005432858348	3166	Economy	10100.00
0005432584722	3166	Economy	10100.00
0005432858282	3166	Economy	10100.00
0005432584653	31511	Economy	11100.00
0005432584509	31511	Economy	11100.00
0005432584525	31511	Economy	11100.00
0005432584484	31511	Economy	11100.00
0005432584502	31511	Economy	10100.00
0005432584563	31511	Economy	10100.00
0005432584489	31511	Economy	10100.00
0005432584557	31511	Economy	10100.00
0005432858387	31511	Economy	10100.00
0005432584542	31511	Economy	10100.00
0005432858391	31511	Economy	10100.00
0005432584576	31511	Economy	10100.00
0005432584465	31511	Economy	10100.00
0005432584574	31511	Economy	10100.00
0005432584541	31511	Economy	10100.00
0005432858389	31511	Economy	10100.00
0005432584466	31511	Economy	10100.00
0005432584579	31511	Economy	10100.00
0005432584543	31511	Economy	10100.00
0005432858390	31511	Economy	10100.00
0005432584565	31511	Economy	10100.00
0005432584475	31511	Economy	10100.00
0005432584537	31511	Economy	10100.00
0005432858393	31511	Economy	10100.00
0005432584663	31511	Economy	10100.00
0005432584564	31511	Economy	10100.00
0005432584526	31511	Economy	10100.00
0005432584519	31511	Economy	10100.00
0005432584626	31511	Economy	10100.00
0005432584518	31511	Economy	10100.00
0005432858394	31511	Economy	10100.00
0005432584456	31511	Economy	10100.00
0005432584457	31511	Economy	10100.00
0005432858388	31511	Economy	10100.00
0005432584470	31511	Economy	10100.00
0005432584455	31511	Economy	10100.00
0005432584538	31511	Economy	10100.00
0005432584575	31511	Economy	10100.00
0005432584513	31511	Economy	10100.00
0005432858392	31511	Economy	10100.00
0005434943600	874	Economy	7500.00
0005433255225	874	Economy	7500.00
0005434943603	874	Economy	7500.00
0005433255224	874	Economy	7500.00
0005434943598	874	Economy	7500.00
0005434943602	874	Economy	7500.00
0005434943601	874	Economy	7500.00
0005433255227	874	Economy	7500.00
0005433255226	874	Economy	7500.00
0005434943597	874	Economy	7500.00
0005433255211	874	Economy	7500.00
0005434943599	874	Economy	7500.00
0005434943558	16203	Economy	7500.00
0005434943518	16203	Economy	7500.00
0005433255267	16203	Economy	7500.00
0005433255263	16203	Economy	7500.00
0005434943533	16203	Economy	7500.00
0005433255264	16203	Economy	7500.00
0005434943540	16203	Economy	7500.00
0005434943532	16203	Economy	7500.00
0005434943470	16203	Economy	7500.00
0005434943528	16203	Economy	7500.00
0005433255265	16203	Economy	7500.00
0005434943557	16203	Economy	7500.00
0005434943552	16203	Economy	7500.00
0005434943529	16203	Economy	7500.00
0005433255266	16203	Economy	7500.00
0005434943530	16203	Economy	7500.00
0005434943517	16203	Economy	7500.00
0005434943531	16203	Economy	7500.00
0005433811665	14368	Economy	4400.00
0005433927535	14368	Economy	4400.00
0005433927536	14368	Economy	4400.00
0005433927534	14368	Economy	4400.00
0005435654285	21755	Business	9800.00
0005433368579	21755	Business	9800.00
0005433368510	21755	Business	9800.00
0005435654289	21755	Business	9800.00
0005433368695	21755	Business	9800.00
0005433368542	21755	Business	9800.00
0005435654265	21755	Business	9800.00
0005433368560	21755	Business	9800.00
0005435654255	21755	Business	9800.00
0005435654276	21755	Business	9800.00
0005433368396	21755	Business	9800.00
0005433368526	21755	Business	9800.00
0005433368540	21755	Economy	3300.00
0005435654256	21755	Economy	3300.00
0005433368457	21755	Economy	3300.00
0005435654280	21755	Economy	3300.00
0005433368663	21755	Economy	3300.00
0005435654295	21755	Economy	3300.00
0005435654261	21755	Economy	3300.00
0005435654283	21755	Economy	3300.00
0005433368702	21755	Economy	3300.00
0005433368524	21755	Economy	3300.00
0005435654277	21755	Economy	3600.00
0005433368525	21755	Economy	3600.00
0005435654297	21755	Economy	3600.00
0005435654271	21755	Economy	3600.00
0005435654274	21755	Economy	3600.00
0005433368653	21755	Economy	3300.00
0005435654262	21755	Economy	3300.00
0005433368559	21755	Economy	3300.00
0005433368499	21755	Economy	3300.00
0005433368652	21755	Economy	3300.00
0005435654284	21755	Economy	3300.00
0005433368701	21755	Economy	3300.00
0005435654259	21755	Economy	3300.00
0005435654279	21755	Economy	3300.00
0005433368694	21755	Economy	3300.00
0005435654291	21755	Economy	3300.00
0005433368643	21755	Economy	3300.00
0005435654294	21755	Economy	3300.00
0005435654287	21755	Economy	3300.00
0005435654293	21755	Economy	3300.00
0005433368644	21755	Economy	3300.00
0005435654264	21755	Economy	3300.00
0005435654286	21755	Economy	3300.00
0005435654250	21755	Economy	3300.00
0005435654278	21755	Economy	3300.00
0005435654299	21755	Economy	3300.00
0005433368639	21755	Economy	3300.00
0005433368565	21755	Economy	3300.00
0005435654253	21755	Economy	3300.00
0005435654296	21755	Economy	3300.00
0005433368659	21755	Economy	3300.00
0005433368512	21755	Economy	3300.00
0005435654266	21755	Economy	3300.00
0005435654252	21755	Economy	3300.00
0005433368397	21755	Economy	3300.00
0005433368658	21755	Economy	3300.00
0005435654292	21755	Economy	3300.00
0005435654260	21755	Economy	3300.00
0005435654275	21755	Economy	3300.00
0005433368593	21755	Economy	3300.00
0005433368737	21755	Economy	3300.00
0005433368468	21755	Economy	3300.00
0005435654288	21755	Economy	3300.00
0005433368511	21755	Economy	3300.00
0005435654251	21755	Economy	3300.00
0005435654273	21755	Economy	3300.00
0005435654257	21755	Economy	3300.00
0005435654267	21755	Economy	3300.00
0005435654290	21755	Economy	3300.00
0005433368657	21755	Economy	3300.00
0005433368527	21755	Economy	3300.00
0005435654272	21755	Economy	3300.00
0005435654281	21755	Economy	3300.00
0005435654258	21755	Economy	3300.00
0005433368614	21755	Economy	3300.00
0005435654254	21755	Economy	3300.00
0005433368431	21755	Economy	3300.00
0005433368654	21755	Economy	3300.00
0005435654263	21755	Economy	3300.00
0005433368578	21755	Economy	3300.00
0005435654282	21755	Economy	3300.00
0005433368615	21755	Economy	3300.00
0005433368696	21755	Economy	3300.00
0005435654268	21755	Economy	3300.00
0005435654269	21755	Economy	3300.00
0005435654298	21755	Economy	3300.00
0005433368493	21755	Economy	3300.00
0005433368494	21755	Economy	3300.00
0005433368537	21755	Economy	3300.00
0005433368509	21755	Economy	3300.00
0005433368541	21755	Economy	3300.00
0005433368669	21755	Economy	3300.00
0005435654270	21755	Economy	3300.00
0005433368498	21755	Economy	3300.00
0005433368458	21755	Economy	3300.00
0005433786039	9387	Business	186200.00
0005434270247	9387	Business	186200.00
0005433806345	9387	Business	186200.00
0005433786013	9387	Business	186200.00
0005433786001	9387	Business	186200.00
0005433786037	9387	Business	186200.00
0005433785994	9387	Business	186200.00
0005433786024	9387	Business	186200.00
0005434171380	9387	Business	186200.00
0005433786014	9387	Business	186200.00
0005433806324	9387	Business	186200.00
0005433806334	9387	Business	186200.00
0005432667512	9387	Business	186200.00
0005433785989	9387	Business	186200.00
0005433763596	9387	Business	186200.00
0005433786008	9387	Economy	68300.00
0005433806343	9387	Economy	62100.00
0005433786036	9387	Economy	62100.00
0005433786003	9387	Economy	62100.00
0005433785998	9387	Economy	62100.00
0005434273110	9387	Economy	62100.00
0005433806325	9387	Economy	62100.00
0005433786012	9387	Economy	62100.00
0005433806341	9387	Economy	62100.00
0005433785995	9387	Economy	62100.00
0005433785990	9387	Economy	62100.00
0005433785993	9387	Economy	62100.00
0005433806335	9387	Economy	62100.00
0005434151761	9387	Economy	62100.00
0005433806337	9387	Economy	62100.00
0005433786005	9387	Economy	62100.00
0005433786011	9387	Economy	62100.00
0005434151752	9387	Economy	62100.00
0005433786016	9387	Economy	62100.00
0005433785982	9387	Economy	62100.00
0005433763601	9387	Economy	62100.00
0005434171319	9387	Economy	62100.00
0005433763598	9387	Economy	62100.00
0005433786015	9387	Economy	62100.00
0005433786032	9387	Economy	62100.00
0005433806342	9387	Economy	62100.00
0005434151753	9387	Economy	62100.00
0005433785985	9387	Economy	62100.00
0005433806344	9387	Economy	62100.00
0005433786029	9387	Economy	62100.00
0005434171352	9387	Economy	62100.00
0005434270240	9387	Economy	62100.00
0005433786034	9387	Economy	62100.00
0005433786026	9387	Economy	62100.00
0005434270241	9387	Economy	62100.00
0005433785988	9387	Economy	62100.00
0005433806347	9387	Economy	62100.00
0005433786019	9387	Economy	62100.00
0005433806330	9387	Economy	62100.00
0005433786021	9387	Economy	62100.00
0005433806352	9387	Economy	62100.00
0005433786017	9387	Economy	62100.00
0005433785987	9387	Economy	62100.00
0005433806336	9387	Economy	62100.00
0005433806346	9387	Economy	62100.00
0005433786000	9387	Economy	62100.00
0005433786022	9387	Economy	62100.00
0005434171364	9387	Economy	62100.00
0005433806328	9387	Economy	62100.00
0005433786035	9387	Economy	62100.00
0005433786004	9387	Economy	62100.00
0005433785999	9387	Economy	62100.00
0005434171360	9387	Economy	62100.00
0005433785997	9387	Economy	62100.00
0005434171379	9387	Economy	62100.00
0005433786023	9387	Economy	62100.00
0005433786009	9387	Economy	62100.00
0005433786038	9387	Economy	62100.00
0005432665331	9387	Economy	62100.00
0005433806351	9387	Economy	62100.00
0005433785996	9387	Economy	68300.00
0005433786033	9387	Economy	68300.00
0005433785984	9387	Economy	62100.00
0005434270242	9387	Economy	62100.00
0005433785983	9387	Economy	62100.00
0005433806350	9387	Economy	62100.00
0005433786031	9387	Economy	62100.00
0005433786002	9387	Economy	62100.00
0005433806339	9387	Economy	62100.00
0005433806333	9387	Economy	62100.00
0005433786020	9387	Economy	62100.00
0005433806340	9387	Economy	62100.00
0005433785991	9387	Economy	62100.00
0005432657533	9387	Economy	62100.00
0005433763600	9387	Economy	62100.00
0005433786025	9387	Economy	62100.00
0005433786018	9387	Economy	62100.00
0005433806332	9387	Economy	62100.00
0005433786010	9387	Economy	62100.00
0005433806338	9387	Economy	62100.00
0005433806348	9387	Economy	62100.00
0005433763599	9387	Economy	62100.00
0005434270239	9387	Economy	62100.00
0005433785986	9387	Economy	62100.00
0005434171353	9387	Economy	62100.00
0005433785981	9387	Economy	62100.00
0005434151751	9387	Economy	62100.00
0005433806329	9387	Economy	62100.00
0005434270248	9387	Economy	62100.00
0005433806326	9387	Economy	62100.00
0005433786028	9387	Economy	62100.00
0005433806327	9387	Economy	62100.00
0005433785992	9387	Economy	62100.00
0005433786006	9387	Economy	62100.00
0005433806331	9387	Economy	62100.00
0005434151740	9387	Economy	62100.00
0005433786007	9387	Economy	62100.00
0005433806323	9387	Economy	62100.00
0005432657534	9387	Economy	62100.00
0005433763597	9387	Economy	62100.00
0005434171381	9387	Economy	62100.00
0005433806349	9387	Economy	62100.00
0005432667511	9387	Economy	62100.00
0005433786027	9387	Economy	62100.00
0005433786030	9387	Economy	62100.00
0005433763438	26271	Business	186200.00
0005432666418	26271	Business	186200.00
0005433785476	26271	Business	186200.00
0005433805967	26271	Business	186200.00
0005433785468	26271	Business	186200.00
0005433785739	26271	Business	186200.00
0005435270123	26271	Business	186200.00
0005433785709	26271	Business	186200.00
0005435270117	26271	Business	186200.00
0005433805974	26271	Business	186200.00
0005433763468	26271	Business	186200.00
0005433785545	26271	Business	186200.00
0005433785613	26271	Business	186200.00
0005434171449	26271	Business	186200.00
0005434171441	26271	Business	186200.00
0005434171447	26271	Business	186200.00
0005433763538	26271	Business	186200.00
0005434171443	26271	Business	186200.00
0005435270115	26271	Business	186200.00
0005435270110	26271	Business	186200.00
0005435270112	26271	Business	186200.00
0005433763452	26271	Business	186200.00
0005433806101	26271	Business	186200.00
0005433806009	26271	Business	186200.00
0005433805966	26271	Business	186200.00
0005434171439	26271	Business	186200.00
0005433785537	26271	Business	186200.00
0005433785595	26271	Economy	68300.00
0005433785572	26271	Economy	62100.00
0005433805851	26271	Economy	62100.00
0005433806197	26271	Economy	62100.00
0005435270108	26271	Economy	62100.00
0005434171448	26271	Economy	62100.00
0005434171445	26271	Economy	62100.00
0005434270262	26271	Economy	62100.00
0005433805852	26271	Economy	62100.00
0005433785502	26271	Economy	62100.00
0005434269158	26271	Economy	62100.00
0005434270264	26271	Economy	62100.00
0005433785629	26271	Economy	62100.00
0005433785480	26271	Economy	62100.00
0005433785553	26271	Economy	62100.00
0005433805855	26271	Economy	62100.00
0005434171446	26271	Economy	62100.00
0005433806013	26271	Economy	62100.00
0005433785681	26271	Economy	62100.00
0005433763487	26271	Economy	62100.00
0005433763539	26271	Economy	62100.00
0005433805914	26271	Economy	62100.00
0005433763363	26271	Economy	62100.00
0005433785477	26271	Economy	62100.00
0005433785571	26271	Economy	62100.00
0005433805951	26271	Economy	62100.00
0005433785503	26271	Economy	62100.00
0005435270119	26271	Economy	62100.00
0005434151784	26271	Economy	62100.00
0005432663067	26271	Economy	62100.00
0005435270126	26271	Economy	62100.00
0005432659747	26271	Economy	62100.00
0005433806045	26271	Economy	62100.00
0005433805856	26271	Economy	62100.00
0005433805994	26271	Economy	62100.00
0005434269157	26271	Economy	62100.00
0005433785611	26271	Economy	62100.00
0005433785649	26271	Economy	62100.00
0005432657499	26271	Economy	62100.00
0005433785690	26271	Economy	62100.00
0005433806113	26271	Economy	62100.00
0005433805898	26271	Economy	62100.00
0005433785536	26271	Economy	62100.00
0005433785465	26271	Economy	62100.00
0005433785682	26271	Economy	62100.00
0005433785612	26271	Economy	62100.00
0005433785723	26271	Economy	62100.00
0005435270116	26271	Economy	62100.00
0005433785623	26271	Economy	62100.00
0005433806024	26271	Economy	62100.00
0005433785432	26271	Economy	62100.00
0005433806026	26271	Economy	62100.00
0005435270111	26271	Economy	62100.00
0005434171438	26271	Economy	62100.00
0005434271368	26271	Economy	62100.00
0005435270114	26271	Economy	62100.00
0005433785675	26271	Economy	62100.00
0005432659742	26271	Economy	62100.00
0005433785735	26271	Economy	62100.00
0005432666422	26271	Economy	62100.00
0005434171442	26271	Economy	62100.00
0005433805975	26271	Economy	62100.00
0005433785648	26271	Economy	62100.00
0005433785507	26271	Economy	62100.00
0005432657498	26271	Economy	68300.00
0005432657510	26271	Economy	62100.00
0005433785662	26271	Economy	68300.00
0005433805995	26271	Economy	68300.00
0005433785639	26271	Economy	62100.00
0005433785736	26271	Economy	62100.00
0005435270122	26271	Economy	62100.00
0005433806116	26271	Economy	62100.00
0005433763476	26271	Economy	62100.00
0005435270113	26271	Economy	62100.00
0005433785741	26271	Economy	62100.00
0005434270263	26271	Economy	62100.00
0005433785705	26271	Economy	62100.00
0005433806143	26271	Economy	62100.00
0005435270121	26271	Economy	62100.00
0005432657506	26271	Economy	62100.00
0005435270109	26271	Economy	62100.00
0005433806112	26271	Economy	62100.00
0005435270124	26271	Economy	62100.00
0005432657500	26271	Economy	62100.00
0005433785738	26271	Economy	62100.00
0005433785711	26271	Economy	62100.00
0005432657509	26271	Economy	62100.00
0005434151786	26271	Economy	62100.00
0005433805853	26271	Economy	62100.00
0005434151785	26271	Economy	62100.00
0005433785674	26271	Economy	62100.00
0005433785508	26271	Economy	62100.00
0005433763432	26271	Economy	62100.00
0005435270127	26271	Economy	62100.00
0005432666417	26271	Economy	62100.00
0005433785466	26271	Economy	62100.00
0005433806094	26271	Economy	62100.00
0005433785544	26271	Economy	62100.00
0005435270120	26271	Economy	62100.00
0005433785650	26271	Economy	62100.00
0005432666428	26271	Economy	62100.00
0005433785732	26271	Economy	62100.00
0005433785742	26271	Economy	62100.00
0005434171444	26271	Economy	62100.00
0005433806006	26271	Economy	62100.00
0005433763514	26271	Economy	62100.00
0005435270118	26271	Economy	62100.00
0005433806114	26271	Economy	62100.00
0005434171440	26271	Economy	62100.00
0005432659745	26271	Economy	62100.00
0005432666427	26271	Economy	62100.00
0005435270125	26271	Economy	62100.00
0005433785640	26271	Economy	62100.00
0005433785683	26271	Economy	62100.00
0005433806198	26271	Economy	62100.00
0005435929698	4913	Economy	5900.00
0005435135799	4913	Economy	5300.00
0005435929701	4913	Economy	5300.00
0005435929702	4913	Economy	5300.00
0005435929696	4913	Economy	5300.00
0005435135800	4913	Economy	5300.00
0005435135757	33051	Economy	5900.00
0005435929718	33051	Economy	5300.00
0005435135756	33051	Economy	5300.00
0005435929719	33051	Economy	5300.00
0005435135759	33051	Economy	5300.00
0005435135761	33051	Economy	5300.00
0005435135760	33051	Economy	5300.00
0005434218041	9502	Economy	17900.00
0005434218048	9502	Economy	17900.00
0005434983427	9502	Economy	17900.00
0005434218040	9502	Economy	17900.00
0005434218034	9502	Economy	17900.00
0005434983425	9502	Economy	17900.00
0005434218033	9502	Economy	17900.00
0005434218039	9502	Economy	17900.00
0005434218038	9502	Economy	17900.00
0005434983426	9502	Economy	17900.00
0005434983397	27349	Economy	19700.00
0005434983393	27349	Economy	17900.00
0005434983399	27349	Economy	17900.00
0005434218080	27349	Economy	17900.00
0005434983392	27349	Economy	17900.00
0005433961744	24234	Business	36400.00
0005433986807	24234	Business	36400.00
0005433961653	24234	Business	36400.00
0005433986471	24234	Business	36400.00
0005433961924	24234	Business	36400.00
0005433986801	24234	Business	36400.00
0005433986651	24234	Business	36400.00
0005433986674	24234	Business	36400.00
0005433961861	24234	Business	36400.00
0005433961725	24234	Business	36400.00
0005433986806	24234	Business	36400.00
0005433986659	24234	Business	36400.00
0005433961746	24234	Business	36400.00
0005433961613	24234	Business	36400.00
0005433986830	24234	Economy	13400.00
0005433986611	24234	Economy	13400.00
0005433961825	24234	Economy	12100.00
0005433961880	24234	Economy	12100.00
0005433961604	24234	Economy	12100.00
0005433961968	24234	Economy	12100.00
0005433961745	24234	Economy	12100.00
0005433961967	24234	Economy	12100.00
0005433986673	24234	Economy	12100.00
0005433961780	24234	Economy	12100.00
0005433961898	24234	Economy	12100.00
0005433961660	24234	Economy	12100.00
0005433986753	24234	Economy	12100.00
0005433961931	24234	Economy	12100.00
0005433961763	24234	Economy	12100.00
0005433961659	24234	Economy	12100.00
0005433986766	24234	Economy	12100.00
0005433961946	24234	Economy	12100.00
0005433986799	24234	Economy	12100.00
0005433961565	24234	Economy	12100.00
0005433961936	24234	Economy	12100.00
0005433961731	24234	Economy	12100.00
0005433961900	24234	Economy	12100.00
0005433961865	24234	Economy	12100.00
0005433986730	24234	Economy	12100.00
0005433986808	24234	Economy	12100.00
0005433961752	24234	Economy	12100.00
0005433986805	24234	Economy	12100.00
0005433986821	24234	Economy	12100.00
0005433986652	24234	Economy	12100.00
0005433961934	24234	Economy	12100.00
0005433961724	24234	Economy	12100.00
0005433986831	24234	Economy	12100.00
0005433986754	24234	Economy	12100.00
0005433961972	24234	Economy	12100.00
0005433961874	24234	Economy	12100.00
0005433986719	24234	Economy	12100.00
0005433986820	24234	Economy	12100.00
0005433986747	24234	Economy	12100.00
0005433961914	24234	Economy	12100.00
0005433961666	24234	Economy	12100.00
0005433986720	24234	Economy	12100.00
0005433961897	24234	Economy	12100.00
0005433961905	24234	Economy	12100.00
0005433986765	24234	Economy	12100.00
0005433961611	24234	Economy	12100.00
0005433961778	24234	Economy	12100.00
0005433961953	24234	Economy	12100.00
0005433986755	24234	Economy	13400.00
0005433961952	24234	Economy	13400.00
0005433961872	24234	Economy	12100.00
0005433961925	24234	Economy	13400.00
0005433986656	24234	Economy	12100.00
0005433961873	24234	Economy	12100.00
0005433961749	24234	Economy	12100.00
0005433986687	24234	Economy	12100.00
0005433961932	24234	Economy	12100.00
0005433961958	24234	Economy	12100.00
0005433961862	24234	Economy	12100.00
0005433986675	24234	Economy	12100.00
0005433961973	24234	Economy	12100.00
0005433961866	24234	Economy	12100.00
0005433986612	24234	Economy	12100.00
0005433986790	24234	Economy	12100.00
0005433961774	24234	Economy	12100.00
0005433961935	24234	Economy	12100.00
0005433986815	24234	Economy	12100.00
0005433961850	24234	Economy	12100.00
0005433961846	24234	Economy	12100.00
0005433961943	24234	Economy	12100.00
0005433986742	24234	Economy	12100.00
0005433986708	24234	Economy	12100.00
0005433986746	24234	Economy	12100.00
0005433986832	24234	Economy	12100.00
0005433986800	24234	Economy	12100.00
0005433986813	24234	Economy	12100.00
0005433961959	24234	Economy	12100.00
0005433986688	24234	Economy	12100.00
0005433961824	24234	Economy	12100.00
0005433961849	24234	Economy	12100.00
0005433961700	24234	Economy	12100.00
0005433961894	24234	Economy	12100.00
0005433986701	24234	Economy	12100.00
0005433961906	24234	Economy	12100.00
0005433961945	24234	Economy	12100.00
0005433986764	24234	Economy	12100.00
0005433987202	25928	Business	36400.00
0005433962398	25928	Business	36400.00
0005433962422	25928	Business	36400.00
0005433987230	25928	Business	36400.00
0005433987207	25928	Business	36400.00
0005433962444	25928	Business	36400.00
0005433987201	25928	Business	36400.00
0005433962391	25928	Business	36400.00
0005433962424	25928	Business	36400.00
0005433987214	25928	Business	36400.00
0005433962402	25928	Business	36400.00
0005433987219	25928	Business	36400.00
0005433962427	25928	Economy	13400.00
0005433962449	25928	Economy	13400.00
0005433987208	25928	Economy	12100.00
0005433962454	25928	Economy	12100.00
0005433962429	25928	Economy	12100.00
0005433962387	25928	Economy	12100.00
0005433962430	25928	Economy	12100.00
0005433962446	25928	Economy	12100.00
0005433987216	25928	Economy	12100.00
0005433987197	25928	Economy	12100.00
0005433962407	25928	Economy	12100.00
0005433987217	25928	Economy	12100.00
0005433962442	25928	Economy	12100.00
0005433962412	25928	Economy	12100.00
0005433987194	25928	Economy	12100.00
0005433987200	25928	Economy	12100.00
0005433987234	25928	Economy	12100.00
0005433987210	25928	Economy	12100.00
0005433962448	25928	Economy	12100.00
0005433962386	25928	Economy	12100.00
0005433962419	25928	Economy	12100.00
0005433987215	25928	Economy	12100.00
0005433987190	25928	Economy	12100.00
0005433987205	25928	Economy	12100.00
0005433987222	25928	Economy	12100.00
0005433962389	25928	Economy	12100.00
0005433962395	25928	Economy	12100.00
0005433987235	25928	Economy	12100.00
0005433987221	25928	Economy	12100.00
0005433962414	25928	Economy	12100.00
0005433962411	25928	Economy	12100.00
0005433962450	25928	Economy	12100.00
0005433962403	25928	Economy	12100.00
0005433962406	25928	Economy	12100.00
0005433962397	25928	Economy	12100.00
0005433962420	25928	Economy	12100.00
0005433987231	25928	Economy	12100.00
0005433962451	25928	Economy	12100.00
0005433987218	25928	Economy	12100.00
0005433962425	25928	Economy	12100.00
0005433962440	25928	Economy	12100.00
0005433962421	25928	Economy	12100.00
0005433962390	25928	Economy	12100.00
0005433962417	25928	Economy	12100.00
0005433962423	25928	Economy	12100.00
0005433962428	25928	Economy	12100.00
0005433962393	25928	Economy	12100.00
0005433962453	25928	Economy	12100.00
0005433962439	25928	Economy	12100.00
0005433962401	25928	Economy	12100.00
0005433962385	25928	Economy	12100.00
0005433962452	25928	Economy	12100.00
0005433987228	25928	Economy	12100.00
0005433962443	25928	Economy	12100.00
0005433962436	25928	Economy	12100.00
0005433987223	25928	Economy	12100.00
0005433962415	25928	Economy	12100.00
0005433962405	25928	Economy	12100.00
0005433962416	25928	Economy	12100.00
0005433987211	25928	Economy	12100.00
0005433987238	25928	Economy	12100.00
0005433962399	25928	Economy	13400.00
0005433987189	25928	Economy	12100.00
0005433962409	25928	Economy	12100.00
0005433987226	25928	Economy	13400.00
0005433962394	25928	Economy	12100.00
0005433962445	25928	Economy	12100.00
0005433987206	25928	Economy	12100.00
0005433962400	25928	Economy	12100.00
0005433987204	25928	Economy	12100.00
0005433962388	25928	Economy	12100.00
0005433962431	25928	Economy	12100.00
0005433962408	25928	Economy	12100.00
0005433962441	25928	Economy	12100.00
0005433962384	25928	Economy	12100.00
0005433962447	25928	Economy	12100.00
0005433987227	25928	Economy	12100.00
0005433962433	25928	Economy	12100.00
0005433962383	25928	Economy	12100.00
0005433962404	25928	Economy	12100.00
0005433962438	25928	Economy	12100.00
0005433962382	25928	Economy	12100.00
0005433987195	25928	Economy	12100.00
0005433962418	25928	Economy	12100.00
0005433987220	25928	Economy	12100.00
0005433987232	25928	Economy	12100.00
0005433962437	25928	Economy	12100.00
0005433987224	25928	Economy	12100.00
0005433987198	25928	Economy	12100.00
0005433987193	25928	Economy	12100.00
0005433962413	25928	Economy	12100.00
0005433962396	25928	Economy	12100.00
0005433987233	25928	Economy	12100.00
0005433987191	25928	Economy	12100.00
0005433962435	25928	Economy	12100.00
0005433987236	25928	Economy	12100.00
0005433987212	25928	Economy	12100.00
0005433962410	25928	Economy	12100.00
0005433962392	25928	Economy	12100.00
0005433987213	25928	Economy	12100.00
0005433987203	25928	Economy	12100.00
0005433962455	25928	Economy	12100.00
0005433962432	25928	Economy	12100.00
0005433987239	25928	Economy	12100.00
0005433987199	25928	Economy	12100.00
0005433987237	25928	Economy	12100.00
0005433987192	25928	Economy	12100.00
0005433962434	25928	Economy	12100.00
0005433987196	25928	Economy	12100.00
0005433987225	25928	Economy	12100.00
0005433987209	25928	Economy	12100.00
0005433987240	25928	Economy	12100.00
0005433987229	25928	Economy	12100.00
0005433962426	25928	Economy	12100.00
0005434481003	956	Economy	25400.00
0005434481002	956	Economy	25400.00
0005433166167	956	Economy	25400.00
0005433166172	956	Economy	25400.00
0005433166166	956	Economy	23100.00
0005432269572	956	Economy	23100.00
0005433166178	956	Economy	23100.00
0005434481001	956	Economy	23100.00
0005433166174	956	Economy	23100.00
0005434481011	956	Economy	23100.00
0005433166165	956	Economy	23100.00
0005434480995	956	Economy	23100.00
0005432269571	956	Economy	23100.00
0005433166126	956	Economy	23100.00
0005433166092	956	Economy	23100.00
0005434480999	956	Economy	23100.00
0005434480994	956	Economy	23100.00
0005433166177	956	Economy	23100.00
0005434481008	956	Economy	23100.00
0005433166169	956	Economy	23100.00
0005434481007	956	Economy	23100.00
0005434481009	956	Economy	23100.00
0005433166197	956	Economy	23100.00
0005433166119	956	Economy	23100.00
0005434481012	956	Economy	23100.00
0005433166181	956	Economy	23100.00
0005433166176	956	Economy	23100.00
0005434481010	956	Economy	23100.00
0005433166214	956	Economy	23100.00
0005432269570	956	Economy	23100.00
0005433166199	956	Economy	23100.00
0005434481004	956	Economy	23100.00
0005433166107	956	Economy	23100.00
0005433166200	956	Economy	23100.00
0005433166171	956	Economy	23100.00
0005433166159	956	Economy	23100.00
0005433166108	956	Economy	23100.00
0005433166198	956	Economy	23100.00
0005434481013	956	Economy	23100.00
0005433166158	956	Economy	23100.00
0005434480993	956	Economy	23100.00
0005434481000	956	Economy	23100.00
0005434480998	956	Economy	23100.00
0005434481005	956	Economy	23100.00
0005433166152	956	Economy	23100.00
0005434481006	956	Economy	23100.00
0005433166215	956	Economy	23100.00
0005433166182	956	Economy	23100.00
0005434480997	956	Economy	23100.00
0005434480996	956	Economy	23100.00
0005433166254	16592	Economy	25400.00
0005434480781	16592	Economy	25400.00
0005434480806	16592	Economy	25400.00
0005433166256	16592	Economy	23100.00
0005433166266	16592	Economy	23100.00
0005433166262	16592	Economy	23100.00
0005433166261	16592	Economy	23100.00
0005434480735	16592	Economy	23100.00
0005433166260	16592	Economy	23100.00
0005434480858	16592	Economy	23100.00
0005433166258	16592	Economy	23100.00
0005434480750	16592	Economy	23100.00
0005433166263	16592	Economy	23100.00
0005434480852	16592	Economy	23100.00
0005433166257	16592	Economy	23100.00
0005434480840	16592	Economy	23100.00
0005433166259	16592	Economy	23100.00
0005434480814	16592	Economy	23100.00
0005434480790	16592	Economy	23100.00
0005434480772	16592	Economy	23100.00
0005434480854	16592	Economy	23100.00
0005434480789	16592	Economy	23100.00
0005434480832	16592	Economy	23100.00
0005434480773	16592	Economy	23100.00
0005434480845	16592	Economy	23100.00
0005434480796	16592	Economy	23100.00
0005434480782	16592	Economy	23100.00
0005434480700	16592	Economy	23100.00
0005433166264	16592	Economy	23100.00
0005434480797	16592	Economy	23100.00
0005434480859	16592	Economy	23100.00
0005433166255	16592	Economy	23100.00
0005433166265	16592	Economy	23100.00
0005434480764	16592	Economy	23100.00
0005434480699	16592	Economy	23100.00
0005434480841	16592	Economy	23100.00
0005433872578	3211	Economy	17200.00
0005433872576	3211	Economy	17200.00
0005433872575	3211	Economy	17200.00
0005433872574	3211	Economy	17200.00
0005433872577	3211	Economy	17200.00
0005433289964	10346	Economy	17000.00
0005433289953	10346	Economy	17000.00
0005435150392	10346	Economy	17000.00
0005435150401	10346	Economy	17000.00
0005435150391	10346	Economy	15400.00
0005435142930	10346	Economy	15400.00
0005433289974	10346	Economy	15400.00
0005433289948	10346	Economy	15400.00
0005435386667	10346	Economy	15400.00
0005433289982	10346	Economy	15400.00
0005435386718	10346	Economy	15400.00
0005435142924	10346	Economy	15400.00
0005435142928	10346	Economy	15400.00
0005435142926	10346	Economy	15400.00
0005433289987	10346	Economy	15400.00
0005433289956	10346	Economy	15400.00
0005435150394	10346	Economy	15400.00
0005435150395	10346	Economy	15400.00
0005435142927	10346	Economy	15400.00
0005433289986	10346	Economy	15400.00
0005433289996	10346	Economy	15400.00
0005433289971	10346	Economy	15400.00
0005435142933	10346	Economy	15400.00
0005435150398	10346	Economy	15400.00
0005435142925	10346	Economy	15400.00
0005435150399	10346	Economy	15400.00
0005435386685	10346	Economy	15400.00
0005435142932	10346	Economy	15400.00
0005435150400	10346	Economy	15400.00
0005435150390	10346	Economy	15400.00
0005435142931	10346	Economy	15400.00
0005435386686	10346	Economy	15400.00
0005435150396	10346	Economy	15400.00
0005435142929	10346	Economy	15400.00
0005435150397	10346	Economy	15400.00
0005433289957	10346	Economy	15400.00
0005435150393	10346	Economy	15400.00
0005435386683	10346	Economy	15400.00
0005433289970	10346	Economy	15400.00
0005435150301	21946	Economy	17000.00
0005435150253	21946	Economy	17000.00
0005435150322	21946	Economy	15400.00
0005435142814	21946	Economy	15400.00
0005435150259	21946	Economy	15400.00
0005435142817	21946	Economy	15400.00
0005435150273	21946	Economy	15400.00
0005435142837	21946	Economy	15400.00
0005433290052	21946	Economy	15400.00
0005435386746	21946	Economy	15400.00
0005435142852	21946	Economy	15400.00
0005435150255	21946	Economy	15400.00
0005435386744	21946	Economy	15400.00
0005435142794	21946	Economy	15400.00
0005433290051	21946	Economy	15400.00
0005435142806	21946	Economy	15400.00
0005435142815	21946	Economy	15400.00
0005435142823	21946	Economy	15400.00
0005435142900	21946	Economy	15400.00
0005435150265	21946	Economy	15400.00
0005435386745	21946	Economy	15400.00
0005435150254	21946	Economy	15400.00
0005433290050	21946	Economy	15400.00
0005435150271	21946	Economy	15400.00
0005435142858	21946	Economy	15400.00
0005435142853	21946	Economy	15400.00
0005435150300	21946	Economy	15400.00
0005435150326	21946	Economy	15400.00
0005435150318	21946	Economy	15400.00
0005433290049	21946	Economy	15400.00
0005435150272	21946	Economy	15400.00
0005435150296	21946	Economy	15400.00
0005435142818	21946	Economy	15400.00
0005435386743	21946	Economy	15400.00
0005435150266	21946	Economy	15400.00
0005435142807	21946	Economy	15400.00
0005433290054	21946	Economy	15400.00
0005435386742	21946	Economy	15400.00
0005435150236	21946	Economy	15400.00
0005433290053	21946	Economy	15400.00
0005435502654	11222	Business	57200.00
0005435545865	11222	Business	57200.00
0005435502768	11222	Business	57200.00
0005435545867	11222	Business	57200.00
0005435319747	11222	Business	57200.00
0005435502732	11222	Business	57200.00
0005435319748	11222	Business	57200.00
0005435529681	11222	Business	57200.00
0005435319760	11222	Economy	19100.00
0005435529708	11222	Economy	19100.00
0005435529680	11222	Economy	19100.00
0005435545870	11222	Economy	19100.00
0005434573726	11222	Economy	19100.00
0005435502744	11222	Economy	21000.00
0005434573727	11222	Economy	21000.00
0005435502722	11222	Economy	21000.00
0005435502787	11222	Economy	21000.00
0005435319691	11222	Economy	19100.00
0005435502767	11222	Economy	19100.00
0005435502780	11222	Economy	19100.00
0005435502612	11222	Economy	19100.00
0005434573724	11222	Economy	19100.00
0005434573728	11222	Economy	19100.00
0005435502657	11222	Economy	19100.00
0005435529654	11222	Economy	19100.00
0005435545895	11222	Economy	19100.00
0005435502656	11222	Economy	19100.00
0005435502655	11222	Economy	19100.00
0005435529614	11222	Economy	19100.00
0005435545882	11222	Economy	19100.00
0005435502788	11222	Economy	19100.00
0005435502670	11222	Economy	19100.00
0005435545893	11222	Economy	19100.00
0005434573725	11222	Economy	19100.00
0005435319746	11222	Economy	19100.00
0005435529616	11222	Economy	19100.00
0005435502653	11222	Economy	19100.00
0005435502669	11222	Economy	19100.00
0005435502690	11222	Economy	19100.00
0005435502802	11222	Economy	19100.00
0005435529717	11222	Economy	19100.00
0005435502611	11222	Economy	19100.00
0005435529675	11222	Economy	19100.00
0005435502786	11222	Economy	19100.00
0005435529629	11222	Economy	19100.00
0005435529674	11222	Economy	19100.00
0005435545894	11222	Economy	19100.00
0005434573731	11222	Economy	19100.00
0005435545869	11222	Economy	19100.00
0005434573729	11222	Economy	19100.00
0005435319761	11222	Economy	19100.00
0005435529556	11222	Economy	19100.00
0005434573722	11222	Economy	19100.00
0005435319783	11222	Economy	19100.00
0005434573730	11222	Economy	19100.00
0005435502733	11222	Economy	19100.00
0005435502783	11222	Economy	19100.00
0005435502766	11222	Economy	19100.00
0005434573723	11222	Economy	19100.00
0005435319731	11222	Economy	19100.00
0005435502752	11222	Economy	19100.00
0005435502891	20944	Business	57200.00
0005435508766	20944	Business	57200.00
0005435502889	20944	Business	57200.00
0005435319818	20944	Business	57200.00
0005435508757	20944	Business	57200.00
0005435508749	20944	Business	57200.00
0005435508762	20944	Business	57200.00
0005435508751	20944	Business	57200.00
0005434573615	20944	Business	57200.00
0005435508753	20944	Business	57200.00
0005435518397	20944	Economy	19100.00
0005434573645	20944	Economy	19100.00
0005434573648	20944	Economy	19100.00
0005435518405	20944	Economy	19100.00
0005435502883	20944	Economy	19100.00
0005435518402	20944	Economy	19100.00
0005435518395	20944	Economy	19100.00
0005435518391	20944	Economy	19100.00
0005435502903	20944	Economy	19100.00
0005434573602	20944	Economy	19100.00
0005435508764	20944	Economy	21000.00
0005435508770	20944	Economy	21000.00
0005434573570	20944	Economy	21000.00
0005434573667	20944	Economy	21000.00
0005435518396	20944	Economy	19100.00
0005435502884	20944	Economy	19100.00
0005435502898	20944	Economy	19100.00
0005435319820	20944	Economy	19100.00
0005435518393	20944	Economy	19100.00
0005435319817	20944	Economy	19100.00
0005434573603	20944	Economy	19100.00
0005435502899	20944	Economy	19100.00
0005435518400	20944	Economy	19100.00
0005435518401	20944	Economy	19100.00
0005435508760	20944	Economy	19100.00
0005435518406	20944	Economy	19100.00
0005435508755	20944	Economy	19100.00
0005435518390	20944	Economy	19100.00
0005434573666	20944	Economy	19100.00
0005435508769	20944	Economy	19100.00
0005435502893	20944	Economy	19100.00
0005435502897	20944	Economy	19100.00
0005435518389	20944	Economy	19100.00
0005435518407	20944	Economy	19100.00
0005435502901	20944	Economy	19100.00
0005435518408	20944	Economy	19100.00
0005435502900	20944	Economy	19100.00
0005435502896	20944	Economy	19100.00
0005432291996	20944	Economy	19100.00
0005434573644	20944	Economy	19100.00
0005435508761	20944	Economy	19100.00
0005435502894	20944	Economy	19100.00
0005435319819	20944	Economy	19100.00
0005435508754	20944	Economy	19100.00
0005434573555	20944	Economy	19100.00
0005434573558	20944	Economy	19100.00
0005435502902	20944	Economy	19100.00
0005435502888	20944	Economy	19100.00
0005435508748	20944	Economy	19100.00
0005435508758	20944	Economy	19100.00
0005435508763	20944	Economy	19100.00
0005435502885	20944	Economy	19100.00
0005435502887	20944	Economy	19100.00
0005435502892	20944	Economy	19100.00
0005432291995	20944	Economy	19100.00
0005435518399	20944	Economy	19100.00
0005435518392	20944	Economy	19100.00
0005435518398	20944	Economy	19100.00
0005435508759	20944	Economy	19100.00
0005435508765	20944	Economy	19100.00
0005435518404	20944	Economy	19100.00
0005434573571	20944	Economy	19100.00
0005435508771	20944	Economy	19100.00
0005434573614	20944	Economy	19100.00
0005435502886	20944	Economy	19100.00
0005435508767	20944	Economy	19100.00
0005435518388	20944	Economy	19100.00
0005435518394	20944	Economy	19100.00
0005435508752	20944	Economy	19100.00
0005435508750	20944	Economy	19100.00
0005435508768	20944	Economy	19100.00
0005435502890	20944	Economy	19100.00
0005434573597	20944	Economy	19100.00
0005435518403	20944	Economy	19100.00
0005435508756	20944	Economy	19100.00
0005434573559	20944	Economy	19100.00
0005435502895	20944	Economy	19100.00
0005432693624	2914	Business	10300.00
0005432693711	2914	Business	10300.00
0005432693666	2914	Business	10300.00
0005432693444	2914	Business	10300.00
0005432693650	2914	Business	10300.00
0005432693750	2914	Business	10300.00
0005432693655	2914	Economy	3400.00
0005432693683	2914	Economy	3400.00
0005432693591	2914	Economy	3400.00
0005432693521	2914	Economy	3400.00
0005432693582	2914	Economy	3800.00
0005432693694	2914	Economy	3400.00
0005432693617	2914	Economy	3400.00
0005432693756	2914	Economy	3400.00
0005432693584	2914	Economy	3400.00
0005432693656	2914	Economy	3400.00
0005432693716	2914	Economy	3400.00
0005432693653	2914	Economy	3400.00
0005432693631	2914	Economy	3400.00
0005432693693	2914	Economy	3400.00
0005432693760	2914	Economy	3400.00
0005432693632	2914	Economy	3400.00
0005432693522	2914	Economy	3400.00
0005432693607	2914	Economy	3400.00
0005432693446	2914	Economy	3400.00
0005432693660	2914	Economy	3400.00
0005432693675	2914	Economy	3400.00
0005432693757	2914	Economy	3400.00
0005432693659	2914	Economy	3400.00
0005432693445	2914	Economy	3400.00
0005432693651	2914	Economy	3400.00
0005432693577	2914	Economy	3400.00
0005432693687	2914	Economy	3400.00
0005432693608	2914	Economy	3400.00
0005432693667	2914	Economy	3400.00
0005432693538	2914	Economy	3400.00
0005432693717	2914	Economy	3400.00
0005432693554	2914	Economy	3400.00
0005432693576	2914	Economy	3400.00
0005432693684	2914	Economy	3400.00
0005432881095	2917	Business	10300.00
0005432217855	2917	Business	10300.00
0005433124259	2917	Business	10300.00
0005433124297	2917	Business	10300.00
0005432881102	2917	Business	10300.00
0005432707467	2917	Business	10300.00
0005433124317	2917	Business	10300.00
0005432707458	2917	Economy	3400.00
0005432707456	2917	Economy	3400.00
0005432217856	2917	Economy	3400.00
0005433124307	2917	Economy	3400.00
0005433124261	2917	Economy	3400.00
0005432707465	2917	Economy	3400.00
0005433124344	2917	Economy	3400.00
0005432707463	2917	Economy	3400.00
0005433124299	2917	Economy	3800.00
0005433124329	2917	Economy	3800.00
0005432707452	2917	Economy	3800.00
0005432881005	2917	Economy	3800.00
0005433124244	2917	Economy	3400.00
0005432707470	2917	Economy	3400.00
0005432707459	2917	Economy	3400.00
0005432881065	2917	Economy	3400.00
0005432881090	2917	Economy	3400.00
0005433124311	2917	Economy	3400.00
0005433124306	2917	Economy	3400.00
0005432881091	2917	Economy	3400.00
0005432881066	2917	Economy	3400.00
0005433124328	2917	Economy	3400.00
0005432881087	2917	Economy	3400.00
0005433124245	2917	Economy	3400.00
0005432217854	2917	Economy	3400.00
0005432707453	2917	Economy	3400.00
0005433124262	2917	Economy	3400.00
0005432707468	2917	Economy	3400.00
0005432707469	2917	Economy	3400.00
0005433194908	2917	Economy	3400.00
0005433124247	2917	Economy	3400.00
0005432881137	2917	Economy	3400.00
0005432881105	2917	Economy	3400.00
0005432707466	2917	Economy	3400.00
0005433124338	2917	Economy	3400.00
0005432707460	2917	Economy	3400.00
0005433124231	2917	Economy	3400.00
0005432881155	2917	Economy	3400.00
0005432707462	2917	Economy	3400.00
0005432707454	2917	Economy	3400.00
0005432707471	2917	Economy	3400.00
0005433194922	2917	Economy	3400.00
0005433124232	2917	Economy	3400.00
0005432707464	2917	Economy	3400.00
0005432881110	2917	Economy	3400.00
0005433124310	2917	Economy	3400.00
0005432881033	2917	Economy	3400.00
0005432881097	2917	Economy	3400.00
0005432707455	2917	Economy	3400.00
0005433124375	2917	Economy	3400.00
0005432707457	2917	Economy	3400.00
0005432217853	2917	Economy	3400.00
0005432707461	2917	Economy	3400.00
0005433124330	2917	Economy	3400.00
0005433124316	2917	Economy	3400.00
0005433124489	30066	Business	10300.00
0005432707404	30066	Business	10300.00
0005432881213	30066	Business	10300.00
0005432693905	30066	Business	10300.00
0005433194947	30066	Business	10300.00
0005432707356	30066	Business	10300.00
0005433124482	30066	Business	10300.00
0005432881215	30066	Business	10300.00
0005432881207	30066	Business	10300.00
0005432707393	30066	Business	10300.00
0005432881209	30066	Business	10300.00
0005432693914	30066	Business	10300.00
0005432707180	30066	Economy	3400.00
0005433124467	30066	Economy	3400.00
0005433124473	30066	Economy	3400.00
0005432693906	30066	Economy	3400.00
0005432693909	30066	Economy	3400.00
0005432707405	30066	Economy	3400.00
0005433124480	30066	Economy	3400.00
0005432707376	30066	Economy	3400.00
0005432881206	30066	Economy	3400.00
0005432693903	30066	Economy	3400.00
0005433124483	30066	Economy	3800.00
0005433124474	30066	Economy	3800.00
0005432707330	30066	Economy	3800.00
0005432707325	30066	Economy	3800.00
0005432707165	30066	Economy	3800.00
0005432693921	30066	Economy	3400.00
0005433194950	30066	Economy	3400.00
0005433124470	30066	Economy	3400.00
0005433124478	30066	Economy	3400.00
0005432881217	30066	Economy	3400.00
0005433194958	30066	Economy	3400.00
0005432693922	30066	Economy	3400.00
0005432707281	30066	Economy	3400.00
0005433194959	30066	Economy	3400.00
0005432707354	30066	Economy	3400.00
0005433124471	30066	Economy	3400.00
0005432693916	30066	Economy	3400.00
0005433124475	30066	Economy	3400.00
0005432693919	30066	Economy	3400.00
0005433124486	30066	Economy	3400.00
0005432707355	30066	Economy	3400.00
0005433124469	30066	Economy	3400.00
0005432693923	30066	Economy	3400.00
0005432707310	30066	Economy	3400.00
0005433194953	30066	Economy	3400.00
0005432693913	30066	Economy	3400.00
0005432693908	30066	Economy	3400.00
0005433124485	30066	Economy	3400.00
0005432707296	30066	Economy	3400.00
0005432693918	30066	Economy	3400.00
0005432881210	30066	Economy	3400.00
0005433124488	30066	Economy	3400.00
0005432693924	30066	Economy	3400.00
0005432693907	30066	Economy	3400.00
0005433124472	30066	Economy	3400.00
0005433194955	30066	Economy	3400.00
0005432707280	30066	Economy	3400.00
0005432707335	30066	Economy	3400.00
0005432693917	30066	Economy	3400.00
0005432693912	30066	Economy	3400.00
0005433194954	30066	Economy	3400.00
0005432707357	30066	Economy	3400.00
0005432881211	30066	Economy	3400.00
0005432693911	30066	Economy	3400.00
0005432881208	30066	Economy	3400.00
0005432707342	30066	Economy	3400.00
0005432881212	30066	Economy	3400.00
0005432707242	30066	Economy	3400.00
0005433194951	30066	Economy	3400.00
0005432693910	30066	Economy	3400.00
0005432693920	30066	Economy	3400.00
0005432693915	30066	Economy	3400.00
0005433124479	30066	Economy	3400.00
0005432707341	30066	Economy	3400.00
0005432707311	30066	Economy	3400.00
0005432881214	30066	Economy	3400.00
0005433194952	30066	Economy	3400.00
0005433124481	30066	Economy	3400.00
0005433124487	30066	Economy	3400.00
0005433194949	30066	Economy	3400.00
0005433124477	30066	Economy	3400.00
0005433124468	30066	Economy	3400.00
0005432693904	30066	Economy	3400.00
0005433194960	30066	Economy	3400.00
0005433194956	30066	Economy	3400.00
0005432707435	30066	Economy	3400.00
0005433124484	30066	Economy	3400.00
0005432707331	30066	Economy	3400.00
0005433124476	30066	Economy	3400.00
0005433194948	30066	Economy	3400.00
0005432881216	30066	Economy	3400.00
0005432707140	30066	Economy	3400.00
0005433194957	30066	Economy	3400.00
0005432707353	30066	Economy	3400.00
0005434980591	23704	Economy	4000.00
0005434989038	23704	Economy	4000.00
0005434980584	23704	Economy	3600.00
0005434989033	23704	Economy	3600.00
0005434989035	23704	Economy	3600.00
0005434989037	23704	Economy	3600.00
0005434980593	23704	Economy	3600.00
0005434980586	23704	Economy	3600.00
0005434989032	23704	Economy	3600.00
0005434989042	23704	Economy	3600.00
0005434989039	23704	Economy	3600.00
0005434989036	23704	Economy	3600.00
0005434980590	23704	Economy	3600.00
0005434980572	23704	Economy	3600.00
0005434980583	23704	Economy	3600.00
0005434980588	23704	Economy	3600.00
0005434980577	23704	Economy	3600.00
0005434989044	23704	Economy	3600.00
0005434989034	23704	Economy	3600.00
0005434980571	23704	Economy	3600.00
0005434980579	23704	Economy	3600.00
0005434980592	23704	Economy	3600.00
0005434980582	23704	Economy	3600.00
0005434980575	23704	Economy	3600.00
0005434989040	23704	Economy	3600.00
0005434980581	23704	Economy	3600.00
0005434980578	23704	Economy	3600.00
0005434980573	23704	Economy	3600.00
0005434980580	23704	Economy	3600.00
0005434980574	23704	Economy	3600.00
0005434989041	23704	Economy	3600.00
0005434980576	23704	Economy	3600.00
0005434980587	23704	Economy	3600.00
0005434989045	23704	Economy	3600.00
0005434980589	23704	Economy	3600.00
0005434989047	23704	Economy	3600.00
0005434980585	23704	Economy	3600.00
0005434989043	23704	Economy	3600.00
0005434989046	23704	Economy	3600.00
0005434980344	27570	Economy	4000.00
0005434988898	27570	Economy	4000.00
0005434980395	27570	Economy	3600.00
0005434988913	27570	Economy	3600.00
0005434980307	27570	Economy	3600.00
0005434980309	27570	Economy	3600.00
0005434980317	27570	Economy	3600.00
0005434988921	27570	Economy	3600.00
0005434988933	27570	Economy	3600.00
0005434980328	27570	Economy	3600.00
0005434980321	27570	Economy	3600.00
0005434980278	27570	Economy	3600.00
0005434980169	27570	Economy	3600.00
0005434980373	27570	Economy	3600.00
0005434980222	27570	Economy	3600.00
0005434988934	27570	Economy	3600.00
0005434980389	27570	Economy	3600.00
0005434988922	27570	Economy	3600.00
0005434980343	27570	Economy	3600.00
0005434980374	27570	Economy	3600.00
0005434980277	27570	Economy	3600.00
0005434980359	27570	Economy	3600.00
0005434980327	27570	Economy	3600.00
0005434988915	27570	Economy	3600.00
0005434988929	27570	Economy	3600.00
0005434988904	27570	Economy	3600.00
0005434980405	27570	Economy	3600.00
0005434980372	27570	Economy	3600.00
0005434980355	27570	Economy	3600.00
0005434980308	27570	Economy	3600.00
0005434980221	27570	Economy	3600.00
0005434980170	27570	Economy	3600.00
0005434980413	27570	Economy	3600.00
0005434980325	27570	Economy	3600.00
0005434988937	27570	Economy	3600.00
0005434980255	27570	Economy	3600.00
0005434980326	27570	Economy	3600.00
0005434980334	27570	Economy	3600.00
0005434988897	27570	Economy	3600.00
0005434988935	27570	Economy	3600.00
0005434980464	27570	Economy	3600.00
0005434302570	10284	Economy	21600.00
0005434302900	10284	Economy	21600.00
0005434302899	10284	Economy	19700.00
0005434302571	10284	Economy	19700.00
0005434302898	10284	Economy	19700.00
0005434302572	10284	Economy	19700.00
0005434302897	10284	Economy	19700.00
0005434302522	19615	Economy	19700.00
0005434302536	19615	Economy	19700.00
0005434302548	19615	Economy	19700.00
0005434302533	19615	Economy	19700.00
0005434302535	19615	Economy	19700.00
0005434302521	19615	Economy	19700.00
0005434302534	19615	Economy	19700.00
0005435925640	3555	Business	26900.00
0005435070494	3555	Business	26900.00
0005435719110	3555	Business	26900.00
0005435070493	3555	Business	26900.00
0005435070465	3555	Business	26900.00
0005435070483	3555	Business	26900.00
0005435070470	3555	Business	26900.00
0005435925491	3555	Economy	9000.00
0005435950315	3555	Economy	9000.00
0005435925638	3555	Economy	9000.00
0005435719109	3555	Economy	9000.00
0005435950308	3555	Economy	9000.00
0005435939913	3555	Economy	9900.00
0005435070471	3555	Economy	9900.00
0005435070472	3555	Economy	9900.00
0005435925525	3555	Economy	9900.00
0005435070487	3555	Economy	9000.00
0005435925582	3555	Economy	9000.00
0005435950316	3555	Economy	9000.00
0005435925537	3555	Economy	9000.00
0005435925639	3555	Economy	9000.00
0005435950319	3555	Economy	9000.00
0005435070473	3555	Economy	9000.00
0005435070495	3555	Economy	9000.00
0005435950309	3555	Economy	9000.00
0005435939924	3555	Economy	9000.00
0005435070491	3555	Economy	9000.00
0005435070479	3555	Economy	9000.00
0005435950311	3555	Economy	9000.00
0005435070484	3555	Economy	9000.00
0005435950313	3555	Economy	9000.00
0005435070492	3555	Economy	9000.00
0005435719111	3555	Economy	9000.00
0005435719107	3555	Economy	9000.00
0005435070476	3555	Economy	9000.00
0005435070490	3555	Economy	9000.00
0005435070474	3555	Economy	9000.00
0005435925532	3555	Economy	9000.00
0005435070480	3555	Economy	9000.00
0005435070481	3555	Economy	9000.00
0005435719113	3555	Economy	9000.00
0005435719106	3555	Economy	9000.00
0005435070466	3555	Economy	9000.00
0005435719108	3555	Economy	9000.00
0005435070468	3555	Economy	9000.00
0005435070489	3555	Economy	9000.00
0005435070485	3555	Economy	9000.00
0005435719105	3555	Economy	9000.00
0005435070467	3555	Economy	9000.00
0005435070469	3555	Economy	9000.00
0005435939905	3555	Economy	9000.00
0005435070482	3555	Economy	9000.00
0005435950314	3555	Economy	9000.00
0005435950320	3555	Economy	9000.00
0005435950312	3555	Economy	9000.00
0005435950318	3555	Economy	9000.00
0005435925492	3555	Economy	9000.00
0005435925531	3555	Economy	9000.00
0005435925533	3555	Economy	9000.00
0005435950310	3555	Economy	9000.00
0005435070477	3555	Economy	9000.00
0005435925490	3555	Economy	9000.00
0005435070486	3555	Economy	9000.00
0005435950317	3555	Economy	9000.00
0005435070488	3555	Economy	9000.00
0005435070475	3555	Economy	9000.00
0005435070478	3555	Economy	9000.00
0005435719112	3555	Economy	9000.00
0005435069647	15322	Business	26900.00
0005435069895	15322	Business	26900.00
0005435069894	15322	Business	26900.00
0005435070056	15322	Business	26900.00
0005435069840	15322	Business	26900.00
0005435069969	15322	Business	26900.00
0005435069868	15322	Business	26900.00
0005435070025	15322	Business	26900.00
0005435070093	15322	Business	26900.00
0005435070003	15322	Business	26900.00
0005435069967	15322	Economy	9000.00
0005435925670	15322	Economy	9000.00
0005435070034	15322	Economy	9000.00
0005435069854	15322	Economy	9000.00
0005435925686	15322	Economy	9000.00
0005435925684	15322	Economy	9000.00
0005435925675	15322	Economy	9000.00
0005435925685	15322	Economy	9900.00
0005435925682	15322	Economy	9900.00
0005435069813	15322	Economy	9900.00
0005435069968	15322	Economy	9000.00
0005435925671	15322	Economy	9000.00
0005435069648	15322	Economy	9000.00
0005435069814	15322	Economy	9000.00
0005435069999	15322	Economy	9000.00
0005435070022	15322	Economy	9000.00
0005435069973	15322	Economy	9000.00
0005435069937	15322	Economy	9000.00
0005435070128	15322	Economy	9000.00
0005435925679	15322	Economy	9000.00
0005435070129	15322	Economy	9000.00
0005435925677	15322	Economy	9000.00
0005435925676	15322	Economy	9000.00
0005435069938	15322	Economy	9000.00
0005435925672	15322	Economy	9000.00
0005435070141	15322	Economy	9000.00
0005435069881	15322	Economy	9000.00
0005435925673	15322	Economy	9000.00
0005435070092	15322	Economy	9000.00
0005435925688	15322	Economy	9000.00
0005435925680	15322	Economy	9000.00
0005435070243	15322	Economy	9000.00
0005435925683	15322	Economy	9000.00
0005435070021	15322	Economy	9000.00
0005435925690	15322	Economy	9000.00
0005435925674	15322	Economy	9000.00
0005435069986	15322	Economy	9000.00
0005435070020	15322	Economy	9000.00
0005435070002	15322	Economy	9000.00
0005435069717	15322	Economy	9000.00
0005435939953	15322	Economy	9000.00
0005435925681	15322	Economy	9000.00
0005435925689	15322	Economy	9000.00
0005435070016	15322	Economy	9000.00
0005435925678	15322	Economy	9000.00
0005435069955	15322	Economy	9000.00
0005435070048	15322	Economy	9000.00
0005435069931	15322	Economy	9000.00
0005435070057	15322	Economy	9000.00
0005435069992	15322	Economy	9000.00
0005435939955	15322	Economy	9000.00
0005435070140	15322	Economy	9000.00
0005435069899	15322	Economy	9000.00
0005435069853	15322	Economy	9000.00
0005435939954	15322	Economy	9000.00
0005435070001	15322	Economy	9000.00
0005435070263	15322	Economy	9000.00
0005435069880	15322	Economy	9000.00
0005435925687	15322	Economy	9000.00
0005435070105	15322	Economy	9000.00
0005432658649	18166	Economy	5900.00
0005432660875	18166	Economy	5900.00
0005432659764	18166	Economy	5900.00
0005432660876	18166	Economy	5900.00
0005432658648	18166	Economy	5900.00
0005432660874	18166	Economy	5900.00
0005432664187	26429	Economy	5900.00
0005432664162	26429	Economy	5900.00
0005432664163	26429	Economy	5900.00
0005432667490	26429	Economy	5900.00
0005432660852	26429	Economy	5900.00
0005432660860	26429	Economy	5900.00
0005432660861	26429	Economy	5900.00
0005432660858	26429	Economy	5900.00
0005433103214	232	Business	20000.00
0005432901988	232	Business	20000.00
0005433103160	232	Business	20000.00
0005432901949	232	Business	20000.00
0005433103143	232	Business	20000.00
0005433103059	232	Business	20000.00
0005433103076	232	Business	20000.00
0005433103140	232	Business	20000.00
0005433103181	232	Business	20000.00
0005433103114	232	Business	20000.00
0005432902006	232	Business	20000.00
0005433103169	232	Business	20000.00
0005432920219	232	Business	20000.00
0005433103056	232	Business	20000.00
0005433103156	232	Business	20000.00
0005432920209	232	Business	20000.00
0005433103093	232	Economy	7300.00
0005432920284	232	Economy	7300.00
0005433103182	232	Economy	7300.00
0005433103192	232	Economy	7300.00
0005432677662	232	Economy	7300.00
0005433103115	232	Economy	6700.00
0005433103164	232	Economy	6700.00
0005432920235	232	Economy	6700.00
0005433103075	232	Economy	6700.00
0005433103092	232	Economy	6700.00
0005433103077	232	Economy	6700.00
0005433103121	232	Economy	6700.00
0005433103204	232	Economy	6700.00
0005433103063	232	Economy	6700.00
0005433103015	232	Economy	6700.00
0005432920183	232	Economy	6700.00
0005433103091	232	Economy	6700.00
0005433103170	232	Economy	6700.00
0005433102970	232	Economy	6700.00
0005433103062	232	Economy	6700.00
0005432901984	232	Economy	6700.00
0005432901987	232	Economy	6700.00
0005432901985	232	Economy	6700.00
0005433103048	232	Economy	6700.00
0005433103148	232	Economy	6700.00
0005432901925	232	Economy	6700.00
0005433103165	232	Economy	6700.00
0005433103088	232	Economy	6700.00
0005433103203	232	Economy	6700.00
0005433103126	232	Economy	6700.00
0005432920270	232	Economy	6700.00
0005432901938	232	Economy	6700.00
0005433103111	232	Economy	6700.00
0005432901986	232	Economy	6700.00
0005432920304	232	Economy	6700.00
0005433103145	232	Economy	6700.00
0005432677656	232	Economy	6700.00
0005432920182	232	Economy	6700.00
0005433103087	232	Economy	6700.00
0005432920330	232	Economy	6700.00
0005432677663	232	Economy	6700.00
0005432901907	232	Economy	6700.00
0005432920306	232	Economy	6700.00
0005433103108	232	Economy	6700.00
0005432920283	232	Economy	7300.00
0005433103179	232	Economy	7300.00
0005432901951	232	Economy	7300.00
0005432902000	232	Economy	7300.00
0005432901999	232	Economy	6700.00
0005432920215	232	Economy	6700.00
0005433103049	232	Economy	6700.00
0005433103168	232	Economy	6700.00
0005433103212	232	Economy	6700.00
0005433103033	232	Economy	6700.00
0005433103163	232	Economy	6700.00
0005433103109	232	Economy	6700.00
0005433103166	232	Economy	6700.00
0005432920319	232	Economy	6700.00
0005432920238	232	Economy	6700.00
0005433102924	232	Economy	6700.00
0005433103014	232	Economy	6700.00
0005432920273	232	Economy	6700.00
0005432901952	232	Economy	6700.00
0005433103146	232	Economy	6700.00
0005433103120	232	Economy	6700.00
0005432901937	232	Economy	6700.00
0005432920189	232	Economy	6700.00
0005433103180	232	Economy	6700.00
0005433102990	232	Economy	6700.00
0005432920246	232	Economy	6700.00
0005432920269	232	Economy	6700.00
0005433103130	232	Economy	6700.00
0005432920307	232	Economy	6700.00
0005432920194	232	Economy	6700.00
0005433102949	232	Economy	6700.00
0005432920181	232	Economy	6700.00
0005433103210	232	Economy	6700.00
0005432920249	232	Economy	6700.00
0005433102916	232	Economy	6700.00
0005432920264	232	Economy	6700.00
0005433103211	232	Economy	6700.00
0005432920294	232	Economy	6700.00
0005432677651	232	Economy	6700.00
0005433103213	232	Economy	6700.00
0005433102912	232	Economy	6700.00
0005433103139	232	Economy	6700.00
0005432920312	232	Economy	6700.00
0005433103122	232	Economy	6700.00
0005433103123	232	Economy	6700.00
0005433103207	232	Economy	6700.00
0005432263133	233	Business	20000.00
0005434152863	233	Business	20000.00
0005432818277	233	Business	20000.00
0005432263144	233	Business	20000.00
0005432753358	233	Business	20000.00
0005432263132	233	Business	20000.00
0005432289075	233	Business	20000.00
0005433477224	233	Business	20000.00
0005433687735	233	Business	20000.00
0005433477199	233	Business	20000.00
0005434157731	233	Business	20000.00
0005433477205	233	Business	20000.00
0005432263131	233	Business	20000.00
0005432818267	233	Business	20000.00
0005432818273	233	Business	20000.00
0005433477227	233	Business	20000.00
0005433477208	233	Business	20000.00
0005432263147	233	Economy	7300.00
0005432818284	233	Economy	7300.00
0005432818283	233	Economy	7300.00
0005433687738	233	Economy	7300.00
0005432263150	233	Economy	7300.00
0005433477195	233	Economy	7300.00
0005432756907	233	Economy	6700.00
0005432818268	233	Economy	6700.00
0005432818286	233	Economy	6700.00
0005432818270	233	Economy	6700.00
0005432263146	233	Economy	6700.00
0005434153577	233	Economy	6700.00
0005433477206	233	Economy	6700.00
0005432818287	233	Economy	6700.00
0005432263155	233	Economy	6700.00
0005432207731	233	Economy	6700.00
0005433477219	233	Economy	6700.00
0005433477209	233	Economy	6700.00
0005432753362	233	Economy	6700.00
0005433477222	233	Economy	6700.00
0005432263126	233	Economy	6700.00
0005433477207	233	Economy	6700.00
0005434152864	233	Economy	6700.00
0005433687736	233	Economy	6700.00
0005432753357	233	Economy	6700.00
0005432818291	233	Economy	6700.00
0005432263143	233	Economy	6700.00
0005432263130	233	Economy	6700.00
0005432263127	233	Economy	6700.00
0005432818271	233	Economy	6700.00
0005433477203	233	Economy	6700.00
0005432263140	233	Economy	6700.00
0005432818275	233	Economy	6700.00
0005432818276	233	Economy	6700.00
0005433477200	233	Economy	6700.00
0005433687739	233	Economy	6700.00
0005433477223	233	Economy	6700.00
0005432263160	233	Economy	6700.00
0005432207732	233	Economy	6700.00
0005433477202	233	Economy	6700.00
0005432263159	233	Economy	6700.00
0005433687742	233	Economy	6700.00
0005433477201	233	Economy	6700.00
0005432263157	233	Economy	6700.00
0005433477215	233	Economy	6700.00
0005432263161	233	Economy	6700.00
0005432263134	233	Economy	6700.00
0005432263154	233	Economy	6700.00
0005433477221	233	Economy	6700.00
0005432818282	233	Economy	7300.00
0005432289076	233	Economy	7300.00
0005432818269	233	Economy	7300.00
0005434152862	233	Economy	7300.00
0005433477213	233	Economy	7300.00
0005433477197	233	Economy	6700.00
0005433477211	233	Economy	6700.00
0005432263139	233	Economy	6700.00
0005432818290	233	Economy	6700.00
0005432263128	233	Economy	7300.00
0005433477217	233	Economy	6700.00
0005434153576	233	Economy	6700.00
0005432263153	233	Economy	6700.00
0005432818281	233	Economy	6700.00
0005433477228	233	Economy	6700.00
0005433477220	233	Economy	6700.00
0005432818278	233	Economy	6700.00
0005432263142	233	Economy	6700.00
0005434153575	233	Economy	6700.00
0005432289074	233	Economy	6700.00
0005432263141	233	Economy	6700.00
0005432818285	233	Economy	6700.00
0005433477216	233	Economy	6700.00
0005433477218	233	Economy	6700.00
0005433477212	233	Economy	6700.00
0005432818289	233	Economy	6700.00
0005432818280	233	Economy	6700.00
0005432263135	233	Economy	6700.00
0005433477210	233	Economy	6700.00
0005432818274	233	Economy	6700.00
0005433687743	233	Economy	6700.00
0005432263149	233	Economy	6700.00
0005432263129	233	Economy	6700.00
0005433477196	233	Economy	6700.00
0005432289077	233	Economy	6700.00
0005432818279	233	Economy	6700.00
0005433477229	233	Economy	6700.00
0005434157732	233	Economy	6700.00
0005432263152	233	Economy	6700.00
0005433477198	233	Economy	6700.00
0005432756901	233	Economy	6700.00
0005432263151	233	Economy	6700.00
0005432263162	233	Economy	6700.00
0005432756906	233	Economy	6700.00
0005432263148	233	Economy	6700.00
0005433477225	233	Economy	6700.00
0005432263156	233	Economy	6700.00
0005432263138	233	Economy	6700.00
0005432263158	233	Economy	6700.00
0005433477204	233	Economy	6700.00
0005432263136	233	Economy	6700.00
0005432818272	233	Economy	6700.00
0005432263145	233	Economy	6700.00
0005432818288	233	Economy	6700.00
0005433477230	233	Economy	6700.00
0005432263137	233	Economy	6700.00
0005433477214	233	Economy	6700.00
0005433477226	233	Economy	6700.00
0005433103624	8025	Business	20000.00
0005432020989	8025	Business	20000.00
0005432044601	8025	Business	20000.00
0005433103672	8025	Business	20000.00
0005433103629	8025	Business	20000.00
0005432044603	8025	Business	20000.00
0005433103673	8025	Business	20000.00
0005432020986	8025	Business	20000.00
0005433103620	8025	Business	20000.00
0005432020991	8025	Business	20000.00
0005432020985	8025	Business	20000.00
0005433103644	8025	Business	20000.00
0005433103615	8025	Business	20000.00
0005432920428	8025	Business	20000.00
0005433103618	8025	Business	20000.00
0005433103678	8025	Business	20000.00
0005432920425	8025	Business	20000.00
0005433103638	8025	Business	20000.00
0005433103658	8025	Business	20000.00
0005432920418	8025	Economy	7300.00
0005432920426	8025	Economy	7300.00
0005433103623	8025	Economy	7300.00
0005433103640	8025	Economy	6700.00
0005433103631	8025	Economy	6700.00
0005433103674	8025	Economy	6700.00
0005432677682	8025	Economy	6700.00
0005432751618	8025	Economy	6700.00
0005433103632	8025	Economy	6700.00
0005432020998	8025	Economy	6700.00
0005433103646	8025	Economy	6700.00
0005433103647	8025	Economy	6700.00
0005432920430	8025	Economy	6700.00
0005432920420	8025	Economy	6700.00
0005433103671	8025	Economy	6700.00
0005432920423	8025	Economy	6700.00
0005432020984	8025	Economy	6700.00
0005433103659	8025	Economy	6700.00
0005432751621	8025	Economy	6700.00
0005432920422	8025	Economy	6700.00
0005433103626	8025	Economy	6700.00
0005432920434	8025	Economy	6700.00
0005433103652	8025	Economy	6700.00
0005432020988	8025	Economy	6700.00
0005433103663	8025	Economy	6700.00
0005432751619	8025	Economy	6700.00
0005433103656	8025	Economy	6700.00
0005433103669	8025	Economy	6700.00
0005433103648	8025	Economy	6700.00
0005432677681	8025	Economy	6700.00
0005433103639	8025	Economy	6700.00
0005432677683	8025	Economy	6700.00
0005433103643	8025	Economy	6700.00
0005433103666	8025	Economy	6700.00
0005433103619	8025	Economy	6700.00
0005433103667	8025	Economy	6700.00
0005433103617	8025	Economy	6700.00
0005432021001	8025	Economy	6700.00
0005433103613	8025	Economy	6700.00
0005432044602	8025	Economy	6700.00
0005433103634	8025	Economy	6700.00
0005433103657	8025	Economy	6700.00
0005432020996	8025	Economy	6700.00
0005432020992	8025	Economy	6700.00
0005433103670	8025	Economy	6700.00
0005432020995	8025	Economy	6700.00
0005433103633	8025	Economy	6700.00
0005433103664	8025	Economy	6700.00
0005433103675	8025	Economy	7300.00
0005432021000	8025	Economy	7300.00
0005433103660	8025	Economy	7300.00
0005433103622	8025	Economy	6700.00
0005433103653	8025	Economy	7300.00
0005433103630	8025	Economy	6700.00
0005433103641	8025	Economy	6700.00
0005432677685	8025	Economy	6700.00
0005433103642	8025	Economy	6700.00
0005433103665	8025	Economy	6700.00
0005433103635	8025	Economy	6700.00
0005432020987	8025	Economy	6700.00
0005432020999	8025	Economy	6700.00
0005432392082	8025	Economy	6700.00
0005432920421	8025	Economy	6700.00
0005433103662	8025	Economy	6700.00
0005433103628	8025	Economy	6700.00
0005432751620	8025	Economy	6700.00
0005433103627	8025	Economy	6700.00
0005433103650	8025	Economy	6700.00
0005433103677	8025	Economy	6700.00
0005432920435	8025	Economy	6700.00
0005432753393	8025	Economy	6700.00
0005433103655	8025	Economy	6700.00
0005433103625	8025	Economy	6700.00
0005432920427	8025	Economy	6700.00
0005433103645	8025	Economy	6700.00
0005433103679	8025	Economy	6700.00
0005433103668	8025	Economy	6700.00
0005432677684	8025	Economy	6700.00
0005433103649	8025	Economy	6700.00
0005433103612	8025	Economy	6700.00
0005433103680	8025	Economy	6700.00
0005433103676	8025	Economy	6700.00
0005432920432	8025	Economy	6700.00
0005433103661	8025	Economy	6700.00
0005433103654	8025	Economy	6700.00
0005432920431	8025	Economy	6700.00
0005432920433	8025	Economy	6700.00
0005432920424	8025	Economy	6700.00
0005432920417	8025	Economy	6700.00
0005433103681	8025	Economy	6700.00
0005433103651	8025	Economy	6700.00
0005432020993	8025	Economy	6700.00
0005432020990	8025	Economy	6700.00
0005432920429	8025	Economy	6700.00
0005432020997	8025	Economy	6700.00
0005433103621	8025	Economy	6700.00
0005433103614	8025	Economy	6700.00
0005433103637	8025	Economy	6700.00
0005432020994	8025	Economy	6700.00
0005432920419	8025	Economy	6700.00
0005432021002	8025	Economy	6700.00
0005432920416	8025	Economy	6700.00
0005433103636	8025	Economy	6700.00
0005433103616	8025	Economy	6700.00
0005432902081	8027	Business	20000.00
0005432818087	8027	Business	20000.00
0005432902088	8027	Business	20000.00
0005432818070	8027	Business	20000.00
0005432817972	8027	Business	20000.00
0005432817996	8027	Business	20000.00
0005432818082	8027	Business	20000.00
0005432818208	8027	Business	20000.00
0005432902080	8027	Business	20000.00
0005432902078	8027	Business	20000.00
0005432902089	8027	Economy	7300.00
0005432818207	8027	Economy	7300.00
0005432902084	8027	Economy	7300.00
0005432818021	8027	Economy	6700.00
0005432002133	8027	Economy	6700.00
0005432818030	8027	Economy	6700.00
0005432817976	8027	Economy	6700.00
0005432817880	8027	Economy	6700.00
0005432818026	8027	Economy	6700.00
0005432818027	8027	Economy	6700.00
0005432818007	8027	Economy	6700.00
0005432818035	8027	Economy	6700.00
0005432902087	8027	Economy	6700.00
0005432902090	8027	Economy	6700.00
0005432818022	8027	Economy	6700.00
0005432902086	8027	Economy	6700.00
0005432818006	8027	Economy	6700.00
0005432902091	8027	Economy	7300.00
0005432818116	8027	Economy	7300.00
0005432817999	8027	Economy	6700.00
0005432818005	8027	Economy	6700.00
0005432902085	8027	Economy	6700.00
0005432002132	8027	Economy	6700.00
0005432817955	8027	Economy	6700.00
0005432818029	8027	Economy	6700.00
0005432817854	8027	Economy	6700.00
0005432902079	8027	Economy	6700.00
0005432902082	8027	Economy	6700.00
0005432817995	8027	Economy	6700.00
0005432818010	8027	Economy	6700.00
0005432818088	8027	Economy	6700.00
0005432818017	8027	Economy	6700.00
0005432817998	8027	Economy	6700.00
0005432817882	8027	Economy	6700.00
0005432817881	8027	Economy	6700.00
0005432818206	8027	Economy	6700.00
0005432818016	8027	Economy	6700.00
0005432902083	8027	Economy	6700.00
0005433870793	9694	Economy	6900.00
0005434175829	9694	Economy	6900.00
0005434175838	9694	Economy	6900.00
0005433870761	32321	Economy	6900.00
0005433870769	32321	Economy	6900.00
0005433870775	32321	Economy	6900.00
0005433870773	32321	Economy	6900.00
0005433870768	32321	Economy	6900.00
0005433870774	32321	Economy	6900.00
0005434175867	32321	Economy	6900.00
0005435914024	3472	Business	35000.00
0005434880795	3472	Business	35000.00
0005434938673	3472	Business	35000.00
0005434880836	3472	Business	35000.00
0005432611807	3472	Business	35000.00
0005434427416	3472	Business	35000.00
0005434427405	3472	Business	35000.00
0005434427410	3472	Business	35000.00
0005432800233	3472	Business	35000.00
0005435626703	3472	Business	35000.00
0005435127477	3472	Business	35000.00
0005435914007	3472	Business	35000.00
0005434880779	3472	Business	35000.00
0005434427409	3472	Business	35000.00
0005435626708	3472	Business	35000.00
0005434938674	3472	Business	35000.00
0005435127485	3472	Business	35000.00
0005434880776	3472	Comfort	19900.00
0005435127498	3472	Comfort	19900.00
0005434880780	3472	Comfort	19900.00
0005434880782	3472	Comfort	19900.00
0005435626694	3472	Comfort	19900.00
0005435127486	3472	Comfort	19900.00
0005434427415	3472	Comfort	19900.00
0005435626709	3472	Comfort	19900.00
0005432613972	3472	Comfort	19900.00
0005434938682	3472	Comfort	19900.00
0005434427407	3472	Comfort	19900.00
0005435902940	3472	Comfort	19900.00
0005435626720	3472	Comfort	19900.00
0005434938677	3472	Comfort	19900.00
0005432800226	3472	Comfort	19900.00
0005434427414	3472	Comfort	19900.00
0005434427412	3472	Comfort	19900.00
0005435127491	3472	Comfort	19900.00
0005435914006	3472	Comfort	19900.00
0005434880786	3472	Comfort	19900.00
0005432800229	3472	Comfort	19900.00
0005432800222	3472	Comfort	19900.00
0005432613974	3472	Comfort	19900.00
0005435127495	3472	Comfort	19900.00
0005435127478	3472	Comfort	19900.00
0005435127501	3472	Comfort	19900.00
0005434880830	3472	Comfort	19900.00
0005434938671	3472	Economy	11700.00
0005435902941	3472	Economy	11700.00
0005434880783	3472	Economy	11700.00
0005434880797	3472	Economy	11700.00
0005434880822	3472	Economy	11700.00
0005434880834	3472	Economy	11700.00
0005434880823	3472	Economy	11700.00
0005435626707	3472	Economy	11700.00
0005434880816	3472	Economy	11700.00
0005434880777	3472	Economy	11700.00
0005434427420	3472	Economy	11700.00
0005432611808	3472	Economy	11700.00
0005434427421	3472	Economy	11700.00
0005435127470	3472	Economy	11700.00
0005432611810	3472	Economy	11700.00
0005435626719	3472	Economy	11700.00
0005435903108	3472	Economy	11700.00
0005434880808	3472	Economy	11700.00
0005435127493	3472	Economy	11700.00
0005435903029	3472	Economy	11700.00
0005435127500	3472	Economy	11700.00
0005434880814	3472	Economy	11700.00
0005434880769	3472	Economy	11700.00
0005435914725	3472	Economy	11700.00
0005434938675	3472	Economy	11700.00
0005434880796	3472	Economy	11700.00
0005434880804	3472	Economy	11700.00
0005435903094	3472	Economy	11700.00
0005435127483	3472	Economy	11700.00
0005435913990	3472	Economy	11700.00
0005435626722	3472	Economy	11700.00
0005435127471	3472	Economy	11700.00
0005435127499	3472	Economy	11700.00
0005434880774	3472	Economy	11700.00
0005432613973	3472	Economy	11700.00
0005434427404	3472	Economy	11700.00
0005434880768	3472	Economy	11700.00
0005435914012	3472	Economy	11700.00
0005435127481	3472	Economy	12800.00
0005435914746	3472	Economy	12800.00
0005434880798	3472	Economy	11700.00
0005434880790	3472	Economy	11700.00
0005435626713	3472	Economy	11700.00
0005434880775	3472	Economy	12800.00
0005434880827	3472	Economy	12800.00
0005434880771	3472	Economy	11700.00
0005435626699	3472	Economy	11700.00
0005434880799	3472	Economy	11700.00
0005435127487	3472	Economy	11700.00
0005432800225	3472	Economy	11700.00
0005432800230	3472	Economy	11700.00
0005434880802	3472	Economy	11700.00
0005435626705	3472	Economy	11700.00
0005432800217	3472	Economy	11700.00
0005434880770	3472	Economy	11700.00
0005435914720	3472	Economy	11700.00
0005435841106	3472	Economy	11700.00
0005434880829	3472	Economy	11700.00
0005435127479	3472	Economy	11700.00
0005434880824	3472	Economy	11700.00
0005435127488	3472	Economy	11700.00
0005434880815	3472	Economy	11700.00
0005435626698	3472	Economy	11700.00
0005434938676	3472	Economy	11700.00
0005435127474	3472	Economy	11700.00
0005435902948	3472	Economy	11700.00
0005435127484	3472	Economy	11700.00
0005434880791	3472	Economy	11700.00
0005434938670	3472	Economy	11700.00
0005435127497	3472	Economy	11700.00
0005435626691	3472	Economy	11700.00
0005435626702	3472	Economy	11700.00
0005434880778	3472	Economy	11700.00
0005434880831	3472	Economy	11700.00
0005435626718	3472	Economy	11700.00
0005434938672	3472	Economy	11700.00
0005434427413	3472	Economy	11700.00
0005435626706	3472	Economy	11700.00
0005435903027	3472	Economy	11700.00
0005434880793	3472	Economy	11700.00
0005435626711	3472	Economy	11700.00
0005435626716	3472	Economy	11700.00
0005435127482	3472	Economy	11700.00
0005435626693	3472	Economy	11700.00
0005435127472	3472	Economy	11700.00
0005435626695	3472	Economy	11700.00
0005432800220	3472	Economy	11700.00
0005432800228	3472	Economy	11700.00
0005434880817	3472	Economy	11700.00
0005434880818	3472	Economy	11700.00
0005434880821	3472	Economy	11700.00
0005435626690	3472	Economy	11700.00
0005435902949	3472	Economy	11700.00
0005435127494	3472	Economy	11700.00
0005435127480	3472	Economy	11700.00
0005435626692	3472	Economy	11700.00
0005432183525	3472	Economy	11700.00
0005435914023	3472	Economy	11700.00
0005435903122	3472	Economy	11700.00
0005434938669	3472	Economy	11700.00
0005435903076	3472	Economy	11700.00
0005434427418	3472	Economy	11700.00
0005434880813	3472	Economy	11700.00
0005435626723	3472	Economy	11700.00
0005434880835	3472	Economy	11700.00
0005434880832	3472	Economy	11700.00
0005434427408	3472	Economy	11700.00
0005435903082	3472	Economy	11700.00
0005434880794	3472	Economy	11700.00
0005435903030	3472	Economy	11700.00
0005435626714	3472	Economy	11700.00
0005434427417	3472	Economy	11700.00
0005434880819	3472	Economy	11700.00
0005432800227	3472	Economy	11700.00
0005434880767	3472	Economy	11700.00
0005432800223	3472	Economy	12800.00
0005435626712	3472	Economy	12800.00
0005434938678	3472	Economy	12800.00
0005434880809	3472	Economy	12800.00
0005435626696	3472	Economy	12800.00
0005435127475	3472	Economy	11700.00
0005432800224	3472	Economy	11700.00
0005435626704	3472	Economy	11700.00
0005435626700	3472	Economy	11700.00
0005434880820	3472	Economy	11700.00
0005435903038	3472	Economy	11700.00
0005432800219	3472	Economy	11700.00
0005434880787	3472	Economy	11700.00
0005435903031	3472	Economy	11700.00
0005432800218	3472	Economy	11700.00
0005432613975	3472	Economy	11700.00
0005435626697	3472	Economy	11700.00
0005434427411	3472	Economy	11700.00
0005434880803	3472	Economy	11700.00
0005434880785	3472	Economy	11700.00
0005434880773	3472	Economy	11700.00
0005434938680	3472	Economy	11700.00
0005435841114	3472	Economy	11700.00
0005434880833	3472	Economy	11700.00
0005434880807	3472	Economy	11700.00
0005434880772	3472	Economy	11700.00
0005435841112	3472	Economy	11700.00
0005435127490	3472	Economy	11700.00
0005434880811	3472	Economy	11700.00
0005434880800	3472	Economy	11700.00
0005435626717	3472	Economy	11700.00
0005435626710	3472	Economy	11700.00
0005434880788	3472	Economy	11700.00
0005434880781	3472	Economy	11700.00
0005434880801	3472	Economy	11700.00
0005435903039	3472	Economy	11700.00
0005434880812	3472	Economy	11700.00
0005435127468	3472	Economy	11700.00
0005434938681	3472	Economy	11700.00
0005435127489	3472	Economy	11700.00
0005435626724	3472	Economy	11700.00
0005435903081	3472	Economy	11700.00
0005434880784	3472	Economy	11700.00
0005432611809	3472	Economy	11700.00
0005435127469	3472	Economy	11700.00
0005434880810	3472	Economy	11700.00
0005432800221	3472	Economy	11700.00
0005434427419	3472	Economy	11700.00
0005434880806	3472	Economy	11700.00
0005435626721	3472	Economy	11700.00
0005435127473	3472	Economy	11700.00
0005434938679	3472	Economy	11700.00
0005435127476	3472	Economy	11700.00
0005435127492	3472	Economy	11700.00
0005434880805	3472	Economy	11700.00
0005432800231	3472	Economy	11700.00
0005434880789	3472	Economy	11700.00
0005435127496	3472	Economy	11700.00
0005432800232	3472	Economy	11700.00
0005435626701	3472	Economy	11700.00
0005434880825	3472	Economy	11700.00
0005434880792	3472	Economy	11700.00
0005435913977	3472	Economy	11700.00
0005434427406	3472	Economy	11700.00
0005435903050	3472	Economy	11700.00
0005435841115	3472	Economy	11700.00
0005434880826	3472	Economy	11700.00
0005434880828	3472	Economy	11700.00
0005435914005	3472	Economy	11700.00
0005435626715	3472	Economy	11700.00
0005434880266	14533	Business	35000.00
0005434880149	14533	Business	35000.00
0005435127099	14533	Business	35000.00
0005434880142	14533	Business	35000.00
0005434880220	14533	Business	35000.00
0005435914757	14533	Business	35000.00
0005434879991	14533	Business	35000.00
0005435914146	14533	Business	35000.00
0005435903193	14533	Business	35000.00
0005435626508	14533	Business	35000.00
0005432799937	14533	Business	35000.00
0005434879759	14533	Business	35000.00
0005435903189	14533	Business	35000.00
0005435626513	14533	Business	35000.00
0005435914132	14533	Business	35000.00
0005432799947	14533	Business	35000.00
0005432800094	14533	Business	35000.00
0005435127236	14533	Business	35000.00
0005434879818	14533	Business	35000.00
0005434880011	14533	Business	35000.00
0005434880008	14533	Business	35000.00
0005434427053	14533	Business	35000.00
0005435914147	14533	Comfort	19900.00
0005435914142	14533	Comfort	19900.00
0005435903194	14533	Comfort	19900.00
0005435626510	14533	Comfort	19900.00
0005432799939	14533	Comfort	19900.00
0005434427056	14533	Comfort	19900.00
0005434427270	14533	Comfort	19900.00
0005432799845	14533	Comfort	19900.00
0005435626500	14533	Comfort	19900.00
0005435903191	14533	Comfort	19900.00
0005434879845	14533	Comfort	19900.00
0005434879946	14533	Comfort	19900.00
0005435903192	14533	Comfort	19900.00
0005434880254	14533	Comfort	19900.00
0005434427115	14533	Comfort	19900.00
0005435127061	14533	Comfort	19900.00
0005435626524	14533	Comfort	19900.00
0005432799906	14533	Comfort	19900.00
0005432800095	14533	Comfort	19900.00
0005432799873	14533	Comfort	19900.00
0005435127248	14533	Comfort	19900.00
0005434427151	14533	Comfort	19900.00
0005434427209	14533	Comfort	19900.00
0005435626501	14533	Comfort	19900.00
0005435127230	14533	Comfort	19900.00
0005435126993	14533	Comfort	19900.00
0005432799955	14533	Comfort	19900.00
0005435626415	14533	Comfort	19900.00
0005435903182	14533	Comfort	19900.00
0005434879641	14533	Comfort	19900.00
0005435127232	14533	Comfort	19900.00
0005434880411	14533	Comfort	19900.00
0005434879926	14533	Comfort	19900.00
0005434938530	14533	Comfort	19900.00
0005432611772	14533	Economy	11700.00
0005435914756	14533	Economy	11700.00
0005434879925	14533	Economy	11700.00
0005434879924	14533	Economy	11700.00
0005434880024	14533	Economy	11700.00
0005435914754	14533	Economy	11700.00
0005435626471	14533	Economy	11700.00
0005432799968	14533	Economy	11700.00
0005434879651	14533	Economy	11700.00
0005435127116	14533	Economy	11700.00
0005434880290	14533	Economy	11700.00
0005435914130	14533	Economy	11700.00
0005434879834	14533	Economy	11700.00
0005434427224	14533	Economy	11700.00
0005432800034	14533	Economy	11700.00
0005434880009	14533	Economy	11700.00
0005435127163	14533	Economy	11700.00
0005435127056	14533	Economy	11700.00
0005435626525	14533	Economy	11700.00
0005435127035	14533	Economy	11700.00
0005434427248	14533	Economy	11700.00
0005434879921	14533	Economy	11700.00
0005434880007	14533	Economy	11700.00
0005432059560	14533	Economy	11700.00
0005434879844	14533	Economy	11700.00
0005434879652	14533	Economy	11700.00
0005434426989	14533	Economy	11700.00
0005434880267	14533	Economy	11700.00
0005435914150	14533	Economy	11700.00
0005435626521	14533	Economy	11700.00
0005435127154	14533	Economy	11700.00
0005434879936	14533	Economy	11700.00
0005435914118	14533	Economy	11700.00
0005435626446	14533	Economy	11700.00
0005434938603	14533	Economy	11700.00
0005435127064	14533	Economy	11700.00
0005435127127	14533	Economy	11700.00
0005434879953	14533	Economy	11700.00
0005434427156	14533	Economy	11700.00
0005435914138	14533	Economy	11700.00
0005434880457	14533	Economy	11700.00
0005434879577	14533	Economy	11700.00
0005435914124	14533	Economy	11700.00
0005435914133	14533	Economy	11700.00
0005434880402	14533	Economy	12800.00
0005435626461	14533	Economy	11700.00
0005434938552	14533	Economy	12800.00
0005434427011	14533	Economy	11700.00
0005435127086	14533	Economy	11700.00
0005434427054	14533	Economy	12800.00
0005434879400	14533	Economy	12800.00
0005435626455	14533	Economy	11700.00
0005435903184	14533	Economy	11700.00
0005435127034	14533	Economy	11700.00
0005434880381	14533	Economy	11700.00
0005435626445	14533	Economy	11700.00
0005435914131	14533	Economy	11700.00
0005434879665	14533	Economy	11700.00
0005432799954	14533	Economy	11700.00
0005432607631	14533	Economy	11700.00
0005434427154	14533	Economy	11700.00
0005435626519	14533	Economy	11700.00
0005434879932	14533	Economy	11700.00
0005434880042	14533	Economy	11700.00
0005435127143	14533	Economy	11700.00
0005435626518	14533	Economy	11700.00
0005434427114	14533	Economy	11700.00
0005435127162	14533	Economy	11700.00
0005435127126	14533	Economy	11700.00
0005434879941	14533	Economy	11700.00
0005435626520	14533	Economy	11700.00
0005435914135	14533	Economy	11700.00
0005435127301	14533	Economy	11700.00
0005435127107	14533	Economy	11700.00
0005435903190	14533	Economy	11700.00
0005434427093	14533	Economy	11700.00
0005435126992	14533	Economy	11700.00
0005434880094	14533	Economy	11700.00
0005435626447	14533	Economy	11700.00
0005435914123	14533	Economy	11700.00
0005432800006	14533	Economy	11700.00
0005434880239	14533	Economy	11700.00
0005434938498	14533	Economy	11700.00
0005435914116	14533	Economy	11700.00
0005434427012	14533	Economy	11700.00
0005435914129	14533	Economy	11700.00
0005435914755	14533	Economy	11700.00
0005435914126	14533	Economy	11700.00
0005434938529	14533	Economy	11700.00
0005434880345	14533	Economy	11700.00
0005435914141	14533	Economy	11700.00
0005434879689	14533	Economy	11700.00
0005432799907	14533	Economy	11700.00
0005434879743	14533	Economy	11700.00
0005435127065	14533	Economy	11700.00
0005432799948	14533	Economy	11700.00
0005435914145	14533	Economy	11700.00
0005434427202	14533	Economy	11700.00
0005435903185	14533	Economy	11700.00
0005435914758	14533	Economy	11700.00
0005434880348	14533	Economy	11700.00
0005434938528	14533	Economy	11700.00
0005435914128	14533	Economy	11700.00
0005434880135	14533	Economy	11700.00
0005435903186	14533	Economy	11700.00
0005432800079	14533	Economy	11700.00
0005432800128	14533	Economy	11700.00
0005435903187	14533	Economy	11700.00
0005435903195	14533	Economy	11700.00
0005435626456	14533	Economy	11700.00
0005435914137	14533	Economy	11700.00
0005435914136	14533	Economy	11700.00
0005435914143	14533	Economy	11700.00
0005434879401	14533	Economy	11700.00
0005434879935	14533	Economy	11700.00
0005434938512	14533	Economy	11700.00
0005435841847	14533	Economy	11700.00
0005435914119	14533	Economy	11700.00
0005434938553	14533	Economy	11700.00
0005434880028	14533	Economy	11700.00
0005435626517	14533	Economy	11700.00
0005434879850	14533	Economy	12800.00
0005434880056	14533	Economy	12800.00
0005434427203	14533	Economy	12800.00
0005435914760	14533	Economy	12800.00
0005434880297	14533	Economy	12800.00
0005435903180	14533	Economy	11700.00
0005435626509	14533	Economy	11700.00
0005434880344	14533	Economy	11700.00
0005432800004	14533	Economy	11700.00
0005435914148	14533	Economy	11700.00
0005434879742	14533	Economy	11700.00
0005434879760	14533	Economy	11700.00
0005434880160	14533	Economy	11700.00
0005434938511	14533	Economy	11700.00
0005434879863	14533	Economy	11700.00
0005434427057	14533	Economy	11700.00
0005435914120	14533	Economy	11700.00
0005432799872	14533	Economy	11700.00
0005435127231	14533	Economy	11700.00
0005434879864	14533	Economy	11700.00
0005435903188	14533	Economy	11700.00
0005434427094	14533	Economy	11700.00
0005435626503	14533	Economy	11700.00
0005434427155	14533	Economy	11700.00
0005435127300	14533	Economy	11700.00
0005435626522	14533	Economy	11700.00
0005435914144	14533	Economy	11700.00
0005435127087	14533	Economy	11700.00
0005434427141	14533	Economy	11700.00
0005432611771	14533	Economy	11700.00
0005435914149	14533	Economy	11700.00
0005435127196	14533	Economy	11700.00
0005435914127	14533	Economy	11700.00
0005435914122	14533	Economy	11700.00
0005434879952	14533	Economy	11700.00
0005434880458	14533	Economy	11700.00
0005434938556	14533	Economy	11700.00
0005434880241	14533	Economy	11700.00
0005432800035	14533	Economy	11700.00
0005435914121	14533	Economy	11700.00
0005432799964	14533	Economy	11700.00
0005432799943	14533	Economy	11700.00
0005435914140	14533	Economy	11700.00
0005434427208	14533	Economy	11700.00
0005435127168	14533	Economy	11700.00
0005434427249	14533	Economy	11700.00
0005434880034	14533	Economy	11700.00
0005435126994	14533	Economy	11700.00
0005435914134	14533	Economy	11700.00
0005434880456	14533	Economy	11700.00
0005434938582	14533	Economy	11700.00
0005435626514	14533	Economy	11700.00
0005432799999	14533	Economy	11700.00
0005434879940	14533	Economy	11700.00
0005432799967	14533	Economy	11700.00
0005434879819	14533	Economy	11700.00
0005434879968	14533	Economy	11700.00
0005432800107	14533	Economy	11700.00
0005435914151	14533	Economy	11700.00
0005432607630	14533	Economy	11700.00
0005434880010	14533	Economy	11700.00
0005435127249	14533	Economy	11700.00
0005434938568	14533	Economy	11700.00
0005434938497	14533	Economy	11700.00
0005435914759	14533	Economy	11700.00
0005435914125	14533	Economy	11700.00
0005434880064	14533	Economy	11700.00
0005432799998	14533	Economy	11700.00
0005434427150	14533	Economy	11700.00
0005434938583	14533	Economy	11700.00
0005435914117	14533	Economy	11700.00
0005435127258	14533	Economy	11700.00
0005434879758	14533	Economy	11700.00
0005435626504	14533	Economy	11700.00
0005435914139	14533	Economy	11700.00
0005432800060	14533	Economy	11700.00
0005434879690	14533	Economy	11700.00
0005435127042	14533	Economy	11700.00
0005435903181	14533	Economy	11700.00
0005435127058	14533	Economy	11700.00
0005434880159	14533	Economy	11700.00
0005435903183	14533	Economy	11700.00
0005434325961	3610	Economy	16300.00
0005435890037	3610	Economy	16300.00
0005434325960	3610	Economy	16300.00
0005435889975	3610	Economy	14800.00
0005435890025	3610	Economy	14800.00
0005434325965	3610	Economy	14800.00
0005435889987	3610	Economy	14800.00
0005434325958	3610	Economy	14800.00
0005435890012	3610	Economy	14800.00
0005434325966	3610	Economy	14800.00
0005434325964	3610	Economy	14800.00
0005435889988	3610	Economy	14800.00
0005434325963	3610	Economy	14800.00
0005435890013	3610	Economy	14800.00
0005434312376	3610	Economy	14800.00
0005434325959	3610	Economy	14800.00
0005434325962	3610	Economy	14800.00
0005435890064	15607	Economy	16300.00
0005435890065	15607	Economy	14800.00
0005434325863	15607	Economy	14800.00
0005434325831	15607	Economy	14800.00
0005435890063	15607	Economy	14800.00
0005434325904	15607	Economy	14800.00
0005435890060	15607	Economy	14800.00
0005434325898	15607	Economy	14800.00
0005434325899	15607	Economy	14800.00
0005434325905	15607	Economy	14800.00
0005434325897	15607	Economy	14800.00
0005434325884	15607	Economy	14800.00
0005434325893	15607	Economy	14800.00
0005434325883	15607	Economy	14800.00
0005434325889	15607	Economy	14800.00
0005435890061	15607	Economy	14800.00
0005434325843	15607	Economy	14800.00
0005435890062	15607	Economy	14800.00
0005434325830	15607	Economy	14800.00
0005434325885	15607	Economy	14800.00
0005433420566	626	Economy	4500.00
0005435958104	626	Economy	4100.00
0005435958107	626	Economy	4100.00
0005435958103	626	Economy	4100.00
0005435958100	626	Economy	4100.00
0005435958106	626	Economy	4100.00
0005433420540	626	Economy	4100.00
0005433420539	626	Economy	4100.00
0005433420522	626	Economy	4100.00
0005435958102	626	Economy	4100.00
0005435958101	626	Economy	4100.00
0005435958105	626	Economy	4100.00
0005435958099	626	Economy	4100.00
0005435957953	15156	Economy	4500.00
0005433420634	15156	Economy	4500.00
0005435957984	15156	Economy	4500.00
0005433420630	15156	Economy	4100.00
0005433420632	15156	Economy	4100.00
0005435957992	15156	Economy	4100.00
0005435958012	15156	Economy	4100.00
0005435957983	15156	Economy	4100.00
0005435957987	15156	Economy	4100.00
0005435958034	15156	Economy	4100.00
0005435958037	15156	Economy	4100.00
0005435957980	15156	Economy	4100.00
0005435957952	15156	Economy	4100.00
0005435957954	15156	Economy	4100.00
0005435958036	15156	Economy	4100.00
0005435957993	15156	Economy	4100.00
0005435957990	15156	Economy	4100.00
0005435957932	15156	Economy	4100.00
0005435958038	15156	Economy	4100.00
0005433420635	15156	Economy	4100.00
0005433420633	15156	Economy	4100.00
0005435957981	15156	Economy	4100.00
0005435957964	15156	Economy	4100.00
0005435957970	15156	Economy	4100.00
0005435957982	15156	Economy	4100.00
0005435957931	15156	Economy	4100.00
0005435957969	15156	Economy	4100.00
0005435957958	15156	Economy	4100.00
0005433420631	15156	Economy	4100.00
0005435957959	15156	Economy	4100.00
0005433420636	15156	Economy	4100.00
0005434247194	8926	Economy	10400.00
0005434247193	8926	Economy	10400.00
0005434247200	8926	Economy	10400.00
0005434247218	16082	Economy	10400.00
0005434247217	16082	Economy	10400.00
0005434096773	11829	Economy	14700.00
0005434096772	11829	Economy	14700.00
0005434096765	11829	Economy	13400.00
0005434096768	11829	Economy	13400.00
0005434096771	11829	Economy	13400.00
0005434096774	11829	Economy	13400.00
0005434096766	11829	Economy	13400.00
0005435163375	4430	Economy	13400.00
0005435933519	4430	Economy	13400.00
0005435933517	4430	Economy	13400.00
0005435933512	4430	Economy	12200.00
0005435933514	4430	Economy	12200.00
0005435933526	4430	Economy	12200.00
0005435933532	4430	Economy	12200.00
0005435163373	4430	Economy	12200.00
0005435163376	4430	Economy	12200.00
0005435933525	4430	Economy	12200.00
0005435933510	4430	Economy	12200.00
0005435933518	4430	Economy	12200.00
0005435933515	4430	Economy	12200.00
0005435163371	4430	Economy	12200.00
0005435163370	4430	Economy	12200.00
0005435163374	4430	Economy	12200.00
0005435933524	4430	Economy	12200.00
0005435163372	4430	Economy	12200.00
0005435933511	4430	Economy	12200.00
0005435163331	29515	Economy	13400.00
0005435163322	29515	Economy	13400.00
0005435163320	29515	Economy	12200.00
0005435163317	29515	Economy	12200.00
0005435933552	29515	Economy	12200.00
0005435933550	29515	Economy	12200.00
0005435163330	29515	Economy	12200.00
0005435933548	29515	Economy	12200.00
0005435933549	29515	Economy	12200.00
0005435163332	29515	Economy	12200.00
0005435163329	29515	Economy	12200.00
0005435933551	29515	Economy	12200.00
0005435163321	29515	Economy	12200.00
0005435163319	29515	Economy	12200.00
0005433404913	2879	Business	12600.00
0005435797860	2879	Business	12600.00
0005435797863	2879	Economy	4200.00
0005433404927	2879	Economy	4600.00
0005433404910	2879	Economy	4200.00
0005433404938	2879	Economy	4200.00
0005435797867	2879	Economy	4200.00
0005435797866	2879	Economy	4200.00
0005433404937	2879	Economy	4200.00
0005433404983	2879	Economy	4200.00
0005435797868	2879	Economy	4200.00
0005435797862	2879	Economy	4200.00
0005435797864	2879	Economy	4200.00
0005433404911	2879	Economy	4200.00
0005433404985	2879	Economy	4200.00
0005435797865	2879	Economy	4200.00
0005435797861	2879	Economy	4200.00
0005435797769	29327	Business	12600.00
0005433405017	29327	Business	12600.00
0005433405012	29327	Economy	4200.00
0005435797688	29327	Economy	4600.00
0005435797772	29327	Economy	4200.00
0005435797737	29327	Economy	4200.00
0005433405016	29327	Economy	4200.00
0005435797773	29327	Economy	4200.00
0005433405018	29327	Economy	4200.00
0005435797752	29327	Economy	4200.00
0005435797744	29327	Economy	4200.00
0005433405015	29327	Economy	4200.00
0005435797764	29327	Economy	4200.00
0005433405011	29327	Economy	4200.00
0005433405013	29327	Economy	4200.00
0005433405014	29327	Economy	4200.00
0005435797739	29327	Economy	4200.00
0005435797712	29327	Economy	4200.00
0005435797713	29327	Economy	4200.00
0005435797697	29327	Economy	4200.00
0005435797738	29327	Economy	4200.00
0005435797809	29327	Economy	4200.00
0005435376399	5791	Economy	6800.00
0005434948246	5823	Economy	6800.00
0005434948247	5823	Economy	6800.00
0005434948248	5823	Economy	6800.00
0005434948249	5823	Economy	6800.00
0005434948201	16350	Economy	6800.00
0005434948194	16350	Economy	6800.00
0005435376424	16350	Economy	6800.00
0005434948193	16350	Economy	6800.00
0005434948200	16350	Economy	6800.00
0005434948183	16350	Economy	6800.00
0005435376421	16350	Economy	6800.00
0005435376420	16350	Economy	6800.00
0005435376422	16350	Economy	6800.00
0005434948179	16350	Economy	6800.00
0005435376423	16350	Economy	6800.00
0005433962498	6935	Business	21400.00
0005433962467	6935	Business	21400.00
0005433962517	6935	Business	21400.00
0005433962495	6935	Business	21400.00
0005433962464	6935	Business	21400.00
0005433962503	6935	Business	21400.00
0005433962482	6935	Business	21400.00
0005433962481	6935	Business	21400.00
0005433962458	6935	Business	21400.00
0005433962473	6935	Business	21400.00
0005433962492	6935	Economy	7100.00
0005433962484	6935	Economy	7100.00
0005433962504	6935	Economy	7100.00
0005433962490	6935	Economy	7100.00
0005433962478	6935	Economy	7100.00
0005433962486	6935	Economy	7100.00
0005433962487	6935	Economy	7100.00
0005433962469	6935	Economy	7800.00
0005433962463	6935	Economy	7800.00
0005433962501	6935	Economy	7800.00
0005433962499	6935	Economy	7800.00
0005433962519	6935	Economy	7800.00
0005433962460	6935	Economy	7100.00
0005433962509	6935	Economy	7100.00
0005433962477	6935	Economy	7100.00
0005433962502	6935	Economy	7100.00
0005433962488	6935	Economy	7100.00
0005433962512	6935	Economy	7100.00
0005433962475	6935	Economy	7100.00
0005433962505	6935	Economy	7100.00
0005433962483	6935	Economy	7100.00
0005433962516	6935	Economy	7100.00
0005433962461	6935	Economy	7100.00
0005433962485	6935	Economy	7100.00
0005433962511	6935	Economy	7100.00
0005433962479	6935	Economy	7100.00
0005433962489	6935	Economy	7100.00
0005433962506	6935	Economy	7100.00
0005433962510	6935	Economy	7100.00
0005433962465	6935	Economy	7100.00
0005433962494	6935	Economy	7100.00
0005433962507	6935	Economy	7100.00
0005433962515	6935	Economy	7100.00
0005433962518	6935	Economy	7100.00
0005433962514	6935	Economy	7100.00
0005433962456	6935	Economy	7100.00
0005433962471	6935	Economy	7100.00
0005433962491	6935	Economy	7100.00
0005433962462	6935	Economy	7100.00
0005433962513	6935	Economy	7100.00
0005433962457	6935	Economy	7100.00
0005433962480	6935	Economy	7100.00
0005433962493	6935	Economy	7100.00
0005433962508	6935	Economy	7100.00
0005433962497	6935	Economy	7100.00
0005433962466	6935	Economy	7100.00
0005433962496	6935	Economy	7100.00
0005433962468	6935	Economy	7100.00
0005433962472	6935	Economy	7100.00
0005433962474	6935	Economy	7100.00
0005433962500	6935	Economy	7100.00
0005433962470	6935	Economy	7100.00
0005433962459	6935	Economy	7100.00
0005433962476	6935	Economy	7100.00
0005433961636	25812	Business	21400.00
0005433961556	25812	Business	21400.00
0005433961737	25812	Business	21400.00
0005433961760	25812	Business	21400.00
0005433961803	25812	Business	21400.00
0005433961681	25812	Economy	7100.00
0005433961663	25812	Economy	7100.00
0005433961637	25812	Economy	7100.00
0005433961758	25812	Economy	7100.00
0005433961836	25812	Economy	7100.00
0005433961535	25812	Economy	7100.00
0005433961815	25812	Economy	7100.00
0005433961716	25812	Economy	7800.00
0005433961705	25812	Economy	7800.00
0005433961754	25812	Economy	7800.00
0005433961578	25812	Economy	7800.00
0005433961808	25812	Economy	7800.00
0005433961616	25812	Economy	7100.00
0005433961829	25812	Economy	7100.00
0005433961735	25812	Economy	7100.00
0005433961602	25812	Economy	7100.00
0005433961603	25812	Economy	7100.00
0005433961759	25812	Economy	7100.00
0005433961673	25812	Economy	7100.00
0005433961787	25812	Economy	7100.00
0005433961708	25812	Economy	7100.00
0005433961738	25812	Economy	7100.00
0005433961554	25812	Economy	7100.00
0005433961555	25812	Economy	7100.00
0005433961845	25812	Economy	7100.00
0005433961709	25812	Economy	7100.00
0005433961534	25812	Economy	7100.00
0005433961838	25812	Economy	7100.00
0005433961809	25812	Economy	7100.00
0005433961710	25812	Economy	7100.00
0005433961523	25812	Economy	7100.00
0005433961665	25812	Economy	7100.00
0005433961766	25812	Economy	7100.00
0005433961804	25812	Economy	7100.00
0005433961806	25812	Economy	7100.00
0005433961826	25812	Economy	7100.00
0005433961533	25812	Economy	7100.00
0005433961816	25812	Economy	7100.00
0005433961802	25812	Economy	7100.00
0005433961777	25812	Economy	7100.00
0005433961524	25812	Economy	7100.00
0005433961650	25812	Economy	7100.00
0005433961844	25812	Economy	7100.00
0005433961728	25812	Economy	7100.00
0005433961753	25812	Economy	7100.00
0005433961431	25812	Economy	7100.00
0005433961830	25812	Economy	7100.00
0005433961723	25812	Economy	7100.00
0005433961807	25812	Economy	7100.00
0005433961789	25812	Economy	7100.00
0005433961767	25812	Economy	7100.00
0005433961786	25812	Economy	7100.00
0005433961739	25812	Economy	7100.00
0005433961788	25812	Economy	7100.00
0005433961719	25812	Economy	7100.00
0005433961736	25812	Economy	7100.00
0005433961704	25812	Economy	7100.00
0005435082917	24483	Economy	3900.00
0005435082886	24483	Economy	3900.00
0005435082939	24483	Economy	3900.00
0005435082922	24483	Economy	3900.00
0005435082949	24483	Economy	3900.00
0005435082903	24483	Economy	3900.00
0005435082937	24483	Economy	3900.00
0005435082938	24483	Economy	3900.00
0005435082923	24483	Economy	3900.00
0005435082916	24483	Economy	3900.00
0005435082909	24483	Economy	3900.00
0005435083006	26098	Economy	3900.00
0005435083007	26098	Economy	3900.00
0005435083004	26098	Economy	3900.00
0005435083005	26098	Economy	3900.00
0005435083001	26098	Economy	3900.00
0005435083003	26098	Economy	3900.00
0005435083000	26098	Economy	3900.00
0005435082999	26098	Economy	3900.00
0005435082998	26098	Economy	3900.00
0005435083002	26098	Economy	3900.00
0005435082997	26098	Economy	3900.00
0005433534539	5099	Business	18000.00
0005434245768	5099	Business	18000.00
0005434245782	5099	Business	18000.00
0005434245785	5099	Business	18000.00
0005433534538	5099	Economy	6600.00
0005433534540	5099	Economy	6000.00
0005435286718	5099	Economy	6000.00
0005434245789	5099	Economy	6000.00
0005434245787	5099	Economy	6000.00
0005435286720	5099	Economy	6000.00
0005434245781	5099	Economy	6000.00
0005434245792	5099	Economy	6000.00
0005434245769	5099	Economy	6000.00
0005434245773	5099	Economy	6000.00
0005434245779	5099	Economy	6000.00
0005434245772	5099	Economy	6000.00
0005435286719	5099	Economy	6000.00
0005434245780	5099	Economy	6000.00
0005434245774	5099	Economy	6600.00
0005434245771	5099	Economy	6600.00
0005434245786	5099	Economy	6600.00
0005434245776	5099	Economy	6000.00
0005434245770	5099	Economy	6000.00
0005434245783	5099	Economy	6000.00
0005434245777	5099	Economy	6000.00
0005434245784	5099	Economy	6000.00
0005433534543	5099	Economy	6000.00
0005434245788	5099	Economy	6000.00
0005434245790	5099	Economy	6000.00
0005434245791	5099	Economy	6000.00
0005434245775	5099	Economy	6000.00
0005434245778	5099	Economy	6000.00
0005433616666	5098	Business	18000.00
0005433786019	5098	Business	18000.00
0005432106857	5098	Business	18000.00
0005433616679	5098	Business	18000.00
0005432106874	5098	Business	18000.00
0005433616671	5098	Business	18000.00
0005433616662	5098	Business	18000.00
0005433616661	5098	Business	18000.00
0005432106855	5098	Business	18000.00
0005432106877	5098	Business	18000.00
0005433616684	5098	Business	18000.00
0005433616690	5098	Business	18000.00
0005433616685	5098	Business	18000.00
0005432145168	5098	Business	18000.00
0005433785982	5098	Business	18000.00
0005433785995	5098	Business	18000.00
0005433616688	5098	Business	18000.00
0005433616672	5098	Business	18000.00
0005433616710	5098	Business	18000.00
0005432145167	5098	Business	18000.00
0005433616709	5098	Business	18000.00
0005433616674	5098	Business	18000.00
0005433616708	5098	Business	18000.00
0005433616665	5098	Business	18000.00
0005432106867	5098	Business	18000.00
0005433786036	5098	Business	18000.00
0005433785987	5098	Business	18000.00
0005432106861	5098	Economy	6600.00
0005433786022	5098	Economy	6600.00
0005432106851	5098	Economy	6600.00
0005433616663	5098	Economy	6600.00
0005433616689	5098	Economy	6600.00
0005433785983	5098	Economy	6600.00
0005433785992	5098	Economy	6000.00
0005433786038	5098	Economy	6000.00
0005433616699	5098	Economy	6000.00
0005433616696	5098	Economy	6000.00
0005433786016	5098	Economy	6000.00
0005433785991	5098	Economy	6000.00
0005433785997	5098	Economy	6000.00
0005433616697	5098	Economy	6000.00
0005432106846	5098	Economy	6000.00
0005433616668	5098	Economy	6000.00
0005433616667	5098	Economy	6000.00
0005433616673	5098	Economy	6000.00
0005433616664	5098	Economy	6000.00
0005432106863	5098	Economy	6000.00
0005433785993	5098	Economy	6000.00
0005433785996	5098	Economy	6000.00
0005432106864	5098	Economy	6000.00
0005432106862	5098	Economy	6000.00
0005432106847	5098	Economy	6000.00
0005433616677	5098	Economy	6000.00
0005433786035	5098	Economy	6000.00
0005432667512	5098	Economy	6000.00
0005433786032	5098	Economy	6000.00
0005433616693	5098	Economy	6000.00
0005433786021	5098	Economy	6000.00
0005433786006	5098	Economy	6000.00
0005433786017	5098	Economy	6000.00
0005433616703	5098	Economy	6000.00
0005433616711	5098	Economy	6000.00
0005433616670	5098	Economy	6000.00
0005432106853	5098	Economy	6000.00
0005433786002	5098	Economy	6000.00
0005433786027	5098	Economy	6000.00
0005433786033	5098	Economy	6000.00
0005432106856	5098	Economy	6000.00
0005433786009	5098	Economy	6000.00
0005433786005	5098	Economy	6000.00
0005432106858	5098	Economy	6000.00
0005432106865	5098	Economy	6000.00
0005433786034	5098	Economy	6000.00
0005433616660	5098	Economy	6000.00
0005433785985	5098	Economy	6000.00
0005432106842	5098	Economy	6000.00
0005433786023	5098	Economy	6000.00
0005433785998	5098	Economy	6000.00
0005432106845	5098	Economy	6000.00
0005433616686	5098	Economy	6000.00
0005433786030	5098	Economy	6000.00
0005432106866	5098	Economy	6000.00
0005432106873	5098	Economy	6000.00
0005434230050	5098	Economy	6000.00
0005433786001	5098	Economy	6000.00
0005433785986	5098	Economy	6000.00
0005433785994	5098	Economy	6000.00
0005432106869	5098	Economy	6000.00
0005433616694	5098	Economy	6600.00
0005432106878	5098	Economy	6600.00
0005433786029	5098	Economy	6600.00
0005433616659	5098	Economy	6600.00
0005433616683	5098	Economy	6600.00
0005433616678	5098	Economy	6000.00
0005433616692	5098	Economy	6000.00
0005432106859	5098	Economy	6000.00
0005433616676	5098	Economy	6000.00
0005432106868	5098	Economy	6000.00
0005433786012	5098	Economy	6600.00
0005432106850	5098	Economy	6000.00
0005433785984	5098	Economy	6000.00
0005432106841	5098	Economy	6000.00
0005432106848	5098	Economy	6000.00
0005433786018	5098	Economy	6000.00
0005433616700	5098	Economy	6000.00
0005433786008	5098	Economy	6000.00
0005433786010	5098	Economy	6000.00
0005433616680	5098	Economy	6000.00
0005433786025	5098	Economy	6000.00
0005432106870	5098	Economy	6000.00
0005432665331	5098	Economy	6000.00
0005433616705	5098	Economy	6000.00
0005432106840	5098	Economy	6000.00
0005433785999	5098	Economy	6000.00
0005432106875	5098	Economy	6000.00
0005433616701	5098	Economy	6000.00
0005433786037	5098	Economy	6000.00
0005433616704	5098	Economy	6000.00
0005433616695	5098	Economy	6000.00
0005433616687	5098	Economy	6000.00
0005433616681	5098	Economy	6000.00
0005433786007	5098	Economy	6000.00
0005433616712	5098	Economy	6000.00
0005433616691	5098	Economy	6000.00
0005432106843	5098	Economy	6000.00
0005432106854	5098	Economy	6000.00
0005433616702	5098	Economy	6000.00
0005433786028	5098	Economy	6000.00
0005432106852	5098	Economy	6000.00
0005433786020	5098	Economy	6000.00
0005433616707	5098	Economy	6000.00
0005432106849	5098	Economy	6000.00
0005433616698	5098	Economy	6000.00
0005432106876	5098	Economy	6000.00
0005433785988	5098	Economy	6000.00
0005433616682	5098	Economy	6000.00
0005433786014	5098	Economy	6000.00
0005433786015	5098	Economy	6000.00
0005432145166	5098	Economy	6000.00
0005432106860	5098	Economy	6000.00
0005432667511	5098	Economy	6000.00
0005433616669	5098	Economy	6000.00
0005433616675	5098	Economy	6000.00
0005433786011	5098	Economy	6000.00
0005433786003	5098	Economy	6000.00
0005432106844	5098	Economy	6000.00
0005433786031	5098	Economy	6000.00
0005433786004	5098	Economy	6000.00
0005432106871	5098	Economy	6000.00
0005433786039	5098	Economy	6000.00
0005433616706	5098	Economy	6000.00
0005433786000	5098	Economy	6000.00
0005433786024	5098	Economy	6000.00
0005433786013	5098	Economy	6000.00
0005433785981	5098	Economy	6000.00
0005433785989	5098	Economy	6000.00
0005433786026	5098	Economy	6000.00
0005433785990	5098	Economy	6000.00
0005432106872	5098	Economy	6000.00
0005432336289	5092	Business	18000.00
0005434265847	5092	Business	18000.00
0005434265844	5092	Business	18000.00
0005434265838	5092	Business	18000.00
0005434150054	5092	Business	18000.00
0005432336202	5092	Business	18000.00
0005434173658	5092	Business	18000.00
0005435269875	5092	Business	18000.00
0005434173630	5092	Business	18000.00
0005435007501	5092	Business	18000.00
0005435007363	5092	Business	18000.00
0005433685565	5092	Business	18000.00
0005434150059	5092	Business	18000.00
0005435007455	5092	Business	18000.00
0005435007476	5092	Business	18000.00
0005434150050	5092	Business	18000.00
0005434229982	5092	Business	18000.00
0005434229991	5092	Business	18000.00
0005434150058	5092	Business	18000.00
0005434229993	5092	Economy	6600.00
0005434229984	5092	Economy	6600.00
0005432336330	5092	Economy	6600.00
0005432336259	5092	Economy	6600.00
0005434150052	5092	Economy	6600.00
0005432336219	5092	Economy	6000.00
0005434150051	5092	Economy	6000.00
0005435007485	5092	Economy	6000.00
0005433688841	5092	Economy	6000.00
0005434265839	5092	Economy	6000.00
0005435007466	5092	Economy	6000.00
0005435007516	5092	Economy	6000.00
0005434229985	5092	Economy	6000.00
0005434265841	5092	Economy	6000.00
0005434173632	5092	Economy	6000.00
0005434265842	5092	Economy	6000.00
0005435007572	5092	Economy	6000.00
0005434229986	5092	Economy	6000.00
0005433688840	5092	Economy	6000.00
0005434265846	5092	Economy	6000.00
0005434229987	5092	Economy	6000.00
0005435007512	5092	Economy	6000.00
0005435007456	5092	Economy	6000.00
0005435007551	5092	Economy	6000.00
0005434229978	5092	Economy	6000.00
0005435007541	5092	Economy	6000.00
0005435007552	5092	Economy	6000.00
0005434265849	5092	Economy	6000.00
0005434265848	5092	Economy	6000.00
0005434265830	5092	Economy	6000.00
0005434265829	5092	Economy	6000.00
0005434229983	5092	Economy	6000.00
0005434229989	5092	Economy	6000.00
0005435007505	5092	Economy	6000.00
0005432336224	5092	Economy	6000.00
0005435007447	5092	Economy	6000.00
0005434265850	5092	Economy	6000.00
0005434229994	5092	Economy	6000.00
0005435007542	5092	Economy	6000.00
0005432336204	5092	Economy	6000.00
0005435007557	5092	Economy	6000.00
0005435007559	5092	Economy	6000.00
0005434265837	5092	Economy	6000.00
0005432336250	5092	Economy	6000.00
0005434173656	5092	Economy	6000.00
0005434150057	5092	Economy	6000.00
0005434265832	5092	Economy	6000.00
0005432336249	5092	Economy	6000.00
0005435007408	5092	Economy	6000.00
0005434265833	5092	Economy	6600.00
0005432336283	5092	Economy	6600.00
0005434229980	5092	Economy	6600.00
0005434265836	5092	Economy	6600.00
0005435269877	5092	Economy	6000.00
0005434265834	5092	Economy	6000.00
0005432336267	5092	Economy	6000.00
0005434229981	5092	Economy	6600.00
0005435007500	5092	Economy	6000.00
0005435007341	5092	Economy	6000.00
0005434265840	5092	Economy	6000.00
0005434173629	5092	Economy	6000.00
0005435007373	5092	Economy	6000.00
0005435007465	5092	Economy	6000.00
0005434150055	5092	Economy	6000.00
0005435007374	5092	Economy	6000.00
0005433688839	5092	Economy	6000.00
0005435269880	5092	Economy	6000.00
0005432336220	5092	Economy	6000.00
0005434265843	5092	Economy	6000.00
0005434150056	5092	Economy	6000.00
0005434265835	5092	Economy	6000.00
0005435007449	5092	Economy	6000.00
0005434150053	5092	Economy	6000.00
0005434173657	5092	Economy	6000.00
0005433815452	5092	Economy	6000.00
0005435007477	5092	Economy	6000.00
0005432336277	5092	Economy	6000.00
0005434229988	5092	Economy	6000.00
0005434311254	5092	Economy	6000.00
0005435007421	5092	Economy	6000.00
0005434312356	5092	Economy	6000.00
0005434229990	5092	Economy	6000.00
0005435007362	5092	Economy	6000.00
0005434265831	5092	Economy	6000.00
0005435007342	5092	Economy	6000.00
0005435269881	5092	Economy	6000.00
0005434312363	5092	Economy	6000.00
0005432336308	5092	Economy	6000.00
0005434173633	5092	Economy	6000.00
0005434173631	5092	Economy	6000.00
0005434229979	5092	Economy	6000.00
0005434265845	5092	Economy	6000.00
0005432336265	5092	Economy	6000.00
0005435269876	5092	Economy	6000.00
0005434229992	5092	Economy	6000.00
0005434245532	8505	Business	18000.00
0005433785507	8505	Business	18000.00
0005434245512	8505	Business	18000.00
0005435270122	8505	Business	18000.00
0005433785682	8505	Business	18000.00
0005433785466	8505	Business	18000.00
0005433785595	8505	Business	18000.00
0005434245510	8505	Business	18000.00
0005433785675	8505	Business	18000.00
0005434245694	8505	Business	18000.00
0005433785611	8505	Business	18000.00
0005435270127	8505	Business	18000.00
0005435270113	8505	Business	18000.00
0005433785742	8505	Economy	6600.00
0005433785705	8505	Economy	6600.00
0005433785536	8505	Economy	6600.00
0005433785612	8505	Economy	6600.00
0005432666428	8505	Economy	6000.00
0005432659745	8505	Economy	6000.00
0005434245511	8505	Economy	6000.00
0005434245535	8505	Economy	6000.00
0005435270120	8505	Economy	6000.00
0005433785468	8505	Economy	6000.00
0005433785480	8505	Economy	6000.00
0005435270124	8505	Economy	6000.00
0005434245553	8505	Economy	6000.00
0005435270109	8505	Economy	6000.00
0005434245576	8505	Economy	6000.00
0005435270114	8505	Economy	6000.00
0005433785738	8505	Economy	6000.00
0005433785709	8505	Economy	6000.00
0005433785477	8505	Economy	6000.00
0005434245509	8505	Economy	6000.00
0005432666417	8505	Economy	6000.00
0005433785502	8505	Economy	6000.00
0005435270108	8505	Economy	6000.00
0005434245664	8505	Economy	6000.00
0005434245544	8505	Economy	6000.00
0005434245508	8505	Economy	6000.00
0005433785649	8505	Economy	6000.00
0005433785739	8505	Economy	6000.00
0005433785465	8505	Economy	6000.00
0005433785662	8505	Economy	6000.00
0005433785741	8505	Economy	6000.00
0005433785640	8505	Economy	6000.00
0005435270123	8505	Economy	6000.00
0005433785681	8505	Economy	6000.00
0005432666427	8505	Economy	6000.00
0005435270118	8505	Economy	6000.00
0005433785683	8505	Economy	6000.00
0005433785623	8505	Economy	6000.00
0005432666418	8505	Economy	6600.00
0005435270111	8505	Economy	6600.00
0005435270117	8505	Economy	6000.00
0005433785537	8505	Economy	6600.00
0005433785432	8505	Economy	6000.00
0005435270119	8505	Economy	6000.00
0005435270125	8505	Economy	6000.00
0005433785732	8505	Economy	6000.00
0005433785544	8505	Economy	6000.00
0005432659747	8505	Economy	6000.00
0005435270112	8505	Economy	6000.00
0005432666422	8505	Economy	6000.00
0005433785553	8505	Economy	6000.00
0005433785736	8505	Economy	6000.00
0005434245693	8505	Economy	6000.00
0005433785690	8505	Economy	6000.00
0005434245522	8505	Economy	6000.00
0005433785639	8505	Economy	6000.00
0005433785648	8505	Economy	6000.00
0005433785629	8505	Economy	6000.00
0005433785723	8505	Economy	6000.00
0005432659742	8505	Economy	6000.00
0005433785571	8505	Economy	6000.00
0005433785572	8505	Economy	6000.00
0005434245573	8505	Economy	6000.00
0005435270121	8505	Economy	6000.00
0005435270110	8505	Economy	6000.00
0005433785545	8505	Economy	6000.00
0005434245527	8505	Economy	6000.00
0005433785503	8505	Economy	6000.00
0005435270115	8505	Economy	6000.00
0005433785613	8505	Economy	6000.00
0005433785650	8505	Economy	6000.00
0005433785508	8505	Economy	6000.00
0005433785674	8505	Economy	6000.00
0005433785476	8505	Economy	6000.00
0005434245554	8505	Economy	6000.00
0005432663067	8505	Economy	6000.00
0005435270126	8505	Economy	6000.00
0005433785735	8505	Economy	6000.00
0005435270116	8505	Economy	6000.00
0005433785711	8505	Economy	6000.00
0005433615975	8506	Business	18000.00
0005433615888	8506	Business	18000.00
0005433616218	8506	Business	18000.00
0005433615995	8506	Business	18000.00
0005433616118	8506	Business	18000.00
0005433615709	8506	Business	18000.00
0005433616193	8506	Business	18000.00
0005433615902	8506	Business	18000.00
0005433615985	8506	Business	18000.00
0005433616174	8506	Business	18000.00
0005433616120	8506	Business	18000.00
0005433616101	8506	Business	18000.00
0005433616247	8506	Business	18000.00
0005433616220	8506	Business	18000.00
0005433616182	8506	Business	18000.00
0005433616097	8506	Economy	6600.00
0005433616121	8506	Economy	6600.00
0005433615905	8506	Economy	6600.00
0005433615862	8506	Economy	6000.00
0005433615916	8506	Economy	6000.00
0005433616196	8506	Economy	6000.00
0005433615653	8506	Economy	6000.00
0005433616181	8506	Economy	6000.00
0005433615876	8506	Economy	6000.00
0005433616038	8506	Economy	6000.00
0005433615903	8506	Economy	6000.00
0005433616117	8506	Economy	6000.00
0005433616128	8506	Economy	6000.00
0005433615954	8506	Economy	6000.00
0005433615928	8506	Economy	6000.00
0005433616186	8506	Economy	6000.00
0005433616198	8506	Economy	6000.00
0005433616237	8506	Economy	6000.00
0005433616326	8506	Economy	6000.00
0005433616217	8506	Economy	6000.00
0005433616036	8506	Economy	6000.00
0005433616004	8506	Economy	6000.00
0005433616271	8506	Economy	6000.00
0005433615885	8506	Economy	6000.00
0005433615654	8506	Economy	6000.00
0005433616295	8506	Economy	6000.00
0005433616129	8506	Economy	6000.00
0005433615803	8506	Economy	6000.00
0005433616173	8506	Economy	6000.00
0005433616098	8506	Economy	6000.00
0005433615863	8506	Economy	6600.00
0005433616099	8506	Economy	6000.00
0005433616011	8506	Economy	6000.00
0005433616275	8506	Economy	6000.00
0005433615879	8506	Economy	6000.00
0005433615842	8506	Economy	6000.00
0005433615419	8506	Economy	6000.00
0005433616265	8506	Economy	6000.00
0005433616003	8506	Economy	6000.00
0005433615991	8506	Economy	6000.00
0005433616248	8506	Economy	6000.00
0005433615711	8506	Economy	6000.00
0005433616192	8506	Economy	6000.00
0005433616013	8506	Economy	6000.00
0005433615828	8506	Economy	6000.00
0005433616114	8506	Economy	6000.00
0005433616100	8506	Economy	6000.00
0005433615990	8506	Economy	6000.00
0005433616369	8506	Economy	6000.00
0005433616119	8506	Economy	6000.00
0005433616012	8506	Economy	6000.00
0005433615861	8506	Economy	6000.00
0005433616370	8506	Economy	6000.00
0005433615994	8506	Economy	6000.00
0005433616037	8506	Economy	6000.00
0005433616290	8506	Economy	6000.00
0005433615884	8506	Economy	6000.00
0005433615883	8506	Economy	6000.00
0005433616283	8506	Economy	6000.00
0005434149961	8507	Business	18000.00
0005434229778	8507	Business	18000.00
0005432336360	8507	Business	18000.00
0005434229775	8507	Business	18000.00
0005434265750	8507	Business	18000.00
0005434265562	8507	Business	18000.00
0005434173593	8507	Business	18000.00
0005435007664	8507	Business	18000.00
0005435286801	8507	Business	18000.00
0005434265726	8507	Business	18000.00
0005432035695	8507	Business	18000.00
0005435007657	8507	Business	18000.00
0005432336367	8507	Business	18000.00
0005434229721	8507	Business	18000.00
0005432035709	8507	Business	18000.00
0005434149962	8507	Business	18000.00
0005433815518	8507	Business	18000.00
0005435007667	8507	Business	18000.00
0005434173591	8507	Business	18000.00
0005434229807	8507	Business	18000.00
0005433689968	8507	Business	18000.00
0005434149967	8507	Business	18000.00
0005435007666	8507	Business	18000.00
0005435007663	8507	Business	18000.00
0005435286799	8507	Business	18000.00
0005434229766	8507	Economy	6600.00
0005432035706	8507	Economy	6600.00
0005433815516	8507	Economy	6600.00
0005432336361	8507	Economy	6600.00
0005432035715	8507	Economy	6600.00
0005435286803	8507	Economy	6600.00
0005435286804	8507	Economy	6000.00
0005434265601	8507	Economy	6000.00
0005435007671	8507	Economy	6000.00
0005432047652	8507	Economy	6000.00
0005435286805	8507	Economy	6000.00
0005434149993	8507	Economy	6000.00
0005432035710	8507	Economy	6000.00
0005434229832	8507	Economy	6000.00
0005433815515	8507	Economy	6000.00
0005434149929	8507	Economy	6000.00
0005433690982	8507	Economy	6000.00
0005432336366	8507	Economy	6000.00
0005434265587	8507	Economy	6000.00
0005435286795	8507	Economy	6000.00
0005434229695	8507	Economy	6000.00
0005435286794	8507	Economy	6000.00
0005434265528	8507	Economy	6000.00
0005434173574	8507	Economy	6000.00
0005435007675	8507	Economy	6000.00
0005434229718	8507	Economy	6000.00
0005434229662	8507	Economy	6000.00
0005435007669	8507	Economy	6000.00
0005435286808	8507	Economy	6000.00
0005434149928	8507	Economy	6000.00
0005434265575	8507	Economy	6000.00
0005432035713	8507	Economy	6000.00
0005435286806	8507	Economy	6000.00
0005435007658	8507	Economy	6000.00
0005432336363	8507	Economy	6000.00
0005435007674	8507	Economy	6000.00
0005434265539	8507	Economy	6000.00
0005434173599	8507	Economy	6000.00
0005434229895	8507	Economy	6000.00
0005432035703	8507	Economy	6000.00
0005432035705	8507	Economy	6000.00
0005434265717	8507	Economy	6000.00
0005434265660	8507	Economy	6000.00
0005435007662	8507	Economy	6000.00
0005435286810	8507	Economy	6000.00
0005434265686	8507	Economy	6000.00
0005434265687	8507	Economy	6000.00
0005432047653	8507	Economy	6000.00
0005432035699	8507	Economy	6000.00
0005434229883	8507	Economy	6000.00
0005432035714	8507	Economy	6000.00
0005434265618	8507	Economy	6000.00
0005434229776	8507	Economy	6000.00
0005435286802	8507	Economy	6000.00
0005434229717	8507	Economy	6000.00
0005434229744	8507	Economy	6000.00
0005434265540	8507	Economy	6000.00
0005434229856	8507	Economy	6000.00
0005434265561	8507	Economy	6000.00
0005435007661	8507	Economy	6000.00
0005435286809	8507	Economy	6000.00
0005435007660	8507	Economy	6000.00
0005432035712	8507	Economy	6000.00
0005432035702	8507	Economy	6000.00
0005432035711	8507	Economy	6600.00
0005432336362	8507	Economy	6600.00
0005435286797	8507	Economy	6600.00
0005433534556	8507	Economy	6600.00
0005434265578	8507	Economy	6600.00
0005432035697	8507	Economy	6000.00
0005433688865	8507	Economy	6000.00
0005434173598	8507	Economy	6000.00
0005434149951	8507	Economy	6000.00
0005434229700	8507	Economy	6000.00
0005435007665	8507	Economy	6600.00
0005434265638	8507	Economy	6000.00
0005434265577	8507	Economy	6000.00
0005432336359	8507	Economy	6000.00
0005432336365	8507	Economy	6000.00
0005433690981	8507	Economy	6000.00
0005434229850	8507	Economy	6000.00
0005434265635	8507	Economy	6000.00
0005432035696	8507	Economy	6000.00
0005434229889	8507	Economy	6000.00
0005434265584	8507	Economy	6000.00
0005435007668	8507	Economy	6000.00
0005434229873	8507	Economy	6000.00
0005433815556	8507	Economy	6000.00
0005432336364	8507	Economy	6000.00
0005435286798	8507	Economy	6000.00
0005433689967	8507	Economy	6000.00
0005433815558	8507	Economy	6000.00
0005434173592	8507	Economy	6000.00
0005433534557	8507	Economy	6000.00
0005433815519	8507	Economy	6000.00
0005434265636	8507	Economy	6000.00
0005434265631	8507	Economy	6000.00
0005434173606	8507	Economy	6000.00
0005434229743	8507	Economy	6000.00
0005434229894	8507	Economy	6000.00
0005434149966	8507	Economy	6000.00
0005435286796	8507	Economy	6000.00
0005432035701	8507	Economy	6000.00
0005434229767	8507	Economy	6000.00
0005435007659	8507	Economy	6000.00
0005432336358	8507	Economy	6000.00
0005435007672	8507	Economy	6000.00
0005432035700	8507	Economy	6000.00
0005434150008	8507	Economy	6000.00
0005432035707	8507	Economy	6000.00
0005432035698	8507	Economy	6000.00
0005435286800	8507	Economy	6000.00
0005435007656	8507	Economy	6000.00
0005434229784	8507	Economy	6000.00
0005435007670	8507	Economy	6000.00
0005434229777	8507	Economy	6000.00
0005432035704	8507	Economy	6000.00
0005433815557	8507	Economy	6000.00
0005434149920	8507	Economy	6000.00
0005434149952	8507	Economy	6000.00
0005432035708	8507	Economy	6000.00
0005432336368	8507	Economy	6000.00
0005433815559	8507	Economy	6000.00
0005434229838	8507	Economy	6000.00
0005435286807	8507	Economy	6000.00
0005434229699	8507	Economy	6000.00
0005433815517	8507	Economy	6000.00
0005432035717	8507	Economy	6000.00
0005432035694	8507	Economy	6000.00
0005434265560	8507	Economy	6000.00
0005433534558	8507	Economy	6000.00
0005434311275	8507	Economy	6000.00
0005434265617	8507	Economy	6000.00
0005435007673	8507	Economy	6000.00
0005432035716	8507	Economy	6000.00
0005434265586	8507	Economy	6000.00
0005434639750	12612	Economy	16200.00
0005434639665	12612	Economy	16200.00
0005433202768	12612	Economy	16200.00
0005434639664	12612	Economy	16200.00
0005434639926	12612	Economy	14800.00
0005433202760	12612	Economy	14800.00
0005434639847	12612	Economy	14800.00
0005434639852	12612	Economy	14800.00
0005434639914	12612	Economy	14800.00
0005434639710	12612	Economy	14800.00
0005433202769	12612	Economy	14800.00
0005434639941	12612	Economy	14800.00
0005433202759	12612	Economy	14800.00
0005434639751	12612	Economy	14800.00
0005433202766	12612	Economy	14800.00
0005434639850	12612	Economy	14800.00
0005433202762	12612	Economy	14800.00
0005434639848	12612	Economy	14800.00
0005434639915	12612	Economy	14800.00
0005434639849	12612	Economy	14800.00
0005434639734	12612	Economy	14800.00
0005434639840	12612	Economy	14800.00
0005434639942	12612	Economy	14800.00
0005434639704	12612	Economy	14800.00
0005434639912	12612	Economy	14800.00
0005433202767	12612	Economy	14800.00
0005434639711	12612	Economy	14800.00
0005434639864	12612	Economy	14800.00
0005434639795	12612	Economy	14800.00
0005433202764	12612	Economy	14800.00
0005434639800	12612	Economy	14800.00
0005434639803	12612	Economy	14800.00
0005434639851	12612	Economy	14800.00
0005433202770	12612	Economy	14800.00
0005434639865	12612	Economy	14800.00
0005433202761	12612	Economy	14800.00
0005434639876	12612	Economy	14800.00
0005434639749	12612	Economy	14800.00
0005433202763	12612	Economy	14800.00
0005434639835	12612	Economy	14800.00
0005434639729	12612	Economy	14800.00
0005434639748	12612	Economy	14800.00
0005433202765	12612	Economy	14800.00
0005434640001	23382	Economy	16200.00
0005433202559	23382	Economy	16200.00
0005433202591	23382	Economy	16200.00
0005434640011	23382	Economy	14800.00
0005433202612	23382	Economy	14800.00
0005433202560	23382	Economy	14800.00
0005433202555	23382	Economy	14800.00
0005434640020	23382	Economy	14800.00
0005432290716	23382	Economy	14800.00
0005434640000	23382	Economy	14800.00
0005434640018	23382	Economy	14800.00
0005434640002	23382	Economy	14800.00
0005434640015	23382	Economy	14800.00
0005434640008	23382	Economy	14800.00
0005434640006	23382	Economy	14800.00
0005434640012	23382	Economy	14800.00
0005433202654	23382	Economy	14800.00
0005434640013	23382	Economy	14800.00
0005434640007	23382	Economy	14800.00
0005433202674	23382	Economy	14800.00
0005434639999	23382	Economy	14800.00
0005434640019	23382	Economy	14800.00
0005433202590	23382	Economy	14800.00
0005434640003	23382	Economy	14800.00
0005433202673	23382	Economy	14800.00
0005434640017	23382	Economy	14800.00
0005433202575	23382	Economy	14800.00
0005433202656	23382	Economy	14800.00
0005434640005	23382	Economy	14800.00
0005432290715	23382	Economy	14800.00
0005433202618	23382	Economy	14800.00
0005433202655	23382	Economy	14800.00
0005434640014	23382	Economy	14800.00
0005434640009	23382	Economy	14800.00
0005433202574	23382	Economy	14800.00
0005434640010	23382	Economy	14800.00
0005434640021	23382	Economy	14800.00
0005433202632	23382	Economy	14800.00
0005434640016	23382	Economy	14800.00
0005434640004	23382	Economy	14800.00
0005432848906	21088	Business	18900.00
0005432383795	21088	Business	18900.00
0005432329483	21088	Business	18900.00
0005432329720	21088	Business	18900.00
0005432383843	21088	Business	18900.00
0005432329614	21088	Business	18900.00
0005432383904	21088	Business	18900.00
0005432383662	21088	Business	18900.00
0005432383685	21088	Business	18900.00
0005432329552	21088	Business	18900.00
0005432848905	21088	Business	18900.00
0005432329540	21088	Economy	6300.00
0005432329589	21088	Economy	6300.00
0005432329574	21088	Economy	6300.00
0005432384040	21088	Economy	6300.00
0005432383821	21088	Economy	6300.00
0005432329649	21088	Economy	6300.00
0005432329502	21088	Economy	6300.00
0005432383851	21088	Economy	6300.00
0005432383900	21088	Economy	6300.00
0005432329590	21088	Economy	6300.00
0005432383661	21088	Economy	6900.00
0005432383792	21088	Economy	6900.00
0005432848899	21088	Economy	6900.00
0005432383912	21088	Economy	6900.00
0005432384024	21088	Economy	6900.00
0005432383980	21088	Economy	6300.00
0005432329544	21088	Economy	6300.00
0005432054386	21088	Economy	6300.00
0005432848904	21088	Economy	6300.00
0005432054387	21088	Economy	6300.00
0005432383905	21088	Economy	6300.00
0005432329488	21088	Economy	6300.00
0005432329489	21088	Economy	6300.00
0005432383949	21088	Economy	6300.00
0005432384039	21088	Economy	6300.00
0005432329573	21088	Economy	6300.00
0005432329575	21088	Economy	6300.00
0005432383939	21088	Economy	6300.00
0005432383863	21088	Economy	6300.00
0005432329655	21088	Economy	6300.00
0005432383950	21088	Economy	6300.00
0005432329458	21088	Economy	6300.00
0005432383663	21088	Economy	6300.00
0005432329648	21088	Economy	6300.00
0005432329616	21088	Economy	6300.00
0005432384056	21088	Economy	6300.00
0005432329374	21088	Economy	6300.00
0005432383867	21088	Economy	6300.00
0005432848901	21088	Economy	6300.00
0005432384028	21088	Economy	6300.00
0005432383864	21088	Economy	6300.00
0005432329593	21088	Economy	6300.00
0005432848903	21088	Economy	6300.00
0005432329490	21088	Economy	6300.00
0005432848900	21088	Economy	6300.00
0005432329621	21088	Economy	6300.00
0005432383907	21088	Economy	6300.00
0005432384023	21088	Economy	6300.00
0005432329459	21088	Economy	6300.00
0005432383981	21088	Economy	6300.00
0005432383880	21088	Economy	6300.00
0005432383873	21088	Economy	6300.00
0005432383857	21088	Economy	6300.00
0005432329570	21088	Economy	6300.00
0005432329551	21088	Economy	6300.00
0005432383970	21088	Economy	6300.00
0005432383922	21088	Economy	6300.00
0005432329569	21088	Economy	6300.00
0005432384022	21088	Economy	6300.00
0005432329619	21088	Economy	6300.00
0005432383911	21088	Economy	6300.00
0005432329327	21088	Economy	6300.00
0005432383940	21088	Economy	6300.00
0005432329615	21088	Economy	6300.00
0005432383860	21088	Economy	6300.00
0005432329654	21088	Economy	6300.00
0005432329484	21088	Economy	6300.00
0005432329556	21088	Economy	6300.00
0005432848902	21088	Economy	6300.00
0005432329559	21088	Economy	6300.00
0005432383871	21088	Economy	6300.00
0005432329555	21088	Economy	6300.00
0005432329426	21088	Economy	6300.00
0005432383908	21088	Economy	6300.00
0005432383948	21088	Economy	6300.00
0005432329554	21088	Economy	6300.00
0005432383874	21088	Economy	6300.00
0005432383861	21088	Economy	6300.00
0005432383850	21088	Economy	6300.00
0005432383872	21088	Economy	6300.00
0005432383844	21088	Economy	6300.00
0005432383856	21088	Economy	6300.00
0005432329485	21088	Economy	6300.00
0005432383885	21088	Economy	6300.00
0005432383879	21088	Economy	6300.00
0005432329927	31250	Business	18900.00
0005432329933	31250	Business	18900.00
0005432329934	31250	Business	18900.00
0005432329914	31250	Business	18900.00
0005432287323	31250	Business	18900.00
0005432329913	31250	Business	18900.00
0005432384199	31250	Business	18900.00
0005432384214	31250	Business	18900.00
0005432384204	31250	Business	18900.00
0005432329902	31250	Business	18900.00
0005432384228	31250	Business	18900.00
0005432287325	31250	Business	18900.00
0005432329912	31250	Economy	6300.00
0005432384215	31250	Economy	6300.00
0005432329916	31250	Economy	6300.00
0005432329905	31250	Economy	6300.00
0005432384224	31250	Economy	6300.00
0005432848853	31250	Economy	6300.00
0005432384201	31250	Economy	6300.00
0005432329929	31250	Economy	6300.00
0005432329924	31250	Economy	6300.00
0005432287322	31250	Economy	6300.00
0005432848855	31250	Economy	6900.00
0005432384218	31250	Economy	6900.00
0005432384231	31250	Economy	6900.00
0005432329930	31250	Economy	6900.00
0005432329937	31250	Economy	6300.00
0005432384202	31250	Economy	6300.00
0005432384230	31250	Economy	6300.00
0005432384206	31250	Economy	6300.00
0005432384217	31250	Economy	6300.00
0005432848862	31250	Economy	6300.00
0005432848850	31250	Economy	6300.00
0005432384229	31250	Economy	6300.00
0005432384219	31250	Economy	6300.00
0005432384233	31250	Economy	6300.00
0005432287326	31250	Economy	6300.00
0005432848856	31250	Economy	6300.00
0005432848847	31250	Economy	6300.00
0005432384203	31250	Economy	6300.00
0005432329919	31250	Economy	6300.00
0005432329923	31250	Economy	6300.00
0005432329911	31250	Economy	6300.00
0005432329938	31250	Economy	6300.00
0005432384200	31250	Economy	6300.00
0005432384198	31250	Economy	6300.00
0005432329932	31250	Economy	6300.00
0005432329908	31250	Economy	6300.00
0005432329906	31250	Economy	6300.00
0005432329910	31250	Economy	6300.00
0005432329936	31250	Economy	6300.00
0005432384225	31250	Economy	6300.00
0005432329921	31250	Economy	6300.00
0005432329918	31250	Economy	6300.00
0005432384205	31250	Economy	6300.00
0005432384222	31250	Economy	6300.00
0005432384213	31250	Economy	6300.00
0005432329928	31250	Economy	6300.00
0005432384209	31250	Economy	6300.00
0005432384227	31250	Economy	6300.00
0005432384212	31250	Economy	6300.00
0005432329904	31250	Economy	6300.00
0005432329922	31250	Economy	6300.00
0005432329925	31250	Economy	6300.00
0005432384208	31250	Economy	6300.00
0005432287327	31250	Economy	6300.00
0005432848854	31250	Economy	6300.00
0005432287324	31250	Economy	6300.00
0005432384211	31250	Economy	6300.00
0005432329909	31250	Economy	6300.00
0005432329917	31250	Economy	6300.00
0005432329931	31250	Economy	6300.00
0005432329915	31250	Economy	6300.00
0005432329935	31250	Economy	6300.00
0005432329939	31250	Economy	6300.00
0005432329900	31250	Economy	6300.00
0005432848863	31250	Economy	6300.00
0005432384221	31250	Economy	6300.00
0005432384223	31250	Economy	6300.00
0005432384207	31250	Economy	6300.00
0005432848852	31250	Economy	6300.00
0005432848848	31250	Economy	6300.00
0005432384210	31250	Economy	6300.00
0005432384226	31250	Economy	6300.00
0005432329926	31250	Economy	6300.00
0005432384220	31250	Economy	6300.00
0005432384216	31250	Economy	6300.00
0005432329920	31250	Economy	6300.00
0005432329907	31250	Economy	6300.00
0005432329903	31250	Economy	6300.00
0005432329901	31250	Economy	6300.00
0005432384232	31250	Economy	6300.00
0005433642734	2475	Business	89600.00
0005432954106	2475	Business	89600.00
0005432954108	2475	Business	89600.00
0005433642744	2475	Business	89600.00
0005433642759	2475	Business	89600.00
0005432954121	2475	Business	89600.00
0005433642738	2475	Economy	29900.00
0005433642754	2475	Economy	29900.00
0005433642756	2475	Economy	29900.00
0005433642748	2475	Economy	29900.00
0005433642753	2475	Economy	29900.00
0005433642746	2475	Economy	29900.00
0005433642755	2475	Economy	32800.00
0005433642742	2475	Economy	32800.00
0005432954122	2475	Economy	32800.00
0005433642758	2475	Economy	29900.00
0005433642736	2475	Economy	29900.00
0005433642737	2475	Economy	29900.00
0005433642747	2475	Economy	29900.00
0005432954099	2475	Economy	29900.00
0005433642740	2475	Economy	29900.00
0005432954095	2475	Economy	29900.00
0005432954085	2475	Economy	29900.00
0005433642735	2475	Economy	29900.00
0005433642739	2475	Economy	29900.00
0005433642741	2475	Economy	29900.00
0005432954073	2475	Economy	29900.00
0005432954092	2475	Economy	29900.00
0005433642749	2475	Economy	29900.00
0005432954086	2475	Economy	29900.00
0005432954098	2475	Economy	29900.00
0005433642751	2475	Economy	29900.00
0005432954088	2475	Economy	29900.00
0005432954120	2475	Economy	29900.00
0005432954061	2475	Economy	29900.00
0005432954107	2475	Economy	29900.00
0005433642743	2475	Economy	29900.00
0005433642750	2475	Economy	29900.00
0005432954079	2475	Economy	29900.00
0005433642752	2475	Economy	29900.00
0005433642757	2475	Economy	29900.00
0005432954087	2475	Economy	29900.00
0005433642745	2475	Economy	29900.00
0005432954096	2475	Economy	29900.00
0005432954169	27601	Business	89600.00
0005433642529	27601	Business	89600.00
0005433642657	27601	Business	89600.00
0005433642546	27601	Business	89600.00
0005433642619	27601	Economy	29900.00
0005433642658	27601	Economy	29900.00
0005432954167	27601	Economy	29900.00
0005433642608	27601	Economy	29900.00
0005432954150	27601	Economy	29900.00
0005432954152	27601	Economy	29900.00
0005433642558	27601	Economy	32800.00
0005432954157	27601	Economy	32800.00
0005432954156	27601	Economy	32800.00
0005432954153	27601	Economy	32800.00
0005433642659	27601	Economy	29900.00
0005432954164	27601	Economy	29900.00
0005432954160	27601	Economy	29900.00
0005433642568	27601	Economy	29900.00
0005432954151	27601	Economy	29900.00
0005433642654	27601	Economy	29900.00
0005432954170	27601	Economy	29900.00
0005432954161	27601	Economy	29900.00
0005432954159	27601	Economy	29900.00
0005432954166	27601	Economy	29900.00
0005433642587	27601	Economy	29900.00
0005433642562	27601	Economy	29900.00
0005432954165	27601	Economy	29900.00
0005433642580	27601	Economy	29900.00
0005433642626	27601	Economy	29900.00
0005432954168	27601	Economy	29900.00
0005433642588	27601	Economy	29900.00
0005433642541	27601	Economy	29900.00
0005433642602	27601	Economy	29900.00
0005432954155	27601	Economy	29900.00
0005433642569	27601	Economy	29900.00
0005432954162	27601	Economy	29900.00
0005432954163	27601	Economy	29900.00
0005433642528	27601	Economy	29900.00
0005433642609	27601	Economy	29900.00
0005432954158	27601	Economy	29900.00
0005433642643	27601	Economy	29900.00
0005433642596	27601	Economy	29900.00
0005433642535	27601	Economy	29900.00
0005433642534	27601	Economy	29900.00
0005433642665	27601	Economy	29900.00
0005433642579	27601	Economy	29900.00
0005432954154	27601	Economy	29900.00
0005432954149	27601	Economy	29900.00
0005433642623	27601	Economy	29900.00
0005433642570	27601	Economy	29900.00
0005432954171	27601	Economy	29900.00
0005433642559	27601	Economy	29900.00
0005433642607	27601	Economy	29900.00
0005433642560	27601	Economy	29900.00
0005433642627	27601	Economy	29900.00
0005433642567	27601	Economy	29900.00
0005433642561	27601	Economy	29900.00
0005433642603	27601	Economy	29900.00
0005432425748	13314	Business	12700.00
0005432425731	13314	Business	12700.00
0005432425737	13314	Business	12700.00
0005432425746	13314	Business	12700.00
0005432425721	13314	Business	12700.00
0005432425718	13314	Business	12700.00
0005432425715	13314	Economy	4200.00
0005432425719	13314	Economy	4200.00
0005432425727	13314	Economy	4700.00
0005432425753	13314	Economy	4200.00
0005432425747	13314	Economy	4200.00
0005432425736	13314	Economy	4200.00
0005432425723	13314	Economy	4200.00
0005432425742	13314	Economy	4200.00
0005432425751	13314	Economy	4200.00
0005432425752	13314	Economy	4200.00
0005432425749	13314	Economy	4200.00
0005432425734	13314	Economy	4200.00
0005432425754	13314	Economy	4200.00
0005432425738	13314	Economy	4200.00
0005432425745	13314	Economy	4200.00
0005432425716	13314	Economy	4200.00
0005432425741	13314	Economy	4200.00
0005432425733	13314	Economy	4200.00
0005432425740	13314	Economy	4200.00
0005432425717	13314	Economy	4200.00
0005432425732	13314	Economy	4200.00
0005432425739	13314	Economy	4200.00
0005432425713	13314	Economy	4200.00
0005432425735	13314	Economy	4200.00
0005432425714	13314	Economy	4200.00
0005432425726	13314	Economy	4200.00
0005432425725	13314	Economy	4200.00
0005432425722	13314	Economy	4200.00
0005432425744	13314	Economy	4200.00
0005432425712	13314	Economy	4200.00
0005432425720	13314	Economy	4200.00
0005432425728	13314	Economy	4200.00
0005432425730	13314	Economy	4200.00
0005432425724	13314	Economy	4200.00
0005432425729	13314	Economy	4200.00
0005432425750	13314	Economy	4200.00
0005432425743	13314	Economy	4200.00
0005432425253	30736	Business	12700.00
0005432425358	30736	Business	12700.00
0005432425353	30736	Economy	4200.00
0005432425303	30736	Economy	4200.00
0005432425202	30736	Economy	4200.00
0005432425351	30736	Economy	4200.00
0005432425104	30736	Economy	4200.00
0005432425356	30736	Economy	4200.00
0005432425251	30736	Economy	4200.00
0005432425344	30736	Economy	4700.00
0005432425299	30736	Economy	4700.00
0005432425327	30736	Economy	4700.00
0005432425360	30736	Economy	4700.00
0005432425179	30736	Economy	4200.00
0005432425244	30736	Economy	4200.00
0005432425296	30736	Economy	4200.00
0005432425257	30736	Economy	4200.00
0005432425373	30736	Economy	4200.00
0005432425345	30736	Economy	4200.00
0005432425366	30736	Economy	4200.00
0005432425250	30736	Economy	4200.00
0005432425271	30736	Economy	4200.00
0005432425365	30736	Economy	4200.00
0005432425262	30736	Economy	4200.00
0005432425222	30736	Economy	4200.00
0005432425201	30736	Economy	4200.00
0005432425180	30736	Economy	4200.00
0005432425223	30736	Economy	4200.00
0005432425377	30736	Economy	4200.00
0005432425352	30736	Economy	4200.00
0005432425249	30736	Economy	4200.00
0005432425354	30736	Economy	4200.00
0005432425181	30736	Economy	4200.00
0005432425178	30736	Economy	4200.00
0005432425330	30736	Economy	4200.00
0005432425246	30736	Economy	4200.00
0005432425255	30736	Economy	4200.00
0005432425256	30736	Economy	4200.00
0005432425270	30736	Economy	4200.00
0005432425297	30736	Economy	4200.00
0005432425272	30736	Economy	4200.00
0005432425372	30736	Economy	4200.00
0005432425292	30736	Economy	4200.00
0005432425103	30736	Economy	4200.00
0005432425357	30736	Economy	4200.00
0005432425369	30736	Economy	4200.00
0005432425248	30736	Economy	4200.00
0005432425231	30736	Economy	4200.00
0005432425245	30736	Economy	4200.00
0005432425374	30736	Economy	4200.00
0005432901972	9622	Business	32600.00
0005432822419	9622	Business	32600.00
0005432901967	9622	Business	32600.00
0005432901966	9622	Business	32600.00
0005434186263	9622	Business	32600.00
0005432818274	9622	Business	32600.00
0005432901954	9622	Business	32600.00
0005432818269	9622	Business	32600.00
0005432901897	9622	Economy	10900.00
0005432822417	9622	Economy	10900.00
0005432822418	9622	Economy	10900.00
0005434448410	9622	Economy	10900.00
0005432289077	9622	Economy	10900.00
0005432901958	9622	Economy	10900.00
0005432818289	9622	Economy	11900.00
0005432818284	9622	Economy	11900.00
0005432818270	9622	Economy	11900.00
0005432818267	9622	Economy	11900.00
0005432818283	9622	Economy	10900.00
0005432818288	9622	Economy	10900.00
0005432901888	9622	Economy	10900.00
0005434157672	9622	Economy	10900.00
0005432289074	9622	Economy	10900.00
0005432818291	9622	Economy	10900.00
0005432822413	9622	Economy	10900.00
0005432818268	9622	Economy	10900.00
0005432818278	9622	Economy	10900.00
0005432901955	9622	Economy	10900.00
0005432901889	9622	Economy	10900.00
0005432818277	9622	Economy	10900.00
0005432822414	9622	Economy	10900.00
0005434157631	9622	Economy	10900.00
0005432901956	9622	Economy	10900.00
0005432818286	9622	Economy	10900.00
0005432822416	9622	Economy	10900.00
0005432901947	9622	Economy	10900.00
0005434157673	9622	Economy	10900.00
0005432818279	9622	Economy	10900.00
0005432901957	9622	Economy	10900.00
0005432818290	9622	Economy	10900.00
0005432289075	9622	Economy	10900.00
0005432818276	9622	Economy	10900.00
0005432818275	9622	Economy	10900.00
0005432818281	9622	Economy	10900.00
0005432818273	9622	Economy	10900.00
0005432818287	9622	Economy	10900.00
0005434448411	9622	Economy	10900.00
0005434186264	9622	Economy	10900.00
0005432818272	9622	Economy	10900.00
0005434186262	9622	Economy	10900.00
0005432901851	9622	Economy	10900.00
0005434157640	9622	Economy	10900.00
0005432901971	9622	Economy	10900.00
0005432901905	9622	Economy	10900.00
0005432901953	9622	Economy	10900.00
0005432901948	9622	Economy	10900.00
0005434448409	9622	Economy	10900.00
0005432818282	9622	Economy	10900.00
0005432818285	9622	Economy	10900.00
0005432289076	9622	Economy	10900.00
0005432901979	9622	Economy	10900.00
0005432822415	9622	Economy	10900.00
0005432818271	9622	Economy	10900.00
0005432818280	9622	Economy	10900.00
0005432901970	9622	Economy	10900.00
0005432817882	28987	Business	32600.00
0005432817999	28987	Business	32600.00
0005432818010	28987	Business	32600.00
0005432817996	28987	Business	32600.00
0005432818030	28987	Business	32600.00
0005432902090	28987	Business	32600.00
0005432822350	28987	Business	32600.00
0005434448368	28987	Business	32600.00
0005434186277	28987	Business	32600.00
0005434186278	28987	Business	32600.00
0005434448376	28987	Economy	10900.00
0005432902091	28987	Economy	10900.00
0005434157690	28987	Economy	10900.00
0005432822354	28987	Economy	10900.00
0005432817881	28987	Economy	10900.00
0005432818017	28987	Economy	10900.00
0005432817880	28987	Economy	10900.00
0005432902088	28987	Economy	10900.00
0005432818022	28987	Economy	11900.00
0005432817955	28987	Economy	11900.00
0005432817972	28987	Economy	11900.00
0005432818088	28987	Economy	11900.00
0005432818206	28987	Economy	11900.00
0005432902078	28987	Economy	10900.00
0005432822358	28987	Economy	10900.00
0005432818082	28987	Economy	10900.00
0005432902079	28987	Economy	10900.00
0005432902087	28987	Economy	10900.00
0005432822377	28987	Economy	10900.00
0005434448394	28987	Economy	10900.00
0005432002133	28987	Economy	10900.00
0005434448395	28987	Economy	10900.00
0005432902089	28987	Economy	10900.00
0005432818026	28987	Economy	10900.00
0005432822344	28987	Economy	10900.00
0005432817854	28987	Economy	10900.00
0005432902084	28987	Economy	10900.00
0005432818207	28987	Economy	10900.00
0005432902081	28987	Economy	10900.00
0005432818006	28987	Economy	10900.00
0005432902082	28987	Economy	10900.00
0005432818007	28987	Economy	10900.00
0005434157693	28987	Economy	10900.00
0005432817976	28987	Economy	10900.00
0005432822357	28987	Economy	10900.00
0005432902085	28987	Economy	10900.00
0005432818016	28987	Economy	10900.00
0005432822349	28987	Economy	10900.00
0005432002132	28987	Economy	10900.00
0005434157691	28987	Economy	10900.00
0005432822337	28987	Economy	10900.00
0005432902083	28987	Economy	10900.00
0005432817998	28987	Economy	10900.00
0005432818087	28987	Economy	10900.00
0005432818116	28987	Economy	10900.00
0005432818029	28987	Economy	10900.00
0005432818021	28987	Economy	10900.00
0005432818208	28987	Economy	10900.00
0005434448378	28987	Economy	10900.00
0005432902080	28987	Economy	10900.00
0005432822343	28987	Economy	10900.00
0005432822376	28987	Economy	10900.00
0005432902086	28987	Economy	10900.00
0005432818005	28987	Economy	10900.00
0005432818035	28987	Economy	10900.00
0005434157692	28987	Economy	10900.00
0005432818070	28987	Economy	10900.00
0005432817995	28987	Economy	10900.00
0005434448377	28987	Economy	10900.00
0005434186276	28987	Economy	10900.00
0005432822378	28987	Economy	10900.00
0005432818027	28987	Economy	10900.00
0005432613972	15113	Economy	11000.00
0005432613973	15113	Economy	11000.00
0005432611809	15113	Economy	11000.00
0005435841114	15113	Economy	11000.00
0005432611810	15113	Economy	11000.00
0005435841115	15113	Economy	11000.00
0005432611808	15113	Economy	11000.00
0005435841106	15113	Economy	11000.00
0005435841112	15113	Economy	11000.00
0005432611807	15113	Economy	11000.00
0005432613975	15113	Economy	11000.00
0005432613974	15113	Economy	11000.00
0005432611771	31636	Economy	11000.00
0005435841847	31636	Economy	11000.00
0005432607631	31636	Economy	11000.00
0005432611772	31636	Economy	11000.00
0005432607630	31636	Economy	11000.00
0005433570758	11870	Business	105900.00
0005433570707	11870	Business	105900.00
0005433570761	11870	Business	105900.00
0005433570689	11870	Business	105900.00
0005432949198	11870	Business	105900.00
0005433570691	11870	Business	105900.00
0005433570697	11870	Business	105900.00
0005433570702	11870	Business	105900.00
0005432949291	11870	Business	105900.00
0005432949016	11870	Business	105900.00
0005433570701	11870	Business	105900.00
0005432949304	11870	Business	105900.00
0005433570733	11870	Business	105900.00
0005432948933	11870	Business	105900.00
0005432949119	11870	Business	105900.00
0005433570705	11870	Business	105900.00
0005433570721	11870	Business	105900.00
0005433570694	11870	Business	105900.00
0005433570737	11870	Business	105900.00
0005433570760	11870	Economy	35300.00
0005433570725	11870	Business	105900.00
0005433570748	11870	Economy	35300.00
0005432949157	11870	Economy	35300.00
0005433570728	11870	Economy	35300.00
0005432949101	11870	Economy	35300.00
0005433570754	11870	Economy	35300.00
0005433570759	11870	Economy	35300.00
0005432949110	11870	Economy	35300.00
0005433570687	11870	Economy	35300.00
0005433570722	11870	Economy	35300.00
0005433570731	11870	Economy	35300.00
0005433570693	11870	Economy	35300.00
0005433570735	11870	Economy	35300.00
0005432949011	11870	Economy	38800.00
0005432949109	11870	Economy	38800.00
0005433570736	11870	Economy	38800.00
0005432949084	11870	Economy	35300.00
0005432949017	11870	Economy	38800.00
0005433570717	11870	Economy	35300.00
0005433570718	11870	Economy	35300.00
0005433570700	11870	Economy	35300.00
0005432949214	11870	Economy	35300.00
0005433570755	11870	Economy	35300.00
0005432949166	11870	Economy	35300.00
0005433570709	11870	Economy	35300.00
0005433570738	11870	Economy	35300.00
0005433570723	11870	Economy	35300.00
0005433570688	11870	Economy	35300.00
0005433570686	11870	Economy	35300.00
0005432949143	11870	Economy	35300.00
0005433570729	11870	Economy	35300.00
0005433570713	11870	Economy	35300.00
0005433570741	11870	Economy	35300.00
0005432949334	11870	Economy	35300.00
0005432949077	11870	Economy	35300.00
0005433570740	11870	Economy	35300.00
0005433570696	11870	Economy	35300.00
0005433570744	11870	Economy	35300.00
0005432949075	11870	Economy	35300.00
0005433570706	11870	Economy	35300.00
0005433570732	11870	Economy	35300.00
0005432949158	11870	Economy	35300.00
0005433570704	11870	Economy	35300.00
0005432949250	11870	Economy	35300.00
0005433570719	11870	Economy	35300.00
0005432949311	11870	Economy	35300.00
0005433570692	11870	Economy	35300.00
0005433570762	11870	Economy	35300.00
0005433570710	11870	Economy	35300.00
0005433570753	11870	Economy	35300.00
0005433570750	11870	Economy	35300.00
0005433570715	11870	Economy	35300.00
0005432949249	11870	Economy	35300.00
0005433570716	11870	Economy	35300.00
0005432949100	11870	Economy	35300.00
0005433570752	11870	Economy	35300.00
0005432949251	11870	Economy	35300.00
0005433570708	11870	Economy	35300.00
0005432949103	11870	Economy	35300.00
0005433570734	11870	Economy	35300.00
0005433570726	11870	Economy	35300.00
0005433570690	11870	Economy	35300.00
0005433570698	11870	Economy	35300.00
0005433570720	11870	Economy	35300.00
0005433570749	11870	Economy	35300.00
0005433570712	11870	Economy	35300.00
0005432949010	11870	Economy	35300.00
0005433570711	11870	Economy	35300.00
0005433570751	11870	Economy	35300.00
0005433570757	11870	Economy	35300.00
0005432949281	11870	Economy	35300.00
0005432949142	11870	Economy	35300.00
0005433570747	11870	Economy	35300.00
0005433570742	11870	Economy	35300.00
0005432949168	11870	Economy	35300.00
0005433570703	11870	Economy	35300.00
0005432949140	11870	Economy	35300.00
0005433570743	11870	Economy	35300.00
0005432948932	11870	Economy	35300.00
0005432949218	11870	Economy	35300.00
0005432949141	11870	Economy	35300.00
0005433570746	11870	Economy	35300.00
0005432949305	11870	Economy	35300.00
0005432949245	11870	Economy	35300.00
0005433570695	11870	Economy	35300.00
0005433570714	11870	Economy	35300.00
0005432949104	11870	Economy	35300.00
0005433570727	11870	Economy	35300.00
0005433570730	11870	Economy	35300.00
0005433570756	11870	Economy	35300.00
0005433570699	11870	Economy	35300.00
0005432949333	11870	Economy	35300.00
0005432949026	11870	Economy	35300.00
0005433570745	11870	Economy	35300.00
0005433570739	11870	Economy	35300.00
0005433570724	11870	Economy	35300.00
0005432949608	25303	Business	105900.00
0005433570211	25303	Business	105900.00
0005433569991	25303	Business	105900.00
0005433570100	25303	Business	105900.00
0005433570082	25303	Business	105900.00
0005433569922	25303	Business	105900.00
0005433569921	25303	Business	105900.00
0005433569857	25303	Business	105900.00
0005433570293	25303	Business	105900.00
0005433570223	25303	Business	105900.00
0005433570398	25303	Business	105900.00
0005432949596	25303	Business	105900.00
0005433570122	25303	Business	105900.00
0005432949589	25303	Business	105900.00
0005432949594	25303	Business	105900.00
0005433570212	25303	Business	105900.00
0005433569992	25303	Business	105900.00
0005432949602	25303	Economy	35300.00
0005433570402	25303	Economy	35300.00
0005433570198	25303	Economy	35300.00
0005432949603	25303	Economy	35300.00
0005433570152	25303	Economy	35300.00
0005433569974	25303	Economy	35300.00
0005433570061	25303	Economy	35300.00
0005433570403	25303	Economy	35300.00
0005432949592	25303	Economy	38800.00
0005433569907	25303	Economy	38800.00
0005432949593	25303	Economy	38800.00
0005433570229	25303	Economy	35300.00
0005432949605	25303	Economy	35300.00
0005433570409	25303	Economy	35300.00
0005433570567	25303	Economy	35300.00
0005433570105	25303	Economy	35300.00
0005433570251	25303	Economy	35300.00
0005433570038	25303	Economy	35300.00
0005433570037	25303	Economy	35300.00
0005432949609	25303	Economy	35300.00
0005433570189	25303	Economy	35300.00
0005433570054	25303	Economy	35300.00
0005433570006	25303	Economy	35300.00
0005433569767	25303	Economy	35300.00
0005433570408	25303	Economy	35300.00
0005432949610	25303	Economy	35300.00
0005432949604	25303	Economy	35300.00
0005433570230	25303	Economy	35300.00
0005432949595	25303	Economy	35300.00
0005433570252	25303	Economy	35300.00
0005433570011	25303	Economy	35300.00
0005433570284	25303	Economy	35300.00
0005433570114	25303	Economy	35300.00
0005433570350	25303	Economy	35300.00
0005433570375	25303	Economy	35300.00
0005433570028	25303	Economy	35300.00
0005432949607	25303	Economy	35300.00
0005432949591	25303	Economy	35300.00
0005433570084	25303	Economy	35300.00
0005433570197	25303	Economy	35300.00
0005433570196	25303	Economy	35300.00
0005432949600	25303	Economy	35300.00
0005433570190	25303	Economy	35300.00
0005433570077	25303	Economy	35300.00
0005433570464	25303	Economy	35300.00
0005433569870	25303	Economy	35300.00
0005433570104	25303	Economy	35300.00
0005433570224	25303	Economy	35300.00
0005433569871	25303	Economy	35300.00
0005432949598	25303	Economy	35300.00
0005432949586	25303	Economy	35300.00
0005432949588	25303	Economy	35300.00
0005433570055	25303	Economy	35300.00
0005433570120	25303	Economy	35300.00
0005433570027	25303	Economy	35300.00
0005433570119	25303	Economy	35300.00
0005432949606	25303	Economy	35300.00
0005433570199	25303	Economy	35300.00
0005432949599	25303	Economy	35300.00
0005433570360	25303	Economy	35300.00
0005433570220	25303	Economy	35300.00
0005432949601	25303	Economy	35300.00
0005433570382	25303	Economy	35300.00
0005432949590	25303	Economy	35300.00
0005433570083	25303	Economy	35300.00
0005433570062	25303	Economy	35300.00
0005433570219	25303	Economy	35300.00
0005432949597	25303	Economy	35300.00
0005432949587	25303	Economy	35300.00
0005435340490	5417	Business	67200.00
0005434655466	5417	Business	67200.00
0005434655467	5417	Business	67200.00
0005434655480	5417	Business	67200.00
0005434656612	5417	Business	67200.00
0005434655484	5417	Economy	22400.00
0005434655487	5417	Economy	22400.00
0005435340541	5417	Economy	24600.00
0005434655477	5417	Economy	24600.00
0005434655465	5417	Economy	24600.00
0005435340548	5417	Economy	22400.00
0005435340493	5417	Economy	22400.00
0005435340568	5417	Economy	22400.00
0005434655478	5417	Economy	22400.00
0005434655482	5417	Economy	22400.00
0005434655479	5417	Economy	22400.00
0005434655476	5417	Economy	22400.00
0005435340465	5417	Economy	22400.00
0005435340566	5417	Economy	22400.00
0005432114290	5417	Economy	22400.00
0005434655472	5417	Economy	22400.00
0005435340552	5417	Economy	22400.00
0005434655471	5417	Economy	22400.00
0005434655474	5417	Economy	22400.00
0005432114291	5417	Economy	22400.00
0005434655483	5417	Economy	22400.00
0005435340547	5417	Economy	22400.00
0005435340550	5417	Economy	22400.00
0005434655473	5417	Economy	22400.00
0005434655470	5417	Economy	22400.00
0005434655468	5417	Economy	22400.00
0005434655475	5417	Economy	22400.00
0005434655469	5417	Economy	22400.00
0005435340522	5417	Economy	22400.00
0005434655481	5417	Economy	22400.00
0005435340588	5417	Economy	22400.00
0005434655488	5417	Economy	22400.00
0005435340567	5417	Economy	22400.00
0005435340551	5417	Economy	22400.00
0005435340519	5417	Economy	22400.00
0005434655486	5417	Economy	22400.00
0005434655485	5417	Economy	22400.00
0005435340549	5417	Economy	22400.00
0005435340677	12557	Business	67200.00
0005435340680	12557	Business	67200.00
0005435555425	12557	Business	67200.00
0005435340673	12557	Business	67200.00
0005434655210	12557	Business	67200.00
0005434655291	12557	Business	67200.00
0005434655197	12557	Business	67200.00
0005435340676	12557	Economy	22400.00
0005434655270	12557	Economy	22400.00
0005434655307	12557	Economy	22400.00
0005435340675	12557	Economy	24600.00
0005434655296	12557	Economy	22400.00
0005434655298	12557	Economy	22400.00
0005435555426	12557	Economy	22400.00
0005434655308	12557	Economy	22400.00
0005434655269	12557	Economy	22400.00
0005435340674	12557	Economy	22400.00
0005435340681	12557	Economy	22400.00
0005434655346	12557	Economy	22400.00
0005435340679	12557	Economy	22400.00
0005434655189	12557	Economy	22400.00
0005434655182	12557	Economy	22400.00
0005434655205	12557	Economy	22400.00
0005434655154	12557	Economy	22400.00
0005434655161	12557	Economy	22400.00
0005434655170	12557	Economy	22400.00
0005434655242	12557	Economy	22400.00
0005434656592	12557	Economy	22400.00
0005434655183	12557	Economy	22400.00
0005434655196	12557	Economy	22400.00
0005434655260	12557	Economy	22400.00
0005434655211	12557	Economy	22400.00
0005434655335	12557	Economy	22400.00
0005434655214	12557	Economy	22400.00
0005435340678	12557	Economy	22400.00
0005434655264	12557	Economy	22400.00
0005434655122	12557	Economy	22400.00
0005434655297	12557	Economy	22400.00
0005434655241	12557	Economy	22400.00
0005434655317	12557	Economy	22400.00
0005434655324	12557	Economy	22400.00
0005434655169	12557	Economy	22400.00
0005434655171	12557	Economy	22400.00
0005434655268	12557	Economy	22400.00
0005433717325	7455	Business	32000.00
0005433717302	7455	Business	32000.00
0005432078258	7455	Business	32000.00
0005433722421	7455	Business	32000.00
0005435266284	7455	Business	32000.00
0005433722410	7455	Business	32000.00
0005433656760	7455	Business	32000.00
0005433719231	7455	Business	32000.00
0005433717314	7455	Economy	10700.00
0005433717332	7455	Economy	10700.00
0005433656759	7455	Economy	10700.00
0005433717320	7455	Economy	10700.00
0005433717308	7455	Economy	10700.00
0005433690980	7455	Economy	10700.00
0005433722418	7455	Economy	10700.00
0005433717328	7455	Economy	10700.00
0005433722413	7455	Economy	10700.00
0005433717316	7455	Economy	10700.00
0005433717323	7455	Economy	10700.00
0005433717310	7455	Economy	10700.00
0005433722422	7455	Economy	10700.00
0005432078255	7455	Economy	10700.00
0005433717322	7455	Economy	10700.00
0005433717311	7455	Economy	10700.00
0005433656761	7455	Economy	10700.00
0005433722411	7455	Economy	10700.00
0005433717307	7455	Economy	10700.00
0005433717334	7455	Economy	10700.00
0005432429000	7455	Economy	10700.00
0005433717309	7455	Economy	10700.00
0005433722417	7455	Economy	10700.00
0005432078256	7455	Economy	10700.00
0005433717313	7455	Economy	10700.00
0005433722424	7455	Economy	11700.00
0005432078257	7455	Economy	11700.00
0005435266292	7455	Economy	11700.00
0005433717337	7455	Economy	11700.00
0005433722425	7455	Economy	11700.00
0005435266265	7455	Economy	10700.00
0005435266226	7455	Economy	10700.00
0005433690979	7455	Economy	10700.00
0005433722415	7455	Economy	10700.00
0005433717333	7455	Economy	10700.00
0005435266243	7455	Economy	10700.00
0005433717317	7455	Economy	10700.00
0005435266283	7455	Economy	10700.00
0005433717331	7455	Economy	10700.00
0005433717312	7455	Economy	10700.00
0005433722412	7455	Economy	10700.00
0005433722423	7455	Economy	10700.00
0005433717326	7455	Economy	10700.00
0005433722419	7455	Economy	10700.00
0005433717305	7455	Economy	10700.00
0005435266236	7455	Economy	10700.00
0005433656758	7455	Economy	10700.00
0005433717336	7455	Economy	10700.00
0005433717306	7455	Economy	10700.00
0005433717335	7455	Economy	10700.00
0005433656763	7455	Economy	10700.00
0005433717329	7455	Economy	10700.00
0005433717318	7455	Economy	10700.00
0005432078254	7455	Economy	10700.00
0005433717304	7455	Economy	10700.00
0005433656762	7455	Economy	10700.00
0005435266244	7455	Economy	10700.00
0005435266282	7455	Economy	10700.00
0005433717330	7455	Economy	10700.00
0005432429001	7455	Economy	10700.00
0005433717324	7455	Economy	10700.00
0005433717303	7455	Economy	10700.00
0005433717315	7455	Economy	10700.00
0005435266281	7455	Economy	10700.00
0005433717321	7455	Economy	10700.00
0005433717319	7455	Economy	10700.00
0005432078259	7455	Economy	10700.00
0005433722416	7455	Economy	10700.00
0005433689966	7455	Economy	10700.00
0005433722420	7455	Economy	10700.00
0005435266211	7455	Economy	10700.00
0005433722414	7455	Economy	10700.00
0005433717327	7455	Economy	10700.00
0005433722426	7455	Economy	10700.00
0005433656733	29253	Business	32000.00
0005433717067	29253	Business	32000.00
0005433716939	29253	Business	32000.00
0005432429022	29253	Business	32000.00
0005433722330	29253	Business	32000.00
0005432006844	29253	Business	32000.00
0005433716843	29253	Business	32000.00
0005433716541	29253	Business	32000.00
0005433717005	29253	Business	32000.00
0005433716849	29253	Business	32000.00
0005433716944	29253	Business	32000.00
0005433716670	29253	Economy	10700.00
0005432006841	29253	Economy	10700.00
0005433716731	29253	Economy	10700.00
0005433716912	29253	Economy	10700.00
0005433716772	29253	Economy	10700.00
0005433716811	29253	Economy	10700.00
0005433716757	29253	Economy	10700.00
0005433716885	29253	Economy	10700.00
0005433716812	29253	Economy	10700.00
0005433716956	29253	Economy	10700.00
0005433716866	29253	Economy	10700.00
0005433656739	29253	Economy	10700.00
0005433716718	29253	Economy	10700.00
0005433716820	29253	Economy	10700.00
0005433717031	29253	Economy	10700.00
0005433716990	29253	Economy	10700.00
0005433716953	29253	Economy	10700.00
0005432429024	29253	Economy	10700.00
0005433716771	29253	Economy	10700.00
0005433716848	29253	Economy	10700.00
0005433717101	29253	Economy	10700.00
0005433717018	29253	Economy	10700.00
0005432429023	29253	Economy	10700.00
0005433722312	29253	Economy	10700.00
0005433688839	29253	Economy	10700.00
0005433717037	29253	Economy	10700.00
0005433716839	29253	Economy	10700.00
0005433722323	29253	Economy	10700.00
0005433716965	29253	Economy	10700.00
0005433716951	29253	Economy	10700.00
0005433716745	29253	Economy	10700.00
0005433716611	29253	Economy	10700.00
0005433716884	29253	Economy	11700.00
0005433716979	29253	Economy	11700.00
0005433716874	29253	Economy	11700.00
0005433717091	29253	Economy	11700.00
0005433722340	29253	Economy	10700.00
0005433722334	29253	Economy	10700.00
0005433717019	29253	Economy	10700.00
0005433717059	29253	Economy	10700.00
0005433716878	29253	Economy	10700.00
0005433717003	29253	Economy	10700.00
0005433717052	29253	Economy	10700.00
0005433716943	29253	Economy	10700.00
0005433716873	29253	Economy	10700.00
0005433716983	29253	Economy	10700.00
0005433717069	29253	Economy	10700.00
0005433717004	29253	Economy	10700.00
0005433717038	29253	Economy	10700.00
0005433716867	29253	Economy	10700.00
0005433716902	29253	Economy	10700.00
0005433688840	29253	Economy	10700.00
0005432006842	29253	Economy	10700.00
0005433716838	29253	Economy	10700.00
0005433716610	29253	Economy	10700.00
0005433722318	29253	Economy	10700.00
0005433656732	29253	Economy	10700.00
0005433656717	29253	Economy	10700.00
0005433716952	29253	Economy	10700.00
0005433716730	29253	Economy	10700.00
0005433688841	29253	Economy	10700.00
0005433716877	29253	Economy	10700.00
0005433716784	29253	Economy	10700.00
0005433656718	29253	Economy	10700.00
0005433722317	29253	Economy	10700.00
0005433716758	29253	Economy	10700.00
0005433717173	29253	Economy	10700.00
0005433716917	29253	Economy	10700.00
0005433716819	29253	Economy	10700.00
0005433716907	29253	Economy	10700.00
0005433717047	29253	Economy	10700.00
0005433717046	29253	Economy	10700.00
0005433716842	29253	Economy	10700.00
0005433716844	29253	Economy	10700.00
0005433716732	29253	Economy	10700.00
0005433685565	29253	Economy	10700.00
0005433717016	29253	Economy	10700.00
0005432006843	29253	Economy	10700.00
0005433716901	29253	Economy	10700.00
0005433717058	29253	Economy	10700.00
0005433716908	29253	Economy	10700.00
0005433716909	29253	Economy	10700.00
0005433722341	29253	Economy	10700.00
0005433717102	29253	Economy	10700.00
0005433716733	29253	Economy	10700.00
0005433717053	29253	Economy	10700.00
0005433722322	29253	Economy	10700.00
0005433716803	29253	Economy	10700.00
0005433717068	29253	Economy	10700.00
0005433716717	29253	Economy	10700.00
0005433716540	29253	Economy	10700.00
0005432429021	29253	Economy	10700.00
0005434182436	8666	Business	36500.00
0005434182469	8666	Business	36500.00
0005434143770	8666	Business	36500.00
0005434143771	8666	Business	36500.00
0005434182447	8666	Business	36500.00
0005434182410	8666	Business	36500.00
0005434182471	8666	Business	36500.00
0005434184704	8666	Business	36500.00
0005434182404	8666	Economy	12200.00
0005434143779	8666	Economy	12200.00
0005434143778	8666	Economy	12200.00
0005434143784	8666	Economy	12200.00
0005434184710	8666	Economy	12200.00
0005434143769	8666	Economy	12200.00
0005434184705	8666	Economy	13400.00
0005434182470	8666	Economy	13400.00
0005434095670	8666	Economy	13400.00
0005434143783	8666	Economy	13400.00
0005434143767	8666	Economy	13400.00
0005434143786	8666	Economy	12200.00
0005434326089	8666	Economy	12200.00
0005434182395	8666	Economy	12200.00
0005434182396	8666	Economy	12200.00
0005434182441	8666	Economy	12200.00
0005434143782	8666	Economy	12200.00
0005434143777	8666	Economy	12200.00
0005434095668	8666	Economy	12200.00
0005434143790	8666	Economy	12200.00
0005434143773	8666	Economy	12200.00
0005434143791	8666	Economy	12200.00
0005434143781	8666	Economy	12200.00
0005434143785	8666	Economy	12200.00
0005434182398	8666	Economy	12200.00
0005434095663	8666	Economy	12200.00
0005434143772	8666	Economy	12200.00
0005434143787	8666	Economy	12200.00
0005434184712	8666	Economy	12200.00
0005434182444	8666	Economy	12200.00
0005434143776	8666	Economy	12200.00
0005434182468	8666	Economy	12200.00
0005434143775	8666	Economy	12200.00
0005434095671	8666	Economy	12200.00
0005434182387	8666	Economy	12200.00
0005434184703	8666	Economy	12200.00
0005434095664	8666	Economy	12200.00
0005434095667	8666	Economy	12200.00
0005434182409	8666	Economy	12200.00
0005434143780	8666	Economy	12200.00
0005434182467	8666	Economy	12200.00
0005434095665	8666	Economy	12200.00
0005434184706	8666	Economy	12200.00
0005434182442	8666	Economy	12200.00
0005434143789	8666	Economy	12200.00
0005434143788	8666	Economy	12200.00
0005434143768	8666	Economy	12200.00
0005434143774	8666	Economy	12200.00
0005434182397	8666	Economy	12200.00
0005434095669	8666	Economy	12200.00
0005434095666	8666	Economy	12200.00
0005434184711	8666	Economy	12200.00
0005435860692	11652	Business	36500.00
0005435860681	11652	Business	36500.00
0005435860687	11652	Business	36500.00
0005434095602	11652	Business	36500.00
0005435860683	11652	Business	36500.00
0005434182524	11652	Business	36500.00
0005434095563	11652	Business	36500.00
0005434184720	11652	Business	36500.00
0005435860690	11652	Economy	12200.00
0005435860684	11652	Economy	12200.00
0005435860686	11652	Economy	12200.00
0005434182520	11652	Economy	13400.00
0005434095500	11652	Economy	13400.00
0005434095525	11652	Economy	13400.00
0005435860689	11652	Economy	13400.00
0005435860685	11652	Economy	12200.00
0005434182525	11652	Economy	12200.00
0005434143752	11652	Economy	12200.00
0005434182519	11652	Economy	12200.00
0005434182523	11652	Economy	12200.00
0005434182526	11652	Economy	12200.00
0005434095508	11652	Economy	12200.00
0005434095548	11652	Economy	12200.00
0005435860682	11652	Economy	12200.00
0005435860694	11652	Economy	12200.00
0005434095488	11652	Economy	12200.00
0005434182522	11652	Economy	12200.00
0005434095547	11652	Economy	12200.00
0005434095467	11652	Economy	12200.00
0005434095554	11652	Economy	12200.00
0005434095552	11652	Economy	12200.00
0005434095543	11652	Economy	12200.00
0005434095466	11652	Economy	12200.00
0005434183634	11652	Economy	12200.00
0005434095540	11652	Economy	12200.00
0005434182521	11652	Economy	12200.00
0005434095570	11652	Economy	12200.00
0005435860688	11652	Economy	12200.00
0005435860691	11652	Economy	12200.00
0005434184719	11652	Economy	12200.00
0005434095539	11652	Economy	12200.00
0005435860693	11652	Economy	12200.00
0005434095553	11652	Economy	12200.00
0005435732684	1426	Business	33000.00
0005433399152	1426	Business	33000.00
0005435732685	1426	Business	33000.00
0005432906586	1426	Business	33000.00
0005435732672	1426	Business	33000.00
0005435732686	1426	Business	33000.00
0005435732676	1426	Business	33000.00
0005433399158	1426	Business	33000.00
0005433398771	1426	Business	33000.00
0005433399027	1426	Business	33000.00
0005433398992	1426	Business	33000.00
0005433399105	1426	Economy	11000.00
0005433398990	1426	Economy	11000.00
0005433398905	1426	Economy	11000.00
0005433399165	1426	Economy	11000.00
0005433399031	1426	Economy	11000.00
0005433399014	1426	Economy	11000.00
0005433398909	1426	Economy	11000.00
0005435725760	1426	Economy	12100.00
0005433398931	1426	Economy	12100.00
0005435732682	1426	Economy	12100.00
0005433399025	1426	Economy	12100.00
0005435725761	1426	Economy	11000.00
0005433398930	1426	Economy	11000.00
0005433398881	1426	Economy	11000.00
0005433399030	1426	Economy	11000.00
0005433399024	1426	Economy	11000.00
0005433398880	1426	Economy	11000.00
0005435732671	1426	Economy	11000.00
0005433398770	1426	Economy	11000.00
0005435732678	1426	Economy	11000.00
0005433398923	1426	Economy	11000.00
0005435732681	1426	Economy	11000.00
0005433398882	1426	Economy	11000.00
0005433399159	1426	Economy	11000.00
0005433399092	1426	Economy	11000.00
0005433398969	1426	Economy	11000.00
0005433399026	1426	Economy	11000.00
0005432906573	1426	Economy	11000.00
0005433398932	1426	Economy	11000.00
0005432906584	1426	Economy	11000.00
0005435732683	1426	Economy	11000.00
0005433399048	1426	Economy	11000.00
0005433399098	1426	Economy	11000.00
0005435725758	1426	Economy	11000.00
0005433398933	1426	Economy	11000.00
0005433398968	1426	Economy	11000.00
0005433399160	1426	Economy	11000.00
0005433398786	1426	Economy	11000.00
0005432297349	1426	Economy	11000.00
0005433398785	1426	Economy	11000.00
0005433457081	1426	Economy	11000.00
0005435732679	1426	Economy	11000.00
0005433398904	1426	Economy	11000.00
0005433399040	1426	Economy	11000.00
0005433399041	1426	Economy	11000.00
0005433399185	1426	Economy	11000.00
0005433398796	1426	Economy	11000.00
0005435732675	1426	Economy	11000.00
0005433457082	1426	Economy	11000.00
0005433398991	1426	Economy	11000.00
0005433399093	1426	Economy	11000.00
0005433399086	1426	Economy	11000.00
0005433399001	1426	Economy	11000.00
0005432906585	1426	Economy	11000.00
0005435732674	1426	Economy	11000.00
0005432906587	1426	Economy	11000.00
0005433457080	1426	Economy	11000.00
0005435732677	1426	Economy	11000.00
0005435732680	1426	Economy	11000.00
0005433399141	1426	Economy	11000.00
0005433398797	1426	Economy	11000.00
0005435725759	1426	Economy	11000.00
0005433399006	1426	Economy	11000.00
0005435732673	1426	Economy	11000.00
0005433399116	1426	Economy	11000.00
0005435732670	1426	Economy	11000.00
0005433457060	19240	Business	33000.00
0005433399372	19240	Business	33000.00
0005433399364	19240	Business	33000.00
0005433457046	19240	Business	33000.00
0005433457052	19240	Business	33000.00
0005435732547	19240	Business	33000.00
0005433399353	19240	Business	33000.00
0005433399380	19240	Business	33000.00
0005433399362	19240	Economy	11000.00
0005433399366	19240	Economy	11000.00
0005433399357	19240	Economy	11000.00
0005435732568	19240	Economy	11000.00
0005435732585	19240	Economy	11000.00
0005433399348	19240	Economy	11000.00
0005433457039	19240	Economy	11000.00
0005433457051	19240	Economy	11000.00
0005435732584	19240	Economy	12100.00
0005433399379	19240	Economy	12100.00
0005435732546	19240	Economy	12100.00
0005433399355	19240	Economy	11000.00
0005433399341	19240	Economy	11000.00
0005433399352	19240	Economy	11000.00
0005433399359	19240	Economy	11000.00
0005435732538	19240	Economy	11000.00
0005435732569	19240	Economy	11000.00
0005433399370	19240	Economy	11000.00
0005433457045	19240	Economy	11000.00
0005433399342	19240	Economy	11000.00
0005433399346	19240	Economy	11000.00
0005435732598	19240	Economy	11000.00
0005435732604	19240	Economy	11000.00
0005433399344	19240	Economy	11000.00
0005433399350	19240	Economy	11000.00
0005433399377	19240	Economy	11000.00
0005432906603	19240	Economy	11000.00
0005433399345	19240	Economy	11000.00
0005433457059	19240	Economy	11000.00
0005433399363	19240	Economy	11000.00
0005433399360	19240	Economy	11000.00
0005433399371	19240	Economy	11000.00
0005433399347	19240	Economy	11000.00
0005433399368	19240	Economy	11000.00
0005433457055	19240	Economy	11000.00
0005433457065	19240	Economy	11000.00
0005433399374	19240	Economy	11000.00
0005433399369	19240	Economy	11000.00
0005433399340	19240	Economy	11000.00
0005433399365	19240	Economy	11000.00
0005433399378	19240	Economy	11000.00
0005433399358	19240	Economy	11000.00
0005433457054	19240	Economy	11000.00
0005433457062	19240	Economy	11000.00
0005433399351	19240	Economy	11000.00
0005433399375	19240	Economy	11000.00
0005433399373	19240	Economy	11000.00
0005433399376	19240	Economy	11000.00
0005435732605	19240	Economy	11000.00
0005435732597	19240	Economy	11000.00
0005433399349	19240	Economy	11000.00
0005433399354	19240	Economy	11000.00
0005433399367	19240	Economy	11000.00
0005433399356	19240	Economy	11000.00
0005433399343	19240	Economy	11000.00
0005433399361	19240	Economy	11000.00
0005435311565	17353	Economy	15600.00
0005435311564	17353	Economy	14100.00
0005435311567	17353	Economy	14100.00
0005435311566	17353	Economy	14100.00
0005434443971	17353	Economy	14100.00
0005434444026	17353	Economy	14100.00
0005434444019	17353	Economy	14100.00
0005434443964	17353	Economy	14100.00
0005434444036	17353	Economy	14100.00
0005434444031	17353	Economy	14100.00
0005435311563	17353	Economy	14100.00
0005434444035	17353	Economy	14100.00
0005434444069	17353	Economy	14100.00
0005434444020	17353	Economy	14100.00
0005434444138	20592	Economy	14100.00
0005434444133	20592	Economy	14100.00
0005434444132	20592	Economy	14100.00
0005434444139	20592	Economy	14100.00
0005434444131	20592	Economy	14100.00
0005434444135	20592	Economy	14100.00
0005434444136	20592	Economy	14100.00
0005434444140	20592	Economy	14100.00
0005434444134	20592	Economy	14100.00
0005434444137	20592	Economy	14100.00
0005435377608	7275	Economy	5800.00
0005434954715	7275	Economy	5800.00
0005435377636	7275	Economy	5800.00
0005434954716	7275	Economy	5800.00
0005434954677	28328	Economy	5800.00
0005434954684	28328	Economy	5800.00
0005434954680	28328	Economy	5800.00
0005434954674	28328	Economy	5800.00
0005434954673	28328	Economy	5800.00
0005434352041	4465	Economy	15400.00
0005435893780	4465	Economy	15400.00
0005434352045	4465	Economy	14000.00
0005435893798	4465	Economy	14000.00
0005435893799	4465	Economy	14000.00
0005434352037	4465	Economy	14000.00
0005434183616	4465	Economy	14000.00
0005434326295	4465	Economy	14000.00
0005435893781	4465	Economy	14000.00
0005434352042	4465	Economy	14000.00
0005434183617	4465	Economy	14000.00
0005434326293	4465	Economy	14000.00
0005434352043	4465	Economy	14000.00
0005434352044	4465	Economy	14000.00
0005435893768	4465	Economy	14000.00
0005434183611	4465	Economy	14000.00
0005434352039	4465	Economy	14000.00
0005434326294	4465	Economy	14000.00
0005434352038	4465	Economy	14000.00
0005434352040	4465	Economy	14000.00
0005434183605	4465	Economy	14000.00
0005435893765	4465	Economy	14000.00
0005434351915	29635	Economy	15400.00
0005434351884	29635	Economy	14000.00
0005434351931	29635	Economy	14000.00
0005435893827	29635	Economy	14000.00
0005434351932	29635	Economy	14000.00
0005434351940	29635	Economy	14000.00
0005434351962	29635	Economy	14000.00
0005435893824	29635	Economy	14000.00
0005434351936	29635	Economy	14000.00
0005434351963	29635	Economy	14000.00
0005435893825	29635	Economy	14000.00
0005435893826	29635	Economy	14000.00
0005434351945	29635	Economy	14000.00
0005434351942	29635	Economy	14000.00
0005434351943	29635	Economy	14000.00
0005434351914	29635	Economy	14000.00
0005434351946	29635	Economy	14000.00
0005434351885	29635	Economy	14000.00
0005434352018	29635	Economy	14000.00
0005434351913	29635	Economy	14000.00
0005435893823	29635	Economy	14000.00
0005433345165	1088	Business	30600.00
0005433344974	1088	Business	30600.00
0005433345199	1088	Business	30600.00
0005433345242	1088	Business	30600.00
0005433344805	1088	Business	30600.00
0005433344998	1088	Business	30600.00
0005435545948	1088	Business	30600.00
0005433344630	1088	Business	30600.00
0005433344727	1088	Business	30600.00
0005433344264	1088	Business	30600.00
0005433345044	1088	Business	30600.00
0005433344895	1088	Business	30600.00
0005433344398	1088	Business	30600.00
0005433345280	1088	Business	30600.00
0005433344822	1088	Business	30600.00
0005433344645	1088	Business	30600.00
0005433344842	1088	Business	30600.00
0005433269831	1088	Business	30600.00
0005433344796	1088	Economy	11200.00
0005433344731	1088	Economy	11200.00
0005433344802	1088	Economy	11200.00
0005433344773	1088	Economy	11200.00
0005435092343	1088	Economy	10200.00
0005433344551	1088	Economy	10200.00
0005433345019	1088	Economy	10200.00
0005433345279	1088	Economy	10200.00
0005433344657	1088	Economy	10200.00
0005433345219	1088	Economy	10200.00
0005433344899	1088	Economy	10200.00
0005433345388	1088	Economy	10200.00
0005433345133	1088	Economy	10200.00
0005433344946	1088	Economy	10200.00
0005433345045	1088	Economy	10200.00
0005433345040	1088	Economy	10200.00
0005434446585	1088	Economy	10200.00
0005433345339	1088	Economy	10200.00
0005433345153	1088	Economy	10200.00
0005433345105	1088	Economy	10200.00
0005433344960	1088	Economy	10200.00
0005433269808	1088	Economy	10200.00
0005433344456	1088	Economy	10200.00
0005433345135	1088	Economy	10200.00
0005433344594	1088	Economy	10200.00
0005435545946	1088	Economy	10200.00
0005433344838	1088	Economy	10200.00
0005433158168	1088	Economy	10200.00
0005434445314	1088	Economy	10200.00
0005433344572	1088	Economy	10200.00
0005433344938	1088	Economy	10200.00
0005433345467	1088	Economy	10200.00
0005433344631	1088	Economy	10200.00
0005433344992	1088	Economy	10200.00
0005433158163	1088	Economy	10200.00
0005433344571	1088	Economy	10200.00
0005433269813	1088	Economy	10200.00
0005433344866	1088	Economy	10200.00
0005433344439	1088	Economy	10200.00
0005433344706	1088	Economy	10200.00
0005433345075	1088	Economy	10200.00
0005433344811	1088	Economy	10200.00
0005435092341	1088	Economy	10200.00
0005433463961	1088	Economy	10200.00
0005433345024	1088	Economy	10200.00
0005433344704	1088	Economy	10200.00
0005433345060	1088	Economy	10200.00
0005433345278	1088	Economy	10200.00
0005433344540	1088	Economy	10200.00
0005435092344	1088	Economy	10200.00
0005433344841	1088	Economy	10200.00
0005433344680	1088	Economy	10200.00
0005433344821	1088	Economy	10200.00
0005433345106	1088	Economy	10200.00
0005433344449	1088	Economy	10200.00
0005433344455	1088	Economy	10200.00
0005433345337	1088	Economy	10200.00
0005433344792	1088	Economy	10200.00
0005433345132	1088	Economy	10200.00
0005434446583	1088	Economy	10200.00
0005433345335	1088	Economy	11200.00
0005433345086	1088	Economy	10200.00
0005433344823	1088	Economy	10200.00
0005433345134	1088	Economy	10200.00
0005433344843	1088	Economy	10200.00
0005433344801	1088	Economy	10200.00
0005433344797	1088	Economy	10200.00
0005433345262	1088	Economy	10200.00
0005433269811	1088	Economy	10200.00
0005434445315	1088	Economy	10200.00
0005433344629	1088	Economy	10200.00
0005433344728	1088	Economy	10200.00
0005433345180	1088	Economy	10200.00
0005433344824	1088	Economy	10200.00
0005433344867	1088	Economy	10200.00
0005435092342	1088	Economy	10200.00
0005433344737	1088	Economy	10200.00
0005433344721	1088	Economy	10200.00
0005433344961	1088	Economy	10200.00
0005433345136	1088	Economy	10200.00
0005433344810	1088	Economy	10200.00
0005433345224	1088	Economy	10200.00
0005433269827	1088	Economy	10200.00
0005433344619	1088	Economy	10200.00
0005435545947	1088	Economy	10200.00
0005433344975	1088	Economy	10200.00
0005433345092	1088	Economy	10200.00
0005433269832	1088	Economy	10200.00
0005434446584	1088	Economy	10200.00
0005433344707	1088	Economy	10200.00
0005433344658	1088	Economy	10200.00
0005433344991	1088	Economy	10200.00
0005433344898	1088	Economy	10200.00
0005433344541	1088	Economy	10200.00
0005433159354	1088	Economy	10200.00
0005433345085	1088	Economy	10200.00
0005433345164	1088	Economy	10200.00
0005433269815	1088	Economy	10200.00
0005433344559	1088	Economy	10200.00
0005433344774	1088	Economy	10200.00
0005432293274	1088	Economy	10200.00
0005433345160	1088	Economy	10200.00
0005433345238	1088	Economy	10200.00
0005433345213	1088	Economy	10200.00
0005433159355	1088	Economy	10200.00
0005433345220	1088	Economy	10200.00
0005433344806	1088	Economy	10200.00
0005433344650	1088	Economy	10200.00
0005433345336	1088	Economy	10200.00
0005433344550	1088	Economy	10200.00
0005433345089	1088	Economy	10200.00
0005433345291	1088	Economy	10200.00
0005433345809	17074	Business	30600.00
0005435508526	17074	Business	30600.00
0005433269868	17074	Business	30600.00
0005433345797	17074	Business	30600.00
0005433345805	17074	Business	30600.00
0005433345817	17074	Business	30600.00
0005433345798	17074	Business	30600.00
0005435508561	17074	Business	30600.00
0005433269867	17074	Business	30600.00
0005435508591	17074	Business	30600.00
0005433345818	17074	Business	30600.00
0005433345744	17074	Business	30600.00
0005433159373	17074	Business	30600.00
0005433345761	17074	Business	30600.00
0005433345756	17074	Business	30600.00
0005435508538	17074	Economy	11200.00
0005433269864	17074	Economy	10200.00
0005433345802	17074	Economy	10200.00
0005433345794	17074	Economy	10200.00
0005433345801	17074	Economy	10200.00
0005435529990	17074	Economy	10200.00
0005433345796	17074	Economy	10200.00
0005433345749	17074	Economy	10200.00
0005433345826	17074	Economy	10200.00
0005433345751	17074	Economy	10200.00
0005433158202	17074	Economy	10200.00
0005435508601	17074	Economy	10200.00
0005433345820	17074	Economy	10200.00
0005433345767	17074	Economy	10200.00
0005435092321	17074	Economy	10200.00
0005433345815	17074	Economy	10200.00
0005433345783	17074	Economy	10200.00
0005435508523	17074	Economy	10200.00
0005433345813	17074	Economy	10200.00
0005433345743	17074	Economy	10200.00
0005433345755	17074	Economy	10200.00
0005433345807	17074	Economy	10200.00
0005433345772	17074	Economy	10200.00
0005435092257	17074	Economy	10200.00
0005433345781	17074	Economy	10200.00
0005433345760	17074	Economy	10200.00
0005435529989	17074	Economy	10200.00
0005435508667	17074	Economy	10200.00
0005433345812	17074	Economy	10200.00
0005435508576	17074	Economy	10200.00
0005435508592	17074	Economy	10200.00
0005433345811	17074	Economy	10200.00
0005435508607	17074	Economy	10200.00
0005434445287	17074	Economy	10200.00
0005433269869	17074	Economy	10200.00
0005435508648	17074	Economy	10200.00
0005433345766	17074	Economy	10200.00
0005435529985	17074	Economy	10200.00
0005433345752	17074	Economy	10200.00
0005433345788	17074	Economy	10200.00
0005433345822	17074	Economy	10200.00
0005433345741	17074	Economy	10200.00
0005433345791	17074	Economy	10200.00
0005433345775	17074	Economy	10200.00
0005433345816	17074	Economy	10200.00
0005433345778	17074	Economy	10200.00
0005433345799	17074	Economy	10200.00
0005435092320	17074	Economy	10200.00
0005433345825	17074	Economy	10200.00
0005433345824	17074	Economy	10200.00
0005435508522	17074	Economy	10200.00
0005433345765	17074	Economy	10200.00
0005433345819	17074	Economy	10200.00
0005433345810	17074	Economy	10200.00
0005433269866	17074	Economy	10200.00
0005434445288	17074	Economy	10200.00
0005433345769	17074	Economy	10200.00
0005433345784	17074	Economy	10200.00
0005433345808	17074	Economy	10200.00
0005435529991	17074	Economy	10200.00
0005433345759	17074	Economy	11200.00
0005433269865	17074	Economy	10200.00
0005433345780	17074	Economy	10200.00
0005433345786	17074	Economy	11200.00
0005433345800	17074	Economy	10200.00
0005433345764	17074	Economy	11200.00
0005433345753	17074	Economy	10200.00
0005435508567	17074	Economy	10200.00
0005433345806	17074	Economy	10200.00
0005434445281	17074	Economy	10200.00
0005434445294	17074	Economy	10200.00
0005433345785	17074	Economy	10200.00
0005433345774	17074	Economy	10200.00
0005433345770	17074	Economy	10200.00
0005433345779	17074	Economy	10200.00
0005433345795	17074	Economy	10200.00
0005433345746	17074	Economy	10200.00
0005433345754	17074	Economy	10200.00
0005433345768	17074	Economy	10200.00
0005435508647	17074	Economy	10200.00
0005435529976	17074	Economy	10200.00
0005433345773	17074	Economy	10200.00
0005433345782	17074	Economy	10200.00
0005433345821	17074	Economy	10200.00
0005435529977	17074	Economy	10200.00
0005435508642	17074	Economy	10200.00
0005433345814	17074	Economy	10200.00
0005433345771	17074	Economy	10200.00
0005435529975	17074	Economy	10200.00
0005435529986	17074	Economy	10200.00
0005433345777	17074	Economy	10200.00
0005433345776	17074	Economy	10200.00
0005433345763	17074	Economy	10200.00
0005433345792	17074	Economy	10200.00
0005433345758	17074	Economy	10200.00
0005433345823	17074	Economy	10200.00
0005433345790	17074	Economy	10200.00
0005433345789	17074	Economy	10200.00
0005435508539	17074	Economy	10200.00
0005433345740	17074	Economy	10200.00
0005433345742	17074	Economy	10200.00
0005433158203	17074	Economy	10200.00
0005433345747	17074	Economy	10200.00
0005435508521	17074	Economy	10200.00
0005433345787	17074	Economy	10200.00
0005435508555	17074	Economy	10200.00
0005433345750	17074	Economy	10200.00
0005433345745	17074	Economy	10200.00
0005433345803	17074	Economy	10200.00
0005435508606	17074	Economy	10200.00
0005433345748	17074	Economy	10200.00
0005433345793	17074	Economy	10200.00
0005433345757	17074	Economy	10200.00
0005433345762	17074	Economy	10200.00
0005435529988	17074	Economy	10200.00
0005433345804	17074	Economy	10200.00
0005435092289	17074	Economy	10200.00
0005434445280	17074	Economy	10200.00
0005432390456	1340	Business	101000.00
0005432390452	1340	Business	101000.00
0005432390451	1340	Business	101000.00
0005432392080	1340	Business	101000.00
0005432852035	1340	Business	101000.00
0005432392078	1340	Business	101000.00
0005432851991	1340	Business	101000.00
0005432392077	1340	Business	101000.00
0005432390441	1340	Business	101000.00
0005432390453	1340	Business	101000.00
0005432390439	1340	Economy	33700.00
0005432852022	1340	Economy	33700.00
0005432852039	1340	Economy	33700.00
0005432392075	1340	Economy	33700.00
0005432852005	1340	Economy	33700.00
0005432852041	1340	Economy	33700.00
0005432852018	1340	Economy	33700.00
0005432390433	1340	Economy	37000.00
0005432392073	1340	Economy	37000.00
0005432852034	1340	Economy	33700.00
0005432852019	1340	Economy	33700.00
0005432390447	1340	Economy	33700.00
0005432390461	1340	Economy	33700.00
0005432390444	1340	Economy	33700.00
0005432390443	1340	Economy	33700.00
0005432390434	1340	Economy	33700.00
0005432390448	1340	Economy	33700.00
0005432390450	1340	Economy	33700.00
0005432390460	1340	Economy	33700.00
0005432852006	1340	Economy	33700.00
0005432852014	1340	Economy	33700.00
0005432851992	1340	Economy	33700.00
0005432390435	1340	Economy	33700.00
0005432390442	1340	Economy	33700.00
0005432390449	1340	Economy	33700.00
0005432390454	1340	Economy	33700.00
0005432390458	1340	Economy	33700.00
0005432392081	1340	Economy	33700.00
0005432390462	1340	Economy	33700.00
0005432852015	1340	Economy	33700.00
0005432390436	1340	Economy	33700.00
0005432390459	1340	Economy	33700.00
0005432390440	1340	Economy	33700.00
0005432390438	1340	Economy	33700.00
0005432390457	1340	Economy	33700.00
0005432390445	1340	Economy	33700.00
0005432852023	1340	Economy	33700.00
0005432392079	1340	Economy	33700.00
0005432390463	1340	Economy	33700.00
0005432390455	1340	Economy	33700.00
0005432852016	1340	Economy	33700.00
0005432390437	1340	Economy	33700.00
0005432392076	1340	Economy	33700.00
0005432852004	1340	Economy	33700.00
0005432392074	1340	Economy	33700.00
0005432390446	1340	Economy	33700.00
0005434068657	12789	Business	40300.00
0005434068789	12789	Business	40300.00
0005434082168	12789	Business	40300.00
0005434068977	12789	Business	40300.00
0005434082325	12789	Business	40300.00
0005434068632	12789	Business	40300.00
0005434069040	12789	Business	40300.00
0005434082470	12789	Business	40300.00
0005434068580	12789	Business	40300.00
0005432159986	12789	Business	40300.00
0005434082254	12789	Business	40300.00
0005434082286	12789	Business	40300.00
0005434068857	12789	Economy	13400.00
0005434082303	12789	Economy	13400.00
0005434082313	12789	Economy	13400.00
0005434069043	12789	Economy	13400.00
0005434068755	12789	Economy	13400.00
0005434082289	12789	Economy	13400.00
0005434068798	12789	Economy	13400.00
0005432159985	12789	Economy	13400.00
0005434082355	12789	Economy	13400.00
0005432159983	12789	Economy	13400.00
0005434068944	12789	Economy	13400.00
0005434068729	12789	Economy	13400.00
0005434082348	12789	Economy	13400.00
0005434068935	12789	Economy	13400.00
0005433989846	12789	Economy	13400.00
0005434068921	12789	Economy	13400.00
0005434082324	12789	Economy	13400.00
0005434069216	12789	Economy	13400.00
0005432161214	12789	Economy	13400.00
0005434068608	12789	Economy	13400.00
0005434082318	12789	Economy	13400.00
0005434069134	12789	Economy	13400.00
0005434068856	12789	Economy	13400.00
0005434068985	12789	Economy	13400.00
0005433989840	12789	Economy	13400.00
0005434068976	12789	Economy	13400.00
0005434082314	12789	Economy	13400.00
0005434082308	12789	Economy	13400.00
0005434026737	12789	Economy	13400.00
0005432433825	12789	Economy	13400.00
0005434068752	12789	Economy	13400.00
0005434069156	12789	Economy	13400.00
0005434082311	12789	Economy	13400.00
0005434082285	12789	Economy	13400.00
0005434068581	12789	Economy	13400.00
0005434068840	12789	Economy	13400.00
0005434068754	12789	Economy	13400.00
0005434068619	12789	Economy	13400.00
0005434068873	12789	Economy	13400.00
0005433989868	12789	Economy	13400.00
0005434082241	12789	Economy	14800.00
0005434068922	12789	Economy	14800.00
0005432433826	12789	Economy	14800.00
0005434068834	12789	Economy	14800.00
0005434068737	12789	Economy	14800.00
0005434082270	12789	Economy	13400.00
0005434068735	12789	Economy	13400.00
0005434082356	12789	Economy	13400.00
0005435283486	12789	Economy	13400.00
0005434069184	12789	Economy	13400.00
0005434068791	12789	Economy	13400.00
0005434068797	12789	Economy	13400.00
0005434069023	12789	Economy	13400.00
0005434068803	12789	Economy	13400.00
0005434068750	12789	Economy	13400.00
0005434082238	12789	Economy	13400.00
0005434069042	12789	Economy	13400.00
0005434068892	12789	Economy	13400.00
0005434069176	12789	Economy	13400.00
0005434082310	12789	Economy	13400.00
0005434069157	12789	Economy	13400.00
0005434082373	12789	Economy	13400.00
0005434069082	12789	Economy	13400.00
0005434068841	12789	Economy	13400.00
0005434026738	12789	Economy	13400.00
0005434069135	12789	Economy	13400.00
0005434068759	12789	Economy	13400.00
0005434026740	12789	Economy	13400.00
0005434068947	12789	Economy	13400.00
0005434068656	12789	Economy	13400.00
0005433812964	12789	Economy	13400.00
0005434068730	12789	Economy	13400.00
0005434068799	12789	Economy	13400.00
0005434082326	12789	Economy	13400.00
0005434082312	12789	Economy	13400.00
0005434068513	12789	Economy	13400.00
0005434082269	12789	Economy	13400.00
0005434069111	12789	Economy	13400.00
0005434068469	12789	Economy	13400.00
0005434068975	12789	Economy	13400.00
0005434068920	12789	Economy	13400.00
0005434069048	12789	Economy	13400.00
0005435283489	12789	Economy	13400.00
0005433812963	12789	Economy	13400.00
0005432433824	12789	Economy	13400.00
0005433989873	12789	Economy	13400.00
0005434068891	12789	Economy	13400.00
0005434069049	12789	Economy	13400.00
0005434068766	12789	Economy	13400.00
0005434082309	12789	Economy	13400.00
0005434068850	12789	Economy	13400.00
0005433989845	12789	Economy	13400.00
0005434069217	12789	Economy	13400.00
0005432159984	12789	Economy	13400.00
0005434068625	12789	Economy	13400.00
0005434082290	12789	Economy	13400.00
0005435283487	12789	Economy	13400.00
0005435283488	12789	Economy	13400.00
0005433989839	12789	Economy	13400.00
0005434069022	12789	Economy	13400.00
0005434068597	12789	Economy	13400.00
0005434068751	12789	Economy	13400.00
0005434069083	12789	Economy	13400.00
0005434068946	12789	Economy	13400.00
0005434082167	12789	Economy	13400.00
0005434068875	12789	Economy	13400.00
0005434068788	12789	Economy	13400.00
0005432161215	12789	Economy	13400.00
0005433989838	12789	Economy	13400.00
0005434068758	12789	Economy	13400.00
0005434068753	12789	Economy	13400.00
0005434082349	12789	Economy	13400.00
0005434068919	12789	Economy	13400.00
0005434069449	30646	Business	40300.00
0005434069452	30646	Business	40300.00
0005432433779	30646	Business	40300.00
0005432150406	30646	Business	40300.00
0005434069417	30646	Business	40300.00
0005434069441	30646	Business	40300.00
0005435283416	30646	Business	40300.00
0005434069406	30646	Business	40300.00
0005434069448	30646	Business	40300.00
0005435283421	30646	Business	40300.00
0005434069464	30646	Business	40300.00
0005434069416	30646	Business	40300.00
0005434069460	30646	Economy	13400.00
0005434082550	30646	Economy	13400.00
0005433989895	30646	Economy	13400.00
0005434069456	30646	Economy	13400.00
0005434069422	30646	Economy	13400.00
0005434069411	30646	Economy	13400.00
0005434069454	30646	Economy	13400.00
0005434069433	30646	Economy	13400.00
0005434069462	30646	Economy	13400.00
0005435283417	30646	Economy	13400.00
0005434069401	30646	Economy	13400.00
0005434082553	30646	Economy	13400.00
0005434082539	30646	Economy	13400.00
0005434069412	30646	Economy	13400.00
0005432433767	30646	Economy	13400.00
0005434069429	30646	Economy	13400.00
0005434069447	30646	Economy	13400.00
0005434069463	30646	Economy	13400.00
0005434082562	30646	Economy	13400.00
0005434082552	30646	Economy	13400.00
0005434069427	30646	Economy	13400.00
0005434069444	30646	Economy	13400.00
0005434069457	30646	Economy	13400.00
0005432186965	30646	Economy	13400.00
0005434082561	30646	Economy	13400.00
0005434082548	30646	Economy	13400.00
0005432433778	30646	Economy	13400.00
0005434082551	30646	Economy	13400.00
0005434069404	30646	Economy	13400.00
0005434069430	30646	Economy	13400.00
0005434069407	30646	Economy	13400.00
0005434069424	30646	Economy	13400.00
0005434082554	30646	Economy	13400.00
0005434069445	30646	Economy	13400.00
0005434069451	30646	Economy	13400.00
0005434069428	30646	Economy	13400.00
0005434069421	30646	Economy	13400.00
0005434082566	30646	Economy	13400.00
0005434069453	30646	Economy	13400.00
0005433989896	30646	Economy	14800.00
0005434069438	30646	Economy	14800.00
0005434069459	30646	Economy	14800.00
0005434082556	30646	Economy	14800.00
0005434069415	30646	Economy	13400.00
0005432186967	30646	Economy	13400.00
0005432150402	30646	Economy	13400.00
0005432433768	30646	Economy	13400.00
0005434069443	30646	Economy	13400.00
0005434069442	30646	Economy	13400.00
0005434069436	30646	Economy	13400.00
0005432150404	30646	Economy	13400.00
0005434082546	30646	Economy	13400.00
0005434082541	30646	Economy	13400.00
0005434069434	30646	Economy	13400.00
0005434069446	30646	Economy	13400.00
0005434069410	30646	Economy	13400.00
0005434069405	30646	Economy	13400.00
0005434082555	30646	Economy	13400.00
0005434069423	30646	Economy	13400.00
0005434069435	30646	Economy	13400.00
0005432150400	30646	Economy	13400.00
0005434069458	30646	Economy	13400.00
0005434082538	30646	Economy	13400.00
0005434069418	30646	Economy	13400.00
0005432150407	30646	Economy	13400.00
0005434069414	30646	Economy	13400.00
0005434082559	30646	Economy	13400.00
0005432433788	30646	Economy	13400.00
0005434082557	30646	Economy	13400.00
0005432150405	30646	Economy	13400.00
0005434069439	30646	Economy	13400.00
0005434069437	30646	Economy	13400.00
0005434069402	30646	Economy	13400.00
0005434082547	30646	Economy	13400.00
0005434069425	30646	Economy	13400.00
0005434069450	30646	Economy	13400.00
0005434069420	30646	Economy	13400.00
0005432186966	30646	Economy	13400.00
0005432186964	30646	Economy	13400.00
0005432150408	30646	Economy	13400.00
0005435283412	30646	Economy	13400.00
0005434082558	30646	Economy	13400.00
0005434069461	30646	Economy	13400.00
0005434069426	30646	Economy	13400.00
0005432150401	30646	Economy	13400.00
0005435283422	30646	Economy	13400.00
0005434069403	30646	Economy	13400.00
0005434069413	30646	Economy	13400.00
0005434082563	30646	Economy	13400.00
0005434082542	30646	Economy	13400.00
0005434069431	30646	Economy	13400.00
0005434082544	30646	Economy	13400.00
0005434082565	30646	Economy	13400.00
0005434082545	30646	Economy	13400.00
0005432186968	30646	Economy	13400.00
0005434082564	30646	Economy	13400.00
0005434082560	30646	Economy	13400.00
0005434082543	30646	Economy	13400.00
0005434082540	30646	Economy	13400.00
0005434069408	30646	Economy	13400.00
0005434069409	30646	Economy	13400.00
0005434082549	30646	Economy	13400.00
0005435283413	30646	Economy	13400.00
0005434069419	30646	Economy	13400.00
0005434069432	30646	Economy	13400.00
0005435283420	30646	Economy	13400.00
0005432150403	30646	Economy	13400.00
0005434069440	30646	Economy	13400.00
0005434069455	30646	Economy	13400.00
0005435767933	5537	Business	35300.00
0005434265564	5537	Business	35300.00
0005434265477	5537	Business	35300.00
0005435735261	5537	Business	35300.00
0005433529380	5537	Business	35300.00
0005435767899	5537	Business	35300.00
0005435767955	5537	Business	35300.00
0005435767915	5537	Business	35300.00
0005435463130	5537	Business	35300.00
0005435463067	5537	Business	35300.00
0005435767903	5537	Business	35300.00
0005432140669	5537	Business	35300.00
0005435767937	5537	Business	35300.00
0005435463091	5537	Business	35300.00
0005435767956	5537	Business	35300.00
0005435767941	5537	Business	35300.00
0005434265523	5537	Business	35300.00
0005435767900	5537	Business	35300.00
0005435767935	5537	Economy	12900.00
0005435767950	5537	Economy	12900.00
0005435767946	5537	Economy	12900.00
0005435767901	5537	Economy	11800.00
0005435767943	5537	Economy	11800.00
0005435463211	5537	Economy	11800.00
0005435767920	5537	Economy	11800.00
0005435767909	5537	Economy	11800.00
0005435720861	5537	Economy	11800.00
0005432535915	5537	Economy	11800.00
0005434265695	5537	Economy	11800.00
0005434265580	5537	Economy	11800.00
0005434265524	5537	Economy	11800.00
0005435617174	5537	Economy	11800.00
0005434831237	5537	Economy	11800.00
0005434265599	5537	Economy	11800.00
0005435767942	5537	Economy	11800.00
0005435767926	5537	Economy	11800.00
0005432140666	5537	Economy	11800.00
0005435767914	5537	Economy	11800.00
0005435725727	5537	Economy	11800.00
0005432140668	5537	Economy	11800.00
0005435463069	5537	Economy	11800.00
0005435767919	5537	Economy	11800.00
0005435767917	5537	Economy	11800.00
0005432535920	5537	Economy	11800.00
0005435767947	5537	Economy	11800.00
0005435463060	5537	Economy	11800.00
0005435767904	5537	Economy	11800.00
0005432140673	5537	Economy	11800.00
0005434831243	5537	Economy	11800.00
0005434265530	5537	Economy	11800.00
0005435767927	5537	Economy	11800.00
0005433527371	5537	Economy	11800.00
0005435767916	5537	Economy	11800.00
0005435768112	5537	Economy	11800.00
0005435617175	5537	Economy	11800.00
0005435767939	5537	Economy	11800.00
0005435767932	5537	Economy	11800.00
0005434265513	5537	Economy	11800.00
0005433529382	5537	Economy	11800.00
0005435463175	5537	Economy	11800.00
0005434831222	5537	Economy	11800.00
0005435767911	5537	Economy	11800.00
0005435463248	5537	Economy	11800.00
0005435768109	5537	Economy	11800.00
0005435463115	5537	Economy	11800.00
0005435767949	5537	Economy	11800.00
0005435463102	5537	Economy	11800.00
0005435767954	5537	Economy	11800.00
0005435767908	5537	Economy	11800.00
0005435463131	5537	Economy	11800.00
0005435767936	5537	Economy	11800.00
0005435463222	5537	Economy	11800.00
0005432140670	5537	Economy	11800.00
0005434265537	5537	Economy	11800.00
0005435617177	5537	Economy	11800.00
0005435463043	5537	Economy	11800.00
0005435767930	5537	Economy	11800.00
0005435767906	5537	Economy	11800.00
0005435463249	5537	Economy	11800.00
0005434265694	5537	Economy	11800.00
0005435463122	5537	Economy	11800.00
0005435463068	5537	Economy	11800.00
0005435767938	5537	Economy	11800.00
0005435767951	5537	Economy	11800.00
0005435463116	5537	Economy	11800.00
0005432140672	5537	Economy	11800.00
0005435767907	5537	Economy	11800.00
0005435767953	5537	Economy	11800.00
0005434831225	5537	Economy	11800.00
0005435767925	5537	Economy	11800.00
0005435767934	5537	Economy	11800.00
0005432535925	5537	Economy	12900.00
0005435767910	5537	Economy	11800.00
0005434265591	5537	Economy	11800.00
0005432140671	5537	Economy	11800.00
0005435767944	5537	Economy	12900.00
0005435767945	5537	Economy	12900.00
0005434265525	5537	Economy	11800.00
0005434265655	5537	Economy	11800.00
0005435462941	5537	Economy	11800.00
0005434831229	5537	Economy	11800.00
0005435767931	5537	Economy	11800.00
0005435463054	5537	Economy	11800.00
0005434831213	5537	Economy	11800.00
0005432140667	5537	Economy	11800.00
0005434831218	5537	Economy	11800.00
0005434265625	5537	Economy	11800.00
0005435735263	5537	Economy	11800.00
0005435720859	5537	Economy	11800.00
0005435767928	5537	Economy	11800.00
0005435768110	5537	Economy	11800.00
0005435725729	5537	Economy	11800.00
0005435767905	5537	Economy	11800.00
0005435463214	5537	Economy	11800.00
0005435767952	5537	Economy	11800.00
0005434265606	5537	Economy	11800.00
0005435767913	5537	Economy	11800.00
0005434265634	5537	Economy	11800.00
0005435767948	5537	Economy	11800.00
0005435767921	5537	Economy	11800.00
0005435767940	5537	Economy	11800.00
0005435768111	5537	Economy	11800.00
0005435463207	5537	Economy	11800.00
0005434831244	5537	Economy	11800.00
0005432140674	5537	Economy	11800.00
0005434265522	5537	Economy	11800.00
0005433529381	5537	Economy	11800.00
0005434265600	5537	Economy	11800.00
0005435767918	5537	Economy	11800.00
0005434265538	5537	Economy	11800.00
0005435767898	5537	Economy	11800.00
0005435463148	5537	Economy	11800.00
0005435617182	5537	Economy	11800.00
0005435463187	5537	Economy	11800.00
0005435767923	5537	Economy	11800.00
0005433529383	5537	Economy	11800.00
0005435767912	5537	Economy	11800.00
0005435463055	5537	Economy	11800.00
0005435767929	5537	Economy	11800.00
0005434265670	5537	Economy	11800.00
0005434265665	5537	Economy	11800.00
0005435617183	5537	Economy	11800.00
0005435767924	5537	Economy	11800.00
0005434265671	5537	Economy	11800.00
0005435463215	5537	Economy	11800.00
0005435767922	5537	Economy	11800.00
0005435725730	5537	Economy	11800.00
0005435767902	5537	Economy	11800.00
0005435725728	5537	Economy	11800.00
0005434265607	5537	Economy	11800.00
0005435735262	5537	Economy	11800.00
0005433527370	5537	Economy	11800.00
0005434265579	5537	Economy	11800.00
0005435720860	5537	Economy	11800.00
0005435767175	13445	Business	35300.00
0005435463466	13445	Business	35300.00
0005435735230	13445	Business	35300.00
0005432535969	13445	Business	35300.00
0005435767386	13445	Business	35300.00
0005435767144	13445	Business	35300.00
0005435767343	13445	Business	35300.00
0005435767495	13445	Business	35300.00
0005434265829	13445	Business	35300.00
0005435767437	13445	Business	35300.00
0005434265843	13445	Business	35300.00
0005435043307	13445	Business	35300.00
0005435463448	13445	Business	35300.00
0005435735231	13445	Business	35300.00
0005432535967	13445	Business	35300.00
0005432535970	13445	Business	35300.00
0005435767034	13445	Business	35300.00
0005434265837	13445	Business	35300.00
0005435463451	13445	Business	35300.00
0005435722093	13445	Business	35300.00
0005434265848	13445	Business	35300.00
0005435767412	13445	Business	35300.00
0005435735204	13445	Business	35300.00
0005435767373	13445	Economy	12900.00
0005435463456	13445	Economy	12900.00
0005435767443	13445	Economy	11800.00
0005435463450	13445	Economy	11800.00
0005435463458	13445	Economy	11800.00
0005435463477	13445	Economy	11800.00
0005435767342	13445	Economy	11800.00
0005435463478	13445	Economy	11800.00
0005435735226	13445	Economy	11800.00
0005435617195	13445	Economy	11800.00
0005435463447	13445	Economy	11800.00
0005435720151	13445	Economy	11800.00
0005435767426	13445	Economy	11800.00
0005435767434	13445	Economy	11800.00
0005434265831	13445	Economy	11800.00
0005434265830	13445	Economy	11800.00
0005435617196	13445	Economy	11800.00
0005434265839	13445	Economy	11800.00
0005435767057	13445	Economy	11800.00
0005435767191	13445	Economy	11800.00
0005435767185	13445	Economy	11800.00
0005435463449	13445	Economy	11800.00
0005435463452	13445	Economy	11800.00
0005435617194	13445	Economy	11800.00
0005434265842	13445	Economy	11800.00
0005435767291	13445	Economy	11800.00
0005434831279	13445	Economy	11800.00
0005435767307	13445	Economy	11800.00
0005435767402	13445	Economy	11800.00
0005435463457	13445	Economy	11800.00
0005435617193	13445	Economy	11800.00
0005432194626	13445	Economy	11800.00
0005435767287	13445	Economy	11800.00
0005435767452	13445	Economy	11800.00
0005435720147	13445	Economy	11800.00
0005435463453	13445	Economy	11800.00
0005435767377	13445	Economy	11800.00
0005435767273	13445	Economy	11800.00
0005435463460	13445	Economy	11800.00
0005435463473	13445	Economy	11800.00
0005435463468	13445	Economy	11800.00
0005435767288	13445	Economy	11800.00
0005435767253	13445	Economy	11800.00
0005435463464	13445	Economy	11800.00
0005435767388	13445	Economy	11800.00
0005435463467	13445	Economy	11800.00
0005435767296	13445	Economy	11800.00
0005435767568	13445	Economy	11800.00
0005434265836	13445	Economy	11800.00
0005435767230	13445	Economy	11800.00
0005435767297	13445	Economy	11800.00
0005435767587	13445	Economy	11800.00
0005435767303	13445	Economy	11800.00
0005434265840	13445	Economy	11800.00
0005435767566	13445	Economy	11800.00
0005435767515	13445	Economy	11800.00
0005435463462	13445	Economy	11800.00
0005435463463	13445	Economy	11800.00
0005435767737	13445	Economy	11800.00
0005435463471	13445	Economy	11800.00
0005435463469	13445	Economy	11800.00
0005434831278	13445	Economy	11800.00
0005435767094	13445	Economy	11800.00
0005435767143	13445	Economy	11800.00
0005435723075	13445	Economy	11800.00
0005435463461	13445	Economy	11800.00
0005435767371	13445	Economy	11800.00
0005432194624	13445	Economy	11800.00
0005435767454	13445	Economy	11800.00
0005434831281	13445	Economy	11800.00
0005434265847	13445	Economy	11800.00
0005435767403	13445	Economy	11800.00
0005434265846	13445	Economy	11800.00
0005435767249	13445	Economy	11800.00
0005434265844	13445	Economy	11800.00
0005435767269	13445	Economy	12900.00
0005435767510	13445	Economy	12900.00
0005435735213	13445	Economy	11800.00
0005435722100	13445	Economy	11800.00
0005434831282	13445	Economy	12900.00
0005435767438	13445	Economy	11800.00
0005435463476	13445	Economy	11800.00
0005434265832	13445	Economy	11800.00
0005435767174	13445	Economy	11800.00
0005434265841	13445	Economy	11800.00
0005435767493	13445	Economy	11800.00
0005434265833	13445	Economy	11800.00
0005435463446	13445	Economy	11800.00
0005435767290	13445	Economy	11800.00
0005435463470	13445	Economy	11800.00
0005434265834	13445	Economy	11800.00
0005435767161	13445	Economy	11800.00
0005435043306	13445	Economy	11800.00
0005435767370	13445	Economy	11800.00
0005435767516	13445	Economy	11800.00
0005435767261	13445	Economy	11800.00
0005435767247	13445	Economy	11800.00
0005435735198	13445	Economy	11800.00
0005434265838	13445	Economy	11800.00
0005432194625	13445	Economy	11800.00
0005434265835	13445	Economy	11800.00
0005435767260	13445	Economy	11800.00
0005435463455	13445	Economy	11800.00
0005434265849	13445	Economy	11800.00
0005435463475	13445	Economy	11800.00
0005435767613	13445	Economy	11800.00
0005435767389	13445	Economy	11800.00
0005435767315	13445	Economy	11800.00
0005435767453	13445	Economy	11800.00
0005435463465	13445	Economy	11800.00
0005435767304	13445	Economy	11800.00
0005435767419	13445	Economy	11800.00
0005435767427	13445	Economy	11800.00
0005435463459	13445	Economy	11800.00
0005434831280	13445	Economy	11800.00
0005435767058	13445	Economy	11800.00
0005435767554	13445	Economy	11800.00
0005435767198	13445	Economy	11800.00
0005435767306	13445	Economy	11800.00
0005435767267	13445	Economy	11800.00
0005432535968	13445	Economy	11800.00
0005435722099	13445	Economy	11800.00
0005434265845	13445	Economy	11800.00
0005435767422	13445	Economy	11800.00
0005435463454	13445	Economy	11800.00
0005435767421	13445	Economy	11800.00
0005435767314	13445	Economy	11800.00
0005435767369	13445	Economy	11800.00
0005435463472	13445	Economy	11800.00
0005435767356	13445	Economy	11800.00
0005435767351	13445	Economy	11800.00
0005435735225	13445	Economy	11800.00
0005435767339	13445	Economy	11800.00
0005434265850	13445	Economy	11800.00
0005435463474	13445	Economy	11800.00
0005435767420	13445	Economy	11800.00
0005435043308	13445	Economy	11800.00
0005435767455	13445	Economy	11800.00
0005435735212	13445	Economy	11800.00
0005434602944	18754	Economy	3300.00
0005434602945	18754	Economy	3300.00
0005434513650	18662	Economy	3300.00
0005434515039	18662	Economy	3300.00
0005434604959	18662	Economy	3300.00
0005434604960	18662	Economy	3300.00
0005434604961	18662	Economy	3300.00
0005434515038	18662	Economy	3300.00
0005434515040	18662	Economy	3300.00
0005434604947	18662	Economy	3300.00
0005434604967	18662	Economy	3300.00
0005434515037	18662	Economy	3300.00
0005434515016	19190	Economy	3300.00
0005434515013	19190	Economy	3300.00
0005432649521	25079	Business	88300.00
0005432649519	25079	Business	88300.00
0005435846353	25079	Business	88300.00
0005435846351	25079	Economy	29400.00
0005432649513	25079	Economy	29400.00
0005432649537	25079	Economy	32400.00
0005432649473	25079	Economy	29400.00
0005432649511	25079	Economy	29400.00
0005432649512	25079	Economy	29400.00
0005432649510	25079	Economy	29400.00
0005435846350	25079	Economy	29400.00
0005435846349	25079	Economy	29400.00
0005432649515	25079	Economy	29400.00
0005432649522	25079	Economy	29400.00
0005435846352	25079	Economy	29400.00
0005432649480	25079	Economy	29400.00
0005432649520	25079	Economy	29400.00
0005435846348	25079	Economy	29400.00
0005433285993	1862	Business	48700.00
0005433009236	1862	Business	48700.00
0005433285975	1862	Business	48700.00
0005433009663	1862	Business	48700.00
0005433285989	1862	Business	48700.00
0005433009342	1862	Business	48700.00
0005433810726	1862	Business	48700.00
0005433009545	1862	Business	48700.00
0005433009219	1862	Business	48700.00
0005433009495	1862	Business	48700.00
0005433285853	1862	Business	48700.00
0005433285906	1862	Business	48700.00
0005433285876	1862	Economy	16200.00
0005433285861	1862	Economy	16200.00
0005433009480	1862	Economy	16200.00
0005433286048	1862	Economy	16200.00
0005433009320	1862	Economy	16200.00
0005433285806	1862	Economy	16200.00
0005433285939	1862	Economy	16200.00
0005433009341	1862	Economy	16200.00
0005433285854	1862	Economy	16200.00
0005433285789	1862	Economy	16200.00
0005433285863	1862	Economy	17900.00
0005433009380	1862	Economy	17900.00
0005433009624	1862	Economy	17900.00
0005433009584	1862	Economy	17900.00
0005433009603	1862	Economy	17900.00
0005433285878	1862	Economy	16200.00
0005433009381	1862	Economy	16200.00
0005433009567	1862	Economy	16200.00
0005433009178	1862	Economy	16200.00
0005433009177	1862	Economy	16200.00
0005433009610	1862	Economy	16200.00
0005433285953	1862	Economy	16200.00
0005433009410	1862	Economy	16200.00
0005433285952	1862	Economy	16200.00
0005433009539	1862	Economy	16200.00
0005432295953	1862	Economy	16200.00
0005433810729	1862	Economy	16200.00
0005433285768	1862	Economy	16200.00
0005433009523	1862	Economy	16200.00
0005433285905	1862	Economy	16200.00
0005433810724	1862	Economy	16200.00
0005433009221	1862	Economy	16200.00
0005433285950	1862	Economy	16200.00
0005433285784	1862	Economy	16200.00
0005433285958	1862	Economy	16200.00
0005433009625	1862	Economy	16200.00
0005433810723	1862	Economy	16200.00
0005433285940	1862	Economy	16200.00
0005433285807	1862	Economy	16200.00
0005433009489	1862	Economy	16200.00
0005433285945	1862	Economy	16200.00
0005433009411	1862	Economy	16200.00
0005433009559	1862	Economy	16200.00
0005433009372	1862	Economy	16200.00
0005433285671	1862	Economy	16200.00
0005433009627	1862	Economy	16200.00
0005432295952	1862	Economy	16200.00
0005433810720	1862	Economy	16200.00
0005433285888	1862	Economy	16200.00
0005433810730	1862	Economy	16200.00
0005433009220	1862	Economy	16200.00
0005433810721	1862	Economy	16200.00
0005433009560	1862	Economy	16200.00
0005433009602	1862	Economy	16200.00
0005433009623	1862	Economy	16200.00
0005433009569	1862	Economy	16200.00
0005433009323	1862	Economy	16200.00
0005433009366	1862	Economy	16200.00
0005432295951	1862	Economy	16200.00
0005433810727	1862	Economy	16200.00
0005433810728	1862	Economy	16200.00
0005433286008	1862	Economy	16200.00
0005433009622	1862	Economy	16200.00
0005433009558	1862	Economy	16200.00
0005433285908	1862	Economy	16200.00
0005433810725	1862	Economy	16200.00
0005433285990	1862	Economy	16200.00
0005433285936	1862	Economy	16200.00
0005433285862	1862	Economy	16200.00
0005433009566	1862	Economy	16200.00
0005433009423	1862	Economy	16200.00
0005433810722	1862	Economy	16200.00
0005433285889	1862	Economy	16200.00
0005433009335	1862	Economy	16200.00
0005433009324	1862	Economy	16200.00
0005433285949	1862	Economy	16200.00
0005433009450	1862	Economy	16200.00
0005433009449	1862	Economy	16200.00
0005433009616	1862	Economy	16200.00
0005433285790	1862	Economy	16200.00
0005433285882	1862	Economy	16200.00
0005433009222	1862	Economy	16200.00
0005433286049	1862	Economy	16200.00
0005433009664	1862	Economy	16200.00
0005433009365	1862	Economy	16200.00
0005433009844	22610	Business	48700.00
0005433286142	22610	Business	48700.00
0005433286123	22610	Business	48700.00
0005433009833	22610	Business	48700.00
0005433810594	22610	Business	48700.00
0005433286129	22610	Business	48700.00
0005433009845	22610	Business	48700.00
0005433009819	22610	Economy	16200.00
0005433009842	22610	Economy	16200.00
0005433286132	22610	Economy	16200.00
0005433286140	22610	Economy	16200.00
0005433286130	22610	Economy	17900.00
0005433286126	22610	Economy	17900.00
0005433286119	22610	Economy	17900.00
0005433009837	22610	Economy	17900.00
0005433286131	22610	Economy	16200.00
0005433286133	22610	Economy	16200.00
0005433810593	22610	Economy	16200.00
0005433810613	22610	Economy	16200.00
0005433286138	22610	Economy	16200.00
0005433286120	22610	Economy	16200.00
0005433286139	22610	Economy	16200.00
0005433286124	22610	Economy	16200.00
0005433810599	22610	Economy	16200.00
0005433810612	22610	Economy	16200.00
0005433009824	22610	Economy	16200.00
0005433286117	22610	Economy	16200.00
0005433286134	22610	Economy	16200.00
0005433286121	22610	Economy	16200.00
0005433286118	22610	Economy	16200.00
0005433810598	22610	Economy	16200.00
0005433009829	22610	Economy	16200.00
0005433009823	22610	Economy	16200.00
0005433286128	22610	Economy	16200.00
0005433009826	22610	Economy	16200.00
0005433009843	22610	Economy	16200.00
0005433009818	22610	Economy	16200.00
0005433286135	22610	Economy	16200.00
0005433009836	22610	Economy	16200.00
0005433009822	22610	Economy	16200.00
0005433009832	22610	Economy	16200.00
0005433009817	22610	Economy	16200.00
0005433009838	22610	Economy	16200.00
0005433009841	22610	Economy	16200.00
0005433286143	22610	Economy	16200.00
0005433810608	22610	Economy	16200.00
0005433286137	22610	Economy	16200.00
0005433009847	22610	Economy	16200.00
0005433009825	22610	Economy	16200.00
0005433286127	22610	Economy	16200.00
0005433009828	22610	Economy	16200.00
0005433286122	22610	Economy	16200.00
0005433286125	22610	Economy	16200.00
0005433009840	22610	Economy	16200.00
0005433009834	22610	Economy	16200.00
0005433009827	22610	Economy	16200.00
0005433009820	22610	Economy	16200.00
0005433009821	22610	Economy	16200.00
0005433009831	22610	Economy	16200.00
0005433286116	22610	Economy	16200.00
0005433009835	22610	Economy	16200.00
0005433286136	22610	Economy	16200.00
0005433810610	22610	Economy	16200.00
0005433810611	22610	Economy	16200.00
0005433009830	22610	Economy	16200.00
0005433009839	22610	Economy	16200.00
0005433286141	22610	Economy	16200.00
0005433009846	22610	Economy	16200.00
0005434152850	12281	Business	83800.00
0005434151812	12281	Business	83800.00
0005432751585	12281	Business	83800.00
0005432755122	12281	Business	83800.00
0005432755126	12281	Economy	27900.00
0005432751583	12281	Economy	27900.00
0005432755121	12281	Economy	30700.00
0005432755138	12281	Economy	30700.00
0005432755139	12281	Economy	27900.00
0005434152847	12281	Economy	27900.00
0005432755127	12281	Economy	27900.00
0005434152849	12281	Economy	27900.00
0005432755113	12281	Economy	27900.00
0005434152845	12281	Economy	27900.00
0005432755134	12281	Economy	27900.00
0005432755135	12281	Economy	27900.00
0005432755129	12281	Economy	27900.00
0005434151809	12281	Economy	27900.00
0005434152846	12281	Economy	27900.00
0005434151810	12281	Economy	27900.00
0005434151811	12281	Economy	27900.00
0005432755128	12281	Economy	27900.00
0005434151813	12281	Economy	27900.00
0005434152848	12281	Economy	27900.00
0005432755140	12281	Economy	27900.00
0005434151814	12281	Economy	27900.00
0005432751579	12281	Economy	27900.00
0005434151815	12281	Economy	27900.00
0005432751584	12281	Economy	27900.00
0005432755130	12281	Economy	27900.00
0005432755114	12281	Economy	27900.00
0005435283002	5580	Business	99800.00
0005435282900	5580	Business	99800.00
0005433848311	5580	Business	99800.00
0005433848312	5580	Business	99800.00
0005433848316	5580	Business	99800.00
0005433848296	5580	Business	99800.00
0005434173586	5580	Business	99800.00
0005435282950	5580	Business	99800.00
0005433848319	5580	Business	99800.00
0005433848288	5580	Business	99800.00
0005433848303	5580	Business	99800.00
0005433848308	5580	Business	99800.00
0005435283007	5580	Economy	33300.00
0005435282875	5580	Economy	33300.00
0005433815553	5580	Economy	33300.00
0005433815513	5580	Economy	33300.00
0005435282884	5580	Economy	33300.00
0005433848283	5580	Economy	33300.00
0005433848317	5580	Economy	33300.00
0005435282968	5580	Economy	36600.00
0005433815514	5580	Economy	36600.00
0005432081684	5580	Economy	33300.00
0005433848310	5580	Economy	33300.00
0005433848299	5580	Economy	33300.00
0005435282915	5580	Economy	33300.00
0005433848285	5580	Economy	33300.00
0005433848287	5580	Economy	33300.00
0005433848318	5580	Economy	33300.00
0005433848309	5580	Economy	33300.00
0005433848293	5580	Economy	33300.00
0005434173573	5580	Economy	33300.00
0005435283001	5580	Economy	33300.00
0005433848292	5580	Economy	33300.00
0005434173588	5580	Economy	33300.00
0005433848301	5580	Economy	33300.00
0005433848290	5580	Economy	33300.00
0005433815554	5580	Economy	33300.00
0005435282853	5580	Economy	33300.00
0005433848315	5580	Economy	33300.00
0005433848304	5580	Economy	33300.00
0005433848282	5580	Economy	33300.00
0005435282951	5580	Economy	33300.00
0005433848286	5580	Economy	33300.00
0005433815555	5580	Economy	33300.00
0005435282996	5580	Economy	33300.00
0005435283027	5580	Economy	33300.00
0005435282874	5580	Economy	33300.00
0005433848313	5580	Economy	33300.00
0005433848307	5580	Economy	33300.00
0005433848314	5580	Economy	33300.00
0005433848305	5580	Economy	33300.00
0005433815552	5580	Economy	33300.00
0005433848298	5580	Economy	33300.00
0005433848291	5580	Economy	33300.00
0005433848306	5580	Economy	33300.00
0005433848284	5580	Economy	33300.00
0005433848302	5580	Economy	33300.00
0005435282943	5580	Economy	33300.00
0005433848297	5580	Economy	33300.00
0005433848300	5580	Economy	33300.00
0005435282967	5580	Economy	33300.00
0005433848289	5580	Economy	33300.00
0005433848295	5580	Economy	33300.00
0005435283006	5580	Economy	33300.00
0005433848294	5580	Economy	33300.00
0005433847915	13880	Business	99800.00
0005433847738	13880	Business	99800.00
0005435283191	13880	Business	99800.00
0005435283186	13880	Business	99800.00
0005433847843	13880	Business	99800.00
0005435283183	13880	Business	99800.00
0005433847800	13880	Business	99800.00
0005433847924	13880	Business	99800.00
0005434173629	13880	Business	99800.00
0005433847967	13880	Business	99800.00
0005435283193	13880	Business	99800.00
0005433847677	13880	Business	99800.00
0005433847908	13880	Business	99800.00
0005433847526	13880	Business	99800.00
0005433847887	13880	Business	99800.00
0005433847804	13880	Business	99800.00
0005433847960	13880	Business	99800.00
0005434173656	13880	Business	99800.00
0005433847986	13880	Economy	33300.00
0005433848019	13880	Business	99800.00
0005433848095	13880	Economy	33300.00
0005433848012	13880	Economy	33300.00
0005433847973	13880	Economy	33300.00
0005433847799	13880	Economy	33300.00
0005435283185	13880	Economy	33300.00
0005433847694	13880	Economy	33300.00
0005433847801	13880	Economy	33300.00
0005433847772	13880	Economy	33300.00
0005433847890	13880	Economy	33300.00
0005433847882	13880	Economy	33300.00
0005433847851	13880	Economy	36600.00
0005435283184	13880	Economy	36600.00
0005433847670	13880	Economy	36600.00
0005433847693	13880	Economy	36600.00
0005433847778	13880	Economy	33300.00
0005432003786	13880	Economy	33300.00
0005435283190	13880	Economy	33300.00
0005435283188	13880	Economy	33300.00
0005433848008	13880	Economy	33300.00
0005435283189	13880	Economy	33300.00
0005433847984	13880	Economy	33300.00
0005433847762	13880	Economy	33300.00
0005435283196	13880	Economy	33300.00
0005435283182	13880	Economy	33300.00
0005435283179	13880	Economy	33300.00
0005433847852	13880	Economy	33300.00
0005433847837	13880	Economy	33300.00
0005433848158	13880	Economy	33300.00
0005435283180	13880	Economy	33300.00
0005433847574	13880	Economy	33300.00
0005433848154	13880	Economy	33300.00
0005435283194	13880	Economy	33300.00
0005433847867	13880	Economy	33300.00
0005433848156	13880	Economy	33300.00
0005434173658	13880	Economy	33300.00
0005433847985	13880	Economy	33300.00
0005433847676	13880	Economy	33300.00
0005434173657	13880	Economy	33300.00
0005433815452	13880	Economy	33300.00
0005433848153	13880	Economy	33300.00
0005433847942	13880	Economy	33300.00
0005433847645	13880	Economy	33300.00
0005433847739	13880	Economy	33300.00
0005435283192	13880	Economy	33300.00
0005433847909	13880	Economy	33300.00
0005432003787	13880	Economy	33300.00
0005433847707	13880	Economy	33300.00
0005433847848	13880	Economy	33300.00
0005435283195	13880	Economy	33300.00
0005433847866	13880	Economy	33300.00
0005432003788	13880	Economy	33300.00
0005433847719	13880	Economy	33300.00
0005433847525	13880	Economy	33300.00
0005433848014	13880	Economy	33300.00
0005434173631	13880	Economy	33300.00
0005435283181	13880	Economy	33300.00
0005434173632	13880	Economy	33300.00
0005433847671	13880	Economy	33300.00
0005434173630	13880	Economy	33300.00
0005433847832	13880	Economy	33300.00
0005433847868	13880	Economy	33300.00
0005433847803	13880	Economy	33300.00
0005435283197	13880	Economy	33300.00
0005433847945	13880	Economy	33300.00
0005433847987	13880	Economy	33300.00
0005433847573	13880	Economy	33300.00
0005433847706	13880	Economy	33300.00
0005433847906	13880	Economy	33300.00
0005435283178	13880	Economy	33300.00
0005433847812	13880	Economy	33300.00
0005433848015	13880	Economy	33300.00
0005433847483	13880	Economy	33300.00
0005433847838	13880	Economy	33300.00
0005435283198	13880	Economy	33300.00
0005433847689	13880	Economy	33300.00
0005433847775	13880	Economy	33300.00
0005433847828	13880	Economy	33300.00
0005433847955	13880	Economy	33300.00
0005433848009	13880	Economy	33300.00
0005433847761	13880	Economy	33300.00
0005433848157	13880	Economy	33300.00
0005434173633	13880	Economy	33300.00
0005435283187	13880	Economy	33300.00
0005432112577	7803	Economy	16600.00
0005434621144	7803	Economy	15100.00
0005434621147	7803	Economy	15100.00
0005435332573	7803	Economy	15100.00
0005434621142	7803	Economy	15100.00
0005434621151	7803	Economy	15100.00
0005434621143	7803	Economy	15100.00
0005435332581	7803	Economy	15100.00
0005435332572	7803	Economy	15100.00
0005432112576	7803	Economy	15100.00
0005434621141	7803	Economy	15100.00
0005435332555	7803	Economy	15100.00
0005435332551	7803	Economy	15100.00
0005435332519	7803	Economy	15100.00
0005435332580	7803	Economy	15100.00
0005435332579	7803	Economy	15100.00
0005435332552	7803	Economy	15100.00
0005432112578	7803	Economy	15100.00
0005435332578	7803	Economy	15100.00
0005435332520	7803	Economy	15100.00
0005434621145	7803	Economy	15100.00
0005434621149	7803	Economy	15100.00
0005434621140	7803	Economy	15100.00
0005434621152	7803	Economy	15100.00
0005435332521	7803	Economy	15100.00
0005434621146	7803	Economy	15100.00
0005434621150	7803	Economy	15100.00
0005435332517	7803	Economy	15100.00
0005434621148	7803	Economy	15100.00
0005435332615	32989	Economy	16600.00
0005434621038	32989	Economy	16600.00
0005434621056	32989	Economy	16600.00
0005435332614	32989	Economy	15100.00
0005434620970	32989	Economy	15100.00
0005434620989	32989	Economy	15100.00
0005434620893	32989	Economy	15100.00
0005434621000	32989	Economy	15100.00
0005435332618	32989	Economy	15100.00
0005434620894	32989	Economy	15100.00
0005435332617	32989	Economy	15100.00
0005434620978	32989	Economy	15100.00
0005435332616	32989	Economy	15100.00
0005434620924	32989	Economy	15100.00
0005434621072	32989	Economy	15100.00
0005434621001	32989	Economy	15100.00
0005435937458	4274	Business	38000.00
0005435937442	4274	Business	38000.00
0005435786292	4274	Business	38000.00
0005435918744	4274	Business	38000.00
0005435918739	4274	Business	38000.00
0005432190737	4274	Business	38000.00
0005435786288	4274	Business	38000.00
0005434994289	4274	Business	38000.00
0005435937469	4274	Economy	12700.00
0005434994286	4274	Economy	12700.00
0005435786283	4274	Economy	12700.00
0005435786300	4274	Economy	12700.00
0005435918745	4274	Economy	13900.00
0005435786282	4274	Economy	13900.00
0005434994287	4274	Economy	13900.00
0005435786293	4274	Economy	12700.00
0005435918758	4274	Economy	12700.00
0005435786285	4274	Economy	12700.00
0005435937461	4274	Economy	12700.00
0005435786302	4274	Economy	12700.00
0005434994290	4274	Economy	12700.00
0005434994288	4274	Economy	12700.00
0005434994291	4274	Economy	12700.00
0005435786298	4274	Economy	12700.00
0005435786286	4274	Economy	12700.00
0005435937459	4274	Economy	12700.00
0005435786287	4274	Economy	12700.00
0005435937464	4274	Economy	12700.00
0005435786299	4274	Economy	12700.00
0005435786301	4274	Economy	12700.00
0005435786289	4274	Economy	12700.00
0005435918723	4274	Economy	12700.00
0005435786304	4274	Economy	12700.00
0005435918740	4274	Economy	12700.00
0005435786290	4274	Economy	12700.00
0005435937460	4274	Economy	12700.00
0005432190735	4274	Economy	12700.00
0005432190736	4274	Economy	12700.00
0005435937441	4274	Economy	12700.00
0005435786294	4274	Economy	12700.00
0005432190734	4274	Economy	12700.00
0005435786291	4274	Economy	12700.00
0005434994285	4274	Economy	12700.00
0005435786297	4274	Economy	12700.00
0005432190733	4274	Economy	12700.00
0005435937463	4274	Economy	12700.00
0005435786295	4274	Economy	12700.00
0005435786303	4274	Economy	12700.00
0005435786296	4274	Economy	12700.00
0005435786284	4274	Economy	12700.00
0005435918741	4274	Economy	12700.00
0005435785936	27277	Business	38000.00
0005435786015	27277	Business	38000.00
0005435937541	27277	Business	38000.00
0005435787384	27277	Business	38000.00
0005434994208	27277	Business	38000.00
0005435937533	27277	Business	38000.00
0005435785948	27277	Business	38000.00
0005435785981	27277	Business	38000.00
0005435786057	27277	Economy	12700.00
0005435937540	27277	Economy	12700.00
0005435937538	27277	Economy	12700.00
0005435937537	27277	Economy	12700.00
0005435786032	27277	Economy	13900.00
0005435786058	27277	Economy	13900.00
0005432195751	27277	Economy	13900.00
0005435785980	27277	Economy	13900.00
0005434994176	27277	Economy	12700.00
0005435785918	27277	Economy	12700.00
0005435785947	27277	Economy	12700.00
0005435785942	27277	Economy	12700.00
0005435785860	27277	Economy	12700.00
0005435785975	27277	Economy	12700.00
0005435786021	27277	Economy	12700.00
0005435918785	27277	Economy	12700.00
0005434994199	27277	Economy	12700.00
0005435786010	27277	Economy	12700.00
0005435937532	27277	Economy	12700.00
0005435785721	27277	Economy	12700.00
0005435937535	27277	Economy	12700.00
0005435785779	27277	Economy	12700.00
0005435937531	27277	Economy	12700.00
0005435785722	27277	Economy	12700.00
0005435787382	27277	Economy	12700.00
0005435786067	27277	Economy	12700.00
0005435785907	27277	Economy	12700.00
0005435937539	27277	Economy	12700.00
0005434994198	27277	Economy	12700.00
0005435937530	27277	Economy	12700.00
0005435786009	27277	Economy	12700.00
0005435786033	27277	Economy	12700.00
0005435785976	27277	Economy	12700.00
0005435937534	27277	Economy	12700.00
0005435937536	27277	Economy	12700.00
0005435785829	27277	Economy	12700.00
0005435785956	27277	Economy	12700.00
0005435918786	27277	Economy	12700.00
0005434994185	27277	Economy	12700.00
0005435787383	27277	Economy	12700.00
0005434994175	27277	Economy	12700.00
0005435918784	27277	Economy	12700.00
0005435785791	27277	Economy	12700.00
0005435785850	27277	Economy	12700.00
0005435785828	27277	Economy	12700.00
0005434994190	27277	Economy	12700.00
0005435786011	27277	Economy	12700.00
0005435785720	27277	Economy	12700.00
0005435786027	27277	Economy	12700.00
0005435785851	27277	Economy	12700.00
0005435785968	27277	Economy	12700.00
0005435785957	27277	Economy	12700.00
0005432146255	19867	Economy	12800.00
0005434559154	4719	Business	40900.00
0005434559158	4719	Business	40900.00
0005432461270	4719	Business	40900.00
0005432461293	4719	Business	40900.00
0005432170566	4719	Business	40900.00
0005434559163	4719	Business	40900.00
0005432569272	4719	Business	40900.00
0005435840387	4719	Business	40900.00
0005432461278	4719	Business	40900.00
0005432569302	4719	Business	40900.00
0005432170571	4719	Business	40900.00
0005434082586	4719	Business	40900.00
0005433451673	4719	Business	40900.00
0005432571424	4719	Business	40900.00
0005434082575	4719	Business	40900.00
0005434559160	4719	Business	40900.00
0005432569279	4719	Business	40900.00
0005432461290	4719	Business	40900.00
0005434082569	4719	Business	40900.00
0005432569264	4719	Business	40900.00
0005432569284	4719	Business	40900.00
0005433452792	4719	Business	40900.00
0005432461268	4719	Business	40900.00
0005432569308	4719	Business	40900.00
0005434559155	4719	Economy	15000.00
0005434082579	4719	Economy	15000.00
0005432569286	4719	Economy	13600.00
0005432569283	4719	Economy	13600.00
0005435840378	4719	Economy	13600.00
0005432569266	4719	Economy	13600.00
0005435840371	4719	Economy	13600.00
0005435840370	4719	Economy	13600.00
0005432571426	4719	Economy	13600.00
0005432461284	4719	Economy	13600.00
0005434082571	4719	Economy	13600.00
0005432461253	4719	Economy	13600.00
0005432569262	4719	Economy	13600.00
0005432569261	4719	Economy	13600.00
0005432461269	4719	Economy	13600.00
0005432569276	4719	Economy	13600.00
0005432461254	4719	Economy	13600.00
0005432569275	4719	Economy	13600.00
0005432170565	4719	Economy	13600.00
0005432461279	4719	Economy	13600.00
0005432461261	4719	Economy	13600.00
0005432461267	4719	Economy	13600.00
0005434559164	4719	Economy	13600.00
0005432461263	4719	Economy	13600.00
0005432569304	4719	Economy	13600.00
0005432461260	4719	Economy	13600.00
0005432569278	4719	Economy	13600.00
0005432461256	4719	Economy	13600.00
0005432461274	4719	Economy	13600.00
0005432569307	4719	Economy	13600.00
0005432461275	4719	Economy	13600.00
0005432569280	4719	Economy	13600.00
0005434082587	4719	Economy	13600.00
0005435840381	4719	Economy	13600.00
0005432461259	4719	Economy	13600.00
0005432569306	4719	Economy	13600.00
0005433452793	4719	Economy	13600.00
0005432569271	4719	Economy	13600.00
0005432170569	4719	Economy	13600.00
0005434559157	4719	Economy	13600.00
0005432461295	4719	Economy	13600.00
0005432569309	4719	Economy	13600.00
0005432461277	4719	Economy	13600.00
0005432569270	4719	Economy	13600.00
0005432461292	4719	Economy	13600.00
0005432461262	4719	Economy	13600.00
0005434082577	4719	Economy	13600.00
0005434082573	4719	Economy	13600.00
0005432569293	4719	Economy	13600.00
0005432569292	4719	Economy	13600.00
0005432569263	4719	Economy	13600.00
0005434082588	4719	Economy	13600.00
0005432569289	4719	Economy	13600.00
0005432569273	4719	Economy	13600.00
0005432569274	4719	Economy	13600.00
0005432569268	4719	Economy	13600.00
0005432569294	4719	Economy	13600.00
0005432569310	4719	Economy	13600.00
0005432569301	4719	Economy	13600.00
0005432569282	4719	Economy	13600.00
0005432461264	4719	Economy	13600.00
0005432461273	4719	Economy	13600.00
0005434082570	4719	Economy	13600.00
0005434082580	4719	Economy	13600.00
0005433726166	4719	Economy	13600.00
0005434082576	4719	Economy	13600.00
0005432569265	4719	Economy	15000.00
0005432569290	4719	Economy	13600.00
0005432461265	4719	Economy	13600.00
0005434559162	4719	Economy	13600.00
0005432569291	4719	Economy	15000.00
0005434082578	4719	Economy	15000.00
0005432461276	4719	Economy	13600.00
0005432461258	4719	Economy	13600.00
0005434082582	4719	Economy	13600.00
0005432569269	4719	Economy	13600.00
0005432461288	4719	Economy	13600.00
0005432569277	4719	Economy	13600.00
0005432461266	4719	Economy	13600.00
0005432569297	4719	Economy	13600.00
0005435840382	4719	Economy	13600.00
0005432461289	4719	Economy	13600.00
0005432569298	4719	Economy	13600.00
0005432569295	4719	Economy	13600.00
0005434559165	4719	Economy	13600.00
0005432569287	4719	Economy	13600.00
0005432571425	4719	Economy	13600.00
0005434082567	4719	Economy	13600.00
0005434082583	4719	Economy	13600.00
0005432569300	4719	Economy	13600.00
0005433726167	4719	Economy	13600.00
0005432461280	4719	Economy	13600.00
0005432569305	4719	Economy	13600.00
0005434559159	4719	Economy	13600.00
0005432461282	4719	Economy	13600.00
0005434082574	4719	Economy	13600.00
0005435840375	4719	Economy	13600.00
0005435840376	4719	Economy	13600.00
0005432461281	4719	Economy	13600.00
0005432461285	4719	Economy	13600.00
0005432569285	4719	Economy	13600.00
0005432461283	4719	Economy	13600.00
0005435840373	4719	Economy	13600.00
0005432461291	4719	Economy	13600.00
0005432170567	4719	Economy	13600.00
0005432569281	4719	Economy	13600.00
0005432461271	4719	Economy	13600.00
0005432569299	4719	Economy	13600.00
0005432569303	4719	Economy	13600.00
0005434559161	4719	Economy	13600.00
0005432461255	4719	Economy	13600.00
0005434559156	4719	Economy	13600.00
0005432170568	4719	Economy	13600.00
0005432170570	4719	Economy	13600.00
0005432461272	4719	Economy	13600.00
0005432461286	4719	Economy	13600.00
0005432569288	4719	Economy	13600.00
0005434082568	4719	Economy	13600.00
0005432461294	4719	Economy	13600.00
0005434082584	4719	Economy	13600.00
0005434082585	4719	Economy	13600.00
0005432461257	4719	Economy	13600.00
0005435840377	4719	Economy	13600.00
0005434082581	4719	Economy	13600.00
0005432569267	4719	Economy	13600.00
0005435840374	4719	Economy	13600.00
0005432569296	4719	Economy	13600.00
0005434082572	4719	Economy	13600.00
0005432461287	4719	Economy	13600.00
0005432569165	30571	Business	40900.00
0005432568943	30571	Business	40900.00
0005432460922	30571	Business	40900.00
0005432460819	30571	Business	40900.00
0005432568893	30571	Business	40900.00
0005432568887	30571	Business	40900.00
0005432568921	30571	Business	40900.00
0005432568781	30571	Business	40900.00
0005432568648	30571	Business	40900.00
0005433726135	30571	Business	40900.00
0005432568869	30571	Business	40900.00
0005433726126	30571	Business	40900.00
0005432460986	30571	Business	40900.00
0005432460924	30571	Business	40900.00
0005434082326	30571	Business	40900.00
0005432568790	30571	Business	40900.00
0005432568757	30571	Business	40900.00
0005434150143	30571	Business	40900.00
0005432568643	30571	Business	40900.00
0005432461011	30571	Business	40900.00
0005434150142	30571	Business	40900.00
0005432460845	30571	Business	40900.00
0005432460943	30571	Business	40900.00
0005432568669	30571	Business	40900.00
0005434082241	30571	Economy	15000.00
0005432568639	30571	Business	40900.00
0005432460909	30571	Economy	15000.00
0005432460890	30571	Economy	15000.00
0005432569018	30571	Economy	15000.00
0005432461039	30571	Economy	13600.00
0005432460820	30571	Economy	13600.00
0005432568848	30571	Economy	13600.00
0005432460901	30571	Economy	13600.00
0005434082309	30571	Economy	13600.00
0005433726138	30571	Economy	13600.00
0005432568969	30571	Economy	13600.00
0005432460897	30571	Economy	13600.00
0005432568654	30571	Economy	13600.00
0005432460872	30571	Economy	13600.00
0005432568812	30571	Economy	13600.00
0005432460737	30571	Economy	13600.00
0005432568710	30571	Economy	13600.00
0005432568762	30571	Economy	13600.00
0005432568644	30571	Economy	13600.00
0005432460875	30571	Economy	13600.00
0005432568942	30571	Economy	13600.00
0005433726130	30571	Economy	13600.00
0005432460907	30571	Economy	13600.00
0005432460921	30571	Economy	13600.00
0005434082168	30571	Economy	13600.00
0005432460728	30571	Economy	13600.00
0005434082470	30571	Economy	13600.00
0005432568955	30571	Economy	13600.00
0005432460949	30571	Economy	13600.00
0005432571391	30571	Economy	13600.00
0005432461115	30571	Economy	13600.00
0005432213707	30571	Economy	13600.00
0005432568716	30571	Economy	13600.00
0005434082356	30571	Economy	13600.00
0005433726117	30571	Economy	13600.00
0005433726136	30571	Economy	13600.00
0005432460895	30571	Economy	13600.00
0005434082348	30571	Economy	13600.00
0005432568811	30571	Economy	13600.00
0005432568748	30571	Economy	13600.00
0005432568709	30571	Economy	13600.00
0005434082285	30571	Economy	13600.00
0005432161215	30571	Economy	13600.00
0005432460883	30571	Economy	13600.00
0005432460876	30571	Economy	13600.00
0005432460896	30571	Economy	13600.00
0005432568950	30571	Economy	13600.00
0005433454914	30571	Economy	13600.00
0005432568668	30571	Economy	13600.00
0005432568688	30571	Economy	13600.00
0005432461061	30571	Economy	13600.00
0005432460734	30571	Economy	13600.00
0005434082286	30571	Economy	13600.00
0005432460950	30571	Economy	13600.00
0005432461003	30571	Economy	13600.00
0005432569016	30571	Economy	13600.00
0005432460726	30571	Economy	13600.00
0005432460865	30571	Economy	13600.00
0005433726112	30571	Economy	13600.00
0005432568686	30571	Economy	13600.00
0005432568670	30571	Economy	13600.00
0005434082324	30571	Economy	13600.00
0005432568715	30571	Economy	13600.00
0005432460920	30571	Economy	13600.00
0005432568749	30571	Economy	13600.00
0005432568632	30571	Economy	13600.00
0005432213706	30571	Economy	13600.00
0005432568851	30571	Economy	13600.00
0005434082373	30571	Economy	13600.00
0005432571392	30571	Economy	13600.00
0005433726122	30571	Economy	13600.00
0005434150149	30571	Economy	13600.00
0005434082318	30571	Economy	13600.00
0005432568635	30571	Economy	13600.00
0005433452774	30571	Economy	13600.00
0005434082303	30571	Economy	13600.00
0005434082325	30571	Economy	13600.00
0005432461048	30571	Economy	13600.00
0005432568711	30571	Economy	13600.00
0005432568595	30571	Economy	13600.00
0005433454913	30571	Economy	13600.00
0005432568561	30571	Economy	13600.00
0005434082167	30571	Economy	13600.00
0005433726127	30571	Economy	13600.00
0005432568999	30571	Economy	13600.00
0005432460936	30571	Economy	13600.00
0005434082312	30571	Economy	13600.00
0005433452778	30571	Economy	13600.00
0005432568547	30571	Economy	13600.00
0005432568874	30571	Economy	13600.00
0005433454915	30571	Economy	13600.00
0005432568712	30571	Economy	13600.00
0005432460918	30571	Economy	13600.00
0005432460729	30571	Economy	13600.00
0005432568759	30571	Economy	13600.00
0005434150148	30571	Economy	13600.00
0005432569164	30571	Economy	13600.00
0005432568782	30571	Economy	13600.00
0005432568740	30571	Economy	13600.00
0005432568791	30571	Economy	13600.00
0005432460935	30571	Economy	13600.00
0005432460948	30571	Economy	15000.00
0005432461068	30571	Economy	13600.00
0005434082269	30571	Economy	15000.00
0005432568852	30571	Economy	13600.00
0005432568631	30571	Economy	13600.00
0005433726118	30571	Economy	15000.00
0005432460854	30571	Economy	13600.00
0005432460837	30571	Economy	13600.00
0005434082313	30571	Economy	13600.00
0005432213705	30571	Economy	13600.00
0005434082355	30571	Economy	13600.00
0005432461040	30571	Economy	13600.00
0005432568756	30571	Economy	13600.00
0005432568733	30571	Economy	13600.00
0005432568601	30571	Economy	13600.00
0005433726125	30571	Economy	13600.00
0005432568732	30571	Economy	13600.00
0005433726124	30571	Economy	13600.00
0005434150145	30571	Economy	13600.00
0005433726113	30571	Economy	13600.00
0005432568758	30571	Economy	13600.00
0005434082314	30571	Economy	13600.00
0005432460855	30571	Economy	13600.00
0005434082290	30571	Economy	13600.00
0005432460934	30571	Economy	13600.00
0005434082349	30571	Economy	13600.00
0005434082254	30571	Economy	13600.00
0005434150147	30571	Economy	13600.00
0005434082238	30571	Economy	13600.00
0005432568837	30571	Economy	13600.00
0005432460862	30571	Economy	13600.00
0005432461047	30571	Economy	13600.00
0005432568582	30571	Economy	13600.00
0005433726123	30571	Economy	13600.00
0005432568923	30571	Economy	13600.00
0005432568839	30571	Economy	13600.00
0005432460942	30571	Economy	13600.00
0005434082270	30571	Economy	13600.00
0005433726128	30571	Economy	13600.00
0005432568886	30571	Economy	13600.00
0005432568685	30571	Economy	13600.00
0005432568954	30571	Economy	13600.00
0005433452779	30571	Economy	13600.00
0005433726116	30571	Economy	13600.00
0005432161214	30571	Economy	13600.00
0005432460988	30571	Economy	13600.00
0005432460882	30571	Economy	13600.00
0005434082311	30571	Economy	13600.00
0005432460750	30571	Economy	13600.00
0005432460941	30571	Economy	13600.00
0005432460751	30571	Economy	13600.00
0005432460906	30571	Economy	13600.00
0005432568785	30571	Economy	13600.00
0005432460917	30571	Economy	13600.00
0005432460725	30571	Economy	13600.00
0005432460815	30571	Economy	13600.00
0005434082289	30571	Economy	13600.00
0005432568761	30571	Economy	13600.00
0005432460951	30571	Economy	13600.00
0005433726129	30571	Economy	13600.00
0005432460828	30571	Economy	13600.00
0005434082310	30571	Economy	13600.00
0005432568870	30571	Economy	13600.00
0005434150146	30571	Economy	13600.00
0005432568894	30571	Economy	13600.00
0005432568947	30571	Economy	13600.00
0005432568638	30571	Economy	13600.00
0005432460863	30571	Economy	13600.00
0005434082308	30571	Economy	13600.00
0005432568553	30571	Economy	13600.00
0005432460818	30571	Economy	13600.00
0005434150144	30571	Economy	13600.00
0005432568895	30571	Economy	13600.00
0005432460926	30571	Economy	13600.00
0005432568831	30571	Economy	13600.00
0005432568560	30571	Economy	13600.00
0005432569003	30571	Economy	13600.00
0005435720861	13666	Economy	9900.00
0005435720859	13666	Economy	9900.00
0005435720860	13666	Economy	9900.00
0005435720150	21227	Economy	9900.00
0005435720146	21227	Economy	9900.00
0005435722101	21227	Economy	9900.00
0005432295952	22798	Economy	8800.00
0005432295951	22798	Economy	8800.00
0005432295953	22798	Economy	8800.00
0005433345851	11120	Business	23600.00
0005435380383	11120	Business	23600.00
0005435508549	11120	Business	23600.00
0005433345835	11120	Business	23600.00
0005433345837	11120	Business	23600.00
0005433345865	11120	Business	23600.00
0005433345878	11120	Business	23600.00
0005433345880	11120	Business	23600.00
0005435097469	11120	Business	23600.00
0005433345861	11120	Business	23600.00
0005433345857	11120	Business	23600.00
0005433345832	11120	Business	23600.00
0005433345876	11120	Economy	7900.00
0005435508564	11120	Economy	7900.00
0005435508625	11120	Economy	7900.00
0005435508638	11120	Economy	7900.00
0005435508603	11120	Economy	7900.00
0005435508578	11120	Economy	7900.00
0005433345838	11120	Economy	7900.00
0005435529994	11120	Economy	7900.00
0005435508590	11120	Economy	7900.00
0005435508656	11120	Economy	7900.00
0005433345895	11120	Economy	7900.00
0005433345893	11120	Economy	7900.00
0005435508559	11120	Economy	7900.00
0005435508626	11120	Economy	7900.00
0005433345852	11120	Economy	7900.00
0005433345827	11120	Economy	7900.00
0005433345828	11120	Economy	7900.00
0005433345872	11120	Economy	7900.00
0005435097472	11120	Economy	7900.00
0005435097470	11120	Economy	7900.00
0005433345863	11120	Economy	7900.00
0005435097475	11120	Economy	7900.00
0005435508508	11120	Economy	7900.00
0005433345854	11120	Economy	7900.00
0005433345884	11120	Economy	7900.00
0005435508658	11120	Economy	7900.00
0005435529987	11120	Economy	7900.00
0005433345875	11120	Economy	7900.00
0005433345891	11120	Economy	7900.00
0005433345890	11120	Economy	7900.00
0005435380397	11120	Economy	7900.00
0005435380394	11120	Economy	7900.00
0005435097476	11120	Economy	7900.00
0005433345829	11120	Economy	7900.00
0005435508630	11120	Economy	7900.00
0005433345847	11120	Economy	7900.00
0005433345886	11120	Economy	7900.00
0005433345859	11120	Economy	7900.00
0005435508640	11120	Economy	7900.00
0005433345840	11120	Economy	7900.00
0005433345883	11120	Economy	8600.00
0005435508544	11120	Economy	8600.00
0005435529992	11120	Economy	8600.00
0005435097473	11120	Economy	8600.00
0005435529993	11120	Economy	8600.00
0005433345889	11120	Economy	8600.00
0005433345850	11120	Economy	7900.00
0005435529984	11120	Economy	7900.00
0005433345833	11120	Economy	7900.00
0005433345866	11120	Economy	7900.00
0005435508598	11120	Economy	7900.00
0005435508629	11120	Economy	7900.00
0005435508633	11120	Economy	7900.00
0005433345885	11120	Economy	7900.00
0005433345844	11120	Economy	7900.00
0005433345846	11120	Economy	7900.00
0005435529978	11120	Economy	7900.00
0005435530006	11120	Economy	7900.00
0005433345881	11120	Economy	7900.00
0005433345834	11120	Economy	7900.00
0005435508543	11120	Economy	7900.00
0005435097478	11120	Economy	7900.00
0005433345867	11120	Economy	7900.00
0005435097477	11120	Economy	7900.00
0005435380382	11120	Economy	7900.00
0005435508565	11120	Economy	7900.00
0005435508507	11120	Economy	7900.00
0005433345858	11120	Economy	7900.00
0005433345871	11120	Economy	7900.00
0005435508545	11120	Economy	7900.00
0005433345841	11120	Economy	7900.00
0005433345892	11120	Economy	7900.00
0005435508589	11120	Economy	7900.00
0005433345864	11120	Economy	7900.00
0005433345848	11120	Economy	7900.00
0005435529998	11120	Economy	7900.00
0005433345839	11120	Economy	7900.00
0005435529997	11120	Economy	7900.00
0005435380346	11120	Economy	7900.00
0005433345869	11120	Economy	7900.00
0005433345874	11120	Economy	7900.00
0005433345862	11120	Economy	7900.00
0005433345879	11120	Economy	7900.00
0005433345868	11120	Economy	7900.00
0005433345887	11120	Economy	7900.00
0005433345877	11120	Economy	7900.00
0005435508639	11120	Economy	7900.00
0005433345860	11120	Economy	7900.00
0005433345882	11120	Economy	7900.00
0005433345849	11120	Economy	7900.00
0005433345894	11120	Economy	7900.00
0005433345856	11120	Economy	7900.00
0005433345845	11120	Economy	7900.00
0005435097471	11120	Economy	7900.00
0005435530009	11120	Economy	7900.00
0005435097474	11120	Economy	7900.00
0005435530008	11120	Economy	7900.00
0005433345842	11120	Economy	7900.00
0005433345873	11120	Economy	7900.00
0005433345831	11120	Economy	7900.00
0005435508560	11120	Economy	7900.00
0005433345855	11120	Economy	7900.00
0005435508657	11120	Economy	7900.00
0005433345843	11120	Economy	7900.00
0005435380379	11120	Economy	7900.00
0005435508579	11120	Economy	7900.00
0005433345830	11120	Economy	7900.00
0005433345836	11120	Economy	7900.00
0005433345888	11120	Economy	7900.00
0005433345870	11120	Economy	7900.00
0005435508506	11120	Economy	7900.00
0005435380376	11120	Economy	7900.00
0005435380409	11120	Economy	7900.00
0005433345853	11120	Economy	7900.00
0005435530007	11120	Economy	7900.00
0005433345092	17094	Business	23600.00
0005435097445	17094	Business	23600.00
0005433344398	17094	Business	23600.00
0005435380432	17094	Business	23600.00
0005433345040	17094	Business	23600.00
0005433344960	17094	Business	23600.00
0005433345388	17094	Business	23600.00
0005433345089	17094	Business	23600.00
0005435097397	17094	Business	23600.00
0005433345280	17094	Business	23600.00
0005433345045	17094	Business	23600.00
0005435097442	17094	Business	23600.00
0005433344706	17094	Economy	7900.00
0005433345106	17094	Economy	7900.00
0005433345075	17094	Economy	7900.00
0005435380428	17094	Economy	7900.00
0005433344456	17094	Economy	7900.00
0005433345279	17094	Economy	7900.00
0005433345278	17094	Economy	7900.00
0005433345199	17094	Economy	7900.00
0005435097375	17094	Economy	7900.00
0005433345133	17094	Economy	7900.00
0005433344630	17094	Economy	7900.00
0005435097374	17094	Economy	7900.00
0005433344707	17094	Economy	7900.00
0005433344774	17094	Economy	7900.00
0005433344773	17094	Economy	7900.00
0005433344974	17094	Economy	7900.00
0005435097393	17094	Economy	7900.00
0005433344551	17094	Economy	7900.00
0005433344838	17094	Economy	7900.00
0005433344449	17094	Economy	7900.00
0005433344645	17094	Economy	7900.00
0005433344541	17094	Economy	7900.00
0005435097371	17094	Economy	7900.00
0005435380431	17094	Economy	7900.00
0005435097407	17094	Economy	7900.00
0005433345085	17094	Economy	7900.00
0005433344841	17094	Economy	7900.00
0005433344806	17094	Economy	7900.00
0005433344821	17094	Economy	7900.00
0005433345019	17094	Economy	7900.00
0005435097443	17094	Economy	7900.00
0005433345467	17094	Economy	7900.00
0005433344540	17094	Economy	7900.00
0005433344805	17094	Economy	7900.00
0005433345044	17094	Economy	7900.00
0005433345219	17094	Economy	7900.00
0005433344899	17094	Economy	7900.00
0005433344801	17094	Economy	7900.00
0005433345024	17094	Economy	7900.00
0005433345262	17094	Economy	7900.00
0005435097362	17094	Economy	8600.00
0005433344594	17094	Economy	8600.00
0005433345132	17094	Economy	8600.00
0005433345134	17094	Economy	8600.00
0005433345086	17094	Economy	8600.00
0005433344728	17094	Economy	8600.00
0005433344992	17094	Economy	7900.00
0005433344895	17094	Economy	7900.00
0005433345242	17094	Economy	7900.00
0005435097444	17094	Economy	7900.00
0005435097355	17094	Economy	7900.00
0005433344657	17094	Economy	7900.00
0005433344264	17094	Economy	7900.00
0005433344822	17094	Economy	7900.00
0005435545947	17094	Economy	7900.00
0005433344843	17094	Economy	7900.00
0005435097354	17094	Economy	7900.00
0005433344938	17094	Economy	7900.00
0005433344898	17094	Economy	7900.00
0005433345160	17094	Economy	7900.00
0005433344727	17094	Economy	7900.00
0005433345238	17094	Economy	7900.00
0005433344792	17094	Economy	7900.00
0005435545946	17094	Economy	7900.00
0005433345153	17094	Economy	7900.00
0005435545948	17094	Economy	7900.00
0005433345213	17094	Economy	7900.00
0005433344680	17094	Economy	7900.00
0005433344571	17094	Economy	7900.00
0005433345164	17094	Economy	7900.00
0005433344439	17094	Economy	7900.00
0005433344455	17094	Economy	7900.00
0005433344810	17094	Economy	7900.00
0005435097368	17094	Economy	7900.00
0005432293274	17094	Economy	7900.00
0005433344802	17094	Economy	7900.00
0005433344658	17094	Economy	7900.00
0005433344721	17094	Economy	7900.00
0005433344991	17094	Economy	7900.00
0005433344961	17094	Economy	7900.00
0005433344998	17094	Economy	7900.00
0005433344650	17094	Economy	7900.00
0005433345291	17094	Economy	7900.00
0005433344823	17094	Economy	7900.00
0005435380429	17094	Economy	7900.00
0005433345180	17094	Economy	7900.00
0005433345136	17094	Economy	7900.00
0005433344797	17094	Economy	7900.00
0005435380430	17094	Economy	7900.00
0005435097367	17094	Economy	7900.00
0005433344975	17094	Economy	7900.00
0005433345337	17094	Economy	7900.00
0005433345339	17094	Economy	7900.00
0005433344550	17094	Economy	7900.00
0005433345336	17094	Economy	7900.00
0005433344811	17094	Economy	7900.00
0005433345135	17094	Economy	7900.00
0005433344704	17094	Economy	7900.00
0005433345165	17094	Economy	7900.00
0005433345224	17094	Economy	7900.00
0005433345060	17094	Economy	7900.00
0005433344796	17094	Economy	7900.00
0005433345335	17094	Economy	7900.00
0005433344619	17094	Economy	7900.00
0005435097394	17094	Economy	7900.00
0005433344842	17094	Economy	7900.00
0005433344631	17094	Economy	7900.00
0005433344867	17094	Economy	7900.00
0005433344946	17094	Economy	7900.00
0005433344824	17094	Economy	7900.00
0005433344737	17094	Economy	7900.00
0005433344559	17094	Economy	7900.00
0005433344572	17094	Economy	7900.00
0005433345220	17094	Economy	7900.00
0005433345105	17094	Economy	7900.00
0005433344731	17094	Economy	7900.00
0005433344866	17094	Economy	7900.00
0005433344629	17094	Economy	7900.00
0005434159016	9101	Business	26600.00
0005433477219	9101	Business	26600.00
0005433477208	9101	Business	26600.00
0005433507687	9101	Business	26600.00
0005432920265	9101	Business	26600.00
0005433477200	9101	Business	26600.00
0005433477207	9101	Business	26600.00
0005434159019	9101	Business	26600.00
0005433477218	9101	Business	26600.00
0005434159014	9101	Economy	8900.00
0005434159011	9101	Economy	8900.00
0005433477210	9101	Economy	8900.00
0005433481377	9101	Economy	8900.00
0005433507685	9101	Economy	8900.00
0005433477202	9101	Economy	8900.00
0005433477230	9101	Economy	8900.00
0005432920255	9101	Economy	8900.00
0005433477213	9101	Economy	9800.00
0005433507680	9101	Economy	9800.00
0005433507681	9101	Economy	9800.00
0005433507684	9101	Economy	8900.00
0005432920248	9101	Economy	8900.00
0005434159012	9101	Economy	8900.00
0005433477225	9101	Economy	8900.00
0005433481378	9101	Economy	8900.00
0005432920201	9101	Economy	8900.00
0005433477205	9101	Economy	8900.00
0005432920242	9101	Economy	8900.00
0005433477199	9101	Economy	8900.00
0005433477229	9101	Economy	8900.00
0005433507682	9101	Economy	8900.00
0005433477226	9101	Economy	8900.00
0005433477227	9101	Economy	8900.00
0005433477211	9101	Economy	8900.00
0005433477220	9101	Economy	8900.00
0005433477201	9101	Economy	8900.00
0005433477197	9101	Economy	8900.00
0005433507679	9101	Economy	8900.00
0005433477222	9101	Economy	8900.00
0005433477214	9101	Economy	8900.00
0005434159015	9101	Economy	8900.00
0005434159025	9101	Economy	8900.00
0005433477206	9101	Economy	8900.00
0005433477212	9101	Economy	8900.00
0005433477215	9101	Economy	8900.00
0005433477217	9101	Economy	8900.00
0005434159013	9101	Economy	8900.00
0005433477228	9101	Economy	8900.00
0005432920349	9101	Economy	8900.00
0005433481376	9101	Economy	8900.00
0005433477221	9101	Economy	8900.00
0005432920272	9101	Economy	8900.00
0005433477224	9101	Economy	8900.00
0005432920224	9101	Economy	8900.00
0005433507683	9101	Economy	8900.00
0005433507688	9101	Economy	8900.00
0005433477223	9101	Economy	8900.00
0005433477196	9101	Economy	8900.00
0005433477195	9101	Economy	8900.00
0005434159010	9101	Economy	8900.00
0005433477204	9101	Economy	8900.00
0005433481379	9101	Economy	8900.00
0005433477209	9101	Economy	8900.00
0005432920230	9101	Economy	8900.00
0005433507686	9101	Economy	8900.00
0005433477203	9101	Economy	8900.00
0005433477216	9101	Economy	8900.00
0005433507678	9101	Economy	8900.00
0005432920202	9101	Economy	8900.00
0005433477198	9101	Economy	8900.00
0005432920199	9101	Economy	8900.00
0005433481319	20482	Business	26600.00
0005432920450	20482	Business	26600.00
0005433507547	20482	Business	26600.00
0005433507516	20482	Business	26600.00
0005433507561	20482	Business	26600.00
0005433507565	20482	Business	26600.00
0005433481345	20482	Business	26600.00
0005433507590	20482	Business	26600.00
0005433481299	20482	Economy	8900.00
0005433481283	20482	Economy	8900.00
0005432920444	20482	Economy	8900.00
0005433481307	20482	Economy	8900.00
0005433507499	20482	Economy	8900.00
0005433507558	20482	Economy	8900.00
0005432920443	20482	Economy	8900.00
0005433507472	20482	Economy	8900.00
0005432920449	20482	Economy	9800.00
0005433507581	20482	Economy	9800.00
0005433507562	20482	Economy	9800.00
0005433481284	20482	Economy	8900.00
0005433507593	20482	Economy	8900.00
0005433507571	20482	Economy	8900.00
0005433507612	20482	Economy	8900.00
0005433507579	20482	Economy	8900.00
0005432920447	20482	Economy	8900.00
0005433507548	20482	Economy	8900.00
0005433507582	20482	Economy	8900.00
0005433507594	20482	Economy	8900.00
0005432920436	20482	Economy	8900.00
0005433507530	20482	Economy	8900.00
0005433507536	20482	Economy	8900.00
0005433507509	20482	Economy	8900.00
0005433507498	20482	Economy	8900.00
0005432920441	20482	Economy	8900.00
0005433507550	20482	Economy	8900.00
0005432920440	20482	Economy	8900.00
0005433481318	20482	Economy	8900.00
0005433507580	20482	Economy	8900.00
0005432920438	20482	Economy	8900.00
0005432920442	20482	Economy	8900.00
0005432920445	20482	Economy	8900.00
0005432920439	20482	Economy	8900.00
0005432920452	20482	Economy	8900.00
0005433507517	20482	Economy	8900.00
0005432920451	20482	Economy	8900.00
0005433507531	20482	Economy	8900.00
0005433507533	20482	Economy	8900.00
0005433507557	20482	Economy	8900.00
0005432920446	20482	Economy	8900.00
0005433507572	20482	Economy	8900.00
0005433507560	20482	Economy	8900.00
0005432920437	20482	Economy	8900.00
0005432920448	20482	Economy	8900.00
0005433507637	20482	Economy	8900.00
0005433507591	20482	Economy	8900.00
0005433507510	20482	Economy	8900.00
0005433481316	20482	Economy	8900.00
0005433507574	20482	Economy	8900.00
0005433507511	20482	Economy	8900.00
0005433507556	20482	Economy	8900.00
0005435179702	10194	Economy	5800.00
0005432396346	10194	Economy	5800.00
0005435179004	10194	Economy	5800.00
0005432396347	10194	Economy	5800.00
0005432394210	10194	Economy	5800.00
0005435179703	10194	Economy	5800.00
0005432394212	10194	Economy	5800.00
0005432394211	10194	Economy	5800.00
0005432396348	10194	Economy	5800.00
0005432400182	18338	Economy	5800.00
0005432396319	18338	Economy	5800.00
0005435179716	18338	Economy	5800.00
0005432396314	18338	Economy	5800.00
0005432396315	18338	Economy	5800.00
0005432400181	18338	Economy	5800.00
0005435179715	18338	Economy	5800.00
0005432400211	18338	Economy	5800.00
0005435179714	18338	Economy	5800.00
0005432400212	18338	Economy	5800.00
0005432396318	18338	Economy	5800.00
0005435626500	11010	Business	9500.00
0005435626461	11010	Business	9500.00
0005435127258	11010	Business	9500.00
0005435556737	11010	Business	9500.00
0005435127168	11010	Business	9500.00
0005435554274	11010	Business	9500.00
0005435626514	11010	Business	9500.00
0005435554277	11010	Business	9500.00
0005435127301	11010	Economy	3200.00
0005435127058	11010	Economy	3200.00
0005435554262	11010	Economy	3200.00
0005435127249	11010	Economy	3200.00
0005435554276	11010	Economy	3200.00
0005435626445	11010	Economy	3200.00
0005435626524	11010	Economy	3200.00
0005435626513	11010	Economy	3200.00
0005435626447	11010	Economy	3500.00
0005435626471	11010	Economy	3500.00
0005435626415	11010	Economy	3500.00
0005435554294	11010	Economy	3200.00
0005435626503	11010	Economy	3200.00
0005435626518	11010	Economy	3200.00
0005435127236	11010	Economy	3200.00
0005434928378	11010	Economy	3200.00
0005435127087	11010	Economy	3200.00
0005435127127	11010	Economy	3200.00
0005435127143	11010	Economy	3200.00
0005435127163	11010	Economy	3200.00
0005435127116	11010	Economy	3200.00
0005435626508	11010	Economy	3200.00
0005435626519	11010	Economy	3200.00
0005435126993	11010	Economy	3200.00
0005435626520	11010	Economy	3200.00
0005435127061	11010	Economy	3200.00
0005435127086	11010	Economy	3200.00
0005435127099	11010	Economy	3200.00
0005435127034	11010	Economy	3200.00
0005435127300	11010	Economy	3200.00
0005435626522	11010	Economy	3200.00
0005435626517	11010	Economy	3200.00
0005435127230	11010	Economy	3200.00
0005435626504	11010	Economy	3200.00
0005435127231	11010	Economy	3200.00
0005435626456	11010	Economy	3200.00
0005435127232	11010	Economy	3200.00
0005435127196	11010	Economy	3200.00
0005435626501	11010	Economy	3200.00
0005435127064	11010	Economy	3200.00
0005435127107	11010	Economy	3200.00
0005435554295	11010	Economy	3200.00
0005435127042	11010	Economy	3200.00
0005435626525	11010	Economy	3200.00
0005435127248	11010	Economy	3200.00
0005435554261	11010	Economy	3200.00
0005435127154	11010	Economy	3200.00
0005435626455	11010	Economy	3200.00
0005435626521	11010	Economy	3200.00
0005435127126	11010	Economy	3200.00
0005435126992	11010	Economy	3200.00
0005435626510	11010	Economy	3200.00
0005435127056	11010	Economy	3200.00
0005435126994	11010	Economy	3200.00
0005435626509	11010	Economy	3200.00
0005435127035	11010	Economy	3200.00
0005435626446	11010	Economy	3200.00
0005435127065	11010	Economy	3200.00
0005435127162	11010	Economy	3200.00
0005435626722	14773	Business	9500.00
0005435626713	14773	Business	9500.00
0005435127474	14773	Business	9500.00
0005435626703	14773	Business	9500.00
0005435127499	14773	Business	9500.00
0005434411870	14773	Business	9500.00
0005435127501	14773	Business	9500.00
0005435626723	14773	Business	9500.00
0005435127479	14773	Business	9500.00
0005435127490	14773	Business	9500.00
0005435626720	14773	Business	9500.00
0005434411864	14773	Economy	3200.00
0005435626702	14773	Economy	3200.00
0005435626708	14773	Economy	3200.00
0005434411869	14773	Economy	3200.00
0005435626706	14773	Economy	3200.00
0005435626705	14773	Economy	3200.00
0005435127485	14773	Economy	3200.00
0005435554315	14773	Economy	3200.00
0005435626699	14773	Economy	3500.00
0005435127497	14773	Economy	3500.00
0005435626721	14773	Economy	3500.00
0005435127469	14773	Economy	3200.00
0005435626692	14773	Economy	3200.00
0005435127487	14773	Economy	3200.00
0005435127478	14773	Economy	3200.00
0005435626698	14773	Economy	3200.00
0005435626710	14773	Economy	3200.00
0005435626696	14773	Economy	3200.00
0005435626693	14773	Economy	3200.00
0005435127483	14773	Economy	3200.00
0005435127493	14773	Economy	3200.00
0005435127477	14773	Economy	3200.00
0005435127486	14773	Economy	3200.00
0005435626707	14773	Economy	3200.00
0005435127495	14773	Economy	3200.00
0005435626715	14773	Economy	3200.00
0005435127489	14773	Economy	3200.00
0005435626691	14773	Economy	3200.00
0005435626694	14773	Economy	3200.00
0005435127482	14773	Economy	3200.00
0005435556761	14773	Economy	3200.00
0005435127492	14773	Economy	3200.00
0005435626701	14773	Economy	3200.00
0005434411843	14773	Economy	3200.00
0005435626695	14773	Economy	3200.00
0005435127488	14773	Economy	3200.00
0005435626709	14773	Economy	3200.00
0005435127475	14773	Economy	3200.00
0005435626704	14773	Economy	3200.00
0005435626717	14773	Economy	3200.00
0005435556762	14773	Economy	3200.00
0005435127498	14773	Economy	3200.00
0005435626697	14773	Economy	3200.00
0005435127491	14773	Economy	3200.00
0005435127472	14773	Economy	3200.00
0005435127484	14773	Economy	3200.00
0005435127481	14773	Economy	3200.00
0005435127480	14773	Economy	3200.00
0005435127494	14773	Economy	3200.00
0005435626716	14773	Economy	3200.00
0005435626724	14773	Economy	3200.00
0005435626700	14773	Economy	3200.00
0005435127476	14773	Economy	3200.00
0005435626718	14773	Economy	3200.00
0005435626690	14773	Economy	3200.00
0005435127468	14773	Economy	3200.00
0005435626719	14773	Economy	3200.00
0005435127496	14773	Economy	3200.00
0005435127473	14773	Economy	3200.00
0005435127500	14773	Economy	3200.00
0005435626712	14773	Economy	3200.00
0005434928350	14773	Economy	3200.00
0005435554314	14773	Economy	3200.00
0005435127471	14773	Economy	3200.00
0005434411858	14773	Economy	3200.00
0005435626711	14773	Economy	3200.00
0005435127470	14773	Economy	3200.00
0005435626714	14773	Economy	3200.00
0005435715932	7140	Business	86900.00
0005435715937	7140	Business	86900.00
0005435221067	7140	Business	86900.00
0005435216629	7140	Economy	29000.00
0005435715942	7140	Economy	31900.00
0005435216624	7140	Economy	31900.00
0005435443463	7140	Economy	29000.00
0005432400219	7140	Economy	29000.00
0005435179410	7140	Economy	29000.00
0005435715929	7140	Economy	29000.00
0005435715944	7140	Economy	29000.00
0005435443505	7140	Economy	29000.00
0005435443467	7140	Economy	29000.00
0005432398294	7140	Economy	29000.00
0005435715935	7140	Economy	29000.00
0005435715931	7140	Economy	29000.00
0005432400218	7140	Economy	29000.00
0005435715934	7140	Economy	29000.00
0005435219237	7140	Economy	29000.00
0005435715939	7140	Economy	29000.00
0005435443506	7140	Economy	29000.00
0005435715940	7140	Economy	29000.00
0005435715930	7140	Economy	29000.00
0005432398295	7140	Economy	29000.00
0005432398296	7140	Economy	29000.00
0005435443487	7140	Economy	29000.00
0005435179411	7140	Economy	29000.00
0005435179406	7140	Economy	29000.00
0005435443482	7140	Economy	29000.00
0005435178528	7140	Economy	29000.00
0005435715941	7140	Economy	29000.00
0005435715933	7140	Economy	29000.00
0005435443464	7140	Economy	29000.00
0005435715936	7140	Economy	29000.00
0005435715943	7140	Economy	29000.00
0005435219245	7140	Economy	29000.00
0005435443484	7140	Economy	29000.00
0005435216630	7140	Economy	29000.00
0005435715938	7140	Economy	29000.00
0005432400217	7140	Economy	29000.00
0005435179018	27052	Business	86900.00
0005432398269	27052	Business	86900.00
0005435715778	27052	Business	86900.00
0005435715862	27052	Economy	29000.00
0005435443572	27052	Economy	29000.00
0005435178537	27052	Economy	29000.00
0005435715796	27052	Economy	29000.00
0005435443570	27052	Economy	29000.00
0005435443568	27052	Economy	29000.00
0005435443573	27052	Economy	29000.00
0005435715797	27052	Economy	29000.00
0005435715720	27052	Economy	29000.00
0005435715810	27052	Economy	29000.00
0005432398260	27052	Economy	29000.00
0005435715864	27052	Economy	29000.00
0005432398266	27052	Economy	29000.00
0005435715863	27052	Economy	29000.00
0005435715807	27052	Economy	29000.00
0005435715737	27052	Economy	29000.00
0005435443571	27052	Economy	29000.00
0005435715765	27052	Economy	29000.00
0005435443574	27052	Economy	29000.00
0005435443567	27052	Economy	29000.00
0005435715759	27052	Economy	29000.00
0005435179017	27052	Economy	29000.00
0005435178536	27052	Economy	29000.00
0005435443569	27052	Economy	29000.00
0005435715787	27052	Economy	29000.00
0005435715740	27052	Economy	29000.00
0005435715789	27052	Economy	29000.00
0005435715822	27052	Economy	29000.00
0005432398270	27052	Economy	29000.00
0005434085057	2721	Economy	7700.00
0005434085058	2721	Economy	7700.00
0005434085056	2721	Economy	7700.00
0005433060460	2721	Economy	7700.00
0005433060486	28477	Economy	7700.00
0005434085008	28477	Economy	7700.00
0005434085026	28477	Economy	7700.00
0005434085006	28477	Economy	7700.00
0005433060487	28477	Economy	7700.00
0005435541382	11385	Business	20200.00
0005435541454	11385	Business	20200.00
0005435541501	11385	Business	20200.00
0005435518237	11385	Business	20200.00
0005435518313	11385	Business	20200.00
0005435541388	11385	Business	20200.00
0005435541438	11385	Economy	6700.00
0005435541503	11385	Economy	6700.00
0005435518283	11385	Economy	6700.00
0005435541441	11385	Economy	6700.00
0005435541513	11385	Economy	6700.00
0005435518227	11385	Economy	7400.00
0005435518198	11385	Economy	6700.00
0005435518293	11385	Economy	6700.00
0005435518256	11385	Economy	6700.00
0005435518276	11385	Economy	6700.00
0005435518330	11385	Economy	6700.00
0005435541389	11385	Economy	6700.00
0005435518275	11385	Economy	6700.00
0005435541515	11385	Economy	6700.00
0005435541365	11385	Economy	6700.00
0005435518349	11385	Economy	6700.00
0005435518255	11385	Economy	6700.00
0005435518263	11385	Economy	6700.00
0005435541500	11385	Economy	6700.00
0005435518322	11385	Economy	6700.00
0005435541366	11385	Economy	6700.00
0005435518226	11385	Economy	6700.00
0005435541499	11385	Economy	6700.00
0005435541411	11385	Economy	6700.00
0005435518253	11385	Economy	6700.00
0005435518350	11385	Economy	6700.00
0005435541539	11385	Economy	6700.00
0005435518331	11385	Economy	6700.00
0005435518361	11385	Economy	6700.00
0005435541394	11385	Economy	6700.00
0005435518248	11385	Economy	6700.00
0005435541412	11385	Economy	6700.00
0005435541514	11385	Economy	6700.00
0005435518277	11385	Economy	6700.00
0005435518184	11385	Economy	6700.00
0005435518239	11385	Economy	6700.00
0005435518238	11385	Economy	6700.00
0005435529830	22260	Business	20200.00
0005435541581	22260	Business	20200.00
0005435530130	22260	Business	20200.00
0005435541590	22260	Business	20200.00
0005435541584	22260	Business	20200.00
0005432294551	22260	Business	20200.00
0005435529839	22260	Business	20200.00
0005435529845	22260	Economy	6700.00
0005435530123	22260	Economy	6700.00
0005435541589	22260	Economy	6700.00
0005435530127	22260	Economy	6700.00
0005435530119	22260	Economy	6700.00
0005435541585	22260	Economy	7400.00
0005435529833	22260	Economy	7400.00
0005435530131	22260	Economy	7400.00
0005435530133	22260	Economy	7400.00
0005435541586	22260	Economy	7400.00
0005435530135	22260	Economy	6700.00
0005435530134	22260	Economy	6700.00
0005435541575	22260	Economy	6700.00
0005435541582	22260	Economy	6700.00
0005435529836	22260	Economy	6700.00
0005435530132	22260	Economy	6700.00
0005435541587	22260	Economy	6700.00
0005435530124	22260	Economy	6700.00
0005435529829	22260	Economy	6700.00
0005435530137	22260	Economy	6700.00
0005435530121	22260	Economy	6700.00
0005435541578	22260	Economy	6700.00
0005435530122	22260	Economy	6700.00
0005435541579	22260	Economy	6700.00
0005435541576	22260	Economy	6700.00
0005435529841	22260	Economy	6700.00
0005435529842	22260	Economy	6700.00
0005435541580	22260	Economy	6700.00
0005435530125	22260	Economy	6700.00
0005435529831	22260	Economy	6700.00
0005435541583	22260	Economy	6700.00
0005435530136	22260	Economy	6700.00
0005435541577	22260	Economy	6700.00
0005435530139	22260	Economy	6700.00
0005435529837	22260	Economy	6700.00
0005435530120	22260	Economy	6700.00
0005435541591	22260	Economy	6700.00
0005435529828	22260	Economy	6700.00
0005435541573	22260	Economy	6700.00
0005432294552	22260	Economy	6700.00
0005435529832	22260	Economy	6700.00
0005435529840	22260	Economy	6700.00
0005435541574	22260	Economy	6700.00
0005435530128	22260	Economy	6700.00
0005435529834	22260	Economy	6700.00
0005435529844	22260	Economy	6700.00
0005435529838	22260	Economy	6700.00
0005435529835	22260	Economy	6700.00
0005435530126	22260	Economy	6700.00
0005435530138	22260	Economy	6700.00
0005435529843	22260	Economy	6700.00
0005435530129	22260	Economy	6700.00
0005435541588	22260	Economy	6700.00
0005434908762	2260	Business	20200.00
0005434908779	2260	Business	20200.00
0005433252116	2260	Business	20200.00
0005435787460	2260	Business	20200.00
0005433252115	2260	Business	20200.00
0005434908768	2260	Business	20200.00
0005435787464	2260	Business	20200.00
0005433252157	2260	Business	20200.00
0005433252089	2260	Business	20200.00
0005434908767	2260	Economy	6700.00
0005434908753	2260	Economy	6700.00
0005433252154	2260	Economy	6700.00
0005434908748	2260	Economy	6700.00
0005434908758	2260	Economy	6700.00
0005434908763	2260	Economy	6700.00
0005434908738	2260	Economy	6700.00
0005434908737	2260	Economy	6700.00
0005434908750	2260	Economy	6700.00
0005434908769	2260	Economy	7400.00
0005433252151	2260	Economy	7400.00
0005433252076	2260	Economy	7400.00
0005433252158	2260	Economy	7400.00
0005433251971	2260	Economy	7400.00
0005434908745	2260	Economy	6700.00
0005434908747	2260	Economy	6700.00
0005434908760	2260	Economy	6700.00
0005434908736	2260	Economy	6700.00
0005434908751	2260	Economy	6700.00
0005434908765	2260	Economy	6700.00
0005433252004	2260	Economy	6700.00
0005434908778	2260	Economy	6700.00
0005433252156	2260	Economy	6700.00
0005433252168	2260	Economy	6700.00
0005434908761	2260	Economy	6700.00
0005433252152	2260	Economy	6700.00
0005433252155	2260	Economy	6700.00
0005434908749	2260	Economy	6700.00
0005434908766	2260	Economy	6700.00
0005434908739	2260	Economy	6700.00
0005434908741	2260	Economy	6700.00
0005433252122	2260	Economy	6700.00
0005434908743	2260	Economy	6700.00
0005434908757	2260	Economy	6700.00
0005433252045	2260	Economy	6700.00
0005434908773	2260	Economy	6700.00
0005433252124	2260	Economy	6700.00
0005433252166	2260	Economy	6700.00
0005434908775	2260	Economy	6700.00
0005433252123	2260	Economy	6700.00
0005434908740	2260	Economy	6700.00
0005435787462	2260	Economy	6700.00
0005434908771	2260	Economy	6700.00
0005433252161	2260	Economy	6700.00
0005434908772	2260	Economy	6700.00
0005434908744	2260	Economy	6700.00
0005434908777	2260	Economy	6700.00
0005433401036	2260	Economy	6700.00
0005433252201	2260	Economy	6700.00
0005435787463	2260	Economy	6700.00
0005433252017	2260	Economy	6700.00
0005433252035	2260	Economy	6700.00
0005434908764	2260	Economy	6700.00
0005434908754	2260	Economy	6700.00
0005434908774	2260	Economy	6700.00
0005435787461	2260	Economy	6700.00
0005434908742	2260	Economy	6700.00
0005434908746	2260	Economy	6700.00
0005434908776	2260	Economy	6700.00
0005434908755	2260	Economy	6700.00
0005434908752	2260	Economy	6700.00
0005433252091	2260	Economy	6700.00
0005434908756	2260	Economy	6700.00
0005433252024	2260	Economy	6700.00
0005434908759	2260	Economy	6700.00
0005434908735	2260	Economy	6700.00
0005434908770	2260	Economy	6700.00
0005433252090	2260	Economy	6700.00
0005433252032	2260	Economy	6700.00
0005434908298	25584	Business	20200.00
0005434908162	25584	Business	20200.00
0005434908270	25584	Business	20200.00
0005433252319	25584	Business	20200.00
0005434907900	25584	Business	20200.00
0005434908186	25584	Business	20200.00
0005433252325	25584	Business	20200.00
0005434908293	25584	Business	20200.00
0005433401067	25584	Business	20200.00
0005433252328	25584	Business	20200.00
0005434908164	25584	Business	20200.00
0005434908161	25584	Economy	6700.00
0005434908294	25584	Economy	6700.00
0005434908193	25584	Economy	6700.00
0005434908441	25584	Economy	6700.00
0005433252329	25584	Economy	6700.00
0005434908002	25584	Economy	6700.00
0005434908332	25584	Economy	6700.00
0005434908274	25584	Economy	6700.00
0005434908147	25584	Economy	7400.00
0005434908139	25584	Economy	7400.00
0005434908362	25584	Economy	7400.00
0005434908196	25584	Economy	7400.00
0005434908371	25584	Economy	7400.00
0005434908361	25584	Economy	6700.00
0005434908137	25584	Economy	6700.00
0005434908320	25584	Economy	6700.00
0005434908204	25584	Economy	6700.00
0005434908167	25584	Economy	6700.00
0005434908316	25584	Economy	6700.00
0005434908366	25584	Economy	6700.00
0005434907970	25584	Economy	6700.00
0005433252318	25584	Economy	6700.00
0005433252326	25584	Economy	6700.00
0005434907899	25584	Economy	6700.00
0005434908223	25584	Economy	6700.00
0005434908422	25584	Economy	6700.00
0005433252316	25584	Economy	6700.00
0005434908392	25584	Economy	6700.00
0005434908163	25584	Economy	6700.00
0005434908241	25584	Economy	6700.00
0005434908176	25584	Economy	6700.00
0005433252314	25584	Economy	6700.00
0005434908331	25584	Economy	6700.00
0005433252327	25584	Economy	6700.00
0005434908388	25584	Economy	6700.00
0005434908278	25584	Economy	6700.00
0005434908275	25584	Economy	6700.00
0005434908205	25584	Economy	6700.00
0005434908138	25584	Economy	6700.00
0005434908195	25584	Economy	6700.00
0005433252324	25584	Economy	6700.00
0005433252315	25584	Economy	6700.00
0005433252321	25584	Economy	6700.00
0005434908321	25584	Economy	6700.00
0005434908171	25584	Economy	6700.00
0005434908339	25584	Economy	6700.00
0005434908386	25584	Economy	6700.00
0005434908175	25584	Economy	6700.00
0005434908240	25584	Economy	6700.00
0005434908330	25584	Economy	6700.00
0005434908168	25584	Economy	6700.00
0005433401066	25584	Economy	6700.00
0005433252317	25584	Economy	6700.00
0005434908265	25584	Economy	6700.00
0005434908074	25584	Economy	6700.00
0005434908250	25584	Economy	6700.00
0005433252322	25584	Economy	6700.00
0005434908198	25584	Economy	6700.00
0005434908341	25584	Economy	6700.00
0005434908194	25584	Economy	6700.00
0005434907898	25584	Economy	6700.00
0005434908095	25584	Economy	6700.00
0005434908269	25584	Economy	6700.00
0005434908380	25584	Economy	6700.00
0005433252323	25584	Economy	6700.00
0005434908370	25584	Economy	6700.00
0005433252320	25584	Economy	6700.00
0005433252313	25584	Economy	6700.00
0005434908338	25584	Economy	6700.00
0005434908387	25584	Economy	6700.00
0005434908169	25584	Economy	6700.00
0005434908242	25584	Economy	6700.00
0005434908136	25584	Economy	6700.00
0005434908295	25584	Economy	6700.00
0005434908187	25584	Economy	6700.00
0005434908346	25584	Economy	6700.00
0005434908197	25584	Economy	6700.00
0005434908271	25584	Economy	6700.00
0005432621431	2531	Economy	13600.00
0005432621432	2531	Economy	13600.00
0005432621429	2531	Economy	12400.00
0005432621427	2531	Economy	12400.00
0005432862479	2531	Economy	12400.00
0005432621422	2531	Economy	12400.00
0005432621424	2531	Economy	12400.00
0005432621423	2531	Economy	12400.00
0005432621430	2531	Economy	12400.00
0005432621425	2531	Economy	12400.00
0005432862473	2531	Economy	12400.00
0005432862445	2531	Economy	12400.00
0005432621426	2531	Economy	12400.00
0005432621428	2531	Economy	12400.00
0005432862474	2531	Economy	12400.00
0005432621273	28030	Economy	12400.00
0005432621288	28030	Economy	12400.00
0005432621308	28030	Economy	12400.00
0005432862513	28030	Economy	12400.00
0005432862517	28030	Economy	12400.00
0005432862514	28030	Economy	12400.00
0005432862515	28030	Economy	12400.00
0005432621274	28030	Economy	12400.00
0005432862518	28030	Economy	12400.00
0005432621272	28030	Economy	12400.00
0005432621376	28030	Economy	12400.00
0005432862516	28030	Economy	12400.00
0005434097510	13086	Economy	11300.00
0005433452792	31055	Economy	8400.00
0005433452793	31055	Economy	8400.00
0005433451673	31055	Economy	8400.00
0005433454914	31361	Economy	8400.00
0005433454915	31361	Economy	8400.00
0005433454913	31361	Economy	8400.00
0005433452774	31361	Economy	8400.00
0005433452778	31361	Economy	8400.00
0005433452779	31361	Economy	8400.00
0005433134225	11986	Economy	7200.00
0005434142677	11986	Economy	7200.00
0005434142685	11986	Economy	7200.00
0005434142674	11986	Economy	6600.00
0005434142684	11986	Economy	6600.00
0005434326058	11986	Economy	6600.00
0005434326057	11986	Economy	6600.00
0005433134213	11986	Economy	6600.00
0005434142683	11986	Economy	6600.00
0005434142695	11986	Economy	6600.00
0005434142694	11986	Economy	6600.00
0005433134214	11986	Economy	6600.00
0005433129349	11986	Economy	6600.00
0005433129358	11986	Economy	6600.00
0005433129348	11986	Economy	6600.00
0005434326059	11986	Economy	6600.00
0005434142680	11986	Economy	6600.00
0005434142696	11986	Economy	6600.00
0005434142718	29810	Economy	7200.00
0005434326281	29810	Economy	6600.00
0005434142715	29810	Economy	6600.00
0005434142717	29810	Economy	6600.00
0005434183636	29810	Economy	6600.00
0005434142716	29810	Economy	6600.00
0005434183637	29810	Economy	6600.00
0005434183635	29810	Economy	6600.00
0005433134257	29810	Economy	6600.00
0005434326279	29810	Economy	6600.00
0005433131831	29810	Economy	6600.00
0005434184722	29810	Economy	6600.00
0005434326278	29810	Economy	6600.00
0005433134258	29810	Economy	6600.00
0005434184721	29810	Economy	6600.00
0005435698088	16474	Economy	19900.00
0005435698081	16474	Economy	19900.00
0005435698079	16474	Economy	18100.00
0005435698096	16474	Economy	18100.00
0005435935089	16474	Economy	18100.00
0005435698083	16474	Economy	18100.00
0005435698090	16474	Economy	18100.00
0005435698093	16474	Economy	18100.00
0005435698086	16474	Economy	18100.00
0005435698098	16474	Economy	18100.00
0005435698099	16474	Economy	18100.00
0005435698075	16474	Economy	18100.00
0005435698084	16474	Economy	18100.00
0005435698097	16474	Economy	18100.00
0005435698078	16474	Economy	18100.00
0005435698087	16474	Economy	18100.00
0005435698095	16474	Economy	18100.00
0005435935090	16474	Economy	18100.00
0005435698077	16474	Economy	18100.00
0005435698092	16474	Economy	18100.00
0005435698080	16474	Economy	18100.00
0005435935095	16474	Economy	18100.00
0005435698076	16474	Economy	18100.00
0005435698091	16474	Economy	18100.00
0005435698085	16474	Economy	18100.00
0005435698073	16474	Economy	18100.00
0005435698094	16474	Economy	18100.00
0005435698074	16474	Economy	18100.00
0005435935120	16474	Economy	18100.00
0005435698082	16474	Economy	18100.00
0005435935119	16474	Economy	18100.00
0005435698089	16474	Economy	18100.00
0005435935088	16474	Economy	18100.00
0005435697897	24702	Economy	19900.00
0005435697817	24702	Economy	19900.00
0005435697974	24702	Economy	19900.00
0005435697860	24702	Economy	19900.00
0005435697833	24702	Economy	18100.00
0005435697956	24702	Economy	18100.00
0005435697846	24702	Economy	18100.00
0005435697862	24702	Economy	18100.00
0005435697797	24702	Economy	18100.00
0005435697876	24702	Economy	18100.00
0005435697916	24702	Economy	18100.00
0005435697842	24702	Economy	18100.00
0005435697859	24702	Economy	18100.00
0005435697879	24702	Economy	18100.00
0005435697894	24702	Economy	18100.00
0005435697875	24702	Economy	18100.00
0005435697877	24702	Economy	18100.00
0005435697850	24702	Economy	18100.00
0005435697835	24702	Economy	18100.00
0005435933582	24702	Economy	18100.00
0005435697770	24702	Economy	18100.00
0005435697969	24702	Economy	18100.00
0005435697951	24702	Economy	18100.00
0005435697851	24702	Economy	18100.00
0005435697745	24702	Economy	18100.00
0005435697834	24702	Economy	18100.00
0005435697815	24702	Economy	18100.00
0005435697768	24702	Economy	18100.00
0005435697980	24702	Economy	18100.00
0005435697771	24702	Economy	18100.00
0005435697917	24702	Economy	18100.00
0005435933584	24702	Economy	18100.00
0005435935130	24702	Economy	18100.00
0005435935131	24702	Economy	18100.00
0005435698044	24702	Economy	18100.00
0005435697847	24702	Economy	18100.00
0005435697938	24702	Economy	18100.00
0005435933583	24702	Economy	18100.00
0005435697849	24702	Economy	18100.00
0005433724925	18791	Economy	4400.00
0005432968880	18791	Economy	4400.00
0005432968872	18791	Economy	4400.00
0005433724926	18791	Economy	4400.00
0005433724927	18791	Economy	4400.00
0005433724903	21612	Economy	4400.00
0005433724888	21612	Economy	4400.00
0005433724906	21612	Economy	4400.00
0005433724902	21612	Economy	4400.00
0005433724897	21612	Economy	4400.00
0005433724889	21612	Economy	4400.00
0005433724898	21612	Economy	4400.00
0005434140379	7307	Business	23100.00
0005434140431	7307	Business	23100.00
0005434140412	7307	Business	23100.00
0005434140441	7307	Business	23100.00
0005434140381	7307	Business	23100.00
0005434140448	7307	Business	23100.00
0005434140380	7307	Business	23100.00
0005434140417	7307	Business	23100.00
0005434140418	7307	Business	23100.00
0005434140396	7307	Business	23100.00
0005434140397	7307	Economy	7700.00
0005434140444	7307	Economy	7700.00
0005434140421	7307	Economy	7700.00
0005434140424	7307	Economy	7700.00
0005434140398	7307	Economy	7700.00
0005434140382	7307	Economy	7700.00
0005434140393	7307	Economy	7700.00
0005434140447	7307	Economy	7700.00
0005434140451	7307	Economy	7700.00
0005434087647	7307	Economy	7700.00
0005434140408	7307	Economy	8500.00
0005434140433	7307	Economy	8500.00
0005434140439	7307	Economy	8500.00
0005434140377	7307	Economy	8500.00
0005434140404	7307	Economy	7700.00
0005434140403	7307	Economy	7700.00
0005434140442	7307	Economy	7700.00
0005434140452	7307	Economy	7700.00
0005434140378	7307	Economy	7700.00
0005434140406	7307	Economy	7700.00
0005434140415	7307	Economy	7700.00
0005434140392	7307	Economy	7700.00
0005434140411	7307	Economy	7700.00
0005434140445	7307	Economy	7700.00
0005434140440	7307	Economy	7700.00
0005434087645	7307	Economy	7700.00
0005434140434	7307	Economy	7700.00
0005434140407	7307	Economy	7700.00
0005434140389	7307	Economy	7700.00
0005434140409	7307	Economy	7700.00
0005434140435	7307	Economy	7700.00
0005434140413	7307	Economy	7700.00
0005434140425	7307	Economy	7700.00
0005434140423	7307	Economy	7700.00
0005434140414	7307	Economy	7700.00
0005435283567	7307	Economy	7700.00
0005434140437	7307	Economy	7700.00
0005434140391	7307	Economy	7700.00
0005434140443	7307	Economy	7700.00
0005434140436	7307	Economy	7700.00
0005434140401	7307	Economy	7700.00
0005434140427	7307	Economy	7700.00
0005434140450	7307	Economy	7700.00
0005434140446	7307	Economy	7700.00
0005434140386	7307	Economy	7700.00
0005434140384	7307	Economy	7700.00
0005434140399	7307	Economy	7700.00
0005434140383	7307	Economy	7700.00
0005434140428	7307	Economy	7700.00
0005434140422	7307	Economy	7700.00
0005434140388	7307	Economy	7700.00
0005434140376	7307	Economy	7700.00
0005434140426	7307	Economy	7700.00
0005434140410	7307	Economy	7700.00
0005434140402	7307	Economy	7700.00
0005434140394	7307	Economy	7700.00
0005434140385	7307	Economy	7700.00
0005434140387	7307	Economy	7700.00
0005434140420	7307	Economy	7700.00
0005434140395	7307	Economy	7700.00
0005434140400	7307	Economy	7700.00
0005434140416	7307	Economy	7700.00
0005434140449	7307	Economy	7700.00
0005434140432	7307	Economy	7700.00
0005434140405	7307	Economy	7700.00
0005434087646	7307	Economy	7700.00
0005434140438	7307	Economy	7700.00
0005434140430	7307	Economy	7700.00
0005434140419	7307	Economy	7700.00
0005434140390	7307	Economy	7700.00
0005434140429	7307	Economy	7700.00
0005434139583	28528	Business	23100.00
0005434087588	28528	Business	23100.00
0005434139550	28528	Business	23100.00
0005434139580	28528	Business	23100.00
0005434139486	28528	Business	23100.00
0005434139681	28528	Business	23100.00
0005434087625	28528	Business	23100.00
0005434139651	28528	Business	23100.00
0005434139774	28528	Business	23100.00
0005434139773	28528	Business	23100.00
0005434139531	28528	Economy	7700.00
0005434139149	28528	Economy	7700.00
0005434139679	28528	Economy	7700.00
0005434139551	28528	Economy	7700.00
0005434139606	28528	Economy	7700.00
0005434139380	28528	Economy	7700.00
0005434139485	28528	Economy	7700.00
0005434139756	28528	Economy	8500.00
0005434139736	28528	Economy	8500.00
0005434139564	28528	Economy	8500.00
0005434139585	28528	Economy	8500.00
0005434139452	28528	Economy	8500.00
0005434139451	28528	Economy	7700.00
0005434139708	28528	Economy	7700.00
0005434139582	28528	Economy	7700.00
0005434139421	28528	Economy	7700.00
0005434139435	28528	Economy	7700.00
0005434139379	28528	Economy	7700.00
0005434139481	28528	Economy	7700.00
0005434139584	28528	Economy	7700.00
0005434139561	28528	Economy	7700.00
0005434139682	28528	Economy	7700.00
0005434087597	28528	Economy	7700.00
0005434139745	28528	Economy	7700.00
0005434139145	28528	Economy	7700.00
0005434139597	28528	Economy	7700.00
0005434139688	28528	Economy	7700.00
0005434139475	28528	Economy	7700.00
0005434139512	28528	Economy	7700.00
0005434139581	28528	Economy	7700.00
0005434139482	28528	Economy	7700.00
0005434139707	28528	Economy	7700.00
0005434139517	28528	Economy	7700.00
0005434139757	28528	Economy	7700.00
0005434139565	28528	Economy	7700.00
0005434139455	28528	Economy	7700.00
0005434139769	28528	Economy	7700.00
0005434139487	28528	Economy	7700.00
0005434139709	28528	Economy	7700.00
0005434139765	28528	Economy	7700.00
0005434139676	28528	Economy	7700.00
0005434139405	28528	Economy	7700.00
0005434139534	28528	Economy	7700.00
0005434139677	28528	Economy	7700.00
0005434139635	28528	Economy	7700.00
0005434139562	28528	Economy	7700.00
0005434139744	28528	Economy	7700.00
0005434139799	28528	Economy	7700.00
0005434139605	28528	Economy	7700.00
0005434139458	28528	Economy	7700.00
0005434139533	28528	Economy	7700.00
0005434139807	28528	Economy	7700.00
0005434139566	28528	Economy	7700.00
0005434139772	28528	Economy	7700.00
0005434139742	28528	Economy	7700.00
0005434139798	28528	Economy	7700.00
0005434139391	28528	Economy	7700.00
0005434139735	28528	Economy	7700.00
0005434087598	28528	Economy	7700.00
0005434139625	28528	Economy	7700.00
0005434139800	28528	Economy	7700.00
0005434139740	28528	Economy	7700.00
0005434139417	28528	Economy	7700.00
0005434139689	28528	Economy	7700.00
0005434139604	28528	Economy	7700.00
0005434139743	28528	Economy	7700.00
0005434139649	28528	Economy	7700.00
0005434139668	28528	Economy	7700.00
0005434139617	28528	Economy	7700.00
0005434139739	28528	Economy	7700.00
0005434139643	28528	Economy	7700.00
0005434139825	28528	Economy	7700.00
0005434139480	28528	Economy	7700.00
0005434139618	28528	Economy	7700.00
0005434139558	28528	Economy	7700.00
0005434139764	28528	Economy	7700.00
0005434139556	28528	Economy	7700.00
0005434139806	28528	Economy	7700.00
0005435808507	1908	Economy	23900.00
0005433407657	1908	Economy	21700.00
0005433407642	1908	Economy	21700.00
0005435808508	1908	Economy	21700.00
0005433407641	1908	Economy	21700.00
0005435808510	1908	Economy	21700.00
0005435808502	1908	Economy	21700.00
0005435808506	1908	Economy	21700.00
0005435808504	1908	Economy	21700.00
0005435808505	1908	Economy	21700.00
0005434610331	1908	Economy	21700.00
0005435808509	1908	Economy	21700.00
0005433407658	1908	Economy	21700.00
0005433407659	1908	Economy	21700.00
0005434610329	1908	Economy	21700.00
0005435808503	1908	Economy	21700.00
0005433407666	1908	Economy	21700.00
0005433407660	1908	Economy	21700.00
0005435808511	1908	Economy	21700.00
0005433407656	1908	Economy	21700.00
0005434610330	1908	Economy	21700.00
0005434610273	23116	Economy	21700.00
0005434504890	16696	Economy	7600.00
0005434504781	16696	Economy	7600.00
0005434504925	16696	Economy	7600.00
0005434504785	16696	Economy	7600.00
0005434505031	16696	Economy	6900.00
0005434504969	16696	Economy	6900.00
0005434504756	16696	Economy	6900.00
0005434504966	16696	Economy	6900.00
0005434504863	16696	Economy	6900.00
0005434504779	16696	Economy	6900.00
0005434504809	16696	Economy	6900.00
0005434504920	16696	Economy	6900.00
0005434504835	16696	Economy	6900.00
0005434504877	16696	Economy	6900.00
0005434504891	16696	Economy	6900.00
0005434504701	16696	Economy	6900.00
0005434504801	16696	Economy	6900.00
0005434504757	16696	Economy	6900.00
0005434504758	16696	Economy	6900.00
0005434504902	16696	Economy	6900.00
0005434504948	16696	Economy	6900.00
0005434504918	16696	Economy	6900.00
0005434504965	16696	Economy	6900.00
0005434504837	16696	Economy	6900.00
0005434504888	16696	Economy	6900.00
0005434505008	16696	Economy	6900.00
0005434504728	16696	Economy	6900.00
0005434504786	16696	Economy	6900.00
0005434504947	16696	Economy	6900.00
0005434504900	16696	Economy	6900.00
0005434504901	16696	Economy	6900.00
0005434504876	16696	Economy	6900.00
0005434504970	16696	Economy	6900.00
0005434504607	16696	Economy	6900.00
0005434504934	16696	Economy	6900.00
0005434504915	16696	Economy	6900.00
0005434504867	16696	Economy	6900.00
0005434504808	16696	Economy	6900.00
0005434505195	22901	Economy	7600.00
0005434505221	22901	Economy	7600.00
0005434505203	22901	Economy	6900.00
0005434505188	22901	Economy	6900.00
0005434505218	22901	Economy	6900.00
0005434505206	22901	Economy	6900.00
0005434505205	22901	Economy	6900.00
0005434505215	22901	Economy	6900.00
0005434505220	22901	Economy	6900.00
0005434505211	22901	Economy	6900.00
0005434505187	22901	Economy	6900.00
0005434505219	22901	Economy	6900.00
0005434505212	22901	Economy	6900.00
0005434505217	22901	Economy	6900.00
0005434505197	22901	Economy	6900.00
0005434505191	22901	Economy	6900.00
0005434505210	22901	Economy	6900.00
0005434505202	22901	Economy	6900.00
0005434505194	22901	Economy	6900.00
0005434505189	22901	Economy	6900.00
0005434505192	22901	Economy	6900.00
0005434505213	22901	Economy	6900.00
0005434505201	22901	Economy	6900.00
0005434505198	22901	Economy	6900.00
0005434505214	22901	Economy	6900.00
0005434505208	22901	Economy	6900.00
0005434505193	22901	Economy	6900.00
0005434505190	22901	Economy	6900.00
0005434505209	22901	Economy	6900.00
0005434505204	22901	Economy	6900.00
0005434505207	22901	Economy	6900.00
0005434505200	22901	Economy	6900.00
0005434505196	22901	Economy	6900.00
0005434505216	22901	Economy	6900.00
0005434505222	22901	Economy	6900.00
0005434505199	22901	Economy	6900.00
0005433266872	2195	Economy	7700.00
0005433266874	2195	Economy	7000.00
0005433266894	2195	Economy	7000.00
0005433266901	2195	Economy	7000.00
0005433266875	2195	Economy	7000.00
0005435078760	2195	Economy	7000.00
0005433266912	2195	Economy	7000.00
0005435078758	2195	Economy	7000.00
0005435078755	2195	Economy	7000.00
0005435078763	2195	Economy	7000.00
0005433266902	2195	Economy	7000.00
0005433266876	2195	Economy	7000.00
0005435078764	2195	Economy	7000.00
0005435078759	2195	Economy	7000.00
0005435078757	2195	Economy	7000.00
0005435078762	2195	Economy	7000.00
0005433266913	2195	Economy	7000.00
0005433266873	2195	Economy	7000.00
0005435078765	2195	Economy	7000.00
0005433266837	2195	Economy	7000.00
0005435078766	2195	Economy	7000.00
0005435078761	2195	Economy	7000.00
0005435078756	2195	Economy	7000.00
0005435078608	24342	Economy	7700.00
0005435078548	24342	Economy	7000.00
0005435078630	24342	Economy	7000.00
0005433266978	24342	Economy	7000.00
0005435078636	24342	Economy	7000.00
0005435078632	24342	Economy	7000.00
0005435078613	24342	Economy	7000.00
0005433266976	24342	Economy	7000.00
0005435078651	24342	Economy	7000.00
0005435078631	24342	Economy	7000.00
0005435078689	24342	Economy	7000.00
0005433266975	24342	Economy	7000.00
0005435078658	24342	Economy	7000.00
0005435078711	24342	Economy	7000.00
0005435078589	24342	Economy	7000.00
0005435078609	24342	Economy	7000.00
0005435078611	24342	Economy	7000.00
0005435078650	24342	Economy	7000.00
0005435078661	24342	Economy	7000.00
0005435078708	24342	Economy	7000.00
0005435078607	24342	Economy	7000.00
0005433266979	24342	Economy	7000.00
0005435078646	24342	Economy	7000.00
0005435078637	24342	Economy	7000.00
0005433266980	24342	Economy	7000.00
0005433266977	24342	Economy	7000.00
0005434989054	6622	Economy	10800.00
0005435464542	6622	Economy	10800.00
0005434989051	6622	Economy	10800.00
0005435464549	6622	Economy	9800.00
0005435803343	6622	Economy	9800.00
0005434989048	6622	Economy	9800.00
0005434989055	6622	Economy	9800.00
0005435803344	6622	Economy	9800.00
0005434989053	6622	Economy	9800.00
0005435464548	6622	Economy	9800.00
0005435803345	6622	Economy	9800.00
0005434989059	6622	Economy	9800.00
0005435464543	6622	Economy	9800.00
0005435464551	6622	Economy	9800.00
0005434989049	6622	Economy	9800.00
0005434989056	6622	Economy	9800.00
0005434989050	6622	Economy	9800.00
0005434989058	6622	Economy	9800.00
0005434989052	6622	Economy	9800.00
0005434989057	6622	Economy	9800.00
0005435803327	23586	Economy	9800.00
0005434988872	23586	Economy	9800.00
0005435803297	23586	Economy	9800.00
0005435803326	23586	Economy	9800.00
0005435803315	23586	Economy	9800.00
0005435464562	23586	Economy	9800.00
0005434988873	23586	Economy	9800.00
0005435803325	23586	Economy	9800.00
0005434988874	23586	Economy	9800.00
0005435803319	23586	Economy	9800.00
0005433453818	30461	Business	9900.00
0005433450573	30461	Business	9900.00
0005432384237	30461	Business	9900.00
0005433450568	30461	Business	9900.00
0005432384267	30461	Business	9900.00
0005432384236	30461	Business	9900.00
0005433450565	30461	Business	9900.00
0005432384260	30461	Business	9900.00
0005432384238	30461	Economy	3300.00
0005432384248	30461	Economy	3300.00
0005432384240	30461	Economy	3300.00
0005433450569	30461	Economy	3300.00
0005432384234	30461	Economy	3300.00
0005432384241	30461	Economy	3300.00
0005432384252	30461	Economy	3300.00
0005433450566	30461	Economy	3600.00
0005432384253	30461	Economy	3600.00
0005432384262	30461	Economy	3600.00
0005432384239	30461	Economy	3300.00
0005432384243	30461	Economy	3300.00
0005433450560	30461	Economy	3300.00
0005432384266	30461	Economy	3300.00
0005432384244	30461	Economy	3300.00
0005432384257	30461	Economy	3300.00
0005432384259	30461	Economy	3300.00
0005433450567	30461	Economy	3300.00
0005433450561	30461	Economy	3300.00
0005433450564	30461	Economy	3300.00
0005432384268	30461	Economy	3300.00
0005432384263	30461	Economy	3300.00
0005432384235	30461	Economy	3300.00
0005432384254	30461	Economy	3300.00
0005432384246	30461	Economy	3300.00
0005433450570	30461	Economy	3300.00
0005433450558	30461	Economy	3300.00
0005433450562	30461	Economy	3300.00
0005433450563	30461	Economy	3300.00
0005432384245	30461	Economy	3300.00
0005432384247	30461	Economy	3300.00
0005432384251	30461	Economy	3300.00
0005432384249	30461	Economy	3300.00
0005433450571	30461	Economy	3300.00
0005432384255	30461	Economy	3300.00
0005432384258	30461	Economy	3300.00
0005432384264	30461	Economy	3300.00
0005432384250	30461	Economy	3300.00
0005432384265	30461	Economy	3300.00
0005432384261	30461	Economy	3300.00
0005433450559	30461	Economy	3300.00
0005433450572	30461	Economy	3300.00
0005432384256	30461	Economy	3300.00
0005432384242	30461	Economy	3300.00
0005432383884	31286	Business	9900.00
0005432383798	31286	Business	9900.00
0005432383876	31286	Business	9900.00
0005433450382	31286	Business	9900.00
0005432383725	31286	Business	9900.00
0005432383762	31286	Business	9900.00
0005433450363	31286	Business	9900.00
0005432383910	31286	Business	9900.00
0005433450457	31286	Business	9900.00
0005433453802	31286	Economy	3300.00
0005433450299	31286	Economy	3300.00
0005433450434	31286	Economy	3300.00
0005433450367	31286	Economy	3300.00
0005433450431	31286	Economy	3300.00
0005432383890	31286	Economy	3300.00
0005433451663	31286	Economy	3600.00
0005433450467	31286	Economy	3600.00
0005432383930	31286	Economy	3600.00
0005433450282	31286	Economy	3300.00
0005432383763	31286	Economy	3300.00
0005432383891	31286	Economy	3300.00
0005432383933	31286	Economy	3300.00
0005432383739	31286	Economy	3300.00
0005432383877	31286	Economy	3300.00
0005432383686	31286	Economy	3300.00
0005433450409	31286	Economy	3300.00
0005432383901	31286	Economy	3300.00
0005433450395	31286	Economy	3300.00
0005432383838	31286	Economy	3300.00
0005433450368	31286	Economy	3300.00
0005432383846	31286	Economy	3300.00
0005432383726	31286	Economy	3300.00
0005433450466	31286	Economy	3300.00
0005432383889	31286	Economy	3300.00
0005432383895	31286	Economy	3300.00
0005433450300	31286	Economy	3300.00
0005432383757	31286	Economy	3300.00
0005432383894	31286	Economy	3300.00
0005432383724	31286	Economy	3300.00
0005432383929	31286	Economy	3300.00
0005433450445	31286	Economy	3300.00
0005432383973	31286	Economy	3300.00
0005432383780	31286	Economy	3300.00
0005432383809	31286	Economy	3300.00
0005432383749	31286	Economy	3300.00
0005432383902	31286	Economy	3300.00
0005432383882	31286	Economy	3300.00
0005432383837	31286	Economy	3300.00
0005432383812	31286	Economy	3300.00
0005433450383	31286	Economy	3300.00
0005432383845	31286	Economy	3300.00
0005433450364	31286	Economy	3300.00
0005432383932	31286	Economy	3300.00
0005432383800	31286	Economy	3300.00
0005433450458	31286	Economy	3300.00
0005432383839	31286	Economy	3300.00
0005432383840	31286	Economy	3300.00
0005433450384	31286	Economy	3300.00
0005433453803	31286	Economy	3300.00
0005433450391	31286	Economy	3300.00
0005432383646	31286	Economy	3300.00
0005433450344	31286	Economy	3300.00
0005433450435	31286	Economy	3300.00
0005432383875	31286	Economy	3300.00
0005432383883	31286	Economy	3300.00
0005433450301	31286	Economy	3300.00
0005433450343	31286	Economy	3300.00
0005432383916	31286	Economy	3300.00
0005432383740	31286	Economy	3300.00
0005432383813	31286	Economy	3300.00
0005432383801	31286	Economy	3300.00
0005433450385	31286	Economy	3300.00
0005433450456	31286	Economy	3300.00
0005433788314	20828	Economy	26200.00
0005433788307	20828	Economy	26200.00
0005435548549	20828	Economy	23800.00
0005433788306	20828	Economy	23800.00
0005435548550	20828	Economy	23800.00
0005435548562	20828	Economy	23800.00
0005433788311	20828	Economy	23800.00
0005433788316	20828	Economy	23800.00
0005433788315	20828	Economy	23800.00
0005433788319	20828	Economy	23800.00
0005433788305	20828	Economy	23800.00
0005433788318	20828	Economy	23800.00
0005435548572	20828	Economy	23800.00
0005435548574	20828	Economy	23800.00
0005433788317	20828	Economy	23800.00
0005433788308	20828	Economy	23800.00
0005435548564	20828	Economy	23800.00
0005435548571	20828	Economy	23800.00
0005433788309	20828	Economy	23800.00
0005433788313	20828	Economy	23800.00
0005435548563	20828	Economy	23800.00
0005433788310	20828	Economy	23800.00
0005435548554	20828	Economy	23800.00
0005435548565	20828	Economy	23800.00
0005435548545	20828	Economy	23800.00
0005435548575	20828	Economy	23800.00
0005435548546	20828	Economy	23800.00
0005435548573	20828	Economy	23800.00
0005435548557	20828	Economy	23800.00
0005433788312	20828	Economy	23800.00
0005433788320	20828	Economy	23800.00
0005435548613	26463	Economy	26200.00
0005433788277	26463	Economy	23800.00
0005435548622	26463	Economy	23800.00
0005435548617	26463	Economy	23800.00
0005433788266	26463	Economy	23800.00
0005435548615	26463	Economy	23800.00
0005433788272	26463	Economy	23800.00
0005435548618	26463	Economy	23800.00
0005433788271	26463	Economy	23800.00
0005433788279	26463	Economy	23800.00
0005433788286	26463	Economy	23800.00
0005433788287	26463	Economy	23800.00
0005435548614	26463	Economy	23800.00
0005435548623	26463	Economy	23800.00
0005435548616	26463	Economy	23800.00
0005433788270	26463	Economy	23800.00
0005433788269	26463	Economy	23800.00
0005435548621	26463	Economy	23800.00
0005435548620	26463	Economy	23800.00
0005433788268	26463	Economy	23800.00
0005433788257	26463	Economy	23800.00
0005435548619	26463	Economy	23800.00
0005433788278	26463	Economy	23800.00
0005433788267	26463	Economy	23800.00
0005435548612	26463	Economy	23800.00
0005433131773	10775	Economy	15600.00
0005433131806	10775	Economy	15600.00
0005433131775	10775	Economy	15600.00
0005435299866	10775	Economy	15600.00
0005433126932	10775	Economy	15600.00
0005433126920	10775	Economy	15600.00
0005435299855	10775	Economy	15600.00
0005433131774	10775	Economy	15600.00
0005435299865	10775	Economy	15600.00
0005433131807	10775	Economy	15600.00
0005433131798	10775	Economy	15600.00
0005433126931	10775	Economy	15600.00
0005435304232	10775	Economy	15600.00
0005433126914	10775	Economy	15600.00
0005433126940	10775	Economy	15600.00
0005433126913	10775	Economy	15600.00
0005433126933	10775	Economy	15600.00
0005433126939	10775	Economy	15600.00
0005435299883	10775	Economy	15600.00
0005433131802	10775	Economy	15600.00
0005433126929	10775	Economy	15600.00
0005433131790	10775	Economy	15600.00
0005433126928	10775	Economy	15600.00
0005433131787	10775	Economy	15600.00
0005433129405	29720	Economy	17100.00
0005433126973	29720	Economy	17100.00
0005433126972	29720	Economy	17100.00
0005433129404	29720	Economy	15600.00
0005435302330	29720	Economy	15600.00
0005435302331	29720	Economy	15600.00
0005435299912	29720	Economy	15600.00
0005435302332	29720	Economy	15600.00
0005435302333	29720	Economy	15600.00
0005435302334	29720	Economy	15600.00
0005433129406	29720	Economy	15600.00
0005433129403	29720	Economy	15600.00
0005435299911	29720	Economy	15600.00
0005433129402	29720	Economy	15600.00
0005434287894	2423	Economy	17200.00
0005434287884	2423	Economy	17200.00
0005433110302	2423	Economy	17200.00
0005432264543	2423	Economy	15700.00
0005434287890	2423	Economy	15700.00
0005434287893	2423	Economy	15700.00
0005434287895	2423	Economy	15700.00
0005433110320	2423	Economy	15700.00
0005434287886	2423	Economy	15700.00
0005433110319	2423	Economy	15700.00
0005434287902	2423	Economy	15700.00
0005434287889	2423	Economy	15700.00
0005433110322	2423	Economy	15700.00
0005434287901	2423	Economy	15700.00
0005433110279	2423	Economy	15700.00
0005433110278	2423	Economy	15700.00
0005433110298	2423	Economy	15700.00
0005434287898	2423	Economy	15700.00
0005434287897	2423	Economy	15700.00
0005434287892	2423	Economy	15700.00
0005432264544	2423	Economy	15700.00
0005434287888	2423	Economy	15700.00
0005433110297	2423	Economy	15700.00
0005433110270	2423	Economy	15700.00
0005432264545	2423	Economy	15700.00
0005433110321	2423	Economy	15700.00
0005434287891	2423	Economy	15700.00
0005433110299	2423	Economy	15700.00
0005434287883	2423	Economy	15700.00
0005434287896	2423	Economy	15700.00
0005434287900	2423	Economy	15700.00
0005434287899	2423	Economy	15700.00
0005434287903	2423	Economy	15700.00
0005434287885	2423	Economy	15700.00
0005434287887	2423	Economy	15700.00
0005434287678	26837	Economy	17200.00
0005434287765	26837	Economy	15700.00
0005434287766	26837	Economy	15700.00
0005433110381	26837	Economy	15700.00
0005434287665	26837	Economy	15700.00
0005433110379	26837	Economy	15700.00
0005433110382	26837	Economy	15700.00
0005434287748	26837	Economy	15700.00
0005434287753	26837	Economy	15700.00
0005434287767	26837	Economy	15700.00
0005434287714	26837	Economy	15700.00
0005433110378	26837	Economy	15700.00
0005434287729	26837	Economy	15700.00
0005434287730	26837	Economy	15700.00
0005434287632	26837	Economy	15700.00
0005434287631	26837	Economy	15700.00
0005434287715	26837	Economy	15700.00
0005434287695	26837	Economy	15700.00
0005433110380	26837	Economy	15700.00
0005434287749	26837	Economy	15700.00
0005434287604	26837	Economy	15700.00
0005434287657	26837	Economy	15700.00
0005434287716	26837	Economy	15700.00
0005435856322	25484	Economy	25000.00
0005435856320	25484	Economy	22800.00
0005435856356	25484	Economy	22800.00
0005435856354	25484	Economy	22800.00
0005434272220	25484	Economy	22800.00
0005435856355	25484	Economy	22800.00
0005435856323	25484	Economy	22800.00
0005435856321	25484	Economy	22800.00
0005434272218	25484	Economy	22800.00
0005434272219	25484	Economy	22800.00
0005435856353	25484	Economy	22800.00
0005434273134	26651	Economy	25000.00
0005435856269	26651	Economy	25000.00
0005434272234	26651	Economy	22800.00
0005434273133	26651	Economy	22800.00
0005435856270	26651	Economy	22800.00
0005434273121	26651	Economy	22800.00
0005434273122	26651	Economy	22800.00
0005435856292	26651	Economy	22800.00
0005435314906	6100	Economy	24600.00
0005434520489	6100	Economy	24600.00
0005434520497	6100	Economy	24600.00
0005435314905	6100	Economy	22300.00
0005435314887	6100	Economy	22300.00
0005434520501	6100	Economy	22300.00
0005434520484	6100	Economy	22300.00
0005434520500	6100	Economy	22300.00
0005435314892	6100	Economy	22300.00
0005434520495	6100	Economy	22300.00
0005434520493	6100	Economy	22300.00
0005435314896	6100	Economy	22300.00
0005434520490	6100	Economy	22300.00
0005435314909	6100	Economy	22300.00
0005434520494	6100	Economy	22300.00
0005434520487	6100	Economy	22300.00
0005434520491	6100	Economy	22300.00
0005434520482	6100	Economy	22300.00
0005434520488	6100	Economy	22300.00
0005434520483	6100	Economy	22300.00
0005434520496	6100	Economy	22300.00
0005434520498	6100	Economy	22300.00
0005434520499	6100	Economy	22300.00
0005434520492	6100	Economy	22300.00
0005434520486	6100	Economy	22300.00
0005435314913	6100	Economy	22300.00
0005435314891	6100	Economy	22300.00
0005434520485	6100	Economy	22300.00
0005433651080	7167	Business	89800.00
0005433651036	7167	Business	89800.00
0005435263700	7167	Business	89800.00
0005433651044	7167	Business	89800.00
0005435263736	7167	Business	89800.00
0005433651045	7167	Business	89800.00
0005433651037	7167	Business	89800.00
0005435263755	7167	Business	89800.00
0005435263729	7167	Business	89800.00
0005435263757	7167	Business	89800.00
0005433651031	7167	Business	89800.00
0005433651073	7167	Economy	29900.00
0005433651082	7167	Economy	29900.00
0005433651070	7167	Economy	29900.00
0005433651028	7167	Economy	29900.00
0005433651065	7167	Economy	29900.00
0005433651075	7167	Economy	29900.00
0005433651038	7167	Economy	29900.00
0005433651042	7167	Economy	29900.00
0005433651050	7167	Economy	29900.00
0005435263754	7167	Economy	32900.00
0005433651064	7167	Economy	32900.00
0005433651041	7167	Economy	32900.00
0005433651034	7167	Economy	32900.00
0005435263730	7167	Economy	32900.00
0005433651061	7167	Economy	29900.00
0005435263765	7167	Economy	29900.00
0005433651063	7167	Economy	29900.00
0005435263725	7167	Economy	29900.00
0005433651027	7167	Economy	29900.00
0005435263706	7167	Economy	29900.00
0005433651054	7167	Economy	29900.00
0005435263709	7167	Economy	29900.00
0005433651062	7167	Economy	29900.00
0005433651076	7167	Economy	29900.00
0005433651081	7167	Economy	29900.00
0005433651052	7167	Economy	29900.00
0005433651072	7167	Economy	29900.00
0005433651046	7167	Economy	29900.00
0005433651030	7167	Economy	29900.00
0005433651047	7167	Economy	29900.00
0005433651068	7167	Economy	29900.00
0005433651040	7167	Economy	29900.00
0005433651060	7167	Economy	29900.00
0005435263705	7167	Economy	29900.00
0005435263762	7167	Economy	29900.00
0005433651084	7167	Economy	29900.00
0005433651048	7167	Economy	29900.00
0005433651058	7167	Economy	29900.00
0005433651026	7167	Economy	29900.00
0005433651035	7167	Economy	29900.00
0005433651033	7167	Economy	29900.00
0005433651055	7167	Economy	29900.00
0005435263740	7167	Economy	29900.00
0005435263745	7167	Economy	29900.00
0005433651067	7167	Economy	29900.00
0005433651029	7167	Economy	29900.00
0005433651077	7167	Economy	29900.00
0005433651066	7167	Economy	29900.00
0005435263743	7167	Economy	29900.00
0005435263739	7167	Economy	29900.00
0005433651078	7167	Economy	29900.00
0005435263728	7167	Economy	29900.00
0005433651079	7167	Economy	29900.00
0005435263727	7167	Economy	29900.00
0005433651032	7167	Economy	29900.00
0005433651039	7167	Economy	29900.00
0005435263733	7167	Economy	29900.00
0005433651043	7167	Economy	29900.00
0005435263761	7167	Economy	29900.00
0005433651059	7167	Economy	29900.00
0005433651071	7167	Economy	29900.00
0005433651049	7167	Economy	29900.00
0005433651057	7167	Economy	29900.00
0005433651051	7167	Economy	29900.00
0005433651053	7167	Economy	29900.00
0005435263726	7167	Economy	29900.00
0005433651069	7167	Economy	29900.00
0005435263744	7167	Economy	29900.00
0005435263724	7167	Economy	29900.00
0005435263735	7167	Economy	29900.00
0005433651083	7167	Economy	29900.00
0005435263760	7167	Economy	29900.00
0005433651074	7167	Economy	29900.00
0005435263766	7167	Economy	29900.00
0005435263731	7167	Economy	29900.00
0005435263732	7167	Economy	29900.00
0005435263741	7167	Economy	29900.00
0005433651056	7167	Economy	29900.00
0005435263734	7167	Economy	29900.00
0005433650825	27636	Business	89800.00
0005435263815	27636	Business	89800.00
0005435263812	27636	Business	89800.00
0005433650949	27636	Business	89800.00
0005433650953	27636	Business	89800.00
0005433650912	27636	Business	89800.00
0005435263801	27636	Business	89800.00
0005435263804	27636	Business	89800.00
0005433650890	27636	Economy	29900.00
0005435263811	27636	Economy	29900.00
0005433650914	27636	Economy	29900.00
0005435263803	27636	Economy	29900.00
0005435263823	27636	Economy	29900.00
0005433650969	27636	Economy	29900.00
0005433650896	27636	Economy	29900.00
0005433650867	27636	Economy	29900.00
0005433650826	27636	Economy	32900.00
0005433650950	27636	Economy	32900.00
0005433650900	27636	Economy	32900.00
0005433650827	27636	Economy	29900.00
0005433650976	27636	Economy	29900.00
0005433650892	27636	Economy	29900.00
0005433650891	27636	Economy	29900.00
0005433650927	27636	Economy	29900.00
0005435263802	27636	Economy	29900.00
0005433651004	27636	Economy	29900.00
0005433650915	27636	Economy	29900.00
0005435263810	27636	Economy	29900.00
0005433650932	27636	Economy	29900.00
0005435263822	27636	Economy	29900.00
0005433650929	27636	Economy	29900.00
0005433650828	27636	Economy	29900.00
0005435263805	27636	Economy	29900.00
0005433650899	27636	Economy	29900.00
0005433650942	27636	Economy	29900.00
0005435263807	27636	Economy	29900.00
0005435263817	27636	Economy	29900.00
0005433650937	27636	Economy	29900.00
0005433650928	27636	Economy	29900.00
0005433650889	27636	Economy	29900.00
0005435263813	27636	Economy	29900.00
0005433651003	27636	Economy	29900.00
0005433650819	27636	Economy	29900.00
0005435263806	27636	Economy	29900.00
0005435263820	27636	Economy	29900.00
0005435263816	27636	Economy	29900.00
0005433650933	27636	Economy	29900.00
0005433650959	27636	Economy	29900.00
0005433650939	27636	Economy	29900.00
0005433650926	27636	Economy	29900.00
0005433650952	27636	Economy	29900.00
0005433650934	27636	Economy	29900.00
0005435263819	27636	Economy	29900.00
0005435263814	27636	Economy	29900.00
0005435263809	27636	Economy	29900.00
0005433650874	27636	Economy	29900.00
0005433651007	27636	Economy	29900.00
0005433650938	27636	Economy	29900.00
0005433650820	27636	Economy	29900.00
0005433650913	27636	Economy	29900.00
0005435263818	27636	Economy	29900.00
0005433650866	27636	Economy	29900.00
0005433650910	27636	Economy	29900.00
0005433650868	27636	Economy	29900.00
0005433650911	27636	Economy	29900.00
0005433650887	27636	Economy	29900.00
0005435263808	27636	Economy	29900.00
0005435263821	27636	Economy	29900.00
0005435860544	4783	Economy	19400.00
0005433869534	4783	Economy	19400.00
0005435860562	4783	Economy	19400.00
0005433869547	4783	Economy	19400.00
0005433869530	4783	Economy	17600.00
0005433869539	4783	Economy	17600.00
0005433869549	4783	Economy	17600.00
0005433869543	4783	Economy	17600.00
0005433869537	4783	Economy	17600.00
0005433869535	4783	Economy	17600.00
0005433869523	4783	Economy	17600.00
0005433869548	4783	Economy	17600.00
0005433869525	4783	Economy	17600.00
0005433869529	4783	Economy	17600.00
0005433869533	4783	Economy	17600.00
0005433869545	4783	Economy	17600.00
0005433869541	4783	Economy	17600.00
0005433869532	4783	Economy	17600.00
0005433869540	4783	Economy	17600.00
0005433869524	4783	Economy	17600.00
0005433869538	4783	Economy	17600.00
0005433869531	4783	Economy	17600.00
0005433869526	4783	Economy	17600.00
0005435860567	4783	Economy	17600.00
0005433869527	4783	Economy	17600.00
0005433869542	4783	Economy	17600.00
0005433869528	4783	Economy	17600.00
0005433869546	4783	Economy	17600.00
0005433869536	4783	Economy	17600.00
0005433869544	4783	Economy	17600.00
0005435860556	4783	Economy	17600.00
0005435860530	4783	Economy	17600.00
0005435860612	32607	Economy	19400.00
0005433869254	32607	Economy	19400.00
0005433869003	32607	Economy	19400.00
0005435860604	32607	Economy	19400.00
0005433869078	32607	Economy	17600.00
0005433869048	32607	Economy	17600.00
0005433869110	32607	Economy	17600.00
0005433869166	32607	Economy	17600.00
0005433869169	32607	Economy	17600.00
0005435860611	32607	Economy	17600.00
0005433869226	32607	Economy	17600.00
0005433869239	32607	Economy	17600.00
0005435860613	32607	Economy	17600.00
0005433869283	32607	Economy	17600.00
0005433869100	32607	Economy	17600.00
0005433869134	32607	Economy	17600.00
0005433869223	32607	Economy	17600.00
0005435860606	32607	Economy	17600.00
0005433869083	32607	Economy	17600.00
0005433869242	32607	Economy	17600.00
0005433869133	32607	Economy	17600.00
0005433869130	32607	Economy	17600.00
0005433869168	32607	Economy	17600.00
0005435860605	32607	Economy	17600.00
0005433869241	32607	Economy	17600.00
0005433869167	32607	Economy	17600.00
0005433869243	32607	Economy	17600.00
0005433869188	32607	Economy	17600.00
0005433869238	32607	Economy	17600.00
0005433869235	32607	Economy	17600.00
0005433869124	32607	Economy	17600.00
0005433869131	32607	Economy	17600.00
0005433869187	32607	Economy	17600.00
0005433869302	32607	Economy	17600.00
0005433869203	32607	Economy	17600.00
0005433869101	32607	Economy	17600.00
0005433869189	32607	Economy	17600.00
0005435860607	32607	Economy	17600.00
0005435860610	32607	Economy	17600.00
0005435860609	32607	Economy	17600.00
0005433869084	32607	Economy	17600.00
0005433869348	32607	Economy	17600.00
0005433869179	32607	Economy	17600.00
0005433869118	32607	Economy	17600.00
0005433869132	32607	Economy	17600.00
0005435860614	32607	Economy	17600.00
0005433869184	32607	Economy	17600.00
0005435860608	32607	Economy	17600.00
0005433869204	32607	Economy	17600.00
0005433869212	32607	Economy	17600.00
0005435911592	3455	Economy	24800.00
0005434663778	3455	Economy	24800.00
0005434663783	3455	Economy	24800.00
0005435911620	3455	Economy	22600.00
0005434663780	3455	Economy	22600.00
0005434663777	3455	Economy	22600.00
0005434663779	3455	Economy	22600.00
0005435911578	3455	Economy	22600.00
0005434663785	3455	Economy	22600.00
0005435911594	3455	Economy	22600.00
0005435911577	3455	Economy	22600.00
0005434461706	3455	Economy	22600.00
0005434663786	3455	Economy	22600.00
0005434663782	3455	Economy	22600.00
0005434663776	3455	Economy	22600.00
0005434663775	3455	Economy	22600.00
0005434663781	3455	Economy	22600.00
0005434663784	3455	Economy	22600.00
0005435911626	3455	Economy	22600.00
0005434663673	12452	Economy	22600.00
0005434663674	12452	Economy	22600.00
0005434663656	12452	Economy	22600.00
0005434663640	12452	Economy	22600.00
0005434663672	12452	Economy	22600.00
0005435911658	12452	Economy	22600.00
0005434663657	12452	Economy	22600.00
0005434663591	12452	Economy	22600.00
0005435911657	12452	Economy	22600.00
0005434663614	12452	Economy	22600.00
0005435911656	12452	Economy	22600.00
0005434663615	12452	Economy	22600.00
0005435911655	12452	Economy	22600.00
0005434663667	12452	Economy	22600.00
0005434663691	12452	Economy	22600.00
0005434663627	12452	Economy	22600.00
0005434663641	12452	Economy	22600.00
0005434663658	12452	Economy	22600.00
0005434663626	12452	Economy	22600.00
0005433869302	14485	Economy	18500.00
0005433869124	14485	Economy	18500.00
0005433869189	14485	Economy	18500.00
0005433869235	14485	Economy	18500.00
0005433869241	14485	Economy	16800.00
0005433869283	14485	Economy	16800.00
0005435860606	14485	Economy	16800.00
0005433869203	14485	Economy	16800.00
0005433869110	14485	Economy	16800.00
0005433869048	14485	Economy	16800.00
0005435860607	14485	Economy	16800.00
0005435860609	14485	Economy	16800.00
0005433869134	14485	Economy	16800.00
0005435860614	14485	Economy	16800.00
0005433869168	14485	Economy	16800.00
0005433869243	14485	Economy	16800.00
0005433869254	14485	Economy	16800.00
0005433869083	14485	Economy	16800.00
0005433869238	14485	Economy	16800.00
0005433869179	14485	Economy	16800.00
0005433869084	14485	Economy	16800.00
0005433869204	14485	Economy	16800.00
0005433869212	14485	Economy	16800.00
0005433869100	14485	Economy	16800.00
0005433869188	14485	Economy	16800.00
0005433869167	14485	Economy	16800.00
0005433869133	14485	Economy	16800.00
0005435860613	14485	Economy	16800.00
0005433869169	14485	Economy	16800.00
0005435860612	14485	Economy	16800.00
0005435860605	14485	Economy	16800.00
0005433869223	14485	Economy	16800.00
0005435860611	14485	Economy	16800.00
0005433869130	14485	Economy	16800.00
0005433869184	14485	Economy	16800.00
0005433869348	14485	Economy	16800.00
0005433869226	14485	Economy	16800.00
0005433869131	14485	Economy	16800.00
0005433869166	14485	Economy	16800.00
0005435860604	14485	Economy	16800.00
0005433869187	14485	Economy	16800.00
0005435860610	14485	Economy	16800.00
0005433869101	14485	Economy	16800.00
0005433869242	14485	Economy	16800.00
0005433869132	14485	Economy	16800.00
0005433869239	14485	Economy	16800.00
0005433869003	14485	Economy	16800.00
0005433869118	14485	Economy	16800.00
0005435860608	14485	Economy	16800.00
0005433869078	14485	Economy	16800.00
0005435860526	32662	Economy	18500.00
0005433869516	32662	Economy	18500.00
0005435860545	32662	Economy	18500.00
0005433869499	32662	Economy	18500.00
0005435860525	32662	Economy	16800.00
0005435860542	32662	Economy	16800.00
0005433869509	32662	Economy	16800.00
0005435860557	32662	Economy	16800.00
0005433869521	32662	Economy	16800.00
0005435860554	32662	Economy	16800.00
0005435860543	32662	Economy	16800.00
0005433869500	32662	Economy	16800.00
0005433869495	32662	Economy	16800.00
0005435860529	32662	Economy	16800.00
0005433869510	32662	Economy	16800.00
0005433869508	32662	Economy	16800.00
0005433869502	32662	Economy	16800.00
0005433869506	32662	Economy	16800.00
0005433869522	32662	Economy	16800.00
0005433869520	32662	Economy	16800.00
0005433869492	32662	Economy	16800.00
0005435860527	32662	Economy	16800.00
0005433869504	32662	Economy	16800.00
0005435860553	32662	Economy	16800.00
0005433869486	32662	Economy	16800.00
0005433869493	32662	Economy	16800.00
0005433869505	32662	Economy	16800.00
0005433869501	32662	Economy	16800.00
0005433869513	32662	Economy	16800.00
0005433869515	32662	Economy	16800.00
0005433869490	32662	Economy	16800.00
0005433869496	32662	Economy	16800.00
0005433869514	32662	Economy	16800.00
0005433869507	32662	Economy	16800.00
0005433869489	32662	Economy	16800.00
0005433869488	32662	Economy	16800.00
0005433869518	32662	Economy	16800.00
0005433869498	32662	Economy	16800.00
0005433869494	32662	Economy	16800.00
0005433869512	32662	Economy	16800.00
0005433869519	32662	Economy	16800.00
0005433869491	32662	Economy	16800.00
0005433869511	32662	Economy	16800.00
0005433869487	32662	Economy	16800.00
0005433869503	32662	Economy	16800.00
0005433869517	32662	Economy	16800.00
0005433869497	32662	Economy	16800.00
0005433869485	32662	Economy	16800.00
0005432799873	12122	Economy	4900.00
0005432799907	12122	Economy	4900.00
0005432799968	12122	Economy	4400.00
0005432800094	12122	Economy	4400.00
0005432799964	12122	Economy	4400.00
0005432800107	12122	Economy	4400.00
0005432800004	12122	Economy	4400.00
0005432799872	12122	Economy	4400.00
0005432799937	12122	Economy	4400.00
0005432799845	12122	Economy	4400.00
0005432800006	12122	Economy	4400.00
0005432799947	12122	Economy	4400.00
0005432799998	12122	Economy	4400.00
0005432799906	12122	Economy	4400.00
0005432799954	12122	Economy	4400.00
0005432800079	12122	Economy	4400.00
0005432800060	12122	Economy	4400.00
0005432799955	12122	Economy	4400.00
0005432799999	12122	Economy	4400.00
0005432799943	12122	Economy	4400.00
0005432799967	12122	Economy	4400.00
0005432800035	12122	Economy	4400.00
0005432799939	12122	Economy	4400.00
0005432799948	12122	Economy	4400.00
0005432800034	12122	Economy	4400.00
0005432800095	12122	Economy	4400.00
0005432800128	12122	Economy	4400.00
0005432800214	14788	Economy	4400.00
0005432800201	14788	Economy	4400.00
0005432800212	14788	Economy	4400.00
0005432800206	14788	Economy	4400.00
0005432800204	14788	Economy	4400.00
0005432800197	14788	Economy	4400.00
0005432800198	14788	Economy	4400.00
0005432800199	14788	Economy	4400.00
0005432800211	14788	Economy	4400.00
0005432800205	14788	Economy	4400.00
0005432800196	14788	Economy	4400.00
0005432800202	14788	Economy	4400.00
0005432800207	14788	Economy	4400.00
0005432800203	14788	Economy	4400.00
0005432800209	14788	Economy	4400.00
0005432800215	14788	Economy	4400.00
0005432800210	14788	Economy	4400.00
0005432800208	14788	Economy	4400.00
0005432800216	14788	Economy	4400.00
0005432800200	14788	Economy	4400.00
0005432800195	14788	Economy	4400.00
0005432800213	14788	Economy	4400.00
0005435311291	7082	Business	49100.00
0005435311260	7082	Business	49100.00
0005435293492	7082	Business	49100.00
0005434409486	7082	Business	49100.00
0005434409467	7082	Business	49100.00
0005434409488	7082	Business	49100.00
0005434409468	7082	Business	49100.00
0005435311261	7082	Business	49100.00
0005434300180	7082	Business	49100.00
0005434409493	7082	Economy	16400.00
0005435311267	7082	Economy	16400.00
0005435311241	7082	Economy	16400.00
0005434300184	7082	Economy	16400.00
0005434300195	7082	Economy	16400.00
0005434300188	7082	Economy	16400.00
0005434409462	7082	Economy	16400.00
0005434300190	7082	Economy	16400.00
0005434409492	7082	Economy	16400.00
0005435293427	7082	Economy	16400.00
0005435293475	7082	Economy	16400.00
0005434409496	7082	Economy	16400.00
0005434409466	7082	Economy	16400.00
0005435311336	7082	Economy	16400.00
0005434409489	7082	Economy	16400.00
0005434409469	7082	Economy	16400.00
0005435311272	7082	Economy	16400.00
0005434409485	7082	Economy	16400.00
0005434409498	7082	Economy	16400.00
0005435311243	7082	Economy	16400.00
0005434300179	7082	Economy	16400.00
0005434409483	7082	Economy	16400.00
0005434409481	7082	Economy	16400.00
0005434409473	7082	Economy	16400.00
0005434409471	7082	Economy	16400.00
0005432154128	7082	Economy	16400.00
0005434300197	7082	Economy	16400.00
0005434409474	7082	Economy	16400.00
0005434409461	7082	Economy	16400.00
0005435311312	7082	Economy	16400.00
0005434300183	7082	Economy	16400.00
0005434409494	7082	Economy	16400.00
0005434409482	7082	Economy	16400.00
0005435311266	7082	Economy	16400.00
0005435293471	7082	Economy	18000.00
0005435311318	7082	Economy	18000.00
0005434300181	7082	Economy	18000.00
0005434409480	7082	Economy	16400.00
0005434409464	7082	Economy	16400.00
0005435311282	7082	Economy	16400.00
0005435311290	7082	Economy	16400.00
0005435311296	7082	Economy	16400.00
0005434409484	7082	Economy	16400.00
0005435311413	7082	Economy	16400.00
0005434409470	7082	Economy	16400.00
0005434300189	7082	Economy	16400.00
0005435311283	7082	Economy	16400.00
0005434300186	7082	Economy	16400.00
0005434300192	7082	Economy	16400.00
0005435293468	7082	Economy	16400.00
0005434409487	7082	Economy	16400.00
0005435293500	7082	Economy	16400.00
0005435311374	7082	Economy	16400.00
0005434300182	7082	Economy	16400.00
0005432154130	7082	Economy	16400.00
0005435311319	7082	Economy	16400.00
0005435293501	7082	Economy	16400.00
0005434409497	7082	Economy	16400.00
0005434409491	7082	Economy	16400.00
0005434409495	7082	Economy	16400.00
0005435311256	7082	Economy	16400.00
0005435311250	7082	Economy	16400.00
0005432108319	7082	Economy	16400.00
0005432154129	7082	Economy	16400.00
0005435311287	7082	Economy	16400.00
0005434300196	7082	Economy	16400.00
0005434300185	7082	Economy	16400.00
0005434409490	7082	Economy	16400.00
0005435311275	7082	Economy	16400.00
0005434409472	7082	Economy	16400.00
0005434409479	7082	Economy	16400.00
0005435311314	7082	Economy	16400.00
0005434409476	7082	Economy	16400.00
0005435311365	7082	Economy	16400.00
0005434300193	7082	Economy	16400.00
0005435311330	7082	Economy	16400.00
0005434409475	7082	Economy	16400.00
0005435311273	7082	Economy	16400.00
0005432154131	7082	Economy	16400.00
0005435293466	7082	Economy	16400.00
0005434300194	7082	Economy	16400.00
0005434409465	7082	Economy	16400.00
0005434300187	7082	Economy	16400.00
0005434409500	7082	Economy	16400.00
0005434409499	7082	Economy	16400.00
0005434409463	7082	Economy	16400.00
0005434409501	7082	Economy	16400.00
0005434409460	7082	Economy	16400.00
0005435293465	7082	Economy	16400.00
0005432154132	7082	Economy	16400.00
0005434300191	7082	Economy	16400.00
0005435311412	7082	Economy	16400.00
0005434409478	7082	Economy	16400.00
0005434409477	7082	Economy	16400.00
0005435293467	7082	Economy	16400.00
0005434300059	26930	Business	49100.00
0005434300055	26930	Business	49100.00
0005434409053	26930	Business	49100.00
0005434409039	26930	Business	49100.00
0005434408665	26930	Business	49100.00
0005434300085	26930	Business	49100.00
0005434300102	26930	Business	49100.00
0005434409188	26930	Business	49100.00
0005434408806	26930	Business	49100.00
0005434409064	26930	Business	49100.00
0005435311468	26930	Business	49100.00
0005434408979	26930	Business	49100.00
0005434299958	26930	Economy	16400.00
0005434409189	26930	Economy	16400.00
0005434300049	26930	Economy	16400.00
0005435311475	26930	Economy	16400.00
0005435311470	26930	Economy	16400.00
0005434408978	26930	Economy	16400.00
0005434300070	26930	Economy	16400.00
0005434300083	26930	Economy	16400.00
0005435311472	26930	Economy	16400.00
0005434408911	26930	Economy	16400.00
0005434409003	26930	Economy	16400.00
0005434408863	26930	Economy	16400.00
0005434408674	26930	Economy	16400.00
0005434300031	26930	Economy	16400.00
0005434300082	26930	Economy	16400.00
0005434408780	26930	Economy	16400.00
0005434299974	26930	Economy	16400.00
0005434300056	26930	Economy	16400.00
0005434408926	26930	Economy	16400.00
0005434408861	26930	Economy	16400.00
0005435311469	26930	Economy	16400.00
0005435311471	26930	Economy	16400.00
0005434408466	26930	Economy	16400.00
0005434408922	26930	Economy	16400.00
0005435311467	26930	Economy	16400.00
0005435293597	26930	Economy	16400.00
0005434300123	26930	Economy	16400.00
0005434408947	26930	Economy	16400.00
0005434409077	26930	Economy	16400.00
0005434408997	26930	Economy	16400.00
0005434409096	26930	Economy	16400.00
0005435293601	26930	Economy	16400.00
0005435311473	26930	Economy	16400.00
0005434408796	26930	Economy	16400.00
0005434408872	26930	Economy	16400.00
0005435293596	26930	Economy	16400.00
0005434408949	26930	Economy	16400.00
0005434408870	26930	Economy	16400.00
0005434300032	26930	Economy	16400.00
0005434299983	26930	Economy	16400.00
0005434300103	26930	Economy	18000.00
0005434299966	26930	Economy	18000.00
0005434299980	26930	Economy	18000.00
0005434408646	26930	Economy	18000.00
0005434408859	26930	Economy	18000.00
0005434408908	26930	Economy	18000.00
0005434408489	26930	Economy	16400.00
0005434409026	26930	Economy	16400.00
0005434408833	26930	Economy	16400.00
0005434408793	26930	Economy	16400.00
0005432058489	26930	Economy	16400.00
0005434409093	26930	Economy	16400.00
0005434409040	26930	Economy	16400.00
0005434409014	26930	Economy	16400.00
0005434408932	26930	Economy	16400.00
0005434408843	26930	Economy	16400.00
0005434408671	26930	Economy	16400.00
0005434299981	26930	Economy	16400.00
0005434300054	26930	Economy	16400.00
0005434409041	26930	Economy	16400.00
0005434408778	26930	Economy	16400.00
0005435293599	26930	Economy	16400.00
0005434300050	26930	Economy	16400.00
0005434408966	26930	Economy	16400.00
0005434408488	26930	Economy	16400.00
0005434299982	26930	Economy	16400.00
0005434408752	26930	Economy	16400.00
0005434409054	26930	Economy	16400.00
0005434408959	26930	Economy	16400.00
0005434300033	26930	Economy	16400.00
0005434408860	26930	Economy	16400.00
0005435293600	26930	Economy	16400.00
0005434409086	26930	Economy	16400.00
0005434409063	26930	Economy	16400.00
0005434408736	26930	Economy	16400.00
0005434408772	26930	Economy	16400.00
0005434408779	26930	Economy	16400.00
0005434408912	26930	Economy	16400.00
0005434299992	26930	Economy	16400.00
0005434409190	26930	Economy	16400.00
0005434299959	26930	Economy	16400.00
0005434300084	26930	Economy	16400.00
0005434408849	26930	Economy	16400.00
0005434408871	26930	Economy	16400.00
0005435311474	26930	Economy	16400.00
0005435293602	26930	Economy	16400.00
0005434408945	26930	Economy	16400.00
0005434408862	26930	Economy	16400.00
0005434409008	26930	Economy	16400.00
0005434409065	26930	Economy	16400.00
0005434408880	26930	Economy	16400.00
0005434408675	26930	Economy	16400.00
0005434408751	26930	Economy	16400.00
0005434300051	26930	Economy	16400.00
0005434409094	26930	Economy	16400.00
0005434409052	26930	Economy	16400.00
0005435293595	26930	Economy	16400.00
0005434408467	26930	Economy	16400.00
0005434408847	26930	Economy	16400.00
0005434408837	26930	Economy	16400.00
0005435293603	26930	Economy	16400.00
0005434408834	26930	Economy	16400.00
0005435311476	26930	Economy	16400.00
0005434300012	26930	Economy	16400.00
0005434408910	26930	Economy	16400.00
0005434409107	26930	Economy	16400.00
0005435293598	26930	Economy	16400.00
0005434408890	26930	Economy	16400.00
0005434409085	26930	Economy	16400.00
0005434299991	26930	Economy	16400.00
0005434300122	26930	Economy	16400.00
0005432058488	26930	Economy	16400.00
0005434408794	26930	Economy	16400.00
0005434408832	26930	Economy	16400.00
0005434408848	26930	Economy	16400.00
0005434299975	26930	Economy	16400.00
0005434300015	26930	Economy	16400.00
0005434409076	26930	Economy	16400.00
0005432605415	6468	Economy	16500.00
0005432605403	6468	Economy	16500.00
0005432605434	6468	Economy	16500.00
0005432605404	6468	Economy	15000.00
0005432605407	6468	Economy	15000.00
0005432605405	6468	Economy	15000.00
0005432605417	6468	Economy	15000.00
0005432605411	6468	Economy	15000.00
0005435312901	6468	Economy	15000.00
0005432605421	6468	Economy	15000.00
0005435218126	6468	Economy	15000.00
0005432605432	6468	Economy	15000.00
0005435220498	6468	Economy	15000.00
0005435218125	6468	Economy	15000.00
0005432605412	6468	Economy	15000.00
0005432605425	6468	Economy	15000.00
0005434512240	6468	Economy	15000.00
0005432605431	6468	Economy	15000.00
0005435218124	6468	Economy	15000.00
0005434512239	6468	Economy	15000.00
0005434512238	6468	Economy	15000.00
0005435220499	6468	Economy	15000.00
0005432605429	6468	Economy	15000.00
0005432605409	6468	Economy	15000.00
0005432605428	6468	Economy	15000.00
0005432605418	6468	Economy	15000.00
0005432605410	6468	Economy	15000.00
0005435218127	6468	Economy	15000.00
0005432605419	6468	Economy	15000.00
0005432605422	6468	Economy	15000.00
0005432605416	6468	Economy	15000.00
0005432605420	6468	Economy	15000.00
0005432605413	6468	Economy	15000.00
0005432605406	6468	Economy	15000.00
0005432605408	6468	Economy	15000.00
0005432605426	6468	Economy	15000.00
0005432605423	6468	Economy	15000.00
0005435220500	6468	Economy	15000.00
0005432605427	6468	Economy	15000.00
0005432605433	6468	Economy	15000.00
0005434512241	6468	Economy	15000.00
0005432605414	6468	Economy	15000.00
0005432605424	6468	Economy	15000.00
0005432605430	6468	Economy	15000.00
0005432605003	21374	Economy	16500.00
0005432604973	21374	Economy	16500.00
0005434512215	21374	Economy	16500.00
0005432605149	21374	Economy	16500.00
0005434512198	21374	Economy	15000.00
0005432604860	21374	Economy	15000.00
0005432605002	21374	Economy	15000.00
0005432605151	21374	Economy	15000.00
0005432605216	21374	Economy	15000.00
0005434512193	21374	Economy	15000.00
0005432605099	21374	Economy	15000.00
0005434512217	21374	Economy	15000.00
0005434512201	21374	Economy	15000.00
0005432605126	21374	Economy	15000.00
0005432605103	21374	Economy	15000.00
0005432605008	21374	Economy	15000.00
0005434512213	21374	Economy	15000.00
0005432604994	21374	Economy	15000.00
0005432604861	21374	Economy	15000.00
0005432604957	21374	Economy	15000.00
0005432605059	21374	Economy	15000.00
0005434512200	21374	Economy	15000.00
0005434512214	21374	Economy	15000.00
0005432605104	21374	Economy	15000.00
0005432605157	21374	Economy	15000.00
0005432605044	21374	Economy	15000.00
0005432605125	21374	Economy	15000.00
0005432605105	21374	Economy	15000.00
0005432605235	21374	Economy	15000.00
0005432605086	21374	Economy	15000.00
0005432605108	21374	Economy	15000.00
0005432604978	21374	Economy	15000.00
0005432605106	21374	Economy	15000.00
0005432605234	21374	Economy	15000.00
0005432604996	21374	Economy	15000.00
0005434512194	21374	Economy	15000.00
0005432604948	21374	Economy	15000.00
0005432604993	21374	Economy	15000.00
0005432604780	21374	Economy	15000.00
0005432605033	21374	Economy	15000.00
0005432605098	21374	Economy	15000.00
0005432605028	21374	Economy	15000.00
0005432605203	21374	Economy	15000.00
0005432605233	21374	Economy	15000.00
0005432605041	21374	Economy	15000.00
0005432605150	21374	Economy	15000.00
0005432605171	21374	Economy	15000.00
0005432604962	21374	Economy	15000.00
0005432605025	21374	Economy	15000.00
0005432604995	21374	Economy	15000.00
0005434908338	14976	Business	18900.00
0005434908320	14976	Business	18900.00
0005434908147	14976	Business	18900.00
0005434908332	14976	Business	18900.00
0005433252315	14976	Business	18900.00
0005434908194	14976	Business	18900.00
0005434908164	14976	Business	18900.00
0005434908241	14976	Business	18900.00
0005434908387	14976	Business	18900.00
0005433252317	14976	Economy	6300.00
0005434908186	14976	Economy	6300.00
0005433252319	14976	Economy	6300.00
0005434908223	14976	Economy	6300.00
0005434908161	14976	Economy	6300.00
0005434908321	14976	Economy	6300.00
0005434908193	14976	Economy	6300.00
0005434908386	14976	Economy	6300.00
0005433252316	14976	Economy	6300.00
0005434908361	14976	Economy	6300.00
0005434908265	14976	Economy	6900.00
0005434908163	14976	Economy	6900.00
0005434908388	14976	Economy	6900.00
0005434908162	14976	Economy	6900.00
0005433252326	14976	Economy	6900.00
0005434908441	14976	Economy	6300.00
0005434908197	14976	Economy	6300.00
0005434908331	14976	Economy	6300.00
0005434908240	14976	Economy	6300.00
0005434908271	14976	Economy	6300.00
0005433252313	14976	Economy	6300.00
0005433252323	14976	Economy	6300.00
0005434908370	14976	Economy	6300.00
0005434908175	14976	Economy	6300.00
0005434908138	14976	Economy	6300.00
0005433252324	14976	Economy	6300.00
0005434908371	14976	Economy	6300.00
0005434908278	14976	Economy	6300.00
0005434908269	14976	Economy	6300.00
0005434908169	14976	Economy	6300.00
0005434908095	14976	Economy	6300.00
0005433252325	14976	Economy	6300.00
0005434908274	14976	Economy	6300.00
0005434908380	14976	Economy	6300.00
0005433252328	14976	Economy	6300.00
0005434908196	14976	Economy	6300.00
0005434907900	14976	Economy	6300.00
0005434908195	14976	Economy	6300.00
0005433252322	14976	Economy	6300.00
0005434907898	14976	Economy	6300.00
0005434908275	14976	Economy	6300.00
0005434908339	14976	Economy	6300.00
0005434908346	14976	Economy	6300.00
0005433252321	14976	Economy	6300.00
0005434908136	14976	Economy	6300.00
0005434908176	14976	Economy	6300.00
0005434908187	14976	Economy	6300.00
0005434908316	14976	Economy	6300.00
0005434908422	14976	Economy	6300.00
0005433252318	14976	Economy	6300.00
0005434908366	14976	Economy	6300.00
0005434908168	14976	Economy	6300.00
0005434908295	14976	Economy	6300.00
0005434908330	14976	Economy	6300.00
0005434908171	14976	Economy	6300.00
0005434908139	14976	Economy	6300.00
0005434908205	14976	Economy	6300.00
0005434908294	14976	Economy	6300.00
0005434908298	14976	Economy	6300.00
0005434908002	14976	Economy	6300.00
0005433252329	14976	Economy	6300.00
0005434908270	14976	Economy	6300.00
0005433252327	14976	Economy	6300.00
0005434908167	14976	Economy	6300.00
0005434908341	14976	Economy	6300.00
0005434908362	14976	Economy	6300.00
0005434908392	14976	Economy	6300.00
0005434908250	14976	Economy	6300.00
0005434908198	14976	Economy	6300.00
0005434907899	14976	Economy	6300.00
0005434908242	14976	Economy	6300.00
0005433252314	14976	Economy	6300.00
0005433252320	14976	Economy	6300.00
0005434908074	14976	Economy	6300.00
0005434908137	14976	Economy	6300.00
0005434907970	14976	Economy	6300.00
0005434908204	14976	Economy	6300.00
0005434908293	14976	Economy	6300.00
0005434908687	25842	Business	18900.00
0005433252092	25842	Business	18900.00
0005434908722	25842	Business	18900.00
0005434908696	25842	Business	18900.00
0005433252075	25842	Business	18900.00
0005434908711	25842	Business	18900.00
0005433252015	25842	Business	18900.00
0005434908684	25842	Business	18900.00
0005434908716	25842	Business	18900.00
0005433252222	25842	Business	18900.00
0005434908727	25842	Business	18900.00
0005433252145	25842	Economy	6300.00
0005434908683	25842	Economy	6300.00
0005433252113	25842	Economy	6300.00
0005434908677	25842	Economy	6300.00
0005434908689	25842	Economy	6300.00
0005434908715	25842	Economy	6300.00
0005433252002	25842	Economy	6300.00
0005433252060	25842	Economy	6300.00
0005434908698	25842	Economy	6300.00
0005433252105	25842	Economy	6900.00
0005434908690	25842	Economy	6900.00
0005434908717	25842	Economy	6900.00
0005434908688	25842	Economy	6900.00
0005433252143	25842	Economy	6900.00
0005434908714	25842	Economy	6300.00
0005434908707	25842	Economy	6300.00
0005434908719	25842	Economy	6300.00
0005434908703	25842	Economy	6300.00
0005434908693	25842	Economy	6300.00
0005434908678	25842	Economy	6300.00
0005434908720	25842	Economy	6300.00
0005434908679	25842	Economy	6300.00
0005434908705	25842	Economy	6300.00
0005434908725	25842	Economy	6300.00
0005434908712	25842	Economy	6300.00
0005434908692	25842	Economy	6300.00
0005433252112	25842	Economy	6300.00
0005433251998	25842	Economy	6300.00
0005433252104	25842	Economy	6300.00
0005434908721	25842	Economy	6300.00
0005433252083	25842	Economy	6300.00
0005433252186	25842	Economy	6300.00
0005434908674	25842	Economy	6300.00
0005434908694	25842	Economy	6300.00
0005434908681	25842	Economy	6300.00
0005433251908	25842	Economy	6300.00
0005433252144	25842	Economy	6300.00
0005433252016	25842	Economy	6300.00
0005434908704	25842	Economy	6300.00
0005433252086	25842	Economy	6300.00
0005433252084	25842	Economy	6300.00
0005434908728	25842	Economy	6300.00
0005433252040	25842	Economy	6300.00
0005434908676	25842	Economy	6300.00
0005434908730	25842	Economy	6300.00
0005434908710	25842	Economy	6300.00
0005434908699	25842	Economy	6300.00
0005433252211	25842	Economy	6300.00
0005433252063	25842	Economy	6300.00
0005434908695	25842	Economy	6300.00
0005434908731	25842	Economy	6300.00
0005434908700	25842	Economy	6300.00
0005434908675	25842	Economy	6300.00
0005434908709	25842	Economy	6300.00
0005434908734	25842	Economy	6300.00
0005434908702	25842	Economy	6300.00
0005433251997	25842	Economy	6300.00
0005434908713	25842	Economy	6300.00
0005434908723	25842	Economy	6300.00
0005434908724	25842	Economy	6300.00
0005434908718	25842	Economy	6300.00
0005434908733	25842	Economy	6300.00
0005434908680	25842	Economy	6300.00
0005434908685	25842	Economy	6300.00
0005433251907	25842	Economy	6300.00
0005433252039	25842	Economy	6300.00
0005433252210	25842	Economy	6300.00
0005433251981	25842	Economy	6300.00
0005434908682	25842	Economy	6300.00
0005434908708	25842	Economy	6300.00
0005433252121	25842	Economy	6300.00
0005434908729	25842	Economy	6300.00
0005434908697	25842	Economy	6300.00
0005434908726	25842	Economy	6300.00
0005433252026	25842	Economy	6300.00
0005434908691	25842	Economy	6300.00
0005434908732	25842	Economy	6300.00
0005434908701	25842	Economy	6300.00
0005433252072	25842	Economy	6300.00
0005433252054	25842	Economy	6300.00
0005433252074	25842	Economy	6300.00
0005434908706	25842	Economy	6300.00
0005433252187	25842	Economy	6300.00
0005434908686	25842	Economy	6300.00
0005433009862	14206	Business	52300.00
0005433009876	14206	Business	52300.00
0005433009850	14206	Business	52300.00
0005433009869	14206	Business	52300.00
0005433009848	14206	Business	52300.00
0005433009883	14206	Business	52300.00
0005433009853	14206	Economy	17400.00
0005433009856	14206	Economy	17400.00
0005433009857	14206	Economy	17400.00
0005433009861	14206	Economy	17400.00
0005433009882	14206	Economy	19200.00
0005433009872	14206	Economy	19200.00
0005433009854	14206	Economy	17400.00
0005433009870	14206	Economy	17400.00
0005433009879	14206	Economy	17400.00
0005433009873	14206	Economy	17400.00
0005433009878	14206	Economy	17400.00
0005433009849	14206	Economy	17400.00
0005433009880	14206	Economy	17400.00
0005433009871	14206	Economy	17400.00
0005433009866	14206	Economy	17400.00
0005433009885	14206	Economy	17400.00
0005433810605	14206	Economy	17400.00
0005433009888	14206	Economy	17400.00
0005433009865	14206	Economy	17400.00
0005433009887	14206	Economy	17400.00
0005433009859	14206	Economy	17400.00
0005433009851	14206	Economy	17400.00
0005433009864	14206	Economy	17400.00
0005433009852	14206	Economy	17400.00
0005433009868	14206	Economy	17400.00
0005433009860	14206	Economy	17400.00
0005433009875	14206	Economy	17400.00
0005433009881	14206	Economy	17400.00
0005433009858	14206	Economy	17400.00
0005433810607	14206	Economy	17400.00
0005433009874	14206	Economy	17400.00
0005433009867	14206	Economy	17400.00
0005433009877	14206	Economy	17400.00
0005433810604	14206	Economy	17400.00
0005433009863	14206	Economy	17400.00
0005433009884	14206	Economy	17400.00
0005433009886	14206	Economy	17400.00
0005433009855	14206	Economy	17400.00
0005433810614	14206	Economy	17400.00
0005433009492	22816	Business	52300.00
0005433009593	22816	Business	52300.00
0005433009446	22816	Business	52300.00
0005433009394	22816	Business	52300.00
0005433009597	22816	Business	52300.00
0005433810710	22816	Business	52300.00
0005433810711	22816	Business	52300.00
0005433009386	22816	Business	52300.00
0005433009338	22816	Business	52300.00
0005433009448	22816	Economy	17400.00
0005433009384	22816	Economy	17400.00
0005433009514	22816	Economy	17400.00
0005433009337	22816	Economy	17400.00
0005433009434	22816	Economy	17400.00
0005433009596	22816	Economy	17400.00
0005433009435	22816	Economy	17400.00
0005433810716	22816	Economy	19200.00
0005433009417	22816	Economy	19200.00
0005433009530	22816	Economy	19200.00
0005433009740	22816	Economy	19200.00
0005433009416	22816	Economy	17400.00
0005433009439	22816	Economy	17400.00
0005433009307	22816	Economy	17400.00
0005433009519	22816	Economy	17400.00
0005433009351	22816	Economy	17400.00
0005433810708	22816	Economy	17400.00
0005433810705	22816	Economy	17400.00
0005433810714	22816	Economy	17400.00
0005433009587	22816	Economy	17400.00
0005433009447	22816	Economy	17400.00
0005433810707	22816	Economy	17400.00
0005433009388	22816	Economy	17400.00
0005433009420	22816	Economy	17400.00
0005433009400	22816	Economy	17400.00
0005433810717	22816	Economy	17400.00
0005433810709	22816	Economy	17400.00
0005433009331	22816	Economy	17400.00
0005433009393	22816	Economy	17400.00
0005433810718	22816	Economy	17400.00
0005433810715	22816	Economy	17400.00
0005433009352	22816	Economy	17400.00
0005433009321	22816	Economy	17400.00
0005433009592	22816	Economy	17400.00
0005433810713	22816	Economy	17400.00
0005433810706	22816	Economy	17400.00
0005433009373	22816	Economy	17400.00
0005433009522	22816	Economy	17400.00
0005433009385	22816	Economy	17400.00
0005433009467	22816	Economy	17400.00
0005433810719	22816	Economy	17400.00
0005433009529	22816	Economy	17400.00
0005433009647	22816	Economy	17400.00
0005433810712	22816	Economy	17400.00
0005433009432	22816	Economy	17400.00
0005433009591	22816	Economy	17400.00
0005433009466	22816	Economy	17400.00
0005433009249	22816	Economy	17400.00
0005433009363	22816	Economy	17400.00
0005433009513	22816	Economy	17400.00
0005433009233	22816	Economy	17400.00
0005433009415	22816	Economy	17400.00
0005433009484	22816	Economy	17400.00
0005435718991	27117	Business	85200.00
0005435719000	27117	Business	85200.00
0005435719016	27117	Business	85200.00
0005435718985	27117	Business	85200.00
0005435719010	27117	Business	85200.00
0005435719012	27117	Economy	28400.00
0005435719025	27117	Economy	28400.00
0005435719015	27117	Economy	28400.00
0005435719017	27117	Economy	31200.00
0005435718990	27117	Economy	31200.00
0005435718988	27117	Economy	28400.00
0005435719006	27117	Economy	28400.00
0005435718993	27117	Economy	28400.00
0005435719018	27117	Economy	28400.00
0005435719034	27117	Economy	28400.00
0005435719004	27117	Economy	28400.00
0005435718997	27117	Economy	28400.00
0005435719031	27117	Economy	28400.00
0005435719009	27117	Economy	28400.00
0005435719028	27117	Economy	28400.00
0005435718992	27117	Economy	28400.00
0005435719022	27117	Economy	28400.00
0005435719024	27117	Economy	28400.00
0005435719027	27117	Economy	28400.00
0005435719008	27117	Economy	28400.00
0005435718998	27117	Economy	28400.00
0005435719007	27117	Economy	28400.00
0005435719001	27117	Economy	28400.00
0005435718996	27117	Economy	28400.00
0005435719002	27117	Economy	28400.00
0005435718994	27117	Economy	28400.00
0005435718995	27117	Economy	28400.00
0005435719011	27117	Economy	28400.00
0005435718987	27117	Economy	28400.00
0005435719019	27117	Economy	28400.00
0005435719029	27117	Economy	28400.00
0005435719005	27117	Economy	28400.00
0005435719023	27117	Economy	28400.00
0005435718989	27117	Economy	28400.00
0005435719030	27117	Economy	28400.00
0005435718999	27117	Economy	28400.00
0005434926360	14928	Business	22900.00
0005434926477	14928	Business	22900.00
0005434926440	14928	Business	22900.00
0005434926320	14928	Business	22900.00
0005434926340	14928	Business	22900.00
0005434926403	14928	Business	22900.00
0005434926361	14928	Business	22900.00
0005434926355	14928	Economy	7600.00
0005434926226	14928	Economy	7600.00
0005434926276	14928	Economy	7600.00
0005434926346	14928	Economy	8400.00
0005434926441	14928	Economy	8400.00
0005434926322	14928	Economy	8400.00
0005434926420	14928	Economy	7600.00
0005434926489	14928	Economy	7600.00
0005434926379	14928	Economy	7600.00
0005434926409	14928	Economy	7600.00
0005434926254	14928	Economy	7600.00
0005434926399	14928	Economy	7600.00
0005434926393	14928	Economy	7600.00
0005434926253	14928	Economy	7600.00
0005434926375	14928	Economy	7600.00
0005434926397	14928	Economy	7600.00
0005434926372	14928	Economy	7600.00
0005434926370	14928	Economy	7600.00
0005434926490	14928	Economy	7600.00
0005434926367	14928	Economy	7600.00
0005435375180	14928	Economy	7600.00
0005434926352	14928	Economy	7600.00
0005434926448	14928	Economy	7600.00
0005434926419	14928	Economy	7600.00
0005434926582	14928	Economy	7600.00
0005434926338	14928	Economy	7600.00
0005434926274	14928	Economy	7600.00
0005434926317	14928	Economy	7600.00
0005434926463	14928	Economy	7600.00
0005434926373	14928	Economy	7600.00
0005434926398	14928	Economy	7600.00
0005434926326	14928	Economy	7600.00
0005434926316	14928	Economy	7600.00
0005434926321	14928	Economy	7600.00
0005434926270	14928	Economy	7600.00
0005434926464	14928	Economy	7600.00
0005434926273	14928	Economy	7600.00
0005434926305	14928	Economy	7600.00
0005434926684	20550	Business	22900.00
0005434926681	20550	Business	22900.00
0005434926663	20550	Business	22900.00
0005434926702	20550	Business	22900.00
0005434926672	20550	Business	22900.00
0005434926692	20550	Business	22900.00
0005434926676	20550	Business	22900.00
0005434926662	20550	Economy	7600.00
0005434926689	20550	Economy	7600.00
0005434926699	20550	Economy	7600.00
0005434926700	20550	Economy	7600.00
0005434926666	20550	Economy	8400.00
0005434926667	20550	Economy	8400.00
0005434926683	20550	Economy	7600.00
0005434926686	20550	Economy	7600.00
0005434926670	20550	Economy	7600.00
0005434926697	20550	Economy	7600.00
0005434926704	20550	Economy	7600.00
0005434926659	20550	Economy	7600.00
0005434926668	20550	Economy	7600.00
0005434926680	20550	Economy	7600.00
0005434926705	20550	Economy	7600.00
0005434926673	20550	Economy	7600.00
0005434926687	20550	Economy	7600.00
0005434926695	20550	Economy	7600.00
0005434926677	20550	Economy	7600.00
0005434926675	20550	Economy	7600.00
0005434926665	20550	Economy	7600.00
0005434926691	20550	Economy	7600.00
0005434926690	20550	Economy	7600.00
0005434926678	20550	Economy	7600.00
0005434926701	20550	Economy	7600.00
0005434926664	20550	Economy	7600.00
0005434926682	20550	Economy	7600.00
0005434926661	20550	Economy	7600.00
0005434926679	20550	Economy	7600.00
0005434926703	20550	Economy	7600.00
0005434926698	20550	Economy	7600.00
0005434926685	20550	Economy	7600.00
0005434926660	20550	Economy	7600.00
0005434926671	20550	Economy	7600.00
0005434926693	20550	Economy	7600.00
0005434926674	20550	Economy	7600.00
0005434926669	20550	Economy	7600.00
0005434926696	20550	Economy	7600.00
0005434926694	20550	Economy	7600.00
0005434926688	20550	Economy	7600.00
0005435999617	15842	Economy	8900.00
0005435999643	15842	Economy	8100.00
0005435999645	15842	Economy	8100.00
0005435488435	15842	Economy	8100.00
0005435488436	15842	Economy	8100.00
0005435999597	15842	Economy	8100.00
0005435488429	15842	Economy	8100.00
0005435488431	15842	Economy	8100.00
0005435999634	15842	Economy	8100.00
0005435999477	15842	Economy	8100.00
0005435999592	15842	Economy	8100.00
0005435999635	15842	Economy	8100.00
0005435488432	15842	Economy	8100.00
0005435999584	15842	Economy	8100.00
0005435999604	15842	Economy	8100.00
0005435999583	15842	Economy	8100.00
0005435999553	15842	Economy	8100.00
0005435999644	15842	Economy	8100.00
0005435488428	15842	Economy	8100.00
0005435488437	15842	Economy	8100.00
0005435999525	15842	Economy	8100.00
0005435488433	15842	Economy	8100.00
0005435488426	15842	Economy	8100.00
0005435488430	15842	Economy	8100.00
0005435999479	15842	Economy	8100.00
0005435488427	15842	Economy	8100.00
0005435999526	15842	Economy	8100.00
0005435999593	15842	Economy	8100.00
0005435488424	15842	Economy	8100.00
0005435488434	15842	Economy	8100.00
0005435999528	15842	Economy	8100.00
0005435999524	15842	Economy	8100.00
0005435999609	15842	Economy	8100.00
0005435999478	15842	Economy	8100.00
0005435999527	15842	Economy	8100.00
0005435488438	15842	Economy	8100.00
0005435488425	15842	Economy	8100.00
0005435999639	15842	Economy	8100.00
0005435999773	19686	Economy	8900.00
0005435999748	19686	Economy	8900.00
0005435999757	19686	Economy	8900.00
0005435488212	19686	Economy	8900.00
0005435999744	19686	Economy	8100.00
0005435488209	19686	Economy	8100.00
0005435488325	19686	Economy	8100.00
0005435999766	19686	Economy	8100.00
0005435488191	19686	Economy	8100.00
0005435999758	19686	Economy	8100.00
0005435999750	19686	Economy	8100.00
0005435488303	19686	Economy	8100.00
0005435999751	19686	Economy	8100.00
0005435999774	19686	Economy	8100.00
0005435488255	19686	Economy	8100.00
0005435488200	19686	Economy	8100.00
0005435999769	19686	Economy	8100.00
0005435999749	19686	Economy	8100.00
0005435999742	19686	Economy	8100.00
0005435999762	19686	Economy	8100.00
0005435999754	19686	Economy	8100.00
0005435999765	19686	Economy	8100.00
0005435999760	19686	Economy	8100.00
0005435999747	19686	Economy	8100.00
0005435999759	19686	Economy	8100.00
0005435488190	19686	Economy	8100.00
0005435999767	19686	Economy	8100.00
0005435488208	19686	Economy	8100.00
0005435999752	19686	Economy	8100.00
0005435999743	19686	Economy	8100.00
0005435999764	19686	Economy	8100.00
0005435999775	19686	Economy	8100.00
0005435999761	19686	Economy	8100.00
0005435488242	19686	Economy	8100.00
0005435999756	19686	Economy	8100.00
0005435999768	19686	Economy	8100.00
0005435999753	19686	Economy	8100.00
0005435999755	19686	Economy	8100.00
0005435999763	19686	Economy	8100.00
0005435999746	19686	Economy	8100.00
0005435999745	19686	Economy	8100.00
0005435488326	19686	Economy	8100.00
0005435999772	19686	Economy	8100.00
0005435488164	19686	Economy	8100.00
0005435999771	19686	Economy	8100.00
0005435488186	19686	Economy	8100.00
0005435999770	19686	Economy	8100.00
0005435488290	19686	Economy	8100.00
0005435840220	6027	Business	199300.00
0005435840216	6027	Business	199300.00
0005435473124	6027	Business	199300.00
0005432537090	6027	Business	199300.00
0005432660878	6027	Business	199300.00
0005435840223	6027	Economy	66400.00
0005435473130	6027	Economy	66400.00
0005432537089	6027	Economy	66400.00
0005432142339	6027	Economy	73100.00
0005435840230	6027	Economy	73100.00
0005435840226	6027	Economy	66400.00
0005435840231	6027	Economy	66400.00
0005435473107	6027	Economy	66400.00
0005435840222	6027	Economy	66400.00
0005435840232	6027	Economy	66400.00
0005435473113	6027	Economy	66400.00
0005435840229	6027	Economy	66400.00
0005432660877	6027	Economy	66400.00
0005435473148	6027	Economy	66400.00
0005435840234	6027	Economy	66400.00
0005432142340	6027	Economy	66400.00
0005435840219	6027	Economy	66400.00
0005432660880	6027	Economy	66400.00
0005435473088	6027	Economy	66400.00
0005435473185	6027	Economy	66400.00
0005432142338	6027	Economy	66400.00
0005435840218	6027	Economy	66400.00
0005432537099	6027	Economy	66400.00
0005435840224	6027	Economy	66400.00
0005435840217	6027	Economy	66400.00
0005435840233	6027	Economy	66400.00
0005435840215	6027	Economy	66400.00
0005432660879	6027	Economy	66400.00
0005435840227	6027	Economy	66400.00
0005435840228	6027	Economy	66400.00
0005435840225	6027	Economy	66400.00
0005435473125	6027	Economy	66400.00
0005435473106	6027	Economy	66400.00
0005435840221	6027	Economy	66400.00
0005435473114	6027	Economy	66400.00
0005435840034	18045	Business	199300.00
0005435840042	18045	Business	199300.00
0005435840035	18045	Business	199300.00
0005432664172	18045	Business	199300.00
0005435839888	18045	Business	199300.00
0005432667486	18045	Business	199300.00
0005435839969	18045	Economy	66400.00
0005435840036	18045	Economy	66400.00
0005435840023	18045	Economy	66400.00
0005435839975	18045	Economy	66400.00
0005435473253	18045	Economy	66400.00
0005435473254	18045	Economy	73100.00
0005435840020	18045	Economy	73100.00
0005435839861	18045	Economy	66400.00
0005435617244	18045	Economy	66400.00
0005435473255	18045	Economy	66400.00
0005435473260	18045	Economy	66400.00
0005435839990	18045	Economy	66400.00
0005432660856	18045	Economy	66400.00
0005432660846	18045	Economy	66400.00
0005432664167	18045	Economy	66400.00
0005435473257	18045	Economy	66400.00
0005435840009	18045	Economy	66400.00
0005435473249	18045	Economy	66400.00
0005435840015	18045	Economy	66400.00
0005435473252	18045	Economy	66400.00
0005435839946	18045	Economy	66400.00
0005435473250	18045	Economy	66400.00
0005432537118	18045	Economy	66400.00
0005435840048	18045	Economy	66400.00
0005435473259	18045	Economy	66400.00
0005435473251	18045	Economy	66400.00
0005432667491	18045	Economy	66400.00
0005435840010	18045	Economy	66400.00
0005435840019	18045	Economy	66400.00
0005435839876	18045	Economy	66400.00
0005435840049	18045	Economy	66400.00
0005435840066	18045	Economy	66400.00
0005435473261	18045	Economy	66400.00
0005435473258	18045	Economy	66400.00
0005432664168	18045	Economy	66400.00
0005435839887	18045	Economy	66400.00
0005435839922	18045	Economy	66400.00
0005435839929	18045	Economy	66400.00
0005435840033	18045	Economy	66400.00
0005435839976	18045	Economy	66400.00
0005435473256	18045	Economy	66400.00
0005435839989	18045	Economy	66400.00
0005432664166	18045	Economy	66400.00
0005435839886	18045	Economy	66400.00
0005433462784	19913	Business	146400.00
0005433462777	19913	Business	146400.00
0005433460470	19913	Economy	48800.00
0005433462772	19913	Economy	48800.00
0005433462776	19913	Economy	48800.00
0005433462783	19913	Economy	48800.00
0005433460466	19913	Economy	48800.00
0005433460463	19913	Economy	48800.00
0005433460449	19913	Economy	48800.00
0005433460461	19913	Economy	48800.00
0005433460472	19913	Economy	48800.00
0005433460462	19913	Economy	48800.00
0005433460454	19913	Economy	48800.00
0005433462786	19913	Economy	48800.00
0005433462768	19913	Economy	48800.00
0005433460465	19913	Economy	48800.00
0005433462782	19913	Economy	48800.00
0005433460474	19913	Economy	48800.00
0005433460471	19913	Economy	48800.00
0005433462778	19913	Economy	48800.00
0005433462765	19913	Economy	48800.00
0005433460469	19913	Economy	48800.00
0005433462787	19913	Economy	48800.00
0005435104233	23018	Business	15700.00
0005435104219	23018	Business	15700.00
0005433285936	23018	Business	15700.00
0005435104235	23018	Business	15700.00
0005433285790	23018	Business	15700.00
0005435104232	23018	Business	15700.00
0005433285882	23018	Business	15700.00
0005433285876	23018	Economy	5200.00
0005435104228	23018	Economy	5200.00
0005435104238	23018	Economy	5200.00
0005433285853	23018	Economy	5200.00
0005433285806	23018	Economy	5200.00
0005433285990	23018	Economy	5200.00
0005433285768	23018	Economy	5200.00
0005433285958	23018	Economy	5200.00
0005433285854	23018	Economy	5200.00
0005433286049	23018	Economy	5200.00
0005433285905	23018	Economy	5200.00
0005433285945	23018	Economy	5200.00
0005435104223	23018	Economy	5200.00
0005433286048	23018	Economy	5200.00
0005433285993	23018	Economy	5200.00
0005435104221	23018	Economy	5200.00
0005435104224	23018	Economy	5200.00
0005435104236	23018	Economy	5200.00
0005435104230	23018	Economy	5700.00
0005435104229	23018	Economy	5700.00
0005433285789	23018	Economy	5700.00
0005433285908	23018	Economy	5700.00
0005433286008	23018	Economy	5200.00
0005433285975	23018	Economy	5200.00
0005433285861	23018	Economy	5200.00
0005435104213	23018	Economy	5200.00
0005435104226	23018	Economy	5200.00
0005433285906	23018	Economy	5200.00
0005435104222	23018	Economy	5200.00
0005433285949	23018	Economy	5200.00
0005435104215	23018	Economy	5200.00
0005433285784	23018	Economy	5200.00
0005435104234	23018	Economy	5200.00
0005433285939	23018	Economy	5200.00
0005433285878	23018	Economy	5200.00
0005435104214	23018	Economy	5200.00
0005433285862	23018	Economy	5200.00
0005433285989	23018	Economy	5200.00
0005435104217	23018	Economy	5200.00
0005433285863	23018	Economy	5200.00
0005435104225	23018	Economy	5200.00
0005435104237	23018	Economy	5200.00
0005433285950	23018	Economy	5200.00
0005435104220	23018	Economy	5200.00
0005435104216	23018	Economy	5200.00
0005435104218	23018	Economy	5200.00
0005433285888	23018	Economy	5200.00
0005433285953	23018	Economy	5200.00
0005433285940	23018	Economy	5200.00
0005435104212	23018	Economy	5200.00
0005435104227	23018	Economy	5200.00
0005433285807	23018	Economy	5200.00
0005433285671	23018	Economy	5200.00
0005435104231	23018	Economy	5200.00
0005433285952	23018	Economy	5200.00
0005433285889	23018	Economy	5200.00
0005433286156	32084	Business	15700.00
0005433286152	32084	Business	15700.00
0005433286158	32084	Economy	5200.00
0005433286157	32084	Economy	5200.00
0005433286149	32084	Economy	5200.00
0005433286153	32084	Economy	5200.00
0005433286147	32084	Economy	5200.00
0005433286155	32084	Economy	5200.00
0005433286164	32084	Economy	5200.00
0005435104021	32084	Economy	5200.00
0005433286166	32084	Economy	5200.00
0005433286161	32084	Economy	5200.00
0005435104044	32084	Economy	5700.00
0005435104022	32084	Economy	5700.00
0005433286159	32084	Economy	5200.00
0005433286150	32084	Economy	5200.00
0005433286145	32084	Economy	5200.00
0005435104042	32084	Economy	5200.00
0005433286151	32084	Economy	5200.00
0005433286148	32084	Economy	5200.00
0005433286146	32084	Economy	5200.00
0005433286165	32084	Economy	5200.00
0005433286162	32084	Economy	5200.00
0005435104061	32084	Economy	5200.00
0005433286160	32084	Economy	5200.00
0005435104054	32084	Economy	5200.00
0005433286144	32084	Economy	5200.00
0005433286163	32084	Economy	5200.00
0005435104043	32084	Economy	5200.00
0005433286154	32084	Economy	5200.00
0005432802557	19943	Business	150400.00
0005434302875	19943	Business	150400.00
0005432802584	19943	Business	150400.00
0005432802548	19943	Business	150400.00
0005432802585	19943	Business	150400.00
0005432892818	19943	Business	150400.00
0005433112411	19943	Business	150400.00
0005433111555	19943	Business	150400.00
0005434302873	19943	Business	150400.00
0005433111562	19943	Business	150400.00
0005433111554	19943	Business	150400.00
0005432892814	19943	Business	150400.00
0005433112410	19943	Business	150400.00
0005432802567	19943	Business	150400.00
0005433112416	19943	Business	150400.00
0005433111556	19943	Economy	50100.00
0005432802572	19943	Economy	50100.00
0005432802591	19943	Economy	50100.00
0005433111551	19943	Economy	50100.00
0005432892812	19943	Economy	50100.00
0005433112412	19943	Economy	50100.00
0005432802570	19943	Economy	55200.00
0005432802590	19943	Economy	50100.00
0005432802569	19943	Economy	50100.00
0005432802541	19943	Economy	50100.00
0005432802538	19943	Economy	50100.00
0005433112415	19943	Economy	50100.00
0005432802551	19943	Economy	50100.00
0005432802547	19943	Economy	50100.00
0005433112408	19943	Economy	50100.00
0005432892816	19943	Economy	50100.00
0005433112413	19943	Economy	50100.00
0005433111559	19943	Economy	50100.00
0005432802563	19943	Economy	50100.00
0005432802550	19943	Economy	50100.00
0005432802580	19943	Economy	50100.00
0005432802545	19943	Economy	50100.00
0005432802579	19943	Economy	50100.00
0005432892817	19943	Economy	50100.00
0005432802583	19943	Economy	50100.00
0005432892820	19943	Economy	50100.00
0005432892819	19943	Economy	50100.00
0005432802589	19943	Economy	50100.00
0005433111564	19943	Economy	50100.00
0005433111561	19943	Economy	50100.00
0005432802564	19943	Economy	50100.00
0005432892813	19943	Economy	50100.00
0005432802581	19943	Economy	50100.00
0005432892815	19943	Economy	50100.00
0005432802571	19943	Economy	50100.00
0005433111553	19943	Economy	50100.00
0005432892811	19943	Economy	50100.00
0005433112414	19943	Economy	50100.00
0005434302876	19943	Economy	50100.00
0005434302874	19943	Economy	50100.00
0005432802535	19943	Economy	50100.00
0005433112418	19943	Economy	50100.00
0005432802588	19943	Economy	50100.00
0005433112417	19943	Economy	50100.00
0005432802565	19943	Economy	50100.00
0005432802534	19943	Economy	50100.00
0005432802558	19943	Economy	50100.00
0005433111557	19943	Economy	50100.00
0005432802536	19943	Economy	50100.00
0005432802566	19943	Economy	50100.00
0005433111558	19943	Economy	50100.00
0005432802582	19943	Economy	50100.00
0005432802576	19943	Economy	50100.00
0005432802549	19943	Economy	50100.00
0005432802587	19943	Economy	50100.00
0005432802552	19943	Economy	50100.00
0005432802586	19943	Economy	50100.00
0005433111552	19943	Economy	50100.00
0005433112409	19943	Economy	50100.00
0005432802568	19943	Economy	50100.00
0005432892810	19943	Economy	50100.00
0005433111560	19943	Economy	50100.00
0005433111563	19943	Economy	50100.00
0005432530238	30584	Business	42100.00
0005434068971	30584	Business	42100.00
0005435215404	30584	Business	42100.00
0005432530637	30584	Business	42100.00
0005434068964	30584	Business	42100.00
0005432530857	30584	Business	42100.00
0005432531251	30584	Business	42100.00
0005432530448	30584	Business	42100.00
0005434069069	30584	Business	42100.00
0005434068954	30584	Business	42100.00
0005434068661	30584	Business	42100.00
0005432530654	30584	Business	42100.00
0005434068923	30584	Business	42100.00
0005434068854	30584	Business	42100.00
0005432531077	30584	Business	42100.00
0005434068945	30584	Business	42100.00
0005432531004	30584	Business	42100.00
0005432530490	30584	Business	42100.00
0005435215428	30584	Business	42100.00
0005432530418	30584	Business	42100.00
0005432530691	30584	Business	42100.00
0005435283491	30584	Comfort	23900.00
0005432530725	30584	Comfort	23900.00
0005434068915	30584	Comfort	23900.00
0005432531055	30584	Comfort	23900.00
0005435631050	30584	Comfort	23900.00
0005432530720	30584	Comfort	23900.00
0005432530800	30584	Comfort	23900.00
0005435283495	30584	Comfort	23900.00
0005432530504	30584	Comfort	23900.00
0005432531020	30584	Comfort	23900.00
0005432530480	30584	Comfort	23900.00
0005435283498	30584	Comfort	23900.00
0005434068868	30584	Comfort	23900.00
0005435215436	30584	Comfort	23900.00
0005435215442	30584	Comfort	23900.00
0005435215426	30584	Comfort	23900.00
0005434069001	30584	Comfort	23900.00
0005435215416	30584	Comfort	23900.00
0005435215439	30584	Comfort	23900.00
0005432530528	30584	Comfort	23900.00
0005432530992	30584	Comfort	23900.00
0005434068962	30584	Comfort	23900.00
0005434068560	30584	Comfort	23900.00
0005435215427	30584	Comfort	23900.00
0005432530560	30584	Comfort	23900.00
0005434068741	30584	Comfort	23900.00
0005434068932	30584	Comfort	23900.00
0005434068953	30584	Comfort	23900.00
0005432530552	30584	Comfort	23900.00
0005435215414	30584	Comfort	23900.00
0005432531101	30584	Economy	14000.00
0005435215430	30584	Economy	14000.00
0005434068983	30584	Economy	14000.00
0005432531102	30584	Economy	14000.00
0005432533352	30584	Economy	14000.00
0005432530446	30584	Economy	14000.00
0005435215421	30584	Economy	14000.00
0005432530677	30584	Economy	14000.00
0005432535936	30584	Economy	14000.00
0005434068941	30584	Economy	14000.00
0005434068821	30584	Economy	14000.00
0005434068902	30584	Economy	14000.00
0005432531003	30584	Economy	14000.00
0005432531250	30584	Economy	14000.00
0005432530580	30584	Economy	14000.00
0005435215435	30584	Economy	14000.00
0005432530292	30584	Economy	14000.00
0005432530993	30584	Economy	14000.00
0005432530077	30584	Economy	14000.00
0005434068942	30584	Economy	14000.00
0005432530684	30584	Economy	14000.00
0005435215423	30584	Economy	14000.00
0005432533355	30584	Economy	14000.00
0005435215422	30584	Economy	14000.00
0005434068811	30584	Economy	14000.00
0005435215409	30584	Economy	14000.00
0005434068911	30584	Economy	14000.00
0005432530940	30584	Economy	14000.00
0005432530778	30584	Economy	14000.00
0005432530071	30584	Economy	14000.00
0005432530829	30584	Economy	14000.00
0005432530554	30584	Economy	14000.00
0005432530295	30584	Economy	14000.00
0005434068851	30584	Economy	14000.00
0005432530360	30584	Economy	14000.00
0005432159987	30584	Economy	14000.00
0005435215429	30584	Economy	14000.00
0005432530646	30584	Economy	14000.00
0005432530475	30584	Economy	14000.00
0005432530621	30584	Economy	14000.00
0005435283501	30584	Economy	14000.00
0005432530607	30584	Economy	14000.00
0005432531078	30584	Economy	14000.00
0005434068733	30584	Economy	14000.00
0005432530447	30584	Economy	14000.00
0005432530516	30584	Economy	14000.00
0005432530555	30584	Economy	14000.00
0005434069093	30584	Economy	14000.00
0005435283500	30584	Economy	14000.00
0005432535963	30584	Economy	14000.00
0005435215419	30584	Economy	14000.00
0005434068867	30584	Economy	15400.00
0005432530570	30584	Economy	15400.00
0005434068866	30584	Economy	14000.00
0005435283490	30584	Economy	15400.00
0005432537096	30584	Economy	14000.00
0005432530638	30584	Economy	14000.00
0005432530827	30584	Economy	14000.00
0005432530291	30584	Economy	15400.00
0005432530690	30584	Economy	14000.00
0005435215410	30584	Economy	15400.00
0005434068948	30584	Economy	14000.00
0005432530717	30584	Economy	14000.00
0005432211711	30584	Economy	14000.00
0005432531168	30584	Economy	14000.00
0005434069002	30584	Economy	14000.00
0005432530828	30584	Economy	14000.00
0005434068924	30584	Economy	14000.00
0005434068836	30584	Economy	14000.00
0005432530588	30584	Economy	14000.00
0005435215415	30584	Economy	14000.00
0005432530517	30584	Economy	14000.00
0005432530045	30584	Economy	14000.00
0005432529773	30584	Economy	14000.00
0005435215433	30584	Economy	14000.00
0005432530826	30584	Economy	14000.00
0005434068548	30584	Economy	14000.00
0005432530294	30584	Economy	14000.00
0005434068561	30584	Economy	14000.00
0005432211714	30584	Economy	14000.00
0005435215413	30584	Economy	14000.00
0005432530653	30584	Economy	14000.00
0005432530097	30584	Economy	14000.00
0005432530606	30584	Economy	14000.00
0005432530489	30584	Economy	14000.00
0005432530647	30584	Economy	14000.00
0005432531038	30584	Economy	14000.00
0005435283504	30584	Economy	14000.00
0005434069077	30584	Economy	14000.00
0005435283502	30584	Economy	14000.00
0005432530319	30584	Economy	14000.00
0005435215441	30584	Economy	14000.00
0005432530692	30584	Economy	14000.00
0005432531249	30584	Economy	14000.00
0005435215424	30584	Economy	14000.00
0005434068931	30584	Economy	14000.00
0005432530565	30584	Economy	14000.00
0005432211715	30584	Economy	14000.00
0005432530577	30584	Economy	14000.00
0005432530786	30584	Economy	14000.00
0005432531167	30584	Economy	14000.00
0005432537095	30584	Economy	14000.00
0005432530605	30584	Economy	14000.00
0005432530237	30584	Economy	14000.00
0005432530923	30584	Economy	14000.00
0005432529983	30584	Economy	14000.00
0005434068901	30584	Economy	14000.00
0005435215432	30584	Economy	14000.00
0005434068740	30584	Economy	14000.00
0005432530010	30584	Economy	14000.00
0005432530592	30584	Economy	14000.00
0005434068815	30584	Economy	14000.00
0005432530724	30584	Economy	14000.00
0005434068903	30584	Economy	14000.00
0005432530715	30584	Economy	14000.00
0005434069279	30584	Economy	14000.00
0005432530386	30584	Economy	14000.00
0005435215408	30584	Economy	14000.00
0005435215405	30584	Economy	14000.00
0005432530251	30584	Economy	14000.00
0005432531019	30584	Economy	14000.00
0005432530278	30584	Economy	14000.00
0005434069109	30584	Economy	14000.00
0005432530200	30584	Economy	14000.00
0005435215443	30584	Economy	14000.00
0005432535941	30584	Economy	14000.00
0005432530948	30584	Economy	14000.00
0005434069017	30584	Economy	14000.00
0005432537100	30584	Economy	14000.00
0005432533354	30584	Economy	14000.00
0005432530830	30584	Economy	14000.00
0005434068862	30584	Economy	14000.00
0005434069016	30584	Economy	14000.00
0005435215434	30584	Economy	14000.00
0005435215412	30584	Economy	14000.00
0005432529651	30584	Economy	14000.00
0005432531100	30584	Economy	14000.00
0005432530718	30584	Economy	14000.00
0005435215425	30584	Economy	14000.00
0005434069127	30584	Economy	14000.00
0005435283497	30584	Economy	14000.00
0005434068973	30584	Economy	14000.00
0005435215431	30584	Economy	14000.00
0005432535938	30584	Economy	14000.00
0005434068636	30584	Economy	14000.00
0005432530337	30584	Economy	15400.00
0005432530995	30584	Economy	15400.00
0005434069021	30584	Economy	15400.00
0005432530515	30584	Economy	15400.00
0005432530719	30584	Economy	14000.00
0005432530922	30584	Economy	14000.00
0005434068701	30584	Economy	14000.00
0005432530784	30584	Economy	14000.00
0005432530511	30584	Economy	14000.00
0005432530622	30584	Economy	14000.00
0005432530474	30584	Economy	14000.00
0005432530843	30584	Economy	14000.00
0005435215440	30584	Economy	14000.00
0005432535937	30584	Economy	14000.00
0005434068847	30584	Economy	14000.00
0005432530553	30584	Economy	14000.00
0005432211713	30584	Economy	14000.00
0005434068846	30584	Economy	14000.00
0005432530628	30584	Economy	14000.00
0005435283503	30584	Economy	14000.00
0005434069055	30584	Economy	14000.00
0005432530683	30584	Economy	14000.00
0005432530466	30584	Economy	14000.00
0005434069056	30584	Economy	14000.00
0005432530921	30584	Economy	14000.00
0005434068969	30584	Economy	14000.00
0005432530834	30584	Economy	14000.00
0005434069110	30584	Economy	14000.00
0005432530618	30584	Economy	14000.00
0005432530596	30584	Economy	14000.00
0005434069192	30584	Economy	14000.00
0005432530317	30584	Economy	14000.00
0005432530803	30584	Economy	14000.00
0005435215406	30584	Economy	14000.00
0005434069280	30584	Economy	14000.00
0005435283492	30584	Economy	14000.00
0005435215418	30584	Economy	14000.00
0005432530858	30584	Economy	14000.00
0005432211712	30584	Economy	14000.00
0005432530470	30584	Economy	14000.00
0005435283494	30584	Economy	14000.00
0005434068933	30584	Economy	14000.00
0005434068760	30584	Economy	14000.00
0005432530604	30584	Economy	14000.00
0005432530785	30584	Economy	14000.00
0005435283499	30584	Economy	14000.00
0005435215417	30584	Economy	14000.00
0005432530742	30584	Economy	14000.00
0005432530716	30584	Economy	14000.00
0005432530046	30584	Economy	14000.00
0005432535942	30584	Economy	14000.00
0005432530011	30584	Economy	14000.00
0005435215407	30584	Economy	14000.00
0005435283496	30584	Economy	14000.00
0005435215411	30584	Economy	14000.00
0005434069126	30584	Economy	14000.00
0005434069167	30584	Economy	14000.00
0005432530603	30584	Economy	14000.00
0005432530694	30584	Economy	14000.00
0005435283493	30584	Economy	14000.00
0005434068686	30584	Economy	14000.00
0005432530670	30584	Economy	14000.00
0005434068936	30584	Economy	14000.00
0005434068980	30584	Economy	14000.00
0005435215437	30584	Economy	14000.00
0005432533351	30584	Economy	14000.00
0005432530693	30584	Economy	14000.00
0005434068700	30584	Economy	14000.00
0005432530709	30584	Economy	14000.00
0005435215438	30584	Economy	14000.00
0005434068806	30584	Economy	14000.00
0005434068956	30584	Economy	14000.00
0005434069054	30584	Economy	14000.00
0005432530710	30584	Economy	14000.00
0005432530527	30584	Economy	14000.00
0005435215420	30584	Economy	14000.00
0005434069047	30584	Economy	14000.00
0005435653765	24819	Business	9800.00
0005433368933	24819	Business	9800.00
0005433368934	24819	Business	9800.00
0005433368941	24819	Business	9800.00
0005433368928	24819	Business	9800.00
0005435653897	24819	Business	9800.00
0005433368929	24819	Business	9800.00
0005435653919	24819	Business	9800.00
0005435653849	24819	Economy	3300.00
0005435653725	24819	Economy	3300.00
0005433368922	24819	Economy	3300.00
0005435653848	24819	Economy	3300.00
0005435653820	24819	Economy	3300.00
0005435653726	24819	Economy	3300.00
0005433368920	24819	Economy	3600.00
0005435653881	24819	Economy	3600.00
0005433368916	24819	Economy	3600.00
0005435653870	24819	Economy	3600.00
0005433368944	24819	Economy	3300.00
0005435653987	24819	Economy	3300.00
0005433368937	24819	Economy	3300.00
0005435653796	24819	Economy	3300.00
0005433368926	24819	Economy	3300.00
0005435653951	24819	Economy	3300.00
0005435653992	24819	Economy	3300.00
0005433368918	24819	Economy	3300.00
0005435653885	24819	Economy	3300.00
0005433368931	24819	Economy	3300.00
0005435653864	24819	Economy	3300.00
0005435653946	24819	Economy	3300.00
0005435653611	24819	Economy	3300.00
0005435653869	24819	Economy	3300.00
0005435654006	24819	Economy	3300.00
0005433368925	24819	Economy	3300.00
0005435653941	24819	Economy	3300.00
0005435653940	24819	Economy	3300.00
0005433368924	24819	Economy	3300.00
0005433368927	24819	Economy	3300.00
0005433368938	24819	Economy	3300.00
0005433368919	24819	Economy	3300.00
0005435653900	24819	Economy	3300.00
0005433368932	24819	Economy	3300.00
0005435653819	24819	Economy	3300.00
0005435653918	24819	Economy	3300.00
0005435653867	24819	Economy	3300.00
0005433368942	24819	Economy	3300.00
0005435653797	24819	Economy	3300.00
0005435653952	24819	Economy	3300.00
0005435653830	24819	Economy	3300.00
0005435653913	24819	Economy	3300.00
0005433368939	24819	Economy	3300.00
0005435653886	24819	Economy	3300.00
0005433368935	24819	Economy	3300.00
0005435653879	24819	Economy	3300.00
0005435653795	24819	Economy	3300.00
0005435653945	24819	Economy	3300.00
0005435653722	24819	Economy	3300.00
0005433368930	24819	Economy	3300.00
0005435653766	24819	Economy	3300.00
0005435653866	24819	Economy	3300.00
0005435653825	24819	Economy	3300.00
0005435653901	24819	Economy	3300.00
0005435653858	24819	Economy	3300.00
0005433368940	24819	Economy	3300.00
0005433368923	24819	Economy	3300.00
0005435653826	24819	Economy	3300.00
0005433368921	24819	Economy	3300.00
0005435653794	24819	Economy	3300.00
0005435653997	24819	Economy	3300.00
0005433368917	24819	Economy	3300.00
0005435653998	24819	Economy	3300.00
0005435653808	24819	Economy	3300.00
0005435653904	24819	Economy	3300.00
0005435653757	24819	Economy	3300.00
0005433368943	24819	Economy	3300.00
0005435653903	24819	Economy	3300.00
0005435653993	24819	Economy	3300.00
0005435654001	24819	Economy	3300.00
0005433368936	24819	Economy	3300.00
0005435949855	6597	Economy	20600.00
0005435949853	6597	Economy	18700.00
0005435949856	6597	Economy	18700.00
0005435949861	6597	Economy	18700.00
0005435949859	6597	Economy	18700.00
0005435949862	6597	Economy	18700.00
0005435949858	6597	Economy	18700.00
0005435949860	6597	Economy	18700.00
0005435949857	6597	Economy	18700.00
0005435949863	6597	Economy	18700.00
0005435949864	6597	Economy	18700.00
0005435949854	6597	Economy	18700.00
0005434980623	2030	Economy	10500.00
0005434980628	2030	Economy	10500.00
0005434980625	2030	Economy	10500.00
0005434980627	2030	Economy	9500.00
0005434980631	2030	Economy	9500.00
0005434980629	2030	Economy	9500.00
0005434980633	2030	Economy	9500.00
0005434980621	2030	Economy	9500.00
0005434980624	2030	Economy	9500.00
0005434980618	2030	Economy	9500.00
0005434980619	2030	Economy	9500.00
0005434980630	2030	Economy	9500.00
0005434980626	2030	Economy	9500.00
0005434980634	2030	Economy	9500.00
0005434980635	2030	Economy	9500.00
0005434980620	2030	Economy	9500.00
0005434980622	2030	Economy	9500.00
0005434980632	2030	Economy	9500.00
0005434980355	23573	Economy	10500.00
0005434980464	23573	Economy	10500.00
0005434980344	23573	Economy	10500.00
0005434980309	23573	Economy	9500.00
0005434980170	23573	Economy	9500.00
0005434980307	23573	Economy	9500.00
0005434980222	23573	Economy	9500.00
0005434980255	23573	Economy	9500.00
0005434980169	23573	Economy	9500.00
0005434980277	23573	Economy	9500.00
0005434980317	23573	Economy	9500.00
0005434980359	23573	Economy	9500.00
0005434980334	23573	Economy	9500.00
0005434980405	23573	Economy	9500.00
0005434980328	23573	Economy	9500.00
0005435801764	23573	Economy	9500.00
0005434980278	23573	Economy	9500.00
0005434980389	23573	Economy	9500.00
0005434980395	23573	Economy	9500.00
0005434980325	23573	Economy	9500.00
0005434980221	23573	Economy	9500.00
0005434980343	23573	Economy	9500.00
0005435801756	23573	Economy	9500.00
0005434980308	23573	Economy	9500.00
0005434980374	23573	Economy	9500.00
0005435801763	23573	Economy	9500.00
0005434980326	23573	Economy	9500.00
0005434980321	23573	Economy	9500.00
0005434980327	23573	Economy	9500.00
0005434980372	23573	Economy	9500.00
0005434980413	23573	Economy	9500.00
0005434980373	23573	Economy	9500.00
0005434952634	2601	Economy	5300.00
0005433256463	2602	Economy	5300.00
0005433256464	2602	Economy	5300.00
0005434952618	28231	Economy	5300.00
0005433256488	28231	Economy	5300.00
0005433112419	19738	Economy	8700.00
0005434302877	19738	Economy	8700.00
0005433112420	19738	Economy	8700.00
0005434302878	19738	Economy	8700.00
0005434302880	19738	Economy	8700.00
0005434139729	11919	Business	9700.00
0005434139981	11919	Business	9700.00
0005434139640	11919	Business	9700.00
0005434139794	11919	Business	9700.00
0005434139503	11919	Business	9700.00
0005434139612	11919	Business	9700.00
0005434139786	11919	Business	9700.00
0005434139570	11919	Business	9700.00
0005434139476	11919	Business	9700.00
0005434139898	11919	Business	9700.00
0005434139615	11919	Business	9700.00
0005434139987	11919	Business	9700.00
0005434139850	11919	Economy	3200.00
0005434139946	11919	Economy	3200.00
0005434139782	11919	Economy	3200.00
0005434139858	11919	Economy	3200.00
0005434139826	11919	Economy	3200.00
0005434139730	11919	Economy	3200.00
0005434139886	11919	Economy	3500.00
0005434139734	11919	Economy	3500.00
0005434139823	11919	Economy	3500.00
0005434139925	11919	Economy	3500.00
0005434139812	11919	Economy	3500.00
0005434139795	11919	Economy	3200.00
0005434139536	11919	Economy	3200.00
0005434139904	11919	Economy	3200.00
0005434139939	11919	Economy	3200.00
0005434139662	11919	Economy	3200.00
0005434139824	11919	Economy	3200.00
0005434139626	11919	Economy	3200.00
0005434139771	11919	Economy	3200.00
0005434139767	11919	Economy	3200.00
0005434139554	11919	Economy	3200.00
0005434139638	11919	Economy	3200.00
0005434139623	11919	Economy	3200.00
0005434139977	11919	Economy	3200.00
0005434139887	11919	Economy	3200.00
0005434139704	11919	Economy	3200.00
0005434139518	11919	Economy	3200.00
0005434139639	11919	Economy	3200.00
0005434139867	11919	Economy	3200.00
0005434139703	11919	Economy	3200.00
0005434139613	11919	Economy	3200.00
0005434139787	11919	Economy	3200.00
0005434140041	11919	Economy	3200.00
0005434139885	11919	Economy	3200.00
0005434140000	11919	Economy	3200.00
0005434139827	11919	Economy	3200.00
0005434139492	11919	Economy	3200.00
0005434139810	11919	Economy	3200.00
0005434139766	11919	Economy	3200.00
0005434139714	11919	Economy	3200.00
0005434139755	11919	Economy	3200.00
0005434139502	11919	Economy	3200.00
0005434139814	11919	Economy	3200.00
0005434139733	11919	Economy	3200.00
0005434139368	11919	Economy	3200.00
0005434139813	11919	Economy	3200.00
0005434139811	11919	Economy	3200.00
0005434139747	11919	Economy	3200.00
0005434139857	11919	Economy	3200.00
0005434139275	11919	Economy	3200.00
0005434139942	11919	Economy	3200.00
0005434139728	11919	Economy	3200.00
0005434139793	11919	Economy	3200.00
0005434139976	11919	Economy	3200.00
0005434139690	11919	Economy	3200.00
0005434139748	11919	Economy	3200.00
0005434139943	11919	Economy	3200.00
0005434140001	11919	Economy	3200.00
0005434139663	11919	Economy	3200.00
0005434139866	11919	Economy	3200.00
0005434139822	11919	Economy	3200.00
0005434139750	11919	Economy	3200.00
0005434139680	11919	Economy	3200.00
0005434139815	11919	Economy	3200.00
0005434139364	11919	Economy	3200.00
0005434139555	11919	Economy	3200.00
0005434139903	11919	Economy	3200.00
0005434139988	11919	Economy	3200.00
0005434139622	11919	Economy	3200.00
0005434139875	11919	Economy	3200.00
0005434139571	11919	Economy	3200.00
0005434139369	11919	Economy	3200.00
0005434140379	28735	Business	9700.00
0005434140398	28735	Business	9700.00
0005434140412	28735	Business	9700.00
0005434140414	28735	Business	9700.00
0005434140396	28735	Business	9700.00
0005434140418	28735	Business	9700.00
0005434140384	28735	Business	9700.00
0005434140428	28735	Business	9700.00
0005434140413	28735	Business	9700.00
0005434140420	28735	Business	9700.00
0005434140408	28735	Economy	3200.00
0005434140442	28735	Economy	3200.00
0005434140434	28735	Economy	3200.00
0005434140429	28735	Economy	3200.00
0005434140436	28735	Economy	3200.00
0005434140421	28735	Economy	3200.00
0005434140393	28735	Economy	3200.00
0005435283567	28735	Economy	3200.00
0005434140404	28735	Economy	3500.00
0005434140411	28735	Economy	3500.00
0005434140417	28735	Economy	3500.00
0005434140446	28735	Economy	3500.00
0005434140394	28735	Economy	3500.00
0005434140381	28735	Economy	3200.00
0005434140377	28735	Economy	3200.00
0005434140405	28735	Economy	3200.00
0005434140380	28735	Economy	3200.00
0005434140438	28735	Economy	3200.00
0005434140437	28735	Economy	3200.00
0005434140403	28735	Economy	3200.00
0005434140416	28735	Economy	3200.00
0005434140386	28735	Economy	3200.00
0005434140445	28735	Economy	3200.00
0005434140431	28735	Economy	3200.00
0005434140439	28735	Economy	3200.00
0005434140443	28735	Economy	3200.00
0005434140426	28735	Economy	3200.00
0005434140432	28735	Economy	3200.00
0005434140449	28735	Economy	3200.00
0005434140451	28735	Economy	3200.00
0005434140448	28735	Economy	3200.00
0005434140425	28735	Economy	3200.00
0005434140397	28735	Economy	3200.00
0005434140450	28735	Economy	3200.00
0005434140406	28735	Economy	3200.00
0005434140395	28735	Economy	3200.00
0005434140441	28735	Economy	3200.00
0005434140392	28735	Economy	3200.00
0005434140409	28735	Economy	3200.00
0005434140388	28735	Economy	3200.00
0005434140423	28735	Economy	3200.00
0005434140422	28735	Economy	3200.00
0005434140378	28735	Economy	3200.00
0005434140407	28735	Economy	3200.00
0005434140387	28735	Economy	3200.00
0005434140427	28735	Economy	3200.00
0005434140440	28735	Economy	3200.00
0005434140400	28735	Economy	3200.00
0005434140435	28735	Economy	3200.00
0005434140376	28735	Economy	3200.00
0005434140383	28735	Economy	3200.00
0005434140419	28735	Economy	3200.00
0005434140391	28735	Economy	3200.00
0005434140389	28735	Economy	3200.00
0005434140399	28735	Economy	3200.00
0005434140415	28735	Economy	3200.00
0005434140402	28735	Economy	3200.00
0005434140385	28735	Economy	3200.00
0005434140410	28735	Economy	3200.00
0005434140433	28735	Economy	3200.00
0005434140390	28735	Economy	3200.00
0005434140444	28735	Economy	3200.00
0005434140401	28735	Economy	3200.00
0005434140382	28735	Economy	3200.00
0005434140424	28735	Economy	3200.00
0005434140430	28735	Economy	3200.00
0005434140447	28735	Economy	3200.00
0005434140452	28735	Economy	3200.00
0005433539106	6822	Economy	9900.00
0005433534560	6822	Economy	9900.00
0005433539107	6822	Economy	9900.00
0005433539109	6822	Economy	9900.00
0005435259834	6822	Economy	9900.00
0005433534559	6822	Economy	9900.00
0005435259835	6822	Economy	9900.00
0005435259851	6822	Economy	9900.00
0005435259852	6822	Economy	9900.00
0005435259853	6822	Economy	9900.00
0005435259855	6822	Economy	9900.00
0005435259856	6822	Economy	9900.00
0005433539108	6822	Economy	9900.00
0005433538995	25002	Economy	10900.00
0005433539032	25002	Economy	9900.00
0005433539074	25002	Economy	9900.00
0005433539022	25002	Economy	9900.00
0005433539041	25002	Economy	9900.00
0005435259881	25002	Economy	9900.00
0005433539056	25002	Economy	9900.00
0005435259882	25002	Economy	9900.00
0005435259880	25002	Economy	9900.00
0005433539042	25002	Economy	9900.00
0005433539049	25002	Economy	9900.00
0005433539070	25002	Economy	9900.00
0005433539021	25002	Economy	9900.00
0005433539037	25002	Economy	9900.00
0005433539036	25002	Economy	9900.00
0005433539050	25002	Economy	9900.00
0005433512183	825	Economy	16100.00
0005432922612	825	Economy	14600.00
0005433512181	825	Economy	14600.00
0005433512180	825	Economy	14600.00
0005432922613	825	Economy	14600.00
0005433512182	825	Economy	14600.00
0005432922601	825	Economy	14600.00
0005433512119	16149	Economy	14600.00
0005433512130	16149	Economy	14600.00
0005432922636	16149	Economy	14600.00
0005433512110	16149	Economy	14600.00
0005433512145	16149	Economy	14600.00
0005432922637	16149	Economy	14600.00
0005433512128	16149	Economy	14600.00
0005433512098	16149	Economy	14600.00
0005433512129	16149	Economy	14600.00
0005433512114	16149	Economy	14600.00
0005433512113	16149	Economy	14600.00
0005433512118	16149	Economy	14600.00
0005435698138	3699	Economy	7900.00
0005434950653	3699	Economy	7900.00
0005435698139	3699	Economy	7200.00
0005435698133	3699	Economy	7200.00
0005435698134	3699	Economy	7200.00
0005435698136	3699	Economy	7200.00
0005434950654	3699	Economy	7200.00
0005434950657	3699	Economy	7200.00
0005435698131	3699	Economy	7200.00
0005435698135	3699	Economy	7200.00
0005434950656	3699	Economy	7200.00
0005435698127	3699	Economy	7200.00
0005435698132	3699	Economy	7200.00
0005435698130	3699	Economy	7200.00
0005434950655	3699	Economy	7200.00
0005435698129	3699	Economy	7200.00
0005435698126	3699	Economy	7200.00
0005435698137	3699	Economy	7200.00
0005435698128	3699	Economy	7200.00
0005434950652	3699	Economy	7200.00
0005435698044	16294	Economy	7900.00
0005435697851	16294	Economy	7900.00
0005435697842	16294	Economy	7200.00
0005435697879	16294	Economy	7200.00
0005434950585	16294	Economy	7200.00
0005435697862	16294	Economy	7200.00
0005435697951	16294	Economy	7200.00
0005435697833	16294	Economy	7200.00
0005435697969	16294	Economy	7200.00
0005435697849	16294	Economy	7200.00
0005435697875	16294	Economy	7200.00
0005435697897	16294	Economy	7200.00
0005435697768	16294	Economy	7200.00
0005435697797	16294	Economy	7200.00
0005435933582	16294	Economy	7200.00
0005435697834	16294	Economy	7200.00
0005435697817	16294	Economy	7200.00
0005435697938	16294	Economy	7200.00
0005435697850	16294	Economy	7200.00
0005435697770	16294	Economy	7200.00
0005435697860	16294	Economy	7200.00
0005434950633	16294	Economy	7200.00
0005435697877	16294	Economy	7200.00
0005435697846	16294	Economy	7200.00
0005435697956	16294	Economy	7200.00
0005435697974	16294	Economy	7200.00
0005435697980	16294	Economy	7200.00
0005435697916	16294	Economy	7200.00
0005435697917	16294	Economy	7200.00
0005435935130	16294	Economy	7200.00
0005435933583	16294	Economy	7200.00
0005435697835	16294	Economy	7200.00
0005435697876	16294	Economy	7200.00
0005435697745	16294	Economy	7200.00
0005434950609	16294	Economy	7200.00
0005435697815	16294	Economy	7200.00
0005435697894	16294	Economy	7200.00
0005435933584	16294	Economy	7200.00
0005435697771	16294	Economy	7200.00
0005435697847	16294	Economy	7200.00
0005435697859	16294	Economy	7200.00
0005435935131	16294	Economy	7200.00
0005434950632	16294	Economy	7200.00
0005434605005	3987	Economy	21300.00
0005433519587	3987	Economy	21300.00
0005434606930	3987	Economy	21300.00
0005433519586	3987	Economy	19300.00
0005434605004	3987	Economy	19300.00
0005434606929	3987	Economy	19300.00
0005434606928	3987	Economy	19300.00
0005434605003	3987	Economy	19300.00
0005435904717	3987	Economy	19300.00
0005432609847	3987	Economy	19300.00
0005432609845	3987	Economy	19300.00
0005434606931	3987	Economy	19300.00
0005435842346	3987	Economy	19300.00
0005435904718	3987	Economy	19300.00
0005435853649	3987	Economy	19300.00
0005434605006	3987	Economy	19300.00
0005433519585	3987	Economy	19300.00
0005432609846	3987	Economy	19300.00
0005435904725	22061	Economy	21300.00
0005434606890	22061	Economy	21300.00
0005435904911	22061	Economy	19300.00
0005433519545	22061	Economy	19300.00
0005435853664	22061	Economy	19300.00
0005435904910	22061	Economy	19300.00
0005435853663	22061	Economy	19300.00
0005434606889	22061	Economy	19300.00
0005433519547	22061	Economy	19300.00
0005434606891	22061	Economy	19300.00
0005433519537	22061	Economy	19300.00
0005435904912	22061	Economy	19300.00
0005435904724	22061	Economy	19300.00
0005433519553	22061	Economy	19300.00
0005433519546	22061	Economy	19300.00
0005433519551	22061	Economy	19300.00
0005435628821	742	Economy	3700.00
0005433349107	742	Economy	3700.00
0005435628820	742	Economy	3700.00
0005433349108	742	Economy	3700.00
0005435628819	742	Economy	3700.00
0005435628818	742	Economy	3700.00
0005433349109	742	Economy	3700.00
0005433349128	742	Economy	3700.00
0005433349157	15898	Economy	3700.00
0005433349155	15898	Economy	3700.00
0005433349156	15898	Economy	3700.00
0005435628800	15898	Economy	3700.00
0005433349154	15898	Economy	3700.00
0005433349153	15898	Economy	3700.00
0005433349158	15898	Economy	3700.00
0005434445315	17188	Economy	7100.00
0005433158163	17188	Economy	7100.00
0005433158168	17188	Economy	7100.00
0005434445314	17188	Economy	7100.00
0005434446585	17188	Economy	7100.00
0005433159354	17188	Economy	7100.00
0005434446583	17188	Economy	7100.00
0005434446584	17188	Economy	7100.00
0005433159355	17188	Economy	7100.00
0005434445286	17590	Economy	7100.00
0005434445296	17590	Economy	7100.00
0005434445285	17590	Economy	7100.00
0005434445293	17590	Economy	7100.00
0005433158206	17590	Economy	7100.00
0005434445297	17590	Economy	7100.00
0005434445298	17590	Economy	7100.00
0005435133180	7860	Economy	5900.00
0005435383260	7860	Economy	5400.00
0005435383270	7860	Economy	5400.00
0005435383235	7860	Economy	5400.00
0005435133182	7860	Economy	5400.00
0005435383234	7860	Economy	5400.00
0005435133183	7860	Economy	5400.00
0005435383259	7860	Economy	5400.00
0005435133178	7860	Economy	5400.00
0005435133184	7860	Economy	5400.00
0005435133179	7860	Economy	5400.00
0005435133181	7860	Economy	5400.00
0005435133121	33090	Economy	5900.00
0005435133053	33090	Economy	5400.00
0005435133120	33090	Economy	5400.00
0005435133096	33090	Economy	5400.00
0005435133110	33090	Economy	5400.00
0005435133119	33090	Economy	5400.00
0005435383303	33090	Economy	5400.00
0005435133123	33090	Economy	5400.00
0005435383304	33090	Economy	5400.00
0005435133074	33090	Economy	5400.00
0005435383301	33090	Economy	5400.00
0005435133146	33090	Economy	5400.00
0005435133068	33090	Economy	5400.00
0005435383302	33090	Economy	5400.00
0005435390413	7499	Economy	13800.00
0005435160614	7499	Economy	13800.00
0005435160615	7499	Economy	12500.00
0005435160612	7499	Economy	12500.00
0005435160611	7499	Economy	12500.00
0005435160616	7499	Economy	12500.00
0005435160618	7499	Economy	12500.00
0005435160617	7499	Economy	12500.00
0005435390364	7499	Economy	12500.00
0005435160610	7499	Economy	12500.00
0005435160613	7499	Economy	12500.00
0005435390363	7499	Economy	12500.00
0005435390390	7499	Economy	12500.00
0005435160540	29554	Economy	13800.00
0005435160526	29554	Economy	12500.00
0005435160555	29554	Economy	12500.00
0005435160536	29554	Economy	12500.00
0005435160499	29554	Economy	12500.00
0005435160533	29554	Economy	12500.00
0005435160568	29554	Economy	12500.00
0005435160584	29554	Economy	12500.00
0005435160532	29554	Economy	12500.00
0005435160498	29554	Economy	12500.00
0005435160537	29554	Economy	12500.00
0005435160508	29554	Economy	12500.00
0005435160583	29554	Economy	12500.00
0005432394200	18457	Economy	4900.00
0005432398261	18457	Economy	4900.00
0005432394193	18457	Economy	4900.00
0005432394201	18457	Economy	4900.00
0005432398278	18457	Economy	4900.00
0005432398271	18457	Economy	4900.00
0005432394166	18457	Economy	4900.00
0005432394199	18457	Economy	4900.00
0005432394183	18457	Economy	4900.00
0005432398262	18457	Economy	4900.00
0005432394184	18457	Economy	4900.00
0005432394198	18457	Economy	4900.00
0005435179406	27139	Economy	4900.00
0005435179410	27139	Economy	4900.00
0005432398295	27139	Economy	4900.00
0005432398294	27139	Economy	4900.00
0005435179411	27139	Economy	4900.00
0005435178528	27139	Economy	4900.00
0005432400217	27139	Economy	4900.00
0005432400219	27139	Economy	4900.00
0005432400218	27139	Economy	4900.00
0005432398296	27139	Economy	4900.00
0005434552905	9716	Economy	4400.00
0005434552904	9716	Economy	4400.00
0005434552906	9716	Economy	4400.00
0005434191304	9716	Economy	4400.00
0005434552908	9716	Economy	4400.00
0005434552910	9716	Economy	4400.00
0005434552909	9716	Economy	4400.00
0005434552907	9716	Economy	4400.00
0005432661978	21838	Business	92200.00
0005432664195	21838	Business	92200.00
0005432661975	21838	Business	92200.00
0005432663097	21838	Business	92200.00
0005432661986	21838	Business	92200.00
0005432663098	21838	Business	92200.00
0005432661983	21838	Business	92200.00
0005432663096	21838	Business	92200.00
0005432663099	21838	Business	92200.00
0005432661982	21838	Business	92200.00
0005432664189	21838	Economy	30700.00
0005432661980	21838	Economy	30700.00
0005432661988	21838	Economy	30700.00
0005432663090	21838	Economy	30700.00
0005432663100	21838	Economy	30700.00
0005432661979	21838	Economy	30700.00
0005432664193	21838	Economy	30700.00
0005432661984	21838	Economy	30700.00
0005432663092	21838	Economy	30700.00
0005432664188	21838	Economy	30700.00
0005432663094	21838	Economy	30700.00
0005432663088	21838	Economy	30700.00
0005432663095	21838	Economy	30700.00
0005432663089	21838	Economy	30700.00
0005432664190	21838	Economy	30700.00
0005432663093	21838	Economy	30700.00
0005432661987	21838	Economy	30700.00
0005432663086	21838	Economy	30700.00
0005432661985	21838	Economy	30700.00
0005432664196	21838	Economy	30700.00
0005432664197	21838	Economy	30700.00
0005432664198	21838	Economy	30700.00
0005432661977	21838	Economy	30700.00
0005432664199	21838	Economy	30700.00
0005432664194	21838	Economy	30700.00
0005432661981	21838	Economy	30700.00
0005432661976	21838	Economy	30700.00
0005432664191	21838	Economy	30700.00
0005432663087	21838	Economy	30700.00
0005432664200	21838	Economy	30700.00
0005432664192	21838	Economy	30700.00
0005432663091	21838	Economy	30700.00
0005434505266	6519	Business	48400.00
0005435104300	6519	Business	48400.00
0005435104307	6519	Business	48400.00
0005435104288	6519	Business	48400.00
0005435104311	6519	Business	48400.00
0005435104294	6519	Business	48400.00
0005435104283	6519	Business	48400.00
0005434505267	6519	Business	48400.00
0005434505269	6519	Economy	16100.00
0005435104287	6519	Economy	16100.00
0005434505248	6519	Economy	16100.00
0005434505265	6519	Economy	16100.00
0005435104295	6519	Economy	17800.00
0005435104284	6519	Economy	17800.00
0005434505253	6519	Economy	17800.00
0005435104303	6519	Economy	17800.00
0005435104290	6519	Economy	16100.00
0005434505260	6519	Economy	16100.00
0005434505251	6519	Economy	16100.00
0005434505261	6519	Economy	16100.00
0005435104285	6519	Economy	16100.00
0005434505256	6519	Economy	16100.00
0005435104298	6519	Economy	16100.00
0005435104308	6519	Economy	16100.00
0005434505249	6519	Economy	16100.00
0005435104312	6519	Economy	16100.00
0005435104302	6519	Economy	16100.00
0005435104317	6519	Economy	16100.00
0005434505258	6519	Economy	16100.00
0005435104310	6519	Economy	16100.00
0005435104304	6519	Economy	16100.00
0005434505252	6519	Economy	16100.00
0005434505270	6519	Economy	16100.00
0005435104315	6519	Economy	16100.00
0005435104305	6519	Economy	16100.00
0005435104297	6519	Economy	16100.00
0005435104316	6519	Economy	16100.00
0005434505250	6519	Economy	16100.00
0005434505257	6519	Economy	16100.00
0005434505268	6519	Economy	16100.00
0005434505264	6519	Economy	16100.00
0005435104292	6519	Economy	16100.00
0005435104301	6519	Economy	16100.00
0005434505263	6519	Economy	16100.00
0005434505259	6519	Economy	16100.00
0005435104306	6519	Economy	16100.00
0005435104291	6519	Economy	16100.00
0005435104299	6519	Economy	16100.00
0005435104296	6519	Economy	16100.00
0005435104293	6519	Economy	16100.00
0005435104289	6519	Economy	16100.00
0005434505247	6519	Economy	16100.00
0005435104282	6519	Economy	16100.00
0005435104313	6519	Economy	16100.00
0005435104286	6519	Economy	16100.00
0005434505262	6519	Economy	16100.00
0005434505254	6519	Economy	16100.00
0005434505255	6519	Economy	16100.00
0005435104314	6519	Economy	16100.00
0005435104309	6519	Economy	16100.00
0005434504902	22682	Business	48400.00
0005434504891	22682	Business	48400.00
0005434504965	22682	Business	48400.00
0005434504863	22682	Business	48400.00
0005435104044	22682	Economy	16100.00
0005434504918	22682	Economy	16100.00
0005434504607	22682	Economy	16100.00
0005434504876	22682	Economy	16100.00
0005434504835	22682	Economy	16100.00
0005434504966	22682	Economy	17800.00
0005435104061	22682	Economy	17800.00
0005434504809	22682	Economy	17800.00
0005434504925	22682	Economy	16100.00
0005434504757	22682	Economy	16100.00
0005434504867	22682	Economy	16100.00
0005435104054	22682	Economy	16100.00
0005434504947	22682	Economy	16100.00
0005434504837	22682	Economy	16100.00
0005434504969	22682	Economy	16100.00
0005435104021	22682	Economy	16100.00
0005434504786	22682	Economy	16100.00
0005434504970	22682	Economy	16100.00
0005434504948	22682	Economy	16100.00
0005434504901	22682	Economy	16100.00
0005434504934	22682	Economy	16100.00
0005434504785	22682	Economy	16100.00
0005434504701	22682	Economy	16100.00
0005434504890	22682	Economy	16100.00
0005434504728	22682	Economy	16100.00
0005434504756	22682	Economy	16100.00
0005434504877	22682	Economy	16100.00
0005434504758	22682	Economy	16100.00
0005434504801	22682	Economy	16100.00
0005435104022	22682	Economy	16100.00
0005434505008	22682	Economy	16100.00
0005434504915	22682	Economy	16100.00
0005434504808	22682	Economy	16100.00
0005434504781	22682	Economy	16100.00
0005434504888	22682	Economy	16100.00
0005434505031	22682	Economy	16100.00
0005435104043	22682	Economy	16100.00
0005434504920	22682	Economy	16100.00
0005434504779	22682	Economy	16100.00
0005434504900	22682	Economy	16100.00
0005435104042	22682	Economy	16100.00
0005433368594	1690	Business	50000.00
0005435654401	1690	Business	50000.00
0005435654357	1690	Business	50000.00
0005433368636	1690	Business	50000.00
0005433368482	1690	Business	50000.00
0005435654367	1690	Business	50000.00
0005435654402	1690	Business	50000.00
0005435654392	1690	Business	50000.00
0005435654381	1690	Business	50000.00
0005435654379	1690	Business	50000.00
0005435654390	1690	Business	50000.00
0005435654371	1690	Economy	16700.00
0005435654384	1690	Economy	16700.00
0005435654405	1690	Economy	16700.00
0005433368483	1690	Economy	16700.00
0005433368475	1690	Economy	16700.00
0005435654361	1690	Economy	16700.00
0005433368665	1690	Economy	16700.00
0005435654393	1690	Economy	16700.00
0005435654365	1690	Economy	18300.00
0005433368700	1690	Economy	18300.00
0005435654368	1690	Economy	18300.00
0005435654400	1690	Economy	18300.00
0005435790408	1690	Economy	18300.00
0005433368699	1690	Economy	16700.00
0005435654372	1690	Economy	16700.00
0005433368476	1690	Economy	16700.00
0005435654360	1690	Economy	16700.00
0005433368610	1690	Economy	16700.00
0005433368751	1690	Economy	16700.00
0005435790409	1690	Economy	16700.00
0005433368671	1690	Economy	16700.00
0005435654366	1690	Economy	16700.00
0005435654399	1690	Economy	16700.00
0005433368581	1690	Economy	16700.00
0005433368638	1690	Economy	16700.00
0005433368588	1690	Economy	16700.00
0005435654377	1690	Economy	16700.00
0005435654387	1690	Economy	16700.00
0005433368528	1690	Economy	16700.00
0005435654378	1690	Economy	16700.00
0005435654386	1690	Economy	16700.00
0005435654362	1690	Economy	16700.00
0005435654374	1690	Economy	16700.00
0005435654376	1690	Economy	16700.00
0005435654385	1690	Economy	16700.00
0005435654364	1690	Economy	16700.00
0005435654398	1690	Economy	16700.00
0005435654403	1690	Economy	16700.00
0005433368787	1690	Economy	16700.00
0005435654359	1690	Economy	16700.00
0005433368768	1690	Economy	16700.00
0005433368637	1690	Economy	16700.00
0005435654358	1690	Economy	16700.00
0005435654391	1690	Economy	16700.00
0005435654369	1690	Economy	16700.00
0005435654395	1690	Economy	16700.00
0005435654370	1690	Economy	16700.00
0005435654396	1690	Economy	16700.00
0005435654404	1690	Economy	16700.00
0005433368712	1690	Economy	16700.00
0005433368562	1690	Economy	16700.00
0005433368597	1690	Economy	16700.00
0005433368754	1690	Economy	16700.00
0005433368633	1690	Economy	16700.00
0005435654363	1690	Economy	16700.00
0005433368558	1690	Economy	16700.00
0005435654394	1690	Economy	16700.00
0005435654356	1690	Economy	16700.00
0005433368609	1690	Economy	16700.00
0005433368595	1690	Economy	16700.00
0005433368723	1690	Economy	16700.00
0005433368672	1690	Economy	16700.00
0005433368532	1690	Economy	16700.00
0005433368611	1690	Economy	16700.00
0005435654380	1690	Economy	16700.00
0005433368533	1690	Economy	16700.00
0005433368750	1690	Economy	16700.00
0005435654389	1690	Economy	16700.00
0005433368662	1690	Economy	16700.00
0005435654355	1690	Economy	16700.00
0005435654382	1690	Economy	16700.00
0005433368646	1690	Economy	16700.00
0005433368632	1690	Economy	16700.00
0005435654397	1690	Economy	16700.00
0005435654388	1690	Economy	16700.00
0005435654373	1690	Economy	16700.00
0005435654383	1690	Economy	16700.00
0005435654375	1690	Economy	16700.00
0005435653794	21665	Business	50000.00
0005435653998	21665	Business	50000.00
0005433368919	21665	Business	50000.00
0005435653897	21665	Business	50000.00
0005433368940	21665	Business	50000.00
0005435653886	21665	Business	50000.00
0005435653611	21665	Business	50000.00
0005433368921	21665	Business	50000.00
0005435653722	21665	Business	50000.00
0005433368924	21665	Business	50000.00
0005433368941	21665	Economy	16700.00
0005435653797	21665	Economy	16700.00
0005433368920	21665	Economy	16700.00
0005435653993	21665	Economy	16700.00
0005435653725	21665	Economy	16700.00
0005435653825	21665	Economy	16700.00
0005435653945	21665	Economy	16700.00
0005435653879	21665	Economy	16700.00
0005435654001	21665	Economy	16700.00
0005433368937	21665	Economy	18300.00
0005433368918	21665	Economy	18300.00
0005433368932	21665	Economy	18300.00
0005435654006	21665	Economy	16700.00
0005435653765	21665	Economy	16700.00
0005435653941	21665	Economy	16700.00
0005435653946	21665	Economy	16700.00
0005433368916	21665	Economy	16700.00
0005435653881	21665	Economy	16700.00
0005435653904	21665	Economy	16700.00
0005433368923	21665	Economy	16700.00
0005433368939	21665	Economy	16700.00
0005435653766	21665	Economy	16700.00
0005433368927	21665	Economy	16700.00
0005433368942	21665	Economy	16700.00
0005435653992	21665	Economy	16700.00
0005433368929	21665	Economy	16700.00
0005435653940	21665	Economy	16700.00
0005433368943	21665	Economy	16700.00
0005435653913	21665	Economy	16700.00
0005435653869	21665	Economy	16700.00
0005435653796	21665	Economy	16700.00
0005435653826	21665	Economy	16700.00
0005433368925	21665	Economy	16700.00
0005435653795	21665	Economy	16700.00
0005435653808	21665	Economy	16700.00
0005435653952	21665	Economy	16700.00
0005435653867	21665	Economy	16700.00
0005435653819	21665	Economy	16700.00
0005435653900	21665	Economy	16700.00
0005433368931	21665	Economy	16700.00
0005435653858	21665	Economy	16700.00
0005433368930	21665	Economy	16700.00
0005433368933	21665	Economy	16700.00
0005433368935	21665	Economy	16700.00
0005435653997	21665	Economy	16700.00
0005435653951	21665	Economy	16700.00
0005435653849	21665	Economy	16700.00
0005435653757	21665	Economy	16700.00
0005435653903	21665	Economy	16700.00
0005435653919	21665	Economy	16700.00
0005435653987	21665	Economy	16700.00
0005433368928	21665	Economy	16700.00
0005435653870	21665	Economy	16700.00
0005433368936	21665	Economy	16700.00
0005433368934	21665	Economy	16700.00
0005435653726	21665	Economy	16700.00
0005435653918	21665	Economy	16700.00
0005435653830	21665	Economy	16700.00
0005435653820	21665	Economy	16700.00
0005435653901	21665	Economy	16700.00
0005435653848	21665	Economy	16700.00
0005433368944	21665	Economy	16700.00
0005433368938	21665	Economy	16700.00
0005433368922	21665	Economy	16700.00
0005435653866	21665	Economy	16700.00
0005433368917	21665	Economy	16700.00
0005435653885	21665	Economy	16700.00
0005433368926	21665	Economy	16700.00
0005435653864	21665	Economy	16700.00
0005435627130	12229	Economy	11200.00
0005433987298	4178	Business	21500.00
0005433987296	4178	Business	21500.00
0005433987287	4178	Business	21500.00
0005433987307	4178	Business	21500.00
0005433987282	4178	Business	21500.00
0005433987292	4178	Business	21500.00
0005433987289	4178	Business	21500.00
0005433987297	4178	Business	21500.00
0005433987312	4178	Economy	7200.00
0005433987303	4178	Economy	7200.00
0005433987300	4178	Economy	7200.00
0005433987286	4178	Economy	7200.00
0005433987301	4178	Economy	7200.00
0005433987308	4178	Economy	7200.00
0005433987281	4178	Economy	7200.00
0005433987311	4178	Economy	7200.00
0005433987291	4178	Economy	7200.00
0005433987310	4178	Economy	7200.00
0005433987304	4178	Economy	7200.00
0005433987294	4178	Economy	7200.00
0005433987309	4178	Economy	7200.00
0005433987293	4178	Economy	7200.00
0005433987284	4178	Economy	7200.00
0005433987314	4178	Economy	7200.00
0005433987302	4178	Economy	7200.00
0005433987280	4178	Economy	7200.00
0005433987279	4178	Economy	7200.00
0005433987299	4178	Economy	7200.00
0005433987295	4178	Economy	7200.00
0005433987290	4178	Economy	7200.00
0005433987313	4178	Economy	7200.00
0005433987285	4178	Economy	7200.00
0005433987283	4178	Economy	7200.00
0005433987288	4178	Economy	7200.00
0005433987305	4178	Economy	7200.00
0005433987306	4178	Economy	7200.00
0005433986875	25669	Business	21500.00
0005433986646	25669	Business	21500.00
0005433987127	25669	Business	21500.00
0005433986812	25669	Business	21500.00
0005433986776	25669	Business	21500.00
0005435788825	25669	Economy	7200.00
0005433986692	25669	Economy	7200.00
0005433986568	25669	Economy	7200.00
0005433986851	25669	Economy	7200.00
0005435788823	25669	Economy	7200.00
0005433986834	25669	Economy	7200.00
0005433987105	25669	Economy	7900.00
0005433986777	25669	Economy	7200.00
0005433987031	25669	Economy	7200.00
0005433986854	25669	Economy	7200.00
0005433986816	25669	Economy	7200.00
0005433986911	25669	Economy	7200.00
0005433986700	25669	Economy	7200.00
0005433986603	25669	Economy	7200.00
0005433986522	25669	Economy	7200.00
0005433986787	25669	Economy	7200.00
0005433986602	25669	Economy	7200.00
0005435788814	25669	Economy	7200.00
0005433986905	25669	Economy	7200.00
0005433986917	25669	Economy	7200.00
0005433986606	25669	Economy	7200.00
0005435788824	25669	Economy	7200.00
0005433987000	25669	Economy	7200.00
0005433986524	25669	Economy	7200.00
0005433986924	25669	Economy	7200.00
0005433987042	25669	Economy	7200.00
0005433987032	25669	Economy	7200.00
0005433987188	25669	Economy	7200.00
0005433986782	25669	Economy	7200.00
0005433986918	25669	Economy	7200.00
0005433986567	25669	Economy	7200.00
0005433986891	25669	Economy	7200.00
0005433986913	25669	Economy	7200.00
0005433986974	25669	Economy	7200.00
0005433986715	25669	Economy	7200.00
0005433986836	25669	Economy	7200.00
0005433987187	25669	Economy	7200.00
0005433986793	25669	Economy	7200.00
0005433986716	25669	Economy	7200.00
0005433986604	25669	Economy	7200.00
0005433986811	25669	Economy	7200.00
0005433986957	25669	Economy	7200.00
0005435720850	21241	Economy	10400.00
0005435719583	21241	Economy	9400.00
0005435720851	21241	Economy	9400.00
0005435719580	21241	Economy	9400.00
0005435719584	21241	Economy	9400.00
0005435720165	24777	Economy	10400.00
0005435720164	24777	Economy	9400.00
0005435719601	24777	Economy	9400.00
0005435719600	24777	Economy	9400.00
0005434516133	9025	Economy	26000.00
0005434190431	9025	Economy	26000.00
0005434516138	9025	Economy	23600.00
0005434190445	9025	Economy	23600.00
0005434190441	9025	Economy	23600.00
0005434190440	9025	Economy	23600.00
0005434190444	9025	Economy	23600.00
0005434516139	9025	Economy	23600.00
0005434516136	9025	Economy	23600.00
0005434190430	9025	Economy	23600.00
0005434190442	9025	Economy	23600.00
0005434190452	9025	Economy	23600.00
0005434516135	9025	Economy	23600.00
0005434190436	9025	Economy	23600.00
0005434190446	9025	Economy	23600.00
0005434516137	9025	Economy	23600.00
0005434516134	9025	Economy	23600.00
0005434190451	9025	Economy	23600.00
0005432663072	17826	Business	18000.00
0005432667495	17826	Business	18000.00
0005432655799	17826	Business	18000.00
0005432869716	17826	Economy	6000.00
0005432655834	17826	Economy	6000.00
0005432658638	17826	Economy	6000.00
0005432869713	17826	Economy	6000.00
0005432655800	17826	Economy	6600.00
0005432655778	17826	Economy	6600.00
0005432663074	17826	Economy	6600.00
0005432655777	17826	Economy	6000.00
0005432663073	17826	Economy	6000.00
0005432869715	17826	Economy	6000.00
0005432666435	17826	Economy	6000.00
0005432663071	17826	Economy	6000.00
0005434151790	17826	Economy	6000.00
0005432659746	17826	Economy	6000.00
0005432869714	17826	Economy	6000.00
0005432658639	17826	Economy	6000.00
0005432655762	17826	Economy	6000.00
0005432655746	17826	Economy	6000.00
0005432667489	17826	Economy	6000.00
0005432663085	17826	Economy	6000.00
0005432666431	17826	Economy	6000.00
0005432663084	17826	Economy	6000.00
0005432659754	17826	Economy	6000.00
0005434151789	17826	Economy	6000.00
0005432655788	17826	Economy	6000.00
0005432664174	17826	Economy	6000.00
0005432655763	17826	Economy	6000.00
0005434151740	26328	Business	18000.00
0005432665331	26328	Business	18000.00
0005432659764	26328	Business	18000.00
0005432869622	26328	Business	18000.00
0005432655859	26328	Business	18000.00
0005432869652	26328	Economy	6000.00
0005432655857	26328	Economy	6000.00
0005432667511	26328	Economy	6600.00
0005432869629	26328	Economy	6000.00
0005432667512	26328	Economy	6000.00
0005434151752	26328	Economy	6000.00
0005432658648	26328	Economy	6000.00
0005432655853	26328	Economy	6000.00
0005432869630	26328	Economy	6000.00
0005434151761	26328	Economy	6000.00
0005432660875	26328	Economy	6000.00
0005432660876	26328	Economy	6000.00
0005432655858	26328	Economy	6000.00
0005432869619	26328	Economy	6000.00
0005432869620	26328	Economy	6000.00
0005432655855	26328	Economy	6000.00
0005432657534	26328	Economy	6000.00
0005432655854	26328	Economy	6000.00
0005432660874	26328	Economy	6000.00
0005432869655	26328	Economy	6000.00
0005432655856	26328	Economy	6000.00
0005434151751	26328	Economy	6000.00
0005432869656	26328	Economy	6000.00
0005432655852	26328	Economy	6000.00
0005432658649	26328	Economy	6000.00
0005434151753	26328	Economy	6000.00
0005432657533	26328	Economy	6000.00
0005432869637	26328	Economy	6000.00
0005432905237	3100	Business	16100.00
0005432848888	3100	Business	16100.00
0005433439087	3100	Business	16100.00
0005433439089	3100	Business	16100.00
0005432287331	3100	Business	16100.00
0005433439090	3100	Business	16100.00
0005432329981	3100	Economy	5400.00
0005432287332	3100	Economy	5400.00
0005432848878	3100	Economy	5400.00
0005432329992	3100	Economy	5400.00
0005432329982	3100	Economy	5400.00
0005432329977	3100	Economy	5400.00
0005432848865	3100	Economy	5400.00
0005432848887	3100	Economy	5900.00
0005433439091	3100	Economy	5900.00
0005432329989	3100	Economy	5900.00
0005432329978	3100	Economy	5400.00
0005433439088	3100	Economy	5400.00
0005432329983	3100	Economy	5400.00
0005433439096	3100	Economy	5400.00
0005432329997	3100	Economy	5400.00
0005432329993	3100	Economy	5400.00
0005432329986	3100	Economy	5400.00
0005432329995	3100	Economy	5400.00
0005432329976	3100	Economy	5400.00
0005432329990	3100	Economy	5400.00
0005432905218	3100	Economy	5400.00
0005432329998	3100	Economy	5400.00
0005432329980	3100	Economy	5400.00
0005433439092	3100	Economy	5400.00
0005432848873	3100	Economy	5400.00
0005432329994	3100	Economy	5400.00
0005432329974	3100	Economy	5400.00
0005433439086	3100	Economy	5400.00
0005433439093	3100	Economy	5400.00
0005432329988	3100	Economy	5400.00
0005432905268	3100	Economy	5400.00
0005432848864	3100	Economy	5400.00
0005433439095	3100	Economy	5400.00
0005432329984	3100	Economy	5400.00
0005432329991	3100	Economy	5400.00
0005432329996	3100	Economy	5400.00
0005432905217	3100	Economy	5400.00
0005432905267	3100	Economy	5400.00
0005432329979	3100	Economy	5400.00
0005432329975	3100	Economy	5400.00
0005433439094	3100	Economy	5400.00
0005432329987	3100	Economy	5400.00
0005432329985	3100	Economy	5400.00
0005432287333	3100	Economy	5400.00
0005433439003	31158	Business	16100.00
0005432329749	31158	Business	16100.00
0005432329400	31158	Business	16100.00
0005432329620	31158	Business	16100.00
0005432329592	31158	Business	16100.00
0005432329474	31158	Business	16100.00
0005432329663	31158	Business	16100.00
0005432329583	31158	Business	16100.00
0005432329601	31158	Business	16100.00
0005432329722	31158	Business	16100.00
0005432329581	31158	Business	16100.00
0005433439027	31158	Business	16100.00
0005432329737	31158	Economy	5400.00
0005433438979	31158	Economy	5400.00
0005432329564	31158	Economy	5400.00
0005432329692	31158	Economy	5400.00
0005432905285	31158	Economy	5900.00
0005432329673	31158	Economy	5900.00
0005432329525	31158	Economy	5900.00
0005432329514	31158	Economy	5400.00
0005432329504	31158	Economy	5400.00
0005433439004	31158	Economy	5400.00
0005432329594	31158	Economy	5400.00
0005432329524	31158	Economy	5400.00
0005433438978	31158	Economy	5400.00
0005433439019	31158	Economy	5400.00
0005432329736	31158	Economy	5400.00
0005432329568	31158	Economy	5400.00
0005433438996	31158	Economy	5400.00
0005432905284	31158	Economy	5400.00
0005432329442	31158	Economy	5400.00
0005432329472	31158	Economy	5400.00
0005432329475	31158	Economy	5400.00
0005432329779	31158	Economy	5400.00
0005432329696	31158	Economy	5400.00
0005432329463	31158	Economy	5400.00
0005432329437	31158	Economy	5400.00
0005432329793	31158	Economy	5400.00
0005432329478	31158	Economy	5400.00
0005432329584	31158	Economy	5400.00
0005432329542	31158	Economy	5400.00
0005432905287	31158	Economy	5400.00
0005432905286	31158	Economy	5400.00
0005432329408	31158	Economy	5400.00
0005432329780	31158	Economy	5400.00
0005433438974	31158	Economy	5400.00
0005432905283	31158	Economy	5400.00
0005432329537	31158	Economy	5400.00
0005432329666	31158	Economy	5400.00
0005432329761	31158	Economy	5400.00
0005432329697	31158	Economy	5400.00
0005432329277	31158	Economy	5400.00
0005432329627	31158	Economy	5400.00
0005432329626	31158	Economy	5400.00
0005432054388	31158	Economy	5400.00
0005432054389	31158	Economy	5400.00
0005432329536	31158	Economy	5400.00
0005432329576	31158	Economy	5400.00
0005432329794	31158	Economy	5400.00
0005432329543	31158	Economy	5400.00
0005432329653	31158	Economy	5400.00
0005432329600	31158	Economy	5400.00
0005432054390	31158	Economy	5400.00
0005432329541	31158	Economy	5400.00
0005432329605	31158	Economy	5400.00
0005432329409	31158	Economy	5400.00
0005432329503	31158	Economy	5400.00
0005433439049	31158	Economy	5400.00
0005432329795	31158	Economy	5400.00
0005435999813	6188	Business	124600.00
0005435999795	6188	Business	124600.00
0005434310130	6188	Business	124600.00
0005435297213	6188	Business	124600.00
0005435488259	6188	Business	124600.00
0005435488248	6188	Economy	41500.00
0005435999804	6188	Economy	41500.00
0005434310126	6188	Economy	41500.00
0005434310124	6188	Economy	41500.00
0005435999798	6188	Economy	41500.00
0005435999801	6188	Economy	41500.00
0005435488141	6188	Economy	41500.00
0005435999808	6188	Economy	41500.00
0005435999810	6188	Economy	41500.00
0005435999799	6188	Economy	41500.00
0005434310129	6188	Economy	41500.00
0005435488257	6188	Economy	41500.00
0005435488245	6188	Economy	41500.00
0005435999803	6188	Economy	41500.00
0005435488291	6188	Economy	41500.00
0005435488239	6188	Economy	41500.00
0005435999802	6188	Economy	41500.00
0005434310123	6188	Economy	45700.00
0005435999815	6188	Economy	45700.00
0005435297194	6188	Economy	41500.00
0005435297212	6188	Economy	41500.00
0005435297210	6188	Economy	41500.00
0005435297202	6188	Economy	41500.00
0005435999800	6188	Economy	41500.00
0005435488273	6188	Economy	41500.00
0005435297208	6188	Economy	41500.00
0005435297192	6188	Economy	41500.00
0005435488271	6188	Economy	41500.00
0005435488193	6188	Economy	41500.00
0005435999814	6188	Economy	41500.00
0005434310125	6188	Economy	41500.00
0005435488274	6188	Economy	41500.00
0005435999806	6188	Economy	41500.00
0005435488234	6188	Economy	41500.00
0005435488194	6188	Economy	41500.00
0005435999805	6188	Economy	41500.00
0005434310127	6188	Economy	41500.00
0005435999807	6188	Economy	41500.00
0005435488181	6188	Economy	41500.00
0005435488215	6188	Economy	41500.00
0005435999797	6188	Economy	41500.00
0005435488180	6188	Economy	41500.00
0005435999796	6188	Economy	41500.00
0005435488272	6188	Economy	41500.00
0005435999812	6188	Economy	41500.00
0005435999809	6188	Economy	41500.00
0005434310128	6188	Economy	41500.00
0005435999811	6188	Economy	41500.00
0005435488432	19559	Business	124600.00
0005434309982	19559	Business	124600.00
0005435999609	19559	Business	124600.00
0005435999597	19559	Business	124600.00
0005435999644	19559	Business	124600.00
0005435999528	19559	Business	124600.00
0005435488433	19559	Business	124600.00
0005434310002	19559	Economy	41500.00
0005435488437	19559	Economy	41500.00
0005434310042	19559	Economy	41500.00
0005435488425	19559	Economy	41500.00
0005435488430	19559	Economy	41500.00
0005434310036	19559	Economy	41500.00
0005435297255	19559	Economy	41500.00
0005435488426	19559	Economy	41500.00
0005434310020	19559	Economy	41500.00
0005435999634	19559	Economy	41500.00
0005435999639	19559	Economy	41500.00
0005435999584	19559	Economy	41500.00
0005435999478	19559	Economy	41500.00
0005435999643	19559	Economy	41500.00
0005434310026	19559	Economy	41500.00
0005434310014	19559	Economy	41500.00
0005435488424	19559	Economy	41500.00
0005435488431	19559	Economy	41500.00
0005435999479	19559	Economy	41500.00
0005435999592	19559	Economy	41500.00
0005435999526	19559	Economy	41500.00
0005434310051	19559	Economy	41500.00
0005435999477	19559	Economy	41500.00
0005435488427	19559	Economy	45700.00
0005434309993	19559	Economy	45700.00
0005435488438	19559	Economy	45700.00
0005434310033	19559	Economy	45700.00
0005434310063	19559	Economy	41500.00
0005434309984	19559	Economy	41500.00
0005435999524	19559	Economy	41500.00
0005434309962	19559	Economy	41500.00
0005435999527	19559	Economy	41500.00
0005435999617	19559	Economy	41500.00
0005434310060	19559	Economy	41500.00
0005434310029	19559	Economy	41500.00
0005434309983	19559	Economy	41500.00
0005435999553	19559	Economy	41500.00
0005435999593	19559	Economy	41500.00
0005434309961	19559	Economy	41500.00
0005435297252	19559	Economy	41500.00
0005435999583	19559	Economy	41500.00
0005435488434	19559	Economy	41500.00
0005435999635	19559	Economy	41500.00
0005434310013	19559	Economy	41500.00
0005435488436	19559	Economy	41500.00
0005434310052	19559	Economy	41500.00
0005434310015	19559	Economy	41500.00
0005435999645	19559	Economy	41500.00
0005435488429	19559	Economy	41500.00
0005435999525	19559	Economy	41500.00
0005435488435	19559	Economy	41500.00
0005434309994	19559	Economy	41500.00
0005434310001	19559	Economy	41500.00
0005434310025	19559	Economy	41500.00
0005435297254	19559	Economy	41500.00
0005434310061	19559	Economy	41500.00
0005435999604	19559	Economy	41500.00
0005434310037	19559	Economy	41500.00
0005434309992	19559	Economy	41500.00
0005435488428	19559	Economy	41500.00
0005434309995	19559	Economy	41500.00
0005435297253	19559	Economy	41500.00
0005435508799	1565	Business	86000.00
0005435518428	1565	Business	86000.00
0005435508792	1565	Business	86000.00
0005434566289	1565	Business	86000.00
0005434566292	1565	Business	86000.00
0005435508789	1565	Business	86000.00
0005435518430	1565	Economy	28700.00
0005435508798	1565	Economy	28700.00
0005435502923	1565	Economy	28700.00
0005435502927	1565	Economy	28700.00
0005435508794	1565	Economy	28700.00
0005435508788	1565	Economy	28700.00
0005435502930	1565	Economy	31500.00
0005435508803	1565	Economy	31500.00
0005435502936	1565	Economy	28700.00
0005435502929	1565	Economy	28700.00
0005435508802	1565	Economy	28700.00
0005435508800	1565	Economy	28700.00
0005435518427	1565	Economy	28700.00
0005435502933	1565	Economy	28700.00
0005435508790	1565	Economy	28700.00
0005435502925	1565	Economy	28700.00
0005435508797	1565	Economy	28700.00
0005433186270	1565	Economy	28700.00
0005434566291	1565	Economy	28700.00
0005435518434	1565	Economy	28700.00
0005433186269	1565	Economy	28700.00
0005435502931	1565	Economy	28700.00
0005435518429	1565	Economy	28700.00
0005435518423	1565	Economy	28700.00
0005435518426	1565	Economy	28700.00
0005435518431	1565	Economy	28700.00
0005435518432	1565	Economy	28700.00
0005433186299	1565	Economy	28700.00
0005435502924	1565	Economy	28700.00
0005435502926	1565	Economy	28700.00
0005435508801	1565	Economy	28700.00
0005435518424	1565	Economy	28700.00
0005433186275	1565	Economy	28700.00
0005435518433	1565	Economy	28700.00
0005435508791	1565	Economy	28700.00
0005435518425	1565	Economy	28700.00
0005435508796	1565	Economy	28700.00
0005435518435	1565	Economy	28700.00
0005435502935	1565	Economy	28700.00
0005434566290	1565	Economy	28700.00
0005435502928	1565	Economy	28700.00
0005435502932	1565	Economy	28700.00
0005435502934	1565	Economy	28700.00
0005435508795	1565	Economy	28700.00
0005435508793	1565	Economy	28700.00
0005435502767	20862	Business	86000.00
0005435502657	20862	Business	86000.00
0005435529556	20862	Business	86000.00
0005433186358	20862	Business	86000.00
0005435545894	20862	Business	86000.00
0005434566194	20862	Business	86000.00
0005435545870	20862	Business	86000.00
0005435529680	20862	Business	86000.00
0005433186362	20862	Economy	28700.00
0005434566199	20862	Economy	28700.00
0005434566195	20862	Economy	28700.00
0005435545893	20862	Economy	28700.00
0005435502787	20862	Economy	28700.00
0005434566193	20862	Economy	28700.00
0005435529681	20862	Economy	31500.00
0005435529717	20862	Economy	31500.00
0005435502752	20862	Economy	28700.00
0005435545867	20862	Economy	28700.00
0005435529675	20862	Economy	28700.00
0005435529616	20862	Economy	28700.00
0005435502744	20862	Economy	28700.00
0005435502670	20862	Economy	28700.00
0005435502612	20862	Economy	28700.00
0005435529629	20862	Economy	28700.00
0005435529614	20862	Economy	28700.00
0005435502654	20862	Economy	28700.00
0005435502656	20862	Economy	28700.00
0005435545882	20862	Economy	28700.00
0005435545895	20862	Economy	28700.00
0005434566206	20862	Economy	28700.00
0005435502611	20862	Economy	28700.00
0005435545865	20862	Economy	28700.00
0005435502732	20862	Economy	28700.00
0005435502655	20862	Economy	28700.00
0005434566196	20862	Economy	28700.00
0005435502690	20862	Economy	28700.00
0005435529708	20862	Economy	28700.00
0005433186359	20862	Economy	28700.00
0005435502802	20862	Economy	28700.00
0005433186361	20862	Economy	28700.00
0005435545869	20862	Economy	28700.00
0005435502786	20862	Economy	28700.00
0005435529674	20862	Economy	28700.00
0005435502780	20862	Economy	28700.00
0005435502788	20862	Economy	28700.00
0005435502722	20862	Economy	28700.00
0005434566205	20862	Economy	28700.00
0005435502783	20862	Economy	28700.00
0005435529654	20862	Economy	28700.00
0005435502766	20862	Economy	28700.00
0005435502733	20862	Economy	28700.00
0005433186360	20862	Economy	28700.00
0005435502653	20862	Economy	28700.00
0005435502768	20862	Economy	28700.00
0005435502669	20862	Economy	28700.00
0005435931679	3873	Economy	21600.00
0005435153932	3873	Economy	19700.00
0005435143000	3873	Economy	19700.00
0005435142998	3873	Economy	19700.00
0005435153929	3873	Economy	19700.00
0005435142999	3873	Economy	19700.00
0005435153933	3873	Economy	19700.00
0005435153931	3873	Economy	19700.00
0005435931672	3873	Economy	19700.00
0005435153930	3873	Economy	19700.00
0005434230044	21892	Economy	21600.00
0005435153870	21892	Economy	19700.00
0005435153874	21892	Economy	19700.00
0005435931707	21892	Economy	19700.00
0005435153889	21892	Economy	19700.00
0005435153880	21892	Economy	19700.00
0005435153875	21892	Economy	19700.00
0005435153872	21892	Economy	19700.00
0005434230045	21892	Economy	19700.00
0005435153869	21892	Economy	19700.00
0005435931708	21892	Economy	19700.00
0005435153887	21892	Economy	19700.00
0005435153873	21892	Economy	19700.00
0005432629269	7196	Economy	14300.00
0005432629264	7196	Economy	14300.00
0005432629260	7196	Economy	14300.00
0005432629271	7196	Economy	13000.00
0005432629262	7196	Economy	13000.00
0005432629263	7196	Economy	13000.00
0005432629261	7196	Economy	13000.00
0005435225758	7196	Economy	13000.00
0005435225712	7196	Economy	13000.00
0005435225765	7196	Economy	13000.00
0005435225753	7196	Economy	13000.00
0005432629267	7196	Economy	13000.00
0005435225774	7196	Economy	13000.00
0005432629265	7196	Economy	13000.00
0005432629268	7196	Economy	13000.00
0005435225781	7196	Economy	13000.00
0005432629266	7196	Economy	13000.00
0005432629259	7196	Economy	13000.00
0005435225766	7196	Economy	13000.00
0005435225711	7196	Economy	13000.00
0005435225751	7196	Economy	13000.00
0005432629270	7196	Economy	13000.00
0005435225752	7196	Economy	13000.00
0005435225744	7196	Economy	13000.00
0005432629133	28143	Economy	14300.00
0005432629239	28143	Economy	14300.00
0005432629156	28143	Economy	13000.00
0005432629141	28143	Economy	13000.00
0005432629151	28143	Economy	13000.00
0005432629159	28143	Economy	13000.00
0005432629181	28143	Economy	13000.00
0005432629209	28143	Economy	13000.00
0005435225805	28143	Economy	13000.00
0005432629155	28143	Economy	13000.00
0005432629182	28143	Economy	13000.00
0005432629179	28143	Economy	13000.00
0005435225806	28143	Economy	13000.00
0005432629152	28143	Economy	13000.00
0005432629130	28143	Economy	13000.00
0005432629178	28143	Economy	13000.00
0005432629132	28143	Economy	13000.00
0005432629134	28143	Economy	13000.00
0005432629131	28143	Economy	13000.00
0005432629195	28143	Economy	13000.00
0005432629204	28143	Economy	13000.00
0005434268016	8721	Economy	10500.00
0005434268033	8721	Economy	10500.00
0005435960157	8721	Economy	10500.00
0005435960160	8721	Economy	10500.00
0005434268017	8721	Economy	10500.00
0005435960156	8721	Economy	10500.00
0005435960159	8721	Economy	10500.00
0005435960158	8721	Economy	10500.00
0005434268042	8721	Economy	10500.00
0005435960125	15249	Economy	11500.00
0005435960126	15249	Economy	10500.00
0005435960133	15249	Economy	10500.00
0005434268056	15249	Economy	10500.00
0005435939977	15249	Economy	10500.00
0005435939978	15249	Economy	10500.00
0005432675564	1216	Business	115000.00
0005432873449	1216	Business	115000.00
0005432677683	1216	Business	115000.00
0005432677684	1216	Business	115000.00
0005432873440	1216	Business	115000.00
0005432675562	1216	Business	115000.00
0005432693907	1216	Business	115000.00
0005432693910	1216	Business	115000.00
0005432873442	1216	Economy	38300.00
0005432675558	1216	Economy	38300.00
0005432873470	1216	Economy	38300.00
0005432693915	1216	Economy	38300.00
0005432693905	1216	Economy	42200.00
0005432675563	1216	Economy	38300.00
0005432675561	1216	Economy	38300.00
0005432693913	1216	Economy	38300.00
0005432677682	1216	Economy	38300.00
0005432675565	1216	Economy	38300.00
0005432693908	1216	Economy	38300.00
0005432675560	1216	Economy	38300.00
0005432693924	1216	Economy	38300.00
0005432873471	1216	Economy	38300.00
0005432675559	1216	Economy	38300.00
0005432693921	1216	Economy	38300.00
0005432693917	1216	Economy	38300.00
0005432693923	1216	Economy	38300.00
0005432693920	1216	Economy	38300.00
0005432693909	1216	Economy	38300.00
0005432693919	1216	Economy	38300.00
0005432693903	1216	Economy	38300.00
0005432873425	1216	Economy	38300.00
0005432693914	1216	Economy	38300.00
0005432693911	1216	Economy	38300.00
0005432677685	1216	Economy	38300.00
0005432693912	1216	Economy	38300.00
0005432693906	1216	Economy	38300.00
0005432675557	1216	Economy	38300.00
0005432693918	1216	Economy	38300.00
0005432693904	1216	Economy	38300.00
0005432693922	1216	Economy	38300.00
0005432677681	1216	Economy	38300.00
0005432693916	1216	Economy	38300.00
0005432693610	17501	Business	115000.00
0005432675369	17501	Business	115000.00
0005432675418	17501	Business	115000.00
0005432693671	17501	Business	115000.00
0005432693626	17501	Business	115000.00
0005432693725	17501	Business	115000.00
0005432693764	17501	Business	115000.00
0005432693741	17501	Business	115000.00
0005432693543	17501	Business	115000.00
0005432675415	17501	Economy	38300.00
0005432677652	17501	Economy	38300.00
0005432677653	17501	Economy	38300.00
0005432693765	17501	Economy	38300.00
0005432675458	17501	Economy	38300.00
0005432693785	17501	Economy	38300.00
0005432693642	17501	Economy	38300.00
0005432693613	17501	Economy	38300.00
0005432675479	17501	Economy	38300.00
0005432693531	17501	Economy	42200.00
0005432675425	17501	Economy	42200.00
0005432693710	17501	Economy	38300.00
0005432693619	17501	Economy	38300.00
0005432693786	17501	Economy	38300.00
0005432693724	17501	Economy	38300.00
0005432693609	17501	Economy	38300.00
0005432693639	17501	Economy	38300.00
0005432675480	17501	Economy	38300.00
0005432675443	17501	Economy	38300.00
0005432693574	17501	Economy	38300.00
0005432873489	17501	Economy	38300.00
0005432693686	17501	Economy	38300.00
0005432675391	17501	Economy	38300.00
0005432693595	17501	Economy	38300.00
0005432693575	17501	Economy	38300.00
0005432693662	17501	Economy	38300.00
0005432693596	17501	Economy	38300.00
0005432693669	17501	Economy	38300.00
0005432873491	17501	Economy	38300.00
0005432693657	17501	Economy	38300.00
0005432693673	17501	Economy	38300.00
0005432693590	17501	Economy	38300.00
0005432675486	17501	Economy	38300.00
0005432693663	17501	Economy	38300.00
0005432675392	17501	Economy	38300.00
0005432693511	17501	Economy	38300.00
0005432675426	17501	Economy	38300.00
0005432675487	17501	Economy	38300.00
0005432693640	17501	Economy	38300.00
0005432873490	17501	Economy	38300.00
0005432675410	17501	Economy	38300.00
0005432693742	17501	Economy	38300.00
0005432873488	17501	Economy	38300.00
0005432693670	17501	Economy	38300.00
0005432675470	17501	Economy	38300.00
0005432693614	17501	Economy	38300.00
0005432693674	17501	Economy	38300.00
0005432675461	17501	Economy	38300.00
0005432675368	17501	Economy	38300.00
0005432693664	17501	Economy	38300.00
0005432693672	17501	Economy	38300.00
0005434435614	1156	Economy	15200.00
0005434435615	1156	Economy	13900.00
0005433156966	1156	Economy	13900.00
0005434435616	1156	Economy	13900.00
0005433156940	1156	Economy	13900.00
0005434435622	1156	Economy	13900.00
0005433156958	1156	Economy	13900.00
0005433156908	1156	Economy	13900.00
0005434435619	1156	Economy	13900.00
0005434435621	1156	Economy	13900.00
0005433156939	1156	Economy	13900.00
0005433156941	1156	Economy	13900.00
0005433156935	1156	Economy	13900.00
0005434435618	1156	Economy	13900.00
0005433156954	1156	Economy	13900.00
0005434435620	1156	Economy	13900.00
0005434435623	1156	Economy	13900.00
0005433156911	1156	Economy	13900.00
0005433156925	1156	Economy	13900.00
0005433156959	1156	Economy	13900.00
0005433156915	1156	Economy	13900.00
0005434435617	1156	Economy	13900.00
0005433156936	1156	Economy	13900.00
0005433156996	17323	Economy	15200.00
0005434435529	17323	Economy	15200.00
0005434435531	17323	Economy	13900.00
0005434435433	17323	Economy	13900.00
0005434435516	17323	Economy	13900.00
0005434435532	17323	Economy	13900.00
0005434435515	17323	Economy	13900.00
0005433157000	17323	Economy	13900.00
0005434435528	17323	Economy	13900.00
0005434435447	17323	Economy	13900.00
0005433156998	17323	Economy	13900.00
0005433156999	17323	Economy	13900.00
0005433156997	17323	Economy	13900.00
0005434435505	17323	Economy	13900.00
0005434435503	17323	Economy	13900.00
0005434435504	17323	Economy	13900.00
0005434435415	17323	Economy	13900.00
0005433156995	17323	Economy	13900.00
0005435928237	4082	Economy	7500.00
0005435087051	4082	Economy	7500.00
0005435928249	4082	Economy	7500.00
0005435087048	4082	Economy	7500.00
0005435087046	4082	Economy	7500.00
0005435087049	4082	Economy	7500.00
0005435928244	4082	Economy	7500.00
0005435928250	4082	Economy	7500.00
0005435087045	4082	Economy	7500.00
0005435087047	4082	Economy	7500.00
0005435087050	4082	Economy	7500.00
0005435928282	24435	Economy	8200.00
0005435928280	24435	Economy	8200.00
0005435928281	24435	Economy	8200.00
0005435086984	24435	Economy	7500.00
0005435086983	24435	Economy	7500.00
0005435086972	24435	Economy	7500.00
0005435086991	24435	Economy	7500.00
0005435087044	24435	Economy	7500.00
0005435086979	24435	Economy	7500.00
0005435086988	24435	Economy	7500.00
0005435086992	24435	Economy	7500.00
0005435086953	24435	Economy	7500.00
0005435087007	24435	Economy	7500.00
0005435551704	11068	Business	144300.00
0005435551712	11068	Business	144300.00
0005435551685	11068	Business	144300.00
0005435098577	11068	Business	144300.00
0005435551650	11068	Business	144300.00
0005435551696	11068	Business	144300.00
0005435098576	11068	Business	144300.00
0005435551701	11068	Economy	52900.00
0005435551687	11068	Economy	52900.00
0005435551681	11068	Economy	52900.00
0005435098596	11068	Economy	48100.00
0005435098595	11068	Economy	48100.00
0005435551707	11068	Economy	48100.00
0005435551708	11068	Economy	48100.00
0005435551651	11068	Economy	48100.00
0005435551698	11068	Economy	48100.00
0005435551688	11068	Economy	48100.00
0005435098588	11068	Economy	48100.00
0005435098594	11068	Economy	48100.00
0005435551706	11068	Economy	48100.00
0005435098593	11068	Economy	48100.00
0005435551700	11068	Economy	48100.00
0005435098589	11068	Economy	48100.00
0005435551691	11068	Economy	48100.00
0005435098587	11068	Economy	48100.00
0005435098597	11068	Economy	48100.00
0005435551705	11068	Economy	48100.00
0005435551682	11068	Economy	48100.00
0005435551667	11068	Economy	48100.00
0005435551714	11068	Economy	48100.00
0005435551699	11068	Economy	48100.00
0005435551697	11068	Economy	48100.00
0005435654512	17018	Business	144300.00
0005435551749	17018	Business	144300.00
0005435654514	17018	Economy	52900.00
0005435551759	17018	Economy	48100.00
0005435551760	17018	Economy	48100.00
0005435654515	17018	Economy	48100.00
0005435551756	17018	Economy	48100.00
0005435098615	17018	Economy	48100.00
0005435551754	17018	Economy	48100.00
0005435098614	17018	Economy	48100.00
0005435551757	17018	Economy	48100.00
0005435654513	17018	Economy	48100.00
0005435098616	17018	Economy	48100.00
0005435551755	17018	Economy	48100.00
0005435551751	17018	Economy	48100.00
0005435098613	17018	Economy	48100.00
0005435551750	17018	Economy	48100.00
0005435551758	17018	Economy	48100.00
0005435551753	17018	Economy	48100.00
0005435551752	17018	Economy	48100.00
0005435098612	17018	Economy	48100.00
0005434964657	18253	Business	203300.00
0005434964647	18253	Business	203300.00
0005434964673	18253	Business	203300.00
0005434964498	18253	Business	203300.00
0005434964677	18253	Business	203300.00
0005433261847	18253	Business	203300.00
0005434964534	18253	Business	203300.00
0005434964523	18253	Business	203300.00
0005434964616	18253	Economy	74500.00
0005434964563	18253	Economy	67800.00
0005434964528	18253	Economy	67800.00
0005434964607	18253	Economy	67800.00
0005433261843	18253	Economy	67800.00
0005434964489	18253	Economy	67800.00
0005433261842	18253	Economy	67800.00
0005433261845	18253	Economy	67800.00
0005434964661	18253	Economy	67800.00
0005434964613	18253	Economy	67800.00
0005434964586	18253	Economy	67800.00
0005434964606	18253	Economy	67800.00
0005434964582	18253	Economy	67800.00
0005434964550	18253	Economy	67800.00
0005434964593	18253	Economy	67800.00
0005434964595	18253	Economy	67800.00
0005434964594	18253	Economy	67800.00
0005434964585	18253	Economy	67800.00
0005433261844	18253	Economy	67800.00
0005434964698	18253	Economy	67800.00
0005434964521	18253	Economy	67800.00
0005434964583	18253	Economy	67800.00
0005434964527	18253	Economy	67800.00
0005434964544	18253	Economy	67800.00
0005434964578	18253	Economy	67800.00
0005434964504	18253	Economy	67800.00
0005433261841	18253	Economy	67800.00
0005434964590	18253	Economy	67800.00
0005433261846	18253	Economy	67800.00
0005434964589	18253	Economy	67800.00
0005434964591	18253	Economy	67800.00
0005434964685	18253	Economy	67800.00
0005434964535	18253	Economy	67800.00
0005434964551	18253	Economy	67800.00
0005434964604	18253	Economy	67800.00
0005433261849	18253	Economy	67800.00
0005434964631	18253	Economy	67800.00
0005434964662	18253	Economy	67800.00
0005434964524	18253	Economy	67800.00
0005433261848	18253	Economy	67800.00
0005434964579	18253	Economy	67800.00
0005434964658	18253	Economy	67800.00
0005434964499	18253	Economy	67800.00
0005435907625	4834	Business	44200.00
0005434626227	4834	Economy	14700.00
0005433194908	4834	Economy	16200.00
0005435907611	4834	Economy	16200.00
0005434626230	4834	Economy	16200.00
0005434626229	4834	Economy	14700.00
0005435907607	4834	Economy	14700.00
0005434626226	4834	Economy	14700.00
0005435907608	4834	Economy	14700.00
0005433194922	4834	Economy	14700.00
0005435907565	4834	Economy	14700.00
0005434626228	4834	Economy	14700.00
0005434626231	4834	Economy	14700.00
0005435907637	4834	Economy	14700.00
0005435907612	4834	Economy	14700.00
0005435907624	4834	Economy	14700.00
0005434626170	32895	Business	44200.00
0005433194978	32895	Economy	14700.00
0005433194985	32895	Economy	14700.00
0005433194976	32895	Economy	14700.00
0005434626159	32895	Economy	14700.00
0005433194982	32895	Economy	14700.00
0005433194986	32895	Economy	16200.00
0005433194987	32895	Economy	16200.00
0005433194984	32895	Economy	14700.00
0005433194977	32895	Economy	14700.00
0005433194990	32895	Economy	14700.00
0005434626171	32895	Economy	14700.00
0005434626149	32895	Economy	14700.00
0005435907646	32895	Economy	14700.00
0005435907648	32895	Economy	14700.00
0005435907647	32895	Economy	14700.00
0005433194989	32895	Economy	14700.00
0005433194988	32895	Economy	14700.00
0005434626181	32895	Economy	14700.00
0005435907649	32895	Economy	14700.00
0005435907650	32895	Economy	14700.00
0005434626180	32895	Economy	14700.00
0005433194981	32895	Economy	14700.00
0005433194983	32895	Economy	14700.00
0005433194979	32895	Economy	14700.00
0005433194980	32895	Economy	14700.00
0005435785974	13750	Economy	3400.00
0005435937552	13750	Economy	3400.00
0005435785921	13750	Economy	3400.00
0005435786130	13750	Economy	3400.00
0005435786116	13750	Economy	3100.00
0005435785950	13750	Economy	3100.00
0005435785886	13750	Economy	3100.00
0005435937553	13750	Economy	3100.00
0005435786037	13750	Economy	3100.00
0005435785909	13750	Economy	3100.00
0005435786018	13750	Economy	3100.00
0005435785924	13750	Economy	3100.00
0005435786017	13750	Economy	3100.00
0005435785938	13750	Economy	3100.00
0005435937551	13750	Economy	3100.00
0005435937555	13750	Economy	3100.00
0005435785994	13750	Economy	3100.00
0005435786028	13750	Economy	3100.00
0005435786002	13750	Economy	3100.00
0005435786079	13750	Economy	3100.00
0005435786029	13750	Economy	3100.00
0005435786093	13750	Economy	3100.00
0005435785973	13750	Economy	3100.00
0005435786040	13750	Economy	3100.00
0005435786036	13750	Economy	3100.00
0005435937554	13750	Economy	3100.00
0005435937549	13750	Economy	3100.00
0005435785891	13750	Economy	3100.00
0005435786051	13750	Economy	3100.00
0005435785992	13750	Economy	3100.00
0005435937557	13750	Economy	3100.00
0005435785932	13750	Economy	3100.00
0005435785937	13750	Economy	3100.00
0005435937550	13750	Economy	3100.00
0005435785984	13750	Economy	3100.00
0005435785892	13750	Economy	3100.00
0005435785949	13750	Economy	3100.00
0005435937556	13750	Economy	3100.00
0005435785890	13750	Economy	3100.00
0005435785908	13750	Economy	3100.00
0005435786063	13750	Economy	3100.00
0005435786050	13750	Economy	3100.00
0005435785914	13750	Economy	3100.00
0005435786016	13750	Economy	3100.00
0005435787391	13750	Economy	3100.00
0005435786102	13750	Economy	3100.00
0005435786190	13750	Economy	3100.00
0005435786030	13750	Economy	3100.00
0005435786191	13750	Economy	3100.00
0005435786019	13750	Economy	3100.00
0005435786296	27419	Economy	3400.00
0005435786293	27419	Economy	3400.00
0005432190735	27419	Economy	3400.00
0005435937458	27419	Economy	3100.00
0005435786290	27419	Economy	3100.00
0005435786299	27419	Economy	3100.00
0005435786283	27419	Economy	3100.00
0005435786295	27419	Economy	3100.00
0005435786292	27419	Economy	3100.00
0005435937464	27419	Economy	3100.00
0005435786286	27419	Economy	3100.00
0005435786291	27419	Economy	3100.00
0005435786282	27419	Economy	3100.00
0005435786285	27419	Economy	3100.00
0005435786287	27419	Economy	3100.00
0005432190733	27419	Economy	3100.00
0005432190737	27419	Economy	3100.00
0005435786304	27419	Economy	3100.00
0005435786302	27419	Economy	3100.00
0005435786294	27419	Economy	3100.00
0005435786298	27419	Economy	3100.00
0005432190734	27419	Economy	3100.00
0005435937463	27419	Economy	3100.00
0005435937441	27419	Economy	3100.00
0005435937460	27419	Economy	3100.00
0005435937469	27419	Economy	3100.00
0005435786303	27419	Economy	3100.00
0005435786297	27419	Economy	3100.00
0005435786301	27419	Economy	3100.00
0005432190736	27419	Economy	3100.00
0005435937442	27419	Economy	3100.00
0005435937459	27419	Economy	3100.00
0005435786289	27419	Economy	3100.00
0005435786300	27419	Economy	3100.00
0005435786288	27419	Economy	3100.00
0005435786284	27419	Economy	3100.00
0005435937461	27419	Economy	3100.00
0005434408598	20285	Business	12000.00
0005434408695	20285	Business	12000.00
0005434409042	20285	Business	12000.00
0005435311511	20285	Business	12000.00
0005434409002	20285	Business	12000.00
0005434408950	20285	Business	12000.00
0005434408980	20285	Business	12000.00
0005434409058	20285	Business	12000.00
0005434409032	20285	Business	12000.00
0005434409043	20285	Business	12000.00
0005434409044	20285	Business	12000.00
0005434409017	20285	Economy	4000.00
0005435311506	20285	Economy	4000.00
0005434408868	20285	Economy	4000.00
0005434408954	20285	Economy	4000.00
0005435311519	20285	Economy	4000.00
0005434409071	20285	Economy	4000.00
0005435311504	20285	Economy	4000.00
0005434408804	20285	Economy	4000.00
0005435311516	20285	Economy	4000.00
0005435311515	20285	Economy	4000.00
0005435311518	20285	Economy	4400.00
0005435311521	20285	Economy	4400.00
0005434409247	20285	Economy	4400.00
0005434408901	20285	Economy	4400.00
0005435311522	20285	Economy	4400.00
0005434408818	20285	Economy	4000.00
0005435311509	20285	Economy	4000.00
0005434409142	20285	Economy	4000.00
0005434409255	20285	Economy	4000.00
0005434409059	20285	Economy	4000.00
0005434408800	20285	Economy	4000.00
0005435311524	20285	Economy	4000.00
0005434408992	20285	Economy	4000.00
0005435311513	20285	Economy	4000.00
0005434408928	20285	Economy	4000.00
0005434408599	20285	Economy	4000.00
0005434408877	20285	Economy	4000.00
0005434408915	20285	Economy	4000.00
0005434408951	20285	Economy	4000.00
0005435311507	20285	Economy	4000.00
0005434408955	20285	Economy	4000.00
0005434409138	20285	Economy	4000.00
0005434409027	20285	Economy	4000.00
0005434408869	20285	Economy	4000.00
0005435311523	20285	Economy	4000.00
0005434408991	20285	Economy	4000.00
0005434409127	20285	Economy	4000.00
0005434409082	20285	Economy	4000.00
0005434408927	20285	Economy	4000.00
0005434409035	20285	Economy	4000.00
0005434409069	20285	Economy	4000.00
0005434408986	20285	Economy	4000.00
0005434409013	20285	Economy	4000.00
0005434409143	20285	Economy	4000.00
0005434408768	20285	Economy	4000.00
0005434408846	20285	Economy	4000.00
0005434409200	20285	Economy	4000.00
0005435311508	20285	Economy	4000.00
0005434409075	20285	Economy	4000.00
0005434409074	20285	Economy	4000.00
0005434409078	20285	Economy	4000.00
0005434408993	20285	Economy	4000.00
0005434409070	20285	Economy	4000.00
0005434409012	20285	Economy	4000.00
0005434408995	20285	Economy	4000.00
0005434408985	20285	Economy	4000.00
0005434408803	20285	Economy	4000.00
0005435311505	20285	Economy	4000.00
0005434408799	20285	Economy	4000.00
0005434409079	20285	Economy	4000.00
0005435311514	20285	Economy	4000.00
0005434409083	20285	Economy	4000.00
0005434408802	20285	Economy	4000.00
0005434409171	20285	Economy	4000.00
0005435311517	20285	Economy	4000.00
0005434409146	20285	Economy	4000.00
0005434408805	20285	Economy	4000.00
0005435311512	20285	Economy	4000.00
0005434409213	20285	Economy	4000.00
0005434408998	20285	Economy	4000.00
0005434409144	20285	Economy	4000.00
0005434409311	20285	Economy	4000.00
0005434408550	20285	Economy	4000.00
0005434409242	20285	Economy	4000.00
0005434408994	20285	Economy	4000.00
0005434408623	20285	Economy	4000.00
0005434408844	20285	Economy	4000.00
0005434409145	20285	Economy	4000.00
0005434408845	20285	Economy	4000.00
0005435311510	20285	Economy	4000.00
0005434409243	20285	Economy	4000.00
0005435311520	20285	Economy	4000.00
0005434409503	26984	Business	12000.00
0005434409535	26984	Business	12000.00
0005434409505	26984	Business	12000.00
0005434409525	26984	Business	12000.00
0005435311302	26984	Business	12000.00
0005435311357	26984	Business	12000.00
0005434409540	26984	Business	12000.00
0005434409523	26984	Business	12000.00
0005434409517	26984	Economy	4000.00
0005434409519	26984	Economy	4000.00
0005434409513	26984	Economy	4000.00
0005434409529	26984	Economy	4000.00
0005434409510	26984	Economy	4000.00
0005434409522	26984	Economy	4000.00
0005434409545	26984	Economy	4000.00
0005435311317	26984	Economy	4000.00
0005435311323	26984	Economy	4400.00
0005434409549	26984	Economy	4400.00
0005434409520	26984	Economy	4400.00
0005434409527	26984	Economy	4400.00
0005434409530	26984	Economy	4400.00
0005435311321	26984	Economy	4000.00
0005434409508	26984	Economy	4000.00
0005434409534	26984	Economy	4000.00
0005434409531	26984	Economy	4000.00
0005435311315	26984	Economy	4000.00
0005435311334	26984	Economy	4000.00
0005434409515	26984	Economy	4000.00
0005434409543	26984	Economy	4000.00
0005432154133	26984	Economy	4000.00
0005434409506	26984	Economy	4000.00
0005435311276	26984	Economy	4000.00
0005434409516	26984	Economy	4000.00
0005435311409	26984	Economy	4000.00
0005434409541	26984	Economy	4000.00
0005434409524	26984	Economy	4000.00
0005435311295	26984	Economy	4000.00
0005434409514	26984	Economy	4000.00
0005434409509	26984	Economy	4000.00
0005434409537	26984	Economy	4000.00
0005435311400	26984	Economy	4000.00
0005434409544	26984	Economy	4000.00
0005434409502	26984	Economy	4000.00
0005435311410	26984	Economy	4000.00
0005434409526	26984	Economy	4000.00
0005434409507	26984	Economy	4000.00
0005434409539	26984	Economy	4000.00
0005435311316	26984	Economy	4000.00
0005434409536	26984	Economy	4000.00
0005434409538	26984	Economy	4000.00
0005434409511	26984	Economy	4000.00
0005434409528	26984	Economy	4000.00
0005432154134	26984	Economy	4000.00
0005435311299	26984	Economy	4000.00
0005434409547	26984	Economy	4000.00
0005434409550	26984	Economy	4000.00
0005435311285	26984	Economy	4000.00
0005434409548	26984	Economy	4000.00
0005434409521	26984	Economy	4000.00
0005434409542	26984	Economy	4000.00
0005434409533	26984	Economy	4000.00
0005434409532	26984	Economy	4000.00
0005434409546	26984	Economy	4000.00
0005435311405	26984	Economy	4000.00
0005434409518	26984	Economy	4000.00
0005434409512	26984	Economy	4000.00
0005435311284	26984	Economy	4000.00
0005435311326	26984	Economy	4000.00
0005434409504	26984	Economy	4000.00
0005434319815	5717	Business	43300.00
0005434311289	5717	Business	43300.00
0005434319821	5717	Business	43300.00
0005434319808	5717	Business	43300.00
0005432109780	5717	Economy	14400.00
0005433124356	5717	Economy	14400.00
0005434319816	5717	Economy	14400.00
0005434319824	5717	Economy	14400.00
0005434319822	5717	Economy	14400.00
0005434319820	5717	Economy	14400.00
0005433124321	5717	Economy	15900.00
0005433124362	5717	Economy	15900.00
0005435297361	5717	Economy	14400.00
0005433124355	5717	Economy	14400.00
0005434319814	5717	Economy	14400.00
0005433124347	5717	Economy	14400.00
0005433124254	5717	Economy	14400.00
0005433124382	5717	Economy	14400.00
0005434319812	5717	Economy	14400.00
0005433124335	5717	Economy	14400.00
0005433124342	5717	Economy	14400.00
0005435297363	5717	Economy	14400.00
0005433124253	5717	Economy	14400.00
0005433124340	5717	Economy	14400.00
0005434319810	5717	Economy	14400.00
0005432109781	5717	Economy	14400.00
0005434319811	5717	Economy	14400.00
0005433124346	5717	Economy	14400.00
0005434319823	5717	Economy	14400.00
0005433124267	5717	Economy	14400.00
0005434319809	5717	Economy	14400.00
0005433124323	5717	Economy	14400.00
0005434319817	5717	Economy	14400.00
0005434319818	5717	Economy	14400.00
0005434319819	5717	Economy	14400.00
0005432109782	5717	Economy	14400.00
0005433124251	5717	Economy	14400.00
0005433124224	5717	Economy	14400.00
0005433124385	5717	Economy	14400.00
0005434319813	5717	Economy	14400.00
0005433124302	5717	Economy	14400.00
0005433124322	5717	Economy	14400.00
0005433124517	15685	Business	43300.00
0005435297387	15685	Business	43300.00
0005433124522	15685	Business	43300.00
0005433124514	15685	Business	43300.00
0005433124513	15685	Economy	14400.00
0005433124511	15685	Economy	14400.00
0005434319637	15685	Economy	14400.00
0005434319687	15685	Economy	14400.00
0005435297389	15685	Economy	15900.00
0005434319635	15685	Economy	15900.00
0005434319686	15685	Economy	15900.00
0005433124512	15685	Economy	14400.00
0005435297388	15685	Economy	14400.00
0005433124520	15685	Economy	14400.00
0005434319636	15685	Economy	14400.00
0005435297392	15685	Economy	14400.00
0005433124516	15685	Economy	14400.00
0005434319732	15685	Economy	14400.00
0005434319649	15685	Economy	14400.00
0005434319652	15685	Economy	14400.00
0005434319709	15685	Economy	14400.00
0005433124521	15685	Economy	14400.00
0005434319638	15685	Economy	14400.00
0005433124510	15685	Economy	14400.00
0005434319653	15685	Economy	14400.00
0005434319624	15685	Economy	14400.00
0005433124509	15685	Economy	14400.00
0005433124515	15685	Economy	14400.00
0005435297390	15685	Economy	14400.00
0005435297391	15685	Economy	14400.00
0005433124518	15685	Economy	14400.00
0005434319683	15685	Economy	14400.00
0005433124508	15685	Economy	14400.00
0005434319625	15685	Economy	14400.00
0005433124519	15685	Economy	14400.00
0005434319672	15685	Economy	14400.00
0005434319643	15685	Economy	14400.00
0005435217742	24988	Economy	17100.00
0005435217743	24988	Economy	15500.00
0005435217754	24988	Economy	15500.00
0005435220350	24988	Economy	15500.00
0005435220351	24988	Economy	15500.00
0005435220354	24988	Economy	15500.00
0005435220348	24988	Economy	15500.00
0005435220347	24988	Economy	15500.00
0005435217758	24988	Economy	15500.00
0005435220346	24988	Economy	15500.00
0005434484532	9015	Economy	24900.00
0005434189298	9015	Economy	24900.00
0005434484533	9015	Economy	24900.00
0005434189289	9015	Economy	24900.00
0005434189307	9015	Economy	24900.00
0005434189285	9015	Economy	24900.00
0005434484531	9015	Economy	24900.00
0005434189294	9015	Economy	24900.00
0005434189299	9015	Economy	24900.00
0005434484534	9015	Economy	24900.00
0005434484474	16642	Economy	24900.00
0005434189336	16642	Economy	24900.00
0005434484504	16642	Economy	24900.00
0005434189337	16642	Economy	24900.00
0005435903223	16642	Economy	24900.00
0005435903222	16642	Economy	24900.00
0005434484503	16642	Economy	24900.00
0005434484475	16642	Economy	24900.00
0005434189338	16642	Economy	24900.00
0005434484472	16642	Economy	24900.00
0005435903224	16642	Economy	24900.00
0005433124510	7587	Business	11100.00
0005433124522	7587	Business	11100.00
0005433124515	7587	Business	11100.00
0005433124509	7587	Economy	3700.00
0005433124521	7587	Economy	3700.00
0005433124520	7587	Economy	3700.00
0005433124514	7587	Economy	3700.00
0005433124513	7587	Economy	3700.00
0005433124516	7587	Economy	3700.00
0005433124517	7587	Economy	3700.00
0005433124519	7587	Economy	3700.00
0005433124512	7587	Economy	3700.00
0005433124518	7587	Economy	3700.00
0005433124511	7587	Economy	3700.00
0005433124508	7587	Economy	3700.00
0005433450579	7588	Business	11100.00
0005432071657	7588	Business	11100.00
0005432693934	7588	Business	11100.00
0005432693943	7588	Business	11100.00
0005433450574	7588	Business	11100.00
0005433450577	7588	Business	11100.00
0005432693942	7588	Economy	3700.00
0005432693936	7588	Economy	3700.00
0005432721654	7588	Economy	3700.00
0005432693935	7588	Economy	3700.00
0005433450585	7588	Economy	3700.00
0005432721651	7588	Economy	4100.00
0005432721643	7588	Economy	4100.00
0005433450582	7588	Economy	4100.00
0005433450578	7588	Economy	4100.00
0005432693930	7588	Economy	3700.00
0005432693927	7588	Economy	3700.00
0005432693938	7588	Economy	3700.00
0005432693939	7588	Economy	3700.00
0005433450575	7588	Economy	3700.00
0005433450584	7588	Economy	3700.00
0005432721653	7588	Economy	3700.00
0005432693929	7588	Economy	3700.00
0005432693931	7588	Economy	3700.00
0005433450586	7588	Economy	3700.00
0005432721650	7588	Economy	3700.00
0005432693937	7588	Economy	3700.00
0005432721644	7588	Economy	3700.00
0005432721648	7588	Economy	3700.00
0005432693941	7588	Economy	3700.00
0005432693926	7588	Economy	3700.00
0005433450576	7588	Economy	3700.00
0005432693928	7588	Economy	3700.00
0005433450581	7588	Economy	3700.00
0005432693933	7588	Economy	3700.00
0005432721645	7588	Economy	3700.00
0005432721646	7588	Economy	3700.00
0005432721652	7588	Economy	3700.00
0005432721647	7588	Economy	3700.00
0005432693940	7588	Economy	3700.00
0005432693932	7588	Economy	3700.00
0005432693925	7588	Economy	3700.00
0005432721649	7588	Economy	3700.00
0005433450583	7588	Economy	3700.00
0005432071658	7588	Economy	3700.00
0005433450580	7588	Economy	3700.00
0005433450399	30361	Business	11100.00
0005433450390	30361	Business	11100.00
0005432693674	30361	Business	11100.00
0005432693786	30361	Business	11100.00
0005432693663	30361	Business	11100.00
0005432693673	30361	Business	11100.00
0005433450447	30361	Business	11100.00
0005433450371	30361	Economy	3700.00
0005432693710	30361	Economy	3700.00
0005432693724	30361	Economy	3700.00
0005432693595	30361	Economy	3700.00
0005432693575	30361	Economy	3700.00
0005433450327	30361	Economy	4100.00
0005432693590	30361	Economy	4100.00
0005432693669	30361	Economy	3700.00
0005432693764	30361	Economy	3700.00
0005433450328	30361	Economy	3700.00
0005432693626	30361	Economy	3700.00
0005433450377	30361	Economy	3700.00
0005433450398	30361	Economy	3700.00
0005433450407	30361	Economy	3700.00
0005432693664	30361	Economy	3700.00
0005433450376	30361	Economy	3700.00
0005433450473	30361	Economy	3700.00
0005432693531	30361	Economy	3700.00
0005432693725	30361	Economy	3700.00
0005432693662	30361	Economy	3700.00
0005432693619	30361	Economy	3700.00
0005432693640	30361	Economy	3700.00
0005432693741	30361	Economy	3700.00
0005433450422	30361	Economy	3700.00
0005433450412	30361	Economy	3700.00
0005432693671	30361	Economy	3700.00
0005433450474	30361	Economy	3700.00
0005433450370	30361	Economy	3700.00
0005433450421	30361	Economy	3700.00
0005432693742	30361	Economy	3700.00
0005432693610	30361	Economy	3700.00
0005433450451	30361	Economy	3700.00
0005432693614	30361	Economy	3700.00
0005433450452	30361	Economy	3700.00
0005432693765	30361	Economy	3700.00
0005432693657	30361	Economy	3700.00
0005432693511	30361	Economy	3700.00
0005432693613	30361	Economy	3700.00
0005432693686	30361	Economy	3700.00
0005432693670	30361	Economy	3700.00
0005432693672	30361	Economy	3700.00
0005433450408	30361	Economy	3700.00
0005432693639	30361	Economy	3700.00
0005432693596	30361	Economy	3700.00
0005432693574	30361	Economy	3700.00
0005432693785	30361	Economy	3700.00
0005432693543	30361	Economy	3700.00
0005432693642	30361	Economy	3700.00
0005432693609	30361	Economy	3700.00
0005432721487	30360	Business	11100.00
0005433124224	30360	Business	11100.00
0005432721509	30360	Business	11100.00
0005432721398	30360	Business	11100.00
0005433722465	30360	Business	11100.00
0005433124342	30360	Business	11100.00
0005432721463	30360	Business	11100.00
0005433722459	30360	Business	11100.00
0005432721520	30360	Business	11100.00
0005432721438	30360	Business	11100.00
0005433722472	30360	Business	11100.00
0005432721450	30360	Economy	3700.00
0005433722450	30360	Economy	3700.00
0005433124302	30360	Economy	3700.00
0005433722457	30360	Economy	3700.00
0005433124346	30360	Economy	3700.00
0005432721403	30360	Economy	3700.00
0005433124355	30360	Economy	3700.00
0005433124323	30360	Economy	3700.00
0005432721494	30360	Economy	4100.00
0005433722469	30360	Economy	4100.00
0005432721567	30360	Economy	4100.00
0005432721488	30360	Economy	4100.00
0005433124254	30360	Economy	4100.00
0005433722463	30360	Economy	3700.00
0005432721508	30360	Economy	3700.00
0005432721589	30360	Economy	3700.00
0005432721436	30360	Economy	3700.00
0005433722470	30360	Economy	3700.00
0005432721538	30360	Economy	3700.00
0005432721459	30360	Economy	3700.00
0005432721472	30360	Economy	3700.00
0005433722451	30360	Economy	3700.00
0005433124385	30360	Economy	3700.00
0005433722455	30360	Economy	3700.00
0005433722467	30360	Economy	3700.00
0005432721551	30360	Economy	3700.00
0005432721481	30360	Economy	3700.00
0005433722458	30360	Economy	3700.00
0005433124321	30360	Economy	3700.00
0005433722454	30360	Economy	3700.00
0005433722456	30360	Economy	3700.00
0005433124335	30360	Economy	3700.00
0005432721451	30360	Economy	3700.00
0005432721397	30360	Economy	3700.00
0005432721479	30360	Economy	3700.00
0005433124340	30360	Economy	3700.00
0005433124267	30360	Economy	3700.00
0005433124251	30360	Economy	3700.00
0005432721496	30360	Economy	3700.00
0005433722473	30360	Economy	3700.00
0005433124356	30360	Economy	3700.00
0005432721568	30360	Economy	3700.00
0005433722453	30360	Economy	3700.00
0005433124362	30360	Economy	3700.00
0005432721606	30360	Economy	3700.00
0005433722471	30360	Economy	3700.00
0005433722464	30360	Economy	3700.00
0005432721439	30360	Economy	3700.00
0005433722449	30360	Economy	3700.00
0005432721437	30360	Economy	3700.00
0005432721495	30360	Economy	3700.00
0005433722462	30360	Economy	3700.00
0005433722452	30360	Economy	3700.00
0005432721480	30360	Economy	3700.00
0005432721331	30360	Economy	3700.00
0005433124253	30360	Economy	3700.00
0005433124382	30360	Economy	3700.00
0005432721519	30360	Economy	3700.00
0005433722466	30360	Economy	3700.00
0005433124322	30360	Economy	3700.00
0005432721505	30360	Economy	3700.00
0005432721554	30360	Economy	3700.00
0005433124347	30360	Economy	3700.00
0005433722460	30360	Economy	3700.00
0005432721401	30360	Economy	3700.00
0005433722468	30360	Economy	3700.00
0005432721467	30360	Economy	3700.00
0005432721537	30360	Economy	3700.00
0005433722461	30360	Economy	3700.00
0005432721368	30360	Economy	3700.00
0005432721458	30360	Economy	3700.00
0005433724935	1369	Business	70400.00
0005433724932	1369	Business	70400.00
0005434515042	1369	Business	70400.00
0005432271085	1369	Business	70400.00
0005433193310	1369	Business	70400.00
0005434587330	1369	Business	70400.00
0005434515045	1369	Economy	23500.00
0005433525347	1369	Economy	23500.00
0005432968889	1369	Economy	23500.00
0005434587326	1369	Economy	23500.00
0005432928106	1369	Economy	23500.00
0005433525346	1369	Economy	23500.00
0005434587320	1369	Economy	23500.00
0005433724934	1369	Economy	25800.00
0005434587327	1369	Economy	25800.00
0005434513655	1369	Economy	23500.00
0005432928107	1369	Economy	23500.00
0005432928097	1369	Economy	23500.00
0005434515043	1369	Economy	23500.00
0005432271084	1369	Economy	23500.00
0005433193339	1369	Economy	23500.00
0005434587332	1369	Economy	23500.00
0005434587325	1369	Economy	23500.00
0005433525344	1369	Economy	23500.00
0005432968887	1369	Economy	23500.00
0005433193379	1369	Economy	23500.00
0005433193309	1369	Economy	23500.00
0005432928104	1369	Economy	23500.00
0005434587324	1369	Economy	23500.00
0005434513654	1369	Economy	23500.00
0005434587329	1369	Economy	23500.00
0005432928105	1369	Economy	23500.00
0005433193280	1369	Economy	23500.00
0005433525345	1369	Economy	23500.00
0005434587333	1369	Economy	23500.00
0005433193296	1369	Economy	23500.00
0005433193331	1369	Economy	23500.00
0005432928094	1369	Economy	23500.00
0005433193380	1369	Economy	23500.00
0005433193295	1369	Economy	23500.00
0005432968888	1369	Economy	23500.00
0005434587331	1369	Economy	23500.00
0005432928096	1369	Economy	23500.00
0005432271083	1369	Economy	23500.00
0005434587322	1369	Economy	23500.00
0005434587328	1369	Economy	23500.00
0005432968886	1369	Economy	23500.00
0005433724933	1369	Economy	23500.00
0005433193332	1369	Economy	23500.00
0005434587321	1369	Economy	23500.00
0005434587323	1369	Economy	23500.00
0005433525343	1369	Economy	23500.00
0005434515044	1369	Economy	23500.00
0005434587178	18496	Business	70400.00
0005433724902	18496	Business	70400.00
0005432928135	18496	Business	70400.00
0005433724903	18496	Business	70400.00
0005433724888	18496	Business	70400.00
0005433525244	18496	Economy	23500.00
0005433724906	18496	Economy	23500.00
0005433724897	18496	Economy	23500.00
0005434587080	18496	Economy	23500.00
0005434587102	18496	Economy	23500.00
0005434587165	18496	Economy	23500.00
0005434587174	18496	Economy	25800.00
0005434587022	18496	Economy	25800.00
0005433193420	18496	Economy	25800.00
0005434587136	18496	Economy	23500.00
0005434587177	18496	Economy	23500.00
0005434587122	18496	Economy	23500.00
0005433193425	18496	Economy	23500.00
0005434587023	18496	Economy	23500.00
0005433724898	18496	Economy	23500.00
0005433525272	18496	Economy	23500.00
0005433193426	18496	Economy	23500.00
0005433525261	18496	Economy	23500.00
0005434587104	18496	Economy	23500.00
0005434515016	18496	Economy	23500.00
0005432928134	18496	Economy	23500.00
0005434587029	18496	Economy	23500.00
0005434587152	18496	Economy	23500.00
0005434587143	18496	Economy	23500.00
0005434515013	18496	Economy	23500.00
0005434587179	18496	Economy	23500.00
0005434587028	18496	Economy	23500.00
0005434587205	18496	Economy	23500.00
0005434587130	18496	Economy	23500.00
0005434587125	18496	Economy	23500.00
0005434587196	18496	Economy	23500.00
0005433193418	18496	Economy	23500.00
0005433193422	18496	Economy	23500.00
0005434587195	18496	Economy	23500.00
0005433193423	18496	Economy	23500.00
0005433193424	18496	Economy	23500.00
0005434587103	18496	Economy	23500.00
0005434587197	18496	Economy	23500.00
0005433193421	18496	Economy	23500.00
0005433724889	18496	Economy	23500.00
0005434587173	18496	Economy	23500.00
0005433193419	18496	Economy	23500.00
0005434345183	11436	Economy	4300.00
0005434345207	11436	Economy	4300.00
0005434142725	11436	Economy	4300.00
0005435302290	11436	Economy	4300.00
0005434345211	11436	Economy	4000.00
0005434345206	11436	Economy	4000.00
0005435302281	11436	Economy	4000.00
0005434345208	11436	Economy	4000.00
0005434345194	11436	Economy	4000.00
0005435302288	11436	Economy	4000.00
0005434345198	11436	Economy	4000.00
0005434345195	11436	Economy	4000.00
0005434345185	11436	Economy	4000.00
0005434345192	11436	Economy	4000.00
0005434345203	11436	Economy	4000.00
0005434345196	11436	Economy	4000.00
0005435302295	11436	Economy	4000.00
0005434345201	11436	Economy	4000.00
0005435302299	11436	Economy	4000.00
0005434345189	11436	Economy	4000.00
0005434345200	11436	Economy	4000.00
0005435302280	11436	Economy	4000.00
0005434345193	11436	Economy	4000.00
0005435302302	11436	Economy	4000.00
0005434142726	11436	Economy	4000.00
0005434345188	11436	Economy	4000.00
0005434345190	11436	Economy	4000.00
0005434345191	11436	Economy	4000.00
0005434142724	11436	Economy	4000.00
0005434345204	11436	Economy	4000.00
0005434142723	11436	Economy	4000.00
0005434345205	11436	Economy	4000.00
0005435302294	11436	Economy	4000.00
0005434345209	11436	Economy	4000.00
0005434345184	11436	Economy	4000.00
0005434345199	11436	Economy	4000.00
0005434345210	11436	Economy	4000.00
0005434345202	11436	Economy	4000.00
0005434345186	11436	Economy	4000.00
0005435302303	11436	Economy	4000.00
0005434345197	11436	Economy	4000.00
0005435302304	11436	Economy	4000.00
0005434345187	11436	Economy	4000.00
0005435304271	29802	Economy	4300.00
0005434344828	29802	Economy	4300.00
0005435304269	29802	Economy	4000.00
0005434344836	29802	Economy	4000.00
0005434344938	29802	Economy	4000.00
0005435304268	29802	Economy	4000.00
0005434344891	29802	Economy	4000.00
0005434344827	29802	Economy	4000.00
0005434344937	29802	Economy	4000.00
0005434344925	29802	Economy	4000.00
0005434344835	29802	Economy	4000.00
0005434344927	29802	Economy	4000.00
0005435305076	29802	Economy	4000.00
0005434344914	29802	Economy	4000.00
0005434142684	29802	Economy	4000.00
0005434142694	29802	Economy	4000.00
0005434344974	29802	Economy	4000.00
0005434344939	29802	Economy	4000.00
0005434142683	29802	Economy	4000.00
0005434344855	29802	Economy	4000.00
0005434142677	29802	Economy	4000.00
0005434344868	29802	Economy	4000.00
0005434344892	29802	Economy	4000.00
0005434344973	29802	Economy	4000.00
0005434344898	29802	Economy	4000.00
0005434142685	29802	Economy	4000.00
0005434345108	29802	Economy	4000.00
0005434142674	29802	Economy	4000.00
0005434344837	29802	Economy	4000.00
0005435304270	29802	Economy	4000.00
0005434344924	29802	Economy	4000.00
0005434344915	29802	Economy	4000.00
0005434345072	29802	Economy	4000.00
0005434344899	29802	Economy	4000.00
0005434344840	29802	Economy	4000.00
0005434142695	29802	Economy	4000.00
0005434344885	29802	Economy	4000.00
0005435305075	29802	Economy	4000.00
0005434344742	29802	Economy	4000.00
0005434142696	29802	Economy	4000.00
0005434142680	29802	Economy	4000.00
0005434344923	29802	Economy	4000.00
0005434344926	29802	Economy	4000.00
0005435825386	1265	Business	199800.00
0005433415941	1265	Business	199800.00
0005433415996	1265	Business	199800.00
0005433415936	1265	Business	199800.00
0005433415999	1265	Business	199800.00
0005435825379	1265	Economy	66600.00
0005432284642	1265	Economy	73200.00
0005433415935	1265	Economy	73200.00
0005435825382	1265	Economy	66600.00
0005435825383	1265	Economy	66600.00
0005433416000	1265	Economy	66600.00
0005435825380	1265	Economy	66600.00
0005433415995	1265	Economy	66600.00
0005432284643	1265	Economy	66600.00
0005433415953	1265	Economy	66600.00
0005435825385	1265	Economy	66600.00
0005433415994	1265	Economy	66600.00
0005433416029	1265	Economy	66600.00
0005433415987	1265	Economy	66600.00
0005433415950	1265	Economy	66600.00
0005433415986	1265	Economy	66600.00
0005433416014	1265	Economy	66600.00
0005433416026	1265	Economy	66600.00
0005433415954	1265	Economy	66600.00
0005435825381	1265	Economy	66600.00
0005435825384	1265	Economy	66600.00
0005435825209	17987	Business	199800.00
0005435825177	17987	Business	199800.00
0005433416116	17987	Business	199800.00
0005435825116	17987	Business	199800.00
0005435825202	17987	Business	199800.00
0005435825229	17987	Economy	66600.00
0005435825219	17987	Economy	66600.00
0005435825186	17987	Economy	66600.00
0005435825324	17987	Economy	73200.00
0005433416108	17987	Economy	73200.00
0005435825246	17987	Economy	66600.00
0005433416107	17987	Economy	66600.00
0005433416111	17987	Economy	66600.00
0005435825280	17987	Economy	66600.00
0005435825228	17987	Economy	66600.00
0005435825104	17987	Economy	66600.00
0005435825133	17987	Economy	66600.00
0005435825040	17987	Economy	66600.00
0005433416114	17987	Economy	66600.00
0005435825132	17987	Economy	66600.00
0005433416109	17987	Economy	66600.00
0005435825201	17987	Economy	66600.00
0005435825098	17987	Economy	66600.00
0005433416110	17987	Economy	66600.00
0005435825220	17987	Economy	66600.00
0005435825097	17987	Economy	66600.00
0005435825245	17987	Economy	66600.00
0005435825171	17987	Economy	66600.00
0005433416115	17987	Economy	66600.00
0005433416112	17987	Economy	66600.00
0005433416117	17987	Economy	66600.00
0005433416118	17987	Economy	66600.00
0005435825138	17987	Economy	66600.00
0005433416113	17987	Economy	66600.00
0005435825060	17987	Economy	66600.00
0005435825157	17987	Economy	66600.00
0005435825039	17987	Economy	66600.00
0005435825172	17987	Economy	66600.00
0005435825223	17987	Economy	66600.00
0005434460536	17530	Economy	14800.00
0005434460542	17530	Economy	13500.00
0005434462835	17530	Economy	13500.00
0005434460540	17530	Economy	13500.00
0005434460541	17530	Economy	13500.00
0005434460533	17530	Economy	13500.00
0005434460543	17530	Economy	13500.00
0005434460537	17530	Economy	13500.00
0005434460553	17530	Economy	13500.00
0005434462832	17530	Economy	13500.00
0005434462826	17530	Economy	13500.00
0005434462828	17530	Economy	13500.00
0005434462831	17530	Economy	13500.00
0005434462833	17530	Economy	13500.00
0005434460554	17530	Economy	13500.00
0005434460535	17530	Economy	13500.00
0005434462830	17530	Economy	13500.00
0005434462829	17530	Economy	13500.00
0005434462823	17530	Economy	13500.00
0005434462825	17530	Economy	13500.00
0005434462827	17530	Economy	13500.00
0005432785286	5630	Business	27800.00
0005435949997	5630	Business	27800.00
0005432785295	5630	Business	27800.00
0005435243418	5630	Business	27800.00
0005435476881	5630	Business	27800.00
0005435243309	5630	Business	27800.00
0005432785298	5630	Business	27800.00
0005435243300	5630	Business	27800.00
0005435476926	5630	Business	27800.00
0005435476889	5630	Business	27800.00
0005432785294	5630	Business	27800.00
0005432785285	5630	Economy	9300.00
0005432785299	5630	Economy	9300.00
0005432785305	5630	Economy	9300.00
0005432785313	5630	Economy	9300.00
0005432785311	5630	Economy	9300.00
0005435950008	5630	Economy	9300.00
0005432785304	5630	Economy	9300.00
0005432785287	5630	Economy	9300.00
0005435476906	5630	Economy	9300.00
0005435949995	5630	Economy	9300.00
0005435950000	5630	Economy	10200.00
0005435243299	5630	Economy	10200.00
0005432785289	5630	Economy	10200.00
0005432785308	5630	Economy	10200.00
0005435243369	5630	Economy	10200.00
0005432785297	5630	Economy	9300.00
0005435476942	5630	Economy	9300.00
0005432785310	5630	Economy	9300.00
0005435243458	5630	Economy	9300.00
0005435476872	5630	Economy	9300.00
0005435950010	5630	Economy	9300.00
0005432785290	5630	Economy	9300.00
0005435950009	5630	Economy	9300.00
0005432785302	5630	Economy	9300.00
0005435243405	5630	Economy	9300.00
0005435949996	5630	Economy	9300.00
0005435243396	5630	Economy	9300.00
0005435476922	5630	Economy	9300.00
0005435950001	5630	Economy	9300.00
0005435243301	5630	Economy	9300.00
0005435243280	5630	Economy	9300.00
0005435243335	5630	Economy	9300.00
0005435476871	5630	Economy	9300.00
0005435476925	5630	Economy	9300.00
0005435476915	5630	Economy	9300.00
0005432785303	5630	Economy	9300.00
0005435950005	5630	Economy	9300.00
0005432785312	5630	Economy	9300.00
0005435949999	5630	Economy	9300.00
0005432785309	5630	Economy	9300.00
0005432785314	5630	Economy	9300.00
0005435243322	5630	Economy	9300.00
0005435476937	5630	Economy	9300.00
0005435243397	5630	Economy	9300.00
0005435476923	5630	Economy	9300.00
0005432785291	5630	Economy	9300.00
0005435243268	5630	Economy	9300.00
0005435243306	5630	Economy	9300.00
0005435950003	5630	Economy	9300.00
0005432785296	5630	Economy	9300.00
0005432785307	5630	Economy	9300.00
0005435476960	5630	Economy	9300.00
0005435476901	5630	Economy	9300.00
0005435243266	5630	Economy	9300.00
0005435243364	5630	Economy	9300.00
0005435949998	5630	Economy	9300.00
0005432785292	5630	Economy	9300.00
0005432785306	5630	Economy	9300.00
0005432785288	5630	Economy	9300.00
0005435476882	5630	Economy	9300.00
0005435243350	5630	Economy	9300.00
0005435950007	5630	Economy	9300.00
0005432785300	5630	Economy	9300.00
0005435950002	5630	Economy	9300.00
0005432785293	5630	Economy	9300.00
0005435243457	5630	Economy	9300.00
0005435243378	5630	Economy	9300.00
0005435243281	5630	Economy	9300.00
0005435950006	5630	Economy	9300.00
0005435950004	5630	Economy	9300.00
0005435243424	5630	Economy	9300.00
0005435243417	5630	Economy	9300.00
0005435476894	5630	Economy	9300.00
0005432785301	5630	Economy	9300.00
0005435476980	15372	Business	27800.00
0005432784807	15372	Business	27800.00
0005432785134	15372	Business	27800.00
0005432784687	15372	Business	27800.00
0005435243608	15372	Business	27800.00
0005432784861	15372	Business	27800.00
0005432784703	15372	Economy	9300.00
0005432784801	15372	Economy	9300.00
0005432784630	15372	Economy	9300.00
0005432784888	15372	Economy	9300.00
0005435243604	15372	Economy	9300.00
0005432784645	15372	Economy	9300.00
0005432784870	15372	Economy	9300.00
0005435476977	15372	Economy	9300.00
0005432785136	15372	Economy	9300.00
0005432784854	15372	Economy	9300.00
0005432784951	15372	Economy	10200.00
0005435243599	15372	Economy	10200.00
0005435243609	15372	Economy	10200.00
0005432784776	15372	Economy	10200.00
0005435243598	15372	Economy	10200.00
0005435243603	15372	Economy	9300.00
0005435243602	15372	Economy	9300.00
0005432784831	15372	Economy	9300.00
0005435476979	15372	Economy	9300.00
0005435243610	15372	Economy	9300.00
0005435243611	15372	Economy	9300.00
0005432784913	15372	Economy	9300.00
0005435243594	15372	Economy	9300.00
0005435243601	15372	Economy	9300.00
0005435243589	15372	Economy	9300.00
0005432784862	15372	Economy	9300.00
0005435476981	15372	Economy	9300.00
0005432784830	15372	Economy	9300.00
0005432784740	15372	Economy	9300.00
0005432784950	15372	Economy	9300.00
0005432784942	15372	Economy	9300.00
0005432784885	15372	Economy	9300.00
0005435243593	15372	Economy	9300.00
0005432784963	15372	Economy	9300.00
0005432784971	15372	Economy	9300.00
0005435243595	15372	Economy	9300.00
0005435243590	15372	Economy	9300.00
0005432784761	15372	Economy	9300.00
0005435476982	15372	Economy	9300.00
0005432784944	15372	Economy	9300.00
0005435243605	15372	Economy	9300.00
0005435476983	15372	Economy	9300.00
0005432784884	15372	Economy	9300.00
0005435243606	15372	Economy	9300.00
0005432784925	15372	Economy	9300.00
0005432784741	15372	Economy	9300.00
0005435243600	15372	Economy	9300.00
0005435243591	15372	Economy	9300.00
0005435243596	15372	Economy	9300.00
0005432784855	15372	Economy	9300.00
0005432784631	15372	Economy	9300.00
0005435476984	15372	Economy	9300.00
0005432784924	15372	Economy	9300.00
0005432785109	15372	Economy	9300.00
0005435476986	15372	Economy	9300.00
0005435243592	15372	Economy	9300.00
0005432785138	15372	Economy	9300.00
0005435243597	15372	Economy	9300.00
0005435476978	15372	Economy	9300.00
0005432784685	15372	Economy	9300.00
0005432785135	15372	Economy	9300.00
0005435243607	15372	Economy	9300.00
0005432785108	15372	Economy	9300.00
0005435476985	15372	Economy	9300.00
0005432784667	15372	Economy	9300.00
0005432784825	15372	Economy	9300.00
0005432784583	15372	Economy	9300.00
0005432784584	15372	Economy	9300.00
0005435851124	4356	Economy	6300.00
0005434462851	4356	Economy	6300.00
0005432848714	4356	Economy	6300.00
0005432848717	4356	Economy	6300.00
0005432848713	4356	Economy	6300.00
0005435851081	4356	Economy	6300.00
0005434462853	4356	Economy	6300.00
0005435851108	4356	Economy	6300.00
0005435851112	4356	Economy	6300.00
0005435851141	4356	Economy	6300.00
0005434462852	4356	Economy	6300.00
0005432848712	4356	Economy	6300.00
0005435851079	4356	Economy	6300.00
0005432848715	4356	Economy	6300.00
0005432848716	4356	Economy	6300.00
0005434463977	28840	Economy	7000.00
0005432848622	28840	Economy	7000.00
0005435851168	28840	Economy	6300.00
0005432848586	28840	Economy	6300.00
0005435851167	28840	Economy	6300.00
0005435851166	28840	Economy	6300.00
0005435851163	28840	Economy	6300.00
0005432848655	28840	Economy	6300.00
0005432848578	28840	Economy	6300.00
0005432848579	28840	Economy	6300.00
0005435851164	28840	Economy	6300.00
0005435851165	28840	Economy	6300.00
0005434463978	28840	Economy	6300.00
0005435851169	28840	Economy	6300.00
0005435851161	28840	Economy	6300.00
0005434463963	28840	Economy	6300.00
0005434463979	28840	Economy	6300.00
0005435851162	28840	Economy	6300.00
0005434463964	28840	Economy	6300.00
0005432848656	28840	Economy	6300.00
0005432848601	28840	Economy	6300.00
0005432848640	28840	Economy	6300.00
0005432848641	28840	Economy	6300.00
0005432848587	28840	Economy	6300.00
0005434463968	28840	Economy	6300.00
0005434463969	28840	Economy	6300.00
0005432848639	28840	Economy	6300.00
0005432848577	28840	Economy	6300.00
0005432848585	28840	Economy	6300.00
0005434926793	6251	Business	11900.00
0005434926785	6251	Business	11900.00
0005434926757	6251	Business	11900.00
0005435257439	6251	Business	11900.00
0005433497853	6251	Business	11900.00
0005434444154	6251	Business	11900.00
0005434926787	6251	Business	11900.00
0005433497847	6251	Business	11900.00
0005434444167	6251	Business	11900.00
0005434444169	6251	Business	11900.00
0005435257451	6251	Business	11900.00
0005433497842	6251	Economy	4000.00
0005433497854	6251	Economy	4000.00
0005434444160	6251	Economy	4000.00
0005433497858	6251	Economy	4000.00
0005435257429	6251	Economy	4000.00
0005434926770	6251	Economy	4000.00
0005434926771	6251	Economy	4000.00
0005433497855	6251	Economy	4000.00
0005433497857	6251	Economy	4000.00
0005434926784	6251	Economy	4400.00
0005434444166	6251	Economy	4400.00
0005435257468	6251	Economy	4400.00
0005434926788	6251	Economy	4400.00
0005434926755	6251	Economy	4400.00
0005434926778	6251	Economy	4000.00
0005435257430	6251	Economy	4000.00
0005434926767	6251	Economy	4000.00
0005435257397	6251	Economy	4000.00
0005433497840	6251	Economy	4000.00
0005434926783	6251	Economy	4000.00
0005434926773	6251	Economy	4000.00
0005434926763	6251	Economy	4000.00
0005434926794	6251	Economy	4000.00
0005434926760	6251	Economy	4000.00
0005434926791	6251	Economy	4000.00
0005434444157	6251	Economy	4000.00
0005435257427	6251	Economy	4000.00
0005433497837	6251	Economy	4000.00
0005434926777	6251	Economy	4000.00
0005434926753	6251	Economy	4000.00
0005434926780	6251	Economy	4000.00
0005435257469	6251	Economy	4000.00
0005434926782	6251	Economy	4000.00
0005434444159	6251	Economy	4000.00
0005434926776	6251	Economy	4000.00
0005434926789	6251	Economy	4000.00
0005434926769	6251	Economy	4000.00
0005433497851	6251	Economy	4000.00
0005435257407	6251	Economy	4000.00
0005434444164	6251	Economy	4000.00
0005433497838	6251	Economy	4000.00
0005433497844	6251	Economy	4000.00
0005434926764	6251	Economy	4000.00
0005433497856	6251	Economy	4000.00
0005433497848	6251	Economy	4000.00
0005434926790	6251	Economy	4000.00
0005434444168	6251	Economy	4000.00
0005433497841	6251	Economy	4000.00
0005434926779	6251	Economy	4000.00
0005434926786	6251	Economy	4000.00
0005433497839	6251	Economy	4000.00
0005434444162	6251	Economy	4000.00
0005434926758	6251	Economy	4000.00
0005435257414	6251	Economy	4000.00
0005434926759	6251	Economy	4000.00
0005433497845	6251	Economy	4000.00
0005434926774	6251	Economy	4000.00
0005434926766	6251	Economy	4000.00
0005433497849	6251	Economy	4000.00
0005434444156	6251	Economy	4000.00
0005434444161	6251	Economy	4000.00
0005434926754	6251	Economy	4000.00
0005433497846	6251	Economy	4000.00
0005434444165	6251	Economy	4000.00
0005433497843	6251	Economy	4000.00
0005434926761	6251	Economy	4000.00
0005434444163	6251	Economy	4000.00
0005434926768	6251	Economy	4000.00
0005433497852	6251	Economy	4000.00
0005434926762	6251	Economy	4000.00
0005434444170	6251	Economy	4000.00
0005434926772	6251	Economy	4000.00
0005434926781	6251	Economy	4000.00
0005434926775	6251	Economy	4000.00
0005435257459	6251	Economy	4000.00
0005434926792	6251	Economy	4000.00
0005434444155	6251	Economy	4000.00
0005433497850	6251	Economy	4000.00
0005434926756	6251	Economy	4000.00
0005434444158	6251	Economy	4000.00
0005434926765	6251	Economy	4000.00
0005435257458	6251	Economy	4000.00
0005435257522	20320	Business	11900.00
0005435257526	20320	Economy	4400.00
0005435257527	20320	Economy	4400.00
0005435257523	20320	Economy	4000.00
0005435257530	20320	Economy	4000.00
0005435257525	20320	Economy	4000.00
0005435257524	20320	Economy	4000.00
0005435257528	20320	Economy	4000.00
0005435257529	20320	Economy	4000.00
0005434926431	20321	Business	11900.00
0005434444011	20321	Business	11900.00
0005434444018	20321	Business	11900.00
0005433497657	20321	Business	11900.00
0005434444012	20321	Business	11900.00
0005433497681	20321	Business	11900.00
0005434926404	20321	Business	11900.00
0005434444065	20321	Business	11900.00
0005434926425	20321	Business	11900.00
0005433497511	20321	Economy	4000.00
0005434926402	20321	Economy	4000.00
0005434926451	20321	Economy	4000.00
0005433497744	20321	Economy	4000.00
0005434926350	20321	Economy	4000.00
0005434926411	20321	Economy	4000.00
0005434926459	20321	Economy	4000.00
0005434444064	20321	Economy	4400.00
0005434444002	20321	Economy	4400.00
0005433497745	20321	Economy	4400.00
0005434444039	20321	Economy	4400.00
0005433497570	20321	Economy	4000.00
0005433497682	20321	Economy	4000.00
0005433497583	20321	Economy	4000.00
0005434926452	20321	Economy	4000.00
0005434444037	20321	Economy	4000.00
0005434444068	20321	Economy	4000.00
0005434926469	20321	Economy	4000.00
0005434926395	20321	Economy	4000.00
0005433497663	20321	Economy	4000.00
0005434444017	20321	Economy	4000.00
0005434926343	20321	Economy	4000.00
0005433497699	20321	Economy	4000.00
0005434926389	20321	Economy	4000.00
0005434926387	20321	Economy	4000.00
0005434926359	20321	Economy	4000.00
0005434926426	20321	Economy	4000.00
0005433497670	20321	Economy	4000.00
0005434926388	20321	Economy	4000.00
0005434926405	20321	Economy	4000.00
0005433497652	20321	Economy	4000.00
0005433497641	20321	Economy	4000.00
0005434926456	20321	Economy	4000.00
0005434926410	20321	Economy	4000.00
0005434926390	20321	Economy	4000.00
0005434926384	20321	Economy	4000.00
0005433497593	20321	Economy	4000.00
0005433497683	20321	Economy	4000.00
0005433497584	20321	Economy	4000.00
0005434926396	20321	Economy	4000.00
0005434443974	20321	Economy	4000.00
0005434926460	20321	Economy	4000.00
0005434444062	20321	Economy	4000.00
0005433497697	20321	Economy	4000.00
0005433497671	20321	Economy	4000.00
0005434926385	20321	Economy	4000.00
0005433497373	20321	Economy	4000.00
0005434443959	20321	Economy	4000.00
0005434926424	20321	Economy	4000.00
0005434926376	20321	Economy	4000.00
0005434926335	20321	Economy	4000.00
0005433497696	20321	Economy	4000.00
0005434926444	20321	Economy	4000.00
0005434444038	20321	Economy	4000.00
0005434444003	20321	Economy	4000.00
0005434926262	20321	Economy	4000.00
0005433497700	20321	Economy	4000.00
0005434444063	20321	Economy	4000.00
0005434926331	20321	Economy	4000.00
0005433497524	20321	Economy	4000.00
0005433497711	20321	Economy	4000.00
0005434926347	20321	Economy	4000.00
0005434926401	20321	Economy	4000.00
0005433497520	20321	Economy	4000.00
0005434926334	20321	Economy	4000.00
0005433497669	20321	Economy	4000.00
0005433497590	20321	Economy	4000.00
0005433497372	20321	Economy	4000.00
0005432785060	12196	Business	41200.00
0005432784749	12196	Business	41200.00
0005435243617	12196	Business	41200.00
0005432785062	12196	Business	41200.00
0005432784739	12196	Business	41200.00
0005432784844	12196	Business	41200.00
0005435243616	12196	Business	41200.00
0005435243626	12196	Business	41200.00
0005432784897	12196	Business	41200.00
0005432785010	12196	Business	41200.00
0005432784836	12196	Business	41200.00
0005435243624	12196	Business	41200.00
0005432784805	12196	Economy	13700.00
0005432784899	12196	Economy	13700.00
0005432784995	12196	Economy	13700.00
0005435243625	12196	Economy	13700.00
0005432784843	12196	Economy	13700.00
0005432784992	12196	Economy	13700.00
0005432784723	12196	Economy	13700.00
0005435243622	12196	Economy	15100.00
0005432784958	12196	Economy	15100.00
0005432784960	12196	Economy	15100.00
0005432784967	12196	Economy	15100.00
0005432784732	12196	Economy	13700.00
0005432784787	12196	Economy	13700.00
0005432784802	12196	Economy	13700.00
0005435243615	12196	Economy	13700.00
0005432784635	12196	Economy	13700.00
0005432784839	12196	Economy	13700.00
0005432784724	12196	Economy	13700.00
0005432785095	12196	Economy	13700.00
0005432785018	12196	Economy	13700.00
0005432784902	12196	Economy	13700.00
0005432784686	12196	Economy	13700.00
0005432784738	12196	Economy	13700.00
0005435243620	12196	Economy	13700.00
0005432784876	12196	Economy	13700.00
0005432784840	12196	Economy	13700.00
0005432784780	12196	Economy	13700.00
0005432784903	12196	Economy	13700.00
0005432785011	12196	Economy	13700.00
0005432784968	12196	Economy	13700.00
0005432784881	12196	Economy	13700.00
0005432785141	12196	Economy	13700.00
0005432784978	12196	Economy	13700.00
0005432784811	12196	Economy	13700.00
0005432784954	12196	Economy	13700.00
0005432784962	12196	Economy	13700.00
0005432784838	12196	Economy	13700.00
0005435243623	12196	Economy	13700.00
0005432784615	12196	Economy	13700.00
0005432785096	12196	Economy	13700.00
0005435243619	12196	Economy	13700.00
0005432784731	12196	Economy	13700.00
0005432784898	12196	Economy	13700.00
0005432785061	12196	Economy	13700.00
0005435243621	12196	Economy	13700.00
0005432784959	12196	Economy	13700.00
0005432784655	12196	Economy	13700.00
0005432784896	12196	Economy	13700.00
0005435243627	12196	Economy	13700.00
0005432784725	12196	Economy	13700.00
0005432785053	12196	Economy	13700.00
0005435243618	12196	Economy	13700.00
0005432785009	12196	Economy	13700.00
0005435243614	12196	Economy	13700.00
0005432784969	12196	Economy	13700.00
0005435243613	12196	Economy	13700.00
0005432784798	12196	Economy	13700.00
0005435243612	12196	Economy	13700.00
0005432784728	12196	Economy	13700.00
0005432784837	12196	Economy	13700.00
0005432784945	12196	Economy	13700.00
0005432784966	12196	Economy	13700.00
0005432784799	12196	Economy	13700.00
0005435243377	15443	Business	41200.00
0005435243246	15443	Business	41200.00
0005432785276	15443	Business	41200.00
0005432785255	15443	Business	41200.00
0005435243390	15443	Business	41200.00
0005432785282	15443	Business	41200.00
0005432785259	15443	Business	41200.00
0005435243366	15443	Business	41200.00
0005432785274	15443	Business	41200.00
0005435243316	15443	Business	41200.00
0005432785243	15443	Economy	13700.00
0005432785250	15443	Economy	13700.00
0005435243297	15443	Economy	13700.00
0005435243456	15443	Economy	13700.00
0005432785240	15443	Economy	15100.00
0005432785284	15443	Economy	13700.00
0005435243293	15443	Economy	13700.00
0005432785269	15443	Economy	13700.00
0005432785283	15443	Economy	13700.00
0005432785242	15443	Economy	13700.00
0005435243302	15443	Economy	13700.00
0005432785268	15443	Economy	13700.00
0005432785279	15443	Economy	13700.00
0005432785265	15443	Economy	13700.00
0005435243338	15443	Economy	13700.00
0005432785270	15443	Economy	13700.00
0005432785278	15443	Economy	13700.00
0005435243245	15443	Economy	13700.00
0005435243315	15443	Economy	13700.00
0005432785249	15443	Economy	13700.00
0005432785246	15443	Economy	13700.00
0005432785245	15443	Economy	13700.00
0005432785267	15443	Economy	13700.00
0005432785244	15443	Economy	13700.00
0005432785264	15443	Economy	13700.00
0005432785248	15443	Economy	13700.00
0005432785258	15443	Economy	13700.00
0005432785272	15443	Economy	13700.00
0005432785252	15443	Economy	13700.00
0005432785263	15443	Economy	13700.00
0005432785275	15443	Economy	13700.00
0005432785256	15443	Economy	13700.00
0005432785253	15443	Economy	13700.00
0005435243258	15443	Economy	13700.00
0005435243384	15443	Economy	13700.00
0005435243317	15443	Economy	13700.00
0005435243344	15443	Economy	13700.00
0005432785281	15443	Economy	13700.00
0005432785247	15443	Economy	13700.00
0005432785254	15443	Economy	13700.00
0005435243337	15443	Economy	13700.00
0005432785280	15443	Economy	13700.00
0005435243367	15443	Economy	13700.00
0005432785277	15443	Economy	13700.00
0005432785241	15443	Economy	13700.00
0005432785262	15443	Economy	13700.00
0005432785266	15443	Economy	13700.00
0005432785261	15443	Economy	13700.00
0005432785260	15443	Economy	13700.00
0005435243303	15443	Economy	13700.00
0005435243383	15443	Economy	13700.00
0005432785257	15443	Economy	13700.00
0005432785273	15443	Economy	13700.00
0005432785271	15443	Economy	13700.00
0005435243336	15443	Economy	13700.00
0005432785251	15443	Economy	13700.00
0005434880104	10109	Business	49700.00
0005434880643	10109	Business	49700.00
0005434758945	10109	Business	49700.00
0005434880025	10109	Business	49700.00
0005434880379	10109	Business	49700.00
0005434879906	10109	Business	49700.00
0005434910180	10109	Business	49700.00
0005435914159	10109	Business	49700.00
0005434879727	10109	Business	49700.00
0005434879726	10109	Business	49700.00
0005434880035	10109	Business	49700.00
0005434880106	10109	Business	49700.00
0005434880285	10109	Business	49700.00
0005434880071	10109	Business	49700.00
0005434879849	10109	Business	49700.00
0005434880236	10109	Business	49700.00
0005434879905	10109	Business	49700.00
0005434880165	10109	Business	49700.00
0005434879928	10109	Business	49700.00
0005434880286	10109	Business	49700.00
0005434879970	10109	Economy	16600.00
0005434879902	10109	Economy	16600.00
0005434879975	10109	Economy	16600.00
0005435914157	10109	Economy	16600.00
0005435914153	10109	Economy	16600.00
0005435914158	10109	Economy	16600.00
0005434880237	10109	Economy	16600.00
0005434880303	10109	Economy	16600.00
0005434879947	10109	Economy	16600.00
0005434880044	10109	Economy	16600.00
0005434910181	10109	Economy	16600.00
0005434880120	10109	Economy	16600.00
0005434879815	10109	Economy	16600.00
0005435914161	10109	Economy	18200.00
0005434879832	10109	Economy	18200.00
0005434879736	10109	Economy	18200.00
0005434880058	10109	Economy	18200.00
0005434880073	10109	Economy	16600.00
0005434880181	10109	Economy	16600.00
0005434880208	10109	Economy	16600.00
0005434880304	10109	Economy	16600.00
0005434880092	10109	Economy	16600.00
0005434880019	10109	Economy	16600.00
0005434880078	10109	Economy	16600.00
0005434880051	10109	Economy	16600.00
0005434880380	10109	Economy	16600.00
0005434880172	10109	Economy	16600.00
0005435914152	10109	Economy	16600.00
0005435914156	10109	Economy	16600.00
0005434880516	10109	Economy	16600.00
0005434879994	10109	Economy	16600.00
0005434880072	10109	Economy	16600.00
0005434880133	10109	Economy	16600.00
0005434880096	10109	Economy	16600.00
0005434879860	10109	Economy	16600.00
0005434880079	10109	Economy	16600.00
0005434880175	10109	Economy	16600.00
0005434880136	10109	Economy	16600.00
0005434880495	10109	Economy	16600.00
0005434879898	10109	Economy	16600.00
0005434880515	10109	Economy	16600.00
0005434879833	10109	Economy	16600.00
0005434880219	10109	Economy	16600.00
0005434910179	10109	Economy	16600.00
0005434880180	10109	Economy	16600.00
0005434880548	10109	Economy	16600.00
0005434879811	10109	Economy	16600.00
0005435914154	10109	Economy	16600.00
0005434880085	10109	Economy	16600.00
0005434879907	10109	Economy	16600.00
0005434879982	10109	Economy	16600.00
0005434879872	10109	Economy	16600.00
0005434880218	10109	Economy	16600.00
0005434880077	10109	Economy	16600.00
0005434880122	10109	Economy	16600.00
0005434880188	10109	Economy	16600.00
0005434880068	10109	Economy	16600.00
0005434879995	10109	Economy	16600.00
0005434880247	10109	Economy	16600.00
0005434879871	10109	Economy	16600.00
0005434880103	10109	Economy	16600.00
0005434880198	10109	Economy	16600.00
0005434880105	10109	Economy	16600.00
0005434880081	10109	Economy	16600.00
0005434880259	10109	Economy	16600.00
0005434880217	10109	Economy	16600.00
0005434879996	10109	Economy	16600.00
0005434880097	10109	Economy	16600.00
0005434758937	10109	Economy	16600.00
0005434879802	10109	Economy	16600.00
0005434880361	10109	Economy	16600.00
0005434880052	10109	Economy	16600.00
0005434880302	10109	Economy	16600.00
0005434880258	10109	Economy	16600.00
0005434879696	10109	Economy	16600.00
0005434880362	10109	Economy	16600.00
0005434879810	10109	Economy	16600.00
0005434879983	10109	Economy	16600.00
0005435914160	10109	Economy	16600.00
0005434880517	10109	Economy	16600.00
0005434880041	10109	Economy	16600.00
0005434879971	10109	Economy	16600.00
0005434880076	10109	Economy	16600.00
0005434758928	10109	Economy	16600.00
0005434880163	10109	Economy	16600.00
0005434758946	10109	Economy	16600.00
0005434880036	10109	Economy	16600.00
0005434880364	10109	Economy	16600.00
0005434879814	10109	Economy	16600.00
0005434880164	10109	Economy	16600.00
0005435914155	10109	Economy	16600.00
0005434879848	10109	Economy	16600.00
0005434758947	10109	Economy	16600.00
0005434879939	10109	Economy	16600.00
0005434758936	10109	Economy	16600.00
0005434880235	10109	Economy	16600.00
0005434880897	14623	Business	49700.00
0005434880881	14623	Business	49700.00
0005435914011	14623	Business	49700.00
0005434880886	14623	Business	49700.00
0005434880865	14623	Business	49700.00
0005434910161	14623	Business	49700.00
0005434880852	14623	Business	49700.00
0005434880848	14623	Business	49700.00
0005434880838	14623	Business	49700.00
0005434880860	14623	Business	49700.00
0005435914026	14623	Business	49700.00
0005434880841	14623	Business	49700.00
0005434880877	14623	Business	49700.00
0005435914014	14623	Business	49700.00
0005434880853	14623	Business	49700.00
0005434880875	14623	Economy	16600.00
0005434880870	14623	Economy	16600.00
0005434880847	14623	Economy	16600.00
0005434880854	14623	Economy	16600.00
0005434880858	14623	Economy	16600.00
0005434880866	14623	Economy	16600.00
0005434880884	14623	Economy	16600.00
0005434880855	14623	Economy	16600.00
0005434880898	14623	Economy	18200.00
0005434880874	14623	Economy	16600.00
0005434880876	14623	Economy	16600.00
0005434880883	14623	Economy	16600.00
0005434880859	14623	Economy	16600.00
0005434880873	14623	Economy	16600.00
0005435913980	14623	Economy	16600.00
0005434758960	14623	Economy	16600.00
0005434880885	14623	Economy	16600.00
0005434880849	14623	Economy	16600.00
0005434880890	14623	Economy	16600.00
0005435914018	14623	Economy	16600.00
0005434910164	14623	Economy	16600.00
0005434910167	14623	Economy	16600.00
0005434880891	14623	Economy	16600.00
0005434880864	14623	Economy	16600.00
0005434880867	14623	Economy	16600.00
0005434880857	14623	Economy	16600.00
0005434880846	14623	Economy	16600.00
0005434880843	14623	Economy	16600.00
0005434880892	14623	Economy	16600.00
0005434880844	14623	Economy	16600.00
0005435913983	14623	Economy	16600.00
0005434880869	14623	Economy	16600.00
0005434880863	14623	Economy	16600.00
0005434880837	14623	Economy	16600.00
0005434880878	14623	Economy	16600.00
0005434910163	14623	Economy	16600.00
0005434880871	14623	Economy	16600.00
0005434880862	14623	Economy	16600.00
0005434880845	14623	Economy	16600.00
0005435914015	14623	Economy	16600.00
0005434880896	14623	Economy	16600.00
0005434910162	14623	Economy	16600.00
0005434880842	14623	Economy	16600.00
0005435914001	14623	Economy	16600.00
0005434880856	14623	Economy	16600.00
0005434880868	14623	Economy	16600.00
0005434880887	14623	Economy	16600.00
0005435913998	14623	Economy	16600.00
0005434880840	14623	Economy	16600.00
0005435914013	14623	Economy	16600.00
0005434880893	14623	Economy	16600.00
0005434880888	14623	Economy	16600.00
0005434880889	14623	Economy	16600.00
0005434880880	14623	Economy	16600.00
0005434758959	14623	Economy	16600.00
0005434880895	14623	Economy	16600.00
0005434880839	14623	Economy	16600.00
0005435914017	14623	Economy	16600.00
0005434880850	14623	Economy	16600.00
0005434880879	14623	Economy	16600.00
0005434880861	14623	Economy	16600.00
0005434880851	14623	Economy	16600.00
0005435914002	14623	Economy	16600.00
0005434880872	14623	Economy	16600.00
0005434880882	14623	Economy	16600.00
0005434880894	14623	Economy	16600.00
0005435660451	9216	Economy	20300.00
0005435660450	9216	Economy	20300.00
0005434252139	9216	Economy	20300.00
0005435660453	9216	Economy	20300.00
0005435660448	9216	Economy	20300.00
0005434252144	9216	Economy	20300.00
0005435660452	9216	Economy	20300.00
0005435660455	9216	Economy	20300.00
0005434252156	9216	Economy	20300.00
0005435660454	9216	Economy	20300.00
0005435660449	9216	Economy	20300.00
0005434252213	9216	Economy	20300.00
0005434252145	9216	Economy	20300.00
0005434252212	9216	Economy	20300.00
0005435933557	24649	Economy	22400.00
0005435933562	24649	Economy	22400.00
0005435660358	24649	Economy	20300.00
0005434252233	24649	Economy	20300.00
0005434252235	24649	Economy	20300.00
0005435660352	24649	Economy	20300.00
0005435933561	24649	Economy	20300.00
0005435660377	24649	Economy	20300.00
0005435660385	24649	Economy	20300.00
0005435660387	24649	Economy	20300.00
0005435660382	24649	Economy	20300.00
0005435660404	24649	Economy	20300.00
0005434252232	24649	Economy	20300.00
0005435660351	24649	Economy	20300.00
0005435660359	24649	Economy	20300.00
0005435933556	24649	Economy	20300.00
0005435933563	24649	Economy	20300.00
0005434252234	24649	Economy	20300.00
0005434252237	24649	Economy	20300.00
0005435660423	24649	Economy	20300.00
0005434252236	24649	Economy	20300.00
0005432967546	2822	Business	33000.00
0005433681896	2822	Business	33000.00
0005433681900	2822	Business	33000.00
0005433681891	2822	Business	33000.00
0005432967545	2822	Business	33000.00
0005432967508	2822	Business	33000.00
0005433681894	2822	Economy	11000.00
0005433681898	2822	Economy	11000.00
0005432967483	2822	Economy	11000.00
0005432967469	2822	Economy	11000.00
0005432967507	2822	Economy	11000.00
0005433681914	2822	Economy	11000.00
0005433681910	2822	Economy	11000.00
0005433681908	2822	Economy	11000.00
0005432222931	2822	Economy	11000.00
0005432967502	2822	Economy	12100.00
0005433681907	2822	Economy	12100.00
0005433681916	2822	Economy	12100.00
0005432967520	2822	Economy	12100.00
0005432967470	2822	Economy	11000.00
0005433684478	2822	Economy	11000.00
0005433681897	2822	Economy	11000.00
0005433681901	2822	Economy	11000.00
0005433681906	2822	Economy	11000.00
0005433684477	2822	Economy	11000.00
0005432222932	2822	Economy	11000.00
0005432967522	2822	Economy	11000.00
0005433681887	2822	Economy	11000.00
0005433681889	2822	Economy	11000.00
0005432967568	2822	Economy	11000.00
0005433681890	2822	Economy	11000.00
0005432967379	2822	Economy	11000.00
0005433681893	2822	Economy	11000.00
0005432967364	2822	Economy	11000.00
0005432967378	2822	Economy	11000.00
0005433681918	2822	Economy	11000.00
0005433681919	2822	Economy	11000.00
0005433681902	2822	Economy	11000.00
0005432967467	2822	Economy	11000.00
0005433681915	2822	Economy	11000.00
0005432967448	2822	Economy	11000.00
0005432967369	2822	Economy	11000.00
0005432967394	2822	Economy	11000.00
0005432967447	2822	Economy	11000.00
0005432967468	2822	Economy	11000.00
0005432222930	2822	Economy	11000.00
0005432967437	2822	Economy	11000.00
0005432967368	2822	Economy	11000.00
0005432967463	2822	Economy	11000.00
0005432967428	2822	Economy	11000.00
0005432967441	2822	Economy	11000.00
0005433681917	2822	Economy	11000.00
0005433681904	2822	Economy	11000.00
0005432967398	2822	Economy	11000.00
0005432967413	2822	Economy	11000.00
0005433681913	2822	Economy	11000.00
0005433681895	2822	Economy	11000.00
0005433681888	2822	Economy	11000.00
0005432967436	2822	Economy	11000.00
0005432967399	2822	Economy	11000.00
0005432967509	2822	Economy	11000.00
0005433681899	2822	Economy	11000.00
0005433681905	2822	Economy	11000.00
0005432967465	2822	Economy	11000.00
0005432967466	2822	Economy	11000.00
0005432967451	2822	Economy	11000.00
0005432967442	2822	Economy	11000.00
0005433681911	2822	Economy	11000.00
0005433681892	2822	Economy	11000.00
0005432967438	2822	Economy	11000.00
0005432967521	2822	Economy	11000.00
0005433681886	2822	Economy	11000.00
0005432222933	2822	Economy	11000.00
0005432967517	2822	Economy	11000.00
0005433681909	2822	Economy	11000.00
0005432967382	2822	Economy	11000.00
0005432967332	2822	Economy	11000.00
0005432967569	2822	Economy	11000.00
0005433681912	2822	Economy	11000.00
0005432967464	2822	Economy	11000.00
0005432967490	2822	Economy	11000.00
0005433681903	2822	Economy	11000.00
0005433681497	29179	Business	33000.00
0005433681538	29179	Business	33000.00
0005433681785	29179	Business	33000.00
0005433681502	29179	Business	33000.00
0005433681666	29179	Business	33000.00
0005432967648	29179	Business	33000.00
0005433681598	29179	Business	33000.00
0005433684455	29179	Business	33000.00
0005433681713	29179	Business	33000.00
0005433681515	29179	Business	33000.00
0005432967644	29179	Business	33000.00
0005433681349	29179	Economy	11000.00
0005432967656	29179	Economy	11000.00
0005433681587	29179	Economy	11000.00
0005433681459	29179	Economy	11000.00
0005433681500	29179	Economy	11000.00
0005433681722	29179	Economy	11000.00
0005433681682	29179	Economy	11000.00
0005433681645	29179	Economy	11000.00
0005433681738	29179	Economy	12100.00
0005433684464	29179	Economy	12100.00
0005433681528	29179	Economy	12100.00
0005433681375	29179	Economy	12100.00
0005433681654	29179	Economy	11000.00
0005432967643	29179	Economy	11000.00
0005433681578	29179	Economy	11000.00
0005433687753	29179	Economy	11000.00
0005432967646	29179	Economy	11000.00
0005432967642	29179	Economy	11000.00
0005433681458	29179	Economy	11000.00
0005433690980	29179	Economy	11000.00
0005433681714	29179	Economy	11000.00
0005432967647	29179	Economy	11000.00
0005432967645	29179	Economy	11000.00
0005433681644	29179	Economy	11000.00
0005433681589	29179	Economy	11000.00
0005433681597	29179	Economy	11000.00
0005433681554	29179	Economy	11000.00
0005433681460	29179	Economy	11000.00
0005433684456	29179	Economy	11000.00
0005433681496	29179	Economy	11000.00
0005433681689	29179	Economy	11000.00
0005433681386	29179	Economy	11000.00
0005433681394	29179	Economy	11000.00
0005433681688	29179	Economy	11000.00
0005433681636	29179	Economy	11000.00
0005433684465	29179	Economy	11000.00
0005432967651	29179	Economy	11000.00
0005433681350	29179	Economy	11000.00
0005432967640	29179	Economy	11000.00
0005433681677	29179	Economy	11000.00
0005433681379	29179	Economy	11000.00
0005433681539	29179	Economy	11000.00
0005433681552	29179	Economy	11000.00
0005433681579	29179	Economy	11000.00
0005432967652	29179	Economy	11000.00
0005432967654	29179	Economy	11000.00
0005433681704	29179	Economy	11000.00
0005432967641	29179	Economy	11000.00
0005433681503	29179	Economy	11000.00
0005433681546	29179	Economy	11000.00
0005433681676	29179	Economy	11000.00
0005433681312	29179	Economy	11000.00
0005432967650	29179	Economy	11000.00
0005433681786	29179	Economy	11000.00
0005432967655	29179	Economy	11000.00
0005433681731	29179	Economy	11000.00
0005433681499	29179	Economy	11000.00
0005433687734	29179	Economy	11000.00
0005433681543	29179	Economy	11000.00
0005432967649	29179	Economy	11000.00
0005433681461	29179	Economy	11000.00
0005433681555	29179	Economy	11000.00
0005433681492	29179	Economy	11000.00
0005432967653	29179	Economy	11000.00
0005433681378	29179	Economy	11000.00
0005433681491	29179	Economy	11000.00
0005433681537	29179	Economy	11000.00
0005433681590	29179	Economy	11000.00
0005433681697	29179	Economy	11000.00
0005432755168	9321	Business	132900.00
0005434152831	9321	Business	132900.00
0005433578182	9321	Business	132900.00
0005433616672	9321	Business	132900.00
0005433578183	9321	Business	132900.00
0005433578191	9321	Business	132900.00
0005432145166	9321	Business	132900.00
0005433616699	9321	Business	132900.00
0005433634743	9321	Business	132900.00
0005434269145	9321	Business	132900.00
0005433616696	9321	Business	132900.00
0005433616663	9321	Business	132900.00
0005433634762	9321	Business	132900.00
0005433634748	9321	Business	132900.00
0005433616710	9321	Business	132900.00
0005433616664	9321	Business	132900.00
0005432755170	9321	Economy	48700.00
0005433634739	9321	Economy	48700.00
0005433634751	9321	Economy	48700.00
0005434272225	9321	Economy	44300.00
0005433634756	9321	Economy	44300.00
0005433634746	9321	Economy	44300.00
0005433616678	9321	Economy	44300.00
0005433616668	9321	Economy	44300.00
0005433634747	9321	Economy	44300.00
0005434163800	9321	Economy	44300.00
0005433616676	9321	Economy	44300.00
0005433616686	9321	Economy	44300.00
0005433634757	9321	Economy	44300.00
0005433616677	9321	Economy	44300.00
0005432756936	9321	Economy	44300.00
0005433616669	9321	Economy	44300.00
0005435983704	9321	Economy	44300.00
0005433634753	9321	Economy	44300.00
0005433616702	9321	Economy	44300.00
0005433616694	9321	Economy	44300.00
0005434272217	9321	Economy	44300.00
0005432756938	9321	Economy	44300.00
0005432755169	9321	Economy	44300.00
0005433634754	9321	Economy	44300.00
0005433634755	9321	Economy	44300.00
0005433616707	9321	Economy	44300.00
0005433616708	9321	Economy	44300.00
0005434163805	9321	Economy	44300.00
0005433616673	9321	Economy	44300.00
0005433634758	9321	Economy	44300.00
0005433616700	9321	Economy	44300.00
0005433616671	9321	Economy	44300.00
0005433616709	9321	Economy	44300.00
0005433616680	9321	Economy	44300.00
0005433634765	9321	Economy	44300.00
0005433634744	9321	Economy	44300.00
0005434163809	9321	Economy	44300.00
0005433634741	9321	Economy	44300.00
0005433578184	9321	Economy	44300.00
0005433616698	9321	Economy	44300.00
0005433578188	9321	Economy	44300.00
0005434163799	9321	Economy	44300.00
0005433616666	9321	Economy	44300.00
0005433616689	9321	Economy	44300.00
0005434163820	9321	Economy	44300.00
0005433616693	9321	Economy	44300.00
0005433634761	9321	Economy	48700.00
0005432145167	9321	Economy	48700.00
0005433616670	9321	Economy	48700.00
0005433634745	9321	Economy	44300.00
0005433616687	9321	Economy	44300.00
0005433634750	9321	Economy	44300.00
0005433616692	9321	Economy	44300.00
0005433616660	9321	Economy	44300.00
0005433616661	9321	Economy	48700.00
0005433616705	9321	Economy	44300.00
0005433616674	9321	Economy	44300.00
0005434272224	9321	Economy	44300.00
0005433616681	9321	Economy	44300.00
0005433634742	9321	Economy	44300.00
0005433616695	9321	Economy	44300.00
0005433578185	9321	Economy	44300.00
0005433616685	9321	Economy	44300.00
0005433616688	9321	Economy	44300.00
0005433616711	9321	Economy	44300.00
0005433616703	9321	Economy	44300.00
0005433616690	9321	Economy	44300.00
0005433616691	9321	Economy	44300.00
0005433616682	9321	Economy	44300.00
0005433578186	9321	Economy	44300.00
0005433616704	9321	Economy	44300.00
0005433634752	9321	Economy	44300.00
0005433634764	9321	Economy	44300.00
0005433578190	9321	Economy	44300.00
0005434163777	9321	Economy	44300.00
0005433616697	9321	Economy	44300.00
0005433616667	9321	Economy	44300.00
0005433634763	9321	Economy	44300.00
0005433616679	9321	Economy	44300.00
0005433634759	9321	Economy	44300.00
0005433578187	9321	Economy	44300.00
0005433616665	9321	Economy	44300.00
0005433634740	9321	Economy	44300.00
0005433634766	9321	Economy	44300.00
0005434152832	9321	Economy	44300.00
0005433616659	9321	Economy	44300.00
0005434163778	9321	Economy	44300.00
0005433578189	9321	Economy	44300.00
0005435983703	9321	Economy	44300.00
0005433634749	9321	Economy	44300.00
0005433616675	9321	Economy	44300.00
0005433616662	9321	Economy	44300.00
0005434152830	9321	Economy	44300.00
0005433616684	9321	Economy	44300.00
0005434163821	9321	Economy	44300.00
0005433616683	9321	Economy	44300.00
0005434272216	9321	Economy	44300.00
0005432145168	9321	Economy	44300.00
0005432756937	9321	Economy	44300.00
0005433634760	9321	Economy	44300.00
0005433616712	9321	Economy	44300.00
0005433616701	9321	Economy	44300.00
0005434269144	9321	Economy	44300.00
0005433616706	9321	Economy	44300.00
0005434272221	9321	Economy	44300.00
0005433616201	25247	Business	132900.00
0005432755134	25247	Business	132900.00
0005434272234	25247	Business	132900.00
0005434152846	25247	Business	132900.00
0005433615775	25247	Business	132900.00
0005433634518	25247	Business	132900.00
0005433616302	25247	Business	132900.00
0005434273122	25247	Business	132900.00
0005433616143	25247	Business	132900.00
0005432751579	25247	Business	132900.00
0005433615887	25247	Business	132900.00
0005433616142	25247	Business	132900.00
0005433616102	25247	Business	132900.00
0005433616340	25247	Business	132900.00
0005433616266	25247	Business	132900.00
0005433615999	25247	Business	132900.00
0005433615843	25247	Business	132900.00
0005433616070	25247	Business	132900.00
0005433615980	25247	Business	132900.00
0005433634573	25247	Business	132900.00
0005433634404	25247	Business	132900.00
0005433616055	25247	Business	132900.00
0005434163870	25247	Business	132900.00
0005433616268	25247	Business	132900.00
0005433615923	25247	Business	132900.00
0005434163874	25247	Business	132900.00
0005433615858	25247	Business	132900.00
0005433616110	25247	Economy	48700.00
0005433634355	25247	Economy	48700.00
0005433578091	25247	Economy	48700.00
0005432755114	25247	Economy	48700.00
0005433615935	25247	Economy	48700.00
0005433616267	25247	Economy	44300.00
0005433634268	25247	Economy	44300.00
0005433616032	25247	Economy	44300.00
0005433615971	25247	Economy	44300.00
0005433616401	25247	Economy	44300.00
0005433578072	25247	Economy	44300.00
0005433615849	25247	Economy	44300.00
0005432755138	25247	Economy	44300.00
0005433616312	25247	Economy	44300.00
0005433616371	25247	Economy	44300.00
0005433578057	25247	Economy	44300.00
0005433616339	25247	Economy	44300.00
0005433634401	25247	Economy	44300.00
0005433616207	25247	Economy	44300.00
0005433634525	25247	Economy	44300.00
0005432755135	25247	Economy	44300.00
0005433634331	25247	Economy	44300.00
0005433616126	25247	Economy	44300.00
0005433578100	25247	Economy	44300.00
0005433616372	25247	Economy	44300.00
0005433615943	25247	Economy	44300.00
0005432751585	25247	Economy	44300.00
0005433634351	25247	Economy	44300.00
0005433615924	25247	Economy	44300.00
0005433616203	25247	Economy	44300.00
0005433634300	25247	Economy	44300.00
0005434152850	25247	Economy	44300.00
0005434152848	25247	Economy	44300.00
0005433578105	25247	Economy	44300.00
0005433616324	25247	Economy	44300.00
0005433616208	25247	Economy	44300.00
0005434273121	25247	Economy	44300.00
0005433578058	25247	Economy	44300.00
0005433634301	25247	Economy	44300.00
0005433616400	25247	Economy	44300.00
0005433616111	25247	Economy	44300.00
0005433615664	25247	Economy	44300.00
0005433615831	25247	Economy	44300.00
0005433616185	25247	Economy	44300.00
0005433616314	25247	Economy	44300.00
0005433616031	25247	Economy	44300.00
0005433615925	25247	Economy	44300.00
0005433616200	25247	Economy	44300.00
0005434152847	25247	Economy	44300.00
0005433615993	25247	Economy	44300.00
0005432755128	25247	Economy	44300.00
0005432755126	25247	Economy	44300.00
0005433634332	25247	Economy	44300.00
0005432755121	25247	Economy	44300.00
0005433615857	25247	Economy	44300.00
0005433616113	25247	Economy	44300.00
0005434151810	25247	Economy	44300.00
0005433616361	25247	Economy	44300.00
0005433616386	25247	Economy	44300.00
0005433634407	25247	Economy	44300.00
0005433634495	25247	Economy	44300.00
0005433578074	25247	Economy	44300.00
0005433616229	25247	Economy	44300.00
0005432755113	25247	Economy	44300.00
0005434151809	25247	Economy	44300.00
0005433616323	25247	Economy	48700.00
0005433615859	25247	Economy	48700.00
0005432755130	25247	Economy	48700.00
0005433616162	25247	Economy	48700.00
0005433616215	25247	Economy	48700.00
0005433615942	25247	Economy	44300.00
0005434163869	25247	Economy	44300.00
0005433634602	25247	Economy	44300.00
0005433615979	25247	Economy	44300.00
0005432755139	25247	Economy	48700.00
0005433615973	25247	Economy	44300.00
0005433578065	25247	Economy	44300.00
0005433634510	25247	Economy	44300.00
0005432751583	25247	Economy	44300.00
0005433634283	25247	Economy	44300.00
0005434163873	25247	Economy	44300.00
0005433616373	25247	Economy	44300.00
0005433615844	25247	Economy	44300.00
0005433634261	25247	Economy	44300.00
0005432755127	25247	Economy	44300.00
0005433615946	25247	Economy	44300.00
0005433634394	25247	Economy	44300.00
0005433578089	25247	Economy	44300.00
0005433578092	25247	Economy	44300.00
0005433616163	25247	Economy	44300.00
0005433616230	25247	Economy	44300.00
0005433634467	25247	Economy	44300.00
0005434163868	25247	Economy	44300.00
0005433578069	25247	Economy	44300.00
0005433616216	25247	Economy	44300.00
0005433578063	25247	Economy	44300.00
0005433616365	25247	Economy	44300.00
0005433578064	25247	Economy	44300.00
0005433616204	25247	Economy	44300.00
0005434273133	25247	Economy	44300.00
0005434151812	25247	Economy	44300.00
0005433615897	25247	Economy	44300.00
0005432755140	25247	Economy	44300.00
0005434273134	25247	Economy	44300.00
0005434152849	25247	Economy	44300.00
0005433616301	25247	Economy	44300.00
0005433615944	25247	Economy	44300.00
0005433616124	25247	Economy	44300.00
0005433578090	25247	Economy	44300.00
0005433634395	25247	Economy	44300.00
0005432751584	25247	Economy	44300.00
0005434151814	25247	Economy	44300.00
0005434163872	25247	Economy	44300.00
0005433616127	25247	Economy	44300.00
0005433615972	25247	Economy	44300.00
0005432755129	25247	Economy	44300.00
0005434151813	25247	Economy	44300.00
0005433616282	25247	Economy	44300.00
0005433616260	25247	Economy	44300.00
0005432755122	25247	Economy	44300.00
0005433616079	25247	Economy	44300.00
0005434151815	25247	Economy	44300.00
0005434152845	25247	Economy	44300.00
0005433634414	25247	Economy	44300.00
0005434151811	25247	Economy	44300.00
0005433578073	25247	Economy	44300.00
0005433615992	25247	Economy	44300.00
0005433615666	25247	Economy	44300.00
0005433615665	25247	Economy	44300.00
0005433578071	25247	Economy	44300.00
0005433616161	25247	Economy	44300.00
0005433616053	25247	Economy	44300.00
0005433615959	25247	Economy	44300.00
0005433615997	25247	Economy	44300.00
0005433578059	25247	Economy	44300.00
0005433634496	25247	Economy	44300.00
0005433634517	25247	Economy	44300.00
0005434163871	25247	Economy	44300.00
0005433616024	25247	Economy	44300.00
0005435947555	4228	Business	193100.00
0005435856306	4228	Business	193100.00
0005435947592	4228	Business	193100.00
0005435947480	4228	Business	193100.00
0005435947502	4228	Business	193100.00
0005435947557	4228	Economy	64400.00
0005435987025	4228	Economy	64400.00
0005435987021	4228	Economy	64400.00
0005435987022	4228	Economy	64400.00
0005435987026	4228	Economy	64400.00
0005435856300	4228	Economy	64400.00
0005435987020	4228	Economy	64400.00
0005435856303	4228	Economy	64400.00
0005434271357	4228	Economy	64400.00
0005435947558	4228	Economy	64400.00
0005435987032	4228	Economy	64400.00
0005435947501	4228	Economy	64400.00
0005435856301	4228	Economy	64400.00
0005435856295	4228	Economy	64400.00
0005435987031	4228	Economy	64400.00
0005435987029	4228	Economy	70800.00
0005435947506	4228	Economy	64400.00
0005435787392	4228	Economy	64400.00
0005432571391	4228	Economy	64400.00
0005435987027	4228	Economy	64400.00
0005435987028	4228	Economy	64400.00
0005435947554	4228	Economy	64400.00
0005432571392	4228	Economy	64400.00
0005435947537	4228	Economy	64400.00
0005435856302	4228	Economy	64400.00
0005435856280	4228	Economy	64400.00
0005435987023	4228	Economy	64400.00
0005435947538	4228	Economy	64400.00
0005435987030	4228	Economy	64400.00
0005435947593	4228	Economy	64400.00
0005435987019	4228	Economy	64400.00
0005435987024	4228	Economy	64400.00
0005435986923	26608	Business	193100.00
0005432571431	26608	Business	193100.00
0005435947662	26608	Economy	64400.00
0005432571430	26608	Economy	64400.00
0005435986904	26608	Economy	64400.00
0005435986947	26608	Economy	64400.00
0005435947665	26608	Economy	64400.00
0005435947663	26608	Economy	64400.00
0005435856358	26608	Economy	64400.00
0005435986888	26608	Economy	64400.00
0005435856324	26608	Economy	64400.00
0005435856326	26608	Economy	64400.00
0005435856359	26608	Economy	64400.00
0005435856360	26608	Economy	64400.00
0005435856325	26608	Economy	64400.00
0005432571433	26608	Economy	64400.00
0005435856357	26608	Economy	70800.00
0005435986879	26608	Economy	64400.00
0005432571432	26608	Economy	64400.00
0005435947661	26608	Economy	64400.00
0005435986910	26608	Economy	64400.00
0005435947664	26608	Economy	64400.00
0005435986948	26608	Economy	64400.00
0005434087970	353	Business	21500.00
0005433570857	353	Business	21500.00
0005433570854	353	Business	21500.00
0005434087973	353	Business	21500.00
0005433570862	353	Business	21500.00
0005433075229	353	Business	21500.00
0005433075268	353	Business	21500.00
0005433570855	353	Business	21500.00
0005433570843	353	Business	21500.00
0005433570856	353	Business	21500.00
0005433570848	353	Business	21500.00
0005432949169	353	Business	21500.00
0005433570869	353	Business	21500.00
0005433570866	353	Business	21500.00
0005433570829	353	Business	21500.00
0005433075286	353	Business	21500.00
0005433570835	353	Business	21500.00
0005434087968	353	Business	21500.00
0005434087981	353	Business	21500.00
0005432949255	353	Business	21500.00
0005434087963	353	Business	21500.00
0005432949243	353	Business	21500.00
0005433134220	353	Business	21500.00
0005433075299	353	Business	21500.00
0005434087966	353	Business	21500.00
0005433075327	353	Business	21500.00
0005433075362	353	Business	21500.00
0005433075285	353	Business	21500.00
0005434087964	353	Economy	7900.00
0005433075117	353	Economy	7900.00
0005433570873	353	Economy	7900.00
0005432949153	353	Economy	7900.00
0005433075419	353	Economy	7900.00
0005433570860	353	Economy	7200.00
0005433570858	353	Economy	7900.00
0005433134237	353	Economy	7200.00
0005433134215	353	Economy	7200.00
0005433075269	353	Economy	7200.00
0005433075360	353	Economy	7200.00
0005433929863	353	Economy	7200.00
0005433570867	353	Economy	7200.00
0005434087980	353	Economy	7200.00
0005434087976	353	Economy	7200.00
0005434087971	353	Economy	7200.00
0005432949325	353	Economy	7200.00
0005434087967	353	Economy	7200.00
0005432949326	353	Economy	7200.00
0005433075303	353	Economy	7200.00
0005432239110	353	Economy	7200.00
0005433570849	353	Economy	7200.00
0005433570874	353	Economy	7200.00
0005433570865	353	Economy	7200.00
0005433075247	353	Economy	7200.00
0005433570850	353	Economy	7200.00
0005433075221	353	Economy	7200.00
0005433134228	353	Economy	7200.00
0005433570830	353	Economy	7200.00
0005433075324	353	Economy	7200.00
0005432949220	353	Economy	7200.00
0005432239109	353	Economy	7200.00
0005433570863	353	Economy	7200.00
0005434087962	353	Economy	7200.00
0005433570832	353	Economy	7200.00
0005432949294	353	Economy	7200.00
0005432949288	353	Economy	7200.00
0005432949070	353	Economy	7200.00
0005432949365	353	Economy	7200.00
0005434087972	353	Economy	7200.00
0005433570845	353	Economy	7200.00
0005432949286	353	Economy	7200.00
0005433570837	353	Economy	7200.00
0005433570871	353	Economy	7200.00
0005433075240	353	Economy	7200.00
0005433570841	353	Economy	7200.00
0005432949237	353	Economy	7200.00
0005433570836	353	Economy	7200.00
0005433570838	353	Economy	7200.00
0005433075400	353	Economy	7200.00
0005434087979	353	Economy	7200.00
0005433075267	353	Economy	7200.00
0005433134229	353	Economy	7200.00
0005433129378	353	Economy	7200.00
0005433075323	353	Economy	7200.00
0005433570852	353	Economy	7200.00
0005433075093	353	Economy	7200.00
0005432949244	353	Economy	7200.00
0005432949224	353	Economy	7200.00
0005434087977	353	Economy	7200.00
0005433570831	353	Economy	7200.00
0005433134218	353	Economy	7200.00
0005433075298	353	Economy	7200.00
0005434087969	353	Economy	7200.00
0005433570842	353	Economy	7900.00
0005433570828	353	Economy	7900.00
0005433570872	353	Economy	7900.00
0005432949160	353	Economy	7900.00
0005433075116	353	Economy	7900.00
0005433075302	353	Economy	7200.00
0005433075388	353	Economy	7200.00
0005432949219	353	Economy	7200.00
0005432949179	353	Economy	7200.00
0005434087978	353	Economy	7200.00
0005433075266	353	Economy	7200.00
0005433570834	353	Economy	7200.00
0005432949256	353	Economy	7200.00
0005434087975	353	Economy	7200.00
0005432949417	353	Economy	7200.00
0005433075421	353	Economy	7200.00
0005433570840	353	Economy	7200.00
0005433075287	353	Economy	7200.00
0005434087974	353	Economy	7200.00
0005433075397	353	Economy	7200.00
0005432949241	353	Economy	7200.00
0005433075326	353	Economy	7200.00
0005434087965	353	Economy	7200.00
0005433075361	353	Economy	7200.00
0005432949152	353	Economy	7200.00
0005433570868	353	Economy	7200.00
0005433134227	353	Economy	7200.00
0005433570851	353	Economy	7200.00
0005433075352	353	Economy	7200.00
0005433075349	353	Economy	7200.00
0005433570833	353	Economy	7200.00
0005432949159	353	Economy	7200.00
0005433570875	353	Economy	7200.00
0005432949314	353	Economy	7200.00
0005433570879	353	Economy	7200.00
0005432949178	353	Economy	7200.00
0005432239107	353	Economy	7200.00
0005433129371	353	Economy	7200.00
0005432239108	353	Economy	7200.00
0005433570876	353	Economy	7200.00
0005432949317	353	Economy	7200.00
0005433570844	353	Economy	7200.00
0005433075420	353	Economy	7200.00
0005433570880	353	Economy	7200.00
0005432949358	353	Economy	7200.00
0005432949313	353	Economy	7200.00
0005433075383	353	Economy	7200.00
0005433570878	353	Economy	7200.00
0005433570853	353	Economy	7200.00
0005433570839	353	Economy	7200.00
0005432949347	353	Economy	7200.00
0005433570859	353	Economy	7200.00
0005432949327	353	Economy	7200.00
0005433570846	353	Economy	7200.00
0005433570864	353	Economy	7200.00
0005432949257	353	Economy	7200.00
0005432949228	353	Economy	7200.00
0005433075276	353	Economy	7200.00
0005433075398	353	Economy	7200.00
0005432949207	353	Economy	7200.00
0005433570847	353	Economy	7200.00
0005432949359	353	Economy	7200.00
0005433134217	353	Economy	7200.00
0005433075210	353	Economy	7200.00
0005433129379	353	Economy	7200.00
0005433134216	353	Economy	7200.00
0005433570877	353	Economy	7200.00
0005433929864	353	Economy	7200.00
0005433570861	353	Economy	7200.00
0005433570870	353	Economy	7200.00
0005433134219	353	Economy	7200.00
0005434087982	353	Economy	7200.00
0005432949242	353	Economy	7200.00
0005432949379	353	Economy	7200.00
0005433570567	11602	Business	21500.00
0005432949596	11602	Business	21500.00
0005433570105	11602	Business	21500.00
0005433570114	11602	Business	21500.00
0005433131833	11602	Business	21500.00
0005433570220	11602	Business	21500.00
0005433570402	11602	Business	21500.00
0005433570230	11602	Business	21500.00
0005433075503	11602	Business	21500.00
0005433075505	11602	Business	21500.00
0005433570198	11602	Business	21500.00
0005433075506	11602	Business	21500.00
0005433570284	11602	Business	21500.00
0005433570077	11602	Business	21500.00
0005433570062	11602	Business	21500.00
0005433569922	11602	Business	21500.00
0005434087920	11602	Business	21500.00
0005432192409	11602	Economy	7900.00
0005433570083	11602	Economy	7900.00
0005433075504	11602	Economy	7200.00
0005433570011	11602	Economy	7200.00
0005433075510	11602	Economy	7200.00
0005433570082	11602	Economy	7200.00
0005432949586	11602	Economy	7200.00
0005433570104	11602	Economy	7200.00
0005433570196	11602	Economy	7200.00
0005432949592	11602	Economy	7200.00
0005434087919	11602	Economy	7200.00
0005432949595	11602	Economy	7200.00
0005433570251	11602	Economy	7200.00
0005433570055	11602	Economy	7200.00
0005432949591	11602	Economy	7200.00
0005433075497	11602	Economy	7200.00
0005433569992	11602	Economy	7200.00
0005433570038	11602	Economy	7200.00
0005432949597	11602	Economy	7200.00
0005432949610	11602	Economy	7200.00
0005433134259	11602	Economy	7200.00
0005434087921	11602	Economy	7200.00
0005432949601	11602	Economy	7200.00
0005433570037	11602	Economy	7200.00
0005432949606	11602	Economy	7200.00
0005432949593	11602	Economy	7200.00
0005433075499	11602	Economy	7200.00
0005433570229	11602	Economy	7200.00
0005433570403	11602	Economy	7200.00
0005433075512	11602	Economy	7200.00
0005433569870	11602	Economy	7200.00
0005433569871	11602	Economy	7200.00
0005432949588	11602	Economy	7200.00
0005433134260	11602	Economy	7200.00
0005433570223	11602	Economy	7200.00
0005433570120	11602	Economy	7200.00
0005433570190	11602	Economy	7200.00
0005433570152	11602	Economy	7200.00
0005433131834	11602	Economy	7200.00
0005433570252	11602	Economy	7200.00
0005433075509	11602	Economy	7200.00
0005433570398	11602	Economy	7200.00
0005433075498	11602	Economy	7200.00
0005432949602	11602	Economy	7200.00
0005432192408	11602	Economy	7200.00
0005433570027	11602	Economy	7200.00
0005433131832	11602	Economy	7200.00
0005433569907	11602	Economy	7200.00
0005433569767	11602	Economy	7200.00
0005433570408	11602	Economy	7900.00
0005433075508	11602	Economy	7900.00
0005432949590	11602	Economy	7900.00
0005433569974	11602	Economy	7200.00
0005433570293	11602	Economy	7200.00
0005432949600	11602	Economy	7200.00
0005433570350	11602	Economy	7200.00
0005433569921	11602	Economy	7200.00
0005432949605	11602	Economy	7200.00
0005433075501	11602	Economy	7200.00
0005433569857	11602	Economy	7200.00
0005433570006	11602	Economy	7200.00
0005433570382	11602	Economy	7200.00
0005432949607	11602	Economy	7200.00
0005433570219	11602	Economy	7200.00
0005433075511	11602	Economy	7200.00
0005432949589	11602	Economy	7200.00
0005432949599	11602	Economy	7200.00
0005433570119	11602	Economy	7200.00
0005433570199	11602	Economy	7200.00
0005433569991	11602	Economy	7200.00
0005433570224	11602	Economy	7200.00
0005433570197	11602	Economy	7200.00
0005432949598	11602	Economy	7200.00
0005433075507	11602	Economy	7200.00
0005433570061	11602	Economy	7200.00
0005433075500	11602	Economy	7200.00
0005433570211	11602	Economy	7200.00
0005433075496	11602	Economy	7200.00
0005433570375	11602	Economy	7200.00
0005433570360	11602	Economy	7200.00
0005433570122	11602	Economy	7200.00
0005433075513	11602	Economy	7200.00
0005433570464	11602	Economy	7200.00
0005433570054	11602	Economy	7200.00
0005432949603	11602	Economy	7200.00
0005433570084	11602	Economy	7200.00
0005433570212	11602	Economy	7200.00
0005432949608	11602	Economy	7200.00
0005433570100	11602	Economy	7200.00
0005433131835	11602	Economy	7200.00
0005433075502	11602	Economy	7200.00
0005433570028	11602	Economy	7200.00
0005432949604	11602	Economy	7200.00
0005432949587	11602	Economy	7200.00
0005432949609	11602	Economy	7200.00
0005432949594	11602	Economy	7200.00
0005433570409	11602	Economy	7200.00
0005433570189	11602	Economy	7200.00
0005433817573	10036	Economy	6300.00
0005434733049	10036	Economy	6300.00
0005434733048	10036	Economy	6300.00
0005434733051	10036	Economy	6300.00
0005434733050	10036	Economy	6300.00
0005434733047	10036	Economy	6300.00
0005433817574	10036	Economy	6300.00
0005434733067	10036	Economy	6300.00
0005434733081	13929	Economy	6300.00
0005433817551	13929	Economy	6300.00
0005432985776	2345	Business	184500.00
0005433755775	2345	Business	184500.00
0005433435295	2345	Business	184500.00
0005433435208	2345	Business	184500.00
0005435983585	2345	Business	184500.00
0005432985834	2345	Business	184500.00
0005433755780	2345	Business	184500.00
0005433766766	2345	Business	184500.00
0005432655875	2345	Business	184500.00
0005433755806	2345	Business	184500.00
0005433755804	2345	Business	184500.00
0005433755779	2345	Business	184500.00
0005433755790	2345	Business	184500.00
0005433755785	2345	Business	184500.00
0005433755796	2345	Business	184500.00
0005435983588	2345	Business	184500.00
0005432985597	2345	Business	184500.00
0005433435285	2345	Business	184500.00
0005434731259	2345	Economy	67700.00
0005433435209	2345	Economy	67700.00
0005433435290	2345	Economy	67700.00
0005433755783	2345	Economy	67700.00
0005435983596	2345	Economy	61500.00
0005432869661	2345	Economy	61500.00
0005432985772	2345	Economy	61500.00
0005435983592	2345	Economy	61500.00
0005435983600	2345	Economy	61500.00
0005435983602	2345	Economy	61500.00
0005435983583	2345	Economy	61500.00
0005432985773	2345	Economy	61500.00
0005432985611	2345	Economy	61500.00
0005432985591	2345	Economy	61500.00
0005433755799	2345	Economy	61500.00
0005433435132	2345	Economy	61500.00
0005435983614	2345	Economy	61500.00
0005432655880	2345	Economy	61500.00
0005433766747	2345	Economy	61500.00
0005432655879	2345	Economy	61500.00
0005432655873	2345	Economy	61500.00
0005433755787	2345	Economy	61500.00
0005435983609	2345	Economy	61500.00
0005432655872	2345	Economy	61500.00
0005433755802	2345	Economy	61500.00
0005433435210	2345	Economy	61500.00
0005432985803	2345	Economy	61500.00
0005432869618	2345	Economy	61500.00
0005433435219	2345	Economy	61500.00
0005433435284	2345	Economy	61500.00
0005432226234	2345	Economy	61500.00
0005435983612	2345	Economy	61500.00
0005435983599	2345	Economy	61500.00
0005435983586	2345	Economy	61500.00
0005433435201	2345	Economy	61500.00
0005435983608	2345	Economy	61500.00
0005433755803	2345	Economy	61500.00
0005432869651	2345	Economy	61500.00
0005433755786	2345	Economy	61500.00
0005433766764	2345	Economy	61500.00
0005432226230	2345	Economy	61500.00
0005435983590	2345	Economy	61500.00
0005433755789	2345	Economy	61500.00
0005432300430	2345	Economy	61500.00
0005435983591	2345	Economy	61500.00
0005433755811	2345	Economy	61500.00
0005433755809	2345	Economy	61500.00
0005432869642	2345	Economy	61500.00
0005432655871	2345	Economy	61500.00
0005435983595	2345	Economy	61500.00
0005433755800	2345	Economy	61500.00
0005435983594	2345	Economy	61500.00
0005433435299	2345	Economy	61500.00
0005435983610	2345	Economy	61500.00
0005433766749	2345	Economy	61500.00
0005432869643	2345	Economy	61500.00
0005433755792	2345	Economy	61500.00
0005432985705	2345	Economy	61500.00
0005432226232	2345	Economy	61500.00
0005435983605	2345	Economy	61500.00
0005433755784	2345	Economy	61500.00
0005432985799	2345	Economy	61500.00
0005432985778	2345	Economy	61500.00
0005432655870	2345	Economy	61500.00
0005432985875	2345	Economy	61500.00
0005433435193	2345	Economy	61500.00
0005432985824	2345	Economy	61500.00
0005433435188	2345	Economy	61500.00
0005432300428	2345	Economy	61500.00
0005432985595	2345	Economy	61500.00
0005433435246	2345	Economy	61500.00
0005435983613	2345	Economy	61500.00
0005432869666	2345	Economy	61500.00
0005435983611	2345	Economy	61500.00
0005433755794	2345	Economy	61500.00
0005433435298	2345	Economy	61500.00
0005433435192	2345	Economy	61500.00
0005432300427	2345	Economy	61500.00
0005433755782	2345	Economy	61500.00
0005433435256	2345	Economy	61500.00
0005435983587	2345	Economy	67700.00
0005433435221	2345	Economy	61500.00
0005433766765	2345	Economy	67700.00
0005433435283	2345	Economy	67700.00
0005433755791	2345	Economy	61500.00
0005433755795	2345	Economy	61500.00
0005433755777	2345	Economy	61500.00
0005433755781	2345	Economy	61500.00
0005435983589	2345	Economy	61500.00
0005432226231	2345	Economy	61500.00
0005432300429	2345	Economy	61500.00
0005433755793	2345	Economy	61500.00
0005435983597	2345	Economy	61500.00
0005432985874	2345	Economy	61500.00
0005433755773	2345	Economy	61500.00
0005433435296	2345	Economy	61500.00
0005435983582	2345	Economy	61500.00
0005433755778	2345	Economy	61500.00
0005433755810	2345	Economy	61500.00
0005432226229	2345	Economy	61500.00
0005435983601	2345	Economy	61500.00
0005432869662	2345	Economy	61500.00
0005433755808	2345	Economy	61500.00
0005433435237	2345	Economy	61500.00
0005435983593	2345	Economy	61500.00
0005435983603	2345	Economy	61500.00
0005433755798	2345	Economy	61500.00
0005433755797	2345	Economy	61500.00
0005435983606	2345	Economy	61500.00
0005432655877	2345	Economy	61500.00
0005432985592	2345	Economy	61500.00
0005432655876	2345	Economy	61500.00
0005432869667	2345	Economy	61500.00
0005435983598	2345	Economy	61500.00
0005433755774	2345	Economy	61500.00
0005433435245	2345	Economy	61500.00
0005432985775	2345	Economy	61500.00
0005432985562	2345	Economy	61500.00
0005433755807	2345	Economy	61500.00
0005432985731	2345	Economy	61500.00
0005433435274	2345	Economy	61500.00
0005433766746	2345	Economy	61500.00
0005432869658	2345	Economy	61500.00
0005432655878	2345	Economy	61500.00
0005435983604	2345	Economy	61500.00
0005433755788	2345	Economy	61500.00
0005433766745	2345	Economy	61500.00
0005432655874	2345	Economy	61500.00
0005435983607	2345	Economy	61500.00
0005432985594	2345	Economy	61500.00
0005432985765	2345	Economy	61500.00
0005433435102	2345	Economy	61500.00
0005432985786	2345	Economy	61500.00
0005435983581	2345	Economy	61500.00
0005433755801	2345	Economy	61500.00
0005435983584	2345	Economy	61500.00
0005433435334	2345	Economy	61500.00
0005433755805	2345	Economy	61500.00
0005433755776	2345	Economy	61500.00
0005433766748	2345	Economy	61500.00
0005432226233	2345	Economy	61500.00
0005433755326	26164	Business	184500.00
0005435983185	26164	Business	184500.00
0005433435463	26164	Business	184500.00
0005432985970	26164	Business	184500.00
0005433755540	26164	Business	184500.00
0005433755367	26164	Business	184500.00
0005435983119	26164	Business	184500.00
0005433755636	26164	Business	184500.00
0005433755507	26164	Business	184500.00
0005432655813	26164	Business	184500.00
0005432051217	26164	Business	184500.00
0005433755165	26164	Business	184500.00
0005433755359	26164	Business	184500.00
0005433755164	26164	Business	184500.00
0005435983004	26164	Business	184500.00
0005432655791	26164	Business	184500.00
0005435983001	26164	Business	184500.00
0005433435454	26164	Business	184500.00
0005435983199	26164	Business	184500.00
0005432985982	26164	Business	184500.00
0005435983239	26164	Economy	67700.00
0005435983049	26164	Economy	67700.00
0005433766710	26164	Economy	61500.00
0005435983280	26164	Economy	61500.00
0005432985975	26164	Economy	61500.00
0005432049565	26164	Economy	61500.00
0005433755589	26164	Economy	61500.00
0005432985964	26164	Economy	61500.00
0005433755196	26164	Economy	61500.00
0005432985976	26164	Economy	61500.00
0005433755444	26164	Economy	61500.00
0005433755276	26164	Economy	61500.00
0005435983233	26164	Economy	61500.00
0005432985974	26164	Economy	61500.00
0005433435465	26164	Economy	61500.00
0005433755319	26164	Economy	61500.00
0005433755387	26164	Economy	61500.00
0005432985979	26164	Economy	61500.00
0005435982995	26164	Economy	61500.00
0005432985973	26164	Economy	61500.00
0005435983194	26164	Economy	61500.00
0005432869710	26164	Economy	61500.00
0005435983293	26164	Economy	61500.00
0005433435462	26164	Economy	61500.00
0005433755227	26164	Economy	61500.00
0005432655775	26164	Economy	61500.00
0005432051218	26164	Economy	61500.00
0005433755553	26164	Economy	61500.00
0005433755228	26164	Economy	61500.00
0005432655785	26164	Economy	61500.00
0005435983186	26164	Economy	61500.00
0005435983076	26164	Economy	61500.00
0005433755425	26164	Economy	61500.00
0005435983077	26164	Economy	61500.00
0005433755574	26164	Economy	61500.00
0005434376166	26164	Economy	61500.00
0005433435453	26164	Economy	61500.00
0005433435469	26164	Economy	61500.00
0005435983118	26164	Economy	61500.00
0005432985971	26164	Economy	61500.00
0005433435468	26164	Economy	61500.00
0005433755304	26164	Economy	61500.00
0005432985972	26164	Economy	61500.00
0005432869709	26164	Economy	61500.00
0005433755327	26164	Economy	61500.00
0005433755509	26164	Economy	61500.00
0005433755499	26164	Economy	61500.00
0005435983153	26164	Economy	61500.00
0005432985966	26164	Economy	61500.00
0005435983232	26164	Economy	61500.00
0005433755508	26164	Economy	61500.00
0005433755467	26164	Economy	61500.00
0005433755492	26164	Economy	61500.00
0005435983136	26164	Economy	61500.00
0005435982942	26164	Economy	61500.00
0005432655748	26164	Economy	61500.00
0005435982987	26164	Economy	61500.00
0005433755461	26164	Economy	61500.00
0005432985967	26164	Economy	61500.00
0005433755229	26164	Economy	61500.00
0005433435457	26164	Economy	61500.00
0005433755198	26164	Economy	61500.00
0005432869708	26164	Economy	61500.00
0005433755510	26164	Economy	61500.00
0005435983234	26164	Economy	61500.00
0005433755329	26164	Economy	61500.00
0005433755588	26164	Economy	61500.00
0005435983175	26164	Economy	61500.00
0005433755185	26164	Economy	61500.00
0005433755462	26164	Economy	61500.00
0005433755277	26164	Economy	61500.00
0005433755197	26164	Economy	61500.00
0005433755341	26164	Economy	61500.00
0005433435456	26164	Economy	61500.00
0005435983225	26164	Economy	61500.00
0005432985980	26164	Economy	61500.00
0005432655770	26164	Economy	61500.00
0005435983192	26164	Economy	61500.00
0005432655769	26164	Economy	61500.00
0005433435464	26164	Economy	61500.00
0005435983338	26164	Economy	61500.00
0005435983224	26164	Economy	67700.00
0005433755575	26164	Economy	61500.00
0005433755506	26164	Economy	61500.00
0005433755456	26164	Economy	61500.00
0005433435460	26164	Economy	67700.00
0005435983156	26164	Economy	61500.00
0005435982941	26164	Economy	61500.00
0005433755177	26164	Economy	61500.00
0005432985981	26164	Economy	61500.00
0005433755578	26164	Economy	61500.00
0005433755328	26164	Economy	61500.00
0005435983166	26164	Economy	61500.00
0005432985978	26164	Economy	61500.00
0005433755439	26164	Economy	61500.00
0005433764721	26164	Economy	61500.00
0005435983078	26164	Economy	61500.00
0005433755082	26164	Economy	61500.00
0005435983229	26164	Economy	61500.00
0005432869707	26164	Economy	61500.00
0005433755579	26164	Economy	61500.00
0005435983083	26164	Economy	61500.00
0005433755384	26164	Economy	61500.00
0005433755323	26164	Economy	61500.00
0005435983189	26164	Economy	61500.00
0005435983084	26164	Economy	61500.00
0005435983050	26164	Economy	61500.00
0005435983193	26164	Economy	61500.00
0005433755320	26164	Economy	61500.00
0005432985969	26164	Economy	61500.00
0005433755324	26164	Economy	61500.00
0005433435467	26164	Economy	61500.00
0005432655790	26164	Economy	61500.00
0005433755404	26164	Economy	61500.00
0005433755050	26164	Economy	61500.00
0005433755358	26164	Economy	61500.00
0005432985977	26164	Economy	61500.00
0005433755366	26164	Economy	61500.00
0005433755432	26164	Economy	61500.00
0005433435458	26164	Economy	61500.00
0005433755388	26164	Economy	61500.00
0005435983196	26164	Economy	61500.00
0005433435455	26164	Economy	61500.00
0005432655747	26164	Economy	61500.00
0005433435466	26164	Economy	61500.00
0005432985965	26164	Economy	61500.00
0005433755154	26164	Economy	61500.00
0005432869712	26164	Economy	61500.00
0005433435452	26164	Economy	61500.00
0005435983282	26164	Economy	61500.00
0005433435459	26164	Economy	61500.00
0005433755318	26164	Economy	61500.00
0005433755431	26164	Economy	61500.00
0005432655774	26164	Economy	61500.00
0005432049564	26164	Economy	61500.00
0005432869711	26164	Economy	61500.00
0005432985968	26164	Economy	61500.00
0005435983240	26164	Economy	61500.00
0005435983370	26164	Economy	61500.00
0005433435461	26164	Economy	61500.00
0005435983091	26164	Economy	61500.00
0005432049563	26164	Economy	61500.00
0005435983165	26164	Economy	61500.00
0005433755331	26164	Economy	61500.00
0005435983031	26164	Economy	61500.00
0005433755469	26164	Economy	61500.00
0005433152188	1534	Business	38900.00
0005433152190	1534	Business	38900.00
0005433764718	1534	Business	38900.00
0005433152000	1534	Business	38900.00
0005432268085	1534	Business	38900.00
0005434375964	1534	Business	38900.00
0005434375987	1534	Business	38900.00
0005434375960	1534	Business	38900.00
0005434375981	1534	Business	38900.00
0005434375977	1534	Economy	13000.00
0005433152193	1534	Economy	13000.00
0005433152030	1534	Economy	13000.00
0005432268084	1534	Economy	13000.00
0005434376165	1534	Economy	13000.00
0005434375990	1534	Economy	13000.00
0005434375976	1534	Economy	13000.00
0005433152192	1534	Economy	13000.00
0005433152158	1534	Economy	13000.00
0005433152037	1534	Economy	13000.00
0005434375961	1534	Economy	13000.00
0005433151959	1534	Economy	13000.00
0005434375983	1534	Economy	13000.00
0005433152199	1534	Economy	13000.00
0005433152101	1534	Economy	13000.00
0005433931519	1534	Economy	13000.00
0005433152282	1534	Economy	13000.00
0005433764709	1534	Economy	13000.00
0005434375963	1534	Economy	13000.00
0005434375957	1534	Economy	13000.00
0005434375979	1534	Economy	13000.00
0005434375971	1534	Economy	13000.00
0005434375972	1534	Economy	13000.00
0005433152031	1534	Economy	13000.00
0005432268083	1534	Economy	13000.00
0005434375978	1534	Economy	14300.00
0005434375986	1534	Economy	14300.00
0005433152280	1534	Economy	14300.00
0005433152138	1534	Economy	13000.00
0005433152104	1534	Economy	13000.00
0005433152198	1534	Economy	13000.00
0005433931527	1534	Economy	13000.00
0005434375984	1534	Economy	13000.00
0005434376183	1534	Economy	13000.00
0005434375974	1534	Economy	13000.00
0005433152281	1534	Economy	13000.00
0005434375975	1534	Economy	13000.00
0005434376184	1534	Economy	13000.00
0005434375973	1534	Economy	13000.00
0005434375965	1534	Economy	13000.00
0005434375988	1534	Economy	13000.00
0005433151958	1534	Economy	13000.00
0005433152189	1534	Economy	13000.00
0005433460497	1534	Economy	13000.00
0005434375980	1534	Economy	13000.00
0005433152168	1534	Economy	13000.00
0005434375959	1534	Economy	13000.00
0005434376164	1534	Economy	13000.00
0005434375985	1534	Economy	13000.00
0005434376182	1534	Economy	13000.00
0005434375967	1534	Economy	13000.00
0005433152109	1534	Economy	13000.00
0005433764710	1534	Economy	13000.00
0005433152191	1534	Economy	13000.00
0005434375966	1534	Economy	13000.00
0005433151933	1534	Economy	13000.00
0005433152102	1534	Economy	13000.00
0005434375989	1534	Economy	13000.00
0005432268086	1534	Economy	13000.00
0005434375969	1534	Economy	13000.00
0005434375962	1534	Economy	13000.00
0005433152196	1534	Economy	13000.00
0005434375958	1534	Economy	13000.00
0005434375982	1534	Economy	13000.00
0005433152194	1534	Economy	13000.00
0005433152105	1534	Economy	13000.00
0005434375970	1534	Economy	13000.00
0005433152147	1534	Economy	13000.00
0005433461650	1534	Economy	13000.00
0005434375968	1534	Economy	13000.00
0005434375446	20107	Business	38900.00
0005434375632	20107	Business	38900.00
0005434375695	20107	Business	38900.00
0005434375647	20107	Business	38900.00
0005434375640	20107	Business	38900.00
0005433152371	20107	Business	38900.00
0005434375356	20107	Business	38900.00
0005434375437	20107	Economy	13000.00
0005434375502	20107	Economy	13000.00
0005433152364	20107	Economy	13000.00
0005434375535	20107	Economy	13000.00
0005434375685	20107	Economy	13000.00
0005434375551	20107	Economy	13000.00
0005434375723	20107	Economy	13000.00
0005434375453	20107	Economy	13000.00
0005434375503	20107	Economy	13000.00
0005434375693	20107	Economy	13000.00
0005434375696	20107	Economy	13000.00
0005434375710	20107	Economy	13000.00
0005433152377	20107	Economy	13000.00
0005433152365	20107	Economy	13000.00
0005434375638	20107	Economy	13000.00
0005434375447	20107	Economy	13000.00
0005434375686	20107	Economy	13000.00
0005433152363	20107	Economy	13000.00
0005434375767	20107	Economy	13000.00
0005434375588	20107	Economy	13000.00
0005434375701	20107	Economy	13000.00
0005433152369	20107	Economy	14300.00
0005434375585	20107	Economy	14300.00
0005433152375	20107	Economy	14300.00
0005434375586	20107	Economy	14300.00
0005434375665	20107	Economy	13000.00
0005434375621	20107	Economy	13000.00
0005433152370	20107	Economy	13000.00
0005432056404	20107	Economy	13000.00
0005433152366	20107	Economy	13000.00
0005434375606	20107	Economy	13000.00
0005434375694	20107	Economy	13000.00
0005434375521	20107	Economy	13000.00
0005434375510	20107	Economy	13000.00
0005434375369	20107	Economy	13000.00
0005433931553	20107	Economy	13000.00
0005433152367	20107	Economy	13000.00
0005433152361	20107	Economy	13000.00
0005433152373	20107	Economy	13000.00
0005433152372	20107	Economy	13000.00
0005434375448	20107	Economy	13000.00
0005434375550	20107	Economy	13000.00
0005434375597	20107	Economy	13000.00
0005434375639	20107	Economy	13000.00
0005432056403	20107	Economy	13000.00
0005434375425	20107	Economy	13000.00
0005434375648	20107	Economy	13000.00
0005434375307	20107	Economy	13000.00
0005434375598	20107	Economy	13000.00
0005434375549	20107	Economy	13000.00
0005434375379	20107	Economy	13000.00
0005433152368	20107	Economy	13000.00
0005434375652	20107	Economy	13000.00
0005434375498	20107	Economy	13000.00
0005434375722	20107	Economy	13000.00
0005434375466	20107	Economy	13000.00
0005434375667	20107	Economy	13000.00
0005434375472	20107	Economy	13000.00
0005434375674	20107	Economy	13000.00
0005434375570	20107	Economy	13000.00
0005434375504	20107	Economy	13000.00
0005434375673	20107	Economy	13000.00
0005434375467	20107	Economy	13000.00
0005433152362	20107	Economy	13000.00
0005434375637	20107	Economy	13000.00
0005434375605	20107	Economy	13000.00
0005433152374	20107	Economy	13000.00
0005434375329	20107	Economy	13000.00
0005433152376	20107	Economy	13000.00
0005434375488	20107	Economy	13000.00
0005434375424	20107	Economy	13000.00
0005432425840	565	Business	27500.00
0005432425874	565	Business	27500.00
0005432425851	565	Business	27500.00
0005432425863	565	Business	27500.00
0005432425858	565	Business	27500.00
0005432425859	565	Business	27500.00
0005432425825	565	Business	27500.00
0005432283058	565	Business	27500.00
0005432425827	565	Business	27500.00
0005432425882	565	Business	27500.00
0005432425867	565	Economy	9200.00
0005432425847	565	Economy	9200.00
0005432425849	565	Economy	9200.00
0005432425866	565	Economy	9200.00
0005432425862	565	Economy	9200.00
0005432425861	565	Economy	9200.00
0005432425857	565	Economy	9200.00
0005432425855	565	Economy	9200.00
0005432425852	565	Economy	9200.00
0005432425880	565	Economy	9200.00
0005432425881	565	Economy	9200.00
0005432425841	565	Economy	9200.00
0005432425830	565	Economy	9200.00
0005432425842	565	Economy	9200.00
0005432425844	565	Economy	9200.00
0005432425824	565	Economy	9200.00
0005432425877	565	Economy	9200.00
0005432283062	565	Economy	9200.00
0005432425836	565	Economy	9200.00
0005432425875	565	Economy	9200.00
0005432425831	565	Economy	9200.00
0005432425860	565	Economy	9200.00
0005432425871	565	Economy	9200.00
0005432283061	565	Economy	9200.00
0005432425838	565	Economy	9200.00
0005432425837	565	Economy	9200.00
0005432425839	565	Economy	9200.00
0005432425869	565	Economy	9200.00
0005432425845	565	Economy	9200.00
0005432425870	565	Economy	9200.00
0005432425823	565	Economy	10100.00
0005432425846	565	Economy	9200.00
0005432425829	565	Economy	10100.00
0005432425853	565	Economy	9200.00
0005432425868	565	Economy	9200.00
0005432283063	565	Economy	9200.00
0005432425822	565	Economy	9200.00
0005432425854	565	Economy	9200.00
0005432425879	565	Economy	9200.00
0005432425828	565	Economy	9200.00
0005432425856	565	Economy	9200.00
0005432425832	565	Economy	9200.00
0005432425850	565	Economy	9200.00
0005432425826	565	Economy	9200.00
0005432425865	565	Economy	9200.00
0005432425872	565	Economy	9200.00
0005432425833	565	Economy	9200.00
0005432425835	565	Economy	9200.00
0005432425878	565	Economy	9200.00
0005432425876	565	Economy	9200.00
0005432425864	565	Economy	9200.00
0005432425834	565	Economy	9200.00
0005432425843	565	Economy	9200.00
0005432425873	565	Economy	9200.00
0005432283060	565	Economy	9200.00
0005432425848	565	Economy	9200.00
0005432283059	565	Economy	9200.00
0005433262008	12878	Business	27500.00
0005433261999	12878	Business	27500.00
0005433261996	12878	Business	27500.00
0005433262001	12878	Business	27500.00
0005433262007	12878	Economy	10100.00
0005433262003	12878	Economy	10100.00
0005433766764	12878	Economy	9200.00
0005433262002	12878	Economy	9200.00
0005433262000	12878	Economy	9200.00
0005433262004	12878	Economy	9200.00
0005433766765	12878	Economy	9200.00
0005433262005	12878	Economy	9200.00
0005433766766	12878	Economy	9200.00
0005433261997	12878	Economy	10100.00
0005433262012	12878	Economy	9200.00
0005433262006	12878	Economy	9200.00
0005433261998	12878	Economy	9200.00
0005433262010	12878	Economy	9200.00
0005433262011	12878	Economy	9200.00
0005433262009	12878	Economy	9200.00
0005432302437	12878	Economy	9200.00
0005432425455	12861	Business	27500.00
0005432425388	12861	Business	27500.00
0005432425426	12861	Business	27500.00
0005432425342	12861	Business	27500.00
0005432425169	12861	Business	27500.00
0005432425452	12861	Business	27500.00
0005432425421	12861	Business	27500.00
0005432425399	12861	Economy	10100.00
0005432425186	12861	Economy	9200.00
0005432425338	12861	Economy	9200.00
0005432425456	12861	Economy	9200.00
0005432425348	12861	Economy	9200.00
0005432425359	12861	Economy	9200.00
0005432425413	12861	Economy	9200.00
0005432425316	12861	Economy	9200.00
0005432425269	12861	Economy	9200.00
0005432425343	12861	Economy	9200.00
0005432425347	12861	Economy	9200.00
0005432425397	12861	Economy	9200.00
0005432425434	12861	Economy	9200.00
0005432425437	12861	Economy	9200.00
0005432425375	12861	Economy	9200.00
0005432425415	12861	Economy	9200.00
0005432425196	12861	Economy	9200.00
0005432425197	12861	Economy	9200.00
0005432425440	12861	Economy	9200.00
0005432425451	12861	Economy	9200.00
0005432425293	12861	Economy	9200.00
0005432425313	12861	Economy	9200.00
0005432425355	12861	Economy	9200.00
0005432425339	12861	Economy	10100.00
0005432425414	12861	Economy	10100.00
0005432425416	12861	Economy	10100.00
0005432425341	12861	Economy	9200.00
0005432425398	12861	Economy	9200.00
0005432425436	12861	Economy	9200.00
0005432425418	12861	Economy	9200.00
0005432425425	12861	Economy	9200.00
0005432425040	12861	Economy	9200.00
0005432425218	12861	Economy	9200.00
0005432425346	12861	Economy	9200.00
0005432425420	12861	Economy	9200.00
0005432425417	12861	Economy	9200.00
0005432425424	12861	Economy	9200.00
0005432425380	12861	Economy	9200.00
0005432425394	12861	Economy	9200.00
0005432425389	12861	Economy	9200.00
0005432425367	12861	Economy	9200.00
0005432425387	12861	Economy	9200.00
0005432425419	12861	Economy	9200.00
0005434025591	468	Business	24500.00
0005433058750	468	Business	24500.00
0005434025584	468	Business	24500.00
0005433058631	468	Business	24500.00
0005433058785	468	Business	24500.00
0005433058730	468	Business	24500.00
0005434025594	468	Business	24500.00
0005434025605	468	Business	24500.00
0005434025606	468	Business	24500.00
0005434025598	468	Business	24500.00
0005433058898	468	Business	24500.00
0005434025623	468	Business	24500.00
0005434025599	468	Business	24500.00
0005434025610	468	Business	24500.00
0005434025587	468	Business	24500.00
0005434025620	468	Economy	9000.00
0005434025586	468	Economy	9000.00
0005433058847	468	Economy	9000.00
0005433058704	468	Economy	9000.00
0005434028391	468	Economy	8200.00
0005433058887	468	Economy	8200.00
0005434025603	468	Economy	8200.00
0005433058840	468	Economy	8200.00
0005433058783	468	Economy	8200.00
0005433058563	468	Economy	8200.00
0005433058793	468	Economy	8200.00
0005433058786	468	Economy	8200.00
0005434025609	468	Economy	8200.00
0005433058663	468	Economy	8200.00
0005433058900	468	Economy	8200.00
0005433058751	468	Economy	8200.00
0005432235852	468	Economy	8200.00
0005434029725	468	Economy	8200.00
0005433058694	468	Economy	8200.00
0005433058651	468	Economy	8200.00
0005434025613	468	Economy	8200.00
0005434025611	468	Economy	8200.00
0005433058676	468	Economy	8200.00
0005433058839	468	Economy	8200.00
0005433058664	468	Economy	8200.00
0005433058709	468	Economy	8200.00
0005434032149	468	Economy	8200.00
0005434025621	468	Economy	8200.00
0005433058823	468	Economy	8200.00
0005433058748	468	Economy	8200.00
0005434025604	468	Economy	8200.00
0005434025607	468	Economy	8200.00
0005433058634	468	Economy	8200.00
0005433058794	468	Economy	8200.00
0005433058638	468	Economy	8200.00
0005433058819	468	Economy	8200.00
0005433058648	468	Economy	8200.00
0005433058683	468	Economy	8200.00
0005433058795	468	Economy	8200.00
0005434025612	468	Economy	8200.00
0005433058779	468	Economy	8200.00
0005433058675	468	Economy	8200.00
0005433058710	468	Economy	8200.00
0005433058564	468	Economy	8200.00
0005433684459	468	Economy	8200.00
0005433058781	468	Economy	8200.00
0005433058838	468	Economy	8200.00
0005434028389	468	Economy	8200.00
0005434735789	468	Economy	8200.00
0005433058822	468	Economy	8200.00
0005434032152	468	Economy	8200.00
0005434735783	468	Economy	8200.00
0005434025618	468	Economy	8200.00
0005433058780	468	Economy	8200.00
0005433058633	468	Economy	8200.00
0005434032151	468	Economy	8200.00
0005434025592	468	Economy	8200.00
0005434032150	468	Economy	9000.00
0005433058640	468	Economy	8200.00
0005434028388	468	Economy	8200.00
0005434025601	468	Economy	8200.00
0005433929691	468	Economy	8200.00
0005434025616	468	Economy	8200.00
0005433058674	468	Economy	8200.00
0005432235853	468	Economy	8200.00
0005434025590	468	Economy	8200.00
0005432235850	468	Economy	8200.00
0005434025615	468	Economy	8200.00
0005433058800	468	Economy	8200.00
0005433058757	468	Economy	8200.00
0005433058703	468	Economy	8200.00
0005434025597	468	Economy	8200.00
0005433058899	468	Economy	8200.00
0005433684460	468	Economy	8200.00
0005434025622	468	Economy	8200.00
0005434025593	468	Economy	8200.00
0005434025614	468	Economy	8200.00
0005434025619	468	Economy	8200.00
0005433058782	468	Economy	8200.00
0005432235849	468	Economy	8200.00
0005433058765	468	Economy	8200.00
0005433058749	468	Economy	8200.00
0005434025582	468	Economy	8200.00
0005434025602	468	Economy	8200.00
0005433058905	468	Economy	8200.00
0005434028390	468	Economy	8200.00
0005433058768	468	Economy	8200.00
0005433058767	468	Economy	8200.00
0005434025583	468	Economy	8200.00
0005434025585	468	Economy	8200.00
0005434025600	468	Economy	8200.00
0005433929668	468	Economy	8200.00
0005434025588	468	Economy	8200.00
0005434025608	468	Economy	8200.00
0005433684461	468	Economy	8200.00
0005433684453	468	Economy	8200.00
0005434735753	468	Economy	8200.00
0005432235851	468	Economy	8200.00
0005434025589	468	Economy	8200.00
0005434025596	468	Economy	8200.00
0005433058657	468	Economy	8200.00
0005433684452	468	Economy	8200.00
0005434025617	468	Economy	8200.00
0005433058632	468	Economy	8200.00
0005434025595	468	Economy	8200.00
0005434024859	12650	Business	24500.00
0005434025073	12650	Business	24500.00
0005434025197	12650	Business	24500.00
0005433059016	12650	Business	24500.00
0005433059003	12650	Business	24500.00
0005433059020	12650	Business	24500.00
0005433059014	12650	Business	24500.00
0005433059001	12650	Business	24500.00
0005434025238	12650	Business	24500.00
0005433058995	12650	Business	24500.00
0005433059019	12650	Business	24500.00
0005434024912	12650	Business	24500.00
0005434024950	12650	Business	24500.00
0005434025260	12650	Business	24500.00
0005434024983	12650	Business	24500.00
0005434024858	12650	Business	24500.00
0005434025300	12650	Business	24500.00
0005434024903	12650	Business	24500.00
0005434735836	12650	Business	24500.00
0005434025239	12650	Business	24500.00
0005434025146	12650	Business	24500.00
0005432157546	12650	Business	24500.00
0005434025198	12650	Economy	9000.00
0005434735838	12650	Economy	9000.00
0005434024943	12650	Economy	9000.00
0005433059024	12650	Economy	8200.00
0005433059022	12650	Economy	8200.00
0005434025144	12650	Economy	8200.00
0005434025204	12650	Economy	8200.00
0005434025291	12650	Economy	8200.00
0005434025270	12650	Economy	8200.00
0005434032115	12650	Economy	8200.00
0005434024885	12650	Economy	8200.00
0005434028345	12650	Economy	8200.00
0005434024759	12650	Economy	8200.00
0005434032118	12650	Economy	8200.00
0005434032099	12650	Economy	8200.00
0005433059010	12650	Economy	8200.00
0005434025168	12650	Economy	8200.00
0005434024815	12650	Economy	8200.00
0005433059012	12650	Economy	8200.00
0005433059007	12650	Economy	8200.00
0005434028344	12650	Economy	8200.00
0005434025093	12650	Economy	8200.00
0005434024957	12650	Economy	8200.00
0005434025290	12650	Economy	8200.00
0005434028360	12650	Economy	8200.00
0005432156487	12650	Economy	8200.00
0005434025077	12650	Economy	8200.00
0005433059005	12650	Economy	8200.00
0005434025023	12650	Economy	8200.00
0005433059018	12650	Economy	8200.00
0005434028374	12650	Economy	8200.00
0005432156488	12650	Economy	8200.00
0005434025078	12650	Economy	8200.00
0005433059025	12650	Economy	8200.00
0005434025018	12650	Economy	8200.00
0005433059002	12650	Economy	8200.00
0005434024942	12650	Economy	8200.00
0005434025428	12650	Economy	8200.00
0005434025245	12650	Economy	8200.00
0005434024823	12650	Economy	8200.00
0005433058998	12650	Economy	8200.00
0005434025214	12650	Economy	8200.00
0005434024749	12650	Economy	8200.00
0005433059004	12650	Economy	8200.00
0005433059015	12650	Economy	8200.00
0005434024796	12650	Economy	8200.00
0005434025071	12650	Economy	8200.00
0005433059009	12650	Economy	8200.00
0005434024949	12650	Economy	8200.00
0005433059000	12650	Economy	8200.00
0005433684481	12650	Economy	8200.00
0005434735835	12650	Economy	8200.00
0005433058997	12650	Economy	8200.00
0005434025137	12650	Economy	8200.00
0005434032117	12650	Economy	8200.00
0005434032116	12650	Economy	8200.00
0005434025427	12650	Economy	8200.00
0005434028373	12650	Economy	8200.00
0005434024845	12650	Economy	9000.00
0005433059013	12650	Economy	8200.00
0005434025070	12650	Economy	8200.00
0005434025236	12650	Economy	8200.00
0005433059017	12650	Economy	9000.00
0005433058999	12650	Economy	9000.00
0005433059006	12650	Economy	8200.00
0005433929726	12650	Economy	8200.00
0005434024839	12650	Economy	8200.00
0005434028343	12650	Economy	8200.00
0005434024758	12650	Economy	8200.00
0005433684479	12650	Economy	8200.00
0005433684480	12650	Economy	8200.00
0005434024948	12650	Economy	8200.00
0005434025180	12650	Economy	8200.00
0005434032094	12650	Economy	8200.00
0005434024755	12650	Economy	8200.00
0005434025003	12650	Economy	8200.00
0005434025108	12650	Economy	8200.00
0005434735837	12650	Economy	8200.00
0005432157547	12650	Economy	8200.00
0005433059021	12650	Economy	8200.00
0005433059011	12650	Economy	8200.00
0005434025311	12650	Economy	8200.00
0005433059023	12650	Economy	8200.00
0005433059008	12650	Economy	8200.00
0005434032100	12650	Economy	8200.00
0005434025304	12650	Economy	8200.00
0005433929725	12650	Economy	8200.00
0005434024840	12650	Economy	8200.00
0005433058996	12650	Economy	8200.00
0005434025203	12650	Economy	8200.00
0005434025213	12650	Economy	8200.00
0005434024844	12650	Economy	8200.00
0005434025246	12650	Economy	8200.00
0005434025145	12650	Economy	8200.00
0005434025271	12650	Economy	8200.00
0005434025005	12650	Economy	8200.00
0005434025303	12650	Economy	8200.00
0005434024822	12650	Economy	8200.00
0005432157545	12650	Economy	8200.00
0005432156489	12650	Economy	8200.00
0005433527366	13825	Business	111600.00
0005433529376	13825	Business	111600.00
0005433529380	13825	Economy	37200.00
0005433527369	13825	Economy	37200.00
0005433529381	13825	Economy	40900.00
0005433527370	13825	Economy	40900.00
0005433529378	13825	Economy	37200.00
0005433527363	13825	Economy	37200.00
0005433529382	13825	Economy	37200.00
0005433529379	13825	Economy	37200.00
0005433527367	13825	Economy	37200.00
0005433529377	13825	Economy	37200.00
0005433527365	13825	Economy	37200.00
0005433529375	13825	Economy	37200.00
0005433527371	13825	Economy	37200.00
0005433527364	13825	Economy	37200.00
0005433527368	13825	Economy	37200.00
0005433529383	13825	Economy	37200.00
0005433533361	32446	Business	111600.00
0005433529342	32446	Business	111600.00
0005433533389	32446	Economy	37200.00
0005433529340	32446	Economy	40900.00
0005433529344	32446	Economy	37200.00
0005433533403	32446	Economy	37200.00
0005433533385	32446	Economy	37200.00
0005433529353	32446	Economy	37200.00
0005433533404	32446	Economy	37200.00
0005433529333	32446	Economy	37200.00
0005433533375	32446	Economy	37200.00
0005433533360	32446	Economy	37200.00
0005433529343	32446	Economy	37200.00
0005433533388	32446	Economy	37200.00
0005433533367	32446	Economy	37200.00
0005433529323	32446	Economy	37200.00
0005433529332	32446	Economy	37200.00
0005433926005	2128	Business	34700.00
0005434028345	2128	Business	34700.00
0005433925979	2128	Business	34700.00
0005433926014	2128	Business	34700.00
0005433925999	2128	Business	34700.00
0005433925997	2128	Business	34700.00
0005433926009	2128	Business	34700.00
0005433037308	2128	Business	34700.00
0005433925968	2128	Business	34700.00
0005433926008	2128	Business	34700.00
0005433925961	2128	Business	34700.00
0005433925966	2128	Business	34700.00
0005433037334	2128	Business	34700.00
0005432231862	2128	Business	34700.00
0005433037506	2128	Business	34700.00
0005433925983	2128	Business	34700.00
0005433037231	2128	Business	34700.00
0005433037431	2128	Business	34700.00
0005434028374	2128	Business	34700.00
0005432231864	2128	Economy	12700.00
0005433037321	2128	Economy	12700.00
0005433926017	2128	Economy	11600.00
0005433926002	2128	Economy	11600.00
0005433929726	2128	Economy	11600.00
0005433925987	2128	Economy	11600.00
0005433925996	2128	Economy	11600.00
0005433925984	2128	Economy	11600.00
0005433925982	2128	Economy	11600.00
0005433925965	2128	Economy	11600.00
0005433037401	2128	Economy	11600.00
0005433926016	2128	Economy	11600.00
0005433926007	2128	Economy	11600.00
0005433926020	2128	Economy	11600.00
0005433037445	2128	Economy	11600.00
0005433037400	2128	Economy	11600.00
0005433037448	2128	Economy	11600.00
0005433925962	2128	Economy	11600.00
0005433037200	2128	Economy	11600.00
0005433925980	2128	Economy	11600.00
0005433926019	2128	Economy	11600.00
0005433925991	2128	Economy	11600.00
0005433925994	2128	Economy	11600.00
0005433929880	2128	Economy	11600.00
0005433037461	2128	Economy	11600.00
0005433037307	2128	Economy	11600.00
0005433037428	2128	Economy	11600.00
0005433925990	2128	Economy	11600.00
0005432231865	2128	Economy	11600.00
0005433926001	2128	Economy	11600.00
0005433037346	2128	Economy	11600.00
0005433926012	2128	Economy	11600.00
0005433925985	2128	Economy	11600.00
0005433037600	2128	Economy	11600.00
0005433926018	2128	Economy	11600.00
0005433925970	2128	Economy	11600.00
0005433037325	2128	Economy	11600.00
0005433037399	2128	Economy	11600.00
0005433037689	2128	Economy	11600.00
0005433037327	2128	Economy	11600.00
0005433925977	2128	Economy	11600.00
0005433037199	2128	Economy	11600.00
0005433037132	2128	Economy	11600.00
0005433925986	2128	Economy	11600.00
0005433037560	2128	Economy	11600.00
0005433037276	2128	Economy	11600.00
0005433925989	2128	Economy	11600.00
0005433925971	2128	Economy	11600.00
0005433925992	2128	Economy	11600.00
0005433929725	2128	Economy	11600.00
0005433037149	2128	Economy	11600.00
0005433926015	2128	Economy	11600.00
0005434028343	2128	Economy	11600.00
0005433925964	2128	Economy	11600.00
0005433037326	2128	Economy	11600.00
0005433037454	2128	Economy	11600.00
0005433037534	2128	Economy	11600.00
0005433037161	2128	Economy	11600.00
0005433925998	2128	Economy	11600.00
0005433037527	2128	Economy	11600.00
0005433037148	2128	Economy	11600.00
0005433037440	2128	Economy	11600.00
0005433037439	2128	Economy	12700.00
0005432749827	2128	Economy	11600.00
0005433929879	2128	Economy	12700.00
0005433925981	2128	Economy	11600.00
0005433037097	2128	Economy	11600.00
0005433037324	2128	Economy	12700.00
0005432231860	2128	Economy	11600.00
0005433037133	2128	Economy	11600.00
0005434028373	2128	Economy	11600.00
0005433037277	2128	Economy	11600.00
0005433925978	2128	Economy	11600.00
0005433926010	2128	Economy	11600.00
0005433925975	2128	Economy	11600.00
0005432231866	2128	Economy	11600.00
0005433037263	2128	Economy	11600.00
0005433925974	2128	Economy	11600.00
0005433926011	2128	Economy	11600.00
0005433037430	2128	Economy	11600.00
0005433926004	2128	Economy	11600.00
0005433925993	2128	Economy	11600.00
0005433925967	2128	Economy	11600.00
0005433037367	2128	Economy	11600.00
0005433037538	2128	Economy	11600.00
0005433037296	2128	Economy	11600.00
0005433037444	2128	Economy	11600.00
0005433037155	2128	Economy	11600.00
0005433925969	2128	Economy	11600.00
0005433929882	2128	Economy	11600.00
0005433037306	2128	Economy	11600.00
0005432231863	2128	Economy	11600.00
0005433929881	2128	Economy	11600.00
0005432231861	2128	Economy	11600.00
0005434028360	2128	Economy	11600.00
0005433037287	2128	Economy	11600.00
0005433037446	2128	Economy	11600.00
0005433037505	2128	Economy	11600.00
0005433925995	2128	Economy	11600.00
0005433925988	2128	Economy	11600.00
0005433925976	2128	Economy	11600.00
0005433037368	2128	Economy	11600.00
0005433926000	2128	Economy	11600.00
0005432231859	2128	Economy	11600.00
0005433037508	2128	Economy	11600.00
0005433925963	2128	Economy	11600.00
0005433037232	2128	Economy	11600.00
0005433037350	2128	Economy	11600.00
0005433931553	2128	Economy	11600.00
0005433926003	2128	Economy	11600.00
0005433037285	2128	Economy	11600.00
0005433925973	2128	Economy	11600.00
0005434028344	2128	Economy	11600.00
0005433926013	2128	Economy	11600.00
0005433037320	2128	Economy	11600.00
0005433926006	2128	Economy	11600.00
0005433037150	2128	Economy	11600.00
0005433037298	2128	Economy	11600.00
0005433925972	2128	Economy	11600.00
0005433925446	24102	Business	34700.00
0005433925207	24102	Business	34700.00
0005433925073	24102	Business	34700.00
0005433925424	24102	Business	34700.00
0005433037766	24102	Business	34700.00
0005433924790	24102	Business	34700.00
0005433925453	24102	Business	34700.00
0005433925581	24102	Business	34700.00
0005433037778	24102	Business	34700.00
0005433929704	24102	Business	34700.00
0005433925413	24102	Business	34700.00
0005433924950	24102	Business	34700.00
0005433037791	24102	Business	34700.00
0005432749849	24102	Business	34700.00
0005434376185	24102	Business	34700.00
0005433925023	24102	Business	34700.00
0005433929693	24102	Business	34700.00
0005433037771	24102	Business	34700.00
0005433924967	24102	Business	34700.00
0005433925131	24102	Business	34700.00
0005433037787	24102	Business	34700.00
0005433925169	24102	Business	34700.00
0005434088052	24102	Business	34700.00
0005433875415	24102	Economy	12700.00
0005433925178	24102	Economy	12700.00
0005433924872	24102	Economy	12700.00
0005433925507	24102	Economy	11600.00
0005432206356	24102	Economy	11600.00
0005433925504	24102	Economy	11600.00
0005433925437	24102	Economy	11600.00
0005433037757	24102	Economy	11600.00
0005433925256	24102	Economy	11600.00
0005433925662	24102	Economy	11600.00
0005433924940	24102	Economy	11600.00
0005433037767	24102	Economy	11600.00
0005433925383	24102	Economy	11600.00
0005433929697	24102	Economy	11600.00
0005433929700	24102	Economy	11600.00
0005433925323	24102	Economy	11600.00
0005433925400	24102	Economy	11600.00
0005433924591	24102	Economy	11600.00
0005433037786	24102	Economy	11600.00
0005433924789	24102	Economy	11600.00
0005433925407	24102	Economy	11600.00
0005433924984	24102	Economy	11600.00
0005433925193	24102	Economy	11600.00
0005433037788	24102	Economy	11600.00
0005433924751	24102	Economy	11600.00
0005433925506	24102	Economy	11600.00
0005433925285	24102	Economy	11600.00
0005433925034	24102	Economy	11600.00
0005432749846	24102	Economy	11600.00
0005433037761	24102	Economy	11600.00
0005433925363	24102	Economy	11600.00
0005433925190	24102	Economy	11600.00
0005433925317	24102	Economy	11600.00
0005433924996	24102	Economy	11600.00
0005433925293	24102	Economy	11600.00
0005433037789	24102	Economy	11600.00
0005433929694	24102	Economy	11600.00
0005433037785	24102	Economy	11600.00
0005433925199	24102	Economy	11600.00
0005433925384	24102	Economy	11600.00
0005433924816	24102	Economy	11600.00
0005433925438	24102	Economy	11600.00
0005433925214	24102	Economy	11600.00
0005433924828	24102	Economy	11600.00
0005433037772	24102	Economy	11600.00
0005433037779	24102	Economy	11600.00
0005433037769	24102	Economy	11600.00
0005432749847	24102	Economy	11600.00
0005433925364	24102	Economy	11600.00
0005433037756	24102	Economy	11600.00
0005433925459	24102	Economy	11600.00
0005433925402	24102	Economy	11600.00
0005433925161	24102	Economy	11600.00
0005433037780	24102	Economy	11600.00
0005433925212	24102	Economy	11600.00
0005433037774	24102	Economy	11600.00
0005433925187	24102	Economy	11600.00
0005433925225	24102	Economy	11600.00
0005434028392	24102	Economy	11600.00
0005433925064	24102	Economy	11600.00
0005433925376	24102	Economy	11600.00
0005433929868	24102	Economy	11600.00
0005434376186	24102	Economy	11600.00
0005433925206	24102	Economy	11600.00
0005433037777	24102	Economy	11600.00
0005433037759	24102	Economy	11600.00
0005433925633	24102	Economy	11600.00
0005433037764	24102	Economy	11600.00
0005433924986	24102	Economy	11600.00
0005432207735	24102	Economy	11600.00
0005433925163	24102	Economy	11600.00
0005433875411	24102	Economy	11600.00
0005433925679	24102	Economy	11600.00
0005433037768	24102	Economy	11600.00
0005433925198	24102	Economy	11600.00
0005433925194	24102	Economy	11600.00
0005433925141	24102	Economy	11600.00
0005433925253	24102	Economy	11600.00
0005433929705	24102	Economy	11600.00
0005433037790	24102	Economy	11600.00
0005433925140	24102	Economy	11600.00
0005433929699	24102	Economy	11600.00
0005433925556	24102	Economy	11600.00
0005433925157	24102	Economy	11600.00
0005433925332	24102	Economy	11600.00
0005433875416	24102	Economy	11600.00
0005433037773	24102	Economy	11600.00
0005433037776	24102	Economy	11600.00
0005433925412	24102	Economy	11600.00
0005433924985	24102	Economy	12700.00
0005433925410	24102	Economy	12700.00
0005433925308	24102	Economy	11600.00
0005433924966	24102	Economy	12700.00
0005434088050	24102	Economy	12700.00
0005433925022	24102	Economy	11600.00
0005433037763	24102	Economy	11600.00
0005433925704	24102	Economy	11600.00
0005433925404	24102	Economy	11600.00
0005433037765	24102	Economy	11600.00
0005433925447	24102	Economy	11600.00
0005433925186	24102	Economy	11600.00
0005434088051	24102	Economy	11600.00
0005433925197	24102	Economy	11600.00
0005434028393	24102	Economy	11600.00
0005433925557	24102	Economy	11600.00
0005433925257	24102	Economy	11600.00
0005433037793	24102	Economy	11600.00
0005433037760	24102	Economy	11600.00
0005433925152	24102	Economy	11600.00
0005433925374	24102	Economy	11600.00
0005433925259	24102	Economy	11600.00
0005433925159	24102	Economy	11600.00
0005432749848	24102	Economy	11600.00
0005433037775	24102	Economy	11600.00
0005433925213	24102	Economy	11600.00
0005433925349	24102	Economy	11600.00
0005433925251	24102	Economy	11600.00
0005433925288	24102	Economy	11600.00
0005433925077	24102	Economy	11600.00
0005433925247	24102	Economy	11600.00
0005433925182	24102	Economy	11600.00
0005433924817	24102	Economy	11600.00
0005433037783	24102	Economy	11600.00
0005433925181	24102	Economy	11600.00
0005433925160	24102	Economy	11600.00
0005433925028	24102	Economy	11600.00
0005433925555	24102	Economy	11600.00
0005433924827	24102	Economy	11600.00
0005433925411	24102	Economy	11600.00
0005433037784	24102	Economy	11600.00
0005433037770	24102	Economy	11600.00
0005433925210	24102	Economy	11600.00
0005433925284	24102	Economy	11600.00
0005433037781	24102	Economy	11600.00
0005433037758	24102	Economy	11600.00
0005433925200	24102	Economy	11600.00
0005433929706	24102	Economy	11600.00
0005433925705	24102	Economy	11600.00
0005433925458	24102	Economy	11600.00
0005433037792	24102	Economy	11600.00
0005433037782	24102	Economy	11600.00
0005433929698	24102	Economy	11600.00
0005433925663	24102	Economy	11600.00
0005433925703	24102	Economy	11600.00
0005433037762	24102	Economy	11600.00
0005433925399	24102	Economy	11600.00
0005433929867	24102	Economy	11600.00
0005433235354	287	Business	83700.00
0005434728841	287	Business	83700.00
0005432278186	287	Business	83700.00
0005434728829	287	Business	83700.00
0005433126943	287	Business	83700.00
0005433235695	287	Business	83700.00
0005434552764	287	Business	83700.00
0005434552778	287	Business	83700.00
0005434552771	287	Business	83700.00
0005434552759	287	Business	83700.00
0005434032105	287	Business	83700.00
0005433235481	287	Business	83700.00
0005434552770	287	Business	83700.00
0005433131791	287	Business	83700.00
0005434728824	287	Business	83700.00
0005433235550	287	Business	83700.00
0005433235268	287	Business	83700.00
0005435142944	287	Business	83700.00
0005434728878	287	Business	83700.00
0005433235532	287	Comfort	47400.00
0005432278183	287	Comfort	47400.00
0005434032107	287	Comfort	47400.00
0005433235499	287	Comfort	47400.00
0005433126921	287	Comfort	47400.00
0005434728871	287	Comfort	47400.00
0005433235651	287	Comfort	47400.00
0005434728839	287	Comfort	47400.00
0005434731286	287	Comfort	47400.00
0005433766719	287	Comfort	47400.00
0005433235333	287	Comfort	47400.00
0005433235493	287	Comfort	47400.00
0005434728888	287	Comfort	47400.00
0005434552786	287	Comfort	47400.00
0005433235505	287	Comfort	47400.00
0005434552772	287	Comfort	47400.00
0005433181573	287	Comfort	47400.00
0005433235696	287	Comfort	47400.00
0005434728826	287	Comfort	47400.00
0005434728884	287	Comfort	47400.00
0005433235426	287	Comfort	47400.00
0005433235456	287	Comfort	47400.00
0005433235531	287	Comfort	47400.00
0005433113577	287	Comfort	47400.00
0005434728836	287	Comfort	47400.00
0005433235504	287	Comfort	47400.00
0005433235467	287	Comfort	47400.00
0005434552760	287	Comfort	47400.00
0005435142948	287	Comfort	47400.00
0005433111545	287	Comfort	47400.00
0005433235359	287	Comfort	47400.00
0005434728828	287	Comfort	47400.00
0005434552768	287	Comfort	47400.00
0005433235421	287	Comfort	47400.00
0005433181594	287	Economy	27900.00
0005433235679	287	Economy	27900.00
0005434728830	287	Economy	27900.00
0005433235658	287	Economy	27900.00
0005434552785	287	Economy	27900.00
0005434728851	287	Economy	27900.00
0005433289997	287	Economy	27900.00
0005434728846	287	Economy	27900.00
0005433181572	287	Economy	27900.00
0005433235417	287	Economy	27900.00
0005433235366	287	Economy	27900.00
0005433181528	287	Economy	27900.00
0005433235452	287	Economy	27900.00
0005434728827	287	Economy	27900.00
0005434728885	287	Economy	27900.00
0005434728838	287	Economy	27900.00
0005434728842	287	Economy	27900.00
0005433181588	287	Economy	27900.00
0005433181745	287	Economy	27900.00
0005433290011	287	Economy	27900.00
0005434728853	287	Economy	27900.00
0005433235517	287	Economy	27900.00
0005433235425	287	Economy	27900.00
0005434552779	287	Economy	27900.00
0005434552790	287	Economy	27900.00
0005434728848	287	Economy	27900.00
0005433235626	287	Economy	27900.00
0005432278191	287	Economy	27900.00
0005432278187	287	Economy	27900.00
0005434302904	287	Economy	27900.00
0005433131781	287	Economy	27900.00
0005433766731	287	Economy	27900.00
0005433181744	287	Economy	27900.00
0005432278190	287	Economy	27900.00
0005434552784	287	Economy	27900.00
0005432278182	287	Economy	27900.00
0005433235375	287	Economy	27900.00
0005434552757	287	Economy	27900.00
0005434552761	287	Economy	27900.00
0005434728887	287	Economy	27900.00
0005435142949	287	Economy	27900.00
0005433235507	287	Economy	27900.00
0005433235678	287	Economy	27900.00
0005433235700	287	Economy	27900.00
0005434728889	287	Economy	27900.00
0005434728845	287	Economy	27900.00
0005433111550	287	Economy	30700.00
0005434728834	287	Economy	27900.00
0005433235627	287	Economy	30700.00
0005433766711	287	Economy	27900.00
0005434552762	287	Economy	30700.00
0005433235424	287	Economy	30700.00
0005434728891	287	Economy	27900.00
0005433235609	287	Economy	27900.00
0005434728859	287	Economy	27900.00
0005433235558	287	Economy	27900.00
0005434728880	287	Economy	27900.00
0005434552788	287	Economy	27900.00
0005434728844	287	Economy	27900.00
0005433235593	287	Economy	27900.00
0005434728860	287	Economy	27900.00
0005433181571	287	Economy	27900.00
0005433235416	287	Economy	27900.00
0005433290009	287	Economy	27900.00
0005434302905	287	Economy	27900.00
0005435142945	287	Economy	27900.00
0005433235334	287	Economy	27900.00
0005433235419	287	Economy	27900.00
0005434728854	287	Economy	27900.00
0005434735832	287	Economy	27900.00
0005433290010	287	Economy	27900.00
0005434728835	287	Economy	27900.00
0005434731288	287	Economy	27900.00
0005433235387	287	Economy	27900.00
0005433235173	287	Economy	27900.00
0005434728850	287	Economy	27900.00
0005433235707	287	Economy	27900.00
0005434552758	287	Economy	27900.00
0005433181621	287	Economy	27900.00
0005433111548	287	Economy	27900.00
0005434552780	287	Economy	27900.00
0005433126922	287	Economy	27900.00
0005433766713	287	Economy	27900.00
0005434728843	287	Economy	27900.00
0005433235462	287	Economy	27900.00
0005433235502	287	Economy	27900.00
0005433235554	287	Economy	27900.00
0005434552754	287	Economy	27900.00
0005434552782	287	Economy	27900.00
0005434552787	287	Economy	27900.00
0005433181620	287	Economy	27900.00
0005433235283	287	Economy	27900.00
0005433235522	287	Economy	27900.00
0005434728892	287	Economy	27900.00
0005433235559	287	Economy	27900.00
0005434728847	287	Economy	27900.00
0005433235508	287	Economy	27900.00
0005434552774	287	Economy	27900.00
0005434302577	287	Economy	27900.00
0005434728879	287	Economy	27900.00
0005433289998	287	Economy	27900.00
0005433181470	287	Economy	27900.00
0005434728866	287	Economy	27900.00
0005434728857	287	Economy	27900.00
0005434552763	287	Economy	27900.00
0005434728875	287	Economy	27900.00
0005433111546	287	Economy	27900.00
0005433235694	287	Economy	27900.00
0005434032106	287	Economy	27900.00
0005434728855	287	Economy	27900.00
0005432278184	287	Economy	27900.00
0005432278188	287	Economy	27900.00
0005434728865	287	Economy	27900.00
0005433111547	287	Economy	27900.00
0005434728873	287	Economy	27900.00
0005435142943	287	Economy	27900.00
0005434552767	287	Economy	27900.00
0005432278192	287	Economy	27900.00
0005434728874	287	Economy	27900.00
0005434552765	287	Economy	27900.00
0005433766718	287	Economy	27900.00
0005434728869	287	Economy	27900.00
0005433131795	287	Economy	27900.00
0005434552791	287	Economy	27900.00
0005433126942	287	Economy	27900.00
0005434728831	287	Economy	27900.00
0005435142951	287	Economy	27900.00
0005434728868	287	Economy	27900.00
0005434032126	287	Economy	27900.00
0005433235172	287	Economy	27900.00
0005434728837	287	Economy	27900.00
0005433235388	287	Economy	27900.00
0005433113572	287	Economy	27900.00
0005433235293	287	Economy	27900.00
0005434032103	287	Economy	27900.00
0005434728877	287	Economy	27900.00
0005433235363	287	Economy	27900.00
0005434728823	287	Economy	30700.00
0005434552769	287	Economy	30700.00
0005433111539	287	Economy	30700.00
0005434728864	287	Economy	30700.00
0005434728856	287	Economy	27900.00
0005434728883	287	Economy	27900.00
0005434728833	287	Economy	27900.00
0005434728870	287	Economy	27900.00
0005434728863	287	Economy	27900.00
0005434731289	287	Economy	27900.00
0005434728852	287	Economy	27900.00
0005432278189	287	Economy	27900.00
0005434728882	287	Economy	27900.00
0005434728872	287	Economy	27900.00
0005434728858	287	Economy	27900.00
0005434552766	287	Economy	27900.00
0005434728867	287	Economy	27900.00
0005433181607	287	Economy	27900.00
0005434552755	287	Economy	27900.00
0005433235164	287	Economy	27900.00
0005435142946	287	Economy	27900.00
0005435142947	287	Economy	27900.00
0005434728840	287	Economy	27900.00
0005434728822	287	Economy	27900.00
0005433235512	287	Economy	27900.00
0005434552773	287	Economy	27900.00
0005434552783	287	Economy	27900.00
0005434731287	287	Economy	27900.00
0005433181529	287	Economy	27900.00
0005434735834	287	Economy	27900.00
0005433111549	287	Economy	27900.00
0005433235544	287	Economy	27900.00
0005433181589	287	Economy	27900.00
0005433181601	287	Economy	27900.00
0005434728881	287	Economy	27900.00
0005434728832	287	Economy	27900.00
0005433766732	287	Economy	27900.00
0005433235657	287	Economy	27900.00
0005433235506	287	Economy	27900.00
0005434032125	287	Economy	27900.00
0005435142950	287	Economy	27900.00
0005433289999	287	Economy	27900.00
0005433235518	287	Economy	27900.00
0005433235431	287	Economy	27900.00
0005434552775	287	Economy	27900.00
0005433235468	287	Economy	27900.00
0005434302578	287	Economy	27900.00
0005434728890	287	Economy	27900.00
0005434728861	287	Economy	27900.00
0005433181676	287	Economy	27900.00
0005433131825	287	Economy	27900.00
0005434728876	287	Economy	27900.00
0005434032108	287	Economy	27900.00
0005434728862	287	Economy	27900.00
0005434728849	287	Economy	27900.00
0005434728886	287	Economy	27900.00
0005434552777	287	Economy	27900.00
0005433131796	287	Economy	27900.00
0005434552781	287	Economy	27900.00
0005433290000	287	Economy	27900.00
0005432278185	287	Economy	27900.00
0005434728825	287	Economy	27900.00
0005433235418	287	Economy	27900.00
0005433235701	287	Economy	27900.00
0005434735833	287	Economy	27900.00
0005433131826	287	Economy	27900.00
0005434552776	287	Economy	27900.00
0005433235576	287	Economy	27900.00
0005434552789	287	Economy	27900.00
0005433235358	287	Economy	27900.00
0005434552756	287	Economy	27900.00
0005433235516	287	Economy	27900.00
0005434552282	9874	Business	83700.00
0005434727574	9874	Business	83700.00
0005434727484	9874	Business	83700.00
0005434728213	9874	Business	83700.00
0005433126972	9874	Business	83700.00
0005434728077	9874	Business	83700.00
0005433235951	9874	Business	83700.00
0005434727222	9874	Business	83700.00
0005434727597	9874	Business	83700.00
0005433129406	9874	Business	83700.00
0005434728360	9874	Business	83700.00
0005433129405	9874	Business	83700.00
0005434552147	9874	Business	83700.00
0005434032154	9874	Business	83700.00
0005433290052	9874	Business	83700.00
0005434552196	9874	Business	83700.00
0005433235954	9874	Business	83700.00
0005434552337	9874	Business	83700.00
0005434552479	9874	Business	83700.00
0005434552092	9874	Business	83700.00
0005434727602	9874	Business	83700.00
0005434727932	9874	Business	83700.00
0005434727879	9874	Comfort	47400.00
0005434552091	9874	Business	83700.00
0005434552422	9874	Comfort	47400.00
0005434727781	9874	Comfort	47400.00
0005434728436	9874	Comfort	47400.00
0005433235963	9874	Comfort	47400.00
0005434728101	9874	Comfort	47400.00
0005433181812	9874	Comfort	47400.00
0005434727986	9874	Comfort	47400.00
0005434728373	9874	Comfort	47400.00
0005433235930	9874	Comfort	47400.00
0005433766746	9874	Comfort	47400.00
0005434552471	9874	Comfort	47400.00
0005434728193	9874	Comfort	47400.00
0005434728307	9874	Comfort	47400.00
0005434727449	9874	Comfort	47400.00
0005434727749	9874	Comfort	47400.00
0005434727955	9874	Comfort	47400.00
0005434727714	9874	Comfort	47400.00
0005434552118	9874	Comfort	47400.00
0005434728320	9874	Comfort	47400.00
0005434728032	9874	Comfort	47400.00
0005435142807	9874	Comfort	47400.00
0005434727569	9874	Comfort	47400.00
0005433129404	9874	Comfort	47400.00
0005433235937	9874	Comfort	47400.00
0005432199434	9874	Comfort	47400.00
0005434728023	9874	Comfort	47400.00
0005434552488	9874	Comfort	47400.00
0005434727560	9874	Comfort	47400.00
0005434728047	9874	Comfort	47400.00
0005434552209	9874	Comfort	47400.00
0005434728134	9874	Comfort	47400.00
0005434552261	9874	Comfort	47400.00
0005434727627	9874	Comfort	47400.00
0005435142858	9874	Comfort	47400.00
0005434728416	9874	Comfort	47400.00
0005434552014	9874	Economy	27900.00
0005433290054	9874	Economy	27900.00
0005433235959	9874	Economy	27900.00
0005434552148	9874	Economy	27900.00
0005433766747	9874	Economy	27900.00
0005434728296	9874	Economy	27900.00
0005434552392	9874	Economy	27900.00
0005433235943	9874	Economy	27900.00
0005434727938	9874	Economy	27900.00
0005434551896	9874	Economy	27900.00
0005433235938	9874	Economy	27900.00
0005434727568	9874	Economy	27900.00
0005434727937	9874	Economy	27900.00
0005434727988	9874	Economy	27900.00
0005434727908	9874	Economy	27900.00
0005435142817	9874	Economy	27900.00
0005434727547	9874	Economy	27900.00
0005434552311	9874	Economy	27900.00
0005434727746	9874	Economy	27900.00
0005433181811	9874	Economy	27900.00
0005434727521	9874	Economy	27900.00
0005434728260	9874	Economy	27900.00
0005432199435	9874	Economy	27900.00
0005433235939	9874	Economy	27900.00
0005434728319	9874	Economy	27900.00
0005434728135	9874	Economy	27900.00
0005434728458	9874	Economy	27900.00
0005433235956	9874	Economy	27900.00
0005434727347	9874	Economy	27900.00
0005434727969	9874	Economy	27900.00
0005433235932	9874	Economy	27900.00
0005434728062	9874	Economy	27900.00
0005433181809	9874	Economy	27900.00
0005434727850	9874	Economy	27900.00
0005434552260	9874	Economy	27900.00
0005433181814	9874	Economy	27900.00
0005434552169	9874	Economy	27900.00
0005434728123	9874	Economy	27900.00
0005433235955	9874	Economy	27900.00
0005433235964	9874	Economy	27900.00
0005434302538	9874	Economy	27900.00
0005434728122	9874	Economy	27900.00
0005434552081	9874	Economy	27900.00
0005433235966	9874	Economy	27900.00
0005434727706	9874	Economy	27900.00
0005434728009	9874	Economy	27900.00
0005432199441	9874	Economy	27900.00
0005434727543	9874	Economy	27900.00
0005434032153	9874	Economy	27900.00
0005435142815	9874	Economy	27900.00
0005434728048	9874	Economy	27900.00
0005434727976	9874	Economy	27900.00
0005433181813	9874	Economy	27900.00
0005433235965	9874	Economy	27900.00
0005434727520	9874	Economy	30700.00
0005433235947	9874	Economy	30700.00
0005433129402	9874	Economy	30700.00
0005434727601	9874	Economy	27900.00
0005433113596	9874	Economy	27900.00
0005434552334	9874	Economy	27900.00
0005433235935	9874	Economy	27900.00
0005434727968	9874	Economy	30700.00
0005434727831	9874	Economy	27900.00
0005435142853	9874	Economy	30700.00
0005434552312	9874	Economy	27900.00
0005433181801	9874	Economy	27900.00
0005434727612	9874	Economy	27900.00
0005434728196	9874	Economy	27900.00
0005434728308	9874	Economy	27900.00
0005434727448	9874	Economy	27900.00
0005434727751	9874	Economy	27900.00
0005434727329	9874	Economy	27900.00
0005433235957	9874	Economy	27900.00
0005434552423	9874	Economy	27900.00
0005434551897	9874	Economy	27900.00
0005434727905	9874	Economy	27900.00
0005434727833	9874	Economy	27900.00
0005434552285	9874	Economy	27900.00
0005435142814	9874	Economy	27900.00
0005433235936	9874	Economy	27900.00
0005433181805	9874	Economy	27900.00
0005434728120	9874	Economy	27900.00
0005434552292	9874	Economy	27900.00
0005433235948	9874	Economy	27900.00
0005434727779	9874	Economy	27900.00
0005434735799	9874	Economy	27900.00
0005434552489	9874	Economy	27900.00
0005433181802	9874	Economy	27900.00
0005434727760	9874	Economy	27900.00
0005434728180	9874	Economy	27900.00
0005434552117	9874	Economy	27900.00
0005434728126	9874	Economy	27900.00
0005433290053	9874	Economy	27900.00
0005433235961	9874	Economy	27900.00
0005434728438	9874	Economy	27900.00
0005434552462	9874	Economy	27900.00
0005434728055	9874	Economy	27900.00
0005434727970	9874	Economy	27900.00
0005434727280	9874	Economy	27900.00
0005434552404	9874	Economy	27900.00
0005434727997	9874	Economy	27900.00
0005434727649	9874	Economy	27900.00
0005433181808	9874	Economy	27900.00
0005433290051	9874	Economy	27900.00
0005434728179	9874	Economy	27900.00
0005434727598	9874	Economy	27900.00
0005435142837	9874	Economy	27900.00
0005434728321	9874	Economy	27900.00
0005434552015	9874	Economy	27900.00
0005433181810	9874	Economy	27900.00
0005434727519	9874	Economy	27900.00
0005434728240	9874	Economy	27900.00
0005434727722	9874	Economy	27900.00
0005434552329	9874	Economy	27900.00
0005434728303	9874	Economy	27900.00
0005433235953	9874	Economy	27900.00
0005434552080	9874	Economy	27900.00
0005434552273	9874	Economy	27900.00
0005433181806	9874	Economy	27900.00
0005434552382	9874	Economy	27900.00
0005434727396	9874	Economy	27900.00
0005434727658	9874	Economy	27900.00
0005433235960	9874	Economy	27900.00
0005435142806	9874	Economy	27900.00
0005434552284	9874	Economy	27900.00
0005433235949	9874	Economy	27900.00
0005434552300	9874	Economy	27900.00
0005433235946	9874	Economy	27900.00
0005434727370	9874	Economy	27900.00
0005434552162	9874	Economy	27900.00
0005433235941	9874	Economy	27900.00
0005434727825	9874	Economy	27900.00
0005434728232	9874	Economy	27900.00
0005434727931	9874	Economy	27900.00
0005433235950	9874	Economy	27900.00
0005434727485	9874	Economy	27900.00
0005434728132	9874	Economy	27900.00
0005434728437	9874	Economy	27900.00
0005434727789	9874	Economy	27900.00
0005433766748	9874	Economy	27900.00
0005434727838	9874	Economy	27900.00
0005434735792	9874	Economy	27900.00
0005434727328	9874	Economy	27900.00
0005433235952	9874	Economy	30700.00
0005434302553	9874	Economy	30700.00
0005435142823	9874	Economy	30700.00
0005433235928	9874	Economy	30700.00
0005433181807	9874	Economy	27900.00
0005434728022	9874	Economy	27900.00
0005432199439	9874	Economy	27900.00
0005434727859	9874	Economy	27900.00
0005434552295	9874	Economy	27900.00
0005434728212	9874	Economy	27900.00
0005433235958	9874	Economy	27900.00
0005434728256	9874	Economy	27900.00
0005432199438	9874	Economy	27900.00
0005433235929	9874	Economy	27900.00
0005433181804	9874	Economy	27900.00
0005434727860	9874	Economy	27900.00
0005433235931	9874	Economy	27900.00
0005435142852	9874	Economy	27900.00
0005434727628	9874	Economy	27900.00
0005435142900	9874	Economy	27900.00
0005434728117	9874	Economy	27900.00
0005434552299	9874	Economy	27900.00
0005434728103	9874	Economy	27900.00
0005434552460	9874	Economy	27900.00
0005434552472	9874	Economy	27900.00
0005434728233	9874	Economy	27900.00
0005434727723	9874	Economy	27900.00
0005434727752	9874	Economy	27900.00
0005434727737	9874	Economy	27900.00
0005433235944	9874	Economy	27900.00
0005434728049	9874	Economy	27900.00
0005434552069	9874	Economy	27900.00
0005434735793	9874	Economy	27900.00
0005433766745	9874	Economy	27900.00
0005434728359	9874	Economy	27900.00
0005433235927	9874	Economy	27900.00
0005433290050	9874	Economy	27900.00
0005434552336	9874	Economy	27900.00
0005435142818	9874	Economy	27900.00
0005434552168	9874	Economy	27900.00
0005433235945	9874	Economy	27900.00
0005433129403	9874	Economy	27900.00
0005435142794	9874	Economy	27900.00
0005434727839	9874	Economy	27900.00
0005434552119	9874	Economy	27900.00
0005433235934	9874	Economy	27900.00
0005433290049	9874	Economy	27900.00
0005434727866	9874	Economy	27900.00
0005434727903	9874	Economy	27900.00
0005434728241	9874	Economy	27900.00
0005434727613	9874	Economy	27900.00
0005434727667	9874	Economy	27900.00
0005434552070	9874	Economy	27900.00
0005433126973	9874	Economy	27900.00
0005434728124	9874	Economy	27900.00
0005434302546	9874	Economy	27900.00
0005434727996	9874	Economy	27900.00
0005433235940	9874	Economy	27900.00
0005434552164	9874	Economy	27900.00
0005434302545	9874	Economy	27900.00
0005433181803	9874	Economy	27900.00
0005433766749	9874	Economy	27900.00
0005433235933	9874	Economy	27900.00
0005434727745	9874	Economy	27900.00
0005434727718	9874	Economy	27900.00
0005434552461	9874	Economy	27900.00
0005434727788	9874	Economy	27900.00
0005432199437	9874	Economy	27900.00
0005434552307	9874	Economy	27900.00
0005434727725	9874	Economy	27900.00
0005434552083	9874	Economy	27900.00
0005434727548	9874	Economy	27900.00
0005434727950	9874	Economy	27900.00
0005433235942	9874	Economy	27900.00
0005434727599	9874	Economy	27900.00
0005433235962	9874	Economy	27900.00
0005434731259	9874	Economy	27900.00
0005434728121	9874	Economy	27900.00
0005434728255	9874	Economy	27900.00
0005434552087	9874	Economy	27900.00
0005434552335	9874	Economy	27900.00
0005433113595	9874	Economy	27900.00
0005434552195	9874	Economy	27900.00
0005434302539	9874	Economy	27900.00
0005432199436	9874	Economy	27900.00
0005434727748	9874	Economy	27900.00
0005434727832	9874	Economy	27900.00
0005434727573	9874	Economy	27900.00
0005434551937	9874	Economy	27900.00
0005434727794	9874	Economy	27900.00
0005434728334	9874	Economy	27900.00
0005434552194	9874	Economy	27900.00
0005434727747	9874	Economy	27900.00
0005432199440	9874	Economy	27900.00
0005434727780	9874	Economy	27900.00
0005434552291	9874	Economy	27900.00
0005434069546	7751	Business	42100.00
0005435214952	7751	Business	42100.00
0005432531660	7751	Business	42100.00
0005432531619	7751	Business	42100.00
0005432531636	7751	Business	42100.00
0005435214980	7751	Business	42100.00
0005432531647	7751	Business	42100.00
0005434069554	7751	Business	42100.00
0005434069532	7751	Business	42100.00
0005432531670	7751	Business	42100.00
0005432531638	7751	Business	42100.00
0005434069555	7751	Business	42100.00
0005434069537	7751	Business	42100.00
0005432531611	7751	Business	42100.00
0005432531652	7751	Business	42100.00
0005434069538	7751	Business	42100.00
0005435214779	7751	Business	42100.00
0005435214921	7751	Business	42100.00
0005434069571	7751	Comfort	23900.00
0005432531644	7751	Comfort	23900.00
0005434069550	7751	Comfort	23900.00
0005432531607	7751	Comfort	23900.00
0005434069542	7751	Comfort	23900.00
0005432531669	7751	Comfort	23900.00
0005435215105	7751	Comfort	23900.00
0005435214944	7751	Comfort	23900.00
0005435725698	7751	Comfort	23900.00
0005432533370	7751	Comfort	23900.00
0005434069557	7751	Comfort	23900.00
0005432531637	7751	Comfort	23900.00
0005432531617	7751	Comfort	23900.00
0005432535973	7751	Comfort	23900.00
0005435215158	7751	Comfort	23900.00
0005434069540	7751	Comfort	23900.00
0005432070065	7751	Comfort	23900.00
0005435215104	7751	Comfort	23900.00
0005435214876	7751	Comfort	23900.00
0005432531668	7751	Comfort	23900.00
0005434069551	7751	Comfort	23900.00
0005435214757	7751	Comfort	23900.00
0005435215084	7751	Comfort	23900.00
0005432531672	7751	Comfort	23900.00
0005434069564	7751	Comfort	23900.00
0005435215261	7751	Comfort	23900.00
0005432531677	7751	Comfort	23900.00
0005435725697	7751	Economy	14000.00
0005434069535	7751	Economy	14000.00
0005432531680	7751	Economy	14000.00
0005434069526	7751	Economy	14000.00
0005432531685	7751	Economy	14000.00
0005434069558	7751	Economy	14000.00
0005435214913	7751	Economy	14000.00
0005432531675	7751	Economy	14000.00
0005435215074	7751	Economy	14000.00
0005432531645	7751	Economy	14000.00
0005434069565	7751	Economy	14000.00
0005432531686	7751	Economy	14000.00
0005434069534	7751	Economy	14000.00
0005435214968	7751	Economy	14000.00
0005434069525	7751	Economy	14000.00
0005432531665	7751	Economy	14000.00
0005435214875	7751	Economy	14000.00
0005435215059	7751	Economy	14000.00
0005432531673	7751	Economy	14000.00
0005435214814	7751	Economy	14000.00
0005435214813	7751	Economy	14000.00
0005432531657	7751	Economy	14000.00
0005432531629	7751	Economy	14000.00
0005432531628	7751	Economy	14000.00
0005434069567	7751	Economy	14000.00
0005432531608	7751	Economy	14000.00
0005432531676	7751	Economy	14000.00
0005435214977	7751	Economy	14000.00
0005432531678	7751	Economy	14000.00
0005432531632	7751	Economy	14000.00
0005434069560	7751	Economy	14000.00
0005432429027	7751	Economy	14000.00
0005434069561	7751	Economy	14000.00
0005435214831	7751	Economy	14000.00
0005432531620	7751	Economy	14000.00
0005434069533	7751	Economy	14000.00
0005434069529	7751	Economy	14000.00
0005435215065	7751	Economy	14000.00
0005432531671	7751	Economy	14000.00
0005434069544	7751	Economy	14000.00
0005435214847	7751	Economy	14000.00
0005432531654	7751	Economy	14000.00
0005435214970	7751	Economy	14000.00
0005432531614	7751	Economy	14000.00
0005432531662	7751	Economy	14000.00
0005435214857	7751	Economy	14000.00
0005432531655	7751	Economy	15400.00
0005432537118	7751	Economy	15400.00
0005432531633	7751	Economy	15400.00
0005435214930	7751	Economy	14000.00
0005432531663	7751	Economy	14000.00
0005432531631	7751	Economy	14000.00
0005435215069	7751	Economy	14000.00
0005432531641	7751	Economy	14000.00
0005434069539	7751	Economy	14000.00
0005432531626	7751	Economy	14000.00
0005432531616	7751	Economy	14000.00
0005432531621	7751	Economy	14000.00
0005432531653	7751	Economy	14000.00
0005434069552	7751	Economy	14000.00
0005432531648	7751	Economy	14000.00
0005435215157	7751	Economy	14000.00
0005434069547	7751	Economy	14000.00
0005434069536	7751	Economy	14000.00
0005432535971	7751	Economy	14000.00
0005432531658	7751	Economy	14000.00
0005432531635	7751	Economy	14000.00
0005435631024	7751	Economy	14000.00
0005435214855	7751	Economy	14000.00
0005432531679	7751	Economy	14000.00
0005435214687	7751	Economy	14000.00
0005432531643	7751	Economy	14000.00
0005432533371	7751	Economy	14000.00
0005435215097	7751	Economy	14000.00
0005432531610	7751	Economy	14000.00
0005435631025	7751	Economy	14000.00
0005432070063	7751	Economy	14000.00
0005435214927	7751	Economy	14000.00
0005434069543	7751	Economy	14000.00
0005435214856	7751	Economy	14000.00
0005435214706	7751	Economy	14000.00
0005435214817	7751	Economy	14000.00
0005435214928	7751	Economy	14000.00
0005435215083	7751	Economy	14000.00
0005432070064	7751	Economy	14000.00
0005432531681	7751	Economy	14000.00
0005434069559	7751	Economy	14000.00
0005435214811	7751	Economy	14000.00
0005435214707	7751	Economy	14000.00
0005435214842	7751	Economy	14000.00
0005432070061	7751	Economy	14000.00
0005432531622	7751	Economy	14000.00
0005434069527	7751	Economy	14000.00
0005435214877	7751	Economy	14000.00
0005432070058	7751	Economy	14000.00
0005432531649	7751	Economy	14000.00
0005432531618	7751	Economy	14000.00
0005435215175	7751	Economy	14000.00
0005434069562	7751	Economy	14000.00
0005432531615	7751	Economy	14000.00
0005434069549	7751	Economy	14000.00
0005434069568	7751	Economy	14000.00
0005435215137	7751	Economy	14000.00
0005434069553	7751	Economy	14000.00
0005434069566	7751	Economy	14000.00
0005434069528	7751	Economy	14000.00
0005434069545	7751	Economy	14000.00
0005432531625	7751	Economy	14000.00
0005434069548	7751	Economy	14000.00
0005432531656	7751	Economy	14000.00
0005434069563	7751	Economy	15400.00
0005434069570	7751	Economy	15400.00
0005435283415	7751	Economy	15400.00
0005432070060	7751	Economy	14000.00
0005432150417	7751	Economy	15400.00
0005435214929	7751	Economy	14000.00
0005435215010	7751	Economy	14000.00
0005435725710	7751	Economy	14000.00
0005435725699	7751	Economy	14000.00
0005432531651	7751	Economy	14000.00
0005432531640	7751	Economy	14000.00
0005435214845	7751	Economy	14000.00
0005432150418	7751	Economy	14000.00
0005434069531	7751	Economy	14000.00
0005432531684	7751	Economy	14000.00
0005432531664	7751	Economy	14000.00
0005432531646	7751	Economy	14000.00
0005432531661	7751	Economy	14000.00
0005434069556	7751	Economy	14000.00
0005432070062	7751	Economy	14000.00
0005435215179	7751	Economy	14000.00
0005435725711	7751	Economy	14000.00
0005432531609	7751	Economy	14000.00
0005432429025	7751	Economy	14000.00
0005432531650	7751	Economy	14000.00
0005432531624	7751	Economy	14000.00
0005432531627	7751	Economy	14000.00
0005435283419	7751	Economy	14000.00
0005435214949	7751	Economy	14000.00
0005432531639	7751	Economy	14000.00
0005432531666	7751	Economy	14000.00
0005432531642	7751	Economy	14000.00
0005432531612	7751	Economy	14000.00
0005434069569	7751	Economy	14000.00
0005432531613	7751	Economy	14000.00
0005432070059	7751	Economy	14000.00
0005434069541	7751	Economy	14000.00
0005434069530	7751	Economy	14000.00
0005432531667	7751	Economy	14000.00
0005432531683	7751	Economy	14000.00
0005432531674	7751	Economy	14000.00
0005432531630	7751	Economy	14000.00
0005432531682	7751	Economy	14000.00
0005432535972	7751	Economy	14000.00
0005432531634	7751	Economy	14000.00
0005432429026	7751	Economy	14000.00
0005435214843	7751	Economy	14000.00
0005435214969	7751	Economy	14000.00
0005432533372	7751	Economy	14000.00
0005432531659	7751	Economy	14000.00
0005435214759	7751	Economy	14000.00
0005435214976	7751	Economy	14000.00
0005432531623	7751	Economy	14000.00
0005435215011	7751	Economy	14000.00
0005435426257	5343	Business	43100.00
0005435319782	5343	Business	43100.00
0005435616872	5343	Business	43100.00
0005435426306	5343	Business	43100.00
0005435319758	5343	Business	43100.00
0005435616857	5343	Business	43100.00
0005435426296	5343	Business	43100.00
0005435426409	5343	Business	43100.00
0005435616882	5343	Business	43100.00
0005432841042	5343	Business	43100.00
0005434345232	5343	Business	43100.00
0005435616878	5343	Business	43100.00
0005435097489	5343	Business	43100.00
0005434573752	5343	Business	43100.00
0005435426497	5343	Business	43100.00
0005435426176	5343	Business	43100.00
0005435426303	5343	Business	43100.00
0005435616839	5343	Business	43100.00
0005435042892	5343	Business	43100.00
0005435305045	5343	Comfort	24400.00
0005434345214	5343	Comfort	24400.00
0005435426299	5343	Comfort	24400.00
0005435426305	5343	Comfort	24400.00
0005435617194	5343	Comfort	24400.00
0005435616834	5343	Comfort	24400.00
0005435616856	5343	Comfort	24400.00
0005435616847	5343	Comfort	24400.00
0005435426339	5343	Comfort	24400.00
0005435616887	5343	Comfort	24400.00
0005432047656	5343	Comfort	24400.00
0005435616841	5343	Comfort	24400.00
0005435616826	5343	Comfort	24400.00
0005435616890	5343	Comfort	24400.00
0005434345216	5343	Comfort	24400.00
0005435616836	5343	Comfort	24400.00
0005434345213	5343	Comfort	24400.00
0005435305053	5343	Comfort	24400.00
0005434245532	5343	Comfort	24400.00
0005435426427	5343	Comfort	24400.00
0005435380407	5343	Comfort	24400.00
0005434245535	5343	Comfort	24400.00
0005435490331	5343	Comfort	24400.00
0005435426159	5343	Comfort	24400.00
0005434345234	5343	Comfort	24400.00
0005434245522	5343	Comfort	24400.00
0005434345220	5343	Comfort	24400.00
0005435616838	5343	Comfort	24400.00
0005435426421	5343	Comfort	24400.00
0005435426234	5343	Comfort	24400.00
0005434245508	5343	Comfort	24400.00
0005435426304	5343	Comfort	24400.00
0005435616884	5343	Comfort	24400.00
0005434573748	5343	Comfort	24400.00
0005435616897	5343	Economy	14400.00
0005435426343	5343	Economy	14400.00
0005435616832	5343	Economy	14400.00
0005435426019	5343	Economy	14400.00
0005435616879	5343	Economy	14400.00
0005435425972	5343	Economy	14400.00
0005434345215	5343	Economy	14400.00
0005435380411	5343	Economy	14400.00
0005432363482	5343	Economy	14400.00
0005435616840	5343	Economy	14400.00
0005435616860	5343	Economy	14400.00
0005435616893	5343	Economy	14400.00
0005435616846	5343	Economy	14400.00
0005434245527	5343	Economy	14400.00
0005435305051	5343	Economy	14400.00
0005435097488	5343	Economy	14400.00
0005432133632	5343	Economy	14400.00
0005435426279	5343	Economy	14400.00
0005435426115	5343	Economy	14400.00
0005435616869	5343	Economy	14400.00
0005435616873	5343	Economy	14400.00
0005435426267	5343	Economy	14400.00
0005434345223	5343	Economy	14400.00
0005434345233	5343	Economy	14400.00
0005435617193	5343	Economy	14400.00
0005435426325	5343	Economy	14400.00
0005435616848	5343	Economy	14400.00
0005435426018	5343	Economy	14400.00
0005435305046	5343	Economy	14400.00
0005435425995	5343	Economy	14400.00
0005435426218	5343	Economy	14400.00
0005434345212	5343	Economy	14400.00
0005434573745	5343	Economy	14400.00
0005435426370	5343	Economy	14400.00
0005435426410	5343	Economy	14400.00
0005435616883	5343	Economy	14400.00
0005435616859	5343	Economy	14400.00
0005435426229	5343	Economy	14400.00
0005434345227	5343	Economy	15800.00
0005432133629	5343	Economy	15800.00
0005435426328	5343	Economy	15800.00
0005435555425	5343	Economy	14400.00
0005435425900	5343	Economy	14400.00
0005435616895	5343	Economy	14400.00
0005435097490	5343	Economy	14400.00
0005432133630	5343	Economy	14400.00
0005435426386	5343	Economy	14400.00
0005434245693	5343	Economy	14400.00
0005435426295	5343	Economy	14400.00
0005435616858	5343	Economy	14400.00
0005435319738	5343	Economy	14400.00
0005434345236	5343	Economy	14400.00
0005434345222	5343	Economy	14400.00
0005434573746	5343	Economy	14400.00
0005435616886	5343	Economy	14400.00
0005435616894	5343	Economy	14400.00
0005434345218	5343	Economy	14400.00
0005435426116	5343	Economy	14400.00
0005435426233	5343	Economy	14400.00
0005435426274	5343	Economy	14400.00
0005435426083	5343	Economy	14400.00
0005435426228	5343	Economy	14400.00
0005432133631	5343	Economy	14400.00
0005435426302	5343	Economy	14400.00
0005435426297	5343	Economy	14400.00
0005434345219	5343	Economy	14400.00
0005435319778	5343	Economy	14400.00
0005434245664	5343	Economy	14400.00
0005432047657	5343	Economy	14400.00
0005435426430	5343	Economy	14400.00
0005435319777	5343	Economy	14400.00
0005435426025	5343	Economy	14400.00
0005435426217	5343	Economy	14400.00
0005434245553	5343	Economy	14400.00
0005432047654	5343	Economy	14400.00
0005435426320	5343	Economy	14400.00
0005435380404	5343	Economy	14400.00
0005434345229	5343	Economy	14400.00
0005435426498	5343	Economy	14400.00
0005435319776	5343	Economy	14400.00
0005432047655	5343	Economy	14400.00
0005435616876	5343	Economy	14400.00
0005432363491	5343	Economy	14400.00
0005434573749	5343	Economy	14400.00
0005435426225	5343	Economy	14400.00
0005434245694	5343	Economy	14400.00
0005435426319	5343	Economy	14400.00
0005435426235	5343	Economy	14400.00
0005435616885	5343	Economy	14400.00
0005435305047	5343	Economy	14400.00
0005435616875	5343	Economy	14400.00
0005435426300	5343	Economy	14400.00
0005434245510	5343	Economy	14400.00
0005435616837	5343	Economy	14400.00
0005435616861	5343	Economy	14400.00
0005435616853	5343	Economy	14400.00
0005435426293	5343	Economy	14400.00
0005435617244	5343	Economy	14400.00
0005435616880	5343	Economy	14400.00
0005434345225	5343	Economy	14400.00
0005432133628	5343	Economy	14400.00
0005435616889	5343	Economy	14400.00
0005435042893	5343	Economy	14400.00
0005435616871	5343	Economy	14400.00
0005435616850	5343	Economy	14400.00
0005434345221	5343	Economy	14400.00
0005432841047	5343	Economy	14400.00
0005435616835	5343	Economy	14400.00
0005435616827	5343	Economy	14400.00
0005434573747	5343	Economy	14400.00
0005435426294	5343	Economy	14400.00
0005435616849	5343	Economy	14400.00
0005435616855	5343	Economy	14400.00
0005435616865	5343	Economy	14400.00
0005435380393	5343	Economy	14400.00
0005435426152	5343	Economy	14400.00
0005435616874	5343	Economy	15800.00
0005435426082	5343	Economy	15800.00
0005435617196	5343	Economy	15800.00
0005435426258	5343	Economy	15800.00
0005434345231	5343	Economy	15800.00
0005435616867	5343	Economy	15800.00
0005435616852	5343	Economy	14400.00
0005435426349	5343	Economy	14400.00
0005435616851	5343	Economy	14400.00
0005435426017	5343	Economy	14400.00
0005435616842	5343	Economy	14400.00
0005435616896	5343	Economy	14400.00
0005435426510	5343	Economy	14400.00
0005435616892	5343	Economy	14400.00
0005435491502	5343	Economy	14400.00
0005434573750	5343	Economy	14400.00
0005435616845	5343	Economy	14400.00
0005435380373	5343	Economy	14400.00
0005434345217	5343	Economy	14400.00
0005435426323	5343	Economy	14400.00
0005435425901	5343	Economy	14400.00
0005435426396	5343	Economy	14400.00
0005434245576	5343	Economy	14400.00
0005435616863	5343	Economy	14400.00
0005434245512	5343	Economy	14400.00
0005435616868	5343	Economy	14400.00
0005435616891	5343	Economy	14400.00
0005435616881	5343	Economy	14400.00
0005435426395	5343	Economy	14400.00
0005435042894	5343	Economy	14400.00
0005435616829	5343	Economy	14400.00
0005435426085	5343	Economy	14400.00
0005434656592	5343	Economy	14400.00
0005434573751	5343	Economy	14400.00
0005435616843	5343	Economy	14400.00
0005435616877	5343	Economy	14400.00
0005435616833	5343	Economy	14400.00
0005435426151	5343	Economy	14400.00
0005435319737	5343	Economy	14400.00
0005435426129	5343	Economy	14400.00
0005435617195	5343	Economy	14400.00
0005435305054	5343	Economy	14400.00
0005435616844	5343	Economy	14400.00
0005434245511	5343	Economy	14400.00
0005435616854	5343	Economy	14400.00
0005434345226	5343	Economy	14400.00
0005435305052	5343	Economy	14400.00
0005434345238	5343	Economy	14400.00
0005434345235	5343	Economy	14400.00
0005434245509	5343	Economy	14400.00
0005435616831	5343	Economy	14400.00
0005434345224	5343	Economy	14400.00
0005435425902	5343	Economy	14400.00
0005435426298	5343	Economy	14400.00
0005434245544	5343	Economy	14400.00
0005435426385	5343	Economy	14400.00
0005435490330	5343	Economy	14400.00
0005434245554	5343	Economy	14400.00
0005434345228	5343	Economy	14400.00
0005435616888	5343	Economy	14400.00
0005435426413	5343	Economy	14400.00
0005435555426	5343	Economy	14400.00
0005435380408	5343	Economy	14400.00
0005435097487	5343	Economy	14400.00
0005435426324	5343	Economy	14400.00
0005435319781	5343	Economy	14400.00
0005435426426	5343	Economy	14400.00
0005435616828	5343	Economy	14400.00
0005434345230	5343	Economy	14400.00
0005435319744	5343	Economy	14400.00
0005435302282	5343	Economy	14400.00
0005435426307	5343	Economy	14400.00
0005435426357	5343	Economy	14400.00
0005435616870	5343	Economy	14400.00
0005434245573	5343	Economy	14400.00
0005435616864	5343	Economy	14400.00
0005435380410	5343	Economy	14400.00
0005435616862	5343	Economy	14400.00
0005435616866	5343	Economy	14400.00
0005434345237	5343	Economy	14400.00
0005435616830	5343	Economy	14400.00
0005435097374	10904	Business	43100.00
0005432166989	10904	Business	43100.00
0005435097442	10904	Business	43100.00
0005435546235	10904	Business	43100.00
0005435615831	10904	Business	43100.00
0005435616090	10904	Business	43100.00
0005435616228	10904	Business	43100.00
0005435426743	10904	Business	43100.00
0005434344815	10904	Business	43100.00
0005432165252	10904	Business	43100.00
0005435616047	10904	Business	43100.00
0005435097393	10904	Business	43100.00
0005435615812	10904	Business	43100.00
0005435426734	10904	Business	43100.00
0005435615859	10904	Business	43100.00
0005435615471	10904	Business	43100.00
0005435616254	10904	Business	43100.00
0005435615742	10904	Business	43100.00
0005435615686	10904	Business	43100.00
0005435615997	10904	Business	43100.00
0005435426750	10904	Business	43100.00
0005435615998	10904	Comfort	24400.00
0005435491483	10904	Comfort	24400.00
0005435615943	10904	Comfort	24400.00
0005434344906	10904	Comfort	24400.00
0005435426714	10904	Comfort	24400.00
0005435615653	10904	Comfort	24400.00
0005435546236	10904	Comfort	24400.00
0005435615496	10904	Comfort	24400.00
0005434344793	10904	Comfort	24400.00
0005434344760	10904	Comfort	24400.00
0005435615231	10904	Comfort	24400.00
0005435616172	10904	Comfort	24400.00
0005435426719	10904	Comfort	24400.00
0005435426722	10904	Comfort	24400.00
0005435615777	10904	Comfort	24400.00
0005435426708	10904	Comfort	24400.00
0005435426745	10904	Comfort	24400.00
0005435097375	10904	Comfort	24400.00
0005435615920	10904	Comfort	24400.00
0005434245813	10904	Comfort	24400.00
0005435616159	10904	Comfort	24400.00
0005435615849	10904	Comfort	24400.00
0005435097397	10904	Comfort	24400.00
0005435616171	10904	Comfort	24400.00
0005435615544	10904	Comfort	24400.00
0005435616278	10904	Comfort	24400.00
0005434573645	10904	Comfort	24400.00
0005435426715	10904	Comfort	24400.00
0005435615683	10904	Comfort	24400.00
0005435615600	10904	Comfort	24400.00
0005434573558	10904	Comfort	24400.00
0005435615697	10904	Economy	14400.00
0005434344931	10904	Economy	14400.00
0005435616420	10904	Economy	14400.00
0005434344968	10904	Economy	14400.00
0005435615890	10904	Economy	14400.00
0005434573666	10904	Economy	14400.00
0005434344807	10904	Economy	14400.00
0005434656613	10904	Economy	14400.00
0005434245810	10904	Economy	14400.00
0005432166990	10904	Economy	14400.00
0005435426735	10904	Economy	14400.00
0005434344811	10904	Economy	14400.00
0005435615775	10904	Economy	14400.00
0005435616374	10904	Economy	14400.00
0005435615937	10904	Economy	14400.00
0005435426710	10904	Economy	14400.00
0005432165256	10904	Economy	14400.00
0005434573644	10904	Economy	14400.00
0005435555411	10904	Economy	14400.00
0005435042934	10904	Economy	14400.00
0005435304266	10904	Economy	14400.00
0005435615881	10904	Economy	14400.00
0005434344875	10904	Economy	14400.00
0005435426741	10904	Economy	14400.00
0005434573555	10904	Economy	14400.00
0005434344848	10904	Economy	14400.00
0005435305073	10904	Economy	14400.00
0005435304267	10904	Economy	14400.00
0005434573570	10904	Economy	14400.00
0005435426723	10904	Economy	14400.00
0005434573614	10904	Economy	14400.00
0005435616253	10904	Economy	14400.00
0005435426752	10904	Economy	14400.00
0005435426753	10904	Economy	14400.00
0005435615882	10904	Economy	14400.00
0005435426742	10904	Economy	14400.00
0005435319818	10904	Economy	14400.00
0005432363511	10904	Economy	14400.00
0005434344902	10904	Economy	14400.00
0005433719235	10904	Economy	14400.00
0005434245798	10904	Economy	14400.00
0005434344808	10904	Economy	14400.00
0005435426724	10904	Economy	14400.00
0005435097371	10904	Economy	14400.00
0005435616426	10904	Economy	14400.00
0005435426718	10904	Economy	14400.00
0005434344881	10904	Economy	14400.00
0005435615994	10904	Economy	14400.00
0005435616017	10904	Economy	14400.00
0005434344872	10904	Economy	14400.00
0005435555412	10904	Economy	14400.00
0005435616101	10904	Economy	14400.00
0005434344995	10904	Economy	14400.00
0005435616176	10904	Economy	14400.00
0005434344761	10904	Economy	14400.00
0005435426739	10904	Economy	14400.00
0005435615837	10904	Economy	14400.00
0005434344666	10904	Economy	14400.00
0005434344762	10904	Economy	14400.00
0005435426711	10904	Economy	14400.00
0005434344792	10904	Economy	14400.00
0005434245805	10904	Economy	15800.00
0005435426709	10904	Economy	14400.00
0005435616260	10904	Economy	15800.00
0005432166991	10904	Economy	14400.00
0005435615894	10904	Economy	14400.00
0005434344813	10904	Economy	15800.00
0005435616070	10904	Economy	14400.00
0005434344967	10904	Economy	15800.00
0005434245812	10904	Economy	14400.00
0005435616092	10904	Economy	14400.00
0005434245804	10904	Economy	14400.00
0005435615847	10904	Economy	14400.00
0005434245795	10904	Economy	14400.00
0005434245797	10904	Economy	14400.00
0005435426733	10904	Economy	14400.00
0005435615787	10904	Economy	14400.00
0005434344854	10904	Economy	14400.00
0005434344806	10904	Economy	14400.00
0005435615874	10904	Economy	14400.00
0005435426731	10904	Economy	14400.00
0005435097354	10904	Economy	14400.00
0005435426712	10904	Economy	14400.00
0005435042935	10904	Economy	14400.00
0005435616151	10904	Economy	14400.00
0005435616256	10904	Economy	14400.00
0005435615958	10904	Economy	14400.00
0005435426720	10904	Economy	14400.00
0005435490295	10904	Economy	14400.00
0005435426740	10904	Economy	14400.00
0005435615938	10904	Economy	14400.00
0005435380430	10904	Economy	14400.00
0005435426726	10904	Economy	14400.00
0005435615559	10904	Economy	14400.00
0005434344763	10904	Economy	14400.00
0005435426725	10904	Economy	14400.00
0005435615959	10904	Economy	14400.00
0005435615232	10904	Economy	14400.00
0005435615802	10904	Economy	14400.00
0005435615813	10904	Economy	14400.00
0005435615260	10904	Economy	14400.00
0005434573615	10904	Economy	14400.00
0005435615755	10904	Economy	14400.00
0005435426736	10904	Economy	14400.00
0005435615647	10904	Economy	14400.00
0005434245802	10904	Economy	14400.00
0005434344912	10904	Economy	14400.00
0005435380431	10904	Economy	14400.00
0005435097362	10904	Economy	14400.00
0005435097394	10904	Economy	14400.00
0005435615230	10904	Economy	14400.00
0005435097445	10904	Economy	14400.00
0005435304265	10904	Economy	14400.00
0005435426721	10904	Economy	14400.00
0005435617176	10904	Economy	14400.00
0005435305074	10904	Economy	14400.00
0005435615803	10904	Economy	14400.00
0005435616121	10904	Economy	14400.00
0005435615919	10904	Economy	14400.00
0005434573571	10904	Economy	14400.00
0005435490303	10904	Economy	14400.00
0005435615846	10904	Economy	14400.00
0005432165255	10904	Economy	14400.00
0005435615662	10904	Economy	14400.00
0005435615564	10904	Economy	14400.00
0005434344775	10904	Economy	14400.00
0005435615684	10904	Economy	14400.00
0005435319817	10904	Economy	14400.00
0005435615754	10904	Economy	14400.00
0005435616089	10904	Economy	14400.00
0005435616124	10904	Economy	14400.00
0005435616073	10904	Economy	14400.00
0005434344812	10904	Economy	14400.00
0005435097367	10904	Economy	14400.00
0005435319819	10904	Economy	14400.00
0005435616160	10904	Economy	14400.00
0005434656614	10904	Economy	14400.00
0005435097355	10904	Economy	14400.00
0005432363509	10904	Economy	14400.00
0005434344929	10904	Economy	14400.00
0005435615690	10904	Economy	14400.00
0005435615949	10904	Economy	14400.00
0005434344789	10904	Economy	14400.00
0005435426737	10904	Economy	14400.00
0005435426744	10904	Economy	14400.00
0005435616258	10904	Economy	14400.00
0005435616072	10904	Economy	14400.00
0005435615975	10904	Economy	14400.00
0005435615654	10904	Economy	14400.00
0005432363510	10904	Economy	14400.00
0005434245806	10904	Economy	14400.00
0005435615336	10904	Economy	14400.00
0005435615756	10904	Economy	14400.00
0005435616069	10904	Economy	14400.00
0005434245808	10904	Economy	14400.00
0005435097444	10904	Economy	14400.00
0005435426730	10904	Economy	14400.00
0005435426747	10904	Economy	14400.00
0005435305071	10904	Economy	14400.00
0005435426732	10904	Economy	14400.00
0005435615776	10904	Economy	14400.00
0005432165253	10904	Economy	14400.00
0005435426716	10904	Economy	14400.00
0005435615688	10904	Economy	14400.00
0005435615942	10904	Economy	14400.00
0005434573602	10904	Economy	14400.00
0005434245803	10904	Economy	15800.00
0005434344759	10904	Economy	15800.00
0005435615313	10904	Economy	14400.00
0005435616123	10904	Economy	15800.00
0005435615932	10904	Economy	14400.00
0005435616264	10904	Economy	14400.00
0005435491489	10904	Economy	14400.00
0005435097368	10904	Economy	14400.00
0005434344928	10904	Economy	14400.00
0005435490309	10904	Economy	14400.00
0005434245814	10904	Economy	14400.00
0005434573667	10904	Economy	14400.00
0005435319820	10904	Economy	14400.00
0005435491484	10904	Economy	14400.00
0005435616166	10904	Economy	14400.00
0005434245811	10904	Economy	14400.00
0005434245801	10904	Economy	14400.00
0005435380428	10904	Economy	14400.00
0005434344946	10904	Economy	14400.00
0005435615607	10904	Economy	14400.00
0005435615893	10904	Economy	14400.00
0005435426755	10904	Economy	14400.00
0005435426748	10904	Economy	14400.00
0005435615314	10904	Economy	14400.00
0005434573603	10904	Economy	14400.00
0005435097407	10904	Economy	14400.00
0005435426754	10904	Economy	14400.00
0005435305072	10904	Economy	14400.00
0005435616175	10904	Economy	14400.00
0005435615915	10904	Economy	14400.00
0005435426728	10904	Economy	14400.00
0005435490304	10904	Economy	14400.00
0005435616133	10904	Economy	14400.00
0005435615729	10904	Economy	14400.00
0005434344980	10904	Economy	14400.00
0005435616170	10904	Economy	14400.00
0005434573597	10904	Economy	14400.00
0005434344913	10904	Economy	14400.00
0005435426717	10904	Economy	14400.00
0005435615685	10904	Economy	14400.00
0005435426727	10904	Economy	14400.00
0005434573559	10904	Economy	14400.00
0005435615879	10904	Economy	14400.00
0005432165257	10904	Economy	14400.00
0005435615497	10904	Economy	14400.00
0005434656615	10904	Economy	14400.00
0005435426729	10904	Economy	14400.00
0005432165254	10904	Economy	14400.00
0005435426749	10904	Economy	14400.00
0005435615889	10904	Economy	14400.00
0005435615976	10904	Economy	14400.00
0005435615914	10904	Economy	14400.00
0005435380429	10904	Economy	14400.00
0005434245794	10904	Economy	14400.00
0005435615828	10904	Economy	14400.00
0005434344823	10904	Economy	14400.00
0005435615558	10904	Economy	14400.00
0005435615753	10904	Economy	14400.00
0005435490296	10904	Economy	14400.00
0005434245799	10904	Economy	14400.00
0005434245809	10904	Economy	14400.00
0005434245807	10904	Economy	14400.00
0005435615864	10904	Economy	14400.00
0005435491485	10904	Economy	14400.00
0005435616071	10904	Economy	14400.00
0005434573648	10904	Economy	14400.00
0005435097443	10904	Economy	14400.00
0005435426713	10904	Economy	14400.00
0005434344930	10904	Economy	14400.00
0005435616277	10904	Economy	14400.00
0005434245800	10904	Economy	14400.00
0005435615642	10904	Economy	14400.00
0005435615950	10904	Economy	14400.00
0005435616059	10904	Economy	14400.00
0005435380432	10904	Economy	14400.00
0005433719236	10904	Economy	14400.00
0005435426751	10904	Economy	14400.00
0005435615850	10904	Economy	14400.00
0005435615993	10904	Economy	14400.00
0005435615814	10904	Economy	14400.00
0005435426746	10904	Economy	14400.00
0005435615936	10904	Economy	14400.00
0005435616259	10904	Economy	14400.00
0005435615851	10904	Economy	14400.00
0005434344799	10904	Economy	14400.00
0005434245796	10904	Economy	14400.00
0005434245793	10904	Economy	14400.00
0005435615609	10904	Economy	14400.00
0005435616425	10904	Economy	14400.00
0005435615603	10904	Economy	14400.00
0005435616261	10904	Economy	14400.00
0005434344800	10904	Economy	14400.00
0005435426738	10904	Economy	14400.00
0005432460750	3260	Business	18800.00
0005432460890	3260	Business	18800.00
0005432182341	3260	Business	18800.00
0005432460943	3260	Business	18800.00
0005432182337	3260	Business	18800.00
0005432460901	3260	Business	18800.00
0005432461048	3260	Business	18800.00
0005432461047	3260	Business	18800.00
0005432461039	3260	Business	18800.00
0005433507701	3260	Business	18800.00
0005433634787	3260	Business	18800.00
0005432460726	3260	Business	18800.00
0005432460920	3260	Business	18800.00
0005432460734	3260	Business	18800.00
0005433507699	3260	Business	18800.00
0005432460819	3260	Business	18800.00
0005433806353	3260	Business	18800.00
0005433634770	3260	Business	18800.00
0005432460855	3260	Business	18800.00
0005433634789	3260	Business	18800.00
0005432460729	3260	Business	18800.00
0005432460863	3260	Business	18800.00
0005433806373	3260	Business	18800.00
0005434143803	3260	Business	18800.00
0005434143805	3260	Business	18800.00
0005434143796	3260	Business	18800.00
0005433806354	3260	Business	18800.00
0005434150146	3260	Business	18800.00
0005434143801	3260	Economy	6900.00
0005432460897	3260	Economy	6900.00
0005432460934	3260	Economy	6900.00
0005434143795	3260	Economy	6900.00
0005432460951	3260	Economy	6900.00
0005433634773	3260	Economy	6900.00
0005433634790	3260	Economy	6300.00
0005432460895	3260	Economy	6300.00
0005433634786	3260	Economy	6300.00
0005433806360	3260	Economy	6300.00
0005433507691	3260	Economy	6300.00
0005433806367	3260	Economy	6300.00
0005433634781	3260	Economy	6300.00
0005433806357	3260	Economy	6300.00
0005433806372	3260	Economy	6300.00
0005434143806	3260	Economy	6300.00
0005433507700	3260	Economy	6300.00
0005432461068	3260	Economy	6300.00
0005433806359	3260	Economy	6300.00
0005432460865	3260	Economy	6300.00
0005433634767	3260	Economy	6300.00
0005434143813	3260	Economy	6300.00
0005432182345	3260	Economy	6300.00
0005432460725	3260	Economy	6300.00
0005433507694	3260	Economy	6300.00
0005432460949	3260	Economy	6300.00
0005433507690	3260	Economy	6300.00
0005434143799	3260	Economy	6300.00
0005434150145	3260	Economy	6300.00
0005432182342	3260	Economy	6300.00
0005432461040	3260	Economy	6300.00
0005433806369	3260	Economy	6300.00
0005432182340	3260	Economy	6300.00
0005432461003	3260	Economy	6300.00
0005434143802	3260	Economy	6300.00
0005434143808	3260	Economy	6300.00
0005432460875	3260	Economy	6300.00
0005434143794	3260	Economy	6300.00
0005432460950	3260	Economy	6300.00
0005433634792	3260	Economy	6300.00
0005433634771	3260	Economy	6300.00
0005433634791	3260	Economy	6300.00
0005433634783	3260	Economy	6300.00
0005434150149	3260	Economy	6300.00
0005433806366	3260	Economy	6300.00
0005433507693	3260	Economy	6300.00
0005432460918	3260	Economy	6300.00
0005432460872	3260	Economy	6300.00
0005434150144	3260	Economy	6300.00
0005433634784	3260	Economy	6300.00
0005433634793	3260	Economy	6300.00
0005432460728	3260	Economy	6300.00
0005432460909	3260	Economy	6300.00
0005433634780	3260	Economy	6300.00
0005434150147	3260	Economy	6300.00
0005432460883	3260	Economy	6300.00
0005432460936	3260	Economy	6300.00
0005434143814	3260	Economy	6300.00
0005434150142	3260	Economy	6300.00
0005432460948	3260	Economy	6300.00
0005432460907	3260	Economy	6300.00
0005434143811	3260	Economy	6300.00
0005433507697	3260	Economy	6300.00
0005432460828	3260	Economy	6300.00
0005432461061	3260	Economy	6300.00
0005432460924	3260	Economy	6300.00
0005434143812	3260	Economy	6900.00
0005434143793	3260	Economy	6900.00
0005433806365	3260	Economy	6900.00
0005432460837	3260	Economy	6900.00
0005433634768	3260	Economy	6900.00
0005432460906	3260	Economy	6300.00
0005432460935	3260	Economy	6300.00
0005432182346	3260	Economy	6300.00
0005434143816	3260	Economy	6300.00
0005434143800	3260	Economy	6900.00
0005432182338	3260	Economy	6300.00
0005434143817	3260	Economy	6300.00
0005433806362	3260	Economy	6300.00
0005434150148	3260	Economy	6300.00
0005433634777	3260	Economy	6300.00
0005433507698	3260	Economy	6300.00
0005433507696	3260	Economy	6300.00
0005432460988	3260	Economy	6300.00
0005432182339	3260	Economy	6300.00
0005433507689	3260	Economy	6300.00
0005434143815	3260	Economy	6300.00
0005432182347	3260	Economy	6300.00
0005432460926	3260	Economy	6300.00
0005434143810	3260	Economy	6300.00
0005432182348	3260	Economy	6300.00
0005432460922	3260	Economy	6300.00
0005434143809	3260	Economy	6300.00
0005432182343	3260	Economy	6300.00
0005434143807	3260	Economy	6300.00
0005433507692	3260	Economy	6300.00
0005433634785	3260	Economy	6300.00
0005432182336	3260	Economy	6300.00
0005432460751	3260	Economy	6300.00
0005432460917	3260	Economy	6300.00
0005433634788	3260	Economy	6300.00
0005432460854	3260	Economy	6300.00
0005433634782	3260	Economy	6300.00
0005432460941	3260	Economy	6300.00
0005432460876	3260	Economy	6300.00
0005432460820	3260	Economy	6300.00
0005432460818	3260	Economy	6300.00
0005432460942	3260	Economy	6300.00
0005432460882	3260	Economy	6300.00
0005432460737	3260	Economy	6300.00
0005433806358	3260	Economy	6300.00
0005433634776	3260	Economy	6300.00
0005432460815	3260	Economy	6300.00
0005433806371	3260	Economy	6300.00
0005432460986	3260	Economy	6300.00
0005433806355	3260	Economy	6300.00
0005434150143	3260	Economy	6300.00
0005432461115	3260	Economy	6300.00
0005433806370	3260	Economy	6300.00
0005433806361	3260	Economy	6300.00
0005433634775	3260	Economy	6300.00
0005434143797	3260	Economy	6300.00
0005432460845	3260	Economy	6300.00
0005433806363	3260	Economy	6300.00
0005433806356	3260	Economy	6300.00
0005432460896	3260	Economy	6300.00
0005432182335	3260	Economy	6300.00
0005434143804	3260	Economy	6300.00
0005433806364	3260	Economy	6300.00
0005432182344	3260	Economy	6300.00
0005433634778	3260	Economy	6300.00
0005434143792	3260	Economy	6300.00
0005433634772	3260	Economy	6300.00
0005433634779	3260	Economy	6300.00
0005432461011	3260	Economy	6300.00
0005433634774	3260	Economy	6300.00
0005434143798	3260	Economy	6300.00
0005433806368	3260	Economy	6300.00
0005433634769	3260	Economy	6300.00
0005433507695	3260	Economy	6300.00
0005432460921	3260	Economy	6300.00
0005432460862	3260	Economy	6300.00
0005435886213	3259	Business	18800.00
0005435886253	3259	Business	18800.00
0005435886228	3259	Business	18800.00
0005435886236	3259	Business	18800.00
0005435886199	3259	Business	18800.00
0005435886277	3259	Business	18800.00
0005435886363	3259	Business	18800.00
0005435886200	3259	Economy	6900.00
0005435886164	3259	Economy	6300.00
0005435886320	3259	Economy	6300.00
0005435886388	3259	Economy	6300.00
0005435886510	3259	Economy	6300.00
0005435886176	3259	Economy	6300.00
0005435886206	3259	Economy	6300.00
0005435886511	3259	Economy	6300.00
0005435886154	3259	Economy	6300.00
0005435886153	3259	Economy	6300.00
0005435886326	3259	Economy	6300.00
0005435886355	3259	Economy	6300.00
0005435886242	3259	Economy	6300.00
0005435886637	3259	Economy	6300.00
0005435886349	3259	Economy	6300.00
0005435886249	3259	Economy	6300.00
0005435886490	3259	Economy	6300.00
0005435886265	3259	Economy	6300.00
0005435886290	3259	Economy	6300.00
0005435886357	3259	Economy	6300.00
0005435886126	3259	Economy	6300.00
0005435886155	3259	Economy	6300.00
0005435886214	3259	Economy	6300.00
0005435886196	3259	Economy	6300.00
0005435886163	3259	Economy	6300.00
0005435886529	3259	Economy	6300.00
0005435886313	3259	Economy	6300.00
0005435886256	3259	Economy	6300.00
0005435886489	3259	Economy	6300.00
0005435886227	3259	Economy	6300.00
0005435886356	3259	Economy	6300.00
0005435886323	3259	Economy	6300.00
0005435886255	3259	Economy	6300.00
0005435886264	3259	Economy	6300.00
0005435886312	3259	Economy	6300.00
0005435886250	3259	Economy	6300.00
0005435886488	3259	Economy	6300.00
0005435886058	3259	Economy	6300.00
0005435886254	3259	Economy	6300.00
0005435886102	3259	Economy	6300.00
0005435886671	8285	Business	18800.00
0005432461348	8285	Business	18800.00
0005435886668	8285	Business	18800.00
0005433507499	8285	Business	18800.00
0005432461332	8285	Business	18800.00
0005435886728	8285	Business	18800.00
0005433507472	8285	Business	18800.00
0005432043103	8285	Business	18800.00
0005433507637	8285	Business	18800.00
0005435886721	8285	Business	18800.00
0005433507548	8285	Business	18800.00
0005435886716	8285	Business	18800.00
0005434312379	8285	Business	18800.00
0005435886697	8285	Business	18800.00
0005432461342	8285	Business	18800.00
0005435886729	8285	Business	18800.00
0005432461338	8285	Business	18800.00
0005435886710	8285	Business	18800.00
0005432461331	8285	Business	18800.00
0005432461335	8285	Business	18800.00
0005435886727	8285	Business	18800.00
0005433507517	8285	Business	18800.00
0005435886683	8285	Business	18800.00
0005433507530	8285	Business	18800.00
0005435886717	8285	Business	18800.00
0005434312396	8285	Business	18800.00
0005435886675	8285	Economy	6900.00
0005435886689	8285	Economy	6900.00
0005435886700	8285	Economy	6900.00
0005432461344	8285	Economy	6900.00
0005435886722	8285	Economy	6900.00
0005433507531	8285	Economy	6900.00
0005435886688	8285	Economy	6300.00
0005433507562	8285	Economy	6300.00
0005433507590	8285	Economy	6300.00
0005435886704	8285	Economy	6300.00
0005433507580	8285	Economy	6300.00
0005435886713	8285	Economy	6300.00
0005435143001	8285	Economy	6300.00
0005432461350	8285	Economy	6300.00
0005435886732	8285	Economy	6300.00
0005432043105	8285	Economy	6300.00
0005435886694	8285	Economy	6300.00
0005435886693	8285	Economy	6300.00
0005432461347	8285	Economy	6300.00
0005432461354	8285	Economy	6300.00
0005433507579	8285	Economy	6300.00
0005435886702	8285	Economy	6300.00
0005432461339	8285	Economy	6300.00
0005435886681	8285	Economy	6300.00
0005433507510	8285	Economy	6300.00
0005435886708	8285	Economy	6300.00
0005434312380	8285	Economy	6300.00
0005435886714	8285	Economy	6300.00
0005435886723	8285	Economy	6300.00
0005433507565	8285	Economy	6300.00
0005433507509	8285	Economy	6300.00
0005434326102	8285	Economy	6300.00
0005432461356	8285	Economy	6300.00
0005432461360	8285	Economy	6300.00
0005432461333	8285	Economy	6300.00
0005435886669	8285	Economy	6300.00
0005435886731	8285	Economy	6300.00
0005435886712	8285	Economy	6300.00
0005433507498	8285	Economy	6300.00
0005435886677	8285	Economy	6300.00
0005433507591	8285	Economy	6300.00
0005435886715	8285	Economy	6300.00
0005435886670	8285	Economy	6300.00
0005435886686	8285	Economy	6300.00
0005435886674	8285	Economy	6300.00
0005432461349	8285	Economy	6300.00
0005433507556	8285	Economy	6300.00
0005435886680	8285	Economy	6300.00
0005433507557	8285	Economy	6300.00
0005435143003	8285	Economy	6300.00
0005435886673	8285	Economy	6300.00
0005432043106	8285	Economy	6300.00
0005435886730	8285	Economy	6300.00
0005435886706	8285	Economy	6300.00
0005435143002	8285	Economy	6300.00
0005435886699	8285	Economy	6300.00
0005435886734	8285	Economy	6300.00
0005432461355	8285	Economy	6300.00
0005432043107	8285	Economy	6300.00
0005433507594	8285	Economy	6300.00
0005435886718	8285	Economy	6900.00
0005433507560	8285	Economy	6900.00
0005432461357	8285	Economy	6900.00
0005435886726	8285	Economy	6900.00
0005433507574	8285	Economy	6900.00
0005434326296	8285	Economy	6300.00
0005435886695	8285	Economy	6300.00
0005432043104	8285	Economy	6300.00
0005432461343	8285	Economy	6300.00
0005435886676	8285	Economy	6900.00
0005433507612	8285	Economy	6300.00
0005435886720	8285	Economy	6300.00
0005432461352	8285	Economy	6300.00
0005432461359	8285	Economy	6300.00
0005432043102	8285	Economy	6300.00
0005433507550	8285	Economy	6300.00
0005435886709	8285	Economy	6300.00
0005435886705	8285	Economy	6300.00
0005435886692	8285	Economy	6300.00
0005432461351	8285	Economy	6300.00
0005435886684	8285	Economy	6300.00
0005435886698	8285	Economy	6300.00
0005433507582	8285	Economy	6300.00
0005432461353	8285	Economy	6300.00
0005435886733	8285	Economy	6300.00
0005432461358	8285	Economy	6300.00
0005432461336	8285	Economy	6300.00
0005435886691	8285	Economy	6300.00
0005433507571	8285	Economy	6300.00
0005432461337	8285	Economy	6300.00
0005432461346	8285	Economy	6300.00
0005433507558	8285	Economy	6300.00
0005433507536	8285	Economy	6300.00
0005432461341	8285	Economy	6300.00
0005433507593	8285	Economy	6300.00
0005433507547	8285	Economy	6300.00
0005434326103	8285	Economy	6300.00
0005432043108	8285	Economy	6300.00
0005433507561	8285	Economy	6300.00
0005433507572	8285	Economy	6300.00
0005435886682	8285	Economy	6300.00
0005432461345	8285	Economy	6300.00
0005433507581	8285	Economy	6300.00
0005435886678	8285	Economy	6300.00
0005435886687	8285	Economy	6300.00
0005435886724	8285	Economy	6300.00
0005435886711	8285	Economy	6300.00
0005435886701	8285	Economy	6300.00
0005435886719	8285	Economy	6300.00
0005435886685	8285	Economy	6300.00
0005432043110	8285	Economy	6300.00
0005433507516	8285	Economy	6300.00
0005435886703	8285	Economy	6300.00
0005435886696	8285	Economy	6300.00
0005432461334	8285	Economy	6300.00
0005435886690	8285	Economy	6300.00
0005435886672	8285	Economy	6300.00
0005432043109	8285	Economy	6300.00
0005435886725	8285	Economy	6300.00
0005433507511	8285	Economy	6300.00
0005434312395	8285	Economy	6300.00
0005432461340	8285	Economy	6300.00
0005435886667	8285	Economy	6300.00
0005433507533	8285	Economy	6300.00
0005435886679	8285	Economy	6300.00
0005435886707	8285	Economy	6300.00
0005433805976	8284	Business	18800.00
0005433805922	8284	Business	18800.00
0005433806258	8284	Business	18800.00
0005433634467	8284	Business	18800.00
0005433634407	8284	Business	18800.00
0005433805923	8284	Business	18800.00
0005435860696	8284	Business	18800.00
0005433805972	8284	Business	18800.00
0005435858711	8284	Business	18800.00
0005433634300	8284	Business	18800.00
0005433806073	8284	Business	18800.00
0005433806163	8284	Business	18800.00
0005433805990	8284	Business	18800.00
0005433805971	8284	Economy	6900.00
0005433634331	8284	Economy	6900.00
0005433634518	8284	Economy	6900.00
0005433806090	8284	Economy	6300.00
0005433806089	8284	Economy	6300.00
0005435860697	8284	Economy	6300.00
0005433634332	8284	Economy	6300.00
0005434143747	8284	Economy	6300.00
0005435858714	8284	Economy	6300.00
0005433634525	8284	Economy	6300.00
0005433806107	8284	Economy	6300.00
0005435860701	8284	Economy	6300.00
0005433634283	8284	Economy	6300.00
0005433634496	8284	Economy	6300.00
0005433634495	8284	Economy	6300.00
0005433806149	8284	Economy	6300.00
0005433806134	8284	Economy	6300.00
0005433806046	8284	Economy	6300.00
0005433806108	8284	Economy	6300.00
0005435858715	8284	Economy	6300.00
0005434143748	8284	Economy	6300.00
0005433634510	8284	Economy	6300.00
0005433805977	8284	Economy	6300.00
0005433634261	8284	Economy	6300.00
0005433634268	8284	Economy	6300.00
0005435860699	8284	Economy	6300.00
0005433806077	8284	Economy	6300.00
0005433634401	8284	Economy	6300.00
0005433806133	8284	Economy	6300.00
0005433634414	8284	Economy	6300.00
0005435858713	8284	Economy	6300.00
0005433806135	8284	Economy	6300.00
0005433634395	8284	Economy	6300.00
0005435858710	8284	Economy	6900.00
0005433806047	8284	Economy	6900.00
0005435858712	8284	Economy	6300.00
0005433634394	8284	Economy	6300.00
0005433634355	8284	Economy	6300.00
0005433634602	8284	Economy	6300.00
0005433806048	8284	Economy	6300.00
0005433634404	8284	Economy	6300.00
0005433806074	8284	Economy	6300.00
0005433806064	8284	Economy	6300.00
0005433634573	8284	Economy	6300.00
0005435860698	8284	Economy	6300.00
0005433634351	8284	Economy	6300.00
0005433806157	8284	Economy	6300.00
0005435860702	8284	Economy	6300.00
0005435860695	8284	Economy	6300.00
0005433806150	8284	Economy	6300.00
0005433806099	8284	Economy	6300.00
0005433805991	8284	Economy	6300.00
0005433806106	8284	Economy	6300.00
0005433634301	8284	Economy	6300.00
0005433806025	8284	Economy	6300.00
0005433806049	8284	Economy	6300.00
0005433806164	8284	Economy	6300.00
0005433806171	8284	Economy	6300.00
0005433634517	8284	Economy	6300.00
0005435860700	8284	Economy	6300.00
0005433806041	8284	Economy	6300.00
0005433806126	8284	Economy	6300.00
0005433806063	8284	Economy	6300.00
0005432384289	4551	Business	9900.00
0005432728285	4551	Business	9900.00
0005434300238	4551	Business	9900.00
0005432384287	4551	Business	9900.00
0005433194973	4551	Business	9900.00
0005433722460	4551	Business	9900.00
0005432384285	4551	Business	9900.00
0005433722464	4551	Economy	3300.00
0005433722449	4551	Economy	3300.00
0005432384279	4551	Economy	3300.00
0005432384280	4551	Economy	3300.00
0005432728287	4551	Economy	3300.00
0005433194968	4551	Economy	3300.00
0005432384292	4551	Economy	3300.00
0005432384291	4551	Economy	3300.00
0005433722468	4551	Economy	3300.00
0005432728280	4551	Economy	3600.00
0005432384271	4551	Economy	3600.00
0005433722459	4551	Economy	3600.00
0005433722470	4551	Economy	3600.00
0005432384281	4551	Economy	3300.00
0005433722451	4551	Economy	3300.00
0005433722462	4551	Economy	3300.00
0005433194966	4551	Economy	3300.00
0005433194967	4551	Economy	3300.00
0005433194965	4551	Economy	3300.00
0005432728291	4551	Economy	3300.00
0005433722467	4551	Economy	3300.00
0005433454932	4551	Economy	3300.00
0005433722472	4551	Economy	3300.00
0005433722461	4551	Economy	3300.00
0005434300237	4551	Economy	3300.00
0005432384277	4551	Economy	3300.00
0005433722458	4551	Economy	3300.00
0005432384283	4551	Economy	3300.00
0005433194964	4551	Economy	3300.00
0005432384276	4551	Economy	3300.00
0005433194961	4551	Economy	3300.00
0005433722469	4551	Economy	3300.00
0005432384272	4551	Economy	3300.00
0005433722453	4551	Economy	3300.00
0005432728288	4551	Economy	3300.00
0005432384290	4551	Economy	3300.00
0005432728279	4551	Economy	3300.00
0005434300234	4551	Economy	3300.00
0005432728284	4551	Economy	3300.00
0005433194974	4551	Economy	3300.00
0005432728282	4551	Economy	3300.00
0005433722466	4551	Economy	3300.00
0005432384270	4551	Economy	3300.00
0005432728290	4551	Economy	3300.00
0005432384278	4551	Economy	3300.00
0005434300236	4551	Economy	3300.00
0005433722457	4551	Economy	3300.00
0005433194975	4551	Economy	3300.00
0005433194970	4551	Economy	3300.00
0005432384273	4551	Economy	3300.00
0005432384286	4551	Economy	3300.00
0005433722465	4551	Economy	3300.00
0005433453819	4551	Economy	3300.00
0005433722455	4551	Economy	3300.00
0005433722454	4551	Economy	3300.00
0005432728289	4551	Economy	3300.00
0005433722473	4551	Economy	3300.00
0005433194972	4551	Economy	3300.00
0005432384284	4551	Economy	3300.00
0005433722452	4551	Economy	3300.00
0005432384282	4551	Economy	3300.00
0005433194962	4551	Economy	3300.00
0005433722450	4551	Economy	3300.00
0005432384269	4551	Economy	3300.00
0005432384288	4551	Economy	3300.00
0005432728281	4551	Economy	3300.00
0005433194969	4551	Economy	3300.00
0005433194971	4551	Economy	3300.00
0005433722456	4551	Economy	3300.00
0005433722471	4551	Economy	3300.00
0005432384274	4551	Economy	3300.00
0005432728286	4551	Economy	3300.00
0005434300235	4551	Economy	3300.00
0005432384275	4551	Economy	3300.00
0005433194963	4551	Economy	3300.00
0005432728283	4551	Economy	3300.00
0005433722463	4551	Economy	3300.00
0005432383839	30249	Business	9900.00
0005432728157	30249	Business	9900.00
0005432383895	30249	Business	9900.00
0005432728213	30249	Business	9900.00
0005432383916	30249	Business	9900.00
0005432383845	30249	Business	9900.00
0005433722323	30249	Business	9900.00
0005432728158	30249	Business	9900.00
0005432728156	30249	Business	9900.00
0005432383882	30249	Economy	3300.00
0005432383932	30249	Economy	3300.00
0005432728164	30249	Economy	3300.00
0005433722330	30249	Economy	3300.00
0005432383686	30249	Economy	3300.00
0005432728167	30249	Economy	3300.00
0005433722341	30249	Economy	3300.00
0005432383757	30249	Economy	3300.00
0005433722334	30249	Economy	3600.00
0005432383740	30249	Economy	3600.00
0005432383846	30249	Economy	3600.00
0005433722340	30249	Economy	3600.00
0005432383840	30249	Economy	3300.00
0005433453803	30249	Economy	3300.00
0005432383891	30249	Economy	3300.00
0005433722312	30249	Economy	3300.00
0005432383762	30249	Economy	3300.00
0005432383838	30249	Economy	3300.00
0005433722318	30249	Economy	3300.00
0005432383894	30249	Economy	3300.00
0005432728214	30249	Economy	3300.00
0005433722317	30249	Economy	3300.00
0005432383812	30249	Economy	3300.00
0005432383724	30249	Economy	3300.00
0005432383933	30249	Economy	3300.00
0005432383646	30249	Economy	3300.00
0005433194908	30249	Economy	3300.00
0005432383973	30249	Economy	3300.00
0005432383910	30249	Economy	3300.00
0005432728215	30249	Economy	3300.00
0005432383798	30249	Economy	3300.00
0005432383809	30249	Economy	3300.00
0005432383813	30249	Economy	3300.00
0005432383883	30249	Economy	3300.00
0005432383890	30249	Economy	3300.00
0005432383739	30249	Economy	3300.00
0005433722322	30249	Economy	3300.00
0005432383930	30249	Economy	3300.00
0005432383902	30249	Economy	3300.00
0005433453802	30249	Economy	3300.00
0005432383800	30249	Economy	3300.00
0005432383889	30249	Economy	3300.00
0005432383875	30249	Economy	3300.00
0005433451663	30249	Economy	3300.00
0005432383876	30249	Economy	3300.00
0005432728192	30249	Economy	3300.00
0005432728223	30249	Economy	3300.00
0005433194922	30249	Economy	3300.00
0005432383763	30249	Economy	3300.00
0005432383801	30249	Economy	3300.00
0005432383877	30249	Economy	3300.00
0005432383726	30249	Economy	3300.00
0005432383929	30249	Economy	3300.00
0005432383884	30249	Economy	3300.00
0005432383780	30249	Economy	3300.00
0005432383837	30249	Economy	3300.00
0005432728163	30249	Economy	3300.00
0005432728185	30249	Economy	3300.00
0005432383725	30249	Economy	3300.00
0005432383901	30249	Economy	3300.00
0005432383749	30249	Economy	3300.00
0005435530167	1734	Business	57200.00
0005435530158	1734	Business	57200.00
0005435530162	1734	Business	57200.00
0005432925152	1734	Business	57200.00
0005435541607	1734	Business	57200.00
0005435530157	1734	Business	57200.00
0005432925126	1734	Business	57200.00
0005435529863	1734	Business	57200.00
0005435529875	1734	Economy	19100.00
0005435541612	1734	Economy	19100.00
0005435530169	1734	Economy	19100.00
0005435529864	1734	Economy	19100.00
0005435541606	1734	Economy	19100.00
0005435529867	1734	Economy	21000.00
0005435541614	1734	Economy	21000.00
0005435530166	1734	Economy	21000.00
0005435529871	1734	Economy	21000.00
0005435529873	1734	Economy	19100.00
0005435529870	1734	Economy	19100.00
0005435529874	1734	Economy	19100.00
0005435541613	1734	Economy	19100.00
0005435541619	1734	Economy	19100.00
0005432925142	1734	Economy	19100.00
0005435541615	1734	Economy	19100.00
0005435529862	1734	Economy	19100.00
0005435530171	1734	Economy	19100.00
0005435541620	1734	Economy	19100.00
0005433517152	1734	Economy	19100.00
0005435541609	1734	Economy	19100.00
0005435530161	1734	Economy	19100.00
0005435529872	1734	Economy	19100.00
0005432925143	1734	Economy	19100.00
0005435541617	1734	Economy	19100.00
0005435530160	1734	Economy	19100.00
0005432925153	1734	Economy	19100.00
0005435529869	1734	Economy	19100.00
0005435541621	1734	Economy	19100.00
0005435541618	1734	Economy	19100.00
0005433517155	1734	Economy	19100.00
0005435529865	1734	Economy	19100.00
0005435541616	1734	Economy	19100.00
0005435529866	1734	Economy	19100.00
0005435530168	1734	Economy	19100.00
0005433517154	1734	Economy	19100.00
0005435530164	1734	Economy	19100.00
0005432925144	1734	Economy	19100.00
0005433517153	1734	Economy	19100.00
0005435541611	1734	Economy	19100.00
0005435530159	1734	Economy	19100.00
0005435541608	1734	Economy	19100.00
0005435530163	1734	Economy	19100.00
0005435530172	1734	Economy	19100.00
0005435530165	1734	Economy	19100.00
0005435541610	1734	Economy	19100.00
0005435529868	1734	Economy	19100.00
0005435530170	1734	Economy	19100.00
0005435541514	22018	Business	57200.00
0005435518331	22018	Business	57200.00
0005435541389	22018	Business	57200.00
0005435541412	22018	Business	57200.00
0005435541501	22018	Business	57200.00
0005435541394	22018	Economy	19100.00
0005433517068	22018	Economy	19100.00
0005435541500	22018	Economy	19100.00
0005435518184	22018	Economy	19100.00
0005433517065	22018	Economy	19100.00
0005435518255	22018	Economy	19100.00
0005435541365	22018	Economy	19100.00
0005435518349	22018	Economy	21000.00
0005433517066	22018	Economy	21000.00
0005435518237	22018	Economy	21000.00
0005435541388	22018	Economy	19100.00
0005435518277	22018	Economy	19100.00
0005435518330	22018	Economy	19100.00
0005433517087	22018	Economy	19100.00
0005435518313	22018	Economy	19100.00
0005435541454	22018	Economy	19100.00
0005433517080	22018	Economy	19100.00
0005435518253	22018	Economy	19100.00
0005435541441	22018	Economy	19100.00
0005435541513	22018	Economy	19100.00
0005432925171	22018	Economy	19100.00
0005435518248	22018	Economy	19100.00
0005435518361	22018	Economy	19100.00
0005435518275	22018	Economy	19100.00
0005435518256	22018	Economy	19100.00
0005432925170	22018	Economy	19100.00
0005435541503	22018	Economy	19100.00
0005433517078	22018	Economy	19100.00
0005433517043	22018	Economy	19100.00
0005435518283	22018	Economy	19100.00
0005433517086	22018	Economy	19100.00
0005435541515	22018	Economy	19100.00
0005435541539	22018	Economy	19100.00
0005435518226	22018	Economy	19100.00
0005435541499	22018	Economy	19100.00
0005435518293	22018	Economy	19100.00
0005435518198	22018	Economy	19100.00
0005435518239	22018	Economy	19100.00
0005435518350	22018	Economy	19100.00
0005435541366	22018	Economy	19100.00
0005435541382	22018	Economy	19100.00
0005435518238	22018	Economy	19100.00
0005435541411	22018	Economy	19100.00
0005433517044	22018	Economy	19100.00
0005435518227	22018	Economy	19100.00
0005435518322	22018	Economy	19100.00
0005433517079	22018	Economy	19100.00
0005435541438	22018	Economy	19100.00
0005435518263	22018	Economy	19100.00
0005435518276	22018	Economy	19100.00
0005435253026	7387	Business	18500.00
0005432839906	7387	Business	18500.00
0005434459396	7387	Business	18500.00
0005434459389	7387	Business	18500.00
0005432841072	7387	Business	18500.00
0005435491478	7387	Business	18500.00
0005434459393	7387	Business	18500.00
0005434459395	7387	Economy	6200.00
0005432839899	7387	Economy	6200.00
0005435253102	7387	Economy	6200.00
0005432839896	7387	Economy	6200.00
0005434665005	7387	Economy	6200.00
0005432841070	7387	Economy	6200.00
0005435491492	7387	Economy	6800.00
0005432839904	7387	Economy	6800.00
0005435253058	7387	Economy	6800.00
0005432823505	7387	Economy	6200.00
0005434665006	7387	Economy	6200.00
0005434459390	7387	Economy	6200.00
0005432839895	7387	Economy	6200.00
0005432073491	7387	Economy	6200.00
0005432839891	7387	Economy	6200.00
0005432839894	7387	Economy	6200.00
0005432839905	7387	Economy	6200.00
0005432073489	7387	Economy	6200.00
0005432839900	7387	Economy	6200.00
0005432839902	7387	Economy	6200.00
0005434665007	7387	Economy	6200.00
0005435491488	7387	Economy	6200.00
0005434459387	7387	Economy	6200.00
0005435491482	7387	Economy	6200.00
0005435253110	7387	Economy	6200.00
0005435253059	7387	Economy	6200.00
0005435253020	7387	Economy	6200.00
0005435253080	7387	Economy	6200.00
0005434459386	7387	Economy	6200.00
0005434459397	7387	Economy	6200.00
0005432839903	7387	Economy	6200.00
0005434459392	7387	Economy	6200.00
0005435252988	7387	Economy	6200.00
0005435253100	7387	Economy	6200.00
0005432839893	7387	Economy	6200.00
0005432073490	7387	Economy	6200.00
0005435253111	7387	Economy	6200.00
0005434459388	7387	Economy	6200.00
0005432839897	7387	Economy	6200.00
0005434459394	7387	Economy	6200.00
0005432841071	7387	Economy	6200.00
0005432823506	7387	Economy	6200.00
0005432073487	7387	Economy	6200.00
0005432073488	7387	Economy	6200.00
0005435253027	7387	Economy	6200.00
0005434459391	7387	Economy	6200.00
0005435253112	7387	Economy	6200.00
0005435253081	7387	Economy	6200.00
0005435253084	7387	Economy	6200.00
0005432839892	7387	Economy	6200.00
0005435491493	7387	Economy	6200.00
0005432839898	7387	Economy	6200.00
0005435253057	7387	Economy	6200.00
0005432839901	7387	Economy	6200.00
0005435491503	28930	Business	18500.00
0005432839659	28930	Business	18500.00
0005432839734	28930	Business	18500.00
0005434459194	28930	Business	18500.00
0005434459145	28930	Business	18500.00
0005435253202	28930	Business	18500.00
0005434459218	28930	Business	18500.00
0005432839709	28930	Business	18500.00
0005432839660	28930	Business	18500.00
0005432839740	28930	Business	18500.00
0005432839681	28930	Economy	6200.00
0005432839636	28930	Economy	6200.00
0005434459219	28930	Economy	6200.00
0005432839645	28930	Economy	6200.00
0005434459240	28930	Economy	6200.00
0005434459176	28930	Economy	6200.00
0005432839573	28930	Economy	6200.00
0005434459239	28930	Economy	6800.00
0005435491504	28930	Economy	6800.00
0005434459203	28930	Economy	6800.00
0005432839806	28930	Economy	6200.00
0005432839801	28930	Economy	6200.00
0005432839665	28930	Economy	6200.00
0005434459221	28930	Economy	6200.00
0005434459132	28930	Economy	6200.00
0005432839628	28930	Economy	6200.00
0005432839719	28930	Economy	6200.00
0005432839606	28930	Economy	6200.00
0005432839596	28930	Economy	6200.00
0005432839546	28930	Economy	6200.00
0005432823496	28930	Economy	6200.00
0005432839755	28930	Economy	6200.00
0005432839696	28930	Economy	6200.00
0005434459274	28930	Economy	6200.00
0005435253203	28930	Economy	6200.00
0005434459233	28930	Economy	6200.00
0005434459204	28930	Economy	6200.00
0005435253200	28930	Economy	6200.00
0005432839641	28930	Economy	6200.00
0005432839605	28930	Economy	6200.00
0005434665023	28930	Economy	6200.00
0005432839702	28930	Economy	6200.00
0005432839689	28930	Economy	6200.00
0005435253198	28930	Economy	6200.00
0005434459216	28930	Economy	6200.00
0005432839597	28930	Economy	6200.00
0005432839800	28930	Economy	6200.00
0005432839661	28930	Economy	6200.00
0005432839599	28930	Economy	6200.00
0005432839613	28930	Economy	6200.00
0005432839629	28930	Economy	6200.00
0005432839598	28930	Economy	6200.00
0005434459259	28930	Economy	6200.00
0005434459193	28930	Economy	6200.00
0005434459255	28930	Economy	6200.00
0005432839688	28930	Economy	6200.00
0005432839797	28930	Economy	6200.00
0005432839545	28930	Economy	6200.00
0005435253201	28930	Economy	6200.00
0005432839741	28930	Economy	6200.00
0005432839706	28930	Economy	6200.00
0005432839721	28930	Economy	6200.00
0005434459275	28930	Economy	6200.00
0005432839690	28930	Economy	6200.00
0005435253199	28930	Economy	6200.00
0005432823497	28930	Economy	6200.00
0005434459217	28930	Economy	6200.00
0005432839697	28930	Economy	6200.00
0005435253204	28930	Economy	6200.00
0005434276167	8832	Business	145300.00
0005434276158	8832	Business	145300.00
0005434276143	8832	Business	145300.00
0005434276138	8832	Economy	48400.00
0005435990823	8832	Economy	48400.00
0005434276168	8832	Economy	53300.00
0005434276139	8832	Economy	48400.00
0005435990824	8832	Economy	48400.00
0005435990825	8832	Economy	48400.00
0005434276157	8832	Economy	48400.00
0005434276162	8832	Economy	48400.00
0005434276166	8832	Economy	48400.00
0005434276116	8832	Economy	48400.00
0005434276161	8832	Economy	48400.00
0005434276169	8832	Economy	48400.00
0005435990822	8832	Economy	48400.00
0005435990821	8832	Economy	48400.00
0005434276190	15766	Business	145300.00
0005435990747	15766	Business	145300.00
0005435990781	15766	Business	145300.00
0005435990748	15766	Economy	48400.00
0005435990773	15766	Economy	48400.00
0005434276192	15766	Economy	48400.00
0005434276191	15766	Economy	48400.00
0005435990772	15766	Economy	48400.00
0005434276189	15766	Economy	48400.00
0005433476934	20631	Economy	15900.00
0005432427201	20631	Economy	14500.00
0005432427203	20631	Economy	14500.00
0005432427204	20631	Economy	14500.00
0005432427202	20631	Economy	14500.00
0005433476935	20631	Economy	14500.00
0005433476931	20631	Economy	14500.00
0005433476930	20631	Economy	14500.00
0005433476932	20631	Economy	14500.00
0005433476929	20631	Economy	14500.00
0005433476933	20631	Economy	14500.00
0005432427205	20631	Economy	14500.00
0005435177636	6404	Business	36600.00
0005432363509	6404	Business	36600.00
0005432361715	6404	Business	36600.00
0005435490296	6404	Business	36600.00
0005434149968	6404	Business	36600.00
0005432361716	6404	Business	36600.00
0005432336372	6404	Business	36600.00
0005432361699	6404	Economy	12200.00
0005432361695	6404	Economy	12200.00
0005432336369	6404	Economy	12200.00
0005432361710	6404	Economy	12200.00
0005432361708	6404	Economy	12200.00
0005434149986	6404	Economy	12200.00
0005435177683	6404	Economy	12200.00
0005435177510	6404	Economy	12200.00
0005435177676	6404	Economy	12200.00
0005432336371	6404	Economy	12200.00
0005432361712	6404	Economy	12200.00
0005435177682	6404	Economy	12200.00
0005432361707	6404	Economy	12200.00
0005432062383	6404	Economy	12200.00
0005434150001	6404	Economy	12200.00
0005432336375	6404	Economy	12200.00
0005435177651	6404	Economy	12200.00
0005432361704	6404	Economy	12200.00
0005432361693	6404	Economy	12200.00
0005435177736	6404	Economy	12200.00
0005435177598	6404	Economy	12200.00
0005432361709	6404	Economy	12200.00
0005434150002	6404	Economy	12200.00
0005432361691	6404	Economy	12200.00
0005432361700	6404	Economy	12200.00
0005432361714	6404	Economy	12200.00
0005435177622	6404	Economy	12200.00
0005435177650	6404	Economy	12200.00
0005435177611	6404	Economy	13400.00
0005432361713	6404	Economy	12200.00
0005432062380	6404	Economy	13400.00
0005432361696	6404	Economy	12200.00
0005432361686	6404	Economy	12200.00
0005434149939	6404	Economy	12200.00
0005435490309	6404	Economy	12200.00
0005435177599	6404	Economy	12200.00
0005434149969	6404	Economy	12200.00
0005432363511	6404	Economy	12200.00
0005435177648	6404	Economy	12200.00
0005432361689	6404	Economy	12200.00
0005432361717	6404	Economy	12200.00
0005432361697	6404	Economy	12200.00
0005435490295	6404	Economy	12200.00
0005432062381	6404	Economy	12200.00
0005435177654	6404	Economy	12200.00
0005432361706	6404	Economy	12200.00
0005435177652	6404	Economy	12200.00
0005435177663	6404	Economy	12200.00
0005432361702	6404	Economy	12200.00
0005435177704	6404	Economy	12200.00
0005432336373	6404	Economy	12200.00
0005432336370	6404	Economy	12200.00
0005432361687	6404	Economy	12200.00
0005432361705	6404	Economy	12200.00
0005435490304	6404	Economy	12200.00
0005432062379	6404	Economy	12200.00
0005432361694	6404	Economy	12200.00
0005432361690	6404	Economy	12200.00
0005435177675	6404	Economy	12200.00
0005435490303	6404	Economy	12200.00
0005435177662	6404	Economy	12200.00
0005435177679	6404	Economy	12200.00
0005432361701	6404	Economy	12200.00
0005435177731	6404	Economy	12200.00
0005435177807	6404	Economy	12200.00
0005432363510	6404	Economy	12200.00
0005432361688	6404	Economy	12200.00
0005435177694	6404	Economy	12200.00
0005435177645	6404	Economy	12200.00
0005432361698	6404	Economy	12200.00
0005435177646	6404	Economy	12200.00
0005435177702	6404	Economy	12200.00
0005432361703	6404	Economy	12200.00
0005432062382	6404	Economy	12200.00
0005435177699	6404	Economy	12200.00
0005432336374	6404	Economy	12200.00
0005435177700	6404	Economy	12200.00
0005435177533	6404	Economy	12200.00
0005432361711	6404	Economy	12200.00
0005432361692	6404	Economy	12200.00
0005435490334	21032	Business	36600.00
0005432361464	21032	Business	36600.00
0005432361411	21032	Business	36600.00
0005432336297	21032	Business	36600.00
0005432361316	21032	Business	36600.00
0005432361246	21032	Business	36600.00
0005432361419	21032	Business	36600.00
0005432336286	21032	Business	36600.00
0005432361155	21032	Business	36600.00
0005432361421	21032	Business	36600.00
0005432361128	21032	Economy	12200.00
0005432361136	21032	Economy	12200.00
0005432336336	21032	Economy	12200.00
0005432361412	21032	Economy	12200.00
0005432361288	21032	Economy	12200.00
0005432336338	21032	Economy	12200.00
0005432361106	21032	Economy	12200.00
0005432361190	21032	Economy	12200.00
0005432361278	21032	Economy	12200.00
0005432361404	21032	Economy	12200.00
0005432361290	21032	Economy	12200.00
0005435177838	21032	Economy	12200.00
0005432361431	21032	Economy	12200.00
0005432361519	21032	Economy	12200.00
0005432361105	21032	Economy	12200.00
0005432361460	21032	Economy	12200.00
0005432361154	21032	Economy	12200.00
0005432361285	21032	Economy	12200.00
0005432361328	21032	Economy	12200.00
0005432361430	21032	Economy	12200.00
0005435723102	21032	Economy	12200.00
0005432361307	21032	Economy	12200.00
0005432361161	21032	Economy	12200.00
0005434150063	21032	Economy	12200.00
0005435723103	21032	Economy	12200.00
0005432361236	21032	Economy	12200.00
0005435177839	21032	Economy	12200.00
0005435177835	21032	Economy	12200.00
0005432336287	21032	Economy	12200.00
0005432336295	21032	Economy	12200.00
0005432336236	21032	Economy	12200.00
0005432361329	21032	Economy	12200.00
0005435490332	21032	Economy	12200.00
0005435177836	21032	Economy	13400.00
0005435177843	21032	Economy	13400.00
0005432361461	21032	Economy	13400.00
0005434150061	21032	Economy	13400.00
0005432361452	21032	Economy	12200.00
0005435490333	21032	Economy	12200.00
0005432361159	21032	Economy	12200.00
0005432363487	21032	Economy	12200.00
0005432361213	21032	Economy	12200.00
0005432361315	21032	Economy	12200.00
0005435177833	21032	Economy	12200.00
0005432361403	21032	Economy	12200.00
0005432361387	21032	Economy	12200.00
0005434150066	21032	Economy	12200.00
0005434150060	21032	Economy	12200.00
0005432336310	21032	Economy	12200.00
0005435177834	21032	Economy	12200.00
0005435177841	21032	Economy	12200.00
0005432361162	21032	Economy	12200.00
0005432361402	21032	Economy	12200.00
0005432361344	21032	Economy	12200.00
0005432361160	21032	Economy	12200.00
0005432361413	21032	Economy	12200.00
0005432361107	21032	Economy	12200.00
0005432361212	21032	Economy	12200.00
0005432336255	21032	Economy	12200.00
0005435177842	21032	Economy	12200.00
0005432361429	21032	Economy	12200.00
0005432361314	21032	Economy	12200.00
0005432336311	21032	Economy	12200.00
0005435177837	21032	Economy	12200.00
0005435177832	21032	Economy	12200.00
0005432336324	21032	Economy	12200.00
0005435177844	21032	Economy	12200.00
0005432361138	21032	Economy	12200.00
0005432336312	21032	Economy	12200.00
0005432361339	21032	Economy	12200.00
0005432361420	21032	Economy	12200.00
0005432361520	21032	Economy	12200.00
0005434150062	21032	Economy	12200.00
0005435177830	21032	Economy	12200.00
0005435177831	21032	Economy	12200.00
0005432361313	21032	Economy	12200.00
0005432361503	21032	Economy	12200.00
0005432361463	21032	Economy	12200.00
0005432336337	21032	Economy	12200.00
0005435177840	21032	Economy	12200.00
0005434150065	21032	Economy	12200.00
0005434150064	21032	Economy	12200.00
0005432361336	21032	Economy	12200.00
0005434459267	17736	Economy	3400.00
0005434459220	17736	Economy	3400.00
0005434448391	17736	Economy	3400.00
0005434459264	17736	Economy	3400.00
0005434459212	17736	Economy	3100.00
0005434459260	17736	Economy	3100.00
0005434459242	17736	Economy	3100.00
0005434459209	17736	Economy	3100.00
0005434463976	17736	Economy	3100.00
0005434459307	17736	Economy	3100.00
0005434459251	17736	Economy	3100.00
0005434459128	17736	Economy	3100.00
0005434448389	17736	Economy	3100.00
0005434186283	17736	Economy	3100.00
0005434459214	17736	Economy	3100.00
0005434459234	17736	Economy	3100.00
0005434459229	17736	Economy	3100.00
0005434186282	17736	Economy	3100.00
0005434459293	17736	Economy	3100.00
0005434459265	17736	Economy	3100.00
0005434459129	17736	Economy	3100.00
0005434459213	17736	Economy	3100.00
0005434459228	17736	Economy	3100.00
0005434463975	17736	Economy	3100.00
0005434459278	17736	Economy	3100.00
0005434186281	17736	Economy	3100.00
0005434459277	17736	Economy	3100.00
0005434459178	17736	Economy	3100.00
0005434459205	17736	Economy	3100.00
0005434459292	17736	Economy	3100.00
0005434459283	17736	Economy	3100.00
0005434186284	17736	Economy	3100.00
0005434459266	17736	Economy	3100.00
0005434459206	17736	Economy	3100.00
0005434459215	17736	Economy	3100.00
0005434461682	17736	Economy	3100.00
0005434448390	17736	Economy	3100.00
0005434459190	17736	Economy	3100.00
0005434459191	17736	Economy	3100.00
0005434459127	17736	Economy	3100.00
0005434186264	29121	Economy	3400.00
0005434448409	29121	Economy	3400.00
0005434459395	29121	Economy	3100.00
0005434459386	29121	Economy	3100.00
0005434459389	29121	Economy	3100.00
0005434459393	29121	Economy	3100.00
0005434459390	29121	Economy	3100.00
0005434448410	29121	Economy	3100.00
0005434462849	29121	Economy	3100.00
0005434448411	29121	Economy	3100.00
0005434459397	29121	Economy	3100.00
0005434459388	29121	Economy	3100.00
0005434186263	29121	Economy	3100.00
0005434459394	29121	Economy	3100.00
0005434459392	29121	Economy	3100.00
0005434459391	29121	Economy	3100.00
0005434459396	29121	Economy	3100.00
0005434463989	29121	Economy	3100.00
0005434459387	29121	Economy	3100.00
0005434462850	29121	Economy	3100.00
0005434186262	29121	Economy	3100.00
0005434463990	29121	Economy	3100.00
0005435218124	21417	Economy	7300.00
0005432605425	21417	Economy	7300.00
0005432605421	21417	Economy	6600.00
0005432605409	21417	Economy	6600.00
0005435220498	21417	Economy	6600.00
0005432605422	21417	Economy	6600.00
0005432605415	21417	Economy	6600.00
0005432605434	21417	Economy	6600.00
0005432605406	21417	Economy	6600.00
0005432605417	21417	Economy	6600.00
0005432605427	21417	Economy	6600.00
0005435218126	21417	Economy	6600.00
0005432605432	21417	Economy	6600.00
0005432605429	21417	Economy	6600.00
0005435218125	21417	Economy	6600.00
0005435218127	21417	Economy	6600.00
0005432605423	21417	Economy	6600.00
0005432605424	21417	Economy	6600.00
0005432605431	21417	Economy	6600.00
0005435220499	21417	Economy	6600.00
0005432605418	21417	Economy	6600.00
0005432605405	21417	Economy	6600.00
0005432605408	21417	Economy	6600.00
0005432605414	21417	Economy	6600.00
0005432605413	21417	Economy	6600.00
0005432605426	21417	Economy	6600.00
0005432605410	21417	Economy	6600.00
0005432605428	21417	Economy	6600.00
0005432605407	21417	Economy	6600.00
0005432605411	21417	Economy	6600.00
0005432605403	21417	Economy	6600.00
0005432605416	21417	Economy	6600.00
0005432605430	21417	Economy	6600.00
0005432605433	21417	Economy	6600.00
0005432605420	21417	Economy	6600.00
0005432605419	21417	Economy	6600.00
0005432605412	21417	Economy	6600.00
0005435220500	21417	Economy	6600.00
0005432605404	21417	Economy	6600.00
0005432605087	31694	Economy	7300.00
0005432605159	31694	Economy	7300.00
0005432605085	31694	Economy	7300.00
0005432605175	31694	Economy	6600.00
0005432605021	31694	Economy	6600.00
0005432605227	31694	Economy	6600.00
0005432605045	31694	Economy	6600.00
0005432605052	31694	Economy	6600.00
0005432605136	31694	Economy	6600.00
0005432605225	31694	Economy	6600.00
0005432605226	31694	Economy	6600.00
0005432605100	31694	Economy	6600.00
0005432605251	31694	Economy	6600.00
0005432605166	31694	Economy	6600.00
0005432604921	31694	Economy	6600.00
0005432605176	31694	Economy	6600.00
0005432605065	31694	Economy	6600.00
0005432605138	31694	Economy	6600.00
0005432605250	31694	Economy	6600.00
0005432605083	31694	Economy	6600.00
0005432605160	31694	Economy	6600.00
0005432605247	31694	Economy	6600.00
0005432605123	31694	Economy	6600.00
0005432605076	31694	Economy	6600.00
0005432605079	31694	Economy	6600.00
0005432605066	31694	Economy	6600.00
0005432605142	31694	Economy	6600.00
0005432605114	31694	Economy	6600.00
0005432605167	31694	Economy	6600.00
0005432605140	31694	Economy	6600.00
0005432604864	31694	Economy	6600.00
0005432605158	31694	Economy	6600.00
0005432605135	31694	Economy	6600.00
0005432605031	31694	Economy	6600.00
0005432605116	31694	Economy	6600.00
0005432605068	31694	Economy	6600.00
0005432605249	31694	Economy	6600.00
0005432605043	31694	Economy	6600.00
0005432605084	31694	Economy	6600.00
0005432604952	31694	Economy	6600.00
0005432605248	31694	Economy	6600.00
0005432605035	31694	Economy	6600.00
0005432605141	31694	Economy	6600.00
0005432605067	31694	Economy	6600.00
0005432605042	31694	Economy	6600.00
0005433293346	12301	Economy	19500.00
0005435154681	12301	Economy	17800.00
0005433293340	12301	Economy	17800.00
0005435154688	12301	Economy	17800.00
0005435154685	12301	Economy	17800.00
0005433293337	12301	Economy	17800.00
0005433293367	12301	Economy	17800.00
0005435154678	12301	Economy	17800.00
0005435154686	12301	Economy	17800.00
0005435154679	12301	Economy	17800.00
0005435154680	12301	Economy	17800.00
0005433293357	12301	Economy	17800.00
0005433293364	12301	Economy	17800.00
0005433293378	12301	Economy	17800.00
0005435154687	12301	Economy	17800.00
0005435154689	12301	Economy	17800.00
0005435154690	12301	Economy	17800.00
0005435154683	12301	Economy	17800.00
0005435154684	12301	Economy	17800.00
0005433293308	12301	Economy	17800.00
0005433293339	12301	Economy	17800.00
0005435154682	12301	Economy	17800.00
0005433293358	12301	Economy	17800.00
0005433293366	12301	Economy	17800.00
0005435154675	12301	Economy	17800.00
0005435154676	12301	Economy	17800.00
0005435154677	12301	Economy	17800.00
0005433293342	12301	Economy	17800.00
0005433293345	12301	Economy	17800.00
0005435904726	18918	Economy	6600.00
0005435904913	18918	Economy	6600.00
0005435904727	18918	Economy	6600.00
0005434606905	18918	Economy	6600.00
0005434605001	22356	Economy	6600.00
0005435904714	22356	Economy	6600.00
0005434605002	22356	Economy	6600.00
0005434605000	22356	Economy	6600.00
0005434606925	22356	Economy	6600.00
0005434606927	22356	Economy	6600.00
0005434606926	22356	Economy	6600.00
0005432748613	384	Business	44500.00
0005432891399	384	Business	44500.00
0005432748612	384	Business	44500.00
0005435154695	384	Business	44500.00
0005432891315	384	Business	44500.00
0005432748617	384	Business	44500.00
0005432748622	384	Business	44500.00
0005432748621	384	Business	44500.00
0005432748614	384	Economy	14800.00
0005432891429	384	Economy	14800.00
0005432748616	384	Economy	14800.00
0005435154692	384	Economy	14800.00
0005432748632	384	Economy	14800.00
0005432748626	384	Economy	14800.00
0005435154693	384	Economy	14800.00
0005432891364	384	Economy	14800.00
0005432891455	384	Economy	14800.00
0005432748610	384	Economy	16300.00
0005432748628	384	Economy	16300.00
0005432748619	384	Economy	16300.00
0005432891329	384	Economy	16300.00
0005432891363	384	Economy	16300.00
0005435154698	384	Economy	14800.00
0005432220123	384	Economy	14800.00
0005435154696	384	Economy	14800.00
0005432748631	384	Economy	14800.00
0005432220124	384	Economy	14800.00
0005432748634	384	Economy	14800.00
0005432891336	384	Economy	14800.00
0005435627131	384	Economy	14800.00
0005432891412	384	Economy	14800.00
0005433293373	384	Economy	14800.00
0005432748627	384	Economy	14800.00
0005432748620	384	Economy	14800.00
0005432220125	384	Economy	14800.00
0005432748609	384	Economy	14800.00
0005432751619	384	Economy	14800.00
0005432891328	384	Economy	14800.00
0005433293384	384	Economy	14800.00
0005432891367	384	Economy	14800.00
0005433293354	384	Economy	14800.00
0005432891447	384	Economy	14800.00
0005432748618	384	Economy	14800.00
0005432749844	384	Economy	14800.00
0005432891398	384	Economy	14800.00
0005432891482	384	Economy	14800.00
0005432748635	384	Economy	14800.00
0005432748629	384	Economy	14800.00
0005432891332	384	Economy	14800.00
0005432891430	384	Economy	14800.00
0005432748633	384	Economy	14800.00
0005435627132	384	Economy	14800.00
0005435154697	384	Economy	14800.00
0005433293375	384	Economy	14800.00
0005432748615	384	Economy	14800.00
0005432748630	384	Economy	14800.00
0005432753393	384	Economy	14800.00
0005432891338	384	Economy	14800.00
0005432891355	384	Economy	14800.00
0005432751618	384	Economy	14800.00
0005435154699	384	Economy	14800.00
0005432748625	384	Economy	14800.00
0005435154694	384	Economy	14800.00
0005432748624	384	Economy	14800.00
0005432891368	384	Economy	14800.00
0005432749845	384	Economy	14800.00
0005432751620	384	Economy	14800.00
0005435154691	384	Economy	14800.00
0005433875412	384	Economy	14800.00
0005432891461	384	Economy	14800.00
0005432748611	384	Economy	14800.00
0005432891456	384	Economy	14800.00
0005432891337	384	Economy	14800.00
0005432891454	384	Economy	14800.00
0005432751621	384	Economy	14800.00
0005432891415	384	Economy	14800.00
0005432748623	384	Economy	14800.00
0005432748396	12070	Business	44500.00
0005433293421	12070	Business	44500.00
0005432748376	12070	Business	44500.00
0005434152868	12070	Business	44500.00
0005432748395	12070	Business	44500.00
0005432748272	12070	Business	44500.00
0005432748394	12070	Business	44500.00
0005433293420	12070	Business	44500.00
0005432748304	12070	Business	44500.00
0005432891561	12070	Economy	14800.00
0005433875428	12070	Economy	14800.00
0005432748539	12070	Economy	14800.00
0005433293426	12070	Economy	14800.00
0005432214866	12070	Economy	14800.00
0005432748553	12070	Economy	14800.00
0005432756902	12070	Economy	14800.00
0005432756912	12070	Economy	14800.00
0005432891564	12070	Economy	14800.00
0005432748404	12070	Economy	16300.00
0005432748526	12070	Economy	16300.00
0005432891568	12070	Economy	16300.00
0005432748332	12070	Economy	16300.00
0005433293422	12070	Economy	16300.00
0005432214865	12070	Economy	14800.00
0005432748449	12070	Economy	14800.00
0005432748296	12070	Economy	14800.00
0005432748543	12070	Economy	14800.00
0005435154625	12070	Economy	14800.00
0005432748401	12070	Economy	14800.00
0005432748295	12070	Economy	14800.00
0005433293425	12070	Economy	14800.00
0005435154627	12070	Economy	14800.00
0005435154628	12070	Economy	14800.00
0005432748347	12070	Economy	14800.00
0005432891570	12070	Economy	14800.00
0005432748350	12070	Economy	14800.00
0005432748377	12070	Economy	14800.00
0005433875427	12070	Economy	14800.00
0005435154630	12070	Economy	14800.00
0005432891571	12070	Economy	14800.00
0005432748378	12070	Economy	14800.00
0005432748436	12070	Economy	14800.00
0005432891563	12070	Economy	14800.00
0005432749839	12070	Economy	14800.00
0005432748398	12070	Economy	14800.00
0005433293429	12070	Economy	14800.00
0005432748555	12070	Economy	14800.00
0005432756916	12070	Economy	14800.00
0005432748414	12070	Economy	14800.00
0005434152867	12070	Economy	14800.00
0005432748243	12070	Economy	14800.00
0005432748392	12070	Economy	14800.00
0005432891566	12070	Economy	14800.00
0005432748540	12070	Economy	14800.00
0005432748544	12070	Economy	14800.00
0005433293424	12070	Economy	14800.00
0005432748554	12070	Economy	14800.00
0005432748393	12070	Economy	14800.00
0005432748424	12070	Economy	14800.00
0005433293427	12070	Economy	14800.00
0005432748451	12070	Economy	14800.00
0005432753367	12070	Economy	14800.00
0005432756895	12070	Economy	14800.00
0005432891562	12070	Economy	14800.00
0005432748399	12070	Economy	14800.00
0005432891569	12070	Economy	14800.00
0005432748335	12070	Economy	14800.00
0005432749833	12070	Economy	14800.00
0005432748403	12070	Economy	14800.00
0005433293423	12070	Economy	14800.00
0005432748538	12070	Economy	14800.00
0005432748242	12070	Economy	14800.00
0005433293431	12070	Economy	14800.00
0005432749830	12070	Economy	14800.00
0005433293419	12070	Economy	14800.00
0005432891565	12070	Economy	14800.00
0005432748397	12070	Economy	14800.00
0005435154623	12070	Economy	14800.00
0005432748351	12070	Economy	14800.00
0005432748400	12070	Economy	14800.00
0005432748250	12070	Economy	14800.00
0005432749831	12070	Economy	14800.00
0005432891567	12070	Economy	14800.00
0005432748432	12070	Economy	14800.00
0005433293428	12070	Economy	14800.00
0005435154626	12070	Economy	14800.00
0005432891560	12070	Economy	14800.00
0005432748402	12070	Economy	14800.00
0005433293430	12070	Economy	14800.00
0005432748311	12070	Economy	14800.00
0005433533415	18977	Economy	28200.00
0005433531399	18977	Economy	28200.00
0005432928093	18977	Economy	25700.00
0005433533411	18977	Economy	25700.00
0005433525339	18977	Economy	25700.00
0005433525335	18977	Economy	25700.00
0005433533414	18977	Economy	25700.00
0005433533412	18977	Economy	25700.00
0005433525342	18977	Economy	25700.00
0005433525341	18977	Economy	25700.00
0005433531400	18977	Economy	25700.00
0005433525337	18977	Economy	25700.00
0005433525340	18977	Economy	25700.00
0005433525336	18977	Economy	25700.00
0005433525338	18977	Economy	25700.00
0005432928109	18977	Economy	25700.00
0005432928108	18977	Economy	25700.00
0005433533413	18977	Economy	25700.00
0005433527325	32472	Economy	28200.00
0005432928137	32472	Economy	28200.00
0005433525252	32472	Economy	28200.00
0005433525243	32472	Economy	28200.00
0005432928138	32472	Economy	25700.00
0005433531384	32472	Economy	25700.00
0005432928139	32472	Economy	25700.00
0005433525304	32472	Economy	25700.00
0005433527347	32472	Economy	25700.00
0005433531380	32472	Economy	25700.00
0005433525268	32472	Economy	25700.00
0005433525226	32472	Economy	25700.00
0005433531360	32472	Economy	25700.00
0005433525305	32472	Economy	25700.00
0005433525276	32472	Economy	25700.00
0005433525242	32472	Economy	25700.00
0005433527334	32472	Economy	25700.00
0005433531362	32472	Economy	25700.00
0005433525269	32472	Economy	25700.00
0005433527348	32472	Economy	25700.00
0005433525236	32472	Economy	25700.00
0005433525263	32472	Economy	25700.00
0005433525264	32472	Economy	25700.00
0005432928136	32472	Economy	25700.00
0005433525275	32472	Economy	25700.00
0005433531361	32472	Economy	25700.00
0005433525262	32472	Economy	25700.00
0005433525312	32472	Economy	25700.00
0005433525273	32472	Economy	25700.00
0005432928140	32472	Economy	25700.00
0005433525237	32472	Economy	25700.00
0005433525225	32472	Economy	25700.00
0005434831279	5256	Business	84000.00
0005434827089	5256	Business	84000.00
0005435661982	5256	Business	84000.00
0005434827115	5256	Business	84000.00
0005432121735	5256	Business	84000.00
0005435374588	5256	Business	84000.00
0005435735204	5256	Business	84000.00
0005435374146	5256	Business	84000.00
0005434558546	5256	Business	84000.00
0005435661992	5256	Business	84000.00
0005434827126	5256	Business	84000.00
0005432121732	5256	Business	84000.00
0005435374671	5256	Business	84000.00
0005432396352	5256	Comfort	47600.00
0005434827124	5256	Comfort	47600.00
0005435314956	5256	Comfort	47600.00
0005434827130	5256	Comfort	47600.00
0005435374253	5256	Comfort	47600.00
0005434827132	5256	Comfort	47600.00
0005434827143	5256	Comfort	47600.00
0005435386690	5256	Comfort	47600.00
0005434827118	5256	Comfort	47600.00
0005434558535	5256	Comfort	47600.00
0005435374649	5256	Comfort	47600.00
0005435374261	5256	Comfort	47600.00
0005435386714	5256	Comfort	47600.00
0005435374373	5256	Comfort	47600.00
0005434558539	5256	Comfort	47600.00
0005435374279	5256	Comfort	47600.00
0005434827110	5256	Comfort	47600.00
0005435374806	5256	Comfort	47600.00
0005434827074	5256	Comfort	47600.00
0005434558551	5256	Comfort	47600.00
0005434827105	5256	Comfort	47600.00
0005434558553	5256	Comfort	47600.00
0005434827142	5256	Comfort	47600.00
0005434827121	5256	Comfort	47600.00
0005434827131	5256	Comfort	47600.00
0005435374309	5256	Comfort	47600.00
0005435374436	5256	Comfort	47600.00
0005435374252	5256	Economy	28000.00
0005434827116	5256	Comfort	47600.00
0005434558547	5256	Economy	28000.00
0005434827119	5256	Economy	28000.00
0005432396353	5256	Economy	28000.00
0005434827125	5256	Economy	28000.00
0005435386679	5256	Economy	28000.00
0005435374547	5256	Economy	28000.00
0005434558541	5256	Economy	28000.00
0005435374682	5256	Economy	28000.00
0005435150426	5256	Economy	28000.00
0005434558531	5256	Economy	28000.00
0005435150414	5256	Economy	28000.00
0005435374166	5256	Economy	28000.00
0005434827144	5256	Economy	28000.00
0005434827083	5256	Economy	28000.00
0005434558527	5256	Economy	28000.00
0005434827076	5256	Economy	28000.00
0005435150415	5256	Economy	28000.00
0005434558532	5256	Economy	28000.00
0005435374790	5256	Economy	28000.00
0005434827095	5256	Economy	28000.00
0005435150425	5256	Economy	28000.00
0005434827090	5256	Economy	28000.00
0005435735230	5256	Economy	28000.00
0005435374179	5256	Economy	28000.00
0005434828772	5256	Economy	28000.00
0005434827087	5256	Economy	28000.00
0005434827094	5256	Economy	28000.00
0005435374469	5256	Economy	28000.00
0005434827086	5256	Economy	28000.00
0005435374388	5256	Economy	28000.00
0005435735213	5256	Economy	28000.00
0005434827103	5256	Economy	28000.00
0005435150419	5256	Economy	28000.00
0005435661988	5256	Economy	28000.00
0005434558549	5256	Economy	28000.00
0005434827112	5256	Economy	28000.00
0005434558533	5256	Economy	30800.00
0005435374700	5256	Economy	28000.00
0005434558542	5256	Economy	28000.00
0005435374526	5256	Economy	30800.00
0005434827123	5256	Economy	28000.00
0005435314983	5256	Economy	30800.00
0005434827085	5256	Economy	28000.00
0005434827129	5256	Economy	28000.00
0005435314953	5256	Economy	28000.00
0005435374387	5256	Economy	28000.00
0005435735231	5256	Economy	28000.00
0005432121736	5256	Economy	28000.00
0005434827135	5256	Economy	28000.00
0005435314960	5256	Economy	28000.00
0005435374636	5256	Economy	28000.00
0005435150423	5256	Economy	28000.00
0005435150421	5256	Economy	28000.00
0005434827102	5256	Economy	28000.00
0005434558529	5256	Economy	28000.00
0005435374668	5256	Economy	28000.00
0005435374704	5256	Economy	28000.00
0005435374452	5256	Economy	28000.00
0005434827070	5256	Economy	28000.00
0005434827088	5256	Economy	28000.00
0005435150416	5256	Economy	28000.00
0005435374263	5256	Economy	28000.00
0005434558548	5256	Economy	28000.00
0005434665022	5256	Economy	28000.00
0005435374868	5256	Economy	28000.00
0005434827099	5256	Economy	28000.00
0005432823481	5256	Economy	28000.00
0005435661993	5256	Economy	28000.00
0005434827091	5256	Economy	28000.00
0005434827075	5256	Economy	28000.00
0005434558543	5256	Economy	28000.00
0005434827114	5256	Economy	28000.00
0005434827140	5256	Economy	28000.00
0005435374467	5256	Economy	28000.00
0005435179704	5256	Economy	28000.00
0005432121738	5256	Economy	28000.00
0005435374625	5256	Economy	28000.00
0005434558537	5256	Economy	28000.00
0005434827107	5256	Economy	28000.00
0005434827100	5256	Economy	28000.00
0005435374338	5256	Economy	28000.00
0005434827139	5256	Economy	28000.00
0005432121725	5256	Economy	28000.00
0005435374445	5256	Economy	28000.00
0005432121730	5256	Economy	28000.00
0005434827120	5256	Economy	28000.00
0005434827108	5256	Economy	28000.00
0005434827134	5256	Economy	28000.00
0005434827122	5256	Economy	28000.00
0005434827101	5256	Economy	28000.00
0005435304245	5256	Economy	28000.00
0005434831278	5256	Economy	28000.00
0005435374578	5256	Economy	28000.00
0005434827080	5256	Economy	28000.00
0005434827077	5256	Economy	28000.00
0005435661987	5256	Economy	28000.00
0005435299856	5256	Economy	28000.00
0005434827137	5256	Economy	28000.00
0005435386715	5256	Economy	28000.00
0005434558545	5256	Economy	28000.00
0005435374374	5256	Economy	28000.00
0005434827128	5256	Economy	28000.00
0005435374623	5256	Economy	28000.00
0005434827111	5256	Economy	28000.00
0005434827078	5256	Economy	28000.00
0005434828771	5256	Economy	28000.00
0005435735212	5256	Economy	28000.00
0005434827096	5256	Economy	28000.00
0005434831282	5256	Economy	28000.00
0005435150417	5256	Economy	28000.00
0005434827071	5256	Economy	28000.00
0005434827127	5256	Economy	28000.00
0005432121728	5256	Economy	28000.00
0005435374280	5256	Economy	30800.00
0005432121733	5256	Economy	30800.00
0005435314974	5256	Economy	30800.00
0005432121734	5256	Economy	30800.00
0005434827082	5256	Economy	28000.00
0005435374672	5256	Economy	28000.00
0005434827136	5256	Economy	28000.00
0005435314957	5256	Economy	28000.00
0005434827098	5256	Economy	28000.00
0005432121727	5256	Economy	28000.00
0005435314982	5256	Economy	28000.00
0005435374375	5256	Economy	28000.00
0005434558536	5256	Economy	28000.00
0005435735226	5256	Economy	28000.00
0005435661985	5256	Economy	28000.00
0005434827093	5256	Economy	28000.00
0005435374555	5256	Economy	28000.00
0005435374641	5256	Economy	28000.00
0005435374626	5256	Economy	28000.00
0005435374579	5256	Economy	28000.00
0005435374814	5256	Economy	28000.00
0005435374548	5256	Economy	28000.00
0005434827113	5256	Economy	28000.00
0005434827109	5256	Economy	28000.00
0005434827072	5256	Economy	28000.00
0005435735198	5256	Economy	28000.00
0005434827117	5256	Economy	28000.00
0005435374869	5256	Economy	28000.00
0005434831280	5256	Economy	28000.00
0005434558534	5256	Economy	28000.00
0005435374703	5256	Economy	28000.00
0005435314969	5256	Economy	28000.00
0005435374468	5256	Economy	28000.00
0005434558550	5256	Economy	28000.00
0005434827104	5256	Economy	28000.00
0005435374685	5256	Economy	28000.00
0005435374565	5256	Economy	28000.00
0005434558552	5256	Economy	28000.00
0005434827133	5256	Economy	28000.00
0005434558540	5256	Economy	28000.00
0005435661983	5256	Economy	28000.00
0005435150422	5256	Economy	28000.00
0005434827145	5256	Economy	28000.00
0005435150418	5256	Economy	28000.00
0005435374624	5256	Economy	28000.00
0005432121737	5256	Economy	28000.00
0005434827081	5256	Economy	28000.00
0005434827092	5256	Economy	28000.00
0005432121729	5256	Economy	28000.00
0005435374437	5256	Economy	28000.00
0005434827106	5256	Economy	28000.00
0005435374453	5256	Economy	28000.00
0005434558538	5256	Economy	28000.00
0005435374699	5256	Economy	28000.00
0005435374745	5256	Economy	28000.00
0005435374813	5256	Economy	28000.00
0005435735225	5256	Economy	28000.00
0005434558530	5256	Economy	28000.00
0005435150424	5256	Economy	28000.00
0005434558528	5256	Economy	28000.00
0005434558544	5256	Economy	28000.00
0005435386680	5256	Economy	28000.00
0005434831281	5256	Economy	28000.00
0005432823485	5256	Economy	28000.00
0005434827097	5256	Economy	28000.00
0005434827141	5256	Economy	28000.00
0005435314966	5256	Economy	28000.00
0005434827073	5256	Economy	28000.00
0005435150420	5256	Economy	28000.00
0005432121726	5256	Economy	28000.00
0005434827084	5256	Economy	28000.00
0005434827079	5256	Economy	28000.00
0005434827138	5256	Economy	28000.00
0005435374696	5256	Economy	28000.00
0005432121731	5256	Economy	28000.00
0005435374446	5256	Economy	28000.00
0005435150267	9928	Business	84000.00
0005432203267	9928	Business	84000.00
0005435375086	9928	Business	84000.00
0005434826272	9928	Business	84000.00
0005435375085	9928	Business	84000.00
0005435150286	9928	Business	84000.00
0005435386751	9928	Business	84000.00
0005434826151	9928	Business	84000.00
0005435735273	9928	Business	84000.00
0005434825695	9928	Business	84000.00
0005434826145	9928	Business	84000.00
0005435179426	9928	Business	84000.00
0005434826504	9928	Business	84000.00
0005434826300	9928	Business	84000.00
0005434828739	9928	Business	84000.00
0005435375084	9928	Business	84000.00
0005434826144	9928	Comfort	47600.00
0005434826295	9928	Business	84000.00
0005434825491	9928	Comfort	47600.00
0005434826084	9928	Comfort	47600.00
0005435315098	9928	Comfort	47600.00
0005435375070	9928	Comfort	47600.00
0005434831228	9928	Comfort	47600.00
0005434826093	9928	Comfort	47600.00
0005434825780	9928	Comfort	47600.00
0005435375103	9928	Comfort	47600.00
0005435375079	9928	Comfort	47600.00
0005434826227	9928	Comfort	47600.00
0005434831242	9928	Comfort	47600.00
0005435375096	9928	Comfort	47600.00
0005435315102	9928	Comfort	47600.00
0005434825008	9928	Comfort	47600.00
0005434826171	9928	Comfort	47600.00
0005435302331	9928	Comfort	47600.00
0005435375098	9928	Comfort	47600.00
0005434826118	9928	Comfort	47600.00
0005434825996	9928	Comfort	47600.00
0005434558432	9928	Comfort	47600.00
0005435375069	9928	Comfort	47600.00
0005435375099	9928	Comfort	47600.00
0005435386747	9928	Comfort	47600.00
0005434826200	9928	Comfort	47600.00
0005435375074	9928	Comfort	47600.00
0005434825787	9928	Comfort	47600.00
0005434826110	9928	Comfort	47600.00
0005434825997	9928	Comfort	47600.00
0005434825928	9928	Comfort	47600.00
0005434826399	9928	Economy	28000.00
0005432396320	9928	Economy	28000.00
0005434825987	9928	Economy	28000.00
0005434826000	9928	Economy	28000.00
0005432396332	9928	Economy	28000.00
0005434826183	9928	Economy	28000.00
0005434825975	9928	Economy	28000.00
0005435375066	9928	Economy	28000.00
0005434825854	9928	Economy	28000.00
0005435150310	9928	Economy	28000.00
0005435315100	9928	Economy	28000.00
0005435150309	9928	Economy	28000.00
0005434826347	9928	Economy	28000.00
0005434831234	9928	Economy	28000.00
0005435375090	9928	Economy	28000.00
0005434826439	9928	Economy	28000.00
0005434825713	9928	Economy	28000.00
0005434825340	9928	Economy	28000.00
0005435375075	9928	Economy	28000.00
0005434828740	9928	Economy	28000.00
0005435375102	9928	Economy	28000.00
0005434825860	9928	Economy	28000.00
0005435375068	9928	Economy	28000.00
0005432400183	9928	Economy	28000.00
0005435150307	9928	Economy	28000.00
0005435375095	9928	Economy	28000.00
0005432203266	9928	Economy	28000.00
0005434826082	9928	Economy	28000.00
0005434826104	9928	Economy	28000.00
0005434826464	9928	Economy	28000.00
0005434826204	9928	Economy	28000.00
0005435315106	9928	Economy	28000.00
0005435315110	9928	Economy	28000.00
0005434826229	9928	Economy	28000.00
0005435386749	9928	Economy	28000.00
0005434826299	9928	Economy	28000.00
0005435150349	9928	Economy	28000.00
0005432203269	9928	Economy	28000.00
0005434825936	9928	Economy	28000.00
0005435375093	9928	Economy	30800.00
0005434825712	9928	Economy	28000.00
0005434825853	9928	Economy	28000.00
0005434826263	9928	Economy	28000.00
0005435179717	9928	Economy	30800.00
0005434826128	9928	Economy	28000.00
0005435375094	9928	Economy	30800.00
0005434825887	9928	Economy	28000.00
0005432400189	9928	Economy	28000.00
0005434826391	9928	Economy	28000.00
0005434826366	9928	Economy	28000.00
0005435315107	9928	Economy	28000.00
0005435315103	9928	Economy	28000.00
0005434826368	9928	Economy	28000.00
0005434826598	9928	Economy	28000.00
0005434826595	9928	Economy	28000.00
0005434825715	9928	Economy	28000.00
0005434826514	9928	Economy	28000.00
0005434826513	9928	Economy	28000.00
0005435375076	9928	Economy	28000.00
0005434665000	9928	Economy	28000.00
0005434826129	9928	Economy	28000.00
0005434826597	9928	Economy	28000.00
0005434826119	9928	Economy	28000.00
0005434826018	9928	Economy	28000.00
0005435375087	9928	Economy	28000.00
0005434828751	9928	Economy	28000.00
0005434826112	9928	Economy	28000.00
0005434826193	9928	Economy	28000.00
0005434825976	9928	Economy	28000.00
0005435375072	9928	Economy	28000.00
0005435150344	9928	Economy	28000.00
0005434825896	9928	Economy	28000.00
0005434664999	9928	Economy	28000.00
0005435150299	9928	Economy	28000.00
0005434825826	9928	Economy	28000.00
0005434826117	9928	Economy	28000.00
0005435375100	9928	Economy	28000.00
0005435375089	9928	Economy	28000.00
0005434831235	9928	Economy	28000.00
0005434826147	9928	Economy	28000.00
0005434558433	9928	Economy	28000.00
0005434826001	9928	Economy	28000.00
0005432396333	9928	Economy	28000.00
0005434826294	9928	Economy	28000.00
0005435735270	9928	Economy	28000.00
0005435375082	9928	Economy	28000.00
0005435375080	9928	Economy	28000.00
0005434826228	9928	Economy	28000.00
0005434825897	9928	Economy	28000.00
0005434826431	9928	Economy	28000.00
0005435375081	9928	Economy	28000.00
0005434826075	9928	Economy	28000.00
0005435375101	9928	Economy	28000.00
0005432400198	9928	Economy	28000.00
0005434826094	9928	Economy	28000.00
0005434826095	9928	Economy	28000.00
0005435386750	9928	Economy	28000.00
0005435735269	9928	Economy	28000.00
0005434825929	9928	Economy	28000.00
0005434825922	9928	Economy	28000.00
0005434826152	9928	Economy	28000.00
0005435302332	9928	Economy	28000.00
0005435375077	9928	Economy	28000.00
0005434825779	9928	Economy	28000.00
0005434825912	9928	Economy	28000.00
0005434826059	9928	Economy	28000.00
0005435735272	9928	Economy	28000.00
0005435375083	9928	Economy	28000.00
0005434826373	9928	Economy	28000.00
0005434825885	9928	Economy	28000.00
0005434826437	9928	Economy	28000.00
0005435179427	9928	Economy	28000.00
0005434831227	9928	Economy	30800.00
0005435375078	9928	Economy	28000.00
0005435150280	9928	Economy	30800.00
0005434826205	9928	Economy	30800.00
0005435179718	9928	Economy	28000.00
0005434826186	9928	Economy	28000.00
0005435150270	9928	Economy	28000.00
0005434826244	9928	Economy	28000.00
0005434825945	9928	Economy	28000.00
0005434826286	9928	Economy	28000.00
0005435179425	9928	Economy	28000.00
0005434826201	9928	Economy	28000.00
0005435386752	9928	Economy	28000.00
0005434831258	9928	Economy	28000.00
0005434825927	9928	Economy	28000.00
0005434826063	9928	Economy	28000.00
0005434828760	9928	Economy	28000.00
0005435375071	9928	Economy	28000.00
0005435315099	9928	Economy	28000.00
0005435302334	9928	Economy	28000.00
0005435150276	9928	Economy	28000.00
0005434825356	9928	Economy	28000.00
0005434826185	9928	Economy	28000.00
0005434826120	9928	Economy	28000.00
0005435735271	9928	Economy	28000.00
0005435315108	9928	Economy	28000.00
0005435302333	9928	Economy	28000.00
0005435315105	9928	Economy	28000.00
0005434831249	9928	Economy	28000.00
0005434826438	9928	Economy	28000.00
0005435375091	9928	Economy	28000.00
0005434828759	9928	Economy	28000.00
0005435315101	9928	Economy	28000.00
0005434825714	9928	Economy	28000.00
0005435315104	9928	Economy	28000.00
0005435375097	9928	Economy	28000.00
0005434825417	9928	Economy	28000.00
0005435302330	9928	Economy	28000.00
0005434826596	9928	Economy	28000.00
0005435150269	9928	Economy	28000.00
0005434826268	9928	Economy	28000.00
0005434826062	9928	Economy	28000.00
0005435375073	9928	Economy	28000.00
0005435375092	9928	Economy	28000.00
0005434826083	9928	Economy	28000.00
0005435386748	9928	Economy	28000.00
0005434826369	9928	Economy	28000.00
0005434825895	9928	Economy	28000.00
0005434826096	9928	Economy	28000.00
0005434825935	9928	Economy	28000.00
0005434826656	9928	Economy	28000.00
0005434826043	9928	Economy	28000.00
0005432400197	9928	Economy	28000.00
0005434826041	9928	Economy	28000.00
0005435299911	9928	Economy	28000.00
0005434826019	9928	Economy	28000.00
0005434826107	9928	Economy	28000.00
0005434826441	9928	Economy	28000.00
0005434831259	9928	Economy	28000.00
0005434826103	9928	Economy	28000.00
0005435375067	9928	Economy	28000.00
0005432203268	9928	Economy	28000.00
0005434826362	9928	Economy	28000.00
0005435299912	9928	Economy	28000.00
0005434826374	9928	Economy	28000.00
0005435375088	9928	Economy	28000.00
0005434826140	9928	Economy	28000.00
0005434825859	9928	Economy	28000.00
0005434828741	9928	Economy	28000.00
0005435315109	9928	Economy	28000.00
0005435083017	6998	Economy	8200.00
0005435083023	6998	Economy	7400.00
0005435083016	6998	Economy	7400.00
0005435790387	6998	Economy	7400.00
0005435083018	6998	Economy	7400.00
0005435790389	6998	Economy	7400.00
0005435790388	6998	Economy	7400.00
0005435083022	6998	Economy	7400.00
0005435083019	6998	Economy	7400.00
0005435083020	6998	Economy	7400.00
0005435083021	6998	Economy	7400.00
0005435083024	6998	Economy	7400.00
0005435082933	25975	Economy	7400.00
0005435082956	25975	Economy	7400.00
0005435082899	25975	Economy	7400.00
0005435082951	25975	Economy	7400.00
0005435790367	25975	Economy	7400.00
0005435082898	25975	Economy	7400.00
0005435082946	25975	Economy	7400.00
0005435082930	25975	Economy	7400.00
0005434757606	9525	Business	32800.00
0005434215348	9525	Business	32800.00
0005434757611	9525	Business	32800.00
0005434757614	9525	Business	32800.00
0005434215309	9525	Business	32800.00
0005434215473	9525	Business	32800.00
0005434215692	9525	Business	32800.00
0005434215543	9525	Business	32800.00
0005434215241	9525	Economy	10900.00
0005434757610	9525	Economy	10900.00
0005434215244	9525	Economy	10900.00
0005434215472	9525	Economy	10900.00
0005434215217	9525	Economy	10900.00
0005434215542	9525	Economy	10900.00
0005434215454	9525	Economy	10900.00
0005434215367	9525	Economy	12000.00
0005434757621	9525	Economy	12000.00
0005434757618	9525	Economy	12000.00
0005434215347	9525	Economy	12000.00
0005434757624	9525	Economy	12000.00
0005434757612	9525	Economy	10900.00
0005434215216	9525	Economy	10900.00
0005434757615	9525	Economy	10900.00
0005434215215	9525	Economy	10900.00
0005434215242	9525	Economy	10900.00
0005434215636	9525	Economy	10900.00
0005434757623	9525	Economy	10900.00
0005434757609	9525	Economy	10900.00
0005434215428	9525	Economy	10900.00
0005434757617	9525	Economy	10900.00
0005434215380	9525	Economy	10900.00
0005434215416	9525	Economy	10900.00
0005434215629	9525	Economy	10900.00
0005434757602	9525	Economy	10900.00
0005434757597	9525	Economy	10900.00
0005434215425	9525	Economy	10900.00
0005434757608	9525	Economy	10900.00
0005434215090	9525	Economy	10900.00
0005434757601	9525	Economy	10900.00
0005434215300	9525	Economy	10900.00
0005434757600	9525	Economy	10900.00
0005434757607	9525	Economy	10900.00
0005434215471	9525	Economy	10900.00
0005434757619	9525	Economy	10900.00
0005434757598	9525	Economy	10900.00
0005434215541	9525	Economy	10900.00
0005434215630	9525	Economy	10900.00
0005434757616	9525	Economy	10900.00
0005434757613	9525	Economy	10900.00
0005434215424	9525	Economy	10900.00
0005434215628	9525	Economy	10900.00
0005434215553	9525	Economy	10900.00
0005434215423	9525	Economy	10900.00
0005434757603	9525	Economy	10900.00
0005434215362	9525	Economy	10900.00
0005434215421	9525	Economy	10900.00
0005434757620	9525	Economy	10900.00
0005434215496	9525	Economy	10900.00
0005434215470	9525	Economy	10900.00
0005434757604	9525	Economy	10900.00
0005434215275	9525	Economy	10900.00
0005434757596	9525	Economy	10900.00
0005434215369	9525	Economy	10900.00
0005434757599	9525	Economy	10900.00
0005434757605	9525	Economy	10900.00
0005434215436	9525	Economy	10900.00
0005434215516	9525	Economy	10900.00
0005434215240	9525	Economy	10900.00
0005434757622	9525	Economy	10900.00
0005434215531	9525	Economy	10900.00
0005434215544	9525	Economy	10900.00
0005434215596	9525	Economy	10900.00
0005434757188	28641	Business	32800.00
0005434756992	28641	Business	32800.00
0005434215802	28641	Business	32800.00
0005434756979	28641	Business	32800.00
0005434215777	28641	Business	32800.00
0005434215804	28641	Business	32800.00
0005434757098	28641	Business	32800.00
0005434757328	28641	Business	32800.00
0005434757201	28641	Business	32800.00
0005434757046	28641	Economy	10900.00
0005434215801	28641	Economy	10900.00
0005434757187	28641	Economy	10900.00
0005434757260	28641	Economy	10900.00
0005434757198	28641	Economy	10900.00
0005434215787	28641	Economy	10900.00
0005434215796	28641	Economy	12000.00
0005434757189	28641	Economy	12000.00
0005434756993	28641	Economy	12000.00
0005434215784	28641	Economy	12000.00
0005434215808	28641	Economy	10900.00
0005434215799	28641	Economy	10900.00
0005434215783	28641	Economy	10900.00
0005434215785	28641	Economy	10900.00
0005434757231	28641	Economy	10900.00
0005434757243	28641	Economy	10900.00
0005434215792	28641	Economy	10900.00
0005434757196	28641	Economy	10900.00
0005434757271	28641	Economy	10900.00
0005434757200	28641	Economy	10900.00
0005434757174	28641	Economy	10900.00
0005434215780	28641	Economy	10900.00
0005434215812	28641	Economy	10900.00
0005434757047	28641	Economy	10900.00
0005434757175	28641	Economy	10900.00
0005434215779	28641	Economy	10900.00
0005434215788	28641	Economy	10900.00
0005434757142	28641	Economy	10900.00
0005434757408	28641	Economy	10900.00
0005434757164	28641	Economy	10900.00
0005434215797	28641	Economy	10900.00
0005434215811	28641	Economy	10900.00
0005434215776	28641	Economy	10900.00
0005434757312	28641	Economy	10900.00
0005434215806	28641	Economy	10900.00
0005434215800	28641	Economy	10900.00
0005434757327	28641	Economy	10900.00
0005434757428	28641	Economy	10900.00
0005434215805	28641	Economy	10900.00
0005434215793	28641	Economy	10900.00
0005434215789	28641	Economy	10900.00
0005434215798	28641	Economy	10900.00
0005434757249	28641	Economy	10900.00
0005434215782	28641	Economy	10900.00
0005434215809	28641	Economy	10900.00
0005434757079	28641	Economy	10900.00
0005434215790	28641	Economy	10900.00
0005434215794	28641	Economy	10900.00
0005434757261	28641	Economy	10900.00
0005434757143	28641	Economy	10900.00
0005434757233	28641	Economy	10900.00
0005434215810	28641	Economy	10900.00
0005434215786	28641	Economy	10900.00
0005434215781	28641	Economy	10900.00
0005434757230	28641	Economy	10900.00
0005434215791	28641	Economy	10900.00
0005434757290	28641	Economy	10900.00
0005434757210	28641	Economy	10900.00
0005434757361	28641	Economy	10900.00
0005434215807	28641	Economy	10900.00
0005434757080	28641	Economy	10900.00
0005434215778	28641	Economy	10900.00
0005434215775	28641	Economy	10900.00
0005434757209	28641	Economy	10900.00
0005434757139	28641	Economy	10900.00
0005434215795	28641	Economy	10900.00
0005434757234	28641	Economy	10900.00
0005434757199	28641	Economy	10900.00
0005434757190	28641	Economy	10900.00
0005434757148	28641	Economy	10900.00
0005434215803	28641	Economy	10900.00
0005435100205	10847	Economy	9800.00
0005435100206	10847	Economy	8900.00
0005435100182	31836	Economy	9800.00
0005435100181	31836	Economy	8900.00
0005434760266	31836	Economy	8900.00
0005435100184	31836	Economy	8900.00
0005435100197	31836	Economy	8900.00
0005435100198	31836	Economy	8900.00
0005434640050	1985	Economy	20900.00
0005434640058	1985	Economy	20900.00
0005433202625	1985	Economy	19000.00
0005434640064	1985	Economy	19000.00
0005433202627	1985	Economy	19000.00
0005432290721	1985	Economy	19000.00
0005434640057	1985	Economy	19000.00
0005434640059	1985	Economy	19000.00
0005434640051	1985	Economy	19000.00
0005434640062	1985	Economy	19000.00
0005434640049	1985	Economy	19000.00
0005434640066	1985	Economy	19000.00
0005434640055	1985	Economy	19000.00
0005434640056	1985	Economy	19000.00
0005434640053	1985	Economy	19000.00
0005432290720	1985	Economy	19000.00
0005433202626	1985	Economy	19000.00
0005434640063	1985	Economy	19000.00
0005433202628	1985	Economy	19000.00
0005434640054	1985	Economy	19000.00
0005434640067	1985	Economy	19000.00
0005433202617	1985	Economy	19000.00
0005434640052	1985	Economy	19000.00
0005433202682	1985	Economy	19000.00
0005434640061	1985	Economy	19000.00
0005433202687	1985	Economy	19000.00
0005434640060	1985	Economy	19000.00
0005434640065	1985	Economy	19000.00
0005433202638	1985	Economy	19000.00
0005434639734	23269	Economy	20900.00
0005433202759	23269	Economy	20900.00
0005434639876	23269	Economy	20900.00
0005433202770	23269	Economy	20900.00
0005434639835	23269	Economy	19000.00
0005434639847	23269	Economy	19000.00
0005435948352	23269	Economy	19000.00
0005433202765	23269	Economy	19000.00
0005434639942	23269	Economy	19000.00
0005433202768	23269	Economy	19000.00
0005433202766	23269	Economy	19000.00
0005434639941	23269	Economy	19000.00
0005434639852	23269	Economy	19000.00
0005433202763	23269	Economy	19000.00
0005434639751	23269	Economy	19000.00
0005435948342	23269	Economy	19000.00
0005434639711	23269	Economy	19000.00
0005433202762	23269	Economy	19000.00
0005434639803	23269	Economy	19000.00
0005434639914	23269	Economy	19000.00
0005434639795	23269	Economy	19000.00
0005434639750	23269	Economy	19000.00
0005434639848	23269	Economy	19000.00
0005434639915	23269	Economy	19000.00
0005433202767	23269	Economy	19000.00
0005434639749	23269	Economy	19000.00
0005435948353	23269	Economy	19000.00
0005434639865	23269	Economy	19000.00
0005433202760	23269	Economy	19000.00
0005434639840	23269	Economy	19000.00
0005434639748	23269	Economy	19000.00
0005434639664	23269	Economy	19000.00
0005433202761	23269	Economy	19000.00
0005434639926	23269	Economy	19000.00
0005433202764	23269	Economy	19000.00
0005434639864	23269	Economy	19000.00
0005434639851	23269	Economy	19000.00
0005435948350	23269	Economy	19000.00
0005434639704	23269	Economy	19000.00
0005434639665	23269	Economy	19000.00
0005434639850	23269	Economy	19000.00
0005435948349	23269	Economy	19000.00
0005434639710	23269	Economy	19000.00
0005434639729	23269	Economy	19000.00
0005434639800	23269	Economy	19000.00
0005433202769	23269	Economy	19000.00
0005434639849	23269	Economy	19000.00
0005434639912	23269	Economy	19000.00
0005432111365	6063	Business	69700.00
0005433533416	6063	Business	69700.00
0005435327027	6063	Business	69700.00
0005434601552	6063	Business	69700.00
0005435327037	6063	Economy	23200.00
0005435327057	6063	Economy	23200.00
0005435327044	6063	Economy	23200.00
0005435327023	6063	Economy	25600.00
0005434601554	6063	Economy	25600.00
0005435327006	6063	Economy	23200.00
0005435327022	6063	Economy	23200.00
0005432111364	6063	Economy	23200.00
0005435326958	6063	Economy	23200.00
0005435326995	6063	Economy	23200.00
0005435327050	6063	Economy	23200.00
0005434601562	6063	Economy	23200.00
0005434601549	6063	Economy	23200.00
0005434601559	6063	Economy	23200.00
0005434601558	6063	Economy	23200.00
0005434601551	6063	Economy	23200.00
0005434601555	6063	Economy	23200.00
0005435327049	6063	Economy	23200.00
0005433531401	6063	Economy	23200.00
0005434601557	6063	Economy	23200.00
0005434601560	6063	Economy	23200.00
0005434601556	6063	Economy	23200.00
0005435327043	6063	Economy	23200.00
0005434601553	6063	Economy	23200.00
0005433533417	6063	Economy	23200.00
0005435326977	6063	Economy	23200.00
0005435326964	6063	Economy	23200.00
0005432111363	6063	Economy	23200.00
0005435327058	6063	Economy	23200.00
0005434601550	6063	Economy	23200.00
0005435326989	6063	Economy	23200.00
0005435327026	6063	Economy	23200.00
0005435326979	6063	Economy	23200.00
0005434601561	6063	Economy	23200.00
0005433531402	6063	Economy	23200.00
0005435327059	6063	Economy	23200.00
0005434601400	18558	Business	69700.00
0005433531348	18558	Business	69700.00
0005433531371	18558	Business	69700.00
0005433527337	18558	Business	69700.00
0005435327126	18558	Business	69700.00
0005434601429	18558	Business	69700.00
0005434601401	18558	Business	69700.00
0005434601373	18558	Business	69700.00
0005434601348	18558	Business	69700.00
0005433531347	18558	Business	69700.00
0005434601364	18558	Economy	23200.00
0005434601467	18558	Economy	23200.00
0005434601355	18558	Economy	23200.00
0005434601386	18558	Economy	23200.00
0005434601341	18558	Economy	25600.00
0005433527331	18558	Economy	23200.00
0005433527330	18558	Economy	23200.00
0005434601349	18558	Economy	23200.00
0005434601313	18558	Economy	23200.00
0005435327128	18558	Economy	23200.00
0005433531359	18558	Economy	23200.00
0005433531363	18558	Economy	23200.00
0005434601353	18558	Economy	23200.00
0005433531376	18558	Economy	23200.00
0005434601225	18558	Economy	23200.00
0005434601381	18558	Economy	23200.00
0005434601342	18558	Economy	23200.00
0005433527315	18558	Economy	23200.00
0005434601372	18558	Economy	23200.00
0005434601343	18558	Economy	23200.00
0005433527333	18558	Economy	23200.00
0005434601466	18558	Economy	23200.00
0005434601187	18558	Economy	23200.00
0005435327127	18558	Economy	23200.00
0005434601354	18558	Economy	23200.00
0005434601186	18558	Economy	23200.00
0005434601185	18558	Economy	23200.00
0005433531365	18558	Economy	23200.00
0005433531372	18558	Economy	23200.00
0005435327125	18558	Economy	23200.00
0005434601380	18558	Economy	23200.00
0005433531366	18558	Economy	23200.00
0005433527346	18558	Economy	23200.00
0005434601465	18558	Economy	23200.00
0005434601312	18558	Economy	23200.00
0005433527329	18558	Economy	23200.00
0005434601258	18558	Economy	23200.00
0005433531364	18558	Economy	23200.00
0005434601395	18558	Economy	23200.00
0005433527332	18558	Economy	23200.00
0005434552742	10626	Business	9100.00
0005434552721	10626	Business	9100.00
0005433181585	10626	Business	9100.00
0005433181501	10626	Business	9100.00
0005434558521	10626	Business	9100.00
0005433181666	10626	Business	9100.00
0005433181719	10626	Business	9100.00
0005433181602	10626	Business	9100.00
0005433181559	10626	Business	9100.00
0005433181667	10626	Business	9100.00
0005434554121	10626	Economy	3000.00
0005434552731	10626	Economy	3000.00
0005434552716	10626	Economy	3000.00
0005434552741	10626	Economy	3000.00
0005433181587	10626	Economy	3000.00
0005434552749	10626	Economy	3000.00
0005434552733	10626	Economy	3000.00
0005434552745	10626	Economy	3000.00
0005433181558	10626	Economy	3000.00
0005434558517	10626	Economy	3000.00
0005434552738	10626	Economy	3300.00
0005434552722	10626	Economy	3300.00
0005434558515	10626	Economy	3300.00
0005433181677	10626	Economy	3300.00
0005434552740	10626	Economy	3300.00
0005434552751	10626	Economy	3000.00
0005433181566	10626	Economy	3000.00
0005434558525	10626	Economy	3000.00
0005434552744	10626	Economy	3000.00
0005434552735	10626	Economy	3000.00
0005434558520	10626	Economy	3000.00
0005433181503	10626	Economy	3000.00
0005434552739	10626	Economy	3000.00
0005433181586	10626	Economy	3000.00
0005434552747	10626	Economy	3000.00
0005433181629	10626	Economy	3000.00
0005433181520	10626	Economy	3000.00
0005433181579	10626	Economy	3000.00
0005433181477	10626	Economy	3000.00
0005434552737	10626	Economy	3000.00
0005434558526	10626	Economy	3000.00
0005433181678	10626	Economy	3000.00
0005434552736	10626	Economy	3000.00
0005433181519	10626	Economy	3000.00
0005434552719	10626	Economy	3000.00
0005434558519	10626	Economy	3000.00
0005434552715	10626	Economy	3000.00
0005434552727	10626	Economy	3000.00
0005434552743	10626	Economy	3000.00
0005433181603	10626	Economy	3000.00
0005434552724	10626	Economy	3000.00
0005434552728	10626	Economy	3000.00
0005434552750	10626	Economy	3000.00
0005434558514	10626	Economy	3000.00
0005433181567	10626	Economy	3000.00
0005434552752	10626	Economy	3000.00
0005434552726	10626	Economy	3000.00
0005433181557	10626	Economy	3000.00
0005434552720	10626	Economy	3000.00
0005434552734	10626	Economy	3000.00
0005434558518	10626	Economy	3000.00
0005433181672	10626	Economy	3000.00
0005433181673	10626	Economy	3000.00
0005433181502	10626	Economy	3000.00
0005434558523	10626	Economy	3000.00
0005434558522	10626	Economy	3000.00
0005433181679	10626	Economy	3000.00
0005434552718	10626	Economy	3000.00
0005434552746	10626	Economy	3000.00
0005434552725	10626	Economy	3000.00
0005433181641	10626	Economy	3000.00
0005433181555	10626	Economy	3000.00
0005434552729	10626	Economy	3000.00
0005434558516	10626	Economy	3000.00
0005434552723	10626	Economy	3000.00
0005434552732	10626	Economy	3000.00
0005434552717	10626	Economy	3000.00
0005433181515	10626	Economy	3000.00
0005433181539	10626	Economy	3000.00
0005433181642	10626	Economy	3000.00
0005434552730	10626	Economy	3000.00
0005433181647	10626	Economy	3000.00
0005434552748	10626	Economy	3000.00
0005433181619	10626	Economy	3000.00
0005433181540	10626	Economy	3000.00
0005433181680	10626	Economy	3000.00
0005433181556	10626	Economy	3000.00
0005433181578	10626	Economy	3000.00
0005434558524	10626	Economy	3000.00
0005433181368	10626	Economy	3000.00
0005434552753	10626	Economy	3000.00
0005435315101	27709	Business	9100.00
0005433181812	27709	Business	9100.00
0005433181811	27709	Business	9100.00
0005433181806	27709	Business	9100.00
0005433181805	27709	Economy	3000.00
0005433181801	27709	Economy	3000.00
0005433181810	27709	Economy	3000.00
0005435315108	27709	Economy	3300.00
0005433181802	27709	Economy	3000.00
0005434757709	27709	Economy	3000.00
0005435315104	27709	Economy	3000.00
0005433181814	27709	Economy	3000.00
0005433181813	27709	Economy	3000.00
0005435315099	27709	Economy	3000.00
0005435315102	27709	Economy	3000.00
0005433181804	27709	Economy	3000.00
0005435315105	27709	Economy	3000.00
0005435315107	27709	Economy	3000.00
0005435315098	27709	Economy	3000.00
0005433181809	27709	Economy	3000.00
0005435315110	27709	Economy	3000.00
0005435315103	27709	Economy	3000.00
0005433181807	27709	Economy	3000.00
0005433181808	27709	Economy	3000.00
0005435315106	27709	Economy	3000.00
0005435315109	27709	Economy	3000.00
0005435315100	27709	Economy	3000.00
0005434757710	27709	Economy	3000.00
0005433181803	27709	Economy	3000.00
0005434552220	27710	Business	9100.00
0005434552006	27710	Business	9100.00
0005434552384	27710	Business	9100.00
0005434552429	27710	Business	9100.00
0005434552235	27710	Business	9100.00
0005434552358	27710	Business	9100.00
0005434552125	27710	Business	9100.00
0005434552604	27710	Business	9100.00
0005434552535	27710	Business	9100.00
0005434552002	27710	Business	9100.00
0005434552061	27710	Economy	3000.00
0005434552060	27710	Economy	3000.00
0005434552412	27710	Economy	3000.00
0005434552377	27710	Economy	3000.00
0005434552124	27710	Economy	3000.00
0005434552271	27710	Economy	3000.00
0005434552231	27710	Economy	3000.00
0005434552482	27710	Economy	3300.00
0005434552333	27710	Economy	3300.00
0005434552536	27710	Economy	3300.00
0005434552342	27710	Economy	3300.00
0005434552402	27710	Economy	3000.00
0005434552483	27710	Economy	3000.00
0005434552441	27710	Economy	3000.00
0005434552044	27710	Economy	3000.00
0005434558431	27710	Economy	3000.00
0005434552425	27710	Economy	3000.00
0005434552518	27710	Economy	3000.00
0005434552305	27710	Economy	3000.00
0005434552359	27710	Economy	3000.00
0005434558452	27710	Economy	3000.00
0005434552434	27710	Economy	3000.00
0005434552413	27710	Economy	3000.00
0005434552431	27710	Economy	3000.00
0005434552163	27710	Economy	3000.00
0005434552053	27710	Economy	3000.00
0005434552322	27710	Economy	3000.00
0005434552379	27710	Economy	3000.00
0005434552278	27710	Economy	3000.00
0005434552275	27710	Economy	3000.00
0005434552314	27710	Economy	3000.00
0005434552245	27710	Economy	3000.00
0005434552493	27710	Economy	3000.00
0005434552445	27710	Economy	3000.00
0005434552426	27710	Economy	3000.00
0005434552315	27710	Economy	3000.00
0005434552432	27710	Economy	3000.00
0005434552249	27710	Economy	3000.00
0005434552433	27710	Economy	3000.00
0005434558428	27710	Economy	3000.00
0005434558447	27710	Economy	3000.00
0005434552481	27710	Economy	3000.00
0005434552332	27710	Economy	3000.00
0005434552438	27710	Economy	3000.00
0005434552341	27710	Economy	3000.00
0005434552484	27710	Economy	3000.00
0005434552325	27710	Economy	3000.00
0005434552517	27710	Economy	3000.00
0005434552346	27710	Economy	3000.00
0005434552274	27710	Economy	3000.00
0005434552356	27710	Economy	3000.00
0005434552516	27710	Economy	3000.00
0005434552203	27710	Economy	3000.00
0005434558430	27710	Economy	3000.00
0005434552368	27710	Economy	3000.00
0005434552494	27710	Economy	3000.00
0005434552270	27710	Economy	3000.00
0005434552414	27710	Economy	3000.00
0005434552430	27710	Economy	3000.00
0005434551982	27710	Economy	3000.00
0005434552403	27710	Economy	3000.00
0005434552424	27710	Economy	3000.00
0005434558429	27710	Economy	3000.00
0005434552043	27710	Economy	3000.00
0005433459338	6116	Economy	11700.00
0005433459335	6116	Economy	11700.00
0005435254523	6116	Economy	11700.00
0005433459339	6116	Economy	11700.00
0005433459337	6116	Economy	11700.00
0005433459336	6116	Economy	11700.00
0005433459313	19308	Economy	11700.00
0005433459323	19308	Economy	11700.00
0005433459312	19308	Economy	11700.00
0005433459317	19308	Economy	11700.00
0005433459318	19308	Economy	11700.00
0005433459322	19308	Economy	11700.00
0005435438352	6761	Business	51100.00
0005435438449	6761	Business	51100.00
0005435683287	6761	Business	51100.00
0005435683295	6761	Business	51100.00
0005435683292	6761	Business	51100.00
0005435683291	6761	Business	51100.00
0005435438466	6761	Business	51100.00
0005435662010	6761	Business	51100.00
0005435220363	6761	Business	51100.00
0005435683281	6761	Business	51100.00
0005435683294	6761	Business	51100.00
0005435438421	6761	Business	51100.00
0005435221528	6761	Economy	17000.00
0005435683293	6761	Economy	17000.00
0005434828748	6761	Economy	17000.00
0005432136309	6761	Economy	17000.00
0005435217747	6761	Economy	17000.00
0005435438360	6761	Economy	17000.00
0005434828743	6761	Economy	18700.00
0005435438403	6761	Economy	18700.00
0005435438409	6761	Economy	18700.00
0005432533347	6761	Economy	18700.00
0005435221529	6761	Economy	18700.00
0005435438462	6761	Economy	17000.00
0005435631048	6761	Economy	17000.00
0005435662011	6761	Economy	17000.00
0005435683280	6761	Economy	17000.00
0005435683273	6761	Economy	17000.00
0005435438317	6761	Economy	17000.00
0005435217756	6761	Economy	17000.00
0005435217757	6761	Economy	17000.00
0005435438389	6761	Economy	17000.00
0005435438318	6761	Economy	17000.00
0005435683297	6761	Economy	17000.00
0005435438339	6761	Economy	17000.00
0005435683284	6761	Economy	17000.00
0005435683275	6761	Economy	17000.00
0005435683274	6761	Economy	17000.00
0005432136306	6761	Economy	17000.00
0005435438420	6761	Economy	17000.00
0005435719602	6761	Economy	17000.00
0005435683285	6761	Economy	17000.00
0005435438479	6761	Economy	17000.00
0005435683286	6761	Economy	17000.00
0005435683276	6761	Economy	17000.00
0005435438470	6761	Economy	17000.00
0005435683296	6761	Economy	17000.00
0005435683279	6761	Economy	17000.00
0005435217755	6761	Economy	17000.00
0005432136307	6761	Economy	17000.00
0005435683283	6761	Economy	17000.00
0005435217752	6761	Economy	17000.00
0005435438306	6761	Economy	17000.00
0005435438192	6761	Economy	17000.00
0005435438446	6761	Economy	17000.00
0005435438480	6761	Economy	17000.00
0005432533348	6761	Economy	17000.00
0005435438435	6761	Economy	17000.00
0005435438448	6761	Economy	17000.00
0005435720166	6761	Economy	17000.00
0005435438357	6761	Economy	17000.00
0005435683278	6761	Economy	17000.00
0005435438424	6761	Economy	17000.00
0005435438410	6761	Economy	17000.00
0005435683272	6761	Economy	17000.00
0005435683289	6761	Economy	17000.00
0005432136308	6761	Economy	17000.00
0005435631049	6761	Economy	17000.00
0005435438369	6761	Economy	17000.00
0005435438404	6761	Economy	17000.00
0005435683288	6761	Economy	17000.00
0005435221527	6761	Economy	17000.00
0005435683277	6761	Economy	17000.00
0005435438405	6761	Economy	17000.00
0005435683290	6761	Economy	17000.00
0005435438450	6761	Economy	17000.00
0005435221526	6761	Economy	17000.00
0005435662009	6761	Economy	17000.00
0005435683282	6761	Economy	17000.00
0005435438567	24608	Business	51100.00
0005435682726	24608	Business	51100.00
0005435438565	24608	Business	51100.00
0005435682975	24608	Business	51100.00
0005435631024	24608	Business	51100.00
0005435682917	24608	Business	51100.00
0005435682774	24608	Business	51100.00
0005435682891	24608	Business	51100.00
0005435220377	24608	Business	51100.00
0005435682967	24608	Business	51100.00
0005432533370	24608	Business	51100.00
0005432533372	24608	Business	51100.00
0005435438572	24608	Economy	17000.00
0005435438562	24608	Economy	17000.00
0005435683000	24608	Economy	17000.00
0005435719574	24608	Economy	17000.00
0005435683011	24608	Economy	17000.00
0005435682951	24608	Economy	17000.00
0005435220379	24608	Economy	17000.00
0005435682974	24608	Economy	17000.00
0005435661998	24608	Economy	17000.00
0005435683024	24608	Economy	18700.00
0005435220378	24608	Economy	18700.00
0005435631025	24608	Economy	18700.00
0005435682984	24608	Economy	18700.00
0005435682976	24608	Economy	18700.00
0005435683038	24608	Economy	17000.00
0005435682815	24608	Economy	17000.00
0005435682998	24608	Economy	17000.00
0005435219259	24608	Economy	17000.00
0005435682840	24608	Economy	17000.00
0005435438564	24608	Economy	17000.00
0005435682934	24608	Economy	17000.00
0005435219258	24608	Economy	17000.00
0005435683013	24608	Economy	17000.00
0005435682724	24608	Economy	17000.00
0005435683037	24608	Economy	17000.00
0005435683002	24608	Economy	17000.00
0005435683121	24608	Economy	17000.00
0005435682870	24608	Economy	17000.00
0005435719582	24608	Economy	17000.00
0005435682999	24608	Economy	17000.00
0005435682777	24608	Economy	17000.00
0005435682824	24608	Economy	17000.00
0005435682668	24608	Economy	17000.00
0005435438571	24608	Economy	17000.00
0005435683026	24608	Economy	17000.00
0005435682725	24608	Economy	17000.00
0005435682993	24608	Economy	17000.00
0005435683146	24608	Economy	17000.00
0005432533371	24608	Economy	17000.00
0005435438570	24608	Economy	17000.00
0005435438563	24608	Economy	17000.00
0005435219260	24608	Economy	17000.00
0005435220519	24608	Economy	17000.00
0005435682996	24608	Economy	17000.00
0005435682897	24608	Economy	17000.00
0005435438566	24608	Economy	17000.00
0005435661980	24608	Economy	17000.00
0005435682930	24608	Economy	17000.00
0005435220380	24608	Economy	17000.00
0005435682916	24608	Economy	17000.00
0005435682728	24608	Economy	17000.00
0005435438573	24608	Economy	17000.00
0005435683108	24608	Economy	17000.00
0005432305818	24608	Economy	17000.00
0005435682828	24608	Economy	17000.00
0005435682816	24608	Economy	17000.00
0005434828773	24608	Economy	17000.00
0005435683014	24608	Economy	17000.00
0005435438574	24608	Economy	17000.00
0005435682814	24608	Economy	17000.00
0005435683099	24608	Economy	17000.00
0005435220517	24608	Economy	17000.00
0005435220376	24608	Economy	17000.00
0005435719573	24608	Economy	17000.00
0005435438569	24608	Economy	17000.00
0005435438568	24608	Economy	17000.00
0005435683001	24608	Economy	17000.00
0005435682948	24608	Economy	17000.00
0005435682925	24608	Economy	17000.00
0005435220518	24608	Economy	17000.00
0005435219257	24608	Economy	17000.00
0005435682933	24608	Economy	17000.00
0005435682918	24608	Economy	17000.00
0005432305817	24608	Economy	17000.00
0005435683147	24608	Economy	17000.00
0005435683059	24608	Economy	17000.00
0005435683019	24608	Economy	17000.00
0005435682776	24608	Economy	17000.00
0005435682947	24608	Economy	17000.00
0005435682904	24608	Economy	17000.00
0005435127483	11561	Business	26400.00
0005435127478	11561	Business	26400.00
0005435127501	11561	Economy	8800.00
0005435106069	11561	Economy	8800.00
0005435127476	11561	Economy	8800.00
0005435127486	11561	Economy	8800.00
0005435106068	11561	Economy	8800.00
0005435127472	11561	Economy	8800.00
0005435127475	11561	Economy	8800.00
0005435127469	11561	Economy	8800.00
0005435127482	11561	Economy	8800.00
0005435127479	11561	Economy	8800.00
0005435127498	11561	Economy	8800.00
0005435127471	11561	Economy	8800.00
0005435127497	11561	Economy	8800.00
0005435127480	11561	Economy	8800.00
0005435127493	11561	Economy	8800.00
0005435127491	11561	Economy	8800.00
0005435127488	11561	Economy	8800.00
0005435127495	11561	Economy	8800.00
0005435127485	11561	Economy	8800.00
0005435127499	11561	Economy	8800.00
0005435127490	11561	Economy	8800.00
0005435127474	11561	Economy	8800.00
0005435127496	11561	Economy	8800.00
0005435127481	11561	Economy	8800.00
0005435127468	11561	Economy	8800.00
0005435127487	11561	Economy	8800.00
0005435127477	11561	Economy	8800.00
0005435127489	11561	Economy	8800.00
0005435127484	11561	Economy	8800.00
0005435127492	11561	Economy	8800.00
0005435127500	11561	Economy	8800.00
0005435127494	11561	Economy	8800.00
0005435127473	11561	Economy	8800.00
0005435127470	11561	Economy	8800.00
0005435127151	31868	Business	26400.00
0005435127242	31868	Business	26400.00
0005435127147	31868	Business	26400.00
0005435127349	31868	Business	26400.00
0005435127144	31868	Business	26400.00
0005435127077	31868	Business	26400.00
0005435127026	31868	Economy	8800.00
0005435098590	31868	Economy	8800.00
0005435127183	31868	Economy	8800.00
0005435127101	31868	Economy	9700.00
0005435127273	31868	Economy	9700.00
0005435127208	31868	Economy	8800.00
0005435127156	31868	Economy	8800.00
0005435127197	31868	Economy	8800.00
0005435127009	31868	Economy	8800.00
0005435127223	31868	Economy	8800.00
0005435126970	31868	Economy	8800.00
0005435127225	31868	Economy	8800.00
0005435127090	31868	Economy	8800.00
0005435127303	31868	Economy	8800.00
0005435127135	31868	Economy	8800.00
0005435127350	31868	Economy	8800.00
0005435127282	31868	Economy	8800.00
0005435126969	31868	Economy	8800.00
0005435127106	31868	Economy	8800.00
0005435127111	31868	Economy	8800.00
0005435127194	31868	Economy	8800.00
0005435127224	31868	Economy	8800.00
0005435106036	31868	Economy	8800.00
0005435127283	31868	Economy	8800.00
0005435127198	31868	Economy	8800.00
0005435127211	31868	Economy	8800.00
0005435127145	31868	Economy	8800.00
0005435127100	31868	Economy	8800.00
0005435127130	31868	Economy	8800.00
0005435127201	31868	Economy	8800.00
0005435106037	31868	Economy	8800.00
0005435127227	31868	Economy	8800.00
0005435127257	31868	Economy	8800.00
0005435127193	31868	Economy	8800.00
0005435127146	31868	Economy	8800.00
0005435127296	31868	Economy	8800.00
0005435127195	31868	Economy	8800.00
0005435127252	31868	Economy	8800.00
0005435127110	31868	Economy	8800.00
0005435127329	31868	Economy	8800.00
0005433399384	13520	Business	36600.00
0005435732591	13520	Business	36600.00
0005433399394	13520	Business	36600.00
0005433399388	13520	Business	36600.00
0005435732552	13520	Economy	12200.00
0005433399395	13520	Economy	12200.00
0005433399414	13520	Economy	12200.00
0005433399392	13520	Economy	12200.00
0005435732557	13520	Economy	13400.00
0005433399397	13520	Economy	13400.00
0005435732593	13520	Economy	12200.00
0005433399409	13520	Economy	12200.00
0005433399390	13520	Economy	12200.00
0005433399411	13520	Economy	12200.00
0005433399406	13520	Economy	12200.00
0005435732578	13520	Economy	12200.00
0005433399391	13520	Economy	12200.00
0005433399413	13520	Economy	12200.00
0005433399402	13520	Economy	12200.00
0005435732609	13520	Economy	12200.00
0005433399381	13520	Economy	12200.00
0005433399399	13520	Economy	12200.00
0005433399385	13520	Economy	12200.00
0005433399412	13520	Economy	12200.00
0005435732629	13520	Economy	12200.00
0005433399403	13520	Economy	12200.00
0005433399383	13520	Economy	12200.00
0005435732628	13520	Economy	12200.00
0005433399405	13520	Economy	12200.00
0005433399404	13520	Economy	12200.00
0005433399393	13520	Economy	12200.00
0005433399401	13520	Economy	12200.00
0005435732579	13520	Economy	12200.00
0005433399389	13520	Economy	12200.00
0005435732610	13520	Economy	12200.00
0005433399407	13520	Economy	12200.00
0005435732561	13520	Economy	12200.00
0005433399386	13520	Economy	12200.00
0005435732551	13520	Economy	12200.00
0005435732549	13520	Economy	12200.00
0005433399408	13520	Economy	12200.00
0005433399410	13520	Economy	12200.00
0005433399400	13520	Economy	12200.00
0005433399387	13520	Economy	12200.00
0005433399396	13520	Economy	12200.00
0005435732592	13520	Economy	12200.00
0005435732550	13520	Economy	12200.00
0005433399398	13520	Economy	12200.00
0005433399382	13520	Economy	12200.00
0005433399070	19422	Business	36600.00
0005433398970	19422	Business	36600.00
0005433398943	19422	Business	36600.00
0005435732694	19422	Business	36600.00
0005433399135	19422	Business	36600.00
0005433398942	19422	Business	36600.00
0005433399064	19422	Business	36600.00
0005433399021	19422	Business	36600.00
0005433399073	19422	Business	36600.00
0005433399061	19422	Economy	12200.00
0005435732699	19422	Economy	12200.00
0005435732690	19422	Economy	12200.00
0005433399057	19422	Economy	12200.00
0005433399112	19422	Economy	12200.00
0005433399104	19422	Economy	12200.00
0005433399144	19422	Economy	12200.00
0005433398971	19422	Economy	12200.00
0005433399016	19422	Economy	12200.00
0005433399049	19422	Economy	13400.00
0005433398964	19422	Economy	13400.00
0005433398824	19422	Economy	13400.00
0005433398944	19422	Economy	13400.00
0005433399038	19422	Economy	12200.00
0005435732692	19422	Economy	12200.00
0005433399056	19422	Economy	12200.00
0005435725763	19422	Economy	12200.00
0005433398783	19422	Economy	12200.00
0005435732697	19422	Economy	12200.00
0005433399170	19422	Economy	12200.00
0005432297351	19422	Economy	12200.00
0005435732693	19422	Economy	12200.00
0005433399103	19422	Economy	12200.00
0005435725762	19422	Economy	12200.00
0005433398963	19422	Economy	12200.00
0005433399313	19422	Economy	12200.00
0005435725764	19422	Economy	12200.00
0005433398997	19422	Economy	12200.00
0005433399020	19422	Economy	12200.00
0005433399136	19422	Economy	12200.00
0005433398927	19422	Economy	12200.00
0005435732701	19422	Economy	12200.00
0005433399163	19422	Economy	12200.00
0005435732688	19422	Economy	12200.00
0005433399145	19422	Economy	12200.00
0005433399062	19422	Economy	12200.00
0005433399200	19422	Economy	12200.00
0005433399114	19422	Economy	12200.00
0005435732695	19422	Economy	12200.00
0005433399023	19422	Economy	12200.00
0005433399134	19422	Economy	12200.00
0005433399071	19422	Economy	12200.00
0005433399113	19422	Economy	12200.00
0005433399050	19422	Economy	12200.00
0005433399312	19422	Economy	12200.00
0005433398926	19422	Economy	12200.00
0005433399074	19422	Economy	12200.00
0005433399175	19422	Economy	12200.00
0005433398995	19422	Economy	12200.00
0005435732687	19422	Economy	12200.00
0005435732691	19422	Economy	12200.00
0005433399146	19422	Economy	12200.00
0005435725766	19422	Economy	12200.00
0005433398916	19422	Economy	12200.00
0005435725765	19422	Economy	12200.00
0005433399079	19422	Economy	12200.00
0005435732696	19422	Economy	12200.00
0005433399115	19422	Economy	12200.00
0005433398917	19422	Economy	12200.00
0005435732689	19422	Economy	12200.00
0005433398890	19422	Economy	12200.00
0005433398928	19422	Economy	12200.00
0005433399005	19422	Economy	12200.00
0005433398879	19422	Economy	12200.00
0005433399004	19422	Economy	12200.00
0005435732700	19422	Economy	12200.00
0005435732698	19422	Economy	12200.00
0005433399060	19422	Economy	12200.00
0005435732702	19422	Economy	12200.00
0005432297350	19422	Economy	12200.00
0005433398996	19422	Economy	12200.00
0005433398898	19422	Economy	12200.00
0005435070151	13140	Business	11300.00
0005435069994	13140	Business	11300.00
0005435070106	13140	Business	11300.00
0005435070130	13140	Business	11300.00
0005435070150	13140	Business	11300.00
0005435070156	13140	Business	11300.00
0005435070207	13140	Business	11300.00
0005435070043	13140	Business	11300.00
0005435070135	13140	Business	11300.00
0005435070157	13140	Economy	3800.00
0005435070208	13140	Economy	3800.00
0005435070107	13140	Economy	3800.00
0005435070050	13140	Economy	3800.00
0005435070077	13140	Economy	3800.00
0005435070047	13140	Economy	4100.00
0005435070044	13140	Economy	4100.00
0005435070274	13140	Economy	4100.00
0005435069831	13140	Economy	3800.00
0005435069993	13140	Economy	3800.00
0005435070051	13140	Economy	3800.00
0005435070225	13140	Economy	3800.00
0005435069977	13140	Economy	3800.00
0005435070123	13140	Economy	3800.00
0005435070124	13140	Economy	3800.00
0005435070098	13140	Economy	3800.00
0005435070211	13140	Economy	3800.00
0005435070039	13140	Economy	3800.00
0005435070103	13140	Economy	3800.00
0005435070132	13140	Economy	3800.00
0005435070104	13140	Economy	3800.00
0005435070078	13140	Economy	3800.00
0005435069913	13140	Economy	3800.00
0005435070009	13140	Economy	3800.00
0005435070049	13140	Economy	3800.00
0005435070095	13140	Economy	3800.00
0005435070099	13140	Economy	3800.00
0005435070245	13140	Economy	3800.00
0005435069912	13140	Economy	3800.00
0005435070071	13140	Economy	3800.00
0005435070148	13140	Economy	3800.00
0005435070134	13140	Economy	3800.00
0005435070094	13140	Economy	3800.00
0005435070136	13140	Economy	3800.00
0005435069862	13140	Economy	3800.00
0005435070270	13140	Economy	3800.00
0005435070163	13140	Economy	3800.00
0005435070275	13140	Economy	3800.00
0005435069998	13140	Economy	3800.00
0005435070086	13140	Economy	3800.00
0005435070213	13140	Economy	3800.00
0005435070171	13140	Economy	3800.00
0005435070116	13140	Economy	3800.00
0005435070220	13140	Economy	3800.00
0005435070038	13140	Economy	3800.00
0005435070013	13140	Economy	3800.00
0005435070075	13140	Economy	3800.00
0005435070479	15485	Business	11300.00
0005435925492	15485	Business	11300.00
0005435925491	15485	Business	11300.00
0005435070494	15485	Business	11300.00
0005435070467	15485	Business	11300.00
0005435070481	15485	Business	11300.00
0005435925533	15485	Business	11300.00
0005435925537	15485	Economy	3800.00
0005435070493	15485	Economy	3800.00
0005435070468	15485	Economy	3800.00
0005435070491	15485	Economy	4100.00
0005435925640	15485	Economy	4100.00
0005435925582	15485	Economy	3800.00
0005435925490	15485	Economy	3800.00
0005435925532	15485	Economy	3800.00
0005435070474	15485	Economy	3800.00
0005435070466	15485	Economy	3800.00
0005435070488	15485	Economy	3800.00
0005435070476	15485	Economy	3800.00
0005435070475	15485	Economy	3800.00
0005435070490	15485	Economy	3800.00
0005435070473	15485	Economy	3800.00
0005435070484	15485	Economy	3800.00
0005435070471	15485	Economy	3800.00
0005435070465	15485	Economy	3800.00
0005435070495	15485	Economy	3800.00
0005435070485	15485	Economy	3800.00
0005435070492	15485	Economy	3800.00
0005435925531	15485	Economy	3800.00
0005435070469	15485	Economy	3800.00
0005435070477	15485	Economy	3800.00
0005435070487	15485	Economy	3800.00
0005435070482	15485	Economy	3800.00
0005435070489	15485	Economy	3800.00
0005435070478	15485	Economy	3800.00
0005435070483	15485	Economy	3800.00
0005435070480	15485	Economy	3800.00
0005435070486	15485	Economy	3800.00
0005435925525	15485	Economy	3800.00
0005435925638	15485	Economy	3800.00
0005435925639	15485	Economy	3800.00
0005435070472	15485	Economy	3800.00
0005435070470	15485	Economy	3800.00
0005435808493	23191	Economy	27100.00
0005433407659	23191	Economy	24700.00
0005435808508	23191	Economy	24700.00
0005433407656	23191	Economy	24700.00
0005435808511	23191	Economy	24700.00
0005435808498	23191	Economy	24700.00
0005433407666	23191	Economy	24700.00
0005435808505	23191	Economy	24700.00
0005435808496	23191	Economy	24700.00
0005435808499	23191	Economy	24700.00
0005435808501	23191	Economy	24700.00
0005433407657	23191	Economy	24700.00
0005433407641	23191	Economy	24700.00
0005435808495	23191	Economy	24700.00
0005433407673	23191	Economy	24700.00
0005435808504	23191	Economy	24700.00
0005435808506	23191	Economy	24700.00
0005433407658	23191	Economy	24700.00
0005435808497	23191	Economy	24700.00
0005435808494	23191	Economy	24700.00
0005433407642	23191	Economy	24700.00
0005435808509	23191	Economy	24700.00
0005433407674	23191	Economy	24700.00
0005435808500	23191	Economy	24700.00
0005435808503	23191	Economy	24700.00
0005435808502	23191	Economy	24700.00
0005433407660	23191	Economy	24700.00
0005435808510	23191	Economy	24700.00
0005435808507	23191	Economy	24700.00
0005434756975	10701	Business	61300.00
0005434215832	10701	Business	61300.00
0005434215825	10701	Business	61300.00
0005434757124	10701	Business	61300.00
0005434757165	10701	Business	61300.00
0005434215814	10701	Business	61300.00
0005434757220	10701	Business	61300.00
0005434757072	10701	Business	61300.00
0005434215844	10701	Business	61300.00
0005434757285	10701	Economy	20400.00
0005434215823	10701	Economy	20400.00
0005434757055	10701	Economy	20400.00
0005434215816	10701	Economy	20400.00
0005434215843	10701	Economy	20400.00
0005434757278	10701	Economy	20400.00
0005434757311	10701	Economy	20400.00
0005434215821	10701	Economy	22500.00
0005434215842	10701	Economy	22500.00
0005434757240	10701	Economy	22500.00
0005434756976	10701	Economy	22500.00
0005434757310	10701	Economy	20400.00
0005434215837	10701	Economy	20400.00
0005434215830	10701	Economy	20400.00
0005434757109	10701	Economy	20400.00
0005434215820	10701	Economy	20400.00
0005434757289	10701	Economy	20400.00
0005434757166	10701	Economy	20400.00
0005434215817	10701	Economy	20400.00
0005434757247	10701	Economy	20400.00
0005434215824	10701	Economy	20400.00
0005434757157	10701	Economy	20400.00
0005434215831	10701	Economy	20400.00
0005434757162	10701	Economy	20400.00
0005434215841	10701	Economy	20400.00
0005434757073	10701	Economy	20400.00
0005434215836	10701	Economy	20400.00
0005434757183	10701	Economy	20400.00
0005434215827	10701	Economy	20400.00
0005434757218	10701	Economy	20400.00
0005434757332	10701	Economy	20400.00
0005434757110	10701	Economy	20400.00
0005434757062	10701	Economy	20400.00
0005434757219	10701	Economy	20400.00
0005434215835	10701	Economy	20400.00
0005434757286	10701	Economy	20400.00
0005434215834	10701	Economy	20400.00
0005434757331	10701	Economy	20400.00
0005434215818	10701	Economy	20400.00
0005434757056	10701	Economy	20400.00
0005434215839	10701	Economy	20400.00
0005434757182	10701	Economy	20400.00
0005434757229	10701	Economy	20400.00
0005434215826	10701	Economy	20400.00
0005434757221	10701	Economy	20400.00
0005434757185	10701	Economy	20400.00
0005434757191	10701	Economy	20400.00
0005434757276	10701	Economy	20400.00
0005434757070	10701	Economy	20400.00
0005434757071	10701	Economy	20400.00
0005434757248	10701	Economy	20400.00
0005434757258	10701	Economy	20400.00
0005434215815	10701	Economy	20400.00
0005434757239	10701	Economy	20400.00
0005434215822	10701	Economy	20400.00
0005434215838	10701	Economy	20400.00
0005434215813	10701	Economy	20400.00
0005434215833	10701	Economy	20400.00
0005434757274	10701	Economy	20400.00
0005434757063	10701	Economy	20400.00
0005434215840	10701	Economy	20400.00
0005434215828	10701	Economy	20400.00
0005434215829	10701	Economy	20400.00
0005434757215	10701	Economy	20400.00
0005434757356	10701	Economy	20400.00
0005434215819	10701	Economy	20400.00
0005434757586	28683	Business	61300.00
0005434215450	28683	Business	61300.00
0005434757572	28683	Business	61300.00
0005434757570	28683	Business	61300.00
0005434757574	28683	Business	61300.00
0005434215456	28683	Business	61300.00
0005434215312	28683	Business	61300.00
0005434215442	28683	Business	61300.00
0005434215408	28683	Economy	20400.00
0005434215372	28683	Economy	20400.00
0005434215378	28683	Economy	20400.00
0005434215468	28683	Economy	20400.00
0005434215265	28683	Economy	20400.00
0005434757595	28683	Economy	20400.00
0005434215338	28683	Economy	20400.00
0005434215430	28683	Economy	20400.00
0005434215373	28683	Economy	20400.00
0005434215388	28683	Economy	20400.00
0005434757590	28683	Economy	22500.00
0005434215379	28683	Economy	22500.00
0005434215350	28683	Economy	22500.00
0005434757579	28683	Economy	20400.00
0005434215439	28683	Economy	20400.00
0005434215339	28683	Economy	20400.00
0005434215337	28683	Economy	20400.00
0005434215464	28683	Economy	20400.00
0005434757566	28683	Economy	20400.00
0005434757588	28683	Economy	20400.00
0005434757585	28683	Economy	20400.00
0005434215635	28683	Economy	20400.00
0005434757576	28683	Economy	20400.00
0005434757573	28683	Economy	20400.00
0005434215438	28683	Economy	20400.00
0005434757582	28683	Economy	20400.00
0005434757589	28683	Economy	20400.00
0005434215298	28683	Economy	20400.00
0005434757594	28683	Economy	20400.00
0005434215437	28683	Economy	20400.00
0005434757578	28683	Economy	20400.00
0005434757584	28683	Economy	20400.00
0005434215517	28683	Economy	20400.00
0005434215506	28683	Economy	20400.00
0005434215351	28683	Economy	20400.00
0005434215297	28683	Economy	20400.00
0005434215376	28683	Economy	20400.00
0005434215409	28683	Economy	20400.00
0005434215558	28683	Economy	20400.00
0005434215412	28683	Economy	20400.00
0005434215255	28683	Economy	20400.00
0005434215234	28683	Economy	20400.00
0005434757592	28683	Economy	20400.00
0005434215634	28683	Economy	20400.00
0005434215441	28683	Economy	20400.00
0005434757580	28683	Economy	20400.00
0005434215355	28683	Economy	20400.00
0005434215280	28683	Economy	20400.00
0005434215320	28683	Economy	20400.00
0005434215250	28683	Economy	20400.00
0005434215418	28683	Economy	20400.00
0005434757581	28683	Economy	20400.00
0005434215407	28683	Economy	20400.00
0005434215185	28683	Economy	20400.00
0005434215505	28683	Economy	20400.00
0005434215455	28683	Economy	20400.00
0005434757587	28683	Economy	20400.00
0005434757568	28683	Economy	20400.00
0005434757577	28683	Economy	20400.00
0005434757593	28683	Economy	20400.00
0005434757575	28683	Economy	20400.00
0005434215311	28683	Economy	20400.00
0005434757583	28683	Economy	20400.00
0005434757567	28683	Economy	20400.00
0005434215443	28683	Economy	20400.00
0005434757591	28683	Economy	20400.00
0005434215417	28683	Economy	20400.00
0005434757571	28683	Economy	20400.00
0005434757569	28683	Economy	20400.00
0005435041606	5475	Business	29500.00
0005432125655	5475	Business	29500.00
0005435041600	5475	Business	29500.00
0005432125656	5475	Business	29500.00
0005432125654	5475	Business	29500.00
0005435041582	5475	Business	29500.00
0005435043312	5475	Business	29500.00
0005435007690	5475	Economy	9800.00
0005435041585	5475	Economy	9800.00
0005435041614	5475	Economy	9800.00
0005435041590	5475	Economy	9800.00
0005435043311	5475	Economy	9800.00
0005435041587	5475	Economy	9800.00
0005435041595	5475	Economy	9800.00
0005434229841	5475	Economy	9800.00
0005435041611	5475	Economy	9800.00
0005435007678	5475	Economy	9800.00
0005435377920	5475	Economy	9800.00
0005435041613	5475	Economy	9800.00
0005435041608	5475	Economy	9800.00
0005435041580	5475	Economy	9800.00
0005435007686	5475	Economy	9800.00
0005435377913	5475	Economy	9800.00
0005435041597	5475	Economy	9800.00
0005435042935	5475	Economy	9800.00
0005434229806	5475	Economy	9800.00
0005435041592	5475	Economy	9800.00
0005435041616	5475	Economy	9800.00
0005435041577	5475	Economy	9800.00
0005435041584	5475	Economy	9800.00
0005434229904	5475	Economy	9800.00
0005435007687	5475	Economy	9800.00
0005435007681	5475	Economy	9800.00
0005435042934	5475	Economy	9800.00
0005435043313	5475	Economy	9800.00
0005435041594	5475	Economy	9800.00
0005435007679	5475	Economy	9800.00
0005434229849	5475	Economy	9800.00
0005435041596	5475	Economy	9800.00
0005435041612	5475	Economy	10800.00
0005434229783	5475	Economy	10800.00
0005435041610	5475	Economy	10800.00
0005435043309	5475	Economy	10800.00
0005434229866	5475	Economy	9800.00
0005435041609	5475	Economy	9800.00
0005435041591	5475	Economy	9800.00
0005435041599	5475	Economy	9800.00
0005435041603	5475	Economy	9800.00
0005434229835	5475	Economy	9800.00
0005435041581	5475	Economy	9800.00
0005435377915	5475	Economy	9800.00
0005435007684	5475	Economy	9800.00
0005434229782	5475	Economy	9800.00
0005434229902	5475	Economy	9800.00
0005435041604	5475	Economy	9800.00
0005435041583	5475	Economy	9800.00
0005435041605	5475	Economy	9800.00
0005435007689	5475	Economy	9800.00
0005435041589	5475	Economy	9800.00
0005435007691	5475	Economy	9800.00
0005435377912	5475	Economy	9800.00
0005434229839	5475	Economy	9800.00
0005435007677	5475	Economy	9800.00
0005435041588	5475	Economy	9800.00
0005435007683	5475	Economy	9800.00
0005435041579	5475	Economy	9800.00
0005435041578	5475	Economy	9800.00
0005434229903	5475	Economy	9800.00
0005434229826	5475	Economy	9800.00
0005435041602	5475	Economy	9800.00
0005435041601	5475	Economy	9800.00
0005435043310	5475	Economy	9800.00
0005435041607	5475	Economy	9800.00
0005435041598	5475	Economy	9800.00
0005435041615	5475	Economy	9800.00
0005434229805	5475	Economy	9800.00
0005434229726	5475	Economy	9800.00
0005435007676	5475	Economy	9800.00
0005435007682	5475	Economy	9800.00
0005435041586	5475	Economy	9800.00
0005435007688	5475	Economy	9800.00
0005435007685	5475	Economy	9800.00
0005435041593	5475	Economy	9800.00
0005435007680	5475	Economy	9800.00
0005434229840	5475	Economy	9800.00
0005434229848	5475	Economy	9800.00
0005435042911	12976	Business	29500.00
0005435041124	12976	Business	29500.00
0005435041140	12976	Business	29500.00
0005435041234	12976	Business	29500.00
0005435377944	12976	Business	29500.00
0005435007467	12976	Business	29500.00
0005435040949	12976	Business	29500.00
0005435377943	12976	Business	29500.00
0005435040822	12976	Business	29500.00
0005435041048	12976	Business	29500.00
0005435041021	12976	Business	29500.00
0005435041141	12976	Business	29500.00
0005435007556	12976	Economy	9800.00
0005432304510	12976	Economy	9800.00
0005435007471	12976	Economy	9800.00
0005434229998	12976	Economy	9800.00
0005435041173	12976	Economy	9800.00
0005435040963	12976	Economy	9800.00
0005435041013	12976	Economy	9800.00
0005435042920	12976	Economy	9800.00
0005435041101	12976	Economy	9800.00
0005435042921	12976	Economy	9800.00
0005435041008	12976	Economy	9800.00
0005435040969	12976	Economy	9800.00
0005435041050	12976	Economy	9800.00
0005435377952	12976	Economy	9800.00
0005435377949	12976	Economy	9800.00
0005435041100	12976	Economy	9800.00
0005434230010	12976	Economy	9800.00
0005435040984	12976	Economy	9800.00
0005435007436	12976	Economy	9800.00
0005435040925	12976	Economy	9800.00
0005435377946	12976	Economy	9800.00
0005435377948	12976	Economy	9800.00
0005435041147	12976	Economy	9800.00
0005435041001	12976	Economy	9800.00
0005435377938	12976	Economy	9800.00
0005435040966	12976	Economy	9800.00
0005435007469	12976	Economy	9800.00
0005434230000	12976	Economy	9800.00
0005435041049	12976	Economy	9800.00
0005435007535	12976	Economy	9800.00
0005435007470	12976	Economy	9800.00
0005435007468	12976	Economy	9800.00
0005435007529	12976	Economy	9800.00
0005435040962	12976	Economy	9800.00
0005435007543	12976	Economy	9800.00
0005435040603	12976	Economy	9800.00
0005435007546	12976	Economy	9800.00
0005435377950	12976	Economy	9800.00
0005435041109	12976	Economy	10800.00
0005434230007	12976	Economy	10800.00
0005434230009	12976	Economy	10800.00
0005434230004	12976	Economy	10800.00
0005435007464	12976	Economy	10800.00
0005435007504	12976	Economy	10800.00
0005435041146	12976	Economy	9800.00
0005435041306	12976	Economy	9800.00
0005435377953	12976	Economy	9800.00
0005435007533	12976	Economy	9800.00
0005434230008	12976	Economy	9800.00
0005435040991	12976	Economy	9800.00
0005434230005	12976	Economy	9800.00
0005435041142	12976	Economy	9800.00
0005435040995	12976	Economy	9800.00
0005435377951	12976	Economy	9800.00
0005435041015	12976	Economy	9800.00
0005435041136	12976	Economy	9800.00
0005434230006	12976	Economy	9800.00
0005434230001	12976	Economy	9800.00
0005435041139	12976	Economy	9800.00
0005435041233	12976	Economy	9800.00
0005435007583	12976	Economy	9800.00
0005435041020	12976	Economy	9800.00
0005435042910	12976	Economy	9800.00
0005434229996	12976	Economy	9800.00
0005435040948	12976	Economy	9800.00
0005432304509	12976	Economy	9800.00
0005435041286	12976	Economy	9800.00
0005434229999	12976	Economy	9800.00
0005434229997	12976	Economy	9800.00
0005435377940	12976	Economy	9800.00
0005435007555	12976	Economy	9800.00
0005435041390	12976	Economy	9800.00
0005432304507	12976	Economy	9800.00
0005435041145	12976	Economy	9800.00
0005435040965	12976	Economy	9800.00
0005434230002	12976	Economy	9800.00
0005435041000	12976	Economy	9800.00
0005435377941	12976	Economy	9800.00
0005435556766	12976	Economy	9800.00
0005435041132	12976	Economy	9800.00
0005435041080	12976	Economy	9800.00
0005435377942	12976	Economy	9800.00
0005435041065	12976	Economy	9800.00
0005435041423	12976	Economy	9800.00
0005435040994	12976	Economy	9800.00
0005435041391	12976	Economy	9800.00
0005435041148	12976	Economy	9800.00
0005435040926	12976	Economy	9800.00
0005435041304	12976	Economy	9800.00
0005435007528	12976	Economy	9800.00
0005435040602	12976	Economy	9800.00
0005435041361	12976	Economy	9800.00
0005435041017	12976	Economy	9800.00
0005435377947	12976	Economy	9800.00
0005435007448	12976	Economy	9800.00
0005435041150	12976	Economy	9800.00
0005435041212	12976	Economy	9800.00
0005435041079	12976	Economy	9800.00
0005435040990	12976	Economy	9800.00
0005435735279	12976	Economy	9800.00
0005432304508	12976	Economy	9800.00
0005435007420	12976	Economy	9800.00
0005435041424	12976	Economy	9800.00
0005435040757	12976	Economy	9800.00
0005435041307	12976	Economy	9800.00
0005434230003	12976	Economy	9800.00
0005435041087	12976	Economy	9800.00
0005435041303	12976	Economy	9800.00
0005435377945	12976	Economy	9800.00
0005435041123	12976	Economy	9800.00
0005435041308	12976	Economy	9800.00
0005435041149	12976	Economy	9800.00
0005434229995	12976	Economy	9800.00
0005435040735	12976	Economy	9800.00
0005435007524	12976	Economy	9800.00
0005435377939	12976	Economy	9800.00
0005435903081	14886	Business	52900.00
0005434427410	14886	Business	52900.00
0005434427411	14886	Business	52900.00
0005434427421	14886	Business	52900.00
0005434427417	14886	Business	52900.00
0005435554261	14886	Economy	17600.00
0005435554295	14886	Economy	17600.00
0005435902941	14886	Economy	17600.00
0005435903076	14886	Economy	17600.00
0005434427409	14886	Economy	19400.00
0005435554277	14886	Economy	19400.00
0005435554294	14886	Economy	17600.00
0005435554274	14886	Economy	17600.00
0005434427419	14886	Economy	17600.00
0005435903108	14886	Economy	17600.00
0005434427416	14886	Economy	17600.00
0005435902949	14886	Economy	17600.00
0005435903082	14886	Economy	17600.00
0005434427407	14886	Economy	17600.00
0005435903027	14886	Economy	17600.00
0005435903038	14886	Economy	17600.00
0005434427406	14886	Economy	17600.00
0005434427408	14886	Economy	17600.00
0005434427412	14886	Economy	17600.00
0005435902940	14886	Economy	17600.00
0005435554262	14886	Economy	17600.00
0005435554276	14886	Economy	17600.00
0005434427405	14886	Economy	17600.00
0005435903094	14886	Economy	17600.00
0005435903029	14886	Economy	17600.00
0005435902948	14886	Economy	17600.00
0005434427415	14886	Economy	17600.00
0005435903122	14886	Economy	17600.00
0005435903050	14886	Economy	17600.00
0005434427413	14886	Economy	17600.00
0005435903039	14886	Economy	17600.00
0005434427404	14886	Economy	17600.00
0005435903030	14886	Economy	17600.00
0005434427418	14886	Economy	17600.00
0005434427414	14886	Economy	17600.00
0005435903031	14886	Economy	17600.00
0005434427420	14886	Economy	17600.00
0005434427245	20209	Business	52900.00
0005434411867	20209	Business	52900.00
0005434411865	20209	Business	52900.00
0005435903198	20209	Business	52900.00
0005434427169	20209	Business	52900.00
0005434427183	20209	Business	52900.00
0005435903196	20209	Economy	17600.00
0005432059561	20209	Economy	17600.00
0005434427220	20209	Economy	17600.00
0005434427186	20209	Economy	17600.00
0005432059562	20209	Economy	17600.00
0005435903200	20209	Economy	17600.00
0005435554322	20209	Economy	17600.00
0005435903197	20209	Economy	19400.00
0005434427231	20209	Economy	19400.00
0005434411871	20209	Economy	19400.00
0005434427246	20209	Economy	17600.00
0005434427277	20209	Economy	17600.00
0005435903204	20209	Economy	17600.00
0005435903201	20209	Economy	17600.00
0005435903202	20209	Economy	17600.00
0005434427309	20209	Economy	17600.00
0005434427216	20209	Economy	17600.00
0005434411861	20209	Economy	17600.00
0005434427174	20209	Economy	17600.00
0005435903203	20209	Economy	17600.00
0005434427259	20209	Economy	17600.00
0005434427293	20209	Economy	17600.00
0005434427163	20209	Economy	17600.00
0005434427168	20209	Economy	17600.00
0005434427043	20209	Economy	17600.00
0005434427073	20209	Economy	17600.00
0005434427258	20209	Economy	17600.00
0005434427247	20209	Economy	17600.00
0005432059563	20209	Economy	17600.00
0005434427204	20209	Economy	17600.00
0005434427160	20209	Economy	17600.00
0005434427159	20209	Economy	17600.00
0005434411866	20209	Economy	17600.00
0005434427157	20209	Economy	17600.00
0005434427308	20209	Economy	17600.00
0005435554320	20209	Economy	17600.00
0005434427167	20209	Economy	17600.00
0005434427292	20209	Economy	17600.00
0005435903199	20209	Economy	17600.00
0005434427287	20209	Economy	17600.00
0005434411860	20209	Economy	17600.00
0005434427113	20209	Economy	17600.00
0005434427288	20209	Economy	17600.00
0005435554321	20209	Economy	17600.00
0005434427180	20209	Economy	17600.00
0005435554323	20209	Economy	17600.00
0005434427215	20209	Economy	17600.00
0005434427166	20209	Economy	17600.00
0005434559134	30888	Business	106800.00
0005434559149	30888	Business	106800.00
0005434559138	30888	Business	106800.00
0005434559133	30888	Business	106800.00
0005434559132	30888	Economy	35600.00
0005434559152	30888	Economy	35600.00
0005434559156	30888	Economy	35600.00
0005434559159	30888	Economy	35600.00
0005432462541	30888	Economy	35600.00
0005434559163	30888	Economy	35600.00
0005434559125	30888	Economy	35600.00
0005434559148	30888	Economy	35600.00
0005434559128	30888	Economy	35600.00
0005434559157	30888	Economy	35600.00
0005434559123	30888	Economy	35600.00
0005434559143	30888	Economy	35600.00
0005432462551	30888	Economy	35600.00
0005434559161	30888	Economy	35600.00
0005432462552	30888	Economy	35600.00
0005434559158	30888	Economy	39200.00
0005432462556	30888	Economy	39200.00
0005434559145	30888	Economy	39200.00
0005432462550	30888	Economy	35600.00
0005432462546	30888	Economy	35600.00
0005434559129	30888	Economy	35600.00
0005434559146	30888	Economy	35600.00
0005434523838	30888	Economy	35600.00
0005434559137	30888	Economy	35600.00
0005432462559	30888	Economy	35600.00
0005434559130	30888	Economy	35600.00
0005434559140	30888	Economy	35600.00
0005434559141	30888	Economy	35600.00
0005434559135	30888	Economy	35600.00
0005434559160	30888	Economy	35600.00
0005432462547	30888	Economy	35600.00
0005434559155	30888	Economy	35600.00
0005434523841	30888	Economy	35600.00
0005434523836	30888	Economy	35600.00
0005434559136	30888	Economy	35600.00
0005434559162	30888	Economy	35600.00
0005434559164	30888	Economy	35600.00
0005434559139	30888	Economy	35600.00
0005434559127	30888	Economy	35600.00
0005434559144	30888	Economy	35600.00
0005434559124	30888	Economy	35600.00
0005434559147	30888	Economy	35600.00
0005434559151	30888	Economy	35600.00
0005434559126	30888	Economy	35600.00
0005434523839	30888	Economy	35600.00
0005434559153	30888	Economy	35600.00
0005434559142	30888	Economy	35600.00
0005434559150	30888	Economy	35600.00
0005434559131	30888	Economy	35600.00
0005434559122	30888	Economy	35600.00
0005434523837	30888	Economy	35600.00
0005434523840	30888	Economy	35600.00
0005434559154	30888	Economy	35600.00
0005434559165	30888	Economy	35600.00
0005433435265	26534	Business	18500.00
0005433435228	26534	Business	18500.00
0005435983559	26534	Business	18500.00
0005433435206	26534	Business	18500.00
0005435983565	26534	Business	18500.00
0005432300421	26534	Business	18500.00
0005433435244	26534	Business	18500.00
0005435983561	26534	Business	18500.00
0005433435167	26534	Economy	6200.00
0005435983562	26534	Economy	6200.00
0005435983551	26534	Economy	6200.00
0005435983575	26534	Economy	6200.00
0005435983552	26534	Economy	6200.00
0005435983560	26534	Economy	6200.00
0005433435229	26534	Economy	6200.00
0005433435247	26534	Economy	6200.00
0005435983564	26534	Economy	6200.00
0005433435273	26534	Economy	6800.00
0005435983573	26534	Economy	6800.00
0005433435323	26534	Economy	6800.00
0005435983554	26534	Economy	6800.00
0005435983563	26534	Economy	6800.00
0005435983570	26534	Economy	6200.00
0005433435090	26534	Economy	6200.00
0005435983548	26534	Economy	6200.00
0005435983576	26534	Economy	6200.00
0005433435319	26534	Economy	6200.00
0005432300426	26534	Economy	6200.00
0005433435136	26534	Economy	6200.00
0005434270247	26534	Economy	6200.00
0005434270239	26534	Economy	6200.00
0005432300422	26534	Economy	6200.00
0005433435271	26534	Economy	6200.00
0005434270240	26534	Economy	6200.00
0005433435251	26534	Economy	6200.00
0005434273110	26534	Economy	6200.00
0005435983572	26534	Economy	6200.00
0005435983547	26534	Economy	6200.00
0005435983557	26534	Economy	6200.00
0005433435089	26534	Economy	6200.00
0005435983556	26534	Economy	6200.00
0005433435293	26534	Economy	6200.00
0005435983555	26534	Economy	6200.00
0005433435137	26534	Economy	6200.00
0005435983568	26534	Economy	6200.00
0005433435088	26534	Economy	6200.00
0005435983546	26534	Economy	6200.00
0005435983578	26534	Economy	6200.00
0005435983574	26534	Economy	6200.00
0005432300423	26534	Economy	6200.00
0005435983553	26534	Economy	6200.00
0005433435307	26534	Economy	6200.00
0005434270241	26534	Economy	6200.00
0005435983579	26534	Economy	6200.00
0005432300424	26534	Economy	6200.00
0005433435214	26534	Economy	6200.00
0005433435213	26534	Economy	6200.00
0005435983580	26534	Economy	6200.00
0005435983566	26534	Economy	6200.00
0005433435255	26534	Economy	6200.00
0005433435250	26534	Economy	6200.00
0005433435176	26534	Economy	6200.00
0005435983571	26534	Economy	6200.00
0005432300425	26534	Economy	6200.00
0005433435272	26534	Economy	6200.00
0005434270248	26534	Economy	6200.00
0005433435236	26534	Economy	6200.00
0005434270242	26534	Economy	6200.00
0005433435165	26534	Economy	6200.00
0005435983558	26534	Economy	6200.00
0005435983550	26534	Economy	6200.00
0005433435235	26534	Economy	6200.00
0005433435322	26534	Economy	6200.00
0005433435317	26534	Economy	6200.00
0005435983569	26534	Economy	6200.00
0005435983549	26534	Economy	6200.00
0005433435166	26534	Economy	6200.00
0005435983567	26534	Economy	6200.00
0005433435168	26534	Economy	6200.00
0005435983577	26534	Economy	6200.00
0005435983282	26739	Business	18500.00
0005435983185	26739	Business	18500.00
0005435982942	26739	Business	18500.00
0005435983229	26739	Business	18500.00
0005435983076	26739	Business	18500.00
0005435983031	26739	Business	18500.00
0005435983232	26739	Business	18500.00
0005435983077	26739	Business	18500.00
0005435983050	26739	Business	18500.00
0005433435457	26739	Business	18500.00
0005435982941	26739	Business	18500.00
0005435983199	26739	Economy	6200.00
0005435983196	26739	Economy	6200.00
0005435983091	26739	Economy	6200.00
0005433435463	26739	Economy	6200.00
0005435983240	26739	Economy	6200.00
0005433435464	26739	Economy	6200.00
0005433435452	26739	Economy	6800.00
0005435982995	26739	Economy	6800.00
0005433435462	26739	Economy	6800.00
0005435983156	26739	Economy	6800.00
0005433435458	26739	Economy	6200.00
0005433435468	26739	Economy	6200.00
0005435983175	26739	Economy	6200.00
0005433435456	26739	Economy	6200.00
0005435983078	26739	Economy	6200.00
0005435983001	26739	Economy	6200.00
0005435982987	26739	Economy	6200.00
0005435983136	26739	Economy	6200.00
0005432051217	26739	Economy	6200.00
0005435983192	26739	Economy	6200.00
0005435983194	26739	Economy	6200.00
0005433435461	26739	Economy	6200.00
0005435983193	26739	Economy	6200.00
0005435983280	26739	Economy	6200.00
0005434269161	26739	Economy	6200.00
0005435983370	26739	Economy	6200.00
0005435983189	26739	Economy	6200.00
0005435983119	26739	Economy	6200.00
0005434271372	26739	Economy	6200.00
0005435983083	26739	Economy	6200.00
0005433435460	26739	Economy	6200.00
0005435983338	26739	Economy	6200.00
0005435983153	26739	Economy	6200.00
0005433435453	26739	Economy	6200.00
0005435983049	26739	Economy	6200.00
0005435983239	26739	Economy	6200.00
0005432051218	26739	Economy	6200.00
0005435983004	26739	Economy	6200.00
0005433435466	26739	Economy	6200.00
0005434269162	26739	Economy	6200.00
0005433435469	26739	Economy	6200.00
0005433435467	26739	Economy	6200.00
0005433435454	26739	Economy	6200.00
0005433435465	26739	Economy	6200.00
0005433435455	26739	Economy	6200.00
0005435983233	26739	Economy	6200.00
0005435983084	26739	Economy	6200.00
0005435983166	26739	Economy	6200.00
0005434271371	26739	Economy	6200.00
0005435983186	26739	Economy	6200.00
0005435983165	26739	Economy	6200.00
0005435983224	26739	Economy	6200.00
0005435983234	26739	Economy	6200.00
0005435983293	26739	Economy	6200.00
0005435983225	26739	Economy	6200.00
0005435983118	26739	Economy	6200.00
0005434270265	26739	Economy	6200.00
0005433435459	26739	Economy	6200.00
0005432584748	3160	Economy	11100.00
0005432858185	3160	Economy	10100.00
0005432858304	3160	Economy	10100.00
0005432584751	3160	Economy	10100.00
0005432584733	3160	Economy	10100.00
0005432584743	3160	Economy	10100.00
0005432584736	3160	Economy	10100.00
0005432584744	3160	Economy	10100.00
0005432858319	3160	Economy	10100.00
0005432858305	3160	Economy	10100.00
0005432584749	3160	Economy	10100.00
0005432584746	3160	Economy	10100.00
0005432858313	3160	Economy	10100.00
0005432858306	3160	Economy	10100.00
0005432584738	3160	Economy	10100.00
0005432584734	3160	Economy	10100.00
0005432584750	3160	Economy	10100.00
0005432584752	3160	Economy	10100.00
0005432858307	3160	Economy	10100.00
0005432858261	3160	Economy	10100.00
0005432584742	3160	Economy	10100.00
0005432584735	3160	Economy	10100.00
0005432584741	3160	Economy	10100.00
0005432584747	3160	Economy	10100.00
0005432584745	3160	Economy	10100.00
0005432584737	3160	Economy	10100.00
0005432858292	3160	Economy	10100.00
0005432584753	3160	Economy	10100.00
0005432584739	3160	Economy	10100.00
0005432216351	3160	Economy	10100.00
0005432858291	3160	Economy	10100.00
0005432584740	3160	Economy	10100.00
0005432584602	31508	Economy	11100.00
0005432584368	31508	Economy	11100.00
0005432584581	31508	Economy	11100.00
0005432584545	31508	Economy	10100.00
0005432858396	31508	Economy	10100.00
0005432584443	31508	Economy	10100.00
0005432858395	31508	Economy	10100.00
0005432858397	31508	Economy	10100.00
0005432584580	31508	Economy	10100.00
0005432584550	31508	Economy	10100.00
0005432584601	31508	Economy	10100.00
0005432584592	31508	Economy	10100.00
0005432858398	31508	Economy	10100.00
0005432584568	31508	Economy	10100.00
0005432584654	31508	Economy	10100.00
0005432584434	31508	Economy	10100.00
0005432584508	31508	Economy	10100.00
0005432584593	31508	Economy	10100.00
0005432584520	31508	Economy	10100.00
0005432584442	31508	Economy	10100.00
0005432584496	31508	Economy	10100.00
0005432584536	31508	Economy	10100.00
0005434943608	915	Economy	8300.00
0005433255234	915	Economy	7500.00
0005434943609	915	Economy	7500.00
0005433255232	915	Economy	7500.00
0005434943605	915	Economy	7500.00
0005433255231	915	Economy	7500.00
0005433255236	915	Economy	7500.00
0005434943607	915	Economy	7500.00
0005434943606	915	Economy	7500.00
0005433255217	915	Economy	7500.00
0005433255191	915	Economy	7500.00
0005433255247	915	Economy	7500.00
0005433255230	915	Economy	7500.00
0005433255248	915	Economy	7500.00
0005433255235	915	Economy	7500.00
0005433255223	915	Economy	7500.00
0005434943604	915	Economy	7500.00
0005434943492	16205	Economy	8300.00
0005434943582	16205	Economy	8300.00
0005434943535	16205	Economy	7500.00
0005434943508	16205	Economy	7500.00
0005434943534	16205	Economy	7500.00
0005434943548	16205	Economy	7500.00
0005434943545	16205	Economy	7500.00
0005434943581	16205	Economy	7500.00
0005435999867	11144	Economy	29700.00
0005435999865	11144	Economy	29700.00
0005435999868	11144	Economy	29700.00
0005435999866	11144	Economy	29700.00
0005435858674	27613	Business	90500.00
0005433654897	27613	Business	90500.00
0005433654904	27613	Business	90500.00
0005433654898	27613	Business	90500.00
0005433654874	27613	Business	90500.00
0005433654943	27613	Business	90500.00
0005433654873	27613	Business	90500.00
0005435858682	27613	Business	90500.00
0005435858679	27613	Business	90500.00
0005435858678	27613	Business	90500.00
0005433654848	27613	Economy	30200.00
0005433654878	27613	Economy	30200.00
0005435858684	27613	Economy	30200.00
0005433654906	27613	Economy	30200.00
0005433654910	27613	Economy	30200.00
0005433654946	27613	Economy	33200.00
0005435858683	27613	Economy	30200.00
0005433654890	27613	Economy	33200.00
0005433654865	27613	Economy	30200.00
0005435858685	27613	Economy	30200.00
0005433654885	27613	Economy	30200.00
0005435858673	27613	Economy	30200.00
0005433654902	27613	Economy	30200.00
0005433654872	27613	Economy	30200.00
0005433654907	27613	Economy	30200.00
0005433654940	27613	Economy	30200.00
0005433654928	27613	Economy	30200.00
0005435858671	27613	Economy	30200.00
0005433654901	27613	Economy	30200.00
0005435858676	27613	Economy	30200.00
0005433654909	27613	Economy	30200.00
0005435858670	27613	Economy	30200.00
0005433654850	27613	Economy	30200.00
0005433654900	27613	Economy	30200.00
0005433654915	27613	Economy	30200.00
0005433654899	27613	Economy	30200.00
0005433654903	27613	Economy	30200.00
0005433654916	27613	Economy	30200.00
0005433654849	27613	Economy	30200.00
0005433654892	27613	Economy	30200.00
0005435858681	27613	Economy	30200.00
0005435858675	27613	Economy	30200.00
0005433654912	27613	Economy	30200.00
0005433654866	27613	Economy	30200.00
0005435858672	27613	Economy	30200.00
0005433654884	27613	Economy	30200.00
0005435858677	27613	Economy	30200.00
0005435858680	27613	Economy	30200.00
0005433654942	27613	Economy	30200.00
0005433654917	27613	Economy	30200.00
0005433654941	27613	Economy	30200.00
0005433654908	27613	Economy	30200.00
0005433654891	27613	Economy	30200.00
0005433927537	14384	Economy	4400.00
0005433811661	14384	Economy	4400.00
0005433811658	14384	Economy	4400.00
0005433811659	14384	Economy	4400.00
0005433811660	14384	Economy	4400.00
0005433811666	14384	Economy	4400.00
0005435654308	21753	Business	9800.00
0005435654337	21753	Business	9800.00
0005435654347	21753	Business	9800.00
0005435654323	21753	Business	9800.00
0005435654327	21753	Business	9800.00
0005435654322	21753	Business	9800.00
0005435654346	21753	Business	9800.00
0005435654329	21753	Business	9800.00
0005435654303	21753	Business	9800.00
0005435654312	21753	Business	9800.00
0005433368804	21753	Business	9800.00
0005433368589	21753	Economy	3300.00
0005435654344	21753	Economy	3300.00
0005435654314	21753	Economy	3300.00
0005433368602	21753	Economy	3300.00
0005435654330	21753	Economy	3300.00
0005435654350	21753	Economy	3300.00
0005435654353	21753	Economy	3300.00
0005433368550	21753	Economy	3300.00
0005435654315	21753	Economy	3300.00
0005435654334	21753	Economy	3600.00
0005433368687	21753	Economy	3600.00
0005435654341	21753	Economy	3600.00
0005435654318	21753	Economy	3600.00
0005433368729	21753	Economy	3300.00
0005435654300	21753	Economy	3300.00
0005435654306	21753	Economy	3300.00
0005435654331	21753	Economy	3300.00
0005435654335	21753	Economy	3300.00
0005435654317	21753	Economy	3300.00
0005433368623	21753	Economy	3300.00
0005433368590	21753	Economy	3300.00
0005435654336	21753	Economy	3300.00
0005435654319	21753	Economy	3300.00
0005433368492	21753	Economy	3300.00
0005433368425	21753	Economy	3300.00
0005433368598	21753	Economy	3300.00
0005435654321	21753	Economy	3300.00
0005435654332	21753	Economy	3300.00
0005433368758	21753	Economy	3300.00
0005435654345	21753	Economy	3300.00
0005435654324	21753	Economy	3300.00
0005433368534	21753	Economy	3300.00
0005435654310	21753	Economy	3300.00
0005435654343	21753	Economy	3300.00
0005435654326	21753	Economy	3300.00
0005433368726	21753	Economy	3300.00
0005433368587	21753	Economy	3300.00
0005435654309	21753	Economy	3300.00
0005433368627	21753	Economy	3300.00
0005435654338	21753	Economy	3300.00
0005435654339	21753	Economy	3300.00
0005433368688	21753	Economy	3300.00
0005435654305	21753	Economy	3300.00
0005433368678	21753	Economy	3300.00
0005433368572	21753	Economy	3300.00
0005435654313	21753	Economy	3300.00
0005435654307	21753	Economy	3300.00
0005435654354	21753	Economy	3300.00
0005435654352	21753	Economy	3300.00
0005435654333	21753	Economy	3300.00
0005433368741	21753	Economy	3300.00
0005435654328	21753	Economy	3300.00
0005435654301	21753	Economy	3300.00
0005435654342	21753	Economy	3300.00
0005435654325	21753	Economy	3300.00
0005435654349	21753	Economy	3300.00
0005435654302	21753	Economy	3300.00
0005433368447	21753	Economy	3300.00
0005435654320	21753	Economy	3300.00
0005433368599	21753	Economy	3300.00
0005433368553	21753	Economy	3300.00
0005435654348	21753	Economy	3300.00
0005435654311	21753	Economy	3300.00
0005435654316	21753	Economy	3300.00
0005433368568	21753	Economy	3300.00
0005435654304	21753	Economy	3300.00
0005433368586	21753	Economy	3300.00
0005435654340	21753	Economy	3300.00
0005435654351	21753	Economy	3300.00
0005433786070	9365	Business	186200.00
0005433786064	9365	Business	186200.00
0005433786078	9365	Business	186200.00
0005433806370	9365	Business	186200.00
0005433806360	9365	Business	186200.00
0005433786051	9365	Business	186200.00
0005433786072	9365	Business	186200.00
0005433806356	9365	Business	186200.00
0005433786055	9365	Business	186200.00
0005432666446	9365	Business	186200.00
0005432657536	9365	Business	186200.00
0005434171346	9365	Business	186200.00
0005434171351	9365	Business	186200.00
0005433786063	9365	Business	186200.00
0005434171344	9365	Business	186200.00
0005433806363	9365	Economy	68300.00
0005433786068	9365	Economy	62100.00
0005433786040	9365	Economy	62100.00
0005433786057	9365	Economy	62100.00
0005432667513	9365	Economy	62100.00
0005434171289	9365	Economy	62100.00
0005432657535	9365	Economy	62100.00
0005433806373	9365	Economy	62100.00
0005434171315	9365	Economy	62100.00
0005433806362	9365	Economy	62100.00
0005432657537	9365	Economy	62100.00
0005433786052	9365	Economy	62100.00
0005433786065	9365	Economy	62100.00
0005433806372	9365	Economy	62100.00
0005433786076	9365	Economy	62100.00
0005434171343	9365	Economy	62100.00
0005433786071	9365	Economy	62100.00
0005433786085	9365	Economy	62100.00
0005433806367	9365	Economy	62100.00
0005434270256	9365	Economy	62100.00
0005433763602	9365	Economy	62100.00
0005433806365	9365	Economy	62100.00
0005433786053	9365	Economy	62100.00
0005433786041	9365	Economy	62100.00
0005435269875	9365	Economy	62100.00
0005433786046	9365	Economy	62100.00
0005433786090	9365	Economy	62100.00
0005433786056	9365	Economy	62100.00
0005433806366	9365	Economy	62100.00
0005433763608	9365	Economy	62100.00
0005433806369	9365	Economy	62100.00
0005434171348	9365	Economy	62100.00
0005433763603	9365	Economy	62100.00
0005432667514	9365	Economy	62100.00
0005433786054	9365	Economy	62100.00
0005433763606	9365	Economy	62100.00
0005433806357	9365	Economy	62100.00
0005433806361	9365	Economy	62100.00
0005433786084	9365	Economy	62100.00
0005433806358	9365	Economy	62100.00
0005433786080	9365	Economy	62100.00
0005435269881	9365	Economy	62100.00
0005433786047	9365	Economy	62100.00
0005433806368	9365	Economy	62100.00
0005432666444	9365	Economy	62100.00
0005433786049	9365	Economy	62100.00
0005433806355	9365	Economy	62100.00
0005433786089	9365	Economy	62100.00
0005433786050	9365	Economy	62100.00
0005433786091	9365	Economy	62100.00
0005433786092	9365	Economy	62100.00
0005434270255	9365	Economy	62100.00
0005433786087	9365	Economy	62100.00
0005433786074	9365	Economy	62100.00
0005433786093	9365	Economy	62100.00
0005434270254	9365	Economy	62100.00
0005433806364	9365	Economy	62100.00
0005434171317	9365	Economy	62100.00
0005433786066	9365	Economy	62100.00
0005434171341	9365	Economy	68300.00
0005433786077	9365	Economy	62100.00
0005434171288	9365	Economy	62100.00
0005433786059	9365	Economy	62100.00
0005434171369	9365	Economy	62100.00
0005433786061	9365	Economy	62100.00
0005433786073	9365	Economy	62100.00
0005434171291	9365	Economy	62100.00
0005433786083	9365	Economy	62100.00
0005433786082	9365	Economy	62100.00
0005433786069	9365	Economy	62100.00
0005433786086	9365	Economy	62100.00
0005433786044	9365	Economy	62100.00
0005433786048	9365	Economy	62100.00
0005434171376	9365	Economy	62100.00
0005434151770	9365	Economy	62100.00
0005433806353	9365	Economy	62100.00
0005433786081	9365	Economy	62100.00
0005435269880	9365	Economy	62100.00
0005433786043	9365	Economy	62100.00
0005432666445	9365	Economy	62100.00
0005433786058	9365	Economy	62100.00
0005434171390	9365	Economy	62100.00
0005433763607	9365	Economy	62100.00
0005433763610	9365	Economy	62100.00
0005433806359	9365	Economy	62100.00
0005433763604	9365	Economy	62100.00
0005433806354	9365	Economy	62100.00
0005433763605	9365	Economy	62100.00
0005433786060	9365	Economy	62100.00
0005433786079	9365	Economy	62100.00
0005434171339	9365	Economy	62100.00
0005434171316	9365	Economy	62100.00
0005433786088	9365	Economy	62100.00
0005433786045	9365	Economy	62100.00
0005433806371	9365	Economy	62100.00
0005435269876	9365	Economy	62100.00
0005433786042	9365	Economy	62100.00
0005433786067	9365	Economy	62100.00
0005435269877	9365	Economy	62100.00
0005433786062	9365	Economy	62100.00
0005433763609	9365	Economy	62100.00
0005434171401	9365	Economy	62100.00
0005433786075	9365	Economy	62100.00
0005434271369	26219	Business	186200.00
0005433763472	26219	Business	186200.00
0005433763535	26219	Business	186200.00
0005433785520	26219	Business	186200.00
0005433785657	26219	Business	186200.00
0005433805972	26219	Business	186200.00
0005433785730	26219	Business	186200.00
0005435270140	26219	Business	186200.00
0005435270132	26219	Business	186200.00
0005432659736	26219	Business	186200.00
0005433785635	26219	Business	186200.00
0005433763495	26219	Business	186200.00
0005433806064	26219	Business	186200.00
0005433763492	26219	Business	186200.00
0005433806106	26219	Business	186200.00
0005433785646	26219	Business	186200.00
0005433805977	26219	Business	186200.00
0005434151788	26219	Business	186200.00
0005433785724	26219	Business	186200.00
0005435270128	26219	Business	186200.00
0005433785744	26219	Business	186200.00
0005433785703	26219	Business	186200.00
0005435270135	26219	Business	186200.00
0005435858714	26219	Business	186200.00
0005434171458	26219	Economy	68300.00
0005434171457	26219	Economy	68300.00
0005433785673	26219	Economy	68300.00
0005433763496	26219	Economy	68300.00
0005433785577	26219	Economy	62100.00
0005433785688	26219	Economy	62100.00
0005433763536	26219	Economy	62100.00
0005433763482	26219	Economy	62100.00
0005434171455	26219	Economy	62100.00
0005433763483	26219	Economy	62100.00
0005433806164	26219	Economy	62100.00
0005433785760	26219	Economy	62100.00
0005433806150	26219	Economy	62100.00
0005433763466	26219	Economy	62100.00
0005433785534	26219	Economy	62100.00
0005435270142	26219	Economy	62100.00
0005433785740	26219	Economy	62100.00
0005434171461	26219	Economy	62100.00
0005433785636	26219	Economy	62100.00
0005433806074	26219	Economy	62100.00
0005433763484	26219	Economy	62100.00
0005435270144	26219	Economy	62100.00
0005434171459	26219	Economy	62100.00
0005435270138	26219	Economy	62100.00
0005435270136	26219	Economy	62100.00
0005433763488	26219	Economy	62100.00
0005433763512	26219	Economy	62100.00
0005433785691	26219	Economy	62100.00
0005433785672	26219	Economy	62100.00
0005433806126	26219	Economy	62100.00
0005435270157	26219	Economy	62100.00
0005433763567	26219	Economy	62100.00
0005435270129	26219	Economy	62100.00
0005433785499	26219	Economy	62100.00
0005433806049	26219	Economy	62100.00
0005433785632	26219	Economy	62100.00
0005433805922	26219	Economy	62100.00
0005435270131	26219	Economy	62100.00
0005433806063	26219	Economy	62100.00
0005433785746	26219	Economy	62100.00
0005435270130	26219	Economy	62100.00
0005433763524	26219	Economy	62100.00
0005434171451	26219	Economy	62100.00
0005433806048	26219	Economy	62100.00
0005433806157	26219	Economy	62100.00
0005435270151	26219	Economy	62100.00
0005433806134	26219	Economy	62100.00
0005433805923	26219	Economy	62100.00
0005434171462	26219	Economy	62100.00
0005435270137	26219	Economy	62100.00
0005433806163	26219	Economy	62100.00
0005435270153	26219	Economy	62100.00
0005432657511	26219	Economy	62100.00
0005434171453	26219	Economy	62100.00
0005433785645	26219	Economy	62100.00
0005433806041	26219	Economy	62100.00
0005433806108	26219	Economy	62100.00
0005433785692	26219	Economy	62100.00
0005433785620	26219	Economy	62100.00
0005433806171	26219	Economy	62100.00
0005435858711	26219	Economy	62100.00
0005433806090	26219	Economy	62100.00
0005434151787	26219	Economy	62100.00
0005435858712	26219	Economy	62100.00
0005433785604	26219	Economy	62100.00
0005435270154	26219	Economy	62100.00
0005433763510	26219	Economy	62100.00
0005433806073	26219	Economy	62100.00
0005435270146	26219	Economy	62100.00
0005433805971	26219	Economy	62100.00
0005433806107	26219	Economy	62100.00
0005433785634	26219	Economy	62100.00
0005433806099	26219	Economy	62100.00
0005435270158	26219	Economy	62100.00
0005435270148	26219	Economy	62100.00
0005432666436	26219	Economy	62100.00
0005435270150	26219	Economy	68300.00
0005433806133	26219	Economy	68300.00
0005433785702	26219	Economy	62100.00
0005433785638	26219	Economy	62100.00
0005435270145	26219	Economy	68300.00
0005433763511	26219	Economy	62100.00
0005433805991	26219	Economy	62100.00
0005433806135	26219	Economy	62100.00
0005433806089	26219	Economy	62100.00
0005434171454	26219	Economy	62100.00
0005433785651	26219	Economy	62100.00
0005434269160	26219	Economy	62100.00
0005435270134	26219	Economy	62100.00
0005433785637	26219	Economy	62100.00
0005433806149	26219	Economy	62100.00
0005433785679	26219	Economy	62100.00
0005433806077	26219	Economy	62100.00
0005435270143	26219	Economy	62100.00
0005433785839	26219	Economy	62100.00
0005435270141	26219	Economy	62100.00
0005433806047	26219	Economy	62100.00
0005435270156	26219	Economy	62100.00
0005433785633	26219	Economy	62100.00
0005435858715	26219	Economy	62100.00
0005433785669	26219	Economy	62100.00
0005433806046	26219	Economy	62100.00
0005435270139	26219	Economy	62100.00
0005433806025	26219	Economy	62100.00
0005435270155	26219	Economy	62100.00
0005433785689	26219	Economy	62100.00
0005434171460	26219	Economy	62100.00
0005434171450	26219	Economy	62100.00
0005433785824	26219	Economy	62100.00
0005433805990	26219	Economy	62100.00
0005433785745	26219	Economy	62100.00
0005435270152	26219	Economy	62100.00
0005434171452	26219	Economy	62100.00
0005433763437	26219	Economy	62100.00
0005434271370	26219	Economy	62100.00
0005435270147	26219	Economy	62100.00
0005435270149	26219	Economy	62100.00
0005433805976	26219	Economy	62100.00
0005433785519	26219	Economy	62100.00
0005435270133	26219	Economy	62100.00
0005433785823	26219	Economy	62100.00
0005433785603	26219	Economy	62100.00
0005434171456	26219	Economy	62100.00
0005433785670	26219	Economy	62100.00
0005433785590	26219	Economy	62100.00
0005433806258	26219	Economy	62100.00
0005433785522	26219	Economy	62100.00
0005434269159	26219	Economy	62100.00
0005433785576	26219	Economy	62100.00
0005435858710	26219	Economy	62100.00
0005432657521	26219	Economy	62100.00
0005435858713	26219	Economy	62100.00
0005433785825	26219	Economy	62100.00
0005435135801	4904	Economy	5300.00
0005435929692	4904	Economy	5300.00
0005435929691	4904	Economy	5300.00
0005435135802	4904	Economy	5300.00
0005435135765	33003	Economy	5900.00
0005435135787	33003	Economy	5300.00
0005435929720	33003	Economy	5300.00
0005435135758	33003	Economy	5300.00
0005435929721	33003	Economy	5300.00
0005435135772	33003	Economy	5300.00
0005434218049	9460	Economy	19700.00
0005434983429	9460	Economy	17900.00
0005434218059	9460	Economy	17900.00
0005434983430	9460	Economy	17900.00
0005434983428	9460	Economy	17900.00
0005434218045	9460	Economy	17900.00
0005434218050	9460	Economy	17900.00
0005434983412	27391	Economy	19700.00
0005434983403	27391	Economy	17900.00
0005434983396	27391	Economy	17900.00
0005434983405	27391	Economy	17900.00
0005434218082	27391	Economy	17900.00
0005434983395	27391	Economy	17900.00
0005434983402	27391	Economy	17900.00
0005434218081	27391	Economy	17900.00
0005434983404	27391	Economy	17900.00
0005434983400	27391	Economy	17900.00
0005434983401	27391	Economy	17900.00
0005434983388	27391	Economy	17900.00
0005434218083	27391	Economy	17900.00
0005433961781	24252	Business	36400.00
0005433961954	24252	Business	36400.00
0005433961715	24252	Business	36400.00
0005433962013	24252	Business	36400.00
0005433962007	24252	Business	36400.00
0005433986854	24252	Business	36400.00
0005433986924	24252	Business	36400.00
0005433961901	24252	Business	36400.00
0005433986604	24252	Business	36400.00
0005433961907	24252	Business	36400.00
0005433961883	24252	Business	36400.00
0005433961854	24252	Business	36400.00
0005433961756	24252	Business	36400.00
0005433987031	24252	Economy	13400.00
0005433961950	24252	Economy	13400.00
0005433961957	24252	Economy	12100.00
0005433986851	24252	Economy	13400.00
0005433961742	24252	Economy	12100.00
0005433986793	24252	Economy	12100.00
0005433986811	24252	Economy	12100.00
0005433986974	24252	Economy	12100.00
0005433986957	24252	Economy	12100.00
0005433961971	24252	Economy	12100.00
0005433987042	24252	Economy	12100.00
0005433961902	24252	Economy	12100.00
0005433961896	24252	Economy	12100.00
0005433961994	24252	Economy	12100.00
0005433961812	24252	Economy	12100.00
0005433962029	24252	Economy	12100.00
0005433986602	24252	Economy	12100.00
0005433961656	24252	Economy	12100.00
0005433961717	24252	Economy	12100.00
0005434908903	24252	Economy	12100.00
0005433986836	24252	Economy	12100.00
0005433962012	24252	Economy	12100.00
0005433961923	24252	Economy	12100.00
0005433962028	24252	Economy	12100.00
0005433962018	24252	Economy	12100.00
0005433961915	24252	Economy	12100.00
0005433986715	24252	Economy	12100.00
0005433961975	24252	Economy	12100.00
0005433961980	24252	Economy	12100.00
0005433961654	24252	Economy	12100.00
0005433961991	24252	Economy	12100.00
0005433961949	24252	Economy	12100.00
0005433986891	24252	Economy	12100.00
0005433986787	24252	Economy	12100.00
0005433986905	24252	Economy	12100.00
0005433986777	24252	Economy	12100.00
0005433961989	24252	Economy	12100.00
0005433986812	24252	Economy	12100.00
0005433961773	24252	Economy	12100.00
0005433961714	24252	Economy	12100.00
0005433962010	24252	Economy	12100.00
0005433986606	24252	Economy	12100.00
0005433986911	24252	Economy	12100.00
0005433961878	24252	Economy	12100.00
0005433961885	24252	Economy	12100.00
0005433987105	24252	Economy	12100.00
0005433961879	24252	Economy	12100.00
0005433987188	24252	Economy	12100.00
0005433961741	24252	Economy	12100.00
0005433961916	24252	Economy	12100.00
0005433962009	24252	Economy	13400.00
0005433961899	24252	Economy	12100.00
0005433986524	24252	Economy	12100.00
0005433961757	24252	Economy	12100.00
0005433961882	24252	Economy	12100.00
0005433986913	24252	Economy	12100.00
0005433986568	24252	Economy	12100.00
0005433987187	24252	Economy	12100.00
0005433986875	24252	Economy	12100.00
0005433961965	24252	Economy	12100.00
0005433987127	24252	Economy	12100.00
0005433986917	24252	Economy	12100.00
0005433986646	24252	Economy	12100.00
0005433986567	24252	Economy	12100.00
0005433986776	24252	Economy	12100.00
0005433961904	24252	Economy	12100.00
0005433961718	24252	Economy	12100.00
0005433962008	24252	Economy	12100.00
0005433961703	24252	Economy	12100.00
0005433961884	24252	Economy	12100.00
0005433961877	24252	Economy	12100.00
0005433961979	24252	Economy	12100.00
0005433961881	24252	Economy	12100.00
0005433961988	24252	Economy	12100.00
0005433986700	24252	Economy	12100.00
0005433961782	24252	Economy	12100.00
0005433962020	24252	Economy	12100.00
0005433986716	24252	Economy	12100.00
0005433986918	24252	Economy	12100.00
0005433986782	24252	Economy	12100.00
0005433986522	24252	Economy	12100.00
0005433961851	24252	Economy	12100.00
0005433961833	24252	Economy	12100.00
0005433986603	24252	Economy	12100.00
0005433962016	24252	Economy	12100.00
0005433986816	24252	Economy	12100.00
0005433986692	24252	Economy	12100.00
0005433961970	24252	Economy	12100.00
0005433987000	24252	Economy	12100.00
0005433987032	24252	Economy	12100.00
0005433986834	24252	Economy	12100.00
0005433962017	24252	Economy	12100.00
0005433962026	24252	Economy	12100.00
0005433961811	24252	Economy	12100.00
0005433962493	25958	Business	36400.00
0005433962510	25958	Business	36400.00
0005433962466	25958	Business	36400.00
0005433962502	25958	Business	36400.00
0005433987265	25958	Business	36400.00
0005433962474	25958	Business	36400.00
0005433987263	25958	Business	36400.00
0005433962476	25958	Business	36400.00
0005433962486	25958	Business	36400.00
0005433987254	25958	Business	36400.00
0005433987257	25958	Business	36400.00
0005433962458	25958	Business	36400.00
0005433962468	25958	Business	36400.00
0005433987250	25958	Business	36400.00
0005433987260	25958	Business	36400.00
0005433962464	25958	Business	36400.00
0005433962479	25958	Business	36400.00
0005433962507	25958	Economy	13400.00
0005433962516	25958	Economy	13400.00
0005433962505	25958	Economy	12100.00
0005433987278	25958	Economy	12100.00
0005433962488	25958	Economy	12100.00
0005433962508	25958	Economy	12100.00
0005433987249	25958	Economy	12100.00
0005433962495	25958	Economy	12100.00
0005433962478	25958	Economy	12100.00
0005433987245	25958	Economy	12100.00
0005433962480	25958	Economy	12100.00
0005433962501	25958	Economy	12100.00
0005433962459	25958	Economy	12100.00
0005433987242	25958	Economy	12100.00
0005433987252	25958	Economy	12100.00
0005433962469	25958	Economy	12100.00
0005433962506	25958	Economy	12100.00
0005433987248	25958	Economy	12100.00
0005433962461	25958	Economy	12100.00
0005433962497	25958	Economy	12100.00
0005433962471	25958	Economy	12100.00
0005433962484	25958	Economy	12100.00
0005433987256	25958	Economy	12100.00
0005433962472	25958	Economy	12100.00
0005433962492	25958	Economy	12100.00
0005433962475	25958	Economy	12100.00
0005433962462	25958	Economy	12100.00
0005433987275	25958	Economy	12100.00
0005433962511	25958	Economy	12100.00
0005433987272	25958	Economy	12100.00
0005433987268	25958	Economy	12100.00
0005433987276	25958	Economy	12100.00
0005433962499	25958	Economy	12100.00
0005433962512	25958	Economy	12100.00
0005433962503	25958	Economy	12100.00
0005433962467	25958	Economy	12100.00
0005433987274	25958	Economy	12100.00
0005433987277	25958	Economy	12100.00
0005433962481	25958	Economy	12100.00
0005433987266	25958	Economy	13400.00
0005433987271	25958	Economy	12100.00
0005433962500	25958	Economy	12100.00
0005433987246	25958	Economy	12100.00
0005433962491	25958	Economy	12100.00
0005433987251	25958	Economy	12100.00
0005433987269	25958	Economy	12100.00
0005433987261	25958	Economy	12100.00
0005433962518	25958	Economy	12100.00
0005433987244	25958	Economy	12100.00
0005433987267	25958	Economy	12100.00
0005433962477	25958	Economy	12100.00
0005433962509	25958	Economy	12100.00
0005433962470	25958	Economy	12100.00
0005433962482	25958	Economy	12100.00
0005433962504	25958	Economy	12100.00
0005433962490	25958	Economy	12100.00
0005433962515	25958	Economy	12100.00
0005433962485	25958	Economy	12100.00
0005433987262	25958	Economy	12100.00
0005433962517	25958	Economy	12100.00
0005433962460	25958	Economy	12100.00
0005433962473	25958	Economy	12100.00
0005433962463	25958	Economy	12100.00
0005433962494	25958	Economy	12100.00
0005433987258	25958	Economy	12100.00
0005433962514	25958	Economy	12100.00
0005433987255	25958	Economy	12100.00
0005433962519	25958	Economy	12100.00
0005433962456	25958	Economy	12100.00
0005433987247	25958	Economy	12100.00
0005433987270	25958	Economy	12100.00
0005433987259	25958	Economy	12100.00
0005433962465	25958	Economy	12100.00
0005433962513	25958	Economy	12100.00
0005433987243	25958	Economy	12100.00
0005433962487	25958	Economy	12100.00
0005433987264	25958	Economy	12100.00
0005433987241	25958	Economy	12100.00
0005433962457	25958	Economy	12100.00
0005433987273	25958	Economy	12100.00
0005433962483	25958	Economy	12100.00
0005433962496	25958	Economy	12100.00
0005433962489	25958	Economy	12100.00
0005433987253	25958	Economy	12100.00
0005433962498	25958	Economy	12100.00
0005434481022	976	Economy	25400.00
0005433166179	976	Economy	23100.00
0005433166212	976	Economy	23100.00
0005433166148	976	Economy	23100.00
0005434481023	976	Economy	23100.00
0005434481015	976	Economy	23100.00
0005432269573	976	Economy	23100.00
0005434481016	976	Economy	23100.00
0005434481024	976	Economy	23100.00
0005433166145	976	Economy	23100.00
0005434481021	976	Economy	23100.00
0005434481025	976	Economy	23100.00
0005433166162	976	Economy	23100.00
0005434481017	976	Economy	23100.00
0005433166185	976	Economy	23100.00
0005434481020	976	Economy	23100.00
0005434481018	976	Economy	23100.00
0005433166141	976	Economy	23100.00
0005433166173	976	Economy	23100.00
0005434481019	976	Economy	23100.00
0005433166186	976	Economy	23100.00
0005433166161	976	Economy	23100.00
0005433166211	976	Economy	23100.00
0005434481014	976	Economy	23100.00
0005434480780	16604	Economy	25400.00
0005434480793	16604	Economy	25400.00
0005434480851	16604	Economy	25400.00
0005434480860	16604	Economy	25400.00
0005434480839	16604	Economy	23100.00
0005434480872	16604	Economy	23100.00
0005434480798	16604	Economy	23100.00
0005434480864	16604	Economy	23100.00
0005434480799	16604	Economy	23100.00
0005434480728	16604	Economy	23100.00
0005434480873	16604	Economy	23100.00
0005434480838	16604	Economy	23100.00
0005433166275	16604	Economy	23100.00
0005433166270	16604	Economy	23100.00
0005434480893	16604	Economy	23100.00
0005434480879	16604	Economy	23100.00
0005433166273	16604	Economy	23100.00
0005434480783	16604	Economy	23100.00
0005434480765	16604	Economy	23100.00
0005433166271	16604	Economy	23100.00
0005434480809	16604	Economy	23100.00
0005433166267	16604	Economy	23100.00
0005434480826	16604	Economy	23100.00
0005434480813	16604	Economy	23100.00
0005433166269	16604	Economy	23100.00
0005433166274	16604	Economy	23100.00
0005434480736	16604	Economy	23100.00
0005434480729	16604	Economy	23100.00
0005434480910	16604	Economy	23100.00
0005434480812	16604	Economy	23100.00
0005433166272	16604	Economy	23100.00
0005433166268	16604	Economy	23100.00
0005434480775	16604	Economy	23100.00
0005434480865	16604	Economy	23100.00
0005434480816	16604	Economy	23100.00
0005435142942	10328	Economy	17000.00
0005435150411	10328	Economy	17000.00
0005435150407	10328	Economy	17000.00
0005435386695	10328	Economy	15400.00
0005435150402	10328	Economy	15400.00
0005435150413	10328	Economy	15400.00
0005435386682	10328	Economy	15400.00
0005435142935	10328	Economy	15400.00
0005435150403	10328	Economy	15400.00
0005435386712	10328	Economy	15400.00
0005435386692	10328	Economy	15400.00
0005435386689	10328	Economy	15400.00
0005435386675	10328	Economy	15400.00
0005435150406	10328	Economy	15400.00
0005435150412	10328	Economy	15400.00
0005433289993	10328	Economy	15400.00
0005435150405	10328	Economy	15400.00
0005435150408	10328	Economy	15400.00
0005435386702	10328	Economy	15400.00
0005433289992	10328	Economy	15400.00
0005435386696	10328	Economy	15400.00
0005435142934	10328	Economy	15400.00
0005435142936	10328	Economy	15400.00
0005435142938	10328	Economy	15400.00
0005435150404	10328	Economy	15400.00
0005435142939	10328	Economy	15400.00
0005435142940	10328	Economy	15400.00
0005435142937	10328	Economy	15400.00
0005435142941	10328	Economy	15400.00
0005435386699	10328	Economy	15400.00
0005435150410	10328	Economy	15400.00
0005435150409	10328	Economy	15400.00
0005435386749	21960	Economy	17000.00
0005435150299	21960	Economy	17000.00
0005433290057	21960	Economy	17000.00
0005435150276	21960	Economy	17000.00
0005435142829	21960	Economy	15400.00
0005435142854	21960	Economy	15400.00
0005435142788	21960	Economy	15400.00
0005435150309	21960	Economy	15400.00
0005435150267	21960	Economy	15400.00
0005435150286	21960	Economy	15400.00
0005435142808	21960	Economy	15400.00
0005435142812	21960	Economy	15400.00
0005435142839	21960	Economy	15400.00
0005435150270	21960	Economy	15400.00
0005435150349	21960	Economy	15400.00
0005435142840	21960	Economy	15400.00
0005433290056	21960	Economy	15400.00
0005435150307	21960	Economy	15400.00
0005435142873	21960	Economy	15400.00
0005433290055	21960	Economy	15400.00
0005435386748	21960	Economy	15400.00
0005435386751	21960	Economy	15400.00
0005435150280	21960	Economy	15400.00
0005433290058	21960	Economy	15400.00
0005435386752	21960	Economy	15400.00
0005435150344	21960	Economy	15400.00
0005435150310	21960	Economy	15400.00
0005435386750	21960	Economy	15400.00
0005435386747	21960	Economy	15400.00
0005435142845	21960	Economy	15400.00
0005435150269	21960	Economy	15400.00
0005435529624	11213	Business	57200.00
0005435529647	11213	Business	57200.00
0005434573733	11213	Business	57200.00
0005435502811	11213	Business	57200.00
0005435319752	11213	Business	57200.00
0005435529627	11213	Business	57200.00
0005435502755	11213	Business	57200.00
0005435319735	11213	Business	57200.00
0005435529753	11213	Business	57200.00
0005435529692	11213	Business	57200.00
0005435529739	11213	Economy	19100.00
0005434573735	11213	Economy	19100.00
0005435545875	11213	Economy	19100.00
0005435502778	11213	Economy	19100.00
0005435502851	11213	Economy	19100.00
0005435502676	11213	Economy	19100.00
0005435529704	11213	Economy	19100.00
0005434573741	11213	Economy	21000.00
0005435545902	11213	Economy	21000.00
0005435529660	11213	Economy	21000.00
0005435319724	11213	Economy	19100.00
0005435529743	11213	Economy	19100.00
0005435545868	11213	Economy	19100.00
0005435319736	11213	Economy	19100.00
0005435529742	11213	Economy	19100.00
0005434573734	11213	Economy	19100.00
0005435502707	11213	Economy	19100.00
0005435529670	11213	Economy	19100.00
0005435319751	11213	Economy	19100.00
0005435529646	11213	Economy	19100.00
0005435502689	11213	Economy	19100.00
0005435502795	11213	Economy	19100.00
0005435529705	11213	Economy	19100.00
0005435502737	11213	Economy	19100.00
0005435529626	11213	Economy	19100.00
0005435319741	11213	Economy	19100.00
0005434573732	11213	Economy	19100.00
0005435319743	11213	Economy	19100.00
0005435502835	11213	Economy	19100.00
0005434573736	11213	Economy	19100.00
0005434573742	11213	Economy	19100.00
0005435319750	11213	Economy	19100.00
0005435502805	11213	Economy	19100.00
0005434573739	11213	Economy	19100.00
0005434573743	11213	Economy	19100.00
0005435529668	11213	Economy	19100.00
0005435319759	11213	Economy	19100.00
0005434573740	11213	Economy	19100.00
0005434573738	11213	Economy	19100.00
0005435529691	11213	Economy	19100.00
0005435529733	11213	Economy	19100.00
0005435529638	11213	Economy	19100.00
0005435529661	11213	Economy	19100.00
0005435529625	11213	Economy	19100.00
0005435502836	11213	Economy	19100.00
0005435529650	11213	Economy	19100.00
0005435319742	11213	Economy	19100.00
0005435545901	11213	Economy	19100.00
0005435502740	11213	Economy	19100.00
0005435319734	11213	Economy	19100.00
0005435529690	11213	Economy	19100.00
0005435502677	11213	Economy	19100.00
0005434573744	11213	Economy	19100.00
0005435502739	11213	Economy	19100.00
0005435529740	11213	Economy	19100.00
0005435502756	11213	Economy	19100.00
0005435502806	11213	Economy	19100.00
0005435529732	11213	Economy	19100.00
0005435319723	11213	Economy	19100.00
0005434573737	11213	Economy	19100.00
0005435518411	20945	Business	57200.00
0005434573624	20945	Business	57200.00
0005435518414	20945	Business	57200.00
0005435518416	20945	Business	57200.00
0005435518418	20945	Business	57200.00
0005435508775	20945	Business	57200.00
0005434573595	20945	Business	57200.00
0005434573640	20945	Business	57200.00
0005435502919	20945	Business	57200.00
0005434573622	20945	Business	57200.00
0005434573642	20945	Business	57200.00
0005435518409	20945	Business	57200.00
0005435518419	20945	Economy	19100.00
0005435319822	20945	Economy	19100.00
0005435518412	20945	Economy	19100.00
0005434573663	20945	Economy	19100.00
0005435508779	20945	Economy	19100.00
0005434573631	20945	Economy	21000.00
0005435518410	20945	Economy	21000.00
0005435508786	20945	Economy	21000.00
0005435502920	20945	Economy	21000.00
0005435508774	20945	Economy	21000.00
0005435502905	20945	Economy	19100.00
0005435502908	20945	Economy	19100.00
0005435502921	20945	Economy	19100.00
0005434573589	20945	Economy	19100.00
0005432291997	20945	Economy	19100.00
0005434573628	20945	Economy	19100.00
0005435502911	20945	Economy	19100.00
0005435502910	20945	Economy	19100.00
0005435518415	20945	Economy	19100.00
0005435518420	20945	Economy	19100.00
0005434573623	20945	Economy	19100.00
0005435502912	20945	Economy	19100.00
0005435502922	20945	Economy	19100.00
0005435508784	20945	Economy	19100.00
0005435518422	20945	Economy	19100.00
0005435502914	20945	Economy	19100.00
0005434573582	20945	Economy	19100.00
0005434573630	20945	Economy	19100.00
0005435502909	20945	Economy	19100.00
0005434573591	20945	Economy	19100.00
0005435518413	20945	Economy	19100.00
0005435518421	20945	Economy	19100.00
0005435518417	20945	Economy	19100.00
0005435508772	20945	Economy	19100.00
0005434573669	20945	Economy	19100.00
0005432291998	20945	Economy	19100.00
0005434573599	20945	Economy	19100.00
0005435319821	20945	Economy	19100.00
0005435502916	20945	Economy	19100.00
0005435502913	20945	Economy	19100.00
0005434573598	20945	Economy	19100.00
0005434573635	20945	Economy	19100.00
0005434573590	20945	Economy	19100.00
0005435508777	20945	Economy	19100.00
0005434573643	20945	Economy	19100.00
0005435508787	20945	Economy	19100.00
0005434573625	20945	Economy	19100.00
0005435508773	20945	Economy	19100.00
0005434573585	20945	Economy	19100.00
0005434573641	20945	Economy	19100.00
0005435502915	20945	Economy	19100.00
0005435508780	20945	Economy	19100.00
0005435508776	20945	Economy	19100.00
0005435502917	20945	Economy	19100.00
0005434573592	20945	Economy	19100.00
0005435508782	20945	Economy	19100.00
0005435508783	20945	Economy	19100.00
0005435508781	20945	Economy	19100.00
0005435508785	20945	Economy	19100.00
0005434573654	20945	Economy	19100.00
0005435502904	20945	Economy	19100.00
0005435502906	20945	Economy	19100.00
0005435508778	20945	Economy	19100.00
0005435502907	20945	Economy	19100.00
0005434573560	20945	Economy	19100.00
0005435502918	20945	Economy	19100.00
0005434573629	20945	Economy	19100.00
0005433927489	24314	Economy	18800.00
0005433683409	24314	Economy	17100.00
0005433927491	24314	Economy	17100.00
0005433683412	24314	Economy	17100.00
0005433683413	24314	Economy	17100.00
0005433927499	24314	Economy	17100.00
0005433927490	24314	Economy	17100.00
0005433927477	24314	Economy	17100.00
0005433683411	24314	Economy	17100.00
0005433927494	24314	Economy	17100.00
0005433683410	24314	Economy	17100.00
0005433683387	29285	Economy	17100.00
0005433683390	29285	Economy	17100.00
0005433683397	29285	Economy	17100.00
0005433683392	29285	Economy	17100.00
0005433683406	29285	Economy	17100.00
0005433927512	29285	Economy	17100.00
0005433683405	29285	Economy	17100.00
0005433683391	29285	Economy	17100.00
0005433683396	29285	Economy	17100.00
0005433927513	29285	Economy	17100.00
0005433927510	29285	Economy	17100.00
0005433683389	29285	Economy	17100.00
0005433683395	29285	Economy	17100.00
0005433683381	29285	Economy	17100.00
0005433927511	29285	Economy	17100.00
0005433683394	29285	Economy	17100.00
0005433683388	29285	Economy	17100.00
0005432693511	3023	Business	10300.00
0005432693670	3023	Business	10300.00
0005432693596	3023	Business	10300.00
0005432693574	3023	Economy	3400.00
0005432693669	3023	Economy	3400.00
0005432693590	3023	Economy	3400.00
0005432693639	3023	Economy	3800.00
0005432693663	3023	Economy	3800.00
0005432693671	3023	Economy	3400.00
0005432693674	3023	Economy	3400.00
0005432693619	3023	Economy	3400.00
0005432693531	3023	Economy	3400.00
0005432693786	3023	Economy	3400.00
0005432693575	3023	Economy	3400.00
0005432693673	3023	Economy	3400.00
0005432693613	3023	Economy	3400.00
0005432693595	3023	Economy	3400.00
0005432693724	3023	Economy	3400.00
0005432693609	3023	Economy	3400.00
0005432693672	3023	Economy	3400.00
0005432693764	3023	Economy	3400.00
0005432693741	3023	Economy	3400.00
0005432693657	3023	Economy	3400.00
0005432693710	3023	Economy	3400.00
0005432693664	3023	Economy	3400.00
0005432693725	3023	Economy	3400.00
0005432693626	3023	Economy	3400.00
0005432693765	3023	Economy	3400.00
0005432693610	3023	Economy	3400.00
0005432693640	3023	Economy	3400.00
0005432693742	3023	Economy	3400.00
0005432693686	3023	Economy	3400.00
0005432693543	3023	Economy	3400.00
0005432693785	3023	Economy	3400.00
0005432693614	3023	Economy	3400.00
0005432693662	3023	Economy	3400.00
0005432693642	3023	Economy	3400.00
0005432217857	3024	Business	10300.00
0005433124254	3024	Business	10300.00
0005432881123	3024	Business	10300.00
0005432881068	3024	Business	10300.00
0005432881158	3024	Business	10300.00
0005433124382	3024	Business	10300.00
0005432881106	3024	Business	10300.00
0005432707480	3024	Economy	3400.00
0005432881124	3024	Economy	3400.00
0005432707473	3024	Economy	3400.00
0005432707476	3024	Economy	3400.00
0005433124322	3024	Economy	3400.00
0005433124251	3024	Economy	3800.00
0005432881143	3024	Economy	3800.00
0005433124302	3024	Economy	3400.00
0005432881142	3024	Economy	3400.00
0005433124253	3024	Economy	3400.00
0005432881131	3024	Economy	3400.00
0005433124355	3024	Economy	3400.00
0005432881074	3024	Economy	3400.00
0005432881092	3024	Economy	3400.00
0005433124362	3024	Economy	3400.00
0005432707483	3024	Economy	3400.00
0005432707477	3024	Economy	3400.00
0005432881100	3024	Economy	3400.00
0005432881093	3024	Economy	3400.00
0005433124342	3024	Economy	3400.00
0005433124347	3024	Economy	3400.00
0005432881144	3024	Economy	3400.00
0005432881094	3024	Economy	3400.00
0005432881125	3024	Economy	3400.00
0005432707478	3024	Economy	3400.00
0005433194914	3024	Economy	3400.00
0005433124267	3024	Economy	3400.00
0005433124335	3024	Economy	3400.00
0005432707484	3024	Economy	3400.00
0005432707474	3024	Economy	3400.00
0005432707475	3024	Economy	3400.00
0005432881099	3024	Economy	3400.00
0005433124323	3024	Economy	3400.00
0005433124356	3024	Economy	3400.00
0005432707472	3024	Economy	3400.00
0005433124224	3024	Economy	3400.00
0005432707479	3024	Economy	3400.00
0005432707482	3024	Economy	3400.00
0005433124340	3024	Economy	3400.00
0005432881108	3024	Economy	3400.00
0005433124321	3024	Economy	3400.00
0005432881101	3024	Economy	3400.00
0005432881069	3024	Economy	3400.00
0005432707481	3024	Economy	3400.00
0005432881107	3024	Economy	3400.00
0005433124385	3024	Economy	3400.00
0005433124346	3024	Economy	3400.00
0005432693926	29956	Business	10300.00
0005432707211	29956	Business	10300.00
0005432707289	29956	Business	10300.00
0005433124490	29956	Business	10300.00
0005432881230	29956	Business	10300.00
0005432693932	29956	Business	10300.00
0005432707321	29956	Business	10300.00
0005433194968	29956	Business	10300.00
0005432707327	29956	Business	10300.00
0005432693936	29956	Business	10300.00
0005432707387	29956	Business	10300.00
0005433124501	29956	Business	10300.00
0005434300238	29956	Economy	3400.00
0005432881223	29956	Economy	3400.00
0005432693937	29956	Economy	3400.00
0005433124504	29956	Economy	3400.00
0005433194961	29956	Economy	3400.00
0005432693938	29956	Economy	3400.00
0005433124493	29956	Economy	3400.00
0005433124506	29956	Economy	3400.00
0005432707188	29956	Economy	3400.00
0005432693939	29956	Economy	3400.00
0005432707370	29956	Economy	3800.00
0005432881219	29956	Economy	3800.00
0005432693931	29956	Economy	3800.00
0005432707324	29956	Economy	3800.00
0005432707318	29956	Economy	3800.00
0005432707288	29956	Economy	3400.00
0005433194966	29956	Economy	3400.00
0005432707302	29956	Economy	3400.00
0005432693928	29956	Economy	3400.00
0005433124494	29956	Economy	3400.00
0005433124492	29956	Economy	3400.00
0005433194964	29956	Economy	3400.00
0005432693943	29956	Economy	3400.00
0005432881229	29956	Economy	3400.00
0005433194972	29956	Economy	3400.00
0005432707409	29956	Economy	3400.00
0005433124496	29956	Economy	3400.00
0005432707301	29956	Economy	3400.00
0005432693935	29956	Economy	3400.00
0005432707252	29956	Economy	3400.00
0005433124499	29956	Economy	3400.00
0005432707208	29956	Economy	3400.00
0005433124505	29956	Economy	3400.00
0005433194963	29956	Economy	3400.00
0005433194971	29956	Economy	3400.00
0005433194967	29956	Economy	3400.00
0005433194974	29956	Economy	3400.00
0005432707271	29956	Economy	3400.00
0005433124491	29956	Economy	3400.00
0005432693927	29956	Economy	3400.00
0005432707272	29956	Economy	3400.00
0005433194962	29956	Economy	3400.00
0005433194970	29956	Economy	3400.00
0005432707315	29956	Economy	3400.00
0005432707365	29956	Economy	3400.00
0005433124507	29956	Economy	3400.00
0005434300237	29956	Economy	3400.00
0005433124503	29956	Economy	3400.00
0005433124502	29956	Economy	3400.00
0005432881226	29956	Economy	3400.00
0005432707220	29956	Economy	3400.00
0005432693930	29956	Economy	3400.00
0005432693941	29956	Economy	3400.00
0005434300235	29956	Economy	3400.00
0005432881221	29956	Economy	3400.00
0005432881225	29956	Economy	3400.00
0005432881224	29956	Economy	3400.00
0005432693929	29956	Economy	3400.00
0005432881227	29956	Economy	3400.00
0005434300234	29956	Economy	3400.00
0005432881231	29956	Economy	3400.00
0005432707332	29956	Economy	3400.00
0005432707347	29956	Economy	3400.00
0005432693933	29956	Economy	3400.00
0005432693934	29956	Economy	3400.00
0005432881218	29956	Economy	3400.00
0005432707328	29956	Economy	3400.00
0005432881228	29956	Economy	3400.00
0005432881222	29956	Economy	3400.00
0005433124500	29956	Economy	3400.00
0005432881220	29956	Economy	3400.00
0005432693940	29956	Economy	3400.00
0005433194973	29956	Economy	3400.00
0005433124497	29956	Economy	3400.00
0005433124495	29956	Economy	3400.00
0005433194969	29956	Economy	3400.00
0005433124498	29956	Economy	3400.00
0005433194965	29956	Economy	3400.00
0005434300236	29956	Economy	3400.00
0005433194975	29956	Economy	3400.00
0005432707251	29956	Economy	3400.00
0005432693942	29956	Economy	3400.00
0005432707209	29956	Economy	3400.00
0005432693925	29956	Economy	3400.00
0005432707189	29956	Economy	3400.00
0005434980617	23706	Economy	4000.00
0005434980602	23706	Economy	4000.00
0005434980596	23706	Economy	4000.00
0005434980605	23706	Economy	3600.00
0005434980607	23706	Economy	3600.00
0005434980604	23706	Economy	3600.00
0005434989059	23706	Economy	3600.00
0005434989057	23706	Economy	3600.00
0005434980598	23706	Economy	3600.00
0005434989058	23706	Economy	3600.00
0005434980594	23706	Economy	3600.00
0005434989048	23706	Economy	3600.00
0005434980600	23706	Economy	3600.00
0005434980609	23706	Economy	3600.00
0005434980616	23706	Economy	3600.00
0005434980610	23706	Economy	3600.00
0005434989054	23706	Economy	3600.00
0005434980613	23706	Economy	3600.00
0005434980612	23706	Economy	3600.00
0005434980615	23706	Economy	3600.00
0005434989050	23706	Economy	3600.00
0005434980608	23706	Economy	3600.00
0005434989049	23706	Economy	3600.00
0005434980601	23706	Economy	3600.00
0005434989051	23706	Economy	3600.00
0005434989052	23706	Economy	3600.00
0005434989056	23706	Economy	3600.00
0005434980603	23706	Economy	3600.00
0005434980599	23706	Economy	3600.00
0005434980597	23706	Economy	3600.00
0005434989053	23706	Economy	3600.00
0005434980606	23706	Economy	3600.00
0005434980614	23706	Economy	3600.00
0005434980595	23706	Economy	3600.00
0005434980611	23706	Economy	3600.00
0005434989055	23706	Economy	3600.00
0005434980239	27572	Economy	4000.00
0005434980342	27572	Economy	4000.00
0005434980330	27572	Economy	4000.00
0005434980459	27572	Economy	3600.00
0005434988941	27572	Economy	3600.00
0005434980472	27572	Economy	3600.00
0005434980360	27572	Economy	3600.00
0005434988943	27572	Economy	3600.00
0005434980301	27572	Economy	3600.00
0005434980367	27572	Economy	3600.00
0005434988944	27572	Economy	3600.00
0005434980247	27572	Economy	3600.00
0005434980392	27572	Economy	3600.00
0005434980329	27572	Economy	3600.00
0005434980369	27572	Economy	3600.00
0005434988925	27572	Economy	3600.00
0005434980368	27572	Economy	3600.00
0005434988894	27572	Economy	3600.00
0005434980388	27572	Economy	3600.00
0005434988945	27572	Economy	3600.00
0005434980428	27572	Economy	3600.00
0005434980419	27572	Economy	3600.00
0005434980425	27572	Economy	3600.00
0005434980429	27572	Economy	3600.00
0005434980366	27572	Economy	3600.00
0005434980350	27572	Economy	3600.00
0005434980281	27572	Economy	3600.00
0005434980427	27572	Economy	3600.00
0005434980302	27572	Economy	3600.00
0005434980299	27572	Economy	3600.00
0005434988942	27572	Economy	3600.00
0005434980353	27572	Economy	3600.00
0005434988949	27572	Economy	3600.00
0005434980370	27572	Economy	3600.00
0005434980447	27572	Economy	3600.00
0005434980371	27572	Economy	3600.00
0005434980341	27572	Economy	3600.00
0005434988916	27572	Economy	3600.00
0005434980396	27572	Economy	3600.00
0005434980300	27572	Economy	3600.00
0005434988948	27572	Economy	3600.00
0005434302903	10270	Economy	21600.00
0005433113573	10270	Economy	19700.00
0005433113580	10270	Economy	19700.00
0005434302575	10270	Economy	19700.00
0005433113574	10270	Economy	19700.00
0005433111543	10270	Economy	19700.00
0005433111535	10270	Economy	19700.00
0005434302902	10270	Economy	19700.00
0005434302576	10270	Economy	19700.00
0005434302573	10270	Economy	19700.00
0005434302901	10270	Economy	19700.00
0005434302574	10270	Economy	19700.00
0005433113576	10270	Economy	19700.00
0005434302546	19634	Economy	19700.00
0005433113595	19634	Economy	19700.00
0005434302553	19634	Economy	19700.00
0005433113596	19634	Economy	19700.00
0005434302545	19634	Economy	19700.00
0005434302539	19634	Economy	19700.00
0005434302538	19634	Economy	19700.00
0005435070500	3564	Business	26900.00
0005435925546	3564	Business	26900.00
0005435950328	3564	Business	26900.00
0005435070518	3564	Business	26900.00
0005435925607	3564	Business	26900.00
0005435950323	3564	Business	26900.00
0005435939932	3564	Economy	9000.00
0005435070508	3564	Economy	9900.00
0005435950324	3564	Economy	9000.00
0005435070512	3564	Economy	9000.00
0005435925551	3564	Economy	9000.00
0005435070507	3564	Economy	9000.00
0005435070517	3564	Economy	9000.00
0005435925596	3564	Economy	9000.00
0005435070516	3564	Economy	9000.00
0005435070497	3564	Economy	9000.00
0005435070499	3564	Economy	9000.00
0005435070503	3564	Economy	9000.00
0005435070504	3564	Economy	9000.00
0005435719115	3564	Economy	9000.00
0005435070501	3564	Economy	9000.00
0005435719114	3564	Economy	9000.00
0005435070515	3564	Economy	9000.00
0005435070513	3564	Economy	9000.00
0005435719116	3564	Economy	9000.00
0005435925534	3564	Economy	9000.00
0005435070510	3564	Economy	9000.00
0005435070509	3564	Economy	9000.00
0005435950325	3564	Economy	9000.00
0005435950321	3564	Economy	9000.00
0005435070514	3564	Economy	9000.00
0005435950326	3564	Economy	9000.00
0005435070506	3564	Economy	9000.00
0005435950327	3564	Economy	9000.00
0005435070511	3564	Economy	9000.00
0005435950322	3564	Economy	9000.00
0005435925566	3564	Economy	9000.00
0005435719117	3564	Economy	9000.00
0005435070496	3564	Economy	9000.00
0005435070505	3564	Economy	9000.00
0005435925550	3564	Economy	9000.00
0005435070502	3564	Economy	9000.00
0005435070498	3564	Economy	9000.00
0005435925538	3564	Economy	9000.00
0005435925563	3564	Economy	9000.00
0005435925547	3564	Economy	9000.00
0005435719015	15326	Business	26900.00
0005435718988	15326	Business	26900.00
0005435718995	15326	Business	26900.00
0005435070044	15326	Business	26900.00
0005435070148	15326	Business	26900.00
0005435718992	15326	Business	26900.00
0005435070171	15326	Business	26900.00
0005435070124	15326	Business	26900.00
0005435069977	15326	Business	26900.00
0005435070163	15326	Business	26900.00
0005435719031	15326	Business	26900.00
0005435719009	15326	Business	26900.00
0005435070275	15326	Economy	9000.00
0005435070136	15326	Economy	9000.00
0005435070116	15326	Economy	9000.00
0005435070047	15326	Economy	9000.00
0005435070225	15326	Economy	9000.00
0005435718985	15326	Economy	9000.00
0005435070099	15326	Economy	9000.00
0005435718997	15326	Economy	9000.00
0005435718989	15326	Economy	9000.00
0005435719034	15326	Economy	9000.00
0005435069912	15326	Economy	9900.00
0005435069994	15326	Economy	9900.00
0005435719028	15326	Economy	9900.00
0005435070156	15326	Economy	9900.00
0005435069998	15326	Economy	9900.00
0005435069831	15326	Economy	9000.00
0005435719025	15326	Economy	9000.00
0005435719010	15326	Economy	9000.00
0005435070132	15326	Economy	9000.00
0005435070039	15326	Economy	9000.00
0005435718996	15326	Economy	9000.00
0005435070051	15326	Economy	9000.00
0005435070043	15326	Economy	9000.00
0005435070130	15326	Economy	9000.00
0005435070123	15326	Economy	9000.00
0005435070220	15326	Economy	9000.00
0005435070094	15326	Economy	9000.00
0005435719029	15326	Economy	9000.00
0005435069913	15326	Economy	9000.00
0005435070049	15326	Economy	9000.00
0005435070207	15326	Economy	9000.00
0005435070270	15326	Economy	9000.00
0005435070208	15326	Economy	9000.00
0005435718993	15326	Economy	9000.00
0005435719006	15326	Economy	9000.00
0005435719018	15326	Economy	9000.00
0005435719011	15326	Economy	9000.00
0005435719008	15326	Economy	9000.00
0005435070104	15326	Economy	9000.00
0005435070134	15326	Economy	9000.00
0005435719000	15326	Economy	9000.00
0005435718990	15326	Economy	9000.00
0005435070009	15326	Economy	9000.00
0005435070071	15326	Economy	9000.00
0005435070150	15326	Economy	9000.00
0005435070107	15326	Economy	9000.00
0005435718999	15326	Economy	9000.00
0005435070013	15326	Economy	9000.00
0005435069862	15326	Economy	9000.00
0005435718991	15326	Economy	9000.00
0005435070095	15326	Economy	9000.00
0005435719024	15326	Economy	9000.00
0005435718987	15326	Economy	9000.00
0005435070075	15326	Economy	9000.00
0005435070151	15326	Economy	9000.00
0005435719017	15326	Economy	9000.00
0005435719022	15326	Economy	9000.00
0005435070106	15326	Economy	9000.00
0005435719012	15326	Economy	9000.00
0005435719005	15326	Economy	9000.00
0005435070077	15326	Economy	9000.00
0005435719016	15326	Economy	9000.00
0005435719001	15326	Economy	9000.00
0005435719019	15326	Economy	9000.00
0005435070135	15326	Economy	9000.00
0005435718994	15326	Economy	9000.00
0005435070050	15326	Economy	9000.00
0005435719004	15326	Economy	9000.00
0005435070086	15326	Economy	9000.00
0005435070157	15326	Economy	9000.00
0005435719002	15326	Economy	9000.00
0005435070274	15326	Economy	9000.00
0005435070103	15326	Economy	9000.00
0005435070211	15326	Economy	9000.00
0005435719023	15326	Economy	9000.00
0005435719007	15326	Economy	9000.00
0005435070098	15326	Economy	9000.00
0005435070213	15326	Economy	9000.00
0005435718998	15326	Economy	9000.00
0005435719027	15326	Economy	9000.00
0005435719030	15326	Economy	9000.00
0005435070038	15326	Economy	9000.00
0005435070078	15326	Economy	9000.00
0005435070245	15326	Economy	9000.00
0005435069993	15326	Economy	9000.00
0005432660878	18151	Economy	5900.00
0005432660879	18151	Economy	5900.00
0005432660880	18151	Economy	5900.00
0005432660877	18151	Economy	5900.00
0005432667488	26346	Economy	5900.00
0005432664182	26346	Economy	5900.00
0005432664177	26346	Economy	5900.00
0005432667497	26346	Economy	5900.00
0005432664178	26346	Economy	5900.00
0005432667496	26346	Economy	5900.00
0005432664176	26346	Economy	5900.00
0005433103158	70	Business	20000.00
0005433103282	70	Business	20000.00
0005433103225	70	Business	20000.00
0005432920233	70	Business	20000.00
0005433103167	70	Business	20000.00
0005432920263	70	Business	20000.00
0005432920241	70	Business	20000.00
0005432901996	70	Business	20000.00
0005433103318	70	Business	20000.00
0005433103226	70	Business	20000.00
0005433103281	70	Business	20000.00
0005432901995	70	Business	20000.00
0005432920290	70	Business	20000.00
0005433103251	70	Business	20000.00
0005432677652	70	Business	20000.00
0005432392044	70	Business	20000.00
0005433103045	70	Business	20000.00
0005433103241	70	Business	20000.00
0005432901911	70	Business	20000.00
0005432920326	70	Business	20000.00
0005433103174	70	Economy	7300.00
0005432920268	70	Economy	7300.00
0005433103198	70	Economy	7300.00
0005432920299	70	Economy	7300.00
0005433103275	70	Economy	7300.00
0005432920200	70	Economy	6700.00
0005433103199	70	Economy	6700.00
0005433103209	70	Economy	6700.00
0005432920234	70	Economy	6700.00
0005433103195	70	Economy	6700.00
0005432902031	70	Economy	6700.00
0005432920286	70	Economy	6700.00
0005432392043	70	Economy	6700.00
0005433102910	70	Economy	6700.00
0005432901923	70	Economy	6700.00
0005433103112	70	Economy	6700.00
0005432920247	70	Economy	6700.00
0005433103105	70	Economy	6700.00
0005433103249	70	Economy	6700.00
0005432920333	70	Economy	6700.00
0005432901928	70	Economy	6700.00
0005433103235	70	Economy	6700.00
0005432920300	70	Economy	6700.00
0005433103071	70	Economy	6700.00
0005433103307	70	Economy	6700.00
0005433103113	70	Economy	6700.00
0005432920223	70	Economy	6700.00
0005432920327	70	Economy	6700.00
0005433103250	70	Economy	6700.00
0005433103193	70	Economy	6700.00
0005433103261	70	Economy	6700.00
0005433103135	70	Economy	6700.00
0005433103117	70	Economy	6700.00
0005433103147	70	Economy	6700.00
0005432920301	70	Economy	6700.00
0005432901866	70	Economy	6700.00
0005433103019	70	Economy	6700.00
0005433103276	70	Economy	6700.00
0005433102983	70	Economy	6700.00
0005432901998	70	Economy	6700.00
0005433103136	70	Economy	6700.00
0005433103236	70	Economy	6700.00
0005432392038	70	Economy	6700.00
0005433103119	70	Economy	6700.00
0005432157546	70	Economy	6700.00
0005432920343	70	Economy	6700.00
0005432392039	70	Economy	6700.00
0005433103159	70	Economy	6700.00
0005433103044	70	Economy	7300.00
0005433103138	70	Economy	7300.00
0005432920342	70	Economy	7300.00
0005433103316	70	Economy	7300.00
0005432392057	70	Economy	7300.00
0005432920267	70	Economy	6700.00
0005432677653	70	Economy	6700.00
0005433103238	70	Economy	7300.00
0005432901939	70	Economy	6700.00
0005432392032	70	Economy	6700.00
0005433103118	70	Economy	6700.00
0005433103258	70	Economy	6700.00
0005433103178	70	Economy	6700.00
0005432157547	70	Economy	6700.00
0005432920250	70	Economy	6700.00
0005433103242	70	Economy	6700.00
0005432902019	70	Economy	6700.00
0005433103295	70	Economy	6700.00
0005433103324	70	Economy	6700.00
0005432920278	70	Economy	6700.00
0005433103277	70	Economy	6700.00
0005433103043	70	Economy	6700.00
0005433103257	70	Economy	6700.00
0005433103320	70	Economy	6700.00
0005432392051	70	Economy	6700.00
0005433103317	70	Economy	6700.00
0005432901929	70	Economy	6700.00
0005432157545	70	Economy	6700.00
0005433103286	70	Economy	6700.00
0005433103297	70	Economy	6700.00
0005433103228	70	Economy	6700.00
0005433103133	70	Economy	6700.00
0005432901927	70	Economy	6700.00
0005433103319	70	Economy	6700.00
0005432901940	70	Economy	6700.00
0005432901924	70	Economy	6700.00
0005432920295	70	Economy	6700.00
0005433103298	70	Economy	6700.00
0005433103194	70	Economy	6700.00
0005432920344	70	Economy	6700.00
0005433103252	70	Economy	6700.00
0005432920298	70	Economy	6700.00
0005433103323	70	Economy	6700.00
0005432901962	70	Economy	6700.00
0005432392056	70	Economy	6700.00
0005432392029	70	Economy	6700.00
0005432920332	70	Economy	6700.00
0005433103134	70	Economy	6700.00
0005433103151	70	Economy	6700.00
0005432392050	70	Economy	6700.00
0005433477232	71	Business	20000.00
0005434157736	71	Business	20000.00
0005434157748	71	Business	20000.00
0005432818307	71	Business	20000.00
0005434157741	71	Business	20000.00
0005432263177	71	Business	20000.00
0005434157734	71	Business	20000.00
0005432263175	71	Business	20000.00
0005433477239	71	Business	20000.00
0005433477236	71	Business	20000.00
0005432818301	71	Business	20000.00
0005434157740	71	Business	20000.00
0005434152866	71	Business	20000.00
0005432818303	71	Business	20000.00
0005434157744	71	Business	20000.00
0005432207734	71	Business	20000.00
0005434157756	71	Business	20000.00
0005432263165	71	Economy	7300.00
0005432818299	71	Economy	7300.00
0005434157733	71	Economy	6700.00
0005432263169	71	Economy	6700.00
0005433687745	71	Economy	6700.00
0005432263184	71	Economy	6700.00
0005433477247	71	Economy	6700.00
0005433477231	71	Economy	6700.00
0005434157750	71	Economy	6700.00
0005432263180	71	Economy	6700.00
0005432263164	71	Economy	6700.00
0005434157747	71	Economy	6700.00
0005432263181	71	Economy	6700.00
0005432263167	71	Economy	6700.00
0005432263174	71	Economy	6700.00
0005432818308	71	Economy	6700.00
0005433477246	71	Economy	6700.00
0005432756915	71	Economy	6700.00
0005433477233	71	Economy	6700.00
0005432818302	71	Economy	6700.00
0005434157752	71	Economy	6700.00
0005434153580	71	Economy	6700.00
0005432289078	71	Economy	6700.00
0005432818306	71	Economy	6700.00
0005432263178	71	Economy	6700.00
0005432263171	71	Economy	6700.00
0005432289079	71	Economy	6700.00
0005432818300	71	Economy	6700.00
0005434157735	71	Economy	6700.00
0005432263176	71	Economy	6700.00
0005432753360	71	Economy	6700.00
0005434157742	71	Economy	6700.00
0005432263172	71	Economy	6700.00
0005434157739	71	Economy	6700.00
0005434157743	71	Economy	6700.00
0005434157745	71	Economy	6700.00
0005433477237	71	Economy	6700.00
0005434157746	71	Economy	7300.00
0005432263173	71	Economy	7300.00
0005432263166	71	Economy	7300.00
0005434157755	71	Economy	6700.00
0005433477245	71	Economy	6700.00
0005434157738	71	Economy	6700.00
0005432263183	71	Economy	6700.00
0005434157751	71	Economy	6700.00
0005433477248	71	Economy	6700.00
0005433477249	71	Economy	6700.00
0005433477242	71	Economy	6700.00
0005432263179	71	Economy	6700.00
0005432818298	71	Economy	6700.00
0005433477240	71	Economy	6700.00
0005432818295	71	Economy	6700.00
0005434157749	71	Economy	6700.00
0005433477241	71	Economy	6700.00
0005434153579	71	Economy	6700.00
0005433477238	71	Economy	6700.00
0005434157754	71	Economy	6700.00
0005432263186	71	Economy	6700.00
0005432207733	71	Economy	6700.00
0005433477235	71	Economy	6700.00
0005433477244	71	Economy	6700.00
0005432753361	71	Economy	6700.00
0005434153578	71	Economy	6700.00
0005432818294	71	Economy	6700.00
0005434157753	71	Economy	6700.00
0005432818293	71	Economy	6700.00
0005432263170	71	Economy	6700.00
0005433477243	71	Economy	6700.00
0005434152865	71	Economy	6700.00
0005432818297	71	Economy	6700.00
0005432263163	71	Economy	6700.00
0005432818304	71	Economy	6700.00
0005432263182	71	Economy	6700.00
0005432753363	71	Economy	6700.00
0005432818305	71	Economy	6700.00
0005432263185	71	Economy	6700.00
0005432263168	71	Economy	6700.00
0005434157737	71	Economy	6700.00
0005433690973	71	Economy	6700.00
0005432818296	71	Economy	6700.00
0005432818292	71	Economy	6700.00
0005432756894	71	Economy	6700.00
0005433477234	71	Economy	6700.00
0005432045668	7951	Business	20000.00
0005433103720	7951	Business	20000.00
0005433103706	7951	Business	20000.00
0005433103722	7951	Business	20000.00
0005433103708	7951	Business	20000.00
0005433103746	7951	Business	20000.00
0005432920447	7951	Business	20000.00
0005433103696	7951	Business	20000.00
0005432021009	7951	Business	20000.00
0005433103747	7951	Business	20000.00
0005433103734	7951	Business	20000.00
0005432021011	7951	Business	20000.00
0005433103759	7951	Business	20000.00
0005433103713	7951	Business	20000.00
0005433103754	7951	Business	20000.00
0005433103683	7951	Business	20000.00
0005433103698	7951	Business	20000.00
0005432920440	7951	Business	20000.00
0005433103704	7951	Business	20000.00
0005433103732	7951	Economy	7300.00
0005433103721	7951	Economy	7300.00
0005433103742	7951	Economy	7300.00
0005433103688	7951	Economy	6700.00
0005432753396	7951	Economy	6700.00
0005433103690	7951	Economy	6700.00
0005432021008	7951	Economy	6700.00
0005433103718	7951	Economy	6700.00
0005432920445	7951	Economy	6700.00
0005433103751	7951	Economy	6700.00
0005433103740	7951	Economy	6700.00
0005433103755	7951	Economy	6700.00
0005433103692	7951	Economy	6700.00
0005433103748	7951	Economy	6700.00
0005433103709	7951	Economy	6700.00
0005432920444	7951	Economy	6700.00
0005432920449	7951	Economy	6700.00
0005433103731	7951	Economy	6700.00
0005433103710	7951	Economy	6700.00
0005433103728	7951	Economy	6700.00
0005433103689	7951	Economy	6700.00
0005433103687	7951	Economy	6700.00
0005433103758	7951	Economy	6700.00
0005433103700	7951	Economy	6700.00
0005432920446	7951	Economy	6700.00
0005432920451	7951	Economy	6700.00
0005433103702	7951	Economy	6700.00
0005433103725	7951	Economy	6700.00
0005432021010	7951	Economy	6700.00
0005432021005	7951	Economy	6700.00
0005432751623	7951	Economy	6700.00
0005433103756	7951	Economy	6700.00
0005432753397	7951	Economy	6700.00
0005433103717	7951	Economy	6700.00
0005433103757	7951	Economy	6700.00
0005432920439	7951	Economy	6700.00
0005432021013	7951	Economy	6700.00
0005433103745	7951	Economy	6700.00
0005432920450	7951	Economy	6700.00
0005433103694	7951	Economy	6700.00
0005433103753	7951	Economy	6700.00
0005433103729	7951	Economy	6700.00
0005433103715	7951	Economy	6700.00
0005432920438	7951	Economy	6700.00
0005432021015	7951	Economy	6700.00
0005432920443	7951	Economy	6700.00
0005432920436	7951	Economy	6700.00
0005433103736	7951	Economy	6700.00
0005433103686	7951	Economy	6700.00
0005433103685	7951	Economy	6700.00
0005433103739	7951	Economy	7300.00
0005433103699	7951	Economy	7300.00
0005432677686	7951	Economy	7300.00
0005433103684	7951	Economy	6700.00
0005433103711	7951	Economy	6700.00
0005432392083	7951	Economy	7300.00
0005433103714	7951	Economy	6700.00
0005433103744	7951	Economy	6700.00
0005433103752	7951	Economy	6700.00
0005433103743	7951	Economy	6700.00
0005432021007	7951	Economy	6700.00
0005433103682	7951	Economy	6700.00
0005433103691	7951	Economy	6700.00
0005433103693	7951	Economy	6700.00
0005432920452	7951	Economy	6700.00
0005432021003	7951	Economy	6700.00
0005433103741	7951	Economy	6700.00
0005432920437	7951	Economy	6700.00
0005433103701	7951	Economy	6700.00
0005433103730	7951	Economy	6700.00
0005433103726	7951	Economy	6700.00
0005432751622	7951	Economy	6700.00
0005432753395	7951	Economy	6700.00
0005432920441	7951	Economy	6700.00
0005432753394	7951	Economy	6700.00
0005433103737	7951	Economy	6700.00
0005433103750	7951	Economy	6700.00
0005433103749	7951	Economy	6700.00
0005433103738	7951	Economy	6700.00
0005432045667	7951	Economy	6700.00
0005433103719	7951	Economy	6700.00
0005432021012	7951	Economy	6700.00
0005432021004	7951	Economy	6700.00
0005432021017	7951	Economy	6700.00
0005432920442	7951	Economy	6700.00
0005433103724	7951	Economy	6700.00
0005433103712	7951	Economy	6700.00
0005433103697	7951	Economy	6700.00
0005433103716	7951	Economy	6700.00
0005432021016	7951	Economy	6700.00
0005433103695	7951	Economy	6700.00
0005433103723	7951	Economy	6700.00
0005433103735	7951	Economy	6700.00
0005433103705	7951	Economy	6700.00
0005432021006	7951	Economy	6700.00
0005432920448	7951	Economy	6700.00
0005433103727	7951	Economy	6700.00
0005433103707	7951	Economy	6700.00
0005433103703	7951	Economy	6700.00
0005433103733	7951	Economy	6700.00
0005432021014	7951	Economy	6700.00
0005432818054	7950	Business	20000.00
0005432902095	7950	Business	20000.00
0005432818093	7950	Business	20000.00
0005432002134	7950	Business	20000.00
0005432818119	7950	Business	20000.00
0005432818182	7950	Business	20000.00
0005432818134	7950	Business	20000.00
0005432818012	7950	Business	20000.00
0005432002136	7950	Economy	7300.00
0005432818089	7950	Economy	7300.00
0005432818176	7950	Economy	7300.00
0005432902093	7950	Economy	6700.00
0005432002135	7950	Economy	6700.00
0005432817982	7950	Economy	6700.00
0005432818157	7950	Economy	6700.00
0005432818067	7950	Economy	6700.00
0005432902092	7950	Economy	6700.00
0005432818055	7950	Economy	6700.00
0005432817930	7950	Economy	6700.00
0005432818094	7950	Economy	6700.00
0005432902097	7950	Economy	6700.00
0005432817956	7950	Economy	6700.00
0005432902098	7950	Economy	6700.00
0005432818168	7950	Economy	6700.00
0005432902104	7950	Economy	6700.00
0005432818098	7950	Economy	6700.00
0005432818071	7950	Economy	6700.00
0005432818025	7950	Economy	6700.00
0005432818011	7950	Economy	6700.00
0005432818047	7950	Economy	6700.00
0005432902100	7950	Economy	6700.00
0005432902099	7950	Economy	7300.00
0005432818110	7950	Economy	7300.00
0005432817983	7950	Economy	6700.00
0005432818053	7950	Economy	7300.00
0005432902102	7950	Economy	6700.00
0005432902096	7950	Economy	6700.00
0005432902094	7950	Economy	6700.00
0005432817986	7950	Economy	6700.00
0005432817943	7950	Economy	6700.00
0005432818113	7950	Economy	6700.00
0005432818107	7950	Economy	6700.00
0005432818120	7950	Economy	6700.00
0005432818106	7950	Economy	6700.00
0005432817942	7950	Economy	6700.00
0005432902101	7950	Economy	6700.00
0005432818034	7950	Economy	6700.00
0005432902103	7950	Economy	6700.00
0005432818033	7950	Economy	6700.00
0005432818181	7950	Economy	6700.00
0005432818109	7950	Economy	6700.00
0005432817957	7950	Economy	6700.00
0005432817974	7950	Economy	6700.00
0005432817929	7950	Economy	6700.00
0005432818102	7950	Economy	6700.00
0005434175846	9645	Economy	6900.00
0005434175835	9645	Economy	6900.00
0005433870795	9645	Economy	6900.00
0005434175831	9645	Economy	6900.00
0005434175847	9645	Economy	6900.00
0005433870796	9645	Economy	6900.00
0005434175832	9645	Economy	6900.00
0005434175848	9645	Economy	6900.00
0005433870794	9645	Economy	6900.00
0005434175826	9645	Economy	6900.00
0005434175827	9645	Economy	6900.00
0005434175869	32356	Economy	6900.00
0005434175870	32356	Economy	6900.00
0005434175868	32356	Economy	6900.00
0005432183527	3503	Business	35000.00
0005435626764	3503	Business	35000.00
0005434427438	3503	Business	35000.00
0005434427431	3503	Business	35000.00
0005434880859	3503	Business	35000.00
0005432800247	3503	Business	35000.00
0005435902985	3503	Business	35000.00
0005435127505	3503	Business	35000.00
0005434880853	3503	Business	35000.00
0005434880845	3503	Business	35000.00
0005434427427	3503	Business	35000.00
0005434880887	3503	Business	35000.00
0005435127513	3503	Business	35000.00
0005435626747	3503	Business	35000.00
0005432800235	3503	Comfort	19900.00
0005435626746	3503	Comfort	19900.00
0005434427430	3503	Comfort	19900.00
0005434880844	3503	Comfort	19900.00
0005432613977	3503	Comfort	19900.00
0005435626730	3503	Comfort	19900.00
0005435914730	3503	Comfort	19900.00
0005435626755	3503	Comfort	19900.00
0005432800239	3503	Comfort	19900.00
0005435127511	3503	Comfort	19900.00
0005435626731	3503	Comfort	19900.00
0005432800234	3503	Comfort	19900.00
0005434880855	3503	Comfort	19900.00
0005432800236	3503	Comfort	19900.00
0005434427433	3503	Comfort	19900.00
0005435626736	3503	Comfort	19900.00
0005435626733	3503	Comfort	19900.00
0005434880896	3503	Comfort	19900.00
0005434938691	3503	Comfort	19900.00
0005435902952	3503	Comfort	19900.00
0005435626735	3503	Comfort	19900.00
0005434880866	3503	Comfort	19900.00
0005432800238	3503	Comfort	19900.00
0005435626757	3503	Comfort	19900.00
0005434880879	3503	Comfort	19900.00
0005435127503	3503	Comfort	19900.00
0005435626725	3503	Comfort	19900.00
0005435902954	3503	Economy	11700.00
0005434880897	3503	Economy	11700.00
0005434880842	3503	Economy	11700.00
0005432800248	3503	Economy	11700.00
0005434880891	3503	Economy	11700.00
0005435626734	3503	Economy	11700.00
0005435626744	3503	Economy	11700.00
0005435626738	3503	Economy	11700.00
0005434427439	3503	Economy	11700.00
0005434880862	3503	Economy	11700.00
0005434938692	3503	Economy	11700.00
0005435626761	3503	Economy	11700.00
0005435903078	3503	Economy	11700.00
0005434880869	3503	Economy	11700.00
0005435626742	3503	Economy	11700.00
0005434880892	3503	Economy	11700.00
0005432188699	3503	Economy	11700.00
0005435626763	3503	Economy	11700.00
0005435626756	3503	Economy	11700.00
0005434880843	3503	Economy	11700.00
0005435902953	3503	Economy	11700.00
0005434427424	3503	Economy	11700.00
0005434427428	3503	Economy	11700.00
0005435914722	3503	Economy	11700.00
0005434427426	3503	Economy	11700.00
0005434880893	3503	Economy	11700.00
0005434880846	3503	Economy	11700.00
0005434427435	3503	Economy	11700.00
0005434880849	3503	Economy	11700.00
0005435127504	3503	Economy	11700.00
0005434880837	3503	Economy	11700.00
0005432611812	3503	Economy	11700.00
0005435127519	3503	Economy	11700.00
0005435626753	3503	Economy	11700.00
0005435914002	3503	Economy	11700.00
0005435626737	3503	Economy	11700.00
0005434938688	3503	Economy	11700.00
0005432800243	3503	Economy	11700.00
0005434880851	3503	Economy	11700.00
0005435902986	3503	Economy	11700.00
0005434427425	3503	Economy	11700.00
0005435913980	3503	Economy	11700.00
0005435127520	3503	Economy	11700.00
0005434427434	3503	Economy	12800.00
0005434938689	3503	Economy	12800.00
0005434880839	3503	Economy	12800.00
0005435903100	3503	Economy	11700.00
0005435914018	3503	Economy	12800.00
0005435626751	3503	Economy	12800.00
0005434427429	3503	Economy	11700.00
0005434880876	3503	Economy	11700.00
0005434880894	3503	Economy	11700.00
0005434880872	3503	Economy	11700.00
0005432800237	3503	Economy	11700.00
0005434880878	3503	Economy	11700.00
0005435626740	3503	Economy	11700.00
0005435127516	3503	Economy	11700.00
0005435626754	3503	Economy	11700.00
0005435914727	3503	Economy	11700.00
0005435626752	3503	Economy	11700.00
0005435626748	3503	Economy	11700.00
0005435127515	3503	Economy	11700.00
0005434427422	3503	Economy	11700.00
0005434880882	3503	Economy	11700.00
0005432188700	3503	Economy	11700.00
0005435626729	3503	Economy	11700.00
0005434880841	3503	Economy	11700.00
0005435626758	3503	Economy	11700.00
0005435626745	3503	Economy	11700.00
0005432800242	3503	Economy	11700.00
0005434880840	3503	Economy	11700.00
0005434427436	3503	Economy	11700.00
0005435626749	3503	Economy	11700.00
0005435903077	3503	Economy	11700.00
0005435914721	3503	Economy	11700.00
0005435914013	3503	Economy	11700.00
0005434880856	3503	Economy	11700.00
0005434880888	3503	Economy	11700.00
0005435626767	3503	Economy	11700.00
0005434880838	3503	Economy	11700.00
0005432611811	3503	Economy	11700.00
0005435127517	3503	Economy	11700.00
0005434880873	3503	Economy	11700.00
0005435903093	3503	Economy	11700.00
0005435914026	3503	Economy	11700.00
0005435841839	3503	Economy	11700.00
0005435127522	3503	Economy	11700.00
0005432800244	3503	Economy	11700.00
0005435626759	3503	Economy	11700.00
0005434880867	3503	Economy	11700.00
0005434880875	3503	Economy	11700.00
0005434880852	3503	Economy	11700.00
0005434938687	3503	Economy	11700.00
0005435903064	3503	Economy	11700.00
0005434880863	3503	Economy	11700.00
0005432800240	3503	Economy	11700.00
0005435913983	3503	Economy	11700.00
0005434938685	3503	Economy	11700.00
0005434880848	3503	Economy	11700.00
0005434880877	3503	Economy	11700.00
0005435914719	3503	Economy	11700.00
0005435626766	3503	Economy	11700.00
0005435914011	3503	Economy	11700.00
0005434880895	3503	Economy	11700.00
0005434880860	3503	Economy	11700.00
0005434938683	3503	Economy	11700.00
0005434880880	3503	Economy	11700.00
0005435914724	3503	Economy	11700.00
0005435127507	3503	Economy	11700.00
0005434880883	3503	Economy	11700.00
0005435841105	3503	Economy	12800.00
0005432613976	3503	Economy	12800.00
0005435626727	3503	Economy	12800.00
0005435626760	3503	Economy	12800.00
0005435903091	3503	Economy	11700.00
0005435626750	3503	Economy	12800.00
0005435626732	3503	Economy	11700.00
0005434427432	3503	Economy	11700.00
0005434880864	3503	Economy	11700.00
0005434880850	3503	Economy	11700.00
0005434880881	3503	Economy	11700.00
0005434427423	3503	Economy	11700.00
0005434880847	3503	Economy	11700.00
0005435127518	3503	Economy	11700.00
0005435626741	3503	Economy	11700.00
0005434880857	3503	Economy	11700.00
0005435914017	3503	Economy	11700.00
0005435626728	3503	Economy	11700.00
0005434880870	3503	Economy	11700.00
0005435127523	3503	Economy	11700.00
0005435127510	3503	Economy	11700.00
0005435127514	3503	Economy	11700.00
0005435903065	3503	Economy	11700.00
0005435127508	3503	Economy	11700.00
0005434880874	3503	Economy	11700.00
0005434880861	3503	Economy	11700.00
0005435127506	3503	Economy	11700.00
0005435903035	3503	Economy	11700.00
0005435903054	3503	Economy	11700.00
0005435626726	3503	Economy	11700.00
0005435127509	3503	Economy	11700.00
0005435626739	3503	Economy	11700.00
0005435914723	3503	Economy	11700.00
0005435626765	3503	Economy	11700.00
0005435914014	3503	Economy	11700.00
0005434880854	3503	Economy	11700.00
0005434880886	3503	Economy	11700.00
0005435903025	3503	Economy	11700.00
0005435626762	3503	Economy	11700.00
0005432800246	3503	Economy	11700.00
0005435903104	3503	Economy	11700.00
0005435914001	3503	Economy	11700.00
0005435914015	3503	Economy	11700.00
0005432800245	3503	Economy	11700.00
0005434938690	3503	Economy	11700.00
0005434880889	3503	Economy	11700.00
0005434427437	3503	Economy	11700.00
0005435903101	3503	Economy	11700.00
0005434880885	3503	Economy	11700.00
0005435626743	3503	Economy	11700.00
0005435914726	3503	Economy	11700.00
0005432183526	3503	Economy	11700.00
0005435913998	3503	Economy	11700.00
0005434938686	3503	Economy	11700.00
0005434427440	3503	Economy	11700.00
0005434880858	3503	Economy	11700.00
0005434880884	3503	Economy	11700.00
0005434938684	3503	Economy	11700.00
0005434880865	3503	Economy	11700.00
0005432800241	3503	Economy	11700.00
0005432183528	3503	Economy	11700.00
0005435127521	3503	Economy	11700.00
0005434880890	3503	Economy	11700.00
0005435127512	3503	Economy	11700.00
0005434880898	3503	Economy	11700.00
0005434880868	3503	Economy	11700.00
0005434880871	3503	Economy	11700.00
0005435127502	3503	Economy	11700.00
0005435903028	3503	Economy	11700.00
0005435841118	3503	Economy	11700.00
0005434427247	14536	Business	35000.00
0005434880133	14536	Business	35000.00
0005432607650	14536	Business	35000.00
0005435127237	14536	Business	35000.00
0005435914156	14536	Business	35000.00
0005434879905	14536	Business	35000.00
0005434880058	14536	Business	35000.00
0005434427215	14536	Business	35000.00
0005434880180	14536	Business	35000.00
0005434880188	14536	Business	35000.00
0005435127037	14536	Business	35000.00
0005432607628	14536	Business	35000.00
0005432800076	14536	Business	35000.00
0005435127206	14536	Business	35000.00
0005434879906	14536	Business	35000.00
0005434427160	14536	Business	35000.00
0005434427258	14536	Business	35000.00
0005434880071	14536	Business	35000.00
0005434938493	14536	Business	35000.00
0005434427073	14536	Business	35000.00
0005434880072	14536	Business	35000.00
0005434880036	14536	Comfort	19900.00
0005434880105	14536	Comfort	19900.00
0005432611773	14536	Comfort	19900.00
0005434427245	14536	Comfort	19900.00
0005435127238	14536	Comfort	19900.00
0005432611801	14536	Comfort	19900.00
0005435127342	14536	Comfort	19900.00
0005434879995	14536	Comfort	19900.00
0005434879802	14536	Comfort	19900.00
0005435914152	14536	Comfort	19900.00
0005432800021	14536	Comfort	19900.00
0005435903200	14536	Comfort	19900.00
0005434879726	14536	Comfort	19900.00
0005435127216	14536	Comfort	19900.00
0005435127082	14536	Comfort	19900.00
0005432800061	14536	Comfort	19900.00
0005432059562	14536	Comfort	19900.00
0005434879928	14536	Comfort	19900.00
0005434938551	14536	Comfort	19900.00
0005434879902	14536	Comfort	19900.00
0005434880285	14536	Comfort	19900.00
0005432800183	14536	Comfort	19900.00
0005434879872	14536	Comfort	19900.00
0005434880163	14536	Comfort	19900.00
0005432059561	14536	Comfort	19900.00
0005435626454	14536	Comfort	19900.00
0005434880175	14536	Comfort	19900.00
0005434879947	14536	Comfort	19900.00
0005434938550	14536	Comfort	19900.00
0005435126985	14536	Economy	11700.00
0005434880235	14536	Comfort	19900.00
0005435127033	14536	Economy	11700.00
0005432800050	14536	Economy	11700.00
0005434879871	14536	Economy	11700.00
0005435127104	14536	Economy	11700.00
0005434938492	14536	Economy	11700.00
0005435127218	14536	Economy	11700.00
0005435127134	14536	Economy	11700.00
0005435127137	14536	Economy	11700.00
0005434880136	14536	Economy	11700.00
0005432800093	14536	Economy	11700.00
0005435626490	14536	Economy	11700.00
0005435127138	14536	Economy	11700.00
0005432799976	14536	Economy	11700.00
0005434880516	14536	Economy	11700.00
0005432800084	14536	Economy	11700.00
0005434427163	14536	Economy	11700.00
0005435914160	14536	Economy	11700.00
0005434427186	14536	Economy	11700.00
0005434880025	14536	Economy	11700.00
0005435127186	14536	Economy	11700.00
0005432611774	14536	Economy	11700.00
0005434938520	14536	Economy	11700.00
0005434880041	14536	Economy	11700.00
0005435126987	14536	Economy	11700.00
0005434880096	14536	Economy	11700.00
0005435127150	14536	Economy	11700.00
0005434427167	14536	Economy	11700.00
0005434938581	14536	Economy	11700.00
0005434880085	14536	Economy	11700.00
0005434880120	14536	Economy	11700.00
0005435127172	14536	Economy	11700.00
0005434880302	14536	Economy	11700.00
0005434427277	14536	Economy	11700.00
0005434427157	14536	Economy	11700.00
0005434427292	14536	Economy	11700.00
0005434880237	14536	Economy	11700.00
0005434880236	14536	Economy	11700.00
0005434879848	14536	Economy	11700.00
0005435127343	14536	Economy	11700.00
0005432800070	14536	Economy	11700.00
0005434879994	14536	Economy	11700.00
0005432800011	14536	Economy	11700.00
0005432800088	14536	Economy	11700.00
0005432800016	14536	Economy	11700.00
0005432800012	14536	Economy	11700.00
0005435914763	14536	Economy	12800.00
0005435127139	14536	Economy	11700.00
0005434880247	14536	Economy	12800.00
0005434938579	14536	Economy	11700.00
0005434880103	14536	Economy	12800.00
0005435914761	14536	Economy	12800.00
0005434879982	14536	Economy	11700.00
0005434879849	14536	Economy	12800.00
0005434938580	14536	Economy	11700.00
0005435127189	14536	Economy	12800.00
0005432800089	14536	Economy	11700.00
0005435903198	14536	Economy	11700.00
0005435127080	14536	Economy	11700.00
0005435914158	14536	Economy	11700.00
0005434880106	14536	Economy	11700.00
0005434427246	14536	Economy	11700.00
0005432800033	14536	Economy	11700.00
0005434879860	14536	Economy	11700.00
0005434879815	14536	Economy	11700.00
0005435914154	14536	Economy	11700.00
0005434879814	14536	Economy	11700.00
0005434427183	14536	Economy	11700.00
0005435914157	14536	Economy	11700.00
0005435127043	14536	Economy	11700.00
0005434938541	14536	Economy	11700.00
0005435914762	14536	Economy	11700.00
0005435127136	14536	Economy	11700.00
0005435127184	14536	Economy	11700.00
0005432799995	14536	Economy	11700.00
0005435127185	14536	Economy	11700.00
0005434427287	14536	Economy	11700.00
0005435127270	14536	Economy	11700.00
0005435127187	14536	Economy	11700.00
0005432800036	14536	Economy	11700.00
0005434938521	14536	Economy	11700.00
0005435127205	14536	Economy	11700.00
0005434880097	14536	Economy	11700.00
0005432800067	14536	Economy	11700.00
0005435127114	14536	Economy	11700.00
0005434879971	14536	Economy	11700.00
0005435127165	14536	Economy	11700.00
0005434880219	14536	Economy	11700.00
0005434427308	14536	Economy	11700.00
0005435903204	14536	Economy	11700.00
0005434879810	14536	Economy	11700.00
0005434880092	14536	Economy	11700.00
0005434880217	14536	Economy	11700.00
0005434427309	14536	Economy	11700.00
0005434880643	14536	Economy	11700.00
0005434879975	14536	Economy	11700.00
0005434880517	14536	Economy	11700.00
0005434938453	14536	Economy	11700.00
0005432799963	14536	Economy	11700.00
0005432611789	14536	Economy	11700.00
0005432800075	14536	Economy	11700.00
0005435903197	14536	Economy	11700.00
0005434938544	14536	Economy	11700.00
0005435127173	14536	Economy	11700.00
0005434427293	14536	Economy	11700.00
0005435903202	14536	Economy	11700.00
0005434880165	14536	Economy	11700.00
0005434938578	14536	Economy	11700.00
0005432799961	14536	Economy	11700.00
0005435127036	14536	Economy	11700.00
0005435126935	14536	Economy	11700.00
0005435903203	14536	Economy	11700.00
0005435127251	14536	Economy	11700.00
0005434879727	14536	Economy	11700.00
0005434880077	14536	Economy	11700.00
0005434880198	14536	Economy	11700.00
0005435127182	14536	Economy	11700.00
0005434880164	14536	Economy	11700.00
0005434880218	14536	Economy	11700.00
0005434879696	14536	Economy	11700.00
0005435626485	14536	Economy	11700.00
0005435914153	14536	Economy	11700.00
0005435127234	14536	Economy	11700.00
0005435903199	14536	Economy	11700.00
0005435127188	14536	Economy	11700.00
0005434880073	14536	Economy	11700.00
0005435127233	14536	Economy	11700.00
0005432611800	14536	Economy	11700.00
0005434880304	14536	Economy	11700.00
0005434880172	14536	Economy	11700.00
0005435626489	14536	Economy	11700.00
0005434880035	14536	Economy	11700.00
0005432800032	14536	Economy	11700.00
0005435914155	14536	Economy	11700.00
0005435626467	14536	Economy	11700.00
0005434880286	14536	Economy	11700.00
0005435914159	14536	Economy	11700.00
0005434427166	14536	Economy	11700.00
0005434879832	14536	Economy	11700.00
0005432799854	14536	Economy	11700.00
0005435126934	14536	Economy	11700.00
0005435127229	14536	Economy	11700.00
0005435127180	14536	Economy	11700.00
0005432800077	14536	Economy	11700.00
0005434427043	14536	Economy	11700.00
0005435127124	14536	Economy	11700.00
0005432799994	14536	Economy	11700.00
0005434427216	14536	Economy	11700.00
0005432799962	14536	Economy	11700.00
0005432611788	14536	Economy	11700.00
0005434427220	14536	Economy	11700.00
0005434427169	14536	Economy	12800.00
0005434879983	14536	Economy	12800.00
0005435127264	14536	Economy	12800.00
0005432800020	14536	Economy	12800.00
0005434938643	14536	Economy	12800.00
0005434880380	14536	Economy	11700.00
0005434880068	14536	Economy	11700.00
0005435127174	14536	Economy	11700.00
0005432607644	14536	Economy	11700.00
0005435914764	14536	Economy	11700.00
0005435127081	14536	Economy	11700.00
0005434427174	14536	Economy	11700.00
0005434880259	14536	Economy	11700.00
0005434427168	14536	Economy	11700.00
0005434880379	14536	Economy	11700.00
0005434427159	14536	Economy	11700.00
0005432800047	14536	Economy	11700.00
0005434938577	14536	Economy	11700.00
0005435914161	14536	Economy	11700.00
0005435127063	14536	Economy	11700.00
0005435626468	14536	Economy	11700.00
0005434880122	14536	Economy	11700.00
0005434880081	14536	Economy	11700.00
0005434880515	14536	Economy	11700.00
0005434879811	14536	Economy	11700.00
0005434879996	14536	Economy	11700.00
0005435127263	14536	Economy	11700.00
0005432799853	14536	Economy	11700.00
0005435626475	14536	Economy	11700.00
0005435127181	14536	Economy	11700.00
0005435626484	14536	Economy	11700.00
0005434879939	14536	Economy	11700.00
0005434879736	14536	Economy	11700.00
0005434938596	14536	Economy	11700.00
0005434880078	14536	Economy	11700.00
0005434879833	14536	Economy	11700.00
0005432059563	14536	Economy	11700.00
0005434880019	14536	Economy	11700.00
0005434880104	14536	Economy	11700.00
0005434427259	14536	Economy	11700.00
0005435626493	14536	Economy	11700.00
0005435127267	14536	Economy	11700.00
0005435126913	14536	Economy	11700.00
0005434880548	14536	Economy	11700.00
0005435126988	14536	Economy	11700.00
0005435127078	14536	Economy	11700.00
0005434880303	14536	Economy	11700.00
0005434880051	14536	Economy	11700.00
0005434880076	14536	Economy	11700.00
0005434427204	14536	Economy	11700.00
0005434879898	14536	Economy	11700.00
0005434880361	14536	Economy	11700.00
0005435127207	14536	Economy	11700.00
0005434879970	14536	Economy	11700.00
0005432800087	14536	Economy	11700.00
0005432800037	14536	Economy	11700.00
0005435127153	14536	Economy	11700.00
0005434879907	14536	Economy	11700.00
0005434880208	14536	Economy	11700.00
0005435903201	14536	Economy	11700.00
0005434938543	14536	Economy	11700.00
0005434880044	14536	Economy	11700.00
0005435903196	14536	Economy	11700.00
0005434427113	14536	Economy	11700.00
0005434880181	14536	Economy	11700.00
0005434938548	14536	Economy	11700.00
0005434880364	14536	Economy	11700.00
0005434427180	14536	Economy	11700.00
0005434880258	14536	Economy	11700.00
0005434880495	14536	Economy	11700.00
0005435127085	14536	Economy	11700.00
0005434880079	14536	Economy	11700.00
0005435127091	14536	Economy	11700.00
0005435126911	14536	Economy	11700.00
0005434880362	14536	Economy	11700.00
0005435626453	14536	Economy	11700.00
0005435127092	14536	Economy	11700.00
0005435626494	14536	Economy	11700.00
0005435127220	14536	Economy	11700.00
0005435127217	14536	Economy	11700.00
0005435127105	14536	Economy	11700.00
0005435127103	14536	Economy	11700.00
0005435626462	14536	Economy	11700.00
0005432607645	14536	Economy	11700.00
0005434427288	14536	Economy	11700.00
0005435127385	14536	Economy	11700.00
0005434880052	14536	Economy	11700.00
0005435127239	14536	Economy	11700.00
0005434427231	14536	Economy	11700.00
0005434312394	3608	Economy	16300.00
0005434325970	3608	Economy	14800.00
0005435890010	3608	Economy	14800.00
0005434325967	3608	Economy	14800.00
0005435890017	3608	Economy	14800.00
0005434312393	3608	Economy	14800.00
0005434312377	3608	Economy	14800.00
0005435889976	3608	Economy	14800.00
0005435890019	3608	Economy	14800.00
0005434325972	3608	Economy	14800.00
0005434312378	3608	Economy	14800.00
0005434325969	3608	Economy	14800.00
0005434325971	3608	Economy	14800.00
0005435890018	3608	Economy	14800.00
0005434325968	3608	Economy	14800.00
0005435890032	3608	Economy	14800.00
0005434325973	3608	Economy	14800.00
0005435890069	15634	Economy	16300.00
0005434325929	15634	Economy	16300.00
0005434325881	15634	Economy	16300.00
0005435890068	15634	Economy	14800.00
0005434325923	15634	Economy	14800.00
0005434325892	15634	Economy	14800.00
0005435890070	15634	Economy	14800.00
0005434325886	15634	Economy	14800.00
0005434325910	15634	Economy	14800.00
0005435890067	15634	Economy	14800.00
0005434325882	15634	Economy	14800.00
0005434325964	15634	Economy	14800.00
0005435890066	15634	Economy	14800.00
0005434325928	15634	Economy	14800.00
0005434325909	15634	Economy	14800.00
0005433420575	618	Economy	4500.00
0005435958113	618	Economy	4100.00
0005433420579	618	Economy	4100.00
0005435958110	618	Economy	4100.00
0005433420590	618	Economy	4100.00
0005433420580	618	Economy	4100.00
0005435958111	618	Economy	4100.00
0005435958112	618	Economy	4100.00
0005433420578	618	Economy	4100.00
0005435958108	618	Economy	4100.00
0005435958109	618	Economy	4100.00
0005433420557	618	Economy	4100.00
0005435957973	15192	Economy	4500.00
0005435957999	15192	Economy	4500.00
0005435958015	15192	Economy	4500.00
0005435957997	15192	Economy	4100.00
0005435958021	15192	Economy	4100.00
0005435958001	15192	Economy	4100.00
0005435958000	15192	Economy	4100.00
0005435957972	15192	Economy	4100.00
0005433420640	15192	Economy	4100.00
0005435957946	15192	Economy	4100.00
0005435958022	15192	Economy	4100.00
0005433420638	15192	Economy	4100.00
0005435957947	15192	Economy	4100.00
0005435957948	15192	Economy	4100.00
0005435958009	15192	Economy	4100.00
0005435957944	15192	Economy	4100.00
0005435957988	15192	Economy	4100.00
0005435958016	15192	Economy	4100.00
0005433420637	15192	Economy	4100.00
0005435958069	15192	Economy	4100.00
0005435958062	15192	Economy	4100.00
0005435958055	15192	Economy	4100.00
0005433420639	15192	Economy	4100.00
0005435958063	15192	Economy	4100.00
0005435216652	31772	Economy	28100.00
0005435218145	31772	Economy	28100.00
0005435216646	31772	Economy	25500.00
0005435217772	31772	Economy	25500.00
0005435218142	31772	Economy	25500.00
0005435217771	31772	Economy	25500.00
0005435217770	31772	Economy	25500.00
0005435217773	31772	Economy	25500.00
0005435218143	31772	Economy	25500.00
0005435216645	31772	Economy	25500.00
0005435218144	31772	Economy	25500.00
0005435216651	31772	Economy	25500.00
0005435216650	31772	Economy	25500.00
0005435216648	31772	Economy	25500.00
0005435216649	31772	Economy	25500.00
0005435216647	31772	Economy	25500.00
0005434995360	6705	Business	94000.00
0005434995362	6705	Business	94000.00
0005434995361	6705	Economy	31300.00
0005434995357	6705	Economy	31300.00
0005434995359	6705	Economy	31300.00
0005434995358	6705	Economy	31300.00
0005434995364	6705	Economy	31300.00
0005434995356	6705	Economy	31300.00
0005434995355	6705	Economy	31300.00
0005434995365	6705	Economy	31300.00
0005434995363	6705	Economy	31300.00
0005434995354	6705	Economy	31300.00
0005434247204	8893	Economy	10400.00
0005434247219	16052	Economy	10400.00
0005434247220	16052	Economy	10400.00
0005435629434	16052	Economy	10400.00
0005434467826	4007	Economy	21200.00
0005434467828	4007	Economy	21200.00
0005434467827	4007	Economy	21200.00
0005434467824	4007	Economy	21200.00
0005434467825	4007	Economy	21200.00
0005434467798	23211	Economy	21200.00
0005434467807	23211	Economy	21200.00
0005434467806	23211	Economy	21200.00
0005434467799	23211	Economy	21200.00
0005434467802	23211	Economy	21200.00
0005434467801	23211	Economy	21200.00
0005434467792	23211	Economy	21200.00
0005434467808	23211	Economy	21200.00
0005434467800	23211	Economy	21200.00
0005434096801	20170	Economy	14700.00
0005434096796	20170	Economy	14700.00
0005434096798	20170	Economy	13400.00
0005434096799	20170	Economy	13400.00
0005434096795	20170	Economy	13400.00
0005434096797	20170	Economy	13400.00
0005434096800	20170	Economy	13400.00
0005434096794	20170	Economy	13400.00
0005432646360	6845	Business	87700.00
0005432646361	6845	Business	87700.00
0005432646353	6845	Business	87700.00
0005432646351	6845	Business	87700.00
0005435229563	6845	Business	87700.00
0005435229577	6845	Business	87700.00
0005432646334	6845	Business	87700.00
0005432646356	6845	Economy	29200.00
0005432646343	6845	Economy	29200.00
0005432646335	6845	Economy	29200.00
0005435229568	6845	Economy	29200.00
0005432646337	6845	Economy	29200.00
0005435229579	6845	Economy	32200.00
0005432646350	6845	Economy	32200.00
0005435229572	6845	Economy	32200.00
0005432646339	6845	Economy	29200.00
0005432646347	6845	Economy	29200.00
0005432646358	6845	Economy	29200.00
0005435229537	6845	Economy	29200.00
0005435229574	6845	Economy	29200.00
0005432646357	6845	Economy	29200.00
0005435229534	6845	Economy	29200.00
0005435229545	6845	Economy	29200.00
0005435229561	6845	Economy	29200.00
0005435229586	6845	Economy	29200.00
0005435229578	6845	Economy	29200.00
0005432646340	6845	Economy	29200.00
0005435229546	6845	Economy	29200.00
0005432646346	6845	Economy	29200.00
0005432646344	6845	Economy	29200.00
0005435229556	6845	Economy	29200.00
0005432646359	6845	Economy	29200.00
0005432646341	6845	Economy	29200.00
0005432646355	6845	Economy	29200.00
0005432646348	6845	Economy	29200.00
0005435229551	6845	Economy	29200.00
0005432646342	6845	Economy	29200.00
0005435229539	6845	Economy	29200.00
0005435229547	6845	Economy	29200.00
0005435229580	6845	Economy	29200.00
0005432646352	6845	Economy	29200.00
0005432646364	6845	Economy	29200.00
0005432646345	6845	Economy	29200.00
0005432646338	6845	Economy	29200.00
0005432646362	6845	Economy	29200.00
0005435229584	6845	Economy	29200.00
0005435229562	6845	Economy	29200.00
0005432646336	6845	Economy	29200.00
0005432646333	6845	Economy	29200.00
0005435229585	6845	Economy	29200.00
0005432646365	6845	Economy	29200.00
0005432646349	6845	Economy	29200.00
0005435229538	6845	Economy	29200.00
0005432646363	6845	Economy	29200.00
0005432646354	6845	Economy	29200.00
0005435229555	6845	Economy	29200.00
0005435229583	6845	Economy	29200.00
0005432646169	25106	Business	87700.00
0005435229612	25106	Business	87700.00
0005432646246	25106	Business	87700.00
0005435229615	25106	Business	87700.00
0005435229620	25106	Business	87700.00
0005432646271	25106	Business	87700.00
0005432646188	25106	Business	87700.00
0005435229622	25106	Business	87700.00
0005432646202	25106	Business	87700.00
0005432646243	25106	Business	87700.00
0005432646231	25106	Economy	29200.00
0005432646219	25106	Economy	29200.00
0005435229621	25106	Economy	29200.00
0005432646229	25106	Economy	29200.00
0005432646215	25106	Economy	29200.00
0005432646227	25106	Economy	29200.00
0005435229627	25106	Economy	29200.00
0005432646238	25106	Economy	29200.00
0005435229630	25106	Economy	29200.00
0005432646218	25106	Economy	32200.00
0005432646228	25106	Economy	32200.00
0005432646183	25106	Economy	32200.00
0005432646259	25106	Economy	32200.00
0005432646192	25106	Economy	29200.00
0005432646152	25106	Economy	29200.00
0005435229632	25106	Economy	29200.00
0005432646191	25106	Economy	29200.00
0005435229616	25106	Economy	29200.00
0005432646225	25106	Economy	29200.00
0005432646223	25106	Economy	29200.00
0005432646193	25106	Economy	29200.00
0005435229614	25106	Economy	29200.00
0005432646148	25106	Economy	29200.00
0005432646201	25106	Economy	29200.00
0005435229628	25106	Economy	29200.00
0005432646277	25106	Economy	29200.00
0005432646236	25106	Economy	29200.00
0005435229631	25106	Economy	29200.00
0005432646167	25106	Economy	29200.00
0005432646210	25106	Economy	29200.00
0005435229613	25106	Economy	29200.00
0005432646207	25106	Economy	29200.00
0005432646265	25106	Economy	29200.00
0005432646239	25106	Economy	29200.00
0005432646263	25106	Economy	29200.00
0005432646240	25106	Economy	29200.00
0005432646185	25106	Economy	29200.00
0005432646206	25106	Economy	29200.00
0005435229611	25106	Economy	29200.00
0005432646224	25106	Economy	29200.00
0005432646151	25106	Economy	29200.00
0005432646190	25106	Economy	29200.00
0005432646154	25106	Economy	29200.00
0005432646204	25106	Economy	29200.00
0005435229624	25106	Economy	29200.00
0005435229623	25106	Economy	29200.00
0005432646187	25106	Economy	29200.00
0005432646189	25106	Economy	29200.00
0005435229618	25106	Economy	29200.00
0005432646168	25106	Economy	29200.00
0005432646155	25106	Economy	29200.00
0005432646182	25106	Economy	29200.00
0005435229610	25106	Economy	29200.00
0005435229626	25106	Economy	29200.00
0005432646245	25106	Economy	29200.00
0005432646226	25106	Economy	29200.00
0005432646230	25106	Economy	29200.00
0005432646237	25106	Economy	29200.00
0005432646198	25106	Economy	29200.00
0005435229619	25106	Economy	29200.00
0005432646267	25106	Economy	29200.00
0005435229629	25106	Economy	29200.00
0005435229609	25106	Economy	29200.00
0005432646266	25106	Economy	29200.00
0005435229617	25106	Economy	29200.00
0005432646097	25106	Economy	29200.00
0005432646244	25106	Economy	29200.00
0005432646186	25106	Economy	29200.00
0005432646235	25106	Economy	29200.00
0005432646197	25106	Economy	29200.00
0005435229625	25106	Economy	29200.00
0005435797875	2882	Economy	4200.00
0005435797881	2882	Economy	4200.00
0005435797870	2882	Economy	4200.00
0005435797880	2882	Economy	4600.00
0005433404950	2882	Economy	4200.00
0005435797871	2882	Economy	4200.00
0005435797877	2882	Economy	4200.00
0005433404967	2882	Economy	4200.00
0005433404980	2882	Economy	4200.00
0005433404971	2882	Economy	4200.00
0005435797878	2882	Economy	4200.00
0005435797876	2882	Economy	4200.00
0005433404921	2882	Economy	4200.00
0005435797879	2882	Economy	4200.00
0005433404951	2882	Economy	4200.00
0005433404953	2882	Economy	4200.00
0005435797869	2882	Economy	4200.00
0005433404957	2882	Economy	4200.00
0005435797872	2882	Economy	4200.00
0005433404958	2882	Economy	4200.00
0005433404972	2882	Economy	4200.00
0005435797874	2882	Economy	4200.00
0005435797873	2882	Economy	4200.00
0005435797755	29304	Business	12600.00
0005435797732	29304	Business	12600.00
0005433405024	29304	Business	12600.00
0005435797779	29304	Business	12600.00
0005435797846	29304	Economy	4200.00
0005435797731	29304	Economy	4200.00
0005435797782	29304	Economy	4200.00
0005435797741	29304	Economy	4200.00
0005433405019	29304	Economy	4200.00
0005435797767	29304	Economy	4200.00
0005435797783	29304	Economy	4200.00
0005435797742	29304	Economy	4200.00
0005435797730	29304	Economy	4200.00
0005433405020	29304	Economy	4200.00
0005433405023	29304	Economy	4200.00
0005433405021	29304	Economy	4200.00
0005435797761	29304	Economy	4200.00
0005435797820	29304	Economy	4200.00
0005433405022	29304	Economy	4200.00
0005435797729	29304	Economy	4200.00
0005435797777	29304	Economy	4200.00
0005435797717	29304	Economy	4200.00
0005435797735	29304	Economy	4200.00
0005435376418	5832	Economy	6800.00
0005435376416	5832	Economy	6800.00
0005435376414	5832	Economy	6800.00
0005434948250	5770	Economy	6800.00
0005434948253	5770	Economy	6800.00
0005434948251	5770	Economy	6800.00
0005434948252	5770	Economy	6800.00
0005435376427	16328	Economy	6800.00
0005434948242	16328	Economy	6800.00
0005434948177	16328	Economy	6800.00
0005435376425	16328	Economy	6800.00
0005434948199	16328	Economy	6800.00
0005434948190	16328	Economy	6800.00
0005434948214	16328	Economy	6800.00
0005435376426	16328	Economy	6800.00
0005434948191	16328	Economy	6800.00
0005433962527	6904	Business	21400.00
0005433962522	6904	Business	21400.00
0005433962545	6904	Business	21400.00
0005433962532	6904	Business	21400.00
0005433962585	6904	Business	21400.00
0005433962564	6904	Business	21400.00
0005433962539	6904	Business	21400.00
0005433962530	6904	Business	21400.00
0005433962526	6904	Business	21400.00
0005433962567	6904	Business	21400.00
0005433962553	6904	Economy	7100.00
0005433962535	6904	Economy	7100.00
0005433962568	6904	Economy	7100.00
0005433962547	6904	Economy	7100.00
0005433962536	6904	Economy	7100.00
0005433962580	6904	Economy	7100.00
0005433962581	6904	Economy	7800.00
0005433962542	6904	Economy	7800.00
0005433962534	6904	Economy	7800.00
0005433962520	6904	Economy	7100.00
0005433962550	6904	Economy	7100.00
0005433962521	6904	Economy	7100.00
0005433962548	6904	Economy	7100.00
0005433962586	6904	Economy	7100.00
0005433962531	6904	Economy	7100.00
0005433962572	6904	Economy	7100.00
0005433962584	6904	Economy	7100.00
0005433962587	6904	Economy	7100.00
0005433962537	6904	Economy	7100.00
0005433962569	6904	Economy	7100.00
0005433962543	6904	Economy	7100.00
0005433962559	6904	Economy	7100.00
0005433962557	6904	Economy	7100.00
0005433962551	6904	Economy	7100.00
0005433962566	6904	Economy	7100.00
0005433962575	6904	Economy	7100.00
0005433962556	6904	Economy	7100.00
0005433962560	6904	Economy	7100.00
0005433962523	6904	Economy	7100.00
0005433962525	6904	Economy	7100.00
0005433962529	6904	Economy	7100.00
0005433962574	6904	Economy	7100.00
0005433962563	6904	Economy	7100.00
0005433962571	6904	Economy	7100.00
0005433962579	6904	Economy	7100.00
0005433962541	6904	Economy	7100.00
0005433962576	6904	Economy	7100.00
0005433962538	6904	Economy	7100.00
0005433962577	6904	Economy	7100.00
0005433962546	6904	Economy	7100.00
0005433962561	6904	Economy	7100.00
0005433962533	6904	Economy	7100.00
0005433962544	6904	Economy	7100.00
0005433962578	6904	Economy	7100.00
0005433962589	6904	Economy	7100.00
0005433962570	6904	Economy	7100.00
0005433962573	6904	Economy	7100.00
0005433962582	6904	Economy	7100.00
0005433962558	6904	Economy	7100.00
0005433962549	6904	Economy	7100.00
0005433962565	6904	Economy	7100.00
0005433962555	6904	Economy	7100.00
0005433962588	6904	Economy	7100.00
0005433962562	6904	Economy	7100.00
0005433962528	6904	Economy	7100.00
0005433962583	6904	Economy	7100.00
0005433962524	6904	Economy	7100.00
0005433962540	6904	Economy	7100.00
0005433962554	6904	Economy	7100.00
0005433962590	6904	Economy	7100.00
0005433962552	6904	Economy	7100.00
0005433961850	25761	Business	21400.00
0005433961825	25761	Business	21400.00
0005433961873	25761	Business	21400.00
0005433961898	25761	Business	21400.00
0005433961565	25761	Business	21400.00
0005433961731	25761	Business	21400.00
0005433961897	25761	Economy	7100.00
0005433961874	25761	Economy	7100.00
0005433961778	25761	Economy	7100.00
0005433961952	25761	Economy	7100.00
0005433961824	25761	Economy	7100.00
0005433961604	25761	Economy	7100.00
0005433961700	25761	Economy	7100.00
0005433961749	25761	Economy	7800.00
0005433961953	25761	Economy	7800.00
0005433961968	25761	Economy	7800.00
0005433961900	25761	Economy	7100.00
0005433961945	25761	Economy	7100.00
0005433961914	25761	Economy	7100.00
0005433961724	25761	Economy	7100.00
0005433961861	25761	Economy	7100.00
0005433961763	25761	Economy	7100.00
0005433961659	25761	Economy	7100.00
0005433961849	25761	Economy	7100.00
0005433961967	25761	Economy	7100.00
0005433961936	25761	Economy	7100.00
0005433961846	25761	Economy	7100.00
0005433961932	25761	Economy	7100.00
0005433961959	25761	Economy	7100.00
0005433961973	25761	Economy	7100.00
0005433961613	25761	Economy	7100.00
0005433961744	25761	Economy	7100.00
0005433961946	25761	Economy	7100.00
0005433961653	25761	Economy	7100.00
0005433961865	25761	Economy	7100.00
0005433961862	25761	Economy	7100.00
0005433961872	25761	Economy	7100.00
0005433961745	25761	Economy	7100.00
0005433961666	25761	Economy	7100.00
0005433961866	25761	Economy	7100.00
0005433961905	25761	Economy	7100.00
0005433961780	25761	Economy	7100.00
0005433961972	25761	Economy	7100.00
0005433961935	25761	Economy	7100.00
0005433961725	25761	Economy	7100.00
0005433961958	25761	Economy	7100.00
0005433961880	25761	Economy	7100.00
0005433961934	25761	Economy	7100.00
0005433961925	25761	Economy	7100.00
0005433961752	25761	Economy	7100.00
0005433961943	25761	Economy	7100.00
0005433961931	25761	Economy	7100.00
0005433961774	25761	Economy	7100.00
0005433961746	25761	Economy	7100.00
0005433961894	25761	Economy	7100.00
0005433961906	25761	Economy	7100.00
0005433961611	25761	Economy	7100.00
0005433961924	25761	Economy	7100.00
0005433961660	25761	Economy	7100.00
0005435082946	24512	Economy	3900.00
0005435082899	24512	Economy	3900.00
0005435082930	24512	Economy	3900.00
0005435082898	24512	Economy	3900.00
0005435082933	24512	Economy	3900.00
0005435082951	24512	Economy	3900.00
0005435082956	24512	Economy	3900.00
0005435083011	26100	Economy	3900.00
0005435083009	26100	Economy	3900.00
0005435083012	26100	Economy	3900.00
0005435083015	26100	Economy	3900.00
0005435083010	26100	Economy	3900.00
0005435083008	26100	Economy	3900.00
0005435083013	26100	Economy	3900.00
0005435083014	26100	Economy	3900.00
0005432166989	5095	Business	18000.00
0005434245796	5095	Business	18000.00
0005434245808	5095	Business	18000.00
0005435286732	5095	Business	18000.00
0005434245799	5095	Economy	6600.00
0005434245812	5095	Economy	6600.00
0005434245813	5095	Economy	6000.00
0005434245807	5095	Economy	6000.00
0005434245804	5095	Economy	6000.00
0005434245797	5095	Economy	6000.00
0005434245803	5095	Economy	6000.00
0005434245800	5095	Economy	6000.00
0005434245814	5095	Economy	6000.00
0005432166990	5095	Economy	6600.00
0005432166991	5095	Economy	6000.00
0005434245810	5095	Economy	6000.00
0005434245798	5095	Economy	6000.00
0005434245795	5095	Economy	6000.00
0005434245802	5095	Economy	6000.00
0005434245811	5095	Economy	6000.00
0005434245794	5095	Economy	6000.00
0005434245801	5095	Economy	6000.00
0005435286715	5095	Economy	6000.00
0005434245809	5095	Economy	6000.00
0005434245793	5095	Economy	6000.00
0005434245806	5095	Economy	6000.00
0005434245805	5095	Economy	6000.00
0005433786055	5096	Business	18000.00
0005434230053	5096	Business	18000.00
0005433616717	5096	Business	18000.00
0005433786089	5096	Business	18000.00
0005433616729	5096	Business	18000.00
0005434230056	5096	Business	18000.00
0005433786063	5096	Business	18000.00
0005432106882	5096	Business	18000.00
0005432106893	5096	Business	18000.00
0005433616739	5096	Business	18000.00
0005432106903	5096	Business	18000.00
0005433786054	5096	Business	18000.00
0005433786041	5096	Business	18000.00
0005432106891	5096	Business	18000.00
0005433786073	5096	Business	18000.00
0005433786087	5096	Business	18000.00
0005433786040	5096	Business	18000.00
0005434230051	5096	Business	18000.00
0005432106884	5096	Business	18000.00
0005433786056	5096	Business	18000.00
0005433616740	5096	Business	18000.00
0005432106895	5096	Business	18000.00
0005432106890	5096	Business	18000.00
0005433786045	5096	Economy	6600.00
0005433616727	5096	Economy	6600.00
0005433786090	5096	Economy	6600.00
0005433616728	5096	Economy	6600.00
0005433616750	5096	Economy	6000.00
0005433616715	5096	Economy	6000.00
0005432106881	5096	Economy	6000.00
0005433786049	5096	Economy	6000.00
0005434230055	5096	Economy	6000.00
0005432106883	5096	Economy	6000.00
0005433786072	5096	Economy	6000.00
0005432106886	5096	Economy	6000.00
0005433616752	5096	Economy	6000.00
0005433786069	5096	Economy	6000.00
0005433786078	5096	Economy	6000.00
0005433616747	5096	Economy	6000.00
0005433616713	5096	Economy	6000.00
0005433616716	5096	Economy	6000.00
0005433616748	5096	Economy	6000.00
0005432106907	5096	Economy	6000.00
0005432106892	5096	Economy	6000.00
0005433786043	5096	Economy	6000.00
0005433786050	5096	Economy	6000.00
0005433786079	5096	Economy	6000.00
0005433616722	5096	Economy	6000.00
0005433786088	5096	Economy	6000.00
0005432106879	5096	Economy	6000.00
0005433786076	5096	Economy	6000.00
0005433786080	5096	Economy	6000.00
0005433786085	5096	Economy	6000.00
0005433786074	5096	Economy	6000.00
0005433616719	5096	Economy	6000.00
0005433616738	5096	Economy	6000.00
0005432106887	5096	Economy	6000.00
0005433616730	5096	Economy	6000.00
0005433786082	5096	Economy	6000.00
0005432666445	5096	Economy	6000.00
0005433616754	5096	Economy	6000.00
0005433616755	5096	Economy	6000.00
0005433786051	5096	Economy	6000.00
0005433616732	5096	Economy	6000.00
0005433786042	5096	Economy	6000.00
0005433786092	5096	Economy	6000.00
0005432106896	5096	Economy	6000.00
0005433616733	5096	Economy	6000.00
0005433616725	5096	Economy	6000.00
0005432666446	5096	Economy	6000.00
0005433616726	5096	Economy	6000.00
0005433786047	5096	Economy	6000.00
0005433786084	5096	Economy	6000.00
0005432106880	5096	Economy	6000.00
0005433786059	5096	Economy	6000.00
0005433786044	5096	Economy	6000.00
0005432667513	5096	Economy	6000.00
0005433616736	5096	Economy	6000.00
0005433616720	5096	Economy	6000.00
0005433616731	5096	Economy	6600.00
0005432106898	5096	Economy	6600.00
0005432667514	5096	Economy	6600.00
0005433616741	5096	Economy	6600.00
0005434230052	5096	Economy	6000.00
0005433616737	5096	Economy	6000.00
0005433616735	5096	Economy	6000.00
0005433616743	5096	Economy	6000.00
0005432106901	5096	Economy	6600.00
0005432666444	5096	Economy	6000.00
0005433786075	5096	Economy	6000.00
0005432106900	5096	Economy	6000.00
0005433786066	5096	Economy	6000.00
0005432106885	5096	Economy	6000.00
0005433616749	5096	Economy	6000.00
0005433786048	5096	Economy	6000.00
0005433616751	5096	Economy	6000.00
0005433786083	5096	Economy	6000.00
0005433786071	5096	Economy	6000.00
0005433786091	5096	Economy	6000.00
0005433786052	5096	Economy	6000.00
0005434230054	5096	Economy	6000.00
0005432106888	5096	Economy	6000.00
0005433616742	5096	Economy	6000.00
0005433616745	5096	Economy	6000.00
0005432106894	5096	Economy	6000.00
0005433786062	5096	Economy	6000.00
0005432106906	5096	Economy	6000.00
0005433786064	5096	Economy	6000.00
0005433786057	5096	Economy	6000.00
0005433616734	5096	Economy	6000.00
0005433786070	5096	Economy	6000.00
0005433616744	5096	Economy	6000.00
0005433786053	5096	Economy	6000.00
0005433616723	5096	Economy	6000.00
0005433616724	5096	Economy	6000.00
0005433616718	5096	Economy	6000.00
0005433786058	5096	Economy	6000.00
0005433786081	5096	Economy	6000.00
0005432106902	5096	Economy	6000.00
0005433786077	5096	Economy	6000.00
0005432106905	5096	Economy	6000.00
0005433616753	5096	Economy	6000.00
0005433786093	5096	Economy	6000.00
0005433786086	5096	Economy	6000.00
0005433786061	5096	Economy	6000.00
0005433786068	5096	Economy	6000.00
0005434230057	5096	Economy	6000.00
0005432106899	5096	Economy	6000.00
0005434230058	5096	Economy	6000.00
0005433786067	5096	Economy	6000.00
0005433786046	5096	Economy	6000.00
0005432106889	5096	Economy	6000.00
0005433786065	5096	Economy	6000.00
0005433786060	5096	Economy	6000.00
0005432106897	5096	Economy	6000.00
0005432106904	5096	Economy	6000.00
0005432145169	5096	Economy	6000.00
0005433616746	5096	Economy	6000.00
0005433616714	5096	Economy	6000.00
0005433616721	5096	Economy	6000.00
0005434150066	5100	Business	18000.00
0005434173660	5100	Business	18000.00
0005432336236	5100	Business	18000.00
0005435007448	5100	Business	18000.00
0005433685553	5100	Business	18000.00
0005434265866	5100	Business	18000.00
0005433815466	5100	Business	18000.00
0005435007469	5100	Business	18000.00
0005432336297	5100	Business	18000.00
0005435007471	5100	Business	18000.00
0005435007464	5100	Business	18000.00
0005435007529	5100	Business	18000.00
0005433815482	5100	Business	18000.00
0005433685557	5100	Business	18000.00
0005435269896	5100	Business	18000.00
0005435007546	5100	Business	18000.00
0005435007468	5100	Business	18000.00
0005432336337	5100	Economy	6600.00
0005434173661	5100	Economy	6600.00
0005434265852	5100	Economy	6600.00
0005435269898	5100	Economy	6000.00
0005435007528	5100	Economy	6000.00
0005434230004	5100	Economy	6000.00
0005434173659	5100	Economy	6000.00
0005434265868	5100	Economy	6000.00
0005434230001	5100	Economy	6000.00
0005434265857	5100	Economy	6000.00
0005435007436	5100	Economy	6000.00
0005435007420	5100	Economy	6000.00
0005434265858	5100	Economy	6000.00
0005434150063	5100	Economy	6000.00
0005433685558	5100	Economy	6000.00
0005434265851	5100	Economy	6000.00
0005433685559	5100	Economy	6000.00
0005434265855	5100	Economy	6000.00
0005435007533	5100	Economy	6000.00
0005434265859	5100	Economy	6000.00
0005435269899	5100	Economy	6000.00
0005434173634	5100	Economy	6000.00
0005434229997	5100	Economy	6000.00
0005435007583	5100	Economy	6000.00
0005432336286	5100	Economy	6000.00
0005434150065	5100	Economy	6000.00
0005434230008	5100	Economy	6000.00
0005435269878	5100	Economy	6000.00
0005434265853	5100	Economy	6000.00
0005432336287	5100	Economy	6000.00
0005433685555	5100	Economy	6000.00
0005432336336	5100	Economy	6000.00
0005434150060	5100	Economy	6000.00
0005433815461	5100	Economy	6000.00
0005435269895	5100	Economy	6000.00
0005434230009	5100	Economy	6000.00
0005434229998	5100	Economy	6000.00
0005434265863	5100	Economy	6000.00
0005435269919	5100	Economy	6600.00
0005434229999	5100	Economy	6600.00
0005433685554	5100	Economy	6600.00
0005434265862	5100	Economy	6600.00
0005435269907	5100	Economy	6600.00
0005433685552	5100	Economy	6000.00
0005435269908	5100	Economy	6600.00
0005435269897	5100	Economy	6000.00
0005434265861	5100	Economy	6000.00
0005435007470	5100	Economy	6000.00
0005433815491	5100	Economy	6000.00
0005434150064	5100	Economy	6000.00
0005434230002	5100	Economy	6000.00
0005434265867	5100	Economy	6000.00
0005433685556	5100	Economy	6000.00
0005434265856	5100	Economy	6000.00
0005435007504	5100	Economy	6000.00
0005434229996	5100	Economy	6000.00
0005434265865	5100	Economy	6000.00
0005435007556	5100	Economy	6000.00
0005432336310	5100	Economy	6000.00
0005433815463	5100	Economy	6000.00
0005435269872	5100	Economy	6000.00
0005434230010	5100	Economy	6000.00
0005434265854	5100	Economy	6000.00
0005434230006	5100	Economy	6000.00
0005434230000	5100	Economy	6000.00
0005432336312	5100	Economy	6000.00
0005434229995	5100	Economy	6000.00
0005434150062	5100	Economy	6000.00
0005434265864	5100	Economy	6000.00
0005435007543	5100	Economy	6000.00
0005434230003	5100	Economy	6000.00
0005432336295	5100	Economy	6000.00
0005435269905	5100	Economy	6000.00
0005432336324	5100	Economy	6000.00
0005434230005	5100	Economy	6000.00
0005435269900	5100	Economy	6000.00
0005432336255	5100	Economy	6000.00
0005434265860	5100	Economy	6000.00
0005435007555	5100	Economy	6000.00
0005434150061	5100	Economy	6000.00
0005435269913	5100	Economy	6000.00
0005432336338	5100	Economy	6000.00
0005435007535	5100	Economy	6000.00
0005432336311	5100	Economy	6000.00
0005435007524	5100	Economy	6000.00
0005435007467	5100	Economy	6000.00
0005433815460	5100	Economy	6000.00
0005433815481	5100	Economy	6000.00
0005434265869	5100	Economy	6000.00
0005434230007	5100	Economy	6000.00
0005433785577	8585	Business	18000.00
0005434245593	8585	Business	18000.00
0005435270130	8585	Business	18000.00
0005433785534	8585	Business	18000.00
0005433785691	8585	Business	18000.00
0005435270157	8585	Business	18000.00
0005435270139	8585	Business	18000.00
0005435270153	8585	Business	18000.00
0005433785689	8585	Business	18000.00
0005434245678	8585	Business	18000.00
0005435270133	8585	Business	18000.00
0005435270154	8585	Business	18000.00
0005433785499	8585	Business	18000.00
0005433785603	8585	Business	18000.00
0005434245572	8585	Business	18000.00
0005432666436	8585	Business	18000.00
0005435270132	8585	Business	18000.00
0005435270145	8585	Business	18000.00
0005433785760	8585	Economy	6600.00
0005433785604	8585	Economy	6600.00
0005433785657	8585	Economy	6000.00
0005435270137	8585	Economy	6000.00
0005435270152	8585	Economy	6000.00
0005432659736	8585	Economy	6000.00
0005435270138	8585	Economy	6000.00
0005435270158	8585	Economy	6000.00
0005435270135	8585	Economy	6000.00
0005433785744	8585	Economy	6000.00
0005433785670	8585	Economy	6000.00
0005433785632	8585	Economy	6000.00
0005434245524	8585	Economy	6000.00
0005434245613	8585	Economy	6000.00
0005433785824	8585	Economy	6000.00
0005433785520	8585	Economy	6000.00
0005435270155	8585	Economy	6000.00
0005433785724	8585	Economy	6000.00
0005434245514	8585	Economy	6000.00
0005433785669	8585	Economy	6000.00
0005433785576	8585	Economy	6000.00
0005433785823	8585	Economy	6000.00
0005433785638	8585	Economy	6000.00
0005435270149	8585	Economy	6000.00
0005433785839	8585	Economy	6000.00
0005435270128	8585	Economy	6000.00
0005433785522	8585	Economy	6000.00
0005433785672	8585	Economy	6000.00
0005434245680	8585	Economy	6000.00
0005433785633	8585	Economy	6000.00
0005434245495	8585	Economy	6000.00
0005435270146	8585	Economy	6000.00
0005434245563	8585	Economy	6000.00
0005435270150	8585	Economy	6000.00
0005435270131	8585	Economy	6000.00
0005433785590	8585	Economy	6000.00
0005433785645	8585	Economy	6000.00
0005434245658	8585	Economy	6600.00
0005433785825	8585	Economy	6600.00
0005435270147	8585	Economy	6600.00
0005434245579	8585	Economy	6600.00
0005434245478	8585	Economy	6000.00
0005433785745	8585	Economy	6000.00
0005433785730	8585	Economy	6000.00
0005434245513	8585	Economy	6000.00
0005434245648	8585	Economy	6000.00
0005433785673	8585	Economy	6000.00
0005434245592	8585	Economy	6000.00
0005435270129	8585	Economy	6000.00
0005433785740	8585	Economy	6000.00
0005434245564	8585	Economy	6000.00
0005435270134	8585	Economy	6000.00
0005434245614	8585	Economy	6000.00
0005434245659	8585	Economy	6000.00
0005433785651	8585	Economy	6000.00
0005434245618	8585	Economy	6000.00
0005434245570	8585	Economy	6000.00
0005434245612	8585	Economy	6000.00
0005435270142	8585	Economy	6000.00
0005434245611	8585	Economy	6000.00
0005434245645	8585	Economy	6000.00
0005435270151	8585	Economy	6000.00
0005433785620	8585	Economy	6000.00
0005434245523	8585	Economy	6000.00
0005435270148	8585	Economy	6000.00
0005435270140	8585	Economy	6000.00
0005435270156	8585	Economy	6000.00
0005433785746	8585	Economy	6000.00
0005433785679	8585	Economy	6000.00
0005434245591	8585	Economy	6000.00
0005434245610	8585	Economy	6000.00
0005433785637	8585	Economy	6000.00
0005434245646	8585	Economy	6000.00
0005434245526	8585	Economy	6000.00
0005433785635	8585	Economy	6000.00
0005433785702	8585	Economy	6000.00
0005434245679	8585	Economy	6000.00
0005435270144	8585	Economy	6000.00
0005434245571	8585	Economy	6000.00
0005433785703	8585	Economy	6000.00
0005433785646	8585	Economy	6000.00
0005433785634	8585	Economy	6000.00
0005435270136	8585	Economy	6000.00
0005434245588	8585	Economy	6000.00
0005435270141	8585	Economy	6000.00
0005433785692	8585	Economy	6000.00
0005435270143	8585	Economy	6000.00
0005433785688	8585	Economy	6000.00
0005433785636	8585	Economy	6000.00
0005433785519	8585	Economy	6000.00
0005434245711	8585	Economy	6000.00
0005433615993	8586	Business	18000.00
0005433615943	8586	Business	18000.00
0005433615775	8586	Business	18000.00
0005433616386	8586	Business	18000.00
0005433616216	8586	Business	18000.00
0005433616079	8586	Business	18000.00
0005433616266	8586	Business	18000.00
0005433616204	8586	Business	18000.00
0005433616110	8586	Business	18000.00
0005433616032	8586	Business	18000.00
0005433616268	8586	Business	18000.00
0005433616185	8586	Business	18000.00
0005433616312	8586	Business	18000.00
0005433616260	8586	Business	18000.00
0005433615997	8586	Business	18000.00
0005433616267	8586	Economy	6600.00
0005433616126	8586	Economy	6600.00
0005433615843	8586	Economy	6600.00
0005433616111	8586	Economy	6000.00
0005433616229	8586	Economy	6000.00
0005433616400	8586	Economy	6000.00
0005433616372	8586	Economy	6000.00
0005433616324	8586	Economy	6000.00
0005433616371	8586	Economy	6000.00
0005433616161	8586	Economy	6000.00
0005433615897	8586	Economy	6000.00
0005433615849	8586	Economy	6000.00
0005433615959	8586	Economy	6000.00
0005433616124	8586	Economy	6000.00
0005433615925	8586	Economy	6000.00
0005433616208	8586	Economy	6000.00
0005433615665	8586	Economy	6000.00
0005433615935	8586	Economy	6000.00
0005433615844	8586	Economy	6000.00
0005433616323	8586	Economy	6000.00
0005433615946	8586	Economy	6000.00
0005433616230	8586	Economy	6000.00
0005433615999	8586	Economy	6000.00
0005433616282	8586	Economy	6000.00
0005433616207	8586	Economy	6000.00
0005433615971	8586	Economy	6000.00
0005433616031	8586	Economy	6000.00
0005433615858	8586	Economy	6000.00
0005433615887	8586	Economy	6000.00
0005433616215	8586	Economy	6000.00
0005433615664	8586	Economy	6000.00
0005433616102	8586	Economy	6000.00
0005433616143	8586	Economy	6000.00
0005433615924	8586	Economy	6600.00
0005433615992	8586	Economy	6600.00
0005433615973	8586	Economy	6600.00
0005433615980	8586	Economy	6000.00
0005433616373	8586	Economy	6000.00
0005433616127	8586	Economy	6600.00
0005433615666	8586	Economy	6000.00
0005433616142	8586	Economy	6000.00
0005433615942	8586	Economy	6000.00
0005433616055	8586	Economy	6000.00
0005433616203	8586	Economy	6000.00
0005433616340	8586	Economy	6000.00
0005433616113	8586	Economy	6000.00
0005433616302	8586	Economy	6000.00
0005433616365	8586	Economy	6000.00
0005433616301	8586	Economy	6000.00
0005433615979	8586	Economy	6000.00
0005433616401	8586	Economy	6000.00
0005433616361	8586	Economy	6000.00
0005433616201	8586	Economy	6000.00
0005433616314	8586	Economy	6000.00
0005433616162	8586	Economy	6000.00
0005433616200	8586	Economy	6000.00
0005433615923	8586	Economy	6000.00
0005433615944	8586	Economy	6000.00
0005433615831	8586	Economy	6000.00
0005433616070	8586	Economy	6000.00
0005433616163	8586	Economy	6000.00
0005433616339	8586	Economy	6000.00
0005433616024	8586	Economy	6000.00
0005433615859	8586	Economy	6000.00
0005433615857	8586	Economy	6000.00
0005433615972	8586	Economy	6000.00
0005433616053	8586	Economy	6000.00
0005434265612	8587	Business	18000.00
0005432035721	8587	Business	18000.00
0005434149968	8587	Business	18000.00
0005432336373	8587	Business	18000.00
0005435286830	8587	Business	18000.00
0005434265699	8587	Business	18000.00
0005435286840	8587	Business	18000.00
0005435007680	8587	Business	18000.00
0005435007685	8587	Business	18000.00
0005432336370	8587	Business	18000.00
0005434229805	8587	Business	18000.00
0005434229902	8587	Business	18000.00
0005434265751	8587	Business	18000.00
0005432035730	8587	Business	18000.00
0005435007679	8587	Business	18000.00
0005435007689	8587	Business	18000.00
0005434149986	8587	Business	18000.00
0005434149969	8587	Business	18000.00
0005432047654	8587	Business	18000.00
0005435286832	8587	Business	18000.00
0005434229835	8587	Business	18000.00
0005433690984	8587	Business	18000.00
0005435286826	8587	Economy	6600.00
0005433534559	8587	Economy	6600.00
0005434265696	8587	Economy	6600.00
0005435286829	8587	Economy	6600.00
0005435286847	8587	Economy	6600.00
0005434149939	8587	Economy	6000.00
0005435286813	8587	Economy	6000.00
0005432336374	8587	Economy	6000.00
0005435286824	8587	Economy	6000.00
0005434265677	8587	Economy	6000.00
0005435286816	8587	Economy	6000.00
0005433534560	8587	Economy	6000.00
0005434229782	8587	Economy	6000.00
0005434265541	8587	Economy	6000.00
0005434265620	8587	Economy	6000.00
0005432336371	8587	Economy	6000.00
0005435007686	8587	Economy	6000.00
0005434265697	8587	Economy	6000.00
0005435007683	8587	Economy	6000.00
0005434265708	8587	Economy	6000.00
0005435286823	8587	Economy	6000.00
0005434265651	8587	Economy	6000.00
0005435286821	8587	Economy	6000.00
0005432035719	8587	Economy	6000.00
0005435286827	8587	Economy	6000.00
0005432035728	8587	Economy	6000.00
0005434265661	8587	Economy	6000.00
0005435007676	8587	Economy	6000.00
0005434150002	8587	Economy	6000.00
0005434229840	8587	Economy	6000.00
0005434311289	8587	Economy	6000.00
0005434229726	8587	Economy	6000.00
0005432035731	8587	Economy	6000.00
0005435286833	8587	Economy	6000.00
0005434229806	8587	Economy	6000.00
0005434265608	8587	Economy	6000.00
0005435007684	8587	Economy	6000.00
0005434229866	8587	Economy	6000.00
0005435286846	8587	Economy	6000.00
0005434265643	8587	Economy	6000.00
0005435286845	8587	Economy	6000.00
0005434265649	8587	Economy	6000.00
0005435286841	8587	Economy	6000.00
0005432035726	8587	Economy	6000.00
0005434265676	8587	Economy	6000.00
0005432035718	8587	Economy	6000.00
0005435286843	8587	Economy	6000.00
0005434229903	8587	Economy	6000.00
0005435286822	8587	Economy	6000.00
0005435286839	8587	Economy	6000.00
0005434229826	8587	Economy	6000.00
0005435286836	8587	Economy	6000.00
0005435286817	8587	Economy	6000.00
0005433815560	8587	Economy	6000.00
0005435286835	8587	Economy	6000.00
0005434265698	8587	Economy	6000.00
0005432035734	8587	Economy	6000.00
0005432035723	8587	Economy	6600.00
0005435286828	8587	Economy	6600.00
0005435286815	8587	Economy	6600.00
0005434265644	8587	Economy	6600.00
0005435286838	8587	Economy	6000.00
0005435286820	8587	Economy	6000.00
0005435286825	8587	Economy	6000.00
0005432047657	8587	Economy	6600.00
0005432336372	8587	Economy	6000.00
0005432035729	8587	Economy	6000.00
0005435286851	8587	Economy	6000.00
0005435007691	8587	Economy	6000.00
0005433690983	8587	Economy	6000.00
0005433689969	8587	Economy	6000.00
0005432035722	8587	Economy	6000.00
0005433815520	8587	Economy	6000.00
0005435286837	8587	Economy	6000.00
0005435007687	8587	Economy	6000.00
0005435007678	8587	Economy	6000.00
0005434265653	8587	Economy	6000.00
0005433815521	8587	Economy	6000.00
0005432035725	8587	Economy	6000.00
0005432035732	8587	Economy	6000.00
0005435286848	8587	Economy	6000.00
0005435286811	8587	Economy	6000.00
0005435286849	8587	Economy	6000.00
0005432035720	8587	Economy	6000.00
0005434229841	8587	Economy	6000.00
0005433815561	8587	Economy	6000.00
0005434265656	8587	Economy	6000.00
0005435007688	8587	Economy	6000.00
0005434229849	8587	Economy	6000.00
0005435286831	8587	Economy	6000.00
0005434265652	8587	Economy	6000.00
0005435007690	8587	Economy	6000.00
0005435286814	8587	Economy	6000.00
0005435286818	8587	Economy	6000.00
0005432336369	8587	Economy	6000.00
0005434150001	8587	Economy	6000.00
0005435286842	8587	Economy	6000.00
0005434229839	8587	Economy	6000.00
0005432047656	8587	Economy	6000.00
0005434229904	8587	Economy	6000.00
0005432035733	8587	Economy	6000.00
0005432035735	8587	Economy	6000.00
0005435007682	8587	Economy	6000.00
0005432035724	8587	Economy	6000.00
0005435286812	8587	Economy	6000.00
0005435286819	8587	Economy	6000.00
0005435286850	8587	Economy	6000.00
0005434265645	8587	Economy	6000.00
0005432336375	8587	Economy	6000.00
0005434265650	8587	Economy	6000.00
0005435286844	8587	Economy	6000.00
0005434265551	8587	Economy	6000.00
0005435007677	8587	Economy	6000.00
0005434265646	8587	Economy	6000.00
0005434229848	8587	Economy	6000.00
0005432047655	8587	Economy	6000.00
0005435286834	8587	Economy	6000.00
0005432035727	8587	Economy	6000.00
0005435286852	8587	Economy	6000.00
0005434265621	8587	Economy	6000.00
0005435007681	8587	Economy	6000.00
0005434229783	8587	Economy	6000.00
0005434639953	12616	Economy	16200.00
0005434639907	12616	Economy	16200.00
0005433202772	12616	Economy	14800.00
0005433202775	12616	Economy	14800.00
0005434639757	12616	Economy	14800.00
0005433202776	12616	Economy	14800.00
0005433202777	12616	Economy	14800.00
0005434639763	12616	Economy	14800.00
0005434639863	12616	Economy	14800.00
0005434639829	12616	Economy	14800.00
0005434639879	12616	Economy	14800.00
0005433202779	12616	Economy	14800.00
0005434639807	12616	Economy	14800.00
0005434639905	12616	Economy	14800.00
0005434639878	12616	Economy	14800.00
0005434639940	12616	Economy	14800.00
0005434639707	12616	Economy	14800.00
0005434639755	12616	Economy	14800.00
0005434639950	12616	Economy	14800.00
0005434639823	12616	Economy	14800.00
0005434639877	12616	Economy	14800.00
0005433202773	12616	Economy	14800.00
0005434639775	12616	Economy	14800.00
0005433202780	12616	Economy	14800.00
0005433202781	12616	Economy	14800.00
0005433202778	12616	Economy	14800.00
0005434639776	12616	Economy	14800.00
0005433202774	12616	Economy	14800.00
0005434639764	12616	Economy	14800.00
0005434639809	12616	Economy	14800.00
0005433202771	12616	Economy	14800.00
0005434639808	12616	Economy	14800.00
0005434639904	12616	Economy	14800.00
0005432290717	23341	Economy	16200.00
0005434640043	23341	Economy	16200.00
0005434640037	23341	Economy	16200.00
0005434640041	23341	Economy	16200.00
0005434640039	23341	Economy	14800.00
0005433202641	23341	Economy	14800.00
0005434640042	23341	Economy	14800.00
0005434640026	23341	Economy	14800.00
0005433202666	23341	Economy	14800.00
0005433202621	23341	Economy	14800.00
0005434640046	23341	Economy	14800.00
0005434640040	23341	Economy	14800.00
0005433202640	23341	Economy	14800.00
0005434640038	23341	Economy	14800.00
0005434640024	23341	Economy	14800.00
0005432290719	23341	Economy	14800.00
0005433202662	23341	Economy	14800.00
0005434640045	23341	Economy	14800.00
0005432290718	23341	Economy	14800.00
0005434640022	23341	Economy	14800.00
0005433202678	23341	Economy	14800.00
0005433202668	23341	Economy	14800.00
0005433202634	23341	Economy	14800.00
0005434640034	23341	Economy	14800.00
0005433202653	23341	Economy	14800.00
0005433202577	23341	Economy	14800.00
0005434640048	23341	Economy	14800.00
0005434640035	23341	Economy	14800.00
0005434640028	23341	Economy	14800.00
0005434640025	23341	Economy	14800.00
0005434640031	23341	Economy	14800.00
0005433202576	23341	Economy	14800.00
0005434640032	23341	Economy	14800.00
0005433202609	23341	Economy	14800.00
0005434640047	23341	Economy	14800.00
0005433202635	23341	Economy	14800.00
0005433202643	23341	Economy	14800.00
0005434640044	23341	Economy	14800.00
0005434640023	23341	Economy	14800.00
0005434640036	23341	Economy	14800.00
0005433202701	23341	Economy	14800.00
0005434640029	23341	Economy	14800.00
0005434640030	23341	Economy	14800.00
0005434640033	23341	Economy	14800.00
0005433202679	23341	Economy	14800.00
0005434640027	23341	Economy	14800.00
0005432329697	21100	Business	18900.00
0005432383955	21100	Business	18900.00
0005432383909	21100	Business	18900.00
0005432329478	21100	Business	18900.00
0005432329594	21100	Business	18900.00
0005432329627	21100	Business	18900.00
0005432329663	21100	Business	18900.00
0005432329794	21100	Business	18900.00
0005432329653	21100	Business	18900.00
0005432384003	21100	Business	18900.00
0005432329736	21100	Business	18900.00
0005432383921	21100	Business	18900.00
0005432329437	21100	Economy	6300.00
0005432383913	21100	Economy	6300.00
0005432329472	21100	Economy	6300.00
0005432329536	21100	Economy	6300.00
0005432054389	21100	Economy	6300.00
0005432383896	21100	Economy	6300.00
0005432054390	21100	Economy	6300.00
0005432383859	21100	Economy	6300.00
0005432383954	21100	Economy	6300.00
0005432384067	21100	Economy	6900.00
0005432329600	21100	Economy	6900.00
0005432383858	21100	Economy	6900.00
0005432329696	21100	Economy	6900.00
0005432384088	21100	Economy	6900.00
0005432329442	21100	Economy	6300.00
0005432383920	21100	Economy	6300.00
0005432383974	21100	Economy	6300.00
0005432384016	21100	Economy	6300.00
0005432329568	21100	Economy	6300.00
0005432383774	21100	Economy	6300.00
0005432329576	21100	Economy	6300.00
0005432329737	21100	Economy	6300.00
0005432383899	21100	Economy	6300.00
0005432383775	21100	Economy	6300.00
0005432383768	21100	Economy	6300.00
0005432383898	21100	Economy	6300.00
0005432329581	21100	Economy	6300.00
0005432329408	21100	Economy	6300.00
0005432329584	21100	Economy	6300.00
0005432329692	21100	Economy	6300.00
0005432329277	21100	Economy	6300.00
0005432384068	21100	Economy	6300.00
0005432383893	21100	Economy	6300.00
0005432329722	21100	Economy	6300.00
0005432384005	21100	Economy	6300.00
0005432383938	21100	Economy	6300.00
0005432329541	21100	Economy	6300.00
0005432329795	21100	Economy	6300.00
0005432383892	21100	Economy	6300.00
0005432383730	21100	Economy	6300.00
0005432383995	21100	Economy	6300.00
0005432329543	21100	Economy	6300.00
0005432329666	21100	Economy	6300.00
0005432383977	21100	Economy	6300.00
0005432329524	21100	Economy	6300.00
0005432383937	21100	Economy	6300.00
0005432329601	21100	Economy	6300.00
0005432383745	21100	Economy	6300.00
0005432329673	21100	Economy	6300.00
0005432329409	21100	Economy	6300.00
0005432383797	21100	Economy	6300.00
0005432329475	21100	Economy	6300.00
0005432329626	21100	Economy	6300.00
0005432384087	21100	Economy	6300.00
0005432329583	21100	Economy	6300.00
0005432329620	21100	Economy	6300.00
0005432383990	21100	Economy	6300.00
0005432329474	21100	Economy	6300.00
0005432329793	21100	Economy	6300.00
0005432329761	21100	Economy	6300.00
0005432329537	21100	Economy	6300.00
0005432329780	21100	Economy	6300.00
0005432383796	21100	Economy	6300.00
0005432329463	21100	Economy	6300.00
0005432329542	21100	Economy	6300.00
0005432384004	21100	Economy	6300.00
0005432383716	21100	Economy	6300.00
0005432329564	21100	Economy	6300.00
0005432054388	21100	Economy	6300.00
0005432329503	21100	Economy	6300.00
0005432384060	21100	Economy	6300.00
0005432329592	21100	Economy	6300.00
0005432383729	21100	Economy	6300.00
0005432329525	21100	Economy	6300.00
0005432329605	21100	Economy	6300.00
0005432329504	21100	Economy	6300.00
0005432329779	21100	Economy	6300.00
0005432383816	21100	Economy	6300.00
0005432329514	21100	Economy	6300.00
0005432329400	21100	Economy	6300.00
0005432329749	21100	Economy	6300.00
0005432383967	21100	Economy	6300.00
0005432383703	21100	Economy	6300.00
0005432329961	31268	Business	18900.00
0005432384241	31268	Business	18900.00
0005432384234	31268	Business	18900.00
0005432329963	31268	Business	18900.00
0005432384259	31268	Business	18900.00
0005432384268	31268	Business	18900.00
0005432329953	31268	Business	18900.00
0005432329947	31268	Business	18900.00
0005432384248	31268	Business	18900.00
0005432329962	31268	Business	18900.00
0005432384240	31268	Business	18900.00
0005432329967	31268	Economy	6300.00
0005432329949	31268	Economy	6300.00
0005432384243	31268	Economy	6300.00
0005432384262	31268	Economy	6300.00
0005432329964	31268	Economy	6300.00
0005432384260	31268	Economy	6300.00
0005432329957	31268	Economy	6300.00
0005432287329	31268	Economy	6900.00
0005432384238	31268	Economy	6900.00
0005432384252	31268	Economy	6900.00
0005432384247	31268	Economy	6300.00
0005432329943	31268	Economy	6300.00
0005432329945	31268	Economy	6300.00
0005432329940	31268	Economy	6300.00
0005432329960	31268	Economy	6300.00
0005432384244	31268	Economy	6300.00
0005432384257	31268	Economy	6300.00
0005432329971	31268	Economy	6300.00
0005432384239	31268	Economy	6300.00
0005432287328	31268	Economy	6300.00
0005432384267	31268	Economy	6300.00
0005432848859	31268	Economy	6300.00
0005432329942	31268	Economy	6300.00
0005432384235	31268	Economy	6300.00
0005432329946	31268	Economy	6300.00
0005432848866	31268	Economy	6300.00
0005432384250	31268	Economy	6300.00
0005432384264	31268	Economy	6300.00
0005432384265	31268	Economy	6300.00
0005432329965	31268	Economy	6300.00
0005432384258	31268	Economy	6300.00
0005432384246	31268	Economy	6300.00
0005432384253	31268	Economy	6300.00
0005432329972	31268	Economy	6300.00
0005432329950	31268	Economy	6300.00
0005432329958	31268	Economy	6300.00
0005432287330	31268	Economy	6300.00
0005432329959	31268	Economy	6300.00
0005432384263	31268	Economy	6300.00
0005432384261	31268	Economy	6300.00
0005432384245	31268	Economy	6300.00
0005432384236	31268	Economy	6300.00
0005432384256	31268	Economy	6300.00
0005432329954	31268	Economy	6300.00
0005432329955	31268	Economy	6300.00
0005432848881	31268	Economy	6300.00
0005432329956	31268	Economy	6300.00
0005432848858	31268	Economy	6300.00
0005432384255	31268	Economy	6300.00
0005432384254	31268	Economy	6300.00
0005432329951	31268	Economy	6300.00
0005432329941	31268	Economy	6300.00
0005432848880	31268	Economy	6300.00
0005432329966	31268	Economy	6300.00
0005432329952	31268	Economy	6300.00
0005432329969	31268	Economy	6300.00
0005432384249	31268	Economy	6300.00
0005432329944	31268	Economy	6300.00
0005432384242	31268	Economy	6300.00
0005432329973	31268	Economy	6300.00
0005432329968	31268	Economy	6300.00
0005432329970	31268	Economy	6300.00
0005432384251	31268	Economy	6300.00
0005432384266	31268	Economy	6300.00
0005432384237	31268	Economy	6300.00
0005432329948	31268	Economy	6300.00
0005432425802	13359	Business	12700.00
0005432425760	13359	Business	12700.00
0005432425758	13359	Business	12700.00
0005432425820	13359	Business	12700.00
0005432425784	13359	Business	12700.00
0005432425757	13359	Business	12700.00
0005432425763	13359	Business	12700.00
0005432425755	13359	Business	12700.00
0005432425792	13359	Economy	4200.00
0005432425761	13359	Economy	4200.00
0005432425787	13359	Economy	4200.00
0005432425785	13359	Economy	4200.00
0005432425777	13359	Economy	4200.00
0005432425775	13359	Economy	4200.00
0005432425786	13359	Economy	4200.00
0005432425770	13359	Economy	4200.00
0005432425819	13359	Economy	4200.00
0005432425774	13359	Economy	4700.00
0005432425803	13359	Economy	4700.00
0005432425772	13359	Economy	4700.00
0005432425762	13359	Economy	4700.00
0005432425781	13359	Economy	4700.00
0005432425818	13359	Economy	4200.00
0005432425779	13359	Economy	4200.00
0005432425782	13359	Economy	4200.00
0005432425799	13359	Economy	4200.00
0005432425804	13359	Economy	4200.00
0005432425798	13359	Economy	4200.00
0005432425768	13359	Economy	4200.00
0005432425766	13359	Economy	4200.00
0005432425776	13359	Economy	4200.00
0005432425783	13359	Economy	4200.00
0005432425808	13359	Economy	4200.00
0005432425794	13359	Economy	4200.00
0005432425790	13359	Economy	4200.00
0005432425759	13359	Economy	4200.00
0005432425756	13359	Economy	4200.00
0005432425778	13359	Economy	4200.00
0005432425810	13359	Economy	4200.00
0005432425821	13359	Economy	4200.00
0005432425809	13359	Economy	4200.00
0005432425769	13359	Economy	4200.00
0005432425771	13359	Economy	4200.00
0005432425797	13359	Economy	4200.00
0005432425801	13359	Economy	4200.00
0005432425814	13359	Economy	4200.00
0005432425813	13359	Economy	4200.00
0005432425812	13359	Economy	4200.00
0005432425795	13359	Economy	4200.00
0005432425767	13359	Economy	4200.00
0005432425806	13359	Economy	4200.00
0005432425780	13359	Economy	4200.00
0005432425789	13359	Economy	4200.00
0005432425807	13359	Economy	4200.00
0005432425791	13359	Economy	4200.00
0005432425765	13359	Economy	4200.00
0005432425764	13359	Economy	4200.00
0005432425817	13359	Economy	4200.00
0005432425773	13359	Economy	4200.00
0005432425800	13359	Economy	4200.00
0005432425796	13359	Economy	4200.00
0005432425788	13359	Economy	4200.00
0005432425816	13359	Economy	4200.00
0005432425793	13359	Economy	4200.00
0005432425805	13359	Economy	4200.00
0005432425815	13359	Economy	4200.00
0005432425811	13359	Economy	4200.00
0005432425341	30780	Business	12700.00
0005432425416	30780	Business	12700.00
0005432425388	30780	Business	12700.00
0005432425456	30780	Business	12700.00
0005432425434	30780	Business	12700.00
0005432425313	30780	Economy	4200.00
0005432425040	30780	Economy	4200.00
0005432425389	30780	Economy	4200.00
0005432425375	30780	Economy	4200.00
0005432425398	30780	Economy	4700.00
0005432425399	30780	Economy	4700.00
0005432425269	30780	Economy	4700.00
0005432425394	30780	Economy	4200.00
0005432425437	30780	Economy	4200.00
0005432425413	30780	Economy	4200.00
0005432425415	30780	Economy	4200.00
0005432425418	30780	Economy	4200.00
0005432425414	30780	Economy	4200.00
0005432425451	30780	Economy	4200.00
0005432425417	30780	Economy	4200.00
0005432425397	30780	Economy	4200.00
0005432425380	30780	Economy	4200.00
0005432425419	30780	Economy	4200.00
0005432425342	30780	Economy	4200.00
0005432425338	30780	Economy	4200.00
0005432425348	30780	Economy	4200.00
0005432425455	30780	Economy	4200.00
0005432425218	30780	Economy	4200.00
0005432425347	30780	Economy	4200.00
0005432425420	30780	Economy	4200.00
0005432425436	30780	Economy	4200.00
0005432425346	30780	Economy	4200.00
0005432425387	30780	Economy	4200.00
0005432425196	30780	Economy	4200.00
0005432425421	30780	Economy	4200.00
0005432425197	30780	Economy	4200.00
0005432425343	30780	Economy	4200.00
0005432425355	30780	Economy	4200.00
0005432425293	30780	Economy	4200.00
0005432425452	30780	Economy	4200.00
0005432425339	30780	Economy	4200.00
0005432425359	30780	Economy	4200.00
0005432425440	30780	Economy	4200.00
0005432425316	30780	Economy	4200.00
0005432425426	30780	Economy	4200.00
0005432425169	30780	Economy	4200.00
0005432425367	30780	Economy	4200.00
0005432425186	30780	Economy	4200.00
0005432425424	30780	Economy	4200.00
0005432425425	30780	Economy	4200.00
0005432818296	9612	Business	32600.00
0005432901986	9612	Business	32600.00
0005434157652	9612	Business	32600.00
0005432822420	9612	Business	32600.00
0005432822424	9612	Business	32600.00
0005432901949	9612	Business	32600.00
0005432818306	9612	Economy	10900.00
0005434157657	9612	Economy	10900.00
0005432818297	9612	Economy	10900.00
0005434186244	9612	Economy	10900.00
0005432818308	9612	Economy	10900.00
0005432818292	9612	Economy	10900.00
0005432901907	9612	Economy	11900.00
0005434186257	9612	Economy	11900.00
0005432818300	9612	Economy	11900.00
0005432901988	9612	Economy	11900.00
0005432818293	9612	Economy	11900.00
0005432289079	9612	Economy	10900.00
0005434157634	9612	Economy	10900.00
0005432901999	9612	Economy	10900.00
0005432902006	9612	Economy	10900.00
0005434157626	9612	Economy	10900.00
0005434157654	9612	Economy	10900.00
0005434157676	9612	Economy	10900.00
0005432822421	9612	Economy	10900.00
0005432818295	9612	Economy	10900.00
0005432822423	9612	Economy	10900.00
0005434157633	9612	Economy	10900.00
0005432818299	9612	Economy	10900.00
0005434157659	9612	Economy	10900.00
0005432901951	9612	Economy	10900.00
0005432901925	9612	Economy	10900.00
0005434186258	9612	Economy	10900.00
0005432818298	9612	Economy	10900.00
0005432289078	9612	Economy	10900.00
0005434157615	9612	Economy	10900.00
0005432902000	9612	Economy	10900.00
0005434157624	9612	Economy	10900.00
0005434186256	9612	Economy	10900.00
0005434448412	9612	Economy	10900.00
0005432818303	9612	Economy	10900.00
0005434157656	9612	Economy	10900.00
0005434186259	9612	Economy	10900.00
0005432901937	9612	Economy	10900.00
0005434157658	9612	Economy	10900.00
0005432901985	9612	Economy	10900.00
0005432901987	9612	Economy	10900.00
0005432901938	9612	Economy	10900.00
0005434157623	9612	Economy	10900.00
0005432901984	9612	Economy	10900.00
0005432818305	9612	Economy	10900.00
0005432822422	9612	Economy	10900.00
0005432818301	9612	Economy	10900.00
0005434157617	9612	Economy	10900.00
0005432818307	9612	Economy	10900.00
0005432818294	9612	Economy	10900.00
0005432901952	9612	Economy	10900.00
0005434157616	9612	Economy	10900.00
0005434157639	9612	Economy	10900.00
0005432818302	9612	Economy	10900.00
0005432818304	9612	Economy	10900.00
0005432818168	28996	Business	32600.00
0005432902096	28996	Business	32600.00
0005432818110	28996	Business	32600.00
0005432817957	28996	Business	32600.00
0005432817943	28996	Business	32600.00
0005432818134	28996	Business	32600.00
0005432902095	28996	Business	32600.00
0005432818025	28996	Business	32600.00
0005432822338	28996	Business	32600.00
0005432818120	28996	Economy	10900.00
0005432818034	28996	Economy	10900.00
0005432818089	28996	Economy	10900.00
0005432817982	28996	Economy	10900.00
0005432817956	28996	Economy	10900.00
0005432818067	28996	Economy	10900.00
0005432818033	28996	Economy	10900.00
0005432818094	28996	Economy	11900.00
0005432902101	28996	Economy	11900.00
0005432817942	28996	Economy	10900.00
0005432818102	28996	Economy	10900.00
0005432818054	28996	Economy	10900.00
0005432902098	28996	Economy	10900.00
0005432822347	28996	Economy	10900.00
0005432822363	28996	Economy	10900.00
0005432817929	28996	Economy	10900.00
0005432902093	28996	Economy	10900.00
0005434186280	28996	Economy	10900.00
0005432822402	28996	Economy	10900.00
0005432818181	28996	Economy	10900.00
0005434157696	28996	Economy	10900.00
0005432002135	28996	Economy	10900.00
0005432817986	28996	Economy	10900.00
0005434157698	28996	Economy	10900.00
0005432902092	28996	Economy	10900.00
0005432818011	28996	Economy	10900.00
0005432817930	28996	Economy	10900.00
0005432818119	28996	Economy	10900.00
0005432002134	28996	Economy	10900.00
0005432902102	28996	Economy	10900.00
0005432818012	28996	Economy	10900.00
0005432818113	28996	Economy	10900.00
0005434157697	28996	Economy	10900.00
0005432822364	28996	Economy	10900.00
0005434157694	28996	Economy	10900.00
0005434157695	28996	Economy	10900.00
0005434448393	28996	Economy	10900.00
0005432817983	28996	Economy	10900.00
0005432902097	28996	Economy	10900.00
0005434448387	28996	Economy	10900.00
0005432822362	28996	Economy	10900.00
0005432818176	28996	Economy	10900.00
0005432818107	28996	Economy	10900.00
0005432818157	28996	Economy	10900.00
0005432818182	28996	Economy	10900.00
0005432817974	28996	Economy	10900.00
0005432818093	28996	Economy	10900.00
0005432818055	28996	Economy	10900.00
0005432902104	28996	Economy	10900.00
0005432818071	28996	Economy	10900.00
0005432902103	28996	Economy	10900.00
0005432902100	28996	Economy	10900.00
0005432002136	28996	Economy	10900.00
0005432818098	28996	Economy	10900.00
0005432818109	28996	Economy	10900.00
0005432818106	28996	Economy	10900.00
0005432818053	28996	Economy	10900.00
0005432902099	28996	Economy	10900.00
0005432818047	28996	Economy	10900.00
0005432822351	28996	Economy	10900.00
0005434157699	28996	Economy	10900.00
0005432902094	28996	Economy	10900.00
0005434186279	28996	Economy	10900.00
0005432611812	15132	Economy	11000.00
0005432613977	15132	Economy	11000.00
0005435841105	15132	Economy	11000.00
0005435841118	15132	Economy	11000.00
0005435841839	15132	Economy	11000.00
0005432611811	15132	Economy	11000.00
0005432613976	15132	Economy	11000.00
0005432607645	31536	Economy	11000.00
0005432607644	31536	Economy	11000.00
0005432607650	31536	Economy	11000.00
0005432611801	31536	Economy	11000.00
0005432611800	31536	Economy	11000.00
0005432611773	31536	Economy	11000.00
0005432611788	31536	Economy	11000.00
0005432607628	31536	Economy	11000.00
0005432611774	31536	Economy	11000.00
0005432611789	31536	Economy	11000.00
0005433570766	11880	Business	105900.00
0005433570775	11880	Business	105900.00
0005433570779	11880	Business	105900.00
0005433570783	11880	Business	105900.00
0005432949269	11880	Business	105900.00
0005433570805	11880	Business	105900.00
0005433570794	11880	Business	105900.00
0005433570763	11880	Business	105900.00
0005433570811	11880	Business	105900.00
0005433570821	11880	Business	105900.00
0005433570773	11880	Business	105900.00
0005433570774	11880	Business	105900.00
0005433570767	11880	Business	105900.00
0005433570768	11880	Business	105900.00
0005433570803	11880	Business	105900.00
0005432949277	11880	Business	105900.00
0005433570804	11880	Economy	35300.00
0005432949208	11880	Economy	35300.00
0005433570806	11880	Economy	35300.00
0005432949150	11880	Economy	35300.00
0005433570801	11880	Economy	35300.00
0005433570776	11880	Economy	35300.00
0005433570790	11880	Economy	35300.00
0005433570825	11880	Economy	35300.00
0005432949209	11880	Economy	35300.00
0005433570802	11880	Economy	35300.00
0005432949200	11880	Economy	38800.00
0005433570826	11880	Economy	38800.00
0005433570822	11880	Economy	35300.00
0005432949253	11880	Economy	35300.00
0005432949232	11880	Economy	35300.00
0005433570823	11880	Economy	35300.00
0005433570789	11880	Economy	35300.00
0005433570807	11880	Economy	35300.00
0005432949306	11880	Economy	35300.00
0005433570817	11880	Economy	35300.00
0005432949351	11880	Economy	35300.00
0005432949270	11880	Economy	35300.00
0005432949380	11880	Economy	35300.00
0005433570769	11880	Economy	35300.00
0005433570814	11880	Economy	35300.00
0005433570793	11880	Economy	35300.00
0005433570800	11880	Economy	35300.00
0005433570781	11880	Economy	35300.00
0005433570799	11880	Economy	35300.00
0005433570788	11880	Economy	35300.00
0005433570786	11880	Economy	35300.00
0005432949381	11880	Economy	35300.00
0005433570772	11880	Economy	35300.00
0005433570785	11880	Economy	35300.00
0005433570792	11880	Economy	35300.00
0005432949403	11880	Economy	35300.00
0005433570827	11880	Economy	35300.00
0005433570791	11880	Economy	35300.00
0005432949431	11880	Economy	35300.00
0005433570764	11880	Economy	35300.00
0005432949352	11880	Economy	35300.00
0005433570771	11880	Economy	35300.00
0005433570820	11880	Economy	35300.00
0005433570810	11880	Economy	35300.00
0005432949307	11880	Economy	35300.00
0005433570797	11880	Economy	35300.00
0005433570815	11880	Economy	35300.00
0005433570812	11880	Economy	35300.00
0005432949299	11880	Economy	35300.00
0005432949278	11880	Economy	35300.00
0005433570795	11880	Economy	35300.00
0005432949402	11880	Economy	35300.00
0005432949302	11880	Economy	35300.00
0005433570770	11880	Economy	35300.00
0005433570798	11880	Economy	35300.00
0005433570780	11880	Economy	35300.00
0005433570819	11880	Economy	35300.00
0005433570816	11880	Economy	35300.00
0005433570824	11880	Economy	35300.00
0005432949151	11880	Economy	35300.00
0005433570818	11880	Economy	35300.00
0005433570787	11880	Economy	35300.00
0005433570765	11880	Economy	35300.00
0005433570808	11880	Economy	35300.00
0005433570782	11880	Economy	35300.00
0005433570784	11880	Economy	35300.00
0005433570809	11880	Economy	35300.00
0005433570778	11880	Economy	35300.00
0005433570796	11880	Economy	35300.00
0005433570777	11880	Economy	35300.00
0005433570813	11880	Economy	35300.00
0005433570277	25294	Business	105900.00
0005433570172	25294	Business	105900.00
0005433570255	25294	Business	105900.00
0005433570160	25294	Business	105900.00
0005433570345	25294	Business	105900.00
0005433570012	25294	Business	105900.00
0005433570384	25294	Business	105900.00
0005433570150	25294	Business	105900.00
0005433570246	25294	Business	105900.00
0005433570316	25294	Business	105900.00
0005433570341	25294	Business	105900.00
0005433570085	25294	Business	105900.00
0005433570138	25294	Business	105900.00
0005433570090	25294	Business	105900.00
0005433570275	25294	Business	105900.00
0005433570344	25294	Economy	35300.00
0005433570195	25294	Business	105900.00
0005433570129	25294	Economy	35300.00
0005433570233	25294	Economy	35300.00
0005433570121	25294	Economy	35300.00
0005433570159	25294	Economy	35300.00
0005432949626	25294	Economy	35300.00
0005433570320	25294	Economy	35300.00
0005433570339	25294	Economy	35300.00
0005433570168	25294	Economy	35300.00
0005433570254	25294	Economy	35300.00
0005433570113	25294	Economy	35300.00
0005433570200	25294	Economy	38800.00
0005433570367	25294	Economy	38800.00
0005433570343	25294	Economy	38800.00
0005432949629	25294	Economy	38800.00
0005433570139	25294	Economy	35300.00
0005433570266	25294	Economy	35300.00
0005433570128	25294	Economy	35300.00
0005433570588	25294	Economy	35300.00
0005432949633	25294	Economy	35300.00
0005433570313	25294	Economy	35300.00
0005433570340	25294	Economy	35300.00
0005433570438	25294	Economy	35300.00
0005433570437	25294	Economy	35300.00
0005433570170	25294	Economy	35300.00
0005433570179	25294	Economy	35300.00
0005433570111	25294	Economy	35300.00
0005433570314	25294	Economy	35300.00
0005432949632	25294	Economy	35300.00
0005433570267	25294	Economy	35300.00
0005432949631	25294	Economy	35300.00
0005432949617	25294	Economy	35300.00
0005433570315	25294	Economy	35300.00
0005433570457	25294	Economy	35300.00
0005433570319	25294	Economy	35300.00
0005433570308	25294	Economy	35300.00
0005433570087	25294	Economy	35300.00
0005433570260	25294	Economy	35300.00
0005432949625	25294	Economy	35300.00
0005433570041	25294	Economy	35300.00
0005432949627	25294	Economy	35300.00
0005433570221	25294	Economy	35300.00
0005433570178	25294	Economy	35300.00
0005432949620	25294	Economy	35300.00
0005432949636	25294	Economy	35300.00
0005432949630	25294	Economy	35300.00
0005433570294	25294	Economy	35300.00
0005432949619	25294	Economy	35300.00
0005432949622	25294	Economy	35300.00
0005433570167	25294	Economy	35300.00
0005432949613	25294	Economy	35300.00
0005433569842	25294	Economy	35300.00
0005433570329	25294	Economy	35300.00
0005432949614	25294	Economy	35300.00
0005432949615	25294	Economy	35300.00
0005433570270	25294	Economy	35300.00
0005433570338	25294	Economy	35300.00
0005433570449	25294	Economy	35300.00
0005432949616	25294	Economy	35300.00
0005433570261	25294	Economy	35300.00
0005432949635	25294	Economy	35300.00
0005432949611	25294	Economy	35300.00
0005432949624	25294	Economy	35300.00
0005432949634	25294	Economy	35300.00
0005433570042	25294	Economy	35300.00
0005433570278	25294	Economy	35300.00
0005433570413	25294	Economy	35300.00
0005432949621	25294	Economy	35300.00
0005433570091	25294	Economy	35300.00
0005432949618	25294	Economy	35300.00
0005433570307	25294	Economy	35300.00
0005433570110	25294	Economy	35300.00
0005432949612	25294	Economy	35300.00
0005433570333	25294	Economy	35300.00
0005433570086	25294	Economy	35300.00
0005432949628	25294	Economy	35300.00
0005433570222	25294	Economy	35300.00
0005432949623	25294	Economy	35300.00
0005433808482	30829	Business	117400.00
0005432430927	30829	Business	117400.00
0005434026741	30829	Business	117400.00
0005433808478	30829	Business	117400.00
0005434026738	30829	Business	117400.00
0005433808480	30829	Business	117400.00
0005432430901	30829	Economy	39100.00
0005434026742	30829	Economy	39100.00
0005434026734	30829	Economy	39100.00
0005434026740	30829	Economy	39100.00
0005433808483	30829	Economy	39100.00
0005432430911	30829	Economy	43000.00
0005432430924	30829	Economy	39100.00
0005432430947	30829	Economy	39100.00
0005432430931	30829	Economy	39100.00
0005432430912	30829	Economy	39100.00
0005432430928	30829	Economy	39100.00
0005432430910	30829	Economy	39100.00
0005433808479	30829	Economy	39100.00
0005432430933	30829	Economy	39100.00
0005433812964	30829	Economy	39100.00
0005433812963	30829	Economy	39100.00
0005434026739	30829	Economy	39100.00
0005432430902	30829	Economy	39100.00
0005433808484	30829	Economy	39100.00
0005432430919	30829	Economy	39100.00
0005433808481	30829	Economy	39100.00
0005432430932	30829	Economy	39100.00
0005433812962	30829	Economy	39100.00
0005432430923	30829	Economy	39100.00
0005434026737	30829	Economy	39100.00
0005432114294	5418	Business	67200.00
0005435340561	5418	Business	67200.00
0005434655490	5418	Business	67200.00
0005434655502	5418	Economy	22400.00
0005435340616	5418	Economy	22400.00
0005435555411	5418	Economy	22400.00
0005434655505	5418	Economy	22400.00
0005434655494	5418	Economy	22400.00
0005435340502	5418	Economy	24600.00
0005434655495	5418	Economy	24600.00
0005432114293	5418	Economy	22400.00
0005435340540	5418	Economy	22400.00
0005434655501	5418	Economy	22400.00
0005435340607	5418	Economy	22400.00
0005434655503	5418	Economy	22400.00
0005434656613	5418	Economy	22400.00
0005434656615	5418	Economy	22400.00
0005435340605	5418	Economy	22400.00
0005435340572	5418	Economy	22400.00
0005434656614	5418	Economy	22400.00
0005434655498	5418	Economy	22400.00
0005435340596	5418	Economy	22400.00
0005435340533	5418	Economy	22400.00
0005434655491	5418	Economy	22400.00
0005434655493	5418	Economy	22400.00
0005432114292	5418	Economy	22400.00
0005435340556	5418	Economy	22400.00
0005434655504	5418	Economy	22400.00
0005435555412	5418	Economy	22400.00
0005434655496	5418	Economy	22400.00
0005434655489	5418	Economy	22400.00
0005435340538	5418	Economy	22400.00
0005435340524	5418	Economy	22400.00
0005435340587	5418	Economy	22400.00
0005434655499	5418	Economy	22400.00
0005435340586	5418	Economy	22400.00
0005434655497	5418	Economy	22400.00
0005434655500	5418	Economy	22400.00
0005434655492	5418	Economy	22400.00
0005434655256	12551	Business	67200.00
0005434655293	12551	Business	67200.00
0005435340692	12551	Business	67200.00
0005434656604	12551	Business	67200.00
0005434655263	12551	Business	67200.00
0005434655198	12551	Business	67200.00
0005434655125	12551	Business	67200.00
0005434655350	12551	Business	67200.00
0005434655216	12551	Business	67200.00
0005435340685	12551	Business	67200.00
0005435340682	12551	Economy	22400.00
0005435340688	12551	Economy	22400.00
0005434655299	12551	Economy	22400.00
0005434655321	12551	Economy	22400.00
0005434655175	12551	Economy	22400.00
0005434655220	12551	Economy	22400.00
0005434655245	12551	Economy	22400.00
0005435340693	12551	Economy	24600.00
0005434655153	12551	Economy	24600.00
0005434655203	12551	Economy	24600.00
0005434656593	12551	Economy	24600.00
0005434655247	12551	Economy	22400.00
0005434655254	12551	Economy	22400.00
0005434656589	12551	Economy	22400.00
0005434655160	12551	Economy	22400.00
0005434655176	12551	Economy	22400.00
0005434655353	12551	Economy	22400.00
0005434655248	12551	Economy	22400.00
0005435340684	12551	Economy	22400.00
0005434655229	12551	Economy	22400.00
0005434655202	12551	Economy	22400.00
0005434655287	12551	Economy	22400.00
0005434655180	12551	Economy	22400.00
0005434655351	12551	Economy	22400.00
0005434655294	12551	Economy	22400.00
0005435340690	12551	Economy	22400.00
0005434655159	12551	Economy	22400.00
0005435340691	12551	Economy	22400.00
0005435340687	12551	Economy	22400.00
0005434655228	12551	Economy	22400.00
0005435340686	12551	Economy	22400.00
0005434656590	12551	Economy	22400.00
0005435340683	12551	Economy	22400.00
0005434655181	12551	Economy	22400.00
0005434655206	12551	Economy	22400.00
0005434655255	12551	Economy	22400.00
0005434655349	12551	Economy	22400.00
0005435340689	12551	Economy	22400.00
0005434655300	12551	Economy	22400.00
0005433717362	7426	Business	32000.00
0005435266229	7426	Business	32000.00
0005433717357	7426	Business	32000.00
0005433722428	7426	Business	32000.00
0005435266258	7426	Business	32000.00
0005433722448	7426	Business	32000.00
0005433717353	7426	Business	32000.00
0005433690981	7426	Business	32000.00
0005435266260	7426	Business	32000.00
0005433717347	7426	Economy	10700.00
0005433722430	7426	Economy	10700.00
0005433722444	7426	Economy	10700.00
0005433722439	7426	Economy	10700.00
0005432078262	7426	Economy	10700.00
0005432429015	7426	Economy	10700.00
0005433717361	7426	Economy	10700.00
0005433717358	7426	Economy	10700.00
0005433722440	7426	Economy	10700.00
0005433719232	7426	Economy	10700.00
0005432078261	7426	Economy	10700.00
0005433722443	7426	Economy	10700.00
0005432428998	7426	Economy	10700.00
0005433690982	7426	Economy	10700.00
0005433717363	7426	Economy	10700.00
0005433717365	7426	Economy	10700.00
0005432428999	7426	Economy	10700.00
0005432428988	7426	Economy	10700.00
0005433688865	7426	Economy	10700.00
0005433722441	7426	Economy	10700.00
0005435266220	7426	Economy	10700.00
0005433717340	7426	Economy	10700.00
0005435266259	7426	Economy	10700.00
0005432428984	7426	Economy	10700.00
0005435266252	7426	Economy	10700.00
0005433656765	7426	Economy	10700.00
0005435266256	7426	Economy	10700.00
0005433717344	7426	Economy	10700.00
0005435266228	7426	Economy	10700.00
0005433722429	7426	Economy	10700.00
0005433722427	7426	Economy	10700.00
0005433717350	7426	Economy	10700.00
0005432428997	7426	Economy	10700.00
0005433719234	7426	Economy	10700.00
0005433722435	7426	Economy	10700.00
0005433717338	7426	Economy	11700.00
0005433717356	7426	Economy	11700.00
0005433722445	7426	Economy	11700.00
0005432078263	7426	Economy	11700.00
0005435266253	7426	Economy	10700.00
0005433717345	7426	Economy	10700.00
0005433717364	7426	Economy	10700.00
0005435266261	7426	Economy	10700.00
0005433719233	7426	Economy	10700.00
0005433722433	7426	Economy	10700.00
0005433722442	7426	Economy	10700.00
0005435266250	7426	Economy	10700.00
0005432428995	7426	Economy	10700.00
0005433717339	7426	Economy	10700.00
0005433722436	7426	Economy	10700.00
0005433717349	7426	Economy	10700.00
0005435266230	7426	Economy	10700.00
0005433717351	7426	Economy	10700.00
0005433689967	7426	Economy	10700.00
0005433717341	7426	Economy	10700.00
0005432429016	7426	Economy	10700.00
0005435266293	7426	Economy	10700.00
0005433717355	7426	Economy	10700.00
0005433717343	7426	Economy	10700.00
0005435266233	7426	Economy	10700.00
0005433717342	7426	Economy	10700.00
0005433722432	7426	Economy	10700.00
0005435266221	7426	Economy	10700.00
0005432078260	7426	Economy	10700.00
0005433689968	7426	Economy	10700.00
0005433717346	7426	Economy	10700.00
0005433717348	7426	Economy	10700.00
0005433656764	7426	Economy	10700.00
0005432429014	7426	Economy	10700.00
0005433722434	7426	Economy	10700.00
0005433722438	7426	Economy	10700.00
0005433722431	7426	Economy	10700.00
0005433722437	7426	Economy	10700.00
0005433722446	7426	Economy	10700.00
0005433717354	7426	Economy	10700.00
0005433717359	7426	Economy	10700.00
0005433717360	7426	Economy	10700.00
0005433722447	7426	Economy	10700.00
0005432428996	7426	Economy	10700.00
0005433717352	7426	Economy	10700.00
0005433717084	29202	Business	32000.00
0005433717121	29202	Business	32000.00
0005433716966	29202	Business	32000.00
0005433716927	29202	Business	32000.00
0005433716809	29202	Business	32000.00
0005433716921	29202	Business	32000.00
0005433717022	29202	Economy	10700.00
0005432006846	29202	Economy	10700.00
0005433716962	29202	Economy	10700.00
0005433716810	29202	Economy	10700.00
0005433716658	29202	Economy	10700.00
0005433716946	29202	Economy	10700.00
0005433717062	29202	Economy	10700.00
0005433716864	29202	Economy	10700.00
0005433717122	29202	Economy	10700.00
0005433716694	29202	Economy	10700.00
0005432429026	29202	Economy	10700.00
0005433716785	29202	Economy	10700.00
0005433716955	29202	Economy	10700.00
0005433716971	29202	Economy	10700.00
0005433717089	29202	Economy	10700.00
0005433716802	29202	Economy	10700.00
0005433716872	29202	Economy	10700.00
0005433717024	29202	Economy	10700.00
0005433716992	29202	Economy	10700.00
0005433716923	29202	Economy	10700.00
0005433717040	29202	Economy	11700.00
0005433717104	29202	Economy	11700.00
0005433716994	29202	Economy	11700.00
0005433716830	29202	Economy	11700.00
0005433717119	29202	Economy	11700.00
0005433685556	29202	Economy	11700.00
0005433685554	29202	Economy	10700.00
0005433717077	29202	Economy	10700.00
0005433716854	29202	Economy	10700.00
0005433717034	29202	Economy	10700.00
0005433717055	29202	Economy	10700.00
0005433717090	29202	Economy	10700.00
0005433685552	29202	Economy	10700.00
0005433685557	29202	Economy	10700.00
0005433716947	29202	Economy	10700.00
0005433685555	29202	Economy	10700.00
0005433685559	29202	Economy	10700.00
0005433717064	29202	Economy	10700.00
0005433716972	29202	Economy	10700.00
0005433716858	29202	Economy	10700.00
0005433716963	29202	Economy	10700.00
0005433716974	29202	Economy	10700.00
0005433716919	29202	Economy	10700.00
0005433716931	29202	Economy	10700.00
0005432429025	29202	Economy	10700.00
0005433716954	29202	Economy	10700.00
0005433716937	29202	Economy	10700.00
0005432429027	29202	Economy	10700.00
0005432006845	29202	Economy	10700.00
0005433716973	29202	Economy	10700.00
0005433716967	29202	Economy	10700.00
0005433716871	29202	Economy	10700.00
0005433716920	29202	Economy	10700.00
0005433716870	29202	Economy	10700.00
0005433685553	29202	Economy	10700.00
0005433716968	29202	Economy	10700.00
0005433716928	29202	Economy	10700.00
0005433685558	29202	Economy	10700.00
0005433716918	29202	Economy	10700.00
0005433716930	29202	Economy	10700.00
0005433717063	29202	Economy	10700.00
0005433717088	29202	Economy	10700.00
0005433716880	29202	Economy	10700.00
0005434182515	8662	Business	36500.00
0005434143808	8662	Business	36500.00
0005434184699	8662	Business	36500.00
0005434095675	8662	Business	36500.00
0005434095679	8662	Business	36500.00
0005434182454	8662	Business	36500.00
0005434143802	8662	Business	36500.00
0005434326061	8662	Economy	12200.00
0005434143798	8662	Economy	12200.00
0005434182457	8662	Economy	13400.00
0005434143811	8662	Economy	13400.00
0005434143795	8662	Economy	13400.00
0005434095682	8662	Economy	12200.00
0005434182477	8662	Economy	12200.00
0005434143816	8662	Economy	12200.00
0005434095672	8662	Economy	12200.00
0005434095681	8662	Economy	12200.00
0005434182406	8662	Economy	12200.00
0005434143793	8662	Economy	12200.00
0005434143814	8662	Economy	12200.00
0005434143815	8662	Economy	12200.00
0005434143812	8662	Economy	12200.00
0005434095683	8662	Economy	12200.00
0005434143796	8662	Economy	12200.00
0005434182474	8662	Economy	12200.00
0005434095676	8662	Economy	12200.00
0005434143817	8662	Economy	12200.00
0005434143797	8662	Economy	12200.00
0005434182478	8662	Economy	12200.00
0005434143801	8662	Economy	12200.00
0005434182494	8662	Economy	12200.00
0005434143807	8662	Economy	12200.00
0005434143800	8662	Economy	12200.00
0005434143805	8662	Economy	12200.00
0005434143799	8662	Economy	12200.00
0005434095677	8662	Economy	12200.00
0005434143810	8662	Economy	12200.00
0005434182466	8662	Economy	12200.00
0005434143794	8662	Economy	12200.00
0005434143803	8662	Economy	12200.00
0005434143806	8662	Economy	12200.00
0005434182425	8662	Economy	12200.00
0005434182464	8662	Economy	12200.00
0005434182431	8662	Economy	12200.00
0005434143804	8662	Economy	12200.00
0005434326060	8662	Economy	12200.00
0005434143813	8662	Economy	12200.00
0005434095680	8662	Economy	12200.00
0005434095678	8662	Economy	12200.00
0005434182465	8662	Economy	12200.00
0005434143809	8662	Economy	12200.00
0005434095673	8662	Economy	12200.00
0005434143792	8662	Economy	12200.00
0005434182430	8662	Economy	12200.00
0005434095674	8662	Economy	12200.00
0005434326278	11669	Business	36500.00
0005434182529	11669	Business	36500.00
0005435860697	11669	Business	36500.00
0005434182528	11669	Business	36500.00
0005434183636	11669	Business	36500.00
0005435860701	11669	Economy	12200.00
0005434184722	11669	Economy	12200.00
0005434095557	11669	Economy	12200.00
0005434182533	11669	Economy	12200.00
0005434095519	11669	Economy	13400.00
0005434326279	11669	Economy	13400.00
0005435860700	11669	Economy	12200.00
0005434095544	11669	Economy	12200.00
0005434095612	11669	Economy	12200.00
0005434182527	11669	Economy	12200.00
0005434095520	11669	Economy	12200.00
0005435860702	11669	Economy	12200.00
0005434143748	11669	Economy	12200.00
0005434095568	11669	Economy	12200.00
0005434184721	11669	Economy	12200.00
0005434183635	11669	Economy	12200.00
0005434095590	11669	Economy	12200.00
0005434095572	11669	Economy	12200.00
0005434095505	11669	Economy	12200.00
0005434326281	11669	Economy	12200.00
0005435860695	11669	Economy	12200.00
0005434095589	11669	Economy	12200.00
0005435860696	11669	Economy	12200.00
0005434182530	11669	Economy	12200.00
0005434143747	11669	Economy	12200.00
0005434183637	11669	Economy	12200.00
0005434182531	11669	Economy	12200.00
0005434182532	11669	Economy	12200.00
0005435860698	11669	Economy	12200.00
0005435860699	11669	Economy	12200.00
0005433399050	1423	Business	33000.00
0005435732693	1423	Business	33000.00
0005433399056	1423	Business	33000.00
0005433399175	1423	Business	33000.00
0005435732701	1423	Business	33000.00
0005433398928	1423	Business	33000.00
0005433398970	1423	Business	33000.00
0005433398824	1423	Business	33000.00
0005433399134	1423	Business	33000.00
0005432906581	1423	Business	33000.00
0005433399060	1423	Business	33000.00
0005433398926	1423	Economy	11000.00
0005433399070	1423	Economy	11000.00
0005433399136	1423	Economy	11000.00
0005433399049	1423	Economy	11000.00
0005435732688	1423	Economy	11000.00
0005433398997	1423	Economy	11000.00
0005435725766	1423	Economy	11000.00
0005433399073	1423	Economy	11000.00
0005433399313	1423	Economy	12100.00
0005433399113	1423	Economy	12100.00
0005433399104	1423	Economy	12100.00
0005433399135	1423	Economy	12100.00
0005435732687	1423	Economy	12100.00
0005433399005	1423	Economy	11000.00
0005432297350	1423	Economy	11000.00
0005433399200	1423	Economy	11000.00
0005433399004	1423	Economy	11000.00
0005435725763	1423	Economy	11000.00
0005433399312	1423	Economy	11000.00
0005435725764	1423	Economy	11000.00
0005433398971	1423	Economy	11000.00
0005435725762	1423	Economy	11000.00
0005433398944	1423	Economy	11000.00
0005433399074	1423	Economy	11000.00
0005433398783	1423	Economy	11000.00
0005433398898	1423	Economy	11000.00
0005433399170	1423	Economy	11000.00
0005433398996	1423	Economy	11000.00
0005435725765	1423	Economy	11000.00
0005433398879	1423	Economy	11000.00
0005433399115	1423	Economy	11000.00
0005433398995	1423	Economy	11000.00
0005433399146	1423	Economy	11000.00
0005433398943	1423	Economy	11000.00
0005433399057	1423	Economy	11000.00
0005435732697	1423	Economy	11000.00
0005433399071	1423	Economy	11000.00
0005435732691	1423	Economy	11000.00
0005433399103	1423	Economy	11000.00
0005433398942	1423	Economy	11000.00
0005433399062	1423	Economy	11000.00
0005433457084	1423	Economy	11000.00
0005435732689	1423	Economy	11000.00
0005433399079	1423	Economy	11000.00
0005435732699	1423	Economy	11000.00
0005435732696	1423	Economy	11000.00
0005433398917	1423	Economy	11000.00
0005433398963	1423	Economy	11000.00
0005433398916	1423	Economy	11000.00
0005435732692	1423	Economy	11000.00
0005432297351	1423	Economy	11000.00
0005433399061	1423	Economy	11000.00
0005433399144	1423	Economy	11000.00
0005433399145	1423	Economy	11000.00
0005433399020	1423	Economy	11000.00
0005435732690	1423	Economy	11000.00
0005433399064	1423	Economy	11000.00
0005433399021	1423	Economy	11000.00
0005433399112	1423	Economy	11000.00
0005435732694	1423	Economy	11000.00
0005435732702	1423	Economy	11000.00
0005433399163	1423	Economy	11000.00
0005433399023	1423	Economy	11000.00
0005432906579	1423	Economy	11000.00
0005433399038	1423	Economy	11000.00
0005435732700	1423	Economy	11000.00
0005433457083	1423	Economy	11000.00
0005433398964	1423	Economy	11000.00
0005435732695	1423	Economy	11000.00
0005435732698	1423	Economy	11000.00
0005433399016	1423	Economy	11000.00
0005433399114	1423	Economy	11000.00
0005433398927	1423	Economy	11000.00
0005433398890	1423	Economy	11000.00
0005433399414	19267	Business	33000.00
0005435732550	19267	Business	33000.00
0005433399411	19267	Business	33000.00
0005435732591	19267	Business	33000.00
0005435732551	19267	Business	33000.00
0005433399403	19267	Business	33000.00
0005433399413	19267	Economy	11000.00
0005435732557	19267	Economy	11000.00
0005433399405	19267	Economy	11000.00
0005433399393	19267	Economy	11000.00
0005433399391	19267	Economy	11000.00
0005433399401	19267	Economy	11000.00
0005435732578	19267	Economy	12100.00
0005435732629	19267	Economy	12100.00
0005433399402	19267	Economy	11000.00
0005433399396	19267	Economy	11000.00
0005433399404	19267	Economy	11000.00
0005433399381	19267	Economy	11000.00
0005433399407	19267	Economy	11000.00
0005433399397	19267	Economy	11000.00
0005433399384	19267	Economy	11000.00
0005433399410	19267	Economy	11000.00
0005433399406	19267	Economy	11000.00
0005433399409	19267	Economy	11000.00
0005433399388	19267	Economy	11000.00
0005435732609	19267	Economy	11000.00
0005433399389	19267	Economy	11000.00
0005433399392	19267	Economy	11000.00
0005433399395	19267	Economy	11000.00
0005435732561	19267	Economy	11000.00
0005433399399	19267	Economy	11000.00
0005433399408	19267	Economy	11000.00
0005433399387	19267	Economy	11000.00
0005433399394	19267	Economy	11000.00
0005435732549	19267	Economy	11000.00
0005433399398	19267	Economy	11000.00
0005433399383	19267	Economy	11000.00
0005433399385	19267	Economy	11000.00
0005433399382	19267	Economy	11000.00
0005435732579	19267	Economy	11000.00
0005433399400	19267	Economy	11000.00
0005435732628	19267	Economy	11000.00
0005435732552	19267	Economy	11000.00
0005433457053	19267	Economy	11000.00
0005435732610	19267	Economy	11000.00
0005433399390	19267	Economy	11000.00
0005435732593	19267	Economy	11000.00
0005433399386	19267	Economy	11000.00
0005435732592	19267	Economy	11000.00
0005433399412	19267	Economy	11000.00
0005434444037	17373	Economy	15600.00
0005434444062	17373	Economy	14100.00
0005434444064	17373	Economy	14100.00
0005434444003	17373	Economy	14100.00
0005434444002	17373	Economy	14100.00
0005434444039	17373	Economy	14100.00
0005434444065	17373	Economy	14100.00
0005434444068	17373	Economy	14100.00
0005434444018	17373	Economy	14100.00
0005434444017	17373	Economy	14100.00
0005434443974	17373	Economy	14100.00
0005434444012	17373	Economy	14100.00
0005434444038	17373	Economy	14100.00
0005434444011	17373	Economy	14100.00
0005434443959	17373	Economy	14100.00
0005434444063	17373	Economy	14100.00
0005434444151	20606	Economy	15600.00
0005434444150	20606	Economy	15600.00
0005434444152	20606	Economy	14100.00
0005434444144	20606	Economy	14100.00
0005434444146	20606	Economy	14100.00
0005434444153	20606	Economy	14100.00
0005434444145	20606	Economy	14100.00
0005434444148	20606	Economy	14100.00
0005434444147	20606	Economy	14100.00
0005434444142	20606	Economy	14100.00
0005434444141	20606	Economy	14100.00
0005434444149	20606	Economy	14100.00
0005434444143	20606	Economy	14100.00
0005435377637	7273	Economy	5800.00
0005435377627	7273	Economy	5800.00
0005434954717	7273	Economy	5800.00
0005435377638	7273	Economy	5800.00
0005435377628	7273	Economy	5800.00
0005434954687	28311	Economy	5800.00
0005434954692	28311	Economy	5800.00
0005434954688	28311	Economy	5800.00
0005435377644	28311	Economy	5800.00
0005434954691	28311	Economy	5800.00
0005435377645	28311	Economy	5800.00
0005434954689	28311	Economy	5800.00
0005434352049	4493	Economy	15400.00
0005434326102	4493	Economy	15400.00
0005434352047	4493	Economy	14000.00
0005435893744	4493	Economy	14000.00
0005434326103	4493	Economy	14000.00
0005435893797	4493	Economy	14000.00
0005434183620	4493	Economy	14000.00
0005434183615	4493	Economy	14000.00
0005435893774	4493	Economy	14000.00
0005435893756	4493	Economy	14000.00
0005434326296	4493	Economy	14000.00
0005435893796	4493	Economy	14000.00
0005434352048	4493	Economy	14000.00
0005434352046	4493	Economy	14000.00
0005434352050	4493	Economy	14000.00
0005435893745	4493	Economy	14000.00
0005435893791	4493	Economy	14000.00
0005434351918	29681	Economy	15400.00
0005435893828	29681	Economy	15400.00
0005434351917	29681	Economy	15400.00
0005435893832	29681	Economy	14000.00
0005434182549	29681	Economy	14000.00
0005434351941	29681	Economy	14000.00
0005434351955	29681	Economy	14000.00
0005434351953	29681	Economy	14000.00
0005434351906	29681	Economy	14000.00
0005434351919	29681	Economy	14000.00
0005434352007	29681	Economy	14000.00
0005434351980	29681	Economy	14000.00
0005434351986	29681	Economy	14000.00
0005434351976	29681	Economy	14000.00
0005435893831	29681	Economy	14000.00
0005434351935	29681	Economy	14000.00
0005434351930	29681	Economy	14000.00
0005434351956	29681	Economy	14000.00
0005435893830	29681	Economy	14000.00
0005434351972	29681	Economy	14000.00
0005434351987	29681	Economy	14000.00
0005434182550	29681	Economy	14000.00
0005435893829	29681	Economy	14000.00
0005435893833	29681	Economy	14000.00
0005434351952	29681	Economy	14000.00
0005434351961	29681	Economy	14000.00
0005433345118	1093	Business	30600.00
0005433344963	1093	Business	30600.00
0005433158175	1093	Business	30600.00
0005433463963	1093	Business	30600.00
0005433344491	1093	Business	30600.00
0005433345381	1093	Business	30600.00
0005433344872	1093	Business	30600.00
0005432293276	1093	Business	30600.00
0005433345256	1093	Business	30600.00
0005433345127	1093	Business	30600.00
0005433345074	1093	Business	30600.00
0005433344903	1093	Business	30600.00
0005435545950	1093	Business	30600.00
0005433345399	1093	Business	30600.00
0005433345223	1093	Business	30600.00
0005433345183	1093	Business	30600.00
0005433345058	1093	Business	30600.00
0005435092345	1093	Economy	11200.00
0005433345059	1093	Economy	11200.00
0005433158174	1093	Economy	10200.00
0005433345208	1093	Economy	10200.00
0005433344739	1093	Economy	10200.00
0005434446586	1093	Economy	10200.00
0005433345104	1093	Economy	10200.00
0005435092348	1093	Economy	10200.00
0005433344988	1093	Economy	10200.00
0005433345218	1093	Economy	10200.00
0005433345168	1093	Economy	10200.00
0005433344887	1093	Economy	10200.00
0005433344962	1093	Economy	10200.00
0005433345039	1093	Economy	10200.00
0005433345008	1093	Economy	10200.00
0005433345382	1093	Economy	10200.00
0005433344720	1093	Economy	10200.00
0005433269825	1093	Economy	10200.00
0005434446587	1093	Economy	10200.00
0005433345116	1093	Economy	10200.00
0005433344977	1093	Economy	10200.00
0005433345167	1093	Economy	10200.00
0005433344789	1093	Economy	10200.00
0005435545949	1093	Economy	10200.00
0005433344852	1093	Economy	10200.00
0005433344851	1093	Economy	10200.00
0005435092346	1093	Economy	10200.00
0005435092347	1093	Economy	10200.00
0005433462803	1093	Economy	10200.00
0005435092351	1093	Economy	10200.00
0005433345205	1093	Economy	10200.00
0005433344964	1093	Economy	10200.00
0005433344954	1093	Economy	10200.00
0005433463962	1093	Economy	10200.00
0005433345217	1093	Economy	10200.00
0005433345139	1093	Economy	10200.00
0005433345033	1093	Economy	10200.00
0005433344937	1093	Economy	10200.00
0005434445319	1093	Economy	10200.00
0005433344915	1093	Economy	10200.00
0005433345330	1093	Economy	10200.00
0005433345140	1093	Economy	10200.00
0005433345413	1093	Economy	10200.00
0005433344981	1093	Economy	10200.00
0005433344957	1093	Economy	10200.00
0005433345181	1093	Economy	10200.00
0005434445318	1093	Economy	10200.00
0005433345518	1093	Economy	10200.00
0005433344965	1093	Economy	10200.00
0005433345157	1093	Economy	10200.00
0005434445320	1093	Economy	10200.00
0005433345361	1093	Economy	10200.00
0005433345379	1093	Economy	10200.00
0005433344949	1093	Economy	10200.00
0005433269826	1093	Economy	10200.00
0005433344733	1093	Economy	10200.00
0005433344871	1093	Economy	10200.00
0005433345360	1093	Economy	10200.00
0005433345204	1093	Economy	10200.00
0005433345236	1093	Economy	10200.00
0005433344983	1093	Economy	10200.00
0005433345000	1093	Economy	10200.00
0005433345414	1093	Economy	11200.00
0005433344969	1093	Economy	10200.00
0005433158169	1093	Economy	11200.00
0005433345117	1093	Economy	10200.00
0005434445317	1093	Economy	10200.00
0005433345263	1093	Economy	10200.00
0005433345103	1093	Economy	10200.00
0005433344827	1093	Economy	10200.00
0005434445316	1093	Economy	10200.00
0005433345172	1093	Economy	10200.00
0005433345191	1093	Economy	10200.00
0005433345592	1093	Economy	10200.00
0005433345173	1093	Economy	10200.00
0005433345162	1093	Economy	10200.00
0005432293275	1093	Economy	10200.00
0005433345077	1093	Economy	10200.00
0005433345143	1093	Economy	10200.00
0005433345331	1093	Economy	10200.00
0005433344698	1093	Economy	10200.00
0005433345082	1093	Economy	10200.00
0005433344483	1093	Economy	10200.00
0005433345171	1093	Economy	10200.00
0005433345124	1093	Economy	10200.00
0005433345169	1093	Economy	10200.00
0005433158177	1093	Economy	10200.00
0005433345384	1093	Economy	10200.00
0005433344966	1093	Economy	10200.00
0005433345147	1093	Economy	10200.00
0005433345349	1093	Economy	10200.00
0005433269841	1093	Economy	10200.00
0005433344798	1093	Economy	10200.00
0005433344869	1093	Economy	10200.00
0005433345001	1093	Economy	10200.00
0005433345214	1093	Economy	10200.00
0005433345272	1093	Economy	10200.00
0005433344958	1093	Economy	10200.00
0005433344942	1093	Economy	10200.00
0005433344482	1093	Economy	10200.00
0005433344888	1093	Economy	10200.00
0005435092349	1093	Economy	10200.00
0005435545951	1093	Economy	10200.00
0005433345184	1093	Economy	10200.00
0005433344870	1093	Economy	10200.00
0005433344524	1093	Economy	10200.00
0005432293277	1093	Economy	10200.00
0005433344683	1093	Economy	10200.00
0005435092350	1093	Economy	10200.00
0005433345398	1093	Economy	10200.00
0005433344970	1093	Economy	10200.00
0005433344868	1093	Economy	10200.00
0005433158167	1093	Economy	10200.00
0005433345517	1093	Economy	10200.00
0005433462776	17063	Business	30600.00
0005435508578	17063	Business	30600.00
0005435508545	17063	Business	30600.00
0005433345885	17063	Business	30600.00
0005433460466	17063	Business	30600.00
0005435508629	17063	Business	30600.00
0005435508658	17063	Business	30600.00
0005433345853	17063	Business	30600.00
0005433345828	17063	Business	30600.00
0005435508625	17063	Business	30600.00
0005435092287	17063	Business	30600.00
0005435092305	17063	Business	30600.00
0005433345859	17063	Business	30600.00
0005433345866	17063	Business	30600.00
0005433345884	17063	Business	30600.00
0005433462783	17063	Business	30600.00
0005435508579	17063	Business	30600.00
0005433159375	17063	Business	30600.00
0005435508543	17063	Business	30600.00
0005435092328	17063	Business	30600.00
0005433269870	17063	Economy	11200.00
0005433345846	17063	Economy	11200.00
0005433460465	17063	Economy	11200.00
0005433345873	17063	Economy	10200.00
0005435092270	17063	Economy	10200.00
0005435092301	17063	Economy	10200.00
0005433345862	17063	Economy	10200.00
0005435529998	17063	Economy	10200.00
0005433345861	17063	Economy	10200.00
0005433345856	17063	Economy	10200.00
0005433345870	17063	Economy	10200.00
0005433345872	17063	Economy	10200.00
0005435529978	17063	Economy	10200.00
0005435508633	17063	Economy	10200.00
0005433462787	17063	Economy	10200.00
0005435092267	17063	Economy	10200.00
0005433345849	17063	Economy	10200.00
0005435508507	17063	Economy	10200.00
0005433345889	17063	Economy	10200.00
0005435508657	17063	Economy	10200.00
0005433460474	17063	Economy	10200.00
0005435092304	17063	Economy	10200.00
0005433460472	17063	Economy	10200.00
0005433460462	17063	Economy	10200.00
0005433345841	17063	Economy	10200.00
0005433345860	17063	Economy	10200.00
0005435508589	17063	Economy	10200.00
0005433345887	17063	Economy	10200.00
0005433345837	17063	Economy	10200.00
0005435508506	17063	Economy	10200.00
0005435530007	17063	Economy	10200.00
0005433460471	17063	Economy	10200.00
0005433345831	17063	Economy	10200.00
0005435508626	17063	Economy	10200.00
0005434445279	17063	Economy	10200.00
0005433345877	17063	Economy	10200.00
0005433345854	17063	Economy	10200.00
0005433345857	17063	Economy	10200.00
0005433345855	17063	Economy	10200.00
0005433345840	17063	Economy	10200.00
0005433462782	17063	Economy	10200.00
0005433159374	17063	Economy	10200.00
0005435092329	17063	Economy	10200.00
0005433345833	17063	Economy	10200.00
0005435092266	17063	Economy	10200.00
0005433158205	17063	Economy	10200.00
0005433345836	17063	Economy	10200.00
0005435508638	17063	Economy	10200.00
0005435508603	17063	Economy	10200.00
0005433345845	17063	Economy	10200.00
0005435529992	17063	Economy	10200.00
0005435508656	17063	Economy	10200.00
0005433345851	17063	Economy	10200.00
0005433345835	17063	Economy	10200.00
0005433345852	17063	Economy	10200.00
0005435508598	17063	Economy	10200.00
0005433345882	17063	Economy	10200.00
0005433345829	17063	Economy	10200.00
0005433460461	17063	Economy	10200.00
0005435092303	17063	Economy	10200.00
0005433345843	17063	Economy	10200.00
0005433345842	17063	Economy	10200.00
0005433462772	17063	Economy	10200.00
0005433345844	17063	Economy	10200.00
0005435508508	17063	Economy	10200.00
0005433158204	17063	Economy	10200.00
0005435529994	17063	Economy	10200.00
0005433345827	17063	Economy	10200.00
0005435529993	17063	Economy	10200.00
0005434445284	17063	Economy	10200.00
0005435508549	17063	Economy	10200.00
0005433345890	17063	Economy	10200.00
0005435508630	17063	Economy	10200.00
0005435529987	17063	Economy	10200.00
0005433345892	17063	Economy	10200.00
0005433345838	17063	Economy	11200.00
0005433460470	17063	Economy	11200.00
0005433462768	17063	Economy	10200.00
0005433460463	17063	Economy	11200.00
0005433345881	17063	Economy	10200.00
0005433345879	17063	Economy	10200.00
0005433345883	17063	Economy	10200.00
0005435508590	17063	Economy	10200.00
0005433462765	17063	Economy	10200.00
0005435092279	17063	Economy	10200.00
0005433345832	17063	Economy	10200.00
0005433345868	17063	Economy	10200.00
0005433460449	17063	Economy	10200.00
0005435092272	17063	Economy	10200.00
0005433345894	17063	Economy	10200.00
0005435530006	17063	Economy	10200.00
0005433345867	17063	Economy	10200.00
0005435092280	17063	Economy	10200.00
0005435529984	17063	Economy	10200.00
0005433345865	17063	Economy	10200.00
0005433345850	17063	Economy	10200.00
0005433345891	17063	Economy	10200.00
0005435092271	17063	Economy	10200.00
0005433345895	17063	Economy	10200.00
0005434445289	17063	Economy	10200.00
0005433345878	17063	Economy	10200.00
0005433345830	17063	Economy	10200.00
0005433345893	17063	Economy	10200.00
0005435092261	17063	Economy	10200.00
0005433345876	17063	Economy	10200.00
0005435092286	17063	Economy	10200.00
0005435530009	17063	Economy	10200.00
0005433345869	17063	Economy	10200.00
0005433462777	17063	Economy	10200.00
0005433345871	17063	Economy	10200.00
0005435092288	17063	Economy	10200.00
0005433462786	17063	Economy	10200.00
0005433345886	17063	Economy	10200.00
0005435530008	17063	Economy	10200.00
0005435508640	17063	Economy	10200.00
0005433345880	17063	Economy	10200.00
0005435092268	17063	Economy	10200.00
0005433345834	17063	Economy	10200.00
0005435529997	17063	Economy	10200.00
0005433345875	17063	Economy	10200.00
0005435508565	17063	Economy	10200.00
0005433460469	17063	Economy	10200.00
0005433345864	17063	Economy	10200.00
0005435508544	17063	Economy	10200.00
0005433345888	17063	Economy	10200.00
0005435508564	17063	Economy	10200.00
0005435508560	17063	Economy	10200.00
0005433345874	17063	Economy	10200.00
0005433345839	17063	Economy	10200.00
0005435508559	17063	Economy	10200.00
0005433460454	17063	Economy	10200.00
0005433462784	17063	Economy	10200.00
0005433345848	17063	Economy	10200.00
0005435508639	17063	Economy	10200.00
0005433345858	17063	Economy	10200.00
0005433345863	17063	Economy	10200.00
0005433462778	17063	Economy	10200.00
0005433345847	17063	Economy	10200.00
0005432390408	18269	Business	101000.00
0005432390331	18269	Business	101000.00
0005432390372	18269	Business	101000.00
0005432390332	18269	Business	101000.00
0005432852086	18269	Business	101000.00
0005432852076	18269	Business	101000.00
0005432392050	18269	Business	101000.00
0005432390359	18269	Business	101000.00
0005432390327	18269	Business	101000.00
0005432390333	18269	Economy	33700.00
0005432390384	18269	Economy	33700.00
0005432852089	18269	Economy	33700.00
0005432392051	18269	Economy	33700.00
0005432390324	18269	Economy	33700.00
0005432852075	18269	Economy	33700.00
0005432390379	18269	Economy	37000.00
0005432852079	18269	Economy	33700.00
0005432390328	18269	Economy	33700.00
0005432390304	18269	Economy	33700.00
0005432390368	18269	Economy	33700.00
0005432392056	18269	Economy	33700.00
0005432852082	18269	Economy	33700.00
0005432852081	18269	Economy	33700.00
0005432852088	18269	Economy	33700.00
0005432392038	18269	Economy	33700.00
0005432852084	18269	Economy	33700.00
0005432390315	18269	Economy	33700.00
0005432852090	18269	Economy	33700.00
0005432390355	18269	Economy	33700.00
0005432390306	18269	Economy	33700.00
0005432390375	18269	Economy	33700.00
0005432392057	18269	Economy	33700.00
0005432852080	18269	Economy	33700.00
0005432390305	18269	Economy	33700.00
0005432390325	18269	Economy	33700.00
0005432852085	18269	Economy	33700.00
0005432392043	18269	Economy	33700.00
0005432392039	18269	Economy	33700.00
0005432390369	18269	Economy	33700.00
0005432392032	18269	Economy	33700.00
0005432390329	18269	Economy	33700.00
0005432390373	18269	Economy	33700.00
0005432852077	18269	Economy	33700.00
0005432390340	18269	Economy	33700.00
0005432390425	18269	Economy	33700.00
0005432390326	18269	Economy	33700.00
0005432390352	18269	Economy	33700.00
0005432852078	18269	Economy	33700.00
0005432852083	18269	Economy	33700.00
0005432392044	18269	Economy	33700.00
0005432390303	18269	Economy	33700.00
0005432390335	18269	Economy	33700.00
0005432392029	18269	Economy	33700.00
0005432390366	18269	Economy	33700.00
0005432852087	18269	Economy	33700.00
0005432390334	18269	Economy	33700.00
0005434082321	12765	Business	40300.00
0005434068836	12765	Business	40300.00
0005434082439	12765	Business	40300.00
0005434068811	12765	Business	40300.00
0005434068915	12765	Business	40300.00
0005434082255	12765	Business	40300.00
0005434068962	12765	Business	40300.00
0005434069167	12765	Business	40300.00
0005434082358	12765	Business	40300.00
0005434082447	12765	Business	40300.00
0005435283501	12765	Business	40300.00
0005434068847	12765	Business	40300.00
0005435283495	12765	Economy	13400.00
0005434082201	12765	Economy	13400.00
0005434068862	12765	Economy	13400.00
0005434068901	12765	Economy	13400.00
0005434068868	12765	Economy	13400.00
0005432433829	12765	Economy	13400.00
0005434068701	12765	Economy	13400.00
0005434068560	12765	Economy	13400.00
0005434068931	12765	Economy	13400.00
0005434068740	12765	Economy	13400.00
0005434068851	12765	Economy	13400.00
0005434068661	12765	Economy	13400.00
0005434069054	12765	Economy	13400.00
0005434068932	12765	Economy	13400.00
0005432433828	12765	Economy	13400.00
0005434082396	12765	Economy	13400.00
0005434069001	12765	Economy	13400.00
0005434068971	12765	Economy	13400.00
0005434068903	12765	Economy	13400.00
0005434069069	12765	Economy	13400.00
0005434068733	12765	Economy	13400.00
0005434069047	12765	Economy	13400.00
0005434069127	12765	Economy	13400.00
0005435283498	12765	Economy	13400.00
0005434068923	12765	Economy	13400.00
0005434082413	12765	Economy	13400.00
0005434082266	12765	Economy	13400.00
0005434068973	12765	Economy	13400.00
0005434082256	12765	Economy	13400.00
0005434069126	12765	Economy	13400.00
0005435283494	12765	Economy	13400.00
0005435283499	12765	Economy	13400.00
0005433989863	12765	Economy	13400.00
0005434068846	12765	Economy	13400.00
0005434068911	12765	Economy	13400.00
0005434068902	12765	Economy	13400.00
0005434069002	12765	Economy	14800.00
0005434068636	12765	Economy	14800.00
0005434068806	12765	Economy	14800.00
0005434082315	12765	Economy	14800.00
0005434082267	12765	Economy	14800.00
0005434069016	12765	Economy	14800.00
0005434068700	12765	Economy	13400.00
0005434068866	12765	Economy	13400.00
0005434082357	12765	Economy	13400.00
0005434082335	12765	Economy	13400.00
0005434069077	12765	Economy	13400.00
0005434082406	12765	Economy	13400.00
0005432433832	12765	Economy	13400.00
0005434082291	12765	Economy	13400.00
0005434069017	12765	Economy	13400.00
0005434068953	12765	Economy	13400.00
0005434068933	12765	Economy	13400.00
0005434069055	12765	Economy	13400.00
0005434069093	12765	Economy	13400.00
0005435283490	12765	Economy	13400.00
0005433989852	12765	Economy	13400.00
0005434068821	12765	Economy	13400.00
0005435283493	12765	Economy	13400.00
0005434068867	12765	Economy	13400.00
0005434068561	12765	Economy	13400.00
0005434082343	12765	Economy	13400.00
0005435283492	12765	Economy	13400.00
0005435283496	12765	Economy	13400.00
0005434082236	12765	Economy	13400.00
0005434069279	12765	Economy	13400.00
0005434069021	12765	Economy	13400.00
0005434069280	12765	Economy	13400.00
0005434068954	12765	Economy	13400.00
0005434068969	12765	Economy	13400.00
0005435283504	12765	Economy	13400.00
0005435283500	12765	Economy	13400.00
0005434069110	12765	Economy	13400.00
0005434082257	12765	Economy	13400.00
0005432159987	12765	Economy	13400.00
0005434068936	12765	Economy	13400.00
0005434082395	12765	Economy	13400.00
0005434082448	12765	Economy	13400.00
0005434068956	12765	Economy	13400.00
0005434068760	12765	Economy	13400.00
0005434082336	12765	Economy	13400.00
0005434068945	12765	Economy	13400.00
0005434069056	12765	Economy	13400.00
0005434068983	12765	Economy	13400.00
0005434068686	12765	Economy	13400.00
0005432433830	12765	Economy	13400.00
0005434068815	12765	Economy	13400.00
0005434082319	12765	Economy	13400.00
0005434069109	12765	Economy	13400.00
0005435283491	12765	Economy	13400.00
0005434082292	12765	Economy	13400.00
0005432433827	12765	Economy	13400.00
0005434068980	12765	Economy	13400.00
0005434068964	12765	Economy	13400.00
0005432433831	12765	Economy	13400.00
0005434068942	12765	Economy	13400.00
0005434082268	12765	Economy	13400.00
0005434082322	12765	Economy	13400.00
0005434082316	12765	Economy	13400.00
0005434068924	12765	Economy	13400.00
0005434082392	12765	Economy	13400.00
0005434069192	12765	Economy	13400.00
0005434068941	12765	Economy	13400.00
0005434082377	12765	Economy	13400.00
0005434082376	12765	Economy	13400.00
0005434068948	12765	Economy	13400.00
0005434068741	12765	Economy	13400.00
0005434068548	12765	Economy	13400.00
0005435283502	12765	Economy	13400.00
0005435283503	12765	Economy	13400.00
0005435283497	12765	Economy	13400.00
0005434068854	12765	Economy	13400.00
0005432150413	30637	Business	40300.00
0005434069476	30637	Business	40300.00
0005433989897	30637	Business	40300.00
0005434069517	30637	Business	40300.00
0005434069513	30637	Business	40300.00
0005434082578	30637	Business	40300.00
0005434069502	30637	Business	40300.00
0005434069523	30637	Business	40300.00
0005434069494	30637	Business	40300.00
0005434082580	30637	Business	40300.00
0005434069486	30637	Business	40300.00
0005434082586	30637	Economy	13400.00
0005434082575	30637	Economy	13400.00
0005434082570	30637	Economy	13400.00
0005434082576	30637	Economy	13400.00
0005434069479	30637	Economy	13400.00
0005435283423	30637	Economy	13400.00
0005434069501	30637	Economy	13400.00
0005434069524	30637	Economy	13400.00
0005434082585	30637	Economy	13400.00
0005434069507	30637	Economy	13400.00
0005434069488	30637	Economy	13400.00
0005434069500	30637	Economy	13400.00
0005434069467	30637	Economy	13400.00
0005434069489	30637	Economy	13400.00
0005434082588	30637	Economy	13400.00
0005434082569	30637	Economy	13400.00
0005434069481	30637	Economy	13400.00
0005434069478	30637	Economy	13400.00
0005432150415	30637	Economy	13400.00
0005434082583	30637	Economy	13400.00
0005434069519	30637	Economy	13400.00
0005434069490	30637	Economy	13400.00
0005434082568	30637	Economy	13400.00
0005434069518	30637	Economy	13400.00
0005434069475	30637	Economy	13400.00
0005434069503	30637	Economy	13400.00
0005434069474	30637	Economy	13400.00
0005434069491	30637	Economy	13400.00
0005434069466	30637	Economy	13400.00
0005434069508	30637	Economy	13400.00
0005434069465	30637	Economy	14800.00
0005434069470	30637	Economy	14800.00
0005432433794	30637	Economy	14800.00
0005434082574	30637	Economy	14800.00
0005434069499	30637	Economy	14800.00
0005434069522	30637	Economy	13400.00
0005432150410	30637	Economy	13400.00
0005432150409	30637	Economy	13400.00
0005434069482	30637	Economy	13400.00
0005434069509	30637	Economy	13400.00
0005434069493	30637	Economy	13400.00
0005435283425	30637	Economy	13400.00
0005434069480	30637	Economy	13400.00
0005434069511	30637	Economy	13400.00
0005434082582	30637	Economy	13400.00
0005432150416	30637	Economy	13400.00
0005434082573	30637	Economy	13400.00
0005432150414	30637	Economy	13400.00
0005434082572	30637	Economy	13400.00
0005434069472	30637	Economy	13400.00
0005434069495	30637	Economy	13400.00
0005434069471	30637	Economy	13400.00
0005434069468	30637	Economy	13400.00
0005434069506	30637	Economy	13400.00
0005434069473	30637	Economy	13400.00
0005434069504	30637	Economy	13400.00
0005434082587	30637	Economy	13400.00
0005434082571	30637	Economy	13400.00
0005434069496	30637	Economy	13400.00
0005434069520	30637	Economy	13400.00
0005434082581	30637	Economy	13400.00
0005434069512	30637	Economy	13400.00
0005434069498	30637	Economy	13400.00
0005434069515	30637	Economy	13400.00
0005434082579	30637	Economy	13400.00
0005434069483	30637	Economy	13400.00
0005434069492	30637	Economy	13400.00
0005434069484	30637	Economy	13400.00
0005434069477	30637	Economy	13400.00
0005434082567	30637	Economy	13400.00
0005432150411	30637	Economy	13400.00
0005434082584	30637	Economy	13400.00
0005432150412	30637	Economy	13400.00
0005432433784	30637	Economy	13400.00
0005435283424	30637	Economy	13400.00
0005432433799	30637	Economy	13400.00
0005434069521	30637	Economy	13400.00
0005434069485	30637	Economy	13400.00
0005434069514	30637	Economy	13400.00
0005434069487	30637	Economy	13400.00
0005434069510	30637	Economy	13400.00
0005434069516	30637	Economy	13400.00
0005434069497	30637	Economy	13400.00
0005435283411	30637	Economy	13400.00
0005434069505	30637	Economy	13400.00
0005434069469	30637	Economy	13400.00
0005432433785	30637	Economy	13400.00
0005434082577	30637	Economy	13400.00
0005433686697	9033	Economy	19300.00
0005433685586	9033	Economy	17600.00
0005433685589	9033	Economy	17600.00
0005433685588	9033	Economy	17600.00
0005433687764	9033	Economy	17600.00
0005433685587	9033	Economy	17600.00
0005433686694	9033	Economy	17600.00
0005433686693	9033	Economy	17600.00
0005433685584	9033	Economy	17600.00
0005433687763	9033	Economy	17600.00
0005433685583	9033	Economy	17600.00
0005433685581	9033	Economy	17600.00
0005433685582	9033	Economy	17600.00
0005433686695	9033	Economy	17600.00
0005433686698	9033	Economy	17600.00
0005433685585	9033	Economy	17600.00
0005433686696	9033	Economy	17600.00
0005435463171	5490	Business	35300.00
0005435463078	5490	Business	35300.00
0005435043297	5490	Business	35300.00
0005434265560	5490	Business	35300.00
0005435463226	5490	Business	35300.00
0005435723099	5490	Business	35300.00
0005435463183	5490	Business	35300.00
0005435767990	5490	Business	35300.00
0005432140676	5490	Business	35300.00
0005435768117	5490	Business	35300.00
0005435768118	5490	Business	35300.00
0005432535928	5490	Business	35300.00
0005434265687	5490	Business	35300.00
0005435767995	5490	Business	35300.00
0005435723100	5490	Business	35300.00
0005435463111	5490	Business	35300.00
0005434265539	5490	Business	35300.00
0005434265562	5490	Economy	12900.00
0005432140677	5490	Economy	12900.00
0005435767982	5490	Economy	12900.00
0005435722120	5490	Economy	11800.00
0005435767977	5490	Economy	11800.00
0005434831239	5490	Economy	11800.00
0005432535924	5490	Economy	11800.00
0005435767965	5490	Economy	11800.00
0005433529384	5490	Economy	11800.00
0005435463342	5490	Economy	11800.00
0005435767987	5490	Economy	11800.00
0005435735266	5490	Economy	11800.00
0005435768002	5490	Economy	11800.00
0005435767962	5490	Economy	11800.00
0005435767998	5490	Economy	11800.00
0005435735267	5490	Economy	11800.00
0005435767974	5490	Economy	11800.00
0005435463076	5490	Economy	11800.00
0005435463334	5490	Economy	11800.00
0005432535922	5490	Economy	11800.00
0005435767985	5490	Economy	11800.00
0005435767980	5490	Economy	11800.00
0005435767975	5490	Economy	11800.00
0005434265631	5490	Economy	11800.00
0005434265601	5490	Economy	11800.00
0005435767959	5490	Economy	11800.00
0005434265717	5490	Economy	11800.00
0005434265660	5490	Economy	11800.00
0005435768114	5490	Economy	11800.00
0005435768001	5490	Economy	11800.00
0005435767994	5490	Economy	11800.00
0005435767978	5490	Economy	11800.00
0005435463074	5490	Economy	11800.00
0005434265635	5490	Economy	11800.00
0005435725733	5490	Economy	11800.00
0005434265750	5490	Economy	11800.00
0005432535921	5490	Economy	11800.00
0005435463225	5490	Economy	11800.00
0005435725732	5490	Economy	11800.00
0005435767964	5490	Economy	11800.00
0005432535918	5490	Economy	11800.00
0005435767970	5490	Economy	11800.00
0005435463199	5490	Economy	11800.00
0005435463139	5490	Economy	11800.00
0005435768000	5490	Economy	11800.00
0005435767966	5490	Economy	11800.00
0005435463252	5490	Economy	11800.00
0005435768004	5490	Economy	11800.00
0005435767999	5490	Economy	11800.00
0005435767960	5490	Economy	11800.00
0005435767957	5490	Economy	11800.00
0005435463096	5490	Economy	11800.00
0005434265540	5490	Economy	11800.00
0005435463296	5490	Economy	11800.00
0005435767968	5490	Economy	11800.00
0005434265578	5490	Economy	11800.00
0005435463114	5490	Economy	11800.00
0005434265726	5490	Economy	11800.00
0005435767986	5490	Economy	11800.00
0005432535923	5490	Economy	11800.00
0005434831238	5490	Economy	11800.00
0005435463192	5490	Economy	11800.00
0005435463317	5490	Economy	11800.00
0005435463198	5490	Economy	11800.00
0005435767991	5490	Economy	11800.00
0005435463250	5490	Economy	11800.00
0005435463147	5490	Economy	11800.00
0005435767984	5490	Economy	11800.00
0005435463168	5490	Economy	11800.00
0005435735268	5490	Economy	11800.00
0005435463251	5490	Economy	11800.00
0005434265636	5490	Economy	11800.00
0005435463219	5490	Economy	11800.00
0005435767988	5490	Economy	11800.00
0005435767973	5490	Economy	11800.00
0005434831232	5490	Economy	11800.00
0005434265586	5490	Economy	11800.00
0005435463193	5490	Economy	12900.00
0005434265561	5490	Economy	11800.00
0005433529385	5490	Economy	11800.00
0005435735265	5490	Economy	12900.00
0005435767983	5490	Economy	12900.00
0005432140679	5490	Economy	11800.00
0005434265575	5490	Economy	11800.00
0005435463090	5490	Economy	11800.00
0005435767976	5490	Economy	11800.00
0005435767969	5490	Economy	11800.00
0005435463172	5490	Economy	11800.00
0005435767967	5490	Economy	11800.00
0005432140678	5490	Economy	11800.00
0005432140675	5490	Economy	11800.00
0005432140680	5490	Economy	11800.00
0005435768116	5490	Economy	11800.00
0005434265686	5490	Economy	11800.00
0005435463265	5490	Economy	11800.00
0005434831221	5490	Economy	11800.00
0005434831233	5490	Economy	11800.00
0005435767971	5490	Economy	11800.00
0005435767961	5490	Economy	11800.00
0005434265584	5490	Economy	11800.00
0005435725736	5490	Economy	11800.00
0005435767979	5490	Economy	11800.00
0005435463063	5490	Economy	11800.00
0005435767993	5490	Economy	11800.00
0005435463169	5490	Economy	11800.00
0005435767992	5490	Economy	11800.00
0005432535919	5490	Economy	11800.00
0005435463097	5490	Economy	11800.00
0005435723101	5490	Economy	11800.00
0005435463106	5490	Economy	11800.00
0005435767981	5490	Economy	11800.00
0005435768003	5490	Economy	11800.00
0005435767972	5490	Economy	11800.00
0005435767989	5490	Economy	11800.00
0005434265617	5490	Economy	11800.00
0005435463197	5490	Economy	11800.00
0005435463182	5490	Economy	11800.00
0005435463089	5490	Economy	11800.00
0005435767963	5490	Economy	11800.00
0005435767997	5490	Economy	11800.00
0005435463077	5490	Economy	11800.00
0005432535944	5490	Economy	11800.00
0005434265577	5490	Economy	11800.00
0005435463098	5490	Economy	11800.00
0005435463280	5490	Economy	11800.00
0005434265587	5490	Economy	11800.00
0005435725735	5490	Economy	11800.00
0005435768113	5490	Economy	11800.00
0005435768115	5490	Economy	11800.00
0005434265638	5490	Economy	11800.00
0005432535927	5490	Economy	11800.00
0005434265618	5490	Economy	11800.00
0005435463266	5490	Economy	11800.00
0005435725731	5490	Economy	11800.00
0005435767958	5490	Economy	11800.00
0005435767996	5490	Economy	11800.00
0005435463075	5490	Economy	11800.00
0005435463150	5490	Economy	11800.00
0005435463279	5490	Economy	11800.00
0005434265528	5490	Economy	11800.00
0005435735264	5490	Economy	11800.00
0005435725734	5490	Economy	11800.00
0005432535917	5490	Economy	11800.00
0005432535945	5490	Economy	11800.00
0005434265852	13473	Business	35300.00
0005435767483	13473	Business	35300.00
0005435735242	13473	Business	35300.00
0005435767365	13473	Business	35300.00
0005435725698	13473	Business	35300.00
0005435463492	13473	Business	35300.00
0005435463480	13473	Business	35300.00
0005435463491	13473	Business	35300.00
0005432194630	13473	Business	35300.00
0005435767190	13473	Business	35300.00
0005435767765	13473	Business	35300.00
0005435767164	13473	Business	35300.00
0005434265855	13473	Business	35300.00
0005435463495	13473	Business	35300.00
0005435767391	13473	Business	35300.00
0005435767259	13473	Business	35300.00
0005435767527	13473	Business	35300.00
0005434265869	13473	Business	35300.00
0005435767440	13473	Economy	12900.00
0005435767096	13473	Economy	12900.00
0005435720146	13473	Economy	12900.00
0005435767631	13473	Economy	11800.00
0005435767387	13473	Economy	11800.00
0005435767573	13473	Economy	11800.00
0005435463482	13473	Economy	11800.00
0005435043311	13473	Economy	11800.00
0005435463490	13473	Economy	11800.00
0005435767661	13473	Economy	11800.00
0005432535971	13473	Economy	11800.00
0005435767696	13473	Economy	11800.00
0005435767089	13473	Economy	11800.00
0005435767496	13473	Economy	11800.00
0005435767494	13473	Economy	11800.00
0005435767256	13473	Economy	11800.00
0005432535973	13473	Economy	11800.00
0005435767822	13473	Economy	11800.00
0005434265858	13473	Economy	11800.00
0005435463485	13473	Economy	11800.00
0005435767604	13473	Economy	11800.00
0005434265864	13473	Economy	11800.00
0005435767572	13473	Economy	11800.00
0005434831284	13473	Economy	11800.00
0005435463487	13473	Economy	11800.00
0005434265867	13473	Economy	11800.00
0005435767323	13473	Economy	11800.00
0005435735241	13473	Economy	11800.00
0005435043312	13473	Economy	11800.00
0005435767745	13473	Economy	11800.00
0005435767511	13473	Economy	11800.00
0005435767392	13473	Economy	11800.00
0005435617198	13473	Economy	11800.00
0005435767530	13473	Economy	11800.00
0005434265856	13473	Economy	11800.00
0005435767490	13473	Economy	11800.00
0005435767322	13473	Economy	11800.00
0005435767621	13473	Economy	11800.00
0005435767134	13473	Economy	11800.00
0005434265851	13473	Economy	11800.00
0005435767107	13473	Economy	11800.00
0005434265866	13473	Economy	11800.00
0005435463493	13473	Economy	11800.00
0005435463489	13473	Economy	11800.00
0005435463494	13473	Economy	11800.00
0005434265857	13473	Economy	11800.00
0005435767547	13473	Economy	11800.00
0005435463488	13473	Economy	11800.00
0005435767414	13473	Economy	11800.00
0005434265860	13473	Economy	11800.00
0005435767629	13473	Economy	11800.00
0005435767509	13473	Economy	11800.00
0005435725711	13473	Economy	11800.00
0005435767277	13473	Economy	11800.00
0005435767764	13473	Economy	11800.00
0005435767366	13473	Economy	11800.00
0005432535972	13473	Economy	11800.00
0005435767258	13473	Economy	11800.00
0005435767529	13473	Economy	11800.00
0005435767413	13473	Economy	11800.00
0005435767548	13473	Economy	11800.00
0005435043310	13473	Economy	11800.00
0005435767528	13473	Economy	11800.00
0005435463486	13473	Economy	11800.00
0005434265859	13473	Economy	11800.00
0005435767487	13473	Economy	11800.00
0005435767298	13473	Economy	11800.00
0005435463483	13473	Economy	11800.00
0005435767309	13473	Economy	11800.00
0005435463497	13473	Economy	11800.00
0005435463484	13473	Economy	12900.00
0005435767478	13473	Economy	12900.00
0005435767278	13473	Economy	12900.00
0005435767488	13473	Economy	12900.00
0005435725697	13473	Economy	11800.00
0005434265868	13473	Economy	11800.00
0005435617199	13473	Economy	11800.00
0005435767126	13473	Economy	11800.00
0005435767561	13473	Economy	11800.00
0005435617201	13473	Economy	11800.00
0005435767129	13473	Economy	11800.00
0005434265865	13473	Economy	11800.00
0005435767519	13473	Economy	11800.00
0005435767609	13473	Economy	11800.00
0005435767130	13473	Economy	11800.00
0005435463479	13473	Economy	11800.00
0005435767390	13473	Economy	11800.00
0005435617197	13473	Economy	11800.00
0005435722101	13473	Economy	11800.00
0005435767090	13473	Economy	11800.00
0005435617200	13473	Economy	11800.00
0005432194628	13473	Economy	11800.00
0005435767268	13473	Economy	11800.00
0005435767299	13473	Economy	11800.00
0005432194627	13473	Economy	11800.00
0005434265863	13473	Economy	11800.00
0005435767746	13473	Economy	11800.00
0005434265862	13473	Economy	11800.00
0005435767534	13473	Economy	11800.00
0005435767346	13473	Economy	11800.00
0005434831283	13473	Economy	11800.00
0005435767489	13473	Economy	11800.00
0005435767456	13473	Economy	11800.00
0005435767665	13473	Economy	11800.00
0005435463496	13473	Economy	11800.00
0005435767300	13473	Economy	11800.00
0005434265861	13473	Economy	11800.00
0005435767461	13473	Economy	11800.00
0005435735215	13473	Economy	11800.00
0005435767584	13473	Economy	11800.00
0005435043309	13473	Economy	11800.00
0005435767585	13473	Economy	11800.00
0005435720150	13473	Economy	11800.00
0005435767460	13473	Economy	11800.00
0005435767628	13473	Economy	11800.00
0005434265854	13473	Economy	11800.00
0005435767276	13473	Economy	11800.00
0005432194629	13473	Economy	11800.00
0005435767486	13473	Economy	11800.00
0005435725710	13473	Economy	11800.00
0005435767633	13473	Economy	11800.00
0005435767630	13473	Economy	11800.00
0005435725699	13473	Economy	11800.00
0005434265853	13473	Economy	11800.00
0005435767384	13473	Economy	11800.00
0005435767142	13473	Economy	11800.00
0005435043313	13473	Economy	11800.00
0005435463481	13473	Economy	11800.00
0005435767439	13473	Economy	11800.00
0005434602946	18742	Economy	3300.00
0005434604962	18638	Economy	3300.00
0005434604982	18638	Economy	3300.00
0005434604983	18638	Economy	3300.00
0005435904489	18638	Economy	3300.00
0005434513652	18638	Economy	3300.00
0005434513651	18638	Economy	3300.00
0005434513653	18638	Economy	3300.00
0005434515041	18638	Economy	3300.00
0005434602968	19176	Economy	3300.00
0005434515021	19176	Economy	3300.00
0005434602970	19176	Economy	3300.00
0005434602972	19176	Economy	3300.00
0005434602974	19176	Economy	3300.00
0005434602969	19176	Economy	3300.00
0005434515028	19176	Economy	3300.00
0005434515023	19176	Economy	3300.00
0005434602973	19176	Economy	3300.00
0005434602971	19176	Economy	3300.00
0005433009565	1782	Business	48700.00
0005433009613	1782	Business	48700.00
0005433009532	1782	Business	48700.00
0005433285860	1782	Business	48700.00
0005433009451	1782	Business	48700.00
0005433009667	1782	Business	48700.00
0005433009646	1782	Business	48700.00
0005433009628	1782	Business	48700.00
0005433810751	1782	Business	48700.00
0005433009516	1782	Business	48700.00
0005433009552	1782	Business	48700.00
0005433810733	1782	Business	48700.00
0005433009594	1782	Economy	16200.00
0005433285900	1782	Economy	16200.00
0005433009595	1782	Economy	16200.00
0005433810734	1782	Economy	16200.00
0005433810746	1782	Economy	16200.00
0005433285979	1782	Economy	16200.00
0005433810741	1782	Economy	16200.00
0005433009550	1782	Economy	16200.00
0005433285919	1782	Economy	16200.00
0005433810747	1782	Economy	16200.00
0005433009744	1782	Economy	17900.00
0005433285962	1782	Economy	17900.00
0005433009713	1782	Economy	17900.00
0005433009482	1782	Economy	17900.00
0005433009668	1782	Economy	17900.00
0005433810750	1782	Economy	16200.00
0005433286014	1782	Economy	16200.00
0005433285996	1782	Economy	16200.00
0005433009649	1782	Economy	16200.00
0005433286042	1782	Economy	16200.00
0005433285967	1782	Economy	16200.00
0005433285868	1782	Economy	16200.00
0005433810737	1782	Economy	16200.00
0005433810739	1782	Economy	16200.00
0005433009617	1782	Economy	16200.00
0005433009809	1782	Economy	16200.00
0005433009483	1782	Economy	16200.00
0005433285779	1782	Economy	16200.00
0005433285842	1782	Economy	16200.00
0005433009655	1782	Economy	16200.00
0005433009607	1782	Economy	16200.00
0005433810745	1782	Economy	16200.00
0005433285837	1782	Economy	16200.00
0005433810740	1782	Economy	16200.00
0005433810742	1782	Economy	16200.00
0005433009283	1782	Economy	16200.00
0005433810743	1782	Economy	16200.00
0005433285985	1782	Economy	16200.00
0005433810744	1782	Economy	16200.00
0005433285869	1782	Economy	16200.00
0005433009509	1782	Economy	16200.00
0005432295955	1782	Economy	16200.00
0005433009478	1782	Economy	16200.00
0005433009508	1782	Economy	16200.00
0005433009469	1782	Economy	16200.00
0005433009700	1782	Economy	16200.00
0005433285981	1782	Economy	16200.00
0005433285937	1782	Economy	16200.00
0005433009551	1782	Economy	16200.00
0005433285865	1782	Economy	16200.00
0005433810735	1782	Economy	16200.00
0005433286023	1782	Economy	16200.00
0005433810732	1782	Economy	16200.00
0005433285836	1782	Economy	16200.00
0005433810738	1782	Economy	16200.00
0005433810731	1782	Economy	16200.00
0005433009497	1782	Economy	16200.00
0005433286005	1782	Economy	16200.00
0005433009745	1782	Economy	16200.00
0005433285896	1782	Economy	16200.00
0005433810748	1782	Economy	16200.00
0005433285984	1782	Economy	16200.00
0005433810749	1782	Economy	16200.00
0005433009676	1782	Economy	16200.00
0005433009648	1782	Economy	16200.00
0005433285850	1782	Economy	16200.00
0005433009438	1782	Economy	16200.00
0005432295954	1782	Economy	16200.00
0005433009583	1782	Economy	16200.00
0005433009368	1782	Economy	16200.00
0005433810736	1782	Economy	16200.00
0005433009643	1782	Economy	16200.00
0005433009452	1782	Economy	16200.00
0005433285980	1782	Economy	16200.00
0005433009580	1782	Economy	16200.00
0005433286015	1782	Economy	16200.00
0005433009541	1782	Economy	16200.00
0005433009515	1782	Economy	16200.00
0005433009808	1782	Economy	16200.00
0005433009425	1782	Economy	16200.00
0005433009704	1782	Economy	16200.00
0005433285918	1782	Economy	16200.00
0005433285895	1782	Economy	16200.00
0005433285901	1782	Economy	16200.00
0005433285904	1782	Economy	16200.00
0005433009865	22594	Business	48700.00
0005433286144	22594	Business	48700.00
0005433009864	22594	Business	48700.00
0005433286162	22594	Business	48700.00
0005433009876	22594	Business	48700.00
0005433009861	22594	Business	48700.00
0005433009879	22594	Business	48700.00
0005433286159	22594	Economy	16200.00
0005433009874	22594	Economy	16200.00
0005433009858	22594	Economy	16200.00
0005433286153	22594	Economy	16200.00
0005433286158	22594	Economy	16200.00
0005433009869	22594	Economy	16200.00
0005433009859	22594	Economy	16200.00
0005433286166	22594	Economy	16200.00
0005433286150	22594	Economy	17900.00
0005433009870	22594	Economy	17900.00
0005433009881	22594	Economy	17900.00
0005433009878	22594	Economy	17900.00
0005433009852	22594	Economy	16200.00
0005433810614	22594	Economy	16200.00
0005433009850	22594	Economy	16200.00
0005433286161	22594	Economy	16200.00
0005433009868	22594	Economy	16200.00
0005433009882	22594	Economy	16200.00
0005433286147	22594	Economy	16200.00
0005433009872	22594	Economy	16200.00
0005433009856	22594	Economy	16200.00
0005433009867	22594	Economy	16200.00
0005433009888	22594	Economy	16200.00
0005433286157	22594	Economy	16200.00
0005433009871	22594	Economy	16200.00
0005433286165	22594	Economy	16200.00
0005433009863	22594	Economy	16200.00
0005433286164	22594	Economy	16200.00
0005433286145	22594	Economy	16200.00
0005433009857	22594	Economy	16200.00
0005433009862	22594	Economy	16200.00
0005433009853	22594	Economy	16200.00
0005433009849	22594	Economy	16200.00
0005433286155	22594	Economy	16200.00
0005433009883	22594	Economy	16200.00
0005433009866	22594	Economy	16200.00
0005433810604	22594	Economy	16200.00
0005433286160	22594	Economy	16200.00
0005433009877	22594	Economy	16200.00
0005433286146	22594	Economy	16200.00
0005433286154	22594	Economy	16200.00
0005433009854	22594	Economy	16200.00
0005433009885	22594	Economy	16200.00
0005433009860	22594	Economy	16200.00
0005433810605	22594	Economy	16200.00
0005433009880	22594	Economy	16200.00
0005433286151	22594	Economy	16200.00
0005433286152	22594	Economy	16200.00
0005433009851	22594	Economy	16200.00
0005433286156	22594	Economy	16200.00
0005433009887	22594	Economy	16200.00
0005433009875	22594	Economy	16200.00
0005433286148	22594	Economy	16200.00
0005433009855	22594	Economy	16200.00
0005433009873	22594	Economy	16200.00
0005433009884	22594	Economy	16200.00
0005433286163	22594	Economy	16200.00
0005433009886	22594	Economy	16200.00
0005433810607	22594	Economy	16200.00
0005433286149	22594	Economy	16200.00
0005433009848	22594	Economy	16200.00
0005432756935	25342	Business	83800.00
0005432755161	25342	Business	83800.00
0005434153556	25342	Business	83800.00
0005432755162	25342	Business	83800.00
0005434152814	25342	Business	83800.00
0005434153558	25342	Business	83800.00
0005434152824	25342	Economy	27900.00
0005432755160	25342	Economy	27900.00
0005432756934	25342	Economy	27900.00
0005434153555	25342	Economy	27900.00
0005432755165	25342	Economy	27900.00
0005432756933	25342	Economy	27900.00
0005432755163	25342	Economy	27900.00
0005432756930	25342	Economy	27900.00
0005432756929	25342	Economy	27900.00
0005432755164	25342	Economy	27900.00
0005434153557	25342	Economy	27900.00
0005434153561	25342	Economy	27900.00
0005434153548	25342	Economy	27900.00
0005432755167	25342	Economy	27900.00
0005434153563	25342	Economy	27900.00
0005432756932	25342	Economy	27900.00
0005432756931	25342	Economy	27900.00
0005434153551	25342	Economy	27900.00
0005434153550	25342	Economy	27900.00
0005432755166	25342	Economy	27900.00
0005434152821	25342	Economy	27900.00
0005434153562	25342	Economy	27900.00
0005435282928	5603	Business	99800.00
0005433815515	5603	Business	99800.00
0005434173593	5603	Business	99800.00
0005433848327	5603	Business	99800.00
0005435283074	5603	Business	99800.00
0005432081686	5603	Business	99800.00
0005435283127	5603	Business	99800.00
0005434173574	5603	Business	99800.00
0005434173591	5603	Business	99800.00
0005433848336	5603	Business	99800.00
0005433848335	5603	Business	99800.00
0005433815557	5603	Business	99800.00
0005433848344	5603	Business	99800.00
0005433848328	5603	Economy	33300.00
0005435283032	5603	Business	99800.00
0005435283057	5603	Economy	33300.00
0005433848341	5603	Economy	33300.00
0005434173592	5603	Economy	33300.00
0005435282919	5603	Economy	33300.00
0005435283026	5603	Economy	33300.00
0005433815519	5603	Economy	33300.00
0005435282920	5603	Economy	33300.00
0005433848334	5603	Economy	33300.00
0005434173599	5603	Economy	33300.00
0005435283128	5603	Economy	33300.00
0005433848345	5603	Economy	36600.00
0005433815556	5603	Economy	33300.00
0005435283052	5603	Economy	33300.00
0005433848348	5603	Economy	33300.00
0005433848340	5603	Economy	33300.00
0005435283017	5603	Economy	33300.00
0005433848339	5603	Economy	33300.00
0005433848329	5603	Economy	33300.00
0005433848342	5603	Economy	33300.00
0005432081687	5603	Economy	33300.00
0005432081690	5603	Economy	33300.00
0005433848321	5603	Economy	33300.00
0005435282913	5603	Economy	33300.00
0005432081689	5603	Economy	33300.00
0005433848349	5603	Economy	33300.00
0005433848347	5603	Economy	33300.00
0005435283053	5603	Economy	33300.00
0005433815516	5603	Economy	33300.00
0005435283018	5603	Economy	33300.00
0005435283016	5603	Economy	33300.00
0005433848323	5603	Economy	33300.00
0005433848325	5603	Economy	33300.00
0005433848332	5603	Economy	33300.00
0005433848333	5603	Economy	33300.00
0005433848337	5603	Economy	33300.00
0005432081685	5603	Economy	33300.00
0005435283033	5603	Economy	33300.00
0005433848320	5603	Economy	33300.00
0005435283098	5603	Economy	33300.00
0005435283056	5603	Economy	33300.00
0005433848338	5603	Economy	33300.00
0005433848322	5603	Economy	33300.00
0005434173598	5603	Economy	33300.00
0005432081688	5603	Economy	33300.00
0005433848346	5603	Economy	33300.00
0005433848330	5603	Economy	33300.00
0005433815517	5603	Economy	33300.00
0005435283122	5603	Economy	33300.00
0005434173606	5603	Economy	33300.00
0005435283055	5603	Economy	33300.00
0005433848326	5603	Economy	33300.00
0005433848350	5603	Economy	33300.00
0005433815558	5603	Economy	33300.00
0005435282964	5603	Economy	33300.00
0005433848324	5603	Economy	33300.00
0005433848331	5603	Economy	33300.00
0005435283105	5603	Economy	33300.00
0005433848343	5603	Economy	33300.00
0005435282914	5603	Economy	33300.00
0005433815518	5603	Economy	33300.00
0005433815559	5603	Economy	33300.00
0005435283014	5603	Economy	33300.00
0005435283205	13850	Business	99800.00
0005433815460	13850	Business	99800.00
0005435283199	13850	Business	99800.00
0005435283204	13850	Business	99800.00
0005433847869	13850	Business	99800.00
0005433847794	13850	Business	99800.00
0005433847822	13850	Business	99800.00
0005433847934	13850	Business	99800.00
0005433847961	13850	Business	99800.00
0005433815466	13850	Business	99800.00
0005434173659	13850	Economy	33300.00
0005433848105	13850	Economy	33300.00
0005435283210	13850	Economy	33300.00
0005434173634	13850	Economy	33300.00
0005433847913	13850	Economy	33300.00
0005434173660	13850	Economy	33300.00
0005433815482	13850	Economy	33300.00
0005433847760	13850	Economy	33300.00
0005435283212	13850	Economy	36600.00
0005435283209	13850	Economy	36600.00
0005433847582	13850	Economy	36600.00
0005432003789	13850	Economy	36600.00
0005433847914	13850	Economy	33300.00
0005433847872	13850	Economy	33300.00
0005433815461	13850	Economy	33300.00
0005433847606	13850	Economy	33300.00
0005433847402	13850	Economy	33300.00
0005433848018	13850	Economy	33300.00
0005435283203	13850	Economy	33300.00
0005433847816	13850	Economy	33300.00
0005433847975	13850	Economy	33300.00
0005433847932	13850	Economy	33300.00
0005435283211	13850	Economy	33300.00
0005433815463	13850	Economy	33300.00
0005435283214	13850	Economy	33300.00
0005435283201	13850	Economy	33300.00
0005433847943	13850	Economy	33300.00
0005433847951	13850	Economy	33300.00
0005433848191	13850	Economy	33300.00
0005435283200	13850	Economy	33300.00
0005432003790	13850	Economy	33300.00
0005433848000	13850	Economy	33300.00
0005433848144	13850	Economy	33300.00
0005433847962	13850	Economy	33300.00
0005433847802	13850	Economy	33300.00
0005433847460	13850	Economy	33300.00
0005435283208	13850	Economy	33300.00
0005435283206	13850	Economy	33300.00
0005433847844	13850	Economy	33300.00
0005433847923	13850	Economy	33300.00
0005435283207	13850	Economy	33300.00
0005433847696	13850	Economy	33300.00
0005433847922	13850	Economy	33300.00
0005433815481	13850	Economy	33300.00
0005433847885	13850	Economy	33300.00
0005433847999	13850	Economy	33300.00
0005433847636	13850	Economy	33300.00
0005433847938	13850	Economy	33300.00
0005433815491	13850	Economy	33300.00
0005432003792	13850	Economy	33300.00
0005434173661	13850	Economy	33300.00
0005435283202	13850	Economy	33300.00
0005433848045	13850	Economy	33300.00
0005433847805	13850	Economy	33300.00
0005435283213	13850	Economy	33300.00
0005433847701	13850	Economy	33300.00
0005433847944	13850	Economy	33300.00
0005433847664	13850	Economy	33300.00
0005433847734	13850	Economy	33300.00
0005432003791	13850	Economy	33300.00
0005433847583	13850	Economy	33300.00
0005433847459	13850	Economy	33300.00
0005434621155	7827	Economy	16600.00
0005434621159	7827	Economy	15100.00
0005435332536	7827	Economy	15100.00
0005434621160	7827	Economy	15100.00
0005435332524	7827	Economy	15100.00
0005434621161	7827	Economy	15100.00
0005434621154	7827	Economy	15100.00
0005434621158	7827	Economy	15100.00
0005434621156	7827	Economy	15100.00
0005434621153	7827	Economy	15100.00
0005432112579	7827	Economy	15100.00
0005435332525	7827	Economy	15100.00
0005435332538	7827	Economy	15100.00
0005434621157	7827	Economy	15100.00
0005434621046	32954	Economy	16600.00
0005435332620	32954	Economy	15100.00
0005434620968	32954	Economy	15100.00
0005434621035	32954	Economy	15100.00
0005435332623	32954	Economy	15100.00
0005435332625	32954	Economy	15100.00
0005434621004	32954	Economy	15100.00
0005435332627	32954	Economy	15100.00
0005434621068	32954	Economy	15100.00
0005435332628	32954	Economy	15100.00
0005434621087	32954	Economy	15100.00
0005434620954	32954	Economy	15100.00
0005435332626	32954	Economy	15100.00
0005434620960	32954	Economy	15100.00
0005434620967	32954	Economy	15100.00
0005434620953	32954	Economy	15100.00
0005434620997	32954	Economy	15100.00
0005434621034	32954	Economy	15100.00
0005435332621	32954	Economy	15100.00
0005435332624	32954	Economy	15100.00
0005434621005	32954	Economy	15100.00
0005435332622	32954	Economy	15100.00
0005434620961	32954	Economy	15100.00
0005434621078	32954	Economy	15100.00
0005434621020	32954	Economy	15100.00
0005434621044	32954	Economy	15100.00
0005434621017	32954	Economy	15100.00
0005434621067	32954	Economy	15100.00
0005435332619	32954	Economy	15100.00
0005434620868	32954	Economy	15100.00
0005434620869	32954	Economy	15100.00
0005434621079	32954	Economy	15100.00
0005434621036	32954	Economy	15100.00
0005435786315	4272	Business	38000.00
0005435786306	4272	Business	38000.00
0005432190739	4272	Business	38000.00
0005435937493	4272	Business	38000.00
0005435918754	4272	Economy	12700.00
0005435786316	4272	Economy	12700.00
0005435786314	4272	Economy	12700.00
0005435786313	4272	Economy	12700.00
0005434994295	4272	Economy	13900.00
0005434994292	4272	Economy	13900.00
0005434994296	4272	Economy	13900.00
0005435786321	4272	Economy	13900.00
0005434994294	4272	Economy	12700.00
0005435786311	4272	Economy	12700.00
0005435786305	4272	Economy	12700.00
0005435937476	4272	Economy	12700.00
0005435786307	4272	Economy	12700.00
0005435937465	4272	Economy	12700.00
0005435918753	4272	Economy	12700.00
0005435937478	4272	Economy	12700.00
0005435937505	4272	Economy	12700.00
0005435786310	4272	Economy	12700.00
0005435786319	4272	Economy	12700.00
0005435786318	4272	Economy	12700.00
0005435787412	4272	Economy	12700.00
0005432190738	4272	Economy	12700.00
0005435937466	4272	Economy	12700.00
0005435937457	4272	Economy	12700.00
0005435786308	4272	Economy	12700.00
0005435786317	4272	Economy	12700.00
0005434994293	4272	Economy	12700.00
0005435786309	4272	Economy	12700.00
0005435786322	4272	Economy	12700.00
0005435786312	4272	Economy	12700.00
0005435786320	4272	Economy	12700.00
0005435937477	4272	Economy	12700.00
0005435937547	27315	Business	38000.00
0005435786003	27315	Business	38000.00
0005435937543	27315	Business	38000.00
0005435786100	27315	Business	38000.00
0005434994227	27315	Business	38000.00
0005435937546	27315	Business	38000.00
0005435785993	27315	Business	38000.00
0005435918787	27315	Business	38000.00
0005435785868	27315	Economy	12700.00
0005435918791	27315	Economy	12700.00
0005434994229	27315	Economy	12700.00
0005434994215	27315	Economy	12700.00
0005434994226	27315	Economy	12700.00
0005434994233	27315	Economy	12700.00
0005435785910	27315	Economy	12700.00
0005435785985	27315	Economy	13900.00
0005435785954	27315	Economy	12700.00
0005435918790	27315	Economy	12700.00
0005435918788	27315	Economy	12700.00
0005435785935	27315	Economy	12700.00
0005435787392	27315	Economy	12700.00
0005434994189	27315	Economy	12700.00
0005435785995	27315	Economy	12700.00
0005435785869	27315	Economy	12700.00
0005435786099	27315	Economy	12700.00
0005435785915	27315	Economy	12700.00
0005435937548	27315	Economy	12700.00
0005435785952	27315	Economy	12700.00
0005435937542	27315	Economy	12700.00
0005434994188	27315	Economy	12700.00
0005435937545	27315	Economy	12700.00
0005435786013	27315	Economy	12700.00
0005435786023	27315	Economy	12700.00
0005432195753	27315	Economy	12700.00
0005435785955	27315	Economy	12700.00
0005435785885	27315	Economy	12700.00
0005435785841	27315	Economy	12700.00
0005435785972	27315	Economy	12700.00
0005435786012	27315	Economy	12700.00
0005435918789	27315	Economy	12700.00
0005435786025	27315	Economy	12700.00
0005435785772	27315	Economy	12700.00
0005435786014	27315	Economy	12700.00
0005435786101	27315	Economy	12700.00
0005435785916	27315	Economy	12700.00
0005435785953	27315	Economy	12700.00
0005434994225	27315	Economy	12700.00
0005435785870	27315	Economy	12700.00
0005435786004	27315	Economy	12700.00
0005435785842	27315	Economy	12700.00
0005435786024	27315	Economy	12700.00
0005432195752	27315	Economy	12700.00
0005435937544	27315	Economy	12700.00
0005435785986	27315	Economy	12700.00
0005435918792	27315	Economy	12700.00
0005432146257	19861	Economy	12800.00
0005432146256	19861	Economy	12800.00
0005434082604	4698	Business	40900.00
0005434082609	4698	Business	40900.00
0005434082603	4698	Business	40900.00
0005433726169	4698	Business	40900.00
0005432571428	4698	Business	40900.00
0005432461325	4698	Business	40900.00
0005432569341	4698	Business	40900.00
0005434082605	4698	Business	40900.00
0005434559168	4698	Business	40900.00
0005432461320	4698	Business	40900.00
0005433451675	4698	Business	40900.00
0005432170573	4698	Business	40900.00
0005435840392	4698	Business	40900.00
0005432569337	4698	Business	40900.00
0005432461322	4698	Economy	15000.00
0005434559167	4698	Economy	15000.00
0005432186970	4698	Economy	13600.00
0005432569336	4698	Economy	13600.00
0005434559169	4698	Economy	13600.00
0005432569318	4698	Economy	13600.00
0005432461300	4698	Economy	13600.00
0005435840397	4698	Economy	13600.00
0005432569326	4698	Economy	13600.00
0005435840400	4698	Economy	13600.00
0005434082591	4698	Economy	13600.00
0005432569315	4698	Economy	13600.00
0005432569333	4698	Economy	13600.00
0005432569311	4698	Economy	13600.00
0005435840362	4698	Economy	13600.00
0005432461309	4698	Economy	13600.00
0005432569338	4698	Economy	13600.00
0005432461303	4698	Economy	13600.00
0005432461316	4698	Economy	13600.00
0005432461297	4698	Economy	13600.00
0005434082590	4698	Economy	13600.00
0005432569323	4698	Economy	13600.00
0005434082594	4698	Economy	13600.00
0005432571429	4698	Economy	13600.00
0005434082608	4698	Economy	13600.00
0005434559176	4698	Economy	13600.00
0005432569319	4698	Economy	13600.00
0005432569312	4698	Economy	13600.00
0005432569327	4698	Economy	13600.00
0005432569330	4698	Economy	13600.00
0005432569313	4698	Economy	13600.00
0005432569324	4698	Economy	13600.00
0005434082595	4698	Economy	13600.00
0005432461317	4698	Economy	13600.00
0005432461310	4698	Economy	13600.00
0005432461326	4698	Economy	13600.00
0005432569325	4698	Economy	13600.00
0005432569314	4698	Economy	13600.00
0005432461315	4698	Economy	13600.00
0005432461330	4698	Economy	13600.00
0005434559172	4698	Economy	13600.00
0005432569321	4698	Economy	13600.00
0005433451674	4698	Economy	13600.00
0005434559174	4698	Economy	13600.00
0005432569332	4698	Economy	13600.00
0005434082598	4698	Economy	13600.00
0005432569331	4698	Economy	13600.00
0005432461323	4698	Economy	13600.00
0005432569320	4698	Economy	13600.00
0005432571427	4698	Economy	13600.00
0005432569322	4698	Economy	13600.00
0005432186969	4698	Economy	13600.00
0005432461304	4698	Economy	13600.00
0005434082606	4698	Economy	13600.00
0005432461306	4698	Economy	13600.00
0005434559173	4698	Economy	13600.00
0005432461321	4698	Economy	13600.00
0005432461328	4698	Economy	13600.00
0005435840386	4698	Economy	13600.00
0005433726168	4698	Economy	13600.00
0005432186972	4698	Economy	13600.00
0005432569328	4698	Economy	13600.00
0005433452794	4698	Economy	13600.00
0005432461296	4698	Economy	13600.00
0005432569317	4698	Economy	13600.00
0005432170574	4698	Economy	13600.00
0005432461308	4698	Economy	13600.00
0005432461313	4698	Economy	13600.00
0005432461298	4698	Economy	13600.00
0005434082597	4698	Economy	13600.00
0005434082596	4698	Economy	13600.00
0005432461311	4698	Economy	13600.00
0005434082600	4698	Economy	13600.00
0005432569339	4698	Economy	13600.00
0005432461314	4698	Economy	13600.00
0005432461312	4698	Economy	13600.00
0005432461299	4698	Economy	13600.00
0005432461305	4698	Economy	13600.00
0005432461324	4698	Economy	13600.00
0005432461307	4698	Economy	13600.00
0005432569316	4698	Economy	13600.00
0005432461327	4698	Economy	13600.00
0005432461318	4698	Economy	13600.00
0005434559166	4698	Economy	13600.00
0005434082602	4698	Economy	13600.00
0005434082599	4698	Economy	13600.00
0005432569329	4698	Economy	13600.00
0005434082593	4698	Economy	13600.00
0005432461302	4698	Economy	13600.00
0005435840369	4698	Economy	13600.00
0005434082592	4698	Economy	13600.00
0005432170572	4698	Economy	13600.00
0005434082589	4698	Economy	13600.00
0005432569342	4698	Economy	13600.00
0005434082607	4698	Economy	13600.00
0005434082601	4698	Economy	13600.00
0005432461329	4698	Economy	13600.00
0005432569340	4698	Economy	13600.00
0005432461319	4698	Economy	13600.00
0005432186971	4698	Economy	13600.00
0005432569334	4698	Economy	13600.00
0005434559171	4698	Economy	13600.00
0005432461301	4698	Economy	13600.00
0005434559175	4698	Economy	13600.00
0005432569335	4698	Economy	13600.00
0005434559170	4698	Economy	13600.00
0005432461117	30536	Business	40900.00
0005435840505	30536	Business	40900.00
0005434150160	30536	Business	40900.00
0005432569072	30536	Business	40900.00
0005432568846	30536	Business	40900.00
0005432568976	30536	Business	40900.00
0005432460731	30536	Business	40900.00
0005432568941	30536	Business	40900.00
0005434150151	30536	Business	40900.00
0005434082321	30536	Business	40900.00
0005432568960	30536	Business	40900.00
0005432571400	30536	Business	40900.00
0005432568890	30536	Business	40900.00
0005434082255	30536	Business	40900.00
0005434150182	30536	Business	40900.00
0005432569078	30536	Business	40900.00
0005432460889	30536	Business	40900.00
0005434150172	30536	Business	40900.00
0005435840502	30536	Business	40900.00
0005432568871	30536	Business	40900.00
0005434150153	30536	Business	40900.00
0005432568908	30536	Business	40900.00
0005432568980	30536	Business	40900.00
0005432460623	30536	Business	40900.00
0005432569077	30536	Business	40900.00
0005432568734	30536	Economy	15000.00
0005434150178	30536	Economy	15000.00
0005432568940	30536	Economy	15000.00
0005434150158	30536	Economy	13600.00
0005434082377	30536	Economy	13600.00
0005434082315	30536	Economy	13600.00
0005432568953	30536	Economy	13600.00
0005435840504	30536	Economy	13600.00
0005432568844	30536	Economy	13600.00
0005434150177	30536	Economy	13600.00
0005432460898	30536	Economy	13600.00
0005434082396	30536	Economy	13600.00
0005435840489	30536	Economy	13600.00
0005435840486	30536	Economy	13600.00
0005432568822	30536	Economy	13600.00
0005432460705	30536	Economy	13600.00
0005435840498	30536	Economy	13600.00
0005432461163	30536	Economy	13600.00
0005435840506	30536	Economy	13600.00
0005434150168	30536	Economy	13600.00
0005432461158	30536	Economy	13600.00
0005435840499	30536	Economy	13600.00
0005432568730	30536	Economy	13600.00
0005434150175	30536	Economy	13600.00
0005435840483	30536	Economy	13600.00
0005434082267	30536	Economy	13600.00
0005432568892	30536	Economy	13600.00
0005434082268	30536	Economy	13600.00
0005432569076	30536	Economy	13600.00
0005434150164	30536	Economy	13600.00
0005432568891	30536	Economy	13600.00
0005434150166	30536	Economy	13600.00
0005434082291	30536	Economy	13600.00
0005435840507	30536	Economy	13600.00
0005432460900	30536	Economy	13600.00
0005434082395	30536	Economy	13600.00
0005434082447	30536	Economy	13600.00
0005435840501	30536	Economy	13600.00
0005432568817	30536	Economy	13600.00
0005432568853	30536	Economy	13600.00
0005432460983	30536	Economy	13600.00
0005432571401	30536	Economy	13600.00
0005434150154	30536	Economy	13600.00
0005434082413	30536	Economy	13600.00
0005432568847	30536	Economy	13600.00
0005432460963	30536	Economy	13600.00
0005433454916	30536	Economy	13600.00
0005432569140	30536	Economy	13600.00
0005432569032	30536	Economy	13600.00
0005432460741	30536	Economy	13600.00
0005434082357	30536	Economy	13600.00
0005435840493	30536	Economy	13600.00
0005432460836	30536	Economy	13600.00
0005435960172	30536	Economy	13600.00
0005432568735	30536	Economy	13600.00
0005432568674	30536	Economy	13600.00
0005434082336	30536	Economy	13600.00
0005434082201	30536	Economy	13600.00
0005432568841	30536	Economy	13600.00
0005434150157	30536	Economy	13600.00
0005432568918	30536	Economy	13600.00
0005434150173	30536	Economy	13600.00
0005435840478	30536	Economy	13600.00
0005434150170	30536	Economy	13600.00
0005434082376	30536	Economy	13600.00
0005434082256	30536	Economy	13600.00
0005434150179	30536	Economy	13600.00
0005434150163	30536	Economy	13600.00
0005432568649	30536	Economy	13600.00
0005432460955	30536	Economy	13600.00
0005434082448	30536	Economy	13600.00
0005432571398	30536	Economy	13600.00
0005432460799	30536	Economy	13600.00
0005432568966	30536	Economy	13600.00
0005434150162	30536	Economy	13600.00
0005432568909	30536	Economy	13600.00
0005432569088	30536	Economy	13600.00
0005434150180	30536	Economy	13600.00
0005432569141	30536	Economy	13600.00
0005432568650	30536	Economy	13600.00
0005432568915	30536	Economy	13600.00
0005432460952	30536	Economy	13600.00
0005432568833	30536	Economy	13600.00
0005432460730	30536	Economy	13600.00
0005434082392	30536	Economy	13600.00
0005434150159	30536	Economy	13600.00
0005432568845	30536	Economy	13600.00
0005435840497	30536	Economy	13600.00
0005432568939	30536	Economy	13600.00
0005435840487	30536	Economy	13600.00
0005432568913	30536	Economy	13600.00
0005435840490	30536	Economy	13600.00
0005434082343	30536	Economy	13600.00
0005432461164	30536	Economy	13600.00
0005435960171	30536	Economy	13600.00
0005432460947	30536	Economy	13600.00
0005435840492	30536	Economy	13600.00
0005432460970	30536	Economy	15000.00
0005432460798	30536	Economy	13600.00
0005432569223	30536	Economy	15000.00
0005435840481	30536	Economy	13600.00
0005434082236	30536	Economy	13600.00
0005435840488	30536	Economy	15000.00
0005434082257	30536	Economy	13600.00
0005432569116	30536	Economy	15000.00
0005435840485	30536	Economy	13600.00
0005432460835	30536	Economy	13600.00
0005432568981	30536	Economy	13600.00
0005432460946	30536	Economy	13600.00
0005435960173	30536	Economy	13600.00
0005432460704	30536	Economy	13600.00
0005432568731	30536	Economy	13600.00
0005432569115	30536	Economy	13600.00
0005434150155	30536	Economy	13600.00
0005434082335	30536	Economy	13600.00
0005432571407	30536	Economy	13600.00
0005434082358	30536	Economy	13600.00
0005434082319	30536	Economy	13600.00
0005434150174	30536	Economy	13600.00
0005432569046	30536	Economy	13600.00
0005434150176	30536	Economy	13600.00
0005435840479	30536	Economy	13600.00
0005432461103	30536	Economy	13600.00
0005432568832	30536	Economy	13600.00
0005432568850	30536	Economy	13600.00
0005432569041	30536	Economy	13600.00
0005432571402	30536	Economy	13600.00
0005434150169	30536	Economy	13600.00
0005432568961	30536	Economy	13600.00
0005432460693	30536	Economy	13600.00
0005432568880	30536	Economy	13600.00
0005435840482	30536	Economy	13600.00
0005432568673	30536	Economy	13600.00
0005434150181	30536	Economy	13600.00
0005432568938	30536	Economy	13600.00
0005434082322	30536	Economy	13600.00
0005434150171	30536	Economy	13600.00
0005434150150	30536	Economy	13600.00
0005432568975	30536	Economy	13600.00
0005432460953	30536	Economy	13600.00
0005435840484	30536	Economy	13600.00
0005432460939	30536	Economy	13600.00
0005432460940	30536	Economy	13600.00
0005435840503	30536	Economy	13600.00
0005434150156	30536	Economy	13600.00
0005432568789	30536	Economy	13600.00
0005432569042	30536	Economy	13600.00
0005435840496	30536	Economy	13600.00
0005432460927	30536	Economy	13600.00
0005432568818	30536	Economy	13600.00
0005432571375	30536	Economy	13600.00
0005434082292	30536	Economy	13600.00
0005432569114	30536	Economy	13600.00
0005432568914	30536	Economy	13600.00
0005434082439	30536	Economy	13600.00
0005435840494	30536	Economy	13600.00
0005434082266	30536	Economy	13600.00
0005432568974	30536	Economy	13600.00
0005435840500	30536	Economy	13600.00
0005434082406	30536	Economy	13600.00
0005435840495	30536	Economy	13600.00
0005432571403	30536	Economy	13600.00
0005432571399	30536	Economy	13600.00
0005434150152	30536	Economy	13600.00
0005432460888	30536	Economy	13600.00
0005435840491	30536	Economy	13600.00
0005435840477	30536	Economy	13600.00
0005434150167	30536	Economy	13600.00
0005432569047	30536	Economy	13600.00
0005432460887	30536	Economy	13600.00
0005434150183	30536	Economy	13600.00
0005435840480	30536	Economy	13600.00
0005434082316	30536	Economy	13600.00
0005434150165	30536	Economy	13600.00
0005432461118	30536	Economy	13600.00
0005433454912	30536	Economy	13600.00
0005434150161	30536	Economy	13600.00
0005435722120	13648	Economy	9900.00
0005435722109	21170	Economy	9900.00
0005435722110	21170	Economy	9900.00
0005435722108	21170	Economy	9900.00
0005432295954	22799	Economy	8800.00
0005432295955	22799	Economy	8800.00
0005435508583	11123	Business	23600.00
0005433345933	11123	Business	23600.00
0005433345947	11123	Business	23600.00
0005433345897	11123	Business	23600.00
0005435508677	11123	Business	23600.00
0005435530016	11123	Business	23600.00
0005433345903	11123	Business	23600.00
0005435097482	11123	Business	23600.00
0005433345896	11123	Business	23600.00
0005433345936	11123	Economy	7900.00
0005433345917	11123	Economy	7900.00
0005433345900	11123	Economy	7900.00
0005435380387	11123	Economy	7900.00
0005433345948	11123	Economy	7900.00
0005435097480	11123	Economy	7900.00
0005435380385	11123	Economy	7900.00
0005433345941	11123	Economy	7900.00
0005435508600	11123	Economy	7900.00
0005433345912	11123	Economy	7900.00
0005433345911	11123	Economy	7900.00
0005433345957	11123	Economy	7900.00
0005435097481	11123	Economy	7900.00
0005435508575	11123	Economy	7900.00
0005433345918	11123	Economy	7900.00
0005433345945	11123	Economy	7900.00
0005435097484	11123	Economy	7900.00
0005433345914	11123	Economy	7900.00
0005433345942	11123	Economy	7900.00
0005435529983	11123	Economy	7900.00
0005433345898	11123	Economy	7900.00
0005435508682	11123	Economy	7900.00
0005435380369	11123	Economy	7900.00
0005435508594	11123	Economy	7900.00
0005433345907	11123	Economy	7900.00
0005433345926	11123	Economy	7900.00
0005435380391	11123	Economy	7900.00
0005433345901	11123	Economy	7900.00
0005433345951	11123	Economy	7900.00
0005433345922	11123	Economy	7900.00
0005433345954	11123	Economy	7900.00
0005433345950	11123	Economy	7900.00
0005433345927	11123	Economy	7900.00
0005433345929	11123	Economy	8600.00
0005435530017	11123	Economy	8600.00
0005433345956	11123	Economy	8600.00
0005435508675	11123	Economy	8600.00
0005433345906	11123	Economy	8600.00
0005433345955	11123	Economy	8600.00
0005435530037	11123	Economy	7900.00
0005433345902	11123	Economy	7900.00
0005435380406	11123	Economy	7900.00
0005435530049	11123	Economy	7900.00
0005433345930	11123	Economy	7900.00
0005433345905	11123	Economy	7900.00
0005433345944	11123	Economy	7900.00
0005433345953	11123	Economy	7900.00
0005435380396	11123	Economy	7900.00
0005435508671	11123	Economy	7900.00
0005435380386	11123	Economy	7900.00
0005433345937	11123	Economy	7900.00
0005433345908	11123	Economy	7900.00
0005435508674	11123	Economy	7900.00
0005435530018	11123	Economy	7900.00
0005435508676	11123	Economy	7900.00
0005435097485	11123	Economy	7900.00
0005433345940	11123	Economy	7900.00
0005435508581	11123	Economy	7900.00
0005435380402	11123	Economy	7900.00
0005433345916	11123	Economy	7900.00
0005433345904	11123	Economy	7900.00
0005433345919	11123	Economy	7900.00
0005435508582	11123	Economy	7900.00
0005435380390	11123	Economy	7900.00
0005435530028	11123	Economy	7900.00
0005433345910	11123	Economy	7900.00
0005435508595	11123	Economy	7900.00
0005435508681	11123	Economy	7900.00
0005433345949	11123	Economy	7900.00
0005433345934	11123	Economy	7900.00
0005435097479	11123	Economy	7900.00
0005435508623	11123	Economy	7900.00
0005433345915	11123	Economy	7900.00
0005433345928	11123	Economy	7900.00
0005433345935	11123	Economy	7900.00
0005433345952	11123	Economy	7900.00
0005433345913	11123	Economy	7900.00
0005433345924	11123	Economy	7900.00
0005435380368	11123	Economy	7900.00
0005435508614	11123	Economy	7900.00
0005435508542	11123	Economy	7900.00
0005435508670	11123	Economy	7900.00
0005435097486	11123	Economy	7900.00
0005433345923	11123	Economy	7900.00
0005433345943	11123	Economy	7900.00
0005433345946	11123	Economy	7900.00
0005435508593	11123	Economy	7900.00
0005433345909	11123	Economy	7900.00
0005435380400	11123	Economy	7900.00
0005433345932	11123	Economy	7900.00
0005433345931	11123	Economy	7900.00
0005433345958	11123	Economy	7900.00
0005435530042	11123	Economy	7900.00
0005433345938	11123	Economy	7900.00
0005435380389	11123	Economy	7900.00
0005433345899	11123	Economy	7900.00
0005433345925	11123	Economy	7900.00
0005435530036	11123	Economy	7900.00
0005435530014	11123	Economy	7900.00
0005435508683	11123	Economy	7900.00
0005435380395	11123	Economy	7900.00
0005433345920	11123	Economy	7900.00
0005435097483	11123	Economy	7900.00
0005433345921	11123	Economy	7900.00
0005433345939	11123	Economy	7900.00
0005433345147	17134	Business	23600.00
0005433344965	17134	Business	23600.00
0005433345218	17134	Business	23600.00
0005433345172	17134	Business	23600.00
0005433345169	17134	Business	23600.00
0005433344983	17134	Business	23600.00
0005433345214	17134	Business	23600.00
0005433345384	17134	Business	23600.00
0005433344937	17134	Business	23600.00
0005433344988	17134	Business	23600.00
0005433344957	17134	Business	23600.00
0005433344949	17134	Business	23600.00
0005433345059	17134	Economy	7900.00
0005435545951	17134	Economy	7900.00
0005433344966	17134	Economy	7900.00
0005435097414	17134	Economy	7900.00
0005435380438	17134	Economy	7900.00
0005433345124	17134	Economy	7900.00
0005433345191	17134	Economy	7900.00
0005433344739	17134	Economy	7900.00
0005433345000	17134	Economy	7900.00
0005433345008	17134	Economy	7900.00
0005435097388	17134	Economy	7900.00
0005433345140	17134	Economy	7900.00
0005433344903	17134	Economy	7900.00
0005433344887	17134	Economy	7900.00
0005433344958	17134	Economy	7900.00
0005433345413	17134	Economy	7900.00
0005433345033	17134	Economy	7900.00
0005435097365	17134	Economy	7900.00
0005433345518	17134	Economy	7900.00
0005433345236	17134	Economy	7900.00
0005433345272	17134	Economy	7900.00
0005433344888	17134	Economy	7900.00
0005435097398	17134	Economy	7900.00
0005433344482	17134	Economy	7900.00
0005433344733	17134	Economy	7900.00
0005432293275	17134	Economy	7900.00
0005435097411	17134	Economy	7900.00
0005433345399	17134	Economy	7900.00
0005433345118	17134	Economy	7900.00
0005435380434	17134	Economy	7900.00
0005435380437	17134	Economy	7900.00
0005433344524	17134	Economy	7900.00
0005435097421	17134	Economy	7900.00
0005435097387	17134	Economy	7900.00
0005433344970	17134	Economy	7900.00
0005433345592	17134	Economy	7900.00
0005435545949	17134	Economy	7900.00
0005433345205	17134	Economy	7900.00
0005435380436	17134	Economy	7900.00
0005432293277	17134	Economy	7900.00
0005433344963	17134	Economy	8600.00
0005433344964	17134	Economy	8600.00
0005433345217	17134	Economy	8600.00
0005433345184	17134	Economy	8600.00
0005433345167	17134	Economy	8600.00
0005433344491	17134	Economy	7900.00
0005433344798	17134	Economy	8600.00
0005433344977	17134	Economy	7900.00
0005433345117	17134	Economy	7900.00
0005433344915	17134	Economy	7900.00
0005433344954	17134	Economy	7900.00
0005433344851	17134	Economy	7900.00
0005433344827	17134	Economy	7900.00
0005433345361	17134	Economy	7900.00
0005433345331	17134	Economy	7900.00
0005433344869	17134	Economy	7900.00
0005435097413	17134	Economy	7900.00
0005433345077	17134	Economy	7900.00
0005433345001	17134	Economy	7900.00
0005435097423	17134	Economy	7900.00
0005432293276	17134	Economy	7900.00
0005433344789	17134	Economy	7900.00
0005435097396	17134	Economy	7900.00
0005433345143	17134	Economy	7900.00
0005433345039	17134	Economy	7900.00
0005433345168	17134	Economy	7900.00
0005433345181	17134	Economy	7900.00
0005433345127	17134	Economy	7900.00
0005433345058	17134	Economy	7900.00
0005433345379	17134	Economy	7900.00
0005433344483	17134	Economy	7900.00
0005433344720	17134	Economy	7900.00
0005433345104	17134	Economy	7900.00
0005433344870	17134	Economy	7900.00
0005433345204	17134	Economy	7900.00
0005433345139	17134	Economy	7900.00
0005433345208	17134	Economy	7900.00
0005433344942	17134	Economy	7900.00
0005433345116	17134	Economy	7900.00
0005435545950	17134	Economy	7900.00
0005435380433	17134	Economy	7900.00
0005435097395	17134	Economy	7900.00
0005435097386	17134	Economy	7900.00
0005435380439	17134	Economy	7900.00
0005435380435	17134	Economy	7900.00
0005433345171	17134	Economy	7900.00
0005433345382	17134	Economy	7900.00
0005433345223	17134	Economy	7900.00
0005433345173	17134	Economy	7900.00
0005433345183	17134	Economy	7900.00
0005433345074	17134	Economy	7900.00
0005433344698	17134	Economy	7900.00
0005433344962	17134	Economy	7900.00
0005433345381	17134	Economy	7900.00
0005433344868	17134	Economy	7900.00
0005433345517	17134	Economy	7900.00
0005435097420	17134	Economy	7900.00
0005433345330	17134	Economy	7900.00
0005433344871	17134	Economy	7900.00
0005435097409	17134	Economy	7900.00
0005433344852	17134	Economy	7900.00
0005433345414	17134	Economy	7900.00
0005433345103	17134	Economy	7900.00
0005433345157	17134	Economy	7900.00
0005433345398	17134	Economy	7900.00
0005433344969	17134	Economy	7900.00
0005435097379	17134	Economy	7900.00
0005433345349	17134	Economy	7900.00
0005435097360	17134	Economy	7900.00
0005433344981	17134	Economy	7900.00
0005433344872	17134	Economy	7900.00
0005433345263	17134	Economy	7900.00
0005433345360	17134	Economy	7900.00
0005433345082	17134	Economy	7900.00
0005433345256	17134	Economy	7900.00
0005433345162	17134	Economy	7900.00
0005435097399	17134	Economy	7900.00
0005433344683	17134	Economy	7900.00
0005432920182	9098	Business	26600.00
0005432920194	9098	Business	26600.00
0005432920319	9098	Business	26600.00
0005432920312	9098	Business	26600.00
0005433507692	9098	Business	26600.00
0005433507693	9098	Business	26600.00
0005433481381	9098	Economy	8900.00
0005432920219	9098	Economy	8900.00
0005433477235	9098	Economy	8900.00
0005432920215	9098	Economy	8900.00
0005433507699	9098	Economy	8900.00
0005434159020	9098	Economy	8900.00
0005432920330	9098	Economy	8900.00
0005433507694	9098	Economy	8900.00
0005432920294	9098	Economy	9800.00
0005433507696	9098	Economy	9800.00
0005433481380	9098	Economy	8900.00
0005433481383	9098	Economy	8900.00
0005432920283	9098	Economy	8900.00
0005433507689	9098	Economy	8900.00
0005433477236	9098	Economy	8900.00
0005433477233	9098	Economy	8900.00
0005433477243	9098	Economy	8900.00
0005433477239	9098	Economy	8900.00
0005433477240	9098	Economy	8900.00
0005434159021	9098	Economy	8900.00
0005433507695	9098	Economy	8900.00
0005432920269	9098	Economy	8900.00
0005433477245	9098	Economy	8900.00
0005432920270	9098	Economy	8900.00
0005432920304	9098	Economy	8900.00
0005433477246	9098	Economy	8900.00
0005433477249	9098	Economy	8900.00
0005432920189	9098	Economy	8900.00
0005433477244	9098	Economy	8900.00
0005433477234	9098	Economy	8900.00
0005433477242	9098	Economy	8900.00
0005432920246	9098	Economy	8900.00
0005433477247	9098	Economy	8900.00
0005433477238	9098	Economy	8900.00
0005432920183	9098	Economy	8900.00
0005433507700	9098	Economy	8900.00
0005433507690	9098	Economy	8900.00
0005432920181	9098	Economy	8900.00
0005432920235	9098	Economy	8900.00
0005432920209	9098	Economy	8900.00
0005433507701	9098	Economy	8900.00
0005434159017	9098	Economy	8900.00
0005433507691	9098	Economy	8900.00
0005433507698	9098	Economy	8900.00
0005432920249	9098	Economy	8900.00
0005433477232	9098	Economy	8900.00
0005433507697	9098	Economy	8900.00
0005432920264	9098	Economy	8900.00
0005432920273	9098	Economy	8900.00
0005433477241	9098	Economy	8900.00
0005433477231	9098	Economy	8900.00
0005433481382	9098	Economy	8900.00
0005432920238	9098	Economy	8900.00
0005432920284	9098	Economy	8900.00
0005433477248	9098	Economy	8900.00
0005433477237	9098	Economy	8900.00
0005432920307	9098	Economy	8900.00
0005432920306	9098	Economy	8900.00
0005432920454	20471	Business	26600.00
0005433481327	20471	Business	26600.00
0005433507411	20471	Business	26600.00
0005433481341	20471	Business	26600.00
0005433477012	20471	Business	26600.00
0005433477003	20471	Business	26600.00
0005433507559	20471	Business	26600.00
0005432920453	20471	Business	26600.00
0005432920460	20471	Business	26600.00
0005433507459	20471	Economy	8900.00
0005433481342	20471	Economy	8900.00
0005432920457	20471	Economy	8900.00
0005433476975	20471	Economy	8900.00
0005433481328	20471	Economy	9800.00
0005433507573	20471	Economy	9800.00
0005433476983	20471	Economy	8900.00
0005434159053	20471	Economy	8900.00
0005433476969	20471	Economy	8900.00
0005433481317	20471	Economy	8900.00
0005434159051	20471	Economy	8900.00
0005433476965	20471	Economy	8900.00
0005433507542	20471	Economy	8900.00
0005433476968	20471	Economy	8900.00
0005433477010	20471	Economy	8900.00
0005432920455	20471	Economy	8900.00
0005432920462	20471	Economy	8900.00
0005433507541	20471	Economy	8900.00
0005433477021	20471	Economy	8900.00
0005433481331	20471	Economy	8900.00
0005433481302	20471	Economy	8900.00
0005434159050	20471	Economy	8900.00
0005433507619	20471	Economy	8900.00
0005433476970	20471	Economy	8900.00
0005433507460	20471	Economy	8900.00
0005433476982	20471	Economy	8900.00
0005433507583	20471	Economy	8900.00
0005432920461	20471	Economy	8900.00
0005433476976	20471	Economy	8900.00
0005433476980	20471	Economy	8900.00
0005433476987	20471	Economy	8900.00
0005433476966	20471	Economy	8900.00
0005433477002	20471	Economy	8900.00
0005432920458	20471	Economy	8900.00
0005433476981	20471	Economy	8900.00
0005433476979	20471	Economy	8900.00
0005432920459	20471	Economy	8900.00
0005433481301	20471	Economy	8900.00
0005433476992	20471	Economy	8900.00
0005432920463	20471	Economy	8900.00
0005433477008	20471	Economy	8900.00
0005433476977	20471	Economy	8900.00
0005433481332	20471	Economy	8900.00
0005433477001	20471	Economy	8900.00
0005433476971	20471	Economy	8900.00
0005433507543	20471	Economy	8900.00
0005432920456	20471	Economy	8900.00
0005433507636	20471	Economy	8900.00
0005433476972	20471	Economy	8900.00
0005433507544	20471	Economy	8900.00
0005433507549	20471	Economy	8900.00
0005433476978	20471	Economy	8900.00
0005434159052	20471	Economy	8900.00
0005434159054	20471	Economy	8900.00
0005432396350	10200	Economy	5800.00
0005435179008	10200	Economy	5800.00
0005432394214	10200	Economy	5800.00
0005432394213	10200	Economy	5800.00
0005432396351	10200	Economy	5800.00
0005432396349	10200	Economy	5800.00
0005435179005	10200	Economy	5800.00
0005432394215	10200	Economy	5800.00
0005432396320	18281	Economy	5800.00
0005435179425	18281	Economy	5800.00
0005435179426	18281	Economy	5800.00
0005435179717	18281	Economy	5800.00
0005432400198	18281	Economy	5800.00
0005432400183	18281	Economy	5800.00
0005435179718	18281	Economy	5800.00
0005432396333	18281	Economy	5800.00
0005432400189	18281	Economy	5800.00
0005435179427	18281	Economy	5800.00
0005432400197	18281	Economy	5800.00
0005432396332	18281	Economy	5800.00
0005435127233	10999	Business	9500.00
0005435626490	10999	Business	9500.00
0005435127080	10999	Business	9500.00
0005435556744	10999	Business	9500.00
0005435127185	10999	Business	9500.00
0005435127037	10999	Business	9500.00
0005435626475	10999	Business	9500.00
0005435127082	10999	Business	9500.00
0005435127085	10999	Business	9500.00
0005435127081	10999	Business	9500.00
0005435554271	10999	Business	9500.00
0005435127205	10999	Economy	3200.00
0005435127165	10999	Economy	3200.00
0005435127172	10999	Economy	3200.00
0005435626494	10999	Economy	3200.00
0005435127114	10999	Economy	3200.00
0005435127234	10999	Economy	3200.00
0005435127188	10999	Economy	3200.00
0005435626468	10999	Economy	3200.00
0005435626485	10999	Economy	3200.00
0005435127103	10999	Economy	3500.00
0005435127180	10999	Economy	3500.00
0005435127173	10999	Economy	3500.00
0005435127239	10999	Economy	3500.00
0005435126934	10999	Economy	3200.00
0005435127092	10999	Economy	3200.00
0005435554301	10999	Economy	3200.00
0005435127263	10999	Economy	3200.00
0005435127218	10999	Economy	3200.00
0005435626453	10999	Economy	3200.00
0005435554300	10999	Economy	3200.00
0005435127343	10999	Economy	3200.00
0005435127187	10999	Economy	3200.00
0005435127043	10999	Economy	3200.00
0005435127105	10999	Economy	3200.00
0005435127184	10999	Economy	3200.00
0005435626493	10999	Economy	3200.00
0005435626467	10999	Economy	3200.00
0005435127174	10999	Economy	3200.00
0005435127238	10999	Economy	3200.00
0005434411896	10999	Economy	3200.00
0005435127220	10999	Economy	3200.00
0005435554278	10999	Economy	3200.00
0005435127182	10999	Economy	3200.00
0005434928379	10999	Economy	3200.00
0005435127186	10999	Economy	3200.00
0005435127134	10999	Economy	3200.00
0005435127078	10999	Economy	3200.00
0005435127033	10999	Economy	3200.00
0005435127137	10999	Economy	3200.00
0005435127136	10999	Economy	3200.00
0005435126935	10999	Economy	3200.00
0005435554290	10999	Economy	3200.00
0005435127104	10999	Economy	3200.00
0005435126913	10999	Economy	3200.00
0005435127153	10999	Economy	3200.00
0005434411895	10999	Economy	3200.00
0005435126987	10999	Economy	3200.00
0005435127124	10999	Economy	3200.00
0005435127267	10999	Economy	3200.00
0005435127216	10999	Economy	3200.00
0005435127237	10999	Economy	3200.00
0005435626462	10999	Economy	3200.00
0005435126911	10999	Economy	3200.00
0005435127063	10999	Economy	3200.00
0005435626454	10999	Economy	3200.00
0005435556743	10999	Economy	3200.00
0005435127139	10999	Economy	3200.00
0005435127091	10999	Economy	3200.00
0005435127251	10999	Economy	3200.00
0005435127270	10999	Economy	3200.00
0005435554291	10999	Economy	3200.00
0005435127207	10999	Economy	3200.00
0005435127036	10999	Economy	3200.00
0005435127181	10999	Economy	3200.00
0005435127342	10999	Economy	3200.00
0005435127189	10999	Economy	3200.00
0005435127229	10999	Economy	3200.00
0005435126985	10999	Economy	3200.00
0005435626489	10999	Economy	3200.00
0005435127138	10999	Economy	3200.00
0005435127206	10999	Economy	3200.00
0005435127150	10999	Economy	3200.00
0005435127385	10999	Economy	3200.00
0005435626484	10999	Economy	3200.00
0005435126988	10999	Economy	3200.00
0005435127264	10999	Economy	3200.00
0005435127217	10999	Economy	3200.00
0005434411894	10999	Economy	3200.00
0005435554270	10999	Economy	3200.00
0005435626753	14677	Business	9500.00
0005435626742	14677	Business	9500.00
0005435127510	14677	Business	9500.00
0005435127511	14677	Business	9500.00
0005435127518	14677	Business	9500.00
0005435127522	14677	Business	9500.00
0005435626739	14677	Business	9500.00
0005435626740	14677	Economy	3200.00
0005435626750	14677	Economy	3200.00
0005435127513	14677	Economy	3200.00
0005434928367	14677	Economy	3200.00
0005435554319	14677	Economy	3200.00
0005435127519	14677	Economy	3200.00
0005435127512	14677	Economy	3200.00
0005435127516	14677	Economy	3200.00
0005435626731	14677	Economy	3200.00
0005435626741	14677	Economy	3500.00
0005435127514	14677	Economy	3500.00
0005435626749	14677	Economy	3500.00
0005434928368	14677	Economy	3500.00
0005435626737	14677	Economy	3500.00
0005435127507	14677	Economy	3200.00
0005435127504	14677	Economy	3200.00
0005435626746	14677	Economy	3200.00
0005435626765	14677	Economy	3200.00
0005435626743	14677	Economy	3200.00
0005435626733	14677	Economy	3200.00
0005435626760	14677	Economy	3200.00
0005435626729	14677	Economy	3200.00
0005435127508	14677	Economy	3200.00
0005435626726	14677	Economy	3200.00
0005435626744	14677	Economy	3200.00
0005435626736	14677	Economy	3200.00
0005435626752	14677	Economy	3200.00
0005435626763	14677	Economy	3200.00
0005435626725	14677	Economy	3200.00
0005435626761	14677	Economy	3200.00
0005435626766	14677	Economy	3200.00
0005435626764	14677	Economy	3200.00
0005434928366	14677	Economy	3200.00
0005435626734	14677	Economy	3200.00
0005435127505	14677	Economy	3200.00
0005435626767	14677	Economy	3200.00
0005434411854	14677	Economy	3200.00
0005435626735	14677	Economy	3200.00
0005435626732	14677	Economy	3200.00
0005435626738	14677	Economy	3200.00
0005435626745	14677	Economy	3200.00
0005435626727	14677	Economy	3200.00
0005435626747	14677	Economy	3200.00
0005435626762	14677	Economy	3200.00
0005435626755	14677	Economy	3200.00
0005435626754	14677	Economy	3200.00
0005435127502	14677	Economy	3200.00
0005435127509	14677	Economy	3200.00
0005435556763	14677	Economy	3200.00
0005435554318	14677	Economy	3200.00
0005435626730	14677	Economy	3200.00
0005435554317	14677	Economy	3200.00
0005435626758	14677	Economy	3200.00
0005435626728	14677	Economy	3200.00
0005435626756	14677	Economy	3200.00
0005435127506	14677	Economy	3200.00
0005435626759	14677	Economy	3200.00
0005435554316	14677	Economy	3200.00
0005435127523	14677	Economy	3200.00
0005435127521	14677	Economy	3200.00
0005435127515	14677	Economy	3200.00
0005435127520	14677	Economy	3200.00
0005435626748	14677	Economy	3200.00
0005435127503	14677	Economy	3200.00
0005435626757	14677	Economy	3200.00
0005435626751	14677	Economy	3200.00
0005435127517	14677	Economy	3200.00
0005435715948	7150	Business	86900.00
0005435221071	7150	Business	86900.00
0005435216625	7150	Business	86900.00
0005435443521	7150	Business	86900.00
0005435221075	7150	Economy	29000.00
0005435178517	7150	Economy	29000.00
0005435219239	7150	Economy	29000.00
0005432398298	7150	Economy	29000.00
0005435443499	7150	Economy	29000.00
0005432398297	7150	Economy	31900.00
0005435443519	7150	Economy	31900.00
0005435443520	7150	Economy	29000.00
0005435443498	7150	Economy	29000.00
0005435715954	7150	Economy	29000.00
0005435443483	7150	Economy	29000.00
0005435443480	7150	Economy	29000.00
0005435715952	7150	Economy	29000.00
0005432400220	7150	Economy	29000.00
0005435715953	7150	Economy	29000.00
0005435715950	7150	Economy	29000.00
0005435715946	7150	Economy	29000.00
0005432400221	7150	Economy	29000.00
0005432398299	7150	Economy	29000.00
0005435715951	7150	Economy	29000.00
0005435715949	7150	Economy	29000.00
0005435715955	7150	Economy	29000.00
0005435443537	7150	Economy	29000.00
0005435178523	7150	Economy	29000.00
0005435178522	7150	Economy	29000.00
0005435443518	7150	Economy	29000.00
0005435216626	7150	Economy	29000.00
0005435715947	7150	Economy	29000.00
0005435219238	7150	Economy	29000.00
0005435715945	7150	Economy	29000.00
0005435443507	7150	Economy	29000.00
0005435715837	27075	Business	86900.00
0005435715836	27075	Business	86900.00
0005435715752	27075	Business	86900.00
0005435715818	27075	Business	86900.00
0005435715817	27075	Business	86900.00
0005435715795	27075	Business	86900.00
0005435715803	27075	Economy	29000.00
0005435179020	27075	Economy	29000.00
0005435715843	27075	Economy	29000.00
0005432398259	27075	Economy	29000.00
0005435443578	27075	Economy	29000.00
0005432394161	27075	Economy	29000.00
0005435443579	27075	Economy	29000.00
0005435443576	27075	Economy	29000.00
0005435715811	27075	Economy	29000.00
0005435715784	27075	Economy	29000.00
0005435715800	27075	Economy	29000.00
0005435443575	27075	Economy	29000.00
0005435715751	27075	Economy	29000.00
0005435715840	27075	Economy	29000.00
0005435715838	27075	Economy	29000.00
0005435179019	27075	Economy	29000.00
0005435715766	27075	Economy	29000.00
0005435443580	27075	Economy	29000.00
0005435715827	27075	Economy	29000.00
0005435715828	27075	Economy	29000.00
0005435178538	27075	Economy	29000.00
0005435715848	27075	Economy	29000.00
0005435443577	27075	Economy	29000.00
0005435715816	27075	Economy	29000.00
0005435715753	27075	Economy	29000.00
0005432398258	27075	Economy	29000.00
0005432394160	27075	Economy	29000.00
0005435715849	27075	Economy	29000.00
0005435715856	27075	Economy	29000.00
0005435715785	27075	Economy	29000.00
0005435715750	27075	Economy	29000.00
0005435715829	27075	Economy	29000.00
0005434085061	2750	Economy	7700.00
0005433060464	2750	Economy	7700.00
0005434085060	2750	Economy	7700.00
0005433060472	2750	Economy	7700.00
0005434085059	2750	Economy	7700.00
0005433060477	2750	Economy	7700.00
0005433060473	2750	Economy	7700.00
0005433060488	28475	Economy	7700.00
0005434085023	28475	Economy	7700.00
0005433060489	28475	Economy	7700.00
0005434085047	28475	Economy	7700.00
0005434085017	28475	Economy	7700.00
0005432632929	25206	Economy	29000.00
0005435844380	25206	Economy	29000.00
0005432632909	25206	Economy	29000.00
0005432632914	25206	Economy	29000.00
0005432632927	25206	Economy	26400.00
0005435844375	25206	Economy	26400.00
0005435844363	25206	Economy	26400.00
0005435844381	25206	Economy	26400.00
0005432632922	25206	Economy	26400.00
0005435844383	25206	Economy	26400.00
0005435844392	25206	Economy	26400.00
0005432632911	25206	Economy	26400.00
0005435844362	25206	Economy	26400.00
0005432632930	25206	Economy	26400.00
0005432632924	25206	Economy	26400.00
0005432632903	25206	Economy	26400.00
0005435844385	25206	Economy	26400.00
0005432632918	25206	Economy	26400.00
0005432632905	25206	Economy	26400.00
0005432632921	25206	Economy	26400.00
0005435844391	25206	Economy	26400.00
0005435844376	25206	Economy	26400.00
0005432632904	25206	Economy	26400.00
0005432632920	25206	Economy	26400.00
0005432632917	25206	Economy	26400.00
0005435844382	25206	Economy	26400.00
0005435844377	25206	Economy	26400.00
0005432632923	25206	Economy	26400.00
0005432632926	25206	Economy	26400.00
0005432632919	25206	Economy	26400.00
0005432632907	25206	Economy	26400.00
0005432632928	25206	Economy	26400.00
0005435844370	25206	Economy	26400.00
0005432632925	25206	Economy	26400.00
0005432632910	25206	Economy	26400.00
0005435844374	25206	Economy	26400.00
0005432632913	25206	Economy	26400.00
0005432632912	25206	Economy	26400.00
0005435844379	25206	Economy	26400.00
0005432632916	25206	Economy	26400.00
0005432632915	25206	Economy	26400.00
0005435844369	25206	Economy	26400.00
0005432632906	25206	Economy	26400.00
0005432632908	25206	Economy	26400.00
0005435844433	28168	Economy	29000.00
0005435844435	28168	Economy	29000.00
0005432632858	28168	Economy	29000.00
0005432632850	28168	Economy	26400.00
0005432632869	28168	Economy	26400.00
0005432632860	28168	Economy	26400.00
0005432632812	28168	Economy	26400.00
0005432632833	28168	Economy	26400.00
0005432632844	28168	Economy	26400.00
0005435844428	28168	Economy	26400.00
0005432632870	28168	Economy	26400.00
0005432632838	28168	Economy	26400.00
0005432632839	28168	Economy	26400.00
0005432632855	28168	Economy	26400.00
0005435844432	28168	Economy	26400.00
0005432632847	28168	Economy	26400.00
0005432632843	28168	Economy	26400.00
0005435844425	28168	Economy	26400.00
0005432632842	28168	Economy	26400.00
0005432632879	28168	Economy	26400.00
0005432632902	28168	Economy	26400.00
0005432632851	28168	Economy	26400.00
0005435844420	28168	Economy	26400.00
0005435844430	28168	Economy	26400.00
0005432632840	28168	Economy	26400.00
0005432632871	28168	Economy	26400.00
0005432632880	28168	Economy	26400.00
0005432632854	28168	Economy	26400.00
0005435844426	28168	Economy	26400.00
0005435844421	28168	Economy	26400.00
0005435844424	28168	Economy	26400.00
0005432632859	28168	Economy	26400.00
0005432632846	28168	Economy	26400.00
0005432632856	28168	Economy	26400.00
0005435844431	28168	Economy	26400.00
0005432632864	28168	Economy	26400.00
0005435844427	28168	Economy	26400.00
0005435844434	28168	Economy	26400.00
0005432632872	28168	Economy	26400.00
0005432632853	28168	Economy	26400.00
0005432632832	28168	Economy	26400.00
0005435844422	28168	Economy	26400.00
0005435844423	28168	Economy	26400.00
0005435844429	28168	Economy	26400.00
0005432632862	28168	Economy	26400.00
0005432632852	28168	Economy	26400.00
0005435541452	11406	Business	20200.00
0005435518259	11406	Business	20200.00
0005435518304	11406	Business	20200.00
0005435518294	11406	Economy	6700.00
0005435518305	11406	Economy	6700.00
0005435541417	11406	Economy	7400.00
0005435541466	11406	Economy	7400.00
0005435518325	11406	Economy	7400.00
0005435541414	11406	Economy	6700.00
0005435518346	11406	Economy	6700.00
0005435518267	11406	Economy	6700.00
0005435541468	11406	Economy	6700.00
0005435541446	11406	Economy	6700.00
0005435541390	11406	Economy	6700.00
0005435518357	11406	Economy	6700.00
0005435541407	11406	Economy	6700.00
0005435518181	11406	Economy	6700.00
0005435541467	11406	Economy	6700.00
0005435518299	11406	Economy	6700.00
0005435541436	11406	Economy	6700.00
0005435541431	11406	Economy	6700.00
0005435541381	11406	Economy	6700.00
0005435541439	11406	Economy	6700.00
0005435518249	11406	Economy	6700.00
0005435518262	11406	Economy	6700.00
0005435541342	11406	Economy	6700.00
0005435518312	11406	Economy	6700.00
0005435541451	11406	Economy	6700.00
0005435518225	11406	Economy	6700.00
0005435541380	11406	Economy	6700.00
0005435541437	11406	Economy	6700.00
0005435518228	11406	Economy	6700.00
0005435518261	11406	Economy	6700.00
0005435541406	11406	Economy	6700.00
0005435518266	11406	Economy	6700.00
0005435518324	11406	Economy	6700.00
0005435518258	11406	Economy	6700.00
0005432294554	22221	Business	20200.00
0005435541600	22221	Business	20200.00
0005435541604	22221	Business	20200.00
0005435530153	22221	Business	20200.00
0005435529859	22221	Business	20200.00
0005435529849	22221	Business	20200.00
0005435530147	22221	Economy	6700.00
0005435529850	22221	Economy	6700.00
0005435541605	22221	Economy	6700.00
0005435541599	22221	Economy	6700.00
0005435529858	22221	Economy	6700.00
0005435541597	22221	Economy	6700.00
0005435530142	22221	Economy	7400.00
0005435541601	22221	Economy	6700.00
0005435541594	22221	Economy	6700.00
0005435529851	22221	Economy	6700.00
0005435530146	22221	Economy	6700.00
0005435529848	22221	Economy	6700.00
0005435541595	22221	Economy	6700.00
0005435541598	22221	Economy	6700.00
0005435530148	22221	Economy	6700.00
0005435530155	22221	Economy	6700.00
0005435530141	22221	Economy	6700.00
0005435530149	22221	Economy	6700.00
0005435530143	22221	Economy	6700.00
0005435529856	22221	Economy	6700.00
0005435541592	22221	Economy	6700.00
0005435530154	22221	Economy	6700.00
0005435530150	22221	Economy	6700.00
0005435530151	22221	Economy	6700.00
0005435530140	22221	Economy	6700.00
0005432294555	22221	Economy	6700.00
0005435541596	22221	Economy	6700.00
0005435530156	22221	Economy	6700.00
0005435530152	22221	Economy	6700.00
0005435541603	22221	Economy	6700.00
0005435529855	22221	Economy	6700.00
0005435529857	22221	Economy	6700.00
0005435529852	22221	Economy	6700.00
0005435530144	22221	Economy	6700.00
0005435541602	22221	Economy	6700.00
0005435529853	22221	Economy	6700.00
0005435529860	22221	Economy	6700.00
0005435530145	22221	Economy	6700.00
0005435529854	22221	Economy	6700.00
0005432294553	22221	Economy	6700.00
0005435541593	22221	Economy	6700.00
0005435529861	22221	Economy	6700.00
0005435529847	22221	Economy	6700.00
0005435529846	22221	Economy	6700.00
0005433252100	2304	Business	20200.00
0005434908792	2304	Business	20200.00
0005434908783	2304	Business	20200.00
0005433252058	2304	Business	20200.00
0005433252182	2304	Business	20200.00
0005433252093	2304	Business	20200.00
0005433252098	2304	Business	20200.00
0005433252102	2304	Business	20200.00
0005434908807	2304	Business	20200.00
0005434908780	2304	Business	20200.00
0005433252128	2304	Business	20200.00
0005433252136	2304	Economy	6700.00
0005433252009	2304	Economy	6700.00
0005434908790	2304	Economy	6700.00
0005434908798	2304	Economy	6700.00
0005435787467	2304	Economy	6700.00
0005433252069	2304	Economy	6700.00
0005434908803	2304	Economy	6700.00
0005435787468	2304	Economy	6700.00
0005434908793	2304	Economy	6700.00
0005433252103	2304	Economy	7400.00
0005433252255	2304	Economy	7400.00
0005434908806	2304	Economy	7400.00
0005433252127	2304	Economy	7400.00
0005434908786	2304	Economy	6700.00
0005434908795	2304	Economy	6700.00
0005434908784	2304	Economy	6700.00
0005433252010	2304	Economy	6700.00
0005434908796	2304	Economy	6700.00
0005433401055	2304	Economy	6700.00
0005434908817	2304	Economy	6700.00
0005433252109	2304	Economy	6700.00
0005434908802	2304	Economy	6700.00
0005433252146	2304	Economy	6700.00
0005433252106	2304	Economy	6700.00
0005434908787	2304	Economy	6700.00
0005433252120	2304	Economy	6700.00
0005434908801	2304	Economy	6700.00
0005434908819	2304	Economy	6700.00
0005434908785	2304	Economy	6700.00
0005433252108	2304	Economy	6700.00
0005433252078	2304	Economy	6700.00
0005434908788	2304	Economy	6700.00
0005433252030	2304	Economy	6700.00
0005434908799	2304	Economy	6700.00
0005434908815	2304	Economy	6700.00
0005434908811	2304	Economy	6700.00
0005435787465	2304	Economy	6700.00
0005434908816	2304	Economy	6700.00
0005434908810	2304	Economy	6700.00
0005433252095	2304	Economy	6700.00
0005434908797	2304	Economy	6700.00
0005433252094	2304	Economy	6700.00
0005433252147	2304	Economy	6700.00
0005433252031	2304	Economy	6700.00
0005434908805	2304	Economy	6700.00
0005434908809	2304	Economy	6700.00
0005434908818	2304	Economy	6700.00
0005433252126	2304	Economy	6700.00
0005435787466	2304	Economy	6700.00
0005433252130	2304	Economy	6700.00
0005434908782	2304	Economy	6700.00
0005433252139	2304	Economy	6700.00
0005434908800	2304	Economy	6700.00
0005433252176	2304	Economy	6700.00
0005433252068	2304	Economy	6700.00
0005433252107	2304	Economy	6700.00
0005434908781	2304	Economy	6700.00
0005433252280	2304	Economy	6700.00
0005434908791	2304	Economy	6700.00
0005433252138	2304	Economy	6700.00
0005433252101	2304	Economy	6700.00
0005434908813	2304	Economy	6700.00
0005433252135	2304	Economy	6700.00
0005434908794	2304	Economy	6700.00
0005434908808	2304	Economy	6700.00
0005434908812	2304	Economy	6700.00
0005433252114	2304	Economy	6700.00
0005433252099	2304	Economy	6700.00
0005434908789	2304	Economy	6700.00
0005434908804	2304	Economy	6700.00
0005433252067	2304	Economy	6700.00
0005433252073	2304	Economy	6700.00
0005434908814	2304	Economy	6700.00
0005433252169	2304	Economy	6700.00
0005433252331	25616	Business	20200.00
0005434908376	25616	Business	20200.00
0005434908344	25616	Business	20200.00
0005434908334	25616	Business	20200.00
0005434908563	25616	Business	20200.00
0005434908324	25616	Business	20200.00
0005433252344	25616	Business	20200.00
0005434908224	25616	Business	20200.00
0005433252342	25616	Economy	6700.00
0005434908313	25616	Economy	6700.00
0005434908188	25616	Economy	6700.00
0005434908433	25616	Economy	6700.00
0005434908211	25616	Economy	6700.00
0005434908429	25616	Economy	6700.00
0005434908217	25616	Economy	7400.00
0005433252336	25616	Economy	7400.00
0005434908078	25616	Economy	7400.00
0005434908189	25616	Economy	7400.00
0005434908228	25616	Economy	6700.00
0005434908333	25616	Economy	6700.00
0005433252332	25616	Economy	6700.00
0005434908403	25616	Economy	6700.00
0005434908336	25616	Economy	6700.00
0005433252333	25616	Economy	6700.00
0005434907987	25616	Economy	6700.00
0005434908227	25616	Economy	6700.00
0005434908564	25616	Economy	6700.00
0005433252334	25616	Economy	6700.00
0005434908355	25616	Economy	6700.00
0005434908226	25616	Economy	6700.00
0005434908132	25616	Economy	6700.00
0005433252338	25616	Economy	6700.00
0005433252335	25616	Economy	6700.00
0005434908431	25616	Economy	6700.00
0005434908208	25616	Economy	6700.00
0005434908356	25616	Economy	6700.00
0005434908436	25616	Economy	6700.00
0005434908281	25616	Economy	6700.00
0005434908416	25616	Economy	6700.00
0005434908225	25616	Economy	6700.00
0005434908282	25616	Economy	6700.00
0005434908364	25616	Economy	6700.00
0005433252339	25616	Economy	6700.00
0005434908536	25616	Economy	6700.00
0005433252337	25616	Economy	6700.00
0005434908511	25616	Economy	6700.00
0005433252330	25616	Economy	6700.00
0005434908190	25616	Economy	6700.00
0005434908385	25616	Economy	6700.00
0005434908566	25616	Economy	6700.00
0005433401069	25616	Economy	6700.00
0005434908464	25616	Economy	6700.00
0005434908317	25616	Economy	6700.00
0005433252340	25616	Economy	6700.00
0005434908306	25616	Economy	6700.00
0005434908369	25616	Economy	6700.00
0005434908118	25616	Economy	6700.00
0005434908174	25616	Economy	6700.00
0005434908353	25616	Economy	6700.00
0005433401068	25616	Economy	6700.00
0005433252343	25616	Economy	6700.00
0005434908384	25616	Economy	6700.00
0005434908088	25616	Economy	6700.00
0005434908121	25616	Economy	6700.00
0005434908307	25616	Economy	6700.00
0005434908229	25616	Economy	6700.00
0005433252341	25616	Economy	6700.00
0005434908212	25616	Economy	6700.00
0005434908375	25616	Economy	6700.00
0005434908414	25616	Economy	6700.00
0005434908089	25616	Economy	6700.00
0005432862496	2550	Economy	13600.00
0005432621434	2550	Economy	12400.00
0005432621439	2550	Economy	12400.00
0005432862491	2550	Economy	12400.00
0005432862458	2550	Economy	12400.00
0005432621441	2550	Economy	12400.00
0005432862459	2550	Economy	12400.00
0005432862492	2550	Economy	12400.00
0005432621437	2550	Economy	12400.00
0005432621438	2550	Economy	12400.00
0005432621433	2550	Economy	12400.00
0005432862490	2550	Economy	12400.00
0005432621436	2550	Economy	12400.00
0005432621440	2550	Economy	12400.00
0005432621435	2550	Economy	12400.00
0005432862476	2550	Economy	12400.00
0005432862442	2550	Economy	12400.00
0005432621319	28049	Economy	13600.00
0005432862520	28049	Economy	12400.00
0005432621325	28049	Economy	12400.00
0005432621329	28049	Economy	12400.00
0005432621334	28049	Economy	12400.00
0005432862519	28049	Economy	12400.00
0005432621314	28049	Economy	12400.00
0005432621315	28049	Economy	12400.00
0005432621297	28049	Economy	12400.00
0005432621332	28049	Economy	12400.00
0005432621333	28049	Economy	12400.00
0005432621296	28049	Economy	12400.00
0005432621316	28049	Economy	12400.00
0005432621338	28049	Economy	12400.00
0005432621326	28049	Economy	12400.00
0005434097511	13095	Economy	11300.00
0005434097512	13095	Economy	11300.00
0005433451675	31091	Economy	8400.00
0005433452794	31091	Economy	8400.00
0005433451674	31091	Economy	8400.00
0005433454912	31395	Economy	8400.00
0005433454916	31395	Economy	8400.00
0005434184712	12019	Economy	7200.00
0005433134219	12019	Economy	7200.00
0005434184706	12019	Economy	7200.00
0005433134216	12019	Economy	6600.00
0005433134229	12019	Economy	6600.00
0005434326089	12019	Economy	6600.00
0005433134237	12019	Economy	6600.00
0005434184703	12019	Economy	6600.00
0005433129378	12019	Economy	6600.00
0005433129379	12019	Economy	6600.00
0005434184704	12019	Economy	6600.00
0005433134228	12019	Economy	6600.00
0005434142701	12019	Economy	6600.00
0005433134215	12019	Economy	6600.00
0005434184711	12019	Economy	6600.00
0005434184705	12019	Economy	6600.00
0005433134218	12019	Economy	6600.00
0005434184710	12019	Economy	6600.00
0005434142700	12019	Economy	6600.00
0005433129371	12019	Economy	6600.00
0005433134227	12019	Economy	6600.00
0005433134220	12019	Economy	6600.00
0005433134217	12019	Economy	6600.00
0005433134260	29818	Economy	7200.00
0005433131833	29818	Economy	7200.00
0005434184723	29818	Economy	6600.00
0005433134259	29818	Economy	6600.00
0005433131832	29818	Economy	6600.00
0005434142721	29818	Economy	6600.00
0005433131835	29818	Economy	6600.00
0005434142722	29818	Economy	6600.00
0005434142719	29818	Economy	6600.00
0005434142720	29818	Economy	6600.00
0005433131834	29818	Economy	6600.00
0005434184724	29818	Economy	6600.00
0005435698113	16444	Economy	19900.00
0005435698120	16444	Economy	19900.00
0005435698105	16444	Economy	19900.00
0005435698104	16444	Economy	19900.00
0005435935107	16444	Economy	18100.00
0005435698124	16444	Economy	18100.00
0005435698102	16444	Economy	18100.00
0005435698117	16444	Economy	18100.00
0005435698106	16444	Economy	18100.00
0005435698110	16444	Economy	18100.00
0005435698112	16444	Economy	18100.00
0005435698123	16444	Economy	18100.00
0005435698108	16444	Economy	18100.00
0005435698107	16444	Economy	18100.00
0005435935106	16444	Economy	18100.00
0005435698109	16444	Economy	18100.00
0005435698121	16444	Economy	18100.00
0005435698100	16444	Economy	18100.00
0005435698114	16444	Economy	18100.00
0005435698118	16444	Economy	18100.00
0005435698111	16444	Economy	18100.00
0005435698115	16444	Economy	18100.00
0005435698103	16444	Economy	18100.00
0005435698101	16444	Economy	18100.00
0005435935097	16444	Economy	18100.00
0005435698122	16444	Economy	18100.00
0005435698119	16444	Economy	18100.00
0005435935096	16444	Economy	18100.00
0005435935101	16444	Economy	18100.00
0005435698116	16444	Economy	18100.00
0005435935102	16444	Economy	18100.00
0005435698125	16444	Economy	18100.00
0005435697913	24736	Economy	19900.00
0005435697931	24736	Economy	19900.00
0005435697841	24736	Economy	19900.00
0005435698017	24736	Economy	18100.00
0005435697840	24736	Economy	18100.00
0005435697882	24736	Economy	18100.00
0005435697981	24736	Economy	18100.00
0005435697856	24736	Economy	18100.00
0005435697843	24736	Economy	18100.00
0005435935132	24736	Economy	18100.00
0005435697872	24736	Economy	18100.00
0005435697929	24736	Economy	18100.00
0005435697903	24736	Economy	18100.00
0005435697996	24736	Economy	18100.00
0005435697928	24736	Economy	18100.00
0005435697871	24736	Economy	18100.00
0005435697802	24736	Economy	18100.00
0005435698014	24736	Economy	18100.00
0005435697957	24736	Economy	18100.00
0005435697958	24736	Economy	18100.00
0005435697977	24736	Economy	18100.00
0005435697874	24736	Economy	18100.00
0005435697904	24736	Economy	18100.00
0005435697829	24736	Economy	18100.00
0005435698005	24736	Economy	18100.00
0005435697945	24736	Economy	18100.00
0005435935133	24736	Economy	18100.00
0005435697955	24736	Economy	18100.00
0005435697873	24736	Economy	18100.00
0005435697792	24736	Economy	18100.00
0005435697912	24736	Economy	18100.00
0005435697923	24736	Economy	18100.00
0005435697954	24736	Economy	18100.00
0005433724931	18765	Economy	4400.00
0005432968882	18765	Economy	4400.00
0005433724930	18765	Economy	4400.00
0005432968890	18765	Economy	4400.00
0005433724929	18765	Economy	4400.00
0005432968881	18765	Economy	4400.00
0005433724928	18765	Economy	4400.00
0005433724911	21634	Economy	4400.00
0005433724909	21634	Economy	4400.00
0005433724892	21634	Economy	4400.00
0005432968905	21634	Economy	4400.00
0005432968907	21634	Economy	4400.00
0005432968906	21634	Economy	4400.00
0005433724910	21634	Economy	4400.00
0005434140454	7330	Business	23100.00
0005434140466	7330	Business	23100.00
0005434140456	7330	Business	23100.00
0005434140460	7330	Business	23100.00
0005434140470	7330	Business	23100.00
0005434140461	7330	Business	23100.00
0005434140484	7330	Economy	7700.00
0005434140494	7330	Economy	7700.00
0005434140468	7330	Economy	7700.00
0005434140481	7330	Economy	7700.00
0005435283559	7330	Economy	7700.00
0005434140479	7330	Economy	8500.00
0005435283560	7330	Economy	8500.00
0005434140480	7330	Economy	8500.00
0005434087649	7330	Economy	7700.00
0005434140463	7330	Economy	7700.00
0005434140496	7330	Economy	7700.00
0005434140489	7330	Economy	7700.00
0005434140487	7330	Economy	7700.00
0005434140493	7330	Economy	7700.00
0005434140459	7330	Economy	7700.00
0005434140465	7330	Economy	7700.00
0005434140467	7330	Economy	7700.00
0005434140490	7330	Economy	7700.00
0005434140469	7330	Economy	7700.00
0005434140491	7330	Economy	7700.00
0005434140473	7330	Economy	7700.00
0005434140453	7330	Economy	7700.00
0005434140482	7330	Economy	7700.00
0005434140488	7330	Economy	7700.00
0005435283568	7330	Economy	7700.00
0005434087648	7330	Economy	7700.00
0005434087650	7330	Economy	7700.00
0005434140483	7330	Economy	7700.00
0005434140474	7330	Economy	7700.00
0005434140492	7330	Economy	7700.00
0005434140462	7330	Economy	7700.00
0005434140477	7330	Economy	7700.00
0005434140475	7330	Economy	7700.00
0005434140471	7330	Economy	7700.00
0005434140495	7330	Economy	7700.00
0005434140457	7330	Economy	7700.00
0005434140455	7330	Economy	7700.00
0005434140500	7330	Economy	7700.00
0005434140497	7330	Economy	7700.00
0005434140498	7330	Economy	7700.00
0005434140486	7330	Economy	7700.00
0005434140458	7330	Economy	7700.00
0005434140464	7330	Economy	7700.00
0005434140478	7330	Economy	7700.00
0005434140472	7330	Economy	7700.00
0005434140499	7330	Economy	7700.00
0005434140485	7330	Economy	7700.00
0005434140476	7330	Economy	7700.00
0005434139856	28576	Business	23100.00
0005434139569	28576	Business	23100.00
0005434139915	28576	Business	23100.00
0005434139575	28576	Business	23100.00
0005434139647	28576	Business	23100.00
0005434139515	28576	Business	23100.00
0005434139751	28576	Business	23100.00
0005434140086	28576	Business	23100.00
0005434139746	28576	Business	23100.00
0005434139644	28576	Business	23100.00
0005434139758	28576	Business	23100.00
0005434139504	28576	Economy	7700.00
0005434139835	28576	Economy	7700.00
0005434139842	28576	Economy	7700.00
0005434139652	28576	Economy	7700.00
0005434139386	28576	Economy	7700.00
0005434139673	28576	Economy	7700.00
0005434139725	28576	Economy	7700.00
0005434139820	28576	Economy	7700.00
0005434139749	28576	Economy	7700.00
0005434087618	28576	Economy	7700.00
0005434139256	28576	Economy	8500.00
0005434139474	28576	Economy	8500.00
0005435283564	28576	Economy	8500.00
0005434139721	28576	Economy	8500.00
0005434139535	28576	Economy	8500.00
0005434139983	28576	Economy	7700.00
0005434139923	28576	Economy	7700.00
0005434139863	28576	Economy	7700.00
0005434139642	28576	Economy	7700.00
0005434139906	28576	Economy	7700.00
0005434139752	28576	Economy	7700.00
0005434139692	28576	Economy	7700.00
0005434139587	28576	Economy	7700.00
0005434139888	28576	Economy	7700.00
0005434139288	28576	Economy	7700.00
0005434139788	28576	Economy	7700.00
0005434139716	28576	Economy	7700.00
0005434140178	28576	Economy	7700.00
0005434139776	28576	Economy	7700.00
0005434139693	28576	Economy	7700.00
0005434087622	28576	Economy	7700.00
0005434139775	28576	Economy	7700.00
0005434139916	28576	Economy	7700.00
0005434139717	28576	Economy	7700.00
0005434139700	28576	Economy	7700.00
0005434140270	28576	Economy	7700.00
0005434139724	28576	Economy	7700.00
0005434139659	28576	Economy	7700.00
0005434139645	28576	Economy	7700.00
0005434139720	28576	Economy	7700.00
0005434139630	28576	Economy	7700.00
0005434139667	28576	Economy	7700.00
0005435283569	28576	Economy	7700.00
0005434139567	28576	Economy	7700.00
0005434139921	28576	Economy	7700.00
0005435283561	28576	Economy	7700.00
0005434139713	28576	Economy	7700.00
0005434139464	28576	Economy	7700.00
0005434139624	28576	Economy	7700.00
0005434139926	28576	Economy	7700.00
0005434139732	28576	Economy	7700.00
0005434139358	28576	Economy	7700.00
0005434139754	28576	Economy	7700.00
0005434139641	28576	Economy	7700.00
0005434139933	28576	Economy	7700.00
0005434139918	28576	Economy	7700.00
0005434139924	28576	Economy	7700.00
0005434139768	28576	Economy	7700.00
0005434139723	28576	Economy	7700.00
0005434087621	28576	Economy	7700.00
0005434139930	28576	Economy	7700.00
0005435283563	28576	Economy	7700.00
0005434139843	28576	Economy	7700.00
0005434139701	28576	Economy	7700.00
0005434139588	28576	Economy	7700.00
0005434139753	28576	Economy	7700.00
0005434139951	28576	Economy	7700.00
0005435283570	28576	Economy	7700.00
0005434139791	28576	Economy	7700.00
0005434139574	28576	Economy	7700.00
0005434139568	28576	Economy	7700.00
0005434139303	28576	Economy	7700.00
0005434139890	28576	Economy	7700.00
0005434139629	28576	Economy	7700.00
0005434139889	28576	Economy	7700.00
0005434139648	28576	Economy	7700.00
0005434139722	28576	Economy	7700.00
0005434139699	28576	Economy	7700.00
0005435283562	28576	Economy	7700.00
0005434139586	28576	Economy	7700.00
0005433407681	1906	Economy	21700.00
0005435808515	1906	Economy	21700.00
0005435808517	1906	Economy	21700.00
0005433407671	1906	Economy	21700.00
0005435808518	1906	Economy	21700.00
0005433407653	1906	Economy	21700.00
0005433407672	1906	Economy	21700.00
0005435808512	1906	Economy	21700.00
0005435808513	1906	Economy	21700.00
0005435808516	1906	Economy	21700.00
0005433407661	1906	Economy	21700.00
0005433407654	1906	Economy	21700.00
0005433407679	1906	Economy	21700.00
0005433407678	1906	Economy	21700.00
0005433407662	1906	Economy	21700.00
0005433407676	1906	Economy	21700.00
0005433407667	1906	Economy	21700.00
0005433407680	1906	Economy	21700.00
0005435808514	1906	Economy	21700.00
0005433407702	23117	Economy	23900.00
0005435808398	23117	Economy	23900.00
0005433407701	23117	Economy	21700.00
0005433407704	23117	Economy	21700.00
0005434610301	23117	Economy	21700.00
0005435808408	23117	Economy	21700.00
0005435808401	23117	Economy	21700.00
0005433407706	23117	Economy	21700.00
0005433407703	23117	Economy	21700.00
0005435808427	23117	Economy	21700.00
0005435808415	23117	Economy	21700.00
0005434610308	23117	Economy	21700.00
0005435808439	23117	Economy	21700.00
0005435808417	23117	Economy	21700.00
0005435808393	23117	Economy	21700.00
0005433407705	23117	Economy	21700.00
0005435808361	23117	Economy	21700.00
0005435808409	23117	Economy	21700.00
0005435808399	23117	Economy	21700.00
0005435808404	23117	Economy	21700.00
0005435808407	23117	Economy	21700.00
0005435808426	23117	Economy	21700.00
0005434610288	23117	Economy	21700.00
0005434610310	23117	Economy	21700.00
0005435808400	23117	Economy	21700.00
0005435808416	23117	Economy	21700.00
0005434610285	23117	Economy	21700.00
0005434610287	23117	Economy	21700.00
0005435808402	23117	Economy	21700.00
0005435808440	23117	Economy	21700.00
0005434610309	23117	Economy	21700.00
0005434610297	23117	Economy	21700.00
0005434505041	16699	Economy	7600.00
0005434504765	16699	Economy	7600.00
0005434504944	16699	Economy	6900.00
0005434504814	16699	Economy	6900.00
0005434505158	16699	Economy	6900.00
0005434504913	16699	Economy	6900.00
0005434504871	16699	Economy	6900.00
0005434504800	16699	Economy	6900.00
0005434504933	16699	Economy	6900.00
0005434505028	16699	Economy	6900.00
0005434505040	16699	Economy	6900.00
0005434504806	16699	Economy	6900.00
0005434504878	16699	Economy	6900.00
0005434504870	16699	Economy	6900.00
0005434504884	16699	Economy	6900.00
0005434505027	16699	Economy	6900.00
0005434504964	16699	Economy	6900.00
0005434504911	16699	Economy	6900.00
0005434504815	16699	Economy	6900.00
0005434504921	16699	Economy	6900.00
0005434504910	16699	Economy	6900.00
0005434505109	16699	Economy	6900.00
0005434504803	16699	Economy	6900.00
0005434504930	16699	Economy	6900.00
0005434504799	16699	Economy	6900.00
0005434504990	16699	Economy	6900.00
0005434504722	16699	Economy	6900.00
0005434504903	16699	Economy	6900.00
0005434504885	16699	Economy	6900.00
0005434504805	16699	Economy	6900.00
0005434504954	16699	Economy	6900.00
0005434504804	16699	Economy	6900.00
0005434504953	16699	Economy	6900.00
0005434504796	16699	Economy	6900.00
0005434504894	16699	Economy	6900.00
0005434504879	16699	Economy	6900.00
0005434505235	22887	Economy	7600.00
0005434505234	22887	Economy	7600.00
0005434505228	22887	Economy	7600.00
0005434505230	22887	Economy	6900.00
0005434505240	22887	Economy	6900.00
0005434505231	22887	Economy	6900.00
0005434505237	22887	Economy	6900.00
0005434505244	22887	Economy	6900.00
0005434505226	22887	Economy	6900.00
0005434505233	22887	Economy	6900.00
0005434505238	22887	Economy	6900.00
0005434505246	22887	Economy	6900.00
0005434505227	22887	Economy	6900.00
0005434505239	22887	Economy	6900.00
0005434505245	22887	Economy	6900.00
0005434505241	22887	Economy	6900.00
0005434505242	22887	Economy	6900.00
0005434505225	22887	Economy	6900.00
0005434505243	22887	Economy	6900.00
0005434505232	22887	Economy	6900.00
0005434505224	22887	Economy	6900.00
0005434505223	22887	Economy	6900.00
0005434505229	22887	Economy	6900.00
0005434505236	22887	Economy	6900.00
0005433266906	2228	Economy	7700.00
0005433266892	2228	Economy	7700.00
0005433266890	2228	Economy	7000.00
0005435078769	2228	Economy	7000.00
0005435078772	2228	Economy	7000.00
0005435078768	2228	Economy	7000.00
0005435078767	2228	Economy	7000.00
0005433266905	2228	Economy	7000.00
0005435078770	2228	Economy	7000.00
0005435078773	2228	Economy	7000.00
0005433266910	2228	Economy	7000.00
0005433266891	2228	Economy	7000.00
0005435078771	2228	Economy	7000.00
0005435078774	2228	Economy	7000.00
0005433266896	2228	Economy	7000.00
0005433266984	24379	Economy	7700.00
0005435078621	24379	Economy	7700.00
0005435078672	24379	Economy	7000.00
0005435078561	24379	Economy	7000.00
0005435078680	24379	Economy	7000.00
0005435078562	24379	Economy	7000.00
0005435078678	24379	Economy	7000.00
0005435078619	24379	Economy	7000.00
0005433266981	24379	Economy	7000.00
0005435078677	24379	Economy	7000.00
0005433266982	24379	Economy	7000.00
0005435078647	24379	Economy	7000.00
0005435078648	24379	Economy	7000.00
0005435078673	24379	Economy	7000.00
0005435078716	24379	Economy	7000.00
0005435078681	24379	Economy	7000.00
0005435078679	24379	Economy	7000.00
0005435078642	24379	Economy	7000.00
0005433266983	24379	Economy	7000.00
0005434989075	6640	Economy	10800.00
0005434989065	6640	Economy	9800.00
0005434989077	6640	Economy	9800.00
0005434989074	6640	Economy	9800.00
0005434989061	6640	Economy	9800.00
0005434989066	6640	Economy	9800.00
0005434989063	6640	Economy	9800.00
0005435803348	6640	Economy	9800.00
0005435803347	6640	Economy	9800.00
0005435803346	6640	Economy	9800.00
0005434989073	6640	Economy	9800.00
0005434989071	6640	Economy	9800.00
0005434989060	6640	Economy	9800.00
0005434989062	6640	Economy	9800.00
0005434989068	6640	Economy	9800.00
0005434989072	6640	Economy	9800.00
0005434989064	6640	Economy	9800.00
0005434989076	6640	Economy	9800.00
0005434989070	6640	Economy	9800.00
0005434989069	6640	Economy	9800.00
0005434989067	6640	Economy	9800.00
0005434988898	23607	Economy	9800.00
0005434988935	23607	Economy	9800.00
0005435803323	23607	Economy	9800.00
0005435803316	23607	Economy	9800.00
0005434988922	23607	Economy	9800.00
0005435803329	23607	Economy	9800.00
0005434988921	23607	Economy	9800.00
0005434988913	23607	Economy	9800.00
0005435464563	23607	Economy	9800.00
0005434988937	23607	Economy	9800.00
0005434988934	23607	Economy	9800.00
0005435464564	23607	Economy	9800.00
0005435803314	23607	Economy	9800.00
0005434988933	23607	Economy	9800.00
0005434988915	23607	Economy	9800.00
0005435803320	23607	Economy	9800.00
0005434988897	23607	Economy	9800.00
0005434988929	23607	Economy	9800.00
0005434988904	23607	Economy	9800.00
0005433450586	30492	Business	9900.00
0005432384291	30492	Business	9900.00
0005433450578	30492	Business	9900.00
0005432384284	30492	Economy	3300.00
0005432384289	30492	Economy	3300.00
0005433450574	30492	Economy	3300.00
0005432384285	30492	Economy	3600.00
0005433450581	30492	Economy	3600.00
0005432384281	30492	Economy	3300.00
0005432384269	30492	Economy	3300.00
0005432384275	30492	Economy	3300.00
0005433450580	30492	Economy	3300.00
0005433450585	30492	Economy	3300.00
0005433450579	30492	Economy	3300.00
0005432384272	30492	Economy	3300.00
0005432384286	30492	Economy	3300.00
0005432384278	30492	Economy	3300.00
0005432384287	30492	Economy	3300.00
0005432384270	30492	Economy	3300.00
0005433450577	30492	Economy	3300.00
0005432384292	30492	Economy	3300.00
0005432384283	30492	Economy	3300.00
0005432384273	30492	Economy	3300.00
0005433450576	30492	Economy	3300.00
0005433450583	30492	Economy	3300.00
0005432384290	30492	Economy	3300.00
0005432384279	30492	Economy	3300.00
0005432384282	30492	Economy	3300.00
0005432384271	30492	Economy	3300.00
0005432384277	30492	Economy	3300.00
0005433450582	30492	Economy	3300.00
0005432384280	30492	Economy	3300.00
0005432384288	30492	Economy	3300.00
0005432384274	30492	Economy	3300.00
0005433454932	30492	Economy	3300.00
0005433453819	30492	Economy	3300.00
0005433450584	30492	Economy	3300.00
0005433450575	30492	Economy	3300.00
0005432384276	30492	Economy	3300.00
0005433451660	31331	Business	9900.00
0005432383950	31331	Business	9900.00
0005433450371	31331	Business	9900.00
0005433451659	31331	Business	9900.00
0005432383879	31331	Business	9900.00
0005432384040	31331	Business	9900.00
0005432383857	31331	Business	9900.00
0005433450408	31331	Business	9900.00
0005432383939	31331	Economy	3300.00
0005432383905	31331	Economy	3300.00
0005432383885	31331	Economy	3300.00
0005432383861	31331	Economy	3300.00
0005432384023	31331	Economy	3300.00
0005432383661	31331	Economy	3300.00
0005432384024	31331	Economy	3600.00
0005432383940	31331	Economy	3600.00
0005433450447	31331	Economy	3600.00
0005432383900	31331	Economy	3600.00
0005433450422	31331	Economy	3300.00
0005433453805	31331	Economy	3300.00
0005432383904	31331	Economy	3300.00
0005432383843	31331	Economy	3300.00
0005432383851	31331	Economy	3300.00
0005432383860	31331	Economy	3300.00
0005432383864	31331	Economy	3300.00
0005432383874	31331	Economy	3300.00
0005433450421	31331	Economy	3300.00
0005433450473	31331	Economy	3300.00
0005433450474	31331	Economy	3300.00
0005433450398	31331	Economy	3300.00
0005433453797	31331	Economy	3300.00
0005433450399	31331	Economy	3300.00
0005432383795	31331	Economy	3300.00
0005433450390	31331	Economy	3300.00
0005432383873	31331	Economy	3300.00
0005432383970	31331	Economy	3300.00
0005432383821	31331	Economy	3300.00
0005432383662	31331	Economy	3300.00
0005432383981	31331	Economy	3300.00
0005433450370	31331	Economy	3300.00
0005433450451	31331	Economy	3300.00
0005432383980	31331	Economy	3300.00
0005432383856	31331	Economy	3300.00
0005432384056	31331	Economy	3300.00
0005433450376	31331	Economy	3300.00
0005432383663	31331	Economy	3300.00
0005433450327	31331	Economy	3300.00
0005432383867	31331	Economy	3300.00
0005432383908	31331	Economy	3300.00
0005433450407	31331	Economy	3300.00
0005432383948	31331	Economy	3300.00
0005432384022	31331	Economy	3300.00
0005432383949	31331	Economy	3300.00
0005432383880	31331	Economy	3300.00
0005432383850	31331	Economy	3300.00
0005432383911	31331	Economy	3300.00
0005433450328	31331	Economy	3300.00
0005433450452	31331	Economy	3300.00
0005433453806	31331	Economy	3300.00
0005432383792	31331	Economy	3300.00
0005432384039	31331	Economy	3300.00
0005432383871	31331	Economy	3300.00
0005432383844	31331	Economy	3300.00
0005432383912	31331	Economy	3300.00
0005432383685	31331	Economy	3300.00
0005433450412	31331	Economy	3300.00
0005432383907	31331	Economy	3300.00
0005432384028	31331	Economy	3300.00
0005432383863	31331	Economy	3300.00
0005432383872	31331	Economy	3300.00
0005432383922	31331	Economy	3300.00
0005433450377	31331	Economy	3300.00
0005435299868	10787	Economy	17100.00
0005433126948	10787	Economy	15600.00
0005433131794	10787	Economy	15600.00
0005435299873	10787	Economy	15600.00
0005433131793	10787	Economy	15600.00
0005435299850	10787	Economy	15600.00
0005433131785	10787	Economy	15600.00
0005435304247	10787	Economy	15600.00
0005435304246	10787	Economy	15600.00
0005433131792	10787	Economy	15600.00
0005433126947	10787	Economy	15600.00
0005435299874	10787	Economy	15600.00
0005433131788	10787	Economy	15600.00
0005433131808	10787	Economy	15600.00
0005433126974	29691	Economy	17100.00
0005435299917	29691	Economy	15600.00
0005433129407	29691	Economy	15600.00
0005435302335	29691	Economy	15600.00
0005433129408	29691	Economy	15600.00
0005435299915	29691	Economy	15600.00
0005433129409	29691	Economy	15600.00
0005435299913	29691	Economy	15600.00
0005435299914	29691	Economy	15600.00
0005433126975	29691	Economy	15600.00
0005435299916	29691	Economy	15600.00
0005434287905	2384	Economy	15700.00
0005434287904	2384	Economy	15700.00
0005433110325	2384	Economy	15700.00
0005434287908	2384	Economy	15700.00
0005433110293	2384	Economy	15700.00
0005433110295	2384	Economy	15700.00
0005434287906	2384	Economy	15700.00
0005434287907	2384	Economy	15700.00
0005433110326	2384	Economy	15700.00
0005434287912	2384	Economy	15700.00
0005432264546	2384	Economy	15700.00
0005432264547	2384	Economy	15700.00
0005433110296	2384	Economy	15700.00
0005434287913	2384	Economy	15700.00
0005434287910	2384	Economy	15700.00
0005433110258	2384	Economy	15700.00
0005434287915	2384	Economy	15700.00
0005434287911	2384	Economy	15700.00
0005434287909	2384	Economy	15700.00
0005434287914	2384	Economy	15700.00
0005434287666	26876	Economy	17200.00
0005434287712	26876	Economy	17200.00
0005434287760	26876	Economy	17200.00
0005434287711	26876	Economy	15700.00
0005434287726	26876	Economy	15700.00
0005434287727	26876	Economy	15700.00
0005434287734	26876	Economy	15700.00
0005434287774	26876	Economy	15700.00
0005434287735	26876	Economy	15700.00
0005434287732	26876	Economy	15700.00
0005434287759	26876	Economy	15700.00
0005434287702	26876	Economy	15700.00
0005433110383	26876	Economy	15700.00
0005434287731	26876	Economy	15700.00
0005434287790	26876	Economy	15700.00
0005433110384	26876	Economy	15700.00
0005434287724	26876	Economy	15700.00
0005433110386	26876	Economy	15700.00
0005434287654	26876	Economy	15700.00
0005434287717	26876	Economy	15700.00
0005434287701	26876	Economy	15700.00
0005434287775	26876	Economy	15700.00
0005434287795	26876	Economy	15700.00
0005434287706	26876	Economy	15700.00
0005434287743	26876	Economy	15700.00
0005434287871	26876	Economy	15700.00
0005434287776	26876	Economy	15700.00
0005433110387	26876	Economy	15700.00
0005434287721	26876	Economy	15700.00
0005434287761	26876	Economy	15700.00
0005434287740	26876	Economy	15700.00
0005434287707	26876	Economy	15700.00
0005433110385	26876	Economy	15700.00
0005434287758	26876	Economy	15700.00
0005434287791	26876	Economy	15700.00
0005434287653	26876	Economy	15700.00
0005435856326	25470	Economy	22800.00
0005435856359	25470	Economy	22800.00
0005435856357	25470	Economy	22800.00
0005434269141	25470	Economy	22800.00
0005434269138	25470	Economy	22800.00
0005435856325	25470	Economy	22800.00
0005435856358	25470	Economy	22800.00
0005434269142	25470	Economy	22800.00
0005435856360	25470	Economy	22800.00
0005435856324	25470	Economy	22800.00
0005435856283	26636	Economy	25000.00
0005435856279	26636	Economy	22800.00
0005435854070	26636	Economy	22800.00
0005434273123	26636	Economy	22800.00
0005434273125	26636	Economy	22800.00
0005435856284	26636	Economy	22800.00
0005434272236	26636	Economy	22800.00
0005435854069	26636	Economy	22800.00
0005434272235	26636	Economy	22800.00
0005434273124	26636	Economy	22800.00
0005434272237	26636	Economy	22800.00
0005435856278	26636	Economy	22800.00
0005433869565	4794	Economy	19400.00
0005433869561	4794	Economy	19400.00
0005435860563	4794	Economy	19400.00
0005433869552	4794	Economy	17600.00
0005435860569	4794	Economy	17600.00
0005433869554	4794	Economy	17600.00
0005433869566	4794	Economy	17600.00
0005433869555	4794	Economy	17600.00
0005435860592	4794	Economy	17600.00
0005433869558	4794	Economy	17600.00
0005435860565	4794	Economy	17600.00
0005433869557	4794	Economy	17600.00
0005433869574	4794	Economy	17600.00
0005433869568	4794	Economy	17600.00
0005435860564	4794	Economy	17600.00
0005433869567	4794	Economy	17600.00
0005435860552	4794	Economy	17600.00
0005433869551	4794	Economy	17600.00
0005435860528	4794	Economy	17600.00
0005435860548	4794	Economy	17600.00
0005435860551	4794	Economy	17600.00
0005435860566	4794	Economy	17600.00
0005433869571	4794	Economy	17600.00
0005433869573	4794	Economy	17600.00
0005433869553	4794	Economy	17600.00
0005435860541	4794	Economy	17600.00
0005433869575	4794	Economy	17600.00
0005435860547	4794	Economy	17600.00
0005433869550	4794	Economy	17600.00
0005433869569	4794	Economy	17600.00
0005433869564	4794	Economy	17600.00
0005433869560	4794	Economy	17600.00
0005433869563	4794	Economy	17600.00
0005433869562	4794	Economy	17600.00
0005433869559	4794	Economy	17600.00
0005433869556	4794	Economy	17600.00
0005433869570	4794	Economy	17600.00
0005433869572	4794	Economy	17600.00
0005433869406	32606	Economy	19400.00
0005433869031	32606	Economy	19400.00
0005433868927	32606	Economy	19400.00
0005435860617	32606	Economy	19400.00
0005433869103	32606	Economy	17600.00
0005433868939	32606	Economy	17600.00
0005433869319	32606	Economy	17600.00
0005435860618	32606	Economy	17600.00
0005433868923	32606	Economy	17600.00
0005433869228	32606	Economy	17600.00
0005433869247	32606	Economy	17600.00
0005433869165	32606	Economy	17600.00
0005433869343	32606	Economy	17600.00
0005433869218	32606	Economy	17600.00
0005435860615	32606	Economy	17600.00
0005433869399	32606	Economy	17600.00
0005433869154	32606	Economy	17600.00
0005433869161	32606	Economy	17600.00
0005433869074	32606	Economy	17600.00
0005433869030	32606	Economy	17600.00
0005433869035	32606	Economy	17600.00
0005433869153	32606	Economy	17600.00
0005433869344	32606	Economy	17600.00
0005433869164	32606	Economy	17600.00
0005433869172	32606	Economy	17600.00
0005433869163	32606	Economy	17600.00
0005433869219	32606	Economy	17600.00
0005433869234	32606	Economy	17600.00
0005433869104	32606	Economy	17600.00
0005433869205	32606	Economy	17600.00
0005433869405	32606	Economy	17600.00
0005433869075	32606	Economy	17600.00
0005433869162	32606	Economy	17600.00
0005433869191	32606	Economy	17600.00
0005433869222	32606	Economy	17600.00
0005433869314	32606	Economy	17600.00
0005433869249	32606	Economy	17600.00
0005433869318	32606	Economy	17600.00
0005435860619	32606	Economy	17600.00
0005433869248	32606	Economy	17600.00
0005433869173	32606	Economy	17600.00
0005435860616	32606	Economy	17600.00
0005433869227	32606	Economy	17600.00
0005433869029	32606	Economy	17600.00
0005433868926	32606	Economy	17600.00
0005433869190	32606	Economy	17600.00
0005433869260	32606	Economy	17600.00
0005433869171	32606	Economy	17600.00
0005433869192	32606	Economy	17600.00
0005433869233	32606	Economy	17600.00
0005434663792	3412	Economy	22600.00
0005435911598	3412	Economy	22600.00
0005435911597	3412	Economy	22600.00
0005435911611	3412	Economy	22600.00
0005435911570	3412	Economy	22600.00
0005435911602	3412	Economy	22600.00
0005435911610	3412	Economy	22600.00
0005434461707	3412	Economy	22600.00
0005435911596	3412	Economy	22600.00
0005434663787	3412	Economy	22600.00
0005435911572	3412	Economy	22600.00
0005434663790	3412	Economy	22600.00
0005435911595	3412	Economy	22600.00
0005435911603	3412	Economy	22600.00
0005434663791	3412	Economy	22600.00
0005435911614	3412	Economy	22600.00
0005434663789	3412	Economy	22600.00
0005435911604	3412	Economy	22600.00
0005434663788	3412	Economy	22600.00
0005435911601	3412	Economy	22600.00
0005435911583	3412	Economy	22600.00
0005435911609	3412	Economy	22600.00
0005434663700	12478	Economy	24800.00
0005435911659	12478	Economy	22600.00
0005434663651	12478	Economy	22600.00
0005434663663	12478	Economy	22600.00
0005434663664	12478	Economy	22600.00
0005434663689	12478	Economy	22600.00
0005434663678	12478	Economy	22600.00
0005435911660	12478	Economy	22600.00
0005434663645	12478	Economy	22600.00
0005434663622	12478	Economy	22600.00
0005434663644	12478	Economy	22600.00
0005434663693	12478	Economy	22600.00
0005434663690	12478	Economy	22600.00
0005434663621	12478	Economy	22600.00
0005434663650	12478	Economy	22600.00
0005433869075	14510	Economy	18500.00
0005433869163	14510	Economy	18500.00
0005433869154	14510	Economy	18500.00
0005433869218	14510	Economy	18500.00
0005433869153	14510	Economy	16800.00
0005433869172	14510	Economy	16800.00
0005433869227	14510	Economy	16800.00
0005433869031	14510	Economy	16800.00
0005433869247	14510	Economy	16800.00
0005433868927	14510	Economy	16800.00
0005433869234	14510	Economy	16800.00
0005433869228	14510	Economy	16800.00
0005433869103	14510	Economy	16800.00
0005433869318	14510	Economy	16800.00
0005433869192	14510	Economy	16800.00
0005433869205	14510	Economy	16800.00
0005433869344	14510	Economy	16800.00
0005433869399	14510	Economy	16800.00
0005433869035	14510	Economy	16800.00
0005433869162	14510	Economy	16800.00
0005433869222	14510	Economy	16800.00
0005433869104	14510	Economy	16800.00
0005433869190	14510	Economy	16800.00
0005433869314	14510	Economy	16800.00
0005433869173	14510	Economy	16800.00
0005433869030	14510	Economy	16800.00
0005433869074	14510	Economy	16800.00
0005433869161	14510	Economy	16800.00
0005433869248	14510	Economy	16800.00
0005433869233	14510	Economy	16800.00
0005435860618	14510	Economy	16800.00
0005433869249	14510	Economy	16800.00
0005433869343	14510	Economy	16800.00
0005433869164	14510	Economy	16800.00
0005433869219	14510	Economy	16800.00
0005433869165	14510	Economy	16800.00
0005433868923	14510	Economy	16800.00
0005435860616	14510	Economy	16800.00
0005433869171	14510	Economy	16800.00
0005435860619	14510	Economy	16800.00
0005435860615	14510	Economy	16800.00
0005435860617	14510	Economy	16800.00
0005433869191	14510	Economy	16800.00
0005433869260	14510	Economy	16800.00
0005433868939	14510	Economy	16800.00
0005433869405	14510	Economy	16800.00
0005433869319	14510	Economy	16800.00
0005433869406	14510	Economy	16800.00
0005433869029	14510	Economy	16800.00
0005433868926	14510	Economy	16800.00
0005433869539	32688	Economy	18500.00
0005433869546	32688	Economy	18500.00
0005433869538	32688	Economy	16800.00
0005433869532	32688	Economy	16800.00
0005433869524	32688	Economy	16800.00
0005433869525	32688	Economy	16800.00
0005433869544	32688	Economy	16800.00
0005433869529	32688	Economy	16800.00
0005435860567	32688	Economy	16800.00
0005433869549	32688	Economy	16800.00
0005433869531	32688	Economy	16800.00
0005433869526	32688	Economy	16800.00
0005433869523	32688	Economy	16800.00
0005433869527	32688	Economy	16800.00
0005433869533	32688	Economy	16800.00
0005435860544	32688	Economy	16800.00
0005433869541	32688	Economy	16800.00
0005433869548	32688	Economy	16800.00
0005433869536	32688	Economy	16800.00
0005433869537	32688	Economy	16800.00
0005433869547	32688	Economy	16800.00
0005433869530	32688	Economy	16800.00
0005433869542	32688	Economy	16800.00
0005435860556	32688	Economy	16800.00
0005435860530	32688	Economy	16800.00
0005433869540	32688	Economy	16800.00
0005433869534	32688	Economy	16800.00
0005433869543	32688	Economy	16800.00
0005433869528	32688	Economy	16800.00
0005435860562	32688	Economy	16800.00
0005433869535	32688	Economy	16800.00
0005433869545	32688	Economy	16800.00
0005432800047	12103	Economy	4900.00
0005432800036	12103	Economy	4900.00
0005432800011	12103	Economy	4900.00
0005432800037	12103	Economy	4400.00
0005432800067	12103	Economy	4400.00
0005432799995	12103	Economy	4400.00
0005432800061	12103	Economy	4400.00
0005432799963	12103	Economy	4400.00
0005432800016	12103	Economy	4400.00
0005432800093	12103	Economy	4400.00
0005432800032	12103	Economy	4400.00
0005432800033	12103	Economy	4400.00
0005432799976	12103	Economy	4400.00
0005432800050	12103	Economy	4400.00
0005432800012	12103	Economy	4400.00
0005432800089	12103	Economy	4400.00
0005432800076	12103	Economy	4400.00
0005432800020	12103	Economy	4400.00
0005432799853	12103	Economy	4400.00
0005432799961	12103	Economy	4400.00
0005432800070	12103	Economy	4400.00
0005432800088	12103	Economy	4400.00
0005432799854	12103	Economy	4400.00
0005432799994	12103	Economy	4400.00
0005432800021	12103	Economy	4400.00
0005432800075	12103	Economy	4400.00
0005432799962	12103	Economy	4400.00
0005432800084	12103	Economy	4400.00
0005432800183	12103	Economy	4400.00
0005432800087	12103	Economy	4400.00
0005432800077	12103	Economy	4400.00
0005432800230	14814	Economy	4900.00
0005432800226	14814	Economy	4400.00
0005432800225	14814	Economy	4400.00
0005432800232	14814	Economy	4400.00
0005432800218	14814	Economy	4400.00
0005432800229	14814	Economy	4400.00
0005432800224	14814	Economy	4400.00
0005432800228	14814	Economy	4400.00
0005432800220	14814	Economy	4400.00
0005432800233	14814	Economy	4400.00
0005432800217	14814	Economy	4400.00
0005432800221	14814	Economy	4400.00
0005432800222	14814	Economy	4400.00
0005432800231	14814	Economy	4400.00
0005432800219	14814	Economy	4400.00
0005432800223	14814	Economy	4400.00
0005432800227	14814	Economy	4400.00
0005434300206	7065	Business	49100.00
0005434409540	7065	Business	49100.00
0005434409532	7065	Business	49100.00
0005434409542	7065	Business	49100.00
0005435311321	7065	Business	49100.00
0005435311405	7065	Business	49100.00
0005435293491	7065	Business	49100.00
0005435311323	7065	Business	49100.00
0005434409528	7065	Business	49100.00
0005435311295	7065	Business	49100.00
0005435311302	7065	Economy	16400.00
0005434409520	7065	Economy	16400.00
0005434409546	7065	Economy	16400.00
0005434409537	7065	Economy	16400.00
0005434409535	7065	Economy	16400.00
0005434300203	7065	Economy	16400.00
0005435293485	7065	Economy	16400.00
0005435293505	7065	Economy	16400.00
0005434409529	7065	Economy	16400.00
0005435311285	7065	Economy	16400.00
0005434409506	7065	Economy	16400.00
0005434409527	7065	Economy	16400.00
0005434409536	7065	Economy	16400.00
0005434409548	7065	Economy	16400.00
0005434409534	7065	Economy	16400.00
0005435293556	7065	Economy	16400.00
0005434409530	7065	Economy	16400.00
0005434409507	7065	Economy	16400.00
0005434409510	7065	Economy	16400.00
0005434409512	7065	Economy	16400.00
0005435311334	7065	Economy	16400.00
0005434300200	7065	Economy	16400.00
0005434409526	7065	Economy	16400.00
0005434409524	7065	Economy	16400.00
0005435311326	7065	Economy	16400.00
0005434409518	7065	Economy	16400.00
0005434409531	7065	Economy	16400.00
0005435293525	7065	Economy	16400.00
0005435293528	7065	Economy	16400.00
0005434409525	7065	Economy	18000.00
0005435311315	7065	Economy	18000.00
0005434409549	7065	Economy	18000.00
0005434409539	7065	Economy	16400.00
0005435293554	7065	Economy	18000.00
0005434409515	7065	Economy	16400.00
0005434409538	7065	Economy	16400.00
0005434300201	7065	Economy	16400.00
0005434409543	7065	Economy	16400.00
0005435293540	7065	Economy	16400.00
0005435293527	7065	Economy	16400.00
0005434409505	7065	Economy	16400.00
0005434409509	7065	Economy	16400.00
0005435293539	7065	Economy	16400.00
0005434300199	7065	Economy	16400.00
0005434409541	7065	Economy	16400.00
0005435311284	7065	Economy	16400.00
0005434409533	7065	Economy	16400.00
0005435311400	7065	Economy	16400.00
0005434409521	7065	Economy	16400.00
0005434409502	7065	Economy	16400.00
0005435311276	7065	Economy	16400.00
0005434409517	7065	Economy	16400.00
0005435293484	7065	Economy	16400.00
0005434300205	7065	Economy	16400.00
0005434409508	7065	Economy	16400.00
0005434409504	7065	Economy	16400.00
0005434409544	7065	Economy	16400.00
0005434409513	7065	Economy	16400.00
0005434409547	7065	Economy	16400.00
0005434409519	7065	Economy	16400.00
0005434409550	7065	Economy	16400.00
0005435311316	7065	Economy	16400.00
0005435311299	7065	Economy	16400.00
0005434409514	7065	Economy	16400.00
0005434409545	7065	Economy	16400.00
0005434300204	7065	Economy	16400.00
0005434409511	7065	Economy	16400.00
0005435311410	7065	Economy	16400.00
0005435293473	7065	Economy	16400.00
0005435293510	7065	Economy	16400.00
0005435293550	7065	Economy	16400.00
0005435293511	7065	Economy	16400.00
0005434409523	7065	Economy	16400.00
0005434409503	7065	Economy	16400.00
0005435311409	7065	Economy	16400.00
0005434409516	7065	Economy	16400.00
0005435293576	7065	Economy	16400.00
0005432154134	7065	Economy	16400.00
0005432154133	7065	Economy	16400.00
0005435311317	7065	Economy	16400.00
0005434300202	7065	Economy	16400.00
0005434409522	7065	Economy	16400.00
0005435311357	7065	Economy	16400.00
0005434300198	7065	Economy	16400.00
0005435293506	7065	Economy	16400.00
0005434300131	26933	Business	49100.00
0005434408701	26933	Business	49100.00
0005434300024	26933	Business	49100.00
0005434300157	26933	Business	49100.00
0005434409007	26933	Business	49100.00
0005434409018	26933	Business	49100.00
0005434300052	26933	Business	49100.00
0005435311494	26933	Business	49100.00
0005434408903	26933	Business	49100.00
0005435311493	26933	Business	49100.00
0005434409010	26933	Business	49100.00
0005434408807	26933	Economy	16400.00
0005434300077	26933	Economy	16400.00
0005434408983	26933	Economy	16400.00
0005434408785	26933	Economy	16400.00
0005434409161	26933	Economy	16400.00
0005434408520	26933	Economy	16400.00
0005434408856	26933	Economy	16400.00
0005432058491	26933	Economy	16400.00
0005435311485	26933	Economy	16400.00
0005434300023	26933	Economy	16400.00
0005434409091	26933	Economy	16400.00
0005435311500	26933	Economy	16400.00
0005434408839	26933	Economy	16400.00
0005434409153	26933	Economy	16400.00
0005434409165	26933	Economy	16400.00
0005434409034	26933	Economy	16400.00
0005434300034	26933	Economy	16400.00
0005434409090	26933	Economy	16400.00
0005434408677	26933	Economy	16400.00
0005434300079	26933	Economy	16400.00
0005434409135	26933	Economy	16400.00
0005435293610	26933	Economy	16400.00
0005435311487	26933	Economy	16400.00
0005434409147	26933	Economy	16400.00
0005434300076	26933	Economy	16400.00
0005434408875	26933	Economy	16400.00
0005434408904	26933	Economy	16400.00
0005434300058	26933	Economy	16400.00
0005435311480	26933	Economy	16400.00
0005435311490	26933	Economy	16400.00
0005434409162	26933	Economy	16400.00
0005434408876	26933	Economy	16400.00
0005434408939	26933	Economy	16400.00
0005434408916	26933	Economy	16400.00
0005432058490	26933	Economy	16400.00
0005434300065	26933	Economy	16400.00
0005434409120	26933	Economy	16400.00
0005434409241	26933	Economy	18000.00
0005435311489	26933	Economy	18000.00
0005434408941	26933	Economy	18000.00
0005434408902	26933	Economy	18000.00
0005434409125	26933	Economy	18000.00
0005435311479	26933	Economy	18000.00
0005435311477	26933	Economy	16400.00
0005435311503	26933	Economy	16400.00
0005434299961	26933	Economy	16400.00
0005434408808	26933	Economy	16400.00
0005434408618	26933	Economy	16400.00
0005434299946	26933	Economy	16400.00
0005435311478	26933	Economy	16400.00
0005434408956	26933	Economy	16400.00
0005434408938	26933	Economy	16400.00
0005434408819	26933	Economy	16400.00
0005434408920	26933	Economy	16400.00
0005434408835	26933	Economy	16400.00
0005434408930	26933	Economy	16400.00
0005435311484	26933	Economy	16400.00
0005434408892	26933	Economy	16400.00
0005434409151	26933	Economy	16400.00
0005434409006	26933	Economy	16400.00
0005434300066	26933	Economy	16400.00
0005434408917	26933	Economy	16400.00
0005432058492	26933	Economy	16400.00
0005434409148	26933	Economy	16400.00
0005435311486	26933	Economy	16400.00
0005434300041	26933	Economy	16400.00
0005434300111	26933	Economy	16400.00
0005434300091	26933	Economy	16400.00
0005434408929	26933	Economy	16400.00
0005435311495	26933	Economy	16400.00
0005434408820	26933	Economy	16400.00
0005434409033	26933	Economy	16400.00
0005435311497	26933	Economy	16400.00
0005434300078	26933	Economy	16400.00
0005434409302	26933	Economy	16400.00
0005435293609	26933	Economy	16400.00
0005434299945	26933	Economy	16400.00
0005434409055	26933	Economy	16400.00
0005434409119	26933	Economy	16400.00
0005435311492	26933	Economy	16400.00
0005435311496	26933	Economy	16400.00
0005434409056	26933	Economy	16400.00
0005435293608	26933	Economy	16400.00
0005435311491	26933	Economy	16400.00
0005435293607	26933	Economy	16400.00
0005434300090	26933	Economy	16400.00
0005432058493	26933	Economy	16400.00
0005435293604	26933	Economy	16400.00
0005434300061	26933	Economy	16400.00
0005434408678	26933	Economy	16400.00
0005435293606	26933	Economy	16400.00
0005435311488	26933	Economy	16400.00
0005435311502	26933	Economy	16400.00
0005435311499	26933	Economy	16400.00
0005434300130	26933	Economy	16400.00
0005435293605	26933	Economy	16400.00
0005434409152	26933	Economy	16400.00
0005434408948	26933	Economy	16400.00
0005434409019	26933	Economy	16400.00
0005434408840	26933	Economy	16400.00
0005434408850	26933	Economy	16400.00
0005434300040	26933	Economy	16400.00
0005435311481	26933	Economy	16400.00
0005434408617	26933	Economy	16400.00
0005435311501	26933	Economy	16400.00
0005434409057	26933	Economy	16400.00
0005435311482	26933	Economy	16400.00
0005435311483	26933	Economy	16400.00
0005434409141	26933	Economy	16400.00
0005435311498	26933	Economy	16400.00
0005434409011	26933	Economy	16400.00
0005435312899	6453	Economy	16500.00
0005432605445	6453	Economy	16500.00
0005432605446	6453	Economy	16500.00
0005435221548	6453	Economy	15000.00
0005432605449	6453	Economy	15000.00
0005432605447	6453	Economy	15000.00
0005434512242	6453	Economy	15000.00
0005432605440	6453	Economy	15000.00
0005432605438	6453	Economy	15000.00
0005432605460	6453	Economy	15000.00
0005432605441	6453	Economy	15000.00
0005432605436	6453	Economy	15000.00
0005432605454	6453	Economy	15000.00
0005432605462	6453	Economy	15000.00
0005432605453	6453	Economy	15000.00
0005435312895	6453	Economy	15000.00
0005432605448	6453	Economy	15000.00
0005432605451	6453	Economy	15000.00
0005435221549	6453	Economy	15000.00
0005434512244	6453	Economy	15000.00
0005434512247	6453	Economy	15000.00
0005432605439	6453	Economy	15000.00
0005432605437	6453	Economy	15000.00
0005432605458	6453	Economy	15000.00
0005432605444	6453	Economy	15000.00
0005432605443	6453	Economy	15000.00
0005434512245	6453	Economy	15000.00
0005432605456	6453	Economy	15000.00
0005432605435	6453	Economy	15000.00
0005434512246	6453	Economy	15000.00
0005432605450	6453	Economy	15000.00
0005434512243	6453	Economy	15000.00
0005435218128	6453	Economy	15000.00
0005432605452	6453	Economy	15000.00
0005432605442	6453	Economy	15000.00
0005432605457	6453	Economy	15000.00
0005432605455	6453	Economy	15000.00
0005432605459	6453	Economy	15000.00
0005434512248	6453	Economy	15000.00
0005435221550	6453	Economy	15000.00
0005432605461	6453	Economy	15000.00
0005432605068	21390	Economy	16500.00
0005432605066	21390	Economy	16500.00
0005432605138	21390	Economy	16500.00
0005432605225	21390	Economy	16500.00
0005432605250	21390	Economy	15000.00
0005432605116	21390	Economy	15000.00
0005432605035	21390	Economy	15000.00
0005432605135	21390	Economy	15000.00
0005432605248	21390	Economy	15000.00
0005432605114	21390	Economy	15000.00
0005432605042	21390	Economy	15000.00
0005434512224	21390	Economy	15000.00
0005432605249	21390	Economy	15000.00
0005432605084	21390	Economy	15000.00
0005432605175	21390	Economy	15000.00
0005432604864	21390	Economy	15000.00
0005432605085	21390	Economy	15000.00
0005432605227	21390	Economy	15000.00
0005432605226	21390	Economy	15000.00
0005432604952	21390	Economy	15000.00
0005432605031	21390	Economy	15000.00
0005432605043	21390	Economy	15000.00
0005434512182	21390	Economy	15000.00
0005432605067	21390	Economy	15000.00
0005432605100	21390	Economy	15000.00
0005432605123	21390	Economy	15000.00
0005432605140	21390	Economy	15000.00
0005432605247	21390	Economy	15000.00
0005432605083	21390	Economy	15000.00
0005432605065	21390	Economy	15000.00
0005432605176	21390	Economy	15000.00
0005432605142	21390	Economy	15000.00
0005432605158	21390	Economy	15000.00
0005432605167	21390	Economy	15000.00
0005432605166	21390	Economy	15000.00
0005432605052	21390	Economy	15000.00
0005432605045	21390	Economy	15000.00
0005432604921	21390	Economy	15000.00
0005434512223	21390	Economy	15000.00
0005432605251	21390	Economy	15000.00
0005432605021	21390	Economy	15000.00
0005432605160	21390	Economy	15000.00
0005432605136	21390	Economy	15000.00
0005432605141	21390	Economy	15000.00
0005432605159	21390	Economy	15000.00
0005432605087	21390	Economy	15000.00
0005434512221	21390	Economy	15000.00
0005432605076	21390	Economy	15000.00
0005432605079	21390	Economy	15000.00
0005434908355	14980	Business	18900.00
0005434908333	14980	Business	18900.00
0005434908566	14980	Business	18900.00
0005434908563	14980	Business	18900.00
0005433252340	14980	Business	18900.00
0005434908364	14980	Business	18900.00
0005434908324	14980	Business	18900.00
0005434908356	14980	Business	18900.00
0005434908226	14980	Business	18900.00
0005434908208	14980	Business	18900.00
0005434908511	14980	Economy	6300.00
0005433252334	14980	Economy	6300.00
0005434908217	14980	Economy	6300.00
0005433252341	14980	Economy	6300.00
0005434908088	14980	Economy	6900.00
0005434908189	14980	Economy	6900.00
0005434908281	14980	Economy	6900.00
0005434908376	14980	Economy	6900.00
0005434908336	14980	Economy	6900.00
0005434908225	14980	Economy	6300.00
0005433252335	14980	Economy	6300.00
0005433252344	14980	Economy	6300.00
0005434908306	14980	Economy	6300.00
0005433252332	14980	Economy	6300.00
0005434908344	14980	Economy	6300.00
0005434908188	14980	Economy	6300.00
0005434908118	14980	Economy	6300.00
0005434907987	14980	Economy	6300.00
0005434908414	14980	Economy	6300.00
0005434908334	14980	Economy	6300.00
0005434908307	14980	Economy	6300.00
0005434908089	14980	Economy	6300.00
0005433252336	14980	Economy	6300.00
0005434908078	14980	Economy	6300.00
0005434908375	14980	Economy	6300.00
0005434908369	14980	Economy	6300.00
0005433252330	14980	Economy	6300.00
0005434908190	14980	Economy	6300.00
0005434908433	14980	Economy	6300.00
0005434908564	14980	Economy	6300.00
0005434908353	14980	Economy	6300.00
0005434908121	14980	Economy	6300.00
0005433252331	14980	Economy	6300.00
0005434908317	14980	Economy	6300.00
0005434908385	14980	Economy	6300.00
0005433252333	14980	Economy	6300.00
0005434908464	14980	Economy	6300.00
0005434908436	14980	Economy	6300.00
0005433252338	14980	Economy	6300.00
0005434908403	14980	Economy	6300.00
0005434908228	14980	Economy	6300.00
0005434908229	14980	Economy	6300.00
0005433252342	14980	Economy	6300.00
0005434908132	14980	Economy	6300.00
0005434908431	14980	Economy	6300.00
0005434908429	14980	Economy	6300.00
0005434908282	14980	Economy	6300.00
0005434908384	14980	Economy	6300.00
0005434908211	14980	Economy	6300.00
0005433252337	14980	Economy	6300.00
0005434908224	14980	Economy	6300.00
0005434908212	14980	Economy	6300.00
0005434908313	14980	Economy	6300.00
0005434908227	14980	Economy	6300.00
0005434908536	14980	Economy	6300.00
0005434908416	14980	Economy	6300.00
0005434908174	14980	Economy	6300.00
0005433252339	14980	Economy	6300.00
0005433252343	14980	Economy	6300.00
0005434908739	25861	Business	18900.00
0005433252116	25861	Business	18900.00
0005434908756	25861	Business	18900.00
0005433252201	25861	Business	18900.00
0005434908737	25861	Business	18900.00
0005434908742	25861	Business	18900.00
0005434908778	25861	Business	18900.00
0005434908772	25861	Economy	6300.00
0005433251971	25861	Economy	6300.00
0005434908771	25861	Economy	6300.00
0005433252032	25861	Economy	6300.00
0005434908752	25861	Economy	6300.00
0005433252089	25861	Economy	6300.00
0005434908735	25861	Economy	6300.00
0005434908759	25861	Economy	6900.00
0005433252166	25861	Economy	6900.00
0005434908757	25861	Economy	6900.00
0005434908762	25861	Economy	6900.00
0005434908775	25861	Economy	6300.00
0005433252155	25861	Economy	6300.00
0005434908751	25861	Economy	6300.00
0005433252158	25861	Economy	6300.00
0005434908755	25861	Economy	6300.00
0005434908750	25861	Economy	6300.00
0005433252152	25861	Economy	6300.00
0005433252115	25861	Economy	6300.00
0005433252045	25861	Economy	6300.00
0005434908753	25861	Economy	6300.00
0005434908745	25861	Economy	6300.00
0005434908741	25861	Economy	6300.00
0005434908760	25861	Economy	6300.00
0005434908758	25861	Economy	6300.00
0005434908774	25861	Economy	6300.00
0005433252124	25861	Economy	6300.00
0005434908748	25861	Economy	6300.00
0005433252091	25861	Economy	6300.00
0005434908744	25861	Economy	6300.00
0005434908763	25861	Economy	6300.00
0005434908761	25861	Economy	6300.00
0005434908773	25861	Economy	6300.00
0005434908769	25861	Economy	6300.00
0005434908746	25861	Economy	6300.00
0005434908743	25861	Economy	6300.00
0005434908779	25861	Economy	6300.00
0005433252122	25861	Economy	6300.00
0005433252024	25861	Economy	6300.00
0005434908767	25861	Economy	6300.00
0005434908749	25861	Economy	6300.00
0005434908754	25861	Economy	6300.00
0005433252157	25861	Economy	6300.00
0005433252156	25861	Economy	6300.00
0005434908738	25861	Economy	6300.00
0005433252168	25861	Economy	6300.00
0005434908770	25861	Economy	6300.00
0005433252004	25861	Economy	6300.00
0005434908776	25861	Economy	6300.00
0005433252090	25861	Economy	6300.00
0005434908766	25861	Economy	6300.00
0005433252035	25861	Economy	6300.00
0005434908768	25861	Economy	6300.00
0005433252076	25861	Economy	6300.00
0005433252017	25861	Economy	6300.00
0005433252161	25861	Economy	6300.00
0005433252151	25861	Economy	6300.00
0005434908764	25861	Economy	6300.00
0005434908765	25861	Economy	6300.00
0005433252154	25861	Economy	6300.00
0005434908736	25861	Economy	6300.00
0005434908747	25861	Economy	6300.00
0005433252123	25861	Economy	6300.00
0005434908740	25861	Economy	6300.00
0005434908777	25861	Economy	6300.00
0005432609841	22478	Economy	16400.00
0005432607671	22478	Economy	16400.00
0005432609836	22478	Economy	14900.00
0005432607668	22478	Economy	14900.00
0005432607672	22478	Economy	14900.00
0005435841481	22478	Economy	14900.00
0005432609843	22478	Economy	14900.00
0005432607670	22478	Economy	14900.00
0005432607674	22478	Economy	14900.00
0005432609837	22478	Economy	14900.00
0005432607673	22478	Economy	14900.00
0005432609838	22478	Economy	14900.00
0005435842344	22478	Economy	14900.00
0005432607669	22478	Economy	14900.00
0005435842341	22478	Economy	14900.00
0005432609842	22478	Economy	14900.00
0005435842339	22478	Economy	14900.00
0005432607676	22478	Economy	14900.00
0005435841487	22478	Economy	14900.00
0005432609844	22478	Economy	14900.00
0005432609840	22478	Economy	14900.00
0005435841486	22478	Economy	14900.00
0005432609839	22478	Economy	14900.00
0005432609835	22478	Economy	14900.00
0005432607678	22478	Economy	14900.00
0005432607677	22478	Economy	14900.00
0005432607679	22478	Economy	14900.00
0005435841484	22478	Economy	14900.00
0005435841483	22478	Economy	14900.00
0005435842340	22478	Economy	14900.00
0005432607675	22478	Economy	14900.00
0005432613946	31725	Economy	16400.00
0005432609777	31725	Economy	16400.00
0005435841124	31725	Economy	14900.00
0005432613939	31725	Economy	14900.00
0005432609793	31725	Economy	14900.00
0005435841491	31725	Economy	14900.00
0005432613928	31725	Economy	14900.00
0005432609794	31725	Economy	14900.00
0005435841125	31725	Economy	14900.00
0005432613940	31725	Economy	14900.00
0005435841489	31725	Economy	14900.00
0005432613951	31725	Economy	14900.00
0005435841493	31725	Economy	14900.00
0005432613960	31725	Economy	14900.00
0005435841122	31725	Economy	14900.00
0005435841492	31725	Economy	14900.00
0005432613950	31725	Economy	14900.00
0005435841488	31725	Economy	14900.00
0005435841121	31725	Economy	14900.00
0005432613943	31725	Economy	14900.00
0005432609810	31725	Economy	14900.00
0005432609782	31725	Economy	14900.00
0005432609816	31725	Economy	14900.00
0005432613927	31725	Economy	14900.00
0005432609809	31725	Economy	14900.00
0005432613949	31725	Economy	14900.00
0005435841490	31725	Economy	14900.00
0005432613941	31725	Economy	14900.00
0005432613934	31725	Economy	14900.00
0005432613944	31725	Economy	14900.00
0005435841123	31725	Economy	14900.00
0005433009889	14200	Business	52300.00
0005433009897	14200	Business	52300.00
0005433810622	14200	Business	52300.00
0005433009893	14200	Business	52300.00
0005433009906	14200	Business	52300.00
0005433009900	14200	Business	52300.00
0005433009890	14200	Business	52300.00
0005433009911	14200	Economy	17400.00
0005433810623	14200	Economy	17400.00
0005433009915	14200	Economy	17400.00
0005433810602	14200	Economy	19200.00
0005433009892	14200	Economy	17400.00
0005433009916	14200	Economy	17400.00
0005433009901	14200	Economy	17400.00
0005433009899	14200	Economy	17400.00
0005433810635	14200	Economy	17400.00
0005433810618	14200	Economy	17400.00
0005433810603	14200	Economy	17400.00
0005433009907	14200	Economy	17400.00
0005433009895	14200	Economy	17400.00
0005433810620	14200	Economy	17400.00
0005433009896	14200	Economy	17400.00
0005433810615	14200	Economy	17400.00
0005433810600	14200	Economy	17400.00
0005433009894	14200	Economy	17400.00
0005433009903	14200	Economy	17400.00
0005433009905	14200	Economy	17400.00
0005433009910	14200	Economy	17400.00
0005433009912	14200	Economy	17400.00
0005433009902	14200	Economy	17400.00
0005433009904	14200	Economy	17400.00
0005433009908	14200	Economy	17400.00
0005433810619	14200	Economy	17400.00
0005433810636	14200	Economy	17400.00
0005433009909	14200	Economy	17400.00
0005433009898	14200	Economy	17400.00
0005433810601	14200	Economy	17400.00
0005433009913	14200	Economy	17400.00
0005433009914	14200	Economy	17400.00
0005433009891	14200	Economy	17400.00
0005433810638	14200	Economy	17400.00
0005433810630	14200	Economy	17400.00
0005433009222	22871	Business	52300.00
0005433009219	22871	Business	52300.00
0005433009603	22871	Business	52300.00
0005433009569	22871	Business	52300.00
0005433009365	22871	Business	52300.00
0005433009341	22871	Business	52300.00
0005433009610	22871	Business	52300.00
0005433810729	22871	Business	52300.00
0005433009423	22871	Business	52300.00
0005433009559	22871	Economy	17400.00
0005433009178	22871	Economy	17400.00
0005433009335	22871	Economy	17400.00
0005433009584	22871	Economy	17400.00
0005433009372	22871	Economy	19200.00
0005433009221	22871	Economy	19200.00
0005433009177	22871	Economy	19200.00
0005433009616	22871	Economy	19200.00
0005433009495	22871	Economy	17400.00
0005433009342	22871	Economy	17400.00
0005433810722	22871	Economy	17400.00
0005433009450	22871	Economy	17400.00
0005433009663	22871	Economy	17400.00
0005433009410	22871	Economy	17400.00
0005433810720	22871	Economy	17400.00
0005433009366	22871	Economy	17400.00
0005433009624	22871	Economy	17400.00
0005433009627	22871	Economy	17400.00
0005433009560	22871	Economy	17400.00
0005433810727	22871	Economy	17400.00
0005433810721	22871	Economy	17400.00
0005433810730	22871	Economy	17400.00
0005433009323	22871	Economy	17400.00
0005433009324	22871	Economy	17400.00
0005433810723	22871	Economy	17400.00
0005433009622	22871	Economy	17400.00
0005433009625	22871	Economy	17400.00
0005433009380	22871	Economy	17400.00
0005433810724	22871	Economy	17400.00
0005433009558	22871	Economy	17400.00
0005433810725	22871	Economy	17400.00
0005433009566	22871	Economy	17400.00
0005433810726	22871	Economy	17400.00
0005433009480	22871	Economy	17400.00
0005433009567	22871	Economy	17400.00
0005433009489	22871	Economy	17400.00
0005433009539	22871	Economy	17400.00
0005433009545	22871	Economy	17400.00
0005433009220	22871	Economy	17400.00
0005433009236	22871	Economy	17400.00
0005433009381	22871	Economy	17400.00
0005433009523	22871	Economy	17400.00
0005433810728	22871	Economy	17400.00
0005433009320	22871	Economy	17400.00
0005433009664	22871	Economy	17400.00
0005433009449	22871	Economy	17400.00
0005433009623	22871	Economy	17400.00
0005433009411	22871	Economy	17400.00
0005433009602	22871	Economy	17400.00
0005434926390	14954	Business	22900.00
0005434926426	14954	Business	22900.00
0005434926388	14954	Business	22900.00
0005434926376	14954	Business	22900.00
0005434926395	14954	Business	22900.00
0005434926452	14954	Business	22900.00
0005434926389	14954	Business	22900.00
0005434926456	14954	Business	22900.00
0005434926396	14954	Economy	7600.00
0005434926384	14954	Economy	7600.00
0005434926350	14954	Economy	7600.00
0005434926404	14954	Economy	8400.00
0005434926335	14954	Economy	8400.00
0005434926359	14954	Economy	7600.00
0005434926331	14954	Economy	7600.00
0005434926401	14954	Economy	7600.00
0005434926469	14954	Economy	7600.00
0005434926459	14954	Economy	7600.00
0005434926410	14954	Economy	7600.00
0005434926334	14954	Economy	7600.00
0005434926451	14954	Economy	7600.00
0005434926347	14954	Economy	7600.00
0005434926411	14954	Economy	7600.00
0005434926385	14954	Economy	7600.00
0005434926387	14954	Economy	7600.00
0005434926444	14954	Economy	7600.00
0005434926405	14954	Economy	7600.00
0005434926431	14954	Economy	7600.00
0005434926262	14954	Economy	7600.00
0005434926460	14954	Economy	7600.00
0005434926343	14954	Economy	7600.00
0005434926424	14954	Economy	7600.00
0005434926402	14954	Economy	7600.00
0005434926425	14954	Economy	7600.00
0005434926709	20511	Business	22900.00
0005434926749	20511	Business	22900.00
0005434926741	20511	Business	22900.00
0005434926707	20511	Business	22900.00
0005434926739	20511	Business	22900.00
0005434926708	20511	Business	22900.00
0005434926710	20511	Business	22900.00
0005434926720	20511	Economy	7600.00
0005434926717	20511	Economy	7600.00
0005434926730	20511	Economy	7600.00
0005434926731	20511	Economy	7600.00
0005434926743	20511	Economy	7600.00
0005434926732	20511	Economy	8400.00
0005434926721	20511	Economy	7600.00
0005434926744	20511	Economy	7600.00
0005434926742	20511	Economy	7600.00
0005434926740	20511	Economy	7600.00
0005434926734	20511	Economy	7600.00
0005434926725	20511	Economy	7600.00
0005434926718	20511	Economy	7600.00
0005434926723	20511	Economy	7600.00
0005434926748	20511	Economy	7600.00
0005434926733	20511	Economy	7600.00
0005434926724	20511	Economy	7600.00
0005434926727	20511	Economy	7600.00
0005434926715	20511	Economy	7600.00
0005434926736	20511	Economy	7600.00
0005434926747	20511	Economy	7600.00
0005434926746	20511	Economy	7600.00
0005434926729	20511	Economy	7600.00
0005434926738	20511	Economy	7600.00
0005434926728	20511	Economy	7600.00
0005434926719	20511	Economy	7600.00
0005434926706	20511	Economy	7600.00
0005434926735	20511	Economy	7600.00
0005434926750	20511	Economy	7600.00
0005434926745	20511	Economy	7600.00
0005434926726	20511	Economy	7600.00
0005434926716	20511	Economy	7600.00
0005434926712	20511	Economy	7600.00
0005434926722	20511	Economy	7600.00
0005434926711	20511	Economy	7600.00
0005434926737	20511	Economy	7600.00
0005434926751	20511	Economy	7600.00
0005434926714	20511	Economy	7600.00
0005434926752	20511	Economy	7600.00
0005434926713	20511	Economy	7600.00
0005435488447	15823	Economy	8900.00
0005435488448	15823	Economy	8900.00
0005435488450	15823	Economy	8100.00
0005435488440	15823	Economy	8100.00
0005435999625	15823	Economy	8100.00
0005435999624	15823	Economy	8100.00
0005435999615	15823	Economy	8100.00
0005435488449	15823	Economy	8100.00
0005435999629	15823	Economy	8100.00
0005435999559	15823	Economy	8100.00
0005435488444	15823	Economy	8100.00
0005435999627	15823	Economy	8100.00
0005435999605	15823	Economy	8100.00
0005435999628	15823	Economy	8100.00
0005435999610	15823	Economy	8100.00
0005435999588	15823	Economy	8100.00
0005435488443	15823	Economy	8100.00
0005435999510	15823	Economy	8100.00
0005435999608	15823	Economy	8100.00
0005435488451	15823	Economy	8100.00
0005435488441	15823	Economy	8100.00
0005435999637	15823	Economy	8100.00
0005435999551	15823	Economy	8100.00
0005435999607	15823	Economy	8100.00
0005435488442	15823	Economy	8100.00
0005435488439	15823	Economy	8100.00
0005435999589	15823	Economy	8100.00
0005435999612	15823	Economy	8100.00
0005435488452	15823	Economy	8100.00
0005435999606	15823	Economy	8100.00
0005435999602	15823	Economy	8100.00
0005435999560	15823	Economy	8100.00
0005435488445	15823	Economy	8100.00
0005435999611	15823	Economy	8100.00
0005435999517	15823	Economy	8100.00
0005435999601	15823	Economy	8100.00
0005435488446	15823	Economy	8100.00
0005435999631	15823	Economy	8100.00
0005435999776	19709	Economy	8900.00
0005435999783	19709	Economy	8900.00
0005435999790	19709	Economy	8900.00
0005435999779	19709	Economy	8900.00
0005435999778	19709	Economy	8100.00
0005435488235	19709	Economy	8100.00
0005435488216	19709	Economy	8100.00
0005435999793	19709	Economy	8100.00
0005435999787	19709	Economy	8100.00
0005435488288	19709	Economy	8100.00
0005435488221	19709	Economy	8100.00
0005435488316	19709	Economy	8100.00
0005435488201	19709	Economy	8100.00
0005435488238	19709	Economy	8100.00
0005435999785	19709	Economy	8100.00
0005435488270	19709	Economy	8100.00
0005435488207	19709	Economy	8100.00
0005435999786	19709	Economy	8100.00
0005435488250	19709	Economy	8100.00
0005435488307	19709	Economy	8100.00
0005435999788	19709	Economy	8100.00
0005435999794	19709	Economy	8100.00
0005435488204	19709	Economy	8100.00
0005435488251	19709	Economy	8100.00
0005435999789	19709	Economy	8100.00
0005435488210	19709	Economy	8100.00
0005435488252	19709	Economy	8100.00
0005435488228	19709	Economy	8100.00
0005435488220	19709	Economy	8100.00
0005435488261	19709	Economy	8100.00
0005435999784	19709	Economy	8100.00
0005435488258	19709	Economy	8100.00
0005435488222	19709	Economy	8100.00
0005435999780	19709	Economy	8100.00
0005435999792	19709	Economy	8100.00
0005435488264	19709	Economy	8100.00
0005435488099	19709	Economy	8100.00
0005435488256	19709	Economy	8100.00
0005435488241	19709	Economy	8100.00
0005435488269	19709	Economy	8100.00
0005435488308	19709	Economy	8100.00
0005435999781	19709	Economy	8100.00
0005435488227	19709	Economy	8100.00
0005435488336	19709	Economy	8100.00
0005435999777	19709	Economy	8100.00
0005435999782	19709	Economy	8100.00
0005435488240	19709	Economy	8100.00
0005435488199	19709	Economy	8100.00
0005435999791	19709	Economy	8100.00
0005432537102	6017	Business	199300.00
0005435840247	6017	Business	199300.00
0005432537093	6017	Business	199300.00
0005432537101	6017	Business	199300.00
0005435840241	6017	Business	199300.00
0005435473061	6017	Business	199300.00
0005435840246	6017	Economy	66400.00
0005432537094	6017	Economy	66400.00
0005435840244	6017	Economy	66400.00
0005432659767	6017	Economy	66400.00
0005435473111	6017	Economy	66400.00
0005435473137	6017	Economy	66400.00
0005435840239	6017	Economy	66400.00
0005432142341	6017	Economy	66400.00
0005432659766	6017	Economy	66400.00
0005435840248	6017	Economy	66400.00
0005432537088	6017	Economy	66400.00
0005432658651	6017	Economy	66400.00
0005435840245	6017	Economy	66400.00
0005435473076	6017	Economy	66400.00
0005432537087	6017	Economy	66400.00
0005435840238	6017	Economy	66400.00
0005435473176	6017	Economy	66400.00
0005435840242	6017	Economy	66400.00
0005435473136	6017	Economy	66400.00
0005435840237	6017	Economy	66400.00
0005435473087	6017	Economy	66400.00
0005435473109	6017	Economy	66400.00
0005432659765	6017	Economy	66400.00
0005435840236	6017	Economy	66400.00
0005435473112	6017	Economy	66400.00
0005435473110	6017	Economy	66400.00
0005432658650	6017	Economy	66400.00
0005435840243	6017	Economy	66400.00
0005435473144	6017	Economy	66400.00
0005435840240	6017	Economy	66400.00
0005435840235	6017	Economy	66400.00
0005435840249	6017	Economy	66400.00
0005435473196	6017	Economy	66400.00
0005435840250	6017	Economy	66400.00
0005435473274	18041	Business	199300.00
0005435839844	18041	Business	199300.00
0005435839959	18041	Business	199300.00
0005435473272	18041	Business	199300.00
0005435473269	18041	Business	199300.00
0005432660852	18041	Business	199300.00
0005435839966	18041	Business	199300.00
0005435840063	18041	Business	199300.00
0005435840070	18041	Business	199300.00
0005435839979	18041	Business	199300.00
0005435839980	18041	Business	199300.00
0005432664187	18041	Economy	66400.00
0005435840041	18041	Economy	66400.00
0005435840040	18041	Economy	66400.00
0005435840072	18041	Economy	66400.00
0005435839981	18041	Economy	73100.00
0005435839903	18041	Economy	73100.00
0005432660860	18041	Economy	66400.00
0005435473268	18041	Economy	66400.00
0005435840071	18041	Economy	66400.00
0005435473266	18041	Economy	66400.00
0005435473270	18041	Economy	66400.00
0005432660861	18041	Economy	66400.00
0005435473263	18041	Economy	66400.00
0005435840080	18041	Economy	66400.00
0005432664163	18041	Economy	66400.00
0005435840130	18041	Economy	66400.00
0005435473267	18041	Economy	66400.00
0005435840154	18041	Economy	66400.00
0005432667490	18041	Economy	66400.00
0005435473264	18041	Economy	66400.00
0005435840129	18041	Economy	66400.00
0005432537119	18041	Economy	66400.00
0005432660858	18041	Economy	66400.00
0005432664162	18041	Economy	66400.00
0005435473273	18041	Economy	66400.00
0005435473262	18041	Economy	66400.00
0005435473271	18041	Economy	66400.00
0005435840021	18041	Economy	66400.00
0005435840153	18041	Economy	66400.00
0005435840113	18041	Economy	66400.00
0005435840037	18041	Economy	66400.00
0005435473265	18041	Economy	66400.00
0005435840128	18041	Economy	66400.00
0005435840081	18041	Economy	66400.00
0005433286014	23051	Business	15700.00
0005435104276	23051	Business	15700.00
0005435104277	23051	Business	15700.00
0005433285837	23051	Business	15700.00
0005435104278	23051	Economy	5200.00
0005435104263	23051	Economy	5200.00
0005435104249	23051	Economy	5200.00
0005433285860	23051	Economy	5200.00
0005435104259	23051	Economy	5200.00
0005433285967	23051	Economy	5200.00
0005435104274	23051	Economy	5200.00
0005433285979	23051	Economy	5200.00
0005435104242	23051	Economy	5200.00
0005435104255	23051	Economy	5200.00
0005435104254	23051	Economy	5200.00
0005435104252	23051	Economy	5200.00
0005435104271	23051	Economy	5200.00
0005435104266	23051	Economy	5200.00
0005433286005	23051	Economy	5200.00
0005435104257	23051	Economy	5200.00
0005435104268	23051	Economy	5200.00
0005433285996	23051	Economy	5200.00
0005433286023	23051	Economy	5200.00
0005433285981	23051	Economy	5200.00
0005433285918	23051	Economy	5200.00
0005433286015	23051	Economy	5200.00
0005433285836	23051	Economy	5200.00
0005435104279	23051	Economy	5200.00
0005435104239	23051	Economy	5700.00
0005435104253	23051	Economy	5700.00
0005433285779	23051	Economy	5700.00
0005435104246	23051	Economy	5700.00
0005433285904	23051	Economy	5200.00
0005433285850	23051	Economy	5200.00
0005435104280	23051	Economy	5200.00
0005433286042	23051	Economy	5200.00
0005435104260	23051	Economy	5200.00
0005435104258	23051	Economy	5200.00
0005435104256	23051	Economy	5200.00
0005435104264	23051	Economy	5200.00
0005433285896	23051	Economy	5200.00
0005435104265	23051	Economy	5200.00
0005435104240	23051	Economy	5200.00
0005433285937	23051	Economy	5200.00
0005435104251	23051	Economy	5200.00
0005435104245	23051	Economy	5200.00
0005435104241	23051	Economy	5200.00
0005433285919	23051	Economy	5200.00
0005433285901	23051	Economy	5200.00
0005433285985	23051	Economy	5200.00
0005433285984	23051	Economy	5200.00
0005435104261	23051	Economy	5200.00
0005435104275	23051	Economy	5200.00
0005435104269	23051	Economy	5200.00
0005435104262	23051	Economy	5200.00
0005433285962	23051	Economy	5200.00
0005435104243	23051	Economy	5200.00
0005433285868	23051	Economy	5200.00
0005433285865	23051	Economy	5200.00
0005435104270	23051	Economy	5200.00
0005435104250	23051	Economy	5200.00
0005433285900	23051	Economy	5200.00
0005433285895	23051	Economy	5200.00
0005435104281	23051	Economy	5200.00
0005435104272	23051	Economy	5200.00
0005433285842	23051	Economy	5200.00
0005435104248	23051	Economy	5200.00
0005433285869	23051	Economy	5200.00
0005433285980	23051	Economy	5200.00
0005435104244	23051	Economy	5200.00
0005435104273	23051	Economy	5200.00
0005435104247	23051	Economy	5200.00
0005435104267	23051	Economy	5200.00
0005433286174	32090	Business	15700.00
0005433286178	32090	Business	15700.00
0005433286182	32090	Business	15700.00
0005433286169	32090	Business	15700.00
0005433286173	32090	Business	15700.00
0005433286180	32090	Economy	5200.00
0005435104052	32090	Economy	5200.00
0005433286170	32090	Economy	5200.00
0005433286176	32090	Economy	5200.00
0005435104069	32090	Economy	5200.00
0005433286171	32090	Economy	5200.00
0005433286177	32090	Economy	5200.00
0005433286186	32090	Economy	5200.00
0005433286175	32090	Economy	5200.00
0005435104014	32090	Economy	5200.00
0005433286168	32090	Economy	5200.00
0005433286184	32090	Economy	5200.00
0005435104051	32090	Economy	5200.00
0005433286187	32090	Economy	5200.00
0005433286185	32090	Economy	5200.00
0005433286183	32090	Economy	5200.00
0005433286181	32090	Economy	5200.00
0005433286179	32090	Economy	5200.00
0005433286167	32090	Economy	5200.00
0005433286172	32090	Economy	5200.00
0005435104041	32090	Economy	5200.00
0005435852651	23857	Economy	12300.00
0005433475811	23857	Economy	12300.00
0005433475795	23857	Economy	12300.00
0005433475771	23857	Economy	12300.00
0005433475770	23857	Economy	12300.00
0005433475787	23857	Economy	12300.00
0005433475769	23857	Economy	12300.00
0005433475782	23857	Economy	12300.00
0005433475794	23857	Economy	12300.00
0005433475810	23857	Economy	12300.00
0005435852652	23857	Economy	12300.00
0005433475797	23857	Economy	12300.00
0005435283518	30621	Business	42100.00
0005434068805	30621	Business	42100.00
0005432530806	30621	Business	42100.00
0005435631053	30621	Business	42100.00
0005432530763	30621	Business	42100.00
0005434068804	30621	Business	42100.00
0005434069344	30621	Business	42100.00
0005435215474	30621	Business	42100.00
0005435283505	30621	Business	42100.00
0005432530833	30621	Business	42100.00
0005432530657	30621	Business	42100.00
0005434068970	30621	Business	42100.00
0005434068771	30621	Business	42100.00
0005435215448	30621	Business	42100.00
0005432530714	30621	Business	42100.00
0005435283512	30621	Business	42100.00
0005432530636	30621	Business	42100.00
0005432530417	30621	Business	42100.00
0005432530838	30621	Business	42100.00
0005432530767	30621	Comfort	23900.00
0005434069139	30621	Comfort	23900.00
0005432211717	30621	Comfort	23900.00
0005435283507	30621	Comfort	23900.00
0005435215455	30621	Comfort	23900.00
0005434069100	30621	Comfort	23900.00
0005432531332	30621	Comfort	23900.00
0005432530877	30621	Comfort	23900.00
0005432530836	30621	Comfort	23900.00
0005432530912	30621	Comfort	23900.00
0005435283517	30621	Comfort	23900.00
0005434068728	30621	Comfort	23900.00
0005434069080	30621	Comfort	23900.00
0005432531330	30621	Comfort	23900.00
0005432530766	30621	Comfort	23900.00
0005434068864	30621	Comfort	23900.00
0005432530673	30621	Comfort	23900.00
0005432530931	30621	Comfort	23900.00
0005434068958	30621	Comfort	23900.00
0005432531070	30621	Comfort	23900.00
0005435215472	30621	Comfort	23900.00
0005432531317	30621	Comfort	23900.00
0005432530267	30621	Comfort	23900.00
0005435215444	30621	Comfort	23900.00
0005432530903	30621	Comfort	23900.00
0005432530593	30621	Comfort	23900.00
0005435215458	30621	Comfort	23900.00
0005432535934	30621	Comfort	23900.00
0005434068885	30621	Comfort	23900.00
0005434069044	30621	Comfort	23900.00
0005434068853	30621	Comfort	23900.00
0005432530378	30621	Comfort	23900.00
0005435215478	30621	Comfort	23900.00
0005432530706	30621	Economy	14000.00
0005434069229	30621	Economy	14000.00
0005435725737	30621	Economy	14000.00
0005435215475	30621	Economy	14000.00
0005434069038	30621	Economy	14000.00
0005432530682	30621	Economy	14000.00
0005432531109	30621	Economy	14000.00
0005435215456	30621	Economy	14000.00
0005432530905	30621	Economy	14000.00
0005432530840	30621	Economy	14000.00
0005435215450	30621	Economy	14000.00
0005435215476	30621	Economy	14000.00
0005432535958	30621	Economy	14000.00
0005432530894	30621	Economy	14000.00
0005435725738	30621	Economy	14000.00
0005434068762	30621	Economy	14000.00
0005432530521	30621	Economy	14000.00
0005432530680	30621	Economy	14000.00
0005434068527	30621	Economy	14000.00
0005435215454	30621	Economy	14000.00
0005435215462	30621	Economy	14000.00
0005432531176	30621	Economy	14000.00
0005434069036	30621	Economy	14000.00
0005434069112	30621	Economy	14000.00
0005435215449	30621	Economy	14000.00
0005434068999	30621	Economy	14000.00
0005432530616	30621	Economy	14000.00
0005434068888	30621	Economy	14000.00
0005434069427	30621	Economy	14000.00
0005434068727	30621	Economy	14000.00
0005435215479	30621	Economy	14000.00
0005434069089	30621	Economy	14000.00
0005432531205	30621	Economy	14000.00
0005432530705	30621	Economy	14000.00
0005432530891	30621	Economy	14000.00
0005434068796	30621	Economy	14000.00
0005434068930	30621	Economy	14000.00
0005432531079	30621	Economy	14000.00
0005434069041	30621	Economy	14000.00
0005432530774	30621	Economy	14000.00
0005435631052	30621	Economy	14000.00
0005435215459	30621	Economy	14000.00
0005432530881	30621	Economy	14000.00
0005434068807	30621	Economy	15400.00
0005432530700	30621	Economy	14000.00
0005435215467	30621	Economy	15400.00
0005435283509	30621	Economy	15400.00
0005434068963	30621	Economy	15400.00
0005432531071	30621	Economy	14000.00
0005432530839	30621	Economy	15400.00
0005435215468	30621	Economy	14000.00
0005435283514	30621	Economy	14000.00
0005432531045	30621	Economy	14000.00
0005434068668	30621	Economy	14000.00
0005432530775	30621	Economy	14000.00
0005434068810	30621	Economy	14000.00
0005432530579	30621	Economy	14000.00
0005432530608	30621	Economy	14000.00
0005432531425	30621	Economy	14000.00
0005432530586	30621	Economy	14000.00
0005435215447	30621	Economy	14000.00
0005435215446	30621	Economy	14000.00
0005434069037	30621	Economy	14000.00
0005432530150	30621	Economy	14000.00
0005434068918	30621	Economy	14000.00
0005432530991	30621	Economy	14000.00
0005432530872	30621	Economy	14000.00
0005435215457	30621	Economy	14000.00
0005432530911	30621	Economy	14000.00
0005432530650	30621	Economy	14000.00
0005432530768	30621	Economy	14000.00
0005434069057	30621	Economy	14000.00
0005435631054	30621	Economy	14000.00
0005432531431	30621	Economy	14000.00
0005434068880	30621	Economy	14000.00
0005432530665	30621	Economy	14000.00
0005435215464	30621	Economy	14000.00
0005434068929	30621	Economy	14000.00
0005432530998	30621	Economy	14000.00
0005432530678	30621	Economy	14000.00
0005434068663	30621	Economy	14000.00
0005434069000	30621	Economy	14000.00
0005432530890	30621	Economy	14000.00
0005434069004	30621	Economy	14000.00
0005432530582	30621	Economy	14000.00
0005434069028	30621	Economy	14000.00
0005434069079	30621	Economy	14000.00
0005432530764	30621	Economy	14000.00
0005432531110	30621	Economy	14000.00
0005432530664	30621	Economy	14000.00
0005432211716	30621	Economy	14000.00
0005432530649	30621	Economy	14000.00
0005434068769	30621	Economy	14000.00
0005432530197	30621	Economy	14000.00
0005432530668	30621	Economy	14000.00
0005432531010	30621	Economy	14000.00
0005432530482	30621	Economy	14000.00
0005435631051	30621	Economy	14000.00
0005434069025	30621	Economy	14000.00
0005432211718	30621	Economy	14000.00
0005434068904	30621	Economy	14000.00
0005434069088	30621	Economy	14000.00
0005434068978	30621	Economy	14000.00
0005432530313	30621	Economy	14000.00
0005435215466	30621	Economy	14000.00
0005432531011	30621	Economy	14000.00
0005432530949	30621	Economy	14000.00
0005434068995	30621	Economy	14000.00
0005432530594	30621	Economy	14000.00
0005432530902	30621	Economy	14000.00
0005432530741	30621	Economy	14000.00
0005432535933	30621	Economy	14000.00
0005434068889	30621	Economy	14000.00
0005434068881	30621	Economy	14000.00
0005432530208	30621	Economy	14000.00
0005432530640	30621	Economy	14000.00
0005435283508	30621	Economy	14000.00
0005432530423	30621	Economy	14000.00
0005432531319	30621	Economy	14000.00
0005432530873	30621	Economy	14000.00
0005432530196	30621	Economy	14000.00
0005432530672	30621	Economy	14000.00
0005434069140	30621	Economy	14000.00
0005432530358	30621	Economy	14000.00
0005432530424	30621	Economy	14000.00
0005432530930	30621	Economy	14000.00
0005435215477	30621	Economy	14000.00
0005432531268	30621	Economy	14000.00
0005432531107	30621	Economy	14000.00
0005434068927	30621	Economy	14000.00
0005432530860	30621	Economy	14000.00
0005435215469	30621	Economy	14000.00
0005432531318	30621	Economy	14000.00
0005435215480	30621	Economy	14000.00
0005434068990	30621	Economy	14000.00
0005434069099	30621	Economy	14000.00
0005434068826	30621	Economy	14000.00
0005435215463	30621	Economy	15400.00
0005434069064	30621	Economy	15400.00
0005432531080	30621	Economy	15400.00
0005435215471	30621	Economy	14000.00
0005432530895	30621	Economy	14000.00
0005434068905	30621	Economy	14000.00
0005432211719	30621	Economy	14000.00
0005434068858	30621	Economy	14000.00
0005432530476	30621	Economy	14000.00
0005434069228	30621	Economy	14000.00
0005434068642	30621	Economy	14000.00
0005432530613	30621	Economy	14000.00
0005435283516	30621	Economy	14000.00
0005432530703	30621	Economy	14000.00
0005434068882	30621	Economy	14000.00
0005435283513	30621	Economy	14000.00
0005432530713	30621	Economy	14000.00
0005432530312	30621	Economy	14000.00
0005435215473	30621	Economy	14000.00
0005435215445	30621	Economy	14000.00
0005432530658	30621	Economy	14000.00
0005432535950	30621	Economy	14000.00
0005432530837	30621	Economy	14000.00
0005432530756	30621	Economy	14000.00
0005434069024	30621	Economy	14000.00
0005435215465	30621	Economy	14000.00
0005432530681	30621	Economy	14000.00
0005432531331	30621	Economy	14000.00
0005432530707	30621	Economy	14000.00
0005434068910	30621	Economy	14000.00
0005434068928	30621	Economy	14000.00
0005432530266	30621	Economy	14000.00
0005435215453	30621	Economy	14000.00
0005432530841	30621	Economy	14000.00
0005435215451	30621	Economy	14000.00
0005432530198	30621	Economy	14000.00
0005432530639	30621	Economy	14000.00
0005432530669	30621	Economy	14000.00
0005434068863	30621	Economy	14000.00
0005432530740	30621	Economy	14000.00
0005434069090	30621	Economy	14000.00
0005432530701	30621	Economy	14000.00
0005435215470	30621	Economy	14000.00
0005432530699	30621	Economy	14000.00
0005434069116	30621	Economy	14000.00
0005435283510	30621	Economy	14000.00
0005432530612	30621	Economy	14000.00
0005435215452	30621	Economy	14000.00
0005432535951	30621	Economy	14000.00
0005434068526	30621	Economy	14000.00
0005432530929	30621	Economy	14000.00
0005432535935	30621	Economy	14000.00
0005432530229	30621	Economy	14000.00
0005432531076	30621	Economy	14000.00
0005432530702	30621	Economy	14000.00
0005432533356	30621	Economy	14000.00
0005432530708	30621	Economy	14000.00
0005432531430	30621	Economy	14000.00
0005432530807	30621	Economy	14000.00
0005435283511	30621	Economy	14000.00
0005432530363	30621	Economy	14000.00
0005435215461	30621	Economy	14000.00
0005432530595	30621	Economy	14000.00
0005435283506	30621	Economy	14000.00
0005432535956	30621	Economy	14000.00
0005434068879	30621	Economy	14000.00
0005434068861	30621	Economy	14000.00
0005432530530	30621	Economy	14000.00
0005435283515	30621	Economy	14000.00
0005432530617	30621	Economy	14000.00
0005432530493	30621	Economy	14000.00
0005432530522	30621	Economy	14000.00
0005432530398	30621	Economy	14000.00
0005432531081	30621	Economy	14000.00
0005435215460	30621	Economy	14000.00
0005435653990	24866	Business	9800.00
0005433368964	24866	Business	9800.00
0005435653984	24866	Business	9800.00
0005435654040	24866	Business	9800.00
0005435653986	24866	Business	9800.00
0005433368953	24866	Business	9800.00
0005435654095	24866	Business	9800.00
0005435653835	24866	Business	9800.00
0005435653999	24866	Business	9800.00
0005435653852	24866	Economy	3300.00
0005435653934	24866	Economy	3300.00
0005435653912	24866	Economy	3300.00
0005433368950	24866	Economy	3300.00
0005435654130	24866	Economy	3300.00
0005435653840	24866	Economy	3300.00
0005435654077	24866	Economy	3300.00
0005435654103	24866	Economy	3300.00
0005435653922	24866	Economy	3300.00
0005433368945	24866	Economy	3300.00
0005435653891	24866	Economy	3600.00
0005433368952	24866	Economy	3600.00
0005435653868	24866	Economy	3600.00
0005433368948	24866	Economy	3600.00
0005435654127	24866	Economy	3300.00
0005435654004	24866	Economy	3300.00
0005435654035	24866	Economy	3300.00
0005433368960	24866	Economy	3300.00
0005435653936	24866	Economy	3300.00
0005435654034	24866	Economy	3300.00
0005435654078	24866	Economy	3300.00
0005435653774	24866	Economy	3300.00
0005435653908	24866	Economy	3300.00
0005433368946	24866	Economy	3300.00
0005433368951	24866	Economy	3300.00
0005435653899	24866	Economy	3300.00
0005435653855	24866	Economy	3300.00
0005435653926	24866	Economy	3300.00
0005435653982	24866	Economy	3300.00
0005435653800	24866	Economy	3300.00
0005433368949	24866	Economy	3300.00
0005435653957	24866	Economy	3300.00
0005435654137	24866	Economy	3300.00
0005433368956	24866	Economy	3300.00
0005433368954	24866	Economy	3300.00
0005435654102	24866	Economy	3300.00
0005435653839	24866	Economy	3300.00
0005435654009	24866	Economy	3300.00
0005435653983	24866	Economy	3300.00
0005435653799	24866	Economy	3300.00
0005435653973	24866	Economy	3300.00
0005433368958	24866	Economy	3300.00
0005433368955	24866	Economy	3300.00
0005433368961	24866	Economy	3300.00
0005433368947	24866	Economy	3300.00
0005435653844	24866	Economy	3300.00
0005435654031	24866	Economy	3300.00
0005435653686	24866	Economy	3300.00
0005435654151	24866	Economy	3300.00
0005433368963	24866	Economy	3300.00
0005433368962	24866	Economy	3300.00
0005435653865	24866	Economy	3300.00
0005435653853	24866	Economy	3300.00
0005435653959	24866	Economy	3300.00
0005435653834	24866	Economy	3300.00
0005435653975	24866	Economy	3300.00
0005435653906	24866	Economy	3300.00
0005433368959	24866	Economy	3300.00
0005435653937	24866	Economy	3300.00
0005433368957	24866	Economy	3300.00
0005435654033	24866	Economy	3300.00
0005435654096	24866	Economy	3300.00
0005433368965	24866	Economy	3300.00
0005435654000	24866	Economy	3300.00
0005435653974	24866	Economy	3300.00
0005435653958	24866	Economy	3300.00
0005435653994	24866	Economy	3300.00
0005435653991	24866	Economy	3300.00
0005435654005	24866	Economy	3300.00
0005435949839	23320	Economy	20600.00
0005435949838	23320	Economy	18700.00
0005435949840	23320	Economy	18700.00
0005435949841	23320	Economy	18700.00
0005435949826	23320	Economy	18700.00
0005434980637	2033	Economy	10500.00
0005434980640	2033	Economy	10500.00
0005434980649	2033	Economy	9500.00
0005434980652	2033	Economy	9500.00
0005434980643	2033	Economy	9500.00
0005434980647	2033	Economy	9500.00
0005434980636	2033	Economy	9500.00
0005434980653	2033	Economy	9500.00
0005434980642	2033	Economy	9500.00
0005434980641	2033	Economy	9500.00
0005434980650	2033	Economy	9500.00
0005434980648	2033	Economy	9500.00
0005434980651	2033	Economy	9500.00
0005434980644	2033	Economy	9500.00
0005435801779	2033	Economy	9500.00
0005434980645	2033	Economy	9500.00
0005434980646	2033	Economy	9500.00
0005434980639	2033	Economy	9500.00
0005434980638	2033	Economy	9500.00
0005434980654	2033	Economy	9500.00
0005435801755	23537	Economy	10500.00
0005434980281	23537	Economy	10500.00
0005434980425	23537	Economy	9500.00
0005434980247	23537	Economy	9500.00
0005434980472	23537	Economy	9500.00
0005435801754	23537	Economy	9500.00
0005434980459	23537	Economy	9500.00
0005434980368	23537	Economy	9500.00
0005434980419	23537	Economy	9500.00
0005434980396	23537	Economy	9500.00
0005434980392	23537	Economy	9500.00
0005434980367	23537	Economy	9500.00
0005434980447	23537	Economy	9500.00
0005434980427	23537	Economy	9500.00
0005434980366	23537	Economy	9500.00
0005434980239	23537	Economy	9500.00
0005434980350	23537	Economy	9500.00
0005434980330	23537	Economy	9500.00
0005434980342	23537	Economy	9500.00
0005434980341	23537	Economy	9500.00
0005434980300	23537	Economy	9500.00
0005434980329	23537	Economy	9500.00
0005434980301	23537	Economy	9500.00
0005434980353	23537	Economy	9500.00
0005434980360	23537	Economy	9500.00
0005434980299	23537	Economy	9500.00
0005434980371	23537	Economy	9500.00
0005434980369	23537	Economy	9500.00
0005434980302	23537	Economy	9500.00
0005434980429	23537	Economy	9500.00
0005434980370	23537	Economy	9500.00
0005434980388	23537	Economy	9500.00
0005434980428	23537	Economy	9500.00
0005433256466	2604	Economy	5300.00
0005433256489	28206	Economy	5300.00
0005433256490	28206	Economy	5300.00
0005433112422	19785	Economy	8700.00
0005434302882	19785	Economy	8700.00
0005434302883	19785	Economy	8700.00
0005434302881	19785	Economy	8700.00
0005433112421	19785	Economy	8700.00
0005434140159	11933	Business	9700.00
0005434139960	11933	Business	9700.00
0005434139935	11933	Business	9700.00
0005434139761	11933	Business	9700.00
0005434139877	11933	Business	9700.00
0005434139653	11933	Business	9700.00
0005434139396	11933	Business	9700.00
0005434139936	11933	Business	9700.00
0005435283572	11933	Business	9700.00
0005434139634	11933	Business	9700.00
0005434140199	11933	Business	9700.00
0005434139949	11933	Business	9700.00
0005434140033	11933	Economy	3200.00
0005434139715	11933	Economy	3200.00
0005434139780	11933	Economy	3200.00
0005434139834	11933	Economy	3200.00
0005434139884	11933	Economy	3200.00
0005434139537	11933	Economy	3200.00
0005434139855	11933	Economy	3200.00
0005434139792	11933	Economy	3200.00
0005434139956	11933	Economy	3200.00
0005434139853	11933	Economy	3200.00
0005434139975	11933	Economy	3500.00
0005434139980	11933	Economy	3500.00
0005434139658	11933	Economy	3500.00
0005434140002	11933	Economy	3500.00
0005434139796	11933	Economy	3200.00
0005434140149	11933	Economy	3200.00
0005434139984	11933	Economy	3200.00
0005435283571	11933	Economy	3200.00
0005434140095	11933	Economy	3200.00
0005434139986	11933	Economy	3200.00
0005434139844	11933	Economy	3200.00
0005434139876	11933	Economy	3200.00
0005434139985	11933	Economy	3200.00
0005434140198	11933	Economy	3200.00
0005434139917	11933	Economy	3200.00
0005434139957	11933	Economy	3200.00
0005434139845	11933	Economy	3200.00
0005434139657	11933	Economy	3200.00
0005434139864	11933	Economy	3200.00
0005434139779	11933	Economy	3200.00
0005434139683	11933	Economy	3200.00
0005434139846	11933	Economy	3200.00
0005434139913	11933	Economy	3200.00
0005434139783	11933	Economy	3200.00
0005434139914	11933	Economy	3200.00
0005434139674	11933	Economy	3200.00
0005434140013	11933	Economy	3200.00
0005434140028	11933	Economy	3200.00
0005434139388	11933	Economy	3200.00
0005434139900	11933	Economy	3200.00
0005434139684	11933	Economy	3200.00
0005434139538	11933	Economy	3200.00
0005434140027	11933	Economy	3200.00
0005434139552	11933	Economy	3200.00
0005434139922	11933	Economy	3200.00
0005434139907	11933	Economy	3200.00
0005434139797	11933	Economy	3200.00
0005434140106	11933	Economy	3200.00
0005434139687	11933	Economy	3200.00
0005434139979	11933	Economy	3200.00
0005434139901	11933	Economy	3200.00
0005434139932	11933	Economy	3200.00
0005434139685	11933	Economy	3200.00
0005434139832	11933	Economy	3200.00
0005434139738	11933	Economy	3200.00
0005434139784	11933	Economy	3200.00
0005434139790	11933	Economy	3200.00
0005434139854	11933	Economy	3200.00
0005434139762	11933	Economy	3200.00
0005434139549	11933	Economy	3200.00
0005434139675	11933	Economy	3200.00
0005434140160	11933	Economy	3200.00
0005434139837	11933	Economy	3200.00
0005434139686	11933	Economy	3200.00
0005434140107	11933	Economy	3200.00
0005434139637	11933	Economy	3200.00
0005434139836	11933	Economy	3200.00
0005435283573	11933	Economy	3200.00
0005434139982	11933	Economy	3200.00
0005434139833	11933	Economy	3200.00
0005434139619	11933	Economy	3200.00
0005434139948	11933	Economy	3200.00
0005434139947	11933	Economy	3200.00
0005434140497	28740	Business	9700.00
0005434140485	28740	Business	9700.00
0005434140483	28740	Business	9700.00
0005434140472	28740	Business	9700.00
0005434140494	28740	Business	9700.00
0005434140458	28740	Business	9700.00
0005434140469	28740	Business	9700.00
0005434140477	28740	Economy	3200.00
0005434140473	28740	Economy	3200.00
0005434140456	28740	Economy	3200.00
0005434140464	28740	Economy	3200.00
0005434140498	28740	Economy	3200.00
0005434140463	28740	Economy	3500.00
0005434140462	28740	Economy	3500.00
0005434140482	28740	Economy	3200.00
0005434140471	28740	Economy	3200.00
0005434140484	28740	Economy	3200.00
0005434140488	28740	Economy	3200.00
0005434140467	28740	Economy	3200.00
0005434140492	28740	Economy	3200.00
0005434140454	28740	Economy	3200.00
0005434140495	28740	Economy	3200.00
0005434140493	28740	Economy	3200.00
0005434140481	28740	Economy	3200.00
0005434140496	28740	Economy	3200.00
0005434140491	28740	Economy	3200.00
0005434140460	28740	Economy	3200.00
0005434140466	28740	Economy	3200.00
0005434140457	28740	Economy	3200.00
0005434140461	28740	Economy	3200.00
0005434140487	28740	Economy	3200.00
0005434140468	28740	Economy	3200.00
0005434140490	28740	Economy	3200.00
0005434140500	28740	Economy	3200.00
0005434140486	28740	Economy	3200.00
0005434140453	28740	Economy	3200.00
0005434140480	28740	Economy	3200.00
0005435283568	28740	Economy	3200.00
0005434140499	28740	Economy	3200.00
0005434140476	28740	Economy	3200.00
0005434140478	28740	Economy	3200.00
0005434140475	28740	Economy	3200.00
0005434140459	28740	Economy	3200.00
0005434140474	28740	Economy	3200.00
0005434140465	28740	Economy	3200.00
0005434140479	28740	Economy	3200.00
0005434140489	28740	Economy	3200.00
0005434140470	28740	Economy	3200.00
0005434140455	28740	Economy	3200.00
0005434466601	6569	Economy	20900.00
0005434466602	6569	Economy	20900.00
0005435312866	6569	Economy	20900.00
0005434466600	6569	Economy	20900.00
0005434466604	6569	Economy	20900.00
0005434466603	6569	Economy	20900.00
0005434466599	6569	Economy	20900.00
0005434190462	19091	Economy	26000.00
0005434516113	19091	Economy	26000.00
0005434516116	19091	Economy	26000.00
0005434190460	19091	Economy	23600.00
0005434513626	19091	Economy	23600.00
0005434513632	19091	Economy	23600.00
0005434516124	19091	Economy	23600.00
0005434516126	19091	Economy	23600.00
0005434516121	19091	Economy	23600.00
0005434513627	19091	Economy	23600.00
0005434513635	19091	Economy	23600.00
0005434190461	19091	Economy	23600.00
0005434513638	19091	Economy	23600.00
0005434513645	19091	Economy	23600.00
0005434516106	19091	Economy	23600.00
0005434513631	19091	Economy	23600.00
0005434513628	19091	Economy	23600.00
0005434513644	19091	Economy	23600.00
0005434513629	19091	Economy	23600.00
0005434190463	19091	Economy	23600.00
0005434516107	19091	Economy	23600.00
0005434513630	19091	Economy	23600.00
0005433539110	6808	Economy	10900.00
0005433539115	6808	Economy	9900.00
0005433539116	6808	Economy	9900.00
0005435259867	6808	Economy	9900.00
0005435259868	6808	Economy	9900.00
0005433539114	6808	Economy	9900.00
0005435259846	6808	Economy	9900.00
0005433534561	6808	Economy	9900.00
0005435259847	6808	Economy	9900.00
0005433539111	6808	Economy	9900.00
0005433539112	6808	Economy	9900.00
0005433539113	6808	Economy	9900.00
0005435259859	6808	Economy	9900.00
0005435259857	6808	Economy	9900.00
0005435259858	6808	Economy	9900.00
0005435259860	6808	Economy	9900.00
0005433539077	25001	Economy	10900.00
0005433539060	25001	Economy	9900.00
0005435259884	25001	Economy	9900.00
0005433539038	25001	Economy	9900.00
0005433539069	25001	Economy	9900.00
0005433539052	25001	Economy	9900.00
0005435259883	25001	Economy	9900.00
0005433539097	25001	Economy	9900.00
0005433539047	25001	Economy	9900.00
0005433539061	25001	Economy	9900.00
0005433539048	25001	Economy	9900.00
0005433539051	25001	Economy	9900.00
0005433534545	25001	Economy	9900.00
0005432922619	805	Economy	14600.00
0005433512186	805	Economy	14600.00
0005433512184	805	Economy	14600.00
0005433512185	805	Economy	14600.00
0005433512187	805	Economy	14600.00
0005433512188	805	Economy	14600.00
0005433512127	16147	Economy	14600.00
0005433512121	16147	Economy	14600.00
0005433512138	16147	Economy	14600.00
0005433512122	16147	Economy	14600.00
0005433512123	16147	Economy	14600.00
0005433512126	16147	Economy	14600.00
0005433512137	16147	Economy	14600.00
0005433512135	16147	Economy	14600.00
0005433512132	16147	Economy	14600.00
0005433512144	16147	Economy	14600.00
0005435935112	3678	Economy	7900.00
0005435935108	3678	Economy	7900.00
0005435935116	3678	Economy	7900.00
0005435698152	3678	Economy	7200.00
0005435935118	3678	Economy	7200.00
0005435698143	3678	Economy	7200.00
0005434950659	3678	Economy	7200.00
0005435698146	3678	Economy	7200.00
0005435698151	3678	Economy	7200.00
0005435698142	3678	Economy	7200.00
0005435935111	3678	Economy	7200.00
0005435698145	3678	Economy	7200.00
0005435935117	3678	Economy	7200.00
0005435698154	3678	Economy	7200.00
0005435698150	3678	Economy	7200.00
0005434950658	3678	Economy	7200.00
0005435698153	3678	Economy	7200.00
0005435698148	3678	Economy	7200.00
0005435698141	3678	Economy	7200.00
0005435916226	3678	Economy	7200.00
0005435698149	3678	Economy	7200.00
0005435935113	3678	Economy	7200.00
0005435698144	3678	Economy	7200.00
0005435698147	3678	Economy	7200.00
0005435698140	3678	Economy	7200.00
0005435697923	16298	Economy	7900.00
0005435697903	16298	Economy	7900.00
0005434950618	16298	Economy	7900.00
0005435697913	16298	Economy	7200.00
0005435697996	16298	Economy	7200.00
0005435697931	16298	Economy	7200.00
0005435697958	16298	Economy	7200.00
0005435697929	16298	Economy	7200.00
0005435697873	16298	Economy	7200.00
0005435697871	16298	Economy	7200.00
0005435697945	16298	Economy	7200.00
0005435697957	16298	Economy	7200.00
0005435935133	16298	Economy	7200.00
0005435697792	16298	Economy	7200.00
0005435935132	16298	Economy	7200.00
0005434950619	16298	Economy	7200.00
0005435697872	16298	Economy	7200.00
0005435698005	16298	Economy	7200.00
0005435697928	16298	Economy	7200.00
0005435697856	16298	Economy	7200.00
0005435697955	16298	Economy	7200.00
0005435697843	16298	Economy	7200.00
0005434950605	16298	Economy	7200.00
0005435697981	16298	Economy	7200.00
0005435697954	16298	Economy	7200.00
0005434950604	16298	Economy	7200.00
0005435697829	16298	Economy	7200.00
0005435697874	16298	Economy	7200.00
0005435698017	16298	Economy	7200.00
0005435697841	16298	Economy	7200.00
0005435698014	16298	Economy	7200.00
0005435697912	16298	Economy	7200.00
0005434950622	16298	Economy	7200.00
0005435697802	16298	Economy	7200.00
0005435697840	16298	Economy	7200.00
0005435697882	16298	Economy	7200.00
0005435697904	16298	Economy	7200.00
0005435697977	16298	Economy	7200.00
0005434606933	3951	Economy	21300.00
0005435842343	3951	Economy	19300.00
0005435904907	3951	Economy	19300.00
0005435853652	3951	Economy	19300.00
0005435904906	3951	Economy	19300.00
0005435853648	3951	Economy	19300.00
0005434606932	3951	Economy	19300.00
0005435904722	3951	Economy	19300.00
0005433519589	3951	Economy	19300.00
0005433519588	3951	Economy	19300.00
0005432609848	3951	Economy	19300.00
0005434606934	3951	Economy	19300.00
0005433519569	22056	Economy	21300.00
0005435841121	22056	Economy	21300.00
0005435841124	22056	Economy	21300.00
0005432613949	22056	Economy	21300.00
0005435853666	22056	Economy	19300.00
0005432609794	22056	Economy	19300.00
0005432613940	22056	Economy	19300.00
0005435841123	22056	Economy	19300.00
0005435841122	22056	Economy	19300.00
0005432609777	22056	Economy	19300.00
0005432613946	22056	Economy	19300.00
0005432613950	22056	Economy	19300.00
0005432613927	22056	Economy	19300.00
0005435841490	22056	Economy	19300.00
0005432609816	22056	Economy	19300.00
0005435841489	22056	Economy	19300.00
0005432609810	22056	Economy	19300.00
0005435853665	22056	Economy	19300.00
0005432613960	22056	Economy	19300.00
0005435841491	22056	Economy	19300.00
0005432613934	22056	Economy	19300.00
0005435904913	22056	Economy	19300.00
0005435841493	22056	Economy	19300.00
0005434606905	22056	Economy	19300.00
0005435841125	22056	Economy	19300.00
0005432613941	22056	Economy	19300.00
0005435841492	22056	Economy	19300.00
0005433519552	22056	Economy	19300.00
0005432609793	22056	Economy	19300.00
0005433519561	22056	Economy	19300.00
0005432613928	22056	Economy	19300.00
0005432613943	22056	Economy	19300.00
0005435904726	22056	Economy	19300.00
0005432613939	22056	Economy	19300.00
0005432609809	22056	Economy	19300.00
0005435841488	22056	Economy	19300.00
0005432609782	22056	Economy	19300.00
0005432613951	22056	Economy	19300.00
0005435904727	22056	Economy	19300.00
0005432613944	22056	Economy	19300.00
0005435628824	730	Economy	3700.00
0005435628825	730	Economy	3700.00
0005435628822	730	Economy	3700.00
0005433349087	730	Economy	3700.00
0005433349113	730	Economy	3700.00
0005433349118	730	Economy	3700.00
0005433349114	730	Economy	3700.00
0005435628828	730	Economy	3700.00
0005435628826	730	Economy	3700.00
0005435628823	730	Economy	3700.00
0005435628827	730	Economy	3700.00
0005433349162	15987	Economy	3700.00
0005435628797	15987	Economy	3700.00
0005433349160	15987	Economy	3700.00
0005433349161	15987	Economy	3700.00
0005435628786	15987	Economy	3700.00
0005435628787	15987	Economy	3700.00
0005435628796	15987	Economy	3700.00
0005435628785	15987	Economy	3700.00
0005433349159	15987	Economy	3700.00
0005434445316	17174	Economy	7100.00
0005434445318	17174	Economy	7100.00
0005434445319	17174	Economy	7100.00
0005434445320	17174	Economy	7100.00
0005434445317	17174	Economy	7100.00
0005433158167	17174	Economy	7100.00
0005433158169	17174	Economy	7100.00
0005433158177	17174	Economy	7100.00
0005433158174	17174	Economy	7100.00
0005433158175	17174	Economy	7100.00
0005434446587	17174	Economy	7100.00
0005434446586	17174	Economy	7100.00
0005433159376	17627	Economy	7100.00
0005434445302	17627	Economy	7100.00
0005434445300	17627	Economy	7100.00
0005434445299	17627	Economy	7100.00
0005435133188	7892	Economy	5400.00
0005435383281	7892	Economy	5400.00
0005435133187	7892	Economy	5400.00
0005435383280	7892	Economy	5400.00
0005435133185	7892	Economy	5400.00
0005435383250	7892	Economy	5400.00
0005435383255	7892	Economy	5400.00
0005435383265	7892	Economy	5400.00
0005435133186	7892	Economy	5400.00
0005435383251	7892	Economy	5400.00
0005435383256	7892	Economy	5400.00
0005435383257	7892	Economy	5400.00
0005435133133	33112	Economy	5900.00
0005435133145	33112	Economy	5900.00
0005435133141	33112	Economy	5400.00
0005435383305	33112	Economy	5400.00
0005435133117	33112	Economy	5400.00
0005435133099	33112	Economy	5400.00
0005435133097	33112	Economy	5400.00
0005435133113	33112	Economy	5400.00
0005435133158	33112	Economy	5400.00
0005435133116	33112	Economy	5400.00
0005435133098	33112	Economy	5400.00
0005435133115	33112	Economy	5400.00
0005435133132	33112	Economy	5400.00
0005435133129	33112	Economy	5400.00
0005435133114	33112	Economy	5400.00
0005435133157	33112	Economy	5400.00
0005435133134	33112	Economy	5400.00
0005435383306	33112	Economy	5400.00
0005435133144	33112	Economy	5400.00
0005435811222	4406	Business	133200.00
0005435811216	4406	Business	133200.00
0005435811215	4406	Business	133200.00
0005435811218	4406	Business	133200.00
0005435811217	4406	Economy	44400.00
0005435938935	4406	Economy	44400.00
0005435811224	4406	Economy	44400.00
0005435938950	4406	Economy	44400.00
0005435811220	4406	Economy	44400.00
0005435811221	4406	Economy	44400.00
0005435938943	4406	Economy	44400.00
0005435811225	4406	Economy	44400.00
0005435938931	4406	Economy	44400.00
0005435938944	4406	Economy	44400.00
0005435938930	4406	Economy	44400.00
0005435938934	4406	Economy	44400.00
0005435938936	4406	Economy	44400.00
0005435938923	4406	Economy	44400.00
0005435811219	4406	Economy	44400.00
0005435811223	4406	Economy	44400.00
0005435938933	4406	Economy	44400.00
0005435938951	4406	Economy	44400.00
0005435811161	29455	Business	133200.00
0005435938963	29455	Business	133200.00
0005435811163	29455	Business	133200.00
0005435811150	29455	Economy	44400.00
0005435938964	29455	Economy	44400.00
0005435811160	29455	Economy	44400.00
0005435811158	29455	Economy	44400.00
0005435938965	29455	Economy	48800.00
0005435811166	29455	Economy	44400.00
0005435811190	29455	Economy	44400.00
0005435811202	29455	Economy	44400.00
0005435811174	29455	Economy	44400.00
0005435938962	29455	Economy	44400.00
0005435811173	29455	Economy	44400.00
0005435938960	29455	Economy	44400.00
0005435811175	29455	Economy	44400.00
0005435811189	29455	Economy	44400.00
0005435938961	29455	Economy	44400.00
0005435811193	29455	Economy	44400.00
0005435811192	29455	Economy	44400.00
0005435811162	29455	Economy	44400.00
0005435811176	29455	Economy	44400.00
0005435811172	29455	Economy	44400.00
0005435938959	29455	Economy	44400.00
0005435160623	7515	Economy	13800.00
0005435390391	7515	Economy	12500.00
0005435390377	7515	Economy	12500.00
0005435390376	7515	Economy	12500.00
0005435390387	7515	Economy	12500.00
0005435390384	7515	Economy	12500.00
0005435160620	7515	Economy	12500.00
0005435160622	7515	Economy	12500.00
0005435390383	7515	Economy	12500.00
0005435390371	7515	Economy	12500.00
0005435390372	7515	Economy	12500.00
0005435390400	7515	Economy	12500.00
0005435390378	7515	Economy	12500.00
0005435390399	7515	Economy	12500.00
0005435160619	7515	Economy	12500.00
0005435160621	7515	Economy	12500.00
0005435390362	7515	Economy	12500.00
0005435390408	7515	Economy	12500.00
0005435160577	29555	Economy	13800.00
0005435160535	29555	Economy	13800.00
0005435160561	29555	Economy	12500.00
0005435160548	29555	Economy	12500.00
0005435390435	29555	Economy	12500.00
0005435160575	29555	Economy	12500.00
0005435160556	29555	Economy	12500.00
0005435160534	29555	Economy	12500.00
0005435160576	29555	Economy	12500.00
0005435160547	29555	Economy	12500.00
0005432398286	18442	Economy	4900.00
0005432398268	18442	Economy	4900.00
0005432394180	18442	Economy	4900.00
0005432398277	18442	Economy	4900.00
0005432398275	18442	Economy	4900.00
0005432394202	18442	Economy	4900.00
0005432394203	18442	Economy	4900.00
0005432394190	18442	Economy	4900.00
0005432394204	18442	Economy	4900.00
0005432394185	18442	Economy	4900.00
0005435179021	18442	Economy	4900.00
0005432398267	18442	Economy	4900.00
0005435178517	27141	Economy	4900.00
0005435178522	27141	Economy	4900.00
0005432400220	27141	Economy	4900.00
0005432398299	27141	Economy	4900.00
0005432398298	27141	Economy	4900.00
0005432398297	27141	Economy	4900.00
0005432400221	27141	Economy	4900.00
0005435178523	27141	Economy	4900.00
0005432639486	2235	Business	87300.00
0005432639494	2235	Economy	32000.00
0005432639485	2235	Economy	32000.00
0005432639495	2235	Economy	32000.00
0005432639493	2235	Economy	29100.00
0005432866147	2235	Economy	29100.00
0005432866173	2235	Economy	29100.00
0005432639484	2235	Economy	29100.00
0005432639481	2235	Economy	29100.00
0005432866148	2235	Economy	29100.00
0005432639478	2235	Economy	29100.00
0005432639491	2235	Economy	29100.00
0005432866165	2235	Economy	29100.00
0005432639490	2235	Economy	29100.00
0005432866172	2235	Economy	29100.00
0005432639477	2235	Economy	29100.00
0005432639482	2235	Economy	29100.00
0005432639489	2235	Economy	29100.00
0005432866141	2235	Economy	29100.00
0005432639476	2235	Economy	29100.00
0005432639492	2235	Economy	29100.00
0005432866164	2235	Economy	29100.00
0005432866166	2235	Economy	29100.00
0005432866142	2235	Economy	29100.00
0005432639483	2235	Economy	29100.00
0005432866149	2235	Economy	29100.00
0005432639479	2235	Economy	29100.00
0005432639480	2235	Economy	29100.00
0005432639487	2235	Economy	29100.00
0005432639488	2235	Economy	29100.00
0005434552912	9707	Economy	4400.00
0005434552914	9707	Economy	4400.00
0005434552915	9707	Economy	4400.00
0005434552913	9707	Economy	4400.00
0005434552911	9707	Economy	4400.00
0005434505288	6542	Business	48400.00
0005435104338	6542	Business	48400.00
0005434505282	6542	Business	48400.00
0005434505283	6542	Business	48400.00
0005435104336	6542	Economy	16100.00
0005435104327	6542	Economy	16100.00
0005434505276	6542	Economy	16100.00
0005435104342	6542	Economy	16100.00
0005435104319	6542	Economy	17800.00
0005434505284	6542	Economy	17800.00
0005435104321	6542	Economy	17800.00
0005435104340	6542	Economy	17800.00
0005434505273	6542	Economy	16100.00
0005435104320	6542	Economy	16100.00
0005434505281	6542	Economy	16100.00
0005435104322	6542	Economy	16100.00
0005434505272	6542	Economy	16100.00
0005435104324	6542	Economy	16100.00
0005435104337	6542	Economy	16100.00
0005435104331	6542	Economy	16100.00
0005434505286	6542	Economy	16100.00
0005434505271	6542	Economy	16100.00
0005435104318	6542	Economy	16100.00
0005435104335	6542	Economy	16100.00
0005434505277	6542	Economy	16100.00
0005435104325	6542	Economy	16100.00
0005435104332	6542	Economy	16100.00
0005435104330	6542	Economy	16100.00
0005434505289	6542	Economy	16100.00
0005434505279	6542	Economy	16100.00
0005435104333	6542	Economy	16100.00
0005435104326	6542	Economy	16100.00
0005435104329	6542	Economy	16100.00
0005435104334	6542	Economy	16100.00
0005434505275	6542	Economy	16100.00
0005435104339	6542	Economy	16100.00
0005434505285	6542	Economy	16100.00
0005434505280	6542	Economy	16100.00
0005435104341	6542	Economy	16100.00
0005435104323	6542	Economy	16100.00
0005434505274	6542	Economy	16100.00
0005435104328	6542	Economy	16100.00
0005434505287	6542	Economy	16100.00
0005434505278	6542	Economy	16100.00
0005434505028	22644	Business	48400.00
0005434504805	22644	Business	48400.00
0005434504954	22644	Business	48400.00
0005435104069	22644	Business	48400.00
0005434504990	22644	Business	48400.00
0005434504964	22644	Business	48400.00
0005434504870	22644	Economy	16100.00
0005434504800	22644	Economy	17800.00
0005434504765	22644	Economy	17800.00
0005434504921	22644	Economy	16100.00
0005434504911	22644	Economy	16100.00
0005434504910	22644	Economy	16100.00
0005435104052	22644	Economy	16100.00
0005434504903	22644	Economy	16100.00
0005434504944	22644	Economy	16100.00
0005434504799	22644	Economy	16100.00
0005435104041	22644	Economy	16100.00
0005434504803	22644	Economy	16100.00
0005434504796	22644	Economy	16100.00
0005434505027	22644	Economy	16100.00
0005434505041	22644	Economy	16100.00
0005434504894	22644	Economy	16100.00
0005434504885	22644	Economy	16100.00
0005434504879	22644	Economy	16100.00
0005434504806	22644	Economy	16100.00
0005434505109	22644	Economy	16100.00
0005435104014	22644	Economy	16100.00
0005434504913	22644	Economy	16100.00
0005434504878	22644	Economy	16100.00
0005434505040	22644	Economy	16100.00
0005434504722	22644	Economy	16100.00
0005434504884	22644	Economy	16100.00
0005434504933	22644	Economy	16100.00
0005434504804	22644	Economy	16100.00
0005434504815	22644	Economy	16100.00
0005434504871	22644	Economy	16100.00
0005435104051	22644	Economy	16100.00
0005434504814	22644	Economy	16100.00
0005434504930	22644	Economy	16100.00
0005434504953	22644	Economy	16100.00
0005434505158	22644	Economy	16100.00
0005435654416	1670	Business	50000.00
0005433368824	1670	Business	50000.00
0005435654440	1670	Business	50000.00
0005435654421	1670	Business	50000.00
0005435654432	1670	Business	50000.00
0005435654423	1670	Business	50000.00
0005433368772	1670	Business	50000.00
0005433368517	1670	Business	50000.00
0005435654408	1670	Business	50000.00
0005435654425	1670	Business	50000.00
0005433368675	1670	Economy	16700.00
0005433368635	1670	Economy	16700.00
0005435654428	1670	Economy	16700.00
0005433368567	1670	Economy	18300.00
0005433368818	1670	Economy	18300.00
0005435654413	1670	Economy	18300.00
0005435654422	1670	Economy	16700.00
0005433368606	1670	Economy	16700.00
0005433368704	1670	Economy	16700.00
0005435654409	1670	Economy	16700.00
0005435654420	1670	Economy	16700.00
0005435654435	1670	Economy	16700.00
0005435654411	1670	Economy	16700.00
0005433368681	1670	Economy	16700.00
0005435654406	1670	Economy	16700.00
0005433368576	1670	Economy	16700.00
0005435654434	1670	Economy	16700.00
0005435654412	1670	Economy	16700.00
0005435654410	1670	Economy	16700.00
0005435654424	1670	Economy	16700.00
0005433368580	1670	Economy	16700.00
0005435654433	1670	Economy	16700.00
0005433368575	1670	Economy	16700.00
0005435654431	1670	Economy	16700.00
0005435654430	1670	Economy	16700.00
0005435654415	1670	Economy	16700.00
0005435654438	1670	Economy	16700.00
0005433368634	1670	Economy	16700.00
0005435654414	1670	Economy	16700.00
0005435654426	1670	Economy	16700.00
0005433368785	1670	Economy	16700.00
0005433368566	1670	Economy	16700.00
0005433368655	1670	Economy	16700.00
0005435654417	1670	Economy	16700.00
0005433368670	1670	Economy	16700.00
0005433368679	1670	Economy	16700.00
0005433368656	1670	Economy	16700.00
0005433368740	1670	Economy	16700.00
0005435654436	1670	Economy	16700.00
0005435654429	1670	Economy	16700.00
0005435654437	1670	Economy	16700.00
0005433368680	1670	Economy	16700.00
0005433368574	1670	Economy	16700.00
0005433368784	1670	Economy	16700.00
0005435654427	1670	Economy	16700.00
0005435654439	1670	Economy	16700.00
0005433368773	1670	Economy	16700.00
0005435654419	1670	Economy	16700.00
0005435654441	1670	Economy	16700.00
0005435654407	1670	Economy	16700.00
0005435654418	1670	Economy	16700.00
0005433368703	1670	Economy	16700.00
0005433368957	21708	Business	50000.00
0005435653975	21708	Business	50000.00
0005435653912	21708	Business	50000.00
0005435653908	21708	Business	50000.00
0005433368952	21708	Business	50000.00
0005435653973	21708	Business	50000.00
0005433368965	21708	Business	50000.00
0005435653957	21708	Business	50000.00
0005435654102	21708	Business	50000.00
0005435653986	21708	Business	50000.00
0005433368958	21708	Economy	16700.00
0005433368950	21708	Economy	16700.00
0005433368954	21708	Economy	16700.00
0005435653840	21708	Economy	16700.00
0005435654130	21708	Economy	16700.00
0005435653926	21708	Economy	16700.00
0005433368946	21708	Economy	16700.00
0005435653984	21708	Economy	16700.00
0005435653835	21708	Economy	18300.00
0005435654077	21708	Economy	18300.00
0005435653868	21708	Economy	18300.00
0005435653937	21708	Economy	16700.00
0005435654151	21708	Economy	16700.00
0005433368963	21708	Economy	16700.00
0005435653852	21708	Economy	16700.00
0005435654127	21708	Economy	16700.00
0005435654078	21708	Economy	16700.00
0005435653844	21708	Economy	16700.00
0005435653800	21708	Economy	16700.00
0005435654103	21708	Economy	16700.00
0005435654000	21708	Economy	16700.00
0005433368955	21708	Economy	16700.00
0005433368961	21708	Economy	16700.00
0005435653982	21708	Economy	16700.00
0005435653974	21708	Economy	16700.00
0005435653853	21708	Economy	16700.00
0005435653934	21708	Economy	16700.00
0005435653958	21708	Economy	16700.00
0005435653906	21708	Economy	16700.00
0005435653855	21708	Economy	16700.00
0005433368945	21708	Economy	16700.00
0005435654096	21708	Economy	16700.00
0005435653686	21708	Economy	16700.00
0005435653936	21708	Economy	16700.00
0005435653891	21708	Economy	16700.00
0005435653799	21708	Economy	16700.00
0005435654137	21708	Economy	16700.00
0005435654035	21708	Economy	16700.00
0005435654034	21708	Economy	16700.00
0005435653990	21708	Economy	16700.00
0005435653839	21708	Economy	16700.00
0005435653774	21708	Economy	16700.00
0005435653865	21708	Economy	16700.00
0005435654009	21708	Economy	16700.00
0005435653991	21708	Economy	16700.00
0005435653899	21708	Economy	16700.00
0005433368947	21708	Economy	16700.00
0005435653922	21708	Economy	16700.00
0005433368962	21708	Economy	16700.00
0005435654004	21708	Economy	16700.00
0005433368949	21708	Economy	16700.00
0005435654095	21708	Economy	16700.00
0005435653999	21708	Economy	16700.00
0005435654005	21708	Economy	16700.00
0005435653959	21708	Economy	16700.00
0005433368960	21708	Economy	16700.00
0005435654033	21708	Economy	16700.00
0005435654031	21708	Economy	16700.00
0005433368956	21708	Economy	16700.00
0005433368953	21708	Economy	16700.00
0005433368948	21708	Economy	16700.00
0005435653994	21708	Economy	16700.00
0005433368964	21708	Economy	16700.00
0005433368959	21708	Economy	16700.00
0005435653983	21708	Economy	16700.00
0005435653834	21708	Economy	16700.00
0005433368951	21708	Economy	16700.00
0005435654040	21708	Economy	16700.00
0005435627132	12218	Economy	11200.00
0005435627131	12218	Economy	11200.00
0005434466560	23235	Economy	23000.00
0005434466557	23235	Economy	23000.00
0005434466553	23235	Economy	20900.00
0005434466550	23235	Economy	20900.00
0005434466579	23235	Economy	20900.00
0005434466558	23235	Economy	20900.00
0005435312874	23235	Economy	20900.00
0005434466549	23235	Economy	20900.00
0005434466572	23235	Economy	20900.00
0005434466575	23235	Economy	20900.00
0005434466571	23235	Economy	20900.00
0005434466573	23235	Economy	20900.00
0005434466551	23235	Economy	20900.00
0005434466565	23235	Economy	20900.00
0005434466552	23235	Economy	20900.00
0005435312877	23235	Economy	20900.00
0005434466576	23235	Economy	20900.00
0005435312876	23235	Economy	20900.00
0005435312875	23235	Economy	20900.00
0005434466580	23235	Economy	20900.00
0005433987350	4152	Business	21500.00
0005433987319	4152	Economy	7200.00
0005433987349	4152	Economy	7200.00
0005433987330	4152	Economy	7200.00
0005433987339	4152	Economy	7200.00
0005433987321	4152	Economy	7900.00
0005433987334	4152	Economy	7900.00
0005433987324	4152	Economy	7900.00
0005433987336	4152	Economy	7900.00
0005433987318	4152	Economy	7200.00
0005433987325	4152	Economy	7200.00
0005433987327	4152	Economy	7200.00
0005433987326	4152	Economy	7200.00
0005435788843	4152	Economy	7200.00
0005433987344	4152	Economy	7200.00
0005433987343	4152	Economy	7200.00
0005433987329	4152	Economy	7200.00
0005433987323	4152	Economy	7200.00
0005433987338	4152	Economy	7200.00
0005433987331	4152	Economy	7200.00
0005433987335	4152	Economy	7200.00
0005433987347	4152	Economy	7200.00
0005433987317	4152	Economy	7200.00
0005433987345	4152	Economy	7200.00
0005435788842	4152	Economy	7200.00
0005433987315	4152	Economy	7200.00
0005433987340	4152	Economy	7200.00
0005433987328	4152	Economy	7200.00
0005433987333	4152	Economy	7200.00
0005433987337	4152	Economy	7200.00
0005433987316	4152	Economy	7200.00
0005433987342	4152	Economy	7200.00
0005433987348	4152	Economy	7200.00
0005433987332	4152	Economy	7200.00
0005433987320	4152	Economy	7200.00
0005433987322	4152	Economy	7200.00
0005433987346	4152	Economy	7200.00
0005433987341	4152	Economy	7200.00
0005435788828	25660	Business	21500.00
0005433986771	25660	Business	21500.00
0005433986669	25660	Business	21500.00
0005433987027	25660	Business	21500.00
0005433986671	25660	Business	21500.00
0005433986770	25660	Economy	7200.00
0005433986844	25660	Economy	7200.00
0005433986648	25660	Economy	7200.00
0005433986829	25660	Economy	7200.00
0005433986947	25660	Economy	7200.00
0005433987017	25660	Economy	7200.00
0005433986841	25660	Economy	7200.00
0005433986847	25660	Economy	7900.00
0005433986921	25660	Economy	7900.00
0005433986984	25660	Economy	7200.00
0005433986914	25660	Economy	7200.00
0005433986933	25660	Economy	7200.00
0005433986869	25660	Economy	7200.00
0005433986920	25660	Economy	7200.00
0005433986923	25660	Economy	7200.00
0005433986877	25660	Economy	7200.00
0005433986858	25660	Economy	7200.00
0005433986934	25660	Economy	7200.00
0005433986845	25660	Economy	7200.00
0005433986995	25660	Economy	7200.00
0005433986804	25660	Economy	7200.00
0005433987041	25660	Economy	7200.00
0005433986901	25660	Economy	7200.00
0005433986842	25660	Economy	7200.00
0005433986907	25660	Economy	7200.00
0005433986794	25660	Economy	7200.00
0005433986936	25660	Economy	7200.00
0005435788829	25660	Economy	7200.00
0005433986775	25660	Economy	7200.00
0005433986900	25660	Economy	7200.00
0005433986887	25660	Economy	7200.00
0005433986896	25660	Economy	7200.00
0005433986928	25660	Economy	7200.00
0005433986769	25660	Economy	7200.00
0005433986647	25660	Economy	7200.00
0005433987048	25660	Economy	7200.00
0005433986725	25660	Economy	7200.00
0005433986835	25660	Economy	7200.00
0005433986874	25660	Economy	7200.00
0005433986850	25660	Economy	7200.00
0005433987049	25660	Economy	7200.00
0005435788836	25660	Economy	7200.00
0005433986672	25660	Economy	7200.00
0005433986915	25660	Economy	7200.00
0005433986997	25660	Economy	7200.00
0005433986826	25660	Economy	7200.00
0005433986897	25660	Economy	7200.00
0005433986843	25660	Economy	7200.00
0005433986857	25660	Economy	7200.00
0005433987028	25660	Economy	7200.00
0005433463938	19922	Business	201300.00
0005433463935	19922	Business	201300.00
0005433461622	19922	Business	201300.00
0005433461621	19922	Business	201300.00
0005433463929	19922	Economy	67100.00
0005433463937	19922	Economy	67100.00
0005433463930	19922	Economy	67100.00
0005433463927	19922	Economy	67100.00
0005433461613	19922	Economy	67100.00
0005433463940	19922	Economy	67100.00
0005433463931	19922	Economy	67100.00
0005433463928	19922	Economy	67100.00
0005433461619	19922	Economy	67100.00
0005433461618	19922	Economy	67100.00
0005433461626	19922	Economy	67100.00
0005433463934	19922	Economy	67100.00
0005433463926	19922	Economy	67100.00
0005433463936	19922	Economy	67100.00
0005433461625	19922	Economy	73800.00
0005433463932	19922	Economy	73800.00
0005433461624	19922	Economy	67100.00
0005433461599	19922	Economy	67100.00
0005433461616	19922	Economy	67100.00
0005433461620	19922	Economy	67100.00
0005433463941	19922	Economy	67100.00
0005433461615	19922	Economy	67100.00
0005433461614	19922	Economy	67100.00
0005433461612	19922	Economy	67100.00
0005433461623	19922	Economy	67100.00
0005435719588	21282	Economy	10400.00
0005435720848	21282	Economy	9400.00
0005435720843	21282	Economy	9400.00
0005435720847	21282	Economy	9400.00
0005435719589	21282	Economy	9400.00
0005435719602	24773	Economy	9400.00
0005435720166	24773	Economy	9400.00
0005434509370	1625	Economy	17000.00
0005433168457	1625	Economy	17000.00
0005433168452	1625	Economy	17000.00
0005434509371	1625	Economy	17000.00
0005433168454	1625	Economy	15500.00
0005433168450	1625	Economy	15500.00
0005434509372	1625	Economy	15500.00
0005433168479	1625	Economy	15500.00
0005434509364	1625	Economy	15500.00
0005433168458	1625	Economy	15500.00
0005433168453	1625	Economy	15500.00
0005434509369	1625	Economy	15500.00
0005434509361	1625	Economy	15500.00
0005434509373	1625	Economy	15500.00
0005433168472	1625	Economy	15500.00
0005434509366	1625	Economy	15500.00
0005433168481	1625	Economy	15500.00
0005433168447	1625	Economy	15500.00
0005434509360	1625	Economy	15500.00
0005434509363	1625	Economy	15500.00
0005433168449	1625	Economy	15500.00
0005433168436	1625	Economy	15500.00
0005433168462	1625	Economy	15500.00
0005433168456	1625	Economy	15500.00
0005433168464	1625	Economy	15500.00
0005433168455	1625	Economy	15500.00
0005433168446	1625	Economy	15500.00
0005434509362	1625	Economy	15500.00
0005434509367	1625	Economy	15500.00
0005434509365	1625	Economy	15500.00
0005434509368	1625	Economy	15500.00
0005433168434	1625	Economy	15500.00
0005432663082	17822	Business	18000.00
0005432665322	17822	Business	18000.00
0005432655757	17822	Business	18000.00
0005432869717	17822	Business	18000.00
0005432655784	17822	Business	18000.00
0005432663081	17822	Business	18000.00
0005432655815	17822	Economy	6000.00
0005432655805	17822	Economy	6000.00
0005432655789	17822	Economy	6000.00
0005432658637	17822	Economy	6000.00
0005432661974	17822	Economy	6000.00
0005432665323	17822	Economy	6000.00
0005432869718	17822	Economy	6600.00
0005432664186	17822	Economy	6600.00
0005432664175	17822	Economy	6600.00
0005432659755	17822	Economy	6000.00
0005432869719	17822	Economy	6000.00
0005432660863	17822	Economy	6000.00
0005432655814	17822	Economy	6000.00
0005432660865	17822	Economy	6000.00
0005434151792	17822	Economy	6000.00
0005432655802	17822	Economy	6000.00
0005432660862	17822	Economy	6000.00
0005432657507	17822	Economy	6000.00
0005432655779	17822	Economy	6000.00
0005432657502	17822	Economy	6000.00
0005432661968	17822	Economy	6000.00
0005432663075	17822	Economy	6000.00
0005432655728	17822	Economy	6000.00
0005432655760	17822	Economy	6000.00
0005432664185	17822	Economy	6000.00
0005432667498	17822	Economy	6000.00
0005432661973	17822	Economy	6000.00
0005432869720	17822	Economy	6000.00
0005432661972	17822	Economy	6000.00
0005432657508	17822	Economy	6000.00
0005432660864	17822	Economy	6000.00
0005432655801	17822	Economy	6000.00
0005432655726	17822	Economy	6000.00
0005432655798	17822	Economy	6000.00
0005432655756	17822	Economy	6000.00
0005432661971	17822	Economy	6000.00
0005432659748	17822	Economy	6000.00
0005432658641	17822	Economy	6000.00
0005434151791	17822	Economy	6000.00
0005432667499	17822	Economy	6000.00
0005432661967	17822	Economy	6000.00
0005432655729	17822	Economy	6000.00
0005432655803	17822	Economy	6000.00
0005432660867	17822	Economy	6000.00
0005432655796	17822	Economy	6000.00
0005432659756	17822	Economy	6000.00
0005432655869	26327	Business	18000.00
0005432663087	26327	Business	18000.00
0005432664197	26327	Business	18000.00
0005432663091	26327	Business	18000.00
0005432655867	26327	Business	18000.00
0005432663093	26327	Business	18000.00
0005432660879	26327	Business	18000.00
0005432666446	26327	Business	18000.00
0005432663096	26327	Business	18000.00
0005432661982	26327	Economy	6000.00
0005432663097	26327	Economy	6000.00
0005432655860	26327	Economy	6000.00
0005432655868	26327	Economy	6000.00
0005432655862	26327	Economy	6000.00
0005432661986	26327	Economy	6000.00
0005432661983	26327	Economy	6000.00
0005432655863	26327	Economy	6000.00
0005432664200	26327	Economy	6600.00
0005434151770	26327	Economy	6600.00
0005432667514	26327	Economy	6600.00
0005432655861	26327	Economy	6600.00
0005432661988	26327	Economy	6000.00
0005432660877	26327	Economy	6000.00
0005432661987	26327	Economy	6000.00
0005432664196	26327	Economy	6000.00
0005432664199	26327	Economy	6000.00
0005432661984	26327	Economy	6000.00
0005432664189	26327	Economy	6000.00
0005432664192	26327	Economy	6000.00
0005432664198	26327	Economy	6000.00
0005432664195	26327	Economy	6000.00
0005432663089	26327	Economy	6000.00
0005432660878	26327	Economy	6000.00
0005432663088	26327	Economy	6000.00
0005432666445	26327	Economy	6000.00
0005432661981	26327	Economy	6000.00
0005432655864	26327	Economy	6000.00
0005432661975	26327	Economy	6000.00
0005432661979	26327	Economy	6000.00
0005432661977	26327	Economy	6000.00
0005432664191	26327	Economy	6000.00
0005432657536	26327	Economy	6000.00
0005432663100	26327	Economy	6000.00
0005432663099	26327	Economy	6000.00
0005432663090	26327	Economy	6000.00
0005432655866	26327	Economy	6000.00
0005432655865	26327	Economy	6000.00
0005432663095	26327	Economy	6000.00
0005432663092	26327	Economy	6000.00
0005432666444	26327	Economy	6000.00
0005432667513	26327	Economy	6000.00
0005432661976	26327	Economy	6000.00
0005432664188	26327	Economy	6000.00
0005432663086	26327	Economy	6000.00
0005432664190	26327	Economy	6000.00
0005432661980	26327	Economy	6000.00
0005432660880	26327	Economy	6000.00
0005432663094	26327	Economy	6000.00
0005432657537	26327	Economy	6000.00
0005432664193	26327	Economy	6000.00
0005432661985	26327	Economy	6000.00
0005432661978	26327	Economy	6000.00
0005432664194	26327	Economy	6000.00
0005432657535	26327	Economy	6000.00
0005432869631	26327	Economy	6000.00
0005432663098	26327	Economy	6000.00
0005432639439	25072	Business	87300.00
0005432639347	25072	Business	87300.00
0005432639345	25072	Business	87300.00
0005432639393	25072	Business	87300.00
0005432639367	25072	Business	87300.00
0005432866206	25072	Business	87300.00
0005432639309	25072	Business	87300.00
0005432639432	25072	Business	87300.00
0005432639334	25072	Economy	29100.00
0005432639442	25072	Economy	29100.00
0005432639365	25072	Economy	29100.00
0005432866213	25072	Economy	29100.00
0005432866209	25072	Economy	29100.00
0005432866212	25072	Economy	29100.00
0005432639448	25072	Economy	29100.00
0005432639337	25072	Economy	32000.00
0005432639370	25072	Economy	32000.00
0005432866218	25072	Economy	29100.00
0005432866217	25072	Economy	29100.00
0005432639394	25072	Economy	29100.00
0005432639311	25072	Economy	29100.00
0005432639392	25072	Economy	29100.00
0005432639433	25072	Economy	29100.00
0005432639447	25072	Economy	29100.00
0005432639373	25072	Economy	29100.00
0005432639349	25072	Economy	29100.00
0005432639438	25072	Economy	29100.00
0005432639361	25072	Economy	29100.00
0005432639310	25072	Economy	29100.00
0005432639405	25072	Economy	29100.00
0005432639346	25072	Economy	29100.00
0005432639368	25072	Economy	29100.00
0005432866207	25072	Economy	29100.00
0005432639338	25072	Economy	29100.00
0005432639413	25072	Economy	29100.00
0005432639364	25072	Economy	29100.00
0005432639360	25072	Economy	29100.00
0005432866211	25072	Economy	29100.00
0005432639431	25072	Economy	29100.00
0005432866214	25072	Economy	29100.00
0005432866215	25072	Economy	29100.00
0005432866208	25072	Economy	29100.00
0005432866210	25072	Economy	29100.00
0005432639374	25072	Economy	29100.00
0005432639362	25072	Economy	29100.00
0005432639348	25072	Economy	29100.00
0005432866216	25072	Economy	29100.00
0005432848879	3081	Business	16100.00
0005432330007	3081	Business	16100.00
0005432287337	3081	Business	16100.00
0005432848867	3081	Business	16100.00
0005432330021	3081	Economy	5400.00
0005432330020	3081	Economy	5400.00
0005432330010	3081	Economy	5400.00
0005432330012	3081	Economy	5900.00
0005433439098	3081	Economy	5400.00
0005432330017	3081	Economy	5400.00
0005433439113	3081	Economy	5400.00
0005432330002	3081	Economy	5400.00
0005432330009	3081	Economy	5400.00
0005432330018	3081	Economy	5400.00
0005433439100	3081	Economy	5400.00
0005432330013	3081	Economy	5400.00
0005432330011	3081	Economy	5400.00
0005432287336	3081	Economy	5400.00
0005432848898	3081	Economy	5400.00
0005432330000	3081	Economy	5400.00
0005432330023	3081	Economy	5400.00
0005432905249	3081	Economy	5400.00
0005432330006	3081	Economy	5400.00
0005433439097	3081	Economy	5400.00
0005432330019	3081	Economy	5400.00
0005433439099	3081	Economy	5400.00
0005432330025	3081	Economy	5400.00
0005432330008	3081	Economy	5400.00
0005432330001	3081	Economy	5400.00
0005432848869	3081	Economy	5400.00
0005432848897	3081	Economy	5400.00
0005432848876	3081	Economy	5400.00
0005432330014	3081	Economy	5400.00
0005432330015	3081	Economy	5400.00
0005432848875	3081	Economy	5400.00
0005432329999	3081	Economy	5400.00
0005432287334	3081	Economy	5400.00
0005432330022	3081	Economy	5400.00
0005432330024	3081	Economy	5400.00
0005432330016	3081	Economy	5400.00
0005432330003	3081	Economy	5400.00
0005432330004	3081	Economy	5400.00
0005432287335	3081	Economy	5400.00
0005432330005	3081	Economy	5400.00
0005432329631	31142	Business	16100.00
0005432329725	31142	Business	16100.00
0005433439016	31142	Business	16100.00
0005432329682	31142	Business	16100.00
0005432329618	31142	Business	16100.00
0005432329684	31142	Economy	5400.00
0005432329842	31142	Economy	5400.00
0005432329818	31142	Economy	5400.00
0005433439011	31142	Economy	5400.00
0005432329617	31142	Economy	5400.00
0005432329557	31142	Economy	5400.00
0005432329704	31142	Economy	5400.00
0005432329608	31142	Economy	5400.00
0005432329609	31142	Economy	5900.00
0005432329723	31142	Economy	5900.00
0005432329727	31142	Economy	5900.00
0005432329493	31142	Economy	5900.00
0005432329644	31142	Economy	5400.00
0005433439013	31142	Economy	5400.00
0005432329703	31142	Economy	5400.00
0005433439026	31142	Economy	5400.00
0005432905289	31142	Economy	5400.00
0005432329445	31142	Economy	5400.00
0005433439014	31142	Economy	5400.00
0005432329587	31142	Economy	5400.00
0005432329632	31142	Economy	5400.00
0005432329639	31142	Economy	5400.00
0005433439012	31142	Economy	5400.00
0005432329630	31142	Economy	5400.00
0005432329638	31142	Economy	5400.00
0005432329724	31142	Economy	5400.00
0005432329494	31142	Economy	5400.00
0005433438975	31142	Economy	5400.00
0005432329622	31142	Economy	5400.00
0005432329607	31142	Economy	5400.00
0005432329538	31142	Economy	5400.00
0005432329742	31142	Economy	5400.00
0005432329443	31142	Economy	5400.00
0005432329530	31142	Economy	5400.00
0005432329520	31142	Economy	5400.00
0005432329683	31142	Economy	5400.00
0005432329734	31142	Economy	5400.00
0005433439025	31142	Economy	5400.00
0005433439002	31142	Economy	5400.00
0005433438990	31142	Economy	5400.00
0005432329580	31142	Economy	5400.00
0005432329444	31142	Economy	5400.00
0005432329586	31142	Economy	5400.00
0005432329519	31142	Economy	5400.00
0005432905288	31142	Economy	5400.00
0005432329726	31142	Economy	5400.00
0005432329610	31142	Economy	5400.00
0005432329645	31142	Economy	5400.00
0005432329606	31142	Economy	5400.00
0005432329550	31142	Economy	5400.00
0005432329636	31142	Economy	5400.00
0005433439015	31142	Economy	5400.00
0005432329809	31142	Economy	5400.00
0005435297222	6225	Business	124600.00
0005434310132	6225	Business	124600.00
0005435999832	6225	Business	124600.00
0005434310136	6225	Business	124600.00
0005435488321	6225	Business	124600.00
0005435999834	6225	Economy	41500.00
0005435999829	6225	Economy	41500.00
0005435999820	6225	Economy	41500.00
0005435999838	6225	Economy	41500.00
0005435297204	6225	Economy	41500.00
0005435488289	6225	Economy	41500.00
0005435488253	6225	Economy	41500.00
0005434310135	6225	Economy	41500.00
0005435999828	6225	Economy	41500.00
0005435488330	6225	Economy	41500.00
0005435999830	6225	Economy	41500.00
0005435999817	6225	Economy	41500.00
0005435999823	6225	Economy	41500.00
0005435297174	6225	Economy	41500.00
0005435488309	6225	Economy	41500.00
0005435488331	6225	Economy	41500.00
0005434310134	6225	Economy	41500.00
0005435999835	6225	Economy	41500.00
0005434310133	6225	Economy	41500.00
0005435297188	6225	Economy	45700.00
0005435999819	6225	Economy	41500.00
0005432146258	6225	Economy	41500.00
0005435999840	6225	Economy	41500.00
0005435297170	6225	Economy	41500.00
0005435297203	6225	Economy	41500.00
0005435999831	6225	Economy	41500.00
0005435999816	6225	Economy	41500.00
0005435999822	6225	Economy	41500.00
0005435488266	6225	Economy	41500.00
0005435999837	6225	Economy	41500.00
0005434310131	6225	Economy	41500.00
0005435297197	6225	Economy	41500.00
0005435297173	6225	Economy	41500.00
0005435999825	6225	Economy	41500.00
0005435999821	6225	Economy	41500.00
0005435999826	6225	Economy	41500.00
0005435999836	6225	Economy	41500.00
0005435999818	6225	Economy	41500.00
0005435488211	6225	Economy	41500.00
0005435297189	6225	Economy	41500.00
0005435999824	6225	Economy	41500.00
0005435488322	6225	Economy	41500.00
0005435488249	6225	Economy	41500.00
0005435999827	6225	Economy	41500.00
0005435488263	6225	Economy	41500.00
0005435488314	6225	Economy	41500.00
0005435999833	6225	Economy	41500.00
0005435297190	6225	Economy	41500.00
0005435488171	6225	Economy	41500.00
0005435297198	6225	Economy	41500.00
0005435999839	6225	Economy	41500.00
0005435488449	19548	Business	124600.00
0005435999631	19548	Business	124600.00
0005435999624	19548	Business	124600.00
0005435297258	19548	Business	124600.00
0005435488439	19548	Business	124600.00
0005435488451	19548	Business	124600.00
0005435488441	19548	Economy	41500.00
0005435999611	19548	Economy	41500.00
0005434310005	19548	Economy	41500.00
0005434310004	19548	Economy	41500.00
0005435999608	19548	Economy	41500.00
0005435999510	19548	Economy	41500.00
0005435999612	19548	Economy	41500.00
0005435999517	19548	Economy	41500.00
0005435488442	19548	Economy	41500.00
0005435999605	19548	Economy	41500.00
0005435488440	19548	Economy	41500.00
0005435999606	19548	Economy	41500.00
0005435488443	19548	Economy	41500.00
0005435999602	19548	Economy	41500.00
0005435999607	19548	Economy	41500.00
0005435999601	19548	Economy	41500.00
0005435999589	19548	Economy	41500.00
0005435297256	19548	Economy	41500.00
0005434309988	19548	Economy	41500.00
0005435297260	19548	Economy	45700.00
0005434310021	19548	Economy	45700.00
0005434310048	19548	Economy	45700.00
0005435488444	19548	Economy	45700.00
0005435488447	19548	Economy	41500.00
0005434310074	19548	Economy	41500.00
0005434310096	19548	Economy	41500.00
0005435999560	19548	Economy	41500.00
0005435999627	19548	Economy	41500.00
0005435488452	19548	Economy	41500.00
0005435999551	19548	Economy	41500.00
0005435488448	19548	Economy	41500.00
0005435999628	19548	Economy	41500.00
0005434310031	19548	Economy	41500.00
0005435297259	19548	Economy	41500.00
0005434310022	19548	Economy	41500.00
0005435488446	19548	Economy	41500.00
0005435999588	19548	Economy	41500.00
0005435999559	19548	Economy	41500.00
0005435999625	19548	Economy	41500.00
0005434309989	19548	Economy	41500.00
0005435999637	19548	Economy	41500.00
0005434309991	19548	Economy	41500.00
0005435999610	19548	Economy	41500.00
0005434309990	19548	Economy	41500.00
0005435999615	19548	Economy	41500.00
0005434310038	19548	Economy	41500.00
0005435999629	19548	Economy	41500.00
0005435488445	19548	Economy	41500.00
0005435297257	19548	Economy	41500.00
0005435488450	19548	Economy	41500.00
0005433158195	17538	Economy	13600.00
0005434446570	17538	Economy	13600.00
0005434446571	17538	Economy	12300.00
0005434446565	17538	Economy	12300.00
0005434446561	17538	Economy	12300.00
0005434446566	17538	Economy	12300.00
0005434446569	17538	Economy	12300.00
0005432292001	1591	Business	86000.00
0005433186351	1591	Business	86000.00
0005433186306	1591	Business	86000.00
0005432291999	1591	Business	86000.00
0005435502938	1591	Business	86000.00
0005433186314	1591	Business	86000.00
0005435502945	1591	Business	86000.00
0005432292002	1591	Economy	28700.00
0005433186280	1591	Economy	28700.00
0005435508808	1591	Economy	28700.00
0005435518437	1591	Economy	28700.00
0005435518439	1591	Economy	31500.00
0005434566293	1591	Economy	31500.00
0005433186315	1591	Economy	28700.00
0005435518442	1591	Economy	28700.00
0005435502944	1591	Economy	28700.00
0005435518440	1591	Economy	28700.00
0005434566297	1591	Economy	28700.00
0005434566300	1591	Economy	28700.00
0005435508806	1591	Economy	28700.00
0005435518438	1591	Economy	28700.00
0005433186333	1591	Economy	28700.00
0005433186328	1591	Economy	28700.00
0005435508804	1591	Economy	28700.00
0005435502939	1591	Economy	28700.00
0005435508805	1591	Economy	28700.00
0005435502941	1591	Economy	28700.00
0005434566298	1591	Economy	28700.00
0005434566301	1591	Economy	28700.00
0005434566296	1591	Economy	28700.00
0005435502940	1591	Economy	28700.00
0005435518436	1591	Economy	28700.00
0005435518444	1591	Economy	28700.00
0005433186326	1591	Economy	28700.00
0005434566294	1591	Economy	28700.00
0005435508811	1591	Economy	28700.00
0005434566302	1591	Economy	28700.00
0005433186307	1591	Economy	28700.00
0005434566295	1591	Economy	28700.00
0005435508810	1591	Economy	28700.00
0005435518441	1591	Economy	28700.00
0005435502946	1591	Economy	28700.00
0005435502943	1591	Economy	28700.00
0005435502937	1591	Economy	28700.00
0005435518443	1591	Economy	28700.00
0005435508809	1591	Economy	28700.00
0005435502942	1591	Economy	28700.00
0005433186279	1591	Economy	28700.00
0005434566299	1591	Economy	28700.00
0005432292000	1591	Economy	28700.00
0005433186263	1591	Economy	28700.00
0005435508813	1591	Economy	28700.00
0005435508812	1591	Economy	28700.00
0005433186332	1591	Economy	28700.00
0005434566303	1591	Economy	28700.00
0005435508807	1591	Economy	28700.00
0005434566213	20891	Business	86000.00
0005435529691	20891	Business	86000.00
0005434566229	20891	Business	86000.00
0005435502677	20891	Business	86000.00
0005433186364	20891	Business	86000.00
0005435502737	20891	Business	86000.00
0005435529626	20891	Economy	28700.00
0005433186363	20891	Economy	28700.00
0005435545875	20891	Economy	28700.00
0005435529742	20891	Economy	28700.00
0005435502740	20891	Economy	28700.00
0005435529647	20891	Economy	28700.00
0005435529704	20891	Economy	28700.00
0005435502835	20891	Economy	31500.00
0005434566161	20891	Economy	31500.00
0005434566190	20891	Economy	31500.00
0005435529739	20891	Economy	31500.00
0005435545868	20891	Economy	28700.00
0005435529690	20891	Economy	28700.00
0005433186369	20891	Economy	28700.00
0005435529705	20891	Economy	28700.00
0005435529627	20891	Economy	28700.00
0005434566174	20891	Economy	28700.00
0005435529646	20891	Economy	28700.00
0005435529670	20891	Economy	28700.00
0005435529740	20891	Economy	28700.00
0005434566209	20891	Economy	28700.00
0005434566232	20891	Economy	28700.00
0005434566192	20891	Economy	28700.00
0005435545902	20891	Economy	28700.00
0005434566197	20891	Economy	28700.00
0005435502755	20891	Economy	28700.00
0005435502756	20891	Economy	28700.00
0005435502851	20891	Economy	28700.00
0005434566228	20891	Economy	28700.00
0005435502806	20891	Economy	28700.00
0005435529638	20891	Economy	28700.00
0005435502778	20891	Economy	28700.00
0005434566211	20891	Economy	28700.00
0005435529625	20891	Economy	28700.00
0005435529661	20891	Economy	28700.00
0005434566227	20891	Economy	28700.00
0005435529732	20891	Economy	28700.00
0005433186368	20891	Economy	28700.00
0005435529624	20891	Economy	28700.00
0005434566186	20891	Economy	28700.00
0005434566187	20891	Economy	28700.00
0005434566191	20891	Economy	28700.00
0005435529692	20891	Economy	28700.00
0005435502795	20891	Economy	28700.00
0005435502805	20891	Economy	28700.00
0005433186366	20891	Economy	28700.00
0005433186367	20891	Economy	28700.00
0005434566173	20891	Economy	28700.00
0005435502707	20891	Economy	28700.00
0005433186365	20891	Economy	28700.00
0005435529660	20891	Economy	28700.00
0005434566175	20891	Economy	28700.00
0005435529650	20891	Economy	28700.00
0005435529753	20891	Economy	28700.00
0005435529733	20891	Economy	28700.00
0005435502739	20891	Economy	28700.00
0005435529668	20891	Economy	28700.00
0005435502836	20891	Economy	28700.00
0005435502689	20891	Economy	28700.00
0005435545901	20891	Economy	28700.00
0005434566210	20891	Economy	28700.00
0005434566149	20891	Economy	28700.00
0005435502811	20891	Economy	28700.00
0005434566215	20891	Economy	28700.00
0005435529743	20891	Economy	28700.00
0005435502676	20891	Economy	28700.00
0005434566171	20891	Economy	28700.00
0005435931681	3903	Economy	21600.00
0005435931678	3903	Economy	21600.00
0005435153938	3903	Economy	21600.00
0005435153934	3903	Economy	19700.00
0005435931676	3903	Economy	19700.00
0005435931674	3903	Economy	19700.00
0005435143002	3903	Economy	19700.00
0005435931677	3903	Economy	19700.00
0005435931691	3903	Economy	19700.00
0005435153935	3903	Economy	19700.00
0005435931682	3903	Economy	19700.00
0005435143001	3903	Economy	19700.00
0005435153937	3903	Economy	19700.00
0005435931673	3903	Economy	19700.00
0005435143003	3903	Economy	19700.00
0005435931669	3903	Economy	19700.00
0005435153936	3903	Economy	19700.00
0005435153867	21893	Economy	21600.00
0005435153891	21893	Economy	21600.00
0005434230049	21893	Economy	19700.00
0005435931709	21893	Economy	19700.00
0005434230047	21893	Economy	19700.00
0005434230046	21893	Economy	19700.00
0005435153868	21893	Economy	19700.00
0005435153890	21893	Economy	19700.00
0005434230048	21893	Economy	19700.00
0005432629277	7172	Economy	14300.00
0005432629279	7172	Economy	13000.00
0005435225772	7172	Economy	13000.00
0005435225760	7172	Economy	13000.00
0005432629274	7172	Economy	13000.00
0005432629276	7172	Economy	13000.00
0005432629275	7172	Economy	13000.00
0005432629283	7172	Economy	13000.00
0005432629272	7172	Economy	13000.00
0005432629280	7172	Economy	13000.00
0005432629281	7172	Economy	13000.00
0005435225770	7172	Economy	13000.00
0005432629273	7172	Economy	13000.00
0005435225757	7172	Economy	13000.00
0005432629278	7172	Economy	13000.00
0005432629282	7172	Economy	13000.00
0005435225759	7172	Economy	13000.00
0005432629194	28137	Economy	13000.00
0005432629144	28137	Economy	13000.00
0005432629162	28137	Economy	13000.00
0005435225808	28137	Economy	13000.00
0005435225809	28137	Economy	13000.00
0005432629199	28137	Economy	13000.00
0005432629163	28137	Economy	13000.00
0005432629203	28137	Economy	13000.00
0005432629206	28137	Economy	13000.00
0005432629097	28137	Economy	13000.00
0005432629122	28137	Economy	13000.00
0005432629121	28137	Economy	13000.00
0005432629222	28137	Economy	13000.00
0005432629219	28137	Economy	13000.00
0005432629184	28137	Economy	13000.00
0005432629196	28137	Economy	13000.00
0005432629145	28137	Economy	13000.00
0005435225807	28137	Economy	13000.00
0005432629176	28137	Economy	13000.00
0005432629146	28137	Economy	13000.00
0005432629175	28137	Economy	13000.00
0005432629098	28137	Economy	13000.00
0005434268025	8771	Economy	11500.00
0005435960161	8771	Economy	10500.00
0005434268032	8771	Economy	10500.00
0005434268026	8771	Economy	10500.00
0005434268036	8771	Economy	10500.00
0005435960162	8771	Economy	10500.00
0005435960132	15231	Economy	11500.00
0005435477009	15231	Economy	10500.00
0005434268060	15231	Economy	10500.00
0005434268059	15231	Economy	10500.00
0005435960131	15231	Economy	10500.00
0005434268057	15231	Economy	10500.00
0005435960138	15231	Economy	10500.00
0005435960137	15231	Economy	10500.00
0005435960147	15231	Economy	10500.00
0005435939980	15231	Economy	10500.00
0005434268058	15231	Economy	10500.00
0005435939979	15231	Economy	10500.00
0005432693937	1200	Business	115000.00
0005432873447	1200	Business	115000.00
0005432873435	1200	Business	115000.00
0005432873451	1200	Business	115000.00
0005432677686	1200	Business	115000.00
0005432675569	1200	Business	115000.00
0005432693930	1200	Business	115000.00
0005432693926	1200	Economy	38300.00
0005432693936	1200	Economy	38300.00
0005432873434	1200	Economy	42200.00
0005432693925	1200	Economy	42200.00
0005432693940	1200	Economy	38300.00
0005432873446	1200	Economy	38300.00
0005432675570	1200	Economy	38300.00
0005432693929	1200	Economy	38300.00
0005432693927	1200	Economy	38300.00
0005432693943	1200	Economy	38300.00
0005432873433	1200	Economy	38300.00
0005432693933	1200	Economy	38300.00
0005432675574	1200	Economy	38300.00
0005432873464	1200	Economy	38300.00
0005432675573	1200	Economy	38300.00
0005432675571	1200	Economy	38300.00
0005432675576	1200	Economy	38300.00
0005432873475	1200	Economy	38300.00
0005432693932	1200	Economy	38300.00
0005432693941	1200	Economy	38300.00
0005432873474	1200	Economy	38300.00
0005432693942	1200	Economy	38300.00
0005432693934	1200	Economy	38300.00
0005432693935	1200	Economy	38300.00
0005432873473	1200	Economy	38300.00
0005432675567	1200	Economy	38300.00
0005432693928	1200	Economy	38300.00
0005432693938	1200	Economy	38300.00
0005432693939	1200	Economy	38300.00
0005432675566	1200	Economy	38300.00
0005432873416	1200	Economy	38300.00
0005432675568	1200	Economy	38300.00
0005432675575	1200	Economy	38300.00
0005432675572	1200	Economy	38300.00
0005432693931	1200	Economy	38300.00
0005432873432	1200	Economy	38300.00
0005432675378	17506	Business	115000.00
0005432693748	17506	Business	115000.00
0005432693621	17506	Business	115000.00
0005432675390	17506	Business	115000.00
0005432693586	17506	Business	115000.00
0005432693753	17506	Business	115000.00
0005432693762	17506	Business	115000.00
0005432675554	17506	Business	115000.00
0005432693706	17506	Business	115000.00
0005432693623	17506	Business	115000.00
0005432693722	17506	Economy	38300.00
0005432693713	17506	Economy	38300.00
0005432675397	17506	Economy	38300.00
0005432675449	17506	Economy	38300.00
0005432675485	17506	Economy	38300.00
0005432693731	17506	Economy	38300.00
0005432693636	17506	Economy	42200.00
0005432675451	17506	Economy	38300.00
0005432873494	17506	Economy	42200.00
0005432693601	17506	Economy	38300.00
0005432675460	17506	Economy	38300.00
0005432693746	17506	Economy	38300.00
0005432693637	17506	Economy	38300.00
0005432693699	17506	Economy	38300.00
0005432693754	17506	Economy	38300.00
0005432675389	17506	Economy	38300.00
0005432693732	17506	Economy	38300.00
0005432675472	17506	Economy	38300.00
0005432873492	17506	Economy	38300.00
0005432693708	17506	Economy	38300.00
0005432693714	17506	Economy	38300.00
0005432675459	17506	Economy	38300.00
0005432693801	17506	Economy	38300.00
0005432675464	17506	Economy	38300.00
0005432675503	17506	Economy	38300.00
0005432693709	17506	Economy	38300.00
0005432675494	17506	Economy	38300.00
0005432693676	17506	Economy	38300.00
0005432693747	17506	Economy	38300.00
0005432693707	17506	Economy	38300.00
0005432693625	17506	Economy	38300.00
0005432873493	17506	Economy	38300.00
0005432693719	17506	Economy	38300.00
0005432675388	17506	Economy	38300.00
0005432693658	17506	Economy	38300.00
0005432675471	17506	Economy	38300.00
0005432693698	17506	Economy	38300.00
0005432675525	17506	Economy	38300.00
0005432693620	17506	Economy	38300.00
0005432675511	17506	Economy	38300.00
0005432693749	17506	Economy	38300.00
0005432693720	17506	Economy	38300.00
0005432693677	17506	Economy	38300.00
0005432693622	17506	Economy	38300.00
0005432693602	17506	Economy	38300.00
0005434435624	1104	Economy	13900.00
0005433156974	1104	Economy	13900.00
0005433156921	1104	Economy	13900.00
0005434435625	1104	Economy	13900.00
0005433156933	1104	Economy	13900.00
0005433156934	1104	Economy	13900.00
0005433156902	1104	Economy	13900.00
0005433156920	1104	Economy	13900.00
0005434435523	17318	Economy	15200.00
0005434435576	17318	Economy	15200.00
0005434435443	17318	Economy	13900.00
0005434435496	17318	Economy	13900.00
0005434435534	17318	Economy	13900.00
0005434435462	17318	Economy	13900.00
0005434435497	17318	Economy	13900.00
0005434435545	17318	Economy	13900.00
0005433157004	17318	Economy	13900.00
0005434435491	17318	Economy	13900.00
0005434435533	17318	Economy	13900.00
0005434435490	17318	Economy	13900.00
0005433157001	17318	Economy	13900.00
0005434435544	17318	Economy	13900.00
0005434435463	17318	Economy	13900.00
0005434435493	17318	Economy	13900.00
0005434435522	17318	Economy	13900.00
0005434435546	17318	Economy	13900.00
0005433157002	17318	Economy	13900.00
0005433157003	17318	Economy	13900.00
0005435087052	4099	Economy	8200.00
0005435928255	4099	Economy	7500.00
0005435087053	4099	Economy	7500.00
0005435928243	4099	Economy	7500.00
0005435928254	4099	Economy	7500.00
0005435928217	4099	Economy	7500.00
0005435087054	4099	Economy	7500.00
0005435087006	24386	Economy	8200.00
0005435928285	24386	Economy	8200.00
0005435928283	24386	Economy	8200.00
0005435928287	24386	Economy	7500.00
0005435086998	24386	Economy	7500.00
0005435928286	24386	Economy	7500.00
0005435087009	24386	Economy	7500.00
0005435087008	24386	Economy	7500.00
0005435928284	24386	Economy	7500.00
0005435086999	24386	Economy	7500.00
0005435086981	24386	Economy	7500.00
0005433373717	2460	Business	86800.00
0005435706854	2460	Business	86800.00
0005433373681	2460	Business	86800.00
0005435706847	2460	Business	86800.00
0005433373695	2460	Business	86800.00
0005435706858	2460	Business	86800.00
0005433373731	2460	Business	86800.00
0005433373689	2460	Business	86800.00
0005433373718	2460	Economy	28900.00
0005433373694	2460	Economy	28900.00
0005433373709	2460	Economy	28900.00
0005435706850	2460	Economy	28900.00
0005433373683	2460	Economy	31800.00
0005433373744	2460	Economy	31800.00
0005435706848	2460	Economy	28900.00
0005433373682	2460	Economy	28900.00
0005435706857	2460	Economy	28900.00
0005433373688	2460	Economy	28900.00
0005433373696	2460	Economy	28900.00
0005433373759	2460	Economy	28900.00
0005433373706	2460	Economy	28900.00
0005435706860	2460	Economy	28900.00
0005435706859	2460	Economy	28900.00
0005433373732	2460	Economy	28900.00
0005435706856	2460	Economy	28900.00
0005433373710	2460	Economy	28900.00
0005433373742	2460	Economy	28900.00
0005433373711	2460	Economy	28900.00
0005435706853	2460	Economy	28900.00
0005433373738	2460	Economy	28900.00
0005435706849	2460	Economy	28900.00
0005433373720	2460	Economy	28900.00
0005433373730	2460	Economy	28900.00
0005435706846	2460	Economy	28900.00
0005435706855	2460	Economy	28900.00
0005435706845	2460	Economy	28900.00
0005433373723	2460	Economy	28900.00
0005433373687	2460	Economy	28900.00
0005435706852	2460	Economy	28900.00
0005435706851	2460	Economy	28900.00
0005433373716	2460	Economy	28900.00
0005433373796	27036	Business	86800.00
0005435706792	27036	Business	86800.00
0005435706649	27036	Business	86800.00
0005435706728	27036	Business	86800.00
0005435706692	27036	Business	86800.00
0005435706788	27036	Economy	28900.00
0005435706763	27036	Economy	28900.00
0005435706739	27036	Economy	28900.00
0005435706737	27036	Economy	28900.00
0005433373797	27036	Economy	31800.00
0005433373792	27036	Economy	31800.00
0005433373791	27036	Economy	28900.00
0005433373788	27036	Economy	28900.00
0005435706648	27036	Economy	28900.00
0005435706665	27036	Economy	28900.00
0005435706684	27036	Economy	28900.00
0005435706680	27036	Economy	28900.00
0005435706724	27036	Economy	28900.00
0005435706797	27036	Economy	28900.00
0005435706651	27036	Economy	28900.00
0005435706686	27036	Economy	28900.00
0005435706674	27036	Economy	28900.00
0005433373789	27036	Economy	28900.00
0005435706687	27036	Economy	28900.00
0005435706698	27036	Economy	28900.00
0005435706669	27036	Economy	28900.00
0005435706723	27036	Economy	28900.00
0005435706726	27036	Economy	28900.00
0005433373798	27036	Economy	28900.00
0005435706762	27036	Economy	28900.00
0005433373794	27036	Economy	28900.00
0005435706700	27036	Economy	28900.00
0005435706732	27036	Economy	28900.00
0005435706733	27036	Economy	28900.00
0005435706650	27036	Economy	28900.00
0005435706705	27036	Economy	28900.00
0005435706730	27036	Economy	28900.00
0005433373799	27036	Economy	28900.00
0005435706697	27036	Economy	28900.00
0005435706787	27036	Economy	28900.00
0005435706759	27036	Economy	28900.00
0005435706735	27036	Economy	28900.00
0005435706713	27036	Economy	28900.00
0005433373793	27036	Economy	28900.00
0005435706699	27036	Economy	28900.00
0005435706666	27036	Economy	28900.00
0005435706753	27036	Economy	28900.00
0005435706706	27036	Economy	28900.00
0005435706690	27036	Economy	28900.00
0005433373795	27036	Economy	28900.00
0005435706752	27036	Economy	28900.00
0005433373790	27036	Economy	28900.00
0005435706710	27036	Economy	28900.00
0005435706740	27036	Economy	28900.00
0005435706760	27036	Economy	28900.00
0005435706734	27036	Economy	28900.00
0005435706731	27036	Economy	28900.00
0005433261793	1325	Business	203300.00
0005433261792	1325	Business	203300.00
0005434964772	1325	Business	203300.00
0005433261774	1325	Business	203300.00
0005433261766	1325	Business	203300.00
0005433261772	1325	Business	203300.00
0005434964758	1325	Business	203300.00
0005433261730	1325	Business	203300.00
0005433261784	1325	Business	203300.00
0005434964761	1325	Business	203300.00
0005434964775	1325	Business	203300.00
0005434964749	1325	Business	203300.00
0005434964776	1325	Business	203300.00
0005434964750	1325	Business	203300.00
0005433261753	1325	Business	203300.00
0005434964760	1325	Economy	74500.00
0005433261790	1325	Economy	74500.00
0005433261761	1325	Economy	67800.00
0005433261757	1325	Economy	67800.00
0005433261726	1325	Economy	67800.00
0005434964769	1325	Economy	67800.00
0005433261778	1325	Economy	67800.00
0005433261789	1325	Economy	67800.00
0005434964777	1325	Economy	67800.00
0005434964770	1325	Economy	67800.00
0005433261738	1325	Economy	67800.00
0005433261729	1325	Economy	67800.00
0005434964764	1325	Economy	67800.00
0005432279334	1325	Economy	67800.00
0005434964774	1325	Economy	67800.00
0005433261787	1325	Economy	67800.00
0005433261759	1325	Economy	67800.00
0005433261702	1325	Economy	67800.00
0005433261724	1325	Economy	67800.00
0005433261723	1325	Economy	67800.00
0005432279337	1325	Economy	67800.00
0005434964757	1325	Economy	67800.00
0005434964778	1325	Economy	67800.00
0005433261779	1325	Economy	67800.00
0005434964771	1325	Economy	67800.00
0005434964754	1325	Economy	67800.00
0005434964763	1325	Economy	67800.00
0005434964747	1325	Economy	67800.00
0005433261734	1325	Economy	67800.00
0005434964748	1325	Economy	67800.00
0005433261764	1325	Economy	67800.00
0005433261791	1325	Economy	67800.00
0005433261767	1325	Economy	67800.00
0005433261743	1325	Economy	67800.00
0005434964752	1325	Economy	67800.00
0005433261769	1325	Economy	67800.00
0005434964759	1325	Economy	74500.00
0005433261775	1325	Economy	67800.00
0005434964753	1325	Economy	74500.00
0005434964751	1325	Economy	67800.00
0005433261788	1325	Economy	67800.00
0005434964762	1325	Economy	67800.00
0005434964767	1325	Economy	67800.00
0005433261765	1325	Economy	67800.00
0005432279335	1325	Economy	67800.00
0005433261744	1325	Economy	67800.00
0005433261752	1325	Economy	67800.00
0005433261701	1325	Economy	67800.00
0005434964755	1325	Economy	67800.00
0005433261727	1325	Economy	67800.00
0005434964768	1325	Economy	67800.00
0005434964779	1325	Economy	67800.00
0005434964765	1325	Economy	67800.00
0005433261773	1325	Economy	67800.00
0005433261750	1325	Economy	67800.00
0005434964766	1325	Economy	67800.00
0005432279333	1325	Economy	67800.00
0005433261768	1325	Economy	67800.00
0005434964773	1325	Economy	67800.00
0005433261760	1325	Economy	67800.00
0005433261728	1325	Economy	67800.00
0005433261763	1325	Economy	67800.00
0005433261795	1325	Economy	67800.00
0005434964756	1325	Economy	67800.00
0005432279336	1325	Economy	67800.00
0005434626233	4873	Economy	14700.00
0005434626234	4873	Economy	14700.00
0005435907623	4873	Economy	14700.00
0005433194914	4873	Economy	14700.00
0005434626232	4873	Economy	14700.00
0005434626182	32936	Business	44200.00
0005434626192	32936	Business	44200.00
0005435907652	32936	Business	44200.00
0005433194997	32936	Business	44200.00
0005434626210	32936	Business	44200.00
0005433194993	32936	Business	44200.00
0005434626178	32936	Economy	14700.00
0005433194996	32936	Economy	14700.00
0005433194995	32936	Economy	14700.00
0005433194998	32936	Economy	14700.00
0005434626190	32936	Economy	14700.00
0005433194994	32936	Economy	14700.00
0005434626160	32936	Economy	14700.00
0005434626196	32936	Economy	14700.00
0005435907653	32936	Economy	14700.00
0005434626183	32936	Economy	14700.00
0005433194992	32936	Economy	14700.00
0005434626200	32936	Economy	14700.00
0005434626176	32936	Economy	14700.00
0005435907651	32936	Economy	14700.00
0005434626191	32936	Economy	14700.00
0005434626177	32936	Economy	14700.00
0005434626199	32936	Economy	14700.00
0005434626136	32936	Economy	14700.00
0005433194991	32936	Economy	14700.00
0005434626195	32936	Economy	14700.00
0005435937563	13781	Economy	3400.00
0005435785999	13781	Economy	3400.00
0005435786056	13781	Economy	3400.00
0005435785919	13781	Economy	3400.00
0005435785967	13781	Economy	3100.00
0005435785969	13781	Economy	3100.00
0005435786031	13781	Economy	3100.00
0005435937564	13781	Economy	3100.00
0005435937565	13781	Economy	3100.00
0005435785959	13781	Economy	3100.00
0005435786047	13781	Economy	3100.00
0005435786001	13781	Economy	3100.00
0005435785958	13781	Economy	3100.00
0005435786044	13781	Economy	3100.00
0005435786006	13781	Economy	3100.00
0005435937562	13781	Economy	3100.00
0005435983727	13781	Economy	3100.00
0005435786117	13781	Economy	3100.00
0005435786073	13781	Economy	3100.00
0005435786098	13781	Economy	3100.00
0005435786144	13781	Economy	3100.00
0005435786048	13781	Economy	3100.00
0005435786205	13781	Economy	3100.00
0005435785965	13781	Economy	3100.00
0005435937558	13781	Economy	3100.00
0005435786140	13781	Economy	3100.00
0005435786201	13781	Economy	3100.00
0005435786089	13781	Economy	3100.00
0005435983728	13781	Economy	3100.00
0005435937566	13781	Economy	3100.00
0005435786074	13781	Economy	3100.00
0005435785966	13781	Economy	3100.00
0005435937560	13781	Economy	3100.00
0005435786005	13781	Economy	3100.00
0005435785933	13781	Economy	3100.00
0005435785970	13781	Economy	3100.00
0005435785934	13781	Economy	3100.00
0005435786083	13781	Economy	3100.00
0005435786200	13781	Economy	3100.00
0005435786049	13781	Economy	3100.00
0005435786045	13781	Economy	3100.00
0005435786042	13781	Economy	3100.00
0005435937559	13781	Economy	3100.00
0005435786133	13781	Economy	3100.00
0005435937561	13781	Economy	3100.00
0005435786320	27418	Economy	3400.00
0005435786314	27418	Economy	3400.00
0005435786321	27418	Economy	3400.00
0005435786311	27418	Economy	3400.00
0005435786315	27418	Economy	3100.00
0005435786312	27418	Economy	3100.00
0005435786306	27418	Economy	3100.00
0005435937466	27418	Economy	3100.00
0005432190739	27418	Economy	3100.00
0005435787412	27418	Economy	3100.00
0005435786313	27418	Economy	3100.00
0005435937478	27418	Economy	3100.00
0005432190738	27418	Economy	3100.00
0005435786318	27418	Economy	3100.00
0005435786319	27418	Economy	3100.00
0005435786310	27418	Economy	3100.00
0005435937477	27418	Economy	3100.00
0005435786317	27418	Economy	3100.00
0005435937493	27418	Economy	3100.00
0005435937505	27418	Economy	3100.00
0005435937476	27418	Economy	3100.00
0005435937465	27418	Economy	3100.00
0005435786307	27418	Economy	3100.00
0005435786308	27418	Economy	3100.00
0005435937457	27418	Economy	3100.00
0005435786305	27418	Economy	3100.00
0005435786309	27418	Economy	3100.00
0005435786316	27418	Economy	3100.00
0005435786322	27418	Economy	3100.00
0005434408973	20276	Business	12000.00
0005434409273	20276	Business	12000.00
0005434408918	20276	Business	12000.00
0005434408842	20276	Business	12000.00
0005434409036	20276	Business	12000.00
0005434408770	20276	Business	12000.00
0005434409022	20276	Business	12000.00
0005435311532	20276	Business	12000.00
0005434409021	20276	Business	12000.00
0005434409124	20276	Economy	4000.00
0005434408919	20276	Economy	4000.00
0005435311537	20276	Economy	4000.00
0005434409037	20276	Economy	4000.00
0005434408940	20276	Economy	4000.00
0005435311528	20276	Economy	4000.00
0005434409175	20276	Economy	4400.00
0005434409181	20276	Economy	4400.00
0005435311531	20276	Economy	4400.00
0005434408971	20276	Economy	4400.00
0005435311536	20276	Economy	4400.00
0005434409289	20276	Economy	4000.00
0005432058495	20276	Economy	4000.00
0005435311534	20276	Economy	4000.00
0005434409133	20276	Economy	4000.00
0005434409020	20276	Economy	4000.00
0005434408984	20276	Economy	4000.00
0005434408923	20276	Economy	4000.00
0005435311526	20276	Economy	4000.00
0005434408792	20276	Economy	4000.00
0005435311533	20276	Economy	4000.00
0005434408963	20276	Economy	4000.00
0005434409122	20276	Economy	4000.00
0005435311529	20276	Economy	4000.00
0005434409100	20276	Economy	4000.00
0005435311527	20276	Economy	4000.00
0005434408889	20276	Economy	4000.00
0005434409290	20276	Economy	4000.00
0005434409028	20276	Economy	4000.00
0005434408750	20276	Economy	4000.00
0005434408970	20276	Economy	4000.00
0005434409166	20276	Economy	4000.00
0005434409045	20276	Economy	4000.00
0005434409137	20276	Economy	4000.00
0005434409156	20276	Economy	4000.00
0005434408886	20276	Economy	4000.00
0005435311525	20276	Economy	4000.00
0005434409172	20276	Economy	4000.00
0005434409092	20276	Economy	4000.00
0005434409337	20276	Economy	4000.00
0005434409110	20276	Economy	4000.00
0005434409089	20276	Economy	4000.00
0005432058494	20276	Economy	4000.00
0005434408982	20276	Economy	4000.00
0005434409123	20276	Economy	4000.00
0005435311535	20276	Economy	4000.00
0005434408974	20276	Economy	4000.00
0005434409131	20276	Economy	4000.00
0005434409009	20276	Economy	4000.00
0005434409167	20276	Economy	4000.00
0005434408905	20276	Economy	4000.00
0005434408999	20276	Economy	4000.00
0005434409252	20276	Economy	4000.00
0005435311530	20276	Economy	4000.00
0005434409338	20276	Economy	4000.00
0005434408942	20276	Economy	4000.00
0005434408761	20276	Economy	4000.00
0005432154135	27013	Business	12000.00
0005435311368	27013	Business	12000.00
0005435311327	27013	Business	12000.00
0005434409571	27013	Business	12000.00
0005434409573	27013	Business	12000.00
0005434409569	27013	Economy	4000.00
0005434409565	27013	Economy	4000.00
0005435311361	27013	Economy	4000.00
0005435311345	27013	Economy	4000.00
0005435311320	27013	Economy	4000.00
0005435311406	27013	Economy	4000.00
0005434409561	27013	Economy	4000.00
0005434409551	27013	Economy	4000.00
0005434409572	27013	Economy	4400.00
0005434409570	27013	Economy	4400.00
0005434409559	27013	Economy	4000.00
0005434409564	27013	Economy	4000.00
0005435311420	27013	Economy	4000.00
0005434409574	27013	Economy	4000.00
0005434409554	27013	Economy	4000.00
0005434409576	27013	Economy	4000.00
0005435311332	27013	Economy	4000.00
0005435311339	27013	Economy	4000.00
0005435311293	27013	Economy	4000.00
0005434409558	27013	Economy	4000.00
0005435311249	27013	Economy	4000.00
0005435311333	27013	Economy	4000.00
0005434409575	27013	Economy	4000.00
0005435311376	27013	Economy	4000.00
0005435311331	27013	Economy	4000.00
0005435311391	27013	Economy	4000.00
0005435311397	27013	Economy	4000.00
0005434409556	27013	Economy	4000.00
0005434409553	27013	Economy	4000.00
0005435311398	27013	Economy	4000.00
0005434409562	27013	Economy	4000.00
0005434409555	27013	Economy	4000.00
0005435311344	27013	Economy	4000.00
0005434409567	27013	Economy	4000.00
0005434409563	27013	Economy	4000.00
0005434409560	27013	Economy	4000.00
0005434409577	27013	Economy	4000.00
0005435311306	27013	Economy	4000.00
0005434409557	27013	Economy	4000.00
0005434409552	27013	Economy	4000.00
0005435311268	27013	Economy	4000.00
0005432154136	27013	Economy	4000.00
0005435311359	27013	Economy	4000.00
0005435311360	27013	Economy	4000.00
0005434409566	27013	Economy	4000.00
0005434409568	27013	Economy	4000.00
0005433124369	5728	Business	43300.00
0005433124418	5728	Business	43300.00
0005434319831	5728	Business	43300.00
0005433124411	5728	Business	43300.00
0005434319826	5728	Business	43300.00
0005433124318	5728	Business	43300.00
0005433124366	5728	Business	43300.00
0005434319841	5728	Economy	14400.00
0005434310152	5728	Economy	14400.00
0005433124352	5728	Economy	14400.00
0005434310153	5728	Economy	14400.00
0005433124313	5728	Economy	14400.00
0005433124373	5728	Economy	15900.00
0005434319834	5728	Economy	15900.00
0005433124477	5728	Economy	14400.00
0005434311276	5728	Economy	14400.00
0005433124374	5728	Economy	14400.00
0005434319828	5728	Economy	14400.00
0005434319837	5728	Economy	14400.00
0005433124407	5728	Economy	14400.00
0005434319839	5728	Economy	14400.00
0005434319842	5728	Economy	14400.00
0005434310151	5728	Economy	14400.00
0005433124280	5728	Economy	14400.00
0005433124359	5728	Economy	14400.00
0005433124270	5728	Economy	14400.00
0005434319832	5728	Economy	14400.00
0005434319840	5728	Economy	14400.00
0005434319846	5728	Economy	14400.00
0005434319843	5728	Economy	14400.00
0005434319827	5728	Economy	14400.00
0005434311290	5728	Economy	14400.00
0005434319833	5728	Economy	14400.00
0005434319825	5728	Economy	14400.00
0005433124271	5728	Economy	14400.00
0005433124341	5728	Economy	14400.00
0005434310150	5728	Economy	14400.00
0005434319836	5728	Economy	14400.00
0005434319838	5728	Economy	14400.00
0005434319830	5728	Economy	14400.00
0005433124272	5728	Economy	14400.00
0005434319835	5728	Economy	14400.00
0005434311277	5728	Economy	14400.00
0005434319845	5728	Economy	14400.00
0005434319844	5728	Economy	14400.00
0005433124367	5728	Economy	14400.00
0005435297351	5728	Economy	14400.00
0005434310154	5728	Economy	14400.00
0005433124331	5728	Economy	14400.00
0005434319829	5728	Economy	14400.00
0005434311265	15687	Business	43300.00
0005434319675	15687	Business	43300.00
0005433124528	15687	Business	43300.00
0005434311266	15687	Economy	14400.00
0005433124525	15687	Economy	14400.00
0005433124524	15687	Economy	14400.00
0005434319607	15687	Economy	14400.00
0005434319661	15687	Economy	14400.00
0005433124523	15687	Economy	14400.00
0005433124530	15687	Economy	14400.00
0005434319676	15687	Economy	14400.00
0005434312360	15687	Economy	15900.00
0005434319655	15687	Economy	15900.00
0005434319606	15687	Economy	14400.00
0005434311264	15687	Economy	14400.00
0005433124526	15687	Economy	14400.00
0005434319654	15687	Economy	14400.00
0005434312361	15687	Economy	14400.00
0005434319642	15687	Economy	14400.00
0005434319664	15687	Economy	14400.00
0005434319673	15687	Economy	14400.00
0005433124527	15687	Economy	14400.00
0005434311262	15687	Economy	14400.00
0005433124529	15687	Economy	14400.00
0005434319674	15687	Economy	14400.00
0005434319656	15687	Economy	14400.00
0005434311259	15687	Economy	14400.00
0005435219261	31755	Economy	15500.00
0005435220521	31755	Economy	15500.00
0005435220381	31755	Economy	15500.00
0005435220520	31755	Economy	15500.00
0005435220383	31755	Economy	15500.00
0005435220382	31755	Economy	15500.00
0005435219262	31755	Economy	15500.00
0005435219264	31755	Economy	15500.00
0005435219263	31755	Economy	15500.00
0005434484538	8974	Economy	27400.00
0005434189318	8974	Economy	27400.00
0005434189319	8974	Economy	24900.00
0005434189283	8974	Economy	24900.00
0005434484536	8974	Economy	24900.00
0005434189327	8974	Economy	24900.00
0005434484537	8974	Economy	24900.00
0005434189297	8974	Economy	24900.00
0005434189312	8974	Economy	24900.00
0005434484535	8974	Economy	24900.00
0005434484492	16638	Economy	27400.00
0005434484511	16638	Economy	24900.00
0005435903228	16638	Economy	24900.00
0005435903225	16638	Economy	24900.00
0005434484486	16638	Economy	24900.00
0005434484491	16638	Economy	24900.00
0005434189339	16638	Economy	24900.00
0005434484494	16638	Economy	24900.00
0005435903227	16638	Economy	24900.00
0005434484495	16638	Economy	24900.00
0005434189340	16638	Economy	24900.00
0005435903226	16638	Economy	24900.00
0005435903229	16638	Economy	24900.00
0005433722344	7593	Business	11100.00
0005433722326	7593	Economy	3700.00
0005433124530	7593	Economy	3700.00
0005433124528	7593	Economy	3700.00
0005433124526	7593	Economy	3700.00
0005433124529	7593	Economy	4100.00
0005433124523	7593	Economy	3700.00
0005433722339	7593	Economy	3700.00
0005433124527	7593	Economy	3700.00
0005433722319	7593	Economy	3700.00
0005433124525	7593	Economy	3700.00
0005433722343	7593	Economy	3700.00
0005433722332	7593	Economy	3700.00
0005433722345	7593	Economy	3700.00
0005433722346	7593	Economy	3700.00
0005433722320	7593	Economy	3700.00
0005433722337	7593	Economy	3700.00
0005433722338	7593	Economy	3700.00
0005433124524	7593	Economy	3700.00
0005433450587	7592	Business	11100.00
0005432721657	7592	Business	11100.00
0005432693953	7592	Economy	3700.00
0005433450590	7592	Economy	3700.00
0005432693956	7592	Economy	4100.00
0005433450595	7592	Economy	4100.00
0005432721665	7592	Economy	4100.00
0005432721660	7592	Economy	4100.00
0005432071659	7592	Economy	3700.00
0005433450588	7592	Economy	3700.00
0005432071661	7592	Economy	3700.00
0005432721670	7592	Economy	3700.00
0005432721666	7592	Economy	3700.00
0005432071660	7592	Economy	3700.00
0005433450592	7592	Economy	3700.00
0005432721659	7592	Economy	3700.00
0005432721658	7592	Economy	3700.00
0005432693952	7592	Economy	3700.00
0005432721662	7592	Economy	3700.00
0005433450596	7592	Economy	3700.00
0005433450599	7592	Economy	3700.00
0005433450598	7592	Economy	3700.00
0005432693951	7592	Economy	3700.00
0005432693950	7592	Economy	3700.00
0005433450593	7592	Economy	3700.00
0005432693944	7592	Economy	3700.00
0005432721667	7592	Economy	3700.00
0005432693947	7592	Economy	3700.00
0005432693949	7592	Economy	3700.00
0005432693946	7592	Economy	3700.00
0005432721656	7592	Economy	3700.00
0005432721664	7592	Economy	3700.00
0005433450597	7592	Economy	3700.00
0005432721671	7592	Economy	3700.00
0005432721655	7592	Economy	3700.00
0005432693954	7592	Economy	3700.00
0005432693948	7592	Economy	3700.00
0005432721663	7592	Economy	3700.00
0005432721661	7592	Economy	3700.00
0005432693945	7592	Economy	3700.00
0005432721669	7592	Economy	3700.00
0005432693955	7592	Economy	3700.00
0005433450591	7592	Economy	3700.00
0005432721668	7592	Economy	3700.00
0005433450594	7592	Economy	3700.00
0005433450589	7592	Economy	3700.00
0005432693714	30343	Business	11100.00
0005432693658	30343	Business	11100.00
0005432693708	30343	Business	11100.00
0005433450381	30343	Business	11100.00
0005433450448	30343	Economy	3700.00
0005432693753	30343	Economy	3700.00
0005433450374	30343	Economy	3700.00
0005432693586	30343	Economy	3700.00
0005433450496	30343	Economy	3700.00
0005433450274	30343	Economy	3700.00
0005433450508	30343	Economy	3700.00
0005432693602	30343	Economy	3700.00
0005432693677	30343	Economy	3700.00
0005433450450	30343	Economy	4100.00
0005432693623	30343	Economy	4100.00
0005432693620	30343	Economy	4100.00
0005432693625	30343	Economy	4100.00
0005433450517	30343	Economy	3700.00
0005432693698	30343	Economy	3700.00
0005432693746	30343	Economy	3700.00
0005432693720	30343	Economy	3700.00
0005432693699	30343	Economy	3700.00
0005433450375	30343	Economy	3700.00
0005432693676	30343	Economy	3700.00
0005432693747	30343	Economy	3700.00
0005432693719	30343	Economy	3700.00
0005433450433	30343	Economy	3700.00
0005433450432	30343	Economy	3700.00
0005432693637	30343	Economy	3700.00
0005433450428	30343	Economy	3700.00
0005432693636	30343	Economy	3700.00
0005432693749	30343	Economy	3700.00
0005432693707	30343	Economy	3700.00
0005432693754	30343	Economy	3700.00
0005433450461	30343	Economy	3700.00
0005432693801	30343	Economy	3700.00
0005432693722	30343	Economy	3700.00
0005432693713	30343	Economy	3700.00
0005432693709	30343	Economy	3700.00
0005432693762	30343	Economy	3700.00
0005433450275	30343	Economy	3700.00
0005432693622	30343	Economy	3700.00
0005433450429	30343	Economy	3700.00
0005432693731	30343	Economy	3700.00
0005432693732	30343	Economy	3700.00
0005432693748	30343	Economy	3700.00
0005433450338	30343	Economy	3700.00
0005432693601	30343	Economy	3700.00
0005433450449	30343	Economy	3700.00
0005432693706	30343	Economy	3700.00
0005432693621	30343	Economy	3700.00
0005433450495	30343	Economy	3700.00
0005433450463	30343	Economy	3700.00
0005433450430	30343	Economy	3700.00
0005432721502	30342	Business	11100.00
0005432721530	30342	Business	11100.00
0005434310151	30342	Business	11100.00
0005432721500	30342	Business	11100.00
0005432721367	30342	Business	11100.00
0005433124270	30342	Business	11100.00
0005433124367	30342	Business	11100.00
0005433722488	30342	Economy	3700.00
0005432721561	30342	Economy	3700.00
0005432721431	30342	Economy	3700.00
0005432721317	30342	Economy	3700.00
0005433124374	30342	Economy	3700.00
0005433124280	30342	Economy	3700.00
0005434310152	30342	Economy	4100.00
0005433722477	30342	Economy	4100.00
0005432721402	30342	Economy	3700.00
0005432721430	30342	Economy	3700.00
0005433124331	30342	Economy	3700.00
0005433124272	30342	Economy	3700.00
0005433124369	30342	Economy	3700.00
0005433722486	30342	Economy	3700.00
0005433124407	30342	Economy	3700.00
0005433124366	30342	Economy	3700.00
0005433722480	30342	Economy	3700.00
0005433124477	30342	Economy	3700.00
0005433722484	30342	Economy	3700.00
0005432721471	30342	Economy	3700.00
0005432721497	30342	Economy	3700.00
0005432721469	30342	Economy	3700.00
0005433722485	30342	Economy	3700.00
0005434310153	30342	Economy	3700.00
0005433722476	30342	Economy	3700.00
0005433124411	30342	Economy	3700.00
0005433124359	30342	Economy	3700.00
0005432721562	30342	Economy	3700.00
0005432721501	30342	Economy	3700.00
0005433722479	30342	Economy	3700.00
0005433722481	30342	Economy	3700.00
0005433722482	30342	Economy	3700.00
0005432721529	30342	Economy	3700.00
0005432721449	30342	Economy	3700.00
0005432721536	30342	Economy	3700.00
0005432721490	30342	Economy	3700.00
0005433722487	30342	Economy	3700.00
0005433722475	30342	Economy	3700.00
0005432721483	30342	Economy	3700.00
0005433124271	30342	Economy	3700.00
0005433124373	30342	Economy	3700.00
0005433124341	30342	Economy	3700.00
0005432721489	30342	Economy	3700.00
0005433722483	30342	Economy	3700.00
0005432721470	30342	Economy	3700.00
0005432721590	30342	Economy	3700.00
0005432721548	30342	Economy	3700.00
0005434310154	30342	Economy	3700.00
0005432721549	30342	Economy	3700.00
0005432721456	30342	Economy	3700.00
0005433722478	30342	Economy	3700.00
0005433124418	30342	Economy	3700.00
0005433124318	30342	Economy	3700.00
0005433124352	30342	Economy	3700.00
0005432721586	30342	Economy	3700.00
0005434310150	30342	Economy	3700.00
0005433124313	30342	Economy	3700.00
0005433722474	30342	Economy	3700.00
0005433193336	1378	Business	70400.00
0005433525353	1378	Business	70400.00
0005432968891	1378	Business	70400.00
0005433193270	1378	Business	70400.00
0005433525352	1378	Economy	23500.00
0005433193383	1378	Economy	23500.00
0005432928099	1378	Economy	23500.00
0005434587338	1378	Economy	23500.00
0005432271086	1378	Economy	23500.00
0005434513657	1378	Economy	25800.00
0005433525351	1378	Economy	25800.00
0005433525354	1378	Economy	25800.00
0005432928095	1378	Economy	25800.00
0005432928092	1378	Economy	23500.00
0005432928084	1378	Economy	23500.00
0005433525350	1378	Economy	23500.00
0005432928103	1378	Economy	23500.00
0005434513658	1378	Economy	23500.00
0005434587337	1378	Economy	23500.00
0005433193384	1378	Economy	23500.00
0005433193335	1378	Economy	23500.00
0005434587339	1378	Economy	23500.00
0005433193366	1378	Economy	23500.00
0005434587334	1378	Economy	23500.00
0005434513656	1378	Economy	23500.00
0005434587340	1378	Economy	23500.00
0005432968892	1378	Economy	23500.00
0005434587343	1378	Economy	23500.00
0005434587342	1378	Economy	23500.00
0005433525348	1378	Economy	23500.00
0005433525355	1378	Economy	23500.00
0005432271088	1378	Economy	23500.00
0005434587346	1378	Economy	23500.00
0005433525349	1378	Economy	23500.00
0005433193346	1378	Economy	23500.00
0005432271087	1378	Economy	23500.00
0005433724936	1378	Economy	23500.00
0005434587345	1378	Economy	23500.00
0005434587336	1378	Economy	23500.00
0005433525356	1378	Economy	23500.00
0005434587344	1378	Economy	23500.00
0005432928102	1378	Economy	23500.00
0005434587341	1378	Economy	23500.00
0005434587335	1378	Economy	23500.00
0005433193337	1378	Economy	23500.00
0005433193429	18510	Business	70400.00
0005434587201	18510	Business	70400.00
0005434587228	18510	Business	70400.00
0005434587229	18510	Business	70400.00
0005433525243	18510	Business	70400.00
0005434515028	18510	Economy	23500.00
0005433724911	18510	Economy	23500.00
0005433525237	18510	Economy	23500.00
0005433724910	18510	Economy	23500.00
0005434587211	18510	Economy	23500.00
0005434587192	18510	Economy	23500.00
0005433525263	18510	Economy	25800.00
0005433525236	18510	Economy	25800.00
0005433525305	18510	Economy	25800.00
0005433525252	18510	Economy	25800.00
0005433525226	18510	Economy	23500.00
0005432928140	18510	Economy	23500.00
0005434587142	18510	Economy	23500.00
0005434587144	18510	Economy	23500.00
0005434587052	18510	Economy	23500.00
0005434586978	18510	Economy	23500.00
0005433525304	18510	Economy	23500.00
0005433525268	18510	Economy	23500.00
0005433525312	18510	Economy	23500.00
0005433193430	18510	Economy	23500.00
0005433525262	18510	Economy	23500.00
0005432968906	18510	Economy	23500.00
0005434587054	18510	Economy	23500.00
0005434515023	18510	Economy	23500.00
0005432928139	18510	Economy	23500.00
0005433525273	18510	Economy	23500.00
0005434587175	18510	Economy	23500.00
0005433193427	18510	Economy	23500.00
0005434587123	18510	Economy	23500.00
0005434587227	18510	Economy	23500.00
0005433525242	18510	Economy	23500.00
0005434587124	18510	Economy	23500.00
0005434587204	18510	Economy	23500.00
0005432928138	18510	Economy	23500.00
0005433525269	18510	Economy	23500.00
0005433193428	18510	Economy	23500.00
0005434587193	18510	Economy	23500.00
0005432928137	18510	Economy	23500.00
0005434587169	18510	Economy	23500.00
0005433525275	18510	Economy	23500.00
0005433193432	18510	Economy	23500.00
0005433193433	18510	Economy	23500.00
0005434587097	18510	Economy	23500.00
0005432968907	18510	Economy	23500.00
0005433193431	18510	Economy	23500.00
0005434587016	18510	Economy	23500.00
0005433724909	18510	Economy	23500.00
0005434587083	18510	Economy	23500.00
0005434587145	18510	Economy	23500.00
0005434587015	18510	Economy	23500.00
0005433525225	18510	Economy	23500.00
0005433525264	18510	Economy	23500.00
0005434515021	18510	Economy	23500.00
0005433525276	18510	Economy	23500.00
0005434587168	18510	Economy	23500.00
0005432968905	18510	Economy	23500.00
0005432928136	18510	Economy	23500.00
0005434587053	18510	Economy	23500.00
0005433724892	18510	Economy	23500.00
0005434345213	11480	Economy	4300.00
0005434345219	11480	Economy	4300.00
0005434345233	11480	Economy	4300.00
0005434345225	11480	Economy	4000.00
0005435305051	11480	Economy	4000.00
0005434345221	11480	Economy	4000.00
0005434345222	11480	Economy	4000.00
0005434345214	11480	Economy	4000.00
0005434345215	11480	Economy	4000.00
0005434142728	11480	Economy	4000.00
0005434345228	11480	Economy	4000.00
0005434345218	11480	Economy	4000.00
0005434345224	11480	Economy	4000.00
0005434142727	11480	Economy	4000.00
0005435302282	11480	Economy	4000.00
0005434345220	11480	Economy	4000.00
0005435305046	11480	Economy	4000.00
0005434345237	11480	Economy	4000.00
0005434345229	11480	Economy	4000.00
0005434345232	11480	Economy	4000.00
0005434345217	11480	Economy	4000.00
0005435305047	11480	Economy	4000.00
0005434345216	11480	Economy	4000.00
0005434345230	11480	Economy	4000.00
0005434345238	11480	Economy	4000.00
0005434345231	11480	Economy	4000.00
0005435305053	11480	Economy	4000.00
0005434345226	11480	Economy	4000.00
0005435305054	11480	Economy	4000.00
0005434345234	11480	Economy	4000.00
0005434345212	11480	Economy	4000.00
0005434345236	11480	Economy	4000.00
0005435305052	11480	Economy	4000.00
0005434345223	11480	Economy	4000.00
0005435305045	11480	Economy	4000.00
0005434345227	11480	Economy	4000.00
0005434345235	11480	Economy	4000.00
0005435305078	29751	Economy	4300.00
0005434344801	29751	Economy	4300.00
0005434345008	29751	Economy	4300.00
0005434344948	29751	Economy	4300.00
0005434344889	29751	Economy	4000.00
0005434344862	29751	Economy	4000.00
0005434344947	29751	Economy	4000.00
0005435304273	29751	Economy	4000.00
0005434344794	29751	Economy	4000.00
0005434142701	29751	Economy	4000.00
0005434344661	29751	Economy	4000.00
0005434345057	29751	Economy	4000.00
0005434344858	29751	Economy	4000.00
0005434344856	29751	Economy	4000.00
0005434344863	29751	Economy	4000.00
0005434344851	29751	Economy	4000.00
0005435304272	29751	Economy	4000.00
0005434344984	29751	Economy	4000.00
0005434344879	29751	Economy	4000.00
0005434344880	29751	Economy	4000.00
0005434344662	29751	Economy	4000.00
0005434344663	29751	Economy	4000.00
0005434345026	29751	Economy	4000.00
0005434344773	29751	Economy	4000.00
0005434344910	29751	Economy	4000.00
0005434344883	29751	Economy	4000.00
0005434344982	29751	Economy	4000.00
0005434344878	29751	Economy	4000.00
0005434344890	29751	Economy	4000.00
0005435304275	29751	Economy	4000.00
0005434345017	29751	Economy	4000.00
0005434344857	29751	Economy	4000.00
0005434344993	29751	Economy	4000.00
0005435304274	29751	Economy	4000.00
0005434344877	29751	Economy	4000.00
0005434344882	29751	Economy	4000.00
0005435305077	29751	Economy	4000.00
0005434344830	29751	Economy	4000.00
0005434344897	29751	Economy	4000.00
0005434345018	29751	Economy	4000.00
0005434344983	29751	Economy	4000.00
0005434142700	29751	Economy	4000.00
0005434344876	29751	Economy	4000.00
0005435825399	1293	Business	199800.00
0005433416036	1293	Economy	66600.00
0005433416035	1293	Economy	66600.00
0005433415978	1293	Economy	73200.00
0005435825391	1293	Economy	66600.00
0005435825388	1293	Economy	66600.00
0005432284644	1293	Economy	66600.00
0005435825389	1293	Economy	66600.00
0005435825394	1293	Economy	66600.00
0005435825395	1293	Economy	66600.00
0005435825390	1293	Economy	66600.00
0005433416001	1293	Economy	66600.00
0005435825397	1293	Economy	66600.00
0005433416025	1293	Economy	66600.00
0005433416002	1293	Economy	66600.00
0005435825392	1293	Economy	66600.00
0005435825398	1293	Economy	66600.00
0005435825387	1293	Economy	66600.00
0005435825393	1293	Economy	66600.00
0005435825396	1293	Economy	66600.00
0005435825193	17993	Business	199800.00
0005435825277	17993	Business	199800.00
0005435825145	17993	Business	199800.00
0005435825204	17993	Economy	66600.00
0005435825101	17993	Business	199800.00
0005435825205	17993	Economy	66600.00
0005435825237	17993	Economy	66600.00
0005435825128	17993	Economy	66600.00
0005433416119	17993	Economy	66600.00
0005435825102	17993	Economy	66600.00
0005435825275	17993	Economy	66600.00
0005435825161	17993	Economy	66600.00
0005435825141	17993	Economy	66600.00
0005435825252	17993	Economy	66600.00
0005433416124	17993	Economy	66600.00
0005435825188	17993	Economy	66600.00
0005435825319	17993	Economy	66600.00
0005435825189	17993	Economy	66600.00
0005435825170	17993	Economy	66600.00
0005433416125	17993	Economy	66600.00
0005435825241	17993	Economy	66600.00
0005435825190	17993	Economy	66600.00
0005433416121	17993	Economy	66600.00
0005435825310	17993	Economy	66600.00
0005435825313	17993	Economy	66600.00
0005435825240	17993	Economy	66600.00
0005435825207	17993	Economy	66600.00
0005435825140	17993	Economy	66600.00
0005435825236	17993	Economy	66600.00
0005435825206	17993	Economy	66600.00
0005435825208	17993	Economy	66600.00
0005433416122	17993	Economy	66600.00
0005433416120	17993	Economy	66600.00
0005435825139	17993	Economy	66600.00
0005433416126	17993	Economy	66600.00
0005435825295	17993	Economy	66600.00
0005435825169	17993	Economy	66600.00
0005433416123	17993	Economy	66600.00
0005435825075	17993	Economy	66600.00
0005435950014	5608	Business	27800.00
0005435476859	5608	Business	27800.00
0005435950013	5608	Business	27800.00
0005432785330	5608	Business	27800.00
0005435243380	5608	Business	27800.00
0005432785322	5608	Business	27800.00
0005435243400	5608	Business	27800.00
0005435476903	5608	Business	27800.00
0005435243438	5608	Business	27800.00
0005435243470	5608	Economy	9300.00
0005435243379	5608	Economy	9300.00
0005435243357	5608	Economy	9300.00
0005435243426	5608	Economy	9300.00
0005432785328	5608	Economy	9300.00
0005435243428	5608	Economy	9300.00
0005435243327	5608	Economy	9300.00
0005435950017	5608	Economy	9300.00
0005435950025	5608	Economy	10200.00
0005432785315	5608	Economy	10200.00
0005432785329	5608	Economy	10200.00
0005435243451	5608	Economy	10200.00
0005432785327	5608	Economy	10200.00
0005432785317	5608	Economy	9300.00
0005435243427	5608	Economy	9300.00
0005435950024	5608	Economy	9300.00
0005435243286	5608	Economy	9300.00
0005432785331	5608	Economy	9300.00
0005432785334	5608	Economy	9300.00
0005432785332	5608	Economy	9300.00
0005435476873	5608	Economy	9300.00
0005435243362	5608	Economy	9300.00
0005435950020	5608	Economy	9300.00
0005435243480	5608	Economy	9300.00
0005432785324	5608	Economy	9300.00
0005435243423	5608	Economy	9300.00
0005435476888	5608	Economy	9300.00
0005435243375	5608	Economy	9300.00
0005432785316	5608	Economy	9300.00
0005435950021	5608	Economy	9300.00
0005435476874	5608	Economy	9300.00
0005435243496	5608	Economy	9300.00
0005432785325	5608	Economy	9300.00
0005435243353	5608	Economy	9300.00
0005435243354	5608	Economy	9300.00
0005432785326	5608	Economy	9300.00
0005435243414	5608	Economy	9300.00
0005435243413	5608	Economy	9300.00
0005432785319	5608	Economy	9300.00
0005435243469	5608	Economy	9300.00
0005435950027	5608	Economy	9300.00
0005435476902	5608	Economy	9300.00
0005435243422	5608	Economy	9300.00
0005432785323	5608	Economy	9300.00
0005435243421	5608	Economy	9300.00
0005435243439	5608	Economy	9300.00
0005435950023	5608	Economy	9300.00
0005432785333	5608	Economy	9300.00
0005432785320	5608	Economy	9300.00
0005435950011	5608	Economy	9300.00
0005435476904	5608	Economy	9300.00
0005435950019	5608	Economy	9300.00
0005435243494	5608	Economy	9300.00
0005435950015	5608	Economy	9300.00
0005435476866	5608	Economy	9300.00
0005432785318	5608	Economy	9300.00
0005435243495	5608	Economy	9300.00
0005435243374	5608	Economy	9300.00
0005435243437	5608	Economy	9300.00
0005435950012	5608	Economy	9300.00
0005432785321	5608	Economy	9300.00
0005435243355	5608	Economy	9300.00
0005435243376	5608	Economy	9300.00
0005435950016	5608	Economy	9300.00
0005435950026	5608	Economy	9300.00
0005435950022	5608	Economy	9300.00
0005435243412	5608	Economy	9300.00
0005435950018	5608	Economy	9300.00
0005435476867	5608	Economy	9300.00
0005435243425	5608	Economy	9300.00
0005432784837	15395	Business	27800.00
0005432785096	15395	Business	27800.00
0005435243617	15395	Business	27800.00
0005432784968	15395	Business	27800.00
0005432784731	15395	Business	27800.00
0005432784725	15395	Business	27800.00
0005432784897	15395	Business	27800.00
0005435243615	15395	Business	27800.00
0005435243619	15395	Business	27800.00
0005432784962	15395	Business	27800.00
0005432784898	15395	Economy	9300.00
0005432784836	15395	Economy	9300.00
0005432784978	15395	Economy	9300.00
0005432784899	15395	Economy	9300.00
0005432784945	15395	Economy	9300.00
0005435476994	15395	Economy	9300.00
0005435949978	15395	Economy	9300.00
0005432785011	15395	Economy	9300.00
0005435476989	15395	Economy	9300.00
0005432784802	15395	Economy	10200.00
0005432784960	15395	Economy	10200.00
0005432784839	15395	Economy	10200.00
0005435243623	15395	Economy	10200.00
0005432785141	15395	Economy	9300.00
0005432784881	15395	Economy	9300.00
0005432784724	15395	Economy	9300.00
0005432784635	15395	Economy	9300.00
0005435243624	15395	Economy	9300.00
0005435243614	15395	Economy	9300.00
0005435243616	15395	Economy	9300.00
0005435243621	15395	Economy	9300.00
0005435476988	15395	Economy	9300.00
0005432784798	15395	Economy	9300.00
0005432784876	15395	Economy	9300.00
0005432784838	15395	Economy	9300.00
0005432784799	15395	Economy	9300.00
0005432785061	15395	Economy	9300.00
0005432784903	15395	Economy	9300.00
0005435243613	15395	Economy	9300.00
0005435243627	15395	Economy	9300.00
0005432784686	15395	Economy	9300.00
0005432785060	15395	Economy	9300.00
0005435243612	15395	Economy	9300.00
0005435949979	15395	Economy	9300.00
0005432784723	15395	Economy	9300.00
0005432784844	15395	Economy	9300.00
0005432785009	15395	Economy	9300.00
0005432784992	15395	Economy	9300.00
0005432784843	15395	Economy	9300.00
0005432784896	15395	Economy	9300.00
0005435243618	15395	Economy	9300.00
0005432784966	15395	Economy	9300.00
0005432784738	15395	Economy	9300.00
0005432784958	15395	Economy	9300.00
0005432784954	15395	Economy	9300.00
0005432784811	15395	Economy	9300.00
0005432785062	15395	Economy	9300.00
0005435626884	15395	Economy	9300.00
0005435243626	15395	Economy	9300.00
0005432784728	15395	Economy	9300.00
0005435476991	15395	Economy	9300.00
0005432785018	15395	Economy	9300.00
0005435476993	15395	Economy	9300.00
0005432784969	15395	Economy	9300.00
0005432784902	15395	Economy	9300.00
0005435476990	15395	Economy	9300.00
0005432784840	15395	Economy	9300.00
0005435243620	15395	Economy	9300.00
0005432784967	15395	Economy	9300.00
0005432784995	15395	Economy	9300.00
0005432784787	15395	Economy	9300.00
0005432784780	15395	Economy	9300.00
0005435476987	15395	Economy	9300.00
0005432784749	15395	Economy	9300.00
0005432784959	15395	Economy	9300.00
0005435476992	15395	Economy	9300.00
0005432784615	15395	Economy	9300.00
0005432785095	15395	Economy	9300.00
0005432784739	15395	Economy	9300.00
0005432785053	15395	Economy	9300.00
0005432784732	15395	Economy	9300.00
0005432784655	15395	Economy	9300.00
0005435243625	15395	Economy	9300.00
0005435243622	15395	Economy	9300.00
0005432784805	15395	Economy	9300.00
0005432785010	15395	Economy	9300.00
0005432848721	4341	Economy	7000.00
0005435851084	4341	Economy	7000.00
0005435851101	4341	Economy	6300.00
0005435851088	4341	Economy	6300.00
0005434463991	4341	Economy	6300.00
0005434463992	4341	Economy	6300.00
0005435851090	4341	Economy	6300.00
0005432848720	4341	Economy	6300.00
0005435851103	4341	Economy	6300.00
0005432848718	4341	Economy	6300.00
0005435851091	4341	Economy	6300.00
0005435851140	4341	Economy	6300.00
0005434463993	4341	Economy	6300.00
0005435851100	4341	Economy	6300.00
0005435851105	4341	Economy	6300.00
0005435851099	4341	Economy	6300.00
0005432848719	4341	Economy	6300.00
0005435851136	4341	Economy	6300.00
0005432848620	28845	Economy	7000.00
0005435851174	28845	Economy	7000.00
0005432848642	28845	Economy	6300.00
0005432848626	28845	Economy	6300.00
0005432848598	28845	Economy	6300.00
0005434463975	28845	Economy	6300.00
0005432848610	28845	Economy	6300.00
0005435851171	28845	Economy	6300.00
0005434463976	28845	Economy	6300.00
0005432848624	28845	Economy	6300.00
0005432848645	28845	Economy	6300.00
0005435851173	28845	Economy	6300.00
0005435851172	28845	Economy	6300.00
0005432848619	28845	Economy	6300.00
0005435851170	28845	Economy	6300.00
0005432848611	28845	Economy	6300.00
0005432848625	28845	Economy	6300.00
0005432848612	28845	Economy	6300.00
0005432848646	28845	Economy	6300.00
0005432848643	28845	Economy	6300.00
0005434461682	28845	Economy	6300.00
0005435851175	28845	Economy	6300.00
0005432848644	28845	Economy	6300.00
0005433497869	6264	Business	11900.00
0005434926797	6264	Business	11900.00
0005434926803	6264	Business	11900.00
0005433497866	6264	Business	11900.00
0005433497871	6264	Business	11900.00
0005434926795	6264	Business	11900.00
0005434926796	6264	Business	11900.00
0005435257421	6264	Business	11900.00
0005434926814	6264	Economy	4000.00
0005433497862	6264	Economy	4000.00
0005434926816	6264	Economy	4000.00
0005435257435	6264	Economy	4000.00
0005434926817	6264	Economy	4000.00
0005433497864	6264	Economy	4000.00
0005434926798	6264	Economy	4000.00
0005435257409	6264	Economy	4000.00
0005434444171	6264	Economy	4400.00
0005433497861	6264	Economy	4400.00
0005434926805	6264	Economy	4400.00
0005434926804	6264	Economy	4000.00
0005435257425	6264	Economy	4000.00
0005433497859	6264	Economy	4000.00
0005433497868	6264	Economy	4000.00
0005433497870	6264	Economy	4000.00
0005435257457	6264	Economy	4000.00
0005435257420	6264	Economy	4000.00
0005433497865	6264	Economy	4000.00
0005433497863	6264	Economy	4000.00
0005432075323	6264	Economy	4000.00
0005434926808	6264	Economy	4000.00
0005434444174	6264	Economy	4000.00
0005434926815	6264	Economy	4000.00
0005434926810	6264	Economy	4000.00
0005434444175	6264	Economy	4000.00
0005435257453	6264	Economy	4000.00
0005435257412	6264	Economy	4000.00
0005434926806	6264	Economy	4000.00
0005433497860	6264	Economy	4000.00
0005434444176	6264	Economy	4000.00
0005434926809	6264	Economy	4000.00
0005435257410	6264	Economy	4000.00
0005434926799	6264	Economy	4000.00
0005434926813	6264	Economy	4000.00
0005434926812	6264	Economy	4000.00
0005435257424	6264	Economy	4000.00
0005434926800	6264	Economy	4000.00
0005435257431	6264	Economy	4000.00
0005433497867	6264	Economy	4000.00
0005433497872	6264	Economy	4000.00
0005434444172	6264	Economy	4000.00
0005432075322	6264	Economy	4000.00
0005434926807	6264	Economy	4000.00
0005435257452	6264	Economy	4000.00
0005434444173	6264	Economy	4000.00
0005434926811	6264	Economy	4000.00
0005435257436	6264	Economy	4000.00
0005434926801	6264	Economy	4000.00
0005434926802	6264	Economy	4000.00
0005435257432	6264	Economy	4000.00
0005435257426	6264	Economy	4000.00
0005435257456	6264	Economy	4000.00
0005435257533	20361	Economy	4000.00
0005435257531	20361	Economy	4000.00
0005435257532	20361	Economy	4000.00
0005435257534	20361	Economy	4000.00
0005433497705	20335	Business	11900.00
0005434444001	20335	Business	11900.00
0005433497701	20335	Business	11900.00
0005434926416	20335	Business	11900.00
0005434926418	20335	Business	11900.00
0005434926453	20335	Business	11900.00
0005433497616	20335	Business	11900.00
0005434443958	20335	Business	11900.00
0005433497685	20335	Business	11900.00
0005434926415	20335	Business	11900.00
0005434444032	20335	Business	11900.00
0005434444015	20335	Economy	4000.00
0005434926354	20335	Economy	4000.00
0005433497779	20335	Economy	4000.00
0005434443957	20335	Economy	4000.00
0005434926432	20335	Economy	4000.00
0005434926439	20335	Economy	4000.00
0005434444113	20335	Economy	4000.00
0005433497757	20335	Economy	4000.00
0005434926437	20335	Economy	4400.00
0005433497509	20335	Economy	4400.00
0005433497601	20335	Economy	4400.00
0005434926391	20335	Economy	4400.00
0005433497579	20335	Economy	4400.00
0005434926368	20335	Economy	4000.00
0005433497603	20335	Economy	4000.00
0005434444013	20335	Economy	4000.00
0005433497722	20335	Economy	4000.00
0005434926394	20335	Economy	4000.00
0005434926371	20335	Economy	4000.00
0005434926348	20335	Economy	4000.00
0005434443996	20335	Economy	4000.00
0005434926434	20335	Economy	4000.00
0005434926392	20335	Economy	4000.00
0005434444097	20335	Economy	4000.00
0005434926465	20335	Economy	4000.00
0005433497674	20335	Economy	4000.00
0005434444016	20335	Economy	4000.00
0005433497595	20335	Economy	4000.00
0005433497675	20335	Economy	4000.00
0005434926353	20335	Economy	4000.00
0005433497611	20335	Economy	4000.00
0005434926436	20335	Economy	4000.00
0005434926407	20335	Economy	4000.00
0005433497707	20335	Economy	4000.00
0005433497763	20335	Economy	4000.00
0005433497647	20335	Economy	4000.00
0005433497643	20335	Economy	4000.00
0005433497550	20335	Economy	4000.00
0005433497586	20335	Economy	4000.00
0005433497759	20335	Economy	4000.00
0005434926246	20335	Economy	4000.00
0005433497508	20335	Economy	4000.00
0005434926433	20335	Economy	4000.00
0005434926408	20335	Economy	4000.00
0005434926430	20335	Economy	4000.00
0005433497708	20335	Economy	4000.00
0005433497673	20335	Economy	4000.00
0005434444046	20335	Economy	4000.00
0005433497781	20335	Economy	4000.00
0005434444000	20335	Economy	4000.00
0005433497642	20335	Economy	4000.00
0005434926455	20335	Economy	4000.00
0005433497564	20335	Economy	4000.00
0005433497758	20335	Economy	4000.00
0005434926380	20335	Economy	4000.00
0005434926406	20335	Economy	4000.00
0005433497600	20335	Economy	4000.00
0005433497676	20335	Economy	4000.00
0005433497780	20335	Economy	4000.00
0005434926435	20335	Economy	4000.00
0005433497679	20335	Economy	4000.00
0005433497753	20335	Economy	4000.00
0005433497680	20335	Economy	4000.00
0005433497596	20335	Economy	4000.00
0005433497690	20335	Economy	4000.00
0005434926414	20335	Economy	4000.00
0005434926364	20335	Economy	4000.00
0005434926454	20335	Economy	4000.00
0005434444045	20335	Economy	4000.00
0005433497587	20335	Economy	4000.00
0005433497738	20335	Economy	4000.00
0005434926365	20335	Economy	4000.00
0005433497648	20335	Economy	4000.00
0005433497785	20335	Economy	4000.00
0005433497624	20335	Economy	4000.00
0005434444109	20335	Economy	4000.00
0005433497646	20335	Economy	4000.00
0005434926413	20335	Economy	4000.00
0005435243633	12186	Business	41200.00
0005432785088	12186	Business	41200.00
0005432784993	12186	Business	41200.00
0005432785049	12186	Business	41200.00
0005432785103	12186	Business	41200.00
0005432785069	12186	Economy	13700.00
0005435243641	12186	Economy	13700.00
0005432785015	12186	Economy	13700.00
0005435243629	12186	Economy	13700.00
0005432784923	12186	Economy	13700.00
0005432784908	12186	Economy	15100.00
0005432784628	12186	Economy	15100.00
0005435243632	12186	Economy	13700.00
0005432784856	12186	Economy	13700.00
0005435243639	12186	Economy	13700.00
0005432784813	12186	Economy	13700.00
0005432785084	12186	Economy	13700.00
0005435243630	12186	Economy	13700.00
0005432785055	12186	Economy	13700.00
0005435243637	12186	Economy	13700.00
0005432785094	12186	Economy	13700.00
0005435243635	12186	Economy	13700.00
0005432785014	12186	Economy	13700.00
0005432784943	12186	Economy	13700.00
0005435243636	12186	Economy	13700.00
0005432785121	12186	Economy	13700.00
0005432784889	12186	Economy	13700.00
0005432785019	12186	Economy	13700.00
0005435243628	12186	Economy	13700.00
0005432784796	12186	Economy	13700.00
0005432785013	12186	Economy	13700.00
0005432784883	12186	Economy	13700.00
0005432784882	12186	Economy	13700.00
0005432784988	12186	Economy	13700.00
0005432784717	12186	Economy	13700.00
0005432785016	12186	Economy	13700.00
0005432784893	12186	Economy	13700.00
0005432785083	12186	Economy	13700.00
0005432785068	12186	Economy	13700.00
0005432784974	12186	Economy	13700.00
0005432784939	12186	Economy	13700.00
0005432785031	12186	Economy	13700.00
0005435243640	12186	Economy	13700.00
0005432784905	12186	Economy	13700.00
0005432784781	12186	Economy	13700.00
0005435243642	12186	Economy	13700.00
0005432785085	12186	Economy	13700.00
0005435243631	12186	Economy	13700.00
0005432784828	12186	Economy	13700.00
0005435243643	12186	Economy	13700.00
0005435243638	12186	Economy	13700.00
0005432784795	12186	Economy	13700.00
0005435243634	12186	Economy	13700.00
0005432784829	12186	Economy	13700.00
0005435243281	15440	Business	41200.00
0005432785285	15440	Business	41200.00
0005432785306	15440	Business	41200.00
0005432785297	15440	Business	41200.00
0005432785296	15440	Business	41200.00
0005435243417	15440	Business	41200.00
0005432785309	15440	Economy	13700.00
0005435243268	15440	Economy	13700.00
0005432785299	15440	Economy	13700.00
0005432785310	15440	Economy	13700.00
0005432785303	15440	Economy	13700.00
0005435243457	15440	Economy	15100.00
0005435243322	15440	Economy	15100.00
0005432785293	15440	Economy	15100.00
0005432785311	15440	Economy	13700.00
0005432785291	15440	Economy	13700.00
0005435243300	15440	Economy	13700.00
0005432785286	15440	Economy	13700.00
0005435243378	15440	Economy	13700.00
0005435243405	15440	Economy	13700.00
0005432785294	15440	Economy	13700.00
0005435243309	15440	Economy	13700.00
0005435243266	15440	Economy	13700.00
0005435243424	15440	Economy	13700.00
0005432785313	15440	Economy	13700.00
0005432785312	15440	Economy	13700.00
0005432785300	15440	Economy	13700.00
0005432785308	15440	Economy	13700.00
0005435243458	15440	Economy	13700.00
0005432785289	15440	Economy	13700.00
0005435243364	15440	Economy	13700.00
0005435243418	15440	Economy	13700.00
0005432785290	15440	Economy	13700.00
0005435243299	15440	Economy	13700.00
0005432785314	15440	Economy	13700.00
0005432785295	15440	Economy	13700.00
0005432785292	15440	Economy	13700.00
0005432785298	15440	Economy	13700.00
0005432785304	15440	Economy	13700.00
0005432785287	15440	Economy	13700.00
0005435243369	15440	Economy	13700.00
0005435243301	15440	Economy	13700.00
0005432785301	15440	Economy	13700.00
0005435243335	15440	Economy	13700.00
0005435243350	15440	Economy	13700.00
0005432785302	15440	Economy	13700.00
0005432785307	15440	Economy	13700.00
0005435243280	15440	Economy	13700.00
0005432785288	15440	Economy	13700.00
0005435243306	15440	Economy	13700.00
0005432785305	15440	Economy	13700.00
0005435243396	15440	Economy	13700.00
0005435243397	15440	Economy	13700.00
0005434880261	10065	Business	49700.00
0005434880206	10065	Business	49700.00
0005434880201	10065	Business	49700.00
0005434880586	10065	Business	49700.00
0005434879857	10065	Business	49700.00
0005435914175	10065	Business	49700.00
0005434880275	10065	Business	49700.00
0005434880224	10065	Business	49700.00
0005434880377	10065	Business	49700.00
0005434880321	10065	Business	49700.00
0005434880325	10065	Business	49700.00
0005434880306	10065	Business	49700.00
0005434880447	10065	Business	49700.00
0005434880314	10065	Business	49700.00
0005434880192	10065	Business	49700.00
0005434880140	10065	Business	49700.00
0005434880017	10065	Business	49700.00
0005434880273	10065	Business	49700.00
0005434880583	10065	Business	49700.00
0005434880139	10065	Economy	16600.00
0005434880183	10065	Business	49700.00
0005434879972	10065	Economy	16600.00
0005434879855	10065	Economy	16600.00
0005434880143	10065	Economy	16600.00
0005434880322	10065	Economy	16600.00
0005435914166	10065	Economy	16600.00
0005435914167	10065	Economy	16600.00
0005434880204	10065	Economy	16600.00
0005434880443	10065	Economy	16600.00
0005434880126	10065	Economy	16600.00
0005434880577	10065	Economy	16600.00
0005434880356	10065	Economy	16600.00
0005434880244	10065	Economy	16600.00
0005434880448	10065	Economy	18200.00
0005434880115	10065	Economy	18200.00
0005434880141	10065	Economy	18200.00
0005435914178	10065	Economy	16600.00
0005434880269	10065	Economy	18200.00
0005435914173	10065	Economy	16600.00
0005434880347	10065	Economy	16600.00
0005434879981	10065	Economy	16600.00
0005434880433	10065	Economy	16600.00
0005434910182	10065	Economy	16600.00
0005435914172	10065	Economy	16600.00
0005434880189	10065	Economy	16600.00
0005434880301	10065	Economy	16600.00
0005434880245	10065	Economy	16600.00
0005435914162	10065	Economy	16600.00
0005434880603	10065	Economy	16600.00
0005434880145	10065	Economy	16600.00
0005434880432	10065	Economy	16600.00
0005434880174	10065	Economy	16600.00
0005435914174	10065	Economy	16600.00
0005434880067	10065	Economy	16600.00
0005434880114	10065	Economy	16600.00
0005434880346	10065	Economy	16600.00
0005434880195	10065	Economy	16600.00
0005434880223	10065	Economy	16600.00
0005434880299	10065	Economy	16600.00
0005434880307	10065	Economy	16600.00
0005435914171	10065	Economy	16600.00
0005434879856	10065	Economy	16600.00
0005435914170	10065	Economy	16600.00
0005434758940	10065	Economy	16600.00
0005434880243	10065	Economy	16600.00
0005434880202	10065	Economy	16600.00
0005434880098	10065	Economy	16600.00
0005434880320	10065	Economy	16600.00
0005434880099	10065	Economy	16600.00
0005434880121	10065	Economy	16600.00
0005434880538	10065	Economy	16600.00
0005435914168	10065	Economy	16600.00
0005435914177	10065	Economy	16600.00
0005435914181	10065	Economy	16600.00
0005434880191	10065	Economy	16600.00
0005434880127	10065	Economy	16600.00
0005435914165	10065	Economy	16600.00
0005434880125	10065	Economy	16600.00
0005434880386	10065	Economy	16600.00
0005434880430	10065	Economy	16600.00
0005435914169	10065	Economy	16600.00
0005434880262	10065	Economy	16600.00
0005434879794	10065	Economy	16600.00
0005435914179	10065	Economy	16600.00
0005434880190	10065	Economy	16600.00
0005434879795	10065	Economy	16600.00
0005434880480	10065	Economy	16600.00
0005434880161	10065	Economy	16600.00
0005434880203	10065	Economy	16600.00
0005434880585	10065	Economy	16600.00
0005434879841	10065	Economy	16600.00
0005434880298	10065	Economy	16600.00
0005434880652	10065	Economy	16600.00
0005434879739	10065	Economy	16600.00
0005434880046	10065	Economy	16600.00
0005434880268	10065	Economy	16600.00
0005435914163	10065	Economy	16600.00
0005434880045	10065	Economy	16600.00
0005434880197	10065	Economy	16600.00
0005435914180	10065	Economy	16600.00
0005434880470	10065	Economy	16600.00
0005434880284	10065	Economy	16600.00
0005434880404	10065	Economy	16600.00
0005434880196	10065	Economy	16600.00
0005434879973	10065	Economy	16600.00
0005434880283	10065	Economy	16600.00
0005435914176	10065	Economy	16600.00
0005434880144	10065	Economy	16600.00
0005434880431	10065	Economy	16600.00
0005434880324	10065	Economy	16600.00
0005434880387	10065	Economy	16600.00
0005434880276	10065	Economy	16600.00
0005434880116	10065	Economy	16600.00
0005434879740	10065	Economy	16600.00
0005435914164	10065	Economy	16600.00
0005434880162	10065	Economy	16600.00
0005434880910	14594	Business	49700.00
0005434880900	14594	Business	49700.00
0005434880901	14594	Business	49700.00
0005434880905	14594	Business	49700.00
0005434880935	14594	Business	49700.00
0005434880904	14594	Business	49700.00
0005434880933	14594	Business	49700.00
0005434880936	14594	Business	49700.00
0005434880934	14594	Business	49700.00
0005434880927	14594	Business	49700.00
0005434880907	14594	Economy	16600.00
0005434880932	14594	Economy	16600.00
0005434880922	14594	Economy	16600.00
0005434880939	14594	Economy	16600.00
0005434880930	14594	Economy	16600.00
0005434880928	14594	Economy	16600.00
0005434880903	14594	Economy	16600.00
0005434880911	14594	Economy	18200.00
0005435913988	14594	Economy	16600.00
0005434880917	14594	Economy	16600.00
0005434880926	14594	Economy	16600.00
0005435914032	14594	Economy	16600.00
0005434880924	14594	Economy	16600.00
0005434880906	14594	Economy	16600.00
0005434880919	14594	Economy	16600.00
0005434880912	14594	Economy	16600.00
0005434880908	14594	Economy	16600.00
0005434880925	14594	Economy	16600.00
0005434880918	14594	Economy	16600.00
0005435913992	14594	Economy	16600.00
0005434880914	14594	Economy	16600.00
0005435914010	14594	Economy	16600.00
0005434880915	14594	Economy	16600.00
0005435914041	14594	Economy	16600.00
0005434880931	14594	Economy	16600.00
0005435914009	14594	Economy	16600.00
0005434880916	14594	Economy	16600.00
0005434880909	14594	Economy	16600.00
0005434880899	14594	Economy	16600.00
0005434880920	14594	Economy	16600.00
0005434910145	14594	Economy	16600.00
0005434880940	14594	Economy	16600.00
0005434880921	14594	Economy	16600.00
0005434880929	14594	Economy	16600.00
0005434880902	14594	Economy	16600.00
0005434880923	14594	Economy	16600.00
0005434880938	14594	Economy	16600.00
0005434880937	14594	Economy	16600.00
0005434880913	14594	Economy	16600.00
0005435914030	14594	Economy	16600.00
0005435914008	14594	Economy	16600.00
0005435660457	9228	Economy	20300.00
0005434252169	9228	Economy	20300.00
0005434252183	9228	Economy	20300.00
0005434252128	9228	Economy	20300.00
0005434252177	9228	Economy	20300.00
0005435660458	9228	Economy	20300.00
0005435660460	9228	Economy	20300.00
0005434252178	9228	Economy	20300.00
0005434252182	9228	Economy	20300.00
0005435660462	9228	Economy	20300.00
0005434252181	9228	Economy	20300.00
0005435660456	9228	Economy	20300.00
0005435660463	9228	Economy	20300.00
0005435660461	9228	Economy	20300.00
0005435660459	9228	Economy	20300.00
0005435660363	24626	Economy	20300.00
0005435660364	24626	Economy	20300.00
0005434252238	24626	Economy	20300.00
0005435933565	24626	Economy	20300.00
0005435660379	24626	Economy	20300.00
0005435933558	24626	Economy	20300.00
0005434252239	24626	Economy	20300.00
0005434252242	24626	Economy	20300.00
0005435933564	24626	Economy	20300.00
0005435933559	24626	Economy	20300.00
0005435660394	24626	Economy	20300.00
0005435660353	24626	Economy	20300.00
0005435660354	24626	Economy	20300.00
0005434252241	24626	Economy	20300.00
0005434252240	24626	Economy	20300.00
0005433681932	2778	Business	33000.00
0005433681941	2778	Business	33000.00
0005433681926	2778	Business	33000.00
0005433681921	2778	Business	33000.00
0005433681930	2778	Business	33000.00
0005433681931	2778	Business	33000.00
0005432967487	2778	Economy	11000.00
0005433681928	2778	Economy	11000.00
0005433681933	2778	Economy	11000.00
0005432967529	2778	Economy	12100.00
0005432967537	2778	Economy	12100.00
0005432967563	2778	Economy	12100.00
0005432967392	2778	Economy	11000.00
0005432967404	2778	Economy	11000.00
0005433681936	2778	Economy	11000.00
0005433681939	2778	Economy	11000.00
0005433681942	2778	Economy	11000.00
0005432967374	2778	Economy	11000.00
0005433681938	2778	Economy	11000.00
0005433681927	2778	Economy	11000.00
0005432222935	2778	Economy	11000.00
0005433681922	2778	Economy	11000.00
0005433681934	2778	Economy	11000.00
0005433681924	2778	Economy	11000.00
0005432967477	2778	Economy	11000.00
0005432967514	2778	Economy	11000.00
0005433681944	2778	Economy	11000.00
0005433684481	2778	Economy	11000.00
0005433681937	2778	Economy	11000.00
0005433681925	2778	Economy	11000.00
0005432967572	2778	Economy	11000.00
0005433681929	2778	Economy	11000.00
0005433681923	2778	Economy	11000.00
0005432967373	2778	Economy	11000.00
0005433681920	2778	Economy	11000.00
0005433681943	2778	Economy	11000.00
0005432967486	2778	Economy	11000.00
0005433681940	2778	Economy	11000.00
0005432967435	2778	Economy	11000.00
0005433684479	2778	Economy	11000.00
0005432967420	2778	Economy	11000.00
0005433684480	2778	Economy	11000.00
0005432222934	2778	Economy	11000.00
0005433681935	2778	Economy	11000.00
0005432967459	2778	Economy	11000.00
0005433681512	29152	Business	33000.00
0005432967664	29152	Business	33000.00
0005433681591	29152	Business	33000.00
0005433681787	29152	Business	33000.00
0005433681580	29152	Business	33000.00
0005433681540	29152	Business	33000.00
0005432967666	29152	Business	33000.00
0005433681827	29152	Business	33000.00
0005432967669	29152	Business	33000.00
0005433681656	29152	Business	33000.00
0005433681865	29152	Business	33000.00
0005433681623	29152	Economy	11000.00
0005433681477	29152	Economy	11000.00
0005433681447	29152	Economy	11000.00
0005433681518	29152	Economy	11000.00
0005433681670	29152	Economy	11000.00
0005433681828	29152	Economy	11000.00
0005433690962	29152	Economy	12100.00
0005433681501	29152	Economy	12100.00
0005433681604	29152	Economy	11000.00
0005432967665	29152	Economy	11000.00
0005432967668	29152	Economy	11000.00
0005433690968	29152	Economy	11000.00
0005433681632	29152	Economy	11000.00
0005433681696	29152	Economy	11000.00
0005433681690	29152	Economy	11000.00
0005433690963	29152	Economy	11000.00
0005433681700	29152	Economy	11000.00
0005433681626	29152	Economy	11000.00
0005432967658	29152	Economy	11000.00
0005432967657	29152	Economy	11000.00
0005433681678	29152	Economy	11000.00
0005433681649	29152	Economy	11000.00
0005433690964	29152	Economy	11000.00
0005433681746	29152	Economy	11000.00
0005433681446	29152	Economy	11000.00
0005432967663	29152	Economy	11000.00
0005433681572	29152	Economy	11000.00
0005432967660	29152	Economy	11000.00
0005433681478	29152	Economy	11000.00
0005432967667	29152	Economy	11000.00
0005432967670	29152	Economy	11000.00
0005433681535	29152	Economy	11000.00
0005433681504	29152	Economy	11000.00
0005433681691	29152	Economy	11000.00
0005433681581	29152	Economy	11000.00
0005433681633	29152	Economy	11000.00
0005432967662	29152	Economy	11000.00
0005433681624	29152	Economy	11000.00
0005433681514	29152	Economy	11000.00
0005433681635	29152	Economy	11000.00
0005433681811	29152	Economy	11000.00
0005433681686	29152	Economy	11000.00
0005433681679	29152	Economy	11000.00
0005433681767	29152	Economy	11000.00
0005433681655	29152	Economy	11000.00
0005432967659	29152	Economy	11000.00
0005433681653	29152	Economy	11000.00
0005433681701	29152	Economy	11000.00
0005433681642	29152	Economy	11000.00
0005433681766	29152	Economy	11000.00
0005433681476	29152	Economy	11000.00
0005433681721	29152	Economy	11000.00
0005433681810	29152	Economy	11000.00
0005433690966	29152	Economy	11000.00
0005433681625	29152	Economy	11000.00
0005432967661	29152	Economy	11000.00
0005433681505	29152	Economy	11000.00
0005433681605	29152	Economy	11000.00
0005433681665	29152	Economy	11000.00
0005433681586	29152	Economy	11000.00
0005433616747	9305	Business	132900.00
0005433634771	9305	Business	132900.00
0005433616751	9305	Business	132900.00
0005433634768	9305	Business	132900.00
0005433616735	9305	Business	132900.00
0005433634788	9305	Business	132900.00
0005433616728	9305	Business	132900.00
0005432755171	9305	Business	132900.00
0005433634769	9305	Business	132900.00
0005433616731	9305	Business	132900.00
0005433634778	9305	Business	132900.00
0005433616729	9305	Business	132900.00
0005433616733	9305	Economy	48700.00
0005433616749	9305	Economy	48700.00
0005433616725	9305	Economy	48700.00
0005433616719	9305	Economy	44300.00
0005433578193	9305	Economy	44300.00
0005433616723	9305	Economy	44300.00
0005435983707	9305	Economy	44300.00
0005434163792	9305	Economy	44300.00
0005433616738	9305	Economy	44300.00
0005432145169	9305	Economy	44300.00
0005435983711	9305	Economy	44300.00
0005433616741	9305	Economy	44300.00
0005435983710	9305	Economy	44300.00
0005434163825	9305	Economy	44300.00
0005433616736	9305	Economy	44300.00
0005433616717	9305	Economy	44300.00
0005434163819	9305	Economy	44300.00
0005433634780	9305	Economy	44300.00
0005433616745	9305	Economy	44300.00
0005434163801	9305	Economy	44300.00
0005433616713	9305	Economy	44300.00
0005433634792	9305	Economy	44300.00
0005433616718	9305	Economy	44300.00
0005434163798	9305	Economy	44300.00
0005433578194	9305	Economy	44300.00
0005435983708	9305	Economy	44300.00
0005433616755	9305	Economy	44300.00
0005433616716	9305	Economy	44300.00
0005433616753	9305	Economy	44300.00
0005434163806	9305	Economy	44300.00
0005433616724	9305	Economy	44300.00
0005433616727	9305	Economy	44300.00
0005433616737	9305	Economy	44300.00
0005433616743	9305	Economy	44300.00
0005433616720	9305	Economy	44300.00
0005433634790	9305	Economy	48700.00
0005433634784	9305	Economy	48700.00
0005433634779	9305	Economy	48700.00
0005435983709	9305	Economy	48700.00
0005433616714	9305	Economy	44300.00
0005433616722	9305	Economy	48700.00
0005433634791	9305	Economy	44300.00
0005433634793	9305	Economy	44300.00
0005433634782	9305	Economy	44300.00
0005433616748	9305	Economy	44300.00
0005433616726	9305	Economy	44300.00
0005433634787	9305	Economy	44300.00
0005433634783	9305	Economy	44300.00
0005433616740	9305	Economy	44300.00
0005433616715	9305	Economy	44300.00
0005433616754	9305	Economy	44300.00
0005433634774	9305	Economy	44300.00
0005433634767	9305	Economy	44300.00
0005435983705	9305	Economy	44300.00
0005433634781	9305	Economy	44300.00
0005433616739	9305	Economy	44300.00
0005433634786	9305	Economy	44300.00
0005433634775	9305	Economy	44300.00
0005434163803	9305	Economy	44300.00
0005433634789	9305	Economy	44300.00
0005435983706	9305	Economy	44300.00
0005433616732	9305	Economy	44300.00
0005433616750	9305	Economy	44300.00
0005433634777	9305	Economy	44300.00
0005433616742	9305	Economy	44300.00
0005434163807	9305	Economy	44300.00
0005433616744	9305	Economy	44300.00
0005433634785	9305	Economy	44300.00
0005434163844	9305	Economy	44300.00
0005433616746	9305	Economy	44300.00
0005433616730	9305	Economy	44300.00
0005433634776	9305	Economy	44300.00
0005433616752	9305	Economy	44300.00
0005433634773	9305	Economy	44300.00
0005433634770	9305	Economy	44300.00
0005433616734	9305	Economy	44300.00
0005433634772	9305	Economy	44300.00
0005432756939	9305	Economy	44300.00
0005433616721	9305	Economy	44300.00
0005433578192	9305	Economy	44300.00
0005433616222	25230	Business	132900.00
0005433634533	25230	Business	132900.00
0005433616305	25230	Business	132900.00
0005433616050	25230	Business	132900.00
0005433634558	25230	Business	132900.00
0005433634335	25230	Business	132900.00
0005434163880	25230	Business	132900.00
0005433616145	25230	Business	132900.00
0005433616183	25230	Business	132900.00
0005433578085	25230	Business	132900.00
0005434273123	25230	Business	132900.00
0005433616209	25230	Business	132900.00
0005433616411	25230	Business	132900.00
0005433634493	25230	Business	132900.00
0005433616028	25230	Business	132900.00
0005433578061	25230	Business	132900.00
0005433616062	25230	Business	132900.00
0005433616504	25230	Business	132900.00
0005433634358	25230	Business	132900.00
0005433615948	25230	Business	132900.00
0005433616342	25230	Business	132900.00
0005433634532	25230	Business	132900.00
0005433634515	25230	Business	132900.00
0005433616415	25230	Business	132900.00
0005433634468	25230	Business	132900.00
0005433616063	25230	Business	132900.00
0005433616014	25230	Business	132900.00
0005433616332	25230	Business	132900.00
0005433634483	25230	Economy	48700.00
0005433616292	25230	Economy	48700.00
0005434163879	25230	Economy	48700.00
0005433616321	25230	Economy	48700.00
0005433634454	25230	Economy	48700.00
0005433616360	25230	Economy	48700.00
0005433634368	25230	Economy	44300.00
0005433616083	25230	Economy	44300.00
0005433616235	25230	Economy	44300.00
0005433634453	25230	Economy	44300.00
0005433634416	25230	Economy	44300.00
0005433616199	25230	Economy	44300.00
0005433616253	25230	Economy	44300.00
0005433615939	25230	Economy	44300.00
0005433616320	25230	Economy	44300.00
0005433634530	25230	Economy	44300.00
0005433616413	25230	Economy	44300.00
0005434163875	25230	Economy	44300.00
0005433616160	25230	Economy	44300.00
0005434273124	25230	Economy	44300.00
0005433578101	25230	Economy	44300.00
0005433615821	25230	Economy	44300.00
0005433616159	25230	Economy	44300.00
0005434273125	25230	Economy	44300.00
0005433616410	25230	Economy	44300.00
0005433616257	25230	Economy	44300.00
0005433616412	25230	Economy	44300.00
0005433616092	25230	Economy	44300.00
0005433615988	25230	Economy	44300.00
0005433578096	25230	Economy	44300.00
0005433634442	25230	Economy	44300.00
0005433616039	25230	Economy	44300.00
0005433616179	25230	Economy	44300.00
0005433616289	25230	Economy	44300.00
0005433616138	25230	Economy	44300.00
0005433615720	25230	Economy	44300.00
0005433578110	25230	Economy	44300.00
0005433616146	25230	Economy	44300.00
0005433634503	25230	Economy	44300.00
0005433616444	25230	Economy	44300.00
0005433634509	25230	Economy	44300.00
0005433616010	25230	Economy	44300.00
0005434272237	25230	Economy	44300.00
0005434163878	25230	Economy	44300.00
0005433634357	25230	Economy	44300.00
0005433634441	25230	Economy	44300.00
0005433578093	25230	Economy	44300.00
0005433616165	25230	Economy	44300.00
0005433616210	25230	Economy	44300.00
0005433616058	25230	Economy	44300.00
0005433615952	25230	Economy	44300.00
0005433616484	25230	Economy	44300.00
0005433616091	25230	Economy	44300.00
0005433615899	25230	Economy	44300.00
0005433616293	25230	Economy	44300.00
0005433616144	25230	Economy	44300.00
0005433634534	25230	Economy	44300.00
0005433615898	25230	Economy	44300.00
0005433578033	25230	Economy	44300.00
0005433634492	25230	Economy	44300.00
0005433616212	25230	Economy	44300.00
0005433616106	25230	Economy	48700.00
0005433616443	25230	Economy	48700.00
0005433616378	25230	Economy	48700.00
0005433615871	25230	Economy	48700.00
0005433616047	25230	Economy	48700.00
0005433616093	25230	Economy	44300.00
0005433616002	25230	Economy	44300.00
0005433634504	25230	Economy	44300.00
0005433578045	25230	Economy	44300.00
0005433616089	25230	Economy	48700.00
0005433634369	25230	Economy	44300.00
0005433615931	25230	Economy	44300.00
0005433616246	25230	Economy	44300.00
0005433616067	25230	Economy	44300.00
0005433634619	25230	Economy	44300.00
0005433616090	25230	Economy	44300.00
0005433616068	25230	Economy	44300.00
0005434163876	25230	Economy	44300.00
0005433616214	25230	Economy	44300.00
0005433616084	25230	Economy	44300.00
0005433634391	25230	Economy	44300.00
0005433616158	25230	Economy	44300.00
0005433615822	25230	Economy	44300.00
0005433616358	25230	Economy	44300.00
0005433616315	25230	Economy	44300.00
0005433615721	25230	Economy	44300.00
0005433615866	25230	Economy	44300.00
0005433616221	25230	Economy	44300.00
0005433616291	25230	Economy	44300.00
0005433616206	25230	Economy	44300.00
0005433616319	25230	Economy	44300.00
0005433578077	25230	Economy	44300.00
0005433634485	25230	Economy	44300.00
0005433578095	25230	Economy	44300.00
0005433616048	25230	Economy	44300.00
0005433634487	25230	Economy	44300.00
0005433616035	25230	Economy	44300.00
0005434163877	25230	Economy	44300.00
0005433616345	25230	Economy	44300.00
0005433634475	25230	Economy	44300.00
0005433616240	25230	Economy	44300.00
0005433616140	25230	Economy	44300.00
0005434272236	25230	Economy	44300.00
0005433578099	25230	Economy	44300.00
0005433578062	25230	Economy	44300.00
0005433616154	25230	Economy	44300.00
0005433616379	25230	Economy	44300.00
0005433616202	25230	Economy	44300.00
0005433616088	25230	Economy	44300.00
0005433616054	25230	Economy	44300.00
0005433634415	25230	Economy	44300.00
0005433634538	25230	Economy	44300.00
0005433615722	25230	Economy	44300.00
0005433578034	25230	Economy	44300.00
0005433616258	25230	Economy	44300.00
0005433634531	25230	Economy	44300.00
0005433634559	25230	Economy	44300.00
0005433616316	25230	Economy	44300.00
0005433634494	25230	Economy	44300.00
0005433616205	25230	Economy	44300.00
0005433578044	25230	Economy	44300.00
0005433578111	25230	Economy	44300.00
0005433616259	25230	Economy	44300.00
0005433616414	25230	Economy	44300.00
0005433616107	25230	Economy	44300.00
0005434272235	25230	Economy	44300.00
0005433616211	25230	Economy	44300.00
0005433616213	25230	Economy	44300.00
0005434163881	25230	Economy	44300.00
0005433616452	25230	Economy	44300.00
0005433616049	25230	Economy	44300.00
0005435987044	4244	Business	193100.00
0005435987042	4244	Business	193100.00
0005435960172	4244	Business	193100.00
0005432571407	4244	Business	193100.00
0005435987045	4244	Business	193100.00
0005435987035	4244	Business	193100.00
0005435856299	4244	Business	193100.00
0005435947579	4244	Economy	70800.00
0005435947559	4244	Economy	70800.00
0005435854071	4244	Economy	64400.00
0005432571401	4244	Economy	64400.00
0005435987033	4244	Economy	64400.00
0005435987039	4244	Economy	64400.00
0005435787391	4244	Economy	64400.00
0005435987036	4244	Economy	64400.00
0005435854074	4244	Economy	64400.00
0005435947560	4244	Economy	64400.00
0005435960171	4244	Economy	64400.00
0005432571399	4244	Economy	64400.00
0005435947582	4244	Economy	64400.00
0005435987041	4244	Economy	64400.00
0005432571400	4244	Economy	64400.00
0005435947520	4244	Economy	64400.00
0005435987040	4244	Economy	64400.00
0005435856260	4244	Economy	64400.00
0005435947519	4244	Economy	64400.00
0005432571398	4244	Economy	64400.00
0005435947553	4244	Economy	64400.00
0005435947516	4244	Economy	64400.00
0005432571375	4244	Economy	64400.00
0005435947552	4244	Economy	64400.00
0005435987037	4244	Economy	64400.00
0005435947577	4244	Economy	64400.00
0005435947589	4244	Economy	64400.00
0005435987034	4244	Economy	64400.00
0005432571403	4244	Economy	64400.00
0005435987046	4244	Economy	64400.00
0005435960173	4244	Economy	64400.00
0005435947568	4244	Economy	64400.00
0005435987038	4244	Economy	64400.00
0005435856298	4244	Economy	64400.00
0005432185031	4244	Economy	64400.00
0005435947566	4244	Economy	64400.00
0005435987043	4244	Economy	64400.00
0005432571402	4244	Economy	64400.00
0005435947615	4244	Economy	64400.00
0005435787414	26577	Business	193100.00
0005435856361	26577	Business	193100.00
0005435986926	26577	Business	193100.00
0005435856327	26577	Economy	70800.00
0005435986925	26577	Economy	70800.00
0005435947667	26577	Economy	64400.00
0005435986894	26577	Economy	64400.00
0005435856329	26577	Economy	64400.00
0005435986954	26577	Economy	64400.00
0005435947666	26577	Economy	64400.00
0005432571434	26577	Economy	64400.00
0005435947668	26577	Economy	64400.00
0005435787413	26577	Economy	64400.00
0005435986914	26577	Economy	70800.00
0005435986953	26577	Economy	64400.00
0005435947670	26577	Economy	64400.00
0005435787415	26577	Economy	64400.00
0005435856328	26577	Economy	64400.00
0005435986955	26577	Economy	64400.00
0005435947669	26577	Economy	64400.00
0005432949187	347	Business	21500.00
0005433075373	347	Business	21500.00
0005432949323	347	Business	21500.00
0005432949310	347	Business	21500.00
0005432949308	347	Business	21500.00
0005432949185	347	Business	21500.00
0005434087983	347	Business	21500.00
0005434088001	347	Business	21500.00
0005433570905	347	Business	21500.00
0005433075234	347	Business	21500.00
0005433570908	347	Business	21500.00
0005433570891	347	Business	21500.00
0005434088006	347	Business	21500.00
0005434087987	347	Business	21500.00
0005432949254	347	Business	21500.00
0005433075401	347	Business	21500.00
0005434087997	347	Business	21500.00
0005434326024	347	Business	21500.00
0005432949194	347	Business	21500.00
0005434088050	347	Business	21500.00
0005434326020	347	Business	21500.00
0005433570882	347	Business	21500.00
0005432949322	347	Business	21500.00
0005432949240	347	Business	21500.00
0005434087993	347	Business	21500.00
0005434326022	347	Business	21500.00
0005432949341	347	Economy	7900.00
0005433075256	347	Economy	7900.00
0005432949321	347	Economy	7900.00
0005434087984	347	Economy	7900.00
0005432949337	347	Economy	7900.00
0005433570892	347	Economy	7900.00
0005433075333	347	Economy	7200.00
0005434087998	347	Economy	7200.00
0005432949252	347	Economy	7200.00
0005434326012	347	Economy	7200.00
0005432949500	347	Economy	7200.00
0005432949295	347	Economy	7200.00
0005434326019	347	Economy	7200.00
0005433570910	347	Economy	7200.00
0005434087986	347	Economy	7200.00
0005432949247	347	Economy	7200.00
0005433929867	347	Economy	7200.00
0005433570883	347	Economy	7200.00
0005432949057	347	Economy	7200.00
0005433075328	347	Economy	7200.00
0005433075346	347	Economy	7200.00
0005433570899	347	Economy	7200.00
0005433075441	347	Economy	7200.00
0005432949354	347	Economy	7200.00
0005433075374	347	Economy	7200.00
0005433134236	347	Economy	7200.00
0005433075225	347	Economy	7200.00
0005432239112	347	Economy	7200.00
0005433075250	347	Economy	7200.00
0005433075209	347	Economy	7200.00
0005434088002	347	Economy	7200.00
0005434326023	347	Economy	7200.00
0005432949186	347	Economy	7200.00
0005432949479	347	Economy	7200.00
0005433570897	347	Economy	7200.00
0005433570893	347	Economy	7200.00
0005433570911	347	Economy	7200.00
0005433075372	347	Economy	7200.00
0005432949440	347	Economy	7200.00
0005433075208	347	Economy	7200.00
0005434087990	347	Economy	7200.00
0005433075316	347	Economy	7200.00
0005434087999	347	Economy	7200.00
0005432949375	347	Economy	7200.00
0005433134239	347	Economy	7200.00
0005434326013	347	Economy	7200.00
0005433570885	347	Economy	7200.00
0005434326014	347	Economy	7200.00
0005433075283	347	Economy	7200.00
0005433129390	347	Economy	7200.00
0005433075263	347	Economy	7200.00
0005433075264	347	Economy	7200.00
0005433075224	347	Economy	7200.00
0005433570903	347	Economy	7200.00
0005433075342	347	Economy	7200.00
0005433570890	347	Economy	7200.00
0005434087996	347	Economy	7200.00
0005434087995	347	Economy	7200.00
0005432949349	347	Economy	7200.00
0005433075282	347	Economy	7200.00
0005433570886	347	Economy	7200.00
0005432949376	347	Economy	7200.00
0005433570887	347	Economy	7200.00
0005432239111	347	Economy	7200.00
0005432949345	347	Economy	7200.00
0005433075312	347	Economy	7900.00
0005432949389	347	Economy	7900.00
0005432949413	347	Economy	7900.00
0005434087991	347	Economy	7900.00
0005434088007	347	Economy	7900.00
0005434088010	347	Economy	7200.00
0005434326016	347	Economy	7200.00
0005433075376	347	Economy	7200.00
0005433570881	347	Economy	7200.00
0005432949338	347	Economy	7900.00
0005432949248	347	Economy	7200.00
0005434088052	347	Economy	7200.00
0005433570894	347	Economy	7200.00
0005434326021	347	Economy	7200.00
0005433075319	347	Economy	7200.00
0005433075217	347	Economy	7200.00
0005432949274	347	Economy	7200.00
0005432949268	347	Economy	7200.00
0005432949176	347	Economy	7200.00
0005432949184	347	Economy	7200.00
0005433570904	347	Economy	7200.00
0005433570884	347	Economy	7200.00
0005432949353	347	Economy	7200.00
0005434087985	347	Economy	7200.00
0005433075336	347	Economy	7200.00
0005432949239	347	Economy	7200.00
0005434326015	347	Economy	7200.00
0005434088005	347	Economy	7200.00
0005433129370	347	Economy	7200.00
0005432949388	347	Economy	7200.00
0005432949459	347	Economy	7200.00
0005434087989	347	Economy	7200.00
0005433570888	347	Economy	7200.00
0005432949387	347	Economy	7200.00
0005432949173	347	Economy	7200.00
0005433075271	347	Economy	7200.00
0005433075238	347	Economy	7200.00
0005434088051	347	Economy	7200.00
0005433134235	347	Economy	7200.00
0005432949174	347	Economy	7200.00
0005433075235	347	Economy	7200.00
0005433075270	347	Economy	7200.00
0005433570889	347	Economy	7200.00
0005434087994	347	Economy	7200.00
0005432949329	347	Economy	7200.00
0005433570900	347	Economy	7200.00
0005433570896	347	Economy	7200.00
0005432949460	347	Economy	7200.00
0005433570909	347	Economy	7200.00
0005434088004	347	Economy	7200.00
0005434088003	347	Economy	7200.00
0005432949290	347	Economy	7200.00
0005432949199	347	Economy	7200.00
0005433570895	347	Economy	7200.00
0005434088008	347	Economy	7200.00
0005433570906	347	Economy	7200.00
0005434326018	347	Economy	7200.00
0005433570901	347	Economy	7200.00
0005434088009	347	Economy	7200.00
0005433570907	347	Economy	7200.00
0005432949226	347	Economy	7200.00
0005433570912	347	Economy	7200.00
0005434087988	347	Economy	7200.00
0005434088000	347	Economy	7200.00
0005432949309	347	Economy	7200.00
0005433570902	347	Economy	7200.00
0005433570898	347	Economy	7200.00
0005433929868	347	Economy	7200.00
0005434087992	347	Economy	7200.00
0005433129389	347	Economy	7200.00
0005434326017	347	Economy	7200.00
0005432949441	347	Economy	7200.00
0005433075290	347	Economy	7200.00
0005432949339	347	Economy	7200.00
0005433075345	347	Economy	7200.00
0005433075377	347	Economy	7200.00
0005433570320	11589	Business	21500.00
0005433570270	11589	Business	21500.00
0005432949627	11589	Business	21500.00
0005433570277	11589	Business	21500.00
0005433131836	11589	Business	21500.00
0005432949626	11589	Business	21500.00
0005433570178	11589	Business	21500.00
0005433570384	11589	Business	21500.00
0005433570086	11589	Business	21500.00
0005433075521	11589	Business	21500.00
0005433570091	11589	Business	21500.00
0005433570129	11589	Business	21500.00
0005433570246	11589	Business	21500.00
0005432949621	11589	Business	21500.00
0005433570437	11589	Business	21500.00
0005433570278	11589	Business	21500.00
0005432949619	11589	Business	21500.00
0005433570333	11589	Business	21500.00
0005433570087	11589	Business	21500.00
0005433570041	11589	Economy	7900.00
0005433570085	11589	Economy	7900.00
0005433570222	11589	Economy	7200.00
0005433570438	11589	Economy	7200.00
0005433570090	11589	Economy	7200.00
0005433570294	11589	Economy	7200.00
0005433570128	11589	Economy	7200.00
0005432949617	11589	Economy	7200.00
0005432949613	11589	Economy	7200.00
0005433075518	11589	Economy	7200.00
0005433570266	11589	Economy	7200.00
0005433075524	11589	Economy	7200.00
0005432949631	11589	Economy	7200.00
0005432949622	11589	Economy	7200.00
0005433570255	11589	Economy	7200.00
0005432949634	11589	Economy	7200.00
0005432949625	11589	Economy	7200.00
0005433075520	11589	Economy	7200.00
0005433075526	11589	Economy	7200.00
0005432949628	11589	Economy	7200.00
0005433569842	11589	Economy	7200.00
0005432949633	11589	Economy	7200.00
0005433570313	11589	Economy	7200.00
0005433570160	11589	Economy	7200.00
0005433570233	11589	Economy	7200.00
0005433570138	11589	Economy	7200.00
0005433570339	11589	Economy	7200.00
0005433570413	11589	Economy	7200.00
0005433570314	11589	Economy	7200.00
0005433075517	11589	Economy	7200.00
0005433570367	11589	Economy	7200.00
0005433570111	11589	Economy	7200.00
0005433570113	11589	Economy	7200.00
0005433570267	11589	Economy	7200.00
0005433075516	11589	Economy	7200.00
0005433570200	11589	Economy	7200.00
0005433570139	11589	Economy	7200.00
0005432949616	11589	Economy	7200.00
0005433570588	11589	Economy	7200.00
0005432949620	11589	Economy	7200.00
0005433570329	11589	Economy	7200.00
0005433570345	11589	Economy	7200.00
0005433570168	11589	Economy	7200.00
0005433570341	11589	Economy	7200.00
0005432949629	11589	Economy	7900.00
0005432949636	11589	Economy	7900.00
0005433075523	11589	Economy	7200.00
0005433134261	11589	Economy	7200.00
0005433075525	11589	Economy	7200.00
0005433570340	11589	Economy	7200.00
0005433570167	11589	Economy	7200.00
0005433570315	11589	Economy	7200.00
0005432949612	11589	Economy	7200.00
0005433075514	11589	Economy	7200.00
0005433134262	11589	Economy	7200.00
0005433075527	11589	Economy	7200.00
0005432949611	11589	Economy	7200.00
0005433570308	11589	Economy	7200.00
0005433570343	11589	Economy	7200.00
0005433570179	11589	Economy	7200.00
0005432949614	11589	Economy	7200.00
0005432949618	11589	Economy	7200.00
0005433075519	11589	Economy	7200.00
0005433570170	11589	Economy	7200.00
0005432949635	11589	Economy	7200.00
0005433570344	11589	Economy	7200.00
0005433570261	11589	Economy	7200.00
0005433570012	11589	Economy	7200.00
0005433075515	11589	Economy	7200.00
0005433929883	11589	Economy	7200.00
0005433570195	11589	Economy	7200.00
0005433131837	11589	Economy	7200.00
0005433570275	11589	Economy	7200.00
0005433570338	11589	Economy	7200.00
0005433570150	11589	Economy	7200.00
0005433570042	11589	Economy	7200.00
0005433570121	11589	Economy	7200.00
0005432949632	11589	Economy	7200.00
0005433570110	11589	Economy	7200.00
0005433570254	11589	Economy	7200.00
0005433570260	11589	Economy	7200.00
0005433570449	11589	Economy	7200.00
0005432949630	11589	Economy	7200.00
0005433570221	11589	Economy	7200.00
0005433570319	11589	Economy	7200.00
0005433570457	11589	Economy	7200.00
0005433570307	11589	Economy	7200.00
0005433570316	11589	Economy	7200.00
0005433570159	11589	Economy	7200.00
0005433570172	11589	Economy	7200.00
0005433131838	11589	Economy	7200.00
0005432949623	11589	Economy	7200.00
0005432192410	11589	Economy	7200.00
0005433075522	11589	Economy	7200.00
0005432949624	11589	Economy	7200.00
0005432949615	11589	Economy	7200.00
0005433817575	10023	Economy	6300.00
0005434733065	10023	Economy	6300.00
0005434733063	10023	Economy	6300.00
0005434733066	10023	Economy	6300.00
0005433817576	10023	Economy	6300.00
0005434733055	10023	Economy	6300.00
0005433817577	10023	Economy	6300.00
0005434733057	10023	Economy	6300.00
0005434733064	10023	Economy	6300.00
0005434733062	10023	Economy	6300.00
0005434733056	10023	Economy	6300.00
0005434733039	10023	Economy	6300.00
0005433817562	14004	Economy	6300.00
0005433817561	14004	Economy	6300.00
0005433817548	14004	Economy	6300.00
0005433817554	14004	Economy	6300.00
0005432985787	2371	Business	184500.00
0005433755829	2371	Business	184500.00
0005433435145	2371	Business	184500.00
0005432985768	2371	Business	184500.00
0005433755820	2371	Business	184500.00
0005433755840	2371	Business	184500.00
0005433755818	2371	Business	184500.00
0005432655882	2371	Business	184500.00
0005432869674	2371	Business	184500.00
0005432985843	2371	Business	184500.00
0005432226235	2371	Business	184500.00
0005432655883	2371	Business	184500.00
0005435983618	2371	Business	184500.00
0005433435262	2371	Business	184500.00
0005432985728	2371	Business	184500.00
0005432655884	2371	Business	184500.00
0005432985769	2371	Economy	67700.00
0005432869673	2371	Economy	67700.00
0005432985783	2371	Economy	67700.00
0005435983637	2371	Economy	61500.00
0005433755831	2371	Economy	61500.00
0005432985782	2371	Economy	61500.00
0005433766750	2371	Economy	61500.00
0005435983624	2371	Economy	61500.00
0005433435365	2371	Economy	61500.00
0005434731255	2371	Economy	61500.00
0005433435288	2371	Economy	61500.00
0005433755816	2371	Economy	61500.00
0005435983616	2371	Economy	61500.00
0005433435222	2371	Economy	61500.00
0005433755819	2371	Economy	61500.00
0005433755830	2371	Economy	61500.00
0005433755834	2371	Economy	61500.00
0005433755824	2371	Economy	61500.00
0005433435225	2371	Economy	61500.00
0005433435085	2371	Economy	61500.00
0005432300431	2371	Economy	61500.00
0005435983634	2371	Economy	61500.00
0005433435364	2371	Economy	61500.00
0005432300436	2371	Economy	61500.00
0005435983622	2371	Economy	61500.00
0005433435084	2371	Economy	61500.00
0005433435224	2371	Economy	61500.00
0005435983636	2371	Economy	61500.00
0005435983644	2371	Economy	61500.00
0005435983620	2371	Economy	61500.00
0005435983638	2371	Economy	61500.00
0005432985679	2371	Economy	61500.00
0005433435223	2371	Economy	61500.00
0005433435331	2371	Economy	61500.00
0005435983633	2371	Economy	61500.00
0005435983640	2371	Economy	61500.00
0005432869675	2371	Economy	61500.00
0005432985720	2371	Economy	61500.00
0005433435200	2371	Economy	61500.00
0005432985781	2371	Economy	61500.00
0005435983629	2371	Economy	61500.00
0005432869649	2371	Economy	61500.00
0005433435275	2371	Economy	61500.00
0005433435146	2371	Economy	61500.00
0005432300432	2371	Economy	61500.00
0005432985676	2371	Economy	61500.00
0005433435287	2371	Economy	61500.00
0005434731254	2371	Economy	61500.00
0005433755825	2371	Economy	61500.00
0005432985867	2371	Economy	61500.00
0005432300433	2371	Economy	61500.00
0005433435083	2371	Economy	61500.00
0005433755827	2371	Economy	61500.00
0005433766767	2371	Economy	61500.00
0005432985670	2371	Economy	61500.00
0005433755836	2371	Economy	61500.00
0005432985813	2371	Economy	61500.00
0005433755833	2371	Economy	61500.00
0005434731273	2371	Economy	61500.00
0005433755821	2371	Economy	61500.00
0005432985779	2371	Economy	61500.00
0005435983642	2371	Economy	61500.00
0005432985699	2371	Economy	61500.00
0005435983631	2371	Economy	61500.00
0005433435220	2371	Economy	61500.00
0005432985807	2371	Economy	61500.00
0005432985860	2371	Economy	61500.00
0005433435149	2371	Economy	61500.00
0005432985808	2371	Economy	61500.00
0005432985802	2371	Economy	61500.00
0005432985809	2371	Economy	61500.00
0005432985820	2371	Economy	61500.00
0005433755835	2371	Economy	61500.00
0005432985879	2371	Economy	61500.00
0005433755815	2371	Economy	61500.00
0005433435171	2371	Economy	67700.00
0005432655885	2371	Economy	61500.00
0005433755832	2371	Economy	61500.00
0005435983630	2371	Economy	61500.00
0005435983632	2371	Economy	67700.00
0005433435330	2371	Economy	61500.00
0005432869648	2371	Economy	61500.00
0005432655886	2371	Economy	61500.00
0005435983625	2371	Economy	61500.00
0005433755813	2371	Economy	61500.00
0005432985730	2371	Economy	61500.00
0005433435199	2371	Economy	61500.00
0005435983641	2371	Economy	61500.00
0005435983635	2371	Economy	61500.00
0005433755828	2371	Economy	61500.00
0005433435198	2371	Economy	61500.00
0005435983623	2371	Economy	61500.00
0005433435157	2371	Economy	61500.00
0005433435230	2371	Economy	61500.00
0005432985810	2371	Economy	61500.00
0005432869650	2371	Economy	61500.00
0005435983615	2371	Economy	61500.00
0005433435150	2371	Economy	61500.00
0005435983619	2371	Economy	61500.00
0005433755826	2371	Economy	61500.00
0005433435294	2371	Economy	61500.00
0005435983643	2371	Economy	61500.00
0005432985729	2371	Economy	61500.00
0005435983628	2371	Economy	61500.00
0005433435259	2371	Economy	61500.00
0005432985811	2371	Economy	61500.00
0005432985572	2371	Economy	61500.00
0005435983626	2371	Economy	61500.00
0005433435335	2371	Economy	61500.00
0005432300435	2371	Economy	61500.00
0005433435207	2371	Economy	61500.00
0005432985601	2371	Economy	61500.00
0005435983621	2371	Economy	61500.00
0005433755812	2371	Economy	61500.00
0005433755838	2371	Economy	61500.00
0005432226236	2371	Economy	61500.00
0005432985719	2371	Economy	61500.00
0005432985850	2371	Economy	61500.00
0005433435382	2371	Economy	61500.00
0005435983639	2371	Economy	61500.00
0005432300434	2371	Economy	61500.00
0005433755839	2371	Economy	61500.00
0005433755814	2371	Economy	61500.00
0005435983627	2371	Economy	61500.00
0005434731253	2371	Economy	61500.00
0005433755837	2371	Economy	61500.00
0005433755822	2371	Economy	61500.00
0005435983617	2371	Economy	61500.00
0005432655881	2371	Economy	61500.00
0005433435342	2371	Economy	61500.00
0005432985780	2371	Economy	61500.00
0005433755823	2371	Economy	61500.00
0005433435269	2371	Economy	61500.00
0005433435381	2371	Economy	61500.00
0005433755817	2371	Economy	61500.00
0005432985983	26191	Business	184500.00
0005432049566	26191	Business	184500.00
0005433755560	26191	Business	184500.00
0005433755373	26191	Business	184500.00
0005435983167	26191	Business	184500.00
0005432655762	26191	Business	184500.00
0005435983207	26191	Business	184500.00
0005435983100	26191	Business	184500.00
0005432655800	26191	Business	184500.00
0005435983128	26191	Business	184500.00
0005433755140	26191	Business	184500.00
0005432869715	26191	Business	184500.00
0005433755538	26191	Business	184500.00
0005435983287	26191	Business	184500.00
0005433435483	26191	Business	184500.00
0005435983266	26191	Business	184500.00
0005435983180	26191	Business	184500.00
0005435983246	26191	Business	184500.00
0005433755386	26191	Business	184500.00
0005435983242	26191	Business	184500.00
0005435983344	26191	Business	184500.00
0005432985990	26191	Business	184500.00
0005435983265	26191	Economy	67700.00
0005435983017	26191	Economy	67700.00
0005433435474	26191	Economy	67700.00
0005433755172	26191	Economy	67700.00
0005435983345	26191	Economy	61500.00
0005433755375	26191	Economy	61500.00
0005435983184	26191	Economy	61500.00
0005433755479	26191	Economy	61500.00
0005433755285	26191	Economy	61500.00
0005435983318	26191	Economy	61500.00
0005435983103	26191	Economy	61500.00
0005433755309	26191	Economy	61500.00
0005433755528	26191	Economy	61500.00
0005433755561	26191	Economy	61500.00
0005433755709	26191	Economy	61500.00
0005433755724	26191	Economy	61500.00
0005433755282	26191	Economy	61500.00
0005433755364	26191	Economy	61500.00
0005433755424	26191	Economy	61500.00
0005435983490	26191	Economy	61500.00
0005432655834	26191	Economy	61500.00
0005433755494	26191	Economy	61500.00
0005432655788	26191	Economy	61500.00
0005435983204	26191	Economy	61500.00
0005433435478	26191	Economy	61500.00
0005433435475	26191	Economy	61500.00
0005433755480	26191	Economy	61500.00
0005435983269	26191	Economy	61500.00
0005433435473	26191	Economy	61500.00
0005432985989	26191	Economy	61500.00
0005433755369	26191	Economy	61500.00
0005433755723	26191	Economy	61500.00
0005432869716	26191	Economy	61500.00
0005432655763	26191	Economy	61500.00
0005432869713	26191	Economy	61500.00
0005433755376	26191	Economy	61500.00
0005433435479	26191	Economy	61500.00
0005433755286	26191	Economy	61500.00
0005433755330	26191	Economy	61500.00
0005433755374	26191	Economy	61500.00
0005434731290	26191	Economy	61500.00
0005435983262	26191	Economy	61500.00
0005435983124	26191	Economy	61500.00
0005433435484	26191	Economy	61500.00
0005433755281	26191	Economy	61500.00
0005433755495	26191	Economy	61500.00
0005433755520	26191	Economy	61500.00
0005433755513	26191	Economy	61500.00
0005433755365	26191	Economy	61500.00
0005435983209	26191	Economy	61500.00
0005433435477	26191	Economy	61500.00
0005434376167	26191	Economy	61500.00
0005433755530	26191	Economy	61500.00
0005432655799	26191	Economy	61500.00
0005433755544	26191	Economy	61500.00
0005432985988	26191	Economy	61500.00
0005433755370	26191	Economy	61500.00
0005433755298	26191	Economy	61500.00
0005433755297	26191	Economy	61500.00
0005435983159	26191	Economy	61500.00
0005433755332	26191	Economy	61500.00
0005435983107	26191	Economy	61500.00
0005435983270	26191	Economy	61500.00
0005432869714	26191	Economy	61500.00
0005433755545	26191	Economy	61500.00
0005435983190	26191	Economy	61500.00
0005433755430	26191	Economy	61500.00
0005433755587	26191	Economy	61500.00
0005432985992	26191	Economy	61500.00
0005435983018	26191	Economy	61500.00
0005435983158	26191	Economy	61500.00
0005433766715	26191	Economy	61500.00
0005435983267	26191	Economy	61500.00
0005433755565	26191	Economy	61500.00
0005433755415	26191	Economy	61500.00
0005435983125	26191	Economy	61500.00
0005433755416	26191	Economy	67700.00
0005435983099	26191	Economy	67700.00
0005433435471	26191	Economy	61500.00
0005433766714	26191	Economy	61500.00
0005435983243	26191	Economy	61500.00
0005433435480	26191	Economy	67700.00
0005432655778	26191	Economy	67700.00
0005435983208	26191	Economy	61500.00
0005433435485	26191	Economy	61500.00
0005435983327	26191	Economy	61500.00
0005433755311	26191	Economy	61500.00
0005433435481	26191	Economy	61500.00
0005435983379	26191	Economy	61500.00
0005433755537	26191	Economy	61500.00
0005433435472	26191	Economy	61500.00
0005433755455	26191	Economy	61500.00
0005435983121	26191	Economy	61500.00
0005433755487	26191	Economy	61500.00
0005433755529	26191	Economy	61500.00
0005433755259	26191	Economy	61500.00
0005435983055	26191	Economy	61500.00
0005432655746	26191	Economy	61500.00
0005435983216	26191	Economy	61500.00
0005433755338	26191	Economy	61500.00
0005433755333	26191	Economy	61500.00
0005432985987	26191	Economy	61500.00
0005433755073	26191	Economy	61500.00
0005433435482	26191	Economy	61500.00
0005433435476	26191	Economy	61500.00
0005433755310	26191	Economy	61500.00
0005433764722	26191	Economy	61500.00
0005435983104	26191	Economy	61500.00
0005432985984	26191	Economy	61500.00
0005435983218	26191	Economy	61500.00
0005433764719	26191	Economy	61500.00
0005433764720	26191	Economy	61500.00
0005435983279	26191	Economy	61500.00
0005435983395	26191	Economy	61500.00
0005433766730	26191	Economy	61500.00
0005435983332	26191	Economy	61500.00
0005433755171	26191	Economy	61500.00
0005433755248	26191	Economy	61500.00
0005433755377	26191	Economy	61500.00
0005432985985	26191	Economy	61500.00
0005433755454	26191	Economy	61500.00
0005433435470	26191	Economy	61500.00
0005435983317	26191	Economy	61500.00
0005433755671	26191	Economy	61500.00
0005433764728	26191	Economy	61500.00
0005432985991	26191	Economy	61500.00
0005435983263	26191	Economy	61500.00
0005435983056	26191	Economy	61500.00
0005433755337	26191	Economy	61500.00
0005432985986	26191	Economy	61500.00
0005433755482	26191	Economy	61500.00
0005432655777	26191	Economy	61500.00
0005433755568	26191	Economy	61500.00
0005435983257	26191	Economy	61500.00
0005435983228	26191	Economy	61500.00
0005433755466	26191	Economy	61500.00
0005433755127	26191	Economy	61500.00
0005435983394	26191	Economy	61500.00
0005435983101	26191	Economy	61500.00
0005434376019	1538	Business	38900.00
0005434375991	1538	Business	38900.00
0005433152180	1538	Business	38900.00
0005433152070	1538	Business	38900.00
0005433152024	1538	Business	38900.00
0005433764721	1538	Business	38900.00
0005433152257	1538	Business	38900.00
0005434376004	1538	Economy	13000.00
0005434376005	1538	Economy	13000.00
0005434376012	1538	Economy	13000.00
0005433152169	1538	Economy	13000.00
0005433461651	1538	Economy	13000.00
0005434375996	1538	Economy	13000.00
0005433152263	1538	Economy	13000.00
0005434376009	1538	Economy	13000.00
0005433152235	1538	Economy	13000.00
0005433152248	1538	Economy	13000.00
0005433152145	1538	Economy	13000.00
0005434376010	1538	Economy	13000.00
0005433152096	1538	Economy	13000.00
0005434029711	1538	Economy	13000.00
0005434376008	1538	Economy	13000.00
0005433152066	1538	Economy	13000.00
0005434029708	1538	Economy	13000.00
0005433152110	1538	Economy	13000.00
0005433152171	1538	Economy	13000.00
0005434375995	1538	Economy	13000.00
0005433152111	1538	Economy	13000.00
0005433152237	1538	Economy	13000.00
0005434376007	1538	Economy	13000.00
0005434375997	1538	Economy	13000.00
0005434376166	1538	Economy	13000.00
0005434376020	1538	Economy	13000.00
0005433152181	1538	Economy	13000.00
0005433152283	1538	Economy	13000.00
0005433152197	1538	Economy	13000.00
0005434376003	1538	Economy	14300.00
0005433152146	1538	Economy	14300.00
0005433152004	1538	Economy	14300.00
0005434375998	1538	Economy	14300.00
0005434376000	1538	Economy	13000.00
0005434376013	1538	Economy	13000.00
0005433152218	1538	Economy	13000.00
0005433152099	1538	Economy	13000.00
0005434376186	1538	Economy	13000.00
0005433152130	1538	Economy	13000.00
0005434376002	1538	Economy	13000.00
0005434375999	1538	Economy	13000.00
0005434376014	1538	Economy	13000.00
0005433152225	1538	Economy	13000.00
0005434376011	1538	Economy	13000.00
0005434376018	1538	Economy	13000.00
0005433152236	1538	Economy	13000.00
0005433152135	1538	Economy	13000.00
0005433152081	1538	Economy	13000.00
0005433152284	1538	Economy	13000.00
0005434376185	1538	Economy	13000.00
0005434376235	1538	Economy	13000.00
0005433152265	1538	Economy	13000.00
0005433152272	1538	Economy	13000.00
0005433461652	1538	Economy	13000.00
0005434375994	1538	Economy	13000.00
0005434375992	1538	Economy	13000.00
0005433152095	1538	Economy	13000.00
0005433460498	1538	Economy	13000.00
0005434376001	1538	Economy	13000.00
0005433152224	1538	Economy	13000.00
0005433152258	1538	Economy	13000.00
0005433152170	1538	Economy	13000.00
0005433152216	1538	Economy	13000.00
0005433152195	1538	Economy	13000.00
0005433152117	1538	Economy	13000.00
0005434376017	1538	Economy	13000.00
0005433152201	1538	Economy	13000.00
0005434376016	1538	Economy	13000.00
0005433152217	1538	Economy	13000.00
0005434375993	1538	Economy	13000.00
0005434376015	1538	Economy	13000.00
0005434376006	1538	Economy	13000.00
0005433152106	1538	Economy	13000.00
0005434375716	20138	Business	38900.00
0005434375700	20138	Business	38900.00
0005433152383	20138	Business	38900.00
0005434375514	20138	Business	38900.00
0005434375506	20138	Business	38900.00
0005434375558	20138	Business	38900.00
0005434375671	20138	Business	38900.00
0005434029727	20138	Business	38900.00
0005433152379	20138	Economy	13000.00
0005434375391	20138	Economy	13000.00
0005433931557	20138	Economy	13000.00
0005433931556	20138	Economy	13000.00
0005434375725	20138	Economy	13000.00
0005433152384	20138	Economy	13000.00
0005434375676	20138	Economy	13000.00
0005434375338	20138	Economy	13000.00
0005432056405	20138	Economy	13000.00
0005434375661	20138	Economy	13000.00
0005434375663	20138	Economy	13000.00
0005433152390	20138	Economy	13000.00
0005433152386	20138	Economy	13000.00
0005434375532	20138	Economy	13000.00
0005434375559	20138	Economy	13000.00
0005434375611	20138	Economy	13000.00
0005433931554	20138	Economy	13000.00
0005434375365	20138	Economy	13000.00
0005434375747	20138	Economy	13000.00
0005434375653	20138	Economy	13000.00
0005434029726	20138	Economy	14300.00
0005434375534	20138	Economy	14300.00
0005434375458	20138	Economy	14300.00
0005434375339	20138	Economy	14300.00
0005434375793	20138	Economy	14300.00
0005434375575	20138	Economy	13000.00
0005434375358	20138	Economy	13000.00
0005434375629	20138	Economy	13000.00
0005434029728	20138	Economy	13000.00
0005434375808	20138	Economy	13000.00
0005433931555	20138	Economy	13000.00
0005434375780	20138	Economy	13000.00
0005433152381	20138	Economy	13000.00
0005433152382	20138	Economy	13000.00
0005434375499	20138	Economy	13000.00
0005434375745	20138	Economy	13000.00
0005434375782	20138	Economy	13000.00
0005434375781	20138	Economy	13000.00
0005434375576	20138	Economy	13000.00
0005434375610	20138	Economy	13000.00
0005434375724	20138	Economy	13000.00
0005434375366	20138	Economy	13000.00
0005434375511	20138	Economy	13000.00
0005434376225	20138	Economy	13000.00
0005433152388	20138	Economy	13000.00
0005434375641	20138	Economy	13000.00
0005434375809	20138	Economy	13000.00
0005434375622	20138	Economy	13000.00
0005434375662	20138	Economy	13000.00
0005434375515	20138	Economy	13000.00
0005434375589	20138	Economy	13000.00
0005434375569	20138	Economy	13000.00
0005434375783	20138	Economy	13000.00
0005434375497	20138	Economy	13000.00
0005434375624	20138	Economy	13000.00
0005434375590	20138	Economy	13000.00
0005433152387	20138	Economy	13000.00
0005434375688	20138	Economy	13000.00
0005433152380	20138	Economy	13000.00
0005434375512	20138	Economy	13000.00
0005434375513	20138	Economy	13000.00
0005433152378	20138	Economy	13000.00
0005434375733	20138	Economy	13000.00
0005434375560	20138	Economy	13000.00
0005434375654	20138	Economy	13000.00
0005433152389	20138	Economy	13000.00
0005433152385	20138	Economy	13000.00
0005434375617	20138	Economy	13000.00
0005432425895	576	Business	27500.00
0005432425899	576	Business	27500.00
0005432425898	576	Business	27500.00
0005432425918	576	Business	27500.00
0005432425896	576	Business	27500.00
0005432425944	576	Business	27500.00
0005432425883	576	Business	27500.00
0005432425916	576	Business	27500.00
0005432425923	576	Business	27500.00
0005432425928	576	Business	27500.00
0005432425913	576	Business	27500.00
0005432425907	576	Business	27500.00
0005432425919	576	Economy	10100.00
0005432425904	576	Economy	10100.00
0005432425897	576	Economy	10100.00
0005432425927	576	Economy	10100.00
0005432425942	576	Economy	9200.00
0005432283064	576	Economy	9200.00
0005432283065	576	Economy	9200.00
0005432425908	576	Economy	9200.00
0005432425889	576	Economy	9200.00
0005432425938	576	Economy	9200.00
0005432425924	576	Economy	9200.00
0005432425890	576	Economy	9200.00
0005432425933	576	Economy	9200.00
0005432425935	576	Economy	9200.00
0005432425884	576	Economy	9200.00
0005432425905	576	Economy	9200.00
0005432425930	576	Economy	9200.00
0005432425894	576	Economy	9200.00
0005432425902	576	Economy	9200.00
0005432425931	576	Economy	9200.00
0005432425887	576	Economy	9200.00
0005432425906	576	Economy	9200.00
0005432425886	576	Economy	9200.00
0005432425900	576	Economy	9200.00
0005432425914	576	Economy	9200.00
0005432425939	576	Economy	9200.00
0005432425885	576	Economy	9200.00
0005432425934	576	Economy	9200.00
0005432425893	576	Economy	9200.00
0005432425945	576	Economy	9200.00
0005432425891	576	Economy	9200.00
0005432425920	576	Economy	9200.00
0005432425910	576	Economy	9200.00
0005432425926	576	Economy	9200.00
0005432425912	576	Economy	9200.00
0005432425915	576	Economy	9200.00
0005432425943	576	Economy	9200.00
0005432425937	576	Economy	9200.00
0005432425917	576	Economy	9200.00
0005432425941	576	Economy	9200.00
0005432425909	576	Economy	9200.00
0005432425922	576	Economy	9200.00
0005432425888	576	Economy	9200.00
0005432425911	576	Economy	9200.00
0005432425901	576	Economy	9200.00
0005432425892	576	Economy	9200.00
0005432425936	576	Economy	9200.00
0005432425921	576	Economy	9200.00
0005432425925	576	Economy	9200.00
0005432425903	576	Economy	9200.00
0005432425929	576	Economy	9200.00
0005432425940	576	Economy	9200.00
0005432425932	576	Economy	9200.00
0005433262024	12913	Business	27500.00
0005432302438	12913	Business	27500.00
0005433766767	12913	Business	27500.00
0005433262017	12913	Business	27500.00
0005433262021	12913	Business	27500.00
0005433262027	12913	Economy	9200.00
0005433262014	12913	Economy	9200.00
0005433262018	12913	Economy	9200.00
0005434446565	12913	Economy	9200.00
0005434446570	12913	Economy	9200.00
0005433262016	12913	Economy	9200.00
0005433262026	12913	Economy	9200.00
0005434446571	12913	Economy	10100.00
0005434446569	12913	Economy	10100.00
0005433262025	12913	Economy	10100.00
0005433158195	12913	Economy	10100.00
0005433262015	12913	Economy	9200.00
0005434446561	12913	Economy	9200.00
0005433262020	12913	Economy	9200.00
0005433262023	12913	Economy	9200.00
0005434446566	12913	Economy	9200.00
0005432302440	12913	Economy	9200.00
0005433262013	12913	Economy	9200.00
0005433262019	12913	Economy	9200.00
0005432302439	12913	Economy	9200.00
0005433262022	12913	Economy	9200.00
0005432425379	12880	Business	27500.00
0005432425472	12880	Business	27500.00
0005432425323	12880	Business	27500.00
0005432425406	12880	Business	27500.00
0005432425449	12880	Business	27500.00
0005432425276	12880	Business	27500.00
0005432425288	12880	Economy	10100.00
0005432425328	12880	Economy	10100.00
0005432425229	12880	Economy	10100.00
0005432425385	12880	Economy	10100.00
0005432425331	12880	Economy	9200.00
0005432425488	12880	Economy	9200.00
0005432425275	12880	Economy	9200.00
0005432425396	12880	Economy	9200.00
0005432425191	12880	Economy	9200.00
0005432425370	12880	Economy	9200.00
0005432425464	12880	Economy	9200.00
0005432425471	12880	Economy	9200.00
0005432425454	12880	Economy	9200.00
0005432425467	12880	Economy	9200.00
0005432425301	12880	Economy	9200.00
0005432425378	12880	Economy	9200.00
0005432425305	12880	Economy	10100.00
0005432425427	12880	Economy	9200.00
0005432425405	12880	Economy	9200.00
0005432425381	12880	Economy	9200.00
0005432425453	12880	Economy	9200.00
0005432425448	12880	Economy	9200.00
0005432425391	12880	Economy	9200.00
0005432425470	12880	Economy	9200.00
0005432425473	12880	Economy	9200.00
0005432425329	12880	Economy	9200.00
0005432425450	12880	Economy	9200.00
0005432425435	12880	Economy	9200.00
0005432425304	12880	Economy	9200.00
0005432425337	12880	Economy	9200.00
0005432425302	12880	Economy	9200.00
0005434735799	486	Business	24500.00
0005433684456	486	Business	24500.00
0005433058916	486	Business	24500.00
0005433058792	486	Business	24500.00
0005434025637	486	Business	24500.00
0005433058940	486	Business	24500.00
0005434025625	486	Business	24500.00
0005433058814	486	Business	24500.00
0005434735792	486	Business	24500.00
0005433929704	486	Business	24500.00
0005433684464	486	Business	24500.00
0005433684465	486	Business	24500.00
0005433929700	486	Economy	9000.00
0005433058600	486	Economy	9000.00
0005432235854	486	Economy	8200.00
0005433929706	486	Economy	8200.00
0005434025639	486	Economy	8200.00
0005433058789	486	Economy	8200.00
0005434025643	486	Economy	8200.00
0005433929693	486	Economy	8200.00
0005434025631	486	Economy	8200.00
0005434028393	486	Economy	8200.00
0005434025638	486	Economy	8200.00
0005434025627	486	Economy	8200.00
0005433929698	486	Economy	8200.00
0005432045668	486	Economy	8200.00
0005433058729	486	Economy	8200.00
0005434025647	486	Economy	8200.00
0005433929699	486	Economy	8200.00
0005434032154	486	Economy	8200.00
0005434028392	486	Economy	8200.00
0005434025636	486	Economy	8200.00
0005434025646	486	Economy	8200.00
0005433058907	486	Economy	8200.00
0005433058547	486	Economy	8200.00
0005433058821	486	Economy	8200.00
0005434025649	486	Economy	8200.00
0005433058599	486	Economy	8200.00
0005434735793	486	Economy	8200.00
0005434025642	486	Economy	8200.00
0005434025645	486	Economy	8200.00
0005433058735	486	Economy	8200.00
0005433058601	486	Economy	8200.00
0005433058705	486	Economy	8200.00
0005433058906	486	Economy	8200.00
0005432235855	486	Economy	8200.00
0005433929697	486	Economy	8200.00
0005433058764	486	Economy	8200.00
0005433058777	486	Economy	8200.00
0005433058834	486	Economy	8200.00
0005433058610	486	Economy	8200.00
0005434025641	486	Economy	8200.00
0005434025651	486	Economy	8200.00
0005433684455	486	Economy	8200.00
0005433929705	486	Economy	8200.00
0005434025624	486	Economy	9000.00
0005432235857	486	Economy	8200.00
0005433058707	486	Economy	8200.00
0005434025634	486	Economy	8200.00
0005434025644	486	Economy	8200.00
0005434025650	486	Economy	8200.00
0005434025635	486	Economy	8200.00
0005433058592	486	Economy	8200.00
0005433929694	486	Economy	8200.00
0005433058662	486	Economy	8200.00
0005432045667	486	Economy	8200.00
0005434025626	486	Economy	8200.00
0005434025629	486	Economy	8200.00
0005434025640	486	Economy	8200.00
0005434032153	486	Economy	8200.00
0005433058820	486	Economy	8200.00
0005434025632	486	Economy	8200.00
0005433058741	486	Economy	8200.00
0005432235856	486	Economy	8200.00
0005434025648	486	Economy	8200.00
0005433058706	486	Economy	8200.00
0005433058712	486	Economy	8200.00
0005433058799	486	Economy	8200.00
0005433058713	486	Economy	8200.00
0005434025633	486	Economy	8200.00
0005434025628	486	Economy	8200.00
0005433058714	486	Economy	8200.00
0005434025630	486	Economy	8200.00
0005434024891	12651	Business	24500.00
0005434025143	12651	Business	24500.00
0005434025317	12651	Business	24500.00
0005434025326	12651	Business	24500.00
0005434025085	12651	Business	24500.00
0005434025064	12651	Business	24500.00
0005434025174	12651	Business	24500.00
0005434024935	12651	Business	24500.00
0005434025185	12651	Business	24500.00
0005434025302	12651	Business	24500.00
0005434025432	12651	Business	24500.00
0005433059034	12651	Business	24500.00
0005434025467	12651	Business	24500.00
0005434025366	12651	Business	24500.00
0005433059026	12651	Business	24500.00
0005434025016	12651	Business	24500.00
0005434025258	12651	Business	24500.00
0005434028356	12651	Economy	9000.00
0005434025211	12651	Economy	8200.00
0005434032121	12651	Economy	8200.00
0005432156491	12651	Economy	8200.00
0005434025042	12651	Economy	8200.00
0005434025156	12651	Economy	8200.00
0005434032097	12651	Economy	8200.00
0005434025095	12651	Economy	8200.00
0005434025060	12651	Economy	8200.00
0005433059036	12651	Economy	8200.00
0005434025055	12651	Economy	8200.00
0005434025030	12651	Economy	8200.00
0005434032127	12651	Economy	8200.00
0005434025222	12651	Economy	8200.00
0005434025155	12651	Economy	8200.00
0005434025210	12651	Economy	8200.00
0005434025050	12651	Economy	8200.00
0005434376235	12651	Economy	8200.00
0005434032109	12651	Economy	8200.00
0005434025325	12651	Economy	8200.00
0005434024936	12651	Economy	8200.00
0005434025405	12651	Economy	8200.00
0005434025053	12651	Economy	8200.00
0005434025094	12651	Economy	8200.00
0005434025106	12651	Economy	8200.00
0005433059040	12651	Economy	8200.00
0005434025041	12651	Economy	8200.00
0005434025061	12651	Economy	8200.00
0005433059039	12651	Economy	8200.00
0005434025107	12651	Economy	8200.00
0005434024947	12651	Economy	8200.00
0005434735839	12651	Economy	8200.00
0005434025054	12651	Economy	8200.00
0005434025206	12651	Economy	8200.00
0005434025201	12651	Economy	8200.00
0005434025212	12651	Economy	8200.00
0005434025135	12651	Economy	8200.00
0005434025224	12651	Economy	8200.00
0005434032122	12651	Economy	8200.00
0005433929727	12651	Economy	8200.00
0005434024704	12651	Economy	8200.00
0005433059035	12651	Economy	8200.00
0005433059027	12651	Economy	8200.00
0005434025154	12651	Economy	8200.00
0005434032123	12651	Economy	8200.00
0005434025184	12651	Economy	8200.00
0005434025308	12651	Economy	8200.00
0005434032132	12651	Economy	8200.00
0005433059030	12651	Economy	8200.00
0005434024928	12651	Economy	8200.00
0005434032111	12651	Economy	8200.00
0005434025121	12651	Economy	8200.00
0005433059032	12651	Economy	8200.00
0005434025017	12651	Economy	8200.00
0005434025056	12651	Economy	8200.00
0005434024793	12651	Economy	8200.00
0005433059033	12651	Economy	9000.00
0005434025153	12651	Economy	9000.00
0005434735840	12651	Economy	8200.00
0005434025099	12651	Economy	8200.00
0005433684482	12651	Economy	8200.00
0005434025298	12651	Economy	8200.00
0005434025057	12651	Economy	8200.00
0005434025253	12651	Economy	8200.00
0005433059028	12651	Economy	8200.00
0005434025243	12651	Economy	8200.00
0005433059038	12651	Economy	8200.00
0005434025171	12651	Economy	8200.00
0005434025223	12651	Economy	8200.00
0005432157548	12651	Economy	8200.00
0005434025322	12651	Economy	8200.00
0005434025202	12651	Economy	8200.00
0005434025043	12651	Economy	8200.00
0005433059041	12651	Economy	8200.00
0005434024974	12651	Economy	8200.00
0005434032114	12651	Economy	8200.00
0005434029708	12651	Economy	8200.00
0005434025170	12651	Economy	8200.00
0005433059029	12651	Economy	8200.00
0005434025120	12651	Economy	8200.00
0005434025242	12651	Economy	8200.00
0005434025183	12651	Economy	8200.00
0005434024879	12651	Economy	8200.00
0005433059037	12651	Economy	8200.00
0005434025086	12651	Economy	8200.00
0005432156490	12651	Economy	8200.00
0005434025104	12651	Economy	8200.00
0005434025087	12651	Economy	8200.00
0005434032131	12651	Economy	8200.00
0005433059031	12651	Economy	8200.00
0005434025209	12651	Economy	8200.00
0005434028357	12651	Economy	8200.00
0005434025122	12651	Economy	8200.00
0005434025169	12651	Economy	8200.00
0005434029711	12651	Economy	8200.00
0005432044606	2135	Business	34700.00
0005433037301	2135	Business	34700.00
0005433926043	2135	Business	34700.00
0005432231867	2135	Business	34700.00
0005433926030	2135	Business	34700.00
0005433037449	2135	Business	34700.00
0005433037361	2135	Business	34700.00
0005433037358	2135	Business	34700.00
0005433926047	2135	Business	34700.00
0005432231870	2135	Business	34700.00
0005433926057	2135	Business	34700.00
0005433037654	2135	Economy	12700.00
0005433931555	2135	Economy	12700.00
0005433926037	2135	Economy	11600.00
0005433926046	2135	Economy	11600.00
0005433037246	2135	Economy	11600.00
0005434028356	2135	Economy	11600.00
0005433926039	2135	Economy	11600.00
0005433037407	2135	Economy	11600.00
0005433037573	2135	Economy	11600.00
0005433926051	2135	Economy	11600.00
0005433926052	2135	Economy	11600.00
0005433926028	2135	Economy	11600.00
0005433037253	2135	Economy	11600.00
0005433037309	2135	Economy	11600.00
0005433037388	2135	Economy	11600.00
0005433926025	2135	Economy	11600.00
0005433037357	2135	Economy	11600.00
0005433926048	2135	Economy	11600.00
0005433037451	2135	Economy	11600.00
0005433926045	2135	Economy	11600.00
0005433926038	2135	Economy	11600.00
0005433926026	2135	Economy	11600.00
0005433037500	2135	Economy	11600.00
0005433926050	2135	Economy	11600.00
0005433875427	2135	Economy	11600.00
0005433926056	2135	Economy	11600.00
0005433926024	2135	Economy	11600.00
0005433926042	2135	Economy	11600.00
0005433926033	2135	Economy	11600.00
0005433926027	2135	Economy	11600.00
0005433037254	2135	Economy	11600.00
0005433037472	2135	Economy	11600.00
0005433931557	2135	Economy	11600.00
0005432749831	2135	Economy	11600.00
0005433926036	2135	Economy	11600.00
0005433926029	2135	Economy	11600.00
0005432231869	2135	Economy	11600.00
0005433037353	2135	Economy	11600.00
0005432749830	2135	Economy	11600.00
0005433875428	2135	Economy	11600.00
0005432749833	2135	Economy	11600.00
0005433037554	2135	Economy	11600.00
0005433929727	2135	Economy	12700.00
0005433037387	2135	Economy	11600.00
0005433926034	2135	Economy	12700.00
0005433037356	2135	Economy	12700.00
0005433037266	2135	Economy	11600.00
0005433037408	2135	Economy	11600.00
0005433037436	2135	Economy	11600.00
0005433926031	2135	Economy	11600.00
0005433037342	2135	Economy	11600.00
0005433926044	2135	Economy	11600.00
0005433926041	2135	Economy	11600.00
0005433926040	2135	Economy	11600.00
0005433037473	2135	Economy	11600.00
0005433926055	2135	Economy	11600.00
0005433931554	2135	Economy	11600.00
0005432749839	2135	Economy	11600.00
0005433926053	2135	Economy	11600.00
0005433926022	2135	Economy	11600.00
0005433037219	2135	Economy	11600.00
0005433037476	2135	Economy	11600.00
0005433037352	2135	Economy	11600.00
0005433037450	2135	Economy	11600.00
0005432044604	2135	Economy	11600.00
0005433037491	2135	Economy	11600.00
0005433037603	2135	Economy	11600.00
0005434028357	2135	Economy	11600.00
0005433926035	2135	Economy	11600.00
0005433037195	2135	Economy	11600.00
0005433037343	2135	Economy	11600.00
0005433926054	2135	Economy	11600.00
0005432044605	2135	Economy	11600.00
0005432231868	2135	Economy	11600.00
0005433037490	2135	Economy	11600.00
0005433037315	2135	Economy	11600.00
0005433931556	2135	Economy	11600.00
0005433926023	2135	Economy	11600.00
0005433037533	2135	Economy	11600.00
0005433926021	2135	Economy	11600.00
0005433926032	2135	Economy	11600.00
0005433037310	2135	Economy	11600.00
0005433926049	2135	Economy	11600.00
0005433037218	2135	Economy	11600.00
0005433925378	24114	Business	34700.00
0005433875421	24114	Business	34700.00
0005433037798	24114	Business	34700.00
0005433925451	24114	Business	34700.00
0005433925696	24114	Business	34700.00
0005433925573	24114	Business	34700.00
0005433925356	24114	Business	34700.00
0005433925273	24114	Business	34700.00
0005433925051	24114	Business	34700.00
0005433925701	24114	Business	34700.00
0005433924843	24114	Business	34700.00
0005433925422	24114	Business	34700.00
0005433925353	24114	Business	34700.00
0005433925266	24114	Economy	12700.00
0005433925386	24114	Economy	12700.00
0005433925079	24114	Economy	11600.00
0005433925560	24114	Economy	11600.00
0005433925489	24114	Economy	11600.00
0005433925335	24114	Economy	11600.00
0005433925352	24114	Economy	11600.00
0005433925450	24114	Economy	11600.00
0005434088053	24114	Economy	11600.00
0005433925537	24114	Economy	11600.00
0005433925405	24114	Economy	11600.00
0005434376189	24114	Economy	11600.00
0005434088054	24114	Economy	11600.00
0005433925246	24114	Economy	11600.00
0005433925123	24114	Economy	11600.00
0005432207736	24114	Economy	11600.00
0005433925797	24114	Economy	11600.00
0005433925295	24114	Economy	11600.00
0005434376187	24114	Economy	11600.00
0005433925056	24114	Economy	11600.00
0005433925508	24114	Economy	11600.00
0005433925292	24114	Economy	11600.00
0005433925497	24114	Economy	11600.00
0005433925379	24114	Economy	11600.00
0005433037817	24114	Economy	11600.00
0005433925112	24114	Economy	11600.00
0005433037811	24114	Economy	11600.00
0005433037810	24114	Economy	11600.00
0005433925267	24114	Economy	11600.00
0005433925057	24114	Economy	11600.00
0005433925495	24114	Economy	11600.00
0005433037805	24114	Economy	11600.00
0005433925050	24114	Economy	11600.00
0005433925648	24114	Economy	11600.00
0005433925244	24114	Economy	11600.00
0005433925183	24114	Economy	11600.00
0005433037812	24114	Economy	11600.00
0005433925300	24114	Economy	11600.00
0005433925279	24114	Economy	11600.00
0005433925130	24114	Economy	11600.00
0005433925365	24114	Economy	11600.00
0005433037807	24114	Economy	11600.00
0005433924721	24114	Economy	11600.00
0005433037797	24114	Economy	11600.00
0005433925695	24114	Economy	11600.00
0005433037803	24114	Economy	11600.00
0005434028394	24114	Economy	11600.00
0005433037808	24114	Economy	11600.00
0005433925338	24114	Economy	11600.00
0005433925252	24114	Economy	11600.00
0005433925408	24114	Economy	11600.00
0005433037801	24114	Economy	11600.00
0005433925430	24114	Economy	11600.00
0005433925272	24114	Economy	11600.00
0005433929865	24114	Economy	11600.00
0005433037813	24114	Economy	11600.00
0005433925387	24114	Economy	11600.00
0005433925417	24114	Economy	11600.00
0005433925538	24114	Economy	11600.00
0005433925320	24114	Economy	11600.00
0005433925509	24114	Economy	12700.00
0005433925494	24114	Economy	11600.00
0005433925429	24114	Economy	11600.00
0005434376188	24114	Economy	12700.00
0005433925366	24114	Economy	12700.00
0005433925201	24114	Economy	11600.00
0005433037819	24114	Economy	11600.00
0005433037809	24114	Economy	11600.00
0005433037795	24114	Economy	11600.00
0005433931529	24114	Economy	11600.00
0005433037814	24114	Economy	11600.00
0005433924834	24114	Economy	11600.00
0005433925649	24114	Economy	11600.00
0005433929866	24114	Economy	11600.00
0005432206358	24114	Economy	11600.00
0005433037804	24114	Economy	11600.00
0005433037806	24114	Economy	11600.00
0005433931522	24114	Economy	11600.00
0005432207737	24114	Economy	11600.00
0005433924833	24114	Economy	11600.00
0005433925170	24114	Economy	11600.00
0005433037799	24114	Economy	11600.00
0005433925702	24114	Economy	11600.00
0005433924913	24114	Economy	11600.00
0005433925294	24114	Economy	11600.00
0005433875402	24114	Economy	11600.00
0005434028395	24114	Economy	11600.00
0005433037796	24114	Economy	11600.00
0005433931543	24114	Economy	11600.00
0005433925202	24114	Economy	11600.00
0005433925245	24114	Economy	11600.00
0005433925694	24114	Economy	11600.00
0005433925691	24114	Economy	11600.00
0005433925714	24114	Economy	11600.00
0005433037800	24114	Economy	11600.00
0005433925334	24114	Economy	11600.00
0005433925428	24114	Economy	11600.00
0005433925321	24114	Economy	11600.00
0005433925113	24114	Economy	11600.00
0005433037816	24114	Economy	11600.00
0005433037794	24114	Economy	11600.00
0005433875413	24114	Economy	11600.00
0005433931535	24114	Economy	11600.00
0005432206357	24114	Economy	11600.00
0005433037802	24114	Economy	11600.00
0005433925271	24114	Economy	11600.00
0005433925565	24114	Economy	11600.00
0005433925260	24114	Economy	11600.00
0005433925124	24114	Economy	11600.00
0005433037815	24114	Economy	11600.00
0005433037818	24114	Economy	11600.00
0005433925249	24114	Economy	11600.00
0005433925336	24114	Economy	11600.00
0005433924968	24114	Economy	11600.00
0005433235454	285	Business	83700.00
0005433235513	285	Business	83700.00
0005434302908	285	Business	83700.00
0005434552822	285	Business	83700.00
0005434728951	285	Business	83700.00
0005434728908	285	Business	83700.00
0005433235621	285	Business	83700.00
0005433235476	285	Business	83700.00
0005432278198	285	Business	83700.00
0005434728895	285	Business	83700.00
0005434728934	285	Business	83700.00
0005434728921	285	Business	83700.00
0005434728909	285	Business	83700.00
0005433235649	285	Business	83700.00
0005434728926	285	Business	83700.00
0005434302579	285	Business	83700.00
0005433235500	285	Business	83700.00
0005434552814	285	Business	83700.00
0005434728899	285	Business	83700.00
0005434728905	285	Comfort	47400.00
0005433289968	285	Comfort	47400.00
0005433181604	285	Comfort	47400.00
0005433235663	285	Comfort	47400.00
0005434552796	285	Comfort	47400.00
0005434728894	285	Comfort	47400.00
0005433235704	285	Comfort	47400.00
0005434728896	285	Comfort	47400.00
0005433235437	285	Comfort	47400.00
0005433235561	285	Comfort	47400.00
0005434735838	285	Comfort	47400.00
0005434728924	285	Comfort	47400.00
0005434552804	285	Comfort	47400.00
0005434728940	285	Comfort	47400.00
0005434728904	285	Comfort	47400.00
0005433235759	285	Comfort	47400.00
0005434728903	285	Comfort	47400.00
0005433290014	285	Comfort	47400.00
0005433235410	285	Comfort	47400.00
0005434552802	285	Comfort	47400.00
0005434728915	285	Comfort	47400.00
0005432278193	285	Comfort	47400.00
0005433181626	285	Comfort	47400.00
0005433181624	285	Comfort	47400.00
0005434728931	285	Comfort	47400.00
0005434735836	285	Comfort	47400.00
0005434728941	285	Comfort	47400.00
0005433235615	285	Comfort	47400.00
0005434552795	285	Comfort	47400.00
0005434728950	285	Comfort	47400.00
0005433235509	285	Comfort	47400.00
0005433235152	285	Comfort	47400.00
0005433111544	285	Comfort	47400.00
0005433131799	285	Comfort	47400.00
0005434032115	285	Comfort	47400.00
0005434552819	285	Comfort	47400.00
0005433235774	285	Comfort	47400.00
0005433235697	285	Economy	27900.00
0005434552817	285	Economy	27900.00
0005433235385	285	Economy	27900.00
0005434552792	285	Economy	27900.00
0005434552799	285	Economy	27900.00
0005433289995	285	Economy	27900.00
0005433235574	285	Economy	27900.00
0005434728919	285	Economy	27900.00
0005434728927	285	Economy	27900.00
0005434728935	285	Economy	27900.00
0005434728901	285	Economy	27900.00
0005432278195	285	Economy	27900.00
0005433235828	285	Economy	27900.00
0005434728900	285	Economy	27900.00
0005433235624	285	Economy	27900.00
0005433235511	285	Economy	27900.00
0005434728936	285	Economy	27900.00
0005433235832	285	Economy	27900.00
0005433235677	285	Economy	27900.00
0005434728953	285	Economy	27900.00
0005433235455	285	Economy	27900.00
0005433235430	285	Economy	27900.00
0005433235492	285	Economy	27900.00
0005434728902	285	Economy	27900.00
0005433235720	285	Economy	27900.00
0005433235343	285	Economy	27900.00
0005434728929	285	Economy	27900.00
0005433181652	285	Economy	27900.00
0005433181605	285	Economy	27900.00
0005433235384	285	Economy	27900.00
0005433235479	285	Economy	27900.00
0005433181584	285	Economy	27900.00
0005434728930	285	Economy	27900.00
0005434728956	285	Economy	27900.00
0005433181596	285	Economy	27900.00
0005433235584	285	Economy	27900.00
0005433131777	285	Economy	27900.00
0005433181627	285	Economy	27900.00
0005433289988	285	Economy	27900.00
0005434552808	285	Economy	27900.00
0005434728942	285	Economy	30700.00
0005433235816	285	Economy	27900.00
0005433235687	285	Economy	27900.00
0005433181618	285	Economy	30700.00
0005434552810	285	Economy	27900.00
0005433235833	285	Economy	30700.00
0005433235411	285	Economy	30700.00
0005434728925	285	Economy	27900.00
0005433235878	285	Economy	27900.00
0005433235494	285	Economy	27900.00
0005434728893	285	Economy	27900.00
0005433235408	285	Economy	27900.00
0005433113581	285	Economy	27900.00
0005434552806	285	Economy	27900.00
0005434728944	285	Economy	27900.00
0005433235279	285	Economy	27900.00
0005434728938	285	Economy	27900.00
0005433235450	285	Economy	27900.00
0005433181614	285	Economy	27900.00
0005434728923	285	Economy	27900.00
0005434728960	285	Economy	27900.00
0005433766710	285	Economy	27900.00
0005434032094	285	Economy	27900.00
0005434552815	285	Economy	27900.00
0005433235571	285	Economy	27900.00
0005433235271	285	Economy	27900.00
0005433235620	285	Economy	27900.00
0005434552811	285	Economy	27900.00
0005434552818	285	Economy	27900.00
0005434728912	285	Economy	27900.00
0005435142953	285	Economy	27900.00
0005433126936	285	Economy	27900.00
0005434728907	285	Economy	27900.00
0005432278199	285	Economy	27900.00
0005434552798	285	Economy	27900.00
0005434728920	285	Economy	27900.00
0005433235714	285	Economy	27900.00
0005433181617	285	Economy	27900.00
0005433290024	285	Economy	27900.00
0005433235815	285	Economy	27900.00
0005434728906	285	Economy	27900.00
0005433235744	285	Economy	27900.00
0005433235570	285	Economy	27900.00
0005433235536	285	Economy	27900.00
0005433235569	285	Economy	27900.00
0005434552800	285	Economy	27900.00
0005433126927	285	Economy	27900.00
0005434728943	285	Economy	27900.00
0005433126934	285	Economy	27900.00
0005434728958	285	Economy	27900.00
0005433235702	285	Economy	27900.00
0005433235510	285	Economy	27900.00
0005432278197	285	Economy	27900.00
0005433235390	285	Economy	27900.00
0005434552812	285	Economy	27900.00
0005434728949	285	Economy	27900.00
0005433235630	285	Economy	27900.00
0005433181548	285	Economy	27900.00
0005434552794	285	Economy	27900.00
0005433181654	285	Economy	27900.00
0005434552803	285	Economy	27900.00
0005433235745	285	Economy	27900.00
0005434728957	285	Economy	27900.00
0005433181645	285	Economy	27900.00
0005433235760	285	Economy	27900.00
0005433235817	285	Economy	27900.00
0005433235616	285	Economy	27900.00
0005434552821	285	Economy	27900.00
0005434032099	285	Economy	27900.00
0005434552805	285	Economy	27900.00
0005433235422	285	Economy	27900.00
0005434728932	285	Economy	27900.00
0005434302909	285	Economy	27900.00
0005434735837	285	Economy	27900.00
0005433181615	285	Economy	27900.00
0005434032117	285	Economy	27900.00
0005434728916	285	Economy	27900.00
0005433181660	285	Economy	27900.00
0005433235501	285	Economy	27900.00
0005433290005	285	Economy	27900.00
0005434302907	285	Economy	27900.00
0005433289955	285	Economy	27900.00
0005433235827	285	Economy	27900.00
0005433181655	285	Economy	27900.00
0005434728918	285	Economy	27900.00
0005434302906	285	Economy	27900.00
0005433235820	285	Economy	27900.00
0005434735835	285	Economy	27900.00
0005433235703	285	Economy	27900.00
0005433235157	285	Economy	27900.00
0005434728933	285	Economy	27900.00
0005433181591	285	Economy	27900.00
0005433131815	285	Economy	27900.00
0005433289969	285	Economy	30700.00
0005433235342	285	Economy	30700.00
0005433126938	285	Economy	30700.00
0005434728959	285	Economy	30700.00
0005434552807	285	Economy	27900.00
0005434552813	285	Economy	27900.00
0005433235698	285	Economy	27900.00
0005434552820	285	Economy	27900.00
0005434728928	285	Economy	27900.00
0005434728913	285	Economy	27900.00
0005434728917	285	Economy	27900.00
0005433113579	285	Economy	27900.00
0005433111538	285	Economy	27900.00
0005432278196	285	Economy	27900.00
0005432278194	285	Economy	27900.00
0005433289983	285	Economy	27900.00
0005434728897	285	Economy	27900.00
0005433235642	285	Economy	27900.00
0005434032116	285	Economy	27900.00
0005433290004	285	Economy	27900.00
0005433126937	285	Economy	27900.00
0005433235779	285	Economy	27900.00
0005434032118	285	Economy	27900.00
0005434728898	285	Economy	27900.00
0005433181646	285	Economy	27900.00
0005434552816	285	Economy	27900.00
0005434552793	285	Economy	27900.00
0005433289954	285	Economy	27900.00
0005434728952	285	Economy	27900.00
0005433235270	285	Economy	27900.00
0005434728914	285	Economy	27900.00
0005434728937	285	Economy	27900.00
0005433235650	285	Economy	27900.00
0005433235562	285	Economy	27900.00
0005434552801	285	Economy	27900.00
0005434032100	285	Economy	27900.00
0005435142955	285	Economy	27900.00
0005434728922	285	Economy	27900.00
0005433235535	285	Economy	27900.00
0005433181653	285	Economy	27900.00
0005434552797	285	Economy	27900.00
0005433235491	285	Economy	27900.00
0005433181636	285	Economy	27900.00
0005434728939	285	Economy	27900.00
0005433289984	285	Economy	27900.00
0005433235362	285	Economy	27900.00
0005434728955	285	Economy	27900.00
0005433235581	285	Economy	27900.00
0005434728948	285	Economy	27900.00
0005433181592	285	Economy	27900.00
0005434728946	285	Economy	27900.00
0005433111536	285	Economy	27900.00
0005433181651	285	Economy	27900.00
0005433235573	285	Economy	27900.00
0005434728945	285	Economy	27900.00
0005433181456	285	Economy	27900.00
0005434728910	285	Economy	27900.00
0005433181633	285	Economy	27900.00
0005433111537	285	Economy	27900.00
0005434728947	285	Economy	27900.00
0005435142952	285	Economy	27900.00
0005434728911	285	Economy	27900.00
0005433235780	285	Economy	27900.00
0005433235818	285	Economy	27900.00
0005433235572	285	Economy	27900.00
0005433235389	285	Economy	27900.00
0005433235743	285	Economy	27900.00
0005433235563	285	Economy	27900.00
0005433289989	285	Economy	27900.00
0005434552809	285	Economy	27900.00
0005434728954	285	Economy	27900.00
0005435142954	285	Economy	27900.00
0005433235474	285	Economy	27900.00
0005433181632	285	Economy	27900.00
0005433235713	285	Economy	27900.00
0005434728326	9828	Business	83700.00
0005434727488	9828	Business	83700.00
0005434552061	9828	Business	83700.00
0005434727915	9828	Business	83700.00
0005434552346	9828	Business	83700.00
0005433235989	9828	Business	83700.00
0005434552445	9828	Business	83700.00
0005434728029	9828	Business	83700.00
0005434728133	9828	Business	83700.00
0005434728004	9828	Business	83700.00
0005434728191	9828	Business	83700.00
0005434728259	9828	Business	83700.00
0005433235971	9828	Business	83700.00
0005434728138	9828	Business	83700.00
0005434728275	9828	Business	83700.00
0005433290057	9828	Business	83700.00
0005434727666	9828	Business	83700.00
0005433766750	9828	Business	83700.00
0005433235984	9828	Business	83700.00
0005434552163	9828	Business	83700.00
0005434728195	9828	Business	83700.00
0005433235985	9828	Business	83700.00
0005434727786	9828	Comfort	47400.00
0005434728377	9828	Comfort	47400.00
0005434552482	9828	Comfort	47400.00
0005434728067	9828	Comfort	47400.00
0005433235994	9828	Comfort	47400.00
0005434552484	9828	Comfort	47400.00
0005434552322	9828	Comfort	47400.00
0005434551982	9828	Comfort	47400.00
0005434728371	9828	Comfort	47400.00
0005434728098	9828	Comfort	47400.00
0005433181815	9828	Comfort	47400.00
0005434552481	9828	Comfort	47400.00
0005433235996	9828	Comfort	47400.00
0005434728297	9828	Comfort	47400.00
0005434727500	9828	Comfort	47400.00
0005432199442	9828	Comfort	47400.00
0005434728516	9828	Comfort	47400.00
0005433235999	9828	Comfort	47400.00
0005434727886	9828	Comfort	47400.00
0005434727796	9828	Comfort	47400.00
0005434727985	9828	Comfort	47400.00
0005434728325	9828	Comfort	47400.00
0005434552305	9828	Comfort	47400.00
0005434552518	9828	Comfort	47400.00
0005433129407	9828	Comfort	47400.00
0005434728517	9828	Comfort	47400.00
0005434728298	9828	Comfort	47400.00
0005434735796	9828	Comfort	47400.00
0005433235973	9828	Comfort	47400.00
0005434552278	9828	Comfort	47400.00
0005434728005	9828	Comfort	47400.00
0005434552006	9828	Comfort	47400.00
0005434727911	9828	Comfort	47400.00
0005434552377	9828	Comfort	47400.00
0005434728427	9828	Economy	27900.00
0005434552536	9828	Economy	27900.00
0005434552438	9828	Economy	27900.00
0005434728034	9828	Economy	27900.00
0005434727912	9828	Economy	27900.00
0005434728605	9828	Economy	27900.00
0005434552379	9828	Economy	27900.00
0005434552060	9828	Economy	27900.00
0005433235988	9828	Economy	27900.00
0005434727922	9828	Economy	27900.00
0005433235980	9828	Economy	27900.00
0005434728409	9828	Economy	27900.00
0005433235974	9828	Economy	27900.00
0005434552604	9828	Economy	27900.00
0005434728016	9828	Economy	27900.00
0005433235997	9828	Economy	27900.00
0005434552315	9828	Economy	27900.00
0005434728717	9828	Economy	27900.00
0005434552412	9828	Economy	27900.00
0005433235982	9828	Economy	27900.00
0005434727824	9828	Economy	27900.00
0005434727861	9828	Economy	27900.00
0005434552434	9828	Economy	27900.00
0005434727960	9828	Economy	27900.00
0005434552358	9828	Economy	27900.00
0005433126974	9828	Economy	27900.00
0005434728107	9828	Economy	27900.00
0005434728351	9828	Economy	27900.00
0005434727991	9828	Economy	27900.00
0005434552341	9828	Economy	27900.00
0005434728254	9828	Economy	27900.00
0005434728030	9828	Economy	27900.00
0005434727775	9828	Economy	27900.00
0005434728106	9828	Economy	27900.00
0005434727980	9828	Economy	27900.00
0005434728069	9828	Economy	27900.00
0005433236001	9828	Economy	27900.00
0005433235969	9828	Economy	27900.00
0005434728250	9828	Economy	27900.00
0005434728033	9828	Economy	27900.00
0005433181816	9828	Economy	27900.00
0005434727965	9828	Economy	27900.00
0005434727887	9828	Economy	27900.00
0005434727285	9828	Economy	27900.00
0005434552332	9828	Economy	27900.00
0005433235992	9828	Economy	27900.00
0005434728051	9828	Economy	30700.00
0005433181820	9828	Economy	27900.00
0005435142873	9828	Economy	30700.00
0005434552431	9828	Economy	27900.00
0005433235986	9828	Economy	27900.00
0005434727546	9828	Economy	27900.00
0005434727805	9828	Economy	30700.00
0005434552356	9828	Economy	30700.00
0005434728335	9828	Economy	30700.00
0005434552203	9828	Economy	27900.00
0005434552235	9828	Economy	27900.00
0005434728253	9828	Economy	27900.00
0005434728031	9828	Economy	27900.00
0005434727570	9828	Economy	27900.00
0005434728369	9828	Economy	27900.00
0005434728088	9828	Economy	27900.00
0005434728261	9828	Economy	27900.00
0005434727956	9828	Economy	27900.00
0005435142845	9828	Economy	27900.00
0005434728159	9828	Economy	27900.00
0005433235981	9828	Economy	27900.00
0005434727979	9828	Economy	27900.00
0005434727319	9828	Economy	27900.00
0005433235991	9828	Economy	27900.00
0005434728015	9828	Economy	27900.00
0005434552270	9828	Economy	27900.00
0005434727959	9828	Economy	27900.00
0005434728201	9828	Economy	27900.00
0005434552314	9828	Economy	27900.00
0005434552384	9828	Economy	27900.00
0005434727836	9828	Economy	27900.00
0005434727674	9828	Economy	27900.00
0005433290055	9828	Economy	27900.00
0005434727835	9828	Economy	27900.00
0005434727435	9828	Economy	27900.00
0005434727797	9828	Economy	27900.00
0005434727804	9828	Economy	27900.00
0005434735802	9828	Economy	27900.00
0005434731273	9828	Economy	27900.00
0005434731255	9828	Economy	27900.00
0005434302547	9828	Economy	27900.00
0005434727983	9828	Economy	27900.00
0005434552125	9828	Economy	27900.00
0005434728200	9828	Economy	27900.00
0005433129409	9828	Economy	27900.00
0005434552002	9828	Economy	27900.00
0005434728518	9828	Economy	27900.00
0005433235970	9828	Economy	27900.00
0005435142839	9828	Economy	27900.00
0005434728483	9828	Economy	27900.00
0005434552413	9828	Economy	27900.00
0005433235983	9828	Economy	27900.00
0005434728002	9828	Economy	27900.00
0005434727877	9828	Economy	27900.00
0005434727693	9828	Economy	27900.00
0005434552432	9828	Economy	27900.00
0005434728194	9828	Economy	27900.00
0005433235967	9828	Economy	27900.00
0005434728376	9828	Economy	27900.00
0005434727609	9828	Economy	27900.00
0005434728097	9828	Economy	27900.00
0005434728343	9828	Economy	27900.00
0005433235968	9828	Economy	27900.00
0005435142829	9828	Economy	27900.00
0005434552368	9828	Economy	27900.00
0005434552231	9828	Economy	27900.00
0005433235995	9828	Economy	27900.00
0005434552424	9828	Economy	27900.00
0005433290056	9828	Economy	27900.00
0005434728607	9828	Economy	27900.00
0005434728405	9828	Economy	27900.00
0005433235978	9828	Economy	27900.00
0005434727489	9828	Economy	27900.00
0005434728379	9828	Economy	27900.00
0005433129408	9828	Economy	27900.00
0005434727891	9828	Economy	27900.00
0005432199444	9828	Economy	27900.00
0005433235990	9828	Economy	27900.00
0005434728349	9828	Economy	27900.00
0005434727545	9828	Economy	27900.00
0005434552403	9828	Economy	27900.00
0005434552220	9828	Economy	27900.00
0005434727862	9828	Economy	27900.00
0005434552043	9828	Economy	27900.00
0005434728225	9828	Economy	27900.00
0005433126975	9828	Economy	27900.00
0005432199443	9828	Economy	27900.00
0005434552271	9828	Economy	27900.00
0005434552493	9828	Economy	27900.00
0005434552325	9828	Economy	27900.00
0005434728246	9828	Economy	27900.00
0005434728125	9828	Economy	27900.00
0005434727947	9828	Economy	30700.00
0005434552441	9828	Economy	27900.00
0005434728170	9828	Economy	30700.00
0005434735791	9828	Economy	30700.00
0005433113597	9828	Economy	27900.00
0005434728600	9828	Economy	27900.00
0005434728183	9828	Economy	27900.00
0005434728606	9828	Economy	27900.00
0005434552249	9828	Economy	27900.00
0005434552044	9828	Economy	27900.00
0005434552516	9828	Economy	27900.00
0005434728385	9828	Economy	27900.00
0005433236000	9828	Economy	27900.00
0005434552494	9828	Economy	27900.00
0005434727787	9828	Economy	27900.00
0005434728355	9828	Economy	27900.00
0005434728046	9828	Economy	27900.00
0005434727904	9828	Economy	27900.00
0005434552275	9828	Economy	27900.00
0005434552124	9828	Economy	27900.00
0005433181818	9828	Economy	27900.00
0005434552517	9828	Economy	27900.00
0005434727815	9828	Economy	27900.00
0005433235977	9828	Economy	27900.00
0005434727934	9828	Economy	27900.00
0005433235998	9828	Economy	27900.00
0005433235976	9828	Economy	27900.00
0005433181817	9828	Economy	27900.00
0005434552426	9828	Economy	27900.00
0005434728190	9828	Economy	27900.00
0005434727356	9828	Economy	27900.00
0005434728141	9828	Economy	27900.00
0005434552483	9828	Economy	27900.00
0005434728313	9828	Economy	27900.00
0005434728384	9828	Economy	27900.00
0005434552274	9828	Economy	27900.00
0005434552402	9828	Economy	27900.00
0005434552433	9828	Economy	27900.00
0005434727890	9828	Economy	27900.00
0005434552053	9828	Economy	27900.00
0005435142854	9828	Economy	27900.00
0005434735797	9828	Economy	27900.00
0005434552342	9828	Economy	27900.00
0005433235979	9828	Economy	27900.00
0005433235993	9828	Economy	27900.00
0005434727698	9828	Economy	27900.00
0005434552245	9828	Economy	27900.00
0005435142812	9828	Economy	27900.00
0005433290058	9828	Economy	27900.00
0005434552425	9828	Economy	27900.00
0005434728348	9828	Economy	27900.00
0005434728444	9828	Economy	27900.00
0005434728428	9828	Economy	27900.00
0005434552535	9828	Economy	27900.00
0005434727878	9828	Economy	27900.00
0005434728245	9828	Economy	27900.00
0005434727284	9828	Economy	27900.00
0005434728142	9828	Economy	27900.00
0005434552333	9828	Economy	27900.00
0005434727782	9828	Economy	27900.00
0005433235987	9828	Economy	27900.00
0005435142788	9828	Economy	27900.00
0005434727707	9828	Economy	27900.00
0005433235972	9828	Economy	27900.00
0005434727823	9828	Economy	27900.00
0005434552429	9828	Economy	27900.00
0005434552414	9828	Economy	27900.00
0005434727948	9828	Economy	27900.00
0005434727987	9828	Economy	27900.00
0005435142840	9828	Economy	27900.00
0005434727989	9828	Economy	27900.00
0005434731253	9828	Economy	27900.00
0005434728299	9828	Economy	27900.00
0005433181819	9828	Economy	27900.00
0005435142808	9828	Economy	27900.00
0005433235975	9828	Economy	27900.00
0005434552359	9828	Economy	27900.00
0005434728162	9828	Economy	27900.00
0005434552430	9828	Economy	27900.00
0005434728294	9828	Economy	27900.00
0005434731254	9828	Economy	27900.00
0005432070067	7767	Business	42100.00
0005435214868	7767	Business	42100.00
0005432531703	7767	Business	42100.00
0005432531717	7767	Business	42100.00
0005432531721	7767	Business	42100.00
0005435215066	7767	Comfort	23900.00
0005435215014	7767	Comfort	23900.00
0005432531694	7767	Comfort	23900.00
0005432531705	7767	Comfort	23900.00
0005435214890	7767	Comfort	23900.00
0005435215070	7767	Comfort	23900.00
0005434069603	7767	Comfort	23900.00
0005434069581	7767	Comfort	23900.00
0005432531707	7767	Comfort	23900.00
0005432531691	7767	Comfort	23900.00
0005432070071	7767	Comfort	23900.00
0005435215013	7767	Comfort	23900.00
0005435215150	7767	Comfort	23900.00
0005432429029	7767	Economy	14000.00
0005434069601	7767	Economy	14000.00
0005435215055	7767	Economy	14000.00
0005432531704	7767	Economy	14000.00
0005435215004	7767	Economy	14000.00
0005435215054	7767	Economy	14000.00
0005435215351	7767	Economy	14000.00
0005434069579	7767	Economy	14000.00
0005434069590	7767	Economy	14000.00
0005432150419	7767	Economy	14000.00
0005432531698	7767	Economy	14000.00
0005435725690	7767	Economy	14000.00
0005435214993	7767	Economy	14000.00
0005434069583	7767	Economy	14000.00
0005432531711	7767	Economy	14000.00
0005432531715	7767	Economy	14000.00
0005435214832	7767	Economy	14000.00
0005432531724	7767	Economy	14000.00
0005432531712	7767	Economy	14000.00
0005432531688	7767	Economy	14000.00
0005432531723	7767	Economy	14000.00
0005435215035	7767	Economy	14000.00
0005434069594	7767	Economy	14000.00
0005434069585	7767	Economy	14000.00
0005435215301	7767	Economy	14000.00
0005434069586	7767	Economy	15400.00
0005435215350	7767	Economy	14000.00
0005435215081	7767	Economy	15400.00
0005434069589	7767	Economy	15400.00
0005435215122	7767	Economy	14000.00
0005435214869	7767	Economy	14000.00
0005432531702	7767	Economy	14000.00
0005432531727	7767	Economy	14000.00
0005435725692	7767	Economy	14000.00
0005435215220	7767	Economy	14000.00
0005434069602	7767	Economy	14000.00
0005432531706	7767	Economy	14000.00
0005435725693	7767	Economy	14000.00
0005435214735	7767	Economy	14000.00
0005435631035	7767	Economy	14000.00
0005435214932	7767	Economy	14000.00
0005435215142	7767	Economy	14000.00
0005434069591	7767	Economy	14000.00
0005435214801	7767	Economy	14000.00
0005432531687	7767	Economy	14000.00
0005434069588	7767	Economy	14000.00
0005435214931	7767	Economy	14000.00
0005435214824	7767	Economy	14000.00
0005435215005	7767	Economy	14000.00
0005434069576	7767	Economy	14000.00
0005432531692	7767	Economy	14000.00
0005434069584	7767	Economy	14000.00
0005435215134	7767	Economy	14000.00
0005434069580	7767	Economy	14000.00
0005432531726	7767	Economy	14000.00
0005432531699	7767	Economy	14000.00
0005434069597	7767	Economy	14000.00
0005434069592	7767	Economy	14000.00
0005434069599	7767	Economy	14000.00
0005432070069	7767	Economy	14000.00
0005434069587	7767	Economy	14000.00
0005434069574	7767	Economy	14000.00
0005432531690	7767	Economy	14000.00
0005432531720	7767	Economy	14000.00
0005432070066	7767	Economy	14000.00
0005434069573	7767	Economy	14000.00
0005432531725	7767	Economy	14000.00
0005435214728	7767	Economy	14000.00
0005435214838	7767	Economy	14000.00
0005434069578	7767	Economy	14000.00
0005435215152	7767	Economy	14000.00
0005435214752	7767	Economy	14000.00
0005434069575	7767	Economy	14000.00
0005435214651	7767	Economy	14000.00
0005432535974	7767	Economy	14000.00
0005435215233	7767	Economy	14000.00
0005432531708	7767	Economy	14000.00
0005435214897	7767	Economy	14000.00
0005434069593	7767	Economy	14000.00
0005432533374	7767	Economy	14000.00
0005432537119	7767	Economy	14000.00
0005432531714	7767	Economy	14000.00
0005432531696	7767	Economy	14000.00
0005432531710	7767	Economy	14000.00
0005432533375	7767	Economy	14000.00
0005434069600	7767	Economy	14000.00
0005432070068	7767	Economy	14000.00
0005432531693	7767	Economy	14000.00
0005435214945	7767	Economy	15400.00
0005435214883	7767	Economy	15400.00
0005432531695	7767	Economy	15400.00
0005435214833	7767	Economy	14000.00
0005432533373	7767	Economy	14000.00
0005435214766	7767	Economy	14000.00
0005435214652	7767	Economy	14000.00
0005434069596	7767	Economy	14000.00
0005432531697	7767	Economy	14000.00
0005435214891	7767	Economy	14000.00
0005432531701	7767	Economy	14000.00
0005435214896	7767	Economy	14000.00
0005434069595	7767	Economy	14000.00
0005432070070	7767	Economy	14000.00
0005435214925	7767	Economy	14000.00
0005433656726	7767	Economy	14000.00
0005432429028	7767	Economy	14000.00
0005432531718	7767	Economy	14000.00
0005432531689	7767	Economy	14000.00
0005432531700	7767	Economy	14000.00
0005435214892	7767	Economy	14000.00
0005435214879	7767	Economy	14000.00
0005433656735	7767	Economy	14000.00
0005435215068	7767	Economy	14000.00
0005434069598	7767	Economy	14000.00
0005432531716	7767	Economy	14000.00
0005435215090	7767	Economy	14000.00
0005432531713	7767	Economy	14000.00
0005435215045	7767	Economy	14000.00
0005435215121	7767	Economy	14000.00
0005434069582	7767	Economy	14000.00
0005434069604	7767	Economy	14000.00
0005435215151	7767	Economy	14000.00
0005432531722	7767	Economy	14000.00
0005434069572	7767	Economy	14000.00
0005432531709	7767	Economy	14000.00
0005432531719	7767	Economy	14000.00
0005435214884	7767	Economy	14000.00
0005435215053	7767	Economy	14000.00
0005434069577	7767	Economy	14000.00
0005435215003	7767	Economy	14000.00
0005435725681	7767	Economy	14000.00
0005435214837	7767	Economy	14000.00
0005435214878	7767	Economy	14000.00
0005435214971	7767	Economy	14000.00
0005435616943	5318	Business	43100.00
0005434345245	5318	Business	43100.00
0005435616938	5318	Business	43100.00
0005435617199	5318	Business	43100.00
0005434573753	5318	Business	43100.00
0005434345242	5318	Business	43100.00
0005434245524	5318	Business	43100.00
0005435616918	5318	Business	43100.00
0005434345246	5318	Business	43100.00
0005434345252	5318	Business	43100.00
0005434245563	5318	Business	43100.00
0005434245478	5318	Business	43100.00
0005435616904	5318	Business	43100.00
0005434573760	5318	Business	43100.00
0005435380403	5318	Business	43100.00
0005435426655	5318	Business	43100.00
0005434573755	5318	Business	43100.00
0005435616913	5318	Comfort	24400.00
0005435426425	5318	Comfort	24400.00
0005435426554	5318	Comfort	24400.00
0005435426268	5318	Comfort	24400.00
0005435426442	5318	Comfort	24400.00
0005435426363	5318	Comfort	24400.00
0005434245513	5318	Comfort	24400.00
0005435319786	5318	Comfort	24400.00
0005435426128	5318	Comfort	24400.00
0005434245592	5318	Comfort	24400.00
0005435616951	5318	Comfort	24400.00
0005435616941	5318	Comfort	24400.00
0005435616955	5318	Comfort	24400.00
0005435426514	5318	Comfort	24400.00
0005434245591	5318	Comfort	24400.00
0005435426605	5318	Comfort	24400.00
0005435426536	5318	Comfort	24400.00
0005435616922	5318	Comfort	24400.00
0005435616898	5318	Comfort	24400.00
0005435616905	5318	Comfort	24400.00
0005435426412	5318	Comfort	24400.00
0005434245611	5318	Comfort	24400.00
0005435042911	5318	Comfort	24400.00
0005434245514	5318	Comfort	24400.00
0005435426408	5318	Comfort	24400.00
0005434245526	5318	Comfort	24400.00
0005435616933	5318	Comfort	24400.00
0005435426564	5318	Comfort	24400.00
0005435426330	5318	Comfort	24400.00
0005434345239	5318	Comfort	24400.00
0005435426264	5318	Comfort	24400.00
0005434345247	5318	Economy	14400.00
0005435616948	5318	Economy	14400.00
0005434345256	5318	Economy	14400.00
0005435617198	5318	Economy	14400.00
0005435426636	5318	Economy	14400.00
0005435380372	5318	Economy	14400.00
0005432133641	5318	Economy	14400.00
0005435616927	5318	Economy	14400.00
0005435426394	5318	Economy	14400.00
0005434656593	5318	Economy	14400.00
0005434656604	5318	Economy	14400.00
0005435616921	5318	Economy	14400.00
0005435426630	5318	Economy	14400.00
0005435616928	5318	Economy	14400.00
0005435426513	5318	Economy	14400.00
0005434245572	5318	Economy	14400.00
0005435616958	5318	Economy	14400.00
0005435616917	5318	Economy	14400.00
0005434345253	5318	Economy	14400.00
0005435319770	5318	Economy	14400.00
0005434573758	5318	Economy	14400.00
0005432133644	5318	Economy	14400.00
0005435319780	5318	Economy	14400.00
0005434345250	5318	Economy	14400.00
0005435319754	5318	Economy	14400.00
0005434245523	5318	Economy	14400.00
0005435426136	5318	Economy	14400.00
0005435490333	5318	Economy	14400.00
0005435319798	5318	Economy	14400.00
0005432133645	5318	Economy	14400.00
0005434245610	5318	Economy	14400.00
0005435302301	5318	Economy	14400.00
0005434573757	5318	Economy	14400.00
0005435426520	5318	Economy	14400.00
0005435616919	5318	Economy	14400.00
0005435426591	5318	Economy	14400.00
0005435426252	5318	Economy	14400.00
0005435616956	5318	Economy	14400.00
0005435426213	5318	Economy	14400.00
0005435426201	5318	Economy	14400.00
0005435616934	5318	Economy	14400.00
0005432363487	5318	Economy	14400.00
0005435426424	5318	Economy	14400.00
0005435426652	5318	Economy	14400.00
0005435426317	5318	Economy	14400.00
0005434656589	5318	Economy	14400.00
0005435616908	5318	Economy	14400.00
0005434345248	5318	Economy	14400.00
0005435426353	5318	Economy	14400.00
0005435426411	5318	Economy	15800.00
0005435616911	5318	Economy	14400.00
0005432133642	5318	Economy	14400.00
0005435616935	5318	Economy	14400.00
0005435426331	5318	Economy	14400.00
0005435426332	5318	Economy	14400.00
0005435491504	5318	Economy	14400.00
0005434245679	5318	Economy	14400.00
0005434245593	5318	Economy	14400.00
0005432133643	5318	Economy	14400.00
0005435426463	5318	Economy	14400.00
0005435616907	5318	Economy	14400.00
0005432133634	5318	Economy	14400.00
0005435426590	5318	Economy	14400.00
0005435426555	5318	Economy	14400.00
0005435616937	5318	Economy	14400.00
0005435319790	5318	Economy	14400.00
0005435617201	5318	Economy	14400.00
0005434245614	5318	Economy	14400.00
0005435616925	5318	Economy	14400.00
0005435426638	5318	Economy	14400.00
0005435616947	5318	Economy	14400.00
0005434245645	5318	Economy	14400.00
0005434345240	5318	Economy	14400.00
0005435426537	5318	Economy	14400.00
0005435491503	5318	Economy	14400.00
0005435616952	5318	Economy	14400.00
0005435616954	5318	Economy	14400.00
0005432133633	5318	Economy	14400.00
0005435426350	5318	Economy	14400.00
0005434245571	5318	Economy	14400.00
0005435616932	5318	Economy	14400.00
0005435616912	5318	Economy	14400.00
0005435426383	5318	Economy	14400.00
0005435042920	5318	Economy	14400.00
0005435380398	5318	Economy	14400.00
0005434345244	5318	Economy	14400.00
0005435426202	5318	Economy	14400.00
0005434245658	5318	Economy	14400.00
0005435042921	5318	Economy	14400.00
0005434245613	5318	Economy	14400.00
0005435616899	5318	Economy	14400.00
0005435097491	5318	Economy	14400.00
0005435616942	5318	Economy	14400.00
0005435616915	5318	Economy	14400.00
0005435426440	5318	Economy	14400.00
0005435302278	5318	Economy	14400.00
0005434345243	5318	Economy	14400.00
0005435426333	5318	Economy	14400.00
0005432133640	5318	Economy	14400.00
0005434573754	5318	Economy	14400.00
0005435426253	5318	Economy	14400.00
0005435616940	5318	Economy	14400.00
0005435616914	5318	Economy	14400.00
0005432133635	5318	Economy	14400.00
0005435616931	5318	Economy	14400.00
0005435426127	5318	Economy	14400.00
0005435490332	5318	Economy	14400.00
0005435616926	5318	Economy	14400.00
0005435616909	5318	Economy	14400.00
0005434573759	5318	Economy	14400.00
0005434345241	5318	Economy	14400.00
0005435616903	5318	Economy	14400.00
0005435490334	5318	Economy	14400.00
0005435616945	5318	Economy	14400.00
0005435426637	5318	Economy	14400.00
0005434345255	5318	Economy	14400.00
0005435426341	5318	Economy	14400.00
0005435319789	5318	Economy	14400.00
0005434573761	5318	Economy	14400.00
0005435302291	5318	Economy	14400.00
0005435616949	5318	Economy	14400.00
0005434245711	5318	Economy	15800.00
0005435426472	5318	Economy	14400.00
0005435426126	5318	Economy	14400.00
0005435380399	5318	Economy	14400.00
0005435616924	5318	Economy	14400.00
0005435617200	5318	Economy	14400.00
0005434656590	5318	Economy	14400.00
0005435616944	5318	Economy	14400.00
0005435319763	5318	Economy	14400.00
0005435616939	5318	Economy	14400.00
0005435616901	5318	Economy	14400.00
0005435380413	5318	Economy	14400.00
0005435302310	5318	Economy	14400.00
0005432047659	5318	Economy	14400.00
0005435426326	5318	Economy	14400.00
0005432133639	5318	Economy	14400.00
0005434245648	5318	Economy	14400.00
0005434245678	5318	Economy	14400.00
0005434245579	5318	Economy	14400.00
0005435616950	5318	Economy	14400.00
0005434345257	5318	Economy	14400.00
0005435319745	5318	Economy	14400.00
0005434245659	5318	Economy	14400.00
0005434245618	5318	Economy	14400.00
0005435426352	5318	Economy	14400.00
0005434245646	5318	Economy	14400.00
0005435426135	5318	Economy	14400.00
0005432133637	5318	Economy	14400.00
0005435426278	5318	Economy	14400.00
0005432133636	5318	Economy	14400.00
0005435616923	5318	Economy	14400.00
0005435319779	5318	Economy	14400.00
0005434245570	5318	Economy	14400.00
0005435616900	5318	Economy	14400.00
0005435616906	5318	Economy	14400.00
0005435616910	5318	Economy	14400.00
0005435426364	5318	Economy	14400.00
0005435616916	5318	Economy	14400.00
0005435426130	5318	Economy	14400.00
0005435302307	5318	Economy	14400.00
0005435426416	5318	Economy	14400.00
0005435556766	5318	Economy	14400.00
0005435380412	5318	Economy	14400.00
0005435426629	5318	Economy	14400.00
0005435426241	5318	Economy	14400.00
0005435319764	5318	Economy	14400.00
0005432047658	5318	Economy	14400.00
0005435616957	5318	Economy	14400.00
0005435616902	5318	Economy	14400.00
0005435617197	5318	Economy	14400.00
0005435042910	5318	Economy	14400.00
0005434345251	5318	Economy	14400.00
0005435616953	5318	Economy	14400.00
0005435426477	5318	Economy	14400.00
0005435616936	5318	Economy	14400.00
0005435426563	5318	Economy	14400.00
0005434245588	5318	Economy	14400.00
0005434245680	5318	Economy	14400.00
0005435426327	5318	Economy	14400.00
0005434245495	5318	Economy	14400.00
0005435426340	5318	Economy	14400.00
0005435616946	5318	Economy	14400.00
0005435616929	5318	Economy	14400.00
0005435097492	5318	Economy	14400.00
0005434345254	5318	Economy	14400.00
0005435426604	5318	Economy	14400.00
0005434245612	5318	Economy	14400.00
0005434573756	5318	Economy	14400.00
0005434345249	5318	Economy	14400.00
0005435302292	5318	Economy	14400.00
0005435426157	5318	Economy	14400.00
0005435426444	5318	Economy	14400.00
0005435616930	5318	Economy	14400.00
0005432133638	5318	Economy	14400.00
0005434345258	5318	Economy	14400.00
0005435319725	5318	Economy	14400.00
0005435616920	5318	Economy	14400.00
0005434245564	5318	Economy	14400.00
0005435615931	10902	Business	43100.00
0005435616382	10902	Business	43100.00
0005435616200	10902	Business	43100.00
0005435615345	10902	Business	43100.00
0005435616229	10902	Business	43100.00
0005434245826	10902	Business	43100.00
0005434573625	10902	Business	43100.00
0005435616310	10902	Business	43100.00
0005435615772	10902	Business	43100.00
0005435768119	10902	Business	43100.00
0005435615677	10902	Business	43100.00
0005435615681	10902	Business	43100.00
0005435616055	10902	Business	43100.00
0005435426781	10902	Business	43100.00
0005434344827	10902	Business	43100.00
0005435426794	10902	Business	43100.00
0005435654512	10902	Business	43100.00
0005435616011	10902	Business	43100.00
0005435426762	10902	Business	43100.00
0005435615861	10902	Business	43100.00
0005435426757	10902	Business	43100.00
0005435616695	10902	Business	43100.00
0005435097421	10902	Business	43100.00
0005434245818	10902	Business	43100.00
0005435616293	10902	Comfort	24400.00
0005435426756	10902	Comfort	24400.00
0005434245825	10902	Comfort	24400.00
0005435615840	10902	Comfort	24400.00
0005434245815	10902	Comfort	24400.00
0005435490305	10902	Comfort	24400.00
0005435490291	10902	Comfort	24400.00
0005435615817	10902	Comfort	24400.00
0005435426760	10902	Comfort	24400.00
0005435616027	10902	Comfort	24400.00
0005435616043	10902	Comfort	24400.00
0005435616220	10902	Comfort	24400.00
0005435615620	10902	Comfort	24400.00
0005434344925	10902	Comfort	24400.00
0005435615765	10902	Comfort	24400.00
0005435490306	10902	Comfort	24400.00
0005435546234	10902	Comfort	24400.00
0005435616105	10902	Comfort	24400.00
0005435616378	10902	Comfort	24400.00
0005434344938	10902	Comfort	24400.00
0005435616506	10902	Comfort	24400.00
0005434573622	10902	Comfort	24400.00
0005435426765	10902	Comfort	24400.00
0005435426772	10902	Comfort	24400.00
0005435615510	10902	Comfort	24400.00
0005434573641	10902	Comfort	24400.00
0005435426780	10902	Comfort	24400.00
0005435615577	10902	Comfort	24400.00
0005435615628	10902	Comfort	24400.00
0005435616322	10902	Comfort	24400.00
0005435426776	10902	Comfort	24400.00
0005435426790	10902	Comfort	24400.00
0005435617240	10902	Comfort	24400.00
0005435305075	10902	Comfort	24400.00
0005434573640	10902	Comfort	24400.00
0005435097398	10902	Comfort	24400.00
0005435616346	10902	Comfort	24400.00
0005435305076	10902	Economy	14400.00
0005435615576	10902	Economy	14400.00
0005435616345	10902	Economy	14400.00
0005435426786	10902	Economy	14400.00
0005435615818	10902	Economy	14400.00
0005435616131	10902	Economy	14400.00
0005435097411	10902	Economy	14400.00
0005435616086	10902	Economy	14400.00
0005435615922	10902	Economy	14400.00
0005435615989	10902	Economy	14400.00
0005435426768	10902	Economy	14400.00
0005432841073	10902	Economy	14400.00
0005434573595	10902	Economy	14400.00
0005435615963	10902	Economy	14400.00
0005434245817	10902	Economy	14400.00
0005435304271	10902	Economy	14400.00
0005434344924	10902	Economy	14400.00
0005435097388	10902	Economy	14400.00
0005434573635	10902	Economy	14400.00
0005435615985	10902	Economy	14400.00
0005435380438	10902	Economy	14400.00
0005435615921	10902	Economy	14400.00
0005435615884	10902	Economy	14400.00
0005435616156	10902	Economy	14400.00
0005434344914	10902	Economy	14400.00
0005435617239	10902	Economy	14400.00
0005435304269	10902	Economy	14400.00
0005434573582	10902	Economy	14400.00
0005435426788	10902	Economy	14400.00
0005435097395	10902	Economy	14400.00
0005435097360	10902	Economy	14400.00
0005435616044	10902	Economy	14400.00
0005435426774	10902	Economy	14400.00
0005435615548	10902	Economy	14400.00
0005435615672	10902	Economy	14400.00
0005434344868	10902	Economy	14400.00
0005435616379	10902	Economy	14400.00
0005435426793	10902	Economy	14400.00
0005435615876	10902	Economy	14400.00
0005434573591	10902	Economy	14400.00
0005435615955	10902	Economy	14400.00
0005434573590	10902	Economy	14400.00
0005434344927	10902	Economy	14400.00
0005434344899	10902	Economy	14400.00
0005435615634	10902	Economy	14400.00
0005435097386	10902	Economy	14400.00
0005434573585	10902	Economy	14400.00
0005435617238	10902	Economy	14400.00
0005434245816	10902	Economy	14400.00
0005435426789	10902	Economy	14400.00
0005434573599	10902	Economy	14400.00
0005435426784	10902	Economy	14400.00
0005435555414	10902	Economy	14400.00
0005435615718	10902	Economy	14400.00
0005435615546	10902	Economy	14400.00
0005435616383	10902	Economy	14400.00
0005434344898	10902	Economy	15800.00
0005435615954	10902	Economy	15800.00
0005435615741	10902	Economy	15800.00
0005435615703	10902	Economy	14400.00
0005435380435	10902	Economy	14400.00
0005434344937	10902	Economy	15800.00
0005435615860	10902	Economy	14400.00
0005435426761	10902	Economy	15800.00
0005435615670	10902	Economy	15800.00
0005435616388	10902	Economy	14400.00
0005434573589	10902	Economy	14400.00
0005435615970	10902	Economy	14400.00
0005435615535	10902	Economy	14400.00
0005435615773	10902	Economy	14400.00
0005434344828	10902	Economy	14400.00
0005434344974	10902	Economy	14400.00
0005435319822	10902	Economy	14400.00
0005434344926	10902	Economy	14400.00
0005434573560	10902	Economy	14400.00
0005435616085	10902	Economy	14400.00
0005435616329	10902	Economy	14400.00
0005435616158	10902	Economy	14400.00
0005435426795	10902	Economy	14400.00
0005435304268	10902	Economy	14400.00
0005434344891	10902	Economy	14400.00
0005435616186	10902	Economy	14400.00
0005435097379	10902	Economy	14400.00
0005434573654	10902	Economy	14400.00
0005435615935	10902	Economy	14400.00
0005435616182	10902	Economy	14400.00
0005435616045	10902	Economy	14400.00
0005434344837	10902	Economy	14400.00
0005435616396	10902	Economy	14400.00
0005434245820	10902	Economy	14400.00
0005435615604	10902	Economy	14400.00
0005435426792	10902	Economy	14400.00
0005434245821	10902	Economy	14400.00
0005435615462	10902	Economy	14400.00
0005435616132	10902	Economy	14400.00
0005435654515	10902	Economy	14400.00
0005435615547	10902	Economy	14400.00
0005432363514	10902	Economy	14400.00
0005435616311	10902	Economy	14400.00
0005434345072	10902	Economy	14400.00
0005434573642	10902	Economy	14400.00
0005434344892	10902	Economy	14400.00
0005435616355	10902	Economy	14400.00
0005435615655	10902	Economy	14400.00
0005435616004	10902	Economy	14400.00
0005435616295	10902	Economy	14400.00
0005435616007	10902	Economy	14400.00
0005435615599	10902	Economy	14400.00
0005435616505	10902	Economy	14400.00
0005435616201	10902	Economy	14400.00
0005435380437	10902	Economy	14400.00
0005435615977	10902	Economy	14400.00
0005435097414	10902	Economy	14400.00
0005435615991	10902	Economy	14400.00
0005432363513	10902	Economy	14400.00
0005435615947	10902	Economy	14400.00
0005435615774	10902	Economy	14400.00
0005435616189	10902	Economy	14400.00
0005435615901	10902	Economy	14400.00
0005435615793	10902	Economy	14400.00
0005435426767	10902	Economy	14400.00
0005435615992	10902	Economy	14400.00
0005435617181	10902	Economy	14400.00
0005434245819	10902	Economy	14400.00
0005435426787	10902	Economy	14400.00
0005435616243	10902	Economy	14400.00
0005435615237	10902	Economy	14400.00
0005435615863	10902	Economy	14400.00
0005435555413	10902	Economy	14400.00
0005435490287	10902	Economy	14400.00
0005434344742	10902	Economy	14400.00
0005433719238	10902	Economy	14400.00
0005435615536	10902	Economy	14400.00
0005435615674	10902	Economy	14400.00
0005432363512	10902	Economy	14400.00
0005434344835	10902	Economy	14400.00
0005435426759	10902	Economy	14400.00
0005435426791	10902	Economy	14400.00
0005435380434	10902	Economy	14400.00
0005434573631	10902	Economy	14400.00
0005435097399	10902	Economy	14400.00
0005435097420	10902	Economy	14400.00
0005435491486	10902	Economy	14400.00
0005435615766	10902	Economy	14400.00
0005435615767	10902	Economy	14400.00
0005435615630	10902	Economy	14400.00
0005435616694	10902	Economy	14400.00
0005435615965	10902	Economy	14400.00
0005434245827	10902	Economy	14400.00
0005435616028	10902	Economy	14400.00
0005435097423	10902	Economy	14400.00
0005434344885	10902	Economy	14400.00
0005434573630	10902	Economy	14400.00
0005435615839	10902	Economy	14400.00
0005435426778	10902	Economy	14400.00
0005435615783	10902	Economy	14400.00
0005435616262	10902	Economy	15800.00
0005435616325	10902	Economy	15800.00
0005432166993	10902	Economy	15800.00
0005434344836	10902	Economy	15800.00
0005435616507	10902	Economy	14400.00
0005435616005	10902	Economy	14400.00
0005434573628	10902	Economy	14400.00
0005435426796	10902	Economy	14400.00
0005435304270	10902	Economy	14400.00
0005434344855	10902	Economy	14400.00
0005434344939	10902	Economy	14400.00
0005435426775	10902	Economy	14400.00
0005435615691	10902	Economy	14400.00
0005435319821	10902	Economy	14400.00
0005435615862	10902	Economy	14400.00
0005435616319	10902	Economy	14400.00
0005435616294	10902	Economy	14400.00
0005433719237	10902	Economy	14400.00
0005434345108	10902	Economy	14400.00
0005435615841	10902	Economy	14400.00
0005435615682	10902	Economy	14400.00
0005435654513	10902	Economy	14400.00
0005435615764	10902	Economy	14400.00
0005435616204	10902	Economy	14400.00
0005435768121	10902	Economy	14400.00
0005434573598	10902	Economy	14400.00
0005435615716	10902	Economy	14400.00
0005435426782	10902	Economy	14400.00
0005435615902	10902	Economy	14400.00
0005435380436	10902	Economy	14400.00
0005434573623	10902	Economy	14400.00
0005435616188	10902	Economy	14400.00
0005435426758	10902	Economy	14400.00
0005435768120	10902	Economy	14400.00
0005435616320	10902	Economy	14400.00
0005435616316	10902	Economy	14400.00
0005435097396	10902	Economy	14400.00
0005435615346	10902	Economy	14400.00
0005435616330	10902	Economy	14400.00
0005435616251	10902	Economy	14400.00
0005434344973	10902	Economy	14400.00
0005435615575	10902	Economy	14400.00
0005435616030	10902	Economy	14400.00
0005435426764	10902	Economy	14400.00
0005434245824	10902	Economy	14400.00
0005435426783	10902	Economy	14400.00
0005434245822	10902	Economy	14400.00
0005435426779	10902	Economy	14400.00
0005435426773	10902	Economy	14400.00
0005435426777	10902	Economy	14400.00
0005432166992	10902	Economy	14400.00
0005435615539	10902	Economy	14400.00
0005434573669	10902	Economy	14400.00
0005435615885	10902	Economy	14400.00
0005435426770	10902	Economy	14400.00
0005435616097	10902	Economy	14400.00
0005435616309	10902	Economy	14400.00
0005435616237	10902	Economy	14400.00
0005435615671	10902	Economy	14400.00
0005435617184	10902	Economy	14400.00
0005435616155	10902	Economy	14400.00
0005435097387	10902	Economy	14400.00
0005435654514	10902	Economy	14400.00
0005435616230	10902	Economy	14400.00
0005435426766	10902	Economy	14400.00
0005435616252	10902	Economy	14400.00
0005435097413	10902	Economy	14400.00
0005434573663	10902	Economy	14400.00
0005435426763	10902	Economy	14400.00
0005435616221	10902	Economy	14400.00
0005435097409	10902	Economy	14400.00
0005435380439	10902	Economy	14400.00
0005434573624	10902	Economy	14400.00
0005434344923	10902	Economy	14400.00
0005435615854	10902	Economy	14400.00
0005435426771	10902	Economy	14400.00
0005434573643	10902	Economy	14400.00
0005435615981	10902	Economy	14400.00
0005435616010	10902	Economy	14400.00
0005435426785	10902	Economy	14400.00
0005435616046	10902	Economy	14400.00
0005434573629	10902	Economy	14400.00
0005434344915	10902	Economy	14400.00
0005435615698	10902	Economy	14400.00
0005435426769	10902	Economy	14400.00
0005434573592	10902	Economy	14400.00
0005435097365	10902	Economy	14400.00
0005434344840	10902	Economy	14400.00
0005435380433	10902	Economy	14400.00
0005435490292	10902	Economy	14400.00
0005434245823	10902	Economy	14400.00
0005435615865	10902	Economy	14400.00
0005432461158	3338	Business	18800.00
0005432460955	3338	Business	18800.00
0005433634800	3338	Business	18800.00
0005433507702	3338	Business	18800.00
0005433634796	3338	Business	18800.00
0005432460946	3338	Business	18800.00
0005432460983	3338	Business	18800.00
0005433634806	3338	Business	18800.00
0005433634801	3338	Business	18800.00
0005434265915	3338	Business	18800.00
0005434143824	3338	Business	18800.00
0005433634803	3338	Business	18800.00
0005434150177	3338	Business	18800.00
0005434265925	3338	Business	18800.00
0005432460900	3338	Business	18800.00
0005434150150	3338	Business	18800.00
0005433507707	3338	Business	18800.00
0005434182549	3338	Business	18800.00
0005434143818	3338	Business	18800.00
0005433806384	3338	Business	18800.00
0005432182353	3338	Business	18800.00
0005432460704	3338	Business	18800.00
0005434143831	3338	Business	18800.00
0005432182350	3338	Business	18800.00
0005434150180	3338	Business	18800.00
0005434150179	3338	Economy	6900.00
0005432461103	3338	Economy	6900.00
0005433806382	3338	Economy	6900.00
0005432461163	3338	Economy	6900.00
0005433634798	3338	Economy	6900.00
0005434150161	3338	Economy	6900.00
0005434265923	3338	Economy	6300.00
0005434150151	3338	Economy	6300.00
0005432460798	3338	Economy	6300.00
0005434150176	3338	Economy	6300.00
0005433507704	3338	Economy	6300.00
0005433806376	3338	Economy	6300.00
0005434143823	3338	Economy	6300.00
0005433507709	3338	Economy	6300.00
0005434150158	3338	Economy	6300.00
0005434143830	3338	Economy	6300.00
0005434143834	3338	Economy	6300.00
0005434150156	3338	Economy	6300.00
0005434150169	3338	Economy	6300.00
0005434143828	3338	Economy	6300.00
0005432460887	3338	Economy	6300.00
0005434265916	3338	Economy	6300.00
0005434265924	3338	Economy	6300.00
0005434150175	3338	Economy	6300.00
0005434150157	3338	Economy	6300.00
0005432461117	3338	Economy	6300.00
0005434150165	3338	Economy	6300.00
0005432460952	3338	Economy	6300.00
0005432460705	3338	Economy	6300.00
0005434143822	3338	Economy	6300.00
0005434265932	3338	Economy	6300.00
0005434143821	3338	Economy	6300.00
0005434150178	3338	Economy	6300.00
0005432460731	3338	Economy	6300.00
0005432460953	3338	Economy	6300.00
0005432182351	3338	Economy	6300.00
0005434265928	3338	Economy	6300.00
0005433507711	3338	Economy	6300.00
0005434150171	3338	Economy	6300.00
0005432460940	3338	Economy	6300.00
0005433507710	3338	Economy	6300.00
0005433634807	3338	Economy	6300.00
0005434265914	3338	Economy	6300.00
0005433634804	3338	Economy	6300.00
0005432460836	3338	Economy	6300.00
0005434265917	3338	Economy	6300.00
0005434150166	3338	Economy	6300.00
0005432460970	3338	Economy	6300.00
0005433634797	3338	Economy	6300.00
0005434150182	3338	Economy	6300.00
0005433634810	3338	Economy	6300.00
0005434150163	3338	Economy	6300.00
0005433634802	3338	Economy	6300.00
0005433634809	3338	Economy	6300.00
0005434265927	3338	Economy	6300.00
0005433507703	3338	Economy	6300.00
0005432460623	3338	Economy	6300.00
0005433634794	3338	Economy	6300.00
0005432182355	3338	Economy	6300.00
0005434265930	3338	Economy	6300.00
0005432460741	3338	Economy	6300.00
0005434150172	3338	Economy	6900.00
0005432460693	3338	Economy	6900.00
0005434143825	3338	Economy	6900.00
0005434182550	3338	Economy	6900.00
0005434150167	3338	Economy	6900.00
0005434150152	3338	Economy	6300.00
0005434150183	3338	Economy	6300.00
0005432460963	3338	Economy	6300.00
0005433634799	3338	Economy	6300.00
0005432460927	3338	Economy	6900.00
0005434143826	3338	Economy	6300.00
0005434265926	3338	Economy	6300.00
0005432461118	3338	Economy	6300.00
0005434143833	3338	Economy	6300.00
0005434265921	3338	Economy	6300.00
0005434265919	3338	Economy	6300.00
0005432460888	3338	Economy	6300.00
0005432460889	3338	Economy	6300.00
0005433806378	3338	Economy	6300.00
0005434143827	3338	Economy	6300.00
0005432460947	3338	Economy	6300.00
0005434150164	3338	Economy	6300.00
0005433634808	3338	Economy	6300.00
0005434143836	3338	Economy	6300.00
0005433507712	3338	Economy	6300.00
0005432460898	3338	Economy	6300.00
0005433507705	3338	Economy	6300.00
0005434150173	3338	Economy	6300.00
0005434150159	3338	Economy	6300.00
0005434150155	3338	Economy	6300.00
0005433507706	3338	Economy	6300.00
0005433634811	3338	Economy	6300.00
0005433507708	3338	Economy	6300.00
0005434265922	3338	Economy	6300.00
0005434265920	3338	Economy	6300.00
0005432182356	3338	Economy	6300.00
0005434265929	3338	Economy	6300.00
0005433806377	3338	Economy	6300.00
0005434150181	3338	Economy	6300.00
0005432460730	3338	Economy	6300.00
0005432182354	3338	Economy	6300.00
0005434265931	3338	Economy	6300.00
0005434143819	3338	Economy	6300.00
0005433806374	3338	Economy	6300.00
0005432460799	3338	Economy	6300.00
0005433806375	3338	Economy	6300.00
0005434150174	3338	Economy	6300.00
0005432182349	3338	Economy	6300.00
0005434265918	3338	Economy	6300.00
0005432182352	3338	Economy	6300.00
0005433634795	3338	Economy	6300.00
0005432460835	3338	Economy	6300.00
0005432461164	3338	Economy	6300.00
0005434150162	3338	Economy	6300.00
0005434143820	3338	Economy	6300.00
0005434230045	3338	Economy	6300.00
0005434150154	3338	Economy	6300.00
0005434150153	3338	Economy	6300.00
0005434150170	3338	Economy	6300.00
0005433806381	3338	Economy	6300.00
0005433806383	3338	Economy	6300.00
0005434143835	3338	Economy	6300.00
0005434150168	3338	Economy	6300.00
0005434143829	3338	Economy	6300.00
0005433634805	3338	Economy	6300.00
0005432460939	3338	Economy	6300.00
0005433806380	3338	Economy	6300.00
0005434150160	3338	Economy	6300.00
0005434230044	3338	Economy	6300.00
0005434143832	3338	Economy	6300.00
0005433806379	3338	Economy	6300.00
0005435886098	3339	Business	18800.00
0005435886296	3339	Business	18800.00
0005435886083	3339	Business	18800.00
0005435886410	3339	Business	18800.00
0005435886434	3339	Business	18800.00
0005435886405	3339	Business	18800.00
0005435886404	3339	Business	18800.00
0005435886248	3339	Business	18800.00
0005435886172	3339	Business	18800.00
0005435886099	3339	Economy	6900.00
0005435886299	3339	Economy	6900.00
0005435886230	3339	Economy	6900.00
0005435886340	3339	Economy	6300.00
0005435886183	3339	Economy	6300.00
0005435886366	3339	Economy	6300.00
0005435886351	3339	Economy	6300.00
0005435886333	3339	Economy	6300.00
0005435886359	3339	Economy	6300.00
0005435886286	3339	Economy	6300.00
0005435886352	3339	Economy	6300.00
0005435886145	3339	Economy	6300.00
0005435886358	3339	Economy	6300.00
0005435886482	3339	Economy	6300.00
0005435886261	3339	Economy	6300.00
0005435886394	3339	Economy	6300.00
0005435886061	3339	Economy	6300.00
0005435886418	3339	Economy	6300.00
0005435886420	3339	Economy	6300.00
0005435886585	3339	Economy	6300.00
0005435886478	3339	Economy	6300.00
0005435886403	3339	Economy	6300.00
0005435886131	3339	Economy	6300.00
0005435886386	3339	Economy	6300.00
0005435886177	3339	Economy	6300.00
0005435886295	3339	Economy	6300.00
0005435886237	3339	Economy	6900.00
0005435886143	3339	Economy	6300.00
0005435886368	3339	Economy	6300.00
0005435886365	3339	Economy	6300.00
0005435886097	3339	Economy	6300.00
0005435886322	3339	Economy	6300.00
0005435886481	3339	Economy	6300.00
0005435886586	3339	Economy	6300.00
0005435886197	3339	Economy	6300.00
0005435886171	3339	Economy	6300.00
0005435886146	3339	Economy	6300.00
0005435886755	8252	Business	18800.00
0005435886737	8252	Business	18800.00
0005435939978	8252	Business	18800.00
0005435886778	8252	Business	18800.00
0005432461383	8252	Business	18800.00
0005433507460	8252	Business	18800.00
0005433507549	8252	Business	18800.00
0005435886735	8252	Business	18800.00
0005435886761	8252	Business	18800.00
0005435886793	8252	Business	18800.00
0005434312398	8252	Business	18800.00
0005435886758	8252	Business	18800.00
0005435933556	8252	Business	18800.00
0005435886763	8252	Business	18800.00
0005433507411	8252	Business	18800.00
0005435886756	8252	Business	18800.00
0005432461389	8252	Business	18800.00
0005435886754	8252	Business	18800.00
0005432461381	8252	Business	18800.00
0005435886741	8252	Business	18800.00
0005435886744	8252	Business	18800.00
0005432043120	8252	Business	18800.00
0005435886764	8252	Business	18800.00
0005435886748	8252	Business	18800.00
0005432461387	8252	Business	18800.00
0005435886759	8252	Economy	6900.00
0005435886749	8252	Economy	6900.00
0005435933557	8252	Economy	6900.00
0005435886747	8252	Economy	6300.00
0005435903222	8252	Economy	6300.00
0005432461375	8252	Economy	6300.00
0005435886780	8252	Economy	6300.00
0005432461373	8252	Economy	6300.00
0005432043113	8252	Economy	6300.00
0005432461376	8252	Economy	6300.00
0005433507542	8252	Economy	6300.00
0005432461391	8252	Economy	6300.00
0005432461367	8252	Economy	6300.00
0005435886770	8252	Economy	6300.00
0005432461378	8252	Economy	6300.00
0005435886762	8252	Economy	6300.00
0005435886791	8252	Economy	6300.00
0005432461368	8252	Economy	6300.00
0005433507459	8252	Economy	6300.00
0005435886743	8252	Economy	6300.00
0005432043117	8252	Economy	6300.00
0005435886746	8252	Economy	6300.00
0005433507583	8252	Economy	6300.00
0005435886795	8252	Economy	6300.00
0005435886784	8252	Economy	6300.00
0005432043114	8252	Economy	6300.00
0005432461382	8252	Economy	6300.00
0005435886790	8252	Economy	6300.00
0005434326297	8252	Economy	6300.00
0005434312384	8252	Economy	6300.00
0005434326298	8252	Economy	6300.00
0005435886783	8252	Economy	6300.00
0005435886742	8252	Economy	6300.00
0005432461372	8252	Economy	6300.00
0005435886794	8252	Economy	6300.00
0005433507619	8252	Economy	6300.00
0005433507573	8252	Economy	6300.00
0005432043111	8252	Economy	6300.00
0005435886750	8252	Economy	6300.00
0005433507541	8252	Economy	6300.00
0005435886768	8252	Economy	6300.00
0005435886753	8252	Economy	6300.00
0005435886774	8252	Economy	6300.00
0005432043121	8252	Economy	6300.00
0005435886789	8252	Economy	6300.00
0005432461369	8252	Economy	6300.00
0005432461377	8252	Economy	6300.00
0005432461374	8252	Economy	6300.00
0005433507544	8252	Economy	6300.00
0005432461370	8252	Economy	6300.00
0005435886773	8252	Economy	6900.00
0005432043119	8252	Economy	6300.00
0005432461392	8252	Economy	6900.00
0005432043116	8252	Economy	6300.00
0005433507559	8252	Economy	6300.00
0005434312381	8252	Economy	6300.00
0005432461385	8252	Economy	6300.00
0005435886777	8252	Economy	6300.00
0005432461362	8252	Economy	6300.00
0005435886752	8252	Economy	6300.00
0005432461390	8252	Economy	6300.00
0005434326299	8252	Economy	6300.00
0005432461384	8252	Economy	6300.00
0005432043124	8252	Economy	6300.00
0005432043122	8252	Economy	6300.00
0005435886739	8252	Economy	6300.00
0005432461386	8252	Economy	6300.00
0005435886771	8252	Economy	6300.00
0005435886779	8252	Economy	6300.00
0005432461388	8252	Economy	6300.00
0005435886751	8252	Economy	6300.00
0005432461366	8252	Economy	6300.00
0005435886786	8252	Economy	6300.00
0005432461365	8252	Economy	6300.00
0005432461364	8252	Economy	6300.00
0005432461363	8252	Economy	6300.00
0005435933562	8252	Economy	6300.00
0005435886760	8252	Economy	6300.00
0005432043112	8252	Economy	6300.00
0005432461371	8252	Economy	6300.00
0005432043118	8252	Economy	6300.00
0005434312397	8252	Economy	6300.00
0005433507543	8252	Economy	6300.00
0005435886785	8252	Economy	6300.00
0005435886738	8252	Economy	6300.00
0005435886772	8252	Economy	6300.00
0005435886766	8252	Economy	6300.00
0005432043123	8252	Economy	6300.00
0005435886776	8252	Economy	6300.00
0005435886736	8252	Economy	6300.00
0005435886769	8252	Economy	6300.00
0005435886767	8252	Economy	6300.00
0005435886792	8252	Economy	6300.00
0005435886740	8252	Economy	6300.00
0005434312383	8252	Economy	6300.00
0005435886757	8252	Economy	6300.00
0005432461379	8252	Economy	6300.00
0005435903223	8252	Economy	6300.00
0005435886745	8252	Economy	6300.00
0005435886775	8252	Economy	6300.00
0005432461361	8252	Economy	6300.00
0005435886781	8252	Economy	6300.00
0005435886765	8252	Economy	6300.00
0005434312382	8252	Economy	6300.00
0005435903224	8252	Economy	6300.00
0005435886788	8252	Economy	6300.00
0005433507636	8252	Economy	6300.00
0005435933563	8252	Economy	6300.00
0005435933561	8252	Economy	6300.00
0005435886787	8252	Economy	6300.00
0005432043115	8252	Economy	6300.00
0005432461380	8252	Economy	6300.00
0005435939977	8252	Economy	6300.00
0005435886782	8252	Economy	6300.00
0005433805980	8256	Business	18800.00
0005433634504	8256	Business	18800.00
0005435858725	8256	Business	18800.00
0005435860711	8256	Business	18800.00
0005433806020	8256	Business	18800.00
0005433634415	8256	Business	18800.00
0005433806152	8256	Business	18800.00
0005435858728	8256	Business	18800.00
0005433634335	8256	Business	18800.00
0005433634534	8256	Business	18800.00
0005434143751	8256	Business	18800.00
0005433806084	8256	Business	18800.00
0005433806019	8256	Business	18800.00
0005433634368	8256	Business	18800.00
0005433634532	8256	Economy	6900.00
0005433634559	8256	Economy	6900.00
0005435858721	8256	Economy	6900.00
0005433806100	8256	Economy	6900.00
0005433806160	8256	Economy	6900.00
0005435860703	8256	Economy	6300.00
0005435858729	8256	Economy	6300.00
0005433634468	8256	Economy	6300.00
0005433634531	8256	Economy	6300.00
0005435860704	8256	Economy	6300.00
0005435858726	8256	Economy	6300.00
0005433634492	8256	Economy	6300.00
0005433634442	8256	Economy	6300.00
0005433634358	8256	Economy	6300.00
0005433634454	8256	Economy	6300.00
0005435860708	8256	Economy	6300.00
0005433805911	8256	Economy	6300.00
0005433634416	8256	Economy	6300.00
0005433806144	8256	Economy	6300.00
0005433634357	8256	Economy	6300.00
0005433806021	8256	Economy	6300.00
0005433805999	8256	Economy	6300.00
0005435858719	8256	Economy	6300.00
0005433805965	8256	Economy	6300.00
0005435858724	8256	Economy	6300.00
0005433634515	8256	Economy	6300.00
0005433806241	8256	Economy	6300.00
0005433634483	8256	Economy	6300.00
0005433634494	8256	Economy	6300.00
0005433806004	8256	Economy	6300.00
0005433806012	8256	Economy	6300.00
0005433634369	8256	Economy	6300.00
0005433634441	8256	Economy	6300.00
0005433634533	8256	Economy	6300.00
0005433805910	8256	Economy	6300.00
0005433806022	8256	Economy	6300.00
0005433634530	8256	Economy	6300.00
0005433634493	8256	Economy	6300.00
0005433634538	8256	Economy	6300.00
0005433806057	8256	Economy	6300.00
0005433806085	8256	Economy	6300.00
0005434271355	8256	Economy	6900.00
0005433806148	8256	Economy	6900.00
0005433634475	8256	Economy	6300.00
0005435860712	8256	Economy	6300.00
0005435860705	8256	Economy	6300.00
0005433634487	8256	Economy	6300.00
0005433634485	8256	Economy	6300.00
0005433634509	8256	Economy	6300.00
0005435860710	8256	Economy	6300.00
0005435860706	8256	Economy	6300.00
0005435860713	8256	Economy	6300.00
0005433806051	8256	Economy	6300.00
0005433806005	8256	Economy	6300.00
0005435858722	8256	Economy	6300.00
0005435860707	8256	Economy	6300.00
0005435858720	8256	Economy	6300.00
0005433806050	8256	Economy	6300.00
0005435858727	8256	Economy	6300.00
0005435858717	8256	Economy	6300.00
0005433634503	8256	Economy	6300.00
0005433634619	8256	Economy	6300.00
0005435858718	8256	Economy	6300.00
0005435858716	8256	Economy	6300.00
0005435858723	8256	Economy	6300.00
0005433634453	8256	Economy	6300.00
0005433806166	8256	Economy	6300.00
0005434271356	8256	Economy	6300.00
0005433806083	8256	Economy	6300.00
0005433634391	8256	Economy	6300.00
0005433806138	8256	Economy	6300.00
0005433806023	8256	Economy	6300.00
0005435860709	8256	Economy	6300.00
0005433634558	8256	Economy	6300.00
0005434183624	8266	Economy	6300.00
0005434183622	8266	Economy	6300.00
0005434183619	8266	Economy	6300.00
0005434183623	8266	Economy	6300.00
0005434183618	8266	Economy	6300.00
0005432384294	4537	Business	9900.00
0005432728295	4537	Business	9900.00
0005432384303	4537	Business	9900.00
0005433454933	4537	Business	9900.00
0005432384310	4537	Business	9900.00
0005433722477	4537	Business	9900.00
0005433194983	4537	Business	9900.00
0005434300242	4537	Business	9900.00
0005433722483	4537	Economy	3300.00
0005432384313	4537	Economy	3300.00
0005433722474	4537	Economy	3300.00
0005434300247	4537	Economy	3300.00
0005433722480	4537	Economy	3300.00
0005433194981	4537	Economy	3600.00
0005432384302	4537	Economy	3600.00
0005434300239	4537	Economy	3600.00
0005432384308	4537	Economy	3300.00
0005433722478	4537	Economy	3300.00
0005433722481	4537	Economy	3300.00
0005432384304	4537	Economy	3300.00
0005433194977	4537	Economy	3300.00
0005432384309	4537	Economy	3300.00
0005434300249	4537	Economy	3300.00
0005432384298	4537	Economy	3300.00
0005433194987	4537	Economy	3300.00
0005432728293	4537	Economy	3300.00
0005432384300	4537	Economy	3300.00
0005432384297	4537	Economy	3300.00
0005432728296	4537	Economy	3300.00
0005434300245	4537	Economy	3300.00
0005432728294	4537	Economy	3300.00
0005432384293	4537	Economy	3300.00
0005433194976	4537	Economy	3300.00
0005432384306	4537	Economy	3300.00
0005434300243	4537	Economy	3300.00
0005432384295	4537	Economy	3300.00
0005433194989	4537	Economy	3300.00
0005434300241	4537	Economy	3300.00
0005433194988	4537	Economy	3300.00
0005434300244	4537	Economy	3300.00
0005434300248	4537	Economy	3300.00
0005433194985	4537	Economy	3300.00
0005432384296	4537	Economy	3300.00
0005434300246	4537	Economy	3300.00
0005432728297	4537	Economy	3300.00
0005432728292	4537	Economy	3300.00
0005433722482	4537	Economy	3300.00
0005433194980	4537	Economy	3300.00
0005432384307	4537	Economy	3300.00
0005433194990	4537	Economy	3300.00
0005433194979	4537	Economy	3300.00
0005432384311	4537	Economy	3300.00
0005433194986	4537	Economy	3300.00
0005433722488	4537	Economy	3300.00
0005433722484	4537	Economy	3300.00
0005433722479	4537	Economy	3300.00
0005432384305	4537	Economy	3300.00
0005434300250	4537	Economy	3300.00
0005432384301	4537	Economy	3300.00
0005433194984	4537	Economy	3300.00
0005433722475	4537	Economy	3300.00
0005434300240	4537	Economy	3300.00
0005433194982	4537	Economy	3300.00
0005433722485	4537	Economy	3300.00
0005432384299	4537	Economy	3300.00
0005433722486	4537	Economy	3300.00
0005433194978	4537	Economy	3300.00
0005432384312	4537	Economy	3300.00
0005433722476	4537	Economy	3300.00
0005433722487	4537	Economy	3300.00
0005432384039	30148	Business	9900.00
0005433194914	30148	Business	9900.00
0005432383662	30148	Business	9900.00
0005432383821	30148	Business	9900.00
0005432383795	30148	Business	9900.00
0005432383863	30148	Business	9900.00
0005432383843	30148	Business	9900.00
0005432728199	30148	Business	9900.00
0005432383856	30148	Business	9900.00
0005433453806	30148	Business	9900.00
0005432383861	30148	Economy	3300.00
0005432728183	30148	Economy	3300.00
0005432383792	30148	Economy	3300.00
0005432383900	30148	Economy	3300.00
0005432728210	30148	Economy	3300.00
0005432384040	30148	Economy	3300.00
0005432728212	30148	Economy	3300.00
0005432728184	30148	Economy	3300.00
0005432383874	30148	Economy	3600.00
0005432383879	30148	Economy	3600.00
0005432383940	30148	Economy	3600.00
0005432383860	30148	Economy	3300.00
0005432728211	30148	Economy	3300.00
0005432383904	30148	Economy	3300.00
0005432383872	30148	Economy	3300.00
0005432383864	30148	Economy	3300.00
0005432383939	30148	Economy	3300.00
0005432383880	30148	Economy	3300.00
0005433451660	30148	Economy	3300.00
0005432384028	30148	Economy	3300.00
0005433451659	30148	Economy	3300.00
0005432728176	30148	Economy	3300.00
0005432384024	30148	Economy	3300.00
0005432384023	30148	Economy	3300.00
0005432728203	30148	Economy	3300.00
0005432383867	30148	Economy	3300.00
0005432383970	30148	Economy	3300.00
0005433453797	30148	Economy	3300.00
0005432383873	30148	Economy	3300.00
0005432384056	30148	Economy	3300.00
0005432383844	30148	Economy	3300.00
0005432728175	30148	Economy	3300.00
0005432383661	30148	Economy	3300.00
0005432728177	30148	Economy	3300.00
0005432383663	30148	Economy	3300.00
0005432383908	30148	Economy	3300.00
0005432383948	30148	Economy	3300.00
0005432383885	30148	Economy	3300.00
0005432383850	30148	Economy	3300.00
0005432383950	30148	Economy	3300.00
0005432383851	30148	Economy	3300.00
0005432383857	30148	Economy	3300.00
0005432728204	30148	Economy	3300.00
0005432383871	30148	Economy	3300.00
0005432383911	30148	Economy	3300.00
0005432383949	30148	Economy	3300.00
0005432728207	30148	Economy	3300.00
0005432383905	30148	Economy	3300.00
0005432383912	30148	Economy	3300.00
0005432383922	30148	Economy	3300.00
0005433453805	30148	Economy	3300.00
0005432383685	30148	Economy	3300.00
0005432383981	30148	Economy	3300.00
0005432383907	30148	Economy	3300.00
0005432383980	30148	Economy	3300.00
0005432384022	30148	Economy	3300.00
0005435530179	1744	Business	57200.00
0005432925154	1744	Business	57200.00
0005435529881	1744	Business	57200.00
0005432925127	1744	Business	57200.00
0005435541635	1744	Economy	19100.00
0005432925150	1744	Economy	19100.00
0005435529878	1744	Economy	19100.00
0005435530181	1744	Economy	19100.00
0005435541626	1744	Economy	19100.00
0005435529880	1744	Economy	19100.00
0005435530173	1744	Economy	19100.00
0005435541630	1744	Economy	21000.00
0005435529883	1744	Economy	21000.00
0005435541629	1744	Economy	21000.00
0005435530175	1744	Economy	19100.00
0005435530180	1744	Economy	19100.00
0005433517158	1744	Economy	19100.00
0005435529882	1744	Economy	19100.00
0005435530183	1744	Economy	19100.00
0005433517157	1744	Economy	19100.00
0005435530177	1744	Economy	19100.00
0005435529876	1744	Economy	19100.00
0005435541632	1744	Economy	19100.00
0005432294558	1744	Economy	19100.00
0005435541633	1744	Economy	19100.00
0005435529879	1744	Economy	19100.00
0005435529877	1744	Economy	19100.00
0005435541634	1744	Economy	19100.00
0005432294557	1744	Economy	19100.00
0005433517156	1744	Economy	19100.00
0005435541624	1744	Economy	19100.00
0005432925135	1744	Economy	19100.00
0005435541628	1744	Economy	19100.00
0005435541627	1744	Economy	19100.00
0005435530178	1744	Economy	19100.00
0005435541623	1744	Economy	19100.00
0005435541625	1744	Economy	19100.00
0005432925134	1744	Economy	19100.00
0005435530182	1744	Economy	19100.00
0005435541622	1744	Economy	19100.00
0005433517159	1744	Economy	19100.00
0005435530176	1744	Economy	19100.00
0005435530174	1744	Economy	19100.00
0005435541631	1744	Economy	19100.00
0005432294556	1744	Economy	19100.00
0005435541467	21989	Business	57200.00
0005433517120	21989	Business	57200.00
0005435541452	21989	Business	57200.00
0005435541446	21989	Business	57200.00
0005435518262	21989	Economy	19100.00
0005435518259	21989	Economy	19100.00
0005435518299	21989	Economy	19100.00
0005435518181	21989	Economy	19100.00
0005435541342	21989	Economy	19100.00
0005435541436	21989	Economy	21000.00
0005435541466	21989	Economy	19100.00
0005433517112	21989	Economy	19100.00
0005433517096	21989	Economy	19100.00
0005435541380	21989	Economy	19100.00
0005435541431	21989	Economy	19100.00
0005435541439	21989	Economy	19100.00
0005433517070	21989	Economy	19100.00
0005435518304	21989	Economy	19100.00
0005435541437	21989	Economy	19100.00
0005433517089	21989	Economy	19100.00
0005435541451	21989	Economy	19100.00
0005435518294	21989	Economy	19100.00
0005435541390	21989	Economy	19100.00
0005435518266	21989	Economy	19100.00
0005433517048	21989	Economy	19100.00
0005433517071	21989	Economy	19100.00
0005435518357	21989	Economy	19100.00
0005435518305	21989	Economy	19100.00
0005435518225	21989	Economy	19100.00
0005435541406	21989	Economy	19100.00
0005435518261	21989	Economy	19100.00
0005435541414	21989	Economy	19100.00
0005435518267	21989	Economy	19100.00
0005435541381	21989	Economy	19100.00
0005435518325	21989	Economy	19100.00
0005435518249	21989	Economy	19100.00
0005435518258	21989	Economy	19100.00
0005435541417	21989	Economy	19100.00
0005435541407	21989	Economy	19100.00
0005435518228	21989	Economy	19100.00
0005435541468	21989	Economy	19100.00
0005435518346	21989	Economy	19100.00
0005435518324	21989	Economy	19100.00
0005435518312	21989	Economy	19100.00
0005433517088	21989	Economy	19100.00
0005435253128	7403	Business	18500.00
0005434459400	7403	Business	18500.00
0005434459402	7403	Business	18500.00
0005432839915	7403	Business	18500.00
0005435253056	7403	Economy	6200.00
0005432839914	7403	Economy	6200.00
0005435253070	7403	Economy	6200.00
0005432839921	7403	Economy	6200.00
0005435491484	7403	Economy	6800.00
0005435252969	7403	Economy	6800.00
0005432839908	7403	Economy	6800.00
0005432073493	7403	Economy	6800.00
0005435491489	7403	Economy	6200.00
0005432839922	7403	Economy	6200.00
0005435253065	7403	Economy	6200.00
0005434459398	7403	Economy	6200.00
0005432839912	7403	Economy	6200.00
0005432839918	7403	Economy	6200.00
0005432839916	7403	Economy	6200.00
0005435253095	7403	Economy	6200.00
0005435253092	7403	Economy	6200.00
0005435253093	7403	Economy	6200.00
0005432073492	7403	Economy	6200.00
0005432839913	7403	Economy	6200.00
0005432839910	7403	Economy	6200.00
0005434459399	7403	Economy	6200.00
0005434459401	7403	Economy	6200.00
0005432839917	7403	Economy	6200.00
0005432839920	7403	Economy	6200.00
0005432839919	7403	Economy	6200.00
0005434665000	7403	Economy	6200.00
0005435491483	7403	Economy	6200.00
0005432839911	7403	Economy	6200.00
0005432839909	7403	Economy	6200.00
0005435253127	7403	Economy	6200.00
0005435491485	7403	Economy	6200.00
0005434459403	7403	Economy	6200.00
0005434664999	7403	Economy	6200.00
0005435253099	7403	Economy	6200.00
0005432839907	7403	Economy	6200.00
0005435253131	7403	Economy	6200.00
0005432839633	28896	Business	18500.00
0005435491506	28896	Business	18500.00
0005435491505	28896	Business	18500.00
0005432839778	28896	Business	18500.00
0005432841065	28896	Business	18500.00
0005434459206	28896	Business	18500.00
0005434459234	28896	Business	18500.00
0005432839505	28896	Business	18500.00
0005432839823	28896	Business	18500.00
0005432839752	28896	Business	18500.00
0005434459128	28896	Business	18500.00
0005432839658	28896	Economy	6200.00
0005435253213	28896	Economy	6200.00
0005434459209	28896	Economy	6200.00
0005432839712	28896	Economy	6200.00
0005434459264	28896	Economy	6200.00
0005434459220	28896	Economy	6200.00
0005435253210	28896	Economy	6200.00
0005434459229	28896	Economy	6800.00
0005432839727	28896	Economy	6800.00
0005432839504	28896	Economy	6800.00
0005434459205	28896	Economy	6200.00
0005432839861	28896	Economy	6200.00
0005432839862	28896	Economy	6200.00
0005434459266	28896	Economy	6200.00
0005432839640	28896	Economy	6200.00
0005434459283	28896	Economy	6200.00
0005432839779	28896	Economy	6200.00
0005435253205	28896	Economy	6200.00
0005435253214	28896	Economy	6200.00
0005432839807	28896	Economy	6200.00
0005434459214	28896	Economy	6200.00
0005435253211	28896	Economy	6200.00
0005432839699	28896	Economy	6200.00
0005432839637	28896	Economy	6200.00
0005432839663	28896	Economy	6200.00
0005432839825	28896	Economy	6200.00
0005432839860	28896	Economy	6200.00
0005435253212	28896	Economy	6200.00
0005432839664	28896	Economy	6200.00
0005432839824	28896	Economy	6200.00
0005432001080	28896	Economy	6200.00
0005434459278	28896	Economy	6200.00
0005432839722	28896	Economy	6200.00
0005434459292	28896	Economy	6200.00
0005434459267	28896	Economy	6200.00
0005434459251	28896	Economy	6200.00
0005434459178	28896	Economy	6200.00
0005432839705	28896	Economy	6200.00
0005434459307	28896	Economy	6200.00
0005434459129	28896	Economy	6200.00
0005434459215	28896	Economy	6200.00
0005432839737	28896	Economy	6200.00
0005432839777	28896	Economy	6200.00
0005435253208	28896	Economy	6200.00
0005432841064	28896	Economy	6200.00
0005435253206	28896	Economy	6200.00
0005432839816	28896	Economy	6200.00
0005432839619	28896	Economy	6200.00
0005434459127	28896	Economy	6200.00
0005434459228	28896	Economy	6200.00
0005435253209	28896	Economy	6200.00
0005434459212	28896	Economy	6200.00
0005432839704	28896	Economy	6200.00
0005435253207	28896	Economy	6200.00
0005434459293	28896	Economy	6200.00
0005434459260	28896	Economy	6200.00
0005434459213	28896	Economy	6200.00
0005434459242	28896	Economy	6200.00
0005434459190	28896	Economy	6200.00
0005434459265	28896	Economy	6200.00
0005432839811	28896	Economy	6200.00
0005434459277	28896	Economy	6200.00
0005432839810	28896	Economy	6200.00
0005434459191	28896	Economy	6200.00
0005432839742	28896	Economy	6200.00
0005435990828	8790	Business	145300.00
0005435990830	8790	Business	145300.00
0005435990831	8790	Business	145300.00
0005435990826	8790	Business	145300.00
0005435990827	8790	Business	145300.00
0005435990832	8790	Economy	48400.00
0005434276154	8790	Economy	48400.00
0005435990829	8790	Economy	48400.00
0005434276155	8790	Economy	48400.00
0005434276148	8790	Economy	48400.00
0005434276147	8790	Economy	48400.00
0005434276160	8790	Economy	48400.00
0005435990790	15749	Business	145300.00
0005435990783	15749	Business	145300.00
0005434276194	15749	Business	145300.00
0005435990789	15749	Business	145300.00
0005435990750	15749	Economy	48400.00
0005433435513	15749	Economy	48400.00
0005433435512	15749	Economy	48400.00
0005433435510	15749	Economy	48400.00
0005433435511	15749	Economy	48400.00
0005434276193	15749	Economy	48400.00
0005435990764	15749	Economy	48400.00
0005434276195	15749	Economy	48400.00
0005432427192	30851	Economy	15900.00
0005433476953	30851	Economy	15900.00
0005432427180	30851	Economy	15900.00
0005432427194	30851	Economy	15900.00
0005433476952	30851	Economy	14500.00
0005432427190	30851	Economy	14500.00
0005433476951	30851	Economy	14500.00
0005433476950	30851	Economy	14500.00
0005432427179	30851	Economy	14500.00
0005432427188	30851	Economy	14500.00
0005432427191	30851	Economy	14500.00
0005433468527	23829	Economy	13300.00
0005433468513	23829	Economy	13300.00
0005433468505	23829	Economy	12100.00
0005432909436	23829	Economy	12100.00
0005433468500	23829	Economy	12100.00
0005433468561	23829	Economy	12100.00
0005433468514	23829	Economy	12100.00
0005432909435	23829	Economy	12100.00
0005433468504	23829	Economy	12100.00
0005433468463	23829	Economy	12100.00
0005433468521	23829	Economy	12100.00
0005433468506	23829	Economy	12100.00
0005433468494	23829	Economy	12100.00
0005433468489	23829	Economy	12100.00
0005432909432	23829	Economy	12100.00
0005433468512	23829	Economy	12100.00
0005433468490	23829	Economy	12100.00
0005433468522	23829	Economy	12100.00
0005433468523	23829	Economy	12100.00
0005433468493	23829	Economy	12100.00
0005432909434	23829	Economy	12100.00
0005432909433	23829	Economy	12100.00
0005433468520	23829	Economy	12100.00
0005435177744	6395	Business	36600.00
0005435490292	6395	Business	36600.00
0005432361720	6395	Business	36600.00
0005434149987	6395	Business	36600.00
0005432336376	6395	Business	36600.00
0005434149983	6395	Business	36600.00
0005432361721	6395	Business	36600.00
0005435177657	6395	Business	36600.00
0005432363512	6395	Business	36600.00
0005435723084	6395	Business	36600.00
0005435177616	6395	Business	36600.00
0005432361718	6395	Economy	12200.00
0005432361729	6395	Economy	12200.00
0005432361722	6395	Economy	12200.00
0005435177790	6395	Economy	12200.00
0005434150020	6395	Economy	12200.00
0005432336381	6395	Economy	12200.00
0005432361726	6395	Economy	12200.00
0005432361734	6395	Economy	12200.00
0005434150044	6395	Economy	12200.00
0005434149980	6395	Economy	12200.00
0005432361724	6395	Economy	12200.00
0005434149953	6395	Economy	12200.00
0005432062385	6395	Economy	12200.00
0005434149970	6395	Economy	12200.00
0005434149954	6395	Economy	12200.00
0005432361727	6395	Economy	12200.00
0005435177705	6395	Economy	12200.00
0005434149977	6395	Economy	12200.00
0005435177640	6395	Economy	12200.00
0005434149976	6395	Economy	12200.00
0005434149988	6395	Economy	12200.00
0005435177746	6395	Economy	12200.00
0005432363513	6395	Economy	12200.00
0005435723087	6395	Economy	13400.00
0005435177647	6395	Economy	13400.00
0005435177745	6395	Economy	12200.00
0005435177615	6395	Economy	12200.00
0005435723094	6395	Economy	12200.00
0005435177692	6395	Economy	12200.00
0005432361723	6395	Economy	12200.00
0005432361725	6395	Economy	12200.00
0005435723085	6395	Economy	12200.00
0005435177693	6395	Economy	12200.00
0005434149979	6395	Economy	12200.00
0005435723086	6395	Economy	12200.00
0005435177661	6395	Economy	12200.00
0005435177617	6395	Economy	12200.00
0005432336382	6395	Economy	12200.00
0005432361719	6395	Economy	12200.00
0005432336378	6395	Economy	12200.00
0005435177691	6395	Economy	12200.00
0005434150042	6395	Economy	12200.00
0005434149999	6395	Economy	12200.00
0005434150043	6395	Economy	12200.00
0005432361736	6395	Economy	12200.00
0005435177669	6395	Economy	12200.00
0005435490305	6395	Economy	12200.00
0005434150021	6395	Economy	12200.00
0005435490306	6395	Economy	12200.00
0005435177639	6395	Economy	12200.00
0005435177668	6395	Economy	12200.00
0005432361733	6395	Economy	12200.00
0005435177743	6395	Economy	12200.00
0005435177667	6395	Economy	12200.00
0005432363514	6395	Economy	12200.00
0005435177649	6395	Economy	12200.00
0005432361728	6395	Economy	12200.00
0005432336380	6395	Economy	12200.00
0005435490287	6395	Economy	12200.00
0005435177753	6395	Economy	12200.00
0005432361732	6395	Economy	12200.00
0005432062384	6395	Economy	12200.00
0005435177653	6395	Economy	12200.00
0005435490291	6395	Economy	12200.00
0005432361730	6395	Economy	12200.00
0005435177658	6395	Economy	12200.00
0005432336377	6395	Economy	12200.00
0005435177722	6395	Economy	12200.00
0005432361735	6395	Economy	12200.00
0005434149949	6395	Economy	12200.00
0005432361731	6395	Economy	12200.00
0005432336379	6395	Economy	12200.00
0005434150000	6395	Economy	12200.00
0005432336275	21015	Business	36600.00
0005434150071	21015	Business	36600.00
0005432361305	21015	Business	36600.00
0005432361337	21015	Business	36600.00
0005432361370	21015	Business	36600.00
0005432361356	21015	Business	36600.00
0005432361345	21015	Business	36600.00
0005432336266	21015	Business	36600.00
0005432361549	21015	Business	36600.00
0005432361343	21015	Economy	12200.00
0005435177850	21015	Economy	12200.00
0005432361518	21015	Economy	12200.00
0005435490337	21015	Economy	12200.00
0005432336305	21015	Economy	12200.00
0005432361477	21015	Economy	12200.00
0005432336206	21015	Economy	12200.00
0005432361428	21015	Economy	12200.00
0005432361511	21015	Economy	12200.00
0005432361273	21015	Economy	12200.00
0005432336303	21015	Economy	12200.00
0005432361379	21015	Economy	12200.00
0005432336276	21015	Economy	12200.00
0005432361571	21015	Economy	12200.00
0005432363478	21015	Economy	12200.00
0005432361325	21015	Economy	12200.00
0005432361249	21015	Economy	12200.00
0005434150067	21015	Economy	12200.00
0005435177855	21015	Economy	12200.00
0005432361275	21015	Economy	12200.00
0005432361354	21015	Economy	12200.00
0005432361304	21015	Economy	12200.00
0005432361301	21015	Economy	12200.00
0005432361439	21015	Economy	12200.00
0005432361268	21015	Economy	12200.00
0005432361515	21015	Economy	12200.00
0005432361251	21015	Economy	12200.00
0005432361373	21015	Economy	12200.00
0005432363476	21015	Economy	12200.00
0005435490336	21015	Economy	12200.00
0005432361434	21015	Economy	13400.00
0005435490335	21015	Economy	13400.00
0005432361382	21015	Economy	13400.00
0005432336268	21015	Economy	13400.00
0005432361435	21015	Economy	13400.00
0005434150068	21015	Economy	12200.00
0005432361516	21015	Economy	12200.00
0005432363489	21015	Economy	12200.00
0005435177852	21015	Economy	12200.00
0005435177856	21015	Economy	12200.00
0005432361495	21015	Economy	12200.00
0005432361296	21015	Economy	12200.00
0005435177846	21015	Economy	12200.00
0005432361517	21015	Economy	12200.00
0005432361270	21015	Economy	12200.00
0005432361427	21015	Economy	12200.00
0005432361383	21015	Economy	12200.00
0005432361512	21015	Economy	12200.00
0005432361306	21015	Economy	12200.00
0005432361399	21015	Economy	12200.00
0005432336270	21015	Economy	12200.00
0005434150069	21015	Economy	12200.00
0005432361353	21015	Economy	12200.00
0005432361426	21015	Economy	12200.00
0005435177848	21015	Economy	12200.00
0005435177849	21015	Economy	12200.00
0005432361396	21015	Economy	12200.00
0005432336242	21015	Economy	12200.00
0005432336269	21015	Economy	12200.00
0005432361276	21015	Economy	12200.00
0005432363488	21015	Economy	12200.00
0005432361310	21015	Economy	12200.00
0005432361311	21015	Economy	12200.00
0005432336241	21015	Economy	12200.00
0005432361445	21015	Economy	12200.00
0005432361271	21015	Economy	12200.00
0005432361369	21015	Economy	12200.00
0005432361250	21015	Economy	12200.00
0005432363480	21015	Economy	12200.00
0005435177851	21015	Economy	12200.00
0005435177845	21015	Economy	12200.00
0005432361480	21015	Economy	12200.00
0005432336304	21015	Economy	12200.00
0005434150070	21015	Economy	12200.00
0005432361401	21015	Economy	12200.00
0005432361374	21015	Economy	12200.00
0005432361548	21015	Economy	12200.00
0005432336245	21015	Economy	12200.00
0005435177854	21015	Economy	12200.00
0005432361357	21015	Economy	12200.00
0005435177853	21015	Economy	12200.00
0005432361272	21015	Economy	12200.00
0005432361326	21015	Economy	12200.00
0005435177847	21015	Economy	12200.00
0005432361355	21015	Economy	12200.00
0005432361274	21015	Economy	12200.00
0005432361295	21015	Economy	12200.00
0005432361267	21015	Economy	12200.00
0005434459297	17682	Economy	3400.00
0005434459347	17682	Economy	3100.00
0005434459280	17682	Economy	3100.00
0005434461693	17682	Economy	3100.00
0005434448375	17682	Economy	3100.00
0005434459224	17682	Economy	3100.00
0005434459187	17682	Economy	3100.00
0005434459208	17682	Economy	3100.00
0005434459247	17682	Economy	3100.00
0005434459262	17682	Economy	3100.00
0005434459261	17682	Economy	3100.00
0005434448392	17682	Economy	3100.00
0005434459348	17682	Economy	3100.00
0005434461691	17682	Economy	3100.00
0005434461692	17682	Economy	3100.00
0005434448404	17682	Economy	3100.00
0005434448382	17682	Economy	3100.00
0005434459311	17682	Economy	3100.00
0005434461683	17682	Economy	3100.00
0005434459300	17682	Economy	3100.00
0005434459299	17682	Economy	3100.00
0005434459279	17682	Economy	3100.00
0005434459301	17682	Economy	3100.00
0005434186285	17682	Economy	3100.00
0005434459225	17682	Economy	3100.00
0005434448383	17682	Economy	3100.00
0005434461696	17682	Economy	3100.00
0005434459398	29088	Economy	3400.00
0005434459402	29088	Economy	3100.00
0005434186257	29088	Economy	3100.00
0005434186259	29088	Economy	3100.00
0005434462853	29088	Economy	3100.00
0005434459400	29088	Economy	3100.00
0005434459403	29088	Economy	3100.00
0005434459399	29088	Economy	3100.00
0005434186244	29088	Economy	3100.00
0005434462851	29088	Economy	3100.00
0005434448412	29088	Economy	3100.00
0005434186258	29088	Economy	3100.00
0005434462852	29088	Economy	3100.00
0005434186256	29088	Economy	3100.00
0005434459401	29088	Economy	3100.00
0005432661932	21836	Business	185300.00
0005432658623	21836	Business	185300.00
0005432661945	21836	Business	185300.00
0005432665302	21836	Business	185300.00
0005432658616	21836	Economy	61800.00
0005432661942	21836	Economy	61800.00
0005432658609	21836	Economy	61800.00
0005432665304	21836	Economy	61800.00
0005432661953	21836	Economy	67900.00
0005432658617	21836	Economy	67900.00
0005432661944	21836	Economy	61800.00
0005432665286	21836	Economy	61800.00
0005432665301	21836	Economy	61800.00
0005432665288	21836	Economy	61800.00
0005432658612	21836	Economy	61800.00
0005432658614	21836	Economy	61800.00
0005432665294	21836	Economy	61800.00
0005432661950	21836	Economy	61800.00
0005432661933	21836	Economy	61800.00
0005432665287	21836	Economy	61800.00
0005432665297	21836	Economy	61800.00
0005432658626	21836	Economy	61800.00
0005432665293	21836	Economy	61800.00
0005432661931	21836	Economy	61800.00
0005432665296	21836	Economy	61800.00
0005432661952	21836	Economy	61800.00
0005432665313	21836	Economy	61800.00
0005432658627	21836	Economy	61800.00
0005432661951	21836	Economy	61800.00
0005432661946	21836	Economy	61800.00
0005432661930	21836	Economy	61800.00
0005432661929	21836	Economy	61800.00
0005432661943	21836	Economy	61800.00
0005432665295	21836	Economy	61800.00
0005432665300	21836	Economy	61800.00
0005432658613	21836	Economy	61800.00
0005432665305	21836	Economy	61800.00
0005432658628	21836	Economy	61800.00
0005432665303	21836	Economy	61800.00
0005432605441	21418	Economy	7300.00
0005432605452	21418	Economy	7300.00
0005432605449	21418	Economy	6600.00
0005432605442	21418	Economy	6600.00
0005435221549	21418	Economy	6600.00
0005432605443	21418	Economy	6600.00
0005432605462	21418	Economy	6600.00
0005432605461	21418	Economy	6600.00
0005432605445	21418	Economy	6600.00
0005432605448	21418	Economy	6600.00
0005435221550	21418	Economy	6600.00
0005432605460	21418	Economy	6600.00
0005432605454	21418	Economy	6600.00
0005432605440	21418	Economy	6600.00
0005432605457	21418	Economy	6600.00
0005432605458	21418	Economy	6600.00
0005432605459	21418	Economy	6600.00
0005435218128	21418	Economy	6600.00
0005432605447	21418	Economy	6600.00
0005432605439	21418	Economy	6600.00
0005432605444	21418	Economy	6600.00
0005432605435	21418	Economy	6600.00
0005432605456	21418	Economy	6600.00
0005432605437	21418	Economy	6600.00
0005432605453	21418	Economy	6600.00
0005432605455	21418	Economy	6600.00
0005432605446	21418	Economy	6600.00
0005432605438	21418	Economy	6600.00
0005432605436	21418	Economy	6600.00
0005435221548	21418	Economy	6600.00
0005432605451	21418	Economy	6600.00
0005432605450	21418	Economy	6600.00
0005432605118	31673	Economy	7300.00
0005432605124	31673	Economy	7300.00
0005435221535	31673	Economy	7300.00
0005432605184	31673	Economy	7300.00
0005432605095	31673	Economy	6600.00
0005432605180	31673	Economy	6600.00
0005432605178	31673	Economy	6600.00
0005432605230	31673	Economy	6600.00
0005432605169	31673	Economy	6600.00
0005435221082	31673	Economy	6600.00
0005432605324	31673	Economy	6600.00
0005432605121	31673	Economy	6600.00
0005432605046	31673	Economy	6600.00
0005432605102	31673	Economy	6600.00
0005432605261	31673	Economy	6600.00
0005432605229	31673	Economy	6600.00
0005432605047	31673	Economy	6600.00
0005432604980	31673	Economy	6600.00
0005432605185	31673	Economy	6600.00
0005435221081	31673	Economy	6600.00
0005432605244	31673	Economy	6600.00
0005432605029	31673	Economy	6600.00
0005432605117	31673	Economy	6600.00
0005432605056	31673	Economy	6600.00
0005432605186	31673	Economy	6600.00
0005432605191	31673	Economy	6600.00
0005432605115	31673	Economy	6600.00
0005432605030	31673	Economy	6600.00
0005432605228	31673	Economy	6600.00
0005432605192	31673	Economy	6600.00
0005432604971	31673	Economy	6600.00
0005432605262	31673	Economy	6600.00
0005432605269	31673	Economy	6600.00
0005432605323	31673	Economy	6600.00
0005432605179	31673	Economy	6600.00
0005432605122	31673	Economy	6600.00
0005432605177	31673	Economy	6600.00
0005432605134	31673	Economy	6600.00
0005432605127	31673	Economy	6600.00
0005432605063	31673	Economy	6600.00
0005432605094	31673	Economy	6600.00
0005433293437	29592	Economy	19500.00
0005435154634	29592	Economy	19500.00
0005433293435	29592	Economy	17800.00
0005435154662	29592	Economy	17800.00
0005433293434	29592	Economy	17800.00
0005435154631	29592	Economy	17800.00
0005433293432	29592	Economy	17800.00
0005435154635	29592	Economy	17800.00
0005433293436	29592	Economy	17800.00
0005435154622	29592	Economy	17800.00
0005433293433	29592	Economy	17800.00
0005435154653	29592	Economy	17800.00
0005435154621	29592	Economy	17800.00
0005435154639	29592	Economy	17800.00
0005433293438	29592	Economy	17800.00
0005435154624	29592	Economy	17800.00
0005435154632	29592	Economy	17800.00
0005435154633	29592	Economy	17800.00
0005435154647	29592	Economy	17800.00
0005433473527	6690	Economy	14000.00
0005435257316	6690	Economy	14000.00
0005435257344	6690	Economy	12700.00
0005435257345	6690	Economy	12700.00
0005435257356	6690	Economy	12700.00
0005433473526	6690	Economy	12700.00
0005433473524	6690	Economy	12700.00
0005433473528	6690	Economy	12700.00
0005435257343	6690	Economy	12700.00
0005435257320	6690	Economy	12700.00
0005435257366	6690	Economy	12700.00
0005433473530	6690	Economy	12700.00
0005435257355	6690	Economy	12700.00
0005435257346	6690	Economy	12700.00
0005435257342	6690	Economy	12700.00
0005435257357	6690	Economy	12700.00
0005433473525	6690	Economy	12700.00
0005433473529	6690	Economy	12700.00
0005435257349	6690	Economy	12700.00
0005433473531	6690	Economy	12700.00
0005433473471	23900	Economy	14000.00
0005433473431	23900	Economy	14000.00
0005433473434	23900	Economy	12700.00
0005433473478	23900	Economy	12700.00
0005433473444	23900	Economy	12700.00
0005435257380	23900	Economy	12700.00
0005433473423	23900	Economy	12700.00
0005435257379	23900	Economy	12700.00
0005433473433	23900	Economy	12700.00
0005433473426	23900	Economy	12700.00
0005433473469	23900	Economy	12700.00
0005433473422	23900	Economy	12700.00
0005435257378	23900	Economy	12700.00
0005435257377	23900	Economy	12700.00
0005433473455	23900	Economy	12700.00
0005433473485	23900	Economy	12700.00
0005433473425	23900	Economy	12700.00
0005435257381	23900	Economy	12700.00
0005433473454	23900	Economy	12700.00
0005434606909	18879	Economy	6600.00
0005434606908	18879	Economy	6600.00
0005434606907	18879	Economy	6600.00
0005435904728	18879	Economy	6600.00
0005434606906	18879	Economy	6600.00
0005434606896	18879	Economy	6600.00
0005434605005	22394	Economy	6600.00
0005434605004	22394	Economy	6600.00
0005435904718	22394	Economy	6600.00
0005434606928	22394	Economy	6600.00
0005434606931	22394	Economy	6600.00
0005434606930	22394	Economy	6600.00
0005435904717	22394	Economy	6600.00
0005434605003	22394	Economy	6600.00
0005434606929	22394	Economy	6600.00
0005434605006	22394	Economy	6600.00
0005434522555	3856	Economy	24900.00
0005434603025	3856	Economy	24900.00
0005434522554	3856	Economy	24900.00
0005434602976	3856	Economy	22600.00
0005435904462	3856	Economy	22600.00
0005434522552	3856	Economy	22600.00
0005434602975	3856	Economy	22600.00
0005434522551	3856	Economy	22600.00
0005435904463	3856	Economy	22600.00
0005434522553	3856	Economy	22600.00
0005434602977	3856	Economy	22600.00
0005435904458	3856	Economy	22600.00
0005434603024	3856	Economy	22600.00
0005434522532	19066	Economy	24900.00
0005434522529	19066	Economy	24900.00
0005434602945	19066	Economy	22600.00
0005434522520	19066	Economy	22600.00
0005434522525	19066	Economy	22600.00
0005434602944	19066	Economy	22600.00
0005435904490	19066	Economy	22600.00
0005434604962	19066	Economy	22600.00
0005434522515	19066	Economy	22600.00
0005435904489	19066	Economy	22600.00
0005434604964	19066	Economy	22600.00
0005435904475	19066	Economy	22600.00
0005435904477	19066	Economy	22600.00
0005434522527	19066	Economy	22600.00
0005434604982	19066	Economy	22600.00
0005434522533	19066	Economy	22600.00
0005434522535	19066	Economy	22600.00
0005434604983	19066	Economy	22600.00
0005434602946	19066	Economy	22600.00
0005435904476	19066	Economy	22600.00
0005432220126	369	Business	44500.00
0005432753396	369	Business	44500.00
0005433293382	369	Business	44500.00
0005432748653	369	Business	44500.00
0005432748654	369	Business	44500.00
0005432748638	369	Business	44500.00
0005432748648	369	Business	44500.00
0005435154701	369	Business	44500.00
0005433293383	369	Economy	14800.00
0005432748642	369	Economy	14800.00
0005433875415	369	Economy	14800.00
0005432748647	369	Economy	14800.00
0005432748650	369	Economy	14800.00
0005432891453	369	Economy	14800.00
0005435627133	369	Economy	14800.00
0005435154700	369	Economy	14800.00
0005432891392	369	Economy	14800.00
0005432753397	369	Economy	14800.00
0005432891390	369	Economy	16300.00
0005433875416	369	Economy	16300.00
0005432748636	369	Economy	16300.00
0005432891441	369	Economy	16300.00
0005432891530	369	Economy	14800.00
0005432891531	369	Economy	14800.00
0005432749849	369	Economy	14800.00
0005433875411	369	Economy	14800.00
0005432751622	369	Economy	14800.00
0005432891436	369	Economy	14800.00
0005432753395	369	Economy	14800.00
0005432891413	369	Economy	14800.00
0005432748657	369	Economy	14800.00
0005432891409	369	Economy	14800.00
0005432891383	369	Economy	14800.00
0005432891437	369	Economy	14800.00
0005432891432	369	Economy	14800.00
0005432748637	369	Economy	14800.00
0005433293355	369	Economy	14800.00
0005432753394	369	Economy	14800.00
0005432891347	369	Economy	14800.00
0005432748651	369	Economy	14800.00
0005432751623	369	Economy	14800.00
0005432891431	369	Economy	14800.00
0005433293356	369	Economy	14800.00
0005432748655	369	Economy	14800.00
0005435154702	369	Economy	14800.00
0005432748640	369	Economy	14800.00
0005432748641	369	Economy	14800.00
0005432749846	369	Economy	14800.00
0005432749847	369	Economy	14800.00
0005432748639	369	Economy	14800.00
0005432748646	369	Economy	14800.00
0005432891410	369	Economy	14800.00
0005432891442	369	Economy	14800.00
0005432891468	369	Economy	14800.00
0005432748656	369	Economy	14800.00
0005432891435	369	Economy	14800.00
0005432891382	369	Economy	14800.00
0005432891391	369	Economy	14800.00
0005432748644	369	Economy	14800.00
0005435627134	369	Economy	14800.00
0005432748652	369	Economy	14800.00
0005432891433	369	Economy	14800.00
0005432748645	369	Economy	14800.00
0005432891388	369	Economy	14800.00
0005432749848	369	Economy	14800.00
0005433293374	369	Economy	14800.00
0005432748643	369	Economy	14800.00
0005432891460	369	Economy	14800.00
0005435154703	369	Economy	14800.00
0005432891477	369	Economy	14800.00
0005432748649	369	Economy	14800.00
0005434152869	12044	Business	44500.00
0005432748316	12044	Business	44500.00
0005432749825	12044	Business	44500.00
0005432748439	12044	Business	44500.00
0005432756908	12044	Business	44500.00
0005432748420	12044	Business	44500.00
0005432748480	12044	Business	44500.00
0005432748233	12044	Business	44500.00
0005432891573	12044	Business	44500.00
0005432891576	12044	Economy	14800.00
0005432748506	12044	Economy	14800.00
0005432748381	12044	Economy	14800.00
0005432748463	12044	Economy	14800.00
0005432748517	12044	Economy	14800.00
0005432748440	12044	Economy	16300.00
0005432748427	12044	Economy	16300.00
0005432749828	12044	Economy	14800.00
0005432748315	12044	Economy	14800.00
0005432891575	12044	Economy	14800.00
0005432748185	12044	Economy	14800.00
0005432749829	12044	Economy	14800.00
0005432748535	12044	Economy	14800.00
0005432748380	12044	Economy	14800.00
0005432748371	12044	Economy	14800.00
0005432748495	12044	Economy	14800.00
0005432748406	12044	Economy	14800.00
0005434153583	12044	Economy	14800.00
0005432891572	12044	Economy	14800.00
0005432214868	12044	Economy	14800.00
0005432748314	12044	Economy	14800.00
0005432748379	12044	Economy	14800.00
0005432891577	12044	Economy	14800.00
0005432748362	12044	Economy	14800.00
0005432891574	12044	Economy	14800.00
0005432749834	12044	Economy	14800.00
0005432753359	12044	Economy	14800.00
0005432748426	12044	Economy	14800.00
0005432748184	12044	Economy	14800.00
0005432756914	12044	Economy	14800.00
0005432214867	12044	Economy	14800.00
0005432748234	12044	Economy	14800.00
0005432753382	12044	Economy	14800.00
0005432748472	12044	Economy	14800.00
0005432748590	12044	Economy	14800.00
0005432748563	12044	Economy	14800.00
0005432748564	12044	Economy	14800.00
0005432756888	12044	Economy	14800.00
0005432756889	12044	Economy	14800.00
0005432748372	12044	Economy	14800.00
0005432748331	12044	Economy	14800.00
0005432749826	12044	Economy	14800.00
0005432748591	12044	Economy	14800.00
0005432749835	12044	Economy	14800.00
0005432756910	12044	Economy	14800.00
0005434153582	12044	Economy	14800.00
0005434153581	12044	Economy	14800.00
0005432756900	12044	Economy	14800.00
0005432748374	12044	Economy	14800.00
0005432748454	12044	Economy	14800.00
0005432748405	12044	Economy	14800.00
0005432756909	12044	Economy	14800.00
0005432748550	12044	Economy	14800.00
0005433525343	18952	Economy	28200.00
0005432928105	18952	Economy	25700.00
0005433531402	18952	Economy	25700.00
0005433525345	18952	Economy	25700.00
0005432928106	18952	Economy	25700.00
0005433531401	18952	Economy	25700.00
0005432928096	18952	Economy	25700.00
0005433525346	18952	Economy	25700.00
0005432928104	18952	Economy	25700.00
0005433533416	18952	Economy	25700.00
0005433525347	18952	Economy	25700.00
0005432928094	18952	Economy	25700.00
0005432928097	18952	Economy	25700.00
0005432928107	18952	Economy	25700.00
0005433533417	18952	Economy	25700.00
0005433525344	18952	Economy	25700.00
0005433527343	32502	Economy	28200.00
0005432928143	32502	Economy	28200.00
0005432928144	32502	Economy	25700.00
0005433527340	32502	Economy	25700.00
0005433525274	32502	Economy	25700.00
0005433525253	32502	Economy	25700.00
0005433525240	32502	Economy	25700.00
0005432928142	32502	Economy	25700.00
0005433527345	32502	Economy	25700.00
0005433531374	32502	Economy	25700.00
0005433527323	32502	Economy	25700.00
0005433525241	32502	Economy	25700.00
0005433527344	32502	Economy	25700.00
0005433531373	32502	Economy	25700.00
0005432928141	32502	Economy	25700.00
0005433525313	32502	Economy	25700.00
0005433525314	32502	Economy	25700.00
0005435374581	5289	Business	84000.00
0005435374720	5289	Business	84000.00
0005434827184	5289	Business	84000.00
0005434827182	5289	Business	84000.00
0005434827172	5289	Business	84000.00
0005435150430	5289	Business	84000.00
0005434558578	5289	Business	84000.00
0005435374439	5289	Business	84000.00
0005434558574	5289	Business	84000.00
0005435179707	5289	Business	84000.00
0005434558577	5289	Business	84000.00
0005434558564	5289	Business	84000.00
0005434827170	5289	Business	84000.00
0005435374764	5289	Business	84000.00
0005435374996	5289	Business	84000.00
0005435299872	5289	Business	84000.00
0005435304250	5289	Business	84000.00
0005434827196	5289	Comfort	47600.00
0005435374486	5289	Business	84000.00
0005435374721	5289	Comfort	47600.00
0005435314971	5289	Comfort	47600.00
0005435374519	5289	Comfort	47600.00
0005435150427	5289	Comfort	47600.00
0005434827169	5289	Comfort	47600.00
0005432121743	5289	Comfort	47600.00
0005434827188	5289	Comfort	47600.00
0005434827155	5289	Comfort	47600.00
0005434827195	5289	Comfort	47600.00
0005434558566	5289	Comfort	47600.00
0005435374656	5289	Comfort	47600.00
0005435375033	5289	Comfort	47600.00
0005434827153	5289	Comfort	47600.00
0005434827179	5289	Comfort	47600.00
0005435386733	5289	Comfort	47600.00
0005435374681	5289	Comfort	47600.00
0005434827171	5289	Comfort	47600.00
0005435661980	5289	Comfort	47600.00
0005435299878	5289	Comfort	47600.00
0005435150429	5289	Comfort	47600.00
0005435374779	5289	Comfort	47600.00
0005435374676	5289	Comfort	47600.00
0005435374713	5289	Comfort	47600.00
0005434827159	5289	Comfort	47600.00
0005434827163	5289	Comfort	47600.00
0005435386687	5289	Comfort	47600.00
0005435299897	5289	Economy	28000.00
0005435374809	5289	Economy	28000.00
0005435735242	5289	Economy	28000.00
0005434827186	5289	Economy	28000.00
0005434558560	5289	Economy	28000.00
0005432121741	5289	Economy	28000.00
0005434827158	5289	Economy	28000.00
0005434831283	5289	Economy	28000.00
0005434827191	5289	Economy	28000.00
0005435374645	5289	Economy	28000.00
0005432394216	5289	Economy	28000.00
0005435374492	5289	Economy	28000.00
0005434558568	5289	Economy	28000.00
0005434831284	5289	Economy	28000.00
0005434828773	5289	Economy	28000.00
0005435299898	5289	Economy	28000.00
0005434827194	5289	Economy	28000.00
0005435314961	5289	Economy	28000.00
0005434558562	5289	Economy	28000.00
0005434827149	5289	Economy	28000.00
0005435374503	5289	Economy	30800.00
0005434827178	5289	Economy	30800.00
0005434827167	5289	Economy	28000.00
0005435150428	5289	Economy	30800.00
0005435374780	5289	Economy	28000.00
0005435374712	5289	Economy	28000.00
0005434827176	5289	Economy	30800.00
0005432121744	5289	Economy	30800.00
0005434558569	5289	Economy	28000.00
0005435375036	5289	Economy	28000.00
0005434827154	5289	Economy	28000.00
0005434827192	5289	Economy	28000.00
0005435735241	5289	Economy	28000.00
0005435374821	5289	Economy	28000.00
0005434827164	5289	Economy	28000.00
0005434827162	5289	Economy	28000.00
0005435375035	5289	Economy	28000.00
0005435386691	5289	Economy	28000.00
0005432823497	5289	Economy	28000.00
0005435374708	5289	Economy	28000.00
0005435374485	5289	Economy	28000.00
0005434827161	5289	Economy	28000.00
0005434827198	5289	Economy	28000.00
0005435374777	5289	Economy	28000.00
0005434827150	5289	Economy	28000.00
0005435374834	5289	Economy	28000.00
0005434827193	5289	Economy	28000.00
0005434827187	5289	Economy	28000.00
0005435374508	5289	Economy	28000.00
0005434827148	5289	Economy	28000.00
0005435314954	5289	Economy	28000.00
0005434827157	5289	Economy	28000.00
0005434665023	5289	Economy	28000.00
0005434827165	5289	Economy	28000.00
0005435374734	5289	Economy	28000.00
0005435374539	5289	Economy	28000.00
0005435374758	5289	Economy	28000.00
0005435735215	5289	Economy	28000.00
0005434827168	5289	Economy	28000.00
0005432121739	5289	Economy	28000.00
0005435374518	5289	Economy	28000.00
0005434558554	5289	Economy	28000.00
0005435386672	5289	Economy	28000.00
0005435374440	5289	Economy	28000.00
0005435374474	5289	Economy	28000.00
0005435374995	5289	Economy	28000.00
0005434558575	5289	Economy	28000.00
0005435374498	5289	Economy	28000.00
0005434827146	5289	Economy	28000.00
0005435374755	5289	Economy	28000.00
0005435386734	5289	Economy	28000.00
0005435386673	5289	Economy	28000.00
0005435374458	5289	Economy	28000.00
0005435374499	5289	Economy	28000.00
0005434827197	5289	Economy	28000.00
0005434827174	5289	Economy	28000.00
0005435374660	5289	Economy	28000.00
0005435374389	5289	Economy	28000.00
0005434827147	5289	Economy	28000.00
0005434827166	5289	Economy	28000.00
0005434827185	5289	Economy	28000.00
0005434558559	5289	Economy	28000.00
0005435374915	5289	Economy	28000.00
0005435374627	5289	Economy	28000.00
0005432823496	5289	Economy	28000.00
0005434558576	5289	Economy	28000.00
0005434558555	5289	Economy	30800.00
0005434827189	5289	Economy	30800.00
0005435374577	5289	Economy	28000.00
0005434558565	5289	Economy	28000.00
0005435374589	5289	Economy	28000.00
0005435386724	5289	Economy	28000.00
0005435374347	5289	Economy	28000.00
0005435374512	5289	Economy	28000.00
0005432394218	5289	Economy	28000.00
0005434827180	5289	Economy	28000.00
0005434827156	5289	Economy	28000.00
0005434558556	5289	Economy	28000.00
0005434827151	5289	Economy	28000.00
0005435374644	5289	Economy	28000.00
0005435374820	5289	Economy	28000.00
0005435386723	5289	Economy	28000.00
0005435374733	5289	Economy	28000.00
0005434558558	5289	Economy	28000.00
0005434558571	5289	Economy	28000.00
0005434827160	5289	Economy	28000.00
0005434558573	5289	Economy	28000.00
0005432396355	5289	Economy	28000.00
0005434827181	5289	Economy	28000.00
0005434827183	5289	Economy	28000.00
0005435375034	5289	Economy	28000.00
0005435374491	5289	Economy	28000.00
0005434558563	5289	Economy	28000.00
0005435374523	5289	Economy	28000.00
0005435386719	5289	Economy	28000.00
0005435314972	5289	Economy	28000.00
0005434558570	5289	Economy	28000.00
0005434558561	5289	Economy	28000.00
0005435661998	5289	Economy	28000.00
0005434558567	5289	Economy	28000.00
0005435375032	5289	Economy	28000.00
0005434827173	5289	Economy	28000.00
0005434558581	5289	Economy	28000.00
0005432121742	5289	Economy	28000.00
0005435374637	5289	Economy	28000.00
0005434558572	5289	Economy	28000.00
0005435374743	5289	Economy	28000.00
0005434827190	5289	Economy	28000.00
0005434558557	5289	Economy	28000.00
0005434558579	5289	Economy	28000.00
0005435374759	5289	Economy	28000.00
0005435299875	5289	Economy	28000.00
0005435304242	5289	Economy	28000.00
0005434827152	5289	Economy	28000.00
0005435374877	5289	Economy	28000.00
0005435374390	5289	Economy	28000.00
0005435374727	5289	Economy	28000.00
0005432396354	5289	Economy	28000.00
0005435374410	5289	Economy	28000.00
0005434558580	5289	Economy	28000.00
0005435374497	5289	Economy	28000.00
0005432121740	5289	Economy	28000.00
0005434827175	5289	Economy	28000.00
0005434827177	5289	Economy	28000.00
0005434827199	5289	Economy	28000.00
0005432394217	5289	Economy	28000.00
0005435375113	9913	Business	84000.00
0005435150306	9913	Business	84000.00
0005434826223	9913	Business	84000.00
0005434826149	9913	Business	84000.00
0005434826315	9913	Business	84000.00
0005434826311	9913	Business	84000.00
0005434825348	9913	Business	84000.00
0005435315115	9913	Business	84000.00
0005435315126	9913	Business	84000.00
0005434826534	9913	Business	84000.00
0005434825845	9913	Business	84000.00
0005434826389	9913	Business	84000.00
0005434826206	9913	Comfort	47600.00
0005435315113	9913	Business	84000.00
0005434826914	9913	Comfort	47600.00
0005434826040	9913	Comfort	47600.00
0005435299915	9913	Comfort	47600.00
0005434826068	9913	Comfort	47600.00
0005434825843	9913	Comfort	47600.00
0005434826309	9913	Comfort	47600.00
0005434826141	9913	Comfort	47600.00
0005434826878	9913	Comfort	47600.00
0005434826111	9913	Comfort	47600.00
0005435150262	9913	Comfort	47600.00
0005435315112	9913	Comfort	47600.00
0005434826814	9913	Comfort	47600.00
0005434826494	9913	Comfort	47600.00
0005435150244	9913	Comfort	47600.00
0005435315121	9913	Comfort	47600.00
0005434826007	9913	Comfort	47600.00
0005435375111	9913	Comfort	47600.00
0005434558428	9913	Comfort	47600.00
0005434826510	9913	Comfort	47600.00
0005435386753	9913	Comfort	47600.00
0005434826046	9913	Comfort	47600.00
0005435315111	9913	Comfort	47600.00
0005434831254	9913	Comfort	47600.00
0005435375114	9913	Comfort	47600.00
0005435375121	9913	Comfort	47600.00
0005434826266	9913	Comfort	47600.00
0005434826316	9913	Comfort	47600.00
0005434826317	9913	Comfort	47600.00
0005434825791	9913	Comfort	47600.00
0005434826175	9913	Economy	28000.00
0005434826600	9913	Economy	28000.00
0005434826405	9913	Economy	28000.00
0005434826879	9913	Economy	28000.00
0005434826474	9913	Economy	28000.00
0005435315116	9913	Economy	28000.00
0005434826559	9913	Economy	28000.00
0005434558429	9913	Economy	28000.00
0005432400192	9913	Economy	28000.00
0005434826267	9913	Economy	28000.00
0005434825873	9913	Economy	28000.00
0005435375115	9913	Economy	28000.00
0005435375107	9913	Economy	28000.00
0005435375124	9913	Economy	28000.00
0005434826008	9913	Economy	28000.00
0005434826074	9913	Economy	28000.00
0005435735275	9913	Economy	28000.00
0005434825816	9913	Economy	28000.00
0005434831240	9913	Economy	28000.00
0005435375109	9913	Economy	28000.00
0005434828761	9913	Economy	28000.00
0005435375116	9913	Economy	28000.00
0005434826523	9913	Economy	28000.00
0005434558452	9913	Economy	28000.00
0005435375118	9913	Economy	28000.00
0005435315117	9913	Economy	28000.00
0005435315123	9913	Economy	28000.00
0005434825950	9913	Economy	28000.00
0005434826585	9913	Economy	28000.00
0005434825722	9913	Economy	28000.00
0005434826499	9913	Economy	28000.00
0005434558447	9913	Economy	28000.00
0005435375127	9913	Economy	28000.00
0005434826222	9913	Economy	28000.00
0005434831253	9913	Economy	28000.00
0005434826125	9913	Economy	28000.00
0005435375126	9913	Economy	28000.00
0005434825881	9913	Economy	28000.00
0005434825874	9913	Economy	28000.00
0005434826049	9913	Economy	28000.00
0005434826006	9913	Economy	28000.00
0005434826121	9913	Economy	30800.00
0005434825833	9913	Economy	30800.00
0005434826354	9913	Economy	28000.00
0005434826403	9913	Economy	28000.00
0005435375112	9913	Economy	28000.00
0005435386757	9913	Economy	30800.00
0005434825723	9913	Economy	28000.00
0005434825610	9913	Economy	28000.00
0005434826383	9913	Economy	28000.00
0005435375122	9913	Economy	28000.00
0005435375117	9913	Economy	28000.00
0005434826678	9913	Economy	28000.00
0005435150329	9913	Economy	28000.00
0005434831246	9913	Economy	28000.00
0005435375128	9913	Economy	28000.00
0005434825986	9913	Economy	28000.00
0005434825911	9913	Economy	28000.00
0005435315122	9913	Economy	28000.00
0005435179720	9913	Economy	28000.00
0005434826473	9913	Economy	28000.00
0005435375132	9913	Economy	28000.00
0005434825815	9913	Economy	28000.00
0005434826408	9913	Economy	28000.00
0005435150261	9913	Economy	28000.00
0005434825846	9913	Economy	28000.00
0005435150313	9913	Economy	28000.00
0005435302335	9913	Economy	28000.00
0005435315125	9913	Economy	28000.00
0005434558431	9913	Economy	28000.00
0005435299917	9913	Economy	28000.00
0005434826484	9913	Economy	28000.00
0005434826493	9913	Economy	28000.00
0005435375133	9913	Economy	28000.00
0005435375125	9913	Economy	28000.00
0005435375110	9913	Economy	28000.00
0005434826492	9913	Economy	28000.00
0005434826225	9913	Economy	28000.00
0005434826312	9913	Economy	28000.00
0005435735274	9913	Economy	28000.00
0005434826353	9913	Economy	28000.00
0005435375108	9913	Economy	28000.00
0005435315120	9913	Economy	28000.00
0005434825944	9913	Economy	28000.00
0005435315118	9913	Economy	28000.00
0005434826136	9913	Economy	28000.00
0005434826701	9913	Economy	28000.00
0005435375120	9913	Economy	28000.00
0005435375130	9913	Economy	28000.00
0005434826621	9913	Economy	28000.00
0005434825909	9913	Economy	28000.00
0005434826133	9913	Economy	28000.00
0005434825534	9913	Economy	28000.00
0005434826538	9913	Economy	28000.00
0005434826509	9913	Economy	28000.00
0005432400193	9913	Economy	28000.00
0005435375106	9913	Economy	28000.00
0005435375134	9913	Economy	28000.00
0005435386756	9913	Economy	28000.00
0005434826815	9913	Economy	28000.00
0005434825933	9913	Economy	28000.00
0005434826411	9913	Economy	28000.00
0005435150282	9913	Economy	28000.00
0005434826215	9913	Economy	28000.00
0005434825844	9913	Economy	28000.00
0005434826777	9913	Economy	28000.00
0005434831241	9913	Economy	28000.00
0005434825947	9913	Economy	28000.00
0005435375119	9913	Economy	28000.00
0005434826169	9913	Economy	28000.00
0005435315114	9913	Economy	28000.00
0005434826310	9913	Economy	28000.00
0005434826486	9913	Economy	30800.00
0005434825578	9913	Economy	28000.00
0005434825908	9913	Economy	28000.00
0005434826410	9913	Economy	28000.00
0005434826226	9913	Economy	28000.00
0005435150250	9913	Economy	28000.00
0005435386754	9913	Economy	28000.00
0005435315119	9913	Economy	28000.00
0005435179719	9913	Economy	28000.00
0005434826337	9913	Economy	28000.00
0005434826384	9913	Economy	28000.00
0005435150321	9913	Economy	28000.00
0005434826154	9913	Economy	28000.00
0005434826601	9913	Economy	28000.00
0005434826148	9913	Economy	28000.00
0005434558430	9913	Economy	28000.00
0005435375135	9913	Economy	28000.00
0005435315127	9913	Economy	28000.00
0005434826394	9913	Economy	28000.00
0005434826620	9913	Economy	28000.00
0005434826134	9913	Economy	28000.00
0005434826798	9913	Economy	28000.00
0005435375131	9913	Economy	28000.00
0005434826436	9913	Economy	28000.00
0005434826392	9913	Economy	28000.00
0005435375104	9913	Economy	28000.00
0005435299916	9913	Economy	28000.00
0005434826422	9913	Economy	28000.00
0005435375129	9913	Economy	28000.00
0005434831251	9913	Economy	28000.00
0005435386755	9913	Economy	28000.00
0005435315124	9913	Economy	28000.00
0005434826435	9913	Economy	28000.00
0005434826390	9913	Economy	28000.00
0005434826501	9913	Economy	28000.00
0005434826619	9913	Economy	28000.00
0005434828756	9913	Economy	28000.00
0005435150245	9913	Economy	28000.00
0005434831250	9913	Economy	28000.00
0005434831255	9913	Economy	28000.00
0005434826799	9913	Economy	28000.00
0005434826500	9913	Economy	28000.00
0005435299914	9913	Economy	28000.00
0005434826584	9913	Economy	28000.00
0005435150375	9913	Economy	28000.00
0005435150376	9913	Economy	28000.00
0005435299913	9913	Economy	28000.00
0005434826067	9913	Economy	28000.00
0005434826142	9913	Economy	28000.00
0005435662012	9913	Economy	28000.00
0005434825579	9913	Economy	28000.00
0005434826460	9913	Economy	28000.00
0005434826530	9913	Economy	28000.00
0005434825474	9913	Economy	28000.00
0005434826323	9913	Economy	28000.00
0005434826187	9913	Economy	28000.00
0005432396328	9913	Economy	28000.00
0005435375123	9913	Economy	28000.00
0005434826406	9913	Economy	28000.00
0005435375105	9913	Economy	28000.00
0005434826009	9913	Economy	28000.00
0005434826058	9913	Economy	28000.00
0005434825934	9913	Economy	28000.00
0005435375136	9913	Economy	28000.00
0005434826674	9913	Economy	28000.00
0005435083027	6972	Economy	8200.00
0005435083030	6972	Economy	7400.00
0005435083031	6972	Economy	7400.00
0005435083025	6972	Economy	7400.00
0005435083028	6972	Economy	7400.00
0005435083029	6972	Economy	7400.00
0005435083026	6972	Economy	7400.00
0005435082968	25990	Economy	8200.00
0005435790371	25990	Economy	7400.00
0005435082955	25990	Economy	7400.00
0005435082915	25990	Economy	7400.00
0005435082943	25990	Economy	7400.00
0005435082942	25990	Economy	7400.00
0005435790369	25990	Economy	7400.00
0005435082961	25990	Economy	7400.00
0005435790370	25990	Economy	7400.00
0005435082973	25990	Economy	7400.00
0005435082914	25990	Economy	7400.00
0005435082962	25990	Economy	7400.00
0005434215588	9566	Business	32800.00
0005434757627	9566	Business	32800.00
0005434757638	9566	Business	32800.00
0005434757625	9566	Business	32800.00
0005434757635	9566	Business	32800.00
0005434215491	9566	Business	32800.00
0005434757634	9566	Business	32800.00
0005434215403	9566	Business	32800.00
0005434215353	9566	Economy	10900.00
0005434757645	9566	Economy	10900.00
0005434757648	9566	Economy	10900.00
0005434215574	9566	Economy	10900.00
0005434215322	9566	Economy	10900.00
0005434215448	9566	Economy	10900.00
0005434757641	9566	Economy	12000.00
0005434215402	9566	Economy	12000.00
0005434757646	9566	Economy	12000.00
0005434215545	9566	Economy	12000.00
0005434757637	9566	Economy	12000.00
0005434757636	9566	Economy	10900.00
0005434215475	9566	Economy	10900.00
0005434215370	9566	Economy	10900.00
0005434757644	9566	Economy	10900.00
0005434757629	9566	Economy	10900.00
0005434215487	9566	Economy	10900.00
0005434215364	9566	Economy	10900.00
0005434215365	9566	Economy	10900.00
0005434215429	9566	Economy	10900.00
0005434757632	9566	Economy	10900.00
0005434215401	9566	Economy	10900.00
0005434215394	9566	Economy	10900.00
0005434215667	9566	Economy	10900.00
0005434757626	9566	Economy	10900.00
0005434757653	9566	Economy	10900.00
0005434215419	9566	Economy	10900.00
0005434215638	9566	Economy	10900.00
0005434215361	9566	Economy	10900.00
0005434215582	9566	Economy	10900.00
0005434757640	9566	Economy	10900.00
0005434757651	9566	Economy	10900.00
0005434757630	9566	Economy	10900.00
0005434215482	9566	Economy	10900.00
0005434215581	9566	Economy	10900.00
0005434757639	9566	Economy	10900.00
0005434215474	9566	Economy	10900.00
0005434757628	9566	Economy	10900.00
0005434215504	9566	Economy	10900.00
0005434757643	9566	Economy	10900.00
0005434757650	9566	Economy	10900.00
0005434757642	9566	Economy	10900.00
0005434215352	9566	Economy	10900.00
0005434757631	9566	Economy	10900.00
0005434215492	9566	Economy	10900.00
0005434215567	9566	Economy	10900.00
0005434215321	9566	Economy	10900.00
0005434757652	9566	Economy	10900.00
0005434215245	9566	Economy	10900.00
0005434215389	9566	Economy	10900.00
0005434757633	9566	Economy	10900.00
0005434215449	9566	Economy	10900.00
0005434215478	9566	Economy	10900.00
0005434215479	9566	Economy	10900.00
0005434215302	9566	Economy	10900.00
0005434757649	9566	Economy	10900.00
0005434215477	9566	Economy	10900.00
0005434215433	9566	Economy	10900.00
0005434215313	9566	Economy	10900.00
0005434757647	9566	Economy	10900.00
0005434215249	9566	Economy	10900.00
0005434215451	9566	Economy	10900.00
0005434757258	28616	Business	32800.00
0005434757310	28616	Business	32800.00
0005434215831	28616	Business	32800.00
0005434215832	28616	Business	32800.00
0005434215820	28616	Business	32800.00
0005434757183	28616	Business	32800.00
0005434757239	28616	Business	32800.00
0005434757286	28616	Business	32800.00
0005434215818	28616	Business	32800.00
0005434757062	28616	Business	32800.00
0005434757285	28616	Economy	10900.00
0005434756976	28616	Economy	10900.00
0005434757219	28616	Economy	10900.00
0005434757220	28616	Economy	10900.00
0005434215823	28616	Economy	10900.00
0005434757229	28616	Economy	10900.00
0005434757332	28616	Economy	10900.00
0005434215825	28616	Economy	12000.00
0005434757073	28616	Economy	12000.00
0005434757072	28616	Economy	12000.00
0005434757110	28616	Economy	10900.00
0005434215835	28616	Economy	10900.00
0005434757185	28616	Economy	10900.00
0005434215828	28616	Economy	10900.00
0005434757276	28616	Economy	10900.00
0005434215816	28616	Economy	10900.00
0005434757248	28616	Economy	10900.00
0005434215822	28616	Economy	10900.00
0005434215837	28616	Economy	10900.00
0005434757221	28616	Economy	10900.00
0005434757124	28616	Economy	10900.00
0005434215821	28616	Economy	10900.00
0005434757071	28616	Economy	10900.00
0005434215815	28616	Economy	10900.00
0005434215838	28616	Economy	10900.00
0005434215844	28616	Economy	10900.00
0005434215827	28616	Economy	10900.00
0005434757165	28616	Economy	10900.00
0005434757215	28616	Economy	10900.00
0005434757331	28616	Economy	10900.00
0005434757274	28616	Economy	10900.00
0005434215814	28616	Economy	10900.00
0005434757055	28616	Economy	10900.00
0005434215834	28616	Economy	10900.00
0005434757311	28616	Economy	10900.00
0005434215839	28616	Economy	10900.00
0005434215840	28616	Economy	10900.00
0005434215836	28616	Economy	10900.00
0005434215819	28616	Economy	10900.00
0005434215829	28616	Economy	10900.00
0005434757166	28616	Economy	10900.00
0005434757240	28616	Economy	10900.00
0005434757070	28616	Economy	10900.00
0005434215817	28616	Economy	10900.00
0005434215833	28616	Economy	10900.00
0005434757109	28616	Economy	10900.00
0005434757056	28616	Economy	10900.00
0005434215824	28616	Economy	10900.00
0005434215841	28616	Economy	10900.00
0005434215826	28616	Economy	10900.00
0005434757218	28616	Economy	10900.00
0005434757162	28616	Economy	10900.00
0005434756975	28616	Economy	10900.00
0005434215813	28616	Economy	10900.00
0005434757278	28616	Economy	10900.00
0005434757063	28616	Economy	10900.00
0005434757289	28616	Economy	10900.00
0005434757247	28616	Economy	10900.00
0005434757157	28616	Economy	10900.00
0005434757182	28616	Economy	10900.00
0005434757356	28616	Economy	10900.00
0005434215842	28616	Economy	10900.00
0005434215830	28616	Economy	10900.00
0005434757191	28616	Economy	10900.00
0005434215843	28616	Economy	10900.00
0005434760249	10804	Economy	8900.00
0005434760245	10804	Economy	8900.00
0005435100207	10804	Economy	8900.00
0005434760244	10804	Economy	8900.00
0005434760250	10804	Economy	8900.00
0005435100193	31805	Economy	8900.00
0005435100192	31805	Economy	8900.00
0005435100191	31805	Economy	8900.00
0005435100194	31805	Economy	8900.00
0005435100183	31805	Economy	8900.00
0005432290722	1954	Economy	20900.00
0005434640077	1954	Economy	20900.00
0005433202651	1954	Economy	19000.00
0005433202570	1954	Economy	19000.00
0005434640082	1954	Economy	19000.00
0005433202629	1954	Economy	19000.00
0005434640080	1954	Economy	19000.00
0005433202699	1954	Economy	19000.00
0005434640068	1954	Economy	19000.00
0005434640072	1954	Economy	19000.00
0005432290723	1954	Economy	19000.00
0005433202652	1954	Economy	19000.00
0005434640078	1954	Economy	19000.00
0005434640071	1954	Economy	19000.00
0005434640069	1954	Economy	19000.00
0005432290725	1954	Economy	19000.00
0005433202650	1954	Economy	19000.00
0005434640073	1954	Economy	19000.00
0005433202698	1954	Economy	19000.00
0005434640070	1954	Economy	19000.00
0005434640076	1954	Economy	19000.00
0005433202664	1954	Economy	19000.00
0005432290724	1954	Economy	19000.00
0005433202697	1954	Economy	19000.00
0005434640075	1954	Economy	19000.00
0005434640079	1954	Economy	19000.00
0005433202631	1954	Economy	19000.00
0005434640081	1954	Economy	19000.00
0005433202665	1954	Economy	19000.00
0005433202630	1954	Economy	19000.00
0005433202642	1954	Economy	19000.00
0005434640083	1954	Economy	19000.00
0005435948361	1954	Economy	19000.00
0005434640085	1954	Economy	19000.00
0005433202683	1954	Economy	19000.00
0005433202696	1954	Economy	19000.00
0005434640074	1954	Economy	19000.00
0005434640086	1954	Economy	19000.00
0005434640084	1954	Economy	19000.00
0005433202660	1954	Economy	19000.00
0005433202779	23249	Economy	20900.00
0005434639755	23249	Economy	20900.00
0005433202780	23249	Economy	20900.00
0005433202781	23249	Economy	20900.00
0005433202771	23249	Economy	19000.00
0005433202777	23249	Economy	19000.00
0005434639776	23249	Economy	19000.00
0005434639878	23249	Economy	19000.00
0005434639829	23249	Economy	19000.00
0005433202776	23249	Economy	19000.00
0005434639879	23249	Economy	19000.00
0005434639707	23249	Economy	19000.00
0005434639863	23249	Economy	19000.00
0005434639950	23249	Economy	19000.00
0005434639808	23249	Economy	19000.00
0005434639763	23249	Economy	19000.00
0005434639877	23249	Economy	19000.00
0005434639907	23249	Economy	19000.00
0005433202778	23249	Economy	19000.00
0005434639809	23249	Economy	19000.00
0005434639905	23249	Economy	19000.00
0005434639807	23249	Economy	19000.00
0005433202775	23249	Economy	19000.00
0005433202773	23249	Economy	19000.00
0005433202774	23249	Economy	19000.00
0005434639953	23249	Economy	19000.00
0005434639904	23249	Economy	19000.00
0005434639823	23249	Economy	19000.00
0005434639940	23249	Economy	19000.00
0005433202772	23249	Economy	19000.00
0005434639775	23249	Economy	19000.00
0005434639764	23249	Economy	19000.00
0005434639757	23249	Economy	19000.00
0005435327030	6041	Business	69700.00
0005434601566	6041	Business	69700.00
0005435327028	6041	Economy	23200.00
0005435327054	6041	Economy	23200.00
0005435326992	6041	Economy	23200.00
0005434601567	6041	Economy	23200.00
0005435327095	6041	Economy	25600.00
0005434601568	6041	Economy	23200.00
0005433531404	6041	Economy	23200.00
0005434601565	6041	Economy	23200.00
0005433531405	6041	Economy	23200.00
0005433531403	6041	Economy	23200.00
0005434601569	6041	Economy	23200.00
0005434601573	6041	Economy	23200.00
0005435327067	6041	Economy	23200.00
0005435327025	6041	Economy	23200.00
0005435327096	6041	Economy	23200.00
0005435327053	6041	Economy	23200.00
0005434601571	6041	Economy	23200.00
0005434601575	6041	Economy	23200.00
0005434601574	6041	Economy	23200.00
0005434601564	6041	Economy	23200.00
0005434601576	6041	Economy	23200.00
0005432111366	6041	Economy	23200.00
0005434601563	6041	Economy	23200.00
0005434601572	6041	Economy	23200.00
0005434601570	6041	Economy	23200.00
0005434601375	18581	Business	69700.00
0005434601324	18581	Business	69700.00
0005434601322	18581	Economy	23200.00
0005435327131	18581	Economy	23200.00
0005433531362	18581	Economy	23200.00
0005434601442	18581	Economy	23200.00
0005434601398	18581	Economy	25600.00
0005434601270	18581	Economy	25600.00
0005433531360	18581	Economy	23200.00
0005434601443	18581	Economy	23200.00
0005433531361	18581	Economy	23200.00
0005435327132	18581	Economy	23200.00
0005434601346	18581	Economy	23200.00
0005434601444	18581	Economy	23200.00
0005434601469	18581	Economy	23200.00
0005434601287	18581	Economy	23200.00
0005434601323	18581	Economy	23200.00
0005434601347	18581	Economy	23200.00
0005433531380	18581	Economy	23200.00
0005433527348	18581	Economy	23200.00
0005434601422	18581	Economy	23200.00
0005433527334	18581	Economy	23200.00
0005435327129	18581	Economy	23200.00
0005434601470	18581	Economy	23200.00
0005433527325	18581	Economy	23200.00
0005434601379	18581	Economy	23200.00
0005434601327	18581	Economy	23200.00
0005433527347	18581	Economy	23200.00
0005434601378	18581	Economy	23200.00
0005435327130	18581	Economy	23200.00
0005433531384	18581	Economy	23200.00
0005434558540	10603	Business	9100.00
0005434552784	10603	Business	9100.00
0005434552769	10603	Business	9100.00
0005434552782	10603	Business	9100.00
0005434552790	10603	Business	9100.00
0005433181589	10603	Business	9100.00
0005435314957	10603	Business	9100.00
0005433181607	10603	Business	9100.00
0005434558537	10603	Business	9100.00
0005435314953	10603	Business	9100.00
0005433181573	10603	Business	9100.00
0005434552756	10603	Business	9100.00
0005434558544	10603	Economy	3000.00
0005434558547	10603	Economy	3000.00
0005434558536	10603	Economy	3000.00
0005434558541	10603	Economy	3000.00
0005434552755	10603	Economy	3000.00
0005434558533	10603	Economy	3000.00
0005435314969	10603	Economy	3000.00
0005434552768	10603	Economy	3000.00
0005434558551	10603	Economy	3000.00
0005434558534	10603	Economy	3000.00
0005434558529	10603	Economy	3300.00
0005434558548	10603	Economy	3300.00
0005433181529	10603	Economy	3300.00
0005434552788	10603	Economy	3300.00
0005434552776	10603	Economy	3000.00
0005434558535	10603	Economy	3000.00
0005435314983	10603	Economy	3000.00
0005433181594	10603	Economy	3000.00
0005434552773	10603	Economy	3000.00
0005434558532	10603	Economy	3000.00
0005434552772	10603	Economy	3000.00
0005434552766	10603	Economy	3000.00
0005435314974	10603	Economy	3000.00
0005434552760	10603	Economy	3000.00
0005434558543	10603	Economy	3000.00
0005434558531	10603	Economy	3000.00
0005434552771	10603	Economy	3000.00
0005434552775	10603	Economy	3000.00
0005434552787	10603	Economy	3000.00
0005434552758	10603	Economy	3000.00
0005433181621	10603	Economy	3000.00
0005434552791	10603	Economy	3000.00
0005433181528	10603	Economy	3000.00
0005433181744	10603	Economy	3000.00
0005434552757	10603	Economy	3000.00
0005434554122	10603	Economy	3000.00
0005433181620	10603	Economy	3000.00
0005434552785	10603	Economy	3000.00
0005434558528	10603	Economy	3000.00
0005434552770	10603	Economy	3000.00
0005433181470	10603	Economy	3000.00
0005434558546	10603	Economy	3000.00
0005434558542	10603	Economy	3000.00
0005433181571	10603	Economy	3000.00
0005434558545	10603	Economy	3000.00
0005434552778	10603	Economy	3000.00
0005433181588	10603	Economy	3000.00
0005435314960	10603	Economy	3000.00
0005433181601	10603	Economy	3000.00
0005434552764	10603	Economy	3000.00
0005434552762	10603	Economy	3000.00
0005434552754	10603	Economy	3000.00
0005433181572	10603	Economy	3000.00
0005434552761	10603	Economy	3000.00
0005434552780	10603	Economy	3000.00
0005434558527	10603	Economy	3000.00
0005434558539	10603	Economy	3000.00
0005434552777	10603	Economy	3000.00
0005434552786	10603	Economy	3000.00
0005434552783	10603	Economy	3000.00
0005434558530	10603	Economy	3000.00
0005434558552	10603	Economy	3000.00
0005434552781	10603	Economy	3000.00
0005435314966	10603	Economy	3000.00
0005434558550	10603	Economy	3000.00
0005434552763	10603	Economy	3000.00
0005435314956	10603	Economy	3000.00
0005434552779	10603	Economy	3000.00
0005433181676	10603	Economy	3000.00
0005434554123	10603	Economy	3000.00
0005434558549	10603	Economy	3000.00
0005434552759	10603	Economy	3000.00
0005434558553	10603	Economy	3000.00
0005434552765	10603	Economy	3000.00
0005433181745	10603	Economy	3000.00
0005434552774	10603	Economy	3000.00
0005434558538	10603	Economy	3000.00
0005434552767	10603	Economy	3000.00
0005434552789	10603	Economy	3000.00
0005435314982	10603	Economy	3000.00
0005435315119	27673	Business	9100.00
0005433181820	27673	Economy	3000.00
0005435315114	27673	Economy	3000.00
0005435315123	27673	Economy	3300.00
0005433181815	27673	Economy	3000.00
0005435315127	27673	Economy	3000.00
0005435315111	27673	Economy	3000.00
0005435315117	27673	Economy	3000.00
0005435315124	27673	Economy	3000.00
0005435315116	27673	Economy	3000.00
0005435315120	27673	Economy	3000.00
0005435315113	27673	Economy	3000.00
0005435315121	27673	Economy	3000.00
0005433181818	27673	Economy	3000.00
0005435315126	27673	Economy	3000.00
0005435315125	27673	Economy	3000.00
0005435315112	27673	Economy	3000.00
0005435315118	27673	Economy	3000.00
0005433181817	27673	Economy	3000.00
0005433181816	27673	Economy	3000.00
0005435315115	27673	Economy	3000.00
0005433181819	27673	Economy	3000.00
0005435315122	27673	Economy	3000.00
0005434552524	27672	Business	9100.00
0005434552450	27672	Business	9100.00
0005434552485	27672	Business	9100.00
0005434552455	27672	Business	9100.00
0005434552338	27672	Business	9100.00
0005434552554	27672	Business	9100.00
0005434552522	27672	Business	9100.00
0005434558449	27672	Business	9100.00
0005434552251	27672	Business	9100.00
0005434552465	27672	Economy	3000.00
0005434552543	27672	Economy	3000.00
0005434552364	27672	Economy	3000.00
0005434552283	27672	Economy	3000.00
0005434552380	27672	Economy	3000.00
0005434552411	27672	Economy	3000.00
0005434552490	27672	Economy	3300.00
0005434552230	27672	Economy	3300.00
0005434552369	27672	Economy	3300.00
0005434552555	27672	Economy	3000.00
0005434552049	27672	Economy	3000.00
0005434554120	27672	Economy	3000.00
0005434558450	27672	Economy	3000.00
0005434552250	27672	Economy	3000.00
0005434558437	27672	Economy	3000.00
0005434552244	27672	Economy	3000.00
0005434552237	27672	Economy	3000.00
0005434552272	27672	Economy	3000.00
0005434552544	27672	Economy	3000.00
0005434552381	27672	Economy	3000.00
0005434552211	27672	Economy	3000.00
0005434552527	27672	Economy	3000.00
0005434552232	27672	Economy	3000.00
0005434552182	27672	Economy	3000.00
0005434552468	27672	Economy	3000.00
0005434552367	27672	Economy	3000.00
0005434552449	27672	Economy	3000.00
0005434558411	27672	Economy	3000.00
0005434552142	27672	Economy	3000.00
0005434552373	27672	Economy	3000.00
0005434552542	27672	Economy	3000.00
0005434552525	27672	Economy	3000.00
0005434552323	27672	Economy	3000.00
0005434552174	27672	Economy	3000.00
0005434552286	27672	Economy	3000.00
0005434552214	27672	Economy	3000.00
0005434552469	27672	Economy	3000.00
0005434552259	27672	Economy	3000.00
0005434552210	27672	Economy	3000.00
0005434552531	27672	Economy	3000.00
0005434558442	27672	Economy	3000.00
0005434554119	27672	Economy	3000.00
0005434552349	27672	Economy	3000.00
0005434552446	27672	Economy	3000.00
0005434552141	27672	Economy	3000.00
0005434552363	27672	Economy	3000.00
0005434552467	27672	Economy	3000.00
0005434552243	27672	Economy	3000.00
0005434552464	27672	Economy	3000.00
0005434552236	27672	Economy	3000.00
0005434552050	27672	Economy	3000.00
0005434554118	27672	Economy	3000.00
0005434552378	27672	Economy	3000.00
0005434552258	27672	Economy	3000.00
0005434552339	27672	Economy	3000.00
0005434552545	27672	Economy	3000.00
0005434552454	27672	Economy	3000.00
0005434552189	27672	Economy	3000.00
0005434552313	27672	Economy	3000.00
0005434558448	27672	Economy	3000.00
0005434558451	27672	Economy	3000.00
0005434552486	27672	Economy	3000.00
0005434552398	27672	Economy	3000.00
0005434552370	27672	Economy	3000.00
0005434552499	27672	Economy	3000.00
0005434552178	27672	Economy	3000.00
0005434558446	27672	Economy	3000.00
0005433459340	6155	Economy	11700.00
0005433459341	6155	Economy	11700.00
0005433459298	19322	Economy	11700.00
0005433459284	19322	Economy	11700.00
0005433459311	19322	Economy	11700.00
0005433459300	19322	Economy	11700.00
0005433459297	19322	Economy	11700.00
0005433459314	19322	Economy	11700.00
0005435719603	6744	Business	51100.00
0005435654515	6744	Business	51100.00
0005435683307	6744	Business	51100.00
0005435654512	6744	Business	51100.00
0005435438532	6744	Business	51100.00
0005435683300	6744	Business	51100.00
0005435654513	6744	Business	51100.00
0005432533352	6744	Business	51100.00
0005432533355	6744	Business	51100.00
0005435683304	6744	Economy	17000.00
0005435220367	6744	Economy	17000.00
0005434828741	6744	Economy	17000.00
0005435683299	6744	Economy	17000.00
0005435790413	6744	Economy	18700.00
0005434828739	6744	Economy	18700.00
0005435438445	6744	Economy	18700.00
0005435220356	6744	Economy	17000.00
0005435683306	6744	Economy	17000.00
0005434828740	6744	Economy	17000.00
0005435683302	6744	Economy	17000.00
0005435438461	6744	Economy	17000.00
0005435438429	6744	Economy	17000.00
0005435719605	6744	Economy	17000.00
0005435720167	6744	Economy	17000.00
0005435438488	6744	Economy	17000.00
0005435220359	6744	Economy	17000.00
0005435654514	6744	Economy	17000.00
0005434828760	6744	Economy	17000.00
0005435683301	6744	Economy	17000.00
0005435220355	6744	Economy	17000.00
0005435438392	6744	Economy	17000.00
0005432136311	6744	Economy	17000.00
0005434828751	6744	Economy	17000.00
0005435438436	6744	Economy	17000.00
0005435438390	6744	Economy	17000.00
0005435438393	6744	Economy	17000.00
0005435683309	6744	Economy	17000.00
0005435438444	6744	Economy	17000.00
0005435438391	6744	Economy	17000.00
0005435438481	6744	Economy	17000.00
0005435438437	6744	Economy	17000.00
0005435438487	6744	Economy	17000.00
0005435220365	6744	Economy	17000.00
0005435220364	6744	Economy	17000.00
0005435631050	6744	Economy	17000.00
0005432533354	6744	Economy	17000.00
0005435438458	6744	Economy	17000.00
0005435438337	6744	Economy	17000.00
0005432136310	6744	Economy	17000.00
0005435683298	6744	Economy	17000.00
0005435719604	6744	Economy	17000.00
0005435683308	6744	Economy	17000.00
0005435438385	6744	Economy	17000.00
0005434828759	6744	Economy	17000.00
0005435438396	6744	Economy	17000.00
0005435438443	6744	Economy	17000.00
0005435438423	6744	Economy	17000.00
0005435683310	6744	Economy	17000.00
0005432533351	6744	Economy	17000.00
0005435683305	6744	Economy	17000.00
0005435438442	6744	Economy	17000.00
0005435438530	6744	Economy	17000.00
0005435438531	6744	Economy	17000.00
0005435438400	6744	Economy	17000.00
0005435720168	6744	Economy	17000.00
0005435683303	6744	Economy	17000.00
0005435719583	24577	Business	51100.00
0005435682821	24577	Business	51100.00
0005435682899	24577	Business	51100.00
0005435682966	24577	Business	51100.00
0005435683167	24577	Business	51100.00
0005435682750	24577	Business	51100.00
0005435683154	24577	Economy	17000.00
0005435682902	24577	Economy	17000.00
0005435661995	24577	Economy	17000.00
0005435719584	24577	Economy	17000.00
0005435683155	24577	Economy	17000.00
0005435682926	24577	Economy	18700.00
0005435682983	24577	Economy	18700.00
0005435682900	24577	Economy	17000.00
0005435683064	24577	Economy	17000.00
0005432533374	24577	Economy	17000.00
0005435661986	24577	Economy	17000.00
0005435720850	24577	Economy	17000.00
0005435683065	24577	Economy	17000.00
0005435682943	24577	Economy	17000.00
0005435682803	24577	Economy	17000.00
0005435438580	24577	Economy	17000.00
0005435682936	24577	Economy	17000.00
0005435719580	24577	Economy	17000.00
0005435438577	24577	Economy	17000.00
0005435683101	24577	Economy	17000.00
0005435438579	24577	Economy	17000.00
0005435682737	24577	Economy	17000.00
0005435682749	24577	Economy	17000.00
0005435682929	24577	Economy	17000.00
0005435682942	24577	Economy	17000.00
0005435683052	24577	Economy	17000.00
0005435438581	24577	Economy	17000.00
0005435438578	24577	Economy	17000.00
0005435683027	24577	Economy	17000.00
0005435682928	24577	Economy	17000.00
0005435682804	24577	Economy	17000.00
0005432533375	24577	Economy	17000.00
0005435683142	24577	Economy	17000.00
0005435683004	24577	Economy	17000.00
0005435683134	24577	Economy	17000.00
0005435682901	24577	Economy	17000.00
0005435682944	24577	Economy	17000.00
0005435682963	24577	Economy	17000.00
0005432533373	24577	Economy	17000.00
0005435661994	24577	Economy	17000.00
0005435683003	24577	Economy	17000.00
0005435682783	24577	Economy	17000.00
0005435438576	24577	Economy	17000.00
0005435683133	24577	Economy	17000.00
0005435438575	24577	Economy	17000.00
0005435720851	24577	Economy	17000.00
0005435631035	24577	Economy	17000.00
0005435682894	24577	Economy	17000.00
0005435683066	24577	Economy	17000.00
0005435558136	11555	Business	26400.00
0005435558148	11555	Business	26400.00
0005435127523	11555	Business	26400.00
0005435127503	11555	Business	26400.00
0005435558149	11555	Economy	8800.00
0005435127519	11555	Economy	8800.00
0005435127522	11555	Economy	8800.00
0005435558150	11555	Economy	8800.00
0005435098613	11555	Economy	8800.00
0005435127513	11555	Economy	8800.00
0005435098615	11555	Economy	8800.00
0005435127508	11555	Economy	8800.00
0005435127509	11555	Economy	9700.00
0005435127511	11555	Economy	9700.00
0005435106071	11555	Economy	8800.00
0005435127502	11555	Economy	8800.00
0005435127517	11555	Economy	8800.00
0005435127515	11555	Economy	8800.00
0005435127504	11555	Economy	8800.00
0005435127520	11555	Economy	8800.00
0005435098612	11555	Economy	8800.00
0005435106070	11555	Economy	8800.00
0005435127510	11555	Economy	8800.00
0005435127506	11555	Economy	8800.00
0005435127507	11555	Economy	8800.00
0005435098614	11555	Economy	8800.00
0005435558135	11555	Economy	8800.00
0005435127521	11555	Economy	8800.00
0005435127514	11555	Economy	8800.00
0005435127505	11555	Economy	8800.00
0005435098616	11555	Economy	8800.00
0005435127518	11555	Economy	8800.00
0005435127512	11555	Economy	8800.00
0005435127516	11555	Economy	8800.00
0005435127160	31891	Business	26400.00
0005435127029	31891	Business	26400.00
0005435127317	31891	Business	26400.00
0005435098601	31891	Business	26400.00
0005435127245	31891	Economy	8800.00
0005435127025	31891	Economy	8800.00
0005435127192	31891	Economy	8800.00
0005435127176	31891	Economy	9700.00
0005435127024	31891	Economy	9700.00
0005435127268	31891	Economy	9700.00
0005435098592	31891	Economy	9700.00
0005435127209	31891	Economy	8800.00
0005435106051	31891	Economy	8800.00
0005435127246	31891	Economy	8800.00
0005435098600	31891	Economy	8800.00
0005435127164	31891	Economy	8800.00
0005435127210	31891	Economy	8800.00
0005435127213	31891	Economy	8800.00
0005435106060	31891	Economy	8800.00
0005435127269	31891	Economy	8800.00
0005435127292	31891	Economy	8800.00
0005435127311	31891	Economy	8800.00
0005435127310	31891	Economy	8800.00
0005435127240	31891	Economy	8800.00
0005435127219	31891	Economy	8800.00
0005435127289	31891	Economy	8800.00
0005435106050	31891	Economy	8800.00
0005435127128	31891	Economy	8800.00
0005435127266	31891	Economy	8800.00
0005435106035	31891	Economy	8800.00
0005435127175	31891	Economy	8800.00
0005435098591	31891	Economy	8800.00
0005435098602	31891	Economy	8800.00
0005435127265	31891	Economy	8800.00
0005435127247	31891	Economy	8800.00
0005435106034	31891	Economy	8800.00
0005435127290	31891	Economy	8800.00
0005435127272	31891	Economy	8800.00
0005435127129	31891	Economy	8800.00
0005435127072	31891	Economy	8800.00
0005435127341	31891	Economy	8800.00
0005435127241	31891	Economy	8800.00
0005435127212	31891	Economy	8800.00
0005435106059	31891	Economy	8800.00
0005435127339	31891	Economy	8800.00
0005435127393	31891	Economy	8800.00
0005435127389	31891	Economy	8800.00
0005433399437	13507	Business	36600.00
0005433399424	13507	Business	36600.00
0005433399430	13507	Business	36600.00
0005433399429	13507	Business	36600.00
0005433399417	13507	Economy	12200.00
0005433399415	13507	Economy	12200.00
0005433399420	13507	Economy	12200.00
0005433399436	13507	Economy	12200.00
0005433399432	13507	Economy	12200.00
0005435732622	13507	Economy	13400.00
0005433399425	13507	Economy	12200.00
0005433399426	13507	Economy	12200.00
0005433399434	13507	Economy	12200.00
0005435732602	13507	Economy	12200.00
0005433399427	13507	Economy	12200.00
0005433399433	13507	Economy	12200.00
0005433399435	13507	Economy	12200.00
0005435732625	13507	Economy	12200.00
0005433399422	13507	Economy	12200.00
0005433399421	13507	Economy	12200.00
0005435732608	13507	Economy	12200.00
0005435732576	13507	Economy	12200.00
0005433399423	13507	Economy	12200.00
0005435732599	13507	Economy	12200.00
0005433399416	13507	Economy	12200.00
0005435732618	13507	Economy	12200.00
0005435732588	13507	Economy	12200.00
0005435732612	13507	Economy	12200.00
0005433399419	13507	Economy	12200.00
0005433399428	13507	Economy	12200.00
0005433399431	13507	Economy	12200.00
0005435732603	13507	Economy	12200.00
0005435732626	13507	Economy	12200.00
0005433399418	13507	Economy	12200.00
0005435732577	13507	Economy	12200.00
0005433399214	19396	Business	36600.00
0005433398975	19396	Business	36600.00
0005435725772	19396	Business	36600.00
0005433398891	19396	Business	36600.00
0005435732712	19396	Business	36600.00
0005433399106	19396	Business	36600.00
0005433398866	19396	Business	36600.00
0005435725767	19396	Business	36600.00
0005433399220	19396	Business	36600.00
0005435732707	19396	Economy	12200.00
0005433399203	19396	Economy	12200.00
0005433399254	19396	Economy	12200.00
0005433399110	19396	Economy	12200.00
0005433399034	19396	Economy	12200.00
0005433399094	19396	Economy	12200.00
0005433398977	19396	Economy	13400.00
0005435725773	19396	Economy	13400.00
0005433398865	19396	Economy	12200.00
0005435725768	19396	Economy	12200.00
0005433399091	19396	Economy	12200.00
0005433399000	19396	Economy	12200.00
0005435732709	19396	Economy	12200.00
0005432297352	19396	Economy	12200.00
0005433398919	19396	Economy	12200.00
0005435725769	19396	Economy	12200.00
0005433398913	19396	Economy	12200.00
0005433398914	19396	Economy	12200.00
0005435732710	19396	Economy	12200.00
0005433399080	19396	Economy	12200.00
0005435732703	19396	Economy	12200.00
0005433399036	19396	Economy	12200.00
0005435732705	19396	Economy	12200.00
0005433399221	19396	Economy	12200.00
0005433399172	19396	Economy	12200.00
0005433399090	19396	Economy	12200.00
0005433399219	19396	Economy	12200.00
0005433399010	19396	Economy	12200.00
0005433399123	19396	Economy	12200.00
0005435732711	19396	Economy	12200.00
0005433399154	19396	Economy	12200.00
0005433398976	19396	Economy	12200.00
0005433398994	19396	Economy	12200.00
0005435725771	19396	Economy	12200.00
0005435732704	19396	Economy	12200.00
0005435725770	19396	Economy	12200.00
0005433399002	19396	Economy	12200.00
0005433399153	19396	Economy	12200.00
0005433399171	19396	Economy	12200.00
0005433399258	19396	Economy	12200.00
0005433399089	19396	Economy	12200.00
0005435732713	19396	Economy	12200.00
0005435732706	19396	Economy	12200.00
0005433399063	19396	Economy	12200.00
0005433399173	19396	Economy	12200.00
0005433399068	19396	Economy	12200.00
0005433399109	19396	Economy	12200.00
0005435732708	19396	Economy	12200.00
0005435070291	13136	Business	11300.00
0005435070004	13136	Business	11300.00
0005435070065	13136	Business	11300.00
0005435070046	13136	Business	11300.00
0005435069884	13136	Business	11300.00
0005435070142	13136	Business	11300.00
0005435069958	13136	Business	11300.00
0005435070018	13136	Business	11300.00
0005435070187	13136	Business	11300.00
0005435070017	13136	Economy	3800.00
0005435070035	13136	Economy	3800.00
0005435069963	13136	Economy	3800.00
0005435070076	13136	Economy	3800.00
0005435070464	13136	Economy	3800.00
0005435925697	13136	Economy	3800.00
0005435070176	13136	Economy	3800.00
0005435069907	13136	Economy	4100.00
0005435070194	13136	Economy	4100.00
0005435070019	13136	Economy	4100.00
0005435070067	13136	Economy	3800.00
0005435070306	13136	Economy	3800.00
0005435070045	13136	Economy	3800.00
0005435070317	13136	Economy	3800.00
0005435070372	13136	Economy	3800.00
0005435070036	13136	Economy	3800.00
0005435070068	13136	Economy	3800.00
0005435070186	13136	Economy	3800.00
0005435925694	13136	Economy	3800.00
0005435925698	13136	Economy	3800.00
0005435925699	13136	Economy	3800.00
0005435070164	13136	Economy	3800.00
0005435070463	13136	Economy	3800.00
0005435070318	13136	Economy	3800.00
0005435070097	13136	Economy	3800.00
0005435069971	13136	Economy	3800.00
0005435925701	13136	Economy	3800.00
0005435070126	13136	Economy	3800.00
0005435070133	13136	Economy	3800.00
0005435070028	13136	Economy	3800.00
0005435069970	13136	Economy	3800.00
0005435925691	13136	Economy	3800.00
0005435070441	13136	Economy	3800.00
0005435070005	13136	Economy	3800.00
0005435925692	13136	Economy	3800.00
0005435070118	13136	Economy	3800.00
0005435925696	13136	Economy	3800.00
0005435925695	13136	Economy	3800.00
0005435069972	13136	Economy	3800.00
0005435070188	13136	Economy	3800.00
0005435070290	13136	Economy	3800.00
0005435070307	13136	Economy	3800.00
0005435070166	13136	Economy	3800.00
0005435070096	13136	Economy	3800.00
0005435070169	13136	Economy	3800.00
0005435925700	13136	Economy	3800.00
0005435070152	13136	Economy	3800.00
0005435070226	13136	Economy	3800.00
0005435070058	13136	Economy	3800.00
0005435070012	13136	Economy	3800.00
0005435925702	13136	Economy	3800.00
0005435069906	13136	Economy	3800.00
0005435070268	13136	Economy	3800.00
0005435069964	13136	Economy	3800.00
0005435069883	13136	Economy	3800.00
0005435070244	13136	Economy	3800.00
0005435070029	13136	Economy	3800.00
0005435070267	13136	Economy	3800.00
0005435070006	13136	Economy	3800.00
0005435069957	13136	Economy	3800.00
0005435070353	13136	Economy	3800.00
0005435925693	13136	Economy	3800.00
0005435070117	13136	Economy	3800.00
0005435070066	13136	Economy	3800.00
0005435070064	13136	Economy	3800.00
0005435070125	13136	Economy	3800.00
0005435070175	13136	Economy	3800.00
0005435070072	13136	Economy	3800.00
0005435070496	15492	Business	11300.00
0005435925550	15492	Business	11300.00
0005435070504	15492	Business	11300.00
0005435925596	15492	Business	11300.00
0005435925607	15492	Business	11300.00
0005435925538	15492	Economy	3800.00
0005435070511	15492	Economy	3800.00
0005435070502	15492	Economy	3800.00
0005435070509	15492	Economy	3800.00
0005435070498	15492	Economy	3800.00
0005435925547	15492	Economy	3800.00
0005435070518	15492	Economy	4100.00
0005435070517	15492	Economy	4100.00
0005435070499	15492	Economy	3800.00
0005435070515	15492	Economy	3800.00
0005435070508	15492	Economy	3800.00
0005435925551	15492	Economy	3800.00
0005435925563	15492	Economy	3800.00
0005435070513	15492	Economy	3800.00
0005435925546	15492	Economy	3800.00
0005435925534	15492	Economy	3800.00
0005435070514	15492	Economy	3800.00
0005435070516	15492	Economy	3800.00
0005435070500	15492	Economy	3800.00
0005435070512	15492	Economy	3800.00
0005435070503	15492	Economy	3800.00
0005435925566	15492	Economy	3800.00
0005435070507	15492	Economy	3800.00
0005435070510	15492	Economy	3800.00
0005435070497	15492	Economy	3800.00
0005435070505	15492	Economy	3800.00
0005435070501	15492	Economy	3800.00
0005435070506	15492	Economy	3800.00
0005435808419	29488	Economy	27100.00
0005433407709	29488	Economy	24700.00
0005435808464	29488	Economy	24700.00
0005435808454	29488	Economy	24700.00
0005433407708	29488	Economy	24700.00
0005435808421	29488	Economy	24700.00
0005435808390	29488	Economy	24700.00
0005435808423	29488	Economy	24700.00
0005435808403	29488	Economy	24700.00
0005435808429	29488	Economy	24700.00
0005435808422	29488	Economy	24700.00
0005433407707	29488	Economy	24700.00
0005435808420	29488	Economy	24700.00
0005435808430	29488	Economy	24700.00
0005435808465	29488	Economy	24700.00
0005435808412	29488	Economy	24700.00
0005434757253	10692	Business	61300.00
0005434215860	10692	Business	61300.00
0005434215850	10692	Business	61300.00
0005434757281	10692	Business	61300.00
0005434757238	10692	Business	61300.00
0005434757295	10692	Business	61300.00
0005434757241	10692	Business	61300.00
0005434757323	10692	Economy	20400.00
0005434757101	10692	Economy	20400.00
0005434757117	10692	Economy	20400.00
0005434215854	10692	Economy	20400.00
0005434215856	10692	Economy	20400.00
0005434757263	10692	Economy	20400.00
0005434757237	10692	Economy	20400.00
0005434757255	10692	Economy	20400.00
0005434215853	10692	Economy	22500.00
0005434215858	10692	Economy	22500.00
0005434757296	10692	Economy	22500.00
0005434757204	10692	Economy	22500.00
0005434215863	10692	Economy	20400.00
0005434757228	10692	Economy	20400.00
0005434215857	10692	Economy	20400.00
0005434757242	10692	Economy	20400.00
0005434215846	10692	Economy	20400.00
0005434757184	10692	Economy	20400.00
0005434215849	10692	Economy	20400.00
0005434757173	10692	Economy	20400.00
0005434215862	10692	Economy	20400.00
0005434757320	10692	Economy	20400.00
0005434757232	10692	Economy	20400.00
0005434757259	10692	Economy	20400.00
0005434215864	10692	Economy	20400.00
0005434757300	10692	Economy	20400.00
0005434757193	10692	Economy	20400.00
0005434215847	10692	Economy	20400.00
0005434215852	10692	Economy	20400.00
0005434757282	10692	Economy	20400.00
0005434757254	10692	Economy	20400.00
0005434757100	10692	Economy	20400.00
0005434757197	10692	Economy	20400.00
0005434215855	10692	Economy	20400.00
0005434215851	10692	Economy	20400.00
0005434757301	10692	Economy	20400.00
0005434215861	10692	Economy	20400.00
0005434757178	10692	Economy	20400.00
0005434757292	10692	Economy	20400.00
0005434215859	10692	Economy	20400.00
0005434757256	10692	Economy	20400.00
0005434757284	10692	Economy	20400.00
0005434757236	10692	Economy	20400.00
0005434215845	10692	Economy	20400.00
0005434757202	10692	Economy	20400.00
0005434215848	10692	Economy	20400.00
0005434757262	10692	Economy	20400.00
0005434757302	10692	Economy	20400.00
0005434757291	10692	Economy	20400.00
0005434757118	10692	Economy	20400.00
0005434757235	10692	Economy	20400.00
0005434757374	10692	Economy	20400.00
0005434757611	28695	Business	61300.00
0005434757622	28695	Business	61300.00
0005434215348	28695	Business	61300.00
0005434757596	28695	Business	61300.00
0005434757600	28695	Business	61300.00
0005434215215	28695	Business	61300.00
0005434757621	28695	Business	61300.00
0005434215472	28695	Business	61300.00
0005434215628	28695	Business	61300.00
0005434757613	28695	Economy	20400.00
0005434757618	28695	Economy	20400.00
0005434215544	28695	Economy	20400.00
0005434215090	28695	Economy	20400.00
0005434757608	28695	Economy	20400.00
0005434757624	28695	Economy	20400.00
0005434757612	28695	Economy	22500.00
0005434215275	28695	Economy	22500.00
0005434757616	28695	Economy	22500.00
0005434215428	28695	Economy	22500.00
0005434215367	28695	Economy	22500.00
0005434215531	28695	Economy	20400.00
0005434757606	28695	Economy	20400.00
0005434215454	28695	Economy	20400.00
0005434215630	28695	Economy	20400.00
0005434757599	28695	Economy	20400.00
0005434215596	28695	Economy	20400.00
0005434215425	28695	Economy	20400.00
0005434757609	28695	Economy	20400.00
0005434215516	28695	Economy	20400.00
0005434757597	28695	Economy	20400.00
0005434215244	28695	Economy	20400.00
0005434215541	28695	Economy	20400.00
0005434215424	28695	Economy	20400.00
0005434215692	28695	Economy	20400.00
0005434215300	28695	Economy	20400.00
0005434215421	28695	Economy	20400.00
0005434215240	28695	Economy	20400.00
0005434215423	28695	Economy	20400.00
0005434215241	28695	Economy	20400.00
0005434215636	28695	Economy	20400.00
0005434757623	28695	Economy	20400.00
0005434757619	28695	Economy	20400.00
0005434757617	28695	Economy	20400.00
0005434215470	28695	Economy	20400.00
0005434757607	28695	Economy	20400.00
0005434757605	28695	Economy	20400.00
0005434215471	28695	Economy	20400.00
0005434215629	28695	Economy	20400.00
0005434215369	28695	Economy	20400.00
0005434757620	28695	Economy	20400.00
0005434215380	28695	Economy	20400.00
0005434215436	28695	Economy	20400.00
0005434215242	28695	Economy	20400.00
0005434215217	28695	Economy	20400.00
0005434215473	28695	Economy	20400.00
0005434757604	28695	Economy	20400.00
0005434215347	28695	Economy	20400.00
0005434215416	28695	Economy	20400.00
0005434215309	28695	Economy	20400.00
0005434757602	28695	Economy	20400.00
0005434215496	28695	Economy	20400.00
0005434215553	28695	Economy	20400.00
0005434757614	28695	Economy	20400.00
0005434757598	28695	Economy	20400.00
0005434757610	28695	Economy	20400.00
0005434757615	28695	Economy	20400.00
0005434757603	28695	Economy	20400.00
0005434757601	28695	Economy	20400.00
0005434215543	28695	Economy	20400.00
0005434215362	28695	Economy	20400.00
0005434215542	28695	Economy	20400.00
0005434215216	28695	Economy	20400.00
0005434229813	5481	Business	29500.00
0005435007706	5481	Business	29500.00
0005432125658	5481	Business	29500.00
0005435007702	5481	Business	29500.00
0005435041644	5481	Business	29500.00
0005435007694	5481	Business	29500.00
0005434229870	5481	Business	29500.00
0005435041617	5481	Economy	9800.00
0005435041618	5481	Economy	9800.00
0005435007700	5481	Economy	9800.00
0005434229762	5481	Economy	9800.00
0005434229844	5481	Economy	9800.00
0005435041631	5481	Economy	9800.00
0005435041635	5481	Economy	9800.00
0005434229837	5481	Economy	9800.00
0005434229927	5481	Economy	9800.00
0005434229836	5481	Economy	9800.00
0005434229814	5481	Economy	9800.00
0005435041623	5481	Economy	9800.00
0005435007696	5481	Economy	9800.00
0005434229828	5481	Economy	9800.00
0005435041628	5481	Economy	9800.00
0005435041630	5481	Economy	9800.00
0005435041627	5481	Economy	9800.00
0005435377922	5481	Economy	9800.00
0005435041646	5481	Economy	9800.00
0005435041649	5481	Economy	9800.00
0005435041633	5481	Economy	9800.00
0005434229928	5481	Economy	10800.00
0005435041624	5481	Economy	10800.00
0005434229871	5481	Economy	10800.00
0005435041625	5481	Economy	10800.00
0005435007695	5481	Economy	10800.00
0005435007693	5481	Economy	10800.00
0005434229812	5481	Economy	9800.00
0005434229906	5481	Economy	9800.00
0005435377921	5481	Economy	9800.00
0005435041626	5481	Economy	9800.00
0005435041634	5481	Economy	9800.00
0005434229815	5481	Economy	9800.00
0005434229843	5481	Economy	9800.00
0005435041643	5481	Economy	9800.00
0005435041641	5481	Economy	9800.00
0005435041645	5481	Economy	9800.00
0005435007701	5481	Economy	9800.00
0005432125657	5481	Economy	9800.00
0005435007705	5481	Economy	9800.00
0005435007697	5481	Economy	9800.00
0005435041640	5481	Economy	9800.00
0005435041637	5481	Economy	9800.00
0005435041642	5481	Economy	9800.00
0005435007703	5481	Economy	9800.00
0005435007704	5481	Economy	9800.00
0005435041629	5481	Economy	9800.00
0005435041620	5481	Economy	9800.00
0005435041621	5481	Economy	9800.00
0005434229797	5481	Economy	9800.00
0005435007698	5481	Economy	9800.00
0005434229882	5481	Economy	9800.00
0005435041622	5481	Economy	9800.00
0005434229825	5481	Economy	9800.00
0005435041632	5481	Economy	9800.00
0005435041638	5481	Economy	9800.00
0005434229786	5481	Economy	9800.00
0005434229817	5481	Economy	9800.00
0005434229785	5481	Economy	9800.00
0005435007692	5481	Economy	9800.00
0005435041619	5481	Economy	9800.00
0005434229874	5481	Economy	9800.00
0005435041647	5481	Economy	9800.00
0005435041648	5481	Economy	9800.00
0005435041639	5481	Economy	9800.00
0005435041636	5481	Economy	9800.00
0005434229804	5481	Economy	9800.00
0005435007699	5481	Economy	9800.00
0005435377916	5481	Economy	9800.00
0005434229816	5481	Economy	9800.00
0005434229847	5481	Economy	9800.00
0005435041193	12960	Business	29500.00
0005435007479	12960	Business	29500.00
0005435377968	12960	Business	29500.00
0005435040664	12960	Business	29500.00
0005435007445	12960	Business	29500.00
0005435007599	12960	Business	29500.00
0005435007428	12960	Business	29500.00
0005435735281	12960	Business	29500.00
0005435041088	12960	Business	29500.00
0005435041069	12960	Business	29500.00
0005435007521	12960	Business	29500.00
0005435007553	12960	Economy	9800.00
0005435041192	12960	Economy	9800.00
0005435007495	12960	Economy	9800.00
0005435041178	12960	Economy	9800.00
0005435041319	12960	Economy	9800.00
0005435041305	12960	Economy	9800.00
0005435041208	12960	Economy	9800.00
0005435377954	12960	Economy	9800.00
0005435040803	12960	Economy	9800.00
0005435556767	12960	Economy	9800.00
0005435377955	12960	Economy	9800.00
0005435377965	12960	Economy	9800.00
0005434230020	12960	Economy	9800.00
0005435041097	12960	Economy	9800.00
0005435041046	12960	Economy	9800.00
0005435007481	12960	Economy	9800.00
0005435041070	12960	Economy	9800.00
0005435007478	12960	Economy	9800.00
0005435041203	12960	Economy	9800.00
0005435041223	12960	Economy	9800.00
0005435041121	12960	Economy	9800.00
0005435041258	12960	Economy	9800.00
0005434230019	12960	Economy	9800.00
0005435041209	12960	Economy	9800.00
0005435040973	12960	Economy	9800.00
0005435556769	12960	Economy	9800.00
0005435041071	12960	Economy	9800.00
0005435377967	12960	Economy	9800.00
0005435041168	12960	Economy	9800.00
0005435041134	12960	Economy	9800.00
0005435377959	12960	Economy	9800.00
0005435041318	12960	Economy	9800.00
0005435007578	12960	Economy	9800.00
0005435041216	12960	Economy	9800.00
0005435377957	12960	Economy	9800.00
0005435007519	12960	Economy	9800.00
0005435007517	12960	Economy	9800.00
0005434230011	12960	Economy	9800.00
0005435041130	12960	Economy	10800.00
0005435041179	12960	Economy	10800.00
0005435040886	12960	Economy	10800.00
0005435007499	12960	Economy	10800.00
0005434230015	12960	Economy	10800.00
0005435007507	12960	Economy	9800.00
0005435041240	12960	Economy	9800.00
0005435377963	12960	Economy	9800.00
0005435042915	12960	Economy	9800.00
0005435377961	12960	Economy	9800.00
0005435041068	12960	Economy	9800.00
0005435041382	12960	Economy	9800.00
0005435007565	12960	Economy	9800.00
0005435040876	12960	Economy	9800.00
0005435007513	12960	Economy	9800.00
0005434230016	12960	Economy	9800.00
0005435377964	12960	Economy	9800.00
0005435007532	12960	Economy	9800.00
0005435007437	12960	Economy	9800.00
0005435041067	12960	Economy	9800.00
0005435007515	12960	Economy	9800.00
0005435040875	12960	Economy	9800.00
0005435041215	12960	Economy	9800.00
0005435377958	12960	Economy	9800.00
0005434230021	12960	Economy	9800.00
0005435041163	12960	Economy	9800.00
0005434230018	12960	Economy	9800.00
0005435377960	12960	Economy	9800.00
0005434230013	12960	Economy	9800.00
0005435007600	12960	Economy	9800.00
0005435042898	12960	Economy	9800.00
0005435040885	12960	Economy	9800.00
0005435007494	12960	Economy	9800.00
0005435007563	12960	Economy	9800.00
0005435041098	12960	Economy	9800.00
0005435040815	12960	Economy	9800.00
0005435007496	12960	Economy	9800.00
0005435007429	12960	Economy	9800.00
0005435040968	12960	Economy	9800.00
0005435041047	12960	Economy	9800.00
0005435377962	12960	Economy	9800.00
0005435042902	12960	Economy	9800.00
0005435007591	12960	Economy	9800.00
0005435041175	12960	Economy	9800.00
0005435556768	12960	Economy	9800.00
0005435041176	12960	Economy	9800.00
0005435040967	12960	Economy	9800.00
0005435041075	12960	Economy	9800.00
0005435735282	12960	Economy	9800.00
0005435377956	12960	Economy	9800.00
0005435007598	12960	Economy	9800.00
0005435041235	12960	Economy	9800.00
0005435007493	12960	Economy	9800.00
0005435042916	12960	Economy	9800.00
0005434230012	12960	Economy	9800.00
0005435041296	12960	Economy	9800.00
0005435041437	12960	Economy	9800.00
0005435007514	12960	Economy	9800.00
0005435007520	12960	Economy	9800.00
0005435735280	12960	Economy	9800.00
0005435007482	12960	Economy	9800.00
0005434230017	12960	Economy	9800.00
0005435041133	12960	Economy	9800.00
0005435041191	12960	Economy	9800.00
0005434230014	12960	Economy	9800.00
0005435377966	12960	Economy	9800.00
0005435041443	12960	Economy	9800.00
0005435007592	12960	Economy	9800.00
0005434427423	14849	Business	52900.00
0005434411895	14849	Business	52900.00
0005434427440	14849	Business	52900.00
0005434427435	14849	Business	52900.00
0005434427428	14849	Business	52900.00
0005434427437	14849	Business	52900.00
0005435554290	14849	Economy	17600.00
0005434427425	14849	Economy	17600.00
0005435903077	14849	Economy	17600.00
0005435903025	14849	Economy	17600.00
0005432188700	14849	Economy	17600.00
0005435903104	14849	Economy	17600.00
0005435554300	14849	Economy	17600.00
0005435554278	14849	Economy	19400.00
0005435902985	14849	Economy	19400.00
0005434427439	14849	Economy	17600.00
0005434427438	14849	Economy	17600.00
0005434427424	14849	Economy	17600.00
0005435903100	14849	Economy	17600.00
0005435902954	14849	Economy	17600.00
0005434427426	14849	Economy	17600.00
0005434427433	14849	Economy	17600.00
0005435903064	14849	Economy	17600.00
0005435903054	14849	Economy	17600.00
0005435903101	14849	Economy	17600.00
0005435903093	14849	Economy	17600.00
0005434427422	14849	Economy	17600.00
0005435554271	14849	Economy	17600.00
0005434427431	14849	Economy	17600.00
0005434427436	14849	Economy	17600.00
0005435902952	14849	Economy	17600.00
0005434427427	14849	Economy	17600.00
0005435554291	14849	Economy	17600.00
0005434427430	14849	Economy	17600.00
0005434427432	14849	Economy	17600.00
0005435902953	14849	Economy	17600.00
0005435903028	14849	Economy	17600.00
0005434427429	14849	Economy	17600.00
0005434427434	14849	Economy	17600.00
0005435554301	14849	Economy	17600.00
0005435903078	14849	Economy	17600.00
0005434411896	14849	Economy	17600.00
0005435902986	14849	Economy	17600.00
0005435903091	14849	Economy	17600.00
0005435903035	14849	Economy	17600.00
0005434411894	14849	Economy	17600.00
0005435554270	14849	Economy	17600.00
0005432188699	14849	Economy	17600.00
0005435903065	14849	Economy	17600.00
0005434427300	20180	Business	52900.00
0005434427269	20180	Business	52900.00
0005435554327	20180	Business	52900.00
0005434427148	20180	Business	52900.00
0005434427077	20180	Business	52900.00
0005434427170	20180	Business	52900.00
0005434427257	20180	Economy	17600.00
0005434427235	20180	Economy	17600.00
0005434427339	20180	Economy	17600.00
0005434427152	20180	Economy	17600.00
0005434427210	20180	Economy	17600.00
0005435903214	20180	Economy	19400.00
0005435903210	20180	Economy	19400.00
0005434427240	20180	Economy	19400.00
0005434427272	20180	Economy	19400.00
0005435903208	20180	Economy	17600.00
0005434427282	20180	Economy	17600.00
0005434427212	20180	Economy	17600.00
0005434427214	20180	Economy	17600.00
0005434427271	20180	Economy	17600.00
0005435554324	20180	Economy	17600.00
0005434427260	20180	Economy	17600.00
0005435554326	20180	Economy	17600.00
0005435903211	20180	Economy	17600.00
0005434427256	20180	Economy	17600.00
0005434427165	20180	Economy	17600.00
0005434427118	20180	Economy	17600.00
0005434427241	20180	Economy	17600.00
0005435903206	20180	Economy	17600.00
0005434427122	20180	Economy	17600.00
0005434427123	20180	Economy	17600.00
0005434411877	20180	Economy	17600.00
0005435903212	20180	Economy	17600.00
0005434427387	20180	Economy	17600.00
0005434427125	20180	Economy	17600.00
0005434427281	20180	Economy	17600.00
0005434427291	20180	Economy	17600.00
0005434427289	20180	Economy	17600.00
0005434427187	20180	Economy	17600.00
0005434427147	20180	Economy	17600.00
0005435903207	20180	Economy	17600.00
0005434427213	20180	Economy	17600.00
0005434411878	20180	Economy	17600.00
0005434427275	20180	Economy	17600.00
0005434427290	20180	Economy	17600.00
0005435903205	20180	Economy	17600.00
0005435554325	20180	Economy	17600.00
0005435903213	20180	Economy	17600.00
0005434427178	20180	Economy	17600.00
0005434427236	20180	Economy	17600.00
0005434427338	20180	Economy	17600.00
0005434427253	20180	Economy	17600.00
0005434427177	20180	Economy	17600.00
0005434427232	20180	Economy	17600.00
0005434427276	20180	Economy	17600.00
0005434427124	20180	Economy	17600.00
0005434427146	20180	Economy	17600.00
0005435903209	20180	Economy	17600.00
0005434427145	20180	Economy	17600.00
0005433435299	26515	Business	18500.00
0005435983594	26515	Business	18500.00
0005435983590	26515	Business	18500.00
0005433435237	26515	Business	18500.00
0005435983581	26515	Business	18500.00
0005432300429	26515	Business	18500.00
0005433435285	26515	Business	18500.00
0005435983589	26515	Economy	6200.00
0005433435201	26515	Economy	6200.00
0005433435188	26515	Economy	6200.00
0005435983608	26515	Economy	6200.00
0005435983593	26515	Economy	6800.00
0005435983611	26515	Economy	6800.00
0005434270255	26515	Economy	6800.00
0005435983605	26515	Economy	6800.00
0005435983598	26515	Economy	6800.00
0005433435210	26515	Economy	6200.00
0005433435295	26515	Economy	6200.00
0005435983602	26515	Economy	6200.00
0005435983585	26515	Economy	6200.00
0005432300427	26515	Economy	6200.00
0005433435274	26515	Economy	6200.00
0005435983600	26515	Economy	6200.00
0005433435193	26515	Economy	6200.00
0005435983614	26515	Economy	6200.00
0005433435283	26515	Economy	6200.00
0005433435208	26515	Economy	6200.00
0005435983613	26515	Economy	6200.00
0005433435221	26515	Economy	6200.00
0005434270256	26515	Economy	6200.00
0005433435284	26515	Economy	6200.00
0005433435290	26515	Economy	6200.00
0005435983601	26515	Economy	6200.00
0005435983595	26515	Economy	6200.00
0005433435219	26515	Economy	6200.00
0005433435298	26515	Economy	6200.00
0005433435256	26515	Economy	6200.00
0005434270254	26515	Economy	6200.00
0005435983612	26515	Economy	6200.00
0005433435192	26515	Economy	6200.00
0005435983606	26515	Economy	6200.00
0005435983583	26515	Economy	6200.00
0005435983584	26515	Economy	6200.00
0005433435132	26515	Economy	6200.00
0005432300430	26515	Economy	6200.00
0005433435246	26515	Economy	6200.00
0005433435334	26515	Economy	6200.00
0005432300428	26515	Economy	6200.00
0005433435209	26515	Economy	6200.00
0005435983588	26515	Economy	6200.00
0005435983603	26515	Economy	6200.00
0005433435296	26515	Economy	6200.00
0005433435102	26515	Economy	6200.00
0005435983596	26515	Economy	6200.00
0005435983604	26515	Economy	6200.00
0005435983586	26515	Economy	6200.00
0005433435245	26515	Economy	6200.00
0005435983587	26515	Economy	6200.00
0005435983591	26515	Economy	6200.00
0005435983597	26515	Economy	6200.00
0005435983582	26515	Economy	6200.00
0005435983609	26515	Economy	6200.00
0005435983592	26515	Economy	6200.00
0005435983607	26515	Economy	6200.00
0005435983599	26515	Economy	6200.00
0005435983610	26515	Economy	6200.00
0005434269164	26724	Business	18500.00
0005435983395	26724	Business	18500.00
0005435983099	26724	Business	18500.00
0005435983208	26724	Business	18500.00
0005434271374	26724	Business	18500.00
0005435983100	26724	Business	18500.00
0005433435483	26724	Business	18500.00
0005435983101	26724	Business	18500.00
0005435983246	26724	Business	18500.00
0005435983242	26724	Economy	6200.00
0005435983394	26724	Economy	6200.00
0005433435478	26724	Economy	6200.00
0005434271373	26724	Economy	6200.00
0005433435473	26724	Economy	6200.00
0005433435477	26724	Economy	6200.00
0005435983263	26724	Economy	6200.00
0005435983332	26724	Economy	6800.00
0005433435471	26724	Economy	6800.00
0005435983207	26724	Economy	6800.00
0005435983167	26724	Economy	6800.00
0005434269163	26724	Economy	6200.00
0005435983287	26724	Economy	6200.00
0005435983262	26724	Economy	6200.00
0005435983243	26724	Economy	6200.00
0005435983327	26724	Economy	6200.00
0005435983159	26724	Economy	6200.00
0005433435484	26724	Economy	6200.00
0005435983180	26724	Economy	6200.00
0005433435485	26724	Economy	6200.00
0005435983318	26724	Economy	6200.00
0005435983269	26724	Economy	6200.00
0005433435474	26724	Economy	6200.00
0005433435479	26724	Economy	6200.00
0005435983345	26724	Economy	6200.00
0005433435481	26724	Economy	6200.00
0005435983124	26724	Economy	6200.00
0005435983190	26724	Economy	6200.00
0005435983125	26724	Economy	6200.00
0005435983158	26724	Economy	6200.00
0005435983266	26724	Economy	6200.00
0005435983267	26724	Economy	6200.00
0005435983270	26724	Economy	6200.00
0005435983257	26724	Economy	6200.00
0005435983265	26724	Economy	6200.00
0005435983344	26724	Economy	6200.00
0005435983204	26724	Economy	6200.00
0005435983379	26724	Economy	6200.00
0005433435480	26724	Economy	6200.00
0005433435482	26724	Economy	6200.00
0005435983017	26724	Economy	6200.00
0005435983103	26724	Economy	6200.00
0005435983056	26724	Economy	6200.00
0005435983128	26724	Economy	6200.00
0005433435475	26724	Economy	6200.00
0005433435470	26724	Economy	6200.00
0005433435472	26724	Economy	6200.00
0005435983279	26724	Economy	6200.00
0005435983490	26724	Economy	6200.00
0005435983104	26724	Economy	6200.00
0005435983216	26724	Economy	6200.00
0005433435476	26724	Economy	6200.00
0005435983228	26724	Economy	6200.00
0005435983218	26724	Economy	6200.00
0005435983018	26724	Economy	6200.00
0005435983121	26724	Economy	6200.00
0005435983317	26724	Economy	6200.00
0005435983184	26724	Economy	6200.00
0005435983107	26724	Economy	6200.00
0005435983209	26724	Economy	6200.00
0005435983055	26724	Economy	6200.00
0005432584759	3159	Economy	11100.00
0005432584756	3159	Economy	11100.00
0005432584760	3159	Economy	10100.00
0005432858320	3159	Economy	10100.00
0005432858381	3159	Economy	10100.00
0005432584758	3159	Economy	10100.00
0005432584761	3159	Economy	10100.00
0005432858321	3159	Economy	10100.00
0005432858333	3159	Economy	10100.00
0005432584757	3159	Economy	10100.00
0005432858332	3159	Economy	10100.00
0005432584754	3159	Economy	10100.00
0005432858300	3159	Economy	10100.00
0005432858329	3159	Economy	10100.00
0005432584755	3159	Economy	10100.00
0005432858322	3159	Economy	10100.00
0005432584617	31485	Economy	11100.00
0005432584567	31485	Economy	11100.00
0005432584703	31485	Economy	11100.00
0005432584616	31485	Economy	10100.00
0005432858400	31485	Economy	10100.00
0005432584583	31485	Economy	10100.00
0005432584491	31485	Economy	10100.00
0005432584649	31485	Economy	10100.00
0005432584615	31485	Economy	10100.00
0005432584530	31485	Economy	10100.00
0005432584552	31485	Economy	10100.00
0005432584591	31485	Economy	10100.00
0005432584640	31485	Economy	10100.00
0005432584697	31485	Economy	10100.00
0005432858403	31485	Economy	10100.00
0005432584551	31485	Economy	10100.00
0005432584618	31485	Economy	10100.00
0005432584529	31485	Economy	10100.00
0005432584531	31485	Economy	10100.00
0005432584532	31485	Economy	10100.00
0005432584614	31485	Economy	10100.00
0005432584613	31485	Economy	10100.00
0005432584636	31485	Economy	10100.00
0005432858402	31485	Economy	10100.00
0005432584688	31485	Economy	10100.00
0005432584582	31485	Economy	10100.00
0005432584705	31485	Economy	10100.00
0005432584693	31485	Economy	10100.00
0005432584555	31485	Economy	10100.00
0005432584612	31485	Economy	10100.00
0005432584517	31485	Economy	10100.00
0005432584622	31485	Economy	10100.00
0005432584566	31485	Economy	10100.00
0005432584641	31485	Economy	10100.00
0005432858401	31485	Economy	10100.00
0005432584704	31485	Economy	10100.00
0005432584597	31485	Economy	10100.00
0005432858404	31485	Economy	10100.00
0005432858399	31485	Economy	10100.00
0005432584556	31485	Economy	10100.00
0005432584621	31485	Economy	10100.00
0005432584516	31485	Economy	10100.00
0005432584505	31485	Economy	10100.00
0005432584698	31485	Economy	10100.00
0005433255244	911	Economy	7500.00
0005434943613	911	Economy	7500.00
0005433255228	911	Economy	7500.00
0005433255242	911	Economy	7500.00
0005434943611	911	Economy	7500.00
0005434943610	911	Economy	7500.00
0005433255215	911	Economy	7500.00
0005433255243	911	Economy	7500.00
0005434943612	911	Economy	7500.00
0005433255268	16214	Economy	8300.00
0005433255269	16214	Economy	8300.00
0005434943523	16214	Economy	7500.00
0005434943583	16214	Economy	7500.00
0005433255270	16214	Economy	7500.00
0005434943568	16214	Economy	7500.00
0005434943569	16214	Economy	7500.00
0005434943584	16214	Economy	7500.00
0005435858633	4320	Business	90500.00
0005433654971	4320	Business	90500.00
0005433654974	4320	Business	90500.00
0005435858645	4320	Business	90500.00
0005433654983	4320	Business	90500.00
0005435858653	4320	Economy	30200.00
0005433654975	4320	Economy	30200.00
0005433654976	4320	Economy	30200.00
0005433654978	4320	Economy	30200.00
0005433654969	4320	Economy	30200.00
0005433654982	4320	Economy	30200.00
0005435858630	4320	Economy	33200.00
0005433654981	4320	Economy	33200.00
0005435858649	4320	Economy	30200.00
0005435858638	4320	Economy	30200.00
0005435858618	4320	Economy	30200.00
0005433654972	4320	Economy	30200.00
0005433654970	4320	Economy	30200.00
0005435858636	4320	Economy	30200.00
0005435858629	4320	Economy	30200.00
0005435858647	4320	Economy	30200.00
0005435858637	4320	Economy	30200.00
0005435858646	4320	Economy	30200.00
0005433654979	4320	Economy	30200.00
0005435858648	4320	Economy	30200.00
0005435858632	4320	Economy	30200.00
0005433654980	4320	Economy	30200.00
0005433654973	4320	Economy	30200.00
0005433654984	4320	Economy	30200.00
0005435858652	4320	Economy	30200.00
0005433654977	4320	Economy	30200.00
0005435858654	4320	Economy	30200.00
0005435858631	4320	Economy	30200.00
0005435858615	4320	Economy	30200.00
0005433811662	14400	Economy	4400.00
0005433811668	14400	Economy	4400.00
0005433811678	14400	Economy	4400.00
0005433811679	14400	Economy	4400.00
0005433811667	14400	Economy	4400.00
0005435654367	21766	Business	9800.00
0005435654375	21766	Business	9800.00
0005433368768	21766	Business	9800.00
0005435654387	21766	Business	9800.00
0005435654402	21766	Business	9800.00
0005433368533	21766	Business	9800.00
0005435654393	21766	Business	9800.00
0005433368633	21766	Business	9800.00
0005435654365	21766	Business	9800.00
0005433368750	21766	Business	9800.00
0005435654357	21766	Business	9800.00
0005435654358	21766	Economy	3300.00
0005433368610	21766	Economy	3300.00
0005435654372	21766	Economy	3300.00
0005433368597	21766	Economy	3300.00
0005433368700	21766	Economy	3300.00
0005435654386	21766	Economy	3300.00
0005435654401	21766	Economy	3300.00
0005435654379	21766	Economy	3300.00
0005435654360	21766	Economy	3600.00
0005435654361	21766	Economy	3600.00
0005435654366	21766	Economy	3600.00
0005433368723	21766	Economy	3600.00
0005435654405	21766	Economy	3600.00
0005435654370	21766	Economy	3300.00
0005435654376	21766	Economy	3300.00
0005435654355	21766	Economy	3300.00
0005435654385	21766	Economy	3300.00
0005435654374	21766	Economy	3300.00
0005435654362	21766	Economy	3300.00
0005435654368	21766	Economy	3300.00
0005433368482	21766	Economy	3300.00
0005435654388	21766	Economy	3300.00
0005435654404	21766	Economy	3300.00
0005435654359	21766	Economy	3300.00
0005433368609	21766	Economy	3300.00
0005435654377	21766	Economy	3300.00
0005435654395	21766	Economy	3300.00
0005433368483	21766	Economy	3300.00
0005433368712	21766	Economy	3300.00
0005433368558	21766	Economy	3300.00
0005433368476	21766	Economy	3300.00
0005435654397	21766	Economy	3300.00
0005435654391	21766	Economy	3300.00
0005433368611	21766	Economy	3300.00
0005433368637	21766	Economy	3300.00
0005435654363	21766	Economy	3300.00
0005433368581	21766	Economy	3300.00
0005433368532	21766	Economy	3300.00
0005433368475	21766	Economy	3300.00
0005435654390	21766	Economy	3300.00
0005435654380	21766	Economy	3300.00
0005435654396	21766	Economy	3300.00
0005433368665	21766	Economy	3300.00
0005433368528	21766	Economy	3300.00
0005435654381	21766	Economy	3300.00
0005435654389	21766	Economy	3300.00
0005435654392	21766	Economy	3300.00
0005433368671	21766	Economy	3300.00
0005435654382	21766	Economy	3300.00
0005433368636	21766	Economy	3300.00
0005435654399	21766	Economy	3300.00
0005433368754	21766	Economy	3300.00
0005433368632	21766	Economy	3300.00
0005435654398	21766	Economy	3300.00
0005435654384	21766	Economy	3300.00
0005435654369	21766	Economy	3300.00
0005435654403	21766	Economy	3300.00
0005435654383	21766	Economy	3300.00
0005435654364	21766	Economy	3300.00
0005435654378	21766	Economy	3300.00
0005433368595	21766	Economy	3300.00
0005433368699	21766	Economy	3300.00
0005433368751	21766	Economy	3300.00
0005435654394	21766	Economy	3300.00
0005433368672	21766	Economy	3300.00
0005435654373	21766	Economy	3300.00
0005433368787	21766	Economy	3300.00
0005435654356	21766	Economy	3300.00
0005433368662	21766	Economy	3300.00
0005433368562	21766	Economy	3300.00
0005433368594	21766	Economy	3300.00
0005435654371	21766	Economy	3300.00
0005433368646	21766	Economy	3300.00
0005433368588	21766	Economy	3300.00
0005435654400	21766	Economy	3300.00
0005433368638	21766	Economy	3300.00
0005433786111	9339	Business	186200.00
0005435269919	9339	Business	186200.00
0005433806375	9339	Business	186200.00
0005433786106	9339	Business	186200.00
0005433786096	9339	Business	186200.00
0005434151769	9339	Business	186200.00
0005433786119	9339	Business	186200.00
0005432657538	9339	Business	186200.00
0005432665333	9339	Business	186200.00
0005433763614	9339	Business	186200.00
0005435269895	9339	Business	186200.00
0005433786101	9339	Business	186200.00
0005435269878	9339	Business	186200.00
0005433763611	9339	Economy	68300.00
0005434171358	9339	Economy	68300.00
0005434270253	9339	Economy	62100.00
0005434151775	9339	Economy	62100.00
0005434171394	9339	Economy	62100.00
0005433786116	9339	Economy	62100.00
0005433763612	9339	Economy	62100.00
0005435269908	9339	Economy	62100.00
0005433806380	9339	Economy	62100.00
0005433786127	9339	Economy	62100.00
0005435269913	9339	Economy	62100.00
0005433786121	9339	Economy	62100.00
0005435269907	9339	Economy	62100.00
0005433763615	9339	Economy	62100.00
0005433786098	9339	Economy	62100.00
0005434151768	9339	Economy	62100.00
0005433786102	9339	Economy	62100.00
0005435269905	9339	Economy	62100.00
0005433806376	9339	Economy	62100.00
0005433786124	9339	Economy	62100.00
0005434171371	9339	Economy	62100.00
0005435269872	9339	Economy	62100.00
0005434171424	9339	Economy	62100.00
0005434171392	9339	Economy	62100.00
0005433786105	9339	Economy	62100.00
0005433763616	9339	Economy	62100.00
0005433786109	9339	Economy	62100.00
0005433806378	9339	Economy	62100.00
0005432665332	9339	Economy	62100.00
0005433786095	9339	Economy	62100.00
0005434270252	9339	Economy	62100.00
0005433786114	9339	Economy	62100.00
0005433786130	9339	Economy	62100.00
0005433786097	9339	Economy	62100.00
0005433763618	9339	Economy	62100.00
0005434273117	9339	Economy	62100.00
0005434273109	9339	Economy	62100.00
0005434171337	9339	Economy	62100.00
0005433806383	9339	Economy	62100.00
0005433786099	9339	Economy	62100.00
0005433786128	9339	Economy	68300.00
0005433786129	9339	Economy	62100.00
0005435269900	9339	Economy	68300.00
0005433786126	9339	Economy	62100.00
0005434273112	9339	Economy	62100.00
0005433806377	9339	Economy	62100.00
0005435269896	9339	Economy	62100.00
0005433786117	9339	Economy	62100.00
0005433763617	9339	Economy	62100.00
0005433786120	9339	Economy	62100.00
0005433786113	9339	Economy	62100.00
0005433786110	9339	Economy	62100.00
0005433786112	9339	Economy	62100.00
0005433763619	9339	Economy	62100.00
0005433806379	9339	Economy	62100.00
0005433806374	9339	Economy	62100.00
0005434171393	9339	Economy	62100.00
0005433806381	9339	Economy	62100.00
0005433806382	9339	Economy	62100.00
0005433806384	9339	Economy	62100.00
0005432665334	9339	Economy	62100.00
0005433786122	9339	Economy	62100.00
0005433786103	9339	Economy	62100.00
0005433786123	9339	Economy	62100.00
0005433786100	9339	Economy	62100.00
0005433763613	9339	Economy	62100.00
0005435269898	9339	Economy	62100.00
0005435269899	9339	Economy	62100.00
0005433786107	9339	Economy	62100.00
0005434151762	9339	Economy	62100.00
0005433786115	9339	Economy	62100.00
0005434171383	9339	Economy	62100.00
0005434171382	9339	Economy	62100.00
0005433786104	9339	Economy	62100.00
0005433786108	9339	Economy	62100.00
0005433786125	9339	Economy	62100.00
0005433786094	9339	Economy	62100.00
0005434270251	9339	Economy	62100.00
0005435269897	9339	Economy	62100.00
0005433786118	9339	Economy	62100.00
0005434171359	9339	Economy	62100.00
0005435270171	26231	Business	186200.00
0005433806019	26231	Business	186200.00
0005433806144	26231	Business	186200.00
0005433763447	26231	Business	186200.00
0005433763501	26231	Business	186200.00
0005432663085	26231	Business	186200.00
0005433785618	26231	Business	186200.00
0005433806051	26231	Business	186200.00
0005433785898	26231	Business	186200.00
0005433785585	26231	Business	186200.00
0005435270178	26231	Business	186200.00
0005432663071	26231	Business	186200.00
0005432663074	26231	Business	186200.00
0005433763471	26231	Business	186200.00
0005432663084	26231	Business	186200.00
0005433806023	26231	Business	186200.00
0005433785904	26231	Economy	68300.00
0005435270160	26231	Economy	68300.00
0005435270176	26231	Economy	62100.00
0005433805980	26231	Economy	62100.00
0005433806005	26231	Economy	62100.00
0005435858727	26231	Economy	62100.00
0005433785684	26231	Economy	62100.00
0005435858721	26231	Economy	62100.00
0005432666431	26231	Economy	62100.00
0005433785768	26231	Economy	62100.00
0005433806084	26231	Economy	62100.00
0005435270177	26231	Economy	62100.00
0005435858722	26231	Economy	62100.00
0005433785715	26231	Economy	62100.00
0005433806004	26231	Economy	62100.00
0005433806241	26231	Economy	62100.00
0005435858719	26231	Economy	62100.00
0005434271372	26231	Economy	62100.00
0005433785786	26231	Economy	62100.00
0005433785658	26231	Economy	62100.00
0005433785661	26231	Economy	62100.00
0005435270161	26231	Economy	62100.00
0005432666435	26231	Economy	62100.00
0005433785900	26231	Economy	62100.00
0005435270169	26231	Economy	62100.00
0005433785793	26231	Economy	62100.00
0005435858724	26231	Economy	62100.00
0005435270167	26231	Economy	62100.00
0005433806012	26231	Economy	62100.00
0005435858726	26231	Economy	62100.00
0005433805910	26231	Economy	62100.00
0005435270173	26231	Economy	62100.00
0005433785819	26231	Economy	62100.00
0005433806166	26231	Economy	62100.00
0005433785663	26231	Economy	62100.00
0005433806160	26231	Economy	62100.00
0005433763550	26231	Economy	62100.00
0005433806100	26231	Economy	62100.00
0005435858720	26231	Economy	62100.00
0005434269162	26231	Economy	62100.00
0005433805911	26231	Economy	62100.00
0005435858729	26231	Economy	62100.00
0005433763551	26231	Economy	62100.00
0005433806020	26231	Economy	62100.00
0005433785626	26231	Economy	62100.00
0005433806085	26231	Economy	62100.00
0005434270265	26231	Economy	62100.00
0005433806148	26231	Economy	62100.00
0005433763564	26231	Economy	62100.00
0005433806083	26231	Economy	62100.00
0005433806050	26231	Economy	62100.00
0005435270168	26231	Economy	62100.00
0005433785772	26231	Economy	62100.00
0005433785617	26231	Economy	62100.00
0005433785659	26231	Economy	62100.00
0005433785751	26231	Economy	62100.00
0005435270162	26231	Economy	62100.00
0005433785899	26231	Economy	68300.00
0005432659754	26231	Economy	62100.00
0005435270164	26231	Economy	62100.00
0005435858728	26231	Economy	68300.00
0005435270170	26231	Economy	62100.00
0005435858717	26231	Economy	68300.00
0005433785707	26231	Economy	62100.00
0005435858718	26231	Economy	62100.00
0005433763533	26231	Economy	62100.00
0005435270172	26231	Economy	62100.00
0005433785769	26231	Economy	62100.00
0005433763542	26231	Economy	62100.00
0005434269161	26231	Economy	62100.00
0005433785627	26231	Economy	62100.00
0005435270180	26231	Economy	62100.00
0005433763502	26231	Economy	62100.00
0005432659746	26231	Economy	62100.00
0005433805965	26231	Economy	62100.00
0005433806138	26231	Economy	62100.00
0005433785605	26231	Economy	62100.00
0005435270181	26231	Economy	62100.00
0005433785584	26231	Economy	62100.00
0005433785614	26231	Economy	62100.00
0005432663073	26231	Economy	62100.00
0005435858716	26231	Economy	62100.00
0005435270174	26231	Economy	62100.00
0005433806152	26231	Economy	62100.00
0005435270159	26231	Economy	62100.00
0005433785607	26231	Economy	62100.00
0005433763552	26231	Economy	62100.00
0005433785750	26231	Economy	62100.00
0005434151790	26231	Economy	62100.00
0005435858723	26231	Economy	62100.00
0005435270166	26231	Economy	62100.00
0005435270165	26231	Economy	62100.00
0005434171463	26231	Economy	62100.00
0005435270163	26231	Economy	62100.00
0005433806022	26231	Economy	62100.00
0005432663072	26231	Economy	62100.00
0005435858725	26231	Economy	62100.00
0005433785685	26231	Economy	62100.00
0005433806057	26231	Economy	62100.00
0005435270175	26231	Economy	62100.00
0005434151789	26231	Economy	62100.00
0005433806021	26231	Economy	62100.00
0005433785538	26231	Economy	62100.00
0005433785714	26231	Economy	62100.00
0005434271371	26231	Economy	62100.00
0005433785708	26231	Economy	62100.00
0005433763491	26231	Economy	62100.00
0005433763543	26231	Economy	62100.00
0005433785794	26231	Economy	62100.00
0005433805999	26231	Economy	62100.00
0005435270179	26231	Economy	62100.00
0005435929707	4896	Economy	5300.00
0005435929695	4896	Economy	5300.00
0005435929697	4896	Economy	5300.00
0005435135803	4896	Economy	5300.00
0005435135785	33007	Economy	5300.00
0005435135778	33007	Economy	5300.00
0005435135771	33007	Economy	5300.00
0005435135777	33007	Economy	5300.00
0005435135786	33007	Economy	5300.00
0005435135780	33007	Economy	5300.00
0005435135779	33007	Economy	5300.00
0005435135769	33007	Economy	5300.00
0005434218055	9489	Economy	17900.00
0005434218056	9489	Economy	17900.00
0005434983432	9489	Economy	17900.00
0005434983431	9489	Economy	17900.00
0005434218054	9489	Economy	17900.00
0005434983406	27357	Economy	17900.00
0005434983389	27357	Economy	17900.00
0005434218087	27357	Economy	17900.00
0005434218085	27357	Economy	17900.00
0005434983391	27357	Economy	17900.00
0005434218086	27357	Economy	17900.00
0005434218084	27357	Economy	17900.00
0005434983423	27357	Economy	17900.00
0005433986845	24272	Business	36400.00
0005433962097	24272	Business	36400.00
0005433961823	24272	Business	36400.00
0005433986934	24272	Business	36400.00
0005433987041	24272	Business	36400.00
0005433986877	24272	Business	36400.00
0005433961822	24272	Business	36400.00
0005433962041	24272	Business	36400.00
0005433986804	24272	Business	36400.00
0005433961867	24272	Business	36400.00
0005433961969	24272	Business	36400.00
0005433962106	24272	Business	36400.00
0005433986920	24272	Business	36400.00
0005433961675	24272	Business	36400.00
0005433986928	24272	Business	36400.00
0005433961986	24272	Business	36400.00
0005433987028	24272	Economy	13400.00
0005433987049	24272	Economy	13400.00
0005433962058	24272	Economy	12100.00
0005433986858	24272	Economy	12100.00
0005433961730	24272	Economy	12100.00
0005433961996	24272	Economy	12100.00
0005433986869	24272	Economy	12100.00
0005433961895	24272	Economy	12100.00
0005433987048	24272	Economy	12100.00
0005433962001	24272	Economy	12100.00
0005433986874	24272	Economy	12100.00
0005433962086	24272	Economy	12100.00
0005433986997	24272	Economy	12100.00
0005433987027	24272	Economy	12100.00
0005433962000	24272	Economy	12100.00
0005433986850	24272	Economy	12100.00
0005433962111	24272	Economy	12100.00
0005433986933	24272	Economy	12100.00
0005433986769	24272	Economy	12100.00
0005433962006	24272	Economy	12100.00
0005433986900	24272	Economy	12100.00
0005433961870	24272	Economy	12100.00
0005433986842	24272	Economy	12100.00
0005433986648	24272	Economy	12100.00
0005433986671	24272	Economy	12100.00
0005433961974	24272	Economy	12100.00
0005433986921	24272	Economy	12100.00
0005433961876	24272	Economy	12100.00
0005433986725	24272	Economy	12100.00
0005433962048	24272	Economy	12100.00
0005433961839	24272	Economy	12100.00
0005433962031	24272	Economy	12100.00
0005433986947	24272	Economy	12100.00
0005433961937	24272	Economy	12100.00
0005433986857	24272	Economy	12100.00
0005433986794	24272	Economy	12100.00
0005433986647	24272	Economy	12100.00
0005433961993	24272	Economy	12100.00
0005433962103	24272	Economy	12100.00
0005433961985	24272	Economy	12100.00
0005433961853	24272	Economy	12100.00
0005433962112	24272	Economy	12100.00
0005433962052	24272	Economy	12100.00
0005433962059	24272	Economy	12100.00
0005433961875	24272	Economy	12100.00
0005433986843	24272	Economy	12100.00
0005433986770	24272	Economy	12100.00
0005433986672	24272	Economy	12100.00
0005433961977	24272	Economy	12100.00
0005433986887	24272	Economy	12100.00
0005433962115	24272	Economy	12100.00
0005433962082	24272	Economy	12100.00
0005433961995	24272	Economy	12100.00
0005433962005	24272	Economy	12100.00
0005433961998	24272	Economy	12100.00
0005433986907	24272	Economy	12100.00
0005433962061	24272	Economy	13400.00
0005433962107	24272	Economy	13400.00
0005433986897	24272	Economy	12100.00
0005433986995	24272	Economy	13400.00
0005433986669	24272	Economy	12100.00
0005433961981	24272	Economy	12100.00
0005433986835	24272	Economy	12100.00
0005433962019	24272	Economy	12100.00
0005433961772	24272	Economy	12100.00
0005433961863	24272	Economy	12100.00
0005433961855	24272	Economy	12100.00
0005433961864	24272	Economy	12100.00
0005433986896	24272	Economy	12100.00
0005433986915	24272	Economy	12100.00
0005433986826	24272	Economy	12100.00
0005433961917	24272	Economy	12100.00
0005433962093	24272	Economy	12100.00
0005433962090	24272	Economy	12100.00
0005433962027	24272	Economy	12100.00
0005433962075	24272	Economy	12100.00
0005433961852	24272	Economy	12100.00
0005433961860	24272	Economy	12100.00
0005433961755	24272	Economy	12100.00
0005433961674	24272	Economy	12100.00
0005433961978	24272	Economy	12100.00
0005433961992	24272	Economy	12100.00
0005433962060	24272	Economy	12100.00
0005433986829	24272	Economy	12100.00
0005433961938	24272	Economy	12100.00
0005433986984	24272	Economy	12100.00
0005433961918	24272	Economy	12100.00
0005433986847	24272	Economy	12100.00
0005433986914	24272	Economy	12100.00
0005433986775	24272	Economy	12100.00
0005433962094	24272	Economy	12100.00
0005433961831	24272	Economy	12100.00
0005433961840	24272	Economy	12100.00
0005433986844	24272	Economy	12100.00
0005433986841	24272	Economy	12100.00
0005433987017	24272	Economy	12100.00
0005433986923	24272	Economy	12100.00
0005433961871	24272	Economy	12100.00
0005433986771	24272	Economy	12100.00
0005433986901	24272	Economy	12100.00
0005433986936	24272	Economy	12100.00
0005433962540	25912	Business	36400.00
0005433962551	25912	Business	36400.00
0005433987290	25912	Business	36400.00
0005433962552	25912	Business	36400.00
0005433962550	25912	Business	36400.00
0005433987291	25912	Business	36400.00
0005433987314	25912	Business	36400.00
0005433962530	25912	Business	36400.00
0005433987306	25912	Business	36400.00
0005433962525	25912	Business	36400.00
0005433962549	25912	Business	36400.00
0005433962569	25912	Economy	13400.00
0005433962541	25912	Economy	13400.00
0005433962554	25912	Economy	13400.00
0005433987313	25912	Economy	12100.00
0005433987296	25912	Economy	12100.00
0005433962572	25912	Economy	12100.00
0005433962578	25912	Economy	12100.00
0005433987288	25912	Economy	12100.00
0005433987295	25912	Economy	12100.00
0005433987283	25912	Economy	12100.00
0005433962544	25912	Economy	12100.00
0005433962523	25912	Economy	12100.00
0005433962587	25912	Economy	12100.00
0005433962590	25912	Economy	12100.00
0005433962573	25912	Economy	12100.00
0005433962560	25912	Economy	12100.00
0005433962567	25912	Economy	12100.00
0005433962543	25912	Economy	12100.00
0005433962583	25912	Economy	12100.00
0005433962580	25912	Economy	12100.00
0005433962581	25912	Economy	12100.00
0005433962546	25912	Economy	12100.00
0005433962538	25912	Economy	12100.00
0005433962528	25912	Economy	12100.00
0005433962575	25912	Economy	12100.00
0005433987300	25912	Economy	12100.00
0005433962558	25912	Economy	12100.00
0005433987311	25912	Economy	12100.00
0005433962527	25912	Economy	12100.00
0005433987287	25912	Economy	12100.00
0005433962526	25912	Economy	12100.00
0005433962565	25912	Economy	12100.00
0005433962579	25912	Economy	12100.00
0005433962534	25912	Economy	12100.00
0005433962556	25912	Economy	12100.00
0005433962547	25912	Economy	12100.00
0005433987286	25912	Economy	12100.00
0005433962576	25912	Economy	12100.00
0005433987309	25912	Economy	12100.00
0005433987298	25912	Economy	12100.00
0005433987282	25912	Economy	12100.00
0005433962548	25912	Economy	12100.00
0005433962533	25912	Economy	12100.00
0005433987310	25912	Economy	12100.00
0005433962531	25912	Economy	12100.00
0005433987293	25912	Economy	12100.00
0005433987285	25912	Economy	12100.00
0005433962545	25912	Economy	12100.00
0005433962557	25912	Economy	12100.00
0005433987303	25912	Economy	12100.00
0005433962582	25912	Economy	12100.00
0005433962522	25912	Economy	12100.00
0005433962536	25912	Economy	12100.00
0005433962529	25912	Economy	13400.00
0005433962555	25912	Economy	13400.00
0005433962588	25912	Economy	12100.00
0005433962537	25912	Economy	13400.00
0005433962566	25912	Economy	12100.00
0005433962559	25912	Economy	12100.00
0005433962584	25912	Economy	12100.00
0005433962589	25912	Economy	12100.00
0005433962571	25912	Economy	12100.00
0005433962562	25912	Economy	12100.00
0005433987280	25912	Economy	12100.00
0005433987292	25912	Economy	12100.00
0005433987305	25912	Economy	12100.00
0005433962520	25912	Economy	12100.00
0005433962585	25912	Economy	12100.00
0005433987297	25912	Economy	12100.00
0005433962563	25912	Economy	12100.00
0005433962564	25912	Economy	12100.00
0005433987289	25912	Economy	12100.00
0005433987284	25912	Economy	12100.00
0005433962561	25912	Economy	12100.00
0005433962524	25912	Economy	12100.00
0005433987302	25912	Economy	12100.00
0005433962539	25912	Economy	12100.00
0005433987304	25912	Economy	12100.00
0005433962568	25912	Economy	12100.00
0005433987279	25912	Economy	12100.00
0005433962532	25912	Economy	12100.00
0005433987307	25912	Economy	12100.00
0005433987308	25912	Economy	12100.00
0005433987294	25912	Economy	12100.00
0005433962577	25912	Economy	12100.00
0005433962570	25912	Economy	12100.00
0005433962521	25912	Economy	12100.00
0005433962586	25912	Economy	12100.00
0005433962542	25912	Economy	12100.00
0005433962535	25912	Economy	12100.00
0005433962553	25912	Economy	12100.00
0005433987281	25912	Economy	12100.00
0005433987299	25912	Economy	12100.00
0005433987312	25912	Economy	12100.00
0005433962574	25912	Economy	12100.00
0005433987301	25912	Economy	12100.00
0005433166191	918	Economy	25400.00
0005434481029	918	Economy	23100.00
0005433166227	918	Economy	23100.00
0005433166170	918	Economy	23100.00
0005434481031	918	Economy	23100.00
0005433166213	918	Economy	23100.00
0005433166242	918	Economy	23100.00
0005433166240	918	Economy	23100.00
0005433166192	918	Economy	23100.00
0005434481026	918	Economy	23100.00
0005432269575	918	Economy	23100.00
0005433166168	918	Economy	23100.00
0005433166228	918	Economy	23100.00
0005432269574	918	Economy	23100.00
0005434481030	918	Economy	23100.00
0005433166241	918	Economy	23100.00
0005434481027	918	Economy	23100.00
0005433166153	918	Economy	23100.00
0005434481028	918	Economy	23100.00
0005434480803	16588	Economy	25400.00
0005434480896	16588	Economy	25400.00
0005434480847	16588	Economy	23100.00
0005433166276	16588	Economy	23100.00
0005434480737	16588	Economy	23100.00
0005434480805	16588	Economy	23100.00
0005434480787	16588	Economy	23100.00
0005434480849	16588	Economy	23100.00
0005434480807	16588	Economy	23100.00
0005434480800	16588	Economy	23100.00
0005434480738	16588	Economy	23100.00
0005434480784	16588	Economy	23100.00
0005434480936	16588	Economy	23100.00
0005434480935	16588	Economy	23100.00
0005433166277	16588	Economy	23100.00
0005433166278	16588	Economy	23100.00
0005434480850	16588	Economy	23100.00
0005434480823	16588	Economy	23100.00
0005434480788	16588	Economy	23100.00
0005434480890	16588	Economy	23100.00
0005434480808	16588	Economy	23100.00
0005434480804	16588	Economy	23100.00
0005434480878	16588	Economy	23100.00
0005434480889	16588	Economy	23100.00
0005433166279	16588	Economy	23100.00
0005433872581	3214	Economy	17200.00
0005433872584	3214	Economy	17200.00
0005433872582	3214	Economy	17200.00
0005433872585	3214	Economy	17200.00
0005433872586	3214	Economy	17200.00
0005433872580	3214	Economy	17200.00
0005433872583	3214	Economy	17200.00
0005433872587	3214	Economy	17200.00
0005433872579	3214	Economy	17200.00
0005433872556	32546	Economy	17200.00
0005433872555	32546	Economy	17200.00
0005433872554	32546	Economy	17200.00
0005433872553	32546	Economy	17200.00
0005433872557	32546	Economy	17200.00
0005433872552	32546	Economy	17200.00
0005433872568	32546	Economy	17200.00
0005435150415	10369	Economy	17000.00
0005435150421	10369	Economy	17000.00
0005435150423	10369	Economy	15400.00
0005435386715	10369	Economy	15400.00
0005435386679	10369	Economy	15400.00
0005435150426	10369	Economy	15400.00
0005435150420	10369	Economy	15400.00
0005435150422	10369	Economy	15400.00
0005433290009	10369	Economy	15400.00
0005433290011	10369	Economy	15400.00
0005435142945	10369	Economy	15400.00
0005435142944	10369	Economy	15400.00
0005435150416	10369	Economy	15400.00
0005435150424	10369	Economy	15400.00
0005435386680	10369	Economy	15400.00
0005435142948	10369	Economy	15400.00
0005435150419	10369	Economy	15400.00
0005435150418	10369	Economy	15400.00
0005435150425	10369	Economy	15400.00
0005433290010	10369	Economy	15400.00
0005435386714	10369	Economy	15400.00
0005435386690	10369	Economy	15400.00
0005435142947	10369	Economy	15400.00
0005435142943	10369	Economy	15400.00
0005435142951	10369	Economy	15400.00
0005433289998	10369	Economy	15400.00
0005435142949	10369	Economy	15400.00
0005433290000	10369	Economy	15400.00
0005435150417	10369	Economy	15400.00
0005435150414	10369	Economy	15400.00
0005435142950	10369	Economy	15400.00
0005435142946	10369	Economy	15400.00
0005433289997	10369	Economy	15400.00
0005433289999	10369	Economy	15400.00
0005435150329	21931	Economy	17000.00
0005435142869	21931	Economy	17000.00
0005435142824	21931	Economy	17000.00
0005435142810	21931	Economy	17000.00
0005435150245	21931	Economy	15400.00
0005435142826	21931	Economy	15400.00
0005435142848	21931	Economy	15400.00
0005435142865	21931	Economy	15400.00
0005435142867	21931	Economy	15400.00
0005435150262	21931	Economy	15400.00
0005433290061	21931	Economy	15400.00
0005435142864	21931	Economy	15400.00
0005435142813	21931	Economy	15400.00
0005435142811	21931	Economy	15400.00
0005435150282	21931	Economy	15400.00
0005435142809	21931	Economy	15400.00
0005435150244	21931	Economy	15400.00
0005435142897	21931	Economy	15400.00
0005435150250	21931	Economy	15400.00
0005435150376	21931	Economy	15400.00
0005435386755	21931	Economy	15400.00
0005435142866	21931	Economy	15400.00
0005435142846	21931	Economy	15400.00
0005435150321	21931	Economy	15400.00
0005435150313	21931	Economy	15400.00
0005435150261	21931	Economy	15400.00
0005435386757	21931	Economy	15400.00
0005435142860	21931	Economy	15400.00
0005435142876	21931	Economy	15400.00
0005435142879	21931	Economy	15400.00
0005435386754	21931	Economy	15400.00
0005435386756	21931	Economy	15400.00
0005435150306	21931	Economy	15400.00
0005435150375	21931	Economy	15400.00
0005435142868	21931	Economy	15400.00
0005435142847	21931	Economy	15400.00
0005435142859	21931	Economy	15400.00
0005433290060	21931	Economy	15400.00
0005435386753	21931	Economy	15400.00
0005435142825	21931	Economy	15400.00
0005435142896	21931	Economy	15400.00
0005433290059	21931	Economy	15400.00
0005435502770	11194	Business	57200.00
0005434573748	11194	Business	57200.00
0005435529662	11194	Business	57200.00
0005435529664	11194	Business	57200.00
0005435502779	11194	Business	57200.00
0005435319776	11194	Business	57200.00
0005434573752	11194	Business	57200.00
0005435529747	11194	Business	57200.00
0005435502769	11194	Business	57200.00
0005435502817	11194	Economy	19100.00
0005435529673	11194	Economy	19100.00
0005434573750	11194	Economy	19100.00
0005435529634	11194	Economy	19100.00
0005435502790	11194	Economy	19100.00
0005435502759	11194	Economy	19100.00
0005435529701	11194	Economy	19100.00
0005435529669	11194	Economy	21000.00
0005435529748	11194	Economy	21000.00
0005435529731	11194	Economy	21000.00
0005435529721	11194	Economy	21000.00
0005435502731	11194	Economy	19100.00
0005434573749	11194	Economy	19100.00
0005435319781	11194	Economy	19100.00
0005435529683	11194	Economy	19100.00
0005435529720	11194	Economy	19100.00
0005435529700	11194	Economy	19100.00
0005435545880	11194	Economy	19100.00
0005435529711	11194	Economy	19100.00
0005435502848	11194	Economy	19100.00
0005435545885	11194	Economy	19100.00
0005435502649	11194	Economy	19100.00
0005435545899	11194	Economy	19100.00
0005435545903	11194	Economy	19100.00
0005435529712	11194	Economy	19100.00
0005435502648	11194	Economy	19100.00
0005435319778	11194	Economy	19100.00
0005434573751	11194	Economy	19100.00
0005435529713	11194	Economy	19100.00
0005435502829	11194	Economy	19100.00
0005435529635	11194	Economy	19100.00
0005435529687	11194	Economy	19100.00
0005435319744	11194	Economy	19100.00
0005435502708	11194	Economy	19100.00
0005435502776	11194	Economy	19100.00
0005435319782	11194	Economy	19100.00
0005434573746	11194	Economy	19100.00
0005435502753	11194	Economy	19100.00
0005435529659	11194	Economy	19100.00
0005435529689	11194	Economy	19100.00
0005435502813	11194	Economy	19100.00
0005435502847	11194	Economy	19100.00
0005434573747	11194	Economy	19100.00
0005435529722	11194	Economy	19100.00
0005435319738	11194	Economy	19100.00
0005434573745	11194	Economy	19100.00
0005435502763	11194	Economy	19100.00
0005435529665	11194	Economy	19100.00
0005435502822	11194	Economy	19100.00
0005435529746	11194	Economy	19100.00
0005435502762	11194	Economy	19100.00
0005435545879	11194	Economy	19100.00
0005435319737	11194	Economy	19100.00
0005435529695	11194	Economy	19100.00
0005435319758	11194	Economy	19100.00
0005435502650	11194	Economy	19100.00
0005435545900	11194	Economy	19100.00
0005435545878	11194	Economy	19100.00
0005435502735	11194	Economy	19100.00
0005435529688	11194	Economy	19100.00
0005435502777	11194	Economy	19100.00
0005435529786	11194	Economy	19100.00
0005435529752	11194	Economy	19100.00
0005435529718	11194	Economy	19100.00
0005435319777	11194	Economy	19100.00
0005435529787	11194	Economy	19100.00
0005435319823	20929	Business	57200.00
0005434573672	20929	Business	57200.00
0005435502932	20929	Business	57200.00
0005434573638	20929	Business	57200.00
0005435502928	20929	Business	57200.00
0005435502929	20929	Business	57200.00
0005435502926	20929	Business	57200.00
0005435502927	20929	Business	57200.00
0005435508794	20929	Economy	19100.00
0005435508796	20929	Economy	19100.00
0005435508793	20929	Economy	19100.00
0005435508792	20929	Economy	19100.00
0005435518429	20929	Economy	19100.00
0005434573564	20929	Economy	19100.00
0005435502923	20929	Economy	21000.00
0005435518428	20929	Economy	19100.00
0005435518433	20929	Economy	19100.00
0005435502931	20929	Economy	19100.00
0005435508795	20929	Economy	19100.00
0005435518432	20929	Economy	19100.00
0005434573626	20929	Economy	19100.00
0005435502933	20929	Economy	19100.00
0005435319824	20929	Economy	19100.00
0005435508797	20929	Economy	19100.00
0005434573637	20929	Economy	19100.00
0005435508799	20929	Economy	19100.00
0005435508790	20929	Economy	19100.00
0005434573633	20929	Economy	19100.00
0005435502924	20929	Economy	19100.00
0005435518424	20929	Economy	19100.00
0005434573668	20929	Economy	19100.00
0005434573702	20929	Economy	19100.00
0005435518423	20929	Economy	19100.00
0005435508801	20929	Economy	19100.00
0005435508791	20929	Economy	19100.00
0005435502934	20929	Economy	19100.00
0005435518425	20929	Economy	19100.00
0005435508789	20929	Economy	19100.00
0005435502936	20929	Economy	19100.00
0005434573601	20929	Economy	19100.00
0005435508802	20929	Economy	19100.00
0005434573674	20929	Economy	19100.00
0005435502925	20929	Economy	19100.00
0005434573689	20929	Economy	19100.00
0005435518431	20929	Economy	19100.00
0005435502930	20929	Economy	19100.00
0005435508788	20929	Economy	19100.00
0005435518430	20929	Economy	19100.00
0005435518427	20929	Economy	19100.00
0005435518434	20929	Economy	19100.00
0005435508798	20929	Economy	19100.00
0005435508803	20929	Economy	19100.00
0005435508800	20929	Economy	19100.00
0005435518435	20929	Economy	19100.00
0005435518426	20929	Economy	19100.00
0005435502935	20929	Economy	19100.00
0005434573634	20929	Economy	19100.00
0005432693747	3042	Business	10300.00
0005432693754	3042	Business	10300.00
0005432693746	3042	Economy	3400.00
0005432693732	3042	Economy	3400.00
0005432693720	3042	Economy	3400.00
0005432693676	3042	Economy	3400.00
0005432693621	3042	Economy	3800.00
0005432693708	3042	Economy	3800.00
0005432693714	3042	Economy	3400.00
0005432693586	3042	Economy	3400.00
0005432693623	3042	Economy	3400.00
0005432693707	3042	Economy	3400.00
0005432693713	3042	Economy	3400.00
0005432693625	3042	Economy	3400.00
0005432693602	3042	Economy	3400.00
0005432693722	3042	Economy	3400.00
0005432693620	3042	Economy	3400.00
0005432693709	3042	Economy	3400.00
0005432693719	3042	Economy	3400.00
0005432693698	3042	Economy	3400.00
0005432693706	3042	Economy	3400.00
0005432693677	3042	Economy	3400.00
0005432693636	3042	Economy	3400.00
0005432693762	3042	Economy	3400.00
0005432693753	3042	Economy	3400.00
0005432693749	3042	Economy	3400.00
0005432693622	3042	Economy	3400.00
0005432693748	3042	Economy	3400.00
0005432693601	3042	Economy	3400.00
0005432693801	3042	Economy	3400.00
0005432693731	3042	Economy	3400.00
0005432693699	3042	Economy	3400.00
0005432693658	3042	Economy	3400.00
0005432693637	3042	Economy	3400.00
0005432881115	3046	Business	10300.00
0005432881117	3046	Business	10300.00
0005433124352	3046	Business	10300.00
0005433124418	3046	Business	10300.00
0005432707487	3046	Business	10300.00
0005432881145	3046	Business	10300.00
0005432881103	3046	Business	10300.00
0005433194912	3046	Business	10300.00
0005432881116	3046	Business	10300.00
0005432707496	3046	Economy	3400.00
0005433124366	3046	Economy	3400.00
0005434310151	3046	Economy	3400.00
0005432707492	3046	Economy	3400.00
0005433124341	3046	Economy	3400.00
0005432707498	3046	Economy	3400.00
0005433194917	3046	Economy	3400.00
0005432707488	3046	Economy	3400.00
0005432217860	3046	Economy	3800.00
0005433124271	3046	Economy	3800.00
0005433194903	3046	Economy	3800.00
0005432707485	3046	Economy	3800.00
0005432881127	3046	Economy	3400.00
0005433194910	3046	Economy	3400.00
0005432217859	3046	Economy	3400.00
0005432881048	3046	Economy	3400.00
0005433124359	3046	Economy	3400.00
0005432881187	3046	Economy	3400.00
0005434310150	3046	Economy	3400.00
0005432707493	3046	Economy	3400.00
0005433194906	3046	Economy	3400.00
0005432707495	3046	Economy	3400.00
0005433124374	3046	Economy	3400.00
0005432881128	3046	Economy	3400.00
0005433124407	3046	Economy	3400.00
0005433194916	3046	Economy	3400.00
0005432881118	3046	Economy	3400.00
0005432881085	3046	Economy	3400.00
0005433124270	3046	Economy	3400.00
0005433124313	3046	Economy	3400.00
0005434310153	3046	Economy	3400.00
0005432707490	3046	Economy	3400.00
0005432881178	3046	Economy	3400.00
0005432217858	3046	Economy	3400.00
0005433194905	3046	Economy	3400.00
0005433124318	3046	Economy	3400.00
0005434310154	3046	Economy	3400.00
0005432881186	3046	Economy	3400.00
0005433124272	3046	Economy	3400.00
0005433124369	3046	Economy	3400.00
0005432881055	3046	Economy	3400.00
0005432707491	3046	Economy	3400.00
0005432707486	3046	Economy	3400.00
0005432707494	3046	Economy	3400.00
0005434310152	3046	Economy	3400.00
0005432881047	3046	Economy	3400.00
0005432881003	3046	Economy	3400.00
0005432707497	3046	Economy	3400.00
0005433194907	3046	Economy	3400.00
0005433124373	3046	Economy	3400.00
0005433124331	3046	Economy	3400.00
0005433124411	3046	Economy	3400.00
0005432881104	3046	Economy	3400.00
0005433124477	3046	Economy	3400.00
0005433124367	3046	Economy	3400.00
0005433124280	3046	Economy	3400.00
0005432707489	3046	Economy	3400.00
0005432881149	3046	Economy	3400.00
0005432707350	29984	Business	10300.00
0005433124514	29984	Business	10300.00
0005432693947	29984	Business	10300.00
0005432707333	29984	Business	10300.00
0005432707427	29984	Business	10300.00
0005432707314	29984	Business	10300.00
0005432707364	29984	Business	10300.00
0005432693944	29984	Business	10300.00
0005433194988	29984	Business	10300.00
0005432881236	29984	Business	10300.00
0005432693952	29984	Business	10300.00
0005434300249	29984	Business	10300.00
0005434300242	29984	Economy	3400.00
0005433124513	29984	Economy	3400.00
0005432693954	29984	Economy	3400.00
0005432707383	29984	Economy	3400.00
0005434300250	29984	Economy	3400.00
0005432693945	29984	Economy	3400.00
0005433124515	29984	Economy	3400.00
0005433124522	29984	Economy	3400.00
0005433124512	29984	Economy	3400.00
0005432707388	29984	Economy	3400.00
0005433124509	29984	Economy	3800.00
0005433124508	29984	Economy	3800.00
0005432693949	29984	Economy	3800.00
0005432707283	29984	Economy	3800.00
0005432707292	29984	Economy	3800.00
0005432707246	29984	Economy	3400.00
0005434300241	29984	Economy	3400.00
0005432707428	29984	Economy	3400.00
0005432881233	29984	Economy	3400.00
0005432693946	29984	Economy	3400.00
0005433194980	29984	Economy	3400.00
0005432693955	29984	Economy	3400.00
0005434300248	29984	Economy	3400.00
0005432707254	29984	Economy	3400.00
0005434300243	29984	Economy	3400.00
0005432707326	29984	Economy	3400.00
0005433124510	29984	Economy	3400.00
0005434300244	29984	Economy	3400.00
0005432707261	29984	Economy	3400.00
0005432693950	29984	Economy	3400.00
0005432707250	29984	Economy	3400.00
0005432707378	29984	Economy	3400.00
0005434300245	29984	Economy	3400.00
0005433124517	29984	Economy	3400.00
0005432693948	29984	Economy	3400.00
0005432707266	29984	Economy	3400.00
0005432707377	29984	Economy	3400.00
0005432707284	29984	Economy	3400.00
0005434300239	29984	Economy	3400.00
0005433124511	29984	Economy	3400.00
0005432693951	29984	Economy	3400.00
0005433124518	29984	Economy	3400.00
0005433194987	29984	Economy	3400.00
0005432707282	29984	Economy	3400.00
0005433194990	29984	Economy	3400.00
0005432693953	29984	Economy	3400.00
0005433194982	29984	Economy	3400.00
0005432707323	29984	Economy	3400.00
0005433194983	29984	Economy	3400.00
0005433194989	29984	Economy	3400.00
0005433124520	29984	Economy	3400.00
0005432881235	29984	Economy	3400.00
0005432881234	29984	Economy	3400.00
0005433194985	29984	Economy	3400.00
0005432881232	29984	Economy	3400.00
0005433194986	29984	Economy	3400.00
0005433194978	29984	Economy	3400.00
0005434300247	29984	Economy	3400.00
0005433194976	29984	Economy	3400.00
0005433124521	29984	Economy	3400.00
0005434300246	29984	Economy	3400.00
0005433194977	29984	Economy	3400.00
0005432707300	29984	Economy	3400.00
0005433194979	29984	Economy	3400.00
0005432707304	29984	Economy	3400.00
0005432707322	29984	Economy	3400.00
0005432707294	29984	Economy	3400.00
0005433194984	29984	Economy	3400.00
0005433124516	29984	Economy	3400.00
0005432693956	29984	Economy	3400.00
0005432707245	29984	Economy	3400.00
0005434300240	29984	Economy	3400.00
0005433194981	29984	Economy	3400.00
0005432707270	29984	Economy	3400.00
0005432707293	29984	Economy	3400.00
0005433124519	29984	Economy	3400.00
0005434980631	23654	Economy	4000.00
0005434989073	23654	Economy	4000.00
0005434989070	23654	Economy	4000.00
0005434980629	23654	Economy	3600.00
0005434980634	23654	Economy	3600.00
0005434980620	23654	Economy	3600.00
0005434980628	23654	Economy	3600.00
0005434989074	23654	Economy	3600.00
0005434980632	23654	Economy	3600.00
0005434980619	23654	Economy	3600.00
0005434980624	23654	Economy	3600.00
0005434980625	23654	Economy	3600.00
0005434989065	23654	Economy	3600.00
0005434989066	23654	Economy	3600.00
0005434989075	23654	Economy	3600.00
0005434989063	23654	Economy	3600.00
0005434989062	23654	Economy	3600.00
0005434980627	23654	Economy	3600.00
0005434989072	23654	Economy	3600.00
0005434980630	23654	Economy	3600.00
0005434989060	23654	Economy	3600.00
0005434980622	23654	Economy	3600.00
0005434989067	23654	Economy	3600.00
0005434980621	23654	Economy	3600.00
0005434980635	23654	Economy	3600.00
0005434989064	23654	Economy	3600.00
0005434989068	23654	Economy	3600.00
0005434989077	23654	Economy	3600.00
0005434980633	23654	Economy	3600.00
0005434989061	23654	Economy	3600.00
0005434980626	23654	Economy	3600.00
0005434989069	23654	Economy	3600.00
0005434980623	23654	Economy	3600.00
0005434989071	23654	Economy	3600.00
0005434989076	23654	Economy	3600.00
0005434980618	23654	Economy	3600.00
0005434980513	27557	Economy	4000.00
0005434980319	27557	Economy	4000.00
0005434980311	27557	Economy	4000.00
0005434980430	27557	Economy	4000.00
0005434980357	27557	Economy	3600.00
0005434980386	27557	Economy	3600.00
0005434988928	27557	Economy	3600.00
0005434980337	27557	Economy	3600.00
0005434980538	27557	Economy	3600.00
0005434980385	27557	Economy	3600.00
0005434980287	27557	Economy	3600.00
0005434980349	27557	Economy	3600.00
0005434980401	27557	Economy	3600.00
0005434980312	27557	Economy	3600.00
0005434988936	27557	Economy	3600.00
0005434980438	27557	Economy	3600.00
0005434980335	27557	Economy	3600.00
0005434988956	27557	Economy	3600.00
0005434988955	27557	Economy	3600.00
0005434980397	27557	Economy	3600.00
0005434980387	27557	Economy	3600.00
0005434980512	27557	Economy	3600.00
0005434980288	27557	Economy	3600.00
0005434980414	27557	Economy	3600.00
0005434980348	27557	Economy	3600.00
0005434980398	27557	Economy	3600.00
0005434980382	27557	Economy	3600.00
0005434988924	27557	Economy	3600.00
0005434980539	27557	Economy	3600.00
0005434980431	27557	Economy	3600.00
0005434980437	27557	Economy	3600.00
0005434988927	27557	Economy	3600.00
0005434980432	27557	Economy	3600.00
0005434980375	27557	Economy	3600.00
0005434980318	27557	Economy	3600.00
0005434988923	27557	Economy	3600.00
0005434980383	27557	Economy	3600.00
0005434980361	27557	Economy	3600.00
0005434980415	27557	Economy	3600.00
0005433113572	10289	Economy	19700.00
0005433113577	10289	Economy	19700.00
0005433111545	10289	Economy	19700.00
0005433111549	10289	Economy	19700.00
0005434302904	10289	Economy	19700.00
0005433111550	10289	Economy	19700.00
0005433111539	10289	Economy	19700.00
0005434302577	10289	Economy	19700.00
0005434302905	10289	Economy	19700.00
0005434302578	10289	Economy	19700.00
0005433111548	10289	Economy	19700.00
0005433111547	10289	Economy	19700.00
0005433111546	10289	Economy	19700.00
0005434302547	19597	Economy	19700.00
0005433113597	19597	Economy	19700.00
0005435070535	3583	Business	26900.00
0005435950332	3583	Business	26900.00
0005435939931	3583	Business	26900.00
0005435925602	3583	Business	26900.00
0005435950331	3583	Business	26900.00
0005435925593	3583	Business	26900.00
0005435939921	3583	Business	26900.00
0005435070519	3583	Business	26900.00
0005435070528	3583	Economy	9000.00
0005435070520	3583	Economy	9000.00
0005435070533	3583	Economy	9000.00
0005435925559	3583	Economy	9000.00
0005435925587	3583	Economy	9000.00
0005435925650	3583	Economy	9000.00
0005435925539	3583	Economy	9000.00
0005435925571	3583	Economy	9900.00
0005435925561	3583	Economy	9900.00
0005435939914	3583	Economy	9000.00
0005435070537	3583	Economy	9000.00
0005435070527	3583	Economy	9000.00
0005435939922	3583	Economy	9000.00
0005435939934	3583	Economy	9000.00
0005435719118	3583	Economy	9000.00
0005435939940	3583	Economy	9000.00
0005435070530	3583	Economy	9000.00
0005435925580	3583	Economy	9000.00
0005435070532	3583	Economy	9000.00
0005435925606	3583	Economy	9000.00
0005435925586	3583	Economy	9000.00
0005435925601	3583	Economy	9000.00
0005435939920	3583	Economy	9000.00
0005435070524	3583	Economy	9000.00
0005435950329	3583	Economy	9000.00
0005435070526	3583	Economy	9000.00
0005435939941	3583	Economy	9000.00
0005435719119	3583	Economy	9000.00
0005435070523	3583	Economy	9000.00
0005435939942	3583	Economy	9000.00
0005435950333	3583	Economy	9000.00
0005435950330	3583	Economy	9000.00
0005435939933	3583	Economy	9000.00
0005435925617	3583	Economy	9000.00
0005435925603	3583	Economy	9000.00
0005435070536	3583	Economy	9000.00
0005435070529	3583	Economy	9000.00
0005435070522	3583	Economy	9000.00
0005435925562	3583	Economy	9000.00
0005435070534	3583	Economy	9000.00
0005435719120	3583	Economy	9000.00
0005435070525	3583	Economy	9000.00
0005435070538	3583	Economy	9000.00
0005435070521	3583	Economy	9000.00
0005435939923	3583	Economy	9000.00
0005435070531	3583	Economy	9000.00
0005435070133	15324	Business	26900.00
0005435070290	15324	Business	26900.00
0005435070036	15324	Business	26900.00
0005435070372	15324	Business	26900.00
0005435070186	15324	Business	26900.00
0005435925691	15324	Business	26900.00
0005435070076	15324	Business	26900.00
0005435069958	15324	Business	26900.00
0005435925702	15324	Business	26900.00
0005435070066	15324	Business	26900.00
0005435069907	15324	Business	26900.00
0005435070046	15324	Economy	9000.00
0005435925697	15324	Economy	9000.00
0005435070029	15324	Economy	9000.00
0005435070307	15324	Economy	9000.00
0005435925700	15324	Economy	9000.00
0005435070152	15324	Economy	9000.00
0005435939958	15324	Economy	9000.00
0005435070244	15324	Economy	9000.00
0005435939960	15324	Economy	9000.00
0005435070169	15324	Economy	9900.00
0005435069957	15324	Economy	9900.00
0005435070464	15324	Economy	9900.00
0005435925693	15324	Economy	9900.00
0005435069883	15324	Economy	9900.00
0005435070035	15324	Economy	9000.00
0005435070045	15324	Economy	9000.00
0005435070118	15324	Economy	9000.00
0005435925692	15324	Economy	9000.00
0005435925701	15324	Economy	9000.00
0005435070194	15324	Economy	9000.00
0005435070096	15324	Economy	9000.00
0005435939959	15324	Economy	9000.00
0005435070019	15324	Economy	9000.00
0005435070317	15324	Economy	9000.00
0005435070187	15324	Economy	9000.00
0005435069972	15324	Economy	9000.00
0005435070005	15324	Economy	9000.00
0005435070064	15324	Economy	9000.00
0005435069963	15324	Economy	9000.00
0005435925694	15324	Economy	9000.00
0005435070018	15324	Economy	9000.00
0005435070268	15324	Economy	9000.00
0005435070125	15324	Economy	9000.00
0005435939957	15324	Economy	9000.00
0005435070068	15324	Economy	9000.00
0005435925699	15324	Economy	9000.00
0005435069906	15324	Economy	9000.00
0005435070291	15324	Economy	9000.00
0005435070267	15324	Economy	9000.00
0005435070142	15324	Economy	9000.00
0005435925695	15324	Economy	9000.00
0005435070441	15324	Economy	9000.00
0005435070072	15324	Economy	9000.00
0005435069971	15324	Economy	9000.00
0005435069970	15324	Economy	9000.00
0005435070318	15324	Economy	9000.00
0005435070463	15324	Economy	9000.00
0005435070004	15324	Economy	9000.00
0005435070176	15324	Economy	9000.00
0005435070017	15324	Economy	9000.00
0005435069964	15324	Economy	9000.00
0005435925696	15324	Economy	9000.00
0005435070226	15324	Economy	9000.00
0005435070065	15324	Economy	9000.00
0005435925698	15324	Economy	9000.00
0005435070306	15324	Economy	9000.00
0005435939956	15324	Economy	9000.00
0005435070117	15324	Economy	9000.00
0005435070067	15324	Economy	9000.00
0005435070012	15324	Economy	9000.00
0005435070188	15324	Economy	9000.00
0005435070097	15324	Economy	9000.00
0005435069884	15324	Economy	9000.00
0005435070353	15324	Economy	9000.00
0005435939961	15324	Economy	9000.00
0005435070166	15324	Economy	9000.00
0005435070058	15324	Economy	9000.00
0005435070126	15324	Economy	9000.00
0005435070028	15324	Economy	9000.00
0005435070006	15324	Economy	9000.00
0005435070164	15324	Economy	9000.00
0005435070175	15324	Economy	9000.00
0005432659766	18135	Economy	5900.00
0005432658650	18135	Economy	5900.00
0005432659765	18135	Economy	5900.00
0005432658651	18135	Economy	5900.00
0005432659767	18135	Economy	5900.00
0005432664174	26359	Economy	5900.00
0005432667495	26359	Economy	5900.00
0005432667489	26359	Economy	5900.00
0005433103296	120	Business	20000.00
0005432902024	120	Business	20000.00
0005433103287	120	Business	20000.00
0005433103154	120	Business	20000.00
0005432902056	120	Business	20000.00
0005432902005	120	Business	20000.00
0005432920373	120	Business	20000.00
0005433103157	120	Business	20000.00
0005432920401	120	Business	20000.00
0005433103223	120	Business	20000.00
0005433103183	120	Business	20000.00
0005433103218	120	Business	20000.00
0005432902068	120	Business	20000.00
0005432920336	120	Business	20000.00
0005433103219	120	Business	20000.00
0005432901969	120	Business	20000.00
0005433103057	120	Business	20000.00
0005433103273	120	Economy	7300.00
0005432920355	120	Economy	7300.00
0005433103161	120	Economy	7300.00
0005433103308	120	Economy	7300.00
0005432901950	120	Economy	6700.00
0005432920321	120	Economy	6700.00
0005432920285	120	Economy	6700.00
0005432901920	120	Economy	6700.00
0005432902014	120	Economy	6700.00
0005433103162	120	Economy	6700.00
0005432920231	120	Economy	6700.00
0005432157548	120	Economy	6700.00
0005432902034	120	Economy	6700.00
0005432902032	120	Economy	6700.00
0005433103095	120	Economy	6700.00
0005433103288	120	Economy	6700.00
0005432920335	120	Economy	6700.00
0005433103061	120	Economy	6700.00
0005433103269	120	Economy	6700.00
0005432920383	120	Economy	6700.00
0005433103153	120	Economy	6700.00
0005432920369	120	Economy	6700.00
0005433103270	120	Economy	6700.00
0005432920340	120	Economy	6700.00
0005433103328	120	Economy	6700.00
0005433103248	120	Economy	6700.00
0005433103333	120	Economy	6700.00
0005433103274	120	Economy	6700.00
0005433103272	120	Economy	6700.00
0005432920311	120	Economy	6700.00
0005432902069	120	Economy	6700.00
0005433103293	120	Economy	6700.00
0005433103116	120	Economy	6700.00
0005433103309	120	Economy	6700.00
0005433103152	120	Economy	6700.00
0005433103215	120	Economy	6700.00
0005432902013	120	Economy	6700.00
0005433103321	120	Economy	6700.00
0005432902017	120	Economy	6700.00
0005433103327	120	Economy	6700.00
0005433103184	120	Economy	6700.00
0005433103314	120	Economy	6700.00
0005432920368	120	Economy	7300.00
0005432901916	120	Economy	7300.00
0005433103332	120	Economy	7300.00
0005433103217	120	Economy	6700.00
0005433103107	120	Economy	6700.00
0005433103335	120	Economy	7300.00
0005432901994	120	Economy	6700.00
0005433103338	120	Economy	6700.00
0005433103315	120	Economy	6700.00
0005433103263	120	Economy	6700.00
0005433103331	120	Economy	6700.00
0005432920384	120	Economy	6700.00
0005433103262	120	Economy	6700.00
0005432902012	120	Economy	6700.00
0005432901989	120	Economy	6700.00
0005432920320	120	Economy	6700.00
0005432920366	120	Economy	6700.00
0005432920309	120	Economy	6700.00
0005433103326	120	Economy	6700.00
0005432920367	120	Economy	6700.00
0005432920252	120	Economy	6700.00
0005433103271	120	Economy	6700.00
0005433103264	120	Economy	6700.00
0005433103011	120	Economy	6700.00
0005432901921	120	Economy	6700.00
0005433103239	120	Economy	6700.00
0005433103322	120	Economy	6700.00
0005432920266	120	Economy	6700.00
0005432920385	120	Economy	6700.00
0005433103240	120	Economy	6700.00
0005432902018	120	Economy	6700.00
0005433103060	120	Economy	6700.00
0005433103337	120	Economy	6700.00
0005433103278	120	Economy	6700.00
0005432920356	120	Economy	6700.00
0005433103200	120	Economy	6700.00
0005432920337	120	Economy	6700.00
0005433103208	120	Economy	6700.00
0005432901993	120	Economy	6700.00
0005433103334	120	Economy	6700.00
0005433103216	120	Economy	6700.00
0005432902067	120	Economy	6700.00
0005432902023	120	Economy	6700.00
0005432902011	120	Economy	6700.00
0005432901992	120	Economy	6700.00
0005433103336	120	Economy	6700.00
0005432901977	120	Economy	6700.00
0005433103128	120	Economy	6700.00
0005432901978	120	Economy	6700.00
0005433477272	121	Business	20000.00
0005432818310	121	Business	20000.00
0005434157783	121	Business	20000.00
0005434157787	121	Business	20000.00
0005432263188	121	Business	20000.00
0005434152867	121	Business	20000.00
0005434157761	121	Business	20000.00
0005432263203	121	Business	20000.00
0005434157759	121	Business	20000.00
0005434157778	121	Business	20000.00
0005434157758	121	Business	20000.00
0005432263187	121	Business	20000.00
0005434157757	121	Business	20000.00
0005432263201	121	Business	20000.00
0005433477255	121	Business	20000.00
0005432289081	121	Business	20000.00
0005432818320	121	Economy	7300.00
0005433687734	121	Economy	7300.00
0005433477252	121	Economy	7300.00
0005433477254	121	Economy	7300.00
0005432263191	121	Economy	7300.00
0005434157786	121	Economy	7300.00
0005432207735	121	Economy	6700.00
0005433477271	121	Economy	6700.00
0005433477259	121	Economy	6700.00
0005432818318	121	Economy	6700.00
0005434157773	121	Economy	6700.00
0005432263196	121	Economy	6700.00
0005432263190	121	Economy	6700.00
0005432818313	121	Economy	6700.00
0005432263199	121	Economy	6700.00
0005432756895	121	Economy	6700.00
0005434157784	121	Economy	6700.00
0005432263192	121	Economy	6700.00
0005434157779	121	Economy	6700.00
0005432818314	121	Economy	6700.00
0005432263204	121	Economy	6700.00
0005432263189	121	Economy	6700.00
0005433477261	121	Economy	6700.00
0005433477262	121	Economy	6700.00
0005432818315	121	Economy	6700.00
0005432818317	121	Economy	6700.00
0005434157769	121	Economy	6700.00
0005434157772	121	Economy	6700.00
0005433477269	121	Economy	6700.00
0005432263198	121	Economy	6700.00
0005434157765	121	Economy	6700.00
0005432818319	121	Economy	6700.00
0005432756902	121	Economy	6700.00
0005433477251	121	Economy	6700.00
0005434157766	121	Economy	6700.00
0005432263200	121	Economy	6700.00
0005432263202	121	Economy	6700.00
0005434157789	121	Economy	6700.00
0005433477267	121	Economy	7300.00
0005433477266	121	Economy	7300.00
0005433477273	121	Economy	6700.00
0005432263194	121	Economy	6700.00
0005433477257	121	Economy	6700.00
0005434157785	121	Economy	6700.00
0005434152868	121	Economy	6700.00
0005432818311	121	Economy	6700.00
0005432756916	121	Economy	6700.00
0005434157776	121	Economy	6700.00
0005434157777	121	Economy	6700.00
0005434157775	121	Economy	6700.00
0005432818312	121	Economy	6700.00
0005432818316	121	Economy	6700.00
0005433477263	121	Economy	6700.00
0005433477265	121	Economy	6700.00
0005432289080	121	Economy	6700.00
0005434157764	121	Economy	6700.00
0005434157782	121	Economy	6700.00
0005434157774	121	Economy	6700.00
0005434157771	121	Economy	6700.00
0005433687753	121	Economy	6700.00
0005432818309	121	Economy	6700.00
0005432263193	121	Economy	6700.00
0005433477270	121	Economy	6700.00
0005434157760	121	Economy	6700.00
0005433477258	121	Economy	6700.00
0005434157770	121	Economy	6700.00
0005434157788	121	Economy	6700.00
0005432263195	121	Economy	6700.00
0005433690980	121	Economy	6700.00
0005433477268	121	Economy	6700.00
0005434157781	121	Economy	6700.00
0005432756912	121	Economy	6700.00
0005432753367	121	Economy	6700.00
0005433477256	121	Economy	6700.00
0005434157767	121	Economy	6700.00
0005434157768	121	Economy	6700.00
0005433477250	121	Economy	6700.00
0005433477264	121	Economy	6700.00
0005434157763	121	Economy	6700.00
0005433477253	121	Economy	6700.00
0005432263197	121	Economy	6700.00
0005434157780	121	Economy	6700.00
0005433477260	121	Economy	6700.00
0005434157762	121	Economy	6700.00
0005433435512	8156	Business	20000.00
0005433476977	8156	Business	20000.00
0005433439113	8156	Business	20000.00
0005432920462	8156	Business	20000.00
0005433103827	8156	Business	20000.00
0005433103823	8156	Business	20000.00
0005433103807	8156	Business	20000.00
0005433103832	8156	Business	20000.00
0005432920458	8156	Business	20000.00
0005433103801	8156	Business	20000.00
0005433435510	8156	Business	20000.00
0005433103799	8156	Business	20000.00
0005432021021	8156	Business	20000.00
0005433103810	8156	Business	20000.00
0005433103796	8156	Business	20000.00
0005432021020	8156	Business	20000.00
0005433103763	8156	Business	20000.00
0005433103808	8156	Business	20000.00
0005433103761	8156	Business	20000.00
0005433103802	8156	Business	20000.00
0005433103768	8156	Business	20000.00
0005432920463	8156	Economy	7300.00
0005433476969	8156	Economy	7300.00
0005433435513	8156	Economy	7300.00
0005433477008	8156	Economy	7300.00
0005433476971	8156	Economy	7300.00
0005433103776	8156	Economy	6700.00
0005432044605	8156	Economy	6700.00
0005433103798	8156	Economy	6700.00
0005433103805	8156	Economy	6700.00
0005433476979	8156	Economy	6700.00
0005433103780	8156	Economy	6700.00
0005433103785	8156	Economy	6700.00
0005433103792	8156	Economy	6700.00
0005433435511	8156	Economy	6700.00
0005433103793	8156	Economy	6700.00
0005432021022	8156	Economy	6700.00
0005432920460	8156	Economy	6700.00
0005433103778	8156	Economy	6700.00
0005433477003	8156	Economy	6700.00
0005433103815	8156	Economy	6700.00
0005433476987	8156	Economy	6700.00
0005432677688	8156	Economy	6700.00
0005433103786	8156	Economy	6700.00
0005433476981	8156	Economy	6700.00
0005433103781	8156	Economy	6700.00
0005432753399	8156	Economy	6700.00
0005433103791	8156	Economy	6700.00
0005433476975	8156	Economy	6700.00
0005432920453	8156	Economy	6700.00
0005433103811	8156	Economy	6700.00
0005433103794	8156	Economy	6700.00
0005433476972	8156	Economy	6700.00
0005433477021	8156	Economy	6700.00
0005433103817	8156	Economy	6700.00
0005433103821	8156	Economy	6700.00
0005433477001	8156	Economy	6700.00
0005433103830	8156	Economy	6700.00
0005432045669	8156	Economy	6700.00
0005433477010	8156	Economy	6700.00
0005433103788	8156	Economy	6700.00
0005433103822	8156	Economy	6700.00
0005433103814	8156	Economy	6700.00
0005432021025	8156	Economy	6700.00
0005433103820	8156	Economy	6700.00
0005433103806	8156	Economy	6700.00
0005433103829	8156	Economy	6700.00
0005433103772	8156	Economy	6700.00
0005433476965	8156	Economy	6700.00
0005433103760	8156	Economy	6700.00
0005433476968	8156	Economy	6700.00
0005432920455	8156	Economy	6700.00
0005433476966	8156	Economy	6700.00
0005433103831	8156	Economy	7300.00
0005433103826	8156	Economy	7300.00
0005433476980	8156	Economy	7300.00
0005433103784	8156	Economy	7300.00
0005433103800	8156	Economy	7300.00
0005432753398	8156	Economy	6700.00
0005433103779	8156	Economy	6700.00
0005433103813	8156	Economy	6700.00
0005433103828	8156	Economy	7300.00
0005432920456	8156	Economy	6700.00
0005432920461	8156	Economy	6700.00
0005432021026	8156	Economy	6700.00
0005433103774	8156	Economy	6700.00
0005433476970	8156	Economy	6700.00
0005433103787	8156	Economy	6700.00
0005433477002	8156	Economy	6700.00
0005433103783	8156	Economy	6700.00
0005433103767	8156	Economy	6700.00
0005432044606	8156	Economy	6700.00
0005433103825	8156	Economy	6700.00
0005433103818	8156	Economy	6700.00
0005433103765	8156	Economy	6700.00
0005432751624	8156	Economy	6700.00
0005433103790	8156	Economy	6700.00
0005432920454	8156	Economy	6700.00
0005432021024	8156	Economy	6700.00
0005433476978	8156	Economy	6700.00
0005433103766	8156	Economy	6700.00
0005432021023	8156	Economy	6700.00
0005433103773	8156	Economy	6700.00
0005433103812	8156	Economy	6700.00
0005433103777	8156	Economy	6700.00
0005433103762	8156	Economy	6700.00
0005432920459	8156	Economy	6700.00
0005432044604	8156	Economy	6700.00
0005433476982	8156	Economy	6700.00
0005433103804	8156	Economy	6700.00
0005433103819	8156	Economy	6700.00
0005433103797	8156	Economy	6700.00
0005433103771	8156	Economy	6700.00
0005433477012	8156	Economy	6700.00
0005433103782	8156	Economy	6700.00
0005433103764	8156	Economy	6700.00
0005432677687	8156	Economy	6700.00
0005432751625	8156	Economy	6700.00
0005433103824	8156	Economy	6700.00
0005433476976	8156	Economy	6700.00
0005433103795	8156	Economy	6700.00
0005433103769	8156	Economy	6700.00
0005433103789	8156	Economy	6700.00
0005432920457	8156	Economy	6700.00
0005433476983	8156	Economy	6700.00
0005433476992	8156	Economy	6700.00
0005433103816	8156	Economy	6700.00
0005433103809	8156	Economy	6700.00
0005433103803	8156	Economy	6700.00
0005432021019	8156	Economy	6700.00
0005433103775	8156	Economy	6700.00
0005432021018	8156	Economy	6700.00
0005433103770	8156	Economy	6700.00
0005432818077	8125	Business	20000.00
0005432818190	8125	Business	20000.00
0005432818050	8125	Business	20000.00
0005434513638	8125	Business	20000.00
0005432818136	8125	Business	20000.00
0005434513632	8125	Business	20000.00
0005434513630	8125	Economy	7300.00
0005432818085	8125	Economy	7300.00
0005432818199	8125	Economy	7300.00
0005432902110	8125	Economy	6700.00
0005432817865	8125	Economy	6700.00
0005432818198	8125	Economy	6700.00
0005434513645	8125	Economy	6700.00
0005432902108	8125	Economy	6700.00
0005432818174	8125	Economy	6700.00
0005434513635	8125	Economy	6700.00
0005432902107	8125	Economy	6700.00
0005432818167	8125	Economy	6700.00
0005432818145	8125	Economy	6700.00
0005434513644	8125	Economy	6700.00
0005432818212	8125	Economy	6700.00
0005432818137	8125	Economy	6700.00
0005432902109	8125	Economy	6700.00
0005432817977	8125	Economy	6700.00
0005432818028	8125	Economy	6700.00
0005434513626	8125	Economy	6700.00
0005432818125	8125	Economy	6700.00
0005432818175	8125	Economy	6700.00
0005432818076	8125	Economy	7300.00
0005432818142	8125	Economy	7300.00
0005434513631	8125	Economy	6700.00
0005434513628	8125	Economy	6700.00
0005432818173	8125	Economy	6700.00
0005432817864	8125	Economy	6700.00
0005432818041	8125	Economy	6700.00
0005434513629	8125	Economy	6700.00
0005432902106	8125	Economy	6700.00
0005432818124	8125	Economy	6700.00
0005434513627	8125	Economy	6700.00
0005432818013	8125	Economy	6700.00
0005432902111	8125	Economy	6700.00
0005432818108	8125	Economy	6700.00
0005432817981	8125	Economy	6700.00
0005432818014	8125	Economy	6700.00
0005432818211	8125	Economy	6700.00
0005432002137	8125	Economy	6700.00
0005432818144	8125	Economy	6700.00
0005432902105	8125	Economy	6700.00
0005432818020	8125	Economy	6700.00
0005432818143	8125	Economy	6700.00
0005432818037	8125	Economy	6700.00
0005432817979	8125	Economy	6700.00
0005434175839	9649	Economy	6900.00
0005434175850	9649	Economy	6900.00
0005434175858	9649	Economy	6900.00
0005433870797	9649	Economy	6900.00
0005434175849	9649	Economy	6900.00
0005435626815	3470	Business	35000.00
0005432611813	3470	Business	35000.00
0005435903123	3470	Business	35000.00
0005435626806	3470	Business	35000.00
0005435913992	3470	Business	35000.00
0005435127534	3470	Business	35000.00
0005435127537	3470	Business	35000.00
0005434880908	3470	Business	35000.00
0005432800249	3470	Business	35000.00
0005434427442	3470	Business	35000.00
0005435626800	3470	Business	35000.00
0005434938693	3470	Business	35000.00
0005435626802	3470	Business	35000.00
0005435903169	3470	Business	35000.00
0005434880912	3470	Business	35000.00
0005435127531	3470	Business	35000.00
0005434938704	3470	Business	35000.00
0005435903113	3470	Comfort	19900.00
0005435903072	3470	Comfort	19900.00
0005435626771	3470	Comfort	19900.00
0005434880903	3470	Comfort	19900.00
0005434880917	3470	Comfort	19900.00
0005435914009	3470	Comfort	19900.00
0005435626768	3470	Comfort	19900.00
0005434938698	3470	Comfort	19900.00
0005434938705	3470	Comfort	19900.00
0005434880934	3470	Comfort	19900.00
0005435626801	3470	Comfort	19900.00
0005434427443	3470	Comfort	19900.00
0005435626772	3470	Comfort	19900.00
0005434938706	3470	Comfort	19900.00
0005434880904	3470	Comfort	19900.00
0005434427447	3470	Comfort	19900.00
0005434880940	3470	Comfort	19900.00
0005434880936	3470	Comfort	19900.00
0005432800261	3470	Comfort	19900.00
0005432800253	3470	Comfort	19900.00
0005432611814	3470	Comfort	19900.00
0005435626779	3470	Economy	11700.00
0005434427441	3470	Economy	11700.00
0005435626809	3470	Economy	11700.00
0005435626803	3470	Economy	11700.00
0005435903041	3470	Economy	11700.00
0005435127532	3470	Economy	11700.00
0005434880905	3470	Economy	11700.00
0005435626805	3470	Economy	11700.00
0005434880929	3470	Economy	11700.00
0005434880938	3470	Economy	11700.00
0005434938697	3470	Economy	11700.00
0005435903020	3470	Economy	11700.00
0005434880932	3470	Economy	11700.00
0005434880927	3470	Economy	11700.00
0005434938695	3470	Economy	11700.00
0005435127548	3470	Economy	11700.00
0005434880906	3470	Economy	11700.00
0005435626777	3470	Economy	11700.00
0005435626783	3470	Economy	11700.00
0005435127528	3470	Economy	11700.00
0005434938694	3470	Economy	11700.00
0005434880921	3470	Economy	11700.00
0005435626789	3470	Economy	11700.00
0005434880916	3470	Economy	11700.00
0005434880910	3470	Economy	11700.00
0005434938699	3470	Economy	11700.00
0005434938703	3470	Economy	11700.00
0005434880900	3470	Economy	11700.00
0005435626810	3470	Economy	11700.00
0005435626782	3470	Economy	11700.00
0005434880914	3470	Economy	11700.00
0005435626773	3470	Economy	11700.00
0005434938700	3470	Economy	11700.00
0005434938701	3470	Economy	12800.00
0005432800250	3470	Economy	11700.00
0005435626807	3470	Economy	11700.00
0005435626813	3470	Economy	12800.00
0005434880915	3470	Economy	11700.00
0005435903042	3470	Economy	11700.00
0005435626786	3470	Economy	11700.00
0005435914743	3470	Economy	11700.00
0005435914032	3470	Economy	11700.00
0005435914030	3470	Economy	11700.00
0005435626794	3470	Economy	11700.00
0005435127549	3470	Economy	11700.00
0005434880923	3470	Economy	11700.00
0005435127546	3470	Economy	11700.00
0005434880935	3470	Economy	11700.00
0005435903047	3470	Economy	11700.00
0005435127524	3470	Economy	11700.00
0005432800260	3470	Economy	11700.00
0005435626791	3470	Economy	11700.00
0005432800251	3470	Economy	11700.00
0005435127542	3470	Economy	11700.00
0005432800258	3470	Economy	11700.00
0005432800254	3470	Economy	11700.00
0005434880930	3470	Economy	11700.00
0005435903074	3470	Economy	11700.00
0005434880926	3470	Economy	11700.00
0005434427448	3470	Economy	11700.00
0005434880922	3470	Economy	11700.00
0005435626788	3470	Economy	11700.00
0005435841111	3470	Economy	11700.00
0005435626785	3470	Economy	11700.00
0005435626770	3470	Economy	11700.00
0005434880901	3470	Economy	11700.00
0005435127547	3470	Economy	11700.00
0005435626799	3470	Economy	11700.00
0005434938696	3470	Economy	11700.00
0005435626798	3470	Economy	11700.00
0005435127526	3470	Economy	11700.00
0005435626792	3470	Economy	11700.00
0005435127539	3470	Economy	11700.00
0005435626784	3470	Economy	11700.00
0005432800256	3470	Economy	11700.00
0005435127525	3470	Economy	11700.00
0005434880925	3470	Economy	11700.00
0005435626778	3470	Economy	11700.00
0005435127541	3470	Economy	11700.00
0005435626796	3470	Economy	11700.00
0005434880899	3470	Economy	11700.00
0005435127535	3470	Economy	11700.00
0005435626811	3470	Economy	11700.00
0005435626774	3470	Economy	11700.00
0005435626795	3470	Economy	11700.00
0005435127538	3470	Economy	11700.00
0005434880931	3470	Economy	11700.00
0005435127540	3470	Economy	11700.00
0005435913988	3470	Economy	11700.00
0005435914041	3470	Economy	11700.00
0005435903034	3470	Economy	11700.00
0005435626808	3470	Economy	11700.00
0005434880913	3470	Economy	11700.00
0005432800252	3470	Economy	12800.00
0005434880933	3470	Economy	12800.00
0005435127543	3470	Economy	12800.00
0005435903073	3470	Economy	12800.00
0005435903149	3470	Economy	11700.00
0005434880918	3470	Economy	11700.00
0005435626812	3470	Economy	11700.00
0005435626793	3470	Economy	11700.00
0005435903046	3470	Economy	11700.00
0005435903040	3470	Economy	11700.00
0005435127551	3470	Economy	11700.00
0005434880907	3470	Economy	11700.00
0005432800259	3470	Economy	11700.00
0005434880924	3470	Economy	11700.00
0005434880928	3470	Economy	11700.00
0005435626814	3470	Economy	11700.00
0005432800257	3470	Economy	11700.00
0005435903124	3470	Economy	11700.00
0005435841841	3470	Economy	11700.00
0005435903157	3470	Economy	11700.00
0005435914010	3470	Economy	11700.00
0005434938702	3470	Economy	11700.00
0005435127530	3470	Economy	11700.00
0005435626776	3470	Economy	11700.00
0005435626780	3470	Economy	11700.00
0005434880920	3470	Economy	11700.00
0005435626769	3470	Economy	11700.00
0005435841116	3470	Economy	11700.00
0005435626816	3470	Economy	11700.00
0005435626817	3470	Economy	11700.00
0005435914008	3470	Economy	11700.00
0005435626781	3470	Economy	11700.00
0005435127545	3470	Economy	11700.00
0005435626775	3470	Economy	11700.00
0005435127529	3470	Economy	11700.00
0005434427445	3470	Economy	11700.00
0005434427446	3470	Economy	11700.00
0005435127533	3470	Economy	11700.00
0005435903063	3470	Economy	11700.00
0005432800262	3470	Economy	11700.00
0005435626787	3470	Economy	11700.00
0005434427449	3470	Economy	11700.00
0005435127536	3470	Economy	11700.00
0005435626790	3470	Economy	11700.00
0005435903033	3470	Economy	11700.00
0005434880939	3470	Economy	11700.00
0005432800255	3470	Economy	11700.00
0005434880937	3470	Economy	11700.00
0005434880911	3470	Economy	11700.00
0005435127527	3470	Economy	11700.00
0005432800263	3470	Economy	11700.00
0005434880902	3470	Economy	11700.00
0005435903048	3470	Economy	11700.00
0005434880919	3470	Economy	11700.00
0005435127544	3470	Economy	11700.00
0005435626797	3470	Economy	11700.00
0005435127550	3470	Economy	11700.00
0005434880909	3470	Economy	11700.00
0005434427444	3470	Economy	11700.00
0005435626804	3470	Economy	11700.00
0005435127195	14555	Business	35000.00
0005432799987	14555	Business	35000.00
0005432800108	14555	Business	35000.00
0005434427289	14555	Business	35000.00
0005434880430	14555	Business	35000.00
0005432800030	14555	Business	35000.00
0005434880244	14555	Business	35000.00
0005434938602	14555	Business	35000.00
0005434427212	14555	Business	35000.00
0005434880141	14555	Business	35000.00
0005434427118	14555	Business	35000.00
0005434427260	14555	Business	35000.00
0005435626516	14555	Business	35000.00
0005434880387	14555	Business	35000.00
0005434880585	14555	Business	35000.00
0005434427125	14555	Business	35000.00
0005432799978	14555	Business	35000.00
0005432611780	14555	Business	35000.00
0005435626498	14555	Business	35000.00
0005434880321	14555	Business	35000.00
0005434938646	14555	Business	35000.00
0005434938566	14555	Business	35000.00
0005434880067	14555	Comfort	19900.00
0005434879740	14555	Comfort	19900.00
0005434880480	14555	Comfort	19900.00
0005434427210	14555	Comfort	19900.00
0005434880432	14555	Comfort	19900.00
0005434427077	14555	Comfort	19900.00
0005432611791	14555	Comfort	19900.00
0005432800025	14555	Comfort	19900.00
0005434880307	14555	Comfort	19900.00
0005432799980	14555	Comfort	19900.00
0005435127349	14555	Comfort	19900.00
0005434427152	14555	Comfort	19900.00
0005435914171	14555	Comfort	19900.00
0005434938513	14555	Comfort	19900.00
0005434427241	14555	Comfort	19900.00
0005434880116	14555	Comfort	19900.00
0005432607638	14555	Comfort	19900.00
0005432611797	14555	Comfort	19900.00
0005434880261	14555	Comfort	19900.00
0005434880223	14555	Comfort	19900.00
0005435903209	14555	Comfort	19900.00
0005434880143	14555	Comfort	19900.00
0005434427282	14555	Comfort	19900.00
0005434427256	14555	Comfort	19900.00
0005434880115	14555	Comfort	19900.00
0005435127197	14555	Comfort	19900.00
0005435626554	14555	Comfort	19900.00
0005432800001	14555	Comfort	19900.00
0005435127201	14555	Comfort	19900.00
0005435127009	14555	Comfort	19900.00
0005432800153	14555	Comfort	19900.00
0005434427213	14555	Comfort	19900.00
0005435914178	14555	Economy	11700.00
0005435127156	14555	Comfort	19900.00
0005434880652	14555	Economy	11700.00
0005434880195	14555	Economy	11700.00
0005434880586	14555	Economy	11700.00
0005435914174	14555	Economy	11700.00
0005435914769	14555	Economy	11700.00
0005435914172	14555	Economy	11700.00
0005434880314	14555	Economy	11700.00
0005435914181	14555	Economy	11700.00
0005434880140	14555	Economy	11700.00
0005434880098	14555	Economy	11700.00
0005435626530	14555	Economy	11700.00
0005434880189	14555	Economy	11700.00
0005434880346	14555	Economy	11700.00
0005434880162	14555	Economy	11700.00
0005434880268	14555	Economy	11700.00
0005434880121	14555	Economy	11700.00
0005435127257	14555	Economy	11700.00
0005434427187	14555	Economy	11700.00
0005434880127	14555	Economy	11700.00
0005434880262	14555	Economy	11700.00
0005434880203	14555	Economy	11700.00
0005435127147	14555	Economy	11700.00
0005434427257	14555	Economy	11700.00
0005434880443	14555	Economy	11700.00
0005435626473	14555	Economy	11700.00
0005435127282	14555	Economy	11700.00
0005435626537	14555	Economy	11700.00
0005435903210	14555	Economy	11700.00
0005434880433	14555	Economy	11700.00
0005435126970	14555	Economy	11700.00
0005434879855	14555	Economy	11700.00
0005434938506	14555	Economy	11700.00
0005434880377	14555	Economy	11700.00
0005432800043	14555	Economy	11700.00
0005434427214	14555	Economy	11700.00
0005435127106	14555	Economy	11700.00
0005435127145	14555	Economy	11700.00
0005434880577	14555	Economy	11700.00
0005434427276	14555	Economy	11700.00
0005435914168	14555	Economy	11700.00
0005434938565	14555	Economy	11700.00
0005434880243	14555	Economy	11700.00
0005432799986	14555	Economy	11700.00
0005435914170	14555	Economy	11700.00
0005435903211	14555	Economy	11700.00
0005434880431	14555	Economy	11700.00
0005435127252	14555	Economy	11700.00
0005432800039	14555	Economy	11700.00
0005435127283	14555	Economy	11700.00
0005435914169	14555	Economy	11700.00
0005435914175	14555	Economy	11700.00
0005434427170	14555	Economy	12800.00
0005432800117	14555	Economy	11700.00
0005435903206	14555	Economy	12800.00
0005435903212	14555	Economy	11700.00
0005435127183	14555	Economy	12800.00
0005435127194	14555	Economy	11700.00
0005435127303	14555	Economy	11700.00
0005434880324	14555	Economy	11700.00
0005434938575	14555	Economy	11700.00
0005435914179	14555	Economy	11700.00
0005435914167	14555	Economy	11700.00
0005435914166	14555	Economy	11700.00
0005434880204	14555	Economy	11700.00
0005435127329	14555	Economy	11700.00
0005435127135	14555	Economy	11700.00
0005435914162	14555	Economy	11700.00
0005435127100	14555	Economy	11700.00
0005434880192	14555	Economy	11700.00
0005434880269	14555	Economy	11700.00
0005434879973	14555	Economy	11700.00
0005434427272	14555	Economy	11700.00
0005435127208	14555	Economy	11700.00
0005434879794	14555	Economy	11700.00
0005435127227	14555	Economy	11700.00
0005434427300	14555	Economy	11700.00
0005432799979	14555	Economy	11700.00
0005435127296	14555	Economy	11700.00
0005435127144	14555	Economy	11700.00
0005434427269	14555	Economy	11700.00
0005435127350	14555	Economy	11700.00
0005435914765	14555	Economy	11700.00
0005434879795	14555	Economy	11700.00
0005434427339	14555	Economy	11700.00
0005434427271	14555	Economy	11700.00
0005434427123	14555	Economy	11700.00
0005432800066	14555	Economy	11700.00
0005434427148	14555	Economy	11700.00
0005434427290	14555	Economy	11700.00
0005434880139	14555	Economy	11700.00
0005434880114	14555	Economy	11700.00
0005434880161	14555	Economy	11700.00
0005434880191	14555	Economy	11700.00
0005435914180	14555	Economy	11700.00
0005434427147	14555	Economy	11700.00
0005434880276	14555	Economy	11700.00
0005434427178	14555	Economy	11700.00
0005434427338	14555	Economy	11700.00
0005435914768	14555	Economy	11700.00
0005434880283	14555	Economy	11700.00
0005434880470	14555	Economy	11700.00
0005435914176	14555	Economy	11700.00
0005432799953	14555	Economy	11700.00
0005432800038	14555	Economy	11700.00
0005432800007	14555	Economy	11700.00
0005434938619	14555	Economy	11700.00
0005434880298	14555	Economy	11700.00
0005432800175	14555	Economy	11700.00
0005432800205	14555	Economy	11700.00
0005434880538	14555	Economy	11700.00
0005434880284	14555	Economy	11700.00
0005435127111	14555	Economy	11700.00
0005435127242	14555	Economy	11700.00
0005435127130	14555	Economy	11700.00
0005435914173	14555	Economy	11700.00
0005434880126	14555	Economy	11700.00
0005435626550	14555	Economy	11700.00
0005435914177	14555	Economy	11700.00
0005434880197	14555	Economy	11700.00
0005434880275	14555	Economy	11700.00
0005432800065	14555	Economy	11700.00
0005434938624	14555	Economy	11700.00
0005435626549	14555	Economy	11700.00
0005434880273	14555	Economy	11700.00
0005432800078	14555	Economy	11700.00
0005435127146	14555	Economy	11700.00
0005434938567	14555	Economy	11700.00
0005435626548	14555	Economy	11700.00
0005435903213	14555	Economy	11700.00
0005432799952	14555	Economy	11700.00
0005434427165	14555	Economy	11700.00
0005435127193	14555	Economy	11700.00
0005434427236	14555	Economy	11700.00
0005432611796	14555	Economy	11700.00
0005435127101	14555	Economy	11700.00
0005434938585	14555	Economy	11700.00
0005434880144	14555	Economy	11700.00
0005434427124	14555	Economy	11700.00
0005435914165	14555	Economy	11700.00
0005435127151	14555	Economy	11700.00
0005432800042	14555	Economy	11700.00
0005435914770	14555	Economy	11700.00
0005435903207	14555	Economy	11700.00
0005435626543	14555	Economy	12800.00
0005434880145	14555	Economy	12800.00
0005434938542	14555	Economy	12800.00
0005434427122	14555	Economy	11700.00
0005434880174	14555	Economy	11700.00
0005434427253	14555	Economy	11700.00
0005434427275	14555	Economy	11700.00
0005435127110	14555	Economy	11700.00
0005432799992	14555	Economy	11700.00
0005432800154	14555	Economy	11700.00
0005432800110	14555	Economy	11700.00
0005432800209	14555	Economy	11700.00
0005435903214	14555	Economy	11700.00
0005434427232	14555	Economy	11700.00
0005434879841	14555	Economy	11700.00
0005434880356	14555	Economy	11700.00
0005434880183	14555	Economy	11700.00
0005434427281	14555	Economy	11700.00
0005434880404	14555	Economy	11700.00
0005435903208	14555	Economy	11700.00
0005434427240	14555	Economy	11700.00
0005435842351	14555	Economy	11700.00
0005435914767	14555	Economy	11700.00
0005434427145	14555	Economy	11700.00
0005434880045	14555	Economy	11700.00
0005434427291	14555	Economy	11700.00
0005434880201	14555	Economy	11700.00
0005434880320	14555	Economy	11700.00
0005435914164	14555	Economy	11700.00
0005434427177	14555	Economy	11700.00
0005434880125	14555	Economy	11700.00
0005435626523	14555	Economy	11700.00
0005434880322	14555	Economy	11700.00
0005434880325	14555	Economy	11700.00
0005434880603	14555	Economy	11700.00
0005432800005	14555	Economy	11700.00
0005434879972	14555	Economy	11700.00
0005435127273	14555	Economy	11700.00
0005434880046	14555	Economy	11700.00
0005435903205	14555	Economy	11700.00
0005434427387	14555	Economy	11700.00
0005434880386	14555	Economy	11700.00
0005432800162	14555	Economy	11700.00
0005434880202	14555	Economy	11700.00
0005434938625	14555	Economy	11700.00
0005435127211	14555	Economy	11700.00
0005434427146	14555	Economy	11700.00
0005435127198	14555	Economy	11700.00
0005434880347	14555	Economy	11700.00
0005434880206	14555	Economy	11700.00
0005434880017	14555	Economy	11700.00
0005434880196	14555	Economy	11700.00
0005432800024	14555	Economy	11700.00
0005435127224	14555	Economy	11700.00
0005434880447	14555	Economy	11700.00
0005435914163	14555	Economy	11700.00
0005435626515	14555	Economy	11700.00
0005434880224	14555	Economy	11700.00
0005434880301	14555	Economy	11700.00
0005435626551	14555	Economy	11700.00
0005434879981	14555	Economy	11700.00
0005434938584	14555	Economy	11700.00
0005435127225	14555	Economy	11700.00
0005434427235	14555	Economy	11700.00
0005435914766	14555	Economy	11700.00
0005435126969	14555	Economy	11700.00
0005434880448	14555	Economy	11700.00
0005435127026	14555	Economy	11700.00
0005432800008	14555	Economy	11700.00
0005434938615	14555	Economy	11700.00
0005432800109	14555	Economy	11700.00
0005435842352	14555	Economy	11700.00
0005434879856	14555	Economy	11700.00
0005434880583	14555	Economy	11700.00
0005434880245	14555	Economy	11700.00
0005434879739	14555	Economy	11700.00
0005434879857	14555	Economy	11700.00
0005435127090	14555	Economy	11700.00
0005434880306	14555	Economy	11700.00
0005434880299	14555	Economy	11700.00
0005435127077	14555	Economy	11700.00
0005434880190	14555	Economy	11700.00
0005435127223	14555	Economy	11700.00
0005432611790	14555	Economy	11700.00
0005434880099	14555	Economy	11700.00
0005435890022	3631	Economy	14800.00
0005434325977	3631	Economy	14800.00
0005435890003	3631	Economy	14800.00
0005434325976	3631	Economy	14800.00
0005434325974	3631	Economy	14800.00
0005435890041	3631	Economy	14800.00
0005435890020	3631	Economy	14800.00
0005435890030	3631	Economy	14800.00
0005435890021	3631	Economy	14800.00
0005434312395	3631	Economy	14800.00
0005435890024	3631	Economy	14800.00
0005434325975	3631	Economy	14800.00
0005434312396	3631	Economy	14800.00
0005434312380	3631	Economy	14800.00
0005434312379	3631	Economy	14800.00
0005435890016	3631	Economy	14800.00
0005435890031	3631	Economy	14800.00
0005435890071	15600	Economy	14800.00
0005434325874	15600	Economy	14800.00
0005434325908	15600	Economy	14800.00
0005434325891	15600	Economy	14800.00
0005434325878	15600	Economy	14800.00
0005434325895	15600	Economy	14800.00
0005434325873	15600	Economy	14800.00
0005434325877	15600	Economy	14800.00
0005434325913	15600	Economy	14800.00
0005434325912	15600	Economy	14800.00
0005435890072	15600	Economy	14800.00
0005434325846	15600	Economy	14800.00
0005434325795	15600	Economy	14800.00
0005435958115	617	Economy	4500.00
0005433420548	617	Economy	4100.00
0005433420585	617	Economy	4100.00
0005433420549	617	Economy	4100.00
0005433420615	617	Economy	4100.00
0005433420556	617	Economy	4100.00
0005435958114	617	Economy	4100.00
0005433420607	617	Economy	4100.00
0005433420603	617	Economy	4100.00
0005435958118	617	Economy	4100.00
0005433420604	617	Economy	4100.00
0005433420554	617	Economy	4100.00
0005435958116	617	Economy	4100.00
0005433420568	617	Economy	4100.00
0005435958117	617	Economy	4100.00
0005435958008	15204	Economy	4500.00
0005433420641	15204	Economy	4100.00
0005435958023	15204	Economy	4100.00
0005435958007	15204	Economy	4100.00
0005435957996	15204	Economy	4100.00
0005433420643	15204	Economy	4100.00
0005433420642	15204	Economy	4100.00
0005435958024	15204	Economy	4100.00
0005435958076	15204	Economy	4100.00
0005435957979	15204	Economy	4100.00
0005433420644	15204	Economy	4100.00
0005435958025	15204	Economy	4100.00
0005435958006	15204	Economy	4100.00
0005435958039	15204	Economy	4100.00
0005435221067	27272	Economy	28100.00
0005435216625	27272	Economy	28100.00
0005435219239	27272	Economy	28100.00
0005435216630	27272	Economy	25500.00
0005435219245	27272	Economy	25500.00
0005435221075	27272	Economy	25500.00
0005435221066	27272	Economy	25500.00
0005435221070	27272	Economy	25500.00
0005435216623	27272	Economy	25500.00
0005435219242	27272	Economy	25500.00
0005435216628	27272	Economy	25500.00
0005435219246	27272	Economy	25500.00
0005435216626	27272	Economy	25500.00
0005435216622	27272	Economy	25500.00
0005435216629	27272	Economy	25500.00
0005435219230	27272	Economy	25500.00
0005435219243	27272	Economy	25500.00
0005435221071	27272	Economy	25500.00
0005435216624	27272	Economy	25500.00
0005435219238	27272	Economy	25500.00
0005435219241	27272	Economy	25500.00
0005435221069	27272	Economy	25500.00
0005435219237	27272	Economy	25500.00
0005435216621	27272	Economy	25500.00
0005434247210	8901	Economy	10400.00
0005434247208	8901	Economy	10400.00
0005434247195	8901	Economy	10400.00
0005434247209	8901	Economy	10400.00
0005435426859	16094	Economy	10400.00
0005435426858	16094	Economy	10400.00
0005434247221	16094	Economy	10400.00
0005435629433	16094	Economy	10400.00
0005435426860	16094	Economy	10400.00
0005435629438	16094	Economy	10400.00
0005435629437	16094	Economy	10400.00
0005435933516	4434	Economy	13400.00
0005435933544	4434	Economy	12200.00
0005435163377	4434	Economy	12200.00
0005435933520	4434	Economy	12200.00
0005435163378	4434	Economy	12200.00
0005435163380	4434	Economy	12200.00
0005435163382	4434	Economy	12200.00
0005435933527	4434	Economy	12200.00
0005435163379	4434	Economy	12200.00
0005435163383	4434	Economy	12200.00
0005435933521	4434	Economy	12200.00
0005435933522	4434	Economy	12200.00
0005435163381	4434	Economy	12200.00
0005433404987	2875	Business	12600.00
0005433404962	2875	Business	12600.00
0005433404963	2875	Business	12600.00
0005433404990	2875	Business	12600.00
0005435797885	2875	Economy	4200.00
0005433404955	2875	Economy	4200.00
0005433404954	2875	Economy	4200.00
0005435797884	2875	Economy	4200.00
0005435797882	2875	Economy	4200.00
0005433404960	2875	Economy	4200.00
0005435797883	2875	Economy	4200.00
0005435797889	2875	Economy	4200.00
0005435797887	2875	Economy	4200.00
0005433404961	2875	Economy	4200.00
0005435797888	2875	Economy	4200.00
0005433404968	2875	Economy	4200.00
0005435797886	2875	Economy	4200.00
0005433405028	29315	Business	12600.00
0005435797798	29315	Business	12600.00
0005433405026	29315	Economy	4600.00
0005435797827	29315	Economy	4600.00
0005435797828	29315	Economy	4200.00
0005433405030	29315	Economy	4200.00
0005435797839	29315	Economy	4200.00
0005435797797	29315	Economy	4200.00
0005435797796	29315	Economy	4200.00
0005435797840	29315	Economy	4200.00
0005435797801	29315	Economy	4200.00
0005435797802	29315	Economy	4200.00
0005435797763	29315	Economy	4200.00
0005435797829	29315	Economy	4200.00
0005435797800	29315	Economy	4200.00
0005433405027	29315	Economy	4200.00
0005433405025	29315	Economy	4200.00
0005435797778	29315	Economy	4200.00
0005433405029	29315	Economy	4200.00
0005435797830	29315	Economy	4200.00
0005433405031	29315	Economy	4200.00
0005435797762	29315	Economy	4200.00
0005435376409	5763	Economy	6800.00
0005435376407	5763	Economy	6800.00
0005435376408	5763	Economy	6800.00
0005434948260	5747	Economy	6800.00
0005434948258	5747	Economy	6800.00
0005434948257	5747	Economy	6800.00
0005434948259	5747	Economy	6800.00
0005434948255	5747	Economy	6800.00
0005434948254	5747	Economy	6800.00
0005434948256	5747	Economy	6800.00
0005434948261	5747	Economy	6800.00
0005434948224	16315	Economy	6800.00
0005434948206	16315	Economy	6800.00
0005434948198	16315	Economy	6800.00
0005435376428	16315	Economy	6800.00
0005434948205	16315	Economy	6800.00
0005434948245	16315	Economy	6800.00
0005435376429	16315	Economy	6800.00
0005434948225	16315	Economy	6800.00
0005434948157	16315	Economy	6800.00
0005434948219	16315	Economy	6800.00
0005434948158	16315	Economy	6800.00
0005434948197	16315	Economy	6800.00
0005433962630	6855	Business	21400.00
0005433962656	6855	Business	21400.00
0005433962603	6855	Business	21400.00
0005433962643	6855	Business	21400.00
0005433962598	6855	Business	21400.00
0005433962615	6855	Business	21400.00
0005433962659	6855	Business	21400.00
0005433962632	6855	Business	21400.00
0005433962609	6855	Business	21400.00
0005433962612	6855	Business	21400.00
0005433962614	6855	Business	21400.00
0005433962600	6855	Economy	7100.00
0005433962613	6855	Economy	7100.00
0005433962650	6855	Economy	7100.00
0005433962624	6855	Economy	7100.00
0005433962620	6855	Economy	7100.00
0005433962629	6855	Economy	7800.00
0005433962597	6855	Economy	7800.00
0005433962642	6855	Economy	7800.00
0005433962658	6855	Economy	7100.00
0005433962619	6855	Economy	7100.00
0005433962602	6855	Economy	7100.00
0005433962645	6855	Economy	7100.00
0005433962611	6855	Economy	7100.00
0005433962604	6855	Economy	7100.00
0005433962638	6855	Economy	7100.00
0005433962644	6855	Economy	7100.00
0005433962592	6855	Economy	7100.00
0005433962610	6855	Economy	7100.00
0005433962652	6855	Economy	7100.00
0005433962625	6855	Economy	7100.00
0005433962599	6855	Economy	7100.00
0005433962655	6855	Economy	7100.00
0005433962606	6855	Economy	7100.00
0005433962622	6855	Economy	7100.00
0005433962657	6855	Economy	7100.00
0005433962649	6855	Economy	7100.00
0005433962647	6855	Economy	7100.00
0005433962601	6855	Economy	7100.00
0005433962605	6855	Economy	7100.00
0005433962627	6855	Economy	7100.00
0005433962637	6855	Economy	7100.00
0005433962621	6855	Economy	7100.00
0005433962640	6855	Economy	7100.00
0005433962651	6855	Economy	7100.00
0005433962594	6855	Economy	7100.00
0005433962654	6855	Economy	7100.00
0005433962634	6855	Economy	7100.00
0005433962636	6855	Economy	7100.00
0005433962591	6855	Economy	7100.00
0005433962653	6855	Economy	7100.00
0005433962617	6855	Economy	7100.00
0005433962608	6855	Economy	7100.00
0005433962633	6855	Economy	7100.00
0005433962593	6855	Economy	7100.00
0005433962628	6855	Economy	7100.00
0005433962631	6855	Economy	7100.00
0005433962607	6855	Economy	7100.00
0005433962641	6855	Economy	7100.00
0005433962639	6855	Economy	7100.00
0005433962635	6855	Economy	7100.00
0005433962616	6855	Economy	7100.00
0005433962623	6855	Economy	7100.00
0005433962596	6855	Economy	7100.00
0005433962626	6855	Economy	7100.00
0005433962646	6855	Economy	7100.00
0005433962618	6855	Economy	7100.00
0005433962648	6855	Economy	7100.00
0005433962595	6855	Economy	7100.00
0005433961656	25714	Business	21400.00
0005433961988	25714	Business	21400.00
0005433961833	25714	Business	21400.00
0005433961989	25714	Business	21400.00
0005433961899	25714	Business	21400.00
0005433962012	25714	Business	21400.00
0005433961991	25714	Business	21400.00
0005433961885	25714	Business	21400.00
0005433961975	25714	Economy	7100.00
0005433961970	25714	Economy	7100.00
0005433961654	25714	Economy	7100.00
0005433961904	25714	Economy	7100.00
0005433962013	25714	Economy	7100.00
0005433961902	25714	Economy	7100.00
0005433961896	25714	Economy	7100.00
0005433961881	25714	Economy	7800.00
0005433961907	25714	Economy	7800.00
0005433961971	25714	Economy	7800.00
0005433961781	25714	Economy	7100.00
0005433961923	25714	Economy	7100.00
0005433961949	25714	Economy	7100.00
0005433961717	25714	Economy	7100.00
0005433962010	25714	Economy	7100.00
0005433961994	25714	Economy	7100.00
0005433961979	25714	Economy	7100.00
0005433961742	25714	Economy	7100.00
0005433961950	25714	Economy	7100.00
0005433961878	25714	Economy	7100.00
0005433962029	25714	Economy	7100.00
0005433962007	25714	Economy	7100.00
0005433961714	25714	Economy	7100.00
0005433961756	25714	Economy	7100.00
0005433961851	25714	Economy	7100.00
0005433961882	25714	Economy	7100.00
0005433961980	25714	Economy	7100.00
0005433961883	25714	Economy	7100.00
0005433961757	25714	Economy	7100.00
0005433962016	25714	Economy	7100.00
0005433961715	25714	Economy	7100.00
0005433962020	25714	Economy	7100.00
0005433961811	25714	Economy	7100.00
0005433961879	25714	Economy	7100.00
0005433962008	25714	Economy	7100.00
0005433961915	25714	Economy	7100.00
0005433962028	25714	Economy	7100.00
0005433961877	25714	Economy	7100.00
0005433961884	25714	Economy	7100.00
0005433961718	25714	Economy	7100.00
0005433961812	25714	Economy	7100.00
0005433962009	25714	Economy	7100.00
0005433961916	25714	Economy	7100.00
0005433961741	25714	Economy	7100.00
0005433961954	25714	Economy	7100.00
0005433961901	25714	Economy	7100.00
0005433962026	25714	Economy	7100.00
0005433962017	25714	Economy	7100.00
0005433961703	25714	Economy	7100.00
0005433961773	25714	Economy	7100.00
0005433961957	25714	Economy	7100.00
0005433962018	25714	Economy	7100.00
0005433961854	25714	Economy	7100.00
0005433961965	25714	Economy	7100.00
0005433961782	25714	Economy	7100.00
0005435082973	24545	Economy	3900.00
0005435082968	24545	Economy	3900.00
0005435082962	24545	Economy	3900.00
0005435082943	24545	Economy	3900.00
0005435082914	24545	Economy	3900.00
0005435082942	24545	Economy	3900.00
0005435082915	24545	Economy	3900.00
0005435082955	24545	Economy	3900.00
0005435082961	24545	Economy	3900.00
0005435083021	26150	Economy	3900.00
0005435083020	26150	Economy	3900.00
0005435083022	26150	Economy	3900.00
0005435083016	26150	Economy	3900.00
0005435083019	26150	Economy	3900.00
0005435083024	26150	Economy	3900.00
0005435083017	26150	Economy	3900.00
0005435083018	26150	Economy	3900.00
0005435083023	26150	Economy	3900.00
0005434245824	5168	Business	18000.00
0005435286740	5168	Business	18000.00
0005435286739	5168	Business	18000.00
0005435286714	5168	Business	18000.00
0005434245819	5168	Business	18000.00
0005432166992	5168	Business	18000.00
0005434245827	5168	Economy	6600.00
0005434245818	5168	Economy	6000.00
0005435286727	5168	Economy	6000.00
0005435286744	5168	Economy	6000.00
0005434245825	5168	Economy	6000.00
0005435286737	5168	Economy	6000.00
0005435286741	5168	Economy	6000.00
0005434245817	5168	Economy	6000.00
0005435286738	5168	Economy	6000.00
0005432166993	5168	Economy	6600.00
0005433534545	5168	Economy	6000.00
0005434245816	5168	Economy	6000.00
0005434245822	5168	Economy	6000.00
0005434245821	5168	Economy	6000.00
0005434245815	5168	Economy	6000.00
0005435286742	5168	Economy	6000.00
0005434245826	5168	Economy	6000.00
0005434245820	5168	Economy	6000.00
0005434245823	5168	Economy	6000.00
0005435286745	5168	Economy	6000.00
0005433616787	5171	Business	18000.00
0005433786122	5171	Business	18000.00
0005434230060	5171	Business	18000.00
0005433616764	5171	Business	18000.00
0005432106920	5171	Business	18000.00
0005434230082	5171	Business	18000.00
0005433616756	5171	Business	18000.00
0005432106911	5171	Business	18000.00
0005434230076	5171	Business	18000.00
0005433786095	5171	Business	18000.00
0005433616761	5171	Business	18000.00
0005434230069	5171	Business	18000.00
0005434230063	5171	Business	18000.00
0005434230074	5171	Business	18000.00
0005433616773	5171	Business	18000.00
0005434230068	5171	Business	18000.00
0005432106917	5171	Business	18000.00
0005433616757	5171	Business	18000.00
0005434230077	5171	Business	18000.00
0005433786103	5171	Business	18000.00
0005432106914	5171	Business	18000.00
0005433616771	5171	Economy	6600.00
0005433616781	5171	Economy	6600.00
0005434230080	5171	Economy	6600.00
0005433616785	5171	Economy	6600.00
0005432106912	5171	Economy	6600.00
0005434230072	5171	Economy	6000.00
0005432106925	5171	Economy	6000.00
0005433786099	5171	Economy	6000.00
0005432106926	5171	Economy	6000.00
0005433786105	5171	Economy	6000.00
0005433786113	5171	Economy	6000.00
0005434230064	5171	Economy	6000.00
0005432665332	5171	Economy	6000.00
0005434230062	5171	Economy	6000.00
0005433786119	5171	Economy	6000.00
0005433786102	5171	Economy	6000.00
0005433616772	5171	Economy	6000.00
0005434230065	5171	Economy	6000.00
0005432106928	5171	Economy	6000.00
0005433786118	5171	Economy	6000.00
0005434230071	5171	Economy	6000.00
0005432665333	5171	Economy	6000.00
0005433786110	5171	Economy	6000.00
0005433616790	5171	Economy	6000.00
0005433616784	5171	Economy	6000.00
0005433616763	5171	Economy	6000.00
0005433616788	5171	Economy	6000.00
0005433616766	5171	Economy	6000.00
0005432106924	5171	Economy	6000.00
0005432106919	5171	Economy	6000.00
0005433616770	5171	Economy	6000.00
0005432106916	5171	Economy	6000.00
0005434230066	5171	Economy	6000.00
0005433616776	5171	Economy	6000.00
0005433616774	5171	Economy	6000.00
0005433786114	5171	Economy	6000.00
0005433786123	5171	Economy	6000.00
0005433786121	5171	Economy	6000.00
0005433616768	5171	Economy	6000.00
0005433616786	5171	Economy	6000.00
0005434230067	5171	Economy	6000.00
0005434230075	5171	Economy	6000.00
0005433786111	5171	Economy	6000.00
0005433616777	5171	Economy	6000.00
0005434230081	5171	Economy	6000.00
0005433616760	5171	Economy	6000.00
0005433616782	5171	Economy	6000.00
0005432106930	5171	Economy	6000.00
0005432106927	5171	Economy	6000.00
0005432106922	5171	Economy	6600.00
0005433786128	5171	Economy	6600.00
0005433616758	5171	Economy	6600.00
0005433616765	5171	Economy	6600.00
0005433786096	5171	Economy	6000.00
0005434230070	5171	Economy	6000.00
0005432106908	5171	Economy	6000.00
0005433616789	5171	Economy	6000.00
0005433616779	5171	Economy	6600.00
0005433786127	5171	Economy	6000.00
0005434230059	5171	Economy	6000.00
0005432106931	5171	Economy	6000.00
0005433786129	5171	Economy	6000.00
0005434230061	5171	Economy	6000.00
0005433616778	5171	Economy	6000.00
0005433786125	5171	Economy	6000.00
0005433786097	5171	Economy	6000.00
0005433786130	5171	Economy	6000.00
0005432106910	5171	Economy	6000.00
0005432106918	5171	Economy	6000.00
0005432106923	5171	Economy	6000.00
0005433786106	5171	Economy	6000.00
0005434230083	5171	Economy	6000.00
0005433786107	5171	Economy	6000.00
0005432106913	5171	Economy	6000.00
0005433616775	5171	Economy	6000.00
0005433786126	5171	Economy	6000.00
0005433786094	5171	Economy	6000.00
0005433786112	5171	Economy	6000.00
0005433786116	5171	Economy	6000.00
0005433616767	5171	Economy	6000.00
0005433616762	5171	Economy	6000.00
0005433786104	5171	Economy	6000.00
0005433786109	5171	Economy	6000.00
0005433786108	5171	Economy	6000.00
0005433786115	5171	Economy	6000.00
0005433616783	5171	Economy	6000.00
0005432106909	5171	Economy	6000.00
0005433616759	5171	Economy	6000.00
0005432106929	5171	Economy	6000.00
0005434230085	5171	Economy	6000.00
0005433616769	5171	Economy	6000.00
0005432145170	5171	Economy	6000.00
0005433786098	5171	Economy	6000.00
0005434230084	5171	Economy	6000.00
0005432665334	5171	Economy	6000.00
0005434230078	5171	Economy	6000.00
0005433786100	5171	Economy	6000.00
0005432106921	5171	Economy	6000.00
0005432106915	5171	Economy	6000.00
0005432145171	5171	Economy	6000.00
0005433616780	5171	Economy	6000.00
0005433786124	5171	Economy	6000.00
0005434230079	5171	Economy	6000.00
0005434230073	5171	Economy	6000.00
0005433786101	5171	Economy	6000.00
0005433786120	5171	Economy	6000.00
0005433786117	5171	Economy	6000.00
0005435269921	5192	Business	18000.00
0005435270014	5192	Business	18000.00
0005434173662	5192	Business	18000.00
0005433815493	5192	Business	18000.00
0005435269954	5192	Business	18000.00
0005434265878	5192	Business	18000.00
0005435270045	5192	Business	18000.00
0005432336304	5192	Business	18000.00
0005433815495	5192	Business	18000.00
0005435269993	5192	Business	18000.00
0005435270060	5192	Business	18000.00
0005435269883	5192	Business	18000.00
0005432336268	5192	Business	18000.00
0005435270013	5192	Business	18000.00
0005435007493	5192	Business	18000.00
0005434230021	5192	Business	18000.00
0005435269902	5192	Business	18000.00
0005434150069	5192	Business	18000.00
0005435270039	5192	Business	18000.00
0005435007479	5192	Business	18000.00
0005435007513	5192	Business	18000.00
0005434150067	5192	Business	18000.00
0005435269989	5192	Economy	6600.00
0005435007428	5192	Economy	6600.00
0005435269906	5192	Economy	6600.00
0005435007563	5192	Economy	6600.00
0005435007481	5192	Economy	6600.00
0005434230020	5192	Economy	6600.00
0005435269953	5192	Economy	6000.00
0005435007591	5192	Economy	6000.00
0005435269995	5192	Economy	6000.00
0005435007496	5192	Economy	6000.00
0005435270047	5192	Economy	6000.00
0005435007507	5192	Economy	6000.00
0005434265870	5192	Economy	6000.00
0005434230015	5192	Economy	6000.00
0005435269925	5192	Economy	6000.00
0005434173663	5192	Economy	6000.00
0005432336242	5192	Economy	6000.00
0005435270015	5192	Economy	6000.00
0005435269917	5192	Economy	6000.00
0005435269888	5192	Economy	6000.00
0005433815465	5192	Economy	6000.00
0005435269985	5192	Economy	6000.00
0005432336276	5192	Economy	6000.00
0005435269924	5192	Economy	6000.00
0005435007600	5192	Economy	6000.00
0005434265873	5192	Economy	6000.00
0005434265872	5192	Economy	6000.00
0005435007514	5192	Economy	6000.00
0005434230019	5192	Economy	6000.00
0005435269963	5192	Economy	6000.00
0005435269916	5192	Economy	6000.00
0005434265875	5192	Economy	6000.00
0005434230012	5192	Economy	6000.00
0005435007565	5192	Economy	6000.00
0005435270043	5192	Economy	6000.00
0005435007553	5192	Economy	6000.00
0005432336269	5192	Economy	6000.00
0005435269890	5192	Economy	6000.00
0005435269992	5192	Economy	6000.00
0005435270041	5192	Economy	6000.00
0005434311265	5192	Economy	6000.00
0005434230011	5192	Economy	6000.00
0005434311266	5192	Economy	6000.00
0005434150070	5192	Economy	6000.00
0005433685577	5192	Economy	6000.00
0005435007482	5192	Economy	6000.00
0005432336303	5192	Economy	6000.00
0005434230017	5192	Economy	6000.00
0005435007521	5192	Economy	6000.00
0005432336206	5192	Economy	6000.00
0005435269889	5192	Economy	6000.00
0005434311259	5192	Economy	6000.00
0005434230018	5192	Economy	6000.00
0005435270040	5192	Economy	6000.00
0005432336266	5192	Economy	6000.00
0005435007520	5192	Economy	6000.00
0005435270046	5192	Economy	6600.00
0005435270042	5192	Economy	6600.00
0005434230013	5192	Economy	6600.00
0005434265871	5192	Economy	6600.00
0005435269962	5192	Economy	6000.00
0005435269887	5192	Economy	6000.00
0005434150068	5192	Economy	6000.00
0005434311262	5192	Economy	6000.00
0005435269982	5192	Economy	6000.00
0005432336241	5192	Economy	6600.00
0005435269964	5192	Economy	6000.00
0005434173664	5192	Economy	6000.00
0005435269933	5192	Economy	6000.00
0005435007437	5192	Economy	6000.00
0005435269996	5192	Economy	6000.00
0005434265874	5192	Economy	6000.00
0005435270022	5192	Economy	6000.00
0005435269981	5192	Economy	6000.00
0005435007499	5192	Economy	6000.00
0005432336270	5192	Economy	6000.00
0005432336245	5192	Economy	6000.00
0005435269923	5192	Economy	6000.00
0005433688858	5192	Economy	6000.00
0005435007495	5192	Economy	6000.00
0005433685573	5192	Economy	6000.00
0005434265877	5192	Economy	6000.00
0005435007598	5192	Economy	6000.00
0005432336275	5192	Economy	6000.00
0005435007429	5192	Economy	6000.00
0005435269947	5192	Economy	6000.00
0005435007592	5192	Economy	6000.00
0005435007445	5192	Economy	6000.00
0005435007478	5192	Economy	6000.00
0005435269960	5192	Economy	6000.00
0005435007517	5192	Economy	6000.00
0005433688843	5192	Economy	6000.00
0005435269922	5192	Economy	6000.00
0005435269977	5192	Economy	6000.00
0005432336305	5192	Economy	6000.00
0005433688857	5192	Economy	6000.00
0005435269991	5192	Economy	6000.00
0005435007578	5192	Economy	6000.00
0005434312360	5192	Economy	6000.00
0005435007532	5192	Economy	6000.00
0005435007515	5192	Economy	6000.00
0005435007494	5192	Economy	6000.00
0005433815492	5192	Economy	6000.00
0005435007519	5192	Economy	6000.00
0005434230016	5192	Economy	6000.00
0005435269893	5192	Economy	6000.00
0005435270004	5192	Economy	6000.00
0005434230014	5192	Economy	6000.00
0005435269894	5192	Economy	6000.00
0005434265876	5192	Economy	6000.00
0005435007599	5192	Economy	6000.00
0005435269920	5192	Economy	6000.00
0005434150071	5192	Economy	6000.00
0005434312361	5192	Economy	6000.00
0005434311264	5192	Economy	6000.00
0005434245628	8644	Business	18000.00
0005432659754	8644	Business	18000.00
0005434245662	8644	Business	18000.00
0005433785627	8644	Business	18000.00
0005433785626	8644	Business	18000.00
0005433785614	8644	Business	18000.00
0005434245543	8644	Business	18000.00
0005435270170	8644	Business	18000.00
0005435270173	8644	Business	18000.00
0005433785684	8644	Business	18000.00
0005434245657	8644	Business	18000.00
0005434245642	8644	Business	18000.00
0005433785898	8644	Business	18000.00
0005435270160	8644	Economy	6600.00
0005434245635	8644	Economy	6600.00
0005434245604	8644	Economy	6600.00
0005432666435	8644	Economy	6600.00
0005435270169	8644	Economy	6000.00
0005434245608	8644	Economy	6000.00
0005433785685	8644	Economy	6000.00
0005434245656	8644	Economy	6000.00
0005434245552	8644	Economy	6000.00
0005433785715	8644	Economy	6000.00
0005435270164	8644	Economy	6000.00
0005434245582	8644	Economy	6000.00
0005435270179	8644	Economy	6000.00
0005432659746	8644	Economy	6000.00
0005435270162	8644	Economy	6000.00
0005433785772	8644	Economy	6000.00
0005433785793	8644	Economy	6000.00
0005435270161	8644	Economy	6000.00
0005434245682	8644	Economy	6000.00
0005433785714	8644	Economy	6000.00
0005434245605	8644	Economy	6000.00
0005434245696	8644	Economy	6000.00
0005432663072	8644	Economy	6000.00
0005433785658	8644	Economy	6000.00
0005433785769	8644	Economy	6000.00
0005434245583	8644	Economy	6000.00
0005433785707	8644	Economy	6000.00
0005433785900	8644	Economy	6000.00
0005434245661	8644	Economy	6000.00
0005434245669	8644	Economy	6000.00
0005433785899	8644	Economy	6000.00
0005433785618	8644	Economy	6000.00
0005434245668	8644	Economy	6000.00
0005433785538	8644	Economy	6000.00
0005434245705	8644	Economy	6000.00
0005432663071	8644	Economy	6000.00
0005433785584	8644	Economy	6000.00
0005433785768	8644	Economy	6000.00
0005434245660	8644	Economy	6000.00
0005435270165	8644	Economy	6000.00
0005433785708	8644	Economy	6000.00
0005434245499	8644	Economy	6000.00
0005434245560	8644	Economy	6000.00
0005433785663	8644	Economy	6000.00
0005435270171	8644	Economy	6000.00
0005432663073	8644	Economy	6600.00
0005434245641	8644	Economy	6600.00
0005433785585	8644	Economy	6600.00
0005434245700	8644	Economy	6600.00
0005434245719	8644	Economy	6600.00
0005435270166	8644	Economy	6600.00
0005434245697	8644	Economy	6000.00
0005435270176	8644	Economy	6000.00
0005433785819	8644	Economy	6000.00
0005435270172	8644	Economy	6000.00
0005434245584	8644	Economy	6000.00
0005433785794	8644	Economy	6000.00
0005432666431	8644	Economy	6000.00
0005432663085	8644	Economy	6000.00
0005434245569	8644	Economy	6000.00
0005433785751	8644	Economy	6000.00
0005435270167	8644	Economy	6000.00
0005434245621	8644	Economy	6000.00
0005433785786	8644	Economy	6000.00
0005432663074	8644	Economy	6000.00
0005433785607	8644	Economy	6000.00
0005434245585	8644	Economy	6000.00
0005435270177	8644	Economy	6000.00
0005435270163	8644	Economy	6000.00
0005433785617	8644	Economy	6000.00
0005434245670	8644	Economy	6000.00
0005432663084	8644	Economy	6000.00
0005434245714	8644	Economy	6000.00
0005434245722	8644	Economy	6000.00
0005434245603	8644	Economy	6000.00
0005435270181	8644	Economy	6000.00
0005433785750	8644	Economy	6000.00
0005435270175	8644	Economy	6000.00
0005435270168	8644	Economy	6000.00
0005435270180	8644	Economy	6000.00
0005433785904	8644	Economy	6000.00
0005435270159	8644	Economy	6000.00
0005434245681	8644	Economy	6000.00
0005433785659	8644	Economy	6000.00
0005433785661	8644	Economy	6000.00
0005433785605	8644	Economy	6000.00
0005435270174	8644	Economy	6000.00
0005435270178	8644	Economy	6000.00
0005433616144	8643	Business	18000.00
0005433616210	8643	Business	18000.00
0005433616257	8643	Business	18000.00
0005433615952	8643	Business	18000.00
0005433616443	8643	Business	18000.00
0005433616212	8643	Business	18000.00
0005433616088	8643	Business	18000.00
0005433616316	8643	Business	18000.00
0005433616305	8643	Business	18000.00
0005433616332	8643	Business	18000.00
0005433616140	8643	Business	18000.00
0005433616068	8643	Business	18000.00
0005433616049	8643	Business	18000.00
0005433616315	8643	Business	18000.00
0005433616379	8643	Business	18000.00
0005433615939	8643	Economy	6600.00
0005433616035	8643	Economy	6600.00
0005433616206	8643	Economy	6600.00
0005433616246	8643	Economy	6000.00
0005433616010	8643	Economy	6000.00
0005433616028	8643	Economy	6000.00
0005433616289	8643	Economy	6000.00
0005433616145	8643	Economy	6000.00
0005433616092	8643	Economy	6000.00
0005433616253	8643	Economy	6000.00
0005433616211	8643	Economy	6000.00
0005433616209	8643	Economy	6000.00
0005433616484	8643	Economy	6000.00
0005433616159	8643	Economy	6000.00
0005433616058	8643	Economy	6000.00
0005433616235	8643	Economy	6000.00
0005433616183	8643	Economy	6000.00
0005433616202	8643	Economy	6000.00
0005433616138	8643	Economy	6000.00
0005433616146	8643	Economy	6000.00
0005433616292	8643	Economy	6000.00
0005433616240	8643	Economy	6000.00
0005433616063	8643	Economy	6000.00
0005433616154	8643	Economy	6000.00
0005433615821	8643	Economy	6000.00
0005433616213	8643	Economy	6000.00
0005433616054	8643	Economy	6000.00
0005433616360	8643	Economy	6000.00
0005433615822	8643	Economy	6000.00
0005433616345	8643	Economy	6000.00
0005433616084	8643	Economy	6000.00
0005433616014	8643	Economy	6000.00
0005433616158	8643	Economy	6000.00
0005433616062	8643	Economy	6000.00
0005433616415	8643	Economy	6000.00
0005433616002	8643	Economy	6000.00
0005433616452	8643	Economy	6000.00
0005433615721	8643	Economy	6000.00
0005433616089	8643	Economy	6000.00
0005433616411	8643	Economy	6600.00
0005433616090	8643	Economy	6600.00
0005433616067	8643	Economy	6600.00
0005433616047	8643	Economy	6600.00
0005433616410	8643	Economy	6000.00
0005433615948	8643	Economy	6000.00
0005433616221	8643	Economy	6000.00
0005433616444	8643	Economy	6600.00
0005433616412	8643	Economy	6000.00
0005433616091	8643	Economy	6000.00
0005433616293	8643	Economy	6000.00
0005433616259	8643	Economy	6000.00
0005433616319	8643	Economy	6000.00
0005433615898	8643	Economy	6000.00
0005433615871	8643	Economy	6000.00
0005433616321	8643	Economy	6000.00
0005433616093	8643	Economy	6000.00
0005433615899	8643	Economy	6000.00
0005433615988	8643	Economy	6000.00
0005433615866	8643	Economy	6000.00
0005433616199	8643	Economy	6000.00
0005433616358	8643	Economy	6000.00
0005433616179	8643	Economy	6000.00
0005433616222	8643	Economy	6000.00
0005433616378	8643	Economy	6000.00
0005433615931	8643	Economy	6000.00
0005433616258	8643	Economy	6000.00
0005433616050	8643	Economy	6000.00
0005433615722	8643	Economy	6000.00
0005433616039	8643	Economy	6000.00
0005433616291	8643	Economy	6000.00
0005433616413	8643	Economy	6000.00
0005433616414	8643	Economy	6000.00
0005433616165	8643	Economy	6000.00
0005433616160	8643	Economy	6000.00
0005433615720	8643	Economy	6000.00
0005433616214	8643	Economy	6000.00
0005433616504	8643	Economy	6000.00
0005433616048	8643	Economy	6000.00
0005433616205	8643	Economy	6000.00
0005433616342	8643	Economy	6000.00
0005433616320	8643	Economy	6000.00
0005433616106	8643	Economy	6000.00
0005433616083	8643	Economy	6000.00
0005433616107	8643	Economy	6000.00
0005435286876	8642	Business	18000.00
0005433688867	8642	Business	18000.00
0005434265597	8642	Business	18000.00
0005434149983	8642	Business	18000.00
0005434173602	8642	Business	18000.00
0005434173600	8642	Business	18000.00
0005434311277	8642	Business	18000.00
0005435286859	8642	Business	18000.00
0005435286868	8642	Business	18000.00
0005435286864	8642	Business	18000.00
0005433815526	8642	Business	18000.00
0005435007692	8642	Business	18000.00
0005434265658	8642	Business	18000.00
0005434229927	8642	Business	18000.00
0005434265678	8642	Business	18000.00
0005435286878	8642	Business	18000.00
0005435286854	8642	Business	18000.00
0005434265806	8642	Business	18000.00
0005434265724	8642	Business	18000.00
0005435007702	8642	Business	18000.00
0005434265681	8642	Business	18000.00
0005434265648	8642	Business	18000.00
0005433815522	8642	Business	18000.00
0005434229874	8642	Business	18000.00
0005435286874	8642	Economy	6600.00
0005432035742	8642	Business	18000.00
0005434229928	8642	Economy	6600.00
0005435007696	8642	Economy	6600.00
0005435007704	8642	Economy	6600.00
0005434265727	8642	Economy	6600.00
0005435007699	8642	Economy	6000.00
0005434173601	8642	Economy	6000.00
0005435286858	8642	Economy	6000.00
0005435007703	8642	Economy	6000.00
0005434229870	8642	Economy	6000.00
0005435007701	8642	Economy	6000.00
0005432035743	8642	Economy	6000.00
0005434265680	8642	Economy	6000.00
0005434265713	8642	Economy	6000.00
0005434265725	8642	Economy	6000.00
0005432336376	8642	Economy	6000.00
0005434265684	8642	Economy	6000.00
0005434265715	8642	Economy	6000.00
0005434229906	8642	Economy	6000.00
0005434265576	8642	Economy	6000.00
0005435007706	8642	Economy	6000.00
0005432035738	8642	Economy	6000.00
0005434265657	8642	Economy	6000.00
0005435286867	8642	Economy	6000.00
0005435007694	8642	Economy	6000.00
0005434150020	8642	Economy	6000.00
0005433815525	8642	Economy	6000.00
0005434229786	8642	Economy	6000.00
0005435007693	8642	Economy	6000.00
0005434150042	8642	Economy	6000.00
0005434265705	8642	Economy	6000.00
0005434265669	8642	Economy	6000.00
0005434265627	8642	Economy	6000.00
0005434265690	8642	Economy	6000.00
0005435007698	8642	Economy	6000.00
0005434265701	8642	Economy	6000.00
0005434173620	8642	Economy	6000.00
0005434265619	8642	Economy	6000.00
0005435286857	8642	Economy	6000.00
0005432035739	8642	Economy	6000.00
0005434311290	8642	Economy	6000.00
0005434149949	8642	Economy	6000.00
0005435286853	8642	Economy	6000.00
0005434149988	8642	Economy	6000.00
0005434149954	8642	Economy	6000.00
0005434229812	8642	Economy	6000.00
0005435286875	8642	Economy	6000.00
0005435286871	8642	Economy	6000.00
0005435286856	8642	Economy	6000.00
0005434265683	8642	Economy	6000.00
0005433815524	8642	Economy	6000.00
0005435286872	8642	Economy	6000.00
0005434265823	8642	Economy	6000.00
0005434265664	8642	Economy	6000.00
0005434265704	8642	Economy	6000.00
0005435286863	8642	Economy	6000.00
0005434229817	8642	Economy	6000.00
0005434149977	8642	Economy	6000.00
0005434229813	8642	Economy	6000.00
0005434229815	8642	Economy	6000.00
0005434150044	8642	Economy	6000.00
0005432035740	8642	Economy	6000.00
0005434229828	8642	Economy	6000.00
0005434173580	8642	Economy	6000.00
0005434265728	8642	Economy	6600.00
0005432035745	8642	Economy	6600.00
0005434229871	8642	Economy	6600.00
0005435007697	8642	Economy	6600.00
0005434149953	8642	Economy	6600.00
0005434265805	8642	Economy	6000.00
0005433534561	8642	Economy	6000.00
0005434150000	8642	Economy	6600.00
0005434265613	8642	Economy	6000.00
0005433688866	8642	Economy	6000.00
0005434265714	8642	Economy	6000.00
0005432035746	8642	Economy	6000.00
0005432336380	8642	Economy	6000.00
0005435007695	8642	Economy	6000.00
0005432035737	8642	Economy	6000.00
0005435286855	8642	Economy	6000.00
0005432336381	8642	Economy	6000.00
0005434149976	8642	Economy	6000.00
0005435286877	8642	Economy	6000.00
0005434229762	8642	Economy	6000.00
0005434149987	8642	Economy	6000.00
0005432035744	8642	Economy	6000.00
0005433815562	8642	Economy	6000.00
0005433815523	8642	Economy	6000.00
0005434150021	8642	Economy	6000.00
0005434229837	8642	Economy	6000.00
0005434265640	8642	Economy	6000.00
0005435286861	8642	Economy	6000.00
0005434150043	8642	Economy	6000.00
0005432047658	8642	Economy	6000.00
0005432336382	8642	Economy	6000.00
0005434265682	8642	Economy	6000.00
0005434265689	8642	Economy	6000.00
0005432336379	8642	Economy	6000.00
0005435286866	8642	Economy	6000.00
0005434265659	8642	Economy	6000.00
0005435286865	8642	Economy	6000.00
0005434265749	8642	Economy	6000.00
0005434173581	8642	Economy	6000.00
0005434229797	8642	Economy	6000.00
0005434229882	8642	Economy	6000.00
0005432035741	8642	Economy	6000.00
0005434311276	8642	Economy	6000.00
0005434149970	8642	Economy	6000.00
0005434229816	8642	Economy	6000.00
0005435286869	8642	Economy	6000.00
0005434229785	8642	Economy	6000.00
0005434229843	8642	Economy	6000.00
0005435286870	8642	Economy	6000.00
0005434229814	8642	Economy	6000.00
0005435286860	8642	Economy	6000.00
0005432035736	8642	Economy	6000.00
0005435286862	8642	Economy	6000.00
0005432336378	8642	Economy	6000.00
0005435007700	8642	Economy	6000.00
0005435286873	8642	Economy	6000.00
0005434149979	8642	Economy	6000.00
0005434173619	8642	Economy	6000.00
0005434229847	8642	Economy	6000.00
0005434229836	8642	Economy	6000.00
0005434229825	8642	Economy	6000.00
0005434229804	8642	Economy	6000.00
0005432336377	8642	Economy	6000.00
0005432047659	8642	Economy	6000.00
0005435007705	8642	Economy	6000.00
0005434149980	8642	Economy	6000.00
0005434265674	8642	Economy	6000.00
0005434229844	8642	Economy	6000.00
0005434149999	8642	Economy	6000.00
0005434265688	8642	Economy	6000.00
0005434639934	12611	Economy	16200.00
0005434639857	12611	Economy	14800.00
0005434639744	12611	Economy	14800.00
0005433202784	12611	Economy	14800.00
0005433202783	12611	Economy	14800.00
0005434639896	12611	Economy	14800.00
0005434639855	12611	Economy	14800.00
0005434639901	12611	Economy	14800.00
0005433202785	12611	Economy	14800.00
0005434639841	12611	Economy	14800.00
0005434639783	12611	Economy	14800.00
0005434639839	12611	Economy	14800.00
0005433202782	12611	Economy	14800.00
0005434639894	12611	Economy	14800.00
0005434639895	12611	Economy	14800.00
0005434639743	12611	Economy	14800.00
0005434639919	12611	Economy	14800.00
0005434639935	12611	Economy	14800.00
0005434640064	23360	Economy	16200.00
0005434640050	23360	Economy	16200.00
0005433202625	23360	Economy	16200.00
0005434640049	23360	Economy	14800.00
0005433202617	23360	Economy	14800.00
0005433202638	23360	Economy	14800.00
0005433202626	23360	Economy	14800.00
0005434640057	23360	Economy	14800.00
0005434640061	23360	Economy	14800.00
0005434640059	23360	Economy	14800.00
0005434640056	23360	Economy	14800.00
0005434640051	23360	Economy	14800.00
0005434640054	23360	Economy	14800.00
0005433202628	23360	Economy	14800.00
0005434640067	23360	Economy	14800.00
0005434640060	23360	Economy	14800.00
0005432290721	23360	Economy	14800.00
0005432290720	23360	Economy	14800.00
0005434640063	23360	Economy	14800.00
0005433202627	23360	Economy	14800.00
0005434640055	23360	Economy	14800.00
0005434640065	23360	Economy	14800.00
0005434640052	23360	Economy	14800.00
0005434640053	23360	Economy	14800.00
0005433202687	23360	Economy	14800.00
0005434640066	23360	Economy	14800.00
0005434640058	23360	Economy	14800.00
0005433202682	23360	Economy	14800.00
0005434640062	23360	Economy	14800.00
0005432383886	21086	Business	18900.00
0005432383972	21086	Business	18900.00
0005432329530	21086	Business	18900.00
0005432383959	21086	Business	18900.00
0005432383942	21086	Business	18900.00
0005432384017	21086	Business	18900.00
0005432383790	21086	Business	18900.00
0005432329519	21086	Business	18900.00
0005432329587	21086	Business	18900.00
0005432329682	21086	Business	18900.00
0005432383978	21086	Business	18900.00
0005432383979	21086	Business	18900.00
0005432329606	21086	Economy	6300.00
0005432329684	21086	Economy	6300.00
0005432383765	21086	Economy	6300.00
0005432329617	21086	Economy	6300.00
0005432329580	21086	Economy	6300.00
0005432329639	21086	Economy	6300.00
0005432329631	21086	Economy	6300.00
0005432383924	21086	Economy	6300.00
0005432383992	21086	Economy	6300.00
0005432329818	21086	Economy	6300.00
0005432384020	21086	Economy	6900.00
0005432384062	21086	Economy	6900.00
0005432329610	21086	Economy	6900.00
0005432383914	21086	Economy	6900.00
0005432329494	21086	Economy	6900.00
0005432329809	21086	Economy	6300.00
0005432384041	21086	Economy	6300.00
0005432329618	21086	Economy	6300.00
0005432383989	21086	Economy	6300.00
0005432329622	21086	Economy	6300.00
0005432383764	21086	Economy	6300.00
0005432383817	21086	Economy	6300.00
0005432329444	21086	Economy	6300.00
0005432329703	21086	Economy	6300.00
0005432383952	21086	Economy	6300.00
0005432329725	21086	Economy	6300.00
0005432329742	21086	Economy	6300.00
0005432384035	21086	Economy	6300.00
0005432329842	21086	Economy	6300.00
0005432383923	21086	Economy	6300.00
0005432329727	21086	Economy	6300.00
0005432329724	21086	Economy	6300.00
0005432384057	21086	Economy	6300.00
0005432329704	21086	Economy	6300.00
0005432383927	21086	Economy	6300.00
0005432383789	21086	Economy	6300.00
0005432329550	21086	Economy	6300.00
0005432384050	21086	Economy	6300.00
0005432329608	21086	Economy	6300.00
0005432329638	21086	Economy	6300.00
0005432329586	21086	Economy	6300.00
0005432383925	21086	Economy	6300.00
0005432383991	21086	Economy	6300.00
0005432383976	21086	Economy	6300.00
0005432329645	21086	Economy	6300.00
0005432329726	21086	Economy	6300.00
0005432329609	21086	Economy	6300.00
0005432329443	21086	Economy	6300.00
0005432383818	21086	Economy	6300.00
0005432383984	21086	Economy	6300.00
0005432329723	21086	Economy	6300.00
0005432329630	21086	Economy	6300.00
0005432383953	21086	Economy	6300.00
0005432329538	21086	Economy	6300.00
0005432329607	21086	Economy	6300.00
0005432384036	21086	Economy	6300.00
0005432383968	21086	Economy	6300.00
0005432383926	21086	Economy	6300.00
0005432329557	21086	Economy	6300.00
0005432384032	21086	Economy	6300.00
0005432329644	21086	Economy	6300.00
0005432383787	21086	Economy	6300.00
0005432329493	21086	Economy	6300.00
0005432329632	21086	Economy	6300.00
0005432383836	21086	Economy	6300.00
0005432383841	21086	Economy	6300.00
0005432383830	21086	Economy	6300.00
0005432384021	21086	Economy	6300.00
0005432329520	21086	Economy	6300.00
0005432384019	21086	Economy	6300.00
0005432383947	21086	Economy	6300.00
0005432384042	21086	Economy	6300.00
0005432383915	21086	Economy	6300.00
0005432329445	21086	Economy	6300.00
0005432383956	21086	Economy	6300.00
0005432384018	21086	Economy	6300.00
0005432383985	21086	Economy	6300.00
0005432383786	21086	Economy	6300.00
0005432383791	21086	Economy	6300.00
0005432329734	21086	Economy	6300.00
0005432329636	21086	Economy	6300.00
0005432384058	21086	Economy	6300.00
0005432329683	21086	Economy	6300.00
0005432383988	21086	Economy	6300.00
0005432383965	21086	Economy	6300.00
0005432848888	31247	Business	18900.00
0005432329988	31247	Business	18900.00
0005432329977	31247	Business	18900.00
0005432329985	31247	Business	18900.00
0005432329997	31247	Business	18900.00
0005432329991	31247	Business	18900.00
0005432848887	31247	Business	18900.00
0005432384277	31247	Business	18900.00
0005432329981	31247	Economy	6300.00
0005432329979	31247	Economy	6300.00
0005432329974	31247	Economy	6300.00
0005432329975	31247	Economy	6300.00
0005432329982	31247	Economy	6300.00
0005432384279	31247	Economy	6300.00
0005432848865	31247	Economy	6300.00
0005432287332	31247	Economy	6900.00
0005432329984	31247	Economy	6900.00
0005432329992	31247	Economy	6300.00
0005432384275	31247	Economy	6300.00
0005432287333	31247	Economy	6300.00
0005432848873	31247	Economy	6300.00
0005432329998	31247	Economy	6300.00
0005432384273	31247	Economy	6300.00
0005432384287	31247	Economy	6300.00
0005432384278	31247	Economy	6300.00
0005432329989	31247	Economy	6300.00
0005432329993	31247	Economy	6300.00
0005432384276	31247	Economy	6300.00
0005432384280	31247	Economy	6300.00
0005432384282	31247	Economy	6300.00
0005432329996	31247	Economy	6300.00
0005432384283	31247	Economy	6300.00
0005432329978	31247	Economy	6300.00
0005432329987	31247	Economy	6300.00
0005432384271	31247	Economy	6300.00
0005432848864	31247	Economy	6300.00
0005432384281	31247	Economy	6300.00
0005432384284	31247	Economy	6300.00
0005432384274	31247	Economy	6300.00
0005432384290	31247	Economy	6300.00
0005432384270	31247	Economy	6300.00
0005432329995	31247	Economy	6300.00
0005432329976	31247	Economy	6300.00
0005432384288	31247	Economy	6300.00
0005432384286	31247	Economy	6300.00
0005432329980	31247	Economy	6300.00
0005432384272	31247	Economy	6300.00
0005432329994	31247	Economy	6300.00
0005432384269	31247	Economy	6300.00
0005432384291	31247	Economy	6300.00
0005432329983	31247	Economy	6300.00
0005432329990	31247	Economy	6300.00
0005432384285	31247	Economy	6300.00
0005432384292	31247	Economy	6300.00
0005432384289	31247	Economy	6300.00
0005432848878	31247	Economy	6300.00
0005432287331	31247	Economy	6300.00
0005432329986	31247	Economy	6300.00
0005433642774	2481	Business	89600.00
0005432954081	2481	Business	89600.00
0005433642762	2481	Business	89600.00
0005433642765	2481	Business	89600.00
0005433642776	2481	Business	89600.00
0005433642773	2481	Business	89600.00
0005432954126	2481	Economy	29900.00
0005432954101	2481	Economy	29900.00
0005433642770	2481	Economy	29900.00
0005432954082	2481	Economy	29900.00
0005433642767	2481	Economy	32800.00
0005433642764	2481	Economy	32800.00
0005433642768	2481	Economy	29900.00
0005433642761	2481	Economy	29900.00
0005432954113	2481	Economy	29900.00
0005433642777	2481	Economy	29900.00
0005432954133	2481	Economy	29900.00
0005433642771	2481	Economy	29900.00
0005432954112	2481	Economy	29900.00
0005432954074	2481	Economy	29900.00
0005433642769	2481	Economy	29900.00
0005432954075	2481	Economy	29900.00
0005433642763	2481	Economy	29900.00
0005432954131	2481	Economy	29900.00
0005433642772	2481	Economy	29900.00
0005432954100	2481	Economy	29900.00
0005433642775	2481	Economy	29900.00
0005432954132	2481	Economy	29900.00
0005432954114	2481	Economy	29900.00
0005433642766	2481	Economy	29900.00
0005433642760	2481	Economy	29900.00
0005432954084	2481	Economy	29900.00
0005433642647	27581	Business	89600.00
0005433642713	27581	Business	89600.00
0005433642614	27581	Business	89600.00
0005433642633	27581	Business	89600.00
0005432954181	27581	Business	89600.00
0005433642615	27581	Business	89600.00
0005433642656	27581	Business	89600.00
0005433642655	27581	Business	89600.00
0005433642624	27581	Economy	29900.00
0005432954172	27581	Economy	29900.00
0005433642591	27581	Economy	29900.00
0005433642686	27581	Economy	29900.00
0005433642618	27581	Economy	29900.00
0005432954180	27581	Economy	32800.00
0005433642604	27581	Economy	32800.00
0005432954178	27581	Economy	32800.00
0005433642681	27581	Economy	32800.00
0005433642610	27581	Economy	32800.00
0005433642611	27581	Economy	29900.00
0005433642639	27581	Economy	29900.00
0005433642672	27581	Economy	29900.00
0005432954175	27581	Economy	29900.00
0005433642605	27581	Economy	29900.00
0005433642682	27581	Economy	29900.00
0005433642636	27581	Economy	29900.00
0005432954174	27581	Economy	29900.00
0005432954186	27581	Economy	29900.00
0005433642651	27581	Economy	29900.00
0005433642662	27581	Economy	29900.00
0005433642720	27581	Economy	29900.00
0005433642648	27581	Economy	29900.00
0005433642634	27581	Economy	29900.00
0005433642631	27581	Economy	29900.00
0005433642589	27581	Economy	29900.00
0005432954177	27581	Economy	29900.00
0005433642653	27581	Economy	29900.00
0005433642584	27581	Economy	29900.00
0005432954185	27581	Economy	29900.00
0005432954173	27581	Economy	29900.00
0005433642652	27581	Economy	29900.00
0005433642577	27581	Economy	29900.00
0005433642687	27581	Economy	29900.00
0005433642671	27581	Economy	29900.00
0005432954176	27581	Economy	29900.00
0005433642628	27581	Economy	29900.00
0005433642625	27581	Economy	29900.00
0005433642676	27581	Economy	29900.00
0005433642583	27581	Economy	29900.00
0005433642630	27581	Economy	29900.00
0005433642644	27581	Economy	29900.00
0005432954182	27581	Economy	29900.00
0005432954184	27581	Economy	29900.00
0005433642585	27581	Economy	29900.00
0005432954183	27581	Economy	29900.00
0005432954179	27581	Economy	29900.00
0005433642635	27581	Economy	29900.00
0005432425848	13313	Business	12700.00
0005432425877	13313	Business	12700.00
0005432425882	13313	Business	12700.00
0005432425830	13313	Business	12700.00
0005432425873	13313	Business	12700.00
0005432425829	13313	Business	12700.00
0005432425851	13313	Business	12700.00
0005432425835	13313	Business	12700.00
0005432425852	13313	Business	12700.00
0005432425828	13313	Economy	4200.00
0005432425858	13313	Economy	4200.00
0005432425849	13313	Economy	4200.00
0005432425857	13313	Economy	4200.00
0005432425875	13313	Economy	4200.00
0005432425844	13313	Economy	4200.00
0005432425837	13313	Economy	4200.00
0005432425880	13313	Economy	4700.00
0005432425859	13313	Economy	4700.00
0005432425871	13313	Economy	4700.00
0005432425826	13313	Economy	4700.00
0005432425881	13313	Economy	4200.00
0005432425864	13313	Economy	4200.00
0005432425841	13313	Economy	4200.00
0005432425878	13313	Economy	4200.00
0005432425840	13313	Economy	4200.00
0005432425832	13313	Economy	4200.00
0005432425842	13313	Economy	4200.00
0005432425831	13313	Economy	4200.00
0005432425838	13313	Economy	4200.00
0005432425867	13313	Economy	4200.00
0005432425855	13313	Economy	4200.00
0005432425860	13313	Economy	4200.00
0005432425823	13313	Economy	4200.00
0005432425865	13313	Economy	4200.00
0005432425847	13313	Economy	4200.00
0005432425824	13313	Economy	4200.00
0005432425825	13313	Economy	4200.00
0005432425872	13313	Economy	4200.00
0005432425854	13313	Economy	4200.00
0005432425879	13313	Economy	4200.00
0005432425833	13313	Economy	4200.00
0005432425850	13313	Economy	4200.00
0005432425876	13313	Economy	4200.00
0005432425827	13313	Economy	4200.00
0005432425834	13313	Economy	4200.00
0005432425874	13313	Economy	4200.00
0005432425868	13313	Economy	4200.00
0005432425862	13313	Economy	4200.00
0005432425866	13313	Economy	4200.00
0005432425870	13313	Economy	4200.00
0005432425846	13313	Economy	4200.00
0005432425845	13313	Economy	4200.00
0005432425869	13313	Economy	4200.00
0005432425836	13313	Economy	4200.00
0005432425861	13313	Economy	4200.00
0005432425853	13313	Economy	4200.00
0005432425856	13313	Economy	4200.00
0005432425822	13313	Economy	4200.00
0005432425839	13313	Economy	4200.00
0005432425843	13313	Economy	4200.00
0005432425863	13313	Economy	4200.00
0005432425378	30718	Business	12700.00
0005432425396	30718	Business	12700.00
0005432425381	30718	Business	12700.00
0005432425470	30718	Business	12700.00
0005432425329	30718	Business	12700.00
0005432425449	30718	Economy	4200.00
0005432425276	30718	Economy	4200.00
0005432425448	30718	Economy	4200.00
0005432425191	30718	Economy	4200.00
0005432425288	30718	Economy	4200.00
0005432425467	30718	Economy	4200.00
0005432425229	30718	Economy	4200.00
0005432425331	30718	Economy	4200.00
0005432425337	30718	Economy	4200.00
0005432425453	30718	Economy	4200.00
0005432425488	30718	Economy	4200.00
0005432425471	30718	Economy	4200.00
0005432425385	30718	Economy	4200.00
0005432425473	30718	Economy	4200.00
0005432425450	30718	Economy	4200.00
0005432425464	30718	Economy	4200.00
0005432425427	30718	Economy	4200.00
0005432425435	30718	Economy	4200.00
0005432425302	30718	Economy	4200.00
0005432425472	30718	Economy	4200.00
0005432425323	30718	Economy	4200.00
0005432425379	30718	Economy	4200.00
0005432425370	30718	Economy	4200.00
0005432425301	30718	Economy	4200.00
0005432425304	30718	Economy	4200.00
0005432425406	30718	Economy	4200.00
0005432425454	30718	Economy	4200.00
0005432425391	30718	Economy	4200.00
0005432425405	30718	Economy	4200.00
0005432425328	30718	Economy	4200.00
0005432425305	30718	Economy	4200.00
0005432425275	30718	Economy	4200.00
0005434157646	9634	Business	32600.00
0005432901998	9634	Business	32600.00
0005432901995	9634	Business	32600.00
0005432901940	9634	Business	32600.00
0005432901929	9634	Business	32600.00
0005432901866	9634	Business	32600.00
0005432901962	9634	Business	32600.00
0005434448413	9634	Economy	10900.00
0005434157641	9634	Economy	10900.00
0005432901939	9634	Economy	10900.00
0005434157636	9634	Economy	10900.00
0005432902031	9634	Economy	11900.00
0005432289081	9634	Economy	11900.00
0005434157660	9634	Economy	11900.00
0005432818318	9634	Economy	11900.00
0005432818314	9634	Economy	10900.00
0005432818317	9634	Economy	10900.00
0005432818313	9634	Economy	10900.00
0005432289080	9634	Economy	10900.00
0005432902019	9634	Economy	10900.00
0005432822427	9634	Economy	10900.00
0005432818312	9634	Economy	10900.00
0005432818320	9634	Economy	10900.00
0005432818310	9634	Economy	10900.00
0005432822428	9634	Economy	10900.00
0005434448414	9634	Economy	10900.00
0005432822429	9634	Economy	10900.00
0005434157647	9634	Economy	10900.00
0005434157645	9634	Economy	10900.00
0005432818309	9634	Economy	10900.00
0005434157644	9634	Economy	10900.00
0005434157661	9634	Economy	10900.00
0005432901923	9634	Economy	10900.00
0005432818316	9634	Economy	10900.00
0005432822426	9634	Economy	10900.00
0005434157653	9634	Economy	10900.00
0005432901927	9634	Economy	10900.00
0005432901911	9634	Economy	10900.00
0005432818319	9634	Economy	10900.00
0005432818315	9634	Economy	10900.00
0005432901928	9634	Economy	10900.00
0005432818311	9634	Economy	10900.00
0005434186269	9634	Economy	10900.00
0005434157669	9634	Economy	10900.00
0005432901924	9634	Economy	10900.00
0005432822425	9634	Economy	10900.00
0005432901996	9634	Economy	10900.00
0005434157666	9634	Economy	10900.00
0005434186281	29004	Business	32600.00
0005432822353	29004	Business	32600.00
0005432818076	29004	Business	32600.00
0005432902110	29004	Business	32600.00
0005432818041	29004	Business	32600.00
0005432818145	29004	Business	32600.00
0005434448390	29004	Business	32600.00
0005432818167	29004	Business	32600.00
0005432817865	29004	Economy	10900.00
0005432818173	29004	Economy	10900.00
0005434157703	29004	Economy	10900.00
0005434448391	29004	Economy	10900.00
0005432818143	29004	Economy	10900.00
0005432817977	29004	Economy	10900.00
0005432822372	29004	Economy	10900.00
0005432818014	29004	Economy	10900.00
0005432822370	29004	Economy	11900.00
0005432817981	29004	Economy	10900.00
0005432822348	29004	Economy	10900.00
0005432818124	29004	Economy	10900.00
0005434157701	29004	Economy	10900.00
0005432902107	29004	Economy	10900.00
0005434157704	29004	Economy	10900.00
0005432002137	29004	Economy	10900.00
0005432902105	29004	Economy	10900.00
0005434157702	29004	Economy	10900.00
0005432902109	29004	Economy	10900.00
0005432818125	29004	Economy	10900.00
0005432818199	29004	Economy	10900.00
0005434448389	29004	Economy	10900.00
0005434186284	29004	Economy	10900.00
0005432818174	29004	Economy	10900.00
0005432818077	29004	Economy	10900.00
0005432822339	29004	Economy	10900.00
0005432818037	29004	Economy	10900.00
0005432818050	29004	Economy	10900.00
0005432818108	29004	Economy	10900.00
0005432818136	29004	Economy	10900.00
0005432818137	29004	Economy	10900.00
0005432818013	29004	Economy	10900.00
0005432822371	29004	Economy	10900.00
0005432902108	29004	Economy	10900.00
0005432818028	29004	Economy	10900.00
0005432818212	29004	Economy	10900.00
0005432817979	29004	Economy	10900.00
0005432818190	29004	Economy	10900.00
0005432902106	29004	Economy	10900.00
0005432818020	29004	Economy	10900.00
0005434186283	29004	Economy	10900.00
0005432902111	29004	Economy	10900.00
0005434186282	29004	Economy	10900.00
0005432818085	29004	Economy	10900.00
0005432818142	29004	Economy	10900.00
0005434157700	29004	Economy	10900.00
0005432818144	29004	Economy	10900.00
0005434157705	29004	Economy	10900.00
0005432818211	29004	Economy	10900.00
0005432818175	29004	Economy	10900.00
0005432822365	29004	Economy	10900.00
0005432818198	29004	Economy	10900.00
0005432817864	29004	Economy	10900.00
0005432611813	15096	Economy	11000.00
0005435841111	15096	Economy	11000.00
0005435841841	15096	Economy	11000.00
0005432611814	15096	Economy	11000.00
0005435841116	15096	Economy	11000.00
0005432607638	31596	Economy	11000.00
0005432611791	31596	Economy	11000.00
0005435842351	31596	Economy	11000.00
0005432611790	31596	Economy	11000.00
0005432611797	31596	Economy	11000.00
0005432611780	31596	Economy	11000.00
0005432611796	31596	Economy	11000.00
0005435842352	31596	Economy	11000.00
0005432949288	11862	Business	105900.00
0005432949256	11862	Business	105900.00
0005432949317	11862	Business	105900.00
0005433570839	11862	Business	105900.00
0005432949358	11862	Business	105900.00
0005433570848	11862	Business	105900.00
0005433570863	11862	Business	105900.00
0005433570871	11862	Business	105900.00
0005432949347	11862	Business	105900.00
0005433570850	11862	Business	105900.00
0005433570861	11862	Business	105900.00
0005432949207	11862	Business	105900.00
0005432949379	11862	Business	105900.00
0005433570864	11862	Business	105900.00
0005433570867	11862	Economy	35300.00
0005433570840	11862	Economy	35300.00
0005433570878	11862	Economy	35300.00
0005432949255	11862	Economy	35300.00
0005433570865	11862	Economy	35300.00
0005433570860	11862	Economy	35300.00
0005432949326	11862	Economy	35300.00
0005432949152	11862	Economy	35300.00
0005433570875	11862	Economy	35300.00
0005433570832	11862	Economy	35300.00
0005432949294	11862	Economy	35300.00
0005433570849	11862	Economy	35300.00
0005433570866	11862	Economy	38800.00
0005433570876	11862	Economy	38800.00
0005433570835	11862	Economy	38800.00
0005432949314	11862	Economy	35300.00
0005432949159	11862	Economy	35300.00
0005432949243	11862	Economy	35300.00
0005433570830	11862	Economy	35300.00
0005432949219	11862	Economy	35300.00
0005433570828	11862	Economy	35300.00
0005433570846	11862	Economy	35300.00
0005433570862	11862	Economy	35300.00
0005433570829	11862	Economy	35300.00
0005432949224	11862	Economy	35300.00
0005432949286	11862	Economy	35300.00
0005433570879	11862	Economy	35300.00
0005433570854	11862	Economy	35300.00
0005432949169	11862	Economy	35300.00
0005433570831	11862	Economy	35300.00
0005432949365	11862	Economy	35300.00
0005433570877	11862	Economy	35300.00
0005433570869	11862	Economy	35300.00
0005432949220	11862	Economy	35300.00
0005432949417	11862	Economy	35300.00
0005432949228	11862	Economy	35300.00
0005433570855	11862	Economy	35300.00
0005433570842	11862	Economy	35300.00
0005433570847	11862	Economy	35300.00
0005433570834	11862	Economy	35300.00
0005433570853	11862	Economy	35300.00
0005432949244	11862	Economy	35300.00
0005433570837	11862	Economy	35300.00
0005432949153	11862	Economy	35300.00
0005432949160	11862	Economy	35300.00
0005432949313	11862	Economy	35300.00
0005433570852	11862	Economy	35300.00
0005433570874	11862	Economy	35300.00
0005432949178	11862	Economy	35300.00
0005432949179	11862	Economy	35300.00
0005433570838	11862	Economy	35300.00
0005433570856	11862	Economy	35300.00
0005433570857	11862	Economy	35300.00
0005433570843	11862	Economy	35300.00
0005432949257	11862	Economy	35300.00
0005433570841	11862	Economy	35300.00
0005433570873	11862	Economy	35300.00
0005432949359	11862	Economy	35300.00
0005433570868	11862	Economy	35300.00
0005433570833	11862	Economy	35300.00
0005432949070	11862	Economy	35300.00
0005433570851	11862	Economy	35300.00
0005432949325	11862	Economy	35300.00
0005433570872	11862	Economy	35300.00
0005432949242	11862	Economy	35300.00
0005433570859	11862	Economy	35300.00
0005432949237	11862	Economy	35300.00
0005433570836	11862	Economy	35300.00
0005432949327	11862	Economy	35300.00
0005433570880	11862	Economy	35300.00
0005433570845	11862	Economy	35300.00
0005433570858	11862	Economy	35300.00
0005432949241	11862	Economy	35300.00
0005433570870	11862	Economy	35300.00
0005433570844	11862	Economy	35300.00
0005433570331	25297	Business	105900.00
0005433570353	25297	Business	105900.00
0005432949641	25297	Business	105900.00
0005432949644	25297	Business	105900.00
0005433570052	25297	Business	105900.00
0005433570216	25297	Business	105900.00
0005433570072	25297	Business	105900.00
0005433570133	25297	Business	105900.00
0005433570210	25297	Business	105900.00
0005433570147	25297	Business	105900.00
0005433570310	25297	Business	105900.00
0005433570155	25297	Business	105900.00
0005433570392	25297	Business	105900.00
0005433570351	25297	Business	105900.00
0005433570405	25297	Business	105900.00
0005433570352	25297	Business	105900.00
0005433570377	25297	Economy	35300.00
0005433570271	25297	Economy	35300.00
0005433570259	25297	Economy	35300.00
0005433570207	25297	Economy	35300.00
0005433570209	25297	Economy	35300.00
0005432949637	25297	Economy	35300.00
0005432949663	25297	Economy	35300.00
0005432949651	25297	Economy	35300.00
0005432949647	25297	Economy	35300.00
0005433570288	25297	Economy	35300.00
0005433570290	25297	Economy	35300.00
0005433570162	25297	Economy	35300.00
0005433570053	25297	Economy	38800.00
0005433570137	25297	Economy	38800.00
0005433570218	25297	Economy	38800.00
0005433570406	25297	Economy	35300.00
0005433570410	25297	Economy	35300.00
0005433570240	25297	Economy	35300.00
0005433570132	25297	Economy	35300.00
0005433570272	25297	Economy	35300.00
0005433570183	25297	Economy	35300.00
0005433570173	25297	Economy	35300.00
0005433570049	25297	Economy	35300.00
0005432949661	25297	Economy	35300.00
0005433570118	25297	Economy	35300.00
0005433570181	25297	Economy	35300.00
0005433569944	25297	Economy	35300.00
0005433570404	25297	Economy	35300.00
0005432949653	25297	Economy	35300.00
0005433570166	25297	Economy	35300.00
0005432949658	25297	Economy	35300.00
0005433570276	25297	Economy	35300.00
0005433570263	25297	Economy	35300.00
0005432949652	25297	Economy	35300.00
0005432949638	25297	Economy	35300.00
0005432949645	25297	Economy	35300.00
0005432949649	25297	Economy	35300.00
0005433570151	25297	Economy	35300.00
0005433570298	25297	Economy	35300.00
0005432949657	25297	Economy	35300.00
0005432949642	25297	Economy	35300.00
0005432949660	25297	Economy	35300.00
0005433570239	25297	Economy	35300.00
0005433570182	25297	Economy	35300.00
0005433570051	25297	Economy	35300.00
0005433570134	25297	Economy	35300.00
0005433570368	25297	Economy	35300.00
0005432949648	25297	Economy	35300.00
0005432949659	25297	Economy	35300.00
0005432949640	25297	Economy	35300.00
0005432949646	25297	Economy	35300.00
0005433570287	25297	Economy	35300.00
0005432949639	25297	Economy	35300.00
0005433570140	25297	Economy	35300.00
0005433570249	25297	Economy	35300.00
0005433570407	25297	Economy	35300.00
0005432949656	25297	Economy	35300.00
0005433570106	25297	Economy	35300.00
0005433570050	25297	Economy	35300.00
0005432949643	25297	Economy	35300.00
0005433570175	25297	Economy	35300.00
0005433570123	25297	Economy	35300.00
0005433570131	25297	Economy	35300.00
0005433570225	25297	Economy	35300.00
0005433570242	25297	Economy	35300.00
0005433570385	25297	Economy	35300.00
0005433570125	25297	Economy	35300.00
0005432949662	25297	Economy	35300.00
0005433570188	25297	Economy	35300.00
0005432949654	25297	Economy	35300.00
0005433570180	25297	Economy	35300.00
0005433570174	25297	Economy	35300.00
0005433570253	25297	Economy	35300.00
0005433570330	25297	Economy	35300.00
0005433570332	25297	Economy	35300.00
0005433570241	25297	Economy	35300.00
0005433570097	25297	Economy	35300.00
0005432949655	25297	Economy	35300.00
0005433570176	25297	Economy	35300.00
0005432949650	25297	Economy	35300.00
0005433570161	25297	Economy	35300.00
0005433808459	14461	Business	117400.00
0005433808449	14461	Business	117400.00
0005432430965	14461	Business	117400.00
0005433812955	14461	Business	117400.00
0005432430963	14461	Business	117400.00
0005432430966	14461	Business	117400.00
0005432430964	14461	Business	117400.00
0005432430972	14461	Business	117400.00
0005432430967	14461	Business	117400.00
0005433812935	14461	Business	117400.00
0005433812940	14461	Business	117400.00
0005433812948	14461	Economy	39100.00
0005433808446	14461	Economy	39100.00
0005433812933	14461	Economy	39100.00
0005433812946	14461	Economy	39100.00
0005433808444	14461	Economy	39100.00
0005433808448	14461	Economy	39100.00
0005433812939	14461	Economy	39100.00
0005432430973	14461	Economy	39100.00
0005432430969	14461	Economy	43000.00
0005434026760	14461	Economy	39100.00
0005433812952	14461	Economy	39100.00
0005433812951	14461	Economy	39100.00
0005433812950	14461	Economy	39100.00
0005433808447	14461	Economy	39100.00
0005433808442	14461	Economy	39100.00
0005433812942	14461	Economy	39100.00
0005433812941	14461	Economy	39100.00
0005433808441	14461	Economy	39100.00
0005433812932	14461	Economy	39100.00
0005433812943	14461	Economy	39100.00
0005433808435	14461	Economy	39100.00
0005432430968	14461	Economy	39100.00
0005433808456	14461	Economy	39100.00
0005434026758	14461	Economy	39100.00
0005433808455	14461	Economy	39100.00
0005433812936	14461	Economy	39100.00
0005433808457	14461	Economy	39100.00
0005433808451	14461	Economy	39100.00
0005433808439	14461	Economy	39100.00
0005434026759	14461	Economy	39100.00
0005434026761	14461	Economy	39100.00
0005434026762	14461	Economy	39100.00
0005432430970	14461	Economy	39100.00
0005432430971	14461	Economy	39100.00
0005433808445	14461	Economy	39100.00
0005433808443	14461	Economy	39100.00
0005434026757	14461	Economy	39100.00
0005435340624	5372	Business	67200.00
0005434655521	5372	Business	67200.00
0005435340606	5372	Business	67200.00
0005435555414	5372	Economy	22400.00
0005434655523	5372	Economy	22400.00
0005434655507	5372	Economy	22400.00
0005434655511	5372	Economy	22400.00
0005435340520	5372	Economy	24600.00
0005435340531	5372	Economy	24600.00
0005434655513	5372	Economy	22400.00
0005434655506	5372	Economy	22400.00
0005434655510	5372	Economy	22400.00
0005434655517	5372	Economy	22400.00
0005435340625	5372	Economy	22400.00
0005435340521	5372	Economy	22400.00
0005435340564	5372	Economy	22400.00
0005434655519	5372	Economy	22400.00
0005434655508	5372	Economy	22400.00
0005434655516	5372	Economy	22400.00
0005435340565	5372	Economy	22400.00
0005434655518	5372	Economy	22400.00
0005434655515	5372	Economy	22400.00
0005435555413	5372	Economy	22400.00
0005434655522	5372	Economy	22400.00
0005435340628	5372	Economy	22400.00
0005435340532	5372	Economy	22400.00
0005434655512	5372	Economy	22400.00
0005434655509	5372	Economy	22400.00
0005432114295	5372	Economy	22400.00
0005434655514	5372	Economy	22400.00
0005435340523	5372	Economy	22400.00
0005432114296	5372	Economy	22400.00
0005434655520	5372	Economy	22400.00
0005435340695	12546	Business	67200.00
0005434655178	12546	Business	67200.00
0005434655209	12546	Business	67200.00
0005434655279	12546	Business	67200.00
0005434655208	12546	Business	67200.00
0005435555427	12546	Business	67200.00
0005435340701	12546	Economy	22400.00
0005435340700	12546	Economy	22400.00
0005435340699	12546	Economy	22400.00
0005434655249	12546	Economy	22400.00
0005434655177	12546	Economy	22400.00
0005434655253	12546	Economy	22400.00
0005434655276	12546	Economy	22400.00
0005434655339	12546	Economy	24600.00
0005434655277	12546	Economy	24600.00
0005435340697	12546	Economy	22400.00
0005434655345	12546	Economy	22400.00
0005434655221	12546	Economy	22400.00
0005434655232	12546	Economy	22400.00
0005434655380	12546	Economy	22400.00
0005434655342	12546	Economy	22400.00
0005434655292	12546	Economy	22400.00
0005434655343	12546	Economy	22400.00
0005434655379	12546	Economy	22400.00
0005434655158	12546	Economy	22400.00
0005434655395	12546	Economy	22400.00
0005434655312	12546	Economy	22400.00
0005434655319	12546	Economy	22400.00
0005434655157	12546	Economy	22400.00
0005434655286	12546	Economy	22400.00
0005434655393	12546	Economy	22400.00
0005434655318	12546	Economy	22400.00
0005435340694	12546	Economy	22400.00
0005434655344	12546	Economy	22400.00
0005434655396	12546	Economy	22400.00
0005434655275	12546	Economy	22400.00
0005434655166	12546	Economy	22400.00
0005434656597	12546	Economy	22400.00
0005434655251	12546	Economy	22400.00
0005434655244	12546	Economy	22400.00
0005434655280	12546	Economy	22400.00
0005435340698	12546	Economy	22400.00
0005435340702	12546	Economy	22400.00
0005434655179	12546	Economy	22400.00
0005434655233	12546	Economy	22400.00
0005434655329	12546	Economy	22400.00
0005435340696	12546	Economy	22400.00
0005435555428	12546	Economy	22400.00
0005434655250	12546	Economy	22400.00
0005434655165	12546	Economy	22400.00
0005434655201	12546	Economy	22400.00
0005434655200	12546	Economy	22400.00
0005434655273	12546	Economy	22400.00
0005434655336	12546	Economy	22400.00
0005432078266	7432	Business	32000.00
0005433722471	7432	Business	32000.00
0005432078265	7432	Business	32000.00
0005433717371	7432	Business	32000.00
0005433717380	7432	Business	32000.00
0005433717391	7432	Business	32000.00
0005433717366	7432	Business	32000.00
0005433722468	7432	Economy	10700.00
0005433717387	7432	Economy	10700.00
0005433689969	7432	Economy	10700.00
0005435266213	7432	Economy	10700.00
0005433722473	7432	Economy	10700.00
0005433722466	7432	Economy	10700.00
0005433722469	7432	Economy	10700.00
0005433717390	7432	Economy	10700.00
0005433722449	7432	Economy	10700.00
0005435266237	7432	Economy	10700.00
0005433717368	7432	Economy	10700.00
0005433722455	7432	Economy	10700.00
0005433717383	7432	Economy	10700.00
0005433722451	7432	Economy	10700.00
0005433722460	7432	Economy	10700.00
0005433722456	7432	Economy	10700.00
0005433722465	7432	Economy	10700.00
0005433717374	7432	Economy	10700.00
0005433722452	7432	Economy	10700.00
0005433717372	7432	Economy	10700.00
0005433717385	7432	Economy	10700.00
0005432078267	7432	Economy	10700.00
0005433690984	7432	Economy	10700.00
0005435266239	7432	Economy	10700.00
0005433717369	7432	Economy	10700.00
0005433717367	7432	Economy	11700.00
0005435266222	7432	Economy	11700.00
0005433717393	7432	Economy	11700.00
0005433717384	7432	Economy	10700.00
0005433722462	7432	Economy	10700.00
0005435266212	7432	Economy	10700.00
0005433722459	7432	Economy	10700.00
0005435266231	7432	Economy	10700.00
0005433719235	7432	Economy	10700.00
0005433722450	7432	Economy	10700.00
0005435266291	7432	Economy	10700.00
0005433717376	7432	Economy	10700.00
0005433717379	7432	Economy	10700.00
0005433717392	7432	Economy	10700.00
0005433722461	7432	Economy	10700.00
0005433722463	7432	Economy	10700.00
0005433722457	7432	Economy	10700.00
0005433722470	7432	Economy	10700.00
0005433722467	7432	Economy	10700.00
0005433722472	7432	Economy	10700.00
0005435266240	7432	Economy	10700.00
0005433717382	7432	Economy	10700.00
0005433717377	7432	Economy	10700.00
0005433717381	7432	Economy	10700.00
0005435266275	7432	Economy	10700.00
0005433717389	7432	Economy	10700.00
0005433722458	7432	Economy	10700.00
0005433717375	7432	Economy	10700.00
0005433717378	7432	Economy	10700.00
0005433722453	7432	Economy	10700.00
0005433717370	7432	Economy	10700.00
0005433717386	7432	Economy	10700.00
0005433717373	7432	Economy	10700.00
0005432078264	7432	Economy	10700.00
0005433690983	7432	Economy	10700.00
0005435546236	7432	Economy	10700.00
0005433719236	7432	Economy	10700.00
0005433722464	7432	Economy	10700.00
0005433717388	7432	Economy	10700.00
0005433722454	7432	Economy	10700.00
0005435266247	7432	Economy	10700.00
0005435266238	7432	Economy	10700.00
0005435266274	7432	Economy	10700.00
0005435546235	7432	Economy	10700.00
0005433717007	29213	Business	32000.00
0005433717145	29213	Business	32000.00
0005433722326	29213	Business	32000.00
0005433722337	29213	Business	32000.00
0005433717186	29213	Business	32000.00
0005433717010	29213	Business	32000.00
0005433722339	29213	Economy	10700.00
0005433716984	29213	Economy	10700.00
0005433717082	29213	Economy	10700.00
0005433716985	29213	Economy	10700.00
0005433717255	29213	Economy	10700.00
0005433722338	29213	Economy	10700.00
0005433716906	29213	Economy	10700.00
0005435266329	29213	Economy	10700.00
0005433716856	29213	Economy	10700.00
0005433722319	29213	Economy	10700.00
0005433716905	29213	Economy	10700.00
0005435546237	29213	Economy	10700.00
0005432429029	29213	Economy	10700.00
0005433722320	29213	Economy	10700.00
0005433717116	29213	Economy	10700.00
0005435266321	29213	Economy	10700.00
0005435266322	29213	Economy	10700.00
0005433717202	29213	Economy	10700.00
0005433717146	29213	Economy	10700.00
0005433719204	29213	Economy	10700.00
0005433717099	29213	Economy	10700.00
0005433716916	29213	Economy	10700.00
0005433719196	29213	Economy	10700.00
0005433685573	29213	Economy	10700.00
0005433656735	29213	Economy	10700.00
0005433722345	29213	Economy	10700.00
0005433719209	29213	Economy	10700.00
0005433688843	29213	Economy	10700.00
0005435266328	29213	Economy	10700.00
0005433656726	29213	Economy	10700.00
0005433717044	29213	Economy	10700.00
0005433719214	29213	Economy	10700.00
0005433717106	29213	Economy	11700.00
0005433716993	29213	Economy	11700.00
0005433722344	29213	Economy	11700.00
0005433716904	29213	Economy	10700.00
0005432006848	29213	Economy	10700.00
0005433722332	29213	Economy	10700.00
0005433717015	29213	Economy	10700.00
0005433717189	29213	Economy	10700.00
0005433717100	29213	Economy	10700.00
0005433688858	29213	Economy	10700.00
0005433717036	29213	Economy	10700.00
0005433717081	29213	Economy	10700.00
0005435266323	29213	Economy	10700.00
0005433717083	29213	Economy	10700.00
0005433717185	29213	Economy	10700.00
0005435266324	29213	Economy	10700.00
0005433716915	29213	Economy	10700.00
0005435266325	29213	Economy	10700.00
0005433688857	29213	Economy	10700.00
0005433716865	29213	Economy	10700.00
0005435266330	29213	Economy	10700.00
0005433719205	29213	Economy	10700.00
0005433717188	29213	Economy	10700.00
0005433716903	29213	Economy	10700.00
0005433717107	29213	Economy	10700.00
0005433722346	29213	Economy	10700.00
0005433685577	29213	Economy	10700.00
0005432006847	29213	Economy	10700.00
0005435266327	29213	Economy	10700.00
0005433717105	29213	Economy	10700.00
0005433716850	29213	Economy	10700.00
0005433717201	29213	Economy	10700.00
0005433722343	29213	Economy	10700.00
0005433716851	29213	Economy	10700.00
0005435266326	29213	Economy	10700.00
0005433717008	29213	Economy	10700.00
0005433717009	29213	Economy	10700.00
0005432429028	29213	Economy	10700.00
0005433717095	29213	Economy	10700.00
0005434182451	8699	Business	36500.00
0005434095690	8699	Business	36500.00
0005434143824	8699	Business	36500.00
0005434182462	8699	Business	36500.00
0005434143834	8699	Economy	12200.00
0005434095691	8699	Economy	12200.00
0005434182450	8699	Economy	12200.00
0005434143831	8699	Economy	12200.00
0005434326062	8699	Economy	12200.00
0005434095684	8699	Economy	12200.00
0005434182449	8699	Economy	13400.00
0005434182461	8699	Economy	13400.00
0005434143829	8699	Economy	12200.00
0005434143825	8699	Economy	12200.00
0005434095689	8699	Economy	12200.00
0005434143821	8699	Economy	12200.00
0005434182437	8699	Economy	12200.00
0005434143818	8699	Economy	12200.00
0005434182445	8699	Economy	12200.00
0005434182448	8699	Economy	12200.00
0005434143836	8699	Economy	12200.00
0005434143823	8699	Economy	12200.00
0005434182421	8699	Economy	12200.00
0005434095692	8699	Economy	12200.00
0005434182522	8699	Economy	12200.00
0005434182424	8699	Economy	12200.00
0005434095685	8699	Economy	12200.00
0005434182438	8699	Economy	12200.00
0005434143819	8699	Economy	12200.00
0005434095686	8699	Economy	12200.00
0005434095687	8699	Economy	12200.00
0005434182423	8699	Economy	12200.00
0005434143826	8699	Economy	12200.00
0005434143835	8699	Economy	12200.00
0005434143828	8699	Economy	12200.00
0005434095688	8699	Economy	12200.00
0005434182446	8699	Economy	12200.00
0005434143822	8699	Economy	12200.00
0005434095693	8699	Economy	12200.00
0005434143832	8699	Economy	12200.00
0005434143833	8699	Economy	12200.00
0005434184709	8699	Economy	12200.00
0005434182420	8699	Economy	12200.00
0005434182452	8699	Economy	12200.00
0005434143827	8699	Economy	12200.00
0005434182483	8699	Economy	12200.00
0005434143830	8699	Economy	12200.00
0005434143820	8699	Economy	12200.00
0005434182484	8699	Economy	12200.00
0005434184724	11632	Business	36500.00
0005434182537	11632	Business	36500.00
0005434182541	11632	Economy	12200.00
0005435860706	11632	Economy	12200.00
0005434095577	11632	Economy	13400.00
0005434095538	11632	Economy	13400.00
0005435860710	11632	Economy	13400.00
0005434095536	11632	Economy	13400.00
0005434143751	11632	Economy	12200.00
0005435860713	11632	Economy	12200.00
0005434095541	11632	Economy	12200.00
0005434182535	11632	Economy	12200.00
0005435860703	11632	Economy	12200.00
0005434095631	11632	Economy	12200.00
0005435860712	11632	Economy	12200.00
0005435860705	11632	Economy	12200.00
0005434095583	11632	Economy	12200.00
0005434095595	11632	Economy	12200.00
0005435860708	11632	Economy	12200.00
0005434182543	11632	Economy	12200.00
0005434182539	11632	Economy	12200.00
0005434095593	11632	Economy	12200.00
0005434182536	11632	Economy	12200.00
0005434095576	11632	Economy	12200.00
0005434095594	11632	Economy	12200.00
0005434182542	11632	Economy	12200.00
0005434184723	11632	Economy	12200.00
0005435860711	11632	Economy	12200.00
0005434182534	11632	Economy	12200.00
0005435860704	11632	Economy	12200.00
0005434095597	11632	Economy	12200.00
0005434182538	11632	Economy	12200.00
0005434095542	11632	Economy	12200.00
0005435860707	11632	Economy	12200.00
0005435860709	11632	Economy	12200.00
0005434095598	11632	Economy	12200.00
0005434182540	11632	Economy	12200.00
0005433399123	1415	Business	33000.00
0005433399153	1415	Business	33000.00
0005435725773	1415	Business	33000.00
0005433399080	1415	Business	33000.00
0005433399068	1415	Business	33000.00
0005433399220	1415	Business	33000.00
0005433398994	1415	Business	33000.00
0005433398976	1415	Economy	11000.00
0005433399214	1415	Economy	11000.00
0005433399106	1415	Economy	11000.00
0005433399254	1415	Economy	11000.00
0005433398977	1415	Economy	11000.00
0005433399034	1415	Economy	12100.00
0005435732704	1415	Economy	12100.00
0005435725769	1415	Economy	12100.00
0005435732706	1415	Economy	12100.00
0005433399002	1415	Economy	12100.00
0005433399094	1415	Economy	11000.00
0005433398891	1415	Economy	11000.00
0005433399090	1415	Economy	11000.00
0005435732703	1415	Economy	11000.00
0005433399219	1415	Economy	11000.00
0005433399154	1415	Economy	11000.00
0005435732712	1415	Economy	11000.00
0005433399258	1415	Economy	11000.00
0005435732709	1415	Economy	11000.00
0005433399173	1415	Economy	11000.00
0005435732713	1415	Economy	11000.00
0005433399089	1415	Economy	11000.00
0005433398919	1415	Economy	11000.00
0005433399221	1415	Economy	11000.00
0005435732711	1415	Economy	11000.00
0005433399010	1415	Economy	11000.00
0005433398913	1415	Economy	11000.00
0005433399171	1415	Economy	11000.00
0005435732705	1415	Economy	11000.00
0005433399203	1415	Economy	11000.00
0005433399091	1415	Economy	11000.00
0005432906589	1415	Economy	11000.00
0005435725771	1415	Economy	11000.00
0005433398914	1415	Economy	11000.00
0005433399109	1415	Economy	11000.00
0005435725768	1415	Economy	11000.00
0005433399110	1415	Economy	11000.00
0005433457086	1415	Economy	11000.00
0005433399063	1415	Economy	11000.00
0005432297352	1415	Economy	11000.00
0005433399172	1415	Economy	11000.00
0005435725772	1415	Economy	11000.00
0005435732708	1415	Economy	11000.00
0005435732710	1415	Economy	11000.00
0005435725767	1415	Economy	11000.00
0005433457085	1415	Economy	11000.00
0005433398975	1415	Economy	11000.00
0005435732707	1415	Economy	11000.00
0005433398865	1415	Economy	11000.00
0005433399036	1415	Economy	11000.00
0005433398866	1415	Economy	11000.00
0005435725770	1415	Economy	11000.00
0005433399000	1415	Economy	11000.00
0005432906605	19244	Business	33000.00
0005433457066	19244	Business	33000.00
0005433399416	19244	Business	33000.00
0005433457064	19244	Business	33000.00
0005433399428	19244	Economy	11000.00
0005435732622	19244	Economy	11000.00
0005435732618	19244	Economy	11000.00
0005433457034	19244	Economy	11000.00
0005432906604	19244	Economy	11000.00
0005433399429	19244	Economy	12100.00
0005435732612	19244	Economy	12100.00
0005435732626	19244	Economy	12100.00
0005433399417	19244	Economy	11000.00
0005433399424	19244	Economy	11000.00
0005435732602	19244	Economy	11000.00
0005433399415	19244	Economy	11000.00
0005433457070	19244	Economy	11000.00
0005435732608	19244	Economy	11000.00
0005433399430	19244	Economy	11000.00
0005433399435	19244	Economy	11000.00
0005433399427	19244	Economy	11000.00
0005433457035	19244	Economy	11000.00
0005433399426	19244	Economy	11000.00
0005435732599	19244	Economy	11000.00
0005435732577	19244	Economy	11000.00
0005433399421	19244	Economy	11000.00
0005433399419	19244	Economy	11000.00
0005433399422	19244	Economy	11000.00
0005433457063	19244	Economy	11000.00
0005435732576	19244	Economy	11000.00
0005433399434	19244	Economy	11000.00
0005433399425	19244	Economy	11000.00
0005433399418	19244	Economy	11000.00
0005433399436	19244	Economy	11000.00
0005433457069	19244	Economy	11000.00
0005435732625	19244	Economy	11000.00
0005435732588	19244	Economy	11000.00
0005435732603	19244	Economy	11000.00
0005433399420	19244	Economy	11000.00
0005433399432	19244	Economy	11000.00
0005433399437	19244	Economy	11000.00
0005433399423	19244	Economy	11000.00
0005433399431	19244	Economy	11000.00
0005433457058	19244	Economy	11000.00
0005433399433	19244	Economy	11000.00
0005434444046	17388	Economy	15600.00
0005434444045	17388	Economy	14100.00
0005434444001	17388	Economy	14100.00
0005434444109	17388	Economy	14100.00
0005434444097	17388	Economy	14100.00
0005434444013	17388	Economy	14100.00
0005434443958	17388	Economy	14100.00
0005434443996	17388	Economy	14100.00
0005434444016	17388	Economy	14100.00
0005434444113	17388	Economy	14100.00
0005434444000	17388	Economy	14100.00
0005434444032	17388	Economy	14100.00
0005434444015	17388	Economy	14100.00
0005434443957	17388	Economy	14100.00
0005434444162	20597	Economy	14100.00
0005434444160	20597	Economy	14100.00
0005434444158	20597	Economy	14100.00
0005434444166	20597	Economy	14100.00
0005434444161	20597	Economy	14100.00
0005434444167	20597	Economy	14100.00
0005434444154	20597	Economy	14100.00
0005434444164	20597	Economy	14100.00
0005434444159	20597	Economy	14100.00
0005434444157	20597	Economy	14100.00
0005434444156	20597	Economy	14100.00
0005434444168	20597	Economy	14100.00
0005434444155	20597	Economy	14100.00
0005434444169	20597	Economy	14100.00
0005434444170	20597	Economy	14100.00
0005434444163	20597	Economy	14100.00
0005434444165	20597	Economy	14100.00
0005434954719	7284	Economy	5800.00
0005434954720	7284	Economy	5800.00
0005435377624	7284	Economy	5800.00
0005434954718	7284	Economy	5800.00
0005434954721	7284	Economy	5800.00
0005434954698	28358	Economy	5800.00
0005434954704	28358	Economy	5800.00
0005434954703	28358	Economy	5800.00
0005434954699	28358	Economy	5800.00
0005435893807	4451	Economy	14000.00
0005435893787	4451	Economy	14000.00
0005435893788	4451	Economy	14000.00
0005435893792	4451	Economy	14000.00
0005434326299	4451	Economy	14000.00
0005435893800	4451	Economy	14000.00
0005435893808	4451	Economy	14000.00
0005435893810	4451	Economy	14000.00
0005434352051	4451	Economy	14000.00
0005435893811	4451	Economy	14000.00
0005434326298	4451	Economy	14000.00
0005435893793	4451	Economy	14000.00
0005435893809	4451	Economy	14000.00
0005434352052	4451	Economy	14000.00
0005434352056	4451	Economy	14000.00
0005434352053	4451	Economy	14000.00
0005434352054	4451	Economy	14000.00
0005434326297	4451	Economy	14000.00
0005435893789	4451	Economy	14000.00
0005434352055	4451	Economy	14000.00
0005434351960	29628	Economy	15400.00
0005434351944	29628	Economy	14000.00
0005434351939	29628	Economy	14000.00
0005434351949	29628	Economy	14000.00
0005434351970	29628	Economy	14000.00
0005434351897	29628	Economy	14000.00
0005434352016	29628	Economy	14000.00
0005434351969	29628	Economy	14000.00
0005434351997	29628	Economy	14000.00
0005434351996	29628	Economy	14000.00
0005434351978	29628	Economy	14000.00
0005434352015	29628	Economy	14000.00
0005434351908	29628	Economy	14000.00
0005434351967	29628	Economy	14000.00
0005434182551	29628	Economy	14000.00
0005434182548	29628	Economy	14000.00
0005435893834	29628	Economy	14000.00
0005434351977	29628	Economy	14000.00
0005434351929	29628	Economy	14000.00
0005433345478	1055	Business	30600.00
0005433345290	1055	Business	30600.00
0005433345035	1055	Business	30600.00
0005433344932	1055	Business	30600.00
0005434445322	1055	Business	30600.00
0005433462804	1055	Business	30600.00
0005433344882	1055	Business	30600.00
0005433345179	1055	Business	30600.00
0005433345088	1055	Business	30600.00
0005435545954	1055	Business	30600.00
0005433159360	1055	Business	30600.00
0005434445321	1055	Business	30600.00
0005433344987	1055	Business	30600.00
0005433344929	1055	Business	30600.00
0005433345126	1055	Business	30600.00
0005433345158	1055	Business	30600.00
0005433345351	1055	Business	30600.00
0005433344832	1055	Business	30600.00
0005433345233	1055	Business	30600.00
0005433344945	1055	Economy	11200.00
0005433344746	1055	Economy	11200.00
0005433345240	1055	Economy	10200.00
0005433269816	1055	Economy	10200.00
0005433344939	1055	Economy	10200.00
0005433345036	1055	Economy	10200.00
0005433345013	1055	Economy	10200.00
0005433345099	1055	Economy	10200.00
0005433345432	1055	Economy	10200.00
0005435545952	1055	Economy	10200.00
0005433345125	1055	Economy	10200.00
0005433345281	1055	Economy	10200.00
0005433345352	1055	Economy	10200.00
0005433344436	1055	Economy	10200.00
0005435545989	1055	Economy	10200.00
0005433345403	1055	Economy	10200.00
0005433344748	1055	Economy	10200.00
0005433344930	1055	Economy	10200.00
0005433463965	1055	Economy	10200.00
0005433345440	1055	Economy	10200.00
0005435545956	1055	Economy	10200.00
0005433344795	1055	Economy	10200.00
0005435545953	1055	Economy	10200.00
0005433344993	1055	Economy	10200.00
0005433345321	1055	Economy	10200.00
0005433345582	1055	Economy	10200.00
0005433345122	1055	Economy	10200.00
0005433345237	1055	Economy	10200.00
0005433345479	1055	Economy	10200.00
0005433345442	1055	Economy	10200.00
0005433159361	1055	Economy	10200.00
0005433344931	1055	Economy	10200.00
0005433345120	1055	Economy	10200.00
0005433345282	1055	Economy	10200.00
0005433463964	1055	Economy	10200.00
0005433345071	1055	Economy	10200.00
0005433345427	1055	Economy	10200.00
0005433345326	1055	Economy	10200.00
0005433345178	1055	Economy	10200.00
0005433344953	1055	Economy	10200.00
0005433345350	1055	Economy	10200.00
0005435545957	1055	Economy	10200.00
0005433159356	1055	Economy	10200.00
0005433345434	1055	Economy	10200.00
0005433344722	1055	Economy	10200.00
0005433345433	1055	Economy	10200.00
0005433344747	1055	Economy	10200.00
0005435545955	1055	Economy	10200.00
0005434446588	1055	Economy	10200.00
0005433344723	1055	Economy	10200.00
0005435545990	1055	Economy	10200.00
0005433345391	1055	Economy	10200.00
0005433344435	1055	Economy	10200.00
0005433344994	1055	Economy	10200.00
0005433345229	1055	Economy	10200.00
0005433345530	1055	Economy	10200.00
0005433344598	1055	Economy	10200.00
0005433344881	1055	Economy	10200.00
0005433345216	1055	Economy	10200.00
0005433345428	1055	Economy	11200.00
0005435545991	1055	Economy	10200.00
0005433345239	1055	Economy	11200.00
0005433345629	1055	Economy	11200.00
0005433344850	1055	Economy	10200.00
0005435092356	1055	Economy	10200.00
0005433345175	1055	Economy	10200.00
0005435092354	1055	Economy	10200.00
0005433345123	1055	Economy	10200.00
0005433345289	1055	Economy	10200.00
0005433345129	1055	Economy	10200.00
0005433344434	1055	Economy	10200.00
0005433269830	1055	Economy	10200.00
0005433345583	1055	Economy	10200.00
0005435092355	1055	Economy	10200.00
0005433345195	1055	Economy	10200.00
0005433345128	1055	Economy	10200.00
0005433345076	1055	Economy	10200.00
0005433345032	1055	Economy	10200.00
0005433269848	1055	Economy	10200.00
0005433344745	1055	Economy	10200.00
0005433269829	1055	Economy	10200.00
0005433345119	1055	Economy	10200.00
0005433345305	1055	Economy	10200.00
0005433345327	1055	Economy	10200.00
0005433344597	1055	Economy	10200.00
0005433345121	1055	Economy	10200.00
0005433344973	1055	Economy	10200.00
0005433345241	1055	Economy	10200.00
0005433344940	1055	Economy	10200.00
0005432293278	1055	Economy	10200.00
0005433345084	1055	Economy	10200.00
0005433345243	1055	Economy	10200.00
0005433345401	1055	Economy	10200.00
0005433345345	1055	Economy	10200.00
0005433345194	1055	Economy	10200.00
0005433345046	1055	Economy	10200.00
0005433345417	1055	Economy	10200.00
0005433345400	1055	Economy	10200.00
0005433344959	1055	Economy	10200.00
0005433345325	1055	Economy	10200.00
0005433345448	1055	Economy	10200.00
0005433345404	1055	Economy	10200.00
0005433345176	1055	Economy	10200.00
0005435545988	1055	Economy	10200.00
0005433344995	1055	Economy	10200.00
0005433345102	1055	Economy	10200.00
0005433344778	1055	Economy	10200.00
0005433345234	1055	Economy	10200.00
0005433345215	1055	Economy	10200.00
0005433345177	1055	Economy	10200.00
0005435545958	1055	Economy	10200.00
0005433344779	1055	Economy	10200.00
0005435092353	1055	Economy	10200.00
0005433269852	1055	Economy	10200.00
0005433269828	1055	Economy	10200.00
0005435092352	1055	Economy	10200.00
0005433344833	1055	Economy	10200.00
0005433345091	1055	Economy	10200.00
0005433345907	17078	Business	30600.00
0005433269871	17078	Business	30600.00
0005435092325	17078	Business	30600.00
0005435530017	17078	Business	30600.00
0005434445296	17078	Business	30600.00
0005435508670	17078	Business	30600.00
0005433345937	17078	Business	30600.00
0005433345955	17078	Business	30600.00
0005433345898	17078	Business	30600.00
0005433345928	17078	Business	30600.00
0005435092298	17078	Business	30600.00
0005433345952	17078	Business	30600.00
0005435508600	17078	Business	30600.00
0005433345918	17078	Business	30600.00
0005435508682	17078	Economy	11200.00
0005435530042	17078	Economy	11200.00
0005435508677	17078	Economy	10200.00
0005433345941	17078	Economy	10200.00
0005433345931	17078	Economy	10200.00
0005433345906	17078	Economy	10200.00
0005435530049	17078	Economy	10200.00
0005435508676	17078	Economy	10200.00
0005435508593	17078	Economy	10200.00
0005433345912	17078	Economy	10200.00
0005433345940	17078	Economy	10200.00
0005433345896	17078	Economy	10200.00
0005433345917	17078	Economy	10200.00
0005435508671	17078	Economy	10200.00
0005433345942	17078	Economy	10200.00
0005433345900	17078	Economy	10200.00
0005433345934	17078	Economy	10200.00
0005435508675	17078	Economy	10200.00
0005435508575	17078	Economy	10200.00
0005433345923	17078	Economy	10200.00
0005433345938	17078	Economy	10200.00
0005435508595	17078	Economy	10200.00
0005435530036	17078	Economy	10200.00
0005433345933	17078	Economy	10200.00
0005433345945	17078	Economy	10200.00
0005435508594	17078	Economy	10200.00
0005433345916	17078	Economy	10200.00
0005433345939	17078	Economy	10200.00
0005433345902	17078	Economy	10200.00
0005433345915	17078	Economy	10200.00
0005434445293	17078	Economy	10200.00
0005433345910	17078	Economy	10200.00
0005435092314	17078	Economy	10200.00
0005434445285	17078	Economy	10200.00
0005433345929	17078	Economy	10200.00
0005433345921	17078	Economy	10200.00
0005433345951	17078	Economy	10200.00
0005435530018	17078	Economy	10200.00
0005435508583	17078	Economy	10200.00
0005433345957	17078	Economy	10200.00
0005433345905	17078	Economy	10200.00
0005435508623	17078	Economy	10200.00
0005433345927	17078	Economy	10200.00
0005433345953	17078	Economy	10200.00
0005435529983	17078	Economy	10200.00
0005433345936	17078	Economy	10200.00
0005433345911	17078	Economy	10200.00
0005435508674	17078	Economy	11200.00
0005433345924	17078	Economy	10200.00
0005433345935	17078	Economy	10200.00
0005433345943	17078	Economy	10200.00
0005434445286	17078	Economy	10200.00
0005433345956	17078	Economy	10200.00
0005433345920	17078	Economy	10200.00
0005435530016	17078	Economy	10200.00
0005435530028	17078	Economy	10200.00
0005433345904	17078	Economy	10200.00
0005433345932	17078	Economy	10200.00
0005435092317	17078	Economy	10200.00
0005433345958	17078	Economy	10200.00
0005433345897	17078	Economy	10200.00
0005434445297	17078	Economy	10200.00
0005435092250	17078	Economy	10200.00
0005435092290	17078	Economy	10200.00
0005435530037	17078	Economy	10200.00
0005433345944	17078	Economy	10200.00
0005434445298	17078	Economy	10200.00
0005433345909	17078	Economy	10200.00
0005433345919	17078	Economy	10200.00
0005435508582	17078	Economy	10200.00
0005433158206	17078	Economy	10200.00
0005433345926	17078	Economy	10200.00
0005433345954	17078	Economy	10200.00
0005433345930	17078	Economy	10200.00
0005433345903	17078	Economy	10200.00
0005433345913	17078	Economy	10200.00
0005433345950	17078	Economy	10200.00
0005433345948	17078	Economy	10200.00
0005435508683	17078	Economy	10200.00
0005433345901	17078	Economy	10200.00
0005435530014	17078	Economy	10200.00
0005433345947	17078	Economy	10200.00
0005435508581	17078	Economy	10200.00
0005435092239	17078	Economy	10200.00
0005433345908	17078	Economy	10200.00
0005435508542	17078	Economy	10200.00
0005435508614	17078	Economy	10200.00
0005433345925	17078	Economy	10200.00
0005433345922	17078	Economy	10200.00
0005433345946	17078	Economy	10200.00
0005433345914	17078	Economy	10200.00
0005435508681	17078	Economy	10200.00
0005435092326	17078	Economy	10200.00
0005433345949	17078	Economy	10200.00
0005433345899	17078	Economy	10200.00
0005432433836	12815	Business	40300.00
0005434068978	12815	Business	40300.00
0005434069090	12815	Business	40300.00
0005434068796	12815	Business	40300.00
0005434082457	12815	Business	40300.00
0005434082341	12815	Business	40300.00
0005434082329	12815	Business	40300.00
0005434068910	12815	Business	40300.00
0005434068930	12815	Business	40300.00
0005434068958	12815	Business	40300.00
0005434082262	12815	Business	40300.00
0005434068879	12815	Business	40300.00
0005433812965	12815	Economy	13400.00
0005435283509	12815	Economy	13400.00
0005432161216	12815	Economy	13400.00
0005434082386	12815	Economy	13400.00
0005434068853	12815	Economy	13400.00
0005434069116	12815	Economy	13400.00
0005434068863	12815	Economy	13400.00
0005434068927	12815	Economy	13400.00
0005433989870	12815	Economy	13400.00
0005433812966	12815	Economy	13400.00
0005433989869	12815	Economy	13400.00
0005434082501	12815	Economy	13400.00
0005434026749	12815	Economy	13400.00
0005435283506	12815	Economy	13400.00
0005434069064	12815	Economy	13400.00
0005435283517	12815	Economy	13400.00
0005435283511	12815	Economy	13400.00
0005434082346	12815	Economy	13400.00
0005434082390	12815	Economy	13400.00
0005434082260	12815	Economy	13400.00
0005435283518	12815	Economy	13400.00
0005435283515	12815	Economy	13400.00
0005434082389	12815	Economy	13400.00
0005434069229	12815	Economy	13400.00
0005434068804	12815	Economy	13400.00
0005435283507	12815	Economy	13400.00
0005434068882	12815	Economy	13400.00
0005434082261	12815	Economy	13400.00
0005434068727	12815	Economy	13400.00
0005434069100	12815	Economy	13400.00
0005434069079	12815	Economy	13400.00
0005434068928	12815	Economy	13400.00
0005432433835	12815	Economy	13400.00
0005432161217	12815	Economy	13400.00
0005434068807	12815	Economy	13400.00
0005434068963	12815	Economy	13400.00
0005434069028	12815	Economy	13400.00
0005434068805	12815	Economy	13400.00
0005435283505	12815	Economy	14800.00
0005434068642	12815	Economy	13400.00
0005434068826	12815	Economy	14800.00
0005433989847	12815	Economy	14800.00
0005434068728	12815	Economy	14800.00
0005434069088	12815	Economy	14800.00
0005434069004	12815	Economy	14800.00
0005434068769	12815	Economy	13400.00
0005432433834	12815	Economy	13400.00
0005435283508	12815	Economy	13400.00
0005434068888	12815	Economy	13400.00
0005435283513	12815	Economy	13400.00
0005434082387	12815	Economy	13400.00
0005434069139	12815	Economy	13400.00
0005434069037	12815	Economy	13400.00
0005434068526	12815	Economy	13400.00
0005434068527	12815	Economy	13400.00
0005434069024	12815	Economy	13400.00
0005434068810	12815	Economy	13400.00
0005434068990	12815	Economy	13400.00
0005434082503	12815	Economy	13400.00
0005434069038	12815	Economy	13400.00
0005434026743	12815	Economy	13400.00
0005434069057	12815	Economy	13400.00
0005434068929	12815	Economy	13400.00
0005435283514	12815	Economy	13400.00
0005434068889	12815	Economy	13400.00
0005434068880	12815	Economy	13400.00
0005433989849	12815	Economy	13400.00
0005435283510	12815	Economy	13400.00
0005434068881	12815	Economy	13400.00
0005434069036	12815	Economy	13400.00
0005433989859	12815	Economy	13400.00
0005433989858	12815	Economy	13400.00
0005434082370	12815	Economy	13400.00
0005434082388	12815	Economy	13400.00
0005434082382	12815	Economy	13400.00
0005434068970	12815	Economy	13400.00
0005434069112	12815	Economy	13400.00
0005433989848	12815	Economy	13400.00
0005435283516	12815	Economy	13400.00
0005434069000	12815	Economy	13400.00
0005432433833	12815	Economy	13400.00
0005434082428	12815	Economy	13400.00
0005434068858	12815	Economy	13400.00
0005434069044	12815	Economy	13400.00
0005432161218	12815	Economy	13400.00
0005434068864	12815	Economy	13400.00
0005433989857	12815	Economy	13400.00
0005434068861	12815	Economy	13400.00
0005434082502	12815	Economy	13400.00
0005434068668	12815	Economy	13400.00
0005434069099	12815	Economy	13400.00
0005434069228	12815	Economy	13400.00
0005434082342	12815	Economy	13400.00
0005434082449	12815	Economy	13400.00
0005434069041	12815	Economy	13400.00
0005434068771	12815	Economy	13400.00
0005434069427	12815	Economy	13400.00
0005434068905	12815	Economy	13400.00
0005434069089	12815	Economy	13400.00
0005434068885	12815	Economy	13400.00
0005434068995	12815	Economy	13400.00
0005434069140	12815	Economy	13400.00
0005434068904	12815	Economy	13400.00
0005434068999	12815	Economy	13400.00
0005434069344	12815	Economy	13400.00
0005434068918	12815	Economy	13400.00
0005434068663	12815	Economy	13400.00
0005434069080	12815	Economy	13400.00
0005434082328	12815	Economy	13400.00
0005435283512	12815	Economy	13400.00
0005434082429	12815	Economy	13400.00
0005434082347	12815	Economy	13400.00
0005434069025	12815	Economy	13400.00
0005434068762	12815	Economy	13400.00
0005434069540	30662	Business	40300.00
0005434069537	30662	Business	40300.00
0005433989899	30662	Business	40300.00
0005432186970	30662	Business	40300.00
0005434069570	30662	Business	40300.00
0005432186972	30662	Business	40300.00
0005434069533	30662	Business	40300.00
0005434069557	30662	Business	40300.00
0005434069545	30662	Economy	13400.00
0005432186969	30662	Economy	13400.00
0005433989898	30662	Economy	13400.00
0005434082594	30662	Economy	13400.00
0005435283415	30662	Economy	13400.00
0005432433786	30662	Economy	13400.00
0005434069535	30662	Economy	13400.00
0005434069538	30662	Economy	13400.00
0005434069529	30662	Economy	13400.00
0005434069546	30662	Economy	13400.00
0005434082603	30662	Economy	13400.00
0005434069550	30662	Economy	13400.00
0005434082597	30662	Economy	13400.00
0005432433797	30662	Economy	13400.00
0005434069560	30662	Economy	13400.00
0005434082593	30662	Economy	13400.00
0005434082596	30662	Economy	13400.00
0005434082607	30662	Economy	13400.00
0005433989900	30662	Economy	13400.00
0005434082608	30662	Economy	13400.00
0005434069527	30662	Economy	13400.00
0005434082609	30662	Economy	13400.00
0005432150418	30662	Economy	13400.00
0005434069526	30662	Economy	13400.00
0005434069525	30662	Economy	13400.00
0005434069561	30662	Economy	14800.00
0005434082600	30662	Economy	14800.00
0005434069558	30662	Economy	14800.00
0005434069564	30662	Economy	13400.00
0005434082591	30662	Economy	13400.00
0005434069530	30662	Economy	13400.00
0005434069549	30662	Economy	13400.00
0005434069556	30662	Economy	13400.00
0005434069568	30662	Economy	13400.00
0005434069544	30662	Economy	13400.00
0005434069534	30662	Economy	13400.00
0005434069541	30662	Economy	13400.00
0005434069551	30662	Economy	13400.00
0005432433819	30662	Economy	13400.00
0005434082592	30662	Economy	13400.00
0005434069536	30662	Economy	13400.00
0005434069554	30662	Economy	13400.00
0005434069547	30662	Economy	13400.00
0005434069548	30662	Economy	13400.00
0005433989901	30662	Economy	13400.00
0005434069555	30662	Economy	13400.00
0005435283419	30662	Economy	13400.00
0005434082595	30662	Economy	13400.00
0005432186971	30662	Economy	13400.00
0005434069569	30662	Economy	13400.00
0005432433773	30662	Economy	13400.00
0005434082605	30662	Economy	13400.00
0005434069563	30662	Economy	13400.00
0005434069543	30662	Economy	13400.00
0005432150417	30662	Economy	13400.00
0005434082590	30662	Economy	13400.00
0005434069531	30662	Economy	13400.00
0005434082602	30662	Economy	13400.00
0005434082598	30662	Economy	13400.00
0005434069559	30662	Economy	13400.00
0005434069552	30662	Economy	13400.00
0005434069528	30662	Economy	13400.00
0005434069562	30662	Economy	13400.00
0005434082601	30662	Economy	13400.00
0005434069566	30662	Economy	13400.00
0005432433798	30662	Economy	13400.00
0005434069553	30662	Economy	13400.00
0005434069542	30662	Economy	13400.00
0005434082599	30662	Economy	13400.00
0005434069571	30662	Economy	13400.00
0005434069539	30662	Economy	13400.00
0005432433818	30662	Economy	13400.00
0005434069567	30662	Economy	13400.00
0005434069565	30662	Economy	13400.00
0005434082606	30662	Economy	13400.00
0005434069532	30662	Economy	13400.00
0005434082604	30662	Economy	13400.00
0005434082589	30662	Economy	13400.00
0005432433793	30662	Economy	13400.00
0005432433796	30662	Economy	13400.00
0005433686672	19359	Economy	19300.00
0005433686674	19359	Economy	17600.00
0005433686670	19359	Economy	17600.00
0005433689946	19359	Economy	17600.00
0005433689943	19359	Economy	17600.00
0005433689949	19359	Economy	17600.00
0005433689948	19359	Economy	17600.00
0005433686675	19359	Economy	17600.00
0005433689944	19359	Economy	17600.00
0005433686668	19359	Economy	17600.00
0005433689950	19359	Economy	17600.00
0005433686673	19359	Economy	17600.00
0005433686666	19359	Economy	17600.00
0005433689953	19359	Economy	17600.00
0005433689947	19359	Economy	17600.00
0005433686671	19359	Economy	17600.00
0005433686667	19359	Economy	17600.00
0005433686663	19359	Economy	17600.00
0005435768010	5530	Business	35300.00
0005435462997	5530	Business	35300.00
0005435463138	5530	Business	35300.00
0005435768006	5530	Business	35300.00
0005432535938	5530	Business	35300.00
0005435768039	5530	Business	35300.00
0005435768009	5530	Business	35300.00
0005434831258	5530	Business	35300.00
0005432535937	5530	Business	35300.00
0005435722122	5530	Business	35300.00
0005435768025	5530	Business	35300.00
0005435768033	5530	Business	35300.00
0005435768014	5530	Business	35300.00
0005435768034	5530	Business	35300.00
0005435463109	5530	Business	35300.00
0005435768035	5530	Business	35300.00
0005434265541	5530	Business	35300.00
0005435463263	5530	Business	35300.00
0005434265643	5530	Economy	12900.00
0005434265676	5530	Economy	12900.00
0005435768020	5530	Economy	11800.00
0005435768021	5530	Economy	11800.00
0005433527373	5530	Economy	11800.00
0005435768007	5530	Economy	11800.00
0005434265620	5530	Economy	11800.00
0005435463268	5530	Economy	11800.00
0005435768012	5530	Economy	11800.00
0005434265608	5530	Economy	11800.00
0005434265653	5530	Economy	11800.00
0005435735270	5530	Economy	11800.00
0005435463295	5530	Economy	11800.00
0005435768028	5530	Economy	11800.00
0005434265650	5530	Economy	11800.00
0005435463188	5530	Economy	11800.00
0005435722121	5530	Economy	11800.00
0005435463286	5530	Economy	11800.00
0005435768030	5530	Economy	11800.00
0005435768016	5530	Economy	11800.00
0005434831227	5530	Economy	11800.00
0005435768024	5530	Economy	11800.00
0005434831228	5530	Economy	11800.00
0005434265698	5530	Economy	11800.00
0005435768036	5530	Economy	11800.00
0005434265646	5530	Economy	11800.00
0005435463262	5530	Economy	11800.00
0005435617176	5530	Economy	11800.00
0005435462998	5530	Economy	11800.00
0005432140682	5530	Economy	11800.00
0005435463390	5530	Economy	11800.00
0005434265661	5530	Economy	11800.00
0005435463289	5530	Economy	11800.00
0005435735269	5530	Economy	11800.00
0005435735279	5530	Economy	11800.00
0005435768015	5530	Economy	11800.00
0005435768023	5530	Economy	11800.00
0005435463345	5530	Economy	11800.00
0005434265612	5530	Economy	11800.00
0005435768040	5530	Economy	11800.00
0005435768013	5530	Economy	11800.00
0005435768022	5530	Economy	11800.00
0005432535963	5530	Economy	11800.00
0005434831242	5530	Economy	11800.00
0005435463110	5530	Economy	11800.00
0005435768018	5530	Economy	11800.00
0005435463288	5530	Economy	11800.00
0005435463140	5530	Economy	11800.00
0005434831259	5530	Economy	11800.00
0005434265644	5530	Economy	11800.00
0005435463218	5530	Economy	11800.00
0005435463066	5530	Economy	11800.00
0005435723102	5530	Economy	11800.00
0005434265699	5530	Economy	11800.00
0005434265551	5530	Economy	11800.00
0005434265697	5530	Economy	11800.00
0005435768005	5530	Economy	11800.00
0005435463151	5530	Economy	11800.00
0005433529386	5530	Economy	11800.00
0005433529387	5530	Economy	12900.00
0005435768032	5530	Economy	12900.00
0005434831235	5530	Economy	11800.00
0005435463264	5530	Economy	12900.00
0005435463257	5530	Economy	11800.00
0005432535942	5530	Economy	11800.00
0005435463259	5530	Economy	11800.00
0005434265652	5530	Economy	11800.00
0005435463160	5530	Economy	11800.00
0005435768011	5530	Economy	11800.00
0005434265751	5530	Economy	11800.00
0005435768019	5530	Economy	11800.00
0005435723103	5530	Economy	11800.00
0005434265696	5530	Economy	11800.00
0005435735273	5530	Economy	11800.00
0005433527372	5530	Economy	11800.00
0005435463220	5530	Economy	11800.00
0005435768017	5530	Economy	11800.00
0005432140681	5530	Economy	11800.00
0005435768037	5530	Economy	11800.00
0005435768026	5530	Economy	11800.00
0005435463237	5530	Economy	11800.00
0005434265651	5530	Economy	11800.00
0005435463267	5530	Economy	11800.00
0005435768008	5530	Economy	11800.00
0005434831249	5530	Economy	11800.00
0005435768027	5530	Economy	11800.00
0005434265677	5530	Economy	11800.00
0005434265649	5530	Economy	11800.00
0005432535936	5530	Economy	11800.00
0005435768029	5530	Economy	11800.00
0005435735272	5530	Economy	11800.00
0005435463212	5530	Economy	11800.00
0005434831234	5530	Economy	11800.00
0005432535941	5530	Economy	11800.00
0005434265708	5530	Economy	11800.00
0005435463260	5530	Economy	11800.00
0005435463383	5530	Economy	11800.00
0005434265621	5530	Economy	11800.00
0005434265645	5530	Economy	11800.00
0005435735271	5530	Economy	11800.00
0005435768038	5530	Economy	11800.00
0005435463181	5530	Economy	11800.00
0005434265656	5530	Economy	11800.00
0005435463230	5530	Economy	11800.00
0005435768031	5530	Economy	11800.00
0005433533388	13498	Business	35300.00
0005435767582	13498	Business	35300.00
0005435767577	13498	Business	35300.00
0005435735243	13498	Business	35300.00
0005435767498	13498	Business	35300.00
0005435767234	13498	Business	35300.00
0005434831286	13498	Business	35300.00
0005435617203	13498	Business	35300.00
0005432194633	13498	Business	35300.00
0005433529343	13498	Business	35300.00
0005435723087	13498	Business	35300.00
0005435767552	13498	Business	35300.00
0005434265876	13498	Business	35300.00
0005433529353	13498	Business	35300.00
0005435725690	13498	Business	35300.00
0005435463503	13498	Business	35300.00
0005435767580	13498	Business	35300.00
0005434831285	13498	Business	35300.00
0005435767239	13498	Business	35300.00
0005435767789	13498	Business	35300.00
0005435767575	13498	Business	35300.00
0005434265878	13498	Business	35300.00
0005435767654	13498	Business	35300.00
0005435767684	13498	Business	35300.00
0005435617202	13498	Economy	12900.00
0005435767545	13498	Economy	12900.00
0005433529344	13498	Economy	12900.00
0005435767761	13498	Economy	11800.00
0005435767194	13498	Economy	11800.00
0005435767594	13498	Economy	11800.00
0005435735223	13498	Economy	11800.00
0005435767571	13498	Economy	11800.00
0005435723085	13498	Economy	11800.00
0005435767699	13498	Economy	11800.00
0005435767331	13498	Economy	11800.00
0005435767332	13498	Economy	11800.00
0005435767245	13498	Economy	11800.00
0005435723084	13498	Economy	11800.00
0005435767374	13498	Economy	11800.00
0005435767480	13498	Economy	11800.00
0005435723094	13498	Economy	11800.00
0005435767457	13498	Economy	11800.00
0005434265877	13498	Economy	11800.00
0005434265875	13498	Economy	11800.00
0005435735220	13498	Economy	11800.00
0005435767167	13498	Economy	11800.00
0005435767479	13498	Economy	11800.00
0005435725692	13498	Economy	11800.00
0005434265872	13498	Economy	11800.00
0005435735224	13498	Economy	11800.00
0005434265874	13498	Economy	11800.00
0005435767468	13498	Economy	11800.00
0005435463499	13498	Economy	11800.00
0005435767512	13498	Economy	11800.00
0005435767521	13498	Economy	11800.00
0005432194631	13498	Economy	11800.00
0005435767400	13498	Economy	11800.00
0005435463501	13498	Economy	11800.00
0005435767569	13498	Economy	11800.00
0005433533375	13498	Economy	11800.00
0005435767578	13498	Economy	11800.00
0005433533403	13498	Economy	11800.00
0005435767214	13498	Economy	11800.00
0005435767656	13498	Economy	11800.00
0005435463507	13498	Economy	11800.00
0005435767598	13498	Economy	11800.00
0005435767564	13498	Economy	11800.00
0005433533389	13498	Economy	11800.00
0005435767762	13498	Economy	11800.00
0005435767649	13498	Economy	11800.00
0005435722110	13498	Economy	11800.00
0005435767375	13498	Economy	11800.00
0005435767444	13498	Economy	11800.00
0005435767756	13498	Economy	11800.00
0005435767233	13498	Economy	11800.00
0005435725693	13498	Economy	11800.00
0005435767446	13498	Economy	11800.00
0005435725681	13498	Economy	11800.00
0005435767243	13498	Economy	11800.00
0005435767465	13498	Economy	11800.00
0005435767445	13498	Economy	11800.00
0005434265871	13498	Economy	11800.00
0005433529340	13498	Economy	11800.00
0005435463505	13498	Economy	11800.00
0005435463504	13498	Economy	12900.00
0005435767551	13498	Economy	12900.00
0005434831287	13498	Economy	11800.00
0005433533360	13498	Economy	11800.00
0005434265870	13498	Economy	11800.00
0005435767217	13498	Economy	11800.00
0005435767685	13498	Economy	11800.00
0005433533385	13498	Economy	11800.00
0005435463506	13498	Economy	11800.00
0005435767244	13498	Economy	11800.00
0005435722108	13498	Economy	11800.00
0005435767611	13498	Economy	11800.00
0005435767447	13498	Economy	11800.00
0005435767506	13498	Economy	11800.00
0005435767579	13498	Economy	11800.00
0005435463509	13498	Economy	11800.00
0005433529323	13498	Economy	11800.00
0005432535974	13498	Economy	11800.00
0005434265873	13498	Economy	11800.00
0005435463502	13498	Economy	11800.00
0005435767546	13498	Economy	11800.00
0005435617204	13498	Economy	11800.00
0005435767497	13498	Economy	11800.00
0005435767576	13498	Economy	11800.00
0005433533361	13498	Economy	11800.00
0005435767376	13498	Economy	11800.00
0005435767646	13498	Economy	11800.00
0005435767467	13498	Economy	11800.00
0005435463508	13498	Economy	11800.00
0005435767565	13498	Economy	11800.00
0005433529342	13498	Economy	11800.00
0005435767216	13498	Economy	11800.00
0005435463498	13498	Economy	11800.00
0005433533404	13498	Economy	11800.00
0005433533367	13498	Economy	11800.00
0005433529332	13498	Economy	11800.00
0005432194632	13498	Economy	11800.00
0005435767581	13498	Economy	11800.00
0005433529333	13498	Economy	11800.00
0005435767503	13498	Economy	11800.00
0005435722109	13498	Economy	11800.00
0005435767401	13498	Economy	11800.00
0005435463500	13498	Economy	11800.00
0005435723086	13498	Economy	11800.00
0005435767097	13498	Economy	11800.00
0005434602953	18720	Economy	3300.00
0005434602963	18720	Economy	3300.00
0005434602964	18720	Economy	3300.00
0005434602952	18720	Economy	3300.00
0005434602951	18720	Economy	3300.00
0005434513655	18697	Economy	3300.00
0005434515042	18697	Economy	3300.00
0005434515043	18697	Economy	3300.00
0005434515045	18697	Economy	3300.00
0005434604964	18697	Economy	3300.00
0005435904490	18697	Economy	3300.00
0005434513654	18697	Economy	3300.00
0005434515044	18697	Economy	3300.00
0005434515032	19165	Economy	3300.00
0005434515019	19165	Economy	3300.00
0005434515018	19165	Economy	3300.00
0005432632933	4132	Business	88300.00
0005435846329	4132	Business	88300.00
0005432632939	4132	Business	88300.00
0005432649570	4132	Business	88300.00
0005435846321	4132	Economy	29400.00
0005435846324	4132	Economy	29400.00
0005435846315	4132	Economy	29400.00
0005435846338	4132	Economy	29400.00
0005435846320	4132	Economy	29400.00
0005432649571	4132	Economy	32400.00
0005435844384	4132	Economy	32400.00
0005432632932	4132	Economy	32400.00
0005435846326	4132	Economy	29400.00
0005435846312	4132	Economy	29400.00
0005432649569	4132	Economy	29400.00
0005435846310	4132	Economy	29400.00
0005435846328	4132	Economy	29400.00
0005435846336	4132	Economy	29400.00
0005435844387	4132	Economy	29400.00
0005432632935	4132	Economy	29400.00
0005432649567	4132	Economy	29400.00
0005435846335	4132	Economy	29400.00
0005435844402	4132	Economy	29400.00
0005435846339	4132	Economy	29400.00
0005432632936	4132	Economy	29400.00
0005435846319	4132	Economy	29400.00
0005435844386	4132	Economy	29400.00
0005432632938	4132	Economy	29400.00
0005432632934	4132	Economy	29400.00
0005435846313	4132	Economy	29400.00
0005435846316	4132	Economy	29400.00
0005432649568	4132	Economy	29400.00
0005432632937	4132	Economy	29400.00
0005435844366	4132	Economy	29400.00
0005435846327	4132	Economy	29400.00
0005435844389	4132	Economy	29400.00
0005432632931	4132	Economy	29400.00
0005432632940	4132	Economy	29400.00
0005433286055	1776	Business	48700.00
0005433286017	1776	Business	48700.00
0005433009650	1776	Business	48700.00
0005433285935	1776	Business	48700.00
0005433810760	1776	Business	48700.00
0005433285916	1776	Business	48700.00
0005433286016	1776	Business	48700.00
0005433009579	1776	Business	48700.00
0005433285995	1776	Business	48700.00
0005433009761	1776	Business	48700.00
0005433009470	1776	Business	48700.00
0005433009701	1776	Business	48700.00
0005433009651	1776	Economy	16200.00
0005433285814	1776	Economy	16200.00
0005433810754	1776	Economy	16200.00
0005433285903	1776	Economy	16200.00
0005433009488	1776	Economy	16200.00
0005433286086	1776	Economy	16200.00
0005433286021	1776	Economy	16200.00
0005433285920	1776	Economy	16200.00
0005433285929	1776	Economy	16200.00
0005433285921	1776	Economy	16200.00
0005433009581	1776	Economy	17900.00
0005433285890	1776	Economy	17900.00
0005433285813	1776	Economy	17900.00
0005433286078	1776	Economy	17900.00
0005433009578	1776	Economy	17900.00
0005433009456	1776	Economy	16200.00
0005433009364	1776	Economy	16200.00
0005433285991	1776	Economy	16200.00
0005433810756	1776	Economy	16200.00
0005433009431	1776	Economy	16200.00
0005433286024	1776	Economy	16200.00
0005433285885	1776	Economy	16200.00
0005433009549	1776	Economy	16200.00
0005433286063	1776	Economy	16200.00
0005433285931	1776	Economy	16200.00
0005433009540	1776	Economy	16200.00
0005433009458	1776	Economy	16200.00
0005433285982	1776	Economy	16200.00
0005433810759	1776	Economy	16200.00
0005433810757	1776	Economy	16200.00
0005433009542	1776	Economy	16200.00
0005433009459	1776	Economy	16200.00
0005433009582	1776	Economy	16200.00
0005433810758	1776	Economy	16200.00
0005433285856	1776	Economy	16200.00
0005433286018	1776	Economy	16200.00
0005433285932	1776	Economy	16200.00
0005433286054	1776	Economy	16200.00
0005433009619	1776	Economy	16200.00
0005433009635	1776	Economy	16200.00
0005433286097	1776	Economy	16200.00
0005433009574	1776	Economy	16200.00
0005433286028	1776	Economy	16200.00
0005433009685	1776	Economy	16200.00
0005433286066	1776	Economy	16200.00
0005433285879	1776	Economy	16200.00
0005433009430	1776	Economy	16200.00
0005433285915	1776	Economy	16200.00
0005433285902	1776	Economy	16200.00
0005433285933	1776	Economy	16200.00
0005433285912	1776	Economy	16200.00
0005433009546	1776	Economy	16200.00
0005433009611	1776	Economy	16200.00
0005433009327	1776	Economy	16200.00
0005433009692	1776	Economy	16200.00
0005433285934	1776	Economy	16200.00
0005433009471	1776	Economy	16200.00
0005433009726	1776	Economy	16200.00
0005433009322	1776	Economy	16200.00
0005433286009	1776	Economy	16200.00
0005433009531	1776	Economy	16200.00
0005433285913	1776	Economy	16200.00
0005433009690	1776	Economy	16200.00
0005433009496	1776	Economy	16200.00
0005433009618	1776	Economy	16200.00
0005433009520	1776	Economy	16200.00
0005433009697	1776	Economy	16200.00
0005433009609	1776	Economy	16200.00
0005433009760	1776	Economy	16200.00
0005433286065	1776	Economy	16200.00
0005433009457	1776	Economy	16200.00
0005433009526	1776	Economy	16200.00
0005433810753	1776	Economy	16200.00
0005433009573	1776	Economy	16200.00
0005433285848	1776	Economy	16200.00
0005433285969	1776	Economy	16200.00
0005433285930	1776	Economy	16200.00
0005433009527	1776	Economy	16200.00
0005433009636	1776	Economy	16200.00
0005433810755	1776	Economy	16200.00
0005433286034	1776	Economy	16200.00
0005433009547	1776	Economy	16200.00
0005433286010	1776	Economy	16200.00
0005433009379	1776	Economy	16200.00
0005433810752	1776	Economy	16200.00
0005433286170	22574	Business	48700.00
0005433009900	22574	Business	48700.00
0005433009901	22574	Business	48700.00
0005433009889	22574	Business	48700.00
0005433810638	22574	Business	48700.00
0005433286175	22574	Business	48700.00
0005433810636	22574	Economy	16200.00
0005433286185	22574	Economy	16200.00
0005433009916	22574	Economy	16200.00
0005433009896	22574	Economy	16200.00
0005433286181	22574	Economy	16200.00
0005433810600	22574	Economy	17900.00
0005433009891	22574	Economy	17900.00
0005433009898	22574	Economy	17900.00
0005433286167	22574	Economy	17900.00
0005433286178	22574	Economy	16200.00
0005433286186	22574	Economy	16200.00
0005433009914	22574	Economy	16200.00
0005433810603	22574	Economy	16200.00
0005433009915	22574	Economy	16200.00
0005433286171	22574	Economy	16200.00
0005433810619	22574	Economy	16200.00
0005433009908	22574	Economy	16200.00
0005433810630	22574	Economy	16200.00
0005433009902	22574	Economy	16200.00
0005433810623	22574	Economy	16200.00
0005433009897	22574	Economy	16200.00
0005433009895	22574	Economy	16200.00
0005433009903	22574	Economy	16200.00
0005433009904	22574	Economy	16200.00
0005433009906	22574	Economy	16200.00
0005433286179	22574	Economy	16200.00
0005433009912	22574	Economy	16200.00
0005433009892	22574	Economy	16200.00
0005433810602	22574	Economy	16200.00
0005433810620	22574	Economy	16200.00
0005433009910	22574	Economy	16200.00
0005433009899	22574	Economy	16200.00
0005433009893	22574	Economy	16200.00
0005433810618	22574	Economy	16200.00
0005433286172	22574	Economy	16200.00
0005433810635	22574	Economy	16200.00
0005433286182	22574	Economy	16200.00
0005433009894	22574	Economy	16200.00
0005433009913	22574	Economy	16200.00
0005433286184	22574	Economy	16200.00
0005433286174	22574	Economy	16200.00
0005433009890	22574	Economy	16200.00
0005433286180	22574	Economy	16200.00
0005433810601	22574	Economy	16200.00
0005433810615	22574	Economy	16200.00
0005433286183	22574	Economy	16200.00
0005433286173	22574	Economy	16200.00
0005433286187	22574	Economy	16200.00
0005433009909	22574	Economy	16200.00
0005433009905	22574	Economy	16200.00
0005433009907	22574	Economy	16200.00
0005433009911	22574	Economy	16200.00
0005433286176	22574	Economy	16200.00
0005433286169	22574	Economy	16200.00
0005433286168	22574	Economy	16200.00
0005433286177	22574	Economy	16200.00
0005433810622	22574	Economy	16200.00
0005435282985	5550	Business	99800.00
0005433848352	5550	Business	99800.00
0005435282960	5550	Business	99800.00
0005433815521	5550	Business	99800.00
0005435283061	5550	Business	99800.00
0005435283037	5550	Business	99800.00
0005433848359	5550	Business	99800.00
0005433848353	5550	Business	99800.00
0005435283008	5550	Business	99800.00
0005433848372	5550	Business	99800.00
0005435282956	5550	Business	99800.00
0005433848366	5550	Business	99800.00
0005435283038	5550	Economy	33300.00
0005433848370	5550	Economy	33300.00
0005435282995	5550	Economy	33300.00
0005435283062	5550	Economy	33300.00
0005435282966	5550	Economy	33300.00
0005435282934	5550	Economy	33300.00
0005435282965	5550	Economy	36600.00
0005433848373	5550	Economy	36600.00
0005433848356	5550	Economy	33300.00
0005435283041	5550	Economy	33300.00
0005433848365	5550	Economy	33300.00
0005433848362	5550	Economy	33300.00
0005432081691	5550	Economy	33300.00
0005433848354	5550	Economy	33300.00
0005433848375	5550	Economy	33300.00
0005433848367	5550	Economy	33300.00
0005435282959	5550	Economy	33300.00
0005433848369	5550	Economy	33300.00
0005433848364	5550	Economy	33300.00
0005433848360	5550	Economy	33300.00
0005435282978	5550	Economy	33300.00
0005435282957	5550	Economy	33300.00
0005433815561	5550	Economy	33300.00
0005435282982	5550	Economy	33300.00
0005433848358	5550	Economy	33300.00
0005435282980	5550	Economy	33300.00
0005435283012	5550	Economy	33300.00
0005435283085	5550	Economy	33300.00
0005432081692	5550	Economy	33300.00
0005435282979	5550	Economy	33300.00
0005433848363	5550	Economy	33300.00
0005433848374	5550	Economy	33300.00
0005435283030	5550	Economy	33300.00
0005435282933	5550	Economy	33300.00
0005433848368	5550	Economy	33300.00
0005435283034	5550	Economy	33300.00
0005435282994	5550	Economy	33300.00
0005433815560	5550	Economy	33300.00
0005435282923	5550	Economy	33300.00
0005433815520	5550	Economy	33300.00
0005435282947	5550	Economy	33300.00
0005433848371	5550	Economy	33300.00
0005433848357	5550	Economy	33300.00
0005433848361	5550	Economy	33300.00
0005435283031	5550	Economy	33300.00
0005435282977	5550	Economy	33300.00
0005435283011	5550	Economy	33300.00
0005433848351	5550	Economy	33300.00
0005433848355	5550	Economy	33300.00
0005435283013	5550	Economy	33300.00
0005433847826	13846	Business	99800.00
0005433847728	13846	Business	99800.00
0005433847807	13846	Business	99800.00
0005433847847	13846	Business	99800.00
0005433847808	13846	Business	99800.00
0005433847586	13846	Business	99800.00
0005433847904	13846	Business	99800.00
0005433847966	13846	Business	99800.00
0005435283216	13846	Business	99800.00
0005433847863	13846	Business	99800.00
0005433848104	13846	Economy	33300.00
0005433847880	13846	Economy	33300.00
0005435283218	13846	Economy	33300.00
0005433847988	13846	Economy	33300.00
0005433848205	13846	Economy	33300.00
0005433847758	13846	Economy	33300.00
0005433847888	13846	Economy	33300.00
0005433848031	13846	Economy	33300.00
0005435283224	13846	Economy	36600.00
0005434173664	13846	Economy	36600.00
0005433815493	13846	Economy	36600.00
0005433847949	13846	Economy	33300.00
0005435283220	13846	Economy	33300.00
0005433847820	13846	Economy	33300.00
0005433848102	13846	Economy	33300.00
0005433847814	13846	Economy	33300.00
0005433848091	13846	Economy	33300.00
0005433847827	13846	Economy	33300.00
0005435283221	13846	Economy	33300.00
0005433847992	13846	Economy	33300.00
0005433847704	13846	Economy	33300.00
0005435283226	13846	Economy	33300.00
0005435283223	13846	Economy	33300.00
0005433847916	13846	Economy	33300.00
0005433847950	13846	Economy	33300.00
0005435283222	13846	Economy	33300.00
0005433815465	13846	Economy	33300.00
0005432003793	13846	Economy	33300.00
0005433848270	13846	Economy	33300.00
0005435283217	13846	Economy	33300.00
0005433848046	13846	Economy	33300.00
0005433847755	13846	Economy	33300.00
0005433847587	13846	Economy	33300.00
0005433847818	13846	Economy	33300.00
0005433847817	13846	Economy	33300.00
0005433848111	13846	Economy	33300.00
0005435283225	13846	Economy	33300.00
0005433815492	13846	Economy	33300.00
0005433847840	13846	Economy	33300.00
0005433847947	13846	Economy	33300.00
0005433847821	13846	Economy	33300.00
0005433847889	13846	Economy	33300.00
0005433847993	13846	Economy	33300.00
0005433848103	13846	Economy	33300.00
0005433847946	13846	Economy	33300.00
0005433847795	13846	Economy	33300.00
0005433848034	13846	Economy	33300.00
0005433847776	13846	Economy	33300.00
0005433847948	13846	Economy	33300.00
0005435283215	13846	Economy	33300.00
0005433847935	13846	Economy	33300.00
0005435283228	13846	Economy	33300.00
0005433847862	13846	Economy	33300.00
0005433847858	13846	Economy	33300.00
0005433848194	13846	Economy	33300.00
0005433848114	13846	Economy	33300.00
0005433847806	13846	Economy	33300.00
0005434173662	13846	Economy	33300.00
0005433847729	13846	Economy	33300.00
0005433848096	13846	Economy	33300.00
0005433847588	13846	Economy	33300.00
0005433847841	13846	Economy	33300.00
0005433847931	13846	Economy	33300.00
0005435283227	13846	Economy	33300.00
0005433847815	13846	Economy	33300.00
0005433815495	13846	Economy	33300.00
0005435283219	13846	Economy	33300.00
0005433847839	13846	Economy	33300.00
0005434173663	13846	Economy	33300.00
0005434621162	7849	Economy	16600.00
0005432112580	7849	Economy	15100.00
0005435332507	7849	Economy	15100.00
0005434621165	7849	Economy	15100.00
0005435332557	7849	Economy	15100.00
0005434621170	7849	Economy	15100.00
0005434621166	7849	Economy	15100.00
0005434621168	7849	Economy	15100.00
0005434621171	7849	Economy	15100.00
0005434621167	7849	Economy	15100.00
0005435332550	7849	Economy	15100.00
0005434621164	7849	Economy	15100.00
0005434621163	7849	Economy	15100.00
0005434621169	7849	Economy	15100.00
0005434621062	32966	Economy	16600.00
0005434620975	32966	Economy	15100.00
0005434621048	32966	Economy	15100.00
0005435332629	32966	Economy	15100.00
0005434620992	32966	Economy	15100.00
0005434621018	32966	Economy	15100.00
0005434620994	32966	Economy	15100.00
0005434620993	32966	Economy	15100.00
0005434621073	32966	Economy	15100.00
0005435332630	32966	Economy	15100.00
0005435332631	32966	Economy	15100.00
0005434620996	32966	Economy	15100.00
0005434621007	32966	Economy	15100.00
0005434620985	32966	Economy	15100.00
0005434621006	32966	Economy	15100.00
0005434620938	32966	Economy	15100.00
0005434620982	32966	Economy	15100.00
0005434621025	32966	Economy	15100.00
0005434620937	32966	Economy	15100.00
0005435332632	32966	Economy	15100.00
0005434620966	32966	Economy	15100.00
0005434620995	32966	Economy	15100.00
0005434621047	32966	Economy	15100.00
0005435786325	4283	Business	38000.00
0005435786328	4283	Business	38000.00
0005434994300	4283	Business	38000.00
0005435786323	4283	Business	38000.00
0005435937471	4283	Business	38000.00
0005435786333	4283	Business	38000.00
0005435786332	4283	Economy	12700.00
0005434994302	4283	Economy	12700.00
0005435937470	4283	Economy	13900.00
0005435937494	4283	Economy	12700.00
0005435937499	4283	Economy	12700.00
0005435937487	4283	Economy	12700.00
0005434994299	4283	Economy	12700.00
0005435937498	4283	Economy	12700.00
0005434994297	4283	Economy	12700.00
0005435937479	4283	Economy	12700.00
0005435918763	4283	Economy	12700.00
0005435937472	4283	Economy	12700.00
0005435937497	4283	Economy	12700.00
0005435786337	4283	Economy	12700.00
0005435786339	4283	Economy	12700.00
0005435937496	4283	Economy	12700.00
0005435786330	4283	Economy	12700.00
0005435918762	4283	Economy	12700.00
0005435937473	4283	Economy	12700.00
0005434994298	4283	Economy	12700.00
0005435786329	4283	Economy	12700.00
0005435786336	4283	Economy	12700.00
0005435937480	4283	Economy	12700.00
0005435937486	4283	Economy	12700.00
0005435786338	4283	Economy	12700.00
0005435786335	4283	Economy	12700.00
0005435786327	4283	Economy	12700.00
0005435937488	4283	Economy	12700.00
0005435937510	4283	Economy	12700.00
0005435786326	4283	Economy	12700.00
0005435786324	4283	Economy	12700.00
0005434994301	4283	Economy	12700.00
0005435786334	4283	Economy	12700.00
0005435786331	4283	Economy	12700.00
0005434994207	27325	Business	38000.00
0005435786050	27325	Business	38000.00
0005435786016	27325	Business	38000.00
0005435786063	27325	Business	38000.00
0005434994224	27325	Business	38000.00
0005435937555	27325	Economy	12700.00
0005434994201	27325	Economy	12700.00
0005434994237	27325	Economy	12700.00
0005435785973	27325	Economy	12700.00
0005435786002	27325	Economy	12700.00
0005435785974	27325	Economy	12700.00
0005435785924	27325	Economy	12700.00
0005435786093	27325	Economy	12700.00
0005435785937	27325	Economy	13900.00
0005435937554	27325	Economy	13900.00
0005435785909	27325	Economy	13900.00
0005435937556	27325	Economy	12700.00
0005435785994	27325	Economy	12700.00
0005434994206	27325	Economy	12700.00
0005435786116	27325	Economy	12700.00
0005435786079	27325	Economy	12700.00
0005435786102	27325	Economy	12700.00
0005435785921	27325	Economy	12700.00
0005435786130	27325	Economy	12700.00
0005435786190	27325	Economy	12700.00
0005435787391	27325	Economy	12700.00
0005435786040	27325	Economy	12700.00
0005435785890	27325	Economy	12700.00
0005435786019	27325	Economy	12700.00
0005435937549	27325	Economy	12700.00
0005435786036	27325	Economy	12700.00
0005435786051	27325	Economy	12700.00
0005435785950	27325	Economy	12700.00
0005435785949	27325	Economy	12700.00
0005435785984	27325	Economy	12700.00
0005435786017	27325	Economy	12700.00
0005435785932	27325	Economy	12700.00
0005435937553	27325	Economy	12700.00
0005435786018	27325	Economy	12700.00
0005435785886	27325	Economy	12700.00
0005435785914	27325	Economy	12700.00
0005435785992	27325	Economy	12700.00
0005434994222	27325	Economy	12700.00
0005435786029	27325	Economy	12700.00
0005435786028	27325	Economy	12700.00
0005434994218	27325	Economy	12700.00
0005435937552	27325	Economy	12700.00
0005435785892	27325	Economy	12700.00
0005435937550	27325	Economy	12700.00
0005435786030	27325	Economy	12700.00
0005435786037	27325	Economy	12700.00
0005435785891	27325	Economy	12700.00
0005435785908	27325	Economy	12700.00
0005435786191	27325	Economy	12700.00
0005435785938	27325	Economy	12700.00
0005435937557	27325	Economy	12700.00
0005434994238	27325	Economy	12700.00
0005435937551	27325	Economy	12700.00
0005434994200	27325	Economy	12700.00
0005434994259	27325	Economy	12700.00
0005432569366	4735	Business	40900.00
0005432461349	4735	Business	40900.00
0005432569345	4735	Business	40900.00
0005432569368	4735	Business	40900.00
0005435840366	4735	Business	40900.00
0005432461360	4735	Business	40900.00
0005434082619	4735	Business	40900.00
0005432461355	4735	Business	40900.00
0005432569369	4735	Business	40900.00
0005432170575	4735	Business	40900.00
0005432461336	4735	Business	40900.00
0005432461343	4735	Business	40900.00
0005432170580	4735	Business	40900.00
0005435840364	4735	Business	40900.00
0005432569375	4735	Business	40900.00
0005434082621	4735	Business	40900.00
0005432461344	4735	Economy	15000.00
0005434082620	4735	Economy	15000.00
0005432461359	4735	Economy	13600.00
0005432569362	4735	Economy	13600.00
0005432569364	4735	Economy	13600.00
0005432569373	4735	Economy	13600.00
0005432461331	4735	Economy	13600.00
0005432569357	4735	Economy	13600.00
0005432569358	4735	Economy	13600.00
0005432569350	4735	Economy	13600.00
0005435840365	4735	Economy	13600.00
0005432170576	4735	Economy	13600.00
0005435840368	4735	Economy	13600.00
0005432569361	4735	Economy	13600.00
0005434559180	4735	Economy	13600.00
0005432569359	4735	Economy	13600.00
0005432170581	4735	Economy	13600.00
0005432569372	4735	Economy	13600.00
0005434082622	4735	Economy	13600.00
0005432461333	4735	Economy	13600.00
0005432569367	4735	Economy	13600.00
0005434082616	4735	Economy	13600.00
0005432569370	4735	Economy	13600.00
0005432571433	4735	Economy	13600.00
0005435840379	4735	Economy	13600.00
0005432571431	4735	Economy	13600.00
0005432461348	4735	Economy	13600.00
0005432461347	4735	Economy	13600.00
0005432461335	4735	Economy	13600.00
0005434082623	4735	Economy	13600.00
0005435840389	4735	Economy	13600.00
0005432569374	4735	Economy	13600.00
0005432569346	4735	Economy	13600.00
0005432569351	4735	Economy	13600.00
0005432170577	4735	Economy	13600.00
0005434082610	4735	Economy	13600.00
0005432461342	4735	Economy	13600.00
0005434082618	4735	Economy	13600.00
0005432461352	4735	Economy	13600.00
0005435840361	4735	Economy	13600.00
0005432461332	4735	Economy	13600.00
0005433726171	4735	Economy	13600.00
0005432569347	4735	Economy	13600.00
0005432170579	4735	Economy	13600.00
0005434082613	4735	Economy	13600.00
0005432461351	4735	Economy	13600.00
0005432461356	4735	Economy	13600.00
0005434082614	4735	Economy	13600.00
0005432569356	4735	Economy	13600.00
0005432461339	4735	Economy	13600.00
0005432461334	4735	Economy	15000.00
0005432569354	4735	Economy	13600.00
0005432461337	4735	Economy	13600.00
0005432170578	4735	Economy	13600.00
0005432461345	4735	Economy	13600.00
0005434082615	4735	Economy	15000.00
0005432461346	4735	Economy	15000.00
0005432571430	4735	Economy	13600.00
0005434559177	4735	Economy	13600.00
0005432569371	4735	Economy	13600.00
0005434082612	4735	Economy	13600.00
0005432461353	4735	Economy	13600.00
0005433452795	4735	Economy	13600.00
0005432461341	4735	Economy	13600.00
0005432569352	4735	Economy	13600.00
0005432569343	4735	Economy	13600.00
0005432569355	4735	Economy	13600.00
0005434559179	4735	Economy	13600.00
0005434559178	4735	Economy	13600.00
0005432569344	4735	Economy	13600.00
0005435840396	4735	Economy	13600.00
0005435840367	4735	Economy	13600.00
0005432569365	4735	Economy	13600.00
0005432461354	4735	Economy	13600.00
0005434082611	4735	Economy	13600.00
0005432571432	4735	Economy	13600.00
0005434559181	4735	Economy	13600.00
0005432569363	4735	Economy	13600.00
0005432569360	4735	Economy	13600.00
0005432461357	4735	Economy	13600.00
0005432461340	4735	Economy	13600.00
0005434082617	4735	Economy	13600.00
0005432461338	4735	Economy	13600.00
0005432461358	4735	Economy	13600.00
0005432569349	4735	Economy	13600.00
0005435840395	4735	Economy	13600.00
0005432569353	4735	Economy	13600.00
0005433726170	4735	Economy	13600.00
0005434559182	4735	Economy	13600.00
0005434559183	4735	Economy	13600.00
0005432461350	4735	Economy	13600.00
0005435840391	4735	Economy	13600.00
0005432569348	4735	Economy	13600.00
0005434150190	30558	Business	40900.00
0005432568700	30558	Business	40900.00
0005434082429	30558	Business	40900.00
0005432569201	30558	Business	40900.00
0005432569068	30558	Business	40900.00
0005432461104	30558	Business	40900.00
0005432460959	30558	Business	40900.00
0005434082387	30558	Business	40900.00
0005432161217	30558	Business	40900.00
0005432569053	30558	Business	40900.00
0005434082342	30558	Business	40900.00
0005432568842	30558	Business	40900.00
0005432568907	30558	Business	40900.00
0005434150201	30558	Business	40900.00
0005432460973	30558	Business	40900.00
0005434150196	30558	Business	40900.00
0005435840518	30558	Business	40900.00
0005434082329	30558	Business	40900.00
0005432461221	30558	Business	40900.00
0005434150188	30558	Business	40900.00
0005432460960	30558	Business	40900.00
0005432461112	30558	Business	40900.00
0005432461106	30558	Economy	15000.00
0005432568911	30558	Business	40900.00
0005432569006	30558	Economy	15000.00
0005432569004	30558	Economy	15000.00
0005432569108	30558	Economy	13600.00
0005432569017	30558	Economy	13600.00
0005435960174	30558	Economy	13600.00
0005434082390	30558	Economy	13600.00
0005432460987	30558	Economy	13600.00
0005432568965	30558	Economy	13600.00
0005432460968	30558	Economy	13600.00
0005432569155	30558	Economy	13600.00
0005432569128	30558	Economy	13600.00
0005432568840	30558	Economy	13600.00
0005432568805	30558	Economy	13600.00
0005435840517	30558	Economy	13600.00
0005432569014	30558	Economy	13600.00
0005433452784	30558	Economy	13600.00
0005432461021	30558	Economy	13600.00
0005432161218	30558	Economy	13600.00
0005432460972	30558	Economy	13600.00
0005432461150	30558	Economy	13600.00
0005432461071	30558	Economy	13600.00
0005434150200	30558	Economy	13600.00
0005433452783	30558	Economy	13600.00
0005432460775	30558	Economy	13600.00
0005432568912	30558	Economy	13600.00
0005434150202	30558	Economy	13600.00
0005432461149	30558	Economy	13600.00
0005434082347	30558	Economy	13600.00
0005432461111	30558	Economy	13600.00
0005432460740	30558	Economy	13600.00
0005432461165	30558	Economy	13600.00
0005432569024	30558	Economy	13600.00
0005432568884	30558	Economy	13600.00
0005433452782	30558	Economy	13600.00
0005434082262	30558	Economy	13600.00
0005435840519	30558	Economy	13600.00
0005434082501	30558	Economy	13600.00
0005434082449	30558	Economy	13600.00
0005434150191	30558	Economy	13600.00
0005432568946	30558	Economy	13600.00
0005432569022	30558	Economy	13600.00
0005432569023	30558	Economy	13600.00
0005434150199	30558	Economy	13600.00
0005432569208	30558	Economy	13600.00
0005432461026	30558	Economy	13600.00
0005432568979	30558	Economy	13600.00
0005435840508	30558	Economy	13600.00
0005432461035	30558	Economy	13600.00
0005432569045	30558	Economy	13600.00
0005434082261	30558	Economy	13600.00
0005432571389	30558	Economy	13600.00
0005434082260	30558	Economy	13600.00
0005432568881	30558	Economy	13600.00
0005432571411	30558	Economy	13600.00
0005432460894	30558	Economy	13600.00
0005432460989	30558	Economy	13600.00
0005432568956	30558	Economy	13600.00
0005432568931	30558	Economy	13600.00
0005432460803	30558	Economy	13600.00
0005434082328	30558	Economy	13600.00
0005435840521	30558	Economy	13600.00
0005432569069	30558	Economy	13600.00
0005435840512	30558	Economy	13600.00
0005435960175	30558	Economy	13600.00
0005434150194	30558	Economy	13600.00
0005432569027	30558	Economy	13600.00
0005432461056	30558	Economy	13600.00
0005434082457	30558	Economy	13600.00
0005434082382	30558	Economy	13600.00
0005432460853	30558	Economy	13600.00
0005432569026	30558	Economy	13600.00
0005434082341	30558	Economy	13600.00
0005432569081	30558	Economy	13600.00
0005432569254	30558	Economy	13600.00
0005435840511	30558	Economy	13600.00
0005435840516	30558	Economy	13600.00
0005434150197	30558	Economy	13600.00
0005432460938	30558	Economy	13600.00
0005432461144	30558	Economy	13600.00
0005435840514	30558	Economy	13600.00
0005432568944	30558	Economy	13600.00
0005434082428	30558	Economy	13600.00
0005432569052	30558	Economy	13600.00
0005434150189	30558	Economy	13600.00
0005432461187	30558	Economy	13600.00
0005434082346	30558	Economy	13600.00
0005432568760	30558	Economy	13600.00
0005434082389	30558	Economy	13600.00
0005432569005	30558	Economy	15000.00
0005432569087	30558	Economy	15000.00
0005432568864	30558	Economy	13600.00
0005432569111	30558	Economy	13600.00
0005432461082	30558	Economy	13600.00
0005432461107	30558	Economy	15000.00
0005434150192	30558	Economy	15000.00
0005432569209	30558	Economy	13600.00
0005434150185	30558	Economy	13600.00
0005432569061	30558	Economy	13600.00
0005434082503	30558	Economy	13600.00
0005432461055	30558	Economy	13600.00
0005434082388	30558	Economy	13600.00
0005432569060	30558	Economy	13600.00
0005432461034	30558	Economy	13600.00
0005432568858	30558	Economy	13600.00
0005432568603	30558	Economy	13600.00
0005432568883	30558	Economy	13600.00
0005432568898	30558	Economy	13600.00
0005432461025	30558	Economy	13600.00
0005432569110	30558	Economy	13600.00
0005432461008	30558	Economy	13600.00
0005432460739	30558	Economy	13600.00
0005432569062	30558	Economy	13600.00
0005432568763	30558	Economy	13600.00
0005432460904	30558	Economy	13600.00
0005432569021	30558	Economy	13600.00
0005434150187	30558	Economy	13600.00
0005433454905	30558	Economy	13600.00
0005432460816	30558	Economy	13600.00
0005432461184	30558	Economy	13600.00
0005432568993	30558	Economy	13600.00
0005432569112	30558	Economy	13600.00
0005432568951	30558	Economy	13600.00
0005432569070	30558	Economy	13600.00
0005432568897	30558	Economy	13600.00
0005435840513	30558	Economy	13600.00
0005432568684	30558	Economy	13600.00
0005432461110	30558	Economy	13600.00
0005432460892	30558	Economy	13600.00
0005432568843	30558	Economy	13600.00
0005432461014	30558	Economy	13600.00
0005432569065	30558	Economy	13600.00
0005434150186	30558	Economy	13600.00
0005434150195	30558	Economy	13600.00
0005432461156	30558	Economy	13600.00
0005432569001	30558	Economy	13600.00
0005435840520	30558	Economy	13600.00
0005434150198	30558	Economy	13600.00
0005432569074	30558	Economy	13600.00
0005432161216	30558	Economy	13600.00
0005432460954	30558	Economy	13600.00
0005432460902	30558	Economy	13600.00
0005434082370	30558	Economy	13600.00
0005434082386	30558	Economy	13600.00
0005432460903	30558	Economy	13600.00
0005432569109	30558	Economy	13600.00
0005432460937	30558	Economy	13600.00
0005435840515	30558	Economy	13600.00
0005432460776	30558	Economy	13600.00
0005434082502	30558	Economy	13600.00
0005435840509	30558	Economy	13600.00
0005432460977	30558	Economy	13600.00
0005434150184	30558	Economy	13600.00
0005432460893	30558	Economy	13600.00
0005432568788	30558	Economy	13600.00
0005432461013	30558	Economy	13600.00
0005432568882	30558	Economy	13600.00
0005432568945	30558	Economy	13600.00
0005433452785	30558	Economy	13600.00
0005434150193	30558	Economy	13600.00
0005435840510	30558	Economy	13600.00
0005434150203	30558	Economy	13600.00
0005432461157	30558	Economy	13600.00
0005435722121	13570	Economy	9900.00
0005435722122	13570	Economy	9900.00
0005435720155	21114	Economy	9900.00
0005435722106	21114	Economy	9900.00
0005435720157	21114	Economy	9900.00
0005435722107	21114	Economy	9900.00
0005435720154	21114	Economy	9900.00
0005433345964	11126	Business	23600.00
0005433345987	11126	Business	23600.00
0005435530070	11126	Business	23600.00
0005433345971	11126	Business	23600.00
0005433345997	11126	Business	23600.00
0005433345981	11126	Business	23600.00
0005433345979	11126	Business	23600.00
0005435508613	11126	Business	23600.00
0005433345975	11126	Business	23600.00
0005433345972	11126	Business	23600.00
0005435380393	11126	Economy	7900.00
0005435508685	11126	Economy	7900.00
0005433346005	11126	Economy	7900.00
0005433345973	11126	Economy	7900.00
0005433346000	11126	Economy	7900.00
0005433345959	11126	Economy	7900.00
0005433346004	11126	Economy	7900.00
0005435380373	11126	Economy	7900.00
0005435508664	11126	Economy	7900.00
0005435530053	11126	Economy	7900.00
0005433345992	11126	Economy	7900.00
0005435530055	11126	Economy	7900.00
0005435530075	11126	Economy	7900.00
0005433346002	11126	Economy	7900.00
0005433345977	11126	Economy	7900.00
0005433345974	11126	Economy	7900.00
0005433346008	11126	Economy	7900.00
0005433345985	11126	Economy	7900.00
0005433345969	11126	Economy	7900.00
0005435508612	11126	Economy	7900.00
0005435530013	11126	Economy	7900.00
0005435380408	11126	Economy	7900.00
0005433345995	11126	Economy	7900.00
0005433345996	11126	Economy	7900.00
0005435508624	11126	Economy	7900.00
0005433345976	11126	Economy	7900.00
0005435530025	11126	Economy	7900.00
0005433345990	11126	Economy	7900.00
0005433345968	11126	Economy	7900.00
0005435529981	11126	Economy	7900.00
0005435530003	11126	Economy	7900.00
0005435380411	11126	Economy	7900.00
0005433345970	11126	Economy	7900.00
0005435530022	11126	Economy	7900.00
0005435530026	11126	Economy	7900.00
0005435380407	11126	Economy	7900.00
0005433345998	11126	Economy	7900.00
0005433345991	11126	Economy	8600.00
0005435097487	11126	Economy	8600.00
0005435530024	11126	Economy	8600.00
0005435508562	11126	Economy	8600.00
0005435530011	11126	Economy	7900.00
0005435097488	11126	Economy	8600.00
0005435530000	11126	Economy	7900.00
0005435529979	11126	Economy	7900.00
0005433345966	11126	Economy	7900.00
0005435508710	11126	Economy	7900.00
0005435530057	11126	Economy	7900.00
0005435508684	11126	Economy	7900.00
0005433346007	11126	Economy	7900.00
0005433345986	11126	Economy	7900.00
0005435508599	11126	Economy	7900.00
0005435508611	11126	Economy	7900.00
0005435508610	11126	Economy	7900.00
0005435380410	11126	Economy	7900.00
0005433345989	11126	Economy	7900.00
0005435097489	11126	Economy	7900.00
0005433345980	11126	Economy	7900.00
0005433345994	11126	Economy	7900.00
0005433345961	11126	Economy	7900.00
0005435529980	11126	Economy	7900.00
0005433345988	11126	Economy	7900.00
0005433345984	11126	Economy	7900.00
0005435530074	11126	Economy	7900.00
0005435508666	11126	Economy	7900.00
0005435508602	11126	Economy	7900.00
0005435530020	11126	Economy	7900.00
0005435508678	11126	Economy	7900.00
0005435530071	11126	Economy	7900.00
0005433345983	11126	Economy	7900.00
0005433345967	11126	Economy	7900.00
0005435508615	11126	Economy	7900.00
0005435508608	11126	Economy	7900.00
0005435530012	11126	Economy	7900.00
0005435530027	11126	Economy	7900.00
0005433345963	11126	Economy	7900.00
0005433345978	11126	Economy	7900.00
0005435508665	11126	Economy	7900.00
0005433345982	11126	Economy	7900.00
0005435508563	11126	Economy	7900.00
0005435508692	11126	Economy	7900.00
0005433346003	11126	Economy	7900.00
0005435530076	11126	Economy	7900.00
0005433345999	11126	Economy	7900.00
0005435097490	11126	Economy	7900.00
0005435530052	11126	Economy	7900.00
0005433345965	11126	Economy	7900.00
0005433345993	11126	Economy	7900.00
0005433345960	11126	Economy	7900.00
0005435508660	11126	Economy	7900.00
0005435530077	11126	Economy	7900.00
0005435508672	11126	Economy	7900.00
0005435530068	11126	Economy	7900.00
0005435529982	11126	Economy	7900.00
0005435530004	11126	Economy	7900.00
0005433345962	11126	Economy	7900.00
0005435380404	11126	Economy	7900.00
0005433346006	11126	Economy	7900.00
0005433346001	11126	Economy	7900.00
0005435529974	11126	Economy	7900.00
0005433345178	17132	Business	23600.00
0005435097401	17132	Business	23600.00
0005433345326	17132	Business	23600.00
0005435545956	17132	Business	23600.00
0005435097405	17132	Business	23600.00
0005435545957	17132	Business	23600.00
0005433344945	17132	Business	23600.00
0005435545991	17132	Business	23600.00
0005433345427	17132	Business	23600.00
0005435545954	17132	Business	23600.00
0005433345404	17132	Business	23600.00
0005435545952	17132	Business	23600.00
0005435097400	17132	Economy	7900.00
0005435097412	17132	Economy	7900.00
0005433345479	17132	Economy	7900.00
0005435097408	17132	Economy	7900.00
0005435097406	17132	Economy	7900.00
0005433345327	17132	Economy	7900.00
0005433345234	17132	Economy	7900.00
0005433344931	17132	Economy	7900.00
0005433345289	17132	Economy	7900.00
0005433345241	17132	Economy	7900.00
0005433344939	17132	Economy	7900.00
0005433344882	17132	Economy	7900.00
0005433344746	17132	Economy	7900.00
0005433345128	17132	Economy	7900.00
0005433345176	17132	Economy	7900.00
0005433345179	17132	Economy	7900.00
0005435097391	17132	Economy	7900.00
0005433345442	17132	Economy	7900.00
0005435545955	17132	Economy	7900.00
0005433344795	17132	Economy	7900.00
0005433345530	17132	Economy	7900.00
0005433345046	17132	Economy	7900.00
0005433345099	17132	Economy	7900.00
0005433344973	17132	Economy	7900.00
0005433344833	17132	Economy	7900.00
0005435545990	17132	Economy	7900.00
0005433345122	17132	Economy	7900.00
0005433344930	17132	Economy	7900.00
0005433345119	17132	Economy	7900.00
0005433345216	17132	Economy	7900.00
0005433345032	17132	Economy	7900.00
0005433345126	17132	Economy	7900.00
0005433345281	17132	Economy	7900.00
0005435545988	17132	Economy	7900.00
0005433345629	17132	Economy	7900.00
0005433345345	17132	Economy	7900.00
0005433344748	17132	Economy	7900.00
0005433345013	17132	Economy	7900.00
0005432293278	17132	Economy	7900.00
0005433345448	17132	Economy	7900.00
0005433344832	17132	Economy	8600.00
0005433345433	17132	Economy	8600.00
0005433345325	17132	Economy	8600.00
0005433345243	17132	Economy	8600.00
0005433345120	17132	Economy	8600.00
0005433344723	17132	Economy	8600.00
0005433345240	17132	Economy	7900.00
0005435097392	17132	Economy	7900.00
0005433345123	17132	Economy	7900.00
0005433345350	17132	Economy	7900.00
0005433345440	17132	Economy	7900.00
0005433345195	17132	Economy	7900.00
0005433345125	17132	Economy	7900.00
0005433345351	17132	Economy	7900.00
0005433344881	17132	Economy	7900.00
0005433344940	17132	Economy	7900.00
0005433344994	17132	Economy	7900.00
0005433345233	17132	Economy	7900.00
0005433345229	17132	Economy	7900.00
0005433345129	17132	Economy	7900.00
0005433344436	17132	Economy	7900.00
0005435545989	17132	Economy	7900.00
0005433344932	17132	Economy	7900.00
0005433345434	17132	Economy	7900.00
0005433345102	17132	Economy	7900.00
0005433345076	17132	Economy	7900.00
0005433345035	17132	Economy	7900.00
0005435097422	17132	Economy	7900.00
0005433345391	17132	Economy	7900.00
0005433345403	17132	Economy	7900.00
0005433344953	17132	Economy	7900.00
0005435545953	17132	Economy	7900.00
0005433344987	17132	Economy	7900.00
0005433344434	17132	Economy	7900.00
0005433345071	17132	Economy	7900.00
0005433345091	17132	Economy	7900.00
0005433345088	17132	Economy	7900.00
0005433345194	17132	Economy	7900.00
0005433344929	17132	Economy	7900.00
0005433344959	17132	Economy	7900.00
0005433344747	17132	Economy	7900.00
0005433344598	17132	Economy	7900.00
0005433345401	17132	Economy	7900.00
0005433344778	17132	Economy	7900.00
0005433345084	17132	Economy	7900.00
0005433344850	17132	Economy	7900.00
0005433344722	17132	Economy	7900.00
0005433345478	17132	Economy	7900.00
0005433345432	17132	Economy	7900.00
0005433345583	17132	Economy	7900.00
0005435097432	17132	Economy	7900.00
0005433344435	17132	Economy	7900.00
0005433344993	17132	Economy	7900.00
0005433345321	17132	Economy	7900.00
0005435380440	17132	Economy	7900.00
0005435097410	17132	Economy	7900.00
0005433345239	17132	Economy	7900.00
0005433344597	17132	Economy	7900.00
0005433345428	17132	Economy	7900.00
0005433345305	17132	Economy	7900.00
0005433345175	17132	Economy	7900.00
0005433344745	17132	Economy	7900.00
0005433345582	17132	Economy	7900.00
0005433345215	17132	Economy	7900.00
0005433345352	17132	Economy	7900.00
0005433345177	17132	Economy	7900.00
0005433345400	17132	Economy	7900.00
0005433345158	17132	Economy	7900.00
0005433345036	17132	Economy	7900.00
0005435097402	17132	Economy	7900.00
0005433345417	17132	Economy	7900.00
0005433345121	17132	Economy	7900.00
0005433345282	17132	Economy	7900.00
0005433345237	17132	Economy	7900.00
0005433344779	17132	Economy	7900.00
0005435545958	17132	Economy	7900.00
0005433345290	17132	Economy	7900.00
0005433344995	17132	Economy	7900.00
0005433507708	9094	Business	26600.00
0005433507711	9094	Business	26600.00
0005433477269	9094	Business	26600.00
0005433477264	9094	Business	26600.00
0005433481384	9094	Business	26600.00
0005432920295	9094	Business	26600.00
0005432920200	9094	Business	26600.00
0005433477266	9094	Business	26600.00
0005432920290	9094	Business	26600.00
0005433477270	9094	Business	26600.00
0005433507704	9094	Business	26600.00
0005433477252	9094	Economy	8900.00
0005432920278	9094	Economy	8900.00
0005433477259	9094	Economy	8900.00
0005432920267	9094	Economy	8900.00
0005432920332	9094	Economy	8900.00
0005433477273	9094	Economy	8900.00
0005432920301	9094	Economy	8900.00
0005433507702	9094	Economy	8900.00
0005433507712	9094	Economy	9800.00
0005432920299	9094	Economy	9800.00
0005433477272	9094	Economy	9800.00
0005432920326	9094	Economy	8900.00
0005434159022	9094	Economy	8900.00
0005432920327	9094	Economy	8900.00
0005433477271	9094	Economy	8900.00
0005432920223	9094	Economy	8900.00
0005433477261	9094	Economy	8900.00
0005432920343	9094	Economy	8900.00
0005433477253	9094	Economy	8900.00
0005432920263	9094	Economy	8900.00
0005433477254	9094	Economy	8900.00
0005432920234	9094	Economy	8900.00
0005433477257	9094	Economy	8900.00
0005433477262	9094	Economy	8900.00
0005432920300	9094	Economy	8900.00
0005432920233	9094	Economy	8900.00
0005432920250	9094	Economy	8900.00
0005433507703	9094	Economy	8900.00
0005433507705	9094	Economy	8900.00
0005433507710	9094	Economy	8900.00
0005433477265	9094	Economy	8900.00
0005434159037	9094	Economy	8900.00
0005433481385	9094	Economy	8900.00
0005433481386	9094	Economy	8900.00
0005432920333	9094	Economy	8900.00
0005432920342	9094	Economy	8900.00
0005433477255	9094	Economy	8900.00
0005432920247	9094	Economy	8900.00
0005432920241	9094	Economy	8900.00
0005433477263	9094	Economy	8900.00
0005433477258	9094	Economy	8900.00
0005433477268	9094	Economy	8900.00
0005433507709	9094	Economy	8900.00
0005433507706	9094	Economy	8900.00
0005432920298	9094	Economy	8900.00
0005433477250	9094	Economy	8900.00
0005432920344	9094	Economy	8900.00
0005432920268	9094	Economy	8900.00
0005432920286	9094	Economy	8900.00
0005433477256	9094	Economy	8900.00
0005433507707	9094	Economy	8900.00
0005433477251	9094	Economy	8900.00
0005433477267	9094	Economy	8900.00
0005433477260	9094	Economy	8900.00
0005432920465	20466	Business	26600.00
0005433477042	20466	Business	26600.00
0005433477080	20466	Business	26600.00
0005433476962	20466	Business	26600.00
0005433476961	20466	Business	26600.00
0005433476958	20466	Business	26600.00
0005433477035	20466	Business	26600.00
0005433481334	20466	Business	26600.00
0005433507628	20466	Business	26600.00
0005433477072	20466	Business	26600.00
0005433507483	20466	Business	26600.00
0005433507482	20466	Business	26600.00
0005433477090	20466	Economy	8900.00
0005433476957	20466	Economy	8900.00
0005433477077	20466	Economy	8900.00
0005433507611	20466	Economy	8900.00
0005432920464	20466	Economy	8900.00
0005433476959	20466	Economy	8900.00
0005433476993	20466	Economy	8900.00
0005432920467	20466	Economy	8900.00
0005433477009	20466	Economy	8900.00
0005433507529	20466	Economy	8900.00
0005433477055	20466	Economy	9800.00
0005433477130	20466	Economy	9800.00
0005433476967	20466	Economy	9800.00
0005433477091	20466	Economy	9800.00
0005433507520	20466	Economy	9800.00
0005433507623	20466	Economy	8900.00
0005433477032	20466	Economy	8900.00
0005433507625	20466	Economy	8900.00
0005433477079	20466	Economy	8900.00
0005433476974	20466	Economy	8900.00
0005433507575	20466	Economy	8900.00
0005433476973	20466	Economy	8900.00
0005433481354	20466	Economy	8900.00
0005433477073	20466	Economy	8900.00
0005433507600	20466	Economy	8900.00
0005433507522	20466	Economy	8900.00
0005433507528	20466	Economy	8900.00
0005433477060	20466	Economy	8900.00
0005432920472	20466	Economy	8900.00
0005433481355	20466	Economy	8900.00
0005433477043	20466	Economy	8900.00
0005433477054	20466	Economy	8900.00
0005433481330	20466	Economy	8900.00
0005432920470	20466	Economy	8900.00
0005432920469	20466	Economy	8900.00
0005433477050	20466	Economy	8900.00
0005433507584	20466	Economy	8900.00
0005433507601	20466	Economy	8900.00
0005433507554	20466	Economy	8900.00
0005433507624	20466	Economy	8900.00
0005433477105	20466	Economy	8900.00
0005433507577	20466	Economy	8900.00
0005433477006	20466	Economy	8900.00
0005432920473	20466	Economy	8900.00
0005433507626	20466	Economy	8900.00
0005433477033	20466	Economy	8900.00
0005432920471	20466	Economy	8900.00
0005433507578	20466	Economy	8900.00
0005433481359	20466	Economy	8900.00
0005433477106	20466	Economy	8900.00
0005432920468	20466	Economy	8900.00
0005433507506	20466	Economy	8900.00
0005433476994	20466	Economy	8900.00
0005433477075	20466	Economy	8900.00
0005433477067	20466	Economy	8900.00
0005433476963	20466	Economy	8900.00
0005433477076	20466	Economy	8900.00
0005433476964	20466	Economy	8900.00
0005433477078	20466	Economy	8900.00
0005433476991	20466	Economy	8900.00
0005433477104	20466	Economy	8900.00
0005433507602	20466	Economy	8900.00
0005433476984	20466	Economy	8900.00
0005433476960	20466	Economy	8900.00
0005433507603	20466	Economy	8900.00
0005433481346	20466	Economy	8900.00
0005432920466	20466	Economy	8900.00
0005433477059	20466	Economy	8900.00
0005433507487	20466	Economy	8900.00
0005433477036	20466	Economy	8900.00
0005433507564	20466	Economy	8900.00
0005433481347	20466	Economy	8900.00
0005433477031	20466	Economy	8900.00
0005433507521	20466	Economy	8900.00
0005433477038	20466	Economy	8900.00
0005433477030	20466	Economy	8900.00
0005433477034	20466	Economy	8900.00
0005433477018	20466	Economy	8900.00
0005433476990	20466	Economy	8900.00
0005433477103	20466	Economy	8900.00
0005433481337	20466	Economy	8900.00
0005433477005	20466	Economy	8900.00
0005433476995	20466	Economy	8900.00
0005432396352	10140	Economy	5800.00
0005435179704	10140	Economy	5800.00
0005432396353	10140	Economy	5800.00
0005432400193	18302	Economy	5800.00
0005435179720	18302	Economy	5800.00
0005435179719	18302	Economy	5800.00
0005432396328	18302	Economy	5800.00
0005432400192	18302	Economy	5800.00
0005435556753	11053	Business	9500.00
0005435556740	11053	Business	9500.00
0005435127198	11053	Business	9500.00
0005435554311	11053	Business	9500.00
0005435127195	11053	Business	9500.00
0005435626523	11053	Business	9500.00
0005435127227	11053	Business	9500.00
0005435127211	11053	Business	9500.00
0005435626548	11053	Business	9500.00
0005435127197	11053	Economy	3200.00
0005435127009	11053	Economy	3200.00
0005435554287	11053	Economy	3200.00
0005435626516	11053	Economy	3200.00
0005435127350	11053	Economy	3200.00
0005435554284	11053	Economy	3200.00
0005435554285	11053	Economy	3200.00
0005435554310	11053	Economy	3500.00
0005435127026	11053	Economy	3500.00
0005435554289	11053	Economy	3500.00
0005435626551	11053	Economy	3500.00
0005435127077	11053	Economy	3200.00
0005435127223	11053	Economy	3200.00
0005435127130	11053	Economy	3200.00
0005435127283	11053	Economy	3200.00
0005435127252	11053	Economy	3200.00
0005435127146	11053	Economy	3200.00
0005435554286	11053	Economy	3200.00
0005435127110	11053	Economy	3200.00
0005435127193	11053	Economy	3200.00
0005435127100	11053	Economy	3200.00
0005435556739	11053	Economy	3200.00
0005435626543	11053	Economy	3200.00
0005434411899	11053	Economy	3200.00
0005434411898	11053	Economy	3200.00
0005435626498	11053	Economy	3200.00
0005435127201	11053	Economy	3200.00
0005435626554	11053	Economy	3200.00
0005435127296	11053	Economy	3200.00
0005435127242	11053	Economy	3200.00
0005435127147	11053	Economy	3200.00
0005435126969	11053	Economy	3200.00
0005435556750	11053	Economy	3200.00
0005435127090	11053	Economy	3200.00
0005435127282	11053	Economy	3200.00
0005435127144	11053	Economy	3200.00
0005435127273	11053	Economy	3200.00
0005435554283	11053	Economy	3200.00
0005435127194	11053	Economy	3200.00
0005435556751	11053	Economy	3200.00
0005435127329	11053	Economy	3200.00
0005435127135	11053	Economy	3200.00
0005435127145	11053	Economy	3200.00
0005435556752	11053	Economy	3200.00
0005435554288	11053	Economy	3200.00
0005435126970	11053	Economy	3200.00
0005435626473	11053	Economy	3200.00
0005435626550	11053	Economy	3200.00
0005435626537	11053	Economy	3200.00
0005434928380	11053	Economy	3200.00
0005435127101	11053	Economy	3200.00
0005435127303	11053	Economy	3200.00
0005435127111	11053	Economy	3200.00
0005435127208	11053	Economy	3200.00
0005435127257	11053	Economy	3200.00
0005434411897	11053	Economy	3200.00
0005435127156	11053	Economy	3200.00
0005435127183	11053	Economy	3200.00
0005435127224	11053	Economy	3200.00
0005435127225	11053	Economy	3200.00
0005435127106	11053	Economy	3200.00
0005435626530	11053	Economy	3200.00
0005435127349	11053	Economy	3200.00
0005435626549	11053	Economy	3200.00
0005435127151	11053	Economy	3200.00
0005435626515	11053	Economy	3200.00
0005435626775	14730	Business	9500.00
0005435127534	14730	Business	9500.00
0005435626768	14730	Business	9500.00
0005435626769	14730	Business	9500.00
0005435127549	14730	Business	9500.00
0005435626778	14730	Business	9500.00
0005435127547	14730	Business	9500.00
0005435554320	14730	Business	9500.00
0005435127551	14730	Business	9500.00
0005435626779	14730	Business	9500.00
0005435626796	14730	Business	9500.00
0005435626802	14730	Business	9500.00
0005435127550	14730	Economy	3200.00
0005435626811	14730	Economy	3200.00
0005435626790	14730	Economy	3200.00
0005434928362	14730	Economy	3200.00
0005435127543	14730	Economy	3200.00
0005435626782	14730	Economy	3200.00
0005435127544	14730	Economy	3200.00
0005434411867	14730	Economy	3200.00
0005435127529	14730	Economy	3200.00
0005435626800	14730	Economy	3200.00
0005435626780	14730	Economy	3500.00
0005435626784	14730	Economy	3500.00
0005435127528	14730	Economy	3500.00
0005435556764	14730	Economy	3500.00
0005435626810	14730	Economy	3500.00
0005435626805	14730	Economy	3200.00
0005435626813	14730	Economy	3200.00
0005435626815	14730	Economy	3200.00
0005435626795	14730	Economy	3200.00
0005435127525	14730	Economy	3200.00
0005435626814	14730	Economy	3200.00
0005435554321	14730	Economy	3200.00
0005435626770	14730	Economy	3200.00
0005435626801	14730	Economy	3200.00
0005435127532	14730	Economy	3200.00
0005435626797	14730	Economy	3200.00
0005435127546	14730	Economy	3200.00
0005435626789	14730	Economy	3200.00
0005435626799	14730	Economy	3200.00
0005434411871	14730	Economy	3200.00
0005435626774	14730	Economy	3200.00
0005435127548	14730	Economy	3200.00
0005435626776	14730	Economy	3200.00
0005434411866	14730	Economy	3200.00
0005435626793	14730	Economy	3200.00
0005434928363	14730	Economy	3200.00
0005435626804	14730	Economy	3200.00
0005435127537	14730	Economy	3200.00
0005435127531	14730	Economy	3200.00
0005435626777	14730	Economy	3200.00
0005435626798	14730	Economy	3200.00
0005435626786	14730	Economy	3200.00
0005435626812	14730	Economy	3200.00
0005435626807	14730	Economy	3200.00
0005435626773	14730	Economy	3200.00
0005435626783	14730	Economy	3200.00
0005435626788	14730	Economy	3200.00
0005434411860	14730	Economy	3200.00
0005435626785	14730	Economy	3200.00
0005435626806	14730	Economy	3200.00
0005435554323	14730	Economy	3200.00
0005435626787	14730	Economy	3200.00
0005435554322	14730	Economy	3200.00
0005434928371	14730	Economy	3200.00
0005435127530	14730	Economy	3200.00
0005435127535	14730	Economy	3200.00
0005435127527	14730	Economy	3200.00
0005435626808	14730	Economy	3200.00
0005435127541	14730	Economy	3200.00
0005435127533	14730	Economy	3200.00
0005435626771	14730	Economy	3200.00
0005435626794	14730	Economy	3200.00
0005435127540	14730	Economy	3200.00
0005435127536	14730	Economy	3200.00
0005435626791	14730	Economy	3200.00
0005435127538	14730	Economy	3200.00
0005434411861	14730	Economy	3200.00
0005434411865	14730	Economy	3200.00
0005435127542	14730	Economy	3200.00
0005435626803	14730	Economy	3200.00
0005435127526	14730	Economy	3200.00
0005435556765	14730	Economy	3200.00
0005435626772	14730	Economy	3200.00
0005435626781	14730	Economy	3200.00
0005435626816	14730	Economy	3200.00
0005435127524	14730	Economy	3200.00
0005435626817	14730	Economy	3200.00
0005435626792	14730	Economy	3200.00
0005435127545	14730	Economy	3200.00
0005435626809	14730	Economy	3200.00
0005435127539	14730	Economy	3200.00
0005435219241	7133	Business	86900.00
0005435715960	7133	Business	86900.00
0005432398300	7133	Business	86900.00
0005435715959	7133	Business	86900.00
0005435443503	7133	Business	86900.00
0005435179412	7133	Economy	31900.00
0005435715956	7133	Economy	29000.00
0005435715963	7133	Economy	29000.00
0005435443514	7133	Economy	29000.00
0005435443497	7133	Economy	29000.00
0005435216623	7133	Economy	29000.00
0005435443556	7133	Economy	29000.00
0005435219246	7133	Economy	29000.00
0005435443527	7133	Economy	29000.00
0005435715957	7133	Economy	29000.00
0005435219242	7133	Economy	29000.00
0005435216621	7133	Economy	29000.00
0005435179414	7133	Economy	29000.00
0005435178527	7133	Economy	29000.00
0005435443554	7133	Economy	29000.00
0005435715965	7133	Economy	29000.00
0005435443502	7133	Economy	29000.00
0005435443493	7133	Economy	29000.00
0005432398301	7133	Economy	29000.00
0005435216622	7133	Economy	29000.00
0005435715958	7133	Economy	29000.00
0005435715962	7133	Economy	29000.00
0005435715964	7133	Economy	29000.00
0005435219243	7133	Economy	29000.00
0005435443513	7133	Economy	29000.00
0005435443555	7133	Economy	29000.00
0005435715961	7133	Economy	29000.00
0005435216652	27102	Business	86900.00
0005435217771	27102	Business	86900.00
0005435217770	27102	Business	86900.00
0005435715771	27102	Business	86900.00
0005435216650	27102	Business	86900.00
0005435715768	27102	Business	86900.00
0005432394201	27102	Business	86900.00
0005435715831	27102	Economy	29000.00
0005435218144	27102	Economy	29000.00
0005435217773	27102	Economy	29000.00
0005435715779	27102	Economy	29000.00
0005435715809	27102	Economy	31900.00
0005435715844	27102	Economy	29000.00
0005435216648	27102	Economy	29000.00
0005435715865	27102	Economy	29000.00
0005435715813	27102	Economy	29000.00
0005435443581	27102	Economy	29000.00
0005435715875	27102	Economy	29000.00
0005432398271	27102	Economy	29000.00
0005435218145	27102	Economy	29000.00
0005432394184	27102	Economy	29000.00
0005435715866	27102	Economy	29000.00
0005432398261	27102	Economy	29000.00
0005435715821	27102	Economy	29000.00
0005435216646	27102	Economy	29000.00
0005435217772	27102	Economy	29000.00
0005435218143	27102	Economy	29000.00
0005432398278	27102	Economy	29000.00
0005435715814	27102	Economy	29000.00
0005435216647	27102	Economy	29000.00
0005435715741	27102	Economy	29000.00
0005435715873	27102	Economy	29000.00
0005432394193	27102	Economy	29000.00
0005432394200	27102	Economy	29000.00
0005432394198	27102	Economy	29000.00
0005435218142	27102	Economy	29000.00
0005435715885	27102	Economy	29000.00
0005435715762	27102	Economy	29000.00
0005435216649	27102	Economy	29000.00
0005432394183	27102	Economy	29000.00
0005435715886	27102	Economy	29000.00
0005435715855	27102	Economy	29000.00
0005435715874	27102	Economy	29000.00
0005435715823	27102	Economy	29000.00
0005435216651	27102	Economy	29000.00
0005435715767	27102	Economy	29000.00
0005435715824	27102	Economy	29000.00
0005435216645	27102	Economy	29000.00
0005435715808	27102	Economy	29000.00
0005432394199	27102	Economy	29000.00
0005435715788	27102	Economy	29000.00
0005435715845	27102	Economy	29000.00
0005435715858	27102	Economy	29000.00
0005432394166	27102	Economy	29000.00
0005435715884	27102	Economy	29000.00
0005435715832	27102	Economy	29000.00
0005432398262	27102	Economy	29000.00
0005434085062	2755	Economy	7700.00
0005434085063	2755	Economy	7700.00
0005434085011	28508	Economy	7700.00
0005434085024	28508	Economy	7700.00
0005434085027	28508	Economy	7700.00
0005434085022	28508	Economy	7700.00
0005434085025	28508	Economy	7700.00
0005433060490	28508	Economy	7700.00
0005433788327	11175	Economy	27100.00
0005433788324	11175	Economy	24600.00
0005433788326	11175	Economy	24600.00
0005433788323	11175	Economy	24600.00
0005435548547	11175	Economy	24600.00
0005433788329	11175	Economy	24600.00
0005435548602	11175	Economy	24600.00
0005435548566	11175	Economy	24600.00
0005435548597	11175	Economy	24600.00
0005435548594	11175	Economy	24600.00
0005433788325	11175	Economy	24600.00
0005435548596	11175	Economy	24600.00
0005435548585	11175	Economy	24600.00
0005433788330	11175	Economy	24600.00
0005435548598	11175	Economy	24600.00
0005435548559	11175	Economy	24600.00
0005433788321	11175	Economy	24600.00
0005433788328	11175	Economy	24600.00
0005435548599	11175	Economy	24600.00
0005435548560	11175	Economy	24600.00
0005435548548	11175	Economy	24600.00
0005435548579	11175	Economy	24600.00
0005435548578	11175	Economy	24600.00
0005435548590	11175	Economy	24600.00
0005433788322	11175	Economy	24600.00
0005433788269	20667	Economy	27100.00
0005433788288	20667	Economy	27100.00
0005435548615	20667	Economy	27100.00
0005435548617	20667	Economy	27100.00
0005435548614	20667	Economy	24600.00
0005435548612	20667	Economy	24600.00
0005433788271	20667	Economy	24600.00
0005433788274	20667	Economy	24600.00
0005433788292	20667	Economy	24600.00
0005435548613	20667	Economy	24600.00
0005433788273	20667	Economy	24600.00
0005435548622	20667	Economy	24600.00
0005433788272	20667	Economy	24600.00
0005433788279	20667	Economy	24600.00
0005433788286	20667	Economy	24600.00
0005433788287	20667	Economy	24600.00
0005433788257	20667	Economy	24600.00
0005435548618	20667	Economy	24600.00
0005433788291	20667	Economy	24600.00
0005433788282	20667	Economy	24600.00
0005433788293	20667	Economy	24600.00
0005433788276	20667	Economy	24600.00
0005433788270	20667	Economy	24600.00
0005433788275	20667	Economy	24600.00
0005435548623	20667	Economy	24600.00
0005433788283	20667	Economy	24600.00
0005433788264	20667	Economy	24600.00
0005433788281	20667	Economy	24600.00
0005433788266	20667	Economy	24600.00
0005435548624	20667	Economy	24600.00
0005433788268	20667	Economy	24600.00
0005433788265	20667	Economy	24600.00
0005435548616	20667	Economy	24600.00
0005433788267	20667	Economy	24600.00
0005435548619	20667	Economy	24600.00
0005435548620	20667	Economy	24600.00
0005433788280	20667	Economy	24600.00
0005435548621	20667	Economy	24600.00
0005433788277	20667	Economy	24600.00
0005433788278	20667	Economy	24600.00
0005435541473	11418	Business	20200.00
0005435518316	11418	Business	20200.00
0005435518314	11418	Business	20200.00
0005435541428	11418	Business	20200.00
0005435541413	11418	Economy	6700.00
0005435518318	11418	Economy	6700.00
0005435518270	11418	Economy	6700.00
0005435518307	11418	Economy	6700.00
0005435541477	11418	Economy	6700.00
0005435518247	11418	Economy	7400.00
0005435518272	11418	Economy	7400.00
0005435518344	11418	Economy	7400.00
0005435518317	11418	Economy	6700.00
0005435541364	11418	Economy	6700.00
0005435518274	11418	Economy	6700.00
0005435518288	11418	Economy	6700.00
0005435541483	11418	Economy	6700.00
0005435518306	11418	Economy	6700.00
0005435518257	11418	Economy	6700.00
0005435541504	11418	Economy	6700.00
0005435541542	11418	Economy	6700.00
0005435518285	11418	Economy	6700.00
0005435518289	11418	Economy	6700.00
0005435518281	11418	Economy	6700.00
0005435541481	11418	Economy	6700.00
0005435541496	11418	Economy	6700.00
0005435541480	11418	Economy	6700.00
0005435518246	11418	Economy	6700.00
0005435518300	11418	Economy	6700.00
0005435541489	11418	Economy	6700.00
0005435541450	11418	Economy	6700.00
0005435541465	11418	Economy	6700.00
0005435518273	11418	Economy	6700.00
0005435541474	11418	Economy	6700.00
0005435541429	11418	Economy	6700.00
0005435518271	11418	Economy	6700.00
0005435529873	22252	Business	20200.00
0005435541615	22252	Business	20200.00
0005435530161	22252	Business	20200.00
0005435529863	22252	Business	20200.00
0005435529862	22252	Business	20200.00
0005435541606	22252	Economy	6700.00
0005435530162	22252	Economy	6700.00
0005435530170	22252	Economy	6700.00
0005435541621	22252	Economy	6700.00
0005435541614	22252	Economy	7400.00
0005435541609	22252	Economy	7400.00
0005435541616	22252	Economy	6700.00
0005435541610	22252	Economy	6700.00
0005435529866	22252	Economy	6700.00
0005435541619	22252	Economy	6700.00
0005435530168	22252	Economy	6700.00
0005435530159	22252	Economy	6700.00
0005435530171	22252	Economy	6700.00
0005435529871	22252	Economy	6700.00
0005435541607	22252	Economy	6700.00
0005435530169	22252	Economy	6700.00
0005435529865	22252	Economy	6700.00
0005435541613	22252	Economy	6700.00
0005435529868	22252	Economy	6700.00
0005435541617	22252	Economy	6700.00
0005435530167	22252	Economy	6700.00
0005435541620	22252	Economy	6700.00
0005435529874	22252	Economy	6700.00
0005435529867	22252	Economy	6700.00
0005435541608	22252	Economy	6700.00
0005435541618	22252	Economy	6700.00
0005435529872	22252	Economy	6700.00
0005435529870	22252	Economy	6700.00
0005435530164	22252	Economy	6700.00
0005435530160	22252	Economy	6700.00
0005435530163	22252	Economy	6700.00
0005435541611	22252	Economy	6700.00
0005435541612	22252	Economy	6700.00
0005435530166	22252	Economy	6700.00
0005435529875	22252	Economy	6700.00
0005435530157	22252	Economy	6700.00
0005435530165	22252	Economy	6700.00
0005435529869	22252	Economy	6700.00
0005435530158	22252	Economy	6700.00
0005435529864	22252	Economy	6700.00
0005435530172	22252	Economy	6700.00
0005433252029	2271	Business	20200.00
0005433252290	2271	Business	20200.00
0005434908823	2271	Business	20200.00
0005435787469	2271	Business	20200.00
0005434908843	2271	Business	20200.00
0005434908849	2271	Business	20200.00
0005433252241	2271	Business	20200.00
0005435787470	2271	Business	20200.00
0005434908829	2271	Business	20200.00
0005433252064	2271	Economy	6700.00
0005434908834	2271	Economy	6700.00
0005434908837	2271	Economy	6700.00
0005434908832	2271	Economy	6700.00
0005433252177	2271	Economy	6700.00
0005434908847	2271	Economy	6700.00
0005433252079	2271	Economy	6700.00
0005433252200	2271	Economy	7400.00
0005434908838	2271	Economy	7400.00
0005433401057	2271	Economy	7400.00
0005434908846	2271	Economy	7400.00
0005434908831	2271	Economy	6700.00
0005434908844	2271	Economy	6700.00
0005433401044	2271	Economy	6700.00
0005433252289	2271	Economy	6700.00
0005434908836	2271	Economy	6700.00
0005433252141	2271	Economy	6700.00
0005433252065	2271	Economy	6700.00
0005433252178	2271	Economy	6700.00
0005434908841	2271	Economy	6700.00
0005433252170	2271	Economy	6700.00
0005434908851	2271	Economy	6700.00
0005433252140	2271	Economy	6700.00
0005434908828	2271	Economy	6700.00
0005433252008	2271	Economy	6700.00
0005434908820	2271	Economy	6700.00
0005434908839	2271	Economy	6700.00
0005433252119	2271	Economy	6700.00
0005433251991	2271	Economy	6700.00
0005434908845	2271	Economy	6700.00
0005434908853	2271	Economy	6700.00
0005434908848	2271	Economy	6700.00
0005433252304	2271	Economy	6700.00
0005433251982	2271	Economy	6700.00
0005434908830	2271	Economy	6700.00
0005433252164	2271	Economy	6700.00
0005433252027	2271	Economy	6700.00
0005434908827	2271	Economy	6700.00
0005434908824	2271	Economy	6700.00
0005433401051	2271	Economy	6700.00
0005434908822	2271	Economy	6700.00
0005434908833	2271	Economy	6700.00
0005434908840	2271	Economy	6700.00
0005433401050	2271	Economy	6700.00
0005434908825	2271	Economy	6700.00
0005433252190	2271	Economy	6700.00
0005434908821	2271	Economy	6700.00
0005434908850	2271	Economy	6700.00
0005433252022	2271	Economy	6700.00
0005434908852	2271	Economy	6700.00
0005434908842	2271	Economy	6700.00
0005434908854	2271	Economy	6700.00
0005433252199	2271	Economy	6700.00
0005434908835	2271	Economy	6700.00
0005434908826	2271	Economy	6700.00
0005433252345	25602	Business	20200.00
0005434908352	25602	Business	20200.00
0005434908390	25602	Business	20200.00
0005433252354	25602	Business	20200.00
0005433252352	25602	Business	20200.00
0005434908496	25602	Business	20200.00
0005433401070	25602	Business	20200.00
0005434908276	25602	Business	20200.00
0005433252353	25602	Economy	6700.00
0005433252350	25602	Economy	6700.00
0005434908340	25602	Economy	6700.00
0005434908383	25602	Economy	6700.00
0005433252347	25602	Economy	6700.00
0005434908302	25602	Economy	6700.00
0005434908440	25602	Economy	6700.00
0005434908596	25602	Economy	7400.00
0005433252357	25602	Economy	7400.00
0005434908343	25602	Economy	7400.00
0005434908382	25602	Economy	6700.00
0005434908410	25602	Economy	6700.00
0005434908399	25602	Economy	6700.00
0005433252355	25602	Economy	6700.00
0005434908381	25602	Economy	6700.00
0005434908247	25602	Economy	6700.00
0005434908501	25602	Economy	6700.00
0005434908238	25602	Economy	6700.00
0005434908402	25602	Economy	6700.00
0005434908389	25602	Economy	6700.00
0005433252358	25602	Economy	6700.00
0005434908296	25602	Economy	6700.00
0005433252351	25602	Economy	6700.00
0005434908467	25602	Economy	6700.00
0005434908396	25602	Economy	6700.00
0005434908506	25602	Economy	6700.00
0005433252348	25602	Economy	6700.00
0005434908505	25602	Economy	6700.00
0005433252356	25602	Economy	6700.00
0005434908304	25602	Economy	6700.00
0005434908237	25602	Economy	6700.00
0005434908303	25602	Economy	6700.00
0005434908249	25602	Economy	6700.00
0005434908192	25602	Economy	6700.00
0005434908545	25602	Economy	6700.00
0005434908105	25602	Economy	6700.00
0005434908325	25602	Economy	6700.00
0005434908301	25602	Economy	6700.00
0005434908603	25602	Economy	6700.00
0005434908220	25602	Economy	6700.00
0005435787458	25602	Economy	6700.00
0005434908497	25602	Economy	6700.00
0005434908428	25602	Economy	6700.00
0005434908248	25602	Economy	6700.00
0005434908239	25602	Economy	6700.00
0005434908498	25602	Economy	6700.00
0005433252346	25602	Economy	6700.00
0005434908350	25602	Economy	6700.00
0005434908446	25602	Economy	6700.00
0005433252359	25602	Economy	6700.00
0005434908299	25602	Economy	6700.00
0005434908351	25602	Economy	6700.00
0005434908191	25602	Economy	6700.00
0005434908463	25602	Economy	6700.00
0005434908544	25602	Economy	6700.00
0005434908400	25602	Economy	6700.00
0005434908477	25602	Economy	6700.00
0005434908297	25602	Economy	6700.00
0005435787459	25602	Economy	6700.00
0005434908119	25602	Economy	6700.00
0005433252349	25602	Economy	6700.00
0005435787457	25602	Economy	6700.00
0005432862517	2528	Economy	13600.00
0005432862495	2528	Economy	13600.00
0005432862494	2528	Economy	13600.00
0005432862486	2528	Economy	13600.00
0005432862484	2528	Economy	12400.00
0005432862485	2528	Economy	12400.00
0005432621442	2528	Economy	12400.00
0005432862466	2528	Economy	12400.00
0005432621443	2528	Economy	12400.00
0005432621444	2528	Economy	12400.00
0005432621445	2528	Economy	12400.00
0005432862518	2528	Economy	12400.00
0005432621446	2528	Economy	12400.00
0005432862475	2528	Economy	12400.00
0005432621341	28052	Economy	13600.00
0005432621328	28052	Economy	13600.00
0005432621362	28052	Economy	12400.00
0005432621363	28052	Economy	12400.00
0005432862521	28052	Economy	12400.00
0005432621270	28052	Economy	12400.00
0005432621324	28052	Economy	12400.00
0005432621361	28052	Economy	12400.00
0005432621318	28052	Economy	12400.00
0005432621298	28052	Economy	12400.00
0005432621292	28052	Economy	12400.00
0005432621299	28052	Economy	12400.00
0005432621388	28052	Economy	12400.00
0005432621323	28052	Economy	12400.00
0005432621327	28052	Economy	12400.00
0005434097499	11733	Economy	11300.00
0005432433839	11733	Economy	11300.00
0005434097498	11733	Economy	11300.00
0005432433840	11733	Economy	11300.00
0005434097514	13013	Economy	11300.00
0005434097513	13013	Economy	11300.00
0005433452795	30976	Economy	8400.00
0005433452785	31368	Economy	8400.00
0005433452784	31368	Economy	8400.00
0005433452783	31368	Economy	8400.00
0005433452782	31368	Economy	8400.00
0005433454905	31368	Economy	8400.00
0005434326019	12001	Economy	7200.00
0005434326012	12001	Economy	7200.00
0005434326017	12001	Economy	6600.00
0005434326023	12001	Economy	6600.00
0005433134239	12001	Economy	6600.00
0005434326015	12001	Economy	6600.00
0005433129370	12001	Economy	6600.00
0005434326061	12001	Economy	6600.00
0005433129389	12001	Economy	6600.00
0005433134236	12001	Economy	6600.00
0005434142702	12001	Economy	6600.00
0005434326024	12001	Economy	6600.00
0005434326018	12001	Economy	6600.00
0005434326013	12001	Economy	6600.00
0005434142699	12001	Economy	6600.00
0005434326020	12001	Economy	6600.00
0005434326022	12001	Economy	6600.00
0005433134235	12001	Economy	6600.00
0005434142679	12001	Economy	6600.00
0005435551771	12001	Economy	6600.00
0005434326021	12001	Economy	6600.00
0005434326016	12001	Economy	6600.00
0005434184699	12001	Economy	6600.00
0005433129390	12001	Economy	6600.00
0005434326060	12001	Economy	6600.00
0005434326014	12001	Economy	6600.00
0005434142703	12001	Economy	6600.00
0005434326283	29856	Economy	7200.00
0005433134261	29856	Economy	7200.00
0005434184725	29856	Economy	6600.00
0005434142724	29856	Economy	6600.00
0005434326282	29856	Economy	6600.00
0005433134262	29856	Economy	6600.00
0005434183638	29856	Economy	6600.00
0005433131836	29856	Economy	6600.00
0005434326280	29856	Economy	6600.00
0005434183639	29856	Economy	6600.00
0005433131837	29856	Economy	6600.00
0005434142725	29856	Economy	6600.00
0005434142723	29856	Economy	6600.00
0005433131838	29856	Economy	6600.00
0005434142726	29856	Economy	6600.00
0005435698138	16464	Economy	19900.00
0005435698133	16464	Economy	19900.00
0005435698135	16464	Economy	19900.00
0005435698130	16464	Economy	18100.00
0005435698127	16464	Economy	18100.00
0005435698132	16464	Economy	18100.00
0005435698134	16464	Economy	18100.00
0005435698139	16464	Economy	18100.00
0005435698131	16464	Economy	18100.00
0005435698136	16464	Economy	18100.00
0005435698137	16464	Economy	18100.00
0005435698128	16464	Economy	18100.00
0005435698126	16464	Economy	18100.00
0005435698129	16464	Economy	18100.00
0005435697867	24708	Economy	19900.00
0005435697932	24708	Economy	19900.00
0005435697998	24708	Economy	19900.00
0005435697949	24708	Economy	19900.00
0005435698031	24708	Economy	18100.00
0005435697960	24708	Economy	18100.00
0005435697826	24708	Economy	18100.00
0005435697922	24708	Economy	18100.00
0005435697918	24708	Economy	18100.00
0005435697971	24708	Economy	18100.00
0005435935134	24708	Economy	18100.00
0005435697975	24708	Economy	18100.00
0005435697941	24708	Economy	18100.00
0005435697822	24708	Economy	18100.00
0005435697895	24708	Economy	18100.00
0005435697970	24708	Economy	18100.00
0005435933585	24708	Economy	18100.00
0005435697984	24708	Economy	18100.00
0005435697935	24708	Economy	18100.00
0005435697961	24708	Economy	18100.00
0005435697962	24708	Economy	18100.00
0005435697820	24708	Economy	18100.00
0005435697821	24708	Economy	18100.00
0005435697942	24708	Economy	18100.00
0005435697921	24708	Economy	18100.00
0005435697943	24708	Economy	18100.00
0005435698032	24708	Economy	18100.00
0005435698015	24708	Economy	18100.00
0005435697950	24708	Economy	18100.00
0005435697896	24708	Economy	18100.00
0005435697914	24708	Economy	18100.00
0005435698016	24708	Economy	18100.00
0005435933586	24708	Economy	18100.00
0005435697959	24708	Economy	18100.00
0005433724932	18779	Economy	4400.00
0005432968889	18779	Economy	4400.00
0005433724933	18779	Economy	4400.00
0005433724934	18779	Economy	4400.00
0005433724935	18779	Economy	4400.00
0005432968887	18779	Economy	4400.00
0005432968888	18779	Economy	4400.00
0005432968886	18779	Economy	4400.00
0005433724916	21602	Economy	4400.00
0005433724915	21602	Economy	4400.00
0005433724917	21602	Economy	4400.00
0005432968908	21602	Economy	4400.00
0005432968909	21602	Economy	4400.00
0005434140533	7344	Business	23100.00
0005435283558	7344	Business	23100.00
0005434140530	7344	Business	23100.00
0005434140539	7344	Business	23100.00
0005434140538	7344	Business	23100.00
0005434140521	7344	Business	23100.00
0005434140531	7344	Business	23100.00
0005434140522	7344	Business	23100.00
0005434140503	7344	Economy	7700.00
0005434140524	7344	Economy	7700.00
0005434087653	7344	Economy	7700.00
0005434087652	7344	Economy	7700.00
0005434140544	7344	Economy	7700.00
0005434140529	7344	Economy	7700.00
0005434140540	7344	Economy	8500.00
0005434087654	7344	Economy	7700.00
0005434140549	7344	Economy	7700.00
0005434140545	7344	Economy	7700.00
0005434087651	7344	Economy	7700.00
0005434140523	7344	Economy	7700.00
0005434140526	7344	Economy	7700.00
0005434140542	7344	Economy	7700.00
0005434140504	7344	Economy	7700.00
0005434140546	7344	Economy	7700.00
0005434140501	7344	Economy	7700.00
0005434140502	7344	Economy	7700.00
0005434087655	7344	Economy	7700.00
0005434140511	7344	Economy	7700.00
0005434140543	7344	Economy	7700.00
0005434140527	7344	Economy	7700.00
0005434140509	7344	Economy	7700.00
0005434140520	7344	Economy	7700.00
0005434140507	7344	Economy	7700.00
0005434140506	7344	Economy	7700.00
0005434140518	7344	Economy	7700.00
0005434140547	7344	Economy	7700.00
0005434140535	7344	Economy	7700.00
0005434140528	7344	Economy	7700.00
0005434140513	7344	Economy	7700.00
0005434140541	7344	Economy	7700.00
0005434140510	7344	Economy	7700.00
0005434140517	7344	Economy	7700.00
0005434140512	7344	Economy	7700.00
0005434140519	7344	Economy	7700.00
0005434140525	7344	Economy	7700.00
0005434140548	7344	Economy	7700.00
0005434140514	7344	Economy	7700.00
0005434140537	7344	Economy	7700.00
0005434140536	7344	Economy	7700.00
0005434140515	7344	Economy	7700.00
0005434140534	7344	Economy	7700.00
0005434140532	7344	Economy	7700.00
0005434140505	7344	Economy	7700.00
0005434140508	7344	Economy	7700.00
0005434140516	7344	Economy	7700.00
0005434139815	28566	Business	23100.00
0005434139536	28566	Business	23100.00
0005434139729	28566	Business	23100.00
0005434139503	28566	Business	23100.00
0005434139850	28566	Business	23100.00
0005434139875	28566	Business	23100.00
0005434139640	28566	Business	23100.00
0005434139981	28566	Business	23100.00
0005434139811	28566	Business	23100.00
0005434140041	28566	Business	23100.00
0005434139976	28566	Business	23100.00
0005434139977	28566	Business	23100.00
0005434139898	28566	Economy	7700.00
0005434139570	28566	Economy	7700.00
0005434139786	28566	Economy	7700.00
0005434139690	28566	Economy	7700.00
0005434139887	28566	Economy	7700.00
0005434139554	28566	Economy	7700.00
0005434139826	28566	Economy	7700.00
0005434139943	28566	Economy	7700.00
0005434139827	28566	Economy	7700.00
0005434139368	28566	Economy	7700.00
0005434139867	28566	Economy	8500.00
0005434139476	28566	Economy	8500.00
0005434140001	28566	Economy	8500.00
0005434139755	28566	Economy	8500.00
0005434139747	28566	Economy	8500.00
0005434139903	28566	Economy	7700.00
0005434139812	28566	Economy	7700.00
0005434139728	28566	Economy	7700.00
0005434139369	28566	Economy	7700.00
0005434139857	28566	Economy	7700.00
0005434139866	28566	Economy	7700.00
0005434139571	28566	Economy	7700.00
0005434139794	28566	Economy	7700.00
0005434139734	28566	Economy	7700.00
0005434139795	28566	Economy	7700.00
0005434139925	28566	Economy	7700.00
0005434139942	28566	Economy	7700.00
0005434139885	28566	Economy	7700.00
0005434139987	28566	Economy	7700.00
0005434139782	28566	Economy	7700.00
0005434139714	28566	Economy	7700.00
0005434139612	28566	Economy	7700.00
0005434139823	28566	Economy	7700.00
0005434139824	28566	Economy	7700.00
0005434139858	28566	Economy	7700.00
0005434139813	28566	Economy	7700.00
0005434139766	28566	Economy	7700.00
0005434139626	28566	Economy	7700.00
0005434139638	28566	Economy	7700.00
0005434139639	28566	Economy	7700.00
0005434139680	28566	Economy	7700.00
0005434087615	28566	Economy	7700.00
0005434139810	28566	Economy	7700.00
0005434139663	28566	Economy	7700.00
0005434139555	28566	Economy	7700.00
0005434087614	28566	Economy	7700.00
0005434139822	28566	Economy	7700.00
0005434139518	28566	Economy	7700.00
0005434139704	28566	Economy	7700.00
0005434139886	28566	Economy	7700.00
0005434139622	28566	Economy	7700.00
0005434139730	28566	Economy	7700.00
0005434139615	28566	Economy	7700.00
0005434139623	28566	Economy	7700.00
0005434139492	28566	Economy	7700.00
0005434139787	28566	Economy	7700.00
0005434139733	28566	Economy	7700.00
0005434139793	28566	Economy	7700.00
0005434139613	28566	Economy	7700.00
0005434139767	28566	Economy	7700.00
0005434139662	28566	Economy	7700.00
0005434139771	28566	Economy	7700.00
0005434139275	28566	Economy	7700.00
0005434139750	28566	Economy	7700.00
0005434139703	28566	Economy	7700.00
0005434139814	28566	Economy	7700.00
0005434139364	28566	Economy	7700.00
0005434139939	28566	Economy	7700.00
0005434139748	28566	Economy	7700.00
0005434139502	28566	Economy	7700.00
0005434139988	28566	Economy	7700.00
0005434139946	28566	Economy	7700.00
0005434140000	28566	Economy	7700.00
0005434139904	28566	Economy	7700.00
0005433407647	1910	Economy	23900.00
0005434610334	1910	Economy	21700.00
0005434610332	1910	Economy	21700.00
0005435808523	1910	Economy	21700.00
0005434610333	1910	Economy	21700.00
0005435808522	1910	Economy	21700.00
0005435808520	1910	Economy	21700.00
0005435808519	1910	Economy	21700.00
0005435808521	1910	Economy	21700.00
0005433407665	1910	Economy	21700.00
0005434610302	23066	Economy	21700.00
0005434610290	23066	Economy	21700.00
0005434610306	23066	Economy	21700.00
0005434505002	16670	Economy	7600.00
0005434504881	16670	Economy	7600.00
0005434504998	16670	Economy	7600.00
0005434505053	16670	Economy	6900.00
0005434504999	16670	Economy	6900.00
0005434504706	16670	Economy	6900.00
0005434504928	16670	Economy	6900.00
0005434504924	16670	Economy	6900.00
0005434504789	16670	Economy	6900.00
0005434505034	16670	Economy	6900.00
0005434504959	16670	Economy	6900.00
0005434504760	16670	Economy	6900.00
0005434504917	16670	Economy	6900.00
0005434504987	16670	Economy	6900.00
0005434504916	16670	Economy	6900.00
0005434504847	16670	Economy	6900.00
0005434504869	16670	Economy	6900.00
0005434504790	16670	Economy	6900.00
0005434504909	16670	Economy	6900.00
0005434505010	16670	Economy	6900.00
0005434504844	16670	Economy	6900.00
0005434504898	16670	Economy	6900.00
0005434504926	16670	Economy	6900.00
0005434504927	16670	Economy	6900.00
0005434504829	16670	Economy	6900.00
0005434505052	16670	Economy	6900.00
0005434504971	16670	Economy	6900.00
0005434504908	16670	Economy	6900.00
0005434505009	16670	Economy	6900.00
0005434504761	16670	Economy	6900.00
0005434504943	16670	Economy	6900.00
0005434504848	16670	Economy	6900.00
0005434505247	22879	Economy	7600.00
0005434505252	22879	Economy	7600.00
0005434505264	22879	Economy	6900.00
0005434505254	22879	Economy	6900.00
0005434505268	22879	Economy	6900.00
0005434505263	22879	Economy	6900.00
0005434505250	22879	Economy	6900.00
0005434505270	22879	Economy	6900.00
0005434505258	22879	Economy	6900.00
0005434505265	22879	Economy	6900.00
0005434505251	22879	Economy	6900.00
0005434505262	22879	Economy	6900.00
0005434505266	22879	Economy	6900.00
0005434505260	22879	Economy	6900.00
0005434505255	22879	Economy	6900.00
0005434505249	22879	Economy	6900.00
0005434505267	22879	Economy	6900.00
0005434505261	22879	Economy	6900.00
0005434505256	22879	Economy	6900.00
0005434505248	22879	Economy	6900.00
0005434505257	22879	Economy	6900.00
0005434505269	22879	Economy	6900.00
0005434505253	22879	Economy	6900.00
0005434505259	22879	Economy	6900.00
0005433266920	2193	Economy	7700.00
0005435078779	2193	Economy	7700.00
0005433266923	2193	Economy	7000.00
0005435078776	2193	Economy	7000.00
0005435078775	2193	Economy	7000.00
0005435078777	2193	Economy	7000.00
0005433266919	2193	Economy	7000.00
0005433266972	2193	Economy	7000.00
0005435078778	2193	Economy	7000.00
0005433266922	2193	Economy	7000.00
0005433266917	2193	Economy	7000.00
0005435078709	24359	Economy	7700.00
0005435078654	24359	Economy	7700.00
0005435078657	24359	Economy	7000.00
0005435078627	24359	Economy	7000.00
0005435078684	24359	Economy	7000.00
0005435078639	24359	Economy	7000.00
0005435078704	24359	Economy	7000.00
0005433266986	24359	Economy	7000.00
0005435078629	24359	Economy	7000.00
0005435078707	24359	Economy	7000.00
0005435078617	24359	Economy	7000.00
0005435078597	24359	Economy	7000.00
0005435078644	24359	Economy	7000.00
0005435078616	24359	Economy	7000.00
0005435078655	24359	Economy	7000.00
0005435078685	24359	Economy	7000.00
0005435078705	24359	Economy	7000.00
0005433266985	24359	Economy	7000.00
0005435078628	24359	Economy	7000.00
0005435078645	24359	Economy	7000.00
0005435078669	24359	Economy	7000.00
0005435078640	24359	Economy	7000.00
0005435078712	24359	Economy	7000.00
0005435078660	24359	Economy	7000.00
0005435078706	24359	Economy	7000.00
0005435078643	24359	Economy	7000.00
0005435464546	6643	Economy	10800.00
0005434989096	6643	Economy	10800.00
0005435803349	6643	Economy	9800.00
0005434989083	6643	Economy	9800.00
0005434989086	6643	Economy	9800.00
0005434989091	6643	Economy	9800.00
0005434989079	6643	Economy	9800.00
0005434989092	6643	Economy	9800.00
0005434989095	6643	Economy	9800.00
0005435464544	6643	Economy	9800.00
0005434989082	6643	Economy	9800.00
0005434989097	6643	Economy	9800.00
0005434989087	6643	Economy	9800.00
0005434989085	6643	Economy	9800.00
0005434989098	6643	Economy	9800.00
0005435464547	6643	Economy	9800.00
0005434989089	6643	Economy	9800.00
0005434989084	6643	Economy	9800.00
0005434989090	6643	Economy	9800.00
0005434989081	6643	Economy	9800.00
0005435464545	6643	Economy	9800.00
0005434989093	6643	Economy	9800.00
0005434989080	6643	Economy	9800.00
0005434989088	6643	Economy	9800.00
0005434989094	6643	Economy	9800.00
0005434989078	6643	Economy	9800.00
0005435803335	23609	Economy	10800.00
0005435803333	23609	Economy	10800.00
0005435464565	23609	Economy	9800.00
0005434988941	23609	Economy	9800.00
0005434988894	23609	Economy	9800.00
0005434988925	23609	Economy	9800.00
0005434988948	23609	Economy	9800.00
0005434988942	23609	Economy	9800.00
0005435803334	23609	Economy	9800.00
0005434988943	23609	Economy	9800.00
0005435464566	23609	Economy	9800.00
0005434988944	23609	Economy	9800.00
0005434988949	23609	Economy	9800.00
0005434988945	23609	Economy	9800.00
0005434988916	23609	Economy	9800.00
0005432384311	30513	Business	9900.00
0005433450598	30513	Business	9900.00
0005432384301	30513	Business	9900.00
0005433450596	30513	Economy	3300.00
0005433450595	30513	Economy	3300.00
0005433450590	30513	Economy	3300.00
0005432384295	30513	Economy	3600.00
0005433450593	30513	Economy	3600.00
0005432384313	30513	Economy	3600.00
0005432384297	30513	Economy	3300.00
0005433450599	30513	Economy	3300.00
0005432384303	30513	Economy	3300.00
0005432384304	30513	Economy	3300.00
0005432384307	30513	Economy	3300.00
0005432384294	30513	Economy	3300.00
0005433450589	30513	Economy	3300.00
0005433450591	30513	Economy	3300.00
0005432384302	30513	Economy	3300.00
0005432384310	30513	Economy	3300.00
0005432384298	30513	Economy	3300.00
0005432384300	30513	Economy	3300.00
0005432384309	30513	Economy	3300.00
0005433450592	30513	Economy	3300.00
0005432384306	30513	Economy	3300.00
0005433450597	30513	Economy	3300.00
0005433450594	30513	Economy	3300.00
0005432384312	30513	Economy	3300.00
0005432384308	30513	Economy	3300.00
0005432384293	30513	Economy	3300.00
0005433450588	30513	Economy	3300.00
0005432384305	30513	Economy	3300.00
0005432384299	30513	Economy	3300.00
0005432384296	30513	Economy	3300.00
0005433450587	30513	Economy	3300.00
0005433454933	30513	Economy	3300.00
0005433450428	31334	Business	9900.00
0005432383995	31334	Business	9900.00
0005432383859	31334	Business	9900.00
0005432383954	31334	Business	9900.00
0005432383703	31334	Business	9900.00
0005433451664	31334	Business	9900.00
0005432383775	31334	Business	9900.00
0005432384005	31334	Business	9900.00
0005433450449	31334	Business	9900.00
0005432383937	31334	Business	9900.00
0005432383899	31334	Economy	3300.00
0005432383730	31334	Economy	3300.00
0005432383729	31334	Economy	3300.00
0005433450375	31334	Economy	3300.00
0005433450275	31334	Economy	3300.00
0005433451665	31334	Economy	3300.00
0005433450517	31334	Economy	3300.00
0005432383716	31334	Economy	3600.00
0005433451661	31334	Economy	3600.00
0005433451655	31334	Economy	3600.00
0005432383892	31334	Economy	3600.00
0005433450463	31334	Economy	3300.00
0005432383974	31334	Economy	3300.00
0005432383796	31334	Economy	3300.00
0005432384060	31334	Economy	3300.00
0005433450381	31334	Economy	3300.00
0005432383774	31334	Economy	3300.00
0005433450508	31334	Economy	3300.00
0005433450495	31334	Economy	3300.00
0005433450374	31334	Economy	3300.00
0005432383858	31334	Economy	3300.00
0005432383920	31334	Economy	3300.00
0005432383921	31334	Economy	3300.00
0005432383909	31334	Economy	3300.00
0005433450461	31334	Economy	3300.00
0005432383990	31334	Economy	3300.00
0005432383893	31334	Economy	3300.00
0005432383745	31334	Economy	3300.00
0005433450450	31334	Economy	3300.00
0005432383967	31334	Economy	3300.00
0005432383955	31334	Economy	3300.00
0005433453813	31334	Economy	3300.00
0005432383977	31334	Economy	3300.00
0005433450430	31334	Economy	3300.00
0005433450429	31334	Economy	3300.00
0005433450432	31334	Economy	3300.00
0005433450433	31334	Economy	3300.00
0005432383816	31334	Economy	3300.00
0005433450448	31334	Economy	3300.00
0005432384004	31334	Economy	3300.00
0005433450274	31334	Economy	3300.00
0005433450496	31334	Economy	3300.00
0005432383797	31334	Economy	3300.00
0005432384003	31334	Economy	3300.00
0005432383898	31334	Economy	3300.00
0005432384016	31334	Economy	3300.00
0005432384087	31334	Economy	3300.00
0005432383913	31334	Economy	3300.00
0005432383768	31334	Economy	3300.00
0005433453812	31334	Economy	3300.00
0005432384067	31334	Economy	3300.00
0005432383896	31334	Economy	3300.00
0005433450338	31334	Economy	3300.00
0005432384088	31334	Economy	3300.00
0005432384068	31334	Economy	3300.00
0005432383938	31334	Economy	3300.00
0005433453809	31334	Economy	3300.00
0005433788292	26485	Economy	26200.00
0005433788280	26485	Economy	23800.00
0005433788288	26485	Economy	23800.00
0005433788275	26485	Economy	23800.00
0005433788274	26485	Economy	23800.00
0005433788282	26485	Economy	23800.00
0005435548624	26485	Economy	23800.00
0005433788276	26485	Economy	23800.00
0005433788281	26485	Economy	23800.00
0005433788273	26485	Economy	23800.00
0005433788265	26485	Economy	23800.00
0005433788283	26485	Economy	23800.00
0005433788264	26485	Economy	23800.00
0005433788291	26485	Economy	23800.00
0005433788293	26485	Economy	23800.00
0005433126922	10754	Economy	17100.00
0005433131825	10754	Economy	15600.00
0005433126921	10754	Economy	15600.00
0005433131791	10754	Economy	15600.00
0005433131826	10754	Economy	15600.00
0005435304245	10754	Economy	15600.00
0005433131795	10754	Economy	15600.00
0005433126942	10754	Economy	15600.00
0005435299856	10754	Economy	15600.00
0005433126943	10754	Economy	15600.00
0005433131796	10754	Economy	15600.00
0005433131781	10754	Economy	15600.00
0005433126979	29711	Economy	15600.00
0005435299919	29711	Economy	15600.00
0005433126976	29711	Economy	15600.00
0005435299921	29711	Economy	15600.00
0005435299920	29711	Economy	15600.00
0005435302336	29711	Economy	15600.00
0005435299918	29711	Economy	15600.00
0005433126978	29711	Economy	15600.00
0005433126977	29711	Economy	15600.00
0005435299922	29711	Economy	15600.00
0005434300234	2430	Economy	17200.00
0005434287916	2430	Economy	17200.00
0005434287926	2430	Economy	15700.00
0005433110331	2430	Economy	15700.00
0005433110312	2430	Economy	15700.00
0005433110330	2430	Economy	15700.00
0005433110335	2430	Economy	15700.00
0005434287922	2430	Economy	15700.00
0005434300235	2430	Economy	15700.00
0005433110329	2430	Economy	15700.00
0005434287921	2430	Economy	15700.00
0005434287917	2430	Economy	15700.00
0005434287927	2430	Economy	15700.00
0005434300238	2430	Economy	15700.00
0005434287920	2430	Economy	15700.00
0005433110362	2430	Economy	15700.00
0005433110346	2430	Economy	15700.00
0005433110338	2430	Economy	15700.00
0005433110318	2430	Economy	15700.00
0005434287925	2430	Economy	15700.00
0005434287923	2430	Economy	15700.00
0005434287928	2430	Economy	15700.00
0005433110347	2430	Economy	15700.00
0005433110334	2430	Economy	15700.00
0005433110361	2430	Economy	15700.00
0005434287918	2430	Economy	15700.00
0005433110307	2430	Economy	15700.00
0005434300236	2430	Economy	15700.00
0005433110356	2430	Economy	15700.00
0005433110328	2430	Economy	15700.00
0005433110348	2430	Economy	15700.00
0005433110327	2430	Economy	15700.00
0005434287919	2430	Economy	15700.00
0005434300237	2430	Economy	15700.00
0005433110350	2430	Economy	15700.00
0005433110360	2430	Economy	15700.00
0005433110359	2430	Economy	15700.00
0005434287924	2430	Economy	15700.00
0005434287756	26863	Economy	17200.00
0005433110388	26863	Economy	17200.00
0005434287757	26863	Economy	15700.00
0005434287778	26863	Economy	15700.00
0005433110389	26863	Economy	15700.00
0005434287742	26863	Economy	15700.00
0005434287656	26863	Economy	15700.00
0005434287802	26863	Economy	15700.00
0005433110390	26863	Economy	15700.00
0005434287801	26863	Economy	15700.00
0005434287718	26863	Economy	15700.00
0005434287659	26863	Economy	15700.00
0005434287704	26863	Economy	15700.00
0005434287796	26863	Economy	15700.00
0005434287837	26863	Economy	15700.00
0005434287773	26863	Economy	15700.00
0005434287819	26863	Economy	15700.00
0005434287672	26863	Economy	15700.00
0005434287838	26863	Economy	15700.00
0005434287725	26863	Economy	15700.00
0005434287800	26863	Economy	15700.00
0005434287811	26863	Economy	15700.00
0005434287777	26863	Economy	15700.00
0005434287658	26863	Economy	15700.00
0005434287751	26863	Economy	15700.00
0005434287818	26863	Economy	15700.00
0005434272216	25457	Economy	25000.00
0005435856327	25457	Economy	25000.00
0005435856361	25457	Economy	22800.00
0005434272224	25457	Economy	22800.00
0005435983704	25457	Economy	22800.00
0005434272225	25457	Economy	22800.00
0005435983703	25457	Economy	22800.00
0005434272221	25457	Economy	22800.00
0005435856329	25457	Economy	22800.00
0005435856328	25457	Economy	22800.00
0005434272217	25457	Economy	22800.00
0005434269145	25457	Economy	22800.00
0005434269144	25457	Economy	22800.00
0005435856285	26620	Economy	25000.00
0005435856287	26620	Economy	25000.00
0005435854066	26620	Economy	25000.00
0005435854067	26620	Economy	22800.00
0005434273126	26620	Economy	22800.00
0005435854068	26620	Economy	22800.00
0005435856286	26620	Economy	22800.00
0005435856288	26620	Economy	22800.00
0005434273127	26620	Economy	22800.00
0005435856274	26620	Economy	22800.00
0005434273135	26620	Economy	22800.00
0005434520412	19086	Economy	24600.00
0005434520426	19086	Economy	24600.00
0005435314948	19086	Economy	24600.00
0005435314945	19086	Economy	24600.00
0005434520442	19086	Economy	22300.00
0005434520411	19086	Economy	22300.00
0005434520481	19086	Economy	22300.00
0005435314946	19086	Economy	22300.00
0005434520414	19086	Economy	22300.00
0005434520376	19086	Economy	22300.00
0005434520397	19086	Economy	22300.00
0005434520446	19086	Economy	22300.00
0005434520399	19086	Economy	22300.00
0005434520428	19086	Economy	22300.00
0005434520432	19086	Economy	22300.00
0005434520431	19086	Economy	22300.00
0005434520439	19086	Economy	22300.00
0005434520387	19086	Economy	22300.00
0005434520394	19086	Economy	22300.00
0005434520423	19086	Economy	22300.00
0005434520471	19086	Economy	22300.00
0005434520415	19086	Economy	22300.00
0005434520417	19086	Economy	22300.00
0005434520377	19086	Economy	22300.00
0005434520436	19086	Economy	22300.00
0005434520416	19086	Economy	22300.00
0005434520424	19086	Economy	22300.00
0005434520400	19086	Economy	22300.00
0005434520389	19086	Economy	22300.00
0005434520447	19086	Economy	22300.00
0005434520375	19086	Economy	22300.00
0005434520401	19086	Economy	22300.00
0005435314947	19086	Economy	22300.00
0005434520374	19086	Economy	22300.00
0005434520430	19086	Economy	22300.00
0005435314949	19086	Economy	22300.00
0005434520468	19086	Economy	22300.00
0005434520441	19086	Economy	22300.00
0005434520422	19086	Economy	22300.00
0005434520427	19086	Economy	22300.00
0005434520470	19086	Economy	22300.00
0005434520421	19086	Economy	22300.00
0005434520435	19086	Economy	22300.00
0005434520419	19086	Economy	22300.00
0005434520395	19086	Economy	22300.00
0005434520443	19086	Economy	22300.00
0005434520396	19086	Economy	22300.00
0005434520429	19086	Economy	22300.00
0005434520467	19086	Economy	22300.00
0005434520408	19086	Economy	22300.00
0005433874451	7781	Economy	17400.00
0005433874453	7781	Economy	17400.00
0005433874456	7781	Economy	17400.00
0005433874454	7781	Economy	17400.00
0005433874450	7781	Economy	17400.00
0005433874449	7781	Economy	17400.00
0005433874455	7781	Economy	17400.00
0005433874452	7781	Economy	17400.00
0005433874448	7781	Economy	17400.00
0005433874412	32631	Economy	17400.00
0005433874446	32631	Economy	17400.00
0005433874435	32631	Economy	17400.00
0005433874416	32631	Economy	17400.00
0005433874425	32631	Economy	17400.00
0005433874428	32631	Economy	17400.00
0005433874417	32631	Economy	17400.00
0005433874413	32631	Economy	17400.00
0005433874445	32631	Economy	17400.00
0005433874421	32631	Economy	17400.00
0005433874447	32631	Economy	17400.00
0005433874430	32631	Economy	17400.00
0005433874434	32631	Economy	17400.00
0005433874415	32631	Economy	17400.00
0005433874429	32631	Economy	17400.00
0005435860585	4804	Economy	19400.00
0005433869581	4804	Economy	19400.00
0005433869576	4804	Economy	19400.00
0005433869580	4804	Economy	17600.00
0005433869585	4804	Economy	17600.00
0005435860587	4804	Economy	17600.00
0005433869586	4804	Economy	17600.00
0005435860578	4804	Economy	17600.00
0005433869582	4804	Economy	17600.00
0005433869577	4804	Economy	17600.00
0005433869584	4804	Economy	17600.00
0005435860561	4804	Economy	17600.00
0005433869579	4804	Economy	17600.00
0005433869587	4804	Economy	17600.00
0005433869583	4804	Economy	17600.00
0005433869578	4804	Economy	17600.00
0005433869441	32581	Economy	19400.00
0005433869251	32581	Economy	19400.00
0005433869125	32581	Economy	17600.00
0005433869440	32581	Economy	17600.00
0005433869369	32581	Economy	17600.00
0005433869170	32581	Economy	17600.00
0005433869213	32581	Economy	17600.00
0005435860623	32581	Economy	17600.00
0005433869250	32581	Economy	17600.00
0005435860622	32581	Economy	17600.00
0005433869293	32581	Economy	17600.00
0005433869276	32581	Economy	17600.00
0005433869121	32581	Economy	17600.00
0005433869338	32581	Economy	17600.00
0005433869071	32581	Economy	17600.00
0005433869340	32581	Economy	17600.00
0005433869115	32581	Economy	17600.00
0005433869195	32581	Economy	17600.00
0005433869354	32581	Economy	17600.00
0005433869383	32581	Economy	17600.00
0005433869382	32581	Economy	17600.00
0005433869288	32581	Economy	17600.00
0005433869370	32581	Economy	17600.00
0005433869244	32581	Economy	17600.00
0005433869105	32581	Economy	17600.00
0005433869363	32581	Economy	17600.00
0005433869264	32581	Economy	17600.00
0005433869362	32581	Economy	17600.00
0005435860620	32581	Economy	17600.00
0005433869359	32581	Economy	17600.00
0005433869202	32581	Economy	17600.00
0005433869114	32581	Economy	17600.00
0005433869256	32581	Economy	17600.00
0005433868986	32581	Economy	17600.00
0005433869237	32581	Economy	17600.00
0005433869176	32581	Economy	17600.00
0005433869358	32581	Economy	17600.00
0005433869439	32581	Economy	17600.00
0005433869422	32581	Economy	17600.00
0005435860621	32581	Economy	17600.00
0005433869265	32581	Economy	17600.00
0005434663798	3440	Economy	24800.00
0005435911625	3440	Economy	24800.00
0005435911606	3440	Economy	22600.00
0005434663794	3440	Economy	22600.00
0005434663797	3440	Economy	22600.00
0005435911633	3440	Economy	22600.00
0005435911605	3440	Economy	22600.00
0005435911590	3440	Economy	22600.00
0005435911623	3440	Economy	22600.00
0005434663795	3440	Economy	22600.00
0005434663793	3440	Economy	22600.00
0005435911635	3440	Economy	22600.00
0005434461708	3440	Economy	22600.00
0005434663799	3440	Economy	22600.00
0005435911636	3440	Economy	22600.00
0005434663796	3440	Economy	22600.00
0005435911591	3440	Economy	22600.00
0005434462835	12451	Economy	24800.00
0005434663706	12451	Economy	24800.00
0005434462829	12451	Economy	22600.00
0005434663684	12451	Economy	22600.00
0005434663736	12451	Economy	22600.00
0005434460553	12451	Economy	22600.00
0005434663685	12451	Economy	22600.00
0005434462832	12451	Economy	22600.00
0005434462830	12451	Economy	22600.00
0005434663744	12451	Economy	22600.00
0005434663735	12451	Economy	22600.00
0005434663758	12451	Economy	22600.00
0005434462831	12451	Economy	22600.00
0005434462827	12451	Economy	22600.00
0005434663676	12451	Economy	22600.00
0005434663707	12451	Economy	22600.00
0005434663701	12451	Economy	22600.00
0005434663759	12451	Economy	22600.00
0005434460542	12451	Economy	22600.00
0005434663677	12451	Economy	22600.00
0005434462823	12451	Economy	22600.00
0005434460543	12451	Economy	22600.00
0005434663692	12451	Economy	22600.00
0005434460541	12451	Economy	22600.00
0005434460535	12451	Economy	22600.00
0005434460540	12451	Economy	22600.00
0005434460533	12451	Economy	22600.00
0005434462825	12451	Economy	22600.00
0005434462833	12451	Economy	22600.00
0005434460554	12451	Economy	22600.00
0005434460536	12451	Economy	22600.00
0005434460537	12451	Economy	22600.00
0005434663708	12451	Economy	22600.00
0005434462828	12451	Economy	22600.00
0005434462826	12451	Economy	22600.00
0005434663709	12451	Economy	22600.00
0005434663683	12451	Economy	22600.00
0005433869264	14497	Economy	18500.00
0005433869338	14497	Economy	18500.00
0005433869440	14497	Economy	16800.00
0005435860621	14497	Economy	16800.00
0005433869362	14497	Economy	16800.00
0005433869359	14497	Economy	16800.00
0005433869370	14497	Economy	16800.00
0005433869340	14497	Economy	16800.00
0005433869288	14497	Economy	16800.00
0005433869256	14497	Economy	16800.00
0005433869176	14497	Economy	16800.00
0005433869382	14497	Economy	16800.00
0005433869363	14497	Economy	16800.00
0005433869170	14497	Economy	16800.00
0005433869439	14497	Economy	16800.00
0005433869202	14497	Economy	16800.00
0005435860620	14497	Economy	16800.00
0005433869358	14497	Economy	16800.00
0005433869354	14497	Economy	16800.00
0005433869250	14497	Economy	16800.00
0005433869071	14497	Economy	16800.00
0005433869369	14497	Economy	16800.00
0005433869422	14497	Economy	16800.00
0005433869237	14497	Economy	16800.00
0005433869115	14497	Economy	16800.00
0005435860622	14497	Economy	16800.00
0005433869244	14497	Economy	16800.00
0005435860623	14497	Economy	16800.00
0005433869276	14497	Economy	16800.00
0005433869195	14497	Economy	16800.00
0005433868986	14497	Economy	16800.00
0005433869383	14497	Economy	16800.00
0005433869441	14497	Economy	16800.00
0005433869114	14497	Economy	16800.00
0005433869265	14497	Economy	16800.00
0005433869125	14497	Economy	16800.00
0005433869293	14497	Economy	16800.00
0005433869121	14497	Economy	16800.00
0005433869213	14497	Economy	16800.00
0005433869105	14497	Economy	16800.00
0005433869251	14497	Economy	16800.00
0005435860592	32653	Economy	18500.00
0005433869554	32653	Economy	18500.00
0005433869564	32653	Economy	16800.00
0005433869566	32653	Economy	16800.00
0005433869573	32653	Economy	16800.00
0005435860528	32653	Economy	16800.00
0005433869558	32653	Economy	16800.00
0005435860563	32653	Economy	16800.00
0005435860541	32653	Economy	16800.00
0005433869575	32653	Economy	16800.00
0005433869555	32653	Economy	16800.00
0005433869570	32653	Economy	16800.00
0005433869568	32653	Economy	16800.00
0005433869550	32653	Economy	16800.00
0005433869562	32653	Economy	16800.00
0005433869551	32653	Economy	16800.00
0005433869559	32653	Economy	16800.00
0005435860547	32653	Economy	16800.00
0005433869563	32653	Economy	16800.00
0005433869565	32653	Economy	16800.00
0005433869571	32653	Economy	16800.00
0005435860569	32653	Economy	16800.00
0005433869569	32653	Economy	16800.00
0005433869553	32653	Economy	16800.00
0005433869561	32653	Economy	16800.00
0005433869572	32653	Economy	16800.00
0005435860548	32653	Economy	16800.00
0005433869574	32653	Economy	16800.00
0005433869560	32653	Economy	16800.00
0005433869556	32653	Economy	16800.00
0005435860552	32653	Economy	16800.00
0005435860565	32653	Economy	16800.00
0005435860564	32653	Economy	16800.00
0005435860566	32653	Economy	16800.00
0005433869552	32653	Economy	16800.00
0005433869567	32653	Economy	16800.00
0005433869557	32653	Economy	16800.00
0005435860551	32653	Economy	16800.00
0005432800007	12128	Economy	4900.00
0005432800153	12128	Economy	4900.00
0005432800175	12128	Economy	4900.00
0005432800043	12128	Economy	4400.00
0005432800110	12128	Economy	4400.00
0005432799992	12128	Economy	4400.00
0005432800154	12128	Economy	4400.00
0005432799980	12128	Economy	4400.00
0005432799987	12128	Economy	4400.00
0005432800108	12128	Economy	4400.00
0005432800078	12128	Economy	4400.00
0005432800005	12128	Economy	4400.00
0005432800066	12128	Economy	4400.00
0005432800209	12128	Economy	4400.00
0005432799986	12128	Economy	4400.00
0005432800039	12128	Economy	4400.00
0005432800042	12128	Economy	4400.00
0005432800109	12128	Economy	4400.00
0005432799979	12128	Economy	4400.00
0005432800001	12128	Economy	4400.00
0005432800205	12128	Economy	4400.00
0005432799978	12128	Economy	4400.00
0005432800030	12128	Economy	4400.00
0005432800025	12128	Economy	4400.00
0005432799953	12128	Economy	4400.00
0005432799952	12128	Economy	4400.00
0005432800024	12128	Economy	4400.00
0005432800038	12128	Economy	4400.00
0005432800162	12128	Economy	4400.00
0005432800117	12128	Economy	4400.00
0005432800065	12128	Economy	4400.00
0005432800008	12128	Economy	4400.00
0005432800237	14794	Economy	4400.00
0005432800234	14794	Economy	4400.00
0005432800244	14794	Economy	4400.00
0005432800242	14794	Economy	4400.00
0005432800245	14794	Economy	4400.00
0005432800238	14794	Economy	4400.00
0005432800243	14794	Economy	4400.00
0005432800240	14794	Economy	4400.00
0005432800235	14794	Economy	4400.00
0005432800247	14794	Economy	4400.00
0005432800246	14794	Economy	4400.00
0005432800239	14794	Economy	4400.00
0005432800241	14794	Economy	4400.00
0005432800236	14794	Economy	4400.00
0005432800248	14794	Economy	4400.00
0005434409562	7087	Business	49100.00
0005435293536	7087	Business	49100.00
0005435293535	7087	Business	49100.00
0005434409556	7087	Business	49100.00
0005434409568	7087	Business	49100.00
0005435311397	7087	Business	49100.00
0005434409565	7087	Business	49100.00
0005434409564	7087	Economy	16400.00
0005434300212	7087	Economy	16400.00
0005435311331	7087	Economy	16400.00
0005434409552	7087	Economy	16400.00
0005435311361	7087	Economy	16400.00
0005434409574	7087	Economy	16400.00
0005434409560	7087	Economy	16400.00
0005434300209	7087	Economy	16400.00
0005435311332	7087	Economy	16400.00
0005434409555	7087	Economy	16400.00
0005434409567	7087	Economy	16400.00
0005435311345	7087	Economy	16400.00
0005434409571	7087	Economy	16400.00
0005435293514	7087	Economy	16400.00
0005435293537	7087	Economy	16400.00
0005434409558	7087	Economy	16400.00
0005434409566	7087	Economy	16400.00
0005434409576	7087	Economy	16400.00
0005434409572	7087	Economy	16400.00
0005432108320	7087	Economy	18000.00
0005434300207	7087	Economy	18000.00
0005435293486	7087	Economy	16400.00
0005435311359	7087	Economy	16400.00
0005432108321	7087	Economy	16400.00
0005434409573	7087	Economy	16400.00
0005435311293	7087	Economy	16400.00
0005435293585	7087	Economy	16400.00
0005435311368	7087	Economy	16400.00
0005432154136	7087	Economy	16400.00
0005435293517	7087	Economy	16400.00
0005434300208	7087	Economy	16400.00
0005435311339	7087	Economy	16400.00
0005435311249	7087	Economy	16400.00
0005435311360	7087	Economy	16400.00
0005435293518	7087	Economy	16400.00
0005435311344	7087	Economy	16400.00
0005435311398	7087	Economy	16400.00
0005435311391	7087	Economy	16400.00
0005435311306	7087	Economy	16400.00
0005434300210	7087	Economy	16400.00
0005435311376	7087	Economy	16400.00
0005434300211	7087	Economy	16400.00
0005434409575	7087	Economy	16400.00
0005434409551	7087	Economy	16400.00
0005435293508	7087	Economy	16400.00
0005435293538	7087	Economy	16400.00
0005435311327	7087	Economy	16400.00
0005435311420	7087	Economy	16400.00
0005434409563	7087	Economy	16400.00
0005434409570	7087	Economy	16400.00
0005432154135	7087	Economy	16400.00
0005435293507	7087	Economy	16400.00
0005434409559	7087	Economy	16400.00
0005432108322	7087	Economy	16400.00
0005434409577	7087	Economy	16400.00
0005434409557	7087	Economy	16400.00
0005435311406	7087	Economy	16400.00
0005435311333	7087	Economy	16400.00
0005435311320	7087	Economy	16400.00
0005434409569	7087	Economy	16400.00
0005435311268	7087	Economy	16400.00
0005434409554	7087	Economy	16400.00
0005434409561	7087	Economy	16400.00
0005434409553	7087	Economy	16400.00
0005434409059	26902	Business	49100.00
0005434409027	26902	Business	49100.00
0005434300100	26902	Business	49100.00
0005434300022	26902	Business	49100.00
0005434408598	26902	Business	49100.00
0005434408955	26902	Business	49100.00
0005434408998	26902	Business	49100.00
0005434408695	26902	Business	49100.00
0005434409255	26902	Business	49100.00
0005434408550	26902	Business	49100.00
0005434409146	26902	Business	49100.00
0005434409127	26902	Business	49100.00
0005434409083	26902	Economy	16400.00
0005434408995	26902	Economy	16400.00
0005435293619	26902	Economy	16400.00
0005435311519	26902	Economy	16400.00
0005434408950	26902	Economy	16400.00
0005435293616	26902	Economy	16400.00
0005434408986	26902	Economy	16400.00
0005434408985	26902	Economy	16400.00
0005434409213	26902	Economy	16400.00
0005434408869	26902	Economy	16400.00
0005434409247	26902	Economy	16400.00
0005434408799	26902	Economy	16400.00
0005434408803	26902	Economy	16400.00
0005434408915	26902	Economy	16400.00
0005434408928	26902	Economy	16400.00
0005434408623	26902	Economy	16400.00
0005434408804	26902	Economy	16400.00
0005435311515	26902	Economy	16400.00
0005434409071	26902	Economy	16400.00
0005434409032	26902	Economy	16400.00
0005434300089	26902	Economy	16400.00
0005434408901	26902	Economy	16400.00
0005435311514	26902	Economy	16400.00
0005434408599	26902	Economy	16400.00
0005434300108	26902	Economy	16400.00
0005434408845	26902	Economy	16400.00
0005435311512	26902	Economy	16400.00
0005435293615	26902	Economy	16400.00
0005434409142	26902	Economy	16400.00
0005434409075	26902	Economy	16400.00
0005435311505	26902	Economy	16400.00
0005435311522	26902	Economy	16400.00
0005434300068	26902	Economy	16400.00
0005435311524	26902	Economy	16400.00
0005435293620	26902	Economy	16400.00
0005434408800	26902	Economy	16400.00
0005434409082	26902	Economy	16400.00
0005434409002	26902	Economy	18000.00
0005434300101	26902	Economy	18000.00
0005434300113	26902	Economy	18000.00
0005434408951	26902	Economy	18000.00
0005434409243	26902	Economy	18000.00
0005434408868	26902	Economy	16400.00
0005434408846	26902	Economy	16400.00
0005434408954	26902	Economy	16400.00
0005434409200	26902	Economy	16400.00
0005434409070	26902	Economy	16400.00
0005434409171	26902	Economy	16400.00
0005434300036	26902	Economy	16400.00
0005434409144	26902	Economy	16400.00
0005434409311	26902	Economy	16400.00
0005434409013	26902	Economy	16400.00
0005435311513	26902	Economy	16400.00
0005434409058	26902	Economy	16400.00
0005434409145	26902	Economy	16400.00
0005435311510	26902	Economy	16400.00
0005435293611	26902	Economy	16400.00
0005435293612	26902	Economy	16400.00
0005434408991	26902	Economy	16400.00
0005434409143	26902	Economy	16400.00
0005434408844	26902	Economy	16400.00
0005435311516	26902	Economy	16400.00
0005434408818	26902	Economy	16400.00
0005434300067	26902	Economy	16400.00
0005435311518	26902	Economy	16400.00
0005435293614	26902	Economy	16400.00
0005435311509	26902	Economy	16400.00
0005435311504	26902	Economy	16400.00
0005434408993	26902	Economy	16400.00
0005434300025	26902	Economy	16400.00
0005434300069	26902	Economy	16400.00
0005434409017	26902	Economy	16400.00
0005434408980	26902	Economy	16400.00
0005434300027	26902	Economy	16400.00
0005434300107	26902	Economy	16400.00
0005435311523	26902	Economy	16400.00
0005434409138	26902	Economy	16400.00
0005435311517	26902	Economy	16400.00
0005434409079	26902	Economy	16400.00
0005435311506	26902	Economy	16400.00
0005435311520	26902	Economy	16400.00
0005435311508	26902	Economy	16400.00
0005434409078	26902	Economy	16400.00
0005434408927	26902	Economy	16400.00
0005435293618	26902	Economy	16400.00
0005434408802	26902	Economy	16400.00
0005434300088	26902	Economy	16400.00
0005434408768	26902	Economy	16400.00
0005434300080	26902	Economy	16400.00
0005434409074	26902	Economy	16400.00
0005434408805	26902	Economy	16400.00
0005434300013	26902	Economy	16400.00
0005434300120	26902	Economy	16400.00
0005434409043	26902	Economy	16400.00
0005435311507	26902	Economy	16400.00
0005434408877	26902	Economy	16400.00
0005434300043	26902	Economy	16400.00
0005435311521	26902	Economy	16400.00
0005434408992	26902	Economy	16400.00
0005434409035	26902	Economy	16400.00
0005434409044	26902	Economy	16400.00
0005434409042	26902	Economy	16400.00
0005435311511	26902	Economy	16400.00
0005434409012	26902	Economy	16400.00
0005434300014	26902	Economy	16400.00
0005435293617	26902	Economy	16400.00
0005434409242	26902	Economy	16400.00
0005434408994	26902	Economy	16400.00
0005434409069	26902	Economy	16400.00
0005435293613	26902	Economy	16400.00
0005434300092	26902	Economy	16400.00
0005432605474	6434	Economy	15000.00
0005432605470	6434	Economy	15000.00
0005434512249	6434	Economy	15000.00
0005432605468	6434	Economy	15000.00
0005432605463	6434	Economy	15000.00
0005435220504	6434	Economy	15000.00
0005432605475	6434	Economy	15000.00
0005432605467	6434	Economy	15000.00
0005435218139	6434	Economy	15000.00
0005435220503	6434	Economy	15000.00
0005432605471	6434	Economy	15000.00
0005432605478	6434	Economy	15000.00
0005432605479	6434	Economy	15000.00
0005432605476	6434	Economy	15000.00
0005434512251	6434	Economy	15000.00
0005434512250	6434	Economy	15000.00
0005434512252	6434	Economy	15000.00
0005435218141	6434	Economy	15000.00
0005435312898	6434	Economy	15000.00
0005432605472	6434	Economy	15000.00
0005435218123	6434	Economy	15000.00
0005432605464	6434	Economy	15000.00
0005432605480	6434	Economy	15000.00
0005434512253	6434	Economy	15000.00
0005432605465	6434	Economy	15000.00
0005432605477	6434	Economy	15000.00
0005435218140	6434	Economy	15000.00
0005435220495	6434	Economy	15000.00
0005432605473	6434	Economy	15000.00
0005432605466	6434	Economy	15000.00
0005432605469	6434	Economy	15000.00
0005432605124	21395	Economy	16500.00
0005432605046	21395	Economy	16500.00
0005432605184	21395	Economy	16500.00
0005432605117	21395	Economy	16500.00
0005432605229	21395	Economy	15000.00
0005432605134	21395	Economy	15000.00
0005432605122	21395	Economy	15000.00
0005432605063	21395	Economy	15000.00
0005432605186	21395	Economy	15000.00
0005432605178	21395	Economy	15000.00
0005435312908	21395	Economy	15000.00
0005432605191	21395	Economy	15000.00
0005432604980	21395	Economy	15000.00
0005432605177	21395	Economy	15000.00
0005435221082	21395	Economy	15000.00
0005432605118	21395	Economy	15000.00
0005432605029	21395	Economy	15000.00
0005432605094	21395	Economy	15000.00
0005432605102	21395	Economy	15000.00
0005432605192	21395	Economy	15000.00
0005434512227	21395	Economy	15000.00
0005432605261	21395	Economy	15000.00
0005432605323	21395	Economy	15000.00
0005435221535	21395	Economy	15000.00
0005432605127	21395	Economy	15000.00
0005432605180	21395	Economy	15000.00
0005432605262	21395	Economy	15000.00
0005432605169	21395	Economy	15000.00
0005434512197	21395	Economy	15000.00
0005432605228	21395	Economy	15000.00
0005432605030	21395	Economy	15000.00
0005432605095	21395	Economy	15000.00
0005432605244	21395	Economy	15000.00
0005435312910	21395	Economy	15000.00
0005432605230	21395	Economy	15000.00
0005432605269	21395	Economy	15000.00
0005432604971	21395	Economy	15000.00
0005432605047	21395	Economy	15000.00
0005432605056	21395	Economy	15000.00
0005435221081	21395	Economy	15000.00
0005432605115	21395	Economy	15000.00
0005434512196	21395	Economy	15000.00
0005435312909	21395	Economy	15000.00
0005432605185	21395	Economy	15000.00
0005432605121	21395	Economy	15000.00
0005432605324	21395	Economy	15000.00
0005432605179	21395	Economy	15000.00
0005434908477	15017	Business	18900.00
0005433252346	15017	Business	18900.00
0005434908239	15017	Business	18900.00
0005434908501	15017	Business	18900.00
0005434908350	15017	Business	18900.00
0005434908351	15017	Business	18900.00
0005434908304	15017	Business	18900.00
0005433252353	15017	Business	18900.00
0005434908343	15017	Economy	6300.00
0005434908545	15017	Economy	6300.00
0005434908299	15017	Economy	6300.00
0005434908192	15017	Economy	6300.00
0005434908428	15017	Economy	6300.00
0005434908410	15017	Economy	6900.00
0005434908303	15017	Economy	6900.00
0005433252355	15017	Economy	6900.00
0005434908463	15017	Economy	6300.00
0005434908247	15017	Economy	6300.00
0005433252348	15017	Economy	6300.00
0005434908302	15017	Economy	6300.00
0005434908381	15017	Economy	6300.00
0005434908496	15017	Economy	6300.00
0005434908237	15017	Economy	6300.00
0005433252351	15017	Economy	6300.00
0005434908325	15017	Economy	6300.00
0005434908297	15017	Economy	6300.00
0005434908352	15017	Economy	6300.00
0005434908248	15017	Economy	6300.00
0005434908396	15017	Economy	6300.00
0005434908390	15017	Economy	6300.00
0005434908467	15017	Economy	6300.00
0005434908506	15017	Economy	6300.00
0005433252350	15017	Economy	6300.00
0005433252345	15017	Economy	6300.00
0005434908249	15017	Economy	6300.00
0005433252358	15017	Economy	6300.00
0005434908119	15017	Economy	6300.00
0005433252356	15017	Economy	6300.00
0005434908446	15017	Economy	6300.00
0005433252349	15017	Economy	6300.00
0005434908238	15017	Economy	6300.00
0005433252352	15017	Economy	6300.00
0005434908301	15017	Economy	6300.00
0005434908382	15017	Economy	6300.00
0005434908505	15017	Economy	6300.00
0005434908383	15017	Economy	6300.00
0005434908389	15017	Economy	6300.00
0005433252347	15017	Economy	6300.00
0005434908296	15017	Economy	6300.00
0005434908498	15017	Economy	6300.00
0005433252354	15017	Economy	6300.00
0005434908191	15017	Economy	6300.00
0005434908596	15017	Economy	6300.00
0005433252359	15017	Economy	6300.00
0005434908340	15017	Economy	6300.00
0005434908497	15017	Economy	6300.00
0005434908400	15017	Economy	6300.00
0005434908276	15017	Economy	6300.00
0005434908399	15017	Economy	6300.00
0005434908402	15017	Economy	6300.00
0005434908220	15017	Economy	6300.00
0005434908544	15017	Economy	6300.00
0005434908603	15017	Economy	6300.00
0005434908440	15017	Economy	6300.00
0005434908105	15017	Economy	6300.00
0005433252357	15017	Economy	6300.00
0005433252146	25850	Business	18900.00
0005433252058	25850	Business	18900.00
0005433252107	25850	Business	18900.00
0005433252106	25850	Business	18900.00
0005434908816	25850	Business	18900.00
0005433252010	25850	Business	18900.00
0005433252103	25850	Business	18900.00
0005433252031	25850	Business	18900.00
0005433252078	25850	Business	18900.00
0005434908801	25850	Economy	6300.00
0005433252114	25850	Economy	6300.00
0005434908802	25850	Economy	6300.00
0005433252147	25850	Economy	6300.00
0005434908803	25850	Economy	6300.00
0005434908819	25850	Economy	6300.00
0005433252135	25850	Economy	6300.00
0005433252130	25850	Economy	6300.00
0005433252109	25850	Economy	6300.00
0005434908788	25850	Economy	6900.00
0005433252126	25850	Economy	6900.00
0005434908813	25850	Economy	6900.00
0005433252094	25850	Economy	6300.00
0005434908799	25850	Economy	6300.00
0005433252255	25850	Economy	6300.00
0005433252069	25850	Economy	6300.00
0005434908794	25850	Economy	6300.00
0005434908780	25850	Economy	6300.00
0005433252138	25850	Economy	6300.00
0005434908785	25850	Economy	6300.00
0005434908806	25850	Economy	6300.00
0005434908811	25850	Economy	6300.00
0005434908782	25850	Economy	6300.00
0005434908798	25850	Economy	6300.00
0005433252102	25850	Economy	6300.00
0005434908793	25850	Economy	6300.00
0005434908807	25850	Economy	6300.00
0005433252128	25850	Economy	6300.00
0005434908781	25850	Economy	6300.00
0005433252139	25850	Economy	6300.00
0005433252182	25850	Economy	6300.00
0005433252067	25850	Economy	6300.00
0005433252136	25850	Economy	6300.00
0005433252100	25850	Economy	6300.00
0005434908795	25850	Economy	6300.00
0005434908808	25850	Economy	6300.00
0005434908800	25850	Economy	6300.00
0005434908810	25850	Economy	6300.00
0005434908818	25850	Economy	6300.00
0005433252095	25850	Economy	6300.00
0005433252127	25850	Economy	6300.00
0005434908796	25850	Economy	6300.00
0005434908789	25850	Economy	6300.00
0005434908792	25850	Economy	6300.00
0005434908784	25850	Economy	6300.00
0005434908903	25850	Economy	6300.00
0005434908812	25850	Economy	6300.00
0005433252068	25850	Economy	6300.00
0005433252108	25850	Economy	6300.00
0005433252030	25850	Economy	6300.00
0005434908787	25850	Economy	6300.00
0005433252101	25850	Economy	6300.00
0005434908797	25850	Economy	6300.00
0005433252280	25850	Economy	6300.00
0005434908805	25850	Economy	6300.00
0005433252073	25850	Economy	6300.00
0005434908817	25850	Economy	6300.00
0005433252169	25850	Economy	6300.00
0005433252099	25850	Economy	6300.00
0005434908804	25850	Economy	6300.00
0005434908814	25850	Economy	6300.00
0005433252120	25850	Economy	6300.00
0005433252176	25850	Economy	6300.00
0005433252093	25850	Economy	6300.00
0005434908815	25850	Economy	6300.00
0005434908786	25850	Economy	6300.00
0005433252009	25850	Economy	6300.00
0005434908783	25850	Economy	6300.00
0005433252098	25850	Economy	6300.00
0005434908791	25850	Economy	6300.00
0005434908790	25850	Economy	6300.00
0005434908809	25850	Economy	6300.00
0005433815576	9186	Economy	18100.00
0005433815575	9186	Economy	18100.00
0005433815574	9186	Economy	18100.00
0005433815577	9186	Economy	18100.00
0005433009933	14162	Business	52300.00
0005433009917	14162	Business	52300.00
0005433810627	14162	Business	52300.00
0005433810621	14162	Business	52300.00
0005433810653	14162	Economy	17400.00
0005433009940	14162	Economy	17400.00
0005433009927	14162	Economy	17400.00
0005433009939	14162	Economy	17400.00
0005433009938	14162	Economy	17400.00
0005433009924	14162	Economy	17400.00
0005433810642	14162	Economy	19200.00
0005433009921	14162	Economy	19200.00
0005433009936	14162	Economy	17400.00
0005433009941	14162	Economy	17400.00
0005433810632	14162	Economy	17400.00
0005433009934	14162	Economy	17400.00
0005433009937	14162	Economy	17400.00
0005433810639	14162	Economy	17400.00
0005433009932	14162	Economy	17400.00
0005433009930	14162	Economy	17400.00
0005433810643	14162	Economy	17400.00
0005433009920	14162	Economy	17400.00
0005433009935	14162	Economy	17400.00
0005433009922	14162	Economy	17400.00
0005433009923	14162	Economy	17400.00
0005433009931	14162	Economy	17400.00
0005433810647	14162	Economy	17400.00
0005433009918	14162	Economy	17400.00
0005433810637	14162	Economy	17400.00
0005433009928	14162	Economy	17400.00
0005433009926	14162	Economy	17400.00
0005433009929	14162	Economy	17400.00
0005433009925	14162	Economy	17400.00
0005433009919	14162	Economy	17400.00
0005433009942	14162	Economy	17400.00
0005433009478	22838	Business	52300.00
0005433009648	22838	Business	52300.00
0005433810738	22838	Business	52300.00
0005433810751	22838	Business	52300.00
0005433009583	22838	Business	52300.00
0005433009667	22838	Business	52300.00
0005433009713	22838	Business	52300.00
0005433009668	22838	Economy	17400.00
0005433009649	22838	Economy	17400.00
0005433009808	22838	Economy	17400.00
0005433009700	22838	Economy	17400.00
0005433009482	22838	Economy	17400.00
0005433009425	22838	Economy	17400.00
0005433009809	22838	Economy	17400.00
0005433009580	22838	Economy	17400.00
0005433810750	22838	Economy	19200.00
0005433810749	22838	Economy	19200.00
0005433009516	22838	Economy	19200.00
0005433009613	22838	Economy	19200.00
0005433009552	22838	Economy	17400.00
0005433009483	22838	Economy	17400.00
0005433009744	22838	Economy	17400.00
0005433009594	22838	Economy	17400.00
0005433810748	22838	Economy	17400.00
0005433009565	22838	Economy	17400.00
0005433009655	22838	Economy	17400.00
0005433009469	22838	Economy	17400.00
0005433810743	22838	Economy	17400.00
0005433009595	22838	Economy	17400.00
0005433810737	22838	Economy	17400.00
0005433009704	22838	Economy	17400.00
0005433009438	22838	Economy	17400.00
0005433009628	22838	Economy	17400.00
0005433009550	22838	Economy	17400.00
0005433810742	22838	Economy	17400.00
0005433810741	22838	Economy	17400.00
0005433810732	22838	Economy	17400.00
0005433810733	22838	Economy	17400.00
0005433009745	22838	Economy	17400.00
0005433009283	22838	Economy	17400.00
0005433009551	22838	Economy	17400.00
0005433009509	22838	Economy	17400.00
0005433810731	22838	Economy	17400.00
0005433009541	22838	Economy	17400.00
0005433009451	22838	Economy	17400.00
0005433009607	22838	Economy	17400.00
0005433009643	22838	Economy	17400.00
0005433810734	22838	Economy	17400.00
0005433009508	22838	Economy	17400.00
0005433810747	22838	Economy	17400.00
0005433810744	22838	Economy	17400.00
0005433009515	22838	Economy	17400.00
0005433810745	22838	Economy	17400.00
0005433009676	22838	Economy	17400.00
0005433810740	22838	Economy	17400.00
0005433009646	22838	Economy	17400.00
0005433810735	22838	Economy	17400.00
0005433810746	22838	Economy	17400.00
0005433810739	22838	Economy	17400.00
0005433009617	22838	Economy	17400.00
0005433009497	22838	Economy	17400.00
0005433810736	22838	Economy	17400.00
0005433009452	22838	Economy	17400.00
0005433009532	22838	Economy	17400.00
0005433009368	22838	Economy	17400.00
0005434926433	14945	Business	22900.00
0005434926418	14945	Business	22900.00
0005434926415	14945	Business	22900.00
0005434926394	14945	Business	22900.00
0005434926437	14945	Business	22900.00
0005434926365	14945	Economy	7600.00
0005434926455	14945	Economy	7600.00
0005434926439	14945	Economy	7600.00
0005434926416	14945	Economy	8400.00
0005434926354	14945	Economy	8400.00
0005434926432	14945	Economy	7600.00
0005434926414	14945	Economy	7600.00
0005434926407	14945	Economy	7600.00
0005434926430	14945	Economy	7600.00
0005434926413	14945	Economy	7600.00
0005434926434	14945	Economy	7600.00
0005434926353	14945	Economy	7600.00
0005434926435	14945	Economy	7600.00
0005434926380	14945	Economy	7600.00
0005434926391	14945	Economy	7600.00
0005434926436	14945	Economy	7600.00
0005434926453	14945	Economy	7600.00
0005434926406	14945	Economy	7600.00
0005434926368	14945	Economy	7600.00
0005434926454	14945	Economy	7600.00
0005434926246	14945	Economy	7600.00
0005434926364	14945	Economy	7600.00
0005434926392	14945	Economy	7600.00
0005434926408	14945	Economy	7600.00
0005434926465	14945	Economy	7600.00
0005434926371	14945	Economy	7600.00
0005434926348	14945	Economy	7600.00
0005434926771	20519	Business	22900.00
0005434926769	20519	Business	22900.00
0005434926794	20519	Business	22900.00
0005434926763	20519	Business	22900.00
0005434926772	20519	Business	22900.00
0005434926785	20519	Economy	7600.00
0005434926781	20519	Economy	7600.00
0005434926767	20519	Economy	8400.00
0005434926755	20519	Economy	8400.00
0005434926791	20519	Economy	8400.00
0005434926774	20519	Economy	7600.00
0005434926788	20519	Economy	7600.00
0005434926761	20519	Economy	7600.00
0005434926776	20519	Economy	7600.00
0005434926790	20519	Economy	7600.00
0005434926793	20519	Economy	7600.00
0005434926786	20519	Economy	7600.00
0005434926789	20519	Economy	7600.00
0005434926762	20519	Economy	7600.00
0005434926779	20519	Economy	7600.00
0005434926753	20519	Economy	7600.00
0005434926757	20519	Economy	7600.00
0005434926766	20519	Economy	7600.00
0005434926759	20519	Economy	7600.00
0005434926782	20519	Economy	7600.00
0005434926778	20519	Economy	7600.00
0005434926775	20519	Economy	7600.00
0005434926765	20519	Economy	7600.00
0005434926758	20519	Economy	7600.00
0005434926792	20519	Economy	7600.00
0005434926760	20519	Economy	7600.00
0005434926764	20519	Economy	7600.00
0005434926780	20519	Economy	7600.00
0005434926777	20519	Economy	7600.00
0005434926768	20519	Economy	7600.00
0005434926784	20519	Economy	7600.00
0005434926773	20519	Economy	7600.00
0005434926754	20519	Economy	7600.00
0005434926770	20519	Economy	7600.00
0005434926756	20519	Economy	7600.00
0005434926783	20519	Economy	7600.00
0005434926787	20519	Economy	7600.00
0005435999661	15803	Economy	8900.00
0005435999662	15803	Economy	8900.00
0005435999613	15803	Economy	8900.00
0005435999591	15803	Economy	8100.00
0005435999572	15803	Economy	8100.00
0005435488460	15803	Economy	8100.00
0005435999648	15803	Economy	8100.00
0005435488456	15803	Economy	8100.00
0005435999663	15803	Economy	8100.00
0005435488464	15803	Economy	8100.00
0005435488463	15803	Economy	8100.00
0005435999623	15803	Economy	8100.00
0005435488455	15803	Economy	8100.00
0005435488454	15803	Economy	8100.00
0005435999670	15803	Economy	8100.00
0005435999595	15803	Economy	8100.00
0005435488459	15803	Economy	8100.00
0005435488453	15803	Economy	8100.00
0005435999616	15803	Economy	8100.00
0005435488457	15803	Economy	8100.00
0005435999630	15803	Economy	8100.00
0005435999573	15803	Economy	8100.00
0005435999646	15803	Economy	8100.00
0005435999590	15803	Economy	8100.00
0005435999571	15803	Economy	8100.00
0005435488461	15803	Economy	8100.00
0005435488458	15803	Economy	8100.00
0005435488462	15803	Economy	8100.00
0005435488465	15803	Economy	8100.00
0005435999594	15803	Economy	8100.00
0005435488291	19719	Economy	8900.00
0005435999809	19719	Economy	8900.00
0005435999807	19719	Economy	8900.00
0005435999803	19719	Economy	8900.00
0005435999808	19719	Economy	8100.00
0005435488273	19719	Economy	8100.00
0005435999866	19719	Economy	8100.00
0005435488193	19719	Economy	8100.00
0005435488257	19719	Economy	8100.00
0005435488180	19719	Economy	8100.00
0005435999867	19719	Economy	8100.00
0005435999797	19719	Economy	8100.00
0005435999813	19719	Economy	8100.00
0005435999800	19719	Economy	8100.00
0005435999804	19719	Economy	8100.00
0005435999805	19719	Economy	8100.00
0005435999810	19719	Economy	8100.00
0005435999868	19719	Economy	8100.00
0005435488181	19719	Economy	8100.00
0005435488271	19719	Economy	8100.00
0005435488234	19719	Economy	8100.00
0005435488272	19719	Economy	8100.00
0005435999796	19719	Economy	8100.00
0005435999811	19719	Economy	8100.00
0005435999865	19719	Economy	8100.00
0005435999802	19719	Economy	8100.00
0005435488141	19719	Economy	8100.00
0005435999812	19719	Economy	8100.00
0005435488245	19719	Economy	8100.00
0005435488248	19719	Economy	8100.00
0005435999815	19719	Economy	8100.00
0005435999801	19719	Economy	8100.00
0005435999814	19719	Economy	8100.00
0005435488194	19719	Economy	8100.00
0005435999798	19719	Economy	8100.00
0005435488239	19719	Economy	8100.00
0005435488215	19719	Economy	8100.00
0005435999806	19719	Economy	8100.00
0005435999795	19719	Economy	8100.00
0005435488259	19719	Economy	8100.00
0005435488274	19719	Economy	8100.00
0005435999799	19719	Economy	8100.00
0005435473160	5974	Business	199300.00
0005435840256	5974	Business	199300.00
0005435840253	5974	Business	199300.00
0005435473133	5974	Business	199300.00
0005432658652	5974	Business	199300.00
0005432537096	5974	Business	199300.00
0005432142342	5974	Business	199300.00
0005435473120	5974	Business	199300.00
0005435840262	5974	Business	199300.00
0005435840257	5974	Business	199300.00
0005435840261	5974	Economy	66400.00
0005432537100	5974	Economy	66400.00
0005435473162	5974	Economy	66400.00
0005435473142	5974	Economy	73100.00
0005435617239	5974	Economy	66400.00
0005435473103	5974	Economy	66400.00
0005435473168	5974	Economy	66400.00
0005435840263	5974	Economy	66400.00
0005435840260	5974	Economy	66400.00
0005435473163	5974	Economy	66400.00
0005435473187	5974	Economy	66400.00
0005435473134	5974	Economy	66400.00
0005435473159	5974	Economy	66400.00
0005435840259	5974	Economy	66400.00
0005435473147	5974	Economy	66400.00
0005435473188	5974	Economy	66400.00
0005432537095	5974	Economy	66400.00
0005435840252	5974	Economy	66400.00
0005435473095	5974	Economy	66400.00
0005435617240	5974	Economy	66400.00
0005435473132	5974	Economy	66400.00
0005435473094	5974	Economy	66400.00
0005435473161	5974	Economy	66400.00
0005435473121	5974	Economy	66400.00
0005435473141	5974	Economy	66400.00
0005435473186	5974	Economy	66400.00
0005435840251	5974	Economy	66400.00
0005435840255	5974	Economy	66400.00
0005432660881	5974	Economy	66400.00
0005435473171	5974	Economy	66400.00
0005435840258	5974	Economy	66400.00
0005435473166	5974	Economy	66400.00
0005435473096	5974	Economy	66400.00
0005435840254	5974	Economy	66400.00
0005435617238	5974	Economy	66400.00
0005432660882	5974	Economy	66400.00
0005432664178	18047	Business	199300.00
0005435840079	18047	Business	199300.00
0005432667497	18047	Business	199300.00
0005435840045	18047	Business	199300.00
0005435839919	18047	Business	199300.00
0005435839987	18047	Business	199300.00
0005435840014	18047	Business	199300.00
0005435840142	18047	Business	199300.00
0005435840058	18047	Economy	66400.00
0005435840167	18047	Economy	66400.00
0005435840146	18047	Economy	66400.00
0005435839932	18047	Economy	73100.00
0005435840078	18047	Economy	73100.00
0005435840119	18047	Economy	73100.00
0005435840001	18047	Economy	66400.00
0005435839984	18047	Economy	66400.00
0005432664182	18047	Economy	66400.00
0005435840004	18047	Economy	66400.00
0005435473279	18047	Economy	66400.00
0005435473282	18047	Economy	66400.00
0005435473278	18047	Economy	66400.00
0005435840027	18047	Economy	66400.00
0005435473280	18047	Economy	66400.00
0005435840026	18047	Economy	66400.00
0005435473276	18047	Economy	66400.00
0005432664176	18047	Economy	66400.00
0005432537120	18047	Economy	66400.00
0005435840108	18047	Economy	66400.00
0005435839983	18047	Economy	66400.00
0005435840135	18047	Economy	66400.00
0005435840057	18047	Economy	66400.00
0005435840107	18047	Economy	66400.00
0005435840056	18047	Economy	66400.00
0005435840169	18047	Economy	66400.00
0005435473281	18047	Economy	66400.00
0005435840064	18047	Economy	66400.00
0005432667488	18047	Economy	66400.00
0005435473277	18047	Economy	66400.00
0005435473275	18047	Economy	66400.00
0005432667496	18047	Economy	66400.00
0005435840147	18047	Economy	66400.00
0005435840168	18047	Economy	66400.00
0005435839971	18047	Economy	66400.00
0005435839920	18047	Economy	66400.00
0005435839970	18047	Economy	66400.00
0005435840008	18047	Economy	66400.00
0005432664177	18047	Economy	66400.00
0005435839933	18047	Economy	66400.00
0005435839955	18047	Economy	66400.00
0005435839972	18047	Economy	66400.00
0005435840118	18047	Economy	66400.00
0005435104294	23012	Business	15700.00
0005435104312	23012	Business	15700.00
0005435104299	23012	Business	15700.00
0005433286017	23012	Business	15700.00
0005435104310	23012	Business	15700.00
0005435104296	23012	Business	15700.00
0005433286009	23012	Business	15700.00
0005435104315	23012	Business	15700.00
0005435104302	23012	Business	15700.00
0005435104289	23012	Economy	5200.00
0005433285856	23012	Economy	5200.00
0005433285932	23012	Economy	5200.00
0005435104287	23012	Economy	5200.00
0005433285929	23012	Economy	5200.00
0005435104304	23012	Economy	5200.00
0005433286016	23012	Economy	5200.00
0005433285813	23012	Economy	5200.00
0005433286010	23012	Economy	5200.00
0005433286028	23012	Economy	5200.00
0005433285903	23012	Economy	5200.00
0005435104309	23012	Economy	5200.00
0005433285991	23012	Economy	5200.00
0005433285879	23012	Economy	5200.00
0005433285920	23012	Economy	5200.00
0005435104307	23012	Economy	5200.00
0005433285885	23012	Economy	5200.00
0005433285982	23012	Economy	5200.00
0005435104313	23012	Economy	5200.00
0005435104282	23012	Economy	5200.00
0005433285933	23012	Economy	5200.00
0005433286065	23012	Economy	5200.00
0005435104316	23012	Economy	5200.00
0005433286078	23012	Economy	5200.00
0005435104301	23012	Economy	5200.00
0005435104286	23012	Economy	5200.00
0005435104298	23012	Economy	5200.00
0005435104300	23012	Economy	5700.00
0005433285848	23012	Economy	5700.00
0005433285916	23012	Economy	5700.00
0005435104288	23012	Economy	5200.00
0005435104295	23012	Economy	5200.00
0005433286086	23012	Economy	5200.00
0005433285913	23012	Economy	5200.00
0005433286055	23012	Economy	5200.00
0005433285935	23012	Economy	5200.00
0005433286034	23012	Economy	5200.00
0005433285930	23012	Economy	5200.00
0005433285931	23012	Economy	5200.00
0005433286018	23012	Economy	5200.00
0005433286097	23012	Economy	5200.00
0005433286021	23012	Economy	5200.00
0005435104306	23012	Economy	5200.00
0005433286054	23012	Economy	5200.00
0005435104290	23012	Economy	5200.00
0005435104292	23012	Economy	5200.00
0005435104311	23012	Economy	5200.00
0005433285969	23012	Economy	5200.00
0005433285814	23012	Economy	5200.00
0005435104297	23012	Economy	5200.00
0005433285912	23012	Economy	5200.00
0005435104314	23012	Economy	5200.00
0005433286063	23012	Economy	5200.00
0005435104293	23012	Economy	5200.00
0005435104305	23012	Economy	5200.00
0005435104285	23012	Economy	5200.00
0005435104308	23012	Economy	5200.00
0005435104291	23012	Economy	5200.00
0005435104284	23012	Economy	5200.00
0005433285934	23012	Economy	5200.00
0005435104303	23012	Economy	5200.00
0005433286024	23012	Economy	5200.00
0005433285890	23012	Economy	5200.00
0005433285995	23012	Economy	5200.00
0005435104283	23012	Economy	5200.00
0005433285921	23012	Economy	5200.00
0005433286066	23012	Economy	5200.00
0005433285902	23012	Economy	5200.00
0005435104317	23012	Economy	5200.00
0005433285915	23012	Economy	5200.00
0005433286193	32065	Business	15700.00
0005433286198	32065	Business	15700.00
0005435104114	32065	Economy	5200.00
0005435104080	32065	Economy	5200.00
0005433286195	32065	Economy	5200.00
0005433286200	32065	Economy	5200.00
0005433286194	32065	Economy	5200.00
0005433286190	32065	Economy	5200.00
0005435104070	32065	Economy	5200.00
0005435104071	32065	Economy	5200.00
0005435104076	32065	Economy	5200.00
0005435104099	32065	Economy	5200.00
0005433286189	32065	Economy	5700.00
0005435104090	32065	Economy	5200.00
0005433286197	32065	Economy	5200.00
0005435104115	32065	Economy	5200.00
0005435104066	32065	Economy	5200.00
0005435104075	32065	Economy	5200.00
0005435104116	32065	Economy	5200.00
0005435104104	32065	Economy	5200.00
0005435104100	32065	Economy	5200.00
0005435104072	32065	Economy	5200.00
0005433286191	32065	Economy	5200.00
0005433286199	32065	Economy	5200.00
0005433286192	32065	Economy	5200.00
0005435104102	32065	Economy	5200.00
0005435104081	32065	Economy	5200.00
0005435104091	32065	Economy	5200.00
0005433286196	32065	Economy	5200.00
0005435104101	32065	Economy	5200.00
0005435104103	32065	Economy	5200.00
0005435104073	32065	Economy	5200.00
0005435104108	32065	Economy	5200.00
0005435104122	32065	Economy	5200.00
0005435104074	32065	Economy	5200.00
0005433286188	32065	Economy	5200.00
0005434069008	30610	Business	42100.00
0005432530272	30610	Business	42100.00
0005432531289	30610	Business	42100.00
0005435215492	30610	Business	42100.00
0005432429010	30610	Business	42100.00
0005432535939	30610	Business	42100.00
0005432530810	30610	Business	42100.00
0005435283533	30610	Business	42100.00
0005432531288	30610	Business	42100.00
0005432531022	30610	Business	42100.00
0005432530990	30610	Business	42100.00
0005432530609	30610	Business	42100.00
0005435215488	30610	Business	42100.00
0005434068965	30610	Business	42100.00
0005434069131	30610	Business	42100.00
0005432531042	30610	Business	42100.00
0005432530978	30610	Business	42100.00
0005434068937	30610	Business	42100.00
0005435215483	30610	Business	42100.00
0005432530206	30610	Comfort	23900.00
0005432531253	30610	Comfort	23900.00
0005434069009	30610	Comfort	23900.00
0005432530627	30610	Comfort	23900.00
0005435215498	30610	Comfort	23900.00
0005432535940	30610	Comfort	23900.00
0005432531096	30610	Comfort	23900.00
0005432530614	30610	Comfort	23900.00
0005432530747	30610	Comfort	23900.00
0005432530484	30610	Comfort	23900.00
0005435215496	30610	Comfort	23900.00
0005435215506	30610	Comfort	23900.00
0005434069034	30610	Comfort	23900.00
0005432530880	30610	Comfort	23900.00
0005434069149	30610	Comfort	23900.00
0005432531375	30610	Comfort	23900.00
0005435215487	30610	Comfort	23900.00
0005434068813	30610	Comfort	23900.00
0005434068987	30610	Comfort	23900.00
0005432530739	30610	Comfort	23900.00
0005432530915	30610	Comfort	23900.00
0005432530738	30610	Comfort	23900.00
0005432531000	30610	Comfort	23900.00
0005432530526	30610	Comfort	23900.00
0005432530284	30610	Comfort	23900.00
0005434068887	30610	Comfort	23900.00
0005432530610	30610	Comfort	23900.00
0005434068838	30610	Comfort	23900.00
0005432531046	30610	Comfort	23900.00
0005432531175	30610	Comfort	23900.00
0005432530620	30610	Economy	14000.00
0005435215484	30610	Economy	14000.00
0005432531037	30610	Economy	14000.00
0005435215509	30610	Economy	14000.00
0005435283532	30610	Economy	14000.00
0005432530946	30610	Economy	14000.00
0005434069103	30610	Economy	14000.00
0005432428992	30610	Economy	14000.00
0005432537105	30610	Economy	14000.00
0005435283530	30610	Economy	14000.00
0005432531054	30610	Economy	14000.00
0005435283523	30610	Economy	14000.00
0005432530749	30610	Economy	14000.00
0005432531094	30610	Economy	14000.00
0005432530952	30610	Economy	14000.00
0005432530944	30610	Economy	14000.00
0005434068814	30610	Economy	14000.00
0005432159988	30610	Economy	14000.00
0005432530965	30610	Economy	14000.00
0005432531191	30610	Economy	14000.00
0005432429009	30610	Economy	14000.00
0005432530966	30610	Economy	14000.00
0005432428993	30610	Economy	14000.00
0005435215494	30610	Economy	14000.00
0005435215505	30610	Economy	14000.00
0005435283520	30610	Economy	14000.00
0005432531444	30610	Economy	14000.00
0005434069106	30610	Economy	14000.00
0005432530963	30610	Economy	14000.00
0005434069199	30610	Economy	14000.00
0005432530855	30610	Economy	14000.00
0005435283534	30610	Economy	14000.00
0005432429011	30610	Economy	14000.00
0005432530801	30610	Economy	14000.00
0005432530491	30610	Economy	14000.00
0005432530583	30610	Economy	14000.00
0005432530964	30610	Economy	14000.00
0005432211720	30610	Economy	14000.00
0005432531073	30610	Economy	14000.00
0005432531226	30610	Economy	14000.00
0005435283521	30610	Economy	14000.00
0005432530434	30610	Economy	14000.00
0005434069092	30610	Economy	14000.00
0005434068785	30610	Economy	14000.00
0005435725739	30610	Economy	14000.00
0005435215497	30610	Economy	14000.00
0005432531290	30610	Economy	14000.00
0005432537104	30610	Economy	14000.00
0005432530356	30610	Economy	14000.00
0005434069030	30610	Economy	14000.00
0005432530862	30610	Economy	14000.00
0005434069010	30610	Economy	14000.00
0005432530354	30610	Economy	14000.00
0005432530956	30610	Economy	14000.00
0005432530483	30610	Economy	14000.00
0005432530630	30610	Economy	14000.00
0005435215491	30610	Economy	14000.00
0005434068991	30610	Economy	15400.00
0005434068926	30610	Economy	14000.00
0005435283524	30610	Economy	15400.00
0005432530904	30610	Economy	15400.00
0005432530393	30610	Economy	14000.00
0005435215508	30610	Economy	14000.00
0005432530812	30610	Economy	15400.00
0005434069125	30610	Economy	15400.00
0005432531225	30610	Economy	14000.00
0005433656766	30610	Economy	14000.00
0005432531227	30610	Economy	14000.00
0005432531008	30610	Economy	14000.00
0005432531207	30610	Economy	14000.00
0005432530293	30610	Economy	14000.00
0005434069050	30610	Economy	14000.00
0005434068913	30610	Economy	14000.00
0005434069200	30610	Economy	14000.00
0005435215507	30610	Economy	14000.00
0005432537103	30610	Economy	14000.00
0005432211721	30610	Economy	14000.00
0005432530456	30610	Economy	14000.00
0005432530389	30610	Economy	14000.00
0005432530631	30610	Economy	14000.00
0005432530974	30610	Economy	14000.00
0005432537114	30610	Economy	14000.00
0005432531006	30610	Economy	14000.00
0005432533349	30610	Economy	14000.00
0005432531007	30610	Economy	14000.00
0005434069241	30610	Economy	14000.00
0005432211722	30610	Economy	14000.00
0005432530535	30610	Economy	14000.00
0005434069033	30610	Economy	14000.00
0005432530283	30610	Economy	14000.00
0005435215502	30610	Economy	14000.00
0005434069035	30610	Economy	14000.00
0005432531097	30610	Economy	14000.00
0005435215489	30610	Economy	14000.00
0005434069141	30610	Economy	14000.00
0005434069118	30610	Economy	14000.00
0005434068786	30610	Economy	14000.00
0005432530937	30610	Economy	14000.00
0005432533346	30610	Economy	14000.00
0005435215503	30610	Economy	14000.00
0005433656767	30610	Economy	14000.00
0005432159989	30610	Economy	14000.00
0005432531159	30610	Economy	14000.00
0005434069305	30610	Economy	14000.00
0005434068874	30610	Economy	14000.00
0005432530876	30610	Economy	14000.00
0005432531082	30610	Economy	14000.00
0005434068718	30610	Economy	14000.00
0005432530798	30610	Economy	14000.00
0005434069175	30610	Economy	14000.00
0005434069198	30610	Economy	14000.00
0005434069012	30610	Economy	14000.00
0005432531072	30610	Economy	14000.00
0005434069076	30610	Economy	14000.00
0005434069119	30610	Economy	14000.00
0005432159991	30610	Economy	14000.00
0005432531306	30610	Economy	14000.00
0005432211723	30610	Economy	14000.00
0005432530333	30610	Economy	14000.00
0005435215482	30610	Economy	14000.00
0005432531151	30610	Economy	14000.00
0005432530731	30610	Economy	14000.00
0005435215501	30610	Economy	14000.00
0005432530867	30610	Economy	14000.00
0005435283525	30610	Economy	14000.00
0005432531197	30610	Economy	14000.00
0005435215485	30610	Economy	14000.00
0005432531234	30610	Economy	14000.00
0005432531093	30610	Economy	14000.00
0005432533357	30610	Economy	14000.00
0005432530957	30610	Economy	14000.00
0005432531228	30610	Economy	14000.00
0005435283522	30610	Economy	14000.00
0005432530984	30610	Economy	14000.00
0005434068997	30610	Economy	14000.00
0005435283531	30610	Economy	14000.00
0005432531298	30610	Economy	14000.00
0005434069091	30610	Economy	14000.00
0005432531074	30610	Economy	14000.00
0005432531230	30610	Economy	14000.00
0005432535949	30610	Economy	14000.00
0005435215500	30610	Economy	14000.00
0005434069046	30610	Economy	14000.00
0005434069045	30610	Economy	14000.00
0005432530405	30610	Economy	14000.00
0005435283526	30610	Economy	14000.00
0005432530938	30610	Economy	14000.00
0005432531490	30610	Economy	14000.00
0005432531083	30610	Economy	14000.00
0005435725740	30610	Economy	14000.00
0005434068794	30610	Economy	14000.00
0005432530849	30610	Economy	15400.00
0005434068708	30610	Economy	15400.00
0005432531160	30610	Economy	15400.00
0005432530997	30610	Economy	15400.00
0005434069104	30610	Economy	15400.00
0005432530989	30610	Economy	14000.00
0005434068974	30610	Economy	14000.00
0005435215490	30610	Economy	14000.00
0005432531374	30610	Economy	14000.00
0005432530968	30610	Economy	14000.00
0005435283529	30610	Economy	14000.00
0005434069132	30610	Economy	14000.00
0005434068640	30610	Economy	14000.00
0005432530750	30610	Economy	14000.00
0005434068793	30610	Economy	14000.00
0005432530759	30610	Economy	14000.00
0005435215481	30610	Economy	14000.00
0005432531235	30610	Economy	14000.00
0005435283528	30610	Economy	14000.00
0005432531445	30610	Economy	14000.00
0005432530758	30610	Economy	14000.00
0005432530746	30610	Economy	14000.00
0005432531152	30610	Economy	14000.00
0005432529791	30610	Economy	14000.00
0005434069051	30610	Economy	14000.00
0005432530410	30610	Economy	14000.00
0005435215499	30610	Economy	14000.00
0005432531112	30610	Economy	14000.00
0005432531053	30610	Economy	14000.00
0005432159990	30610	Economy	14000.00
0005435215495	30610	Economy	14000.00
0005435215486	30610	Economy	14000.00
0005432530988	30610	Economy	14000.00
0005435215504	30610	Economy	14000.00
0005435215493	30610	Economy	14000.00
0005432531489	30610	Economy	14000.00
0005432531305	30610	Economy	14000.00
0005434068925	30610	Economy	14000.00
0005432530967	30610	Economy	14000.00
0005435283519	30610	Economy	14000.00
0005432428994	30610	Economy	14000.00
0005432531196	30610	Economy	14000.00
0005434069147	30610	Economy	14000.00
0005432530383	30610	Economy	14000.00
0005432429006	30610	Economy	14000.00
0005435283527	30610	Economy	14000.00
0005432530971	30610	Economy	14000.00
0005434068914	30610	Economy	14000.00
0005432530875	30610	Economy	14000.00
0005432531367	30610	Economy	14000.00
0005432530357	30610	Economy	14000.00
0005432530848	30610	Economy	14000.00
0005432531206	30610	Economy	14000.00
0005432531126	30610	Economy	14000.00
0005432530619	30610	Economy	14000.00
0005432530353	30610	Economy	14000.00
0005432533350	30610	Economy	14000.00
0005432530945	30610	Economy	14000.00
0005434069117	30610	Economy	14000.00
0005434068912	30610	Economy	14000.00
0005432530345	30610	Economy	14000.00
0005432530732	30610	Economy	14000.00
0005432531174	30610	Economy	14000.00
0005432530499	30610	Economy	14000.00
0005432530854	30610	Economy	14000.00
0005432530390	30610	Economy	14000.00
0005432530787	30610	Economy	14000.00
0005432530856	30610	Economy	14000.00
0005432530435	30610	Economy	14000.00
0005434068812	30610	Economy	14000.00
0005432530384	30610	Economy	14000.00
0005432530726	30610	Economy	14000.00
0005432530973	30610	Economy	14000.00
0005432530551	30610	Economy	14000.00
0005434069101	30610	Economy	14000.00
0005432530550	30610	Economy	14000.00
0005435654088	24845	Business	9800.00
0005435654013	24845	Business	9800.00
0005435653778	24845	Business	9800.00
0005435653921	24845	Business	9800.00
0005433368968	24845	Business	9800.00
0005435654112	24845	Business	9800.00
0005435653823	24845	Business	9800.00
0005435653977	24845	Business	9800.00
0005435653947	24845	Economy	3300.00
0005435653909	24845	Economy	3300.00
0005433368966	24845	Economy	3300.00
0005435654027	24845	Economy	3300.00
0005435654111	24845	Economy	3300.00
0005435654106	24845	Economy	3300.00
0005435653972	24845	Economy	3300.00
0005435653943	24845	Economy	3600.00
0005435654015	24845	Economy	3600.00
0005435653734	24845	Economy	3600.00
0005435654008	24845	Economy	3300.00
0005435654030	24845	Economy	3300.00
0005435653776	24845	Economy	3300.00
0005435654038	24845	Economy	3300.00
0005433368973	24845	Economy	3300.00
0005435654029	24845	Economy	3300.00
0005435653996	24845	Economy	3300.00
0005435653933	24845	Economy	3300.00
0005433368967	24845	Economy	3300.00
0005435654056	24845	Economy	3300.00
0005435654039	24845	Economy	3300.00
0005435653777	24845	Economy	3300.00
0005435654053	24845	Economy	3300.00
0005435654179	24845	Economy	3300.00
0005435654037	24845	Economy	3300.00
0005433368975	24845	Economy	3300.00
0005433368969	24845	Economy	3300.00
0005435653822	24845	Economy	3300.00
0005433368970	24845	Economy	3300.00
0005435654235	24845	Economy	3300.00
0005435653809	24845	Economy	3300.00
0005435654065	24845	Economy	3300.00
0005435654090	24845	Economy	3300.00
0005433368971	24845	Economy	3300.00
0005435653861	24845	Economy	3300.00
0005433368976	24845	Economy	3300.00
0005435653810	24845	Economy	3300.00
0005435790413	24845	Economy	3300.00
0005435654032	24845	Economy	3300.00
0005435653907	24845	Economy	3300.00
0005435653932	24845	Economy	3300.00
0005435654346	24845	Economy	3300.00
0005435653860	24845	Economy	3300.00
0005435654080	24845	Economy	3300.00
0005435654201	24845	Economy	3300.00
0005435654236	24845	Economy	3300.00
0005435653843	24845	Economy	3300.00
0005435653968	24845	Economy	3300.00
0005433368972	24845	Economy	3300.00
0005435653927	24845	Economy	3300.00
0005435653953	24845	Economy	3300.00
0005435654051	24845	Economy	3300.00
0005435653821	24845	Economy	3300.00
0005435654028	24845	Economy	3300.00
0005435654202	24845	Economy	3300.00
0005435654066	24845	Economy	3300.00
0005435653971	24845	Economy	3300.00
0005433368974	24845	Economy	3300.00
0005435654055	24845	Economy	3300.00
0005435653824	24845	Economy	3300.00
0005435654016	24845	Economy	3300.00
0005435653842	24845	Economy	3300.00
0005435654050	24845	Economy	3300.00
0005434980656	2029	Economy	10500.00
0005435801780	2029	Economy	10500.00
0005434980657	2029	Economy	9500.00
0005434980662	2029	Economy	9500.00
0005434980659	2029	Economy	9500.00
0005434980660	2029	Economy	9500.00
0005434980658	2029	Economy	9500.00
0005434980661	2029	Economy	9500.00
0005434980655	2029	Economy	9500.00
0005434980663	2029	Economy	9500.00
0005434980311	23574	Economy	10500.00
0005434980383	23574	Economy	10500.00
0005434980401	23574	Economy	9500.00
0005434980385	23574	Economy	9500.00
0005434980430	23574	Economy	9500.00
0005434980349	23574	Economy	9500.00
0005434980319	23574	Economy	9500.00
0005434980387	23574	Economy	9500.00
0005434980386	23574	Economy	9500.00
0005435801761	23574	Economy	9500.00
0005434980382	23574	Economy	9500.00
0005434980432	23574	Economy	9500.00
0005434980337	23574	Economy	9500.00
0005434980438	23574	Economy	9500.00
0005434980437	23574	Economy	9500.00
0005434980361	23574	Economy	9500.00
0005434980335	23574	Economy	9500.00
0005434980357	23574	Economy	9500.00
0005434980512	23574	Economy	9500.00
0005434980513	23574	Economy	9500.00
0005434980539	23574	Economy	9500.00
0005434980398	23574	Economy	9500.00
0005434980287	23574	Economy	9500.00
0005434980431	23574	Economy	9500.00
0005434980415	23574	Economy	9500.00
0005434980538	23574	Economy	9500.00
0005434980397	23574	Economy	9500.00
0005435801769	23574	Economy	9500.00
0005434980318	23574	Economy	9500.00
0005434980414	23574	Economy	9500.00
0005434980288	23574	Economy	9500.00
0005435801762	23574	Economy	9500.00
0005434980312	23574	Economy	9500.00
0005434980348	23574	Economy	9500.00
0005434980375	23574	Economy	9500.00
0005434952636	2611	Economy	5300.00
0005434952635	2611	Economy	5300.00
0005433256492	28286	Economy	5300.00
0005434952608	28286	Economy	5300.00
0005433256494	28286	Economy	5300.00
0005434952612	28286	Economy	5300.00
0005434952613	28286	Economy	5300.00
0005433256493	28286	Economy	5300.00
0005434952616	28286	Economy	5300.00
0005434952606	28286	Economy	5300.00
0005433256491	28286	Economy	5300.00
0005434952617	28286	Economy	5300.00
0005434139972	11952	Business	9700.00
0005435283576	11952	Business	9700.00
0005434140053	11952	Business	9700.00
0005434139691	11952	Business	9700.00
0005434140228	11952	Business	9700.00
0005434139594	11952	Business	9700.00
0005434140010	11952	Business	9700.00
0005435283584	11952	Business	9700.00
0005434140014	11952	Business	9700.00
0005434139891	11952	Business	9700.00
0005434140060	11952	Business	9700.00
0005434140008	11952	Economy	3200.00
0005434140145	11952	Economy	3200.00
0005434139631	11952	Economy	3200.00
0005435283583	11952	Economy	3200.00
0005434140337	11952	Economy	3200.00
0005434140047	11952	Economy	3200.00
0005434140137	11952	Economy	3200.00
0005434140260	11952	Economy	3200.00
0005434139870	11952	Economy	3200.00
0005434140118	11952	Economy	3200.00
0005434140017	11952	Economy	3500.00
0005435283574	11952	Economy	3500.00
0005434139902	11952	Economy	3500.00
0005434139849	11952	Economy	3500.00
0005434140336	11952	Economy	3500.00
0005434140202	11952	Economy	3200.00
0005434139324	11952	Economy	3200.00
0005434139789	11952	Economy	3200.00
0005434140034	11952	Economy	3200.00
0005435283590	11952	Economy	3200.00
0005434140120	11952	Economy	3200.00
0005434140242	11952	Economy	3200.00
0005434140184	11952	Economy	3200.00
0005435283579	11952	Economy	3200.00
0005434139950	11952	Economy	3200.00
0005434140009	11952	Economy	3200.00
0005434140144	11952	Economy	3200.00
0005434139873	11952	Economy	3200.00
0005435283589	11952	Economy	3200.00
0005434140179	11952	Economy	3200.00
0005435283585	11952	Economy	3200.00
0005434140259	11952	Economy	3200.00
0005434139698	11952	Economy	3200.00
0005434140339	11952	Economy	3200.00
0005435283586	11952	Economy	3200.00
0005435283587	11952	Economy	3200.00
0005434140138	11952	Economy	3200.00
0005435283582	11952	Economy	3200.00
0005434139781	11952	Economy	3200.00
0005434139821	11952	Economy	3200.00
0005434140016	11952	Economy	3200.00
0005435283578	11952	Economy	3200.00
0005434140098	11952	Economy	3200.00
0005434139940	11952	Economy	3200.00
0005434140032	11952	Economy	3200.00
0005434140371	11952	Economy	3200.00
0005434139711	11952	Economy	3200.00
0005434140161	11952	Economy	3200.00
0005434140090	11952	Economy	3200.00
0005434139911	11952	Economy	3200.00
0005434140121	11952	Economy	3200.00
0005434139869	11952	Economy	3200.00
0005434140185	11952	Economy	3200.00
0005434139610	11952	Economy	3200.00
0005434139819	11952	Economy	3200.00
0005435283588	11952	Economy	3200.00
0005435283580	11952	Economy	3200.00
0005434139952	11952	Economy	3200.00
0005434139991	11952	Economy	3200.00
0005434140097	11952	Economy	3200.00
0005434140062	11952	Economy	3200.00
0005434139894	11952	Economy	3200.00
0005434139912	11952	Economy	3200.00
0005434139785	11952	Economy	3200.00
0005434139848	11952	Economy	3200.00
0005434139816	11952	Economy	3200.00
0005435283577	11952	Economy	3200.00
0005435283581	11952	Economy	3200.00
0005434139965	11952	Economy	3200.00
0005434140051	11952	Economy	3200.00
0005434140338	11952	Economy	3200.00
0005435283575	11952	Economy	3200.00
0005434140094	11952	Economy	3200.00
0005434140146	11952	Economy	3200.00
0005434140018	11952	Economy	3200.00
0005434140546	28761	Business	9700.00
0005434140542	28761	Business	9700.00
0005434140509	28761	Business	9700.00
0005434140524	28761	Business	9700.00
0005434140521	28761	Business	9700.00
0005434140502	28761	Business	9700.00
0005434140544	28761	Business	9700.00
0005434140541	28761	Business	9700.00
0005434140523	28761	Economy	3200.00
0005434140538	28761	Economy	3200.00
0005434140510	28761	Economy	3200.00
0005434140505	28761	Economy	3200.00
0005434140516	28761	Economy	3200.00
0005434140527	28761	Economy	3200.00
0005434140525	28761	Economy	3500.00
0005434140543	28761	Economy	3500.00
0005434140532	28761	Economy	3500.00
0005434140517	28761	Economy	3200.00
0005434140520	28761	Economy	3200.00
0005434140506	28761	Economy	3200.00
0005434140530	28761	Economy	3200.00
0005434140537	28761	Economy	3200.00
0005434140508	28761	Economy	3200.00
0005434140503	28761	Economy	3200.00
0005434140548	28761	Economy	3200.00
0005434140539	28761	Economy	3200.00
0005434140533	28761	Economy	3200.00
0005434140514	28761	Economy	3200.00
0005434140535	28761	Economy	3200.00
0005434140528	28761	Economy	3200.00
0005434140536	28761	Economy	3200.00
0005434140504	28761	Economy	3200.00
0005434140513	28761	Economy	3200.00
0005434140515	28761	Economy	3200.00
0005434140534	28761	Economy	3200.00
0005434140507	28761	Economy	3200.00
0005434140526	28761	Economy	3200.00
0005434140512	28761	Economy	3200.00
0005434140519	28761	Economy	3200.00
0005434140540	28761	Economy	3200.00
0005434140518	28761	Economy	3200.00
0005434140545	28761	Economy	3200.00
0005434140511	28761	Economy	3200.00
0005434140547	28761	Economy	3200.00
0005434140531	28761	Economy	3200.00
0005434140522	28761	Economy	3200.00
0005434140529	28761	Economy	3200.00
0005434140501	28761	Economy	3200.00
0005434140549	28761	Economy	3200.00
0005433539118	6775	Economy	9900.00
0005433539119	6775	Economy	9900.00
0005433539120	6775	Economy	9900.00
0005435259850	6775	Economy	9900.00
0005433539117	6775	Economy	9900.00
0005435259861	6775	Economy	9900.00
0005433539040	24996	Economy	10900.00
0005433539034	24996	Economy	10900.00
0005433539071	24996	Economy	9900.00
0005435259887	24996	Economy	9900.00
0005433534537	24996	Economy	9900.00
0005433539057	24996	Economy	9900.00
0005433539063	24996	Economy	9900.00
0005433539058	24996	Economy	9900.00
0005435259885	24996	Economy	9900.00
0005433539039	24996	Economy	9900.00
0005433539076	24996	Economy	9900.00
0005433539064	24996	Economy	9900.00
0005433534544	24996	Economy	9900.00
0005435259886	24996	Economy	9900.00
0005433512190	839	Economy	14600.00
0005433512189	839	Economy	14600.00
0005433512160	16124	Economy	14600.00
0005433512142	16124	Economy	14600.00
0005433512159	16124	Economy	14600.00
0005433512146	16124	Economy	14600.00
0005433512143	16124	Economy	14600.00
0005432922638	16124	Economy	14600.00
0005433475831	4022	Economy	13500.00
0005435852624	4022	Economy	12300.00
0005435852632	4022	Economy	12300.00
0005435852642	4022	Economy	12300.00
0005433475832	4022	Economy	12300.00
0005433475828	4022	Economy	12300.00
0005435852625	4022	Economy	12300.00
0005435852623	4022	Economy	12300.00
0005435852631	4022	Economy	12300.00
0005433475827	4022	Economy	12300.00
0005435852639	4022	Economy	12300.00
0005433475829	4022	Economy	12300.00
0005433475826	4022	Economy	12300.00
0005435852630	4022	Economy	12300.00
0005435852633	4022	Economy	12300.00
0005433475830	4022	Economy	12300.00
0005435852637	4022	Economy	12300.00
0005435852641	4022	Economy	12300.00
0005435698155	3684	Economy	7900.00
0005434950660	3684	Economy	7900.00
0005435916233	3684	Economy	7900.00
0005435698158	3684	Economy	7900.00
0005435916222	3684	Economy	7200.00
0005435698159	3684	Economy	7200.00
0005435698160	3684	Economy	7200.00
0005434950661	3684	Economy	7200.00
0005435935109	3684	Economy	7200.00
0005435698156	3684	Economy	7200.00
0005435935103	3684	Economy	7200.00
0005435698157	3684	Economy	7200.00
0005435698162	3684	Economy	7200.00
0005435916221	3684	Economy	7200.00
0005435935099	3684	Economy	7200.00
0005435935115	3684	Economy	7200.00
0005435698161	3684	Economy	7200.00
0005435916223	3684	Economy	7200.00
0005435698163	3684	Economy	7200.00
0005435916234	3684	Economy	7200.00
0005435697975	16252	Economy	7900.00
0005435697820	16252	Economy	7900.00
0005435697896	16252	Economy	7200.00
0005435697935	16252	Economy	7200.00
0005435697914	16252	Economy	7200.00
0005434950626	16252	Economy	7200.00
0005435697822	16252	Economy	7200.00
0005434950637	16252	Economy	7200.00
0005435697949	16252	Economy	7200.00
0005435697922	16252	Economy	7200.00
0005435697826	16252	Economy	7200.00
0005435697941	16252	Economy	7200.00
0005435697895	16252	Economy	7200.00
0005435697921	16252	Economy	7200.00
0005435698015	16252	Economy	7200.00
0005435698032	16252	Economy	7200.00
0005434950635	16252	Economy	7200.00
0005435697961	16252	Economy	7200.00
0005435697950	16252	Economy	7200.00
0005435697942	16252	Economy	7200.00
0005435697960	16252	Economy	7200.00
0005435698016	16252	Economy	7200.00
0005435697998	16252	Economy	7200.00
0005435697971	16252	Economy	7200.00
0005435935134	16252	Economy	7200.00
0005434950606	16252	Economy	7200.00
0005434950625	16252	Economy	7200.00
0005435697984	16252	Economy	7200.00
0005435698031	16252	Economy	7200.00
0005435697867	16252	Economy	7200.00
0005434950636	16252	Economy	7200.00
0005435697959	16252	Economy	7200.00
0005435933586	16252	Economy	7200.00
0005435697962	16252	Economy	7200.00
0005435697970	16252	Economy	7200.00
0005435933585	16252	Economy	7200.00
0005435697932	16252	Economy	7200.00
0005435697918	16252	Economy	7200.00
0005435697943	16252	Economy	7200.00
0005435697821	16252	Economy	7200.00
0005435904716	3958	Economy	21300.00
0005435853656	3958	Economy	19300.00
0005432609850	3958	Economy	19300.00
0005434606935	3958	Economy	19300.00
0005433519592	3958	Economy	19300.00
0005435904715	3958	Economy	19300.00
0005432609851	3958	Economy	19300.00
0005433519591	3958	Economy	19300.00
0005433519590	3958	Economy	19300.00
0005432609849	3958	Economy	19300.00
0005435853653	3958	Economy	19300.00
0005432607680	3958	Economy	19300.00
0005434606896	22050	Economy	19300.00
0005434606908	22050	Economy	19300.00
0005434606907	22050	Economy	19300.00
0005433519558	22050	Economy	19300.00
0005433519557	22050	Economy	19300.00
0005434606906	22050	Economy	19300.00
0005433519565	22050	Economy	19300.00
0005434606909	22050	Economy	19300.00
0005435904728	22050	Economy	19300.00
0005435628829	684	Economy	3700.00
0005433349116	684	Economy	3700.00
0005433349110	684	Economy	3700.00
0005433349115	684	Economy	3700.00
0005433349163	15955	Economy	3700.00
0005435628811	15955	Economy	3700.00
0005433349165	15955	Economy	3700.00
0005433349164	15955	Economy	3700.00
0005435628810	15955	Economy	3700.00
0005434445322	17254	Economy	7100.00
0005433159356	17254	Economy	7100.00
0005434445321	17254	Economy	7100.00
0005433159361	17254	Economy	7100.00
0005433159360	17254	Economy	7100.00
0005434446588	17254	Economy	7100.00
0005434445305	17664	Economy	7100.00
0005434445295	17664	Economy	7100.00
0005434445290	17664	Economy	7100.00
0005435133193	7917	Economy	5400.00
0005435383252	7917	Economy	5400.00
0005435133191	7917	Economy	5400.00
0005435133190	7917	Economy	5400.00
0005435133189	7917	Economy	5400.00
0005435383243	7917	Economy	5400.00
0005435383293	7917	Economy	5400.00
0005435133192	7917	Economy	5400.00
0005435383292	7917	Economy	5400.00
0005435383307	33098	Economy	5900.00
0005435383308	33098	Economy	5400.00
0005435133152	33098	Economy	5400.00
0005435133095	33098	Economy	5400.00
0005435133071	33098	Economy	5400.00
0005435133156	33098	Economy	5400.00
0005435133107	33098	Economy	5400.00
0005435133090	33098	Economy	5400.00
0005435133108	33098	Economy	5400.00
0005435390381	7527	Economy	12500.00
0005435390412	7527	Economy	12500.00
0005435390380	7527	Economy	12500.00
0005435390393	7527	Economy	12500.00
0005435390396	7527	Economy	12500.00
0005435390395	7527	Economy	12500.00
0005435390392	7527	Economy	12500.00
0005435390379	7527	Economy	12500.00
0005435390382	7527	Economy	12500.00
0005435160551	29548	Economy	13800.00
0005435160554	29548	Economy	13800.00
0005435160543	29548	Economy	12500.00
0005435390437	29548	Economy	12500.00
0005435160563	29548	Economy	12500.00
0005435390436	29548	Economy	12500.00
0005435160553	29548	Economy	12500.00
0005435160600	29548	Economy	12500.00
0005435160587	29548	Economy	12500.00
0005435160549	29548	Economy	12500.00
0005435160562	29548	Economy	12500.00
0005435160504	29548	Economy	12500.00
0005435160560	29548	Economy	12500.00
0005435160550	29548	Economy	12500.00
0005435179022	18446	Economy	4900.00
0005432398288	18446	Economy	4900.00
0005432394191	18446	Economy	4900.00
0005432394186	18446	Economy	4900.00
0005432394187	18446	Economy	4900.00
0005432398289	18446	Economy	4900.00
0005432394206	18446	Economy	4900.00
0005432398287	18446	Economy	4900.00
0005435179023	18446	Economy	4900.00
0005432398265	18446	Economy	4900.00
0005435178539	18446	Economy	4900.00
0005435178527	27144	Economy	4900.00
0005435179414	27144	Economy	4900.00
0005432398300	27144	Economy	4900.00
0005435179412	27144	Economy	4900.00
0005432398301	27144	Economy	4900.00
0005434552916	9770	Economy	4400.00
0005434552917	9770	Economy	4400.00
0005435104345	6561	Business	48400.00
0005435104350	6561	Economy	16100.00
0005434505297	6561	Economy	16100.00
0005434505295	6561	Economy	16100.00
0005435104364	6561	Economy	16100.00
0005435104356	6561	Economy	16100.00
0005435104343	6561	Economy	17800.00
0005435104360	6561	Economy	17800.00
0005435104347	6561	Economy	17800.00
0005434505299	6561	Economy	16100.00
0005435104355	6561	Economy	16100.00
0005435104344	6561	Economy	16100.00
0005435104352	6561	Economy	16100.00
0005434505294	6561	Economy	16100.00
0005435104351	6561	Economy	16100.00
0005434505296	6561	Economy	16100.00
0005435104353	6561	Economy	16100.00
0005435104358	6561	Economy	16100.00
0005434505293	6561	Economy	16100.00
0005435104363	6561	Economy	16100.00
0005435104354	6561	Economy	16100.00
0005434505298	6561	Economy	16100.00
0005434505291	6561	Economy	16100.00
0005435104349	6561	Economy	16100.00
0005435104348	6561	Economy	16100.00
0005434505292	6561	Economy	16100.00
0005435104357	6561	Economy	16100.00
0005435104361	6561	Economy	16100.00
0005435104362	6561	Economy	16100.00
0005435104346	6561	Economy	16100.00
0005434505290	6561	Economy	16100.00
0005434505300	6561	Economy	16100.00
0005435104359	6561	Economy	16100.00
0005434504971	22662	Business	48400.00
0005435104076	22662	Business	48400.00
0005434504881	22662	Business	48400.00
0005434504987	22662	Business	48400.00
0005434504928	22662	Business	48400.00
0005435104122	22662	Business	48400.00
0005435104073	22662	Business	48400.00
0005434504706	22662	Economy	16100.00
0005435104090	22662	Economy	16100.00
0005434504847	22662	Economy	16100.00
0005435104074	22662	Economy	16100.00
0005434504926	22662	Economy	17800.00
0005435104102	22662	Economy	16100.00
0005434505034	22662	Economy	16100.00
0005434504760	22662	Economy	16100.00
0005434504924	22662	Economy	16100.00
0005434504927	22662	Economy	16100.00
0005435104081	22662	Economy	16100.00
0005434504959	22662	Economy	16100.00
0005434505010	22662	Economy	16100.00
0005434504998	22662	Economy	16100.00
0005434504908	22662	Economy	16100.00
0005434505053	22662	Economy	16100.00
0005435104116	22662	Economy	16100.00
0005434504790	22662	Economy	16100.00
0005435104101	22662	Economy	16100.00
0005434504898	22662	Economy	16100.00
0005435104071	22662	Economy	16100.00
0005435104100	22662	Economy	16100.00
0005435104099	22662	Economy	16100.00
0005434504829	22662	Economy	16100.00
0005435104115	22662	Economy	16100.00
0005435104066	22662	Economy	16100.00
0005435104103	22662	Economy	16100.00
0005434504943	22662	Economy	16100.00
0005434504789	22662	Economy	16100.00
0005434504909	22662	Economy	16100.00
0005435104070	22662	Economy	16100.00
0005435104104	22662	Economy	16100.00
0005434505052	22662	Economy	16100.00
0005435104075	22662	Economy	16100.00
0005434504869	22662	Economy	16100.00
0005435104091	22662	Economy	16100.00
0005434504848	22662	Economy	16100.00
0005434504761	22662	Economy	16100.00
0005435104072	22662	Economy	16100.00
0005434504916	22662	Economy	16100.00
0005435104114	22662	Economy	16100.00
0005434505002	22662	Economy	16100.00
0005434504999	22662	Economy	16100.00
0005434505009	22662	Economy	16100.00
0005435104108	22662	Economy	16100.00
0005434504917	22662	Economy	16100.00
0005435104080	22662	Economy	16100.00
0005434504844	22662	Economy	16100.00
0005435654458	1679	Business	50000.00
0005433368810	1679	Business	50000.00
0005433368685	1679	Business	50000.00
0005435654452	1679	Business	50000.00
0005433368791	1679	Business	50000.00
0005433368770	1679	Business	50000.00
0005433368844	1679	Business	50000.00
0005433368600	1679	Business	50000.00
0005435654467	1679	Business	50000.00
0005435654454	1679	Business	50000.00
0005433368853	1679	Business	50000.00
0005435654445	1679	Economy	16700.00
0005435654459	1679	Economy	16700.00
0005433368538	1679	Economy	16700.00
0005433368661	1679	Economy	16700.00
0005435654465	1679	Economy	16700.00
0005433368803	1679	Economy	16700.00
0005435654460	1679	Economy	16700.00
0005435654450	1679	Economy	18300.00
0005433368630	1679	Economy	18300.00
0005433368805	1679	Economy	18300.00
0005435654471	1679	Economy	18300.00
0005435654453	1679	Economy	16700.00
0005435654462	1679	Economy	16700.00
0005435654456	1679	Economy	16700.00
0005435654461	1679	Economy	16700.00
0005435654470	1679	Economy	16700.00
0005435654444	1679	Economy	16700.00
0005435654442	1679	Economy	16700.00
0005435654446	1679	Economy	16700.00
0005433368739	1679	Economy	16700.00
0005435654448	1679	Economy	16700.00
0005433368890	1679	Economy	16700.00
0005433368725	1679	Economy	16700.00
0005435654468	1679	Economy	16700.00
0005435654464	1679	Economy	16700.00
0005433368631	1679	Economy	16700.00
0005435654466	1679	Economy	16700.00
0005435654447	1679	Economy	16700.00
0005435654443	1679	Economy	16700.00
0005433368781	1679	Economy	16700.00
0005433368689	1679	Economy	16700.00
0005433368619	1679	Economy	16700.00
0005433368852	1679	Economy	16700.00
0005433368771	1679	Economy	16700.00
0005433368821	1679	Economy	16700.00
0005433368782	1679	Economy	16700.00
0005435654457	1679	Economy	16700.00
0005433368775	1679	Economy	16700.00
0005435654473	1679	Economy	16700.00
0005433368780	1679	Economy	16700.00
0005433368539	1679	Economy	16700.00
0005433368713	1679	Economy	16700.00
0005435654455	1679	Economy	16700.00
0005435654463	1679	Economy	16700.00
0005433368710	1679	Economy	16700.00
0005435654469	1679	Economy	16700.00
0005433368719	1679	Economy	16700.00
0005433368822	1679	Economy	16700.00
0005433368792	1679	Economy	16700.00
0005433368660	1679	Economy	16700.00
0005433368788	1679	Economy	16700.00
0005435654451	1679	Economy	16700.00
0005435654449	1679	Economy	16700.00
0005435654472	1679	Economy	16700.00
0005433368970	21716	Business	50000.00
0005435653971	21716	Business	50000.00
0005435653972	21716	Business	50000.00
0005433368966	21716	Business	50000.00
0005435654053	21716	Business	50000.00
0005435654090	21716	Business	50000.00
0005435654015	21716	Business	50000.00
0005435653822	21716	Business	50000.00
0005435653823	21716	Business	50000.00
0005435653909	21716	Business	50000.00
0005435653776	21716	Economy	16700.00
0005433368971	21716	Economy	16700.00
0005435654028	21716	Economy	16700.00
0005435653777	21716	Economy	16700.00
0005435654055	21716	Economy	16700.00
0005435653927	21716	Economy	16700.00
0005435653977	21716	Economy	16700.00
0005435654111	21716	Economy	16700.00
0005435654088	21716	Economy	16700.00
0005435654050	21716	Economy	18300.00
0005435653861	21716	Economy	18300.00
0005435654056	21716	Economy	18300.00
0005435653824	21716	Economy	18300.00
0005435653842	21716	Economy	16700.00
0005435654066	21716	Economy	16700.00
0005435654065	21716	Economy	16700.00
0005435653809	21716	Economy	16700.00
0005435653933	21716	Economy	16700.00
0005435654201	21716	Economy	16700.00
0005435654236	21716	Economy	16700.00
0005435653996	21716	Economy	16700.00
0005435654038	21716	Economy	16700.00
0005435653943	21716	Economy	16700.00
0005435654039	21716	Economy	16700.00
0005433368967	21716	Economy	16700.00
0005435653821	21716	Economy	16700.00
0005435653921	21716	Economy	16700.00
0005435654030	21716	Economy	16700.00
0005435653932	21716	Economy	16700.00
0005435653968	21716	Economy	16700.00
0005435654032	21716	Economy	16700.00
0005433368969	21716	Economy	16700.00
0005435654080	21716	Economy	16700.00
0005435654106	21716	Economy	16700.00
0005435654346	21716	Economy	16700.00
0005435653947	21716	Economy	16700.00
0005435654179	21716	Economy	16700.00
0005435654013	21716	Economy	16700.00
0005435654202	21716	Economy	16700.00
0005435653810	21716	Economy	16700.00
0005433368973	21716	Economy	16700.00
0005435653907	21716	Economy	16700.00
0005433368976	21716	Economy	16700.00
0005435653778	21716	Economy	16700.00
0005433368968	21716	Economy	16700.00
0005435654029	21716	Economy	16700.00
0005435654112	21716	Economy	16700.00
0005435653860	21716	Economy	16700.00
0005435654008	21716	Economy	16700.00
0005435653953	21716	Economy	16700.00
0005435654027	21716	Economy	16700.00
0005435654037	21716	Economy	16700.00
0005433368972	21716	Economy	16700.00
0005435653843	21716	Economy	16700.00
0005435654051	21716	Economy	16700.00
0005435654016	21716	Economy	16700.00
0005435653734	21716	Economy	16700.00
0005435654235	21716	Economy	16700.00
0005433368975	21716	Economy	16700.00
0005433368974	21716	Economy	16700.00
0005435627133	12273	Economy	11200.00
0005435627134	12273	Economy	11200.00
0005435627126	23768	Economy	11200.00
0005435627127	23768	Economy	11200.00
0005433987366	4143	Business	21500.00
0005433987363	4143	Business	21500.00
0005433987351	4143	Business	21500.00
0005433987362	4143	Economy	7200.00
0005433987359	4143	Economy	7200.00
0005433987356	4143	Economy	7200.00
0005433987357	4143	Economy	7200.00
0005433987364	4143	Economy	7200.00
0005433987353	4143	Economy	7200.00
0005433987355	4143	Economy	7200.00
0005433987354	4143	Economy	7200.00
0005433987360	4143	Economy	7200.00
0005433987358	4143	Economy	7200.00
0005433987361	4143	Economy	7200.00
0005433987352	4143	Economy	7200.00
0005433987365	4143	Economy	7200.00
0005433986946	25672	Business	21500.00
0005433987052	25672	Business	21500.00
0005433987083	25672	Business	21500.00
0005433987018	25672	Business	21500.00
0005433986768	25672	Business	21500.00
0005433986823	25672	Business	21500.00
0005433986817	25672	Economy	7200.00
0005433986963	25672	Economy	7200.00
0005433986870	25672	Economy	7200.00
0005433987036	25672	Economy	7200.00
0005433986863	25672	Economy	7200.00
0005433986767	25672	Economy	7200.00
0005433986712	25672	Economy	7200.00
0005435788820	25672	Economy	7200.00
0005433987007	25672	Economy	7900.00
0005433986873	25672	Economy	7900.00
0005433987019	25672	Economy	7200.00
0005433986966	25672	Economy	7200.00
0005435788838	25672	Economy	7200.00
0005433986867	25672	Economy	7200.00
0005433987053	25672	Economy	7200.00
0005433987010	25672	Economy	7200.00
0005433986970	25672	Economy	7200.00
0005433987072	25672	Economy	7200.00
0005433987060	25672	Economy	7200.00
0005433986986	25672	Economy	7200.00
0005433986824	25672	Economy	7200.00
0005433986969	25672	Economy	7200.00
0005435788837	25672	Economy	7200.00
0005433986976	25672	Economy	7200.00
0005433987006	25672	Economy	7200.00
0005433987020	25672	Economy	7200.00
0005435788821	25672	Economy	7200.00
0005433986849	25672	Economy	7200.00
0005433986989	25672	Economy	7200.00
0005433986888	25672	Economy	7200.00
0005433986931	25672	Economy	7200.00
0005433986968	25672	Economy	7200.00
0005435788830	25672	Economy	7200.00
0005433987029	25672	Economy	7200.00
0005433986818	25672	Economy	7200.00
0005433986822	25672	Economy	7200.00
0005433986945	25672	Economy	7200.00
0005433986908	25672	Economy	7200.00
0005433986951	25672	Economy	7200.00
0005433987040	25672	Economy	7200.00
0005433987024	25672	Economy	7200.00
0005433986948	25672	Economy	7200.00
0005433986965	25672	Economy	7200.00
0005433986964	25672	Economy	7200.00
0005433987025	25672	Economy	7200.00
0005433986713	25672	Economy	7200.00
0005433987030	25672	Economy	7200.00
0005433986975	25672	Economy	7200.00
0005433987037	25672	Economy	7200.00
0005433986876	25672	Economy	7200.00
0005433987026	25672	Economy	7200.00
0005433986819	25672	Economy	7200.00
0005433986909	25672	Economy	7200.00
0005435720854	21254	Economy	9400.00
0005435719591	21254	Economy	9400.00
0005435720853	21254	Economy	9400.00
0005435720167	24746	Economy	9400.00
0005435719603	24746	Economy	9400.00
0005435720168	24746	Economy	9400.00
0005435719604	24746	Economy	9400.00
0005435719605	24746	Economy	9400.00
0005434509300	21328	Economy	17000.00
0005434509313	21328	Economy	17000.00
0005434509311	21328	Economy	17000.00
0005434509312	21328	Economy	15500.00
0005434509305	21328	Economy	15500.00
0005434509307	21328	Economy	15500.00
0005434509337	21328	Economy	15500.00
0005434509294	21328	Economy	15500.00
0005434509297	21328	Economy	15500.00
0005434509324	21328	Economy	15500.00
0005434509298	21328	Economy	15500.00
0005434509315	21328	Economy	15500.00
0005434509296	21328	Economy	15500.00
0005434509263	21328	Economy	15500.00
0005434509281	21328	Economy	15500.00
0005434509289	21328	Economy	15500.00
0005434509339	21328	Economy	15500.00
0005434509304	21328	Economy	15500.00
0005434509316	21328	Economy	15500.00
0005434509329	21328	Economy	15500.00
0005433168493	21328	Economy	15500.00
0005434509286	21328	Economy	15500.00
0005434509350	21328	Economy	15500.00
0005434509336	21328	Economy	15500.00
0005434509257	21328	Economy	15500.00
0005434509340	21328	Economy	15500.00
0005434509295	21328	Economy	15500.00
0005434509287	21328	Economy	15500.00
0005434509321	21328	Economy	15500.00
0005434509332	21328	Economy	15500.00
0005434509320	21328	Economy	15500.00
0005434509280	21328	Economy	15500.00
0005434509328	21328	Economy	15500.00
0005433168492	21328	Economy	15500.00
0005434509314	21328	Economy	15500.00
0005432657515	17835	Business	18000.00
0005432655758	17835	Business	18000.00
0005432869721	17835	Economy	6000.00
0005432666439	17835	Economy	6000.00
0005432660859	17835	Economy	6000.00
0005432655819	17835	Economy	6000.00
0005432655742	17835	Economy	6000.00
0005432663083	17835	Economy	6000.00
0005432667504	17835	Economy	6600.00
0005432869723	17835	Economy	6600.00
0005432664180	17835	Economy	6000.00
0005432655794	17835	Economy	6000.00
0005432655818	17835	Economy	6000.00
0005432655795	17835	Economy	6000.00
0005432655766	17835	Economy	6000.00
0005432663080	17835	Economy	6000.00
0005432664188	17835	Economy	6000.00
0005432655741	17835	Economy	6000.00
0005432655817	17835	Economy	6000.00
0005432661962	17835	Economy	6000.00
0005432659749	17835	Economy	6000.00
0005432869722	17835	Economy	6000.00
0005432658631	17835	Economy	6000.00
0005432657516	17835	Economy	6000.00
0005432664183	17835	Economy	6000.00
0005432658633	17835	Economy	6000.00
0005432664181	17835	Economy	6000.00
0005434151793	17835	Economy	6000.00
0005432657523	17835	Economy	6000.00
0005432655787	17835	Economy	6000.00
0005432663079	17835	Economy	6000.00
0005432667505	17835	Economy	6000.00
0005432661969	17835	Economy	6000.00
0005432869724	17835	Economy	6000.00
0005432659750	17835	Economy	6000.00
0005432658651	26287	Business	18000.00
0005434151775	26287	Business	18000.00
0005432665334	26287	Business	18000.00
0005432655874	26287	Economy	6000.00
0005432655872	26287	Economy	6000.00
0005434151769	26287	Economy	6600.00
0005432869658	26287	Economy	6600.00
0005432655873	26287	Economy	6000.00
0005432869667	26287	Economy	6000.00
0005434151768	26287	Economy	6000.00
0005432869651	26287	Economy	6000.00
0005432659765	26287	Economy	6000.00
0005432655875	26287	Economy	6000.00
0005434151762	26287	Economy	6000.00
0005432869643	26287	Economy	6000.00
0005432655878	26287	Economy	6000.00
0005432869661	26287	Economy	6000.00
0005432869662	26287	Economy	6000.00
0005432665332	26287	Economy	6000.00
0005432655877	26287	Economy	6000.00
0005432869618	26287	Economy	6000.00
0005432657538	26287	Economy	6000.00
0005432665333	26287	Economy	6000.00
0005432655876	26287	Economy	6000.00
0005432655880	26287	Economy	6000.00
0005432655879	26287	Economy	6000.00
0005432658650	26287	Economy	6000.00
0005432869666	26287	Economy	6000.00
0005432655870	26287	Economy	6000.00
0005432659767	26287	Economy	6000.00
0005432869642	26287	Economy	6000.00
0005432659766	26287	Economy	6000.00
0005432655871	26287	Economy	6000.00
0005432848868	3071	Business	16100.00
0005432848904	3071	Business	16100.00
0005432848905	3071	Business	16100.00
0005432330031	3071	Business	16100.00
0005433439104	3071	Business	16100.00
0005432848870	3071	Economy	5400.00
0005433439102	3071	Economy	5400.00
0005433439106	3071	Economy	5900.00
0005432848871	3071	Economy	5900.00
0005433439103	3071	Economy	5400.00
0005432330026	3071	Economy	5400.00
0005432848884	3071	Economy	5400.00
0005432330038	3071	Economy	5400.00
0005432905244	3071	Economy	5400.00
0005432905236	3071	Economy	5400.00
0005432330039	3071	Economy	5400.00
0005432905266	3071	Economy	5400.00
0005432330029	3071	Economy	5400.00
0005432330036	3071	Economy	5400.00
0005432848885	3071	Economy	5400.00
0005432330035	3071	Economy	5400.00
0005432905245	3071	Economy	5400.00
0005433439101	3071	Economy	5400.00
0005432330028	3071	Economy	5400.00
0005432330034	3071	Economy	5400.00
0005433439114	3071	Economy	5400.00
0005433439105	3071	Economy	5400.00
0005433439115	3071	Economy	5400.00
0005432330037	3071	Economy	5400.00
0005432905257	3071	Economy	5400.00
0005432330033	3071	Economy	5400.00
0005432330032	3071	Economy	5400.00
0005432330027	3071	Economy	5400.00
0005432905235	3071	Economy	5400.00
0005432905258	3071	Economy	5400.00
0005432330030	3071	Economy	5400.00
0005432329674	31132	Business	16100.00
0005432329650	31132	Business	16100.00
0005432905290	31132	Business	16100.00
0005432329926	31132	Business	16100.00
0005432329719	31132	Business	16100.00
0005433439038	31132	Economy	5400.00
0005432329375	31132	Economy	5400.00
0005433439005	31132	Economy	5400.00
0005432329716	31132	Economy	5400.00
0005432329652	31132	Economy	5400.00
0005432329717	31132	Economy	5400.00
0005432905292	31132	Economy	5400.00
0005432329798	31132	Economy	5900.00
0005432329477	31132	Economy	5900.00
0005432329713	31132	Economy	5900.00
0005432329927	31132	Economy	5900.00
0005432329743	31132	Economy	5400.00
0005432329784	31132	Economy	5400.00
0005432329515	31132	Economy	5400.00
0005432329599	31132	Economy	5400.00
0005432054391	31132	Economy	5400.00
0005432329598	31132	Economy	5400.00
0005433439042	31132	Economy	5400.00
0005432329603	31132	Economy	5400.00
0005433439037	31132	Economy	5400.00
0005432329781	31132	Economy	5400.00
0005432329826	31132	Economy	5400.00
0005432329797	31132	Economy	5400.00
0005432329476	31132	Economy	5400.00
0005432329625	31132	Economy	5400.00
0005432329715	31132	Economy	5400.00
0005432329820	31132	Economy	5400.00
0005432329685	31132	Economy	5400.00
0005432329545	31132	Economy	5400.00
0005432329582	31132	Economy	5400.00
0005432329718	31132	Economy	5400.00
0005432329647	31132	Economy	5400.00
0005433439023	31132	Economy	5400.00
0005432329665	31132	Economy	5400.00
0005432329783	31132	Economy	5400.00
0005432848908	31132	Economy	5400.00
0005432329679	31132	Economy	5400.00
0005432329758	31132	Economy	5400.00
0005432329805	31132	Economy	5400.00
0005432329740	31132	Economy	5400.00
0005432329856	31132	Economy	5400.00
0005432329495	31132	Economy	5400.00
0005432329686	31132	Economy	5400.00
0005432329646	31132	Economy	5400.00
0005432329671	31132	Economy	5400.00
0005432329672	31132	Economy	5400.00
0005432329772	31132	Economy	5400.00
0005433439034	31132	Economy	5400.00
0005432329777	31132	Economy	5400.00
0005432905291	31132	Economy	5400.00
0005432848909	31132	Economy	5400.00
0005432329376	31132	Economy	5400.00
0005432329778	31132	Economy	5400.00
0005432329799	31132	Economy	5400.00
0005432329701	31132	Economy	5400.00
0005432329664	31132	Economy	5400.00
0005433439022	31132	Economy	5400.00
0005433439039	31132	Economy	5400.00
0005432329651	31132	Economy	5400.00
0005432848907	31132	Economy	5400.00
0005432329759	31132	Economy	5400.00
0005432329505	31132	Economy	5400.00
0005432329782	31132	Economy	5400.00
0005432329624	31132	Economy	5400.00
0005432329506	31132	Economy	5400.00
0005432329827	31132	Economy	5400.00
0005433439018	31132	Economy	5400.00
0005433439035	31132	Economy	5400.00
0005432329567	31132	Economy	5400.00
0005435999850	6212	Business	124600.00
0005435999848	6212	Business	124600.00
0005435488352	6212	Business	124600.00
0005435297219	6212	Business	124600.00
0005435999844	6212	Economy	41500.00
0005434310137	6212	Economy	41500.00
0005435488390	6212	Economy	41500.00
0005435488409	6212	Economy	41500.00
0005435488302	6212	Economy	41500.00
0005435488265	6212	Economy	41500.00
0005435488353	6212	Economy	41500.00
0005435297206	6212	Economy	41500.00
0005434310141	6212	Economy	41500.00
0005435488297	6212	Economy	41500.00
0005435999847	6212	Economy	41500.00
0005435488179	6212	Economy	41500.00
0005435488343	6212	Economy	41500.00
0005434310139	6212	Economy	41500.00
0005435297186	6212	Economy	41500.00
0005435488312	6212	Economy	45700.00
0005435999841	6212	Economy	45700.00
0005435488342	6212	Economy	41500.00
0005435488285	6212	Economy	41500.00
0005434310138	6212	Economy	41500.00
0005435297214	6212	Economy	41500.00
0005435297209	6212	Economy	41500.00
0005435488247	6212	Economy	41500.00
0005435999845	6212	Economy	41500.00
0005435488178	6212	Economy	41500.00
0005434310140	6212	Economy	41500.00
0005435488311	6212	Economy	41500.00
0005435488233	6212	Economy	41500.00
0005435488344	6212	Economy	41500.00
0005435488317	6212	Economy	41500.00
0005435488318	6212	Economy	41500.00
0005435999849	6212	Economy	41500.00
0005434310142	6212	Economy	41500.00
0005435488310	6212	Economy	41500.00
0005432146259	6212	Economy	41500.00
0005435999842	6212	Economy	41500.00
0005435999846	6212	Economy	41500.00
0005435488341	6212	Economy	41500.00
0005435999843	6212	Economy	41500.00
0005435488298	6212	Economy	41500.00
0005435488458	19544	Business	124600.00
0005434310065	19544	Economy	41500.00
0005435488455	19544	Economy	41500.00
0005435488453	19544	Economy	41500.00
0005435488454	19544	Economy	41500.00
0005435488460	19544	Economy	41500.00
0005435999661	19544	Economy	41500.00
0005435488464	19544	Economy	41500.00
0005435488462	19544	Economy	41500.00
0005434310044	19544	Economy	41500.00
0005435999613	19544	Economy	41500.00
0005435297262	19544	Economy	41500.00
0005434310055	19544	Economy	41500.00
0005435999573	19544	Economy	41500.00
0005434310053	19544	Economy	41500.00
0005434310057	19544	Economy	45700.00
0005435999623	19544	Economy	45700.00
0005435999571	19544	Economy	45700.00
0005435999590	19544	Economy	41500.00
0005435999591	19544	Economy	41500.00
0005434309999	19544	Economy	41500.00
0005435999646	19544	Economy	41500.00
0005435999662	19544	Economy	41500.00
0005435999572	19544	Economy	41500.00
0005435297261	19544	Economy	41500.00
0005435488465	19544	Economy	41500.00
0005435488456	19544	Economy	41500.00
0005434310084	19544	Economy	41500.00
0005435488457	19544	Economy	41500.00
0005434310079	19544	Economy	41500.00
0005435488461	19544	Economy	41500.00
0005434310078	19544	Economy	41500.00
0005435488463	19544	Economy	41500.00
0005435999670	19544	Economy	41500.00
0005434310056	19544	Economy	41500.00
0005434310054	19544	Economy	41500.00
0005435999663	19544	Economy	41500.00
0005434310039	19544	Economy	41500.00
0005435488459	19544	Economy	41500.00
0005435999616	19544	Economy	41500.00
0005435999648	19544	Economy	41500.00
0005435999594	19544	Economy	41500.00
0005435999630	19544	Economy	41500.00
0005434310040	19544	Economy	41500.00
0005435999595	19544	Economy	41500.00
0005435518449	1543	Business	86000.00
0005435508819	1543	Business	86000.00
0005434566304	1543	Business	86000.00
0005435518446	1543	Business	86000.00
0005433186303	1543	Business	86000.00
0005435502949	1543	Business	86000.00
0005435518451	1543	Economy	28700.00
0005434566307	1543	Economy	28700.00
0005433186313	1543	Economy	28700.00
0005435508816	1543	Economy	28700.00
0005435518447	1543	Economy	28700.00
0005435508824	1543	Economy	31500.00
0005435508814	1543	Economy	31500.00
0005433186283	1543	Economy	28700.00
0005434566308	1543	Economy	28700.00
0005435508817	1543	Economy	28700.00
0005434566305	1543	Economy	28700.00
0005435508820	1543	Economy	28700.00
0005433186284	1543	Economy	28700.00
0005435502948	1543	Economy	28700.00
0005433186325	1543	Economy	28700.00
0005435518445	1543	Economy	28700.00
0005435518448	1543	Economy	28700.00
0005433186302	1543	Economy	28700.00
0005435502947	1543	Economy	28700.00
0005435508815	1543	Economy	28700.00
0005435502955	1543	Economy	28700.00
0005435508823	1543	Economy	28700.00
0005435518452	1543	Economy	28700.00
0005435502954	1543	Economy	28700.00
0005435502952	1543	Economy	28700.00
0005435508822	1543	Economy	28700.00
0005435518450	1543	Economy	28700.00
0005435508821	1543	Economy	28700.00
0005435518454	1543	Economy	28700.00
0005435518453	1543	Economy	28700.00
0005435502951	1543	Economy	28700.00
0005435508818	1543	Economy	28700.00
0005434566306	1543	Economy	28700.00
0005435502950	1543	Economy	28700.00
0005435502953	1543	Economy	28700.00
0005435502776	20857	Business	86000.00
0005435529700	20857	Business	86000.00
0005435529695	20857	Business	86000.00
0005435529701	20857	Business	86000.00
0005435502847	20857	Business	86000.00
0005433186371	20857	Business	86000.00
0005435529731	20857	Business	86000.00
0005435529747	20857	Business	86000.00
0005434566223	20857	Business	86000.00
0005434566142	20857	Business	86000.00
0005435529748	20857	Business	86000.00
0005435529712	20857	Economy	28700.00
0005435502735	20857	Economy	28700.00
0005435502708	20857	Economy	28700.00
0005434566222	20857	Economy	28700.00
0005435502762	20857	Economy	28700.00
0005435529718	20857	Economy	28700.00
0005433186372	20857	Economy	31500.00
0005435529635	20857	Economy	31500.00
0005435502822	20857	Economy	31500.00
0005435529659	20857	Economy	28700.00
0005435529787	20857	Economy	28700.00
0005435529683	20857	Economy	28700.00
0005435502779	20857	Economy	28700.00
0005435502650	20857	Economy	28700.00
0005435529720	20857	Economy	28700.00
0005435545880	20857	Economy	28700.00
0005435502770	20857	Economy	28700.00
0005435502763	20857	Economy	28700.00
0005435545885	20857	Economy	28700.00
0005435545903	20857	Economy	28700.00
0005435529786	20857	Economy	28700.00
0005434566224	20857	Economy	28700.00
0005435502731	20857	Economy	28700.00
0005435529688	20857	Economy	28700.00
0005435502817	20857	Economy	28700.00
0005435529634	20857	Economy	28700.00
0005435529721	20857	Economy	28700.00
0005435545900	20857	Economy	28700.00
0005435529664	20857	Economy	28700.00
0005435502813	20857	Economy	28700.00
0005435502777	20857	Economy	28700.00
0005435529752	20857	Economy	28700.00
0005434566238	20857	Economy	28700.00
0005435502769	20857	Economy	28700.00
0005434566179	20857	Economy	28700.00
0005435502790	20857	Economy	28700.00
0005435502648	20857	Economy	28700.00
0005435529687	20857	Economy	28700.00
0005434566254	20857	Economy	28700.00
0005435502753	20857	Economy	28700.00
0005435529662	20857	Economy	28700.00
0005434566255	20857	Economy	28700.00
0005435529713	20857	Economy	28700.00
0005435545878	20857	Economy	28700.00
0005435545879	20857	Economy	28700.00
0005435529673	20857	Economy	28700.00
0005435502759	20857	Economy	28700.00
0005434566183	20857	Economy	28700.00
0005434566178	20857	Economy	28700.00
0005435529746	20857	Economy	28700.00
0005433186370	20857	Economy	28700.00
0005435529711	20857	Economy	28700.00
0005435529665	20857	Economy	28700.00
0005435502649	20857	Economy	28700.00
0005434566182	20857	Economy	28700.00
0005434566212	20857	Economy	28700.00
0005435529689	20857	Economy	28700.00
0005435529669	20857	Economy	28700.00
0005435529722	20857	Economy	28700.00
0005435502848	20857	Economy	28700.00
0005435502829	20857	Economy	28700.00
0005435545899	20857	Economy	28700.00
0005435153940	3884	Economy	19700.00
0005435153939	3884	Economy	19700.00
0005435931687	3884	Economy	19700.00
0005435931685	3884	Economy	19700.00
0005435931686	3884	Economy	19700.00
0005435931675	3884	Economy	19700.00
0005435931680	3884	Economy	19700.00
0005435153897	21894	Economy	21600.00
0005435153881	21894	Economy	21600.00
0005435153909	21894	Economy	19700.00
0005435931711	21894	Economy	19700.00
0005435153898	21894	Economy	19700.00
0005435931712	21894	Economy	19700.00
0005435153899	21894	Economy	19700.00
0005435153896	21894	Economy	19700.00
0005435931713	21894	Economy	19700.00
0005435153882	21894	Economy	19700.00
0005435153883	21894	Economy	19700.00
0005435153910	21894	Economy	19700.00
0005435931710	21894	Economy	19700.00
0005435142976	21894	Economy	19700.00
0005435225776	7174	Economy	13000.00
0005435225775	7174	Economy	13000.00
0005435225777	7174	Economy	13000.00
0005432629288	7174	Economy	13000.00
0005432629286	7174	Economy	13000.00
0005432629287	7174	Economy	13000.00
0005432629285	7174	Economy	13000.00
0005432629284	7174	Economy	13000.00
0005432629170	28145	Economy	14300.00
0005432629136	28145	Economy	13000.00
0005432629217	28145	Economy	13000.00
0005435225811	28145	Economy	13000.00
0005432629223	28145	Economy	13000.00
0005435225810	28145	Economy	13000.00
0005432629215	28145	Economy	13000.00
0005432629202	28145	Economy	13000.00
0005432629167	28145	Economy	13000.00
0005432629216	28145	Economy	13000.00
0005432629255	28145	Economy	13000.00
0005432629225	28145	Economy	13000.00
0005432629200	28145	Economy	13000.00
0005432629224	28145	Economy	13000.00
0005432629180	28145	Economy	13000.00
0005432629140	28145	Economy	13000.00
0005432629233	28145	Economy	13000.00
0005434268029	8769	Economy	10500.00
0005435960163	8769	Economy	10500.00
0005434268053	8769	Economy	10500.00
0005434268031	8769	Economy	10500.00
0005435960164	8769	Economy	10500.00
0005435960139	15272	Economy	11500.00
0005435960159	15272	Economy	11500.00
0005435960135	15272	Economy	10500.00
0005435960134	15272	Economy	10500.00
0005435960142	15272	Economy	10500.00
0005435960143	15272	Economy	10500.00
0005435960160	15272	Economy	10500.00
0005435477010	15272	Economy	10500.00
0005435960140	15272	Economy	10500.00
0005435960154	15272	Economy	10500.00
0005434268061	15272	Economy	10500.00
0005432693945	1173	Business	115000.00
0005432693955	1173	Business	115000.00
0005432677688	1173	Business	115000.00
0005432693946	1173	Business	115000.00
0005432675577	1173	Business	115000.00
0005432693954	1173	Economy	38300.00
0005432677687	1173	Economy	38300.00
0005432693944	1173	Economy	38300.00
0005432873441	1173	Economy	38300.00
0005432693956	1173	Economy	38300.00
0005432873452	1173	Economy	38300.00
0005432693948	1173	Economy	38300.00
0005432873463	1173	Economy	38300.00
0005432693947	1173	Economy	38300.00
0005432693953	1173	Economy	38300.00
0005432693951	1173	Economy	38300.00
0005432873437	1173	Economy	38300.00
0005432873436	1173	Economy	38300.00
0005432873458	1173	Economy	38300.00
0005432675579	1173	Economy	38300.00
0005432693949	1173	Economy	38300.00
0005432693950	1173	Economy	38300.00
0005432873453	1173	Economy	38300.00
0005432693952	1173	Economy	38300.00
0005432873454	1173	Economy	38300.00
0005432873465	1173	Economy	38300.00
0005432675578	1173	Economy	38300.00
0005432693681	17483	Business	115000.00
0005432677638	17483	Business	115000.00
0005432693845	17483	Business	115000.00
0005432675475	17483	Economy	38300.00
0005432693744	17483	Economy	38300.00
0005432693634	17483	Economy	38300.00
0005432675349	17483	Economy	38300.00
0005432693597	17483	Economy	38300.00
0005432693844	17483	Economy	38300.00
0005432675402	17483	Economy	38300.00
0005432675506	17483	Economy	38300.00
0005432693793	17483	Economy	38300.00
0005432675455	17483	Economy	38300.00
0005432675473	17483	Economy	38300.00
0005432693690	17483	Economy	38300.00
0005432693685	17483	Economy	38300.00
0005432675524	17483	Economy	38300.00
0005432675505	17483	Economy	38300.00
0005432693755	17483	Economy	38300.00
0005432677661	17483	Economy	38300.00
0005432693792	17483	Economy	38300.00
0005432693758	17483	Economy	38300.00
0005432693805	17483	Economy	38300.00
0005432675457	17483	Economy	38300.00
0005432693723	17483	Economy	38300.00
0005432693633	17483	Economy	38300.00
0005432675456	17483	Economy	38300.00
0005432873495	17483	Economy	38300.00
0005432693682	17483	Economy	38300.00
0005432873496	17483	Economy	38300.00
0005432693689	17483	Economy	38300.00
0005432677637	17483	Economy	38300.00
0005432675466	17483	Economy	38300.00
0005432693721	17483	Economy	38300.00
0005433156973	1136	Economy	15200.00
0005434435626	1136	Economy	13900.00
0005433156955	1136	Economy	13900.00
0005433156985	1136	Economy	13900.00
0005433156914	1136	Economy	13900.00
0005433156972	1136	Economy	13900.00
0005433156953	1136	Economy	13900.00
0005433156945	1136	Economy	13900.00
0005433156913	1136	Economy	13900.00
0005433156952	1136	Economy	13900.00
0005434435630	1136	Economy	13900.00
0005433156946	1136	Economy	13900.00
0005434435629	1136	Economy	13900.00
0005433156928	1136	Economy	13900.00
0005434435627	1136	Economy	13900.00
0005433156930	1136	Economy	13900.00
0005433156996	1136	Economy	13900.00
0005433156923	1136	Economy	13900.00
0005433156929	1136	Economy	13900.00
0005433156938	1136	Economy	13900.00
0005434435628	1136	Economy	13900.00
0005434435578	17291	Economy	15200.00
0005434435498	17291	Economy	15200.00
0005434435551	17291	Economy	13900.00
0005434435552	17291	Economy	13900.00
0005434435514	17291	Economy	13900.00
0005434435499	17291	Economy	13900.00
0005434435500	17291	Economy	13900.00
0005434435471	17291	Economy	13900.00
0005434435543	17291	Economy	13900.00
0005434435513	17291	Economy	13900.00
0005434435540	17291	Economy	13900.00
0005434435538	17291	Economy	13900.00
0005434435539	17291	Economy	13900.00
0005434435530	17291	Economy	13900.00
0005434435541	17291	Economy	13900.00
0005434435464	17291	Economy	13900.00
0005434435550	17291	Economy	13900.00
0005434435542	17291	Economy	13900.00
0005434435519	17291	Economy	13900.00
0005433157005	17291	Economy	13900.00
0005434435517	17291	Economy	13900.00
0005434435477	17291	Economy	13900.00
0005435928242	4053	Economy	8200.00
0005435928247	4053	Economy	8200.00
0005435087060	4053	Economy	7500.00
0005435087058	4053	Economy	7500.00
0005435928236	4053	Economy	7500.00
0005435087056	4053	Economy	7500.00
0005435928239	4053	Economy	7500.00
0005435087061	4053	Economy	7500.00
0005435087059	4053	Economy	7500.00
0005435087055	4053	Economy	7500.00
0005435087057	4053	Economy	7500.00
0005435928253	4053	Economy	7500.00
0005435928240	4053	Economy	7500.00
0005435928246	4053	Economy	7500.00
0005435086966	24439	Economy	8200.00
0005435087001	24439	Economy	8200.00
0005435928289	24439	Economy	7500.00
0005435086993	24439	Economy	7500.00
0005435086965	24439	Economy	7500.00
0005435928288	24439	Economy	7500.00
0005435907620	4833	Business	44200.00
0005435907621	4833	Business	44200.00
0005433194917	4833	Business	44200.00
0005433194906	4833	Economy	14700.00
0005433194910	4833	Economy	14700.00
0005434626236	4833	Economy	14700.00
0005433194907	4833	Economy	14700.00
0005435907616	4833	Economy	14700.00
0005433194912	4833	Economy	14700.00
0005433194903	4833	Economy	14700.00
0005434626235	4833	Economy	14700.00
0005435907614	4833	Economy	14700.00
0005433194916	4833	Economy	14700.00
0005433194905	4833	Economy	14700.00
0005434626174	32888	Business	44200.00
0005434626179	32888	Business	44200.00
0005434626165	32888	Business	44200.00
0005433195006	32888	Business	44200.00
0005433195007	32888	Business	44200.00
0005433194999	32888	Economy	16200.00
0005434626173	32888	Economy	14700.00
0005433195003	32888	Economy	14700.00
0005433195002	32888	Economy	14700.00
0005433195004	32888	Economy	14700.00
0005433195000	32888	Economy	14700.00
0005434626172	32888	Economy	14700.00
0005433195005	32888	Economy	14700.00
0005433195001	32888	Economy	14700.00
0005434626164	32888	Economy	14700.00
0005434626198	32888	Economy	14700.00
0005435937567	13805	Economy	3400.00
0005435785998	13805	Economy	3400.00
0005435786062	13805	Economy	3400.00
0005435786159	13805	Economy	3400.00
0005435786139	13805	Economy	3100.00
0005435786138	13805	Economy	3100.00
0005435786154	13805	Economy	3100.00
0005435786080	13805	Economy	3100.00
0005435937571	13805	Economy	3100.00
0005435786158	13805	Economy	3100.00
0005435786064	13805	Economy	3100.00
0005435937569	13805	Economy	3100.00
0005435937568	13805	Economy	3100.00
0005435786143	13805	Economy	3100.00
0005435787394	13805	Economy	3100.00
0005435785930	13805	Economy	3100.00
0005435786055	13805	Economy	3100.00
0005435786081	13805	Economy	3100.00
0005435787393	13805	Economy	3100.00
0005435786108	13805	Economy	3100.00
0005435786147	13805	Economy	3100.00
0005435786078	13805	Economy	3100.00
0005435786086	13805	Economy	3100.00
0005435786022	13805	Economy	3100.00
0005432195754	13805	Economy	3100.00
0005435786109	13805	Economy	3100.00
0005435785928	13805	Economy	3100.00
0005435786115	13805	Economy	3100.00
0005435786084	13805	Economy	3100.00
0005435786082	13805	Economy	3100.00
0005432195755	13805	Economy	3100.00
0005435786155	13805	Economy	3100.00
0005435786120	13805	Economy	3100.00
0005432195756	13805	Economy	3100.00
0005435786137	13805	Economy	3100.00
0005435786175	13805	Economy	3100.00
0005435937570	13805	Economy	3100.00
0005435786095	13805	Economy	3100.00
0005435786077	13805	Economy	3100.00
0005435786110	13805	Economy	3100.00
0005435786085	13805	Economy	3100.00
0005435786121	13805	Economy	3100.00
0005435786094	13805	Economy	3100.00
0005435786061	13805	Economy	3100.00
0005435785929	13805	Economy	3100.00
0005435785997	13805	Economy	3100.00
0005435785996	13805	Economy	3100.00
0005435785971	13805	Economy	3100.00
0005435785941	13805	Economy	3100.00
0005435785931	13805	Economy	3100.00
0005435786326	27411	Economy	3400.00
0005435937497	27411	Economy	3400.00
0005435937471	27411	Economy	3100.00
0005435786329	27411	Economy	3100.00
0005435786333	27411	Economy	3100.00
0005435786339	27411	Economy	3100.00
0005435937510	27411	Economy	3100.00
0005435786323	27411	Economy	3100.00
0005435937487	27411	Economy	3100.00
0005435786335	27411	Economy	3100.00
0005435937488	27411	Economy	3100.00
0005435937496	27411	Economy	3100.00
0005435786334	27411	Economy	3100.00
0005435786327	27411	Economy	3100.00
0005435786324	27411	Economy	3100.00
0005435937470	27411	Economy	3100.00
0005435937472	27411	Economy	3100.00
0005435937494	27411	Economy	3100.00
0005435786325	27411	Economy	3100.00
0005435937473	27411	Economy	3100.00
0005435937486	27411	Economy	3100.00
0005435786330	27411	Economy	3100.00
0005435786336	27411	Economy	3100.00
0005435937499	27411	Economy	3100.00
0005435786331	27411	Economy	3100.00
0005435786332	27411	Economy	3100.00
0005435937480	27411	Economy	3100.00
0005435786337	27411	Economy	3100.00
0005435786338	27411	Economy	3100.00
0005435786328	27411	Economy	3100.00
0005435937479	27411	Economy	3100.00
0005435937498	27411	Economy	3100.00
0005434409257	20291	Business	12000.00
0005434409272	20291	Business	12000.00
0005434409281	20291	Business	12000.00
0005434409066	20291	Business	12000.00
0005434409173	20291	Business	12000.00
0005434409291	20291	Business	12000.00
0005434409343	20291	Business	12000.00
0005434409251	20291	Business	12000.00
0005435311543	20291	Business	12000.00
0005434409132	20291	Business	12000.00
0005434409456	20291	Business	12000.00
0005434409001	20291	Business	12000.00
0005434409084	20291	Economy	4000.00
0005434409244	20291	Economy	4000.00
0005434409344	20291	Economy	4000.00
0005434409235	20291	Economy	4000.00
0005434409050	20291	Economy	4000.00
0005434409023	20291	Economy	4000.00
0005434409313	20291	Economy	4000.00
0005434409466	20291	Economy	4000.00
0005435311549	20291	Economy	4000.00
0005434409372	20291	Economy	4400.00
0005435311545	20291	Economy	4400.00
0005435311541	20291	Economy	4400.00
0005434409105	20291	Economy	4400.00
0005434409215	20291	Economy	4400.00
0005434409360	20291	Economy	4000.00
0005434409238	20291	Economy	4000.00
0005434409128	20291	Economy	4000.00
0005434409434	20291	Economy	4000.00
0005434409216	20291	Economy	4000.00
0005434409271	20291	Economy	4000.00
0005434409330	20291	Economy	4000.00
0005434409104	20291	Economy	4000.00
0005434409293	20291	Economy	4000.00
0005434409225	20291	Economy	4000.00
0005434409223	20291	Economy	4000.00
0005434408972	20291	Economy	4000.00
0005434409203	20291	Economy	4000.00
0005434408885	20291	Economy	4000.00
0005435311538	20291	Economy	4000.00
0005434409455	20291	Economy	4000.00
0005434409401	20291	Economy	4000.00
0005434409115	20291	Economy	4000.00
0005434409210	20291	Economy	4000.00
0005434409073	20291	Economy	4000.00
0005434409030	20291	Economy	4000.00
0005435311544	20291	Economy	4000.00
0005434409139	20291	Economy	4000.00
0005434409275	20291	Economy	4000.00
0005434408933	20291	Economy	4000.00
0005435311546	20291	Economy	4000.00
0005434408913	20291	Economy	4000.00
0005434409168	20291	Economy	4000.00
0005434409048	20291	Economy	4000.00
0005434409047	20291	Economy	4000.00
0005434409435	20291	Economy	4000.00
0005434409174	20291	Economy	4000.00
0005434409049	20291	Economy	4000.00
0005434409378	20291	Economy	4000.00
0005434409031	20291	Economy	4000.00
0005434409095	20291	Economy	4000.00
0005434409029	20291	Economy	4000.00
0005434408934	20291	Economy	4000.00
0005434409280	20291	Economy	4000.00
0005434409211	20291	Economy	4000.00
0005434409136	20291	Economy	4000.00
0005434409072	20291	Economy	4000.00
0005434409206	20291	Economy	4000.00
0005435311540	20291	Economy	4000.00
0005434409067	20291	Economy	4000.00
0005434409204	20291	Economy	4000.00
0005434409274	20291	Economy	4000.00
0005435311539	20291	Economy	4000.00
0005434409310	20291	Economy	4000.00
0005434409113	20291	Economy	4000.00
0005434409312	20291	Economy	4000.00
0005434409325	20291	Economy	4000.00
0005434409250	20291	Economy	4000.00
0005434409363	20291	Economy	4000.00
0005434409080	20291	Economy	4000.00
0005434409051	20291	Economy	4000.00
0005432058496	20291	Economy	4000.00
0005435311548	20291	Economy	4000.00
0005434409000	20291	Economy	4000.00
0005434409207	20291	Economy	4000.00
0005435311547	20291	Economy	4000.00
0005432058497	20291	Economy	4000.00
0005434409114	20291	Economy	4000.00
0005434409292	20291	Economy	4000.00
0005434409081	20291	Economy	4000.00
0005435311542	20291	Economy	4000.00
0005434409024	20291	Economy	4000.00
0005434408946	20291	Economy	4000.00
0005434409106	20291	Economy	4000.00
0005434409581	26989	Business	12000.00
0005435311416	26989	Business	12000.00
0005434409583	26989	Business	12000.00
0005434409582	26989	Business	12000.00
0005434409592	26989	Economy	4000.00
0005434409594	26989	Economy	4000.00
0005434409580	26989	Economy	4000.00
0005432154137	26989	Economy	4000.00
0005432154139	26989	Economy	4000.00
0005435311367	26989	Economy	4400.00
0005435311328	26989	Economy	4400.00
0005434409587	26989	Economy	4000.00
0005435311430	26989	Economy	4000.00
0005435311356	26989	Economy	4000.00
0005434409597	26989	Economy	4000.00
0005435311377	26989	Economy	4000.00
0005435311278	26989	Economy	4000.00
0005435311337	26989	Economy	4000.00
0005435311378	26989	Economy	4000.00
0005435311304	26989	Economy	4000.00
0005434409579	26989	Economy	4000.00
0005434409591	26989	Economy	4000.00
0005434409578	26989	Economy	4000.00
0005434409593	26989	Economy	4000.00
0005434409589	26989	Economy	4000.00
0005434409588	26989	Economy	4000.00
0005435311303	26989	Economy	4000.00
0005434409590	26989	Economy	4000.00
0005435311399	26989	Economy	4000.00
0005435311279	26989	Economy	4000.00
0005435311371	26989	Economy	4000.00
0005434409595	26989	Economy	4000.00
0005435311308	26989	Economy	4000.00
0005434409586	26989	Economy	4000.00
0005435311370	26989	Economy	4000.00
0005434409585	26989	Economy	4000.00
0005435311309	26989	Economy	4000.00
0005432154138	26989	Economy	4000.00
0005434409584	26989	Economy	4000.00
0005434409596	26989	Economy	4000.00
0005435311369	26989	Economy	4000.00
0005435311380	26989	Economy	4000.00
0005435311338	26989	Economy	4000.00
0005433124396	5726	Business	43300.00
0005434310160	5726	Business	43300.00
0005435297357	5726	Business	43300.00
0005434319855	5726	Business	43300.00
0005433124395	5726	Business	43300.00
0005433124379	5726	Business	43300.00
0005435297358	5726	Economy	14400.00
0005433124368	5726	Economy	14400.00
0005435297354	5726	Economy	14400.00
0005433124348	5726	Economy	14400.00
0005433124462	5726	Economy	14400.00
0005434319853	5726	Economy	15900.00
0005434319847	5726	Economy	15900.00
0005434319854	5726	Economy	15900.00
0005434319848	5726	Economy	15900.00
0005433124314	5726	Economy	14400.00
0005433124333	5726	Economy	14400.00
0005433124424	5726	Economy	14400.00
0005434319851	5726	Economy	14400.00
0005434310161	5726	Economy	14400.00
0005434319850	5726	Economy	14400.00
0005434310163	5726	Economy	14400.00
0005434319852	5726	Economy	14400.00
0005434310159	5726	Economy	14400.00
0005434310155	5726	Economy	14400.00
0005434310156	5726	Economy	14400.00
0005434310158	5726	Economy	14400.00
0005434319857	5726	Economy	14400.00
0005433124351	5726	Economy	14400.00
0005434311291	5726	Economy	14400.00
0005434310157	5726	Economy	14400.00
0005434319859	5726	Economy	14400.00
0005434319858	5726	Economy	14400.00
0005433124350	5726	Economy	14400.00
0005433124349	5726	Economy	14400.00
0005433124403	5726	Economy	14400.00
0005434311278	5726	Economy	14400.00
0005434310164	5726	Economy	14400.00
0005434319856	5726	Economy	14400.00
0005434319849	5726	Economy	14400.00
0005433124315	5726	Economy	14400.00
0005433124402	5726	Economy	14400.00
0005434310162	5726	Economy	14400.00
0005434312362	15700	Business	43300.00
0005433124531	15700	Business	43300.00
0005435297394	15700	Business	43300.00
0005434319691	15700	Business	43300.00
0005433124539	15700	Economy	14400.00
0005434319657	15700	Economy	14400.00
0005434319639	15700	Economy	14400.00
0005433124538	15700	Economy	14400.00
0005433124532	15700	Economy	14400.00
0005435297395	15700	Economy	15900.00
0005434319740	15700	Economy	15900.00
0005434319690	15700	Economy	15900.00
0005433124536	15700	Economy	14400.00
0005434319692	15700	Economy	14400.00
0005433124537	15700	Economy	14400.00
0005433124540	15700	Economy	14400.00
0005433124534	15700	Economy	14400.00
0005434312366	15700	Economy	14400.00
0005434312364	15700	Economy	14400.00
0005435297396	15700	Economy	14400.00
0005434312365	15700	Economy	14400.00
0005435297393	15700	Economy	14400.00
0005434319632	15700	Economy	14400.00
0005433124535	15700	Economy	14400.00
0005434319745	15700	Economy	14400.00
0005434319689	15700	Economy	14400.00
0005434319697	15700	Economy	14400.00
0005434319681	15700	Economy	14400.00
0005434311257	15700	Economy	14400.00
0005434319798	15700	Economy	14400.00
0005434319682	15700	Economy	14400.00
0005434319658	15700	Economy	14400.00
0005433124533	15700	Economy	14400.00
0005434319738	15700	Economy	14400.00
0005434189314	8956	Economy	24900.00
0005434189311	8956	Economy	24900.00
0005434484539	8956	Economy	24900.00
0005434189278	8956	Economy	24900.00
0005434484540	8956	Economy	24900.00
0005434189313	8956	Economy	24900.00
0005434189277	8956	Economy	24900.00
0005434189310	8956	Economy	24900.00
0005434189316	8956	Economy	24900.00
0005434189343	16610	Economy	24900.00
0005434189341	16610	Economy	24900.00
0005434484510	16610	Economy	24900.00
0005434484488	16610	Economy	24900.00
0005434484489	16610	Economy	24900.00
0005434484485	16610	Economy	24900.00
0005434484502	16610	Economy	24900.00
0005434484509	16610	Economy	24900.00
0005434484501	16610	Economy	24900.00
0005434484476	16610	Economy	24900.00
0005434484483	16610	Economy	24900.00
0005434484464	16610	Economy	24900.00
0005434189342	16610	Economy	24900.00
0005433124540	7618	Business	11100.00
0005433722353	7618	Business	11100.00
0005433124536	7618	Economy	3700.00
0005433722350	7618	Economy	4100.00
0005433722333	7618	Economy	4100.00
0005433124539	7618	Economy	4100.00
0005433124532	7618	Economy	3700.00
0005433124535	7618	Economy	3700.00
0005433124531	7618	Economy	3700.00
0005433722342	7618	Economy	3700.00
0005433722347	7618	Economy	3700.00
0005433124533	7618	Economy	3700.00
0005433124534	7618	Economy	3700.00
0005433124537	7618	Economy	3700.00
0005433124538	7618	Economy	3700.00
0005432693960	7619	Business	11100.00
0005432721679	7619	Business	11100.00
0005432721677	7619	Business	11100.00
0005432721678	7619	Business	11100.00
0005432721680	7619	Economy	3700.00
0005432721674	7619	Economy	3700.00
0005432721672	7619	Economy	3700.00
0005432721673	7619	Economy	3700.00
0005433450600	7619	Economy	3700.00
0005432721676	7619	Economy	3700.00
0005432693958	7619	Economy	3700.00
0005432693957	7619	Economy	3700.00
0005432721675	7619	Economy	3700.00
0005432693959	7619	Economy	3700.00
0005433450539	30326	Business	11100.00
0005433450426	30326	Business	11100.00
0005432693723	30326	Business	11100.00
0005433450455	30326	Business	11100.00
0005433450454	30326	Business	11100.00
0005433450388	30326	Economy	3700.00
0005432693805	30326	Economy	3700.00
0005432693744	30326	Economy	3700.00
0005433450503	30326	Economy	3700.00
0005432693681	30326	Economy	4100.00
0005432693845	30326	Economy	4100.00
0005433450436	30326	Economy	3700.00
0005432693844	30326	Economy	3700.00
0005432693634	30326	Economy	3700.00
0005432693793	30326	Economy	3700.00
0005432693792	30326	Economy	3700.00
0005433450460	30326	Economy	3700.00
0005432693755	30326	Economy	3700.00
0005432693689	30326	Economy	3700.00
0005433450459	30326	Economy	3700.00
0005433450489	30326	Economy	3700.00
0005432693758	30326	Economy	3700.00
0005432693690	30326	Economy	3700.00
0005432693597	30326	Economy	3700.00
0005432693685	30326	Economy	3700.00
0005433450386	30326	Economy	3700.00
0005433450440	30326	Economy	3700.00
0005432693633	30326	Economy	3700.00
0005433450389	30326	Economy	3700.00
0005433450437	30326	Economy	3700.00
0005432693721	30326	Economy	3700.00
0005433450492	30326	Economy	3700.00
0005432693682	30326	Economy	3700.00
0005433450502	30326	Economy	3700.00
0005433450393	30326	Economy	3700.00
0005432721600	30325	Business	11100.00
0005432721576	30325	Business	11100.00
0005434310163	30325	Business	11100.00
0005433722489	30325	Business	11100.00
0005435229651	30325	Business	11100.00
0005432721515	30325	Business	11100.00
0005433722497	30325	Business	11100.00
0005432721603	30325	Economy	3700.00
0005434310156	30325	Economy	3700.00
0005432721604	30325	Economy	3700.00
0005432721491	30325	Economy	3700.00
0005433722491	30325	Economy	3700.00
0005435229653	30325	Economy	3700.00
0005432721465	30325	Economy	3700.00
0005433124402	30325	Economy	4100.00
0005433124349	30325	Economy	4100.00
0005434310158	30325	Economy	4100.00
0005432721419	30325	Economy	4100.00
0005432721418	30325	Economy	4100.00
0005433722490	30325	Economy	3700.00
0005433124333	30325	Economy	3700.00
0005434310161	30325	Economy	3700.00
0005433124348	30325	Economy	3700.00
0005432721473	30325	Economy	3700.00
0005432721571	30325	Economy	3700.00
0005432721526	30325	Economy	3700.00
0005433722498	30325	Economy	3700.00
0005435229654	30325	Economy	3700.00
0005435229655	30325	Economy	3700.00
0005433722493	30325	Economy	3700.00
0005432721336	30325	Economy	3700.00
0005433124424	30325	Economy	3700.00
0005432721545	30325	Economy	3700.00
0005434310164	30325	Economy	3700.00
0005432721511	30325	Economy	3700.00
0005433722495	30325	Economy	3700.00
0005434310162	30325	Economy	3700.00
0005434310157	30325	Economy	3700.00
0005432721492	30325	Economy	3700.00
0005434310155	30325	Economy	3700.00
0005435229656	30325	Economy	3700.00
0005435229652	30325	Economy	3700.00
0005432721477	30325	Economy	3700.00
0005432721335	30325	Economy	3700.00
0005432721448	30325	Economy	3700.00
0005432721544	30325	Economy	3700.00
0005432721460	30325	Economy	3700.00
0005435229650	30325	Economy	3700.00
0005432721524	30325	Economy	3700.00
0005433124462	30325	Economy	3700.00
0005432721503	30325	Economy	3700.00
0005433124395	30325	Economy	3700.00
0005433722496	30325	Economy	3700.00
0005433722499	30325	Economy	3700.00
0005433722492	30325	Economy	3700.00
0005432721493	30325	Economy	3700.00
0005433124351	30325	Economy	3700.00
0005434310160	30325	Economy	3700.00
0005432721601	30325	Economy	3700.00
0005433722500	30325	Economy	3700.00
0005433124379	30325	Economy	3700.00
0005433124403	30325	Economy	3700.00
0005432721476	30325	Economy	3700.00
0005433124396	30325	Economy	3700.00
0005434310159	30325	Economy	3700.00
0005432721468	30325	Economy	3700.00
0005432721616	30325	Economy	3700.00
0005432721607	30325	Economy	3700.00
0005433722494	30325	Economy	3700.00
0005433124315	30325	Economy	3700.00
0005433124350	30325	Economy	3700.00
0005432721516	30325	Economy	3700.00
0005433124368	30325	Economy	3700.00
0005433124314	30325	Economy	3700.00
0005433722501	30325	Economy	3700.00
0005432968894	1351	Business	70400.00
0005432271091	1351	Business	70400.00
0005433724939	1351	Business	70400.00
0005433193364	1351	Business	70400.00
0005434587349	1351	Business	70400.00
0005433193391	1351	Business	70400.00
0005432271089	1351	Economy	23500.00
0005433193326	1351	Economy	23500.00
0005433525357	1351	Economy	23500.00
0005433193355	1351	Economy	23500.00
0005433193392	1351	Economy	23500.00
0005434587351	1351	Economy	23500.00
0005434587353	1351	Economy	23500.00
0005432271090	1351	Economy	25800.00
0005433193341	1351	Economy	25800.00
0005433193351	1351	Economy	23500.00
0005434587348	1351	Economy	23500.00
0005432968896	1351	Economy	23500.00
0005433724938	1351	Economy	23500.00
0005432968893	1351	Economy	23500.00
0005433193318	1351	Economy	23500.00
0005433724937	1351	Economy	23500.00
0005434587352	1351	Economy	23500.00
0005434587347	1351	Economy	23500.00
0005433193358	1351	Economy	23500.00
0005433193363	1351	Economy	23500.00
0005433193393	1351	Economy	23500.00
0005433193354	1351	Economy	23500.00
0005433525358	1351	Economy	23500.00
0005434513659	1351	Economy	23500.00
0005433193323	1351	Economy	23500.00
0005433193369	1351	Economy	23500.00
0005433193356	1351	Economy	23500.00
0005433193334	1351	Economy	23500.00
0005434513660	1351	Economy	23500.00
0005433193352	1351	Economy	23500.00
0005433193381	1351	Economy	23500.00
0005432968897	1351	Economy	23500.00
0005434587350	1351	Economy	23500.00
0005433193304	1351	Economy	23500.00
0005433193390	1351	Economy	23500.00
0005432968908	18495	Business	70400.00
0005432928142	18495	Business	70400.00
0005433525240	18495	Business	70400.00
0005434587240	18495	Business	70400.00
0005433193435	18495	Business	70400.00
0005434587219	18495	Business	70400.00
0005434587108	18495	Business	70400.00
0005434587021	18495	Business	70400.00
0005434587254	18495	Economy	23500.00
0005434587216	18495	Economy	23500.00
0005433525241	18495	Economy	23500.00
0005434587220	18495	Economy	23500.00
0005434587119	18495	Economy	23500.00
0005434587243	18495	Economy	25800.00
0005434587230	18495	Economy	25800.00
0005434587010	18495	Economy	25800.00
0005432968909	18495	Economy	25800.00
0005433525313	18495	Economy	23500.00
0005432928144	18495	Economy	23500.00
0005433525314	18495	Economy	23500.00
0005432928141	18495	Economy	23500.00
0005434587235	18495	Economy	23500.00
0005434587198	18495	Economy	23500.00
0005434587157	18495	Economy	23500.00
0005434587239	18495	Economy	23500.00
0005434587185	18495	Economy	23500.00
0005433525274	18495	Economy	23500.00
0005434515032	18495	Economy	23500.00
0005434587131	18495	Economy	23500.00
0005434587154	18495	Economy	23500.00
0005434587109	18495	Economy	23500.00
0005434587223	18495	Economy	23500.00
0005434587247	18495	Economy	23500.00
0005434587281	18495	Economy	23500.00
0005432928143	18495	Economy	23500.00
0005434587153	18495	Economy	23500.00
0005434587231	18495	Economy	23500.00
0005434587085	18495	Economy	23500.00
0005433525253	18495	Economy	23500.00
0005434587208	18495	Economy	23500.00
0005434515018	18495	Economy	23500.00
0005434587128	18495	Economy	23500.00
0005434587248	18495	Economy	23500.00
0005433193434	18495	Economy	23500.00
0005434587129	18495	Economy	23500.00
0005434587282	18495	Economy	23500.00
0005434587222	18495	Economy	23500.00
0005434515019	18495	Economy	23500.00
0005434587110	18495	Economy	23500.00
0005433724916	18495	Economy	23500.00
0005433193436	18495	Economy	23500.00
0005434587111	18495	Economy	23500.00
0005434587242	18495	Economy	23500.00
0005434587009	18495	Economy	23500.00
0005434587199	18495	Economy	23500.00
0005433724917	18495	Economy	23500.00
0005434587269	18495	Economy	23500.00
0005434587283	18495	Economy	23500.00
0005433724915	18495	Economy	23500.00
0005434345245	11468	Economy	4300.00
0005434345255	11468	Economy	4300.00
0005434345247	11468	Economy	4000.00
0005434345240	11468	Economy	4000.00
0005434345241	11468	Economy	4000.00
0005434345244	11468	Economy	4000.00
0005434345246	11468	Economy	4000.00
0005434345253	11468	Economy	4000.00
0005435302307	11468	Economy	4000.00
0005435302278	11468	Economy	4000.00
0005434345239	11468	Economy	4000.00
0005435302291	11468	Economy	4000.00
0005434345243	11468	Economy	4000.00
0005434345256	11468	Economy	4000.00
0005434345257	11468	Economy	4000.00
0005434345249	11468	Economy	4000.00
0005434345248	11468	Economy	4000.00
0005434345251	11468	Economy	4000.00
0005435302292	11468	Economy	4000.00
0005434345242	11468	Economy	4000.00
0005435302301	11468	Economy	4000.00
0005435302310	11468	Economy	4000.00
0005434345258	11468	Economy	4000.00
0005434345252	11468	Economy	4000.00
0005434345254	11468	Economy	4000.00
0005434345250	11468	Economy	4000.00
0005434344979	29790	Economy	4300.00
0005434344841	29790	Economy	4300.00
0005435304276	29790	Economy	4300.00
0005434345068	29790	Economy	4000.00
0005434344911	29790	Economy	4000.00
0005434344960	29790	Economy	4000.00
0005434344961	29790	Economy	4000.00
0005434345067	29790	Economy	4000.00
0005435305080	29790	Economy	4000.00
0005434344959	29790	Economy	4000.00
0005434142702	29790	Economy	4000.00
0005434344901	29790	Economy	4000.00
0005434345127	29790	Economy	4000.00
0005434344861	29790	Economy	4000.00
0005434344884	29790	Economy	4000.00
0005434344909	29790	Economy	4000.00
0005434345054	29790	Economy	4000.00
0005434344893	29790	Economy	4000.00
0005434345036	29790	Economy	4000.00
0005434344867	29790	Economy	4000.00
0005434344978	29790	Economy	4000.00
0005434345010	29790	Economy	4000.00
0005435551771	29790	Economy	4000.00
0005434344921	29790	Economy	4000.00
0005435305079	29790	Economy	4000.00
0005434344900	29790	Economy	4000.00
0005434345037	29790	Economy	4000.00
0005434344919	29790	Economy	4000.00
0005434345009	29790	Economy	4000.00
0005434344922	29790	Economy	4000.00
0005434142699	29790	Economy	4000.00
0005434142703	29790	Economy	4000.00
0005434345011	29790	Economy	4000.00
0005434344920	29790	Economy	4000.00
0005434142679	29790	Economy	4000.00
0005434344945	29790	Economy	4000.00
0005435305081	29790	Economy	4000.00
0005434344767	29790	Economy	4000.00
0005435825405	1292	Business	199800.00
0005433416078	1292	Business	199800.00
0005433416045	1292	Business	199800.00
0005433415966	1292	Business	199800.00
0005433416060	1292	Business	199800.00
0005433416006	1292	Business	199800.00
0005435825408	1292	Business	199800.00
0005433415965	1292	Economy	66600.00
0005433416008	1292	Economy	66600.00
0005435825401	1292	Economy	66600.00
0005433416028	1292	Economy	73200.00
0005433415997	1292	Economy	66600.00
0005435825403	1292	Economy	66600.00
0005432284645	1292	Economy	66600.00
0005435825409	1292	Economy	66600.00
0005433415982	1292	Economy	66600.00
0005433416063	1292	Economy	66600.00
0005433415983	1292	Economy	66600.00
0005433416065	1292	Economy	66600.00
0005435825402	1292	Economy	66600.00
0005433416027	1292	Economy	66600.00
0005433416046	1292	Economy	66600.00
0005435825407	1292	Economy	66600.00
0005433416044	1292	Economy	66600.00
0005433416064	1292	Economy	66600.00
0005435825400	1292	Economy	66600.00
0005433416052	1292	Economy	66600.00
0005433415968	1292	Economy	66600.00
0005435825406	1292	Economy	66600.00
0005435825404	1292	Economy	66600.00
0005435825231	18025	Business	199800.00
0005435825216	18025	Business	199800.00
0005435825271	18025	Business	199800.00
0005435825346	18025	Business	199800.00
0005435825351	18025	Business	199800.00
0005435825191	18025	Business	199800.00
0005435825297	18025	Economy	66600.00
0005435825222	18025	Economy	66600.00
0005435825299	18025	Economy	66600.00
0005435825113	18025	Economy	66600.00
0005435825298	18025	Economy	73200.00
0005435825273	18025	Economy	66600.00
0005435825160	18025	Economy	66600.00
0005435825131	18025	Economy	66600.00
0005435825345	18025	Economy	66600.00
0005435825182	18025	Economy	66600.00
0005435825276	18025	Economy	66600.00
0005435825350	18025	Economy	66600.00
0005435825230	18025	Economy	66600.00
0005435825194	18025	Economy	66600.00
0005435825195	18025	Economy	66600.00
0005435825212	18025	Economy	66600.00
0005433416127	18025	Economy	66600.00
0005435825227	18025	Economy	66600.00
0005435825181	18025	Economy	66600.00
0005433416128	18025	Economy	66600.00
0005434461708	12568	Economy	13500.00
0005434461707	12568	Economy	13500.00
0005434460563	12568	Economy	13500.00
0005434461705	12568	Economy	13500.00
0005434461706	12568	Economy	13500.00
0005434460564	12568	Economy	13500.00
0005434461704	12568	Economy	13500.00
0005432785336	5633	Business	27800.00
0005432785345	5633	Business	27800.00
0005432785352	5633	Business	27800.00
0005435476905	5633	Business	27800.00
0005435243433	5633	Business	27800.00
0005435243411	5633	Business	27800.00
0005435950031	5633	Business	27800.00
0005432785339	5633	Business	27800.00
0005435243349	5633	Business	27800.00
0005435950028	5633	Business	27800.00
0005435950040	5633	Economy	9300.00
0005435243479	5633	Economy	9300.00
0005435476948	5633	Economy	9300.00
0005435243290	5633	Economy	9300.00
0005435626880	5633	Economy	9300.00
0005435243334	5633	Economy	9300.00
0005435950037	5633	Economy	9300.00
0005432785343	5633	Economy	9300.00
0005435950041	5633	Economy	10200.00
0005435243371	5633	Economy	10200.00
0005435950053	5633	Economy	9300.00
0005435950054	5633	Economy	9300.00
0005432785341	5633	Economy	9300.00
0005435476944	5633	Economy	9300.00
0005432785342	5633	Economy	9300.00
0005435243387	5633	Economy	9300.00
0005432785346	5633	Economy	9300.00
0005435243370	5633	Economy	9300.00
0005435243464	5633	Economy	9300.00
0005432785347	5633	Economy	9300.00
0005435950039	5633	Economy	9300.00
0005435243455	5633	Economy	9300.00
0005432785353	5633	Economy	9300.00
0005435243478	5633	Economy	9300.00
0005435243360	5633	Economy	9300.00
0005432785337	5633	Economy	9300.00
0005435950035	5633	Economy	9300.00
0005435243450	5633	Economy	9300.00
0005432785335	5633	Economy	9300.00
0005432785351	5633	Economy	9300.00
0005435950030	5633	Economy	9300.00
0005435476927	5633	Economy	9300.00
0005435950032	5633	Economy	9300.00
0005432785344	5633	Economy	9300.00
0005435243359	5633	Economy	9300.00
0005435950034	5633	Economy	9300.00
0005435950036	5633	Economy	9300.00
0005432785350	5633	Economy	9300.00
0005435243477	5633	Economy	9300.00
0005435476907	5633	Economy	9300.00
0005435243463	5633	Economy	9300.00
0005435476916	5633	Economy	9300.00
0005435950038	5633	Economy	9300.00
0005432785349	5633	Economy	9300.00
0005435243491	5633	Economy	9300.00
0005435243454	5633	Economy	9300.00
0005432785338	5633	Economy	9300.00
0005432144081	5633	Economy	9300.00
0005435243365	5633	Economy	9300.00
0005435950052	5633	Economy	9300.00
0005435950033	5633	Economy	9300.00
0005435243432	5633	Economy	9300.00
0005435243522	5633	Economy	9300.00
0005435243547	5633	Economy	9300.00
0005432785348	5633	Economy	9300.00
0005432785340	5633	Economy	9300.00
0005435243361	5633	Economy	9300.00
0005435243388	5633	Economy	9300.00
0005435950029	5633	Economy	9300.00
0005435243348	5633	Economy	9300.00
0005435476908	5633	Economy	9300.00
0005435949981	15357	Business	27800.00
0005435243637	15357	Business	27800.00
0005435243633	15357	Business	27800.00
0005435243639	15357	Business	27800.00
0005432785049	15357	Business	27800.00
0005432785015	15357	Business	27800.00
0005435243630	15357	Economy	9300.00
0005435243640	15357	Economy	9300.00
0005435243638	15357	Economy	9300.00
0005432785103	15357	Economy	9300.00
0005432784717	15357	Economy	9300.00
0005432785014	15357	Economy	9300.00
0005435476995	15357	Economy	9300.00
0005432784813	15357	Economy	10200.00
0005435243636	15357	Economy	10200.00
0005432785088	15357	Economy	10200.00
0005432784939	15357	Economy	9300.00
0005432785094	15357	Economy	9300.00
0005432784993	15357	Economy	9300.00
0005435243628	15357	Economy	9300.00
0005432785068	15357	Economy	9300.00
0005432784893	15357	Economy	9300.00
0005432784908	15357	Economy	9300.00
0005432785031	15357	Economy	9300.00
0005435243643	15357	Economy	9300.00
0005432784905	15357	Economy	9300.00
0005432784856	15357	Economy	9300.00
0005435243635	15357	Economy	9300.00
0005432784781	15357	Economy	9300.00
0005432784828	15357	Economy	9300.00
0005432784923	15357	Economy	9300.00
0005432785055	15357	Economy	9300.00
0005435243642	15357	Economy	9300.00
0005435243634	15357	Economy	9300.00
0005432784883	15357	Economy	9300.00
0005432784628	15357	Economy	9300.00
0005432784882	15357	Economy	9300.00
0005435950008	15357	Economy	9300.00
0005432785121	15357	Economy	9300.00
0005435243629	15357	Economy	9300.00
0005435626885	15357	Economy	9300.00
0005432784988	15357	Economy	9300.00
0005432785069	15357	Economy	9300.00
0005435476996	15357	Economy	9300.00
0005432785083	15357	Economy	9300.00
0005435243631	15357	Economy	9300.00
0005435243632	15357	Economy	9300.00
0005432784829	15357	Economy	9300.00
0005435243641	15357	Economy	9300.00
0005435950001	15357	Economy	9300.00
0005432784796	15357	Economy	9300.00
0005432784943	15357	Economy	9300.00
0005432784889	15357	Economy	9300.00
0005432784795	15357	Economy	9300.00
0005432784974	15357	Economy	9300.00
0005435626886	15357	Economy	9300.00
0005432785013	15357	Economy	9300.00
0005432785084	15357	Economy	9300.00
0005432785019	15357	Economy	9300.00
0005435950009	15357	Economy	9300.00
0005432785085	15357	Economy	9300.00
0005432785016	15357	Economy	9300.00
0005435851119	4369	Economy	7000.00
0005434463994	4369	Economy	7000.00
0005435851074	4369	Economy	6300.00
0005432848722	4369	Economy	6300.00
0005434463995	4369	Economy	6300.00
0005435851117	4369	Economy	6300.00
0005435851142	4369	Economy	6300.00
0005435851073	4369	Economy	6300.00
0005435851120	4369	Economy	6300.00
0005435851115	4369	Economy	6300.00
0005435851121	4369	Economy	6300.00
0005435851106	4369	Economy	6300.00
0005432848723	4369	Economy	6300.00
0005434462855	4369	Economy	6300.00
0005434462854	4369	Economy	6300.00
0005435851107	4369	Economy	6300.00
0005432848653	28846	Economy	7000.00
0005432848623	28846	Economy	7000.00
0005432848654	28846	Economy	6300.00
0005434461696	28846	Economy	6300.00
0005432848604	28846	Economy	6300.00
0005435851178	28846	Economy	6300.00
0005434461693	28846	Economy	6300.00
0005434461691	28846	Economy	6300.00
0005434461683	28846	Economy	6300.00
0005432848668	28846	Economy	6300.00
0005432848676	28846	Economy	6300.00
0005432848657	28846	Economy	6300.00
0005432848666	28846	Economy	6300.00
0005432848617	28846	Economy	6300.00
0005432848603	28846	Economy	6300.00
0005435851180	28846	Economy	6300.00
0005435851176	28846	Economy	6300.00
0005432848602	28846	Economy	6300.00
0005435851177	28846	Economy	6300.00
0005432848649	28846	Economy	6300.00
0005434461692	28846	Economy	6300.00
0005435851179	28846	Economy	6300.00
0005432848709	28846	Economy	6300.00
0005434926819	6278	Business	11900.00
0005434926828	6278	Business	11900.00
0005433497881	6278	Business	11900.00
0005433497878	6278	Business	11900.00
0005434926833	6278	Business	11900.00
0005435257433	6278	Business	11900.00
0005435257440	6278	Economy	4000.00
0005435257437	6278	Economy	4000.00
0005435257449	6278	Economy	4000.00
0005434926827	6278	Economy	4000.00
0005435257477	6278	Economy	4000.00
0005434926831	6278	Economy	4000.00
0005434926838	6278	Economy	4000.00
0005433497879	6278	Economy	4000.00
0005435257450	6278	Economy	4400.00
0005434444177	6278	Economy	4400.00
0005434926835	6278	Economy	4400.00
0005434926830	6278	Economy	4400.00
0005435257466	6278	Economy	4000.00
0005434444178	6278	Economy	4000.00
0005434926841	6278	Economy	4000.00
0005435257441	6278	Economy	4000.00
0005433497880	6278	Economy	4000.00
0005435257481	6278	Economy	4000.00
0005434926824	6278	Economy	4000.00
0005434444180	6278	Economy	4000.00
0005432075324	6278	Economy	4000.00
0005434926840	6278	Economy	4000.00
0005435257471	6278	Economy	4000.00
0005433497873	6278	Economy	4000.00
0005435257480	6278	Economy	4000.00
0005433497883	6278	Economy	4000.00
0005434926820	6278	Economy	4000.00
0005434926821	6278	Economy	4000.00
0005433497884	6278	Economy	4000.00
0005433497882	6278	Economy	4000.00
0005435257454	6278	Economy	4000.00
0005433497876	6278	Economy	4000.00
0005435257479	6278	Economy	4000.00
0005434926837	6278	Economy	4000.00
0005435257472	6278	Economy	4000.00
0005433497875	6278	Economy	4000.00
0005434926823	6278	Economy	4000.00
0005434926834	6278	Economy	4000.00
0005434926818	6278	Economy	4000.00
0005434926829	6278	Economy	4000.00
0005433497877	6278	Economy	4000.00
0005434926826	6278	Economy	4000.00
0005434926832	6278	Economy	4000.00
0005434926842	6278	Economy	4000.00
0005433497874	6278	Economy	4000.00
0005435257422	6278	Economy	4000.00
0005435257448	6278	Economy	4000.00
0005434444179	6278	Economy	4000.00
0005434926836	6278	Economy	4000.00
0005435257478	6278	Economy	4000.00
0005434926822	6278	Economy	4000.00
0005434926825	6278	Economy	4000.00
0005433497885	6278	Economy	4000.00
0005435257434	6278	Economy	4000.00
0005434926839	6278	Economy	4000.00
0005432075325	6278	Economy	4000.00
0005435257438	6278	Economy	4000.00
0005435257539	20345	Economy	4400.00
0005435257535	20345	Economy	4000.00
0005435257536	20345	Economy	4000.00
0005435257538	20345	Economy	4000.00
0005435257540	20345	Economy	4000.00
0005435257537	20345	Economy	4000.00
0005433497622	20342	Business	11900.00
0005434444074	20342	Business	11900.00
0005434444072	20342	Business	11900.00
0005433497733	20342	Business	11900.00
0005433497692	20342	Business	11900.00
0005434444056	20342	Business	11900.00
0005434443991	20342	Business	11900.00
0005434444050	20342	Business	11900.00
0005434926519	20342	Economy	4000.00
0005434926525	20342	Economy	4000.00
0005433497866	20342	Economy	4000.00
0005434926470	20342	Economy	4000.00
0005434444061	20342	Economy	4000.00
0005434926458	20342	Economy	4000.00
0005434926520	20342	Economy	4000.00
0005434444042	20342	Economy	4000.00
0005433497812	20342	Economy	4000.00
0005433497743	20342	Economy	4400.00
0005434444067	20342	Economy	4400.00
0005433497662	20342	Economy	4400.00
0005434926484	20342	Economy	4400.00
0005434926457	20342	Economy	4000.00
0005433497716	20342	Economy	4000.00
0005433497813	20342	Economy	4000.00
0005433497571	20342	Economy	4000.00
0005433497720	20342	Economy	4000.00
0005433497717	20342	Economy	4000.00
0005434926493	20342	Economy	4000.00
0005434926462	20342	Economy	4000.00
0005433497754	20342	Economy	4000.00
0005433497602	20342	Economy	4000.00
0005434926506	20342	Economy	4000.00
0005433497691	20342	Economy	4000.00
0005434444030	20342	Economy	4000.00
0005433497560	20342	Economy	4000.00
0005433497661	20342	Economy	4000.00
0005434926494	20342	Economy	4000.00
0005434926564	20342	Economy	4000.00
0005433497695	20342	Economy	4000.00
0005434926423	20342	Economy	4000.00
0005433497710	20342	Economy	4000.00
0005434926533	20342	Economy	4000.00
0005433497794	20342	Economy	4000.00
0005433497572	20342	Economy	4000.00
0005434926474	20342	Economy	4000.00
0005434926328	20342	Economy	4000.00
0005433497709	20342	Economy	4000.00
0005434926400	20342	Economy	4000.00
0005433497742	20342	Economy	4000.00
0005434926417	20342	Economy	4000.00
0005434444058	20342	Economy	4000.00
0005433497653	20342	Economy	4000.00
0005433497678	20342	Economy	4000.00
0005433497777	20342	Economy	4000.00
0005434444010	20342	Economy	4000.00
0005434926374	20342	Economy	4000.00
0005434444057	20342	Economy	4000.00
0005434444075	20342	Economy	4000.00
0005434926483	20342	Economy	4000.00
0005434443992	20342	Economy	4000.00
0005434444043	20342	Economy	4000.00
0005434926548	20342	Economy	4000.00
0005434444040	20342	Economy	4000.00
0005433497688	20342	Economy	4000.00
0005434926471	20342	Economy	4000.00
0005434926473	20342	Economy	4000.00
0005434926496	20342	Economy	4000.00
0005433497737	20342	Economy	4000.00
0005433497573	20342	Economy	4000.00
0005433497752	20342	Economy	4000.00
0005433497650	20342	Economy	4000.00
0005434444078	20342	Economy	4000.00
0005434444073	20342	Economy	4000.00
0005434926468	20342	Economy	4000.00
0005433497839	20342	Economy	4000.00
0005434926536	20342	Economy	4000.00
0005434444060	20342	Economy	4000.00
0005434926461	20342	Economy	4000.00
0005433497689	20342	Economy	4000.00
0005434444055	20342	Economy	4000.00
0005432784996	12209	Business	41200.00
0005432785179	12209	Business	41200.00
0005432785070	12209	Business	41200.00
0005435243645	12209	Business	41200.00
0005432785072	12209	Business	41200.00
0005432784938	12209	Business	41200.00
0005432785012	12209	Business	41200.00
0005432784875	12209	Business	41200.00
0005435243650	12209	Business	41200.00
0005432785178	12209	Business	41200.00
0005432784987	12209	Business	41200.00
0005432784833	12209	Economy	13700.00
0005432784906	12209	Economy	13700.00
0005432785082	12209	Economy	13700.00
0005432784887	12209	Economy	13700.00
0005432785056	12209	Economy	13700.00
0005432784777	12209	Economy	13700.00
0005432785051	12209	Economy	13700.00
0005432784752	12209	Economy	15100.00
0005432784886	12209	Economy	15100.00
0005432784990	12209	Economy	15100.00
0005432785081	12209	Economy	15100.00
0005432784751	12209	Economy	13700.00
0005432785091	12209	Economy	13700.00
0005432785175	12209	Economy	13700.00
0005432785078	12209	Economy	13700.00
0005432784936	12209	Economy	13700.00
0005432784932	12209	Economy	13700.00
0005435243646	12209	Economy	13700.00
0005432784819	12209	Economy	13700.00
0005432784937	12209	Economy	13700.00
0005432784918	12209	Economy	13700.00
0005432784874	12209	Economy	13700.00
0005432784980	12209	Economy	13700.00
0005432785002	12209	Economy	13700.00
0005432784818	12209	Economy	13700.00
0005432784783	12209	Economy	13700.00
0005432784750	12209	Economy	13700.00
0005432784964	12209	Economy	13700.00
0005435243648	12209	Economy	13700.00
0005432784729	12209	Economy	13700.00
0005432785052	12209	Economy	13700.00
0005432785071	12209	Economy	13700.00
0005432785000	12209	Economy	13700.00
0005432785180	12209	Economy	13700.00
0005432784961	12209	Economy	13700.00
0005432784877	12209	Economy	13700.00
0005432784991	12209	Economy	13700.00
0005432784965	12209	Economy	13700.00
0005432785024	12209	Economy	13700.00
0005432785174	12209	Economy	13700.00
0005432784901	12209	Economy	13700.00
0005435243652	12209	Economy	13700.00
0005432785027	12209	Economy	13700.00
0005432784979	12209	Economy	13700.00
0005432785124	12209	Economy	13700.00
0005432785137	12209	Economy	13700.00
0005432784866	12209	Economy	13700.00
0005432784890	12209	Economy	13700.00
0005435243649	12209	Economy	13700.00
0005435243655	12209	Economy	13700.00
0005432784970	12209	Economy	13700.00
0005432784952	12209	Economy	13700.00
0005435243647	12209	Economy	13700.00
0005435243653	12209	Economy	13700.00
0005435243644	12209	Economy	13700.00
0005435243651	12209	Economy	13700.00
0005432785100	12209	Economy	13700.00
0005432785099	12209	Economy	13700.00
0005432785140	12209	Economy	13700.00
0005432784850	12209	Economy	13700.00
0005435243654	12209	Economy	13700.00
0005435243413	15437	Business	41200.00
0005435243421	15437	Business	41200.00
0005435243353	15437	Business	41200.00
0005435243438	15437	Business	41200.00
0005432785318	15437	Business	41200.00
0005432785322	15437	Business	41200.00
0005435243354	15437	Business	41200.00
0005432785320	15437	Business	41200.00
0005435243286	15437	Economy	13700.00
0005435243362	15437	Economy	13700.00
0005432785319	15437	Economy	13700.00
0005435243355	15437	Economy	13700.00
0005432785329	15437	Economy	13700.00
0005432785333	15437	Economy	13700.00
0005435243357	15437	Economy	15100.00
0005432785321	15437	Economy	15100.00
0005432785330	15437	Economy	13700.00
0005435243437	15437	Economy	13700.00
0005435243379	15437	Economy	13700.00
0005435243376	15437	Economy	13700.00
0005435243374	15437	Economy	13700.00
0005435243495	15437	Economy	13700.00
0005435243422	15437	Economy	13700.00
0005432785334	15437	Economy	13700.00
0005432785328	15437	Economy	13700.00
0005432785326	15437	Economy	13700.00
0005435243412	15437	Economy	13700.00
0005432785316	15437	Economy	13700.00
0005432785327	15437	Economy	13700.00
0005435243480	15437	Economy	13700.00
0005435243427	15437	Economy	13700.00
0005432785317	15437	Economy	13700.00
0005435243414	15437	Economy	13700.00
0005435243423	15437	Economy	13700.00
0005435243380	15437	Economy	13700.00
0005432785331	15437	Economy	13700.00
0005435243469	15437	Economy	13700.00
0005435243470	15437	Economy	13700.00
0005435243375	15437	Economy	13700.00
0005432785323	15437	Economy	13700.00
0005432785324	15437	Economy	13700.00
0005435243426	15437	Economy	13700.00
0005435243425	15437	Economy	13700.00
0005435243494	15437	Economy	13700.00
0005435243428	15437	Economy	13700.00
0005432785315	15437	Economy	13700.00
0005435243496	15437	Economy	13700.00
0005435243327	15437	Economy	13700.00
0005432785325	15437	Economy	13700.00
0005432785332	15437	Economy	13700.00
0005435243439	15437	Economy	13700.00
0005435243400	15437	Economy	13700.00
0005435243451	15437	Economy	13700.00
0005434880452	10098	Business	49700.00
0005435914194	10098	Business	49700.00
0005434880006	10098	Business	49700.00
0005434880317	10098	Business	49700.00
0005434880498	10098	Business	49700.00
0005434880366	10098	Business	49700.00
0005434880601	10098	Business	49700.00
0005434880199	10098	Business	49700.00
0005434880382	10098	Business	49700.00
0005434758941	10098	Business	49700.00
0005434880439	10098	Business	49700.00
0005434880602	10098	Business	49700.00
0005434880375	10098	Business	49700.00
0005434880544	10098	Business	49700.00
0005435914203	10098	Business	49700.00
0005434880029	10098	Business	49700.00
0005435914198	10098	Business	49700.00
0005434880354	10098	Economy	16600.00
0005434880646	10098	Economy	16600.00
0005434880123	10098	Economy	16600.00
0005435914182	10098	Economy	16600.00
0005434880363	10098	Economy	16600.00
0005434880543	10098	Economy	16600.00
0005434880168	10098	Economy	16600.00
0005434880171	10098	Economy	16600.00
0005435914184	10098	Economy	16600.00
0005434880339	10098	Economy	16600.00
0005434880374	10098	Economy	16600.00
0005434880391	10098	Economy	16600.00
0005434880376	10098	Economy	16600.00
0005434880801	10098	Economy	18200.00
0005434880454	10098	Economy	18200.00
0005434880128	10098	Economy	16600.00
0005435914183	10098	Economy	16600.00
0005435914188	10098	Economy	16600.00
0005434880427	10098	Economy	16600.00
0005434880323	10098	Economy	16600.00
0005434880287	10098	Economy	16600.00
0005435914204	10098	Economy	16600.00
0005434880832	10098	Economy	16600.00
0005435914185	10098	Economy	16600.00
0005435914200	10098	Economy	16600.00
0005434880033	10098	Economy	16600.00
0005434880358	10098	Economy	16600.00
0005435914196	10098	Economy	16600.00
0005434880405	10098	Economy	16600.00
0005435914192	10098	Economy	16600.00
0005434880214	10098	Economy	16600.00
0005435914199	10098	Economy	16600.00
0005434880604	10098	Economy	16600.00
0005434880455	10098	Economy	16600.00
0005434880469	10098	Economy	16600.00
0005434880357	10098	Economy	16600.00
0005434879861	10098	Economy	16600.00
0005434880360	10098	Economy	16600.00
0005434880367	10098	Economy	16600.00
0005434880225	10098	Economy	16600.00
0005434880428	10098	Economy	16600.00
0005435914190	10098	Economy	16600.00
0005434880406	10098	Economy	16600.00
0005434880523	10098	Economy	16600.00
0005434880020	10098	Economy	16600.00
0005434880107	10098	Economy	16600.00
0005434880802	10098	Economy	16600.00
0005434880238	10098	Economy	16600.00
0005435914201	10098	Economy	16600.00
0005434880075	10098	Economy	16600.00
0005434880300	10098	Economy	16600.00
0005434880022	10098	Economy	16600.00
0005434879667	10098	Economy	16600.00
0005435914191	10098	Economy	16600.00
0005435914195	10098	Economy	16600.00
0005434880394	10098	Economy	16600.00
0005435914193	10098	Economy	16600.00
0005435914202	10098	Economy	16600.00
0005434880200	10098	Economy	16600.00
0005434880769	10098	Economy	16600.00
0005435914197	10098	Economy	16600.00
0005434880002	10098	Economy	16600.00
0005435914186	10098	Economy	16600.00
0005434879980	10098	Economy	16600.00
0005434880062	10098	Economy	16600.00
0005435914187	10098	Economy	16600.00
0005434880242	10098	Economy	16600.00
0005434880355	10098	Economy	16600.00
0005434880021	10098	Economy	16600.00
0005434880365	10098	Economy	16600.00
0005434880340	10098	Economy	16600.00
0005434880496	10098	Economy	16600.00
0005435914189	10098	Economy	16600.00
0005434880265	10098	Economy	16600.00
0005434880312	10098	Economy	16600.00
0005434880831	10098	Economy	16600.00
0005434880407	10098	Economy	16600.00
0005434880313	10098	Economy	16600.00
0005434880309	10098	Economy	16600.00
0005434880137	10098	Economy	16600.00
0005434880768	10098	Economy	16600.00
0005434880318	10098	Economy	16600.00
0005434910174	14633	Business	49700.00
0005435914049	14633	Business	49700.00
0005435914048	14633	Business	49700.00
0005435914094	14633	Business	49700.00
0005434880941	14633	Business	49700.00
0005434880964	14633	Business	49700.00
0005435914044	14633	Business	49700.00
0005435914052	14633	Business	49700.00
0005435914020	14633	Business	49700.00
0005435914033	14633	Business	49700.00
0005434880968	14633	Economy	16600.00
0005434880965	14633	Economy	16600.00
0005435914019	14633	Economy	16600.00
0005434880950	14633	Economy	16600.00
0005434880967	14633	Economy	16600.00
0005434880942	14633	Economy	16600.00
0005434880966	14633	Economy	16600.00
0005434880946	14633	Economy	18200.00
0005434880944	14633	Economy	18200.00
0005435913981	14633	Economy	16600.00
0005435914022	14633	Economy	16600.00
0005434880963	14633	Economy	16600.00
0005435914021	14633	Economy	16600.00
0005434880954	14633	Economy	16600.00
0005435914064	14633	Economy	16600.00
0005435914034	14633	Economy	16600.00
0005434880947	14633	Economy	16600.00
0005435914065	14633	Economy	16600.00
0005434880952	14633	Economy	16600.00
0005434880962	14633	Economy	16600.00
0005434880959	14633	Economy	16600.00
0005434880945	14633	Economy	16600.00
0005434880943	14633	Economy	16600.00
0005434910173	14633	Economy	16600.00
0005434880948	14633	Economy	16600.00
0005434910158	14633	Economy	16600.00
0005435914035	14633	Economy	16600.00
0005435914036	14633	Economy	16600.00
0005434880957	14633	Economy	16600.00
0005434880955	14633	Economy	16600.00
0005434880949	14633	Economy	16600.00
0005434880953	14633	Economy	16600.00
0005435914050	14633	Economy	16600.00
0005435914051	14633	Economy	16600.00
0005434880961	14633	Economy	16600.00
0005435914047	14633	Economy	16600.00
0005435914025	14633	Economy	16600.00
0005434880956	14633	Economy	16600.00
0005435914043	14633	Economy	16600.00
0005435914046	14633	Economy	16600.00
0005435914031	14633	Economy	16600.00
0005434880951	14633	Economy	16600.00
0005434880960	14633	Economy	16600.00
0005434880958	14633	Economy	16600.00
0005434252180	9213	Economy	20300.00
0005435660465	9213	Economy	20300.00
0005434252167	9213	Economy	20300.00
0005435660466	9213	Economy	20300.00
0005434252179	9213	Economy	20300.00
0005434252158	9213	Economy	20300.00
0005435660464	9213	Economy	20300.00
0005434252153	9213	Economy	20300.00
0005434252166	9213	Economy	20300.00
0005434252171	9213	Economy	20300.00
0005434252208	9213	Economy	20300.00
0005434252173	9213	Economy	20300.00
0005435660422	24681	Economy	22400.00
0005435660375	24681	Economy	22400.00
0005435660368	24681	Economy	20300.00
0005435660367	24681	Economy	20300.00
0005435660396	24681	Economy	20300.00
0005435660397	24681	Economy	20300.00
0005435660343	24681	Economy	20300.00
0005435660344	24681	Economy	20300.00
0005434252244	24681	Economy	20300.00
0005435660393	24681	Economy	20300.00
0005434252243	24681	Economy	20300.00
0005435660369	24681	Economy	20300.00
0005435933566	24681	Economy	20300.00
0005435660386	24681	Economy	20300.00
0005432967621	2780	Business	33000.00
0005433681949	2780	Business	33000.00
0005433681946	2780	Business	33000.00
0005432967579	2780	Business	33000.00
0005432967584	2780	Business	33000.00
0005432967473	2780	Business	33000.00
0005432967516	2780	Business	33000.00
0005433681948	2780	Economy	11000.00
0005433684482	2780	Economy	11000.00
0005433681950	2780	Economy	11000.00
0005432967562	2780	Economy	11000.00
0005432967532	2780	Economy	12100.00
0005432967596	2780	Economy	12100.00
0005433681955	2780	Economy	12100.00
0005432967531	2780	Economy	11000.00
0005432967414	2780	Economy	11000.00
0005432967515	2780	Economy	11000.00
0005432967493	2780	Economy	11000.00
0005432222938	2780	Economy	11000.00
0005432967533	2780	Economy	11000.00
0005432967511	2780	Economy	11000.00
0005433681947	2780	Economy	11000.00
0005432967597	2780	Economy	11000.00
0005432967446	2780	Economy	11000.00
0005432222936	2780	Economy	11000.00
0005433681945	2780	Economy	11000.00
0005432967580	2780	Economy	11000.00
0005432222937	2780	Economy	11000.00
0005432967495	2780	Economy	11000.00
0005433681953	2780	Economy	11000.00
0005432967370	2780	Economy	11000.00
0005433681954	2780	Economy	11000.00
0005432967599	2780	Economy	11000.00
0005433681951	2780	Economy	11000.00
0005433681952	2780	Economy	11000.00
0005432967494	2780	Economy	11000.00
0005432967474	2780	Economy	11000.00
0005432967530	2780	Economy	11000.00
0005432967518	2780	Economy	11000.00
0005433684473	29166	Business	33000.00
0005433681744	29166	Business	33000.00
0005432967676	29166	Business	33000.00
0005433681743	29166	Business	33000.00
0005432967677	29166	Business	33000.00
0005432967672	29166	Business	33000.00
0005433681522	29166	Business	33000.00
0005433681695	29166	Business	33000.00
0005433687748	29166	Business	33000.00
0005433681424	29166	Economy	11000.00
0005433681613	29166	Economy	11000.00
0005433681675	29166	Economy	11000.00
0005433681498	29166	Economy	11000.00
0005433681600	29166	Economy	12100.00
0005433681602	29166	Economy	12100.00
0005433690960	29166	Economy	11000.00
0005433681728	29166	Economy	11000.00
0005433681585	29166	Economy	11000.00
0005433681729	29166	Economy	11000.00
0005432967671	29166	Economy	11000.00
0005433681425	29166	Economy	11000.00
0005433681693	29166	Economy	11000.00
0005433681643	29166	Economy	11000.00
0005433681618	29166	Economy	11000.00
0005433681521	29166	Economy	11000.00
0005433681472	29166	Economy	11000.00
0005433681473	29166	Economy	11000.00
0005433690972	29166	Economy	11000.00
0005433690965	29166	Economy	11000.00
0005432005293	29166	Economy	11000.00
0005433681647	29166	Economy	11000.00
0005433681705	29166	Economy	11000.00
0005433681617	29166	Economy	11000.00
0005433681710	29166	Economy	11000.00
0005433684462	29166	Economy	11000.00
0005433681745	29166	Economy	11000.00
0005433681708	29166	Economy	11000.00
0005433690976	29166	Economy	11000.00
0005433681583	29166	Economy	11000.00
0005433681527	29166	Economy	11000.00
0005433681634	29166	Economy	11000.00
0005433681601	29166	Economy	11000.00
0005433681582	29166	Economy	11000.00
0005433681584	29166	Economy	11000.00
0005433681616	29166	Economy	11000.00
0005433681718	29166	Economy	11000.00
0005433681648	29166	Economy	11000.00
0005433681548	29166	Economy	11000.00
0005433681614	29166	Economy	11000.00
0005433690961	29166	Economy	11000.00
0005432005292	29166	Economy	11000.00
0005432967673	29166	Economy	11000.00
0005433681615	29166	Economy	11000.00
0005433681692	29166	Economy	11000.00
0005433690967	29166	Economy	11000.00
0005432967675	29166	Economy	11000.00
0005432967674	29166	Economy	11000.00
0005433681391	29166	Economy	11000.00
0005433681735	29166	Economy	11000.00
0005433681748	29166	Economy	11000.00
0005433616759	9317	Business	132900.00
0005433616790	9317	Business	132900.00
0005433616758	9317	Business	132900.00
0005434269155	9317	Business	132900.00
0005433616782	9317	Business	132900.00
0005433634809	9317	Business	132900.00
0005433634811	9317	Business	132900.00
0005432756940	9317	Business	132900.00
0005433578196	9317	Business	132900.00
0005433616779	9317	Business	132900.00
0005433578197	9317	Business	132900.00
0005432756941	9317	Business	132900.00
0005433616756	9317	Economy	48700.00
0005433616787	9317	Economy	48700.00
0005433616776	9317	Economy	44300.00
0005433634798	9317	Economy	44300.00
0005435983716	9317	Economy	44300.00
0005433616770	9317	Economy	44300.00
0005433616762	9317	Economy	44300.00
0005435983714	9317	Economy	44300.00
0005433616760	9317	Economy	44300.00
0005433616788	9317	Economy	44300.00
0005433616785	9317	Economy	44300.00
0005433634807	9317	Economy	44300.00
0005435983713	9317	Economy	44300.00
0005433634796	9317	Economy	44300.00
0005433578198	9317	Economy	44300.00
0005433634801	9317	Economy	44300.00
0005433616773	9317	Economy	44300.00
0005433616764	9317	Economy	44300.00
0005433616772	9317	Economy	44300.00
0005433616789	9317	Economy	44300.00
0005432145170	9317	Economy	44300.00
0005433616765	9317	Economy	44300.00
0005433634803	9317	Economy	44300.00
0005435983715	9317	Economy	44300.00
0005434163786	9317	Economy	44300.00
0005433634804	9317	Economy	44300.00
0005434163808	9317	Economy	44300.00
0005432756942	9317	Economy	44300.00
0005433616780	9317	Economy	44300.00
0005433616778	9317	Economy	44300.00
0005435983717	9317	Economy	44300.00
0005434163793	9317	Economy	44300.00
0005433616781	9317	Economy	48700.00
0005433616761	9317	Economy	48700.00
0005433634810	9317	Economy	44300.00
0005434163790	9317	Economy	44300.00
0005433634802	9317	Economy	48700.00
0005433616768	9317	Economy	44300.00
0005433634799	9317	Economy	44300.00
0005433616757	9317	Economy	44300.00
0005433616767	9317	Economy	44300.00
0005433616771	9317	Economy	44300.00
0005433634808	9317	Economy	44300.00
0005433634800	9317	Economy	44300.00
0005433616763	9317	Economy	44300.00
0005434152827	9317	Economy	44300.00
0005433616769	9317	Economy	44300.00
0005434269143	9317	Economy	44300.00
0005433616783	9317	Economy	44300.00
0005433634806	9317	Economy	44300.00
0005433616784	9317	Economy	44300.00
0005434153570	9317	Economy	44300.00
0005433616774	9317	Economy	44300.00
0005432145171	9317	Economy	44300.00
0005433578195	9317	Economy	44300.00
0005434269151	9317	Economy	44300.00
0005433616786	9317	Economy	44300.00
0005433634794	9317	Economy	44300.00
0005434269147	9317	Economy	44300.00
0005433616766	9317	Economy	44300.00
0005433616777	9317	Economy	44300.00
0005433634805	9317	Economy	44300.00
0005433634795	9317	Economy	44300.00
0005434269146	9317	Economy	44300.00
0005433634797	9317	Economy	44300.00
0005434163831	9317	Economy	44300.00
0005434163791	9317	Economy	44300.00
0005433616775	9317	Economy	44300.00
0005435983712	9317	Economy	44300.00
0005433634613	25224	Business	132900.00
0005433634666	25224	Business	132900.00
0005433634574	25224	Business	132900.00
0005433578175	25224	Business	132900.00
0005433616499	25224	Business	132900.00
0005433634599	25224	Business	132900.00
0005433616116	25224	Business	132900.00
0005435854085	25224	Business	132900.00
0005433616298	25224	Business	132900.00
0005433634547	25224	Business	132900.00
0005433616095	25224	Business	132900.00
0005433634590	25224	Business	132900.00
0005433616071	25224	Business	132900.00
0005433578083	25224	Business	132900.00
0005433634561	25224	Business	132900.00
0005433578176	25224	Business	132900.00
0005433616147	25224	Business	132900.00
0005434273126	25224	Business	132900.00
0005433616252	25224	Business	132900.00
0005433616228	25224	Business	132900.00
0005433616188	25224	Business	132900.00
0005433615953	25224	Business	132900.00
0005433578122	25224	Business	132900.00
0005433616077	25224	Economy	48700.00
0005433634488	25224	Economy	48700.00
0005433616448	25224	Economy	48700.00
0005433634482	25224	Economy	48700.00
0005433616078	25224	Economy	48700.00
0005433578108	25224	Economy	44300.00
0005433616001	25224	Economy	44300.00
0005433616150	25224	Economy	44300.00
0005433616152	25224	Economy	44300.00
0005433616446	25224	Economy	44300.00
0005433634472	25224	Economy	44300.00
0005433634673	25224	Economy	44300.00
0005433634568	25224	Economy	44300.00
0005433578043	25224	Economy	44300.00
0005433578049	25224	Economy	44300.00
0005433634523	25224	Economy	44300.00
0005433616250	25224	Economy	44300.00
0005433616649	25224	Economy	44300.00
0005433616109	25224	Economy	44300.00
0005433616094	25224	Economy	44300.00
0005433616442	25224	Economy	44300.00
0005433616007	25224	Economy	44300.00
0005433634630	25224	Economy	44300.00
0005433616280	25224	Economy	44300.00
0005433634473	25224	Economy	44300.00
0005433616451	25224	Economy	44300.00
0005433616153	25224	Economy	44300.00
0005433616151	25224	Economy	44300.00
0005433616080	25224	Economy	44300.00
0005433634420	25224	Economy	44300.00
0005433616149	25224	Economy	44300.00
0005433616447	25224	Economy	44300.00
0005433578153	25224	Economy	44300.00
0005433616325	25224	Economy	44300.00
0005433634592	25224	Economy	44300.00
0005433616566	25224	Economy	44300.00
0005433634516	25224	Economy	44300.00
0005433634665	25224	Economy	44300.00
0005433634621	25224	Economy	44300.00
0005433616335	25224	Economy	44300.00
0005434163887	25224	Economy	44300.00
0005433634569	25224	Economy	44300.00
0005433634541	25224	Economy	44300.00
0005433634417	25224	Economy	44300.00
0005433615981	25224	Economy	44300.00
0005433616336	25224	Economy	44300.00
0005435854092	25224	Economy	44300.00
0005435854093	25224	Economy	44300.00
0005433616306	25224	Economy	44300.00
0005433616286	25224	Economy	44300.00
0005433616311	25224	Economy	44300.00
0005433616009	25224	Economy	44300.00
0005433616239	25224	Economy	44300.00
0005433634608	25224	Economy	44300.00
0005434163883	25224	Economy	44300.00
0005433634511	25224	Economy	44300.00
0005433578097	25224	Economy	44300.00
0005433615886	25224	Economy	44300.00
0005434163882	25224	Economy	44300.00
0005433634640	25224	Economy	44300.00
0005433616085	25224	Economy	44300.00
0005433616042	25224	Economy	44300.00
0005433634545	25224	Economy	48700.00
0005434163884	25224	Economy	48700.00
0005433616057	25224	Economy	48700.00
0005433578107	25224	Economy	44300.00
0005435854091	25224	Economy	44300.00
0005433616480	25224	Economy	44300.00
0005433634419	25224	Economy	44300.00
0005433616450	25224	Economy	48700.00
0005433634587	25224	Economy	44300.00
0005433634600	25224	Economy	44300.00
0005433578109	25224	Economy	44300.00
0005435854084	25224	Economy	44300.00
0005433616281	25224	Economy	44300.00
0005434163885	25224	Economy	44300.00
0005433616309	25224	Economy	44300.00
0005433578082	25224	Economy	44300.00
0005433616287	25224	Economy	44300.00
0005433578076	25224	Economy	44300.00
0005433634639	25224	Economy	44300.00
0005433616346	25224	Economy	44300.00
0005433616139	25224	Economy	44300.00
0005433616187	25224	Economy	44300.00
0005433616008	25224	Economy	44300.00
0005433616317	25224	Economy	44300.00
0005433634593	25224	Economy	44300.00
0005434273135	25224	Economy	44300.00
0005433634540	25224	Economy	44300.00
0005433634579	25224	Economy	44300.00
0005433616251	25224	Economy	44300.00
0005433616197	25224	Economy	44300.00
0005433634548	25224	Economy	44300.00
0005433616263	25224	Economy	44300.00
0005433616264	25224	Economy	44300.00
0005435854094	25224	Economy	44300.00
0005433616294	25224	Economy	44300.00
0005434273127	25224	Economy	44300.00
0005433616310	25224	Economy	44300.00
0005433634638	25224	Economy	44300.00
0005433634507	25224	Economy	44300.00
0005433616238	25224	Economy	44300.00
0005433634609	25224	Economy	44300.00
0005433616064	25224	Economy	44300.00
0005433634580	25224	Economy	44300.00
0005433616069	25224	Economy	44300.00
0005433634641	25224	Economy	44300.00
0005433616276	25224	Economy	44300.00
0005433616334	25224	Economy	44300.00
0005433616477	25224	Economy	44300.00
0005433634581	25224	Economy	44300.00
0005433578048	25224	Economy	44300.00
0005433634522	25224	Economy	44300.00
0005433616650	25224	Economy	44300.00
0005433634622	25224	Economy	44300.00
0005433634345	25224	Economy	44300.00
0005433634471	25224	Economy	44300.00
0005433634470	25224	Economy	44300.00
0005433634464	25224	Economy	44300.00
0005434163886	25224	Economy	44300.00
0005433616579	25224	Economy	44300.00
0005433616441	25224	Economy	44300.00
0005433634489	25224	Economy	44300.00
0005433634546	25224	Economy	44300.00
0005433634607	25224	Economy	44300.00
0005433616115	25224	Economy	44300.00
0005433634520	25224	Economy	44300.00
0005433616227	25224	Economy	44300.00
0005435947522	4248	Business	193100.00
0005435987053	4248	Business	193100.00
0005435947586	4248	Economy	70800.00
0005435947569	4248	Economy	64400.00
0005432185032	4248	Economy	64400.00
0005435947584	4248	Economy	64400.00
0005435983727	4248	Economy	64400.00
0005432185033	4248	Economy	64400.00
0005435947590	4248	Economy	64400.00
0005435960175	4248	Economy	64400.00
0005432571411	4248	Economy	64400.00
0005435947601	4248	Economy	64400.00
0005435947603	4248	Economy	64400.00
0005435987051	4248	Economy	64400.00
0005435947591	4248	Economy	64400.00
0005435987055	4248	Economy	64400.00
0005435947583	4248	Economy	64400.00
0005435987052	4248	Economy	64400.00
0005435987049	4248	Economy	64400.00
0005435987047	4248	Economy	64400.00
0005435947542	4248	Economy	64400.00
0005435947588	4248	Economy	64400.00
0005435947617	4248	Economy	64400.00
0005435987054	4248	Economy	70800.00
0005434271355	4248	Economy	64400.00
0005434271356	4248	Economy	64400.00
0005435947567	4248	Economy	64400.00
0005435960174	4248	Economy	64400.00
0005435856289	4248	Economy	64400.00
0005435947551	4248	Economy	64400.00
0005435854077	4248	Economy	64400.00
0005435947585	4248	Economy	64400.00
0005435987050	4248	Economy	64400.00
0005432571389	4248	Economy	64400.00
0005435947576	4248	Economy	64400.00
0005435947602	4248	Economy	64400.00
0005435947618	4248	Economy	64400.00
0005435987048	4248	Economy	64400.00
0005435947587	4248	Economy	64400.00
0005435983728	4248	Economy	64400.00
0005432571436	26617	Business	193100.00
0005435947672	26617	Business	193100.00
0005435947678	26617	Business	193100.00
0005432571437	26617	Business	193100.00
0005435986895	26617	Economy	70800.00
0005435986932	26617	Economy	70800.00
0005435856362	26617	Economy	64400.00
0005435947673	26617	Economy	64400.00
0005435947674	26617	Economy	64400.00
0005435477022	26617	Economy	64400.00
0005435856330	26617	Economy	64400.00
0005435477016	26617	Economy	64400.00
0005435986984	26617	Economy	64400.00
0005434268063	26617	Economy	64400.00
0005435986943	26617	Economy	64400.00
0005435477024	26617	Economy	64400.00
0005435986861	26617	Economy	64400.00
0005435477013	26617	Economy	64400.00
0005435947675	26617	Economy	64400.00
0005432571435	26617	Economy	64400.00
0005435947671	26617	Economy	64400.00
0005435986899	26617	Economy	64400.00
0005435986985	26617	Economy	64400.00
0005435477014	26617	Economy	64400.00
0005435477015	26617	Economy	70800.00
0005435477018	26617	Economy	64400.00
0005435986973	26617	Economy	64400.00
0005435986862	26617	Economy	64400.00
0005435947676	26617	Economy	64400.00
0005435986966	26617	Economy	64400.00
0005434268064	26617	Economy	64400.00
0005435986917	26617	Economy	64400.00
0005435477025	26617	Economy	64400.00
0005435477021	26617	Economy	64400.00
0005435477023	26617	Economy	64400.00
0005435947677	26617	Economy	64400.00
0005435477020	26617	Economy	64400.00
0005435477019	26617	Economy	64400.00
0005435477017	26617	Economy	64400.00
0005435986916	26617	Economy	64400.00
0005434326035	366	Business	21500.00
0005434326036	366	Business	21500.00
0005433075255	366	Business	21500.00
0005434326027	366	Business	21500.00
0005433075422	366	Business	21500.00
0005432949156	366	Business	21500.00
0005432949357	366	Business	21500.00
0005432949236	366	Business	21500.00
0005432949368	366	Business	21500.00
0005432949222	366	Business	21500.00
0005434088011	366	Business	21500.00
0005432949409	366	Business	21500.00
0005432949371	366	Business	21500.00
0005434326026	366	Business	21500.00
0005432949263	366	Business	21500.00
0005434088024	366	Business	21500.00
0005432949205	366	Business	21500.00
0005432949235	366	Business	21500.00
0005433570930	366	Business	21500.00
0005433134238	366	Business	21500.00
0005433929866	366	Business	21500.00
0005432949271	366	Business	21500.00
0005433570938	366	Business	21500.00
0005432949369	366	Business	21500.00
0005434088014	366	Business	21500.00
0005433570936	366	Business	21500.00
0005432949382	366	Business	21500.00
0005433075369	366	Economy	7900.00
0005432949356	366	Economy	7900.00
0005433570941	366	Economy	7900.00
0005433075358	366	Economy	7900.00
0005433570924	366	Economy	7900.00
0005432949373	366	Economy	7900.00
0005432949372	366	Economy	7200.00
0005432949273	366	Economy	7200.00
0005432949155	366	Economy	7200.00
0005432949391	366	Economy	7200.00
0005433570920	366	Economy	7200.00
0005434088023	366	Economy	7200.00
0005434088019	366	Economy	7200.00
0005432949276	366	Economy	7200.00
0005432949424	366	Economy	7200.00
0005434326025	366	Economy	7200.00
0005433129376	366	Economy	7200.00
0005433570915	366	Economy	7200.00
0005432949206	366	Economy	7200.00
0005433570931	366	Economy	7200.00
0005433075389	366	Economy	7200.00
0005434088017	366	Economy	7200.00
0005433075408	366	Economy	7200.00
0005433570945	366	Economy	7200.00
0005433075334	366	Economy	7200.00
0005432949410	366	Economy	7200.00
0005433570939	366	Economy	7200.00
0005433129365	366	Economy	7200.00
0005433075254	366	Economy	7200.00
0005433929865	366	Economy	7200.00
0005433075445	366	Economy	7200.00
0005434326029	366	Economy	7200.00
0005434326028	366	Economy	7200.00
0005432949366	366	Economy	7200.00
0005433570922	366	Economy	7200.00
0005432949272	366	Economy	7200.00
0005432949425	366	Economy	7200.00
0005433129375	366	Economy	7200.00
0005432949392	366	Economy	7200.00
0005434088021	366	Economy	7200.00
0005433570926	366	Economy	7200.00
0005433075423	366	Economy	7200.00
0005433075335	366	Economy	7200.00
0005433570923	366	Economy	7200.00
0005434326034	366	Economy	7200.00
0005432949412	366	Economy	7200.00
0005433134233	366	Economy	7200.00
0005432949318	366	Economy	7200.00
0005434088016	366	Economy	7200.00
0005434088020	366	Economy	7200.00
0005432949319	366	Economy	7200.00
0005432949320	366	Economy	7200.00
0005434326031	366	Economy	7200.00
0005433570944	366	Economy	7200.00
0005433129383	366	Economy	7900.00
0005433134221	366	Economy	7900.00
0005432949287	366	Economy	7900.00
0005432949231	366	Economy	7900.00
0005432949390	366	Economy	7200.00
0005433075348	366	Economy	7200.00
0005432949405	366	Economy	7200.00
0005432949370	366	Economy	7200.00
0005432949230	366	Economy	7900.00
0005433075291	366	Economy	7200.00
0005432949397	366	Economy	7200.00
0005432949422	366	Economy	7200.00
0005432949393	366	Economy	7200.00
0005433570935	366	Economy	7200.00
0005433570937	366	Economy	7200.00
0005432949411	366	Economy	7200.00
0005432949344	366	Economy	7200.00
0005433570917	366	Economy	7200.00
0005433570919	366	Economy	7200.00
0005432949296	366	Economy	7200.00
0005433570925	366	Economy	7200.00
0005433075446	366	Economy	7200.00
0005434088054	366	Economy	7200.00
0005433570918	366	Economy	7200.00
0005434326030	366	Economy	7200.00
0005432949401	366	Economy	7200.00
0005434326032	366	Economy	7200.00
0005434088015	366	Economy	7200.00
0005433570916	366	Economy	7200.00
0005433134242	366	Economy	7200.00
0005433075413	366	Economy	7200.00
0005434326033	366	Economy	7200.00
0005433075325	366	Economy	7200.00
0005433570933	366	Economy	7200.00
0005432949289	366	Economy	7200.00
0005433075366	366	Economy	7200.00
0005432949223	366	Economy	7200.00
0005433570940	366	Economy	7200.00
0005433570913	366	Economy	7200.00
0005432949426	366	Economy	7200.00
0005432949348	366	Economy	7200.00
0005434088013	366	Economy	7200.00
0005432949177	366	Economy	7200.00
0005432949423	366	Economy	7200.00
0005433570927	366	Economy	7200.00
0005434088018	366	Economy	7200.00
0005432949367	366	Economy	7200.00
0005433570928	366	Economy	7200.00
0005433570943	366	Economy	7200.00
0005432949297	366	Economy	7200.00
0005434088027	366	Economy	7200.00
0005433129384	366	Economy	7200.00
0005433570929	366	Economy	7200.00
0005433570921	366	Economy	7200.00
0005433134226	366	Economy	7200.00
0005434088012	366	Economy	7200.00
0005433075359	366	Economy	7200.00
0005434088022	366	Economy	7200.00
0005433570934	366	Economy	7200.00
0005434088026	366	Economy	7200.00
0005432949340	366	Economy	7200.00
0005434088053	366	Economy	7200.00
0005433129385	366	Economy	7200.00
0005433570942	366	Economy	7200.00
0005434088025	366	Economy	7200.00
0005433570932	366	Economy	7200.00
0005433570914	366	Economy	7200.00
0005432949446	366	Economy	7200.00
0005433075365	366	Economy	7200.00
0005433570404	11590	Business	21500.00
0005433075534	11590	Business	21500.00
0005433570240	11590	Business	21500.00
0005433570123	11590	Business	21500.00
0005433075537	11590	Business	21500.00
0005433570106	11590	Business	21500.00
0005432949653	11590	Business	21500.00
0005433570097	11590	Business	21500.00
0005433570225	11590	Business	21500.00
0005433570259	11590	Business	21500.00
0005433570051	11590	Business	21500.00
0005433075530	11590	Business	21500.00
0005433570216	11590	Business	21500.00
0005433570125	11590	Business	21500.00
0005432949646	11590	Business	21500.00
0005433570052	11590	Business	21500.00
0005433570166	11590	Business	21500.00
0005433570290	11590	Business	21500.00
0005434087922	11590	Business	21500.00
0005433569944	11590	Business	21500.00
0005433570368	11590	Business	21500.00
0005433570405	11590	Business	21500.00
0005433570181	11590	Economy	7900.00
0005432949639	11590	Economy	7900.00
0005432949640	11590	Economy	7900.00
0005432949647	11590	Economy	7900.00
0005433570331	11590	Economy	7200.00
0005432949642	11590	Economy	7200.00
0005433570176	11590	Economy	7200.00
0005433075535	11590	Economy	7200.00
0005433570118	11590	Economy	7200.00
0005432949663	11590	Economy	7200.00
0005433570053	11590	Economy	7200.00
0005432949641	11590	Economy	7200.00
0005433570272	11590	Economy	7200.00
0005432949655	11590	Economy	7200.00
0005433570271	11590	Economy	7200.00
0005433075531	11590	Economy	7200.00
0005432949644	11590	Economy	7200.00
0005433075533	11590	Economy	7200.00
0005433570253	11590	Economy	7200.00
0005432949645	11590	Economy	7200.00
0005434087925	11590	Economy	7200.00
0005433570161	11590	Economy	7200.00
0005432949661	11590	Economy	7200.00
0005433570406	11590	Economy	7200.00
0005433075536	11590	Economy	7200.00
0005433570392	11590	Economy	7200.00
0005432949656	11590	Economy	7200.00
0005432949652	11590	Economy	7200.00
0005433570410	11590	Economy	7200.00
0005432949637	11590	Economy	7200.00
0005432949657	11590	Economy	7200.00
0005432192413	11590	Economy	7200.00
0005433570330	11590	Economy	7200.00
0005432949651	11590	Economy	7200.00
0005433570241	11590	Economy	7200.00
0005433570353	11590	Economy	7200.00
0005433570310	11590	Economy	7200.00
0005432949659	11590	Economy	7200.00
0005433134263	11590	Economy	7200.00
0005433570180	11590	Economy	7200.00
0005433570218	11590	Economy	7200.00
0005432949658	11590	Economy	7200.00
0005432949643	11590	Economy	7200.00
0005433570242	11590	Economy	7200.00
0005433570175	11590	Economy	7200.00
0005432192411	11590	Economy	7200.00
0005433570209	11590	Economy	7200.00
0005433570263	11590	Economy	7900.00
0005433570133	11590	Economy	7900.00
0005433570239	11590	Economy	7900.00
0005432949654	11590	Economy	7900.00
0005433570134	11590	Economy	7900.00
0005432949638	11590	Economy	7200.00
0005433570385	11590	Economy	7200.00
0005433570162	11590	Economy	7900.00
0005433570288	11590	Economy	7200.00
0005433570332	11590	Economy	7200.00
0005433570377	11590	Economy	7200.00
0005433075538	11590	Economy	7200.00
0005433570207	11590	Economy	7200.00
0005433131839	11590	Economy	7200.00
0005433570188	11590	Economy	7200.00
0005433570132	11590	Economy	7200.00
0005432949662	11590	Economy	7200.00
0005433570183	11590	Economy	7200.00
0005433570049	11590	Economy	7200.00
0005433570173	11590	Economy	7200.00
0005433570287	11590	Economy	7200.00
0005433075539	11590	Economy	7200.00
0005433570210	11590	Economy	7200.00
0005433075540	11590	Economy	7200.00
0005433570050	11590	Economy	7200.00
0005434087924	11590	Economy	7200.00
0005432949650	11590	Economy	7200.00
0005433570140	11590	Economy	7200.00
0005433131840	11590	Economy	7200.00
0005433570174	11590	Economy	7200.00
0005433570072	11590	Economy	7200.00
0005433570147	11590	Economy	7200.00
0005433570249	11590	Economy	7200.00
0005433075532	11590	Economy	7200.00
0005433570276	11590	Economy	7200.00
0005434087923	11590	Economy	7200.00
0005433570155	11590	Economy	7200.00
0005432949660	11590	Economy	7200.00
0005432949648	11590	Economy	7200.00
0005433570298	11590	Economy	7200.00
0005433570351	11590	Economy	7200.00
0005433570151	11590	Economy	7200.00
0005433075528	11590	Economy	7200.00
0005433570182	11590	Economy	7200.00
0005432192412	11590	Economy	7200.00
0005433570407	11590	Economy	7200.00
0005433570131	11590	Economy	7200.00
0005433570352	11590	Economy	7200.00
0005433570137	11590	Economy	7200.00
0005432949649	11590	Economy	7200.00
0005433075529	11590	Economy	7200.00
0005433817555	13998	Economy	6300.00
0005433817559	13998	Economy	6300.00
0005434733082	13998	Economy	6300.00
0005433817556	13998	Economy	6300.00
0005434733083	13998	Economy	6300.00
0005433817558	13998	Economy	6300.00
0005434733084	13998	Economy	6300.00
0005433817547	13998	Economy	6300.00
0005433817557	13998	Economy	6300.00
0005432985749	2372	Business	184500.00
0005433435310	2372	Business	184500.00
0005435983647	2372	Business	184500.00
0005432985704	2372	Business	184500.00
0005433755862	2372	Business	184500.00
0005433435355	2372	Business	184500.00
0005433755846	2372	Business	184500.00
0005432300438	2372	Business	184500.00
0005432300439	2372	Business	184500.00
0005432655889	2372	Business	184500.00
0005432985816	2372	Business	184500.00
0005432869668	2372	Business	184500.00
0005434731265	2372	Economy	67700.00
0005433435268	2372	Economy	67700.00
0005435983649	2372	Economy	67700.00
0005433755866	2372	Economy	67700.00
0005432985746	2372	Economy	61500.00
0005432226239	2372	Economy	61500.00
0005432655888	2372	Economy	61500.00
0005433435327	2372	Economy	61500.00
0005435983646	2372	Economy	61500.00
0005433435297	2372	Economy	61500.00
0005433435311	2372	Economy	61500.00
0005433755842	2372	Economy	61500.00
0005435983668	2372	Economy	61500.00
0005432985788	2372	Economy	61500.00
0005432985792	2372	Economy	61500.00
0005433755864	2372	Economy	61500.00
0005432985645	2372	Economy	61500.00
0005432985849	2372	Economy	61500.00
0005433755852	2372	Economy	61500.00
0005435983651	2372	Economy	61500.00
0005435983663	2372	Economy	61500.00
0005433755858	2372	Economy	61500.00
0005432985789	2372	Economy	61500.00
0005435983665	2372	Economy	61500.00
0005435983658	2372	Economy	61500.00
0005432985763	2372	Economy	61500.00
0005433755848	2372	Economy	61500.00
0005433755844	2372	Economy	61500.00
0005433435329	2372	Economy	61500.00
0005432869683	2372	Economy	61500.00
0005433755863	2372	Economy	61500.00
0005433755860	2372	Economy	61500.00
0005433755857	2372	Economy	61500.00
0005433435379	2372	Economy	61500.00
0005432985777	2372	Economy	61500.00
0005432985886	2372	Economy	61500.00
0005432985640	2372	Economy	61500.00
0005435983664	2372	Economy	61500.00
0005432226240	2372	Economy	61500.00
0005433766753	2372	Economy	61500.00
0005432869682	2372	Economy	61500.00
0005435983661	2372	Economy	61500.00
0005432985712	2372	Economy	61500.00
0005435983662	2372	Economy	61500.00
0005433755849	2372	Economy	61500.00
0005435983654	2372	Economy	61500.00
0005432985871	2372	Economy	61500.00
0005432226238	2372	Economy	61500.00
0005433766752	2372	Economy	61500.00
0005432985818	2372	Economy	61500.00
0005435983648	2372	Economy	61500.00
0005433435215	2372	Economy	61500.00
0005432985885	2372	Economy	61500.00
0005433435337	2372	Economy	61500.00
0005433435216	2372	Economy	61500.00
0005433435352	2372	Economy	61500.00
0005432985748	2372	Economy	61500.00
0005432985750	2372	Economy	61500.00
0005435983657	2372	Economy	61500.00
0005435983652	2372	Economy	61500.00
0005433755845	2372	Economy	61500.00
0005433755865	2372	Economy	61500.00
0005433755851	2372	Economy	61500.00
0005433755843	2372	Economy	61500.00
0005432985851	2372	Economy	61500.00
0005432985735	2372	Economy	61500.00
0005432226237	2372	Economy	67700.00
0005432869654	2372	Economy	61500.00
0005432985881	2372	Economy	61500.00
0005433755854	2372	Economy	67700.00
0005433435127	2372	Economy	61500.00
0005432985747	2372	Economy	61500.00
0005432985953	2372	Economy	61500.00
0005432985832	2372	Economy	61500.00
0005432985870	2372	Economy	61500.00
0005433766768	2372	Economy	61500.00
0005433755847	2372	Economy	61500.00
0005433435147	2372	Economy	61500.00
0005432985646	2372	Economy	61500.00
0005432985856	2372	Economy	61500.00
0005433435336	2372	Economy	61500.00
0005433755859	2372	Economy	61500.00
0005433755856	2372	Economy	61500.00
0005432985764	2372	Economy	61500.00
0005435983659	2372	Economy	61500.00
0005435983667	2372	Economy	61500.00
0005432300437	2372	Economy	61500.00
0005433755855	2372	Economy	61500.00
0005433766751	2372	Economy	61500.00
0005433755861	2372	Economy	61500.00
0005435983645	2372	Economy	61500.00
0005435983656	2372	Economy	61500.00
0005432985887	2372	Economy	61500.00
0005432985848	2372	Economy	61500.00
0005433435205	2372	Economy	61500.00
0005434731256	2372	Economy	61500.00
0005435983660	2372	Economy	61500.00
0005434731262	2372	Economy	61500.00
0005433435369	2372	Economy	61500.00
0005435983650	2372	Economy	61500.00
0005433755850	2372	Economy	61500.00
0005432655890	2372	Economy	61500.00
0005433435370	2372	Economy	61500.00
0005432985711	2372	Economy	61500.00
0005433435359	2372	Economy	61500.00
0005435983653	2372	Economy	61500.00
0005433435291	2372	Economy	61500.00
0005432869669	2372	Economy	61500.00
0005435983655	2372	Economy	61500.00
0005432869684	2372	Economy	61500.00
0005432655887	2372	Economy	61500.00
0005435983666	2372	Economy	61500.00
0005433755853	2372	Economy	61500.00
0005433755841	2372	Economy	61500.00
0005433755517	26205	Business	184500.00
0005434731292	26205	Business	184500.00
0005433755447	26205	Business	184500.00
0005435983419	26205	Business	184500.00
0005435983173	26205	Business	184500.00
0005432655814	26205	Business	184500.00
0005435983202	26205	Business	184500.00
0005433755617	26205	Business	184500.00
0005434731291	26205	Business	184500.00
0005433435499	26205	Business	184500.00
0005433435492	26205	Business	184500.00
0005435983200	26205	Business	184500.00
0005435983356	26205	Business	184500.00
0005433755176	26205	Business	184500.00
0005432985994	26205	Economy	67700.00
0005435983237	26205	Economy	67700.00
0005433435496	26205	Economy	61500.00
0005435983110	26205	Economy	61500.00
0005435983215	26205	Economy	61500.00
0005435983360	26205	Economy	61500.00
0005432985998	26205	Economy	61500.00
0005435983289	26205	Economy	61500.00
0005432985996	26205	Economy	61500.00
0005435983348	26205	Economy	61500.00
0005433755624	26205	Economy	61500.00
0005432655801	26205	Economy	61500.00
0005435983290	26205	Economy	61500.00
0005435983308	26205	Economy	61500.00
0005435983448	26205	Economy	61500.00
0005433435488	26205	Economy	61500.00
0005433755584	26205	Economy	61500.00
0005433755417	26205	Economy	61500.00
0005433435500	26205	Economy	61500.00
0005435983109	26205	Economy	61500.00
0005433755488	26205	Economy	61500.00
0005433435491	26205	Economy	61500.00
0005434376168	26205	Economy	61500.00
0005432655726	26205	Economy	61500.00
0005435983138	26205	Economy	61500.00
0005432655789	26205	Economy	61500.00
0005433755524	26205	Economy	61500.00
0005433755638	26205	Economy	61500.00
0005433755457	26205	Economy	61500.00
0005433755472	26205	Economy	61500.00
0005435983255	26205	Economy	61500.00
0005432655760	26205	Economy	61500.00
0005432655803	26205	Economy	61500.00
0005435983177	26205	Economy	61500.00
0005433755412	26205	Economy	61500.00
0005435983324	26205	Economy	61500.00
0005435983221	26205	Economy	61500.00
0005433755551	26205	Economy	61500.00
0005433755448	26205	Economy	61500.00
0005433755446	26205	Economy	61500.00
0005433755405	26205	Economy	61500.00
0005433435487	26205	Economy	61500.00
0005433435490	26205	Economy	61500.00
0005432655779	26205	Economy	61500.00
0005432655815	26205	Economy	61500.00
0005435983347	26205	Economy	61500.00
0005435983429	26205	Economy	61500.00
0005433755360	26205	Economy	61500.00
0005433755175	26205	Economy	61500.00
0005435983217	26205	Economy	61500.00
0005432655756	26205	Economy	61500.00
0005435983122	26205	Economy	61500.00
0005433755244	26205	Economy	61500.00
0005435983326	26205	Economy	61500.00
0005433755271	26205	Economy	61500.00
0005433755643	26205	Economy	61500.00
0005435983114	26205	Economy	61500.00
0005435983113	26205	Economy	61500.00
0005432985995	26205	Economy	61500.00
0005432869720	26205	Economy	61500.00
0005435983212	26205	Economy	61500.00
0005435983134	26205	Economy	61500.00
0005432655784	26205	Economy	61500.00
0005433755393	26205	Economy	61500.00
0005433755362	26205	Economy	61500.00
0005435983276	26205	Economy	61500.00
0005435983291	26205	Economy	61500.00
0005435983203	26205	Economy	67700.00
0005432869719	26205	Economy	67700.00
0005435983367	26205	Economy	61500.00
0005435983133	26205	Economy	61500.00
0005433435494	26205	Economy	67700.00
0005433755353	26205	Economy	67700.00
0005432655796	26205	Economy	61500.00
0005435983174	26205	Economy	61500.00
0005432655757	26205	Economy	61500.00
0005435983137	26205	Economy	61500.00
0005433435489	26205	Economy	61500.00
0005435983447	26205	Economy	61500.00
0005435982986	26205	Economy	61500.00
0005433755210	26205	Economy	61500.00
0005433435497	26205	Economy	61500.00
0005432985997	26205	Economy	61500.00
0005435983275	26205	Economy	61500.00
0005432869717	26205	Economy	61500.00
0005433435486	26205	Economy	61500.00
0005433755668	26205	Economy	61500.00
0005432655802	26205	Economy	61500.00
0005435983176	26205	Economy	61500.00
0005433755390	26205	Economy	61500.00
0005433435495	26205	Economy	61500.00
0005432655798	26205	Economy	61500.00
0005433755596	26205	Economy	61500.00
0005435983231	26205	Economy	61500.00
0005435983333	26205	Economy	61500.00
0005433755550	26205	Economy	61500.00
0005433435498	26205	Economy	61500.00
0005433755242	26205	Economy	61500.00
0005433755270	26205	Economy	61500.00
0005433755593	26205	Economy	61500.00
0005435983129	26205	Economy	61500.00
0005433755637	26205	Economy	61500.00
0005433755413	26205	Economy	61500.00
0005435983254	26205	Economy	61500.00
0005433755552	26205	Economy	61500.00
0005435983325	26205	Economy	61500.00
0005433755278	26205	Economy	61500.00
0005435983374	26205	Economy	61500.00
0005433755449	26205	Economy	61500.00
0005435983236	26205	Economy	61500.00
0005432655805	26205	Economy	61500.00
0005432655728	26205	Economy	61500.00
0005433755243	26205	Economy	61500.00
0005435983235	26205	Economy	61500.00
0005433435493	26205	Economy	61500.00
0005433755389	26205	Economy	61500.00
0005432869718	26205	Economy	61500.00
0005432655729	26205	Economy	61500.00
0005432985993	26205	Economy	61500.00
0005435983016	26205	Economy	61500.00
0005435983283	26205	Economy	61500.00
0005433755599	26205	Economy	61500.00
0005435983123	26205	Economy	61500.00
0005433755696	26205	Economy	61500.00
0005435983496	26205	Economy	61500.00
0005434376041	1516	Business	38900.00
0005434376028	1516	Business	38900.00
0005434376167	1516	Business	38900.00
0005433152113	1516	Business	38900.00
0005433931522	1516	Business	38900.00
0005434376025	1516	Business	38900.00
0005433152292	1516	Economy	13000.00
0005433152260	1516	Economy	13000.00
0005433152231	1516	Economy	13000.00
0005434376188	1516	Economy	13000.00
0005433152239	1516	Economy	13000.00
0005433152134	1516	Economy	13000.00
0005433152316	1516	Economy	13000.00
0005433931529	1516	Economy	13000.00
0005432268087	1516	Economy	13000.00
0005433152286	1516	Economy	13000.00
0005433931535	1516	Economy	13000.00
0005433152043	1516	Economy	13000.00
0005433764722	1516	Economy	13000.00
0005433152305	1516	Economy	13000.00
0005433152287	1516	Economy	13000.00
0005434376044	1516	Economy	13000.00
0005433152143	1516	Economy	13000.00
0005434376023	1516	Economy	13000.00
0005433152114	1516	Economy	13000.00
0005433152214	1516	Economy	13000.00
0005433152327	1516	Economy	13000.00
0005433152213	1516	Economy	13000.00
0005434376021	1516	Economy	13000.00
0005433152177	1516	Economy	14300.00
0005433152245	1516	Economy	14300.00
0005434376035	1516	Economy	14300.00
0005433152273	1516	Economy	14300.00
0005434376026	1516	Economy	13000.00
0005433931543	1516	Economy	13000.00
0005434376039	1516	Economy	13000.00
0005434376027	1516	Economy	13000.00
0005433152137	1516	Economy	13000.00
0005434376029	1516	Economy	13000.00
0005433152207	1516	Economy	13000.00
0005434376036	1516	Economy	13000.00
0005433152328	1516	Economy	13000.00
0005434376042	1516	Economy	13000.00
0005433764720	1516	Economy	13000.00
0005433152246	1516	Economy	13000.00
0005433152215	1516	Economy	13000.00
0005433152065	1516	Economy	13000.00
0005434376187	1516	Economy	13000.00
0005433152220	1516	Economy	13000.00
0005434376043	1516	Economy	13000.00
0005433152357	1516	Economy	13000.00
0005433764728	1516	Economy	13000.00
0005434376037	1516	Economy	13000.00
0005433152288	1516	Economy	13000.00
0005433152064	1516	Economy	13000.00
0005434376189	1516	Economy	13000.00
0005434376033	1516	Economy	13000.00
0005433152062	1516	Economy	13000.00
0005434376236	1516	Economy	13000.00
0005432268088	1516	Economy	13000.00
0005434376038	1516	Economy	13000.00
0005434376030	1516	Economy	13000.00
0005434376024	1516	Economy	13000.00
0005434376022	1516	Economy	13000.00
0005433152112	1516	Economy	13000.00
0005433152238	1516	Economy	13000.00
0005433152259	1516	Economy	13000.00
0005433461654	1516	Economy	13000.00
0005434376032	1516	Economy	13000.00
0005433152274	1516	Economy	13000.00
0005434376034	1516	Economy	13000.00
0005433152358	1516	Economy	13000.00
0005434376031	1516	Economy	13000.00
0005433152184	1516	Economy	13000.00
0005433461653	1516	Economy	13000.00
0005434376040	1516	Economy	13000.00
0005433764719	1516	Economy	13000.00
0005433463926	20112	Business	38900.00
0005434375702	20112	Business	38900.00
0005434375554	20112	Business	38900.00
0005434375656	20112	Business	38900.00
0005433463929	20112	Business	38900.00
0005433463927	20112	Business	38900.00
0005434375619	20112	Business	38900.00
0005434375487	20112	Business	38900.00
0005434375649	20112	Business	38900.00
0005434375523	20112	Business	38900.00
0005433463941	20112	Business	38900.00
0005433461626	20112	Economy	13000.00
0005434375658	20112	Economy	13000.00
0005433463938	20112	Economy	13000.00
0005434375524	20112	Economy	13000.00
0005434375607	20112	Economy	13000.00
0005433461625	20112	Economy	13000.00
0005434375625	20112	Economy	13000.00
0005433152401	20112	Economy	13000.00
0005434375659	20112	Economy	13000.00
0005434375522	20112	Economy	13000.00
0005434375398	20112	Economy	13000.00
0005432056406	20112	Economy	13000.00
0005434375600	20112	Economy	13000.00
0005433152396	20112	Economy	13000.00
0005434375682	20112	Economy	13000.00
0005434375553	20112	Economy	13000.00
0005434375562	20112	Economy	13000.00
0005433461612	20112	Economy	13000.00
0005433152400	20112	Economy	13000.00
0005433461620	20112	Economy	13000.00
0005434375666	20112	Economy	13000.00
0005433931558	20112	Economy	13000.00
0005434375752	20112	Economy	13000.00
0005434375465	20112	Economy	13000.00
0005433152398	20112	Economy	13000.00
0005434375797	20112	Economy	13000.00
0005434375689	20112	Economy	13000.00
0005433152397	20112	Economy	13000.00
0005434375796	20112	Economy	13000.00
0005434375566	20112	Economy	13000.00
0005434375599	20112	Economy	13000.00
0005434375604	20112	Economy	13000.00
0005434375753	20112	Economy	13000.00
0005434375578	20112	Economy	14300.00
0005433152403	20112	Economy	14300.00
0005434375703	20112	Economy	14300.00
0005433463934	20112	Economy	14300.00
0005433463932	20112	Economy	14300.00
0005434375618	20112	Economy	13000.00
0005433152404	20112	Economy	13000.00
0005433461614	20112	Economy	13000.00
0005433152399	20112	Economy	13000.00
0005433463940	20112	Economy	13000.00
0005434375603	20112	Economy	13000.00
0005433463936	20112	Economy	13000.00
0005434375494	20112	Economy	13000.00
0005433152405	20112	Economy	13000.00
0005434029729	20112	Economy	13000.00
0005433461624	20112	Economy	13000.00
0005433931559	20112	Economy	13000.00
0005433463935	20112	Economy	13000.00
0005433461622	20112	Economy	13000.00
0005434375687	20112	Economy	13000.00
0005433461618	20112	Economy	13000.00
0005434375568	20112	Economy	13000.00
0005433463928	20112	Economy	13000.00
0005433461616	20112	Economy	13000.00
0005434375651	20112	Economy	13000.00
0005433461613	20112	Economy	13000.00
0005434375677	20112	Economy	13000.00
0005434375612	20112	Economy	13000.00
0005434375664	20112	Economy	13000.00
0005433152406	20112	Economy	13000.00
0005434375678	20112	Economy	13000.00
0005433152402	20112	Economy	13000.00
0005433461623	20112	Economy	13000.00
0005434375792	20112	Economy	13000.00
0005434375547	20112	Economy	13000.00
0005434375561	20112	Economy	13000.00
0005434375601	20112	Economy	13000.00
0005433463930	20112	Economy	13000.00
0005433461621	20112	Economy	13000.00
0005433463931	20112	Economy	13000.00
0005434375849	20112	Economy	13000.00
0005433152391	20112	Economy	13000.00
0005434375646	20112	Economy	13000.00
0005433461615	20112	Economy	13000.00
0005434375714	20112	Economy	13000.00
0005433152394	20112	Economy	13000.00
0005434375608	20112	Economy	13000.00
0005434375681	20112	Economy	13000.00
0005434375546	20112	Economy	13000.00
0005434375565	20112	Economy	13000.00
0005433152395	20112	Economy	13000.00
0005434029730	20112	Economy	13000.00
0005434375744	20112	Economy	13000.00
0005434375399	20112	Economy	13000.00
0005433461619	20112	Economy	13000.00
0005434375591	20112	Economy	13000.00
0005433463937	20112	Economy	13000.00
0005434375690	20112	Economy	13000.00
0005434375721	20112	Economy	13000.00
0005433461599	20112	Economy	13000.00
0005434375564	20112	Economy	13000.00
0005433152393	20112	Economy	13000.00
0005434375567	20112	Economy	13000.00
0005433152392	20112	Economy	13000.00
0005432425977	573	Business	27500.00
0005432425978	573	Business	27500.00
0005432425972	573	Business	27500.00
0005432425976	573	Business	27500.00
0005432425989	573	Business	27500.00
0005432425959	573	Business	27500.00
0005432425998	573	Business	27500.00
0005432425985	573	Business	27500.00
0005432425951	573	Business	27500.00
0005432425949	573	Business	27500.00
0005432425990	573	Business	27500.00
0005432425947	573	Economy	10100.00
0005432425956	573	Economy	9200.00
0005432425955	573	Economy	9200.00
0005432425997	573	Economy	9200.00
0005432425974	573	Economy	9200.00
0005432425970	573	Economy	9200.00
0005432425961	573	Economy	9200.00
0005432425983	573	Economy	9200.00
0005432425980	573	Economy	9200.00
0005432425966	573	Economy	9200.00
0005432425993	573	Economy	9200.00
0005432425948	573	Economy	9200.00
0005432425965	573	Economy	9200.00
0005432425981	573	Economy	9200.00
0005432425950	573	Economy	9200.00
0005432425954	573	Economy	9200.00
0005432425960	573	Economy	9200.00
0005432425968	573	Economy	9200.00
0005432425957	573	Economy	9200.00
0005432425973	573	Economy	9200.00
0005432425991	573	Economy	9200.00
0005432425975	573	Economy	9200.00
0005432425979	573	Economy	9200.00
0005432425967	573	Economy	9200.00
0005432425969	573	Economy	9200.00
0005432425958	573	Economy	9200.00
0005432425952	573	Economy	9200.00
0005432425971	573	Economy	9200.00
0005432425964	573	Economy	9200.00
0005432425984	573	Economy	9200.00
0005432425953	573	Economy	9200.00
0005432425988	573	Economy	9200.00
0005432425986	573	Economy	9200.00
0005432425992	573	Economy	9200.00
0005432425996	573	Economy	9200.00
0005432425963	573	Economy	9200.00
0005432425946	573	Economy	9200.00
0005432425995	573	Economy	9200.00
0005432425987	573	Economy	9200.00
0005432425994	573	Economy	9200.00
0005432425982	573	Economy	9200.00
0005432425962	573	Economy	9200.00
0005433262040	12933	Business	27500.00
0005433262032	12933	Business	27500.00
0005433262038	12933	Business	27500.00
0005433262028	12933	Economy	10100.00
0005433262042	12933	Economy	10100.00
0005433262034	12933	Economy	9200.00
0005433262039	12933	Economy	9200.00
0005433262036	12933	Economy	9200.00
0005433262030	12933	Economy	9200.00
0005433262037	12933	Economy	9200.00
0005433262033	12933	Economy	9200.00
0005433262031	12933	Economy	9200.00
0005433262029	12933	Economy	9200.00
0005433766768	12933	Economy	9200.00
0005433262041	12933	Economy	9200.00
0005433262035	12933	Economy	9200.00
0005432302441	12933	Economy	9200.00
0005433262043	12933	Economy	9200.00
0005432425482	12931	Business	27500.00
0005432425468	12931	Business	27500.00
0005432425382	12931	Business	27500.00
0005432425383	12931	Business	27500.00
0005432425350	12931	Business	27500.00
0005432425466	12931	Business	27500.00
0005432425492	12931	Economy	9200.00
0005432425322	12931	Economy	9200.00
0005432425376	12931	Economy	9200.00
0005432425400	12931	Economy	9200.00
0005432425340	12931	Economy	9200.00
0005432425508	12931	Economy	9200.00
0005432425443	12931	Economy	9200.00
0005432425336	12931	Economy	9200.00
0005432425491	12931	Economy	9200.00
0005432425487	12931	Economy	9200.00
0005432425393	12931	Economy	9200.00
0005432425402	12931	Economy	9200.00
0005432425493	12931	Economy	9200.00
0005432425384	12931	Economy	9200.00
0005432425300	12931	Economy	9200.00
0005432425512	12931	Economy	9200.00
0005432425364	12931	Economy	9200.00
0005432425445	12931	Economy	9200.00
0005432425349	12931	Economy	9200.00
0005432425363	12931	Economy	10100.00
0005432425295	12931	Economy	9200.00
0005432425510	12931	Economy	10100.00
0005432425511	12931	Economy	9200.00
0005432425483	12931	Economy	9200.00
0005432425298	12931	Economy	9200.00
0005432425503	12931	Economy	9200.00
0005432425442	12931	Economy	9200.00
0005432425477	12931	Economy	9200.00
0005432425478	12931	Economy	9200.00
0005432425439	12931	Economy	9200.00
0005432425480	12931	Economy	9200.00
0005432425500	12931	Economy	9200.00
0005432425465	12931	Economy	9200.00
0005432425401	12931	Economy	9200.00
0005432425361	12931	Economy	9200.00
0005432425457	12931	Economy	9200.00
0005432425476	12931	Economy	9200.00
0005432425507	12931	Economy	9200.00
0005432425371	12931	Economy	9200.00
0005432425362	12931	Economy	9200.00
0005432425506	12931	Economy	9200.00
0005432425444	12931	Economy	9200.00
0005432425403	12931	Economy	9200.00
0005432425236	12931	Economy	9200.00
0005432425513	12931	Economy	9200.00
0005432425294	12931	Economy	9200.00
0005434025671	444	Business	24500.00
0005434025672	444	Business	24500.00
0005434025666	444	Business	24500.00
0005434025662	444	Business	24500.00
0005433058813	444	Business	24500.00
0005433058954	444	Business	24500.00
0005433058919	444	Business	24500.00
0005432235858	444	Business	24500.00
0005433058595	444	Business	24500.00
0005434025654	444	Business	24500.00
0005434025655	444	Economy	9000.00
0005434028395	444	Economy	8200.00
0005433058718	444	Economy	8200.00
0005433058720	444	Economy	8200.00
0005434025660	444	Economy	8200.00
0005434025669	444	Economy	8200.00
0005433058776	444	Economy	8200.00
0005433058804	444	Economy	8200.00
0005434028394	444	Economy	8200.00
0005433058738	444	Economy	8200.00
0005434025663	444	Economy	8200.00
0005434025653	444	Economy	8200.00
0005433058844	444	Economy	8200.00
0005433058778	444	Economy	8200.00
0005433058736	444	Economy	8200.00
0005433058775	444	Economy	8200.00
0005433058754	444	Economy	8200.00
0005433058673	444	Economy	8200.00
0005433058874	444	Economy	8200.00
0005433058878	444	Economy	8200.00
0005434025667	444	Economy	8200.00
0005433058870	444	Economy	8200.00
0005433058698	444	Economy	8200.00
0005434025658	444	Economy	8200.00
0005433058672	444	Economy	8200.00
0005433058953	444	Economy	8200.00
0005433058744	444	Economy	8200.00
0005434025652	444	Economy	8200.00
0005434029726	444	Economy	8200.00
0005433058875	444	Economy	8200.00
0005434735791	444	Economy	8200.00
0005433058737	444	Economy	8200.00
0005434029727	444	Economy	8200.00
0005434025657	444	Economy	8200.00
0005433058966	444	Economy	8200.00
0005434025670	444	Economy	8200.00
0005433058752	444	Economy	8200.00
0005434025659	444	Economy	8200.00
0005434025656	444	Economy	9000.00
0005433058861	444	Economy	8200.00
0005433058803	444	Economy	8200.00
0005434025664	444	Economy	8200.00
0005433058697	444	Economy	8200.00
0005434376225	444	Economy	8200.00
0005433058652	444	Economy	8200.00
0005434029728	444	Economy	8200.00
0005433058641	444	Economy	8200.00
0005434735797	444	Economy	8200.00
0005434735802	444	Economy	8200.00
0005433058843	444	Economy	8200.00
0005432045669	444	Economy	8200.00
0005433058771	444	Economy	8200.00
0005432235859	444	Economy	8200.00
0005433058845	444	Economy	8200.00
0005434025665	444	Economy	8200.00
0005434025668	444	Economy	8200.00
0005434025673	444	Economy	8200.00
0005433058806	444	Economy	8200.00
0005433058753	444	Economy	8200.00
0005433058965	444	Economy	8200.00
0005434735796	444	Economy	8200.00
0005434025661	444	Economy	8200.00
0005434025118	12682	Business	24500.00
0005434025269	12682	Business	24500.00
0005434025235	12682	Business	24500.00
0005434025259	12682	Business	24500.00
0005433059053	12682	Business	24500.00
0005434025134	12682	Business	24500.00
0005433059051	12682	Business	24500.00
0005434025380	12682	Business	24500.00
0005434025323	12682	Business	24500.00
0005434025068	12682	Business	24500.00
0005433059052	12682	Business	24500.00
0005433059054	12682	Business	24500.00
0005433059048	12682	Business	24500.00
0005434025148	12682	Business	24500.00
0005434024872	12682	Business	24500.00
0005434025321	12682	Business	24500.00
0005434025133	12682	Economy	9000.00
0005434025098	12682	Economy	9000.00
0005434025263	12682	Economy	9000.00
0005434032129	12682	Economy	8200.00
0005434025324	12682	Economy	8200.00
0005434025233	12682	Economy	8200.00
0005434024967	12682	Economy	8200.00
0005434025251	12682	Economy	8200.00
0005434025181	12682	Economy	8200.00
0005434025116	12682	Economy	8200.00
0005434025065	12682	Economy	8200.00
0005434025117	12682	Economy	8200.00
0005434028349	12682	Economy	8200.00
0005434024981	12682	Economy	8200.00
0005434025473	12682	Economy	8200.00
0005434025149	12682	Economy	8200.00
0005434025247	12682	Economy	8200.00
0005433059056	12682	Economy	8200.00
0005434025248	12682	Economy	8200.00
0005434025025	12682	Economy	8200.00
0005433059044	12682	Economy	8200.00
0005433059042	12682	Economy	8200.00
0005433929729	12682	Economy	8200.00
0005434025437	12682	Economy	8200.00
0005434024990	12682	Economy	8200.00
0005433059058	12682	Economy	8200.00
0005434025234	12682	Economy	8200.00
0005434024998	12682	Economy	8200.00
0005433059046	12682	Economy	8200.00
0005433059045	12682	Economy	8200.00
0005434025026	12682	Economy	8200.00
0005434376236	12682	Economy	8200.00
0005434025371	12682	Economy	8200.00
0005434024679	12682	Economy	8200.00
0005434735844	12682	Economy	8200.00
0005433059043	12682	Economy	8200.00
0005434025289	12682	Economy	8200.00
0005434025268	12682	Economy	8200.00
0005434025313	12682	Economy	8200.00
0005434025274	12682	Economy	8200.00
0005434025264	12682	Economy	8200.00
0005433059055	12682	Economy	8200.00
0005434025559	12682	Economy	8200.00
0005434025272	12682	Economy	8200.00
0005434025436	12682	Economy	8200.00
0005434025237	12682	Economy	8200.00
0005434025179	12682	Economy	8200.00
0005434024883	12682	Economy	8200.00
0005434025265	12682	Economy	8200.00
0005433929728	12682	Economy	8200.00
0005434028380	12682	Economy	9000.00
0005434735842	12682	Economy	8200.00
0005434735841	12682	Economy	8200.00
0005434025449	12682	Economy	8200.00
0005433059050	12682	Economy	8200.00
0005433059057	12682	Economy	8200.00
0005434028350	12682	Economy	8200.00
0005434025383	12682	Economy	8200.00
0005434025297	12682	Economy	8200.00
0005434025250	12682	Economy	8200.00
0005434024940	12682	Economy	8200.00
0005434025267	12682	Economy	8200.00
0005434025102	12682	Economy	8200.00
0005434025339	12682	Economy	8200.00
0005434025314	12682	Economy	8200.00
0005433059049	12682	Economy	8200.00
0005434025227	12682	Economy	8200.00
0005434028368	12682	Economy	8200.00
0005434025142	12682	Economy	8200.00
0005434024982	12682	Economy	8200.00
0005434025379	12682	Economy	8200.00
0005433059047	12682	Economy	8200.00
0005434024678	12682	Economy	8200.00
0005434735843	12682	Economy	8200.00
0005434025507	12682	Economy	8200.00
0005434025273	12682	Economy	8200.00
0005433926082	2151	Business	34700.00
0005433037362	2151	Business	34700.00
0005434028380	2151	Business	34700.00
0005433926060	2151	Business	34700.00
0005432749829	2151	Business	34700.00
0005433037420	2151	Business	34700.00
0005433037558	2151	Business	34700.00
0005432231872	2151	Business	34700.00
0005433037373	2151	Business	34700.00
0005433037616	2151	Business	34700.00
0005433037518	2151	Business	34700.00
0005433037415	2151	Business	34700.00
0005433037493	2151	Economy	12700.00
0005432749828	2151	Economy	12700.00
0005433926075	2151	Economy	12700.00
0005433037360	2151	Economy	12700.00
0005433037422	2151	Economy	11600.00
0005433037261	2151	Economy	11600.00
0005433037365	2151	Economy	11600.00
0005433037177	2151	Economy	11600.00
0005433037563	2151	Economy	11600.00
0005433926081	2151	Economy	11600.00
0005433926083	2151	Economy	11600.00
0005432749834	2151	Economy	11600.00
0005433926058	2151	Economy	11600.00
0005433037225	2151	Economy	11600.00
0005433037427	2151	Economy	11600.00
0005433037210	2151	Economy	11600.00
0005433037551	2151	Economy	11600.00
0005433926070	2151	Economy	11600.00
0005433037275	2151	Economy	11600.00
0005433926063	2151	Economy	11600.00
0005433037389	2151	Economy	11600.00
0005433037295	2151	Economy	11600.00
0005433926085	2151	Economy	11600.00
0005433037452	2151	Economy	11600.00
0005432749835	2151	Economy	11600.00
0005433037226	2151	Economy	11600.00
0005433037546	2151	Economy	11600.00
0005433931559	2151	Economy	11600.00
0005433926071	2151	Economy	11600.00
0005433037311	2151	Economy	11600.00
0005432231871	2151	Economy	11600.00
0005433926059	2151	Economy	11600.00
0005433037468	2151	Economy	11600.00
0005433926084	2151	Economy	11600.00
0005433037376	2151	Economy	11600.00
0005433037477	2151	Economy	11600.00
0005433037536	2151	Economy	11600.00
0005434028368	2151	Economy	11600.00
0005433037378	2151	Economy	11600.00
0005433926074	2151	Economy	11600.00
0005433037364	2151	Economy	11600.00
0005433926068	2151	Economy	11600.00
0005433037504	2151	Economy	11600.00
0005433926064	2151	Economy	11600.00
0005434028349	2151	Economy	11600.00
0005433037542	2151	Economy	11600.00
0005432749825	2151	Economy	11600.00
0005433037520	2151	Economy	11600.00
0005433037377	2151	Economy	11600.00
0005433037677	2151	Economy	11600.00
0005433926079	2151	Economy	11600.00
0005432231875	2151	Economy	11600.00
0005433037447	2151	Economy	11600.00
0005433037304	2151	Economy	11600.00
0005433037221	2151	Economy	11600.00
0005433037247	2151	Economy	11600.00
0005433926066	2151	Economy	11600.00
0005433037318	2151	Economy	11600.00
0005433929886	2151	Economy	11600.00
0005433926087	2151	Economy	11600.00
0005433037312	2151	Economy	11600.00
0005433037535	2151	Economy	11600.00
0005433931558	2151	Economy	12700.00
0005433037305	2151	Economy	12700.00
0005432044607	2151	Economy	11600.00
0005433037363	2151	Economy	11600.00
0005433037319	2151	Economy	11600.00
0005433037248	2151	Economy	12700.00
0005432231873	2151	Economy	11600.00
0005433037405	2151	Economy	11600.00
0005433929883	2151	Economy	11600.00
0005433926078	2151	Economy	11600.00
0005433926072	2151	Economy	11600.00
0005433926061	2151	Economy	11600.00
0005433037486	2151	Economy	11600.00
0005433926086	2151	Economy	11600.00
0005433037419	2151	Economy	11600.00
0005433037678	2151	Economy	11600.00
0005433037366	2151	Economy	11600.00
0005433037421	2151	Economy	11600.00
0005433037274	2151	Economy	11600.00
0005433929728	2151	Economy	11600.00
0005433037562	2151	Economy	11600.00
0005432231874	2151	Economy	11600.00
0005433926073	2151	Economy	11600.00
0005433926076	2151	Economy	11600.00
0005433037211	2151	Economy	11600.00
0005433037519	2151	Economy	11600.00
0005433037594	2151	Economy	11600.00
0005433037375	2151	Economy	11600.00
0005433037345	2151	Economy	11600.00
0005433926067	2151	Economy	11600.00
0005433926077	2151	Economy	11600.00
0005434028350	2151	Economy	11600.00
0005432749826	2151	Economy	11600.00
0005433037596	2151	Economy	11600.00
0005433037351	2151	Economy	11600.00
0005433037483	2151	Economy	11600.00
0005433037487	2151	Economy	11600.00
0005433926065	2151	Economy	11600.00
0005433037414	2151	Economy	11600.00
0005433037561	2151	Economy	11600.00
0005433037394	2151	Economy	11600.00
0005433929729	2151	Economy	11600.00
0005433037294	2151	Economy	11600.00
0005433926069	2151	Economy	11600.00
0005433926062	2151	Economy	11600.00
0005433926080	2151	Economy	11600.00
0005433037262	2151	Economy	11600.00
0005433037652	2151	Economy	11600.00
0005433924850	24084	Business	34700.00
0005433925058	24084	Business	34700.00
0005433925059	24084	Business	34700.00
0005433925452	24084	Business	34700.00
0005433925166	24084	Business	34700.00
0005433875417	24084	Business	34700.00
0005433924829	24084	Business	34700.00
0005433925391	24084	Business	34700.00
0005433925472	24084	Business	34700.00
0005433037828	24084	Business	34700.00
0005433037824	24084	Business	34700.00
0005433925848	24084	Business	34700.00
0005433925380	24084	Business	34700.00
0005433037831	24084	Business	34700.00
0005433929709	24084	Business	34700.00
0005433925816	24084	Business	34700.00
0005433924842	24084	Business	34700.00
0005433929696	24084	Economy	12700.00
0005433037834	24084	Economy	12700.00
0005432206360	24084	Economy	12700.00
0005433925473	24084	Economy	12700.00
0005433929708	24084	Economy	11600.00
0005433925847	24084	Economy	11600.00
0005433925484	24084	Economy	11600.00
0005433037836	24084	Economy	11600.00
0005433925608	24084	Economy	11600.00
0005433925104	24084	Economy	11600.00
0005433925431	24084	Economy	11600.00
0005433037822	24084	Economy	11600.00
0005433929690	24084	Economy	11600.00
0005433925518	24084	Economy	11600.00
0005434088055	24084	Economy	11600.00
0005433925545	24084	Economy	11600.00
0005433924841	24084	Economy	11600.00
0005433925659	24084	Economy	11600.00
0005433925328	24084	Economy	11600.00
0005433925445	24084	Economy	11600.00
0005433925106	24084	Economy	11600.00
0005433037827	24084	Economy	11600.00
0005433931532	24084	Economy	11600.00
0005433037840	24084	Economy	11600.00
0005433037829	24084	Economy	11600.00
0005432206359	24084	Economy	11600.00
0005433037820	24084	Economy	11600.00
0005433925741	24084	Economy	11600.00
0005433925780	24084	Economy	11600.00
0005433925444	24084	Economy	11600.00
0005433925360	24084	Economy	11600.00
0005433925755	24084	Economy	11600.00
0005433931533	24084	Economy	11600.00
0005433924972	24084	Economy	11600.00
0005433925065	24084	Economy	11600.00
0005433925220	24084	Economy	11600.00
0005433925728	24084	Economy	11600.00
0005433925029	24084	Economy	11600.00
0005433925081	24084	Economy	11600.00
0005433925250	24084	Economy	11600.00
0005432749850	24084	Economy	11600.00
0005433925439	24084	Economy	11600.00
0005433037830	24084	Economy	11600.00
0005433925416	24084	Economy	11600.00
0005433925000	24084	Economy	11600.00
0005433925432	24084	Economy	11600.00
0005433931520	24084	Economy	11600.00
0005433037821	24084	Economy	11600.00
0005433925588	24084	Economy	11600.00
0005433925543	24084	Economy	11600.00
0005432207738	24084	Economy	11600.00
0005433925680	24084	Economy	11600.00
0005434175876	24084	Economy	11600.00
0005433925471	24084	Economy	11600.00
0005433925456	24084	Economy	11600.00
0005433925381	24084	Economy	11600.00
0005433929689	24084	Economy	11600.00
0005433925060	24084	Economy	11600.00
0005433037823	24084	Economy	11600.00
0005433037839	24084	Economy	12700.00
0005433925107	24084	Economy	11600.00
0005433925727	24084	Economy	11600.00
0005433037825	24084	Economy	12700.00
0005433931524	24084	Economy	11600.00
0005433925270	24084	Economy	11600.00
0005433925254	24084	Economy	11600.00
0005433925485	24084	Economy	11600.00
0005433037833	24084	Economy	11600.00
0005433925397	24084	Economy	11600.00
0005433925740	24084	Economy	11600.00
0005433037841	24084	Economy	11600.00
0005434376190	24084	Economy	11600.00
0005433925587	24084	Economy	11600.00
0005433925185	24084	Economy	11600.00
0005433925221	24084	Economy	11600.00
0005433925544	24084	Economy	11600.00
0005433925333	24084	Economy	11600.00
0005433925392	24084	Economy	11600.00
0005433037832	24084	Economy	11600.00
0005433925440	24084	Economy	11600.00
0005433925523	24084	Economy	11600.00
0005433037838	24084	Economy	11600.00
0005434175873	24084	Economy	11600.00
0005433925230	24084	Economy	11600.00
0005433925418	24084	Economy	11600.00
0005433925274	24084	Economy	11600.00
0005433037837	24084	Economy	11600.00
0005433037835	24084	Economy	11600.00
0005433925164	24084	Economy	11600.00
0005433924999	24084	Economy	11600.00
0005433924830	24084	Economy	11600.00
0005433875418	24084	Economy	11600.00
0005433925224	24084	Economy	11600.00
0005433929695	24084	Economy	11600.00
0005433037826	24084	Economy	11600.00
0005434175875	24084	Economy	11600.00
0005433925125	24084	Economy	11600.00
0005434175872	24084	Economy	11600.00
0005433924851	24084	Economy	11600.00
0005433925670	24084	Economy	11600.00
0005433929713	24084	Economy	11600.00
0005434175874	24084	Economy	11600.00
0005433925671	24084	Economy	11600.00
0005432749851	24084	Economy	11600.00
0005433925401	24084	Economy	11600.00
0005433925455	24084	Economy	11600.00
0005433925105	24084	Economy	11600.00
0005433929710	24084	Economy	11600.00
0005434175877	24084	Economy	11600.00
0005433925398	24084	Economy	11600.00
0005433925231	24084	Economy	11600.00
0005433925815	24084	Economy	11600.00
0005433925658	24084	Economy	11600.00
0005433925539	24084	Economy	11600.00
0005433925414	24084	Economy	11600.00
0005433289985	303	Business	83700.00
0005434728971	303	Business	83700.00
0005433113592	303	Business	83700.00
0005433235585	303	Business	83700.00
0005433235586	303	Business	83700.00
0005433235706	303	Business	83700.00
0005433235567	303	Business	83700.00
0005434728974	303	Business	83700.00
0005434552828	303	Business	83700.00
0005433235553	303	Business	83700.00
0005434728981	303	Business	83700.00
0005434728979	303	Business	83700.00
0005433181730	303	Business	83700.00
0005434728993	303	Business	83700.00
0005432278200	303	Business	83700.00
0005433235525	303	Business	83700.00
0005434728978	303	Business	83700.00
0005434728995	303	Business	83700.00
0005433235326	303	Comfort	47400.00
0005433235723	303	Comfort	47400.00
0005433131818	303	Comfort	47400.00
0005434552840	303	Comfort	47400.00
0005433181570	303	Comfort	47400.00
0005433181724	303	Comfort	47400.00
0005433126962	303	Comfort	47400.00
0005434728977	303	Comfort	47400.00
0005433235442	303	Comfort	47400.00
0005433235610	303	Comfort	47400.00
0005433113582	303	Comfort	47400.00
0005433235291	303	Comfort	47400.00
0005433131803	303	Comfort	47400.00
0005433235605	303	Comfort	47400.00
0005433235486	303	Comfort	47400.00
0005433235547	303	Comfort	47400.00
0005434728987	303	Comfort	47400.00
0005434728973	303	Comfort	47400.00
0005433235482	303	Comfort	47400.00
0005435142964	303	Comfort	47400.00
0005434728985	303	Economy	27900.00
0005433181661	303	Economy	27900.00
0005435142963	303	Economy	27900.00
0005433235436	303	Economy	27900.00
0005432278204	303	Economy	27900.00
0005434728972	303	Economy	27900.00
0005434552826	303	Economy	27900.00
0005433181648	303	Economy	27900.00
0005434032121	303	Economy	27900.00
0005433235604	303	Economy	27900.00
0005433181568	303	Economy	27900.00
0005433235483	303	Economy	27900.00
0005433181674	303	Economy	27900.00
0005433181669	303	Economy	27900.00
0005433289977	303	Economy	27900.00
0005434728986	303	Economy	27900.00
0005433235718	303	Economy	27900.00
0005434728968	303	Economy	27900.00
0005434552831	303	Economy	27900.00
0005433235619	303	Economy	27900.00
0005433181692	303	Economy	27900.00
0005433181639	303	Economy	27900.00
0005434728990	303	Economy	27900.00
0005433235565	303	Economy	27900.00
0005435142957	303	Economy	27900.00
0005434728997	303	Economy	27900.00
0005434032123	303	Economy	27900.00
0005434728989	303	Economy	27900.00
0005434728982	303	Economy	27900.00
0005434728980	303	Economy	27900.00
0005433181612	303	Economy	27900.00
0005433181775	303	Economy	30700.00
0005434728983	303	Economy	30700.00
0005432278202	303	Economy	30700.00
0005433235465	303	Economy	27900.00
0005433235497	303	Economy	27900.00
0005433766715	303	Economy	27900.00
0005433181613	303	Economy	27900.00
0005433235498	303	Economy	27900.00
0005434728975	303	Economy	27900.00
0005434735840	303	Economy	27900.00
0005434552838	303	Economy	27900.00
0005433181640	303	Economy	27900.00
0005434032131	303	Economy	27900.00
0005433131822	303	Economy	27900.00
0005434728969	303	Economy	27900.00
0005434552833	303	Economy	27900.00
0005435142956	303	Economy	27900.00
0005434731290	303	Economy	27900.00
0005434728984	303	Economy	27900.00
0005434032127	303	Economy	27900.00
0005434728992	303	Economy	27900.00
0005433181634	303	Economy	27900.00
0005433181670	303	Economy	27900.00
0005434728967	303	Economy	27900.00
0005433235530	303	Economy	27900.00
0005434552835	303	Economy	27900.00
0005434728963	303	Economy	27900.00
0005434728961	303	Economy	27900.00
0005433235552	303	Economy	27900.00
0005433181700	303	Economy	27900.00
0005433235575	303	Economy	27900.00
0005433235348	303	Economy	27900.00
0005433181675	303	Economy	27900.00
0005433235370	303	Economy	27900.00
0005433235524	303	Economy	27900.00
0005434552839	303	Economy	27900.00
0005434728970	303	Economy	27900.00
0005433235435	303	Economy	27900.00
0005433235606	303	Economy	27900.00
0005433235523	303	Economy	27900.00
0005434728962	303	Economy	27900.00
0005433181576	303	Economy	27900.00
0005434728991	303	Economy	27900.00
0005433181774	303	Economy	27900.00
0005434552829	303	Economy	27900.00
0005433113583	303	Economy	27900.00
0005433235496	303	Economy	27900.00
0005434728976	303	Economy	27900.00
0005434728964	303	Economy	27900.00
0005433181658	303	Economy	27900.00
0005432278206	303	Economy	27900.00
0005433235541	303	Economy	27900.00
0005433181577	303	Economy	27900.00
0005434728965	303	Economy	27900.00
0005434735839	303	Economy	27900.00
0005433235443	303	Economy	27900.00
0005433235434	303	Economy	27900.00
0005433235583	303	Economy	27900.00
0005433235656	303	Economy	27900.00
0005434728994	303	Economy	27900.00
0005434552823	303	Economy	27900.00
0005434728966	303	Economy	27900.00
0005434552836	303	Economy	27900.00
0005434552834	303	Economy	27900.00
0005433235464	303	Economy	30700.00
0005434302580	303	Economy	27900.00
0005433235568	303	Economy	27900.00
0005434552837	303	Economy	27900.00
0005433235614	303	Economy	27900.00
0005433181625	303	Economy	27900.00
0005433235603	303	Economy	27900.00
0005433181635	303	Economy	27900.00
0005433181631	303	Economy	27900.00
0005435142960	303	Economy	27900.00
0005435142959	303	Economy	27900.00
0005433113586	303	Economy	27900.00
0005434032097	303	Economy	27900.00
0005434728996	303	Economy	27900.00
0005432278203	303	Economy	27900.00
0005433181686	303	Economy	27900.00
0005433235607	303	Economy	27900.00
0005434552832	303	Economy	27900.00
0005434032111	303	Economy	27900.00
0005433235729	303	Economy	27900.00
0005433235589	303	Economy	27900.00
0005433131823	303	Economy	27900.00
0005432278201	303	Economy	27900.00
0005434552827	303	Economy	27900.00
0005434032114	303	Economy	27900.00
0005434552830	303	Economy	27900.00
0005433235588	303	Economy	27900.00
0005435142958	303	Economy	27900.00
0005433766730	303	Economy	27900.00
0005434032109	303	Economy	27900.00
0005434552825	303	Economy	27900.00
0005433235278	303	Economy	27900.00
0005433181668	303	Economy	27900.00
0005433235336	303	Economy	27900.00
0005433235463	303	Economy	27900.00
0005435142961	303	Economy	27900.00
0005434032132	303	Economy	27900.00
0005433235560	303	Economy	27900.00
0005433235335	303	Economy	27900.00
0005433235551	303	Economy	27900.00
0005434032122	303	Economy	27900.00
0005435142962	303	Economy	27900.00
0005433766714	303	Economy	27900.00
0005433235643	303	Economy	27900.00
0005433181657	303	Economy	27900.00
0005433289991	303	Economy	27900.00
0005433235587	303	Economy	27900.00
0005432278205	303	Economy	27900.00
0005434728988	303	Economy	27900.00
0005433235361	303	Economy	27900.00
0005433181593	303	Economy	27900.00
0005434552824	303	Economy	27900.00
0005433235540	303	Economy	27900.00
0005434552841	303	Economy	27900.00
0005434728998	303	Economy	27900.00
0005433235566	303	Economy	27900.00
0005433235538	303	Economy	27900.00
0005433181569	303	Economy	27900.00
0005433235608	303	Economy	27900.00
0005433235590	303	Economy	27900.00
0005433126957	303	Economy	27900.00
0005434552842	303	Economy	27900.00
0005434552373	9826	Business	83700.00
0005434728175	9826	Business	83700.00
0005433236005	9826	Business	83700.00
0005433236021	9826	Business	83700.00
0005434727301	9826	Business	83700.00
0005434727902	9826	Business	83700.00
0005434727615	9826	Business	83700.00
0005434728350	9826	Business	83700.00
0005434552237	9826	Business	83700.00
0005433290061	9826	Business	83700.00
0005434728129	9826	Business	83700.00
0005434727750	9826	Business	83700.00
0005434727774	9826	Business	83700.00
0005434727785	9826	Business	83700.00
0005434728209	9826	Business	83700.00
0005434728638	9826	Business	83700.00
0005434552189	9826	Business	83700.00
0005434728019	9826	Business	83700.00
0005434552531	9826	Business	83700.00
0005433236028	9826	Business	83700.00
0005434552313	9826	Business	83700.00
0005434552527	9826	Business	83700.00
0005434728061	9826	Comfort	47400.00
0005434728650	9826	Business	83700.00
0005434728339	9826	Comfort	47400.00
0005434727899	9826	Comfort	47400.00
0005434728060	9826	Comfort	47400.00
0005434728412	9826	Comfort	47400.00
0005434552381	9826	Comfort	47400.00
0005434728139	9826	Comfort	47400.00
0005434728171	9826	Comfort	47400.00
0005435142897	9826	Comfort	47400.00
0005433181825	9826	Comfort	47400.00
0005434728440	9826	Comfort	47400.00
0005434728018	9826	Comfort	47400.00
0005433236026	9826	Comfort	47400.00
0005434728506	9826	Comfort	47400.00
0005434552286	9826	Comfort	47400.00
0005434728229	9826	Comfort	47400.00
0005434728651	9826	Comfort	47400.00
0005434552450	9826	Comfort	47400.00
0005434728639	9826	Comfort	47400.00
0005434552525	9826	Comfort	47400.00
0005434552258	9826	Comfort	47400.00
0005433236010	9826	Comfort	47400.00
0005434552141	9826	Comfort	47400.00
0005433236004	9826	Comfort	47400.00
0005434032155	9826	Comfort	47400.00
0005433236031	9826	Comfort	47400.00
0005434728095	9826	Comfort	47400.00
0005433236002	9826	Comfort	47400.00
0005434728234	9826	Comfort	47400.00
0005435142826	9826	Comfort	47400.00
0005434728094	9826	Comfort	47400.00
0005433181821	9826	Comfort	47400.00
0005434728108	9826	Comfort	47400.00
0005434728389	9826	Comfort	47400.00
0005435142859	9826	Comfort	47400.00
0005433236008	9826	Economy	27900.00
0005434728099	9826	Economy	27900.00
0005434728236	9826	Economy	27900.00
0005435142879	9826	Economy	27900.00
0005434552142	9826	Economy	27900.00
0005433236014	9826	Economy	27900.00
0005434728353	9826	Economy	27900.00
0005434728160	9826	Economy	27900.00
0005434552485	9826	Economy	27900.00
0005434727742	9826	Economy	27900.00
0005434728346	9826	Economy	27900.00
0005434727593	9826	Economy	27900.00
0005434728407	9826	Economy	27900.00
0005434552182	9826	Economy	27900.00
0005434728330	9826	Economy	27900.00
0005434728345	9826	Economy	27900.00
0005435142809	9826	Economy	27900.00
0005435142846	9826	Economy	27900.00
0005435142825	9826	Economy	27900.00
0005433236029	9826	Economy	27900.00
0005434728140	9826	Economy	27900.00
0005434552369	9826	Economy	27900.00
0005434302529	9826	Economy	27900.00
0005435142813	9826	Economy	27900.00
0005433126976	9826	Economy	27900.00
0005434727660	9826	Economy	27900.00
0005433766751	9826	Economy	27900.00
0005433236019	9826	Economy	27900.00
0005434552283	9826	Economy	27900.00
0005434728112	9826	Economy	27900.00
0005434552464	9826	Economy	27900.00
0005434727826	9826	Economy	27900.00
0005434728050	9826	Economy	27900.00
0005433181829	9826	Economy	27900.00
0005434552555	9826	Economy	27900.00
0005433113598	9826	Economy	27900.00
0005435142824	9826	Economy	27900.00
0005434728328	9826	Economy	27900.00
0005434552486	9826	Economy	27900.00
0005434727616	9826	Economy	27900.00
0005434552499	9826	Economy	27900.00
0005434552259	9826	Economy	27900.00
0005434302559	9826	Economy	27900.00
0005433181823	9826	Economy	27900.00
0005434728130	9826	Economy	27900.00
0005433181831	9826	Economy	27900.00
0005434727529	9826	Economy	27900.00
0005434728329	9826	Economy	27900.00
0005434727898	9826	Economy	27900.00
0005435142865	9826	Economy	30700.00
0005434728425	9826	Economy	30700.00
0005434728380	9826	Economy	27900.00
0005434727300	9826	Economy	27900.00
0005434728391	9826	Economy	27900.00
0005434731262	9826	Economy	27900.00
0005434552370	9826	Economy	30700.00
0005434728282	9826	Economy	30700.00
0005433126978	9826	Economy	27900.00
0005434552339	9826	Economy	30700.00
0005434728251	9826	Economy	27900.00
0005434728441	9826	Economy	27900.00
0005433236011	9826	Economy	27900.00
0005434728017	9826	Economy	27900.00
0005434728144	9826	Economy	27900.00
0005435142864	9826	Economy	27900.00
0005434728505	9826	Economy	27900.00
0005433236018	9826	Economy	27900.00
0005433236013	9826	Economy	27900.00
0005434728001	9826	Economy	27900.00
0005435142896	9826	Economy	27900.00
0005435142847	9826	Economy	27900.00
0005434552049	9826	Economy	27900.00
0005434727897	9826	Economy	27900.00
0005435142869	9826	Economy	27900.00
0005434302530	9826	Economy	27900.00
0005434728248	9826	Economy	27900.00
0005434728208	9826	Economy	27900.00
0005433236016	9826	Economy	27900.00
0005433236033	9826	Economy	27900.00
0005434727998	9826	Economy	27900.00
0005434728224	9826	Economy	27900.00
0005434727772	9826	Economy	27900.00
0005434727973	9826	Economy	27900.00
0005434728210	9826	Economy	27900.00
0005434552210	9826	Economy	27900.00
0005434727530	9826	Economy	27900.00
0005434728025	9826	Economy	27900.00
0005434552349	9826	Economy	27900.00
0005433290060	9826	Economy	27900.00
0005433236006	9826	Economy	27900.00
0005434552398	9826	Economy	27900.00
0005433236027	9826	Economy	27900.00
0005434552174	9826	Economy	27900.00
0005434552380	9826	Economy	27900.00
0005434032157	9826	Economy	27900.00
0005435142860	9826	Economy	27900.00
0005433236025	9826	Economy	27900.00
0005434728486	9826	Economy	27900.00
0005434728426	9826	Economy	27900.00
0005434302557	9826	Economy	27900.00
0005434727923	9826	Economy	27900.00
0005434727679	9826	Economy	27900.00
0005434552230	9826	Economy	27900.00
0005434552367	9826	Economy	27900.00
0005434735780	9826	Economy	27900.00
0005434735794	9826	Economy	27900.00
0005434728219	9826	Economy	27900.00
0005434727851	9826	Economy	27900.00
0005434552232	9826	Economy	27900.00
0005434552178	9826	Economy	27900.00
0005434552363	9826	Economy	27900.00
0005434728290	9826	Economy	27900.00
0005433236015	9826	Economy	27900.00
0005434728181	9826	Economy	27900.00
0005434728363	9826	Economy	27900.00
0005434728332	9826	Economy	27900.00
0005433236030	9826	Economy	27900.00
0005433236012	9826	Economy	27900.00
0005433236007	9826	Economy	27900.00
0005434728156	9826	Economy	27900.00
0005434032156	9826	Economy	27900.00
0005434552469	9826	Economy	27900.00
0005434728271	9826	Economy	27900.00
0005434727784	9826	Economy	27900.00
0005434552272	9826	Economy	27900.00
0005434552411	9826	Economy	27900.00
0005435142868	9826	Economy	27900.00
0005434728374	9826	Economy	27900.00
0005434728352	9826	Economy	27900.00
0005433181826	9826	Economy	27900.00
0005435142876	9826	Economy	27900.00
0005434728493	9826	Economy	27900.00
0005434302558	9826	Economy	27900.00
0005434552544	9826	Economy	27900.00
0005434552323	9826	Economy	27900.00
0005433126977	9826	Economy	27900.00
0005434552250	9826	Economy	27900.00
0005434302537	9826	Economy	27900.00
0005434727924	9826	Economy	27900.00
0005433290059	9826	Economy	30700.00
0005435142848	9826	Economy	30700.00
0005434727773	9826	Economy	30700.00
0005434731256	9826	Economy	30700.00
0005434728281	9826	Economy	30700.00
0005434731265	9826	Economy	27900.00
0005433181822	9826	Economy	27900.00
0005433181824	9826	Economy	27900.00
0005435142810	9826	Economy	27900.00
0005434552524	9826	Economy	27900.00
0005434728182	9826	Economy	27900.00
0005433766752	9826	Economy	27900.00
0005434552050	9826	Economy	27900.00
0005434728270	9826	Economy	27900.00
0005434728497	9826	Economy	27900.00
0005434735801	9826	Economy	27900.00
0005434728172	9826	Economy	27900.00
0005434552378	9826	Economy	27900.00
0005434728157	9826	Economy	27900.00
0005433766753	9826	Economy	27900.00
0005434552214	9826	Economy	27900.00
0005434727743	9826	Economy	27900.00
0005434735781	9826	Economy	27900.00
0005434552364	9826	Economy	27900.00
0005434552211	9826	Economy	27900.00
0005434552244	9826	Economy	27900.00
0005434728450	9826	Economy	27900.00
0005434552545	9826	Economy	27900.00
0005434727650	9826	Economy	27900.00
0005433236017	9826	Economy	27900.00
0005435142811	9826	Economy	27900.00
0005434727872	9826	Economy	27900.00
0005434552454	9826	Economy	27900.00
0005434552449	9826	Economy	27900.00
0005434728406	9826	Economy	27900.00
0005434727594	9826	Economy	27900.00
0005434728119	9826	Economy	27900.00
0005434552554	9826	Economy	27900.00
0005434728291	9826	Economy	27900.00
0005434727871	9826	Economy	27900.00
0005434728314	9826	Economy	27900.00
0005433181827	9826	Economy	27900.00
0005434552243	9826	Economy	27900.00
0005434728340	9826	Economy	27900.00
0005434032158	9826	Economy	27900.00
0005434728287	9826	Economy	27900.00
0005434552542	9826	Economy	27900.00
0005434552522	9826	Economy	27900.00
0005435142867	9826	Economy	27900.00
0005433236020	9826	Economy	27900.00
0005434552251	9826	Economy	27900.00
0005433236022	9826	Economy	27900.00
0005434727733	9826	Economy	27900.00
0005434727874	9826	Economy	27900.00
0005434728176	9826	Economy	27900.00
0005433236009	9826	Economy	27900.00
0005434552455	9826	Economy	27900.00
0005434552467	9826	Economy	27900.00
0005434727935	9826	Economy	27900.00
0005434728228	9826	Economy	27900.00
0005434552543	9826	Economy	27900.00
0005434728189	9826	Economy	27900.00
0005434727926	9826	Economy	27900.00
0005434728826	9826	Economy	27900.00
0005434727682	9826	Economy	27900.00
0005433236024	9826	Economy	27900.00
0005434552490	9826	Economy	27900.00
0005433236023	9826	Economy	27900.00
0005434552468	9826	Economy	27900.00
0005434552446	9826	Economy	27900.00
0005433236003	9826	Economy	27900.00
0005434728362	9826	Economy	27900.00
0005434727925	9826	Economy	27900.00
0005434728026	9826	Economy	27900.00
0005433236032	9826	Economy	27900.00
0005434727557	9826	Economy	27900.00
0005433181828	9826	Economy	27900.00
0005434552338	9826	Economy	27900.00
0005434728161	9826	Economy	27900.00
0005433181830	9826	Economy	27900.00
0005434728347	9826	Economy	27900.00
0005434727909	9826	Economy	27900.00
0005434552236	9826	Economy	27900.00
0005435142866	9826	Economy	27900.00
0005434552465	9826	Economy	27900.00
0005434727802	9826	Economy	27900.00
0005433126979	9826	Economy	27900.00
0005435725700	7746	Business	42100.00
0005435215309	7746	Business	42100.00
0005435631032	7746	Business	42100.00
0005432531732	7746	Business	42100.00
0005435215183	7746	Business	42100.00
0005432531728	7746	Business	42100.00
0005435283427	7746	Business	42100.00
0005435215174	7746	Business	42100.00
0005432531777	7746	Business	42100.00
0005432531738	7746	Business	42100.00
0005433656730	7746	Business	42100.00
0005434069609	7746	Business	42100.00
0005434069616	7746	Business	42100.00
0005432531765	7746	Comfort	23900.00
0005432531733	7746	Comfort	23900.00
0005433656737	7746	Comfort	23900.00
0005432070073	7746	Comfort	23900.00
0005435215052	7746	Comfort	23900.00
0005435215115	7746	Comfort	23900.00
0005434069625	7746	Comfort	23900.00
0005432531771	7746	Comfort	23900.00
0005435215128	7746	Comfort	23900.00
0005432531747	7746	Comfort	23900.00
0005435215082	7746	Comfort	23900.00
0005432531767	7746	Comfort	23900.00
0005435725686	7746	Comfort	23900.00
0005432531778	7746	Comfort	23900.00
0005432531762	7746	Comfort	23900.00
0005435725677	7746	Comfort	23900.00
0005432533376	7746	Comfort	23900.00
0005435214997	7746	Comfort	23900.00
0005434069622	7746	Comfort	23900.00
0005434069613	7746	Comfort	23900.00
0005435214853	7746	Comfort	23900.00
0005432150420	7746	Comfort	23900.00
0005432531763	7746	Economy	14000.00
0005435215056	7746	Economy	14000.00
0005432531737	7746	Economy	14000.00
0005435215009	7746	Economy	14000.00
0005432535976	7746	Economy	14000.00
0005435215060	7746	Economy	14000.00
0005433656736	7746	Economy	14000.00
0005432531769	7746	Economy	14000.00
0005432531730	7746	Economy	14000.00
0005435215230	7746	Economy	14000.00
0005432531773	7746	Economy	14000.00
0005432531746	7746	Economy	14000.00
0005432531751	7746	Economy	14000.00
0005434069608	7746	Economy	14000.00
0005435283431	7746	Economy	14000.00
0005435214762	7746	Economy	14000.00
0005432531739	7746	Economy	14000.00
0005434069617	7746	Economy	14000.00
0005433656738	7746	Economy	14000.00
0005435215145	7746	Economy	14000.00
0005435215127	7746	Economy	14000.00
0005435214938	7746	Economy	14000.00
0005432531779	7746	Economy	14000.00
0005432531770	7746	Economy	14000.00
0005435215130	7746	Economy	14000.00
0005434069611	7746	Economy	14000.00
0005432531729	7746	Economy	14000.00
0005432531757	7746	Economy	14000.00
0005435283449	7746	Economy	14000.00
0005432531741	7746	Economy	14000.00
0005432531750	7746	Economy	14000.00
0005435215057	7746	Economy	14000.00
0005435215244	7746	Economy	14000.00
0005435214748	7746	Economy	14000.00
0005432531744	7746	Economy	14000.00
0005435215061	7746	Economy	14000.00
0005432150423	7746	Economy	14000.00
0005432531761	7746	Economy	15400.00
0005434069605	7746	Economy	14000.00
0005435215051	7746	Economy	15400.00
0005432531753	7746	Economy	14000.00
0005432531768	7746	Economy	15400.00
0005432537120	7746	Economy	15400.00
0005432531742	7746	Economy	14000.00
0005432535975	7746	Economy	14000.00
0005435283436	7746	Economy	14000.00
0005432531743	7746	Economy	14000.00
0005432531764	7746	Economy	14000.00
0005432531774	7746	Economy	14000.00
0005435215116	7746	Economy	14000.00
0005434069621	7746	Economy	14000.00
0005435215080	7746	Economy	14000.00
0005435631036	7746	Economy	14000.00
0005435725676	7746	Economy	14000.00
0005435214760	7746	Economy	14000.00
0005435215043	7746	Economy	14000.00
0005435215178	7746	Economy	14000.00
0005432531745	7746	Economy	14000.00
0005435215229	7746	Economy	14000.00
0005432070076	7746	Economy	14000.00
0005434069623	7746	Economy	14000.00
0005435215102	7746	Economy	14000.00
0005435215234	7746	Economy	14000.00
0005435283428	7746	Economy	14000.00
0005433656731	7746	Economy	14000.00
0005435283452	7746	Economy	14000.00
0005435214998	7746	Economy	14000.00
0005435214986	7746	Economy	14000.00
0005435215017	7746	Economy	14000.00
0005432531760	7746	Economy	14000.00
0005435283437	7746	Economy	14000.00
0005432531776	7746	Economy	14000.00
0005432531772	7746	Economy	14000.00
0005435214906	7746	Economy	14000.00
0005435214994	7746	Economy	14000.00
0005434069606	7746	Economy	14000.00
0005435631023	7746	Economy	14000.00
0005434069618	7746	Economy	14000.00
0005432531756	7746	Economy	14000.00
0005432531766	7746	Economy	14000.00
0005432531748	7746	Economy	14000.00
0005435214823	7746	Economy	14000.00
0005435631037	7746	Economy	14000.00
0005434069612	7746	Economy	14000.00
0005434069607	7746	Economy	15400.00
0005435214622	7746	Economy	14000.00
0005434069615	7746	Economy	14000.00
0005435215118	7746	Economy	14000.00
0005435283451	7746	Economy	14000.00
0005435631029	7746	Economy	14000.00
0005435215036	7746	Economy	14000.00
0005435215159	7746	Economy	14000.00
0005432070074	7746	Economy	14000.00
0005432150424	7746	Economy	14000.00
0005432531740	7746	Economy	14000.00
0005435283429	7746	Economy	14000.00
0005435631034	7746	Economy	14000.00
0005435215235	7746	Economy	14000.00
0005435215091	7746	Economy	14000.00
0005435215129	7746	Economy	14000.00
0005435283430	7746	Economy	14000.00
0005435214924	7746	Economy	14000.00
0005434069619	7746	Economy	14000.00
0005435214874	7746	Economy	14000.00
0005432531731	7746	Economy	14000.00
0005432531758	7746	Economy	14000.00
0005432531759	7746	Economy	14000.00
0005435215308	7746	Economy	14000.00
0005435214940	7746	Economy	14000.00
0005435725714	7746	Economy	14000.00
0005435215092	7746	Economy	14000.00
0005432150421	7746	Economy	14000.00
0005432531749	7746	Economy	14000.00
0005432070075	7746	Economy	14000.00
0005432531735	7746	Economy	14000.00
0005432531734	7746	Economy	14000.00
0005432070072	7746	Economy	14000.00
0005435215103	7746	Economy	14000.00
0005434069610	7746	Economy	14000.00
0005434069614	7746	Economy	14000.00
0005432531775	7746	Economy	14000.00
0005434069624	7746	Economy	14000.00
0005432531754	7746	Economy	14000.00
0005432531752	7746	Economy	14000.00
0005432150422	7746	Economy	14000.00
0005435283435	7746	Economy	14000.00
0005435214999	7746	Economy	14000.00
0005434069620	7746	Economy	14000.00
0005435215162	7746	Economy	14000.00
0005435214939	7746	Economy	14000.00
0005432531755	7746	Economy	14000.00
0005432531736	7746	Economy	14000.00
0005435215117	7746	Economy	14000.00
0005432047660	5340	Business	43100.00
0005435426534	5340	Business	43100.00
0005434573766	5340	Business	43100.00
0005435616982	5340	Business	43100.00
0005435426628	5340	Business	43100.00
0005435426224	5340	Business	43100.00
0005435556769	5340	Business	43100.00
0005435616960	5340	Business	43100.00
0005433719204	5340	Business	43100.00
0005435426478	5340	Business	43100.00
0005435380428	5340	Business	43100.00
0005435426445	5340	Business	43100.00
0005435617203	5340	Business	43100.00
0005434245660	5340	Business	43100.00
0005434345268	5340	Business	43100.00
0005435426584	5340	Business	43100.00
0005433719209	5340	Business	43100.00
0005435426145	5340	Business	43100.00
0005435426356	5340	Business	43100.00
0005434345266	5340	Comfort	24400.00
0005435426281	5340	Comfort	24400.00
0005434245604	5340	Comfort	24400.00
0005435426568	5340	Comfort	24400.00
0005435426533	5340	Comfort	24400.00
0005435426491	5340	Comfort	24400.00
0005435555428	5340	Comfort	24400.00
0005434345272	5340	Comfort	24400.00
0005434245642	5340	Comfort	24400.00
0005434573767	5340	Comfort	24400.00
0005432133648	5340	Comfort	24400.00
0005435616989	5340	Comfort	24400.00
0005432133651	5340	Comfort	24400.00
0005435426384	5340	Comfort	24400.00
0005435616972	5340	Comfort	24400.00
0005435319768	5340	Comfort	24400.00
0005432133650	5340	Comfort	24400.00
0005435555427	5340	Comfort	24400.00
0005434245635	5340	Comfort	24400.00
0005432047663	5340	Comfort	24400.00
0005435319775	5340	Comfort	24400.00
0005434245605	5340	Comfort	24400.00
0005435491505	5340	Comfort	24400.00
0005435426595	5340	Comfort	24400.00
0005435556767	5340	Comfort	24400.00
0005435426367	5340	Comfort	24400.00
0005435616986	5340	Comfort	24400.00
0005432363488	5340	Comfort	24400.00
0005435319756	5340	Comfort	24400.00
0005435426439	5340	Comfort	24400.00
0005435426521	5340	Economy	14400.00
0005435426518	5340	Economy	14400.00
0005435426144	5340	Economy	14400.00
0005435426681	5340	Economy	14400.00
0005435426567	5340	Economy	14400.00
0005435616973	5340	Economy	14400.00
0005435426342	5340	Economy	14400.00
0005434245705	5340	Economy	14400.00
0005434345261	5340	Economy	14400.00
0005435546237	5340	Economy	14400.00
0005435616983	5340	Economy	14400.00
0005432841065	5340	Economy	14400.00
0005434573763	5340	Economy	14400.00
0005434345264	5340	Economy	14400.00
0005435491506	5340	Economy	14400.00
0005434245696	5340	Economy	14400.00
0005432363489	5340	Economy	14400.00
0005434245669	5340	Economy	14400.00
0005435616978	5340	Economy	14400.00
0005435616964	5340	Economy	14400.00
0005435426378	5340	Economy	14400.00
0005435426219	5340	Economy	14400.00
0005435616985	5340	Economy	14400.00
0005432047661	5340	Economy	14400.00
0005435426446	5340	Economy	14400.00
0005435426492	5340	Economy	14400.00
0005435616991	5340	Economy	14400.00
0005435616992	5340	Economy	14400.00
0005432133646	5340	Economy	14400.00
0005434245641	5340	Economy	14400.00
0005435426627	5340	Economy	14400.00
0005435616977	5340	Economy	14400.00
0005435426517	5340	Economy	14400.00
0005435380414	5340	Economy	14400.00
0005434345267	5340	Economy	14400.00
0005434345263	5340	Economy	14400.00
0005435042916	5340	Economy	14400.00
0005434245682	5340	Economy	14400.00
0005434245628	5340	Economy	14400.00
0005433719205	5340	Economy	14400.00
0005435426415	5340	Economy	15800.00
0005435426329	5340	Economy	14400.00
0005435305049	5340	Economy	15800.00
0005435319769	5340	Economy	15800.00
0005432133652	5340	Economy	15800.00
0005434345270	5340	Economy	14400.00
0005435616962	5340	Economy	14400.00
0005435426246	5340	Economy	14400.00
0005434245719	5340	Economy	14400.00
0005435319755	5340	Economy	14400.00
0005435426226	5340	Economy	14400.00
0005435426561	5340	Economy	14400.00
0005435616968	5340	Economy	14400.00
0005435426205	5340	Economy	14400.00
0005435617204	5340	Economy	14400.00
0005434245714	5340	Economy	14400.00
0005434245656	5340	Economy	14400.00
0005435302308	5340	Economy	14400.00
0005435616965	5340	Economy	14400.00
0005435426549	5340	Economy	14400.00
0005434245661	5340	Economy	14400.00
0005435097495	5340	Economy	14400.00
0005434245657	5340	Economy	14400.00
0005435042898	5340	Economy	14400.00
0005435426569	5340	Economy	14400.00
0005435426538	5340	Economy	14400.00
0005435616971	5340	Economy	14400.00
0005435426227	5340	Economy	14400.00
0005435042915	5340	Economy	14400.00
0005435616980	5340	Economy	14400.00
0005434245662	5340	Economy	14400.00
0005435616984	5340	Economy	14400.00
0005435556768	5340	Economy	14400.00
0005435426437	5340	Economy	14400.00
0005434245700	5340	Economy	14400.00
0005435616959	5340	Economy	14400.00
0005434245697	5340	Economy	14400.00
0005435426354	5340	Economy	14400.00
0005434245621	5340	Economy	14400.00
0005435426428	5340	Economy	14400.00
0005434573762	5340	Economy	14400.00
0005435426310	5340	Economy	14400.00
0005435426387	5340	Economy	14400.00
0005435305050	5340	Economy	14400.00
0005434345269	5340	Economy	14400.00
0005435426540	5340	Economy	14400.00
0005435426250	5340	Economy	14400.00
0005435302309	5340	Economy	14400.00
0005434245584	5340	Economy	14400.00
0005434245681	5340	Economy	14400.00
0005435426392	5340	Economy	14400.00
0005435319767	5340	Economy	14400.00
0005434656597	5340	Economy	14400.00
0005435616963	5340	Economy	14400.00
0005435616981	5340	Economy	14400.00
0005434345273	5340	Economy	14400.00
0005433719214	5340	Economy	14400.00
0005432363478	5340	Economy	14400.00
0005435426361	5340	Economy	14400.00
0005435616988	5340	Economy	14400.00
0005432363480	5340	Economy	15800.00
0005435616975	5340	Economy	14400.00
0005434245585	5340	Economy	15800.00
0005435426275	5340	Economy	15800.00
0005435097493	5340	Economy	14400.00
0005435426539	5340	Economy	14400.00
0005435426058	5340	Economy	14400.00
0005435616966	5340	Economy	14400.00
0005435426173	5340	Economy	14400.00
0005434345260	5340	Economy	14400.00
0005435426571	5340	Economy	14400.00
0005435426057	5340	Economy	14400.00
0005435616970	5340	Economy	14400.00
0005434345262	5340	Economy	14400.00
0005435302293	5340	Economy	14400.00
0005435490337	5340	Economy	14400.00
0005432841064	5340	Economy	14400.00
0005435302316	5340	Economy	14400.00
0005435616969	5340	Economy	14400.00
0005435426505	5340	Economy	14400.00
0005435617202	5340	Economy	14400.00
0005434345271	5340	Economy	14400.00
0005435426436	5340	Economy	14400.00
0005432363476	5340	Economy	14400.00
0005435319802	5340	Economy	14400.00
0005434245603	5340	Economy	14400.00
0005434573768	5340	Economy	14400.00
0005435626884	5340	Economy	14400.00
0005435616987	5340	Economy	14400.00
0005435616976	5340	Economy	14400.00
0005435616961	5340	Economy	14400.00
0005433719196	5340	Economy	14400.00
0005434245569	5340	Economy	14400.00
0005434245668	5340	Economy	14400.00
0005434345265	5340	Economy	14400.00
0005435302324	5340	Economy	14400.00
0005432133647	5340	Economy	14400.00
0005435426223	5340	Economy	14400.00
0005435426479	5340	Economy	14400.00
0005435426222	5340	Economy	14400.00
0005432047662	5340	Economy	14400.00
0005435490335	5340	Economy	14400.00
0005435302306	5340	Economy	14400.00
0005435380370	5340	Economy	14400.00
0005435616974	5340	Economy	14400.00
0005435319726	5340	Economy	14400.00
0005434573765	5340	Economy	14400.00
0005434245499	5340	Economy	14400.00
0005435097494	5340	Economy	14400.00
0005432133649	5340	Economy	14400.00
0005434245722	5340	Economy	14400.00
0005434245670	5340	Economy	14400.00
0005435426541	5340	Economy	14400.00
0005435426400	5340	Economy	14400.00
0005435616979	5340	Economy	14400.00
0005434245543	5340	Economy	14400.00
0005435380371	5340	Economy	14400.00
0005435616967	5340	Economy	14400.00
0005435426493	5340	Economy	14400.00
0005435042902	5340	Economy	14400.00
0005434245582	5340	Economy	14400.00
0005435426550	5340	Economy	14400.00
0005435616993	5340	Economy	14400.00
0005435426592	5340	Economy	14400.00
0005435490336	5340	Economy	14400.00
0005435426506	5340	Economy	14400.00
0005434245608	5340	Economy	14400.00
0005435616990	5340	Economy	14400.00
0005435426172	5340	Economy	14400.00
0005435305048	5340	Economy	14400.00
0005435426406	5340	Economy	14400.00
0005434245583	5340	Economy	14400.00
0005434245552	5340	Economy	14400.00
0005434345259	5340	Economy	14400.00
0005434573764	5340	Economy	14400.00
0005434245560	5340	Economy	14400.00
0005434245828	10917	Business	43100.00
0005435615785	10917	Business	43100.00
0005435616162	10917	Business	43100.00
0005435616031	10917	Business	43100.00
0005435615699	10917	Business	43100.00
0005433719239	10917	Business	43100.00
0005434344661	10917	Business	43100.00
0005435616058	10917	Business	43100.00
0005435950054	10917	Business	43100.00
0005435097405	10917	Business	43100.00
0005435616274	10917	Business	43100.00
0005434573634	10917	Business	43100.00
0005434573564	10917	Business	43100.00
0005432363515	10917	Business	43100.00
0005435615961	10917	Business	43100.00
0005435426821	10917	Business	43100.00
0005432165258	10917	Business	43100.00
0005434245840	10917	Business	43100.00
0005435616169	10917	Business	43100.00
0005435426824	10917	Business	43100.00
0005435615816	10917	Business	43100.00
0005434345018	10917	Business	43100.00
0005435097406	10917	Business	43100.00
0005435490312	10917	Comfort	24400.00
0005435615964	10917	Comfort	24400.00
0005435615957	10917	Comfort	24400.00
0005435426813	10917	Comfort	24400.00
0005434245831	10917	Comfort	24400.00
0005435615986	10917	Comfort	24400.00
0005435305077	10917	Comfort	24400.00
0005435380440	10917	Comfort	24400.00
0005435616026	10917	Comfort	24400.00
0005434344947	10917	Comfort	24400.00
0005435615823	10917	Comfort	24400.00
0005435615971	10917	Comfort	24400.00
0005434344662	10917	Comfort	24400.00
0005435426798	10917	Comfort	24400.00
0005435616126	10917	Comfort	24400.00
0005435426819	10917	Comfort	24400.00
0005435615956	10917	Comfort	24400.00
0005435426817	10917	Comfort	24400.00
0005435490318	10917	Comfort	24400.00
0005435426804	10917	Comfort	24400.00
0005434573633	10917	Comfort	24400.00
0005435616494	10917	Comfort	24400.00
0005435426803	10917	Comfort	24400.00
0005435097432	10917	Comfort	24400.00
0005435426823	10917	Comfort	24400.00
0005435615906	10917	Comfort	24400.00
0005434344773	10917	Economy	14400.00
0005435616291	10917	Economy	14400.00
0005435042936	10917	Economy	14400.00
0005435615969	10917	Economy	14400.00
0005435616136	10917	Economy	14400.00
0005435616147	10917	Economy	14400.00
0005434573638	10917	Economy	14400.00
0005434245832	10917	Economy	14400.00
0005435616304	10917	Economy	14400.00
0005434245835	10917	Economy	14400.00
0005435555416	10917	Economy	14400.00
0005434344878	10917	Economy	14400.00
0005435616392	10917	Economy	14400.00
0005435616357	10917	Economy	14400.00
0005435615744	10917	Economy	14400.00
0005434245834	10917	Economy	14400.00
0005435616080	10917	Economy	14400.00
0005435616669	10917	Economy	14400.00
0005434344794	10917	Economy	14400.00
0005435097391	10917	Economy	14400.00
0005435426808	10917	Economy	14400.00
0005434345017	10917	Economy	14400.00
0005435616520	10917	Economy	14400.00
0005435616496	10917	Economy	14400.00
0005435616174	10917	Economy	14400.00
0005435616194	10917	Economy	14400.00
0005434344983	10917	Economy	14400.00
0005435426809	10917	Economy	14400.00
0005435616167	10917	Economy	14400.00
0005434344857	10917	Economy	14400.00
0005435616244	10917	Economy	14400.00
0005435426801	10917	Economy	14400.00
0005434344984	10917	Economy	14400.00
0005435615866	10917	Economy	14400.00
0005435426800	10917	Economy	14400.00
0005434344862	10917	Economy	14400.00
0005435426814	10917	Economy	14400.00
0005435616025	10917	Economy	14400.00
0005435616141	10917	Economy	14400.00
0005435616284	10917	Economy	14400.00
0005435616161	10917	Economy	14400.00
0005435426812	10917	Economy	14400.00
0005435616108	10917	Economy	14400.00
0005435615792	10917	Economy	14400.00
0005435097412	10917	Economy	14400.00
0005435616359	10917	Economy	14400.00
0005434344993	10917	Economy	14400.00
0005435615794	10917	Economy	14400.00
0005434344910	10917	Economy	15800.00
0005435426816	10917	Economy	15800.00
0005435616282	10917	Economy	15800.00
0005435616187	10917	Economy	14400.00
0005435615808	10917	Economy	14400.00
0005435616241	10917	Economy	15800.00
0005435490311	10917	Economy	14400.00
0005435616419	10917	Economy	14400.00
0005434345008	10917	Economy	14400.00
0005434573637	10917	Economy	14400.00
0005435426797	10917	Economy	14400.00
0005435616148	10917	Economy	14400.00
0005435616414	10917	Economy	14400.00
0005434344879	10917	Economy	14400.00
0005435304273	10917	Economy	14400.00
0005435616143	10917	Economy	14400.00
0005435615791	10917	Economy	14400.00
0005435615833	10917	Economy	14400.00
0005435616083	10917	Economy	14400.00
0005435616135	10917	Economy	14400.00
0005435616152	10917	Economy	14400.00
0005435426811	10917	Economy	14400.00
0005432165260	10917	Economy	14400.00
0005435616013	10917	Economy	14400.00
0005435950053	10917	Economy	14400.00
0005435616057	10917	Economy	14400.00
0005435426805	10917	Economy	14400.00
0005435616413	10917	Economy	14400.00
0005435616142	10917	Economy	14400.00
0005435616139	10917	Economy	14400.00
0005435615483	10917	Economy	14400.00
0005435616120	10917	Economy	14400.00
0005434344883	10917	Economy	14400.00
0005435097422	10917	Economy	14400.00
0005434245836	10917	Economy	14400.00
0005435426818	10917	Economy	14400.00
0005435626880	10917	Economy	14400.00
0005432165259	10917	Economy	14400.00
0005435616122	10917	Economy	14400.00
0005435616242	10917	Economy	14400.00
0005435616305	10917	Economy	14400.00
0005435319824	10917	Economy	14400.00
0005435616518	10917	Economy	14400.00
0005432166996	10917	Economy	14400.00
0005435097400	10917	Economy	14400.00
0005435615930	10917	Economy	14400.00
0005432165262	10917	Economy	14400.00
0005435616563	10917	Economy	14400.00
0005435616009	10917	Economy	14400.00
0005435616351	10917	Economy	14400.00
0005434245839	10917	Economy	14400.00
0005434573672	10917	Economy	14400.00
0005435617180	10917	Economy	14400.00
0005435616283	10917	Economy	14400.00
0005435616435	10917	Economy	14400.00
0005435616562	10917	Economy	14400.00
0005434573689	10917	Economy	14400.00
0005435616263	10917	Economy	14400.00
0005435097410	10917	Economy	14400.00
0005435616399	10917	Economy	14400.00
0005435426810	10917	Economy	14400.00
0005435616313	10917	Economy	14400.00
0005435426820	10917	Economy	14400.00
0005435616358	10917	Economy	14400.00
0005435616327	10917	Economy	14400.00
0005434344876	10917	Economy	14400.00
0005435304272	10917	Economy	14400.00
0005433719241	10917	Economy	14400.00
0005434245830	10917	Economy	14400.00
0005435616137	10917	Economy	14400.00
0005434345026	10917	Economy	14400.00
0005434344856	10917	Economy	14400.00
0005435616286	10917	Economy	14400.00
0005434344982	10917	Economy	14400.00
0005434573702	10917	Economy	14400.00
0005435616235	10917	Economy	14400.00
0005435615750	10917	Economy	14400.00
0005435097401	10917	Economy	14400.00
0005434245838	10917	Economy	14400.00
0005434573601	10917	Economy	14400.00
0005434344663	10917	Economy	14400.00
0005434245829	10917	Economy	14400.00
0005435616138	10917	Economy	14400.00
0005434344880	10917	Economy	14400.00
0005433719240	10917	Economy	14400.00
0005435616344	10917	Economy	14400.00
0005435950052	10917	Economy	15800.00
0005435042938	10917	Economy	15800.00
0005435615867	10917	Economy	15800.00
0005432165261	10917	Economy	15800.00
0005434245833	10917	Economy	14400.00
0005435615903	10917	Economy	14400.00
0005435615824	10917	Economy	14400.00
0005434344830	10917	Economy	14400.00
0005435426799	10917	Economy	14400.00
0005435616084	10917	Economy	14400.00
0005435616285	10917	Economy	14400.00
0005435616173	10917	Economy	14400.00
0005435616543	10917	Economy	14400.00
0005435616360	10917	Economy	14400.00
0005435615768	10917	Economy	14400.00
0005434344889	10917	Economy	14400.00
0005435616140	10917	Economy	14400.00
0005435426815	10917	Economy	14400.00
0005435616224	10917	Economy	14400.00
0005435615925	10917	Economy	14400.00
0005434573626	10917	Economy	14400.00
0005435319823	10917	Economy	14400.00
0005434345057	10917	Economy	14400.00
0005435305078	10917	Economy	14400.00
0005435304275	10917	Economy	14400.00
0005435616223	10917	Economy	14400.00
0005435616352	10917	Economy	14400.00
0005434344851	10917	Economy	14400.00
0005435426822	10917	Economy	14400.00
0005435616081	10917	Economy	14400.00
0005432166995	10917	Economy	14400.00
0005434344801	10917	Economy	14400.00
0005434573674	10917	Economy	14400.00
0005435615825	10917	Economy	14400.00
0005435615968	10917	Economy	14400.00
0005435304274	10917	Economy	14400.00
0005435616236	10917	Economy	14400.00
0005434245837	10917	Economy	14400.00
0005434344897	10917	Economy	14400.00
0005432166994	10917	Economy	14400.00
0005435616474	10917	Economy	14400.00
0005435616542	10917	Economy	14400.00
0005435426807	10917	Economy	14400.00
0005435616393	10917	Economy	14400.00
0005435616584	10917	Economy	14400.00
0005435616540	10917	Economy	14400.00
0005434344858	10917	Economy	14400.00
0005435616127	10917	Economy	14400.00
0005435615832	10917	Economy	14400.00
0005435616539	10917	Economy	14400.00
0005434344863	10917	Economy	14400.00
0005435616500	10917	Economy	14400.00
0005435097402	10917	Economy	14400.00
0005435042937	10917	Economy	14400.00
0005435616245	10917	Economy	14400.00
0005435616574	10917	Economy	14400.00
0005434344882	10917	Economy	14400.00
0005435616418	10917	Economy	14400.00
0005435616495	10917	Economy	14400.00
0005435097408	10917	Economy	14400.00
0005435616555	10917	Economy	14400.00
0005435616110	10917	Economy	14400.00
0005434344877	10917	Economy	14400.00
0005435616501	10917	Economy	14400.00
0005434344890	10917	Economy	14400.00
0005432363516	10917	Economy	14400.00
0005434344948	10917	Economy	14400.00
0005435616519	10917	Economy	14400.00
0005435426806	10917	Economy	14400.00
0005434573668	10917	Economy	14400.00
0005435426802	10917	Economy	14400.00
0005435615482	10917	Economy	14400.00
0005435615926	10917	Economy	14400.00
0005435097392	10917	Economy	14400.00
0005435616240	10917	Economy	14400.00
0005433634812	3219	Business	18800.00
0005434143842	3219	Business	18800.00
0005434265960	3219	Business	18800.00
0005432182358	3219	Business	18800.00
0005432461107	3219	Business	18800.00
0005432460904	3219	Business	18800.00
0005434150193	3219	Business	18800.00
0005433507716	3219	Business	18800.00
0005433634813	3219	Business	18800.00
0005433507718	3219	Business	18800.00
0005434150191	3219	Business	18800.00
0005434150201	3219	Business	18800.00
0005432182360	3219	Business	18800.00
0005434265952	3219	Business	18800.00
0005432460968	3219	Business	18800.00
0005434150190	3219	Business	18800.00
0005432460803	3219	Business	18800.00
0005434265966	3219	Business	18800.00
0005432460902	3219	Business	18800.00
0005434265973	3219	Business	18800.00
0005434150202	3219	Business	18800.00
0005432460776	3219	Business	18800.00
0005434265959	3219	Business	18800.00
0005434265958	3219	Business	18800.00
0005434143845	3219	Business	18800.00
0005432461187	3219	Business	18800.00
0005432182362	3219	Business	18800.00
0005433507717	3219	Business	18800.00
0005434265941	3219	Economy	6900.00
0005432461014	3219	Economy	6900.00
0005432461110	3219	Economy	6900.00
0005434265956	3219	Economy	6900.00
0005432461021	3219	Economy	6900.00
0005432461056	3219	Economy	6900.00
0005432460959	3219	Economy	6300.00
0005434150197	3219	Economy	6300.00
0005433806392	3219	Economy	6300.00
0005432461026	3219	Economy	6300.00
0005433507715	3219	Economy	6300.00
0005432461221	3219	Economy	6300.00
0005433507720	3219	Economy	6300.00
0005433806394	3219	Economy	6300.00
0005434143840	3219	Economy	6300.00
0005434265965	3219	Economy	6300.00
0005432461082	3219	Economy	6300.00
0005434150198	3219	Economy	6300.00
0005434265935	3219	Economy	6300.00
0005433507721	3219	Economy	6300.00
0005433634816	3219	Economy	6300.00
0005433806391	3219	Economy	6300.00
0005432460972	3219	Economy	6300.00
0005432182359	3219	Economy	6300.00
0005432461106	3219	Economy	6300.00
0005434265967	3219	Economy	6300.00
0005434265955	3219	Economy	6300.00
0005432461156	3219	Economy	6300.00
0005432461013	3219	Economy	6300.00
0005434182548	3219	Economy	6300.00
0005432460816	3219	Economy	6300.00
0005434265971	3219	Economy	6300.00
0005434143844	3219	Economy	6300.00
0005432461034	3219	Economy	6300.00
0005434230049	3219	Economy	6300.00
0005434265943	3219	Economy	6300.00
0005432461157	3219	Economy	6300.00
0005434230048	3219	Economy	6300.00
0005434150188	3219	Economy	6300.00
0005434265949	3219	Economy	6300.00
0005434265940	3219	Economy	6300.00
0005434150186	3219	Economy	6300.00
0005434143846	3219	Economy	6300.00
0005434265963	3219	Economy	6300.00
0005432460903	3219	Economy	6300.00
0005433806385	3219	Economy	6300.00
0005432461150	3219	Economy	6300.00
0005434265972	3219	Economy	6300.00
0005434143838	3219	Economy	6300.00
0005432182363	3219	Economy	6300.00
0005434265946	3219	Economy	6300.00
0005432460973	3219	Economy	6300.00
0005432461071	3219	Economy	6300.00
0005433806388	3219	Economy	6300.00
0005434143837	3219	Economy	6300.00
0005434150203	3219	Economy	6300.00
0005434265954	3219	Economy	6300.00
0005433806389	3219	Economy	6300.00
0005434230046	3219	Economy	6300.00
0005433634815	3219	Economy	6300.00
0005433634814	3219	Economy	6300.00
0005432460960	3219	Economy	6300.00
0005433634819	3219	Economy	6300.00
0005433806387	3219	Economy	6900.00
0005433806395	3219	Economy	6900.00
0005433806386	3219	Economy	6900.00
0005434150196	3219	Economy	6900.00
0005434143841	3219	Economy	6900.00
0005432461184	3219	Economy	6300.00
0005434265933	3219	Economy	6300.00
0005432460892	3219	Economy	6300.00
0005433634817	3219	Economy	6300.00
0005432461035	3219	Economy	6900.00
0005432460740	3219	Economy	6300.00
0005434150200	3219	Economy	6300.00
0005434265945	3219	Economy	6300.00
0005434265937	3219	Economy	6300.00
0005433634818	3219	Economy	6300.00
0005433806393	3219	Economy	6300.00
0005434182551	3219	Economy	6300.00
0005434265964	3219	Economy	6300.00
0005432182361	3219	Economy	6300.00
0005432182357	3219	Economy	6300.00
0005432461165	3219	Economy	6300.00
0005433507714	3219	Economy	6300.00
0005434150194	3219	Economy	6300.00
0005432460977	3219	Economy	6300.00
0005432461104	3219	Economy	6300.00
0005432460894	3219	Economy	6300.00
0005434265961	3219	Economy	6300.00
0005432460893	3219	Economy	6300.00
0005434150185	3219	Economy	6300.00
0005434265951	3219	Economy	6300.00
0005434150189	3219	Economy	6300.00
0005432461008	3219	Economy	6300.00
0005433507722	3219	Economy	6300.00
0005432460987	3219	Economy	6300.00
0005432460775	3219	Economy	6300.00
0005434265939	3219	Economy	6300.00
0005434265947	3219	Economy	6300.00
0005432460954	3219	Economy	6300.00
0005433806390	3219	Economy	6300.00
0005434265953	3219	Economy	6300.00
0005432461112	3219	Economy	6300.00
0005434265962	3219	Economy	6300.00
0005434150187	3219	Economy	6300.00
0005434143839	3219	Economy	6300.00
0005432460989	3219	Economy	6300.00
0005432461025	3219	Economy	6300.00
0005434265970	3219	Economy	6300.00
0005434150195	3219	Economy	6300.00
0005432461149	3219	Economy	6300.00
0005434265950	3219	Economy	6300.00
0005432460937	3219	Economy	6300.00
0005433507719	3219	Economy	6300.00
0005434143843	3219	Economy	6300.00
0005434265944	3219	Economy	6300.00
0005434265936	3219	Economy	6300.00
0005434265934	3219	Economy	6300.00
0005434265957	3219	Economy	6300.00
0005433634820	3219	Economy	6300.00
0005434265948	3219	Economy	6300.00
0005432460739	3219	Economy	6300.00
0005434265942	3219	Economy	6300.00
0005432461055	3219	Economy	6300.00
0005432461144	3219	Economy	6300.00
0005434265968	3219	Economy	6300.00
0005433507713	3219	Economy	6300.00
0005434150199	3219	Economy	6300.00
0005432461111	3219	Economy	6300.00
0005434265969	3219	Economy	6300.00
0005434150184	3219	Economy	6300.00
0005432182364	3219	Economy	6300.00
0005432460938	3219	Economy	6300.00
0005434230047	3219	Economy	6300.00
0005432460853	3219	Economy	6300.00
0005434265938	3219	Economy	6300.00
0005433507723	3219	Economy	6300.00
0005434150192	3219	Economy	6300.00
0005435886548	3220	Business	18800.00
0005435886327	3220	Business	18800.00
0005435886169	3220	Business	18800.00
0005435886395	3220	Business	18800.00
0005435886436	3220	Business	18800.00
0005435886350	3220	Business	18800.00
0005435886311	3220	Business	18800.00
0005435886399	3220	Business	18800.00
0005435886310	3220	Business	18800.00
0005435886192	3220	Economy	6900.00
0005435886428	3220	Economy	6300.00
0005435886582	3220	Economy	6300.00
0005435886193	3220	Economy	6300.00
0005435886329	3220	Economy	6300.00
0005435886581	3220	Economy	6300.00
0005435886390	3220	Economy	6300.00
0005435886369	3220	Economy	6300.00
0005435886396	3220	Economy	6300.00
0005435886309	3220	Economy	6300.00
0005435886387	3220	Economy	6300.00
0005435886370	3220	Economy	6300.00
0005435886170	3220	Economy	6300.00
0005435886194	3220	Economy	6300.00
0005435886271	3220	Economy	6300.00
0005435886466	3220	Economy	6300.00
0005435886547	3220	Economy	6900.00
0005435886247	3220	Economy	6300.00
0005435886233	3220	Economy	6300.00
0005435886702	3220	Economy	6300.00
0005435886384	3220	Economy	6300.00
0005435886087	3220	Economy	6300.00
0005435886452	3220	Economy	6300.00
0005435886308	3220	Economy	6300.00
0005435886284	3220	Economy	6300.00
0005435886285	3220	Economy	6300.00
0005435886328	3220	Economy	6300.00
0005435886445	3220	Economy	6300.00
0005435886580	3220	Economy	6300.00
0005435886453	3220	Economy	6300.00
0005435886518	3220	Economy	6300.00
0005434326301	8267	Business	18800.00
0005432461406	8267	Business	18800.00
0005435886799	8267	Business	18800.00
0005432461402	8267	Business	18800.00
0005432043125	8267	Business	18800.00
0005435903225	8267	Business	18800.00
0005435886822	8267	Business	18800.00
0005435886813	8267	Business	18800.00
0005435886831	8267	Business	18800.00
0005433507624	8267	Business	18800.00
0005435886810	8267	Business	18800.00
0005432461403	8267	Business	18800.00
0005435886837	8267	Business	18800.00
0005433507575	8267	Business	18800.00
0005435886830	8267	Business	18800.00
0005433507528	8267	Business	18800.00
0005435886796	8267	Business	18800.00
0005435886818	8267	Economy	6900.00
0005435886829	8267	Economy	6900.00
0005434326300	8267	Economy	6900.00
0005435886821	8267	Economy	6300.00
0005435886820	8267	Economy	6300.00
0005433507483	8267	Economy	6300.00
0005432461399	8267	Economy	6300.00
0005433507603	8267	Economy	6300.00
0005435886801	8267	Economy	6300.00
0005435886828	8267	Economy	6300.00
0005435933564	8267	Economy	6300.00
0005432461398	8267	Economy	6300.00
0005435886833	8267	Economy	6300.00
0005435886827	8267	Economy	6300.00
0005432461404	8267	Economy	6300.00
0005432461396	8267	Economy	6300.00
0005433507584	8267	Economy	6300.00
0005432461416	8267	Economy	6300.00
0005433507578	8267	Economy	6300.00
0005433507600	8267	Economy	6300.00
0005433507601	8267	Economy	6300.00
0005435886808	8267	Economy	6300.00
0005435886816	8267	Economy	6300.00
0005435903228	8267	Economy	6300.00
0005435886804	8267	Economy	6300.00
0005435886802	8267	Economy	6300.00
0005435933565	8267	Economy	6300.00
0005435886814	8267	Economy	6300.00
0005435886838	8267	Economy	6300.00
0005433507482	8267	Economy	6300.00
0005435886836	8267	Economy	6300.00
0005435933558	8267	Economy	6300.00
0005435886797	8267	Economy	6300.00
0005435939979	8267	Economy	6300.00
0005435886825	8267	Economy	6300.00
0005435903229	8267	Economy	6300.00
0005433507628	8267	Economy	6300.00
0005432461394	8267	Economy	6300.00
0005432461413	8267	Economy	6300.00
0005432461411	8267	Economy	6300.00
0005435886803	8267	Economy	6300.00
0005432461414	8267	Economy	6300.00
0005433507506	8267	Economy	6300.00
0005435886811	8267	Economy	6300.00
0005435886815	8267	Economy	6300.00
0005433507554	8267	Economy	6300.00
0005433507626	8267	Economy	6900.00
0005435886807	8267	Economy	6900.00
0005435886835	8267	Economy	6300.00
0005433507577	8267	Economy	6300.00
0005433507564	8267	Economy	6300.00
0005435886800	8267	Economy	6300.00
0005435903227	8267	Economy	6300.00
0005433507522	8267	Economy	6300.00
0005435886806	8267	Economy	6300.00
0005435886812	8267	Economy	6300.00
0005432461415	8267	Economy	6300.00
0005435886817	8267	Economy	6300.00
0005435886819	8267	Economy	6300.00
0005435939980	8267	Economy	6300.00
0005435886823	8267	Economy	6300.00
0005435886832	8267	Economy	6300.00
0005432461393	8267	Economy	6300.00
0005433507529	8267	Economy	6300.00
0005433507487	8267	Economy	6300.00
0005432461400	8267	Economy	6300.00
0005435903226	8267	Economy	6300.00
0005434326104	8267	Economy	6300.00
0005433507521	8267	Economy	6300.00
0005432461397	8267	Economy	6300.00
0005432461409	8267	Economy	6300.00
0005435886839	8267	Economy	6300.00
0005432461401	8267	Economy	6300.00
0005435886826	8267	Economy	6300.00
0005435933559	8267	Economy	6300.00
0005433507625	8267	Economy	6300.00
0005432461395	8267	Economy	6300.00
0005435886834	8267	Economy	6300.00
0005435886824	8267	Economy	6300.00
0005432461405	8267	Economy	6300.00
0005435886805	8267	Economy	6300.00
0005432461408	8267	Economy	6300.00
0005432461412	8267	Economy	6300.00
0005433507602	8267	Economy	6300.00
0005432461407	8267	Economy	6300.00
0005435886809	8267	Economy	6300.00
0005433507611	8267	Economy	6300.00
0005432461410	8267	Economy	6300.00
0005435886798	8267	Economy	6300.00
0005433507520	8267	Economy	6300.00
0005433507623	8267	Economy	6300.00
0005433634541	8265	Business	18800.00
0005433634540	8265	Business	18800.00
0005434271352	8265	Business	18800.00
0005433806147	8265	Business	18800.00
0005433806146	8265	Business	18800.00
0005433806054	8265	Business	18800.00
0005433634666	8265	Business	18800.00
0005433634638	8265	Business	18800.00
0005435858734	8265	Business	18800.00
0005433634516	8265	Business	18800.00
0005433806122	8265	Business	18800.00
0005433634593	8265	Business	18800.00
0005433806140	8265	Business	18800.00
0005433634470	8265	Business	18800.00
0005433806080	8265	Business	18800.00
0005435860719	8265	Business	18800.00
0005435858733	8265	Business	18800.00
0005433634580	8265	Economy	6900.00
0005433634608	8265	Economy	6900.00
0005433806035	8265	Economy	6900.00
0005433634622	8265	Economy	6900.00
0005433634489	8265	Economy	6300.00
0005433806102	8265	Economy	6300.00
0005433634520	8265	Economy	6300.00
0005433634592	8265	Economy	6300.00
0005435858740	8265	Economy	6300.00
0005433634548	8265	Economy	6300.00
0005433634511	8265	Economy	6300.00
0005434271351	8265	Economy	6300.00
0005433634579	8265	Economy	6300.00
0005433634482	8265	Economy	6300.00
0005433634420	8265	Economy	6300.00
0005433634574	8265	Economy	6300.00
0005433634673	8265	Economy	6300.00
0005433806059	8265	Economy	6300.00
0005433634464	8265	Economy	6300.00
0005433634665	8265	Economy	6300.00
0005433806225	8265	Economy	6300.00
0005433634609	8265	Economy	6300.00
0005433634473	8265	Economy	6300.00
0005435860718	8265	Economy	6300.00
0005433634599	8265	Economy	6300.00
0005433806058	8265	Economy	6300.00
0005433806204	8265	Economy	6300.00
0005433806273	8265	Economy	6300.00
0005433634600	8265	Economy	6300.00
0005433634569	8265	Economy	6300.00
0005433634547	8265	Economy	6300.00
0005433634587	8265	Economy	6300.00
0005433806130	8265	Economy	6300.00
0005433806231	8265	Economy	6300.00
0005433634590	8265	Economy	6300.00
0005433806141	8265	Economy	6300.00
0005433806274	8265	Economy	6300.00
0005433634568	8265	Economy	6300.00
0005433806220	8265	Economy	6300.00
0005433806111	8265	Economy	6300.00
0005433806168	8265	Economy	6300.00
0005433634523	8265	Economy	6300.00
0005435854093	8265	Economy	6300.00
0005433806142	8265	Economy	6300.00
0005433806169	8265	Economy	6300.00
0005433634545	8265	Economy	6300.00
0005433806196	8265	Economy	6300.00
0005435854084	8265	Economy	6300.00
0005433806131	8265	Economy	6300.00
0005433806132	8265	Economy	6300.00
0005433806037	8265	Economy	6900.00
0005435854091	8265	Economy	6900.00
0005435858739	8265	Economy	6900.00
0005433634417	8265	Economy	6300.00
0005433806015	8265	Economy	6300.00
0005433634472	8265	Economy	6900.00
0005433806096	8265	Economy	6300.00
0005433806177	8265	Economy	6300.00
0005433634639	8265	Economy	6300.00
0005435860716	8265	Economy	6300.00
0005433806317	8265	Economy	6300.00
0005433634607	8265	Economy	6300.00
0005433806036	8265	Economy	6300.00
0005433634345	8265	Economy	6300.00
0005433805964	8265	Economy	6300.00
0005435858732	8265	Economy	6300.00
0005433806081	8265	Economy	6300.00
0005435858730	8265	Economy	6300.00
0005433634630	8265	Economy	6300.00
0005435858736	8265	Economy	6300.00
0005433806176	8265	Economy	6300.00
0005433634471	8265	Economy	6300.00
0005435860717	8265	Economy	6300.00
0005433806095	8265	Economy	6300.00
0005433634488	8265	Economy	6300.00
0005433806014	8265	Economy	6300.00
0005435854085	8265	Economy	6300.00
0005433806055	8265	Economy	6300.00
0005435858735	8265	Economy	6300.00
0005433634419	8265	Economy	6300.00
0005435860714	8265	Economy	6300.00
0005433806165	8265	Economy	6300.00
0005433806219	8265	Economy	6300.00
0005435858738	8265	Economy	6300.00
0005433806173	8265	Economy	6300.00
0005435858731	8265	Economy	6300.00
0005433634621	8265	Economy	6300.00
0005433806121	8265	Economy	6300.00
0005433806195	8265	Economy	6300.00
0005433634561	8265	Economy	6300.00
0005435860715	8265	Economy	6300.00
0005433634581	8265	Economy	6300.00
0005433634613	8265	Economy	6300.00
0005433806230	8265	Economy	6300.00
0005433806272	8265	Economy	6300.00
0005433634640	8265	Economy	6300.00
0005433634522	8265	Economy	6300.00
0005433634546	8265	Economy	6300.00
0005433634641	8265	Economy	6300.00
0005433634507	8265	Economy	6300.00
0005435858737	8265	Economy	6300.00
0005435854092	8265	Economy	6300.00
0005435854094	8265	Economy	6300.00
0005433722499	4612	Business	9900.00
0005433722501	4612	Business	9900.00
0005432384323	4612	Business	9900.00
0005432728305	4612	Business	9900.00
0005433194992	4612	Business	9900.00
0005433194991	4612	Business	9900.00
0005432384318	4612	Business	9900.00
0005433194998	4612	Business	9900.00
0005432728302	4612	Business	9900.00
0005433194995	4612	Business	9900.00
0005432384317	4612	Economy	3300.00
0005433722497	4612	Economy	3300.00
0005432728298	4612	Economy	3600.00
0005433194993	4612	Economy	3600.00
0005433454934	4612	Economy	3600.00
0005432728304	4612	Economy	3300.00
0005432384319	4612	Economy	3300.00
0005433722498	4612	Economy	3300.00
0005432384320	4612	Economy	3300.00
0005432384316	4612	Economy	3300.00
0005433722489	4612	Economy	3300.00
0005432384322	4612	Economy	3300.00
0005434300254	4612	Economy	3300.00
0005432728300	4612	Economy	3300.00
0005434300253	4612	Economy	3300.00
0005433722496	4612	Economy	3300.00
0005432728301	4612	Economy	3300.00
0005434300257	4612	Economy	3300.00
0005433722493	4612	Economy	3300.00
0005433194997	4612	Economy	3300.00
0005432384315	4612	Economy	3300.00
0005434300258	4612	Economy	3300.00
0005433722494	4612	Economy	3300.00
0005433722492	4612	Economy	3300.00
0005434300256	4612	Economy	3300.00
0005433194994	4612	Economy	3300.00
0005433722500	4612	Economy	3300.00
0005434300252	4612	Economy	3300.00
0005432728299	4612	Economy	3300.00
0005432384314	4612	Economy	3300.00
0005434300255	4612	Economy	3300.00
0005434300251	4612	Economy	3300.00
0005433722490	4612	Economy	3300.00
0005432728303	4612	Economy	3300.00
0005432384321	4612	Economy	3300.00
0005434300259	4612	Economy	3300.00
0005433722495	4612	Economy	3300.00
0005433194996	4612	Economy	3300.00
0005433722491	4612	Economy	3300.00
0005432384003	30245	Business	9900.00
0005433722337	30245	Business	9900.00
0005432383898	30245	Business	9900.00
0005432383768	30245	Business	9900.00
0005432728209	30245	Business	9900.00
0005432728190	30245	Business	9900.00
0005433722338	30245	Business	9900.00
0005433722319	30245	Business	9900.00
0005433722326	30245	Business	9900.00
0005433453813	30245	Business	9900.00
0005432728165	30245	Business	9900.00
0005433451664	30245	Economy	3300.00
0005433722346	30245	Economy	3300.00
0005432383974	30245	Economy	3300.00
0005433722320	30245	Economy	3300.00
0005432728206	30245	Economy	3300.00
0005433194906	30245	Economy	3300.00
0005432383703	30245	Economy	3300.00
0005432384016	30245	Economy	3300.00
0005432383896	30245	Economy	3300.00
0005432383730	30245	Economy	3600.00
0005433194912	30245	Economy	3600.00
0005433453809	30245	Economy	3600.00
0005432383797	30245	Economy	3600.00
0005433722344	30245	Economy	3300.00
0005433194905	30245	Economy	3300.00
0005432383909	30245	Economy	3300.00
0005432383967	30245	Economy	3300.00
0005432728191	30245	Economy	3300.00
0005432384060	30245	Economy	3300.00
0005432383955	30245	Economy	3300.00
0005432383774	30245	Economy	3300.00
0005432383859	30245	Economy	3300.00
0005432383990	30245	Economy	3300.00
0005432384067	30245	Economy	3300.00
0005433722339	30245	Economy	3300.00
0005432383893	30245	Economy	3300.00
0005432384005	30245	Economy	3300.00
0005432728227	30245	Economy	3300.00
0005433451655	30245	Economy	3300.00
0005433194917	30245	Economy	3300.00
0005433722343	30245	Economy	3300.00
0005432383937	30245	Economy	3300.00
0005433194907	30245	Economy	3300.00
0005432383729	30245	Economy	3300.00
0005432383938	30245	Economy	3300.00
0005433194916	30245	Economy	3300.00
0005432384068	30245	Economy	3300.00
0005432383954	30245	Economy	3300.00
0005432383921	30245	Economy	3300.00
0005432728166	30245	Economy	3300.00
0005433194903	30245	Economy	3300.00
0005432728196	30245	Economy	3300.00
0005432383899	30245	Economy	3300.00
0005433453812	30245	Economy	3300.00
0005432384087	30245	Economy	3300.00
0005432383920	30245	Economy	3300.00
0005432383816	30245	Economy	3300.00
0005433451665	30245	Economy	3300.00
0005433194910	30245	Economy	3300.00
0005432728189	30245	Economy	3300.00
0005433451661	30245	Economy	3300.00
0005432728230	30245	Economy	3300.00
0005432384088	30245	Economy	3300.00
0005432383775	30245	Economy	3300.00
0005432383796	30245	Economy	3300.00
0005432728238	30245	Economy	3300.00
0005432728155	30245	Economy	3300.00
0005432383913	30245	Economy	3300.00
0005433722332	30245	Economy	3300.00
0005432383858	30245	Economy	3300.00
0005432728188	30245	Economy	3300.00
0005432728208	30245	Economy	3300.00
0005432728239	30245	Economy	3300.00
0005433722345	30245	Economy	3300.00
0005432383716	30245	Economy	3300.00
0005432383892	30245	Economy	3300.00
0005432728228	30245	Economy	3300.00
0005432383977	30245	Economy	3300.00
0005432383745	30245	Economy	3300.00
0005432383995	30245	Economy	3300.00
0005432728154	30245	Economy	3300.00
0005432384004	30245	Economy	3300.00
0005432925140	1710	Business	57200.00
0005435530184	1710	Business	57200.00
0005435530187	1710	Business	57200.00
0005435529884	1710	Economy	19100.00
0005432925137	1710	Economy	19100.00
0005432925146	1710	Economy	19100.00
0005435529885	1710	Economy	21000.00
0005433517160	1710	Economy	19100.00
0005435541639	1710	Economy	19100.00
0005435530186	1710	Economy	19100.00
0005435530188	1710	Economy	19100.00
0005432925136	1710	Economy	19100.00
0005435530189	1710	Economy	19100.00
0005435541638	1710	Economy	19100.00
0005435529890	1710	Economy	19100.00
0005435541636	1710	Economy	19100.00
0005432925148	1710	Economy	19100.00
0005435529886	1710	Economy	19100.00
0005432294559	1710	Economy	19100.00
0005432925147	1710	Economy	19100.00
0005435529889	1710	Economy	19100.00
0005432925145	1710	Economy	19100.00
0005435529887	1710	Economy	19100.00
0005435530185	1710	Economy	19100.00
0005435541637	1710	Economy	19100.00
0005435530190	1710	Economy	19100.00
0005432294560	1710	Economy	19100.00
0005435529888	1710	Economy	19100.00
0005435529891	1710	Economy	19100.00
0005435541640	1710	Economy	19100.00
0005433517161	1710	Economy	19100.00
0005435541413	22004	Business	57200.00
0005435541504	22004	Business	57200.00
0005432925174	22004	Business	57200.00
0005435518271	22004	Business	57200.00
0005435541480	22004	Business	57200.00
0005435518344	22004	Business	57200.00
0005435541473	22004	Economy	19100.00
0005433517084	22004	Economy	19100.00
0005432925172	22004	Economy	19100.00
0005435541450	22004	Economy	19100.00
0005435518306	22004	Economy	19100.00
0005435541364	22004	Economy	21000.00
0005435541489	22004	Economy	21000.00
0005433517115	22004	Economy	21000.00
0005435518285	22004	Economy	19100.00
0005435541496	22004	Economy	19100.00
0005435518288	22004	Economy	19100.00
0005435518270	22004	Economy	19100.00
0005433517074	22004	Economy	19100.00
0005435518281	22004	Economy	19100.00
0005435541465	22004	Economy	19100.00
0005435518300	22004	Economy	19100.00
0005435518314	22004	Economy	19100.00
0005433517069	22004	Economy	19100.00
0005435518316	22004	Economy	19100.00
0005435541483	22004	Economy	19100.00
0005435518307	22004	Economy	19100.00
0005435518272	22004	Economy	19100.00
0005435518289	22004	Economy	19100.00
0005435541474	22004	Economy	19100.00
0005435541428	22004	Economy	19100.00
0005435518274	22004	Economy	19100.00
0005435518247	22004	Economy	19100.00
0005435541481	22004	Economy	19100.00
0005435518273	22004	Economy	19100.00
0005435518318	22004	Economy	19100.00
0005433517083	22004	Economy	19100.00
0005433517106	22004	Economy	19100.00
0005435541477	22004	Economy	19100.00
0005435518257	22004	Economy	19100.00
0005432925173	22004	Economy	19100.00
0005433517076	22004	Economy	19100.00
0005435541429	22004	Economy	19100.00
0005435518246	22004	Economy	19100.00
0005435541542	22004	Economy	19100.00
0005433517077	22004	Economy	19100.00
0005433517104	22004	Economy	19100.00
0005435518317	22004	Economy	19100.00
0005432841073	7406	Business	18500.00
0005435253088	7406	Business	18500.00
0005434459411	7406	Business	18500.00
0005435253068	7406	Business	18500.00
0005435253097	7406	Economy	6200.00
0005435253114	7406	Economy	6200.00
0005435253159	7406	Economy	6200.00
0005432839928	7406	Economy	6200.00
0005435253038	7406	Economy	6800.00
0005435253025	7406	Economy	6200.00
0005435253116	7406	Economy	6200.00
0005435253096	7406	Economy	6200.00
0005434459408	7406	Economy	6200.00
0005434459405	7406	Economy	6200.00
0005432073494	7406	Economy	6200.00
0005435253069	7406	Economy	6200.00
0005434459407	7406	Economy	6200.00
0005432839925	7406	Economy	6200.00
0005432839926	7406	Economy	6200.00
0005435253117	7406	Economy	6200.00
0005432839924	7406	Economy	6200.00
0005432839927	7406	Economy	6200.00
0005435253124	7406	Economy	6200.00
0005432839929	7406	Economy	6200.00
0005432839923	7406	Economy	6200.00
0005432839930	7406	Economy	6200.00
0005435253024	7406	Economy	6200.00
0005435253115	7406	Economy	6200.00
0005435491486	7406	Economy	6200.00
0005434459410	7406	Economy	6200.00
0005435253132	7406	Economy	6200.00
0005434459406	7406	Economy	6200.00
0005435253066	7406	Economy	6200.00
0005434459409	7406	Economy	6200.00
0005435252979	7406	Economy	6200.00
0005434459404	7406	Economy	6200.00
0005432073495	7406	Economy	6200.00
0005435253046	7406	Economy	6200.00
0005432839749	28892	Business	18500.00
0005432839848	28892	Business	18500.00
0005432839767	28892	Business	18500.00
0005432839809	28892	Business	18500.00
0005432839835	28892	Business	18500.00
0005432839849	28892	Economy	6200.00
0005434459280	28892	Economy	6200.00
0005432839724	28892	Economy	6200.00
0005434459187	28892	Economy	6200.00
0005432839717	28892	Economy	6200.00
0005434459297	28892	Economy	6200.00
0005432839766	28892	Economy	6200.00
0005432839624	28892	Economy	6200.00
0005434459300	28892	Economy	6800.00
0005432839512	28892	Economy	6800.00
0005434459208	28892	Economy	6800.00
0005432839691	28892	Economy	6800.00
0005434459224	28892	Economy	6200.00
0005432839773	28892	Economy	6200.00
0005432839831	28892	Economy	6200.00
0005432839803	28892	Economy	6200.00
0005432839776	28892	Economy	6200.00
0005435253216	28892	Economy	6200.00
0005432839720	28892	Economy	6200.00
0005434459225	28892	Economy	6200.00
0005432839754	28892	Economy	6200.00
0005435253217	28892	Economy	6200.00
0005432823493	28892	Economy	6200.00
0005432839847	28892	Economy	6200.00
0005432839630	28892	Economy	6200.00
0005432839692	28892	Economy	6200.00
0005434459261	28892	Economy	6200.00
0005432839781	28892	Economy	6200.00
0005432839698	28892	Economy	6200.00
0005432839833	28892	Economy	6200.00
0005432839763	28892	Economy	6200.00
0005432839758	28892	Economy	6200.00
0005435253218	28892	Economy	6200.00
0005435253219	28892	Economy	6200.00
0005434459299	28892	Economy	6200.00
0005432823494	28892	Economy	6200.00
0005432823492	28892	Economy	6200.00
0005432839739	28892	Economy	6200.00
0005434459301	28892	Economy	6200.00
0005432839759	28892	Economy	6200.00
0005432839869	28892	Economy	6200.00
0005432839834	28892	Economy	6200.00
0005432839808	28892	Economy	6200.00
0005434459347	28892	Economy	6200.00
0005432839795	28892	Economy	6200.00
0005432839868	28892	Economy	6200.00
0005432839753	28892	Economy	6200.00
0005432839780	28892	Economy	6200.00
0005432839707	28892	Economy	6200.00
0005432839631	28892	Economy	6200.00
0005434459247	28892	Economy	6200.00
0005434459348	28892	Economy	6200.00
0005434459262	28892	Economy	6200.00
0005432839804	28892	Economy	6200.00
0005432841059	28892	Economy	6200.00
0005434459279	28892	Economy	6200.00
0005432839783	28892	Economy	6200.00
0005435253215	28892	Economy	6200.00
0005434459311	28892	Economy	6200.00
0005434276150	8781	Economy	48400.00
0005434276149	8781	Economy	48400.00
0005433435519	15731	Business	145300.00
0005435990785	15731	Business	145300.00
0005433435515	15731	Business	145300.00
0005433435516	15731	Business	145300.00
0005435990802	15731	Economy	48400.00
0005435990779	15731	Economy	48400.00
0005433435517	15731	Economy	48400.00
0005434276196	15731	Economy	53300.00
0005433435518	15731	Economy	48400.00
0005433435521	15731	Economy	48400.00
0005435990757	15731	Economy	48400.00
0005434276197	15731	Economy	48400.00
0005435990803	15731	Economy	48400.00
0005435990780	15731	Economy	48400.00
0005433435514	15731	Economy	48400.00
0005433435520	15731	Economy	48400.00
0005433468591	2087	Economy	13300.00
0005433468589	2087	Economy	13300.00
0005432909389	2087	Economy	13300.00
0005432909388	2087	Economy	13300.00
0005433468588	2087	Economy	12100.00
0005433468599	2087	Economy	12100.00
0005433468602	2087	Economy	12100.00
0005432909417	2087	Economy	12100.00
0005432909390	2087	Economy	12100.00
0005433468604	2087	Economy	12100.00
0005433468593	2087	Economy	12100.00
0005432909393	2087	Economy	12100.00
0005433468592	2087	Economy	12100.00
0005433468603	2087	Economy	12100.00
0005433468598	2087	Economy	12100.00
0005432909398	2087	Economy	12100.00
0005433468596	2087	Economy	12100.00
0005432909406	2087	Economy	12100.00
0005433468597	2087	Economy	12100.00
0005433468590	2087	Economy	12100.00
0005432909381	2087	Economy	12100.00
0005432909414	2087	Economy	12100.00
0005433468594	2087	Economy	12100.00
0005433468601	2087	Economy	12100.00
0005433468587	2087	Economy	12100.00
0005433468605	2087	Economy	12100.00
0005433468600	2087	Economy	12100.00
0005432909394	2087	Economy	12100.00
0005433468595	2087	Economy	12100.00
0005432909382	2087	Economy	12100.00
0005432909395	2087	Economy	12100.00
0005432909383	2087	Economy	12100.00
0005432909384	2087	Economy	12100.00
0005435177711	6391	Business	36600.00
0005435177655	6391	Business	36600.00
0005435177641	6391	Business	36600.00
0005432062386	6391	Business	36600.00
0005432361739	6391	Business	36600.00
0005435177673	6391	Business	36600.00
0005435177738	6391	Business	36600.00
0005432361748	6391	Economy	12200.00
0005435177784	6391	Economy	12200.00
0005432361746	6391	Economy	12200.00
0005435177725	6391	Economy	12200.00
0005435177714	6391	Economy	12200.00
0005432363515	6391	Economy	12200.00
0005435490318	6391	Economy	12200.00
0005435177730	6391	Economy	12200.00
0005435177590	6391	Economy	12200.00
0005435723091	6391	Economy	12200.00
0005432361751	6391	Economy	12200.00
0005432336384	6391	Economy	12200.00
0005432361743	6391	Economy	12200.00
0005435490312	6391	Economy	12200.00
0005432363516	6391	Economy	12200.00
0005432361750	6391	Economy	12200.00
0005432361745	6391	Economy	12200.00
0005432361747	6391	Economy	12200.00
0005432361753	6391	Economy	12200.00
0005435177766	6391	Economy	12200.00
0005432361741	6391	Economy	12200.00
0005435177690	6391	Economy	13400.00
0005434149981	6391	Economy	13400.00
0005435177706	6391	Economy	13400.00
0005435177772	6391	Economy	12200.00
0005435177609	6391	Economy	12200.00
0005435177709	6391	Economy	12200.00
0005435177672	6391	Economy	12200.00
0005435177710	6391	Economy	12200.00
0005435177728	6391	Economy	12200.00
0005435177780	6391	Economy	12200.00
0005432361744	6391	Economy	12200.00
0005435177713	6391	Economy	12200.00
0005432361737	6391	Economy	12200.00
0005432361740	6391	Economy	12200.00
0005432361752	6391	Economy	12200.00
0005434150005	6391	Economy	12200.00
0005435177681	6391	Economy	12200.00
0005435177750	6391	Economy	12200.00
0005435177773	6391	Economy	12200.00
0005432361754	6391	Economy	12200.00
0005435177712	6391	Economy	12200.00
0005432361749	6391	Economy	12200.00
0005434150054	6391	Economy	12200.00
0005435177751	6391	Economy	12200.00
0005435177689	6391	Economy	12200.00
0005434150055	6391	Economy	12200.00
0005435490311	6391	Economy	12200.00
0005432336383	6391	Economy	12200.00
0005435177764	6391	Economy	12200.00
0005432361738	6391	Economy	12200.00
0005435723082	6391	Economy	12200.00
0005435177739	6391	Economy	12200.00
0005432361742	6391	Economy	12200.00
0005435177637	6391	Economy	12200.00
0005435177656	6391	Economy	12200.00
0005435177735	6391	Economy	12200.00
0005435177734	6391	Economy	12200.00
0005435177591	6391	Economy	12200.00
0005435177768	6391	Economy	12200.00
0005432361598	21009	Business	36600.00
0005434150075	21009	Business	36600.00
0005432363495	21009	Business	36600.00
0005435490339	21009	Business	36600.00
0005435177861	21009	Business	36600.00
0005432361406	21009	Business	36600.00
0005432361657	21009	Business	36600.00
0005432361239	21009	Economy	12200.00
0005435177865	21009	Economy	12200.00
0005432361498	21009	Economy	12200.00
0005432361593	21009	Economy	12200.00
0005432361259	21009	Economy	12200.00
0005435177859	21009	Economy	12200.00
0005432336317	21009	Economy	12200.00
0005432361360	21009	Economy	12200.00
0005432361376	21009	Economy	12200.00
0005432361407	21009	Economy	12200.00
0005432361394	21009	Economy	12200.00
0005435177860	21009	Economy	12200.00
0005432361465	21009	Economy	12200.00
0005432361254	21009	Economy	12200.00
0005432336350	21009	Economy	12200.00
0005432361456	21009	Economy	12200.00
0005432361222	21009	Economy	12200.00
0005432361393	21009	Economy	12200.00
0005432361385	21009	Economy	12200.00
0005432361440	21009	Economy	12200.00
0005432361587	21009	Economy	12200.00
0005432336301	21009	Economy	12200.00
0005432336302	21009	Economy	12200.00
0005435177857	21009	Economy	13400.00
0005432336349	21009	Economy	13400.00
0005432361368	21009	Economy	13400.00
0005432336232	21009	Economy	13400.00
0005432361499	21009	Economy	13400.00
0005432361392	21009	Economy	12200.00
0005432361444	21009	Economy	12200.00
0005432361358	21009	Economy	12200.00
0005435490338	21009	Economy	12200.00
0005435723104	21009	Economy	12200.00
0005435177863	21009	Economy	12200.00
0005432361362	21009	Economy	12200.00
0005432361371	21009	Economy	12200.00
0005432361229	21009	Economy	12200.00
0005432052831	21009	Economy	12200.00
0005432361514	21009	Economy	12200.00
0005432336288	21009	Economy	12200.00
0005432361466	21009	Economy	12200.00
0005432336282	21009	Economy	12200.00
0005434150073	21009	Economy	12200.00
0005432361462	21009	Economy	12200.00
0005432361513	21009	Economy	12200.00
0005432361359	21009	Economy	12200.00
0005435177862	21009	Economy	12200.00
0005434150074	21009	Economy	12200.00
0005432361433	21009	Economy	12200.00
0005432361352	21009	Economy	12200.00
0005432361658	21009	Economy	12200.00
0005434150076	21009	Economy	12200.00
0005434150072	21009	Economy	12200.00
0005432363481	21009	Economy	12200.00
0005432363494	21009	Economy	12200.00
0005435177864	21009	Economy	12200.00
0005432361467	21009	Economy	12200.00
0005432361228	21009	Economy	12200.00
0005435177858	21009	Economy	12200.00
0005432361505	21009	Economy	12200.00
0005432336298	21009	Economy	12200.00
0005435723105	21009	Economy	12200.00
0005432361365	21009	Economy	12200.00
0005432361449	21009	Economy	12200.00
0005432361500	21009	Economy	12200.00
0005432361592	21009	Economy	12200.00
0005432336261	21009	Economy	12200.00
0005432361375	21009	Economy	12200.00
0005432361364	21009	Economy	12200.00
0005432361602	21009	Economy	12200.00
0005432361361	21009	Economy	12200.00
0005434459316	17683	Economy	3400.00
0005434459314	17683	Economy	3400.00
0005434459296	17683	Economy	3400.00
0005434459341	17683	Economy	3100.00
0005434463974	17683	Economy	3100.00
0005434459343	17683	Economy	3100.00
0005434459257	17683	Economy	3100.00
0005434459256	17683	Economy	3100.00
0005434459306	17683	Economy	3100.00
0005434459250	17683	Economy	3100.00
0005434459272	17683	Economy	3100.00
0005434463971	17683	Economy	3100.00
0005434459309	17683	Economy	3100.00
0005434448386	17683	Economy	3100.00
0005434459223	17683	Economy	3100.00
0005434463970	17683	Economy	3100.00
0005434448388	17683	Economy	3100.00
0005434459308	17683	Economy	3100.00
0005434459173	17683	Economy	3100.00
0005434459248	17683	Economy	3100.00
0005434459249	17683	Economy	3100.00
0005434459222	17683	Economy	3100.00
0005434459315	17683	Economy	3100.00
0005434459298	17683	Economy	3100.00
0005434459273	17683	Economy	3100.00
0005434459246	17683	Economy	3100.00
0005434459269	17683	Economy	3100.00
0005434459317	17683	Economy	3100.00
0005434463991	29113	Economy	3400.00
0005434463992	29113	Economy	3100.00
0005434459406	29113	Economy	3100.00
0005434459411	29113	Economy	3100.00
0005434448414	29113	Economy	3100.00
0005434459404	29113	Economy	3100.00
0005434459409	29113	Economy	3100.00
0005434459407	29113	Economy	3100.00
0005434186269	29113	Economy	3100.00
0005434448413	29113	Economy	3100.00
0005434459410	29113	Economy	3100.00
0005434463993	29113	Economy	3100.00
0005434459408	29113	Economy	3100.00
0005434459405	29113	Economy	3100.00
0005432605464	21467	Economy	7300.00
0005432605463	21467	Economy	6600.00
0005432605474	21467	Economy	6600.00
0005432605479	21467	Economy	6600.00
0005432605478	21467	Economy	6600.00
0005435218139	21467	Economy	6600.00
0005435220503	21467	Economy	6600.00
0005432605467	21467	Economy	6600.00
0005435218141	21467	Economy	6600.00
0005432605465	21467	Economy	6600.00
0005432605470	21467	Economy	6600.00
0005432605472	21467	Economy	6600.00
0005432605480	21467	Economy	6600.00
0005432605475	21467	Economy	6600.00
0005432605477	21467	Economy	6600.00
0005432605468	21467	Economy	6600.00
0005432605473	21467	Economy	6600.00
0005435218140	21467	Economy	6600.00
0005432605471	21467	Economy	6600.00
0005432605466	21467	Economy	6600.00
0005432605469	21467	Economy	6600.00
0005435220495	21467	Economy	6600.00
0005432605476	21467	Economy	6600.00
0005435218123	21467	Economy	6600.00
0005435220504	21467	Economy	6600.00
0005432605064	31676	Economy	7300.00
0005432605129	31676	Economy	7300.00
0005432605015	31676	Economy	7300.00
0005432605096	31676	Economy	7300.00
0005432605194	31676	Economy	6600.00
0005432605039	31676	Economy	6600.00
0005432605168	31676	Economy	6600.00
0005432604943	31676	Economy	6600.00
0005432605153	31676	Economy	6600.00
0005432605208	31676	Economy	6600.00
0005432605077	31676	Economy	6600.00
0005432605260	31676	Economy	6600.00
0005432605215	31676	Economy	6600.00
0005432605259	31676	Economy	6600.00
0005432605155	31676	Economy	6600.00
0005432605245	31676	Economy	6600.00
0005432605143	31676	Economy	6600.00
0005432605078	31676	Economy	6600.00
0005432605273	31676	Economy	6600.00
0005432605097	31676	Economy	6600.00
0005432605152	31676	Economy	6600.00
0005432605238	31676	Economy	6600.00
0005432605119	31676	Economy	6600.00
0005432605218	31676	Economy	6600.00
0005432605161	31676	Economy	6600.00
0005432605272	31676	Economy	6600.00
0005432605154	31676	Economy	6600.00
0005432605022	31676	Economy	6600.00
0005432605264	31676	Economy	6600.00
0005432605174	31676	Economy	6600.00
0005432605207	31676	Economy	6600.00
0005432605217	31676	Economy	6600.00
0005432605172	31676	Economy	6600.00
0005432604942	31676	Economy	6600.00
0005432605090	31676	Economy	6600.00
0005432605173	31676	Economy	6600.00
0005432605130	31676	Economy	6600.00
0005432605091	31676	Economy	6600.00
0005432604941	31676	Economy	6600.00
0005432605053	31676	Economy	6600.00
0005432605016	31676	Economy	6600.00
0005432605205	31676	Economy	6600.00
0005432605131	31676	Economy	6600.00
0005432604977	31676	Economy	6600.00
0005432605089	31676	Economy	6600.00
0005432605017	31676	Economy	6600.00
0005432605206	31676	Economy	6600.00
0005432605148	31676	Economy	6600.00
0005432605144	31676	Economy	6600.00
0005432605088	31676	Economy	6600.00
0005434606893	18915	Economy	6600.00
0005435904729	18915	Economy	6600.00
0005435904915	18915	Economy	6600.00
0005434606894	18915	Economy	6600.00
0005434606892	18915	Economy	6600.00
0005435904914	18915	Economy	6600.00
0005434606932	22404	Economy	6600.00
0005435904722	22404	Economy	6600.00
0005434606934	22404	Economy	6600.00
0005435904906	22404	Economy	6600.00
0005434606933	22404	Economy	6600.00
0005435904907	22404	Economy	6600.00
0005433875421	373	Business	44500.00
0005433293394	373	Business	44500.00
0005432748659	373	Business	44500.00
0005432748662	373	Business	44500.00
0005432748666	373	Business	44500.00
0005432891497	373	Business	44500.00
0005432891417	373	Economy	14800.00
0005432891480	373	Economy	16300.00
0005433293377	373	Economy	16300.00
0005432753399	373	Economy	16300.00
0005432220130	373	Economy	14800.00
0005432891438	373	Economy	14800.00
0005432891467	373	Economy	14800.00
0005433875402	373	Economy	14800.00
0005432891478	373	Economy	14800.00
0005432891539	373	Economy	14800.00
0005432220128	373	Economy	14800.00
0005432891470	373	Economy	14800.00
0005432748664	373	Economy	14800.00
0005432891538	373	Economy	14800.00
0005433293376	373	Economy	14800.00
0005432748668	373	Economy	14800.00
0005432891511	373	Economy	14800.00
0005433293353	373	Economy	14800.00
0005433293352	373	Economy	14800.00
0005432220129	373	Economy	14800.00
0005432891479	373	Economy	14800.00
0005432748667	373	Economy	14800.00
0005432891420	373	Economy	14800.00
0005432891465	373	Economy	14800.00
0005432891510	373	Economy	14800.00
0005432220127	373	Economy	14800.00
0005433293391	373	Economy	14800.00
0005432748665	373	Economy	14800.00
0005432891496	373	Economy	14800.00
0005432891416	373	Economy	14800.00
0005432753398	373	Economy	14800.00
0005432891463	373	Economy	14800.00
0005432748669	373	Economy	14800.00
0005432891370	373	Economy	14800.00
0005432891378	373	Economy	14800.00
0005432748658	373	Economy	14800.00
0005432748661	373	Economy	14800.00
0005433293395	373	Economy	14800.00
0005432748663	373	Economy	14800.00
0005432891475	373	Economy	14800.00
0005432751625	373	Economy	14800.00
0005433875413	373	Economy	14800.00
0005432751624	373	Economy	14800.00
0005432748670	373	Economy	14800.00
0005432891466	373	Economy	14800.00
0005432748660	373	Economy	14800.00
0005432748512	12050	Business	44500.00
0005432748549	12050	Business	44500.00
0005435154639	12050	Business	44500.00
0005435627127	12050	Business	44500.00
0005432748453	12050	Business	44500.00
0005435154633	12050	Business	44500.00
0005432748583	12050	Business	44500.00
0005432748246	12050	Business	44500.00
0005432748606	12050	Business	44500.00
0005432891583	12050	Business	44500.00
0005433293438	12050	Economy	14800.00
0005435154647	12050	Economy	14800.00
0005432748578	12050	Economy	14800.00
0005435154662	12050	Economy	14800.00
0005432748474	12050	Economy	14800.00
0005432891580	12050	Economy	14800.00
0005433293432	12050	Economy	14800.00
0005432753368	12050	Economy	16300.00
0005432748382	12050	Economy	16300.00
0005432891579	12050	Economy	14800.00
0005432748247	12050	Economy	14800.00
0005432748505	12050	Economy	14800.00
0005432753375	12050	Economy	14800.00
0005435154624	12050	Economy	14800.00
0005433293433	12050	Economy	14800.00
0005432748579	12050	Economy	14800.00
0005435154635	12050	Economy	14800.00
0005432748389	12050	Economy	14800.00
0005432748357	12050	Economy	14800.00
0005432891581	12050	Economy	14800.00
0005435627126	12050	Economy	14800.00
0005433293437	12050	Economy	14800.00
0005432753370	12050	Economy	14800.00
0005432748442	12050	Economy	14800.00
0005432748338	12050	Economy	14800.00
0005432748302	12050	Economy	14800.00
0005435154631	12050	Economy	14800.00
0005432753374	12050	Economy	14800.00
0005435154621	12050	Economy	14800.00
0005432748339	12050	Economy	14800.00
0005433293436	12050	Economy	14800.00
0005432748471	12050	Economy	14800.00
0005432748470	12050	Economy	14800.00
0005432891582	12050	Economy	14800.00
0005432748361	12050	Economy	14800.00
0005432748343	12050	Economy	14800.00
0005432748561	12050	Economy	14800.00
0005432748488	12050	Economy	14800.00
0005435154653	12050	Economy	14800.00
0005432748268	12050	Economy	14800.00
0005435154632	12050	Economy	14800.00
0005432748431	12050	Economy	14800.00
0005432753369	12050	Economy	14800.00
0005432756919	12050	Economy	14800.00
0005432748363	12050	Economy	14800.00
0005432753373	12050	Economy	14800.00
0005432748435	12050	Economy	14800.00
0005432753372	12050	Economy	14800.00
0005432891578	12050	Economy	14800.00
0005432748373	12050	Economy	14800.00
0005432748525	12050	Economy	14800.00
0005432748548	12050	Economy	14800.00
0005432748430	12050	Economy	14800.00
0005435154622	12050	Economy	14800.00
0005432748375	12050	Economy	14800.00
0005433293434	12050	Economy	14800.00
0005432748360	12050	Economy	14800.00
0005432748528	12050	Economy	14800.00
0005432748303	12050	Economy	14800.00
0005432748434	12050	Economy	14800.00
0005432748422	12050	Economy	14800.00
0005433293435	12050	Economy	14800.00
0005435154634	12050	Economy	14800.00
0005432748390	12050	Economy	14800.00
0005432748511	12050	Economy	14800.00
0005432748494	12050	Economy	14800.00
0005432748421	12050	Economy	14800.00
0005432748607	12050	Economy	14800.00
0005433525349	18953	Economy	28200.00
0005432928103	18953	Economy	28200.00
0005433525353	18953	Economy	25700.00
0005433525350	18953	Economy	25700.00
0005433531405	18953	Economy	25700.00
0005432928099	18953	Economy	25700.00
0005433531403	18953	Economy	25700.00
0005432928095	18953	Economy	25700.00
0005432928102	18953	Economy	25700.00
0005433525354	18953	Economy	25700.00
0005432928092	18953	Economy	25700.00
0005433525348	18953	Economy	25700.00
0005433525356	18953	Economy	25700.00
0005433531404	18953	Economy	25700.00
0005433525352	18953	Economy	25700.00
0005432928084	18953	Economy	25700.00
0005433525355	18953	Economy	25700.00
0005433525351	18953	Economy	25700.00
0005433525265	32506	Economy	28200.00
0005433525343	32506	Economy	28200.00
0005433527328	32506	Economy	25700.00
0005433527341	32506	Economy	25700.00
0005433525291	32506	Economy	25700.00
0005432928147	32506	Economy	25700.00
0005433527350	32506	Economy	25700.00
0005433525266	32506	Economy	25700.00
0005432928148	32506	Economy	25700.00
0005433525267	32506	Economy	25700.00
0005433531379	32506	Economy	25700.00
0005433525329	32506	Economy	25700.00
0005433525328	32506	Economy	25700.00
0005433525344	32506	Economy	25700.00
0005433525290	32506	Economy	25700.00
0005433527349	32506	Economy	25700.00
0005432928145	32506	Economy	25700.00
0005433525289	32506	Economy	25700.00
0005433525277	32506	Economy	25700.00
0005433525249	32506	Economy	25700.00
0005433525301	32506	Economy	25700.00
0005433527342	32506	Economy	25700.00
0005432928146	32506	Economy	25700.00
0005434827224	5277	Business	84000.00
0005435374697	5277	Business	84000.00
0005434827234	5277	Business	84000.00
0005435374736	5277	Business	84000.00
0005435304252	5277	Business	84000.00
0005435179706	5277	Business	84000.00
0005432394219	5277	Business	84000.00
0005435314989	5277	Business	84000.00
0005432121745	5277	Business	84000.00
0005435299867	5277	Business	84000.00
0005435374602	5277	Business	84000.00
0005435374832	5277	Business	84000.00
0005435386670	5277	Business	84000.00
0005435735220	5277	Business	84000.00
0005432394222	5277	Business	84000.00
0005435374799	5277	Business	84000.00
0005434831287	5277	Business	84000.00
0005435374610	5277	Business	84000.00
0005434827200	5277	Business	84000.00
0005435314991	5277	Business	84000.00
0005435374691	5277	Comfort	47600.00
0005435374971	5277	Business	84000.00
0005435314978	5277	Comfort	47600.00
0005435304254	5277	Comfort	47600.00
0005434827233	5277	Comfort	47600.00
0005434827206	5277	Comfort	47600.00
0005435374716	5277	Comfort	47600.00
0005435735224	5277	Comfort	47600.00
0005435374587	5277	Comfort	47600.00
0005434558591	5277	Comfort	47600.00
0005432394220	5277	Comfort	47600.00
0005434558600	5277	Comfort	47600.00
0005434558583	5277	Comfort	47600.00
0005434827211	5277	Comfort	47600.00
0005434827231	5277	Comfort	47600.00
0005435374365	5277	Comfort	47600.00
0005435374530	5277	Comfort	47600.00
0005435374811	5277	Comfort	47600.00
0005434831286	5277	Comfort	47600.00
0005434827223	5277	Comfort	47600.00
0005434827212	5277	Comfort	47600.00
0005435374695	5277	Comfort	47600.00
0005434827230	5277	Comfort	47600.00
0005434827205	5277	Comfort	47600.00
0005435735243	5277	Economy	28000.00
0005434827207	5277	Economy	28000.00
0005434827226	5277	Economy	28000.00
0005434558588	5277	Economy	28000.00
0005434558584	5277	Economy	28000.00
0005434558599	5277	Economy	28000.00
0005435374619	5277	Economy	28000.00
0005435314975	5277	Economy	28000.00
0005434831285	5277	Economy	28000.00
0005435374409	5277	Economy	28000.00
0005434827221	5277	Economy	28000.00
0005435314977	5277	Economy	28000.00
0005434558594	5277	Economy	28000.00
0005435374757	5277	Economy	28000.00
0005434558586	5277	Economy	28000.00
0005435374662	5277	Economy	28000.00
0005435374592	5277	Economy	28000.00
0005435386698	5277	Economy	28000.00
0005435374326	5277	Economy	28000.00
0005435314998	5277	Economy	28000.00
0005435374543	5277	Economy	28000.00
0005435374366	5277	Economy	28000.00
0005432121747	5277	Economy	28000.00
0005432394221	5277	Economy	28000.00
0005435374770	5277	Economy	28000.00
0005434558603	5277	Economy	28000.00
0005435314992	5277	Economy	28000.00
0005435374620	5277	Economy	28000.00
0005435374665	5277	Economy	28000.00
0005432121748	5277	Economy	28000.00
0005434827225	5277	Economy	28000.00
0005435314990	5277	Economy	28000.00
0005432396358	5277	Economy	30800.00
0005435374628	5277	Economy	30800.00
0005435374778	5277	Economy	28000.00
0005434827228	5277	Economy	28000.00
0005435374576	5277	Economy	30800.00
0005435374593	5277	Economy	28000.00
0005435374525	5277	Economy	28000.00
0005435374735	5277	Economy	28000.00
0005435374664	5277	Economy	28000.00
0005435315032	5277	Economy	28000.00
0005435386669	5277	Economy	28000.00
0005434827220	5277	Economy	28000.00
0005435386697	5277	Economy	28000.00
0005434827232	5277	Economy	28000.00
0005435374495	5277	Economy	28000.00
0005434558585	5277	Economy	28000.00
0005435374854	5277	Economy	28000.00
0005435314955	5277	Economy	28000.00
0005434827219	5277	Economy	28000.00
0005435374461	5277	Economy	28000.00
0005435315026	5277	Economy	28000.00
0005432121746	5277	Economy	28000.00
0005435374978	5277	Economy	28000.00
0005434827229	5277	Economy	28000.00
0005434827240	5277	Economy	28000.00
0005434827201	5277	Economy	28000.00
0005435374972	5277	Economy	28000.00
0005434827218	5277	Economy	28000.00
0005434827216	5277	Economy	28000.00
0005435374515	5277	Economy	28000.00
0005434558582	5277	Economy	28000.00
0005435374674	5277	Economy	28000.00
0005435374572	5277	Economy	28000.00
0005435374686	5277	Economy	28000.00
0005434827214	5277	Economy	28000.00
0005435314988	5277	Economy	28000.00
0005432396357	5277	Economy	28000.00
0005435315025	5277	Economy	28000.00
0005435374800	5277	Economy	28000.00
0005434827222	5277	Economy	28000.00
0005435304241	5277	Economy	28000.00
0005435315041	5277	Economy	28000.00
0005435299884	5277	Economy	28000.00
0005435374882	5277	Economy	28000.00
0005434827236	5277	Economy	28000.00
0005435374661	5277	Economy	28000.00
0005435374761	5277	Economy	28000.00
0005435374730	5277	Economy	28000.00
0005434827215	5277	Economy	28000.00
0005435375040	5277	Economy	28000.00
0005434558598	5277	Economy	28000.00
0005435315027	5277	Economy	28000.00
0005435314963	5277	Economy	28000.00
0005435661994	5277	Economy	28000.00
0005435374916	5277	Economy	28000.00
0005434827208	5277	Economy	28000.00
0005434827238	5277	Economy	28000.00
0005435374419	5277	Economy	28000.00
0005435179012	5277	Economy	28000.00
0005435374737	5277	Economy	28000.00
0005435386668	5277	Economy	28000.00
0005435374562	5277	Economy	28000.00
0005435299903	5277	Economy	28000.00
0005435314959	5277	Economy	28000.00
0005434827210	5277	Economy	28000.00
0005435374471	5277	Economy	30800.00
0005434558587	5277	Economy	30800.00
0005434558592	5277	Economy	30800.00
0005432396356	5277	Economy	30800.00
0005435299877	5277	Economy	30800.00
0005434558589	5277	Economy	28000.00
0005435374423	5277	Economy	28000.00
0005435299879	5277	Economy	28000.00
0005435374603	5277	Economy	28000.00
0005434827203	5277	Economy	28000.00
0005435375039	5277	Economy	28000.00
0005434827209	5277	Economy	28000.00
0005434827204	5277	Economy	28000.00
0005434558593	5277	Economy	28000.00
0005434558602	5277	Economy	28000.00
0005435374851	5277	Economy	28000.00
0005435374878	5277	Economy	28000.00
0005435374855	5277	Economy	28000.00
0005435315024	5277	Economy	28000.00
0005434558601	5277	Economy	28000.00
0005435299880	5277	Economy	28000.00
0005434558596	5277	Economy	28000.00
0005434558595	5277	Economy	28000.00
0005435315033	5277	Economy	28000.00
0005435304240	5277	Economy	28000.00
0005435374531	5277	Economy	28000.00
0005435314962	5277	Economy	28000.00
0005435374856	5277	Economy	28000.00
0005435314958	5277	Economy	28000.00
0005434827202	5277	Economy	28000.00
0005435314965	5277	Economy	28000.00
0005435374718	5277	Economy	28000.00
0005435374524	5277	Economy	28000.00
0005434827217	5277	Economy	28000.00
0005435374717	5277	Economy	28000.00
0005435374885	5277	Economy	28000.00
0005434558590	5277	Economy	28000.00
0005435374470	5277	Economy	28000.00
0005434827241	5277	Economy	28000.00
0005435374865	5277	Economy	28000.00
0005435374931	5277	Economy	28000.00
0005434827237	5277	Economy	28000.00
0005435374907	5277	Economy	28000.00
0005435374493	5277	Economy	28000.00
0005435314995	5277	Economy	28000.00
0005434827235	5277	Economy	28000.00
0005435374611	5277	Economy	28000.00
0005435374850	5277	Economy	28000.00
0005435374789	5277	Economy	28000.00
0005435374528	5277	Economy	28000.00
0005435374544	5277	Economy	28000.00
0005435315012	5277	Economy	28000.00
0005434827227	5277	Economy	28000.00
0005434827213	5277	Economy	28000.00
0005435299902	5277	Economy	28000.00
0005435374420	5277	Economy	28000.00
0005435661995	5277	Economy	28000.00
0005435661986	5277	Economy	28000.00
0005434558597	5277	Economy	28000.00
0005435735223	5277	Economy	28000.00
0005435374741	5277	Economy	28000.00
0005434827239	5277	Economy	28000.00
0005434826462	9902	Business	84000.00
0005434825736	9902	Business	84000.00
0005434826612	9902	Business	84000.00
0005434826519	9902	Business	84000.00
0005434826689	9902	Business	84000.00
0005435375141	9902	Business	84000.00
0005434826002	9902	Business	84000.00
0005435315135	9902	Business	84000.00
0005434828764	9902	Business	84000.00
0005434826672	9902	Business	84000.00
0005434825790	9902	Business	84000.00
0005434828766	9902	Business	84000.00
0005434665013	9902	Business	84000.00
0005434826342	9902	Comfort	47600.00
0005435150304	9902	Comfort	47600.00
0005434826340	9902	Comfort	47600.00
0005434826551	9902	Comfort	47600.00
0005434826292	9902	Comfort	47600.00
0005434826543	9902	Comfort	47600.00
0005434826735	9902	Comfort	47600.00
0005435375151	9902	Comfort	47600.00
0005435386760	9902	Comfort	47600.00
0005432400199	9902	Comfort	47600.00
0005435150317	9902	Comfort	47600.00
0005435150295	9902	Comfort	47600.00
0005434558450	9902	Comfort	47600.00
0005434826345	9902	Comfort	47600.00
0005434825891	9902	Comfort	47600.00
0005434826599	9902	Comfort	47600.00
0005434825890	9902	Comfort	47600.00
0005434558437	9902	Comfort	47600.00
0005434826202	9902	Comfort	47600.00
0005434825734	9902	Comfort	47600.00
0005434826030	9902	Comfort	47600.00
0005435150252	9902	Comfort	47600.00
0005434826219	9902	Comfort	47600.00
0005435375146	9902	Economy	28000.00
0005434826414	9902	Economy	28000.00
0005434826158	9902	Economy	28000.00
0005435150350	9902	Economy	28000.00
0005435375150	9902	Economy	28000.00
0005434826164	9902	Economy	28000.00
0005434825875	9902	Economy	28000.00
0005435150281	9902	Economy	28000.00
0005435150315	9902	Economy	28000.00
0005434665009	9902	Economy	28000.00
0005434826707	9902	Economy	28000.00
0005435299922	9902	Economy	28000.00
0005434826150	9902	Economy	28000.00
0005434826203	9902	Economy	28000.00
0005434826393	9902	Economy	28000.00
0005434826649	9902	Economy	28000.00
0005434826475	9902	Economy	28000.00
0005434828747	9902	Economy	28000.00
0005435150251	9902	Economy	28000.00
0005435315133	9902	Economy	28000.00
0005434826005	9902	Economy	28000.00
0005434826506	9902	Economy	28000.00
0005435386758	9902	Economy	28000.00
0005434826458	9902	Economy	28000.00
0005434826237	9902	Economy	28000.00
0005435150341	9902	Economy	28000.00
0005434826238	9902	Economy	28000.00
0005435299921	9902	Economy	28000.00
0005434825253	9902	Economy	28000.00
0005435315128	9902	Economy	28000.00
0005432396330	9902	Economy	28000.00
0005434826491	9902	Economy	28000.00
0005435150314	9902	Economy	28000.00
0005434665011	9902	Economy	28000.00
0005434826688	9902	Economy	28000.00
0005434826544	9902	Economy	28000.00
0005435150293	9902	Economy	28000.00
0005435375145	9902	Economy	28000.00
0005434826056	9902	Economy	28000.00
0005435150338	9902	Economy	28000.00
0005434826562	9902	Economy	30800.00
0005434826545	9902	Economy	30800.00
0005435150336	9902	Economy	28000.00
0005435375137	9902	Economy	28000.00
0005434826629	9902	Economy	30800.00
0005434558411	9902	Economy	28000.00
0005434826652	9902	Economy	28000.00
0005434558448	9902	Economy	28000.00
0005434826630	9902	Economy	28000.00
0005434826917	9902	Economy	28000.00
0005434826339	9902	Economy	28000.00
0005434826099	9902	Economy	28000.00
0005435735277	9902	Economy	28000.00
0005434826459	9902	Economy	28000.00
0005435150340	9902	Economy	28000.00
0005434826582	9902	Economy	28000.00
0005432823507	9902	Economy	28000.00
0005432396335	9902	Economy	28000.00
0005434826490	9902	Economy	28000.00
0005434826575	9902	Economy	28000.00
0005434826574	9902	Economy	28000.00
0005432400196	9902	Economy	28000.00
0005435150352	9902	Economy	28000.00
0005435315129	9902	Economy	28000.00
0005434826291	9902	Economy	28000.00
0005434665008	9902	Economy	28000.00
0005434826216	9902	Economy	28000.00
0005435302336	9902	Economy	28000.00
0005434828765	9902	Economy	28000.00
0005434826444	9902	Economy	28000.00
0005434826004	9902	Economy	28000.00
0005434826236	9902	Economy	28000.00
0005434825962	9902	Economy	28000.00
0005434826734	9902	Economy	28000.00
0005434826217	9902	Economy	28000.00
0005432396321	9902	Economy	28000.00
0005434826430	9902	Economy	28000.00
0005434826278	9902	Economy	28000.00
0005434826752	9902	Economy	28000.00
0005434826098	9902	Economy	28000.00
0005434826742	9902	Economy	28000.00
0005434826468	9902	Economy	28000.00
0005434826356	9902	Economy	28000.00
0005435299918	9902	Economy	28000.00
0005434826346	9902	Economy	28000.00
0005434826706	9902	Economy	28000.00
0005434826057	9902	Economy	28000.00
0005435375144	9902	Economy	28000.00
0005434826855	9902	Economy	28000.00
0005434558449	9902	Economy	28000.00
0005435375140	9902	Economy	28000.00
0005435150351	9902	Economy	28000.00
0005434826461	9902	Economy	28000.00
0005435299920	9902	Economy	28000.00
0005435375149	9902	Economy	28000.00
0005434826276	9902	Economy	28000.00
0005432396331	9902	Economy	28000.00
0005434826024	9902	Economy	28000.00
0005434826478	9902	Economy	28000.00
0005434826546	9902	Economy	28000.00
0005432396334	9902	Economy	28000.00
0005434826792	9902	Economy	28000.00
0005432396344	9902	Economy	28000.00
0005435375142	9902	Economy	28000.00
0005434825898	9902	Economy	30800.00
0005434558451	9902	Economy	30800.00
0005435735276	9902	Economy	30800.00
0005435662014	9902	Economy	30800.00
0005434825762	9902	Economy	28000.00
0005434826442	9902	Economy	28000.00
0005434826741	9902	Economy	28000.00
0005434825957	9902	Economy	28000.00
0005435150312	9902	Economy	28000.00
0005435375143	9902	Economy	28000.00
0005435150361	9902	Economy	28000.00
0005434826233	9902	Economy	28000.00
0005432400195	9902	Economy	28000.00
0005434826277	9902	Economy	28000.00
0005434558446	9902	Economy	28000.00
0005434558442	9902	Economy	28000.00
0005434826190	9902	Economy	28000.00
0005434826503	9902	Economy	28000.00
0005434826013	9902	Economy	28000.00
0005435375147	9902	Economy	28000.00
0005432400200	9902	Economy	28000.00
0005434826313	9902	Economy	28000.00
0005434826307	9902	Economy	28000.00
0005434826548	9902	Economy	28000.00
0005435150339	9902	Economy	28000.00
0005434826740	9902	Economy	28000.00
0005435315130	9902	Economy	28000.00
0005435315131	9902	Economy	28000.00
0005435375139	9902	Economy	28000.00
0005434826463	9902	Economy	28000.00
0005435386761	9902	Economy	28000.00
0005432396317	9902	Economy	28000.00
0005435315132	9902	Economy	28000.00
0005434825729	9902	Economy	28000.00
0005435150305	9902	Economy	28000.00
0005434826429	9902	Economy	28000.00
0005434826520	9902	Economy	28000.00
0005434826611	9902	Economy	28000.00
0005434826165	9902	Economy	28000.00
0005432396324	9902	Economy	28000.00
0005434831257	9902	Economy	28000.00
0005434826304	9902	Economy	28000.00
0005434825735	9902	Economy	28000.00
0005434826550	9902	Economy	28000.00
0005435662013	9902	Economy	28000.00
0005434826547	9902	Economy	28000.00
0005434826234	9902	Economy	28000.00
0005435386759	9902	Economy	28000.00
0005435375138	9902	Economy	28000.00
0005434826003	9902	Economy	28000.00
0005435150332	9902	Economy	28000.00
0005435386762	9902	Economy	28000.00
0005434826176	9902	Economy	28000.00
0005434826220	9902	Economy	28000.00
0005434826012	9902	Economy	28000.00
0005434826385	9902	Economy	28000.00
0005434826306	9902	Economy	28000.00
0005434826258	9902	Economy	28000.00
0005434826284	9902	Economy	28000.00
0005435315134	9902	Economy	28000.00
0005435150337	9902	Economy	28000.00
0005434825523	9902	Economy	28000.00
0005434826445	9902	Economy	28000.00
0005434826357	9902	Economy	28000.00
0005435375148	9902	Economy	28000.00
0005434826469	9902	Economy	28000.00
0005435299919	9902	Economy	28000.00
0005434665014	9902	Economy	28000.00
0005434825856	9902	Economy	28000.00
0005434826396	9902	Economy	28000.00
0005435790373	26012	Economy	8200.00
0005435082967	26012	Economy	8200.00
0005435790363	26012	Economy	7400.00
0005435082985	26012	Economy	7400.00
0005435790374	26012	Economy	7400.00
0005435082974	26012	Economy	7400.00
0005435082966	26012	Economy	7400.00
0005435082935	26012	Economy	7400.00
0005435082934	26012	Economy	7400.00
0005435790372	26012	Economy	7400.00
0005435082970	26012	Economy	7400.00
0005435082983	26012	Economy	7400.00
0005435790375	26012	Economy	7400.00
0005435082957	26012	Economy	7400.00
0005435790362	26012	Economy	7400.00
0005434757667	9539	Business	32800.00
0005434757666	9539	Business	32800.00
0005434215691	9539	Business	32800.00
0005434215398	9539	Business	32800.00
0005434757671	9539	Business	32800.00
0005434215521	9539	Business	32800.00
0005434215510	9539	Business	32800.00
0005434757674	9539	Business	32800.00
0005434215579	9539	Business	32800.00
0005434215488	9539	Business	32800.00
0005434757657	9539	Economy	10900.00
0005434757656	9539	Economy	10900.00
0005434215324	9539	Economy	10900.00
0005434215368	9539	Economy	10900.00
0005434215463	9539	Economy	10900.00
0005434757660	9539	Economy	12000.00
0005434215498	9539	Economy	12000.00
0005434215668	9539	Economy	12000.00
0005434757664	9539	Economy	12000.00
0005434215601	9539	Economy	10900.00
0005434215476	9539	Economy	10900.00
0005434215613	9539	Economy	10900.00
0005434215374	9539	Economy	10900.00
0005434215354	9539	Economy	10900.00
0005434757661	9539	Economy	10900.00
0005434215614	9539	Economy	10900.00
0005434215693	9539	Economy	10900.00
0005434215514	9539	Economy	10900.00
0005434215600	9539	Economy	10900.00
0005434757670	9539	Economy	10900.00
0005434215486	9539	Economy	10900.00
0005434215555	9539	Economy	10900.00
0005434215580	9539	Economy	10900.00
0005434757658	9539	Economy	10900.00
0005434215349	9539	Economy	10900.00
0005434757654	9539	Economy	10900.00
0005434215589	9539	Economy	10900.00
0005434215323	9539	Economy	10900.00
0005434215670	9539	Economy	10900.00
0005434215584	9539	Economy	10900.00
0005434215397	9539	Economy	10900.00
0005434757655	9539	Economy	10900.00
0005434215333	9539	Economy	10900.00
0005434757662	9539	Economy	10900.00
0005434215497	9539	Economy	10900.00
0005434215578	9539	Economy	10900.00
0005434215552	9539	Economy	10900.00
0005434215382	9539	Economy	10900.00
0005434215536	9539	Economy	10900.00
0005434757663	9539	Economy	10900.00
0005434215375	9539	Economy	10900.00
0005434757668	9539	Economy	10900.00
0005434215598	9539	Economy	10900.00
0005434215532	9539	Economy	10900.00
0005434215315	9539	Economy	10900.00
0005434215539	9539	Economy	10900.00
0005434215511	9539	Economy	10900.00
0005434215515	9539	Economy	10900.00
0005434757673	9539	Economy	10900.00
0005434215551	9539	Economy	10900.00
0005434215413	9539	Economy	10900.00
0005434757665	9539	Economy	10900.00
0005434215341	9539	Economy	10900.00
0005434757672	9539	Economy	10900.00
0005434215535	9539	Economy	10900.00
0005434215494	9539	Economy	10900.00
0005434757669	9539	Economy	10900.00
0005434757659	9539	Economy	10900.00
0005434757242	28605	Business	32800.00
0005434215852	28605	Business	32800.00
0005434215863	28605	Business	32800.00
0005434757178	28605	Business	32800.00
0005434757301	28605	Business	32800.00
0005434215859	28605	Economy	10900.00
0005434757300	28605	Economy	10900.00
0005434757253	28605	Economy	10900.00
0005434757320	28605	Economy	10900.00
0005434757117	28605	Economy	10900.00
0005434215851	28605	Economy	10900.00
0005434757238	28605	Economy	12000.00
0005434757184	28605	Economy	12000.00
0005434757100	28605	Economy	10900.00
0005434757302	28605	Economy	10900.00
0005434215848	28605	Economy	10900.00
0005434215860	28605	Economy	10900.00
0005434757254	28605	Economy	10900.00
0005434757374	28605	Economy	10900.00
0005434757296	28605	Economy	10900.00
0005434757197	28605	Economy	10900.00
0005434757282	28605	Economy	10900.00
0005434757101	28605	Economy	10900.00
0005434757292	28605	Economy	10900.00
0005434215845	28605	Economy	10900.00
0005434757228	28605	Economy	10900.00
0005434757256	28605	Economy	10900.00
0005434757202	28605	Economy	10900.00
0005434757235	28605	Economy	10900.00
0005434215857	28605	Economy	10900.00
0005434215862	28605	Economy	10900.00
0005434215861	28605	Economy	10900.00
0005434215847	28605	Economy	10900.00
0005434757232	28605	Economy	10900.00
0005434757173	28605	Economy	10900.00
0005434215855	28605	Economy	10900.00
0005434757241	28605	Economy	10900.00
0005434757323	28605	Economy	10900.00
0005434757236	28605	Economy	10900.00
0005434757193	28605	Economy	10900.00
0005434215853	28605	Economy	10900.00
0005434757262	28605	Economy	10900.00
0005434215850	28605	Economy	10900.00
0005434757291	28605	Economy	10900.00
0005434757295	28605	Economy	10900.00
0005434215864	28605	Economy	10900.00
0005434215846	28605	Economy	10900.00
0005434757237	28605	Economy	10900.00
0005434757284	28605	Economy	10900.00
0005434215858	28605	Economy	10900.00
0005434757263	28605	Economy	10900.00
0005434757118	28605	Economy	10900.00
0005434215854	28605	Economy	10900.00
0005434757204	28605	Economy	10900.00
0005434757281	28605	Economy	10900.00
0005434757255	28605	Economy	10900.00
0005434215849	28605	Economy	10900.00
0005434757259	28605	Economy	10900.00
0005434215856	28605	Economy	10900.00
0005435100209	10825	Economy	8900.00
0005434760242	10825	Economy	8900.00
0005435100208	10825	Economy	8900.00
0005434760241	10825	Economy	8900.00
0005434760243	10825	Economy	8900.00
0005435100185	31789	Economy	8900.00
0005435100190	31789	Economy	8900.00
0005435100200	31789	Economy	8900.00
0005435100179	31789	Economy	8900.00
0005435100178	31789	Economy	8900.00
0005435100199	31789	Economy	8900.00
0005433202691	1963	Economy	19000.00
0005434640092	1963	Economy	19000.00
0005433202663	1963	Economy	19000.00
0005434640091	1963	Economy	19000.00
0005433202713	1963	Economy	19000.00
0005433202657	1963	Economy	19000.00
0005435948363	1963	Economy	19000.00
0005433202700	1963	Economy	19000.00
0005434640094	1963	Economy	19000.00
0005434640089	1963	Economy	19000.00
0005434640095	1963	Economy	19000.00
0005435948362	1963	Economy	19000.00
0005433202677	1963	Economy	19000.00
0005434640088	1963	Economy	19000.00
0005433202659	1963	Economy	19000.00
0005434640090	1963	Economy	19000.00
0005434640093	1963	Economy	19000.00
0005434640087	1963	Economy	19000.00
0005433202644	1963	Economy	19000.00
0005433202658	1963	Economy	19000.00
0005434639855	23245	Economy	20900.00
0005434639839	23245	Economy	19000.00
0005433202783	23245	Economy	19000.00
0005434639934	23245	Economy	19000.00
0005433202784	23245	Economy	19000.00
0005434639896	23245	Economy	19000.00
0005434639857	23245	Economy	19000.00
0005434639901	23245	Economy	19000.00
0005433202782	23245	Economy	19000.00
0005434639841	23245	Economy	19000.00
0005434639783	23245	Economy	19000.00
0005434639744	23245	Economy	19000.00
0005434639895	23245	Economy	19000.00
0005434639743	23245	Economy	19000.00
0005434639919	23245	Economy	19000.00
0005434639894	23245	Economy	19000.00
0005433202785	23245	Economy	19000.00
0005434639935	23245	Economy	19000.00
0005435327035	6035	Business	69700.00
0005434601584	6035	Economy	23200.00
0005435326997	6035	Economy	23200.00
0005435327069	6035	Economy	23200.00
0005435327036	6035	Economy	25600.00
0005434601580	6035	Economy	25600.00
0005435326994	6035	Economy	23200.00
0005434601578	6035	Economy	23200.00
0005435327048	6035	Economy	23200.00
0005434601577	6035	Economy	23200.00
0005433533419	6035	Economy	23200.00
0005432111369	6035	Economy	23200.00
0005435327087	6035	Economy	23200.00
0005435327061	6035	Economy	23200.00
0005435327056	6035	Economy	23200.00
0005432111367	6035	Economy	23200.00
0005434601581	6035	Economy	23200.00
0005434601583	6035	Economy	23200.00
0005432111368	6035	Economy	23200.00
0005433533418	6035	Economy	23200.00
0005435327090	6035	Economy	23200.00
0005434601579	6035	Economy	23200.00
0005435327068	6035	Economy	23200.00
0005435327031	6035	Economy	23200.00
0005435327060	6035	Economy	23200.00
0005435327039	6035	Economy	23200.00
0005435327070	6035	Economy	23200.00
0005434601582	6035	Economy	23200.00
0005435327038	6035	Economy	23200.00
0005433533420	6035	Economy	23200.00
0005435327055	6035	Economy	23200.00
0005435327062	6035	Economy	23200.00
0005435326998	6035	Economy	23200.00
0005433527323	18608	Business	69700.00
0005434601402	18608	Business	69700.00
0005434601321	18608	Business	69700.00
0005434601433	18608	Economy	23200.00
0005434601383	18608	Economy	23200.00
0005434601359	18608	Economy	23200.00
0005434601479	18608	Economy	23200.00
0005434601377	18608	Economy	23200.00
0005435327137	18608	Economy	25600.00
0005434601304	18608	Economy	23200.00
0005434601336	18608	Economy	23200.00
0005434601507	18608	Economy	23200.00
0005434601387	18608	Economy	23200.00
0005434601451	18608	Economy	23200.00
0005434601474	18608	Economy	23200.00
0005433527340	18608	Economy	23200.00
0005434601426	18608	Economy	23200.00
0005434601384	18608	Economy	23200.00
0005434601404	18608	Economy	23200.00
0005434601396	18608	Economy	23200.00
0005434601462	18608	Economy	23200.00
0005435327136	18608	Economy	23200.00
0005434601436	18608	Economy	23200.00
0005433527344	18608	Economy	23200.00
0005434601480	18608	Economy	23200.00
0005434601296	18608	Economy	23200.00
0005433531374	18608	Economy	23200.00
0005434601305	18608	Economy	23200.00
0005434601320	18608	Economy	23200.00
0005434601427	18608	Economy	23200.00
0005435327133	18608	Economy	23200.00
0005434601376	18608	Economy	23200.00
0005433527345	18608	Economy	23200.00
0005434601290	18608	Economy	23200.00
0005434601397	18608	Economy	23200.00
0005434601463	18608	Economy	23200.00
0005434601450	18608	Economy	23200.00
0005435327135	18608	Economy	23200.00
0005434601358	18608	Economy	23200.00
0005434601403	18608	Economy	23200.00
0005434601385	18608	Economy	23200.00
0005434601425	18608	Economy	23200.00
0005433527343	18608	Economy	23200.00
0005433531373	18608	Economy	23200.00
0005435327134	18608	Economy	23200.00
0005434757700	10658	Business	9100.00
0005434558569	10658	Business	9100.00
0005433181596	10658	Business	9100.00
0005433181605	10658	Business	9100.00
0005434552796	10658	Business	9100.00
0005434558566	10658	Business	9100.00
0005434552800	10658	Business	9100.00
0005433181633	10658	Business	9100.00
0005434558561	10658	Business	9100.00
0005433181632	10658	Business	9100.00
0005435314954	10658	Business	9100.00
0005433181653	10658	Business	9100.00
0005434558573	10658	Economy	3000.00
0005434757698	10658	Economy	3000.00
0005434552799	10658	Economy	3000.00
0005434552813	10658	Economy	3000.00
0005435314961	10658	Economy	3000.00
0005434558570	10658	Economy	3000.00
0005433181618	10658	Economy	3000.00
0005434558562	10658	Economy	3000.00
0005434558556	10658	Economy	3000.00
0005434552805	10658	Economy	3000.00
0005434757697	10658	Economy	3300.00
0005434558577	10658	Economy	3300.00
0005434552816	10658	Economy	3300.00
0005433181456	10658	Economy	3300.00
0005434558554	10658	Economy	3300.00
0005434552822	10658	Economy	3000.00
0005434558565	10658	Economy	3000.00
0005434558555	10658	Economy	3000.00
0005434552821	10658	Economy	3000.00
0005434552814	10658	Economy	3000.00
0005434552792	10658	Economy	3000.00
0005434552811	10658	Economy	3000.00
0005434552812	10658	Economy	3000.00
0005433181591	10658	Economy	3000.00
0005434558557	10658	Economy	3000.00
0005434552807	10658	Economy	3000.00
0005434552818	10658	Economy	3000.00
0005434558568	10658	Economy	3000.00
0005433181615	10658	Economy	3000.00
0005433181660	10658	Economy	3000.00
0005433181636	10658	Economy	3000.00
0005434552794	10658	Economy	3000.00
0005434558576	10658	Economy	3000.00
0005433181624	10658	Economy	3000.00
0005434552806	10658	Economy	3000.00
0005434552808	10658	Economy	3000.00
0005434558567	10658	Economy	3000.00
0005434552815	10658	Economy	3000.00
0005433181614	10658	Economy	3000.00
0005435314972	10658	Economy	3000.00
0005434552820	10658	Economy	3000.00
0005434558578	10658	Economy	3000.00
0005433181584	10658	Economy	3000.00
0005434558575	10658	Economy	3000.00
0005434552803	10658	Economy	3000.00
0005434552804	10658	Economy	3000.00
0005433181626	10658	Economy	3000.00
0005434552819	10658	Economy	3000.00
0005433181646	10658	Economy	3000.00
0005434558579	10658	Economy	3000.00
0005433181592	10658	Economy	3000.00
0005433181627	10658	Economy	3000.00
0005434757699	10658	Economy	3000.00
0005434558572	10658	Economy	3000.00
0005434558563	10658	Economy	3000.00
0005434558574	10658	Economy	3000.00
0005434558559	10658	Economy	3000.00
0005434552801	10658	Economy	3000.00
0005434558558	10658	Economy	3000.00
0005433181645	10658	Economy	3000.00
0005433181651	10658	Economy	3000.00
0005434552798	10658	Economy	3000.00
0005433181652	10658	Economy	3000.00
0005434558571	10658	Economy	3000.00
0005434558564	10658	Economy	3000.00
0005434552795	10658	Economy	3000.00
0005433181654	10658	Economy	3000.00
0005434552809	10658	Economy	3000.00
0005433181617	10658	Economy	3000.00
0005434552810	10658	Economy	3000.00
0005433181548	10658	Economy	3000.00
0005433181655	10658	Economy	3000.00
0005433181604	10658	Economy	3000.00
0005434558560	10658	Economy	3000.00
0005434552817	10658	Economy	3000.00
0005434558581	10658	Economy	3000.00
0005434552793	10658	Economy	3000.00
0005434552802	10658	Economy	3000.00
0005434552797	10658	Economy	3000.00
0005435314971	10658	Economy	3000.00
0005434558580	10658	Economy	3000.00
0005435315135	27695	Business	9100.00
0005433181822	27695	Business	9100.00
0005435315128	27695	Business	9100.00
0005435315132	27695	Economy	3000.00
0005433181831	27695	Economy	3000.00
0005435315129	27695	Economy	3300.00
0005433181827	27695	Economy	3300.00
0005433181828	27695	Economy	3300.00
0005435315133	27695	Economy	3000.00
0005433181821	27695	Economy	3000.00
0005433181829	27695	Economy	3000.00
0005435315131	27695	Economy	3000.00
0005433181826	27695	Economy	3000.00
0005433181823	27695	Economy	3000.00
0005433181824	27695	Economy	3000.00
0005434757712	27695	Economy	3000.00
0005435315134	27695	Economy	3000.00
0005435315130	27695	Economy	3000.00
0005433181825	27695	Economy	3000.00
0005434757711	27695	Economy	3000.00
0005433181830	27695	Economy	3000.00
0005434552474	27694	Business	9100.00
0005434558439	27694	Business	9100.00
0005434552507	27694	Business	9100.00
0005434554108	27694	Business	9100.00
0005434558441	27694	Business	9100.00
0005434552340	27694	Business	9100.00
0005434558475	27694	Business	9100.00
0005434552456	27694	Economy	3000.00
0005434554106	27694	Economy	3000.00
0005434552613	27694	Economy	3000.00
0005434552592	27694	Economy	3000.00
0005434554105	27694	Economy	3000.00
0005434552508	27694	Economy	3000.00
0005434558438	27694	Economy	3000.00
0005434552357	27694	Economy	3300.00
0005434552279	27694	Economy	3300.00
0005434552280	27694	Economy	3300.00
0005434552492	27694	Economy	3300.00
0005434558471	27694	Economy	3000.00
0005434552526	27694	Economy	3000.00
0005434554116	27694	Economy	3000.00
0005434552417	27694	Economy	3000.00
0005434552459	27694	Economy	3000.00
0005434552301	27694	Economy	3000.00
0005434554113	27694	Economy	3000.00
0005434554109	27694	Economy	3000.00
0005434552229	27694	Economy	3000.00
0005434552428	27694	Economy	3000.00
0005434552302	27694	Economy	3000.00
0005434552171	27694	Economy	3000.00
0005434552366	27694	Economy	3000.00
0005434552487	27694	Economy	3000.00
0005434552599	27694	Economy	3000.00
0005434552513	27694	Economy	3000.00
0005434552557	27694	Economy	3000.00
0005434552385	27694	Economy	3000.00
0005434558480	27694	Economy	3000.00
0005434558434	27694	Economy	3000.00
0005434552598	27694	Economy	3000.00
0005434552480	27694	Economy	3000.00
0005434552415	27694	Economy	3000.00
0005434552512	27694	Economy	3000.00
0005434552388	27694	Economy	3000.00
0005434558440	27694	Economy	3000.00
0005434552193	27694	Economy	3000.00
0005434552591	27694	Economy	3000.00
0005434558435	27694	Economy	3000.00
0005434552389	27694	Economy	3000.00
0005434552296	27694	Economy	3000.00
0005434552228	27694	Economy	3000.00
0005434552687	27694	Economy	3000.00
0005434552324	27694	Economy	3000.00
0005434552365	27694	Economy	3000.00
0005434552257	27694	Economy	3000.00
0005434552263	27694	Economy	3000.00
0005434552262	27694	Economy	3000.00
0005434552386	27694	Economy	3000.00
0005434552192	27694	Economy	3000.00
0005434552577	27694	Economy	3000.00
0005434552529	27694	Economy	3000.00
0005434552159	27694	Economy	3000.00
0005434552416	27694	Economy	3000.00
0005435254515	6123	Economy	11700.00
0005435254522	6123	Economy	11700.00
0005433459343	6123	Economy	11700.00
0005433459342	6123	Economy	11700.00
0005433459320	19336	Economy	11700.00
0005433459319	19336	Economy	11700.00
0005433459316	19336	Economy	11700.00
0005433459315	19336	Economy	11700.00
0005432533356	6710	Business	51100.00
0005435683315	6710	Business	51100.00
0005435438431	6710	Business	51100.00
0005435438430	6710	Business	51100.00
0005435438496	6710	Business	51100.00
0005435438500	6710	Business	51100.00
0005435438411	6710	Business	51100.00
0005435438495	6710	Economy	17000.00
0005434828756	6710	Economy	17000.00
0005435438508	6710	Economy	17000.00
0005435438519	6710	Economy	17000.00
0005435683317	6710	Economy	17000.00
0005435217759	6710	Economy	17000.00
0005435631051	6710	Economy	18700.00
0005435683312	6710	Economy	17000.00
0005432136313	6710	Economy	17000.00
0005435631054	6710	Economy	17000.00
0005435683314	6710	Economy	17000.00
0005432136312	6710	Economy	17000.00
0005435631052	6710	Economy	17000.00
0005435683311	6710	Economy	17000.00
0005435438463	6710	Economy	17000.00
0005435217760	6710	Economy	17000.00
0005434828761	6710	Economy	17000.00
0005435438550	6710	Economy	17000.00
0005435438507	6710	Economy	17000.00
0005435631053	6710	Economy	17000.00
0005435790414	6710	Economy	17000.00
0005435438418	6710	Economy	17000.00
0005435683316	6710	Economy	17000.00
0005435790415	6710	Economy	17000.00
0005435438502	6710	Economy	17000.00
0005435683318	6710	Economy	17000.00
0005435438434	6710	Economy	17000.00
0005435683313	6710	Economy	17000.00
0005435683319	6710	Economy	17000.00
0005435662012	6710	Economy	17000.00
0005435438501	6710	Economy	17000.00
0005435438370	6710	Economy	17000.00
0005435438433	6710	Economy	17000.00
0005435438432	6710	Economy	17000.00
0005435438520	6710	Economy	17000.00
0005435438510	6710	Economy	17000.00
0005435217762	6710	Economy	17000.00
0005435682861	24612	Business	51100.00
0005435682985	24612	Business	51100.00
0005435438585	24612	Business	51100.00
0005435682859	24612	Business	51100.00
0005435682935	24612	Business	51100.00
0005435438584	24612	Business	51100.00
0005435631036	24612	Business	51100.00
0005435661989	24612	Business	51100.00
0005435683073	24612	Business	51100.00
0005435683116	24612	Economy	17000.00
0005435683100	24612	Economy	17000.00
0005435719589	24612	Economy	17000.00
0005435683110	24612	Economy	17000.00
0005435220383	24612	Economy	17000.00
0005435631029	24612	Economy	17000.00
0005435683104	24612	Economy	17000.00
0005432305819	24612	Economy	17000.00
0005435683191	24612	Economy	17000.00
0005435683025	24612	Economy	17000.00
0005435682871	24612	Economy	18700.00
0005435631034	24612	Economy	18700.00
0005435683238	24612	Economy	18700.00
0005435683192	24612	Economy	18700.00
0005435683012	24612	Economy	17000.00
0005435683105	24612	Economy	17000.00
0005435719588	24612	Economy	17000.00
0005435438583	24612	Economy	17000.00
0005435631032	24612	Economy	17000.00
0005435682972	24612	Economy	17000.00
0005435220382	24612	Economy	17000.00
0005435683033	24612	Economy	17000.00
0005435682987	24612	Economy	17000.00
0005435682973	24612	Economy	17000.00
0005435683117	24612	Economy	17000.00
0005435682988	24612	Economy	17000.00
0005435682949	24612	Economy	17000.00
0005435720847	24612	Economy	17000.00
0005435683098	24612	Economy	17000.00
0005435683127	24612	Economy	17000.00
0005435683193	24612	Economy	17000.00
0005435720848	24612	Economy	17000.00
0005435631037	24612	Economy	17000.00
0005435683111	24612	Economy	17000.00
0005435683189	24612	Economy	17000.00
0005435720843	24612	Economy	17000.00
0005435683048	24612	Economy	17000.00
0005435219263	24612	Economy	17000.00
0005435683125	24612	Economy	17000.00
0005435219262	24612	Economy	17000.00
0005435682986	24612	Economy	17000.00
0005435683034	24612	Economy	17000.00
0005435683112	24612	Economy	17000.00
0005435683115	24612	Economy	17000.00
0005435683041	24612	Economy	17000.00
0005435220521	24612	Economy	17000.00
0005435683042	24612	Economy	17000.00
0005435683032	24612	Economy	17000.00
0005435220520	24612	Economy	17000.00
0005435219264	24612	Economy	17000.00
0005435220381	24612	Economy	17000.00
0005435631023	24612	Economy	17000.00
0005435683074	24612	Economy	17000.00
0005432533376	24612	Economy	17000.00
0005435683126	24612	Economy	17000.00
0005435683044	24612	Economy	17000.00
0005435219261	24612	Economy	17000.00
0005435438582	24612	Economy	17000.00
0005435682872	24612	Economy	17000.00
0005435683237	24612	Economy	17000.00
0005435682898	24612	Economy	17000.00
0005435683144	24612	Economy	17000.00
0005435682982	24612	Economy	17000.00
0005435683043	24612	Economy	17000.00
0005435682950	24612	Economy	17000.00
0005435127541	11518	Business	26400.00
0005435127535	11518	Business	26400.00
0005435127532	11518	Business	26400.00
0005435127550	11518	Business	26400.00
0005435127527	11518	Business	26400.00
0005435127547	11518	Economy	8800.00
0005435127543	11518	Economy	8800.00
0005435127528	11518	Economy	8800.00
0005435127530	11518	Economy	8800.00
0005435127544	11518	Economy	8800.00
0005435127531	11518	Economy	8800.00
0005435127525	11518	Economy	8800.00
0005435127539	11518	Economy	8800.00
0005435127551	11518	Economy	8800.00
0005435127548	11518	Economy	8800.00
0005435127538	11518	Economy	8800.00
0005435127549	11518	Economy	8800.00
0005435127546	11518	Economy	8800.00
0005435127529	11518	Economy	8800.00
0005435127536	11518	Economy	8800.00
0005435127533	11518	Economy	8800.00
0005435127545	11518	Economy	8800.00
0005435127542	11518	Economy	8800.00
0005435127540	11518	Economy	8800.00
0005435127524	11518	Economy	8800.00
0005435127526	11518	Economy	8800.00
0005435127537	11518	Economy	8800.00
0005435127534	11518	Economy	8800.00
0005435127439	31887	Business	26400.00
0005435098610	31887	Business	26400.00
0005435126998	31887	Business	26400.00
0005435127307	31887	Business	26400.00
0005435127203	31887	Business	26400.00
0005435127376	31887	Business	26400.00
0005435127125	31887	Economy	8800.00
0005435127294	31887	Economy	8800.00
0005435106061	31887	Economy	8800.00
0005435127221	31887	Economy	8800.00
0005435127293	31887	Economy	8800.00
0005435127440	31887	Economy	8800.00
0005435127118	31887	Economy	9700.00
0005435127255	31887	Economy	9700.00
0005435127373	31887	Economy	8800.00
0005435127222	31887	Economy	8800.00
0005435127299	31887	Economy	8800.00
0005435127358	31887	Economy	8800.00
0005435127157	31887	Economy	8800.00
0005435127275	31887	Economy	8800.00
0005435127155	31887	Economy	8800.00
0005435127169	31887	Economy	8800.00
0005435127204	31887	Economy	8800.00
0005435127261	31887	Economy	8800.00
0005435127377	31887	Economy	8800.00
0005435127391	31887	Economy	8800.00
0005435098611	31887	Economy	8800.00
0005435106049	31887	Economy	8800.00
0005435127359	31887	Economy	8800.00
0005435127365	31887	Economy	8800.00
0005435106048	31887	Economy	8800.00
0005435127455	31887	Economy	8800.00
0005435127244	31887	Economy	8800.00
0005435127250	31887	Economy	8800.00
0005435106053	31887	Economy	8800.00
0005435127390	31887	Economy	8800.00
0005435127426	31887	Economy	8800.00
0005435127235	31887	Economy	8800.00
0005435127243	31887	Economy	8800.00
0005435127374	31887	Economy	8800.00
0005435127226	31887	Economy	8800.00
0005435127428	31887	Economy	8800.00
0005435127117	31887	Economy	8800.00
0005435127368	31887	Economy	8800.00
0005435127384	31887	Economy	8800.00
0005435127360	31887	Economy	8800.00
0005435126997	31887	Economy	8800.00
0005435127161	31887	Economy	8800.00
0005435127228	31887	Economy	8800.00
0005435106044	31887	Economy	8800.00
0005435732573	13517	Business	36600.00
0005435732670	13517	Business	36600.00
0005435732613	13517	Business	36600.00
0005435732595	13517	Business	36600.00
0005433399442	13517	Economy	12200.00
0005433399445	13517	Economy	12200.00
0005433399453	13517	Economy	12200.00
0005433399443	13517	Economy	13400.00
0005433399446	13517	Economy	12200.00
0005433399438	13517	Economy	12200.00
0005433399439	13517	Economy	12200.00
0005433399452	13517	Economy	12200.00
0005433399441	13517	Economy	12200.00
0005433399447	13517	Economy	12200.00
0005433399451	13517	Economy	12200.00
0005435732596	13517	Economy	12200.00
0005433399449	13517	Economy	12200.00
0005433399444	13517	Economy	12200.00
0005433399440	13517	Economy	12200.00
0005435732589	13517	Economy	12200.00
0005435732590	13517	Economy	12200.00
0005433399450	13517	Economy	12200.00
0005435732556	13517	Economy	12200.00
0005435732606	13517	Economy	12200.00
0005433399448	13517	Economy	12200.00
0005435725776	19383	Business	36600.00
0005433399097	19383	Business	36600.00
0005433399084	19383	Business	36600.00
0005433399211	19383	Business	36600.00
0005433399256	19383	Business	36600.00
0005433399037	19383	Business	36600.00
0005433399003	19383	Economy	12200.00
0005433399243	19383	Economy	12200.00
0005433399069	19383	Economy	12200.00
0005433398957	19383	Economy	12200.00
0005435732716	19383	Economy	12200.00
0005433399210	19383	Economy	13400.00
0005433399125	19383	Economy	13400.00
0005433399075	19383	Economy	13400.00
0005433399223	19383	Economy	12200.00
0005433399087	19383	Economy	12200.00
0005433399299	19383	Economy	12200.00
0005435725774	19383	Economy	12200.00
0005433399119	19383	Economy	12200.00
0005433399052	19383	Economy	12200.00
0005433398998	19383	Economy	12200.00
0005433399196	19383	Economy	12200.00
0005433398874	19383	Economy	12200.00
0005433399044	19383	Economy	12200.00
0005433399012	19383	Economy	12200.00
0005433398999	19383	Economy	12200.00
0005433398908	19383	Economy	12200.00
0005433399028	19383	Economy	12200.00
0005433399278	19383	Economy	12200.00
0005433399088	19383	Economy	12200.00
0005433399051	19383	Economy	12200.00
0005433399035	19383	Economy	12200.00
0005435725778	19383	Economy	12200.00
0005435725777	19383	Economy	12200.00
0005435732715	19383	Economy	12200.00
0005433399206	19383	Economy	12200.00
0005433399205	19383	Economy	12200.00
0005435725779	19383	Economy	12200.00
0005433399043	19383	Economy	12200.00
0005433399047	19383	Economy	12200.00
0005433398873	19383	Economy	12200.00
0005433399081	19383	Economy	12200.00
0005433398958	19383	Economy	12200.00
0005435725775	19383	Economy	12200.00
0005433398981	19383	Economy	12200.00
0005433399029	19383	Economy	12200.00
0005433399019	19383	Economy	12200.00
0005433399232	19383	Economy	12200.00
0005433399222	19383	Economy	12200.00
0005433399149	19383	Economy	12200.00
0005435732714	19383	Economy	12200.00
0005433399290	19383	Economy	12200.00
0005433398956	19383	Economy	12200.00
0005433399168	19383	Economy	12200.00
0005433398978	19383	Economy	12200.00
0005433399011	19383	Economy	12200.00
0005433399150	19383	Economy	12200.00
0005435070224	13184	Business	11300.00
0005435070311	13184	Business	11300.00
0005435070083	13184	Business	11300.00
0005435925706	13184	Business	11300.00
0005435070346	13184	Business	11300.00
0005435070417	13184	Business	11300.00
0005435070170	13184	Economy	3800.00
0005435070233	13184	Economy	3800.00
0005435070222	13184	Economy	3800.00
0005435070300	13184	Economy	3800.00
0005435070185	13184	Economy	4100.00
0005435070027	13184	Economy	3800.00
0005435070192	13184	Economy	3800.00
0005435925709	13184	Economy	3800.00
0005435925703	13184	Economy	3800.00
0005435070221	13184	Economy	3800.00
0005435925707	13184	Economy	3800.00
0005435070216	13184	Economy	3800.00
0005435070312	13184	Economy	3800.00
0005435070182	13184	Economy	3800.00
0005435070299	13184	Economy	3800.00
0005435070031	13184	Economy	3800.00
0005435069865	13184	Economy	3800.00
0005435925708	13184	Economy	3800.00
0005435069980	13184	Economy	3800.00
0005435069997	13184	Economy	3800.00
0005435070271	13184	Economy	3800.00
0005435070416	13184	Economy	3800.00
0005435070089	13184	Economy	3800.00
0005435070087	13184	Economy	3800.00
0005435925705	13184	Economy	3800.00
0005435070162	13184	Economy	3800.00
0005435070144	13184	Economy	3800.00
0005435925704	13184	Economy	3800.00
0005435070223	13184	Economy	3800.00
0005435070301	13184	Economy	3800.00
0005435069981	13184	Economy	3800.00
0005435070292	13184	Economy	3800.00
0005435070302	13184	Economy	3800.00
0005435925710	13184	Economy	3800.00
0005435070316	13184	Economy	3800.00
0005435070281	13184	Economy	3800.00
0005435070193	13184	Economy	3800.00
0005435070088	13184	Economy	3800.00
0005435069976	13184	Economy	3800.00
0005435070030	13184	Economy	3800.00
0005435070413	13184	Economy	3800.00
0005435070238	13184	Economy	3800.00
0005435070026	13184	Economy	3800.00
0005435070535	15487	Business	11300.00
0005435925603	15487	Business	11300.00
0005435925559	15487	Business	11300.00
0005435925561	15487	Business	11300.00
0005435925593	15487	Business	11300.00
0005435070522	15487	Business	11300.00
0005435070529	15487	Economy	3800.00
0005435070526	15487	Economy	3800.00
0005435925606	15487	Economy	4100.00
0005435070534	15487	Economy	4100.00
0005435925562	15487	Economy	4100.00
0005435925580	15487	Economy	3800.00
0005435070530	15487	Economy	3800.00
0005435925602	15487	Economy	3800.00
0005435070525	15487	Economy	3800.00
0005435070531	15487	Economy	3800.00
0005435070537	15487	Economy	3800.00
0005435925571	15487	Economy	3800.00
0005435925650	15487	Economy	3800.00
0005435925587	15487	Economy	3800.00
0005435070528	15487	Economy	3800.00
0005435070538	15487	Economy	3800.00
0005435070527	15487	Economy	3800.00
0005435070523	15487	Economy	3800.00
0005435925539	15487	Economy	3800.00
0005435070532	15487	Economy	3800.00
0005435070519	15487	Economy	3800.00
0005435070521	15487	Economy	3800.00
0005435070520	15487	Economy	3800.00
0005435070533	15487	Economy	3800.00
0005435925617	15487	Economy	3800.00
0005435925586	15487	Economy	3800.00
0005435070524	15487	Economy	3800.00
0005435070536	15487	Economy	3800.00
0005435925601	15487	Economy	3800.00
0005434215869	10726	Business	61300.00
0005434757376	10726	Business	61300.00
0005434757205	10726	Business	61300.00
0005434215873	10726	Business	61300.00
0005434757266	10726	Business	61300.00
0005434757267	10726	Business	61300.00
0005434757358	10726	Business	61300.00
0005434757213	10726	Business	61300.00
0005434215874	10726	Business	61300.00
0005434757367	10726	Business	61300.00
0005434757141	10726	Economy	20400.00
0005434757083	10726	Economy	20400.00
0005434757315	10726	Economy	20400.00
0005434757169	10726	Economy	20400.00
0005434215868	10726	Economy	20400.00
0005434215870	10726	Economy	22500.00
0005434757154	10726	Economy	22500.00
0005434757082	10726	Economy	22500.00
0005434215867	10726	Economy	20400.00
0005434757316	10726	Economy	20400.00
0005434757433	10726	Economy	20400.00
0005434757275	10726	Economy	20400.00
0005434757161	10726	Economy	20400.00
0005434757097	10726	Economy	20400.00
0005434757114	10726	Economy	20400.00
0005434215878	10726	Economy	20400.00
0005434215872	10726	Economy	20400.00
0005434757363	10726	Economy	20400.00
0005434757353	10726	Economy	20400.00
0005434757435	10726	Economy	20400.00
0005434757244	10726	Economy	20400.00
0005434757265	10726	Economy	20400.00
0005434757364	10726	Economy	20400.00
0005434215866	10726	Economy	20400.00
0005434757352	10726	Economy	20400.00
0005434757357	10726	Economy	20400.00
0005434757372	10726	Economy	20400.00
0005434757434	10726	Economy	20400.00
0005434215877	10726	Economy	20400.00
0005434757368	10726	Economy	20400.00
0005434215871	10726	Economy	20400.00
0005434757377	10726	Economy	20400.00
0005434757283	10726	Economy	20400.00
0005434757111	10726	Economy	20400.00
0005434757555	10726	Economy	20400.00
0005434757297	10726	Economy	20400.00
0005434215875	10726	Economy	20400.00
0005434757382	10726	Economy	20400.00
0005434757383	10726	Economy	20400.00
0005434757430	10726	Economy	20400.00
0005434757170	10726	Economy	20400.00
0005434757214	10726	Economy	20400.00
0005434757226	10726	Economy	20400.00
0005434757307	10726	Economy	20400.00
0005434757344	10726	Economy	20400.00
0005434757130	10726	Economy	20400.00
0005434215865	10726	Economy	20400.00
0005434757113	10726	Economy	20400.00
0005434757160	10726	Economy	20400.00
0005434215876	10726	Economy	20400.00
0005434757632	28706	Business	61300.00
0005434757637	28706	Business	61300.00
0005434757653	28706	Business	61300.00
0005434757635	28706	Business	61300.00
0005434215504	28706	Business	61300.00
0005434215487	28706	Business	61300.00
0005434215638	28706	Business	61300.00
0005434757626	28706	Business	61300.00
0005434215321	28706	Business	61300.00
0005434757651	28706	Business	61300.00
0005434215545	28706	Business	61300.00
0005434215574	28706	Economy	20400.00
0005434215667	28706	Economy	20400.00
0005434757649	28706	Economy	20400.00
0005434757627	28706	Economy	20400.00
0005434757640	28706	Economy	20400.00
0005434215429	28706	Economy	20400.00
0005434757639	28706	Economy	20400.00
0005434215491	28706	Economy	22500.00
0005434757648	28706	Economy	22500.00
0005434215302	28706	Economy	22500.00
0005434215474	28706	Economy	22500.00
0005434215394	28706	Economy	22500.00
0005434757642	28706	Economy	20400.00
0005434215479	28706	Economy	20400.00
0005434215475	28706	Economy	20400.00
0005434757631	28706	Economy	20400.00
0005434215245	28706	Economy	20400.00
0005434215364	28706	Economy	20400.00
0005434757634	28706	Economy	20400.00
0005434757643	28706	Economy	20400.00
0005434757641	28706	Economy	20400.00
0005434757652	28706	Economy	20400.00
0005434757645	28706	Economy	20400.00
0005434757636	28706	Economy	20400.00
0005434215582	28706	Economy	20400.00
0005434757633	28706	Economy	20400.00
0005434215389	28706	Economy	20400.00
0005434215482	28706	Economy	20400.00
0005434215567	28706	Economy	20400.00
0005434215402	28706	Economy	20400.00
0005434215249	28706	Economy	20400.00
0005434215477	28706	Economy	20400.00
0005434215419	28706	Economy	20400.00
0005434215353	28706	Economy	20400.00
0005434757644	28706	Economy	20400.00
0005434215313	28706	Economy	20400.00
0005434757650	28706	Economy	20400.00
0005434215365	28706	Economy	20400.00
0005434215451	28706	Economy	20400.00
0005434757647	28706	Economy	20400.00
0005434215492	28706	Economy	20400.00
0005434215370	28706	Economy	20400.00
0005434215581	28706	Economy	20400.00
0005434215352	28706	Economy	20400.00
0005434757629	28706	Economy	20400.00
0005434757628	28706	Economy	20400.00
0005434215588	28706	Economy	20400.00
0005434757625	28706	Economy	20400.00
0005434215361	28706	Economy	20400.00
0005434215322	28706	Economy	20400.00
0005434215433	28706	Economy	20400.00
0005434757638	28706	Economy	20400.00
0005434215401	28706	Economy	20400.00
0005434215448	28706	Economy	20400.00
0005434215403	28706	Economy	20400.00
0005434757646	28706	Economy	20400.00
0005434757630	28706	Economy	20400.00
0005434215478	28706	Economy	20400.00
0005434215449	28706	Economy	20400.00
0005435041667	5471	Business	29500.00
0005435041660	5471	Business	29500.00
0005434229884	5471	Business	29500.00
0005434229886	5471	Business	29500.00
0005435041661	5471	Business	29500.00
0005435041657	5471	Economy	9800.00
0005435041659	5471	Economy	9800.00
0005435041664	5471	Economy	9800.00
0005435041658	5471	Economy	9800.00
0005435041652	5471	Economy	9800.00
0005435042936	5471	Economy	9800.00
0005434229876	5471	Economy	9800.00
0005432125660	5471	Economy	9800.00
0005435041662	5471	Economy	9800.00
0005434229977	5471	Economy	9800.00
0005435007712	5471	Economy	9800.00
0005435377923	5471	Economy	9800.00
0005435377924	5471	Economy	9800.00
0005435041655	5471	Economy	9800.00
0005435007711	5471	Economy	9800.00
0005434229910	5471	Economy	9800.00
0005434229723	5471	Economy	9800.00
0005434229795	5471	Economy	9800.00
0005435041663	5471	Economy	10800.00
0005435041654	5471	Economy	9800.00
0005432125659	5471	Economy	9800.00
0005435041665	5471	Economy	9800.00
0005435041666	5471	Economy	9800.00
0005435007710	5471	Economy	9800.00
0005435007707	5471	Economy	9800.00
0005435041656	5471	Economy	9800.00
0005435007713	5471	Economy	9800.00
0005435041653	5471	Economy	9800.00
0005432125661	5471	Economy	9800.00
0005435007709	5471	Economy	9800.00
0005434229796	5471	Economy	9800.00
0005435042937	5471	Economy	9800.00
0005434229887	5471	Economy	9800.00
0005434229911	5471	Economy	9800.00
0005434229831	5471	Economy	9800.00
0005434229845	5471	Economy	9800.00
0005434229821	5471	Economy	9800.00
0005435377925	5471	Economy	9800.00
0005434229724	5471	Economy	9800.00
0005435007708	5471	Economy	9800.00
0005434229820	5471	Economy	9800.00
0005434229890	5471	Economy	9800.00
0005434229846	5471	Economy	9800.00
0005435041651	5471	Economy	9800.00
0005435042938	5471	Economy	9800.00
0005434229808	5471	Economy	9800.00
0005434229818	5471	Economy	9800.00
0005435007714	5471	Economy	9800.00
0005434229976	5471	Economy	9800.00
0005435041650	5471	Economy	9800.00
0005435041056	12994	Business	29500.00
0005435377981	12994	Business	29500.00
0005435377971	12994	Business	29500.00
0005435007573	12994	Business	29500.00
0005435041159	12994	Business	29500.00
0005435041102	12994	Business	29500.00
0005435041106	12994	Business	29500.00
0005435041095	12994	Business	29500.00
0005435377979	12994	Business	29500.00
0005435041152	12994	Business	29500.00
0005435041182	12994	Business	29500.00
0005435007527	12994	Business	29500.00
0005435041131	12994	Economy	9800.00
0005434230024	12994	Economy	9800.00
0005435007648	12994	Economy	9800.00
0005435041180	12994	Economy	9800.00
0005435007484	12994	Economy	9800.00
0005435041002	12994	Economy	9800.00
0005435041084	12994	Economy	9800.00
0005435040947	12994	Economy	9800.00
0005435007582	12994	Economy	9800.00
0005435041241	12994	Economy	9800.00
0005435041044	12994	Economy	9800.00
0005435041383	12994	Economy	9800.00
0005435377974	12994	Economy	9800.00
0005435041250	12994	Economy	9800.00
0005435007511	12994	Economy	9800.00
0005434230027	12994	Economy	9800.00
0005435007530	12994	Economy	9800.00
0005435377973	12994	Economy	9800.00
0005435041107	12994	Economy	9800.00
0005435041143	12994	Economy	9800.00
0005435042907	12994	Economy	9800.00
0005435041273	12994	Economy	9800.00
0005435041045	12994	Economy	9800.00
0005435041183	12994	Economy	9800.00
0005435041153	12994	Economy	9800.00
0005435041354	12994	Economy	9800.00
0005434230023	12994	Economy	9800.00
0005435042912	12994	Economy	9800.00
0005435041322	12994	Economy	9800.00
0005435041096	12994	Economy	9800.00
0005435377980	12994	Economy	9800.00
0005435007595	12994	Economy	9800.00
0005435041164	12994	Economy	9800.00
0005435042913	12994	Economy	9800.00
0005435041384	12994	Economy	9800.00
0005435007503	12994	Economy	9800.00
0005435041247	12994	Economy	9800.00
0005435041417	12994	Economy	9800.00
0005435040958	12994	Economy	9800.00
0005435041105	12994	Economy	10800.00
0005435007518	12994	Economy	10800.00
0005435041221	12994	Economy	10800.00
0005435041054	12994	Economy	10800.00
0005435377977	12994	Economy	10800.00
0005435041160	12994	Economy	10800.00
0005435041260	12994	Economy	9800.00
0005435041167	12994	Economy	9800.00
0005435041313	12994	Economy	9800.00
0005435040895	12994	Economy	9800.00
0005435041064	12994	Economy	9800.00
0005435007510	12994	Economy	9800.00
0005435007539	12994	Economy	9800.00
0005435007647	12994	Economy	9800.00
0005435007547	12994	Economy	9800.00
0005435041457	12994	Economy	9800.00
0005435040894	12994	Economy	9800.00
0005435041169	12994	Economy	9800.00
0005435377970	12994	Economy	9800.00
0005435041166	12994	Economy	9800.00
0005435007649	12994	Economy	9800.00
0005435041321	12994	Economy	9800.00
0005435007472	12994	Economy	9800.00
0005435041171	12994	Economy	9800.00
0005435041365	12994	Economy	9800.00
0005435007446	12994	Economy	9800.00
0005435041073	12994	Economy	9800.00
0005435041418	12994	Economy	9800.00
0005435041323	12994	Economy	9800.00
0005435007593	12994	Economy	9800.00
0005435043303	12994	Economy	9800.00
0005435041181	12994	Economy	9800.00
0005435041311	12994	Economy	9800.00
0005435041085	12994	Economy	9800.00
0005435377978	12994	Economy	9800.00
0005435043296	12994	Economy	9800.00
0005435041023	12994	Economy	9800.00
0005435040979	12994	Economy	9800.00
0005435377972	12994	Economy	9800.00
0005435040957	12994	Economy	9800.00
0005435377969	12994	Economy	9800.00
0005434230025	12994	Economy	9800.00
0005435007526	12994	Economy	9800.00
0005435041135	12994	Economy	9800.00
0005435041364	12994	Economy	9800.00
0005435041324	12994	Economy	9800.00
0005435040943	12994	Economy	9800.00
0005434230026	12994	Economy	9800.00
0005435377976	12994	Economy	9800.00
0005435007596	12994	Economy	9800.00
0005435041117	12994	Economy	9800.00
0005435041320	12994	Economy	9800.00
0005435007483	12994	Economy	9800.00
0005435041456	12994	Economy	9800.00
0005435041222	12994	Economy	9800.00
0005435042914	12994	Economy	9800.00
0005435007607	12994	Economy	9800.00
0005435007562	12994	Economy	9800.00
0005435041453	12994	Economy	9800.00
0005435007574	12994	Economy	9800.00
0005434230022	12994	Economy	9800.00
0005435041449	12994	Economy	9800.00
0005435041031	12994	Economy	9800.00
0005435041190	12994	Economy	9800.00
0005435007564	12994	Economy	9800.00
0005435377975	12994	Economy	9800.00
0005435041434	12994	Economy	9800.00
0005435041254	12994	Economy	9800.00
0005435041092	12994	Economy	9800.00
0005435007473	12994	Economy	9800.00
0005435040970	12994	Economy	9800.00
0005435041197	12994	Economy	9800.00
0005435041072	12994	Economy	9800.00
0005435041055	12994	Economy	9800.00
0005435041198	12994	Economy	9800.00
0005435041248	12994	Economy	9800.00
0005435007608	12994	Economy	9800.00
0005435007625	12994	Economy	9800.00
0005435903033	14904	Business	52900.00
0005435903034	14904	Business	52900.00
0005435554311	14904	Business	52900.00
0005434411899	14904	Business	52900.00
0005435903113	14904	Economy	17600.00
0005435903020	14904	Economy	17600.00
0005434427449	14904	Economy	17600.00
0005435554310	14904	Economy	17600.00
0005435554286	14904	Economy	17600.00
0005435903041	14904	Economy	19400.00
0005435903157	14904	Economy	19400.00
0005434427446	14904	Economy	19400.00
0005435903072	14904	Economy	19400.00
0005434427447	14904	Economy	17600.00
0005435554287	14904	Economy	17600.00
0005435903073	14904	Economy	17600.00
0005435554289	14904	Economy	17600.00
0005435903074	14904	Economy	17600.00
0005434411897	14904	Economy	17600.00
0005435903042	14904	Economy	17600.00
0005435554288	14904	Economy	17600.00
0005435903149	14904	Economy	17600.00
0005434427442	14904	Economy	17600.00
0005434427448	14904	Economy	17600.00
0005435903040	14904	Economy	17600.00
0005435554283	14904	Economy	17600.00
0005435903048	14904	Economy	17600.00
0005435903123	14904	Economy	17600.00
0005434427445	14904	Economy	17600.00
0005435903124	14904	Economy	17600.00
0005434411898	14904	Economy	17600.00
0005435903063	14904	Economy	17600.00
0005434427443	14904	Economy	17600.00
0005434427441	14904	Economy	17600.00
0005435903169	14904	Economy	17600.00
0005435903047	14904	Economy	17600.00
0005435554284	14904	Economy	17600.00
0005434427444	14904	Economy	17600.00
0005435554285	14904	Economy	17600.00
0005435903046	14904	Economy	17600.00
0005434427280	20185	Business	52900.00
0005434427234	20185	Business	52900.00
0005434427095	20185	Business	52900.00
0005434427162	20185	Economy	17600.00
0005434427201	20185	Economy	17600.00
0005434427161	20185	Economy	17600.00
0005435903215	20185	Economy	17600.00
0005434427223	20185	Economy	17600.00
0005434427295	20185	Economy	17600.00
0005434427096	20185	Economy	19400.00
0005434427200	20185	Economy	19400.00
0005434427385	20185	Economy	17600.00
0005434427233	20185	Economy	17600.00
0005434427198	20185	Economy	17600.00
0005435903216	20185	Economy	17600.00
0005434427222	20185	Economy	17600.00
0005434427250	20185	Economy	17600.00
0005434427127	20185	Economy	17600.00
0005434427296	20185	Economy	17600.00
0005434427368	20185	Economy	17600.00
0005434427262	20185	Economy	17600.00
0005434427172	20185	Economy	17600.00
0005434427266	20185	Economy	17600.00
0005434427386	20185	Economy	17600.00
0005434411874	20185	Economy	17600.00
0005434427184	20185	Economy	17600.00
0005434427261	20185	Economy	17600.00
0005434427041	20185	Economy	17600.00
0005434427221	20185	Economy	17600.00
0005434411893	20185	Economy	17600.00
0005434411891	20185	Economy	17600.00
0005434427237	20185	Economy	17600.00
0005434427367	20185	Economy	17600.00
0005434427097	20185	Economy	17600.00
0005435554328	20185	Economy	17600.00
0005434411892	20185	Economy	17600.00
0005435983626	26529	Business	18500.00
0005434273112	26529	Business	18500.00
0005433435381	26529	Business	18500.00
0005434270253	26529	Business	18500.00
0005433435259	26529	Business	18500.00
0005435983641	26529	Business	18500.00
0005432300431	26529	Business	18500.00
0005433435365	26529	Business	18500.00
0005435983644	26529	Economy	6200.00
0005434273109	26529	Economy	6200.00
0005433435149	26529	Economy	6200.00
0005433435335	26529	Economy	6200.00
0005433435287	26529	Economy	6200.00
0005433435150	26529	Economy	6200.00
0005435983642	26529	Economy	6200.00
0005435983619	26529	Economy	6800.00
0005435983643	26529	Economy	6800.00
0005434270252	26529	Economy	6800.00
0005433435269	26529	Economy	6200.00
0005433435342	26529	Economy	6200.00
0005435983635	26529	Economy	6200.00
0005433435220	26529	Economy	6200.00
0005433435083	26529	Economy	6200.00
0005433435262	26529	Economy	6200.00
0005433435223	26529	Economy	6200.00
0005435983615	26529	Economy	6200.00
0005433435085	26529	Economy	6200.00
0005435983631	26529	Economy	6200.00
0005435983628	26529	Economy	6200.00
0005432300436	26529	Economy	6200.00
0005433435364	26529	Economy	6200.00
0005433435225	26529	Economy	6200.00
0005435983634	26529	Economy	6200.00
0005435983624	26529	Economy	6200.00
0005435983638	26529	Economy	6200.00
0005435983627	26529	Economy	6200.00
0005435983623	26529	Economy	6200.00
0005433435145	26529	Economy	6200.00
0005435983636	26529	Economy	6200.00
0005433435294	26529	Economy	6200.00
0005435983620	26529	Economy	6200.00
0005433435157	26529	Economy	6200.00
0005435983622	26529	Economy	6200.00
0005435983637	26529	Economy	6200.00
0005433435207	26529	Economy	6200.00
0005435983632	26529	Economy	6200.00
0005435983625	26529	Economy	6200.00
0005432300432	26529	Economy	6200.00
0005435983621	26529	Economy	6200.00
0005432300434	26529	Economy	6200.00
0005432300435	26529	Economy	6200.00
0005433435275	26529	Economy	6200.00
0005433435230	26529	Economy	6200.00
0005433435330	26529	Economy	6200.00
0005433435331	26529	Economy	6200.00
0005435983618	26529	Economy	6200.00
0005433435288	26529	Economy	6200.00
0005435983629	26529	Economy	6200.00
0005435983633	26529	Economy	6200.00
0005435983640	26529	Economy	6200.00
0005433435224	26529	Economy	6200.00
0005433435084	26529	Economy	6200.00
0005432300433	26529	Economy	6200.00
0005435983639	26529	Economy	6200.00
0005435983617	26529	Economy	6200.00
0005433435171	26529	Economy	6200.00
0005433435198	26529	Economy	6200.00
0005433435222	26529	Economy	6200.00
0005435983630	26529	Economy	6200.00
0005433435146	26529	Economy	6200.00
0005435983616	26529	Economy	6200.00
0005434273117	26529	Economy	6200.00
0005433435199	26529	Economy	6200.00
0005433435382	26529	Economy	6200.00
0005433435200	26529	Economy	6200.00
0005434270251	26529	Economy	6200.00
0005435983289	26693	Business	18500.00
0005435983113	26693	Business	18500.00
0005435983429	26693	Business	18500.00
0005435983109	26693	Business	18500.00
0005435983348	26693	Business	18500.00
0005435983114	26693	Business	18500.00
0005435983177	26693	Business	18500.00
0005433435490	26693	Business	18500.00
0005435983174	26693	Business	18500.00
0005435983217	26693	Economy	6200.00
0005435983496	26693	Economy	6200.00
0005435983367	26693	Economy	6200.00
0005433435496	26693	Economy	6200.00
0005435983176	26693	Economy	6200.00
0005435983324	26693	Economy	6200.00
0005435983326	26693	Economy	6200.00
0005433435488	26693	Economy	6200.00
0005435983325	26693	Economy	6800.00
0005433435493	26693	Economy	6800.00
0005435983110	26693	Economy	6200.00
0005435983290	26693	Economy	6200.00
0005435983200	26693	Economy	6200.00
0005435983291	26693	Economy	6200.00
0005435983212	26693	Economy	6200.00
0005435983137	26693	Economy	6200.00
0005435983283	26693	Economy	6200.00
0005435983236	26693	Economy	6200.00
0005433435491	26693	Economy	6200.00
0005433435492	26693	Economy	6200.00
0005435983203	26693	Economy	6200.00
0005434270266	26693	Economy	6200.00
0005435983360	26693	Economy	6200.00
0005435983215	26693	Economy	6200.00
0005435983123	26693	Economy	6200.00
0005435983333	26693	Economy	6200.00
0005435983202	26693	Economy	6200.00
0005435983235	26693	Economy	6200.00
0005435983255	26693	Economy	6200.00
0005435983016	26693	Economy	6200.00
0005435983356	26693	Economy	6200.00
0005433435498	26693	Economy	6200.00
0005435983448	26693	Economy	6200.00
0005433435494	26693	Economy	6200.00
0005435983374	26693	Economy	6200.00
0005435983129	26693	Economy	6200.00
0005433435489	26693	Economy	6200.00
0005433435486	26693	Economy	6200.00
0005435983231	26693	Economy	6200.00
0005433435497	26693	Economy	6200.00
0005433435500	26693	Economy	6200.00
0005435983419	26693	Economy	6200.00
0005435983173	26693	Economy	6200.00
0005435983122	26693	Economy	6200.00
0005435983347	26693	Economy	6200.00
0005435983276	26693	Economy	6200.00
0005435983447	26693	Economy	6200.00
0005434269165	26693	Economy	6200.00
0005435983133	26693	Economy	6200.00
0005435983237	26693	Economy	6200.00
0005433435495	26693	Economy	6200.00
0005435983254	26693	Economy	6200.00
0005435983138	26693	Economy	6200.00
0005435983134	26693	Economy	6200.00
0005435983275	26693	Economy	6200.00
0005435982986	26693	Economy	6200.00
0005435983221	26693	Economy	6200.00
0005433435487	26693	Economy	6200.00
0005435983308	26693	Economy	6200.00
0005433435499	26693	Economy	6200.00
0005432216352	3161	Economy	11100.00
0005432584769	3161	Economy	11100.00
0005432858288	3161	Economy	10100.00
0005432584775	3161	Economy	10100.00
0005432584771	3161	Economy	10100.00
0005432584774	3161	Economy	10100.00
0005432858302	3161	Economy	10100.00
0005432584772	3161	Economy	10100.00
0005432584768	3161	Economy	10100.00
0005432858312	3161	Economy	10100.00
0005432584765	3161	Economy	10100.00
0005432858328	3161	Economy	10100.00
0005432584763	3161	Economy	10100.00
0005432858349	3161	Economy	10100.00
0005432584762	3161	Economy	10100.00
0005432584764	3161	Economy	10100.00
0005432584766	3161	Economy	10100.00
0005432584770	3161	Economy	10100.00
0005432584767	3161	Economy	10100.00
0005432584773	3161	Economy	10100.00
0005432858311	3161	Economy	10100.00
0005432858327	3161	Economy	10100.00
0005432858301	3161	Economy	10100.00
0005432858340	3161	Economy	10100.00
0005432858408	31489	Economy	11100.00
0005432584584	31489	Economy	11100.00
0005432584657	31489	Economy	11100.00
0005432584661	31489	Economy	10100.00
0005432584578	31489	Economy	10100.00
0005432584658	31489	Economy	10100.00
0005432584600	31489	Economy	10100.00
0005432858405	31489	Economy	10100.00
0005432584561	31489	Economy	10100.00
0005432584651	31489	Economy	10100.00
0005432584586	31489	Economy	10100.00
0005432584683	31489	Economy	10100.00
0005432584544	31489	Economy	10100.00
0005432584634	31489	Economy	10100.00
0005432584652	31489	Economy	10100.00
0005432584562	31489	Economy	10100.00
0005432858406	31489	Economy	10100.00
0005432584660	31489	Economy	10100.00
0005432584608	31489	Economy	10100.00
0005432584585	31489	Economy	10100.00
0005432584656	31489	Economy	10100.00
0005432584682	31489	Economy	10100.00
0005432858407	31489	Economy	10100.00
0005432584639	31489	Economy	10100.00
0005432584708	31489	Economy	10100.00
0005434943614	868	Economy	8300.00
0005433255257	868	Economy	8300.00
0005433255250	868	Economy	7500.00
0005433255259	868	Economy	7500.00
0005433255258	868	Economy	7500.00
0005433255253	868	Economy	7500.00
0005433255216	868	Economy	7500.00
0005434943615	868	Economy	7500.00
0005434943519	16243	Economy	8300.00
0005433255273	16243	Economy	7500.00
0005434943553	16243	Economy	7500.00
0005434943554	16243	Economy	7500.00
0005434943604	16243	Economy	7500.00
0005434943544	16243	Economy	7500.00
0005433255272	16243	Economy	7500.00
0005434943605	16243	Economy	7500.00
0005434943567	16243	Economy	7500.00
0005434943566	16243	Economy	7500.00
0005433255271	16243	Economy	7500.00
0005434943561	16243	Economy	7500.00
0005435654421	21768	Business	9800.00
0005433368634	21768	Business	9800.00
0005435654415	21768	Business	9800.00
0005433368679	21768	Business	9800.00
0005435654408	21768	Business	9800.00
0005433368784	21768	Business	9800.00
0005433368656	21768	Business	9800.00
0005435654432	21768	Business	9800.00
0005435654438	21768	Business	9800.00
0005435654410	21768	Economy	3300.00
0005433368681	21768	Economy	3300.00
0005435654409	21768	Economy	3300.00
0005435654429	21768	Economy	3300.00
0005435654406	21768	Economy	3300.00
0005435654419	21768	Economy	3300.00
0005433368517	21768	Economy	3300.00
0005433368740	21768	Economy	3600.00
0005435654425	21768	Economy	3600.00
0005435654420	21768	Economy	3600.00
0005435654423	21768	Economy	3600.00
0005435654427	21768	Economy	3300.00
0005435654431	21768	Economy	3300.00
0005435654433	21768	Economy	3300.00
0005433368773	21768	Economy	3300.00
0005435654414	21768	Economy	3300.00
0005435654439	21768	Economy	3300.00
0005435654424	21768	Economy	3300.00
0005433368670	21768	Economy	3300.00
0005433368606	21768	Economy	3300.00
0005433368675	21768	Economy	3300.00
0005433368818	21768	Economy	3300.00
0005433368655	21768	Economy	3300.00
0005433368772	21768	Economy	3300.00
0005435654436	21768	Economy	3300.00
0005435654417	21768	Economy	3300.00
0005433368576	21768	Economy	3300.00
0005435654440	21768	Economy	3300.00
0005433368704	21768	Economy	3300.00
0005435654418	21768	Economy	3300.00
0005435654413	21768	Economy	3300.00
0005433368566	21768	Economy	3300.00
0005435654435	21768	Economy	3300.00
0005435654430	21768	Economy	3300.00
0005435654437	21768	Economy	3300.00
0005435654428	21768	Economy	3300.00
0005435654422	21768	Economy	3300.00
0005433368680	21768	Economy	3300.00
0005435654426	21768	Economy	3300.00
0005433368785	21768	Economy	3300.00
0005433368703	21768	Economy	3300.00
0005435654411	21768	Economy	3300.00
0005433368580	21768	Economy	3300.00
0005433368574	21768	Economy	3300.00
0005435654441	21768	Economy	3300.00
0005435654407	21768	Economy	3300.00
0005435654412	21768	Economy	3300.00
0005433368575	21768	Economy	3300.00
0005433368824	21768	Economy	3300.00
0005435654434	21768	Economy	3300.00
0005433368567	21768	Economy	3300.00
0005433368635	21768	Economy	3300.00
0005435654416	21768	Economy	3300.00
0005432667515	9350	Business	186200.00
0005434171430	9350	Business	186200.00
0005435269954	9350	Business	186200.00
0005433786146	9350	Business	186200.00
0005433806387	9350	Business	186200.00
0005435269960	9350	Business	186200.00
0005433806391	9350	Business	186200.00
0005435269920	9350	Business	186200.00
0005435269883	9350	Business	186200.00
0005435270015	9350	Business	186200.00
0005435269906	9350	Business	186200.00
0005433786154	9350	Business	186200.00
0005435270040	9350	Business	186200.00
0005435269923	9350	Economy	68300.00
0005433786140	9350	Economy	68300.00
0005433806395	9350	Economy	62100.00
0005433806390	9350	Economy	62100.00
0005435269887	9350	Economy	62100.00
0005433786144	9350	Economy	62100.00
0005434171361	9350	Economy	62100.00
0005435269962	9350	Economy	62100.00
0005433786142	9350	Economy	62100.00
0005434171406	9350	Economy	62100.00
0005433786155	9350	Economy	62100.00
0005435269981	9350	Economy	62100.00
0005433786151	9350	Economy	62100.00
0005432665335	9350	Economy	62100.00
0005434171415	9350	Economy	62100.00
0005435270047	9350	Economy	62100.00
0005433763624	9350	Economy	62100.00
0005434171356	9350	Economy	62100.00
0005433786148	9350	Economy	62100.00
0005433786157	9350	Economy	62100.00
0005433786132	9350	Economy	62100.00
0005435269985	9350	Economy	62100.00
0005433786147	9350	Economy	62100.00
0005435270060	9350	Economy	62100.00
0005435270014	9350	Economy	62100.00
0005433786143	9350	Economy	62100.00
0005435269888	9350	Economy	62100.00
0005435269953	9350	Economy	62100.00
0005435269922	9350	Economy	62100.00
0005435269977	9350	Economy	62100.00
0005435270004	9350	Economy	62100.00
0005433786156	9350	Economy	62100.00
0005434171370	9350	Economy	62100.00
0005433786149	9350	Economy	62100.00
0005433806385	9350	Economy	62100.00
0005435269982	9350	Economy	62100.00
0005434270245	9350	Economy	62100.00
0005435269916	9350	Economy	62100.00
0005435269963	9350	Economy	62100.00
0005433786150	9350	Economy	62100.00
0005435269993	9350	Economy	62100.00
0005435269890	9350	Economy	62100.00
0005435269996	9350	Economy	62100.00
0005433786134	9350	Economy	62100.00
0005433786138	9350	Economy	62100.00
0005435269893	9350	Economy	62100.00
0005435269991	9350	Economy	62100.00
0005433806389	9350	Economy	62100.00
0005435269947	9350	Economy	62100.00
0005433786136	9350	Economy	62100.00
0005433786145	9350	Economy	62100.00
0005435270041	9350	Economy	62100.00
0005435270046	9350	Economy	62100.00
0005433786139	9350	Economy	62100.00
0005433786141	9350	Economy	62100.00
0005435270042	9350	Economy	62100.00
0005433763626	9350	Economy	62100.00
0005435269992	9350	Economy	62100.00
0005433786133	9350	Economy	62100.00
0005434171340	9350	Economy	62100.00
0005433786137	9350	Economy	62100.00
0005433786153	9350	Economy	62100.00
0005435269921	9350	Economy	62100.00
0005433763625	9350	Economy	62100.00
0005434270246	9350	Economy	62100.00
0005435270045	9350	Economy	62100.00
0005433806386	9350	Economy	62100.00
0005435269995	9350	Economy	62100.00
0005435270039	9350	Economy	62100.00
0005435270022	9350	Economy	62100.00
0005435269989	9350	Economy	62100.00
0005435269925	9350	Economy	62100.00
0005433763621	9350	Economy	62100.00
0005433806392	9350	Economy	62100.00
0005434171407	9350	Economy	62100.00
0005433806388	9350	Economy	62100.00
0005434171355	9350	Economy	62100.00
0005435269902	9350	Economy	62100.00
0005433786135	9350	Economy	62100.00
0005434171416	9350	Economy	62100.00
0005432665336	9350	Economy	62100.00
0005434171378	9350	Economy	62100.00
0005435269924	9350	Economy	62100.00
0005433763622	9350	Economy	62100.00
0005435269889	9350	Economy	62100.00
0005433786158	9350	Economy	62100.00
0005435270043	9350	Economy	62100.00
0005433763620	9350	Economy	62100.00
0005433806393	9350	Economy	62100.00
0005435269917	9350	Economy	62100.00
0005433786131	9350	Economy	62100.00
0005435269964	9350	Economy	62100.00
0005433763623	9350	Economy	62100.00
0005435270013	9350	Economy	62100.00
0005433786152	9350	Economy	62100.00
0005435269894	9350	Economy	62100.00
0005433806394	9350	Economy	62100.00
0005433786159	9350	Economy	62100.00
0005435269933	9350	Economy	62100.00
0005432667516	9350	Economy	62100.00
0005433785800	26266	Business	186200.00
0005435270186	26266	Business	186200.00
0005435858733	26266	Business	186200.00
0005432663081	26266	Business	186200.00
0005433806274	26266	Business	186200.00
0005433806055	26266	Business	186200.00
0005435270192	26266	Business	186200.00
0005433763489	26266	Business	186200.00
0005433785556	26266	Business	186200.00
0005435858736	26266	Business	186200.00
0005433763547	26266	Business	186200.00
0005435270183	26266	Business	186200.00
0005435270199	26266	Business	186200.00
0005433785599	26266	Business	186200.00
0005433806231	26266	Business	186200.00
0005434269164	26266	Business	186200.00
0005433806122	26266	Business	186200.00
0005432657507	26266	Economy	68300.00
0005433785797	26266	Economy	68300.00
0005433763549	26266	Economy	68300.00
0005433785759	26266	Economy	62100.00
0005433763513	26266	Economy	62100.00
0005433785668	26266	Economy	62100.00
0005433806080	26266	Economy	62100.00
0005433785704	26266	Economy	62100.00
0005433806165	26266	Economy	62100.00
0005433785727	26266	Economy	62100.00
0005433785575	26266	Economy	62100.00
0005433806195	26266	Economy	62100.00
0005433785642	26266	Economy	62100.00
0005433763537	26266	Economy	62100.00
0005433806054	26266	Economy	62100.00
0005433785687	26266	Economy	62100.00
0005433806081	26266	Economy	62100.00
0005433806035	26266	Economy	62100.00
0005433785665	26266	Economy	62100.00
0005433785913	26266	Economy	62100.00
0005435858738	26266	Economy	62100.00
0005433806140	26266	Economy	62100.00
0005433806219	26266	Economy	62100.00
0005433785686	26266	Economy	62100.00
0005433785758	26266	Economy	62100.00
0005433806225	26266	Economy	62100.00
0005433806176	26266	Economy	62100.00
0005433806036	26266	Economy	62100.00
0005433805964	26266	Economy	62100.00
0005433785802	26266	Economy	62100.00
0005435270194	26266	Economy	62100.00
0005433785667	26266	Economy	62100.00
0005433806102	26266	Economy	62100.00
0005433763546	26266	Economy	62100.00
0005433806146	26266	Economy	62100.00
0005433785777	26266	Economy	62100.00
0005433785733	26266	Economy	62100.00
0005433806141	26266	Economy	62100.00
0005433785600	26266	Economy	62100.00
0005434151791	26266	Economy	62100.00
0005434271373	26266	Economy	62100.00
0005435270201	26266	Economy	62100.00
0005435858734	26266	Economy	62100.00
0005435270198	26266	Economy	62100.00
0005433763584	26266	Economy	62100.00
0005435270204	26266	Economy	62100.00
0005433785762	26266	Economy	62100.00
0005433806121	26266	Economy	62100.00
0005434171465	26266	Economy	62100.00
0005433785780	26266	Economy	62100.00
0005435270191	26266	Economy	62100.00
0005435858730	26266	Economy	62100.00
0005434171464	26266	Economy	62100.00
0005433806273	26266	Economy	62100.00
0005433785693	26266	Economy	62100.00
0005433763498	26266	Economy	62100.00
0005433806131	26266	Economy	62100.00
0005433806014	26266	Economy	62100.00
0005433785788	26266	Economy	62100.00
0005435270185	26266	Economy	62100.00
0005434271374	26266	Economy	62100.00
0005432657508	26266	Economy	62100.00
0005435858731	26266	Economy	62100.00
0005433806177	26266	Economy	62100.00
0005434269163	26266	Economy	62100.00
0005435270190	26266	Economy	62100.00
0005433785729	26266	Economy	62100.00
0005433806142	26266	Economy	62100.00
0005433806058	26266	Economy	62100.00
0005435270196	26266	Economy	62100.00
0005433806204	26266	Economy	62100.00
0005433806196	26266	Economy	62100.00
0005435270189	26266	Economy	62100.00
0005433806147	26266	Economy	62100.00
0005433806015	26266	Economy	62100.00
0005433785771	26266	Economy	62100.00
0005433806317	26266	Economy	62100.00
0005435270195	26266	Economy	62100.00
0005433806095	26266	Economy	68300.00
0005435270197	26266	Economy	62100.00
0005433806220	26266	Economy	68300.00
0005433763544	26266	Economy	62100.00
0005433785680	26266	Economy	62100.00
0005433806132	26266	Economy	62100.00
0005433806111	26266	Economy	62100.00
0005433763534	26266	Economy	62100.00
0005433806096	26266	Economy	62100.00
0005435858740	26266	Economy	62100.00
0005433806037	26266	Economy	62100.00
0005433785641	26266	Economy	62100.00
0005435270182	26266	Economy	62100.00
0005433785799	26266	Economy	62100.00
0005433785728	26266	Economy	62100.00
0005433806230	26266	Economy	62100.00
0005435270202	26266	Economy	62100.00
0005433763548	26266	Economy	62100.00
0005435858735	26266	Economy	62100.00
0005432663075	26266	Economy	62100.00
0005433785779	26266	Economy	62100.00
0005435270200	26266	Economy	62100.00
0005433806059	26266	Economy	62100.00
0005433763583	26266	Economy	62100.00
0005432659756	26266	Economy	62100.00
0005433785555	26266	Economy	62100.00
0005432663082	26266	Economy	62100.00
0005433785801	26266	Economy	62100.00
0005433806168	26266	Economy	62100.00
0005433806130	26266	Economy	62100.00
0005433785737	26266	Economy	62100.00
0005432659755	26266	Economy	62100.00
0005433806169	26266	Economy	62100.00
0005433785778	26266	Economy	62100.00
0005435270203	26266	Economy	62100.00
0005433785765	26266	Economy	62100.00
0005432659748	26266	Economy	62100.00
0005433763545	26266	Economy	62100.00
0005433785757	26266	Economy	62100.00
0005435270188	26266	Economy	62100.00
0005433785666	26266	Economy	62100.00
0005434151792	26266	Economy	62100.00
0005435270187	26266	Economy	62100.00
0005435270193	26266	Economy	62100.00
0005433806173	26266	Economy	62100.00
0005435858732	26266	Economy	62100.00
0005433806272	26266	Economy	62100.00
0005433785734	26266	Economy	62100.00
0005435858737	26266	Economy	62100.00
0005433785783	26266	Economy	62100.00
0005433763497	26266	Economy	62100.00
0005433785574	26266	Economy	62100.00
0005433763528	26266	Economy	62100.00
0005435270184	26266	Economy	62100.00
0005433785743	26266	Economy	62100.00
0005432657502	26266	Economy	62100.00
0005435858739	26266	Economy	62100.00
0005435135805	4926	Economy	5900.00
0005435135804	4926	Economy	5900.00
0005435929708	4926	Economy	5300.00
0005435135806	4926	Economy	5300.00
0005435135791	33018	Economy	5300.00
0005435135768	33018	Economy	5300.00
0005434218065	9510	Economy	17900.00
0005434218091	27348	Economy	19700.00
0005434983418	27348	Economy	17900.00
0005434218088	27348	Economy	17900.00
0005434218090	27348	Economy	17900.00
0005434218089	27348	Economy	17900.00
0005433962014	24275	Business	36400.00
0005433961964	24275	Business	36400.00
0005433987006	24275	Business	36400.00
0005433961796	24275	Business	36400.00
0005433962065	24275	Business	36400.00
0005433986931	24275	Business	36400.00
0005433986819	24275	Business	36400.00
0005433986713	24275	Business	36400.00
0005433961908	24275	Business	36400.00
0005433987083	24275	Business	36400.00
0005433987019	24275	Business	36400.00
0005433962095	24275	Business	36400.00
0005433987010	24275	Business	36400.00
0005433962073	24275	Business	36400.00
0005433962032	24275	Business	36400.00
0005433987052	24275	Business	36400.00
0005433962056	24275	Business	36400.00
0005433986951	24275	Business	36400.00
0005433962003	24275	Economy	13400.00
0005433986873	24275	Economy	13400.00
0005433962057	24275	Economy	12100.00
0005433962002	24275	Economy	12100.00
0005433962074	24275	Economy	12100.00
0005433986849	24275	Economy	12100.00
0005433961983	24275	Economy	12100.00
0005433961910	24275	Economy	12100.00
0005433961783	24275	Economy	12100.00
0005433962071	24275	Economy	12100.00
0005433961820	24275	Economy	12100.00
0005433986876	24275	Economy	12100.00
0005433962040	24275	Economy	12100.00
0005433987025	24275	Economy	12100.00
0005433961795	24275	Economy	12100.00
0005433986968	24275	Economy	12100.00
0005433961886	24275	Economy	12100.00
0005433987072	24275	Economy	12100.00
0005433961909	24275	Economy	12100.00
0005433986712	24275	Economy	12100.00
0005433961819	24275	Economy	12100.00
0005433961821	24275	Economy	12100.00
0005433986970	24275	Economy	12100.00
0005433961987	24275	Economy	12100.00
0005433961889	24275	Economy	12100.00
0005433961859	24275	Economy	12100.00
0005433961982	24275	Economy	12100.00
0005433986867	24275	Economy	12100.00
0005433962083	24275	Economy	12100.00
0005433962023	24275	Economy	12100.00
0005433962022	24275	Economy	12100.00
0005433962068	24275	Economy	12100.00
0005433962055	24275	Economy	12100.00
0005433986823	24275	Economy	12100.00
0005433986986	24275	Economy	12100.00
0005433986975	24275	Economy	12100.00
0005433986909	24275	Economy	12100.00
0005433961960	24275	Economy	12100.00
0005433961848	24275	Economy	12100.00
0005433962070	24275	Economy	12100.00
0005433962054	24275	Economy	12100.00
0005433986964	24275	Economy	12100.00
0005433986908	24275	Economy	12100.00
0005433987037	24275	Economy	12100.00
0005433961887	24275	Economy	12100.00
0005433986817	24275	Economy	12100.00
0005433961869	24275	Economy	12100.00
0005433961868	24275	Economy	12100.00
0005433986822	24275	Economy	12100.00
0005433961888	24275	Economy	12100.00
0005433987030	24275	Economy	12100.00
0005433986969	24275	Economy	12100.00
0005433987026	24275	Economy	12100.00
0005433986863	24275	Economy	12100.00
0005433986963	24275	Economy	12100.00
0005433987020	24275	Economy	13400.00
0005433961933	24275	Economy	13400.00
0005433987024	24275	Economy	12100.00
0005433962047	24275	Economy	12100.00
0005433962044	24275	Economy	12100.00
0005433962085	24275	Economy	12100.00
0005433986870	24275	Economy	12100.00
0005433961961	24275	Economy	12100.00
0005433961942	24275	Economy	12100.00
0005433986946	24275	Economy	12100.00
0005433986989	24275	Economy	12100.00
0005433961828	24275	Economy	12100.00
0005433961890	24275	Economy	12100.00
0005433961920	24275	Economy	12100.00
0005433961857	24275	Economy	12100.00
0005433962004	24275	Economy	12100.00
0005433962072	24275	Economy	12100.00
0005433961984	24275	Economy	12100.00
0005433987053	24275	Economy	12100.00
0005433986888	24275	Economy	12100.00
0005433962035	24275	Economy	12100.00
0005433961921	24275	Economy	12100.00
0005433987018	24275	Economy	12100.00
0005433961847	24275	Economy	12100.00
0005433962066	24275	Economy	12100.00
0005433962033	24275	Economy	12100.00
0005433986965	24275	Economy	12100.00
0005433987029	24275	Economy	12100.00
0005433962084	24275	Economy	12100.00
0005433986966	24275	Economy	12100.00
0005433961858	24275	Economy	12100.00
0005433961913	24275	Economy	12100.00
0005433986948	24275	Economy	12100.00
0005433986768	24275	Economy	12100.00
0005433986945	24275	Economy	12100.00
0005433961911	24275	Economy	12100.00
0005433987040	24275	Economy	12100.00
0005433986976	24275	Economy	12100.00
0005433961922	24275	Economy	12100.00
0005433986818	24275	Economy	12100.00
0005433987007	24275	Economy	12100.00
0005433961941	24275	Economy	12100.00
0005433962096	24275	Economy	12100.00
0005433987036	24275	Economy	12100.00
0005433961856	24275	Economy	12100.00
0005433962036	24275	Economy	12100.00
0005433986767	24275	Economy	12100.00
0005433961912	24275	Economy	12100.00
0005433987060	24275	Economy	12100.00
0005433986824	24275	Economy	12100.00
0005433987347	25939	Business	36400.00
0005433962632	25939	Business	36400.00
0005433962623	25939	Business	36400.00
0005433987341	25939	Business	36400.00
0005433987336	25939	Business	36400.00
0005433962613	25939	Business	36400.00
0005433962622	25939	Business	36400.00
0005433962595	25939	Business	36400.00
0005433962657	25939	Business	36400.00
0005433962651	25939	Business	36400.00
0005433962628	25939	Business	36400.00
0005433962631	25939	Business	36400.00
0005433987326	25939	Business	36400.00
0005433962620	25939	Business	36400.00
0005433962627	25939	Business	36400.00
0005433962615	25939	Business	36400.00
0005433962619	25939	Business	36400.00
0005433962652	25939	Business	36400.00
0005433962604	25939	Business	36400.00
0005433962617	25939	Economy	13400.00
0005433962614	25939	Business	36400.00
0005433962650	25939	Economy	13400.00
0005433987338	25939	Economy	12100.00
0005433962610	25939	Economy	12100.00
0005433962600	25939	Economy	12100.00
0005433962641	25939	Economy	12100.00
0005433962621	25939	Economy	12100.00
0005433962645	25939	Economy	12100.00
0005433962630	25939	Economy	12100.00
0005433962649	25939	Economy	12100.00
0005433962642	25939	Economy	12100.00
0005433962606	25939	Economy	12100.00
0005433962654	25939	Economy	12100.00
0005433962626	25939	Economy	12100.00
0005433962596	25939	Economy	12100.00
0005433962643	25939	Economy	12100.00
0005433987320	25939	Economy	12100.00
0005433987318	25939	Economy	12100.00
0005433962593	25939	Economy	12100.00
0005433962608	25939	Economy	12100.00
0005433987331	25939	Economy	12100.00
0005433962647	25939	Economy	12100.00
0005433962629	25939	Economy	12100.00
0005433987346	25939	Economy	12100.00
0005433962611	25939	Economy	12100.00
0005433962659	25939	Economy	12100.00
0005433962592	25939	Economy	12100.00
0005433987348	25939	Economy	12100.00
0005433987330	25939	Economy	12100.00
0005433962594	25939	Economy	12100.00
0005433962639	25939	Economy	12100.00
0005433987324	25939	Economy	12100.00
0005433962637	25939	Economy	12100.00
0005433987321	25939	Economy	12100.00
0005433987329	25939	Economy	12100.00
0005433987316	25939	Economy	12100.00
0005433962638	25939	Economy	12100.00
0005433962644	25939	Economy	12100.00
0005433987315	25939	Economy	12100.00
0005433987322	25939	Economy	12100.00
0005433987325	25939	Economy	12100.00
0005433962603	25939	Economy	12100.00
0005433987350	25939	Economy	12100.00
0005433987349	25939	Economy	12100.00
0005433987319	25939	Economy	12100.00
0005433987332	25939	Economy	12100.00
0005433987342	25939	Economy	12100.00
0005433987317	25939	Economy	12100.00
0005433962624	25939	Economy	12100.00
0005433962656	25939	Economy	12100.00
0005433987334	25939	Economy	12100.00
0005433962607	25939	Economy	12100.00
0005433962625	25939	Economy	12100.00
0005433962636	25939	Economy	12100.00
0005433987337	25939	Economy	12100.00
0005433962635	25939	Economy	12100.00
0005433962602	25939	Economy	13400.00
0005433987335	25939	Economy	12100.00
0005433962598	25939	Economy	12100.00
0005433987327	25939	Economy	12100.00
0005433962634	25939	Economy	12100.00
0005433987344	25939	Economy	12100.00
0005433987345	25939	Economy	12100.00
0005433962655	25939	Economy	12100.00
0005433987323	25939	Economy	12100.00
0005433962618	25939	Economy	12100.00
0005433987333	25939	Economy	12100.00
0005433962599	25939	Economy	12100.00
0005433987343	25939	Economy	12100.00
0005433962597	25939	Economy	12100.00
0005433962616	25939	Economy	12100.00
0005433962633	25939	Economy	12100.00
0005433962601	25939	Economy	12100.00
0005433962640	25939	Economy	12100.00
0005433962653	25939	Economy	12100.00
0005433962646	25939	Economy	12100.00
0005433962612	25939	Economy	12100.00
0005433962609	25939	Economy	12100.00
0005433987340	25939	Economy	12100.00
0005433987339	25939	Economy	12100.00
0005433962658	25939	Economy	12100.00
0005433962591	25939	Economy	12100.00
0005433962605	25939	Economy	12100.00
0005433962648	25939	Economy	12100.00
0005433987328	25939	Economy	12100.00
0005434481033	933	Economy	25400.00
0005433166196	933	Economy	23100.00
0005434481040	933	Economy	23100.00
0005434481036	933	Economy	23100.00
0005433166230	933	Economy	23100.00
0005433166248	933	Economy	23100.00
0005433166223	933	Economy	23100.00
0005434481035	933	Economy	23100.00
0005432269576	933	Economy	23100.00
0005433166222	933	Economy	23100.00
0005434481037	933	Economy	23100.00
0005433166229	933	Economy	23100.00
0005434481032	933	Economy	23100.00
0005433166195	933	Economy	23100.00
0005433166250	933	Economy	23100.00
0005434481034	933	Economy	23100.00
0005434481039	933	Economy	23100.00
0005433166251	933	Economy	23100.00
0005434481038	933	Economy	23100.00
0005433166224	933	Economy	23100.00
0005434481041	933	Economy	23100.00
0005433166140	933	Economy	23100.00
0005434480863	16591	Economy	25400.00
0005434480810	16591	Economy	25400.00
0005434480874	16591	Economy	25400.00
0005434480891	16591	Economy	23100.00
0005434480928	16591	Economy	23100.00
0005434480940	16591	Economy	23100.00
0005434480827	16591	Economy	23100.00
0005434480871	16591	Economy	23100.00
0005434480866	16591	Economy	23100.00
0005434480876	16591	Economy	23100.00
0005434480828	16591	Economy	23100.00
0005434480882	16591	Economy	23100.00
0005434480867	16591	Economy	23100.00
0005434480939	16591	Economy	23100.00
0005433166282	16591	Economy	23100.00
0005434480875	16591	Economy	23100.00
0005434480837	16591	Economy	23100.00
0005433166280	16591	Economy	23100.00
0005434480791	16591	Economy	23100.00
0005434480902	16591	Economy	23100.00
0005434480892	16591	Economy	23100.00
0005434480825	16591	Economy	23100.00
0005434480877	16591	Economy	23100.00
0005433166281	16591	Economy	23100.00
0005433290005	10362	Economy	17000.00
0005435386724	10362	Economy	17000.00
0005435386687	10362	Economy	17000.00
0005433290024	10362	Economy	17000.00
0005435142952	10362	Economy	15400.00
0005435386719	10362	Economy	15400.00
0005435150429	10362	Economy	15400.00
0005435386691	10362	Economy	15400.00
0005433289983	10362	Economy	15400.00
0005433289988	10362	Economy	15400.00
0005433289955	10362	Economy	15400.00
0005433290014	10362	Economy	15400.00
0005435386723	10362	Economy	15400.00
0005433289995	10362	Economy	15400.00
0005435386734	10362	Economy	15400.00
0005435386673	10362	Economy	15400.00
0005435150428	10362	Economy	15400.00
0005435386733	10362	Economy	15400.00
0005435142954	10362	Economy	15400.00
0005435150427	10362	Economy	15400.00
0005433289968	10362	Economy	15400.00
0005435150430	10362	Economy	15400.00
0005435142953	10362	Economy	15400.00
0005435386672	10362	Economy	15400.00
0005435142955	10362	Economy	15400.00
0005433289954	10362	Economy	15400.00
0005433289984	10362	Economy	15400.00
0005433289989	10362	Economy	15400.00
0005433290004	10362	Economy	15400.00
0005433289969	10362	Economy	15400.00
0005435150252	21911	Economy	17000.00
0005435150251	21911	Economy	15400.00
0005435150341	21911	Economy	15400.00
0005435150339	21911	Economy	15400.00
0005435150281	21911	Economy	15400.00
0005435150317	21911	Economy	15400.00
0005435142913	21911	Economy	15400.00
0005435150293	21911	Economy	15400.00
0005435150351	21911	Economy	15400.00
0005435150312	21911	Economy	15400.00
0005435150314	21911	Economy	15400.00
0005435150304	21911	Economy	15400.00
0005435150336	21911	Economy	15400.00
0005433290063	21911	Economy	15400.00
0005435150332	21911	Economy	15400.00
0005435150337	21911	Economy	15400.00
0005435386760	21911	Economy	15400.00
0005435150295	21911	Economy	15400.00
0005435142911	21911	Economy	15400.00
0005435150350	21911	Economy	15400.00
0005435142875	21911	Economy	15400.00
0005435386762	21911	Economy	15400.00
0005435150315	21911	Economy	15400.00
0005435150361	21911	Economy	15400.00
0005435386761	21911	Economy	15400.00
0005435150340	21911	Economy	15400.00
0005435386758	21911	Economy	15400.00
0005435142838	21911	Economy	15400.00
0005435142834	21911	Economy	15400.00
0005435150305	21911	Economy	15400.00
0005435142912	21911	Economy	15400.00
0005435386759	21911	Economy	15400.00
0005435150352	21911	Economy	15400.00
0005433290064	21911	Economy	15400.00
0005435150338	21911	Economy	15400.00
0005433290062	21911	Economy	15400.00
0005435545911	11196	Business	57200.00
0005435319725	11196	Business	57200.00
0005435529657	11196	Business	57200.00
0005435529699	11196	Business	57200.00
0005435502760	11196	Business	57200.00
0005435502814	11196	Business	57200.00
0005435529730	11196	Business	57200.00
0005435319789	11196	Business	57200.00
0005435502892	11196	Business	57200.00
0005435529729	11196	Business	57200.00
0005435502815	11196	Economy	19100.00
0005435529749	11196	Economy	19100.00
0005435529685	11196	Economy	19100.00
0005435529812	11196	Economy	19100.00
0005435502838	11196	Economy	19100.00
0005435529696	11196	Economy	19100.00
0005435529702	11196	Economy	21000.00
0005434573758	11196	Economy	19100.00
0005435502893	11196	Economy	21000.00
0005435529666	11196	Economy	21000.00
0005435319786	11196	Economy	21000.00
0005435502789	11196	Economy	21000.00
0005435502849	11196	Economy	19100.00
0005434573756	11196	Economy	19100.00
0005435502792	11196	Economy	19100.00
0005435502830	11196	Economy	19100.00
0005435529764	11196	Economy	19100.00
0005435502837	11196	Economy	19100.00
0005435529715	11196	Economy	19100.00
0005435319790	11196	Economy	19100.00
0005435502839	11196	Economy	19100.00
0005435502734	11196	Economy	19100.00
0005435529724	11196	Economy	19100.00
0005435529656	11196	Economy	19100.00
0005434573754	11196	Economy	19100.00
0005434573753	11196	Economy	19100.00
0005435545929	11196	Economy	19100.00
0005435319764	11196	Economy	19100.00
0005435502743	11196	Economy	19100.00
0005435319798	11196	Economy	19100.00
0005435529723	11196	Economy	19100.00
0005435545910	11196	Economy	19100.00
0005435502807	11196	Economy	19100.00
0005435502827	11196	Economy	19100.00
0005435319779	11196	Economy	19100.00
0005435319745	11196	Economy	19100.00
0005435529716	11196	Economy	19100.00
0005435502862	11196	Economy	19100.00
0005435529694	11196	Economy	19100.00
0005435502794	11196	Economy	19100.00
0005435529642	11196	Economy	19100.00
0005435529684	11196	Economy	19100.00
0005435529693	11196	Economy	19100.00
0005435545884	11196	Economy	19100.00
0005435545909	11196	Economy	19100.00
0005435502718	11196	Economy	19100.00
0005434573759	11196	Economy	19100.00
0005435502842	11196	Economy	19100.00
0005435545877	11196	Economy	19100.00
0005435502782	11196	Economy	19100.00
0005435502833	11196	Economy	19100.00
0005435319763	11196	Economy	19100.00
0005435529756	11196	Economy	19100.00
0005435502785	11196	Economy	19100.00
0005435319770	11196	Economy	19100.00
0005435319780	11196	Economy	19100.00
0005435529686	11196	Economy	19100.00
0005435502828	11196	Economy	19100.00
0005435319754	11196	Economy	19100.00
0005434573760	11196	Economy	19100.00
0005434573757	11196	Economy	19100.00
0005435502894	11196	Economy	19100.00
0005434573761	11196	Economy	19100.00
0005434573755	11196	Economy	19100.00
0005435502816	11196	Economy	19100.00
0005435502941	20923	Business	57200.00
0005435518438	20923	Business	57200.00
0005434573621	20923	Business	57200.00
0005435518442	20923	Business	57200.00
0005434573661	20923	Business	57200.00
0005435518444	20923	Business	57200.00
0005434573662	20923	Economy	19100.00
0005435319825	20923	Economy	19100.00
0005435518443	20923	Economy	19100.00
0005432292001	20923	Economy	19100.00
0005435518440	20923	Economy	19100.00
0005432292002	20923	Economy	21000.00
0005435508809	20923	Economy	21000.00
0005435508810	20923	Economy	19100.00
0005432291999	20923	Economy	19100.00
0005435502940	20923	Economy	19100.00
0005435502939	20923	Economy	19100.00
0005435508805	20923	Economy	19100.00
0005435508808	20923	Economy	19100.00
0005435508806	20923	Economy	19100.00
0005435502937	20923	Economy	19100.00
0005435319826	20923	Economy	19100.00
0005434573620	20923	Economy	19100.00
0005435518436	20923	Economy	19100.00
0005434573611	20923	Economy	19100.00
0005435502944	20923	Economy	19100.00
0005435502946	20923	Economy	19100.00
0005435502943	20923	Economy	19100.00
0005435508807	20923	Economy	19100.00
0005435508811	20923	Economy	19100.00
0005435508804	20923	Economy	19100.00
0005434573659	20923	Economy	19100.00
0005435518437	20923	Economy	19100.00
0005434573573	20923	Economy	19100.00
0005435518441	20923	Economy	19100.00
0005435502938	20923	Economy	19100.00
0005435319827	20923	Economy	19100.00
0005435508813	20923	Economy	19100.00
0005435518439	20923	Economy	19100.00
0005432292000	20923	Economy	19100.00
0005435502942	20923	Economy	19100.00
0005434573660	20923	Economy	19100.00
0005434573619	20923	Economy	19100.00
0005435502945	20923	Economy	19100.00
0005435508812	20923	Economy	19100.00
0005432693844	2946	Business	10300.00
0005432693633	2946	Business	10300.00
0005432693723	2946	Economy	3400.00
0005432693685	2946	Economy	3400.00
0005432693597	2946	Economy	3800.00
0005432693755	2946	Economy	3400.00
0005432693744	2946	Economy	3400.00
0005432693845	2946	Economy	3400.00
0005432693689	2946	Economy	3400.00
0005432693690	2946	Economy	3400.00
0005432693634	2946	Economy	3400.00
0005432693793	2946	Economy	3400.00
0005432693682	2946	Economy	3400.00
0005432693758	2946	Economy	3400.00
0005432693805	2946	Economy	3400.00
0005432693792	2946	Economy	3400.00
0005432693721	2946	Economy	3400.00
0005432693681	2946	Economy	3400.00
0005433124395	2944	Business	10300.00
0005432707505	2944	Business	10300.00
0005433124403	2944	Business	10300.00
0005432881133	2944	Business	10300.00
0005432881185	2944	Business	10300.00
0005432881089	2944	Business	10300.00
0005434310157	2944	Economy	3400.00
0005432707503	2944	Economy	3400.00
0005434310162	2944	Economy	3400.00
0005433124379	2944	Economy	3400.00
0005433124333	2944	Economy	3400.00
0005432881164	2944	Economy	3800.00
0005432707501	2944	Economy	3800.00
0005433194919	2944	Economy	3800.00
0005432881139	2944	Economy	3400.00
0005432881175	2944	Economy	3400.00
0005433124462	2944	Economy	3400.00
0005434310158	2944	Economy	3400.00
0005432881183	2944	Economy	3400.00
0005433124351	2944	Economy	3400.00
0005433124315	2944	Economy	3400.00
0005432881134	2944	Economy	3400.00
0005433124314	2944	Economy	3400.00
0005433124348	2944	Economy	3400.00
0005433194915	2944	Economy	3400.00
0005433124349	2944	Economy	3400.00
0005432707502	2944	Economy	3400.00
0005432881132	2944	Economy	3400.00
0005433194928	2944	Economy	3400.00
0005433194926	2944	Economy	3400.00
0005432707504	2944	Economy	3400.00
0005432881184	2944	Economy	3400.00
0005434310155	2944	Economy	3400.00
0005432707506	2944	Economy	3400.00
0005434310163	2944	Economy	3400.00
0005434310164	2944	Economy	3400.00
0005434310160	2944	Economy	3400.00
0005433124424	2944	Economy	3400.00
0005434310156	2944	Economy	3400.00
0005433194920	2944	Economy	3400.00
0005432881163	2944	Economy	3400.00
0005434310161	2944	Economy	3400.00
0005432707500	2944	Economy	3400.00
0005433124402	2944	Economy	3400.00
0005434310159	2944	Economy	3400.00
0005433124350	2944	Economy	3400.00
0005433124396	2944	Economy	3400.00
0005432707499	2944	Economy	3400.00
0005433124368	2944	Economy	3400.00
0005433194992	30054	Business	10300.00
0005432707340	30054	Business	10300.00
0005432707348	30054	Business	10300.00
0005434300257	30054	Business	10300.00
0005432707413	30054	Business	10300.00
0005433194994	30054	Business	10300.00
0005432707359	30054	Economy	3400.00
0005433194993	30054	Economy	3400.00
0005432693958	30054	Economy	3400.00
0005432707344	30054	Economy	3400.00
0005432707414	30054	Economy	3400.00
0005432707204	30054	Economy	3800.00
0005434300252	30054	Economy	3800.00
0005432881238	30054	Economy	3800.00
0005434300259	30054	Economy	3400.00
0005432707424	30054	Economy	3400.00
0005434300256	30054	Economy	3400.00
0005433124528	30054	Economy	3400.00
0005434300255	30054	Economy	3400.00
0005432881242	30054	Economy	3400.00
0005432707415	30054	Economy	3400.00
0005434300258	30054	Economy	3400.00
0005432693959	30054	Economy	3400.00
0005433124524	30054	Economy	3400.00
0005433124525	30054	Economy	3400.00
0005432693960	30054	Economy	3400.00
0005433124527	30054	Economy	3400.00
0005432707279	30054	Economy	3400.00
0005434300253	30054	Economy	3400.00
0005433194997	30054	Economy	3400.00
0005432707345	30054	Economy	3400.00
0005432881237	30054	Economy	3400.00
0005434300251	30054	Economy	3400.00
0005432707343	30054	Economy	3400.00
0005433194995	30054	Economy	3400.00
0005433194991	30054	Economy	3400.00
0005433124523	30054	Economy	3400.00
0005432707363	30054	Economy	3400.00
0005432707329	30054	Economy	3400.00
0005432707420	30054	Economy	3400.00
0005432707425	30054	Economy	3400.00
0005432881241	30054	Economy	3400.00
0005433124530	30054	Economy	3400.00
0005434300254	30054	Economy	3400.00
0005432707373	30054	Economy	3400.00
0005433194998	30054	Economy	3400.00
0005432707295	30054	Economy	3400.00
0005433124526	30054	Economy	3400.00
0005432707319	30054	Economy	3400.00
0005433194996	30054	Economy	3400.00
0005432881239	30054	Economy	3400.00
0005433124529	30054	Economy	3400.00
0005432693957	30054	Economy	3400.00
0005432707346	30054	Economy	3400.00
0005432881240	30054	Economy	3400.00
0005434980647	23680	Economy	4000.00
0005434989078	23680	Economy	4000.00
0005434980646	23680	Economy	4000.00
0005434980643	23680	Economy	3600.00
0005434980637	23680	Economy	3600.00
0005434989098	23680	Economy	3600.00
0005434989097	23680	Economy	3600.00
0005434989092	23680	Economy	3600.00
0005434989082	23680	Economy	3600.00
0005434989088	23680	Economy	3600.00
0005434989089	23680	Economy	3600.00
0005434989090	23680	Economy	3600.00
0005434989086	23680	Economy	3600.00
0005434980636	23680	Economy	3600.00
0005434989083	23680	Economy	3600.00
0005434989081	23680	Economy	3600.00
0005434989093	23680	Economy	3600.00
0005434980653	23680	Economy	3600.00
0005434989084	23680	Economy	3600.00
0005434989080	23680	Economy	3600.00
0005434980640	23680	Economy	3600.00
0005434989087	23680	Economy	3600.00
0005434980650	23680	Economy	3600.00
0005434980651	23680	Economy	3600.00
0005434980648	23680	Economy	3600.00
0005434989091	23680	Economy	3600.00
0005434980652	23680	Economy	3600.00
0005434980639	23680	Economy	3600.00
0005434980642	23680	Economy	3600.00
0005434989096	23680	Economy	3600.00
0005434980654	23680	Economy	3600.00
0005434989095	23680	Economy	3600.00
0005434989085	23680	Economy	3600.00
0005434980645	23680	Economy	3600.00
0005434980644	23680	Economy	3600.00
0005434980641	23680	Economy	3600.00
0005434989094	23680	Economy	3600.00
0005434980638	23680	Economy	3600.00
0005434980649	23680	Economy	3600.00
0005434989079	23680	Economy	3600.00
0005434980381	27519	Economy	4000.00
0005434980489	27519	Economy	4000.00
0005434988947	27519	Economy	4000.00
0005434980338	27519	Economy	4000.00
0005434980463	27519	Economy	3600.00
0005434988952	27519	Economy	3600.00
0005434988946	27519	Economy	3600.00
0005434988957	27519	Economy	3600.00
0005434980526	27519	Economy	3600.00
0005434988940	27519	Economy	3600.00
0005434980527	27519	Economy	3600.00
0005434988950	27519	Economy	3600.00
0005434988959	27519	Economy	3600.00
0005434980544	27519	Economy	3600.00
0005434980421	27519	Economy	3600.00
0005434980453	27519	Economy	3600.00
0005434988932	27519	Economy	3600.00
0005434980380	27519	Economy	3600.00
0005434988965	27519	Economy	3600.00
0005434980426	27519	Economy	3600.00
0005434988973	27519	Economy	3600.00
0005434980339	27519	Economy	3600.00
0005434988930	27519	Economy	3600.00
0005434988931	27519	Economy	3600.00
0005434980483	27519	Economy	3600.00
0005434988958	27519	Economy	3600.00
0005434980422	27519	Economy	3600.00
0005434980487	27519	Economy	3600.00
0005434980476	27519	Economy	3600.00
0005434988967	27519	Economy	3600.00
0005434988912	27519	Economy	3600.00
0005434980455	27519	Economy	3600.00
0005434980391	27519	Economy	3600.00
0005434980406	27519	Economy	3600.00
0005434980534	27519	Economy	3600.00
0005434980454	27519	Economy	3600.00
0005434980501	27519	Economy	3600.00
0005434980461	27519	Economy	3600.00
0005434980462	27519	Economy	3600.00
0005433111538	10281	Economy	21600.00
0005434302908	10281	Economy	19700.00
0005433111537	10281	Economy	19700.00
0005434302579	10281	Economy	19700.00
0005434302907	10281	Economy	19700.00
0005433113579	10281	Economy	19700.00
0005434302909	10281	Economy	19700.00
0005433111544	10281	Economy	19700.00
0005433113581	10281	Economy	19700.00
0005433111536	10281	Economy	19700.00
0005434302906	10281	Economy	19700.00
0005434302557	19642	Economy	19700.00
0005433113598	19642	Economy	19700.00
0005434302529	19642	Economy	19700.00
0005434302530	19642	Economy	19700.00
0005434302559	19642	Economy	19700.00
0005434302537	19642	Economy	19700.00
0005434302558	19642	Economy	19700.00
0005435950337	3539	Business	26900.00
0005435925578	3539	Business	26900.00
0005435925625	3539	Business	26900.00
0005435950334	3539	Economy	9000.00
0005435070545	3539	Economy	9000.00
0005435719122	3539	Economy	9000.00
0005435070543	3539	Economy	9000.00
0005435070542	3539	Economy	9000.00
0005435070549	3539	Economy	9000.00
0005435925569	3539	Economy	9000.00
0005435939948	3539	Economy	9000.00
0005435719121	3539	Economy	9000.00
0005435925635	3539	Economy	9000.00
0005435925584	3539	Economy	9000.00
0005435070544	3539	Economy	9000.00
0005435925619	3539	Economy	9000.00
0005435925583	3539	Economy	9000.00
0005435939947	3539	Economy	9000.00
0005435070547	3539	Economy	9000.00
0005435925643	3539	Economy	9000.00
0005435950335	3539	Economy	9000.00
0005435925649	3539	Economy	9000.00
0005435950336	3539	Economy	9000.00
0005435925570	3539	Economy	9000.00
0005435070539	3539	Economy	9000.00
0005435925590	3539	Economy	9000.00
0005435070546	3539	Economy	9000.00
0005435925615	3539	Economy	9000.00
0005435925614	3539	Economy	9000.00
0005435925585	3539	Economy	9000.00
0005435950338	3539	Economy	9000.00
0005435925572	3539	Economy	9000.00
0005435925536	3539	Economy	9000.00
0005435070540	3539	Economy	9000.00
0005435719123	3539	Economy	9000.00
0005435070541	3539	Economy	9000.00
0005435070548	3539	Economy	9000.00
0005435070182	15314	Business	26900.00
0005435070031	15314	Business	26900.00
0005435070162	15314	Business	26900.00
0005435070416	15314	Business	26900.00
0005435070185	15314	Business	26900.00
0005435069981	15314	Business	26900.00
0005435070316	15314	Business	26900.00
0005435925709	15314	Business	26900.00
0005435070238	15314	Economy	9000.00
0005435070221	15314	Economy	9000.00
0005435070292	15314	Economy	9000.00
0005435925707	15314	Economy	9000.00
0005435070193	15314	Economy	9000.00
0005435070312	15314	Economy	9900.00
0005435069865	15314	Economy	9900.00
0005435070300	15314	Economy	9900.00
0005435070026	15314	Economy	9000.00
0005435925706	15314	Economy	9000.00
0005435939965	15314	Economy	9000.00
0005435070233	15314	Economy	9000.00
0005435070301	15314	Economy	9000.00
0005435070413	15314	Economy	9000.00
0005435925703	15314	Economy	9000.00
0005435069976	15314	Economy	9000.00
0005435070346	15314	Economy	9000.00
0005435070083	15314	Economy	9000.00
0005435925708	15314	Economy	9000.00
0005435070030	15314	Economy	9000.00
0005435069997	15314	Economy	9000.00
0005435070089	15314	Economy	9000.00
0005435070302	15314	Economy	9000.00
0005435070417	15314	Economy	9000.00
0005435925710	15314	Economy	9000.00
0005435070281	15314	Economy	9000.00
0005435939962	15314	Economy	9000.00
0005435070170	15314	Economy	9000.00
0005435070088	15314	Economy	9000.00
0005435070223	15314	Economy	9000.00
0005435925705	15314	Economy	9000.00
0005435070222	15314	Economy	9000.00
0005435925704	15314	Economy	9000.00
0005435070271	15314	Economy	9000.00
0005435070087	15314	Economy	9000.00
0005435070144	15314	Economy	9000.00
0005435939963	15314	Economy	9000.00
0005435070192	15314	Economy	9000.00
0005435070027	15314	Economy	9000.00
0005435939964	15314	Economy	9000.00
0005435070299	15314	Economy	9000.00
0005435939968	15314	Economy	9000.00
0005435070216	15314	Economy	9000.00
0005435070224	15314	Economy	9000.00
0005435069980	15314	Economy	9000.00
0005435939967	15314	Economy	9000.00
0005435939966	15314	Economy	9000.00
0005435070311	15314	Economy	9000.00
0005432658652	18198	Economy	5900.00
0005432660881	18198	Economy	5900.00
0005432660882	18198	Economy	5900.00
0005432660867	26410	Economy	5900.00
0005432664186	26410	Economy	5900.00
0005432660865	26410	Economy	5900.00
0005432667499	26410	Economy	5900.00
0005432667498	26410	Economy	5900.00
0005432664185	26410	Economy	5900.00
0005432660864	26410	Economy	5900.00
0005432660863	26410	Economy	5900.00
0005432664175	26410	Economy	5900.00
0005432660862	26410	Economy	5900.00
0005432920354	102	Business	20000.00
0005433103358	102	Business	20000.00
0005432920341	102	Business	20000.00
0005433103290	102	Business	20000.00
0005433103371	102	Business	20000.00
0005433103243	102	Business	20000.00
0005433103406	102	Business	20000.00
0005433103144	102	Business	20000.00
0005432920370	102	Business	20000.00
0005433103397	102	Business	20000.00
0005432920334	102	Business	20000.00
0005433103409	102	Business	20000.00
0005433103400	102	Business	20000.00
0005433103410	102	Business	20000.00
0005432920254	102	Business	20000.00
0005433103330	102	Business	20000.00
0005432920360	102	Business	20000.00
0005433103237	102	Economy	7300.00
0005433103348	102	Economy	7300.00
0005433103339	102	Economy	6700.00
0005433103231	102	Economy	6700.00
0005432901997	102	Economy	6700.00
0005433103306	102	Economy	6700.00
0005433103280	102	Economy	6700.00
0005432920281	102	Economy	6700.00
0005432902002	102	Economy	6700.00
0005433103255	102	Economy	6700.00
0005433103422	102	Economy	6700.00
0005432920277	102	Economy	6700.00
0005433103404	102	Economy	6700.00
0005433103232	102	Economy	6700.00
0005433103234	102	Economy	6700.00
0005432901975	102	Economy	6700.00
0005433103365	102	Economy	6700.00
0005433103386	102	Economy	6700.00
0005433103372	102	Economy	6700.00
0005432920365	102	Economy	6700.00
0005433103246	102	Economy	6700.00
0005432920280	102	Economy	6700.00
0005433103233	102	Economy	6700.00
0005433103359	102	Economy	6700.00
0005432902054	102	Economy	6700.00
0005433103364	102	Economy	6700.00
0005432920317	102	Economy	6700.00
0005433103325	102	Economy	6700.00
0005433103303	102	Economy	6700.00
0005433103431	102	Economy	6700.00
0005433103385	102	Economy	6700.00
0005433103340	102	Economy	6700.00
0005432920371	102	Economy	6700.00
0005432902038	102	Economy	7300.00
0005433103405	102	Economy	7300.00
0005432902009	102	Economy	7300.00
0005433103141	102	Economy	6700.00
0005432920350	102	Economy	6700.00
0005433103420	102	Economy	7300.00
0005433103227	102	Economy	6700.00
0005433103197	102	Economy	6700.00
0005433103394	102	Economy	6700.00
0005433103366	102	Economy	6700.00
0005432902007	102	Economy	6700.00
0005432920262	102	Economy	6700.00
0005432920372	102	Economy	6700.00
0005432902003	102	Economy	6700.00
0005432902010	102	Economy	6700.00
0005432677637	102	Economy	6700.00
0005433103434	102	Economy	6700.00
0005433103305	102	Economy	6700.00
0005433103253	102	Economy	6700.00
0005432920261	102	Economy	6700.00
0005433103423	102	Economy	6700.00
0005432920253	102	Economy	6700.00
0005432902008	102	Economy	6700.00
0005432902004	102	Economy	6700.00
0005433103311	102	Economy	6700.00
0005432902059	102	Economy	6700.00
0005433103222	102	Economy	6700.00
0005432920276	102	Economy	6700.00
0005432901974	102	Economy	6700.00
0005432902001	102	Economy	6700.00
0005432677638	102	Economy	6700.00
0005433103188	102	Economy	6700.00
0005432901973	102	Economy	6700.00
0005433103304	102	Economy	6700.00
0005433103432	102	Economy	6700.00
0005433103106	102	Economy	6700.00
0005433103369	102	Economy	6700.00
0005432677661	102	Economy	6700.00
0005432901968	102	Economy	6700.00
0005432920271	102	Economy	6700.00
0005432920279	102	Economy	6700.00
0005433103370	102	Economy	6700.00
0005433103196	102	Economy	6700.00
0005433103245	102	Economy	6700.00
0005433103291	102	Economy	6700.00
0005434157827	101	Business	20000.00
0005432263214	101	Business	20000.00
0005432818326	101	Business	20000.00
0005434157811	101	Business	20000.00
0005432818324	101	Business	20000.00
0005432263205	101	Business	20000.00
0005433690963	101	Business	20000.00
0005432263207	101	Business	20000.00
0005432753359	101	Business	20000.00
0005434157795	101	Business	20000.00
0005433690968	101	Business	20000.00
0005432263212	101	Business	20000.00
0005434157790	101	Business	20000.00
0005434157833	101	Business	20000.00
0005434157838	101	Business	20000.00
0005432756909	101	Economy	7300.00
0005433477282	101	Economy	6700.00
0005434157818	101	Economy	7300.00
0005434157823	101	Economy	6700.00
0005434157806	101	Economy	6700.00
0005433477275	101	Economy	6700.00
0005432818327	101	Economy	6700.00
0005432289083	101	Economy	6700.00
0005432263210	101	Economy	6700.00
0005434157822	101	Economy	6700.00
0005434157793	101	Economy	6700.00
0005432263219	101	Economy	6700.00
0005434157834	101	Economy	6700.00
0005434157840	101	Economy	6700.00
0005434157829	101	Economy	6700.00
0005434157842	101	Economy	6700.00
0005434157791	101	Economy	6700.00
0005434157825	101	Economy	6700.00
0005434157815	101	Economy	6700.00
0005434157805	101	Economy	6700.00
0005434157836	101	Economy	6700.00
0005432756914	101	Economy	6700.00
0005432756888	101	Economy	6700.00
0005433690962	101	Economy	6700.00
0005434157808	101	Economy	6700.00
0005433477283	101	Economy	6700.00
0005433477281	101	Economy	6700.00
0005434157809	101	Economy	6700.00
0005434157830	101	Economy	6700.00
0005434157792	101	Economy	6700.00
0005434157794	101	Economy	6700.00
0005434153583	101	Economy	6700.00
0005432263220	101	Economy	6700.00
0005434157839	101	Economy	6700.00
0005433477276	101	Economy	6700.00
0005432818321	101	Economy	6700.00
0005432818328	101	Economy	6700.00
0005434157799	101	Economy	6700.00
0005434157837	101	Economy	6700.00
0005434157798	101	Economy	6700.00
0005432753382	101	Economy	6700.00
0005432263208	101	Economy	6700.00
0005434157810	101	Economy	6700.00
0005434157812	101	Economy	6700.00
0005432289082	101	Economy	6700.00
0005432263216	101	Economy	6700.00
0005434157816	101	Economy	6700.00
0005432263209	101	Economy	6700.00
0005434157831	101	Economy	6700.00
0005434157821	101	Economy	6700.00
0005434157813	101	Economy	6700.00
0005434157814	101	Economy	7300.00
0005434157820	101	Economy	7300.00
0005434157828	101	Economy	7300.00
0005434157841	101	Economy	6700.00
0005433477280	101	Economy	6700.00
0005432818325	101	Economy	7300.00
0005434157819	101	Economy	6700.00
0005432207736	101	Economy	6700.00
0005434157796	101	Economy	6700.00
0005434153581	101	Economy	6700.00
0005434157804	101	Economy	6700.00
0005434157807	101	Economy	6700.00
0005432818323	101	Economy	6700.00
0005433477274	101	Economy	6700.00
0005434157824	101	Economy	6700.00
0005434157803	101	Economy	6700.00
0005433477279	101	Economy	6700.00
0005432207737	101	Economy	6700.00
0005432263213	101	Economy	6700.00
0005432263218	101	Economy	6700.00
0005432756910	101	Economy	6700.00
0005434157801	101	Economy	6700.00
0005434153582	101	Economy	6700.00
0005432263215	101	Economy	6700.00
0005434157826	101	Economy	6700.00
0005432756889	101	Economy	6700.00
0005432263221	101	Economy	6700.00
0005432263211	101	Economy	6700.00
0005433477278	101	Economy	6700.00
0005434157800	101	Economy	6700.00
0005434157817	101	Economy	6700.00
0005432263217	101	Economy	6700.00
0005433477277	101	Economy	6700.00
0005433690966	101	Economy	6700.00
0005434157835	101	Economy	6700.00
0005434157802	101	Economy	6700.00
0005434157797	101	Economy	6700.00
0005432818329	101	Economy	6700.00
0005433690964	101	Economy	6700.00
0005432818322	101	Economy	6700.00
0005432263206	101	Economy	6700.00
0005434157832	101	Economy	6700.00
0005432756908	101	Economy	6700.00
0005434152869	101	Economy	6700.00
0005432756900	101	Economy	6700.00
0005433103893	7982	Business	20000.00
0005433103858	7982	Business	20000.00
0005433476964	7982	Business	20000.00
0005433103853	7982	Business	20000.00
0005433103851	7982	Business	20000.00
0005433477073	7982	Business	20000.00
0005433103838	7982	Business	20000.00
0005432021032	7982	Business	20000.00
0005433103849	7982	Business	20000.00
0005433103850	7982	Business	20000.00
0005433477104	7982	Business	20000.00
0005433435518	7982	Business	20000.00
0005432021035	7982	Business	20000.00
0005433476961	7982	Business	20000.00
0005433103846	7982	Business	20000.00
0005433477090	7982	Business	20000.00
0005433476967	7982	Business	20000.00
0005433103834	7982	Business	20000.00
0005433476984	7982	Business	20000.00
0005433103897	7982	Business	20000.00
0005433477034	7982	Business	20000.00
0005433103836	7982	Business	20000.00
0005433103875	7982	Business	20000.00
0005432920465	7982	Business	20000.00
0005433103865	7982	Business	20000.00
0005433103904	7982	Business	20000.00
0005433103907	7982	Business	20000.00
0005433103872	7982	Business	20000.00
0005432920468	7982	Economy	7300.00
0005433103905	7982	Economy	7300.00
0005433476959	7982	Economy	7300.00
0005433435516	7982	Economy	7300.00
0005432045670	7982	Economy	7300.00
0005433477043	7982	Economy	6700.00
0005433477006	7982	Economy	7300.00
0005433103867	7982	Economy	6700.00
0005432920464	7982	Economy	6700.00
0005433103840	7982	Economy	6700.00
0005433103901	7982	Economy	6700.00
0005433103833	7982	Economy	6700.00
0005433103880	7982	Economy	6700.00
0005433103883	7982	Economy	6700.00
0005433435515	7982	Economy	6700.00
0005433477103	7982	Economy	6700.00
0005433477031	7982	Economy	6700.00
0005433103895	7982	Economy	6700.00
0005433103835	7982	Economy	6700.00
0005433103900	7982	Economy	6700.00
0005432021031	7982	Economy	6700.00
0005433103848	7982	Economy	6700.00
0005433103889	7982	Economy	6700.00
0005433477130	7982	Economy	6700.00
0005433103906	7982	Economy	6700.00
0005432751628	7982	Economy	6700.00
0005433929886	7982	Economy	6700.00
0005432021028	7982	Economy	6700.00
0005433103861	7982	Economy	6700.00
0005432021029	7982	Economy	6700.00
0005433477067	7982	Economy	6700.00
0005433103843	7982	Economy	6700.00
0005433435514	7982	Economy	6700.00
0005433103839	7982	Economy	6700.00
0005433103902	7982	Economy	6700.00
0005433476957	7982	Economy	6700.00
0005433103837	7982	Economy	6700.00
0005433103841	7982	Economy	6700.00
0005433476958	7982	Economy	6700.00
0005432920469	7982	Economy	6700.00
0005433103890	7982	Economy	6700.00
0005433103886	7982	Economy	6700.00
0005433103881	7982	Economy	6700.00
0005433103844	7982	Economy	6700.00
0005432753401	7982	Economy	6700.00
0005433477060	7982	Economy	6700.00
0005433477005	7982	Economy	6700.00
0005432021030	7982	Economy	6700.00
0005433477079	7982	Economy	6700.00
0005433477077	7982	Economy	6700.00
0005433103874	7982	Economy	6700.00
0005433477075	7982	Economy	6700.00
0005433103864	7982	Economy	6700.00
0005433103857	7982	Economy	6700.00
0005433103882	7982	Economy	6700.00
0005432044607	7982	Economy	6700.00
0005432677689	7982	Economy	6700.00
0005433103885	7982	Economy	6700.00
0005433103903	7982	Economy	6700.00
0005433103898	7982	Economy	6700.00
0005433103854	7982	Economy	6700.00
0005433476995	7982	Economy	6700.00
0005432920467	7982	Economy	7300.00
0005433435521	7982	Economy	7300.00
0005433103884	7982	Economy	7300.00
0005433435517	7982	Economy	7300.00
0005433103899	7982	Economy	6700.00
0005433476991	7982	Economy	7300.00
0005433103859	7982	Economy	6700.00
0005433103877	7982	Economy	6700.00
0005433103888	7982	Economy	6700.00
0005433477106	7982	Economy	6700.00
0005433477059	7982	Economy	7300.00
0005433103869	7982	Economy	6700.00
0005433477050	7982	Economy	6700.00
0005433476960	7982	Economy	6700.00
0005433103842	7982	Economy	6700.00
0005432021027	7982	Economy	6700.00
0005433477054	7982	Economy	6700.00
0005433477030	7982	Economy	6700.00
0005432920466	7982	Economy	6700.00
0005433435520	7982	Economy	6700.00
0005433477035	7982	Economy	6700.00
0005433103896	7982	Economy	6700.00
0005433439114	7982	Economy	6700.00
0005432920472	7982	Economy	6700.00
0005433476994	7982	Economy	6700.00
0005433476962	7982	Economy	6700.00
0005433103863	7982	Economy	6700.00
0005433477055	7982	Economy	6700.00
0005433103855	7982	Economy	6700.00
0005433476974	7982	Economy	6700.00
0005433103876	7982	Economy	6700.00
0005433477018	7982	Economy	6700.00
0005433103878	7982	Economy	6700.00
0005433103852	7982	Economy	6700.00
0005433477033	7982	Economy	6700.00
0005433103894	7982	Economy	6700.00
0005433439115	7982	Economy	6700.00
0005433103860	7982	Economy	6700.00
0005433477080	7982	Economy	6700.00
0005433476993	7982	Economy	6700.00
0005433103887	7982	Economy	6700.00
0005433477078	7982	Economy	6700.00
0005433103856	7982	Economy	6700.00
0005433103879	7982	Economy	6700.00
0005432751626	7982	Economy	6700.00
0005433103873	7982	Economy	6700.00
0005433477009	7982	Economy	6700.00
0005433103866	7982	Economy	6700.00
0005432920473	7982	Economy	6700.00
0005433103847	7982	Economy	6700.00
0005432021033	7982	Economy	6700.00
0005432920471	7982	Economy	6700.00
0005433477091	7982	Economy	6700.00
0005433103871	7982	Economy	6700.00
0005432751627	7982	Economy	6700.00
0005433477038	7982	Economy	6700.00
0005433103891	7982	Economy	6700.00
0005433103845	7982	Economy	6700.00
0005432753400	7982	Economy	6700.00
0005433103868	7982	Economy	6700.00
0005433477076	7982	Economy	6700.00
0005433477032	7982	Economy	6700.00
0005433435519	7982	Economy	6700.00
0005432021034	7982	Economy	6700.00
0005433103862	7982	Economy	6700.00
0005433477042	7982	Economy	6700.00
0005433103892	7982	Economy	6700.00
0005433476963	7982	Economy	6700.00
0005433476990	7982	Economy	6700.00
0005433103870	7982	Economy	6700.00
0005432920470	7982	Economy	6700.00
0005433477072	7982	Economy	6700.00
0005433477105	7982	Economy	6700.00
0005433477036	7982	Economy	6700.00
0005433476973	7982	Economy	6700.00
0005432817916	7980	Business	20000.00
0005432818138	7980	Business	20000.00
0005432818078	7980	Business	20000.00
0005432818229	7980	Business	20000.00
0005432818128	7980	Business	20000.00
0005432818228	7980	Business	20000.00
0005432902118	7980	Business	20000.00
0005432818097	7980	Business	20000.00
0005432818257	7980	Business	20000.00
0005432817992	7980	Business	20000.00
0005432902115	7980	Economy	7300.00
0005432902112	7980	Economy	6700.00
0005432818264	7980	Economy	6700.00
0005432818118	7980	Economy	6700.00
0005432818052	7980	Economy	6700.00
0005432818135	7980	Economy	6700.00
0005432818115	7980	Economy	6700.00
0005432902116	7980	Economy	6700.00
0005432818104	7980	Economy	6700.00
0005432818126	7980	Economy	6700.00
0005432818066	7980	Economy	6700.00
0005432818129	7980	Economy	6700.00
0005432818177	7980	Economy	6700.00
0005432818038	7980	Economy	6700.00
0005432902113	7980	Economy	6700.00
0005432902114	7980	Economy	6700.00
0005432818217	7980	Economy	6700.00
0005432818049	7980	Economy	6700.00
0005432818151	7980	Economy	6700.00
0005432818258	7980	Economy	6700.00
0005432818117	7980	Economy	7300.00
0005432818051	7980	Economy	6700.00
0005432818127	7980	Economy	6700.00
0005432817915	7980	Economy	6700.00
0005432818123	7980	Economy	6700.00
0005432818159	7980	Economy	6700.00
0005432818183	7980	Economy	6700.00
0005432818043	7980	Economy	6700.00
0005432818101	7980	Economy	6700.00
0005432902117	7980	Economy	6700.00
0005432818096	7980	Economy	6700.00
0005432818139	7980	Economy	6700.00
0005432818079	7980	Economy	6700.00
0005432818263	7980	Economy	6700.00
0005433870798	9650	Economy	6900.00
0005434175845	9650	Economy	6900.00
0005434175844	9650	Economy	6900.00
0005433870799	9650	Economy	6900.00
0005433870787	32329	Economy	6900.00
0005433870788	32329	Economy	6900.00
0005433870786	32329	Economy	6900.00
0005434880960	3509	Business	35000.00
0005432800266	3509	Business	35000.00
0005435903087	3509	Business	35000.00
0005434880942	3509	Business	35000.00
0005434880941	3509	Business	35000.00
0005435626839	3509	Business	35000.00
0005432800264	3509	Business	35000.00
0005432800269	3509	Business	35000.00
0005435127553	3509	Business	35000.00
0005435626818	3509	Business	35000.00
0005435914732	3509	Business	35000.00
0005435914035	3509	Business	35000.00
0005432611815	3509	Comfort	19900.00
0005435902998	3509	Business	35000.00
0005435914049	3509	Comfort	19900.00
0005434880946	3509	Comfort	19900.00
0005435914033	3509	Comfort	19900.00
0005435127560	3509	Comfort	19900.00
0005435903053	3509	Comfort	19900.00
0005435626836	3509	Comfort	19900.00
0005435914718	3509	Comfort	19900.00
0005435914047	3509	Comfort	19900.00
0005435626822	3509	Comfort	19900.00
0005435914025	3509	Comfort	19900.00
0005435914094	3509	Comfort	19900.00
0005435626820	3509	Comfort	19900.00
0005435841835	3509	Comfort	19900.00
0005435903171	3509	Comfort	19900.00
0005435626837	3509	Comfort	19900.00
0005435903119	3509	Comfort	19900.00
0005435914046	3509	Economy	11700.00
0005435903052	3509	Comfort	19900.00
0005434880954	3509	Economy	11700.00
0005435913981	3509	Economy	11700.00
0005435914050	3509	Economy	11700.00
0005435127561	3509	Economy	11700.00
0005435903069	3509	Economy	11700.00
0005434880956	3509	Economy	11700.00
0005435903051	3509	Economy	11700.00
0005435914052	3509	Economy	11700.00
0005435903096	3509	Economy	11700.00
0005435127552	3509	Economy	11700.00
0005432800265	3509	Economy	11700.00
0005435626828	3509	Economy	11700.00
0005435626826	3509	Economy	11700.00
0005432613980	3509	Economy	11700.00
0005435903049	3509	Economy	11700.00
0005435903130	3509	Economy	11700.00
0005432800270	3509	Economy	11700.00
0005434880961	3509	Economy	11700.00
0005435626838	3509	Economy	11700.00
0005434880959	3509	Economy	11700.00
0005435914034	3509	Economy	11700.00
0005434880952	3509	Economy	11700.00
0005432800267	3509	Economy	11700.00
0005432800268	3509	Economy	11700.00
0005435903026	3509	Economy	11700.00
0005435903092	3509	Economy	11700.00
0005435127555	3509	Economy	11700.00
0005435626823	3509	Economy	11700.00
0005435903067	3509	Economy	11700.00
0005432611816	3509	Economy	12800.00
0005434938715	3509	Economy	11700.00
0005435127562	3509	Economy	11700.00
0005435626819	3509	Economy	12800.00
0005435626827	3509	Economy	11700.00
0005435903118	3509	Economy	11700.00
0005435914036	3509	Economy	11700.00
0005435626833	3509	Economy	11700.00
0005435914031	3509	Economy	11700.00
0005434880965	3509	Economy	11700.00
0005435914051	3509	Economy	11700.00
0005434427457	3509	Economy	11700.00
0005432800271	3509	Economy	11700.00
0005434880949	3509	Economy	11700.00
0005435903183	3509	Economy	11700.00
0005435626835	3509	Economy	11700.00
0005435127554	3509	Economy	11700.00
0005435127564	3509	Economy	11700.00
0005434880955	3509	Economy	11700.00
0005435127567	3509	Economy	11700.00
0005435914739	3509	Economy	11700.00
0005434880953	3509	Economy	11700.00
0005434427454	3509	Economy	11700.00
0005435914043	3509	Economy	11700.00
0005434938709	3509	Economy	11700.00
0005434880948	3509	Economy	11700.00
0005435626824	3509	Economy	11700.00
0005434938710	3509	Economy	11700.00
0005434880945	3509	Economy	11700.00
0005435914021	3509	Economy	11700.00
0005435127556	3509	Economy	11700.00
0005435914019	3509	Economy	11700.00
0005434938708	3509	Economy	11700.00
0005434427456	3509	Economy	11700.00
0005432800272	3509	Economy	11700.00
0005435903141	3509	Economy	11700.00
0005435914020	3509	Economy	11700.00
0005435626825	3509	Economy	11700.00
0005435626821	3509	Economy	11700.00
0005432800273	3509	Economy	11700.00
0005434880950	3509	Economy	11700.00
0005434880958	3509	Economy	11700.00
0005434427452	3509	Economy	11700.00
0005435903131	3509	Economy	11700.00
0005434938714	3509	Economy	12800.00
0005434880963	3509	Economy	12800.00
0005435626834	3509	Economy	11700.00
0005434427451	3509	Economy	11700.00
0005434880966	3509	Economy	11700.00
0005435127565	3509	Economy	11700.00
0005435127563	3509	Economy	11700.00
0005434427453	3509	Economy	11700.00
0005434880951	3509	Economy	11700.00
0005435914065	3509	Economy	11700.00
0005435127558	3509	Economy	11700.00
0005435626829	3509	Economy	11700.00
0005435903116	3509	Economy	11700.00
0005435626832	3509	Economy	11700.00
0005435903068	3509	Economy	11700.00
0005434427450	3509	Economy	11700.00
0005434880962	3509	Economy	11700.00
0005435914064	3509	Economy	11700.00
0005434938713	3509	Economy	11700.00
0005435127568	3509	Economy	11700.00
0005435626830	3509	Economy	11700.00
0005434880957	3509	Economy	11700.00
0005435914044	3509	Economy	11700.00
0005434880964	3509	Economy	11700.00
0005435914048	3509	Economy	11700.00
0005434938707	3509	Economy	11700.00
0005435127566	3509	Economy	11700.00
0005435903103	3509	Economy	11700.00
0005434880944	3509	Economy	11700.00
0005435902997	3509	Economy	11700.00
0005434427455	3509	Economy	11700.00
0005432613979	3509	Economy	11700.00
0005434880968	3509	Economy	11700.00
0005435903095	3509	Economy	11700.00
0005435903059	3509	Economy	11700.00
0005434938712	3509	Economy	11700.00
0005435626831	3509	Economy	11700.00
0005435914022	3509	Economy	11700.00
0005434880947	3509	Economy	11700.00
0005432613978	3509	Economy	11700.00
0005435127557	3509	Economy	11700.00
0005435903075	3509	Economy	11700.00
0005435626840	3509	Economy	11700.00
0005434938711	3509	Economy	11700.00
0005435841120	3509	Economy	11700.00
0005434880967	3509	Economy	11700.00
0005435903097	3509	Economy	11700.00
0005435127559	3509	Economy	11700.00
0005432611817	3509	Economy	11700.00
0005434880943	3509	Economy	11700.00
0005434880769	14542	Business	35000.00
0005435127241	14542	Business	35000.00
0005434880496	14542	Business	35000.00
0005434880062	14542	Business	35000.00
0005435914182	14542	Business	35000.00
0005435127246	14542	Business	35000.00
0005434427161	14542	Business	35000.00
0005434880238	14542	Business	35000.00
0005435914194	14542	Business	35000.00
0005435626542	14542	Business	35000.00
0005434938638	14542	Business	35000.00
0005435914772	14542	Business	35000.00
0005434880355	14542	Business	35000.00
0005432800086	14542	Business	35000.00
0005432800150	14542	Business	35000.00
0005435914191	14542	Business	35000.00
0005434938639	14542	Business	35000.00
0005435914193	14542	Business	35000.00
0005434427234	14542	Business	35000.00
0005434938504	14542	Business	35000.00
0005435914188	14542	Business	35000.00
0005434880439	14542	Comfort	19900.00
0005434880317	14542	Comfort	19900.00
0005434427200	14542	Comfort	19900.00
0005434938531	14542	Comfort	19900.00
0005434938656	14542	Comfort	19900.00
0005432800099	14542	Comfort	19900.00
0005434880394	14542	Comfort	19900.00
0005432800052	14542	Comfort	19900.00
0005435914198	14542	Comfort	19900.00
0005435626534	14542	Comfort	19900.00
0005435626591	14542	Comfort	19900.00
0005435626556	14542	Comfort	19900.00
0005434880363	14542	Comfort	19900.00
0005435127025	14542	Comfort	19900.00
0005432800174	14542	Comfort	19900.00
0005432800015	14542	Comfort	19900.00
0005435841849	14542	Comfort	19900.00
0005434880300	14542	Comfort	19900.00
0005435903216	14542	Comfort	19900.00
0005434880137	14542	Comfort	19900.00
0005435127247	14542	Comfort	19900.00
0005432607660	14542	Comfort	19900.00
0005434880200	14542	Comfort	19900.00
0005435127213	14542	Comfort	19900.00
0005434880123	14542	Economy	11700.00
0005434880427	14542	Economy	11700.00
0005434880287	14542	Economy	11700.00
0005434880375	14542	Economy	11700.00
0005434880265	14542	Economy	11700.00
0005434880523	14542	Economy	11700.00
0005434880498	14542	Economy	11700.00
0005434427222	14542	Economy	11700.00
0005435626565	14542	Economy	11700.00
0005434880376	14542	Economy	11700.00
0005434427201	14542	Economy	11700.00
0005434427385	14542	Economy	11700.00
0005435127310	14542	Economy	11700.00
0005434880601	14542	Economy	11700.00
0005434880318	14542	Economy	11700.00
0005432799991	14542	Economy	11700.00
0005432611787	14542	Economy	11700.00
0005435914199	14542	Economy	11700.00
0005432799971	14542	Economy	11700.00
0005434879861	14542	Economy	11700.00
0005434427250	14542	Economy	11700.00
0005432800062	14542	Economy	11700.00
0005434427172	14542	Economy	11700.00
0005434427295	14542	Economy	11700.00
0005434880312	14542	Economy	11700.00
0005434880452	14542	Economy	11700.00
0005434880033	14542	Economy	11700.00
0005435127219	14542	Economy	11700.00
0005434880075	14542	Economy	11700.00
0005435626590	14542	Economy	11700.00
0005434938599	14542	Economy	11700.00
0005435626535	14542	Economy	11700.00
0005435914190	14542	Economy	11700.00
0005434879667	14542	Economy	11700.00
0005432800014	14542	Economy	11700.00
0005435626592	14542	Economy	11700.00
0005434880354	14542	Economy	11700.00
0005434427097	14542	Economy	11700.00
0005434880128	14542	Economy	11700.00
0005435127290	14542	Economy	11700.00
0005435127129	14542	Economy	11700.00
0005435626576	14542	Economy	11700.00
0005434880604	14542	Economy	11700.00
0005434880832	14542	Economy	11700.00
0005435914771	14542	Economy	11700.00
0005435626589	14542	Economy	11700.00
0005434938564	14542	Economy	11700.00
0005434880454	14542	Economy	11700.00
0005435914201	14542	Economy	11700.00
0005434880168	14542	Economy	11700.00
0005435626583	14542	Economy	11700.00
0005434427262	14542	Economy	11700.00
0005434880214	14542	Economy	11700.00
0005434880374	14542	Economy	12800.00
0005434938560	14542	Economy	12800.00
0005435127192	14542	Economy	11700.00
0005432800098	14542	Economy	11700.00
0005432799990	14542	Economy	11700.00
0005434427198	14542	Economy	12800.00
0005434427095	14542	Economy	12800.00
0005435626585	14542	Economy	12800.00
0005434427184	14542	Economy	11700.00
0005435127024	14542	Economy	11700.00
0005434879980	14542	Economy	11700.00
0005434938536	14542	Economy	11700.00
0005432800138	14542	Economy	11700.00
0005434880768	14542	Economy	11700.00
0005432607652	14542	Economy	11700.00
0005435127175	14542	Economy	11700.00
0005434880455	14542	Economy	11700.00
0005434880242	14542	Economy	11700.00
0005432800056	14542	Economy	11700.00
0005434880428	14542	Economy	11700.00
0005435127289	14542	Economy	11700.00
0005432611784	14542	Economy	11700.00
0005434880225	14542	Economy	11700.00
0005435914187	14542	Economy	11700.00
0005435626584	14542	Economy	11700.00
0005434880313	14542	Economy	11700.00
0005434880022	14542	Economy	11700.00
0005432800013	14542	Economy	11700.00
0005434938665	14542	Economy	11700.00
0005435903215	14542	Economy	11700.00
0005434427296	14542	Economy	11700.00
0005435914203	14542	Economy	11700.00
0005435127389	14542	Economy	11700.00
0005432800097	14542	Economy	11700.00
0005435127209	14542	Economy	11700.00
0005435127393	14542	Economy	11700.00
0005434880309	14542	Economy	11700.00
0005434880020	14542	Economy	11700.00
0005434880367	14542	Economy	11700.00
0005435914195	14542	Economy	11700.00
0005435626555	14542	Economy	11700.00
0005435127210	14542	Economy	11700.00
0005434880002	14542	Economy	11700.00
0005435127164	14542	Economy	11700.00
0005432800141	14542	Economy	11700.00
0005434880366	14542	Economy	11700.00
0005435127245	14542	Economy	11700.00
0005434880365	14542	Economy	11700.00
0005434938563	14542	Economy	11700.00
0005434880171	14542	Economy	11700.00
0005432800140	14542	Economy	11700.00
0005434427266	14542	Economy	11700.00
0005434880360	14542	Economy	11700.00
0005435626567	14542	Economy	11700.00
0005435127339	14542	Economy	11700.00
0005432607661	14542	Economy	11700.00
0005435914192	14542	Economy	11700.00
0005435127317	14542	Economy	11700.00
0005432800185	14542	Economy	11700.00
0005435914186	14542	Economy	11700.00
0005432800186	14542	Economy	11700.00
0005435914196	14542	Economy	11700.00
0005434880391	14542	Economy	11700.00
0005434880029	14542	Economy	11700.00
0005435914183	14542	Economy	11700.00
0005435841848	14542	Economy	11700.00
0005434938618	14542	Economy	11700.00
0005434880646	14542	Economy	11700.00
0005432800173	14542	Economy	11700.00
0005435626609	14542	Economy	11700.00
0005434938664	14542	Economy	11700.00
0005434427162	14542	Economy	11700.00
0005435127128	14542	Economy	11700.00
0005434938562	14542	Economy	11700.00
0005432607651	14542	Economy	11700.00
0005434427237	14542	Economy	11700.00
0005435914185	14542	Economy	11700.00
0005434880802	14542	Economy	11700.00
0005435127269	14542	Economy	11700.00
0005434427261	14542	Economy	11700.00
0005435127212	14542	Economy	11700.00
0005435127072	14542	Economy	12800.00
0005434427386	14542	Economy	11700.00
0005434427367	14542	Economy	11700.00
0005434880357	14542	Economy	11700.00
0005435626558	14542	Economy	11700.00
0005435914773	14542	Economy	11700.00
0005434880406	14542	Economy	11700.00
0005435914200	14542	Economy	11700.00
0005434880199	14542	Economy	11700.00
0005434938598	14542	Economy	11700.00
0005434880323	14542	Economy	11700.00
0005435626600	14542	Economy	11700.00
0005434880021	14542	Economy	11700.00
0005434880382	14542	Economy	11700.00
0005434880339	14542	Economy	11700.00
0005434427127	14542	Economy	11700.00
0005434938595	14542	Economy	11700.00
0005434427041	14542	Economy	11700.00
0005435127265	14542	Economy	11700.00
0005435626538	14542	Economy	11700.00
0005434427280	14542	Economy	11700.00
0005432799972	14542	Economy	11700.00
0005432800096	14542	Economy	11700.00
0005434938600	14542	Economy	11700.00
0005435127160	14542	Economy	11700.00
0005434880469	14542	Economy	11700.00
0005434880405	14542	Economy	11700.00
0005435127292	14542	Economy	11700.00
0005434880107	14542	Economy	11700.00
0005434880544	14542	Economy	11700.00
0005435127341	14542	Economy	11700.00
0005434880407	14542	Economy	11700.00
0005435127272	14542	Economy	11700.00
0005434880602	14542	Economy	11700.00
0005432611786	14542	Economy	11700.00
0005435127176	14542	Economy	11700.00
0005435914197	14542	Economy	11700.00
0005435626608	14542	Economy	11700.00
0005434427096	14542	Economy	11700.00
0005435127240	14542	Economy	11700.00
0005435626564	14542	Economy	11700.00
0005435626559	14542	Economy	11700.00
0005435127311	14542	Economy	11700.00
0005434880831	14542	Economy	11700.00
0005435626599	14542	Economy	11700.00
0005435626539	14542	Economy	11700.00
0005435841850	14542	Economy	11700.00
0005435127268	14542	Economy	11700.00
0005435914204	14542	Economy	11700.00
0005432800085	14542	Economy	11700.00
0005432800080	14542	Economy	11700.00
0005432800092	14542	Economy	11700.00
0005435127029	14542	Economy	11700.00
0005432607643	14542	Economy	11700.00
0005434427233	14542	Economy	11700.00
0005434880358	14542	Economy	11700.00
0005435914202	14542	Economy	11700.00
0005434880340	14542	Economy	11700.00
0005435626593	14542	Economy	11700.00
0005434880543	14542	Economy	11700.00
0005435127266	14542	Economy	11700.00
0005434880801	14542	Economy	11700.00
0005434427221	14542	Economy	11700.00
0005435914184	14542	Economy	11700.00
0005432800055	14542	Economy	11700.00
0005434880006	14542	Economy	11700.00
0005435914189	14542	Economy	11700.00
0005434427223	14542	Economy	11700.00
0005434427368	14542	Economy	11700.00
0005434938525	14542	Economy	11700.00
0005434312398	3615	Economy	16300.00
0005435890035	3615	Economy	14800.00
0005434325981	3615	Economy	14800.00
0005434325979	3615	Economy	14800.00
0005434325980	3615	Economy	14800.00
0005434312382	3615	Economy	14800.00
0005435890047	3615	Economy	14800.00
0005434325978	3615	Economy	14800.00
0005435890048	3615	Economy	14800.00
0005434312383	3615	Economy	14800.00
0005434312384	3615	Economy	14800.00
0005434312397	3615	Economy	14800.00
0005435890036	3615	Economy	14800.00
0005434312381	3615	Economy	14800.00
0005435890023	3615	Economy	14800.00
0005434325903	15588	Economy	16300.00
0005435890074	15588	Economy	14800.00
0005434325919	15588	Economy	14800.00
0005434325934	15588	Economy	14800.00
0005434325936	15588	Economy	14800.00
0005434325871	15588	Economy	14800.00
0005434325870	15588	Economy	14800.00
0005434325911	15588	Economy	14800.00
0005434325872	15588	Economy	14800.00
0005434325942	15588	Economy	14800.00
0005434312388	15588	Economy	14800.00
0005434325933	15588	Economy	14800.00
0005434311287	15588	Economy	14800.00
0005434325937	15588	Economy	14800.00
0005434312386	15588	Economy	14800.00
0005434325890	15588	Economy	14800.00
0005434325943	15588	Economy	14800.00
0005435890073	15588	Economy	14800.00
0005435958125	636	Economy	4500.00
0005433420594	636	Economy	4100.00
0005435958122	636	Economy	4100.00
0005435958126	636	Economy	4100.00
0005435958120	636	Economy	4100.00
0005435958124	636	Economy	4100.00
0005433420576	636	Economy	4100.00
0005433420596	636	Economy	4100.00
0005435958123	636	Economy	4100.00
0005433420595	636	Economy	4100.00
0005435958119	636	Economy	4100.00
0005435958121	636	Economy	4100.00
0005435958011	15191	Economy	4500.00
0005435958029	15191	Economy	4500.00
0005435958044	15191	Economy	4100.00
0005433420645	15191	Economy	4100.00
0005433420647	15191	Economy	4100.00
0005435958014	15191	Economy	4100.00
0005435958085	15191	Economy	4100.00
0005435958056	15191	Economy	4100.00
0005435958043	15191	Economy	4100.00
0005435958026	15191	Economy	4100.00
0005435958053	15191	Economy	4100.00
0005433420646	15191	Economy	4100.00
0005435958030	15191	Economy	4100.00
0005435958086	15191	Economy	4100.00
0005435958040	15191	Economy	4100.00
0005433420648	15191	Economy	4100.00
0005434247197	8863	Economy	10400.00
0005434247198	8863	Economy	10400.00
0005434247207	8863	Economy	10400.00
0005434247206	8863	Economy	10400.00
0005435629431	16017	Economy	10400.00
0005435629430	16017	Economy	10400.00
0005434247222	16017	Economy	10400.00
0005434247223	16017	Economy	10400.00
0005435163328	29528	Economy	13400.00
0005435163326	29528	Economy	12200.00
0005435163333	29528	Economy	12200.00
0005435163334	29528	Economy	12200.00
0005435163337	29528	Economy	12200.00
0005435933555	29528	Economy	12200.00
0005435163306	29528	Economy	12200.00
0005435933553	29528	Economy	12200.00
0005435163344	29528	Economy	12200.00
0005435933554	29528	Economy	12200.00
0005435163353	29528	Economy	12200.00
0005435163352	29528	Economy	12200.00
0005435163305	29528	Economy	12200.00
0005435163359	29528	Economy	12200.00
0005435163339	29528	Economy	12200.00
0005435163336	29528	Economy	12200.00
0005435163345	29528	Economy	12200.00
0005433404944	2847	Business	12600.00
0005435797891	2847	Economy	4200.00
0005435797890	2847	Economy	4600.00
0005433404981	2847	Economy	4200.00
0005433404964	2847	Economy	4200.00
0005435797892	2847	Economy	4200.00
0005433405010	2847	Economy	4200.00
0005433404982	2847	Economy	4200.00
0005433404970	2847	Economy	4200.00
0005433404943	2847	Economy	4200.00
0005433405033	29344	Business	12600.00
0005435797784	29344	Business	12600.00
0005433405034	29344	Business	12600.00
0005435797848	29344	Economy	4200.00
0005435797754	29344	Economy	4200.00
0005435797785	29344	Economy	4600.00
0005433405035	29344	Economy	4600.00
0005435797876	29344	Economy	4200.00
0005435797812	29344	Economy	4200.00
0005435797810	29344	Economy	4200.00
0005435797748	29344	Economy	4200.00
0005435797747	29344	Economy	4200.00
0005435797807	29344	Economy	4200.00
0005435797823	29344	Economy	4200.00
0005435797776	29344	Economy	4200.00
0005435797808	29344	Economy	4200.00
0005435797758	29344	Economy	4200.00
0005435797770	29344	Economy	4200.00
0005435797753	29344	Economy	4200.00
0005435797811	29344	Economy	4200.00
0005435797786	29344	Economy	4200.00
0005433405032	29344	Economy	4200.00
0005435797806	29344	Economy	4200.00
0005435376412	5751	Economy	6800.00
0005435376413	5751	Economy	6800.00
0005434948262	5738	Economy	6800.00
0005434948263	5738	Economy	6800.00
0005434948187	16321	Economy	6800.00
0005434948204	16321	Economy	6800.00
0005434948217	16321	Economy	6800.00
0005434948235	16321	Economy	6800.00
0005434948226	16321	Economy	6800.00
0005434948216	16321	Economy	6800.00
0005434948178	16321	Economy	6800.00
0005434948203	16321	Economy	6800.00
0005434948218	16321	Economy	6800.00
0005434948202	16321	Economy	6800.00
0005434948209	16321	Economy	6800.00
0005434948230	16321	Economy	6800.00
0005433962666	6878	Business	21400.00
0005433962661	6878	Business	21400.00
0005433962670	6878	Business	21400.00
0005433962693	6878	Business	21400.00
0005433962699	6878	Business	21400.00
0005433962685	6878	Business	21400.00
0005433962694	6878	Economy	7100.00
0005433962688	6878	Economy	7100.00
0005433962663	6878	Economy	7100.00
0005433962681	6878	Economy	7100.00
0005433962667	6878	Economy	7800.00
0005433962697	6878	Economy	7100.00
0005433962684	6878	Economy	7100.00
0005433962682	6878	Economy	7100.00
0005433962664	6878	Economy	7100.00
0005433962680	6878	Economy	7100.00
0005433962665	6878	Economy	7100.00
0005433962669	6878	Economy	7100.00
0005433962660	6878	Economy	7100.00
0005433962686	6878	Economy	7100.00
0005433962689	6878	Economy	7100.00
0005433962687	6878	Economy	7100.00
0005433962695	6878	Economy	7100.00
0005433962662	6878	Economy	7100.00
0005433962674	6878	Economy	7100.00
0005433962677	6878	Economy	7100.00
0005433962672	6878	Economy	7100.00
0005433962696	6878	Economy	7100.00
0005433962676	6878	Economy	7100.00
0005433962690	6878	Economy	7100.00
0005433962679	6878	Economy	7100.00
0005433962668	6878	Economy	7100.00
0005433962698	6878	Economy	7100.00
0005433962673	6878	Economy	7100.00
0005433962683	6878	Economy	7100.00
0005433962671	6878	Economy	7100.00
0005433962691	6878	Economy	7100.00
0005433962675	6878	Economy	7100.00
0005433962692	6878	Economy	7100.00
0005433962678	6878	Economy	7100.00
0005433961730	25721	Business	21400.00
0005433961870	25721	Business	21400.00
0005433961985	25721	Business	21400.00
0005433961839	25721	Business	21400.00
0005433962082	25721	Business	21400.00
0005433961978	25721	Business	21400.00
0005433961823	25721	Business	21400.00
0005433962106	25721	Business	21400.00
0005433961831	25721	Economy	7100.00
0005433962112	25721	Economy	7100.00
0005433962093	25721	Economy	7100.00
0005433961867	25721	Economy	7100.00
0005433961918	25721	Economy	7100.00
0005433961938	25721	Economy	7100.00
0005433962058	25721	Economy	7100.00
0005433961998	25721	Economy	7800.00
0005433962060	25721	Economy	7800.00
0005433961969	25721	Economy	7800.00
0005433962090	25721	Economy	7100.00
0005433961937	25721	Economy	7100.00
0005433962103	25721	Economy	7100.00
0005433961974	25721	Economy	7100.00
0005433961822	25721	Economy	7100.00
0005433961977	25721	Economy	7100.00
0005433961755	25721	Economy	7100.00
0005433962006	25721	Economy	7100.00
0005433961992	25721	Economy	7100.00
0005433961995	25721	Economy	7100.00
0005433962094	25721	Economy	7100.00
0005433962097	25721	Economy	7100.00
0005433962041	25721	Economy	7100.00
0005433962075	25721	Economy	7100.00
0005433961860	25721	Economy	7100.00
0005433961875	25721	Economy	7100.00
0005433961876	25721	Economy	7100.00
0005433962059	25721	Economy	7100.00
0005433961993	25721	Economy	7100.00
0005433961871	25721	Economy	7100.00
0005433962115	25721	Economy	7100.00
0005433961895	25721	Economy	7100.00
0005433961996	25721	Economy	7100.00
0005433961772	25721	Economy	7100.00
0005433961986	25721	Economy	7100.00
0005433962001	25721	Economy	7100.00
0005433962052	25721	Economy	7100.00
0005433962086	25721	Economy	7100.00
0005433961852	25721	Economy	7100.00
0005433961917	25721	Economy	7100.00
0005433961864	25721	Economy	7100.00
0005433962000	25721	Economy	7100.00
0005433962111	25721	Economy	7100.00
0005433961863	25721	Economy	7100.00
0005433962031	25721	Economy	7100.00
0005433961855	25721	Economy	7100.00
0005433962048	25721	Economy	7100.00
0005433962005	25721	Economy	7100.00
0005433962019	25721	Economy	7100.00
0005433962107	25721	Economy	7100.00
0005433961981	25721	Economy	7100.00
0005433961840	25721	Economy	7100.00
0005433961853	25721	Economy	7100.00
0005433961674	25721	Economy	7100.00
0005433962061	25721	Economy	7100.00
0005433962027	25721	Economy	7100.00
0005433961675	25721	Economy	7100.00
0005435082966	24538	Economy	3900.00
0005435082970	24538	Economy	3900.00
0005435082974	24538	Economy	3900.00
0005435082935	24538	Economy	3900.00
0005435082967	24538	Economy	3900.00
0005435082934	24538	Economy	3900.00
0005435082985	24538	Economy	3900.00
0005435082957	24538	Economy	3900.00
0005435082983	24538	Economy	3900.00
0005435083028	26038	Economy	3900.00
0005435083027	26038	Economy	3900.00
0005435083030	26038	Economy	3900.00
0005435083025	26038	Economy	3900.00
0005435083029	26038	Economy	3900.00
0005435083031	26038	Economy	3900.00
0005435083026	26038	Economy	3900.00
0005434245831	5181	Business	18000.00
0005434245828	5181	Business	18000.00
0005432166994	5181	Business	18000.00
0005435286736	5181	Business	18000.00
0005434245832	5181	Business	18000.00
0005435286743	5181	Economy	6600.00
0005434245836	5181	Economy	6600.00
0005432166996	5181	Economy	6000.00
0005434245839	5181	Economy	6000.00
0005435286750	5181	Economy	6000.00
0005435286731	5181	Economy	6000.00
0005435286754	5181	Economy	6000.00
0005434245837	5181	Economy	6000.00
0005434245838	5181	Economy	6000.00
0005434245833	5181	Economy	6000.00
0005435286757	5181	Economy	6000.00
0005435286751	5181	Economy	6000.00
0005433534537	5181	Economy	6000.00
0005433534544	5181	Economy	6000.00
0005434245829	5181	Economy	6000.00
0005435286735	5181	Economy	6000.00
0005434245834	5181	Economy	6000.00
0005434245830	5181	Economy	6000.00
0005434245835	5181	Economy	6000.00
0005434245840	5181	Economy	6000.00
0005432166995	5181	Economy	6000.00
0005434230131	5179	Business	18000.00
0005433786144	5179	Business	18000.00
0005433786138	5179	Business	18000.00
0005433786158	5179	Business	18000.00
0005433786148	5179	Business	18000.00
0005433786136	5179	Business	18000.00
0005433616803	5179	Business	18000.00
0005434230098	5179	Business	18000.00
0005434230129	5179	Business	18000.00
0005434230099	5179	Business	18000.00
0005433616802	5179	Business	18000.00
0005433616813	5179	Business	18000.00
0005434230120	5179	Business	18000.00
0005432106944	5179	Business	18000.00
0005434230094	5179	Business	18000.00
0005433786140	5179	Business	18000.00
0005432665336	5179	Business	18000.00
0005433616811	5179	Business	18000.00
0005434230101	5179	Business	18000.00
0005432667516	5179	Business	18000.00
0005433786134	5179	Business	18000.00
0005433616815	5179	Business	18000.00
0005433616816	5179	Business	18000.00
0005433786157	5179	Business	18000.00
0005434230111	5179	Business	18000.00
0005433786131	5179	Economy	6600.00
0005432106942	5179	Economy	6600.00
0005433616798	5179	Economy	6600.00
0005434230118	5179	Economy	6600.00
0005434230133	5179	Economy	6600.00
0005433786133	5179	Economy	6000.00
0005434230119	5179	Economy	6000.00
0005433786150	5179	Economy	6000.00
0005432665335	5179	Economy	6000.00
0005433616812	5179	Economy	6000.00
0005434230105	5179	Economy	6000.00
0005433786153	5179	Economy	6000.00
0005434230115	5179	Economy	6000.00
0005433786156	5179	Economy	6000.00
0005432106937	5179	Economy	6000.00
0005432145173	5179	Economy	6000.00
0005433616807	5179	Economy	6000.00
0005433786142	5179	Economy	6000.00
0005434230136	5179	Economy	6000.00
0005434230122	5179	Economy	6000.00
0005433786152	5179	Economy	6000.00
0005433786135	5179	Economy	6000.00
0005432106936	5179	Economy	6000.00
0005434230089	5179	Economy	6000.00
0005432106941	5179	Economy	6000.00
0005434230096	5179	Economy	6000.00
0005433616796	5179	Economy	6000.00
0005434230121	5179	Economy	6000.00
0005433786147	5179	Economy	6000.00
0005433616805	5179	Economy	6000.00
0005433616814	5179	Economy	6000.00
0005434230127	5179	Economy	6000.00
0005434230095	5179	Economy	6000.00
0005433786155	5179	Economy	6000.00
0005434230128	5179	Economy	6000.00
0005434230093	5179	Economy	6000.00
0005433786159	5179	Economy	6000.00
0005434230097	5179	Economy	6000.00
0005433616806	5179	Economy	6000.00
0005433786137	5179	Economy	6000.00
0005433786154	5179	Economy	6000.00
0005434230135	5179	Economy	6000.00
0005432106939	5179	Economy	6000.00
0005432106943	5179	Economy	6000.00
0005434230116	5179	Economy	6000.00
0005433786139	5179	Economy	6000.00
0005434230117	5179	Economy	6000.00
0005434230134	5179	Economy	6000.00
0005434230092	5179	Economy	6600.00
0005432106945	5179	Economy	6600.00
0005432106933	5179	Economy	6600.00
0005434230110	5179	Economy	6600.00
0005433616801	5179	Economy	6600.00
0005434230130	5179	Economy	6000.00
0005434230125	5179	Economy	6000.00
0005433616809	5179	Economy	6000.00
0005432106934	5179	Economy	6000.00
0005433616793	5179	Economy	6600.00
0005434230126	5179	Economy	6000.00
0005434230107	5179	Economy	6000.00
0005434230102	5179	Economy	6000.00
0005433786151	5179	Economy	6000.00
0005434230106	5179	Economy	6000.00
0005434230138	5179	Economy	6000.00
0005433616810	5179	Economy	6000.00
0005434230108	5179	Economy	6000.00
0005432145172	5179	Economy	6000.00
0005434230100	5179	Economy	6000.00
0005433786132	5179	Economy	6000.00
0005432106935	5179	Economy	6000.00
0005432106938	5179	Economy	6000.00
0005434230104	5179	Economy	6000.00
0005433786145	5179	Economy	6000.00
0005434230086	5179	Economy	6000.00
0005434230090	5179	Economy	6000.00
0005433786149	5179	Economy	6000.00
0005433786146	5179	Economy	6000.00
0005434230114	5179	Economy	6000.00
0005434230124	5179	Economy	6000.00
0005434230113	5179	Economy	6000.00
0005432667515	5179	Economy	6000.00
0005433616792	5179	Economy	6000.00
0005434230112	5179	Economy	6000.00
0005434230137	5179	Economy	6000.00
0005433786143	5179	Economy	6000.00
0005434230132	5179	Economy	6000.00
0005434230087	5179	Economy	6000.00
0005433616791	5179	Economy	6000.00
0005433786141	5179	Economy	6000.00
0005432106932	5179	Economy	6000.00
0005434230123	5179	Economy	6000.00
0005432106940	5179	Economy	6000.00
0005433616795	5179	Economy	6000.00
0005433616799	5179	Economy	6000.00
0005434230109	5179	Economy	6000.00
0005433616804	5179	Economy	6000.00
0005433616800	5179	Economy	6000.00
0005434230088	5179	Economy	6000.00
0005434230103	5179	Economy	6000.00
0005433616794	5179	Economy	6000.00
0005433616808	5179	Economy	6000.00
0005434230091	5179	Economy	6000.00
0005433616797	5179	Economy	6000.00
0005435270055	5173	Business	18000.00
0005435270087	5173	Business	18000.00
0005434230026	5173	Business	18000.00
0005433815483	5173	Business	18000.00
0005435007649	5173	Business	18000.00
0005435270054	5173	Business	18000.00
0005435007473	5173	Business	18000.00
0005434265883	5173	Business	18000.00
0005433688859	5173	Business	18000.00
0005432336301	5173	Business	18000.00
0005435269950	5173	Business	18000.00
0005432336288	5173	Business	18000.00
0005435269909	5173	Business	18000.00
0005433815484	5173	Business	18000.00
0005435269910	5173	Economy	6600.00
0005435269901	5173	Economy	6600.00
0005435269939	5173	Economy	6000.00
0005435007483	5173	Economy	6000.00
0005433815478	5173	Economy	6000.00
0005434230025	5173	Economy	6000.00
0005435007527	5173	Economy	6000.00
0005435007510	5173	Economy	6000.00
0005432336261	5173	Economy	6000.00
0005434150076	5173	Economy	6000.00
0005435269942	5173	Economy	6000.00
0005434173666	5173	Economy	6000.00
0005434265879	5173	Economy	6000.00
0005435270052	5173	Economy	6000.00
0005433688850	5173	Economy	6000.00
0005435007573	5173	Economy	6000.00
0005433688848	5173	Economy	6000.00
0005434312362	5173	Economy	6000.00
0005435007446	5173	Economy	6000.00
0005435269978	5173	Economy	6000.00
0005432336349	5173	Economy	6000.00
0005434150073	5173	Economy	6000.00
0005432336232	5173	Economy	6000.00
0005434230024	5173	Economy	6000.00
0005434265880	5173	Economy	6000.00
0005434311257	5173	Economy	6000.00
0005433688860	5173	Economy	6000.00
0005435007484	5173	Economy	6000.00
0005435007547	5173	Economy	6000.00
0005435007625	5173	Economy	6000.00
0005435270023	5173	Economy	6000.00
0005434230022	5173	Economy	6000.00
0005435007564	5173	Economy	6000.00
0005435270037	5173	Economy	6600.00
0005434265882	5173	Economy	6000.00
0005434150075	5173	Economy	6600.00
0005435269958	5173	Economy	6600.00
0005435269979	5173	Economy	6600.00
0005435007539	5173	Economy	6600.00
0005435269914	5173	Economy	6000.00
0005434312365	5173	Economy	6000.00
0005435007562	5173	Economy	6000.00
0005434265881	5173	Economy	6000.00
0005435007472	5173	Economy	6600.00
0005435007518	5173	Economy	6000.00
0005435269937	5173	Economy	6000.00
0005435269999	5173	Economy	6000.00
0005435007647	5173	Economy	6000.00
0005432336317	5173	Economy	6000.00
0005432336282	5173	Economy	6000.00
0005435007648	5173	Economy	6000.00
0005435007530	5173	Economy	6000.00
0005435269936	5173	Economy	6000.00
0005435007596	5173	Economy	6000.00
0005435270058	5173	Economy	6000.00
0005433688849	5173	Economy	6000.00
0005435007593	5173	Economy	6000.00
0005435007595	5173	Economy	6000.00
0005435269986	5173	Economy	6000.00
0005435007582	5173	Economy	6000.00
0005432336302	5173	Economy	6000.00
0005435007503	5173	Economy	6000.00
0005435269998	5173	Economy	6000.00
0005435269957	5173	Economy	6000.00
0005435007526	5173	Economy	6000.00
0005432336298	5173	Economy	6000.00
0005435007511	5173	Economy	6000.00
0005435269918	5173	Economy	6000.00
0005435269911	5173	Economy	6000.00
0005435270000	5173	Economy	6000.00
0005434173665	5173	Economy	6000.00
0005434150072	5173	Economy	6000.00
0005433815488	5173	Economy	6000.00
0005432336350	5173	Economy	6000.00
0005435007574	5173	Economy	6000.00
0005435269915	5173	Economy	6000.00
0005434150074	5173	Economy	6000.00
0005435007608	5173	Economy	6000.00
0005434230023	5173	Economy	6000.00
0005435270012	5173	Economy	6000.00
0005434312364	5173	Economy	6000.00
0005435270048	5173	Economy	6000.00
0005434265884	5173	Economy	6000.00
0005435269951	5173	Economy	6000.00
0005435269943	5173	Economy	6000.00
0005434312366	5173	Economy	6000.00
0005435270057	5173	Economy	6000.00
0005434230027	5173	Economy	6000.00
0005435007607	5173	Economy	6000.00
0005435270053	5173	Economy	6000.00
0005435270195	8612	Business	18000.00
0005435270192	8612	Business	18000.00
0005433785799	8612	Business	18000.00
0005435270202	8612	Business	18000.00
0005433785758	8612	Business	18000.00
0005434245690	8612	Business	18000.00
0005434245634	8612	Business	18000.00
0005434245671	8612	Business	18000.00
0005435270182	8612	Business	18000.00
0005434245738	8612	Business	18000.00
0005434245625	8612	Business	18000.00
0005435270190	8612	Business	18000.00
0005434245685	8612	Business	18000.00
0005434245616	8612	Business	18000.00
0005434245672	8612	Economy	6600.00
0005433785667	8612	Economy	6600.00
0005434245716	8612	Economy	6600.00
0005433785759	8612	Economy	6600.00
0005434245737	8612	Economy	6000.00
0005433785727	8612	Economy	6000.00
0005432659748	8612	Economy	6000.00
0005433785743	8612	Economy	6000.00
0005434245686	8612	Economy	6000.00
0005433785666	8612	Economy	6000.00
0005433785600	8612	Economy	6000.00
0005434245717	8612	Economy	6000.00
0005433785765	8612	Economy	6000.00
0005435270187	8612	Economy	6000.00
0005433785800	8612	Economy	6000.00
0005433785913	8612	Economy	6000.00
0005433785757	8612	Economy	6000.00
0005434245731	8612	Economy	6000.00
0005434245624	8612	Economy	6000.00
0005433785556	8612	Economy	6000.00
0005434245739	8612	Economy	6000.00
0005433785668	8612	Economy	6000.00
0005435270191	8612	Economy	6000.00
0005433785665	8612	Economy	6000.00
0005433785704	8612	Economy	6000.00
0005434245763	8612	Economy	6000.00
0005433785780	8612	Economy	6000.00
0005435270186	8612	Economy	6000.00
0005434245538	8612	Economy	6000.00
0005434245606	8612	Economy	6000.00
0005434245687	8612	Economy	6000.00
0005435270194	8612	Economy	6000.00
0005433785734	8612	Economy	6000.00
0005434245551	8612	Economy	6000.00
0005433785737	8612	Economy	6000.00
0005434245688	8612	Economy	6000.00
0005433785771	8612	Economy	6000.00
0005433785777	8612	Economy	6000.00
0005435270185	8612	Economy	6000.00
0005433785788	8612	Economy	6000.00
0005435270196	8612	Economy	6000.00
0005434245550	8612	Economy	6000.00
0005433785783	8612	Economy	6000.00
0005434245539	8612	Economy	6000.00
0005434245589	8612	Economy	6000.00
0005433785779	8612	Economy	6000.00
0005432659756	8612	Economy	6000.00
0005435270198	8612	Economy	6000.00
0005432663075	8612	Economy	6000.00
0005433785574	8612	Economy	6000.00
0005433785575	8612	Economy	6600.00
0005433785733	8612	Economy	6600.00
0005434245736	8612	Economy	6600.00
0005435270184	8612	Economy	6600.00
0005433785686	8612	Economy	6600.00
0005433785687	8612	Economy	6000.00
0005434245663	8612	Economy	6000.00
0005434245617	8612	Economy	6000.00
0005433785797	8612	Economy	6600.00
0005433785801	8612	Economy	6000.00
0005433785762	8612	Economy	6000.00
0005433785802	8612	Economy	6000.00
0005434245597	8612	Economy	6000.00
0005434245633	8612	Economy	6000.00
0005432663081	8612	Economy	6000.00
0005434245590	8612	Economy	6000.00
0005433785641	8612	Economy	6000.00
0005433785555	8612	Economy	6000.00
0005433785693	8612	Economy	6000.00
0005434245626	8612	Economy	6000.00
0005433785680	8612	Economy	6000.00
0005432659755	8612	Economy	6000.00
0005435270199	8612	Economy	6000.00
0005432663082	8612	Economy	6000.00
0005435270200	8612	Economy	6000.00
0005434245644	8612	Economy	6000.00
0005435270201	8612	Economy	6000.00
0005434245691	8612	Economy	6000.00
0005433785599	8612	Economy	6000.00
0005435270189	8612	Economy	6000.00
0005435270183	8612	Economy	6000.00
0005435270204	8612	Economy	6000.00
0005433785778	8612	Economy	6000.00
0005435270188	8612	Economy	6000.00
0005433785728	8612	Economy	6000.00
0005434245692	8612	Economy	6000.00
0005433785729	8612	Economy	6000.00
0005434245712	8612	Economy	6000.00
0005435270203	8612	Economy	6000.00
0005434245575	8612	Economy	6000.00
0005434245667	8612	Economy	6000.00
0005434245627	8612	Economy	6000.00
0005434245689	8612	Economy	6000.00
0005435270197	8612	Economy	6000.00
0005433785642	8612	Economy	6000.00
0005435270193	8612	Economy	6000.00
0005433616442	8611	Business	18000.00
0005433616115	8611	Business	18000.00
0005433616480	8611	Business	18000.00
0005433616227	8611	Business	18000.00
0005433616187	8611	Business	18000.00
0005433616649	8611	Business	18000.00
0005433616447	8611	Business	18000.00
0005433616579	8611	Business	18000.00
0005433616152	8611	Economy	6600.00
0005433616085	8611	Economy	6000.00
0005433616147	8611	Economy	6000.00
0005433616335	8611	Economy	6000.00
0005433616252	8611	Economy	6000.00
0005433615953	8611	Economy	6000.00
0005433616294	8611	Economy	6000.00
0005433616287	8611	Economy	6000.00
0005433616150	8611	Economy	6000.00
0005433616311	8611	Economy	6000.00
0005433616276	8611	Economy	6000.00
0005433616149	8611	Economy	6000.00
0005433616228	8611	Economy	6000.00
0005433616077	8611	Economy	6000.00
0005433616094	8611	Economy	6000.00
0005433616499	8611	Economy	6000.00
0005433616286	8611	Economy	6000.00
0005433616250	8611	Economy	6000.00
0005433616317	8611	Economy	6000.00
0005433616080	8611	Economy	6000.00
0005433615886	8611	Economy	6000.00
0005433616095	8611	Economy	6000.00
0005433616334	8611	Economy	6000.00
0005433616188	8611	Economy	6000.00
0005433616238	8611	Economy	6000.00
0005433616309	8611	Economy	6000.00
0005433616451	8611	Economy	6000.00
0005433616448	8611	Economy	6000.00
0005433616251	8611	Economy	6000.00
0005433616001	8611	Economy	6000.00
0005433616650	8611	Economy	6000.00
0005433616153	8611	Economy	6000.00
0005433616239	8611	Economy	6600.00
0005433616008	8611	Economy	6600.00
0005433616007	8611	Economy	6600.00
0005433616441	8611	Economy	6600.00
0005433616042	8611	Economy	6000.00
0005433616346	8611	Economy	6000.00
0005433616109	8611	Economy	6000.00
0005433616325	8611	Economy	6000.00
0005433616263	8611	Economy	6000.00
0005433616281	8611	Economy	6000.00
0005433615981	8611	Economy	6000.00
0005433616336	8611	Economy	6000.00
0005433616069	8611	Economy	6000.00
0005433616298	8611	Economy	6000.00
0005433616446	8611	Economy	6000.00
0005433616116	8611	Economy	6000.00
0005433616264	8611	Economy	6000.00
0005433616450	8611	Economy	6000.00
0005433616306	8611	Economy	6000.00
0005433616071	8611	Economy	6000.00
0005433616151	8611	Economy	6000.00
0005433616064	8611	Economy	6000.00
0005433616139	8611	Economy	6000.00
0005433616477	8611	Economy	6000.00
0005433616310	8611	Economy	6000.00
0005433616078	8611	Economy	6000.00
0005433616197	8611	Economy	6000.00
0005433616057	8611	Economy	6000.00
0005433616566	8611	Economy	6000.00
0005433616009	8611	Economy	6000.00
0005433616280	8611	Economy	6000.00
0005435286882	8610	Business	18000.00
0005435286939	8610	Business	18000.00
0005432047660	8610	Business	18000.00
0005435286928	8610	Business	18000.00
0005434265741	8610	Business	18000.00
0005435286917	8610	Business	18000.00
0005435286906	8610	Business	18000.00
0005434265702	8610	Business	18000.00
0005434229911	8610	Business	18000.00
0005435286947	8610	Business	18000.00
0005435286944	8610	Business	18000.00
0005434229831	8610	Business	18000.00
0005432035754	8610	Business	18000.00
0005434265654	8610	Business	18000.00
0005433690986	8610	Business	18000.00
0005435007707	8610	Business	18000.00
0005432035750	8610	Business	18000.00
0005434150055	8610	Business	18000.00
0005435426858	8610	Business	18000.00
0005434229845	8610	Business	18000.00
0005432047661	8610	Business	18000.00
0005432035748	8610	Business	18000.00
0005433815563	8610	Business	18000.00
0005434229820	8610	Business	18000.00
0005435286915	8610	Business	18000.00
0005434265712	8610	Business	18000.00
0005434265611	8610	Business	18000.00
0005434173609	8610	Business	18000.00
0005432035747	8610	Economy	6600.00
0005435286901	8610	Economy	6600.00
0005434265679	8610	Economy	6600.00
0005435286888	8610	Economy	6600.00
0005435286909	8610	Economy	6600.00
0005435286942	8610	Economy	6600.00
0005434173604	8610	Economy	6000.00
0005434265716	8610	Economy	6000.00
0005435286941	8610	Economy	6000.00
0005434265734	8610	Economy	6000.00
0005432336384	8610	Economy	6000.00
0005435007713	8610	Economy	6000.00
0005435286897	8610	Economy	6000.00
0005435286948	8610	Economy	6000.00
0005434229887	8610	Economy	6000.00
0005435286945	8610	Economy	6000.00
0005435286943	8610	Economy	6000.00
0005434229846	8610	Economy	6000.00
0005434229796	8610	Economy	6000.00
0005435286930	8610	Economy	6000.00
0005434229724	8610	Economy	6000.00
0005435286903	8610	Economy	6000.00
0005435007714	8610	Economy	6000.00
0005434229977	8610	Economy	6000.00
0005432035752	8610	Economy	6000.00
0005434265710	8610	Economy	6000.00
0005434265779	8610	Economy	6000.00
0005434265752	8610	Economy	6000.00
0005435007710	8610	Economy	6000.00
0005434229876	8610	Economy	6000.00
0005435286884	8610	Economy	6000.00
0005435286910	8610	Economy	6000.00
0005435286895	8610	Economy	6000.00
0005432047663	8610	Economy	6000.00
0005435286946	8610	Economy	6000.00
0005434229795	8610	Economy	6000.00
0005434265589	8610	Economy	6000.00
0005435286911	8610	Economy	6000.00
0005435007712	8610	Economy	6000.00
0005435286893	8610	Economy	6000.00
0005435286940	8610	Economy	6000.00
0005435286924	8610	Economy	6000.00
0005434265709	8610	Economy	6000.00
0005435286905	8610	Economy	6000.00
0005435286908	8610	Economy	6000.00
0005434150005	8610	Economy	6000.00
0005432336383	8610	Economy	6000.00
0005435286907	8610	Economy	6000.00
0005435286922	8610	Economy	6000.00
0005435286927	8610	Economy	6000.00
0005434229976	8610	Economy	6000.00
0005433690985	8610	Economy	6000.00
0005434311291	8610	Economy	6000.00
0005432035755	8610	Economy	6000.00
0005435286900	8610	Economy	6000.00
0005435286904	8610	Economy	6000.00
0005435286891	8610	Economy	6000.00
0005435286892	8610	Economy	6000.00
0005435286918	8610	Economy	6000.00
0005435286919	8610	Economy	6000.00
0005435007708	8610	Economy	6000.00
0005434265590	8610	Economy	6600.00
0005435007709	8610	Economy	6600.00
0005435286936	8610	Economy	6600.00
0005435286883	8610	Economy	6600.00
0005432035749	8610	Economy	6000.00
0005435286934	8610	Economy	6600.00
0005435426860	8610	Economy	6000.00
0005434265602	8610	Economy	6000.00
0005434149981	8610	Economy	6000.00
0005434265603	8610	Economy	6600.00
0005435286899	8610	Economy	6000.00
0005434265532	8610	Economy	6000.00
0005434229818	8610	Economy	6000.00
0005434229890	8610	Economy	6000.00
0005434265748	8610	Economy	6000.00
0005434229808	8610	Economy	6000.00
0005435286898	8610	Economy	6000.00
0005435286923	8610	Economy	6000.00
0005434265733	8610	Economy	6000.00
0005435286938	8610	Economy	6000.00
0005434173603	8610	Economy	6000.00
0005435286912	8610	Economy	6000.00
0005435286931	8610	Economy	6000.00
0005435007711	8610	Economy	6000.00
0005432047662	8610	Economy	6000.00
0005434311278	8610	Economy	6000.00
0005434265703	8610	Economy	6000.00
0005434265735	8610	Economy	6000.00
0005435286932	8610	Economy	6000.00
0005435286935	8610	Economy	6000.00
0005434150054	8610	Economy	6000.00
0005435286913	8610	Economy	6000.00
0005434229886	8610	Economy	6000.00
0005435286886	8610	Economy	6000.00
0005434173610	8610	Economy	6000.00
0005434173611	8610	Economy	6000.00
0005435286937	8610	Economy	6000.00
0005432035753	8610	Economy	6000.00
0005435286916	8610	Economy	6000.00
0005435286887	8610	Economy	6000.00
0005435286894	8610	Economy	6000.00
0005435286933	8610	Economy	6000.00
0005435477009	8610	Economy	6000.00
0005434265604	8610	Economy	6000.00
0005435286925	8610	Economy	6000.00
0005435286926	8610	Economy	6000.00
0005435286921	8610	Economy	6000.00
0005435286879	8610	Economy	6000.00
0005435286902	8610	Economy	6000.00
0005434229821	8610	Economy	6000.00
0005434173605	8610	Economy	6000.00
0005435426859	8610	Economy	6000.00
0005432035751	8610	Economy	6000.00
0005435286929	8610	Economy	6000.00
0005434229723	8610	Economy	6000.00
0005435286896	8610	Economy	6000.00
0005434229884	8610	Economy	6000.00
0005435286881	8610	Economy	6000.00
0005434265614	8610	Economy	6000.00
0005434265788	8610	Economy	6000.00
0005434265533	8610	Economy	6000.00
0005435286914	8610	Economy	6000.00
0005434265711	8610	Economy	6000.00
0005435286890	8610	Economy	6000.00
0005435286920	8610	Economy	6000.00
0005434265605	8610	Economy	6000.00
0005434265789	8610	Economy	6000.00
0005434229910	8610	Economy	6000.00
0005434265668	8610	Economy	6000.00
0005435286880	8610	Economy	6000.00
0005435286889	8610	Economy	6000.00
0005435286885	8610	Economy	6000.00
0005434639815	12581	Economy	16200.00
0005434639889	12581	Economy	16200.00
0005433202786	12581	Economy	16200.00
0005434639913	12581	Economy	14800.00
0005434639777	12581	Economy	14800.00
0005434639893	12581	Economy	14800.00
0005434639958	12581	Economy	14800.00
0005434639782	12581	Economy	14800.00
0005434639814	12581	Economy	14800.00
0005434639844	12581	Economy	14800.00
0005434639892	12581	Economy	14800.00
0005434639897	12581	Economy	14800.00
0005434639802	12581	Economy	14800.00
0005434639798	12581	Economy	14800.00
0005434639900	12581	Economy	14800.00
0005434639972	12581	Economy	14800.00
0005434639932	12581	Economy	14800.00
0005433202787	12581	Economy	14800.00
0005434639916	12581	Economy	14800.00
0005434639856	12581	Economy	14800.00
0005434639779	12581	Economy	14800.00
0005434639845	12581	Economy	14800.00
0005433202788	12581	Economy	14800.00
0005434639771	12581	Economy	14800.00
0005434639888	12581	Economy	14800.00
0005434640006	12581	Economy	14800.00
0005434639890	12581	Economy	14800.00
0005434639843	12581	Economy	14800.00
0005434639772	12581	Economy	14800.00
0005434639967	12581	Economy	14800.00
0005434639959	12581	Economy	14800.00
0005434639846	12581	Economy	14800.00
0005434639933	12581	Economy	14800.00
0005434639899	12581	Economy	14800.00
0005434639898	12581	Economy	14800.00
0005432290722	23355	Economy	16200.00
0005433202660	23355	Economy	16200.00
0005434640081	23355	Economy	16200.00
0005434640084	23355	Economy	14800.00
0005434640071	23355	Economy	14800.00
0005434640080	23355	Economy	14800.00
0005434640078	23355	Economy	14800.00
0005434640072	23355	Economy	14800.00
0005433202699	23355	Economy	14800.00
0005434640073	23355	Economy	14800.00
0005434640076	23355	Economy	14800.00
0005433202665	23355	Economy	14800.00
0005434640070	23355	Economy	14800.00
0005434640079	23355	Economy	14800.00
0005433202651	23355	Economy	14800.00
0005433202570	23355	Economy	14800.00
0005434640069	23355	Economy	14800.00
0005434640077	23355	Economy	14800.00
0005434640075	23355	Economy	14800.00
0005434640086	23355	Economy	14800.00
0005433202630	23355	Economy	14800.00
0005434640085	23355	Economy	14800.00
0005432290724	23355	Economy	14800.00
0005433202696	23355	Economy	14800.00
0005434640074	23355	Economy	14800.00
0005434640082	23355	Economy	14800.00
0005433202652	23355	Economy	14800.00
0005433202650	23355	Economy	14800.00
0005434640068	23355	Economy	14800.00
0005433202631	23355	Economy	14800.00
0005433202642	23355	Economy	14800.00
0005432290725	23355	Economy	14800.00
0005433202698	23355	Economy	14800.00
0005432290723	23355	Economy	14800.00
0005433202697	23355	Economy	14800.00
0005433202664	23355	Economy	14800.00
0005433202629	23355	Economy	14800.00
0005433202683	23355	Economy	14800.00
0005434640083	23355	Economy	14800.00
0005432329624	21054	Business	18900.00
0005432329784	21054	Business	18900.00
0005432329671	21054	Business	18900.00
0005432329672	21054	Business	18900.00
0005432383958	21054	Business	18900.00
0005432383881	21054	Business	18900.00
0005432329599	21054	Business	18900.00
0005432329582	21054	Business	18900.00
0005432329715	21054	Business	18900.00
0005432384115	21054	Business	18900.00
0005432329375	21054	Business	18900.00
0005432329625	21054	Business	18900.00
0005432384000	21054	Economy	6300.00
0005432383738	21054	Economy	6300.00
0005432329652	21054	Economy	6300.00
0005432383788	21054	Economy	6300.00
0005432383829	21054	Economy	6300.00
0005432329782	21054	Economy	6300.00
0005432383936	21054	Economy	6300.00
0005432329545	21054	Economy	6300.00
0005432329740	21054	Economy	6300.00
0005432329758	21054	Economy	6300.00
0005432329515	21054	Economy	6900.00
0005432329778	21054	Economy	6900.00
0005432329805	21054	Economy	6900.00
0005432383833	21054	Economy	6900.00
0005432329598	21054	Economy	6900.00
0005432329718	21054	Economy	6300.00
0005432329856	21054	Economy	6300.00
0005432848909	21054	Economy	6300.00
0005432329772	21054	Economy	6300.00
0005432383964	21054	Economy	6300.00
0005432383737	21054	Economy	6300.00
0005432383779	21054	Economy	6300.00
0005432329603	21054	Economy	6300.00
0005432329476	21054	Economy	6300.00
0005432384081	21054	Economy	6300.00
0005432329665	21054	Economy	6300.00
0005432329716	21054	Economy	6300.00
0005432329783	21054	Economy	6300.00
0005432329506	21054	Economy	6300.00
0005432383945	21054	Economy	6300.00
0005432329781	21054	Economy	6300.00
0005432329820	21054	Economy	6300.00
0005432329827	21054	Economy	6300.00
0005432848908	21054	Economy	6300.00
0005432329797	21054	Economy	6300.00
0005432329927	21054	Economy	6300.00
0005432383865	21054	Economy	6300.00
0005432383971	21054	Economy	6300.00
0005432329926	21054	Economy	6300.00
0005432329376	21054	Economy	6300.00
0005432384082	21054	Economy	6300.00
0005432383826	21054	Economy	6300.00
0005432383848	21054	Economy	6300.00
0005432329701	21054	Economy	6300.00
0005432383966	21054	Economy	6300.00
0005432329686	21054	Economy	6300.00
0005432384160	21054	Economy	6300.00
0005432329799	21054	Economy	6300.00
0005432848907	21054	Economy	6300.00
0005432384071	21054	Economy	6300.00
0005432384031	21054	Economy	6300.00
0005432384099	21054	Economy	6300.00
0005432329759	21054	Economy	6300.00
0005432383944	21054	Economy	6300.00
0005432329826	21054	Economy	6300.00
0005432329713	21054	Economy	6300.00
0005432329664	21054	Economy	6300.00
0005432329651	21054	Economy	6300.00
0005432329650	21054	Economy	6300.00
0005432329719	21054	Economy	6300.00
0005432384030	21054	Economy	6300.00
0005432383906	21054	Economy	6300.00
0005432329477	21054	Economy	6300.00
0005432384100	21054	Economy	6300.00
0005432329674	21054	Economy	6300.00
0005432383943	21054	Economy	6300.00
0005432329495	21054	Economy	6300.00
0005432329743	21054	Economy	6300.00
0005432383998	21054	Economy	6300.00
0005432329777	21054	Economy	6300.00
0005432329646	21054	Economy	6300.00
0005432383827	21054	Economy	6300.00
0005432384064	21054	Economy	6300.00
0005432384063	21054	Economy	6300.00
0005432054391	21054	Economy	6300.00
0005432383855	21054	Economy	6300.00
0005432329567	21054	Economy	6300.00
0005432329679	21054	Economy	6300.00
0005432329505	21054	Economy	6300.00
0005432329647	21054	Economy	6300.00
0005432383832	21054	Economy	6300.00
0005432329685	21054	Economy	6300.00
0005432383854	21054	Economy	6300.00
0005432329798	21054	Economy	6300.00
0005432329717	21054	Economy	6300.00
0005432384307	31263	Business	18900.00
0005432330014	31263	Business	18900.00
0005432384309	31263	Business	18900.00
0005432384312	31263	Business	18900.00
0005432384311	31263	Business	18900.00
0005432384297	31263	Business	18900.00
0005432330016	31263	Business	18900.00
0005432384308	31263	Economy	6300.00
0005432330000	31263	Economy	6300.00
0005432330005	31263	Economy	6300.00
0005432330020	31263	Economy	6300.00
0005432848867	31263	Economy	6300.00
0005432287337	31263	Economy	6300.00
0005432330024	31263	Economy	6900.00
0005432330002	31263	Economy	6900.00
0005432330007	31263	Economy	6300.00
0005432330018	31263	Economy	6300.00
0005432330003	31263	Economy	6300.00
0005432384305	31263	Economy	6300.00
0005432384310	31263	Economy	6300.00
0005432848869	31263	Economy	6300.00
0005432384306	31263	Economy	6300.00
0005432848897	31263	Economy	6300.00
0005432384300	31263	Economy	6300.00
0005432384304	31263	Economy	6300.00
0005432330019	31263	Economy	6300.00
0005432330015	31263	Economy	6300.00
0005432848876	31263	Economy	6300.00
0005432330011	31263	Economy	6300.00
0005432330013	31263	Economy	6300.00
0005432384296	31263	Economy	6300.00
0005432330001	31263	Economy	6300.00
0005432330025	31263	Economy	6300.00
0005432287336	31263	Economy	6300.00
0005432330022	31263	Economy	6300.00
0005432330004	31263	Economy	6300.00
0005432329999	31263	Economy	6300.00
0005432384299	31263	Economy	6300.00
0005432330010	31263	Economy	6300.00
0005432287334	31263	Economy	6300.00
0005432848879	31263	Economy	6300.00
0005432384303	31263	Economy	6300.00
0005432330008	31263	Economy	6300.00
0005432384293	31263	Economy	6300.00
0005432330021	31263	Economy	6300.00
0005432287335	31263	Economy	6300.00
0005432848898	31263	Economy	6300.00
0005432330023	31263	Economy	6300.00
0005432384301	31263	Economy	6300.00
0005432330009	31263	Economy	6300.00
0005432384302	31263	Economy	6300.00
0005432384298	31263	Economy	6300.00
0005432848875	31263	Economy	6300.00
0005432330017	31263	Economy	6300.00
0005432384295	31263	Economy	6300.00
0005432384313	31263	Economy	6300.00
0005432330006	31263	Economy	6300.00
0005432384294	31263	Economy	6300.00
0005432330012	31263	Economy	6300.00
0005432425940	13287	Business	12700.00
0005432425887	13287	Business	12700.00
0005432425925	13287	Business	12700.00
0005432425942	13287	Business	12700.00
0005432425937	13287	Business	12700.00
0005432425905	13287	Business	12700.00
0005432425941	13287	Business	12700.00
0005432425900	13287	Economy	4200.00
0005432433840	13287	Economy	4200.00
0005432425901	13287	Economy	4200.00
0005432425927	13287	Economy	4200.00
0005432425912	13287	Economy	4200.00
0005432425939	13287	Economy	4200.00
0005432425934	13287	Economy	4700.00
0005432433839	13287	Economy	4700.00
0005432425915	13287	Economy	4700.00
0005432425892	13287	Economy	4700.00
0005432425902	13287	Economy	4200.00
0005432425929	13287	Economy	4200.00
0005432425906	13287	Economy	4200.00
0005432425944	13287	Economy	4200.00
0005432425922	13287	Economy	4200.00
0005432425945	13287	Economy	4200.00
0005432425909	13287	Economy	4200.00
0005432425896	13287	Economy	4200.00
0005432425886	13287	Economy	4200.00
0005432425891	13287	Economy	4200.00
0005432425921	13287	Economy	4200.00
0005432425883	13287	Economy	4200.00
0005432425917	13287	Economy	4200.00
0005432425911	13287	Economy	4200.00
0005432425930	13287	Economy	4200.00
0005432425920	13287	Economy	4200.00
0005432425914	13287	Economy	4200.00
0005432425928	13287	Economy	4200.00
0005432425936	13287	Economy	4200.00
0005432425931	13287	Economy	4200.00
0005432425899	13287	Economy	4200.00
0005432425884	13287	Economy	4200.00
0005432425913	13287	Economy	4200.00
0005432425908	13287	Economy	4200.00
0005432425895	13287	Economy	4200.00
0005432425888	13287	Economy	4200.00
0005432425889	13287	Economy	4200.00
0005432425893	13287	Economy	4200.00
0005432425919	13287	Economy	4200.00
0005432425890	13287	Economy	4200.00
0005432425894	13287	Economy	4200.00
0005432425938	13287	Economy	4200.00
0005432425943	13287	Economy	4200.00
0005432425926	13287	Economy	4200.00
0005432425924	13287	Economy	4200.00
0005432425898	13287	Economy	4200.00
0005432425916	13287	Economy	4200.00
0005432425935	13287	Economy	4200.00
0005432425932	13287	Economy	4200.00
0005432425918	13287	Economy	4200.00
0005432425933	13287	Economy	4200.00
0005432425897	13287	Economy	4200.00
0005432425885	13287	Economy	4200.00
0005432425907	13287	Economy	4200.00
0005432425904	13287	Economy	4200.00
0005432425910	13287	Economy	4200.00
0005432425903	13287	Economy	4200.00
0005432425923	13287	Economy	4200.00
0005432425384	30788	Business	12700.00
0005432425376	30788	Business	12700.00
0005432425483	30788	Business	12700.00
0005432425364	30788	Business	12700.00
0005432425371	30788	Business	12700.00
0005432425298	30788	Business	12700.00
0005432425445	30788	Business	12700.00
0005432425401	30788	Economy	4200.00
0005432425295	30788	Economy	4200.00
0005432425466	30788	Economy	4200.00
0005432425336	30788	Economy	4200.00
0005432425322	30788	Economy	4200.00
0005432425350	30788	Economy	4700.00
0005432425507	30788	Economy	4200.00
0005432425506	30788	Economy	4200.00
0005432425480	30788	Economy	4200.00
0005432425393	30788	Economy	4200.00
0005432425362	30788	Economy	4200.00
0005432425465	30788	Economy	4200.00
0005432425400	30788	Economy	4200.00
0005432425491	30788	Economy	4200.00
0005432425340	30788	Economy	4200.00
0005432425511	30788	Economy	4200.00
0005432425349	30788	Economy	4200.00
0005432425500	30788	Economy	4200.00
0005432425478	30788	Economy	4200.00
0005432425361	30788	Economy	4200.00
0005432425294	30788	Economy	4200.00
0005432425439	30788	Economy	4200.00
0005432425444	30788	Economy	4200.00
0005432425402	30788	Economy	4200.00
0005432425403	30788	Economy	4200.00
0005432425236	30788	Economy	4200.00
0005432425492	30788	Economy	4200.00
0005432425442	30788	Economy	4200.00
0005432425382	30788	Economy	4200.00
0005432425510	30788	Economy	4200.00
0005432425493	30788	Economy	4200.00
0005432425383	30788	Economy	4200.00
0005432425468	30788	Economy	4200.00
0005432425363	30788	Economy	4200.00
0005432425457	30788	Economy	4200.00
0005432425513	30788	Economy	4200.00
0005432425487	30788	Economy	4200.00
0005432425508	30788	Economy	4200.00
0005432425503	30788	Economy	4200.00
0005432425477	30788	Economy	4200.00
0005432425476	30788	Economy	4200.00
0005432425482	30788	Economy	4200.00
0005432425443	30788	Economy	4200.00
0005432425512	30788	Economy	4200.00
0005432425300	30788	Economy	4200.00
0005434448416	9620	Business	32600.00
0005432289082	9620	Business	32600.00
0005432902005	9620	Business	32600.00
0005432818323	9620	Business	32600.00
0005432901921	9620	Business	32600.00
0005432902013	9620	Economy	10900.00
0005434448415	9620	Economy	10900.00
0005432902018	9620	Economy	10900.00
0005432902014	9620	Economy	10900.00
0005432818324	9620	Economy	11900.00
0005432902056	9620	Economy	11900.00
0005434448418	9620	Economy	11900.00
0005432902011	9620	Economy	11900.00
0005432902032	9620	Economy	10900.00
0005432901977	9620	Economy	10900.00
0005432818325	9620	Economy	10900.00
0005432901992	9620	Economy	10900.00
0005434157642	9620	Economy	10900.00
0005434448417	9620	Economy	10900.00
0005432902012	9620	Economy	10900.00
0005432902034	9620	Economy	10900.00
0005432822430	9620	Economy	10900.00
0005432901969	9620	Economy	10900.00
0005434157655	9620	Economy	10900.00
0005432818322	9620	Economy	10900.00
0005432902068	9620	Economy	10900.00
0005432818321	9620	Economy	10900.00
0005432902017	9620	Economy	10900.00
0005434186260	9620	Economy	10900.00
0005432902023	9620	Economy	10900.00
0005432901993	9620	Economy	10900.00
0005432822431	9620	Economy	10900.00
0005432901920	9620	Economy	10900.00
0005432818327	9620	Economy	10900.00
0005432901989	9620	Economy	10900.00
0005432902069	9620	Economy	10900.00
0005434157665	9620	Economy	10900.00
0005432902067	9620	Economy	10900.00
0005432818328	9620	Economy	10900.00
0005432818326	9620	Economy	10900.00
0005432289083	9620	Economy	10900.00
0005432901950	9620	Economy	10900.00
0005432901994	9620	Economy	10900.00
0005432901978	9620	Economy	10900.00
0005432902024	9620	Economy	10900.00
0005432818329	9620	Economy	10900.00
0005434186271	9620	Economy	10900.00
0005432901916	9620	Economy	10900.00
0005432822345	28955	Business	32600.00
0005432818183	28955	Business	32600.00
0005432818129	28955	Business	32600.00
0005434186285	28955	Business	32600.00
0005432818257	28955	Business	32600.00
0005432818263	28955	Business	32600.00
0005432818052	28955	Business	32600.00
0005434448375	28955	Business	32600.00
0005432902117	28955	Business	32600.00
0005434157707	28955	Business	32600.00
0005432822400	28955	Business	32600.00
0005432822369	28955	Economy	10900.00
0005432818118	28955	Economy	10900.00
0005434157706	28955	Economy	10900.00
0005432818159	28955	Economy	10900.00
0005432818258	28955	Economy	10900.00
0005432902113	28955	Economy	10900.00
0005434448392	28955	Economy	10900.00
0005432818229	28955	Economy	10900.00
0005432818079	28955	Economy	10900.00
0005432822359	28955	Economy	11900.00
0005432818138	28955	Economy	11900.00
0005432818128	28955	Economy	11900.00
0005432822382	28955	Economy	11900.00
0005432818117	28955	Economy	10900.00
0005432818078	28955	Economy	10900.00
0005432818135	28955	Economy	10900.00
0005434157708	28955	Economy	10900.00
0005434448383	28955	Economy	10900.00
0005432818096	28955	Economy	10900.00
0005432818127	28955	Economy	10900.00
0005432818151	28955	Economy	10900.00
0005432902115	28955	Economy	10900.00
0005432818038	28955	Economy	10900.00
0005432818115	28955	Economy	10900.00
0005432818104	28955	Economy	10900.00
0005432818101	28955	Economy	10900.00
0005432818217	28955	Economy	10900.00
0005432902114	28955	Economy	10900.00
0005432818043	28955	Economy	10900.00
0005432818123	28955	Economy	10900.00
0005432818139	28955	Economy	10900.00
0005432818066	28955	Economy	10900.00
0005432817916	28955	Economy	10900.00
0005434157709	28955	Economy	10900.00
0005432818126	28955	Economy	10900.00
0005434157710	28955	Economy	10900.00
0005432817915	28955	Economy	10900.00
0005432817992	28955	Economy	10900.00
0005432818097	28955	Economy	10900.00
0005432818051	28955	Economy	10900.00
0005432818264	28955	Economy	10900.00
0005432902116	28955	Economy	10900.00
0005432818228	28955	Economy	10900.00
0005434448404	28955	Economy	10900.00
0005432822401	28955	Economy	10900.00
0005432822399	28955	Economy	10900.00
0005434448382	28955	Economy	10900.00
0005432818049	28955	Economy	10900.00
0005432902118	28955	Economy	10900.00
0005432822346	28955	Economy	10900.00
0005432902112	28955	Economy	10900.00
0005432818177	28955	Economy	10900.00
0005432611817	15101	Economy	11000.00
0005435841835	15101	Economy	11000.00
0005432611816	15101	Economy	11000.00
0005432611815	15101	Economy	11000.00
0005432613978	15101	Economy	11000.00
0005432613980	15101	Economy	11000.00
0005432613979	15101	Economy	11000.00
0005435841120	15101	Economy	11000.00
0005432607661	31623	Economy	11000.00
0005432611787	31623	Economy	11000.00
0005432607652	31623	Economy	11000.00
0005435841848	31623	Economy	11000.00
0005432611784	31623	Economy	11000.00
0005435841850	31623	Economy	11000.00
0005432607643	31623	Economy	11000.00
0005432607660	31623	Economy	11000.00
0005432607651	31623	Economy	11000.00
0005432611786	31623	Economy	11000.00
0005435841849	31623	Economy	11000.00
0005432949186	11842	Business	105900.00
0005433570903	11842	Business	105900.00
0005433570891	11842	Business	105900.00
0005433570909	11842	Business	105900.00
0005432949337	11842	Business	105900.00
0005433570885	11842	Business	105900.00
0005432949240	11842	Business	105900.00
0005432949185	11842	Business	105900.00
0005433570890	11842	Business	105900.00
0005433570902	11842	Business	105900.00
0005432949268	11842	Business	105900.00
0005432949345	11842	Business	105900.00
0005433570900	11842	Business	105900.00
0005432949252	11842	Business	105900.00
0005432949388	11842	Business	105900.00
0005432949341	11842	Economy	35300.00
0005432949290	11842	Economy	35300.00
0005432949248	11842	Economy	35300.00
0005432949375	11842	Economy	35300.00
0005432949440	11842	Economy	35300.00
0005432949308	11842	Economy	35300.00
0005432949322	11842	Economy	35300.00
0005432949387	11842	Economy	35300.00
0005432949349	11842	Economy	35300.00
0005432949323	11842	Economy	38800.00
0005433570898	11842	Economy	38800.00
0005432949441	11842	Economy	35300.00
0005433570907	11842	Economy	35300.00
0005432949413	11842	Economy	35300.00
0005433570905	11842	Economy	35300.00
0005433570884	11842	Economy	35300.00
0005433570881	11842	Economy	35300.00
0005433570888	11842	Economy	35300.00
0005433570887	11842	Economy	35300.00
0005433570904	11842	Economy	35300.00
0005432949295	11842	Economy	35300.00
0005432949173	11842	Economy	35300.00
0005433570893	11842	Economy	35300.00
0005433570901	11842	Economy	35300.00
0005432949321	11842	Economy	35300.00
0005433570894	11842	Economy	35300.00
0005433570910	11842	Economy	35300.00
0005432949329	11842	Economy	35300.00
0005433570897	11842	Economy	35300.00
0005433570908	11842	Economy	35300.00
0005433570911	11842	Economy	35300.00
0005432949339	11842	Economy	35300.00
0005432949176	11842	Economy	35300.00
0005432949309	11842	Economy	35300.00
0005432949274	11842	Economy	35300.00
0005433570889	11842	Economy	35300.00
0005432949310	11842	Economy	35300.00
0005433570906	11842	Economy	35300.00
0005432949174	11842	Economy	35300.00
0005432949247	11842	Economy	35300.00
0005432949376	11842	Economy	35300.00
0005432949338	11842	Economy	35300.00
0005432949500	11842	Economy	35300.00
0005433570895	11842	Economy	35300.00
0005432949254	11842	Economy	35300.00
0005433570896	11842	Economy	35300.00
0005433570882	11842	Economy	35300.00
0005432949184	11842	Economy	35300.00
0005432949389	11842	Economy	35300.00
0005432949353	11842	Economy	35300.00
0005432949187	11842	Economy	35300.00
0005433570912	11842	Economy	35300.00
0005432949194	11842	Economy	35300.00
0005432949057	11842	Economy	35300.00
0005433570886	11842	Economy	35300.00
0005432949460	11842	Economy	35300.00
0005432949354	11842	Economy	35300.00
0005432949226	11842	Economy	35300.00
0005433570899	11842	Economy	35300.00
0005432949239	11842	Economy	35300.00
0005432949459	11842	Economy	35300.00
0005432949479	11842	Economy	35300.00
0005433570883	11842	Economy	35300.00
0005432949199	11842	Economy	35300.00
0005433570892	11842	Economy	35300.00
0005433570112	25301	Business	105900.00
0005433570393	25301	Business	105900.00
0005433570163	25301	Business	105900.00
0005433570380	25301	Business	105900.00
0005433570428	25301	Business	105900.00
0005433570280	25301	Business	105900.00
0005433570372	25301	Business	105900.00
0005433570044	25301	Business	105900.00
0005433570192	25301	Business	105900.00
0005433569795	25301	Business	105900.00
0005433570565	25301	Business	105900.00
0005433570532	25301	Business	105900.00
0005433570306	25301	Business	105900.00
0005433570429	25301	Business	105900.00
0005432949678	25301	Business	105900.00
0005433570463	25301	Economy	35300.00
0005433570631	25301	Economy	35300.00
0005433570401	25301	Economy	35300.00
0005433570191	25301	Economy	35300.00
0005433570434	25301	Economy	35300.00
0005433570379	25301	Economy	35300.00
0005433570531	25301	Economy	35300.00
0005433570081	25301	Economy	38800.00
0005432949668	25301	Economy	38800.00
0005433570043	25301	Economy	38800.00
0005433570279	25301	Economy	35300.00
0005433570488	25301	Economy	35300.00
0005433570232	25301	Economy	35300.00
0005433570305	25301	Economy	35300.00
0005432949675	25301	Economy	35300.00
0005433570158	25301	Economy	35300.00
0005433570347	25301	Economy	35300.00
0005433570346	25301	Economy	35300.00
0005432949679	25301	Economy	35300.00
0005433570426	25301	Economy	35300.00
0005433569962	25301	Economy	35300.00
0005433570466	25301	Economy	35300.00
0005433570075	25301	Economy	35300.00
0005433570080	25301	Economy	35300.00
0005432949667	25301	Economy	35300.00
0005433570337	25301	Economy	35300.00
0005433570304	25301	Economy	35300.00
0005432949670	25301	Economy	35300.00
0005433570292	25301	Economy	35300.00
0005433570370	25301	Economy	35300.00
0005433570468	25301	Economy	35300.00
0005433570444	25301	Economy	35300.00
0005433570411	25301	Economy	35300.00
0005433570476	25301	Economy	35300.00
0005433570164	25301	Economy	35300.00
0005433570414	25301	Economy	35300.00
0005432949673	25301	Economy	35300.00
0005433570415	25301	Economy	35300.00
0005433570017	25301	Economy	35300.00
0005433570603	25301	Economy	35300.00
0005432949672	25301	Economy	35300.00
0005433569885	25301	Economy	35300.00
0005433570394	25301	Economy	35300.00
0005432949676	25301	Economy	35300.00
0005432949674	25301	Economy	35300.00
0005432949665	25301	Economy	35300.00
0005433570227	25301	Economy	35300.00
0005433570381	25301	Economy	35300.00
0005432949669	25301	Economy	35300.00
0005433570371	25301	Economy	35300.00
0005432949677	25301	Economy	35300.00
0005433570273	25301	Economy	35300.00
0005433570296	25301	Economy	35300.00
0005433570295	25301	Economy	35300.00
0005432949671	25301	Economy	35300.00
0005433570536	25301	Economy	35300.00
0005433570291	25301	Economy	35300.00
0005433570479	25301	Economy	35300.00
0005432949664	25301	Economy	35300.00
0005433569963	25301	Economy	35300.00
0005433570079	25301	Economy	35300.00
0005433570303	25301	Economy	35300.00
0005433570543	25301	Economy	35300.00
0005433570018	25301	Economy	35300.00
0005433570074	25301	Economy	35300.00
0005433569969	25301	Economy	35300.00
0005433570566	25301	Economy	35300.00
0005432949666	25301	Economy	35300.00
0005433570274	25301	Economy	35300.00
0005435340618	5389	Business	67200.00
0005435340612	5389	Business	67200.00
0005434655526	5389	Business	67200.00
0005435340611	5389	Economy	22400.00
0005435340574	5389	Economy	22400.00
0005435340569	5389	Economy	22400.00
0005435340590	5389	Economy	22400.00
0005435340583	5389	Economy	24600.00
0005435340603	5389	Economy	24600.00
0005432114297	5389	Economy	24600.00
0005435340582	5389	Economy	22400.00
0005435340579	5389	Economy	22400.00
0005435340594	5389	Economy	22400.00
0005435340623	5389	Economy	22400.00
0005435340563	5389	Economy	22400.00
0005435340575	5389	Economy	22400.00
0005435340591	5389	Economy	22400.00
0005435340619	5389	Economy	22400.00
0005435340580	5389	Economy	22400.00
0005435340609	5389	Economy	22400.00
0005435340592	5389	Economy	22400.00
0005435555416	5389	Economy	22400.00
0005435340573	5389	Economy	22400.00
0005434655529	5389	Economy	22400.00
0005435340599	5389	Economy	22400.00
0005434655524	5389	Economy	22400.00
0005435340604	5389	Economy	22400.00
0005434655530	5389	Economy	22400.00
0005435340593	5389	Economy	22400.00
0005435340664	5389	Economy	22400.00
0005435340608	5389	Economy	22400.00
0005434655525	5389	Economy	22400.00
0005434655527	5389	Economy	22400.00
0005435340526	5389	Economy	22400.00
0005434655528	5389	Economy	22400.00
0005435340642	5389	Economy	22400.00
0005435340553	5389	Economy	22400.00
0005435340622	5389	Economy	22400.00
0005434655330	12505	Business	67200.00
0005434655358	12505	Business	67200.00
0005434655375	12505	Business	67200.00
0005434655207	12505	Business	67200.00
0005435340705	12505	Business	67200.00
0005434655258	12505	Economy	22400.00
0005435340703	12505	Economy	22400.00
0005434655374	12505	Economy	22400.00
0005434655404	12505	Economy	22400.00
0005434655360	12505	Economy	24600.00
0005434655364	12505	Economy	24600.00
0005434655363	12505	Economy	24600.00
0005434655359	12505	Economy	24600.00
0005434655365	12505	Economy	22400.00
0005434655376	12505	Economy	22400.00
0005434655323	12505	Economy	22400.00
0005434655086	12505	Economy	22400.00
0005434655348	12505	Economy	22400.00
0005435340704	12505	Economy	22400.00
0005434655239	12505	Economy	22400.00
0005434655193	12505	Economy	22400.00
0005434655347	12505	Economy	22400.00
0005434655400	12505	Economy	22400.00
0005434655378	12505	Economy	22400.00
0005434655367	12505	Economy	22400.00
0005434655443	12505	Economy	22400.00
0005434655394	12505	Economy	22400.00
0005434655368	12505	Economy	22400.00
0005434655377	12505	Economy	22400.00
0005434655087	12505	Economy	22400.00
0005434655366	12505	Economy	22400.00
0005434655272	12505	Economy	22400.00
0005434655259	12505	Economy	22400.00
0005434655192	12505	Economy	22400.00
0005434655341	12505	Economy	22400.00
0005435555429	12505	Economy	22400.00
0005434655240	12505	Economy	22400.00
0005434655397	12505	Economy	22400.00
0005434655399	12505	Economy	22400.00
0005433717407	7442	Business	32000.00
0005435266232	7442	Business	32000.00
0005433717414	7442	Business	32000.00
0005433717405	7442	Business	32000.00
0005433688867	7442	Business	32000.00
0005433717413	7442	Economy	10700.00
0005433722484	7442	Economy	10700.00
0005433717403	7442	Economy	10700.00
0005433722477	7442	Economy	10700.00
0005435266257	7442	Economy	10700.00
0005435266271	7442	Economy	10700.00
0005433722488	7442	Economy	10700.00
0005433722482	7442	Economy	10700.00
0005433717396	7442	Economy	10700.00
0005435266290	7442	Economy	10700.00
0005433717394	7442	Economy	10700.00
0005435266266	7442	Economy	10700.00
0005433717395	7442	Economy	10700.00
0005433717404	7442	Economy	11700.00
0005433688866	7442	Economy	11700.00
0005433717409	7442	Economy	11700.00
0005433722478	7442	Economy	10700.00
0005433717410	7442	Economy	10700.00
0005435266263	7442	Economy	10700.00
0005435266268	7442	Economy	10700.00
0005433717402	7442	Economy	10700.00
0005433717399	7442	Economy	10700.00
0005435266269	7442	Economy	10700.00
0005433717401	7442	Economy	10700.00
0005433717406	7442	Economy	10700.00
0005433717411	7442	Economy	10700.00
0005433717398	7442	Economy	10700.00
0005433722475	7442	Economy	10700.00
0005435266289	7442	Economy	10700.00
0005433722481	7442	Economy	10700.00
0005435266241	7442	Economy	10700.00
0005433722486	7442	Economy	10700.00
0005433717412	7442	Economy	10700.00
0005433717400	7442	Economy	10700.00
0005433722474	7442	Economy	10700.00
0005433722487	7442	Economy	10700.00
0005433717397	7442	Economy	10700.00
0005433719238	7442	Economy	10700.00
0005435266249	7442	Economy	10700.00
0005433722483	7442	Economy	10700.00
0005433719237	7442	Economy	10700.00
0005433722479	7442	Economy	10700.00
0005433722480	7442	Economy	10700.00
0005435266270	7442	Economy	10700.00
0005435266242	7442	Economy	10700.00
0005435546234	7442	Economy	10700.00
0005433717408	7442	Economy	10700.00
0005433722485	7442	Economy	10700.00
0005435266264	7442	Economy	10700.00
0005433722476	7442	Economy	10700.00
0005433656736	29201	Business	32000.00
0005433688848	29201	Business	32000.00
0005433717114	29201	Business	32000.00
0005433722353	29201	Business	32000.00
0005433717212	29201	Business	32000.00
0005433719220	29201	Business	32000.00
0005433688850	29201	Business	32000.00
0005433717011	29201	Business	32000.00
0005433722347	29201	Business	32000.00
0005433717151	29201	Economy	10700.00
0005433717182	29201	Economy	10700.00
0005433717150	29201	Economy	10700.00
0005433656730	29201	Economy	10700.00
0005433717071	29201	Economy	10700.00
0005433716914	29201	Economy	10700.00
0005433716818	29201	Economy	10700.00
0005433716959	29201	Economy	10700.00
0005433717076	29201	Economy	10700.00
0005433688859	29201	Economy	10700.00
0005433722350	29201	Economy	10700.00
0005433717250	29201	Economy	10700.00
0005435266335	29201	Economy	10700.00
0005433717153	29201	Economy	10700.00
0005433717252	29201	Economy	10700.00
0005433717096	29201	Economy	10700.00
0005433716977	29201	Economy	10700.00
0005433717225	29201	Economy	10700.00
0005433717051	29201	Economy	11700.00
0005435266332	29201	Economy	11700.00
0005433719213	29201	Economy	11700.00
0005433717001	29201	Economy	11700.00
0005435266333	29201	Economy	11700.00
0005433717073	29201	Economy	10700.00
0005433717203	29201	Economy	10700.00
0005433719211	29201	Economy	10700.00
0005433717043	29201	Economy	10700.00
0005433716896	29201	Economy	10700.00
0005433688849	29201	Economy	10700.00
0005433717204	29201	Economy	10700.00
0005433717251	29201	Economy	10700.00
0005433716925	29201	Economy	10700.00
0005433717226	29201	Economy	10700.00
0005435546238	29201	Economy	10700.00
0005433716960	29201	Economy	10700.00
0005433717000	29201	Economy	10700.00
0005432006849	29201	Economy	10700.00
0005433717198	29201	Economy	10700.00
0005433656738	29201	Economy	10700.00
0005433717056	29201	Economy	10700.00
0005433688860	29201	Economy	10700.00
0005433717115	29201	Economy	10700.00
0005433717078	29201	Economy	10700.00
0005433716999	29201	Economy	10700.00
0005433722342	29201	Economy	10700.00
0005435266336	29201	Economy	10700.00
0005435266337	29201	Economy	10700.00
0005433716735	29201	Economy	10700.00
0005433716976	29201	Economy	10700.00
0005433717066	29201	Economy	10700.00
0005433656737	29201	Economy	10700.00
0005435266331	29201	Economy	10700.00
0005433716987	29201	Economy	10700.00
0005435266338	29201	Economy	10700.00
0005433717072	29201	Economy	10700.00
0005433722333	29201	Economy	10700.00
0005433717162	29201	Economy	10700.00
0005435266334	29201	Economy	10700.00
0005433716722	29201	Economy	10700.00
0005433717152	29201	Economy	10700.00
0005433656731	29201	Economy	10700.00
0005433716770	29201	Economy	10700.00
0005433716964	29201	Economy	10700.00
0005433717050	29201	Economy	10700.00
0005433716998	29201	Economy	10700.00
0005433716721	29201	Economy	10700.00
0005433716897	29201	Economy	10700.00
0005433717042	29201	Economy	10700.00
0005434095695	8684	Business	36500.00
0005434143840	8684	Business	36500.00
0005434143846	8684	Economy	12200.00
0005434095697	8684	Economy	12200.00
0005434182479	8684	Economy	12200.00
0005434182493	8684	Economy	13400.00
0005434182473	8684	Economy	12200.00
0005434095694	8684	Economy	12200.00
0005434326090	8684	Economy	12200.00
0005434143839	8684	Economy	12200.00
0005434143843	8684	Economy	12200.00
0005434143838	8684	Economy	12200.00
0005434182472	8684	Economy	12200.00
0005434143842	8684	Economy	12200.00
0005434095696	8684	Economy	12200.00
0005434143841	8684	Economy	12200.00
0005434095698	8684	Economy	12200.00
0005434143844	8684	Economy	12200.00
0005434143845	8684	Economy	12200.00
0005434143837	8684	Economy	12200.00
0005434326091	8684	Economy	12200.00
0005434095699	8684	Economy	12200.00
0005434182492	8684	Economy	12200.00
0005434184708	8684	Economy	12200.00
0005434095700	8684	Economy	12200.00
0005434326282	11666	Business	36500.00
0005434095668	11666	Business	36500.00
0005434095655	11666	Business	36500.00
0005434095558	11666	Economy	12200.00
0005434095669	11666	Economy	12200.00
0005434095627	11666	Economy	12200.00
0005434095628	11666	Economy	12200.00
0005435860717	11666	Economy	12200.00
0005434183638	11666	Economy	13400.00
0005434184725	11666	Economy	13400.00
0005435860716	11666	Economy	13400.00
0005434095670	11666	Economy	12200.00
0005435860714	11666	Economy	12200.00
0005434095586	11666	Economy	12200.00
0005434182544	11666	Economy	12200.00
0005434326283	11666	Economy	12200.00
0005434095596	11666	Economy	12200.00
0005435860718	11666	Economy	12200.00
0005434095562	11666	Economy	12200.00
0005434095559	11666	Economy	12200.00
0005434095619	11666	Economy	12200.00
0005434095664	11666	Economy	12200.00
0005434095606	11666	Economy	12200.00
0005435860719	11666	Economy	12200.00
0005435860715	11666	Economy	12200.00
0005434326280	11666	Economy	12200.00
0005434183639	11666	Economy	12200.00
0005434095573	11666	Economy	12200.00
0005434095537	11666	Economy	12200.00
0005434095587	11666	Economy	12200.00
0005434095564	11666	Economy	12200.00
0005433399125	1446	Business	33000.00
0005433399047	1446	Business	33000.00
0005433399243	1446	Business	33000.00
0005433399051	1446	Business	33000.00
0005433399037	1446	Business	33000.00
0005433398873	1446	Business	33000.00
0005433399290	1446	Business	33000.00
0005433398957	1446	Business	33000.00
0005433398958	1446	Business	33000.00
0005433399081	1446	Economy	11000.00
0005433399069	1446	Economy	11000.00
0005433399223	1446	Economy	11000.00
0005433399150	1446	Economy	11000.00
0005433399011	1446	Economy	11000.00
0005435732714	1446	Economy	11000.00
0005433399088	1446	Economy	12100.00
0005435725774	1446	Economy	12100.00
0005433399210	1446	Economy	12100.00
0005433399019	1446	Economy	12100.00
0005433398999	1446	Economy	11000.00
0005433398978	1446	Economy	11000.00
0005433399043	1446	Economy	11000.00
0005433399003	1446	Economy	11000.00
0005433398956	1446	Economy	11000.00
0005433399149	1446	Economy	11000.00
0005433399044	1446	Economy	11000.00
0005433399205	1446	Economy	11000.00
0005432906598	1446	Economy	11000.00
0005433399012	1446	Economy	11000.00
0005433399299	1446	Economy	11000.00
0005433399035	1446	Economy	11000.00
0005435725775	1446	Economy	11000.00
0005435732715	1446	Economy	11000.00
0005433399075	1446	Economy	11000.00
0005433399211	1446	Economy	11000.00
0005435725779	1446	Economy	11000.00
0005433399052	1446	Economy	11000.00
0005433399097	1446	Economy	11000.00
0005433399084	1446	Economy	11000.00
0005433399168	1446	Economy	11000.00
0005433399029	1446	Economy	11000.00
0005435725778	1446	Economy	11000.00
0005433399222	1446	Economy	11000.00
0005433399087	1446	Economy	11000.00
0005433399196	1446	Economy	11000.00
0005432906594	1446	Economy	11000.00
0005432906582	1446	Economy	11000.00
0005433399278	1446	Economy	11000.00
0005433399206	1446	Economy	11000.00
0005433398981	1446	Economy	11000.00
0005433399028	1446	Economy	11000.00
0005432906588	1446	Economy	11000.00
0005433398874	1446	Economy	11000.00
0005435725777	1446	Economy	11000.00
0005433398998	1446	Economy	11000.00
0005433399232	1446	Economy	11000.00
0005433399256	1446	Economy	11000.00
0005433398908	1446	Economy	11000.00
0005433399119	1446	Economy	11000.00
0005435732716	1446	Economy	11000.00
0005435725776	1446	Economy	11000.00
0005433457087	1446	Economy	11000.00
0005433399441	19282	Business	33000.00
0005435732556	19282	Business	33000.00
0005433399438	19282	Business	33000.00
0005433399446	19282	Business	33000.00
0005433399451	19282	Economy	11000.00
0005435732573	19282	Economy	11000.00
0005435732590	19282	Economy	12100.00
0005433399453	19282	Economy	11000.00
0005433399449	19282	Economy	11000.00
0005435732613	19282	Economy	11000.00
0005435732606	19282	Economy	11000.00
0005435732670	19282	Economy	11000.00
0005433399445	19282	Economy	11000.00
0005433399440	19282	Economy	11000.00
0005433399450	19282	Economy	11000.00
0005433399447	19282	Economy	11000.00
0005433457068	19282	Economy	11000.00
0005433399448	19282	Economy	11000.00
0005433457067	19282	Economy	11000.00
0005435732589	19282	Economy	11000.00
0005433399452	19282	Economy	11000.00
0005432906607	19282	Economy	11000.00
0005433399439	19282	Economy	11000.00
0005435732595	19282	Economy	11000.00
0005435732596	19282	Economy	11000.00
0005433399442	19282	Economy	11000.00
0005432906606	19282	Economy	11000.00
0005433457071	19282	Economy	11000.00
0005433399443	19282	Economy	11000.00
0005433399444	19282	Economy	11000.00
0005434444074	17392	Economy	15600.00
0005434444057	17392	Economy	14100.00
0005434444010	17392	Economy	14100.00
0005434444078	17392	Economy	14100.00
0005434444060	17392	Economy	14100.00
0005434444061	17392	Economy	14100.00
0005434444056	17392	Economy	14100.00
0005434444067	17392	Economy	14100.00
0005434444050	17392	Economy	14100.00
0005434444042	17392	Economy	14100.00
0005434443992	17392	Economy	14100.00
0005434444040	17392	Economy	14100.00
0005434444055	17392	Economy	14100.00
0005434443991	17392	Economy	14100.00
0005434444072	17392	Economy	14100.00
0005434444058	17392	Economy	14100.00
0005434444075	17392	Economy	14100.00
0005434444043	17392	Economy	14100.00
0005434444030	17392	Economy	14100.00
0005434444073	17392	Economy	14100.00
0005434444171	20586	Economy	15600.00
0005434444174	20586	Economy	14100.00
0005434444176	20586	Economy	14100.00
0005434444173	20586	Economy	14100.00
0005434444172	20586	Economy	14100.00
0005434444175	20586	Economy	14100.00
0005435377633	7265	Economy	5800.00
0005435377634	7265	Economy	5800.00
0005434954707	28346	Economy	5800.00
0005434954706	28346	Economy	5800.00
0005434954702	28346	Economy	5800.00
0005434954695	28346	Economy	5800.00
0005434183624	4500	Economy	15400.00
0005434352058	4500	Economy	14000.00
0005434352057	4500	Economy	14000.00
0005434183619	4500	Economy	14000.00
0005435893786	4500	Economy	14000.00
0005435893785	4500	Economy	14000.00
0005434352059	4500	Economy	14000.00
0005434183618	4500	Economy	14000.00
0005434326300	4500	Economy	14000.00
0005435893782	4500	Economy	14000.00
0005434326104	4500	Economy	14000.00
0005434352060	4500	Economy	14000.00
0005434326301	4500	Economy	14000.00
0005434183622	4500	Economy	14000.00
0005435893790	4500	Economy	14000.00
0005434183623	4500	Economy	14000.00
0005435893784	4500	Economy	14000.00
0005435893783	4500	Economy	14000.00
0005434182552	29641	Economy	15400.00
0005434351985	29641	Economy	15400.00
0005435893837	29641	Economy	14000.00
0005434351984	29641	Economy	14000.00
0005435893835	29641	Economy	14000.00
0005434352006	29641	Economy	14000.00
0005434351951	29641	Economy	14000.00
0005435893836	29641	Economy	14000.00
0005434351950	29641	Economy	14000.00
0005435893838	29641	Economy	14000.00
0005434351982	29641	Economy	14000.00
0005434326098	29641	Economy	14000.00
0005434351988	29641	Economy	14000.00
0005434352005	29641	Economy	14000.00
0005434182553	29641	Economy	14000.00
0005434326097	29641	Economy	14000.00
0005433345613	1041	Business	30600.00
0005433345312	1041	Business	30600.00
0005433269840	1041	Business	30600.00
0005433345009	1041	Business	30600.00
0005433345612	1041	Business	30600.00
0005435092358	1041	Business	30600.00
0005433345206	1041	Business	30600.00
0005433345098	1041	Business	30600.00
0005433463967	1041	Business	30600.00
0005433269824	1041	Business	30600.00
0005433345107	1041	Business	30600.00
0005435546226	1041	Business	30600.00
0005433345163	1041	Business	30600.00
0005433345604	1041	Business	30600.00
0005433345197	1041	Business	30600.00
0005435546228	1041	Business	30600.00
0005435545992	1041	Business	30600.00
0005433345053	1041	Business	30600.00
0005433344784	1041	Economy	11200.00
0005433269836	1041	Business	30600.00
0005433345324	1041	Economy	11200.00
0005433345207	1041	Economy	11200.00
0005435546224	1041	Economy	10200.00
0005433269851	1041	Economy	10200.00
0005433345299	1041	Economy	10200.00
0005433344908	1041	Economy	10200.00
0005433345273	1041	Economy	10200.00
0005433345436	1041	Economy	10200.00
0005433345235	1041	Economy	10200.00
0005433345061	1041	Economy	10200.00
0005433345093	1041	Economy	10200.00
0005435092359	1041	Economy	10200.00
0005433345073	1041	Economy	10200.00
0005433344918	1041	Economy	10200.00
0005433345144	1041	Economy	10200.00
0005433345286	1041	Economy	10200.00
0005433345446	1041	Economy	10200.00
0005433269859	1041	Economy	10200.00
0005433462805	1041	Economy	10200.00
0005433462806	1041	Economy	10200.00
0005433345090	1041	Economy	10200.00
0005433344912	1041	Economy	10200.00
0005433345149	1041	Economy	10200.00
0005433345095	1041	Economy	10200.00
0005435545993	1041	Economy	10200.00
0005433345437	1041	Economy	10200.00
0005434445323	1041	Economy	10200.00
0005433345441	1041	Economy	10200.00
0005433345231	1041	Economy	10200.00
0005433344980	1041	Economy	10200.00
0005433345226	1041	Economy	10200.00
0005435545959	1041	Economy	10200.00
0005433344744	1041	Economy	10200.00
0005435545960	1041	Economy	10200.00
0005433345387	1041	Economy	10200.00
0005433345373	1041	Economy	10200.00
0005433345108	1041	Economy	10200.00
0005435545964	1041	Economy	10200.00
0005435092360	1041	Economy	10200.00
0005433159353	1041	Economy	10200.00
0005433345295	1041	Economy	10200.00
0005433345230	1041	Economy	10200.00
0005433345644	1041	Economy	10200.00
0005433345377	1041	Economy	10200.00
0005433345505	1041	Economy	10200.00
0005433345138	1041	Economy	10200.00
0005433345780	1041	Economy	10200.00
0005433345385	1041	Economy	10200.00
0005433345560	1041	Economy	10200.00
0005433344972	1041	Economy	10200.00
0005433345296	1041	Economy	10200.00
0005433158178	1041	Economy	10200.00
0005433345148	1041	Economy	10200.00
0005435545994	1041	Economy	10200.00
0005433269846	1041	Economy	10200.00
0005433345504	1041	Economy	10200.00
0005433344927	1041	Economy	10200.00
0005433345338	1041	Economy	10200.00
0005433345422	1041	Economy	10200.00
0005434445325	1041	Economy	10200.00
0005435545961	1041	Economy	10200.00
0005433345426	1041	Economy	10200.00
0005433345606	1041	Economy	10200.00
0005433159364	1041	Economy	10200.00
0005433345550	1041	Economy	10200.00
0005433463966	1041	Economy	10200.00
0005433269849	1041	Economy	10200.00
0005435545962	1041	Economy	10200.00
0005434445324	1041	Economy	10200.00
0005435546225	1041	Economy	10200.00
0005435546227	1041	Economy	10200.00
0005433463968	1041	Economy	10200.00
0005433345383	1041	Economy	10200.00
0005433269839	1041	Economy	10200.00
0005433345161	1041	Economy	10200.00
0005433344862	1041	Economy	11200.00
0005435545963	1041	Economy	11200.00
0005433345072	1041	Economy	10200.00
0005433345109	1041	Economy	10200.00
0005433345283	1041	Economy	10200.00
0005433269850	1041	Economy	10200.00
0005433344768	1041	Economy	10200.00
0005433345516	1041	Economy	10200.00
0005433269847	1041	Economy	10200.00
0005433269837	1041	Economy	10200.00
0005433345578	1041	Economy	10200.00
0005433345080	1041	Economy	10200.00
0005433345512	1041	Economy	10200.00
0005433345156	1041	Economy	10200.00
0005433345425	1041	Economy	10200.00
0005433345304	1041	Economy	10200.00
0005433345198	1041	Economy	10200.00
0005433345390	1041	Economy	10200.00
0005433345246	1041	Economy	10200.00
0005433345297	1041	Economy	10200.00
0005433344990	1041	Economy	10200.00
0005433269834	1041	Economy	10200.00
0005433345447	1041	Economy	10200.00
0005433159363	1041	Economy	10200.00
0005433269835	1041	Economy	10200.00
0005433159358	1041	Economy	10200.00
0005433345025	1041	Economy	10200.00
0005433269838	1041	Economy	10200.00
0005433345459	1041	Economy	10200.00
0005435092357	1041	Economy	10200.00
0005433345185	1041	Economy	10200.00
0005433345150	1041	Economy	10200.00
0005433345294	1041	Economy	10200.00
0005433345386	1041	Economy	10200.00
0005433345468	1041	Economy	10200.00
0005433345311	1041	Economy	10200.00
0005433345300	1041	Economy	10200.00
0005433345683	1041	Economy	10200.00
0005433345706	1041	Economy	10200.00
0005433345170	1041	Economy	10200.00
0005433345137	1041	Economy	10200.00
0005433345155	1041	Economy	10200.00
0005435545965	1041	Economy	10200.00
0005433345274	1041	Economy	10200.00
0005433345394	1041	Economy	10200.00
0005433344926	1041	Economy	10200.00
0005433345313	1041	Economy	10200.00
0005433344919	1041	Economy	10200.00
0005433345251	1041	Economy	10200.00
0005433345250	1041	Economy	10200.00
0005434446589	1041	Economy	10200.00
0005433345364	1041	Economy	10200.00
0005433345303	1041	Economy	10200.00
0005433346006	17049	Business	30600.00
0005433345970	17049	Business	30600.00
0005433345966	17049	Business	30600.00
0005435508613	17049	Business	30600.00
0005433345993	17049	Business	30600.00
0005435508664	17049	Business	30600.00
0005433345974	17049	Business	30600.00
0005433345996	17049	Business	30600.00
0005433345961	17049	Business	30600.00
0005433345997	17049	Business	30600.00
0005435530000	17049	Business	30600.00
0005435529981	17049	Business	30600.00
0005435530026	17049	Business	30600.00
0005435530071	17049	Business	30600.00
0005433345983	17049	Business	30600.00
0005435092302	17049	Business	30600.00
0005434445299	17049	Business	30600.00
0005433159376	17049	Business	30600.00
0005433345986	17049	Business	30600.00
0005435092318	17049	Economy	11200.00
0005433345967	17049	Economy	11200.00
0005433345968	17049	Economy	11200.00
0005435092294	17049	Economy	10200.00
0005435508710	17049	Economy	10200.00
0005435508562	17049	Economy	10200.00
0005433346007	17049	Economy	10200.00
0005435530055	17049	Economy	10200.00
0005435092282	17049	Economy	10200.00
0005435508666	17049	Economy	10200.00
0005435530004	17049	Economy	10200.00
0005435530074	17049	Economy	10200.00
0005433345964	17049	Economy	10200.00
0005433346008	17049	Economy	10200.00
0005435508611	17049	Economy	10200.00
0005433345992	17049	Economy	10200.00
0005433345971	17049	Economy	10200.00
0005435508685	17049	Economy	10200.00
0005435092273	17049	Economy	10200.00
0005433346004	17049	Economy	10200.00
0005433345975	17049	Economy	10200.00
0005433345978	17049	Economy	10200.00
0005433345998	17049	Economy	10200.00
0005433345980	17049	Economy	10200.00
0005435530025	17049	Economy	10200.00
0005434445300	17049	Economy	10200.00
0005433345988	17049	Economy	10200.00
0005435508599	17049	Economy	10200.00
0005435530077	17049	Economy	10200.00
0005435530024	17049	Economy	10200.00
0005435092284	17049	Economy	10200.00
0005435092319	17049	Economy	10200.00
0005435530068	17049	Economy	10200.00
0005433269873	17049	Economy	10200.00
0005433346001	17049	Economy	10200.00
0005435508610	17049	Economy	10200.00
0005435508665	17049	Economy	10200.00
0005433345994	17049	Economy	10200.00
0005435530052	17049	Economy	10200.00
0005435508615	17049	Economy	10200.00
0005433345991	17049	Economy	10200.00
0005435508678	17049	Economy	10200.00
0005433345987	17049	Economy	10200.00
0005433345963	17049	Economy	10200.00
0005433345973	17049	Economy	10200.00
0005435529980	17049	Economy	10200.00
0005433345981	17049	Economy	10200.00
0005433345990	17049	Economy	10200.00
0005435508608	17049	Economy	10200.00
0005433345979	17049	Economy	10200.00
0005435508692	17049	Economy	11200.00
0005433345985	17049	Economy	11200.00
0005433345989	17049	Economy	10200.00
0005435530070	17049	Economy	10200.00
0005435530075	17049	Economy	10200.00
0005435530027	17049	Economy	10200.00
0005435530013	17049	Economy	10200.00
0005435508624	17049	Economy	10200.00
0005435530020	17049	Economy	10200.00
0005433345976	17049	Economy	10200.00
0005433345962	17049	Economy	10200.00
0005435508602	17049	Economy	10200.00
0005433345960	17049	Economy	10200.00
0005433345982	17049	Economy	10200.00
0005433345969	17049	Economy	10200.00
0005433345959	17049	Economy	10200.00
0005435529979	17049	Economy	10200.00
0005433346005	17049	Economy	10200.00
0005435530022	17049	Economy	10200.00
0005433346003	17049	Economy	10200.00
0005434445302	17049	Economy	10200.00
0005435530011	17049	Economy	10200.00
0005435529982	17049	Economy	10200.00
0005435530057	17049	Economy	10200.00
0005435530003	17049	Economy	10200.00
0005435508660	17049	Economy	10200.00
0005433345999	17049	Economy	10200.00
0005435508684	17049	Economy	10200.00
0005433269872	17049	Economy	10200.00
0005433345977	17049	Economy	10200.00
0005435530053	17049	Economy	10200.00
0005435508563	17049	Economy	10200.00
0005433345972	17049	Economy	10200.00
0005433346000	17049	Economy	10200.00
0005433345965	17049	Economy	10200.00
0005435508612	17049	Economy	10200.00
0005433345995	17049	Economy	10200.00
0005433346002	17049	Economy	10200.00
0005435530076	17049	Economy	10200.00
0005435530012	17049	Economy	10200.00
0005435508672	17049	Economy	10200.00
0005435529974	17049	Economy	10200.00
0005433345984	17049	Economy	10200.00
0005434068937	12776	Business	40300.00
0005434026754	12776	Business	40300.00
0005434068914	12776	Business	40300.00
0005434068926	12776	Business	40300.00
0005434082462	12776	Business	40300.00
0005434069147	12776	Business	40300.00
0005434068887	12776	Business	40300.00
0005434069103	12776	Business	40300.00
0005434082452	12776	Business	40300.00
0005434082418	12776	Business	40300.00
0005434069010	12776	Business	40300.00
0005434068912	12776	Business	40300.00
0005434082371	12776	Economy	13400.00
0005434068997	12776	Economy	13400.00
0005434069012	12776	Economy	13400.00
0005434069132	12776	Economy	13400.00
0005434082536	12776	Economy	13400.00
0005434069106	12776	Economy	13400.00
0005434069092	12776	Economy	13400.00
0005433812967	12776	Economy	13400.00
0005434082426	12776	Economy	13400.00
0005434082367	12776	Economy	13400.00
0005434069050	12776	Economy	13400.00
0005434069117	12776	Economy	13400.00
0005434068814	12776	Economy	13400.00
0005434082334	12776	Economy	13400.00
0005434082537	12776	Economy	13400.00
0005434068974	12776	Economy	13400.00
0005435283524	12776	Economy	13400.00
0005434068838	12776	Economy	13400.00
0005434068812	12776	Economy	13400.00
0005434069008	12776	Economy	13400.00
0005434082333	12776	Economy	13400.00
0005434082460	12776	Economy	13400.00
0005434068793	12776	Economy	13400.00
0005434082305	12776	Economy	13400.00
0005434068987	12776	Economy	13400.00
0005434069141	12776	Economy	13400.00
0005434068913	12776	Economy	13400.00
0005434068991	12776	Economy	13400.00
0005435283521	12776	Economy	13400.00
0005434068925	12776	Economy	13400.00
0005434069125	12776	Economy	13400.00
0005432159990	12776	Economy	13400.00
0005434082419	12776	Economy	13400.00
0005434069009	12776	Economy	13400.00
0005434069046	12776	Economy	13400.00
0005434069091	12776	Economy	13400.00
0005434069045	12776	Economy	13400.00
0005434082287	12776	Economy	13400.00
0005434069199	12776	Economy	14800.00
0005434082405	12776	Economy	14800.00
0005432159988	12776	Economy	14800.00
0005434082416	12776	Economy	14800.00
0005435283522	12776	Economy	14800.00
0005434069104	12776	Economy	14800.00
0005434082351	12776	Economy	13400.00
0005434068718	12776	Economy	13400.00
0005435283526	12776	Economy	13400.00
0005433989883	12776	Economy	13400.00
0005434082391	12776	Economy	13400.00
0005434069051	12776	Economy	13400.00
0005435860637	12776	Economy	13400.00
0005435283534	12776	Economy	13400.00
0005435283533	12776	Economy	13400.00
0005435283519	12776	Economy	13400.00
0005434082364	12776	Economy	13400.00
0005434082434	12776	Economy	13400.00
0005434069033	12776	Economy	13400.00
0005434082368	12776	Economy	13400.00
0005434069131	12776	Economy	13400.00
0005434082350	12776	Economy	13400.00
0005434068786	12776	Economy	13400.00
0005434082427	12776	Economy	13400.00
0005432433838	12776	Economy	13400.00
0005434026753	12776	Economy	13400.00
0005434082344	12776	Economy	13400.00
0005434082433	12776	Economy	13400.00
0005434082417	12776	Economy	13400.00
0005434068708	12776	Economy	13400.00
0005434068785	12776	Economy	13400.00
0005434068813	12776	Economy	13400.00
0005435283532	12776	Economy	13400.00
0005435283523	12776	Economy	13400.00
0005434069076	12776	Economy	13400.00
0005434082317	12776	Economy	13400.00
0005434082280	12776	Economy	13400.00
0005435283530	12776	Economy	13400.00
0005434069035	12776	Economy	13400.00
0005434069198	12776	Economy	13400.00
0005434068874	12776	Economy	13400.00
0005433989880	12776	Economy	13400.00
0005435283527	12776	Economy	13400.00
0005434068640	12776	Economy	13400.00
0005434082411	12776	Economy	13400.00
0005434068965	12776	Economy	13400.00
0005434069101	12776	Economy	13400.00
0005434068794	12776	Economy	13400.00
0005435283529	12776	Economy	13400.00
0005434069305	12776	Economy	13400.00
0005434069034	12776	Economy	13400.00
0005432159989	12776	Economy	13400.00
0005434069030	12776	Economy	13400.00
0005434069119	12776	Economy	13400.00
0005435283525	12776	Economy	13400.00
0005434069118	12776	Economy	13400.00
0005435283520	12776	Economy	13400.00
0005434082451	12776	Economy	13400.00
0005435860638	12776	Economy	13400.00
0005434082414	12776	Economy	13400.00
0005433989881	12776	Economy	13400.00
0005434082440	12776	Economy	13400.00
0005434069241	12776	Economy	13400.00
0005434082422	12776	Economy	13400.00
0005434069149	12776	Economy	13400.00
0005434082461	12776	Economy	13400.00
0005432433837	12776	Economy	13400.00
0005434082279	12776	Economy	13400.00
0005432159991	12776	Economy	13400.00
0005434082288	12776	Economy	13400.00
0005435283528	12776	Economy	13400.00
0005434082365	12776	Economy	13400.00
0005434069175	12776	Economy	13400.00
0005435283531	12776	Economy	13400.00
0005434069200	12776	Economy	13400.00
0005434069594	30650	Business	40300.00
0005434069577	30650	Business	40300.00
0005434026759	30650	Business	40300.00
0005434069597	30650	Business	40300.00
0005434069598	30650	Business	40300.00
0005434069576	30650	Economy	13400.00
0005434069602	30650	Economy	13400.00
0005433812941	30650	Economy	13400.00
0005433812952	30650	Economy	13400.00
0005434069580	30650	Economy	13400.00
0005434069586	30650	Economy	13400.00
0005434082620	30650	Economy	13400.00
0005434069575	30650	Economy	13400.00
0005433812951	30650	Economy	13400.00
0005432433789	30650	Economy	13400.00
0005434082613	30650	Economy	13400.00
0005434069578	30650	Economy	13400.00
0005434026758	30650	Economy	13400.00
0005434069573	30650	Economy	13400.00
0005434082611	30650	Economy	13400.00
0005434069574	30650	Economy	13400.00
0005433812943	30650	Economy	13400.00
0005433812933	30650	Economy	13400.00
0005434069587	30650	Economy	13400.00
0005433812946	30650	Economy	13400.00
0005434069596	30650	Economy	13400.00
0005432433812	30650	Economy	13400.00
0005434026762	30650	Economy	14800.00
0005433812955	30650	Economy	14800.00
0005434069585	30650	Economy	14800.00
0005434026761	30650	Economy	13400.00
0005433812950	30650	Economy	13400.00
0005434082610	30650	Economy	13400.00
0005434069591	30650	Economy	13400.00
0005433812948	30650	Economy	13400.00
0005434069583	30650	Economy	13400.00
0005434069582	30650	Economy	13400.00
0005433812932	30650	Economy	13400.00
0005434026757	30650	Economy	13400.00
0005432433817	30650	Economy	13400.00
0005432433821	30650	Economy	13400.00
0005434069589	30650	Economy	13400.00
0005432150419	30650	Economy	13400.00
0005434082623	30650	Economy	13400.00
0005434026760	30650	Economy	13400.00
0005433812942	30650	Economy	13400.00
0005434069600	30650	Economy	13400.00
0005433812939	30650	Economy	13400.00
0005434069604	30650	Economy	13400.00
0005434069579	30650	Economy	13400.00
0005433812936	30650	Economy	13400.00
0005434069590	30650	Economy	13400.00
0005434069593	30650	Economy	13400.00
0005434069595	30650	Economy	13400.00
0005434069599	30650	Economy	13400.00
0005434069603	30650	Economy	13400.00
0005434069588	30650	Economy	13400.00
0005432433795	30650	Economy	13400.00
0005434082617	30650	Economy	13400.00
0005434069584	30650	Economy	13400.00
0005434082615	30650	Economy	13400.00
0005434082618	30650	Economy	13400.00
0005434082619	30650	Economy	13400.00
0005434069581	30650	Economy	13400.00
0005434069601	30650	Economy	13400.00
0005434069592	30650	Economy	13400.00
0005434082621	30650	Economy	13400.00
0005433812935	30650	Economy	13400.00
0005433812940	30650	Economy	13400.00
0005434082622	30650	Economy	13400.00
0005434069572	30650	Economy	13400.00
0005434082612	30650	Economy	13400.00
0005434082614	30650	Economy	13400.00
0005434082616	30650	Economy	13400.00
0005432535933	5511	Business	35300.00
0005432535950	5511	Business	35300.00
0005434265674	5511	Business	35300.00
0005435768054	5511	Business	35300.00
0005432535958	5511	Business	35300.00
0005434831254	5511	Business	35300.00
0005435463444	5511	Business	35300.00
0005435463367	5511	Business	35300.00
0005435463231	5511	Business	35300.00
0005435463290	5511	Business	35300.00
0005435735281	5511	Business	35300.00
0005434831255	5511	Business	35300.00
0005434265715	5511	Business	35300.00
0005435463445	5511	Business	35300.00
0005435463180	5511	Business	35300.00
0005435463284	5511	Business	35300.00
0005433529388	5511	Business	35300.00
0005434265680	5511	Economy	12900.00
0005435463124	5511	Economy	12900.00
0005434265689	5511	Economy	12900.00
0005435768058	5511	Economy	11800.00
0005434265704	5511	Economy	11800.00
0005434265713	5511	Economy	11800.00
0005435463292	5511	Economy	11800.00
0005434265658	5511	Economy	11800.00
0005434265664	5511	Economy	11800.00
0005435463123	5511	Economy	11800.00
0005432140684	5511	Economy	11800.00
0005435768056	5511	Economy	11800.00
0005435463356	5511	Economy	11800.00
0005434831240	5511	Economy	11800.00
0005434265648	5511	Economy	11800.00
0005435768119	5511	Economy	11800.00
0005435463328	5511	Economy	11800.00
0005434265805	5511	Economy	11800.00
0005435463282	5511	Economy	11800.00
0005435463357	5511	Economy	11800.00
0005434265576	5511	Economy	11800.00
0005434831253	5511	Economy	11800.00
0005435768049	5511	Economy	11800.00
0005434831241	5511	Economy	11800.00
0005435768120	5511	Economy	11800.00
0005433527374	5511	Economy	11800.00
0005432140683	5511	Economy	11800.00
0005435463297	5511	Economy	11800.00
0005435463438	5511	Economy	11800.00
0005435768051	5511	Economy	11800.00
0005432535935	5511	Economy	11800.00
0005432535934	5511	Economy	11800.00
0005435725738	5511	Economy	11800.00
0005434265640	5511	Economy	11800.00
0005435463402	5511	Economy	11800.00
0005434831250	5511	Economy	11800.00
0005434265749	5511	Economy	11800.00
0005435768047	5511	Economy	11800.00
0005435725737	5511	Economy	11800.00
0005434265823	5511	Economy	11800.00
0005435768045	5511	Economy	11800.00
0005435463269	5511	Economy	11800.00
0005435617181	5511	Economy	11800.00
0005435735275	5511	Economy	11800.00
0005435768048	5511	Economy	11800.00
0005435768057	5511	Economy	11800.00
0005435768050	5511	Economy	11800.00
0005434265725	5511	Economy	11800.00
0005435463314	5511	Economy	11800.00
0005435735280	5511	Economy	11800.00
0005435463313	5511	Economy	11800.00
0005434265678	5511	Economy	11800.00
0005435617184	5511	Economy	11800.00
0005435768046	5511	Economy	11800.00
0005435463162	5511	Economy	11800.00
0005434265714	5511	Economy	11800.00
0005435768043	5511	Economy	12900.00
0005434265659	5511	Economy	11800.00
0005435463350	5511	Economy	11800.00
0005433529389	5511	Economy	11800.00
0005435768041	5511	Economy	12900.00
0005435768042	5511	Economy	12900.00
0005434265613	5511	Economy	11800.00
0005435463439	5511	Economy	11800.00
0005434265683	5511	Economy	11800.00
0005434265806	5511	Economy	11800.00
0005435463423	5511	Economy	11800.00
0005434265724	5511	Economy	11800.00
0005435463276	5511	Economy	11800.00
0005434265727	5511	Economy	11800.00
0005434831246	5511	Economy	11800.00
0005435735274	5511	Economy	11800.00
0005435735282	5511	Economy	11800.00
0005435768044	5511	Economy	11800.00
0005435463285	5511	Economy	11800.00
0005435768052	5511	Economy	11800.00
0005435463213	5511	Economy	11800.00
0005435463229	5511	Economy	11800.00
0005435463161	5511	Economy	11800.00
0005435463136	5511	Economy	11800.00
0005434265705	5511	Economy	11800.00
0005435463366	5511	Economy	11800.00
0005434265690	5511	Economy	11800.00
0005435463125	5511	Economy	11800.00
0005434265701	5511	Economy	11800.00
0005435768121	5511	Economy	11800.00
0005435768060	5511	Economy	11800.00
0005434265684	5511	Economy	11800.00
0005434265688	5511	Economy	11800.00
0005434831251	5511	Economy	11800.00
0005435768053	5511	Economy	11800.00
0005435768061	5511	Economy	11800.00
0005432535956	5511	Economy	11800.00
0005434265657	5511	Economy	11800.00
0005435463228	5511	Economy	11800.00
0005434265627	5511	Economy	11800.00
0005434265619	5511	Economy	11800.00
0005434265597	5511	Economy	11800.00
0005435463349	5511	Economy	11800.00
0005435768059	5511	Economy	11800.00
0005435463170	5511	Economy	11800.00
0005435463270	5511	Economy	11800.00
0005435768055	5511	Economy	11800.00
0005432535951	5511	Economy	11800.00
0005434265669	5511	Economy	11800.00
0005434265728	5511	Economy	11800.00
0005434265682	5511	Economy	11800.00
0005434265681	5511	Economy	11800.00
0005435463227	5511	Economy	11800.00
0005435463141	5511	Economy	11800.00
0005432140685	5511	Economy	11800.00
0005432535975	13490	Business	35300.00
0005435735236	13490	Business	35300.00
0005435767645	13490	Business	35300.00
0005435767622	13490	Business	35300.00
0005435767405	13490	Business	35300.00
0005435767659	13490	Business	35300.00
0005435720157	13490	Business	35300.00
0005435617208	13490	Business	35300.00
0005435767679	13490	Business	35300.00
0005435767617	13490	Business	35300.00
0005435725700	13490	Business	35300.00
0005435767821	13490	Business	35300.00
0005432194635	13490	Business	35300.00
0005435463513	13490	Business	35300.00
0005435463517	13490	Business	35300.00
0005435725677	13490	Business	35300.00
0005435735232	13490	Economy	12900.00
0005435767720	13490	Economy	11800.00
0005434265882	13490	Economy	11800.00
0005434265879	13490	Economy	11800.00
0005435735233	13490	Economy	11800.00
0005435735228	13490	Economy	11800.00
0005435767616	13490	Economy	11800.00
0005435767678	13490	Economy	11800.00
0005435767626	13490	Economy	11800.00
0005435767450	13490	Economy	11800.00
0005435767543	13490	Economy	11800.00
0005435735253	13490	Economy	11800.00
0005435767634	13490	Economy	11800.00
0005435617206	13490	Economy	11800.00
0005435767570	13490	Economy	11800.00
0005435767347	13490	Economy	11800.00
0005435767431	13490	Economy	11800.00
0005435463514	13490	Economy	11800.00
0005435767741	13490	Economy	11800.00
0005435767739	13490	Economy	11800.00
0005435767432	13490	Economy	11800.00
0005435767641	13490	Economy	11800.00
0005435463512	13490	Economy	11800.00
0005435767451	13490	Economy	11800.00
0005435722107	13490	Economy	11800.00
0005435617207	13490	Economy	11800.00
0005435767459	13490	Economy	11800.00
0005434265881	13490	Economy	11800.00
0005435767475	13490	Economy	11800.00
0005435617205	13490	Economy	11800.00
0005435767618	13490	Economy	11800.00
0005434265883	13490	Economy	11800.00
0005435767504	13490	Economy	11800.00
0005432194634	13490	Economy	11800.00
0005435720155	13490	Economy	11800.00
0005435767650	13490	Economy	11800.00
0005435767812	13490	Economy	11800.00
0005435767591	13490	Economy	11800.00
0005435725676	13490	Economy	11800.00
0005435767379	13490	Economy	11800.00
0005435767742	13490	Economy	11800.00
0005434265884	13490	Economy	11800.00
0005435767632	13490	Economy	11800.00
0005435767406	13490	Economy	11800.00
0005435725714	13490	Economy	11800.00
0005435725686	13490	Economy	11800.00
0005435767590	13490	Economy	11800.00
0005435767718	13490	Economy	11800.00
0005435767792	13490	Economy	11800.00
0005435720154	13490	Economy	11800.00
0005435767396	13490	Economy	11800.00
0005432535976	13490	Economy	11800.00
0005435723091	13490	Economy	12900.00
0005435767612	13490	Economy	11800.00
0005435767350	13490	Economy	12900.00
0005435463515	13490	Economy	12900.00
0005435767672	13490	Economy	11800.00
0005435463516	13490	Economy	11800.00
0005435735245	13490	Economy	11800.00
0005435767549	13490	Economy	11800.00
0005434265880	13490	Economy	11800.00
0005435767533	13490	Economy	11800.00
0005435463511	13490	Economy	11800.00
0005435767639	13490	Economy	11800.00
0005435722106	13490	Economy	11800.00
0005435767697	13490	Economy	11800.00
0005435767235	13490	Economy	11800.00
0005435735237	13490	Economy	11800.00
0005435767767	13490	Economy	11800.00
0005435767538	13490	Economy	11800.00
0005435767567	13490	Economy	11800.00
0005435767361	13490	Economy	11800.00
0005435767301	13490	Economy	11800.00
0005435767458	13490	Economy	11800.00
0005435723082	13490	Economy	11800.00
0005435767395	13490	Economy	11800.00
0005435767449	13490	Economy	11800.00
0005435463510	13490	Economy	11800.00
0005435767491	13490	Economy	11800.00
0005435767513	13490	Economy	11800.00
0005435463518	13490	Economy	11800.00
0005435767601	13490	Economy	11800.00
0005435767542	13490	Economy	11800.00
0005435767514	13490	Economy	11800.00
0005435767647	13490	Economy	11800.00
0005435767627	13490	Economy	11800.00
0005435767378	13490	Economy	11800.00
0005435767648	13490	Economy	11800.00
0005435767474	13490	Economy	11800.00
0005435767385	13490	Economy	11800.00
0005435767766	13490	Economy	11800.00
0005434602949	18733	Economy	3300.00
0005434602950	18733	Economy	3300.00
0005434604979	18734	Economy	3300.00
0005434604976	18734	Economy	3300.00
0005434604980	18734	Economy	3300.00
0005434513658	18734	Economy	3300.00
0005434513657	18734	Economy	3300.00
0005435904491	18734	Economy	3300.00
0005434604981	18734	Economy	3300.00
0005434513656	18734	Economy	3300.00
0005434604975	18734	Economy	3300.00
0005434515022	19114	Economy	3300.00
0005434602977	19114	Economy	3300.00
0005434603025	19114	Economy	3300.00
0005434602976	19114	Economy	3300.00
0005434602975	19114	Economy	3300.00
0005434603024	19114	Economy	3300.00
0005432632840	25085	Business	88300.00
0005432649529	25085	Business	88300.00
0005432632838	25085	Business	88300.00
0005435846355	25085	Business	88300.00
0005435844431	25085	Business	88300.00
0005432632853	25085	Business	88300.00
0005435844433	25085	Business	88300.00
0005432649535	25085	Business	88300.00
0005432632856	25085	Business	88300.00
0005435844430	25085	Economy	29400.00
0005432649541	25085	Economy	29400.00
0005432632859	25085	Economy	29400.00
0005435844424	25085	Economy	29400.00
0005432632871	25085	Economy	29400.00
0005432632860	25085	Economy	29400.00
0005432649551	25085	Economy	29400.00
0005432632862	25085	Economy	29400.00
0005432632902	25085	Economy	32400.00
0005432632869	25085	Economy	32400.00
0005432632879	25085	Economy	32400.00
0005432649516	25085	Economy	29400.00
0005435844428	25085	Economy	29400.00
0005432632880	25085	Economy	29400.00
0005432649514	25085	Economy	29400.00
0005432632812	25085	Economy	29400.00
0005432632842	25085	Economy	29400.00
0005432649540	25085	Economy	29400.00
0005435844434	25085	Economy	29400.00
0005435846357	25085	Economy	29400.00
0005435846354	25085	Economy	29400.00
0005432649534	25085	Economy	29400.00
0005432649550	25085	Economy	29400.00
0005432632854	25085	Economy	29400.00
0005435846358	25085	Economy	29400.00
0005432649518	25085	Economy	29400.00
0005435844422	25085	Economy	29400.00
0005435844423	25085	Economy	29400.00
0005432632870	25085	Economy	29400.00
0005432649524	25085	Economy	29400.00
0005432632839	25085	Economy	29400.00
0005432632855	25085	Economy	29400.00
0005432632851	25085	Economy	29400.00
0005432632858	25085	Economy	29400.00
0005432632833	25085	Economy	29400.00
0005435844421	25085	Economy	29400.00
0005435846356	25085	Economy	29400.00
0005435844420	25085	Economy	29400.00
0005435844432	25085	Economy	29400.00
0005432632844	25085	Economy	29400.00
0005432649517	25085	Economy	29400.00
0005432649530	25085	Economy	29400.00
0005432632846	25085	Economy	29400.00
0005432632864	25085	Economy	29400.00
0005432649523	25085	Economy	29400.00
0005435844427	25085	Economy	29400.00
0005432632847	25085	Economy	29400.00
0005432632832	25085	Economy	29400.00
0005435844435	25085	Economy	29400.00
0005432632852	25085	Economy	29400.00
0005432632843	25085	Economy	29400.00
0005432649525	25085	Economy	29400.00
0005435844425	25085	Economy	29400.00
0005432649526	25085	Economy	29400.00
0005432632850	25085	Economy	29400.00
0005432632872	25085	Economy	29400.00
0005435844429	25085	Economy	29400.00
0005435844426	25085	Economy	29400.00
0005433286031	1835	Business	48700.00
0005433286096	1835	Business	48700.00
0005433009577	1835	Business	48700.00
0005433009537	1835	Business	48700.00
0005433286103	1835	Business	48700.00
0005433009723	1835	Business	48700.00
0005433009544	1835	Business	48700.00
0005433009672	1835	Business	48700.00
0005433285892	1835	Business	48700.00
0005433286052	1835	Business	48700.00
0005433009575	1835	Business	48700.00
0005433286001	1835	Business	48700.00
0005433810765	1835	Economy	16200.00
0005432295956	1835	Economy	16200.00
0005433009502	1835	Economy	16200.00
0005433009503	1835	Economy	16200.00
0005433285946	1835	Economy	16200.00
0005433009771	1835	Economy	16200.00
0005433810762	1835	Economy	16200.00
0005433286022	1835	Economy	16200.00
0005433009705	1835	Economy	16200.00
0005433009715	1835	Economy	16200.00
0005433009476	1835	Economy	17900.00
0005432295959	1835	Economy	17900.00
0005433810761	1835	Economy	17900.00
0005432295957	1835	Economy	17900.00
0005433810769	1835	Economy	17900.00
0005433009638	1835	Economy	16200.00
0005433009758	1835	Economy	16200.00
0005433009506	1835	Economy	16200.00
0005433285987	1835	Economy	16200.00
0005433009521	1835	Economy	16200.00
0005433286142	1835	Economy	16200.00
0005433009511	1835	Economy	16200.00
0005433286003	1835	Economy	16200.00
0005433286043	1835	Economy	16200.00
0005433285959	1835	Economy	16200.00
0005433285973	1835	Economy	16200.00
0005433009536	1835	Economy	16200.00
0005433009661	1835	Economy	16200.00
0005433009629	1835	Economy	16200.00
0005433286051	1835	Economy	16200.00
0005433009621	1835	Economy	16200.00
0005433009671	1835	Economy	16200.00
0005433009656	1835	Economy	16200.00
0005433009543	1835	Economy	16200.00
0005433009716	1835	Economy	16200.00
0005433286095	1835	Economy	16200.00
0005433285893	1835	Economy	16200.00
0005433285972	1835	Economy	16200.00
0005433009528	1835	Economy	16200.00
0005433009507	1835	Economy	16200.00
0005433009576	1835	Economy	16200.00
0005433009759	1835	Economy	16200.00
0005433810764	1835	Economy	16200.00
0005433810763	1835	Economy	16200.00
0005433286082	1835	Economy	16200.00
0005433285986	1835	Economy	16200.00
0005433009796	1835	Economy	16200.00
0005433009707	1835	Economy	16200.00
0005433009535	1835	Economy	16200.00
0005433009708	1835	Economy	16200.00
0005433009561	1835	Economy	16200.00
0005433286040	1835	Economy	16200.00
0005433009714	1835	Economy	16200.00
0005433286105	1835	Economy	16200.00
0005433285897	1835	Economy	16200.00
0005433810767	1835	Economy	16200.00
0005433009612	1835	Economy	16200.00
0005433285894	1835	Economy	16200.00
0005433286002	1835	Economy	16200.00
0005433285977	1835	Economy	16200.00
0005433286004	1835	Economy	16200.00
0005433009589	1835	Economy	16200.00
0005433009652	1835	Economy	16200.00
0005433009533	1835	Economy	16200.00
0005433286032	1835	Economy	16200.00
0005433009525	1835	Economy	16200.00
0005433009562	1835	Economy	16200.00
0005433286033	1835	Economy	16200.00
0005433009733	1835	Economy	16200.00
0005433009706	1835	Economy	16200.00
0005433286156	1835	Economy	16200.00
0005433810768	1835	Economy	16200.00
0005433285942	1835	Economy	16200.00
0005433009475	1835	Economy	16200.00
0005433286104	1835	Economy	16200.00
0005433009604	1835	Economy	16200.00
0005432295958	1835	Economy	16200.00
0005433285873	1835	Economy	16200.00
0005433009743	1835	Economy	16200.00
0005433009477	1835	Economy	16200.00
0005433285976	1835	Economy	16200.00
0005433009659	1835	Economy	16200.00
0005433810766	1835	Economy	16200.00
0005433009534	1835	Economy	16200.00
0005433009630	1835	Economy	16200.00
0005433286197	22556	Business	48700.00
0005433286193	22556	Business	48700.00
0005433810643	22556	Business	48700.00
0005433009934	22556	Business	48700.00
0005433009939	22556	Business	48700.00
0005433009929	22556	Business	48700.00
0005433286194	22556	Economy	16200.00
0005433286188	22556	Economy	16200.00
0005433009936	22556	Economy	16200.00
0005433009937	22556	Economy	16200.00
0005433009942	22556	Economy	17900.00
0005433009935	22556	Economy	16200.00
0005433009920	22556	Economy	16200.00
0005433286191	22556	Economy	16200.00
0005433009933	22556	Economy	16200.00
0005433286190	22556	Economy	16200.00
0005433810639	22556	Economy	16200.00
0005433009941	22556	Economy	16200.00
0005433009927	22556	Economy	16200.00
0005433810627	22556	Economy	16200.00
0005433286198	22556	Economy	16200.00
0005433810621	22556	Economy	16200.00
0005433286196	22556	Economy	16200.00
0005433009940	22556	Economy	16200.00
0005433810637	22556	Economy	16200.00
0005433009928	22556	Economy	16200.00
0005433009918	22556	Economy	16200.00
0005433009924	22556	Economy	16200.00
0005433286199	22556	Economy	16200.00
0005433009930	22556	Economy	16200.00
0005433810653	22556	Economy	16200.00
0005433009919	22556	Economy	16200.00
0005433009917	22556	Economy	16200.00
0005433286200	22556	Economy	16200.00
0005433009925	22556	Economy	16200.00
0005433009932	22556	Economy	16200.00
0005433009926	22556	Economy	16200.00
0005433810642	22556	Economy	16200.00
0005433009921	22556	Economy	16200.00
0005433286192	22556	Economy	16200.00
0005433009922	22556	Economy	16200.00
0005433009923	22556	Economy	16200.00
0005433286189	22556	Economy	16200.00
0005433810647	22556	Economy	16200.00
0005433286195	22556	Economy	16200.00
0005433009938	22556	Economy	16200.00
0005433009931	22556	Economy	16200.00
0005433810632	22556	Economy	16200.00
0005435282970	5601	Business	99800.00
0005435283064	5601	Business	99800.00
0005435283076	5601	Business	99800.00
0005433848391	5601	Business	99800.00
0005433848385	5601	Business	99800.00
0005433848377	5601	Business	99800.00
0005433848382	5601	Business	99800.00
0005433848383	5601	Business	99800.00
0005433848386	5601	Business	99800.00
0005435283096	5601	Business	99800.00
0005433848380	5601	Business	99800.00
0005433848393	5601	Business	99800.00
0005435283067	5601	Business	99800.00
0005435282987	5601	Economy	33300.00
0005435282969	5601	Economy	33300.00
0005433848390	5601	Economy	33300.00
0005433848388	5601	Economy	33300.00
0005435283177	5601	Economy	33300.00
0005433848389	5601	Economy	33300.00
0005435283063	5601	Economy	33300.00
0005434173619	5601	Economy	33300.00
0005435283079	5601	Economy	33300.00
0005435283134	5601	Economy	36600.00
0005433848381	5601	Economy	33300.00
0005433848378	5601	Economy	33300.00
0005434173600	5601	Economy	33300.00
0005435282983	5601	Economy	33300.00
0005433815525	5601	Economy	33300.00
0005435282930	5601	Economy	33300.00
0005435283072	5601	Economy	33300.00
0005435283095	5601	Economy	33300.00
0005434173601	5601	Economy	33300.00
0005433848387	5601	Economy	33300.00
0005433848376	5601	Economy	33300.00
0005435283077	5601	Economy	33300.00
0005434173620	5601	Economy	33300.00
0005435283075	5601	Economy	33300.00
0005435282971	5601	Economy	33300.00
0005435283068	5601	Economy	33300.00
0005435282922	5601	Economy	33300.00
0005435282921	5601	Economy	33300.00
0005434173581	5601	Economy	33300.00
0005433848384	5601	Economy	33300.00
0005435283132	5601	Economy	33300.00
0005433815524	5601	Economy	33300.00
0005435283108	5601	Economy	33300.00
0005435282962	5601	Economy	33300.00
0005433815562	5601	Economy	33300.00
0005435283049	5601	Economy	33300.00
0005435283100	5601	Economy	33300.00
0005435283097	5601	Economy	33300.00
0005433848392	5601	Economy	33300.00
0005435283069	5601	Economy	33300.00
0005435283078	5601	Economy	33300.00
0005435283099	5601	Economy	33300.00
0005433848379	5601	Economy	33300.00
0005433815522	5601	Economy	33300.00
0005435283080	5601	Economy	33300.00
0005434173602	5601	Economy	33300.00
0005434173580	5601	Economy	33300.00
0005435282961	5601	Economy	33300.00
0005435283107	5601	Economy	33300.00
0005435283176	5601	Economy	33300.00
0005433815526	5601	Economy	33300.00
0005433815523	5601	Economy	33300.00
0005435282986	5601	Economy	33300.00
0005433848394	5601	Economy	33300.00
0005433848165	13881	Business	99800.00
0005433848004	13881	Business	99800.00
0005433847899	13881	Business	99800.00
0005433847989	13881	Business	99800.00
0005435283244	13881	Business	99800.00
0005433848222	13881	Business	99800.00
0005434173665	13881	Business	99800.00
0005433847900	13881	Business	99800.00
0005433847777	13881	Business	99800.00
0005433847997	13881	Business	99800.00
0005433848093	13881	Business	99800.00
0005435283235	13881	Business	99800.00
0005435283236	13881	Business	99800.00
0005435283238	13881	Business	99800.00
0005433815484	13881	Economy	33300.00
0005433847892	13881	Economy	33300.00
0005433848255	13881	Economy	33300.00
0005433848001	13881	Economy	33300.00
0005433847969	13881	Economy	33300.00
0005433847968	13881	Economy	33300.00
0005435283243	13881	Economy	33300.00
0005433848253	13881	Economy	33300.00
0005433848083	13881	Economy	33300.00
0005433847830	13881	Economy	33300.00
0005433848230	13881	Economy	36600.00
0005433848033	13881	Economy	36600.00
0005433847608	13881	Economy	36600.00
0005433848032	13881	Economy	36600.00
0005432003794	13881	Economy	33300.00
0005432003795	13881	Economy	33300.00
0005433847891	13881	Economy	33300.00
0005435283242	13881	Economy	33300.00
0005433815488	13881	Economy	33300.00
0005433848235	13881	Economy	33300.00
0005433847783	13881	Economy	33300.00
0005433847782	13881	Economy	33300.00
0005433847912	13881	Economy	33300.00
0005433847995	13881	Economy	33300.00
0005433848143	13881	Economy	33300.00
0005435283241	13881	Economy	33300.00
0005435283233	13881	Economy	33300.00
0005433848040	13881	Economy	33300.00
0005433847784	13881	Economy	33300.00
0005433847893	13881	Economy	33300.00
0005432003796	13881	Economy	33300.00
0005433847877	13881	Economy	33300.00
0005435283231	13881	Economy	33300.00
0005433847790	13881	Economy	33300.00
0005433847990	13881	Economy	33300.00
0005435283240	13881	Economy	33300.00
0005435283234	13881	Economy	33300.00
0005433848026	13881	Economy	33300.00
0005435283230	13881	Economy	33300.00
0005433815483	13881	Economy	33300.00
0005433848188	13881	Economy	33300.00
0005433848240	13881	Economy	33300.00
0005433848234	13881	Economy	33300.00
0005433847871	13881	Economy	33300.00
0005433848187	13881	Economy	33300.00
0005433848081	13881	Economy	33300.00
0005433847716	13881	Economy	33300.00
0005433847996	13881	Economy	33300.00
0005433848002	13881	Economy	33300.00
0005435283237	13881	Economy	33300.00
0005433847970	13881	Economy	33300.00
0005435283232	13881	Economy	33300.00
0005433847829	13881	Economy	33300.00
0005433847994	13881	Economy	33300.00
0005433848183	13881	Economy	33300.00
0005434173666	13881	Economy	33300.00
0005433815478	13881	Economy	33300.00
0005433848039	13881	Economy	33300.00
0005433848164	13881	Economy	33300.00
0005433848244	13881	Economy	33300.00
0005433848084	13881	Economy	33300.00
0005435283239	13881	Economy	33300.00
0005435283229	13881	Economy	33300.00
0005433847979	13881	Economy	33300.00
0005433848038	13881	Economy	33300.00
0005433847859	13881	Economy	33300.00
0005433847896	13881	Economy	33300.00
0005433848007	13881	Economy	33300.00
0005434621175	7835	Economy	16600.00
0005434621176	7835	Economy	15100.00
0005434621173	7835	Economy	15100.00
0005434621179	7835	Economy	15100.00
0005435332571	7835	Economy	15100.00
0005434621177	7835	Economy	15100.00
0005434621178	7835	Economy	15100.00
0005434621172	7835	Economy	15100.00
0005434621174	7835	Economy	15100.00
0005435332598	7835	Economy	15100.00
0005434621086	32939	Economy	16600.00
0005434621058	32939	Economy	16600.00
0005434621014	32939	Economy	15100.00
0005434621023	32939	Economy	15100.00
0005434620916	32939	Economy	15100.00
0005434621042	32939	Economy	15100.00
0005434621015	32939	Economy	15100.00
0005434621088	32939	Economy	15100.00
0005434621059	32939	Economy	15100.00
0005434621045	32939	Economy	15100.00
0005435332634	32939	Economy	15100.00
0005434621027	32939	Economy	15100.00
0005434621030	32939	Economy	15100.00
0005434621028	32939	Economy	15100.00
0005434621039	32939	Economy	15100.00
0005434621024	32939	Economy	15100.00
0005434621065	32939	Economy	15100.00
0005434621029	32939	Economy	15100.00
0005434620999	32939	Economy	15100.00
0005434621016	32939	Economy	15100.00
0005435332633	32939	Economy	15100.00
0005434621041	32939	Economy	15100.00
0005434621061	32939	Economy	15100.00
0005434620998	32939	Economy	15100.00
0005434621037	32939	Economy	15100.00
0005434621040	32939	Economy	15100.00
0005434621031	32939	Economy	15100.00
0005434621060	32939	Economy	15100.00
0005435332635	32939	Economy	15100.00
0005434620915	32939	Economy	15100.00
0005434620920	32939	Economy	15100.00
0005434621066	32939	Economy	15100.00
0005435787415	4291	Business	38000.00
0005435918773	4291	Business	38000.00
0005435786341	4291	Business	38000.00
0005435786345	4291	Economy	12700.00
0005435787413	4291	Economy	13900.00
0005435937495	4291	Economy	13900.00
0005434994304	4291	Economy	13900.00
0005435937484	4291	Economy	12700.00
0005435937485	4291	Economy	12700.00
0005435937492	4291	Economy	12700.00
0005435937489	4291	Economy	12700.00
0005435937512	4291	Economy	12700.00
0005434994303	4291	Economy	12700.00
0005435786344	4291	Economy	12700.00
0005435937500	4291	Economy	12700.00
0005435786343	4291	Economy	12700.00
0005435918766	4291	Economy	12700.00
0005435786342	4291	Economy	12700.00
0005435786340	4291	Economy	12700.00
0005435918774	4291	Economy	12700.00
0005435787414	4291	Economy	12700.00
0005435786346	4291	Economy	12700.00
0005435918772	4291	Economy	12700.00
0005435786047	27274	Business	38000.00
0005435937566	27274	Business	38000.00
0005435786001	27274	Business	38000.00
0005434994232	27274	Business	38000.00
0005435785958	27274	Business	38000.00
0005435785966	27274	Business	38000.00
0005435786089	27274	Business	38000.00
0005435786049	27274	Business	38000.00
0005434994234	27274	Business	38000.00
0005435785967	27274	Business	38000.00
0005435937562	27274	Economy	12700.00
0005435785919	27274	Economy	12700.00
0005435785959	27274	Economy	12700.00
0005435786073	27274	Economy	13900.00
0005435786048	27274	Economy	13900.00
0005435785999	27274	Economy	13900.00
0005435786056	27274	Economy	13900.00
0005435937565	27274	Economy	12700.00
0005435786006	27274	Economy	12700.00
0005435937559	27274	Economy	12700.00
0005435937564	27274	Economy	12700.00
0005435786074	27274	Economy	12700.00
0005435786205	27274	Economy	12700.00
0005435786005	27274	Economy	12700.00
0005434994235	27274	Economy	12700.00
0005435786098	27274	Economy	12700.00
0005435937563	27274	Economy	12700.00
0005435937560	27274	Economy	12700.00
0005435937558	27274	Economy	12700.00
0005435786044	27274	Economy	12700.00
0005435785934	27274	Economy	12700.00
0005434994261	27274	Economy	12700.00
0005435786200	27274	Economy	12700.00
0005434994243	27274	Economy	12700.00
0005435786083	27274	Economy	12700.00
0005435786045	27274	Economy	12700.00
0005435786201	27274	Economy	12700.00
0005435983727	27274	Economy	12700.00
0005435786140	27274	Economy	12700.00
0005435786031	27274	Economy	12700.00
0005435785965	27274	Economy	12700.00
0005434994265	27274	Economy	12700.00
0005435785969	27274	Economy	12700.00
0005434994236	27274	Economy	12700.00
0005435785933	27274	Economy	12700.00
0005434994202	27274	Economy	12700.00
0005435983728	27274	Economy	12700.00
0005435785970	27274	Economy	12700.00
0005435786117	27274	Economy	12700.00
0005435786042	27274	Economy	12700.00
0005434994231	27274	Economy	12700.00
0005435937561	27274	Economy	12700.00
0005435786133	27274	Economy	12700.00
0005435786144	27274	Economy	12700.00
0005432146258	19903	Economy	14000.00
0005432461366	4750	Business	40900.00
0005434082627	4750	Business	40900.00
0005432461371	4750	Business	40900.00
0005432461378	4750	Business	40900.00
0005434559189	4750	Business	40900.00
0005432461376	4750	Business	40900.00
0005432569376	4750	Business	40900.00
0005432461363	4750	Business	40900.00
0005432461372	4750	Business	40900.00
0005432461386	4750	Business	40900.00
0005432461365	4750	Business	40900.00
0005435840420	4750	Business	40900.00
0005432170583	4750	Business	40900.00
0005432461361	4750	Business	40900.00
0005434082624	4750	Business	40900.00
0005435840426	4750	Economy	15000.00
0005432170584	4750	Economy	15000.00
0005432569386	4750	Economy	15000.00
0005432569380	4750	Economy	13600.00
0005435840419	4750	Economy	13600.00
0005432569387	4750	Economy	13600.00
0005432461367	4750	Economy	13600.00
0005432461389	4750	Economy	13600.00
0005432461377	4750	Economy	13600.00
0005432461374	4750	Economy	13600.00
0005432569382	4750	Economy	13600.00
0005434082633	4750	Economy	13600.00
0005432461387	4750	Economy	13600.00
0005435840427	4750	Economy	13600.00
0005434559187	4750	Economy	13600.00
0005432461370	4750	Economy	13600.00
0005432461383	4750	Economy	13600.00
0005434082632	4750	Economy	13600.00
0005435840404	4750	Economy	13600.00
0005435840411	4750	Economy	13600.00
0005434082628	4750	Economy	13600.00
0005434082630	4750	Economy	13600.00
0005435840403	4750	Economy	13600.00
0005432569394	4750	Economy	13600.00
0005432461388	4750	Economy	13600.00
0005432569378	4750	Economy	13600.00
0005432569377	4750	Economy	13600.00
0005434559185	4750	Economy	13600.00
0005432569390	4750	Economy	13600.00
0005432569392	4750	Economy	13600.00
0005435840372	4750	Economy	13600.00
0005434082626	4750	Economy	13600.00
0005435840412	4750	Economy	13600.00
0005432461385	4750	Economy	13600.00
0005432569383	4750	Economy	13600.00
0005435840449	4750	Economy	13600.00
0005432461379	4750	Economy	13600.00
0005432461392	4750	Economy	13600.00
0005433451676	4750	Economy	15000.00
0005432461364	4750	Economy	15000.00
0005432461384	4750	Economy	13600.00
0005432569384	4750	Economy	13600.00
0005432569395	4750	Economy	13600.00
0005432569381	4750	Economy	13600.00
0005434559190	4750	Economy	13600.00
0005432569396	4750	Economy	13600.00
0005432461380	4750	Economy	13600.00
0005432461369	4750	Economy	13600.00
0005432569389	4750	Economy	13600.00
0005432569391	4750	Economy	13600.00
0005432461391	4750	Economy	13600.00
0005432170582	4750	Economy	13600.00
0005432569393	4750	Economy	13600.00
0005432569379	4750	Economy	13600.00
0005432461381	4750	Economy	13600.00
0005435840418	4750	Economy	13600.00
0005434082625	4750	Economy	13600.00
0005432461375	4750	Economy	13600.00
0005432569388	4750	Economy	13600.00
0005434082629	4750	Economy	13600.00
0005434559188	4750	Economy	13600.00
0005432569385	4750	Economy	13600.00
0005432571434	4750	Economy	13600.00
0005432461390	4750	Economy	13600.00
0005434559186	4750	Economy	13600.00
0005432461373	4750	Economy	13600.00
0005434082631	4750	Economy	13600.00
0005435840410	4750	Economy	13600.00
0005432461382	4750	Economy	13600.00
0005432461362	4750	Economy	13600.00
0005432461368	4750	Economy	13600.00
0005434559184	4750	Economy	13600.00
0005432170585	4750	Economy	13600.00
0005434150212	30557	Business	40900.00
0005432460969	30557	Business	40900.00
0005432569085	30557	Business	40900.00
0005432569086	30557	Business	40900.00
0005434082537	30557	Business	40900.00
0005432461286	30557	Business	40900.00
0005432568819	30557	Business	40900.00
0005432461007	30557	Business	40900.00
0005432568997	30557	Business	40900.00
0005432460992	30557	Business	40900.00
0005432569010	30557	Business	40900.00
0005434082287	30557	Business	40900.00
0005432461215	30557	Business	40900.00
0005432461001	30557	Business	40900.00
0005434150205	30557	Business	40900.00
0005432571397	30557	Business	40900.00
0005435840524	30557	Business	40900.00
0005432568977	30557	Business	40900.00
0005434150207	30557	Business	40900.00
0005435840531	30557	Business	40900.00
0005432460880	30557	Business	40900.00
0005432569096	30557	Business	40900.00
0005434082368	30557	Business	40900.00
0005434082426	30557	Business	40900.00
0005432460925	30557	Business	40900.00
0005432569063	30557	Business	40900.00
0005432569009	30557	Economy	15000.00
0005432461162	30557	Economy	15000.00
0005432568829	30557	Economy	15000.00
0005435860637	30557	Economy	15000.00
0005435840526	30557	Economy	13600.00
0005434082418	30557	Economy	13600.00
0005432568986	30557	Economy	13600.00
0005432569038	30557	Economy	13600.00
0005432461079	30557	Economy	13600.00
0005432569073	30557	Economy	13600.00
0005434150211	30557	Economy	13600.00
0005432568662	30557	Economy	13600.00
0005432460869	30557	Economy	13600.00
0005432569232	30557	Economy	13600.00
0005432568804	30557	Economy	13600.00
0005435840529	30557	Economy	13600.00
0005432461091	30557	Economy	13600.00
0005432569012	30557	Economy	13600.00
0005434150210	30557	Economy	13600.00
0005435840525	30557	Economy	13600.00
0005432569083	30557	Economy	13600.00
0005432568987	30557	Economy	13600.00
0005432461028	30557	Economy	13600.00
0005432569028	30557	Economy	13600.00
0005432461042	30557	Economy	13600.00
0005434082351	30557	Economy	13600.00
0005432460915	30557	Economy	13600.00
0005432460996	30557	Economy	13600.00
0005432569239	30557	Economy	13600.00
0005432460998	30557	Economy	13600.00
0005432461140	30557	Economy	13600.00
0005434082536	30557	Economy	13600.00
0005433454921	30557	Economy	13600.00
0005434082461	30557	Economy	13600.00
0005432568984	30557	Economy	13600.00
0005434082405	30557	Economy	13600.00
0005432461004	30557	Economy	13600.00
0005432460997	30557	Economy	13600.00
0005432568860	30557	Economy	13600.00
0005432569178	30557	Economy	13600.00
0005435860638	30557	Economy	13600.00
0005434082334	30557	Economy	13600.00
0005434082434	30557	Economy	13600.00
0005432568985	30557	Economy	13600.00
0005432569103	30557	Economy	13600.00
0005434150209	30557	Economy	13600.00
0005432568663	30557	Economy	13600.00
0005432460870	30557	Economy	13600.00
0005434082414	30557	Economy	13600.00
0005434082333	30557	Economy	13600.00
0005434150214	30557	Economy	13600.00
0005432461189	30557	Economy	13600.00
0005432568820	30557	Economy	13600.00
0005434082451	30557	Economy	13600.00
0005432571413	30557	Economy	13600.00
0005432569179	30557	Economy	13600.00
0005432461188	30557	Economy	13600.00
0005432461145	30557	Economy	13600.00
0005434082411	30557	Economy	13600.00
0005434082419	30557	Economy	13600.00
0005432460866	30557	Economy	13600.00
0005432568828	30557	Economy	13600.00
0005432461027	30557	Economy	13600.00
0005432460916	30557	Economy	13600.00
0005433454922	30557	Economy	13600.00
0005434150206	30557	Economy	13600.00
0005434082460	30557	Economy	13600.00
0005434150204	30557	Economy	13600.00
0005434082371	30557	Economy	13600.00
0005434082365	30557	Economy	13600.00
0005432568971	30557	Economy	13600.00
0005432569233	30557	Economy	13600.00
0005433454917	30557	Economy	13600.00
0005432461000	30557	Economy	13600.00
0005432461080	30557	Economy	13600.00
0005432568983	30557	Economy	13600.00
0005432571410	30557	Economy	13600.00
0005434082305	30557	Economy	13600.00
0005432568873	30557	Economy	13600.00
0005432569071	30557	Economy	13600.00
0005432460985	30557	Economy	13600.00
0005432569029	30557	Economy	13600.00
0005432461099	30557	Economy	13600.00
0005434082433	30557	Economy	15000.00
0005432569159	30557	Economy	13600.00
0005435960176	30557	Economy	13600.00
0005432569008	30557	Economy	13600.00
0005432569013	30557	Economy	15000.00
0005434082452	30557	Economy	13600.00
0005432569055	30557	Economy	13600.00
0005432460841	30557	Economy	13600.00
0005432569247	30557	Economy	13600.00
0005432569097	30557	Economy	13600.00
0005432569039	30557	Economy	13600.00
0005432571414	30557	Economy	13600.00
0005432461161	30557	Economy	13600.00
0005434082279	30557	Economy	13600.00
0005432460979	30557	Economy	13600.00
0005432568925	30557	Economy	13600.00
0005432568970	30557	Economy	13600.00
0005432568802	30557	Economy	13600.00
0005432568995	30557	Economy	13600.00
0005432568888	30557	Economy	13600.00
0005432569064	30557	Economy	13600.00
0005434150213	30557	Economy	13600.00
0005432568590	30557	Economy	13600.00
0005432461214	30557	Economy	13600.00
0005432569113	30557	Economy	13600.00
0005432461139	30557	Economy	13600.00
0005435840522	30557	Economy	13600.00
0005432461186	30557	Economy	13600.00
0005434082317	30557	Economy	13600.00
0005435840523	30557	Economy	13600.00
0005432568861	30557	Economy	13600.00
0005434082391	30557	Economy	13600.00
0005432569137	30557	Economy	13600.00
0005435840530	30557	Economy	13600.00
0005434150208	30557	Economy	13600.00
0005432568872	30557	Economy	13600.00
0005434082288	30557	Economy	13600.00
0005434082344	30557	Economy	13600.00
0005432461012	30557	Economy	13600.00
0005434082427	30557	Economy	13600.00
0005432568889	30557	Economy	13600.00
0005435840527	30557	Economy	13600.00
0005432460766	30557	Economy	13600.00
0005434082440	30557	Economy	13600.00
0005432461029	30557	Economy	13600.00
0005432461269	30557	Economy	13600.00
0005434082350	30557	Economy	13600.00
0005432460881	30557	Economy	13600.00
0005432460980	30557	Economy	13600.00
0005434082367	30557	Economy	13600.00
0005435840528	30557	Economy	13600.00
0005434082280	30557	Economy	13600.00
0005432461182	30557	Economy	13600.00
0005432568982	30557	Economy	13600.00
0005432461181	30557	Economy	13600.00
0005434082462	30557	Economy	13600.00
0005432568978	30557	Economy	13600.00
0005432569084	30557	Economy	13600.00
0005432569182	30557	Economy	13600.00
0005434082416	30557	Economy	13600.00
0005434082364	30557	Economy	13600.00
0005432568664	30557	Economy	13600.00
0005434082417	30557	Economy	13600.00
0005432569190	30557	Economy	13600.00
0005432569240	30557	Economy	13600.00
0005432568591	30557	Economy	13600.00
0005434082422	30557	Economy	13600.00
0005432460999	30557	Economy	13600.00
0005432571412	30557	Economy	13600.00
0005432569248	30557	Economy	13600.00
0005435722098	21159	Economy	9900.00
0005435722097	21159	Economy	9900.00
0005435722096	21159	Economy	9900.00
0005435720158	21159	Economy	9900.00
0005435720156	21159	Economy	9900.00
0005432295959	22780	Economy	9700.00
0005432295956	22780	Economy	8800.00
0005432295958	22780	Economy	8800.00
0005432295957	22780	Economy	8800.00
0005435508645	11082	Business	23600.00
0005435508550	11082	Business	23600.00
0005435508744	11082	Business	23600.00
0005433346042	11082	Business	23600.00
0005433346035	11082	Business	23600.00
0005433346027	11082	Business	23600.00
0005435380372	11082	Business	23600.00
0005433346031	11082	Business	23600.00
0005433346020	11082	Economy	7900.00
0005435530038	11082	Economy	7900.00
0005435508712	11082	Economy	7900.00
0005435508655	11082	Economy	7900.00
0005435530061	11082	Economy	7900.00
0005433346023	11082	Economy	7900.00
0005433346009	11082	Economy	7900.00
0005435530111	11082	Economy	7900.00
0005435508619	11082	Economy	7900.00
0005435530083	11082	Economy	7900.00
0005433346029	11082	Economy	7900.00
0005433346039	11082	Economy	7900.00
0005435529996	11082	Economy	7900.00
0005433346019	11082	Economy	7900.00
0005433346028	11082	Economy	7900.00
0005435380403	11082	Economy	7900.00
0005435530029	11082	Economy	7900.00
0005433346038	11082	Economy	7900.00
0005435530033	11082	Economy	7900.00
0005435530051	11082	Economy	7900.00
0005435508701	11082	Economy	7900.00
0005435530058	11082	Economy	7900.00
0005433346014	11082	Economy	7900.00
0005433346032	11082	Economy	7900.00
0005435530002	11082	Economy	7900.00
0005433346022	11082	Economy	7900.00
0005435380398	11082	Economy	7900.00
0005435530005	11082	Economy	7900.00
0005433346043	11082	Economy	7900.00
0005433346015	11082	Economy	7900.00
0005433346010	11082	Economy	7900.00
0005433346012	11082	Economy	8600.00
0005433346041	11082	Economy	8600.00
0005433346044	11082	Economy	8600.00
0005433346024	11082	Economy	7900.00
0005433346013	11082	Economy	7900.00
0005433346040	11082	Economy	7900.00
0005435097491	11082	Economy	7900.00
0005433346025	11082	Economy	7900.00
0005435508618	11082	Economy	7900.00
0005433346018	11082	Economy	7900.00
0005435508646	11082	Economy	7900.00
0005435530109	11082	Economy	7900.00
0005433346030	11082	Economy	7900.00
0005435380413	11082	Economy	7900.00
0005435530040	11082	Economy	7900.00
0005435529995	11082	Economy	7900.00
0005435508733	11082	Economy	7900.00
0005433346036	11082	Economy	7900.00
0005435530108	11082	Economy	7900.00
0005435097492	11082	Economy	7900.00
0005433346021	11082	Economy	7900.00
0005435508711	11082	Economy	7900.00
0005433346033	11082	Economy	7900.00
0005435508662	11082	Economy	7900.00
0005433346037	11082	Economy	7900.00
0005435508654	11082	Economy	7900.00
0005435508652	11082	Economy	7900.00
0005435530035	11082	Economy	7900.00
0005435380399	11082	Economy	7900.00
0005435530081	11082	Economy	7900.00
0005435530059	11082	Economy	7900.00
0005435508702	11082	Economy	7900.00
0005435530045	11082	Economy	7900.00
0005435508659	11082	Economy	7900.00
0005433346017	11082	Economy	7900.00
0005435530063	11082	Economy	7900.00
0005435508609	11082	Economy	7900.00
0005435530034	11082	Economy	7900.00
0005435530110	11082	Economy	7900.00
0005433346011	11082	Economy	7900.00
0005433346026	11082	Economy	7900.00
0005435530021	11082	Economy	7900.00
0005435530060	11082	Economy	7900.00
0005435508700	11082	Economy	7900.00
0005433346016	11082	Economy	7900.00
0005433346034	11082	Economy	7900.00
0005435508663	11082	Economy	7900.00
0005435530082	11082	Economy	7900.00
0005435529999	11082	Economy	7900.00
0005435380412	11082	Economy	7900.00
0005435508588	11082	Economy	7900.00
0005435530001	11082	Economy	7900.00
0005433345251	17117	Business	23600.00
0005433345061	17117	Business	23600.00
0005433345138	17117	Business	23600.00
0005433345312	17117	Business	23600.00
0005433345137	17117	Business	23600.00
0005433345274	17117	Business	23600.00
0005433345107	17117	Business	23600.00
0005435545993	17117	Business	23600.00
0005433345311	17117	Business	23600.00
0005433345286	17117	Business	23600.00
0005433345313	17117	Business	23600.00
0005433344926	17117	Business	23600.00
0005435097373	17117	Economy	7900.00
0005435097431	17117	Economy	7900.00
0005433345578	17117	Economy	7900.00
0005433345303	17117	Economy	7900.00
0005433345394	17117	Economy	7900.00
0005433344744	17117	Economy	7900.00
0005433345613	17117	Economy	7900.00
0005433345025	17117	Economy	7900.00
0005435545960	17117	Economy	7900.00
0005435545959	17117	Economy	7900.00
0005433344919	17117	Economy	7900.00
0005433345297	17117	Economy	7900.00
0005435545994	17117	Economy	7900.00
0005433345109	17117	Economy	7900.00
0005433345296	17117	Economy	7900.00
0005433344918	17117	Economy	7900.00
0005433345080	17117	Economy	7900.00
0005435097438	17117	Economy	7900.00
0005435097385	17117	Economy	7900.00
0005433345304	17117	Economy	7900.00
0005433345093	17117	Economy	7900.00
0005433345550	17117	Economy	7900.00
0005433345155	17117	Economy	7900.00
0005433345706	17117	Economy	7900.00
0005433345390	17117	Economy	7900.00
0005435546226	17117	Economy	7900.00
0005433344908	17117	Economy	7900.00
0005433345170	17117	Economy	7900.00
0005433345436	17117	Economy	7900.00
0005433345606	17117	Economy	7900.00
0005433345235	17117	Economy	7900.00
0005433345073	17117	Economy	7900.00
0005433345447	17117	Economy	7900.00
0005433345504	17117	Economy	7900.00
0005433345364	17117	Economy	7900.00
0005433345446	17117	Economy	7900.00
0005433345230	17117	Economy	7900.00
0005435097416	17117	Economy	7900.00
0005435545962	17117	Economy	7900.00
0005433345780	17117	Economy	8600.00
0005433345294	17117	Economy	8600.00
0005435545992	17117	Economy	8600.00
0005433345226	17117	Economy	8600.00
0005433345197	17117	Economy	8600.00
0005433344990	17117	Economy	8600.00
0005433345098	17117	Economy	7900.00
0005433345144	17117	Economy	7900.00
0005435097417	17117	Economy	7900.00
0005433344784	17117	Economy	7900.00
0005433345090	17117	Economy	7900.00
0005433345295	17117	Economy	7900.00
0005433345185	17117	Economy	7900.00
0005433345009	17117	Economy	7900.00
0005433345250	17117	Economy	7900.00
0005433345612	17117	Economy	7900.00
0005433345377	17117	Economy	7900.00
0005435097383	17117	Economy	7900.00
0005435545961	17117	Economy	7900.00
0005433345425	17117	Economy	7900.00
0005433345231	17117	Economy	7900.00
0005433345386	17117	Economy	7900.00
0005433344768	17117	Economy	7900.00
0005435545965	17117	Economy	7900.00
0005433345246	17117	Economy	7900.00
0005433345198	17117	Economy	7900.00
0005433345324	17117	Economy	7900.00
0005435546228	17117	Economy	7900.00
0005433345108	17117	Economy	7900.00
0005433345516	17117	Economy	7900.00
0005433345387	17117	Economy	7900.00
0005433345161	17117	Economy	7900.00
0005433345383	17117	Economy	7900.00
0005433345385	17117	Economy	7900.00
0005433344862	17117	Economy	7900.00
0005433345207	17117	Economy	7900.00
0005433345437	17117	Economy	7900.00
0005433345072	17117	Economy	7900.00
0005433344972	17117	Economy	7900.00
0005435545964	17117	Economy	7900.00
0005435097415	17117	Economy	7900.00
0005435097356	17117	Economy	7900.00
0005433345644	17117	Economy	7900.00
0005435546227	17117	Economy	7900.00
0005433345053	17117	Economy	7900.00
0005435546224	17117	Economy	7900.00
0005435546225	17117	Economy	7900.00
0005433345149	17117	Economy	7900.00
0005433345422	17117	Economy	7900.00
0005433345560	17117	Economy	7900.00
0005433345206	17117	Economy	7900.00
0005433345512	17117	Economy	7900.00
0005433345604	17117	Economy	7900.00
0005435097390	17117	Economy	7900.00
0005433345283	17117	Economy	7900.00
0005433345163	17117	Economy	7900.00
0005433345459	17117	Economy	7900.00
0005433345426	17117	Economy	7900.00
0005433345148	17117	Economy	7900.00
0005433344980	17117	Economy	7900.00
0005435545963	17117	Economy	7900.00
0005433345441	17117	Economy	7900.00
0005433345299	17117	Economy	7900.00
0005433345150	17117	Economy	7900.00
0005435097384	17117	Economy	7900.00
0005433345468	17117	Economy	7900.00
0005433345095	17117	Economy	7900.00
0005433344912	17117	Economy	7900.00
0005435380441	17117	Economy	7900.00
0005435097372	17117	Economy	7900.00
0005433345300	17117	Economy	7900.00
0005433345373	17117	Economy	7900.00
0005433345338	17117	Economy	7900.00
0005433345683	17117	Economy	7900.00
0005433345156	17117	Economy	7900.00
0005433345505	17117	Economy	7900.00
0005433345273	17117	Economy	7900.00
0005433344927	17117	Economy	7900.00
0005433507718	9107	Business	26600.00
0005433477277	9107	Business	26600.00
0005433477280	9107	Business	26600.00
0005432920311	9107	Business	26600.00
0005433507713	9107	Business	26600.00
0005432920252	9107	Business	26600.00
0005433477283	9107	Business	26600.00
0005432920366	9107	Economy	8900.00
0005433507717	9107	Economy	8900.00
0005432920385	9107	Economy	8900.00
0005433477282	9107	Economy	8900.00
0005433507720	9107	Economy	9800.00
0005433477276	9107	Economy	9800.00
0005433507715	9107	Economy	8900.00
0005433507714	9107	Economy	8900.00
0005433507723	9107	Economy	8900.00
0005433507719	9107	Economy	8900.00
0005432920356	9107	Economy	8900.00
0005433507716	9107	Economy	8900.00
0005433477281	9107	Economy	8900.00
0005432920337	9107	Economy	8900.00
0005432920266	9107	Economy	8900.00
0005432920373	9107	Economy	8900.00
0005432920401	9107	Economy	8900.00
0005432920321	9107	Economy	8900.00
0005432920231	9107	Economy	8900.00
0005432920369	9107	Economy	8900.00
0005432920367	9107	Economy	8900.00
0005432920355	9107	Economy	8900.00
0005432920383	9107	Economy	8900.00
0005433507721	9107	Economy	8900.00
0005432920384	9107	Economy	8900.00
0005432920309	9107	Economy	8900.00
0005432920340	9107	Economy	8900.00
0005432920368	9107	Economy	8900.00
0005433477274	9107	Economy	8900.00
0005433477275	9107	Economy	8900.00
0005432920335	9107	Economy	8900.00
0005432920320	9107	Economy	8900.00
0005432920336	9107	Economy	8900.00
0005433477279	9107	Economy	8900.00
0005432920285	9107	Economy	8900.00
0005433477278	9107	Economy	8900.00
0005433507722	9107	Economy	8900.00
0005433477029	20462	Business	26600.00
0005433477111	20462	Business	26600.00
0005433477039	20462	Business	26600.00
0005432920476	20462	Business	26600.00
0005433507605	20462	Business	26600.00
0005433477028	20462	Business	26600.00
0005433477046	20462	Business	26600.00
0005433507642	20462	Business	26600.00
0005433507627	20462	Business	26600.00
0005434159059	20462	Economy	8900.00
0005432920474	20462	Economy	8900.00
0005433507598	20462	Economy	8900.00
0005433477045	20462	Economy	8900.00
0005433477063	20462	Economy	8900.00
0005434159058	20462	Economy	8900.00
0005433477040	20462	Economy	8900.00
0005433477083	20462	Economy	9800.00
0005433507567	20462	Economy	9800.00
0005434159055	20462	Economy	8900.00
0005433481366	20462	Economy	8900.00
0005433477114	20462	Economy	8900.00
0005433507641	20462	Economy	8900.00
0005433476988	20462	Economy	8900.00
0005433477110	20462	Economy	8900.00
0005433477189	20462	Economy	8900.00
0005432920475	20462	Economy	8900.00
0005433477027	20462	Economy	8900.00
0005433476998	20462	Economy	8900.00
0005433477037	20462	Economy	8900.00
0005433476989	20462	Economy	8900.00
0005433477112	20462	Economy	8900.00
0005433477024	20462	Economy	8900.00
0005433477004	20462	Economy	8900.00
0005433477246	20462	Economy	8900.00
0005433507566	20462	Economy	8900.00
0005433477113	20462	Economy	8900.00
0005433477041	20462	Economy	8900.00
0005434159057	20462	Economy	8900.00
0005433481350	20462	Economy	8900.00
0005433507508	20462	Economy	8900.00
0005433507604	20462	Economy	8900.00
0005433477061	20462	Economy	8900.00
0005433477062	20462	Economy	8900.00
0005433507595	20462	Economy	8900.00
0005433477011	20462	Economy	8900.00
0005433477188	20462	Economy	8900.00
0005433507631	20462	Economy	8900.00
0005433481340	20462	Economy	8900.00
0005433507532	20462	Economy	8900.00
0005433477107	20462	Economy	8900.00
0005433476986	20462	Economy	8900.00
0005433477025	20462	Economy	8900.00
0005433476985	20462	Economy	8900.00
0005433477065	20462	Economy	8900.00
0005433477141	20462	Economy	8900.00
0005434159056	20462	Economy	8900.00
0005433507514	20462	Economy	8900.00
0005433507630	20462	Economy	8900.00
0005433477093	20462	Economy	8900.00
0005433477247	20462	Economy	8900.00
0005433481365	20462	Economy	8900.00
0005433476997	20462	Economy	8900.00
0005433477150	20462	Economy	8900.00
0005433507659	20462	Economy	8900.00
0005433477142	20462	Economy	8900.00
0005433477074	20462	Economy	8900.00
0005433481367	20462	Economy	8900.00
0005433507585	20462	Economy	8900.00
0005432394217	10240	Economy	5800.00
0005432394218	10240	Economy	5800.00
0005432396355	10240	Economy	5800.00
0005432396354	10240	Economy	5800.00
0005435179707	10240	Economy	5800.00
0005432394216	10240	Economy	5800.00
0005432396321	18329	Economy	5800.00
0005432400200	18329	Economy	5800.00
0005432396317	18329	Economy	5800.00
0005432400196	18329	Economy	5800.00
0005432396335	18329	Economy	5800.00
0005432400199	18329	Economy	5800.00
0005432400195	18329	Economy	5800.00
0005432396334	18329	Economy	5800.00
0005432396344	18329	Economy	5800.00
0005432396324	18329	Economy	5800.00
0005432396331	18329	Economy	5800.00
0005432396330	18329	Economy	5800.00
0005435127209	11008	Business	9500.00
0005435127212	11008	Business	9500.00
0005435127029	11008	Business	9500.00
0005435127213	11008	Business	9500.00
0005435127341	11008	Business	9500.00
0005435127241	11008	Business	9500.00
0005435626535	11008	Business	9500.00
0005435127265	11008	Economy	3200.00
0005435127176	11008	Economy	3200.00
0005435554312	11008	Economy	3200.00
0005435127393	11008	Economy	3200.00
0005435127246	11008	Economy	3200.00
0005435626538	11008	Economy	3200.00
0005435626600	11008	Economy	3200.00
0005435127072	11008	Economy	3500.00
0005435127289	11008	Economy	3500.00
0005435127024	11008	Economy	3500.00
0005435626592	11008	Economy	3200.00
0005435626565	11008	Economy	3200.00
0005435626593	11008	Economy	3200.00
0005435127210	11008	Economy	3200.00
0005434411900	11008	Economy	3200.00
0005435626534	11008	Economy	3200.00
0005435127160	11008	Economy	3200.00
0005435127339	11008	Economy	3200.00
0005435127389	11008	Economy	3200.00
0005435127290	11008	Economy	3200.00
0005435127317	11008	Economy	3200.00
0005435127292	11008	Economy	3200.00
0005435127311	11008	Economy	3200.00
0005435127310	11008	Economy	3200.00
0005435626584	11008	Economy	3200.00
0005435626576	11008	Economy	3200.00
0005435127175	11008	Economy	3200.00
0005435626556	11008	Economy	3200.00
0005435556746	11008	Economy	3200.00
0005435127247	11008	Economy	3200.00
0005435127128	11008	Economy	3200.00
0005435626590	11008	Economy	3200.00
0005435127129	11008	Economy	3200.00
0005435626599	11008	Economy	3200.00
0005435127240	11008	Economy	3200.00
0005435626542	11008	Economy	3200.00
0005435626583	11008	Economy	3200.00
0005435127025	11008	Economy	3200.00
0005435626555	11008	Economy	3200.00
0005435127164	11008	Economy	3200.00
0005435626609	11008	Economy	3200.00
0005435556748	11008	Economy	3200.00
0005435127192	11008	Economy	3200.00
0005435626608	11008	Economy	3200.00
0005435127245	11008	Economy	3200.00
0005435127266	11008	Economy	3200.00
0005435626585	11008	Economy	3200.00
0005435127219	11008	Economy	3200.00
0005435626564	11008	Economy	3200.00
0005435626591	11008	Economy	3200.00
0005435556749	11008	Economy	3200.00
0005435626567	11008	Economy	3200.00
0005435127272	11008	Economy	3200.00
0005435127269	11008	Economy	3200.00
0005435127268	11008	Economy	3200.00
0005435626589	11008	Economy	3200.00
0005435626558	11008	Economy	3200.00
0005435626539	11008	Economy	3200.00
0005435626559	11008	Economy	3200.00
0005435556747	11008	Economy	3200.00
0005435554324	14670	Business	9500.00
0005434928364	14670	Business	9500.00
0005435127565	14670	Business	9500.00
0005435626835	14670	Business	9500.00
0005435626840	14670	Business	9500.00
0005434928370	14670	Business	9500.00
0005435626825	14670	Business	9500.00
0005435127557	14670	Business	9500.00
0005435626836	14670	Business	9500.00
0005435626830	14670	Economy	3200.00
0005435554325	14670	Economy	3200.00
0005435626838	14670	Economy	3200.00
0005435554326	14670	Economy	3200.00
0005435626827	14670	Economy	3200.00
0005435127558	14670	Economy	3200.00
0005435127560	14670	Economy	3500.00
0005435626831	14670	Economy	3200.00
0005435626837	14670	Economy	3200.00
0005435626828	14670	Economy	3200.00
0005435626824	14670	Economy	3200.00
0005434411878	14670	Economy	3200.00
0005434928365	14670	Economy	3200.00
0005435626822	14670	Economy	3200.00
0005434411877	14670	Economy	3200.00
0005435127553	14670	Economy	3200.00
0005435626819	14670	Economy	3200.00
0005435626833	14670	Economy	3200.00
0005435626820	14670	Economy	3200.00
0005435626832	14670	Economy	3200.00
0005435626818	14670	Economy	3200.00
0005435127555	14670	Economy	3200.00
0005435127556	14670	Economy	3200.00
0005435626829	14670	Economy	3200.00
0005435127568	14670	Economy	3200.00
0005435626839	14670	Economy	3200.00
0005435127566	14670	Economy	3200.00
0005435626823	14670	Economy	3200.00
0005435127559	14670	Economy	3200.00
0005435127563	14670	Economy	3200.00
0005435554327	14670	Economy	3200.00
0005435127564	14670	Economy	3200.00
0005435127567	14670	Economy	3200.00
0005435127562	14670	Economy	3200.00
0005435127561	14670	Economy	3200.00
0005435127552	14670	Economy	3200.00
0005435127554	14670	Economy	3200.00
0005435626821	14670	Economy	3200.00
0005435626834	14670	Economy	3200.00
0005435626826	14670	Economy	3200.00
0005435179418	7096	Economy	29000.00
0005435179417	7096	Economy	29000.00
0005432398303	7096	Economy	29000.00
0005435715969	7096	Economy	29000.00
0005432398302	7096	Economy	29000.00
0005435715968	7096	Economy	29000.00
0005435216627	7096	Economy	29000.00
0005435216631	7096	Economy	29000.00
0005435443504	7096	Economy	29000.00
0005435443540	7096	Economy	29000.00
0005435715966	7096	Economy	29000.00
0005435443547	7096	Economy	29000.00
0005435443548	7096	Economy	29000.00
0005435715967	7096	Economy	29000.00
0005435216632	7096	Economy	29000.00
0005435443539	7096	Economy	29000.00
0005432398268	27068	Business	86900.00
0005435179021	27068	Business	86900.00
0005435715805	27068	Business	86900.00
0005432398286	27068	Business	86900.00
0005432394190	27068	Economy	29000.00
0005432394202	27068	Economy	29000.00
0005435715756	27068	Economy	31900.00
0005435443585	27068	Economy	31900.00
0005435715943	27068	Economy	29000.00
0005435715912	27068	Economy	29000.00
0005435715944	27068	Economy	29000.00
0005435715882	27068	Economy	29000.00
0005435715804	27068	Economy	29000.00
0005432394204	27068	Economy	29000.00
0005435715846	27068	Economy	29000.00
0005435715883	27068	Economy	29000.00
0005435715825	27068	Economy	29000.00
0005432398277	27068	Economy	29000.00
0005432398275	27068	Economy	29000.00
0005435443584	27068	Economy	29000.00
0005435715847	27068	Economy	29000.00
0005432398267	27068	Economy	29000.00
0005432394180	27068	Economy	29000.00
0005435443583	27068	Economy	29000.00
0005435715755	27068	Economy	29000.00
0005435715897	27068	Economy	29000.00
0005432394185	27068	Economy	29000.00
0005435443582	27068	Economy	29000.00
0005432394203	27068	Economy	29000.00
0005433060470	2761	Economy	7700.00
0005433060478	2761	Economy	7700.00
0005433060466	2761	Economy	7700.00
0005434085035	28473	Economy	7700.00
0005433060491	28473	Economy	7700.00
0005434085044	28473	Economy	7700.00
0005435518290	11410	Business	20200.00
0005435518291	11410	Business	20200.00
0005435541403	11410	Business	20200.00
0005435541375	11410	Business	20200.00
0005435541527	11410	Business	20200.00
0005435541376	11410	Economy	6700.00
0005435518311	11410	Economy	6700.00
0005435541457	11410	Economy	6700.00
0005435541374	11410	Economy	6700.00
0005435541471	11410	Economy	6700.00
0005435518309	11410	Economy	6700.00
0005435541464	11410	Economy	6700.00
0005435518230	11410	Economy	6700.00
0005435541456	11410	Economy	6700.00
0005435518282	11410	Economy	6700.00
0005435518329	11410	Economy	6700.00
0005435518310	11410	Economy	6700.00
0005435518308	11410	Economy	6700.00
0005435541400	11410	Economy	6700.00
0005435518292	11410	Economy	6700.00
0005435518321	11410	Economy	6700.00
0005435541540	11410	Economy	6700.00
0005435541510	11410	Economy	6700.00
0005435518315	11410	Economy	6700.00
0005435518320	11410	Economy	6700.00
0005435541591	11410	Economy	6700.00
0005435541472	11410	Economy	6700.00
0005435541420	11410	Economy	6700.00
0005435530180	22257	Business	20200.00
0005435541624	22257	Business	20200.00
0005435541622	22257	Business	20200.00
0005435530182	22257	Economy	6700.00
0005435541623	22257	Economy	6700.00
0005435530178	22257	Economy	6700.00
0005435541633	22257	Economy	6700.00
0005435541630	22257	Economy	6700.00
0005435530174	22257	Economy	6700.00
0005435529876	22257	Economy	6700.00
0005435530173	22257	Economy	6700.00
0005435529877	22257	Economy	6700.00
0005435530176	22257	Economy	6700.00
0005435529882	22257	Economy	6700.00
0005435530177	22257	Economy	6700.00
0005435530181	22257	Economy	6700.00
0005432294557	22257	Economy	6700.00
0005435529881	22257	Economy	6700.00
0005432294556	22257	Economy	6700.00
0005435530175	22257	Economy	6700.00
0005435529883	22257	Economy	6700.00
0005435529880	22257	Economy	6700.00
0005435541627	22257	Economy	6700.00
0005435541625	22257	Economy	6700.00
0005435541626	22257	Economy	6700.00
0005435541632	22257	Economy	6700.00
0005435530179	22257	Economy	6700.00
0005435541635	22257	Economy	6700.00
0005435541634	22257	Economy	6700.00
0005435529879	22257	Economy	6700.00
0005432294558	22257	Economy	6700.00
0005435541629	22257	Economy	6700.00
0005435530183	22257	Economy	6700.00
0005435541631	22257	Economy	6700.00
0005435529878	22257	Economy	6700.00
0005435541628	22257	Economy	6700.00
0005434908863	2293	Business	20200.00
0005434908858	2293	Business	20200.00
0005433252134	2293	Business	20200.00
0005433252209	2293	Business	20200.00
0005433252080	2293	Business	20200.00
0005433252142	2293	Business	20200.00
0005434908856	2293	Economy	6700.00
0005433252189	2293	Economy	6700.00
0005433252215	2293	Economy	6700.00
0005433252208	2293	Economy	6700.00
0005434908871	2293	Economy	6700.00
0005433252287	2293	Economy	6700.00
0005433252272	2293	Economy	7400.00
0005433252062	2293	Economy	7400.00
0005433252220	2293	Economy	6700.00
0005433252221	2293	Economy	6700.00
0005435787472	2293	Economy	6700.00
0005433252137	2293	Economy	6700.00
0005434908857	2293	Economy	6700.00
0005434908868	2293	Economy	6700.00
0005433252150	2293	Economy	6700.00
0005433252148	2293	Economy	6700.00
0005433252226	2293	Economy	6700.00
0005434908862	2293	Economy	6700.00
0005433252271	2293	Economy	6700.00
0005433252160	2293	Economy	6700.00
0005434908872	2293	Economy	6700.00
0005434908866	2293	Economy	6700.00
0005434908859	2293	Economy	6700.00
0005433252173	2293	Economy	6700.00
0005434908864	2293	Economy	6700.00
0005433252066	2293	Economy	6700.00
0005433401042	2293	Economy	6700.00
0005433252216	2293	Economy	6700.00
0005433252191	2293	Economy	6700.00
0005435787474	2293	Economy	6700.00
0005433252292	2293	Economy	6700.00
0005433252061	2293	Economy	6700.00
0005435787471	2293	Economy	6700.00
0005434908865	2293	Economy	6700.00
0005434908869	2293	Economy	6700.00
0005434908861	2293	Economy	6700.00
0005434908873	2293	Economy	6700.00
0005434908870	2293	Economy	6700.00
0005434908860	2293	Economy	6700.00
0005433401053	2293	Economy	6700.00
0005433401045	2293	Economy	6700.00
0005433252149	2293	Economy	6700.00
0005433252252	2293	Economy	6700.00
0005434908867	2293	Economy	6700.00
0005435787475	2293	Economy	6700.00
0005433252281	2293	Economy	6700.00
0005435787473	2293	Economy	6700.00
0005434908855	2293	Economy	6700.00
0005434908469	25625	Business	20200.00
0005434908523	25625	Business	20200.00
0005434908427	25625	Business	20200.00
0005433252363	25625	Business	20200.00
0005434908408	25625	Business	20200.00
0005434908404	25625	Business	20200.00
0005434908315	25625	Business	20200.00
0005433252371	25625	Business	20200.00
0005433252362	25625	Business	20200.00
0005434908486	25625	Economy	6700.00
0005434908311	25625	Economy	6700.00
0005434908365	25625	Economy	6700.00
0005434908180	25625	Economy	6700.00
0005434908257	25625	Economy	6700.00
0005433252365	25625	Economy	6700.00
0005434908723	25625	Economy	7400.00
0005433252366	25625	Economy	7400.00
0005434908448	25625	Economy	7400.00
0005434908406	25625	Economy	7400.00
0005434908347	25625	Economy	6700.00
0005434908391	25625	Economy	6700.00
0005434908447	25625	Economy	6700.00
0005435787456	25625	Economy	6700.00
0005434908230	25625	Economy	6700.00
0005434908181	25625	Economy	6700.00
0005434908292	25625	Economy	6700.00
0005434908377	25625	Economy	6700.00
0005434908452	25625	Economy	6700.00
0005434908430	25625	Economy	6700.00
0005434908037	25625	Economy	6700.00
0005434908348	25625	Economy	6700.00
0005434908405	25625	Economy	6700.00
0005434908432	25625	Economy	6700.00
0005434908261	25625	Economy	6700.00
0005434908312	25625	Economy	6700.00
0005434908522	25625	Economy	6700.00
0005434908368	25625	Economy	6700.00
0005434908251	25625	Economy	6700.00
0005434908245	25625	Economy	6700.00
0005434908210	25625	Economy	6700.00
0005434908450	25625	Economy	6700.00
0005434908510	25625	Economy	6700.00
0005434908367	25625	Economy	6700.00
0005434908442	25625	Economy	6700.00
0005433252364	25625	Economy	6700.00
0005433252367	25625	Economy	6700.00
0005435787455	25625	Economy	6700.00
0005433252369	25625	Economy	6700.00
0005434908460	25625	Economy	6700.00
0005434908260	25625	Economy	6700.00
0005434908493	25625	Economy	6700.00
0005434908533	25625	Economy	6700.00
0005434908537	25625	Economy	6700.00
0005434908286	25625	Economy	6700.00
0005433252370	25625	Economy	6700.00
0005434908500	25625	Economy	6700.00
0005433252361	25625	Economy	6700.00
0005434908605	25625	Economy	6700.00
0005434908154	25625	Economy	6700.00
0005433252368	25625	Economy	6700.00
0005434908585	25625	Economy	6700.00
0005434908492	25625	Economy	6700.00
0005434908378	25625	Economy	6700.00
0005433252360	25625	Economy	6700.00
0005434908426	25625	Economy	6700.00
0005434908379	25625	Economy	6700.00
0005434908499	25625	Economy	6700.00
0005434908244	25625	Economy	6700.00
0005434908508	25625	Economy	6700.00
0005432862461	2539	Economy	12400.00
0005432862469	2539	Economy	12400.00
0005432621448	2539	Economy	12400.00
0005432621451	2539	Economy	12400.00
0005432621449	2539	Economy	12400.00
0005432862472	2539	Economy	12400.00
0005432862499	2539	Economy	12400.00
0005432862483	2539	Economy	12400.00
0005432862471	2539	Economy	12400.00
0005432862482	2539	Economy	12400.00
0005432862500	2539	Economy	12400.00
0005432862477	2539	Economy	12400.00
0005432621452	2539	Economy	12400.00
0005432862498	2539	Economy	12400.00
0005432862478	2539	Economy	12400.00
0005432862497	2539	Economy	12400.00
0005432621447	2539	Economy	12400.00
0005432862470	2539	Economy	12400.00
0005432621450	2539	Economy	12400.00
0005432621354	28077	Economy	13600.00
0005432621336	28077	Economy	12400.00
0005432621356	28077	Economy	12400.00
0005432621374	28077	Economy	12400.00
0005432621373	28077	Economy	12400.00
0005432621353	28077	Economy	12400.00
0005432621347	28077	Economy	12400.00
0005432621346	28077	Economy	12400.00
0005432621345	28077	Economy	12400.00
0005432621404	28077	Economy	12400.00
0005432621405	28077	Economy	12400.00
0005432621337	28077	Economy	12400.00
0005432621403	28077	Economy	12400.00
0005432621397	28077	Economy	12400.00
0005432621355	28077	Economy	12400.00
0005432621357	28077	Economy	12400.00
0005432862522	28077	Economy	12400.00
0005432862524	28077	Economy	12400.00
0005432862523	28077	Economy	12400.00
0005434097500	11795	Economy	11300.00
0005433451676	30986	Economy	8400.00
0005433454917	31392	Economy	8400.00
0005433454922	31392	Economy	8400.00
0005433454921	31392	Economy	8400.00
0005434326031	11980	Economy	7200.00
0005433129383	11980	Economy	7200.00
0005433129365	11980	Economy	6600.00
0005434326032	11980	Economy	6600.00
0005433134226	11980	Economy	6600.00
0005433129384	11980	Economy	6600.00
0005434184709	11980	Economy	6600.00
0005433134238	11980	Economy	6600.00
0005434326035	11980	Economy	6600.00
0005433129385	11980	Economy	6600.00
0005434142692	11980	Economy	6600.00
0005434142707	11980	Economy	6600.00
0005434326029	11980	Economy	6600.00
0005434326027	11980	Economy	6600.00
0005433134233	11980	Economy	6600.00
0005433134221	11980	Economy	6600.00
0005434326030	11980	Economy	6600.00
0005433129375	11980	Economy	6600.00
0005434326033	11980	Economy	6600.00
0005434326026	11980	Economy	6600.00
0005434142708	11980	Economy	6600.00
0005434326034	11980	Economy	6600.00
0005434326036	11980	Economy	6600.00
0005434326028	11980	Economy	6600.00
0005434326062	11980	Economy	6600.00
0005433129376	11980	Economy	6600.00
0005434142689	11980	Economy	6600.00
0005434142693	11980	Economy	6600.00
0005433134242	11980	Economy	6600.00
0005434326025	11980	Economy	6600.00
0005433131839	29843	Economy	7200.00
0005434184726	29843	Economy	6600.00
0005433134263	29843	Economy	6600.00
0005434184727	29843	Economy	6600.00
0005434142727	29843	Economy	6600.00
0005434142728	29843	Economy	6600.00
0005433131840	29843	Economy	6600.00
0005435698145	16462	Economy	19900.00
0005435698144	16462	Economy	19900.00
0005435935113	16462	Economy	18100.00
0005435935118	16462	Economy	18100.00
0005435698141	16462	Economy	18100.00
0005435698142	16462	Economy	18100.00
0005435935111	16462	Economy	18100.00
0005435698149	16462	Economy	18100.00
0005435698151	16462	Economy	18100.00
0005435698154	16462	Economy	18100.00
0005435935108	16462	Economy	18100.00
0005435698140	16462	Economy	18100.00
0005435698147	16462	Economy	18100.00
0005435698152	16462	Economy	18100.00
0005435698150	16462	Economy	18100.00
0005435698153	16462	Economy	18100.00
0005435935112	16462	Economy	18100.00
0005435935117	16462	Economy	18100.00
0005435698146	16462	Economy	18100.00
0005435698143	16462	Economy	18100.00
0005435935116	16462	Economy	18100.00
0005435698148	16462	Economy	18100.00
0005435933588	24700	Economy	19900.00
0005435697855	24700	Economy	19900.00
0005435697994	24700	Economy	19900.00
0005435697853	24700	Economy	19900.00
0005435933587	24700	Economy	18100.00
0005435698034	24700	Economy	18100.00
0005435697900	24700	Economy	18100.00
0005435697899	24700	Economy	18100.00
0005435697838	24700	Economy	18100.00
0005435935135	24700	Economy	18100.00
0005435697832	24700	Economy	18100.00
0005435697868	24700	Economy	18100.00
0005435698002	24700	Economy	18100.00
0005435697993	24700	Economy	18100.00
0005435697967	24700	Economy	18100.00
0005435697952	24700	Economy	18100.00
0005435698021	24700	Economy	18100.00
0005435697854	24700	Economy	18100.00
0005435697953	24700	Economy	18100.00
0005435697898	24700	Economy	18100.00
0005435697924	24700	Economy	18100.00
0005435697831	24700	Economy	18100.00
0005435697968	24700	Economy	18100.00
0005435697966	24700	Economy	18100.00
0005435697992	24700	Economy	18100.00
0005435697936	24700	Economy	18100.00
0005435697976	24700	Economy	18100.00
0005435698114	24700	Economy	18100.00
0005435698022	24700	Economy	18100.00
0005435935136	24700	Economy	18100.00
0005435697937	24700	Economy	18100.00
0005433724936	18782	Economy	4400.00
0005432968891	18782	Economy	4400.00
0005432968892	18782	Economy	4400.00
0005433724905	21637	Economy	4400.00
0005433724908	21637	Economy	4400.00
0005433724899	21637	Economy	4400.00
0005434140582	7300	Business	23100.00
0005434140575	7300	Business	23100.00
0005434140550	7300	Business	23100.00
0005434140572	7300	Business	23100.00
0005434140585	7300	Business	23100.00
0005434140586	7300	Business	23100.00
0005434140554	7300	Economy	7700.00
0005434140566	7300	Economy	7700.00
0005434140555	7300	Economy	7700.00
0005434140563	7300	Economy	7700.00
0005434140560	7300	Economy	7700.00
0005434140570	7300	Economy	7700.00
0005434140552	7300	Economy	7700.00
0005434140553	7300	Economy	7700.00
0005434140588	7300	Economy	7700.00
0005434140556	7300	Economy	7700.00
0005434140574	7300	Economy	7700.00
0005434140557	7300	Economy	7700.00
0005434140587	7300	Economy	7700.00
0005434140577	7300	Economy	7700.00
0005434140567	7300	Economy	7700.00
0005434140564	7300	Economy	7700.00
0005434140580	7300	Economy	7700.00
0005434140551	7300	Economy	7700.00
0005434140562	7300	Economy	7700.00
0005434140583	7300	Economy	7700.00
0005434140558	7300	Economy	7700.00
0005434140584	7300	Economy	7700.00
0005434140579	7300	Economy	7700.00
0005434140576	7300	Economy	7700.00
0005434140581	7300	Economy	7700.00
0005434140565	7300	Economy	7700.00
0005434140569	7300	Economy	7700.00
0005434140578	7300	Economy	7700.00
0005434140571	7300	Economy	7700.00
0005434140561	7300	Economy	7700.00
0005434140568	7300	Economy	7700.00
0005434140573	7300	Economy	7700.00
0005434140559	7300	Economy	7700.00
0005434139653	28553	Business	23100.00
0005434140199	28553	Business	23100.00
0005434139901	28553	Business	23100.00
0005434139833	28553	Business	23100.00
0005434087607	28553	Business	23100.00
0005434140095	28553	Business	23100.00
0005434139796	28553	Business	23100.00
0005434139683	28553	Business	23100.00
0005434139792	28553	Business	23100.00
0005434139922	28553	Business	23100.00
0005435283565	28553	Business	23100.00
0005434139949	28553	Economy	7700.00
0005434140028	28553	Economy	7700.00
0005434139986	28553	Economy	7700.00
0005434140002	28553	Economy	7700.00
0005434139935	28553	Economy	7700.00
0005434139836	28553	Economy	7700.00
0005434087641	28553	Economy	7700.00
0005434139674	28553	Economy	7700.00
0005434140159	28553	Economy	7700.00
0005434139876	28553	Economy	7700.00
0005434140149	28553	Economy	8500.00
0005435283571	28553	Economy	8500.00
0005434139853	28553	Economy	8500.00
0005435283572	28553	Economy	8500.00
0005435283573	28553	Economy	8500.00
0005434139684	28553	Economy	7700.00
0005434139738	28553	Economy	7700.00
0005434139715	28553	Economy	7700.00
0005434139658	28553	Economy	7700.00
0005434139761	28553	Economy	7700.00
0005434140107	28553	Economy	7700.00
0005434139780	28553	Economy	7700.00
0005434139936	28553	Economy	7700.00
0005434140027	28553	Economy	7700.00
0005434139685	28553	Economy	7700.00
0005434087629	28553	Economy	7700.00
0005434139877	28553	Economy	7700.00
0005434140160	28553	Economy	7700.00
0005434139779	28553	Economy	7700.00
0005434139637	28553	Economy	7700.00
0005434139957	28553	Economy	7700.00
0005434139762	28553	Economy	7700.00
0005434139900	28553	Economy	7700.00
0005434139979	28553	Economy	7700.00
0005434139832	28553	Economy	7700.00
0005434139980	28553	Economy	7700.00
0005434139907	28553	Economy	7700.00
0005434087648	28553	Economy	7700.00
0005434139985	28553	Economy	7700.00
0005434140013	28553	Economy	7700.00
0005434139396	28553	Economy	7700.00
0005434139837	28553	Economy	7700.00
0005434139783	28553	Economy	7700.00
0005434139657	28553	Economy	7700.00
0005434139845	28553	Economy	7700.00
0005434139948	28553	Economy	7700.00
0005434139784	28553	Economy	7700.00
0005434139846	28553	Economy	7700.00
0005434139388	28553	Economy	7700.00
0005434139960	28553	Economy	7700.00
0005434139917	28553	Economy	7700.00
0005434140198	28553	Economy	7700.00
0005434139797	28553	Economy	7700.00
0005434139914	28553	Economy	7700.00
0005434139855	28553	Economy	7700.00
0005434139552	28553	Economy	7700.00
0005434139538	28553	Economy	7700.00
0005434139932	28553	Economy	7700.00
0005434139884	28553	Economy	7700.00
0005434139634	28553	Economy	7700.00
0005434139956	28553	Economy	7700.00
0005434139790	28553	Economy	7700.00
0005434140033	28553	Economy	7700.00
0005434139844	28553	Economy	7700.00
0005434139982	28553	Economy	7700.00
0005434139619	28553	Economy	7700.00
0005434139975	28553	Economy	7700.00
0005434139864	28553	Economy	7700.00
0005434139549	28553	Economy	7700.00
0005434139686	28553	Economy	7700.00
0005434139947	28553	Economy	7700.00
0005434139984	28553	Economy	7700.00
0005434139913	28553	Economy	7700.00
0005434139834	28553	Economy	7700.00
0005435283566	28553	Economy	7700.00
0005434139687	28553	Economy	7700.00
0005434087624	28553	Economy	7700.00
0005434140106	28553	Economy	7700.00
0005434139537	28553	Economy	7700.00
0005434139675	28553	Economy	7700.00
0005434139854	28553	Economy	7700.00
0005434610337	1915	Economy	23900.00
0005434610336	1915	Economy	21700.00
0005433407677	1915	Economy	21700.00
0005435808525	1915	Economy	21700.00
0005433407689	1915	Economy	21700.00
0005434610335	1915	Economy	21700.00
0005435808524	1915	Economy	21700.00
0005433407655	1915	Economy	21700.00
0005434610311	23064	Economy	23900.00
0005435808422	23064	Economy	23900.00
0005435808429	23064	Economy	23900.00
0005433407709	23064	Economy	21700.00
0005433407707	23064	Economy	21700.00
0005435808403	23064	Economy	21700.00
0005434610303	23064	Economy	21700.00
0005435808421	23064	Economy	21700.00
0005435808464	23064	Economy	21700.00
0005435808430	23064	Economy	21700.00
0005435808454	23064	Economy	21700.00
0005435808423	23064	Economy	21700.00
0005434610312	23064	Economy	21700.00
0005435808419	23064	Economy	21700.00
0005435808420	23064	Economy	21700.00
0005435808390	23064	Economy	21700.00
0005434610304	23064	Economy	21700.00
0005434610305	23064	Economy	21700.00
0005433407708	23064	Economy	21700.00
0005434610313	23064	Economy	21700.00
0005435808465	23064	Economy	21700.00
0005435808412	23064	Economy	21700.00
0005434504905	16730	Economy	7600.00
0005434504985	16730	Economy	7600.00
0005434504995	16730	Economy	7600.00
0005434505223	16730	Economy	7600.00
0005434504942	16730	Economy	6900.00
0005434504892	16730	Economy	6900.00
0005434504872	16730	Economy	6900.00
0005434504996	16730	Economy	6900.00
0005434505004	16730	Economy	6900.00
0005434504951	16730	Economy	6900.00
0005434505055	16730	Economy	6900.00
0005434504923	16730	Economy	6900.00
0005434505047	16730	Economy	6900.00
0005434504961	16730	Economy	6900.00
0005434505048	16730	Economy	6900.00
0005434505045	16730	Economy	6900.00
0005434504955	16730	Economy	6900.00
0005434504904	16730	Economy	6900.00
0005434504849	16730	Economy	6900.00
0005434504962	16730	Economy	6900.00
0005434504912	16730	Economy	6900.00
0005434504932	16730	Economy	6900.00
0005434505054	16730	Economy	6900.00
0005434504986	16730	Economy	6900.00
0005434504846	16730	Economy	6900.00
0005434504968	16730	Economy	6900.00
0005434505058	16730	Economy	6900.00
0005434505046	16730	Economy	6900.00
0005434504997	16730	Economy	6900.00
0005434504967	16730	Economy	6900.00
0005434504850	16730	Economy	6900.00
0005434504952	16730	Economy	6900.00
0005434504919	16730	Economy	6900.00
0005434505065	16730	Economy	6900.00
0005434504984	16730	Economy	6900.00
0005434504994	16730	Economy	6900.00
0005434504895	16730	Economy	6900.00
0005434504972	16730	Economy	6900.00
0005434504795	16730	Economy	6900.00
0005434504828	16730	Economy	6900.00
0005434505273	22890	Economy	7600.00
0005434505279	22890	Economy	6900.00
0005434505281	22890	Economy	6900.00
0005434505272	22890	Economy	6900.00
0005434505289	22890	Economy	6900.00
0005434505274	22890	Economy	6900.00
0005434505287	22890	Economy	6900.00
0005434505283	22890	Economy	6900.00
0005434505271	22890	Economy	6900.00
0005434505286	22890	Economy	6900.00
0005434505282	22890	Economy	6900.00
0005434505277	22890	Economy	6900.00
0005434505288	22890	Economy	6900.00
0005434505284	22890	Economy	6900.00
0005434505276	22890	Economy	6900.00
0005434505278	22890	Economy	6900.00
0005434505280	22890	Economy	6900.00
0005434505275	22890	Economy	6900.00
0005434505285	22890	Economy	6900.00
0005435078786	2221	Economy	7700.00
0005435078785	2221	Economy	7700.00
0005435078780	2221	Economy	7000.00
0005433266926	2221	Economy	7000.00
0005435078781	2221	Economy	7000.00
0005433266930	2221	Economy	7000.00
0005433266929	2221	Economy	7000.00
0005433266921	2221	Economy	7000.00
0005433266932	2221	Economy	7000.00
0005433266925	2221	Economy	7000.00
0005435078784	2221	Economy	7000.00
0005435078782	2221	Economy	7000.00
0005435078787	2221	Economy	7000.00
0005433266914	2221	Economy	7000.00
0005433266940	2221	Economy	7000.00
0005433266931	2221	Economy	7000.00
0005435078789	2221	Economy	7000.00
0005435078791	2221	Economy	7000.00
0005435078783	2221	Economy	7000.00
0005435078790	2221	Economy	7000.00
0005435078788	2221	Economy	7000.00
0005433266939	2221	Economy	7000.00
0005435078692	24340	Economy	7000.00
0005435078700	24340	Economy	7000.00
0005435078699	24340	Economy	7000.00
0005433266989	24340	Economy	7000.00
0005435078717	24340	Economy	7000.00
0005435078725	24340	Economy	7000.00
0005435078726	24340	Economy	7000.00
0005435078710	24340	Economy	7000.00
0005435078618	24340	Economy	7000.00
0005433266988	24340	Economy	7000.00
0005433266987	24340	Economy	7000.00
0005435078744	24340	Economy	7000.00
0005435078718	24340	Economy	7000.00
0005434989104	6630	Economy	10800.00
0005434989107	6630	Economy	9800.00
0005435464550	6630	Economy	9800.00
0005434989105	6630	Economy	9800.00
0005434989103	6630	Economy	9800.00
0005435464555	6630	Economy	9800.00
0005434989102	6630	Economy	9800.00
0005434989110	6630	Economy	9800.00
0005434989106	6630	Economy	9800.00
0005434989109	6630	Economy	9800.00
0005434989100	6630	Economy	9800.00
0005434989108	6630	Economy	9800.00
0005434989101	6630	Economy	9800.00
0005434989099	6630	Economy	9800.00
0005435803350	6630	Economy	9800.00
0005434988923	23619	Economy	9800.00
0005434988924	23619	Economy	9800.00
0005434988936	23619	Economy	9800.00
0005434988928	23619	Economy	9800.00
0005434988955	23619	Economy	9800.00
0005434988927	23619	Economy	9800.00
0005434988956	23619	Economy	9800.00
0005432384314	30459	Business	9900.00
0005432384321	30459	Business	9900.00
0005432384315	30459	Economy	3300.00
0005432384317	30459	Economy	3300.00
0005432384322	30459	Economy	3600.00
0005432384323	30459	Economy	3300.00
0005432384318	30459	Economy	3300.00
0005433454934	30459	Economy	3300.00
0005433450600	30459	Economy	3300.00
0005432384316	30459	Economy	3300.00
0005432384319	30459	Economy	3300.00
0005432384320	30459	Economy	3300.00
0005432383985	31281	Business	9900.00
0005433450393	31281	Business	9900.00
0005433450503	31281	Business	9900.00
0005432384057	31281	Business	9900.00
0005433450460	31281	Business	9900.00
0005432383914	31281	Business	9900.00
0005432383817	31281	Business	9900.00
0005432384041	31281	Business	9900.00
0005432384035	31281	Business	9900.00
0005432383841	31281	Economy	3300.00
0005432383988	31281	Economy	3300.00
0005432383978	31281	Economy	3300.00
0005432383976	31281	Economy	3300.00
0005432383989	31281	Economy	3300.00
0005432383984	31281	Economy	3300.00
0005433450437	31281	Economy	3600.00
0005432383979	31281	Economy	3600.00
0005432384019	31281	Economy	3600.00
0005433450455	31281	Economy	3600.00
0005432384021	31281	Economy	3600.00
0005432383915	31281	Economy	3300.00
0005433450388	31281	Economy	3300.00
0005433450459	31281	Economy	3300.00
0005432383972	31281	Economy	3300.00
0005432384042	31281	Economy	3300.00
0005432384032	31281	Economy	3300.00
0005432384050	31281	Economy	3300.00
0005433450454	31281	Economy	3300.00
0005433450502	31281	Economy	3300.00
0005432383942	31281	Economy	3300.00
0005432383787	31281	Economy	3300.00
0005433450440	31281	Economy	3300.00
0005432384017	31281	Economy	3300.00
0005432383952	31281	Economy	3300.00
0005432383765	31281	Economy	3300.00
0005432383968	31281	Economy	3300.00
0005432383790	31281	Economy	3300.00
0005433450426	31281	Economy	3300.00
0005432384058	31281	Economy	3300.00
0005432384018	31281	Economy	3300.00
0005432383965	31281	Economy	3300.00
0005432383992	31281	Economy	3300.00
0005433450489	31281	Economy	3300.00
0005433450386	31281	Economy	3300.00
0005432383953	31281	Economy	3300.00
0005432383791	31281	Economy	3300.00
0005432383924	31281	Economy	3300.00
0005432383923	31281	Economy	3300.00
0005432383947	31281	Economy	3300.00
0005433450539	31281	Economy	3300.00
0005433450492	31281	Economy	3300.00
0005432383764	31281	Economy	3300.00
0005432383991	31281	Economy	3300.00
0005432383818	31281	Economy	3300.00
0005432383789	31281	Economy	3300.00
0005432384062	31281	Economy	3300.00
0005432383786	31281	Economy	3300.00
0005432383959	31281	Economy	3300.00
0005432383836	31281	Economy	3300.00
0005432384036	31281	Economy	3300.00
0005432384020	31281	Economy	3300.00
0005432383925	31281	Economy	3300.00
0005432383830	31281	Economy	3300.00
0005432383886	31281	Economy	3300.00
0005432383926	31281	Economy	3300.00
0005433450389	31281	Economy	3300.00
0005432383927	31281	Economy	3300.00
0005433450436	31281	Economy	3300.00
0005432383956	31281	Economy	3300.00
0005433126927	10761	Economy	15600.00
0005433126938	10761	Economy	15600.00
0005433126936	10761	Economy	15600.00
0005433131777	10761	Economy	15600.00
0005433131799	10761	Economy	15600.00
0005433131815	10761	Economy	15600.00
0005433126937	10761	Economy	15600.00
0005435299872	10761	Economy	15600.00
0005435299875	10761	Economy	15600.00
0005433126934	10761	Economy	15600.00
0005435304250	10761	Economy	15600.00
0005435304242	10761	Economy	15600.00
0005435299878	10761	Economy	15600.00
0005435299897	10761	Economy	15600.00
0005435299898	10761	Economy	15600.00
0005433129410	29727	Economy	17100.00
0005435302337	29727	Economy	15600.00
0005433126981	29727	Economy	15600.00
0005433129411	29727	Economy	15600.00
0005433129412	29727	Economy	15600.00
0005433126980	29727	Economy	15600.00
0005434287930	2438	Economy	17200.00
0005434287929	2438	Economy	17200.00
0005433110291	2438	Economy	17200.00
0005433110376	2438	Economy	15700.00
0005434300244	2438	Economy	15700.00
0005434300243	2438	Economy	15700.00
0005434300245	2438	Economy	15700.00
0005434287931	2438	Economy	15700.00
0005434300250	2438	Economy	15700.00
0005434300246	2438	Economy	15700.00
0005433110310	2438	Economy	15700.00
0005434300239	2438	Economy	15700.00
0005434300247	2438	Economy	15700.00
0005434287933	2438	Economy	15700.00
0005433110345	2438	Economy	15700.00
0005434287932	2438	Economy	15700.00
0005433110317	2438	Economy	15700.00
0005433110377	2438	Economy	15700.00
0005433110290	2438	Economy	15700.00
0005434300248	2438	Economy	15700.00
0005433110337	2438	Economy	15700.00
0005433110343	2438	Economy	15700.00
0005433110351	2438	Economy	15700.00
0005434300249	2438	Economy	15700.00
0005433110294	2438	Economy	15700.00
0005433110276	2438	Economy	15700.00
0005434300241	2438	Economy	15700.00
0005433110352	2438	Economy	15700.00
0005434300242	2438	Economy	15700.00
0005434287934	2438	Economy	15700.00
0005433110367	2438	Economy	15700.00
0005434300240	2438	Economy	15700.00
0005433110316	2438	Economy	15700.00
0005433110344	2438	Economy	15700.00
0005434287769	26878	Economy	17200.00
0005434287779	26878	Economy	17200.00
0005434287814	26878	Economy	17200.00
0005434287815	26878	Economy	17200.00
0005434287836	26878	Economy	15700.00
0005433110391	26878	Economy	15700.00
0005434287834	26878	Economy	15700.00
0005434287835	26878	Economy	15700.00
0005434287785	26878	Economy	15700.00
0005434287783	26878	Economy	15700.00
0005434287867	26878	Economy	15700.00
0005434287784	26878	Economy	15700.00
0005434287722	26878	Economy	15700.00
0005434287826	26878	Economy	15700.00
0005434287768	26878	Economy	15700.00
0005434287876	26878	Economy	15700.00
0005434287847	26878	Economy	15700.00
0005434287664	26878	Economy	15700.00
0005434287781	26878	Economy	15700.00
0005434287723	26878	Economy	15700.00
0005434287799	26878	Economy	15700.00
0005434287689	26878	Economy	15700.00
0005434287762	26878	Economy	15700.00
0005434287691	26878	Economy	15700.00
0005434287690	26878	Economy	15700.00
0005434287780	26878	Economy	15700.00
0005434287860	26878	Economy	15700.00
0005433110392	26878	Economy	15700.00
0005434287866	26878	Economy	15700.00
0005434287810	26878	Economy	15700.00
0005434287788	26878	Economy	15700.00
0005434287879	26878	Economy	15700.00
0005434287728	26878	Economy	15700.00
0005434287671	26878	Economy	15700.00
0005435983711	25452	Economy	25000.00
0005435983710	25452	Economy	25000.00
0005435983705	25452	Economy	22800.00
0005435983708	25452	Economy	22800.00
0005435856330	25452	Economy	22800.00
0005435983707	25452	Economy	22800.00
0005435983709	25452	Economy	22800.00
0005435856362	25452	Economy	22800.00
0005435983706	25452	Economy	22800.00
0005435856302	26635	Economy	22800.00
0005435856306	26635	Economy	22800.00
0005435856280	26635	Economy	22800.00
0005435856295	26635	Economy	22800.00
0005435856300	26635	Economy	22800.00
0005435856303	26635	Economy	22800.00
0005435856301	26635	Economy	22800.00
0005435263768	7163	Business	89800.00
0005435263794	7163	Business	89800.00
0005435263756	7163	Economy	29900.00
0005435263758	7163	Economy	29900.00
0005433651098	7163	Economy	32900.00
0005435263796	7163	Economy	32900.00
0005433651097	7163	Economy	32900.00
0005433651095	7163	Economy	32900.00
0005435263747	7163	Economy	32900.00
0005433651091	7163	Economy	29900.00
0005435263776	7163	Economy	29900.00
0005435263784	7163	Economy	29900.00
0005433651090	7163	Economy	29900.00
0005435263779	7163	Economy	29900.00
0005435263787	7163	Economy	29900.00
0005433651086	7163	Economy	29900.00
0005435263769	7163	Economy	29900.00
0005435263782	7163	Economy	29900.00
0005435263770	7163	Economy	29900.00
0005433651087	7163	Economy	29900.00
0005435263785	7163	Economy	29900.00
0005433651096	7163	Economy	29900.00
0005433651099	7163	Economy	29900.00
0005435263763	7163	Economy	29900.00
0005433651100	7163	Economy	29900.00
0005435263759	7163	Economy	29900.00
0005435263764	7163	Economy	29900.00
0005435263778	7163	Economy	29900.00
0005435263749	7163	Economy	29900.00
0005435263742	7163	Economy	29900.00
0005433651089	7163	Economy	29900.00
0005435263788	7163	Economy	29900.00
0005433651092	7163	Economy	29900.00
0005433651094	7163	Economy	29900.00
0005435263771	7163	Economy	29900.00
0005435263748	7163	Economy	29900.00
0005435263783	7163	Economy	29900.00
0005433651085	7163	Economy	29900.00
0005435263789	7163	Economy	29900.00
0005433651088	7163	Economy	29900.00
0005433651093	7163	Economy	29900.00
0005435860555	4806	Economy	19400.00
0005435860582	4806	Economy	19400.00
0005435860559	4806	Economy	17600.00
0005435860576	4806	Economy	17600.00
0005433869591	4806	Economy	17600.00
0005433869590	4806	Economy	17600.00
0005433869588	4806	Economy	17600.00
0005435860560	4806	Economy	17600.00
0005433869596	4806	Economy	17600.00
0005433869594	4806	Economy	17600.00
0005435860581	4806	Economy	17600.00
0005435860558	4806	Economy	17600.00
0005433869592	4806	Economy	17600.00
0005435860580	4806	Economy	17600.00
0005433869589	4806	Economy	17600.00
0005433869595	4806	Economy	17600.00
0005433869593	4806	Economy	17600.00
0005435860586	4806	Economy	17600.00
0005433869017	32608	Economy	19400.00
0005433869294	32608	Economy	19400.00
0005433869181	32608	Economy	19400.00
0005433869326	32608	Economy	19400.00
0005433869207	32608	Economy	17600.00
0005433869016	32608	Economy	17600.00
0005433869262	32608	Economy	17600.00
0005433869424	32608	Economy	17600.00
0005435860626	32608	Economy	17600.00
0005433869365	32608	Economy	17600.00
0005433869259	32608	Economy	17600.00
0005433869364	32608	Economy	17600.00
0005435860625	32608	Economy	17600.00
0005433869298	32608	Economy	17600.00
0005433869320	32608	Economy	17600.00
0005433869371	32608	Economy	17600.00
0005433869281	32608	Economy	17600.00
0005433869303	32608	Economy	17600.00
0005433869309	32608	Economy	17600.00
0005433869252	32608	Economy	17600.00
0005433869490	32608	Economy	17600.00
0005433869491	32608	Economy	17600.00
0005433869310	32608	Economy	17600.00
0005433869246	32608	Economy	17600.00
0005433869374	32608	Economy	17600.00
0005433869445	32608	Economy	17600.00
0005433869414	32608	Economy	17600.00
0005433869229	32608	Economy	17600.00
0005433869297	32608	Economy	17600.00
0005433869350	32608	Economy	17600.00
0005433869245	32608	Economy	17600.00
0005433869180	32608	Economy	17600.00
0005433869208	32608	Economy	17600.00
0005433869410	32608	Economy	17600.00
0005433869321	32608	Economy	17600.00
0005433869404	32608	Economy	17600.00
0005433869322	32608	Economy	17600.00
0005433869304	32608	Economy	17600.00
0005433869438	32608	Economy	17600.00
0005433869375	32608	Economy	17600.00
0005433869349	32608	Economy	17600.00
0005433869214	32608	Economy	17600.00
0005433869253	32608	Economy	17600.00
0005433869423	32608	Economy	17600.00
0005433869145	32608	Economy	17600.00
0005433869261	32608	Economy	17600.00
0005433869047	32608	Economy	17600.00
0005433869444	32608	Economy	17600.00
0005435860624	32608	Economy	17600.00
0005434460565	3461	Economy	22600.00
0005435911631	3461	Economy	22600.00
0005434663801	3461	Economy	22600.00
0005435911642	3461	Economy	22600.00
0005435911641	3461	Economy	22600.00
0005434461710	3461	Economy	22600.00
0005434461709	3461	Economy	22600.00
0005434460566	3461	Economy	22600.00
0005435911615	3461	Economy	22600.00
0005434663802	3461	Economy	22600.00
0005434663800	3461	Economy	22600.00
0005434663756	12476	Economy	22600.00
0005434663729	12476	Economy	22600.00
0005434663762	12476	Economy	22600.00
0005434663680	12476	Economy	22600.00
0005434663694	12476	Economy	22600.00
0005434663761	12476	Economy	22600.00
0005434663675	12476	Economy	22600.00
0005434663753	12476	Economy	22600.00
0005434663642	12476	Economy	22600.00
0005434663760	12476	Economy	22600.00
0005434663670	12476	Economy	22600.00
0005434663679	12476	Economy	22600.00
0005434663730	12476	Economy	22600.00
0005434663643	12476	Economy	22600.00
0005434663669	12476	Economy	22600.00
0005433869445	14498	Economy	18500.00
0005433869229	14498	Economy	18500.00
0005433869349	14498	Economy	18500.00
0005433869208	14498	Economy	18500.00
0005433869423	14498	Economy	16800.00
0005433869214	14498	Economy	16800.00
0005433869259	14498	Economy	16800.00
0005433869252	14498	Economy	16800.00
0005433869438	14498	Economy	16800.00
0005433869297	14498	Economy	16800.00
0005433869181	14498	Economy	16800.00
0005433869491	14498	Economy	16800.00
0005433869350	14498	Economy	16800.00
0005433869145	14498	Economy	16800.00
0005433869047	14498	Economy	16800.00
0005433869253	14498	Economy	16800.00
0005433869180	14498	Economy	16800.00
0005433869490	14498	Economy	16800.00
0005433869310	14498	Economy	16800.00
0005433869364	14498	Economy	16800.00
0005433869016	14498	Economy	16800.00
0005433869245	14498	Economy	16800.00
0005433869322	14498	Economy	16800.00
0005435860624	14498	Economy	16800.00
0005433869207	14498	Economy	16800.00
0005433869374	14498	Economy	16800.00
0005433869298	14498	Economy	16800.00
0005433869304	14498	Economy	16800.00
0005433869326	14498	Economy	16800.00
0005435860626	14498	Economy	16800.00
0005433869294	14498	Economy	16800.00
0005433869375	14498	Economy	16800.00
0005433869246	14498	Economy	16800.00
0005433869281	14498	Economy	16800.00
0005433869365	14498	Economy	16800.00
0005433869320	14498	Economy	16800.00
0005435860625	14498	Economy	16800.00
0005433869410	14498	Economy	16800.00
0005433869371	14498	Economy	16800.00
0005433869321	14498	Economy	16800.00
0005433869309	14498	Economy	16800.00
0005433869017	14498	Economy	16800.00
0005433869303	14498	Economy	16800.00
0005433869424	14498	Economy	16800.00
0005433869414	14498	Economy	16800.00
0005433869444	14498	Economy	16800.00
0005433869404	14498	Economy	16800.00
0005433869262	14498	Economy	16800.00
0005433869261	14498	Economy	16800.00
0005433869586	32668	Economy	18500.00
0005433869587	32668	Economy	16800.00
0005433869583	32668	Economy	16800.00
0005435860578	32668	Economy	16800.00
0005433869582	32668	Economy	16800.00
0005433869580	32668	Economy	16800.00
0005435860585	32668	Economy	16800.00
0005433869581	32668	Economy	16800.00
0005433869577	32668	Economy	16800.00
0005433869585	32668	Economy	16800.00
0005433869576	32668	Economy	16800.00
0005435860561	32668	Economy	16800.00
0005433869584	32668	Economy	16800.00
0005435860587	32668	Economy	16800.00
0005433869579	32668	Economy	16800.00
0005433869578	32668	Economy	16800.00
0005432800080	12094	Economy	4900.00
0005432799972	12094	Economy	4400.00
0005432800185	12094	Economy	4400.00
0005432800097	12094	Economy	4400.00
0005432799971	12094	Economy	4400.00
0005432800098	12094	Economy	4400.00
0005432800056	12094	Economy	4400.00
0005432800052	12094	Economy	4400.00
0005432799990	12094	Economy	4400.00
0005432800092	12094	Economy	4400.00
0005432800141	12094	Economy	4400.00
0005432800186	12094	Economy	4400.00
0005432799991	12094	Economy	4400.00
0005432800099	12094	Economy	4400.00
0005432800062	12094	Economy	4400.00
0005432800085	12094	Economy	4400.00
0005432800055	12094	Economy	4400.00
0005432800096	12094	Economy	4400.00
0005432800138	12094	Economy	4400.00
0005432800013	12094	Economy	4400.00
0005432800015	12094	Economy	4400.00
0005432800150	12094	Economy	4400.00
0005432800140	12094	Economy	4400.00
0005432800174	12094	Economy	4400.00
0005432800173	12094	Economy	4400.00
0005432800014	12094	Economy	4400.00
0005432800086	12094	Economy	4400.00
0005432800261	14787	Economy	4900.00
0005432800252	14787	Economy	4900.00
0005432800255	14787	Economy	4400.00
0005432800259	14787	Economy	4400.00
0005432800257	14787	Economy	4400.00
0005432800250	14787	Economy	4400.00
0005432800258	14787	Economy	4400.00
0005432800253	14787	Economy	4400.00
0005432800254	14787	Economy	4400.00
0005432800251	14787	Economy	4400.00
0005432800249	14787	Economy	4400.00
0005432800256	14787	Economy	4400.00
0005432800263	14787	Economy	4400.00
0005432800260	14787	Economy	4400.00
0005432800262	14787	Economy	4400.00
0005435311337	7058	Business	49100.00
0005434409591	7058	Business	49100.00
0005434300220	7058	Business	49100.00
0005434409595	7058	Business	49100.00
0005435293523	7058	Business	49100.00
0005434409581	7058	Business	49100.00
0005435311338	7058	Economy	16400.00
0005434409593	7058	Economy	16400.00
0005435293603	7058	Economy	16400.00
0005435311367	7058	Economy	16400.00
0005435311308	7058	Economy	16400.00
0005434409582	7058	Economy	16400.00
0005434300216	7058	Economy	16400.00
0005435311328	7058	Economy	16400.00
0005435311304	7058	Economy	16400.00
0005434409597	7058	Economy	16400.00
0005435311279	7058	Economy	16400.00
0005435311370	7058	Economy	16400.00
0005435293497	7058	Economy	16400.00
0005435293496	7058	Economy	16400.00
0005435293513	7058	Economy	16400.00
0005435311430	7058	Economy	16400.00
0005435293495	7058	Economy	16400.00
0005434409579	7058	Economy	16400.00
0005435311309	7058	Economy	16400.00
0005434409596	7058	Economy	16400.00
0005435311356	7058	Economy	16400.00
0005435311380	7058	Economy	16400.00
0005434409587	7058	Economy	18000.00
0005434409592	7058	Economy	18000.00
0005435293602	7058	Economy	18000.00
0005434300213	7058	Economy	18000.00
0005434409585	7058	Economy	18000.00
0005432154139	7058	Economy	16400.00
0005434409586	7058	Economy	16400.00
0005434409588	7058	Economy	16400.00
0005434409584	7058	Economy	16400.00
0005434300219	7058	Economy	16400.00
0005435293544	7058	Economy	16400.00
0005435311378	7058	Economy	16400.00
0005432154138	7058	Economy	16400.00
0005434409594	7058	Economy	16400.00
0005435293498	7058	Economy	16400.00
0005435311303	7058	Economy	16400.00
0005435293560	7058	Economy	16400.00
0005435293567	7058	Economy	16400.00
0005435293520	7058	Economy	16400.00
0005435311278	7058	Economy	16400.00
0005434409580	7058	Economy	16400.00
0005434300214	7058	Economy	16400.00
0005434300217	7058	Economy	16400.00
0005434300218	7058	Economy	16400.00
0005435311371	7058	Economy	16400.00
0005432154137	7058	Economy	16400.00
0005434409590	7058	Economy	16400.00
0005434409578	7058	Economy	16400.00
0005435311399	7058	Economy	16400.00
0005435311369	7058	Economy	16400.00
0005435293594	7058	Economy	16400.00
0005434300215	7058	Economy	16400.00
0005435311416	7058	Economy	16400.00
0005435311377	7058	Economy	16400.00
0005435293512	7058	Economy	16400.00
0005434409583	7058	Economy	16400.00
0005435293519	7058	Economy	16400.00
0005434409589	7058	Economy	16400.00
0005435293549	7058	Economy	16400.00
0005435293593	7058	Economy	16400.00
0005434300173	26899	Business	49100.00
0005434408919	26899	Business	49100.00
0005434409089	26899	Business	49100.00
0005434409181	26899	Business	49100.00
0005434409131	26899	Business	49100.00
0005434409022	26899	Business	49100.00
0005434409133	26899	Business	49100.00
0005434408923	26899	Business	49100.00
0005434409123	26899	Business	49100.00
0005434408842	26899	Economy	16400.00
0005434408942	26899	Economy	16400.00
0005432058494	26899	Economy	16400.00
0005434409045	26899	Economy	16400.00
0005434300126	26899	Economy	16400.00
0005435311529	26899	Economy	16400.00
0005435311537	26899	Economy	16400.00
0005434408889	26899	Economy	16400.00
0005434409167	26899	Economy	16400.00
0005435311525	26899	Economy	16400.00
0005434409137	26899	Economy	16400.00
0005435311527	26899	Economy	16400.00
0005434408761	26899	Economy	16400.00
0005434300172	26899	Economy	16400.00
0005434408973	26899	Economy	16400.00
0005434409100	26899	Economy	16400.00
0005435311535	26899	Economy	16400.00
0005435311531	26899	Economy	16400.00
0005435293622	26899	Economy	16400.00
0005434409092	26899	Economy	16400.00
0005434409289	26899	Economy	16400.00
0005434409337	26899	Economy	16400.00
0005434299990	26899	Economy	16400.00
0005435311533	26899	Economy	16400.00
0005432058495	26899	Economy	16400.00
0005434300071	26899	Economy	16400.00
0005434409122	26899	Economy	16400.00
0005434408982	26899	Economy	16400.00
0005434300118	26899	Economy	18000.00
0005434408918	26899	Economy	18000.00
0005434409110	26899	Economy	18000.00
0005435311526	26899	Economy	16400.00
0005434300042	26899	Economy	16400.00
0005434409156	26899	Economy	16400.00
0005434300163	26899	Economy	16400.00
0005434409172	26899	Economy	16400.00
0005435293621	26899	Economy	16400.00
0005434409124	26899	Economy	16400.00
0005434300200	26899	Economy	16400.00
0005434409338	26899	Economy	16400.00
0005435311536	26899	Economy	16400.00
0005434408940	26899	Economy	16400.00
0005434299989	26899	Economy	16400.00
0005434408963	26899	Economy	16400.00
0005434409252	26899	Economy	16400.00
0005435311532	26899	Economy	16400.00
0005434300164	26899	Economy	16400.00
0005434408905	26899	Economy	16400.00
0005435311534	26899	Economy	16400.00
0005435311530	26899	Economy	16400.00
0005434409037	26899	Economy	16400.00
0005434408984	26899	Economy	16400.00
0005434300152	26899	Economy	16400.00
0005434300114	26899	Economy	16400.00
0005434409273	26899	Economy	16400.00
0005434408792	26899	Economy	16400.00
0005434408750	26899	Economy	16400.00
0005434408974	26899	Economy	16400.00
0005435311528	26899	Economy	16400.00
0005434300117	26899	Economy	16400.00
0005434408970	26899	Economy	16400.00
0005434408770	26899	Economy	16400.00
0005434409009	26899	Economy	16400.00
0005434409020	26899	Economy	16400.00
0005434408999	26899	Economy	16400.00
0005434409028	26899	Economy	16400.00
0005434409290	26899	Economy	16400.00
0005434300094	26899	Economy	16400.00
0005434300116	26899	Economy	16400.00
0005434408886	26899	Economy	16400.00
0005434409036	26899	Economy	16400.00
0005434409175	26899	Economy	16400.00
0005434409166	26899	Economy	16400.00
0005434409021	26899	Economy	16400.00
0005434408971	26899	Economy	16400.00
0005435312896	6461	Economy	15000.00
0005432605486	6461	Economy	15000.00
0005432605482	6461	Economy	15000.00
0005435221552	6461	Economy	15000.00
0005432605489	6461	Economy	15000.00
0005432605488	6461	Economy	15000.00
0005435221551	6461	Economy	15000.00
0005434512257	6461	Economy	15000.00
0005432605481	6461	Economy	15000.00
0005432605490	6461	Economy	15000.00
0005434512258	6461	Economy	15000.00
0005434512255	6461	Economy	15000.00
0005432605487	6461	Economy	15000.00
0005434512256	6461	Economy	15000.00
0005432605483	6461	Economy	15000.00
0005434512254	6461	Economy	15000.00
0005432605485	6461	Economy	15000.00
0005432605484	6461	Economy	15000.00
0005435220497	6461	Economy	15000.00
0005432605245	21360	Economy	16500.00
0005432605096	21360	Economy	16500.00
0005432604943	21360	Economy	16500.00
0005432605174	21360	Economy	16500.00
0005432605078	21360	Economy	15000.00
0005432605218	21360	Economy	15000.00
0005432605172	21360	Economy	15000.00
0005432605129	21360	Economy	15000.00
0005432605154	21360	Economy	15000.00
0005432605064	21360	Economy	15000.00
0005432605039	21360	Economy	15000.00
0005432605217	21360	Economy	15000.00
0005432605153	21360	Economy	15000.00
0005432604977	21360	Economy	15000.00
0005432605089	21360	Economy	15000.00
0005432604941	21360	Economy	15000.00
0005432604942	21360	Economy	15000.00
0005432605143	21360	Economy	15000.00
0005432605053	21360	Economy	15000.00
0005432605155	21360	Economy	15000.00
0005432605077	21360	Economy	15000.00
0005432605148	21360	Economy	15000.00
0005432605097	21360	Economy	15000.00
0005432605259	21360	Economy	15000.00
0005432605017	21360	Economy	15000.00
0005432605173	21360	Economy	15000.00
0005432605152	21360	Economy	15000.00
0005432605206	21360	Economy	15000.00
0005432605016	21360	Economy	15000.00
0005432605215	21360	Economy	15000.00
0005432605273	21360	Economy	15000.00
0005432605260	21360	Economy	15000.00
0005432605168	21360	Economy	15000.00
0005432605208	21360	Economy	15000.00
0005432605119	21360	Economy	15000.00
0005432605131	21360	Economy	15000.00
0005432605022	21360	Economy	15000.00
0005432605088	21360	Economy	15000.00
0005432605161	21360	Economy	15000.00
0005432605205	21360	Economy	15000.00
0005432605207	21360	Economy	15000.00
0005432605015	21360	Economy	15000.00
0005432605144	21360	Economy	15000.00
0005432605091	21360	Economy	15000.00
0005432605264	21360	Economy	15000.00
0005432605272	21360	Economy	15000.00
0005432605194	21360	Economy	15000.00
0005432605130	21360	Economy	15000.00
0005432605090	21360	Economy	15000.00
0005432605238	21360	Economy	15000.00
0005434908365	14975	Business	18900.00
0005433252361	14975	Business	18900.00
0005434908154	14975	Business	18900.00
0005434908230	14975	Business	18900.00
0005434908286	14975	Business	18900.00
0005434908605	14975	Business	18900.00
0005434908452	14975	Business	18900.00
0005433252360	14975	Business	18900.00
0005434908245	14975	Business	18900.00
0005434908378	14975	Business	18900.00
0005434908368	14975	Business	18900.00
0005433252363	14975	Economy	6300.00
0005433252369	14975	Economy	6300.00
0005434908292	14975	Economy	6300.00
0005434908181	14975	Economy	6300.00
0005434908210	14975	Economy	6300.00
0005434908492	14975	Economy	6300.00
0005433252364	14975	Economy	6300.00
0005434908257	14975	Economy	6900.00
0005434908404	14975	Economy	6900.00
0005434908486	14975	Economy	6900.00
0005434908244	14975	Economy	6900.00
0005434908450	14975	Economy	6300.00
0005434908585	14975	Economy	6300.00
0005433252367	14975	Economy	6300.00
0005434908379	14975	Economy	6300.00
0005434908469	14975	Economy	6300.00
0005434908533	14975	Economy	6300.00
0005433252366	14975	Economy	6300.00
0005434908430	14975	Economy	6300.00
0005434908723	14975	Economy	6300.00
0005434908347	14975	Economy	6300.00
0005434908261	14975	Economy	6300.00
0005434908442	14975	Economy	6300.00
0005434908522	14975	Economy	6300.00
0005433252371	14975	Economy	6300.00
0005434908311	14975	Economy	6300.00
0005433252365	14975	Economy	6300.00
0005434908377	14975	Economy	6300.00
0005434908251	14975	Economy	6300.00
0005434908493	14975	Economy	6300.00
0005434908510	14975	Economy	6300.00
0005434908432	14975	Economy	6300.00
0005433252368	14975	Economy	6300.00
0005434908523	14975	Economy	6300.00
0005434908260	14975	Economy	6300.00
0005434908315	14975	Economy	6300.00
0005433252362	14975	Economy	6300.00
0005434908537	14975	Economy	6300.00
0005434908499	14975	Economy	6300.00
0005434908408	14975	Economy	6300.00
0005434908348	14975	Economy	6300.00
0005434908405	14975	Economy	6300.00
0005434908427	14975	Economy	6300.00
0005434908508	14975	Economy	6300.00
0005434908367	14975	Economy	6300.00
0005434908460	14975	Economy	6300.00
0005434908426	14975	Economy	6300.00
0005434908500	14975	Economy	6300.00
0005434908391	14975	Economy	6300.00
0005434908180	14975	Economy	6300.00
0005434908448	14975	Economy	6300.00
0005434908037	14975	Economy	6300.00
0005433252370	14975	Economy	6300.00
0005434908312	14975	Economy	6300.00
0005434908406	14975	Economy	6300.00
0005434908447	14975	Economy	6300.00
0005434908853	25857	Business	18900.00
0005433252022	25857	Business	18900.00
0005433252029	25857	Business	18900.00
0005433252304	25857	Business	18900.00
0005434908839	25857	Business	18900.00
0005434908821	25857	Business	18900.00
0005434908852	25857	Business	18900.00
0005434908848	25857	Business	18900.00
0005434908840	25857	Business	18900.00
0005434908831	25857	Economy	6300.00
0005433252079	25857	Economy	6300.00
0005434908825	25857	Economy	6300.00
0005434908845	25857	Economy	6300.00
0005434908836	25857	Economy	6900.00
0005434908851	25857	Economy	6900.00
0005434908823	25857	Economy	6900.00
0005434908838	25857	Economy	6900.00
0005434908832	25857	Economy	6300.00
0005433252008	25857	Economy	6300.00
0005434908837	25857	Economy	6300.00
0005434908826	25857	Economy	6300.00
0005434908842	25857	Economy	6300.00
0005434908828	25857	Economy	6300.00
0005433252177	25857	Economy	6300.00
0005433252170	25857	Economy	6300.00
0005433252199	25857	Economy	6300.00
0005434908844	25857	Economy	6300.00
0005433252140	25857	Economy	6300.00
0005433252119	25857	Economy	6300.00
0005434908846	25857	Economy	6300.00
0005434908830	25857	Economy	6300.00
0005434908843	25857	Economy	6300.00
0005434908833	25857	Economy	6300.00
0005433252064	25857	Economy	6300.00
0005433251982	25857	Economy	6300.00
0005433252190	25857	Economy	6300.00
0005433252290	25857	Economy	6300.00
0005434908829	25857	Economy	6300.00
0005433252241	25857	Economy	6300.00
0005434908847	25857	Economy	6300.00
0005433251991	25857	Economy	6300.00
0005434908835	25857	Economy	6300.00
0005434908827	25857	Economy	6300.00
0005433252027	25857	Economy	6300.00
0005434908841	25857	Economy	6300.00
0005434908854	25857	Economy	6300.00
0005434908822	25857	Economy	6300.00
0005433252200	25857	Economy	6300.00
0005434908820	25857	Economy	6300.00
0005433252141	25857	Economy	6300.00
0005434908850	25857	Economy	6300.00
0005434908824	25857	Economy	6300.00
0005433252164	25857	Economy	6300.00
0005433252178	25857	Economy	6300.00
0005434908834	25857	Economy	6300.00
0005433252289	25857	Economy	6300.00
0005433252065	25857	Economy	6300.00
0005434908849	25857	Economy	6300.00
0005433815584	9171	Economy	19900.00
0005434173641	9171	Economy	19900.00
0005434173639	9171	Economy	18100.00
0005434173649	9171	Economy	18100.00
0005434173640	9171	Economy	18100.00
0005434173638	9171	Economy	18100.00
0005433815578	9171	Economy	18100.00
0005433009954	14198	Business	52300.00
0005433009945	14198	Business	52300.00
0005433810628	14198	Business	52300.00
0005433810665	14198	Business	52300.00
0005433009952	14198	Business	52300.00
0005433810631	14198	Economy	17400.00
0005433810646	14198	Economy	17400.00
0005433009948	14198	Economy	17400.00
0005433810648	14198	Economy	19200.00
0005433009946	14198	Economy	19200.00
0005433810626	14198	Economy	19200.00
0005433009949	14198	Economy	17400.00
0005433009950	14198	Economy	17400.00
0005433009947	14198	Economy	17400.00
0005433810652	14198	Economy	17400.00
0005433810666	14198	Economy	17400.00
0005433810664	14198	Economy	17400.00
0005433009944	14198	Economy	17400.00
0005433810649	14198	Economy	17400.00
0005433810629	14198	Economy	17400.00
0005433810654	14198	Economy	17400.00
0005433009955	14198	Economy	17400.00
0005433009957	14198	Economy	17400.00
0005433810625	14198	Economy	17400.00
0005433009956	14198	Economy	17400.00
0005433009943	14198	Economy	17400.00
0005433810659	14198	Economy	17400.00
0005433810645	14198	Economy	17400.00
0005433009951	14198	Economy	17400.00
0005433810624	14198	Economy	17400.00
0005433810660	14198	Economy	17400.00
0005433009953	14198	Economy	17400.00
0005433009582	22861	Business	52300.00
0005433810755	22861	Business	52300.00
0005433009322	22861	Business	52300.00
0005433810758	22861	Economy	17400.00
0005433009574	22861	Economy	17400.00
0005433009685	22861	Economy	17400.00
0005433815577	22861	Economy	17400.00
0005433009542	22861	Economy	17400.00
0005433810760	22861	Economy	19200.00
0005433009527	22861	Economy	19200.00
0005433009611	22861	Economy	19200.00
0005433009471	22861	Economy	19200.00
0005433009540	22861	Economy	17400.00
0005433009636	22861	Economy	17400.00
0005433009488	22861	Economy	17400.00
0005433815575	22861	Economy	17400.00
0005433009609	22861	Economy	17400.00
0005433009760	22861	Economy	17400.00
0005433009549	22861	Economy	17400.00
0005433009531	22861	Economy	17400.00
0005433810753	22861	Economy	17400.00
0005433009457	22861	Economy	17400.00
0005433009520	22861	Economy	17400.00
0005433009458	22861	Economy	17400.00
0005433009546	22861	Economy	17400.00
0005433009573	22861	Economy	17400.00
0005433009470	22861	Economy	17400.00
0005433009726	22861	Economy	17400.00
0005433009635	22861	Economy	17400.00
0005433810754	22861	Economy	17400.00
0005433009650	22861	Economy	17400.00
0005433810759	22861	Economy	17400.00
0005433009430	22861	Economy	17400.00
0005433815576	22861	Economy	17400.00
0005433009327	22861	Economy	17400.00
0005433009526	22861	Economy	17400.00
0005433009496	22861	Economy	17400.00
0005433009578	22861	Economy	17400.00
0005433810757	22861	Economy	17400.00
0005433009701	22861	Economy	17400.00
0005433810752	22861	Economy	17400.00
0005433815574	22861	Economy	17400.00
0005433009459	22861	Economy	17400.00
0005433009690	22861	Economy	17400.00
0005433009618	22861	Economy	17400.00
0005433009619	22861	Economy	17400.00
0005433009692	22861	Economy	17400.00
0005433009547	22861	Economy	17400.00
0005433009379	22861	Economy	17400.00
0005433009456	22861	Economy	17400.00
0005433009651	22861	Economy	17400.00
0005433009697	22861	Economy	17400.00
0005433009364	22861	Economy	17400.00
0005433009761	22861	Economy	17400.00
0005433009431	22861	Economy	17400.00
0005433009581	22861	Economy	17400.00
0005433009579	22861	Economy	17400.00
0005433810756	22861	Economy	17400.00
0005434926471	14968	Business	22900.00
0005434926474	14968	Business	22900.00
0005434926506	14968	Business	22900.00
0005434926423	14968	Business	22900.00
0005434926468	14968	Economy	7600.00
0005434926525	14968	Economy	7600.00
0005434926564	14968	Economy	7600.00
0005434926533	14968	Economy	7600.00
0005434926461	14968	Economy	7600.00
0005434926483	14968	Economy	7600.00
0005434926458	14968	Economy	7600.00
0005434926493	14968	Economy	7600.00
0005434926484	14968	Economy	7600.00
0005434926457	14968	Economy	7600.00
0005434926496	14968	Economy	7600.00
0005434926536	14968	Economy	7600.00
0005434926520	14968	Economy	7600.00
0005434926417	14968	Economy	7600.00
0005434926494	14968	Economy	7600.00
0005434926473	14968	Economy	7600.00
0005434926462	14968	Economy	7600.00
0005434926374	14968	Economy	7600.00
0005434926400	14968	Economy	7600.00
0005434926548	14968	Economy	7600.00
0005434926328	14968	Economy	7600.00
0005434926470	14968	Economy	7600.00
0005434926519	14968	Economy	7600.00
0005434926816	20517	Business	22900.00
0005434926796	20517	Business	22900.00
0005434926813	20517	Economy	7600.00
0005434926811	20517	Economy	7600.00
0005434926806	20517	Economy	7600.00
0005434926799	20517	Economy	7600.00
0005434926804	20517	Economy	8400.00
0005434926809	20517	Economy	8400.00
0005434926803	20517	Economy	8400.00
0005434926798	20517	Economy	7600.00
0005434926808	20517	Economy	7600.00
0005434926812	20517	Economy	7600.00
0005434926807	20517	Economy	7600.00
0005434926817	20517	Economy	7600.00
0005434926801	20517	Economy	7600.00
0005434926815	20517	Economy	7600.00
0005434926800	20517	Economy	7600.00
0005434926797	20517	Economy	7600.00
0005434926810	20517	Economy	7600.00
0005434926805	20517	Economy	7600.00
0005434926795	20517	Economy	7600.00
0005434926814	20517	Economy	7600.00
0005434926802	20517	Economy	7600.00
0005435999587	15833	Economy	8900.00
0005435999749	15833	Economy	8900.00
0005435999555	15833	Economy	8100.00
0005435488470	15833	Economy	8100.00
0005435488467	15833	Economy	8100.00
0005435999676	15833	Economy	8100.00
0005435488466	15833	Economy	8100.00
0005435999722	15833	Economy	8100.00
0005435999675	15833	Economy	8100.00
0005435999636	15833	Economy	8100.00
0005435488471	15833	Economy	8100.00
0005435488468	15833	Economy	8100.00
0005435488469	15833	Economy	8100.00
0005435999664	15833	Economy	8100.00
0005435999750	15833	Economy	8100.00
0005435999618	15833	Economy	8100.00
0005435999672	15833	Economy	8100.00
0005435999619	15833	Economy	8100.00
0005435999728	15833	Economy	8100.00
0005435488472	15833	Economy	8100.00
0005435999673	15833	Economy	8100.00
0005435999709	15833	Economy	8100.00
0005435999710	15833	Economy	8100.00
0005435999565	15833	Economy	8100.00
0005435999614	15833	Economy	8100.00
0005435999632	15833	Economy	8100.00
0005435999740	15833	Economy	8100.00
0005435999600	15833	Economy	8100.00
0005435999836	19663	Economy	8900.00
0005435488321	19663	Economy	8900.00
0005435999825	19663	Economy	8900.00
0005435999823	19663	Economy	8900.00
0005435999819	19663	Economy	8100.00
0005435999822	19663	Economy	8100.00
0005435999835	19663	Economy	8100.00
0005435999820	19663	Economy	8100.00
0005435999840	19663	Economy	8100.00
0005435999824	19663	Economy	8100.00
0005435999821	19663	Economy	8100.00
0005435488330	19663	Economy	8100.00
0005435999832	19663	Economy	8100.00
0005435999833	19663	Economy	8100.00
0005435488249	19663	Economy	8100.00
0005435999818	19663	Economy	8100.00
0005435999817	19663	Economy	8100.00
0005435488263	19663	Economy	8100.00
0005435999829	19663	Economy	8100.00
0005435488171	19663	Economy	8100.00
0005435999827	19663	Economy	8100.00
0005435488289	19663	Economy	8100.00
0005435999828	19663	Economy	8100.00
0005435999831	19663	Economy	8100.00
0005435999837	19663	Economy	8100.00
0005435999834	19663	Economy	8100.00
0005435488211	19663	Economy	8100.00
0005435488253	19663	Economy	8100.00
0005435999830	19663	Economy	8100.00
0005435999838	19663	Economy	8100.00
0005435999816	19663	Economy	8100.00
0005435488322	19663	Economy	8100.00
0005435488331	19663	Economy	8100.00
0005435999839	19663	Economy	8100.00
0005435488314	19663	Economy	8100.00
0005435488309	19663	Economy	8100.00
0005435488266	19663	Economy	8100.00
0005435999826	19663	Economy	8100.00
0005435840267	6020	Business	199300.00
0005435473104	6020	Business	199300.00
0005435473213	6020	Business	199300.00
0005435473156	6020	Business	199300.00
0005435473192	6020	Economy	66400.00
0005432142343	6020	Economy	66400.00
0005435473179	6020	Economy	66400.00
0005432658653	6020	Economy	66400.00
0005435473217	6020	Economy	66400.00
0005435473193	6020	Economy	73100.00
0005435473194	6020	Economy	66400.00
0005435840266	6020	Economy	66400.00
0005435473151	6020	Economy	66400.00
0005435840273	6020	Economy	66400.00
0005435473126	6020	Economy	66400.00
0005432659768	6020	Economy	66400.00
0005435473155	6020	Economy	66400.00
0005432142344	6020	Economy	66400.00
0005435473212	6020	Economy	66400.00
0005435473139	6020	Economy	66400.00
0005435473200	6020	Economy	66400.00
0005435840270	6020	Economy	66400.00
0005435473169	6020	Economy	66400.00
0005435473158	6020	Economy	66400.00
0005435473170	6020	Economy	66400.00
0005435840265	6020	Economy	66400.00
0005435840271	6020	Economy	66400.00
0005435473115	6020	Economy	66400.00
0005435473198	6020	Economy	66400.00
0005435473201	6020	Economy	66400.00
0005435473127	6020	Economy	66400.00
0005435473214	6020	Economy	66400.00
0005435473216	6020	Economy	66400.00
0005435473138	6020	Economy	66400.00
0005435473173	6020	Economy	66400.00
0005435840268	6020	Economy	66400.00
0005435840272	6020	Economy	66400.00
0005435840269	6020	Economy	66400.00
0005435840264	6020	Economy	66400.00
0005435473285	18055	Business	199300.00
0005435840181	18055	Business	199300.00
0005435840031	18055	Business	199300.00
0005435840084	18055	Business	199300.00
0005435840061	18055	Business	199300.00
0005432537121	18055	Business	199300.00
0005435839994	18055	Business	199300.00
0005435840172	18055	Economy	66400.00
0005435840062	18055	Economy	66400.00
0005432667495	18055	Economy	66400.00
0005435840103	18055	Economy	66400.00
0005435473289	18055	Economy	66400.00
0005435473288	18055	Economy	66400.00
0005435473284	18055	Economy	66400.00
0005435839995	18055	Economy	66400.00
0005435840131	18055	Economy	66400.00
0005435840123	18055	Economy	66400.00
0005435840011	18055	Economy	66400.00
0005435840086	18055	Economy	66400.00
0005435473286	18055	Economy	66400.00
0005435840097	18055	Economy	66400.00
0005432537122	18055	Economy	66400.00
0005432667489	18055	Economy	66400.00
0005432664174	18055	Economy	66400.00
0005435840022	18055	Economy	66400.00
0005435840173	18055	Economy	66400.00
0005435473287	18055	Economy	66400.00
0005435840180	18055	Economy	66400.00
0005435473283	18055	Economy	66400.00
0005435840052	18055	Economy	66400.00
0005435840098	18055	Economy	66400.00
0005435839993	18055	Economy	66400.00
0005435840105	18055	Economy	66400.00
0005435840099	18055	Economy	66400.00
0005435104320	23001	Business	15700.00
0005433286095	23001	Business	15700.00
0005435104319	23001	Business	15700.00
0005433285893	23001	Business	15700.00
0005433286003	23001	Business	15700.00
0005435104331	23001	Business	15700.00
0005433286022	23001	Business	15700.00
0005433286031	23001	Business	15700.00
0005435104330	23001	Economy	5200.00
0005435104325	23001	Economy	5200.00
0005435104338	23001	Economy	5200.00
0005433286156	23001	Economy	5200.00
0005433285976	23001	Economy	5200.00
0005435104329	23001	Economy	5200.00
0005435104334	23001	Economy	5200.00
0005435104335	23001	Economy	5200.00
0005435104327	23001	Economy	5200.00
0005435104318	23001	Economy	5200.00
0005433286142	23001	Economy	5200.00
0005435104337	23001	Economy	5200.00
0005433285894	23001	Economy	5200.00
0005433286040	23001	Economy	5200.00
0005435104324	23001	Economy	5200.00
0005435104323	23001	Economy	5700.00
0005435104326	23001	Economy	5700.00
0005433285892	23001	Economy	5700.00
0005433285942	23001	Economy	5200.00
0005433286096	23001	Economy	5200.00
0005435104342	23001	Economy	5200.00
0005433286032	23001	Economy	5200.00
0005433285977	23001	Economy	5200.00
0005433286043	23001	Economy	5200.00
0005433286082	23001	Economy	5200.00
0005433285972	23001	Economy	5200.00
0005433285973	23001	Economy	5200.00
0005433286104	23001	Economy	5200.00
0005433285873	23001	Economy	5200.00
0005433285987	23001	Economy	5200.00
0005433286001	23001	Economy	5200.00
0005435104336	23001	Economy	5200.00
0005435104321	23001	Economy	5200.00
0005435104322	23001	Economy	5200.00
0005435104328	23001	Economy	5200.00
0005433286052	23001	Economy	5200.00
0005435104340	23001	Economy	5200.00
0005433285986	23001	Economy	5200.00
0005435104333	23001	Economy	5200.00
0005433286004	23001	Economy	5200.00
0005433285946	23001	Economy	5200.00
0005435104341	23001	Economy	5200.00
0005435104332	23001	Economy	5200.00
0005433286103	23001	Economy	5200.00
0005433285959	23001	Economy	5200.00
0005433286002	23001	Economy	5200.00
0005433285897	23001	Economy	5200.00
0005435104339	23001	Economy	5200.00
0005433286051	23001	Economy	5200.00
0005433286033	23001	Economy	5200.00
0005433286105	23001	Economy	5200.00
0005435104124	32078	Economy	5200.00
0005433286210	32078	Economy	5200.00
0005435104138	32078	Economy	5200.00
0005435104106	32078	Economy	5200.00
0005435104086	32078	Economy	5200.00
0005435104093	32078	Economy	5200.00
0005433286205	32078	Economy	5200.00
0005433286208	32078	Economy	5200.00
0005435104067	32078	Economy	5200.00
0005435104084	32078	Economy	5200.00
0005435104123	32078	Economy	5700.00
0005433286207	32078	Economy	5700.00
0005433286209	32078	Economy	5700.00
0005435104107	32078	Economy	5200.00
0005435104126	32078	Economy	5200.00
0005435104068	32078	Economy	5200.00
0005435104143	32078	Economy	5200.00
0005433286202	32078	Economy	5200.00
0005433286206	32078	Economy	5200.00
0005435104142	32078	Economy	5200.00
0005433286204	32078	Economy	5200.00
0005433286203	32078	Economy	5200.00
0005435104085	32078	Economy	5200.00
0005433286212	32078	Economy	5200.00
0005433286211	32078	Economy	5200.00
0005435104094	32078	Economy	5200.00
0005435104141	32078	Economy	5200.00
0005433286213	32078	Economy	5200.00
0005433286201	32078	Economy	5200.00
0005435104077	32078	Economy	5200.00
0005433475798	23880	Economy	13500.00
0005433475807	23880	Economy	12300.00
0005433475812	23880	Economy	12300.00
0005435852653	23880	Economy	12300.00
0005433475781	23880	Economy	12300.00
0005433475815	23880	Economy	12300.00
0005433475814	23880	Economy	12300.00
0005434069087	30613	Business	42100.00
0005435215511	30613	Business	42100.00
0005434069485	30613	Business	42100.00
0005435283537	30613	Business	42100.00
0005432530634	30613	Business	42100.00
0005434069251	30613	Business	42100.00
0005434069179	30613	Business	42100.00
0005432535947	30613	Business	42100.00
0005432530926	30613	Business	42100.00
0005432531215	30613	Business	42100.00
0005434068816	30613	Business	42100.00
0005434069263	30613	Business	42100.00
0005432531397	30613	Business	42100.00
0005432531163	30613	Business	42100.00
0005432530799	30613	Business	42100.00
0005432531380	30613	Comfort	23900.00
0005435215522	30613	Comfort	23900.00
0005434068986	30613	Comfort	23900.00
0005432531263	30613	Comfort	23900.00
0005435215525	30613	Comfort	23900.00
0005435215514	30613	Comfort	23900.00
0005432530818	30613	Comfort	23900.00
0005434068934	30613	Comfort	23900.00
0005432530644	30613	Comfort	23900.00
0005435283538	30613	Comfort	23900.00
0005432530081	30613	Comfort	23900.00
0005432530859	30613	Comfort	23900.00
0005432531099	30613	Comfort	23900.00
0005434069174	30613	Comfort	23900.00
0005435215518	30613	Comfort	23900.00
0005435283536	30613	Comfort	23900.00
0005434069129	30613	Comfort	23900.00
0005432530943	30613	Comfort	23900.00
0005432533353	30613	Comfort	23900.00
0005434068899	30613	Comfort	23900.00
0005432531216	30613	Comfort	23900.00
0005432530917	30613	Comfort	23900.00
0005435283542	30613	Comfort	23900.00
0005432530847	30613	Comfort	23900.00
0005432533358	30613	Comfort	23900.00
0005434068955	30613	Comfort	23900.00
0005434068848	30613	Comfort	23900.00
0005434069343	30613	Comfort	23900.00
0005432530898	30613	Comfort	23900.00
0005434068984	30613	Comfort	23900.00
0005432531258	30613	Economy	14000.00
0005432530773	30613	Comfort	23900.00
0005434069007	30613	Economy	14000.00
0005434069137	30613	Economy	14000.00
0005434069177	30613	Economy	14000.00
0005432530629	30613	Economy	14000.00
0005432530897	30613	Economy	14000.00
0005432530737	30613	Economy	14000.00
0005432531352	30613	Economy	14000.00
0005432530542	30613	Economy	14000.00
0005432530927	30613	Economy	14000.00
0005432530754	30613	Economy	14000.00
0005432531214	30613	Economy	14000.00
0005434068855	30613	Economy	14000.00
0005432531202	30613	Economy	14000.00
0005434069062	30613	Economy	14000.00
0005432530686	30613	Economy	14000.00
0005432530597	30613	Economy	14000.00
0005432531136	30613	Economy	14000.00
0005432530889	30613	Economy	14000.00
0005432531064	30613	Economy	14000.00
0005434069014	30613	Economy	14000.00
0005432530655	30613	Economy	14000.00
0005432531157	30613	Economy	14000.00
0005432530685	30613	Economy	14000.00
0005432531185	30613	Economy	14000.00
0005435215527	30613	Economy	14000.00
0005432531209	30613	Economy	14000.00
0005432531282	30613	Economy	14000.00
0005432530980	30613	Economy	14000.00
0005432530748	30613	Economy	14000.00
0005432531137	30613	Economy	14000.00
0005432531039	30613	Economy	14000.00
0005434069238	30613	Economy	14000.00
0005432533360	30613	Economy	14000.00
0005432530821	30613	Economy	14000.00
0005432531184	30613	Economy	14000.00
0005432530769	30613	Economy	14000.00
0005434069060	30613	Economy	14000.00
0005434069133	30613	Economy	14000.00
0005432530782	30613	Economy	14000.00
0005432531192	30613	Economy	14000.00
0005435215513	30613	Economy	14000.00
0005432530082	30613	Economy	14000.00
0005434069085	30613	Economy	14000.00
0005432531060	30613	Economy	14000.00
0005434069333	30613	Economy	14000.00
0005432530736	30613	Economy	14000.00
0005434069063	30613	Economy	15400.00
0005434069145	30613	Economy	14000.00
0005432530996	30613	Economy	14000.00
0005432530537	30613	Economy	14000.00
0005432530573	30613	Economy	14000.00
0005432530651	30613	Economy	15400.00
0005432530918	30613	Economy	15400.00
0005432531280	30613	Economy	14000.00
0005432530666	30613	Economy	14000.00
0005434069068	30613	Economy	14000.00
0005432530723	30613	Economy	14000.00
0005434068917	30613	Economy	14000.00
0005432531338	30613	Economy	14000.00
0005432530947	30613	Economy	14000.00
0005432531127	30613	Economy	14000.00
0005435215515	30613	Economy	14000.00
0005434069019	30613	Economy	14000.00
0005434069451	30613	Economy	14000.00
0005432530783	30613	Economy	14000.00
0005432530635	30613	Economy	14000.00
0005434069164	30613	Economy	14000.00
0005432530430	30613	Economy	14000.00
0005434069020	30613	Economy	14000.00
0005435215519	30613	Economy	14000.00
0005432531308	30613	Economy	14000.00
0005432530969	30613	Economy	14000.00
0005434069006	30613	Economy	14000.00
0005435215517	30613	Economy	14000.00
0005432530851	30613	Economy	14000.00
0005432531043	30613	Economy	14000.00
0005432531372	30613	Economy	14000.00
0005432531309	30613	Economy	14000.00
0005434069196	30613	Economy	14000.00
0005432531218	30613	Economy	14000.00
0005434069105	30613	Economy	14000.00
0005434069331	30613	Economy	14000.00
0005434069144	30613	Economy	14000.00
0005432531016	30613	Economy	14000.00
0005434069178	30613	Economy	14000.00
0005432530942	30613	Economy	14000.00
0005432531669	30613	Economy	14000.00
0005432530954	30613	Economy	14000.00
0005434069267	30613	Economy	14000.00
0005432530809	30613	Economy	14000.00
0005434069322	30613	Economy	14000.00
0005434069071	30613	Economy	14000.00
0005432531005	30613	Economy	14000.00
0005434069256	30613	Economy	14000.00
0005432531516	30613	Economy	14000.00
0005432530986	30613	Economy	14000.00
0005432530819	30613	Economy	14000.00
0005432531193	30613	Economy	14000.00
0005434069128	30613	Economy	14000.00
0005435215524	30613	Economy	14000.00
0005435215510	30613	Economy	14000.00
0005432531201	30613	Economy	14000.00
0005434069072	30613	Economy	14000.00
0005432530850	30613	Economy	14000.00
0005434069070	30613	Economy	14000.00
0005434069086	30613	Economy	14000.00
0005432530733	30613	Economy	14000.00
0005435215521	30613	Economy	14000.00
0005434069173	30613	Economy	14000.00
0005435215520	30613	Economy	14000.00
0005432531283	30613	Economy	14000.00
0005434069264	30613	Economy	14000.00
0005434069375	30613	Economy	14000.00
0005434069061	30613	Economy	14000.00
0005432531281	30613	Economy	14000.00
0005432531294	30613	Economy	14000.00
0005432530979	30613	Economy	14000.00
0005432211724	30613	Economy	14000.00
0005434069323	30613	Economy	14000.00
0005432531068	30613	Economy	14000.00
0005435215512	30613	Economy	15400.00
0005434069078	30613	Economy	15400.00
0005432530755	30613	Economy	15400.00
0005434069342	30613	Economy	15400.00
0005432530941	30613	Economy	15400.00
0005435215526	30613	Economy	14000.00
0005432531156	30613	Economy	14000.00
0005435283535	30613	Economy	14000.00
0005432531279	30613	Economy	14000.00
0005434069130	30613	Economy	14000.00
0005432531088	30613	Economy	14000.00
0005432530970	30613	Economy	14000.00
0005432530953	30613	Economy	14000.00
0005434069239	30613	Economy	14000.00
0005434068972	30613	Economy	14000.00
0005435215523	30613	Economy	14000.00
0005432531320	30613	Economy	14000.00
0005432531379	30613	Economy	14000.00
0005432531105	30613	Economy	14000.00
0005432531369	30613	Economy	14000.00
0005432530587	30613	Economy	14000.00
0005434068957	30613	Economy	14000.00
0005435283539	30613	Economy	14000.00
0005434069005	30613	Economy	14000.00
0005435283541	30613	Economy	14000.00
0005432531089	30613	Economy	14000.00
0005434069136	30613	Economy	14000.00
0005434069075	30613	Economy	14000.00
0005432159992	30613	Economy	14000.00
0005432530667	30613	Economy	14000.00
0005432530712	30613	Economy	14000.00
0005432530885	30613	Economy	14000.00
0005432530883	30613	Economy	14000.00
0005432530477	30613	Economy	14000.00
0005432530886	30613	Economy	14000.00
0005434069252	30613	Economy	14000.00
0005432530576	30613	Economy	14000.00
0005432530656	30613	Economy	14000.00
0005434069073	30613	Economy	14000.00
0005434069385	30613	Economy	14000.00
0005434068900	30613	Economy	14000.00
0005432530846	30613	Economy	14000.00
0005432531069	30613	Economy	14000.00
0005434069018	30613	Economy	14000.00
0005432530541	30613	Economy	14000.00
0005432533359	30613	Economy	14000.00
0005434069285	30613	Economy	14000.00
0005434069450	30613	Economy	14000.00
0005435283540	30613	Economy	14000.00
0005432530920	30613	Economy	14000.00
0005432530529	30613	Economy	14000.00
0005434068979	30613	Economy	14000.00
0005432531034	30613	Economy	14000.00
0005432531295	30613	Economy	14000.00
0005435215516	30613	Economy	14000.00
0005432531446	30613	Economy	14000.00
0005432531033	30613	Economy	14000.00
0005434069074	30613	Economy	14000.00
0005435283543	30613	Economy	14000.00
0005434069240	30613	Economy	14000.00
0005434069102	30613	Economy	14000.00
0005432531351	30613	Economy	14000.00
0005432531009	30613	Economy	14000.00
0005432531284	30613	Economy	14000.00
0005432530919	30613	Economy	14000.00
0005432531264	30613	Economy	14000.00
0005432531056	30613	Economy	14000.00
0005432531177	30613	Economy	14000.00
0005432531327	30613	Economy	14000.00
0005435653924	24864	Business	9800.00
0005433368977	24864	Business	9800.00
0005435654199	24864	Economy	3300.00
0005435654277	24864	Economy	3300.00
0005435654089	24864	Economy	3300.00
0005435653976	24864	Economy	3300.00
0005435654074	24864	Economy	3300.00
0005435654087	24864	Economy	3600.00
0005435653850	24864	Economy	3600.00
0005435790414	24864	Economy	3600.00
0005435654041	24864	Economy	3300.00
0005435654224	24864	Economy	3300.00
0005435654133	24864	Economy	3300.00
0005435654155	24864	Economy	3300.00
0005435654125	24864	Economy	3300.00
0005435653847	24864	Economy	3300.00
0005435654169	24864	Economy	3300.00
0005435653978	24864	Economy	3300.00
0005435654081	24864	Economy	3300.00
0005435654227	24864	Economy	3300.00
0005435654036	24864	Economy	3300.00
0005435653878	24864	Economy	3300.00
0005435653877	24864	Economy	3300.00
0005435653851	24864	Economy	3300.00
0005435790415	24864	Economy	3300.00
0005435654054	24864	Economy	3300.00
0005435654118	24864	Economy	3300.00
0005435654020	24864	Economy	3300.00
0005435654152	24864	Economy	3300.00
0005435654150	24864	Economy	3300.00
0005435654200	24864	Economy	3300.00
0005435654194	24864	Economy	3300.00
0005435654002	24864	Economy	3300.00
0005435653989	24864	Economy	3300.00
0005435654049	24864	Economy	3300.00
0005435654228	24864	Economy	3300.00
0005435654132	24864	Economy	3300.00
0005433368978	24864	Economy	3300.00
0005435654044	24864	Economy	3300.00
0005435654168	24864	Economy	3300.00
0005433368979	24864	Economy	3300.00
0005435654076	24864	Economy	3300.00
0005435653902	24864	Economy	3300.00
0005435654012	24864	Economy	3300.00
0005435654126	24864	Economy	3300.00
0005435654195	24864	Economy	3300.00
0005435949868	6595	Economy	18700.00
0005435949869	6595	Economy	18700.00
0005435949865	6595	Economy	18700.00
0005435949866	6595	Economy	18700.00
0005435949867	6595	Economy	18700.00
0005434980665	2060	Economy	10500.00
0005434980673	2060	Economy	9500.00
0005434980667	2060	Economy	9500.00
0005434980672	2060	Economy	9500.00
0005434980668	2060	Economy	9500.00
0005434980669	2060	Economy	9500.00
0005434980671	2060	Economy	9500.00
0005434980664	2060	Economy	9500.00
0005434980674	2060	Economy	9500.00
0005434980670	2060	Economy	9500.00
0005434980666	2060	Economy	9500.00
0005434980453	23584	Economy	10500.00
0005434980501	23584	Economy	10500.00
0005434980421	23584	Economy	9500.00
0005434980489	23584	Economy	9500.00
0005434980422	23584	Economy	9500.00
0005434980339	23584	Economy	9500.00
0005434980462	23584	Economy	9500.00
0005434980380	23584	Economy	9500.00
0005434980487	23584	Economy	9500.00
0005434980455	23584	Economy	9500.00
0005434980461	23584	Economy	9500.00
0005434980483	23584	Economy	9500.00
0005434980544	23584	Economy	9500.00
0005434980534	23584	Economy	9500.00
0005434980391	23584	Economy	9500.00
0005434980454	23584	Economy	9500.00
0005434980463	23584	Economy	9500.00
0005434980526	23584	Economy	9500.00
0005434980381	23584	Economy	9500.00
0005434980426	23584	Economy	9500.00
0005434980476	23584	Economy	9500.00
0005434980527	23584	Economy	9500.00
0005434980406	23584	Economy	9500.00
0005434980338	23584	Economy	9500.00
0005433256480	2624	Economy	5300.00
0005433256479	2624	Economy	5300.00
0005433256475	2624	Economy	5300.00
0005433256483	2624	Economy	5300.00
0005433256476	2624	Economy	5300.00
0005433256482	2624	Economy	5300.00
0005434952626	28274	Economy	5300.00
0005434952627	28274	Economy	5300.00
0005434952602	28274	Economy	5300.00
0005434952614	28274	Economy	5300.00
0005434952604	28274	Economy	5300.00
0005434952603	28274	Economy	5300.00
0005433111567	19756	Economy	8700.00
0005434302886	19756	Economy	8700.00
0005433112423	19756	Economy	8700.00
0005434302885	19756	Economy	8700.00
0005434139865	11924	Business	9700.00
0005434139525	11924	Business	9700.00
0005434140217	11924	Business	9700.00
0005434139895	11924	Business	9700.00
0005434140450	11924	Business	9700.00
0005435283597	11924	Business	9700.00
0005434140073	11924	Business	9700.00
0005434139726	11924	Business	9700.00
0005434140148	11924	Business	9700.00
0005434139937	11924	Business	9700.00
0005434139847	11924	Business	9700.00
0005434140147	11924	Economy	3200.00
0005434140056	11924	Economy	3200.00
0005434139829	11924	Economy	3200.00
0005434140129	11924	Economy	3200.00
0005434140109	11924	Economy	3200.00
0005434140021	11924	Economy	3200.00
0005435283592	11924	Economy	3200.00
0005434139962	11924	Economy	3200.00
0005434140046	11924	Economy	3200.00
0005435283593	11924	Economy	3500.00
0005434139760	11924	Economy	3500.00
0005434140072	11924	Economy	3500.00
0005435283591	11924	Economy	3500.00
0005434140346	11924	Economy	3200.00
0005434139896	11924	Economy	3200.00
0005434140123	11924	Economy	3200.00
0005435283595	11924	Economy	3200.00
0005434140065	11924	Economy	3200.00
0005434139851	11924	Economy	3200.00
0005434140039	11924	Economy	3200.00
0005434140089	11924	Economy	3200.00
0005434139961	11924	Economy	3200.00
0005434140064	11924	Economy	3200.00
0005434140045	11924	Economy	3200.00
0005434140029	11924	Economy	3200.00
0005434140415	11924	Economy	3200.00
0005434139920	11924	Economy	3200.00
0005434139759	11924	Economy	3200.00
0005434140215	11924	Economy	3200.00
0005434140122	11924	Economy	3200.00
0005434140249	11924	Economy	3200.00
0005434140108	11924	Economy	3200.00
0005434140066	11924	Economy	3200.00
0005434139999	11924	Economy	3200.00
0005434140449	11924	Economy	3200.00
0005434139998	11924	Economy	3200.00
0005434140044	11924	Economy	3200.00
0005434139830	11924	Economy	3200.00
0005434140258	11924	Economy	3200.00
0005434139968	11924	Economy	3200.00
0005434139997	11924	Economy	3200.00
0005434140099	11924	Economy	3200.00
0005434140216	11924	Economy	3200.00
0005434139859	11924	Economy	3200.00
0005434139990	11924	Economy	3200.00
0005434140128	11924	Economy	3200.00
0005435283594	11924	Economy	3200.00
0005435283596	11924	Economy	3200.00
0005434139993	11924	Economy	3200.00
0005434139831	11924	Economy	3200.00
0005434139872	11924	Economy	3200.00
0005434140012	11924	Economy	3200.00
0005434140164	11924	Economy	3200.00
0005434139919	11924	Economy	3200.00
0005434139614	11924	Economy	3200.00
0005434139905	11924	Economy	3200.00
0005434139967	11924	Economy	3200.00
0005434139469	11924	Economy	3200.00
0005434139969	11924	Economy	3200.00
0005434139868	11924	Economy	3200.00
0005434140011	11924	Economy	3200.00
0005434140063	11924	Economy	3200.00
0005434139524	11924	Economy	3200.00
0005434139860	11924	Economy	3200.00
0005434139938	11924	Economy	3200.00
0005434140055	11924	Economy	3200.00
0005434139712	11924	Economy	3200.00
0005434139523	11924	Economy	3200.00
0005434139989	11924	Economy	3200.00
0005434140100	11924	Economy	3200.00
0005434140136	11924	Economy	3200.00
0005434140003	11924	Economy	3200.00
0005434140320	11924	Economy	3200.00
0005434139727	11924	Economy	3200.00
0005434139763	11924	Economy	3200.00
0005434139882	11924	Economy	3200.00
0005434140211	11924	Economy	3200.00
0005434139705	11924	Economy	3200.00
0005434140578	28713	Business	9700.00
0005434140555	28713	Business	9700.00
0005434140582	28713	Business	9700.00
0005434140552	28713	Business	9700.00
0005434140584	28713	Business	9700.00
0005434140581	28713	Business	9700.00
0005434140554	28713	Economy	3200.00
0005434140568	28713	Economy	3500.00
0005434140553	28713	Economy	3500.00
0005434140550	28713	Economy	3500.00
0005434140574	28713	Economy	3500.00
0005434140560	28713	Economy	3200.00
0005434140587	28713	Economy	3200.00
0005434140570	28713	Economy	3200.00
0005434140567	28713	Economy	3200.00
0005434140573	28713	Economy	3200.00
0005434140564	28713	Economy	3200.00
0005434140572	28713	Economy	3200.00
0005434140565	28713	Economy	3200.00
0005434140580	28713	Economy	3200.00
0005434140575	28713	Economy	3200.00
0005434140583	28713	Economy	3200.00
0005434140585	28713	Economy	3200.00
0005434140576	28713	Economy	3200.00
0005434140588	28713	Economy	3200.00
0005434140559	28713	Economy	3200.00
0005434140556	28713	Economy	3200.00
0005434140569	28713	Economy	3200.00
0005434140586	28713	Economy	3200.00
0005434140563	28713	Economy	3200.00
0005434140579	28713	Economy	3200.00
0005434140551	28713	Economy	3200.00
0005434140562	28713	Economy	3200.00
0005434140561	28713	Economy	3200.00
0005434140566	28713	Economy	3200.00
0005434140558	28713	Economy	3200.00
0005434140571	28713	Economy	3200.00
0005434140557	28713	Economy	3200.00
0005434140577	28713	Economy	3200.00
0005435312852	6585	Economy	20900.00
0005435312863	6585	Economy	20900.00
0005434466607	6585	Economy	20900.00
0005434466609	6585	Economy	20900.00
0005435312858	6585	Economy	20900.00
0005434466606	6585	Economy	20900.00
0005435312853	6585	Economy	20900.00
0005434466610	6585	Economy	20900.00
0005434466605	6585	Economy	20900.00
0005435312861	6585	Economy	20900.00
0005434466608	6585	Economy	20900.00
0005435259864	6824	Economy	10900.00
0005433534562	6824	Economy	9900.00
0005435259870	6824	Economy	9900.00
0005433539122	6824	Economy	9900.00
0005433539121	6824	Economy	9900.00
0005435259869	6824	Economy	9900.00
0005433539092	25004	Economy	9900.00
0005433539093	25004	Economy	9900.00
0005433539073	25004	Economy	9900.00
0005433539091	25004	Economy	9900.00
0005433539085	25004	Economy	9900.00
0005433539084	25004	Economy	9900.00
0005433534547	25004	Economy	9900.00
0005433539086	25004	Economy	9900.00
0005433539087	25004	Economy	9900.00
0005433512192	833	Economy	14600.00
0005432922611	833	Economy	14600.00
0005432922604	833	Economy	14600.00
0005432922600	833	Economy	14600.00
0005432922630	833	Economy	14600.00
0005433512193	833	Economy	14600.00
0005433512191	833	Economy	14600.00
0005433512164	16172	Economy	16100.00
0005433512168	16172	Economy	14600.00
0005432922639	16172	Economy	14600.00
0005433512154	16172	Economy	14600.00
0005433512147	16172	Economy	14600.00
0005433512131	16172	Economy	14600.00
0005433512141	16172	Economy	14600.00
0005432922640	16172	Economy	14600.00
0005433512149	16172	Economy	14600.00
0005433512148	16172	Economy	14600.00
0005433512153	16172	Economy	14600.00
0005435698165	3691	Economy	7200.00
0005435698166	3691	Economy	7200.00
0005435698169	3691	Economy	7200.00
0005435698170	3691	Economy	7200.00
0005435916238	3691	Economy	7200.00
0005435698168	3691	Economy	7200.00
0005435698167	3691	Economy	7200.00
0005435916232	3691	Economy	7200.00
0005435698164	3691	Economy	7200.00
0005435933588	16288	Economy	7900.00
0005435697953	16288	Economy	7200.00
0005434950615	16288	Economy	7200.00
0005435697899	16288	Economy	7200.00
0005435698114	16288	Economy	7200.00
0005435697976	16288	Economy	7200.00
0005435697831	16288	Economy	7200.00
0005435697967	16288	Economy	7200.00
0005434950624	16288	Economy	7200.00
0005435697868	16288	Economy	7200.00
0005435935135	16288	Economy	7200.00
0005435698022	16288	Economy	7200.00
0005435697952	16288	Economy	7200.00
0005435698021	16288	Economy	7200.00
0005435697898	16288	Economy	7200.00
0005435697993	16288	Economy	7200.00
0005435697854	16288	Economy	7200.00
0005435697966	16288	Economy	7200.00
0005435697937	16288	Economy	7200.00
0005434950623	16288	Economy	7200.00
0005435697838	16288	Economy	7200.00
0005435697924	16288	Economy	7200.00
0005435697832	16288	Economy	7200.00
0005435697855	16288	Economy	7200.00
0005435697900	16288	Economy	7200.00
0005435933587	16288	Economy	7200.00
0005435697992	16288	Economy	7200.00
0005435697994	16288	Economy	7200.00
0005435697968	16288	Economy	7200.00
0005435697853	16288	Economy	7200.00
0005435698034	16288	Economy	7200.00
0005435698002	16288	Economy	7200.00
0005435697936	16288	Economy	7200.00
0005435935136	16288	Economy	7200.00
0005434950614	16288	Economy	7200.00
0005434605007	3976	Economy	19300.00
0005435842347	3976	Economy	19300.00
0005435904719	3976	Economy	19300.00
0005435904908	3976	Economy	19300.00
0005435853658	3976	Economy	19300.00
0005435842349	3976	Economy	19300.00
0005435842350	3976	Economy	19300.00
0005435904720	3976	Economy	19300.00
0005434606937	3976	Economy	19300.00
0005435853654	3976	Economy	19300.00
0005434606936	3976	Economy	19300.00
0005435842342	3976	Economy	19300.00
0005433519559	22090	Economy	21300.00
0005433519587	22090	Economy	21300.00
0005433519562	22090	Economy	21300.00
0005435904729	22090	Economy	19300.00
0005434606894	22090	Economy	19300.00
0005433519566	22090	Economy	19300.00
0005435904915	22090	Economy	19300.00
0005434606892	22090	Economy	19300.00
0005433519548	22090	Economy	19300.00
0005433519564	22090	Economy	19300.00
0005433519586	22090	Economy	19300.00
0005433519556	22090	Economy	19300.00
0005433519555	22090	Economy	19300.00
0005434606893	22090	Economy	19300.00
0005433519563	22090	Economy	19300.00
0005435904914	22090	Economy	19300.00
0005433349126	698	Economy	3700.00
0005433349091	698	Economy	3700.00
0005433349102	698	Economy	3700.00
0005433349122	698	Economy	3700.00
0005433349094	698	Economy	3700.00
0005433349127	698	Economy	3700.00
0005433349134	698	Economy	3700.00
0005435628830	698	Economy	3700.00
0005433349132	698	Economy	3700.00
0005435628798	15977	Economy	3700.00
0005435628804	15977	Economy	3700.00
0005433349166	15977	Economy	3700.00
0005433349167	15977	Economy	3700.00
0005435628803	15977	Economy	3700.00
0005434445325	17248	Economy	7100.00
0005434445324	17248	Economy	7100.00
0005433159358	17248	Economy	7100.00
0005433158178	17248	Economy	7100.00
0005434446589	17248	Economy	7100.00
0005433159353	17248	Economy	7100.00
0005433159364	17248	Economy	7100.00
0005434445323	17248	Economy	7100.00
0005433159363	17248	Economy	7100.00
0005435383278	7883	Economy	5400.00
0005435383266	7883	Economy	5400.00
0005435383271	7883	Economy	5400.00
0005435133194	7883	Economy	5400.00
0005435383269	7883	Economy	5400.00
0005435133197	7883	Economy	5400.00
0005435383279	7883	Economy	5400.00
0005435133196	7883	Economy	5400.00
0005435133195	7883	Economy	5400.00
0005435383277	7883	Economy	5400.00
0005435133139	33079	Economy	5900.00
0005435133126	33079	Economy	5900.00
0005435133172	33079	Economy	5400.00
0005435133091	33079	Economy	5400.00
0005435133128	33079	Economy	5400.00
0005435133124	33079	Economy	5400.00
0005435133170	33079	Economy	5400.00
0005435133171	33079	Economy	5400.00
0005435133166	33079	Economy	5400.00
0005435133127	33079	Economy	5400.00
0005435133125	33079	Economy	5400.00
0005435133137	33079	Economy	5400.00
0005435938949	4418	Business	133200.00
0005435938938	4418	Business	133200.00
0005435938940	4418	Economy	48800.00
0005435811226	4418	Economy	44400.00
0005435938947	4418	Economy	44400.00
0005435938939	4418	Economy	44400.00
0005435938942	4418	Economy	44400.00
0005435811227	4418	Economy	44400.00
0005435811182	29440	Business	133200.00
0005435811203	29440	Business	133200.00
0005435811171	29440	Economy	44400.00
0005435811185	29440	Economy	44400.00
0005435811170	29440	Economy	44400.00
0005435811201	29440	Economy	44400.00
0005435811211	29440	Economy	44400.00
0005435811181	29440	Economy	44400.00
0005435390402	7510	Economy	13800.00
0005435390415	7510	Economy	12500.00
0005435390409	7510	Economy	12500.00
0005435390368	7510	Economy	12500.00
0005435390374	7510	Economy	12500.00
0005435390401	7510	Economy	12500.00
0005435390369	7510	Economy	12500.00
0005435390373	7510	Economy	12500.00
0005435390410	7510	Economy	12500.00
0005435390388	7510	Economy	12500.00
0005435390439	29534	Economy	13800.00
0005435160601	29534	Economy	12500.00
0005435160578	29534	Economy	12500.00
0005435160602	29534	Economy	12500.00
0005435160565	29534	Economy	12500.00
0005435390440	29534	Economy	12500.00
0005435390438	29534	Economy	12500.00
0005435160559	29534	Economy	12500.00
0005435160552	29534	Economy	12500.00
0005435160598	29534	Economy	12500.00
0005435160599	29534	Economy	12500.00
0005432394192	18426	Economy	4900.00
0005432398282	18426	Economy	4900.00
0005432398285	18426	Economy	4900.00
0005432398281	18426	Economy	4900.00
0005435178540	18426	Economy	4900.00
0005432398302	27147	Economy	4900.00
0005435179418	27147	Economy	4900.00
0005432398303	27147	Economy	4900.00
0005435179417	27147	Economy	4900.00
0005432866192	2247	Economy	29100.00
0005432866182	2247	Economy	29100.00
0005432866159	2247	Economy	32000.00
0005432866167	2247	Economy	29100.00
0005432639501	2247	Economy	29100.00
0005432639498	2247	Economy	29100.00
0005432639499	2247	Economy	29100.00
0005432866178	2247	Economy	29100.00
0005432866189	2247	Economy	29100.00
0005432866160	2247	Economy	29100.00
0005432639496	2247	Economy	29100.00
0005432866183	2247	Economy	29100.00
0005432866168	2247	Economy	29100.00
0005432866180	2247	Economy	29100.00
0005432866144	2247	Economy	29100.00
0005432866181	2247	Economy	29100.00
0005432866150	2247	Economy	29100.00
0005432866191	2247	Economy	29100.00
0005432639500	2247	Economy	29100.00
0005432866179	2247	Economy	29100.00
0005432639497	2247	Economy	29100.00
0005432866176	2247	Economy	29100.00
0005433811681	24294	Business	105400.00
0005433811683	24294	Business	105400.00
0005433811680	24294	Economy	35100.00
0005433811684	24294	Economy	35100.00
0005433811690	24294	Economy	35100.00
0005433811688	24294	Economy	35100.00
0005433811682	24294	Economy	38600.00
0005433811687	24294	Economy	35100.00
0005433811686	24294	Economy	35100.00
0005433811689	24294	Economy	35100.00
0005433811685	24294	Economy	35100.00
0005433811691	24294	Economy	35100.00
0005434552918	9721	Economy	4400.00
0005434191320	32841	Economy	4400.00
0005434191323	32841	Economy	4400.00
0005434191326	32841	Economy	4400.00
0005434191324	32841	Economy	4400.00
0005434191328	32841	Economy	4400.00
0005434191327	32841	Economy	4400.00
0005434191325	32841	Economy	4400.00
0005434191322	32841	Economy	4400.00
0005434191321	32841	Economy	4400.00
0005434191319	32841	Economy	4400.00
0005434191329	32841	Economy	4400.00
0005432661955	26490	Business	92200.00
0005432661972	26490	Business	92200.00
0005432661957	26490	Business	92200.00
0005432665323	26490	Business	92200.00
0005432658641	26490	Business	92200.00
0005432658629	26490	Business	92200.00
0005432665309	26490	Business	92200.00
0005432661968	26490	Business	92200.00
0005432658640	26490	Business	92200.00
0005432658636	26490	Business	92200.00
0005432661956	26490	Business	92200.00
0005432661973	26490	Business	92200.00
0005432661962	26490	Economy	30700.00
0005432665312	26490	Economy	30700.00
0005432661969	26490	Economy	30700.00
0005432661974	26490	Economy	30700.00
0005432658625	26490	Economy	33800.00
0005432661967	26490	Economy	33800.00
0005432665319	26490	Economy	33800.00
0005432661947	26490	Economy	30700.00
0005432661949	26490	Economy	30700.00
0005432661954	26490	Economy	30700.00
0005432661964	26490	Economy	30700.00
0005432658638	26490	Economy	30700.00
0005432665308	26490	Economy	30700.00
0005432658618	26490	Economy	30700.00
0005432658621	26490	Economy	30700.00
0005432658634	26490	Economy	30700.00
0005432665322	26490	Economy	30700.00
0005432658620	26490	Economy	30700.00
0005432665306	26490	Economy	30700.00
0005432665310	26490	Economy	30700.00
0005432661948	26490	Economy	30700.00
0005432658622	26490	Economy	30700.00
0005432658639	26490	Economy	30700.00
0005432665314	26490	Economy	30700.00
0005432658631	26490	Economy	30700.00
0005432658630	26490	Economy	30700.00
0005432665307	26490	Economy	30700.00
0005432661961	26490	Economy	30700.00
0005432658624	26490	Economy	30700.00
0005432661971	26490	Economy	30700.00
0005432665299	26490	Economy	30700.00
0005432661963	26490	Economy	30700.00
0005432658637	26490	Economy	30700.00
0005432665315	26490	Economy	30700.00
0005432661959	26490	Economy	30700.00
0005432661966	26490	Economy	30700.00
0005432661970	26490	Economy	30700.00
0005432658633	26490	Economy	30700.00
0005432665311	26490	Economy	30700.00
0005432658619	26490	Economy	30700.00
0005432661958	26490	Economy	30700.00
0005432658635	26490	Economy	30700.00
0005434505314	6522	Business	48400.00
0005435104368	6522	Business	48400.00
0005434505315	6522	Business	48400.00
0005435104369	6522	Economy	16100.00
0005434505310	6522	Economy	16100.00
0005435104367	6522	Economy	17800.00
0005434505306	6522	Economy	17800.00
0005435104373	6522	Economy	16100.00
0005434505301	6522	Economy	16100.00
0005435104366	6522	Economy	16100.00
0005434505303	6522	Economy	16100.00
0005434505307	6522	Economy	16100.00
0005435104365	6522	Economy	16100.00
0005434505311	6522	Economy	16100.00
0005435104376	6522	Economy	16100.00
0005434505313	6522	Economy	16100.00
0005434505302	6522	Economy	16100.00
0005434505305	6522	Economy	16100.00
0005435104371	6522	Economy	16100.00
0005435104372	6522	Economy	16100.00
0005434505304	6522	Economy	16100.00
0005435104374	6522	Economy	16100.00
0005434505308	6522	Economy	16100.00
0005435104375	6522	Economy	16100.00
0005435104370	6522	Economy	16100.00
0005434505309	6522	Economy	16100.00
0005434505312	6522	Economy	16100.00
0005434505045	22691	Business	48400.00
0005434505054	22691	Business	48400.00
0005435104077	22691	Business	48400.00
0005434504850	22691	Business	48400.00
0005434505055	22691	Business	48400.00
0005434504849	22691	Business	48400.00
0005435104093	22691	Economy	16100.00
0005434504985	22691	Economy	16100.00
0005434505223	22691	Economy	16100.00
0005434505046	22691	Economy	16100.00
0005434505058	22691	Economy	16100.00
0005434504968	22691	Economy	16100.00
0005434504952	22691	Economy	17800.00
0005434504872	22691	Economy	17800.00
0005434505047	22691	Economy	17800.00
0005435104123	22691	Economy	16100.00
0005434504997	22691	Economy	16100.00
0005434504942	22691	Economy	16100.00
0005434504996	22691	Economy	16100.00
0005434504932	22691	Economy	16100.00
0005434504895	22691	Economy	16100.00
0005434504955	22691	Economy	16100.00
0005434504994	22691	Economy	16100.00
0005435104143	22691	Economy	16100.00
0005434504892	22691	Economy	16100.00
0005434504961	22691	Economy	16100.00
0005434505065	22691	Economy	16100.00
0005435104106	22691	Economy	16100.00
0005435104085	22691	Economy	16100.00
0005434504904	22691	Economy	16100.00
0005434505048	22691	Economy	16100.00
0005435104126	22691	Economy	16100.00
0005435104094	22691	Economy	16100.00
0005434504923	22691	Economy	16100.00
0005435104068	22691	Economy	16100.00
0005434504919	22691	Economy	16100.00
0005434504846	22691	Economy	16100.00
0005434504984	22691	Economy	16100.00
0005434505004	22691	Economy	16100.00
0005435104086	22691	Economy	16100.00
0005434504795	22691	Economy	16100.00
0005435104142	22691	Economy	16100.00
0005435104107	22691	Economy	16100.00
0005435104067	22691	Economy	16100.00
0005434504967	22691	Economy	16100.00
0005434504912	22691	Economy	16100.00
0005434504828	22691	Economy	16100.00
0005435104138	22691	Economy	16100.00
0005434504951	22691	Economy	16100.00
0005434504995	22691	Economy	16100.00
0005434504905	22691	Economy	16100.00
0005434504986	22691	Economy	16100.00
0005434504972	22691	Economy	16100.00
0005435104084	22691	Economy	16100.00
0005435104124	22691	Economy	16100.00
0005435104141	22691	Economy	16100.00
0005434504962	22691	Economy	16100.00
0005433368880	1674	Business	50000.00
0005433368477	1674	Business	50000.00
0005433368762	1674	Business	50000.00
0005435654478	1674	Business	50000.00
0005433368882	1674	Business	50000.00
0005433368732	1674	Business	50000.00
0005433368736	1674	Economy	16700.00
0005433368826	1674	Economy	16700.00
0005433368735	1674	Economy	16700.00
0005433368624	1674	Economy	16700.00
0005433368827	1674	Economy	16700.00
0005435654482	1674	Economy	18300.00
0005435654485	1674	Economy	18300.00
0005435654476	1674	Economy	16700.00
0005433368744	1674	Economy	16700.00
0005435654475	1674	Economy	16700.00
0005433368625	1674	Economy	16700.00
0005433368507	1674	Economy	16700.00
0005435654474	1674	Economy	16700.00
0005433368887	1674	Economy	16700.00
0005433368819	1674	Economy	16700.00
0005433368626	1674	Economy	16700.00
0005435654480	1674	Economy	16700.00
0005433368766	1674	Economy	16700.00
0005433368564	1674	Economy	16700.00
0005433368767	1674	Economy	16700.00
0005433368825	1674	Economy	16700.00
0005433368645	1674	Economy	16700.00
0005433368820	1674	Economy	16700.00
0005433368859	1674	Economy	16700.00
0005433368871	1674	Economy	16700.00
0005435654483	1674	Economy	16700.00
0005433368607	1674	Economy	16700.00
0005435654477	1674	Economy	16700.00
0005433368651	1674	Economy	16700.00
0005433368608	1674	Economy	16700.00
0005435654479	1674	Economy	16700.00
0005435654481	1674	Economy	16700.00
0005433368508	1674	Economy	16700.00
0005433368813	1674	Economy	16700.00
0005433368584	1674	Economy	16700.00
0005433368612	1674	Economy	16700.00
0005433368857	1674	Economy	16700.00
0005433368858	1674	Economy	16700.00
0005435654484	1674	Economy	16700.00
0005433368860	1674	Economy	16700.00
0005433368872	1674	Economy	16700.00
0005435790410	1674	Economy	16700.00
0005435653989	21693	Business	50000.00
0005435653924	21693	Business	50000.00
0005435654076	21693	Business	50000.00
0005435654150	21693	Business	50000.00
0005435654089	21693	Business	50000.00
0005435654020	21693	Business	50000.00
0005435654228	21693	Economy	16700.00
0005435654049	21693	Economy	16700.00
0005435654054	21693	Economy	16700.00
0005433368977	21693	Economy	16700.00
0005435654118	21693	Economy	16700.00
0005435653850	21693	Economy	18300.00
0005435653847	21693	Economy	18300.00
0005435653851	21693	Economy	16700.00
0005433368979	21693	Economy	16700.00
0005435653878	21693	Economy	16700.00
0005435654126	21693	Economy	16700.00
0005435654200	21693	Economy	16700.00
0005435654152	21693	Economy	16700.00
0005435654168	21693	Economy	16700.00
0005435653902	21693	Economy	16700.00
0005435654199	21693	Economy	16700.00
0005435654002	21693	Economy	16700.00
0005435654194	21693	Economy	16700.00
0005435653978	21693	Economy	16700.00
0005435654155	21693	Economy	16700.00
0005435654277	21693	Economy	16700.00
0005435654074	21693	Economy	16700.00
0005435654133	21693	Economy	16700.00
0005435653877	21693	Economy	16700.00
0005433368978	21693	Economy	16700.00
0005435654041	21693	Economy	16700.00
0005435654036	21693	Economy	16700.00
0005435654224	21693	Economy	16700.00
0005435654125	21693	Economy	16700.00
0005435653976	21693	Economy	16700.00
0005435654081	21693	Economy	16700.00
0005435654132	21693	Economy	16700.00
0005435654087	21693	Economy	16700.00
0005435654169	21693	Economy	16700.00
0005435654012	21693	Economy	16700.00
0005435654044	21693	Economy	16700.00
0005435654227	21693	Economy	16700.00
0005435654195	21693	Economy	16700.00
0005434466582	23238	Economy	23000.00
0005434466563	23238	Economy	20900.00
0005435312879	23238	Economy	20900.00
0005434466562	23238	Economy	20900.00
0005434466581	23238	Economy	20900.00
0005434466568	23238	Economy	20900.00
0005434466567	23238	Economy	20900.00
0005434466564	23238	Economy	20900.00
0005434466569	23238	Economy	20900.00
0005435312878	23238	Economy	20900.00
0005433987372	4167	Business	21500.00
0005433987368	4167	Economy	7200.00
0005433987370	4167	Economy	7900.00
0005433987369	4167	Economy	7200.00
0005433987371	4167	Economy	7200.00
0005433987367	4167	Economy	7200.00
0005433986959	25671	Business	21500.00
0005433987075	25671	Business	21500.00
0005433986939	25671	Business	21500.00
0005433986885	25671	Business	21500.00
0005433986903	25671	Business	21500.00
0005433986859	25671	Economy	7200.00
0005433987211	25671	Economy	7200.00
0005433986833	25671	Economy	7200.00
0005433986853	25671	Economy	7200.00
0005433987016	25671	Economy	7200.00
0005433986797	25671	Economy	7200.00
0005433986883	25671	Economy	7200.00
0005433986919	25671	Economy	7200.00
0005433986879	25671	Economy	7900.00
0005433986848	25671	Economy	7900.00
0005433986994	25671	Economy	7900.00
0005433986881	25671	Economy	7200.00
0005433986993	25671	Economy	7200.00
0005433987012	25671	Economy	7200.00
0005433987162	25671	Economy	7200.00
0005433987065	25671	Economy	7200.00
0005433986950	25671	Economy	7200.00
0005433987210	25671	Economy	7200.00
0005433986938	25671	Economy	7200.00
0005433986899	25671	Economy	7200.00
0005433986894	25671	Economy	7200.00
0005435788834	25671	Economy	7200.00
0005433986982	25671	Economy	7200.00
0005433986892	25671	Economy	7200.00
0005433987064	25671	Economy	7200.00
0005433987044	25671	Economy	7200.00
0005433987117	25671	Economy	7200.00
0005433986855	25671	Economy	7200.00
0005433986878	25671	Economy	7200.00
0005433987122	25671	Economy	7200.00
0005433986960	25671	Economy	7200.00
0005433987001	25671	Economy	7200.00
0005435788833	25671	Economy	7200.00
0005433986912	25671	Economy	7200.00
0005433986893	25671	Economy	7200.00
0005433986868	25671	Economy	7200.00
0005433986898	25671	Economy	7200.00
0005433986922	25671	Economy	7200.00
0005433987116	25671	Economy	7200.00
0005433986904	25671	Economy	7200.00
0005433987090	25671	Economy	7200.00
0005435788835	25671	Economy	7200.00
0005433987023	25671	Economy	7200.00
0005433987067	25671	Economy	7200.00
0005433986895	25671	Economy	7200.00
0005433987068	25671	Economy	7200.00
0005433987013	25671	Economy	7200.00
0005433986880	25671	Economy	7200.00
0005433986693	25671	Economy	7200.00
0005433986884	25671	Economy	7200.00
0005433987091	25671	Economy	7200.00
0005433986856	25671	Economy	7200.00
0005433986958	25671	Economy	7200.00
0005435720844	21247	Economy	9400.00
0005434509376	1618	Economy	17000.00
0005433168463	1618	Economy	15500.00
0005434509378	1618	Economy	15500.00
0005433168473	1618	Economy	15500.00
0005434509375	1618	Economy	15500.00
0005433168461	1618	Economy	15500.00
0005434509374	1618	Economy	15500.00
0005433168468	1618	Economy	15500.00
0005433168448	1618	Economy	15500.00
0005433168469	1618	Economy	15500.00
0005434509377	1618	Economy	15500.00
0005434509379	1618	Economy	15500.00
0005434190455	9018	Economy	23600.00
0005434190447	9018	Economy	23600.00
0005434190459	9018	Economy	23600.00
0005434190449	9018	Economy	23600.00
0005434190448	9018	Economy	23600.00
0005434516140	9018	Economy	23600.00
0005434190453	9018	Economy	23600.00
0005434190454	9018	Economy	23600.00
0005432660868	17846	Business	18000.00
0005432660869	17846	Business	18000.00
0005432655767	17846	Economy	6000.00
0005432655826	17846	Economy	6000.00
0005432655772	17846	Economy	6600.00
0005432659751	17846	Economy	6600.00
0005432666434	17846	Economy	6000.00
0005434151795	17846	Economy	6000.00
0005432661960	17846	Economy	6000.00
0005432655764	17846	Economy	6000.00
0005432658645	17846	Economy	6000.00
0005432663077	17846	Economy	6000.00
0005432655781	17846	Economy	6000.00
0005432655771	17846	Economy	6000.00
0005432663078	17846	Economy	6000.00
0005432664184	17846	Economy	6000.00
0005432655839	17846	Economy	6000.00
0005432664173	17846	Economy	6000.00
0005432667500	17846	Economy	6000.00
0005432665321	17846	Economy	6000.00
0005432664179	17846	Economy	6000.00
0005432869725	17846	Economy	6000.00
0005432665320	17846	Economy	6000.00
0005432658632	17846	Economy	6000.00
0005432666443	17846	Economy	6000.00
0005432655765	17846	Economy	6000.00
0005432655828	17846	Economy	6000.00
0005434151794	17846	Economy	6000.00
0005432659752	17846	Economy	6000.00
0005432667515	26313	Business	18000.00
0005432655882	26313	Business	18000.00
0005432655885	26313	Economy	6000.00
0005432655881	26313	Economy	6000.00
0005432655886	26313	Economy	6000.00
0005432869648	26313	Economy	6000.00
0005432665336	26313	Economy	6600.00
0005432660882	26313	Economy	6000.00
0005432869675	26313	Economy	6000.00
0005432660881	26313	Economy	6000.00
0005432869674	26313	Economy	6000.00
0005432658652	26313	Economy	6000.00
0005432869673	26313	Economy	6000.00
0005432655883	26313	Economy	6000.00
0005432869649	26313	Economy	6000.00
0005432665335	26313	Economy	6000.00
0005432667516	26313	Economy	6000.00
0005432655884	26313	Economy	6000.00
0005432869650	26313	Economy	6000.00
0005432639402	25071	Business	87300.00
0005432639446	25071	Business	87300.00
0005432639401	25071	Economy	29100.00
0005432639420	25071	Economy	29100.00
0005432639412	25071	Economy	29100.00
0005432639366	25071	Economy	32000.00
0005432639400	25071	Economy	29100.00
0005432639398	25071	Economy	29100.00
0005432639419	25071	Economy	29100.00
0005432639372	25071	Economy	29100.00
0005432639379	25071	Economy	29100.00
0005432639418	25071	Economy	29100.00
0005432639422	25071	Economy	29100.00
0005432866219	25071	Economy	29100.00
0005432639417	25071	Economy	29100.00
0005432639380	25071	Economy	29100.00
0005432639421	25071	Economy	29100.00
0005432639399	25071	Economy	29100.00
0005432639440	25071	Economy	29100.00
0005432639461	25071	Economy	29100.00
0005432639387	25071	Economy	29100.00
0005432639444	25071	Economy	29100.00
0005432639445	25071	Economy	29100.00
0005432639441	25071	Economy	29100.00
0005432639462	25071	Economy	29100.00
0005432905240	3103	Business	16100.00
0005432330049	3103	Economy	5400.00
0005432330044	3103	Economy	5400.00
0005433439108	3103	Economy	5900.00
0005432330047	3103	Economy	5400.00
0005432905254	3103	Economy	5400.00
0005432905256	3103	Economy	5400.00
0005432905238	3103	Economy	5400.00
0005433439109	3103	Economy	5400.00
0005432330046	3103	Economy	5400.00
0005433439107	3103	Economy	5400.00
0005432330051	3103	Economy	5400.00
0005432905253	3103	Economy	5400.00
0005432848892	3103	Economy	5400.00
0005432905239	3103	Economy	5400.00
0005432330042	3103	Economy	5400.00
0005432848893	3103	Economy	5400.00
0005432330050	3103	Economy	5400.00
0005432330043	3103	Economy	5400.00
0005432905255	3103	Economy	5400.00
0005432330040	3103	Economy	5400.00
0005432330045	3103	Economy	5400.00
0005432905223	3103	Economy	5400.00
0005432330048	3103	Economy	5400.00
0005432905270	3103	Economy	5400.00
0005432330041	3103	Economy	5400.00
0005432329677	31112	Business	16100.00
0005433439060	31112	Business	16100.00
0005432329690	31112	Business	16100.00
0005432848910	31112	Business	16100.00
0005432329913	31112	Business	16100.00
0005432329897	31112	Business	16100.00
0005432848914	31112	Business	16100.00
0005432329669	31112	Business	16100.00
0005432329754	31112	Business	16100.00
0005432329821	31112	Business	16100.00
0005432848917	31112	Economy	5400.00
0005432329728	31112	Economy	5400.00
0005432905294	31112	Economy	5400.00
0005432329855	31112	Economy	5400.00
0005432329753	31112	Economy	5400.00
0005432329775	31112	Economy	5400.00
0005432329699	31112	Economy	5400.00
0005432329841	31112	Economy	5900.00
0005432329629	31112	Economy	5900.00
0005432848911	31112	Economy	5900.00
0005432329846	31112	Economy	5900.00
0005432848916	31112	Economy	5400.00
0005432054392	31112	Economy	5400.00
0005432329739	31112	Economy	5400.00
0005432329854	31112	Economy	5400.00
0005432329752	31112	Economy	5400.00
0005432848912	31112	Economy	5400.00
0005432848915	31112	Economy	5400.00
0005432329585	31112	Economy	5400.00
0005432329847	31112	Economy	5400.00
0005432329853	31112	Economy	5400.00
0005432329531	31112	Economy	5400.00
0005432329848	31112	Economy	5400.00
0005432329852	31112	Economy	5400.00
0005433439030	31112	Economy	5400.00
0005433439017	31112	Economy	5400.00
0005432329698	31112	Economy	5400.00
0005432329511	31112	Economy	5400.00
0005433439051	31112	Economy	5400.00
0005432329729	31112	Economy	5400.00
0005433439009	31112	Economy	5400.00
0005432848913	31112	Economy	5400.00
0005432329667	31112	Economy	5400.00
0005432329851	31112	Economy	5400.00
0005432329741	31112	Economy	5400.00
0005432329680	31112	Economy	5400.00
0005433438999	31112	Economy	5400.00
0005432329611	31112	Economy	5400.00
0005432329676	31112	Economy	5400.00
0005432329776	31112	Economy	5400.00
0005432329659	31112	Economy	5400.00
0005432329513	31112	Economy	5400.00
0005432329512	31112	Economy	5400.00
0005432905293	31112	Economy	5400.00
0005433439045	31112	Economy	5400.00
0005433439031	31112	Economy	5400.00
0005432329702	31112	Economy	5400.00
0005432329710	31112	Economy	5400.00
0005432329786	31112	Economy	5400.00
0005432329760	31112	Economy	5400.00
0005432905295	31112	Economy	5400.00
0005432329628	31112	Economy	5400.00
0005433438998	31112	Economy	5400.00
0005432329467	31112	Economy	5400.00
0005432329689	31112	Economy	5400.00
0005432329678	31112	Economy	5400.00
0005432054393	31112	Economy	5400.00
0005435488304	6204	Business	124600.00
0005435297205	6204	Business	124600.00
0005435488305	6204	Business	124600.00
0005435488355	6204	Business	124600.00
0005435488268	6204	Business	124600.00
0005435488360	6204	Business	124600.00
0005434310145	6204	Economy	41500.00
0005435488267	6204	Economy	41500.00
0005435488232	6204	Economy	41500.00
0005435297207	6204	Economy	41500.00
0005435488282	6204	Economy	41500.00
0005435488306	6204	Economy	41500.00
0005435488279	6204	Economy	41500.00
0005435488296	6204	Economy	41500.00
0005435488356	6204	Economy	41500.00
0005435297218	6204	Economy	41500.00
0005435999854	6204	Economy	41500.00
0005435297223	6204	Economy	41500.00
0005435297224	6204	Economy	41500.00
0005435999852	6204	Economy	41500.00
0005435488275	6204	Economy	41500.00
0005435488354	6204	Economy	41500.00
0005435488236	6204	Economy	41500.00
0005435488346	6204	Economy	41500.00
0005435488313	6204	Economy	41500.00
0005435488358	6204	Economy	41500.00
0005435488357	6204	Economy	41500.00
0005435999856	6204	Economy	45700.00
0005435488365	6204	Economy	45700.00
0005435297233	6204	Economy	45700.00
0005435488315	6204	Economy	41500.00
0005434310144	6204	Economy	41500.00
0005435297196	6204	Economy	41500.00
0005435488295	6204	Economy	41500.00
0005435297225	6204	Economy	41500.00
0005435999855	6204	Economy	41500.00
0005435488262	6204	Economy	41500.00
0005434310146	6204	Economy	41500.00
0005435488328	6204	Economy	41500.00
0005435488283	6204	Economy	41500.00
0005435488254	6204	Economy	41500.00
0005435297239	6204	Economy	41500.00
0005435999857	6204	Economy	41500.00
0005435999859	6204	Economy	41500.00
0005435488361	6204	Economy	41500.00
0005435999851	6204	Economy	41500.00
0005435488347	6204	Economy	41500.00
0005434310143	6204	Economy	41500.00
0005435999853	6204	Economy	41500.00
0005435488323	6204	Economy	41500.00
0005435488403	6204	Economy	41500.00
0005435488237	6204	Economy	41500.00
0005435488327	6204	Economy	41500.00
0005435999860	6204	Economy	41500.00
0005435488335	6204	Economy	41500.00
0005435999858	6204	Economy	41500.00
0005435297195	6204	Economy	41500.00
0005435488398	6204	Economy	41500.00
0005435488319	6204	Economy	41500.00
0005435488287	6204	Economy	41500.00
0005434310147	6204	Economy	41500.00
0005435999710	19524	Business	124600.00
0005435488469	19524	Business	124600.00
0005435999565	19524	Business	124600.00
0005435999632	19524	Business	124600.00
0005435999555	19524	Economy	41500.00
0005435488471	19524	Economy	41500.00
0005435999636	19524	Economy	41500.00
0005434310047	19524	Economy	41500.00
0005435999619	19524	Economy	41500.00
0005434310043	19524	Economy	41500.00
0005434310050	19524	Economy	41500.00
0005434310018	19524	Economy	41500.00
0005435999709	19524	Economy	45700.00
0005435999675	19524	Economy	45700.00
0005434310045	19524	Economy	41500.00
0005434310035	19524	Economy	41500.00
0005435999587	19524	Economy	41500.00
0005435999618	19524	Economy	41500.00
0005435999664	19524	Economy	41500.00
0005435488466	19524	Economy	41500.00
0005435999672	19524	Economy	41500.00
0005435999728	19524	Economy	41500.00
0005435999750	19524	Economy	41500.00
0005435488472	19524	Economy	41500.00
0005435999749	19524	Economy	41500.00
0005435999676	19524	Economy	41500.00
0005435488467	19524	Economy	41500.00
0005435999614	19524	Economy	41500.00
0005435999600	19524	Economy	41500.00
0005435999673	19524	Economy	41500.00
0005435488468	19524	Economy	41500.00
0005435999722	19524	Economy	41500.00
0005435999740	19524	Economy	41500.00
0005435488470	19524	Economy	41500.00
0005434310028	19524	Economy	41500.00
0005434310049	19524	Economy	41500.00
0005433186316	1571	Business	86000.00
0005435508827	1571	Business	86000.00
0005433186317	1571	Business	86000.00
0005435518457	1571	Economy	28700.00
0005433186294	1571	Economy	28700.00
0005435508825	1571	Economy	31500.00
0005433186300	1571	Economy	28700.00
0005433186292	1571	Economy	28700.00
0005435502959	1571	Economy	28700.00
0005435518455	1571	Economy	28700.00
0005435508826	1571	Economy	28700.00
0005435502957	1571	Economy	28700.00
0005435518458	1571	Economy	28700.00
0005435518459	1571	Economy	28700.00
0005435518461	1571	Economy	28700.00
0005435518460	1571	Economy	28700.00
0005433186322	1571	Economy	28700.00
0005435502956	1571	Economy	28700.00
0005435518456	1571	Economy	28700.00
0005435502960	1571	Economy	28700.00
0005435502958	1571	Economy	28700.00
0005433186293	1571	Economy	28700.00
0005434566309	1571	Economy	28700.00
0005433186374	20850	Business	86000.00
0005435502893	20850	Business	86000.00
0005434566214	20850	Business	86000.00
0005435502760	20850	Business	86000.00
0005435502794	20850	Business	86000.00
0005435502734	20850	Business	86000.00
0005435529729	20850	Business	86000.00
0005435529666	20850	Business	86000.00
0005435502718	20850	Business	86000.00
0005435529657	20850	Economy	28700.00
0005435502842	20850	Economy	28700.00
0005434566218	20850	Economy	28700.00
0005435502833	20850	Economy	28700.00
0005435502789	20850	Economy	28700.00
0005435502785	20850	Economy	28700.00
0005435529642	20850	Economy	28700.00
0005435529685	20850	Economy	28700.00
0005435529724	20850	Economy	31500.00
0005435529699	20850	Economy	31500.00
0005435529686	20850	Economy	31500.00
0005435502814	20850	Economy	31500.00
0005435502837	20850	Economy	28700.00
0005434566217	20850	Economy	28700.00
0005435502782	20850	Economy	28700.00
0005435529764	20850	Economy	28700.00
0005435502894	20850	Economy	28700.00
0005435502792	20850	Economy	28700.00
0005435529696	20850	Economy	28700.00
0005435529694	20850	Economy	28700.00
0005435502830	20850	Economy	28700.00
0005435502838	20850	Economy	28700.00
0005435545911	20850	Economy	28700.00
0005435502839	20850	Economy	28700.00
0005435502849	20850	Economy	28700.00
0005435502816	20850	Economy	28700.00
0005435529716	20850	Economy	28700.00
0005435502743	20850	Economy	28700.00
0005434566244	20850	Economy	28700.00
0005435529656	20850	Economy	28700.00
0005435502807	20850	Economy	28700.00
0005434566201	20850	Economy	28700.00
0005434566245	20850	Economy	28700.00
0005435502892	20850	Economy	28700.00
0005434566234	20850	Economy	28700.00
0005435545884	20850	Economy	28700.00
0005435502862	20850	Economy	28700.00
0005435545877	20850	Economy	28700.00
0005435529730	20850	Economy	28700.00
0005435545929	20850	Economy	28700.00
0005435529812	20850	Economy	28700.00
0005435529723	20850	Economy	28700.00
0005435545909	20850	Economy	28700.00
0005435529702	20850	Economy	28700.00
0005435529756	20850	Economy	28700.00
0005435502815	20850	Economy	28700.00
0005435529749	20850	Economy	28700.00
0005435502827	20850	Economy	28700.00
0005435529684	20850	Economy	28700.00
0005434566155	20850	Economy	28700.00
0005435529715	20850	Economy	28700.00
0005435502828	20850	Economy	28700.00
0005434566216	20850	Economy	28700.00
0005433186373	20850	Economy	28700.00
0005435545910	20850	Economy	28700.00
0005435529693	20850	Economy	28700.00
0005435153942	3894	Economy	21600.00
0005435931694	3894	Economy	19700.00
0005435153941	3894	Economy	19700.00
0005435153902	21895	Economy	19700.00
0005435142975	21895	Economy	19700.00
0005435142986	21895	Economy	19700.00
0005435153885	21895	Economy	19700.00
0005435142987	21895	Economy	19700.00
0005435931714	21895	Economy	19700.00
0005435153886	21895	Economy	19700.00
0005435153895	21895	Economy	19700.00
0005435142978	21895	Economy	19700.00
0005435142980	21895	Economy	19700.00
0005435142977	21895	Economy	19700.00
0005435225733	7183	Economy	14300.00
0005435225732	7183	Economy	13000.00
0005435225767	7183	Economy	13000.00
0005432629289	7183	Economy	13000.00
0005432629291	7183	Economy	13000.00
0005432629293	7183	Economy	13000.00
0005435225750	7183	Economy	13000.00
0005435225731	7183	Economy	13000.00
0005432629290	7183	Economy	13000.00
0005432629292	7183	Economy	13000.00
0005432629126	28135	Economy	13000.00
0005432629245	28135	Economy	13000.00
0005432629244	28135	Economy	13000.00
0005432629190	28135	Economy	13000.00
0005432629161	28135	Economy	13000.00
0005432629263	28135	Economy	13000.00
0005432629187	28135	Economy	13000.00
0005432629271	28135	Economy	13000.00
0005432629205	28135	Economy	13000.00
0005432629201	28135	Economy	13000.00
0005432629177	28135	Economy	13000.00
0005432629150	28135	Economy	13000.00
0005432629149	28135	Economy	13000.00
0005432629191	28135	Economy	13000.00
0005434268043	8751	Economy	10500.00
0005434268062	15240	Economy	10500.00
0005435960146	15240	Economy	10500.00
0005435477011	15240	Economy	10500.00
0005435960145	15240	Economy	10500.00
0005432873466	1187	Economy	38300.00
0005432675582	1187	Economy	38300.00
0005432693960	1187	Economy	38300.00
0005432693959	1187	Economy	38300.00
0005432675580	1187	Economy	38300.00
0005432693957	1187	Economy	38300.00
0005432677689	1187	Economy	38300.00
0005432693958	1187	Economy	38300.00
0005432675581	1187	Economy	38300.00
0005432675414	17503	Business	115000.00
0005432675529	17503	Business	115000.00
0005432693791	17503	Business	115000.00
0005432693833	17503	Business	115000.00
0005432693808	17503	Business	115000.00
0005432693834	17503	Business	115000.00
0005432693752	17503	Business	115000.00
0005432693774	17503	Business	115000.00
0005432693768	17503	Business	115000.00
0005432693812	17503	Business	115000.00
0005432693743	17503	Business	115000.00
0005432693702	17503	Business	115000.00
0005432693772	17503	Economy	38300.00
0005432675512	17503	Economy	38300.00
0005432675467	17503	Economy	38300.00
0005432693857	17503	Economy	38300.00
0005432675492	17503	Economy	38300.00
0005432675474	17503	Economy	38300.00
0005432675530	17503	Economy	38300.00
0005432693817	17503	Economy	42200.00
0005432693821	17503	Economy	42200.00
0005432693727	17503	Economy	38300.00
0005432873497	17503	Economy	38300.00
0005432693811	17503	Economy	38300.00
0005432693644	17503	Economy	38300.00
0005432675489	17503	Economy	38300.00
0005432675478	17503	Economy	38300.00
0005432693668	17503	Economy	38300.00
0005432675488	17503	Economy	38300.00
0005432675501	17503	Economy	38300.00
0005432675493	17503	Economy	38300.00
0005432693775	17503	Economy	38300.00
0005432693728	17503	Economy	38300.00
0005432693856	17503	Economy	38300.00
0005432693835	17503	Economy	38300.00
0005432693738	17503	Economy	38300.00
0005432693822	17503	Economy	38300.00
0005432693790	17503	Economy	38300.00
0005432693643	17503	Economy	38300.00
0005432693870	17503	Economy	38300.00
0005432693703	17503	Economy	38300.00
0005432693646	17503	Economy	38300.00
0005432693850	17503	Economy	38300.00
0005432675536	17503	Economy	38300.00
0005432693849	17503	Economy	38300.00
0005432693712	17503	Economy	38300.00
0005432693778	17503	Economy	38300.00
0005432675444	17503	Economy	38300.00
0005433156943	1152	Economy	15200.00
0005434435634	1152	Economy	13900.00
0005433156962	1152	Economy	13900.00
0005434435631	1152	Economy	13900.00
0005433156963	1152	Economy	13900.00
0005434435633	1152	Economy	13900.00
0005433156948	1152	Economy	13900.00
0005434435632	1152	Economy	13900.00
0005433156947	1152	Economy	13900.00
0005433156942	1152	Economy	13900.00
0005434435635	1152	Economy	13900.00
0005434435548	17325	Economy	15200.00
0005434435547	17325	Economy	13900.00
0005434435518	17325	Economy	13900.00
0005433157007	17325	Economy	13900.00
0005434435589	17325	Economy	13900.00
0005434435600	17325	Economy	13900.00
0005433157006	17325	Economy	13900.00
0005434435588	17325	Economy	13900.00
0005434435555	17325	Economy	13900.00
0005434435501	17325	Economy	13900.00
0005434435562	17325	Economy	13900.00
0005434435587	17325	Economy	13900.00
0005434435590	17325	Economy	13900.00
0005434435478	17325	Economy	13900.00
0005434435563	17325	Economy	13900.00
0005435928269	4050	Economy	8200.00
0005435928257	4050	Economy	7500.00
0005435928251	4050	Economy	7500.00
0005435928268	4050	Economy	7500.00
0005435087062	4050	Economy	7500.00
0005435928261	4050	Economy	7500.00
0005435928258	4050	Economy	7500.00
0005435087013	24419	Economy	7500.00
0005435087000	24419	Economy	7500.00
0005435087023	24419	Economy	7500.00
0005435087014	24419	Economy	7500.00
0005435087012	24419	Economy	7500.00
0005435551727	11066	Business	144300.00
0005435551728	11066	Business	144300.00
0005435551715	11066	Business	144300.00
0005435551744	11066	Economy	48100.00
0005435551702	11066	Economy	48100.00
0005435551721	11066	Economy	48100.00
0005435551722	11066	Economy	48100.00
0005435551711	11066	Economy	48100.00
0005435098601	11066	Economy	48100.00
0005435551683	11066	Economy	48100.00
0005435551731	11066	Economy	48100.00
0005435551747	11066	Economy	48100.00
0005435098591	11066	Economy	48100.00
0005435551732	11066	Economy	48100.00
0005435551733	11066	Economy	48100.00
0005435098592	11066	Economy	48100.00
0005435098610	11066	Economy	48100.00
0005435098611	11066	Economy	48100.00
0005435551703	11066	Economy	48100.00
0005435551718	11066	Economy	48100.00
0005435551723	11066	Economy	48100.00
0005435551716	11066	Economy	48100.00
0005435551692	11066	Economy	48100.00
0005435551724	11066	Economy	48100.00
0005435551748	11066	Economy	48100.00
0005435551754	11066	Economy	48100.00
0005435098602	11066	Economy	48100.00
0005435551755	11066	Economy	48100.00
0005435551717	11066	Economy	48100.00
0005435098590	11066	Economy	48100.00
0005435551710	11066	Economy	48100.00
0005435098600	11066	Economy	48100.00
0005433373761	2443	Business	86800.00
0005433373741	2443	Business	86800.00
0005433373753	2443	Business	86800.00
0005433373746	2443	Business	86800.00
0005433373754	2443	Business	86800.00
0005433373728	2443	Business	86800.00
0005435706866	2443	Economy	28900.00
0005433373760	2443	Economy	31800.00
0005435706863	2443	Economy	28900.00
0005433373735	2443	Economy	28900.00
0005433373752	2443	Economy	28900.00
0005433373773	2443	Economy	28900.00
0005435706867	2443	Economy	28900.00
0005433373739	2443	Economy	28900.00
0005433373736	2443	Economy	28900.00
0005433373734	2443	Economy	28900.00
0005433373733	2443	Economy	28900.00
0005433373737	2443	Economy	28900.00
0005433373712	2443	Economy	28900.00
0005435706861	2443	Economy	28900.00
0005435706862	2443	Economy	28900.00
0005435706864	2443	Economy	28900.00
0005433373774	2443	Economy	28900.00
0005433373740	2443	Economy	28900.00
0005435706865	2443	Economy	28900.00
0005433373747	2443	Economy	28900.00
0005433373714	2443	Economy	28900.00
0005433373775	2443	Economy	28900.00
0005433373703	2443	Economy	28900.00
0005433373772	2443	Economy	28900.00
0005433373755	2443	Economy	28900.00
0005433373727	2443	Economy	28900.00
0005435706868	2443	Economy	28900.00
0005433373702	2443	Economy	28900.00
0005433373800	27031	Business	86800.00
0005435706744	27031	Business	86800.00
0005435706767	27031	Business	86800.00
0005435706765	27031	Business	86800.00
0005435706722	27031	Business	86800.00
0005435706800	27031	Business	86800.00
0005435706814	27031	Business	86800.00
0005435706745	27031	Economy	28900.00
0005435706743	27031	Economy	28900.00
0005435706781	27031	Economy	28900.00
0005433373801	27031	Economy	31800.00
0005435706789	27031	Economy	31800.00
0005435706768	27031	Economy	28900.00
0005435706694	27031	Economy	28900.00
0005435706717	27031	Economy	28900.00
0005435706702	27031	Economy	28900.00
0005433373802	27031	Economy	28900.00
0005435706707	27031	Economy	28900.00
0005435706721	27031	Economy	28900.00
0005435706812	27031	Economy	28900.00
0005435706712	27031	Economy	28900.00
0005435706773	27031	Economy	28900.00
0005435706779	27031	Economy	28900.00
0005435706764	27031	Economy	28900.00
0005435706719	27031	Economy	28900.00
0005435706742	27031	Economy	28900.00
0005435706778	27031	Economy	28900.00
0005435706729	27031	Economy	28900.00
0005435706796	27031	Economy	28900.00
0005435706813	27031	Economy	28900.00
0005435706774	27031	Economy	28900.00
0005435706720	27031	Economy	28900.00
0005435706741	27031	Economy	28900.00
0005435706709	27031	Economy	28900.00
0005435706718	27031	Economy	28900.00
0005435706772	27031	Economy	28900.00
0005435706780	27031	Economy	28900.00
0005433373803	27031	Economy	28900.00
0005435706795	27031	Economy	28900.00
0005435706766	27031	Economy	28900.00
0005435706758	27031	Economy	28900.00
0005435706708	27031	Economy	28900.00
0005435706695	27031	Economy	28900.00
0005435706696	27031	Economy	28900.00
0005433261786	1328	Business	203300.00
0005433261746	1328	Business	203300.00
0005433261742	1328	Business	203300.00
0005434964787	1328	Business	203300.00
0005433261812	1328	Business	203300.00
0005433261741	1328	Economy	67800.00
0005434964790	1328	Economy	67800.00
0005434964784	1328	Economy	67800.00
0005433261831	1328	Economy	67800.00
0005433261813	1328	Economy	67800.00
0005434964789	1328	Economy	67800.00
0005433261801	1328	Economy	67800.00
0005433261781	1328	Economy	67800.00
0005434964788	1328	Economy	67800.00
0005433261780	1328	Economy	67800.00
0005433261815	1328	Economy	67800.00
0005434964783	1328	Economy	67800.00
0005433261814	1328	Economy	67800.00
0005433261803	1328	Economy	67800.00
0005434964785	1328	Economy	67800.00
0005433261799	1328	Economy	67800.00
0005434964786	1328	Economy	67800.00
0005433261834	1328	Economy	74500.00
0005433261804	1328	Economy	67800.00
0005433261785	1328	Economy	67800.00
0005433261805	1328	Economy	67800.00
0005434964781	1328	Economy	67800.00
0005433261725	1328	Economy	67800.00
0005434964780	1328	Economy	67800.00
0005434964782	1328	Economy	67800.00
0005433261822	1328	Economy	67800.00
0005433261798	1328	Economy	67800.00
0005433261855	18248	Business	203300.00
0005434964648	18248	Business	203300.00
0005433261865	18248	Business	203300.00
0005434964624	18248	Business	203300.00
0005434964600	18248	Business	203300.00
0005434964629	18248	Business	203300.00
0005434215908	18248	Business	203300.00
0005434964614	18248	Business	203300.00
0005433261863	18248	Economy	74500.00
0005434964483	18248	Economy	67800.00
0005434964611	18248	Economy	67800.00
0005433261853	18248	Economy	67800.00
0005434215909	18248	Economy	67800.00
0005433261850	18248	Economy	67800.00
0005433261857	18248	Economy	67800.00
0005434964640	18248	Economy	67800.00
0005434964599	18248	Economy	67800.00
0005434964706	18248	Economy	67800.00
0005434964596	18248	Economy	67800.00
0005434964693	18248	Economy	67800.00
0005434964649	18248	Economy	67800.00
0005434964667	18248	Economy	67800.00
0005433261864	18248	Economy	67800.00
0005434964692	18248	Economy	67800.00
0005433261862	18248	Economy	67800.00
0005434964668	18248	Economy	67800.00
0005433261856	18248	Economy	67800.00
0005434964597	18248	Economy	67800.00
0005434964680	18248	Economy	67800.00
0005434964581	18248	Economy	67800.00
0005434964598	18248	Economy	67800.00
0005434964623	18248	Economy	67800.00
0005434964696	18248	Economy	67800.00
0005434964678	18248	Economy	67800.00
0005433261858	18248	Economy	74500.00
0005434215905	18248	Economy	67800.00
0005434964634	18248	Economy	74500.00
0005434964553	18248	Economy	67800.00
0005434964525	18248	Economy	67800.00
0005433261852	18248	Economy	67800.00
0005434964697	18248	Economy	67800.00
0005433261861	18248	Economy	67800.00
0005434964630	18248	Economy	67800.00
0005434964605	18248	Economy	67800.00
0005434964727	18248	Economy	67800.00
0005433261860	18248	Economy	67800.00
0005433261854	18248	Economy	67800.00
0005434964681	18248	Economy	67800.00
0005434964650	18248	Economy	67800.00
0005434215906	18248	Economy	67800.00
0005434964639	18248	Economy	67800.00
0005434964625	18248	Economy	67800.00
0005433261851	18248	Economy	67800.00
0005433261859	18248	Economy	67800.00
0005434964709	18248	Economy	67800.00
0005434964608	18248	Economy	67800.00
0005434964726	18248	Economy	67800.00
0005434964635	18248	Economy	67800.00
0005434215907	18248	Economy	67800.00
0005434964705	18248	Economy	67800.00
0005434964663	18248	Economy	67800.00
0005434964526	18248	Economy	67800.00
0005434964691	18248	Economy	67800.00
0005435907613	4857	Business	44200.00
0005433194926	4857	Economy	16200.00
0005435907626	4857	Economy	14700.00
0005433194919	4857	Economy	14700.00
0005435907596	4857	Economy	14700.00
0005433194920	4857	Economy	14700.00
0005435907586	4857	Economy	14700.00
0005434626237	4857	Economy	14700.00
0005433194928	4857	Economy	14700.00
0005433194915	4857	Economy	14700.00
0005433195012	32908	Economy	14700.00
0005434626204	32908	Economy	14700.00
0005433195014	32908	Economy	14700.00
0005433195009	32908	Economy	14700.00
0005433195013	32908	Economy	14700.00
0005434626151	32908	Economy	14700.00
0005434626202	32908	Economy	14700.00
0005434626150	32908	Economy	14700.00
0005433195010	32908	Economy	14700.00
0005433195011	32908	Economy	14700.00
0005434626156	32908	Economy	14700.00
0005434626166	32908	Economy	14700.00
0005433195008	32908	Economy	14700.00
0005434626203	32908	Economy	14700.00
0005434626205	32908	Economy	14700.00
0005435785990	13784	Economy	3400.00
0005435785925	13784	Economy	3400.00
0005435786066	13784	Economy	3400.00
0005435937572	13784	Economy	3400.00
0005435786128	13784	Economy	3100.00
0005435785983	13784	Economy	3100.00
0005435787408	13784	Economy	3100.00
0005435787399	13784	Economy	3100.00
0005435786075	13784	Economy	3100.00
0005435786265	13784	Economy	3100.00
0005435786129	13784	Economy	3100.00
0005435785927	13784	Economy	3100.00
0005435786091	13784	Economy	3100.00
0005435787409	13784	Economy	3100.00
0005435786231	13784	Economy	3100.00
0005435786170	13784	Economy	3100.00
0005435786165	13784	Economy	3100.00
0005435786026	13784	Economy	3100.00
0005435786182	13784	Economy	3100.00
0005435786065	13784	Economy	3100.00
0005435787400	13784	Economy	3100.00
0005435786172	13784	Economy	3100.00
0005435787396	13784	Economy	3100.00
0005435786104	13784	Economy	3100.00
0005435787403	13784	Economy	3100.00
0005435786167	13784	Economy	3100.00
0005435786169	13784	Economy	3100.00
0005435785926	13784	Economy	3100.00
0005435786248	13784	Economy	3100.00
0005435786096	13784	Economy	3100.00
0005435786174	13784	Economy	3100.00
0005435786206	13784	Economy	3100.00
0005435786171	13784	Economy	3100.00
0005435786097	13784	Economy	3100.00
0005435786114	13784	Economy	3100.00
0005435787395	13784	Economy	3100.00
0005435786119	13784	Economy	3100.00
0005435786076	13784	Economy	3100.00
0005435786142	13784	Economy	3100.00
0005435786186	13784	Economy	3100.00
0005435786007	13784	Economy	3100.00
0005435786103	13784	Economy	3100.00
0005435786039	13784	Economy	3100.00
0005435786340	27445	Economy	3400.00
0005435786344	27445	Economy	3400.00
0005435937492	27445	Economy	3100.00
0005435937485	27445	Economy	3100.00
0005435937500	27445	Economy	3100.00
0005435787415	27445	Economy	3100.00
0005435937489	27445	Economy	3100.00
0005435786342	27445	Economy	3100.00
0005435786346	27445	Economy	3100.00
0005435937495	27445	Economy	3100.00
0005435937484	27445	Economy	3100.00
0005435786345	27445	Economy	3100.00
0005435787413	27445	Economy	3100.00
0005435786341	27445	Economy	3100.00
0005435937512	27445	Economy	3100.00
0005435786343	27445	Economy	3100.00
0005435787414	27445	Economy	3100.00
0005434409297	20260	Business	12000.00
0005434409140	20260	Business	12000.00
0005434409158	20260	Business	12000.00
0005434409298	20260	Business	12000.00
0005435311554	20260	Business	12000.00
0005435311553	20260	Business	12000.00
0005434409267	20260	Business	12000.00
0005434409130	20260	Business	12000.00
0005434409400	20260	Business	12000.00
0005434409117	20260	Business	12000.00
0005434409296	20260	Economy	4000.00
0005434409374	20260	Economy	4000.00
0005434409180	20260	Economy	4000.00
0005432058499	20260	Economy	4000.00
0005434409157	20260	Economy	4000.00
0005434409179	20260	Economy	4400.00
0005434409405	20260	Economy	4400.00
0005434409497	20260	Economy	4400.00
0005434409208	20260	Economy	4400.00
0005434409268	20260	Economy	4000.00
0005434409184	20260	Economy	4000.00
0005434409306	20260	Economy	4000.00
0005434409178	20260	Economy	4000.00
0005434409513	20260	Economy	4000.00
0005434409221	20260	Economy	4000.00
0005434408878	20260	Economy	4000.00
0005434409305	20260	Economy	4000.00
0005434409304	20260	Economy	4000.00
0005434409220	20260	Economy	4000.00
0005434409182	20260	Economy	4000.00
0005434409231	20260	Economy	4000.00
0005434409373	20260	Economy	4000.00
0005434409495	20260	Economy	4000.00
0005434409309	20260	Economy	4000.00
0005434409212	20260	Economy	4000.00
0005434409116	20260	Economy	4000.00
0005434409103	20260	Economy	4000.00
0005434409258	20260	Economy	4000.00
0005434409278	20260	Economy	4000.00
0005434409150	20260	Economy	4000.00
0005434409219	20260	Economy	4000.00
0005434409061	20260	Economy	4000.00
0005434409222	20260	Economy	4000.00
0005434409134	20260	Economy	4000.00
0005434409308	20260	Economy	4000.00
0005435311555	20260	Economy	4000.00
0005434409269	20260	Economy	4000.00
0005434408921	20260	Economy	4000.00
0005434409224	20260	Economy	4000.00
0005435311550	20260	Economy	4000.00
0005432058498	20260	Economy	4000.00
0005434409149	20260	Economy	4000.00
0005434409118	20260	Economy	4000.00
0005434409159	20260	Economy	4000.00
0005435311552	20260	Economy	4000.00
0005434409038	20260	Economy	4000.00
0005434409279	20260	Economy	4000.00
0005434409230	20260	Economy	4000.00
0005434409062	20260	Economy	4000.00
0005435311551	20260	Economy	4000.00
0005434409237	20260	Economy	4000.00
0005434409112	20260	Economy	4000.00
0005434409129	20260	Economy	4000.00
0005434409307	20260	Economy	4000.00
0005434409259	20260	Economy	4000.00
0005435311349	26998	Business	12000.00
0005435311379	26998	Business	12000.00
0005434409605	26998	Business	12000.00
0005435311414	26998	Business	12000.00
0005435311305	26998	Business	12000.00
0005435311384	26998	Business	12000.00
0005435311363	26998	Economy	4000.00
0005435311390	26998	Economy	4000.00
0005434409600	26998	Economy	4000.00
0005435311415	26998	Economy	4000.00
0005435311348	26998	Economy	4000.00
0005435311301	26998	Economy	4400.00
0005435311394	26998	Economy	4400.00
0005434409607	26998	Economy	4400.00
0005434409601	26998	Economy	4400.00
0005434409606	26998	Economy	4000.00
0005435311375	26998	Economy	4000.00
0005435311404	26998	Economy	4000.00
0005435311347	26998	Economy	4000.00
0005435311395	26998	Economy	4000.00
0005435311437	26998	Economy	4000.00
0005434409604	26998	Economy	4000.00
0005435311431	26998	Economy	4000.00
0005434409598	26998	Economy	4000.00
0005434409599	26998	Economy	4000.00
0005435311313	26998	Economy	4000.00
0005434409609	26998	Economy	4000.00
0005435311408	26998	Economy	4000.00
0005435311294	26998	Economy	4000.00
0005434409610	26998	Economy	4000.00
0005435311325	26998	Economy	4000.00
0005435311385	26998	Economy	4000.00
0005435311324	26998	Economy	4000.00
0005435311343	26998	Economy	4000.00
0005435311350	26998	Economy	4000.00
0005435311351	26998	Economy	4000.00
0005435311396	26998	Economy	4000.00
0005434409608	26998	Economy	4000.00
0005435311364	26998	Economy	4000.00
0005435311329	26998	Economy	4000.00
0005434409603	26998	Economy	4000.00
0005434409602	26998	Economy	4000.00
0005433124336	5722	Business	43300.00
0005434310167	5722	Business	43300.00
0005433124406	5722	Business	43300.00
0005433124337	5722	Business	43300.00
0005434310170	5722	Business	43300.00
0005433124425	5722	Economy	14400.00
0005433124387	5722	Economy	15900.00
0005433124339	5722	Economy	15900.00
0005434311280	5722	Economy	15900.00
0005433124432	5722	Economy	14400.00
0005434310174	5722	Economy	14400.00
0005434319862	5722	Economy	14400.00
0005434310177	5722	Economy	14400.00
0005435297388	5722	Economy	14400.00
0005433124285	5722	Economy	14400.00
0005434310171	5722	Economy	14400.00
0005434310179	5722	Economy	14400.00
0005434310173	5722	Economy	14400.00
0005434310178	5722	Economy	14400.00
0005434310175	5722	Economy	14400.00
0005435297396	5722	Economy	14400.00
0005433124422	5722	Economy	14400.00
0005434311279	5722	Economy	14400.00
0005434310172	5722	Economy	14400.00
0005433124417	5722	Economy	14400.00
0005433124287	5722	Economy	14400.00
0005434310176	5722	Economy	14400.00
0005433124443	5722	Economy	14400.00
0005435297395	5722	Economy	14400.00
0005433124286	5722	Economy	14400.00
0005433124431	5722	Economy	14400.00
0005434310166	5722	Economy	14400.00
0005434319863	5722	Economy	14400.00
0005434310168	5722	Economy	14400.00
0005433124381	5722	Economy	14400.00
0005434319860	5722	Economy	14400.00
0005433124421	5722	Economy	14400.00
0005434319861	5722	Economy	14400.00
0005433124388	5722	Economy	14400.00
0005434310165	5722	Economy	14400.00
0005434319864	5722	Economy	14400.00
0005434310169	5722	Economy	14400.00
0005434319646	15703	Business	43300.00
0005434319743	15703	Business	43300.00
0005434319737	15703	Business	43300.00
0005434319730	15703	Business	43300.00
0005434319698	15703	Business	43300.00
0005433124543	15703	Economy	14400.00
0005434319705	15703	Economy	14400.00
0005434319718	15703	Economy	14400.00
0005434319684	15703	Economy	15900.00
0005433124545	15703	Economy	15900.00
0005433124548	15703	Economy	14400.00
0005434319725	15703	Economy	14400.00
0005433124546	15703	Economy	14400.00
0005434319703	15703	Economy	14400.00
0005433124542	15703	Economy	14400.00
0005434312369	15703	Economy	14400.00
0005434319741	15703	Economy	14400.00
0005434312370	15703	Economy	14400.00
0005433124547	15703	Economy	14400.00
0005434319770	15703	Economy	14400.00
0005434319685	15703	Economy	14400.00
0005434319708	15703	Economy	14400.00
0005434319764	15703	Economy	14400.00
0005434319779	15703	Economy	14400.00
0005434312371	15703	Economy	14400.00
0005434319736	15703	Economy	14400.00
0005433124544	15703	Economy	14400.00
0005434319706	15703	Economy	14400.00
0005433124541	15703	Economy	14400.00
0005434319724	15703	Economy	14400.00
0005434319693	15703	Economy	14400.00
0005434319771	15703	Economy	14400.00
0005434319727	15703	Economy	14400.00
0005433124549	15703	Economy	14400.00
0005434319763	15703	Economy	14400.00
0005433124550	15703	Economy	14400.00
0005435220355	24970	Economy	17100.00
0005435217759	24970	Economy	17100.00
0005435220363	24970	Economy	15500.00
0005435220365	24970	Economy	15500.00
0005435220359	24970	Economy	15500.00
0005435217755	24970	Economy	15500.00
0005435220367	24970	Economy	15500.00
0005435217747	24970	Economy	15500.00
0005435221527	24970	Economy	15500.00
0005435220364	24970	Economy	15500.00
0005435221526	24970	Economy	15500.00
0005435217756	24970	Economy	15500.00
0005435217757	24970	Economy	15500.00
0005435221529	24970	Economy	15500.00
0005435217760	24970	Economy	15500.00
0005435220356	24970	Economy	15500.00
0005435217762	24970	Economy	15500.00
0005435217752	24970	Economy	15500.00
0005435221528	24970	Economy	15500.00
0005434189324	8996	Economy	27400.00
0005434505323	8996	Economy	24900.00
0005434505322	8996	Economy	24900.00
0005434189305	8996	Economy	24900.00
0005434505321	8996	Economy	24900.00
0005434505324	8996	Economy	24900.00
0005434484541	8996	Economy	24900.00
0005434189345	16619	Economy	27400.00
0005434484500	16619	Economy	24900.00
0005435903231	16619	Economy	24900.00
0005434484490	16619	Economy	24900.00
0005434189346	16619	Economy	24900.00
0005435903232	16619	Economy	24900.00
0005434484513	16619	Economy	24900.00
0005434484514	16619	Economy	24900.00
0005435903234	16619	Economy	24900.00
0005434484479	16619	Economy	24900.00
0005434484508	16619	Economy	24900.00
0005434484523	16619	Economy	24900.00
0005435903230	16619	Economy	24900.00
0005434189344	16619	Economy	24900.00
0005435903233	16619	Economy	24900.00
0005434484512	16619	Economy	24900.00
0005433722324	7545	Business	11100.00
0005433124544	7545	Business	11100.00
0005433124543	7545	Economy	3700.00
0005433124541	7545	Economy	3700.00
0005433124548	7545	Economy	3700.00
0005433124550	7545	Economy	4100.00
0005433722349	7545	Economy	3700.00
0005433124542	7545	Economy	3700.00
0005433722331	7545	Economy	3700.00
0005433124545	7545	Economy	3700.00
0005433124547	7545	Economy	3700.00
0005433722352	7545	Economy	3700.00
0005433124546	7545	Economy	3700.00
0005433722348	7545	Economy	3700.00
0005433722357	7545	Economy	3700.00
0005433124549	7545	Economy	3700.00
0005433450608	7544	Business	11100.00
0005432693966	7544	Business	11100.00
0005432071662	7544	Business	11100.00
0005432693967	7544	Business	11100.00
0005432693962	7544	Business	11100.00
0005433450604	7544	Economy	3700.00
0005433450605	7544	Economy	3700.00
0005432721689	7544	Economy	3700.00
0005433450602	7544	Economy	3700.00
0005432721684	7544	Economy	3700.00
0005432693964	7544	Economy	3700.00
0005432721683	7544	Economy	3700.00
0005433450607	7544	Economy	3700.00
0005432721681	7544	Economy	3700.00
0005433450603	7544	Economy	3700.00
0005432721688	7544	Economy	3700.00
0005432693961	7544	Economy	3700.00
0005433450601	7544	Economy	3700.00
0005432071663	7544	Economy	3700.00
0005432721687	7544	Economy	3700.00
0005432721682	7544	Economy	3700.00
0005433450606	7544	Economy	3700.00
0005432721685	7544	Economy	3700.00
0005432693963	7544	Economy	3700.00
0005432693965	7544	Economy	3700.00
0005432721686	7544	Economy	3700.00
0005432693808	30302	Business	11100.00
0005433450491	30302	Business	11100.00
0005432693834	30302	Business	11100.00
0005433450419	30302	Business	11100.00
0005433450411	30302	Business	11100.00
0005432693821	30302	Economy	3700.00
0005433450490	30302	Economy	3700.00
0005433450499	30302	Economy	3700.00
0005432693856	30302	Economy	3700.00
0005432693850	30302	Economy	4100.00
0005432693791	30302	Economy	4100.00
0005432693712	30302	Economy	4100.00
0005432693870	30302	Economy	4100.00
0005433450531	30302	Economy	3700.00
0005433450522	30302	Economy	3700.00
0005433450420	30302	Economy	3700.00
0005433450410	30302	Economy	3700.00
0005432693811	30302	Economy	3700.00
0005432693644	30302	Economy	3700.00
0005432693703	30302	Economy	3700.00
0005432693775	30302	Economy	3700.00
0005432693643	30302	Economy	3700.00
0005432693822	30302	Economy	3700.00
0005432693778	30302	Economy	3700.00
0005432693727	30302	Economy	3700.00
0005432693668	30302	Economy	3700.00
0005432693752	30302	Economy	3700.00
0005432693702	30302	Economy	3700.00
0005432693857	30302	Economy	3700.00
0005433450532	30302	Economy	3700.00
0005432693817	30302	Economy	3700.00
0005432693768	30302	Economy	3700.00
0005432693772	30302	Economy	3700.00
0005433450413	30302	Economy	3700.00
0005432693790	30302	Economy	3700.00
0005432693738	30302	Economy	3700.00
0005433450470	30302	Economy	3700.00
0005432693812	30302	Economy	3700.00
0005432693646	30302	Economy	3700.00
0005433450507	30302	Economy	3700.00
0005432693743	30302	Economy	3700.00
0005432693728	30302	Economy	3700.00
0005433450501	30302	Economy	3700.00
0005433450478	30302	Economy	3700.00
0005432693774	30302	Economy	3700.00
0005432693835	30302	Economy	3700.00
0005432693833	30302	Economy	3700.00
0005432693849	30302	Economy	3700.00
0005432721556	30301	Business	11100.00
0005432721582	30301	Business	11100.00
0005433722505	30301	Business	11100.00
0005433124432	30301	Business	11100.00
0005432721372	30301	Business	11100.00
0005433722504	30301	Business	11100.00
0005432721583	30301	Business	11100.00
0005432721542	30301	Business	11100.00
0005435477018	30301	Business	11100.00
0005432721485	30301	Business	11100.00
0005433124381	30301	Business	11100.00
0005435477024	30301	Economy	3700.00
0005435477025	30301	Economy	3700.00
0005434310174	30301	Economy	3700.00
0005434310172	30301	Economy	3700.00
0005433722502	30301	Economy	3700.00
0005432721518	30301	Economy	3700.00
0005434310176	30301	Economy	3700.00
0005433124431	30301	Economy	3700.00
0005434310177	30301	Economy	3700.00
0005432721595	30301	Economy	4100.00
0005432721553	30301	Economy	4100.00
0005435477016	30301	Economy	4100.00
0005433124406	30301	Economy	4100.00
0005432721620	30301	Economy	3700.00
0005435229657	30301	Economy	3700.00
0005434310178	30301	Economy	3700.00
0005433124417	30301	Economy	3700.00
0005435477015	30301	Economy	3700.00
0005432721635	30301	Economy	3700.00
0005435477019	30301	Economy	3700.00
0005432721369	30301	Economy	3700.00
0005433124287	30301	Economy	3700.00
0005433124336	30301	Economy	3700.00
0005434310168	30301	Economy	3700.00
0005433124422	30301	Economy	3700.00
0005435477021	30301	Economy	3700.00
0005432721564	30301	Economy	3700.00
0005432721484	30301	Economy	3700.00
0005432721637	30301	Economy	3700.00
0005434310171	30301	Economy	3700.00
0005434310167	30301	Economy	3700.00
0005433124337	30301	Economy	3700.00
0005433722507	30301	Economy	3700.00
0005435477013	30301	Economy	3700.00
0005433124387	30301	Economy	3700.00
0005434310169	30301	Economy	3700.00
0005432721525	30301	Economy	3700.00
0005433124286	30301	Economy	3700.00
0005433124339	30301	Economy	3700.00
0005432721580	30301	Economy	3700.00
0005432721594	30301	Economy	3700.00
0005432721569	30301	Economy	3700.00
0005432721608	30301	Economy	3700.00
0005433722503	30301	Economy	3700.00
0005432721435	30301	Economy	3700.00
0005435477014	30301	Economy	3700.00
0005434310175	30301	Economy	3700.00
0005433124425	30301	Economy	3700.00
0005435477017	30301	Economy	3700.00
0005435477023	30301	Economy	3700.00
0005435229658	30301	Economy	3700.00
0005433722508	30301	Economy	3700.00
0005434310165	30301	Economy	3700.00
0005434310179	30301	Economy	3700.00
0005432721521	30301	Economy	3700.00
0005432721644	30301	Economy	3700.00
0005432721581	30301	Economy	3700.00
0005432721504	30301	Economy	3700.00
0005435477020	30301	Economy	3700.00
0005433124443	30301	Economy	3700.00
0005432721543	30301	Economy	3700.00
0005432721555	30301	Economy	3700.00
0005435477022	30301	Economy	3700.00
0005433722506	30301	Economy	3700.00
0005433124421	30301	Economy	3700.00
0005432721478	30301	Economy	3700.00
0005435229659	30301	Economy	3700.00
0005434310170	30301	Economy	3700.00
0005433124388	30301	Economy	3700.00
0005432721643	30301	Economy	3700.00
0005432721577	30301	Economy	3700.00
0005434310173	30301	Economy	3700.00
0005434310166	30301	Economy	3700.00
0005432721371	30301	Economy	3700.00
0005432721523	30301	Economy	3700.00
0005432721621	30301	Economy	3700.00
0005432721455	30301	Economy	3700.00
0005433124285	30301	Economy	3700.00
0005432721370	30301	Economy	3700.00
0005433193344	1373	Business	70400.00
0005433525361	1373	Business	70400.00
0005434587358	1373	Business	70400.00
0005434587356	1373	Business	70400.00
0005433193261	1373	Business	70400.00
0005433193360	1373	Economy	23500.00
0005434513661	1373	Economy	23500.00
0005433193345	1373	Economy	25800.00
0005432928114	1373	Economy	23500.00
0005434515046	1373	Economy	23500.00
0005434587357	1373	Economy	23500.00
0005433525359	1373	Economy	23500.00
0005433193372	1373	Economy	23500.00
0005433193373	1373	Economy	23500.00
0005434587355	1373	Economy	23500.00
0005434587354	1373	Economy	23500.00
0005433193357	1373	Economy	23500.00
0005432928125	1373	Economy	23500.00
0005433193260	1373	Economy	23500.00
0005433193343	1373	Economy	23500.00
0005433193349	1373	Economy	23500.00
0005433525360	1373	Economy	23500.00
0005433193367	1373	Economy	23500.00
0005432928112	1373	Economy	23500.00
0005432928116	1373	Economy	23500.00
0005432928115	1373	Economy	23500.00
0005432928126	1373	Economy	23500.00
0005432928113	1373	Economy	23500.00
0005433193359	1373	Economy	23500.00
0005433525362	1373	Economy	23500.00
0005432928147	18500	Business	70400.00
0005433193439	18500	Business	70400.00
0005434587244	18500	Business	70400.00
0005434587166	18500	Business	70400.00
0005433724905	18500	Business	70400.00
0005433525277	18500	Business	70400.00
0005433525291	18500	Economy	23500.00
0005432928146	18500	Economy	23500.00
0005434587276	18500	Economy	23500.00
0005433525343	18500	Economy	23500.00
0005433724908	18500	Economy	23500.00
0005434587149	18500	Economy	23500.00
0005434587261	18500	Economy	23500.00
0005434587180	18500	Economy	23500.00
0005434587262	18500	Economy	25800.00
0005434587181	18500	Economy	25800.00
0005434515022	18500	Economy	25800.00
0005434587233	18500	Economy	23500.00
0005434587277	18500	Economy	23500.00
0005434587301	18500	Economy	23500.00
0005433193438	18500	Economy	23500.00
0005433724899	18500	Economy	23500.00
0005434587257	18500	Economy	23500.00
0005433525265	18500	Economy	23500.00
0005434587176	18500	Economy	23500.00
0005433525328	18500	Economy	23500.00
0005434587167	18500	Economy	23500.00
0005432928145	18500	Economy	23500.00
0005433525301	18500	Economy	23500.00
0005434587215	18500	Economy	23500.00
0005434587296	18500	Economy	23500.00
0005432928148	18500	Economy	23500.00
0005433525249	18500	Economy	23500.00
0005433525290	18500	Economy	23500.00
0005433193440	18500	Economy	23500.00
0005434587148	18500	Economy	23500.00
0005434587155	18500	Economy	23500.00
0005433525267	18500	Economy	23500.00
0005433525266	18500	Economy	23500.00
0005434587183	18500	Economy	23500.00
0005434587191	18500	Economy	23500.00
0005434587295	18500	Economy	23500.00
0005434587070	18500	Economy	23500.00
0005433193441	18500	Economy	23500.00
0005434587284	18500	Economy	23500.00
0005434587236	18500	Economy	23500.00
0005434587156	18500	Economy	23500.00
0005434587182	18500	Economy	23500.00
0005433525344	18500	Economy	23500.00
0005433525329	18500	Economy	23500.00
0005434587266	18500	Economy	23500.00
0005434587209	18500	Economy	23500.00
0005433525289	18500	Economy	23500.00
0005433193437	18500	Economy	23500.00
0005434345263	11430	Economy	4300.00
0005435305049	11430	Economy	4300.00
0005434345260	11430	Economy	4300.00
0005434345272	11430	Economy	4000.00
0005434345262	11430	Economy	4000.00
0005434345271	11430	Economy	4000.00
0005435305048	11430	Economy	4000.00
0005435302324	11430	Economy	4000.00
0005434345265	11430	Economy	4000.00
0005435302293	11430	Economy	4000.00
0005435302316	11430	Economy	4000.00
0005434345259	11430	Economy	4000.00
0005434345269	11430	Economy	4000.00
0005435302308	11430	Economy	4000.00
0005434345273	11430	Economy	4000.00
0005434345268	11430	Economy	4000.00
0005434345267	11430	Economy	4000.00
0005434345264	11430	Economy	4000.00
0005435305050	11430	Economy	4000.00
0005435302309	11430	Economy	4000.00
0005434345270	11430	Economy	4000.00
0005434345266	11430	Economy	4000.00
0005434345261	11430	Economy	4000.00
0005435302306	11430	Economy	4000.00
0005434345031	29793	Economy	4300.00
0005434344769	29793	Economy	4300.00
0005434344970	29793	Economy	4300.00
0005434345113	29793	Economy	4000.00
0005434142708	29793	Economy	4000.00
0005434344987	29793	Economy	4000.00
0005434345063	29793	Economy	4000.00
0005434344952	29793	Economy	4000.00
0005434344962	29793	Economy	4000.00
0005434344981	29793	Economy	4000.00
0005434345101	29793	Economy	4000.00
0005434345041	29793	Economy	4000.00
0005434345062	29793	Economy	4000.00
0005434344994	29793	Economy	4000.00
0005434345083	29793	Economy	4000.00
0005434345114	29793	Economy	4000.00
0005434142692	29793	Economy	4000.00
0005434345002	29793	Economy	4000.00
0005434344971	29793	Economy	4000.00
0005434345087	29793	Economy	4000.00
0005434345091	29793	Economy	4000.00
0005434345080	29793	Economy	4000.00
0005434345040	29793	Economy	4000.00
0005434344888	29793	Economy	4000.00
0005434345090	29793	Economy	4000.00
0005434345039	29793	Economy	4000.00
0005434344988	29793	Economy	4000.00
0005434345000	29793	Economy	4000.00
0005434345088	29793	Economy	4000.00
0005434345106	29793	Economy	4000.00
0005434142707	29793	Economy	4000.00
0005434345061	29793	Economy	4000.00
0005434345007	29793	Economy	4000.00
0005434142689	29793	Economy	4000.00
0005434142693	29793	Economy	4000.00
0005434345001	29793	Economy	4000.00
0005434345111	29793	Economy	4000.00
0005434345112	29793	Economy	4000.00
0005434344860	29793	Economy	4000.00
0005434345004	29793	Economy	4000.00
0005434344997	29793	Economy	4000.00
0005434344932	29793	Economy	4000.00
0005434345052	29793	Economy	4000.00
0005434345100	29793	Economy	4000.00
0005434344972	29793	Economy	4000.00
0005434344963	29793	Economy	4000.00
0005434344933	29793	Economy	4000.00
0005434344887	29793	Economy	4000.00
0005434344764	29793	Economy	4000.00
0005435825418	1282	Business	199800.00
0005433415998	1282	Business	199800.00
0005433416056	1282	Business	199800.00
0005433416041	1282	Business	199800.00
0005433416057	1282	Business	199800.00
0005433416007	1282	Business	199800.00
0005433416082	1282	Economy	66600.00
0005435825419	1282	Economy	66600.00
0005433416055	1282	Economy	66600.00
0005433416051	1282	Economy	66600.00
0005433416083	1282	Economy	66600.00
0005435825417	1282	Economy	66600.00
0005435825412	1282	Economy	73200.00
0005433416003	1282	Economy	66600.00
0005433416013	1282	Economy	66600.00
0005433416074	1282	Economy	66600.00
0005433416049	1282	Economy	66600.00
0005433416015	1282	Economy	66600.00
0005433415969	1282	Economy	66600.00
0005433416100	1282	Economy	66600.00
0005433416012	1282	Economy	66600.00
0005435825415	1282	Economy	66600.00
0005433415971	1282	Economy	66600.00
0005433416054	1282	Economy	66600.00
0005433416059	1282	Economy	66600.00
0005433416042	1282	Economy	66600.00
0005433416043	1282	Economy	66600.00
0005433416058	1282	Economy	66600.00
0005433416053	1282	Economy	66600.00
0005433416034	1282	Economy	66600.00
0005435825411	1282	Economy	66600.00
0005433415970	1282	Economy	66600.00
0005433416048	1282	Economy	66600.00
0005433416075	1282	Economy	66600.00
0005433416073	1282	Economy	66600.00
0005433416024	1282	Economy	66600.00
0005435825416	1282	Economy	66600.00
0005435825413	1282	Economy	66600.00
0005433416067	1282	Economy	66600.00
0005433416099	1282	Economy	66600.00
0005435825414	1282	Economy	66600.00
0005435825410	1282	Economy	66600.00
0005435825248	17985	Business	199800.00
0005435825226	17985	Business	199800.00
0005435825263	17985	Business	199800.00
0005435825294	17985	Business	199800.00
0005435825178	17985	Business	199800.00
0005435825354	17985	Business	199800.00
0005435825278	17985	Economy	66600.00
0005435825274	17985	Economy	66600.00
0005435825217	17985	Economy	66600.00
0005435825267	17985	Economy	66600.00
0005435825250	17985	Economy	66600.00
0005435825256	17985	Economy	66600.00
0005435825249	17985	Economy	66600.00
0005435825355	17985	Economy	66600.00
0005435825211	17985	Economy	73200.00
0005435825279	17985	Economy	66600.00
0005435825179	17985	Economy	66600.00
0005435825307	17985	Economy	66600.00
0005435825308	17985	Economy	66600.00
0005435825282	17985	Economy	66600.00
0005435825283	17985	Economy	66600.00
0005435825262	17985	Economy	66600.00
0005435825293	17985	Economy	66600.00
0005433416129	17985	Economy	66600.00
0005435825192	17985	Economy	66600.00
0005435825264	17985	Economy	66600.00
0005435825218	17985	Economy	66600.00
0005435825173	17985	Economy	66600.00
0005435825147	17985	Economy	66600.00
0005435825130	17985	Economy	66600.00
0005435825180	17985	Economy	66600.00
0005433416130	17985	Economy	66600.00
0005434460556	17518	Economy	14800.00
0005434460544	17518	Economy	13500.00
0005434460549	17518	Economy	13500.00
0005434462837	17518	Economy	13500.00
0005434460555	17518	Economy	13500.00
0005434462839	17518	Economy	13500.00
0005434462834	17518	Economy	13500.00
0005434460548	17518	Economy	13500.00
0005434462838	17518	Economy	13500.00
0005435243399	5659	Business	27800.00
0005435243318	5659	Business	27800.00
0005435243406	5659	Business	27800.00
0005435950045	5659	Business	27800.00
0005435950044	5659	Business	27800.00
0005435476935	5659	Economy	9300.00
0005432785357	5659	Economy	9300.00
0005435243330	5659	Economy	9300.00
0005432785356	5659	Economy	9300.00
0005435476932	5659	Economy	9300.00
0005435243539	5659	Economy	9300.00
0005432785358	5659	Economy	9300.00
0005435243410	5659	Economy	9300.00
0005435243391	5659	Economy	9300.00
0005435243517	5659	Economy	9300.00
0005432785355	5659	Economy	9300.00
0005435243537	5659	Economy	9300.00
0005435243471	5659	Economy	9300.00
0005435243453	5659	Economy	9300.00
0005435950042	5659	Economy	9300.00
0005435243443	5659	Economy	9300.00
0005435950043	5659	Economy	9300.00
0005435243430	5659	Economy	9300.00
0005435243538	5659	Economy	9300.00
0005435243583	5659	Economy	9300.00
0005435476936	5659	Economy	9300.00
0005435243416	5659	Economy	9300.00
0005435243579	5659	Economy	9300.00
0005435476911	5659	Economy	9300.00
0005435243429	5659	Economy	9300.00
0005435243584	5659	Economy	9300.00
0005435243452	5659	Economy	9300.00
0005432785354	5659	Economy	9300.00
0005435243518	5659	Economy	9300.00
0005432785361	5659	Economy	9300.00
0005435476924	5659	Economy	9300.00
0005435243492	5659	Economy	9300.00
0005432785360	5659	Economy	9300.00
0005435243580	5659	Economy	9300.00
0005435243472	5659	Economy	9300.00
0005435243445	5659	Economy	9300.00
0005435476912	5659	Economy	9300.00
0005432785359	5659	Economy	9300.00
0005435243502	5659	Economy	9300.00
0005435243415	5659	Economy	9300.00
0005432785052	15383	Business	27800.00
0005432784996	15383	Business	27800.00
0005435243645	15383	Business	27800.00
0005432785124	15383	Business	27800.00
0005432784751	15383	Business	27800.00
0005432785012	15383	Business	27800.00
0005432785002	15383	Business	27800.00
0005432785175	15383	Business	27800.00
0005432785051	15383	Business	27800.00
0005432784987	15383	Business	27800.00
0005432784970	15383	Economy	9300.00
0005432784961	15383	Economy	9300.00
0005432785000	15383	Economy	9300.00
0005432784952	15383	Economy	9300.00
0005432785078	15383	Economy	9300.00
0005432784729	15383	Economy	9300.00
0005432785071	15383	Economy	10200.00
0005432785091	15383	Economy	10200.00
0005432784936	15383	Economy	10200.00
0005432785070	15383	Economy	10200.00
0005432784990	15383	Economy	10200.00
0005435243652	15383	Economy	9300.00
0005432784965	15383	Economy	9300.00
0005432784850	15383	Economy	9300.00
0005432784932	15383	Economy	9300.00
0005432784890	15383	Economy	9300.00
0005435243651	15383	Economy	9300.00
0005432784938	15383	Economy	9300.00
0005432784906	15383	Economy	9300.00
0005432784937	15383	Economy	9300.00
0005432785072	15383	Economy	9300.00
0005435243653	15383	Economy	9300.00
0005432784833	15383	Economy	9300.00
0005432785174	15383	Economy	9300.00
0005432784750	15383	Economy	9300.00
0005435243655	15383	Economy	9300.00
0005435243650	15383	Economy	9300.00
0005432784918	15383	Economy	9300.00
0005432784819	15383	Economy	9300.00
0005432785179	15383	Economy	9300.00
0005435476998	15383	Economy	9300.00
0005432785137	15383	Economy	9300.00
0005432785100	15383	Economy	9300.00
0005435243648	15383	Economy	9300.00
0005432784874	15383	Economy	9300.00
0005435476999	15383	Economy	9300.00
0005432785082	15383	Economy	9300.00
0005432784887	15383	Economy	9300.00
0005432784777	15383	Economy	9300.00
0005432784886	15383	Economy	9300.00
0005432784980	15383	Economy	9300.00
0005432785178	15383	Economy	9300.00
0005432785027	15383	Economy	9300.00
0005432784875	15383	Economy	9300.00
0005432784752	15383	Economy	9300.00
0005432785140	15383	Economy	9300.00
0005435243647	15383	Economy	9300.00
0005432784991	15383	Economy	9300.00
0005435476997	15383	Economy	9300.00
0005432785099	15383	Economy	9300.00
0005432784877	15383	Economy	9300.00
0005435243654	15383	Economy	9300.00
0005435626888	15383	Economy	9300.00
0005435626887	15383	Economy	9300.00
0005432785180	15383	Economy	9300.00
0005435243646	15383	Economy	9300.00
0005432785024	15383	Economy	9300.00
0005432784818	15383	Economy	9300.00
0005432785056	15383	Economy	9300.00
0005432784783	15383	Economy	9300.00
0005432784979	15383	Economy	9300.00
0005435243644	15383	Economy	9300.00
0005432784964	15383	Economy	9300.00
0005432785081	15383	Economy	9300.00
0005432784866	15383	Economy	9300.00
0005432784901	15383	Economy	9300.00
0005435243649	15383	Economy	9300.00
0005432848725	4385	Economy	7000.00
0005435851114	4385	Economy	6300.00
0005435851116	4385	Economy	6300.00
0005435851129	4385	Economy	6300.00
0005435851128	4385	Economy	6300.00
0005435851125	4385	Economy	6300.00
0005435851130	4385	Economy	6300.00
0005432848724	4385	Economy	6300.00
0005435851082	4385	Economy	6300.00
0005435851123	4385	Economy	6300.00
0005435851138	4385	Economy	6300.00
0005435851113	4385	Economy	6300.00
0005432848613	28853	Economy	7000.00
0005432848650	28853	Economy	7000.00
0005432848652	28853	Economy	7000.00
0005432848665	28853	Economy	6300.00
0005434463970	28853	Economy	6300.00
0005432848692	28853	Economy	6300.00
0005432848660	28853	Economy	6300.00
0005434463974	28853	Economy	6300.00
0005432848662	28853	Economy	6300.00
0005432848661	28853	Economy	6300.00
0005432848651	28853	Economy	6300.00
0005435851183	28853	Economy	6300.00
0005432848614	28853	Economy	6300.00
0005432848659	28853	Economy	6300.00
0005434463971	28853	Economy	6300.00
0005432848675	28853	Economy	6300.00
0005432848628	28853	Economy	6300.00
0005432848658	28853	Economy	6300.00
0005435851182	28853	Economy	6300.00
0005432848693	28853	Economy	6300.00
0005432848636	28853	Economy	6300.00
0005435851181	28853	Economy	6300.00
0005433497891	6355	Business	11900.00
0005433497890	6355	Business	11900.00
0005435257504	6355	Economy	4000.00
0005435257465	6355	Economy	4000.00
0005435257455	6355	Economy	4000.00
0005434926847	6355	Economy	4000.00
0005434926852	6355	Economy	4400.00
0005435257413	6355	Economy	4400.00
0005432075329	6355	Economy	4000.00
0005432075326	6355	Economy	4000.00
0005432075327	6355	Economy	4000.00
0005435257462	6355	Economy	4000.00
0005433497886	6355	Economy	4000.00
0005435257411	6355	Economy	4000.00
0005433497889	6355	Economy	4000.00
0005434926850	6355	Economy	4000.00
0005432075328	6355	Economy	4000.00
0005434444181	6355	Economy	4000.00
0005434444182	6355	Economy	4000.00
0005435257428	6355	Economy	4000.00
0005434926846	6355	Economy	4000.00
0005434926851	6355	Economy	4000.00
0005433497887	6355	Economy	4000.00
0005434444183	6355	Economy	4000.00
0005435257464	6355	Economy	4000.00
0005434926843	6355	Economy	4000.00
0005435257463	6355	Economy	4000.00
0005434926848	6355	Economy	4000.00
0005435257495	6355	Economy	4000.00
0005433497892	6355	Economy	4000.00
0005434926844	6355	Economy	4000.00
0005433497888	6355	Economy	4000.00
0005434926845	6355	Economy	4000.00
0005434926849	6355	Economy	4000.00
0005435257541	20407	Economy	4000.00
0005435257544	20407	Economy	4000.00
0005435257542	20407	Economy	4000.00
0005435257543	20407	Economy	4000.00
0005433497730	20408	Business	11900.00
0005434926562	20408	Business	11900.00
0005433497703	20408	Business	11900.00
0005434444096	20408	Business	11900.00
0005434926513	20408	Business	11900.00
0005433497789	20408	Business	11900.00
0005434926503	20408	Business	11900.00
0005434926591	20408	Business	11900.00
0005434926356	20408	Business	11900.00
0005434926527	20408	Business	11900.00
0005433497666	20408	Business	11900.00
0005433497825	20408	Economy	4000.00
0005434926377	20408	Economy	4000.00
0005434926563	20408	Economy	4000.00
0005434926550	20408	Economy	4000.00
0005433497672	20408	Economy	4000.00
0005434444091	20408	Economy	4000.00
0005433497767	20408	Economy	4000.00
0005433497621	20408	Economy	4000.00
0005433497826	20408	Economy	4000.00
0005433497644	20408	Economy	4400.00
0005433497687	20408	Economy	4400.00
0005433497729	20408	Economy	4400.00
0005433497651	20408	Economy	4400.00
0005434926598	20408	Economy	4000.00
0005434444084	20408	Economy	4000.00
0005434926505	20408	Economy	4000.00
0005433497788	20408	Economy	4000.00
0005434444115	20408	Economy	4000.00
0005434926442	20408	Economy	4000.00
0005434926443	20408	Economy	4000.00
0005434444093	20408	Economy	4000.00
0005434926481	20408	Economy	4000.00
0005434926566	20408	Economy	4000.00
0005434926472	20408	Economy	4000.00
0005434444034	20408	Economy	4000.00
0005434926603	20408	Economy	4000.00
0005433497736	20408	Economy	4000.00
0005434926538	20408	Economy	4000.00
0005434926549	20408	Economy	4000.00
0005434926467	20408	Economy	4000.00
0005434926488	20408	Economy	4000.00
0005434926579	20408	Economy	4000.00
0005434444047	20408	Economy	4000.00
0005433497686	20408	Economy	4000.00
0005434926528	20408	Economy	4000.00
0005433497667	20408	Economy	4000.00
0005434926600	20408	Economy	4000.00
0005434926547	20408	Economy	4000.00
0005433497769	20408	Economy	4000.00
0005433497748	20408	Economy	4000.00
0005433497768	20408	Economy	4000.00
0005434926575	20408	Economy	4000.00
0005434926341	20408	Economy	4000.00
0005434926466	20408	Economy	4000.00
0005434926543	20408	Economy	4000.00
0005434444114	20408	Economy	4000.00
0005434444033	20408	Economy	4000.00
0005433497755	20408	Economy	4000.00
0005433497816	20408	Economy	4000.00
0005434444090	20408	Economy	4000.00
0005433497620	20408	Economy	4000.00
0005434444014	20408	Economy	4000.00
0005434926378	20408	Economy	4000.00
0005434444083	20408	Economy	4000.00
0005433497726	20408	Economy	4000.00
0005433497728	20408	Economy	4000.00
0005433497756	20408	Economy	4000.00
0005434926412	20408	Economy	4000.00
0005433497735	20408	Economy	4000.00
0005433497704	20408	Economy	4000.00
0005433497747	20408	Economy	4000.00
0005434926514	20408	Economy	4000.00
0005434926604	20408	Economy	4000.00
0005433497727	20408	Economy	4000.00
0005433497741	20408	Economy	4000.00
0005434926487	20408	Economy	4000.00
0005434926599	20408	Economy	4000.00
0005434444059	20408	Economy	4000.00
0005434926526	20408	Economy	4000.00
0005434926261	20408	Economy	4000.00
0005434926512	20408	Economy	4000.00
0005434926606	20408	Economy	4000.00
0005432785046	12161	Business	41200.00
0005432785030	12161	Business	41200.00
0005432784928	12161	Business	41200.00
0005432784895	12161	Business	41200.00
0005432785044	12161	Business	41200.00
0005432785066	12161	Business	41200.00
0005432784926	12161	Economy	13700.00
0005432785132	12161	Economy	13700.00
0005432784821	12161	Economy	13700.00
0005432785086	12161	Economy	13700.00
0005432784916	12161	Economy	15100.00
0005432785183	12161	Economy	15100.00
0005432784759	12161	Economy	13700.00
0005432784927	12161	Economy	13700.00
0005432784955	12161	Economy	13700.00
0005432785067	12161	Economy	13700.00
0005432785120	12161	Economy	13700.00
0005435243659	12161	Economy	13700.00
0005432785042	12161	Economy	13700.00
0005432785043	12161	Economy	13700.00
0005432784760	12161	Economy	13700.00
0005432785028	12161	Economy	13700.00
0005432784941	12161	Economy	13700.00
0005432785029	12161	Economy	13700.00
0005435243658	12161	Economy	13700.00
0005435243656	12161	Economy	13700.00
0005432784986	12161	Economy	13700.00
0005432784956	12161	Economy	13700.00
0005432785169	12161	Economy	13700.00
0005432784957	12161	Economy	13700.00
0005432785119	12161	Economy	13700.00
0005432785036	12161	Economy	13700.00
0005432785045	12161	Economy	13700.00
0005432785065	12161	Economy	13700.00
0005432785111	12161	Economy	13700.00
0005432785168	12161	Economy	13700.00
0005432784917	12161	Economy	13700.00
0005435243657	12161	Economy	13700.00
0005432784975	12161	Economy	13700.00
0005435243660	12161	Economy	13700.00
0005432785035	12161	Economy	13700.00
0005432784894	12161	Economy	13700.00
0005432784873	12161	Economy	13700.00
0005432784789	12161	Economy	13700.00
0005432785040	12161	Economy	13700.00
0005432785039	12161	Economy	13700.00
0005432784872	12161	Economy	13700.00
0005432785342	15434	Business	41200.00
0005435243477	15434	Business	41200.00
0005435243547	15434	Business	41200.00
0005435243411	15434	Business	41200.00
0005435243349	15434	Business	41200.00
0005432785348	15434	Business	41200.00
0005435243454	15434	Economy	13700.00
0005435243388	15434	Economy	13700.00
0005435243463	15434	Economy	13700.00
0005435243361	15434	Economy	13700.00
0005435243479	15434	Economy	13700.00
0005432785339	15434	Economy	13700.00
0005432785351	15434	Economy	13700.00
0005435243522	15434	Economy	13700.00
0005432785343	15434	Economy	13700.00
0005435243450	15434	Economy	13700.00
0005432785335	15434	Economy	13700.00
0005435243491	15434	Economy	13700.00
0005435243478	15434	Economy	13700.00
0005435243432	15434	Economy	13700.00
0005435243290	15434	Economy	13700.00
0005435243387	15434	Economy	13700.00
0005432785349	15434	Economy	13700.00
0005432785340	15434	Economy	13700.00
0005435243455	15434	Economy	13700.00
0005432785352	15434	Economy	13700.00
0005432785337	15434	Economy	13700.00
0005435243365	15434	Economy	13700.00
0005435243371	15434	Economy	13700.00
0005432785336	15434	Economy	13700.00
0005435243360	15434	Economy	13700.00
0005432785350	15434	Economy	13700.00
0005435243370	15434	Economy	13700.00
0005432785347	15434	Economy	13700.00
0005432785345	15434	Economy	13700.00
0005432785338	15434	Economy	13700.00
0005432785353	15434	Economy	13700.00
0005432785346	15434	Economy	13700.00
0005432785341	15434	Economy	13700.00
0005435243464	15434	Economy	13700.00
0005435243359	15434	Economy	13700.00
0005435243433	15434	Economy	13700.00
0005435243334	15434	Economy	13700.00
0005435243348	15434	Economy	13700.00
0005432785344	15434	Economy	13700.00
0005434880450	10072	Business	49700.00
0005434880178	10072	Business	49700.00
0005434880677	10072	Business	49700.00
0005434880669	10072	Business	49700.00
0005434880512	10072	Business	49700.00
0005434880465	10072	Business	49700.00
0005434880488	10072	Business	49700.00
0005434880701	10072	Business	49700.00
0005434880047	10072	Business	49700.00
0005434880229	10072	Business	49700.00
0005434880414	10072	Business	49700.00
0005434880728	10072	Business	49700.00
0005434880205	10072	Business	49700.00
0005434880449	10072	Business	49700.00
0005434880540	10072	Business	49700.00
0005434880310	10072	Business	49700.00
0005434880264	10072	Business	49700.00
0005434880793	10072	Business	49700.00
0005434880416	10072	Business	49700.00
0005434880463	10072	Economy	16600.00
0005434880296	10072	Economy	16600.00
0005434880257	10072	Economy	16600.00
0005434880412	10072	Economy	16600.00
0005434880453	10072	Economy	16600.00
0005434880023	10072	Economy	16600.00
0005434880294	10072	Economy	16600.00
0005434880532	10072	Economy	16600.00
0005435914208	10072	Economy	16600.00
0005434880119	10072	Economy	16600.00
0005434880222	10072	Economy	16600.00
0005434880592	10072	Economy	18200.00
0005434880177	10072	Economy	18200.00
0005434880396	10072	Economy	18200.00
0005434880368	10072	Economy	16600.00
0005434880031	10072	Economy	18200.00
0005434879938	10072	Economy	16600.00
0005434880278	10072	Economy	16600.00
0005434880132	10072	Economy	16600.00
0005434880118	10072	Economy	16600.00
0005434880587	10072	Economy	16600.00
0005434879937	10072	Economy	16600.00
0005434880525	10072	Economy	16600.00
0005434880295	10072	Economy	16600.00
0005434880429	10072	Economy	16600.00
0005434880482	10072	Economy	16600.00
0005434880215	10072	Economy	16600.00
0005435914210	10072	Economy	16600.00
0005434880063	10072	Economy	16600.00
0005434880578	10072	Economy	16600.00
0005434880408	10072	Economy	16600.00
0005434880591	10072	Economy	16600.00
0005434880260	10072	Economy	16600.00
0005434879880	10072	Economy	16600.00
0005434880434	10072	Economy	16600.00
0005434880792	10072	Economy	16600.00
0005435914207	10072	Economy	16600.00
0005434880255	10072	Economy	16600.00
0005435914205	10072	Economy	16600.00
0005434880653	10072	Economy	16600.00
0005434880250	10072	Economy	16600.00
0005434880513	10072	Economy	16600.00
0005434880369	10072	Economy	16600.00
0005434880397	10072	Economy	16600.00
0005434880371	10072	Economy	16600.00
0005434880466	10072	Economy	16600.00
0005434880395	10072	Economy	16600.00
0005434880462	10072	Economy	16600.00
0005434880514	10072	Economy	16600.00
0005434880095	10072	Economy	16600.00
0005434880230	10072	Economy	16600.00
0005434880526	10072	Economy	16600.00
0005434880311	10072	Economy	16600.00
0005434880582	10072	Economy	16600.00
0005434880156	10072	Economy	16600.00
0005434880553	10072	Economy	16600.00
0005435914206	10072	Economy	16600.00
0005434880240	10072	Economy	16600.00
0005434880668	10072	Economy	16600.00
0005434880091	10072	Economy	16600.00
0005434880729	10072	Economy	16600.00
0005434880579	10072	Economy	16600.00
0005434880389	10072	Economy	16600.00
0005434880388	10072	Economy	16600.00
0005434880249	10072	Economy	16600.00
0005434880117	10072	Economy	16600.00
0005434880615	10072	Economy	16600.00
0005434880256	10072	Economy	16600.00
0005434880508	10072	Economy	16600.00
0005434880678	10072	Economy	16600.00
0005434880598	10072	Economy	16600.00
0005434880328	10072	Economy	16600.00
0005434880221	10072	Economy	16600.00
0005434880754	10072	Economy	16600.00
0005434880489	10072	Economy	16600.00
0005434880423	10072	Economy	16600.00
0005434880590	10072	Economy	16600.00
0005434879977	10072	Economy	16600.00
0005434880616	10072	Economy	16600.00
0005435914209	10072	Economy	16600.00
0005434880272	10072	Economy	16600.00
0005434880370	10072	Economy	16600.00
0005434880481	10072	Economy	16600.00
0005434880207	10072	Economy	16600.00
0005434880176	10072	Economy	16600.00
0005435914061	14608	Business	49700.00
0005434880972	14608	Business	49700.00
0005434880975	14608	Business	49700.00
0005435914066	14608	Business	49700.00
0005435914067	14608	Economy	16600.00
0005435914003	14608	Economy	16600.00
0005435914004	14608	Economy	16600.00
0005435914039	14608	Economy	16600.00
0005434880970	14608	Economy	16600.00
0005434880969	14608	Economy	16600.00
0005434910159	14608	Economy	16600.00
0005434910160	14608	Economy	16600.00
0005434880974	14608	Economy	16600.00
0005435914040	14608	Economy	16600.00
0005434880976	14608	Economy	16600.00
0005435914053	14608	Economy	16600.00
0005434758962	14608	Economy	16600.00
0005434910165	14608	Economy	16600.00
0005434880978	14608	Economy	16600.00
0005434910156	14608	Economy	16600.00
0005434880973	14608	Economy	16600.00
0005434880977	14608	Economy	16600.00
0005434910155	14608	Economy	16600.00
0005434880971	14608	Economy	16600.00
0005435914095	14608	Economy	16600.00
0005434758961	14608	Economy	16600.00
0005434252218	9263	Economy	22400.00
0005434252189	9263	Economy	20300.00
0005434252192	9263	Economy	20300.00
0005435660467	9263	Economy	20300.00
0005434252190	9263	Economy	20300.00
0005434252188	9263	Economy	20300.00
0005435660468	9263	Economy	20300.00
0005434252217	9263	Economy	20300.00
0005434252187	9263	Economy	20300.00
0005435660434	24652	Economy	22400.00
0005435660401	24652	Economy	20300.00
0005435660435	24652	Economy	20300.00
0005435660427	24652	Economy	20300.00
0005435660426	24652	Economy	20300.00
0005435660439	24652	Economy	20300.00
0005435660395	24652	Economy	20300.00
0005434252245	24652	Economy	20300.00
0005433681962	2779	Business	33000.00
0005432967565	2779	Business	33000.00
0005432967593	2779	Business	33000.00
0005432967512	2779	Economy	11000.00
0005432967457	2779	Economy	11000.00
0005432967589	2779	Economy	11000.00
0005433681960	2779	Economy	11000.00
0005432967594	2779	Economy	11000.00
0005432967552	2779	Economy	12100.00
0005432967479	2779	Economy	12100.00
0005432967471	2779	Economy	11000.00
0005433681965	2779	Economy	11000.00
0005432967559	2779	Economy	11000.00
0005432222939	2779	Economy	11000.00
0005433681966	2779	Economy	11000.00
0005432967481	2779	Economy	11000.00
0005432967525	2779	Economy	11000.00
0005432967590	2779	Economy	11000.00
0005433681959	2779	Economy	11000.00
0005433681961	2779	Economy	11000.00
0005432967480	2779	Economy	11000.00
0005433681958	2779	Economy	11000.00
0005432967526	2779	Economy	11000.00
0005432967527	2779	Economy	11000.00
0005432967551	2779	Economy	11000.00
0005432967573	2779	Economy	11000.00
0005432967560	2779	Economy	11000.00
0005433681964	2779	Economy	11000.00
0005433681957	2779	Economy	11000.00
0005432967528	2779	Economy	11000.00
0005432967458	2779	Economy	11000.00
0005432967513	2779	Economy	11000.00
0005433681956	2779	Economy	11000.00
0005433681963	2779	Economy	11000.00
0005433681620	29155	Business	33000.00
0005433681758	29155	Business	33000.00
0005433681864	29155	Business	33000.00
0005433681808	29155	Economy	11000.00
0005433681533	29155	Economy	11000.00
0005433681606	29155	Economy	11000.00
0005433681702	29155	Economy	11000.00
0005433681724	29155	Economy	12100.00
0005433681742	29155	Economy	11000.00
0005433681737	29155	Economy	11000.00
0005433690971	29155	Economy	11000.00
0005432967679	29155	Economy	11000.00
0005433681673	29155	Economy	11000.00
0005433681694	29155	Economy	11000.00
0005433690970	29155	Economy	11000.00
0005433687755	29155	Economy	11000.00
0005433681599	29155	Economy	11000.00
0005433681672	29155	Economy	11000.00
0005432967680	29155	Economy	11000.00
0005433681534	29155	Economy	11000.00
0005433681562	29155	Economy	11000.00
0005433681791	29155	Economy	11000.00
0005433681848	29155	Economy	11000.00
0005433681627	29155	Economy	11000.00
0005433681532	29155	Economy	11000.00
0005433687757	29155	Economy	11000.00
0005433684468	29155	Economy	11000.00
0005433684467	29155	Economy	11000.00
0005433681564	29155	Economy	11000.00
0005433690977	29155	Economy	11000.00
0005433684463	29155	Economy	11000.00
0005433681790	29155	Economy	11000.00
0005433681607	29155	Economy	11000.00
0005433681637	29155	Economy	11000.00
0005433681558	29155	Economy	11000.00
0005433681638	29155	Economy	11000.00
0005433687756	29155	Economy	11000.00
0005433681709	29155	Economy	11000.00
0005433681730	29155	Economy	11000.00
0005433681809	29155	Economy	11000.00
0005432967678	29155	Economy	11000.00
0005433634815	9314	Business	132900.00
0005433616814	9314	Business	132900.00
0005433616798	9314	Business	132900.00
0005433616801	9314	Business	132900.00
0005433634819	9314	Business	132900.00
0005433616797	9314	Business	132900.00
0005434152829	9314	Business	132900.00
0005433616799	9314	Business	132900.00
0005433578203	9314	Business	132900.00
0005434163843	9314	Business	132900.00
0005434269148	9314	Business	132900.00
0005434272223	9314	Economy	48700.00
0005433616802	9314	Economy	44300.00
0005432755173	9314	Economy	44300.00
0005435983718	9314	Economy	44300.00
0005434272222	9314	Economy	44300.00
0005433634816	9314	Economy	44300.00
0005433616795	9314	Economy	44300.00
0005434153554	9314	Economy	44300.00
0005434152826	9314	Economy	44300.00
0005433578202	9314	Economy	44300.00
0005434163814	9314	Economy	44300.00
0005435983719	9314	Economy	44300.00
0005433616796	9314	Economy	44300.00
0005432145173	9314	Economy	44300.00
0005434163830	9314	Economy	44300.00
0005433616807	9314	Economy	44300.00
0005434269150	9314	Economy	44300.00
0005433616808	9314	Economy	44300.00
0005433616794	9314	Economy	44300.00
0005433616805	9314	Economy	44300.00
0005433616793	9314	Economy	44300.00
0005434153573	9314	Economy	44300.00
0005433578205	9314	Economy	44300.00
0005434269149	9314	Economy	44300.00
0005434163816	9314	Economy	44300.00
0005433578200	9314	Economy	48700.00
0005433634817	9314	Economy	48700.00
0005433634814	9314	Economy	44300.00
0005434163832	9314	Economy	44300.00
0005433616809	9314	Economy	44300.00
0005433578199	9314	Economy	48700.00
0005433616811	9314	Economy	44300.00
0005433616804	9314	Economy	44300.00
0005435983720	9314	Economy	44300.00
0005433578204	9314	Economy	44300.00
0005433616816	9314	Economy	44300.00
0005433634813	9314	Economy	44300.00
0005432145172	9314	Economy	44300.00
0005434153559	9314	Economy	44300.00
0005433634820	9314	Economy	44300.00
0005433616813	9314	Economy	44300.00
0005434152828	9314	Economy	44300.00
0005433616812	9314	Economy	44300.00
0005434152825	9314	Economy	44300.00
0005433578201	9314	Economy	44300.00
0005434163842	9314	Economy	44300.00
0005433616791	9314	Economy	44300.00
0005433616800	9314	Economy	44300.00
0005433634818	9314	Economy	44300.00
0005433634812	9314	Economy	44300.00
0005432755172	9314	Economy	44300.00
0005433616806	9314	Economy	44300.00
0005433616815	9314	Economy	44300.00
0005433616803	9314	Economy	44300.00
0005433616792	9314	Economy	44300.00
0005433616810	9314	Economy	44300.00
0005434163813	9314	Economy	44300.00
0005433634598	25236	Business	132900.00
0005433634537	25236	Business	132900.00
0005433634576	25236	Business	132900.00
0005433616367	25236	Business	132900.00
0005433616362	25236	Business	132900.00
0005433578116	25236	Business	132900.00
0005433616349	25236	Business	132900.00
0005433616359	25236	Business	132900.00
0005433616393	25236	Business	132900.00
0005433616061	25236	Business	132900.00
0005433616470	25236	Business	132900.00
0005433634529	25236	Business	132900.00
0005433634601	25236	Business	132900.00
0005433616364	25236	Business	132900.00
0005433616578	25236	Business	132900.00
0005433616469	25236	Business	132900.00
0005433578158	25236	Business	132900.00
0005433616550	25236	Business	132900.00
0005433616347	25236	Business	132900.00
0005433616600	25236	Business	132900.00
0005433616156	25236	Economy	48700.00
0005433634551	25236	Economy	48700.00
0005433616043	25236	Economy	48700.00
0005433616178	25236	Economy	48700.00
0005433634555	25236	Economy	48700.00
0005433616019	25236	Economy	44300.00
0005433616436	25236	Economy	44300.00
0005433616456	25236	Economy	44300.00
0005433616299	25236	Economy	44300.00
0005433616520	25236	Economy	44300.00
0005433634605	25236	Economy	44300.00
0005433616471	25236	Economy	44300.00
0005433616164	25236	Economy	44300.00
0005433634614	25236	Economy	44300.00
0005433616018	25236	Economy	44300.00
0005433616449	25236	Economy	44300.00
0005433616177	25236	Economy	44300.00
0005433616166	25236	Economy	44300.00
0005433616395	25236	Economy	44300.00
0005433578141	25236	Economy	44300.00
0005433634577	25236	Economy	44300.00
0005433578098	25236	Economy	44300.00
0005433616195	25236	Economy	44300.00
0005433616457	25236	Economy	44300.00
0005433616430	25236	Economy	44300.00
0005433615910	25236	Economy	44300.00
0005433616243	25236	Economy	44300.00
0005433616425	25236	Economy	44300.00
0005433578027	25236	Economy	44300.00
0005433578152	25236	Economy	44300.00
0005433616176	25236	Economy	44300.00
0005433616341	25236	Economy	44300.00
0005433634623	25236	Economy	44300.00
0005433616505	25236	Economy	44300.00
0005433616472	25236	Economy	44300.00
0005433578104	25236	Economy	44300.00
0005433578103	25236	Economy	44300.00
0005433615950	25236	Economy	44300.00
0005433616402	25236	Economy	44300.00
0005433578151	25236	Economy	44300.00
0005433616551	25236	Economy	44300.00
0005433634611	25236	Economy	44300.00
0005433634582	25236	Economy	44300.00
0005433616366	25236	Economy	44300.00
0005433634705	25236	Economy	48700.00
0005433616194	25236	Economy	48700.00
0005433616044	25236	Economy	48700.00
0005433616556	25236	Economy	48700.00
0005433634536	25236	Economy	44300.00
0005433616459	25236	Economy	44300.00
0005433634612	25236	Economy	44300.00
0005433634624	25236	Economy	48700.00
0005433634659	25236	Economy	44300.00
0005433578102	25236	Economy	44300.00
0005433615909	25236	Economy	44300.00
0005433616394	25236	Economy	44300.00
0005433578055	25236	Economy	44300.00
0005433616363	25236	Economy	44300.00
0005433634550	25236	Economy	44300.00
0005433616458	25236	Economy	44300.00
0005433634557	25236	Economy	44300.00
0005433616086	25236	Economy	44300.00
0005433616473	25236	Economy	44300.00
0005433616300	25236	Economy	44300.00
0005433578125	25236	Economy	44300.00
0005433578054	25236	Economy	44300.00
0005433578133	25236	Economy	44300.00
0005433634704	25236	Economy	44300.00
0005433578123	25236	Economy	44300.00
0005433634597	25236	Economy	44300.00
0005433616431	25236	Economy	44300.00
0005433578132	25236	Economy	44300.00
0005433634508	25236	Economy	44300.00
0005433616087	25236	Economy	44300.00
0005433578115	25236	Economy	44300.00
0005433616279	25236	Economy	44300.00
0005433616377	25236	Economy	44300.00
0005433634450	25236	Economy	44300.00
0005433634556	25236	Economy	44300.00
0005433634657	25236	Economy	44300.00
0005433616368	25236	Economy	44300.00
0005433578150	25236	Economy	44300.00
0005433634481	25236	Economy	44300.00
0005433616475	25236	Economy	44300.00
0005433616277	25236	Economy	44300.00
0005433578142	25236	Economy	44300.00
0005435854086	25236	Economy	44300.00
0005434271351	4237	Business	193100.00
0005432571412	4237	Business	193100.00
0005435856291	4237	Business	193100.00
0005435787394	4237	Business	193100.00
0005435856290	4237	Economy	64400.00
0005435854082	4237	Economy	64400.00
0005435960176	4237	Economy	64400.00
0005435787393	4237	Economy	64400.00
0005432571397	4237	Economy	64400.00
0005435987057	4237	Economy	64400.00
0005435987059	4237	Economy	64400.00
0005435987058	4237	Economy	64400.00
0005435947550	4237	Economy	64400.00
0005435947547	4237	Economy	64400.00
0005435856305	4237	Economy	64400.00
0005435947535	4237	Economy	64400.00
0005435854083	4237	Economy	64400.00
0005435947600	4237	Economy	64400.00
0005434271352	4237	Economy	64400.00
0005435947517	4237	Economy	64400.00
0005432571410	4237	Economy	64400.00
0005435854081	4237	Economy	64400.00
0005435854076	4237	Economy	64400.00
0005435947572	4237	Economy	64400.00
0005435856304	4237	Economy	64400.00
0005435947549	4237	Economy	64400.00
0005432571414	4237	Economy	64400.00
0005435947548	4237	Economy	64400.00
0005435854075	4237	Economy	64400.00
0005435987056	4237	Economy	64400.00
0005432571413	4237	Economy	64400.00
0005435947580	4237	Economy	64400.00
0005435986949	26596	Business	193100.00
0005435947680	26596	Economy	64400.00
0005435986918	26596	Economy	64400.00
0005435947679	26596	Economy	64400.00
0005435987005	26596	Economy	64400.00
0005432571438	26596	Economy	64400.00
0005435986989	26596	Economy	64400.00
0005435986908	26596	Economy	64400.00
0005435986950	26596	Economy	64400.00
0005435986915	26596	Economy	64400.00
0005435986936	26596	Economy	64400.00
0005435947681	26596	Economy	64400.00
0005435986931	26596	Economy	64400.00
0005435856331	26596	Economy	64400.00
0005435986981	26596	Economy	64400.00
0005435986920	26596	Economy	64400.00
0005435986975	26596	Economy	64400.00
0005435986938	26596	Economy	64400.00
0005435986909	26596	Economy	64400.00
0005432949342	361	Business	21500.00
0005433075404	361	Business	21500.00
0005433129368	361	Business	21500.00
0005433570947	361	Business	21500.00
0005432949279	361	Business	21500.00
0005432949461	361	Business	21500.00
0005433570963	361	Business	21500.00
0005433075295	361	Business	21500.00
0005434326039	361	Business	21500.00
0005433075313	361	Business	21500.00
0005433570962	361	Business	21500.00
0005432949476	361	Business	21500.00
0005433129393	361	Business	21500.00
0005433570965	361	Business	21500.00
0005432949434	361	Business	21500.00
0005434326037	361	Business	21500.00
0005434088030	361	Business	21500.00
0005433075402	361	Business	21500.00
0005432949463	361	Business	21500.00
0005432949462	361	Business	21500.00
0005432949229	361	Business	21500.00
0005434088033	361	Business	21500.00
0005433570951	361	Economy	7900.00
0005433570953	361	Economy	7900.00
0005432239114	361	Economy	7900.00
0005432949210	361	Economy	7900.00
0005432949454	361	Economy	7900.00
0005433570961	361	Economy	7900.00
0005432949497	361	Economy	7200.00
0005433570954	361	Economy	7200.00
0005432949211	361	Economy	7200.00
0005432949436	361	Economy	7200.00
0005433075253	361	Economy	7200.00
0005433570955	361	Economy	7200.00
0005433075297	361	Economy	7200.00
0005433075381	361	Economy	7200.00
0005432949435	361	Economy	7200.00
0005432949484	361	Economy	7200.00
0005433075314	361	Economy	7200.00
0005432949331	361	Economy	7200.00
0005433075351	361	Economy	7200.00
0005433570950	361	Economy	7200.00
0005433129394	361	Economy	7200.00
0005434088029	361	Economy	7200.00
0005432949284	361	Economy	7200.00
0005433075368	361	Economy	7200.00
0005432949383	361	Economy	7200.00
0005433129347	361	Economy	7200.00
0005432949355	361	Economy	7200.00
0005433075450	361	Economy	7200.00
0005434088032	361	Economy	7200.00
0005434088039	361	Economy	7200.00
0005432949464	361	Economy	7200.00
0005432949246	361	Economy	7200.00
0005433570958	361	Economy	7200.00
0005432949477	361	Economy	7200.00
0005433075296	361	Economy	7200.00
0005432949421	361	Economy	7200.00
0005433570949	361	Economy	7200.00
0005433570948	361	Economy	7200.00
0005432949478	361	Economy	7900.00
0005433075449	361	Economy	7900.00
0005434088037	361	Economy	7900.00
0005434326041	361	Economy	7900.00
0005433075294	361	Economy	7200.00
0005432949428	361	Economy	7200.00
0005432949492	361	Economy	7900.00
0005432949491	361	Economy	7200.00
0005434326040	361	Economy	7200.00
0005433075284	361	Economy	7200.00
0005433570959	361	Economy	7200.00
0005434088028	361	Economy	7200.00
0005432239113	361	Economy	7200.00
0005433134231	361	Economy	7200.00
0005432949275	361	Economy	7200.00
0005432949415	361	Economy	7200.00
0005434326038	361	Economy	7200.00
0005432949316	361	Economy	7200.00
0005434088031	361	Economy	7200.00
0005433570956	361	Economy	7200.00
0005432949414	361	Economy	7200.00
0005432949303	361	Economy	7200.00
0005432949330	361	Economy	7200.00
0005432949282	361	Economy	7200.00
0005432949416	361	Economy	7200.00
0005433075341	361	Economy	7200.00
0005433570946	361	Economy	7200.00
0005433570964	361	Economy	7200.00
0005433570957	361	Economy	7200.00
0005434088034	361	Economy	7200.00
0005433075380	361	Economy	7200.00
0005432949343	361	Economy	7200.00
0005434088035	361	Economy	7200.00
0005434088036	361	Economy	7200.00
0005432239115	361	Economy	7200.00
0005433570960	361	Economy	7200.00
0005432949332	361	Economy	7200.00
0005432949324	361	Economy	7200.00
0005432949280	361	Economy	7200.00
0005432949485	361	Economy	7200.00
0005434088038	361	Economy	7200.00
0005432949285	361	Economy	7200.00
0005432949483	361	Economy	7200.00
0005432949315	361	Economy	7200.00
0005433075315	361	Economy	7200.00
0005434088055	361	Economy	7200.00
0005433075340	361	Economy	7200.00
0005433129396	361	Economy	7200.00
0005433134232	361	Economy	7200.00
0005433075367	361	Economy	7200.00
0005433129388	361	Economy	7200.00
0005433570952	361	Economy	7200.00
0005433570163	11621	Business	21500.00
0005432949677	11621	Business	21500.00
0005433569885	11621	Business	21500.00
0005432949676	11621	Business	21500.00
0005433570017	11621	Business	21500.00
0005432949671	11621	Business	21500.00
0005433570274	11621	Business	21500.00
0005433570346	11621	Business	21500.00
0005433570227	11621	Business	21500.00
0005433570428	11621	Business	21500.00
0005433570158	11621	Business	21500.00
0005432949675	11621	Business	21500.00
0005433570192	11621	Business	21500.00
0005433569969	11621	Business	21500.00
0005433075545	11621	Business	21500.00
0005434087926	11621	Business	21500.00
0005433570426	11621	Economy	7900.00
0005433570295	11621	Economy	7900.00
0005433570018	11621	Economy	7900.00
0005433570488	11621	Economy	7900.00
0005433570296	11621	Economy	7200.00
0005433570414	11621	Economy	7200.00
0005433075542	11621	Economy	7200.00
0005433570292	11621	Economy	7200.00
0005433570411	11621	Economy	7200.00
0005432949674	11621	Economy	7200.00
0005434087975	11621	Economy	7200.00
0005433570429	11621	Economy	7200.00
0005433570043	11621	Economy	7200.00
0005433570305	11621	Economy	7200.00
0005433075541	11621	Economy	7200.00
0005432949679	11621	Economy	7200.00
0005433570304	11621	Economy	7200.00
0005433570371	11621	Economy	7200.00
0005433570532	11621	Economy	7200.00
0005432949673	11621	Economy	7200.00
0005432949667	11621	Economy	7200.00
0005433570164	11621	Economy	7200.00
0005433570079	11621	Economy	7200.00
0005432949672	11621	Economy	7200.00
0005433570303	11621	Economy	7200.00
0005433570379	11621	Economy	7200.00
0005432949678	11621	Economy	7200.00
0005434087928	11621	Economy	7200.00
0005433570232	11621	Economy	7200.00
0005432949668	11621	Economy	7200.00
0005433570074	11621	Economy	7200.00
0005433570444	11621	Economy	7200.00
0005434087946	11621	Economy	7200.00
0005432949666	11621	Economy	7200.00
0005433570347	11621	Economy	7200.00
0005433570191	11621	Economy	7200.00
0005433570468	11621	Economy	7200.00
0005433075546	11621	Economy	7200.00
0005433570291	11621	Economy	7200.00
0005433075543	11621	Economy	7200.00
0005432949664	11621	Economy	7200.00
0005433570380	11621	Economy	7900.00
0005433570603	11621	Economy	7900.00
0005434087933	11621	Economy	7900.00
0005433570401	11621	Economy	7900.00
0005433075544	11621	Economy	7200.00
0005433570306	11621	Economy	7200.00
0005433570372	11621	Economy	7200.00
0005433570112	11621	Economy	7200.00
0005433570080	11621	Economy	7200.00
0005433570543	11621	Economy	7200.00
0005433570536	11621	Economy	7200.00
0005433570531	11621	Economy	7200.00
0005433570081	11621	Economy	7200.00
0005432949665	11621	Economy	7200.00
0005433570044	11621	Economy	7200.00
0005433570565	11621	Economy	7200.00
0005434087945	11621	Economy	7200.00
0005433570273	11621	Economy	7200.00
0005433570279	11621	Economy	7200.00
0005433570280	11621	Economy	7200.00
0005432949669	11621	Economy	7200.00
0005433570434	11621	Economy	7200.00
0005433569963	11621	Economy	7200.00
0005433570394	11621	Economy	7200.00
0005432192414	11621	Economy	7200.00
0005433570370	11621	Economy	7200.00
0005434087927	11621	Economy	7200.00
0005433570566	11621	Economy	7200.00
0005433570479	11621	Economy	7200.00
0005433570466	11621	Economy	7200.00
0005433570463	11621	Economy	7200.00
0005433569795	11621	Economy	7200.00
0005433570631	11621	Economy	7200.00
0005433570415	11621	Economy	7200.00
0005433570337	11621	Economy	7200.00
0005433570381	11621	Economy	7200.00
0005433569962	11621	Economy	7200.00
0005433570476	11621	Economy	7200.00
0005433570075	11621	Economy	7200.00
0005433570393	11621	Economy	7200.00
0005432949670	11621	Economy	7200.00
0005434733060	9960	Economy	6300.00
0005434733069	9960	Economy	6300.00
0005434733068	9960	Economy	6300.00
0005434733070	9960	Economy	6300.00
0005434733061	9960	Economy	6300.00
0005433817564	13935	Economy	6300.00
0005433817563	13935	Economy	6300.00
0005434733085	13935	Economy	6300.00
0005433817565	13935	Economy	6300.00
0005433817543	13935	Economy	6300.00
0005432985791	2379	Business	184500.00
0005432985854	2379	Business	184500.00
0005433435267	2379	Business	184500.00
0005433755873	2379	Business	184500.00
0005433755869	2379	Business	184500.00
0005433435257	2379	Business	184500.00
0005433435353	2379	Business	184500.00
0005433435360	2379	Business	184500.00
0005433435141	2379	Business	184500.00
0005432985861	2379	Business	184500.00
0005433435372	2379	Business	184500.00
0005433435413	2379	Economy	61500.00
0005432985830	2379	Economy	61500.00
0005432985784	2379	Economy	61500.00
0005432869689	2379	Economy	61500.00
0005432985877	2379	Economy	61500.00
0005433435356	2379	Economy	61500.00
0005433435386	2379	Economy	61500.00
0005432869665	2379	Economy	61500.00
0005432985878	2379	Economy	61500.00
0005432869664	2379	Economy	61500.00
0005433435183	2379	Economy	61500.00
0005433435278	2379	Economy	61500.00
0005432985833	2379	Economy	61500.00
0005432985649	2379	Economy	61500.00
0005435983670	2379	Economy	61500.00
0005433435253	2379	Economy	61500.00
0005432985869	2379	Economy	61500.00
0005433435300	2379	Economy	61500.00
0005432300441	2379	Economy	61500.00
0005433435325	2379	Economy	61500.00
0005432985904	2379	Economy	61500.00
0005433435238	2379	Economy	61500.00
0005432869672	2379	Economy	61500.00
0005432869690	2379	Economy	61500.00
0005432985932	2379	Economy	61500.00
0005433755876	2379	Economy	61500.00
0005433435368	2379	Economy	61500.00
0005433755867	2379	Economy	61500.00
0005433435289	2379	Economy	61500.00
0005433435139	2379	Economy	61500.00
0005432985937	2379	Economy	61500.00
0005433755872	2379	Economy	61500.00
0005432985804	2379	Economy	61500.00
0005434731260	2379	Economy	61500.00
0005433435412	2379	Economy	61500.00
0005432985805	2379	Economy	61500.00
0005432300440	2379	Economy	61500.00
0005433435258	2379	Economy	61500.00
0005433435277	2379	Economy	61500.00
0005433435280	2379	Economy	61500.00
0005433435254	2379	Economy	61500.00
0005433435411	2379	Economy	61500.00
0005432655892	2379	Economy	61500.00
0005432985915	2379	Economy	61500.00
0005432985806	2379	Economy	61500.00
0005435983672	2379	Economy	61500.00
0005433755868	2379	Economy	61500.00
0005433435347	2379	Economy	61500.00
0005433435266	2379	Economy	67700.00
0005432869697	2379	Economy	61500.00
0005432985767	2379	Economy	67700.00
0005433755870	2379	Economy	61500.00
0005433435367	2379	Economy	61500.00
0005433435140	2379	Economy	61500.00
0005433435344	2379	Economy	61500.00
0005432985880	2379	Economy	61500.00
0005433435357	2379	Economy	61500.00
0005435983669	2379	Economy	61500.00
0005432985974	2379	Economy	61500.00
0005432985931	2379	Economy	61500.00
0005432985814	2379	Economy	61500.00
0005432869671	2379	Economy	61500.00
0005432655891	2379	Economy	61500.00
0005435983671	2379	Economy	61500.00
0005432869680	2379	Economy	61500.00
0005432985913	2379	Economy	61500.00
0005432985862	2379	Economy	61500.00
0005433755874	2379	Economy	61500.00
0005433435373	2379	Economy	61500.00
0005433755871	2379	Economy	61500.00
0005434376161	2379	Economy	61500.00
0005433435184	2379	Economy	61500.00
0005432869670	2379	Economy	61500.00
0005432985883	2379	Economy	61500.00
0005432985855	2379	Economy	61500.00
0005433755875	2379	Economy	61500.00
0005432985914	2379	Economy	61500.00
0005433435324	2379	Economy	61500.00
0005432869698	2379	Economy	61500.00
0005432985831	2379	Economy	61500.00
0005433755526	26171	Business	184500.00
0005432655758	26171	Business	184500.00
0005435983358	26171	Business	184500.00
0005435983426	26171	Business	184500.00
0005433755478	26171	Business	184500.00
0005433755484	26171	Business	184500.00
0005435983359	26171	Business	184500.00
0005435983331	26171	Business	184500.00
0005433755402	26171	Business	184500.00
0005435983313	26171	Business	184500.00
0005435983305	26171	Business	184500.00
0005433755451	26171	Business	184500.00
0005433755481	26171	Business	184500.00
0005433755581	26171	Business	184500.00
0005433755601	26171	Business	184500.00
0005432049567	26171	Business	184500.00
0005435983309	26171	Business	184500.00
0005433755477	26171	Business	184500.00
0005432986005	26171	Business	184500.00
0005435983352	26171	Business	184500.00
0005432986004	26171	Economy	67700.00
0005435983201	26171	Economy	67700.00
0005435983380	26171	Economy	67700.00
0005433755410	26171	Economy	61500.00
0005432869724	26171	Economy	61500.00
0005433755468	26171	Economy	61500.00
0005432655742	26171	Economy	61500.00
0005432655766	26171	Economy	61500.00
0005433755453	26171	Economy	61500.00
0005433755618	26171	Economy	61500.00
0005433755582	26171	Economy	61500.00
0005435983284	26171	Economy	61500.00
0005433755714	26171	Economy	61500.00
0005432049568	26171	Economy	61500.00
0005432986006	26171	Economy	61500.00
0005433755426	26171	Economy	61500.00
0005433755392	26171	Economy	61500.00
0005433755598	26171	Economy	61500.00
0005433755483	26171	Economy	61500.00
0005433755403	26171	Economy	61500.00
0005433755443	26171	Economy	61500.00
0005433755747	26171	Economy	61500.00
0005435983281	26171	Economy	61500.00
0005433755604	26171	Economy	61500.00
0005432655818	26171	Economy	61500.00
0005433766755	26171	Economy	61500.00
0005433435503	26171	Economy	61500.00
0005432655817	26171	Economy	61500.00
0005432655787	26171	Economy	61500.00
0005433755336	26171	Economy	61500.00
0005433755427	26171	Economy	61500.00
0005433755442	26171	Economy	61500.00
0005432655794	26171	Economy	61500.00
0005432869723	26171	Economy	61500.00
0005433755124	26171	Economy	61500.00
0005433766754	26171	Economy	61500.00
0005435983065	26171	Economy	61500.00
0005433755284	26171	Economy	61500.00
0005435983210	26171	Economy	61500.00
0005433755476	26171	Economy	61500.00
0005433755603	26171	Economy	61500.00
0005435983477	26171	Economy	61500.00
0005432655795	26171	Economy	61500.00
0005433755489	26171	Economy	61500.00
0005435983353	26171	Economy	61500.00
0005433755632	26171	Economy	61500.00
0005432986002	26171	Economy	61500.00
0005433755325	26171	Economy	61500.00
0005433755288	26171	Economy	61500.00
0005435983366	26171	Economy	61500.00
0005433755555	26171	Economy	61500.00
0005432986003	26171	Economy	61500.00
0005435983357	26171	Economy	61500.00
0005435983211	26171	Economy	61500.00
0005433764729	26171	Economy	61500.00
0005433755673	26171	Economy	61500.00
0005433755562	26171	Economy	61500.00
0005435983286	26171	Economy	61500.00
0005432869721	26171	Economy	61500.00
0005433755429	26171	Economy	61500.00
0005433755585	26171	Economy	61500.00
0005433755396	26171	Economy	61500.00
0005435983082	26171	Economy	61500.00
0005433755653	26171	Economy	61500.00
0005433755527	26171	Economy	61500.00
0005433764724	26171	Economy	61500.00
0005435983484	26171	Economy	67700.00
0005433755423	26171	Economy	61500.00
0005433755411	26171	Economy	61500.00
0005433766756	26171	Economy	67700.00
0005432655741	26171	Economy	67700.00
0005432985999	26171	Economy	61500.00
0005433755345	26171	Economy	61500.00
0005433755470	26171	Economy	61500.00
0005435983302	26171	Economy	61500.00
0005433755713	26171	Economy	61500.00
0005433755641	26171	Economy	61500.00
0005435983120	26171	Economy	61500.00
0005435983264	26171	Economy	61500.00
0005433435501	26171	Economy	61500.00
0005435983310	26171	Economy	61500.00
0005435983299	26171	Economy	61500.00
0005432655819	26171	Economy	61500.00
0005433755452	26171	Economy	61500.00
0005435983334	26171	Economy	61500.00
0005432869722	26171	Economy	61500.00
0005433755583	26171	Economy	61500.00
0005433755516	26171	Economy	61500.00
0005435983226	26171	Economy	61500.00
0005435983164	26171	Economy	61500.00
0005432051219	26171	Economy	61500.00
0005433764727	26171	Economy	61500.00
0005433755597	26171	Economy	61500.00
0005433435502	26171	Economy	61500.00
0005433755631	26171	Economy	61500.00
0005435983268	26171	Economy	61500.00
0005435983519	26171	Economy	61500.00
0005435983354	26171	Economy	61500.00
0005435983461	26171	Economy	61500.00
0005433755391	26171	Economy	61500.00
0005432986000	26171	Economy	61500.00
0005433755287	26171	Economy	61500.00
0005433755602	26171	Economy	61500.00
0005433755710	26171	Economy	61500.00
0005435983303	26171	Economy	61500.00
0005435983285	26171	Economy	61500.00
0005432986001	26171	Economy	61500.00
0005435983319	26171	Economy	61500.00
0005433755791	26171	Economy	61500.00
0005435983335	26171	Economy	61500.00
0005435983478	26171	Economy	61500.00
0005433435504	26171	Economy	61500.00
0005433755567	26171	Economy	61500.00
0005433755428	26171	Economy	61500.00
0005433755515	26171	Economy	61500.00
0005433152185	1522	Business	38900.00
0005434376057	1522	Business	38900.00
0005433931533	1522	Business	38900.00
0005434029712	1522	Business	38900.00
0005434376238	1522	Business	38900.00
0005434376045	1522	Business	38900.00
0005433152157	1522	Business	38900.00
0005433152242	1522	Business	38900.00
0005434376059	1522	Business	38900.00
0005434029714	1522	Business	38900.00
0005433152276	1522	Economy	13000.00
0005433461655	1522	Economy	13000.00
0005434376049	1522	Economy	13000.00
0005434376048	1522	Economy	13000.00
0005434376046	1522	Economy	13000.00
0005433152115	1522	Economy	13000.00
0005433151985	1522	Economy	13000.00
0005433152094	1522	Economy	13000.00
0005434376050	1522	Economy	13000.00
0005433931520	1522	Economy	13000.00
0005433152228	1522	Economy	13000.00
0005433152275	1522	Economy	13000.00
0005433152326	1522	Economy	13000.00
0005433152243	1522	Economy	13000.00
0005434376060	1522	Economy	13000.00
0005434029713	1522	Economy	13000.00
0005433152205	1522	Economy	13000.00
0005433152351	1522	Economy	13000.00
0005433152119	1522	Economy	13000.00
0005433152344	1522	Economy	13000.00
0005433152084	1522	Economy	13000.00
0005433931524	1522	Economy	13000.00
0005434376062	1522	Economy	14300.00
0005433152241	1522	Economy	14300.00
0005433152077	1522	Economy	14300.00
0005434376054	1522	Economy	14300.00
0005433152092	1522	Economy	13000.00
0005433152252	1522	Economy	13000.00
0005434376051	1522	Economy	13000.00
0005433152262	1522	Economy	13000.00
0005433152277	1522	Economy	13000.00
0005434376239	1522	Economy	13000.00
0005433152165	1522	Economy	13000.00
0005434376168	1522	Economy	13000.00
0005434376053	1522	Economy	13000.00
0005434376056	1522	Economy	13000.00
0005433152120	1522	Economy	13000.00
0005433152076	1522	Economy	13000.00
0005433152253	1522	Economy	13000.00
0005434376055	1522	Economy	13000.00
0005433152183	1522	Economy	13000.00
0005432268089	1522	Economy	13000.00
0005433152349	1522	Economy	13000.00
0005433152121	1522	Economy	13000.00
0005433152202	1522	Economy	13000.00
0005434376058	1522	Economy	13000.00
0005433152230	1522	Economy	13000.00
0005434376047	1522	Economy	13000.00
0005434376063	1522	Economy	13000.00
0005434376061	1522	Economy	13000.00
0005434376052	1522	Economy	13000.00
0005433152116	1522	Economy	13000.00
0005433152206	1522	Economy	13000.00
0005433152240	1522	Economy	13000.00
0005433931532	1522	Economy	13000.00
0005434376190	1522	Economy	13000.00
0005433152261	1522	Economy	13000.00
0005434376237	1522	Economy	13000.00
0005433152166	1522	Economy	13000.00
0005433152343	1522	Economy	13000.00
0005434375824	20114	Business	38900.00
0005434375761	20114	Business	38900.00
0005434375630	20114	Business	38900.00
0005434375807	20114	Business	38900.00
0005434375519	20114	Business	38900.00
0005433152411	20114	Economy	13000.00
0005434375822	20114	Economy	13000.00
0005434375728	20114	Economy	13000.00
0005434375827	20114	Economy	13000.00
0005434375739	20114	Economy	13000.00
0005434375655	20114	Economy	13000.00
0005434375758	20114	Economy	13000.00
0005434375592	20114	Economy	13000.00
0005434375583	20114	Economy	13000.00
0005434375573	20114	Economy	13000.00
0005434375623	20114	Economy	13000.00
0005434375832	20114	Economy	13000.00
0005434375635	20114	Economy	13000.00
0005434375727	20114	Economy	13000.00
0005434376161	20114	Economy	13000.00
0005434375863	20114	Economy	13000.00
0005434375726	20114	Economy	13000.00
0005433152413	20114	Economy	13000.00
0005434375828	20114	Economy	13000.00
0005433152410	20114	Economy	13000.00
0005434375684	20114	Economy	13000.00
0005433152407	20114	Economy	13000.00
0005434375717	20114	Economy	13000.00
0005434375584	20114	Economy	14300.00
0005434375810	20114	Economy	14300.00
0005434375743	20114	Economy	14300.00
0005433152408	20114	Economy	13000.00
0005433152412	20114	Economy	13000.00
0005434375712	20114	Economy	13000.00
0005434375841	20114	Economy	13000.00
0005434375456	20114	Economy	13000.00
0005434375675	20114	Economy	13000.00
0005434375705	20114	Economy	13000.00
0005434375518	20114	Economy	13000.00
0005434375740	20114	Economy	13000.00
0005434375765	20114	Economy	13000.00
0005434375866	20114	Economy	13000.00
0005433152409	20114	Economy	13000.00
0005434375668	20114	Economy	13000.00
0005434375704	20114	Economy	13000.00
0005434375823	20114	Economy	13000.00
0005434375713	20114	Economy	13000.00
0005434375616	20114	Economy	13000.00
0005434375574	20114	Economy	13000.00
0005434375457	20114	Economy	13000.00
0005434375902	20114	Economy	13000.00
0005434375579	20114	Economy	13000.00
0005434375762	20114	Economy	13000.00
0005434375760	20114	Economy	13000.00
0005434375865	20114	Economy	13000.00
0005434375683	20114	Economy	13000.00
0005434375593	20114	Economy	13000.00
0005434375816	20114	Economy	13000.00
0005434375864	20114	Economy	13000.00
0005434375794	20114	Economy	13000.00
0005434375935	20114	Economy	13000.00
0005432426042	511	Business	27500.00
0005432426027	511	Business	27500.00
0005432426033	511	Business	27500.00
0005432426009	511	Business	27500.00
0005432426034	511	Business	27500.00
0005432426024	511	Business	27500.00
0005432283067	511	Business	27500.00
0005433261876	511	Business	27500.00
0005432426026	511	Business	27500.00
0005432426015	511	Business	27500.00
0005432426029	511	Business	27500.00
0005432426032	511	Business	27500.00
0005432426010	511	Business	27500.00
0005433158196	511	Business	27500.00
0005433261870	511	Economy	10100.00
0005432426014	511	Economy	10100.00
0005433261877	511	Economy	10100.00
0005433261875	511	Economy	9200.00
0005432425999	511	Economy	9200.00
0005432426035	511	Economy	9200.00
0005432426020	511	Economy	9200.00
0005432426016	511	Economy	9200.00
0005432426019	511	Economy	9200.00
0005432426002	511	Economy	9200.00
0005432426001	511	Economy	9200.00
0005433261872	511	Economy	9200.00
0005433261878	511	Economy	9200.00
0005432426028	511	Economy	9200.00
0005432426012	511	Economy	9200.00
0005432426030	511	Economy	9200.00
0005433261869	511	Economy	9200.00
0005432426023	511	Economy	9200.00
0005432426011	511	Economy	9200.00
0005432426037	511	Economy	9200.00
0005432426003	511	Economy	9200.00
0005432426038	511	Economy	9200.00
0005432426021	511	Economy	9200.00
0005433261871	511	Economy	9200.00
0005432283066	511	Economy	9200.00
0005432426000	511	Economy	9200.00
0005433158198	511	Economy	9200.00
0005432426017	511	Economy	9200.00
0005432426041	511	Economy	9200.00
0005432426008	511	Economy	9200.00
0005432426005	511	Economy	9200.00
0005432426036	511	Economy	9200.00
0005433158197	511	Economy	9200.00
0005432426022	511	Economy	9200.00
0005433261873	511	Economy	9200.00
0005432426018	511	Economy	9200.00
0005432426025	511	Economy	9200.00
0005432426006	511	Economy	9200.00
0005432426013	511	Economy	9200.00
0005432426031	511	Economy	9200.00
0005432426039	511	Economy	9200.00
0005432426040	511	Economy	9200.00
0005432426004	511	Economy	9200.00
0005432426007	511	Economy	9200.00
0005433262046	12879	Business	27500.00
0005433262051	12879	Business	27500.00
0005433262047	12879	Business	27500.00
0005433262052	12879	Economy	9200.00
0005432302442	12879	Economy	9200.00
0005433262045	12879	Economy	9200.00
0005433262049	12879	Economy	9200.00
0005433262054	12879	Economy	9200.00
0005433262053	12879	Economy	10100.00
0005433262048	12879	Economy	9200.00
0005433262044	12879	Economy	9200.00
0005433262050	12879	Economy	9200.00
0005432425576	12893	Business	27500.00
0005432425460	12893	Business	27500.00
0005432425484	12893	Business	27500.00
0005432425566	12893	Business	27500.00
0005432425526	12893	Business	27500.00
0005432425509	12893	Business	27500.00
0005432425499	12893	Economy	10100.00
0005432425544	12893	Economy	10100.00
0005432425543	12893	Economy	9200.00
0005432425518	12893	Economy	9200.00
0005432425498	12893	Economy	9200.00
0005432425558	12893	Economy	9200.00
0005432425567	12893	Economy	9200.00
0005432425535	12893	Economy	9200.00
0005432425428	12893	Economy	9200.00
0005432425565	12893	Economy	9200.00
0005432425433	12893	Economy	9200.00
0005432425411	12893	Economy	9200.00
0005432425520	12893	Economy	9200.00
0005432425412	12893	Economy	9200.00
0005432425542	12893	Economy	9200.00
0005432425532	12893	Economy	9200.00
0005432425175	12893	Economy	9200.00
0005432425458	12893	Economy	9200.00
0005432425177	12893	Economy	9200.00
0005432425516	12893	Economy	9200.00
0005432425459	12893	Economy	9200.00
0005432425494	12893	Economy	9200.00
0005432425446	12893	Economy	9200.00
0005432425495	12893	Economy	9200.00
0005432425548	12893	Economy	9200.00
0005432425515	12893	Economy	9200.00
0005432425577	12893	Economy	9200.00
0005432425496	12893	Economy	10100.00
0005432425549	12893	Economy	10100.00
0005432425461	12893	Economy	9200.00
0005432425392	12893	Economy	9200.00
0005432425552	12893	Economy	9200.00
0005432425441	12893	Economy	9200.00
0005432425524	12893	Economy	9200.00
0005432425545	12893	Economy	9200.00
0005432425368	12893	Economy	9200.00
0005432425176	12893	Economy	9200.00
0005432425537	12893	Economy	9200.00
0005432425568	12893	Economy	9200.00
0005432425525	12893	Economy	9200.00
0005432425497	12893	Economy	9200.00
0005432425541	12893	Economy	9200.00
0005432425407	12893	Economy	9200.00
0005432425529	12893	Economy	9200.00
0005432425517	12893	Economy	9200.00
0005432425404	12893	Economy	9200.00
0005432425429	12893	Economy	9200.00
0005432425514	12893	Economy	9200.00
0005432425447	12893	Economy	9200.00
0005432425531	12893	Economy	9200.00
0005432425538	12893	Economy	9200.00
0005433058727	439	Business	24500.00
0005433058862	439	Business	24500.00
0005434029729	439	Business	24500.00
0005433929696	439	Business	24500.00
0005433058881	439	Business	24500.00
0005434735801	439	Business	24500.00
0005433058728	439	Business	24500.00
0005433059010	439	Business	24500.00
0005433058815	439	Business	24500.00
0005433058762	439	Business	24500.00
0005433058908	439	Business	24500.00
0005433059008	439	Economy	9000.00
0005433684473	439	Economy	8200.00
0005434032157	439	Economy	8200.00
0005433058693	439	Economy	8200.00
0005433058691	439	Economy	8200.00
0005433929710	439	Economy	8200.00
0005434025675	439	Economy	8200.00
0005434025679	439	Economy	8200.00
0005434032155	439	Economy	8200.00
0005433058951	439	Economy	8200.00
0005432045670	439	Economy	8200.00
0005434025682	439	Economy	8200.00
0005434735794	439	Economy	8200.00
0005433058812	439	Economy	8200.00
0005433058943	439	Economy	8200.00
0005434025683	439	Economy	8200.00
0005433058915	439	Economy	8200.00
0005433058855	439	Economy	8200.00
0005433684462	439	Economy	8200.00
0005433058745	439	Economy	8200.00
0005434735781	439	Economy	8200.00
0005433058726	439	Economy	8200.00
0005433058914	439	Economy	8200.00
0005433058873	439	Economy	8200.00
0005433929709	439	Economy	8200.00
0005433058909	439	Economy	8200.00
0005434025681	439	Economy	8200.00
0005433058811	439	Economy	8200.00
0005433058859	439	Economy	8200.00
0005434025674	439	Economy	8200.00
0005433929713	439	Economy	8200.00
0005433058955	439	Economy	8200.00
0005433058865	439	Economy	8200.00
0005434735780	439	Economy	8200.00
0005434032158	439	Economy	8200.00
0005433058882	439	Economy	8200.00
0005433929695	439	Economy	8200.00
0005434025678	439	Economy	8200.00
0005433058858	439	Economy	9000.00
0005433058825	439	Economy	8200.00
0005433058790	439	Economy	8200.00
0005433058692	439	Economy	8200.00
0005433058719	439	Economy	8200.00
0005433929690	439	Economy	8200.00
0005433058917	439	Economy	8200.00
0005433058826	439	Economy	8200.00
0005433058856	439	Economy	8200.00
0005433929708	439	Economy	8200.00
0005434025677	439	Economy	8200.00
0005434025680	439	Economy	8200.00
0005433058734	439	Economy	8200.00
0005433058918	439	Economy	8200.00
0005433058902	439	Economy	8200.00
0005433058619	439	Economy	8200.00
0005434025676	439	Economy	8200.00
0005433058797	439	Economy	8200.00
0005432235860	439	Economy	8200.00
0005433058959	439	Economy	8200.00
0005433929689	439	Economy	8200.00
0005433058784	439	Economy	8200.00
0005432235861	439	Economy	8200.00
0005434029730	439	Economy	8200.00
0005433058796	439	Economy	8200.00
0005433059009	439	Economy	8200.00
0005434032156	439	Economy	8200.00
0005433058869	439	Economy	8200.00
0005434025072	12694	Business	24500.00
0005434376238	12694	Business	24500.00
0005434025336	12694	Business	24500.00
0005434025105	12694	Business	24500.00
0005434025332	12694	Business	24500.00
0005433059061	12694	Business	24500.00
0005434025176	12694	Business	24500.00
0005434029712	12694	Business	24500.00
0005434025024	12694	Business	24500.00
0005432157549	12694	Business	24500.00
0005434025109	12694	Business	24500.00
0005434025081	12694	Business	24500.00
0005433929732	12694	Business	24500.00
0005434025408	12694	Business	24500.00
0005434025319	12694	Business	24500.00
0005434025480	12694	Business	24500.00
0005434025228	12694	Economy	9000.00
0005434025100	12694	Economy	8200.00
0005434025063	12694	Economy	8200.00
0005434025034	12694	Economy	8200.00
0005434025138	12694	Economy	8200.00
0005434025403	12694	Economy	8200.00
0005434376239	12694	Economy	8200.00
0005434025188	12694	Economy	8200.00
0005434025465	12694	Economy	8200.00
0005434025195	12694	Economy	8200.00
0005434025495	12694	Economy	8200.00
0005434025389	12694	Economy	8200.00
0005433059064	12694	Economy	8200.00
0005434025080	12694	Economy	8200.00
0005434025557	12694	Economy	8200.00
0005434025390	12694	Economy	8200.00
0005434025382	12694	Economy	8200.00
0005434025217	12694	Economy	8200.00
0005434025424	12694	Economy	8200.00
0005434025218	12694	Economy	8200.00
0005434025423	12694	Economy	8200.00
0005434024978	12694	Economy	8200.00
0005434025062	12694	Economy	8200.00
0005434025101	12694	Economy	8200.00
0005434025123	12694	Economy	8200.00
0005434025430	12694	Economy	8200.00
0005434025140	12694	Economy	8200.00
0005434025177	12694	Economy	8200.00
0005434028359	12694	Economy	8200.00
0005434025164	12694	Economy	8200.00
0005433059063	12694	Economy	8200.00
0005434025215	12694	Economy	8200.00
0005434028372	12694	Economy	8200.00
0005434025486	12694	Economy	8200.00
0005434025363	12694	Economy	8200.00
0005434025075	12694	Economy	8200.00
0005434376237	12694	Economy	8200.00
0005434025320	12694	Economy	8200.00
0005434025344	12694	Economy	8200.00
0005434025397	12694	Economy	8200.00
0005434029713	12694	Economy	8200.00
0005434025162	12694	Economy	8200.00
0005434025208	12694	Economy	8200.00
0005434025252	12694	Economy	8200.00
0005434025556	12694	Economy	9000.00
0005434029714	12694	Economy	9000.00
0005434025404	12694	Economy	8200.00
0005434025331	12694	Economy	8200.00
0005434025287	12694	Economy	8200.00
0005434025364	12694	Economy	8200.00
0005434025286	12694	Economy	8200.00
0005434025296	12694	Economy	8200.00
0005434025008	12694	Economy	8200.00
0005433929730	12694	Economy	8200.00
0005434025175	12694	Economy	8200.00
0005434028378	12694	Economy	8200.00
0005434025216	12694	Economy	8200.00
0005434025360	12694	Economy	8200.00
0005434025167	12694	Economy	8200.00
0005434025076	12694	Economy	8200.00
0005434025375	12694	Economy	8200.00
0005434025345	12694	Economy	8200.00
0005434025092	12694	Economy	8200.00
0005434025318	12694	Economy	8200.00
0005434025530	12694	Economy	8200.00
0005434028375	12694	Economy	8200.00
0005434025257	12694	Economy	8200.00
0005434025337	12694	Economy	8200.00
0005434025481	12694	Economy	8200.00
0005434025381	12694	Economy	8200.00
0005433059060	12694	Economy	8200.00
0005434025110	12694	Economy	8200.00
0005434025139	12694	Economy	8200.00
0005434025219	12694	Economy	8200.00
0005434025361	12694	Economy	8200.00
0005434032139	12694	Economy	8200.00
0005434025194	12694	Economy	8200.00
0005434025338	12694	Economy	8200.00
0005434025009	12694	Economy	8200.00
0005434024946	12694	Economy	8200.00
0005433929731	12694	Economy	8200.00
0005433059059	12694	Economy	8200.00
0005433059062	12694	Economy	8200.00
0005434025409	12694	Economy	8200.00
0005434028376	12694	Economy	8200.00
0005434028372	2132	Business	34700.00
0005433037540	2132	Business	34700.00
0005433037426	2132	Business	34700.00
0005433037662	2132	Business	34700.00
0005432231877	2132	Business	34700.00
0005433037492	2132	Business	34700.00
0005433926093	2132	Business	34700.00
0005433037330	2132	Business	34700.00
0005433037602	2132	Business	34700.00
0005433037749	2132	Business	34700.00
0005434028378	2132	Business	34700.00
0005433037671	2132	Economy	12700.00
0005433037512	2132	Economy	12700.00
0005433037587	2132	Economy	11600.00
0005433037337	2132	Economy	11600.00
0005433037425	2132	Economy	11600.00
0005434028375	2132	Economy	11600.00
0005433929730	2132	Economy	11600.00
0005433926091	2132	Economy	11600.00
0005432231878	2132	Economy	11600.00
0005433926100	2132	Economy	11600.00
0005433037338	2132	Economy	11600.00
0005433037595	2132	Economy	11600.00
0005433037556	2132	Economy	11600.00
0005433926092	2132	Economy	11600.00
0005433929888	2132	Economy	11600.00
0005433926102	2132	Economy	11600.00
0005433926089	2132	Economy	11600.00
0005433929891	2132	Economy	11600.00
0005433037698	2132	Economy	11600.00
0005433037494	2132	Economy	11600.00
0005433037539	2132	Economy	11600.00
0005433037566	2132	Economy	11600.00
0005433037659	2132	Economy	11600.00
0005433037613	2132	Economy	11600.00
0005433037580	2132	Economy	11600.00
0005432231881	2132	Economy	11600.00
0005434028359	2132	Economy	11600.00
0005433037582	2132	Economy	11600.00
0005433037396	2132	Economy	11600.00
0005433037703	2132	Economy	11600.00
0005433926094	2132	Economy	11600.00
0005433037513	2132	Economy	11600.00
0005433926097	2132	Economy	11600.00
0005433929731	2132	Economy	11600.00
0005433929887	2132	Economy	11600.00
0005433926090	2132	Economy	11600.00
0005433037545	2132	Economy	11600.00
0005433037541	2132	Economy	11600.00
0005434028376	2132	Economy	11600.00
0005432231876	2132	Economy	12700.00
0005433037530	2132	Economy	12700.00
0005433926104	2132	Economy	12700.00
0005433037660	2132	Economy	11600.00
0005433929732	2132	Economy	11600.00
0005433037417	2132	Economy	11600.00
0005433926095	2132	Economy	11600.00
0005433926088	2132	Economy	11600.00
0005433037748	2132	Economy	11600.00
0005433037543	2132	Economy	11600.00
0005433037555	2132	Economy	11600.00
0005432231880	2132	Economy	11600.00
0005433037661	2132	Economy	11600.00
0005433929889	2132	Economy	11600.00
0005433926098	2132	Economy	11600.00
0005433926101	2132	Economy	11600.00
0005433037406	2132	Economy	11600.00
0005433037478	2132	Economy	11600.00
0005433929890	2132	Economy	11600.00
0005433037672	2132	Economy	11600.00
0005432044609	2132	Economy	11600.00
0005433926096	2132	Economy	11600.00
0005433929892	2132	Economy	11600.00
0005432044608	2132	Economy	11600.00
0005432231879	2132	Economy	11600.00
0005433037579	2132	Economy	11600.00
0005433037395	2132	Economy	11600.00
0005433037479	2132	Economy	11600.00
0005433926103	2132	Economy	11600.00
0005433929893	2132	Economy	11600.00
0005433037699	2132	Economy	11600.00
0005433037418	2132	Economy	11600.00
0005433926099	2132	Economy	11600.00
0005433037632	2132	Economy	11600.00
0005433037544	2132	Economy	11600.00
0005433925643	24107	Business	34700.00
0005433925763	24107	Business	34700.00
0005433925673	24107	Business	34700.00
0005433925337	24107	Business	34700.00
0005433875422	24107	Business	34700.00
0005433925580	24107	Business	34700.00
0005433925520	24107	Business	34700.00
0005433925852	24107	Business	34700.00
0005433925515	24107	Business	34700.00
0005433925651	24107	Business	34700.00
0005433931530	24107	Business	34700.00
0005433925603	24107	Business	34700.00
0005433925258	24107	Business	34700.00
0005433925242	24107	Business	34700.00
0005433925269	24107	Economy	12700.00
0005433925143	24107	Economy	12700.00
0005433925390	24107	Economy	12700.00
0005433925498	24107	Economy	11600.00
0005433925227	24107	Economy	11600.00
0005433925796	24107	Economy	11600.00
0005433925403	24107	Economy	11600.00
0005433925813	24107	Economy	11600.00
0005433925327	24107	Economy	11600.00
0005433037844	24107	Economy	11600.00
0005433925343	24107	Economy	11600.00
0005433925108	24107	Economy	11600.00
0005433925602	24107	Economy	11600.00
0005433925598	24107	Economy	11600.00
0005433925482	24107	Economy	11600.00
0005433925762	24107	Economy	11600.00
0005433925478	24107	Economy	11600.00
0005433925344	24107	Economy	11600.00
0005433925736	24107	Economy	11600.00
0005433925563	24107	Economy	11600.00
0005433925470	24107	Economy	11600.00
0005433925636	24107	Economy	11600.00
0005433925674	24107	Economy	11600.00
0005433925779	24107	Economy	11600.00
0005433926055	24107	Economy	11600.00
0005433925795	24107	Economy	11600.00
0005433925826	24107	Economy	11600.00
0005433925264	24107	Economy	11600.00
0005433925729	24107	Economy	11600.00
0005433925530	24107	Economy	11600.00
0005433925241	24107	Economy	11600.00
0005433925600	24107	Economy	11600.00
0005433925511	24107	Economy	11600.00
0005433925693	24107	Economy	11600.00
0005433925486	24107	Economy	11600.00
0005433925948	24107	Economy	11600.00
0005433925426	24107	Economy	11600.00
0005434175879	24107	Economy	11600.00
0005433925283	24107	Economy	11600.00
0005433925289	24107	Economy	11600.00
0005433925477	24107	Economy	11600.00
0005433925536	24107	Economy	11600.00
0005433925585	24107	Economy	11600.00
0005433925382	24107	Economy	11600.00
0005433925558	24107	Economy	11600.00
0005433925584	24107	Economy	11600.00
0005433925787	24107	Economy	11600.00
0005433925723	24107	Economy	11600.00
0005433929702	24107	Economy	11600.00
0005433925599	24107	Economy	11600.00
0005433037843	24107	Economy	11600.00
0005432207741	24107	Economy	11600.00
0005433925461	24107	Economy	11600.00
0005432207740	24107	Economy	11600.00
0005433925331	24107	Economy	11600.00
0005433925927	24107	Economy	11600.00
0005433925232	24107	Economy	11600.00
0005433925385	24107	Economy	11600.00
0005433925155	24107	Economy	11600.00
0005433925389	24107	Economy	11600.00
0005433925248	24107	Economy	11600.00
0005433925664	24107	Economy	11600.00
0005433037845	24107	Economy	11600.00
0005432207739	24107	Economy	11600.00
0005433925595	24107	Economy	11600.00
0005433925377	24107	Economy	11600.00
0005433925144	24107	Economy	11600.00
0005433925165	24107	Economy	11600.00
0005433925375	24107	Economy	11600.00
0005434088056	24107	Economy	12700.00
0005433925861	24107	Economy	12700.00
0005433925086	24107	Economy	11600.00
0005433931525	24107	Economy	11600.00
0005433925812	24107	Economy	11600.00
0005433925903	24107	Economy	11600.00
0005433925904	24107	Economy	11600.00
0005433925793	24107	Economy	11600.00
0005433925481	24107	Economy	11600.00
0005433925794	24107	Economy	11600.00
0005434175878	24107	Economy	11600.00
0005433925800	24107	Economy	11600.00
0005433925535	24107	Economy	11600.00
0005433929716	24107	Economy	11600.00
0005433925604	24107	Economy	11600.00
0005433925457	24107	Economy	11600.00
0005433925156	24107	Economy	11600.00
0005433925510	24107	Economy	11600.00
0005433925644	24107	Economy	11600.00
0005434175880	24107	Economy	11600.00
0005433925676	24107	Economy	11600.00
0005433929717	24107	Economy	11600.00
0005433925373	24107	Economy	11600.00
0005433925764	24107	Economy	11600.00
0005433925521	24107	Economy	11600.00
0005433925891	24107	Economy	11600.00
0005433925707	24107	Economy	11600.00
0005433924937	24107	Economy	11600.00
0005433925597	24107	Economy	11600.00
0005433925722	24107	Economy	11600.00
0005433931552	24107	Economy	11600.00
0005434088057	24107	Economy	11600.00
0005433925596	24107	Economy	11600.00
0005433929703	24107	Economy	11600.00
0005433925859	24107	Economy	11600.00
0005433925846	24107	Economy	11600.00
0005433925828	24107	Economy	11600.00
0005433925503	24107	Economy	11600.00
0005433925851	24107	Economy	11600.00
0005433925922	24107	Economy	11600.00
0005433925318	24107	Economy	11600.00
0005433037842	24107	Economy	11600.00
0005433925860	24107	Economy	11600.00
0005433925531	24107	Economy	11600.00
0005433924936	24107	Economy	11600.00
0005433925601	24107	Economy	11600.00
0005433925462	24107	Economy	11600.00
0005433925519	24107	Economy	11600.00
0005433875414	24107	Economy	11600.00
0005433925532	24107	Economy	11600.00
0005434088058	24107	Economy	11600.00
0005433925316	24107	Economy	11600.00
0005433931526	24107	Economy	11600.00
0005433290003	263	Business	83700.00
0005433290028	263	Business	83700.00
0005434552850	263	Business	83700.00
0005433235810	263	Business	83700.00
0005433290034	263	Business	83700.00
0005433235882	263	Business	83700.00
0005433235792	263	Business	83700.00
0005434552852	263	Business	83700.00
0005433235533	263	Business	83700.00
0005433235635	263	Comfort	47400.00
0005434731292	263	Comfort	47400.00
0005433235804	263	Comfort	47400.00
0005433126941	263	Comfort	47400.00
0005433235413	263	Comfort	47400.00
0005434729004	263	Comfort	47400.00
0005433131810	263	Comfort	47400.00
0005433235688	263	Comfort	47400.00
0005434552849	263	Comfort	47400.00
0005433235709	263	Comfort	47400.00
0005433235644	263	Comfort	47400.00
0005433235460	263	Comfort	47400.00
0005434302910	263	Comfort	47400.00
0005433235715	263	Comfort	47400.00
0005433290001	263	Comfort	47400.00
0005433131800	263	Comfort	47400.00
0005434552844	263	Economy	27900.00
0005433235847	263	Economy	27900.00
0005433235631	263	Economy	27900.00
0005434731291	263	Economy	27900.00
0005433290030	263	Economy	27900.00
0005433235441	263	Economy	27900.00
0005435142966	263	Economy	27900.00
0005433235414	263	Economy	27900.00
0005433235752	263	Economy	27900.00
0005434729007	263	Economy	27900.00
0005433235843	263	Economy	27900.00
0005433113587	263	Economy	27900.00
0005433181664	263	Economy	27900.00
0005433131809	263	Economy	27900.00
0005433290029	263	Economy	27900.00
0005433235840	263	Economy	27900.00
0005434729006	263	Economy	27900.00
0005433290025	263	Economy	27900.00
0005433235639	263	Economy	27900.00
0005433131801	263	Economy	27900.00
0005433235705	263	Economy	27900.00
0005433181599	263	Economy	27900.00
0005434552855	263	Economy	27900.00
0005433290012	263	Economy	27900.00
0005433235655	263	Economy	27900.00
0005433181684	263	Economy	27900.00
0005433126946	263	Economy	27900.00
0005433113584	263	Economy	30700.00
0005434735843	263	Economy	30700.00
0005434552856	263	Economy	27900.00
0005433235680	263	Economy	30700.00
0005433235852	263	Economy	27900.00
0005434735842	263	Economy	27900.00
0005434729021	263	Economy	27900.00
0005434729010	263	Economy	27900.00
0005433235754	263	Economy	27900.00
0005433111561	263	Economy	27900.00
0005433290013	263	Economy	27900.00
0005433235674	263	Economy	27900.00
0005433235534	263	Economy	27900.00
0005433235771	263	Economy	27900.00
0005433181682	263	Economy	27900.00
0005433235461	263	Economy	27900.00
0005433235347	263	Economy	27900.00
0005433181662	263	Economy	27900.00
0005433181598	263	Economy	27900.00
0005434729019	263	Economy	27900.00
0005433235692	263	Economy	27900.00
0005433235638	263	Economy	27900.00
0005434735844	263	Economy	27900.00
0005433111560	263	Economy	27900.00
0005434729005	263	Economy	27900.00
0005434729001	263	Economy	27900.00
0005433235755	263	Economy	27900.00
0005434552843	263	Economy	27900.00
0005434729020	263	Economy	27900.00
0005434729009	263	Economy	27900.00
0005434729000	263	Economy	27900.00
0005434728999	263	Economy	27900.00
0005434729016	263	Economy	27900.00
0005433181770	263	Economy	27900.00
0005433235731	263	Economy	27900.00
0005433181663	263	Economy	27900.00
0005434729017	263	Economy	27900.00
0005435142967	263	Economy	27900.00
0005433181606	263	Economy	27900.00
0005434552846	263	Economy	27900.00
0005434552854	263	Economy	27900.00
0005434729014	263	Economy	27900.00
0005434729013	263	Economy	27900.00
0005433235592	263	Economy	27900.00
0005434032129	263	Economy	27900.00
0005434729011	263	Economy	30700.00
0005433181681	263	Economy	30700.00
0005433235841	263	Economy	30700.00
0005433235753	263	Economy	27900.00
0005433235490	263	Economy	27900.00
0005433235869	263	Economy	27900.00
0005433131811	263	Economy	27900.00
0005433235637	263	Economy	27900.00
0005434552845	263	Economy	27900.00
0005433181623	263	Economy	27900.00
0005433181731	263	Economy	27900.00
0005433181699	263	Economy	27900.00
0005433235599	263	Economy	27900.00
0005434729018	263	Economy	27900.00
0005434302581	263	Economy	27900.00
0005433235555	263	Economy	27900.00
0005433181749	263	Economy	27900.00
0005433235693	263	Economy	27900.00
0005433235636	263	Economy	27900.00
0005433131812	263	Economy	27900.00
0005434552847	263	Economy	27900.00
0005433181757	263	Economy	27900.00
0005434729002	263	Economy	27900.00
0005433235673	263	Economy	27900.00
0005433181698	263	Economy	27900.00
0005433235748	263	Economy	27900.00
0005434552848	263	Economy	27900.00
0005433235689	263	Economy	27900.00
0005434735841	263	Economy	27900.00
0005433113585	263	Economy	27900.00
0005434729015	263	Economy	27900.00
0005434729008	263	Economy	27900.00
0005433181769	263	Economy	27900.00
0005433126953	263	Economy	27900.00
0005433181595	263	Economy	27900.00
0005433235475	263	Economy	27900.00
0005433235883	263	Economy	27900.00
0005433181622	263	Economy	27900.00
0005433235625	263	Economy	27900.00
0005433235440	263	Economy	27900.00
0005434729012	263	Economy	27900.00
0005434552853	263	Economy	27900.00
0005433290002	263	Economy	27900.00
0005433235791	263	Economy	27900.00
0005433131797	263	Economy	27900.00
0005433235775	263	Economy	27900.00
0005434729003	263	Economy	27900.00
0005434552851	263	Economy	27900.00
0005435142965	263	Economy	27900.00
0005433113588	263	Economy	27900.00
0005433181740	263	Economy	27900.00
0005434727940	9850	Business	83700.00
0005434728589	9850	Business	83700.00
0005434728158	9850	Business	83700.00
0005434728465	9850	Business	83700.00
0005434032160	9850	Business	83700.00
0005433129410	9850	Business	83700.00
0005434728491	9850	Business	83700.00
0005433181835	9850	Business	83700.00
0005434728415	9850	Business	83700.00
0005434552592	9850	Business	83700.00
0005434728331	9850	Business	83700.00
0005434728812	9850	Business	83700.00
0005433126980	9850	Business	83700.00
0005433181836	9850	Business	83700.00
0005434728265	9850	Comfort	47400.00
0005434728165	9850	Comfort	47400.00
0005434552416	9850	Comfort	47400.00
0005434728679	9850	Comfort	47400.00
0005434552279	9850	Comfort	47400.00
0005434728231	9850	Comfort	47400.00
0005434552388	9850	Comfort	47400.00
0005434552480	9850	Comfort	47400.00
0005434727807	9850	Comfort	47400.00
0005434552340	9850	Comfort	47400.00
0005434727990	9850	Comfort	47400.00
0005434728540	9850	Comfort	47400.00
0005434728035	9850	Comfort	47400.00
0005434728311	9850	Comfort	47400.00
0005434727830	9850	Comfort	47400.00
0005433236039	9850	Comfort	47400.00
0005435142875	9850	Comfort	47400.00
0005434552526	9850	Comfort	47400.00
0005434728300	9850	Comfort	47400.00
0005433126981	9850	Comfort	47400.00
0005433236040	9850	Comfort	47400.00
0005434727933	9850	Comfort	47400.00
0005434727873	9850	Comfort	47400.00
0005434728091	9850	Economy	27900.00
0005434728164	9850	Economy	27900.00
0005434727803	9850	Economy	27900.00
0005434728411	9850	Economy	27900.00
0005433236041	9850	Economy	27900.00
0005434728288	9850	Economy	27900.00
0005434552193	9850	Economy	27900.00
0005434728273	9850	Economy	27900.00
0005434728344	9850	Economy	27900.00
0005434728499	9850	Economy	27900.00
0005434728520	9850	Economy	27900.00
0005434552459	9850	Economy	27900.00
0005434728396	9850	Economy	27900.00
0005434552192	9850	Economy	27900.00
0005434728772	9850	Economy	27900.00
0005433129411	9850	Economy	27900.00
0005433181837	9850	Economy	27900.00
0005434552302	9850	Economy	27900.00
0005433236037	9850	Economy	27900.00
0005435142911	9850	Economy	27900.00
0005434727978	9850	Economy	27900.00
0005434727820	9850	Economy	27900.00
0005434728207	9850	Economy	27900.00
0005434728498	9850	Economy	27900.00
0005434728410	9850	Economy	27900.00
0005434552357	9850	Economy	27900.00
0005433236047	9850	Economy	27900.00
0005434552257	9850	Economy	27900.00
0005434552228	9850	Economy	27900.00
0005434727977	9850	Economy	27900.00
0005434552262	9850	Economy	27900.00
0005434727907	9850	Economy	27900.00
0005435142838	9850	Economy	27900.00
0005434727919	9850	Economy	27900.00
0005434552687	9850	Economy	27900.00
0005433290063	9850	Economy	30700.00
0005434728464	9850	Economy	27900.00
0005434552492	9850	Economy	27900.00
0005434552280	9850	Economy	27900.00
0005434552385	9850	Economy	30700.00
0005434727644	9850	Economy	27900.00
0005434552159	9850	Economy	27900.00
0005434728487	9850	Economy	27900.00
0005434552456	9850	Economy	27900.00
0005434728192	9850	Economy	27900.00
0005434552229	9850	Economy	27900.00
0005433129412	9850	Economy	27900.00
0005434735810	9850	Economy	27900.00
0005434728197	9850	Economy	27900.00
0005434727921	9850	Economy	27900.00
0005434728424	9850	Economy	27900.00
0005434728457	9850	Economy	27900.00
0005433236051	9850	Economy	27900.00
0005434728503	9850	Economy	27900.00
0005434727995	9850	Economy	27900.00
0005434728301	9850	Economy	27900.00
0005434728289	9850	Economy	27900.00
0005434728068	9850	Economy	27900.00
0005434552591	9850	Economy	27900.00
0005434728266	9850	Economy	27900.00
0005434727982	9850	Economy	27900.00
0005434728751	9850	Economy	27900.00
0005433236035	9850	Economy	27900.00
0005434728045	9850	Economy	27900.00
0005434552171	9850	Economy	27900.00
0005434552598	9850	Economy	27900.00
0005434728708	9850	Economy	27900.00
0005434552365	9850	Economy	27900.00
0005434728151	9850	Economy	27900.00
0005434728145	9850	Economy	27900.00
0005434727981	9850	Economy	27900.00
0005434728814	9850	Economy	27900.00
0005434728531	9850	Economy	27900.00
0005434552386	9850	Economy	27900.00
0005434728354	9850	Economy	27900.00
0005434552557	9850	Economy	27900.00
0005434728375	9850	Economy	27900.00
0005434552487	9850	Economy	27900.00
0005433236043	9850	Economy	27900.00
0005434552577	9850	Economy	27900.00
0005433236045	9850	Economy	27900.00
0005434728043	9850	Economy	27900.00
0005433181833	9850	Economy	27900.00
0005434728519	9850	Economy	27900.00
0005435142913	9850	Economy	27900.00
0005434728028	9850	Economy	27900.00
0005434727845	9850	Economy	27900.00
0005435142912	9850	Economy	27900.00
0005434727918	9850	Economy	27900.00
0005434728722	9850	Economy	27900.00
0005434728532	9850	Economy	27900.00
0005434727916	9850	Economy	27900.00
0005434552507	9850	Economy	27900.00
0005434728356	9850	Economy	27900.00
0005434552474	9850	Economy	27900.00
0005433236048	9850	Economy	27900.00
0005434727846	9850	Economy	27900.00
0005434552296	9850	Economy	27900.00
0005434728489	9850	Economy	27900.00
0005434727847	9850	Economy	27900.00
0005434728090	9850	Economy	27900.00
0005434552324	9850	Economy	27900.00
0005433236049	9850	Economy	30700.00
0005434728076	9850	Economy	30700.00
0005434727670	9850	Economy	30700.00
0005434728150	9850	Economy	30700.00
0005434727963	9850	Economy	30700.00
0005434552513	9850	Economy	27900.00
0005434728083	9850	Economy	27900.00
0005434728597	9850	Economy	27900.00
0005434728116	9850	Economy	27900.00
0005434727994	9850	Economy	27900.00
0005433236036	9850	Economy	27900.00
0005434728267	9850	Economy	27900.00
0005434728378	9850	Economy	27900.00
0005435142834	9850	Economy	27900.00
0005434728402	9850	Economy	27900.00
0005434727645	9850	Economy	27900.00
0005434552389	9850	Economy	27900.00
0005434728014	9850	Economy	27900.00
0005433236044	9850	Economy	27900.00
0005434727880	9850	Economy	27900.00
0005434728010	9850	Economy	27900.00
0005434728163	9850	Economy	27900.00
0005434728397	9850	Economy	27900.00
0005434728813	9850	Economy	27900.00
0005434552599	9850	Economy	27900.00
0005434552417	9850	Economy	27900.00
0005434552428	9850	Economy	27900.00
0005434552263	9850	Economy	27900.00
0005433181832	9850	Economy	27900.00
0005434728044	9850	Economy	27900.00
0005434728504	9850	Economy	27900.00
0005434727964	9850	Economy	27900.00
0005434552301	9850	Economy	27900.00
0005434727920	9850	Economy	27900.00
0005434728696	9850	Economy	27900.00
0005434728490	9850	Economy	27900.00
0005433236042	9850	Economy	27900.00
0005434727446	9850	Economy	27900.00
0005433236034	9850	Economy	27900.00
0005434727939	9850	Economy	27900.00
0005434728423	9850	Economy	27900.00
0005433290064	9850	Economy	27900.00
0005434552512	9850	Economy	27900.00
0005434728393	9850	Economy	27900.00
0005434728239	9850	Economy	27900.00
0005434728027	9850	Economy	27900.00
0005433181834	9850	Economy	27900.00
0005433236046	9850	Economy	27900.00
0005434552613	9850	Economy	27900.00
0005434728488	9850	Economy	27900.00
0005434727936	9850	Economy	27900.00
0005434728479	9850	Economy	27900.00
0005433236038	9850	Economy	27900.00
0005434728683	9850	Economy	27900.00
0005434731260	9850	Economy	27900.00
0005434552508	9850	Economy	27900.00
0005434728367	9850	Economy	27900.00
0005434728502	9850	Economy	27900.00
0005433236050	9850	Economy	27900.00
0005434552529	9850	Economy	27900.00
0005434552366	9850	Economy	27900.00
0005433290062	9850	Economy	27900.00
0005434728382	9850	Economy	27900.00
0005434552415	9850	Economy	27900.00
0005434032159	9850	Economy	27900.00
0005434728302	9850	Economy	27900.00
0005434728579	9850	Economy	27900.00
0005434728187	9850	Economy	27900.00
0005435215306	7731	Business	42100.00
0005432537121	7731	Business	42100.00
0005432429033	7731	Business	42100.00
0005432533377	7731	Business	42100.00
0005435214852	7731	Business	42100.00
0005432070079	7731	Business	42100.00
0005432531808	7731	Business	42100.00
0005435214935	7731	Business	42100.00
0005432531805	7731	Business	42100.00
0005435215218	7731	Business	42100.00
0005433656727	7731	Business	42100.00
0005435214926	7731	Comfort	23900.00
0005435215288	7731	Comfort	23900.00
0005435215020	7731	Comfort	23900.00
0005432537122	7731	Comfort	23900.00
0005432531800	7731	Comfort	23900.00
0005434069626	7731	Comfort	23900.00
0005435725706	7731	Comfort	23900.00
0005435214904	7731	Comfort	23900.00
0005432531785	7731	Comfort	23900.00
0005432531806	7731	Comfort	23900.00
0005435214942	7731	Comfort	23900.00
0005432531781	7731	Comfort	23900.00
0005435215120	7731	Comfort	23900.00
0005435215098	7731	Comfort	23900.00
0005435215067	7731	Comfort	23900.00
0005435215280	7731	Comfort	23900.00
0005435215113	7731	Comfort	23900.00
0005435215099	7731	Comfort	23900.00
0005433656752	7731	Comfort	23900.00
0005435214905	7731	Economy	14000.00
0005435215222	7731	Economy	14000.00
0005432070077	7731	Economy	14000.00
0005434069628	7731	Economy	14000.00
0005435215227	7731	Economy	14000.00
0005435215246	7731	Economy	14000.00
0005435283438	7731	Economy	14000.00
0005432531788	7731	Economy	14000.00
0005435725702	7731	Economy	14000.00
0005432533378	7731	Economy	14000.00
0005432531787	7731	Economy	14000.00
0005435215232	7731	Economy	14000.00
0005432531802	7731	Economy	14000.00
0005435215094	7731	Economy	14000.00
0005435215064	7731	Economy	14000.00
0005432531803	7731	Economy	14000.00
0005435283515	7731	Economy	14000.00
0005435215195	7731	Economy	14000.00
0005435215046	7731	Economy	14000.00
0005435215219	7731	Economy	14000.00
0005435725704	7731	Economy	14000.00
0005435214943	7731	Economy	14000.00
0005432531801	7731	Economy	14000.00
0005432429032	7731	Economy	14000.00
0005432429030	7731	Economy	14000.00
0005435283433	7731	Economy	14000.00
0005435215028	7731	Economy	14000.00
0005435215194	7731	Economy	14000.00
0005435215112	7731	Economy	14000.00
0005433656749	7731	Economy	15400.00
0005432535979	7731	Economy	14000.00
0005435215101	7731	Economy	15400.00
0005432531793	7731	Economy	14000.00
0005432531804	7731	Economy	15400.00
0005435215088	7731	Economy	15400.00
0005435215062	7731	Economy	14000.00
0005435725716	7731	Economy	14000.00
0005435215044	7731	Economy	14000.00
0005435215257	7731	Economy	14000.00
0005435215141	7731	Economy	14000.00
0005435725713	7731	Economy	14000.00
0005435215226	7731	Economy	14000.00
0005432429031	7731	Economy	14000.00
0005435725715	7731	Economy	14000.00
0005435215290	7731	Economy	14000.00
0005432070078	7731	Economy	14000.00
0005432531786	7731	Economy	14000.00
0005434069627	7731	Economy	14000.00
0005435215087	7731	Economy	14000.00
0005435214900	7731	Economy	14000.00
0005435725712	7731	Economy	14000.00
0005435215089	7731	Economy	14000.00
0005432535977	7731	Economy	14000.00
0005435215291	7731	Economy	14000.00
0005432531794	7731	Economy	14000.00
0005432531795	7731	Economy	14000.00
0005435215214	7731	Economy	14000.00
0005435214959	7731	Economy	14000.00
0005435725718	7731	Economy	14000.00
0005434069630	7731	Economy	14000.00
0005432531782	7731	Economy	14000.00
0005435725717	7731	Economy	14000.00
0005432531789	7731	Economy	14000.00
0005435214934	7731	Economy	14000.00
0005435215293	7731	Economy	14000.00
0005432150426	7731	Economy	14000.00
0005435214984	7731	Economy	14000.00
0005435214836	7731	Economy	14000.00
0005434069631	7731	Economy	14000.00
0005435215093	7731	Economy	14000.00
0005435215223	7731	Economy	14000.00
0005435215018	7731	Economy	14000.00
0005435215292	7731	Economy	14000.00
0005434069632	7731	Economy	14000.00
0005435283439	7731	Economy	14000.00
0005435215063	7731	Economy	14000.00
0005435283440	7731	Economy	14000.00
0005432531790	7731	Economy	14000.00
0005435215027	7731	Economy	15400.00
0005435215048	7731	Economy	15400.00
0005432531783	7731	Economy	14000.00
0005435215225	7731	Economy	14000.00
0005435214985	7731	Economy	14000.00
0005435215256	7731	Economy	14000.00
0005435215213	7731	Economy	14000.00
0005432531792	7731	Economy	14000.00
0005435214933	7731	Economy	14000.00
0005432535978	7731	Economy	14000.00
0005433656734	7731	Economy	14000.00
0005435215307	7731	Economy	14000.00
0005434069633	7731	Economy	14000.00
0005435214866	7731	Economy	14000.00
0005435283453	7731	Economy	14000.00
0005435214950	7731	Economy	14000.00
0005435725701	7731	Economy	14000.00
0005435215193	7731	Economy	14000.00
0005435283454	7731	Economy	14000.00
0005435283444	7731	Economy	14000.00
0005432150425	7731	Economy	14000.00
0005432531780	7731	Economy	14000.00
0005435214830	7731	Economy	14000.00
0005432531798	7731	Economy	14000.00
0005432531797	7731	Economy	14000.00
0005435215279	7731	Economy	14000.00
0005435214941	7731	Economy	14000.00
0005435725705	7731	Economy	14000.00
0005435283455	7731	Economy	14000.00
0005432531807	7731	Economy	14000.00
0005435215037	7731	Economy	14000.00
0005432531784	7731	Economy	14000.00
0005432531796	7731	Economy	14000.00
0005432531791	7731	Economy	14000.00
0005432531799	7731	Economy	14000.00
0005435215192	7731	Economy	14000.00
0005435214903	7731	Economy	14000.00
0005435214918	7731	Economy	14000.00
0005434069629	7731	Economy	14000.00
0005435215029	7731	Economy	14000.00
0005435215047	7731	Economy	14000.00
0005434245626	5323	Business	43100.00
0005434345279	5323	Business	43100.00
0005435617002	5323	Business	43100.00
0005435426516	5323	Business	43100.00
0005435426685	5323	Business	43100.00
0005432363481	5323	Business	43100.00
0005435426553	5323	Business	43100.00
0005434245717	5323	Business	43100.00
0005435426315	5323	Business	43100.00
0005435546238	5323	Business	43100.00
0005435617205	5323	Business	43100.00
0005434345277	5323	Business	43100.00
0005435042914	5323	Business	43100.00
0005435305061	5323	Business	43100.00
0005435426284	5323	Business	43100.00
0005434245689	5323	Business	43100.00
0005435426482	5323	Comfort	24400.00
0005435426562	5323	Comfort	24400.00
0005435426368	5323	Comfort	24400.00
0005434345282	5323	Comfort	24400.00
0005435426648	5323	Comfort	24400.00
0005432133656	5323	Comfort	24400.00
0005435042907	5323	Comfort	24400.00
0005435426334	5323	Comfort	24400.00
0005435426200	5323	Comfort	24400.00
0005434245736	5323	Comfort	24400.00
0005435426535	5323	Comfort	24400.00
0005435426552	5323	Comfort	24400.00
0005434573769	5323	Comfort	24400.00
0005435426438	5323	Comfort	24400.00
0005435426335	5323	Comfort	24400.00
0005435097498	5323	Economy	14400.00
0005434245625	5323	Economy	14400.00
0005435380415	5323	Economy	14400.00
0005435551773	5323	Economy	14400.00
0005435426456	5323	Economy	14400.00
0005435617015	5323	Economy	14400.00
0005434245716	5323	Economy	14400.00
0005435616995	5323	Economy	14400.00
0005434245590	5323	Economy	14400.00
0005435319803	5323	Economy	14400.00
0005433719220	5323	Economy	14400.00
0005432133655	5323	Economy	14400.00
0005435042912	5323	Economy	14400.00
0005435319785	5323	Economy	14400.00
0005435616996	5323	Economy	14400.00
0005434573771	5323	Economy	14400.00
0005434245616	5323	Economy	14400.00
0005435426515	5323	Economy	14400.00
0005435426256	5323	Economy	14400.00
0005435617023	5323	Economy	14400.00
0005435426523	5323	Economy	14400.00
0005435426150	5323	Economy	14400.00
0005435426632	5323	Economy	14400.00
0005435426481	5323	Economy	14400.00
0005435426269	5323	Economy	14400.00
0005435617000	5323	Economy	14400.00
0005434345281	5323	Economy	14400.00
0005434573773	5323	Economy	14400.00
0005435617022	5323	Economy	14400.00
0005435616998	5323	Economy	14400.00
0005435426647	5323	Economy	14400.00
0005434345285	5323	Economy	14400.00
0005434245644	5323	Economy	14400.00
0005435617006	5323	Economy	14400.00
0005434245685	5323	Economy	14400.00
0005435426718	5323	Economy	14400.00
0005434245624	5323	Economy	15800.00
0005435617003	5323	Economy	14400.00
0005433719213	5323	Economy	14400.00
0005434245691	5323	Economy	15800.00
0005435617004	5323	Economy	15800.00
0005435626885	5323	Economy	14400.00
0005435551772	5323	Economy	14400.00
0005434245551	5323	Economy	14400.00
0005435426401	5323	Economy	14400.00
0005435617009	5323	Economy	14400.00
0005434245763	5323	Economy	14400.00
0005435617010	5323	Economy	14400.00
0005435617014	5323	Economy	14400.00
0005435551775	5323	Economy	14400.00
0005434245575	5323	Economy	14400.00
0005433719211	5323	Economy	14400.00
0005435426336	5323	Economy	14400.00
0005435426507	5323	Economy	14400.00
0005435617013	5323	Economy	14400.00
0005435319792	5323	Economy	14400.00
0005435626886	5323	Economy	14400.00
0005434245738	5323	Economy	14400.00
0005434345274	5323	Economy	14400.00
0005434245687	5323	Economy	14400.00
0005434245712	5323	Economy	14400.00
0005435426355	5323	Economy	14400.00
0005434345278	5323	Economy	14400.00
0005434245731	5323	Economy	14400.00
0005432047665	5323	Economy	14400.00
0005435426509	5323	Economy	14400.00
0005434345275	5323	Economy	14400.00
0005435555429	5323	Economy	14400.00
0005435617025	5323	Economy	14400.00
0005432363495	5323	Economy	14400.00
0005434245690	5323	Economy	14400.00
0005435426512	5323	Economy	14400.00
0005435617005	5323	Economy	14400.00
0005434345280	5323	Economy	14400.00
0005435617012	5323	Economy	14400.00
0005435426597	5323	Economy	14400.00
0005434245667	5323	Economy	14400.00
0005435617020	5323	Economy	14400.00
0005434245550	5323	Economy	14400.00
0005435426423	5323	Economy	14400.00
0005432363494	5323	Economy	14400.00
0005435319765	5323	Economy	14400.00
0005435097499	5323	Economy	14400.00
0005432133654	5323	Economy	14400.00
0005434245737	5323	Economy	14400.00
0005435617021	5323	Economy	14400.00
0005435319766	5323	Economy	14400.00
0005435042913	5323	Economy	14400.00
0005435617206	5323	Economy	14400.00
0005435426448	5323	Economy	14400.00
0005435319784	5323	Economy	14400.00
0005434245606	5323	Economy	14400.00
0005435426473	5323	Economy	14400.00
0005435319818	5323	Economy	14400.00
0005435426489	5323	Economy	14400.00
0005435426687	5323	Economy	14400.00
0005435551774	5323	Economy	15800.00
0005435426667	5323	Economy	15800.00
0005434573770	5323	Economy	14400.00
0005435426449	5323	Economy	15800.00
0005434245633	5323	Economy	14400.00
0005435319774	5323	Economy	14400.00
0005432047664	5323	Economy	14400.00
0005435426443	5323	Economy	14400.00
0005432841059	5323	Economy	14400.00
0005435097496	5323	Economy	14400.00
0005435426270	5323	Economy	14400.00
0005435617001	5323	Economy	14400.00
0005434245617	5323	Economy	14400.00
0005435426455	5323	Economy	14400.00
0005435319809	5323	Economy	14400.00
0005435617017	5323	Economy	14400.00
0005434245538	5323	Economy	14400.00
0005435426527	5323	Economy	14400.00
0005434245663	5323	Economy	14400.00
0005434573772	5323	Economy	14400.00
0005434245539	5323	Economy	14400.00
0005434245692	5323	Economy	14400.00
0005435426551	5323	Economy	14400.00
0005435426700	5323	Economy	14400.00
0005434245672	5323	Economy	14400.00
0005435426369	5323	Economy	14400.00
0005435617008	5323	Economy	14400.00
0005435617207	5323	Economy	14400.00
0005435426608	5323	Economy	14400.00
0005435617024	5323	Economy	14400.00
0005435617208	5323	Economy	14400.00
0005435617011	5323	Economy	14400.00
0005435097497	5323	Economy	14400.00
0005434245671	5323	Economy	14400.00
0005435426480	5323	Economy	14400.00
0005434245627	5323	Economy	14400.00
0005434245634	5323	Economy	14400.00
0005434345283	5323	Economy	14400.00
0005434345276	5323	Economy	14400.00
0005435426717	5323	Economy	14400.00
0005435616994	5323	Economy	14400.00
0005434245597	5323	Economy	14400.00
0005435426501	5323	Economy	14400.00
0005435490338	5323	Economy	14400.00
0005435617019	5323	Economy	14400.00
0005435426598	5323	Economy	14400.00
0005435617007	5323	Economy	14400.00
0005434245688	5323	Economy	14400.00
0005435617016	5323	Economy	14400.00
0005434345284	5323	Economy	14400.00
0005435319817	5323	Economy	14400.00
0005435305057	5323	Economy	14400.00
0005435617018	5323	Economy	14400.00
0005435305056	5323	Economy	14400.00
0005434245589	5323	Economy	14400.00
0005434245686	5323	Economy	14400.00
0005435426500	5323	Economy	14400.00
0005435616997	5323	Economy	14400.00
0005435616999	5323	Economy	14400.00
0005435380416	5323	Economy	14400.00
0005434245739	5323	Economy	14400.00
0005435426499	5323	Economy	14400.00
0005432133653	5323	Economy	14400.00
0005435426508	5323	Economy	14400.00
0005435490339	5323	Economy	14400.00
0005435555418	10877	Business	43100.00
0005435426836	10877	Business	43100.00
0005434345011	10877	Business	43100.00
0005435616362	10877	Business	43100.00
0005435616411	10877	Business	43100.00
0005435616288	10877	Business	43100.00
0005435616554	10877	Business	43100.00
0005434345037	10877	Business	43100.00
0005434573662	10877	Business	43100.00
0005435097438	10877	Business	43100.00
0005435616836	10877	Business	43100.00
0005435616076	10877	Business	43100.00
0005435616217	10877	Business	43100.00
0005434345036	10877	Business	43100.00
0005435616296	10877	Business	43100.00
0005435616300	10877	Comfort	24400.00
0005435617178	10877	Comfort	24400.00
0005435616463	10877	Comfort	24400.00
0005435616356	10877	Comfort	24400.00
0005435616570	10877	Comfort	24400.00
0005434573573	10877	Comfort	24400.00
0005435042939	10877	Comfort	24400.00
0005435616270	10877	Comfort	24400.00
0005435319827	10877	Comfort	24400.00
0005435616417	10877	Comfort	24400.00
0005435616667	10877	Comfort	24400.00
0005435426834	10877	Comfort	24400.00
0005435616082	10877	Comfort	24400.00
0005435768122	10877	Comfort	24400.00
0005434344978	10877	Comfort	24400.00
0005435615873	10877	Comfort	24400.00
0005435616301	10877	Comfort	24400.00
0005435616408	10877	Comfort	24400.00
0005435616568	10877	Comfort	24400.00
0005435616088	10877	Comfort	24400.00
0005435616064	10877	Comfort	24400.00
0005434344961	10877	Comfort	24400.00
0005434345127	10877	Comfort	24400.00
0005435097390	10877	Comfort	24400.00
0005434344867	10877	Comfort	24400.00
0005435616657	10877	Comfort	24400.00
0005435616001	10877	Economy	14400.00
0005435616066	10877	Economy	14400.00
0005435305081	10877	Economy	14400.00
0005434573660	10877	Economy	14400.00
0005435490314	10877	Economy	14400.00
0005435616216	10877	Economy	14400.00
0005435616289	10877	Economy	14400.00
0005435616032	10877	Economy	14400.00
0005435616109	10877	Economy	14400.00
0005435616118	10877	Economy	14400.00
0005435490301	10877	Economy	14400.00
0005435305079	10877	Economy	14400.00
0005435097416	10877	Economy	14400.00
0005435616306	10877	Economy	14400.00
0005434344920	10877	Economy	14400.00
0005435615953	10877	Economy	14400.00
0005435616381	10877	Economy	14400.00
0005435426831	10877	Economy	14400.00
0005435616534	10877	Economy	14400.00
0005435616079	10877	Economy	14400.00
0005435615857	10877	Economy	14400.00
0005435491487	10877	Economy	14400.00
0005434573621	10877	Economy	14400.00
0005435616193	10877	Economy	14400.00
0005435616268	10877	Economy	14400.00
0005435616468	10877	Economy	14400.00
0005435380441	10877	Economy	14400.00
0005435426828	10877	Economy	14400.00
0005435616314	10877	Economy	14400.00
0005435426827	10877	Economy	14400.00
0005435616315	10877	Economy	15800.00
0005435616464	10877	Economy	15800.00
0005435491481	10877	Economy	14400.00
0005435616451	10877	Economy	15800.00
0005435615900	10877	Economy	14400.00
0005434345068	10877	Economy	14400.00
0005435616265	10877	Economy	15800.00
0005435616343	10877	Economy	14400.00
0005435616125	10877	Economy	15800.00
0005435616761	10877	Economy	15800.00
0005435615878	10877	Economy	14400.00
0005435616247	10877	Economy	14400.00
0005435616323	10877	Economy	14400.00
0005435616280	10877	Economy	14400.00
0005435304276	10877	Economy	14400.00
0005434344921	10877	Economy	14400.00
0005435616269	10877	Economy	14400.00
0005434344945	10877	Economy	14400.00
0005435616279	10877	Economy	14400.00
0005435615717	10877	Economy	14400.00
0005435615952	10877	Economy	14400.00
0005435616107	10877	Economy	14400.00
0005435616078	10877	Economy	14400.00
0005435097372	10877	Economy	14400.00
0005435616784	10877	Economy	14400.00
0005435615845	10877	Economy	14400.00
0005435616569	10877	Economy	14400.00
0005435615858	10877	Economy	14400.00
0005435616208	10877	Economy	14400.00
0005435616380	10877	Economy	14400.00
0005434344959	10877	Economy	14400.00
0005435616336	10877	Economy	14400.00
0005435616255	10877	Economy	14400.00
0005435615527	10877	Economy	14400.00
0005435097431	10877	Economy	14400.00
0005435616409	10877	Economy	14400.00
0005434345009	10877	Economy	14400.00
0005435616185	10877	Economy	14400.00
0005435616153	10877	Economy	14400.00
0005435426830	10877	Economy	14400.00
0005435555422	10877	Economy	14400.00
0005435616000	10877	Economy	14400.00
0005435616368	10877	Economy	14400.00
0005435616369	10877	Economy	14400.00
0005435615852	10877	Economy	14400.00
0005435616272	10877	Economy	14400.00
0005435616168	10877	Economy	14400.00
0005435616658	10877	Economy	14400.00
0005435616549	10877	Economy	14400.00
0005435555419	10877	Economy	14400.00
0005435615665	10877	Economy	14400.00
0005434344979	10877	Economy	14400.00
0005435097356	10877	Economy	14400.00
0005435616248	10877	Economy	14400.00
0005434345010	10877	Economy	14400.00
0005435616067	10877	Economy	14400.00
0005434345067	10877	Economy	14400.00
0005434344767	10877	Economy	14400.00
0005435616075	10877	Economy	14400.00
0005435615917	10877	Economy	14400.00
0005435616758	10877	Economy	14400.00
0005435615948	10877	Economy	14400.00
0005435616119	10877	Economy	14400.00
0005434573661	10877	Economy	14400.00
0005434345054	10877	Economy	14400.00
0005435426826	10877	Economy	14400.00
0005435616338	10877	Economy	14400.00
0005435616581	10877	Economy	14400.00
0005434573620	10877	Economy	14400.00
0005435616590	10877	Economy	14400.00
0005435616328	10877	Economy	14400.00
0005435616410	10877	Economy	14400.00
0005434344911	10877	Economy	14400.00
0005435555420	10877	Economy	14400.00
0005435490302	10877	Economy	14400.00
0005435615974	10877	Economy	14400.00
0005434573659	10877	Economy	14400.00
0005435615951	10877	Economy	14400.00
0005435616209	10877	Economy	14400.00
0005435616184	10877	Economy	14400.00
0005435616307	10877	Economy	14400.00
0005435616183	10877	Economy	15800.00
0005435616249	10877	Economy	14400.00
0005435426832	10877	Economy	15800.00
0005435616788	10877	Economy	15800.00
0005435616461	10877	Economy	14400.00
0005435426837	10877	Economy	14400.00
0005435616548	10877	Economy	14400.00
0005435616762	10877	Economy	14400.00
0005434344909	10877	Economy	14400.00
0005435616318	10877	Economy	14400.00
0005434344960	10877	Economy	14400.00
0005434344922	10877	Economy	14400.00
0005435617179	10877	Economy	14400.00
0005434245841	10877	Economy	14400.00
0005434344861	10877	Economy	14400.00
0005435616065	10877	Economy	14400.00
0005435616003	10877	Economy	14400.00
0005435616317	10877	Economy	14400.00
0005435615916	10877	Economy	14400.00
0005435097415	10877	Economy	14400.00
0005435616659	10877	Economy	14400.00
0005435616471	10877	Economy	14400.00
0005435616098	10877	Economy	14400.00
0005435319825	10877	Economy	14400.00
0005435426833	10877	Economy	14400.00
0005435616308	10877	Economy	14400.00
0005435616177	10877	Economy	14400.00
0005435097417	10877	Economy	14400.00
0005435616450	10877	Economy	14400.00
0005434344884	10877	Economy	14400.00
0005434344901	10877	Economy	14400.00
0005434344919	10877	Economy	14400.00
0005434344893	10877	Economy	14400.00
0005435615853	10877	Economy	14400.00
0005435616759	10877	Economy	14400.00
0005434573611	10877	Economy	14400.00
0005435426835	10877	Economy	14400.00
0005435616552	10877	Economy	14400.00
0005435616250	10877	Economy	14400.00
0005435615898	10877	Economy	14400.00
0005435616157	10877	Economy	14400.00
0005435426838	10877	Economy	14400.00
0005435615979	10877	Economy	14400.00
0005435616553	10877	Economy	14400.00
0005435305080	10877	Economy	14400.00
0005435616203	10877	Economy	14400.00
0005434344900	10877	Economy	14400.00
0005434573619	10877	Economy	14400.00
0005435491494	10877	Economy	14400.00
0005435319826	10877	Economy	14400.00
0005435097383	10877	Economy	14400.00
0005434344841	10877	Economy	14400.00
0005434245842	10877	Economy	14400.00
0005435616373	10877	Economy	14400.00
0005435097373	10877	Economy	14400.00
0005435097385	10877	Economy	14400.00
0005435615929	10877	Economy	14400.00
0005435426825	10877	Economy	14400.00
0005435615805	10877	Economy	14400.00
0005435097384	10877	Economy	14400.00
0005435616462	10877	Economy	14400.00
0005435616763	10877	Economy	14400.00
0005435616337	10877	Economy	14400.00
0005435426829	10877	Economy	14400.00
0005434326097	3238	Business	18800.00
0005434150212	3238	Business	18800.00
0005434311287	3238	Business	18800.00
0005432461028	3238	Business	18800.00
0005434265987	3238	Business	18800.00
0005434265993	3238	Business	18800.00
0005433806397	3238	Business	18800.00
0005435629450	3238	Business	18800.00
0005434150208	3238	Business	18800.00
0005432461027	3238	Business	18800.00
0005433806398	3238	Business	18800.00
0005434268064	3238	Business	18800.00
0005434505322	3238	Business	18800.00
0005434265991	3238	Business	18800.00
0005432460870	3238	Business	18800.00
0005434505321	3238	Business	18800.00
0005432461000	3238	Business	18800.00
0005434143849	3238	Business	18800.00
0005434265994	3238	Business	18800.00
0005434143854	3238	Business	18800.00
0005434265979	3238	Business	18800.00
0005434265980	3238	Business	18800.00
0005434266002	3238	Business	18800.00
0005435629451	3238	Economy	6900.00
0005434505323	3238	Economy	6900.00
0005434266000	3238	Economy	6900.00
0005434265978	3238	Economy	6900.00
0005433507726	3238	Economy	6300.00
0005434265990	3238	Economy	6300.00
0005434265995	3238	Economy	6300.00
0005434265989	3238	Economy	6300.00
0005432461091	3238	Economy	6300.00
0005434266005	3238	Economy	6300.00
0005432461186	3238	Economy	6300.00
0005432460979	3238	Economy	6300.00
0005434265974	3238	Economy	6300.00
0005432460997	3238	Economy	6300.00
0005433806401	3238	Economy	6300.00
0005434266001	3238	Economy	6300.00
0005433806400	3238	Economy	6300.00
0005432461042	3238	Economy	6300.00
0005434265985	3238	Economy	6300.00
0005432461029	3238	Economy	6300.00
0005434265997	3238	Economy	6300.00
0005432461099	3238	Economy	6300.00
0005434265992	3238	Economy	6300.00
0005434326098	3238	Economy	6300.00
0005432460999	3238	Economy	6300.00
0005434150214	3238	Economy	6300.00
0005434265998	3238	Economy	6300.00
0005435856334	3238	Economy	6300.00
0005433507724	3238	Economy	6300.00
0005434266008	3238	Economy	6300.00
0005434265977	3238	Economy	6300.00
0005432461139	3238	Economy	6300.00
0005434265982	3238	Economy	6300.00
0005432460998	3238	Economy	6300.00
0005434265986	3238	Economy	6300.00
0005435854089	3238	Economy	6300.00
0005433806402	3238	Economy	6300.00
0005434150205	3238	Economy	6300.00
0005434150207	3238	Economy	6300.00
0005432182365	3238	Economy	6300.00
0005432460925	3238	Economy	6300.00
0005432461001	3238	Economy	6300.00
0005432461188	3238	Economy	6300.00
0005435856333	3238	Economy	6300.00
0005432461140	3238	Economy	6300.00
0005432460969	3238	Economy	6300.00
0005435142976	3238	Economy	6300.00
0005435856343	3238	Economy	6300.00
0005434266006	3238	Economy	6300.00
0005432460880	3238	Economy	6300.00
0005434268063	3238	Economy	6300.00
0005432460841	3238	Economy	6300.00
0005432460992	3238	Economy	6300.00
0005434265976	3238	Economy	6300.00
0005434182552	3238	Economy	6300.00
0005433806399	3238	Economy	6300.00
0005432460866	3238	Economy	6300.00
0005434182553	3238	Economy	6900.00
0005432460915	3238	Economy	6900.00
0005434266003	3238	Economy	6900.00
0005434143855	3238	Economy	6900.00
0005434265983	3238	Economy	6300.00
0005432461004	3238	Economy	6900.00
0005435856332	3238	Economy	6300.00
0005433507725	3238	Economy	6300.00
0005434143853	3238	Economy	6300.00
0005434265999	3238	Economy	6900.00
0005434150209	3238	Economy	6300.00
0005433634822	3238	Economy	6300.00
0005434143852	3238	Economy	6300.00
0005432460985	3238	Economy	6300.00
0005434265975	3238	Economy	6300.00
0005432461214	3238	Economy	6300.00
0005434150204	3238	Economy	6300.00
0005432182367	3238	Economy	6300.00
0005432182366	3238	Economy	6300.00
0005434143851	3238	Economy	6300.00
0005433806396	3238	Economy	6300.00
0005432460881	3238	Economy	6300.00
0005432460996	3238	Economy	6300.00
0005432461286	3238	Economy	6300.00
0005432461161	3238	Economy	6300.00
0005434143856	3238	Economy	6300.00
0005432461215	3238	Economy	6300.00
0005434143850	3238	Economy	6300.00
0005434143848	3238	Economy	6300.00
0005433634821	3238	Economy	6300.00
0005432461269	3238	Economy	6300.00
0005432461080	3238	Economy	6300.00
0005434265996	3238	Economy	6300.00
0005433507727	3238	Economy	6300.00
0005433806403	3238	Economy	6300.00
0005434312388	3238	Economy	6300.00
0005434150210	3238	Economy	6300.00
0005434312386	3238	Economy	6300.00
0005434265988	3238	Economy	6300.00
0005434143847	3238	Economy	6300.00
0005432461012	3238	Economy	6300.00
0005434266004	3238	Economy	6300.00
0005434150211	3238	Economy	6300.00
0005432461182	3238	Economy	6300.00
0005432461079	3238	Economy	6300.00
0005434266007	3238	Economy	6300.00
0005432460980	3238	Economy	6300.00
0005434505324	3238	Economy	6300.00
0005432461181	3238	Economy	6300.00
0005434143857	3238	Economy	6300.00
0005432460766	3238	Economy	6300.00
0005432460869	3238	Economy	6300.00
0005434265981	3238	Economy	6300.00
0005432461189	3238	Economy	6300.00
0005432460916	3238	Economy	6300.00
0005432461145	3238	Economy	6300.00
0005434150213	3238	Economy	6300.00
0005432461162	3238	Economy	6300.00
0005434265984	3238	Economy	6300.00
0005434150206	3238	Economy	6300.00
0005432461007	3238	Economy	6300.00
0005435886583	3239	Business	18800.00
0005435886319	3239	Business	18800.00
0005435886446	3239	Business	18800.00
0005435886527	3239	Business	18800.00
0005435886503	3239	Business	18800.00
0005435886599	3239	Business	18800.00
0005435886649	3239	Business	18800.00
0005435886224	3239	Business	18800.00
0005435886321	3239	Business	18800.00
0005435886565	3239	Economy	6900.00
0005435886570	3239	Economy	6300.00
0005435886331	3239	Economy	6300.00
0005435886330	3239	Economy	6300.00
0005435886173	3239	Economy	6300.00
0005435886161	3239	Economy	6300.00
0005435886300	3239	Economy	6300.00
0005435886657	3239	Economy	6300.00
0005435886682	3239	Economy	6300.00
0005435886318	3239	Economy	6300.00
0005435886539	3239	Economy	6300.00
0005435886560	3239	Economy	6300.00
0005435886476	3239	Economy	6300.00
0005435886297	3239	Economy	6300.00
0005435886473	3239	Economy	6300.00
0005435886342	3239	Economy	6300.00
0005435886504	3239	Economy	6300.00
0005435886374	3239	Economy	6300.00
0005435886343	3239	Economy	6300.00
0005435886609	3239	Economy	6300.00
0005435886569	3239	Economy	6300.00
0005435886184	3239	Economy	6300.00
0005435886431	3239	Economy	6300.00
0005435886584	3239	Economy	6900.00
0005435886398	3239	Economy	6900.00
0005435886293	3239	Economy	6900.00
0005435886526	3239	Economy	6300.00
0005435886540	3239	Economy	6300.00
0005435886139	3239	Economy	6300.00
0005435886479	3239	Economy	6300.00
0005435886298	3239	Economy	6300.00
0005435886628	3239	Economy	6300.00
0005435886492	3239	Economy	6300.00
0005435886550	3239	Economy	6300.00
0005435886239	3239	Economy	6300.00
0005435886480	3239	Economy	6300.00
0005435886561	3239	Economy	6300.00
0005435886138	3239	Economy	6300.00
0005435886475	3239	Economy	6300.00
0005435886474	3239	Economy	6300.00
0005435886442	3239	Economy	6300.00
0005435886209	3239	Economy	6300.00
0005435886208	3239	Economy	6300.00
0005435886491	3239	Economy	6300.00
0005435886238	3239	Economy	6300.00
0005435886314	3239	Economy	6300.00
0005435886610	3239	Economy	6300.00
0005435886564	3239	Economy	6300.00
0005435886430	3239	Economy	6300.00
0005435886294	3239	Economy	6300.00
0005435886301	3239	Economy	6300.00
0005435886656	3239	Economy	6300.00
0005432461423	8298	Business	18800.00
0005435886846	8298	Business	18800.00
0005435886842	8298	Business	18800.00
0005435886843	8298	Business	18800.00
0005433507641	8298	Business	18800.00
0005432043127	8298	Business	18800.00
0005435886849	8298	Business	18800.00
0005433507630	8298	Business	18800.00
0005432461425	8298	Business	18800.00
0005433507514	8298	Business	18800.00
0005432461418	8298	Business	18800.00
0005432461427	8298	Business	18800.00
0005432461421	8298	Economy	6900.00
0005433507642	8298	Economy	6300.00
0005432461420	8298	Economy	6300.00
0005435886847	8298	Economy	6300.00
0005435886853	8298	Economy	6300.00
0005432043130	8298	Economy	6300.00
0005434326107	8298	Economy	6300.00
0005434312385	8298	Economy	6300.00
0005432461428	8298	Economy	6300.00
0005433507605	8298	Economy	6300.00
0005432461419	8298	Economy	6300.00
0005435886840	8298	Economy	6300.00
0005435886850	8298	Economy	6300.00
0005433507566	8298	Economy	6300.00
0005435886844	8298	Economy	6300.00
0005432461429	8298	Economy	6300.00
0005433507598	8298	Economy	6300.00
0005435886848	8298	Economy	6300.00
0005433507595	8298	Economy	6300.00
0005432461422	8298	Economy	6900.00
0005433507585	8298	Economy	6900.00
0005435886852	8298	Economy	6300.00
0005432461424	8298	Economy	6300.00
0005432461417	8298	Economy	6300.00
0005432043129	8298	Economy	6300.00
0005433507659	8298	Economy	6300.00
0005432461426	8298	Economy	6300.00
0005433507627	8298	Economy	6300.00
0005435886845	8298	Economy	6300.00
0005433507567	8298	Economy	6300.00
0005435886851	8298	Economy	6300.00
0005432043128	8298	Economy	6300.00
0005434326105	8298	Economy	6300.00
0005435933566	8298	Economy	6300.00
0005435886841	8298	Economy	6300.00
0005434326106	8298	Economy	6300.00
0005434326302	8298	Economy	6300.00
0005433507631	8298	Economy	6300.00
0005433507508	8298	Economy	6300.00
0005432043126	8298	Economy	6300.00
0005433507532	8298	Economy	6300.00
0005433507604	8298	Economy	6300.00
0005433634556	8227	Business	18800.00
0005435858742	8227	Business	18800.00
0005435860728	8227	Business	18800.00
0005433634705	8227	Business	18800.00
0005433634623	8227	Business	18800.00
0005433806360	8227	Business	18800.00
0005433806282	8227	Business	18800.00
0005433805892	8227	Business	18800.00
0005434143786	8227	Business	18800.00
0005435860726	8227	Business	18800.00
0005435860730	8227	Business	18800.00
0005435860727	8227	Business	18800.00
0005433634624	8227	Business	18800.00
0005433634529	8227	Business	18800.00
0005433634605	8227	Business	18800.00
0005433634481	8227	Business	18800.00
0005433806104	8227	Business	18800.00
0005435860723	8227	Business	18800.00
0005435858741	8227	Economy	6900.00
0005433806192	8227	Economy	6300.00
0005433634551	8227	Economy	6300.00
0005433634577	8227	Economy	6300.00
0005435860721	8227	Economy	6300.00
0005433806193	8227	Economy	6300.00
0005435860725	8227	Economy	6300.00
0005433806280	8227	Economy	6300.00
0005433806208	8227	Economy	6300.00
0005433806175	8227	Economy	6300.00
0005433634612	8227	Economy	6300.00
0005433806136	8227	Economy	6300.00
0005433634555	8227	Economy	6300.00
0005433634597	8227	Economy	6300.00
0005433806233	8227	Economy	6300.00
0005433634582	8227	Economy	6300.00
0005433806139	8227	Economy	6300.00
0005433806103	8227	Economy	6300.00
0005433806067	8227	Economy	6300.00
0005435860724	8227	Economy	6300.00
0005433806200	8227	Economy	6300.00
0005433806137	8227	Economy	6300.00
0005433806239	8227	Economy	6300.00
0005433806222	8227	Economy	6300.00
0005433806221	8227	Economy	6300.00
0005433634659	8227	Economy	6300.00
0005433806238	8227	Economy	6300.00
0005433634536	8227	Economy	6300.00
0005435860722	8227	Economy	6300.00
0005433806209	8227	Economy	6900.00
0005433634614	8227	Economy	6900.00
0005433634704	8227	Economy	6900.00
0005433634508	8227	Economy	6300.00
0005433806174	8227	Economy	6300.00
0005433634576	8227	Economy	6300.00
0005433634537	8227	Economy	6300.00
0005433634657	8227	Economy	6300.00
0005435860720	8227	Economy	6300.00
0005433805891	8227	Economy	6300.00
0005433806172	8227	Economy	6300.00
0005433806161	8227	Economy	6300.00
0005433634598	8227	Economy	6300.00
0005433806127	8227	Economy	6300.00
0005433806283	8227	Economy	6300.00
0005433806079	8227	Economy	6300.00
0005435854086	8227	Economy	6300.00
0005433806247	8227	Economy	6300.00
0005433634601	8227	Economy	6300.00
0005433806201	8227	Economy	6300.00
0005433806234	8227	Economy	6300.00
0005433634557	8227	Economy	6300.00
0005435860729	8227	Economy	6300.00
0005433806279	8227	Economy	6300.00
0005433806078	8227	Economy	6300.00
0005433806237	8227	Economy	6300.00
0005433806105	8227	Economy	6300.00
0005435858743	8227	Economy	6300.00
0005433634611	8227	Economy	6300.00
0005433634550	8227	Economy	6300.00
0005434143787	8227	Economy	6300.00
0005433806093	8227	Economy	6300.00
0005433634450	8227	Economy	6300.00
0005434183629	8191	Economy	6900.00
0005434150179	8191	Economy	6300.00
0005434183630	8191	Economy	6300.00
0005433722506	4656	Business	9900.00
0005432384324	4656	Business	9900.00
0005432384332	4656	Business	9900.00
0005435477014	4656	Business	9900.00
0005433722508	4656	Business	9900.00
0005435477016	4656	Business	9900.00
0005434300262	4656	Business	9900.00
0005432384335	4656	Business	9900.00
0005434300265	4656	Economy	3300.00
0005433195001	4656	Economy	3300.00
0005432384327	4656	Economy	3300.00
0005434300267	4656	Economy	3600.00
0005435477015	4656	Economy	3600.00
0005432384334	4656	Economy	3300.00
0005434300263	4656	Economy	3300.00
0005434300260	4656	Economy	3300.00
0005435477013	4656	Economy	3300.00
0005435477020	4656	Economy	3300.00
0005432384325	4656	Economy	3300.00
0005435477023	4656	Economy	3300.00
0005432384330	4656	Economy	3300.00
0005435477018	4656	Economy	3300.00
0005433195006	4656	Economy	3300.00
0005433195002	4656	Economy	3300.00
0005432728307	4656	Economy	3300.00
0005434300266	4656	Economy	3300.00
0005433195000	4656	Economy	3300.00
0005433722502	4656	Economy	3300.00
0005432728308	4656	Economy	3300.00
0005433195007	4656	Economy	3300.00
0005432728306	4656	Economy	3300.00
0005433722504	4656	Economy	3300.00
0005433195003	4656	Economy	3300.00
0005432384326	4656	Economy	3300.00
0005435477021	4656	Economy	3300.00
0005434300264	4656	Economy	3300.00
0005435477019	4656	Economy	3300.00
0005435477022	4656	Economy	3300.00
0005432384328	4656	Economy	3300.00
0005433194999	4656	Economy	3300.00
0005433195005	4656	Economy	3300.00
0005433195004	4656	Economy	3300.00
0005435477024	4656	Economy	3300.00
0005432384333	4656	Economy	3300.00
0005433722505	4656	Economy	3300.00
0005433722503	4656	Economy	3300.00
0005435477025	4656	Economy	3300.00
0005432384329	4656	Economy	3300.00
0005434300261	4656	Economy	3300.00
0005433722507	4656	Economy	3300.00
0005435477017	4656	Economy	3300.00
0005432384331	4656	Economy	3300.00
0005432384058	30131	Business	9900.00
0005432383968	30131	Business	9900.00
0005432383817	30131	Business	9900.00
0005432383985	30131	Business	9900.00
0005432384042	30131	Business	9900.00
0005433722333	30131	Business	9900.00
0005432383959	30131	Business	9900.00
0005432383786	30131	Business	9900.00
0005433722342	30131	Business	9900.00
0005432383925	30131	Economy	3300.00
0005432728221	30131	Economy	3300.00
0005432383927	30131	Economy	3300.00
0005432383965	30131	Economy	3300.00
0005432383972	30131	Economy	3300.00
0005432383818	30131	Economy	3300.00
0005432383915	30131	Economy	3300.00
0005432728246	30131	Economy	3300.00
0005432383979	30131	Economy	3300.00
0005432383836	30131	Economy	3600.00
0005432383789	30131	Economy	3600.00
0005432384062	30131	Economy	3600.00
0005432728247	30131	Economy	3600.00
0005432383953	30131	Economy	3300.00
0005432383942	30131	Economy	3300.00
0005432384017	30131	Economy	3300.00
0005432383947	30131	Economy	3300.00
0005432384057	30131	Economy	3300.00
0005432383787	30131	Economy	3300.00
0005432384041	30131	Economy	3300.00
0005432728248	30131	Economy	3300.00
0005432728222	30131	Economy	3300.00
0005432728240	30131	Economy	3300.00
0005432728198	30131	Economy	3300.00
0005432384021	30131	Economy	3300.00
0005432383984	30131	Economy	3300.00
0005432383976	30131	Economy	3300.00
0005432384050	30131	Economy	3300.00
0005432384036	30131	Economy	3300.00
0005432728218	30131	Economy	3300.00
0005432384019	30131	Economy	3300.00
0005432383952	30131	Economy	3300.00
0005432383765	30131	Economy	3300.00
0005433722347	30131	Economy	3300.00
0005433194920	30131	Economy	3300.00
0005432728220	30131	Economy	3300.00
0005432383764	30131	Economy	3300.00
0005432383830	30131	Economy	3300.00
0005433722353	30131	Economy	3300.00
0005433194919	30131	Economy	3300.00
0005432383841	30131	Economy	3300.00
0005433722350	30131	Economy	3300.00
0005432383923	30131	Economy	3300.00
0005432383790	30131	Economy	3300.00
0005432384035	30131	Economy	3300.00
0005432383989	30131	Economy	3300.00
0005432383886	30131	Economy	3300.00
0005432383791	30131	Economy	3300.00
0005432383992	30131	Economy	3300.00
0005432383988	30131	Economy	3300.00
0005432383926	30131	Economy	3300.00
0005432383924	30131	Economy	3300.00
0005432383914	30131	Economy	3300.00
0005432384018	30131	Economy	3300.00
0005432383956	30131	Economy	3300.00
0005432384020	30131	Economy	3300.00
0005433194928	30131	Economy	3300.00
0005432384032	30131	Economy	3300.00
0005432383991	30131	Economy	3300.00
0005433194915	30131	Economy	3300.00
0005433194926	30131	Economy	3300.00
0005432383978	30131	Economy	3300.00
0005432728197	30131	Economy	3300.00
0005435541642	1721	Business	57200.00
0005432925149	1721	Business	57200.00
0005433517162	1721	Business	57200.00
0005433517164	1721	Economy	19100.00
0005435529896	1721	Business	57200.00
0005435541641	1721	Economy	19100.00
0005433517163	1721	Economy	19100.00
0005435529892	1721	Economy	19100.00
0005435530192	1721	Economy	21000.00
0005435541643	1721	Economy	19100.00
0005435529893	1721	Economy	19100.00
0005435529895	1721	Economy	19100.00
0005435530195	1721	Economy	19100.00
0005435529897	1721	Economy	19100.00
0005435530193	1721	Economy	19100.00
0005435530191	1721	Economy	19100.00
0005435529894	1721	Economy	19100.00
0005435530194	1721	Economy	19100.00
0005435541403	22009	Business	57200.00
0005435541457	22009	Business	57200.00
0005433517108	22009	Business	57200.00
0005435541464	22009	Business	57200.00
0005435541375	22009	Business	57200.00
0005433517121	22009	Business	57200.00
0005435518282	22009	Business	57200.00
0005435541456	22009	Economy	19100.00
0005435518309	22009	Economy	19100.00
0005433517093	22009	Economy	19100.00
0005435518320	22009	Economy	19100.00
0005435518310	22009	Economy	19100.00
0005432925177	22009	Economy	19100.00
0005433517126	22009	Economy	19100.00
0005435541540	22009	Economy	19100.00
0005435541420	22009	Economy	19100.00
0005435518329	22009	Economy	19100.00
0005435541376	22009	Economy	19100.00
0005435518311	22009	Economy	19100.00
0005435541471	22009	Economy	19100.00
0005433517130	22009	Economy	19100.00
0005435541591	22009	Economy	19100.00
0005435541510	22009	Economy	19100.00
0005432925175	22009	Economy	19100.00
0005435518290	22009	Economy	19100.00
0005435518292	22009	Economy	19100.00
0005435541400	22009	Economy	19100.00
0005435541472	22009	Economy	19100.00
0005433517105	22009	Economy	19100.00
0005435518315	22009	Economy	19100.00
0005435518230	22009	Economy	19100.00
0005435518308	22009	Economy	19100.00
0005433517092	22009	Economy	19100.00
0005435518291	22009	Economy	19100.00
0005435518321	22009	Economy	19100.00
0005435541374	22009	Economy	19100.00
0005435541527	22009	Economy	19100.00
0005432925178	22009	Economy	19100.00
0005432925176	22009	Economy	19100.00
0005435253125	7361	Business	18500.00
0005434665008	7361	Business	18500.00
0005435253087	7361	Business	18500.00
0005432839934	7361	Business	18500.00
0005432839936	7361	Business	18500.00
0005435253037	7361	Economy	6200.00
0005432839933	7361	Economy	6200.00
0005434665014	7361	Economy	6200.00
0005435253135	7361	Economy	6200.00
0005435253162	7361	Economy	6800.00
0005432839932	7361	Economy	6800.00
0005435253121	7361	Economy	6800.00
0005434459413	7361	Economy	6800.00
0005434459415	7361	Economy	6200.00
0005434459414	7361	Economy	6200.00
0005435253098	7361	Economy	6200.00
0005435253083	7361	Economy	6200.00
0005435253120	7361	Economy	6200.00
0005435253113	7361	Economy	6200.00
0005435253152	7361	Economy	6200.00
0005432839935	7361	Economy	6200.00
0005435253136	7361	Economy	6200.00
0005435253181	7361	Economy	6200.00
0005435253157	7361	Economy	6200.00
0005435253191	7361	Economy	6200.00
0005435253050	7361	Economy	6200.00
0005434665013	7361	Economy	6200.00
0005435253138	7361	Economy	6200.00
0005434459412	7361	Economy	6200.00
0005434665009	7361	Economy	6200.00
0005435253086	7361	Economy	6200.00
0005432839931	7361	Economy	6200.00
0005435253085	7361	Economy	6200.00
0005435253119	7361	Economy	6200.00
0005434665011	7361	Economy	6200.00
0005435253156	7361	Economy	6200.00
0005432823507	7361	Economy	6200.00
0005435253063	7361	Economy	6200.00
0005435253118	7361	Economy	6200.00
0005432839772	28911	Business	18500.00
0005432839851	28911	Business	18500.00
0005434459309	28911	Business	18500.00
0005432839672	28911	Business	18500.00
0005435253220	28911	Economy	6200.00
0005432839903	28911	Economy	6200.00
0005432839642	28911	Economy	6200.00
0005435491509	28911	Economy	6200.00
0005432839710	28911	Economy	6200.00
0005432841067	28911	Economy	6200.00
0005434459341	28911	Economy	6200.00
0005432823501	28911	Economy	6200.00
0005432839769	28911	Economy	6800.00
0005434459249	28911	Economy	6800.00
0005434665025	28911	Economy	6200.00
0005432841068	28911	Economy	6200.00
0005434459314	28911	Economy	6200.00
0005432839855	28911	Economy	6200.00
0005434459316	28911	Economy	6200.00
0005434459223	28911	Economy	6200.00
0005432841056	28911	Economy	6200.00
0005434459343	28911	Economy	6200.00
0005434665024	28911	Economy	6200.00
0005434459296	28911	Economy	6200.00
0005432839830	28911	Economy	6200.00
0005432839726	28911	Economy	6200.00
0005434459272	28911	Economy	6200.00
0005434459257	28911	Economy	6200.00
0005434459273	28911	Economy	6200.00
0005434459269	28911	Economy	6200.00
0005435491508	28911	Economy	6200.00
0005434459256	28911	Economy	6200.00
0005432839802	28911	Economy	6200.00
0005432839852	28911	Economy	6200.00
0005434459308	28911	Economy	6200.00
0005432839902	28911	Economy	6200.00
0005432839770	28911	Economy	6200.00
0005432839771	28911	Economy	6200.00
0005432839877	28911	Economy	6200.00
0005434459317	28911	Economy	6200.00
0005434459298	28911	Economy	6200.00
0005434459246	28911	Economy	6200.00
0005434459222	28911	Economy	6200.00
0005434459248	28911	Economy	6200.00
0005434459250	28911	Economy	6200.00
0005435491507	28911	Economy	6200.00
0005432839768	28911	Economy	6200.00
0005434459315	28911	Economy	6200.00
0005434459306	28911	Economy	6200.00
0005432839761	28911	Economy	6200.00
0005434459173	28911	Economy	6200.00
0005434276144	8824	Business	145300.00
0005434276141	8824	Economy	48400.00
0005434276156	8824	Economy	53300.00
0005434276171	8824	Economy	48400.00
0005434276140	8824	Economy	48400.00
0005435990798	15752	Business	145300.00
0005433435529	15752	Economy	48400.00
0005433435526	15752	Economy	48400.00
0005433435522	15752	Economy	48400.00
0005435990804	15752	Economy	48400.00
0005433435523	15752	Economy	53300.00
0005433435524	15752	Economy	48400.00
0005435990782	15752	Economy	48400.00
0005434276199	15752	Economy	48400.00
0005435990761	15752	Economy	48400.00
0005433435527	15752	Economy	48400.00
0005433435525	15752	Economy	48400.00
0005433435528	15752	Economy	48400.00
0005434276198	15752	Economy	48400.00
0005435990760	15752	Economy	48400.00
0005435990814	15752	Economy	48400.00
0005433476937	20620	Economy	14500.00
0005432427207	20620	Economy	14500.00
0005433476946	20620	Economy	14500.00
0005432427208	20620	Economy	14500.00
0005432427206	20620	Economy	14500.00
0005433476949	20620	Economy	14500.00
0005433476947	20620	Economy	14500.00
0005432427209	20620	Economy	14500.00
0005433476936	20620	Economy	14500.00
0005433476945	20620	Economy	14500.00
0005432427189	30840	Economy	14500.00
0005433476954	30840	Economy	14500.00
0005432427196	30840	Economy	14500.00
0005433468537	23845	Economy	12100.00
0005433468508	23845	Economy	12100.00
0005433468532	23845	Economy	12100.00
0005433468562	23845	Economy	12100.00
0005433468510	23845	Economy	12100.00
0005433468548	23845	Economy	12100.00
0005433468530	23845	Economy	12100.00
0005433468555	23845	Economy	12100.00
0005433468511	23845	Economy	12100.00
0005433468528	23845	Economy	12100.00
0005433468549	23845	Economy	12100.00
0005433468585	23845	Economy	12100.00
0005433468542	23845	Economy	12100.00
0005432909439	23845	Economy	12100.00
0005433468529	23845	Economy	12100.00
0005433468539	23845	Economy	12100.00
0005433468507	23845	Economy	12100.00
0005433468554	23845	Economy	12100.00
0005432909437	23845	Economy	12100.00
0005433468538	23845	Economy	12100.00
0005433468526	23845	Economy	12100.00
0005433468531	23845	Economy	12100.00
0005432909438	23845	Economy	12100.00
0005433468509	23845	Economy	12100.00
0005435177729	6373	Business	36600.00
0005434149985	6373	Business	36600.00
0005434149984	6373	Business	36600.00
0005432361763	6373	Business	36600.00
0005435177671	6373	Economy	12200.00
0005432361759	6373	Economy	12200.00
0005435177715	6373	Economy	12200.00
0005434150025	6373	Economy	12200.00
0005432361760	6373	Economy	12200.00
0005435177776	6373	Economy	12200.00
0005432361762	6373	Economy	12200.00
0005435177703	6373	Economy	12200.00
0005435177660	6373	Economy	12200.00
0005435723090	6373	Economy	12200.00
0005435177762	6373	Economy	12200.00
0005435723089	6373	Economy	12200.00
0005435177763	6373	Economy	13400.00
0005435490314	6373	Economy	13400.00
0005435177783	6373	Economy	13400.00
0005432361755	6373	Economy	12200.00
0005435177775	6373	Economy	12200.00
0005432062387	6373	Economy	12200.00
0005432361756	6373	Economy	12200.00
0005435177814	6373	Economy	12200.00
0005435177837	6373	Economy	12200.00
0005432361761	6373	Economy	12200.00
0005432361758	6373	Economy	12200.00
0005434149974	6373	Economy	12200.00
0005435490302	6373	Economy	12200.00
0005435490301	6373	Economy	12200.00
0005435177836	6373	Economy	12200.00
0005435177698	6373	Economy	12200.00
0005435177752	6373	Economy	12200.00
0005434149937	6373	Economy	12200.00
0005432361757	6373	Economy	12200.00
0005435723088	6373	Economy	12200.00
0005432361318	20984	Business	36600.00
0005432361492	20984	Business	36600.00
0005432361626	20984	Business	36600.00
0005432361436	20984	Business	36600.00
0005432361172	20984	Business	36600.00
0005435177868	20984	Business	36600.00
0005432361417	20984	Economy	12200.00
0005432361458	20984	Economy	12200.00
0005432361457	20984	Economy	12200.00
0005432336351	20984	Economy	12200.00
0005432361322	20984	Economy	12200.00
0005432361447	20984	Economy	12200.00
0005432361523	20984	Economy	12200.00
0005432336321	20984	Economy	12200.00
0005432361526	20984	Economy	12200.00
0005432361450	20984	Economy	12200.00
0005435177867	20984	Economy	12200.00
0005432361234	20984	Economy	12200.00
0005432361528	20984	Economy	12200.00
0005432361171	20984	Economy	12200.00
0005432336300	20984	Economy	12200.00
0005432361451	20984	Economy	12200.00
0005435177870	20984	Economy	12200.00
0005432361493	20984	Economy	12200.00
0005432361215	20984	Economy	12200.00
0005432361233	20984	Economy	13400.00
0005432361474	20984	Economy	13400.00
0005435177871	20984	Economy	13400.00
0005432361324	20984	Economy	12200.00
0005432361530	20984	Economy	12200.00
0005432361448	20984	Economy	12200.00
0005432361167	20984	Economy	12200.00
0005432361166	20984	Economy	12200.00
0005432336347	20984	Economy	12200.00
0005432361391	20984	Economy	12200.00
0005432361424	20984	Economy	12200.00
0005432361323	20984	Economy	12200.00
0005432336327	20984	Economy	12200.00
0005432361581	20984	Economy	12200.00
0005432361214	20984	Economy	12200.00
0005432361425	20984	Economy	12200.00
0005432363498	20984	Economy	12200.00
0005432361527	20984	Economy	12200.00
0005432361423	20984	Economy	12200.00
0005432361410	20984	Economy	12200.00
0005435177866	20984	Economy	12200.00
0005432336290	20984	Economy	12200.00
0005434150078	20984	Economy	12200.00
0005432361627	20984	Economy	12200.00
0005432361524	20984	Economy	12200.00
0005432336344	20984	Economy	12200.00
0005432336256	20984	Economy	12200.00
0005432336264	20984	Economy	12200.00
0005432361641	20984	Economy	12200.00
0005432361409	20984	Economy	12200.00
0005432336294	20984	Economy	12200.00
0005432361488	20984	Economy	12200.00
0005435723106	20984	Economy	12200.00
0005432361580	20984	Economy	12200.00
0005432361317	20984	Economy	12200.00
0005435177869	20984	Economy	12200.00
0005432336263	20984	Economy	12200.00
0005432361529	20984	Economy	12200.00
0005432361342	20984	Economy	12200.00
0005432361479	20984	Economy	12200.00
0005432361395	20984	Economy	12200.00
0005432361582	20984	Economy	12200.00
0005432361473	20984	Economy	12200.00
0005432336293	20984	Economy	12200.00
0005434150077	20984	Economy	12200.00
0005432361341	20984	Economy	12200.00
0005434459291	17725	Economy	3400.00
0005434459302	17725	Economy	3100.00
0005434459288	17725	Economy	3100.00
0005434448379	17725	Economy	3100.00
0005434459184	17725	Economy	3100.00
0005434459303	17725	Economy	3100.00
0005434459258	17725	Economy	3100.00
0005434459290	17725	Economy	3100.00
0005434459207	17725	Economy	3100.00
0005434448397	17725	Economy	3100.00
0005434448400	17725	Economy	3100.00
0005434463987	17725	Economy	3100.00
0005434459373	17725	Economy	3100.00
0005434459295	17725	Economy	3100.00
0005434459318	17725	Economy	3100.00
0005434448396	17725	Economy	3100.00
0005434461695	17725	Economy	3100.00
0005434459289	17725	Economy	3100.00
0005434459333	17725	Economy	3100.00
0005434459294	17725	Economy	3100.00
0005434459383	17725	Economy	3100.00
0005434459332	17725	Economy	3100.00
0005434463986	17725	Economy	3100.00
0005434459412	29090	Economy	3400.00
0005434186271	29090	Economy	3100.00
0005434462855	29090	Economy	3100.00
0005434459413	29090	Economy	3100.00
0005434463995	29090	Economy	3100.00
0005434448415	29090	Economy	3100.00
0005434448418	29090	Economy	3100.00
0005434462854	29090	Economy	3100.00
0005434459415	29090	Economy	3100.00
0005434463994	29090	Economy	3100.00
0005434459414	29090	Economy	3100.00
0005434448416	29090	Economy	3100.00
0005434186260	29090	Economy	3100.00
0005434448417	29090	Economy	3100.00
0005432664201	6491	Business	185300.00
0005432661991	6491	Business	185300.00
0005432661994	6491	Business	185300.00
0005432664207	6491	Business	185300.00
0005432661992	6491	Economy	61800.00
0005432661989	6491	Economy	61800.00
0005432663104	6491	Economy	67900.00
0005432663101	6491	Economy	67900.00
0005432664208	6491	Economy	61800.00
0005432663103	6491	Economy	61800.00
0005432664211	6491	Economy	61800.00
0005432664204	6491	Economy	61800.00
0005432664209	6491	Economy	61800.00
0005432661995	6491	Economy	61800.00
0005432664203	6491	Economy	61800.00
0005432663105	6491	Economy	61800.00
0005432663110	6491	Economy	61800.00
0005432663106	6491	Economy	61800.00
0005432663107	6491	Economy	61800.00
0005432663108	6491	Economy	61800.00
0005432664205	6491	Economy	61800.00
0005432663102	6491	Economy	61800.00
0005432663111	6491	Economy	61800.00
0005432661993	6491	Economy	61800.00
0005432664206	6491	Economy	61800.00
0005432663109	6491	Economy	61800.00
0005432664210	6491	Economy	61800.00
0005432661990	6491	Economy	61800.00
0005432664202	6491	Economy	61800.00
0005432605483	21445	Economy	7300.00
0005432605490	21445	Economy	7300.00
0005432605484	21445	Economy	6600.00
0005432605487	21445	Economy	6600.00
0005435221551	21445	Economy	6600.00
0005432605485	21445	Economy	6600.00
0005432605486	21445	Economy	6600.00
0005435221552	21445	Economy	6600.00
0005435220497	21445	Economy	6600.00
0005432605482	21445	Economy	6600.00
0005432605481	21445	Economy	6600.00
0005432605489	21445	Economy	6600.00
0005432605488	21445	Economy	6600.00
0005432605201	31712	Economy	7300.00
0005432605137	31712	Economy	7300.00
0005432605258	31712	Economy	7300.00
0005432605280	31712	Economy	6600.00
0005432605271	31712	Economy	6600.00
0005432605139	31712	Economy	6600.00
0005432605292	31712	Economy	6600.00
0005432605270	31712	Economy	6600.00
0005432605162	31712	Economy	6600.00
0005432605321	31712	Economy	6600.00
0005432605268	31712	Economy	6600.00
0005432605219	31712	Economy	6600.00
0005432605120	31712	Economy	6600.00
0005432605290	31712	Economy	6600.00
0005432605293	31712	Economy	6600.00
0005432605147	31712	Economy	6600.00
0005432605032	31712	Economy	6600.00
0005432605164	31712	Economy	6600.00
0005432605284	31712	Economy	6600.00
0005432605200	31712	Economy	6600.00
0005432605256	31712	Economy	6600.00
0005432605231	31712	Economy	6600.00
0005432605163	31712	Economy	6600.00
0005435221556	31712	Economy	6600.00
0005432605314	31712	Economy	6600.00
0005432605232	31712	Economy	6600.00
0005432605252	31712	Economy	6600.00
0005432605291	31712	Economy	6600.00
0005432605170	31712	Economy	6600.00
0005432605253	31712	Economy	6600.00
0005432605246	31712	Economy	6600.00
0005433293353	12306	Economy	19500.00
0005433293373	12306	Economy	19500.00
0005435154702	12306	Economy	19500.00
0005435154691	12306	Economy	17800.00
0005433293374	12306	Economy	17800.00
0005435154700	12306	Economy	17800.00
0005433293376	12306	Economy	17800.00
0005433293352	12306	Economy	17800.00
0005433293377	12306	Economy	17800.00
0005433293384	12306	Economy	17800.00
0005433293394	12306	Economy	17800.00
0005433293383	12306	Economy	17800.00
0005433293375	12306	Economy	17800.00
0005435154693	12306	Economy	17800.00
0005435154703	12306	Economy	17800.00
0005433293382	12306	Economy	17800.00
0005433293355	12306	Economy	17800.00
0005435154699	12306	Economy	17800.00
0005435154694	12306	Economy	17800.00
0005435154697	12306	Economy	17800.00
0005433293395	12306	Economy	17800.00
0005435154692	12306	Economy	17800.00
0005435154698	12306	Economy	17800.00
0005433293354	12306	Economy	17800.00
0005435154696	12306	Economy	17800.00
0005433293391	12306	Economy	17800.00
0005435154695	12306	Economy	17800.00
0005433293356	12306	Economy	17800.00
0005435154701	12306	Economy	17800.00
0005435257386	23895	Economy	14000.00
0005433473508	23895	Economy	14000.00
0005433473468	23895	Economy	14000.00
0005435257385	23895	Economy	12700.00
0005433473450	23895	Economy	12700.00
0005433473492	23895	Economy	12700.00
0005435257387	23895	Economy	12700.00
0005433473467	23895	Economy	12700.00
0005433473452	23895	Economy	12700.00
0005433473522	23895	Economy	12700.00
0005433473482	23895	Economy	12700.00
0005433473453	23895	Economy	12700.00
0005435257388	23895	Economy	12700.00
0005435257382	23895	Economy	12700.00
0005433473475	23895	Economy	12700.00
0005433473523	23895	Economy	12700.00
0005435257389	23895	Economy	12700.00
0005433473474	23895	Economy	12700.00
0005433473416	23895	Economy	12700.00
0005435257384	23895	Economy	12700.00
0005435257383	23895	Economy	12700.00
0005434606897	18854	Economy	6600.00
0005434606898	18854	Economy	6600.00
0005434606904	18854	Economy	6600.00
0005434606910	18854	Economy	6600.00
0005434606911	18854	Economy	6600.00
0005435904715	22365	Economy	6600.00
0005435904716	22365	Economy	6600.00
0005434606935	22365	Economy	6600.00
0005434522559	3858	Economy	22600.00
0005434522558	3858	Economy	22600.00
0005434602980	3858	Economy	22600.00
0005435904456	3858	Economy	22600.00
0005435904455	3858	Economy	22600.00
0005435904452	3858	Economy	22600.00
0005435904451	3858	Economy	22600.00
0005435904454	3858	Economy	22600.00
0005434522557	3858	Economy	22600.00
0005435904453	3858	Economy	22600.00
0005434602979	3858	Economy	22600.00
0005434602978	3858	Economy	22600.00
0005434602981	3858	Economy	22600.00
0005434603027	3858	Economy	22600.00
0005434603026	3858	Economy	22600.00
0005434602982	3858	Economy	22600.00
0005435904457	3858	Economy	22600.00
0005434522556	3858	Economy	22600.00
0005434522560	3858	Economy	22600.00
0005434604969	19043	Economy	24900.00
0005434602953	19043	Economy	24900.00
0005434602949	19043	Economy	24900.00
0005434604971	19043	Economy	24900.00
0005435904491	19043	Economy	22600.00
0005434604970	19043	Economy	22600.00
0005434602952	19043	Economy	22600.00
0005434604973	19043	Economy	22600.00
0005434602964	19043	Economy	22600.00
0005434602951	19043	Economy	22600.00
0005434604979	19043	Economy	22600.00
0005434604976	19043	Economy	22600.00
0005434602963	19043	Economy	22600.00
0005434604972	19043	Economy	22600.00
0005434602950	19043	Economy	22600.00
0005435904479	19043	Economy	22600.00
0005434604980	19043	Economy	22600.00
0005434604981	19043	Economy	22600.00
0005435904478	19043	Economy	22600.00
0005434604975	19043	Economy	22600.00
0005434522538	19043	Economy	22600.00
0005432891498	380	Business	44500.00
0005432891375	380	Business	44500.00
0005432891444	380	Business	44500.00
0005432748672	380	Business	44500.00
0005435154705	380	Business	44500.00
0005432891494	380	Economy	14800.00
0005435154706	380	Economy	14800.00
0005432891427	380	Economy	14800.00
0005432749850	380	Economy	14800.00
0005433293380	380	Economy	14800.00
0005432891464	380	Economy	14800.00
0005435154704	380	Economy	14800.00
0005432748675	380	Economy	16300.00
0005432751628	380	Economy	16300.00
0005432748679	380	Economy	16300.00
0005433875417	380	Economy	14800.00
0005432748680	380	Economy	14800.00
0005432891374	380	Economy	14800.00
0005432749851	380	Economy	14800.00
0005432891488	380	Economy	14800.00
0005432891500	380	Economy	14800.00
0005432748678	380	Economy	14800.00
0005432748676	380	Economy	14800.00
0005432891469	380	Economy	14800.00
0005432891354	380	Economy	14800.00
0005432891458	380	Economy	14800.00
0005432891529	380	Economy	14800.00
0005432891541	380	Economy	14800.00
0005432891503	380	Economy	14800.00
0005432751627	380	Economy	14800.00
0005433875418	380	Economy	14800.00
0005433293379	380	Economy	14800.00
0005432891446	380	Economy	14800.00
0005432891443	380	Economy	14800.00
0005432753400	380	Economy	14800.00
0005432891457	380	Economy	14800.00
0005432748671	380	Economy	14800.00
0005433293381	380	Economy	14800.00
0005432753401	380	Economy	14800.00
0005432891542	380	Economy	14800.00
0005432891471	380	Economy	14800.00
0005432748677	380	Economy	14800.00
0005432748673	380	Economy	14800.00
0005432748674	380	Economy	14800.00
0005432891428	380	Economy	14800.00
0005432751626	380	Economy	14800.00
0005432891514	380	Economy	14800.00
0005433293368	380	Economy	14800.00
0005432891487	380	Economy	14800.00
0005432748646	12059	Business	44500.00
0005432748385	12059	Business	44500.00
0005432748452	12059	Business	44500.00
0005432891589	12059	Business	44500.00
0005432891586	12059	Business	44500.00
0005432214869	12059	Business	44500.00
0005432748251	12059	Business	44500.00
0005433875429	12059	Economy	14800.00
0005434153584	12059	Economy	14800.00
0005432748597	12059	Economy	14800.00
0005432748455	12059	Economy	14800.00
0005432748571	12059	Economy	14800.00
0005432748642	12059	Economy	14800.00
0005432748464	12059	Economy	14800.00
0005432748387	12059	Economy	16300.00
0005432749842	12059	Economy	16300.00
0005432748568	12059	Economy	16300.00
0005432748317	12059	Economy	16300.00
0005432748459	12059	Economy	14800.00
0005432748460	12059	Economy	14800.00
0005432748467	12059	Economy	14800.00
0005432748523	12059	Economy	14800.00
0005432756928	12059	Economy	14800.00
0005432748567	12059	Economy	14800.00
0005432748330	12059	Economy	14800.00
0005432749843	12059	Economy	14800.00
0005432756913	12059	Economy	14800.00
0005432756911	12059	Economy	14800.00
0005432753355	12059	Economy	14800.00
0005432748468	12059	Economy	14800.00
0005432891584	12059	Economy	14800.00
0005432748530	12059	Economy	14800.00
0005432748521	12059	Economy	14800.00
0005432756927	12059	Economy	14800.00
0005432748384	12059	Economy	14800.00
0005432756921	12059	Economy	14800.00
0005432748596	12059	Economy	14800.00
0005434152871	12059	Economy	14800.00
0005432748413	12059	Economy	14800.00
0005432748465	12059	Economy	14800.00
0005432748469	12059	Economy	14800.00
0005432748515	12059	Economy	14800.00
0005432891590	12059	Economy	14800.00
0005432749832	12059	Economy	14800.00
0005432748348	12059	Economy	14800.00
0005432748529	12059	Economy	14800.00
0005432748582	12059	Economy	14800.00
0005432891585	12059	Economy	14800.00
0005432748286	12059	Economy	14800.00
0005432748522	12059	Economy	14800.00
0005432748516	12059	Economy	14800.00
0005432748450	12059	Economy	14800.00
0005432891588	12059	Economy	14800.00
0005434152870	12059	Economy	14800.00
0005432748456	12059	Economy	14800.00
0005432748570	12059	Economy	14800.00
0005432748329	12059	Economy	14800.00
0005432748441	12059	Economy	14800.00
0005432748388	12059	Economy	14800.00
0005432891587	12059	Economy	14800.00
0005432748542	12059	Economy	14800.00
0005433533418	18945	Economy	28200.00
0005433525357	18945	Economy	25700.00
0005433533419	18945	Economy	25700.00
0005433525358	18945	Economy	25700.00
0005433533420	18945	Economy	25700.00
0005433525238	32461	Economy	25700.00
0005433525239	32461	Economy	25700.00
0005433525309	32461	Economy	25700.00
0005433531381	32461	Economy	25700.00
0005433531385	32461	Economy	25700.00
0005433525286	32461	Economy	25700.00
0005433527362	32461	Economy	25700.00
0005432928149	32461	Economy	25700.00
0005433527361	32461	Economy	25700.00
0005433527338	32461	Economy	25700.00
0005433525310	32461	Economy	25700.00
0005433531393	32461	Economy	25700.00
0005432928150	32461	Economy	25700.00
0005433525340	32461	Economy	25700.00
0005433527356	32461	Economy	25700.00
0005432394224	5251	Business	84000.00
0005435179014	5251	Business	84000.00
0005435374840	5251	Business	84000.00
0005435374514	5251	Business	84000.00
0005435386709	5251	Business	84000.00
0005435374924	5251	Business	84000.00
0005435661989	5251	Business	84000.00
0005435374888	5251	Business	84000.00
0005435375014	5251	Business	84000.00
0005434558604	5251	Business	84000.00
0005434827257	5251	Business	84000.00
0005434827263	5251	Comfort	47600.00
0005435374905	5251	Business	84000.00
0005435374744	5251	Comfort	47600.00
0005434827267	5251	Comfort	47600.00
0005435375004	5251	Comfort	47600.00
0005434827265	5251	Comfort	47600.00
0005435374527	5251	Comfort	47600.00
0005435374842	5251	Comfort	47600.00
0005435374980	5251	Comfort	47600.00
0005435374669	5251	Comfort	47600.00
0005435314973	5251	Comfort	47600.00
0005435374756	5251	Comfort	47600.00
0005435374632	5251	Comfort	47600.00
0005435374517	5251	Comfort	47600.00
0005435374639	5251	Comfort	47600.00
0005432823494	5251	Comfort	47600.00
0005435315055	5251	Comfort	47600.00
0005435315031	5251	Comfort	47600.00
0005435374509	5251	Comfort	47600.00
0005434827260	5251	Comfort	47600.00
0005435374638	5251	Comfort	47600.00
0005434827262	5251	Comfort	47600.00
0005435374835	5251	Comfort	47600.00
0005435735228	5251	Comfort	47600.00
0005435735245	5251	Comfort	47600.00
0005435374521	5251	Comfort	47600.00
0005434558605	5251	Comfort	47600.00
0005434827270	5251	Comfort	47600.00
0005435374522	5251	Economy	28000.00
0005435315010	5251	Economy	28000.00
0005434827266	5251	Economy	28000.00
0005435314997	5251	Economy	28000.00
0005434827245	5251	Economy	28000.00
0005434827254	5251	Economy	28000.00
0005435386722	5251	Economy	28000.00
0005435374923	5251	Economy	28000.00
0005435374769	5251	Economy	28000.00
0005435374617	5251	Economy	28000.00
0005435374663	5251	Economy	28000.00
0005435374767	5251	Economy	28000.00
0005435374841	5251	Economy	28000.00
0005435150432	5251	Economy	28000.00
0005435374687	5251	Economy	28000.00
0005435374631	5251	Economy	28000.00
0005435374753	5251	Economy	28000.00
0005435735236	5251	Economy	28000.00
0005435374754	5251	Economy	28000.00
0005435374861	5251	Economy	28000.00
0005435314996	5251	Economy	28000.00
0005435315011	5251	Economy	28000.00
0005434558607	5251	Economy	28000.00
0005435299876	5251	Economy	28000.00
0005434827264	5251	Economy	28000.00
0005432121752	5251	Economy	28000.00
0005435374571	5251	Economy	28000.00
0005435299889	5251	Economy	28000.00
0005435374843	5251	Economy	28000.00
0005435315043	5251	Economy	28000.00
0005435374688	5251	Economy	30800.00
0005435374752	5251	Economy	28000.00
0005435315001	5251	Economy	28000.00
0005435374901	5251	Economy	30800.00
0005434827248	5251	Economy	28000.00
0005432121751	5251	Economy	28000.00
0005435374904	5251	Economy	28000.00
0005434827272	5251	Economy	28000.00
0005435735253	5251	Economy	28000.00
0005435315013	5251	Economy	28000.00
0005434827249	5251	Economy	28000.00
0005435386732	5251	Economy	28000.00
0005435374738	5251	Economy	28000.00
0005434558608	5251	Economy	28000.00
0005435374719	5251	Economy	28000.00
0005434827242	5251	Economy	28000.00
0005435374569	5251	Economy	28000.00
0005435179013	5251	Economy	28000.00
0005434827247	5251	Economy	28000.00
0005435299901	5251	Economy	28000.00
0005435314980	5251	Economy	28000.00
0005435374766	5251	Economy	28000.00
0005435375018	5251	Economy	28000.00
0005435299886	5251	Economy	28000.00
0005435374742	5251	Economy	28000.00
0005434827244	5251	Economy	28000.00
0005435386738	5251	Economy	28000.00
0005434558609	5251	Economy	28000.00
0005434827269	5251	Economy	28000.00
0005435374979	5251	Economy	28000.00
0005432823492	5251	Economy	28000.00
0005435315028	5251	Economy	28000.00
0005435304251	5251	Economy	28000.00
0005434827255	5251	Economy	28000.00
0005435374670	5251	Economy	28000.00
0005434827253	5251	Economy	28000.00
0005435374852	5251	Economy	28000.00
0005434827251	5251	Economy	28000.00
0005435386708	5251	Economy	28000.00
0005435735237	5251	Economy	28000.00
0005434827252	5251	Economy	28000.00
0005435374480	5251	Economy	28000.00
0005435374707	5251	Economy	28000.00
0005435374792	5251	Economy	28000.00
0005435315104	5251	Economy	28000.00
0005435299894	5251	Economy	28000.00
0005435374836	5251	Economy	28000.00
0005434827258	5251	Economy	28000.00
0005435374902	5251	Economy	28000.00
0005434827246	5251	Economy	28000.00
0005434558606	5251	Economy	28000.00
0005435374862	5251	Economy	28000.00
0005435374570	5251	Economy	28000.00
0005435315105	5251	Economy	28000.00
0005434827268	5251	Economy	28000.00
0005434827271	5251	Economy	30800.00
0005435374787	5251	Economy	30800.00
0005435374786	5251	Economy	30800.00
0005435314968	5251	Economy	28000.00
0005435374768	5251	Economy	28000.00
0005435315042	5251	Economy	28000.00
0005435314987	5251	Economy	28000.00
0005435374740	5251	Economy	28000.00
0005435374479	5251	Economy	28000.00
0005435374739	5251	Economy	28000.00
0005435386707	5251	Economy	28000.00
0005434827259	5251	Economy	28000.00
0005435315054	5251	Economy	28000.00
0005435374568	5251	Economy	28000.00
0005432121749	5251	Economy	28000.00
0005435375012	5251	Economy	28000.00
0005435375007	5251	Economy	28000.00
0005435386710	5251	Economy	28000.00
0005434827256	5251	Economy	28000.00
0005432121750	5251	Economy	28000.00
0005435315044	5251	Economy	28000.00
0005435374880	5251	Economy	28000.00
0005435374715	5251	Economy	28000.00
0005435374698	5251	Economy	28000.00
0005435386731	5251	Economy	28000.00
0005435374558	5251	Economy	28000.00
0005435374798	5251	Economy	28000.00
0005435735233	5251	Economy	28000.00
0005435374839	5251	Economy	28000.00
0005435374889	5251	Economy	28000.00
0005435735232	5251	Economy	28000.00
0005435314986	5251	Economy	28000.00
0005432394223	5251	Economy	28000.00
0005434827261	5251	Economy	28000.00
0005434827250	5251	Economy	28000.00
0005435315030	5251	Economy	28000.00
0005434827243	5251	Economy	28000.00
0005432823493	5251	Economy	28000.00
0005435315067	5251	Economy	28000.00
0005435374793	5251	Economy	28000.00
0005435150431	5251	Economy	28000.00
0005435314976	5251	Economy	28000.00
0005435315029	5251	Economy	28000.00
0005435315018	5251	Economy	28000.00
0005435314967	5251	Economy	28000.00
0005435374844	5251	Economy	28000.00
0005435314981	5251	Economy	28000.00
0005434826213	9904	Business	84000.00
0005434826580	9904	Business	84000.00
0005435150289	9904	Business	84000.00
0005434826184	9904	Business	84000.00
0005434826343	9904	Business	84000.00
0005435375164	9904	Business	84000.00
0005432203270	9904	Business	84000.00
0005434826561	9904	Business	84000.00
0005434825737	9904	Business	84000.00
0005434826645	9904	Business	84000.00
0005434826446	9904	Business	84000.00
0005434826560	9904	Business	84000.00
0005434826635	9904	Business	84000.00
0005434826432	9904	Business	84000.00
0005434826587	9904	Business	84000.00
0005434558440	9904	Business	84000.00
0005434826296	9904	Business	84000.00
0005434826784	9904	Business	84000.00
0005434826372	9904	Business	84000.00
0005434826398	9904	Comfort	47600.00
0005434826713	9904	Comfort	47600.00
0005434826214	9904	Comfort	47600.00
0005435150342	9904	Comfort	47600.00
0005435150319	9904	Comfort	47600.00
0005434826319	9904	Comfort	47600.00
0005434826507	9904	Comfort	47600.00
0005434826557	9904	Comfort	47600.00
0005435302337	9904	Comfort	47600.00
0005434826956	9904	Comfort	47600.00
0005434826305	9904	Comfort	47600.00
0005434558475	9904	Comfort	47600.00
0005434825971	9904	Comfort	47600.00
0005434831267	9904	Comfort	47600.00
0005435375165	9904	Comfort	47600.00
0005434826087	9904	Comfort	47600.00
0005434826375	9904	Comfort	47600.00
0005434826631	9904	Comfort	47600.00
0005434826283	9904	Comfort	47600.00
0005434558480	9904	Comfort	47600.00
0005434827059	9904	Comfort	47600.00
0005434558439	9904	Comfort	47600.00
0005434826281	9904	Comfort	47600.00
0005434826661	9904	Comfort	47600.00
0005434826591	9904	Economy	28000.00
0005434826050	9904	Economy	28000.00
0005434825973	9904	Economy	28000.00
0005434826235	9904	Economy	28000.00
0005434826924	9904	Economy	28000.00
0005434826605	9904	Economy	28000.00
0005432396341	9904	Economy	28000.00
0005434826338	9904	Economy	28000.00
0005434825738	9904	Economy	28000.00
0005432396340	9904	Economy	28000.00
0005434826130	9904	Economy	28000.00
0005434826553	9904	Economy	28000.00
0005434826699	9904	Economy	28000.00
0005434558438	9904	Economy	28000.00
0005434826552	9904	Economy	28000.00
0005434826662	9904	Economy	28000.00
0005434831236	9904	Economy	28000.00
0005434826456	9904	Economy	28000.00
0005434826344	9904	Economy	28000.00
0005434826280	9904	Economy	28000.00
0005434826324	9904	Economy	28000.00
0005435150391	9904	Economy	28000.00
0005434826333	9904	Economy	28000.00
0005434826646	9904	Economy	28000.00
0005434826269	9904	Economy	28000.00
0005435735278	9904	Economy	28000.00
0005435150320	9904	Economy	28000.00
0005434826274	9904	Economy	28000.00
0005434831265	9904	Economy	28000.00
0005434826773	9904	Economy	28000.00
0005434826733	9904	Economy	28000.00
0005435375159	9904	Economy	28000.00
0005434826450	9904	Economy	28000.00
0005434828754	9904	Economy	28000.00
0005434826718	9904	Economy	28000.00
0005435375156	9904	Economy	30800.00
0005435315138	9904	Economy	28000.00
0005434826379	9904	Economy	30800.00
0005434825972	9904	Economy	28000.00
0005434826622	9904	Economy	28000.00
0005435150287	9904	Economy	28000.00
0005435375169	9904	Economy	30800.00
0005434826783	9904	Economy	28000.00
0005434825636	9904	Economy	28000.00
0005435315136	9904	Economy	28000.00
0005434826803	9904	Economy	28000.00
0005434826681	9904	Economy	28000.00
0005432396325	9904	Economy	28000.00
0005435150364	9904	Economy	28000.00
0005432396323	9904	Economy	28000.00
0005434826088	9904	Economy	28000.00
0005435375157	9904	Economy	28000.00
0005434826719	9904	Economy	28000.00
0005434826590	9904	Economy	28000.00
0005434826483	9904	Economy	28000.00
0005434826259	9904	Economy	28000.00
0005434826653	9904	Economy	28000.00
0005434558471	9904	Economy	28000.00
0005434826481	9904	Economy	28000.00
0005434826271	9904	Economy	28000.00
0005434826804	9904	Economy	28000.00
0005434826449	9904	Economy	28000.00
0005435375168	9904	Economy	28000.00
0005434826615	9904	Economy	28000.00
0005435150348	9904	Economy	28000.00
0005435315137	9904	Economy	28000.00
0005434826609	9904	Economy	28000.00
0005435150374	9904	Economy	28000.00
0005434826955	9904	Economy	28000.00
0005434831263	9904	Economy	28000.00
0005434827014	9904	Economy	28000.00
0005435150347	9904	Economy	28000.00
0005435150392	9904	Economy	28000.00
0005434828769	9904	Economy	28000.00
0005434826282	9904	Economy	28000.00
0005434826328	9904	Economy	28000.00
0005435375162	9904	Economy	28000.00
0005434826241	9904	Economy	28000.00
0005435375160	9904	Economy	28000.00
0005434825637	9904	Economy	28000.00
0005435150346	9904	Economy	28000.00
0005432396327	9904	Economy	28000.00
0005434831261	9904	Economy	28000.00
0005434826212	9904	Economy	28000.00
0005434826482	9904	Economy	28000.00
0005434558441	9904	Economy	28000.00
0005434825904	9904	Economy	28000.00
0005434826614	9904	Economy	28000.00
0005434826360	9904	Economy	28000.00
0005434825980	9904	Economy	28000.00
0005432396326	9904	Economy	28000.00
0005434826425	9904	Economy	28000.00
0005434826588	9904	Economy	28000.00
0005435150373	9904	Economy	28000.00
0005434826415	9904	Economy	28000.00
0005435375161	9904	Economy	28000.00
0005434826679	9904	Economy	28000.00
0005434826589	9904	Economy	28000.00
0005434826455	9904	Economy	28000.00
0005434826318	9904	Economy	28000.00
0005434826537	9904	Economy	30800.00
0005434828770	9904	Economy	30800.00
0005434827015	9904	Economy	28000.00
0005434558434	9904	Economy	28000.00
0005434826025	9904	Economy	28000.00
0005434826089	9904	Economy	28000.00
0005432400206	9904	Economy	28000.00
0005434831248	9904	Economy	28000.00
0005435375163	9904	Economy	28000.00
0005434826488	9904	Economy	28000.00
0005434558435	9904	Economy	28000.00
0005434826512	9904	Economy	28000.00
0005434826651	9904	Economy	28000.00
0005435375152	9904	Economy	28000.00
0005434828746	9904	Economy	28000.00
0005434826327	9904	Economy	28000.00
0005435375166	9904	Economy	28000.00
0005434826101	9904	Economy	28000.00
0005435375167	9904	Economy	28000.00
0005434826454	9904	Economy	28000.00
0005434826809	9904	Economy	28000.00
0005435375155	9904	Economy	28000.00
0005434826554	9904	Economy	28000.00
0005434826603	9904	Economy	28000.00
0005434826314	9904	Economy	28000.00
0005434826791	9904	Economy	28000.00
0005435375154	9904	Economy	28000.00
0005434826443	9904	Economy	28000.00
0005434826840	9904	Economy	28000.00
0005434826558	9904	Economy	28000.00
0005434825893	9904	Economy	28000.00
0005434827017	9904	Economy	28000.00
0005434826680	9904	Economy	28000.00
0005432400205	9904	Economy	28000.00
0005434826301	9904	Economy	28000.00
0005434826751	9904	Economy	28000.00
0005434826382	9904	Economy	28000.00
0005434828753	9904	Economy	28000.00
0005434826116	9904	Economy	28000.00
0005434831256	9904	Economy	28000.00
0005434826380	9904	Economy	28000.00
0005434826684	9904	Economy	28000.00
0005434826636	9904	Economy	28000.00
0005435375153	9904	Economy	28000.00
0005434826685	9904	Economy	28000.00
0005434831266	9904	Economy	28000.00
0005434826700	9904	Economy	28000.00
0005434826608	9904	Economy	28000.00
0005434826827	9904	Economy	28000.00
0005432396322	9904	Economy	28000.00
0005434828755	9904	Economy	28000.00
0005432396337	9904	Economy	28000.00
0005432400209	9904	Economy	28000.00
0005435375158	9904	Economy	28000.00
0005432823509	9904	Economy	28000.00
0005432823508	9904	Economy	28000.00
0005435150360	9904	Economy	28000.00
0005434826604	9904	Economy	28000.00
0005434826457	9904	Economy	28000.00
0005434826279	9904	Economy	28000.00
0005434827018	9904	Economy	28000.00
0005434826325	9904	Economy	28000.00
0005435083032	6976	Economy	8200.00
0005435083034	6976	Economy	7400.00
0005435083033	6976	Economy	7400.00
0005435082947	25973	Economy	8200.00
0005435082978	25973	Economy	7400.00
0005435082979	25973	Economy	7400.00
0005435082950	25973	Economy	7400.00
0005435082977	25973	Economy	7400.00
0005435082984	25973	Economy	7400.00
0005435082980	25973	Economy	7400.00
0005435082976	25973	Economy	7400.00
0005435790368	25973	Economy	7400.00
0005435082971	25973	Economy	7400.00
0005435082972	25973	Economy	7400.00
0005434215681	9570	Business	32800.00
0005434215534	9570	Business	32800.00
0005434215671	9570	Business	32800.00
0005434215607	9570	Business	32800.00
0005434757677	9570	Business	32800.00
0005434757676	9570	Business	32800.00
0005434215420	9570	Business	32800.00
0005434215395	9570	Business	32800.00
0005434215624	9570	Business	32800.00
0005434215568	9570	Business	32800.00
0005434215711	9570	Business	32800.00
0005434215623	9570	Economy	10900.00
0005434215690	9570	Economy	10900.00
0005434215427	9570	Economy	10900.00
0005434215480	9570	Economy	10900.00
0005434215460	9570	Economy	10900.00
0005434215647	9570	Economy	10900.00
0005434215594	9570	Economy	10900.00
0005434757678	9570	Economy	10900.00
0005434215526	9570	Economy	12000.00
0005434215593	9570	Economy	12000.00
0005434215669	9570	Economy	12000.00
0005434215508	9570	Economy	10900.00
0005434757680	9570	Economy	10900.00
0005434215559	9570	Economy	10900.00
0005434215586	9570	Economy	10900.00
0005434757682	9570	Economy	10900.00
0005434215502	9570	Economy	10900.00
0005434215610	9570	Economy	10900.00
0005434215509	9570	Economy	10900.00
0005434215609	9570	Economy	10900.00
0005434215562	9570	Economy	10900.00
0005434215507	9570	Economy	10900.00
0005434215426	9570	Economy	10900.00
0005434215585	9570	Economy	10900.00
0005434215606	9570	Economy	10900.00
0005434215537	9570	Economy	10900.00
0005434757675	9570	Economy	10900.00
0005434215597	9570	Economy	10900.00
0005434215672	9570	Economy	10900.00
0005434215653	9570	Economy	10900.00
0005434215327	9570	Economy	10900.00
0005434215459	9570	Economy	10900.00
0005434215538	9570	Economy	10900.00
0005434215495	9570	Economy	10900.00
0005434215528	9570	Economy	10900.00
0005434215522	9570	Economy	10900.00
0005434215415	9570	Economy	10900.00
0005434757681	9570	Economy	10900.00
0005434215560	9570	Economy	10900.00
0005434215467	9570	Economy	10900.00
0005434215396	9570	Economy	10900.00
0005434215645	9570	Economy	10900.00
0005434215561	9570	Economy	10900.00
0005434215414	9570	Economy	10900.00
0005434215646	9570	Economy	10900.00
0005434215627	9570	Economy	10900.00
0005434757683	9570	Economy	10900.00
0005434215572	9570	Economy	10900.00
0005434757679	9570	Economy	10900.00
0005434215654	9570	Economy	10900.00
0005434215523	9570	Economy	10900.00
0005434215527	9570	Economy	10900.00
0005434215503	9570	Economy	10900.00
0005434215626	9570	Economy	10900.00
0005434215712	9570	Economy	10900.00
0005434215524	9570	Economy	10900.00
0005434757435	28600	Business	32800.00
0005434757377	28600	Business	32800.00
0005434757265	28600	Business	32800.00
0005434757344	28600	Business	32800.00
0005434757141	28600	Business	32800.00
0005434215878	28600	Business	32800.00
0005434215874	28600	Business	32800.00
0005434757160	28600	Economy	10900.00
0005434757364	28600	Economy	10900.00
0005434757113	28600	Economy	10900.00
0005434757213	28600	Economy	10900.00
0005434215876	28600	Economy	10900.00
0005434757357	28600	Economy	10900.00
0005434757169	28600	Economy	12000.00
0005434215866	28600	Economy	12000.00
0005434757082	28600	Economy	12000.00
0005434757382	28600	Economy	10900.00
0005434757154	28600	Economy	10900.00
0005434757170	28600	Economy	10900.00
0005434757205	28600	Economy	10900.00
0005434757214	28600	Economy	10900.00
0005434215868	28600	Economy	10900.00
0005434757358	28600	Economy	10900.00
0005434757226	28600	Economy	10900.00
0005434757267	28600	Economy	10900.00
0005434215869	28600	Economy	10900.00
0005434757283	28600	Economy	10900.00
0005434215867	28600	Economy	10900.00
0005434757316	28600	Economy	10900.00
0005434757433	28600	Economy	10900.00
0005434757376	28600	Economy	10900.00
0005434757363	28600	Economy	10900.00
0005434757307	28600	Economy	10900.00
0005434757430	28600	Economy	10900.00
0005434215872	28600	Economy	10900.00
0005434757111	28600	Economy	10900.00
0005434757368	28600	Economy	10900.00
0005434757161	28600	Economy	10900.00
0005434215877	28600	Economy	10900.00
0005434757130	28600	Economy	10900.00
0005434757315	28600	Economy	10900.00
0005434757244	28600	Economy	10900.00
0005434215873	28600	Economy	10900.00
0005434757266	28600	Economy	10900.00
0005434215871	28600	Economy	10900.00
0005434757434	28600	Economy	10900.00
0005434215875	28600	Economy	10900.00
0005434757297	28600	Economy	10900.00
0005434757383	28600	Economy	10900.00
0005434757353	28600	Economy	10900.00
0005434757367	28600	Economy	10900.00
0005434757555	28600	Economy	10900.00
0005434757097	28600	Economy	10900.00
0005434215870	28600	Economy	10900.00
0005434757352	28600	Economy	10900.00
0005434757372	28600	Economy	10900.00
0005434757114	28600	Economy	10900.00
0005434215865	28600	Economy	10900.00
0005434757083	28600	Economy	10900.00
0005434757275	28600	Economy	10900.00
0005434760253	10845	Economy	8900.00
0005434760251	10845	Economy	8900.00
0005434760248	10845	Economy	8900.00
0005434760240	10845	Economy	8900.00
0005434760246	10845	Economy	8900.00
0005434760247	10845	Economy	8900.00
0005434760252	10845	Economy	8900.00
0005435100204	31819	Economy	8900.00
0005435100187	31819	Economy	8900.00
0005435100186	31819	Economy	8900.00
0005434760267	31819	Economy	8900.00
0005433202703	2008	Economy	20900.00
0005434640101	2008	Economy	19000.00
0005433202732	2008	Economy	19000.00
0005433202647	2008	Economy	19000.00
0005433202757	2008	Economy	19000.00
0005434640100	2008	Economy	19000.00
0005435948364	2008	Economy	19000.00
0005435948365	2008	Economy	19000.00
0005433202733	2008	Economy	19000.00
0005433202645	2008	Economy	19000.00
0005433202692	2008	Economy	19000.00
0005435948366	2008	Economy	19000.00
0005433202670	2008	Economy	19000.00
0005433202671	2008	Economy	19000.00
0005433202756	2008	Economy	19000.00
0005434640098	2008	Economy	19000.00
0005433202686	2008	Economy	19000.00
0005434640097	2008	Economy	19000.00
0005433202622	2008	Economy	19000.00
0005433202689	2008	Economy	19000.00
0005433202690	2008	Economy	19000.00
0005433202688	2008	Economy	19000.00
0005434640099	2008	Economy	19000.00
0005433202646	2008	Economy	19000.00
0005434640096	2008	Economy	19000.00
0005433202649	2008	Economy	19000.00
0005433202786	23267	Economy	20900.00
0005434639890	23267	Economy	20900.00
0005434639856	23267	Economy	20900.00
0005434639897	23267	Economy	19000.00
0005434639899	23267	Economy	19000.00
0005434639814	23267	Economy	19000.00
0005433202787	23267	Economy	19000.00
0005434639846	23267	Economy	19000.00
0005434639916	23267	Economy	19000.00
0005434639815	23267	Economy	19000.00
0005434639843	23267	Economy	19000.00
0005434639933	23267	Economy	19000.00
0005434639779	23267	Economy	19000.00
0005434639959	23267	Economy	19000.00
0005434639972	23267	Economy	19000.00
0005434639782	23267	Economy	19000.00
0005433202788	23267	Economy	19000.00
0005434639772	23267	Economy	19000.00
0005434639844	23267	Economy	19000.00
0005434639802	23267	Economy	19000.00
0005434639845	23267	Economy	19000.00
0005434639771	23267	Economy	19000.00
0005434639913	23267	Economy	19000.00
0005434640006	23267	Economy	19000.00
0005434639798	23267	Economy	19000.00
0005434639967	23267	Economy	19000.00
0005434639888	23267	Economy	19000.00
0005434639893	23267	Economy	19000.00
0005434639958	23267	Economy	19000.00
0005434639900	23267	Economy	19000.00
0005434639777	23267	Economy	19000.00
0005434639892	23267	Economy	19000.00
0005434639889	23267	Economy	19000.00
0005434639898	23267	Economy	19000.00
0005434639932	23267	Economy	19000.00
0005434601587	6081	Business	69700.00
0005435327045	6081	Business	69700.00
0005435327084	6081	Business	69700.00
0005435327085	6081	Economy	25600.00
0005433533421	6081	Economy	25600.00
0005434601586	6081	Economy	23200.00
0005435327063	6081	Economy	23200.00
0005435327014	6081	Economy	23200.00
0005435327080	6081	Economy	23200.00
0005433533422	6081	Economy	23200.00
0005434601585	6081	Economy	23200.00
0005435327089	6081	Economy	23200.00
0005434601588	6081	Economy	23200.00
0005435327046	6081	Economy	23200.00
0005434601589	6081	Economy	23200.00
0005435327016	6081	Economy	23200.00
0005435327064	6081	Economy	23200.00
0005435327015	6081	Economy	23200.00
0005435327074	6081	Economy	23200.00
0005434601409	18561	Business	69700.00
0005433527328	18561	Business	69700.00
0005435327139	18561	Business	69700.00
0005433527350	18561	Business	69700.00
0005434601423	18561	Economy	23200.00
0005434601325	18561	Economy	23200.00
0005434601486	18561	Economy	23200.00
0005433527342	18561	Economy	25600.00
0005435327138	18561	Economy	25600.00
0005434601382	18561	Economy	23200.00
0005433527349	18561	Economy	23200.00
0005434601410	18561	Economy	23200.00
0005434601487	18561	Economy	23200.00
0005434601356	18561	Economy	23200.00
0005434601326	18561	Economy	23200.00
0005433531379	18561	Economy	23200.00
0005434601505	18561	Economy	23200.00
0005434601357	18561	Economy	23200.00
0005434601424	18561	Economy	23200.00
0005434601370	18561	Economy	23200.00
0005435327141	18561	Economy	23200.00
0005434601506	18561	Economy	23200.00
0005435327140	18561	Economy	23200.00
0005433527341	18561	Economy	23200.00
0005434558596	10624	Business	9100.00
0005433181700	10624	Business	9100.00
0005435314959	10624	Business	9100.00
0005434552834	10624	Business	9100.00
0005435314991	10624	Business	9100.00
0005435314958	10624	Business	9100.00
0005435314977	10624	Business	9100.00
0005434558590	10624	Business	9100.00
0005434552836	10624	Business	9100.00
0005434552828	10624	Business	9100.00
0005435315026	10624	Business	9100.00
0005434558586	10624	Business	9100.00
0005434558600	10624	Economy	3000.00
0005434558597	10624	Economy	3000.00
0005435315033	10624	Economy	3000.00
0005433181635	10624	Economy	3000.00
0005435315025	10624	Economy	3000.00
0005435315012	10624	Economy	3000.00
0005434552838	10624	Economy	3000.00
0005433181674	10624	Economy	3000.00
0005433181669	10624	Economy	3000.00
0005433181631	10624	Economy	3000.00
0005433181670	10624	Economy	3300.00
0005433181570	10624	Economy	3300.00
0005434558582	10624	Economy	3300.00
0005435314992	10624	Economy	3300.00
0005435314955	10624	Economy	3300.00
0005435315032	10624	Economy	3000.00
0005433181639	10624	Economy	3000.00
0005433181625	10624	Economy	3000.00
0005433181658	10624	Economy	3000.00
0005433181634	10624	Economy	3000.00
0005433181692	10624	Economy	3000.00
0005434558599	10624	Economy	3000.00
0005433181686	10624	Economy	3000.00
0005434558585	10624	Economy	3000.00
0005435314978	10624	Economy	3000.00
0005435314963	10624	Economy	3000.00
0005433181675	10624	Economy	3000.00
0005434558588	10624	Economy	3000.00
0005434558601	10624	Economy	3000.00
0005434552831	10624	Economy	3000.00
0005434552833	10624	Economy	3000.00
0005434552837	10624	Economy	3000.00
0005435314962	10624	Economy	3000.00
0005433181657	10624	Economy	3000.00
0005435314990	10624	Economy	3000.00
0005435314998	10624	Economy	3000.00
0005433181577	10624	Economy	3000.00
0005433181569	10624	Economy	3000.00
0005434558603	10624	Economy	3000.00
0005434558584	10624	Economy	3000.00
0005435315024	10624	Economy	3000.00
0005433181774	10624	Economy	3000.00
0005433181613	10624	Economy	3000.00
0005434552829	10624	Economy	3000.00
0005434558587	10624	Economy	3000.00
0005435314989	10624	Economy	3000.00
0005435315027	10624	Economy	3000.00
0005433181775	10624	Economy	3000.00
0005435314995	10624	Economy	3000.00
0005434552825	10624	Economy	3000.00
0005434558602	10624	Economy	3000.00
0005435315041	10624	Economy	3000.00
0005435314975	10624	Economy	3000.00
0005433181612	10624	Economy	3000.00
0005434558589	10624	Economy	3000.00
0005434552839	10624	Economy	3000.00
0005433181661	10624	Economy	3000.00
0005433181668	10624	Economy	3000.00
0005435314988	10624	Economy	3000.00
0005433181648	10624	Economy	3000.00
0005434552823	10624	Economy	3000.00
0005434552826	10624	Economy	3000.00
0005434552827	10624	Economy	3000.00
0005434558598	10624	Economy	3000.00
0005434552832	10624	Economy	3000.00
0005433181593	10624	Economy	3000.00
0005433181576	10624	Economy	3000.00
0005433181568	10624	Economy	3000.00
0005433181640	10624	Economy	3000.00
0005434558594	10624	Economy	3000.00
0005434558583	10624	Economy	3000.00
0005434552830	10624	Economy	3000.00
0005434552842	10624	Economy	3000.00
0005434552824	10624	Economy	3000.00
0005435314965	10624	Economy	3000.00
0005434558591	10624	Economy	3000.00
0005433181730	10624	Economy	3000.00
0005434552835	10624	Economy	3000.00
0005433181724	10624	Economy	3000.00
0005434558595	10624	Economy	3000.00
0005434558592	10624	Economy	3000.00
0005434558593	10624	Economy	3000.00
0005434552841	10624	Economy	3000.00
0005434757696	10624	Economy	3000.00
0005434552840	10624	Economy	3000.00
0005433181834	27747	Business	9100.00
0005433181832	27747	Business	9100.00
0005433181836	27747	Economy	3000.00
0005435315138	27747	Economy	3000.00
0005435315137	27747	Economy	3000.00
0005433181835	27747	Economy	3000.00
0005435315136	27747	Economy	3000.00
0005433181833	27747	Economy	3000.00
0005433181837	27747	Economy	3000.00
0005434552355	27748	Business	9100.00
0005434552541	27748	Business	9100.00
0005434552504	27748	Business	9100.00
0005434552519	27748	Business	9100.00
0005434552691	27748	Business	9100.00
0005434552500	27748	Business	9100.00
0005434552331	27748	Business	9100.00
0005434552657	27748	Economy	3000.00
0005434552477	27748	Economy	3000.00
0005434552491	27748	Economy	3000.00
0005434558458	27748	Economy	3000.00
0005434552576	27748	Economy	3000.00
0005434552453	27748	Economy	3300.00
0005434558469	27748	Economy	3300.00
0005434558467	27748	Economy	3300.00
0005434552556	27748	Economy	3000.00
0005434552463	27748	Economy	3000.00
0005434552511	27748	Economy	3000.00
0005434552310	27748	Economy	3000.00
0005434552473	27748	Economy	3000.00
0005434558495	27748	Economy	3000.00
0005434552309	27748	Economy	3000.00
0005434552603	27748	Economy	3000.00
0005434558496	27748	Economy	3000.00
0005434558491	27748	Economy	3000.00
0005434552360	27748	Economy	3000.00
0005434552570	27748	Economy	3000.00
0005434552717	27748	Economy	3000.00
0005434552510	27748	Economy	3000.00
0005434552451	27748	Economy	3000.00
0005434558470	27748	Economy	3000.00
0005434552452	27748	Economy	3000.00
0005434552716	27748	Economy	3000.00
0005434552421	27748	Economy	3000.00
0005434552470	27748	Economy	3000.00
0005434552419	27748	Economy	3000.00
0005434558464	27748	Economy	3000.00
0005434552343	27748	Economy	3000.00
0005434558459	27748	Economy	3000.00
0005434558457	27748	Economy	3000.00
0005434558465	27748	Economy	3000.00
0005434552715	27748	Economy	3000.00
0005434552701	27748	Economy	3000.00
0005434552656	27748	Economy	3000.00
0005434552575	27748	Economy	3000.00
0005434552530	27748	Economy	3000.00
0005434552661	27748	Economy	3000.00
0005434552253	27748	Economy	3000.00
0005434552702	27748	Economy	3000.00
0005434552420	27748	Economy	3000.00
0005434552308	27748	Economy	3000.00
0005434558466	27748	Economy	3000.00
0005434558494	27748	Economy	3000.00
0005434552354	27748	Economy	3000.00
0005434552505	27748	Economy	3000.00
0005434552626	27748	Economy	3000.00
0005434552361	27748	Economy	3000.00
0005434552252	27748	Economy	3000.00
0005434552475	27748	Economy	3000.00
0005434552602	27748	Economy	3000.00
0005434558461	27748	Economy	3000.00
0005434552574	27748	Economy	3000.00
0005435254534	6141	Economy	11700.00
0005435254526	6141	Economy	11700.00
0005433459346	6141	Economy	11700.00
0005435254536	6141	Economy	11700.00
0005433459347	6141	Economy	11700.00
0005435254521	6141	Economy	11700.00
0005433459344	6141	Economy	11700.00
0005433459345	6141	Economy	11700.00
0005435254535	6141	Economy	11700.00
0005433459310	19320	Economy	11700.00
0005433459308	19320	Economy	11700.00
0005433459329	19320	Economy	11700.00
0005433459330	19320	Economy	11700.00
0005433459328	19320	Economy	11700.00
0005433459309	19320	Economy	11700.00
0005433459327	19320	Economy	11700.00
0005433459321	19320	Economy	11700.00
0005435683326	6760	Business	51100.00
0005435438492	6760	Business	51100.00
0005435220369	6760	Business	51100.00
0005435662014	6760	Economy	17000.00
0005432533357	6760	Economy	17000.00
0005435438397	6760	Economy	17000.00
0005432533349	6760	Economy	17000.00
0005435438441	6760	Economy	18700.00
0005435683329	6760	Economy	17000.00
0005435438511	6760	Economy	17000.00
0005434828766	6760	Economy	17000.00
0005434828765	6760	Economy	17000.00
0005435662013	6760	Economy	17000.00
0005435683321	6760	Economy	17000.00
0005435438440	6760	Economy	17000.00
0005435683327	6760	Economy	17000.00
0005435683325	6760	Economy	17000.00
0005432533350	6760	Economy	17000.00
0005435438514	6760	Economy	17000.00
0005435683320	6760	Economy	17000.00
0005435220368	6760	Economy	17000.00
0005435221532	6760	Economy	17000.00
0005435438513	6760	Economy	17000.00
0005432533346	6760	Economy	17000.00
0005435683328	6760	Economy	17000.00
0005435438464	6760	Economy	17000.00
0005435438465	6760	Economy	17000.00
0005435438412	6760	Economy	17000.00
0005435438478	6760	Economy	17000.00
0005435438493	6760	Economy	17000.00
0005434828747	6760	Economy	17000.00
0005435790416	6760	Economy	17000.00
0005435438518	6760	Economy	17000.00
0005435683324	6760	Economy	17000.00
0005434828764	6760	Economy	17000.00
0005435220374	6760	Economy	17000.00
0005435683323	6760	Economy	17000.00
0005435683322	6760	Economy	17000.00
0005435438407	6760	Economy	17000.00
0005435683107	24598	Business	51100.00
0005432533378	24598	Business	51100.00
0005435683138	24598	Business	51100.00
0005435661999	24598	Business	51100.00
0005435683095	24598	Business	51100.00
0005435682952	24598	Business	51100.00
0005435683063	24598	Business	51100.00
0005435438587	24598	Economy	17000.00
0005435662000	24598	Economy	17000.00
0005435683172	24598	Economy	17000.00
0005435661981	24598	Economy	17000.00
0005435683084	24598	Economy	17000.00
0005435683216	24598	Economy	18700.00
0005435683123	24598	Economy	17000.00
0005435682920	24598	Economy	17000.00
0005435682994	24598	Economy	17000.00
0005435683130	24598	Economy	17000.00
0005435683056	24598	Economy	17000.00
0005432533377	24598	Economy	17000.00
0005435683083	24598	Economy	17000.00
0005435683182	24598	Economy	17000.00
0005435683077	24598	Economy	17000.00
0005435683055	24598	Economy	17000.00
0005435683163	24598	Economy	17000.00
0005435683103	24598	Economy	17000.00
0005435682980	24598	Economy	17000.00
0005435683132	24598	Economy	17000.00
0005435682959	24598	Economy	17000.00
0005435682839	24598	Economy	17000.00
0005435682995	24598	Economy	17000.00
0005435683212	24598	Economy	17000.00
0005435661991	24598	Economy	17000.00
0005435683040	24598	Economy	17000.00
0005435682953	24598	Economy	17000.00
0005435683118	24598	Economy	17000.00
0005435683081	24598	Economy	17000.00
0005435719591	24598	Economy	17000.00
0005435438586	24598	Economy	17000.00
0005435683139	24598	Economy	17000.00
0005435683122	24598	Economy	17000.00
0005435683082	24598	Economy	17000.00
0005435682979	24598	Economy	17000.00
0005435683169	24598	Economy	17000.00
0005435682921	24598	Economy	17000.00
0005435683062	24598	Economy	17000.00
0005435654512	24598	Economy	17000.00
0005435661990	24598	Economy	17000.00
0005435720854	24598	Economy	17000.00
0005435683168	24598	Economy	17000.00
0005435683131	24598	Economy	17000.00
0005435682770	24598	Economy	17000.00
0005435683039	24598	Economy	17000.00
0005435720853	24598	Economy	17000.00
0005435683207	24598	Economy	17000.00
0005435683166	24598	Economy	17000.00
0005435127556	11504	Business	26400.00
0005435127565	11504	Business	26400.00
0005435106073	11504	Business	26400.00
0005435127568	11504	Economy	8800.00
0005435127563	11504	Economy	8800.00
0005435127561	11504	Economy	8800.00
0005435127554	11504	Economy	9700.00
0005435127552	11504	Economy	8800.00
0005435127567	11504	Economy	8800.00
0005435127557	11504	Economy	8800.00
0005435127566	11504	Economy	8800.00
0005435106072	11504	Economy	8800.00
0005435127562	11504	Economy	8800.00
0005435127564	11504	Economy	8800.00
0005435127555	11504	Economy	8800.00
0005435558144	11504	Economy	8800.00
0005435127559	11504	Economy	8800.00
0005435127558	11504	Economy	8800.00
0005435127560	11504	Economy	8800.00
0005435127553	11504	Economy	8800.00
0005435127285	31899	Business	26400.00
0005435127313	31899	Business	26400.00
0005435127327	31899	Business	26400.00
0005435127321	31899	Business	26400.00
0005435127464	31899	Business	26400.00
0005435127288	31899	Business	26400.00
0005435127262	31899	Economy	8800.00
0005435127364	31899	Economy	8800.00
0005435127388	31899	Economy	8800.00
0005435106057	31899	Economy	8800.00
0005435127379	31899	Economy	8800.00
0005435127322	31899	Economy	9700.00
0005435127122	31899	Economy	9700.00
0005435127387	31899	Economy	8800.00
0005435098607	31899	Economy	8800.00
0005435127274	31899	Economy	8800.00
0005435127287	31899	Economy	8800.00
0005435127465	31899	Economy	8800.00
0005435127357	31899	Economy	8800.00
0005435127132	31899	Economy	8800.00
0005435127330	31899	Economy	8800.00
0005435127462	31899	Economy	8800.00
0005435127356	31899	Economy	8800.00
0005435127366	31899	Economy	8800.00
0005435127271	31899	Economy	8800.00
0005435127328	31899	Economy	8800.00
0005435106062	31899	Economy	8800.00
0005435127016	31899	Economy	8800.00
0005435106058	31899	Economy	8800.00
0005435098606	31899	Economy	8800.00
0005435127215	31899	Economy	8800.00
0005435098605	31899	Economy	8800.00
0005435127158	31899	Economy	8800.00
0005435127312	31899	Economy	8800.00
0005435127214	31899	Economy	8800.00
0005435127286	31899	Economy	8800.00
0005435127280	31899	Economy	8800.00
0005435127131	31899	Economy	8800.00
0005435106056	31899	Economy	8800.00
0005435127378	31899	Economy	8800.00
0005435127489	31899	Economy	8800.00
0005435127351	31899	Economy	8800.00
0005435106054	31899	Economy	8800.00
0005435127320	31899	Economy	8800.00
0005435127123	31899	Economy	8800.00
0005435732630	13516	Business	36600.00
0005433399455	13516	Economy	12200.00
0005433399460	13516	Economy	12200.00
0005433399463	13516	Economy	13400.00
0005433399454	13516	Economy	12200.00
0005433399462	13516	Economy	12200.00
0005435732582	13516	Economy	12200.00
0005435732656	13516	Economy	12200.00
0005435732634	13516	Economy	12200.00
0005433399456	13516	Economy	12200.00
0005435732611	13516	Economy	12200.00
0005433399459	13516	Economy	12200.00
0005435732664	13516	Economy	12200.00
0005433399461	13516	Economy	12200.00
0005435732663	13516	Economy	12200.00
0005435732684	13516	Economy	12200.00
0005433399458	13516	Economy	12200.00
0005435732685	13516	Economy	12200.00
0005435732636	13516	Economy	12200.00
0005435732653	13516	Economy	12200.00
0005433399457	13516	Economy	12200.00
0005435732635	13516	Economy	12200.00
0005433399246	19375	Business	36600.00
0005435725781	19375	Business	36600.00
0005432297353	19375	Business	36600.00
0005433398987	19375	Business	36600.00
0005435732722	19375	Business	36600.00
0005433399157	19375	Economy	12200.00
0005435725784	19375	Economy	12200.00
0005435732720	19375	Economy	12200.00
0005433399292	19375	Economy	12200.00
0005433399083	19375	Economy	12200.00
0005433398989	19375	Economy	12200.00
0005435732721	19375	Economy	12200.00
0005433399143	19375	Economy	13400.00
0005433399156	19375	Economy	13400.00
0005435732717	19375	Economy	12200.00
0005433399207	19375	Economy	12200.00
0005433399181	19375	Economy	12200.00
0005433399191	19375	Economy	12200.00
0005433399294	19375	Economy	12200.00
0005433399208	19375	Economy	12200.00
0005433398877	19375	Economy	12200.00
0005433399131	19375	Economy	12200.00
0005433399377	19375	Economy	12200.00
0005433399096	19375	Economy	12200.00
0005433399285	19375	Economy	12200.00
0005435725785	19375	Economy	12200.00
0005433399082	19375	Economy	12200.00
0005433399188	19375	Economy	12200.00
0005433399095	19375	Economy	12200.00
0005433399259	19375	Economy	12200.00
0005435725782	19375	Economy	12200.00
0005433398988	19375	Economy	12200.00
0005433399072	19375	Economy	12200.00
0005433399215	19375	Economy	12200.00
0005433399335	19375	Economy	12200.00
0005435725783	19375	Economy	12200.00
0005433399268	19375	Economy	12200.00
0005433399177	19375	Economy	12200.00
0005433398980	19375	Economy	12200.00
0005433399148	19375	Economy	12200.00
0005433399293	19375	Economy	12200.00
0005433399248	19375	Economy	12200.00
0005433399155	19375	Economy	12200.00
0005433399263	19375	Economy	12200.00
0005433399249	19375	Economy	12200.00
0005435732718	19375	Economy	12200.00
0005433399216	19375	Economy	12200.00
0005433399108	19375	Economy	12200.00
0005435732719	19375	Economy	12200.00
0005433398979	19375	Economy	12200.00
0005433399190	19375	Economy	12200.00
0005433399334	19375	Economy	12200.00
0005435725780	19375	Economy	12200.00
0005433399133	19375	Economy	12200.00
0005435070405	13180	Business	11300.00
0005435070343	13180	Business	11300.00
0005435070491	13180	Business	11300.00
0005435070365	13180	Business	11300.00
0005435070184	13180	Business	11300.00
0005435070303	13180	Business	11300.00
0005435070174	13180	Business	11300.00
0005435070395	13180	Business	11300.00
0005435070159	13180	Business	11300.00
0005435925714	13180	Economy	3800.00
0005435070492	13180	Economy	3800.00
0005435070200	13180	Economy	3800.00
0005435070146	13180	Economy	3800.00
0005435925715	13180	Economy	3800.00
0005435070264	13180	Economy	3800.00
0005435070196	13180	Economy	3800.00
0005435070232	13180	Economy	3800.00
0005435070254	13180	Economy	4100.00
0005435070369	13180	Economy	4100.00
0005435925719	13180	Economy	4100.00
0005435925716	13180	Economy	4100.00
0005435070202	13180	Economy	3800.00
0005435070195	13180	Economy	3800.00
0005435925713	13180	Economy	3800.00
0005435070355	13180	Economy	3800.00
0005435070357	13180	Economy	3800.00
0005435070354	13180	Economy	3800.00
0005435070204	13180	Economy	3800.00
0005435070344	13180	Economy	3800.00
0005435070356	13180	Economy	3800.00
0005435070167	13180	Economy	3800.00
0005435925711	13180	Economy	3800.00
0005435070191	13180	Economy	3800.00
0005435925717	13180	Economy	3800.00
0005435070007	13180	Economy	3800.00
0005435070322	13180	Economy	3800.00
0005435070173	13180	Economy	3800.00
0005435070165	13180	Economy	3800.00
0005435070418	13180	Economy	3800.00
0005435070368	13180	Economy	3800.00
0005435070384	13180	Economy	3800.00
0005435070183	13180	Economy	3800.00
0005435070310	13180	Economy	3800.00
0005435070490	13180	Economy	3800.00
0005435070396	13180	Economy	3800.00
0005435070242	13180	Economy	3800.00
0005435070323	13180	Economy	3800.00
0005435070199	13180	Economy	3800.00
0005435070334	13180	Economy	3800.00
0005435070168	13180	Economy	3800.00
0005435070235	13180	Economy	3800.00
0005435070241	13180	Economy	3800.00
0005435070201	13180	Economy	3800.00
0005435070333	13180	Economy	3800.00
0005435070283	13180	Economy	3800.00
0005435070203	13180	Economy	3800.00
0005435925712	13180	Economy	3800.00
0005435925718	13180	Economy	3800.00
0005435070255	13180	Economy	3800.00
0005435070143	13180	Economy	3800.00
0005435070489	13180	Economy	3800.00
0005435070015	13180	Economy	3800.00
0005435070544	15502	Business	11300.00
0005435925572	15502	Business	11300.00
0005435070549	15502	Business	11300.00
0005435070542	15502	Economy	3800.00
0005435925583	15502	Economy	3800.00
0005435925569	15502	Economy	3800.00
0005435925649	15502	Economy	3800.00
0005435070543	15502	Economy	3800.00
0005435925590	15502	Economy	4100.00
0005435925635	15502	Economy	4100.00
0005435070539	15502	Economy	4100.00
0005435070546	15502	Economy	3800.00
0005435070541	15502	Economy	3800.00
0005435925570	15502	Economy	3800.00
0005435925536	15502	Economy	3800.00
0005435070547	15502	Economy	3800.00
0005435070548	15502	Economy	3800.00
0005435925619	15502	Economy	3800.00
0005435070545	15502	Economy	3800.00
0005435925643	15502	Economy	3800.00
0005435925625	15502	Economy	3800.00
0005435925578	15502	Economy	3800.00
0005435925585	15502	Economy	3800.00
0005435925614	15502	Economy	3800.00
0005435070540	15502	Economy	3800.00
0005435925584	15502	Economy	3800.00
0005435925615	15502	Economy	3800.00
0005433407665	23196	Economy	24700.00
0005435808513	23196	Economy	24700.00
0005433407679	23196	Economy	24700.00
0005433407647	23196	Economy	24700.00
0005435808522	23196	Economy	24700.00
0005433407655	23196	Economy	24700.00
0005433407672	23196	Economy	24700.00
0005433407681	23196	Economy	24700.00
0005433407677	23196	Economy	24700.00
0005433407678	23196	Economy	24700.00
0005435808520	23196	Economy	24700.00
0005433407680	23196	Economy	24700.00
0005435808517	23196	Economy	24700.00
0005433407653	23196	Economy	24700.00
0005435808521	23196	Economy	24700.00
0005433407661	23196	Economy	24700.00
0005433407667	23196	Economy	24700.00
0005435808525	23196	Economy	24700.00
0005433407662	23196	Economy	24700.00
0005435808514	23196	Economy	24700.00
0005435808516	23196	Economy	24700.00
0005435808519	23196	Economy	24700.00
0005433407676	23196	Economy	24700.00
0005435808512	23196	Economy	24700.00
0005435808515	23196	Economy	24700.00
0005435808524	23196	Economy	24700.00
0005435808518	23196	Economy	24700.00
0005435808523	23196	Economy	24700.00
0005433407654	23196	Economy	24700.00
0005433407671	23196	Economy	24700.00
0005433407689	23196	Economy	24700.00
0005434757396	10727	Business	61300.00
0005434215887	10727	Business	61300.00
0005434215882	10727	Business	61300.00
0005434757390	10727	Business	61300.00
0005434757518	10727	Business	61300.00
0005434757277	10727	Business	61300.00
0005434757445	10727	Business	61300.00
0005434757180	10727	Business	61300.00
0005434757414	10727	Business	61300.00
0005434215883	10727	Business	61300.00
0005434757324	10727	Business	61300.00
0005434757371	10727	Business	61300.00
0005434757340	10727	Economy	20400.00
0005434757424	10727	Economy	20400.00
0005434757416	10727	Economy	20400.00
0005434215888	10727	Economy	20400.00
0005434215885	10727	Economy	20400.00
0005434215893	10727	Economy	20400.00
0005434757280	10727	Economy	20400.00
0005434757206	10727	Economy	22500.00
0005434757394	10727	Economy	22500.00
0005434757341	10727	Economy	22500.00
0005434757195	10727	Economy	22500.00
0005434215884	10727	Economy	22500.00
0005434215880	10727	Economy	20400.00
0005434757511	10727	Economy	20400.00
0005434757491	10727	Economy	20400.00
0005434756996	10727	Economy	20400.00
0005434757207	10727	Economy	20400.00
0005434757391	10727	Economy	20400.00
0005434215879	10727	Economy	20400.00
0005434215894	10727	Economy	20400.00
0005434215886	10727	Economy	20400.00
0005434757348	10727	Economy	20400.00
0005434757395	10727	Economy	20400.00
0005434757370	10727	Economy	20400.00
0005434757392	10727	Economy	20400.00
0005434757375	10727	Economy	20400.00
0005434757137	10727	Economy	20400.00
0005434757342	10727	Economy	20400.00
0005434215892	10727	Economy	20400.00
0005434215891	10727	Economy	20400.00
0005434757413	10727	Economy	20400.00
0005434757449	10727	Economy	20400.00
0005434215881	10727	Economy	20400.00
0005434757460	10727	Economy	20400.00
0005434757362	10727	Economy	20400.00
0005434757246	10727	Economy	20400.00
0005434757360	10727	Economy	20400.00
0005434215890	10727	Economy	20400.00
0005434757510	10727	Economy	20400.00
0005434757136	10727	Economy	20400.00
0005434757208	10727	Economy	20400.00
0005434757444	10727	Economy	20400.00
0005434757279	10727	Economy	20400.00
0005434757415	10727	Economy	20400.00
0005434757388	10727	Economy	20400.00
0005434757373	10727	Economy	20400.00
0005434215889	10727	Economy	20400.00
0005434757150	10727	Economy	20400.00
0005434757537	10727	Economy	20400.00
0005434757426	10727	Economy	20400.00
0005434757245	10727	Economy	20400.00
0005434757417	10727	Economy	20400.00
0005434757429	10727	Economy	20400.00
0005434757425	10727	Economy	20400.00
0005434757369	10727	Economy	20400.00
0005434757407	10727	Economy	20400.00
0005434757227	10727	Economy	20400.00
0005434215374	28702	Business	61300.00
0005434215691	28702	Business	61300.00
0005434215580	28702	Business	61300.00
0005434215349	28702	Business	61300.00
0005434757663	28702	Business	61300.00
0005434757658	28702	Business	61300.00
0005434757667	28702	Economy	20400.00
0005434215382	28702	Economy	20400.00
0005434215413	28702	Economy	20400.00
0005434215398	28702	Economy	20400.00
0005434215551	28702	Economy	20400.00
0005434757655	28702	Economy	20400.00
0005434757666	28702	Economy	20400.00
0005434215375	28702	Economy	20400.00
0005434215514	28702	Economy	22500.00
0005434215670	28702	Economy	22500.00
0005434215323	28702	Economy	22500.00
0005434757670	28702	Economy	22500.00
0005434215668	28702	Economy	20400.00
0005434215511	28702	Economy	20400.00
0005434215510	28702	Economy	20400.00
0005434215486	28702	Economy	20400.00
0005434757671	28702	Economy	20400.00
0005434215497	28702	Economy	20400.00
0005434215368	28702	Economy	20400.00
0005434757660	28702	Economy	20400.00
0005434215614	28702	Economy	20400.00
0005434215589	28702	Economy	20400.00
0005434215354	28702	Economy	20400.00
0005434215578	28702	Economy	20400.00
0005434215600	28702	Economy	20400.00
0005434215476	28702	Economy	20400.00
0005434757669	28702	Economy	20400.00
0005434215315	28702	Economy	20400.00
0005434215601	28702	Economy	20400.00
0005434757665	28702	Economy	20400.00
0005434757672	28702	Economy	20400.00
0005434757656	28702	Economy	20400.00
0005434215532	28702	Economy	20400.00
0005434757674	28702	Economy	20400.00
0005434215555	28702	Economy	20400.00
0005434215693	28702	Economy	20400.00
0005434215539	28702	Economy	20400.00
0005434757659	28702	Economy	20400.00
0005434757664	28702	Economy	20400.00
0005434215488	28702	Economy	20400.00
0005434215515	28702	Economy	20400.00
0005434757673	28702	Economy	20400.00
0005434757662	28702	Economy	20400.00
0005434215598	28702	Economy	20400.00
0005434215333	28702	Economy	20400.00
0005434757654	28702	Economy	20400.00
0005434215498	28702	Economy	20400.00
0005434215613	28702	Economy	20400.00
0005434215521	28702	Economy	20400.00
0005434757668	28702	Economy	20400.00
0005434757657	28702	Economy	20400.00
0005434215494	28702	Economy	20400.00
0005434215552	28702	Economy	20400.00
0005434215463	28702	Economy	20400.00
0005434215397	28702	Economy	20400.00
0005434757661	28702	Economy	20400.00
0005434215579	28702	Economy	20400.00
0005434215584	28702	Economy	20400.00
0005434215535	28702	Economy	20400.00
0005434215341	28702	Economy	20400.00
0005434215536	28702	Economy	20400.00
0005434215324	28702	Economy	20400.00
0005435041679	5444	Business	29500.00
0005435041687	5444	Business	29500.00
0005435377917	5444	Business	29500.00
0005435042939	5444	Business	29500.00
0005435007717	5444	Business	29500.00
0005435041681	5444	Business	29500.00
0005432125662	5444	Business	29500.00
0005434229864	5444	Business	29500.00
0005434229865	5444	Economy	9800.00
0005435041668	5444	Economy	9800.00
0005435041685	5444	Economy	9800.00
0005435041682	5444	Economy	9800.00
0005434229945	5444	Economy	9800.00
0005435041672	5444	Economy	9800.00
0005435041684	5444	Economy	9800.00
0005434229899	5444	Economy	9800.00
0005435007715	5444	Economy	9800.00
0005435041686	5444	Economy	9800.00
0005435041677	5444	Economy	9800.00
0005435041688	5444	Economy	9800.00
0005435041683	5444	Economy	9800.00
0005434229950	5444	Economy	9800.00
0005434229952	5444	Economy	9800.00
0005435041678	5444	Economy	10800.00
0005435041670	5444	Economy	10800.00
0005435041673	5444	Economy	10800.00
0005434229863	5444	Economy	9800.00
0005434229859	5444	Economy	9800.00
0005434229901	5444	Economy	9800.00
0005434229953	5444	Economy	9800.00
0005435377938	5444	Economy	9800.00
0005434229862	5444	Economy	9800.00
0005435041676	5444	Economy	9800.00
0005434229951	5444	Economy	9800.00
0005435041680	5444	Economy	9800.00
0005435041674	5444	Economy	9800.00
0005434229949	5444	Economy	9800.00
0005434229918	5444	Economy	9800.00
0005435007716	5444	Economy	9800.00
0005434229861	5444	Economy	9800.00
0005434229948	5444	Economy	9800.00
0005434229872	5444	Economy	9800.00
0005434229853	5444	Economy	9800.00
0005435041690	5444	Economy	9800.00
0005434229923	5444	Economy	9800.00
0005435041671	5444	Economy	9800.00
0005435041689	5444	Economy	9800.00
0005435041669	5444	Economy	9800.00
0005435041675	5444	Economy	9800.00
0005435041368	13006	Business	29500.00
0005435040981	13006	Business	29500.00
0005434230037	13006	Business	29500.00
0005435556770	13006	Business	29500.00
0005435041377	13006	Business	29500.00
0005434230028	13006	Business	29500.00
0005435377983	13006	Business	29500.00
0005435041406	13006	Business	29500.00
0005435041151	13006	Business	29500.00
0005435007534	13006	Business	29500.00
0005432304511	13006	Business	29500.00
0005435040816	13006	Economy	9800.00
0005435042919	13006	Economy	9800.00
0005435041004	13006	Economy	9800.00
0005435007549	13006	Economy	9800.00
0005435007540	13006	Economy	9800.00
0005435041289	13006	Economy	9800.00
0005435007603	13006	Economy	9800.00
0005435735283	13006	Economy	9800.00
0005435041112	13006	Economy	9800.00
0005435007586	13006	Economy	9800.00
0005435041202	13006	Economy	9800.00
0005435041177	13006	Economy	9800.00
0005435041468	13006	Economy	9800.00
0005435041204	13006	Economy	9800.00
0005435043301	13006	Economy	9800.00
0005435041217	13006	Economy	9800.00
0005434230038	13006	Economy	9800.00
0005435041334	13006	Economy	9800.00
0005435007680	13006	Economy	9800.00
0005435041439	13006	Economy	9800.00
0005435041228	13006	Economy	9800.00
0005435007609	13006	Economy	9800.00
0005435041467	13006	Economy	9800.00
0005435007554	13006	Economy	9800.00
0005435041118	13006	Economy	9800.00
0005434230035	13006	Economy	9800.00
0005435041325	13006	Economy	9800.00
0005435041469	13006	Economy	9800.00
0005435377982	13006	Economy	9800.00
0005435041282	13006	Economy	9800.00
0005435007622	13006	Economy	9800.00
0005435041436	13006	Economy	9800.00
0005435041376	13006	Economy	9800.00
0005435041003	13006	Economy	9800.00
0005435042906	13006	Economy	9800.00
0005435041119	13006	Economy	9800.00
0005435041063	13006	Economy	9800.00
0005435041335	13006	Economy	9800.00
0005435007619	13006	Economy	9800.00
0005435041219	13006	Economy	10800.00
0005435041103	13006	Economy	10800.00
0005435007602	13006	Economy	10800.00
0005435041061	13006	Economy	10800.00
0005435041360	13006	Economy	10800.00
0005435041326	13006	Economy	10800.00
0005435042900	13006	Economy	9800.00
0005435041211	13006	Economy	9800.00
0005435041362	13006	Economy	9800.00
0005435043300	13006	Economy	9800.00
0005435041338	13006	Economy	9800.00
0005435007580	13006	Economy	9800.00
0005435041170	13006	Economy	9800.00
0005435007632	13006	Economy	9800.00
0005435041511	13006	Economy	9800.00
0005435041255	13006	Economy	9800.00
0005435007531	13006	Economy	9800.00
0005435007561	13006	Economy	9800.00
0005435041165	13006	Economy	9800.00
0005434230029	13006	Economy	9800.00
0005435041339	13006	Economy	9800.00
0005435041410	13006	Economy	9800.00
0005434230032	13006	Economy	9800.00
0005435041385	13006	Economy	9800.00
0005434230030	13006	Economy	9800.00
0005435041288	13006	Economy	9800.00
0005435041113	13006	Economy	9800.00
0005435041341	13006	Economy	9800.00
0005435041350	13006	Economy	9800.00
0005435007585	13006	Economy	9800.00
0005435007569	13006	Economy	9800.00
0005435041290	13006	Economy	9800.00
0005435041336	13006	Economy	9800.00
0005434230031	13006	Economy	9800.00
0005435377985	13006	Economy	9800.00
0005435041276	13006	Economy	9800.00
0005434230034	13006	Economy	9800.00
0005435007601	13006	Economy	9800.00
0005435040667	13006	Economy	9800.00
0005435043299	13006	Economy	9800.00
0005435040988	13006	Economy	9800.00
0005435041104	13006	Economy	9800.00
0005434230036	13006	Economy	9800.00
0005435007523	13006	Economy	9800.00
0005435042908	13006	Economy	9800.00
0005435041283	13006	Economy	9800.00
0005435041347	13006	Economy	9800.00
0005435041378	13006	Economy	9800.00
0005435041201	13006	Economy	9800.00
0005435041220	13006	Economy	9800.00
0005435041389	13006	Economy	9800.00
0005435042899	13006	Economy	9800.00
0005435007498	13006	Economy	9800.00
0005435007663	13006	Economy	9800.00
0005435041210	13006	Economy	9800.00
0005435042895	13006	Economy	9800.00
0005435041407	13006	Economy	9800.00
0005435041062	13006	Economy	9800.00
0005435041342	13006	Economy	9800.00
0005435041369	13006	Economy	9800.00
0005435041270	13006	Economy	9800.00
0005435007584	13006	Economy	9800.00
0005435007579	13006	Economy	9800.00
0005435041277	13006	Economy	9800.00
0005435041478	13006	Economy	9800.00
0005435007497	13006	Economy	9800.00
0005435041294	13006	Economy	9800.00
0005435007560	13006	Economy	9800.00
0005435007587	13006	Economy	9800.00
0005435041120	13006	Economy	9800.00
0005435007588	13006	Economy	9800.00
0005435042918	13006	Economy	9800.00
0005434230033	13006	Economy	9800.00
0005435042896	13006	Economy	9800.00
0005435377984	13006	Economy	9800.00
0005434427454	14865	Business	52900.00
0005435903183	14865	Business	52900.00
0005435903075	14865	Business	52900.00
0005435903087	14865	Business	52900.00
0005434411900	14865	Business	52900.00
0005435903026	14865	Business	52900.00
0005435903067	14865	Business	52900.00
0005434427452	14865	Business	52900.00
0005435902998	14865	Economy	17600.00
0005435903051	14865	Economy	19400.00
0005435903052	14865	Economy	19400.00
0005435903096	14865	Economy	19400.00
0005435903118	14865	Economy	17600.00
0005435903092	14865	Economy	17600.00
0005434427455	14865	Economy	17600.00
0005434427456	14865	Economy	17600.00
0005435554312	14865	Economy	17600.00
0005435903068	14865	Economy	17600.00
0005435903069	14865	Economy	17600.00
0005435903116	14865	Economy	17600.00
0005434427453	14865	Economy	17600.00
0005435903049	14865	Economy	17600.00
0005434427457	14865	Economy	17600.00
0005435902997	14865	Economy	17600.00
0005435903141	14865	Economy	17600.00
0005435903171	14865	Economy	17600.00
0005434427451	14865	Economy	17600.00
0005435903119	14865	Economy	17600.00
0005435903095	14865	Economy	17600.00
0005435903130	14865	Economy	17600.00
0005435903103	14865	Economy	17600.00
0005435903059	14865	Economy	17600.00
0005435903131	14865	Economy	17600.00
0005435903097	14865	Economy	17600.00
0005434427450	14865	Economy	17600.00
0005435903053	14865	Economy	17600.00
0005435903218	20182	Business	52900.00
0005435903219	20182	Business	52900.00
0005434427379	20182	Economy	17600.00
0005434411885	20182	Economy	17600.00
0005434411884	20182	Economy	17600.00
0005434427345	20182	Economy	17600.00
0005434411879	20182	Economy	17600.00
0005435903217	20182	Economy	17600.00
0005434427227	20182	Economy	17600.00
0005434411872	20182	Economy	17600.00
0005434427331	20182	Economy	17600.00
0005434411886	20182	Economy	17600.00
0005434427286	20182	Economy	17600.00
0005434427302	20182	Economy	17600.00
0005434427380	20182	Economy	17600.00
0005434427326	20182	Economy	17600.00
0005434427211	20182	Economy	17600.00
0005434411873	20182	Economy	17600.00
0005434427307	20182	Economy	17600.00
0005434427344	20182	Economy	17600.00
0005434427205	20182	Economy	17600.00
0005434427330	20182	Economy	17600.00
0005434427301	20182	Economy	17600.00
0005434427314	20182	Economy	17600.00
0005434427381	20182	Economy	17600.00
0005434427255	20182	Economy	17600.00
0005434523833	28021	Business	106800.00
0005434523824	28021	Economy	35600.00
0005434559106	28021	Economy	35600.00
0005434559115	28021	Economy	35600.00
0005434523825	28021	Economy	35600.00
0005434523812	28021	Economy	35600.00
0005432462574	28021	Economy	35600.00
0005434559112	28021	Economy	35600.00
0005434559118	28021	Economy	35600.00
0005434559119	28021	Economy	35600.00
0005434559105	28021	Economy	35600.00
0005432462576	28021	Economy	39200.00
0005434559110	28021	Economy	35600.00
0005434523826	28021	Economy	35600.00
0005434559114	28021	Economy	35600.00
0005434523817	28021	Economy	35600.00
0005434559107	28021	Economy	35600.00
0005432462575	28021	Economy	35600.00
0005434559111	28021	Economy	35600.00
0005434559117	28021	Economy	35600.00
0005434559109	28021	Economy	35600.00
0005434523828	28021	Economy	35600.00
0005434523829	28021	Economy	35600.00
0005434523811	28021	Economy	35600.00
0005434559108	28021	Economy	35600.00
0005434559166	30891	Business	106800.00
0005434559182	30891	Business	106800.00
0005432462553	30891	Business	106800.00
0005434559174	30891	Business	106800.00
0005434559190	30891	Business	106800.00
0005432462545	30891	Business	106800.00
0005432462555	30891	Economy	35600.00
0005432462558	30891	Economy	35600.00
0005434559170	30891	Economy	35600.00
0005434559175	30891	Economy	35600.00
0005434559188	30891	Economy	35600.00
0005434559187	30891	Economy	35600.00
0005432462564	30891	Economy	35600.00
0005434523846	30891	Economy	35600.00
0005434559171	30891	Economy	35600.00
0005434523845	30891	Economy	35600.00
0005432462565	30891	Economy	35600.00
0005434559168	30891	Economy	35600.00
0005434559178	30891	Economy	35600.00
0005434559180	30891	Economy	35600.00
0005434559176	30891	Economy	35600.00
0005434559189	30891	Economy	35600.00
0005434523844	30891	Economy	35600.00
0005434559184	30891	Economy	35600.00
0005434559177	30891	Economy	35600.00
0005432462554	30891	Economy	35600.00
0005434559181	30891	Economy	35600.00
0005434559183	30891	Economy	35600.00
0005434559173	30891	Economy	35600.00
0005434523842	30891	Economy	35600.00
0005432462557	30891	Economy	35600.00
0005434523843	30891	Economy	35600.00
0005434559169	30891	Economy	35600.00
0005434559179	30891	Economy	35600.00
0005434559172	30891	Economy	35600.00
0005434559185	30891	Economy	35600.00
0005434559186	30891	Economy	35600.00
0005434559167	30891	Economy	35600.00
0005433726169	30870	Business	91700.00
0005433726166	30870	Business	91700.00
0005433726168	30870	Business	91700.00
0005433726165	30870	Economy	30600.00
0005433726167	30870	Economy	33600.00
0005433726170	30870	Economy	30600.00
0005433726162	30870	Economy	30600.00
0005433726161	30870	Economy	30600.00
0005433726171	30870	Economy	30600.00
0005433726163	30870	Economy	30600.00
0005433726164	30870	Economy	30600.00
0005435983660	26524	Business	18500.00
0005435983645	26524	Business	18500.00
0005433435127	26524	Business	18500.00
0005433435352	26524	Business	18500.00
0005435983664	26524	Business	18500.00
0005434270245	26524	Business	18500.00
0005435983661	26524	Business	18500.00
0005433435327	26524	Business	18500.00
0005432300439	26524	Business	18500.00
0005433435329	26524	Economy	6200.00
0005433435310	26524	Economy	6200.00
0005433435355	26524	Economy	6200.00
0005435983658	26524	Economy	6200.00
0005432300437	26524	Economy	6200.00
0005433435336	26524	Economy	6800.00
0005435983655	26524	Economy	6800.00
0005435983663	26524	Economy	6800.00
0005435983657	26524	Economy	6200.00
0005433435370	26524	Economy	6200.00
0005434270246	26524	Economy	6200.00
0005433435268	26524	Economy	6200.00
0005435983649	26524	Economy	6200.00
0005435983668	26524	Economy	6200.00
0005432300438	26524	Economy	6200.00
0005433435311	26524	Economy	6200.00
0005435983667	26524	Economy	6200.00
0005433435216	26524	Economy	6200.00
0005433435369	26524	Economy	6200.00
0005435983648	26524	Economy	6200.00
0005435983662	26524	Economy	6200.00
0005433435337	26524	Economy	6200.00
0005435983646	26524	Economy	6200.00
0005433435297	26524	Economy	6200.00
0005435983659	26524	Economy	6200.00
0005435983647	26524	Economy	6200.00
0005435983650	26524	Economy	6200.00
0005435983653	26524	Economy	6200.00
0005433435359	26524	Economy	6200.00
0005435983651	26524	Economy	6200.00
0005433435215	26524	Economy	6200.00
0005435983654	26524	Economy	6200.00
0005433435205	26524	Economy	6200.00
0005435983652	26524	Economy	6200.00
0005435983665	26524	Economy	6200.00
0005435983666	26524	Economy	6200.00
0005433435291	26524	Economy	6200.00
0005433435147	26524	Economy	6200.00
0005435983656	26524	Economy	6200.00
0005433435379	26524	Economy	6200.00
0005435983359	26726	Business	18500.00
0005435983281	26726	Business	18500.00
0005435983352	26726	Business	18500.00
0005435983302	26726	Business	18500.00
0005435983310	26726	Business	18500.00
0005435983305	26726	Business	18500.00
0005435983484	26726	Business	18500.00
0005435983065	26726	Business	18500.00
0005435983120	26726	Economy	6200.00
0005435983210	26726	Economy	6200.00
0005435983285	26726	Economy	6200.00
0005435983201	26726	Economy	6800.00
0005435983366	26726	Economy	6800.00
0005433435501	26726	Economy	6200.00
0005435983357	26726	Economy	6200.00
0005435983319	26726	Economy	6200.00
0005435983211	26726	Economy	6200.00
0005435983299	26726	Economy	6200.00
0005435983334	26726	Economy	6200.00
0005435983264	26726	Economy	6200.00
0005432051219	26726	Economy	6200.00
0005435983164	26726	Economy	6200.00
0005435983286	26726	Economy	6200.00
0005435983284	26726	Economy	6200.00
0005435983461	26726	Economy	6200.00
0005435983353	26726	Economy	6200.00
0005435983354	26726	Economy	6200.00
0005435983477	26726	Economy	6200.00
0005435983380	26726	Economy	6200.00
0005433435503	26726	Economy	6200.00
0005435983358	26726	Economy	6200.00
0005435983313	26726	Economy	6200.00
0005435983303	26726	Economy	6200.00
0005435983426	26726	Economy	6200.00
0005435983082	26726	Economy	6200.00
0005433435502	26726	Economy	6200.00
0005435983226	26726	Economy	6200.00
0005434271375	26726	Economy	6200.00
0005433435504	26726	Economy	6200.00
0005435983519	26726	Economy	6200.00
0005435983331	26726	Economy	6200.00
0005435983309	26726	Economy	6200.00
0005435983268	26726	Economy	6200.00
0005435983335	26726	Economy	6200.00
0005435983478	26726	Economy	6200.00
0005433689951	29266	Economy	21000.00
0005433686682	29266	Economy	21000.00
0005433686676	29266	Economy	19100.00
0005433689956	29266	Economy	19100.00
0005433686669	29266	Economy	19100.00
0005433686677	29266	Economy	19100.00
0005433689958	29266	Economy	19100.00
0005433686683	29266	Economy	19100.00
0005433689962	29266	Economy	19100.00
0005433689955	29266	Economy	19100.00
0005433689945	29266	Economy	19100.00
0005433686684	29266	Economy	19100.00
0005433689952	29266	Economy	19100.00
0005433689957	29266	Economy	19100.00
0005433689954	29266	Economy	19100.00
0005432858354	3171	Economy	11100.00
0005432858342	3171	Economy	10100.00
0005432858315	3171	Economy	10100.00
0005432584777	3171	Economy	10100.00
0005432858343	3171	Economy	10100.00
0005432858316	3171	Economy	10100.00
0005432858303	3171	Economy	10100.00
0005432858359	3171	Economy	10100.00
0005432858353	3171	Economy	10100.00
0005432858317	3171	Economy	10100.00
0005432858360	3171	Economy	10100.00
0005432584776	3171	Economy	10100.00
0005432858326	3171	Economy	10100.00
0005432858314	3171	Economy	10100.00
0005432858341	3171	Economy	10100.00
0005432858330	3171	Economy	10100.00
0005432584778	3171	Economy	10100.00
0005432858338	3171	Economy	10100.00
0005432584624	31509	Economy	11100.00
0005432584686	31509	Economy	11100.00
0005432584716	31509	Economy	11100.00
0005432584659	31509	Economy	10100.00
0005432584700	31509	Economy	10100.00
0005432584648	31509	Economy	10100.00
0005432584671	31509	Economy	10100.00
0005432584623	31509	Economy	10100.00
0005432584672	31509	Economy	10100.00
0005432584632	31509	Economy	10100.00
0005432584620	31509	Economy	10100.00
0005432584619	31509	Economy	10100.00
0005432584685	31509	Economy	10100.00
0005432584701	31509	Economy	10100.00
0005432584676	31509	Economy	10100.00
0005432584679	31509	Economy	10100.00
0005432584560	31509	Economy	10100.00
0005432584687	31509	Economy	10100.00
0005432584625	31509	Economy	10100.00
0005432584630	31509	Economy	10100.00
0005432858410	31509	Economy	10100.00
0005432584428	31509	Economy	10100.00
0005432584429	31509	Economy	10100.00
0005432584635	31509	Economy	10100.00
0005432584714	31509	Economy	10100.00
0005432584559	31509	Economy	10100.00
0005432584589	31509	Economy	10100.00
0005432584678	31509	Economy	10100.00
0005432584715	31509	Economy	10100.00
0005432584631	31509	Economy	10100.00
0005432858409	31509	Economy	10100.00
0005432584644	31509	Economy	10100.00
0005432584558	31509	Economy	10100.00
0005433255229	858	Economy	7500.00
0005433255241	858	Economy	7500.00
0005434943616	858	Economy	7500.00
0005433255212	858	Economy	7500.00
0005434943556	16221	Economy	8300.00
0005434943549	16221	Economy	8300.00
0005433255275	16221	Economy	7500.00
0005434943609	16221	Economy	7500.00
0005434943555	16221	Economy	7500.00
0005433255274	16221	Economy	7500.00
0005435999869	11158	Business	89100.00
0005435999870	11158	Business	89100.00
0005435999871	11158	Economy	29700.00
0005433654939	27614	Business	90500.00
0005435858687	27614	Business	90500.00
0005433654933	27614	Business	90500.00
0005433654934	27614	Business	90500.00
0005433654930	27614	Business	90500.00
0005433654924	27614	Economy	30200.00
0005433654964	27614	Economy	30200.00
0005433654951	27614	Economy	30200.00
0005435858688	27614	Economy	30200.00
0005433654914	27614	Economy	30200.00
0005435858686	27614	Economy	30200.00
0005433654913	27614	Economy	30200.00
0005435858692	27614	Economy	30200.00
0005433654950	27614	Economy	30200.00
0005435858689	27614	Economy	30200.00
0005433654947	27614	Economy	30200.00
0005433654938	27614	Economy	30200.00
0005433654921	27614	Economy	30200.00
0005435858690	27614	Economy	30200.00
0005433654932	27614	Economy	30200.00
0005433654923	27614	Economy	30200.00
0005435858693	27614	Economy	30200.00
0005433654925	27614	Economy	30200.00
0005433654911	27614	Economy	30200.00
0005435858691	27614	Economy	30200.00
0005435858694	27614	Economy	30200.00
0005433927538	14396	Economy	4400.00
0005433927539	14396	Economy	4400.00
0005435654466	21734	Business	9800.00
0005435654450	21734	Business	9800.00
0005433368719	21734	Business	9800.00
0005433368782	21734	Business	9800.00
0005435654457	21734	Business	9800.00
0005435654464	21734	Business	9800.00
0005435654467	21734	Business	9800.00
0005433368852	21734	Economy	3300.00
0005435654471	21734	Economy	3300.00
0005433368810	21734	Economy	3300.00
0005433368770	21734	Economy	3300.00
0005433368713	21734	Economy	3300.00
0005435654454	21734	Economy	3300.00
0005433368660	21734	Economy	3600.00
0005433368538	21734	Economy	3600.00
0005435654461	21734	Economy	3600.00
0005435654463	21734	Economy	3600.00
0005433368725	21734	Economy	3300.00
0005433368781	21734	Economy	3300.00
0005433368685	21734	Economy	3300.00
0005433368788	21734	Economy	3300.00
0005435654447	21734	Economy	3300.00
0005435654473	21734	Economy	3300.00
0005435654459	21734	Economy	3300.00
0005435654444	21734	Economy	3300.00
0005433368805	21734	Economy	3300.00
0005433368822	21734	Economy	3300.00
0005433368739	21734	Economy	3300.00
0005433368844	21734	Economy	3300.00
0005435654460	21734	Economy	3300.00
0005433368619	21734	Economy	3300.00
0005435654452	21734	Economy	3300.00
0005435654468	21734	Economy	3300.00
0005433368771	21734	Economy	3300.00
0005435654451	21734	Economy	3300.00
0005433368792	21734	Economy	3300.00
0005433368710	21734	Economy	3300.00
0005433368775	21734	Economy	3300.00
0005435654445	21734	Economy	3300.00
0005435654472	21734	Economy	3300.00
0005435654455	21734	Economy	3300.00
0005433368803	21734	Economy	3300.00
0005435654456	21734	Economy	3300.00
0005433368661	21734	Economy	3300.00
0005435654443	21734	Economy	3300.00
0005433368791	21734	Economy	3300.00
0005433368780	21734	Economy	3300.00
0005435654458	21734	Economy	3300.00
0005433368689	21734	Economy	3300.00
0005435654449	21734	Economy	3300.00
0005433368631	21734	Economy	3300.00
0005435654448	21734	Economy	3300.00
0005435654470	21734	Economy	3300.00
0005435654446	21734	Economy	3300.00
0005435654465	21734	Economy	3300.00
0005433368539	21734	Economy	3300.00
0005435654453	21734	Economy	3300.00
0005433368853	21734	Economy	3300.00
0005435654469	21734	Economy	3300.00
0005433368630	21734	Economy	3300.00
0005435654462	21734	Economy	3300.00
0005435654442	21734	Economy	3300.00
0005433368890	21734	Economy	3300.00
0005433368600	21734	Economy	3300.00
0005433368821	21734	Economy	3300.00
0005433786163	9358	Business	186200.00
0005433786178	9358	Business	186200.00
0005434171373	9358	Business	186200.00
0005434171454	9358	Business	186200.00
0005433806400	9358	Business	186200.00
0005433806396	9358	Business	186200.00
0005435269909	9358	Business	186200.00
0005433786160	9358	Business	186200.00
0005435269979	9358	Business	186200.00
0005433786164	9358	Business	186200.00
0005435269942	9358	Business	186200.00
0005434171456	9358	Business	186200.00
0005433806398	9358	Business	186200.00
0005433806401	9358	Business	186200.00
0005435269986	9358	Economy	68300.00
0005435269914	9358	Economy	62100.00
0005433806399	9358	Economy	62100.00
0005434171384	9358	Economy	62100.00
0005433786174	9358	Economy	62100.00
0005433786169	9358	Economy	62100.00
0005433786170	9358	Economy	62100.00
0005434151773	9358	Economy	62100.00
0005435269951	9358	Economy	62100.00
0005435270054	9358	Economy	62100.00
0005434171403	9358	Economy	62100.00
0005433786167	9358	Economy	62100.00
0005434171455	9358	Economy	62100.00
0005435270023	9358	Economy	62100.00
0005434171372	9358	Economy	62100.00
0005435269957	9358	Economy	62100.00
0005435270057	9358	Economy	62100.00
0005435269950	9358	Economy	62100.00
0005434151771	9358	Economy	62100.00
0005435269978	9358	Economy	62100.00
0005435270048	9358	Economy	62100.00
0005432657539	9358	Economy	62100.00
0005433763629	9358	Economy	62100.00
0005435269958	9358	Economy	62100.00
0005435269918	9358	Economy	62100.00
0005433786179	9358	Economy	62100.00
0005434171419	9358	Economy	62100.00
0005434171386	9358	Economy	62100.00
0005433786181	9358	Economy	62100.00
0005433786162	9358	Economy	62100.00
0005435269998	9358	Economy	62100.00
0005433786183	9358	Economy	62100.00
0005435269943	9358	Economy	62100.00
0005433786182	9358	Economy	62100.00
0005435270012	9358	Economy	62100.00
0005435270087	9358	Economy	62100.00
0005433786176	9358	Economy	62100.00
0005433763628	9358	Economy	62100.00
0005435269936	9358	Economy	62100.00
0005435270000	9358	Economy	62100.00
0005435269911	9358	Economy	62100.00
0005433786180	9358	Economy	62100.00
0005433786161	9358	Economy	62100.00
0005432666447	9358	Economy	68300.00
0005435270052	9358	Economy	62100.00
0005433786184	9358	Economy	62100.00
0005434171385	9358	Economy	62100.00
0005435269901	9358	Economy	62100.00
0005435270037	9358	Economy	62100.00
0005434171357	9358	Economy	62100.00
0005433806397	9358	Economy	62100.00
0005434273114	9358	Economy	62100.00
0005433763627	9358	Economy	62100.00
0005433786168	9358	Economy	62100.00
0005435269937	9358	Economy	62100.00
0005435269910	9358	Economy	62100.00
0005433806403	9358	Economy	62100.00
0005435270055	9358	Economy	62100.00
0005434151774	9358	Economy	62100.00
0005434171433	9358	Economy	62100.00
0005435270053	9358	Economy	62100.00
0005433786165	9358	Economy	62100.00
0005433786172	9358	Economy	62100.00
0005433806402	9358	Economy	62100.00
0005435269999	9358	Economy	62100.00
0005435269915	9358	Economy	62100.00
0005434171432	9358	Economy	62100.00
0005432666448	9358	Economy	62100.00
0005433786171	9358	Economy	62100.00
0005435269939	9358	Economy	62100.00
0005434171412	9358	Economy	62100.00
0005434171413	9358	Economy	62100.00
0005434171389	9358	Economy	62100.00
0005434171350	9358	Economy	62100.00
0005433786177	9358	Economy	62100.00
0005433786166	9358	Economy	62100.00
0005434151772	9358	Economy	62100.00
0005434273113	9358	Economy	62100.00
0005434171362	9358	Economy	62100.00
0005433786173	9358	Economy	62100.00
0005435270058	9358	Economy	62100.00
0005433786175	9358	Economy	62100.00
0005433785781	26264	Business	186200.00
0005433785721	26264	Business	186200.00
0005433785716	26264	Business	186200.00
0005433806208	26264	Business	186200.00
0005434151793	26264	Business	186200.00
0005432657516	26264	Business	186200.00
0005433806247	26264	Business	186200.00
0005433806237	26264	Business	186200.00
0005433805892	26264	Business	186200.00
0005433785785	26264	Business	186200.00
0005435270206	26264	Business	186200.00
0005435270216	26264	Business	186200.00
0005435270205	26264	Business	186200.00
0005433806105	26264	Economy	62100.00
0005433763523	26264	Economy	68300.00
0005433806078	26264	Economy	62100.00
0005433763592	26264	Economy	62100.00
0005435270218	26264	Economy	62100.00
0005435270215	26264	Economy	62100.00
0005434171466	26264	Economy	62100.00
0005433785664	26264	Economy	62100.00
0005435270213	26264	Economy	62100.00
0005433806193	26264	Economy	62100.00
0005433763562	26264	Economy	62100.00
0005433806093	26264	Economy	62100.00
0005435858742	26264	Economy	62100.00
0005433806136	26264	Economy	62100.00
0005433806127	26264	Economy	62100.00
0005433763558	26264	Economy	62100.00
0005433785818	26264	Economy	62100.00
0005433785827	26264	Economy	62100.00
0005435270211	26264	Economy	62100.00
0005433806174	26264	Economy	62100.00
0005433785803	26264	Economy	62100.00
0005434171467	26264	Economy	62100.00
0005433785698	26264	Economy	62100.00
0005434171468	26264	Economy	62100.00
0005433785806	26264	Economy	62100.00
0005433806104	26264	Economy	62100.00
0005433805891	26264	Economy	62100.00
0005433785901	26264	Economy	62100.00
0005432663080	26264	Economy	62100.00
0005433763509	26264	Economy	62100.00
0005433785763	26264	Economy	62100.00
0005433785852	26264	Economy	62100.00
0005433806238	26264	Economy	62100.00
0005433763522	26264	Economy	62100.00
0005433806079	26264	Economy	62100.00
0005433806360	26264	Economy	62100.00
0005433785834	26264	Economy	62100.00
0005433806233	26264	Economy	62100.00
0005433763518	26264	Economy	62100.00
0005434269165	26264	Economy	62100.00
0005433785756	26264	Economy	62100.00
0005434171469	26264	Economy	62100.00
0005433785855	26264	Economy	62100.00
0005433806222	26264	Economy	62100.00
0005432663083	26264	Economy	62100.00
0005433763573	26264	Economy	62100.00
0005433785588	26264	Economy	62100.00
0005433785747	26264	Economy	62100.00
0005433806172	26264	Economy	62100.00
0005432659749	26264	Economy	62100.00
0005433806139	26264	Economy	62100.00
0005433785832	26264	Economy	62100.00
0005432663079	26264	Economy	62100.00
0005433785807	26264	Economy	62100.00
0005433785808	26264	Economy	62100.00
0005433806282	26264	Economy	62100.00
0005433785881	26264	Economy	62100.00
0005433806137	26264	Economy	68300.00
0005433785764	26264	Economy	62100.00
0005433785817	26264	Economy	68300.00
0005433763515	26264	Economy	62100.00
0005433806234	26264	Economy	62100.00
0005434270266	26264	Economy	62100.00
0005435270208	26264	Economy	62100.00
0005433763516	26264	Economy	62100.00
0005433806209	26264	Economy	62100.00
0005433785833	26264	Economy	62100.00
0005433806103	26264	Economy	62100.00
0005435270217	26264	Economy	62100.00
0005433806201	26264	Economy	62100.00
0005433785776	26264	Economy	62100.00
0005435270207	26264	Economy	62100.00
0005433785813	26264	Economy	62100.00
0005435270210	26264	Economy	62100.00
0005432657515	26264	Economy	62100.00
0005435858741	26264	Economy	62100.00
0005433785860	26264	Economy	62100.00
0005435270214	26264	Economy	62100.00
0005433785854	26264	Economy	62100.00
0005433785804	26264	Economy	62100.00
0005433785937	26264	Economy	62100.00
0005435270209	26264	Economy	62100.00
0005433763517	26264	Economy	62100.00
0005433806175	26264	Economy	62100.00
0005433806161	26264	Economy	62100.00
0005433806067	26264	Economy	62100.00
0005433785722	26264	Economy	62100.00
0005433806279	26264	Economy	62100.00
0005432657523	26264	Economy	62100.00
0005433806280	26264	Economy	62100.00
0005432659750	26264	Economy	62100.00
0005433785957	26264	Economy	62100.00
0005435270212	26264	Economy	62100.00
0005435858743	26264	Economy	62100.00
0005433763520	26264	Economy	62100.00
0005432666439	26264	Economy	62100.00
0005433806221	26264	Economy	62100.00
0005433806283	26264	Economy	62100.00
0005433806200	26264	Economy	62100.00
0005433806192	26264	Economy	62100.00
0005433785770	26264	Economy	62100.00
0005433806239	26264	Economy	62100.00
0005435135808	4935	Economy	5300.00
0005435929706	4935	Economy	5300.00
0005435135807	4935	Economy	5300.00
0005435929710	4935	Economy	5300.00
0005435135809	4935	Economy	5300.00
0005435929705	4935	Economy	5300.00
0005435135793	33014	Economy	5300.00
0005435135794	33014	Economy	5300.00
0005435135776	33014	Economy	5300.00
0005435929722	33014	Economy	5300.00
0005435135781	33014	Economy	5300.00
0005435135797	33014	Economy	5300.00
0005434218077	9509	Economy	17900.00
0005434218051	9509	Economy	17900.00
0005434983414	27360	Economy	17900.00
0005434983415	27360	Economy	17900.00
0005434983411	27360	Economy	17900.00
0005434983413	27360	Economy	17900.00
0005434218092	27360	Economy	17900.00
0005434218093	27360	Economy	17900.00
0005433986958	24287	Business	36400.00
0005433962136	24287	Business	36400.00
0005433961990	24287	Business	36400.00
0005433961966	24287	Business	36400.00
0005433986994	24287	Business	36400.00
0005433986833	24287	Business	36400.00
0005433962011	24287	Business	36400.00
0005433986993	24287	Business	36400.00
0005433961927	24287	Business	36400.00
0005433962042	24287	Business	36400.00
0005433987013	24287	Business	36400.00
0005433962079	24287	Business	36400.00
0005433962087	24287	Business	36400.00
0005433962021	24287	Business	36400.00
0005433962024	24287	Business	36400.00
0005433986883	24287	Business	36400.00
0005433987068	24287	Business	36400.00
0005433986899	24287	Economy	13400.00
0005433986879	24287	Economy	13400.00
0005433986859	24287	Economy	12100.00
0005433986922	24287	Economy	12100.00
0005433986982	24287	Economy	12100.00
0005433962100	24287	Economy	12100.00
0005433961928	24287	Economy	12100.00
0005433986892	24287	Economy	12100.00
0005433986939	24287	Economy	12100.00
0005433987023	24287	Economy	12100.00
0005433987211	24287	Economy	12100.00
0005433962049	24287	Economy	12100.00
0005433962166	24287	Economy	12100.00
0005433962077	24287	Economy	12100.00
0005433987067	24287	Economy	12100.00
0005433987075	24287	Economy	12100.00
0005433961976	24287	Economy	12100.00
0005433962064	24287	Economy	12100.00
0005433961944	24287	Economy	12100.00
0005433962151	24287	Economy	12100.00
0005433962146	24287	Economy	12100.00
0005433961997	24287	Economy	12100.00
0005433987016	24287	Economy	12100.00
0005433962128	24287	Economy	12100.00
0005433961940	24287	Economy	12100.00
0005433986693	24287	Economy	12100.00
0005433962134	24287	Economy	12100.00
0005433962152	24287	Economy	12100.00
0005433986884	24287	Economy	12100.00
0005433962119	24287	Economy	12100.00
0005433986797	24287	Economy	12100.00
0005433962063	24287	Economy	12100.00
0005433986898	24287	Economy	12100.00
0005433962101	24287	Economy	12100.00
0005433962129	24287	Economy	12100.00
0005433961947	24287	Economy	12100.00
0005433962025	24287	Economy	12100.00
0005433986912	24287	Economy	12100.00
0005433986960	24287	Economy	12100.00
0005433986894	24287	Economy	12100.00
0005433987091	24287	Economy	12100.00
0005433986856	24287	Economy	12100.00
0005433986853	24287	Economy	12100.00
0005433986880	24287	Economy	12100.00
0005433961800	24287	Economy	12100.00
0005433962053	24287	Economy	12100.00
0005433961951	24287	Economy	12100.00
0005433962098	24287	Economy	12100.00
0005433987090	24287	Economy	12100.00
0005433962030	24287	Economy	12100.00
0005433987117	24287	Economy	12100.00
0005433961939	24287	Economy	12100.00
0005433987065	24287	Economy	12100.00
0005433986904	24287	Economy	12100.00
0005433987064	24287	Economy	13400.00
0005433962165	24287	Economy	12100.00
0005433986950	24287	Economy	12100.00
0005433962078	24287	Economy	12100.00
0005433986885	24287	Economy	12100.00
0005433986959	24287	Economy	12100.00
0005433962118	24287	Economy	12100.00
0005433962122	24287	Economy	12100.00
0005433986868	24287	Economy	12100.00
0005433987122	24287	Economy	12100.00
0005433987012	24287	Economy	12100.00
0005433962062	24287	Economy	12100.00
0005433987044	24287	Economy	12100.00
0005433986878	24287	Economy	12100.00
0005433962081	24287	Economy	12100.00
0005433986848	24287	Economy	12100.00
0005433986903	24287	Economy	12100.00
0005433986893	24287	Economy	12100.00
0005433987001	24287	Economy	12100.00
0005433962121	24287	Economy	12100.00
0005433987116	24287	Economy	12100.00
0005433987210	24287	Economy	12100.00
0005433986855	24287	Economy	12100.00
0005433986895	24287	Economy	12100.00
0005433962123	24287	Economy	12100.00
0005433986919	24287	Economy	12100.00
0005433961999	24287	Economy	12100.00
0005433961903	24287	Economy	12100.00
0005433986938	24287	Economy	12100.00
0005433962142	24287	Economy	12100.00
0005433962137	24287	Economy	12100.00
0005433962147	24287	Economy	12100.00
0005433986881	24287	Economy	12100.00
0005433987162	24287	Economy	12100.00
0005433962694	25938	Business	36400.00
0005433962695	25938	Business	36400.00
0005433962676	25938	Business	36400.00
0005433962660	25938	Business	36400.00
0005433987351	25938	Business	36400.00
0005433987365	25938	Business	36400.00
0005433987357	25938	Business	36400.00
0005433987354	25938	Business	36400.00
0005433987366	25938	Business	36400.00
0005433962680	25938	Economy	12100.00
0005433962669	25938	Economy	12100.00
0005433962665	25938	Economy	12100.00
0005433962696	25938	Economy	12100.00
0005433962681	25938	Economy	12100.00
0005433962693	25938	Economy	12100.00
0005433987360	25938	Economy	12100.00
0005433987364	25938	Economy	12100.00
0005433962692	25938	Economy	12100.00
0005433987356	25938	Economy	12100.00
0005433987353	25938	Economy	12100.00
0005433962698	25938	Economy	12100.00
0005433962661	25938	Economy	12100.00
0005433962662	25938	Economy	12100.00
0005433962699	25938	Economy	12100.00
0005433962663	25938	Economy	12100.00
0005433962668	25938	Economy	12100.00
0005433987352	25938	Economy	12100.00
0005433962683	25938	Economy	12100.00
0005433987362	25938	Economy	12100.00
0005433962687	25938	Economy	12100.00
0005433987358	25938	Economy	12100.00
0005433987361	25938	Economy	12100.00
0005433962672	25938	Economy	12100.00
0005433962673	25938	Economy	12100.00
0005433962671	25938	Economy	12100.00
0005433962682	25938	Economy	12100.00
0005433962685	25938	Economy	13400.00
0005433962697	25938	Economy	13400.00
0005433962675	25938	Economy	12100.00
0005433962688	25938	Economy	12100.00
0005433962690	25938	Economy	12100.00
0005433962679	25938	Economy	12100.00
0005433962666	25938	Economy	12100.00
0005433962686	25938	Economy	12100.00
0005433962664	25938	Economy	12100.00
0005433962678	25938	Economy	12100.00
0005433962689	25938	Economy	12100.00
0005433987355	25938	Economy	12100.00
0005433962674	25938	Economy	12100.00
0005433962670	25938	Economy	12100.00
0005433962691	25938	Economy	12100.00
0005433987359	25938	Economy	12100.00
0005433987363	25938	Economy	12100.00
0005433962667	25938	Economy	12100.00
0005433962684	25938	Economy	12100.00
0005433962677	25938	Economy	12100.00
0005433166193	934	Economy	25400.00
0005433166210	934	Economy	23100.00
0005433166207	934	Economy	23100.00
0005434481046	934	Economy	23100.00
0005434481044	934	Economy	23100.00
0005433166225	934	Economy	23100.00
0005433166252	934	Economy	23100.00
0005434481048	934	Economy	23100.00
0005433166226	934	Economy	23100.00
0005434481047	934	Economy	23100.00
0005433166149	934	Economy	23100.00
0005433166206	934	Economy	23100.00
0005434481043	934	Economy	23100.00
0005434481045	934	Economy	23100.00
0005434481042	934	Economy	23100.00
0005434480905	16587	Economy	25400.00
0005434480774	16587	Economy	25400.00
0005434480961	16587	Economy	23100.00
0005433166284	16587	Economy	23100.00
0005434480958	16587	Economy	23100.00
0005434480970	16587	Economy	23100.00
0005434480915	16587	Economy	23100.00
0005434480897	16587	Economy	23100.00
0005434480909	16587	Economy	23100.00
0005434480857	16587	Economy	23100.00
0005434480907	16587	Economy	23100.00
0005434480815	16587	Economy	23100.00
0005434480960	16587	Economy	23100.00
0005434480834	16587	Economy	23100.00
0005434480856	16587	Economy	23100.00
0005434480824	16587	Economy	23100.00
0005434480846	16587	Economy	23100.00
0005434480792	16587	Economy	23100.00
0005433166285	16587	Economy	23100.00
0005434480833	16587	Economy	23100.00
0005434480921	16587	Economy	23100.00
0005434480885	16587	Economy	23100.00
0005433166286	16587	Economy	23100.00
0005434480908	16587	Economy	23100.00
0005434480794	16587	Economy	23100.00
0005433166283	16587	Economy	23100.00
0005434480951	16587	Economy	23100.00
0005434480906	16587	Economy	23100.00
0005434480955	16587	Economy	23100.00
0005433166287	16587	Economy	23100.00
0005434480898	16587	Economy	23100.00
0005433166288	16587	Economy	23100.00
0005434480959	16587	Economy	23100.00
0005434480855	16587	Economy	23100.00
0005434480971	16587	Economy	23100.00
0005434480881	16587	Economy	23100.00
0005435386697	10363	Economy	17000.00
0005435142964	10363	Economy	15400.00
0005435142962	10363	Economy	15400.00
0005435386669	10363	Economy	15400.00
0005435142956	10363	Economy	15400.00
0005433289991	10363	Economy	15400.00
0005435142960	10363	Economy	15400.00
0005435142961	10363	Economy	15400.00
0005433289977	10363	Economy	15400.00
0005433289985	10363	Economy	15400.00
0005435386698	10363	Economy	15400.00
0005435142958	10363	Economy	15400.00
0005435386668	10363	Economy	15400.00
0005435142957	10363	Economy	15400.00
0005435386670	10363	Economy	15400.00
0005435142959	10363	Economy	15400.00
0005435142963	10363	Economy	15400.00
0005435142922	21921	Economy	17000.00
0005435150342	21921	Economy	17000.00
0005435142919	21921	Economy	17000.00
0005435142830	21921	Economy	17000.00
0005435142831	21921	Economy	15400.00
0005435150319	21921	Economy	15400.00
0005435142908	21921	Economy	15400.00
0005433290065	21921	Economy	15400.00
0005435142871	21921	Economy	15400.00
0005435142893	21921	Economy	15400.00
0005435150347	21921	Economy	15400.00
0005435150364	21921	Economy	15400.00
0005435150391	21921	Economy	15400.00
0005435150289	21921	Economy	15400.00
0005435150320	21921	Economy	15400.00
0005435142870	21921	Economy	15400.00
0005435142842	21921	Economy	15400.00
0005435142836	21921	Economy	15400.00
0005435142874	21921	Economy	15400.00
0005435142832	21921	Economy	15400.00
0005435142882	21921	Economy	15400.00
0005435142888	21921	Economy	15400.00
0005435142887	21921	Economy	15400.00
0005435142841	21921	Economy	15400.00
0005435142844	21921	Economy	15400.00
0005435150360	21921	Economy	15400.00
0005435142920	21921	Economy	15400.00
0005435142880	21921	Economy	15400.00
0005435150287	21921	Economy	15400.00
0005435142894	21921	Economy	15400.00
0005435150348	21921	Economy	15400.00
0005435142827	21921	Economy	15400.00
0005435142886	21921	Economy	15400.00
0005435150373	21921	Economy	15400.00
0005435142881	21921	Economy	15400.00
0005435142878	21921	Economy	15400.00
0005435150374	21921	Economy	15400.00
0005435150346	21921	Economy	15400.00
0005435142923	21921	Economy	15400.00
0005435150392	21921	Economy	15400.00
0005435529779	11203	Business	57200.00
0005435529726	11203	Business	57200.00
0005435529707	11203	Business	57200.00
0005435319802	11203	Business	57200.00
0005435545888	11203	Business	57200.00
0005435529773	11203	Business	57200.00
0005435545889	11203	Economy	19100.00
0005434573762	11203	Economy	19100.00
0005435319755	11203	Economy	19100.00
0005435502696	11203	Economy	19100.00
0005435529790	11203	Economy	19100.00
0005434573765	11203	Economy	19100.00
0005434573766	11203	Economy	19100.00
0005435529757	11203	Economy	21000.00
0005434573763	11203	Economy	21000.00
0005435502726	11203	Economy	21000.00
0005435319768	11203	Economy	19100.00
0005435502824	11203	Economy	19100.00
0005435502823	11203	Economy	19100.00
0005434573764	11203	Economy	19100.00
0005435545949	11203	Economy	19100.00
0005435502791	11203	Economy	19100.00
0005435502695	11203	Economy	19100.00
0005435502758	11203	Economy	19100.00
0005435529651	11203	Economy	19100.00
0005435545913	11203	Economy	19100.00
0005435502727	11203	Economy	19100.00
0005435502742	11203	Economy	19100.00
0005435502803	11203	Economy	19100.00
0005435529792	11203	Economy	19100.00
0005435529796	11203	Economy	19100.00
0005435545897	11203	Economy	19100.00
0005435502850	11203	Economy	19100.00
0005435529648	11203	Economy	19100.00
0005435529738	11203	Economy	19100.00
0005435502757	11203	Economy	19100.00
0005435502781	11203	Economy	19100.00
0005434573768	11203	Economy	19100.00
0005435319769	11203	Economy	19100.00
0005435529727	11203	Economy	19100.00
0005435502688	11203	Economy	19100.00
0005435502846	11203	Economy	19100.00
0005435502774	11203	Economy	19100.00
0005435529649	11203	Economy	19100.00
0005435319756	11203	Economy	19100.00
0005435502859	11203	Economy	19100.00
0005435502797	11203	Economy	19100.00
0005435502687	11203	Economy	19100.00
0005435319726	11203	Economy	19100.00
0005435319775	11203	Economy	19100.00
0005435319767	11203	Economy	19100.00
0005435529758	11203	Economy	19100.00
0005435529768	11203	Economy	19100.00
0005435529767	11203	Economy	19100.00
0005435545896	11203	Economy	19100.00
0005435545912	11203	Economy	19100.00
0005435529728	11203	Economy	19100.00
0005435529741	11203	Economy	19100.00
0005435502804	11203	Economy	19100.00
0005434573767	11203	Economy	19100.00
0005435502878	11203	Economy	19100.00
0005435502948	20936	Business	57200.00
0005435502955	20936	Business	57200.00
0005435508818	20936	Business	57200.00
0005435502951	20936	Business	57200.00
0005435508821	20936	Business	57200.00
0005434573685	20936	Business	57200.00
0005435502950	20936	Economy	19100.00
0005435508823	20936	Economy	19100.00
0005434573684	20936	Economy	19100.00
0005434573652	20936	Economy	19100.00
0005435508816	20936	Economy	19100.00
0005435518445	20936	Economy	19100.00
0005434573692	20936	Economy	19100.00
0005435518446	20936	Economy	19100.00
0005435518451	20936	Economy	19100.00
0005435508822	20936	Economy	19100.00
0005434573651	20936	Economy	19100.00
0005435508819	20936	Economy	19100.00
0005435508815	20936	Economy	19100.00
0005435502949	20936	Economy	19100.00
0005435518449	20936	Economy	19100.00
0005435518453	20936	Economy	19100.00
0005435508820	20936	Economy	19100.00
0005435508814	20936	Economy	19100.00
0005435502953	20936	Economy	19100.00
0005434573653	20936	Economy	19100.00
0005435508817	20936	Economy	19100.00
0005435518454	20936	Economy	19100.00
0005434573649	20936	Economy	19100.00
0005434573655	20936	Economy	19100.00
0005435502947	20936	Economy	19100.00
0005435518450	20936	Economy	19100.00
0005434573656	20936	Economy	19100.00
0005435518452	20936	Economy	19100.00
0005435319828	20936	Economy	19100.00
0005435502954	20936	Economy	19100.00
0005435518448	20936	Economy	19100.00
0005435502952	20936	Economy	19100.00
0005435518447	20936	Economy	19100.00
0005434573650	20936	Economy	19100.00
0005435508824	20936	Economy	19100.00
0005432693856	3047	Business	10300.00
0005432693752	3047	Business	10300.00
0005432693774	3047	Economy	3400.00
0005432693668	3047	Economy	3400.00
0005432693775	3047	Economy	3400.00
0005432693834	3047	Economy	3800.00
0005432693817	3047	Economy	3800.00
0005432693778	3047	Economy	3800.00
0005432693821	3047	Economy	3800.00
0005432693790	3047	Economy	3400.00
0005432693712	3047	Economy	3400.00
0005432693833	3047	Economy	3400.00
0005432693835	3047	Economy	3400.00
0005432693857	3047	Economy	3400.00
0005432693738	3047	Economy	3400.00
0005432693849	3047	Economy	3400.00
0005432693808	3047	Economy	3400.00
0005432693703	3047	Economy	3400.00
0005432693870	3047	Economy	3400.00
0005432693644	3047	Economy	3400.00
0005432693812	3047	Economy	3400.00
0005432693822	3047	Economy	3400.00
0005432693772	3047	Economy	3400.00
0005432693743	3047	Economy	3400.00
0005432693850	3047	Economy	3400.00
0005432693643	3047	Economy	3400.00
0005432693811	3047	Economy	3400.00
0005432693702	3047	Economy	3400.00
0005432693646	3047	Economy	3400.00
0005432693728	3047	Economy	3400.00
0005432693791	3047	Economy	3400.00
0005432693727	3047	Economy	3400.00
0005432693768	3047	Economy	3400.00
0005432881159	3048	Business	10300.00
0005433124381	3048	Business	10300.00
0005432217861	3048	Business	10300.00
0005434310167	3048	Business	10300.00
0005432881126	3048	Business	10300.00
0005432881161	3048	Business	10300.00
0005434310177	3048	Economy	3400.00
0005433124422	3048	Economy	3400.00
0005433124421	3048	Economy	3400.00
0005433194942	3048	Economy	3400.00
0005434310175	3048	Economy	3400.00
0005433124406	3048	Economy	3800.00
0005432881179	3048	Economy	3800.00
0005433124336	3048	Economy	3800.00
0005432881140	3048	Economy	3800.00
0005433124285	3048	Economy	3400.00
0005433194911	3048	Economy	3400.00
0005433194925	3048	Economy	3400.00
0005434310178	3048	Economy	3400.00
0005433124387	3048	Economy	3400.00
0005432881166	3048	Economy	3400.00
0005433124287	3048	Economy	3400.00
0005432881165	3048	Economy	3400.00
0005433194941	3048	Economy	3400.00
0005434310174	3048	Economy	3400.00
0005434310170	3048	Economy	3400.00
0005433124425	3048	Economy	3400.00
0005434310166	3048	Economy	3400.00
0005433124337	3048	Economy	3400.00
0005434310168	3048	Economy	3400.00
0005432881162	3048	Economy	3400.00
0005434310165	3048	Economy	3400.00
0005432881171	3048	Economy	3400.00
0005434310171	3048	Economy	3400.00
0005432881146	3048	Economy	3400.00
0005434310179	3048	Economy	3400.00
0005433124417	3048	Economy	3400.00
0005433124443	3048	Economy	3400.00
0005433124388	3048	Economy	3400.00
0005432881152	3048	Economy	3400.00
0005432881214	3048	Economy	3400.00
0005433124339	3048	Economy	3400.00
0005433194909	3048	Economy	3400.00
0005434310176	3048	Economy	3400.00
0005432881154	3048	Economy	3400.00
0005434310173	3048	Economy	3400.00
0005433124286	3048	Economy	3400.00
0005432217862	3048	Economy	3400.00
0005434310169	3048	Economy	3400.00
0005433124431	3048	Economy	3400.00
0005433124432	3048	Economy	3400.00
0005434310172	3048	Economy	3400.00
0005432881141	3048	Economy	3400.00
0005433124531	29905	Business	10300.00
0005434300261	29905	Business	10300.00
0005433124534	29905	Business	10300.00
0005434300260	29905	Business	10300.00
0005432707430	29905	Business	10300.00
0005433124539	29905	Business	10300.00
0005432693963	29905	Business	10300.00
0005432707403	29905	Business	10300.00
0005432707450	29905	Economy	3400.00
0005433195001	29905	Economy	3400.00
0005433124535	29905	Economy	3400.00
0005432707384	29905	Economy	3400.00
0005434300267	29905	Economy	3400.00
0005432707290	29905	Economy	3800.00
0005433194999	29905	Economy	3800.00
0005433195004	29905	Economy	3800.00
0005432707368	29905	Economy	3400.00
0005433124540	29905	Economy	3400.00
0005432693966	29905	Economy	3400.00
0005432707351	29905	Economy	3400.00
0005432707258	29905	Economy	3400.00
0005432707349	29905	Economy	3400.00
0005434300264	29905	Economy	3400.00
0005434300266	29905	Economy	3400.00
0005433124533	29905	Economy	3400.00
0005432707451	29905	Economy	3400.00
0005433124532	29905	Economy	3400.00
0005433195006	29905	Economy	3400.00
0005432707291	29905	Economy	3400.00
0005432707386	29905	Economy	3400.00
0005433124537	29905	Economy	3400.00
0005432707385	29905	Economy	3400.00
0005434300263	29905	Economy	3400.00
0005433195007	29905	Economy	3400.00
0005432693967	29905	Economy	3400.00
0005432707399	29905	Economy	3400.00
0005434300265	29905	Economy	3400.00
0005433124538	29905	Economy	3400.00
0005432693965	29905	Economy	3400.00
0005432693962	29905	Economy	3400.00
0005433195000	29905	Economy	3400.00
0005433195002	29905	Economy	3400.00
0005433124536	29905	Economy	3400.00
0005433195005	29905	Economy	3400.00
0005432693961	29905	Economy	3400.00
0005433195003	29905	Economy	3400.00
0005432693964	29905	Economy	3400.00
0005434300262	29905	Economy	3400.00
0005432881243	29905	Economy	3400.00
0005432707423	29905	Economy	3400.00
0005432881244	29905	Economy	3400.00
0005432707429	29905	Economy	3400.00
0005434989102	23649	Economy	4000.00
0005434980663	23649	Economy	4000.00
0005434980655	23649	Economy	4000.00
0005434980661	23649	Economy	3600.00
0005434989099	23649	Economy	3600.00
0005434989104	23649	Economy	3600.00
0005434980662	23649	Economy	3600.00
0005434989106	23649	Economy	3600.00
0005434980659	23649	Economy	3600.00
0005434989108	23649	Economy	3600.00
0005434989105	23649	Economy	3600.00
0005434980657	23649	Economy	3600.00
0005434989103	23649	Economy	3600.00
0005434989107	23649	Economy	3600.00
0005434980660	23649	Economy	3600.00
0005434989101	23649	Economy	3600.00
0005434980656	23649	Economy	3600.00
0005434980658	23649	Economy	3600.00
0005434989109	23649	Economy	3600.00
0005434989110	23649	Economy	3600.00
0005434989100	23649	Economy	3600.00
0005434980394	27550	Economy	4000.00
0005434980481	27550	Economy	4000.00
0005434980376	27550	Economy	4000.00
0005434980408	27550	Economy	4000.00
0005434980354	27550	Economy	3600.00
0005434980362	27550	Economy	3600.00
0005434980377	27550	Economy	3600.00
0005434980556	27550	Economy	3600.00
0005434980554	27550	Economy	3600.00
0005434980400	27550	Economy	3600.00
0005434980436	27550	Economy	3600.00
0005434988987	27550	Economy	3600.00
0005434980378	27550	Economy	3600.00
0005434980498	27550	Economy	3600.00
0005434980412	27550	Economy	3600.00
0005434980384	27550	Economy	3600.00
0005434980435	27550	Economy	3600.00
0005434980411	27550	Economy	3600.00
0005434980418	27550	Economy	3600.00
0005434980402	27550	Economy	3600.00
0005434980407	27550	Economy	3600.00
0005434980482	27550	Economy	3600.00
0005434988966	27550	Economy	3600.00
0005434988914	27550	Economy	3600.00
0005434980393	27550	Economy	3600.00
0005434980448	27550	Economy	3600.00
0005434980434	27550	Economy	3600.00
0005434988968	27550	Economy	3600.00
0005434980555	27550	Economy	3600.00
0005434980486	27550	Economy	3600.00
0005434980433	27550	Economy	3600.00
0005434988951	27550	Economy	3600.00
0005434980506	27550	Economy	3600.00
0005434980532	27550	Economy	3600.00
0005434980473	27550	Economy	3600.00
0005434988972	27550	Economy	3600.00
0005434980474	27550	Economy	3600.00
0005434980363	27550	Economy	3600.00
0005433113586	10259	Economy	21600.00
0005433113582	10259	Economy	19700.00
0005433113583	10259	Economy	19700.00
0005434302580	10259	Economy	19700.00
0005433113592	10259	Economy	19700.00
0005435925604	3566	Business	26900.00
0005435925627	3566	Business	26900.00
0005435070551	3566	Business	26900.00
0005435925623	3566	Business	26900.00
0005435939930	3566	Economy	9000.00
0005435070553	3566	Economy	9000.00
0005435939928	3566	Economy	9900.00
0005435925575	3566	Economy	9900.00
0005435925574	3566	Economy	9900.00
0005435939937	3566	Economy	9000.00
0005435070552	3566	Economy	9000.00
0005435925597	3566	Economy	9000.00
0005435070554	3566	Economy	9000.00
0005435925573	3566	Economy	9000.00
0005435939949	3566	Economy	9000.00
0005435939938	3566	Economy	9000.00
0005435925599	3566	Economy	9000.00
0005435925600	3566	Economy	9000.00
0005435925577	3566	Economy	9000.00
0005435925579	3566	Economy	9000.00
0005435939929	3566	Economy	9000.00
0005435070550	3566	Economy	9000.00
0005435925626	3566	Economy	9000.00
0005435925581	3566	Economy	9000.00
0005435939919	3566	Economy	9000.00
0005435925620	3566	Economy	9000.00
0005435925624	3566	Economy	9000.00
0005435070490	15287	Business	26900.00
0005435070405	15287	Business	26900.00
0005435070203	15287	Business	26900.00
0005435925712	15287	Business	26900.00
0005435070492	15287	Business	26900.00
0005435070173	15287	Business	26900.00
0005435070343	15287	Business	26900.00
0005435070365	15287	Business	26900.00
0005435070395	15287	Economy	9000.00
0005435070200	15287	Economy	9000.00
0005435070159	15287	Economy	9000.00
0005435070355	15287	Economy	9000.00
0005435070303	15287	Economy	9000.00
0005435070202	15287	Economy	9000.00
0005435070235	15287	Economy	9000.00
0005435070168	15287	Economy	9000.00
0005435070174	15287	Economy	9900.00
0005435070264	15287	Economy	9900.00
0005435070369	15287	Economy	9900.00
0005435925716	15287	Economy	9000.00
0005435939970	15287	Economy	9000.00
0005435070354	15287	Economy	9000.00
0005435070384	15287	Economy	9000.00
0005435070196	15287	Economy	9000.00
0005435070489	15287	Economy	9000.00
0005435070356	15287	Economy	9000.00
0005435070167	15287	Economy	9000.00
0005435070015	15287	Economy	9000.00
0005435070255	15287	Economy	9000.00
0005435070183	15287	Economy	9000.00
0005435070418	15287	Economy	9000.00
0005435070191	15287	Economy	9000.00
0005435070254	15287	Economy	9000.00
0005435950301	15287	Economy	9000.00
0005435070333	15287	Economy	9000.00
0005435070146	15287	Economy	9000.00
0005435070204	15287	Economy	9000.00
0005435070491	15287	Economy	9000.00
0005435070323	15287	Economy	9000.00
0005435070184	15287	Economy	9000.00
0005435070242	15287	Economy	9000.00
0005435925713	15287	Economy	9000.00
0005435070241	15287	Economy	9000.00
0005435070368	15287	Economy	9000.00
0005435925718	15287	Economy	9000.00
0005435070007	15287	Economy	9000.00
0005435070201	15287	Economy	9000.00
0005435925711	15287	Economy	9000.00
0005435070199	15287	Economy	9000.00
0005435070232	15287	Economy	9000.00
0005435925714	15287	Economy	9000.00
0005435070322	15287	Economy	9000.00
0005435939969	15287	Economy	9000.00
0005435070334	15287	Economy	9000.00
0005435070310	15287	Economy	9000.00
0005435070165	15287	Economy	9000.00
0005435950312	15287	Economy	9000.00
0005435925717	15287	Economy	9000.00
0005435925715	15287	Economy	9000.00
0005435070195	15287	Economy	9000.00
0005435070283	15287	Economy	9000.00
0005435950311	15287	Economy	9000.00
0005435070143	15287	Economy	9000.00
0005435925719	15287	Economy	9000.00
0005435070344	15287	Economy	9000.00
0005435070357	15287	Economy	9000.00
0005435070396	15287	Economy	9000.00
0005432659768	18153	Economy	5900.00
0005432658653	18153	Economy	5900.00
0005432664183	26391	Economy	5900.00
0005432664180	26391	Economy	5900.00
0005432664188	26391	Economy	5900.00
0005432667504	26391	Economy	5900.00
0005432660859	26391	Economy	5900.00
0005432667505	26391	Economy	5900.00
0005432664181	26391	Economy	5900.00
0005432901983	66	Business	20000.00
0005433103344	66	Business	20000.00
0005433103345	66	Business	20000.00
0005433103407	66	Business	20000.00
0005432901963	66	Business	20000.00
0005432920403	66	Business	20000.00
0005432920353	66	Business	20000.00
0005432920213	66	Business	20000.00
0005432920432	66	Business	20000.00
0005433103438	66	Business	20000.00
0005433103206	66	Business	20000.00
0005432920363	66	Business	20000.00
0005433103230	66	Business	20000.00
0005433103427	66	Business	20000.00
0005432902070	66	Business	20000.00
0005433103205	66	Business	20000.00
0005433103353	66	Business	20000.00
0005432902043	66	Business	20000.00
0005432920398	66	Business	20000.00
0005433103433	66	Economy	7300.00
0005433103260	66	Economy	7300.00
0005433103383	66	Economy	7300.00
0005432920359	66	Economy	7300.00
0005433103373	66	Economy	6700.00
0005433103283	66	Economy	6700.00
0005433103414	66	Economy	6700.00
0005432920329	66	Economy	6700.00
0005432920214	66	Economy	6700.00
0005432920397	66	Economy	6700.00
0005433103268	66	Economy	6700.00
0005432920244	66	Economy	6700.00
0005432920346	66	Economy	6700.00
0005432902028	66	Economy	6700.00
0005433103300	66	Economy	6700.00
0005432920433	66	Economy	6700.00
0005432920405	66	Economy	6700.00
0005432902055	66	Economy	6700.00
0005432901982	66	Economy	6700.00
0005432901960	66	Economy	6700.00
0005432902029	66	Economy	6700.00
0005433103411	66	Economy	6700.00
0005433103279	66	Economy	6700.00
0005432901964	66	Economy	6700.00
0005432920328	66	Economy	6700.00
0005433103357	66	Economy	6700.00
0005433103360	66	Economy	6700.00
0005433103354	66	Economy	6700.00
0005433103355	66	Economy	6700.00
0005433103081	66	Economy	6700.00
0005432920434	66	Economy	6700.00
0005433103379	66	Economy	6700.00
0005432920362	66	Economy	6700.00
0005433103441	66	Economy	6700.00
0005433103350	66	Economy	6700.00
0005433103247	66	Economy	6700.00
0005433103310	66	Economy	6700.00
0005432920345	66	Economy	6700.00
0005433103436	66	Economy	6700.00
0005432902049	66	Economy	6700.00
0005433103343	66	Economy	6700.00
0005433103267	66	Economy	7300.00
0005432902073	66	Economy	7300.00
0005433103442	66	Economy	7300.00
0005432920348	66	Economy	7300.00
0005432920282	66	Economy	6700.00
0005433103402	66	Economy	6700.00
0005432902072	66	Economy	6700.00
0005433103259	66	Economy	6700.00
0005433103351	66	Economy	6700.00
0005432920399	66	Economy	6700.00
0005433103408	66	Economy	6700.00
0005433103378	66	Economy	6700.00
0005433103346	66	Economy	6700.00
0005433103142	66	Economy	6700.00
0005433103439	66	Economy	6700.00
0005433103367	66	Economy	6700.00
0005433103299	66	Economy	6700.00
0005432920374	66	Economy	6700.00
0005433103301	66	Economy	6700.00
0005432901961	66	Economy	6700.00
0005433103229	66	Economy	6700.00
0005433103403	66	Economy	6700.00
0005432920361	66	Economy	6700.00
0005432920243	66	Economy	6700.00
0005433103341	66	Economy	6700.00
0005432920395	66	Economy	6700.00
0005433103435	66	Economy	6700.00
0005433103082	66	Economy	6700.00
0005432902050	66	Economy	6700.00
0005432902048	66	Economy	6700.00
0005433103080	66	Economy	6700.00
0005432920435	66	Economy	6700.00
0005433103437	66	Economy	6700.00
0005433103302	66	Economy	6700.00
0005432157549	66	Economy	6700.00
0005432920352	66	Economy	6700.00
0005432902042	66	Economy	6700.00
0005432920325	66	Economy	6700.00
0005433103426	66	Economy	6700.00
0005433103352	66	Economy	6700.00
0005432920404	66	Economy	6700.00
0005433103384	66	Economy	6700.00
0005432920387	66	Economy	6700.00
0005432920347	66	Economy	6700.00
0005434175876	65	Business	20000.00
0005434157862	65	Business	20000.00
0005434157886	65	Business	20000.00
0005434157844	65	Business	20000.00
0005434157871	65	Business	20000.00
0005434157898	65	Business	20000.00
0005432263225	65	Business	20000.00
0005432263224	65	Business	20000.00
0005434157846	65	Business	20000.00
0005434157867	65	Business	20000.00
0005434157866	65	Business	20000.00
0005432753374	65	Business	20000.00
0005434157881	65	Business	20000.00
0005434157899	65	Economy	7300.00
0005434175877	65	Economy	7300.00
0005434157908	65	Economy	7300.00
0005434157913	65	Economy	6700.00
0005434157854	65	Economy	6700.00
0005434175875	65	Economy	6700.00
0005434157872	65	Economy	6700.00
0005434157856	65	Economy	6700.00
0005434157857	65	Economy	6700.00
0005434157859	65	Economy	6700.00
0005433690976	65	Economy	6700.00
0005432756919	65	Economy	6700.00
0005433477286	65	Economy	6700.00
0005434157885	65	Economy	6700.00
0005434175874	65	Economy	6700.00
0005433690967	65	Economy	6700.00
0005434157915	65	Economy	6700.00
0005432753370	65	Economy	6700.00
0005432753372	65	Economy	6700.00
0005434157876	65	Economy	6700.00
0005434157863	65	Economy	6700.00
0005434157890	65	Economy	6700.00
0005432818331	65	Economy	6700.00
0005433690972	65	Economy	6700.00
0005432207738	65	Economy	6700.00
0005434157895	65	Economy	6700.00
0005434157864	65	Economy	6700.00
0005434157879	65	Economy	6700.00
0005432818330	65	Economy	6700.00
0005434157904	65	Economy	6700.00
0005434157858	65	Economy	6700.00
0005434157911	65	Economy	6700.00
0005434157900	65	Economy	6700.00
0005434175873	65	Economy	6700.00
0005434157855	65	Economy	6700.00
0005434157849	65	Economy	6700.00
0005434157878	65	Economy	6700.00
0005434157892	65	Economy	6700.00
0005434157903	65	Economy	6700.00
0005434157843	65	Economy	6700.00
0005434157912	65	Economy	6700.00
0005434157869	65	Economy	6700.00
0005432818332	65	Economy	6700.00
0005434157877	65	Economy	6700.00
0005433690965	65	Economy	7300.00
0005434157860	65	Economy	7300.00
0005434157865	65	Economy	7300.00
0005434157853	65	Economy	6700.00
0005434157910	65	Economy	6700.00
0005434157914	65	Economy	6700.00
0005434157873	65	Economy	6700.00
0005433687748	65	Economy	6700.00
0005434157845	65	Economy	6700.00
0005432753375	65	Economy	6700.00
0005434157861	65	Economy	6700.00
0005433477287	65	Economy	6700.00
0005434157896	65	Economy	6700.00
0005434157874	65	Economy	6700.00
0005434157848	65	Economy	6700.00
0005434157852	65	Economy	6700.00
0005433477285	65	Economy	6700.00
0005434157893	65	Economy	6700.00
0005434157875	65	Economy	6700.00
0005434157847	65	Economy	6700.00
0005434157870	65	Economy	6700.00
0005434175872	65	Economy	6700.00
0005434157891	65	Economy	6700.00
0005434157883	65	Economy	6700.00
0005434157902	65	Economy	6700.00
0005432753373	65	Economy	6700.00
0005434157897	65	Economy	6700.00
0005432263223	65	Economy	6700.00
0005433690961	65	Economy	6700.00
0005434157850	65	Economy	6700.00
0005433477284	65	Economy	6700.00
0005434157868	65	Economy	6700.00
0005432753369	65	Economy	6700.00
0005434157882	65	Economy	6700.00
0005434157894	65	Economy	6700.00
0005432289084	65	Economy	6700.00
0005434157851	65	Economy	6700.00
0005434157880	65	Economy	6700.00
0005434157905	65	Economy	6700.00
0005434157888	65	Economy	6700.00
0005434157907	65	Economy	6700.00
0005434157887	65	Economy	6700.00
0005432263222	65	Economy	6700.00
0005434157909	65	Economy	6700.00
0005434157901	65	Economy	6700.00
0005434157884	65	Economy	6700.00
0005432263226	65	Economy	6700.00
0005434157889	65	Economy	6700.00
0005432753368	65	Economy	6700.00
0005433690960	65	Economy	6700.00
0005434157906	65	Economy	6700.00
0005433103926	7970	Business	20000.00
0005433477024	7970	Business	20000.00
0005433103943	7970	Business	20000.00
0005433435527	7970	Business	20000.00
0005433477037	7970	Business	20000.00
0005433103913	7970	Business	20000.00
0005433477107	7970	Business	20000.00
0005433477045	7970	Business	20000.00
0005433477142	7970	Business	20000.00
0005433690987	7970	Business	20000.00
0005433477113	7970	Business	20000.00
0005432677690	7970	Business	20000.00
0005433477189	7970	Business	20000.00
0005433477093	7970	Business	20000.00
0005433103914	7970	Business	20000.00
0005433103938	7970	Business	20000.00
0005433435522	7970	Economy	7300.00
0005432021040	7970	Economy	7300.00
0005433477247	7970	Economy	6700.00
0005433477111	7970	Economy	6700.00
0005433103937	7970	Economy	6700.00
0005434151802	7970	Economy	6700.00
0005433103915	7970	Economy	6700.00
0005433476997	7970	Economy	6700.00
0005433477074	7970	Economy	6700.00
0005433477141	7970	Economy	6700.00
0005433103916	7970	Economy	6700.00
0005433103912	7970	Economy	6700.00
0005433477025	7970	Economy	6700.00
0005432021036	7970	Economy	6700.00
0005433477004	7970	Economy	6700.00
0005434152854	7970	Economy	6700.00
0005433103921	7970	Economy	6700.00
0005433929891	7970	Economy	6700.00
0005434028399	7970	Economy	6700.00
0005432044608	7970	Economy	6700.00
0005433476988	7970	Economy	6700.00
0005433435524	7970	Economy	6700.00
0005433103940	7970	Economy	6700.00
0005433929893	7970	Economy	6700.00
0005433929889	7970	Economy	6700.00
0005433477110	7970	Economy	6700.00
0005433103941	7970	Economy	6700.00
0005433103910	7970	Economy	6700.00
0005432021041	7970	Economy	6700.00
0005433103919	7970	Economy	6700.00
0005434152856	7970	Economy	6700.00
0005433103925	7970	Economy	6700.00
0005433103934	7970	Economy	6700.00
0005432021042	7970	Economy	6700.00
0005433103909	7970	Economy	6700.00
0005433476998	7970	Economy	6700.00
0005433477246	7970	Economy	6700.00
0005433103922	7970	Economy	6700.00
0005434028397	7970	Economy	6700.00
0005433477114	7970	Economy	6700.00
0005433103942	7970	Economy	6700.00
0005433477029	7970	Economy	6700.00
0005433103936	7970	Economy	6700.00
0005433103918	7970	Economy	7300.00
0005433103908	7970	Economy	7300.00
0005432920474	7970	Economy	7300.00
0005433477065	7970	Economy	6700.00
0005433477040	7970	Economy	6700.00
0005432021037	7970	Economy	6700.00
0005433435526	7970	Economy	6700.00
0005433477062	7970	Economy	6700.00
0005433103935	7970	Economy	6700.00
0005433103923	7970	Economy	6700.00
0005433477112	7970	Economy	6700.00
0005433929890	7970	Economy	6700.00
0005433690993	7970	Economy	6700.00
0005434152852	7970	Economy	6700.00
0005433103930	7970	Economy	6700.00
0005433103927	7970	Economy	6700.00
0005433477046	7970	Economy	6700.00
0005433103911	7970	Economy	6700.00
0005433435523	7970	Economy	6700.00
0005433477188	7970	Economy	6700.00
0005433477083	7970	Economy	6700.00
0005433103917	7970	Economy	6700.00
0005433477028	7970	Economy	6700.00
0005432044609	7970	Economy	6700.00
0005433477063	7970	Economy	6700.00
0005433476986	7970	Economy	6700.00
0005433477039	7970	Economy	6700.00
0005433477011	7970	Economy	6700.00
0005433477150	7970	Economy	6700.00
0005433103928	7970	Economy	6700.00
0005432021043	7970	Economy	6700.00
0005433435528	7970	Economy	6700.00
0005433103932	7970	Economy	6700.00
0005433103939	7970	Economy	6700.00
0005434028398	7970	Economy	6700.00
0005433929892	7970	Economy	6700.00
0005433477061	7970	Economy	6700.00
0005433435529	7970	Economy	6700.00
0005433103924	7970	Economy	6700.00
0005433476989	7970	Economy	6700.00
0005433477027	7970	Economy	6700.00
0005434152853	7970	Economy	6700.00
0005434151799	7970	Economy	6700.00
0005432021038	7970	Economy	6700.00
0005432021039	7970	Economy	6700.00
0005433690992	7970	Economy	6700.00
0005432920476	7970	Economy	6700.00
0005433103920	7970	Economy	6700.00
0005434152866	7970	Economy	6700.00
0005433103933	7970	Economy	6700.00
0005432920475	7970	Economy	6700.00
0005433103944	7970	Economy	6700.00
0005434152855	7970	Economy	6700.00
0005433476985	7970	Economy	6700.00
0005433103931	7970	Economy	6700.00
0005433929887	7970	Economy	6700.00
0005433929888	7970	Economy	6700.00
0005433435525	7970	Economy	6700.00
0005433103929	7970	Economy	6700.00
0005433477041	7970	Economy	6700.00
0005434152865	7970	Economy	6700.00
0005432818064	7973	Business	20000.00
0005432818180	7973	Business	20000.00
0005432818162	7973	Business	20000.00
0005432818072	7973	Business	20000.00
0005432818146	7973	Business	20000.00
0005432818133	7973	Business	20000.00
0005432818074	7973	Business	20000.00
0005432818169	7973	Business	20000.00
0005432818132	7973	Economy	7300.00
0005432818073	7973	Economy	6700.00
0005432818024	7973	Economy	6700.00
0005432818095	7973	Economy	6700.00
0005432818253	7973	Economy	6700.00
0005432818111	7973	Economy	6700.00
0005432818261	7973	Economy	6700.00
0005432902120	7973	Economy	6700.00
0005432818069	7973	Economy	6700.00
0005432902119	7973	Economy	6700.00
0005432818068	7973	Economy	6700.00
0005432818161	7973	Economy	6700.00
0005432902123	7973	Economy	6700.00
0005432818112	7973	Economy	6700.00
0005432818179	7973	Economy	6700.00
0005432818023	7973	Economy	7300.00
0005432818160	7973	Economy	6700.00
0005432902121	7973	Economy	6700.00
0005432902122	7973	Economy	6700.00
0005432818235	7973	Economy	6700.00
0005432818130	7973	Economy	6700.00
0005432818147	7973	Economy	6700.00
0005432818200	7973	Economy	6700.00
0005434175860	9693	Economy	6900.00
0005434175852	9693	Economy	6900.00
0005434175859	9693	Economy	6900.00
0005434175853	9693	Economy	6900.00
0005434175840	9693	Economy	6900.00
0005434175871	32330	Economy	6900.00
0005433870780	32330	Economy	6900.00
0005435903144	3484	Business	35000.00
0005432800276	3484	Business	35000.00
0005435914053	3484	Business	35000.00
0005435903161	3484	Comfort	19900.00
0005434427463	3484	Comfort	19900.00
0005434427460	3484	Comfort	19900.00
0005435903080	3484	Comfort	19900.00
0005434880973	3484	Comfort	19900.00
0005435626854	3484	Comfort	19900.00
0005435841846	3484	Comfort	19900.00
0005432800277	3484	Comfort	19900.00
0005434880976	3484	Comfort	19900.00
0005435127570	3484	Comfort	19900.00
0005435914039	3484	Comfort	19900.00
0005435626850	3484	Comfort	19900.00
0005435903105	3484	Economy	11700.00
0005435626849	3484	Economy	11700.00
0005435914067	3484	Economy	11700.00
0005435626852	3484	Economy	11700.00
0005435626848	3484	Economy	11700.00
0005435903114	3484	Economy	11700.00
0005435127575	3484	Economy	11700.00
0005432800280	3484	Economy	11700.00
0005432800279	3484	Economy	11700.00
0005435914066	3484	Economy	11700.00
0005434880972	3484	Economy	11700.00
0005435127573	3484	Economy	11700.00
0005435903121	3484	Economy	11700.00
0005434880971	3484	Economy	11700.00
0005432800278	3484	Economy	11700.00
0005435903086	3484	Economy	11700.00
0005432800274	3484	Economy	11700.00
0005435903109	3484	Economy	11700.00
0005435626842	3484	Economy	11700.00
0005432800282	3484	Economy	12800.00
0005434427459	3484	Economy	11700.00
0005432611818	3484	Economy	11700.00
0005435903088	3484	Economy	11700.00
0005435127572	3484	Economy	11700.00
0005432613982	3484	Economy	11700.00
0005434880975	3484	Economy	11700.00
0005435626845	3484	Economy	11700.00
0005432800275	3484	Economy	11700.00
0005434880969	3484	Economy	11700.00
0005435626844	3484	Economy	11700.00
0005435127569	3484	Economy	11700.00
0005435626851	3484	Economy	11700.00
0005432800281	3484	Economy	11700.00
0005435903106	3484	Economy	11700.00
0005435914061	3484	Economy	11700.00
0005435914004	3484	Economy	11700.00
0005434880970	3484	Economy	11700.00
0005435127576	3484	Economy	11700.00
0005434938717	3484	Economy	11700.00
0005435841840	3484	Economy	11700.00
0005435903127	3484	Economy	11700.00
0005435914729	3484	Economy	11700.00
0005435903145	3484	Economy	11700.00
0005434880977	3484	Economy	11700.00
0005434427462	3484	Economy	11700.00
0005434880978	3484	Economy	11700.00
0005435903110	3484	Economy	11700.00
0005435903160	3484	Economy	11700.00
0005434880974	3484	Economy	11700.00
0005435914737	3484	Economy	11700.00
0005435914733	3484	Economy	11700.00
0005435903129	3484	Economy	11700.00
0005435903079	3484	Economy	11700.00
0005434427458	3484	Economy	11700.00
0005435626847	3484	Economy	12800.00
0005435626846	3484	Economy	11700.00
0005435626853	3484	Economy	11700.00
0005435914095	3484	Economy	11700.00
0005434427461	3484	Economy	11700.00
0005434938716	3484	Economy	11700.00
0005435914738	3484	Economy	11700.00
0005435903120	3484	Economy	11700.00
0005435903158	3484	Economy	11700.00
0005435903159	3484	Economy	11700.00
0005432800283	3484	Economy	11700.00
0005435914736	3484	Economy	11700.00
0005435127574	3484	Economy	11700.00
0005435127571	3484	Economy	11700.00
0005435914040	3484	Economy	11700.00
0005435914003	3484	Economy	11700.00
0005435626841	3484	Economy	11700.00
0005435903084	3484	Economy	11700.00
0005435626843	3484	Economy	11700.00
0005434938718	3484	Economy	11700.00
0005435903128	3484	Economy	11700.00
0005435903061	3484	Economy	11700.00
0005435626856	3484	Economy	11700.00
0005435626855	3484	Economy	11700.00
0005432613981	3484	Economy	11700.00
0005435914735	3484	Economy	11700.00
0005435903089	3484	Economy	11700.00
0005435903085	3484	Economy	11700.00
0005432800122	14560	Business	35000.00
0005432607654	14560	Business	35000.00
0005434880429	14560	Business	35000.00
0005435127391	14560	Business	35000.00
0005434880532	14560	Business	35000.00
0005434880616	14560	Business	35000.00
0005432607672	14560	Business	35000.00
0005434880466	14560	Business	35000.00
0005435127293	14560	Business	35000.00
0005434427211	14560	Business	35000.00
0005432607671	14560	Business	35000.00
0005435914210	14560	Business	35000.00
0005434938533	14560	Business	35000.00
0005435127226	14560	Business	35000.00
0005434880205	14560	Business	35000.00
0005435626483	14560	Business	35000.00
0005434427379	14560	Business	35000.00
0005434427331	14560	Business	35000.00
0005434427255	14560	Business	35000.00
0005435127360	14560	Business	35000.00
0005432800142	14560	Business	35000.00
0005435626511	14560	Comfort	19900.00
0005434880370	14560	Comfort	19900.00
0005435127374	14560	Comfort	19900.00
0005434880754	14560	Comfort	19900.00
0005434880294	14560	Comfort	19900.00
0005432800132	14560	Comfort	19900.00
0005434880587	14560	Comfort	19900.00
0005435127244	14560	Comfort	19900.00
0005435626557	14560	Comfort	19900.00
0005434427344	14560	Comfort	19900.00
0005434427302	14560	Comfort	19900.00
0005434880590	14560	Comfort	19900.00
0005434938660	14560	Comfort	19900.00
0005432800040	14560	Comfort	19900.00
0005432800019	14560	Comfort	19900.00
0005435914778	14560	Comfort	19900.00
0005434880434	14560	Comfort	19900.00
0005432611785	14560	Comfort	19900.00
0005434880388	14560	Comfort	19900.00
0005434880465	14560	Comfort	19900.00
0005434880328	14560	Comfort	19900.00
0005434880669	14560	Comfort	19900.00
0005434427227	14560	Comfort	19900.00
0005434880257	14560	Comfort	19900.00
0005434880221	14560	Comfort	19900.00
0005434880369	14560	Comfort	19900.00
0005434880615	14560	Comfort	19900.00
0005432800155	14560	Comfort	19900.00
0005435127243	14560	Comfort	19900.00
0005435127221	14560	Comfort	19900.00
0005435626607	14560	Comfort	19900.00
0005435626594	14560	Economy	11700.00
0005434880579	14560	Economy	11700.00
0005435127377	14560	Economy	11700.00
0005434880389	14560	Economy	11700.00
0005432800058	14560	Economy	11700.00
0005434880408	14560	Economy	11700.00
0005432611792	14560	Economy	11700.00
0005434880512	14560	Economy	11700.00
0005432607657	14560	Economy	11700.00
0005432800134	14560	Economy	11700.00
0005435626574	14560	Economy	11700.00
0005435903219	14560	Economy	11700.00
0005435914209	14560	Economy	11700.00
0005432800201	14560	Economy	11700.00
0005435127117	14560	Economy	11700.00
0005434938644	14560	Economy	11700.00
0005434880176	14560	Economy	11700.00
0005435914205	14560	Economy	11700.00
0005434880250	14560	Economy	11700.00
0005434880423	14560	Economy	11700.00
0005435626580	14560	Economy	11700.00
0005432800105	14560	Economy	11700.00
0005435127426	14560	Economy	11700.00
0005435626568	14560	Economy	11700.00
0005434880260	14560	Economy	11700.00
0005434880414	14560	Economy	11700.00
0005434880488	14560	Economy	11700.00
0005434880525	14560	Economy	11700.00
0005432800212	14560	Economy	11700.00
0005435127203	14560	Economy	11700.00
0005434938647	14560	Economy	11700.00
0005434879977	14560	Economy	11700.00
0005434427286	14560	Economy	11700.00
0005435127365	14560	Economy	11700.00
0005435127373	14560	Economy	11700.00
0005432800211	14560	Economy	11700.00
0005434880792	14560	Economy	11700.00
0005435626595	14560	Economy	12800.00
0005434880295	14560	Economy	11700.00
0005432800124	14560	Economy	12800.00
0005435626573	14560	Economy	11700.00
0005432800059	14560	Economy	11700.00
0005432800158	14560	Economy	12800.00
0005434427301	14560	Economy	12800.00
0005434879880	14560	Economy	11700.00
0005435127161	14560	Economy	11700.00
0005435127228	14560	Economy	11700.00
0005434880449	14560	Economy	11700.00
0005434880249	14560	Economy	11700.00
0005432800123	14560	Economy	11700.00
0005434427314	14560	Economy	11700.00
0005434880514	14560	Economy	11700.00
0005434880412	14560	Economy	11700.00
0005434880450	14560	Economy	11700.00
0005434880416	14560	Economy	11700.00
0005435127275	14560	Economy	11700.00
0005434880481	14560	Economy	11700.00
0005434427381	14560	Economy	11700.00
0005434880729	14560	Economy	11700.00
0005434880272	14560	Economy	11700.00
0005435127455	14560	Economy	11700.00
0005434880119	14560	Economy	11700.00
0005435127390	14560	Economy	11700.00
0005432800064	14560	Economy	11700.00
0005435626563	14560	Economy	11700.00
0005435127376	14560	Economy	11700.00
0005432799895	14560	Economy	11700.00
0005435127250	14560	Economy	11700.00
0005434880462	14560	Economy	11700.00
0005435626598	14560	Economy	11700.00
0005434879938	14560	Economy	11700.00
0005434880311	14560	Economy	11700.00
0005434880653	14560	Economy	11700.00
0005435626566	14560	Economy	11700.00
0005435914775	14560	Economy	11700.00
0005434880091	14560	Economy	11700.00
0005434879937	14560	Economy	11700.00
0005434880132	14560	Economy	11700.00
0005434880095	14560	Economy	11700.00
0005432800184	14560	Economy	11700.00
0005434880230	14560	Economy	11700.00
0005435126997	14560	Economy	11700.00
0005435127157	14560	Economy	11700.00
0005434427326	14560	Economy	11700.00
0005434938679	14560	Economy	11700.00
0005434880215	14560	Economy	11700.00
0005434427307	14560	Economy	11700.00
0005434427205	14560	Economy	11700.00
0005434880463	14560	Economy	11700.00
0005435127428	14560	Economy	11700.00
0005434880526	14560	Economy	11700.00
0005435903217	14560	Economy	11700.00
0005434880598	14560	Economy	11700.00
0005434880396	14560	Economy	11700.00
0005435127155	14560	Economy	11700.00
0005435127204	14560	Economy	11700.00
0005435903218	14560	Economy	11700.00
0005435626575	14560	Economy	11700.00
0005435127294	14560	Economy	11700.00
0005434880540	14560	Economy	11700.00
0005435127307	14560	Economy	11700.00
0005434880482	14560	Economy	11700.00
0005435914776	14560	Economy	11700.00
0005434880513	14560	Economy	11700.00
0005435127118	14560	Economy	11700.00
0005434427345	14560	Economy	11700.00
0005435127125	14560	Economy	11700.00
0005432611778	14560	Economy	11700.00
0005432800081	14560	Economy	11700.00
0005435127235	14560	Economy	11700.00
0005432800074	14560	Economy	11700.00
0005434880701	14560	Economy	11700.00
0005434880296	14560	Economy	11700.00
0005434880668	14560	Economy	11700.00
0005434880368	14560	Economy	11700.00
0005432800082	14560	Economy	11700.00
0005434880278	14560	Economy	11700.00
0005434880397	14560	Economy	11700.00
0005435127358	14560	Economy	12800.00
0005434880047	14560	Economy	12800.00
0005434880453	14560	Economy	12800.00
0005432800083	14560	Economy	11700.00
0005435127222	14560	Economy	11700.00
0005434880240	14560	Economy	11700.00
0005434880031	14560	Economy	11700.00
0005434880395	14560	Economy	11700.00
0005435914779	14560	Economy	11700.00
0005435126998	14560	Economy	11700.00
0005432607659	14560	Economy	11700.00
0005434880222	14560	Economy	11700.00
0005435914777	14560	Economy	11700.00
0005435127359	14560	Economy	11700.00
0005432800091	14560	Economy	11700.00
0005435914206	14560	Economy	11700.00
0005435127261	14560	Economy	11700.00
0005434880264	14560	Economy	11700.00
0005435626512	14560	Economy	11700.00
0005434880678	14560	Economy	11700.00
0005434880063	14560	Economy	11700.00
0005434880229	14560	Economy	11700.00
0005432800041	14560	Economy	11700.00
0005434880207	14560	Economy	11700.00
0005432800051	14560	Economy	11700.00
0005434880156	14560	Economy	11700.00
0005432800090	14560	Economy	11700.00
0005435127299	14560	Economy	11700.00
0005434880117	14560	Economy	11700.00
0005434427380	14560	Economy	11700.00
0005435127440	14560	Economy	11700.00
0005432799941	14560	Economy	11700.00
0005434427330	14560	Economy	11700.00
0005434880591	14560	Economy	11700.00
0005434938623	14560	Economy	11700.00
0005435626602	14560	Economy	11700.00
0005434938534	14560	Economy	11700.00
0005435127384	14560	Economy	11700.00
0005432800143	14560	Economy	11700.00
0005432800126	14560	Economy	11700.00
0005435127368	14560	Economy	11700.00
0005432607658	14560	Economy	11700.00
0005432800156	14560	Economy	11700.00
0005434938593	14560	Economy	11700.00
0005434880118	14560	Economy	11700.00
0005432611779	14560	Economy	11700.00
0005434880592	14560	Economy	11700.00
0005435127439	14560	Economy	11700.00
0005435626606	14560	Economy	11700.00
0005435626553	14560	Economy	11700.00
0005435626562	14560	Economy	11700.00
0005432800133	14560	Economy	11700.00
0005434880371	14560	Economy	11700.00
0005432799942	14560	Economy	11700.00
0005434880256	14560	Economy	11700.00
0005432800057	14560	Economy	11700.00
0005432800063	14560	Economy	11700.00
0005432607667	14560	Economy	11700.00
0005434880023	14560	Economy	11700.00
0005434880489	14560	Economy	11700.00
0005434880508	14560	Economy	11700.00
0005434880178	14560	Economy	11700.00
0005435127255	14560	Economy	11700.00
0005434880677	14560	Economy	11700.00
0005434880793	14560	Economy	11700.00
0005435127169	14560	Economy	11700.00
0005434880553	14560	Economy	11700.00
0005434880582	14560	Economy	11700.00
0005432800106	14560	Economy	11700.00
0005435626546	14560	Economy	11700.00
0005435626552	14560	Economy	11700.00
0005434880177	14560	Economy	11700.00
0005432607666	14560	Economy	11700.00
0005434880255	14560	Economy	11700.00
0005435914208	14560	Economy	11700.00
0005434880578	14560	Economy	11700.00
0005435914207	14560	Economy	11700.00
0005434880728	14560	Economy	11700.00
0005435914774	14560	Economy	11700.00
0005434880310	14560	Economy	11700.00
0005435890034	3591	Economy	14800.00
0005434325983	3591	Economy	14800.00
0005435890042	3591	Economy	14800.00
0005434325982	3591	Economy	14800.00
0005435890040	3591	Economy	14800.00
0005435890046	3591	Economy	14800.00
0005434325984	3591	Economy	14800.00
0005434325962	15625	Economy	16300.00
0005434311282	15625	Economy	16300.00
0005434325939	15625	Economy	16300.00
0005434325952	15625	Economy	16300.00
0005434325953	15625	Economy	14800.00
0005435890075	15625	Economy	14800.00
0005434311283	15625	Economy	14800.00
0005434325932	15625	Economy	14800.00
0005434325960	15625	Economy	14800.00
0005434325865	15625	Economy	14800.00
0005434325930	15625	Economy	14800.00
0005434325961	15625	Economy	14800.00
0005434325958	15625	Economy	14800.00
0005434325867	15625	Economy	14800.00
0005434325951	15625	Economy	14800.00
0005434325931	15625	Economy	14800.00
0005434325876	15625	Economy	14800.00
0005434325959	15625	Economy	14800.00
0005434325875	15625	Economy	14800.00
0005434325864	15625	Economy	14800.00
0005433420605	643	Economy	4500.00
0005433420602	643	Economy	4100.00
0005435958128	643	Economy	4100.00
0005433420616	643	Economy	4100.00
0005433420591	643	Economy	4100.00
0005435958130	643	Economy	4100.00
0005435958129	643	Economy	4100.00
0005433420613	643	Economy	4100.00
0005433420583	643	Economy	4100.00
0005433420601	643	Economy	4100.00
0005433420606	643	Economy	4100.00
0005433420599	643	Economy	4100.00
0005435958127	643	Economy	4100.00
0005433420617	643	Economy	4100.00
0005433420600	643	Economy	4100.00
0005433420561	643	Economy	4100.00
0005433420618	643	Economy	4100.00
0005435958042	15159	Economy	4500.00
0005435958047	15159	Economy	4500.00
0005435958067	15159	Economy	4500.00
0005435958073	15159	Economy	4100.00
0005435958057	15159	Economy	4100.00
0005435958041	15159	Economy	4100.00
0005435958102	15159	Economy	4100.00
0005435957923	15159	Economy	4100.00
0005435958010	15159	Economy	4100.00
0005435958049	15159	Economy	4100.00
0005435958068	15159	Economy	4100.00
0005435958002	15159	Economy	4100.00
0005435958058	15159	Economy	4100.00
0005435958019	15159	Economy	4100.00
0005435958048	15159	Economy	4100.00
0005435958018	15159	Economy	4100.00
0005435958017	15159	Economy	4100.00
0005435958066	15159	Economy	4100.00
0005435958074	15159	Economy	4100.00
0005435958046	15159	Economy	4100.00
0005435629445	8895	Economy	10400.00
0005435629451	8896	Economy	10400.00
0005435629450	8896	Economy	10400.00
0005435629429	16018	Economy	10400.00
0005434096786	11817	Economy	14700.00
0005434096783	11817	Economy	13400.00
0005434096785	11817	Economy	13400.00
0005434096779	11817	Economy	13400.00
0005434096782	11817	Economy	13400.00
0005434096780	11817	Economy	13400.00
0005434096781	11817	Economy	13400.00
0005434096784	11817	Economy	13400.00
0005434096787	11817	Economy	13400.00
0005434096805	20177	Economy	14700.00
0005434096803	20177	Economy	13400.00
0005434096802	20177	Economy	13400.00
0005434096804	20177	Economy	13400.00
0005432646247	25117	Business	87700.00
0005432646310	25117	Business	87700.00
0005435229638	25117	Business	87700.00
0005432646264	25117	Business	87700.00
0005432646268	25117	Business	87700.00
0005432646276	25117	Business	87700.00
0005432646260	25117	Business	87700.00
0005432646252	25117	Economy	29200.00
0005432646253	25117	Economy	29200.00
0005435229641	25117	Economy	29200.00
0005435229637	25117	Economy	29200.00
0005435229639	25117	Economy	29200.00
0005432646270	25117	Economy	32200.00
0005432646199	25117	Economy	29200.00
0005432646241	25117	Economy	29200.00
0005432646212	25117	Economy	29200.00
0005432646256	25117	Economy	29200.00
0005432646278	25117	Economy	29200.00
0005432646325	25117	Economy	29200.00
0005432646269	25117	Economy	29200.00
0005432646327	25117	Economy	29200.00
0005432646279	25117	Economy	29200.00
0005432646211	25117	Economy	29200.00
0005432646214	25117	Economy	29200.00
0005432646258	25117	Economy	29200.00
0005435229640	25117	Economy	29200.00
0005432646317	25117	Economy	29200.00
0005432646254	25117	Economy	29200.00
0005435229633	25117	Economy	29200.00
0005432646275	25117	Economy	29200.00
0005432646248	25117	Economy	29200.00
0005432646288	25117	Economy	29200.00
0005432646213	25117	Economy	29200.00
0005432646318	25117	Economy	29200.00
0005432646250	25117	Economy	29200.00
0005432646249	25117	Economy	29200.00
0005435229635	25117	Economy	29200.00
0005435229636	25117	Economy	29200.00
0005432646242	25117	Economy	29200.00
0005432646251	25117	Economy	29200.00
0005435229634	25117	Economy	29200.00
0005432646326	25117	Economy	29200.00
0005432646195	25117	Economy	29200.00
0005432646257	25117	Economy	29200.00
0005432646319	25117	Economy	29200.00
0005432646200	25117	Economy	29200.00
0005432646261	25117	Economy	29200.00
0005432646194	25117	Economy	29200.00
0005435797893	2868	Business	12600.00
0005435797894	2868	Economy	4200.00
0005433404946	2868	Economy	4200.00
0005435797895	2868	Economy	4200.00
0005433405036	29332	Business	12600.00
0005435797822	29332	Business	12600.00
0005435797787	29332	Economy	4200.00
0005435797788	29332	Economy	4200.00
0005435797825	29332	Economy	4600.00
0005435797819	29332	Economy	4600.00
0005435797841	29332	Economy	4200.00
0005435797821	29332	Economy	4200.00
0005435797789	29332	Economy	4200.00
0005435797790	29332	Economy	4200.00
0005435797771	29332	Economy	4200.00
0005435797818	29332	Economy	4200.00
0005435797814	29332	Economy	4200.00
0005435797842	29332	Economy	4200.00
0005435797826	29332	Economy	4200.00
0005435797824	29332	Economy	4200.00
0005435797857	29332	Economy	4200.00
0005435797795	29332	Economy	4200.00
0005435797854	29332	Economy	4200.00
0005435797813	29332	Economy	4200.00
0005433405037	29332	Economy	4200.00
0005435376415	5786	Economy	6800.00
0005434948264	5846	Economy	6800.00
0005434948237	16331	Economy	6800.00
0005435376431	16331	Economy	6800.00
0005434948222	16331	Economy	6800.00
0005435376430	16331	Economy	6800.00
0005434948239	16331	Economy	6800.00
0005434948238	16331	Economy	6800.00
0005434948233	16331	Economy	6800.00
0005434948234	16331	Economy	6800.00
0005434948228	16331	Economy	6800.00
0005433962728	6916	Business	21400.00
0005433962709	6916	Business	21400.00
0005433962701	6916	Business	21400.00
0005433962710	6916	Business	21400.00
0005433962722	6916	Economy	7100.00
0005433962720	6916	Economy	7100.00
0005433962729	6916	Economy	7100.00
0005433962703	6916	Economy	7800.00
0005433962700	6916	Economy	7800.00
0005433962717	6916	Economy	7100.00
0005433962708	6916	Economy	7100.00
0005433962726	6916	Economy	7100.00
0005433962721	6916	Economy	7100.00
0005433962704	6916	Economy	7100.00
0005435787477	6916	Economy	7100.00
0005433962719	6916	Economy	7100.00
0005433962730	6916	Economy	7100.00
0005433962711	6916	Economy	7100.00
0005433962725	6916	Economy	7100.00
0005433962716	6916	Economy	7100.00
0005433962712	6916	Economy	7100.00
0005433962718	6916	Economy	7100.00
0005433962706	6916	Economy	7100.00
0005433962713	6916	Economy	7100.00
0005433962705	6916	Economy	7100.00
0005433962723	6916	Economy	7100.00
0005433962727	6916	Economy	7100.00
0005433962702	6916	Economy	7100.00
0005433962707	6916	Economy	7100.00
0005433962715	6916	Economy	7100.00
0005433962724	6916	Economy	7100.00
0005433962714	6916	Economy	7100.00
0005433962047	25781	Business	21400.00
0005433962071	25781	Business	21400.00
0005433962066	25781	Business	21400.00
0005433962057	25781	Business	21400.00
0005433961869	25781	Business	21400.00
0005433962040	25781	Business	21400.00
0005433961859	25781	Business	21400.00
0005433961819	25781	Business	21400.00
0005433961908	25781	Business	21400.00
0005433961964	25781	Economy	7100.00
0005433962085	25781	Economy	7100.00
0005433962084	25781	Economy	7100.00
0005433961796	25781	Economy	7100.00
0005433961795	25781	Economy	7100.00
0005433962095	25781	Economy	7100.00
0005433961820	25781	Economy	7100.00
0005433962004	25781	Economy	7800.00
0005433961910	25781	Economy	7800.00
0005433961984	25781	Economy	7100.00
0005433962035	25781	Economy	7100.00
0005433961887	25781	Economy	7100.00
0005433961857	25781	Economy	7100.00
0005433961987	25781	Economy	7100.00
0005433961921	25781	Economy	7100.00
0005433961911	25781	Economy	7100.00
0005433961941	25781	Economy	7100.00
0005433961783	25781	Economy	7100.00
0005433961922	25781	Economy	7100.00
0005433961848	25781	Economy	7100.00
0005433961983	25781	Economy	7100.00
0005433961856	25781	Economy	7100.00
0005433961982	25781	Economy	7100.00
0005433962065	25781	Economy	7100.00
0005433962070	25781	Economy	7100.00
0005433961942	25781	Economy	7100.00
0005433962056	25781	Economy	7100.00
0005433961886	25781	Economy	7100.00
0005433962054	25781	Economy	7100.00
0005433961960	25781	Economy	7100.00
0005433962073	25781	Economy	7100.00
0005433962036	25781	Economy	7100.00
0005433962072	25781	Economy	7100.00
0005433962023	25781	Economy	7100.00
0005433962044	25781	Economy	7100.00
0005433961858	25781	Economy	7100.00
0005433961889	25781	Economy	7100.00
0005433961920	25781	Economy	7100.00
0005433962014	25781	Economy	7100.00
0005433961888	25781	Economy	7100.00
0005433962096	25781	Economy	7100.00
0005433961913	25781	Economy	7100.00
0005433962032	25781	Economy	7100.00
0005433962083	25781	Economy	7100.00
0005433962055	25781	Economy	7100.00
0005433962068	25781	Economy	7100.00
0005433962022	25781	Economy	7100.00
0005433961933	25781	Economy	7100.00
0005433961868	25781	Economy	7100.00
0005433961828	25781	Economy	7100.00
0005433961821	25781	Economy	7100.00
0005433962002	25781	Economy	7100.00
0005433962074	25781	Economy	7100.00
0005433962033	25781	Economy	7100.00
0005433961909	25781	Economy	7100.00
0005433961912	25781	Economy	7100.00
0005433961961	25781	Economy	7100.00
0005433961890	25781	Economy	7100.00
0005433962003	25781	Economy	7100.00
0005433961847	25781	Economy	7100.00
0005435082979	24497	Economy	3900.00
0005435082978	24497	Economy	3900.00
0005435082972	24497	Economy	3900.00
0005435082984	24497	Economy	3900.00
0005435082980	24497	Economy	3900.00
0005435082976	24497	Economy	3900.00
0005435082950	24497	Economy	3900.00
0005435082977	24497	Economy	3900.00
0005435082971	24497	Economy	3900.00
0005435082947	24497	Economy	3900.00
0005435286749	5058	Business	18000.00
0005434245842	5058	Business	18000.00
0005434245841	5058	Economy	6000.00
0005433534547	5058	Economy	6000.00
0005432106953	5056	Business	18000.00
0005434230161	5056	Business	18000.00
0005432106948	5056	Business	18000.00
0005434230195	5056	Business	18000.00
0005434230180	5056	Business	18000.00
0005434230205	5056	Business	18000.00
0005434230191	5056	Business	18000.00
0005434230185	5056	Business	18000.00
0005433786179	5056	Business	18000.00
0005434230202	5056	Business	18000.00
0005435960166	5056	Business	18000.00
0005434230149	5056	Business	18000.00
0005434230169	5056	Business	18000.00
0005434230192	5056	Business	18000.00
0005434230162	5056	Business	18000.00
0005434230156	5056	Business	18000.00
0005434230148	5056	Business	18000.00
0005434230166	5056	Business	18000.00
0005434230153	5056	Business	18000.00
0005433786180	5056	Business	18000.00
0005435960167	5056	Economy	6600.00
0005433786176	5056	Economy	6600.00
0005434230193	5056	Economy	6600.00
0005433786183	5056	Economy	6600.00
0005434230145	5056	Economy	6000.00
0005434230196	5056	Economy	6000.00
0005434230203	5056	Economy	6000.00
0005433786161	5056	Economy	6000.00
0005434230172	5056	Economy	6000.00
0005432666447	5056	Economy	6000.00
0005434230143	5056	Economy	6000.00
0005435629448	5056	Economy	6000.00
0005434230210	5056	Economy	6000.00
0005434230197	5056	Economy	6000.00
0005434230141	5056	Economy	6000.00
0005434230151	5056	Economy	6000.00
0005432106946	5056	Economy	6000.00
0005432106950	5056	Economy	6000.00
0005433786166	5056	Economy	6000.00
0005434230198	5056	Economy	6000.00
0005434230171	5056	Economy	6000.00
0005433786163	5056	Economy	6000.00
0005434230146	5056	Economy	6000.00
0005434230147	5056	Economy	6000.00
0005432106949	5056	Economy	6000.00
0005434230150	5056	Economy	6000.00
0005433616817	5056	Economy	6000.00
0005434230181	5056	Economy	6000.00
0005434230175	5056	Economy	6000.00
0005433786169	5056	Economy	6000.00
0005434230144	5056	Economy	6000.00
0005432106952	5056	Economy	6000.00
0005433616819	5056	Economy	6000.00
0005434230178	5056	Economy	6000.00
0005434230187	5056	Economy	6000.00
0005434230184	5056	Economy	6000.00
0005434230204	5056	Economy	6000.00
0005433786168	5056	Economy	6000.00
0005434230207	5056	Economy	6000.00
0005435629447	5056	Economy	6000.00
0005432106947	5056	Economy	6000.00
0005433786174	5056	Economy	6000.00
0005433786171	5056	Economy	6000.00
0005433786181	5056	Economy	6000.00
0005433616818	5056	Economy	6000.00
0005434230160	5056	Economy	6000.00
0005434230139	5056	Economy	6000.00
0005434230159	5056	Economy	6000.00
0005434230168	5056	Economy	6000.00
0005433786182	5056	Economy	6600.00
0005434230209	5056	Economy	6600.00
0005434230183	5056	Economy	6600.00
0005434230142	5056	Economy	6000.00
0005434230208	5056	Economy	6000.00
0005434230140	5056	Economy	6000.00
0005434230200	5056	Economy	6000.00
0005434230194	5056	Economy	6000.00
0005433786178	5056	Economy	6000.00
0005433786175	5056	Economy	6000.00
0005434230155	5056	Economy	6000.00
0005434230186	5056	Economy	6000.00
0005435629446	5056	Economy	6000.00
0005434230164	5056	Economy	6000.00
0005434230163	5056	Economy	6000.00
0005434230190	5056	Economy	6000.00
0005434230188	5056	Economy	6000.00
0005434230206	5056	Economy	6000.00
0005434230157	5056	Economy	6000.00
0005434230189	5056	Economy	6000.00
0005434230179	5056	Economy	6000.00
0005434230170	5056	Economy	6000.00
0005433786177	5056	Economy	6000.00
0005432106951	5056	Economy	6000.00
0005433786165	5056	Economy	6000.00
0005434230165	5056	Economy	6000.00
0005434230167	5056	Economy	6000.00
0005434230201	5056	Economy	6000.00
0005435960168	5056	Economy	6000.00
0005434230158	5056	Economy	6000.00
0005433786160	5056	Economy	6000.00
0005433786184	5056	Economy	6000.00
0005433786170	5056	Economy	6000.00
0005434230173	5056	Economy	6000.00
0005434230154	5056	Economy	6000.00
0005433786162	5056	Economy	6000.00
0005434230199	5056	Economy	6000.00
0005434230152	5056	Economy	6000.00
0005433786173	5056	Economy	6000.00
0005434230174	5056	Economy	6000.00
0005433786167	5056	Economy	6000.00
0005434230176	5056	Economy	6000.00
0005434230177	5056	Economy	6000.00
0005433786172	5056	Economy	6000.00
0005433616820	5056	Economy	6000.00
0005433786164	5056	Economy	6000.00
0005434230182	5056	Economy	6000.00
0005432666448	5056	Economy	6000.00
0005434230038	5054	Business	18000.00
0005435270025	5054	Business	18000.00
0005433815494	5054	Business	18000.00
0005435270051	5054	Business	18000.00
0005435269938	5054	Business	18000.00
0005435269932	5054	Business	18000.00
0005435269928	5054	Business	18000.00
0005435269969	5054	Business	18000.00
0005432336264	5054	Business	18000.00
0005435270086	5054	Business	18000.00
0005435007586	5054	Business	18000.00
0005435007497	5054	Business	18000.00
0005434265889	5054	Business	18000.00
0005435270082	5054	Business	18000.00
0005434150077	5054	Business	18000.00
0005435269966	5054	Business	18000.00
0005435007622	5054	Business	18000.00
0005435270136	5054	Business	18000.00
0005435269948	5054	Business	18000.00
0005433815477	5054	Business	18000.00
0005432336300	5054	Economy	6600.00
0005435007579	5054	Business	18000.00
0005435269980	5054	Economy	6600.00
0005435007554	5054	Economy	6600.00
0005432336327	5054	Economy	6600.00
0005435270090	5054	Economy	6000.00
0005435269926	5054	Economy	6000.00
0005434265891	5054	Economy	6000.00
0005435270089	5054	Economy	6000.00
0005433815505	5054	Economy	6000.00
0005435007619	5054	Economy	6000.00
0005435007580	5054	Economy	6000.00
0005432336294	5054	Economy	6000.00
0005435270081	5054	Economy	6000.00
0005434230029	5054	Economy	6000.00
0005435269931	5054	Economy	6000.00
0005435007549	5054	Economy	6000.00
0005435269949	5054	Economy	6000.00
0005435007603	5054	Economy	6000.00
0005435269988	5054	Economy	6000.00
0005435007609	5054	Economy	6000.00
0005432336344	5054	Economy	6000.00
0005435269968	5054	Economy	6000.00
0005434230035	5054	Economy	6000.00
0005435269940	5054	Economy	6000.00
0005434312370	5054	Economy	6000.00
0005434265890	5054	Economy	6000.00
0005434265885	5054	Economy	6000.00
0005435007587	5054	Economy	6000.00
0005435270065	5054	Economy	6000.00
0005435007523	5054	Economy	6000.00
0005432336321	5054	Economy	6000.00
0005435007588	5054	Economy	6000.00
0005435007534	5054	Economy	6000.00
0005433688853	5054	Economy	6000.00
0005435270017	5054	Economy	6000.00
0005435007663	5054	Economy	6000.00
0005435270138	5054	Economy	6000.00
0005435007560	5054	Economy	6000.00
0005435270084	5054	Economy	6000.00
0005435270080	5054	Economy	6000.00
0005434173667	5054	Economy	6000.00
0005435270059	5054	Economy	6000.00
0005435270070	5054	Economy	6000.00
0005434230032	5054	Economy	6000.00
0005433815502	5054	Economy	6000.00
0005435270083	5054	Economy	6000.00
0005435269930	5054	Economy	6000.00
0005435269904	5054	Economy	6000.00
0005435270069	5054	Economy	6000.00
0005434265888	5054	Economy	6000.00
0005434265892	5054	Economy	6000.00
0005435270044	5054	Economy	6000.00
0005435269967	5054	Economy	6000.00
0005435007569	5054	Economy	6600.00
0005435270074	5054	Economy	6600.00
0005435270027	5054	Economy	6600.00
0005435007584	5054	Economy	6600.00
0005435007585	5054	Economy	6600.00
0005433688852	5054	Economy	6000.00
0005434265886	5054	Economy	6000.00
0005435007561	5054	Economy	6000.00
0005434230034	5054	Economy	6000.00
0005434312371	5054	Economy	6600.00
0005434230031	5054	Economy	6000.00
0005433815501	5054	Economy	6000.00
0005434230030	5054	Economy	6000.00
0005432336256	5054	Economy	6000.00
0005432336263	5054	Economy	6000.00
0005435269974	5054	Economy	6000.00
0005434265887	5054	Economy	6000.00
0005435270018	5054	Economy	6000.00
0005432336347	5054	Economy	6000.00
0005435270016	5054	Economy	6000.00
0005435270026	5054	Economy	6000.00
0005433815500	5054	Economy	6000.00
0005435007601	5054	Economy	6000.00
0005432336351	5054	Economy	6000.00
0005435270085	5054	Economy	6000.00
0005432336293	5054	Economy	6000.00
0005435269941	5054	Economy	6000.00
0005433688854	5054	Economy	6000.00
0005435270119	5054	Economy	6000.00
0005435269984	5054	Economy	6000.00
0005435269961	5054	Economy	6000.00
0005435007632	5054	Economy	6000.00
0005435007540	5054	Economy	6000.00
0005435270137	5054	Economy	6000.00
0005434150078	5054	Economy	6000.00
0005434230037	5054	Economy	6000.00
0005435007680	5054	Economy	6000.00
0005435269903	5054	Economy	6000.00
0005432336290	5054	Economy	6000.00
0005435269891	5054	Economy	6000.00
0005434230036	5054	Economy	6000.00
0005434265893	5054	Economy	6000.00
0005435007498	5054	Economy	6000.00
0005434230033	5054	Economy	6000.00
0005435007602	5054	Economy	6000.00
0005435269929	5054	Economy	6000.00
0005433815485	5054	Economy	6000.00
0005435007531	5054	Economy	6000.00
0005434312369	5054	Economy	6000.00
0005435269976	5054	Economy	6000.00
0005435269892	5054	Economy	6000.00
0005433685570	5054	Economy	6000.00
0005434230028	5054	Economy	6000.00
0005435269973	5054	Economy	6000.00
0005435270208	8577	Business	18000.00
0005432663079	8577	Business	18000.00
0005432663083	8577	Business	18000.00
0005434245800	8577	Business	18000.00
0005433785901	8577	Business	18000.00
0005435270211	8577	Business	18000.00
0005433785881	8577	Business	18000.00
0005434245640	8577	Business	18000.00
0005433785937	8577	Business	18000.00
0005433785834	8577	Business	18000.00
0005435270210	8577	Business	18000.00
0005434245666	8577	Business	18000.00
0005433785817	8577	Business	18000.00
0005432663080	8577	Business	18000.00
0005434245594	8577	Business	18000.00
0005435270205	8577	Economy	6600.00
0005433785716	8577	Economy	6600.00
0005433785852	8577	Economy	6600.00
0005435270214	8577	Economy	6000.00
0005433785813	8577	Economy	6000.00
0005433785721	8577	Economy	6000.00
0005435270209	8577	Economy	6000.00
0005434245710	8577	Economy	6000.00
0005435270207	8577	Economy	6000.00
0005434245547	8577	Economy	6000.00
0005434245791	8577	Economy	6000.00
0005435270213	8577	Economy	6000.00
0005433785833	8577	Economy	6000.00
0005433785722	8577	Economy	6000.00
0005434245709	8577	Economy	6000.00
0005432666439	8577	Economy	6000.00
0005433785806	8577	Economy	6000.00
0005433785698	8577	Economy	6000.00
0005433785860	8577	Economy	6000.00
0005433785770	8577	Economy	6000.00
0005433785747	8577	Economy	6000.00
0005434245783	8577	Economy	6000.00
0005434245558	8577	Economy	6000.00
0005434245732	8577	Economy	6000.00
0005435270212	8577	Economy	6000.00
0005433785781	8577	Economy	6000.00
0005434245598	8577	Economy	6000.00
0005434245546	8577	Economy	6000.00
0005434245792	8577	Economy	6000.00
0005434245559	8577	Economy	6000.00
0005434245665	8577	Economy	6000.00
0005433785588	8577	Economy	6000.00
0005434245638	8577	Economy	6000.00
0005433785807	8577	Economy	6600.00
0005433785804	8577	Economy	6600.00
0005434245451	8577	Economy	6600.00
0005433785957	8577	Economy	6000.00
0005433785776	8577	Economy	6000.00
0005433785763	8577	Economy	6000.00
0005433785827	8577	Economy	6000.00
0005433785664	8577	Economy	6000.00
0005434245799	8577	Economy	6000.00
0005433785785	8577	Economy	6000.00
0005435270218	8577	Economy	6000.00
0005434245733	8577	Economy	6000.00
0005434245450	8577	Economy	6000.00
0005433785756	8577	Economy	6000.00
0005432659750	8577	Economy	6000.00
0005434245734	8577	Economy	6000.00
0005435270217	8577	Economy	6000.00
0005434245629	8577	Economy	6000.00
0005434245639	8577	Economy	6000.00
0005433785855	8577	Economy	6000.00
0005434245743	8577	Economy	6000.00
0005433785803	8577	Economy	6000.00
0005433785818	8577	Economy	6000.00
0005435270206	8577	Economy	6000.00
0005433785808	8577	Economy	6000.00
0005434245609	8577	Economy	6000.00
0005433785764	8577	Economy	6000.00
0005435270215	8577	Economy	6000.00
0005434245721	8577	Economy	6000.00
0005432659749	8577	Economy	6000.00
0005434245452	8577	Economy	6000.00
0005435270216	8577	Economy	6000.00
0005434245735	8577	Economy	6000.00
0005433785854	8577	Economy	6000.00
0005433785832	8577	Economy	6000.00
0005433616164	8576	Business	18000.00
0005433616178	8576	Business	18000.00
0005433616475	8576	Business	18000.00
0005433616556	8576	Economy	6000.00
0005433616359	8576	Economy	6000.00
0005433616341	8576	Economy	6000.00
0005433616347	8576	Economy	6000.00
0005433616156	8576	Economy	6000.00
0005433616600	8576	Economy	6000.00
0005433616377	8576	Economy	6000.00
0005433616473	8576	Economy	6000.00
0005433616349	8576	Economy	6000.00
0005433616402	8576	Economy	6000.00
0005433616363	8576	Economy	6000.00
0005433616393	8576	Economy	6000.00
0005433616431	8576	Economy	6000.00
0005433615910	8576	Economy	6000.00
0005433616469	8576	Economy	6000.00
0005433616449	8576	Economy	6000.00
0005433616195	8576	Economy	6000.00
0005433615909	8576	Economy	6000.00
0005433616043	8576	Economy	6000.00
0005433616061	8576	Economy	6000.00
0005433616430	8576	Economy	6000.00
0005433616044	8576	Economy	6000.00
0005433616470	8576	Economy	6000.00
0005433616176	8576	Economy	6000.00
0005433616395	8576	Economy	6000.00
0005433616472	8576	Economy	6000.00
0005433616578	8576	Economy	6000.00
0005433616166	8576	Economy	6000.00
0005433615950	8576	Economy	6000.00
0005433616436	8576	Economy	6600.00
0005433616299	8576	Economy	6600.00
0005433616550	8576	Economy	6000.00
0005433616471	8576	Economy	6000.00
0005433616520	8576	Economy	6000.00
0005433616459	8576	Economy	6000.00
0005433616364	8576	Economy	6000.00
0005433616458	8576	Economy	6000.00
0005433616425	8576	Economy	6000.00
0005433616279	8576	Economy	6000.00
0005433616368	8576	Economy	6000.00
0005433616394	8576	Economy	6000.00
0005433616277	8576	Economy	6000.00
0005433616362	8576	Economy	6000.00
0005433616018	8576	Economy	6000.00
0005433616551	8576	Economy	6000.00
0005433616194	8576	Economy	6000.00
0005433616087	8576	Economy	6000.00
0005433616456	8576	Economy	6000.00
0005433616367	8576	Economy	6000.00
0005433616366	8576	Economy	6000.00
0005433616177	8576	Economy	6000.00
0005433616243	8576	Economy	6000.00
0005433616505	8576	Economy	6000.00
0005433616019	8576	Economy	6000.00
0005433616300	8576	Economy	6000.00
0005433616457	8576	Economy	6000.00
0005433616086	8576	Economy	6000.00
0005435286949	8575	Business	18000.00
0005435286987	8575	Business	18000.00
0005435551774	8575	Business	18000.00
0005435551773	8575	Business	18000.00
0005434265692	8575	Business	18000.00
0005434229901	8575	Business	18000.00
0005435286986	8575	Business	18000.00
0005434265746	8575	Business	18000.00
0005434173594	8575	Business	18000.00
0005435732737	8575	Business	18000.00
0005433534562	8575	Business	18000.00
0005434173608	8575	Business	18000.00
0005434229948	8575	Business	18000.00
0005435287007	8575	Business	18000.00
0005434265772	8575	Business	18000.00
0005435287004	8575	Business	18000.00
0005434265719	8575	Business	18000.00
0005435286990	8575	Business	18000.00
0005435286975	8575	Business	18000.00
0005434229853	8575	Business	18000.00
0005435286989	8575	Business	18000.00
0005434173607	8575	Economy	6600.00
0005434229918	8575	Economy	6600.00
0005435007716	8575	Economy	6600.00
0005435286959	8575	Economy	6600.00
0005435286968	8575	Economy	6600.00
0005434311279	8575	Economy	6000.00
0005435286965	8575	Economy	6000.00
0005434149984	8575	Economy	6000.00
0005435286961	8575	Economy	6000.00
0005435286956	8575	Economy	6000.00
0005434265800	8575	Economy	6000.00
0005434149985	8575	Economy	6000.00
0005435286954	8575	Economy	6000.00
0005435286988	8575	Economy	6000.00
0005435286998	8575	Economy	6000.00
0005435732732	8575	Economy	6000.00
0005434311280	8575	Economy	6000.00
0005435286958	8575	Economy	6000.00
0005435286967	8575	Economy	6000.00
0005435286971	8575	Economy	6000.00
0005434229859	8575	Economy	6000.00
0005435286950	8575	Economy	6000.00
0005432035756	8575	Economy	6000.00
0005432047664	8575	Economy	6000.00
0005434173596	8575	Economy	6000.00
0005434265720	8575	Economy	6000.00
0005435286982	8575	Economy	6000.00
0005434229949	8575	Economy	6000.00
0005434229899	8575	Economy	6000.00
0005434229872	8575	Economy	6000.00
0005434265754	8575	Economy	6000.00
0005434229952	8575	Economy	6000.00
0005434265834	8575	Economy	6000.00
0005434229864	8575	Economy	6000.00
0005435286974	8575	Economy	6000.00
0005435286996	8575	Economy	6000.00
0005435286973	8575	Economy	6000.00
0005434265799	8575	Economy	6000.00
0005435732731	8575	Economy	6000.00
0005435007715	8575	Economy	6000.00
0005435286985	8575	Economy	6000.00
0005435286976	8575	Economy	6000.00
0005434265755	8575	Economy	6000.00
0005434149974	8575	Economy	6000.00
0005435551772	8575	Economy	6000.00
0005435732734	8575	Economy	6000.00
0005435007717	8575	Economy	6000.00
0005435286991	8575	Economy	6000.00
0005434149937	8575	Economy	6000.00
0005434229865	8575	Economy	6000.00
0005435286983	8575	Economy	6000.00
0005434265737	8575	Economy	6000.00
0005434265693	8575	Economy	6000.00
0005435551775	8575	Economy	6600.00
0005434173595	8575	Economy	6600.00
0005435286980	8575	Economy	6000.00
0005434265824	8575	Economy	6000.00
0005435732736	8575	Economy	6600.00
0005434173613	8575	Economy	6000.00
0005435287006	8575	Economy	6000.00
0005435287000	8575	Economy	6000.00
0005435286963	8575	Economy	6000.00
0005434229945	8575	Economy	6000.00
0005435286955	8575	Economy	6000.00
0005434265753	8575	Economy	6000.00
0005432047665	8575	Economy	6000.00
0005435286981	8575	Economy	6000.00
0005434150025	8575	Economy	6000.00
0005435287003	8575	Economy	6000.00
0005435286984	8575	Economy	6000.00
0005435286978	8575	Economy	6000.00
0005432035759	8575	Economy	6000.00
0005435286977	8575	Economy	6000.00
0005435286979	8575	Economy	6000.00
0005435286960	8575	Economy	6000.00
0005434265785	8575	Economy	6000.00
0005434265642	8575	Economy	6000.00
0005435732733	8575	Economy	6000.00
0005434265691	8575	Economy	6000.00
0005435287002	8575	Economy	6000.00
0005434265773	8575	Economy	6000.00
0005435286970	8575	Economy	6000.00
0005434265801	8575	Economy	6000.00
0005435286952	8575	Economy	6000.00
0005435286995	8575	Economy	6000.00
0005434265815	8575	Economy	6000.00
0005435286966	8575	Economy	6000.00
0005434229923	8575	Economy	6000.00
0005435286997	8575	Economy	6000.00
0005435286962	8575	Economy	6000.00
0005435286994	8575	Economy	6000.00
0005434229862	8575	Economy	6000.00
0005435286957	8575	Economy	6000.00
0005434229863	8575	Economy	6000.00
0005435287005	8575	Economy	6000.00
0005434173597	8575	Economy	6000.00
0005435477010	8575	Economy	6000.00
0005435286999	8575	Economy	6000.00
0005435286964	8575	Economy	6000.00
0005435286993	8575	Economy	6000.00
0005435287001	8575	Economy	6000.00
0005435286953	8575	Economy	6000.00
0005432035758	8575	Economy	6000.00
0005435732735	8575	Economy	6000.00
0005434229950	8575	Economy	6000.00
0005435286969	8575	Economy	6000.00
0005434229861	8575	Economy	6000.00
0005435286992	8575	Economy	6000.00
0005435286972	8575	Economy	6000.00
0005432035757	8575	Economy	6000.00
0005435286951	8575	Economy	6000.00
0005434229951	8575	Economy	6000.00
0005434229953	8575	Economy	6000.00
0005435287008	8575	Economy	6000.00
0005434640038	12608	Economy	16200.00
0005434639821	12608	Economy	14800.00
0005434639983	12608	Economy	14800.00
0005434639853	12608	Economy	14800.00
0005434639870	12608	Economy	14800.00
0005433202790	12608	Economy	14800.00
0005434639931	12608	Economy	14800.00
0005434639875	12608	Economy	14800.00
0005434639917	12608	Economy	14800.00
0005434639822	12608	Economy	14800.00
0005434639884	12608	Economy	14800.00
0005434639922	12608	Economy	14800.00
0005434639874	12608	Economy	14800.00
0005434639854	12608	Economy	14800.00
0005433202792	12608	Economy	14800.00
0005434639883	12608	Economy	14800.00
0005434639820	12608	Economy	14800.00
0005433202791	12608	Economy	14800.00
0005433202789	12608	Economy	14800.00
0005434639921	12608	Economy	14800.00
0005434639920	12608	Economy	14800.00
0005434639872	12608	Economy	14800.00
0005434639871	12608	Economy	14800.00
0005434639869	12608	Economy	14800.00
0005434639866	12608	Economy	14800.00
0005433202677	23391	Economy	16200.00
0005433202663	23391	Economy	14800.00
0005433202659	23391	Economy	14800.00
0005434640093	23391	Economy	14800.00
0005434640091	23391	Economy	14800.00
0005433202691	23391	Economy	14800.00
0005433202658	23391	Economy	14800.00
0005433202700	23391	Economy	14800.00
0005434640094	23391	Economy	14800.00
0005434640088	23391	Economy	14800.00
0005433202644	23391	Economy	14800.00
0005434640089	23391	Economy	14800.00
0005433202657	23391	Economy	14800.00
0005433202713	23391	Economy	14800.00
0005434640092	23391	Economy	14800.00
0005434640095	23391	Economy	14800.00
0005434640087	23391	Economy	14800.00
0005434640090	23391	Economy	14800.00
0005432329611	21051	Business	18900.00
0005432383951	21051	Business	18900.00
0005432384134	21051	Business	18900.00
0005432384001	21051	Business	18900.00
0005432848910	21051	Business	18900.00
0005432383946	21051	Business	18900.00
0005432384080	21051	Business	18900.00
0005432329754	21051	Business	18900.00
0005432384103	21051	Business	18900.00
0005432329676	21051	Business	18900.00
0005432329511	21051	Business	18900.00
0005432848912	21051	Business	18900.00
0005432848916	21051	Economy	6300.00
0005432329680	21051	Economy	6300.00
0005432384053	21051	Economy	6300.00
0005432329897	21051	Economy	6300.00
0005432384133	21051	Economy	6300.00
0005432329585	21051	Economy	6300.00
0005432383994	21051	Economy	6300.00
0005432329854	21051	Economy	6300.00
0005432383878	21051	Economy	6300.00
0005432329855	21051	Economy	6900.00
0005432054393	21051	Economy	6900.00
0005432329702	21051	Economy	6900.00
0005432329851	21051	Economy	6900.00
0005432329853	21051	Economy	6300.00
0005432329848	21051	Economy	6300.00
0005432848911	21051	Economy	6300.00
0005432329531	21051	Economy	6300.00
0005432384014	21051	Economy	6300.00
0005432329669	21051	Economy	6300.00
0005432329741	21051	Economy	6300.00
0005432329677	21051	Economy	6300.00
0005432329628	21051	Economy	6300.00
0005432329841	21051	Economy	6300.00
0005432848915	21051	Economy	6300.00
0005432329629	21051	Economy	6300.00
0005432384047	21051	Economy	6300.00
0005432848917	21051	Economy	6300.00
0005432329786	21051	Economy	6300.00
0005432384118	21051	Economy	6300.00
0005432383969	21051	Economy	6300.00
0005432384002	21051	Economy	6300.00
0005432329821	21051	Economy	6300.00
0005432329846	21051	Economy	6300.00
0005432383870	21051	Economy	6300.00
0005432329752	21051	Economy	6300.00
0005432384037	21051	Economy	6300.00
0005432383935	21051	Economy	6300.00
0005432384073	21051	Economy	6300.00
0005432383842	21051	Economy	6300.00
0005432384104	21051	Economy	6300.00
0005432329729	21051	Economy	6300.00
0005432329775	21051	Economy	6300.00
0005432329698	21051	Economy	6300.00
0005432329512	21051	Economy	6300.00
0005432329678	21051	Economy	6300.00
0005432384083	21051	Economy	6300.00
0005432384015	21051	Economy	6300.00
0005432329667	21051	Economy	6300.00
0005432848913	21051	Economy	6300.00
0005432329776	21051	Economy	6300.00
0005432329467	21051	Economy	6300.00
0005432384095	21051	Economy	6300.00
0005432329699	21051	Economy	6300.00
0005432054392	21051	Economy	6300.00
0005432329852	21051	Economy	6300.00
0005432329689	21051	Economy	6300.00
0005432329690	21051	Economy	6300.00
0005432384096	21051	Economy	6300.00
0005432329739	21051	Economy	6300.00
0005432329847	21051	Economy	6300.00
0005432383934	21051	Economy	6300.00
0005432384038	21051	Economy	6300.00
0005432329710	21051	Economy	6300.00
0005432329659	21051	Economy	6300.00
0005432383897	21051	Economy	6300.00
0005432329513	21051	Economy	6300.00
0005432329913	21051	Economy	6300.00
0005432384027	21051	Economy	6300.00
0005432329728	21051	Economy	6300.00
0005432329753	21051	Economy	6300.00
0005432329760	21051	Economy	6300.00
0005432848914	21051	Economy	6300.00
0005432384322	31276	Business	18900.00
0005432848868	31276	Business	18900.00
0005432330032	31276	Business	18900.00
0005432384314	31276	Business	18900.00
0005432330030	31276	Economy	6300.00
0005432848904	31276	Economy	6300.00
0005432330026	31276	Economy	6300.00
0005432848885	31276	Economy	6300.00
0005432848871	31276	Economy	6900.00
0005432330031	31276	Economy	6900.00
0005432384315	31276	Economy	6300.00
0005432330036	31276	Economy	6300.00
0005432848905	31276	Economy	6300.00
0005432330035	31276	Economy	6300.00
0005432848870	31276	Economy	6300.00
0005432330029	31276	Economy	6300.00
0005432384319	31276	Economy	6300.00
0005432330028	31276	Economy	6300.00
0005432384320	31276	Economy	6300.00
0005432384323	31276	Economy	6300.00
0005432330033	31276	Economy	6300.00
0005432848884	31276	Economy	6300.00
0005432330027	31276	Economy	6300.00
0005432384318	31276	Economy	6300.00
0005432384321	31276	Economy	6300.00
0005432330037	31276	Economy	6300.00
0005432330034	31276	Economy	6300.00
0005432384316	31276	Economy	6300.00
0005432330038	31276	Economy	6300.00
0005432384317	31276	Economy	6300.00
0005432330039	31276	Economy	6300.00
0005433642598	27593	Business	89600.00
0005432954192	27593	Business	89600.00
0005432954188	27593	Business	89600.00
0005432954191	27593	Business	89600.00
0005433642622	27593	Business	89600.00
0005433642595	27593	Business	89600.00
0005433642678	27593	Business	89600.00
0005432954189	27593	Business	89600.00
0005433642668	27593	Economy	29900.00
0005433642721	27593	Economy	29900.00
0005433642621	27593	Economy	29900.00
0005433642693	27593	Economy	32800.00
0005433642683	27593	Economy	32800.00
0005433642600	27593	Economy	29900.00
0005433642669	27593	Economy	29900.00
0005433642638	27593	Economy	29900.00
0005433642709	27593	Economy	29900.00
0005433642684	27593	Economy	29900.00
0005432954187	27593	Economy	29900.00
0005433642620	27593	Economy	29900.00
0005433642708	27593	Economy	29900.00
0005433642700	27593	Economy	29900.00
0005433642599	27593	Economy	29900.00
0005433642632	27593	Economy	29900.00
0005433642674	27593	Economy	29900.00
0005433642641	27593	Economy	29900.00
0005432954194	27593	Economy	29900.00
0005433642677	27593	Economy	29900.00
0005432954193	27593	Economy	29900.00
0005433642685	27593	Economy	29900.00
0005433642679	27593	Economy	29900.00
0005432954195	27593	Economy	29900.00
0005432954190	27593	Economy	29900.00
0005433642640	27593	Economy	29900.00
0005433642637	27593	Economy	29900.00
0005433642642	27593	Economy	29900.00
0005433642740	27593	Economy	29900.00
0005433642601	27593	Economy	29900.00
0005432425992	13307	Business	12700.00
0005432425964	13307	Business	12700.00
0005432425969	13307	Business	12700.00
0005432425982	13307	Business	12700.00
0005432425965	13307	Business	12700.00
0005432425949	13307	Business	12700.00
0005432425953	13307	Economy	4200.00
0005432425967	13307	Economy	4200.00
0005432425983	13307	Economy	4200.00
0005432425948	13307	Economy	4200.00
0005432425950	13307	Economy	4200.00
0005432425959	13307	Economy	4200.00
0005432425960	13307	Economy	4200.00
0005432425998	13307	Economy	4700.00
0005432425976	13307	Economy	4700.00
0005432425996	13307	Economy	4700.00
0005432425957	13307	Economy	4700.00
0005432425958	13307	Economy	4200.00
0005432425956	13307	Economy	4200.00
0005432425993	13307	Economy	4200.00
0005432425986	13307	Economy	4200.00
0005432425955	13307	Economy	4200.00
0005432425947	13307	Economy	4200.00
0005432425971	13307	Economy	4200.00
0005432425990	13307	Economy	4200.00
0005432425989	13307	Economy	4200.00
0005432425994	13307	Economy	4200.00
0005432425962	13307	Economy	4200.00
0005432425988	13307	Economy	4200.00
0005432425974	13307	Economy	4200.00
0005432425978	13307	Economy	4200.00
0005432425997	13307	Economy	4200.00
0005432425951	13307	Economy	4200.00
0005432425952	13307	Economy	4200.00
0005432425984	13307	Economy	4200.00
0005432425970	13307	Economy	4200.00
0005432425968	13307	Economy	4200.00
0005432425977	13307	Economy	4200.00
0005432425991	13307	Economy	4200.00
0005432425985	13307	Economy	4200.00
0005432425973	13307	Economy	4200.00
0005432425963	13307	Economy	4200.00
0005432425966	13307	Economy	4200.00
0005432425972	13307	Economy	4200.00
0005432425961	13307	Economy	4200.00
0005432425975	13307	Economy	4200.00
0005432425981	13307	Economy	4200.00
0005432425980	13307	Economy	4200.00
0005432425954	13307	Economy	4200.00
0005432425979	13307	Economy	4200.00
0005432425946	13307	Economy	4200.00
0005432425987	13307	Economy	4200.00
0005432425995	13307	Economy	4200.00
0005432462581	13307	Economy	4200.00
0005432425458	30739	Business	12700.00
0005432425577	30739	Business	12700.00
0005432425545	30739	Business	12700.00
0005432425516	30739	Business	12700.00
0005432425526	30739	Business	12700.00
0005432425535	30739	Business	12700.00
0005432425542	30739	Business	12700.00
0005432425543	30739	Economy	4200.00
0005432425404	30739	Economy	4200.00
0005432425412	30739	Economy	4200.00
0005432425495	30739	Economy	4200.00
0005432425176	30739	Economy	4200.00
0005432425529	30739	Economy	4200.00
0005432425517	30739	Economy	4700.00
0005432425498	30739	Economy	4700.00
0005432425552	30739	Economy	4700.00
0005432425460	30739	Economy	4200.00
0005432425175	30739	Economy	4200.00
0005432425496	30739	Economy	4200.00
0005432425447	30739	Economy	4200.00
0005432425566	30739	Economy	4200.00
0005432425515	30739	Economy	4200.00
0005432425433	30739	Economy	4200.00
0005432425518	30739	Economy	4200.00
0005432425558	30739	Economy	4200.00
0005432425514	30739	Economy	4200.00
0005432425568	30739	Economy	4200.00
0005432425541	30739	Economy	4200.00
0005432425411	30739	Economy	4200.00
0005432425441	30739	Economy	4200.00
0005432425520	30739	Economy	4200.00
0005432425576	30739	Economy	4200.00
0005432425509	30739	Economy	4200.00
0005432425525	30739	Economy	4200.00
0005432425549	30739	Economy	4200.00
0005432425538	30739	Economy	4200.00
0005432425177	30739	Economy	4200.00
0005432425368	30739	Economy	4200.00
0005432425565	30739	Economy	4200.00
0005432425428	30739	Economy	4200.00
0005432425567	30739	Economy	4200.00
0005432425524	30739	Economy	4200.00
0005432425531	30739	Economy	4200.00
0005432425484	30739	Economy	4200.00
0005432425446	30739	Economy	4200.00
0005432425407	30739	Economy	4200.00
0005432425429	30739	Economy	4200.00
0005432425532	30739	Economy	4200.00
0005432425392	30739	Economy	4200.00
0005432425497	30739	Economy	4200.00
0005432425548	30739	Economy	4200.00
0005432425494	30739	Economy	4200.00
0005432425461	30739	Economy	4200.00
0005432425459	30739	Economy	4200.00
0005432425499	30739	Economy	4200.00
0005432425544	30739	Economy	4200.00
0005432425537	30739	Economy	4200.00
0005432818330	9611	Business	32600.00
0005432901973	9611	Business	32600.00
0005434157650	9611	Business	32600.00
0005434157686	9611	Business	32600.00
0005434157637	9611	Business	32600.00
0005432902010	9611	Economy	10900.00
0005434157651	9611	Economy	10900.00
0005432902004	9611	Economy	10900.00
0005434186280	9611	Economy	11900.00
0005432901997	9611	Economy	11900.00
0005432818331	9611	Economy	10900.00
0005432902002	9611	Economy	10900.00
0005432901975	9611	Economy	10900.00
0005432901968	9611	Economy	10900.00
0005432902054	9611	Economy	10900.00
0005432902007	9611	Economy	10900.00
0005432901974	9611	Economy	10900.00
0005434157648	9611	Economy	10900.00
0005432902001	9611	Economy	10900.00
0005432902009	9611	Economy	10900.00
0005434157649	9611	Economy	10900.00
0005432822434	9611	Economy	10900.00
0005432822432	9611	Economy	10900.00
0005432902008	9611	Economy	10900.00
0005432902003	9611	Economy	10900.00
0005434157638	9611	Economy	10900.00
0005432902038	9611	Economy	10900.00
0005432289084	9611	Economy	10900.00
0005432818332	9611	Economy	10900.00
0005432822433	9611	Economy	10900.00
0005432902059	9611	Economy	10900.00
0005434186267	9611	Economy	10900.00
0005432902120	28972	Business	32600.00
0005432822392	28972	Business	32600.00
0005432902122	28972	Business	32600.00
0005432818064	28972	Business	32600.00
0005432818023	28972	Business	32600.00
0005432818160	28972	Economy	10900.00
0005432818162	28972	Economy	10900.00
0005432818072	28972	Economy	10900.00
0005432818132	28972	Economy	10900.00
0005432818133	28972	Economy	11900.00
0005432818253	28972	Economy	11900.00
0005432818180	28972	Economy	10900.00
0005434448388	28972	Economy	10900.00
0005434448386	28972	Economy	10900.00
0005432818068	28972	Economy	10900.00
0005432818069	28972	Economy	10900.00
0005432902121	28972	Economy	10900.00
0005432818200	28972	Economy	10900.00
0005432818095	28972	Economy	10900.00
0005432818147	28972	Economy	10900.00
0005432818261	28972	Economy	10900.00
0005432818112	28972	Economy	10900.00
0005432818235	28972	Economy	10900.00
0005432818179	28972	Economy	10900.00
0005432818024	28972	Economy	10900.00
0005434157711	28972	Economy	10900.00
0005432818161	28972	Economy	10900.00
0005432818146	28972	Economy	10900.00
0005432818169	28972	Economy	10900.00
0005432818073	28972	Economy	10900.00
0005432902119	28972	Economy	10900.00
0005432818111	28972	Economy	10900.00
0005432818074	28972	Economy	10900.00
0005432818130	28972	Economy	10900.00
0005432902123	28972	Economy	10900.00
0005435841840	15049	Economy	11000.00
0005432613982	15049	Economy	11000.00
0005432611818	15049	Economy	11000.00
0005432613981	15049	Economy	11000.00
0005435841846	15049	Economy	11000.00
0005432607666	31578	Economy	11000.00
0005432611779	31578	Economy	11000.00
0005432607672	31578	Economy	11000.00
0005432611785	31578	Economy	11000.00
0005432607671	31578	Economy	11000.00
0005432607658	31578	Economy	11000.00
0005432611778	31578	Economy	11000.00
0005432607667	31578	Economy	11000.00
0005432611792	31578	Economy	11000.00
0005432607657	31578	Economy	11000.00
0005432607659	31578	Economy	11000.00
0005432607654	31578	Economy	11000.00
0005432949263	11833	Business	105900.00
0005433570915	11833	Business	105900.00
0005432949410	11833	Business	105900.00
0005433570932	11833	Business	105900.00
0005432949319	11833	Business	105900.00
0005432949177	11833	Business	105900.00
0005432949366	11833	Business	105900.00
0005432949425	11833	Business	105900.00
0005433570920	11833	Business	105900.00
0005433570916	11833	Business	105900.00
0005433570923	11833	Business	105900.00
0005433570945	11833	Business	105900.00
0005433570931	11833	Business	105900.00
0005432949369	11833	Business	105900.00
0005432949272	11833	Business	105900.00
0005433570919	11833	Business	105900.00
0005432949344	11833	Business	105900.00
0005433570928	11833	Economy	35300.00
0005432949320	11833	Economy	35300.00
0005432949390	11833	Economy	35300.00
0005432949231	11833	Economy	35300.00
0005432949426	11833	Economy	35300.00
0005432949382	11833	Economy	35300.00
0005433570918	11833	Economy	35300.00
0005433570922	11833	Economy	35300.00
0005432949446	11833	Economy	35300.00
0005432949276	11833	Economy	38800.00
0005432949230	11833	Economy	38800.00
0005433570917	11833	Economy	38800.00
0005433570938	11833	Economy	35300.00
0005432949223	11833	Economy	35300.00
0005432949348	11833	Economy	35300.00
0005432949357	11833	Economy	35300.00
0005432949405	11833	Economy	35300.00
0005433570921	11833	Economy	35300.00
0005432949155	11833	Economy	35300.00
0005432949289	11833	Economy	35300.00
0005432949367	11833	Economy	35300.00
0005432949401	11833	Economy	35300.00
0005432949340	11833	Economy	35300.00
0005432949373	11833	Economy	35300.00
0005433570942	11833	Economy	35300.00
0005433570934	11833	Economy	35300.00
0005433570943	11833	Economy	35300.00
0005432949156	11833	Economy	35300.00
0005433570926	11833	Economy	35300.00
0005432949423	11833	Economy	35300.00
0005433570924	11833	Economy	35300.00
0005433570929	11833	Economy	35300.00
0005432949287	11833	Economy	35300.00
0005432949206	11833	Economy	35300.00
0005432949424	11833	Economy	35300.00
0005432949412	11833	Economy	35300.00
0005433570925	11833	Economy	35300.00
0005433570933	11833	Economy	35300.00
0005432949273	11833	Economy	35300.00
0005432949235	11833	Economy	35300.00
0005433570940	11833	Economy	35300.00
0005432949356	11833	Economy	35300.00
0005432949296	11833	Economy	35300.00
0005432949271	11833	Economy	35300.00
0005433570936	11833	Economy	35300.00
0005432949318	11833	Economy	35300.00
0005432949393	11833	Economy	35300.00
0005433570935	11833	Economy	35300.00
0005433570927	11833	Economy	35300.00
0005432949371	11833	Economy	35300.00
0005432949370	11833	Economy	35300.00
0005432949236	11833	Economy	35300.00
0005432949422	11833	Economy	35300.00
0005432949392	11833	Economy	35300.00
0005433570939	11833	Economy	35300.00
0005433570941	11833	Economy	35300.00
0005433570937	11833	Economy	35300.00
0005432949205	11833	Economy	35300.00
0005432949368	11833	Economy	35300.00
0005432949297	11833	Economy	35300.00
0005432949411	11833	Economy	35300.00
0005432949397	11833	Economy	35300.00
0005433570930	11833	Economy	35300.00
0005432949222	11833	Economy	35300.00
0005432949372	11833	Economy	35300.00
0005432949391	11833	Economy	35300.00
0005432949409	11833	Economy	35300.00
0005433570914	11833	Economy	35300.00
0005433570944	11833	Economy	35300.00
0005433570913	11833	Economy	35300.00
0005433570256	25324	Business	105900.00
0005433570030	25324	Business	105900.00
0005433570171	25324	Business	105900.00
0005433570281	25324	Business	105900.00
0005433570265	25324	Business	105900.00
0005432949690	25324	Business	105900.00
0005433570418	25324	Business	105900.00
0005432949686	25324	Business	105900.00
0005433570376	25324	Business	105900.00
0005433570612	25324	Business	105900.00
0005433570427	25324	Business	105900.00
0005433570517	25324	Business	105900.00
0005432949688	25324	Business	105900.00
0005433570390	25324	Business	105900.00
0005433570386	25324	Business	105900.00
0005432949682	25324	Business	105900.00
0005433570452	25324	Business	105900.00
0005433570489	25324	Economy	35300.00
0005433570257	25324	Economy	35300.00
0005433570560	25324	Economy	35300.00
0005433570454	25324	Economy	35300.00
0005433570202	25324	Economy	35300.00
0005433570578	25324	Economy	35300.00
0005433570247	25324	Economy	35300.00
0005433570481	25324	Economy	35300.00
0005433570248	25324	Economy	35300.00
0005433570421	25324	Economy	35300.00
0005433570451	25324	Economy	35300.00
0005433570326	25324	Economy	38800.00
0005432949684	25324	Economy	38800.00
0005433570465	25324	Economy	35300.00
0005433570317	25324	Economy	35300.00
0005433570516	25324	Economy	35300.00
0005433570519	25324	Economy	35300.00
0005433570673	25324	Economy	35300.00
0005433570594	25324	Economy	35300.00
0005433570545	25324	Economy	35300.00
0005433570520	25324	Economy	35300.00
0005432949683	25324	Economy	35300.00
0005433570521	25324	Economy	35300.00
0005433570753	25324	Economy	35300.00
0005433570165	25324	Economy	35300.00
0005433570662	25324	Economy	35300.00
0005432949687	25324	Economy	35300.00
0005433570546	25324	Economy	35300.00
0005433570599	25324	Economy	35300.00
0005433570327	25324	Economy	35300.00
0005433570235	25324	Economy	35300.00
0005433570359	25324	Economy	35300.00
0005433570388	25324	Economy	35300.00
0005433570583	25324	Economy	35300.00
0005433570712	25324	Economy	35300.00
0005433570609	25324	Economy	35300.00
0005432949691	25324	Economy	35300.00
0005433570302	25324	Economy	35300.00
0005433570354	25324	Economy	35300.00
0005433570318	25324	Economy	35300.00
0005432949685	25324	Economy	35300.00
0005433570262	25324	Economy	35300.00
0005433570416	25324	Economy	35300.00
0005433570205	25324	Economy	35300.00
0005433570450	25324	Economy	35300.00
0005433570387	25324	Economy	35300.00
0005433570269	25324	Economy	35300.00
0005433569960	25324	Economy	35300.00
0005433570561	25324	Economy	35300.00
0005433570357	25324	Economy	35300.00
0005433570268	25324	Economy	35300.00
0005433570389	25324	Economy	35300.00
0005432949689	25324	Economy	35300.00
0005433570355	25324	Economy	35300.00
0005433570595	25324	Economy	35300.00
0005432949692	25324	Economy	35300.00
0005433570206	25324	Economy	35300.00
0005432949680	25324	Economy	35300.00
0005432949681	25324	Economy	35300.00
0005433570035	25324	Economy	35300.00
0005433570492	25324	Economy	35300.00
0005433570312	25324	Economy	35300.00
0005433570564	25324	Economy	35300.00
0005433570356	25324	Economy	35300.00
0005433570417	25324	Economy	35300.00
0005433570477	25324	Economy	35300.00
0005433570282	25324	Economy	35300.00
0005433570422	25324	Economy	35300.00
0005434655538	5374	Business	67200.00
0005434655536	5374	Economy	22400.00
0005435340558	5374	Economy	22400.00
0005435340639	5374	Economy	22400.00
0005435340598	5374	Economy	22400.00
0005435340635	5374	Economy	22400.00
0005434655535	5374	Economy	22400.00
0005434655532	5374	Economy	22400.00
0005435555419	5374	Economy	22400.00
0005435340571	5374	Economy	22400.00
0005435340634	5374	Economy	22400.00
0005432114298	5374	Economy	22400.00
0005434655531	5374	Economy	22400.00
0005435340632	5374	Economy	22400.00
0005435340570	5374	Economy	22400.00
0005435340640	5374	Economy	22400.00
0005435555420	5374	Economy	22400.00
0005434655537	5374	Economy	22400.00
0005435340627	5374	Economy	22400.00
0005435340633	5374	Economy	22400.00
0005435340620	5374	Economy	22400.00
0005435555418	5374	Economy	22400.00
0005435555422	5374	Economy	22400.00
0005435340621	5374	Economy	22400.00
0005434655533	5374	Economy	22400.00
0005434655534	5374	Economy	22400.00
0005434655333	12525	Business	67200.00
0005434655337	12525	Business	67200.00
0005434655438	12525	Business	67200.00
0005434655340	12525	Business	67200.00
0005434655439	12525	Business	67200.00
0005434655433	12525	Economy	22400.00
0005434655222	12525	Economy	22400.00
0005434655437	12525	Economy	24600.00
0005434655257	12525	Economy	24600.00
0005434656608	12525	Economy	22400.00
0005434655434	12525	Economy	22400.00
0005434655419	12525	Economy	22400.00
0005434655288	12525	Economy	22400.00
0005434655338	12525	Economy	22400.00
0005434655320	12525	Economy	22400.00
0005434655289	12525	Economy	22400.00
0005434655426	12525	Economy	22400.00
0005434655409	12525	Economy	22400.00
0005434656602	12525	Economy	22400.00
0005434655246	12525	Economy	22400.00
0005434655410	12525	Economy	22400.00
0005434656609	12525	Economy	22400.00
0005434655401	12525	Economy	22400.00
0005434655303	12525	Economy	22400.00
0005434655327	12525	Economy	22400.00
0005434655217	12525	Economy	22400.00
0005434656598	12525	Economy	22400.00
0005434655334	12525	Economy	22400.00
0005434655418	12525	Economy	22400.00
0005434656599	12525	Economy	22400.00
0005434655403	12525	Economy	22400.00
0005434655283	12525	Economy	22400.00
0005434656607	12525	Economy	22400.00
0005434655306	12525	Economy	22400.00
0005433722500	7433	Business	32000.00
0005433656766	7433	Business	32000.00
0005433722491	7433	Business	32000.00
0005433717422	7433	Business	32000.00
0005432429010	7433	Economy	10700.00
0005433722497	7433	Economy	10700.00
0005433690985	7433	Economy	10700.00
0005435266254	7433	Economy	10700.00
0005435266272	7433	Economy	10700.00
0005433722501	7433	Economy	10700.00
0005433722489	7433	Economy	10700.00
0005435266246	7433	Economy	10700.00
0005433717415	7433	Economy	10700.00
0005433717419	7433	Economy	10700.00
0005433722492	7433	Economy	10700.00
0005435266262	7433	Economy	10700.00
0005432429011	7433	Economy	10700.00
0005433717416	7433	Economy	10700.00
0005432078268	7433	Economy	11700.00
0005433722496	7433	Economy	10700.00
0005432429009	7433	Economy	10700.00
0005433717423	7433	Economy	10700.00
0005432429006	7433	Economy	10700.00
0005435266285	7433	Economy	10700.00
0005432428993	7433	Economy	10700.00
0005433656767	7433	Economy	10700.00
0005432428992	7433	Economy	10700.00
0005433717420	7433	Economy	10700.00
0005435266255	7433	Economy	10700.00
0005433722495	7433	Economy	10700.00
0005433690986	7433	Economy	10700.00
0005433717421	7433	Economy	10700.00
0005433722493	7433	Economy	10700.00
0005433719240	7433	Economy	10700.00
0005433717417	7433	Economy	10700.00
0005432078269	7433	Economy	10700.00
0005432078271	7433	Economy	10700.00
0005432428994	7433	Economy	10700.00
0005433717418	7433	Economy	10700.00
0005433722498	7433	Economy	10700.00
0005433722490	7433	Economy	10700.00
0005433722494	7433	Economy	10700.00
0005432078270	7433	Economy	10700.00
0005435266245	7433	Economy	10700.00
0005433719241	7433	Economy	10700.00
0005435266296	7433	Economy	10700.00
0005433722499	7433	Economy	10700.00
0005433719239	7433	Economy	10700.00
0005433717148	29214	Business	32000.00
0005433717281	29214	Business	32000.00
0005433717211	29214	Business	32000.00
0005433717167	29214	Business	32000.00
0005433717039	29214	Business	32000.00
0005433717139	29214	Business	32000.00
0005432429030	29214	Business	32000.00
0005433688854	29214	Economy	10700.00
0005432429033	29214	Economy	10700.00
0005432006850	29214	Economy	10700.00
0005433719198	29214	Economy	10700.00
0005433716855	29214	Economy	10700.00
0005433717014	29214	Economy	10700.00
0005435266339	29214	Economy	10700.00
0005433717137	29214	Economy	10700.00
0005433716924	29214	Economy	10700.00
0005433717260	29214	Economy	10700.00
0005433717180	29214	Economy	10700.00
0005433717035	29214	Economy	10700.00
0005433722324	29214	Economy	10700.00
0005433717002	29214	Economy	10700.00
0005433656734	29214	Economy	10700.00
0005433716940	29214	Economy	10700.00
0005433685570	29214	Economy	10700.00
0005435266342	29214	Economy	10700.00
0005433722352	29214	Economy	10700.00
0005433717159	29214	Economy	10700.00
0005433717158	29214	Economy	10700.00
0005433719197	29214	Economy	10700.00
0005433717249	29214	Economy	10700.00
0005433688852	29214	Economy	10700.00
0005433717295	29214	Economy	10700.00
0005433717297	29214	Economy	10700.00
0005433722357	29214	Economy	10700.00
0005433717200	29214	Economy	10700.00
0005433717275	29214	Economy	10700.00
0005433717135	29214	Economy	11700.00
0005433717136	29214	Economy	11700.00
0005433717138	29214	Economy	11700.00
0005433719215	29214	Economy	11700.00
0005433717210	29214	Economy	10700.00
0005433719216	29214	Economy	10700.00
0005433656749	29214	Economy	10700.00
0005433717142	29214	Economy	10700.00
0005433716981	29214	Economy	10700.00
0005433717070	29214	Economy	10700.00
0005433717242	29214	Economy	10700.00
0005433656752	29214	Economy	10700.00
0005433717065	29214	Economy	10700.00
0005433717199	29214	Economy	10700.00
0005433656727	29214	Economy	10700.00
0005435266343	29214	Economy	10700.00
0005433717236	29214	Economy	10700.00
0005433717013	29214	Economy	10700.00
0005433722349	29214	Economy	10700.00
0005433688853	29214	Economy	10700.00
0005433716941	29214	Economy	10700.00
0005433717147	29214	Economy	10700.00
0005433717282	29214	Economy	10700.00
0005432429032	29214	Economy	10700.00
0005433717313	29214	Economy	10700.00
0005435266341	29214	Economy	10700.00
0005433722331	29214	Economy	10700.00
0005433717164	29214	Economy	10700.00
0005433717230	29214	Economy	10700.00
0005433717125	29214	Economy	10700.00
0005433716961	29214	Economy	10700.00
0005433722348	29214	Economy	10700.00
0005433719208	29214	Economy	10700.00
0005433717054	29214	Economy	10700.00
0005433716982	29214	Economy	10700.00
0005432429031	29214	Economy	10700.00
0005433716995	29214	Economy	10700.00
0005433719217	29214	Economy	10700.00
0005433716929	29214	Economy	10700.00
0005435266340	29214	Economy	10700.00
0005433717274	29214	Economy	10700.00
0005433716996	29214	Economy	10700.00
0005433717181	29214	Economy	10700.00
0005434143848	8673	Business	36500.00
0005434182458	8673	Business	36500.00
0005434095703	8673	Business	36500.00
0005434143854	8673	Economy	12200.00
0005434182482	8673	Economy	12200.00
0005434143847	8673	Economy	12200.00
0005434182453	8673	Economy	12200.00
0005434184718	8673	Economy	12200.00
0005434182541	8673	Economy	12200.00
0005434182460	8673	Economy	12200.00
0005434182459	8673	Economy	12200.00
0005434095702	8673	Economy	12200.00
0005434182505	8673	Economy	12200.00
0005434143850	8673	Economy	12200.00
0005434326063	8673	Economy	12200.00
0005434182455	8673	Economy	12200.00
0005434182504	8673	Economy	12200.00
0005434095701	8673	Economy	12200.00
0005434143856	8673	Economy	12200.00
0005434184717	8673	Economy	12200.00
0005434143851	8673	Economy	12200.00
0005434143849	8673	Economy	12200.00
0005434143853	8673	Economy	12200.00
0005434326064	8673	Economy	12200.00
0005434182507	8673	Economy	12200.00
0005434143852	8673	Economy	12200.00
0005434182506	8673	Economy	12200.00
0005434143855	8673	Economy	12200.00
0005434143857	8673	Economy	12200.00
0005434095603	11635	Business	36500.00
0005434182546	11635	Business	36500.00
0005435860723	11635	Business	36500.00
0005435860721	11635	Business	36500.00
0005434095582	11635	Business	36500.00
0005435860727	11635	Economy	12200.00
0005434095599	11635	Economy	13400.00
0005434095585	11635	Economy	13400.00
0005435860725	11635	Economy	13400.00
0005434184727	11635	Economy	12200.00
0005435860728	11635	Economy	12200.00
0005434095581	11635	Economy	12200.00
0005435860722	11635	Economy	12200.00
0005434095579	11635	Economy	12200.00
0005435860720	11635	Economy	12200.00
0005434095661	11635	Economy	12200.00
0005434095633	11635	Economy	12200.00
0005434182547	11635	Economy	12200.00
0005435860724	11635	Economy	12200.00
0005434143787	11635	Economy	12200.00
0005435860729	11635	Economy	12200.00
0005435860730	11635	Economy	12200.00
0005434095584	11635	Economy	12200.00
0005434095607	11635	Economy	12200.00
0005434095611	11635	Economy	12200.00
0005435860726	11635	Economy	12200.00
0005434143786	11635	Economy	12200.00
0005434184726	11635	Economy	12200.00
0005434095632	11635	Economy	12200.00
0005434095575	11635	Economy	12200.00
0005434182545	11635	Economy	12200.00
0005434095662	11635	Economy	12200.00
0005433399082	1431	Business	33000.00
0005433398877	1431	Business	33000.00
0005433398979	1431	Business	33000.00
0005435732717	1431	Business	33000.00
0005433399156	1431	Business	33000.00
0005433399190	1431	Business	33000.00
0005433398980	1431	Business	33000.00
0005433399377	1431	Business	33000.00
0005432297353	1431	Business	33000.00
0005433398989	1431	Economy	11000.00
0005433399177	1431	Economy	11000.00
0005435725785	1431	Economy	11000.00
0005433399249	1431	Economy	11000.00
0005435732722	1431	Economy	11000.00
0005435725783	1431	Economy	11000.00
0005433399072	1431	Economy	11000.00
0005435732720	1431	Economy	11000.00
0005433399268	1431	Economy	12100.00
0005433398988	1431	Economy	12100.00
0005435732718	1431	Economy	12100.00
0005435725782	1431	Economy	12100.00
0005433399208	1431	Economy	11000.00
0005433399095	1431	Economy	11000.00
0005433399108	1431	Economy	11000.00
0005433399083	1431	Economy	11000.00
0005433399246	1431	Economy	11000.00
0005433399285	1431	Economy	11000.00
0005433399155	1431	Economy	11000.00
0005433398987	1431	Economy	11000.00
0005435732721	1431	Economy	11000.00
0005432906600	1431	Economy	11000.00
0005433399293	1431	Economy	11000.00
0005433399263	1431	Economy	11000.00
0005432906595	1431	Economy	11000.00
0005433399335	1431	Economy	11000.00
0005433399216	1431	Economy	11000.00
0005435725780	1431	Economy	11000.00
0005433399334	1431	Economy	11000.00
0005433399133	1431	Economy	11000.00
0005433399143	1431	Economy	11000.00
0005433399188	1431	Economy	11000.00
0005433399148	1431	Economy	11000.00
0005433399292	1431	Economy	11000.00
0005432906591	1431	Economy	11000.00
0005433399191	1431	Economy	11000.00
0005433399294	1431	Economy	11000.00
0005433399131	1431	Economy	11000.00
0005435725781	1431	Economy	11000.00
0005433399207	1431	Economy	11000.00
0005433399096	1431	Economy	11000.00
0005433399157	1431	Economy	11000.00
0005435725784	1431	Economy	11000.00
0005433399181	1431	Economy	11000.00
0005435732719	1431	Economy	11000.00
0005433399215	1431	Economy	11000.00
0005432906580	1431	Economy	11000.00
0005433399248	1431	Economy	11000.00
0005433399259	1431	Economy	11000.00
0005433457078	19246	Business	33000.00
0005433457079	19246	Business	33000.00
0005433399462	19246	Economy	11000.00
0005433399463	19246	Economy	11000.00
0005435732685	19246	Economy	11000.00
0005433399455	19246	Economy	11000.00
0005433399456	19246	Economy	12100.00
0005433399454	19246	Economy	11000.00
0005433399458	19246	Economy	11000.00
0005435732653	19246	Economy	11000.00
0005433399457	19246	Economy	11000.00
0005435732684	19246	Economy	11000.00
0005435732664	19246	Economy	11000.00
0005435732656	19246	Economy	11000.00
0005435732611	19246	Economy	11000.00
0005435732582	19246	Economy	11000.00
0005435732635	19246	Economy	11000.00
0005433399460	19246	Economy	11000.00
0005433399459	19246	Economy	11000.00
0005435732630	19246	Economy	11000.00
0005435732663	19246	Economy	11000.00
0005435732636	19246	Economy	11000.00
0005433399461	19246	Economy	11000.00
0005435732634	19246	Economy	11000.00
0005434444014	17357	Economy	14100.00
0005434444091	17357	Economy	14100.00
0005434444093	17357	Economy	14100.00
0005434444115	17357	Economy	14100.00
0005434444114	17357	Economy	14100.00
0005434444059	17357	Economy	14100.00
0005434444083	17357	Economy	14100.00
0005434444096	17357	Economy	14100.00
0005434444090	17357	Economy	14100.00
0005434444033	17357	Economy	14100.00
0005434444047	17357	Economy	14100.00
0005434444034	17357	Economy	14100.00
0005434444084	17357	Economy	14100.00
0005434444180	20608	Economy	15600.00
0005434444179	20608	Economy	14100.00
0005434444178	20608	Economy	14100.00
0005434444177	20608	Economy	14100.00
0005435377631	7254	Economy	5800.00
0005435377632	7254	Economy	5800.00
0005435377635	7254	Economy	5800.00
0005434954678	28318	Economy	5800.00
0005434954679	28318	Economy	5800.00
0005434954676	28318	Economy	5800.00
0005434954697	28318	Economy	5800.00
0005434954683	28318	Economy	5800.00
0005434954700	28318	Economy	5800.00
0005434954696	28318	Economy	5800.00
0005434326105	4488	Economy	15400.00
0005435893805	4488	Economy	14000.00
0005434326107	4488	Economy	14000.00
0005434352061	4488	Economy	14000.00
0005434326106	4488	Economy	14000.00
0005435893801	4488	Economy	14000.00
0005435893822	4488	Economy	14000.00
0005434352062	4488	Economy	14000.00
0005434352064	4488	Economy	14000.00
0005434326302	4488	Economy	14000.00
0005434352063	4488	Economy	14000.00
0005434351974	29676	Economy	15400.00
0005434351994	29676	Economy	14000.00
0005434351973	29676	Economy	14000.00
0005434351989	29676	Economy	14000.00
0005434351999	29676	Economy	14000.00
0005434351966	29676	Economy	14000.00
0005434352035	29676	Economy	14000.00
0005434351995	29676	Economy	14000.00
0005434351965	29676	Economy	14000.00
0005434351916	29676	Economy	14000.00
0005433345576	1048	Business	30600.00
0005433345365	1048	Business	30600.00
0005433269857	1048	Business	30600.00
0005433269862	1048	Business	30600.00
0005433345411	1048	Business	30600.00
0005433345574	1048	Business	30600.00
0005433344985	1048	Business	30600.00
0005433345245	1048	Business	30600.00
0005435545970	1048	Business	30600.00
0005433269858	1048	Business	30600.00
0005433345734	1048	Business	30600.00
0005433345285	1048	Business	30600.00
0005433345048	1048	Business	30600.00
0005433345332	1048	Business	30600.00
0005433345254	1048	Business	30600.00
0005433344877	1048	Business	30600.00
0005433345341	1048	Business	30600.00
0005433345537	1048	Business	30600.00
0005433345767	1048	Business	30600.00
0005433345249	1048	Business	30600.00
0005433159359	1048	Business	30600.00
0005433345266	1048	Economy	11200.00
0005433345145	1048	Economy	11200.00
0005433345166	1048	Economy	10200.00
0005433159365	1048	Economy	10200.00
0005433158194	1048	Economy	10200.00
0005433345015	1048	Economy	10200.00
0005433345396	1048	Economy	10200.00
0005433345284	1048	Economy	10200.00
0005435545969	1048	Economy	10200.00
0005435092361	1048	Economy	10200.00
0005433345713	1048	Economy	10200.00
0005433345308	1048	Economy	10200.00
0005433344986	1048	Economy	10200.00
0005433269856	1048	Economy	10200.00
0005433345561	1048	Economy	10200.00
0005433345210	1048	Economy	10200.00
0005433345536	1048	Economy	10200.00
0005433345232	1048	Economy	10200.00
0005433345638	1048	Economy	10200.00
0005435545972	1048	Economy	10200.00
0005435545968	1048	Economy	10200.00
0005433344944	1048	Economy	10200.00
0005432293280	1048	Economy	10200.00
0005433345420	1048	Economy	10200.00
0005433345067	1048	Economy	10200.00
0005433345450	1048	Economy	10200.00
0005433345557	1048	Economy	10200.00
0005433345062	1048	Economy	10200.00
0005433345768	1048	Economy	10200.00
0005433345247	1048	Economy	10200.00
0005433345454	1048	Economy	10200.00
0005433345611	1048	Economy	10200.00
0005433344967	1048	Economy	10200.00
0005433345380	1048	Economy	10200.00
0005433345211	1048	Economy	10200.00
0005433345317	1048	Economy	10200.00
0005433344971	1048	Economy	10200.00
0005433345628	1048	Economy	10200.00
0005433345419	1048	Economy	10200.00
0005433345650	1048	Economy	10200.00
0005433345228	1048	Economy	10200.00
0005433158182	1048	Economy	10200.00
0005435545966	1048	Economy	10200.00
0005433345614	1048	Economy	10200.00
0005433345255	1048	Economy	10200.00
0005433345586	1048	Economy	10200.00
0005433345511	1048	Economy	10200.00
0005433345585	1048	Economy	10200.00
0005433159367	1048	Economy	10200.00
0005433345575	1048	Economy	10200.00
0005433345589	1048	Economy	10200.00
0005433344791	1048	Economy	10200.00
0005434446590	1048	Economy	10200.00
0005433345186	1048	Economy	10200.00
0005432293279	1048	Economy	10200.00
0005433345456	1048	Economy	10200.00
0005435545996	1048	Economy	10200.00
0005433158179	1048	Economy	10200.00
0005433345292	1048	Economy	10200.00
0005433345146	1048	Economy	10200.00
0005433345248	1048	Economy	10200.00
0005433345624	1048	Economy	10200.00
0005433345244	1048	Economy	10200.00
0005433344982	1048	Economy	10200.00
0005433345004	1048	Economy	10200.00
0005435545995	1048	Economy	10200.00
0005433269863	1048	Economy	11200.00
0005433345597	1048	Economy	10200.00
0005433345225	1048	Economy	10200.00
0005433158193	1048	Economy	11200.00
0005433345047	1048	Economy	10200.00
0005433344839	1048	Economy	11200.00
0005433345549	1048	Economy	10200.00
0005433345451	1048	Economy	10200.00
0005434446591	1048	Economy	10200.00
0005433345556	1048	Economy	10200.00
0005433345421	1048	Economy	10200.00
0005433345340	1048	Economy	10200.00
0005435545967	1048	Economy	10200.00
0005435092362	1048	Economy	10200.00
0005433345348	1048	Economy	10200.00
0005433269861	1048	Economy	10200.00
0005433344847	1048	Economy	10200.00
0005433345316	1048	Economy	10200.00
0005433345002	1048	Economy	10200.00
0005435545971	1048	Economy	10200.00
0005433345005	1048	Economy	10200.00
0005433345063	1048	Economy	10200.00
0005433345028	1048	Economy	10200.00
0005433345455	1048	Economy	10200.00
0005433345588	1048	Economy	10200.00
0005433345329	1048	Economy	10200.00
0005433345623	1048	Economy	10200.00
0005433345265	1048	Economy	10200.00
0005433345320	1048	Economy	10200.00
0005433345714	1048	Economy	10200.00
0005433345667	1048	Economy	10200.00
0005433345615	1048	Economy	10200.00
0005433345526	1048	Economy	10200.00
0005433345227	1048	Economy	10200.00
0005433344876	1048	Economy	10200.00
0005433345264	1048	Economy	10200.00
0005433345003	1048	Economy	10200.00
0005433158192	1048	Economy	10200.00
0005433345374	1048	Economy	10200.00
0005433345309	1048	Economy	10200.00
0005433345375	1048	Economy	10200.00
0005435545997	1048	Economy	10200.00
0005433345418	1048	Economy	10200.00
0005433344997	1048	Economy	10200.00
0005433345701	1048	Economy	10200.00
0005433159366	1048	Economy	10200.00
0005433344943	1048	Economy	10200.00
0005433345458	1048	Economy	10200.00
0005433345222	1048	Economy	10200.00
0005433345051	1048	Economy	10200.00
0005433345591	1048	Economy	10200.00
0005433345424	1048	Economy	10200.00
0005433345347	1048	Economy	10200.00
0005433345368	1048	Economy	10200.00
0005433344996	1048	Economy	10200.00
0005433159362	1048	Economy	10200.00
0005433345573	1048	Economy	10200.00
0005433345378	1048	Economy	10200.00
0005435508744	17025	Business	30600.00
0005435092323	17025	Business	30600.00
0005435530033	17025	Business	30600.00
0005435508654	17025	Business	30600.00
0005435530051	17025	Business	30600.00
0005435092297	17025	Business	30600.00
0005435530110	17025	Business	30600.00
0005435529996	17025	Business	30600.00
0005434445290	17025	Business	30600.00
0005433346009	17025	Economy	11200.00
0005433346042	17025	Economy	11200.00
0005435530029	17025	Economy	10200.00
0005435508609	17025	Economy	10200.00
0005433346028	17025	Economy	10200.00
0005433346035	17025	Economy	10200.00
0005433346022	17025	Economy	10200.00
0005435508588	17025	Economy	10200.00
0005433346014	17025	Economy	10200.00
0005435092334	17025	Economy	10200.00
0005433346015	17025	Economy	10200.00
0005435530108	17025	Economy	10200.00
0005435530082	17025	Economy	10200.00
0005435508702	17025	Economy	10200.00
0005433346031	17025	Economy	10200.00
0005433346038	17025	Economy	10200.00
0005435530081	17025	Economy	10200.00
0005433346032	17025	Economy	10200.00
0005435530059	17025	Economy	10200.00
0005435508645	17025	Economy	10200.00
0005435508712	17025	Economy	10200.00
0005435508733	17025	Economy	10200.00
0005435529999	17025	Economy	10200.00
0005435530061	17025	Economy	10200.00
0005435530058	17025	Economy	10200.00
0005435092333	17025	Economy	10200.00
0005433346020	17025	Economy	10200.00
0005435508618	17025	Economy	10200.00
0005435508550	17025	Economy	10200.00
0005433346030	17025	Economy	10200.00
0005433346013	17025	Economy	10200.00
0005433346019	17025	Economy	10200.00
0005433346040	17025	Economy	10200.00
0005433346033	17025	Economy	10200.00
0005435530060	17025	Economy	10200.00
0005434445295	17025	Economy	10200.00
0005433346012	17025	Economy	10200.00
0005433346018	17025	Economy	10200.00
0005435092295	17025	Economy	10200.00
0005433346043	17025	Economy	10200.00
0005435508701	17025	Economy	10200.00
0005435530083	17025	Economy	10200.00
0005435508655	17025	Economy	10200.00
0005433346037	17025	Economy	10200.00
0005433346041	17025	Economy	10200.00
0005435530035	17025	Economy	10200.00
0005433346021	17025	Economy	10200.00
0005435508663	17025	Economy	10200.00
0005433346024	17025	Economy	10200.00
0005435508662	17025	Economy	10200.00
0005435530002	17025	Economy	10200.00
0005433346029	17025	Economy	10200.00
0005433346044	17025	Economy	10200.00
0005435530045	17025	Economy	10200.00
0005435508646	17025	Economy	10200.00
0005433346023	17025	Economy	10200.00
0005435508711	17025	Economy	10200.00
0005433346027	17025	Economy	10200.00
0005435530109	17025	Economy	10200.00
0005435530063	17025	Economy	10200.00
0005435530005	17025	Economy	10200.00
0005433346036	17025	Economy	10200.00
0005435092277	17025	Economy	10200.00
0005433269874	17025	Economy	10200.00
0005435508700	17025	Economy	10200.00
0005435508652	17025	Economy	10200.00
0005433346034	17025	Economy	10200.00
0005435530111	17025	Economy	10200.00
0005433346025	17025	Economy	10200.00
0005434445305	17025	Economy	10200.00
0005435508659	17025	Economy	10200.00
0005435529995	17025	Economy	10200.00
0005433346017	17025	Economy	10200.00
0005433346039	17025	Economy	10200.00
0005433346011	17025	Economy	10200.00
0005435530040	17025	Economy	10200.00
0005435530038	17025	Economy	10200.00
0005433346016	17025	Economy	10200.00
0005435530021	17025	Economy	10200.00
0005435530001	17025	Economy	10200.00
0005435530034	17025	Economy	10200.00
0005435092278	17025	Economy	10200.00
0005435508619	17025	Economy	10200.00
0005433346026	17025	Economy	10200.00
0005433346010	17025	Economy	10200.00
0005432852047	1334	Business	101000.00
0005432852025	1334	Business	101000.00
0005432852029	1334	Business	101000.00
0005432852043	1334	Business	101000.00
0005432390468	1334	Business	101000.00
0005432852024	1334	Business	101000.00
0005432852050	1334	Business	101000.00
0005432852032	1334	Business	101000.00
0005432852051	1334	Economy	33700.00
0005432852042	1334	Business	101000.00
0005432852048	1334	Economy	33700.00
0005432390484	1334	Economy	33700.00
0005432852049	1334	Economy	37000.00
0005432390482	1334	Economy	37000.00
0005432390480	1334	Economy	33700.00
0005432390471	1334	Economy	37000.00
0005432390483	1334	Economy	33700.00
0005432390470	1334	Economy	33700.00
0005432390465	1334	Economy	33700.00
0005432392082	1334	Economy	33700.00
0005432852044	1334	Economy	33700.00
0005432852070	1334	Economy	33700.00
0005432852040	1334	Economy	33700.00
0005432390475	1334	Economy	33700.00
0005432392083	1334	Economy	33700.00
0005432390473	1334	Economy	33700.00
0005432390467	1334	Economy	33700.00
0005432852021	1334	Economy	33700.00
0005432852026	1334	Economy	33700.00
0005432390477	1334	Economy	33700.00
0005432852069	1334	Economy	33700.00
0005432852045	1334	Economy	33700.00
0005432390476	1334	Economy	33700.00
0005432390481	1334	Economy	33700.00
0005432390478	1334	Economy	33700.00
0005432852052	1334	Economy	33700.00
0005432390464	1334	Economy	33700.00
0005432390472	1334	Economy	33700.00
0005432390474	1334	Economy	33700.00
0005432390466	1334	Economy	33700.00
0005432852030	1334	Economy	33700.00
0005432390479	1334	Economy	33700.00
0005432852054	1334	Economy	33700.00
0005432852027	1334	Economy	33700.00
0005432390469	1334	Economy	33700.00
0005432852046	1334	Economy	33700.00
0005432852037	1334	Economy	33700.00
0005432852028	1334	Economy	33700.00
0005434069072	12819	Business	40300.00
0005434068816	12819	Business	40300.00
0005434069285	12819	Business	40300.00
0005434069179	12819	Business	40300.00
0005434082372	12819	Business	40300.00
0005434068972	12819	Business	40300.00
0005433989877	12819	Business	40300.00
0005435283542	12819	Business	40300.00
0005434069145	12819	Business	40300.00
0005434069450	12819	Business	40300.00
0005434069178	12819	Business	40300.00
0005434082555	12819	Economy	13400.00
0005434069085	12819	Economy	13400.00
0005435283535	12819	Economy	13400.00
0005435283538	12819	Economy	13400.00
0005434069061	12819	Economy	13400.00
0005435283540	12819	Economy	13400.00
0005434069073	12819	Economy	13400.00
0005434069333	12819	Economy	13400.00
0005434082384	12819	Economy	13400.00
0005434082320	12819	Economy	13400.00
0005434069144	12819	Economy	13400.00
0005433989891	12819	Economy	13400.00
0005434069485	12819	Economy	13400.00
0005434082401	12819	Economy	13400.00
0005434069322	12819	Economy	13400.00
0005435283543	12819	Economy	13400.00
0005434068986	12819	Economy	13400.00
0005434069173	12819	Economy	13400.00
0005434069130	12819	Economy	13400.00
0005434082524	12819	Economy	13400.00
0005434069018	12819	Economy	13400.00
0005434082496	12819	Economy	13400.00
0005434069007	12819	Economy	13400.00
0005434069133	12819	Economy	13400.00
0005434069164	12819	Economy	13400.00
0005434069020	12819	Economy	13400.00
0005434082465	12819	Economy	13400.00
0005434068955	12819	Economy	13400.00
0005434082488	12819	Economy	13400.00
0005434069105	12819	Economy	13400.00
0005432159992	12819	Economy	13400.00
0005434068934	12819	Economy	13400.00
0005434082393	12819	Economy	13400.00
0005435283539	12819	Economy	13400.00
0005434068900	12819	Economy	13400.00
0005433989885	12819	Economy	13400.00
0005434082443	12819	Economy	13400.00
0005434026748	12819	Economy	13400.00
0005434082400	12819	Economy	13400.00
0005434069070	12819	Economy	14800.00
0005434082511	12819	Economy	14800.00
0005434069343	12819	Economy	14800.00
0005433989890	12819	Economy	14800.00
0005433989875	12819	Economy	14800.00
0005434069063	12819	Economy	14800.00
0005434069385	12819	Economy	13400.00
0005434082402	12819	Economy	13400.00
0005435283537	12819	Economy	13400.00
0005434069074	12819	Economy	13400.00
0005435283536	12819	Economy	13400.00
0005434068957	12819	Economy	13400.00
0005434069014	12819	Economy	13400.00
0005434069267	12819	Economy	13400.00
0005434082383	12819	Economy	13400.00
0005434069078	12819	Economy	13400.00
0005434069238	12819	Economy	13400.00
0005434069136	12819	Economy	13400.00
0005434082468	12819	Economy	13400.00
0005434082407	12819	Economy	13400.00
0005434069137	12819	Economy	13400.00
0005434069196	12819	Economy	13400.00
0005434068848	12819	Economy	13400.00
0005433989884	12819	Economy	13400.00
0005434069239	12819	Economy	13400.00
0005433989874	12819	Economy	13400.00
0005434082497	12819	Economy	13400.00
0005434069331	12819	Economy	13400.00
0005434069129	12819	Economy	13400.00
0005434069174	12819	Economy	13400.00
0005434069019	12819	Economy	13400.00
0005434082466	12819	Economy	13400.00
0005434069062	12819	Economy	13400.00
0005434069005	12819	Economy	13400.00
0005434082340	12819	Economy	13400.00
0005434068855	12819	Economy	13400.00
0005434068984	12819	Economy	13400.00
0005434069068	12819	Economy	13400.00
0005434082522	12819	Economy	13400.00
0005434069251	12819	Economy	13400.00
0005434069342	12819	Economy	13400.00
0005434069263	12819	Economy	13400.00
0005434082467	12819	Economy	13400.00
0005434069252	12819	Economy	13400.00
0005435283541	12819	Economy	13400.00
0005434069071	12819	Economy	13400.00
0005434082369	12819	Economy	13400.00
0005434069087	12819	Economy	13400.00
0005434069128	12819	Economy	13400.00
0005434082484	12819	Economy	13400.00
0005434068917	12819	Economy	13400.00
0005434069240	12819	Economy	13400.00
0005434069451	12819	Economy	13400.00
0005434069102	12819	Economy	13400.00
0005434069256	12819	Economy	13400.00
0005434069264	12819	Economy	13400.00
0005434069060	12819	Economy	13400.00
0005434082437	12819	Economy	13400.00
0005434082436	12819	Economy	13400.00
0005434069323	12819	Economy	13400.00
0005434069177	12819	Economy	13400.00
0005434082394	12819	Economy	13400.00
0005434082438	12819	Economy	13400.00
0005434082435	12819	Economy	13400.00
0005434068899	12819	Economy	13400.00
0005434069006	12819	Economy	13400.00
0005434069375	12819	Economy	13400.00
0005434082412	12819	Economy	13400.00
0005434069075	12819	Economy	13400.00
0005434068979	12819	Economy	13400.00
0005434069086	12819	Economy	13400.00
0005435283430	30667	Business	40300.00
0005434069613	30667	Business	40300.00
0005434069617	30667	Economy	13400.00
0005434082629	30667	Economy	13400.00
0005433989902	30667	Economy	13400.00
0005434069611	30667	Economy	13400.00
0005434069624	30667	Economy	13400.00
0005435283436	30667	Economy	13400.00
0005435283427	30667	Economy	13400.00
0005432433806	30667	Economy	13400.00
0005434082631	30667	Economy	13400.00
0005434069608	30667	Economy	13400.00
0005434069615	30667	Economy	13400.00
0005434082632	30667	Economy	13400.00
0005435283435	30667	Economy	13400.00
0005435283449	30667	Economy	13400.00
0005434069606	30667	Economy	13400.00
0005435283452	30667	Economy	14800.00
0005434082626	30667	Economy	13400.00
0005434069607	30667	Economy	14800.00
0005434069623	30667	Economy	14800.00
0005432433816	30667	Economy	13400.00
0005434082630	30667	Economy	13400.00
0005434069614	30667	Economy	13400.00
0005432433807	30667	Economy	13400.00
0005434069619	30667	Economy	13400.00
0005434082625	30667	Economy	13400.00
0005434069610	30667	Economy	13400.00
0005435283437	30667	Economy	13400.00
0005432150421	30667	Economy	13400.00
0005434069625	30667	Economy	13400.00
0005434069621	30667	Economy	13400.00
0005434069622	30667	Economy	13400.00
0005434069605	30667	Economy	13400.00
0005432150422	30667	Economy	13400.00
0005435283428	30667	Economy	13400.00
0005434082628	30667	Economy	13400.00
0005435283451	30667	Economy	13400.00
0005432150424	30667	Economy	13400.00
0005433989903	30667	Economy	13400.00
0005434069609	30667	Economy	13400.00
0005432150423	30667	Economy	13400.00
0005432433805	30667	Economy	13400.00
0005435283429	30667	Economy	13400.00
0005432433800	30667	Economy	13400.00
0005434069616	30667	Economy	13400.00
0005434069612	30667	Economy	13400.00
0005434082624	30667	Economy	13400.00
0005434082627	30667	Economy	13400.00
0005434069620	30667	Economy	13400.00
0005434069618	30667	Economy	13400.00
0005432150420	30667	Economy	13400.00
0005434082633	30667	Economy	13400.00
0005432433801	30667	Economy	13400.00
0005435283431	30667	Economy	13400.00
0005433686701	9044	Economy	17600.00
0005433686699	9044	Economy	17600.00
0005433686700	9044	Economy	17600.00
0005433686702	9044	Economy	17600.00
0005433685591	9044	Economy	17600.00
0005433685590	9044	Economy	17600.00
0005433685592	9044	Economy	17600.00
0005435768081	5525	Business	35300.00
0005435617180	5525	Business	35300.00
0005434265605	5525	Business	35300.00
0005434265602	5525	Business	35300.00
0005435463469	5525	Business	35300.00
0005435463239	5525	Business	35300.00
0005434265603	5525	Business	35300.00
0005434265734	5525	Business	35300.00
0005435463307	5525	Business	35300.00
0005435463173	5525	Business	35300.00
0005435768079	5525	Business	35300.00
0005434831257	5525	Economy	11800.00
0005435768080	5525	Economy	11800.00
0005434265668	5525	Economy	11800.00
0005435463305	5525	Economy	11800.00
0005432140687	5525	Economy	11800.00
0005435768068	5525	Economy	11800.00
0005435463235	5525	Economy	11800.00
0005435768073	5525	Economy	11800.00
0005435768075	5525	Economy	11800.00
0005435463236	5525	Economy	11800.00
0005435768064	5525	Economy	11800.00
0005434265702	5525	Economy	11800.00
0005435735277	5525	Economy	11800.00
0005435463281	5525	Economy	11800.00
0005434265789	5525	Economy	11800.00
0005433527375	5525	Economy	11800.00
0005435463094	5525	Economy	11800.00
0005434265788	5525	Economy	11800.00
0005434265709	5525	Economy	11800.00
0005435768076	5525	Economy	11800.00
0005434265748	5525	Economy	11800.00
0005435463253	5525	Economy	11800.00
0005434265711	5525	Economy	11800.00
0005435463385	5525	Economy	11800.00
0005434265733	5525	Economy	11800.00
0005435768063	5525	Economy	11800.00
0005435463315	5525	Economy	11800.00
0005434265712	5525	Economy	11800.00
0005435463362	5525	Economy	11800.00
0005432535949	5525	Economy	11800.00
0005435463468	5525	Economy	11800.00
0005435043296	5525	Economy	11800.00
0005435463294	5525	Economy	11800.00
0005435463254	5525	Economy	11800.00
0005435463234	5525	Economy	11800.00
0005435463325	5525	Economy	11800.00
0005435463363	5525	Economy	11800.00
0005434265604	5525	Economy	11800.00
0005435463240	5525	Economy	11800.00
0005435768069	5525	Economy	11800.00
0005435463326	5525	Economy	11800.00
0005435463327	5525	Economy	11800.00
0005435463386	5525	Economy	11800.00
0005435768067	5525	Economy	11800.00
0005435768074	5525	Economy	11800.00
0005435463395	5525	Economy	11800.00
0005434265611	5525	Economy	11800.00
0005434265532	5525	Economy	11800.00
0005432140686	5525	Economy	12900.00
0005435768066	5525	Economy	11800.00
0005432535940	5525	Economy	11800.00
0005435768065	5525	Economy	11800.00
0005435768071	5525	Economy	11800.00
0005434265716	5525	Economy	11800.00
0005435463443	5525	Economy	11800.00
0005434265735	5525	Economy	11800.00
0005435043303	5525	Economy	11800.00
0005435463382	5525	Economy	11800.00
0005434265654	5525	Economy	11800.00
0005434265779	5525	Economy	11800.00
0005434265710	5525	Economy	11800.00
0005435723105	5525	Economy	11800.00
0005435768078	5525	Economy	11800.00
0005435463437	5525	Economy	11800.00
0005434265533	5525	Economy	11800.00
0005435463293	5525	Economy	11800.00
0005432140688	5525	Economy	11800.00
0005435768077	5525	Economy	11800.00
0005434265679	5525	Economy	11800.00
0005435725739	5525	Economy	11800.00
0005434265703	5525	Economy	11800.00
0005434265589	5525	Economy	11800.00
0005435463397	5525	Economy	11800.00
0005435723104	5525	Economy	11800.00
0005435735276	5525	Economy	11800.00
0005435463190	5525	Economy	11800.00
0005435463306	5525	Economy	11800.00
0005434265741	5525	Economy	11800.00
0005435463191	5525	Economy	11800.00
0005435463337	5525	Economy	11800.00
0005434265590	5525	Economy	11800.00
0005435463304	5525	Economy	11800.00
0005435463152	5525	Economy	11800.00
0005435768072	5525	Economy	11800.00
0005435463223	5525	Economy	11800.00
0005435463442	5525	Economy	11800.00
0005435768070	5525	Economy	11800.00
0005434265614	5525	Economy	11800.00
0005432535939	5525	Economy	11800.00
0005435725740	5525	Economy	11800.00
0005435768062	5525	Economy	11800.00
0005434265752	5525	Economy	11800.00
0005435463417	5525	Economy	11800.00
0005435767716	13456	Business	35300.00
0005435767442	13456	Business	35300.00
0005434265891	13456	Business	35300.00
0005435767740	13456	Business	35300.00
0005435767780	13456	Business	35300.00
0005435767781	13456	Business	35300.00
0005435767615	13456	Business	35300.00
0005434265888	13456	Business	35300.00
0005432535978	13456	Business	35300.00
0005435767779	13456	Business	35300.00
0005435767804	13456	Business	35300.00
0005435767363	13456	Economy	12900.00
0005435723088	13456	Economy	12900.00
0005435767818	13456	Economy	11800.00
0005434265889	13456	Economy	11800.00
0005435767683	13456	Economy	11800.00
0005435617212	13456	Economy	11800.00
0005435767563	13456	Economy	11800.00
0005435767334	13456	Economy	11800.00
0005435767810	13456	Economy	11800.00
0005435617210	13456	Economy	11800.00
0005434265893	13456	Economy	11800.00
0005435767335	13456	Economy	11800.00
0005435725718	13456	Economy	11800.00
0005435767526	13456	Economy	11800.00
0005434265892	13456	Economy	11800.00
0005435725702	13456	Economy	11800.00
0005435725717	13456	Economy	11800.00
0005435767508	13456	Economy	11800.00
0005434265885	13456	Economy	11800.00
0005435722096	13456	Economy	11800.00
0005435767428	13456	Economy	11800.00
0005435735227	13456	Economy	11800.00
0005435767623	13456	Economy	11800.00
0005435735234	13456	Economy	11800.00
0005435767717	13456	Economy	11800.00
0005435767380	13456	Economy	11800.00
0005432194637	13456	Economy	11800.00
0005435463521	13456	Economy	11800.00
0005435767805	13456	Economy	11800.00
0005435463525	13456	Economy	11800.00
0005435768108	13456	Economy	11800.00
0005435767663	13456	Economy	11800.00
0005435463519	13456	Economy	11800.00
0005435767744	13456	Economy	11800.00
0005435617213	13456	Economy	11800.00
0005434265886	13456	Economy	11800.00
0005435767614	13456	Economy	11800.00
0005435767695	13456	Economy	11800.00
0005435725715	13456	Economy	11800.00
0005435725716	13456	Economy	11800.00
0005435767485	13456	Economy	11800.00
0005435463520	13456	Economy	11800.00
0005435767664	13456	Economy	11800.00
0005435767603	13456	Economy	11800.00
0005435723089	13456	Economy	11800.00
0005435725704	13456	Economy	11800.00
0005435767441	13456	Economy	11800.00
0005435463526	13456	Economy	11800.00
0005435767562	13456	Economy	11800.00
0005435725713	13456	Economy	11800.00
0005435767602	13456	Economy	11800.00
0005434265890	13456	Economy	11800.00
0005435767507	13456	Economy	11800.00
0005435463527	13456	Economy	11800.00
0005435725701	13456	Economy	11800.00
0005435767463	13456	Economy	11800.00
0005435767749	13456	Economy	11800.00
0005432535977	13456	Economy	11800.00
0005435767865	13456	Economy	11800.00
0005435767433	13456	Economy	12900.00
0005432535979	13456	Economy	11800.00
0005435722097	13456	Economy	11800.00
0005432194636	13456	Economy	11800.00
0005435767606	13456	Economy	11800.00
0005435725712	13456	Economy	11800.00
0005435767589	13456	Economy	11800.00
0005435725705	13456	Economy	11800.00
0005435767574	13456	Economy	11800.00
0005435463522	13456	Economy	11800.00
0005435767435	13456	Economy	11800.00
0005435722098	13456	Economy	11800.00
0005435463523	13456	Economy	11800.00
0005435767464	13456	Economy	11800.00
0005435768107	13456	Economy	11800.00
0005434265887	13456	Economy	11800.00
0005435617209	13456	Economy	11800.00
0005435617211	13456	Economy	11800.00
0005435723090	13456	Economy	11800.00
0005435720158	13456	Economy	11800.00
0005435767484	13456	Economy	11800.00
0005435720156	13456	Economy	11800.00
0005435725706	13456	Economy	11800.00
0005435767462	13456	Economy	11800.00
0005435767886	13456	Economy	11800.00
0005435767864	13456	Economy	11800.00
0005435767748	13456	Economy	11800.00
0005435767806	13456	Economy	11800.00
0005435463524	13456	Economy	11800.00
0005435767550	13456	Economy	11800.00
0005435767693	13456	Economy	11800.00
0005435767784	13456	Economy	11800.00
0005435767662	13456	Economy	11800.00
0005434602965	18650	Economy	3300.00
0005434602962	18650	Economy	3300.00
0005434602970	18650	Economy	3300.00
0005434602961	18650	Economy	3300.00
0005434602966	18650	Economy	3300.00
0005434513660	18700	Economy	3300.00
0005434604973	18700	Economy	3300.00
0005434604972	18700	Economy	3300.00
0005434604970	18700	Economy	3300.00
0005434513659	18700	Economy	3300.00
0005434604971	18700	Economy	3300.00
0005434604969	18700	Economy	3300.00
0005434515036	19179	Economy	3300.00
0005434515025	19179	Economy	3300.00
0005434515024	19179	Economy	3300.00
0005434515015	19179	Economy	3300.00
0005434515014	19179	Economy	3300.00
0005434515029	19179	Economy	3300.00
0005435844399	4120	Business	88300.00
0005435846341	4120	Business	88300.00
0005435844397	4120	Economy	29400.00
0005435846340	4120	Economy	29400.00
0005435846317	4120	Economy	29400.00
0005435844400	4120	Economy	29400.00
0005432649572	4120	Economy	29400.00
0005432632944	4120	Economy	29400.00
0005432632943	4120	Economy	29400.00
0005435844398	4120	Economy	29400.00
0005435844401	4120	Economy	29400.00
0005435846323	4120	Economy	29400.00
0005432632941	4120	Economy	29400.00
0005435846322	4120	Economy	29400.00
0005432632942	4120	Economy	29400.00
0005435844388	4120	Economy	29400.00
0005435844396	4120	Economy	29400.00
0005435844413	4120	Economy	29400.00
0005435846332	4120	Economy	29400.00
0005435846314	4120	Economy	29400.00
0005433009785	1775	Business	48700.00
0005433810786	1775	Business	48700.00
0005433009658	1775	Business	48700.00
0005433009599	1775	Business	48700.00
0005433009720	1775	Business	48700.00
0005433810771	1775	Business	48700.00
0005433286070	1775	Business	48700.00
0005433286121	1775	Business	48700.00
0005433286012	1775	Business	48700.00
0005433286170	1775	Business	48700.00
0005433810775	1775	Business	48700.00
0005433285923	1775	Business	48700.00
0005433286108	1775	Economy	16200.00
0005433009860	1775	Economy	16200.00
0005433810780	1775	Economy	16200.00
0005433286006	1775	Economy	16200.00
0005435097507	1775	Economy	16200.00
0005433810773	1775	Economy	16200.00
0005433285947	1775	Economy	16200.00
0005433009782	1775	Economy	16200.00
0005433810792	1775	Economy	16200.00
0005433285998	1775	Economy	16200.00
0005433009742	1775	Economy	17900.00
0005433285948	1775	Economy	17900.00
0005433810770	1775	Economy	17900.00
0005433009620	1775	Economy	17900.00
0005433810787	1775	Economy	17900.00
0005433810784	1775	Economy	16200.00
0005433810783	1775	Economy	16200.00
0005433285970	1775	Economy	16200.00
0005433009598	1775	Economy	16200.00
0005433286129	1775	Economy	16200.00
0005433009719	1775	Economy	16200.00
0005433285909	1775	Economy	16200.00
0005433009605	1775	Economy	16200.00
0005433009783	1775	Economy	16200.00
0005433009718	1775	Economy	16200.00
0005435097504	1775	Economy	16200.00
0005433810781	1775	Economy	16200.00
0005433009614	1775	Economy	16200.00
0005433009699	1775	Economy	16200.00
0005433009861	1775	Economy	16200.00
0005433009657	1775	Economy	16200.00
0005433009780	1775	Economy	16200.00
0005433009654	1775	Economy	16200.00
0005433286056	1775	Economy	16200.00
0005433810791	1775	Economy	16200.00
0005433285922	1775	Economy	16200.00
0005433009590	1775	Economy	16200.00
0005433009741	1775	Economy	16200.00
0005433810779	1775	Economy	16200.00
0005433009606	1775	Economy	16200.00
0005433810785	1775	Economy	16200.00
0005433009665	1775	Economy	16200.00
0005433810777	1775	Economy	16200.00
0005433285974	1775	Economy	16200.00
0005433009823	1775	Economy	16200.00
0005433009588	1775	Economy	16200.00
0005433286079	1775	Economy	16200.00
0005433009711	1775	Economy	16200.00
0005433009354	1775	Economy	16200.00
0005433286013	1775	Economy	16200.00
0005433810790	1775	Economy	16200.00
0005433009712	1775	Economy	16200.00
0005433810778	1775	Economy	16200.00
0005433009601	1775	Economy	16200.00
0005433009797	1775	Economy	16200.00
0005433009615	1775	Economy	16200.00
0005433009748	1775	Economy	16200.00
0005433286125	1775	Economy	16200.00
0005433009739	1775	Economy	16200.00
0005433286126	1775	Economy	16200.00
0005433810788	1775	Economy	16200.00
0005433009355	1775	Economy	16200.00
0005433285971	1775	Economy	16200.00
0005433810776	1775	Economy	16200.00
0005433285966	1775	Economy	16200.00
0005433009747	1775	Economy	16200.00
0005433009677	1775	Economy	16200.00
0005433009749	1775	Economy	16200.00
0005433810772	1775	Economy	16200.00
0005433009784	1775	Economy	16200.00
0005433009750	1775	Economy	16200.00
0005433810782	1775	Economy	16200.00
0005433285910	1775	Economy	16200.00
0005433286011	1775	Economy	16200.00
0005433009732	1775	Economy	16200.00
0005433009600	1775	Economy	16200.00
0005433009538	1775	Economy	16200.00
0005435097506	1775	Economy	16200.00
0005433286007	1775	Economy	16200.00
0005433286169	1775	Economy	16200.00
0005433810774	1775	Economy	16200.00
0005435097505	1775	Economy	16200.00
0005433009698	1775	Economy	16200.00
0005433286045	1775	Economy	16200.00
0005433810789	1775	Economy	16200.00
0005433810649	22538	Business	48700.00
0005433810648	22538	Business	48700.00
0005433810626	22538	Business	48700.00
0005433009955	22538	Business	48700.00
0005433286201	22538	Business	48700.00
0005433286204	22538	Business	48700.00
0005433286209	22538	Business	48700.00
0005433286205	22538	Business	48700.00
0005433009943	22538	Business	48700.00
0005433810628	22538	Economy	16200.00
0005433810645	22538	Economy	16200.00
0005433810629	22538	Economy	16200.00
0005433009952	22538	Economy	16200.00
0005433286206	22538	Economy	17900.00
0005433009944	22538	Economy	16200.00
0005433810631	22538	Economy	16200.00
0005433009945	22538	Economy	16200.00
0005433810652	22538	Economy	16200.00
0005433009956	22538	Economy	16200.00
0005433286203	22538	Economy	16200.00
0005433009950	22538	Economy	16200.00
0005433810646	22538	Economy	16200.00
0005433810666	22538	Economy	16200.00
0005433009954	22538	Economy	16200.00
0005433009947	22538	Economy	16200.00
0005433810660	22538	Economy	16200.00
0005433286211	22538	Economy	16200.00
0005433009946	22538	Economy	16200.00
0005433009951	22538	Economy	16200.00
0005433810654	22538	Economy	16200.00
0005433286207	22538	Economy	16200.00
0005433286210	22538	Economy	16200.00
0005433810659	22538	Economy	16200.00
0005433810664	22538	Economy	16200.00
0005433009949	22538	Economy	16200.00
0005433286208	22538	Economy	16200.00
0005433286212	22538	Economy	16200.00
0005433009953	22538	Economy	16200.00
0005433810625	22538	Economy	16200.00
0005433009957	22538	Economy	16200.00
0005433286202	22538	Economy	16200.00
0005433810624	22538	Economy	16200.00
0005433810665	22538	Economy	16200.00
0005433286213	22538	Economy	16200.00
0005433009948	22538	Economy	16200.00
0005434152851	12287	Business	83800.00
0005432751581	12287	Business	83800.00
0005434151816	12287	Business	83800.00
0005432751592	12287	Economy	27900.00
0005432755131	12287	Economy	27900.00
0005432751617	12287	Economy	27900.00
0005432751604	12287	Economy	27900.00
0005432755137	12287	Economy	27900.00
0005432751580	12287	Economy	30700.00
0005434151818	12287	Economy	30700.00
0005432751600	12287	Economy	27900.00
0005432751614	12287	Economy	27900.00
0005432755143	12287	Economy	27900.00
0005432751589	12287	Economy	27900.00
0005432751615	12287	Economy	27900.00
0005432751606	12287	Economy	27900.00
0005434151819	12287	Economy	27900.00
0005432751605	12287	Economy	27900.00
0005432751586	12287	Economy	27900.00
0005432751596	12287	Economy	27900.00
0005432755125	12287	Economy	27900.00
0005432751607	12287	Economy	27900.00
0005432755132	12287	Economy	27900.00
0005434151817	12287	Economy	27900.00
0005432751602	12287	Economy	27900.00
0005432755141	12287	Economy	27900.00
0005432751587	12287	Economy	27900.00
0005432751590	12287	Economy	27900.00
0005432751601	12287	Economy	27900.00
0005432755144	12287	Economy	27900.00
0005432751582	12287	Economy	27900.00
0005432751591	12287	Economy	27900.00
0005434151820	12287	Economy	27900.00
0005432751595	12287	Economy	27900.00
0005432755142	12287	Economy	27900.00
0005432751588	12287	Economy	27900.00
0005435282989	5562	Business	99800.00
0005435282942	5562	Business	99800.00
0005435283058	5562	Business	99800.00
0005435283144	5562	Business	99800.00
0005435283035	5562	Business	99800.00
0005435283141	5562	Business	99800.00
0005435283010	5562	Business	99800.00
0005434173604	5562	Business	99800.00
0005435283175	5562	Business	99800.00
0005432081694	5562	Economy	33300.00
0005434173609	5562	Economy	33300.00
0005435283054	5562	Economy	33300.00
0005435283060	5562	Economy	33300.00
0005435283059	5562	Economy	33300.00
0005435283087	5562	Economy	36600.00
0005433815563	5562	Economy	36600.00
0005435283003	5562	Economy	36600.00
0005434173605	5562	Economy	33300.00
0005433848403	5562	Economy	33300.00
0005434173603	5562	Economy	33300.00
0005433848397	5562	Economy	33300.00
0005433848402	5562	Economy	33300.00
0005432081696	5562	Economy	33300.00
0005433848399	5562	Economy	33300.00
0005435282941	5562	Economy	33300.00
0005435283036	5562	Economy	33300.00
0005435283121	5562	Economy	33300.00
0005435283015	5562	Economy	33300.00
0005435282940	5562	Economy	33300.00
0005433848398	5562	Economy	33300.00
0005433848401	5562	Economy	33300.00
0005435283102	5562	Economy	33300.00
0005435282988	5562	Economy	33300.00
0005432081693	5562	Economy	33300.00
0005433848400	5562	Economy	33300.00
0005433848395	5562	Economy	33300.00
0005433848396	5562	Economy	33300.00
0005432081695	5562	Economy	33300.00
0005435283040	5562	Economy	33300.00
0005434173611	5562	Economy	33300.00
0005435282949	5562	Economy	33300.00
0005435283051	5562	Economy	33300.00
0005434173610	5562	Economy	33300.00
0005435283009	5562	Economy	33300.00
0005435283120	5562	Economy	33300.00
0005433848404	5562	Economy	33300.00
0005435282948	5562	Economy	33300.00
0005435283140	5562	Economy	33300.00
0005433847998	13858	Business	99800.00
0005433847886	13858	Business	99800.00
0005433847982	13858	Business	99800.00
0005433847972	13858	Business	99800.00
0005433848049	13858	Business	99800.00
0005433847884	13858	Business	99800.00
0005433848160	13858	Business	99800.00
0005433848062	13858	Business	99800.00
0005433847819	13858	Business	99800.00
0005433848181	13858	Business	99800.00
0005433848121	13858	Business	99800.00
0005433848063	13858	Business	99800.00
0005433815501	13858	Business	99800.00
0005433848070	13858	Business	99800.00
0005433848135	13858	Economy	33300.00
0005435283249	13858	Economy	33300.00
0005433848167	13858	Economy	33300.00
0005433848037	13858	Economy	33300.00
0005433848090	13858	Economy	33300.00
0005433847926	13858	Economy	33300.00
0005433847876	13858	Economy	33300.00
0005433847939	13858	Economy	33300.00
0005433848086	13858	Economy	36600.00
0005433848112	13858	Economy	36600.00
0005433848180	13858	Economy	33300.00
0005433848210	13858	Economy	33300.00
0005433847925	13858	Economy	33300.00
0005433848131	13858	Economy	33300.00
0005433848319	13858	Economy	33300.00
0005433848053	13858	Economy	33300.00
0005433848030	13858	Economy	33300.00
0005433815477	13858	Economy	33300.00
0005433847991	13858	Economy	33300.00
0005433815502	13858	Economy	33300.00
0005433847971	13858	Economy	33300.00
0005434173667	13858	Economy	33300.00
0005433847854	13858	Economy	33300.00
0005433847953	13858	Economy	33300.00
0005433848072	13858	Economy	33300.00
0005433848163	13858	Economy	33300.00
0005433847927	13858	Economy	33300.00
0005433848318	13858	Economy	33300.00
0005433848092	13858	Economy	33300.00
0005433848148	13858	Economy	33300.00
0005433848149	13858	Economy	33300.00
0005433848190	13858	Economy	33300.00
0005433848047	13858	Economy	33300.00
0005435283246	13858	Economy	33300.00
0005433847980	13858	Economy	33300.00
0005433848116	13858	Economy	33300.00
0005433847898	13858	Economy	33300.00
0005433848050	13858	Economy	33300.00
0005435283248	13858	Economy	33300.00
0005433815485	13858	Economy	33300.00
0005433847881	13858	Economy	33300.00
0005435283245	13858	Economy	33300.00
0005433847903	13858	Economy	33300.00
0005433848115	13858	Economy	33300.00
0005433848126	13858	Economy	33300.00
0005433848169	13858	Economy	33300.00
0005433847855	13858	Economy	33300.00
0005433848110	13858	Economy	33300.00
0005433847825	13858	Economy	33300.00
0005435283247	13858	Economy	33300.00
0005433848082	13858	Economy	33300.00
0005433815500	13858	Economy	33300.00
0005433847954	13858	Economy	33300.00
0005433847902	13858	Economy	33300.00
0005433815505	13858	Economy	33300.00
0005433848286	13858	Economy	33300.00
0005433848161	13858	Economy	33300.00
0005433848137	13858	Economy	33300.00
0005433847792	13858	Economy	33300.00
0005433848080	13858	Economy	33300.00
0005433848136	13858	Economy	33300.00
0005433848066	13858	Economy	33300.00
0005433847897	13858	Economy	33300.00
0005433815494	13858	Economy	33300.00
0005433848069	13858	Economy	33300.00
0005433848071	13858	Economy	33300.00
0005433848087	13858	Economy	33300.00
0005435332596	7819	Economy	16600.00
0005435332562	7819	Economy	15100.00
0005435332563	7819	Economy	15100.00
0005435332582	7819	Economy	15100.00
0005434621180	7819	Economy	15100.00
0005435332605	7819	Economy	15100.00
0005435332597	7819	Economy	15100.00
0005435332606	7819	Economy	15100.00
0005435332559	7819	Economy	15100.00
0005435332534	7819	Economy	15100.00
0005435332583	7819	Economy	15100.00
0005435332533	7819	Economy	15100.00
0005435332632	7819	Economy	15100.00
0005435332532	7819	Economy	15100.00
0005435332584	7819	Economy	15100.00
0005434621032	32949	Economy	15100.00
0005434621114	32949	Economy	15100.00
0005434621077	32949	Economy	15100.00
0005434621021	32949	Economy	15100.00
0005434621110	32949	Economy	15100.00
0005435332637	32949	Economy	15100.00
0005434621069	32949	Economy	15100.00
0005435332638	32949	Economy	15100.00
0005434621022	32949	Economy	15100.00
0005434621113	32949	Economy	15100.00
0005435332641	32949	Economy	15100.00
0005434621109	32949	Economy	15100.00
0005435332640	32949	Economy	15100.00
0005434621076	32949	Economy	15100.00
0005434620988	32949	Economy	15100.00
0005434621118	32949	Economy	15100.00
0005434621108	32949	Economy	15100.00
0005434621033	32949	Economy	15100.00
0005435332636	32949	Economy	15100.00
0005435332639	32949	Economy	15100.00
0005434620986	32949	Economy	15100.00
0005434621019	32949	Economy	15100.00
0005434620987	32949	Economy	15100.00
0005435786352	4277	Business	38000.00
0005435937491	4277	Business	38000.00
0005435786351	4277	Business	38000.00
0005434994308	4277	Economy	13900.00
0005435786355	4277	Economy	12700.00
0005435937511	4277	Economy	12700.00
0005435937541	4277	Economy	12700.00
0005434994306	4277	Economy	12700.00
0005435786349	4277	Economy	12700.00
0005435786354	4277	Economy	12700.00
0005434994307	4277	Economy	12700.00
0005435786356	4277	Economy	12700.00
0005435786350	4277	Economy	12700.00
0005435937490	4277	Economy	12700.00
0005435918761	4277	Economy	12700.00
0005435937501	4277	Economy	12700.00
0005435937483	4277	Economy	12700.00
0005435937527	4277	Economy	12700.00
0005435786347	4277	Economy	12700.00
0005434994305	4277	Economy	12700.00
0005435937503	4277	Economy	12700.00
0005435786348	4277	Economy	12700.00
0005435937540	4277	Economy	12700.00
0005435937462	4277	Economy	12700.00
0005435937502	4277	Economy	12700.00
0005434994309	4277	Economy	12700.00
0005435786353	4277	Economy	12700.00
0005435918759	4277	Economy	12700.00
0005435786357	4277	Economy	12700.00
0005435786108	27309	Business	38000.00
0005435786121	27309	Business	38000.00
0005435786175	27309	Business	38000.00
0005435786138	27309	Business	38000.00
0005434994246	27309	Business	38000.00
0005435937570	27309	Business	38000.00
0005432195756	27309	Economy	12700.00
0005435786085	27309	Economy	12700.00
0005435787393	27309	Economy	12700.00
0005434994193	27309	Economy	12700.00
0005435786094	27309	Economy	12700.00
0005435937568	27309	Economy	12700.00
0005432195755	27309	Economy	12700.00
0005435786154	27309	Economy	13900.00
0005435786081	27309	Economy	13900.00
0005435786077	27309	Economy	13900.00
0005435937571	27309	Economy	13900.00
0005435786055	27309	Economy	13900.00
0005435786022	27309	Economy	12700.00
0005435786109	27309	Economy	12700.00
0005434994223	27309	Economy	12700.00
0005435786120	27309	Economy	12700.00
0005435937569	27309	Economy	12700.00
0005434994255	27309	Economy	12700.00
0005435786139	27309	Economy	12700.00
0005435785997	27309	Economy	12700.00
0005435786115	27309	Economy	12700.00
0005435786095	27309	Economy	12700.00
0005435786080	27309	Economy	12700.00
0005434994254	27309	Economy	12700.00
0005434994216	27309	Economy	12700.00
0005434994191	27309	Economy	12700.00
0005432195754	27309	Economy	12700.00
0005435786064	27309	Economy	12700.00
0005435785931	27309	Economy	12700.00
0005435786155	27309	Economy	12700.00
0005435785928	27309	Economy	12700.00
0005435786110	27309	Economy	12700.00
0005435787394	27309	Economy	12700.00
0005435785941	27309	Economy	12700.00
0005435786084	27309	Economy	12700.00
0005435786086	27309	Economy	12700.00
0005434994274	27309	Economy	12700.00
0005435786158	27309	Economy	12700.00
0005435786137	27309	Economy	12700.00
0005434994192	27309	Economy	12700.00
0005435785998	27309	Economy	12700.00
0005435937567	27309	Economy	12700.00
0005435785929	27309	Economy	12700.00
0005435786159	27309	Economy	12700.00
0005435786082	27309	Economy	12700.00
0005434994239	27309	Economy	12700.00
0005435786147	27309	Economy	12700.00
0005435785930	27309	Economy	12700.00
0005435786062	27309	Economy	12700.00
0005435785971	27309	Economy	12700.00
0005435786078	27309	Economy	12700.00
0005435786061	27309	Economy	12700.00
0005435785996	27309	Economy	12700.00
0005435786143	27309	Economy	12700.00
0005432146259	19868	Economy	12800.00
0005432461402	4726	Business	40900.00
0005432461404	4726	Business	40900.00
0005432569403	4726	Business	40900.00
0005435840408	4726	Business	40900.00
0005432461413	4726	Business	40900.00
0005432461403	4726	Business	40900.00
0005435840424	4726	Business	40900.00
0005432461401	4726	Economy	15000.00
0005435840405	4726	Economy	15000.00
0005434082639	4726	Economy	13600.00
0005432461408	4726	Economy	13600.00
0005432569405	4726	Economy	13600.00
0005432461398	4726	Economy	13600.00
0005432461405	4726	Economy	13600.00
0005435840421	4726	Economy	13600.00
0005435840399	4726	Economy	13600.00
0005434082637	4726	Economy	13600.00
0005435840406	4726	Economy	13600.00
0005435840383	4726	Economy	13600.00
0005432569404	4726	Economy	13600.00
0005432461414	4726	Economy	13600.00
0005432569399	4726	Economy	13600.00
0005433452796	4726	Economy	13600.00
0005432461412	4726	Economy	13600.00
0005434559191	4726	Economy	13600.00
0005432461409	4726	Economy	13600.00
0005432569406	4726	Economy	13600.00
0005432461410	4726	Economy	13600.00
0005432461396	4726	Economy	13600.00
0005432461393	4726	Economy	13600.00
0005434082634	4726	Economy	13600.00
0005432461415	4726	Economy	13600.00
0005435840385	4726	Economy	13600.00
0005435840407	4726	Economy	13600.00
0005434082636	4726	Economy	13600.00
0005434082635	4726	Economy	13600.00
0005432569398	4726	Economy	13600.00
0005435840409	4726	Economy	13600.00
0005432461397	4726	Economy	13600.00
0005433451678	4726	Economy	13600.00
0005432569401	4726	Economy	13600.00
0005432571436	4726	Economy	13600.00
0005432461399	4726	Economy	13600.00
0005435840398	4726	Economy	13600.00
0005432461394	4726	Economy	13600.00
0005432571437	4726	Economy	13600.00
0005432569407	4726	Economy	15000.00
0005435840422	4726	Economy	13600.00
0005435840384	4726	Economy	13600.00
0005432571435	4726	Economy	13600.00
0005432569397	4726	Economy	13600.00
0005432461416	4726	Economy	13600.00
0005434082638	4726	Economy	13600.00
0005432461395	4726	Economy	13600.00
0005432461400	4726	Economy	13600.00
0005432461406	4726	Economy	13600.00
0005432461407	4726	Economy	13600.00
0005432569400	4726	Economy	13600.00
0005433451677	4726	Economy	13600.00
0005432461411	4726	Economy	13600.00
0005432569402	4726	Economy	13600.00
0005434559192	4726	Economy	13600.00
0005432569150	30569	Business	40900.00
0005432461064	30569	Business	40900.00
0005432569130	30569	Business	40900.00
0005432569120	30569	Business	40900.00
0005432569056	30569	Business	40900.00
0005432460944	30569	Business	40900.00
0005434559119	30569	Business	40900.00
0005434082465	30569	Business	40900.00
0005432461063	30569	Business	40900.00
0005432461009	30569	Business	40900.00
0005432461277	30569	Business	40900.00
0005432461278	30569	Business	40900.00
0005434082438	30569	Business	40900.00
0005432213708	30569	Business	40900.00
0005434150221	30569	Business	40900.00
0005432460933	30569	Business	40900.00
0005434082443	30569	Business	40900.00
0005432461073	30569	Business	40900.00
0005434559105	30569	Business	40900.00
0005434082407	30569	Business	40900.00
0005434150219	30569	Business	40900.00
0005434559106	30569	Business	40900.00
0005434082400	30569	Business	40900.00
0005434082511	30569	Business	40900.00
0005432568996	30569	Business	40900.00
0005432461191	30569	Business	40900.00
0005432460991	30569	Business	40900.00
0005434082372	30569	Business	40900.00
0005433454929	30569	Economy	15000.00
0005432461033	30569	Economy	15000.00
0005432569057	30569	Economy	13600.00
0005432569129	30569	Economy	13600.00
0005434150224	30569	Economy	13600.00
0005432569048	30569	Economy	13600.00
0005432461057	30569	Economy	13600.00
0005432460834	30569	Economy	13600.00
0005432461077	30569	Economy	13600.00
0005432460975	30569	Economy	13600.00
0005434559117	30569	Economy	13600.00
0005432461090	30569	Economy	13600.00
0005432461010	30569	Economy	13600.00
0005432569143	30569	Economy	13600.00
0005434082467	30569	Economy	13600.00
0005432461229	30569	Economy	13600.00
0005434150216	30569	Economy	13600.00
0005434082384	30569	Economy	13600.00
0005432460966	30569	Economy	13600.00
0005434559109	30569	Economy	13600.00
0005432461311	30569	Economy	13600.00
0005432569037	30569	Economy	13600.00
0005434082402	30569	Economy	13600.00
0005432461235	30569	Economy	13600.00
0005434082524	30569	Economy	13600.00
0005433454918	30569	Economy	13600.00
0005432461133	30569	Economy	13600.00
0005434082484	30569	Economy	13600.00
0005432461037	30569	Economy	13600.00
0005432461095	30569	Economy	13600.00
0005432461176	30569	Economy	13600.00
0005432461072	30569	Economy	13600.00
0005432568875	30569	Economy	13600.00
0005432568902	30569	Economy	13600.00
0005432568857	30569	Economy	13600.00
0005432461093	30569	Economy	13600.00
0005432569234	30569	Economy	13600.00
0005432461136	30569	Economy	13600.00
0005432461148	30569	Economy	13600.00
0005433452788	30569	Economy	13600.00
0005434082383	30569	Economy	13600.00
0005432569219	30569	Economy	13600.00
0005434082394	30569	Economy	13600.00
0005432568901	30569	Economy	13600.00
0005434082435	30569	Economy	13600.00
0005434082555	30569	Economy	13600.00
0005434150223	30569	Economy	13600.00
0005432569151	30569	Economy	13600.00
0005432568992	30569	Economy	13600.00
0005432460885	30569	Economy	13600.00
0005434150218	30569	Economy	13600.00
0005434559114	30569	Economy	13600.00
0005434150225	30569	Economy	13600.00
0005432569091	30569	Economy	13600.00
0005433452786	30569	Economy	13600.00
0005432461132	30569	Economy	13600.00
0005432460945	30569	Economy	13600.00
0005432569271	30569	Economy	13600.00
0005432568903	30569	Economy	13600.00
0005432568856	30569	Economy	13600.00
0005434082436	30569	Economy	13600.00
0005432569303	30569	Economy	13600.00
0005432461078	30569	Economy	13600.00
0005432569117	30569	Economy	13600.00
0005432460928	30569	Economy	13600.00
0005432569131	30569	Economy	13600.00
0005432568778	30569	Economy	13600.00
0005433452787	30569	Economy	13600.00
0005434559111	30569	Economy	13600.00
0005434559115	30569	Economy	13600.00
0005432461249	30569	Economy	13600.00
0005434082522	30569	Economy	13600.00
0005432569011	30569	Economy	13600.00
0005432461127	30569	Economy	13600.00
0005432569082	30569	Economy	13600.00
0005432569207	30569	Economy	13600.00
0005432569127	30569	Economy	13600.00
0005434082369	30569	Economy	13600.00
0005432461088	30569	Economy	13600.00
0005432568949	30569	Economy	13600.00
0005434559118	30569	Economy	15000.00
0005434150226	30569	Economy	15000.00
0005432461225	30569	Economy	13600.00
0005434150222	30569	Economy	13600.00
0005434082466	30569	Economy	15000.00
0005433452789	30569	Economy	15000.00
0005432569121	30569	Economy	13600.00
0005432461097	30569	Economy	13600.00
0005432461153	30569	Economy	13600.00
0005432461137	30569	Economy	13600.00
0005432460856	30569	Economy	13600.00
0005432461017	30569	Economy	13600.00
0005434082320	30569	Economy	13600.00
0005432569199	30569	Economy	13600.00
0005432461038	30569	Economy	13600.00
0005432569260	30569	Economy	13600.00
0005434082497	30569	Economy	13600.00
0005432568963	30569	Economy	13600.00
0005432569040	30569	Economy	13600.00
0005432461114	30569	Economy	13600.00
0005432569163	30569	Economy	13600.00
0005432460857	30569	Economy	13600.00
0005432461310	30569	Economy	13600.00
0005432461002	30569	Economy	13600.00
0005432569272	30569	Economy	13600.00
0005434082488	30569	Economy	13600.00
0005434082340	30569	Economy	13600.00
0005432461175	30569	Economy	13600.00
0005434150229	30569	Economy	13600.00
0005432460929	30569	Economy	13600.00
0005432568967	30569	Economy	13600.00
0005432569122	30569	Economy	13600.00
0005434150215	30569	Economy	13600.00
0005432460990	30569	Economy	13600.00
0005434559112	30569	Economy	13600.00
0005434559107	30569	Economy	13600.00
0005432461098	30569	Economy	13600.00
0005432461236	30569	Economy	13600.00
0005432568779	30569	Economy	13600.00
0005432461248	30569	Economy	13600.00
0005432571418	30569	Economy	13600.00
0005432460930	30569	Economy	13600.00
0005434150220	30569	Economy	13600.00
0005432461109	30569	Economy	13600.00
0005432569230	30569	Economy	13600.00
0005434082393	30569	Economy	13600.00
0005434082401	30569	Economy	13600.00
0005432569000	30569	Economy	13600.00
0005432569231	30569	Economy	13600.00
0005434150217	30569	Economy	13600.00
0005434082412	30569	Economy	13600.00
0005434082496	30569	Economy	13600.00
0005432569126	30569	Economy	13600.00
0005434082468	30569	Economy	13600.00
0005432460886	30569	Economy	13600.00
0005432568924	30569	Economy	13600.00
0005434559110	30569	Economy	13600.00
0005434082437	30569	Economy	13600.00
0005432461074	30569	Economy	13600.00
0005432461089	30569	Economy	13600.00
0005434559108	30569	Economy	13600.00
0005434150228	30569	Economy	13600.00
0005432461094	30569	Economy	13600.00
0005432568998	30569	Economy	13600.00
0005434150227	30569	Economy	13600.00
0005432460974	30569	Economy	13600.00
0005432569205	30569	Economy	13600.00
0005432568964	30569	Economy	13600.00
0005435722111	21138	Economy	9900.00
0005433346060	11114	Business	23600.00
0005435508628	11114	Business	23600.00
0005433346062	11114	Business	23600.00
0005435508730	11114	Business	23600.00
0005435530104	11114	Business	23600.00
0005435508644	11114	Business	23600.00
0005435530079	11114	Business	23600.00
0005435508669	11114	Business	23600.00
0005435530090	11114	Business	23600.00
0005435508714	11114	Business	23600.00
0005435530015	11114	Economy	7900.00
0005435530096	11114	Economy	7900.00
0005435508643	11114	Economy	7900.00
0005435508713	11114	Economy	7900.00
0005433346046	11114	Economy	7900.00
0005433346047	11114	Economy	7900.00
0005433346048	11114	Economy	7900.00
0005435508634	11114	Economy	7900.00
0005435380371	11114	Economy	7900.00
0005435508754	11114	Economy	7900.00
0005433346057	11114	Economy	7900.00
0005435530157	11114	Economy	7900.00
0005435380428	11114	Economy	7900.00
0005435508752	11114	Economy	7900.00
0005435530023	11114	Economy	7900.00
0005433346059	11114	Economy	7900.00
0005435097495	11114	Economy	7900.00
0005435097493	11114	Economy	7900.00
0005435530019	11114	Economy	7900.00
0005435508604	11114	Economy	7900.00
0005435380414	11114	Economy	7900.00
0005433346045	11114	Economy	7900.00
0005435530078	11114	Economy	7900.00
0005433346050	11114	Economy	7900.00
0005435530105	11114	Economy	8600.00
0005435530031	11114	Economy	8600.00
0005433346058	11114	Economy	8600.00
0005435508731	11114	Economy	8600.00
0005435530124	11114	Economy	7900.00
0005435508745	11114	Economy	7900.00
0005433346049	11114	Economy	7900.00
0005435380370	11114	Economy	7900.00
0005435508627	11114	Economy	7900.00
0005433346054	11114	Economy	7900.00
0005435530039	11114	Economy	7900.00
0005435508753	11114	Economy	7900.00
0005435508632	11114	Economy	7900.00
0005433346055	11114	Economy	7900.00
0005435508641	11114	Economy	7900.00
0005433346061	11114	Economy	7900.00
0005433346066	11114	Economy	7900.00
0005433346056	11114	Economy	7900.00
0005435508715	11114	Economy	7900.00
0005435508584	11114	Economy	7900.00
0005435508637	11114	Economy	7900.00
0005435508622	11114	Economy	7900.00
0005433346064	11114	Economy	7900.00
0005435508709	11114	Economy	7900.00
0005433346051	11114	Economy	7900.00
0005435508689	11114	Economy	7900.00
0005435508718	11114	Economy	7900.00
0005433346067	11114	Economy	7900.00
0005435508653	11114	Economy	7900.00
0005435097494	11114	Economy	7900.00
0005433346063	11114	Economy	7900.00
0005435530064	11114	Economy	7900.00
0005435508696	11114	Economy	7900.00
0005433346052	11114	Economy	7900.00
0005435530032	11114	Economy	7900.00
0005433346065	11114	Economy	7900.00
0005433346053	11114	Economy	7900.00
0005435508668	11114	Economy	7900.00
0005433345365	17086	Business	23600.00
0005433345396	17086	Business	23600.00
0005433345557	17086	Business	23600.00
0005433345734	17086	Business	23600.00
0005433344985	17086	Business	23600.00
0005433345004	17086	Business	23600.00
0005433344944	17086	Business	23600.00
0005433345265	17086	Business	23600.00
0005433345228	17086	Business	23600.00
0005433345537	17086	Business	23600.00
0005433345348	17086	Business	23600.00
0005433345051	17086	Business	23600.00
0005433345244	17086	Economy	7900.00
0005433345266	17086	Economy	7900.00
0005433345222	17086	Economy	7900.00
0005433345047	17086	Economy	7900.00
0005433345421	17086	Economy	7900.00
0005433345575	17086	Economy	7900.00
0005435545969	17086	Economy	7900.00
0005433345292	17086	Economy	7900.00
0005433345650	17086	Economy	7900.00
0005433345573	17086	Economy	7900.00
0005435545971	17086	Economy	7900.00
0005433345247	17086	Economy	7900.00
0005433345320	17086	Economy	7900.00
0005433344847	17086	Economy	7900.00
0005433345249	17086	Economy	7900.00
0005433345028	17086	Economy	7900.00
0005433345561	17086	Economy	7900.00
0005433345615	17086	Economy	7900.00
0005433345341	17086	Economy	7900.00
0005433345062	17086	Economy	7900.00
0005433345588	17086	Economy	7900.00
0005433345451	17086	Economy	7900.00
0005433345264	17086	Economy	7900.00
0005433345378	17086	Economy	7900.00
0005433345145	17086	Economy	7900.00
0005433345309	17086	Economy	7900.00
0005433345714	17086	Economy	7900.00
0005433345225	17086	Economy	7900.00
0005432293279	17086	Economy	7900.00
0005435545972	17086	Economy	7900.00
0005433345015	17086	Economy	7900.00
0005433345374	17086	Economy	7900.00
0005433345624	17086	Economy	7900.00
0005433345254	17086	Economy	7900.00
0005433345340	17086	Economy	7900.00
0005433345585	17086	Economy	7900.00
0005433345308	17086	Economy	7900.00
0005435545997	17086	Economy	7900.00
0005433345368	17086	Economy	7900.00
0005435545968	17086	Economy	7900.00
0005433345411	17086	Economy	8600.00
0005433345248	17086	Economy	8600.00
0005433345003	17086	Economy	8600.00
0005433345591	17086	Economy	8600.00
0005432293280	17086	Economy	8600.00
0005433345638	17086	Economy	8600.00
0005433345332	17086	Economy	7900.00
0005433345768	17086	Economy	7900.00
0005433345227	17086	Economy	7900.00
0005433344996	17086	Economy	7900.00
0005433345611	17086	Economy	7900.00
0005433345005	17086	Economy	7900.00
0005433344839	17086	Economy	7900.00
0005433345166	17086	Economy	7900.00
0005433345002	17086	Economy	7900.00
0005433345556	17086	Economy	7900.00
0005433345614	17086	Economy	7900.00
0005433345450	17086	Economy	7900.00
0005433345549	17086	Economy	7900.00
0005433345628	17086	Economy	7900.00
0005433345420	17086	Economy	7900.00
0005433345048	17086	Economy	7900.00
0005435097450	17086	Economy	7900.00
0005433345067	17086	Economy	7900.00
0005433344877	17086	Economy	7900.00
0005433345375	17086	Economy	7900.00
0005433345063	17086	Economy	7900.00
0005433345454	17086	Economy	7900.00
0005433345455	17086	Economy	7900.00
0005433345186	17086	Economy	7900.00
0005433345245	17086	Economy	7900.00
0005433345146	17086	Economy	7900.00
0005435545967	17086	Economy	7900.00
0005433345597	17086	Economy	7900.00
0005433344997	17086	Economy	7900.00
0005435097437	17086	Economy	7900.00
0005433345623	17086	Economy	7900.00
0005433345511	17086	Economy	7900.00
0005433344971	17086	Economy	7900.00
0005433345667	17086	Economy	7900.00
0005433344791	17086	Economy	7900.00
0005435545996	17086	Economy	7900.00
0005435545966	17086	Economy	7900.00
0005433345285	17086	Economy	7900.00
0005433345458	17086	Economy	7900.00
0005433345767	17086	Economy	7900.00
0005433345284	17086	Economy	7900.00
0005433345418	17086	Economy	7900.00
0005433345456	17086	Economy	7900.00
0005433345210	17086	Economy	7900.00
0005433345713	17086	Economy	7900.00
0005433345424	17086	Economy	7900.00
0005435097389	17086	Economy	7900.00
0005433345574	17086	Economy	7900.00
0005435545970	17086	Economy	7900.00
0005433345316	17086	Economy	7900.00
0005433345232	17086	Economy	7900.00
0005433345329	17086	Economy	7900.00
0005433345701	17086	Economy	7900.00
0005435545995	17086	Economy	7900.00
0005433345211	17086	Economy	7900.00
0005433345536	17086	Economy	7900.00
0005433344967	17086	Economy	7900.00
0005435097430	17086	Economy	7900.00
0005433345255	17086	Economy	7900.00
0005433345589	17086	Economy	7900.00
0005433345380	17086	Economy	7900.00
0005433345526	17086	Economy	7900.00
0005433344943	17086	Economy	7900.00
0005433345586	17086	Economy	7900.00
0005433344982	17086	Economy	7900.00
0005433345347	17086	Economy	7900.00
0005433345576	17086	Economy	7900.00
0005433344986	17086	Economy	7900.00
0005433345419	17086	Economy	7900.00
0005433345317	17086	Economy	7900.00
0005433344876	17086	Economy	7900.00
0005433477284	9080	Business	26600.00
0005432920277	9080	Business	26600.00
0005432920360	9080	Business	26600.00
0005432920365	9080	Economy	8900.00
0005432920261	9080	Economy	8900.00
0005434159032	9080	Economy	8900.00
0005432920341	9080	Economy	9800.00
0005432920370	9080	Economy	8900.00
0005432920280	9080	Economy	8900.00
0005432920334	9080	Economy	8900.00
0005432920253	9080	Economy	8900.00
0005432920350	9080	Economy	8900.00
0005432920254	9080	Economy	8900.00
0005432920281	9080	Economy	8900.00
0005432920276	9080	Economy	8900.00
0005433507726	9080	Economy	8900.00
0005432920279	9080	Economy	8900.00
0005432920354	9080	Economy	8900.00
0005432920372	9080	Economy	8900.00
0005433507725	9080	Economy	8900.00
0005432920271	9080	Economy	8900.00
0005432920262	9080	Economy	8900.00
0005432920317	9080	Economy	8900.00
0005433477285	9080	Economy	8900.00
0005433507724	9080	Economy	8900.00
0005433477287	9080	Economy	8900.00
0005432920371	9080	Economy	8900.00
0005433507727	9080	Economy	8900.00
0005433477286	9080	Economy	8900.00
0005434159026	9080	Economy	8900.00
0005434159043	9080	Economy	8900.00
0005433507618	20455	Business	26600.00
0005433507672	20455	Business	26600.00
0005433507563	20455	Business	26600.00
0005433477097	20455	Business	26600.00
0005433507609	20455	Business	26600.00
0005433507707	20455	Business	26600.00
0005433477023	20455	Business	26600.00
0005433477070	20455	Business	26600.00
0005433507667	20455	Economy	8900.00
0005433507539	20455	Economy	8900.00
0005433477026	20455	Economy	8900.00
0005433481335	20455	Economy	8900.00
0005433507621	20455	Economy	8900.00
0005433507671	20455	Economy	8900.00
0005433507616	20455	Economy	9800.00
0005433477064	20455	Economy	9800.00
0005433507608	20455	Economy	9800.00
0005433477115	20455	Economy	9800.00
0005433477053	20455	Economy	8900.00
0005433507666	20455	Economy	8900.00
0005433477000	20455	Economy	8900.00
0005433477160	20455	Economy	8900.00
0005433507523	20455	Economy	8900.00
0005433481364	20455	Economy	8900.00
0005433507527	20455	Economy	8900.00
0005433477096	20455	Economy	8900.00
0005433507524	20455	Economy	8900.00
0005433476996	20455	Economy	8900.00
0005433476999	20455	Economy	8900.00
0005433507617	20455	Economy	8900.00
0005433477102	20455	Economy	8900.00
0005433507629	20455	Economy	8900.00
0005433507592	20455	Economy	8900.00
0005433477156	20455	Economy	8900.00
0005434159060	20455	Economy	8900.00
0005433477159	20455	Economy	8900.00
0005432920478	20455	Economy	8900.00
0005433477082	20455	Economy	8900.00
0005433477178	20455	Economy	8900.00
0005433507658	20455	Economy	8900.00
0005433477051	20455	Economy	8900.00
0005433481352	20455	Economy	8900.00
0005433477099	20455	Economy	8900.00
0005433477177	20455	Economy	8900.00
0005433507640	20455	Economy	8900.00
0005433481363	20455	Economy	8900.00
0005433507622	20455	Economy	8900.00
0005433477098	20455	Economy	8900.00
0005433507639	20455	Economy	8900.00
0005433507681	20455	Economy	8900.00
0005433477193	20455	Economy	8900.00
0005433477014	20455	Economy	8900.00
0005433477017	20455	Economy	8900.00
0005433477242	20455	Economy	8900.00
0005433481336	20455	Economy	8900.00
0005433507633	20455	Economy	8900.00
0005433477022	20455	Economy	8900.00
0005433507606	20455	Economy	8900.00
0005433477047	20455	Economy	8900.00
0005433477087	20455	Economy	8900.00
0005433477149	20455	Economy	8900.00
0005433477157	20455	Economy	8900.00
0005433477081	20455	Economy	8900.00
0005432920479	20455	Economy	8900.00
0005432920477	20455	Economy	8900.00
0005433477013	20455	Economy	8900.00
0005435179706	10227	Economy	5800.00
0005432394221	10227	Economy	5800.00
0005432396356	10227	Economy	5800.00
0005432396357	10227	Economy	5800.00
0005435179012	10227	Economy	5800.00
0005432394222	10227	Economy	5800.00
0005432394220	10227	Economy	5800.00
0005432394219	10227	Economy	5800.00
0005432396358	10227	Economy	5800.00
0005432396341	18298	Economy	5800.00
0005432400205	18298	Economy	5800.00
0005432396322	18298	Economy	5800.00
0005432396323	18298	Economy	5800.00
0005432396325	18298	Economy	5800.00
0005432396326	18298	Economy	5800.00
0005432396327	18298	Economy	5800.00
0005432400206	18298	Economy	5800.00
0005432400209	18298	Economy	5800.00
0005432396337	18298	Economy	5800.00
0005432396340	18298	Economy	5800.00
0005435127377	10943	Business	9500.00
0005435626575	10943	Business	9500.00
0005435626546	10943	Business	9500.00
0005435626607	10943	Business	9500.00
0005435127221	10943	Business	9500.00
0005435127365	10943	Business	9500.00
0005435127118	10943	Business	9500.00
0005435626580	10943	Economy	3200.00
0005435626563	10943	Economy	3200.00
0005435127390	10943	Economy	3200.00
0005435626574	10943	Economy	3200.00
0005435626594	10943	Economy	3200.00
0005435626562	10943	Economy	3500.00
0005435127228	10943	Economy	3500.00
0005435127204	10943	Economy	3500.00
0005435127125	10943	Economy	3500.00
0005435626595	10943	Economy	3500.00
0005435127428	10943	Economy	3200.00
0005435127275	10943	Economy	3200.00
0005435127307	10943	Economy	3200.00
0005435126997	10943	Economy	3200.00
0005435127359	10943	Economy	3200.00
0005435127439	10943	Economy	3200.00
0005435626602	10943	Economy	3200.00
0005435127376	10943	Economy	3200.00
0005435626566	10943	Economy	3200.00
0005435127368	10943	Economy	3200.00
0005435127243	10943	Economy	3200.00
0005435127261	10943	Economy	3200.00
0005435127391	10943	Economy	3200.00
0005435626552	10943	Economy	3200.00
0005435127455	10943	Economy	3200.00
0005435127161	10943	Economy	3200.00
0005435626483	10943	Economy	3200.00
0005435127157	10943	Economy	3200.00
0005435126998	10943	Economy	3200.00
0005435127117	10943	Economy	3200.00
0005435127203	10943	Economy	3200.00
0005435626606	10943	Economy	3200.00
0005435127244	10943	Economy	3200.00
0005435127294	10943	Economy	3200.00
0005435127293	10943	Economy	3200.00
0005435626512	10943	Economy	3200.00
0005435127235	10943	Economy	3200.00
0005435127226	10943	Economy	3200.00
0005435127155	10943	Economy	3200.00
0005435626511	10943	Economy	3200.00
0005435127299	10943	Economy	3200.00
0005435127360	10943	Economy	3200.00
0005435556738	10943	Economy	3200.00
0005435626553	10943	Economy	3200.00
0005435127384	10943	Economy	3200.00
0005435127169	10943	Economy	3200.00
0005435626568	10943	Economy	3200.00
0005435127440	10943	Economy	3200.00
0005434928381	10943	Economy	3200.00
0005435127373	10943	Economy	3200.00
0005435127255	10943	Economy	3200.00
0005435127426	10943	Economy	3200.00
0005435626573	10943	Economy	3200.00
0005435127358	10943	Economy	3200.00
0005435127250	10943	Economy	3200.00
0005435626598	10943	Economy	3200.00
0005435626557	10943	Economy	3200.00
0005435127374	10943	Economy	3200.00
0005435127222	10943	Economy	3200.00
0005435127572	14720	Business	9500.00
0005434928369	14720	Business	9500.00
0005434928351	14720	Business	9500.00
0005435127574	14720	Business	9500.00
0005435127575	14720	Business	9500.00
0005435127571	14720	Economy	3200.00
0005435626842	14720	Economy	3200.00
0005434411892	14720	Economy	3500.00
0005434928353	14720	Economy	3200.00
0005435626856	14720	Economy	3200.00
0005435626851	14720	Economy	3200.00
0005434411891	14720	Economy	3200.00
0005435626853	14720	Economy	3200.00
0005435626850	14720	Economy	3200.00
0005435626854	14720	Economy	3200.00
0005435626846	14720	Economy	3200.00
0005435127569	14720	Economy	3200.00
0005434928379	14720	Economy	3200.00
0005435127570	14720	Economy	3200.00
0005435626855	14720	Economy	3200.00
0005435626843	14720	Economy	3200.00
0005434411893	14720	Economy	3200.00
0005435626848	14720	Economy	3200.00
0005435626841	14720	Economy	3200.00
0005435127573	14720	Economy	3200.00
0005434411874	14720	Economy	3200.00
0005435554328	14720	Economy	3200.00
0005435626847	14720	Economy	3200.00
0005435127576	14720	Economy	3200.00
0005434928352	14720	Economy	3200.00
0005435626844	14720	Economy	3200.00
0005435626849	14720	Economy	3200.00
0005435626845	14720	Economy	3200.00
0005435626852	14720	Economy	3200.00
0005435443559	7137	Business	86900.00
0005432400222	7137	Business	86900.00
0005435219250	7137	Business	86900.00
0005435443568	7137	Business	86900.00
0005435443511	7137	Business	86900.00
0005435443528	7137	Business	86900.00
0005435219244	7137	Economy	29000.00
0005435443535	7137	Economy	29000.00
0005435216633	7137	Economy	31900.00
0005435715971	7137	Economy	29000.00
0005435715970	7137	Economy	29000.00
0005435443560	7137	Economy	29000.00
0005435443534	7137	Economy	29000.00
0005435219249	7137	Economy	29000.00
0005435443543	7137	Economy	29000.00
0005435443538	7137	Economy	29000.00
0005435216635	7137	Economy	29000.00
0005435443546	7137	Economy	29000.00
0005435216634	7137	Economy	29000.00
0005435443510	7137	Economy	29000.00
0005432394206	27050	Business	86900.00
0005435715850	27050	Business	86900.00
0005435715893	27050	Business	86900.00
0005435179022	27050	Business	86900.00
0005435178539	27050	Economy	29000.00
0005435443588	27050	Economy	29000.00
0005435443587	27050	Economy	31900.00
0005435715857	27050	Economy	31900.00
0005435715859	27050	Economy	29000.00
0005435715891	27050	Economy	29000.00
0005432398287	27050	Economy	29000.00
0005432394187	27050	Economy	29000.00
0005435715906	27050	Economy	29000.00
0005432398288	27050	Economy	29000.00
0005435715820	27050	Economy	29000.00
0005435715860	27050	Economy	29000.00
0005435443586	27050	Economy	29000.00
0005432394186	27050	Economy	29000.00
0005435715905	27050	Economy	29000.00
0005435179023	27050	Economy	29000.00
0005432398289	27050	Economy	29000.00
0005435715833	27050	Economy	29000.00
0005435715911	27050	Economy	29000.00
0005435715909	27050	Economy	29000.00
0005435715861	27050	Economy	29000.00
0005435715904	27050	Economy	29000.00
0005432398265	27050	Economy	29000.00
0005435715894	27050	Economy	29000.00
0005432394191	27050	Economy	29000.00
0005433060471	2716	Economy	7700.00
0005434085040	28470	Economy	7700.00
0005434085033	28470	Economy	7700.00
0005434085043	28470	Economy	7700.00
0005434085042	28470	Economy	7700.00
0005434085019	28470	Economy	7700.00
0005434085045	28470	Economy	7700.00
0005434085039	28470	Economy	7700.00
0005434085046	28470	Economy	7700.00
0005435844402	25202	Economy	29000.00
0005432632938	25202	Economy	29000.00
0005435844389	25202	Economy	26400.00
0005432632934	25202	Economy	26400.00
0005432632931	25202	Economy	26400.00
0005432632936	25202	Economy	26400.00
0005435844384	25202	Economy	26400.00
0005435844387	25202	Economy	26400.00
0005435844366	25202	Economy	26400.00
0005432632940	25202	Economy	26400.00
0005432632935	25202	Economy	26400.00
0005432632939	25202	Economy	26400.00
0005432632932	25202	Economy	26400.00
0005432632933	25202	Economy	26400.00
0005435844386	25202	Economy	26400.00
0005432632937	25202	Economy	26400.00
0005435844438	28172	Economy	29000.00
0005432632891	28172	Economy	26400.00
0005432632885	28172	Economy	26400.00
0005432632875	28172	Economy	26400.00
0005432632877	28172	Economy	26400.00
0005435844441	28172	Economy	26400.00
0005432632866	28172	Economy	26400.00
0005432632898	28172	Economy	26400.00
0005435844440	28172	Economy	26400.00
0005435844439	28172	Economy	26400.00
0005432632894	28172	Economy	26400.00
0005432632897	28172	Economy	26400.00
0005432632863	28172	Economy	26400.00
0005432632882	28172	Economy	26400.00
0005432632878	28172	Economy	26400.00
0005435844436	28172	Economy	26400.00
0005432632899	28172	Economy	26400.00
0005432632868	28172	Economy	26400.00
0005432632881	28172	Economy	26400.00
0005432632892	28172	Economy	26400.00
0005435844442	28172	Economy	26400.00
0005432632867	28172	Economy	26400.00
0005432632923	28172	Economy	26400.00
0005432632874	28172	Economy	26400.00
0005435844437	28172	Economy	26400.00
0005432632896	28172	Economy	26400.00
0005435518323	11398	Business	20200.00
0005435541475	11398	Business	20200.00
0005435541512	11398	Business	20200.00
0005435541531	11398	Economy	6700.00
0005435518343	11398	Economy	6700.00
0005435541448	11398	Economy	6700.00
0005435541507	11398	Economy	6700.00
0005435541453	11398	Economy	6700.00
0005435518345	11398	Economy	7400.00
0005435518342	11398	Economy	7400.00
0005435541523	11398	Economy	6700.00
0005435541530	11398	Economy	6700.00
0005435541511	11398	Economy	6700.00
0005435541561	11398	Economy	6700.00
0005435541585	11398	Economy	6700.00
0005435541416	11398	Economy	6700.00
0005435518280	11398	Economy	6700.00
0005435541502	11398	Economy	6700.00
0005435541532	11398	Economy	6700.00
0005435541570	11398	Economy	6700.00
0005435541546	11398	Economy	6700.00
0005435541590	11398	Economy	6700.00
0005435541522	11398	Economy	6700.00
0005435541553	11398	Economy	6700.00
0005435518278	11398	Economy	6700.00
0005435541470	11398	Economy	6700.00
0005435518347	11398	Economy	6700.00
0005435541589	11398	Economy	6700.00
0005435541469	11398	Economy	6700.00
0005435541588	11398	Economy	6700.00
0005435518376	11398	Economy	6700.00
0005435541447	11398	Economy	6700.00
0005435518295	11398	Economy	6700.00
0005435541424	11398	Economy	6700.00
0005435541524	11398	Economy	6700.00
0005435518296	11398	Economy	6700.00
0005435518287	11398	Economy	6700.00
0005435541455	11398	Economy	6700.00
0005435541554	11398	Economy	6700.00
0005435541517	11398	Economy	6700.00
0005435530187	22256	Business	20200.00
0005435530188	22256	Business	20200.00
0005435529888	22256	Economy	6700.00
0005432294559	22256	Economy	7400.00
0005435541637	22256	Economy	7400.00
0005435529887	22256	Economy	6700.00
0005435530186	22256	Economy	6700.00
0005435529890	22256	Economy	6700.00
0005435529891	22256	Economy	6700.00
0005435541638	22256	Economy	6700.00
0005435541639	22256	Economy	6700.00
0005435529886	22256	Economy	6700.00
0005435541636	22256	Economy	6700.00
0005435530184	22256	Economy	6700.00
0005435541640	22256	Economy	6700.00
0005435530189	22256	Economy	6700.00
0005435529884	22256	Economy	6700.00
0005435529889	22256	Economy	6700.00
0005435529885	22256	Economy	6700.00
0005432294560	22256	Economy	6700.00
0005435530190	22256	Economy	6700.00
0005435530185	22256	Economy	6700.00
0005433252305	2258	Business	20200.00
0005433252188	2258	Business	20200.00
0005433252261	2258	Business	20200.00
0005433252243	2258	Business	20200.00
0005434908877	2258	Business	20200.00
0005434908875	2258	Economy	6700.00
0005434908882	2258	Economy	6700.00
0005434908880	2258	Economy	6700.00
0005433252249	2258	Economy	6700.00
0005433252202	2258	Economy	6700.00
0005433252335	2258	Economy	6700.00
0005433252246	2258	Economy	6700.00
0005433252218	2258	Economy	6700.00
0005433252224	2258	Economy	7400.00
0005433252236	2258	Economy	7400.00
0005433252253	2258	Economy	7400.00
0005433252227	2258	Economy	6700.00
0005434908886	2258	Economy	6700.00
0005433401064	2258	Economy	6700.00
0005433252258	2258	Economy	6700.00
0005435787476	2258	Economy	6700.00
0005433401063	2258	Economy	6700.00
0005433252129	2258	Economy	6700.00
0005433252175	2258	Economy	6700.00
0005433252194	2258	Economy	6700.00
0005434908876	2258	Economy	6700.00
0005433252228	2258	Economy	6700.00
0005433252223	2258	Economy	6700.00
0005434908879	2258	Economy	6700.00
0005433252179	2258	Economy	6700.00
0005434908888	2258	Economy	6700.00
0005433252336	2258	Economy	6700.00
0005433252203	2258	Economy	6700.00
0005434908878	2258	Economy	6700.00
0005433252225	2258	Economy	6700.00
0005433252165	2258	Economy	6700.00
0005433252254	2258	Economy	6700.00
0005433252180	2258	Economy	6700.00
0005433252110	2258	Economy	6700.00
0005434908883	2258	Economy	6700.00
0005433252279	2258	Economy	6700.00
0005434908887	2258	Economy	6700.00
0005434908881	2258	Economy	6700.00
0005433252259	2258	Economy	6700.00
0005433252172	2258	Economy	6700.00
0005434908885	2258	Economy	6700.00
0005433401058	2258	Economy	6700.00
0005433252278	2258	Economy	6700.00
0005433252242	2258	Economy	6700.00
0005434908884	2258	Economy	6700.00
0005433252159	2258	Economy	6700.00
0005434908889	2258	Economy	6700.00
0005434908874	2258	Economy	6700.00
0005433252111	2258	Economy	6700.00
0005433252274	2258	Economy	6700.00
0005434908479	25583	Business	20200.00
0005434908445	25583	Business	20200.00
0005434908543	25583	Business	20200.00
0005434908342	25583	Business	20200.00
0005434908145	25583	Business	20200.00
0005434908345	25583	Business	20200.00
0005434908559	25583	Business	20200.00
0005433252375	25583	Economy	6700.00
0005434908540	25583	Economy	6700.00
0005434908598	25583	Economy	6700.00
0005434908542	25583	Economy	6700.00
0005434908548	25583	Economy	6700.00
0005434908374	25583	Economy	6700.00
0005433252376	25583	Economy	6700.00
0005434908415	25583	Economy	7400.00
0005434908526	25583	Economy	7400.00
0005433252377	25583	Economy	6700.00
0005434908407	25583	Economy	6700.00
0005434908560	25583	Economy	6700.00
0005434908322	25583	Economy	6700.00
0005434908218	25583	Economy	6700.00
0005434908437	25583	Economy	6700.00
0005434908419	25583	Economy	6700.00
0005434908527	25583	Economy	6700.00
0005434908549	25583	Economy	6700.00
0005434908547	25583	Economy	6700.00
0005433252374	25583	Economy	6700.00
0005434908595	25583	Economy	6700.00
0005434908535	25583	Economy	6700.00
0005434908300	25583	Economy	6700.00
0005434908358	25583	Economy	6700.00
0005434908473	25583	Economy	6700.00
0005434908146	25583	Economy	6700.00
0005434908357	25583	Economy	6700.00
0005433252379	25583	Economy	6700.00
0005434908328	25583	Economy	6700.00
0005434908435	25583	Economy	6700.00
0005433252382	25583	Economy	6700.00
0005434908516	25583	Economy	6700.00
0005434908318	25583	Economy	6700.00
0005434908231	25583	Economy	6700.00
0005433252380	25583	Economy	6700.00
0005433252372	25583	Economy	6700.00
0005434908550	25583	Economy	6700.00
0005434908401	25583	Economy	6700.00
0005434908395	25583	Economy	6700.00
0005434908528	25583	Economy	6700.00
0005434908478	25583	Economy	6700.00
0005434908177	25583	Economy	6700.00
0005434908444	25583	Economy	6700.00
0005434908232	25583	Economy	6700.00
0005434908329	25583	Economy	6700.00
0005433252373	25583	Economy	6700.00
0005433252381	25583	Economy	6700.00
0005433252378	25583	Economy	6700.00
0005432621454	2535	Economy	13600.00
0005432862503	2535	Economy	12400.00
0005432621453	2535	Economy	12400.00
0005432862467	2535	Economy	12400.00
0005432862505	2535	Economy	12400.00
0005432862468	2535	Economy	12400.00
0005432621398	28033	Economy	13600.00
0005432621351	28033	Economy	13600.00
0005432621431	28033	Economy	13600.00
0005432862526	28033	Economy	13600.00
0005432862527	28033	Economy	12400.00
0005432621386	28033	Economy	12400.00
0005432621280	28033	Economy	12400.00
0005432621384	28033	Economy	12400.00
0005432862525	28033	Economy	12400.00
0005432621350	28033	Economy	12400.00
0005432621352	28033	Economy	12400.00
0005432621309	28033	Economy	12400.00
0005432621383	28033	Economy	12400.00
0005432621420	28033	Economy	12400.00
0005432621342	28033	Economy	12400.00
0005432621418	28033	Economy	12400.00
0005432621305	28033	Economy	12400.00
0005432621358	28033	Economy	12400.00
0005432621402	28033	Economy	12400.00
0005432621421	28033	Economy	12400.00
0005432621375	28033	Economy	12400.00
0005432621432	28033	Economy	12400.00
0005432862528	28033	Economy	12400.00
0005432621394	28033	Economy	12400.00
0005432621343	28033	Economy	12400.00
0005432621385	28033	Economy	12400.00
0005432621417	28033	Economy	12400.00
0005432433841	11736	Economy	11300.00
0005432433842	11736	Economy	11300.00
0005434097503	11736	Economy	11300.00
0005434097507	11736	Economy	11300.00
0005434191327	28029	Business	89600.00
0005434191326	28029	Economy	29900.00
0005434191322	28029	Economy	29900.00
0005434191321	28029	Economy	29900.00
0005434191325	28029	Economy	29900.00
0005434191319	28029	Economy	29900.00
0005434191323	28029	Economy	29900.00
0005434191320	28029	Economy	29900.00
0005434191328	28029	Economy	29900.00
0005434191324	28029	Economy	29900.00
0005434191329	28029	Economy	29900.00
0005433452796	30997	Economy	8400.00
0005433451677	30997	Economy	8400.00
0005433451678	30997	Economy	8400.00
0005433452787	31444	Economy	8400.00
0005433452786	31444	Economy	8400.00
0005433454918	31444	Economy	8400.00
0005433452789	31444	Economy	8400.00
0005433452788	31444	Economy	8400.00
0005433454929	31444	Economy	8400.00
0005433129396	12005	Economy	6600.00
0005434326038	12005	Economy	6600.00
0005434326090	12005	Economy	6600.00
0005433129347	12005	Economy	6600.00
0005433129393	12005	Economy	6600.00
0005433134232	12005	Economy	6600.00
0005434326039	12005	Economy	6600.00
0005433134231	12005	Economy	6600.00
0005434326040	12005	Economy	6600.00
0005434326037	12005	Economy	6600.00
0005433129368	12005	Economy	6600.00
0005434184708	12005	Economy	6600.00
0005434326091	12005	Economy	6600.00
0005433129394	12005	Economy	6600.00
0005433129388	12005	Economy	6600.00
0005434326041	12005	Economy	6600.00
0005434184728	29819	Economy	6600.00
0005435935103	16481	Economy	19900.00
0005435935109	16481	Economy	18100.00
0005435935099	16481	Economy	18100.00
0005435698155	16481	Economy	18100.00
0005435935115	16481	Economy	18100.00
0005435698162	16481	Economy	18100.00
0005435698158	16481	Economy	18100.00
0005435698159	16481	Economy	18100.00
0005435698160	16481	Economy	18100.00
0005435698157	16481	Economy	18100.00
0005435698156	16481	Economy	18100.00
0005435698161	16481	Economy	18100.00
0005435698163	16481	Economy	18100.00
0005435697908	24719	Economy	19900.00
0005435697909	24719	Economy	19900.00
0005435697946	24719	Economy	18100.00
0005435697947	24719	Economy	18100.00
0005435697983	24719	Economy	18100.00
0005435698069	24719	Economy	18100.00
0005435698103	24719	Economy	18100.00
0005435697907	24719	Economy	18100.00
0005435697978	24719	Economy	18100.00
0005435698041	24719	Economy	18100.00
0005435697905	24719	Economy	18100.00
0005435698020	24719	Economy	18100.00
0005435697995	24719	Economy	18100.00
0005435698046	24719	Economy	18100.00
0005435697944	24719	Economy	18100.00
0005435697925	24719	Economy	18100.00
0005435698045	24719	Economy	18100.00
0005435697869	24719	Economy	18100.00
0005435697948	24719	Economy	18100.00
0005435698043	24719	Economy	18100.00
0005435698019	24719	Economy	18100.00
0005435697926	24719	Economy	18100.00
0005435697906	24719	Economy	18100.00
0005435697997	24719	Economy	18100.00
0005435698040	24719	Economy	18100.00
0005435697982	24719	Economy	18100.00
0005435698042	24719	Economy	18100.00
0005432968893	18787	Economy	4400.00
0005432968894	18787	Economy	4400.00
0005432968896	18787	Economy	4400.00
0005432968897	18787	Economy	4400.00
0005433724937	18787	Economy	4400.00
0005433724939	18787	Economy	4400.00
0005433724938	18787	Economy	4400.00
0005433724922	21614	Economy	4400.00
0005433724914	21614	Economy	4400.00
0005433724901	21614	Economy	4400.00
0005433724921	21614	Economy	4400.00
0005433724913	21614	Economy	4400.00
0005433724900	21614	Economy	4400.00
0005434140602	7313	Business	23100.00
0005434140589	7313	Business	23100.00
0005434140601	7313	Business	23100.00
0005434140597	7313	Business	23100.00
0005434140604	7313	Economy	7700.00
0005434140595	7313	Economy	7700.00
0005434140594	7313	Economy	7700.00
0005434140591	7313	Economy	7700.00
0005434140596	7313	Economy	7700.00
0005434140603	7313	Economy	7700.00
0005434140593	7313	Economy	7700.00
0005434140605	7313	Economy	7700.00
0005434140608	7313	Economy	7700.00
0005434140592	7313	Economy	7700.00
0005434140600	7313	Economy	7700.00
0005434140607	7313	Economy	7700.00
0005434140598	7313	Economy	7700.00
0005434140606	7313	Economy	7700.00
0005434140590	7313	Economy	7700.00
0005434140599	7313	Economy	7700.00
0005434139848	28541	Business	23100.00
0005434139594	28541	Business	23100.00
0005434139873	28541	Business	23100.00
0005434139870	28541	Business	23100.00
0005434139610	28541	Business	23100.00
0005434140121	28541	Business	23100.00
0005434139816	28541	Business	23100.00
0005434139821	28541	Business	23100.00
0005435283578	28541	Business	23100.00
0005435283586	28541	Business	23100.00
0005434140098	28541	Business	23100.00
0005434139631	28541	Business	23100.00
0005434139698	28541	Economy	7700.00
0005434140137	28541	Economy	7700.00
0005434087617	28541	Economy	7700.00
0005434140146	28541	Economy	7700.00
0005434139849	28541	Economy	7700.00
0005435283579	28541	Economy	7700.00
0005434140017	28541	Economy	7700.00
0005434139991	28541	Economy	7700.00
0005434139869	28541	Economy	7700.00
0005434139972	28541	Economy	8500.00
0005434140053	28541	Economy	8500.00
0005434139785	28541	Economy	8500.00
0005434140179	28541	Economy	8500.00
0005434140014	28541	Economy	7700.00
0005434139324	28541	Economy	7700.00
0005434139789	28541	Economy	7700.00
0005435283589	28541	Economy	7700.00
0005434140090	28541	Economy	7700.00
0005434140118	28541	Economy	7700.00
0005434139781	28541	Economy	7700.00
0005434140062	28541	Economy	7700.00
0005435283576	28541	Economy	7700.00
0005434140010	28541	Economy	7700.00
0005435283577	28541	Economy	7700.00
0005435283587	28541	Economy	7700.00
0005434139902	28541	Economy	7700.00
0005434140260	28541	Economy	7700.00
0005434140138	28541	Economy	7700.00
0005435283574	28541	Economy	7700.00
0005434140185	28541	Economy	7700.00
0005435283588	28541	Economy	7700.00
0005435283590	28541	Economy	7700.00
0005434140144	28541	Economy	7700.00
0005434140047	28541	Economy	7700.00
0005434140094	28541	Economy	7700.00
0005434140009	28541	Economy	7700.00
0005434140161	28541	Economy	7700.00
0005435283581	28541	Economy	7700.00
0005434140336	28541	Economy	7700.00
0005434139691	28541	Economy	7700.00
0005434139912	28541	Economy	7700.00
0005434140016	28541	Economy	7700.00
0005434087616	28541	Economy	7700.00
0005434139950	28541	Economy	7700.00
0005434140145	28541	Economy	7700.00
0005434139940	28541	Economy	7700.00
0005434139965	28541	Economy	7700.00
0005434140060	28541	Economy	7700.00
0005434139952	28541	Economy	7700.00
0005434140259	28541	Economy	7700.00
0005434139891	28541	Economy	7700.00
0005434140184	28541	Economy	7700.00
0005434139911	28541	Economy	7700.00
0005434139711	28541	Economy	7700.00
0005434140034	28541	Economy	7700.00
0005434087619	28541	Economy	7700.00
0005434140018	28541	Economy	7700.00
0005434140032	28541	Economy	7700.00
0005434139894	28541	Economy	7700.00
0005434140337	28541	Economy	7700.00
0005434140008	28541	Economy	7700.00
0005435283582	28541	Economy	7700.00
0005435283583	28541	Economy	7700.00
0005434139819	28541	Economy	7700.00
0005435283575	28541	Economy	7700.00
0005434140338	28541	Economy	7700.00
0005434140202	28541	Economy	7700.00
0005434140097	28541	Economy	7700.00
0005434140120	28541	Economy	7700.00
0005434087628	28541	Economy	7700.00
0005434140371	28541	Economy	7700.00
0005434140242	28541	Economy	7700.00
0005435283584	28541	Economy	7700.00
0005435283585	28541	Economy	7700.00
0005434140339	28541	Economy	7700.00
0005435283580	28541	Economy	7700.00
0005434140051	28541	Economy	7700.00
0005434140228	28541	Economy	7700.00
0005435808526	1901	Economy	23900.00
0005433407698	1901	Economy	21700.00
0005435808527	1901	Economy	21700.00
0005433407700	1901	Economy	21700.00
0005435808530	1901	Economy	21700.00
0005435808529	1901	Economy	21700.00
0005433407699	1901	Economy	21700.00
0005435808531	1901	Economy	21700.00
0005435808528	1901	Economy	21700.00
0005434610338	1901	Economy	21700.00
0005433407668	1901	Economy	21700.00
0005434610307	23068	Economy	21700.00
0005434610316	23068	Economy	21700.00
0005434610327	23068	Economy	21700.00
0005434610326	23068	Economy	21700.00
0005434610320	23068	Economy	21700.00
0005434610319	23068	Economy	21700.00
0005434610328	23068	Economy	21700.00
0005434505083	16684	Economy	7600.00
0005434505000	16684	Economy	7600.00
0005434505080	16684	Economy	7600.00
0005434504949	16684	Economy	7600.00
0005434504914	16684	Economy	6900.00
0005434505087	16684	Economy	6900.00
0005434505154	16684	Economy	6900.00
0005434504907	16684	Economy	6900.00
0005434505023	16684	Economy	6900.00
0005434505070	16684	Economy	6900.00
0005434505033	16684	Economy	6900.00
0005434505112	16684	Economy	6900.00
0005434504807	16684	Economy	6900.00
0005434504988	16684	Economy	6900.00
0005434505013	16684	Economy	6900.00
0005434505088	16684	Economy	6900.00
0005434505062	16684	Economy	6900.00
0005434505169	16684	Economy	6900.00
0005434505029	16684	Economy	6900.00
0005434505173	16684	Economy	6900.00
0005434505111	16684	Economy	6900.00
0005434504875	16684	Economy	6900.00
0005434504931	16684	Economy	6900.00
0005434505026	16684	Economy	6900.00
0005434505069	16684	Economy	6900.00
0005434505095	16684	Economy	6900.00
0005434505164	16684	Economy	6900.00
0005434505067	16684	Economy	6900.00
0005434505071	16684	Economy	6900.00
0005434505084	16684	Economy	6900.00
0005434505006	16684	Economy	6900.00
0005434505017	16684	Economy	6900.00
0005434505165	16684	Economy	6900.00
0005434505021	16684	Economy	6900.00
0005434505086	16684	Economy	6900.00
0005434505001	16684	Economy	6900.00
0005434505022	16684	Economy	6900.00
0005434505081	16684	Economy	6900.00
0005434505155	16684	Economy	6900.00
0005434505064	16684	Economy	6900.00
0005434504906	16684	Economy	6900.00
0005434505018	16684	Economy	6900.00
0005434505030	16684	Economy	6900.00
0005434505063	16684	Economy	6900.00
0005434505103	16684	Economy	6900.00
0005434504976	16684	Economy	6900.00
0005434505003	16684	Economy	6900.00
0005434505298	22883	Economy	7600.00
0005434505295	22883	Economy	6900.00
0005434505292	22883	Economy	6900.00
0005434505297	22883	Economy	6900.00
0005434505291	22883	Economy	6900.00
0005434505299	22883	Economy	6900.00
0005434505300	22883	Economy	6900.00
0005434505296	22883	Economy	6900.00
0005434505290	22883	Economy	6900.00
0005434505293	22883	Economy	6900.00
0005434505294	22883	Economy	6900.00
0005433266927	2222	Economy	7700.00
0005433266908	2222	Economy	7000.00
0005433266880	2222	Economy	7000.00
0005435078792	2222	Economy	7000.00
0005433266942	2222	Economy	7000.00
0005433266971	2222	Economy	7000.00
0005433266899	2222	Economy	7000.00
0005433266881	2222	Economy	7000.00
0005433266884	2222	Economy	7000.00
0005433266937	2222	Economy	7000.00
0005433266928	2222	Economy	7000.00
0005433266948	2222	Economy	7000.00
0005433266945	2222	Economy	7000.00
0005433266938	2222	Economy	7000.00
0005433266949	2222	Economy	7000.00
0005435078683	24377	Economy	7000.00
0005435078693	24377	Economy	7000.00
0005435078727	24377	Economy	7000.00
0005435078682	24377	Economy	7000.00
0005433266991	24377	Economy	7000.00
0005435078690	24377	Economy	7000.00
0005435078674	24377	Economy	7000.00
0005433266990	24377	Economy	7000.00
0005435078675	24377	Economy	7000.00
0005435078691	24377	Economy	7000.00
0005435803351	6669	Economy	10800.00
0005435464562	6669	Economy	10800.00
0005434989116	6669	Economy	9800.00
0005435803352	6669	Economy	9800.00
0005434989117	6669	Economy	9800.00
0005434989111	6669	Economy	9800.00
0005434989114	6669	Economy	9800.00
0005434989115	6669	Economy	9800.00
0005435464552	6669	Economy	9800.00
0005435464553	6669	Economy	9800.00
0005434989113	6669	Economy	9800.00
0005434989112	6669	Economy	9800.00
0005434988940	23606	Economy	9800.00
0005434988912	23606	Economy	9800.00
0005434988952	23606	Economy	9800.00
0005434988946	23606	Economy	9800.00
0005434988932	23606	Economy	9800.00
0005434988958	23606	Economy	9800.00
0005435803338	23606	Economy	9800.00
0005434988931	23606	Economy	9800.00
0005435803328	23606	Economy	9800.00
0005434988967	23606	Economy	9800.00
0005434988930	23606	Economy	9800.00
0005434988973	23606	Economy	9800.00
0005435803322	23606	Economy	9800.00
0005435803321	23606	Economy	9800.00
0005434988957	23606	Economy	9800.00
0005434988947	23606	Economy	9800.00
0005434988965	23606	Economy	9800.00
0005434988959	23606	Economy	9800.00
0005435803337	23606	Economy	9800.00
0005434988950	23606	Economy	9800.00
0005432384325	30460	Business	9900.00
0005432384327	30460	Business	9900.00
0005432384328	30460	Business	9900.00
0005432384335	30460	Business	9900.00
0005433450604	30460	Economy	3300.00
0005432384324	30460	Economy	3300.00
0005433450601	30460	Economy	3600.00
0005432384329	30460	Economy	3300.00
0005433450603	30460	Economy	3300.00
0005432384326	30460	Economy	3300.00
0005432384331	30460	Economy	3300.00
0005433450605	30460	Economy	3300.00
0005433450608	30460	Economy	3300.00
0005432384334	30460	Economy	3300.00
0005433450602	30460	Economy	3300.00
0005433450607	30460	Economy	3300.00
0005433450606	30460	Economy	3300.00
0005432384330	30460	Economy	3300.00
0005432384333	30460	Economy	3300.00
0005432384332	30460	Economy	3300.00
0005432384115	31300	Business	9900.00
0005432384000	31300	Business	9900.00
0005432383881	31300	Business	9900.00
0005433450411	31300	Business	9900.00
0005432383855	31300	Business	9900.00
0005433450532	31300	Business	9900.00
0005432384099	31300	Business	9900.00
0005433450499	31300	Business	9900.00
0005432384082	31300	Economy	3300.00
0005432383737	31300	Economy	3300.00
0005432383854	31300	Economy	3300.00
0005433450490	31300	Economy	3300.00
0005432383788	31300	Economy	3300.00
0005432383829	31300	Economy	3300.00
0005433450413	31300	Economy	3600.00
0005433450522	31300	Economy	3600.00
0005433450470	31300	Economy	3600.00
0005432383826	31300	Economy	3600.00
0005432383833	31300	Economy	3300.00
0005432383827	31300	Economy	3300.00
0005432383832	31300	Economy	3300.00
0005432384063	31300	Economy	3300.00
0005433450410	31300	Economy	3300.00
0005433450419	31300	Economy	3300.00
0005433450531	31300	Economy	3300.00
0005432384031	31300	Economy	3300.00
0005433450420	31300	Economy	3300.00
0005432383958	31300	Economy	3300.00
0005433453807	31300	Economy	3300.00
0005432384081	31300	Economy	3300.00
0005432384100	31300	Economy	3300.00
0005433450491	31300	Economy	3300.00
0005433450478	31300	Economy	3300.00
0005432383964	31300	Economy	3300.00
0005432383848	31300	Economy	3300.00
0005433451656	31300	Economy	3300.00
0005433450501	31300	Economy	3300.00
0005432384030	31300	Economy	3300.00
0005433451662	31300	Economy	3300.00
0005432383971	31300	Economy	3300.00
0005432383906	31300	Economy	3300.00
0005432383966	31300	Economy	3300.00
0005432383943	31300	Economy	3300.00
0005433451671	31300	Economy	3300.00
0005432384071	31300	Economy	3300.00
0005432383945	31300	Economy	3300.00
0005432383779	31300	Economy	3300.00
0005432383944	31300	Economy	3300.00
0005432384160	31300	Economy	3300.00
0005433453808	31300	Economy	3300.00
0005432383998	31300	Economy	3300.00
0005433453796	31300	Economy	3300.00
0005433453801	31300	Economy	3300.00
0005432383738	31300	Economy	3300.00
0005432384064	31300	Economy	3300.00
0005432383865	31300	Economy	3300.00
0005433450507	31300	Economy	3300.00
0005432383936	31300	Economy	3300.00
0005433451670	31300	Economy	3300.00
0005433788289	26476	Economy	26200.00
0005435548627	26476	Economy	23800.00
0005435548628	26476	Economy	23800.00
0005433788290	26476	Economy	23800.00
0005433788296	26476	Economy	23800.00
0005435548625	26476	Economy	23800.00
0005433788299	26476	Economy	23800.00
0005433788285	26476	Economy	23800.00
0005435548626	26476	Economy	23800.00
0005433131818	10747	Economy	17100.00
0005435299879	10747	Economy	15600.00
0005435304254	10747	Economy	15600.00
0005435304252	10747	Economy	15600.00
0005433126957	10747	Economy	15600.00
0005433131823	10747	Economy	15600.00
0005433131803	10747	Economy	15600.00
0005435304241	10747	Economy	15600.00
0005435299867	10747	Economy	15600.00
0005433126962	10747	Economy	15600.00
0005435299884	10747	Economy	15600.00
0005435299903	10747	Economy	15600.00
0005433131822	10747	Economy	15600.00
0005435299877	10747	Economy	15600.00
0005435304240	10747	Economy	15600.00
0005435299902	10747	Economy	15600.00
0005435299880	10747	Economy	15600.00
0005433126983	29710	Economy	15600.00
0005433126984	29710	Economy	15600.00
0005433126982	29710	Economy	15600.00
0005434287937	2380	Economy	17200.00
0005434287936	2380	Economy	15700.00
0005434300253	2380	Economy	15700.00
0005434300251	2380	Economy	15700.00
0005433110332	2380	Economy	15700.00
0005434300257	2380	Economy	15700.00
0005433110371	2380	Economy	15700.00
0005434287938	2380	Economy	15700.00
0005433110308	2380	Economy	15700.00
0005433110368	2380	Economy	15700.00
0005434287935	2380	Economy	15700.00
0005434300259	2380	Economy	15700.00
0005434300258	2380	Economy	15700.00
0005434300255	2380	Economy	15700.00
0005434300254	2380	Economy	15700.00
0005433110333	2380	Economy	15700.00
0005433110284	2380	Economy	15700.00
0005434287939	2380	Economy	15700.00
0005434300252	2380	Economy	15700.00
0005434300256	2380	Economy	15700.00
0005433110339	2380	Economy	15700.00
0005434287816	26852	Economy	17200.00
0005434287851	26852	Economy	17200.00
0005434287840	26852	Economy	15700.00
0005434287696	26852	Economy	15700.00
0005434287697	26852	Economy	15700.00
0005434287821	26852	Economy	15700.00
0005434287789	26852	Economy	15700.00
0005434287808	26852	Economy	15700.00
0005434287817	26852	Economy	15700.00
0005434287813	26852	Economy	15700.00
0005434287807	26852	Economy	15700.00
0005434287770	26852	Economy	15700.00
0005434287862	26852	Economy	15700.00
0005434287852	26852	Economy	15700.00
0005434287841	26852	Economy	15700.00
0005434287820	26852	Economy	15700.00
0005434287861	26852	Economy	15700.00
0005435983716	25462	Economy	25000.00
0005435983714	25462	Economy	22800.00
0005435983713	25462	Economy	22800.00
0005435983712	25462	Economy	22800.00
0005435983715	25462	Economy	22800.00
0005434269147	25462	Economy	22800.00
0005435983717	25462	Economy	22800.00
0005434269155	25462	Economy	22800.00
0005435856331	25462	Economy	22800.00
0005434269151	25462	Economy	22800.00
0005434269146	25462	Economy	22800.00
0005434269143	25462	Economy	22800.00
0005435854071	26618	Economy	22800.00
0005434273136	26618	Economy	22800.00
0005435856298	26618	Economy	22800.00
0005435856299	26618	Economy	22800.00
0005435854074	26618	Economy	22800.00
0005434272238	26618	Economy	22800.00
0005435856260	26618	Economy	22800.00
0005435314922	6106	Economy	24600.00
0005435314929	6106	Economy	24600.00
0005434520506	6106	Economy	22300.00
0005435314926	6106	Economy	22300.00
0005434520510	6106	Economy	22300.00
0005435314924	6106	Economy	22300.00
0005435314901	6106	Economy	22300.00
0005434520507	6106	Economy	22300.00
0005435314904	6106	Economy	22300.00
0005435314923	6106	Economy	22300.00
0005434520514	6106	Economy	22300.00
0005435314925	6106	Economy	22300.00
0005435314928	6106	Economy	22300.00
0005434520511	6106	Economy	22300.00
0005434520508	6106	Economy	22300.00
0005434520502	6106	Economy	22300.00
0005435314900	6106	Economy	22300.00
0005434520504	6106	Economy	22300.00
0005435314918	6106	Economy	22300.00
0005434520503	6106	Economy	22300.00
0005434520509	6106	Economy	22300.00
0005435314907	6106	Economy	22300.00
0005435314903	6106	Economy	22300.00
0005434520505	6106	Economy	22300.00
0005434520512	6106	Economy	22300.00
0005435314912	6106	Economy	22300.00
0005434520513	6106	Economy	22300.00
0005435314921	6106	Economy	22300.00
0005435314910	6106	Economy	22300.00
0005435314889	6106	Economy	22300.00
0005435314911	6106	Economy	22300.00
0005435314930	6106	Economy	22300.00
0005435314908	6106	Economy	22300.00
0005433650977	27627	Business	89800.00
0005433650983	27627	Business	89800.00
0005433650975	27627	Business	89800.00
0005433650970	27627	Business	89800.00
0005433650956	27627	Business	89800.00
0005433650966	27627	Business	89800.00
0005433650965	27627	Business	89800.00
0005433651023	27627	Business	89800.00
0005433651024	27627	Business	89800.00
0005433650917	27627	Business	89800.00
0005433650919	27627	Business	89800.00
0005433650925	27627	Economy	29900.00
0005433650981	27627	Economy	29900.00
0005433650931	27627	Economy	29900.00
0005433650993	27627	Economy	29900.00
0005433651005	27627	Economy	29900.00
0005433650930	27627	Economy	29900.00
0005433650940	27627	Economy	29900.00
0005433650979	27627	Economy	29900.00
0005435263837	27627	Economy	32900.00
0005433650851	27627	Economy	32900.00
0005433651020	27627	Economy	32900.00
0005433650923	27627	Economy	29900.00
0005433650948	27627	Economy	29900.00
0005433650974	27627	Economy	29900.00
0005435263827	27627	Economy	29900.00
0005433651019	27627	Economy	29900.00
0005433650936	27627	Economy	29900.00
0005433650881	27627	Economy	29900.00
0005433650972	27627	Economy	29900.00
0005433650941	27627	Economy	29900.00
0005433650918	27627	Economy	29900.00
0005435263834	27627	Economy	29900.00
0005435263826	27627	Economy	29900.00
0005435263829	27627	Economy	29900.00
0005433651006	27627	Economy	29900.00
0005433650962	27627	Economy	29900.00
0005433650968	27627	Economy	29900.00
0005433650809	27627	Economy	29900.00
0005435263836	27627	Economy	29900.00
0005435263830	27627	Economy	29900.00
0005435263825	27627	Economy	29900.00
0005433651014	27627	Economy	29900.00
0005433651018	27627	Economy	29900.00
0005435263828	27627	Economy	29900.00
0005433650943	27627	Economy	29900.00
0005433651025	27627	Economy	29900.00
0005433650967	27627	Economy	29900.00
0005433650954	27627	Economy	29900.00
0005435263835	27627	Economy	29900.00
0005433650957	27627	Economy	29900.00
0005433650955	27627	Economy	29900.00
0005435263832	27627	Economy	29900.00
0005433650964	27627	Economy	29900.00
0005433650990	27627	Economy	29900.00
0005433650921	27627	Economy	29900.00
0005433650944	27627	Economy	29900.00
0005433650884	27627	Economy	29900.00
0005435263833	27627	Economy	29900.00
0005433650991	27627	Economy	29900.00
0005433650920	27627	Economy	29900.00
0005433650982	27627	Economy	29900.00
0005435263824	27627	Economy	29900.00
0005433650850	27627	Economy	29900.00
0005433650908	27627	Economy	29900.00
0005433650916	27627	Economy	29900.00
0005433650992	27627	Economy	29900.00
0005433650924	27627	Economy	29900.00
0005433650951	27627	Economy	29900.00
0005435263831	27627	Economy	29900.00
0005433650935	27627	Economy	29900.00
0005433869602	4754	Economy	19400.00
0005433869601	4754	Economy	17600.00
0005433869598	4754	Economy	17600.00
0005433869599	4754	Economy	17600.00
0005435860568	4754	Economy	17600.00
0005433869597	4754	Economy	17600.00
0005433869603	4754	Economy	17600.00
0005433869600	4754	Economy	17600.00
0005435860575	4754	Economy	17600.00
0005435860573	4754	Economy	17600.00
0005435860574	4754	Economy	17600.00
0005433869282	32622	Economy	19400.00
0005433869144	32622	Economy	19400.00
0005433869333	32622	Economy	19400.00
0005433869128	32622	Economy	19400.00
0005433869034	32622	Economy	17600.00
0005435860627	32622	Economy	17600.00
0005433869332	32622	Economy	17600.00
0005433869355	32622	Economy	17600.00
0005435860631	32622	Economy	17600.00
0005433869287	32622	Economy	17600.00
0005433869201	32622	Economy	17600.00
0005433869272	32622	Economy	17600.00
0005433869215	32622	Economy	17600.00
0005433869388	32622	Economy	17600.00
0005435860630	32622	Economy	17600.00
0005433869274	32622	Economy	17600.00
0005433869061	32622	Economy	17600.00
0005433869334	32622	Economy	17600.00
0005433869273	32622	Economy	17600.00
0005433869263	32622	Economy	17600.00
0005433869323	32622	Economy	17600.00
0005433869316	32622	Economy	17600.00
0005435860628	32622	Economy	17600.00
0005433869216	32622	Economy	17600.00
0005433869280	32622	Economy	17600.00
0005433869327	32622	Economy	17600.00
0005433869425	32622	Economy	17600.00
0005433869328	32622	Economy	17600.00
0005433869360	32622	Economy	17600.00
0005433869200	32622	Economy	17600.00
0005435860629	32622	Economy	17600.00
0005433869284	32622	Economy	17600.00
0005433869454	32622	Economy	17600.00
0005433869335	32622	Economy	17600.00
0005433869279	32622	Economy	17600.00
0005433869313	32622	Economy	17600.00
0005433869325	32622	Economy	17600.00
0005433869275	32622	Economy	17600.00
0005433869329	32622	Economy	17600.00
0005433869306	32622	Economy	17600.00
0005433869315	32622	Economy	17600.00
0005433869361	32622	Economy	17600.00
0005433869415	32622	Economy	17600.00
0005433869416	32622	Economy	17600.00
0005434663803	3401	Economy	22600.00
0005435911639	3401	Economy	22600.00
0005434663804	3401	Economy	22600.00
0005434663806	3401	Economy	22600.00
0005434663805	3401	Economy	22600.00
0005435911640	3401	Economy	22600.00
0005435911638	3401	Economy	22600.00
0005434663752	12454	Economy	24800.00
0005435911661	12454	Economy	24800.00
0005434663755	12454	Economy	22600.00
0005434663698	12454	Economy	22600.00
0005434663696	12454	Economy	22600.00
0005435911664	12454	Economy	22600.00
0005434663705	12454	Economy	22600.00
0005434663757	12454	Economy	22600.00
0005434663686	12454	Economy	22600.00
0005435911663	12454	Economy	22600.00
0005434663703	12454	Economy	22600.00
0005434663713	12454	Economy	22600.00
0005434663697	12454	Economy	22600.00
0005434663733	12454	Economy	22600.00
0005434663695	12454	Economy	22600.00
0005435911662	12454	Economy	22600.00
0005434663745	12454	Economy	22600.00
0005434663699	12454	Economy	22600.00
0005434663687	12454	Economy	22600.00
0005434663739	12454	Economy	22600.00
0005433869328	14494	Economy	18500.00
0005433869425	14494	Economy	18500.00
0005435860628	14494	Economy	16800.00
0005433869263	14494	Economy	16800.00
0005433869275	14494	Economy	16800.00
0005433869280	14494	Economy	16800.00
0005433869273	14494	Economy	16800.00
0005433869313	14494	Economy	16800.00
0005433869332	14494	Economy	16800.00
0005433869327	14494	Economy	16800.00
0005433869282	14494	Economy	16800.00
0005435860627	14494	Economy	16800.00
0005433869415	14494	Economy	16800.00
0005433869361	14494	Economy	16800.00
0005433869128	14494	Economy	16800.00
0005435860631	14494	Economy	16800.00
0005433869284	14494	Economy	16800.00
0005433869274	14494	Economy	16800.00
0005433869416	14494	Economy	16800.00
0005433869201	14494	Economy	16800.00
0005433869323	14494	Economy	16800.00
0005433869325	14494	Economy	16800.00
0005433869034	14494	Economy	16800.00
0005435860629	14494	Economy	16800.00
0005433869215	14494	Economy	16800.00
0005433869335	14494	Economy	16800.00
0005433869287	14494	Economy	16800.00
0005433869360	14494	Economy	16800.00
0005433869334	14494	Economy	16800.00
0005433869272	14494	Economy	16800.00
0005435860630	14494	Economy	16800.00
0005433869279	14494	Economy	16800.00
0005433869454	14494	Economy	16800.00
0005433869315	14494	Economy	16800.00
0005433869329	14494	Economy	16800.00
0005433869355	14494	Economy	16800.00
0005433869144	14494	Economy	16800.00
0005433869388	14494	Economy	16800.00
0005433869333	14494	Economy	16800.00
0005433869200	14494	Economy	16800.00
0005433869316	14494	Economy	16800.00
0005433869061	14494	Economy	16800.00
0005433869306	14494	Economy	16800.00
0005433869216	14494	Economy	16800.00
0005435860586	32647	Economy	18500.00
0005435860580	32647	Economy	16800.00
0005433869593	32647	Economy	16800.00
0005433869596	32647	Economy	16800.00
0005433869590	32647	Economy	16800.00
0005433869595	32647	Economy	16800.00
0005433869589	32647	Economy	16800.00
0005435860559	32647	Economy	16800.00
0005435860558	32647	Economy	16800.00
0005435860555	32647	Economy	16800.00
0005433869594	32647	Economy	16800.00
0005435860576	32647	Economy	16800.00
0005433869591	32647	Economy	16800.00
0005433869588	32647	Economy	16800.00
0005435860560	32647	Economy	16800.00
0005433869592	32647	Economy	16800.00
0005435860582	32647	Economy	16800.00
0005435860581	32647	Economy	16800.00
0005432800201	12099	Economy	4900.00
0005432800058	12099	Economy	4900.00
0005432799941	12099	Economy	4900.00
0005432800212	12099	Economy	4900.00
0005432800019	12099	Economy	4400.00
0005432800057	12099	Economy	4400.00
0005432800064	12099	Economy	4400.00
0005432800155	12099	Economy	4400.00
0005432800126	12099	Economy	4400.00
0005432800105	12099	Economy	4400.00
0005432799942	12099	Economy	4400.00
0005432800124	12099	Economy	4400.00
0005432800122	12099	Economy	4400.00
0005432800184	12099	Economy	4400.00
0005432800134	12099	Economy	4400.00
0005432800143	12099	Economy	4400.00
0005432800156	12099	Economy	4400.00
0005432800074	12099	Economy	4400.00
0005432800132	12099	Economy	4400.00
0005432800040	12099	Economy	4400.00
0005432800142	12099	Economy	4400.00
0005432800091	12099	Economy	4400.00
0005432800083	12099	Economy	4400.00
0005432800090	12099	Economy	4400.00
0005432800063	12099	Economy	4400.00
0005432800158	12099	Economy	4400.00
0005432800051	12099	Economy	4400.00
0005432800133	12099	Economy	4400.00
0005432800059	12099	Economy	4400.00
0005432800082	12099	Economy	4400.00
0005432799895	12099	Economy	4400.00
0005432800211	12099	Economy	4400.00
0005432800123	12099	Economy	4400.00
0005432800106	12099	Economy	4400.00
0005432800081	12099	Economy	4400.00
0005432800041	12099	Economy	4400.00
0005432800264	14821	Economy	4400.00
0005432800273	14821	Economy	4400.00
0005432800265	14821	Economy	4400.00
0005432800271	14821	Economy	4400.00
0005432800272	14821	Economy	4400.00
0005432800267	14821	Economy	4400.00
0005432800269	14821	Economy	4400.00
0005432800270	14821	Economy	4400.00
0005432800268	14821	Economy	4400.00
0005432800266	14821	Economy	4400.00
0005435293586	7041	Business	49100.00
0005435311408	7041	Business	49100.00
0005434409609	7041	Business	49100.00
0005434409605	7041	Business	49100.00
0005435311437	7041	Business	49100.00
0005432108323	7041	Business	49100.00
0005435311385	7041	Business	49100.00
0005435311301	7041	Economy	16400.00
0005434300222	7041	Economy	16400.00
0005435311350	7041	Economy	16400.00
0005434409598	7041	Economy	16400.00
0005435293596	7041	Economy	16400.00
0005435311384	7041	Economy	16400.00
0005434300223	7041	Economy	16400.00
0005435293558	7041	Economy	16400.00
0005435293565	7041	Economy	16400.00
0005435311375	7041	Economy	16400.00
0005435311363	7041	Economy	16400.00
0005435311343	7041	Economy	16400.00
0005434300224	7041	Economy	16400.00
0005434409602	7041	Economy	16400.00
0005435311347	7041	Economy	16400.00
0005434409603	7041	Economy	16400.00
0005434409606	7041	Economy	16400.00
0005434409610	7041	Economy	16400.00
0005435311379	7041	Economy	16400.00
0005435311329	7041	Economy	16400.00
0005435311313	7041	Economy	18000.00
0005434409600	7041	Economy	18000.00
0005435293587	7041	Economy	16400.00
0005435311431	7041	Economy	16400.00
0005435311395	7041	Economy	16400.00
0005435311414	7041	Economy	16400.00
0005435311294	7041	Economy	16400.00
0005435293524	7041	Economy	16400.00
0005435311348	7041	Economy	16400.00
0005432108324	7041	Economy	16400.00
0005434409608	7041	Economy	16400.00
0005435311415	7041	Economy	16400.00
0005435311364	7041	Economy	16400.00
0005435311349	7041	Economy	16400.00
0005434409607	7041	Economy	16400.00
0005434409601	7041	Economy	16400.00
0005435311325	7041	Economy	16400.00
0005435311351	7041	Economy	16400.00
0005435311396	7041	Economy	16400.00
0005435311324	7041	Economy	16400.00
0005435293559	7041	Economy	16400.00
0005434300221	7041	Economy	16400.00
0005434409604	7041	Economy	16400.00
0005435311404	7041	Economy	16400.00
0005435311305	7041	Economy	16400.00
0005435311390	7041	Economy	16400.00
0005434409599	7041	Economy	16400.00
0005435311394	7041	Economy	16400.00
0005434409210	26919	Business	49100.00
0005434408933	26919	Business	49100.00
0005434409104	26919	Business	49100.00
0005434409080	26919	Business	49100.00
0005434409274	26919	Business	49100.00
0005434409250	26919	Business	49100.00
0005434300174	26919	Business	49100.00
0005435311548	26919	Business	49100.00
0005434300140	26919	Business	49100.00
0005434409132	26919	Business	49100.00
0005434409000	26919	Business	49100.00
0005434409067	26919	Business	49100.00
0005434409072	26919	Economy	16400.00
0005434409136	26919	Economy	16400.00
0005434409095	26919	Economy	16400.00
0005434300186	26919	Economy	16400.00
0005434409105	26919	Economy	16400.00
0005434408913	26919	Economy	16400.00
0005434409029	26919	Economy	16400.00
0005434409047	26919	Economy	16400.00
0005434409115	26919	Economy	16400.00
0005434409238	26919	Economy	16400.00
0005435311543	26919	Economy	16400.00
0005434300141	26919	Economy	16400.00
0005434409378	26919	Economy	16400.00
0005435311546	26919	Economy	16400.00
0005434409271	26919	Economy	16400.00
0005434300098	26919	Economy	16400.00
0005434409293	26919	Economy	16400.00
0005434409363	26919	Economy	16400.00
0005435311547	26919	Economy	16400.00
0005435311545	26919	Economy	16400.00
0005434300139	26919	Economy	16400.00
0005434300128	26919	Economy	16400.00
0005434409049	26919	Economy	16400.00
0005434409048	26919	Economy	16400.00
0005434300142	26919	Economy	16400.00
0005435293624	26919	Economy	16400.00
0005434409173	26919	Economy	16400.00
0005434409225	26919	Economy	16400.00
0005434409081	26919	Economy	16400.00
0005434409168	26919	Economy	16400.00
0005434409001	26919	Economy	16400.00
0005434409073	26919	Economy	16400.00
0005434408972	26919	Economy	16400.00
0005434409216	26919	Economy	16400.00
0005434409106	26919	Economy	16400.00
0005434409139	26919	Economy	16400.00
0005435311539	26919	Economy	18000.00
0005434300162	26919	Economy	18000.00
0005434409281	26919	Economy	18000.00
0005435311544	26919	Economy	18000.00
0005434409325	26919	Economy	18000.00
0005435293628	26919	Economy	18000.00
0005434409244	26919	Economy	16400.00
0005434409204	26919	Economy	16400.00
0005434409023	26919	Economy	16400.00
0005434409343	26919	Economy	16400.00
0005434409372	26919	Economy	16400.00
0005434409466	26919	Economy	16400.00
0005434409310	26919	Economy	16400.00
0005434409207	26919	Economy	16400.00
0005435311541	26919	Economy	16400.00
0005434300063	26919	Economy	16400.00
0005435293627	26919	Economy	16400.00
0005435311540	26919	Economy	16400.00
0005434409257	26919	Economy	16400.00
0005434409435	26919	Economy	16400.00
0005435293625	26919	Economy	16400.00
0005434409050	26919	Economy	16400.00
0005434408934	26919	Economy	16400.00
0005434409401	26919	Economy	16400.00
0005434408885	26919	Economy	16400.00
0005434409211	26919	Economy	16400.00
0005434300121	26919	Economy	16400.00
0005434409272	26919	Economy	16400.00
0005434409128	26919	Economy	16400.00
0005434409275	26919	Economy	16400.00
0005434409024	26919	Economy	16400.00
0005434409235	26919	Economy	16400.00
0005434300192	26919	Economy	16400.00
0005435311538	26919	Economy	16400.00
0005434300095	26919	Economy	16400.00
0005434409114	26919	Economy	16400.00
0005434409066	26919	Economy	16400.00
0005435311549	26919	Economy	16400.00
0005434409113	26919	Economy	16400.00
0005434409251	26919	Economy	16400.00
0005434409084	26919	Economy	16400.00
0005434409291	26919	Economy	16400.00
0005434409360	26919	Economy	16400.00
0005434409215	26919	Economy	16400.00
0005432058497	26919	Economy	16400.00
0005434409030	26919	Economy	16400.00
0005434409330	26919	Economy	16400.00
0005434409203	26919	Economy	16400.00
0005434408946	26919	Economy	16400.00
0005434409031	26919	Economy	16400.00
0005434409313	26919	Economy	16400.00
0005434409344	26919	Economy	16400.00
0005434409223	26919	Economy	16400.00
0005434300161	26919	Economy	16400.00
0005434409206	26919	Economy	16400.00
0005434300064	26919	Economy	16400.00
0005434409456	26919	Economy	16400.00
0005434409455	26919	Economy	16400.00
0005432058496	26919	Economy	16400.00
0005435311542	26919	Economy	16400.00
0005435293626	26919	Economy	16400.00
0005434409312	26919	Economy	16400.00
0005434409051	26919	Economy	16400.00
0005435293623	26919	Economy	16400.00
0005434409280	26919	Economy	16400.00
0005434409434	26919	Economy	16400.00
0005434300185	26919	Economy	16400.00
0005434409292	26919	Economy	16400.00
0005434409174	26919	Economy	16400.00
0005432605496	6478	Economy	16500.00
0005435220508	6478	Economy	16500.00
0005435218129	6478	Economy	16500.00
0005432605494	6478	Economy	15000.00
0005432605503	6478	Economy	15000.00
0005435312902	6478	Economy	15000.00
0005432605495	6478	Economy	15000.00
0005435220506	6478	Economy	15000.00
0005432605498	6478	Economy	15000.00
0005435218133	6478	Economy	15000.00
0005435220510	6478	Economy	15000.00
0005432605493	6478	Economy	15000.00
0005435220507	6478	Economy	15000.00
0005432605491	6478	Economy	15000.00
0005432605500	6478	Economy	15000.00
0005432605499	6478	Economy	15000.00
0005432605497	6478	Economy	15000.00
0005432605492	6478	Economy	15000.00
0005432605502	6478	Economy	15000.00
0005432605501	6478	Economy	15000.00
0005432605232	21398	Economy	16500.00
0005432605201	21398	Economy	16500.00
0005432605284	21398	Economy	16500.00
0005432605162	21398	Economy	16500.00
0005432605246	21398	Economy	15000.00
0005435312911	21398	Economy	15000.00
0005432605270	21398	Economy	15000.00
0005432605163	21398	Economy	15000.00
0005434512233	21398	Economy	15000.00
0005432605280	21398	Economy	15000.00
0005432605200	21398	Economy	15000.00
0005434512219	21398	Economy	15000.00
0005432605253	21398	Economy	15000.00
0005432605032	21398	Economy	15000.00
0005432605231	21398	Economy	15000.00
0005432605164	21398	Economy	15000.00
0005434512225	21398	Economy	15000.00
0005432605139	21398	Economy	15000.00
0005432605293	21398	Economy	15000.00
0005432605314	21398	Economy	15000.00
0005432605268	21398	Economy	15000.00
0005434512203	21398	Economy	15000.00
0005432605292	21398	Economy	15000.00
0005432605256	21398	Economy	15000.00
0005434512202	21398	Economy	15000.00
0005432605170	21398	Economy	15000.00
0005432605137	21398	Economy	15000.00
0005432605120	21398	Economy	15000.00
0005432605147	21398	Economy	15000.00
0005432605321	21398	Economy	15000.00
0005432605252	21398	Economy	15000.00
0005435221556	21398	Economy	15000.00
0005432605271	21398	Economy	15000.00
0005434512220	21398	Economy	15000.00
0005432605290	21398	Economy	15000.00
0005435312912	21398	Economy	15000.00
0005432605258	21398	Economy	15000.00
0005432605219	21398	Economy	15000.00
0005432605291	21398	Economy	15000.00
0005434908437	14998	Business	18900.00
0005434908342	14998	Business	18900.00
0005434908232	14998	Business	18900.00
0005434908329	14998	Business	18900.00
0005434908231	14998	Business	18900.00
0005434908550	14998	Business	18900.00
0005433252380	14998	Business	18900.00
0005433252372	14998	Business	18900.00
0005434908548	14998	Economy	6300.00
0005433252381	14998	Economy	6300.00
0005434908345	14998	Economy	6300.00
0005434908146	14998	Economy	6300.00
0005434908177	14998	Economy	6300.00
0005434908318	14998	Economy	6900.00
0005434908560	14998	Economy	6900.00
0005433252374	14998	Economy	6900.00
0005434908395	14998	Economy	6900.00
0005434908401	14998	Economy	6300.00
0005434908479	14998	Economy	6300.00
0005434908473	14998	Economy	6300.00
0005434908535	14998	Economy	6300.00
0005433252377	14998	Economy	6300.00
0005434908419	14998	Economy	6300.00
0005434908322	14998	Economy	6300.00
0005434908527	14998	Economy	6300.00
0005434908598	14998	Economy	6300.00
0005434908540	14998	Economy	6300.00
0005434908145	14998	Economy	6300.00
0005433252373	14998	Economy	6300.00
0005434908528	14998	Economy	6300.00
0005434908516	14998	Economy	6300.00
0005434908542	14998	Economy	6300.00
0005434908559	14998	Economy	6300.00
0005434908415	14998	Economy	6300.00
0005434908328	14998	Economy	6300.00
0005434908358	14998	Economy	6300.00
0005434908543	14998	Economy	6300.00
0005433252375	14998	Economy	6300.00
0005434908445	14998	Economy	6300.00
0005434908218	14998	Economy	6300.00
0005434908478	14998	Economy	6300.00
0005433252379	14998	Economy	6300.00
0005434908407	14998	Economy	6300.00
0005434908526	14998	Economy	6300.00
0005434908357	14998	Economy	6300.00
0005433252376	14998	Economy	6300.00
0005434908435	14998	Economy	6300.00
0005434908595	14998	Economy	6300.00
0005434908549	14998	Economy	6300.00
0005434908300	14998	Economy	6300.00
0005433252382	14998	Economy	6300.00
0005434908374	14998	Economy	6300.00
0005433252378	14998	Economy	6300.00
0005434908547	14998	Economy	6300.00
0005434908444	14998	Economy	6300.00
0005433252142	25862	Business	18900.00
0005434908867	25862	Business	18900.00
0005434908869	25862	Business	18900.00
0005434908873	25862	Business	18900.00
0005434908865	25862	Economy	6300.00
0005434908859	25862	Economy	6300.00
0005434908861	25862	Economy	6300.00
0005434908868	25862	Economy	6300.00
0005434908871	25862	Economy	6300.00
0005433252150	25862	Economy	6300.00
0005433252080	25862	Economy	6300.00
0005434908866	25862	Economy	6900.00
0005433252215	25862	Economy	6900.00
0005433252252	25862	Economy	6900.00
0005434908857	25862	Economy	6900.00
0005433252066	25862	Economy	6300.00
0005433252216	25862	Economy	6300.00
0005433252281	25862	Economy	6300.00
0005433252189	25862	Economy	6300.00
0005433252271	25862	Economy	6300.00
0005433252149	25862	Economy	6300.00
0005434908860	25862	Economy	6300.00
0005433252191	25862	Economy	6300.00
0005433252292	25862	Economy	6300.00
0005434908855	25862	Economy	6300.00
0005433252173	25862	Economy	6300.00
0005434908863	25862	Economy	6300.00
0005434908872	25862	Economy	6300.00
0005434908858	25862	Economy	6300.00
0005433252148	25862	Economy	6300.00
0005433252208	25862	Economy	6300.00
0005433252134	25862	Economy	6300.00
0005433252287	25862	Economy	6300.00
0005433252209	25862	Economy	6300.00
0005434908856	25862	Economy	6300.00
0005433252062	25862	Economy	6300.00
0005433252226	25862	Economy	6300.00
0005433252160	25862	Economy	6300.00
0005433252272	25862	Economy	6300.00
0005433252221	25862	Economy	6300.00
0005433252137	25862	Economy	6300.00
0005434908864	25862	Economy	6300.00
0005434908862	25862	Economy	6300.00
0005434908870	25862	Economy	6300.00
0005433252061	25862	Economy	6300.00
0005433252220	25862	Economy	6300.00
0005434173644	9147	Economy	18100.00
0005434173636	9147	Economy	18100.00
0005434173654	9147	Economy	18100.00
0005434173655	9147	Economy	18100.00
0005434173637	9147	Economy	18100.00
0005434173643	9147	Economy	18100.00
0005433009965	14205	Business	52300.00
0005433810633	14205	Business	52300.00
0005433810658	14205	Business	52300.00
0005433810644	14205	Economy	17400.00
0005433009968	14205	Economy	17400.00
0005433009962	14205	Economy	17400.00
0005433009967	14205	Economy	17400.00
0005433009961	14205	Economy	17400.00
0005433810661	14205	Economy	17400.00
0005433009963	14205	Economy	17400.00
0005433009959	14205	Economy	17400.00
0005433810634	14205	Economy	17400.00
0005433009960	14205	Economy	17400.00
0005433009958	14205	Economy	17400.00
0005433009966	14205	Economy	17400.00
0005433810668	14205	Economy	17400.00
0005433810669	14205	Economy	17400.00
0005433009964	14205	Economy	17400.00
0005433810662	14205	Economy	17400.00
0005434173649	22859	Business	52300.00
0005434173639	22859	Business	52300.00
0005433815584	22859	Business	52300.00
0005433009534	22859	Business	52300.00
0005433009502	22859	Business	52300.00
0005433815578	22859	Business	52300.00
0005433009652	22859	Business	52300.00
0005433009475	22859	Business	52300.00
0005433009705	22859	Business	52300.00
0005433009575	22859	Economy	17400.00
0005433009706	22859	Economy	17400.00
0005433810766	22859	Economy	17400.00
0005433009528	22859	Economy	17400.00
0005433009562	22859	Economy	17400.00
0005433810763	22859	Economy	17400.00
0005433810761	22859	Economy	17400.00
0005433009511	22859	Economy	19200.00
0005434173640	22859	Economy	19200.00
0005433009715	22859	Economy	17400.00
0005433810765	22859	Economy	19200.00
0005433009521	22859	Economy	17400.00
0005433009621	22859	Economy	17400.00
0005433810769	22859	Economy	17400.00
0005433009506	22859	Economy	17400.00
0005433009716	22859	Economy	17400.00
0005433009535	22859	Economy	17400.00
0005433009661	22859	Economy	17400.00
0005433009544	22859	Economy	17400.00
0005433009476	22859	Economy	17400.00
0005433009525	22859	Economy	17400.00
0005433009796	22859	Economy	17400.00
0005433009612	22859	Economy	17400.00
0005433810768	22859	Economy	17400.00
0005433009630	22859	Economy	17400.00
0005433009576	22859	Economy	17400.00
0005433810764	22859	Economy	17400.00
0005434173641	22859	Economy	17400.00
0005433009604	22859	Economy	17400.00
0005433009477	22859	Economy	17400.00
0005433009537	22859	Economy	17400.00
0005433009533	22859	Economy	17400.00
0005433009771	22859	Economy	17400.00
0005433009543	22859	Economy	17400.00
0005433009659	22859	Economy	17400.00
0005433009507	22859	Economy	17400.00
0005433009672	22859	Economy	17400.00
0005433009671	22859	Economy	17400.00
0005433009561	22859	Economy	17400.00
0005433009656	22859	Economy	17400.00
0005433009714	22859	Economy	17400.00
0005433009577	22859	Economy	17400.00
0005433009743	22859	Economy	17400.00
0005433810767	22859	Economy	17400.00
0005433810762	22859	Economy	17400.00
0005433009589	22859	Economy	17400.00
0005433009708	22859	Economy	17400.00
0005433009733	22859	Economy	17400.00
0005433009536	22859	Economy	17400.00
0005433009629	22859	Economy	17400.00
0005433009707	22859	Economy	17400.00
0005433009723	22859	Economy	17400.00
0005433009759	22859	Economy	17400.00
0005433009758	22859	Economy	17400.00
0005434173638	22859	Economy	17400.00
0005433009503	22859	Economy	17400.00
0005433009638	22859	Economy	17400.00
0005434926579	14910	Business	22900.00
0005434926505	14910	Business	22900.00
0005434926547	14910	Business	22900.00
0005434926526	14910	Business	22900.00
0005434926538	14910	Business	22900.00
0005434926599	14910	Economy	7600.00
0005434926604	14910	Economy	7600.00
0005434926527	14910	Economy	7600.00
0005434926566	14910	Economy	8400.00
0005434926442	14910	Economy	7600.00
0005434926443	14910	Economy	7600.00
0005434926563	14910	Economy	7600.00
0005434926412	14910	Economy	7600.00
0005434926481	14910	Economy	7600.00
0005434926503	14910	Economy	7600.00
0005434926466	14910	Economy	7600.00
0005434926528	14910	Economy	7600.00
0005434926562	14910	Economy	7600.00
0005434926549	14910	Economy	7600.00
0005434926550	14910	Economy	7600.00
0005434926514	14910	Economy	7600.00
0005434926512	14910	Economy	7600.00
0005434926591	14910	Economy	7600.00
0005434926467	14910	Economy	7600.00
0005434926488	14910	Economy	7600.00
0005434926472	14910	Economy	7600.00
0005434926341	14910	Economy	7600.00
0005434926603	14910	Economy	7600.00
0005434926261	14910	Economy	7600.00
0005434926513	14910	Economy	7600.00
0005434926606	14910	Economy	7600.00
0005434926487	14910	Economy	7600.00
0005434926543	14910	Economy	7600.00
0005434926378	14910	Economy	7600.00
0005434926575	14910	Economy	7600.00
0005434926356	14910	Economy	7600.00
0005434926600	14910	Economy	7600.00
0005434926377	14910	Economy	7600.00
0005434926598	14910	Economy	7600.00
0005434926842	20532	Business	22900.00
0005434926839	20532	Business	22900.00
0005434926823	20532	Economy	7600.00
0005434926841	20532	Economy	7600.00
0005434926819	20532	Economy	8400.00
0005434926824	20532	Economy	8400.00
0005434926820	20532	Economy	7600.00
0005434926818	20532	Economy	7600.00
0005434926825	20532	Economy	7600.00
0005434926831	20532	Economy	7600.00
0005434926826	20532	Economy	7600.00
0005434926828	20532	Economy	7600.00
0005434926830	20532	Economy	7600.00
0005434926838	20532	Economy	7600.00
0005434926837	20532	Economy	7600.00
0005434926832	20532	Economy	7600.00
0005434926836	20532	Economy	7600.00
0005434926822	20532	Economy	7600.00
0005434926829	20532	Economy	7600.00
0005434926834	20532	Economy	7600.00
0005434926833	20532	Economy	7600.00
0005434926827	20532	Economy	7600.00
0005434926835	20532	Economy	7600.00
0005434926840	20532	Economy	7600.00
0005434926821	20532	Economy	7600.00
0005435999696	15849	Economy	8900.00
0005435999626	15849	Economy	8900.00
0005435488475	15849	Economy	8900.00
0005435999708	15849	Economy	8100.00
0005435999712	15849	Economy	8100.00
0005435999694	15849	Economy	8100.00
0005435999690	15849	Economy	8100.00
0005435999714	15849	Economy	8100.00
0005435999534	15849	Economy	8100.00
0005435999533	15849	Economy	8100.00
0005435999695	15849	Economy	8100.00
0005435999650	15849	Economy	8100.00
0005435488473	15849	Economy	8100.00
0005435999698	15849	Economy	8100.00
0005435999697	15849	Economy	8100.00
0005435999707	15849	Economy	8100.00
0005435488477	15849	Economy	8100.00
0005435999703	15849	Economy	8100.00
0005435999720	15849	Economy	8100.00
0005435999719	15849	Economy	8100.00
0005435999652	15849	Economy	8100.00
0005435999622	15849	Economy	8100.00
0005435999718	15849	Economy	8100.00
0005435999651	15849	Economy	8100.00
0005435488474	15849	Economy	8100.00
0005435999691	15849	Economy	8100.00
0005435488476	15849	Economy	8100.00
0005435999686	15849	Economy	8100.00
0005435999656	15849	Economy	8100.00
0005435488247	19667	Economy	8900.00
0005435999841	19667	Economy	8900.00
0005435488297	19667	Economy	8900.00
0005435999842	19667	Economy	8900.00
0005435488312	19667	Economy	8100.00
0005435488409	19667	Economy	8100.00
0005435488390	19667	Economy	8100.00
0005435488178	19667	Economy	8100.00
0005435488311	19667	Economy	8100.00
0005435999843	19667	Economy	8100.00
0005435488265	19667	Economy	8100.00
0005435488310	19667	Economy	8100.00
0005435488352	19667	Economy	8100.00
0005435999848	19667	Economy	8100.00
0005435488298	19667	Economy	8100.00
0005435488233	19667	Economy	8100.00
0005435999849	19667	Economy	8100.00
0005435488179	19667	Economy	8100.00
0005435488353	19667	Economy	8100.00
0005435488302	19667	Economy	8100.00
0005435999850	19667	Economy	8100.00
0005435488342	19667	Economy	8100.00
0005435488318	19667	Economy	8100.00
0005435488344	19667	Economy	8100.00
0005435488317	19667	Economy	8100.00
0005435488285	19667	Economy	8100.00
0005435999846	19667	Economy	8100.00
0005435488341	19667	Economy	8100.00
0005435488343	19667	Economy	8100.00
0005435999845	19667	Economy	8100.00
0005435999847	19667	Economy	8100.00
0005435999844	19667	Economy	8100.00
0005432537114	5989	Business	199300.00
0005432659770	5989	Business	199300.00
0005435473190	5989	Business	199300.00
0005435473165	5989	Business	199300.00
0005432659769	5989	Business	199300.00
0005435473153	5989	Business	199300.00
0005435473154	5989	Business	199300.00
0005435473174	5989	Business	199300.00
0005432142346	5989	Economy	66400.00
0005432537105	5989	Economy	66400.00
0005435473210	5989	Economy	66400.00
0005435473199	5989	Economy	66400.00
0005435473152	5989	Economy	66400.00
0005435473164	5989	Economy	66400.00
0005435473204	5989	Economy	66400.00
0005435473205	5989	Economy	66400.00
0005435473191	5989	Economy	66400.00
0005432537104	5989	Economy	66400.00
0005435473206	5989	Economy	66400.00
0005435473157	5989	Economy	66400.00
0005432537103	5989	Economy	66400.00
0005435473225	5989	Economy	66400.00
0005435840274	5989	Economy	66400.00
0005432142345	5989	Economy	66400.00
0005435473211	5989	Economy	66400.00
0005435840187	18051	Business	199300.00
0005435840077	18051	Business	199300.00
0005435840125	18051	Business	199300.00
0005435840166	18051	Business	199300.00
0005435840191	18051	Business	199300.00
0005435840124	18051	Economy	66400.00
0005432660863	18051	Economy	66400.00
0005435840075	18051	Economy	73100.00
0005435473295	18051	Economy	73100.00
0005435840089	18051	Economy	66400.00
0005435840085	18051	Economy	66400.00
0005435840101	18051	Economy	66400.00
0005435840076	18051	Economy	66400.00
0005432537123	18051	Economy	66400.00
0005435840096	18051	Economy	66400.00
0005432667498	18051	Economy	66400.00
0005435473294	18051	Economy	66400.00
0005435473290	18051	Economy	66400.00
0005435840065	18051	Economy	66400.00
0005435840093	18051	Economy	66400.00
0005432664175	18051	Economy	66400.00
0005435840189	18051	Economy	66400.00
0005432660862	18051	Economy	66400.00
0005432667499	18051	Economy	66400.00
0005432660867	18051	Economy	66400.00
0005435473292	18051	Economy	66400.00
0005435840207	18051	Economy	66400.00
0005435840073	18051	Economy	66400.00
0005435840208	18051	Economy	66400.00
0005432660864	18051	Economy	66400.00
0005432664185	18051	Economy	66400.00
0005435840060	18051	Economy	66400.00
0005435840087	18051	Economy	66400.00
0005432664186	18051	Economy	66400.00
0005435840137	18051	Economy	66400.00
0005435840190	18051	Economy	66400.00
0005435840111	18051	Economy	66400.00
0005435840088	18051	Economy	66400.00
0005435473293	18051	Economy	66400.00
0005435473291	18051	Economy	66400.00
0005435617245	18051	Economy	66400.00
0005435839957	18051	Economy	66400.00
0005435840183	18051	Economy	66400.00
0005435840115	18051	Economy	66400.00
0005432660865	18051	Economy	66400.00
0005435840074	18051	Economy	66400.00
0005435840112	18051	Economy	66400.00
0005435840209	18051	Economy	66400.00
0005435104351	23002	Business	15700.00
0005435104349	23002	Business	15700.00
0005433286108	23002	Business	15700.00
0005433285947	23002	Business	15700.00
0005433286169	23002	Business	15700.00
0005435104345	23002	Economy	5200.00
0005433285910	23002	Economy	5200.00
0005433286007	23002	Economy	5200.00
0005433286011	23002	Economy	5200.00
0005435104358	23002	Economy	5200.00
0005433285970	23002	Economy	5200.00
0005435097504	23002	Economy	5200.00
0005433285923	23002	Economy	5200.00
0005433285966	23002	Economy	5200.00
0005433285974	23002	Economy	5200.00
0005435104359	23002	Economy	5200.00
0005435104357	23002	Economy	5200.00
0005435104350	23002	Economy	5200.00
0005435104363	23002	Economy	5200.00
0005433285948	23002	Economy	5200.00
0005435104344	23002	Economy	5200.00
0005433286129	23002	Economy	5200.00
0005433286121	23002	Economy	5700.00
0005435097505	23002	Economy	5700.00
0005435104348	23002	Economy	5700.00
0005435104343	23002	Economy	5200.00
0005433285909	23002	Economy	5200.00
0005435104347	23002	Economy	5200.00
0005433286013	23002	Economy	5200.00
0005435097506	23002	Economy	5200.00
0005433286045	23002	Economy	5200.00
0005435104361	23002	Economy	5200.00
0005435104353	23002	Economy	5200.00
0005435104354	23002	Economy	5200.00
0005433285998	23002	Economy	5200.00
0005435104352	23002	Economy	5200.00
0005433286170	23002	Economy	5200.00
0005433286126	23002	Economy	5200.00
0005435097507	23002	Economy	5200.00
0005435104364	23002	Economy	5200.00
0005433286079	23002	Economy	5200.00
0005433286012	23002	Economy	5200.00
0005433286056	23002	Economy	5200.00
0005435104360	23002	Economy	5200.00
0005433285971	23002	Economy	5200.00
0005435104362	23002	Economy	5200.00
0005433286070	23002	Economy	5200.00
0005433286006	23002	Economy	5200.00
0005433286125	23002	Economy	5200.00
0005435104346	23002	Economy	5200.00
0005433285922	23002	Economy	5200.00
0005435104356	23002	Economy	5200.00
0005435104355	23002	Economy	5200.00
0005433286217	32047	Business	15700.00
0005435104083	32047	Business	15700.00
0005435104109	32047	Business	15700.00
0005435104110	32047	Economy	5200.00
0005435104129	32047	Economy	5200.00
0005435104121	32047	Economy	5200.00
0005433286215	32047	Economy	5200.00
0005435104144	32047	Economy	5200.00
0005435104145	32047	Economy	5200.00
0005435104131	32047	Economy	5200.00
0005435104139	32047	Economy	5200.00
0005435104128	32047	Economy	5200.00
0005433286221	32047	Economy	5200.00
0005433286222	32047	Economy	5700.00
0005433286214	32047	Economy	5200.00
0005435104130	32047	Economy	5200.00
0005433286216	32047	Economy	5200.00
0005433286223	32047	Economy	5200.00
0005435104120	32047	Economy	5200.00
0005435104112	32047	Economy	5200.00
0005433286219	32047	Economy	5200.00
0005433286220	32047	Economy	5200.00
0005435104119	32047	Economy	5200.00
0005433286218	32047	Economy	5200.00
0005435104087	32047	Economy	5200.00
0005435104078	32047	Economy	5200.00
0005435104134	32047	Economy	5200.00
0005435104111	32047	Economy	5200.00
0005435104079	32047	Economy	5200.00
0005432531608	30635	Business	42100.00
0005434069098	30635	Business	42100.00
0005432531065	30635	Business	42100.00
0005434069052	30635	Business	42100.00
0005434069372	30635	Business	42100.00
0005432531485	30635	Business	42100.00
0005432531401	30635	Business	42100.00
0005432531577	30635	Business	42100.00
0005434069374	30635	Business	42100.00
0005432531231	30635	Business	42100.00
0005434069204	30635	Business	42100.00
0005432531130	30635	Business	42100.00
0005432530874	30635	Business	42100.00
0005434069339	30635	Business	42100.00
0005432535965	30635	Business	42100.00
0005432531170	30635	Business	42100.00
0005434069244	30635	Business	42100.00
0005432530743	30635	Business	42100.00
0005432531200	30635	Business	42100.00
0005432530981	30635	Business	42100.00
0005432531315	30635	Business	42100.00
0005434068906	30635	Comfort	23900.00
0005432530869	30635	Business	42100.00
0005434068908	30635	Comfort	23900.00
0005432535975	30635	Comfort	23900.00
0005432530814	30635	Comfort	23900.00
0005434069481	30635	Comfort	23900.00
0005434069185	30635	Comfort	23900.00
0005434069165	30635	Comfort	23900.00
0005432531363	30635	Comfort	23900.00
0005433656768	30635	Comfort	23900.00
0005434068981	30635	Comfort	23900.00
0005434069286	30635	Comfort	23900.00
0005432531262	30635	Comfort	23900.00
0005432531059	30635	Comfort	23900.00
0005434069195	30635	Comfort	23900.00
0005434069373	30635	Comfort	23900.00
0005434068865	30635	Comfort	23900.00
0005432429007	30635	Comfort	23900.00
0005434068820	30635	Comfort	23900.00
0005434069194	30635	Comfort	23900.00
0005432531576	30635	Comfort	23900.00
0005434069158	30635	Comfort	23900.00
0005432429019	30635	Comfort	23900.00
0005434069464	30635	Comfort	23900.00
0005432531066	30635	Comfort	23900.00
0005434069482	30635	Comfort	23900.00
0005432531145	30635	Comfort	23900.00
0005432531012	30635	Comfort	23900.00
0005435283545	30635	Economy	14000.00
0005432530689	30635	Comfort	23900.00
0005434069123	30635	Economy	14000.00
0005432531484	30635	Economy	14000.00
0005432530892	30635	Economy	14000.00
0005432530765	30635	Economy	14000.00
0005432531310	30635	Economy	14000.00
0005432530623	30635	Economy	14000.00
0005432531219	30635	Economy	14000.00
0005432533363	30635	Economy	14000.00
0005434069067	30635	Economy	14000.00
0005432530772	30635	Economy	14000.00
0005432531312	30635	Economy	14000.00
0005434069328	30635	Economy	14000.00
0005432530796	30635	Economy	14000.00
0005432530861	30635	Economy	14000.00
0005434069159	30635	Economy	14000.00
0005432530879	30635	Economy	14000.00
0005432531246	30635	Economy	14000.00
0005434069032	30635	Economy	14000.00
0005434069096	30635	Economy	14000.00
0005434068909	30635	Economy	14000.00
0005432531129	30635	Economy	14000.00
0005434068711	30635	Economy	14000.00
0005432530728	30635	Economy	14000.00
0005434068898	30635	Economy	14000.00
0005432531364	30635	Economy	14000.00
0005435215530	30635	Economy	14000.00
0005432531314	30635	Economy	14000.00
0005432530893	30635	Economy	14000.00
0005435283551	30635	Economy	14000.00
0005432531030	30635	Economy	14000.00
0005434069066	30635	Economy	14000.00
0005435215531	30635	Economy	14000.00
0005434069197	30635	Economy	14000.00
0005432531013	30635	Economy	14000.00
0005434069154	30635	Economy	14000.00
0005432531532	30635	Economy	14000.00
0005434069183	30635	Economy	14000.00
0005432531014	30635	Economy	14000.00
0005432537108	30635	Economy	14000.00
0005434069152	30635	Economy	14000.00
0005432531239	30635	Economy	14000.00
0005434069171	30635	Economy	14000.00
0005432531398	30635	Economy	15400.00
0005432531466	30635	Economy	14000.00
0005434069388	30635	Economy	14000.00
0005434069124	30635	Economy	15400.00
0005432531256	30635	Economy	14000.00
0005434069545	30635	Economy	14000.00
0005432531344	30635	Economy	14000.00
0005432531533	30635	Economy	14000.00
0005432531291	30635	Economy	14000.00
0005432531061	30635	Economy	14000.00
0005432531018	30635	Economy	14000.00
0005432531400	30635	Economy	14000.00
0005432531015	30635	Economy	14000.00
0005434069412	30635	Economy	14000.00
0005435283550	30635	Economy	14000.00
0005432531569	30635	Economy	14000.00
0005434069220	30635	Economy	14000.00
0005434069039	30635	Economy	14000.00
0005432531602	30635	Economy	14000.00
0005434069097	30635	Economy	14000.00
0005434069186	30635	Economy	14000.00
0005434069314	30635	Economy	14000.00
0005432530536	30635	Economy	14000.00
0005434069193	30635	Economy	14000.00
0005435631055	30635	Economy	14000.00
0005432531240	30635	Economy	14000.00
0005434068982	30635	Economy	14000.00
0005432531301	30635	Economy	14000.00
0005435283544	30635	Economy	14000.00
0005435215528	30635	Economy	14000.00
0005432530797	30635	Economy	14000.00
0005432429020	30635	Economy	14000.00
0005434069223	30635	Economy	14000.00
0005434069026	30635	Economy	14000.00
0005432530866	30635	Economy	14000.00
0005432531365	30635	Economy	14000.00
0005432531622	30635	Economy	14000.00
0005434069355	30635	Economy	14000.00
0005432535930	30635	Economy	14000.00
0005432531621	30635	Economy	14000.00
0005434069338	30635	Economy	14000.00
0005434069290	30635	Economy	14000.00
0005432530853	30635	Economy	14000.00
0005432535960	30635	Economy	14000.00
0005432535966	30635	Economy	14000.00
0005432531366	30635	Economy	14000.00
0005432531257	30635	Economy	14000.00
0005434069153	30635	Economy	14000.00
0005432531049	30635	Economy	14000.00
0005432531223	30635	Economy	14000.00
0005434069219	30635	Economy	14000.00
0005434069356	30635	Economy	14000.00
0005434069293	30635	Economy	14000.00
0005434069142	30635	Economy	14000.00
0005432531311	30635	Economy	14000.00
0005432531652	30635	Economy	14000.00
0005434068949	30635	Economy	14000.00
0005432531245	30635	Economy	14000.00
0005432531300	30635	Economy	14000.00
0005432531224	30635	Economy	14000.00
0005432531106	30635	Economy	14000.00
0005434069143	30635	Economy	14000.00
0005432530852	30635	Economy	14000.00
0005432531483	30635	Economy	14000.00
0005432530868	30635	Economy	14000.00
0005432533362	30635	Economy	14000.00
0005432531084	30635	Economy	14000.00
0005432531058	30635	Economy	14000.00
0005432531169	30635	Economy	14000.00
0005432530975	30635	Economy	14000.00
0005434069053	30635	Economy	14000.00
0005432531132	30635	Economy	14000.00
0005434069313	30635	Economy	14000.00
0005432530816	30635	Economy	14000.00
0005435725741	30635	Economy	14000.00
0005432531217	30635	Economy	14000.00
0005432531601	30635	Economy	14000.00
0005434069249	30635	Economy	14000.00
0005432531220	30635	Economy	14000.00
0005435283547	30635	Economy	14000.00
0005432531092	30635	Economy	15400.00
0005432531277	30635	Economy	15400.00
0005432530811	30635	Economy	15400.00
0005432530871	30635	Economy	15400.00
0005432535929	30635	Economy	14000.00
0005434069411	30635	Economy	14000.00
0005434069218	30635	Economy	14000.00
0005432531048	30635	Economy	14000.00
0005432531182	30635	Economy	14000.00
0005432531571	30635	Economy	14000.00
0005432531017	30635	Economy	14000.00
0005434069172	30635	Economy	14000.00
0005432531050	30635	Economy	14000.00
0005434068938	30635	Economy	14000.00
0005432531103	30635	Economy	14000.00
0005435283549	30635	Economy	14000.00
0005432531222	30635	Economy	14000.00
0005434069475	30635	Economy	14000.00
0005434069248	30635	Economy	14000.00
0005432531221	30635	Economy	14000.00
0005432530884	30635	Economy	14000.00
0005432531267	30635	Economy	14000.00
0005432531104	30635	Economy	14000.00
0005434069291	30635	Economy	14000.00
0005432531142	30635	Economy	14000.00
0005432531199	30635	Economy	14000.00
0005435215529	30635	Economy	14000.00
0005432531476	30635	Economy	14000.00
0005432531345	30635	Economy	14000.00
0005432529926	30635	Economy	14000.00
0005434068940	30635	Economy	14000.00
0005432530976	30635	Economy	14000.00
0005432530815	30635	Economy	14000.00
0005434069160	30635	Economy	14000.00
0005435283546	30635	Economy	14000.00
0005434069231	30635	Economy	14000.00
0005434068852	30635	Economy	14000.00
0005432531358	30635	Economy	14000.00
0005432531321	30635	Economy	14000.00
0005432531432	30635	Economy	14000.00
0005432531115	30635	Economy	14000.00
0005432530865	30635	Economy	14000.00
0005434068907	30635	Economy	14000.00
0005432530936	30635	Economy	14000.00
0005435283548	30635	Economy	14000.00
0005432429008	30635	Economy	14000.00
0005432531486	30635	Economy	14000.00
0005432531067	30635	Economy	14000.00
0005432531278	30635	Economy	14000.00
0005432531120	30635	Economy	14000.00
0005434069213	30635	Economy	14000.00
0005432530745	30635	Economy	14000.00
0005432531057	30635	Economy	14000.00
0005432531146	30635	Economy	14000.00
0005432531454	30635	Economy	14000.00
0005432531578	30635	Economy	14000.00
0005432531213	30635	Economy	14000.00
0005434068939	30635	Economy	14000.00
0005432530770	30635	Economy	14000.00
0005434069247	30635	Economy	14000.00
0005432531266	30635	Economy	14000.00
0005432531570	30635	Economy	14000.00
0005434069029	30635	Economy	14000.00
0005432530962	30635	Economy	14000.00
0005432530744	30635	Economy	14000.00
0005432531346	30635	Economy	14000.00
0005432531198	30635	Economy	14000.00
0005432535952	30635	Economy	14000.00
0005432530870	30635	Economy	14000.00
0005434069261	30635	Economy	14000.00
0005434068894	30635	Economy	14000.00
0005432531131	30635	Economy	14000.00
0005432531359	30635	Economy	14000.00
0005432531296	30635	Economy	14000.00
0005434068712	30635	Economy	14000.00
0005435654259	24848	Business	9800.00
0005435654384	24848	Business	9800.00
0005435654059	24848	Business	9800.00
0005435654003	24848	Business	9800.00
0005435653995	24848	Business	9800.00
0005435654070	24848	Business	9800.00
0005435653914	24848	Business	9800.00
0005435790416	24848	Business	9800.00
0005435653960	24848	Business	9800.00
0005435654100	24848	Economy	3300.00
0005435654268	24848	Economy	3300.00
0005435654107	24848	Economy	3300.00
0005435653875	24848	Economy	3300.00
0005435654128	24848	Economy	3300.00
0005435654196	24848	Economy	3300.00
0005435654140	24848	Economy	3600.00
0005435654064	24848	Economy	3600.00
0005435653961	24848	Economy	3600.00
0005435654274	24848	Economy	3600.00
0005435654260	24848	Economy	3300.00
0005435654011	24848	Economy	3300.00
0005435654181	24848	Economy	3300.00
0005435654042	24848	Economy	3300.00
0005435654358	24848	Economy	3300.00
0005435653935	24848	Economy	3300.00
0005435654157	24848	Economy	3300.00
0005433368982	24848	Economy	3300.00
0005435654383	24848	Economy	3300.00
0005435654097	24848	Economy	3300.00
0005435653893	24848	Economy	3300.00
0005435654198	24848	Economy	3300.00
0005435654175	24848	Economy	3300.00
0005435654099	24848	Economy	3300.00
0005433368981	24848	Economy	3300.00
0005435654060	24848	Economy	3300.00
0005435654182	24848	Economy	3300.00
0005435654156	24848	Economy	3300.00
0005435653915	24848	Economy	3300.00
0005435654359	24848	Economy	3300.00
0005435653920	24848	Economy	3300.00
0005435654010	24848	Economy	3300.00
0005435654129	24848	Economy	3300.00
0005435654176	24848	Economy	3300.00
0005435654114	24848	Economy	3300.00
0005435654142	24848	Economy	3300.00
0005435654123	24848	Economy	3300.00
0005435654098	24848	Economy	3300.00
0005435654052	24848	Economy	3300.00
0005435654019	24848	Economy	3300.00
0005435653876	24848	Economy	3300.00
0005435653985	24848	Economy	3300.00
0005435654085	24848	Economy	3300.00
0005435653962	24848	Economy	3300.00
0005435654007	24848	Economy	3300.00
0005435654108	24848	Economy	3300.00
0005435654385	24848	Economy	3300.00
0005433368980	24848	Economy	3300.00
0005435654122	24848	Economy	3300.00
0005435654120	24848	Economy	3300.00
0005435654141	24848	Economy	3300.00
0005435654197	24848	Economy	3300.00
0005435654119	24848	Economy	3300.00
0005435654190	24848	Economy	3300.00
0005435654158	24848	Economy	3300.00
0005435949848	23310	Economy	18700.00
0005435949835	23310	Economy	18700.00
0005435949847	23310	Economy	18700.00
0005435949830	23310	Economy	18700.00
0005435949842	23310	Economy	18700.00
0005435949837	23310	Economy	18700.00
0005435949852	23310	Economy	18700.00
0005435949833	23310	Economy	18700.00
0005435949828	23310	Economy	18700.00
0005435949829	23310	Economy	18700.00
0005435949849	23310	Economy	18700.00
0005435949836	23310	Economy	18700.00
0005434980675	2058	Economy	10500.00
0005434980676	2058	Economy	10500.00
0005434980677	2058	Economy	9500.00
0005434980354	23545	Economy	10500.00
0005434980363	23545	Economy	10500.00
0005434980412	23545	Economy	10500.00
0005434980448	23545	Economy	10500.00
0005434980555	23545	Economy	9500.00
0005434980402	23545	Economy	9500.00
0005434980376	23545	Economy	9500.00
0005435801774	23545	Economy	9500.00
0005434980434	23545	Economy	9500.00
0005434980418	23545	Economy	9500.00
0005434980400	23545	Economy	9500.00
0005434980554	23545	Economy	9500.00
0005434980474	23545	Economy	9500.00
0005434980473	23545	Economy	9500.00
0005434980482	23545	Economy	9500.00
0005434980486	23545	Economy	9500.00
0005434980436	23545	Economy	9500.00
0005434980506	23545	Economy	9500.00
0005434980532	23545	Economy	9500.00
0005434980407	23545	Economy	9500.00
0005434980394	23545	Economy	9500.00
0005434980498	23545	Economy	9500.00
0005434980556	23545	Economy	9500.00
0005435801757	23545	Economy	9500.00
0005434980481	23545	Economy	9500.00
0005434980435	23545	Economy	9500.00
0005434980384	23545	Economy	9500.00
0005434980393	23545	Economy	9500.00
0005434980408	23545	Economy	9500.00
0005435801759	23545	Economy	9500.00
0005434980377	23545	Economy	9500.00
0005434980411	23545	Economy	9500.00
0005435801758	23545	Economy	9500.00
0005434980433	23545	Economy	9500.00
0005434980378	23545	Economy	9500.00
0005434980362	23545	Economy	9500.00
0005433256478	2574	Economy	5300.00
0005433256484	2574	Economy	5300.00
0005433256470	2574	Economy	5300.00
0005433256468	2574	Economy	5300.00
0005433256469	2574	Economy	5300.00
0005433256477	2574	Economy	5300.00
0005433256471	2574	Economy	5300.00
0005434952633	28192	Economy	5300.00
0005434952594	28192	Economy	5300.00
0005434952615	28192	Economy	5300.00
0005434952593	28192	Economy	5300.00
0005433111568	19727	Economy	8700.00
0005434302879	19727	Economy	8700.00
0005434302884	19727	Economy	8700.00
0005434139978	11960	Business	9700.00
0005434139804	11960	Business	9700.00
0005434140152	11960	Business	9700.00
0005434139599	11960	Business	9700.00
0005434139828	11960	Business	9700.00
0005434140229	11960	Business	9700.00
0005434140285	11960	Business	9700.00
0005434140292	11960	Business	9700.00
0005434139954	11960	Business	9700.00
0005434140197	11960	Business	9700.00
0005434140170	11960	Economy	3200.00
0005434140114	11960	Economy	3200.00
0005434140281	11960	Economy	3200.00
0005434140277	11960	Economy	3200.00
0005434140082	11960	Economy	3200.00
0005434140201	11960	Economy	3200.00
0005434139805	11960	Economy	3200.00
0005434140196	11960	Economy	3200.00
0005434140113	11960	Economy	3200.00
0005434140302	11960	Economy	3500.00
0005434140134	11960	Economy	3500.00
0005434140357	11960	Economy	3500.00
0005434140264	11960	Economy	3500.00
0005434140135	11960	Economy	3500.00
0005434140223	11960	Economy	3200.00
0005434139963	11960	Economy	3200.00
0005434140284	11960	Economy	3200.00
0005434139953	11960	Economy	3200.00
0005434140366	11960	Economy	3200.00
0005434140169	11960	Economy	3200.00
0005434139941	11960	Economy	3200.00
0005434140157	11960	Economy	3200.00
0005434140019	11960	Economy	3200.00
0005434140153	11960	Economy	3200.00
0005434139852	11960	Economy	3200.00
0005434139966	11960	Economy	3200.00
0005434140200	11960	Economy	3200.00
0005434140092	11960	Economy	3200.00
0005434139802	11960	Economy	3200.00
0005434139927	11960	Economy	3200.00
0005434140030	11960	Economy	3200.00
0005434140188	11960	Economy	3200.00
0005434139878	11960	Economy	3200.00
0005434140085	11960	Economy	3200.00
0005434139964	11960	Economy	3200.00
0005434140315	11960	Economy	3200.00
0005434140316	11960	Economy	3200.00
0005434140225	11960	Economy	3200.00
0005434140189	11960	Economy	3200.00
0005434140187	11960	Economy	3200.00
0005434140328	11960	Economy	3200.00
0005434139600	11960	Economy	3200.00
0005434140154	11960	Economy	3200.00
0005434140221	11960	Economy	3200.00
0005434140091	11960	Economy	3200.00
0005434140276	11960	Economy	3200.00
0005434140081	11960	Economy	3200.00
0005434140300	11960	Economy	3200.00
0005434139871	11960	Economy	3200.00
0005434139928	11960	Economy	3200.00
0005434140275	11960	Economy	3200.00
0005434139995	11960	Economy	3200.00
0005434140052	11960	Economy	3200.00
0005434140130	11960	Economy	3200.00
0005434139958	11960	Economy	3200.00
0005434139801	11960	Economy	3200.00
0005434140168	11960	Economy	3200.00
0005434139803	11960	Economy	3200.00
0005434140104	11960	Economy	3200.00
0005434140020	11960	Economy	3200.00
0005434140358	11960	Economy	3200.00
0005434139908	11960	Economy	3200.00
0005434140004	11960	Economy	3200.00
0005434140031	11960	Economy	3200.00
0005434139931	11960	Economy	3200.00
0005434140301	11960	Economy	3200.00
0005434139955	11960	Economy	3200.00
0005434140167	11960	Economy	3200.00
0005434140110	11960	Economy	3200.00
0005434140171	11960	Economy	3200.00
0005434139929	11960	Economy	3200.00
0005434140074	11960	Economy	3200.00
0005434140263	11960	Economy	3200.00
0005434140084	11960	Economy	3200.00
0005434140005	11960	Economy	3200.00
0005434140131	11960	Economy	3200.00
0005434140595	28739	Economy	3200.00
0005434140589	28739	Economy	3200.00
0005434140600	28739	Economy	3200.00
0005434140601	28739	Economy	3500.00
0005434140591	28739	Economy	3200.00
0005434140604	28739	Economy	3200.00
0005434140593	28739	Economy	3200.00
0005434140608	28739	Economy	3200.00
0005434140607	28739	Economy	3200.00
0005434140605	28739	Economy	3200.00
0005434140590	28739	Economy	3200.00
0005434140606	28739	Economy	3200.00
0005434140592	28739	Economy	3200.00
0005434140596	28739	Economy	3200.00
0005434140594	28739	Economy	3200.00
0005434140603	28739	Economy	3200.00
0005434140597	28739	Economy	3200.00
0005434140602	28739	Economy	3200.00
0005434140599	28739	Economy	3200.00
0005434140598	28739	Economy	3200.00
0005434513648	19103	Economy	23600.00
0005434516130	19103	Economy	23600.00
0005434513643	19103	Economy	23600.00
0005434516127	19103	Economy	23600.00
0005434516132	19103	Economy	23600.00
0005434513649	19103	Economy	23600.00
0005434513653	19103	Economy	23600.00
0005434516114	19103	Economy	23600.00
0005434513647	19103	Economy	23600.00
0005434513636	19103	Economy	23600.00
0005434516129	19103	Economy	23600.00
0005434516117	19103	Economy	23600.00
0005434516119	19103	Economy	23600.00
0005434516131	19103	Economy	23600.00
0005434516120	19103	Economy	23600.00
0005434513642	19103	Economy	23600.00
0005434513641	19103	Economy	23600.00
0005434516128	19103	Economy	23600.00
0005434513637	19103	Economy	23600.00
0005434516118	19103	Economy	23600.00
0005434513650	19103	Economy	23600.00
0005435259882	6820	Economy	10900.00
0005435259863	6820	Economy	10900.00
0005435259875	6820	Economy	9900.00
0005435259854	6820	Economy	9900.00
0005433539123	6820	Economy	9900.00
0005435259883	6820	Economy	9900.00
0005435259862	6820	Economy	9900.00
0005435259881	6820	Economy	9900.00
0005433539066	25041	Economy	9900.00
0005433539054	25041	Economy	9900.00
0005433534553	25041	Economy	9900.00
0005433539053	25041	Economy	9900.00
0005433539055	25041	Economy	9900.00
0005433534555	25041	Economy	9900.00
0005433539104	25041	Economy	9900.00
0005433512196	813	Economy	16100.00
0005432922616	813	Economy	14600.00
0005432922617	813	Economy	14600.00
0005432922618	813	Economy	14600.00
0005433512194	813	Economy	14600.00
0005432922620	813	Economy	14600.00
0005432922628	813	Economy	14600.00
0005433512195	813	Economy	14600.00
0005433512150	16123	Economy	14600.00
0005433512163	16123	Economy	14600.00
0005433512134	16123	Economy	14600.00
0005433512151	16123	Economy	14600.00
0005433512165	16123	Economy	14600.00
0005435852638	4043	Economy	13500.00
0005433475835	4043	Economy	12300.00
0005433475833	4043	Economy	12300.00
0005433475834	4043	Economy	12300.00
0005435698175	3645	Economy	7900.00
0005435698178	3645	Economy	7200.00
0005435916237	3645	Economy	7200.00
0005435935126	3645	Economy	7200.00
0005435698173	3645	Economy	7200.00
0005435916236	3645	Economy	7200.00
0005435916241	3645	Economy	7200.00
0005435935121	3645	Economy	7200.00
0005435698172	3645	Economy	7200.00
0005435698177	3645	Economy	7200.00
0005435698176	3645	Economy	7200.00
0005435698171	3645	Economy	7200.00
0005435916242	3645	Economy	7200.00
0005435935122	3645	Economy	7200.00
0005435935127	3645	Economy	7200.00
0005435698174	3645	Economy	7200.00
0005435697905	16311	Economy	7900.00
0005435697948	16311	Economy	7900.00
0005435697946	16311	Economy	7900.00
0005435697995	16311	Economy	7900.00
0005435697944	16311	Economy	7200.00
0005435698069	16311	Economy	7200.00
0005435697925	16311	Economy	7200.00
0005434950627	16311	Economy	7200.00
0005435697909	16311	Economy	7200.00
0005435697983	16311	Economy	7200.00
0005434950646	16311	Economy	7200.00
0005434950628	16311	Economy	7200.00
0005435697906	16311	Economy	7200.00
0005435698042	16311	Economy	7200.00
0005435698019	16311	Economy	7200.00
0005435697978	16311	Economy	7200.00
0005435698045	16311	Economy	7200.00
0005435698046	16311	Economy	7200.00
0005435697997	16311	Economy	7200.00
0005435697947	16311	Economy	7200.00
0005435697926	16311	Economy	7200.00
0005435697869	16311	Economy	7200.00
0005435697908	16311	Economy	7200.00
0005435698041	16311	Economy	7200.00
0005435697907	16311	Economy	7200.00
0005435698020	16311	Economy	7200.00
0005434950654	16311	Economy	7200.00
0005435698103	16311	Economy	7200.00
0005435698043	16311	Economy	7200.00
0005434950655	16311	Economy	7200.00
0005434950647	16311	Economy	7200.00
0005435697982	16311	Economy	7200.00
0005435698040	16311	Economy	7200.00
0005434606938	3944	Economy	19300.00
0005435842348	3944	Economy	19300.00
0005435853655	3944	Economy	19300.00
0005434606939	3944	Economy	19300.00
0005434606904	22055	Economy	19300.00
0005434606911	22055	Economy	19300.00
0005434606910	22055	Economy	19300.00
0005433519560	22055	Economy	19300.00
0005434606897	22055	Economy	19300.00
0005434606898	22055	Economy	19300.00
0005433349143	779	Economy	3700.00
0005433349144	779	Economy	3700.00
0005433349130	779	Economy	3700.00
0005433349142	779	Economy	3700.00
0005433349125	779	Economy	3700.00
0005433349129	779	Economy	3700.00
0005435628831	779	Economy	3700.00
0005435628808	15938	Economy	3700.00
0005435628802	15938	Economy	3700.00
0005435628817	15938	Economy	3700.00
0005435628809	15938	Economy	3700.00
0005435628816	15938	Economy	3700.00
0005435628801	15938	Economy	3700.00
0005433159367	17151	Economy	7100.00
0005433158194	17151	Economy	7100.00
0005433159362	17151	Economy	7100.00
0005433158193	17151	Economy	7100.00
0005433158182	17151	Economy	7100.00
0005433159365	17151	Economy	7100.00
0005433158179	17151	Economy	7100.00
0005433159359	17151	Economy	7100.00
0005434446591	17151	Economy	7100.00
0005433158192	17151	Economy	7100.00
0005434446590	17151	Economy	7100.00
0005433159366	17151	Economy	7100.00
0005434445307	17654	Economy	7100.00
0005434445304	17654	Economy	7100.00
0005434445308	17654	Economy	7100.00
0005435133198	7898	Economy	5900.00
0005435383273	7898	Economy	5400.00
0005435383294	7898	Economy	5400.00
0005435383272	7898	Economy	5400.00
0005435383290	7898	Economy	5400.00
0005435383276	7898	Economy	5400.00
0005435133151	33062	Economy	5400.00
0005435133103	33062	Economy	5400.00
0005435133149	33062	Economy	5400.00
0005435133184	33062	Economy	5400.00
0005435133122	33062	Economy	5400.00
0005435133150	33062	Economy	5400.00
0005435133183	33062	Economy	5400.00
0005435390407	7474	Economy	13800.00
0005435390389	7474	Economy	12500.00
0005435390406	7474	Economy	12500.00
0005435390430	7474	Economy	12500.00
0005435390418	7474	Economy	12500.00
0005435390431	7474	Economy	12500.00
0005435160608	29535	Economy	12500.00
0005435160567	29535	Economy	12500.00
0005435160579	29535	Economy	12500.00
0005435160566	29535	Economy	12500.00
0005435160607	29535	Economy	12500.00
0005435160580	29535	Economy	12500.00
0005435160588	29535	Economy	12500.00
0005435160609	29535	Economy	12500.00
0005432398273	18439	Economy	4900.00
0005432398272	18439	Economy	4900.00
0005432398276	18439	Economy	4900.00
0005432398294	18439	Economy	4900.00
0005432394189	18439	Economy	4900.00
0005432398296	18439	Economy	4900.00
0005432394196	18439	Economy	4900.00
0005432394197	18439	Economy	4900.00
0005432394195	18439	Economy	4900.00
0005432398274	18439	Economy	4900.00
0005432398295	18439	Economy	4900.00
0005432394188	18439	Economy	4900.00
0005432400222	27150	Economy	4900.00
0005434191309	9804	Economy	4400.00
0005434191313	9804	Economy	4400.00
0005434191308	9804	Economy	4400.00
0005434191312	9804	Economy	4400.00
0005435104377	6536	Economy	17800.00
0005435104380	6536	Economy	17800.00
0005434505318	6536	Economy	16100.00
0005434505317	6536	Economy	16100.00
0005435104379	6536	Economy	16100.00
0005434505316	6536	Economy	16100.00
0005435104378	6536	Economy	16100.00
0005434505064	22688	Business	48400.00
0005434505112	22688	Business	48400.00
0005435104119	22688	Business	48400.00
0005434505006	22688	Business	48400.00
0005434504976	22688	Business	48400.00
0005434505111	22688	Business	48400.00
0005434505063	22688	Business	48400.00
0005434505081	22688	Business	48400.00
0005434504988	22688	Business	48400.00
0005435104087	22688	Business	48400.00
0005434505071	22688	Economy	16100.00
0005434505169	22688	Economy	16100.00
0005434505023	22688	Economy	16100.00
0005434505155	22688	Economy	16100.00
0005435104121	22688	Economy	16100.00
0005434505095	22688	Economy	16100.00
0005435104079	22688	Economy	16100.00
0005434505083	22688	Economy	16100.00
0005435104144	22688	Economy	17800.00
0005434505103	22688	Economy	17800.00
0005434505154	22688	Economy	17800.00
0005434505080	22688	Economy	16100.00
0005434504906	22688	Economy	16100.00
0005434504907	22688	Economy	16100.00
0005434505029	22688	Economy	16100.00
0005434505003	22688	Economy	16100.00
0005434505021	22688	Economy	16100.00
0005435104128	22688	Economy	16100.00
0005434504807	22688	Economy	16100.00
0005434505164	22688	Economy	16100.00
0005435104139	22688	Economy	16100.00
0005435104110	22688	Economy	16100.00
0005434505018	22688	Economy	16100.00
0005435104129	22688	Economy	16100.00
0005435104112	22688	Economy	16100.00
0005434505013	22688	Economy	16100.00
0005434504949	22688	Economy	16100.00
0005434505069	22688	Economy	16100.00
0005435104134	22688	Economy	16100.00
0005434504914	22688	Economy	16100.00
0005434505030	22688	Economy	16100.00
0005434505088	22688	Economy	16100.00
0005435104131	22688	Economy	16100.00
0005434505062	22688	Economy	16100.00
0005435104120	22688	Economy	16100.00
0005434505026	22688	Economy	16100.00
0005434505022	22688	Economy	16100.00
0005434505000	22688	Economy	16100.00
0005435104130	22688	Economy	16100.00
0005434505070	22688	Economy	16100.00
0005434505165	22688	Economy	16100.00
0005435104111	22688	Economy	16100.00
0005434505086	22688	Economy	16100.00
0005435104083	22688	Economy	16100.00
0005434505084	22688	Economy	16100.00
0005435104145	22688	Economy	16100.00
0005434505033	22688	Economy	16100.00
0005434505173	22688	Economy	16100.00
0005434505087	22688	Economy	16100.00
0005434504875	22688	Economy	16100.00
0005434505001	22688	Economy	16100.00
0005434505067	22688	Economy	16100.00
0005435104109	22688	Economy	16100.00
0005434504931	22688	Economy	16100.00
0005434505017	22688	Economy	16100.00
0005435104078	22688	Economy	16100.00
0005433368706	1667	Business	50000.00
0005433368677	1667	Business	50000.00
0005433368707	1667	Business	50000.00
0005433368834	1667	Business	50000.00
0005433368809	1667	Business	50000.00
0005433368711	1667	Business	50000.00
0005435654494	1667	Economy	16700.00
0005433368845	1667	Economy	16700.00
0005435654490	1667	Economy	16700.00
0005433368891	1667	Economy	16700.00
0005433368964	1667	Economy	16700.00
0005433368799	1667	Economy	16700.00
0005433368789	1667	Economy	18300.00
0005433368761	1667	Economy	18300.00
0005435654492	1667	Economy	16700.00
0005433368869	1667	Economy	16700.00
0005433368749	1667	Economy	16700.00
0005433368793	1667	Economy	16700.00
0005435654493	1667	Economy	16700.00
0005433368686	1667	Economy	16700.00
0005433368802	1667	Economy	16700.00
0005433368833	1667	Economy	16700.00
0005433368616	1667	Economy	16700.00
0005435654491	1667	Economy	16700.00
0005433368618	1667	Economy	16700.00
0005433368842	1667	Economy	16700.00
0005435654489	1667	Economy	16700.00
0005433368640	1667	Economy	16700.00
0005433368705	1667	Economy	16700.00
0005433368846	1667	Economy	16700.00
0005433368847	1667	Economy	16700.00
0005433368855	1667	Economy	16700.00
0005433368676	1667	Economy	16700.00
0005433368801	1667	Economy	16700.00
0005433368823	1667	Economy	16700.00
0005433368879	1667	Economy	16700.00
0005433368757	1667	Economy	16700.00
0005435654486	1667	Economy	16700.00
0005433368642	1667	Economy	16700.00
0005435654487	1667	Economy	16700.00
0005433368797	1667	Economy	16700.00
0005433368698	1667	Economy	16700.00
0005435654488	1667	Economy	16700.00
0005433368617	1667	Economy	16700.00
0005433368800	1667	Economy	16700.00
0005433368981	21713	Business	50000.00
0005435654099	21713	Business	50000.00
0005435653893	21713	Business	50000.00
0005435654259	21713	Business	50000.00
0005435654100	21713	Business	50000.00
0005435654175	21713	Business	50000.00
0005435653920	21713	Business	50000.00
0005435654070	21713	Business	50000.00
0005435654198	21713	Economy	16700.00
0005433368980	21713	Economy	16700.00
0005435653962	21713	Economy	16700.00
0005435653935	21713	Economy	16700.00
0005435654052	21713	Economy	16700.00
0005435654156	21713	Economy	16700.00
0005435653914	21713	Economy	16700.00
0005435654190	21713	Economy	18300.00
0005435654157	21713	Economy	18300.00
0005435654383	21713	Economy	18300.00
0005435654060	21713	Economy	18300.00
0005435653960	21713	Economy	18300.00
0005435654119	21713	Economy	16700.00
0005435654059	21713	Economy	16700.00
0005433368982	21713	Economy	16700.00
0005435654123	21713	Economy	16700.00
0005435654176	21713	Economy	16700.00
0005435790406	21713	Economy	16700.00
0005435654274	21713	Economy	16700.00
0005435654141	21713	Economy	16700.00
0005435654140	21713	Economy	16700.00
0005435654358	21713	Economy	16700.00
0005435654158	21713	Economy	16700.00
0005435654120	21713	Economy	16700.00
0005435654098	21713	Economy	16700.00
0005435654011	21713	Economy	16700.00
0005435654097	21713	Economy	16700.00
0005435654122	21713	Economy	16700.00
0005435654108	21713	Economy	16700.00
0005435790407	21713	Economy	16700.00
0005435654385	21713	Economy	16700.00
0005435654114	21713	Economy	16700.00
0005435654064	21713	Economy	16700.00
0005435654107	21713	Economy	16700.00
0005435654359	21713	Economy	16700.00
0005435654260	21713	Economy	16700.00
0005435654003	21713	Economy	16700.00
0005435654182	21713	Economy	16700.00
0005435653876	21713	Economy	16700.00
0005435654129	21713	Economy	16700.00
0005435654197	21713	Economy	16700.00
0005435653875	21713	Economy	16700.00
0005435654085	21713	Economy	16700.00
0005435654268	21713	Economy	16700.00
0005435654042	21713	Economy	16700.00
0005435654019	21713	Economy	16700.00
0005435653985	21713	Economy	16700.00
0005435654384	21713	Economy	16700.00
0005435653995	21713	Economy	16700.00
0005435654181	21713	Economy	16700.00
0005435654142	21713	Economy	16700.00
0005435653915	21713	Economy	16700.00
0005435653961	21713	Economy	16700.00
0005435654196	21713	Economy	16700.00
0005435654010	21713	Economy	16700.00
0005435654128	21713	Economy	16700.00
0005435654007	21713	Economy	16700.00
0005435627128	23787	Economy	11200.00
0005435627124	23787	Economy	11200.00
0005433987376	4190	Economy	7200.00
0005433987377	4190	Economy	7200.00
0005433987375	4190	Economy	7900.00
0005433987373	4190	Economy	7200.00
0005433987374	4190	Economy	7200.00
0005433987038	25662	Business	21500.00
0005433986998	25662	Business	21500.00
0005433987148	25662	Business	21500.00
0005433986981	25662	Business	21500.00
0005433987126	25662	Business	21500.00
0005433987005	25662	Business	21500.00
0005433986978	25662	Business	21500.00
0005433986890	25662	Economy	7200.00
0005433986916	25662	Economy	7200.00
0005433986954	25662	Economy	7200.00
0005433987009	25662	Economy	7200.00
0005433987096	25662	Economy	7900.00
0005433987039	25662	Economy	7900.00
0005433987183	25662	Economy	7900.00
0005433987043	25662	Economy	7200.00
0005433987070	25662	Economy	7200.00
0005433987097	25662	Economy	7200.00
0005433986889	25662	Economy	7200.00
0005433986941	25662	Economy	7200.00
0005433987074	25662	Economy	7200.00
0005433986860	25662	Economy	7200.00
0005433986932	25662	Economy	7200.00
0005433986886	25662	Economy	7200.00
0005433987011	25662	Economy	7200.00
0005433987071	25662	Economy	7200.00
0005433986962	25662	Economy	7200.00
0005433987103	25662	Economy	7200.00
0005433986872	25662	Economy	7200.00
0005433987058	25662	Economy	7200.00
0005433987057	25662	Economy	7200.00
0005433986902	25662	Economy	7200.00
0005433987147	25662	Economy	7200.00
0005433987051	25662	Economy	7200.00
0005433987255	25662	Economy	7200.00
0005433986861	25662	Economy	7200.00
0005433987078	25662	Economy	7200.00
0005433986871	25662	Economy	7200.00
0005433986953	25662	Economy	7200.00
0005433986862	25662	Economy	7200.00
0005433987077	25662	Economy	7200.00
0005433987152	25662	Economy	7200.00
0005433986967	25662	Economy	7200.00
0005433986955	25662	Economy	7200.00
0005433987104	25662	Economy	7200.00
0005435788831	25662	Economy	7200.00
0005433986961	25662	Economy	7200.00
0005433986990	25662	Economy	7200.00
0005433987098	25662	Economy	7200.00
0005433986996	25662	Economy	7200.00
0005433986940	25662	Economy	7200.00
0005433986929	25662	Economy	7200.00
0005433987002	25662	Economy	7200.00
0005433986971	25662	Economy	7200.00
0005433986827	25662	Economy	7200.00
0005433987008	25662	Economy	7200.00
0005433461650	20244	Business	201300.00
0005433461653	20244	Business	201300.00
0005433460493	20244	Business	201300.00
0005433461655	20244	Business	201300.00
0005433461646	20244	Business	201300.00
0005433461652	20244	Economy	67100.00
0005433460491	20244	Economy	67100.00
0005433461644	20244	Economy	67100.00
0005433461645	20244	Economy	67100.00
0005433461649	20244	Economy	67100.00
0005433461651	20244	Economy	67100.00
0005433460497	20244	Economy	67100.00
0005433460496	20244	Economy	67100.00
0005433461654	20244	Economy	67100.00
0005433460498	20244	Economy	67100.00
0005433460495	20244	Economy	67100.00
0005433460492	20244	Economy	67100.00
0005433461648	20244	Economy	67100.00
0005433460494	20244	Economy	67100.00
0005433461647	20244	Economy	67100.00
0005435719587	21270	Economy	9400.00
0005435719593	21270	Economy	9400.00
0005435719590	21270	Economy	9400.00
0005434509327	21330	Economy	17000.00
0005434509335	21330	Economy	15500.00
0005434509306	21330	Economy	15500.00
0005434509334	21330	Economy	15500.00
0005434509341	21330	Economy	15500.00
0005434509326	21330	Economy	15500.00
0005434509342	21330	Economy	15500.00
0005434509330	21330	Economy	15500.00
0005434509319	21330	Economy	15500.00
0005434509359	21330	Economy	15500.00
0005434509308	21330	Economy	15500.00
0005434509325	21330	Economy	15500.00
0005434509310	21330	Economy	15500.00
0005434509333	21330	Economy	15500.00
0005434509358	21330	Economy	15500.00
0005434509357	21330	Economy	15500.00
0005434509356	21330	Economy	15500.00
0005432666429	17819	Business	18000.00
0005432869726	17819	Economy	6000.00
0005432655761	17819	Economy	6000.00
0005432660857	17819	Economy	6600.00
0005432657535	17819	Economy	6600.00
0005432667503	17819	Economy	6000.00
0005432655782	17819	Economy	6000.00
0005432657537	17819	Economy	6000.00
0005432659761	17819	Economy	6000.00
0005432660866	17819	Economy	6000.00
0005432655857	17819	Economy	6000.00
0005432667501	17819	Economy	6000.00
0005432659760	17819	Economy	6000.00
0005432657536	17819	Economy	6000.00
0005432667502	17819	Economy	6000.00
0005432665326	17819	Economy	6000.00
0005432655820	17819	Economy	6000.00
0005432655786	17819	Economy	6000.00
0005432664189	17819	Economy	6000.00
0005432665325	17819	Economy	6000.00
0005432655783	17819	Economy	6000.00
0005432658647	17819	Economy	6000.00
0005432665324	17819	Economy	6000.00
0005432655780	17819	Economy	6000.00
0005432658653	26311	Economy	6000.00
0005434151772	26311	Economy	6000.00
0005432869654	26311	Economy	6600.00
0005432666448	26311	Economy	6600.00
0005432869683	26311	Economy	6000.00
0005432869684	26311	Economy	6000.00
0005434151771	26311	Economy	6000.00
0005434151774	26311	Economy	6000.00
0005432869669	26311	Economy	6000.00
0005432655889	26311	Economy	6000.00
0005432655890	26311	Economy	6000.00
0005432655887	26311	Economy	6000.00
0005432869682	26311	Economy	6000.00
0005434151773	26311	Economy	6000.00
0005432659768	26311	Economy	6000.00
0005432869668	26311	Economy	6000.00
0005432655888	26311	Economy	6000.00
0005432666447	26311	Economy	6000.00
0005432657539	26311	Economy	6000.00
0005432848903	3092	Economy	5400.00
0005432848882	3092	Economy	5400.00
0005432330052	3092	Economy	5900.00
0005432330055	3092	Economy	5400.00
0005432905275	3092	Economy	5400.00
0005432905278	3092	Economy	5400.00
0005432848902	3092	Economy	5400.00
0005432905261	3092	Economy	5400.00
0005432905259	3092	Economy	5400.00
0005432848894	3092	Economy	5400.00
0005432848877	3092	Economy	5400.00
0005432848883	3092	Economy	5400.00
0005432905260	3092	Economy	5400.00
0005432905274	3092	Economy	5400.00
0005432330054	3092	Economy	5400.00
0005432905269	3092	Economy	5400.00
0005433439110	3092	Economy	5400.00
0005432330053	3092	Economy	5400.00
0005432329915	31149	Business	16100.00
0005432329687	31149	Business	16100.00
0005433439028	31149	Business	16100.00
0005432329670	31149	Business	16100.00
0005433439061	31149	Business	16100.00
0005432329879	31149	Economy	5400.00
0005432329658	31149	Economy	5400.00
0005432329899	31149	Economy	5400.00
0005432329823	31149	Economy	5400.00
0005432329641	31149	Economy	5400.00
0005433439077	31149	Economy	5400.00
0005433439056	31149	Economy	5400.00
0005432329730	31149	Economy	5900.00
0005432329766	31149	Economy	5900.00
0005432329789	31149	Economy	5900.00
0005432329612	31149	Economy	5400.00
0005432329896	31149	Economy	5400.00
0005433439076	31149	Economy	5400.00
0005432329812	31149	Economy	5400.00
0005433439024	31149	Economy	5400.00
0005432329928	31149	Economy	5400.00
0005432848918	31149	Economy	5400.00
0005433439029	31149	Economy	5400.00
0005432329688	31149	Economy	5400.00
0005432329824	31149	Economy	5400.00
0005432329802	31149	Economy	5400.00
0005432329596	31149	Economy	5400.00
0005433439062	31149	Economy	5400.00
0005432848919	31149	Economy	5400.00
0005432329595	31149	Economy	5400.00
0005432329837	31149	Economy	5400.00
0005432329807	31149	Economy	5400.00
0005433439053	31149	Economy	5400.00
0005432329668	31149	Economy	5400.00
0005433439073	31149	Economy	5400.00
0005432329806	31149	Economy	5400.00
0005432329751	31149	Economy	5400.00
0005432329642	31149	Economy	5400.00
0005432329693	31149	Economy	5400.00
0005432329643	31149	Economy	5400.00
0005432329735	31149	Economy	5400.00
0005432329811	31149	Economy	5400.00
0005433439074	31149	Economy	5400.00
0005432329835	31149	Economy	5400.00
0005432329747	31149	Economy	5400.00
0005432329731	31149	Economy	5400.00
0005432329577	31149	Economy	5400.00
0005432329640	31149	Economy	5400.00
0005432329750	31149	Economy	5400.00
0005432329748	31149	Economy	5400.00
0005435999862	6224	Business	124600.00
0005435488223	6224	Business	124600.00
0005435488410	6224	Business	124600.00
0005435297217	6224	Economy	41500.00
0005435488286	6224	Economy	41500.00
0005435488364	6224	Economy	41500.00
0005435297232	6224	Economy	41500.00
0005435488243	6224	Economy	41500.00
0005435488284	6224	Economy	41500.00
0005435297211	6224	Economy	45700.00
0005435297246	6224	Economy	41500.00
0005435488278	6224	Economy	41500.00
0005434310149	6224	Economy	41500.00
0005435488224	6224	Economy	41500.00
0005435488340	6224	Economy	41500.00
0005435488276	6224	Economy	41500.00
0005435999861	6224	Economy	41500.00
0005435488382	6224	Economy	41500.00
0005435488407	6224	Economy	41500.00
0005434310148	6224	Economy	41500.00
0005435488299	6224	Economy	41500.00
0005435488277	6224	Economy	41500.00
0005435999691	19573	Business	124600.00
0005435999650	19573	Business	124600.00
0005435999626	19573	Business	124600.00
0005435999622	19573	Business	124600.00
0005435999534	19573	Business	124600.00
0005434310087	19573	Economy	41500.00
0005435999707	19573	Economy	41500.00
0005434310121	19573	Economy	41500.00
0005435999533	19573	Economy	41500.00
0005435999708	19573	Economy	41500.00
0005435999697	19573	Economy	41500.00
0005434310122	19573	Economy	41500.00
0005434310072	19573	Economy	41500.00
0005434310091	19573	Economy	41500.00
0005434310082	19573	Economy	41500.00
0005435999698	19573	Economy	41500.00
0005435999718	19573	Economy	41500.00
0005435999720	19573	Economy	41500.00
0005435999686	19573	Economy	41500.00
0005434310011	19573	Economy	41500.00
0005434310107	19573	Economy	41500.00
0005435999651	19573	Economy	41500.00
0005435999694	19573	Economy	41500.00
0005434310064	19573	Economy	41500.00
0005435488473	19573	Economy	41500.00
0005435999690	19573	Economy	41500.00
0005435999656	19573	Economy	41500.00
0005435999696	19573	Economy	41500.00
0005435488476	19573	Economy	41500.00
0005434310089	19573	Economy	41500.00
0005435999703	19573	Economy	41500.00
0005434310092	19573	Economy	41500.00
0005435488474	19573	Economy	41500.00
0005434310012	19573	Economy	41500.00
0005434310117	19573	Economy	41500.00
0005434310086	19573	Economy	41500.00
0005434310081	19573	Economy	41500.00
0005434310071	19573	Economy	41500.00
0005435999719	19573	Economy	41500.00
0005435488477	19573	Economy	41500.00
0005435999652	19573	Economy	41500.00
0005435999695	19573	Economy	41500.00
0005434310073	19573	Economy	41500.00
0005435999712	19573	Economy	41500.00
0005435488475	19573	Economy	41500.00
0005435999714	19573	Economy	41500.00
0005433157020	17541	Economy	12300.00
0005433157022	17541	Economy	12300.00
0005434446575	17541	Economy	12300.00
0005433157019	17541	Economy	12300.00
0005434446558	17541	Economy	12300.00
0005434446576	17541	Economy	12300.00
0005434446574	17541	Economy	12300.00
0005434446577	17541	Economy	12300.00
0005434446572	17541	Economy	12300.00
0005433157021	17541	Economy	12300.00
0005435502962	1589	Business	86000.00
0005433186321	1589	Economy	28700.00
0005433186320	1589	Economy	28700.00
0005435508832	1589	Economy	31500.00
0005434566311	1589	Economy	28700.00
0005435508829	1589	Economy	28700.00
0005433186311	1589	Economy	28700.00
0005435508828	1589	Economy	28700.00
0005433186301	1589	Economy	28700.00
0005433186319	1589	Economy	28700.00
0005435508830	1589	Economy	28700.00
0005435502963	1589	Economy	28700.00
0005435502961	1589	Economy	28700.00
0005433186309	1589	Economy	28700.00
0005434566310	1589	Economy	28700.00
0005435508831	1589	Economy	28700.00
0005433186312	1589	Economy	28700.00
0005433186310	1589	Economy	28700.00
0005435502757	20892	Business	86000.00
0005435529792	20892	Business	86000.00
0005435502726	20892	Business	86000.00
0005435529741	20892	Business	86000.00
0005435502850	20892	Business	86000.00
0005434566237	20892	Business	86000.00
0005435529757	20892	Business	86000.00
0005435529726	20892	Economy	28700.00
0005434566202	20892	Economy	28700.00
0005435502695	20892	Economy	28700.00
0005434566271	20892	Economy	28700.00
0005435502758	20892	Economy	31500.00
0005435502781	20892	Economy	31500.00
0005435545888	20892	Economy	31500.00
0005435529707	20892	Economy	28700.00
0005435502688	20892	Economy	28700.00
0005435529651	20892	Economy	28700.00
0005434566207	20892	Economy	28700.00
0005435529727	20892	Economy	28700.00
0005435529796	20892	Economy	28700.00
0005435502687	20892	Economy	28700.00
0005435502846	20892	Economy	28700.00
0005435502878	20892	Economy	28700.00
0005434566235	20892	Economy	28700.00
0005434566153	20892	Economy	28700.00
0005434566239	20892	Economy	28700.00
0005435545912	20892	Economy	28700.00
0005435502727	20892	Economy	28700.00
0005435545913	20892	Economy	28700.00
0005435545889	20892	Economy	28700.00
0005435502859	20892	Economy	28700.00
0005435529738	20892	Economy	28700.00
0005435502774	20892	Economy	28700.00
0005435529648	20892	Economy	28700.00
0005435502823	20892	Economy	28700.00
0005435529790	20892	Economy	28700.00
0005435502742	20892	Economy	28700.00
0005434191330	20892	Economy	28700.00
0005434566233	20892	Economy	28700.00
0005434566272	20892	Economy	28700.00
0005435502797	20892	Economy	28700.00
0005434566220	20892	Economy	28700.00
0005434566219	20892	Economy	28700.00
0005434566225	20892	Economy	28700.00
0005435502804	20892	Economy	28700.00
0005435502824	20892	Economy	28700.00
0005435502696	20892	Economy	28700.00
0005434566188	20892	Economy	28700.00
0005435529649	20892	Economy	28700.00
0005434566236	20892	Economy	28700.00
0005435502803	20892	Economy	28700.00
0005433186375	20892	Economy	28700.00
0005435529768	20892	Economy	28700.00
0005435529773	20892	Economy	28700.00
0005435502791	20892	Economy	28700.00
0005434566189	20892	Economy	28700.00
0005434566203	20892	Economy	28700.00
0005435545897	20892	Economy	28700.00
0005435545896	20892	Economy	28700.00
0005434566163	20892	Economy	28700.00
0005435529728	20892	Economy	28700.00
0005435545949	20892	Economy	28700.00
0005435529758	20892	Economy	28700.00
0005435529779	20892	Economy	28700.00
0005434566256	20892	Economy	28700.00
0005435529767	20892	Economy	28700.00
0005435931693	3920	Economy	19700.00
0005435931689	3920	Economy	19700.00
0005435931692	3920	Economy	19700.00
0005435931696	3920	Economy	19700.00
0005435931688	3920	Economy	19700.00
0005435931690	3920	Economy	19700.00
0005435931684	3920	Economy	19700.00
0005435931683	3920	Economy	19700.00
0005435153918	21896	Economy	21600.00
0005435142971	21896	Economy	21600.00
0005435142973	21896	Economy	19700.00
0005435142979	21896	Economy	19700.00
0005435142974	21896	Economy	19700.00
0005435153911	21896	Economy	19700.00
0005435153894	21896	Economy	19700.00
0005435142990	21896	Economy	19700.00
0005435142982	21896	Economy	19700.00
0005435142985	21896	Economy	19700.00
0005435153912	21896	Economy	19700.00
0005435225755	7191	Economy	14300.00
0005435225768	7191	Economy	13000.00
0005435225769	7191	Economy	13000.00
0005435225756	7191	Economy	13000.00
0005435225754	7191	Economy	13000.00
0005435225779	7191	Economy	13000.00
0005435225787	7191	Economy	13000.00
0005432629193	28109	Economy	13000.00
0005432629192	28109	Economy	13000.00
0005435225813	28109	Economy	13000.00
0005432629230	28109	Economy	13000.00
0005432629189	28109	Economy	13000.00
0005432629229	28109	Economy	13000.00
0005432629188	28109	Economy	13000.00
0005435225812	28109	Economy	13000.00
0005435960167	8731	Economy	10500.00
0005434268051	8731	Economy	10500.00
0005434268041	8731	Economy	10500.00
0005434268052	8731	Economy	10500.00
0005435960166	8731	Economy	10500.00
0005434268050	8731	Economy	10500.00
0005435960165	8731	Economy	10500.00
0005435960168	8731	Economy	10500.00
0005435960151	15252	Economy	10500.00
0005435960150	15252	Economy	10500.00
0005432675583	1218	Business	115000.00
0005432675587	1218	Business	115000.00
0005432677690	1218	Business	115000.00
0005432873423	1218	Business	115000.00
0005432873462	1218	Business	115000.00
0005432873459	1218	Economy	38300.00
0005432693964	1218	Economy	38300.00
0005432693963	1218	Economy	38300.00
0005432675585	1218	Economy	38300.00
0005432693966	1218	Economy	38300.00
0005432693965	1218	Economy	38300.00
0005432693961	1218	Economy	38300.00
0005432873460	1218	Economy	38300.00
0005432675584	1218	Economy	38300.00
0005432693967	1218	Economy	38300.00
0005432693962	1218	Economy	38300.00
0005432675586	1218	Economy	38300.00
0005432693701	17475	Business	115000.00
0005432693837	17475	Business	115000.00
0005432693769	17475	Business	115000.00
0005432677649	17475	Business	115000.00
0005432693803	17475	Business	115000.00
0005432675527	17475	Business	115000.00
0005432693883	17475	Economy	38300.00
0005432693885	17475	Economy	38300.00
0005432873503	17475	Economy	38300.00
0005432675490	17475	Economy	38300.00
0005432693770	17475	Economy	38300.00
0005432693761	17475	Economy	42200.00
0005432693771	17475	Economy	42200.00
0005432675491	17475	Economy	38300.00
0005432675528	17475	Economy	38300.00
0005432693839	17475	Economy	38300.00
0005432693851	17475	Economy	38300.00
0005432675498	17475	Economy	38300.00
0005432873498	17475	Economy	38300.00
0005432693869	17475	Economy	38300.00
0005432693751	17475	Economy	38300.00
0005432693865	17475	Economy	38300.00
0005432677666	17475	Economy	38300.00
0005432693810	17475	Economy	38300.00
0005432675500	17475	Economy	38300.00
0005432675452	17475	Economy	38300.00
0005432693700	17475	Economy	38300.00
0005432693868	17475	Economy	38300.00
0005432677667	17475	Economy	38300.00
0005432873502	17475	Economy	38300.00
0005432693804	17475	Economy	38300.00
0005432675545	17475	Economy	38300.00
0005432693838	17475	Economy	38300.00
0005432675526	17475	Economy	38300.00
0005432675476	17475	Economy	38300.00
0005432693819	17475	Economy	38300.00
0005432693818	17475	Economy	38300.00
0005432873501	17475	Economy	38300.00
0005432693809	17475	Economy	38300.00
0005432693763	17475	Economy	38300.00
0005432675519	17475	Economy	38300.00
0005432675546	17475	Economy	38300.00
0005432693780	17475	Economy	38300.00
0005432677650	17475	Economy	38300.00
0005432675499	17475	Economy	38300.00
0005432675504	17475	Economy	38300.00
0005432675515	17475	Economy	38300.00
0005432693884	17475	Economy	38300.00
0005432693797	17475	Economy	38300.00
0005432873500	17475	Economy	38300.00
0005432693836	17475	Economy	38300.00
0005432693726	17475	Economy	38300.00
0005432693861	17475	Economy	38300.00
0005432873499	17475	Economy	38300.00
0005432693781	17475	Economy	38300.00
0005433157000	1110	Economy	13900.00
0005433156999	1110	Economy	13900.00
0005434435637	1110	Economy	13900.00
0005434435636	1110	Economy	13900.00
0005433156960	1110	Economy	13900.00
0005433156944	1110	Economy	13900.00
0005433156949	1110	Economy	13900.00
0005433156975	1110	Economy	13900.00
0005434435593	17320	Economy	15200.00
0005434435607	17320	Economy	15200.00
0005434435537	17320	Economy	13900.00
0005434435524	17320	Economy	13900.00
0005434435585	17320	Economy	13900.00
0005434435608	17320	Economy	13900.00
0005434435506	17320	Economy	13900.00
0005433157009	17320	Economy	13900.00
0005434435620	17320	Economy	13900.00
0005434435479	17320	Economy	13900.00
0005434435556	17320	Economy	13900.00
0005434435586	17320	Economy	13900.00
0005434435480	17320	Economy	13900.00
0005434435554	17320	Economy	13900.00
0005433157008	17320	Economy	13900.00
0005434435549	17320	Economy	13900.00
0005434435557	17320	Economy	13900.00
0005434435584	17320	Economy	13900.00
0005435928241	4070	Economy	7500.00
0005435928262	4070	Economy	7500.00
0005435928266	4070	Economy	7500.00
0005435928279	4070	Economy	7500.00
0005435928264	4070	Economy	7500.00
0005435087041	24431	Economy	7500.00
0005435928291	24431	Economy	7500.00
0005435928290	24431	Economy	7500.00
0005435654520	17010	Business	144300.00
0005435551767	17010	Economy	48100.00
0005435551762	17010	Economy	48100.00
0005435551765	17010	Economy	48100.00
0005435654516	17010	Economy	48100.00
0005435654518	17010	Economy	48100.00
0005435551770	17010	Economy	48100.00
0005435551763	17010	Economy	48100.00
0005435654517	17010	Economy	48100.00
0005435551764	17010	Economy	48100.00
0005435551761	17010	Economy	48100.00
0005435654519	17010	Economy	48100.00
0005435551766	17010	Economy	48100.00
0005435551768	17010	Economy	48100.00
0005435551769	17010	Economy	48100.00
0005433194925	4838	Business	44200.00
0005434626238	4838	Business	44200.00
0005433194941	4838	Business	44200.00
0005435907627	4838	Economy	14700.00
0005435907636	4838	Economy	14700.00
0005433194942	4838	Economy	14700.00
0005435907603	4838	Economy	14700.00
0005433194909	4838	Economy	14700.00
0005435907629	4838	Economy	14700.00
0005435907641	4838	Economy	14700.00
0005435907631	4838	Economy	14700.00
0005433194911	4838	Economy	14700.00
0005435907630	4838	Economy	14700.00
0005434626209	32927	Economy	14700.00
0005433195015	32927	Economy	14700.00
0005434626184	32927	Economy	14700.00
0005434626216	32927	Economy	14700.00
0005434626185	32927	Economy	14700.00
0005434626206	32927	Economy	14700.00
0005434626193	32927	Economy	14700.00
0005434626169	32927	Economy	14700.00
0005434626194	32927	Economy	14700.00
0005435786152	13799	Economy	3400.00
0005435786312	13799	Economy	3400.00
0005435786335	13799	Economy	3400.00
0005435786179	13799	Economy	3400.00
0005435786088	13799	Economy	3100.00
0005435786164	13799	Economy	3100.00
0005435786053	13799	Economy	3100.00
0005435786054	13799	Economy	3100.00
0005435786068	13799	Economy	3100.00
0005435786228	13799	Economy	3100.00
0005435786227	13799	Economy	3100.00
0005435786087	13799	Economy	3100.00
0005435937573	13799	Economy	3100.00
0005435786131	13799	Economy	3100.00
0005435786052	13799	Economy	3100.00
0005435786177	13799	Economy	3100.00
0005435786334	13799	Economy	3100.00
0005435786151	13799	Economy	3100.00
0005435786141	13799	Economy	3100.00
0005435786132	13799	Economy	3100.00
0005432195757	13799	Economy	3100.00
0005435786263	13799	Economy	3100.00
0005435786046	13799	Economy	3100.00
0005435786092	13799	Economy	3100.00
0005435786176	13799	Economy	3100.00
0005435786136	13799	Economy	3100.00
0005435786163	13799	Economy	3100.00
0005435785963	13799	Economy	3100.00
0005435786149	13799	Economy	3100.00
0005435786113	13799	Economy	3100.00
0005435786107	13799	Economy	3100.00
0005435786348	27401	Economy	3400.00
0005435937490	27401	Economy	3400.00
0005435786356	27401	Economy	3100.00
0005435786353	27401	Economy	3100.00
0005435937503	27401	Economy	3100.00
0005435786350	27401	Economy	3100.00
0005435786355	27401	Economy	3100.00
0005435786357	27401	Economy	3100.00
0005435937491	27401	Economy	3100.00
0005435937511	27401	Economy	3100.00
0005435937483	27401	Economy	3100.00
0005435937462	27401	Economy	3100.00
0005435937541	27401	Economy	3100.00
0005435786349	27401	Economy	3100.00
0005435786354	27401	Economy	3100.00
0005435786347	27401	Economy	3100.00
0005435786352	27401	Economy	3100.00
0005435937502	27401	Economy	3100.00
0005435937527	27401	Economy	3100.00
0005435937540	27401	Economy	3100.00
0005435786351	27401	Economy	3100.00
0005435937501	27401	Economy	3100.00
0005434408988	20289	Business	12000.00
0005434409277	20289	Business	12000.00
0005434409232	20289	Business	12000.00
0005434409246	20289	Business	12000.00
0005434409282	20289	Business	12000.00
0005434409345	20289	Business	12000.00
0005434409195	20289	Business	12000.00
0005434409254	20289	Business	12000.00
0005434409239	20289	Economy	4000.00
0005435311557	20289	Economy	4000.00
0005434409288	20289	Economy	4000.00
0005434409160	20289	Economy	4000.00
0005434409324	20289	Economy	4000.00
0005434409236	20289	Economy	4400.00
0005435311556	20289	Economy	4400.00
0005434409265	20289	Economy	4400.00
0005434408996	20289	Economy	4400.00
0005434409183	20289	Economy	4000.00
0005434409101	20289	Economy	4000.00
0005434409287	20289	Economy	4000.00
0005434409370	20289	Economy	4000.00
0005434409377	20289	Economy	4000.00
0005434409351	20289	Economy	4000.00
0005434409346	20289	Economy	4000.00
0005434409170	20289	Economy	4000.00
0005434409205	20289	Economy	4000.00
0005434409485	20289	Economy	4000.00
0005434409369	20289	Economy	4000.00
0005434409202	20289	Economy	4000.00
0005434408989	20289	Economy	4000.00
0005434409245	20289	Economy	4000.00
0005435311558	20289	Economy	4000.00
0005434409266	20289	Economy	4000.00
0005434409176	20289	Economy	4000.00
0005434409240	20289	Economy	4000.00
0005434409102	20289	Economy	4000.00
0005434409379	20289	Economy	4000.00
0005434409285	20289	Economy	4000.00
0005434409286	20289	Economy	4000.00
0005434409376	20289	Economy	4000.00
0005434409060	20289	Economy	4000.00
0005434409323	20289	Economy	4000.00
0005434409154	20289	Economy	4000.00
0005434408990	20289	Economy	4000.00
0005434409233	20289	Economy	4000.00
0005434409339	20289	Economy	4000.00
0005434409201	20289	Economy	4000.00
0005434409417	20289	Economy	4000.00
0005434409194	20289	Economy	4000.00
0005434409155	20289	Economy	4000.00
0005434409384	20289	Economy	4000.00
0005434409484	20289	Economy	4000.00
0005434409358	20289	Economy	4000.00
0005434409486	20289	Economy	4000.00
0005434409264	20289	Economy	4000.00
0005434409111	20289	Economy	4000.00
0005434409359	20289	Economy	4000.00
0005434409283	20289	Economy	4000.00
0005434409046	20289	Economy	4000.00
0005434409229	20289	Economy	4000.00
0005434409209	20289	Economy	4000.00
0005434409284	20289	Economy	4000.00
0005435311298	26965	Business	12000.00
0005435311354	26965	Business	12000.00
0005435311353	26965	Business	12000.00
0005434409612	26965	Business	12000.00
0005434409613	26965	Economy	4000.00
0005435311342	26965	Economy	4000.00
0005435311460	26965	Economy	4000.00
0005435311387	26965	Economy	4000.00
0005435311389	26965	Economy	4000.00
0005435311352	26965	Economy	4000.00
0005435311307	26965	Economy	4000.00
0005434409614	26965	Economy	4000.00
0005435311452	26965	Economy	4000.00
0005435311432	26965	Economy	4000.00
0005434409611	26965	Economy	4000.00
0005435311428	26965	Economy	4000.00
0005435311341	26965	Economy	4000.00
0005435311422	26965	Economy	4000.00
0005435311386	26965	Economy	4000.00
0005433124397	5718	Business	43300.00
0005433124437	5718	Business	43300.00
0005433124415	5718	Business	43300.00
0005433124414	5718	Business	43300.00
0005433124455	5718	Business	43300.00
0005433124464	5718	Economy	14400.00
0005435297356	5718	Economy	14400.00
0005433124399	5718	Economy	14400.00
0005433124456	5718	Economy	14400.00
0005433124324	5718	Economy	14400.00
0005433124465	5718	Economy	15900.00
0005433124389	5718	Economy	15900.00
0005435297350	5718	Economy	14400.00
0005434319867	5718	Economy	14400.00
0005433124442	5718	Economy	14400.00
0005433124343	5718	Economy	14400.00
0005435297355	5718	Economy	14400.00
0005433124386	5718	Economy	14400.00
0005433124378	5718	Economy	14400.00
0005432109783	5718	Economy	14400.00
0005434310182	5718	Economy	14400.00
0005434319865	5718	Economy	14400.00
0005433124413	5718	Economy	14400.00
0005433124466	5718	Economy	14400.00
0005433124398	5718	Economy	14400.00
0005433124393	5718	Economy	14400.00
0005434311281	5718	Economy	14400.00
0005434310180	5718	Economy	14400.00
0005434319866	5718	Economy	14400.00
0005434310181	5718	Economy	14400.00
0005433124410	5718	Economy	14400.00
0005433124394	5718	Economy	14400.00
0005434311268	15682	Business	43300.00
0005434319721	15682	Business	43300.00
0005434319785	15682	Business	43300.00
0005433124552	15682	Business	43300.00
0005434319629	15682	Business	43300.00
0005434312358	15682	Economy	14400.00
0005434319694	15682	Economy	14400.00
0005434319719	15682	Economy	14400.00
0005434319742	15682	Economy	14400.00
0005434319751	15682	Economy	14400.00
0005434319752	15682	Economy	14400.00
0005434319671	15682	Economy	14400.00
0005434319696	15682	Economy	14400.00
0005434319648	15682	Economy	14400.00
0005434319688	15682	Economy	14400.00
0005434312359	15682	Economy	14400.00
0005434319714	15682	Economy	14400.00
0005434319801	15682	Economy	14400.00
0005434311269	15682	Economy	14400.00
0005433124551	15682	Economy	14400.00
0005434311270	15682	Economy	14400.00
0005434319695	15682	Economy	14400.00
0005435297397	15682	Economy	14400.00
0005434319707	15682	Economy	14400.00
0005434319728	15682	Economy	14400.00
0005434319630	15682	Economy	14400.00
0005434319784	15682	Economy	14400.00
0005434319759	15682	Economy	14400.00
0005434319713	15682	Economy	14400.00
0005434312367	15682	Economy	14400.00
0005434319720	15682	Economy	14400.00
0005435220384	31740	Economy	15500.00
0005435220385	31740	Economy	15500.00
0005435219265	31740	Economy	15500.00
0005435220522	31740	Economy	15500.00
0005435220386	31740	Economy	15500.00
0005434189317	8979	Economy	24900.00
0005434189320	8979	Economy	24900.00
0005434189300	8979	Economy	24900.00
0005434189315	8979	Economy	24900.00
0005434484497	16613	Economy	27400.00
0005434484496	16613	Economy	24900.00
0005434484516	16613	Economy	24900.00
0005433722356	7617	Business	11100.00
0005433722365	7617	Economy	3700.00
0005433722354	7617	Economy	3700.00
0005433722351	7617	Economy	3700.00
0005433722368	7617	Economy	4100.00
0005433722366	7617	Economy	3700.00
0005433722375	7617	Economy	3700.00
0005433124552	7617	Economy	3700.00
0005433722362	7617	Economy	3700.00
0005433722376	7617	Economy	3700.00
0005433722367	7617	Economy	3700.00
0005433722361	7617	Economy	3700.00
0005433124551	7617	Economy	3700.00
0005433722369	7617	Economy	3700.00
0005433450610	7616	Economy	3700.00
0005432693968	7616	Economy	3700.00
0005432721690	7616	Economy	3700.00
0005432071664	7616	Economy	3700.00
0005433450609	7616	Economy	3700.00
0005432693969	7616	Economy	3700.00
0005433450396	30284	Business	11100.00
0005432693763	30284	Business	11100.00
0005433450541	30284	Business	11100.00
0005432693780	30284	Business	11100.00
0005432693701	30284	Economy	3700.00
0005432693861	30284	Economy	3700.00
0005432693761	30284	Economy	3700.00
0005433450394	30284	Economy	3700.00
0005432693700	30284	Economy	3700.00
0005433450514	30284	Economy	4100.00
0005433450494	30284	Economy	3700.00
0005432693851	30284	Economy	3700.00
0005432693869	30284	Economy	3700.00
0005433450515	30284	Economy	3700.00
0005432693803	30284	Economy	3700.00
0005432693769	30284	Economy	3700.00
0005432693809	30284	Economy	3700.00
0005432693770	30284	Economy	3700.00
0005433450518	30284	Economy	3700.00
0005433450468	30284	Economy	3700.00
0005433450469	30284	Economy	3700.00
0005432693781	30284	Economy	3700.00
0005432693868	30284	Economy	3700.00
0005432693818	30284	Economy	3700.00
0005433450516	30284	Economy	3700.00
0005432693838	30284	Economy	3700.00
0005432693810	30284	Economy	3700.00
0005432693884	30284	Economy	3700.00
0005432693804	30284	Economy	3700.00
0005432693839	30284	Economy	3700.00
0005432693885	30284	Economy	3700.00
0005432693726	30284	Economy	3700.00
0005432693819	30284	Economy	3700.00
0005433450465	30284	Economy	3700.00
0005432693797	30284	Economy	3700.00
0005433450397	30284	Economy	3700.00
0005432693751	30284	Economy	3700.00
0005432693865	30284	Economy	3700.00
0005432693771	30284	Economy	3700.00
0005432693837	30284	Economy	3700.00
0005433450464	30284	Economy	3700.00
0005432693836	30284	Economy	3700.00
0005432693883	30284	Economy	3700.00
0005433124456	30283	Business	11100.00
0005433124378	30283	Business	11100.00
0005434310180	30283	Business	11100.00
0005432721622	30283	Business	11100.00
0005432721534	30283	Business	11100.00
0005433124415	30283	Economy	3700.00
0005433124437	30283	Economy	3700.00
0005432721638	30283	Economy	3700.00
0005433722509	30283	Economy	3700.00
0005432721535	30283	Economy	3700.00
0005433124414	30283	Economy	3700.00
0005433124442	30283	Economy	3700.00
0005432721506	30283	Economy	3700.00
0005433124410	30283	Economy	3700.00
0005433124393	30283	Economy	3700.00
0005433124324	30283	Economy	3700.00
0005432721517	30283	Economy	3700.00
0005433124397	30283	Economy	3700.00
0005432721540	30283	Economy	3700.00
0005432721541	30283	Economy	3700.00
0005432721597	30283	Economy	3700.00
0005434310182	30283	Economy	3700.00
0005432721512	30283	Economy	3700.00
0005433124466	30283	Economy	3700.00
0005433124398	30283	Economy	3700.00
0005432721599	30283	Economy	3700.00
0005433124389	30283	Economy	3700.00
0005432721598	30283	Economy	3700.00
0005433124465	30283	Economy	3700.00
0005433124413	30283	Economy	3700.00
0005433124394	30283	Economy	3700.00
0005432721612	30283	Economy	3700.00
0005432721527	30283	Economy	3700.00
0005433124386	30283	Economy	3700.00
0005433124455	30283	Economy	3700.00
0005432721574	30283	Economy	3700.00
0005432721550	30283	Economy	3700.00
0005433124343	30283	Economy	3700.00
0005432721575	30283	Economy	3700.00
0005433124399	30283	Economy	3700.00
0005433124464	30283	Economy	3700.00
0005432721507	30283	Economy	3700.00
0005432721617	30283	Economy	3700.00
0005432721539	30283	Economy	3700.00
0005432721623	30283	Economy	3700.00
0005434310181	30283	Economy	3700.00
0005432928111	1362	Business	70400.00
0005434587361	1362	Economy	23500.00
0005434587360	1362	Economy	23500.00
0005433724940	1362	Economy	23500.00
0005433193322	1362	Economy	23500.00
0005432968895	1362	Economy	23500.00
0005433193407	1362	Economy	23500.00
0005433193387	1362	Economy	23500.00
0005433193361	1362	Economy	23500.00
0005433193388	1362	Economy	23500.00
0005433193400	1362	Economy	23500.00
0005433193389	1362	Economy	23500.00
0005434587359	1362	Economy	23500.00
0005433193362	1362	Economy	23500.00
0005432968904	1362	Economy	23500.00
0005433193375	1362	Economy	23500.00
0005433193386	1362	Economy	23500.00
0005433193401	1362	Economy	23500.00
0005434515036	18522	Business	70400.00
0005433724914	18522	Business	70400.00
0005433724922	18522	Business	70400.00
0005434515024	18522	Business	70400.00
0005434587184	18522	Business	70400.00
0005433193443	18522	Business	70400.00
0005434587275	18522	Business	70400.00
0005434587306	18522	Economy	23500.00
0005434587268	18522	Economy	23500.00
0005434587189	18522	Economy	23500.00
0005434587164	18522	Economy	23500.00
0005434587325	18522	Economy	23500.00
0005434587214	18522	Economy	23500.00
0005433724921	18522	Economy	23500.00
0005434587158	18522	Economy	23500.00
0005433193442	18522	Economy	23500.00
0005434587203	18522	Economy	23500.00
0005434587286	18522	Economy	23500.00
0005433724901	18522	Economy	23500.00
0005433525309	18522	Economy	23500.00
0005434587133	18522	Economy	23500.00
0005434587087	18522	Economy	23500.00
0005434515014	18522	Economy	23500.00
0005433724900	18522	Economy	23500.00
0005433525238	18522	Economy	23500.00
0005434515015	18522	Economy	23500.00
0005433193444	18522	Economy	23500.00
0005433724913	18522	Economy	23500.00
0005434587210	18522	Economy	23500.00
0005434515029	18522	Economy	23500.00
0005434587190	18522	Economy	23500.00
0005432928150	18522	Economy	23500.00
0005433193445	18522	Economy	23500.00
0005433525239	18522	Economy	23500.00
0005433525310	18522	Economy	23500.00
0005432928149	18522	Economy	23500.00
0005434587171	18522	Economy	23500.00
0005434515025	18522	Economy	23500.00
0005434587287	18522	Economy	23500.00
0005434587326	18522	Economy	23500.00
0005434587250	18522	Economy	23500.00
0005434587170	18522	Economy	23500.00
0005433525340	18522	Economy	23500.00
0005433525286	18522	Economy	23500.00
0005435305057	11445	Economy	4300.00
0005435305056	11445	Economy	4000.00
0005434345285	11445	Economy	4000.00
0005434345279	11445	Economy	4000.00
0005434345281	11445	Economy	4000.00
0005434345278	11445	Economy	4000.00
0005434345274	11445	Economy	4000.00
0005434345280	11445	Economy	4000.00
0005434345275	11445	Economy	4000.00
0005434345276	11445	Economy	4000.00
0005434345284	11445	Economy	4000.00
0005434345277	11445	Economy	4000.00
0005434345283	11445	Economy	4000.00
0005434345282	11445	Economy	4000.00
0005435305061	11445	Economy	4000.00
0005434344969	29764	Economy	4300.00
0005434344996	29764	Economy	4300.00
0005434345005	29764	Economy	4000.00
0005434345117	29764	Economy	4000.00
0005434344825	29764	Economy	4000.00
0005434345125	29764	Economy	4000.00
0005434345124	29764	Economy	4000.00
0005434345136	29764	Economy	4000.00
0005434344956	29764	Economy	4000.00
0005434345022	29764	Economy	4000.00
0005434344935	29764	Economy	4000.00
0005434345021	29764	Economy	4000.00
0005434345129	29764	Economy	4000.00
0005434345134	29764	Economy	4000.00
0005434344908	29764	Economy	4000.00
0005434344907	29764	Economy	4000.00
0005434345020	29764	Economy	4000.00
0005434344869	29764	Economy	4000.00
0005434345023	29764	Economy	4000.00
0005434344944	29764	Economy	4000.00
0005434345135	29764	Economy	4000.00
0005434344826	29764	Economy	4000.00
0005434344966	29764	Economy	4000.00
0005434345170	29764	Economy	4000.00
0005434345048	29764	Economy	4000.00
0005434345064	29764	Economy	4000.00
0005434345121	29764	Economy	4000.00
0005434344964	29764	Economy	4000.00
0005434345078	29764	Economy	4000.00
0005434344940	29764	Economy	4000.00
0005434345006	29764	Economy	4000.00
0005434344934	29764	Economy	4000.00
0005434344965	29764	Economy	4000.00
0005434345119	29764	Economy	4000.00
0005434344943	29764	Economy	4000.00
0005433416084	1297	Business	199800.00
0005435825420	1297	Business	199800.00
0005433416017	1297	Business	199800.00
0005433416009	1297	Business	199800.00
0005435825421	1297	Business	199800.00
0005433416104	1297	Economy	66600.00
0005433416016	1297	Economy	66600.00
0005433415985	1297	Economy	66600.00
0005433416037	1297	Economy	73200.00
0005433416123	1297	Economy	66600.00
0005433416070	1297	Economy	66600.00
0005433416061	1297	Economy	66600.00
0005433416062	1297	Economy	66600.00
0005433416091	1297	Economy	66600.00
0005433416093	1297	Economy	66600.00
0005435825422	1297	Economy	66600.00
0005433416023	1297	Economy	66600.00
0005433415984	1297	Economy	66600.00
0005433416086	1297	Economy	66600.00
0005433416092	1297	Economy	66600.00
0005435825200	18018	Business	199800.00
0005435825272	18018	Business	199800.00
0005435825251	18018	Business	199800.00
0005435825322	18018	Economy	66600.00
0005435825234	18018	Economy	66600.00
0005435825199	18018	Economy	66600.00
0005435825367	18018	Economy	73200.00
0005435825197	18018	Economy	73200.00
0005435825239	18018	Economy	66600.00
0005435825289	18018	Economy	66600.00
0005433416131	18018	Economy	66600.00
0005435825238	18018	Economy	66600.00
0005435825214	18018	Economy	66600.00
0005435825368	18018	Economy	66600.00
0005435825224	18018	Economy	66600.00
0005435825198	18018	Economy	66600.00
0005435825288	18018	Economy	66600.00
0005435825187	18018	Economy	66600.00
0005435825244	18018	Economy	66600.00
0005435825247	18018	Economy	66600.00
0005435825254	18018	Economy	66600.00
0005435825290	18018	Economy	66600.00
0005435825235	18018	Economy	66600.00
0005435825327	18018	Economy	66600.00
0005435825366	18018	Economy	66600.00
0005435825261	18018	Economy	66600.00
0005435825281	18018	Economy	66600.00
0005435825323	18018	Economy	66600.00
0005435825328	18018	Economy	66600.00
0005435825318	18018	Economy	66600.00
0005435825225	18018	Economy	66600.00
0005435243389	5622	Business	27800.00
0005435243441	5622	Business	27800.00
0005435243493	5622	Business	27800.00
0005432785363	5622	Business	27800.00
0005432785362	5622	Business	27800.00
0005435243499	5622	Business	27800.00
0005435243504	5622	Business	27800.00
0005435243485	5622	Business	27800.00
0005435243486	5622	Economy	9300.00
0005435476930	5622	Economy	9300.00
0005435243509	5622	Economy	9300.00
0005435243587	5622	Economy	9300.00
0005435476952	5622	Economy	10200.00
0005435243419	5622	Economy	9300.00
0005432785365	5622	Economy	9300.00
0005435476992	5622	Economy	9300.00
0005435243404	5622	Economy	9300.00
0005435243420	5622	Economy	9300.00
0005435243403	5622	Economy	9300.00
0005435476929	5622	Economy	9300.00
0005435243408	5622	Economy	9300.00
0005432785366	5622	Economy	9300.00
0005435243586	5622	Economy	9300.00
0005435243475	5622	Economy	9300.00
0005432785364	5622	Economy	9300.00
0005435243407	5622	Economy	9300.00
0005435243533	5622	Economy	9300.00
0005435243487	5622	Economy	9300.00
0005435476919	5622	Economy	9300.00
0005435243498	5622	Economy	9300.00
0005435243527	5622	Economy	9300.00
0005435476971	5622	Economy	9300.00
0005435243528	5622	Economy	9300.00
0005435243510	5622	Economy	9300.00
0005435243508	5622	Economy	9300.00
0005435243436	5622	Economy	9300.00
0005435243544	5622	Economy	9300.00
0005435243435	5622	Economy	9300.00
0005435243467	5622	Economy	9300.00
0005435476961	5622	Economy	9300.00
0005435243434	5622	Economy	9300.00
0005435243468	5622	Economy	9300.00
0005435476920	5622	Economy	9300.00
0005435476928	5622	Economy	9300.00
0005435243409	5622	Economy	9300.00
0005435476951	5622	Economy	9300.00
0005435243440	5622	Economy	9300.00
0005432785045	15353	Business	27800.00
0005432785086	15353	Business	27800.00
0005432784916	15353	Business	27800.00
0005432785029	15353	Business	27800.00
0005432784986	15353	Business	27800.00
0005432784760	15353	Business	27800.00
0005432785119	15353	Business	27800.00
0005432785065	15353	Business	27800.00
0005435243660	15353	Economy	9300.00
0005432785046	15353	Economy	9300.00
0005435243659	15353	Economy	9300.00
0005435477004	15353	Economy	9300.00
0005432784927	15353	Economy	9300.00
0005432784894	15353	Economy	9300.00
0005432784956	15353	Economy	9300.00
0005432784957	15353	Economy	10200.00
0005432784917	15353	Economy	10200.00
0005435477003	15353	Economy	10200.00
0005432784975	15353	Economy	9300.00
0005432785044	15353	Economy	9300.00
0005435477000	15353	Economy	9300.00
0005432785067	15353	Economy	9300.00
0005435477005	15353	Economy	9300.00
0005432785066	15353	Economy	9300.00
0005432785035	15353	Economy	9300.00
0005432785183	15353	Economy	9300.00
0005432784941	15353	Economy	9300.00
0005432784895	15353	Economy	9300.00
0005432784873	15353	Economy	9300.00
0005432785111	15353	Economy	9300.00
0005432785042	15353	Economy	9300.00
0005432785028	15353	Economy	9300.00
0005432784759	15353	Economy	9300.00
0005432785043	15353	Economy	9300.00
0005432784872	15353	Economy	9300.00
0005432784955	15353	Economy	9300.00
0005432784926	15353	Economy	9300.00
0005435243658	15353	Economy	9300.00
0005432784821	15353	Economy	9300.00
0005432785168	15353	Economy	9300.00
0005435243657	15353	Economy	9300.00
0005435477001	15353	Economy	9300.00
0005432785120	15353	Economy	9300.00
0005432785132	15353	Economy	9300.00
0005432785036	15353	Economy	9300.00
0005432784928	15353	Economy	9300.00
0005435477002	15353	Economy	9300.00
0005435243656	15353	Economy	9300.00
0005432784789	15353	Economy	9300.00
0005432785169	15353	Economy	9300.00
0005432785040	15353	Economy	9300.00
0005432785039	15353	Economy	9300.00
0005432785030	15353	Economy	9300.00
0005435851135	4344	Economy	6300.00
0005435851183	4344	Economy	6300.00
0005435851165	4344	Economy	6300.00
0005435851131	4344	Economy	6300.00
0005435851132	4344	Economy	6300.00
0005434463996	4344	Economy	6300.00
0005435851083	4344	Economy	6300.00
0005435851126	4344	Economy	6300.00
0005435851182	4344	Economy	6300.00
0005432848697	28886	Economy	6300.00
0005432848618	28886	Economy	6300.00
0005432848631	28886	Economy	6300.00
0005434463986	28886	Economy	6300.00
0005434461695	28886	Economy	6300.00
0005434463987	28886	Economy	6300.00
0005435851184	28886	Economy	6300.00
0005432848696	28886	Economy	6300.00
0005432848595	28886	Economy	6300.00
0005432848634	28886	Economy	6300.00
0005432848648	28886	Economy	6300.00
0005435851185	28886	Economy	6300.00
0005432848629	28886	Economy	6300.00
0005432848674	28886	Economy	6300.00
0005432848635	28886	Economy	6300.00
0005432848647	28886	Economy	6300.00
0005432848630	28886	Economy	6300.00
0005434926854	6282	Business	11900.00
0005435257467	6282	Business	11900.00
0005435257483	6282	Business	11900.00
0005434926858	6282	Business	11900.00
0005435257444	6282	Economy	4000.00
0005434926853	6282	Economy	4000.00
0005434926860	6282	Economy	4400.00
0005435257419	6282	Economy	4400.00
0005433497893	6282	Economy	4400.00
0005435257445	6282	Economy	4400.00
0005435257470	6282	Economy	4000.00
0005435257416	6282	Economy	4000.00
0005433497894	6282	Economy	4000.00
0005434926855	6282	Economy	4000.00
0005435257442	6282	Economy	4000.00
0005432075331	6282	Economy	4000.00
0005435257510	6282	Economy	4000.00
0005434926857	6282	Economy	4000.00
0005435257443	6282	Economy	4000.00
0005434926856	6282	Economy	4000.00
0005432075330	6282	Economy	4000.00
0005435257486	6282	Economy	4000.00
0005435257446	6282	Economy	4000.00
0005434444185	6282	Economy	4000.00
0005435257511	6282	Economy	4000.00
0005434926859	6282	Economy	4000.00
0005435257487	6282	Economy	4000.00
0005434444186	6282	Economy	4000.00
0005434444184	6282	Economy	4000.00
0005435257473	6282	Economy	4000.00
0005435257492	6282	Economy	4000.00
0005435257545	20331	Economy	4000.00
0005433497858	20329	Business	11900.00
0005433497810	20329	Business	11900.00
0005434926590	20329	Business	11900.00
0005434926515	20329	Business	11900.00
0005434926571	20329	Business	11900.00
0005434926576	20329	Business	11900.00
0005433497820	20329	Business	11900.00
0005434926588	20329	Business	11900.00
0005434926540	20329	Business	11900.00
0005433497796	20329	Business	11900.00
0005434926612	20329	Economy	4000.00
0005434926383	20329	Economy	4000.00
0005433497658	20329	Economy	4000.00
0005434926625	20329	Economy	4000.00
0005434926381	20329	Economy	4000.00
0005433497749	20329	Economy	4000.00
0005434926587	20329	Economy	4000.00
0005434926568	20329	Economy	4400.00
0005434926382	20329	Economy	4400.00
0005434926546	20329	Economy	4400.00
0005434926476	20329	Economy	4400.00
0005434443982	20329	Economy	4400.00
0005433497830	20329	Economy	4000.00
0005433497823	20329	Economy	4000.00
0005434926386	20329	Economy	4000.00
0005434926445	20329	Economy	4000.00
0005434926545	20329	Economy	4000.00
0005433497782	20329	Economy	4000.00
0005434444048	20329	Economy	4000.00
0005434926613	20329	Economy	4000.00
0005434926611	20329	Economy	4000.00
0005434926583	20329	Economy	4000.00
0005434926449	20329	Economy	4000.00
0005434444092	20329	Economy	4000.00
0005434926522	20329	Economy	4000.00
0005434444071	20329	Economy	4000.00
0005434926517	20329	Economy	4000.00
0005434926557	20329	Economy	4000.00
0005434926567	20329	Economy	4000.00
0005434926369	20329	Economy	4000.00
0005434444089	20329	Economy	4000.00
0005434926551	20329	Economy	4000.00
0005434926614	20329	Economy	4000.00
0005434926507	20329	Economy	4000.00
0005434926427	20329	Economy	4000.00
0005433497809	20329	Economy	4000.00
0005434926446	20329	Economy	4000.00
0005434444076	20329	Economy	4000.00
0005434444070	20329	Economy	4000.00
0005434926450	20329	Economy	4000.00
0005433497746	20329	Economy	4000.00
0005434926495	20329	Economy	4000.00
0005433497853	20329	Economy	4000.00
0005433497724	20329	Economy	4000.00
0005434926508	20329	Economy	4000.00
0005434444112	20329	Economy	4000.00
0005434926509	20329	Economy	4000.00
0005434926516	20329	Economy	4000.00
0005434926542	20329	Economy	4000.00
0005434926539	20329	Economy	4000.00
0005434926616	20329	Economy	4000.00
0005433497857	20329	Economy	4000.00
0005434926589	20329	Economy	4000.00
0005434444137	20329	Economy	4000.00
0005433497723	20329	Economy	4000.00
0005434926574	20329	Economy	4000.00
0005434926594	20329	Economy	4000.00
0005434444049	20329	Economy	4000.00
0005433497656	20329	Economy	4000.00
0005434444108	20329	Economy	4000.00
0005433497865	20329	Economy	4000.00
0005433497609	20329	Economy	4000.00
0005434444098	20329	Economy	4000.00
0005433497833	20329	Economy	4000.00
0005434926447	20329	Economy	4000.00
0005434926429	20329	Economy	4000.00
0005434926595	20329	Economy	4000.00
0005434926518	20329	Economy	4000.00
0005434926584	20329	Economy	4000.00
0005433497822	20329	Economy	4000.00
0005433497831	20329	Economy	4000.00
0005434444158	20329	Economy	4000.00
0005432785080	12203	Business	41200.00
0005432785047	12203	Business	41200.00
0005435243664	12203	Business	41200.00
0005432785192	12203	Business	41200.00
0005432785122	12203	Business	41200.00
0005432784998	12203	Business	41200.00
0005432785033	12203	Business	41200.00
0005432785153	12203	Business	41200.00
0005432784929	12203	Economy	13700.00
0005432785001	12203	Economy	13700.00
0005432785003	12203	Economy	13700.00
0005432785182	12203	Economy	13700.00
0005432785307	12203	Economy	13700.00
0005432785193	12203	Economy	13700.00
0005432784915	12203	Economy	15100.00
0005435243662	12203	Economy	15100.00
0005432785228	12203	Economy	13700.00
0005432785164	12203	Economy	13700.00
0005432785074	12203	Economy	13700.00
0005432785034	12203	Economy	13700.00
0005432785227	12203	Economy	13700.00
0005432784999	12203	Economy	13700.00
0005432785032	12203	Economy	13700.00
0005432785123	12203	Economy	13700.00
0005432785079	12203	Economy	13700.00
0005432784931	12203	Economy	13700.00
0005432785048	12203	Economy	13700.00
0005432785073	12203	Economy	13700.00
0005432784907	12203	Economy	13700.00
0005432785077	12203	Economy	13700.00
0005432785176	12203	Economy	13700.00
0005432784930	12203	Economy	13700.00
0005432785177	12203	Economy	13700.00
0005432785059	12203	Economy	13700.00
0005432785152	12203	Economy	13700.00
0005432785063	12203	Economy	13700.00
0005432785144	12203	Economy	13700.00
0005435243661	12203	Economy	13700.00
0005432785170	12203	Economy	13700.00
0005432785151	12203	Economy	13700.00
0005432784997	12203	Economy	13700.00
0005432785076	12203	Economy	13700.00
0005435243663	12203	Economy	13700.00
0005432785104	12203	Economy	13700.00
0005432785207	12203	Economy	13700.00
0005432785058	12203	Economy	13700.00
0005435243471	15431	Business	41200.00
0005435243518	15431	Business	41200.00
0005432785355	15431	Business	41200.00
0005435243406	15431	Business	41200.00
0005432785356	15431	Economy	13700.00
0005435243443	15431	Economy	13700.00
0005432785357	15431	Economy	13700.00
0005435243583	15431	Economy	15100.00
0005435243584	15431	Economy	15100.00
0005432785359	15431	Economy	15100.00
0005435243430	15431	Economy	13700.00
0005435243580	15431	Economy	13700.00
0005435243472	15431	Economy	13700.00
0005435243330	15431	Economy	13700.00
0005435243492	15431	Economy	13700.00
0005432785358	15431	Economy	13700.00
0005435243453	15431	Economy	13700.00
0005435243517	15431	Economy	13700.00
0005435243429	15431	Economy	13700.00
0005435243410	15431	Economy	13700.00
0005435243452	15431	Economy	13700.00
0005435243416	15431	Economy	13700.00
0005435243391	15431	Economy	13700.00
0005435243537	15431	Economy	13700.00
0005435243399	15431	Economy	13700.00
0005435243539	15431	Economy	13700.00
0005432785360	15431	Economy	13700.00
0005435243502	15431	Economy	13700.00
0005435243415	15431	Economy	13700.00
0005435243445	15431	Economy	13700.00
0005432785354	15431	Economy	13700.00
0005435243318	15431	Economy	13700.00
0005432785361	15431	Economy	13700.00
0005435243579	15431	Economy	13700.00
0005435243538	15431	Economy	13700.00
0005435914211	10091	Business	49700.00
0005434880484	10091	Business	49700.00
0005434880350	10091	Business	49700.00
0005434880502	10091	Business	49700.00
0005434880717	10091	Business	49700.00
0005434880424	10091	Business	49700.00
0005434880338	10091	Business	49700.00
0005434880398	10091	Business	49700.00
0005434880351	10091	Business	49700.00
0005434880503	10091	Business	49700.00
0005434880748	10091	Business	49700.00
0005434880742	10091	Business	49700.00
0005434880277	10091	Business	49700.00
0005434880335	10091	Business	49700.00
0005434880378	10091	Business	49700.00
0005434880018	10091	Business	49700.00
0005434880497	10091	Business	49700.00
0005434880131	10091	Economy	16600.00
0005435914213	10091	Economy	16600.00
0005434880336	10091	Economy	16600.00
0005434880409	10091	Economy	16600.00
0005434880148	10091	Economy	16600.00
0005434880483	10091	Economy	16600.00
0005434880332	10091	Economy	16600.00
0005435914212	10091	Economy	16600.00
0005434879964	10091	Economy	16600.00
0005434880657	10091	Economy	16600.00
0005434880747	10091	Economy	18200.00
0005434880614	10091	Economy	18200.00
0005435914215	10091	Economy	18200.00
0005434880594	10091	Economy	16600.00
0005434880679	10091	Economy	18200.00
0005434880762	10091	Economy	16600.00
0005434879965	10091	Economy	16600.00
0005434880440	10091	Economy	16600.00
0005434880158	10091	Economy	16600.00
0005435914214	10091	Economy	16600.00
0005434880274	10091	Economy	16600.00
0005434758944	10091	Economy	16600.00
0005434880485	10091	Economy	16600.00
0005434880486	10091	Economy	16600.00
0005434880471	10091	Economy	16600.00
0005434880291	10091	Economy	16600.00
0005434880535	10091	Economy	16600.00
0005434880570	10091	Economy	16600.00
0005434880672	10091	Economy	16600.00
0005434880473	10091	Economy	16600.00
0005434880572	10091	Economy	16600.00
0005434880474	10091	Economy	16600.00
0005434880612	10091	Economy	16600.00
0005434880511	10091	Economy	16600.00
0005434880599	10091	Economy	16600.00
0005434880390	10091	Economy	16600.00
0005434880655	10091	Economy	16600.00
0005434880613	10091	Economy	16600.00
0005434880666	10091	Economy	16600.00
0005434880319	10091	Economy	16600.00
0005434880709	10091	Economy	16600.00
0005434880554	10091	Economy	16600.00
0005434880393	10091	Economy	16600.00
0005434880680	10091	Economy	16600.00
0005434879779	10091	Economy	16600.00
0005434880707	10091	Economy	16600.00
0005434880472	10091	Economy	16600.00
0005434880130	10091	Economy	16600.00
0005434880718	10091	Economy	16600.00
0005434880617	10091	Economy	16600.00
0005434880337	10091	Economy	16600.00
0005434880528	10091	Economy	16600.00
0005434880656	10091	Economy	16600.00
0005434758952	10091	Economy	16600.00
0005434880070	10091	Economy	16600.00
0005434880084	10091	Economy	16600.00
0005434880593	10091	Economy	16600.00
0005434880507	10091	Economy	16600.00
0005434880210	10091	Economy	16600.00
0005434880333	10091	Economy	16600.00
0005434879780	10091	Economy	16600.00
0005434880819	10091	Economy	16600.00
0005434880555	10091	Economy	16600.00
0005434758951	10091	Economy	16600.00
0005434880253	10091	Economy	16600.00
0005434880524	10091	Economy	16600.00
0005434880547	10091	Economy	16600.00
0005434880331	10091	Economy	16600.00
0005434880531	10091	Economy	16600.00
0005434880910	10091	Economy	16600.00
0005434880334	10091	Economy	16600.00
0005434880631	10091	Economy	16600.00
0005434880252	10091	Economy	16600.00
0005434880611	10091	Economy	16600.00
0005434880658	10091	Economy	16600.00
0005434880251	10091	Economy	16600.00
0005434880372	10091	Economy	16600.00
0005434880417	10091	Economy	16600.00
0005434879955	10091	Economy	16600.00
0005434880909	10091	Economy	16600.00
0005435914029	14627	Business	49700.00
0005435914057	14627	Business	49700.00
0005434910172	14627	Business	49700.00
0005435914123	14627	Business	49700.00
0005435914092	14627	Business	49700.00
0005435914037	14627	Business	49700.00
0005435914073	14627	Business	49700.00
0005434880979	14627	Business	49700.00
0005434758963	14627	Business	49700.00
0005434910169	14627	Economy	16600.00
0005435914081	14627	Economy	16600.00
0005434910168	14627	Economy	16600.00
0005434880985	14627	Economy	16600.00
0005434880980	14627	Economy	16600.00
0005435914085	14627	Economy	16600.00
0005435914109	14627	Economy	16600.00
0005435914136	14627	Economy	18200.00
0005434758964	14627	Economy	16600.00
0005435914093	14627	Economy	16600.00
0005434910171	14627	Economy	16600.00
0005434910166	14627	Economy	16600.00
0005435914122	14627	Economy	16600.00
0005435914038	14627	Economy	16600.00
0005435914168	14627	Economy	16600.00
0005435914089	14627	Economy	16600.00
0005435914087	14627	Economy	16600.00
0005434910157	14627	Economy	16600.00
0005434880983	14627	Economy	16600.00
0005435914070	14627	Economy	16600.00
0005435914042	14627	Economy	16600.00
0005435914111	14627	Economy	16600.00
0005434880981	14627	Economy	16600.00
0005435914137	14627	Economy	16600.00
0005435914084	14627	Economy	16600.00
0005434880984	14627	Economy	16600.00
0005435914110	14627	Economy	16600.00
0005435914090	14627	Economy	16600.00
0005435914045	14627	Economy	16600.00
0005435914086	14627	Economy	16600.00
0005435914071	14627	Economy	16600.00
0005434880982	14627	Economy	16600.00
0005435914129	14627	Economy	16600.00
0005434910170	14627	Economy	16600.00
0005434252186	9222	Economy	22400.00
0005434252196	9222	Economy	22400.00
0005434252195	9222	Economy	20300.00
0005434252143	9222	Economy	20300.00
0005434252227	9222	Economy	20300.00
0005434252185	9222	Economy	20300.00
0005434252201	9222	Economy	20300.00
0005434252214	9222	Economy	20300.00
0005434252194	9222	Economy	20300.00
0005434252225	9222	Economy	20300.00
0005434252226	9222	Economy	20300.00
0005434252200	9222	Economy	20300.00
0005435660432	24657	Economy	22400.00
0005435660414	24657	Economy	20300.00
0005435660372	24657	Economy	20300.00
0005435660441	24657	Economy	20300.00
0005435933567	24657	Economy	20300.00
0005435660415	24657	Economy	20300.00
0005435660440	24657	Economy	20300.00
0005435660457	24657	Economy	20300.00
0005435660380	24657	Economy	20300.00
0005435660405	24657	Economy	20300.00
0005435660361	24657	Economy	20300.00
0005435660398	24657	Economy	20300.00
0005432967592	2819	Business	33000.00
0005433690992	2819	Business	33000.00
0005432967455	2819	Business	33000.00
0005432967523	2819	Economy	11000.00
0005432967595	2819	Economy	12100.00
0005432967449	2819	Economy	12100.00
0005432967587	2819	Economy	12100.00
0005432967561	2819	Economy	11000.00
0005433681968	2819	Economy	11000.00
0005432967591	2819	Economy	11000.00
0005432967588	2819	Economy	11000.00
0005432967554	2819	Economy	11000.00
0005433681967	2819	Economy	11000.00
0005432967615	2819	Economy	11000.00
0005432967570	2819	Economy	11000.00
0005433681971	2819	Economy	11000.00
0005432967576	2819	Economy	11000.00
0005432967482	2819	Economy	11000.00
0005432967571	2819	Economy	11000.00
0005432967524	2819	Economy	11000.00
0005432967456	2819	Economy	11000.00
0005433681970	2819	Economy	11000.00
0005432967586	2819	Economy	11000.00
0005433681969	2819	Economy	11000.00
0005433690987	2819	Economy	11000.00
0005432967555	2819	Economy	11000.00
0005432967506	2819	Economy	11000.00
0005432967575	2819	Economy	11000.00
0005433690993	2819	Economy	11000.00
0005432967557	2819	Economy	11000.00
0005433681619	29167	Business	33000.00
0005433681774	29167	Business	33000.00
0005433684471	29167	Business	33000.00
0005433681669	29167	Business	33000.00
0005433681803	29167	Business	33000.00
0005433681699	29167	Business	33000.00
0005433681800	29167	Business	33000.00
0005433681662	29167	Business	33000.00
0005433681712	29167	Business	33000.00
0005433681663	29167	Economy	11000.00
0005433681723	29167	Economy	11000.00
0005433681854	29167	Economy	11000.00
0005433681523	29167	Economy	11000.00
0005433681484	29167	Economy	11000.00
0005433681901	29167	Economy	12100.00
0005433681706	29167	Economy	12100.00
0005433681801	29167	Economy	12100.00
0005433681595	29167	Economy	12100.00
0005433681802	29167	Economy	11000.00
0005433681799	29167	Economy	11000.00
0005433681754	29167	Economy	11000.00
0005433681798	29167	Economy	11000.00
0005433681824	29167	Economy	11000.00
0005433681768	29167	Economy	11000.00
0005432967681	29167	Economy	11000.00
0005433681483	29167	Economy	11000.00
0005432967682	29167	Economy	11000.00
0005433681915	29167	Economy	11000.00
0005433681594	29167	Economy	11000.00
0005433681914	29167	Economy	11000.00
0005433681524	29167	Economy	11000.00
0005433681732	29167	Economy	11000.00
0005433681751	29167	Economy	11000.00
0005433681574	29167	Economy	11000.00
0005433681856	29167	Economy	11000.00
0005433681568	29167	Economy	11000.00
0005433681825	29167	Economy	11000.00
0005433681715	29167	Economy	11000.00
0005433681885	29167	Economy	11000.00
0005433681752	29167	Economy	11000.00
0005432967684	29167	Economy	11000.00
0005433687759	29167	Economy	11000.00
0005433690969	29167	Economy	11000.00
0005433681652	29167	Economy	11000.00
0005433681884	29167	Economy	11000.00
0005433681707	29167	Economy	11000.00
0005433681860	29167	Economy	11000.00
0005433681668	29167	Economy	11000.00
0005433681575	29167	Economy	11000.00
0005433681674	29167	Economy	11000.00
0005433681855	29167	Economy	11000.00
0005432967683	29167	Economy	11000.00
0005433681482	29167	Economy	11000.00
0005433681733	29167	Economy	11000.00
0005433681879	29167	Economy	11000.00
0005433681878	29167	Economy	11000.00
0005433687754	29167	Economy	11000.00
0005433687760	29167	Economy	11000.00
0005433681755	29167	Economy	11000.00
0005433687737	29167	Economy	11000.00
0005433681629	29167	Economy	11000.00
0005433681703	29167	Economy	11000.00
0005433681698	29167	Economy	11000.00
0005433681680	29167	Economy	11000.00
0005433681667	29167	Economy	11000.00
0005433684466	29167	Economy	11000.00
0005434152837	9283	Business	132900.00
0005434152839	9283	Business	132900.00
0005434272229	9283	Business	132900.00
0005435854089	9283	Business	132900.00
0005435983721	9283	Business	132900.00
0005434163849	9283	Business	132900.00
0005435856334	9283	Economy	44300.00
0005433616820	9283	Economy	44300.00
0005433616819	9283	Economy	44300.00
0005434269154	9283	Economy	44300.00
0005435856343	9283	Economy	44300.00
0005434163852	9283	Economy	44300.00
0005433616818	9283	Economy	44300.00
0005435856333	9283	Economy	44300.00
0005434272228	9283	Economy	44300.00
0005434152838	9283	Economy	44300.00
0005433634821	9283	Economy	44300.00
0005434163840	9283	Economy	48700.00
0005434153572	9283	Economy	44300.00
0005434269156	9283	Economy	44300.00
0005434163804	9283	Economy	44300.00
0005434163839	9283	Economy	44300.00
0005433634822	9283	Economy	44300.00
0005434153569	9283	Economy	44300.00
0005434163848	9283	Economy	44300.00
0005433616817	9283	Economy	44300.00
0005435856332	9283	Economy	44300.00
0005433616570	25249	Business	132900.00
0005432751582	25249	Business	132900.00
0005433634648	25249	Business	132900.00
0005432751596	25249	Business	132900.00
0005433616685	25249	Business	132900.00
0005434152851	25249	Business	132900.00
0005433616581	25249	Business	132900.00
0005434151816	25249	Business	132900.00
0005433634512	25249	Business	132900.00
0005433616422	25249	Business	132900.00
0005433616418	25249	Business	132900.00
0005434151818	25249	Business	132900.00
0005433616168	25249	Business	132900.00
0005433634519	25249	Business	132900.00
0005433616407	25249	Business	132900.00
0005433616627	25249	Business	132900.00
0005433634502	25249	Business	132900.00
0005432751604	25249	Business	132900.00
0005433616396	25249	Business	132900.00
0005433616424	25249	Business	132900.00
0005433634731	25249	Business	132900.00
0005433616416	25249	Business	132900.00
0005433578156	25249	Business	132900.00
0005433634543	25249	Economy	48700.00
0005433634662	25249	Business	132900.00
0005433616409	25249	Economy	48700.00
0005433634702	25249	Economy	48700.00
0005433634615	25249	Economy	48700.00
0005433634645	25249	Economy	48700.00
0005433616236	25249	Economy	48700.00
0005432751591	25249	Economy	44300.00
0005433616374	25249	Economy	44300.00
0005433634797	25249	Economy	44300.00
0005433634535	25249	Economy	44300.00
0005432751590	25249	Economy	44300.00
0005433616122	25249	Economy	44300.00
0005433616184	25249	Economy	44300.00
0005433634644	25249	Economy	44300.00
0005432751601	25249	Economy	44300.00
0005433616329	25249	Economy	44300.00
0005433634330	25249	Economy	44300.00
0005433616296	25249	Economy	44300.00
0005433616285	25249	Economy	44300.00
0005433616337	25249	Economy	44300.00
0005433616592	25249	Economy	44300.00
0005433616571	25249	Economy	44300.00
0005433616433	25249	Economy	44300.00
0005432751592	25249	Economy	44300.00
0005434151819	25249	Economy	44300.00
0005433616123	25249	Economy	44300.00
0005432755142	25249	Economy	44300.00
0005433616066	25249	Economy	44300.00
0005433616343	25249	Economy	44300.00
0005433616352	25249	Economy	44300.00
0005433634329	25249	Economy	44300.00
0005433616375	25249	Economy	44300.00
0005433616474	25249	Economy	44300.00
0005433616391	25249	Economy	44300.00
0005433616021	25249	Economy	44300.00
0005433616529	25249	Economy	44300.00
0005433616516	25249	Economy	44300.00
0005433634627	25249	Economy	44300.00
0005433616419	25249	Economy	44300.00
0005433616489	25249	Economy	44300.00
0005432751587	25249	Economy	44300.00
0005433634585	25249	Economy	44300.00
0005433616738	25249	Economy	44300.00
0005433616490	25249	Economy	44300.00
0005433616408	25249	Economy	44300.00
0005433634691	25249	Economy	44300.00
0005433578157	25249	Economy	44300.00
0005433616582	25249	Economy	44300.00
0005433634631	25249	Economy	44300.00
0005433634544	25249	Economy	44300.00
0005433616023	25249	Economy	44300.00
0005433578094	25249	Economy	44300.00
0005433616432	25249	Economy	44300.00
0005433634790	25249	Economy	44300.00
0005434272238	25249	Economy	48700.00
0005432751580	25249	Economy	48700.00
0005432755144	25249	Economy	48700.00
0005433634646	25249	Economy	48700.00
0005433634616	25249	Economy	44300.00
0005432751607	25249	Economy	44300.00
0005433634674	25249	Economy	44300.00
0005433634501	25249	Economy	44300.00
0005432751588	25249	Economy	48700.00
0005433634586	25249	Economy	44300.00
0005433578187	25249	Economy	44300.00
0005433616219	25249	Economy	44300.00
0005432755125	25249	Economy	44300.00
0005432755141	25249	Economy	44300.00
0005433616538	25249	Economy	44300.00
0005433616065	25249	Economy	44300.00
0005433616381	25249	Economy	44300.00
0005433616488	25249	Economy	44300.00
0005433634643	25249	Economy	44300.00
0005434273136	25249	Economy	44300.00
0005432751600	25249	Economy	44300.00
0005433578178	25249	Economy	44300.00
0005433634583	25249	Economy	44300.00
0005433616445	25249	Economy	44300.00
0005433634618	25249	Economy	44300.00
0005433616245	25249	Economy	44300.00
0005432755131	25249	Economy	44300.00
0005432751586	25249	Economy	44300.00
0005432751602	25249	Economy	44300.00
0005433578086	25249	Economy	44300.00
0005433634750	25249	Economy	44300.00
0005432751595	25249	Economy	44300.00
0005432751605	25249	Economy	44300.00
0005432751606	25249	Economy	44300.00
0005433616383	25249	Economy	44300.00
0005433616420	25249	Economy	44300.00
0005433616284	25249	Economy	44300.00
0005432751589	25249	Economy	44300.00
0005433616543	25249	Economy	44300.00
0005433616656	25249	Economy	44300.00
0005433616528	25249	Economy	44300.00
0005433634554	25249	Economy	44300.00
0005433616344	25249	Economy	44300.00
0005434151820	25249	Economy	44300.00
0005433616380	25249	Economy	44300.00
0005433616406	25249	Economy	44300.00
0005432751617	25249	Economy	44300.00
0005432751615	25249	Economy	44300.00
0005432755143	25249	Economy	44300.00
0005433634642	25249	Economy	44300.00
0005432755137	25249	Economy	44300.00
0005434151817	25249	Economy	44300.00
0005433634584	25249	Economy	44300.00
0005432751581	25249	Economy	44300.00
0005433634542	25249	Economy	44300.00
0005433616256	25249	Economy	44300.00
0005433634766	25249	Economy	44300.00
0005433616382	25249	Economy	44300.00
0005432755132	25249	Economy	44300.00
0005433616244	25249	Economy	44300.00
0005433616022	25249	Economy	44300.00
0005432751614	25249	Economy	44300.00
0005433634500	25249	Economy	44300.00
0005433634617	25249	Economy	44300.00
0005433634765	25249	Economy	44300.00
0005435856294	4225	Business	193100.00
0005435856310	4225	Business	193100.00
0005435947635	4225	Business	193100.00
0005435787395	4225	Business	193100.00
0005435787399	4225	Business	193100.00
0005435787409	4225	Economy	64400.00
0005435987060	4225	Economy	64400.00
0005435947610	4225	Economy	64400.00
0005435787408	4225	Economy	64400.00
0005435947545	4225	Economy	64400.00
0005435787396	4225	Economy	64400.00
0005435854080	4225	Economy	64400.00
0005435947609	4225	Economy	64400.00
0005435947556	4225	Economy	64400.00
0005435856296	4225	Economy	64400.00
0005435947595	4225	Economy	64400.00
0005435947629	4225	Economy	64400.00
0005435947628	4225	Economy	64400.00
0005435947596	4225	Economy	64400.00
0005435947578	4225	Economy	64400.00
0005435856316	4225	Economy	64400.00
0005432571418	4225	Economy	64400.00
0005435987062	4225	Economy	64400.00
0005435947611	4225	Economy	64400.00
0005435947636	4225	Economy	64400.00
0005435856315	4225	Economy	64400.00
0005435787403	4225	Economy	64400.00
0005435987061	4225	Economy	64400.00
0005435856297	4225	Economy	64400.00
0005435856311	4225	Economy	64400.00
0005435947612	4225	Economy	64400.00
0005435787400	4225	Economy	64400.00
0005435986952	26599	Business	193100.00
0005435986922	26599	Business	193100.00
0005435986967	26599	Business	193100.00
0005435987010	26599	Business	193100.00
0005435477031	26599	Economy	70800.00
0005435986946	26599	Economy	64400.00
0005435986921	26599	Economy	64400.00
0005435856363	26599	Economy	64400.00
0005435477029	26599	Economy	64400.00
0005435987011	26599	Economy	64400.00
0005435986944	26599	Economy	64400.00
0005435986994	26599	Economy	64400.00
0005435477026	26599	Economy	64400.00
0005435986919	26599	Economy	64400.00
0005435986972	26599	Economy	64400.00
0005435477028	26599	Economy	64400.00
0005435947683	26599	Economy	64400.00
0005435986945	26599	Economy	70800.00
0005435986990	26599	Economy	64400.00
0005435947682	26599	Economy	64400.00
0005435986993	26599	Economy	64400.00
0005435986959	26599	Economy	64400.00
0005435477027	26599	Economy	64400.00
0005435986963	26599	Economy	64400.00
0005435986991	26599	Economy	64400.00
0005435477030	26599	Economy	64400.00
0005434326045	354	Business	21500.00
0005432949521	354	Business	21500.00
0005433134230	354	Business	21500.00
0005434088041	354	Business	21500.00
0005432949396	354	Business	21500.00
0005432949260	354	Business	21500.00
0005433570971	354	Business	21500.00
0005433129380	354	Business	21500.00
0005432949437	354	Business	21500.00
0005433075405	354	Business	21500.00
0005432949465	354	Business	21500.00
0005432949545	354	Business	21500.00
0005433570970	354	Business	21500.00
0005433570977	354	Business	21500.00
0005433570972	354	Business	21500.00
0005432949487	354	Business	21500.00
0005433129381	354	Business	21500.00
0005432949418	354	Business	21500.00
0005432949474	354	Business	21500.00
0005433075395	354	Economy	7900.00
0005433075393	354	Economy	7900.00
0005434326043	354	Economy	7900.00
0005432949394	354	Economy	7200.00
0005432949439	354	Economy	7200.00
0005433075442	354	Economy	7200.00
0005432949404	354	Economy	7200.00
0005434088040	354	Economy	7200.00
0005432949438	354	Economy	7200.00
0005433075382	354	Economy	7200.00
0005433570976	354	Economy	7200.00
0005432949419	354	Economy	7200.00
0005433570966	354	Economy	7200.00
0005433075304	354	Economy	7200.00
0005433075406	354	Economy	7200.00
0005433075412	354	Economy	7200.00
0005432949312	354	Economy	7200.00
0005432949512	354	Economy	7200.00
0005433075443	354	Economy	7200.00
0005434326044	354	Economy	7200.00
0005433570967	354	Economy	7200.00
0005433129408	354	Economy	7200.00
0005433075364	354	Economy	7200.00
0005432949364	354	Economy	7200.00
0005432949493	354	Economy	7200.00
0005433570979	354	Economy	7200.00
0005432949473	354	Economy	7200.00
0005432949547	354	Economy	7200.00
0005434326046	354	Economy	7200.00
0005434088056	354	Economy	7200.00
0005432949427	354	Economy	7200.00
0005432949443	354	Economy	7200.00
0005433075370	354	Economy	7200.00
0005432949385	354	Economy	7200.00
0005432949336	354	Economy	7200.00
0005433129382	354	Economy	7900.00
0005432949300	354	Economy	7900.00
0005433570975	354	Economy	7900.00
0005434088043	354	Economy	7200.00
0005432949486	354	Economy	7200.00
0005433075275	354	Economy	7900.00
0005433570978	354	Economy	7200.00
0005433075363	354	Economy	7200.00
0005434088058	354	Economy	7200.00
0005433075375	354	Economy	7200.00
0005432949455	354	Economy	7200.00
0005434088042	354	Economy	7200.00
0005432949450	354	Economy	7200.00
0005433134253	354	Economy	7200.00
0005432949432	354	Economy	7200.00
0005432949259	354	Economy	7200.00
0005432949361	354	Economy	7200.00
0005432949350	354	Economy	7200.00
0005432949429	354	Economy	7200.00
0005433570980	354	Economy	7200.00
0005432949384	354	Economy	7200.00
0005433134243	354	Economy	7200.00
0005433075378	354	Economy	7200.00
0005433570973	354	Economy	7200.00
0005433134244	354	Economy	7200.00
0005432949433	354	Economy	7200.00
0005432949420	354	Economy	7200.00
0005433570974	354	Economy	7200.00
0005433075403	354	Economy	7200.00
0005433570969	354	Economy	7200.00
0005433075394	354	Economy	7200.00
0005433129409	354	Economy	7200.00
0005432949227	354	Economy	7200.00
0005432949466	354	Economy	7200.00
0005433570968	354	Economy	7200.00
0005434088057	354	Economy	7200.00
0005432949360	354	Economy	7200.00
0005434326042	354	Economy	7200.00
0005432949453	354	Economy	7200.00
0005432949475	354	Economy	7200.00
0005433075407	354	Economy	7200.00
0005433075274	354	Economy	7200.00
0005433129377	354	Economy	7200.00
0005434087948	11599	Business	21500.00
0005433570427	11599	Business	21500.00
0005433570450	11599	Business	21500.00
0005432949682	11599	Business	21500.00
0005433570205	11599	Business	21500.00
0005433570517	11599	Business	21500.00
0005433570247	11599	Business	21500.00
0005433570418	11599	Business	21500.00
0005433570355	11599	Business	21500.00
0005432192415	11599	Business	21500.00
0005433570712	11599	Business	21500.00
0005434087949	11599	Business	21500.00
0005433570202	11599	Business	21500.00
0005432949684	11599	Business	21500.00
0005434087929	11599	Business	21500.00
0005432949685	11599	Business	21500.00
0005434087976	11599	Business	21500.00
0005433570481	11599	Business	21500.00
0005433929885	11599	Business	21500.00
0005433570612	11599	Business	21500.00
0005433570452	11599	Business	21500.00
0005433570327	11599	Business	21500.00
0005433570416	11599	Economy	7900.00
0005434087943	11599	Economy	7900.00
0005433134264	11599	Economy	7900.00
0005433570030	11599	Economy	7900.00
0005432949688	11599	Economy	7200.00
0005433570248	11599	Economy	7200.00
0005433075548	11599	Economy	7200.00
0005433570673	11599	Economy	7200.00
0005433570268	11599	Economy	7200.00
0005433570389	11599	Economy	7200.00
0005433570454	11599	Economy	7200.00
0005432949683	11599	Economy	7200.00
0005433570256	11599	Economy	7200.00
0005433570257	11599	Economy	7200.00
0005432949692	11599	Economy	7200.00
0005433570326	11599	Economy	7200.00
0005433570516	11599	Economy	7200.00
0005433570521	11599	Economy	7200.00
0005433570546	11599	Economy	7200.00
0005432949687	11599	Economy	7200.00
0005433570520	11599	Economy	7200.00
0005433570492	11599	Economy	7200.00
0005433075547	11599	Economy	7200.00
0005433570417	11599	Economy	7200.00
0005433570578	11599	Economy	7200.00
0005433929884	11599	Economy	7200.00
0005433570206	11599	Economy	7200.00
0005433570302	11599	Economy	7200.00
0005434087938	11599	Economy	7200.00
0005433570282	11599	Economy	7200.00
0005433570519	11599	Economy	7200.00
0005433570489	11599	Economy	7200.00
0005433570269	11599	Economy	7200.00
0005433570599	11599	Economy	7200.00
0005433570235	11599	Economy	7200.00
0005433570561	11599	Economy	7200.00
0005433570386	11599	Economy	7200.00
0005433570422	11599	Economy	7200.00
0005433570594	11599	Economy	7900.00
0005433570265	11599	Economy	7900.00
0005432949690	11599	Economy	7200.00
0005433570421	11599	Economy	7200.00
0005433570354	11599	Economy	7200.00
0005433570545	11599	Economy	7200.00
0005433570171	11599	Economy	7200.00
0005432949681	11599	Economy	7200.00
0005433570564	11599	Economy	7200.00
0005433570262	11599	Economy	7200.00
0005433570359	11599	Economy	7200.00
0005433570312	11599	Economy	7200.00
0005433570662	11599	Economy	7200.00
0005433570560	11599	Economy	7200.00
0005433570388	11599	Economy	7200.00
0005432949680	11599	Economy	7200.00
0005433570753	11599	Economy	7200.00
0005433570357	11599	Economy	7200.00
0005433570281	11599	Economy	7200.00
0005433570318	11599	Economy	7200.00
0005433570465	11599	Economy	7200.00
0005433570165	11599	Economy	7200.00
0005433570583	11599	Economy	7200.00
0005433570609	11599	Economy	7200.00
0005433570477	11599	Economy	7200.00
0005433570376	11599	Economy	7200.00
0005433570451	11599	Economy	7200.00
0005433569960	11599	Economy	7200.00
0005432949686	11599	Economy	7200.00
0005433570317	11599	Economy	7200.00
0005432949691	11599	Economy	7200.00
0005432949689	11599	Economy	7200.00
0005433570035	11599	Economy	7200.00
0005433570390	11599	Economy	7200.00
0005433570387	11599	Economy	7200.00
0005433570595	11599	Economy	7200.00
0005433570356	11599	Economy	7200.00
0005433131841	11599	Economy	7200.00
0005434733073	10018	Economy	6300.00
0005434733076	10018	Economy	6300.00
0005433817553	13902	Economy	6300.00
0005433817552	13902	Economy	6300.00
0005433817549	13902	Economy	6300.00
0005433817550	13902	Economy	6300.00
0005433435252	2327	Business	184500.00
0005433435315	2327	Business	184500.00
0005432985891	2327	Business	184500.00
0005433435371	2327	Business	184500.00
0005432985817	2327	Business	184500.00
0005432985641	2327	Business	184500.00
0005433755886	2327	Business	184500.00
0005432985955	2327	Business	184500.00
0005433435425	2327	Business	184500.00
0005432985975	2327	Economy	67700.00
0005432985842	2327	Economy	61500.00
0005433435313	2327	Economy	61500.00
0005433435378	2327	Economy	61500.00
0005433435326	2327	Economy	61500.00
0005434376162	2327	Economy	61500.00
0005432985796	2327	Economy	61500.00
0005432985965	2327	Economy	61500.00
0005433435340	2327	Economy	61500.00
0005432985976	2327	Economy	61500.00
0005432985888	2327	Economy	61500.00
0005432869659	2327	Economy	61500.00
0005433435314	2327	Economy	61500.00
0005432985865	2327	Economy	61500.00
0005432869699	2327	Economy	61500.00
0005432985841	2327	Economy	61500.00
0005432226241	2327	Economy	61500.00
0005432869681	2327	Economy	61500.00
0005433435301	2327	Economy	61500.00
0005433755881	2327	Economy	61500.00
0005433435341	2327	Economy	61500.00
0005434731274	2327	Economy	61500.00
0005432869700	2327	Economy	61500.00
0005432985844	2327	Economy	61500.00
0005434376160	2327	Economy	61500.00
0005433435316	2327	Economy	61500.00
0005433435312	2327	Economy	61500.00
0005433755877	2327	Economy	61500.00
0005434731269	2327	Economy	61500.00
0005433755884	2327	Economy	61500.00
0005433755879	2327	Economy	61500.00
0005433435328	2327	Economy	61500.00
0005432985752	2327	Economy	61500.00
0005432300442	2327	Economy	61500.00
0005433435349	2327	Economy	61500.00
0005432985774	2327	Economy	61500.00
0005433435343	2327	Economy	61500.00
0005434731263	2327	Economy	61500.00
0005432985819	2327	Economy	61500.00
0005432985852	2327	Economy	61500.00
0005433435439	2327	Economy	61500.00
0005432985785	2327	Economy	61500.00
0005432985757	2327	Economy	67700.00
0005433435409	2327	Economy	61500.00
0005433435321	2327	Economy	61500.00
0005432300443	2327	Economy	67700.00
0005433435306	2327	Economy	67700.00
0005432985738	2327	Economy	61500.00
0005433755880	2327	Economy	61500.00
0005432985840	2327	Economy	61500.00
0005433435308	2327	Economy	61500.00
0005433435366	2327	Economy	61500.00
0005434731257	2327	Economy	61500.00
0005433435410	2327	Economy	61500.00
0005433435309	2327	Economy	61500.00
0005432985838	2327	Economy	61500.00
0005434731268	2327	Economy	61500.00
0005432869712	2327	Economy	61500.00
0005432985853	2327	Economy	61500.00
0005433755883	2327	Economy	61500.00
0005432300444	2327	Economy	61500.00
0005433435276	2327	Economy	61500.00
0005434376163	2327	Economy	61500.00
0005432985897	2327	Economy	61500.00
0005435983673	2327	Economy	61500.00
0005433435438	2327	Economy	61500.00
0005433435348	2327	Economy	61500.00
0005432985709	2327	Economy	61500.00
0005433755885	2327	Economy	61500.00
0005433435264	2327	Economy	61500.00
0005432985966	2327	Economy	61500.00
0005432985727	2327	Economy	61500.00
0005432985890	2327	Economy	61500.00
0005433435305	2327	Economy	61500.00
0005432869663	2327	Economy	61500.00
0005433435354	2327	Economy	61500.00
0005432985845	2327	Economy	61500.00
0005433755882	2327	Economy	61500.00
0005432985889	2327	Economy	61500.00
0005432985866	2327	Economy	61500.00
0005433755878	2327	Economy	61500.00
0005432985745	2327	Economy	61500.00
0005434731264	2327	Economy	61500.00
0005433755518	26182	Business	184500.00
0005433755356	26182	Business	184500.00
0005433755348	26182	Business	184500.00
0005433755679	26182	Business	184500.00
0005433755615	26182	Business	184500.00
0005435983097	26182	Business	184500.00
0005435983098	26182	Business	184500.00
0005435983365	26182	Business	184500.00
0005433755514	26182	Business	184500.00
0005432986007	26182	Business	184500.00
0005432869725	26182	Business	184500.00
0005435983346	26182	Business	184500.00
0005433766722	26182	Business	184500.00
0005435983072	26182	Business	184500.00
0005432986008	26182	Business	184500.00
0005435983294	26182	Business	184500.00
0005433755321	26182	Business	184500.00
0005433755669	26182	Business	184500.00
0005433755459	26182	Business	184500.00
0005435983297	26182	Business	184500.00
0005432655765	26182	Business	184500.00
0005435983295	26182	Business	184500.00
0005435983368	26182	Business	184500.00
0005433755347	26182	Business	184500.00
0005433755383	26182	Business	184500.00
0005432655781	26182	Business	184500.00
0005435983405	26182	Economy	67700.00
0005432655826	26182	Economy	67700.00
0005433755349	26182	Economy	61500.00
0005435983227	26182	Economy	61500.00
0005433755563	26182	Economy	61500.00
0005435983342	26182	Economy	61500.00
0005433435507	26182	Economy	61500.00
0005433755725	26182	Economy	61500.00
0005435983206	26182	Economy	61500.00
0005435983522	26182	Economy	61500.00
0005433755686	26182	Economy	61500.00
0005435983247	26182	Economy	61500.00
0005435983244	26182	Economy	61500.00
0005435983476	26182	Economy	61500.00
0005435983433	26182	Economy	61500.00
0005435983369	26182	Economy	61500.00
0005433755609	26182	Economy	61500.00
0005433755586	26182	Economy	61500.00
0005432655764	26182	Economy	61500.00
0005433755654	26182	Economy	61500.00
0005435983187	26182	Economy	61500.00
0005433755810	26182	Economy	61500.00
0005433755564	26182	Economy	61500.00
0005433755450	26182	Economy	61500.00
0005432655839	26182	Economy	61500.00
0005433755663	26182	Economy	61500.00
0005433755811	26182	Economy	61500.00
0005433755458	26182	Economy	61500.00
0005435983288	26182	Economy	61500.00
0005435983296	26182	Economy	61500.00
0005433435505	26182	Economy	61500.00
0005435983178	26182	Economy	61500.00
0005433755409	26182	Economy	61500.00
0005433755397	26182	Economy	61500.00
0005433755525	26182	Economy	61500.00
0005435983320	26182	Economy	61500.00
0005435983451	26182	Economy	61500.00
0005433764726	26182	Economy	61500.00
0005435983179	26182	Economy	61500.00
0005433766767	26182	Economy	61500.00
0005432655828	26182	Economy	61500.00
0005435983188	26182	Economy	61500.00
0005433755548	26182	Economy	61500.00
0005435983540	26182	Economy	61500.00
0005433755612	26182	Economy	61500.00
0005433755438	26182	Economy	61500.00
0005432986009	26182	Economy	61500.00
0005435983304	26182	Economy	61500.00
0005433435506	26182	Economy	61500.00
0005432986010	26182	Economy	61500.00
0005433764733	26182	Economy	61500.00
0005435983143	26182	Economy	61500.00
0005435983341	26182	Economy	61500.00
0005433755682	26182	Economy	61500.00
0005433755695	26182	Economy	61500.00
0005433764725	26182	Economy	61500.00
0005433755382	26182	Economy	61500.00
0005433755611	26182	Economy	61500.00
0005433755662	26182	Economy	67700.00
0005435983397	26182	Economy	67700.00
0005432655772	26182	Economy	61500.00
0005433755678	26182	Economy	61500.00
0005435983273	26182	Economy	61500.00
0005433766747	26182	Economy	67700.00
0005433755357	26182	Economy	67700.00
0005433755512	26182	Economy	61500.00
0005435983171	26182	Economy	61500.00
0005435983381	26182	Economy	61500.00
0005435983539	26182	Economy	61500.00
0005433755473	26182	Economy	61500.00
0005432655771	26182	Economy	61500.00
0005435983443	26182	Economy	61500.00
0005435983386	26182	Economy	61500.00
0005435983452	26182	Economy	61500.00
0005433755616	26182	Economy	61500.00
0005435983330	26182	Economy	61500.00
0005435983402	26182	Economy	61500.00
0005433755646	26182	Economy	61500.00
0005435983376	26182	Economy	61500.00
0005435983343	26182	Economy	61500.00
0005433755398	26182	Economy	61500.00
0005435983349	26182	Economy	61500.00
0005433755569	26182	Economy	61500.00
0005433755655	26182	Economy	61500.00
0005432655767	26182	Economy	61500.00
0005435983205	26182	Economy	61500.00
0005433755460	26182	Economy	61500.00
0005433755769	26182	Economy	61500.00
0005433755519	26182	Economy	61500.00
0005433755674	26182	Economy	61500.00
0005433755670	26182	Economy	61500.00
0005432986011	26182	Economy	61500.00
0005433755511	26182	Economy	61500.00
0005433755645	26182	Economy	61500.00
0005435983172	26182	Economy	61500.00
0005435983364	26182	Economy	61500.00
0005435983423	26182	Economy	61500.00
0005435983541	26182	Economy	61500.00
0005433755549	26182	Economy	61500.00
0005433766757	26182	Economy	61500.00
0005433755702	26182	Economy	61500.00
0005434376064	1500	Business	38900.00
0005433152318	1500	Business	38900.00
0005433152204	1500	Business	38900.00
0005433152304	1500	Economy	13000.00
0005433931525	1500	Economy	13000.00
0005433931552	1500	Economy	13000.00
0005433152212	1500	Economy	13000.00
0005433152267	1500	Economy	13000.00
0005433764724	1500	Economy	13000.00
0005433931530	1500	Economy	13000.00
0005433152179	1500	Economy	13000.00
0005433152395	1500	Economy	13000.00
0005433152203	1500	Economy	13000.00
0005433152129	1500	Economy	13000.00
0005433152306	1500	Economy	13000.00
0005433152296	1500	Economy	14300.00
0005433152227	1500	Economy	14300.00
0005433764727	1500	Economy	13000.00
0005433152295	1500	Economy	13000.00
0005433152221	1500	Economy	13000.00
0005433152229	1500	Economy	13000.00
0005433764729	1500	Economy	13000.00
0005434376065	1500	Economy	13000.00
0005433152314	1500	Economy	13000.00
0005433931526	1500	Economy	13000.00
0005433152222	1500	Economy	13000.00
0005433152285	1500	Economy	13000.00
0005434029725	1500	Economy	13000.00
0005433152254	1500	Economy	13000.00
0005433152268	1500	Economy	13000.00
0005433152128	1500	Economy	13000.00
0005433152244	1500	Economy	13000.00
0005433152226	1500	Economy	13000.00
0005433152139	1500	Economy	13000.00
0005433152313	1500	Economy	13000.00
0005433152048	1500	Economy	13000.00
0005433152162	1500	Economy	13000.00
0005433152375	1500	Economy	13000.00
0005433152264	1500	Economy	13000.00
0005433152211	1500	Economy	13000.00
0005433152332	1500	Economy	13000.00
0005433152178	1500	Economy	13000.00
0005433152317	1500	Economy	13000.00
0005434375749	20108	Business	38900.00
0005434375836	20108	Business	38900.00
0005434375533	20108	Economy	13000.00
0005434375948	20108	Economy	13000.00
0005434375837	20108	Economy	13000.00
0005434375905	20108	Economy	13000.00
0005434375922	20108	Economy	13000.00
0005434375697	20108	Economy	13000.00
0005434375731	20108	Economy	13000.00
0005434375587	20108	Economy	13000.00
0005434375735	20108	Economy	13000.00
0005433152415	20108	Economy	13000.00
0005434375734	20108	Economy	13000.00
0005433152414	20108	Economy	13000.00
0005434376163	20108	Economy	13000.00
0005434375531	20108	Economy	13000.00
0005434375917	20108	Economy	13000.00
0005434375884	20108	Economy	13000.00
0005434375692	20108	Economy	14300.00
0005434375799	20108	Economy	14300.00
0005434376160	20108	Economy	14300.00
0005434375507	20108	Economy	14300.00
0005434375736	20108	Economy	13000.00
0005434375691	20108	Economy	13000.00
0005434375941	20108	Economy	13000.00
0005434375806	20108	Economy	13000.00
0005434375759	20108	Economy	13000.00
0005434375737	20108	Economy	13000.00
0005434375786	20108	Economy	13000.00
0005434375798	20108	Economy	13000.00
0005434375835	20108	Economy	13000.00
0005434375894	20108	Economy	13000.00
0005434375620	20108	Economy	13000.00
0005434375628	20108	Economy	13000.00
0005434375730	20108	Economy	13000.00
0005434375916	20108	Economy	13000.00
0005434375848	20108	Economy	13000.00
0005434375805	20108	Economy	13000.00
0005434375968	20108	Economy	13000.00
0005434375967	20108	Economy	13000.00
0005434375789	20108	Economy	13000.00
0005434375885	20108	Economy	13000.00
0005434375787	20108	Economy	13000.00
0005434375847	20108	Economy	13000.00
0005434375729	20108	Economy	13000.00
0005434375811	20108	Economy	13000.00
0005434375800	20108	Economy	13000.00
0005434375627	20108	Economy	13000.00
0005434375650	20108	Economy	13000.00
0005434375698	20108	Economy	13000.00
0005434376162	20108	Economy	13000.00
0005434375904	20108	Economy	13000.00
0005432426050	583	Business	27500.00
0005433261888	583	Business	27500.00
0005433261918	583	Business	27500.00
0005433261882	583	Business	27500.00
0005433261896	583	Business	27500.00
0005433261947	583	Business	27500.00
0005433766755	583	Business	27500.00
0005432426061	583	Business	27500.00
0005432426052	583	Business	27500.00
0005432426060	583	Business	27500.00
0005433262005	583	Business	27500.00
0005433261885	583	Business	27500.00
0005432426059	583	Economy	10100.00
0005434444191	583	Economy	10100.00
0005433261953	583	Economy	9200.00
0005433261964	583	Economy	9200.00
0005433766754	583	Economy	9200.00
0005433261952	583	Economy	9200.00
0005432426044	583	Economy	9200.00
0005433261879	583	Economy	9200.00
0005433766756	583	Economy	9200.00
0005432426053	583	Economy	9200.00
0005433261979	583	Economy	9200.00
0005432426062	583	Economy	9200.00
0005433261949	583	Economy	9200.00
0005433261892	583	Economy	9200.00
0005433157010	583	Economy	9200.00
0005434995370	583	Economy	9200.00
0005433261987	583	Economy	9200.00
0005433261900	583	Economy	9200.00
0005433261886	583	Economy	9200.00
0005433261919	583	Economy	9200.00
0005434995373	583	Economy	9200.00
0005434995378	583	Economy	9200.00
0005432426054	583	Economy	9200.00
0005433261874	583	Economy	9200.00
0005432426048	583	Economy	9200.00
0005432426051	583	Economy	9200.00
0005433261912	583	Economy	9200.00
0005432426043	583	Economy	9200.00
0005433261948	583	Economy	9200.00
0005434995371	583	Economy	9200.00
0005433261959	583	Economy	9200.00
0005434995372	583	Economy	10100.00
0005434444188	583	Economy	10100.00
0005432426046	583	Economy	10100.00
0005433261940	583	Economy	9200.00
0005434995368	583	Economy	9200.00
0005434995375	583	Economy	9200.00
0005434444192	583	Economy	9200.00
0005433261960	583	Economy	9200.00
0005433157016	583	Economy	9200.00
0005433261937	583	Economy	9200.00
0005432426047	583	Economy	9200.00
0005433262001	583	Economy	9200.00
0005432426045	583	Economy	9200.00
0005433261980	583	Economy	9200.00
0005434995376	583	Economy	9200.00
0005433261881	583	Economy	9200.00
0005434995367	583	Economy	9200.00
0005432426063	583	Economy	9200.00
0005433261921	583	Economy	9200.00
0005433261909	583	Economy	9200.00
0005433261920	583	Economy	9200.00
0005432426064	583	Economy	9200.00
0005433261955	583	Economy	9200.00
0005433261939	583	Economy	9200.00
0005433261897	583	Economy	9200.00
0005433261943	583	Economy	9200.00
0005432426049	583	Economy	9200.00
0005432426056	583	Economy	9200.00
0005433261911	583	Economy	9200.00
0005432283068	583	Economy	9200.00
0005433261938	583	Economy	9200.00
0005434995377	583	Economy	9200.00
0005432426058	583	Economy	9200.00
0005432426055	583	Economy	9200.00
0005434995369	583	Economy	9200.00
0005434995374	583	Economy	9200.00
0005432426057	583	Economy	9200.00
0005433262057	12831	Business	27500.00
0005433157022	12831	Business	27500.00
0005433157019	12831	Business	27500.00
0005433262055	12831	Business	27500.00
0005434446572	12831	Economy	10100.00
0005433262058	12831	Economy	9200.00
0005433262060	12831	Economy	9200.00
0005434446577	12831	Economy	9200.00
0005434446575	12831	Economy	9200.00
0005433157021	12831	Economy	9200.00
0005434446576	12831	Economy	9200.00
0005433262059	12831	Economy	9200.00
0005433157020	12831	Economy	9200.00
0005434446574	12831	Economy	9200.00
0005434446558	12831	Economy	9200.00
0005433262056	12831	Economy	9200.00
0005432302443	12831	Economy	9200.00
0005432425603	12935	Business	27500.00
0005432425486	12935	Business	27500.00
0005432425430	12935	Business	27500.00
0005432425604	12935	Business	27500.00
0005432425530	12935	Business	27500.00
0005432425474	12935	Business	27500.00
0005432425485	12935	Business	27500.00
0005432425475	12935	Economy	9200.00
0005432425594	12935	Economy	9200.00
0005432425490	12935	Economy	9200.00
0005432425595	12935	Economy	9200.00
0005432425410	12935	Economy	9200.00
0005432425463	12935	Economy	9200.00
0005432425547	12935	Economy	9200.00
0005432425553	12935	Economy	9200.00
0005432425605	12935	Economy	9200.00
0005432425431	12935	Economy	9200.00
0005432425606	12935	Economy	9200.00
0005432425554	12935	Economy	9200.00
0005432425611	12935	Economy	9200.00
0005432425290	12935	Economy	9200.00
0005432425578	12935	Economy	9200.00
0005432425562	12935	Economy	9200.00
0005432425607	12935	Economy	10100.00
0005432425588	12935	Economy	9200.00
0005432425536	12935	Economy	10100.00
0005432425533	12935	Economy	9200.00
0005432425570	12935	Economy	9200.00
0005432425546	12935	Economy	9200.00
0005432425534	12935	Economy	9200.00
0005432425612	12935	Economy	9200.00
0005432425581	12935	Economy	9200.00
0005432425432	12935	Economy	9200.00
0005432425317	12935	Economy	9200.00
0005432425608	12935	Economy	9200.00
0005432425386	12935	Economy	9200.00
0005432425619	12935	Economy	9200.00
0005432425614	12935	Economy	9200.00
0005433058850	449	Business	24500.00
0005433058879	449	Business	24500.00
0005434025693	449	Business	24500.00
0005434025685	449	Business	24500.00
0005433058894	449	Business	24500.00
0005433058948	449	Business	24500.00
0005434025688	449	Business	24500.00
0005434028398	449	Business	24500.00
0005433058876	449	Business	24500.00
0005433058957	449	Business	24500.00
0005433684468	449	Economy	9000.00
0005433058699	449	Economy	8200.00
0005433058832	449	Economy	8200.00
0005433058924	449	Economy	8200.00
0005434025690	449	Economy	8200.00
0005433058877	449	Economy	8200.00
0005434032159	449	Economy	8200.00
0005433059021	449	Economy	8200.00
0005434032160	449	Economy	8200.00
0005433058864	449	Economy	8200.00
0005433058863	449	Economy	8200.00
0005434028397	449	Economy	8200.00
0005433058929	449	Economy	8200.00
0005434025691	449	Economy	8200.00
0005434025686	449	Economy	8200.00
0005433058901	449	Economy	8200.00
0005433058880	449	Economy	8200.00
0005434025694	449	Economy	8200.00
0005433058700	449	Economy	8200.00
0005433684467	449	Economy	8200.00
0005434735810	449	Economy	8200.00
0005433058973	449	Economy	8200.00
0005433058725	449	Economy	8200.00
0005433929716	449	Economy	8200.00
0005433058895	449	Economy	8200.00
0005433684463	449	Economy	8200.00
0005433058975	449	Economy	8200.00
0005433058974	449	Economy	8200.00
0005433058977	449	Economy	8200.00
0005433058930	449	Economy	8200.00
0005433058933	449	Economy	9000.00
0005434025692	449	Economy	9000.00
0005433929703	449	Economy	8200.00
0005434025695	449	Economy	8200.00
0005433058956	449	Economy	8200.00
0005433058925	449	Economy	8200.00
0005433058889	449	Economy	8200.00
0005433058805	449	Economy	8200.00
0005434025689	449	Economy	8200.00
0005433058945	449	Economy	8200.00
0005434025687	449	Economy	8200.00
0005433059002	449	Economy	8200.00
0005433058888	449	Economy	8200.00
0005434025684	449	Economy	8200.00
0005433929702	449	Economy	8200.00
0005433929717	449	Economy	8200.00
0005433058937	449	Economy	8200.00
0005433058791	449	Economy	8200.00
0005433058976	449	Economy	8200.00
0005433058831	449	Economy	8200.00
0005433058849	449	Economy	8200.00
0005433058944	449	Economy	8200.00
0005434025696	449	Economy	8200.00
0005433058958	449	Economy	8200.00
0005433058746	449	Economy	8200.00
0005433058884	449	Economy	8200.00
0005433058934	449	Economy	8200.00
0005434028399	449	Economy	8200.00
0005433058747	449	Economy	8200.00
0005434025262	12662	Business	24500.00
0005434025551	12662	Business	24500.00
0005434025447	12662	Business	24500.00
0005434025306	12662	Business	24500.00
0005434025553	12662	Business	24500.00
0005434025391	12662	Business	24500.00
0005433929733	12662	Business	24500.00
0005434025362	12662	Business	24500.00
0005434025229	12662	Business	24500.00
0005434025141	12662	Business	24500.00
0005434025254	12662	Business	24500.00
0005434025240	12662	Business	24500.00
0005434025665	12662	Business	24500.00
0005434025230	12662	Economy	8200.00
0005434025084	12662	Economy	8200.00
0005434028369	12662	Economy	8200.00
0005434025571	12662	Economy	8200.00
0005434025469	12662	Economy	8200.00
0005434025316	12662	Economy	8200.00
0005434025040	12662	Economy	8200.00
0005434025462	12662	Economy	8200.00
0005434025572	12662	Economy	8200.00
0005434025039	12662	Economy	8200.00
0005434025554	12662	Economy	8200.00
0005434025282	12662	Economy	8200.00
0005434028390	12662	Economy	8200.00
0005434025128	12662	Economy	8200.00
0005434025402	12662	Economy	8200.00
0005434025205	12662	Economy	8200.00
0005434025356	12662	Economy	8200.00
0005434025307	12662	Economy	8200.00
0005434032141	12662	Economy	8200.00
0005434025163	12662	Economy	8200.00
0005434025231	12662	Economy	8200.00
0005434028389	12662	Economy	8200.00
0005433929734	12662	Economy	8200.00
0005434025552	12662	Economy	8200.00
0005434025241	12662	Economy	8200.00
0005434025527	12662	Economy	8200.00
0005434025514	12662	Economy	8200.00
0005434025431	12662	Economy	8200.00
0005434028377	12662	Economy	8200.00
0005434025277	12662	Economy	8200.00
0005434025161	12662	Economy	8200.00
0005434025354	12662	Economy	8200.00
0005434025448	12662	Economy	8200.00
0005434025459	12662	Economy	8200.00
0005434025152	12662	Economy	8200.00
0005434025392	12662	Economy	8200.00
0005434025305	12662	Economy	8200.00
0005434025255	12662	Economy	8200.00
0005434025301	12662	Economy	8200.00
0005434025187	12662	Economy	8200.00
0005434025182	12662	Economy	8200.00
0005434028385	12662	Economy	8200.00
0005434025276	12662	Economy	8200.00
0005434025533	12662	Economy	8200.00
0005434025091	12662	Economy	9000.00
0005434025376	12662	Economy	8200.00
0005434025340	12662	Economy	8200.00
0005434025256	12662	Economy	8200.00
0005434025299	12662	Economy	8200.00
0005434025083	12662	Economy	8200.00
0005434025082	12662	Economy	8200.00
0005434028391	12662	Economy	8200.00
0005434025079	12662	Economy	8200.00
0005434025288	12662	Economy	8200.00
0005434025355	12662	Economy	8200.00
0005434025479	12662	Economy	8200.00
0005434025327	12662	Economy	8200.00
0005434032128	12662	Economy	8200.00
0005434025468	12662	Economy	8200.00
0005434025358	12662	Economy	8200.00
0005434028382	12662	Economy	8200.00
0005434025147	12662	Economy	8200.00
0005434029725	12662	Economy	8200.00
0005434025186	12662	Economy	8200.00
0005434025526	12662	Economy	8200.00
0005434025353	12662	Economy	8200.00
0005434025458	12662	Economy	8200.00
0005434025512	12662	Economy	8200.00
0005434025261	12662	Economy	8200.00
0005434025275	12662	Economy	8200.00
0005434025513	12662	Economy	8200.00
0005434025401	12662	Economy	8200.00
0005434025396	12662	Economy	8200.00
0005433527372	13808	Business	111600.00
0005433529389	13808	Economy	37200.00
0005433527373	13808	Economy	37200.00
0005433529385	13808	Economy	37200.00
0005433529386	13808	Economy	37200.00
0005433529384	13808	Economy	37200.00
0005433527375	13808	Economy	37200.00
0005433529387	13808	Economy	37200.00
0005433529388	13808	Economy	37200.00
0005433527374	13808	Economy	37200.00
0005433533402	32443	Business	111600.00
0005433533415	32443	Business	111600.00
0005433529349	32443	Business	111600.00
0005433533394	32443	Business	111600.00
0005433529367	32443	Business	111600.00
0005433529369	32443	Business	111600.00
0005433533384	32443	Business	111600.00
0005433529354	32443	Business	111600.00
0005433529338	32443	Business	111600.00
0005433533387	32443	Economy	37200.00
0005433529337	32443	Economy	37200.00
0005433533412	32443	Economy	37200.00
0005433533399	32443	Economy	37200.00
0005433529370	32443	Economy	37200.00
0005433533397	32443	Economy	37200.00
0005433533391	32443	Economy	37200.00
0005433533400	32443	Economy	40900.00
0005433529371	32443	Economy	40900.00
0005433533413	32443	Economy	37200.00
0005433533414	32443	Economy	37200.00
0005433533386	32443	Economy	37200.00
0005433529357	32443	Economy	37200.00
0005433533392	32443	Economy	37200.00
0005433529352	32443	Economy	37200.00
0005433533409	32443	Economy	37200.00
0005433533406	32443	Economy	37200.00
0005433533398	32443	Economy	37200.00
0005433529356	32443	Economy	37200.00
0005433529368	32443	Economy	37200.00
0005433533380	32443	Economy	37200.00
0005433529339	32443	Economy	37200.00
0005433529365	32443	Economy	37200.00
0005433529351	32443	Economy	37200.00
0005433529336	32443	Economy	37200.00
0005433533390	32443	Economy	37200.00
0005433533401	32443	Economy	37200.00
0005433533393	32443	Economy	37200.00
0005433529366	32443	Economy	37200.00
0005433533381	32443	Economy	37200.00
0005433529350	32443	Economy	37200.00
0005433529361	32443	Economy	37200.00
0005433529355	32443	Economy	37200.00
0005433926107	2133	Business	34700.00
0005433037741	2133	Business	34700.00
0005433875429	2133	Business	34700.00
0005433037702	2133	Business	34700.00
0005433929896	2133	Business	34700.00
0005433037474	2133	Business	34700.00
0005434028389	2133	Business	34700.00
0005433929733	2133	Business	34700.00
0005433037299	2133	Business	34700.00
0005433037480	2133	Business	34700.00
0005433037462	2133	Business	34700.00
0005433037339	2133	Economy	12700.00
0005434028369	2133	Economy	12700.00
0005433926110	2133	Economy	11600.00
0005433037647	2133	Economy	11600.00
0005433037549	2133	Economy	11600.00
0005433037697	2133	Economy	11600.00
0005433037482	2133	Economy	11600.00
0005433037607	2133	Economy	11600.00
0005433929895	2133	Economy	11600.00
0005433037499	2133	Economy	11600.00
0005433926111	2133	Economy	11600.00
0005433926114	2133	Economy	11600.00
0005433926106	2133	Economy	11600.00
0005433037481	2133	Economy	11600.00
0005433926115	2133	Economy	11600.00
0005433037581	2133	Economy	11600.00
0005433037300	2133	Economy	11600.00
0005434028390	2133	Economy	11600.00
0005433037548	2133	Economy	11600.00
0005433037629	2133	Economy	11600.00
0005433037547	2133	Economy	11600.00
0005433037609	2133	Economy	11600.00
0005433926108	2133	Economy	11600.00
0005433037624	2133	Economy	11600.00
0005433037608	2133	Economy	11600.00
0005433037522	2133	Economy	11600.00
0005433037673	2133	Economy	11600.00
0005433037340	2133	Economy	11600.00
0005433037550	2133	Economy	11600.00
0005433037614	2133	Economy	11600.00
0005433037383	2133	Economy	12700.00
0005433037625	2133	Economy	12700.00
0005433926113	2133	Economy	11600.00
0005433037696	2133	Economy	11600.00
0005433037397	2133	Economy	11600.00
0005433926109	2133	Economy	11600.00
0005434028382	2133	Economy	11600.00
0005433037643	2133	Economy	11600.00
0005433037470	2133	Economy	11600.00
0005434028391	2133	Economy	11600.00
0005433037416	2133	Economy	11600.00
0005432749832	2133	Economy	11600.00
0005434028377	2133	Economy	11600.00
0005433037374	2133	Economy	11600.00
0005433037553	2133	Economy	11600.00
0005433037498	2133	Economy	11600.00
0005433926105	2133	Economy	11600.00
0005433926112	2133	Economy	11600.00
0005433037475	2133	Economy	11600.00
0005433037463	2133	Economy	11600.00
0005433929894	2133	Economy	11600.00
0005433037610	2133	Economy	11600.00
0005432749842	2133	Economy	11600.00
0005433037598	2133	Economy	11600.00
0005434028385	2133	Economy	11600.00
0005432749843	2133	Economy	11600.00
0005433037615	2133	Economy	11600.00
0005433929734	2133	Economy	11600.00
0005433037382	2133	Economy	11600.00
0005433037515	2133	Economy	11600.00
0005433925388	24089	Business	34700.00
0005433925987	24089	Business	34700.00
0005433925645	24089	Business	34700.00
0005433925465	24089	Business	34700.00
0005433925950	24089	Business	34700.00
0005433925238	24089	Business	34700.00
0005433925154	24089	Business	34700.00
0005433931553	24089	Business	34700.00
0005433925474	24089	Business	34700.00
0005433925240	24089	Business	34700.00
0005433925710	24089	Business	34700.00
0005433925772	24089	Business	34700.00
0005433925540	24089	Business	34700.00
0005433925959	24089	Business	34700.00
0005433925236	24089	Business	34700.00
0005433925342	24089	Economy	12700.00
0005433925235	24089	Economy	11600.00
0005433037846	24089	Economy	11600.00
0005433925425	24089	Economy	11600.00
0005433925746	24089	Economy	11600.00
0005432749852	24089	Economy	11600.00
0005433925925	24089	Economy	11600.00
0005433925564	24089	Economy	11600.00
0005433925765	24089	Economy	11600.00
0005433925423	24089	Economy	11600.00
0005433925621	24089	Economy	11600.00
0005433925195	24089	Economy	11600.00
0005433037848	24089	Economy	11600.00
0005433925769	24089	Economy	11600.00
0005433925661	24089	Economy	11600.00
0005433925956	24089	Economy	11600.00
0005433925239	24089	Economy	11600.00
0005433925593	24089	Economy	11600.00
0005433925516	24089	Economy	11600.00
0005433925358	24089	Economy	11600.00
0005433925672	24089	Economy	11600.00
0005434088060	24089	Economy	11600.00
0005433925790	24089	Economy	11600.00
0005433925789	24089	Economy	11600.00
0005433925517	24089	Economy	11600.00
0005433875419	24089	Economy	11600.00
0005433925487	24089	Economy	11600.00
0005433925716	24089	Economy	11600.00
0005433925577	24089	Economy	11600.00
0005433925699	24089	Economy	11600.00
0005433925158	24089	Economy	11600.00
0005433925393	24089	Economy	11600.00
0005433925314	24089	Economy	11600.00
0005433925617	24089	Economy	11600.00
0005433925605	24089	Economy	11600.00
0005433925739	24089	Economy	11600.00
0005433925592	24089	Economy	11600.00
0005433925783	24089	Economy	11600.00
0005434376191	24089	Economy	11600.00
0005433925632	24089	Economy	11600.00
0005433925324	24089	Economy	11600.00
0005433925717	24089	Economy	11600.00
0005433925436	24089	Economy	11600.00
0005433925774	24089	Economy	11600.00
0005433925742	24089	Economy	11600.00
0005433925488	24089	Economy	11600.00
0005434088059	24089	Economy	11600.00
0005433925773	24089	Economy	11600.00
0005433925277	24089	Economy	11600.00
0005433925361	24089	Economy	11600.00
0005433925624	24089	Economy	12700.00
0005433925856	24089	Economy	12700.00
0005433925299	24089	Economy	11600.00
0005433925153	24089	Economy	11600.00
0005433925784	24089	Economy	11600.00
0005433037847	24089	Economy	11600.00
0005433925208	24089	Economy	11600.00
0005433929873	24089	Economy	11600.00
0005433925237	24089	Economy	11600.00
0005433875420	24089	Economy	11600.00
0005433925526	24089	Economy	11600.00
0005433925576	24089	Economy	11600.00
0005433925278	24089	Economy	11600.00
0005433925711	24089	Economy	11600.00
0005433931540	24089	Economy	11600.00
0005433925654	24089	Economy	11600.00
0005433925631	24089	Economy	11600.00
0005433925591	24089	Economy	11600.00
0005433925102	24089	Economy	11600.00
0005433925620	24089	Economy	11600.00
0005433925782	24089	Economy	11600.00
0005433925811	24089	Economy	11600.00
0005433926015	24089	Economy	11600.00
0005433925756	24089	Economy	11600.00
0005433925842	24089	Economy	11600.00
0005433925172	24089	Economy	11600.00
0005433925594	24089	Economy	11600.00
0005433925313	24089	Economy	11600.00
0005433925209	24089	Economy	11600.00
0005433925464	24089	Economy	11600.00
0005433925546	24089	Economy	11600.00
0005433925874	24089	Economy	11600.00
0005433925718	24089	Economy	11600.00
0005433925362	24089	Economy	11600.00
0005434028396	24089	Economy	11600.00
0005433931531	24089	Economy	11600.00
0005433925341	24089	Economy	11600.00
0005433925801	24089	Economy	11600.00
0005433925613	24089	Economy	11600.00
0005433925747	24089	Economy	11600.00
0005433925268	24089	Economy	11600.00
0005433925775	24089	Economy	11600.00
0005433925771	24089	Economy	11600.00
0005433925319	24089	Economy	11600.00
0005433235632	264	Business	83700.00
0005433235742	264	Business	83700.00
0005434729034	264	Business	83700.00
0005433235845	264	Business	83700.00
0005433113578	264	Business	83700.00
0005433235487	264	Business	83700.00
0005433235898	264	Business	83700.00
0005433181732	264	Comfort	47400.00
0005433181761	264	Comfort	47400.00
0005433181789	264	Comfort	47400.00
0005433181726	264	Comfort	47400.00
0005433181746	264	Comfort	47400.00
0005433235699	264	Comfort	47400.00
0005433126968	264	Comfort	47400.00
0005434032139	264	Comfort	47400.00
0005433181790	264	Comfort	47400.00
0005433126959	264	Comfort	47400.00
0005433181656	264	Comfort	47400.00
0005433235641	264	Comfort	47400.00
0005433126960	264	Economy	27900.00
0005433235613	264	Economy	27900.00
0005433181616	264	Economy	27900.00
0005434729032	264	Economy	27900.00
0005434729024	264	Economy	27900.00
0005433235773	264	Economy	27900.00
0005434552862	264	Economy	27900.00
0005434729031	264	Economy	27900.00
0005434729036	264	Economy	27900.00
0005435142968	264	Economy	27900.00
0005433181804	264	Economy	27900.00
0005433181720	264	Economy	27900.00
0005433235880	264	Economy	27900.00
0005433235881	264	Economy	27900.00
0005433235665	264	Economy	27900.00
0005433235353	264	Economy	27900.00
0005433235634	264	Economy	27900.00
0005433126955	264	Economy	27900.00
0005433235747	264	Economy	30700.00
0005433235488	264	Economy	27900.00
0005434729033	264	Economy	30700.00
0005433235726	264	Economy	27900.00
0005433235769	264	Economy	27900.00
0005434729037	264	Economy	30700.00
0005434729023	264	Economy	27900.00
0005433235813	264	Economy	27900.00
0005433235612	264	Economy	27900.00
0005433235846	264	Economy	27900.00
0005432278208	264	Economy	27900.00
0005433235633	264	Economy	27900.00
0005433235591	264	Economy	27900.00
0005433235864	264	Economy	27900.00
0005433181716	264	Economy	27900.00
0005433181767	264	Economy	27900.00
0005433235724	264	Economy	27900.00
0005433235578	264	Economy	27900.00
0005434729027	264	Economy	27900.00
0005432278209	264	Economy	27900.00
0005433181694	264	Economy	27900.00
0005433181762	264	Economy	27900.00
0005434552860	264	Economy	27900.00
0005434729029	264	Economy	27900.00
0005433235770	264	Economy	27900.00
0005433181795	264	Economy	27900.00
0005433235640	264	Economy	27900.00
0005433181792	264	Economy	27900.00
0005433181791	264	Economy	27900.00
0005433235725	264	Economy	27900.00
0005433181739	264	Economy	27900.00
0005434729026	264	Economy	27900.00
0005434552861	264	Economy	27900.00
0005433181717	264	Economy	27900.00
0005433235741	264	Economy	27900.00
0005433235837	264	Economy	27900.00
0005432278207	264	Economy	27900.00
0005434729028	264	Economy	27900.00
0005433181687	264	Economy	27900.00
0005434552857	264	Economy	27900.00
0005433181707	264	Economy	27900.00
0005433235527	264	Economy	27900.00
0005433235528	264	Economy	27900.00
0005433235910	264	Economy	27900.00
0005434552859	264	Economy	27900.00
0005433181665	264	Economy	27900.00
0005433181733	264	Economy	27900.00
0005433181650	264	Economy	27900.00
0005433235776	264	Economy	27900.00
0005433235623	264	Economy	27900.00
0005433181793	264	Economy	27900.00
0005433235480	264	Economy	27900.00
0005434729025	264	Economy	27900.00
0005433235597	264	Economy	27900.00
0005433235662	264	Economy	27900.00
0005433235489	264	Economy	27900.00
0005433181805	264	Economy	27900.00
0005433235661	264	Economy	27900.00
0005433126954	264	Economy	27900.00
0005433235740	264	Economy	27900.00
0005433235664	264	Economy	27900.00
0005434552858	264	Economy	27900.00
0005433181737	264	Economy	27900.00
0005433181693	264	Economy	27900.00
0005433181649	264	Economy	27900.00
0005433235473	264	Economy	27900.00
0005433235750	264	Economy	27900.00
0005434729030	264	Economy	27900.00
0005433131817	264	Economy	27900.00
0005434729038	264	Economy	27900.00
0005433131816	264	Economy	27900.00
0005433235529	264	Economy	27900.00
0005433126967	264	Economy	27900.00
0005433181706	264	Economy	27900.00
0005434729035	264	Economy	27900.00
0005434729022	264	Economy	27900.00
0005433235405	264	Economy	27900.00
0005433235557	264	Economy	27900.00
0005434728762	9867	Business	83700.00
0005434728569	9867	Business	83700.00
0005434552354	9867	Business	83700.00
0005434728136	9867	Business	83700.00
0005434728392	9867	Business	83700.00
0005434552453	9867	Business	83700.00
0005434735806	9867	Business	83700.00
0005434552421	9867	Business	83700.00
0005434302541	9867	Business	83700.00
0005434552715	9867	Business	83700.00
0005434735803	9867	Business	83700.00
0005435142881	9867	Business	83700.00
0005434728109	9867	Business	83700.00
0005434552491	9867	Business	83700.00
0005434728594	9867	Business	83700.00
0005434728568	9867	Business	83700.00
0005433290065	9867	Business	83700.00
0005433236053	9867	Business	83700.00
0005434728220	9867	Business	83700.00
0005434302543	9867	Comfort	47400.00
0005434552500	9867	Business	83700.00
0005434728292	9867	Comfort	47400.00
0005434728758	9867	Comfort	47400.00
0005434728709	9867	Comfort	47400.00
0005434302542	9867	Comfort	47400.00
0005433236055	9867	Comfort	47400.00
0005435142871	9867	Comfort	47400.00
0005434735831	9867	Comfort	47400.00
0005434728796	9867	Comfort	47400.00
0005433236057	9867	Comfort	47400.00
0005435142922	9867	Comfort	47400.00
0005434552657	9867	Comfort	47400.00
0005434728592	9867	Comfort	47400.00
0005434728040	9867	Comfort	47400.00
0005434728666	9867	Comfort	47400.00
0005435142874	9867	Comfort	47400.00
0005433181839	9867	Comfort	47400.00
0005434032161	9867	Comfort	47400.00
0005434552576	9867	Comfort	47400.00
0005434728247	9867	Comfort	47400.00
0005434552470	9867	Comfort	47400.00
0005434728467	9867	Comfort	47400.00
0005435142888	9867	Economy	27900.00
0005434735812	9867	Economy	27900.00
0005434552252	9867	Economy	27900.00
0005435142919	9867	Economy	27900.00
0005434728186	9867	Economy	27900.00
0005434728773	9867	Economy	27900.00
0005434302567	9867	Economy	27900.00
0005434728008	9867	Economy	27900.00
0005435142920	9867	Economy	27900.00
0005434728243	9867	Economy	27900.00
0005435142844	9867	Economy	27900.00
0005434728552	9867	Economy	27900.00
0005434728078	9867	Economy	27900.00
0005434552691	9867	Economy	27900.00
0005434552661	9867	Economy	27900.00
0005434728188	9867	Economy	27900.00
0005435142886	9867	Economy	27900.00
0005435142827	9867	Economy	27900.00
0005434727954	9867	Economy	27900.00
0005433113619	9867	Economy	27900.00
0005434728143	9867	Economy	27900.00
0005434552717	9867	Economy	27900.00
0005434552310	9867	Economy	27900.00
0005434728811	9867	Economy	27900.00
0005434731268	9867	Economy	27900.00
0005435142841	9867	Economy	27900.00
0005435142878	9867	Economy	27900.00
0005434728059	9867	Economy	27900.00
0005434552504	9867	Economy	27900.00
0005434552360	9867	Economy	27900.00
0005434552530	9867	Economy	27900.00
0005434728147	9867	Economy	27900.00
0005434552477	9867	Economy	27900.00
0005435142842	9867	Economy	27900.00
0005434302560	9867	Economy	27900.00
0005434552308	9867	Economy	27900.00
0005434728586	9867	Economy	27900.00
0005434552656	9867	Economy	27900.00
0005434302556	9867	Economy	27900.00
0005434728512	9867	Economy	27900.00
0005434728206	9867	Economy	27900.00
0005433113620	9867	Economy	27900.00
0005434731257	9867	Economy	27900.00
0005434728710	9867	Economy	27900.00
0005434728433	9867	Economy	27900.00
0005434552343	9867	Economy	27900.00
0005434728668	9867	Economy	30700.00
0005435142908	9867	Economy	30700.00
0005434735804	9867	Economy	27900.00
0005434728057	9867	Economy	30700.00
0005433126984	9867	Economy	30700.00
0005434728541	9867	Economy	27900.00
0005434728595	9867	Economy	27900.00
0005434735788	9867	Economy	27900.00
0005434728798	9867	Economy	27900.00
0005434728205	9867	Economy	27900.00
0005434728114	9867	Economy	27900.00
0005434552626	9867	Economy	27900.00
0005433236056	9867	Economy	27900.00
0005434552475	9867	Economy	27900.00
0005434728115	9867	Economy	27900.00
0005434728632	9867	Economy	27900.00
0005434728242	9867	Economy	27900.00
0005434728137	9867	Economy	27900.00
0005434728558	9867	Economy	27900.00
0005434302544	9867	Economy	27900.00
0005434727856	9867	Economy	27900.00
0005434728725	9867	Economy	27900.00
0005434728721	9867	Economy	27900.00
0005434731263	9867	Economy	27900.00
0005434728227	9867	Economy	27900.00
0005433181838	9867	Economy	27900.00
0005434728230	9867	Economy	27900.00
0005434552570	9867	Economy	27900.00
0005434728403	9867	Economy	27900.00
0005434728372	9867	Economy	27900.00
0005434728801	9867	Economy	27900.00
0005434728111	9867	Economy	27900.00
0005434552253	9867	Economy	27900.00
0005434552574	9867	Economy	27900.00
0005434552419	9867	Economy	27900.00
0005434552510	9867	Economy	27900.00
0005434552451	9867	Economy	27900.00
0005434735805	9867	Economy	27900.00
0005434552361	9867	Economy	27900.00
0005434728432	9867	Economy	27900.00
0005434728527	9867	Economy	27900.00
0005434728501	9867	Economy	27900.00
0005434727953	9867	Economy	27900.00
0005434728223	9867	Economy	27900.00
0005434728623	9867	Economy	27900.00
0005433126983	9867	Economy	27900.00
0005434728284	9867	Economy	27900.00
0005434728554	9867	Economy	27900.00
0005435142893	9867	Economy	27900.00
0005434728631	9867	Economy	27900.00
0005434552355	9867	Economy	27900.00
0005434728802	9867	Economy	27900.00
0005434552511	9867	Economy	27900.00
0005434728222	9867	Economy	27900.00
0005434552505	9867	Economy	27900.00
0005434552702	9867	Economy	27900.00
0005434552452	9867	Economy	27900.00
0005433236052	9867	Economy	27900.00
0005434552556	9867	Economy	27900.00
0005434728547	9867	Economy	27900.00
0005434552473	9867	Economy	27900.00
0005434552331	9867	Economy	27900.00
0005434728244	9867	Economy	27900.00
0005434728665	9867	Economy	27900.00
0005434552541	9867	Economy	27900.00
0005434728557	9867	Economy	27900.00
0005434727895	9867	Economy	27900.00
0005434728333	9867	Economy	27900.00
0005434728184	9867	Economy	27900.00
0005434728585	9867	Economy	27900.00
0005434728110	9867	Economy	27900.00
0005434728278	9867	Economy	30700.00
0005434728591	9867	Economy	30700.00
0005434735821	9867	Economy	30700.00
0005435142830	9867	Economy	30700.00
0005435142831	9867	Economy	30700.00
0005434728221	9867	Economy	27900.00
0005434728548	9867	Economy	27900.00
0005434728851	9867	Economy	27900.00
0005434552309	9867	Economy	27900.00
0005434728404	9867	Economy	27900.00
0005434728085	9867	Economy	27900.00
0005434731274	9867	Economy	27900.00
0005434552602	9867	Economy	27900.00
0005434727518	9867	Economy	27900.00
0005435142836	9867	Economy	27900.00
0005434728024	9867	Economy	27900.00
0005434552420	9867	Economy	27900.00
0005434728214	9867	Economy	27900.00
0005434728533	9867	Economy	27900.00
0005434728063	9867	Economy	27900.00
0005435142870	9867	Economy	27900.00
0005434302540	9867	Economy	27900.00
0005434302554	9867	Economy	27900.00
0005435142894	9867	Economy	27900.00
0005434728494	9867	Economy	27900.00
0005434552716	9867	Economy	27900.00
0005434731264	9867	Economy	27900.00
0005434552701	9867	Economy	27900.00
0005435142832	9867	Economy	27900.00
0005433236054	9867	Economy	27900.00
0005434552463	9867	Economy	27900.00
0005435142887	9867	Economy	27900.00
0005434728113	9867	Economy	27900.00
0005434728500	9867	Economy	27900.00
0005434728723	9867	Economy	27900.00
0005434728553	9867	Economy	27900.00
0005434728800	9867	Economy	27900.00
0005433126982	9867	Economy	27900.00
0005434302561	9867	Economy	27900.00
0005435142880	9867	Economy	27900.00
0005434731269	9867	Economy	27900.00
0005434728185	9867	Economy	27900.00
0005434727896	9867	Economy	27900.00
0005434727855	9867	Economy	27900.00
0005434728799	9867	Economy	27900.00
0005434552575	9867	Economy	27900.00
0005435142923	9867	Economy	27900.00
0005434735790	9867	Economy	27900.00
0005434728166	9867	Economy	27900.00
0005435142882	9867	Economy	27900.00
0005434735787	9867	Economy	27900.00
0005434728322	9867	Economy	27900.00
0005434728759	9867	Economy	27900.00
0005434552519	9867	Economy	27900.00
0005434728383	9867	Economy	27900.00
0005434728803	9867	Economy	27900.00
0005434728169	9867	Economy	27900.00
0005433236058	9867	Economy	27900.00
0005434728513	9867	Economy	27900.00
0005434552603	9867	Economy	27900.00
0005434069635	7760	Business	42100.00
0005434069639	7760	Business	42100.00
0005435215039	7760	Business	42100.00
0005435631043	7760	Business	42100.00
0005435215201	7760	Business	42100.00
0005432531822	7760	Business	42100.00
0005434069641	7760	Business	42100.00
0005435214697	7760	Business	42100.00
0005435215211	7760	Business	42100.00
0005435215000	7760	Business	42100.00
0005435215086	7760	Business	42100.00
0005435215271	7760	Business	42100.00
0005432531824	7760	Business	42100.00
0005435725730	7760	Business	42100.00
0005433656750	7760	Comfort	23900.00
0005432531823	7760	Comfort	23900.00
0005435214920	7760	Comfort	23900.00
0005434069643	7760	Comfort	23900.00
0005435214895	7760	Comfort	23900.00
0005435215198	7760	Comfort	23900.00
0005435214911	7760	Comfort	23900.00
0005432531814	7760	Comfort	23900.00
0005432531811	7760	Comfort	23900.00
0005432531819	7760	Comfort	23900.00
0005432531826	7760	Comfort	23900.00
0005435283432	7760	Comfort	23900.00
0005435283483	7760	Comfort	23900.00
0005435215136	7760	Comfort	23900.00
0005435214922	7760	Economy	14000.00
0005435214972	7760	Economy	14000.00
0005435215040	7760	Economy	14000.00
0005435631040	7760	Economy	14000.00
0005432531821	7760	Economy	14000.00
0005435214915	7760	Economy	14000.00
0005435215199	7760	Economy	14000.00
0005435215203	7760	Economy	14000.00
0005435215343	7760	Economy	14000.00
0005435215282	7760	Economy	14000.00
0005435215166	7760	Economy	14000.00
0005435215143	7760	Economy	14000.00
0005432531812	7760	Economy	14000.00
0005434069640	7760	Economy	14000.00
0005435215031	7760	Economy	14000.00
0005435631041	7760	Economy	14000.00
0005432531820	7760	Economy	14000.00
0005432531815	7760	Economy	14000.00
0005435215095	7760	Economy	14000.00
0005435215273	7760	Economy	14000.00
0005435215216	7760	Economy	14000.00
0005435215144	7760	Economy	14000.00
0005435214973	7760	Economy	14000.00
0005435215075	7760	Economy	14000.00
0005435215270	7760	Economy	14000.00
0005435214881	7760	Economy	14000.00
0005435215245	7760	Economy	14000.00
0005435215304	7760	Economy	14000.00
0005432070080	7760	Economy	14000.00
0005435215168	7760	Economy	14000.00
0005434069642	7760	Economy	15400.00
0005434069634	7760	Economy	15400.00
0005435214696	7760	Economy	14000.00
0005435215221	7760	Economy	14000.00
0005435215212	7760	Economy	14000.00
0005435215248	7760	Economy	14000.00
0005432150428	7760	Economy	14000.00
0005435215163	7760	Economy	14000.00
0005432150429	7760	Economy	14000.00
0005435214914	7760	Economy	14000.00
0005433656744	7760	Economy	14000.00
0005435214965	7760	Economy	14000.00
0005432531810	7760	Economy	14000.00
0005432531817	7760	Economy	14000.00
0005435283456	7760	Economy	14000.00
0005435215249	7760	Economy	14000.00
0005435215200	7760	Economy	14000.00
0005435214912	7760	Economy	14000.00
0005432531818	7760	Economy	14000.00
0005435215296	7760	Economy	14000.00
0005435283464	7760	Economy	14000.00
0005435215078	7760	Economy	14000.00
0005432531813	7760	Economy	14000.00
0005435215176	7760	Economy	14000.00
0005435215318	7760	Economy	14000.00
0005435215173	7760	Economy	14000.00
0005435214992	7760	Economy	14000.00
0005435215034	7760	Economy	14000.00
0005435215138	7760	Economy	14000.00
0005434069644	7760	Economy	14000.00
0005435215001	7760	Economy	14000.00
0005435283499	7760	Economy	14000.00
0005435215139	7760	Economy	14000.00
0005435215133	7760	Economy	15400.00
0005432531825	7760	Economy	15400.00
0005434069637	7760	Economy	14000.00
0005435215297	7760	Economy	14000.00
0005435214982	7760	Economy	14000.00
0005435214956	7760	Economy	14000.00
0005435215274	7760	Economy	14000.00
0005435725703	7760	Economy	14000.00
0005435215172	7760	Economy	14000.00
0005435214882	7760	Economy	14000.00
0005435215038	7760	Economy	14000.00
0005434069638	7760	Economy	14000.00
0005432531828	7760	Economy	14000.00
0005432531809	7760	Economy	14000.00
0005432150430	7760	Economy	14000.00
0005434069636	7760	Economy	14000.00
0005432537123	7760	Economy	14000.00
0005435215272	7760	Economy	14000.00
0005435215167	7760	Economy	14000.00
0005435215077	7760	Economy	14000.00
0005435214846	7760	Economy	14000.00
0005435215393	7760	Economy	14000.00
0005435215002	7760	Economy	14000.00
0005435215135	7760	Economy	14000.00
0005432150427	7760	Economy	14000.00
0005435215197	7760	Economy	14000.00
0005435283482	7760	Economy	14000.00
0005432531816	7760	Economy	14000.00
0005435215317	7760	Economy	14000.00
0005435215206	7760	Economy	14000.00
0005435215217	7760	Economy	14000.00
0005435215329	7760	Economy	14000.00
0005432070081	7760	Economy	14000.00
0005435215012	7760	Economy	14000.00
0005435214983	7760	Economy	14000.00
0005435631044	7760	Economy	14000.00
0005432531827	7760	Economy	14000.00
0005435215026	7760	Economy	14000.00
0005435725721	7760	Economy	14000.00
0005435215394	7760	Economy	14000.00
0005435215096	7760	Economy	14000.00
0005435214923	7760	Economy	14000.00
0005435215189	7760	Economy	14000.00
0005432533379	7760	Economy	14000.00
0005435215076	7760	Economy	14000.00
0005435214966	7760	Economy	14000.00
0005435215079	7760	Economy	14000.00
0005435215030	7760	Economy	14000.00
0005435302312	5315	Business	43100.00
0005434245546	5315	Business	43100.00
0005435426155	5315	Business	43100.00
0005435617210	5315	Business	43100.00
0005434656607	5315	Business	43100.00
0005435551782	5315	Business	43100.00
0005435617041	5315	Business	43100.00
0005432133658	5315	Business	43100.00
0005434245609	5315	Business	43100.00
0005435551776	5315	Business	43100.00
0005435426734	5315	Business	43100.00
0005435319773	5315	Business	43100.00
0005435426682	5315	Business	43100.00
0005434656609	5315	Business	43100.00
0005435426457	5315	Business	43100.00
0005435617211	5315	Business	43100.00
0005435042899	5315	Business	43100.00
0005435617036	5315	Comfort	24400.00
0005435319793	5315	Comfort	24400.00
0005435426391	5315	Comfort	24400.00
0005435551779	5315	Comfort	24400.00
0005434245639	5315	Comfort	24400.00
0005435426484	5315	Comfort	24400.00
0005434245743	5315	Comfort	24400.00
0005433719217	5315	Comfort	24400.00
0005434245638	5315	Comfort	24400.00
0005435551778	5315	Comfort	24400.00
0005435319807	5315	Comfort	24400.00
0005435097503	5315	Comfort	24400.00
0005435426099	5315	Comfort	24400.00
0005435551780	5315	Comfort	24400.00
0005432841056	5315	Comfort	24400.00
0005434245594	5315	Comfort	24400.00
0005435042900	5315	Comfort	24400.00
0005435617043	5315	Comfort	24400.00
0005435042896	5315	Comfort	24400.00
0005432841067	5315	Comfort	24400.00
0005435617042	5315	Comfort	24400.00
0005435426575	5315	Comfort	24400.00
0005434245721	5315	Comfort	24400.00
0005435626887	5315	Comfort	24400.00
0005435617031	5315	Economy	14400.00
0005435302318	5315	Economy	14400.00
0005435426337	5315	Economy	14400.00
0005435426654	5315	Economy	14400.00
0005435426576	5315	Economy	14400.00
0005434345288	5315	Economy	14400.00
0005435319813	5315	Economy	14400.00
0005435426485	5315	Economy	14400.00
0005435426721	5315	Economy	14400.00
0005435426581	5315	Economy	14400.00
0005435426089	5315	Economy	14400.00
0005432047666	5315	Economy	14400.00
0005434345286	5315	Economy	14400.00
0005432133659	5315	Economy	14400.00
0005435426397	5315	Economy	14400.00
0005435319772	5315	Economy	14400.00
0005435551777	5315	Economy	14400.00
0005435426712	5315	Economy	14400.00
0005435426593	5315	Economy	14400.00
0005435426528	5315	Economy	14400.00
0005434245450	5315	Economy	14400.00
0005435319812	5315	Economy	14400.00
0005435617245	5315	Economy	14400.00
0005435042918	5315	Economy	14400.00
0005435617044	5315	Economy	14400.00
0005435426287	5315	Economy	14400.00
0005435426156	5315	Economy	14400.00
0005435617030	5315	Economy	14400.00
0005435426435	5315	Economy	14400.00
0005435617038	5315	Economy	14400.00
0005435426273	5315	Economy	14400.00
0005435426625	5315	Economy	15800.00
0005433719215	5315	Economy	15800.00
0005434245734	5315	Economy	15800.00
0005435491509	5315	Economy	15800.00
0005435426405	5315	Economy	14400.00
0005434245783	5315	Economy	14400.00
0005434245791	5315	Economy	14400.00
0005434245710	5315	Economy	14400.00
0005435491507	5315	Economy	14400.00
0005434245558	5315	Economy	14400.00
0005435426265	5315	Economy	14400.00
0005433719197	5315	Economy	14400.00
0005434245732	5315	Economy	14400.00
0005435426286	5315	Economy	14400.00
0005435426670	5315	Economy	14400.00
0005435319787	5315	Economy	14400.00
0005435426390	5315	Economy	14400.00
0005435617209	5315	Economy	14400.00
0005435426588	5315	Economy	14400.00
0005435319806	5315	Economy	14400.00
0005435626888	5315	Economy	14400.00
0005435302313	5315	Economy	14400.00
0005435617035	5315	Economy	14400.00
0005435426582	5315	Economy	14400.00
0005435426532	5315	Economy	14400.00
0005435319788	5315	Economy	14400.00
0005435617028	5315	Economy	14400.00
0005435617212	5315	Economy	14400.00
0005435426460	5315	Economy	14400.00
0005432363498	5315	Economy	14400.00
0005435491508	5315	Economy	14400.00
0005435426599	5315	Economy	14400.00
0005435426458	5315	Economy	14400.00
0005435097500	5315	Economy	14400.00
0005435426659	5315	Economy	14400.00
0005434245629	5315	Economy	14400.00
0005435426495	5315	Economy	14400.00
0005434656598	5315	Economy	14400.00
0005435426602	5315	Economy	14400.00
0005435426404	5315	Economy	14400.00
0005435617027	5315	Economy	14400.00
0005435617039	5315	Economy	14400.00
0005434245800	5315	Economy	14400.00
0005435426692	5315	Economy	14400.00
0005435302314	5315	Economy	14400.00
0005434245451	5315	Economy	14400.00
0005434245666	5315	Economy	14400.00
0005435617026	5315	Economy	14400.00
0005435426221	5315	Economy	14400.00
0005435426434	5315	Economy	14400.00
0005435319808	5315	Economy	14400.00
0005435768108	5315	Economy	14400.00
0005434345287	5315	Economy	14400.00
0005435617037	5315	Economy	14400.00
0005435302322	5315	Economy	14400.00
0005435426601	5315	Economy	14400.00
0005435042906	5315	Economy	15800.00
0005435426701	5315	Economy	15800.00
0005435617213	5315	Economy	15800.00
0005434245640	5315	Economy	15800.00
0005434656608	5315	Economy	15800.00
0005435426365	5315	Economy	14400.00
0005435426749	5315	Economy	14400.00
0005434245547	5315	Economy	14400.00
0005434656602	5315	Economy	14400.00
0005435654512	5315	Economy	14400.00
0005434245559	5315	Economy	14400.00
0005433719208	5315	Economy	14400.00
0005435551781	5315	Economy	14400.00
0005434245735	5315	Economy	14400.00
0005435617033	5315	Economy	14400.00
0005435768107	5315	Economy	14400.00
0005434245799	5315	Economy	14400.00
0005435426346	5315	Economy	14400.00
0005435426566	5315	Economy	14400.00
0005435426722	5315	Economy	14400.00
0005434245709	5315	Economy	14400.00
0005434656599	5315	Economy	14400.00
0005435426634	5315	Economy	14400.00
0005435097501	5315	Economy	14400.00
0005435617040	5315	Economy	14400.00
0005435426574	5315	Economy	14400.00
0005435302317	5315	Economy	14400.00
0005435426282	5315	Economy	14400.00
0005435556770	5315	Economy	14400.00
0005434245452	5315	Economy	14400.00
0005432841068	5315	Economy	14400.00
0005435617032	5315	Economy	14400.00
0005435426347	5315	Economy	14400.00
0005435426366	5315	Economy	14400.00
0005435302315	5315	Economy	14400.00
0005435426344	5315	Economy	14400.00
0005435617034	5315	Economy	14400.00
0005435426743	5315	Economy	14400.00
0005434245733	5315	Economy	14400.00
0005433719198	5315	Economy	14400.00
0005435042908	5315	Economy	14400.00
0005435097502	5315	Economy	14400.00
0005435426450	5315	Economy	14400.00
0005435617029	5315	Economy	14400.00
0005435426184	5315	Economy	14400.00
0005435426635	5315	Economy	14400.00
0005435426431	5315	Economy	14400.00
0005435426348	5315	Economy	14400.00
0005434245665	5315	Economy	14400.00
0005434245792	5315	Economy	14400.00
0005435319771	5315	Economy	14400.00
0005435426616	5315	Economy	14400.00
0005435426459	5315	Economy	14400.00
0005435426672	5315	Economy	14400.00
0005433719216	5315	Economy	14400.00
0005435426494	5315	Economy	14400.00
0005432133657	5315	Economy	14400.00
0005435426693	5315	Economy	14400.00
0005435305058	5315	Economy	14400.00
0005435042919	5315	Economy	14400.00
0005434245598	5315	Economy	14400.00
0005435042895	5315	Economy	14400.00
0005435426565	5315	Economy	14400.00
0005434345031	10897	Business	43100.00
0005435616215	10897	Business	43100.00
0005435616391	10897	Business	43100.00
0005435616111	10897	Business	43100.00
0005435616489	10897	Business	43100.00
0005435616036	10897	Business	43100.00
0005435426844	10897	Business	43100.00
0005434345004	10897	Business	43100.00
0005435615728	10897	Business	43100.00
0005435097430	10897	Business	43100.00
0005435616424	10897	Business	43100.00
0005435616559	10897	Business	43100.00
0005435616626	10897	Business	43100.00
0005434345113	10897	Business	43100.00
0005435616145	10897	Business	43100.00
0005435616191	10897	Comfort	24400.00
0005435491496	10897	Comfort	24400.00
0005434345111	10897	Comfort	24400.00
0005435616564	10897	Comfort	24400.00
0005435616115	10897	Comfort	24400.00
0005435615844	10897	Comfort	24400.00
0005435616340	10897	Comfort	24400.00
0005435616324	10897	Comfort	24400.00
0005434344952	10897	Comfort	24400.00
0005435616440	10897	Comfort	24400.00
0005434345112	10897	Comfort	24400.00
0005432165265	10897	Comfort	24400.00
0005435616192	10897	Comfort	24400.00
0005435616439	10897	Comfort	24400.00
0005435615923	10897	Comfort	24400.00
0005435616428	10897	Comfort	24400.00
0005435616363	10897	Comfort	24400.00
0005432165264	10897	Comfort	24400.00
0005435616467	10897	Comfort	24400.00
0005435615504	10897	Comfort	24400.00
0005434345114	10897	Comfort	24400.00
0005434345083	10897	Comfort	24400.00
0005434573652	10897	Comfort	24400.00
0005435556766	10897	Comfort	24400.00
0005434345101	10897	Comfort	24400.00
0005435615967	10897	Comfort	24400.00
0005435616444	10897	Comfort	24400.00
0005435616415	10897	Economy	14400.00
0005435616516	10897	Economy	14400.00
0005435616818	10897	Economy	14400.00
0005435616565	10897	Economy	14400.00
0005434345088	10897	Economy	14400.00
0005435616458	10897	Economy	14400.00
0005435615924	10897	Economy	14400.00
0005434245844	10897	Economy	14400.00
0005435615995	10897	Economy	14400.00
0005435616485	10897	Economy	14400.00
0005435616312	10897	Economy	14400.00
0005434344887	10897	Economy	14400.00
0005435616472	10897	Economy	14400.00
0005435097437	10897	Economy	14400.00
0005434345041	10897	Economy	14400.00
0005435615912	10897	Economy	14400.00
0005435616432	10897	Economy	14400.00
0005435616412	10897	Economy	14400.00
0005435426840	10897	Economy	14400.00
0005435616753	10897	Economy	14400.00
0005435426839	10897	Economy	14400.00
0005434345090	10897	Economy	14400.00
0005432165263	10897	Economy	14400.00
0005435616366	10897	Economy	14400.00
0005435616487	10897	Economy	14400.00
0005435616517	10897	Economy	14400.00
0005435616146	10897	Economy	14400.00
0005435616117	10897	Economy	14400.00
0005435616594	10897	Economy	14400.00
0005435616035	10897	Economy	14400.00
0005435616077	10897	Economy	14400.00
0005434345007	10897	Economy	14400.00
0005435616231	10897	Economy	14400.00
0005435616154	10897	Economy	14400.00
0005435616349	10897	Economy	14400.00
0005435426845	10897	Economy	14400.00
0005435616292	10897	Economy	14400.00
0005435616585	10897	Economy	14400.00
0005434573649	10897	Economy	15800.00
0005435616227	10897	Economy	14400.00
0005435616888	10897	Economy	14400.00
0005435616442	10897	Economy	15800.00
0005435616484	10897	Economy	15800.00
0005435616503	10897	Economy	14400.00
0005434573655	10897	Economy	15800.00
0005434245843	10897	Economy	14400.00
0005435616796	10897	Economy	14400.00
0005434344988	10897	Economy	14400.00
0005435616394	10897	Economy	14400.00
0005435319828	10897	Economy	14400.00
0005434345052	10897	Economy	14400.00
0005435616430	10897	Economy	14400.00
0005434345001	10897	Economy	14400.00
0005435616750	10897	Economy	14400.00
0005435615913	10897	Economy	14400.00
0005435616499	10897	Economy	14400.00
0005435491498	10897	Economy	14400.00
0005434345040	10897	Economy	14400.00
0005434245845	10897	Economy	14400.00
0005434573653	10897	Economy	14400.00
0005435616364	10897	Economy	14400.00
0005435616674	10897	Economy	14400.00
0005435616367	10897	Economy	14400.00
0005435616441	10897	Economy	14400.00
0005435616214	10897	Economy	14400.00
0005435616627	10897	Economy	14400.00
0005435616342	10897	Economy	14400.00
0005435616690	10897	Economy	14400.00
0005434345087	10897	Economy	14400.00
0005434344860	10897	Economy	14400.00
0005434344997	10897	Economy	14400.00
0005434573656	10897	Economy	14400.00
0005434344932	10897	Economy	14400.00
0005435616886	10897	Economy	14400.00
0005435616033	10897	Economy	14400.00
0005434345091	10897	Economy	14400.00
0005435616885	10897	Economy	14400.00
0005435616015	10897	Economy	14400.00
0005435616021	10897	Economy	14400.00
0005434573692	10897	Economy	14400.00
0005435426842	10897	Economy	14400.00
0005434345080	10897	Economy	14400.00
0005435490317	10897	Economy	14400.00
0005435616390	10897	Economy	14400.00
0005435555417	10897	Economy	14400.00
0005435768123	10897	Economy	14400.00
0005434345000	10897	Economy	14400.00
0005435616429	10897	Economy	14400.00
0005435616062	10897	Economy	14400.00
0005434573651	10897	Economy	14400.00
0005434344933	10897	Economy	14400.00
0005435616608	10897	Economy	14400.00
0005435616134	10897	Economy	14400.00
0005435615769	10897	Economy	14400.00
0005435616752	10897	Economy	14400.00
0005435616466	10897	Economy	14400.00
0005434344769	10897	Economy	14400.00
0005434345063	10897	Economy	14400.00
0005434344972	10897	Economy	14400.00
0005435616225	10897	Economy	14400.00
0005434573684	10897	Economy	14400.00
0005435616628	10897	Economy	14400.00
0005435616014	10897	Economy	14400.00
0005435616093	10897	Economy	14400.00
0005435616037	10897	Economy	14400.00
0005435616029	10897	Economy	14400.00
0005434345002	10897	Economy	15800.00
0005435616321	10897	Economy	15800.00
0005435616290	10897	Economy	15800.00
0005435616302	10897	Economy	14400.00
0005434344963	10897	Economy	14400.00
0005435616395	10897	Economy	14400.00
0005435616483	10897	Economy	14400.00
0005434345061	10897	Economy	14400.00
0005435097450	10897	Economy	14400.00
0005435615996	10897	Economy	14400.00
0005434344962	10897	Economy	14400.00
0005435616473	10897	Economy	14400.00
0005435616347	10897	Economy	14400.00
0005435616550	10897	Economy	14400.00
0005434344970	10897	Economy	14400.00
0005435616502	10897	Economy	14400.00
0005435615962	10897	Economy	14400.00
0005435616703	10897	Economy	14400.00
0005435615966	10897	Economy	14400.00
0005435616769	10897	Economy	14400.00
0005435616704	10897	Economy	14400.00
0005434344994	10897	Economy	14400.00
0005435616207	10897	Economy	14400.00
0005435616561	10897	Economy	14400.00
0005435426843	10897	Economy	14400.00
0005435616595	10897	Economy	14400.00
0005434345100	10897	Economy	14400.00
0005435616365	10897	Economy	14400.00
0005434345062	10897	Economy	14400.00
0005435616538	10897	Economy	14400.00
0005434345106	10897	Economy	14400.00
0005434344764	10897	Economy	14400.00
0005435616178	10897	Economy	14400.00
0005434344971	10897	Economy	14400.00
0005435616749	10897	Economy	14400.00
0005435616116	10897	Economy	14400.00
0005435426841	10897	Economy	14400.00
0005435616423	10897	Economy	14400.00
0005435616593	10897	Economy	14400.00
0005435616490	10897	Economy	14400.00
0005435616537	10897	Economy	14400.00
0005435616819	10897	Economy	14400.00
0005435616303	10897	Economy	14400.00
0005434345039	10897	Economy	14400.00
0005434344981	10897	Economy	14400.00
0005435616459	10897	Economy	14400.00
0005435615843	10897	Economy	14400.00
0005435490310	10897	Economy	14400.00
0005434573685	10897	Economy	14400.00
0005435616560	10897	Economy	14400.00
0005434344987	10897	Economy	14400.00
0005435616206	10897	Economy	14400.00
0005435616571	10897	Economy	14400.00
0005434344888	10897	Economy	14400.00
0005435097389	10897	Economy	14400.00
0005435616887	10897	Economy	14400.00
0005435616061	10897	Economy	14400.00
0005434573650	10897	Economy	14400.00
0005435615899	10897	Economy	14400.00
0005432460945	3261	Business	18800.00
0005434150221	3261	Business	18800.00
0005434266037	3261	Business	18800.00
0005433507729	3261	Business	18800.00
0005434266027	3261	Business	18800.00
0005432461098	3261	Business	18800.00
0005432461133	3261	Business	18800.00
0005434266029	3261	Business	18800.00
0005434266023	3261	Business	18800.00
0005432461064	3261	Business	18800.00
0005434150215	3261	Business	18800.00
0005432461037	3261	Business	18800.00
0005435856351	3261	Business	18800.00
0005432460991	3261	Business	18800.00
0005434266014	3261	Business	18800.00
0005432460834	3261	Business	18800.00
0005432460990	3261	Business	18800.00
0005434143859	3261	Business	18800.00
0005432461277	3261	Business	18800.00
0005434266018	3261	Business	18800.00
0005434266035	3261	Business	18800.00
0005432461072	3261	Business	18800.00
0005432461191	3261	Economy	6900.00
0005432461017	3261	Economy	6900.00
0005432460944	3261	Economy	6900.00
0005432460929	3261	Economy	6900.00
0005432461074	3261	Economy	6900.00
0005435142986	3261	Economy	6300.00
0005434311283	3261	Economy	6300.00
0005432460933	3261	Economy	6300.00
0005432461093	3261	Economy	6300.00
0005435856336	3261	Economy	6300.00
0005433806405	3261	Economy	6300.00
0005432461089	3261	Economy	6300.00
0005434311282	3261	Economy	6300.00
0005434150224	3261	Economy	6300.00
0005432461038	3261	Economy	6300.00
0005432461033	3261	Economy	6300.00
0005434150229	3261	Economy	6300.00
0005432461088	3261	Economy	6300.00
0005432461148	3261	Economy	6300.00
0005432461236	3261	Economy	6300.00
0005434150222	3261	Economy	6300.00
0005434266026	3261	Economy	6300.00
0005432461097	3261	Economy	6300.00
0005435142987	3261	Economy	6300.00
0005434266020	3261	Economy	6300.00
0005432461235	3261	Economy	6300.00
0005434266028	3261	Economy	6300.00
0005434150225	3261	Economy	6300.00
0005432461073	3261	Economy	6300.00
0005434150216	3261	Economy	6300.00
0005434266013	3261	Economy	6300.00
0005432461090	3261	Economy	6300.00
0005433806409	3261	Economy	6300.00
0005435860643	3261	Economy	6300.00
0005434150220	3261	Economy	6300.00
0005433806408	3261	Economy	6300.00
0005434266019	3261	Economy	6300.00
0005433507730	3261	Economy	6300.00
0005432461109	3261	Economy	6300.00
0005434143858	3261	Economy	6300.00
0005433507731	3261	Economy	6300.00
0005432182369	3261	Economy	6300.00
0005432460857	3261	Economy	6300.00
0005434266036	3261	Economy	6300.00
0005434266012	3261	Economy	6300.00
0005434150227	3261	Economy	6300.00
0005435142977	3261	Economy	6300.00
0005432461176	3261	Economy	6300.00
0005432461175	3261	Economy	6300.00
0005435856346	3261	Economy	6300.00
0005432460930	3261	Economy	6300.00
0005434266021	3261	Economy	6300.00
0005434266017	3261	Economy	6900.00
0005434266016	3261	Economy	6900.00
0005432461132	3261	Economy	6900.00
0005432461002	3261	Economy	6900.00
0005435629452	3261	Economy	6900.00
0005434150218	3261	Economy	6300.00
0005433634826	3261	Economy	6300.00
0005432461311	3261	Economy	6300.00
0005434266015	3261	Economy	6300.00
0005432461077	3261	Economy	6300.00
0005432461114	3261	Economy	6300.00
0005432461094	3261	Economy	6300.00
0005432460928	3261	Economy	6300.00
0005434150226	3261	Economy	6300.00
0005432461153	3261	Economy	6300.00
0005432461229	3261	Economy	6300.00
0005433507728	3261	Economy	6300.00
0005432460856	3261	Economy	6300.00
0005435142978	3261	Economy	6300.00
0005434266024	3261	Economy	6300.00
0005432461127	3261	Economy	6300.00
0005434266033	3261	Economy	6300.00
0005434266030	3261	Economy	6300.00
0005432461225	3261	Economy	6300.00
0005432461010	3261	Economy	6300.00
0005432461057	3261	Economy	6300.00
0005432461078	3261	Economy	6300.00
0005432461009	3261	Economy	6300.00
0005434266010	3261	Economy	6300.00
0005432182368	3261	Economy	6300.00
0005434150219	3261	Economy	6300.00
0005433634828	3261	Economy	6300.00
0005433634823	3261	Economy	6300.00
0005433634824	3261	Economy	6300.00
0005433806406	3261	Economy	6300.00
0005433806404	3261	Economy	6300.00
0005434150228	3261	Economy	6300.00
0005434266009	3261	Economy	6300.00
0005432461248	3261	Economy	6300.00
0005432460886	3261	Economy	6300.00
0005432460966	3261	Economy	6300.00
0005432461063	3261	Economy	6300.00
0005433806407	3261	Economy	6300.00
0005432461278	3261	Economy	6300.00
0005432460975	3261	Economy	6300.00
0005434266032	3261	Economy	6300.00
0005434266031	3261	Economy	6300.00
0005434266034	3261	Economy	6300.00
0005435856352	3261	Economy	6300.00
0005432461095	3261	Economy	6300.00
0005434266022	3261	Economy	6300.00
0005432461137	3261	Economy	6300.00
0005434266038	3261	Economy	6300.00
0005432460885	3261	Economy	6300.00
0005432461249	3261	Economy	6300.00
0005434150223	3261	Economy	6300.00
0005432461310	3261	Economy	6300.00
0005432461136	3261	Economy	6300.00
0005434266011	3261	Economy	6300.00
0005433634825	3261	Economy	6300.00
0005435858698	3261	Economy	6300.00
0005432460974	3261	Economy	6300.00
0005434266025	3261	Economy	6300.00
0005435142980	3261	Economy	6300.00
0005434150217	3261	Economy	6300.00
0005435142975	3261	Economy	6300.00
0005433634827	3261	Economy	6300.00
0005435886726	3262	Business	18800.00
0005435886542	3262	Business	18800.00
0005435886367	3262	Business	18800.00
0005435886415	3262	Business	18800.00
0005435886341	3262	Business	18800.00
0005435886332	3262	Business	18800.00
0005435886556	3262	Business	18800.00
0005435886411	3262	Business	18800.00
0005435886495	3262	Economy	6900.00
0005435886402	3262	Economy	6900.00
0005435886408	3262	Economy	6300.00
0005435886712	3262	Economy	6300.00
0005435886413	3262	Economy	6300.00
0005435886591	3262	Economy	6300.00
0005435886324	3262	Economy	6300.00
0005435886353	3262	Economy	6300.00
0005435886266	3262	Economy	6300.00
0005435886502	3262	Economy	6300.00
0005435886536	3262	Economy	6300.00
0005435886337	3262	Economy	6300.00
0005435886433	3262	Economy	6300.00
0005435886505	3262	Economy	6300.00
0005435886451	3262	Economy	6300.00
0005435886412	3262	Economy	6300.00
0005435886421	3262	Economy	6300.00
0005435886414	3262	Economy	6300.00
0005435886449	3262	Economy	6300.00
0005435886347	3262	Economy	6300.00
0005435886427	3262	Economy	6300.00
0005435886535	3262	Economy	6300.00
0005435886345	3262	Economy	6300.00
0005435886623	3262	Economy	6300.00
0005435886432	3262	Economy	6900.00
0005435886530	3262	Economy	6900.00
0005435886447	3262	Economy	6300.00
0005435886517	3262	Economy	6300.00
0005435886156	3262	Economy	6300.00
0005435886422	3262	Economy	6300.00
0005435886541	3262	Economy	6300.00
0005435886457	3262	Economy	6300.00
0005435886496	3262	Economy	6300.00
0005435886400	3262	Economy	6300.00
0005435886448	3262	Economy	6300.00
0005435886538	3262	Economy	6300.00
0005435886467	3262	Economy	6300.00
0005435886189	3262	Economy	6300.00
0005435886379	3262	Economy	6300.00
0005435886364	3262	Economy	6300.00
0005435886537	3262	Economy	6300.00
0005435886555	3262	Economy	6300.00
0005435886606	3262	Economy	6300.00
0005435886733	3262	Economy	6300.00
0005435886423	3262	Economy	6300.00
0005435886344	3262	Economy	6300.00
0005435886600	3262	Economy	6300.00
0005435886426	3262	Economy	6300.00
0005435886568	3262	Economy	6300.00
0005435886401	3262	Economy	6300.00
0005435886325	3262	Economy	6300.00
0005432043132	8177	Business	18800.00
0005433507523	8177	Business	18800.00
0005433507707	8177	Business	18800.00
0005435886855	8177	Business	18800.00
0005435886862	8177	Business	18800.00
0005435886866	8177	Business	18800.00
0005433507616	8177	Economy	6900.00
0005433507667	8177	Economy	6900.00
0005432461436	8177	Economy	6900.00
0005433507672	8177	Economy	6900.00
0005432043131	8177	Economy	6300.00
0005435886858	8177	Economy	6300.00
0005433507606	8177	Economy	6300.00
0005433507609	8177	Economy	6300.00
0005433507608	8177	Economy	6300.00
0005432461431	8177	Economy	6300.00
0005435886865	8177	Economy	6300.00
0005433507633	8177	Economy	6300.00
0005435886856	8177	Economy	6300.00
0005433507658	8177	Economy	6300.00
0005434326108	8177	Economy	6300.00
0005434326109	8177	Economy	6300.00
0005433507621	8177	Economy	6300.00
0005433507622	8177	Economy	6300.00
0005432461433	8177	Economy	6300.00
0005435886860	8177	Economy	6300.00
0005435886867	8177	Economy	6300.00
0005435903233	8177	Economy	6300.00
0005435886863	8177	Economy	6300.00
0005435903231	8177	Economy	6300.00
0005435886868	8177	Economy	6300.00
0005433507524	8177	Economy	6300.00
0005432043135	8177	Economy	6900.00
0005432461434	8177	Economy	6300.00
0005433507639	8177	Economy	6900.00
0005435903234	8177	Economy	6300.00
0005433507539	8177	Economy	6300.00
0005432461432	8177	Economy	6300.00
0005433507640	8177	Economy	6300.00
0005433507563	8177	Economy	6300.00
0005432043134	8177	Economy	6300.00
0005435886854	8177	Economy	6300.00
0005433507617	8177	Economy	6300.00
0005435886864	8177	Economy	6300.00
0005435886861	8177	Economy	6300.00
0005432043133	8177	Economy	6300.00
0005433507629	8177	Economy	6300.00
0005433507671	8177	Economy	6300.00
0005433507666	8177	Economy	6300.00
0005435903230	8177	Economy	6300.00
0005435886859	8177	Economy	6300.00
0005432461435	8177	Economy	6300.00
0005435886857	8177	Economy	6300.00
0005435903232	8177	Economy	6300.00
0005433507681	8177	Economy	6300.00
0005433507527	8177	Economy	6300.00
0005432461430	8177	Economy	6300.00
0005433507618	8177	Economy	6300.00
0005433507592	8177	Economy	6300.00
0005433806181	8178	Business	18800.00
0005434143763	8178	Business	18800.00
0005433806189	8178	Business	18800.00
0005433806145	8178	Business	18800.00
0005433806179	8178	Business	18800.00
0005433806182	8178	Business	18800.00
0005433634797	8178	Business	18800.00
0005433634702	8178	Business	18800.00
0005433634554	8178	Business	18800.00
0005433634790	8178	Business	18800.00
0005433634750	8178	Business	18800.00
0005433634502	8178	Business	18800.00
0005433634329	8178	Business	18800.00
0005433634645	8178	Economy	6900.00
0005433806212	8178	Economy	6900.00
0005435858744	8178	Economy	6900.00
0005433806087	8178	Economy	6300.00
0005434271370	8178	Economy	6300.00
0005433806262	8178	Economy	6300.00
0005435860732	8178	Economy	6300.00
0005433806213	8178	Economy	6300.00
0005433806271	8178	Economy	6300.00
0005433634631	8178	Economy	6300.00
0005433806227	8178	Economy	6300.00
0005433634535	8178	Economy	6300.00
0005433634519	8178	Economy	6300.00
0005433806251	8178	Economy	6300.00
0005433806309	8178	Economy	6300.00
0005433806305	8178	Economy	6300.00
0005433806270	8178	Economy	6300.00
0005433634584	8178	Economy	6300.00
0005433806086	8178	Economy	6300.00
0005433806308	8178	Economy	6300.00
0005433634544	8178	Economy	6300.00
0005433806151	8178	Economy	6300.00
0005433806210	8178	Economy	6300.00
0005433634543	8178	Economy	6300.00
0005433634643	8178	Economy	6300.00
0005433634648	8178	Economy	6300.00
0005433634330	8178	Economy	6300.00
0005433634512	8178	Economy	6300.00
0005433806383	8178	Economy	6300.00
0005433806039	8178	Economy	6300.00
0005433806153	8178	Economy	6300.00
0005433634674	8178	Economy	6300.00
0005433634691	8178	Economy	6300.00
0005433806207	8178	Economy	6300.00
0005433634615	8178	Economy	6900.00
0005433634586	8178	Economy	6900.00
0005433806261	8178	Economy	6900.00
0005433634731	8178	Economy	6300.00
0005433806288	8178	Economy	6300.00
0005433634542	8178	Economy	6300.00
0005433634618	8178	Economy	6300.00
0005433634642	8178	Economy	6300.00
0005435860731	8178	Economy	6300.00
0005433634766	8178	Economy	6300.00
0005433806301	8178	Economy	6300.00
0005433634500	8178	Economy	6300.00
0005433806232	8178	Economy	6300.00
0005433634765	8178	Economy	6300.00
0005433634616	8178	Economy	6300.00
0005433634617	8178	Economy	6300.00
0005433806214	8178	Economy	6300.00
0005433634585	8178	Economy	6300.00
0005433806194	8178	Economy	6300.00
0005433806304	8178	Economy	6300.00
0005433806199	8178	Economy	6300.00
0005433634662	8178	Economy	6300.00
0005433806190	8178	Economy	6300.00
0005433634627	8178	Economy	6300.00
0005433634583	8178	Economy	6300.00
0005433806211	8178	Economy	6300.00
0005433806302	8178	Economy	6300.00
0005435858745	8178	Economy	6300.00
0005433806124	8178	Economy	6300.00
0005433806188	8178	Economy	6300.00
0005433634644	8178	Economy	6300.00
0005433634501	8178	Economy	6300.00
0005433806369	8178	Economy	6300.00
0005434143762	8178	Economy	6300.00
0005433634646	8178	Economy	6300.00
0005433806178	8178	Economy	6300.00
0005434183628	8185	Economy	6300.00
0005434183627	8185	Economy	6300.00
0005434183634	8185	Economy	6300.00
0005434150154	8185	Economy	6300.00
0005434150153	8185	Economy	6300.00
0005434183625	8185	Economy	6300.00
0005434183626	8185	Economy	6300.00
0005432728311	4538	Business	9900.00
0005432384338	4538	Business	9900.00
0005432384336	4538	Business	9900.00
0005433195009	4538	Economy	3300.00
0005432728309	4538	Economy	3300.00
0005434300268	4538	Economy	3600.00
0005432384337	4538	Economy	3300.00
0005433195012	4538	Economy	3300.00
0005433195014	4538	Economy	3300.00
0005434300271	4538	Economy	3300.00
0005433195010	4538	Economy	3300.00
0005434300269	4538	Economy	3300.00
0005432384339	4538	Economy	3300.00
0005433195011	4538	Economy	3300.00
0005434300270	4538	Economy	3300.00
0005433195013	4538	Economy	3300.00
0005432728310	4538	Economy	3300.00
0005433195008	4538	Economy	3300.00
0005433722509	4538	Economy	3300.00
0005432383944	30170	Business	9900.00
0005432383936	30170	Business	9900.00
0005432728237	30170	Business	9900.00
0005432383958	30170	Business	9900.00
0005432384099	30170	Business	9900.00
0005432383865	30170	Economy	3300.00
0005433194911	30170	Economy	3300.00
0005433451656	30170	Economy	3300.00
0005432384030	30170	Economy	3300.00
0005432383855	30170	Economy	3300.00
0005433453807	30170	Economy	3300.00
0005433194925	30170	Economy	3300.00
0005433194909	30170	Economy	3600.00
0005432384082	30170	Economy	3600.00
0005432384081	30170	Economy	3300.00
0005432384071	30170	Economy	3300.00
0005432383854	30170	Economy	3300.00
0005432383738	30170	Economy	3300.00
0005433722331	30170	Economy	3300.00
0005432383881	30170	Economy	3300.00
0005432728217	30170	Economy	3300.00
0005432383971	30170	Economy	3300.00
0005433451662	30170	Economy	3300.00
0005433722348	30170	Economy	3300.00
0005432384031	30170	Economy	3300.00
0005432384100	30170	Economy	3300.00
0005432383737	30170	Economy	3300.00
0005432384063	30170	Economy	3300.00
0005433453801	30170	Economy	3300.00
0005432383779	30170	Economy	3300.00
0005432383964	30170	Economy	3300.00
0005433451671	30170	Economy	3300.00
0005432383826	30170	Economy	3300.00
0005433194941	30170	Economy	3300.00
0005432383833	30170	Economy	3300.00
0005433451670	30170	Economy	3300.00
0005432383945	30170	Economy	3300.00
0005432383998	30170	Economy	3300.00
0005432728234	30170	Economy	3300.00
0005433194942	30170	Economy	3300.00
0005432383788	30170	Economy	3300.00
0005432728229	30170	Economy	3300.00
0005433722352	30170	Economy	3300.00
0005432383906	30170	Economy	3300.00
0005432384160	30170	Economy	3300.00
0005432383832	30170	Economy	3300.00
0005433722349	30170	Economy	3300.00
0005433453796	30170	Economy	3300.00
0005433722357	30170	Economy	3300.00
0005432728216	30170	Economy	3300.00
0005433453808	30170	Economy	3300.00
0005432383827	30170	Economy	3300.00
0005432384064	30170	Economy	3300.00
0005432384000	30170	Economy	3300.00
0005432383848	30170	Economy	3300.00
0005433722324	30170	Economy	3300.00
0005432383966	30170	Economy	3300.00
0005432383943	30170	Economy	3300.00
0005432384115	30170	Economy	3300.00
0005432383829	30170	Economy	3300.00
0005435541644	1736	Business	57200.00
0005435541646	1736	Economy	21000.00
0005433517165	1736	Economy	19100.00
0005432925161	1736	Economy	19100.00
0005435529900	1736	Economy	19100.00
0005435529898	1736	Economy	19100.00
0005435541645	1736	Economy	19100.00
0005432925160	1736	Economy	19100.00
0005432925159	1736	Economy	19100.00
0005435530196	1736	Economy	19100.00
0005435529899	1736	Economy	19100.00
0005435530197	1736	Economy	19100.00
0005435541524	22019	Business	57200.00
0005435541554	22019	Business	57200.00
0005435541475	22019	Business	57200.00
0005435541523	22019	Business	57200.00
0005435541532	22019	Business	57200.00
0005433517097	22019	Economy	19100.00
0005435518376	22019	Economy	19100.00
0005435541511	22019	Economy	19100.00
0005435541447	22019	Economy	19100.00
0005435518342	22019	Economy	19100.00
0005435541416	22019	Economy	21000.00
0005435541546	22019	Economy	21000.00
0005433517154	22019	Economy	19100.00
0005433517127	22019	Economy	19100.00
0005435541588	22019	Economy	19100.00
0005433517098	22019	Economy	19100.00
0005435518343	22019	Economy	19100.00
0005435541470	22019	Economy	19100.00
0005435518347	22019	Economy	19100.00
0005435541455	22019	Economy	19100.00
0005435518323	22019	Economy	19100.00
0005435518280	22019	Economy	19100.00
0005435541585	22019	Economy	19100.00
0005435541512	22019	Economy	19100.00
0005435518295	22019	Economy	19100.00
0005435541553	22019	Economy	19100.00
0005435518296	22019	Economy	19100.00
0005435541531	22019	Economy	19100.00
0005435541522	22019	Economy	19100.00
0005435541530	22019	Economy	19100.00
0005433517091	22019	Economy	19100.00
0005435541424	22019	Economy	19100.00
0005435518287	22019	Economy	19100.00
0005435541561	22019	Economy	19100.00
0005433517090	22019	Economy	19100.00
0005435518278	22019	Economy	19100.00
0005435541502	22019	Economy	19100.00
0005435541517	22019	Economy	19100.00
0005435518345	22019	Economy	19100.00
0005435541469	22019	Economy	19100.00
0005435541448	22019	Economy	19100.00
0005435541507	22019	Economy	19100.00
0005433517153	22019	Economy	19100.00
0005433517128	22019	Economy	19100.00
0005433517085	22019	Economy	19100.00
0005435541453	22019	Economy	19100.00
0005435541570	22019	Economy	19100.00
0005435541589	22019	Economy	19100.00
0005435541590	22019	Economy	19100.00
0005435253130	7365	Business	18500.00
0005435253129	7365	Business	18500.00
0005432073496	7365	Economy	6200.00
0005435253082	7365	Economy	6200.00
0005432823508	7365	Economy	6800.00
0005435491487	7365	Economy	6800.00
0005435253106	7365	Economy	6800.00
0005435253142	7365	Economy	6200.00
0005435253073	7365	Economy	6200.00
0005434459416	7365	Economy	6200.00
0005435253192	7365	Economy	6200.00
0005435253108	7365	Economy	6200.00
0005435253143	7365	Economy	6200.00
0005435491481	7365	Economy	6200.00
0005432073497	7365	Economy	6200.00
0005434459420	7365	Economy	6200.00
0005434459418	7365	Economy	6200.00
0005434459417	7365	Economy	6200.00
0005435253164	7365	Economy	6200.00
0005435253109	7365	Economy	6200.00
0005432823509	7365	Economy	6200.00
0005435253062	7365	Economy	6200.00
0005435253147	7365	Economy	6200.00
0005435253190	7365	Economy	6200.00
0005434459419	7365	Economy	6200.00
0005435491494	7365	Economy	6200.00
0005435253137	7365	Economy	6200.00
0005435253174	7365	Economy	6200.00
0005435253193	7365	Economy	6200.00
0005435253107	7365	Economy	6200.00
0005434459295	28905	Business	18500.00
0005432839887	28905	Business	18500.00
0005432839812	28905	Business	18500.00
0005432839867	28905	Business	18500.00
0005432839817	28905	Business	18500.00
0005432839701	28905	Business	18500.00
0005432839744	28905	Business	18500.00
0005432823500	28905	Business	18500.00
0005432841061	28905	Business	18500.00
0005432839853	28905	Business	18500.00
0005432839828	28905	Economy	6200.00
0005434459303	28905	Economy	6200.00
0005432839731	28905	Economy	6200.00
0005434459289	28905	Economy	6200.00
0005432823491	28905	Economy	6200.00
0005432841066	28905	Economy	6200.00
0005434459184	28905	Economy	6800.00
0005432839757	28905	Economy	6800.00
0005432839892	28905	Economy	6800.00
0005432839906	28905	Economy	6200.00
0005434665026	28905	Economy	6200.00
0005432839857	28905	Economy	6200.00
0005434459333	28905	Economy	6200.00
0005434459383	28905	Economy	6200.00
0005432839743	28905	Economy	6200.00
0005432823499	28905	Economy	6200.00
0005434459332	28905	Economy	6200.00
0005434459207	28905	Economy	6200.00
0005432839886	28905	Economy	6200.00
0005432841060	28905	Economy	6200.00
0005432839856	28905	Economy	6200.00
0005432839746	28905	Economy	6200.00
0005432839882	28905	Economy	6200.00
0005432839821	28905	Economy	6200.00
0005432839858	28905	Economy	6200.00
0005432839694	28905	Economy	6200.00
0005432823495	28905	Economy	6200.00
0005432839609	28905	Economy	6200.00
0005434459288	28905	Economy	6200.00
0005432839891	28905	Economy	6200.00
0005432839683	28905	Economy	6200.00
0005434459291	28905	Economy	6200.00
0005434459373	28905	Economy	6200.00
0005432839745	28905	Economy	6200.00
0005434459294	28905	Economy	6200.00
0005434459302	28905	Economy	6200.00
0005434459290	28905	Economy	6200.00
0005432839750	28905	Economy	6200.00
0005434459318	28905	Economy	6200.00
0005432839732	28905	Economy	6200.00
0005432839751	28905	Economy	6200.00
0005434459258	28905	Economy	6200.00
0005432839733	28905	Economy	6200.00
0005432839700	28905	Economy	6200.00
0005432839827	28905	Economy	6200.00
0005432839854	28905	Economy	6200.00
0005432839760	28905	Economy	6200.00
0005435990833	8783	Business	145300.00
0005434276180	8783	Business	145300.00
0005435987064	8783	Economy	48400.00
0005434276182	8783	Economy	48400.00
0005434276197	8783	Economy	48400.00
0005435990807	15713	Economy	48400.00
0005435990778	15713	Economy	53300.00
0005435990796	15713	Economy	53300.00
0005435990775	15713	Economy	48400.00
0005435990755	15713	Economy	48400.00
0005435990776	15713	Economy	48400.00
0005435990784	15713	Economy	48400.00
0005433435530	15713	Economy	48400.00
0005435990756	15713	Economy	48400.00
0005432909403	2076	Economy	12100.00
0005432909392	2076	Economy	12100.00
0005432909416	2076	Economy	12100.00
0005432909430	2076	Economy	12100.00
0005432909418	2076	Economy	12100.00
0005433468606	2076	Economy	12100.00
0005432909426	2076	Economy	12100.00
0005432909425	2076	Economy	12100.00
0005432909419	2076	Economy	12100.00
0005432909413	2076	Economy	12100.00
0005432909387	2076	Economy	12100.00
0005432909386	2076	Economy	12100.00
0005432909408	2076	Economy	12100.00
0005432909391	2076	Economy	12100.00
0005432909415	2076	Economy	12100.00
0005433468608	2076	Economy	12100.00
0005432909402	2076	Economy	12100.00
0005432909431	2076	Economy	12100.00
0005432909399	2076	Economy	12100.00
0005432909404	2076	Economy	12100.00
0005432909412	2076	Economy	12100.00
0005432909405	2076	Economy	12100.00
0005433468607	2076	Economy	12100.00
0005432909409	2076	Economy	12100.00
0005432909400	2076	Economy	12100.00
0005434149995	6415	Business	36600.00
0005432361769	6415	Business	36600.00
0005435177726	6415	Business	36600.00
0005434150031	6415	Business	36600.00
0005434150009	6415	Business	36600.00
0005435177737	6415	Business	36600.00
0005435177686	6415	Economy	12200.00
0005435177724	6415	Economy	12200.00
0005432361764	6415	Economy	12200.00
0005435177758	6415	Economy	12200.00
0005435177688	6415	Economy	12200.00
0005435177630	6415	Economy	12200.00
0005435177665	6415	Economy	12200.00
0005435177785	6415	Economy	12200.00
0005434150019	6415	Economy	12200.00
0005435177708	6415	Economy	12200.00
0005435490310	6415	Economy	12200.00
0005434150030	6415	Economy	12200.00
0005435177666	6415	Economy	12200.00
0005432361766	6415	Economy	12200.00
0005434150014	6415	Economy	12200.00
0005435177723	6415	Economy	12200.00
0005435177687	6415	Economy	12200.00
0005434149994	6415	Economy	12200.00
0005435177813	6415	Economy	12200.00
0005435177831	6415	Economy	13400.00
0005432361767	6415	Economy	13400.00
0005435723092	6415	Economy	13400.00
0005435177701	6415	Economy	13400.00
0005435177716	6415	Economy	12200.00
0005435177748	6415	Economy	12200.00
0005435177749	6415	Economy	12200.00
0005434150007	6415	Economy	12200.00
0005435177707	6415	Economy	12200.00
0005434150029	6415	Economy	12200.00
0005435177719	6415	Economy	12200.00
0005434150022	6415	Economy	12200.00
0005432361765	6415	Economy	12200.00
0005434150006	6415	Economy	12200.00
0005435177804	6415	Economy	12200.00
0005435177629	6415	Economy	12200.00
0005435177720	6415	Economy	12200.00
0005435177777	6415	Economy	12200.00
0005435177826	6415	Economy	12200.00
0005435723083	6415	Economy	12200.00
0005434150017	6415	Economy	12200.00
0005435177778	6415	Economy	12200.00
0005435490317	6415	Economy	12200.00
0005435177765	6415	Economy	12200.00
0005435177791	6415	Economy	12200.00
0005432361770	6415	Economy	12200.00
0005434150010	6415	Economy	12200.00
0005434149978	6415	Economy	12200.00
0005435177757	6415	Economy	12200.00
0005434150013	6415	Economy	12200.00
0005432361768	6415	Economy	12200.00
0005434150018	6415	Economy	12200.00
0005434150023	6415	Economy	12200.00
0005435177781	6415	Economy	12200.00
0005434149971	6415	Economy	12200.00
0005435723107	20983	Business	36600.00
0005432336315	20983	Business	36600.00
0005432361103	20983	Business	36600.00
0005432361441	20983	Business	36600.00
0005432361645	20983	Business	36600.00
0005432361487	20983	Business	36600.00
0005432361576	20983	Business	36600.00
0005432361349	20983	Economy	12200.00
0005432361418	20983	Economy	12200.00
0005432361535	20983	Economy	12200.00
0005432361625	20983	Economy	12200.00
0005432361414	20983	Economy	12200.00
0005432363499	20983	Economy	12200.00
0005435177872	20983	Economy	12200.00
0005432363506	20983	Economy	12200.00
0005432336334	20983	Economy	12200.00
0005435177874	20983	Economy	12200.00
0005432336299	20983	Economy	12200.00
0005432336314	20983	Economy	12200.00
0005432361484	20983	Economy	12200.00
0005435723108	20983	Economy	12200.00
0005432336292	20983	Economy	12200.00
0005432336360	20983	Economy	12200.00
0005432363505	20983	Economy	12200.00
0005432361542	20983	Economy	12200.00
0005432361442	20983	Economy	12200.00
0005432361594	20983	Economy	12200.00
0005432361579	20983	Economy	12200.00
0005432336325	20983	Economy	12200.00
0005432363496	20983	Economy	12200.00
0005432361550	20983	Economy	13400.00
0005432361669	20983	Economy	13400.00
0005432336313	20983	Economy	12200.00
0005432361534	20983	Economy	12200.00
0005432336316	20983	Economy	12200.00
0005432361471	20983	Economy	12200.00
0005432363497	20983	Economy	12200.00
0005432361415	20983	Economy	12200.00
0005432361670	20983	Economy	12200.00
0005434150080	20983	Economy	12200.00
0005432361443	20983	Economy	12200.00
0005432361486	20983	Economy	12200.00
0005432361348	20983	Economy	12200.00
0005435177873	20983	Economy	12200.00
0005432361485	20983	Economy	12200.00
0005432361454	20983	Economy	12200.00
0005432361453	20983	Economy	12200.00
0005432336341	20983	Economy	12200.00
0005435177875	20983	Economy	12200.00
0005432361483	20983	Economy	12200.00
0005432361494	20983	Economy	12200.00
0005432361470	20983	Economy	12200.00
0005432361578	20983	Economy	12200.00
0005432361327	20983	Economy	12200.00
0005432361472	20983	Economy	12200.00
0005434150079	20983	Economy	12200.00
0005432361646	20983	Economy	12200.00
0005432361591	20983	Economy	12200.00
0005432361577	20983	Economy	12200.00
0005432336296	20983	Economy	12200.00
0005434463980	17733	Economy	3400.00
0005434463981	17733	Economy	3400.00
0005434459304	17733	Economy	3400.00
0005434459284	17733	Economy	3100.00
0005434459263	17733	Economy	3100.00
0005434459241	17733	Economy	3100.00
0005434459330	17733	Economy	3100.00
0005434459334	17733	Economy	3100.00
0005434459351	17733	Economy	3100.00
0005434459268	17733	Economy	3100.00
0005434459349	17733	Economy	3100.00
0005434459361	17733	Economy	3100.00
0005434448399	17733	Economy	3100.00
0005434463985	17733	Economy	3100.00
0005434459326	17733	Economy	3100.00
0005434459362	17733	Economy	3100.00
0005434459245	17733	Economy	3100.00
0005434459331	17733	Economy	3100.00
0005434459327	17733	Economy	3100.00
0005434459310	17733	Economy	3100.00
0005434461685	17733	Economy	3100.00
0005434459337	17733	Economy	3100.00
0005434459363	17733	Economy	3100.00
0005434461690	17733	Economy	3100.00
0005434459202	17733	Economy	3100.00
0005434459380	17733	Economy	3100.00
0005434459364	17733	Economy	3100.00
0005434459368	17733	Economy	3100.00
0005434463983	17733	Economy	3100.00
0005434459244	17733	Economy	3100.00
0005434459322	17733	Economy	3100.00
0005434461686	17733	Economy	3100.00
0005434459354	17733	Economy	3100.00
0005434459353	17733	Economy	3100.00
0005434459287	17733	Economy	3100.00
0005434459243	17733	Economy	3100.00
0005434463984	17733	Economy	3100.00
0005434186280	29078	Economy	3100.00
0005434186267	29078	Economy	3100.00
0005434459419	29078	Economy	3100.00
0005434459417	29078	Economy	3100.00
0005434459418	29078	Economy	3100.00
0005434459420	29078	Economy	3100.00
0005434459416	29078	Economy	3100.00
0005432605493	21440	Economy	7300.00
0005432605498	21440	Economy	6600.00
0005432605496	21440	Economy	6600.00
0005432605492	21440	Economy	6600.00
0005432605501	21440	Economy	6600.00
0005432605495	21440	Economy	6600.00
0005432605491	21440	Economy	6600.00
0005432605494	21440	Economy	6600.00
0005432605502	21440	Economy	6600.00
0005432605500	21440	Economy	6600.00
0005435220506	21440	Economy	6600.00
0005432605497	21440	Economy	6600.00
0005432605503	21440	Economy	6600.00
0005435220507	21440	Economy	6600.00
0005432605499	21440	Economy	6600.00
0005435220508	21440	Economy	6600.00
0005435218129	21440	Economy	6600.00
0005435218133	21440	Economy	6600.00
0005435220510	21440	Economy	6600.00
0005432605213	31706	Economy	7300.00
0005432605212	31706	Economy	7300.00
0005432605223	31706	Economy	7300.00
0005432605329	31706	Economy	7300.00
0005432605054	31706	Economy	6600.00
0005432605220	31706	Economy	6600.00
0005432605193	31706	Economy	6600.00
0005432605165	31706	Economy	6600.00
0005432605283	31706	Economy	6600.00
0005432605187	31706	Economy	6600.00
0005432605190	31706	Economy	6600.00
0005432605112	31706	Economy	6600.00
0005432605109	31706	Economy	6600.00
0005432605074	31706	Economy	6600.00
0005432605221	31706	Economy	6600.00
0005432605113	31706	Economy	6600.00
0005432605257	31706	Economy	6600.00
0005432605214	31706	Economy	6600.00
0005432605211	31706	Economy	6600.00
0005432605328	31706	Economy	6600.00
0005432605222	31706	Economy	6600.00
0005432605240	31706	Economy	6600.00
0005432605188	31706	Economy	6600.00
0005432605327	31706	Economy	6600.00
0005432605392	31706	Economy	6600.00
0005432605263	31706	Economy	6600.00
0005432605288	31706	Economy	6600.00
0005432605277	31706	Economy	6600.00
0005432605289	31706	Economy	6600.00
0005432605146	31706	Economy	6600.00
0005432605062	31706	Economy	6600.00
0005432605367	31706	Economy	6600.00
0005432605279	31706	Economy	6600.00
0005432605274	31706	Economy	6600.00
0005432605075	31706	Economy	6600.00
0005432605306	31706	Economy	6600.00
0005432605241	31706	Economy	6600.00
0005432605145	31706	Economy	6600.00
0005432605338	31706	Economy	6600.00
0005432605278	31706	Economy	6600.00
0005432605282	31706	Economy	6600.00
0005435154652	29613	Economy	19500.00
0005435154666	29613	Economy	17800.00
0005435154642	29613	Economy	17800.00
0005433293439	29613	Economy	17800.00
0005433293440	29613	Economy	17800.00
0005433293441	29613	Economy	17800.00
0005435154667	29613	Economy	17800.00
0005433293443	29613	Economy	17800.00
0005435154648	29613	Economy	17800.00
0005435154663	29613	Economy	17800.00
0005435154659	29613	Economy	17800.00
0005435154655	29613	Economy	17800.00
0005435154646	29613	Economy	17800.00
0005435154641	29613	Economy	17800.00
0005433293442	29613	Economy	17800.00
0005435154640	29613	Economy	17800.00
0005435154637	29613	Economy	17800.00
0005435154654	29613	Economy	17800.00
0005435154629	29613	Economy	17800.00
0005435154658	29613	Economy	17800.00
0005435154638	29613	Economy	17800.00
0005435154649	29613	Economy	17800.00
0005435257328	6693	Economy	14000.00
0005433473535	6693	Economy	14000.00
0005435257329	6693	Economy	12700.00
0005435257338	6693	Economy	12700.00
0005435257354	6693	Economy	12700.00
0005435257330	6693	Economy	12700.00
0005435257352	6693	Economy	12700.00
0005435257361	6693	Economy	12700.00
0005433473532	6693	Economy	12700.00
0005435257350	6693	Economy	12700.00
0005435257362	6693	Economy	12700.00
0005435257353	6693	Economy	12700.00
0005435257375	6693	Economy	12700.00
0005435257360	6693	Economy	12700.00
0005435257372	6693	Economy	12700.00
0005435257337	6693	Economy	12700.00
0005435257359	6693	Economy	12700.00
0005433473534	6693	Economy	12700.00
0005435257348	6693	Economy	12700.00
0005433473533	6693	Economy	12700.00
0005435257358	6693	Economy	12700.00
0005435257351	6693	Economy	12700.00
0005434603022	18850	Economy	6600.00
0005434603021	18850	Economy	6600.00
0005434606914	18850	Economy	6600.00
0005434606913	18850	Economy	6600.00
0005434606912	18850	Economy	6600.00
0005434606899	18850	Economy	6600.00
0005434605007	22311	Economy	6600.00
0005435904908	22311	Economy	6600.00
0005434606937	22311	Economy	6600.00
0005434606936	22311	Economy	6600.00
0005435904719	22311	Economy	6600.00
0005435904720	22311	Economy	6600.00
0005432891408	386	Business	44500.00
0005432891491	386	Business	44500.00
0005432891452	386	Business	44500.00
0005432891564	386	Business	44500.00
0005432220131	386	Business	44500.00
0005434152852	386	Business	44500.00
0005433875414	386	Economy	14800.00
0005434152854	386	Economy	14800.00
0005432891369	386	Economy	14800.00
0005434152856	386	Economy	14800.00
0005432891493	386	Economy	14800.00
0005432748681	386	Economy	16300.00
0005432748682	386	Economy	16300.00
0005434152855	386	Economy	14800.00
0005433293389	386	Economy	14800.00
0005433293415	386	Economy	14800.00
0005433293386	386	Economy	14800.00
0005435154707	386	Economy	14800.00
0005433293385	386	Economy	14800.00
0005434152865	386	Economy	14800.00
0005432891484	386	Economy	14800.00
0005434151802	386	Economy	14800.00
0005435154708	386	Economy	14800.00
0005433293417	386	Economy	14800.00
0005433293399	386	Economy	14800.00
0005432891439	386	Economy	14800.00
0005432891563	386	Economy	14800.00
0005432891507	386	Economy	14800.00
0005434152866	386	Economy	14800.00
0005434151799	386	Economy	14800.00
0005433875422	386	Economy	14800.00
0005432891506	386	Economy	14800.00
0005432891492	386	Economy	14800.00
0005432891440	386	Economy	14800.00
0005433293398	386	Economy	14800.00
0005433293403	386	Economy	14800.00
0005432891527	386	Economy	14800.00
0005434152853	386	Economy	14800.00
0005433293390	386	Economy	14800.00
0005432891462	386	Economy	14800.00
0005432891451	386	Economy	14800.00
0005432891445	386	Economy	14800.00
0005433293414	386	Economy	14800.00
0005433293416	386	Economy	14800.00
0005432891407	386	Economy	14800.00
0005432220132	386	Economy	14800.00
0005432748366	12058	Business	44500.00
0005432753388	12058	Business	44500.00
0005432748514	12058	Business	44500.00
0005432748513	12058	Business	44500.00
0005432748428	12058	Business	44500.00
0005432748586	12058	Economy	14800.00
0005432748551	12058	Economy	14800.00
0005432748443	12058	Economy	14800.00
0005434153585	12058	Economy	14800.00
0005432748337	12058	Economy	14800.00
0005432748307	12058	Economy	16300.00
0005432748308	12058	Economy	16300.00
0005432748490	12058	Economy	16300.00
0005432748429	12058	Economy	16300.00
0005432748507	12058	Economy	14800.00
0005432753386	12058	Economy	14800.00
0005432748573	12058	Economy	14800.00
0005432753379	12058	Economy	14800.00
0005432748587	12058	Economy	14800.00
0005432891594	12058	Economy	14800.00
0005433875430	12058	Economy	14800.00
0005435627128	12058	Economy	14800.00
0005432748479	12058	Economy	14800.00
0005432891591	12058	Economy	14800.00
0005432748493	12058	Economy	14800.00
0005435627124	12058	Economy	14800.00
0005432748616	12058	Economy	14800.00
0005432753371	12058	Economy	14800.00
0005432748649	12058	Economy	14800.00
0005432748356	12058	Economy	14800.00
0005432748301	12058	Economy	14800.00
0005432748386	12058	Economy	14800.00
0005433875431	12058	Economy	14800.00
0005432748481	12058	Economy	14800.00
0005434152872	12058	Economy	14800.00
0005432891595	12058	Economy	14800.00
0005432748572	12058	Economy	14800.00
0005434152873	12058	Economy	14800.00
0005434153586	12058	Economy	14800.00
0005432891593	12058	Economy	14800.00
0005432748249	12058	Economy	14800.00
0005432753380	12058	Economy	14800.00
0005432748336	12058	Economy	14800.00
0005432748478	12058	Economy	14800.00
0005432748407	12058	Economy	14800.00
0005432748309	12058	Economy	14800.00
0005432756923	12058	Economy	14800.00
0005432891596	12058	Economy	14800.00
0005432748617	12058	Economy	14800.00
0005432748408	12058	Economy	14800.00
0005432748491	12058	Economy	14800.00
0005432748584	12058	Economy	14800.00
0005432753381	12058	Economy	14800.00
0005432749838	12058	Economy	14800.00
0005432891592	12058	Economy	14800.00
0005432748492	12058	Economy	14800.00
0005432928115	18976	Economy	25700.00
0005432928126	18976	Economy	25700.00
0005433533421	18976	Economy	25700.00
0005432928114	18976	Economy	25700.00
0005433525361	18976	Economy	25700.00
0005432928112	18976	Economy	25700.00
0005433533422	18976	Economy	25700.00
0005432928116	18976	Economy	25700.00
0005433525359	18976	Economy	25700.00
0005433525360	18976	Economy	25700.00
0005432928113	18976	Economy	25700.00
0005432928125	18976	Economy	25700.00
0005433525362	18976	Economy	25700.00
0005433531367	32503	Economy	28200.00
0005433525281	32503	Economy	28200.00
0005433527359	32503	Economy	28200.00
0005433525303	32503	Economy	25700.00
0005433531375	32503	Economy	25700.00
0005433525323	32503	Economy	25700.00
0005433525324	32503	Economy	25700.00
0005433525347	32503	Economy	25700.00
0005433527353	32503	Economy	25700.00
0005433527358	32503	Economy	25700.00
0005433525302	32503	Economy	25700.00
0005433525296	32503	Economy	25700.00
0005433527360	32503	Economy	25700.00
0005433525325	32503	Economy	25700.00
0005433525282	32503	Economy	25700.00
0005433527354	32503	Economy	25700.00
0005433525285	32503	Economy	25700.00
0005433531368	32503	Economy	25700.00
0005433527357	32503	Economy	25700.00
0005435315007	5246	Business	84000.00
0005434665025	5246	Business	84000.00
0005435374929	5246	Business	84000.00
0005435374890	5246	Business	84000.00
0005434827280	5246	Business	84000.00
0005435374772	5246	Business	84000.00
0005434827289	5246	Business	84000.00
0005435374870	5246	Business	84000.00
0005435374722	5246	Business	84000.00
0005435374863	5246	Business	84000.00
0005435374599	5246	Business	84000.00
0005435374647	5246	Business	84000.00
0005435374746	5246	Comfort	47600.00
0005432121753	5246	Comfort	47600.00
0005435386741	5246	Comfort	47600.00
0005435375001	5246	Comfort	47600.00
0005435314984	5246	Comfort	47600.00
0005435374646	5246	Comfort	47600.00
0005434827287	5246	Comfort	47600.00
0005435315009	5246	Comfort	47600.00
0005434827276	5246	Comfort	47600.00
0005434827283	5246	Comfort	47600.00
0005435374884	5246	Comfort	47600.00
0005435374795	5246	Comfort	47600.00
0005435374920	5246	Comfort	47600.00
0005435179710	5246	Comfort	47600.00
0005435374817	5246	Comfort	47600.00
0005435661999	5246	Comfort	47600.00
0005434827291	5246	Comfort	47600.00
0005435386713	5246	Comfort	47600.00
0005434827285	5246	Comfort	47600.00
0005435374794	5246	Economy	28000.00
0005435314999	5246	Economy	28000.00
0005435374596	5246	Economy	28000.00
0005435374748	5246	Economy	28000.00
0005435315000	5246	Economy	28000.00
0005435375062	5246	Economy	28000.00
0005435150437	5246	Economy	28000.00
0005435374594	5246	Economy	28000.00
0005435150435	5246	Economy	28000.00
0005435374827	5246	Economy	28000.00
0005435374643	5246	Economy	28000.00
0005435374350	5246	Economy	28000.00
0005435374723	5246	Economy	28000.00
0005435375060	5246	Economy	28000.00
0005435374858	5246	Economy	28000.00
0005435374591	5246	Economy	28000.00
0005435374791	5246	Economy	28000.00
0005435374783	5246	Economy	28000.00
0005435315065	5246	Economy	28000.00
0005434558611	5246	Economy	28000.00
0005434827278	5246	Economy	28000.00
0005435374892	5246	Economy	28000.00
0005435374635	5246	Economy	30800.00
0005435374871	5246	Economy	28000.00
0005435661981	5246	Economy	28000.00
0005435374648	5246	Economy	28000.00
0005434827286	5246	Economy	28000.00
0005435299904	5246	Economy	28000.00
0005435662000	5246	Economy	28000.00
0005435374633	5246	Economy	28000.00
0005435374574	5246	Economy	28000.00
0005435315006	5246	Economy	28000.00
0005434827274	5246	Economy	28000.00
0005434827275	5246	Economy	28000.00
0005434558610	5246	Economy	28000.00
0005434827281	5246	Economy	28000.00
0005435374881	5246	Economy	28000.00
0005435374634	5246	Economy	28000.00
0005435374887	5246	Economy	28000.00
0005435150434	5246	Economy	28000.00
0005434827288	5246	Economy	28000.00
0005434558613	5246	Economy	28000.00
0005435374747	5246	Economy	28000.00
0005435315071	5246	Economy	28000.00
0005435299905	5246	Economy	28000.00
0005435304257	5246	Economy	28000.00
0005435374801	5246	Economy	28000.00
0005435386720	5246	Economy	28000.00
0005434827290	5246	Economy	28000.00
0005435374650	5246	Economy	28000.00
0005435299862	5246	Economy	28000.00
0005435374802	5246	Economy	28000.00
0005435304259	5246	Economy	28000.00
0005435374961	5246	Economy	28000.00
0005434827282	5246	Economy	28000.00
0005435374930	5246	Economy	28000.00
0005434827284	5246	Economy	28000.00
0005435374859	5246	Economy	28000.00
0005435299887	5246	Economy	28000.00
0005435299863	5246	Economy	28000.00
0005435386721	5246	Economy	28000.00
0005435314970	5246	Economy	28000.00
0005434558612	5246	Economy	30800.00
0005435374818	5246	Economy	30800.00
0005435304253	5246	Economy	28000.00
0005435374566	5246	Economy	28000.00
0005435150436	5246	Economy	28000.00
0005435374908	5246	Economy	28000.00
0005435374805	5246	Economy	28000.00
0005435735234	5246	Economy	28000.00
0005435374857	5246	Economy	28000.00
0005435315034	5246	Economy	28000.00
0005435661990	5246	Economy	28000.00
0005434665024	5246	Economy	28000.00
0005435386725	5246	Economy	28000.00
0005435374590	5246	Economy	28000.00
0005435374810	5246	Economy	28000.00
0005435374970	5246	Economy	28000.00
0005435374803	5246	Economy	28000.00
0005435661991	5246	Economy	28000.00
0005435374595	5246	Economy	28000.00
0005435374567	5246	Economy	28000.00
0005435374886	5246	Economy	28000.00
0005435374939	5246	Economy	28000.00
0005435179010	5246	Economy	28000.00
0005435314985	5246	Economy	28000.00
0005435374351	5246	Economy	28000.00
0005434827277	5246	Economy	28000.00
0005432823501	5246	Economy	28000.00
0005435375061	5246	Economy	28000.00
0005435315008	5246	Economy	28000.00
0005434827273	5246	Economy	28000.00
0005435374804	5246	Economy	28000.00
0005434558614	5246	Economy	28000.00
0005435150433	5246	Economy	28000.00
0005435374573	5246	Economy	28000.00
0005435735227	5246	Economy	28000.00
0005435374630	5246	Economy	28000.00
0005435315022	5246	Economy	28000.00
0005434827279	5246	Economy	28000.00
0005435386737	5246	Economy	28000.00
0005435374542	5246	Economy	28000.00
0005434826915	9910	Business	84000.00
0005434826569	9910	Business	84000.00
0005435150362	9910	Business	84000.00
0005434826472	9910	Business	84000.00
0005434826192	9910	Business	84000.00
0005434558465	9910	Business	84000.00
0005434826397	9910	Business	84000.00
0005434826816	9910	Business	84000.00
0005434826448	9910	Business	84000.00
0005434826182	9910	Business	84000.00
0005434826447	9910	Business	84000.00
0005434826797	9910	Comfort	47600.00
0005434826440	9910	Comfort	47600.00
0005434826628	9910	Comfort	47600.00
0005434826676	9910	Comfort	47600.00
0005435150283	9910	Comfort	47600.00
0005434826750	9910	Comfort	47600.00
0005432396343	9910	Comfort	47600.00
0005434827125	9910	Comfort	47600.00
0005434558494	9910	Comfort	47600.00
0005432396329	9910	Comfort	47600.00
0005434826540	9910	Comfort	47600.00
0005434825907	9910	Comfort	47600.00
0005435150379	9910	Comfort	47600.00
0005434826817	9910	Comfort	47600.00
0005434831272	9910	Comfort	47600.00
0005434826079	9910	Economy	28000.00
0005434826769	9910	Economy	28000.00
0005435375172	9910	Economy	28000.00
0005434826867	9910	Economy	28000.00
0005434826556	9910	Economy	28000.00
0005434826365	9910	Economy	28000.00
0005434558457	9910	Economy	28000.00
0005434826687	9910	Economy	28000.00
0005434558495	9910	Economy	28000.00
0005434826581	9910	Economy	28000.00
0005434826808	9910	Economy	28000.00
0005434827054	9910	Economy	28000.00
0005434826155	9910	Economy	28000.00
0005434827055	9910	Economy	28000.00
0005434826880	9910	Economy	28000.00
0005434826529	9910	Economy	28000.00
0005434558461	9910	Economy	28000.00
0005434826287	9910	Economy	28000.00
0005434826260	9910	Economy	28000.00
0005434826181	9910	Economy	28000.00
0005435150331	9910	Economy	28000.00
0005434826124	9910	Economy	28000.00
0005434826677	9910	Economy	28000.00
0005434826207	9910	Economy	28000.00
0005434831252	9910	Economy	28000.00
0005434828757	9910	Economy	28000.00
0005434826502	9910	Economy	28000.00
0005434826881	9910	Economy	28000.00
0005435375176	9910	Economy	28000.00
0005434826395	9910	Economy	28000.00
0005435375171	9910	Economy	30800.00
0005434826868	9910	Economy	30800.00
0005434826761	9910	Economy	28000.00
0005434558496	9910	Economy	30800.00
0005435150365	9910	Economy	28000.00
0005434826660	9910	Economy	28000.00
0005434826747	9910	Economy	28000.00
0005434826541	9910	Economy	28000.00
0005434826583	9910	Economy	28000.00
0005434826702	9910	Economy	28000.00
0005434826253	9910	Economy	28000.00
0005435375174	9910	Economy	28000.00
0005434826930	9910	Economy	28000.00
0005434558464	9910	Economy	28000.00
0005434826451	9910	Economy	28000.00
0005434558467	9910	Economy	28000.00
0005434826999	9910	Economy	28000.00
0005434826465	9910	Economy	28000.00
0005435150333	9910	Economy	28000.00
0005434826746	9910	Economy	28000.00
0005434558469	9910	Economy	28000.00
0005434558466	9910	Economy	28000.00
0005434826959	9910	Economy	28000.00
0005434826191	9910	Economy	28000.00
0005434826386	9910	Economy	28000.00
0005435150367	9910	Economy	28000.00
0005434826252	9910	Economy	28000.00
0005434826250	9910	Economy	28000.00
0005434665015	9910	Economy	28000.00
0005434826218	9910	Economy	28000.00
0005434826950	9910	Economy	28000.00
0005434826404	9910	Economy	28000.00
0005434826423	9910	Economy	28000.00
0005434826251	9910	Economy	28000.00
0005434826515	9910	Economy	28000.00
0005432396338	9910	Economy	28000.00
0005434826471	9910	Economy	28000.00
0005434826570	9910	Economy	28000.00
0005434826487	9910	Economy	28000.00
0005434826952	9910	Economy	28000.00
0005435150378	9910	Economy	28000.00
0005434826273	9910	Economy	28000.00
0005435375177	9910	Economy	28000.00
0005435150260	9910	Economy	28000.00
0005434558470	9910	Economy	28000.00
0005434826864	9910	Economy	28000.00
0005434558459	9910	Economy	28000.00
0005434558458	9910	Economy	28000.00
0005434826376	9910	Economy	28000.00
0005434826592	9910	Economy	28000.00
0005434826693	9910	Economy	30800.00
0005434826964	9910	Economy	30800.00
0005434826555	9910	Economy	30800.00
0005434826749	9910	Economy	28000.00
0005434827036	9910	Economy	28000.00
0005435315141	9910	Economy	28000.00
0005434558491	9910	Economy	28000.00
0005434826156	9910	Economy	28000.00
0005434826709	9910	Economy	28000.00
0005434826078	9910	Economy	28000.00
0005435315140	9910	Economy	28000.00
0005432396339	9910	Economy	28000.00
0005435375175	9910	Economy	28000.00
0005435375173	9910	Economy	28000.00
0005434826539	9910	Economy	28000.00
0005434827037	9910	Economy	28000.00
0005434826694	9910	Economy	28000.00
0005434826042	9910	Economy	28000.00
0005434826744	9910	Economy	28000.00
0005434826573	9910	Economy	28000.00
0005435150377	9910	Economy	28000.00
0005434826521	9910	Economy	28000.00
0005434826571	9910	Economy	28000.00
0005434826916	9910	Economy	28000.00
0005434826989	9910	Economy	28000.00
0005434826293	9910	Economy	28000.00
0005434827038	9910	Economy	28000.00
0005434827123	9910	Economy	28000.00
0005435315139	9910	Economy	28000.00
0005434826533	9910	Economy	28000.00
0005434826572	9910	Economy	28000.00
0005434828758	9910	Economy	28000.00
0005432400210	9910	Economy	28000.00
0005434826262	9910	Economy	28000.00
0005434826577	9910	Economy	28000.00
0005434826634	9910	Economy	28000.00
0005434826743	9910	Economy	28000.00
0005434826332	9910	Economy	28000.00
0005434826785	9910	Economy	28000.00
0005434826424	9910	Economy	28000.00
0005434826261	9910	Economy	28000.00
0005434826963	9910	Economy	28000.00
0005434827124	9910	Economy	28000.00
0005435150284	9910	Economy	28000.00
0005432396345	9910	Economy	28000.00
0005435375170	9910	Economy	28000.00
0005434826331	9910	Economy	28000.00
0005435083035	7005	Economy	8200.00
0005435083037	7005	Economy	7400.00
0005435083038	7005	Economy	7400.00
0005435083036	7005	Economy	7400.00
0005435082963	26021	Economy	8200.00
0005435082960	26021	Economy	8200.00
0005435790385	26021	Economy	7400.00
0005435082964	26021	Economy	7400.00
0005435082995	26021	Economy	7400.00
0005435082975	26021	Economy	7400.00
0005435082954	26021	Economy	7400.00
0005435082959	26021	Economy	7400.00
0005435082953	26021	Economy	7400.00
0005434215481	9548	Business	32800.00
0005434215590	9548	Business	32800.00
0005434757685	9548	Business	32800.00
0005434215548	9548	Business	32800.00
0005434215685	9548	Business	32800.00
0005434215452	9548	Business	32800.00
0005434215489	9548	Business	32800.00
0005434215687	9548	Business	32800.00
0005434215639	9548	Economy	10900.00
0005434757684	9548	Economy	10900.00
0005434215683	9548	Economy	10900.00
0005434215383	9548	Economy	10900.00
0005434215599	9548	Economy	10900.00
0005434215682	9548	Economy	10900.00
0005434215576	9548	Economy	12000.00
0005434215618	9548	Economy	10900.00
0005434215723	9548	Economy	10900.00
0005434215619	9548	Economy	10900.00
0005434215386	9548	Economy	10900.00
0005434215663	9548	Economy	10900.00
0005434215661	9548	Economy	10900.00
0005434215755	9548	Economy	10900.00
0005434215540	9548	Economy	10900.00
0005434215592	9548	Economy	10900.00
0005434215573	9548	Economy	10900.00
0005434215704	9548	Economy	10900.00
0005434215392	9548	Economy	10900.00
0005434215744	9548	Economy	10900.00
0005434215513	9548	Economy	10900.00
0005434215722	9548	Economy	10900.00
0005434215587	9548	Economy	10900.00
0005434215694	9548	Economy	10900.00
0005434215557	9548	Economy	10900.00
0005434215684	9548	Economy	10900.00
0005434215591	9548	Economy	10900.00
0005434215807	9548	Economy	10900.00
0005434215520	9548	Economy	10900.00
0005434215615	9548	Economy	10900.00
0005434215384	9548	Economy	10900.00
0005434215730	9548	Economy	10900.00
0005434215385	9548	Economy	10900.00
0005434215556	9548	Economy	10900.00
0005434215808	9548	Economy	10900.00
0005434215546	9548	Economy	10900.00
0005434215655	9548	Economy	10900.00
0005434215617	9548	Economy	10900.00
0005434215659	9548	Economy	10900.00
0005434215483	9548	Economy	10900.00
0005434215570	9548	Economy	10900.00
0005434215888	28599	Business	32800.00
0005434757426	28599	Business	32800.00
0005434757424	28599	Business	32800.00
0005434757392	28599	Business	32800.00
0005434757407	28599	Business	32800.00
0005434757429	28599	Business	32800.00
0005434757348	28599	Business	32800.00
0005434215879	28599	Business	32800.00
0005434215892	28599	Business	32800.00
0005434757391	28599	Business	32800.00
0005434757246	28599	Economy	10900.00
0005434757369	28599	Economy	10900.00
0005434215886	28599	Economy	10900.00
0005434757370	28599	Economy	10900.00
0005434215893	28599	Economy	10900.00
0005434757245	28599	Economy	10900.00
0005434757390	28599	Economy	12000.00
0005434757227	28599	Economy	12000.00
0005434757279	28599	Economy	12000.00
0005434215894	28599	Economy	10900.00
0005434757280	28599	Economy	10900.00
0005434757388	28599	Economy	10900.00
0005434215880	28599	Economy	10900.00
0005434215883	28599	Economy	10900.00
0005434757449	28599	Economy	10900.00
0005434757394	28599	Economy	10900.00
0005434757207	28599	Economy	10900.00
0005434757360	28599	Economy	10900.00
0005434756996	28599	Economy	10900.00
0005434215891	28599	Economy	10900.00
0005434757136	28599	Economy	10900.00
0005434757195	28599	Economy	10900.00
0005434757324	28599	Economy	10900.00
0005434757425	28599	Economy	10900.00
0005434757375	28599	Economy	10900.00
0005434757510	28599	Economy	10900.00
0005434757371	28599	Economy	10900.00
0005434215885	28599	Economy	10900.00
0005434757518	28599	Economy	10900.00
0005434757414	28599	Economy	10900.00
0005434757511	28599	Economy	10900.00
0005434757413	28599	Economy	10900.00
0005434215881	28599	Economy	10900.00
0005434757342	28599	Economy	10900.00
0005434757137	28599	Economy	10900.00
0005434757277	28599	Economy	10900.00
0005434757373	28599	Economy	10900.00
0005434757150	28599	Economy	10900.00
0005434757460	28599	Economy	10900.00
0005434757206	28599	Economy	10900.00
0005434215889	28599	Economy	10900.00
0005434757340	28599	Economy	10900.00
0005434215890	28599	Economy	10900.00
0005434757491	28599	Economy	10900.00
0005434757396	28599	Economy	10900.00
0005434757180	28599	Economy	10900.00
0005434757445	28599	Economy	10900.00
0005434757537	28599	Economy	10900.00
0005434757208	28599	Economy	10900.00
0005434215882	28599	Economy	10900.00
0005434757395	28599	Economy	10900.00
0005434757341	28599	Economy	10900.00
0005434757444	28599	Economy	10900.00
0005434757415	28599	Economy	10900.00
0005434757416	28599	Economy	10900.00
0005434757362	28599	Economy	10900.00
0005434215887	28599	Economy	10900.00
0005434215884	28599	Economy	10900.00
0005434757417	28599	Economy	10900.00
0005434760261	10863	Economy	9800.00
0005434760260	10863	Economy	8900.00
0005434760259	10863	Economy	8900.00
0005434760263	10863	Economy	8900.00
0005434760258	10863	Economy	8900.00
0005435100210	10863	Economy	8900.00
0005435100211	10863	Economy	8900.00
0005433202730	1958	Economy	20900.00
0005433202725	1958	Economy	20900.00
0005433202724	1958	Economy	20900.00
0005434640103	1958	Economy	19000.00
0005434640104	1958	Economy	19000.00
0005433202764	1958	Economy	19000.00
0005433202669	1958	Economy	19000.00
0005433202675	1958	Economy	19000.00
0005433202680	1958	Economy	19000.00
0005433202745	1958	Economy	19000.00
0005433202676	1958	Economy	19000.00
0005433202712	1958	Economy	19000.00
0005433202695	1958	Economy	19000.00
0005433202748	1958	Economy	19000.00
0005434640102	1958	Economy	19000.00
0005433202685	1958	Economy	19000.00
0005433202694	1958	Economy	19000.00
0005433202684	1958	Economy	19000.00
0005433202747	1958	Economy	19000.00
0005433202711	1958	Economy	19000.00
0005433202709	1958	Economy	19000.00
0005433202661	1958	Economy	19000.00
0005433202705	1958	Economy	19000.00
0005433202710	1958	Economy	19000.00
0005433202720	1958	Economy	19000.00
0005433202633	1958	Economy	19000.00
0005435948345	23291	Economy	20900.00
0005433202792	23291	Economy	20900.00
0005434639983	23291	Economy	19000.00
0005434639820	23291	Economy	19000.00
0005435948354	23291	Economy	19000.00
0005434639854	23291	Economy	19000.00
0005434639921	23291	Economy	19000.00
0005434639931	23291	Economy	19000.00
0005434639872	23291	Economy	19000.00
0005434639853	23291	Economy	19000.00
0005434639822	23291	Economy	19000.00
0005433202791	23291	Economy	19000.00
0005434639874	23291	Economy	19000.00
0005434639821	23291	Economy	19000.00
0005434639869	23291	Economy	19000.00
0005434639875	23291	Economy	19000.00
0005435948344	23291	Economy	19000.00
0005434639884	23291	Economy	19000.00
0005434639870	23291	Economy	19000.00
0005434639871	23291	Economy	19000.00
0005434640038	23291	Economy	19000.00
0005433202790	23291	Economy	19000.00
0005434639883	23291	Economy	19000.00
0005434639866	23291	Economy	19000.00
0005434639922	23291	Economy	19000.00
0005435948355	23291	Economy	19000.00
0005434639917	23291	Economy	19000.00
0005433202789	23291	Economy	19000.00
0005434639920	23291	Economy	19000.00
0005435327106	6090	Business	69700.00
0005435327107	6090	Business	69700.00
0005434601592	6090	Economy	23200.00
0005434601590	6090	Economy	23200.00
0005435327075	6090	Economy	25600.00
0005435327094	6090	Economy	23200.00
0005435327066	6090	Economy	23200.00
0005434601591	6090	Economy	23200.00
0005434601511	18563	Business	69700.00
0005434601477	18563	Business	69700.00
0005434601405	18563	Economy	23200.00
0005434601458	18563	Economy	23200.00
0005434601445	18563	Economy	23200.00
0005433531381	18563	Economy	23200.00
0005434601350	18563	Economy	23200.00
0005434601476	18563	Economy	25600.00
0005434601570	18563	Economy	23200.00
0005433527362	18563	Economy	23200.00
0005434601417	18563	Economy	23200.00
0005434601446	18563	Economy	23200.00
0005434601485	18563	Economy	23200.00
0005434601415	18563	Economy	23200.00
0005434601416	18563	Economy	23200.00
0005434601478	18563	Economy	23200.00
0005434601457	18563	Economy	23200.00
0005434601484	18563	Economy	23200.00
0005434601482	18563	Economy	23200.00
0005434601407	18563	Economy	23200.00
0005434601408	18563	Economy	23200.00
0005434601481	18563	Economy	23200.00
0005434601483	18563	Economy	23200.00
0005433527356	18563	Economy	23200.00
0005434601546	18563	Economy	23200.00
0005434601456	18563	Economy	23200.00
0005434601437	18563	Economy	23200.00
0005433531393	18563	Economy	23200.00
0005434601414	18563	Economy	23200.00
0005433527361	18563	Economy	23200.00
0005434601552	18563	Economy	23200.00
0005433527338	18563	Economy	23200.00
0005433531385	18563	Economy	23200.00
0005434601351	18563	Economy	23200.00
0005434601491	18563	Economy	23200.00
0005434601475	18563	Economy	23200.00
0005434601406	18563	Economy	23200.00
0005434601495	18563	Economy	23200.00
0005434601418	18563	Economy	23200.00
0005435314981	10562	Business	9100.00
0005435315054	10562	Business	9100.00
0005435315043	10562	Business	9100.00
0005434552849	10562	Business	9100.00
0005433181769	10562	Business	9100.00
0005435315013	10562	Business	9100.00
0005434558604	10562	Business	9100.00
0005433181699	10562	Business	9100.00
0005435315030	10562	Business	9100.00
0005434552856	10562	Business	9100.00
0005433181595	10562	Economy	3000.00
0005434552846	10562	Economy	3000.00
0005435314976	10562	Economy	3000.00
0005435314967	10562	Economy	3000.00
0005434552851	10562	Economy	3000.00
0005434552848	10562	Economy	3000.00
0005435315029	10562	Economy	3000.00
0005434558609	10562	Economy	3300.00
0005435315042	10562	Economy	3300.00
0005435314968	10562	Economy	3000.00
0005435314973	10562	Economy	3000.00
0005433181698	10562	Economy	3000.00
0005435315067	10562	Economy	3000.00
0005433181623	10562	Economy	3000.00
0005433181663	10562	Economy	3000.00
0005434757705	10562	Economy	3000.00
0005433181682	10562	Economy	3000.00
0005435315105	10562	Economy	3000.00
0005435315104	10562	Economy	3000.00
0005434552855	10562	Economy	3000.00
0005435315010	10562	Economy	3000.00
0005433181684	10562	Economy	3000.00
0005435315031	10562	Economy	3000.00
0005433181749	10562	Economy	3000.00
0005435314987	10562	Economy	3000.00
0005435315028	10562	Economy	3000.00
0005435314996	10562	Economy	3000.00
0005434552850	10562	Economy	3000.00
0005433181664	10562	Economy	3000.00
0005434552852	10562	Economy	3000.00
0005433181757	10562	Economy	3000.00
0005433181622	10562	Economy	3000.00
0005435315055	10562	Economy	3000.00
0005433181770	10562	Economy	3000.00
0005434552843	10562	Economy	3000.00
0005434558607	10562	Economy	3000.00
0005434558608	10562	Economy	3000.00
0005434558606	10562	Economy	3000.00
0005434552847	10562	Economy	3000.00
0005433181681	10562	Economy	3000.00
0005435315018	10562	Economy	3000.00
0005434552854	10562	Economy	3000.00
0005433181598	10562	Economy	3000.00
0005434558605	10562	Economy	3000.00
0005435314986	10562	Economy	3000.00
0005433181662	10562	Economy	3000.00
0005435315001	10562	Economy	3000.00
0005434552845	10562	Economy	3000.00
0005435315044	10562	Economy	3000.00
0005433181606	10562	Economy	3000.00
0005434552853	10562	Economy	3000.00
0005435315011	10562	Economy	3000.00
0005433181599	10562	Economy	3000.00
0005434552844	10562	Economy	3000.00
0005435314997	10562	Economy	3000.00
0005433181731	10562	Economy	3000.00
0005433181740	10562	Economy	3000.00
0005435314980	10562	Economy	3000.00
0005435315140	27750	Economy	3000.00
0005435315141	27750	Economy	3000.00
0005433181838	27750	Economy	3000.00
0005433181839	27750	Economy	3000.00
0005435315139	27750	Economy	3000.00
0005434552619	27749	Business	9100.00
0005434558443	27749	Business	9100.00
0005434552435	27749	Business	9100.00
0005434552585	27749	Business	9100.00
0005434558455	27749	Business	9100.00
0005434552648	27749	Business	9100.00
0005434552437	27749	Business	9100.00
0005434552564	27749	Business	9100.00
0005434552528	27749	Business	9100.00
0005434552550	27749	Business	9100.00
0005434552628	27749	Business	9100.00
0005434552397	27749	Economy	3000.00
0005434552594	27749	Economy	3000.00
0005434552622	27749	Economy	3000.00
0005434552662	27749	Economy	3000.00
0005434552635	27749	Economy	3000.00
0005434552427	27749	Economy	3300.00
0005434552710	27749	Economy	3300.00
0005434552558	27749	Economy	3300.00
0005434552694	27749	Economy	3300.00
0005434552580	27749	Economy	3000.00
0005434552503	27749	Economy	3000.00
0005434552534	27749	Economy	3000.00
0005434552685	27749	Economy	3000.00
0005434554115	27749	Economy	3000.00
0005434552407	27749	Economy	3000.00
0005434552620	27749	Economy	3000.00
0005434558462	27749	Economy	3000.00
0005434552498	27749	Economy	3000.00
0005434558444	27749	Economy	3000.00
0005434552621	27749	Economy	3000.00
0005434552627	27749	Economy	3000.00
0005434558445	27749	Economy	3000.00
0005434558456	27749	Economy	3000.00
0005434552401	27749	Economy	3000.00
0005434552408	27749	Economy	3000.00
0005434552693	27749	Economy	3000.00
0005434558454	27749	Economy	3000.00
0005434552533	27749	Economy	3000.00
0005434552560	27749	Economy	3000.00
0005434558436	27749	Economy	3000.00
0005434552549	27749	Economy	3000.00
0005434552405	27749	Economy	3000.00
0005434552573	27749	Economy	3000.00
0005434552321	27749	Economy	3000.00
0005434552645	27749	Economy	3000.00
0005434552605	27749	Economy	3000.00
0005434552566	27749	Economy	3000.00
0005434552567	27749	Economy	3000.00
0005434552502	27749	Economy	3000.00
0005434552696	27749	Economy	3000.00
0005434552565	27749	Economy	3000.00
0005434552647	27749	Economy	3000.00
0005434552655	27749	Economy	3000.00
0005434552559	27749	Economy	3000.00
0005434552351	27749	Economy	3000.00
0005434552646	27749	Economy	3000.00
0005434552684	27749	Economy	3000.00
0005434552800	27749	Economy	3000.00
0005434552606	27749	Economy	3000.00
0005434552466	27749	Economy	3000.00
0005434552406	27749	Economy	3000.00
0005434552391	27749	Economy	3000.00
0005434552799	27749	Economy	3000.00
0005434552641	27749	Economy	3000.00
0005434552418	27749	Economy	3000.00
0005434558453	27749	Economy	3000.00
0005434552595	27749	Economy	3000.00
0005434552396	27749	Economy	3000.00
0005434552399	27749	Economy	3000.00
0005434552350	27749	Economy	3000.00
0005434552191	27749	Economy	3000.00
0005434552663	27749	Economy	3000.00
0005434552593	27749	Economy	3000.00
0005434552752	27749	Economy	3000.00
0005434552436	27749	Economy	3000.00
0005434552394	27749	Economy	3000.00
0005434552400	27749	Economy	3000.00
0005435254531	6150	Economy	11700.00
0005435254532	6150	Economy	11700.00
0005433459326	19295	Economy	11700.00
0005435683332	6749	Business	51100.00
0005435438515	6749	Business	51100.00
0005435438517	6749	Business	51100.00
0005435220375	6749	Business	51100.00
0005435438509	6749	Business	51100.00
0005435438527	6749	Business	51100.00
0005432136314	6749	Business	51100.00
0005435438408	6749	Economy	17000.00
0005435438499	6749	Economy	17000.00
0005434828755	6749	Economy	17000.00
0005435438428	6749	Economy	17000.00
0005435438476	6749	Economy	17000.00
0005434828746	6749	Economy	17000.00
0005435217764	6749	Economy	18700.00
0005432533353	6749	Economy	18700.00
0005435438545	6749	Economy	17000.00
0005435438477	6749	Economy	17000.00
0005435438506	6749	Economy	17000.00
0005435438452	6749	Economy	17000.00
0005435221534	6749	Economy	17000.00
0005435438427	6749	Economy	17000.00
0005434828754	6749	Economy	17000.00
0005435683333	6749	Economy	17000.00
0005435438541	6749	Economy	17000.00
0005435438512	6749	Economy	17000.00
0005435438475	6749	Economy	17000.00
0005435438482	6749	Economy	17000.00
0005435790417	6749	Economy	17000.00
0005435217765	6749	Economy	17000.00
0005435438526	6749	Economy	17000.00
0005432533359	6749	Economy	17000.00
0005435438497	6749	Economy	17000.00
0005435438529	6749	Economy	17000.00
0005435438426	6749	Economy	17000.00
0005434828769	6749	Economy	17000.00
0005435438453	6749	Economy	17000.00
0005435438425	6749	Economy	17000.00
0005434828753	6749	Economy	17000.00
0005435220382	6749	Economy	17000.00
0005435217767	6749	Economy	17000.00
0005435438498	6749	Economy	17000.00
0005432533358	6749	Economy	17000.00
0005435438544	6749	Economy	17000.00
0005435220358	6749	Economy	17000.00
0005435683330	6749	Economy	17000.00
0005434828770	6749	Economy	17000.00
0005435221533	6749	Economy	17000.00
0005435438551	6749	Economy	17000.00
0005435217761	6749	Economy	17000.00
0005432533360	6749	Economy	17000.00
0005435683331	6749	Economy	17000.00
0005435217766	6749	Economy	17000.00
0005435220381	6749	Economy	17000.00
0005435438406	6749	Economy	17000.00
0005435438516	6749	Economy	17000.00
0005435683178	24597	Business	51100.00
0005435683079	24597	Business	51100.00
0005435683205	24597	Business	51100.00
0005432305821	24597	Business	51100.00
0005435683020	24597	Business	51100.00
0005435438590	24597	Business	51100.00
0005434828774	24597	Business	51100.00
0005435683109	24597	Business	51100.00
0005435682962	24597	Economy	17000.00
0005435682989	24597	Economy	17000.00
0005435662001	24597	Economy	17000.00
0005435683148	24597	Economy	17000.00
0005435682992	24597	Economy	17000.00
0005435682990	24597	Economy	17000.00
0005435683152	24597	Economy	17000.00
0005435683058	24597	Economy	18700.00
0005435683153	24597	Economy	18700.00
0005435654511	24597	Economy	18700.00
0005435683086	24597	Economy	17000.00
0005435683047	24597	Economy	17000.00
0005435682817	24597	Economy	17000.00
0005435683017	24597	Economy	17000.00
0005435682960	24597	Economy	17000.00
0005435683090	24597	Economy	17000.00
0005435654509	24597	Economy	17000.00
0005435683036	24597	Economy	17000.00
0005435438588	24597	Economy	17000.00
0005435683046	24597	Economy	17000.00
0005435683085	24597	Economy	17000.00
0005435683015	24597	Economy	17000.00
0005432533379	24597	Economy	17000.00
0005435683016	24597	Economy	17000.00
0005435631043	24597	Economy	17000.00
0005435683265	24597	Economy	17000.00
0005434828775	24597	Economy	17000.00
0005435631041	24597	Economy	17000.00
0005435683060	24597	Economy	17000.00
0005435683213	24597	Economy	17000.00
0005435683028	24597	Economy	17000.00
0005435654508	24597	Economy	17000.00
0005435683057	24597	Economy	17000.00
0005435682991	24597	Economy	17000.00
0005435683151	24597	Economy	17000.00
0005435683088	24597	Economy	17000.00
0005435654504	24597	Economy	17000.00
0005435683089	24597	Economy	17000.00
0005435631044	24597	Economy	17000.00
0005435683097	24597	Economy	17000.00
0005435683186	24597	Economy	17000.00
0005435683222	24597	Economy	17000.00
0005435720844	24597	Economy	17000.00
0005432305820	24597	Economy	17000.00
0005435682961	24597	Economy	17000.00
0005435654505	24597	Economy	17000.00
0005435438589	24597	Economy	17000.00
0005435654510	24597	Economy	17000.00
0005435683229	24597	Economy	17000.00
0005435683029	24597	Economy	17000.00
0005435631040	24597	Economy	17000.00
0005435558152	11506	Business	26400.00
0005435127576	11506	Business	26400.00
0005435127572	11506	Economy	8800.00
0005435127574	11506	Economy	8800.00
0005435127573	11506	Economy	8800.00
0005435127569	11506	Economy	8800.00
0005435127571	11506	Economy	8800.00
0005435127575	11506	Economy	8800.00
0005435127570	11506	Economy	8800.00
0005435558151	11506	Economy	8800.00
0005435127344	31869	Business	26400.00
0005435127305	31869	Business	26400.00
0005435127291	31869	Business	26400.00
0005435127454	31869	Economy	8800.00
0005435127314	31869	Economy	8800.00
0005435127375	31869	Economy	8800.00
0005435127278	31869	Economy	8800.00
0005435127253	31869	Economy	8800.00
0005435127348	31869	Economy	8800.00
0005435127254	31869	Economy	9700.00
0005435127346	31869	Economy	8800.00
0005435127179	31869	Economy	8800.00
0005435098604	31869	Economy	8800.00
0005435127409	31869	Economy	8800.00
0005435127276	31869	Economy	8800.00
0005435098598	31869	Economy	8800.00
0005435127315	31869	Economy	8800.00
0005435127453	31869	Economy	8800.00
0005435127259	31869	Economy	8800.00
0005435127386	31869	Economy	8800.00
0005435127304	31869	Economy	8800.00
0005435127410	31869	Economy	8800.00
0005435127302	31869	Economy	8800.00
0005435127345	31869	Economy	8800.00
0005435127347	31869	Economy	8800.00
0005435098599	31869	Economy	8800.00
0005435127279	31869	Economy	8800.00
0005435127402	31869	Economy	8800.00
0005435127452	31869	Economy	8800.00
0005435127370	31869	Economy	8800.00
0005435127336	31869	Economy	8800.00
0005435127277	31869	Economy	8800.00
0005435127260	31869	Economy	8800.00
0005435098603	31869	Economy	8800.00
0005435127337	31869	Economy	8800.00
0005435127326	31869	Economy	8800.00
0005435732681	13553	Business	36600.00
0005435732645	13553	Economy	12200.00
0005435732624	13553	Economy	12200.00
0005435732627	13553	Economy	12200.00
0005433399464	13553	Economy	12200.00
0005433399465	13553	Economy	12200.00
0005435732644	13553	Economy	12200.00
0005435732601	13553	Economy	12200.00
0005435732607	13553	Economy	12200.00
0005433399273	19404	Business	36600.00
0005433398986	19404	Business	36600.00
0005433399164	19404	Business	36600.00
0005433399162	19404	Business	36600.00
0005433399302	19404	Business	36600.00
0005433399304	19404	Business	36600.00
0005433399078	19404	Economy	12200.00
0005433399230	19404	Economy	12200.00
0005433399247	19404	Economy	12200.00
0005433399009	19404	Economy	13400.00
0005433399296	19404	Economy	13400.00
0005433399303	19404	Economy	13400.00
0005433399008	19404	Economy	13400.00
0005433399099	19404	Economy	12200.00
0005433399209	19404	Economy	12200.00
0005433399167	19404	Economy	12200.00
0005435732724	19404	Economy	12200.00
0005433399007	19404	Economy	12200.00
0005433399235	19404	Economy	12200.00
0005435725786	19404	Economy	12200.00
0005433399174	19404	Economy	12200.00
0005433398985	19404	Economy	12200.00
0005433399242	19404	Economy	12200.00
0005433399288	19404	Economy	12200.00
0005433399111	19404	Economy	12200.00
0005433399212	19404	Economy	12200.00
0005433399289	19404	Economy	12200.00
0005433399316	19404	Economy	12200.00
0005433399107	19404	Economy	12200.00
0005433399121	19404	Economy	12200.00
0005433398982	19404	Economy	12200.00
0005433399213	19404	Economy	12200.00
0005433399350	19404	Economy	12200.00
0005433399128	19404	Economy	12200.00
0005433399120	19404	Economy	12200.00
0005433399189	19404	Economy	12200.00
0005435725787	19404	Economy	12200.00
0005435732723	19404	Economy	12200.00
0005433399202	19404	Economy	12200.00
0005433399274	19404	Economy	12200.00
0005433399194	19404	Economy	12200.00
0005433399147	19404	Economy	12200.00
0005433399085	19404	Economy	12200.00
0005433399351	19404	Economy	12200.00
0005433399287	19404	Economy	12200.00
0005433399077	19404	Economy	12200.00
0005435732725	19404	Economy	12200.00
0005433399286	19404	Economy	12200.00
0005435070247	13179	Business	11300.00
0005435070082	13179	Business	11300.00
0005435070239	13179	Business	11300.00
0005435070359	13179	Business	11300.00
0005435070250	13179	Business	11300.00
0005435070331	13179	Business	11300.00
0005435070388	13179	Business	11300.00
0005435070360	13179	Business	11300.00
0005435070206	13179	Business	11300.00
0005435925722	13179	Business	11300.00
0005435070284	13179	Business	11300.00
0005435070240	13179	Economy	3800.00
0005435070014	13179	Economy	3800.00
0005435070091	13179	Economy	3800.00
0005435070147	13179	Economy	3800.00
0005435925725	13179	Economy	3800.00
0005435070210	13179	Economy	3800.00
0005435070205	13179	Economy	3800.00
0005435070329	13179	Economy	3800.00
0005435070513	13179	Economy	3800.00
0005435070069	13179	Economy	4100.00
0005435070423	13179	Economy	4100.00
0005435070328	13179	Economy	3800.00
0005435925724	13179	Economy	3800.00
0005435070433	13179	Economy	3800.00
0005435070276	13179	Economy	3800.00
0005435070336	13179	Economy	3800.00
0005435070296	13179	Economy	3800.00
0005435070218	13179	Economy	3800.00
0005435070172	13179	Economy	3800.00
0005435070298	13179	Economy	3800.00
0005435070231	13179	Economy	3800.00
0005435070145	13179	Economy	3800.00
0005435070121	13179	Economy	3800.00
0005435070287	13179	Economy	3800.00
0005435070249	13179	Economy	3800.00
0005435070347	13179	Economy	3800.00
0005435070361	13179	Economy	3800.00
0005435070122	13179	Economy	3800.00
0005435070260	13179	Economy	3800.00
0005435070131	13179	Economy	3800.00
0005435070090	13179	Economy	3800.00
0005435925720	13179	Economy	3800.00
0005435070261	13179	Economy	3800.00
0005435070217	13179	Economy	3800.00
0005435070427	13179	Economy	3800.00
0005435070279	13179	Economy	3800.00
0005435070181	13179	Economy	3800.00
0005435070297	13179	Economy	3800.00
0005435070258	13179	Economy	3800.00
0005435070389	13179	Economy	3800.00
0005435070033	13179	Economy	3800.00
0005435070293	13179	Economy	3800.00
0005435070277	13179	Economy	3800.00
0005435070198	13179	Economy	3800.00
0005435070400	13179	Economy	3800.00
0005435070278	13179	Economy	3800.00
0005435070392	13179	Economy	3800.00
0005435070180	13179	Economy	3800.00
0005435070304	13179	Economy	3800.00
0005435070259	13179	Economy	3800.00
0005435070179	13179	Economy	3800.00
0005435070330	13179	Economy	3800.00
0005435070246	13179	Economy	3800.00
0005435070280	13179	Economy	3800.00
0005435925721	13179	Economy	3800.00
0005435070197	13179	Economy	3800.00
0005435070390	13179	Economy	3800.00
0005435070467	13179	Economy	3800.00
0005435070432	13179	Economy	3800.00
0005435070081	13179	Economy	3800.00
0005435070285	13179	Economy	3800.00
0005435070326	13179	Economy	3800.00
0005435925723	13179	Economy	3800.00
0005435070327	13179	Economy	3800.00
0005435070428	13179	Economy	3800.00
0005435070325	13179	Economy	3800.00
0005435070209	13179	Economy	3800.00
0005435070391	13179	Economy	3800.00
0005435070466	13179	Economy	3800.00
0005435070426	13179	Economy	3800.00
0005435070248	13179	Economy	3800.00
0005435070551	15471	Business	11300.00
0005435925599	15471	Business	11300.00
0005435925627	15471	Economy	3800.00
0005435925574	15471	Economy	3800.00
0005435925597	15471	Economy	3800.00
0005435925623	15471	Economy	3800.00
0005435925575	15471	Economy	3800.00
0005435925624	15471	Economy	3800.00
0005435925573	15471	Economy	3800.00
0005435925581	15471	Economy	3800.00
0005435925579	15471	Economy	3800.00
0005435925626	15471	Economy	3800.00
0005435925604	15471	Economy	3800.00
0005435070553	15471	Economy	3800.00
0005435925577	15471	Economy	3800.00
0005435925620	15471	Economy	3800.00
0005435925600	15471	Economy	3800.00
0005435070554	15471	Economy	3800.00
0005435070552	15471	Economy	3800.00
0005435070550	15471	Economy	3800.00
0005435808433	29492	Economy	27100.00
0005435808432	29492	Economy	27100.00
0005435808456	29492	Economy	27100.00
0005435808455	29492	Economy	27100.00
0005435808444	29492	Economy	24700.00
0005435808485	29492	Economy	24700.00
0005435808487	29492	Economy	24700.00
0005435808411	29492	Economy	24700.00
0005435808434	29492	Economy	24700.00
0005435808453	29492	Economy	24700.00
0005435808459	29492	Economy	24700.00
0005435808461	29492	Economy	24700.00
0005435808460	29492	Economy	24700.00
0005435808489	29492	Economy	24700.00
0005433407712	29492	Economy	24700.00
0005435808437	29492	Economy	24700.00
0005435808486	29492	Economy	24700.00
0005435808435	29492	Economy	24700.00
0005435808425	29492	Economy	24700.00
0005435808428	29492	Economy	24700.00
0005433407711	29492	Economy	24700.00
0005435808488	29492	Economy	24700.00
0005435808436	29492	Economy	24700.00
0005435808449	29492	Economy	24700.00
0005435808469	29492	Economy	24700.00
0005435808410	29492	Economy	24700.00
0005435808431	29492	Economy	24700.00
0005435808413	29492	Economy	24700.00
0005435808468	29492	Economy	24700.00
0005435808457	29492	Economy	24700.00
0005433407710	29492	Economy	24700.00
0005435808441	29492	Economy	24700.00
0005435808458	29492	Economy	24700.00
0005435808392	29492	Economy	24700.00
0005435808470	29492	Economy	24700.00
0005435808414	29492	Economy	24700.00
0005435808445	29492	Economy	24700.00
0005434215898	10717	Business	61300.00
0005434757223	10717	Business	61300.00
0005434757347	10717	Business	61300.00
0005434757317	10717	Business	61300.00
0005434757501	10717	Business	61300.00
0005434757287	10717	Business	61300.00
0005434757512	10717	Business	61300.00
0005434757560	10717	Business	61300.00
0005434757475	10717	Business	61300.00
0005434757487	10717	Economy	20400.00
0005434757365	10717	Economy	20400.00
0005434757552	10717	Economy	20400.00
0005434215896	10717	Economy	20400.00
0005434757480	10717	Economy	22500.00
0005434757349	10717	Economy	22500.00
0005434757505	10717	Economy	22500.00
0005434757222	10717	Economy	22500.00
0005434757346	10717	Economy	20400.00
0005434757410	10717	Economy	20400.00
0005434215900	10717	Economy	20400.00
0005434757380	10717	Economy	20400.00
0005434757423	10717	Economy	20400.00
0005434757345	10717	Economy	20400.00
0005434757216	10717	Economy	20400.00
0005434757494	10717	Economy	20400.00
0005434757308	10717	Economy	20400.00
0005434757399	10717	Economy	20400.00
0005434757319	10717	Economy	20400.00
0005434757469	10717	Economy	20400.00
0005434757561	10717	Economy	20400.00
0005434757493	10717	Economy	20400.00
0005434757309	10717	Economy	20400.00
0005434757470	10717	Economy	20400.00
0005434757339	10717	Economy	20400.00
0005434757264	10717	Economy	20400.00
0005434757488	10717	Economy	20400.00
0005434757318	10717	Economy	20400.00
0005434757411	10717	Economy	20400.00
0005434757381	10717	Economy	20400.00
0005434757474	10717	Economy	20400.00
0005434757350	10717	Economy	20400.00
0005434757343	10717	Economy	20400.00
0005434757484	10717	Economy	20400.00
0005434215895	10717	Economy	20400.00
0005434757251	10717	Economy	20400.00
0005434757485	10717	Economy	20400.00
0005434757252	10717	Economy	20400.00
0005434757409	10717	Economy	20400.00
0005434757419	10717	Economy	20400.00
0005434757559	10717	Economy	20400.00
0005434215899	10717	Economy	20400.00
0005434757217	10717	Economy	20400.00
0005434757513	10717	Economy	20400.00
0005434757288	10717	Economy	20400.00
0005434757483	10717	Economy	20400.00
0005434757366	10717	Economy	20400.00
0005434757299	10717	Economy	20400.00
0005434215897	10717	Economy	20400.00
0005434215901	10717	Economy	20400.00
0005434215507	28653	Business	61300.00
0005434215597	28653	Business	61300.00
0005434215653	28653	Business	61300.00
0005434757682	28653	Business	61300.00
0005434215711	28653	Business	61300.00
0005434215626	28653	Business	61300.00
0005434215606	28653	Business	61300.00
0005434757676	28653	Business	61300.00
0005434215396	28653	Business	61300.00
0005434215690	28653	Business	61300.00
0005434215672	28653	Economy	20400.00
0005434757680	28653	Economy	20400.00
0005434215459	28653	Economy	20400.00
0005434215503	28653	Economy	20400.00
0005434215560	28653	Economy	20400.00
0005434215712	28653	Economy	20400.00
0005434215681	28653	Economy	22500.00
0005434215538	28653	Economy	22500.00
0005434215508	28653	Economy	22500.00
0005434215593	28653	Economy	20400.00
0005434215526	28653	Economy	20400.00
0005434215645	28653	Economy	20400.00
0005434757678	28653	Economy	20400.00
0005434215585	28653	Economy	20400.00
0005434215502	28653	Economy	20400.00
0005434215568	28653	Economy	20400.00
0005434215415	28653	Economy	20400.00
0005434215623	28653	Economy	20400.00
0005434215572	28653	Economy	20400.00
0005434215627	28653	Economy	20400.00
0005434215523	28653	Economy	20400.00
0005434215607	28653	Economy	20400.00
0005434215420	28653	Economy	20400.00
0005434215646	28653	Economy	20400.00
0005434215327	28653	Economy	20400.00
0005434215610	28653	Economy	20400.00
0005434215559	28653	Economy	20400.00
0005434215669	28653	Economy	20400.00
0005434215562	28653	Economy	20400.00
0005434757681	28653	Economy	20400.00
0005434215594	28653	Economy	20400.00
0005434215624	28653	Economy	20400.00
0005434215534	28653	Economy	20400.00
0005434215524	28653	Economy	20400.00
0005434757683	28653	Economy	20400.00
0005434215586	28653	Economy	20400.00
0005434215522	28653	Economy	20400.00
0005434215609	28653	Economy	20400.00
0005434215495	28653	Economy	20400.00
0005434215537	28653	Economy	20400.00
0005434757675	28653	Economy	20400.00
0005434215654	28653	Economy	20400.00
0005434215509	28653	Economy	20400.00
0005434215426	28653	Economy	20400.00
0005434215395	28653	Economy	20400.00
0005434215460	28653	Economy	20400.00
0005434215528	28653	Economy	20400.00
0005434215467	28653	Economy	20400.00
0005434757679	28653	Economy	20400.00
0005434215480	28653	Economy	20400.00
0005434215427	28653	Economy	20400.00
0005434215527	28653	Economy	20400.00
0005434215671	28653	Economy	20400.00
0005434215414	28653	Economy	20400.00
0005434215647	28653	Economy	20400.00
0005434757677	28653	Economy	20400.00
0005434215561	28653	Economy	20400.00
0005435041694	5484	Business	29500.00
0005434229934	5484	Business	29500.00
0005434229916	5484	Business	29500.00
0005434229857	5484	Business	29500.00
0005434229912	5484	Economy	9800.00
0005435377935	5484	Economy	9800.00
0005435041692	5484	Economy	9800.00
0005434229959	5484	Economy	9800.00
0005434229891	5484	Economy	9800.00
0005434229858	5484	Economy	9800.00
0005435377965	5484	Economy	9800.00
0005434229860	5484	Economy	9800.00
0005434230003	5484	Economy	9800.00
0005434229913	5484	Economy	9800.00
0005434229935	5484	Economy	9800.00
0005434229819	5484	Economy	9800.00
0005434229898	5484	Economy	10800.00
0005434229905	5484	Economy	9800.00
0005434229936	5484	Economy	9800.00
0005434229897	5484	Economy	9800.00
0005434229917	5484	Economy	9800.00
0005435041695	5484	Economy	9800.00
0005434229892	5484	Economy	9800.00
0005434229932	5484	Economy	9800.00
0005434229893	5484	Economy	9800.00
0005434229888	5484	Economy	9800.00
0005435556766	5484	Economy	9800.00
0005435377940	5484	Economy	9800.00
0005432125663	5484	Economy	9800.00
0005434229914	5484	Economy	9800.00
0005435007719	5484	Economy	9800.00
0005435041691	5484	Economy	9800.00
0005434230004	5484	Economy	9800.00
0005435007718	5484	Economy	9800.00
0005435041693	5484	Economy	9800.00
0005434229896	5484	Economy	9800.00
0005434229875	5484	Economy	9800.00
0005435007631	12956	Business	29500.00
0005435041537	12956	Business	29500.00
0005435041269	12956	Business	29500.00
0005435041268	12956	Business	29500.00
0005435041483	12956	Business	29500.00
0005435041285	12956	Business	29500.00
0005435043312	12956	Business	29500.00
0005435041590	12956	Economy	9800.00
0005434230039	12956	Economy	9800.00
0005435041284	12956	Economy	9800.00
0005435041345	12956	Economy	9800.00
0005435007669	12956	Economy	9800.00
0005435007558	12956	Economy	9800.00
0005435007537	12956	Economy	9800.00
0005435041076	12956	Economy	9800.00
0005435041256	12956	Economy	9800.00
0005435042905	12956	Economy	9800.00
0005435041438	12956	Economy	9800.00
0005435007635	12956	Economy	9800.00
0005435041432	12956	Economy	9800.00
0005435041536	12956	Economy	9800.00
0005435041388	12956	Economy	9800.00
0005435041174	12956	Economy	9800.00
0005435007590	12956	Economy	9800.00
0005435007630	12956	Economy	9800.00
0005435041257	12956	Economy	9800.00
0005435007597	12956	Economy	9800.00
0005435041317	12956	Economy	9800.00
0005435007606	12956	Economy	9800.00
0005435041547	12956	Economy	9800.00
0005435041386	12956	Economy	9800.00
0005435043313	12956	Economy	9800.00
0005435007545	12956	Economy	9800.00
0005435007544	12956	Economy	9800.00
0005435041027	12956	Economy	9800.00
0005435007670	12956	Economy	9800.00
0005435041295	12956	Economy	9800.00
0005435042904	12956	Economy	9800.00
0005435041373	12956	Economy	9800.00
0005435040930	12956	Economy	9800.00
0005434230041	12956	Economy	10800.00
0005435041207	12956	Economy	10800.00
0005435041161	12956	Economy	10800.00
0005435041371	12956	Economy	9800.00
0005435040900	12956	Economy	9800.00
0005435041508	12956	Economy	9800.00
0005435041125	12956	Economy	9800.00
0005435041367	12956	Economy	9800.00
0005435041253	12956	Economy	9800.00
0005435041301	12956	Economy	9800.00
0005435041251	12956	Economy	9800.00
0005435735284	12956	Economy	9800.00
0005435041481	12956	Economy	9800.00
0005435007577	12956	Economy	9800.00
0005435377988	12956	Economy	9800.00
0005435041291	12956	Economy	9800.00
0005435041473	12956	Economy	9800.00
0005435041507	12956	Economy	9800.00
0005434230040	12956	Economy	9800.00
0005435041259	12956	Economy	9800.00
0005435007550	12956	Economy	9800.00
0005435041074	12956	Economy	9800.00
0005435041346	12956	Economy	9800.00
0005435377986	12956	Economy	9800.00
0005435042917	12956	Economy	9800.00
0005435041275	12956	Economy	9800.00
0005435041433	12956	Economy	9800.00
0005435007671	12956	Economy	9800.00
0005435043302	12956	Economy	9800.00
0005435041077	12956	Economy	9800.00
0005435041279	12956	Economy	9800.00
0005435041272	12956	Economy	9800.00
0005435007612	12956	Economy	9800.00
0005435007536	12956	Economy	9800.00
0005435007626	12956	Economy	9800.00
0005435007646	12956	Economy	9800.00
0005435041387	12956	Economy	9800.00
0005435041546	12956	Economy	9800.00
0005435042903	12956	Economy	9800.00
0005435041246	12956	Economy	9800.00
0005435041381	12956	Economy	9800.00
0005435041264	12956	Economy	9800.00
0005435007627	12956	Economy	9800.00
0005435007589	12956	Economy	9800.00
0005435041591	12956	Economy	9800.00
0005435040929	12956	Economy	9800.00
0005435007604	12956	Economy	9800.00
0005435377987	12956	Economy	9800.00
0005435041122	12956	Economy	9800.00
0005435041509	12956	Economy	9800.00
0005435041162	12956	Economy	9800.00
0005435007538	12956	Economy	9800.00
0005435041252	12956	Economy	9800.00
0005435043311	12956	Economy	9800.00
0005435041366	12956	Economy	9800.00
0005435903109	14854	Business	52900.00
0005435903121	14854	Business	52900.00
0005435903061	14854	Business	52900.00
0005435903120	14854	Business	52900.00
0005434427458	14854	Business	52900.00
0005434427461	14854	Economy	17600.00
0005435903085	14854	Economy	17600.00
0005435903089	14854	Economy	17600.00
0005434427462	14854	Economy	17600.00
0005435903080	14854	Economy	17600.00
0005435903159	14854	Economy	19400.00
0005435903144	14854	Economy	17600.00
0005434427459	14854	Economy	17600.00
0005435903114	14854	Economy	17600.00
0005435903088	14854	Economy	17600.00
0005435903127	14854	Economy	17600.00
0005435903110	14854	Economy	17600.00
0005435903086	14854	Economy	17600.00
0005435903129	14854	Economy	17600.00
0005435903161	14854	Economy	17600.00
0005435903160	14854	Economy	17600.00
0005434427463	14854	Economy	17600.00
0005434427460	14854	Economy	17600.00
0005435903106	14854	Economy	17600.00
0005435903084	14854	Economy	17600.00
0005435903158	14854	Economy	17600.00
0005435903145	14854	Economy	17600.00
0005435903128	14854	Economy	17600.00
0005435903079	14854	Economy	17600.00
0005435903105	14854	Economy	17600.00
0005434427359	20202	Business	52900.00
0005434427369	20202	Business	52900.00
0005434427400	20202	Business	52900.00
0005434427360	20202	Business	52900.00
0005434411880	20202	Economy	17600.00
0005434427362	20202	Economy	17600.00
0005434427230	20202	Economy	17600.00
0005434427355	20202	Economy	17600.00
0005434427197	20202	Economy	17600.00
0005434427342	20202	Economy	19400.00
0005435903220	20202	Economy	19400.00
0005434411881	20202	Economy	19400.00
0005434427244	20202	Economy	17600.00
0005434427299	20202	Economy	17600.00
0005434427239	20202	Economy	17600.00
0005434427343	20202	Economy	17600.00
0005434427340	20202	Economy	17600.00
0005434427364	20202	Economy	17600.00
0005434427325	20202	Economy	17600.00
0005434427265	20202	Economy	17600.00
0005434427354	20202	Economy	17600.00
0005434427229	20202	Economy	17600.00
0005434427361	20202	Economy	17600.00
0005434427242	20202	Economy	17600.00
0005434427283	20202	Economy	17600.00
0005434427352	20202	Economy	17600.00
0005434427313	20202	Economy	17600.00
0005434427341	20202	Economy	17600.00
0005434427278	20202	Economy	17600.00
0005434427336	20202	Economy	17600.00
0005434427312	20202	Economy	17600.00
0005434427353	20202	Economy	17600.00
0005434427363	20202	Economy	17600.00
0005434427243	20202	Economy	17600.00
0005434427238	20202	Economy	17600.00
0005434411887	20202	Economy	17600.00
0005434427264	20202	Economy	17600.00
0005434427228	20202	Economy	17600.00
0005434427294	20202	Economy	17600.00
0005435903221	20202	Economy	17600.00
0005434427395	20202	Economy	17600.00
0005434427377	20202	Economy	17600.00
0005433435347	26527	Business	18500.00
0005433435344	26527	Economy	6200.00
0005433435413	26527	Economy	6200.00
0005433435140	26527	Economy	6200.00
0005433435278	26527	Economy	6200.00
0005433435258	26527	Economy	6200.00
0005433435266	26527	Economy	6200.00
0005434273113	26527	Economy	6800.00
0005433435360	26527	Economy	6800.00
0005433435289	26527	Economy	6800.00
0005433435373	26527	Economy	6800.00
0005433435353	26527	Economy	6200.00
0005433435357	26527	Economy	6200.00
0005433435280	26527	Economy	6200.00
0005433435367	26527	Economy	6200.00
0005433435238	26527	Economy	6200.00
0005433435325	26527	Economy	6200.00
0005433435267	26527	Economy	6200.00
0005433435184	26527	Economy	6200.00
0005433435277	26527	Economy	6200.00
0005433435368	26527	Economy	6200.00
0005432300441	26527	Economy	6200.00
0005434273114	26527	Economy	6200.00
0005433435183	26527	Economy	6200.00
0005433435253	26527	Economy	6200.00
0005433435254	26527	Economy	6200.00
0005435983669	26527	Economy	6200.00
0005433435386	26527	Economy	6200.00
0005435983672	26527	Economy	6200.00
0005433435372	26527	Economy	6200.00
0005433435257	26527	Economy	6200.00
0005433435356	26527	Economy	6200.00
0005433435324	26527	Economy	6200.00
0005435983671	26527	Economy	6200.00
0005433435412	26527	Economy	6200.00
0005433435300	26527	Economy	6200.00
0005433435139	26527	Economy	6200.00
0005433435141	26527	Economy	6200.00
0005435983670	26527	Economy	6200.00
0005432300440	26527	Economy	6200.00
0005433435411	26527	Economy	6200.00
0005435983476	26682	Business	18500.00
0005435983179	26682	Business	18500.00
0005435983330	26682	Business	18500.00
0005435983342	26682	Business	18500.00
0005435983097	26682	Business	18500.00
0005435983369	26682	Economy	6200.00
0005435983187	26682	Economy	6200.00
0005435983364	26682	Economy	6200.00
0005435983540	26682	Economy	6200.00
0005433435506	26682	Economy	6200.00
0005435983451	26682	Economy	6200.00
0005435983539	26682	Economy	6200.00
0005435983376	26682	Economy	6800.00
0005435983098	26682	Economy	6800.00
0005433435507	26682	Economy	6200.00
0005435983288	26682	Economy	6200.00
0005435983386	26682	Economy	6200.00
0005435983273	26682	Economy	6200.00
0005435983341	26682	Economy	6200.00
0005435983297	26682	Economy	6200.00
0005435983227	26682	Economy	6200.00
0005435983188	26682	Economy	6200.00
0005435983205	26682	Economy	6200.00
0005435983397	26682	Economy	6200.00
0005433435505	26682	Economy	6200.00
0005435983346	26682	Economy	6200.00
0005435983343	26682	Economy	6200.00
0005435983433	26682	Economy	6200.00
0005435983452	26682	Economy	6200.00
0005435983320	26682	Economy	6200.00
0005435983206	26682	Economy	6200.00
0005435983247	26682	Economy	6200.00
0005435983294	26682	Economy	6200.00
0005435983178	26682	Economy	6200.00
0005435983443	26682	Economy	6200.00
0005435983365	26682	Economy	6200.00
0005435983381	26682	Economy	6200.00
0005435983295	26682	Economy	6200.00
0005435983402	26682	Economy	6200.00
0005435983368	26682	Economy	6200.00
0005435983244	26682	Economy	6200.00
0005435983423	26682	Economy	6200.00
0005435983296	26682	Economy	6200.00
0005435983541	26682	Economy	6200.00
0005435983405	26682	Economy	6200.00
0005435983172	26682	Economy	6200.00
0005435983522	26682	Economy	6200.00
0005435983349	26682	Economy	6200.00
0005435983304	26682	Economy	6200.00
0005435983072	26682	Economy	6200.00
0005434269166	26682	Economy	6200.00
0005435983143	26682	Economy	6200.00
0005435983171	26682	Economy	6200.00
0005433685583	19519	Economy	21000.00
0005433686693	19519	Economy	21000.00
0005433687764	19519	Economy	21000.00
0005433686697	19519	Economy	19100.00
0005433686700	19519	Economy	19100.00
0005433686699	19519	Economy	19100.00
0005433685584	19519	Economy	19100.00
0005433686701	19519	Economy	19100.00
0005433687763	19519	Economy	19100.00
0005433685592	19519	Economy	19100.00
0005433686694	19519	Economy	19100.00
0005433685587	19519	Economy	19100.00
0005433686696	19519	Economy	19100.00
0005433686702	19519	Economy	19100.00
0005433685588	19519	Economy	19100.00
0005433685591	19519	Economy	19100.00
0005433685586	19519	Economy	19100.00
0005433685581	19519	Economy	19100.00
0005433685590	19519	Economy	19100.00
0005433685585	19519	Economy	19100.00
0005433685582	19519	Economy	19100.00
0005433685589	19519	Economy	19100.00
0005433686698	19519	Economy	19100.00
0005433686695	19519	Economy	19100.00
0005432858363	3151	Economy	11100.00
0005432584784	3151	Economy	11100.00
0005432858383	3151	Economy	11100.00
0005432584785	3151	Economy	11100.00
0005432858361	3151	Economy	10100.00
0005432584786	3151	Economy	10100.00
0005432858337	3151	Economy	10100.00
0005432858382	3151	Economy	10100.00
0005432858336	3151	Economy	10100.00
0005432584782	3151	Economy	10100.00
0005432584780	3151	Economy	10100.00
0005432858375	3151	Economy	10100.00
0005432584779	3151	Economy	10100.00
0005432858358	3151	Economy	10100.00
0005432858362	3151	Economy	10100.00
0005432584783	3151	Economy	10100.00
0005432858308	3151	Economy	10100.00
0005432858374	3151	Economy	10100.00
0005432858335	3151	Economy	10100.00
0005432858357	3151	Economy	10100.00
0005432584781	3151	Economy	10100.00
0005432584573	31522	Economy	11100.00
0005432584742	31522	Economy	11100.00
0005432584497	31522	Economy	11100.00
0005432584569	31522	Economy	10100.00
0005432858412	31522	Economy	10100.00
0005432584741	31522	Economy	10100.00
0005432584610	31522	Economy	10100.00
0005432584711	31522	Economy	10100.00
0005432584611	31522	Economy	10100.00
0005432584710	31522	Economy	10100.00
0005432584642	31522	Economy	10100.00
0005432858413	31522	Economy	10100.00
0005432584595	31522	Economy	10100.00
0005432858411	31522	Economy	10100.00
0005432584588	31522	Economy	10100.00
0005432584609	31522	Economy	10100.00
0005432584638	31522	Economy	10100.00
0005432584587	31522	Economy	10100.00
0005432584645	31522	Economy	10100.00
0005432584692	31522	Economy	10100.00
0005432584594	31522	Economy	10100.00
0005432584684	31522	Economy	10100.00
0005432584637	31522	Economy	10100.00
0005432584750	31522	Economy	10100.00
0005432584650	31522	Economy	10100.00
0005432584570	31522	Economy	10100.00
0005432584709	31522	Economy	10100.00
0005432584662	31522	Economy	10100.00
0005433255246	891	Economy	7500.00
0005433255251	891	Economy	7500.00
0005433255240	891	Economy	7500.00
0005433255263	891	Economy	7500.00
0005433255245	891	Economy	7500.00
0005433255252	891	Economy	7500.00
0005433255249	891	Economy	7500.00
0005434943598	16247	Economy	8300.00
0005434943546	16247	Economy	8300.00
0005434943591	16247	Economy	7500.00
0005434943560	16247	Economy	7500.00
0005434943599	16247	Economy	7500.00
0005434943542	16247	Economy	7500.00
0005434943547	16247	Economy	7500.00
0005434943600	16247	Economy	7500.00
0005434943590	16247	Economy	7500.00
0005434943543	16247	Economy	7500.00
0005434943565	16247	Economy	7500.00
0005434943577	16247	Economy	7500.00
0005434943536	16247	Economy	7500.00
0005434943592	16247	Economy	7500.00
0005435858641	4329	Business	90500.00
0005433654986	4329	Business	90500.00
0005435858651	4329	Business	90500.00
0005435858626	4329	Economy	30200.00
0005435858663	4329	Economy	30200.00
0005435858640	4329	Economy	33200.00
0005435858661	4329	Economy	30200.00
0005435858666	4329	Economy	30200.00
0005435858655	4329	Economy	30200.00
0005433654987	4329	Economy	30200.00
0005435858662	4329	Economy	30200.00
0005435858657	4329	Economy	30200.00
0005435858660	4329	Economy	30200.00
0005433654985	4329	Economy	30200.00
0005435858642	4329	Economy	30200.00
0005435858656	4329	Economy	30200.00
0005435858650	4329	Economy	30200.00
0005435858643	4329	Economy	30200.00
0005433811672	14360	Economy	4400.00
0005433811671	14360	Economy	4400.00
0005433811682	27787	Economy	4400.00
0005433811683	27787	Economy	4400.00
0005433811689	27787	Economy	4400.00
0005433811684	27787	Economy	4400.00
0005433811688	27787	Economy	4400.00
0005433811687	27787	Economy	4400.00
0005433811690	27787	Economy	4400.00
0005433811681	27787	Economy	4400.00
0005433811686	27787	Economy	4400.00
0005433811691	27787	Economy	4400.00
0005433811685	27787	Economy	4400.00
0005433811680	27787	Economy	4400.00
0005435654481	21769	Business	9800.00
0005433368859	21769	Business	9800.00
0005435654480	21769	Business	9800.00
0005433368624	21769	Economy	3300.00
0005433368612	21769	Economy	3300.00
0005433368767	21769	Economy	3600.00
0005433368584	21769	Economy	3600.00
0005433368858	21769	Economy	3600.00
0005433368564	21769	Economy	3300.00
0005433368887	21769	Economy	3300.00
0005433368608	21769	Economy	3300.00
0005435654475	21769	Economy	3300.00
0005433368826	21769	Economy	3300.00
0005433368766	21769	Economy	3300.00
0005433368607	21769	Economy	3300.00
0005435654479	21769	Economy	3300.00
0005433368813	21769	Economy	3300.00
0005433368477	21769	Economy	3300.00
0005433368626	21769	Economy	3300.00
0005433368732	21769	Economy	3300.00
0005433368625	21769	Economy	3300.00
0005435654474	21769	Economy	3300.00
0005433368857	21769	Economy	3300.00
0005433368819	21769	Economy	3300.00
0005433368882	21769	Economy	3300.00
0005435654482	21769	Economy	3300.00
0005435654484	21769	Economy	3300.00
0005433368507	21769	Economy	3300.00
0005435654483	21769	Economy	3300.00
0005433368735	21769	Economy	3300.00
0005433368744	21769	Economy	3300.00
0005435654476	21769	Economy	3300.00
0005433368645	21769	Economy	3300.00
0005435654485	21769	Economy	3300.00
0005433368508	21769	Economy	3300.00
0005433368872	21769	Economy	3300.00
0005433368860	21769	Economy	3300.00
0005433368827	21769	Economy	3300.00
0005433368825	21769	Economy	3300.00
0005433368762	21769	Economy	3300.00
0005433368820	21769	Economy	3300.00
0005433368871	21769	Economy	3300.00
0005433368651	21769	Economy	3300.00
0005435654478	21769	Economy	3300.00
0005433368736	21769	Economy	3300.00
0005433368880	21769	Economy	3300.00
0005435654477	21769	Economy	3300.00
0005435270086	9370	Business	186200.00
0005433806406	9370	Business	186200.00
0005433806407	9370	Business	186200.00
0005435270080	9370	Business	186200.00
0005435269976	9370	Business	186200.00
0005433806408	9370	Business	186200.00
0005435269926	9370	Business	186200.00
0005435270119	9370	Economy	68300.00
0005435270025	9370	Economy	68300.00
0005433786189	9370	Economy	62100.00
0005434171388	9370	Economy	62100.00
0005435269941	9370	Economy	62100.00
0005435270084	9370	Economy	62100.00
0005434171374	9370	Economy	62100.00
0005435269968	9370	Economy	62100.00
0005435270051	9370	Economy	62100.00
0005433806409	9370	Economy	62100.00
0005435269988	9370	Economy	62100.00
0005435270027	9370	Economy	62100.00
0005435270026	9370	Economy	62100.00
0005433786185	9370	Economy	62100.00
0005435270016	9370	Economy	62100.00
0005435269929	9370	Economy	62100.00
0005435269940	9370	Economy	62100.00
0005435269903	9370	Economy	62100.00
0005435269961	9370	Economy	62100.00
0005433786187	9370	Economy	62100.00
0005435269967	9370	Economy	62100.00
0005435270059	9370	Economy	62100.00
0005435270017	9370	Economy	62100.00
0005432657541	9370	Economy	62100.00
0005435270065	9370	Economy	62100.00
0005435269969	9370	Economy	62100.00
0005433763630	9370	Economy	62100.00
0005434171377	9370	Economy	62100.00
0005435270085	9370	Economy	62100.00
0005435269938	9370	Economy	62100.00
0005433806405	9370	Economy	62100.00
0005435269949	9370	Economy	62100.00
0005435269892	9370	Economy	62100.00
0005435269973	9370	Economy	62100.00
0005435269984	9370	Economy	62100.00
0005432657540	9370	Economy	62100.00
0005435269904	9370	Economy	62100.00
0005433786191	9370	Economy	62100.00
0005435269891	9370	Economy	62100.00
0005435270018	9370	Economy	62100.00
0005434171375	9370	Economy	62100.00
0005434171408	9370	Economy	62100.00
0005434171387	9370	Economy	68300.00
0005435270044	9370	Economy	62100.00
0005434171402	9370	Economy	62100.00
0005435270070	9370	Economy	68300.00
0005434171427	9370	Economy	62100.00
0005435269931	9370	Economy	62100.00
0005435269928	9370	Economy	62100.00
0005433806404	9370	Economy	62100.00
0005434171306	9370	Economy	62100.00
0005434171426	9370	Economy	62100.00
0005435269966	9370	Economy	62100.00
0005435270081	9370	Economy	62100.00
0005433786190	9370	Economy	62100.00
0005434171342	9370	Economy	62100.00
0005433786186	9370	Economy	62100.00
0005435270136	9370	Economy	62100.00
0005435270089	9370	Economy	62100.00
0005435269980	9370	Economy	62100.00
0005435269932	9370	Economy	62100.00
0005433786188	9370	Economy	62100.00
0005435270074	9370	Economy	62100.00
0005435270083	9370	Economy	62100.00
0005435269930	9370	Economy	62100.00
0005435269948	9370	Economy	62100.00
0005435270090	9370	Economy	62100.00
0005435269974	9370	Economy	62100.00
0005434273116	9370	Economy	62100.00
0005435858698	9370	Economy	62100.00
0005435270138	9370	Economy	62100.00
0005435270069	9370	Economy	62100.00
0005435270137	9370	Economy	62100.00
0005435270082	9370	Economy	62100.00
0005432659751	26232	Business	186200.00
0005432659752	26232	Business	186200.00
0005433785837	26232	Business	186200.00
0005434151795	26232	Business	186200.00
0005433806145	26232	Business	186200.00
0005433806182	26232	Business	186200.00
0005433785934	26232	Business	186200.00
0005433763554	26232	Business	186200.00
0005433785896	26232	Business	186200.00
0005433785864	26232	Business	186200.00
0005433785942	26232	Business	186200.00
0005433785697	26232	Business	186200.00
0005433785968	26232	Business	186200.00
0005433763553	26232	Economy	68300.00
0005433763508	26232	Economy	68300.00
0005433785812	26232	Economy	62100.00
0005433806124	26232	Economy	62100.00
0005433785954	26232	Economy	62100.00
0005433763507	26232	Economy	62100.00
0005433785892	26232	Economy	62100.00
0005433763566	26232	Economy	62100.00
0005432663078	26232	Economy	62100.00
0005433785792	26232	Economy	62100.00
0005433785897	26232	Economy	62100.00
0005433786007	26232	Economy	62100.00
0005433785910	26232	Economy	62100.00
0005433806305	26232	Economy	62100.00
0005433785963	26232	Economy	62100.00
0005433785922	26232	Economy	62100.00
0005433786058	26232	Economy	62100.00
0005433806304	26232	Economy	62100.00
0005433806181	26232	Economy	62100.00
0005433806087	26232	Economy	62100.00
0005433806270	26232	Economy	62100.00
0005433785923	26232	Economy	62100.00
0005433763561	26232	Economy	62100.00
0005432666443	26232	Economy	62100.00
0005433785921	26232	Economy	62100.00
0005433806271	26232	Economy	62100.00
0005433785953	26232	Economy	62100.00
0005433806301	26232	Economy	62100.00
0005433785731	26232	Economy	62100.00
0005433785943	26232	Economy	62100.00
0005433785919	26232	Economy	62100.00
0005433806308	26232	Economy	62100.00
0005433806288	26232	Economy	62100.00
0005433806151	26232	Economy	62100.00
0005433806207	26232	Economy	62100.00
0005433763568	26232	Economy	62100.00
0005433785696	26232	Economy	62100.00
0005433763530	26232	Economy	62100.00
0005432663077	26232	Economy	62100.00
0005433806211	26232	Economy	62100.00
0005435270221	26232	Economy	62100.00
0005433786016	26232	Economy	62100.00
0005433806190	26232	Economy	62100.00
0005433785869	26232	Economy	62100.00
0005433785909	26232	Economy	62100.00
0005433806309	26232	Economy	62100.00
0005433785893	26232	Economy	62100.00
0005434271375	26232	Economy	62100.00
0005433785894	26232	Economy	62100.00
0005433785787	26232	Economy	62100.00
0005433785905	26232	Economy	62100.00
0005433806194	26232	Economy	62100.00
0005433786022	26232	Economy	62100.00
0005433786023	26232	Economy	62100.00
0005433785835	26232	Economy	62100.00
0005433806383	26232	Economy	62100.00
0005433785863	26232	Economy	62100.00
0005433785621	26232	Economy	62100.00
0005433785720	26232	Economy	62100.00
0005433806302	26232	Economy	68300.00
0005433806214	26232	Economy	62100.00
0005435270220	26232	Economy	62100.00
0005433785775	26232	Economy	68300.00
0005433806262	26232	Economy	62100.00
0005433763594	26232	Economy	62100.00
0005433785755	26232	Economy	62100.00
0005433763506	26232	Economy	62100.00
0005433806178	26232	Economy	62100.00
0005432666434	26232	Economy	62100.00
0005433763480	26232	Economy	62100.00
0005433785920	26232	Economy	62100.00
0005433806210	26232	Economy	62100.00
0005433785841	26232	Economy	62100.00
0005433763479	26232	Economy	62100.00
0005433785961	26232	Economy	62100.00
0005435858744	26232	Economy	62100.00
0005433806232	26232	Economy	62100.00
0005435858745	26232	Economy	62100.00
0005433806086	26232	Economy	62100.00
0005433785836	26232	Economy	62100.00
0005433785561	26232	Economy	62100.00
0005435270219	26232	Economy	62100.00
0005433806153	26232	Economy	62100.00
0005433806212	26232	Economy	62100.00
0005433785927	26232	Economy	62100.00
0005433786008	26232	Economy	62100.00
0005433763529	26232	Economy	62100.00
0005433806199	26232	Economy	62100.00
0005433806179	26232	Economy	62100.00
0005434151794	26232	Economy	62100.00
0005433806369	26232	Economy	62100.00
0005433785840	26232	Economy	62100.00
0005433806261	26232	Economy	62100.00
0005433806188	26232	Economy	62100.00
0005433785928	26232	Economy	62100.00
0005433806039	26232	Economy	62100.00
0005433763578	26232	Economy	62100.00
0005433785791	26232	Economy	62100.00
0005433806251	26232	Economy	62100.00
0005433763607	26232	Economy	62100.00
0005433806189	26232	Economy	62100.00
0005433763577	26232	Economy	62100.00
0005433785962	26232	Economy	62100.00
0005433806227	26232	Economy	62100.00
0005433763563	26232	Economy	62100.00
0005433763574	26232	Economy	62100.00
0005433806213	26232	Economy	62100.00
0005433785829	26232	Economy	62100.00
0005433785719	26232	Economy	62100.00
0005433763593	26232	Economy	62100.00
0005435929715	4910	Economy	5300.00
0005435929714	4910	Economy	5300.00
0005435929713	4910	Economy	5300.00
0005435135767	33041	Economy	5900.00
0005435135800	33041	Economy	5300.00
0005435135788	33041	Economy	5300.00
0005435135782	33041	Economy	5300.00
0005435135783	33041	Economy	5300.00
0005435135784	33041	Economy	5300.00
0005434218061	9468	Economy	19700.00
0005434218071	9468	Economy	19700.00
0005434218058	9468	Economy	17900.00
0005434218062	9468	Economy	17900.00
0005434218072	9468	Economy	17900.00
0005434218073	9468	Economy	17900.00
0005434218074	9468	Economy	17900.00
0005434218060	9468	Economy	17900.00
0005434983410	27337	Economy	19700.00
0005434983425	27337	Economy	17900.00
0005434983421	27337	Economy	17900.00
0005434983409	27337	Economy	17900.00
0005433962257	24260	Business	36400.00
0005433962202	24260	Business	36400.00
0005433962244	24260	Business	36400.00
0005433962198	24260	Business	36400.00
0005433986940	24260	Business	36400.00
0005433986872	24260	Business	36400.00
0005433986998	24260	Business	36400.00
0005433962157	24260	Business	36400.00
0005433962133	24260	Business	36400.00
0005433962038	24260	Business	36400.00
0005433987183	24260	Business	36400.00
0005433987078	24260	Business	36400.00
0005433987077	24260	Business	36400.00
0005433986929	24260	Economy	13400.00
0005433986971	24260	Business	36400.00
0005433987043	24260	Economy	13400.00
0005433986990	24260	Economy	13400.00
0005433986862	24260	Economy	13400.00
0005433962240	24260	Economy	12100.00
0005433986890	24260	Economy	12100.00
0005433987104	24260	Economy	12100.00
0005433962051	24260	Economy	12100.00
0005433962262	24260	Economy	12100.00
0005433962076	24260	Economy	12100.00
0005433962239	24260	Economy	12100.00
0005434908904	24260	Economy	12100.00
0005433962135	24260	Economy	12100.00
0005433962130	24260	Economy	12100.00
0005433962034	24260	Economy	12100.00
0005433986902	24260	Economy	12100.00
0005433987152	24260	Economy	12100.00
0005433962163	24260	Economy	12100.00
0005433986871	24260	Economy	12100.00
0005433961926	24260	Economy	12100.00
0005433961919	24260	Economy	12100.00
0005433987070	24260	Economy	12100.00
0005433962181	24260	Economy	12100.00
0005433962231	24260	Economy	12100.00
0005433986954	24260	Economy	12100.00
0005433962153	24260	Economy	12100.00
0005433962176	24260	Economy	12100.00
0005433962039	24260	Economy	12100.00
0005433987255	24260	Economy	12100.00
0005433987057	24260	Economy	12100.00
0005433962238	24260	Economy	12100.00
0005433962190	24260	Economy	12100.00
0005433986932	24260	Economy	12100.00
0005433962150	24260	Economy	12100.00
0005433987103	24260	Economy	12100.00
0005433986827	24260	Economy	12100.00
0005433962141	24260	Economy	12100.00
0005433962191	24260	Economy	12100.00
0005433962169	24260	Economy	12100.00
0005433962168	24260	Economy	12100.00
0005433962224	24260	Economy	12100.00
0005433962160	24260	Economy	12100.00
0005433986889	24260	Economy	12100.00
0005433986978	24260	Economy	12100.00
0005433962046	24260	Economy	12100.00
0005433962178	24260	Economy	12100.00
0005433961955	24260	Economy	12100.00
0005433986886	24260	Economy	12100.00
0005433962131	24260	Economy	12100.00
0005433986955	24260	Economy	12100.00
0005433962213	24260	Economy	12100.00
0005433986860	24260	Economy	12100.00
0005433962214	24260	Economy	12100.00
0005433987148	24260	Economy	12100.00
0005433962162	24260	Economy	12100.00
0005433987058	24260	Economy	12100.00
0005433962216	24260	Economy	12100.00
0005433986941	24260	Economy	13400.00
0005433987051	24260	Economy	12100.00
0005433962217	24260	Economy	12100.00
0005433987126	24260	Economy	12100.00
0005433962258	24260	Economy	13400.00
0005433962245	24260	Economy	13400.00
0005433962199	24260	Economy	12100.00
0005433987097	24260	Economy	12100.00
0005433962235	24260	Economy	12100.00
0005433986861	24260	Economy	12100.00
0005433962189	24260	Economy	12100.00
0005433962193	24260	Economy	12100.00
0005433986916	24260	Economy	12100.00
0005433986996	24260	Economy	12100.00
0005433962050	24260	Economy	12100.00
0005433962170	24260	Economy	12100.00
0005433987098	24260	Economy	12100.00
0005433962154	24260	Economy	12100.00
0005433986953	24260	Economy	12100.00
0005433986962	24260	Economy	12100.00
0005433986967	24260	Economy	12100.00
0005433987039	24260	Economy	12100.00
0005433987011	24260	Economy	12100.00
0005433961956	24260	Economy	12100.00
0005433987005	24260	Economy	12100.00
0005433987074	24260	Economy	12100.00
0005433987008	24260	Economy	12100.00
0005433962043	24260	Economy	12100.00
0005433962080	24260	Economy	12100.00
0005433987147	24260	Economy	12100.00
0005433986981	24260	Economy	12100.00
0005433987096	24260	Economy	12100.00
0005433986961	24260	Economy	12100.00
0005433987071	24260	Economy	12100.00
0005433987038	24260	Economy	12100.00
0005433962205	24260	Economy	12100.00
0005433962164	24260	Economy	12100.00
0005433962045	24260	Economy	12100.00
0005433987009	24260	Economy	12100.00
0005433987002	24260	Economy	12100.00
0005433962177	24260	Economy	12100.00
0005433962088	24260	Economy	12100.00
0005433962265	24260	Economy	12100.00
0005433962723	25959	Business	36400.00
0005433962728	25959	Business	36400.00
0005433962705	25959	Business	36400.00
0005433962706	25959	Business	36400.00
0005433962701	25959	Business	36400.00
0005433962714	25959	Business	36400.00
0005433987370	25959	Business	36400.00
0005433987369	25959	Economy	13400.00
0005433962717	25959	Economy	12100.00
0005433962702	25959	Economy	12100.00
0005433962700	25959	Economy	12100.00
0005433962726	25959	Economy	12100.00
0005433962730	25959	Economy	12100.00
0005433962707	25959	Economy	12100.00
0005433987367	25959	Economy	12100.00
0005433987368	25959	Economy	12100.00
0005433962720	25959	Economy	12100.00
0005433962727	25959	Economy	12100.00
0005433962708	25959	Economy	12100.00
0005433962719	25959	Economy	12100.00
0005433962713	25959	Economy	12100.00
0005433962722	25959	Economy	12100.00
0005433962710	25959	Economy	12100.00
0005433962729	25959	Economy	12100.00
0005433962711	25959	Economy	12100.00
0005433962716	25959	Economy	12100.00
0005433987372	25959	Economy	12100.00
0005433962712	25959	Economy	12100.00
0005433987371	25959	Economy	12100.00
0005433962721	25959	Economy	12100.00
0005433962725	25959	Economy	12100.00
0005433962709	25959	Economy	12100.00
0005433962715	25959	Economy	12100.00
0005433962703	25959	Economy	12100.00
0005433962718	25959	Economy	12100.00
0005433962704	25959	Economy	12100.00
0005433962724	25959	Economy	12100.00
0005433166203	946	Economy	25400.00
0005433166264	946	Economy	25400.00
0005433166194	946	Economy	23100.00
0005433166144	946	Economy	23100.00
0005433166263	946	Economy	23100.00
0005434481051	946	Economy	23100.00
0005433166180	946	Economy	23100.00
0005433166245	946	Economy	23100.00
0005434481049	946	Economy	23100.00
0005433166205	946	Economy	23100.00
0005433166232	946	Economy	23100.00
0005433166204	946	Economy	23100.00
0005434481050	946	Economy	23100.00
0005434480934	16550	Economy	25400.00
0005434480933	16550	Economy	25400.00
0005434480992	16550	Economy	25400.00
0005434480884	16550	Economy	23100.00
0005434480912	16550	Economy	23100.00
0005434480967	16550	Economy	23100.00
0005434480932	16550	Economy	23100.00
0005434481008	16550	Economy	23100.00
0005434480924	16550	Economy	23100.00
0005434480919	16550	Economy	23100.00
0005434480957	16550	Economy	23100.00
0005434480829	16550	Economy	23100.00
0005434480862	16550	Economy	23100.00
0005434480926	16550	Economy	23100.00
0005434480911	16550	Economy	23100.00
0005434480925	16550	Economy	23100.00
0005434480927	16550	Economy	23100.00
0005434480861	16550	Economy	23100.00
0005434480956	16550	Economy	23100.00
0005434480895	16550	Economy	23100.00
0005434480886	16550	Economy	23100.00
0005434480888	16550	Economy	23100.00
0005434480853	16550	Economy	23100.00
0005434480894	16550	Economy	23100.00
0005434480887	16550	Economy	23100.00
0005434480995	16550	Economy	23100.00
0005434480931	16550	Economy	23100.00
0005434481007	16550	Economy	23100.00
0005433872588	3204	Economy	19000.00
0005433872571	32554	Economy	17200.00
0005433872563	32554	Economy	17200.00
0005433872560	32554	Economy	17200.00
0005433872566	32554	Economy	17200.00
0005433872550	32554	Economy	17200.00
0005433872567	32554	Economy	17200.00
0005433290013	10366	Economy	17000.00
0005435142967	10366	Economy	17000.00
0005433290001	10366	Economy	15400.00
0005435150431	10366	Economy	15400.00
0005435150432	10366	Economy	15400.00
0005435142965	10366	Economy	15400.00
0005433290029	10366	Economy	15400.00
0005433290002	10366	Economy	15400.00
0005435386708	10366	Economy	15400.00
0005433290034	10366	Economy	15400.00
0005435386732	10366	Economy	15400.00
0005435142966	10366	Economy	15400.00
0005433290028	10366	Economy	15400.00
0005435386731	10366	Economy	15400.00
0005435386709	10366	Economy	15400.00
0005433290012	10366	Economy	15400.00
0005435386707	10366	Economy	15400.00
0005435386722	10366	Economy	15400.00
0005433290003	10366	Economy	15400.00
0005433290030	10366	Economy	15400.00
0005435386710	10366	Economy	15400.00
0005433290025	10366	Economy	15400.00
0005435386738	10366	Economy	15400.00
0005435150377	21937	Economy	17000.00
0005435150365	21937	Economy	17000.00
0005435142862	21937	Economy	17000.00
0005435142855	21937	Economy	15400.00
0005435150362	21937	Economy	15400.00
0005435142899	21937	Economy	15400.00
0005435150367	21937	Economy	15400.00
0005435142883	21937	Economy	15400.00
0005435150260	21937	Economy	15400.00
0005435150378	21937	Economy	15400.00
0005435150331	21937	Economy	15400.00
0005435142932	21937	Economy	15400.00
0005435150283	21937	Economy	15400.00
0005435150333	21937	Economy	15400.00
0005435142877	21937	Economy	15400.00
0005435150379	21937	Economy	15400.00
0005435150284	21937	Economy	15400.00
0005435142843	21937	Economy	15400.00
0005434573769	11202	Business	57200.00
0005434573773	11202	Business	57200.00
0005435545881	11202	Business	57200.00
0005435529824	11202	Business	57200.00
0005435529808	11202	Business	57200.00
0005435529791	11202	Business	57200.00
0005435319766	11202	Economy	19100.00
0005435319809	11202	Economy	19100.00
0005435502865	11202	Economy	19100.00
0005435529745	11202	Economy	19100.00
0005435502821	11202	Economy	19100.00
0005435319774	11202	Economy	21000.00
0005435529775	11202	Economy	21000.00
0005435319817	11202	Economy	21000.00
0005435529788	11202	Economy	21000.00
0005435529852	11202	Economy	19100.00
0005435545907	11202	Economy	19100.00
0005435502913	11202	Economy	19100.00
0005435529737	11202	Economy	19100.00
0005435529782	11202	Economy	19100.00
0005435502870	11202	Economy	19100.00
0005435502820	11202	Economy	19100.00
0005435545892	11202	Economy	19100.00
0005435319785	11202	Economy	19100.00
0005435529815	11202	Economy	19100.00
0005435529793	11202	Economy	19100.00
0005435502909	11202	Economy	19100.00
0005435502910	11202	Economy	19100.00
0005434573770	11202	Economy	19100.00
0005435545908	11202	Economy	19100.00
0005435502784	11202	Economy	19100.00
0005435502864	11202	Economy	19100.00
0005435545924	11202	Economy	19100.00
0005435319803	11202	Economy	19100.00
0005435502709	11202	Economy	19100.00
0005435529825	11202	Economy	19100.00
0005435319818	11202	Economy	19100.00
0005435502773	11202	Economy	19100.00
0005435545904	11202	Economy	19100.00
0005435502866	11202	Economy	19100.00
0005435502911	11202	Economy	19100.00
0005435529809	11202	Economy	19100.00
0005435502852	11202	Economy	19100.00
0005435529714	11202	Economy	19100.00
0005435319784	11202	Economy	19100.00
0005435502869	11202	Economy	19100.00
0005435529744	11202	Economy	19100.00
0005435529789	11202	Economy	19100.00
0005435502855	11202	Economy	19100.00
0005435529794	11202	Economy	19100.00
0005435529698	11202	Economy	19100.00
0005435545923	11202	Economy	19100.00
0005435319765	11202	Economy	19100.00
0005435529818	11202	Economy	19100.00
0005435502834	11202	Economy	19100.00
0005434573771	11202	Economy	19100.00
0005435502819	11202	Economy	19100.00
0005435529802	11202	Economy	19100.00
0005435319792	11202	Economy	19100.00
0005435545905	11202	Economy	19100.00
0005434573772	11202	Economy	19100.00
0005435502796	11202	Economy	19100.00
0005435545918	11202	Economy	19100.00
0005435502932	11202	Economy	19100.00
0005435545930	11202	Economy	19100.00
0005435529841	11202	Economy	19100.00
0005434573670	20903	Business	57200.00
0005435518457	20903	Business	57200.00
0005434573682	20903	Business	57200.00
0005435518456	20903	Business	57200.00
0005434573676	20903	Economy	19100.00
0005434573691	20903	Economy	19100.00
0005435502960	20903	Economy	21000.00
0005435518458	20903	Economy	21000.00
0005435518455	20903	Economy	19100.00
0005435502956	20903	Economy	19100.00
0005435508826	20903	Economy	19100.00
0005434573683	20903	Economy	19100.00
0005434573647	20903	Economy	19100.00
0005435508827	20903	Economy	19100.00
0005435518461	20903	Economy	19100.00
0005434573671	20903	Economy	19100.00
0005434573673	20903	Economy	19100.00
0005435518459	20903	Economy	19100.00
0005434573675	20903	Economy	19100.00
0005434573737	20903	Economy	19100.00
0005435518460	20903	Economy	19100.00
0005435502958	20903	Economy	19100.00
0005434573646	20903	Economy	19100.00
0005435502957	20903	Economy	19100.00
0005434573677	20903	Economy	19100.00
0005434573688	20903	Economy	19100.00
0005435319829	20903	Economy	19100.00
0005435502959	20903	Economy	19100.00
0005435508825	20903	Economy	19100.00
0005433683416	24304	Economy	18800.00
0005433927498	24304	Economy	18800.00
0005433927501	24304	Economy	17100.00
0005433927496	24304	Economy	17100.00
0005433927483	24304	Economy	17100.00
0005433927500	24304	Economy	17100.00
0005433927502	24304	Economy	17100.00
0005433683415	24304	Economy	17100.00
0005433683418	24304	Economy	17100.00
0005433683417	24304	Economy	17100.00
0005433683414	24304	Economy	17100.00
0005433927493	24304	Economy	17100.00
0005433927497	24304	Economy	17100.00
0005433927484	24304	Economy	17100.00
0005433927481	24304	Economy	17100.00
0005433927509	24304	Economy	17100.00
0005433927513	24304	Economy	17100.00
0005433927482	24304	Economy	17100.00
0005433683398	29284	Economy	18800.00
0005433927514	29284	Economy	17100.00
0005433683403	29284	Economy	17100.00
0005433683384	29284	Economy	17100.00
0005433683383	29284	Economy	17100.00
0005433683402	29284	Economy	17100.00
0005433683393	29284	Economy	17100.00
0005433927516	29284	Economy	17100.00
0005433683379	29284	Economy	17100.00
0005433927515	29284	Economy	17100.00
0005433683407	29284	Economy	17100.00
0005433683399	29284	Economy	17100.00
0005432693883	2978	Business	10300.00
0005432693861	2978	Business	10300.00
0005432693770	2978	Business	10300.00
0005432693810	2978	Business	10300.00
0005432693885	2978	Business	10300.00
0005432693701	2978	Business	10300.00
0005432693726	2978	Economy	3400.00
0005432693865	2978	Economy	3400.00
0005432693804	2978	Economy	3400.00
0005432693769	2978	Economy	3800.00
0005432693818	2978	Economy	3800.00
0005432693851	2978	Economy	3800.00
0005432693781	2978	Economy	3400.00
0005432693797	2978	Economy	3400.00
0005432693868	2978	Economy	3400.00
0005432693700	2978	Economy	3400.00
0005432693751	2978	Economy	3400.00
0005432693819	2978	Economy	3400.00
0005432693803	2978	Economy	3400.00
0005432693809	2978	Economy	3400.00
0005432693837	2978	Economy	3400.00
0005432693761	2978	Economy	3400.00
0005432693869	2978	Economy	3400.00
0005432693780	2978	Economy	3400.00
0005432693839	2978	Economy	3400.00
0005432693838	2978	Economy	3400.00
0005432693836	2978	Economy	3400.00
0005432693763	2978	Economy	3400.00
0005432693884	2978	Economy	3400.00
0005432693771	2978	Economy	3400.00
0005433124456	2969	Business	10300.00
0005432881147	2969	Business	10300.00
0005433124415	2969	Business	10300.00
0005433124455	2969	Business	10300.00
0005433124442	2969	Business	10300.00
0005432881194	2969	Business	10300.00
0005434310180	2969	Business	10300.00
0005433124324	2969	Economy	3400.00
0005432881157	2969	Economy	3400.00
0005433124393	2969	Economy	3400.00
0005432881135	2969	Economy	3800.00
0005433124397	2969	Economy	3800.00
0005433194921	2969	Economy	3400.00
0005432881138	2969	Economy	3400.00
0005432881176	2969	Economy	3400.00
0005433124465	2969	Economy	3400.00
0005433124410	2969	Economy	3400.00
0005433124399	2969	Economy	3400.00
0005433124394	2969	Economy	3400.00
0005433124464	2969	Economy	3400.00
0005432881207	2969	Economy	3400.00
0005432707509	2969	Economy	3400.00
0005433194918	2969	Economy	3400.00
0005432881148	2969	Economy	3400.00
0005432881156	2969	Economy	3400.00
0005432707508	2969	Economy	3400.00
0005433124398	2969	Economy	3400.00
0005433124386	2969	Economy	3400.00
0005433194959	2969	Economy	3400.00
0005434310182	2969	Economy	3400.00
0005433124413	2969	Economy	3400.00
0005432881136	2969	Economy	3400.00
0005433124343	2969	Economy	3400.00
0005434310181	2969	Economy	3400.00
0005433124414	2969	Economy	3400.00
0005432881177	2969	Economy	3400.00
0005432217863	2969	Economy	3400.00
0005433194950	2969	Economy	3400.00
0005433124389	2969	Economy	3400.00
0005433124378	2969	Economy	3400.00
0005432881206	2969	Economy	3400.00
0005432707507	2969	Economy	3400.00
0005433124437	2969	Economy	3400.00
0005433124466	2969	Economy	3400.00
0005432881150	2969	Economy	3400.00
0005432707416	29949	Business	10300.00
0005432881248	29949	Business	10300.00
0005432881245	29949	Business	10300.00
0005433124541	29949	Business	10300.00
0005432707456	29949	Business	10300.00
0005433195011	29949	Business	10300.00
0005432707408	29949	Business	10300.00
0005433124545	29949	Economy	3400.00
0005432707465	29949	Economy	3400.00
0005432707482	29949	Economy	3400.00
0005432707360	29949	Economy	3400.00
0005433195010	29949	Economy	3400.00
0005432693969	29949	Economy	3800.00
0005433124544	29949	Economy	3400.00
0005433195014	29949	Economy	3400.00
0005433195012	29949	Economy	3400.00
0005433124543	29949	Economy	3400.00
0005433124546	29949	Economy	3400.00
0005434300269	29949	Economy	3400.00
0005433124547	29949	Economy	3400.00
0005433124550	29949	Economy	3400.00
0005433195008	29949	Economy	3400.00
0005432707481	29949	Economy	3400.00
0005434300268	29949	Economy	3400.00
0005433124542	29949	Economy	3400.00
0005432707339	29949	Economy	3400.00
0005432707449	29949	Economy	3400.00
0005432881246	29949	Economy	3400.00
0005434300271	29949	Economy	3400.00
0005432707400	29949	Economy	3400.00
0005433124548	29949	Economy	3400.00
0005432707457	29949	Economy	3400.00
0005432707277	29949	Economy	3400.00
0005434300270	29949	Economy	3400.00
0005432707426	29949	Economy	3400.00
0005433195013	29949	Economy	3400.00
0005432707352	29949	Economy	3400.00
0005433124549	29949	Economy	3400.00
0005432707334	29949	Economy	3400.00
0005433195009	29949	Economy	3400.00
0005432707276	29949	Economy	3400.00
0005432707455	29949	Economy	3400.00
0005432707336	29949	Economy	3400.00
0005432881247	29949	Economy	3400.00
0005432707448	29949	Economy	3400.00
0005432707337	29949	Economy	3400.00
0005432693968	29949	Economy	3400.00
0005432707477	29949	Economy	3400.00
0005434980666	23669	Economy	3600.00
0005434980673	23669	Economy	3600.00
0005434989114	23669	Economy	3600.00
0005434980665	23669	Economy	3600.00
0005434980672	23669	Economy	3600.00
0005434980664	23669	Economy	3600.00
0005434989111	23669	Economy	3600.00
0005434980674	23669	Economy	3600.00
0005434980668	23669	Economy	3600.00
0005434980670	23669	Economy	3600.00
0005434980669	23669	Economy	3600.00
0005434989112	23669	Economy	3600.00
0005434989116	23669	Economy	3600.00
0005434980671	23669	Economy	3600.00
0005434989113	23669	Economy	3600.00
0005434980667	23669	Economy	3600.00
0005434989115	23669	Economy	3600.00
0005434989117	23669	Economy	3600.00
0005434988954	27568	Economy	4000.00
0005434980488	27568	Economy	4000.00
0005434980443	27568	Economy	4000.00
0005434980615	27568	Economy	3600.00
0005434980444	27568	Economy	3600.00
0005434988979	27568	Economy	3600.00
0005434980466	27568	Economy	3600.00
0005434980511	27568	Economy	3600.00
0005434980510	27568	Economy	3600.00
0005434980404	27568	Economy	3600.00
0005434980515	27568	Economy	3600.00
0005434980499	27568	Economy	3600.00
0005434980449	27568	Economy	3600.00
0005434980480	27568	Economy	3600.00
0005434988938	27568	Economy	3600.00
0005434980469	27568	Economy	3600.00
0005434980424	27568	Economy	3600.00
0005434988997	27568	Economy	3600.00
0005434988999	27568	Economy	3600.00
0005434988998	27568	Economy	3600.00
0005434988969	27568	Economy	3600.00
0005434988953	27568	Economy	3600.00
0005434989009	27568	Economy	3600.00
0005434988939	27568	Economy	3600.00
0005434988978	27568	Economy	3600.00
0005434988975	27568	Economy	3600.00
0005434980475	27568	Economy	3600.00
0005434980531	27568	Economy	3600.00
0005434980479	27568	Economy	3600.00
0005434980446	27568	Economy	3600.00
0005434988970	27568	Economy	3600.00
0005434980379	27568	Economy	3600.00
0005434980467	27568	Economy	3600.00
0005434980465	27568	Economy	3600.00
0005434980616	27568	Economy	3600.00
0005434980468	27568	Economy	3600.00
0005433111561	10253	Economy	19700.00
0005433111560	10253	Economy	19700.00
0005433113584	10253	Economy	19700.00
0005433113587	10253	Economy	19700.00
0005434302910	10253	Economy	19700.00
0005434302581	10253	Economy	19700.00
0005433113588	10253	Economy	19700.00
0005433113585	10253	Economy	19700.00
0005434302543	19596	Economy	21600.00
0005434302542	19596	Economy	21600.00
0005433113620	19596	Economy	19700.00
0005434302567	19596	Economy	19700.00
0005433113619	19596	Economy	19700.00
0005434302556	19596	Economy	19700.00
0005434302540	19596	Economy	19700.00
0005434302541	19596	Economy	19700.00
0005434302554	19596	Economy	19700.00
0005434302561	19596	Economy	19700.00
0005434302544	19596	Economy	19700.00
0005434302560	19596	Economy	19700.00
0005435939951	3574	Business	26900.00
0005435950340	3574	Business	26900.00
0005435070561	3574	Business	26900.00
0005435925611	3574	Business	26900.00
0005435925637	3574	Business	26900.00
0005435925589	3574	Economy	9000.00
0005435925656	3574	Economy	9000.00
0005435070558	3574	Economy	9900.00
0005435925655	3574	Economy	9900.00
0005435070562	3574	Economy	9900.00
0005435925681	3574	Economy	9000.00
0005435925613	3574	Economy	9000.00
0005435950339	3574	Economy	9000.00
0005435925591	3574	Economy	9000.00
0005435950341	3574	Economy	9000.00
0005435070560	3574	Economy	9000.00
0005435070563	3574	Economy	9000.00
0005435719124	3574	Economy	9000.00
0005435950342	3574	Economy	9000.00
0005435925610	3574	Economy	9000.00
0005435925636	3574	Economy	9000.00
0005435070555	3574	Economy	9000.00
0005435925605	3574	Economy	9000.00
0005435925588	3574	Economy	9000.00
0005435070557	3574	Economy	9000.00
0005435070556	3574	Economy	9000.00
0005435925680	3574	Economy	9000.00
0005435070559	3574	Economy	9000.00
0005435070427	15334	Business	26900.00
0005435070513	15334	Business	26900.00
0005435950302	15334	Business	26900.00
0005435070400	15334	Business	26900.00
0005435070145	15334	Business	26900.00
0005435070082	15334	Business	26900.00
0005435070240	15334	Business	26900.00
0005435070298	15334	Business	26900.00
0005435070392	15334	Business	26900.00
0005435070336	15334	Business	26900.00
0005435070205	15334	Economy	9000.00
0005435070433	15334	Economy	9000.00
0005435070081	15334	Economy	9000.00
0005435070361	15334	Economy	9000.00
0005435070246	15334	Economy	9000.00
0005435950306	15334	Economy	9000.00
0005435070390	15334	Economy	9000.00
0005435070330	15334	Economy	9000.00
0005435925721	15334	Economy	9000.00
0005435070069	15334	Economy	9900.00
0005435070280	15334	Economy	9900.00
0005435070206	15334	Economy	9900.00
0005435070325	15334	Economy	9900.00
0005435070304	15334	Economy	9000.00
0005435925720	15334	Economy	9000.00
0005435070466	15334	Economy	9000.00
0005435070258	15334	Economy	9000.00
0005435070239	15334	Economy	9000.00
0005435070284	15334	Economy	9000.00
0005435070091	15334	Economy	9000.00
0005435070331	15334	Economy	9000.00
0005435070209	15334	Economy	9000.00
0005435070327	15334	Economy	9000.00
0005435070218	15334	Economy	9000.00
0005435070250	15334	Economy	9000.00
0005435070359	15334	Economy	9000.00
0005435925723	15334	Economy	9000.00
0005435925722	15334	Economy	9000.00
0005435950300	15334	Economy	9000.00
0005435070147	15334	Economy	9000.00
0005435950299	15334	Economy	9000.00
0005435070131	15334	Economy	9000.00
0005435070360	15334	Economy	9000.00
0005435070179	15334	Economy	9000.00
0005435070261	15334	Economy	9000.00
0005435070329	15334	Economy	9000.00
0005435070326	15334	Economy	9000.00
0005435070347	15334	Economy	9000.00
0005435070180	15334	Economy	9000.00
0005435070432	15334	Economy	9000.00
0005435070259	15334	Economy	9000.00
0005435070210	15334	Economy	9000.00
0005435070293	15334	Economy	9000.00
0005435925725	15334	Economy	9000.00
0005435070090	15334	Economy	9000.00
0005435070428	15334	Economy	9000.00
0005435070248	15334	Economy	9000.00
0005435070391	15334	Economy	9000.00
0005435070296	15334	Economy	9000.00
0005435070197	15334	Economy	9000.00
0005435070276	15334	Economy	9000.00
0005435070297	15334	Economy	9000.00
0005435070181	15334	Economy	9000.00
0005435070033	15334	Economy	9000.00
0005435925724	15334	Economy	9000.00
0005435070328	15334	Economy	9000.00
0005435070278	15334	Economy	9000.00
0005435950305	15334	Economy	9000.00
0005435070426	15334	Economy	9000.00
0005435070423	15334	Economy	9000.00
0005435070467	15334	Economy	9000.00
0005435070277	15334	Economy	9000.00
0005435950313	15334	Economy	9000.00
0005435070247	15334	Economy	9000.00
0005435070231	15334	Economy	9000.00
0005435070287	15334	Economy	9000.00
0005435070122	15334	Economy	9000.00
0005435070260	15334	Economy	9000.00
0005435070279	15334	Economy	9000.00
0005435070217	15334	Economy	9000.00
0005435070388	15334	Economy	9000.00
0005435070389	15334	Economy	9000.00
0005435070121	15334	Economy	9000.00
0005435070285	15334	Economy	9000.00
0005435070172	15334	Economy	9000.00
0005435070198	15334	Economy	9000.00
0005435070014	15334	Economy	9000.00
0005435070249	15334	Economy	9000.00
0005432659769	18130	Economy	5900.00
0005432659770	18130	Economy	5900.00
0005432667500	26457	Economy	5900.00
0005432660868	26457	Economy	5900.00
0005432664179	26457	Economy	5900.00
0005432664184	26457	Economy	5900.00
0005432664173	26457	Economy	5900.00
0005432660869	26457	Economy	5900.00
0005433103265	31	Business	20000.00
0005432902101	31	Business	20000.00
0005432902047	31	Business	20000.00
0005432392067	31	Business	20000.00
0005433103377	31	Business	20000.00
0005433103349	31	Business	20000.00
0005433103483	31	Business	20000.00
0005432902021	31	Business	20000.00
0005433103498	31	Business	20000.00
0005433103376	31	Business	20000.00
0005433103460	31	Business	20000.00
0005432392058	31	Business	20000.00
0005433103476	31	Business	20000.00
0005432920392	31	Business	20000.00
0005433103244	31	Business	20000.00
0005433103413	31	Economy	7300.00
0005433103444	31	Economy	7300.00
0005433103375	31	Economy	7300.00
0005432902065	31	Economy	7300.00
0005433103429	31	Economy	7300.00
0005433103401	31	Economy	6700.00
0005433103361	31	Economy	6700.00
0005432902081	31	Economy	6700.00
0005432902064	31	Economy	6700.00
0005433103425	31	Economy	6700.00
0005433103479	31	Economy	6700.00
0005432901980	31	Economy	6700.00
0005433103486	31	Economy	6700.00
0005433103374	31	Economy	6700.00
0005433103329	31	Economy	6700.00
0005432392070	31	Economy	6700.00
0005433103399	31	Economy	6700.00
0005433103388	31	Economy	6700.00
0005432902025	31	Economy	6700.00
0005433103493	31	Economy	6700.00
0005432677667	31	Economy	6700.00
0005433103256	31	Economy	6700.00
0005432902080	31	Economy	6700.00
0005432902045	31	Economy	6700.00
0005433103313	31	Economy	6700.00
0005433103459	31	Economy	6700.00
0005432392065	31	Economy	6700.00
0005432392060	31	Economy	6700.00
0005432392064	31	Economy	6700.00
0005433103463	31	Economy	6700.00
0005432392066	31	Economy	6700.00
0005432392054	31	Economy	6700.00
0005432901981	31	Economy	6700.00
0005433103490	31	Economy	6700.00
0005432902016	31	Economy	6700.00
0005433103457	31	Economy	6700.00
0005433103440	31	Economy	6700.00
0005432920324	31	Economy	6700.00
0005432920322	31	Economy	6700.00
0005432920394	31	Economy	6700.00
0005433103470	31	Economy	6700.00
0005432902079	31	Economy	6700.00
0005432902058	31	Economy	6700.00
0005433103497	31	Economy	6700.00
0005433103418	31	Economy	6700.00
0005433103389	31	Economy	6700.00
0005433103312	31	Economy	7300.00
0005432392061	31	Economy	7300.00
0005433103424	31	Economy	7300.00
0005432677650	31	Economy	7300.00
0005433103398	31	Economy	7300.00
0005433103461	31	Economy	6700.00
0005433103496	31	Economy	6700.00
0005433103489	31	Economy	6700.00
0005432902020	31	Economy	7300.00
0005433103469	31	Economy	6700.00
0005432920323	31	Economy	6700.00
0005432920393	31	Economy	6700.00
0005432392059	31	Economy	6700.00
0005432920305	31	Economy	6700.00
0005432920303	31	Economy	6700.00
0005432902071	31	Economy	6700.00
0005433103412	31	Economy	6700.00
0005432902027	31	Economy	6700.00
0005432902026	31	Economy	6700.00
0005433103491	31	Economy	6700.00
0005433103482	31	Economy	6700.00
0005433103266	31	Economy	6700.00
0005433103477	31	Economy	6700.00
0005432902015	31	Economy	6700.00
0005432920391	31	Economy	6700.00
0005433103221	31	Economy	6700.00
0005432392053	31	Economy	6700.00
0005432902066	31	Economy	6700.00
0005432392062	31	Economy	6700.00
0005432902061	31	Economy	6700.00
0005432920256	31	Economy	6700.00
0005433103462	31	Economy	6700.00
0005432920212	31	Economy	6700.00
0005432677649	31	Economy	6700.00
0005432920339	31	Economy	6700.00
0005433103294	31	Economy	6700.00
0005432920302	31	Economy	6700.00
0005432920351	31	Economy	6700.00
0005433103495	31	Economy	6700.00
0005432920375	31	Economy	6700.00
0005433103481	31	Economy	6700.00
0005432920417	31	Economy	6700.00
0005432392063	31	Economy	6700.00
0005432392052	31	Economy	6700.00
0005433103478	31	Economy	6700.00
0005433103347	31	Economy	6700.00
0005432920211	31	Economy	6700.00
0005432677666	31	Economy	6700.00
0005433103362	31	Economy	6700.00
0005434157940	28	Business	20000.00
0005434157950	28	Business	20000.00
0005434157948	28	Business	20000.00
0005433687757	28	Business	20000.00
0005433477288	28	Business	20000.00
0005432756928	28	Business	20000.00
0005434157924	28	Business	20000.00
0005434153584	28	Business	20000.00
0005435987064	28	Business	20000.00
0005432756921	28	Business	20000.00
0005432756927	28	Business	20000.00
0005433477289	28	Business	20000.00
0005434157934	28	Business	20000.00
0005434157947	28	Business	20000.00
0005434157942	28	Business	20000.00
0005434512261	28	Economy	7300.00
0005434215908	28	Economy	7300.00
0005434215909	28	Economy	7300.00
0005434157922	28	Economy	7300.00
0005434157956	28	Economy	6700.00
0005434157928	28	Economy	6700.00
0005434157939	28	Economy	6700.00
0005434157916	28	Economy	6700.00
0005434157944	28	Economy	6700.00
0005434157932	28	Economy	6700.00
0005434157917	28	Economy	6700.00
0005433690970	28	Economy	6700.00
0005434157933	28	Economy	6700.00
0005432756911	28	Economy	6700.00
0005432753355	28	Economy	6700.00
0005434157931	28	Economy	6700.00
0005434157949	28	Economy	6700.00
0005434157941	28	Economy	6700.00
0005433687755	28	Economy	6700.00
0005432207739	28	Economy	6700.00
0005434157920	28	Economy	6700.00
0005434157954	28	Economy	6700.00
0005432263229	28	Economy	6700.00
0005434157946	28	Economy	6700.00
0005434157926	28	Economy	6700.00
0005434157936	28	Economy	6700.00
0005434175879	28	Economy	6700.00
0005434157935	28	Economy	6700.00
0005432818333	28	Economy	6700.00
0005434215906	28	Economy	6700.00
0005434157943	28	Economy	6700.00
0005434157951	28	Economy	7300.00
0005432207740	28	Economy	7300.00
0005434157923	28	Economy	6700.00
0005434157927	28	Economy	6700.00
0005432818335	28	Economy	7300.00
0005434157945	28	Economy	6700.00
0005434157929	28	Economy	6700.00
0005434157937	28	Economy	6700.00
0005433477290	28	Economy	6700.00
0005434157953	28	Economy	6700.00
0005433477291	28	Economy	6700.00
0005434157918	28	Economy	6700.00
0005434152871	28	Economy	6700.00
0005432756913	28	Economy	6700.00
0005434157921	28	Economy	6700.00
0005434152870	28	Economy	6700.00
0005432207741	28	Economy	6700.00
0005434175878	28	Economy	6700.00
0005434215905	28	Economy	6700.00
0005432263227	28	Economy	6700.00
0005432263230	28	Economy	6700.00
0005434157930	28	Economy	6700.00
0005433690971	28	Economy	6700.00
0005432818334	28	Economy	6700.00
0005434512260	28	Economy	6700.00
0005434157919	28	Economy	6700.00
0005434157925	28	Economy	6700.00
0005434175880	28	Economy	6700.00
0005433687756	28	Economy	6700.00
0005434215907	28	Economy	6700.00
0005433690977	28	Economy	6700.00
0005434157938	28	Economy	6700.00
0005434157952	28	Economy	6700.00
0005434157955	28	Economy	6700.00
0005432263228	28	Economy	6700.00
0005433103973	8106	Business	20000.00
0005433477082	8106	Business	20000.00
0005433103956	8106	Business	20000.00
0005432021046	8106	Business	20000.00
0005434152861	8106	Business	20000.00
0005433103966	8106	Business	20000.00
0005433103977	8106	Business	20000.00
0005433477099	8106	Business	20000.00
0005433476999	8106	Business	20000.00
0005433477178	8106	Business	20000.00
0005433477242	8106	Business	20000.00
0005433103952	8106	Business	20000.00
0005433103967	8106	Business	20000.00
0005433477087	8106	Business	20000.00
0005433103975	8106	Business	20000.00
0005433103968	8106	Business	20000.00
0005433103953	8106	Economy	7300.00
0005433103946	8106	Economy	7300.00
0005433103982	8106	Economy	6700.00
0005433103963	8106	Economy	6700.00
0005433103965	8106	Economy	6700.00
0005433477064	8106	Economy	6700.00
0005433103969	8106	Economy	6700.00
0005433103945	8106	Economy	6700.00
0005433477193	8106	Economy	6700.00
0005434151801	8106	Economy	6700.00
0005433477102	8106	Economy	6700.00
0005432021048	8106	Economy	6700.00
0005433103984	8106	Economy	6700.00
0005433477000	8106	Economy	6700.00
0005433929894	8106	Economy	6700.00
0005433477023	8106	Economy	6700.00
0005433103951	8106	Economy	6700.00
0005433103986	8106	Economy	6700.00
0005433103960	8106	Economy	6700.00
0005433103948	8106	Economy	6700.00
0005433103964	8106	Economy	6700.00
0005433477022	8106	Economy	6700.00
0005433435530	8106	Economy	6700.00
0005433103950	8106	Economy	6700.00
0005433477081	8106	Economy	6700.00
0005433477097	8106	Economy	6700.00
0005433103985	8106	Economy	6700.00
0005433103974	8106	Economy	6700.00
0005433477157	8106	Economy	6700.00
0005433477159	8106	Economy	6700.00
0005433477115	8106	Economy	6700.00
0005433103947	8106	Economy	6700.00
0005432021045	8106	Economy	6700.00
0005432021047	8106	Economy	6700.00
0005433477096	8106	Economy	6700.00
0005433103979	8106	Economy	6700.00
0005433103961	8106	Economy	7300.00
0005433929895	8106	Economy	7300.00
0005433477047	8106	Economy	6700.00
0005434151798	8106	Economy	7300.00
0005433103962	8106	Economy	6700.00
0005433103980	8106	Economy	6700.00
0005434151797	8106	Economy	6700.00
0005433103957	8106	Economy	6700.00
0005433929896	8106	Economy	6700.00
0005432920479	8106	Economy	6700.00
0005432920477	8106	Economy	6700.00
0005434151800	8106	Economy	6700.00
0005433477014	8106	Economy	6700.00
0005433477098	8106	Economy	6700.00
0005433477156	8106	Economy	6700.00
0005433103976	8106	Economy	6700.00
0005433103949	8106	Economy	6700.00
0005433477051	8106	Economy	6700.00
0005433477053	8106	Economy	6700.00
0005433103981	8106	Economy	6700.00
0005433477149	8106	Economy	6700.00
0005433477070	8106	Economy	6700.00
0005433103955	8106	Economy	6700.00
0005433103971	8106	Economy	6700.00
0005433103959	8106	Economy	6700.00
0005433103978	8106	Economy	6700.00
0005433103958	8106	Economy	6700.00
0005432021049	8106	Economy	6700.00
0005433477013	8106	Economy	6700.00
0005433103954	8106	Economy	6700.00
0005433477160	8106	Economy	6700.00
0005432021044	8106	Economy	6700.00
0005433476996	8106	Economy	6700.00
0005433103983	8106	Economy	6700.00
0005433103972	8106	Economy	6700.00
0005433103970	8106	Economy	6700.00
0005433477017	8106	Economy	6700.00
0005432920478	8106	Economy	6700.00
0005433477177	8106	Economy	6700.00
0005433477026	8106	Economy	6700.00
0005432818140	8107	Business	20000.00
0005434513637	8107	Business	20000.00
0005434513636	8107	Business	20000.00
0005432818254	8107	Business	20000.00
0005432818223	8107	Economy	7300.00
0005432902124	8107	Economy	6700.00
0005432818236	8107	Economy	6700.00
0005432818063	8107	Economy	6700.00
0005432818084	8107	Economy	6700.00
0005432818224	8107	Economy	6700.00
0005432818178	8107	Economy	6700.00
0005434513653	8107	Economy	6700.00
0005434513641	8107	Economy	6700.00
0005432818163	8107	Economy	6700.00
0005432818032	8107	Economy	6700.00
0005432818164	8107	Economy	6700.00
0005434513650	8107	Economy	7300.00
0005434513649	8107	Economy	7300.00
0005434513647	8107	Economy	6700.00
0005432818222	8107	Economy	6700.00
0005432818165	8107	Economy	6700.00
0005432818189	8107	Economy	6700.00
0005432818062	8107	Economy	6700.00
0005432818255	8107	Economy	6700.00
0005434513643	8107	Economy	6700.00
0005432818202	8107	Economy	6700.00
0005434513648	8107	Economy	6700.00
0005432818319	8107	Economy	6700.00
0005432818141	8107	Economy	6700.00
0005432818209	8107	Economy	6700.00
0005432818158	8107	Economy	6700.00
0005432818103	8107	Economy	6700.00
0005434513642	8107	Economy	6700.00
0005432818121	8107	Economy	6700.00
0005432818148	8107	Economy	6700.00
0005432818186	8107	Economy	6700.00
0005432818279	8107	Economy	6700.00
0005432818320	8107	Economy	6700.00
0005432818188	8107	Economy	6700.00
0005432818122	8107	Economy	6700.00
0005434175866	9675	Economy	6900.00
0005434175834	9675	Economy	6900.00
0005434175851	9675	Economy	6900.00
0005433870777	32318	Economy	6900.00
0005433870779	32318	Economy	6900.00
0005433870785	32318	Economy	6900.00
0005433870778	32318	Economy	6900.00
0005434880984	3465	Business	35000.00
0005435903117	3465	Business	35000.00
0005434880980	3465	Business	35000.00
0005432188702	3465	Business	35000.00
0005435626859	3465	Business	35000.00
0005435127579	3465	Business	35000.00
0005435903139	3465	Comfort	19900.00
0005435914084	3465	Comfort	19900.00
0005435914070	3465	Comfort	19900.00
0005435914087	3465	Comfort	19900.00
0005435914093	3465	Comfort	19900.00
0005435903148	3465	Comfort	19900.00
0005435626860	3465	Comfort	19900.00
0005435914090	3465	Comfort	19900.00
0005435914111	3465	Comfort	19900.00
0005435127583	3465	Comfort	19900.00
0005434880985	3465	Comfort	19900.00
0005435914042	3465	Comfort	19900.00
0005435626858	3465	Comfort	19900.00
0005435914168	3465	Comfort	19900.00
0005435914089	3465	Comfort	19900.00
0005434427466	3465	Comfort	19900.00
0005435903115	3465	Economy	11700.00
0005435914734	3465	Economy	11700.00
0005435914057	3465	Economy	11700.00
0005435127584	3465	Economy	11700.00
0005435903165	3465	Economy	11700.00
0005434427471	3465	Economy	11700.00
0005435914092	3465	Economy	11700.00
0005434427470	3465	Economy	11700.00
0005435914071	3465	Economy	11700.00
0005435127577	3465	Economy	11700.00
0005435914122	3465	Economy	11700.00
0005434427465	3465	Economy	11700.00
0005434427467	3465	Economy	11700.00
0005434938720	3465	Economy	11700.00
0005432800284	3465	Economy	12800.00
0005435914038	3465	Economy	11700.00
0005435914045	3465	Economy	11700.00
0005432188701	3465	Economy	11700.00
0005435841113	3465	Economy	11700.00
0005434427469	3465	Economy	11700.00
0005434880983	3465	Economy	11700.00
0005435914073	3465	Economy	11700.00
0005435903102	3465	Economy	11700.00
0005434427468	3465	Economy	11700.00
0005435914747	3465	Economy	11700.00
0005434427464	3465	Economy	11700.00
0005434880979	3465	Economy	11700.00
0005435903099	3465	Economy	11700.00
0005435903107	3465	Economy	11700.00
0005435914123	3465	Economy	11700.00
0005434880981	3465	Economy	11700.00
0005435914085	3465	Economy	11700.00
0005435841838	3465	Economy	11700.00
0005435903090	3465	Economy	11700.00
0005435626861	3465	Economy	11700.00
0005435914136	3465	Economy	11700.00
0005432800285	3465	Economy	11700.00
0005435127580	3465	Economy	12800.00
0005435914110	3465	Economy	11700.00
0005435127578	3465	Economy	11700.00
0005435127581	3465	Economy	11700.00
0005435127582	3465	Economy	11700.00
0005435914029	3465	Economy	11700.00
0005435914081	3465	Economy	11700.00
0005435903111	3465	Economy	11700.00
0005435903112	3465	Economy	11700.00
0005435914037	3465	Economy	11700.00
0005435626857	3465	Economy	11700.00
0005435914731	3465	Economy	11700.00
0005435914109	3465	Economy	11700.00
0005434880982	3465	Economy	11700.00
0005434938719	3465	Economy	11700.00
0005435914129	3465	Economy	11700.00
0005435914086	3465	Economy	11700.00
0005435626862	3465	Economy	11700.00
0005435903098	3465	Economy	11700.00
0005435914137	3465	Economy	11700.00
0005434427197	14568	Business	35000.00
0005435127462	14568	Business	35000.00
0005435127330	14568	Business	35000.00
0005432800118	14568	Business	35000.00
0005434427238	14568	Business	35000.00
0005435127312	14568	Business	35000.00
0005434938557	14568	Business	35000.00
0005434880277	14568	Business	35000.00
0005434427359	14568	Business	35000.00
0005432800170	14568	Business	35000.00
0005434880473	14568	Business	35000.00
0005434880718	14568	Business	35000.00
0005435914215	14568	Business	35000.00
0005434880819	14568	Business	35000.00
0005434880611	14568	Business	35000.00
0005435626620	14568	Comfort	19900.00
0005434880486	14568	Comfort	19900.00
0005434880070	14568	Comfort	19900.00
0005432800115	14568	Comfort	19900.00
0005435127285	14568	Comfort	19900.00
0005434427341	14568	Comfort	19900.00
0005434880350	14568	Comfort	19900.00
0005435127387	14568	Comfort	19900.00
0005435127280	14568	Comfort	19900.00
0005435626630	14568	Comfort	19900.00
0005435127379	14568	Comfort	19900.00
0005434880333	14568	Comfort	19900.00
0005432800203	14568	Comfort	19900.00
0005434879779	14568	Comfort	19900.00
0005434427364	14568	Comfort	19900.00
0005435626603	14568	Comfort	19900.00
0005432800120	14568	Comfort	19900.00
0005434880672	14568	Comfort	19900.00
0005434880378	14568	Comfort	19900.00
0005432800135	14568	Comfort	19900.00
0005434880148	14568	Comfort	19900.00
0005434880130	14568	Comfort	19900.00
0005434879965	14568	Comfort	19900.00
0005434938614	14568	Comfort	19900.00
0005434427395	14568	Comfort	19900.00
0005435626536	14568	Comfort	19900.00
0005434427342	14568	Comfort	19900.00
0005434427369	14568	Comfort	19900.00
0005434427363	14568	Economy	11700.00
0005432800169	14568	Economy	11700.00
0005434880748	14568	Economy	11700.00
0005435626601	14568	Economy	11700.00
0005434880535	14568	Economy	11700.00
0005434880497	14568	Economy	11700.00
0005434427239	14568	Economy	11700.00
0005434938667	14568	Economy	11700.00
0005435626633	14568	Economy	11700.00
0005434880131	14568	Economy	11700.00
0005434427325	14568	Economy	11700.00
0005432800137	14568	Economy	11700.00
0005434880717	14568	Economy	11700.00
0005435626569	14568	Economy	11700.00
0005434427264	14568	Economy	11700.00
0005434879780	14568	Economy	11700.00
0005432800130	14568	Economy	11700.00
0005432800002	14568	Economy	11700.00
0005434880656	14568	Economy	11700.00
0005432800068	14568	Economy	11700.00
0005434427244	14568	Economy	11700.00
0005435626560	14568	Economy	11700.00
0005434880210	14568	Economy	11700.00
0005434427360	14568	Economy	11700.00
0005435127122	14568	Economy	11700.00
0005435127286	14568	Economy	11700.00
0005432607655	14568	Economy	11700.00
0005434880253	14568	Economy	11700.00
0005432800136	14568	Economy	11700.00
0005434938558	14568	Economy	11700.00
0005434880483	14568	Economy	11700.00
0005434938677	14568	Economy	11700.00
0005432800121	14568	Economy	11700.00
0005434880084	14568	Economy	11700.00
0005435127123	14568	Economy	11700.00
0005435626596	14568	Economy	11700.00
0005434427265	14568	Economy	11700.00
0005434427294	14568	Economy	11700.00
0005435626578	14568	Economy	11700.00
0005432800177	14568	Economy	11700.00
0005435903220	14568	Economy	11700.00
0005435127465	14568	Economy	11700.00
0005432800172	14568	Economy	11700.00
0005434880484	14568	Economy	11700.00
0005435626577	14568	Economy	11700.00
0005434880547	14568	Economy	11700.00
0005434938622	14568	Economy	11700.00
0005434880334	14568	Economy	11700.00
0005434880018	14568	Economy	12800.00
0005435127262	14568	Economy	11700.00
0005435127313	14568	Economy	11700.00
0005434880680	14568	Economy	11700.00
0005434880158	14568	Economy	12800.00
0005434427312	14568	Economy	12800.00
0005435127320	14568	Economy	11700.00
0005435626561	14568	Economy	12800.00
0005434880631	14568	Economy	11700.00
0005435127214	14568	Economy	11700.00
0005434427336	14568	Economy	11700.00
0005432800131	14568	Economy	11700.00
0005434880511	14568	Economy	11700.00
0005432607649	14568	Economy	11700.00
0005434427361	14568	Economy	11700.00
0005435127357	14568	Economy	11700.00
0005434427283	14568	Economy	11700.00
0005434880612	14568	Economy	11700.00
0005434938601	14568	Economy	11700.00
0005434938538	14568	Economy	11700.00
0005435127388	14568	Economy	11700.00
0005434879955	14568	Economy	11700.00
0005434880338	14568	Economy	11700.00
0005434880502	14568	Economy	11700.00
0005434879964	14568	Economy	11700.00
0005434880742	14568	Economy	11700.00
0005435127288	14568	Economy	11700.00
0005435127287	14568	Economy	11700.00
0005434938586	14568	Economy	11700.00
0005434880762	14568	Economy	11700.00
0005432800054	14568	Economy	11700.00
0005434427242	14568	Economy	11700.00
0005434938555	14568	Economy	11700.00
0005434880572	14568	Economy	11700.00
0005432611793	14568	Economy	11700.00
0005435127356	14568	Economy	11700.00
0005435127364	14568	Economy	11700.00
0005434880707	14568	Economy	11700.00
0005434938611	14568	Economy	11700.00
0005434880614	14568	Economy	11700.00
0005434427299	14568	Economy	11700.00
0005434880570	14568	Economy	11700.00
0005435626610	14568	Economy	11700.00
0005435626631	14568	Economy	11700.00
0005435626611	14568	Economy	11700.00
0005434938549	14568	Economy	11700.00
0005434880617	14568	Economy	11700.00
0005434880599	14568	Economy	11700.00
0005435127321	14568	Economy	11700.00
0005432607646	14568	Economy	11700.00
0005434938587	14568	Economy	11700.00
0005434427362	14568	Economy	11700.00
0005434880252	14568	Economy	11700.00
0005434880319	14568	Economy	11700.00
0005434880251	14568	Economy	11700.00
0005432800159	14568	Economy	11700.00
0005434938678	14568	Economy	11700.00
0005432607648	14568	Economy	11700.00
0005435127131	14568	Economy	11700.00
0005434938621	14568	Economy	11700.00
0005434880503	14568	Economy	11700.00
0005434427400	14568	Economy	11700.00
0005434427313	14568	Economy	11700.00
0005434880440	14568	Economy	11700.00
0005434427340	14568	Economy	11700.00
0005434880909	14568	Economy	11700.00
0005435127274	14568	Economy	11700.00
0005435127464	14568	Economy	11700.00
0005434880398	14568	Economy	11700.00
0005434880528	14568	Economy	11700.00
0005434880655	14568	Economy	11700.00
0005434880471	14568	Economy	11700.00
0005432800053	14568	Economy	11700.00
0005434880657	14568	Economy	11700.00
0005434880485	14568	Economy	11700.00
0005434880332	14568	Economy	11700.00
0005434427229	14568	Economy	11700.00
0005435914212	14568	Economy	11700.00
0005435626582	14568	Economy	11700.00
0005435626579	14568	Economy	11700.00
0005435914213	14568	Economy	11700.00
0005434427354	14568	Economy	11700.00
0005434880472	14568	Economy	11700.00
0005434880524	14568	Economy	11700.00
0005435127328	14568	Economy	11700.00
0005432607656	14568	Economy	12800.00
0005434880417	14568	Economy	12800.00
0005434880291	14568	Economy	12800.00
0005434880555	14568	Economy	12800.00
0005434880351	14568	Economy	12800.00
0005434880554	14568	Economy	11700.00
0005434880613	14568	Economy	11700.00
0005434427355	14568	Economy	11700.00
0005434880390	14568	Economy	11700.00
0005432800125	14568	Economy	11700.00
0005432800176	14568	Economy	11700.00
0005434938612	14568	Economy	11700.00
0005432800171	14568	Economy	11700.00
0005434880747	14568	Economy	11700.00
0005435127271	14568	Economy	11700.00
0005434938539	14568	Economy	11700.00
0005435626529	14568	Economy	11700.00
0005434880337	14568	Economy	11700.00
0005434880507	14568	Economy	11700.00
0005435127132	14568	Economy	11700.00
0005432800116	14568	Economy	11700.00
0005434427377	14568	Economy	11700.00
0005434938591	14568	Economy	11700.00
0005435626581	14568	Economy	11700.00
0005434427230	14568	Economy	11700.00
0005435127489	14568	Economy	11700.00
0005434427353	14568	Economy	11700.00
0005434938668	14568	Economy	11700.00
0005435626547	14568	Economy	11700.00
0005435127322	14568	Economy	11700.00
0005435914214	14568	Economy	11700.00
0005434880335	14568	Economy	11700.00
0005435914211	14568	Economy	11700.00
0005434427278	14568	Economy	11700.00
0005435127016	14568	Economy	11700.00
0005435127366	14568	Economy	11700.00
0005434880594	14568	Economy	11700.00
0005434880336	14568	Economy	11700.00
0005435626622	14568	Economy	11700.00
0005434880424	14568	Economy	11700.00
0005434880474	14568	Economy	11700.00
0005434880679	14568	Economy	11700.00
0005434938559	14568	Economy	11700.00
0005434427228	14568	Economy	11700.00
0005434880658	14568	Economy	11700.00
0005434880709	14568	Economy	11700.00
0005435626586	14568	Economy	11700.00
0005435127215	14568	Economy	11700.00
0005435127351	14568	Economy	11700.00
0005435626570	14568	Economy	11700.00
0005432611802	14568	Economy	11700.00
0005434880372	14568	Economy	11700.00
0005432611777	14568	Economy	11700.00
0005434880409	14568	Economy	11700.00
0005435127158	14568	Economy	11700.00
0005434427352	14568	Economy	11700.00
0005434880910	14568	Economy	11700.00
0005432800129	14568	Economy	11700.00
0005434880393	14568	Economy	11700.00
0005434938613	14568	Economy	11700.00
0005434880274	14568	Economy	11700.00
0005435127378	14568	Economy	11700.00
0005434427243	14568	Economy	11700.00
0005434880666	14568	Economy	11700.00
0005435127327	14568	Economy	11700.00
0005434880531	14568	Economy	11700.00
0005435626492	14568	Economy	11700.00
0005434880331	14568	Economy	11700.00
0005434427343	14568	Economy	11700.00
0005432800119	14568	Economy	11700.00
0005434880593	14568	Economy	11700.00
0005435903221	14568	Economy	11700.00
0005434312385	3624	Economy	14800.00
0005435890045	3624	Economy	14800.00
0005435890050	3624	Economy	14800.00
0005435890028	3624	Economy	14800.00
0005435890027	3624	Economy	14800.00
0005434325920	15595	Economy	16300.00
0005434325914	15595	Economy	14800.00
0005434325954	15595	Economy	14800.00
0005434325947	15595	Economy	14800.00
0005434325924	15595	Economy	14800.00
0005434325915	15595	Economy	14800.00
0005434325946	15595	Economy	14800.00
0005434311286	15595	Economy	14800.00
0005434325896	15595	Economy	14800.00
0005434325916	15595	Economy	14800.00
0005433420623	657	Economy	4100.00
0005433420609	657	Economy	4100.00
0005433420637	657	Economy	4100.00
0005433420626	657	Economy	4100.00
0005433420598	657	Economy	4100.00
0005433420562	657	Economy	4100.00
0005433420597	657	Economy	4100.00
0005435958083	15193	Economy	4100.00
0005435958079	15193	Economy	4100.00
0005433420649	15193	Economy	4100.00
0005435216635	27255	Economy	28100.00
0005435216634	27255	Economy	28100.00
0005435221077	27255	Economy	25500.00
0005435216632	27255	Economy	25500.00
0005435219244	27255	Economy	25500.00
0005435221076	27255	Economy	25500.00
0005435219249	27255	Economy	25500.00
0005435219250	27255	Economy	25500.00
0005435216633	27255	Economy	25500.00
0005435216631	27255	Economy	25500.00
0005435216627	27255	Economy	25500.00
0005435217775	31774	Economy	25500.00
0005435217774	31774	Economy	25500.00
0005435216655	31774	Economy	25500.00
0005435216654	31774	Economy	25500.00
0005435218146	31774	Economy	25500.00
0005435216653	31774	Economy	25500.00
0005434247203	8929	Economy	10400.00
0005434247211	8929	Economy	10400.00
0005434247202	8929	Economy	10400.00
0005435629446	8929	Economy	10400.00
0005435629448	8929	Economy	10400.00
0005435629447	8929	Economy	10400.00
0005434247212	8929	Economy	10400.00
0005435629452	8930	Economy	10400.00
0005434467829	4005	Economy	21200.00
0005434467818	23215	Economy	23400.00
0005434467823	23215	Economy	23400.00
0005434467811	23215	Economy	21200.00
0005434467819	23215	Economy	21200.00
0005434467809	23215	Economy	21200.00
0005434467821	23215	Economy	21200.00
0005434467812	23215	Economy	21200.00
0005434467822	23215	Economy	21200.00
0005434467805	23215	Economy	21200.00
0005434467820	23215	Economy	21200.00
0005435933535	4422	Economy	13400.00
0005435933546	4422	Economy	13400.00
0005435933547	4422	Economy	13400.00
0005435933529	4422	Economy	12200.00
0005435933531	4422	Economy	12200.00
0005435933534	4422	Economy	12200.00
0005435163386	4422	Economy	12200.00
0005435163385	4422	Economy	12200.00
0005435933541	4422	Economy	12200.00
0005435933545	4422	Economy	12200.00
0005435933533	4422	Economy	12200.00
0005435163384	4422	Economy	12200.00
0005435933540	4422	Economy	12200.00
0005435933536	4422	Economy	12200.00
0005435163387	4422	Economy	12200.00
0005435933523	4422	Economy	12200.00
0005435933542	4422	Economy	12200.00
0005435933537	4422	Economy	12200.00
0005435163358	29514	Economy	13400.00
0005435163324	29514	Economy	12200.00
0005435163323	29514	Economy	12200.00
0005435163341	29514	Economy	12200.00
0005435163357	29514	Economy	12200.00
0005435163335	29514	Economy	12200.00
0005435163343	29514	Economy	12200.00
0005435163366	29514	Economy	12200.00
0005435163350	29514	Economy	12200.00
0005435163360	29514	Economy	12200.00
0005435163361	29514	Economy	12200.00
0005435163349	29514	Economy	12200.00
0005435163348	29514	Economy	12200.00
0005435163342	29514	Economy	12200.00
0005435229591	6835	Business	87700.00
0005435229582	6835	Business	87700.00
0005432646371	6835	Business	87700.00
0005435229605	6835	Economy	29200.00
0005432646367	6835	Economy	29200.00
0005435229607	6835	Economy	29200.00
0005435229606	6835	Economy	29200.00
0005432646368	6835	Economy	32200.00
0005435229601	6835	Economy	32200.00
0005432646374	6835	Economy	32200.00
0005435229603	6835	Economy	32200.00
0005435229592	6835	Economy	29200.00
0005435229566	6835	Economy	29200.00
0005435229581	6835	Economy	29200.00
0005432646377	6835	Economy	29200.00
0005435229565	6835	Economy	29200.00
0005435229590	6835	Economy	29200.00
0005435229602	6835	Economy	29200.00
0005435229558	6835	Economy	29200.00
0005432646372	6835	Economy	29200.00
0005435229525	6835	Economy	29200.00
0005435229596	6835	Economy	29200.00
0005435229600	6835	Economy	29200.00
0005435229595	6835	Economy	29200.00
0005435229597	6835	Economy	29200.00
0005432646370	6835	Economy	29200.00
0005432646375	6835	Economy	29200.00
0005432646376	6835	Economy	29200.00
0005435229559	6835	Economy	29200.00
0005435229576	6835	Economy	29200.00
0005435229564	6835	Economy	29200.00
0005435229604	6835	Economy	29200.00
0005432646369	6835	Economy	29200.00
0005432646373	6835	Economy	29200.00
0005435229575	6835	Economy	29200.00
0005432646366	6835	Economy	29200.00
0005435229524	6835	Economy	29200.00
0005435229573	6835	Economy	29200.00
0005435229569	6835	Economy	29200.00
0005435229544	6835	Economy	29200.00
0005433404977	2826	Business	12600.00
0005433404952	2826	Economy	4200.00
0005433404976	2826	Economy	4200.00
0005433404975	2826	Economy	4200.00
0005433405029	2826	Economy	4200.00
0005435797896	2826	Economy	4200.00
0005433405004	2826	Economy	4200.00
0005433404978	2826	Economy	4200.00
0005433405003	2826	Economy	4200.00
0005435797889	29316	Business	12600.00
0005435797888	29316	Business	12600.00
0005435797833	29316	Economy	4200.00
0005435797792	29316	Economy	4200.00
0005435797817	29316	Economy	4200.00
0005435797856	29316	Economy	4200.00
0005435797805	29316	Economy	4200.00
0005435797844	29316	Economy	4200.00
0005435797832	29316	Economy	4200.00
0005435797775	29316	Economy	4200.00
0005435797851	29316	Economy	4200.00
0005435797815	29316	Economy	4200.00
0005435797793	29316	Economy	4200.00
0005435797766	29316	Economy	4200.00
0005435797791	29316	Economy	4200.00
0005435797799	29316	Economy	4200.00
0005435797774	29316	Economy	4200.00
0005435797859	29316	Economy	4200.00
0005435797845	29316	Economy	4200.00
0005435797858	29316	Economy	4200.00
0005435797804	29316	Economy	4200.00
0005435376417	5734	Economy	6800.00
0005435376422	5734	Economy	6800.00
0005434948265	5797	Economy	6800.00
0005435376432	16339	Economy	6800.00
0005434948210	16339	Economy	6800.00
0005434948231	16339	Economy	6800.00
0005434948255	16339	Economy	6800.00
0005434948254	16339	Economy	6800.00
0005434948220	16339	Economy	6800.00
0005434948211	16339	Economy	6800.00
0005434948248	16339	Economy	6800.00
0005434948236	16339	Economy	6800.00
0005434948232	16339	Economy	6800.00
0005433962746	6957	Business	21400.00
0005433962742	6957	Business	21400.00
0005433962735	6957	Business	21400.00
0005433962736	6957	Economy	7100.00
0005433962744	6957	Economy	7100.00
0005433962749	6957	Economy	7100.00
0005433962738	6957	Economy	7100.00
0005433962747	6957	Economy	7100.00
0005433962745	6957	Economy	7100.00
0005433962731	6957	Economy	7100.00
0005433962733	6957	Economy	7100.00
0005433962748	6957	Economy	7100.00
0005433962737	6957	Economy	7100.00
0005433962750	6957	Economy	7100.00
0005433962732	6957	Economy	7100.00
0005433962743	6957	Economy	7100.00
0005433962739	6957	Economy	7100.00
0005433962740	6957	Economy	7100.00
0005433962751	6957	Economy	7100.00
0005433962734	6957	Economy	7100.00
0005433962741	6957	Economy	7100.00
0005433962042	25745	Business	21400.00
0005433962077	25745	Business	21400.00
0005433962166	25745	Business	21400.00
0005433962062	25745	Business	21400.00
0005433962053	25745	Business	21400.00
0005433961940	25745	Economy	7100.00
0005433961944	25745	Economy	7100.00
0005433961999	25745	Economy	7100.00
0005433962087	25745	Economy	7100.00
0005433962063	25745	Economy	7100.00
0005433962147	25745	Economy	7100.00
0005433962142	25745	Economy	7100.00
0005433961951	25745	Economy	7800.00
0005433962134	25745	Economy	7800.00
0005433962101	25745	Economy	7100.00
0005433962129	25745	Economy	7100.00
0005433962078	25745	Economy	7100.00
0005433962100	25745	Economy	7100.00
0005433962119	25745	Economy	7100.00
0005433962151	25745	Economy	7100.00
0005433962011	25745	Economy	7100.00
0005433962137	25745	Economy	7100.00
0005433962030	25745	Economy	7100.00
0005433961976	25745	Economy	7100.00
0005433961966	25745	Economy	7100.00
0005433962165	25745	Economy	7100.00
0005433962121	25745	Economy	7100.00
0005433962079	25745	Economy	7100.00
0005433962146	25745	Economy	7100.00
0005433961939	25745	Economy	7100.00
0005433962024	25745	Economy	7100.00
0005433961903	25745	Economy	7100.00
0005433962122	25745	Economy	7100.00
0005433961928	25745	Economy	7100.00
0005433962098	25745	Economy	7100.00
0005433961927	25745	Economy	7100.00
0005433962123	25745	Economy	7100.00
0005433962025	25745	Economy	7100.00
0005433961800	25745	Economy	7100.00
0005433962064	25745	Economy	7100.00
0005433962152	25745	Economy	7100.00
0005433962021	25745	Economy	7100.00
0005433962136	25745	Economy	7100.00
0005433961947	25745	Economy	7100.00
0005433962049	25745	Economy	7100.00
0005433961997	25745	Economy	7100.00
0005433962128	25745	Economy	7100.00
0005433961990	25745	Economy	7100.00
0005433962118	25745	Economy	7100.00
0005433962081	25745	Economy	7100.00
0005435082953	24454	Economy	3900.00
0005435082995	24454	Economy	3900.00
0005435082954	24454	Economy	3900.00
0005435082960	24454	Economy	3900.00
0005435082975	24454	Economy	3900.00
0005435082959	24454	Economy	3900.00
0005435082963	24454	Economy	3900.00
0005435082964	24454	Economy	3900.00
0005435083034	26073	Economy	3900.00
0005435083032	26073	Economy	3900.00
0005435083033	26073	Economy	3900.00
0005434245843	4943	Business	18000.00
0005434245845	4943	Business	18000.00
0005433534553	4943	Business	18000.00
0005435286761	4943	Business	18000.00
0005435286755	4943	Business	18000.00
0005434245844	4943	Economy	6600.00
0005435286778	4943	Economy	6000.00
0005435286780	4943	Economy	6000.00
0005435286752	4943	Economy	6000.00
0005435286800	4943	Economy	6000.00
0005435286781	4943	Economy	6000.00
0005435286777	4943	Economy	6000.00
0005435286756	4943	Economy	6000.00
0005433534555	4943	Economy	6000.00
0005435286774	4943	Economy	6000.00
0005434230241	4944	Business	18000.00
0005434230218	4944	Business	18000.00
0005433786188	4944	Business	18000.00
0005433786191	4944	Business	18000.00
0005434230246	4944	Business	18000.00
0005433616821	4944	Business	18000.00
0005433616824	4944	Business	18000.00
0005434230245	4944	Business	18000.00
0005433616827	4944	Business	18000.00
0005434230225	4944	Economy	6600.00
0005434230238	4944	Economy	6000.00
0005434230211	4944	Economy	6000.00
0005434230251	4944	Economy	6000.00
0005434230215	4944	Economy	6000.00
0005434230216	4944	Economy	6000.00
0005434230247	4944	Economy	6000.00
0005434230217	4944	Economy	6000.00
0005434230243	4944	Economy	6000.00
0005434230219	4944	Economy	6000.00
0005434230213	4944	Economy	6000.00
0005434230242	4944	Economy	6000.00
0005433786189	4944	Economy	6000.00
0005434230236	4944	Economy	6000.00
0005434230227	4944	Economy	6000.00
0005434230229	4944	Economy	6000.00
0005434230226	4944	Economy	6000.00
0005434230240	4944	Economy	6000.00
0005434230221	4944	Economy	6000.00
0005433616822	4944	Economy	6000.00
0005433786185	4944	Economy	6000.00
0005434230232	4944	Economy	6000.00
0005433786187	4944	Economy	6000.00
0005434230250	4944	Economy	6000.00
0005434230231	4944	Economy	6000.00
0005434230212	4944	Economy	6000.00
0005434230224	4944	Economy	6600.00
0005434230234	4944	Economy	6600.00
0005434230222	4944	Economy	6000.00
0005434230233	4944	Economy	6000.00
0005433786190	4944	Economy	6000.00
0005434230214	4944	Economy	6000.00
0005434230249	4944	Economy	6000.00
0005434230235	4944	Economy	6000.00
0005433616825	4944	Economy	6000.00
0005434230223	4944	Economy	6000.00
0005433616823	4944	Economy	6000.00
0005434230228	4944	Economy	6000.00
0005434230239	4944	Economy	6000.00
0005433786186	4944	Economy	6000.00
0005434230237	4944	Economy	6000.00
0005434230230	4944	Economy	6000.00
0005433616826	4944	Economy	6000.00
0005435629449	4944	Economy	6000.00
0005434230220	4944	Economy	6000.00
0005434230244	4944	Economy	6000.00
0005434230248	4944	Economy	6000.00
0005434311270	4946	Business	18000.00
0005432336341	4946	Business	18000.00
0005433815497	4946	Business	18000.00
0005435270001	4946	Business	18000.00
0005435270031	4946	Business	18000.00
0005435007550	4946	Business	18000.00
0005434312367	4946	Business	18000.00
0005435270030	4946	Business	18000.00
0005435007537	4946	Business	18000.00
0005432336299	4946	Business	18000.00
0005434150079	4946	Business	18000.00
0005434311268	4946	Business	18000.00
0005435270109	4946	Business	18000.00
0005435270142	4946	Business	18000.00
0005435270095	4946	Economy	6600.00
0005435270149	4946	Economy	6600.00
0005435007669	4946	Economy	6600.00
0005435007544	4946	Economy	6000.00
0005433815512	4946	Economy	6000.00
0005432336313	4946	Economy	6000.00
0005434265897	4946	Economy	6000.00
0005434311269	4946	Economy	6000.00
0005435270148	4946	Economy	6000.00
0005435269997	4946	Economy	6000.00
0005435007589	4946	Economy	6000.00
0005435270076	4946	Economy	6000.00
0005433815498	4946	Economy	6000.00
0005435270101	4946	Economy	6000.00
0005435270066	4946	Economy	6000.00
0005435007558	4946	Economy	6000.00
0005435269886	4946	Economy	6000.00
0005433815486	4946	Economy	6000.00
0005433815496	4946	Economy	6000.00
0005435269975	4946	Economy	6000.00
0005435270180	4946	Economy	6000.00
0005435270091	4946	Economy	6000.00
0005432336292	4946	Economy	6000.00
0005432336325	4946	Economy	6000.00
0005432336334	4946	Economy	6000.00
0005432336314	4946	Economy	6000.00
0005435007590	4946	Economy	6000.00
0005434312358	4946	Economy	6000.00
0005435269965	4946	Economy	6000.00
0005434230041	4946	Economy	6000.00
0005435270096	4946	Economy	6000.00
0005434312359	4946	Economy	6000.00
0005435270062	4946	Economy	6000.00
0005433815487	4946	Economy	6000.00
0005432336360	4946	Economy	6000.00
0005435007545	4946	Economy	6000.00
0005432336316	4946	Economy	6000.00
0005435007670	4946	Economy	6000.00
0005435007538	4946	Economy	6000.00
0005432336315	4946	Economy	6000.00
0005435269946	4946	Economy	6000.00
0005435007577	4946	Economy	6600.00
0005435007671	4946	Economy	6600.00
0005435007626	4946	Economy	6600.00
0005434265896	4946	Economy	6600.00
0005435270029	4946	Economy	6000.00
0005435007597	4946	Economy	6000.00
0005433815490	4946	Economy	6000.00
0005435007612	4946	Economy	6000.00
0005433685576	4946	Economy	6000.00
0005435270063	4946	Economy	6000.00
0005435269885	4946	Economy	6000.00
0005435007630	4946	Economy	6000.00
0005435270143	4946	Economy	6000.00
0005435270160	4946	Economy	6000.00
0005434230039	4946	Economy	6000.00
0005435007631	4946	Economy	6000.00
0005434230040	4946	Economy	6000.00
0005435007604	4946	Economy	6000.00
0005434265895	4946	Economy	6000.00
0005435007606	4946	Economy	6000.00
0005435270114	4946	Economy	6000.00
0005435270067	4946	Economy	6000.00
0005433688856	4946	Economy	6000.00
0005435269972	4946	Economy	6000.00
0005435007536	4946	Economy	6000.00
0005435270181	4946	Economy	6000.00
0005435007627	4946	Economy	6000.00
0005434150080	4946	Economy	6000.00
0005435270115	4946	Economy	6000.00
0005435007635	4946	Economy	6000.00
0005435269987	4946	Economy	6000.00
0005434265894	4946	Economy	6000.00
0005432336296	4946	Economy	6000.00
0005435007646	4946	Economy	6000.00
0005433685575	4946	Economy	6000.00
0005433785919	8547	Business	18000.00
0005433785720	8547	Business	18000.00
0005434245643	8547	Business	18000.00
0005434245718	8547	Business	18000.00
0005433786007	8547	Business	18000.00
0005433785697	8547	Business	18000.00
0005433785894	8547	Business	18000.00
0005433785905	8547	Business	18000.00
0005433785840	8547	Business	18000.00
0005434245801	8547	Business	18000.00
0005434245600	8547	Business	18000.00
0005432666443	8547	Business	18000.00
0005433785923	8547	Business	18000.00
0005433785961	8547	Business	18000.00
0005434245630	8547	Business	18000.00
0005434245683	8547	Economy	6600.00
0005434245698	8547	Economy	6600.00
0005433785921	8547	Economy	6600.00
0005433785719	8547	Economy	6000.00
0005432659751	8547	Economy	6000.00
0005434245699	8547	Economy	6000.00
0005433785837	8547	Economy	6000.00
0005433785962	8547	Economy	6000.00
0005433785892	8547	Economy	6000.00
0005433786008	8547	Economy	6000.00
0005433785909	8547	Economy	6000.00
0005432659752	8547	Economy	6000.00
0005433785920	8547	Economy	6000.00
0005433785864	8547	Economy	6000.00
0005433785953	8547	Economy	6000.00
0005433785897	8547	Economy	6000.00
0005433785896	8547	Economy	6000.00
0005433785835	8547	Economy	6000.00
0005435270221	8547	Economy	6000.00
0005433785731	8547	Economy	6000.00
0005433785775	8547	Economy	6000.00
0005433785829	8547	Economy	6000.00
0005434245833	8547	Economy	6000.00
0005432663077	8547	Economy	6000.00
0005433785621	8547	Economy	6000.00
0005433785922	8547	Economy	6000.00
0005433785927	8547	Economy	6000.00
0005433785791	8547	Economy	6000.00
0005433785954	8547	Economy	6000.00
0005433785869	8547	Economy	6000.00
0005433785787	8547	Economy	6000.00
0005434245802	8547	Economy	6000.00
0005432663078	8547	Economy	6000.00
0005433785841	8547	Economy	6000.00
0005433785963	8547	Economy	6600.00
0005434245619	8547	Economy	6600.00
0005433785943	8547	Economy	6000.00
0005434245655	8547	Economy	6600.00
0005433785812	8547	Economy	6000.00
0005434245647	8547	Economy	6000.00
0005433786022	8547	Economy	6000.00
0005433785792	8547	Economy	6000.00
0005433785893	8547	Economy	6000.00
0005432666434	8547	Economy	6000.00
0005433785755	8547	Economy	6000.00
0005433786023	8547	Economy	6000.00
0005435270219	8547	Economy	6000.00
0005433786016	8547	Economy	6000.00
0005433785561	8547	Economy	6000.00
0005434245740	8547	Economy	6000.00
0005434245838	8547	Economy	6000.00
0005433785910	8547	Economy	6000.00
0005433785968	8547	Economy	6000.00
0005433786058	8547	Economy	6000.00
0005435270220	8547	Economy	6000.00
0005433785928	8547	Economy	6000.00
0005433785696	8547	Economy	6000.00
0005434245781	8547	Economy	6000.00
0005433785934	8547	Economy	6000.00
0005433785942	8547	Economy	6000.00
0005433785836	8547	Economy	6000.00
0005434245599	8547	Economy	6000.00
0005433785863	8547	Economy	6000.00
0005433616738	8546	Business	18000.00
0005433616407	8546	Business	18000.00
0005433616168	8546	Business	18000.00
0005433616445	8546	Business	18000.00
0005433616685	8546	Business	18000.00
0005433616391	8546	Business	18000.00
0005433616627	8546	Business	18000.00
0005433616656	8546	Business	18000.00
0005433616489	8546	Business	18000.00
0005433616023	8546	Economy	6600.00
0005433616122	8546	Economy	6600.00
0005433616543	8546	Economy	6000.00
0005433616285	8546	Economy	6000.00
0005433616245	8546	Economy	6000.00
0005433616381	8546	Economy	6000.00
0005433616296	8546	Economy	6000.00
0005433616592	8546	Economy	6000.00
0005433616219	8546	Economy	6000.00
0005433616244	8546	Economy	6000.00
0005433616256	8546	Economy	6000.00
0005433616406	8546	Economy	6000.00
0005433616374	8546	Economy	6000.00
0005433616383	8546	Economy	6000.00
0005433616184	8546	Economy	6000.00
0005433616382	8546	Economy	6000.00
0005433616352	8546	Economy	6000.00
0005433616432	8546	Economy	6000.00
0005433616538	8546	Economy	6000.00
0005433616419	8546	Economy	6000.00
0005433616433	8546	Economy	6000.00
0005433616021	8546	Economy	6000.00
0005433616488	8546	Economy	6000.00
0005433616236	8546	Economy	6000.00
0005433616344	8546	Economy	6000.00
0005433616424	8546	Economy	6000.00
0005433616581	8546	Economy	6600.00
0005433616474	8546	Economy	6600.00
0005433616066	8546	Economy	6600.00
0005433616570	8546	Economy	6600.00
0005433616528	8546	Economy	6000.00
0005433616022	8546	Economy	6000.00
0005433616408	8546	Economy	6000.00
0005433616065	8546	Economy	6000.00
0005433616529	8546	Economy	6000.00
0005433616343	8546	Economy	6000.00
0005433616380	8546	Economy	6000.00
0005433616582	8546	Economy	6000.00
0005433616571	8546	Economy	6000.00
0005433616337	8546	Economy	6000.00
0005433616420	8546	Economy	6000.00
0005433616416	8546	Economy	6000.00
0005433616418	8546	Economy	6000.00
0005433616329	8546	Economy	6000.00
0005433616490	8546	Economy	6000.00
0005433616422	8546	Economy	6000.00
0005433616516	8546	Economy	6000.00
0005433616375	8546	Economy	6000.00
0005433616396	8546	Economy	6000.00
0005433616123	8546	Economy	6000.00
0005433616284	8546	Economy	6000.00
0005433616409	8546	Economy	6000.00
0005434229932	8545	Business	18000.00
0005434150023	8545	Business	18000.00
0005435287019	8545	Business	18000.00
0005435551777	8545	Business	18000.00
0005435287021	8545	Business	18000.00
0005434229905	8545	Business	18000.00
0005434150017	8545	Business	18000.00
0005434265775	8545	Business	18000.00
0005432047666	8545	Business	18000.00
0005434150031	8545	Business	18000.00
0005435551780	8545	Business	18000.00
0005435287022	8545	Business	18000.00
0005435732739	8545	Business	18000.00
0005434265760	8545	Business	18000.00
0005434149971	8545	Business	18000.00
0005434265781	8545	Business	18000.00
0005434149978	8545	Business	18000.00
0005435287010	8545	Business	18000.00
0005434265747	8545	Business	18000.00
0005435732743	8545	Business	18000.00
0005434150018	8545	Economy	6600.00
0005434265740	8545	Economy	6600.00
0005434265780	8545	Economy	6600.00
0005435287024	8545	Economy	6600.00
0005434229891	8545	Economy	6600.00
0005434311281	8545	Economy	6000.00
0005435287034	8545	Economy	6000.00
0005434229917	8545	Economy	6000.00
0005435287026	8545	Economy	6000.00
0005434150010	8545	Economy	6000.00
0005434229896	8545	Economy	6000.00
0005434265700	8545	Economy	6000.00
0005434229934	8545	Economy	6000.00
0005434173618	8545	Economy	6000.00
0005435551782	8545	Economy	6000.00
0005432035760	8545	Economy	6000.00
0005434229914	8545	Economy	6000.00
0005434229858	8545	Economy	6000.00
0005434229912	8545	Economy	6000.00
0005434265765	8545	Economy	6000.00
0005434173633	8545	Economy	6000.00
0005434229913	8545	Economy	6000.00
0005434265766	8545	Economy	6000.00
0005435287015	8545	Economy	6000.00
0005434150006	8545	Economy	6000.00
0005434265629	8545	Economy	6000.00
0005434150009	8545	Economy	6000.00
0005435287017	8545	Economy	6000.00
0005434229916	8545	Economy	6000.00
0005434265628	8545	Economy	6000.00
0005434229893	8545	Economy	6000.00
0005435287018	8545	Economy	6000.00
0005434230004	8545	Economy	6000.00
0005434265761	8545	Economy	6000.00
0005435287028	8545	Economy	6000.00
0005434265759	8545	Economy	6000.00
0005434265647	8545	Economy	6000.00
0005434229897	8545	Economy	6000.00
0005434265792	8545	Economy	6000.00
0005435287013	8545	Economy	6000.00
0005434265729	8545	Economy	6000.00
0005434229892	8545	Economy	6000.00
0005435287031	8545	Economy	6000.00
0005435732741	8545	Economy	6000.00
0005434173617	8545	Economy	6000.00
0005434150022	8545	Economy	6000.00
0005435551776	8545	Economy	6000.00
0005434229860	8545	Economy	6000.00
0005434265768	8545	Economy	6600.00
0005434229936	8545	Economy	6600.00
0005434149995	8545	Economy	6600.00
0005434229819	8545	Economy	6600.00
0005433815564	8545	Economy	6000.00
0005435287033	8545	Economy	6000.00
0005434229935	8545	Economy	6600.00
0005435732742	8545	Economy	6000.00
0005434265672	8545	Economy	6000.00
0005434265798	8545	Economy	6000.00
0005435287025	8545	Economy	6000.00
0005434229875	8545	Economy	6000.00
0005434229959	8545	Economy	6000.00
0005434150019	8545	Economy	6000.00
0005434150013	8545	Economy	6000.00
0005434265706	8545	Economy	6000.00
0005435287011	8545	Economy	6000.00
0005435287032	8545	Economy	6000.00
0005435732740	8545	Economy	6000.00
0005434265707	8545	Economy	6000.00
0005434173632	8545	Economy	6000.00
0005434229857	8545	Economy	6000.00
0005435287029	8545	Economy	6000.00
0005434229898	8545	Economy	6000.00
0005434265828	8545	Economy	6000.00
0005435287016	8545	Economy	6000.00
0005435732738	8545	Economy	6000.00
0005433815566	8545	Economy	6000.00
0005435287023	8545	Economy	6000.00
0005434229888	8545	Economy	6000.00
0005434230003	8545	Economy	6000.00
0005434150014	8545	Economy	6000.00
0005435287030	8545	Economy	6000.00
0005434265797	8545	Economy	6000.00
0005434265732	8545	Economy	6000.00
0005434150030	8545	Economy	6000.00
0005434265816	8545	Economy	6000.00
0005434265731	8545	Economy	6000.00
0005435287020	8545	Economy	6000.00
0005435287009	8545	Economy	6000.00
0005433815565	8545	Economy	6000.00
0005435007719	8545	Economy	6000.00
0005434150029	8545	Economy	6000.00
0005434265762	8545	Economy	6000.00
0005434265774	8545	Economy	6000.00
0005435477011	8545	Economy	6000.00
0005435287014	8545	Economy	6000.00
0005434265758	8545	Economy	6000.00
0005435551779	8545	Economy	6000.00
0005435551781	8545	Economy	6000.00
0005434149994	8545	Economy	6000.00
0005435287027	8545	Economy	6000.00
0005434150007	8545	Economy	6000.00
0005435007718	8545	Economy	6000.00
0005435287012	8545	Economy	6000.00
0005435551778	8545	Economy	6000.00
0005434639903	12634	Economy	16200.00
0005434639968	12634	Economy	16200.00
0005434639937	12634	Economy	16200.00
0005433202797	12634	Economy	16200.00
0005434639982	12634	Economy	14800.00
0005434639971	12634	Economy	14800.00
0005433202795	12634	Economy	14800.00
0005434639886	12634	Economy	14800.00
0005434639929	12634	Economy	14800.00
0005434640033	12634	Economy	14800.00
0005434639882	12634	Economy	14800.00
0005434639970	12634	Economy	14800.00
0005434639962	12634	Economy	14800.00
0005433202794	12634	Economy	14800.00
0005434640041	12634	Economy	14800.00
0005434639861	12634	Economy	14800.00
0005434639974	12634	Economy	14800.00
0005434640040	12634	Economy	14800.00
0005434640011	12634	Economy	14800.00
0005434639885	12634	Economy	14800.00
0005434640044	12634	Economy	14800.00
0005434639938	12634	Economy	14800.00
0005434639910	12634	Economy	14800.00
0005434639973	12634	Economy	14800.00
0005434640045	12634	Economy	14800.00
0005433202796	12634	Economy	14800.00
0005434639939	12634	Economy	14800.00
0005434639887	12634	Economy	14800.00
0005434640012	12634	Economy	14800.00
0005434639981	12634	Economy	14800.00
0005434639969	12634	Economy	14800.00
0005434639975	12634	Economy	14800.00
0005433202793	12634	Economy	14800.00
0005434639891	12634	Economy	14800.00
0005434639862	12634	Economy	14800.00
0005434640099	23361	Economy	16200.00
0005433202688	23361	Economy	14800.00
0005433202733	23361	Economy	14800.00
0005433202649	23361	Economy	14800.00
0005433202670	23361	Economy	14800.00
0005433202732	23361	Economy	14800.00
0005433202703	23361	Economy	14800.00
0005433202647	23361	Economy	14800.00
0005433202692	23361	Economy	14800.00
0005433202622	23361	Economy	14800.00
0005434640101	23361	Economy	14800.00
0005433202690	23361	Economy	14800.00
0005434640096	23361	Economy	14800.00
0005433202686	23361	Economy	14800.00
0005433202689	23361	Economy	14800.00
0005433202646	23361	Economy	14800.00
0005433202671	23361	Economy	14800.00
0005434640097	23361	Economy	14800.00
0005434640098	23361	Economy	14800.00
0005433202645	23361	Economy	14800.00
0005433202757	23361	Economy	14800.00
0005433202756	23361	Economy	14800.00
0005434640100	23361	Economy	14800.00
0005432329612	21101	Business	18900.00
0005432329802	21101	Business	18900.00
0005432329812	21101	Business	18900.00
0005432384054	21101	Business	18900.00
0005432384230	21101	Business	18900.00
0005432384197	21101	Business	18900.00
0005432384135	21101	Business	18900.00
0005432329735	21101	Business	18900.00
0005432329899	21101	Business	18900.00
0005432329928	21101	Business	18900.00
0005432384061	21101	Economy	6300.00
0005432383919	21101	Economy	6300.00
0005432329824	21101	Economy	6300.00
0005432384266	21101	Economy	6300.00
0005432384149	21101	Economy	6300.00
0005432329688	21101	Economy	6300.00
0005432384006	21101	Economy	6300.00
0005432329577	21101	Economy	6300.00
0005432329693	21101	Economy	6300.00
0005432384150	21101	Economy	6900.00
0005432329670	21101	Economy	6900.00
0005432383917	21101	Economy	6900.00
0005432329658	21101	Economy	6900.00
0005432384069	21101	Economy	6900.00
0005432384265	21101	Economy	6300.00
0005432383928	21101	Economy	6300.00
0005432329595	21101	Economy	6300.00
0005432384153	21101	Economy	6300.00
0005432384051	21101	Economy	6300.00
0005432329731	21101	Economy	6300.00
0005432329642	21101	Economy	6300.00
0005432384070	21101	Economy	6300.00
0005432329837	21101	Economy	6300.00
0005432329687	21101	Economy	6300.00
0005432384076	21101	Economy	6300.00
0005432383823	21101	Economy	6300.00
0005432384077	21101	Economy	6300.00
0005432384008	21101	Economy	6300.00
0005432329641	21101	Economy	6300.00
0005432383862	21101	Economy	6300.00
0005432848918	21101	Economy	6300.00
0005432329643	21101	Economy	6300.00
0005432384052	21101	Economy	6300.00
0005432329896	21101	Economy	6300.00
0005432329811	21101	Economy	6300.00
0005432384117	21101	Economy	6300.00
0005432329668	21101	Economy	6300.00
0005432383918	21101	Economy	6300.00
0005432329751	21101	Economy	6300.00
0005432384009	21101	Economy	6300.00
0005432329747	21101	Economy	6300.00
0005432383941	21101	Economy	6300.00
0005432329807	21101	Economy	6300.00
0005432384188	21101	Economy	6300.00
0005432329640	21101	Economy	6300.00
0005432329823	21101	Economy	6300.00
0005432383987	21101	Economy	6300.00
0005432329789	21101	Economy	6300.00
0005432329750	21101	Economy	6300.00
0005432384010	21101	Economy	6300.00
0005432384249	21101	Economy	6300.00
0005432384025	21101	Economy	6300.00
0005432383999	21101	Economy	6300.00
0005432329835	21101	Economy	6300.00
0005432329730	21101	Economy	6300.00
0005432384046	21101	Economy	6300.00
0005432329596	21101	Economy	6300.00
0005432329766	21101	Economy	6300.00
0005432384194	21101	Economy	6300.00
0005432329879	21101	Economy	6300.00
0005432329748	21101	Economy	6300.00
0005432384029	21101	Economy	6300.00
0005432383960	21101	Economy	6300.00
0005432384007	21101	Economy	6300.00
0005432329806	21101	Economy	6300.00
0005432848919	21101	Economy	6300.00
0005432384154	21101	Economy	6300.00
0005432384152	21101	Economy	6300.00
0005432329915	21101	Economy	6300.00
0005432384026	21101	Economy	6300.00
0005432384033	21101	Economy	6300.00
0005432384034	21101	Economy	6300.00
0005432383931	21101	Economy	6300.00
0005432383961	21101	Economy	6300.00
0005432384055	21101	Economy	6300.00
0005432384189	21101	Economy	6300.00
0005432330049	31259	Business	18900.00
0005432330048	31259	Business	18900.00
0005432384330	31259	Business	18900.00
0005432384326	31259	Economy	6300.00
0005432330044	31259	Economy	6300.00
0005432384333	31259	Economy	6900.00
0005432330045	31259	Economy	6300.00
0005432384329	31259	Economy	6300.00
0005432384332	31259	Economy	6300.00
0005432330051	31259	Economy	6300.00
0005432384324	31259	Economy	6300.00
0005432384327	31259	Economy	6300.00
0005432384328	31259	Economy	6300.00
0005432330040	31259	Economy	6300.00
0005432384334	31259	Economy	6300.00
0005432384331	31259	Economy	6300.00
0005432848892	31259	Economy	6300.00
0005432330047	31259	Economy	6300.00
0005432384335	31259	Economy	6300.00
0005432330043	31259	Economy	6300.00
0005432330046	31259	Economy	6300.00
0005432330050	31259	Economy	6300.00
0005432848893	31259	Economy	6300.00
0005432330041	31259	Economy	6300.00
0005432330042	31259	Economy	6300.00
0005432384325	31259	Economy	6300.00
0005432954115	2483	Business	89600.00
0005432954127	2483	Economy	29900.00
0005432954116	2483	Economy	32800.00
0005432954134	2483	Economy	32800.00
0005432954110	2483	Economy	32800.00
0005432954119	2483	Economy	29900.00
0005432954129	2483	Economy	29900.00
0005432954136	2483	Economy	29900.00
0005432954123	2483	Economy	29900.00
0005432954139	2483	Economy	29900.00
0005432954128	2483	Economy	29900.00
0005432954111	2483	Economy	29900.00
0005432954105	2483	Economy	29900.00
0005433642779	2483	Economy	29900.00
0005432954097	2483	Economy	29900.00
0005432954104	2483	Economy	29900.00
0005432954117	2483	Economy	29900.00
0005432954155	2483	Economy	29900.00
0005432954118	2483	Economy	29900.00
0005432954124	2483	Economy	29900.00
0005432954138	2483	Economy	29900.00
0005433642778	2483	Economy	29900.00
0005432954141	2483	Economy	29900.00
0005432954140	2483	Economy	29900.00
0005432426015	13339	Business	12700.00
0005432426038	13339	Business	12700.00
0005432426042	13339	Business	12700.00
0005432426012	13339	Business	12700.00
0005432426022	13339	Business	12700.00
0005432426041	13339	Business	12700.00
0005432426010	13339	Business	12700.00
0005432426026	13339	Economy	4200.00
0005432426001	13339	Economy	4200.00
0005432426008	13339	Economy	4200.00
0005432426009	13339	Economy	4200.00
0005432426032	13339	Economy	4200.00
0005432426021	13339	Economy	4200.00
0005432426030	13339	Economy	4700.00
0005432433842	13339	Economy	4700.00
0005432426031	13339	Economy	4700.00
0005432426039	13339	Economy	4200.00
0005432426006	13339	Economy	4200.00
0005432426005	13339	Economy	4200.00
0005432426017	13339	Economy	4200.00
0005432426002	13339	Economy	4200.00
0005432426033	13339	Economy	4200.00
0005432426027	13339	Economy	4200.00
0005432426029	13339	Economy	4200.00
0005432426025	13339	Economy	4200.00
0005432426037	13339	Economy	4200.00
0005432426023	13339	Economy	4200.00
0005432462582	13339	Economy	4200.00
0005432426035	13339	Economy	4200.00
0005432426020	13339	Economy	4200.00
0005432426018	13339	Economy	4200.00
0005432426040	13339	Economy	4200.00
0005432426028	13339	Economy	4200.00
0005432426003	13339	Economy	4200.00
0005432426011	13339	Economy	4200.00
0005432433841	13339	Economy	4200.00
0005432426019	13339	Economy	4200.00
0005432426000	13339	Economy	4200.00
0005432425999	13339	Economy	4200.00
0005432426014	13339	Economy	4200.00
0005432426034	13339	Economy	4200.00
0005432426036	13339	Economy	4200.00
0005432426013	13339	Economy	4200.00
0005432426007	13339	Economy	4200.00
0005432426016	13339	Economy	4200.00
0005432426004	13339	Economy	4200.00
0005432426024	13339	Economy	4200.00
0005432425604	30793	Business	12700.00
0005432425410	30793	Business	12700.00
0005432425432	30793	Business	12700.00
0005432425612	30793	Business	12700.00
0005432425554	30793	Business	12700.00
0005432425588	30793	Economy	4200.00
0005432425547	30793	Economy	4200.00
0005432425553	30793	Economy	4200.00
0005432425474	30793	Economy	4200.00
0005432425534	30793	Economy	4200.00
0005432425317	30793	Economy	4700.00
0005432425570	30793	Economy	4700.00
0005432425386	30793	Economy	4700.00
0005432425562	30793	Economy	4700.00
0005432425490	30793	Economy	4200.00
0005432425290	30793	Economy	4200.00
0005432425595	30793	Economy	4200.00
0005432425581	30793	Economy	4200.00
0005432425578	30793	Economy	4200.00
0005432425533	30793	Economy	4200.00
0005432425536	30793	Economy	4200.00
0005432425611	30793	Economy	4200.00
0005432425485	30793	Economy	4200.00
0005432425546	30793	Economy	4200.00
0005432425431	30793	Economy	4200.00
0005432425430	30793	Economy	4200.00
0005432425530	30793	Economy	4200.00
0005432425603	30793	Economy	4200.00
0005432425608	30793	Economy	4200.00
0005432425606	30793	Economy	4200.00
0005432425607	30793	Economy	4200.00
0005432425594	30793	Economy	4200.00
0005432425463	30793	Economy	4200.00
0005432425486	30793	Economy	4200.00
0005432425614	30793	Economy	4200.00
0005432425475	30793	Economy	4200.00
0005432425605	30793	Economy	4200.00
0005432425619	30793	Economy	4200.00
0005432902072	9618	Business	32600.00
0005432901983	9618	Business	32600.00
0005432901963	9618	Business	32600.00
0005432902073	9618	Business	32600.00
0005434157694	9618	Economy	10900.00
0005432902043	9618	Economy	10900.00
0005432901960	9618	Economy	10900.00
0005432902070	9618	Economy	11900.00
0005434157664	9618	Economy	10900.00
0005432902029	9618	Economy	10900.00
0005434157691	9618	Economy	10900.00
0005434157690	9618	Economy	10900.00
0005432818334	9618	Economy	10900.00
0005432902042	9618	Economy	10900.00
0005432902049	9618	Economy	10900.00
0005432902055	9618	Economy	10900.00
0005434157689	9618	Economy	10900.00
0005432818335	9618	Economy	10900.00
0005432902028	9618	Economy	10900.00
0005432901961	9618	Economy	10900.00
0005432901964	9618	Economy	10900.00
0005434157663	9618	Economy	10900.00
0005432902048	9618	Economy	10900.00
0005434186265	9618	Economy	10900.00
0005434186266	9618	Economy	10900.00
0005434157667	9618	Economy	10900.00
0005434157688	9618	Economy	10900.00
0005434157662	9618	Economy	10900.00
0005432902050	9618	Economy	10900.00
0005432818333	9618	Economy	10900.00
0005432901982	9618	Economy	10900.00
0005432818186	29002	Business	32600.00
0005432818223	29002	Business	32600.00
0005432818178	29002	Business	32600.00
0005432818209	29002	Business	32600.00
0005432818236	29002	Business	32600.00
0005432818255	29002	Business	32600.00
0005432818188	29002	Business	32600.00
0005434157712	29002	Economy	10900.00
0005432818122	29002	Economy	10900.00
0005432818320	29002	Economy	11900.00
0005432818158	29002	Economy	11900.00
0005432818084	29002	Economy	11900.00
0005432818063	29002	Economy	10900.00
0005434448397	29002	Economy	10900.00
0005432818062	29002	Economy	10900.00
0005432822391	29002	Economy	10900.00
0005432822375	29002	Economy	10900.00
0005432818222	29002	Economy	10900.00
0005432822380	29002	Economy	10900.00
0005432822393	29002	Economy	10900.00
0005432818279	29002	Economy	10900.00
0005434448396	29002	Economy	10900.00
0005432818148	29002	Economy	10900.00
0005432818103	29002	Economy	10900.00
0005432818121	29002	Economy	10900.00
0005432818224	29002	Economy	10900.00
0005432822381	29002	Economy	10900.00
0005432818141	29002	Economy	10900.00
0005432818165	29002	Economy	10900.00
0005434157714	29002	Economy	10900.00
0005432818164	29002	Economy	10900.00
0005432818163	29002	Economy	10900.00
0005432818189	29002	Economy	10900.00
0005432818319	29002	Economy	10900.00
0005432818254	29002	Economy	10900.00
0005432818140	29002	Economy	10900.00
0005434448379	29002	Economy	10900.00
0005434157713	29002	Economy	10900.00
0005432902124	29002	Economy	10900.00
0005432822366	29002	Economy	10900.00
0005432818032	29002	Economy	10900.00
0005432818202	29002	Economy	10900.00
0005434448400	29002	Economy	10900.00
0005435841838	15110	Economy	11000.00
0005435841113	15110	Economy	11000.00
0005432611777	31646	Economy	11000.00
0005432611802	31646	Economy	11000.00
0005432607646	31646	Economy	11000.00
0005432607648	31646	Economy	11000.00
0005432607656	31646	Economy	11000.00
0005432611793	31646	Economy	11000.00
0005432607649	31646	Economy	11000.00
0005432607655	31646	Economy	11000.00
0005432949332	11881	Business	105900.00
0005432949476	11881	Business	105900.00
0005433570958	11881	Business	105900.00
0005432949484	11881	Business	105900.00
0005432949483	11881	Business	105900.00
0005433570953	11881	Business	105900.00
0005432949461	11881	Business	105900.00
0005432949434	11881	Business	105900.00
0005432949454	11881	Business	105900.00
0005432949477	11881	Business	105900.00
0005432949491	11881	Business	105900.00
0005432949463	11881	Business	105900.00
0005432949284	11881	Economy	35300.00
0005432949435	11881	Economy	35300.00
0005433570952	11881	Economy	35300.00
0005432949497	11881	Economy	35300.00
0005433570965	11881	Economy	35300.00
0005432949343	11881	Economy	35300.00
0005433570949	11881	Economy	38800.00
0005433570956	11881	Economy	38800.00
0005432949246	11881	Economy	35300.00
0005432949342	11881	Economy	35300.00
0005433570959	11881	Economy	35300.00
0005432949324	11881	Economy	35300.00
0005433570948	11881	Economy	35300.00
0005432949421	11881	Economy	35300.00
0005433570955	11881	Economy	35300.00
0005432949436	11881	Economy	35300.00
0005433570957	11881	Economy	35300.00
0005432949383	11881	Economy	35300.00
0005432949415	11881	Economy	35300.00
0005432949315	11881	Economy	35300.00
0005433570946	11881	Economy	35300.00
0005433570950	11881	Economy	35300.00
0005432949492	11881	Economy	35300.00
0005433570961	11881	Economy	35300.00
0005433570954	11881	Economy	35300.00
0005432949462	11881	Economy	35300.00
0005432949464	11881	Economy	35300.00
0005432949279	11881	Economy	35300.00
0005432949331	11881	Economy	35300.00
0005432949280	11881	Economy	35300.00
0005433570960	11881	Economy	35300.00
0005433570947	11881	Economy	35300.00
0005432949210	11881	Economy	35300.00
0005432949414	11881	Economy	35300.00
0005432949285	11881	Economy	35300.00
0005433570962	11881	Economy	35300.00
0005432949275	11881	Economy	35300.00
0005432949478	11881	Economy	35300.00
0005433570963	11881	Economy	35300.00
0005432949303	11881	Economy	35300.00
0005432949428	11881	Economy	35300.00
0005432949282	11881	Economy	35300.00
0005433570951	11881	Economy	35300.00
0005432949416	11881	Economy	35300.00
0005432949330	11881	Economy	35300.00
0005432949316	11881	Economy	35300.00
0005432949211	11881	Economy	35300.00
0005432949229	11881	Economy	35300.00
0005433570964	11881	Economy	35300.00
0005432949355	11881	Economy	35300.00
0005432949485	11881	Economy	35300.00
0005433570498	25283	Business	105900.00
0005433570491	25283	Business	105900.00
0005433570684	25283	Business	105900.00
0005433570480	25283	Business	105900.00
0005433570496	25283	Business	105900.00
0005433570555	25283	Business	105900.00
0005433570585	25283	Business	105900.00
0005433570495	25283	Business	105900.00
0005432949696	25283	Business	105900.00
0005433570324	25283	Business	105900.00
0005433570226	25283	Business	105900.00
0005433570436	25283	Business	105900.00
0005433570453	25283	Business	105900.00
0005433570459	25283	Business	105900.00
0005433570509	25283	Economy	35300.00
0005433570283	25283	Economy	35300.00
0005433570522	25283	Economy	35300.00
0005433570621	25283	Economy	35300.00
0005433570552	25283	Economy	35300.00
0005433570663	25283	Economy	35300.00
0005433570448	25283	Economy	35300.00
0005433570771	25283	Economy	35300.00
0005433570542	25283	Economy	38800.00
0005433570671	25283	Economy	38800.00
0005433570430	25283	Economy	35300.00
0005433570800	25283	Economy	35300.00
0005433570440	25283	Economy	35300.00
0005433570487	25283	Economy	35300.00
0005433570652	25283	Economy	35300.00
0005433570286	25283	Economy	35300.00
0005433570397	25283	Economy	35300.00
0005433570361	25283	Economy	35300.00
0005433570378	25283	Economy	35300.00
0005433570544	25283	Economy	35300.00
0005433570460	25283	Economy	35300.00
0005433570620	25283	Economy	35300.00
0005433570554	25283	Economy	35300.00
0005433570439	25283	Economy	35300.00
0005433570458	25283	Economy	35300.00
0005433570534	25283	Economy	35300.00
0005433570685	25283	Economy	35300.00
0005433570323	25283	Economy	35300.00
0005433570187	25283	Economy	35300.00
0005433570396	25283	Economy	35300.00
0005432949699	25283	Economy	35300.00
0005432949693	25283	Economy	35300.00
0005433570664	25283	Economy	35300.00
0005433570432	25283	Economy	35300.00
0005433570285	25283	Economy	35300.00
0005433570584	25283	Economy	35300.00
0005433570540	25283	Economy	35300.00
0005433570383	25283	Economy	35300.00
0005433570485	25283	Economy	35300.00
0005433570541	25283	Economy	35300.00
0005433570321	25283	Economy	35300.00
0005433570497	25283	Economy	35300.00
0005432949697	25283	Economy	35300.00
0005433570447	25283	Economy	35300.00
0005433570530	25283	Economy	35300.00
0005432949698	25283	Economy	35300.00
0005433570486	25283	Economy	35300.00
0005433570549	25283	Economy	35300.00
0005433570258	25283	Economy	35300.00
0005433570322	25283	Economy	35300.00
0005432949694	25283	Economy	35300.00
0005433570325	25283	Economy	35300.00
0005433570435	25283	Economy	35300.00
0005432949695	25283	Economy	35300.00
0005433812953	14454	Business	117400.00
0005434026763	14454	Business	117400.00
0005433808436	14454	Business	117400.00
0005433808434	14454	Business	117400.00
0005433812961	14454	Economy	39100.00
0005433808473	14454	Economy	39100.00
0005433808468	14454	Economy	43000.00
0005432430975	14454	Economy	39100.00
0005432430974	14454	Economy	39100.00
0005433808438	14454	Economy	39100.00
0005433808464	14454	Economy	39100.00
0005433812945	14454	Economy	39100.00
0005433812959	14454	Economy	39100.00
0005433812944	14454	Economy	39100.00
0005433812949	14454	Economy	39100.00
0005433808437	14454	Economy	39100.00
0005433808466	14454	Economy	39100.00
0005433812938	14454	Economy	39100.00
0005433812937	14454	Economy	39100.00
0005433808467	14454	Economy	39100.00
0005433808452	14454	Economy	39100.00
0005433812960	14454	Economy	39100.00
0005433808433	14454	Economy	39100.00
0005433812947	14454	Economy	39100.00
0005433808469	14454	Economy	39100.00
0005433808458	14454	Economy	39100.00
0005433808460	14454	Economy	39100.00
0005432430949	30834	Business	117400.00
0005432430940	30834	Business	117400.00
0005434026754	30834	Economy	39100.00
0005434026743	30834	Economy	39100.00
0005433808486	30834	Economy	39100.00
0005432430961	30834	Economy	39100.00
0005432430935	30834	Economy	39100.00
0005432430938	30834	Economy	39100.00
0005432430942	30834	Economy	39100.00
0005432430952	30834	Economy	39100.00
0005433812965	30834	Economy	39100.00
0005432430936	30834	Economy	39100.00
0005432430937	30834	Economy	39100.00
0005432430950	30834	Economy	39100.00
0005434026748	30834	Economy	39100.00
0005433808485	30834	Economy	39100.00
0005432430962	30834	Economy	39100.00
0005432430944	30834	Economy	39100.00
0005433812966	30834	Economy	39100.00
0005432430953	30834	Economy	39100.00
0005432430941	30834	Economy	39100.00
0005432430945	30834	Economy	39100.00
0005433812967	30834	Economy	39100.00
0005434026753	30834	Economy	39100.00
0005434026749	30834	Economy	39100.00
0005432430943	30834	Economy	39100.00
0005432430948	30834	Economy	39100.00
0005435340601	5403	Business	67200.00
0005435340688	5403	Business	67200.00
0005435340576	5403	Economy	22400.00
0005435340687	5403	Economy	22400.00
0005435340577	5403	Economy	24600.00
0005435340629	5403	Economy	22400.00
0005434655541	5403	Economy	22400.00
0005435340689	5403	Economy	22400.00
0005435340673	5403	Economy	22400.00
0005435340578	5403	Economy	22400.00
0005435340600	5403	Economy	22400.00
0005435340636	5403	Economy	22400.00
0005435340615	5403	Economy	22400.00
0005435340661	5403	Economy	22400.00
0005434655542	5403	Economy	22400.00
0005435555417	5403	Economy	22400.00
0005435340675	5403	Economy	22400.00
0005435340690	5403	Economy	22400.00
0005434655539	5403	Economy	22400.00
0005434655540	5403	Economy	22400.00
0005434655236	12506	Business	67200.00
0005434655315	12506	Business	67200.00
0005434655386	12506	Business	67200.00
0005435340706	12506	Economy	22400.00
0005434655408	12506	Economy	24600.00
0005434655261	12506	Economy	22400.00
0005434655429	12506	Economy	22400.00
0005434655304	12506	Economy	22400.00
0005434655430	12506	Economy	22400.00
0005434655284	12506	Economy	22400.00
0005434655301	12506	Economy	22400.00
0005434655281	12506	Economy	22400.00
0005434655505	12506	Economy	22400.00
0005434655519	12506	Economy	22400.00
0005435340707	12506	Economy	22400.00
0005434655384	12506	Economy	22400.00
0005434655504	12506	Economy	22400.00
0005434655465	12506	Economy	22400.00
0005434655383	12506	Economy	22400.00
0005434655362	12506	Economy	22400.00
0005434655235	12506	Economy	22400.00
0005434655385	12506	Economy	22400.00
0005434656606	12506	Economy	22400.00
0005434655369	12506	Economy	22400.00
0005434655328	12506	Economy	22400.00
0005434655262	12506	Economy	22400.00
0005434656601	12506	Economy	22400.00
0005434655305	12506	Economy	22400.00
0005434655370	12506	Economy	22400.00
0005434656600	12506	Economy	22400.00
0005434655234	12506	Economy	22400.00
0005434655461	12506	Economy	22400.00
0005434655282	12506	Economy	22400.00
0005433722508	7417	Business	32000.00
0005435266310	7417	Economy	10700.00
0005435266302	7417	Economy	10700.00
0005435266298	7417	Economy	10700.00
0005435266280	7417	Economy	10700.00
0005433722506	7417	Economy	10700.00
0005433722507	7417	Economy	10700.00
0005435266276	7417	Economy	10700.00
0005433722505	7417	Economy	10700.00
0005433717424	7417	Economy	11700.00
0005435266277	7417	Economy	11700.00
0005435266287	7417	Economy	11700.00
0005435266273	7417	Economy	10700.00
0005433717426	7417	Economy	10700.00
0005435266279	7417	Economy	10700.00
0005435266297	7417	Economy	10700.00
0005435266300	7417	Economy	10700.00
0005435266299	7417	Economy	10700.00
0005433722502	7417	Economy	10700.00
0005433722504	7417	Economy	10700.00
0005435266278	7417	Economy	10700.00
0005433722503	7417	Economy	10700.00
0005435266308	7417	Economy	10700.00
0005435266309	7417	Economy	10700.00
0005433717425	7417	Economy	10700.00
0005433717103	29217	Business	32000.00
0005433717030	29217	Business	32000.00
0005433717291	29217	Business	32000.00
0005433717017	29217	Business	32000.00
0005433685576	29217	Economy	10700.00
0005433656744	29217	Economy	10700.00
0005433717178	29217	Economy	10700.00
0005433722368	29217	Economy	10700.00
0005433722365	29217	Economy	10700.00
0005433717165	29217	Economy	10700.00
0005433717312	29217	Economy	10700.00
0005433717075	29217	Economy	10700.00
0005433717086	29217	Economy	10700.00
0005433722366	29217	Economy	10700.00
0005435546239	29217	Economy	10700.00
0005433717129	29217	Economy	10700.00
0005433717111	29217	Economy	10700.00
0005433717092	29217	Economy	10700.00
0005433717094	29217	Economy	10700.00
0005433688856	29217	Economy	10700.00
0005433722376	29217	Economy	10700.00
0005433717233	29217	Economy	10700.00
0005433722354	29217	Economy	10700.00
0005433717160	29217	Economy	10700.00
0005433717061	29217	Economy	10700.00
0005433722367	29217	Economy	10700.00
0005433717166	29217	Economy	11700.00
0005433719207	29217	Economy	11700.00
0005433716988	29217	Economy	11700.00
0005433717130	29217	Economy	10700.00
0005433717161	29217	Economy	10700.00
0005433722369	29217	Economy	10700.00
0005433716989	29217	Economy	10700.00
0005433717112	29217	Economy	10700.00
0005433717110	29217	Economy	10700.00
0005435266344	29217	Economy	10700.00
0005433717325	29217	Economy	10700.00
0005433717060	29217	Economy	10700.00
0005433717128	29217	Economy	10700.00
0005433717324	29217	Economy	10700.00
0005433717156	29217	Economy	10700.00
0005433716978	29217	Economy	10700.00
0005433717041	29217	Economy	10700.00
0005433717163	29217	Economy	10700.00
0005433717318	29217	Economy	10700.00
0005433717232	29217	Economy	10700.00
0005433722362	29217	Economy	10700.00
0005433717023	29217	Economy	10700.00
0005433717149	29217	Economy	10700.00
0005433717131	29217	Economy	10700.00
0005433717329	29217	Economy	10700.00
0005433719227	29217	Economy	10700.00
0005433717283	29217	Economy	10700.00
0005433685575	29217	Economy	10700.00
0005433717223	29217	Economy	10700.00
0005433717328	29217	Economy	10700.00
0005433722375	29217	Economy	10700.00
0005433717123	29217	Economy	10700.00
0005433717209	29217	Economy	10700.00
0005433722356	29217	Economy	10700.00
0005433717057	29217	Economy	10700.00
0005433717087	29217	Economy	10700.00
0005433656750	29217	Economy	10700.00
0005433717284	29217	Economy	10700.00
0005433722361	29217	Economy	10700.00
0005433722351	29217	Economy	10700.00
0005433717093	29217	Economy	10700.00
0005435266345	29217	Economy	10700.00
0005434182480	8681	Business	36500.00
0005434182481	8681	Economy	12200.00
0005434095707	8681	Economy	12200.00
0005434095705	8681	Economy	12200.00
0005434182514	8681	Economy	12200.00
0005434182487	8681	Economy	12200.00
0005435860643	8681	Economy	12200.00
0005434182485	8681	Economy	12200.00
0005434143859	8681	Economy	12200.00
0005434095706	8681	Economy	12200.00
0005434326092	8681	Economy	12200.00
0005434095704	8681	Economy	12200.00
0005434182499	8681	Economy	12200.00
0005434182486	8681	Economy	12200.00
0005434182416	8681	Economy	12200.00
0005434095708	8681	Economy	12200.00
0005434182435	8681	Economy	12200.00
0005434143858	8681	Economy	12200.00
0005434182490	8681	Economy	12200.00
0005434184728	11676	Business	36500.00
0005434143763	11676	Business	36500.00
0005434095605	11676	Economy	12200.00
0005435860732	11676	Economy	12200.00
0005434095638	11676	Economy	12200.00
0005434095647	11676	Economy	12200.00
0005435860731	11676	Economy	12200.00
0005434095648	11676	Economy	12200.00
0005434095623	11676	Economy	12200.00
0005434095604	11676	Economy	12200.00
0005434095644	11676	Economy	12200.00
0005434143762	11676	Economy	12200.00
0005434095622	11676	Economy	12200.00
0005434095630	11676	Economy	12200.00
0005433399009	1447	Business	33000.00
0005433399242	1447	Business	33000.00
0005433398986	1447	Business	33000.00
0005433399128	1447	Business	33000.00
0005433399107	1447	Business	33000.00
0005433399174	1447	Business	33000.00
0005433399209	1447	Business	33000.00
0005433399274	1447	Business	33000.00
0005433399164	1447	Economy	11000.00
0005433399212	1447	Economy	11000.00
0005433399189	1447	Economy	11000.00
0005433399303	1447	Economy	11000.00
0005433399350	1447	Economy	11000.00
0005432906593	1447	Economy	11000.00
0005433399302	1447	Economy	11000.00
0005433399351	1447	Economy	11000.00
0005433399111	1447	Economy	11000.00
0005435732724	1447	Economy	11000.00
0005433398982	1447	Economy	11000.00
0005433399147	1447	Economy	11000.00
0005433399120	1447	Economy	11000.00
0005433399008	1447	Economy	11000.00
0005433399304	1447	Economy	11000.00
0005433398985	1447	Economy	11000.00
0005433399085	1447	Economy	11000.00
0005433399194	1447	Economy	11000.00
0005433399121	1447	Economy	11000.00
0005433399167	1447	Economy	11000.00
0005433399202	1447	Economy	11000.00
0005433399230	1447	Economy	11000.00
0005433399007	1447	Economy	11000.00
0005433399213	1447	Economy	11000.00
0005433399235	1447	Economy	11000.00
0005433399316	1447	Economy	11000.00
0005433399162	1447	Economy	11000.00
0005433399286	1447	Economy	11000.00
0005432906592	1447	Economy	11000.00
0005435725786	1447	Economy	11000.00
0005433399247	1447	Economy	11000.00
0005435732723	1447	Economy	11000.00
0005433399077	1447	Economy	11000.00
0005433399289	1447	Economy	11000.00
0005433399287	1447	Economy	11000.00
0005433399296	1447	Economy	11000.00
0005435732725	1447	Economy	11000.00
0005433399078	1447	Economy	11000.00
0005433399099	1447	Economy	11000.00
0005433399288	1447	Economy	11000.00
0005433399273	1447	Economy	11000.00
0005433457088	1447	Economy	11000.00
0005435725787	1447	Economy	11000.00
0005435732624	19254	Business	33000.00
0005433457049	19254	Business	33000.00
0005433457061	19254	Economy	11000.00
0005435732644	19254	Economy	12100.00
0005433457085	19254	Economy	12100.00
0005435732627	19254	Economy	11000.00
0005435732681	19254	Economy	11000.00
0005433457077	19254	Economy	11000.00
0005432906608	19254	Economy	11000.00
0005433457074	19254	Economy	11000.00
0005435732645	19254	Economy	11000.00
0005433399465	19254	Economy	11000.00
0005433399464	19254	Economy	11000.00
0005435732607	19254	Economy	11000.00
0005433457050	19254	Economy	11000.00
0005432906609	19254	Economy	11000.00
0005435732601	19254	Economy	11000.00
0005433457057	19254	Economy	11000.00
0005434444048	17375	Economy	15600.00
0005434444070	17375	Economy	15600.00
0005434444112	17375	Economy	14100.00
0005434444158	17375	Economy	14100.00
0005434444137	17375	Economy	14100.00
0005434443982	17375	Economy	14100.00
0005434444098	17375	Economy	14100.00
0005434444049	17375	Economy	14100.00
0005434444092	17375	Economy	14100.00
0005434444108	17375	Economy	14100.00
0005434444089	17375	Economy	14100.00
0005434444071	17375	Economy	14100.00
0005434444076	17375	Economy	14100.00
0005434444181	20562	Economy	14100.00
0005434444182	20562	Economy	14100.00
0005434444183	20562	Economy	14100.00
0005435377640	7276	Economy	5800.00
0005435377639	7276	Economy	5800.00
0005434954694	28336	Economy	5800.00
0005434954693	28336	Economy	5800.00
0005434954705	28336	Economy	5800.00
0005434954690	28336	Economy	5800.00
0005434326109	4474	Economy	15400.00
0005435893830	4474	Economy	15400.00
0005435893803	4474	Economy	14000.00
0005434183629	4474	Economy	14000.00
0005435893813	4474	Economy	14000.00
0005434352065	4474	Economy	14000.00
0005435893814	4474	Economy	14000.00
0005435893804	4474	Economy	14000.00
0005435893812	4474	Economy	14000.00
0005434183630	4474	Economy	14000.00
0005434326108	4474	Economy	14000.00
0005434352019	29653	Economy	14000.00
0005434351983	29653	Economy	14000.00
0005434351968	29653	Economy	14000.00
0005434182555	29653	Economy	14000.00
0005434352020	29653	Economy	14000.00
0005434326053	29653	Economy	14000.00
0005434352033	29653	Economy	14000.00
0005434352044	29653	Economy	14000.00
0005434352045	29653	Economy	14000.00
0005434352043	29653	Economy	14000.00
0005434352013	29653	Economy	14000.00
0005434352034	29653	Economy	14000.00
0005434352001	29653	Economy	14000.00
0005434326054	29653	Economy	14000.00
0005434352012	29653	Economy	14000.00
0005434182554	29653	Economy	14000.00
0005433345672	1070	Business	30600.00
0005433345564	1070	Business	30600.00
0005433345430	1070	Business	30600.00
0005433345066	1070	Business	30600.00
0005433345508	1070	Business	30600.00
0005433345078	1070	Business	30600.00
0005433345622	1070	Business	30600.00
0005433345261	1070	Business	30600.00
0005433345209	1070	Business	30600.00
0005433345794	1070	Business	30600.00
0005433345495	1070	Business	30600.00
0005433345697	1070	Business	30600.00
0005433345800	1070	Economy	11200.00
0005435546001	1070	Economy	11200.00
0005433345817	1070	Economy	10200.00
0005433345872	1070	Economy	10200.00
0005433345653	1070	Economy	10200.00
0005433345037	1070	Economy	10200.00
0005434446592	1070	Economy	10200.00
0005433345483	1070	Economy	10200.00
0005433345372	1070	Economy	10200.00
0005433345646	1070	Economy	10200.00
0005433345367	1070	Economy	10200.00
0005433345196	1070	Economy	10200.00
0005433345548	1070	Economy	10200.00
0005433345542	1070	Economy	10200.00
0005433345514	1070	Economy	10200.00
0005433345815	1070	Economy	10200.00
0005433345496	1070	Economy	10200.00
0005433345593	1070	Economy	10200.00
0005433158190	1070	Economy	10200.00
0005433345277	1070	Economy	10200.00
0005433345731	1070	Economy	10200.00
0005433345492	1070	Economy	10200.00
0005433345527	1070	Economy	10200.00
0005435545974	1070	Economy	10200.00
0005433345737	1070	Economy	10200.00
0005433344917	1070	Economy	10200.00
0005433345908	1070	Economy	10200.00
0005433345570	1070	Economy	10200.00
0005433345111	1070	Economy	10200.00
0005433344874	1070	Economy	10200.00
0005433345151	1070	Economy	10200.00
0005433345555	1070	Economy	10200.00
0005433345645	1070	Economy	10200.00
0005433345259	1070	Economy	10200.00
0005433344873	1070	Economy	10200.00
0005433345735	1070	Economy	10200.00
0005435545998	1070	Economy	10200.00
0005433269853	1070	Economy	10200.00
0005433345252	1070	Economy	10200.00
0005433462808	1070	Economy	10200.00
0005433345402	1070	Economy	10200.00
0005433345855	1070	Economy	10200.00
0005433345480	1070	Economy	10200.00
0005433344875	1070	Economy	10200.00
0005433345618	1070	Economy	10200.00
0005433345431	1070	Economy	10200.00
0005433345814	1070	Economy	10200.00
0005433345563	1070	Economy	10200.00
0005433345370	1070	Economy	10200.00
0005433345811	1070	Economy	10200.00
0005433345457	1070	Economy	10200.00
0005433345466	1070	Economy	10200.00
0005433345346	1070	Economy	10200.00
0005433345547	1070	Economy	10200.00
0005435545999	1070	Economy	10200.00
0005433345870	1070	Economy	11200.00
0005433345323	1070	Economy	11200.00
0005433462807	1070	Economy	10200.00
0005433345484	1070	Economy	10200.00
0005433345634	1070	Economy	10200.00
0005433345301	1070	Economy	11200.00
0005433269845	1070	Economy	10200.00
0005433345816	1070	Economy	10200.00
0005433345777	1070	Economy	10200.00
0005433158184	1070	Economy	10200.00
0005433345652	1070	Economy	10200.00
0005435545973	1070	Economy	10200.00
0005433345871	1070	Economy	10200.00
0005433345393	1070	Economy	10200.00
0005435546000	1070	Economy	10200.00
0005433345569	1070	Economy	10200.00
0005433345482	1070	Economy	10200.00
0005433344713	1070	Economy	10200.00
0005433345174	1070	Economy	10200.00
0005433345221	1070	Economy	10200.00
0005433345507	1070	Economy	10200.00
0005433345656	1070	Economy	10200.00
0005433345519	1070	Economy	10200.00
0005433345635	1070	Economy	10200.00
0005433345392	1070	Economy	10200.00
0005433345253	1070	Economy	10200.00
0005433345562	1070	Economy	10200.00
0005433345359	1070	Economy	10200.00
0005433345778	1070	Economy	10200.00
0005433345842	1070	Economy	10200.00
0005433345617	1070	Economy	10200.00
0005433345302	1070	Economy	10200.00
0005433345812	1070	Economy	10200.00
0005433345568	1070	Economy	10200.00
0005433345333	1070	Economy	10200.00
0005433345738	1070	Economy	10200.00
0005433345369	1070	Economy	10200.00
0005433345671	1070	Economy	10200.00
0005433345412	1070	Economy	10200.00
0005433345159	1070	Economy	10200.00
0005435092363	1070	Economy	10200.00
0005433345506	1070	Economy	10200.00
0005433269844	1070	Economy	10200.00
0005433345376	1070	Economy	10200.00
0005433345389	1070	Economy	10200.00
0005435092364	1070	Economy	10200.00
0005433345429	1070	Economy	10200.00
0005435530023	17032	Business	30600.00
0005435092283	17032	Business	30600.00
0005435508634	17032	Business	30600.00
0005433346059	17032	Business	30600.00
0005435508584	17032	Business	30600.00
0005435508713	17032	Business	30600.00
0005435530039	17032	Business	30600.00
0005435092341	17032	Business	30600.00
0005433346055	17032	Business	30600.00
0005435530096	17032	Business	30600.00
0005433269876	17032	Business	30600.00
0005433346046	17032	Economy	11200.00
0005435508604	17032	Economy	11200.00
0005433346049	17032	Economy	11200.00
0005435508730	17032	Economy	10200.00
0005435508632	17032	Economy	10200.00
0005435092293	17032	Economy	10200.00
0005433346048	17032	Economy	10200.00
0005435530104	17032	Economy	10200.00
0005435508696	17032	Economy	10200.00
0005435508752	17032	Economy	10200.00
0005435530124	17032	Economy	10200.00
0005435530064	17032	Economy	10200.00
0005433346064	17032	Economy	10200.00
0005433346058	17032	Economy	10200.00
0005435530032	17032	Economy	10200.00
0005435508627	17032	Economy	10200.00
0005435530019	17032	Economy	10200.00
0005435530157	17032	Economy	10200.00
0005435508637	17032	Economy	10200.00
0005435508641	17032	Economy	10200.00
0005435530105	17032	Economy	10200.00
0005433346045	17032	Economy	10200.00
0005435508668	17032	Economy	10200.00
0005435530090	17032	Economy	10200.00
0005435092312	17032	Economy	10200.00
0005433346063	17032	Economy	10200.00
0005435508714	17032	Economy	10200.00
0005433346050	17032	Economy	10200.00
0005435508643	17032	Economy	10200.00
0005435530079	17032	Economy	10200.00
0005433346053	17032	Economy	10200.00
0005433346065	17032	Economy	10200.00
0005435508754	17032	Economy	10200.00
0005435508718	17032	Economy	10200.00
0005435530015	17032	Economy	10200.00
0005435508689	17032	Economy	11200.00
0005435508709	17032	Economy	10200.00
0005435508753	17032	Economy	10200.00
0005433346054	17032	Economy	10200.00
0005435508669	17032	Economy	10200.00
0005435508715	17032	Economy	10200.00
0005435508731	17032	Economy	10200.00
0005435530078	17032	Economy	10200.00
0005433346047	17032	Economy	10200.00
0005433346067	17032	Economy	10200.00
0005433346052	17032	Economy	10200.00
0005433346062	17032	Economy	10200.00
0005435508622	17032	Economy	10200.00
0005433346057	17032	Economy	10200.00
0005435530031	17032	Economy	10200.00
0005435092345	17032	Economy	10200.00
0005433269875	17032	Economy	10200.00
0005433346056	17032	Economy	10200.00
0005435508653	17032	Economy	10200.00
0005433346051	17032	Economy	10200.00
0005435508745	17032	Economy	10200.00
0005435092353	17032	Economy	10200.00
0005435508628	17032	Economy	10200.00
0005433346066	17032	Economy	10200.00
0005435092300	17032	Economy	10200.00
0005433346060	17032	Economy	10200.00
0005433346061	17032	Economy	10200.00
0005435508644	17032	Economy	10200.00
0005432390358	18260	Business	101000.00
0005432852100	18260	Business	101000.00
0005432392064	18260	Business	101000.00
0005432390414	18260	Business	101000.00
0005432390409	18260	Business	101000.00
0005432390381	18260	Business	101000.00
0005432390364	18260	Business	101000.00
0005432390383	18260	Business	101000.00
0005432390403	18260	Business	101000.00
0005432392070	18260	Economy	33700.00
0005432392058	18260	Business	101000.00
0005432390348	18260	Economy	33700.00
0005432390371	18260	Economy	33700.00
0005432392063	18260	Economy	33700.00
0005432852099	18260	Economy	33700.00
0005432390362	18260	Economy	33700.00
0005432390419	18260	Economy	33700.00
0005432852101	18260	Economy	33700.00
0005432392059	18260	Economy	33700.00
0005432390410	18260	Economy	33700.00
0005432392062	18260	Economy	37000.00
0005432852092	18260	Economy	33700.00
0005432390378	18260	Economy	33700.00
0005432390349	18260	Economy	33700.00
0005432852091	18260	Economy	33700.00
0005432392060	18260	Economy	33700.00
0005432390374	18260	Economy	33700.00
0005432392067	18260	Economy	33700.00
0005432390395	18260	Economy	33700.00
0005432390365	18260	Economy	33700.00
0005432390356	18260	Economy	33700.00
0005432390363	18260	Economy	33700.00
0005432392052	18260	Economy	33700.00
0005432390323	18260	Economy	33700.00
0005432392066	18260	Economy	33700.00
0005432390387	18260	Economy	33700.00
0005432390416	18260	Economy	33700.00
0005432390316	18260	Economy	33700.00
0005432390367	18260	Economy	33700.00
0005432390322	18260	Economy	33700.00
0005432390427	18260	Economy	33700.00
0005432852102	18260	Economy	33700.00
0005432390350	18260	Economy	33700.00
0005432392054	18260	Economy	33700.00
0005432852096	18260	Economy	33700.00
0005432390274	18260	Economy	33700.00
0005432390407	18260	Economy	33700.00
0005432852103	18260	Economy	33700.00
0005432852098	18260	Economy	33700.00
0005432390412	18260	Economy	33700.00
0005432390422	18260	Economy	33700.00
0005432390380	18260	Economy	33700.00
0005432390382	18260	Economy	33700.00
0005432390392	18260	Economy	33700.00
0005432390415	18260	Economy	33700.00
0005432392061	18260	Economy	33700.00
0005432852095	18260	Economy	33700.00
0005432852097	18260	Economy	33700.00
0005432390396	18260	Economy	33700.00
0005432390370	18260	Economy	33700.00
0005432390428	18260	Economy	33700.00
0005432390273	18260	Economy	33700.00
0005432390361	18260	Economy	33700.00
0005432390417	18260	Economy	33700.00
0005432392053	18260	Economy	33700.00
0005432390397	18260	Economy	33700.00
0005432852093	18260	Economy	33700.00
0005432390413	18260	Economy	33700.00
0005432852094	18260	Economy	33700.00
0005432390411	18260	Economy	33700.00
0005432392065	18260	Economy	33700.00
0005434082398	12807	Business	40300.00
0005434069249	12807	Business	40300.00
0005434068982	12807	Business	40300.00
0005434069154	12807	Business	40300.00
0005434082535	12807	Business	40300.00
0005435860640	12807	Business	40300.00
0005434069328	12807	Business	40300.00
0005434069475	12807	Business	40300.00
0005434069373	12807	Business	40300.00
0005434069244	12807	Business	40300.00
0005433989878	12807	Business	40300.00
0005434082495	12807	Business	40300.00
0005434069218	12807	Economy	13400.00
0005434069291	12807	Economy	13400.00
0005435283550	12807	Economy	13400.00
0005434082425	12807	Economy	13400.00
0005434069231	12807	Economy	13400.00
0005434082359	12807	Economy	13400.00
0005434069123	12807	Economy	13400.00
0005434068820	12807	Economy	13400.00
0005434082366	12807	Economy	13400.00
0005435283545	12807	Economy	13400.00
0005435283551	12807	Economy	13400.00
0005434069374	12807	Economy	13400.00
0005434068898	12807	Economy	13400.00
0005434069290	12807	Economy	13400.00
0005434069545	12807	Economy	13400.00
0005434069186	12807	Economy	13400.00
0005434069143	12807	Economy	13400.00
0005434068981	12807	Economy	13400.00
0005434069204	12807	Economy	13400.00
0005434069197	12807	Economy	13400.00
0005434068894	12807	Economy	13400.00
0005433989886	12807	Economy	13400.00
0005434069247	12807	Economy	13400.00
0005434069039	12807	Economy	13400.00
0005434069152	12807	Economy	13400.00
0005434069355	12807	Economy	13400.00
0005434069286	12807	Economy	13400.00
0005434069066	12807	Economy	13400.00
0005433812968	12807	Economy	13400.00
0005434068938	12807	Economy	13400.00
0005434082353	12807	Economy	13400.00
0005434069193	12807	Economy	13400.00
0005435860639	12807	Economy	13400.00
0005434069096	12807	Economy	13400.00
0005434069142	12807	Economy	13400.00
0005434068712	12807	Economy	14800.00
0005434068865	12807	Economy	14800.00
0005434069153	12807	Economy	14800.00
0005434069098	12807	Economy	14800.00
0005434068906	12807	Economy	14800.00
0005434069158	12807	Economy	13400.00
0005434082518	12807	Economy	13400.00
0005434082441	12807	Economy	13400.00
0005434082456	12807	Economy	13400.00
0005434069172	12807	Economy	13400.00
0005434069032	12807	Economy	13400.00
0005434082423	12807	Economy	13400.00
0005434082360	12807	Economy	13400.00
0005434069372	12807	Economy	13400.00
0005434069029	12807	Economy	13400.00
0005434082483	12807	Economy	13400.00
0005434069223	12807	Economy	13400.00
0005434069338	12807	Economy	13400.00
0005434068907	12807	Economy	13400.00
0005435283549	12807	Economy	13400.00
0005434069261	12807	Economy	13400.00
0005434069219	12807	Economy	13400.00
0005434068852	12807	Economy	13400.00
0005434082361	12807	Economy	13400.00
0005434068908	12807	Economy	13400.00
0005434069481	12807	Economy	13400.00
0005434069482	12807	Economy	13400.00
0005434069356	12807	Economy	13400.00
0005434069388	12807	Economy	13400.00
0005434082363	12807	Economy	13400.00
0005434068940	12807	Economy	13400.00
0005434068909	12807	Economy	13400.00
0005434069097	12807	Economy	13400.00
0005435283546	12807	Economy	13400.00
0005434069183	12807	Economy	13400.00
0005434069165	12807	Economy	13400.00
0005434069194	12807	Economy	13400.00
0005434069195	12807	Economy	13400.00
0005435283547	12807	Economy	13400.00
0005434082339	12807	Economy	13400.00
0005434069412	12807	Economy	13400.00
0005434082424	12807	Economy	13400.00
0005434069213	12807	Economy	13400.00
0005434069314	12807	Economy	13400.00
0005435283544	12807	Economy	13400.00
0005434068711	12807	Economy	13400.00
0005433989879	12807	Economy	13400.00
0005434069411	12807	Economy	13400.00
0005434069052	12807	Economy	13400.00
0005434069248	12807	Economy	13400.00
0005434069159	12807	Economy	13400.00
0005433989867	12807	Economy	13400.00
0005434069171	12807	Economy	13400.00
0005434082381	12807	Economy	13400.00
0005434069313	12807	Economy	13400.00
0005434082517	12807	Economy	13400.00
0005434068949	12807	Economy	13400.00
0005435283548	12807	Economy	13400.00
0005434069185	12807	Economy	13400.00
0005434082446	12807	Economy	13400.00
0005434069220	12807	Economy	13400.00
0005434082397	12807	Economy	13400.00
0005434069026	12807	Economy	13400.00
0005434068939	12807	Economy	13400.00
0005434069293	12807	Economy	13400.00
0005434082500	12807	Economy	13400.00
0005434069067	12807	Economy	13400.00
0005434069053	12807	Economy	13400.00
0005434069464	12807	Economy	13400.00
0005434069160	12807	Economy	13400.00
0005434069339	12807	Economy	13400.00
0005434069124	12807	Economy	13400.00
0005435283455	30687	Business	40300.00
0005434069631	30687	Business	40300.00
0005435283453	30687	Business	40300.00
0005434069628	30687	Business	40300.00
0005435283438	30687	Business	40300.00
0005432433826	30687	Economy	13400.00
0005435283433	30687	Economy	13400.00
0005434082635	30687	Economy	13400.00
0005434069630	30687	Economy	13400.00
0005432433808	30687	Economy	13400.00
0005434069626	30687	Economy	13400.00
0005434069632	30687	Economy	13400.00
0005432150426	30687	Economy	13400.00
0005432433804	30687	Economy	14800.00
0005434069627	30687	Economy	14800.00
0005435283440	30687	Economy	14800.00
0005432433809	30687	Economy	13400.00
0005432150425	30687	Economy	13400.00
0005434082639	30687	Economy	13400.00
0005434082634	30687	Economy	13400.00
0005432433833	30687	Economy	13400.00
0005435283439	30687	Economy	13400.00
0005434082637	30687	Economy	13400.00
0005434069633	30687	Economy	13400.00
0005433989904	30687	Economy	13400.00
0005433989906	30687	Economy	13400.00
0005435283444	30687	Economy	13400.00
0005435283454	30687	Economy	13400.00
0005434082638	30687	Economy	13400.00
0005434082636	30687	Economy	13400.00
0005435283515	30687	Economy	13400.00
0005432433810	30687	Economy	13400.00
0005433989905	30687	Economy	13400.00
0005434069629	30687	Economy	13400.00
0005432433803	30687	Economy	13400.00
0005433689956	19353	Economy	17600.00
0005433689962	19353	Economy	17600.00
0005433686684	19353	Economy	17600.00
0005433686676	19353	Economy	17600.00
0005433689945	19353	Economy	17600.00
0005433689952	19353	Economy	17600.00
0005433689957	19353	Economy	17600.00
0005433689958	19353	Economy	17600.00
0005433686669	19353	Economy	17600.00
0005433689955	19353	Economy	17600.00
0005433686683	19353	Economy	17600.00
0005433689951	19353	Economy	17600.00
0005433686677	19353	Economy	17600.00
0005433689954	19353	Economy	17600.00
0005433686682	19353	Economy	17600.00
0005434265692	5506	Business	35300.00
0005434831256	5506	Business	35300.00
0005435463261	5506	Business	35300.00
0005435463451	5506	Business	35300.00
0005435463303	5506	Business	35300.00
0005435463368	5506	Business	35300.00
0005435768122	5506	Business	35300.00
0005435463352	5506	Business	35300.00
0005434265834	5506	Business	35300.00
0005435463440	5506	Business	35300.00
0005435463310	5506	Business	35300.00
0005434831261	5506	Business	35300.00
0005435732736	5506	Business	35300.00
0005434265719	5506	Business	35300.00
0005435732733	5506	Business	35300.00
0005434265746	5506	Economy	12900.00
0005434831248	5506	Economy	12900.00
0005434265755	5506	Economy	11800.00
0005434265800	5506	Economy	11800.00
0005435463416	5506	Economy	11800.00
0005435463396	5506	Economy	11800.00
0005435463311	5506	Economy	11800.00
0005435463221	5506	Economy	11800.00
0005434265785	5506	Economy	11800.00
0005435732731	5506	Economy	11800.00
0005435463243	5506	Economy	11800.00
0005435043300	5506	Economy	11800.00
0005435463271	5506	Economy	11800.00
0005434831266	5506	Economy	11800.00
0005435768083	5506	Economy	11800.00
0005435463177	5506	Economy	11800.00
0005434265815	5506	Economy	11800.00
0005435463351	5506	Economy	11800.00
0005434265754	5506	Economy	11800.00
0005435735283	5506	Economy	11800.00
0005435768085	5506	Economy	11800.00
0005433529390	5506	Economy	11800.00
0005435463472	5506	Economy	11800.00
0005435043301	5506	Economy	11800.00
0005435768091	5506	Economy	11800.00
0005434265753	5506	Economy	11800.00
0005434265737	5506	Economy	11800.00
0005434265642	5506	Economy	11800.00
0005432140690	5506	Economy	11800.00
0005435768087	5506	Economy	11800.00
0005432140689	5506	Economy	11800.00
0005434831263	5506	Economy	11800.00
0005435723106	5506	Economy	11800.00
0005435463302	5506	Economy	11800.00
0005435463394	5506	Economy	11800.00
0005434265772	5506	Economy	11800.00
0005435463338	5506	Economy	11800.00
0005435735278	5506	Economy	11800.00
0005434831265	5506	Economy	11800.00
0005435463309	5506	Economy	11800.00
0005434265799	5506	Economy	11800.00
0005435463238	5506	Economy	12900.00
0005434265720	5506	Economy	11800.00
0005435617178	5506	Economy	11800.00
0005435463258	5506	Economy	11800.00
0005434265693	5506	Economy	11800.00
0005435463339	5506	Economy	11800.00
0005435617179	5506	Economy	11800.00
0005435768086	5506	Economy	11800.00
0005434265773	5506	Economy	11800.00
0005435463331	5506	Economy	11800.00
0005435463232	5506	Economy	11800.00
0005435768084	5506	Economy	11800.00
0005434265691	5506	Economy	11800.00
0005435463364	5506	Economy	11800.00
0005434265801	5506	Economy	11800.00
0005435463369	5506	Economy	11800.00
0005435463393	5506	Economy	11800.00
0005434831267	5506	Economy	11800.00
0005435732734	5506	Economy	11800.00
0005435732732	5506	Economy	11800.00
0005434831236	5506	Economy	11800.00
0005435463452	5506	Economy	11800.00
0005435732737	5506	Economy	11800.00
0005435768089	5506	Economy	11800.00
0005435463360	5506	Economy	11800.00
0005435463341	5506	Economy	11800.00
0005435043299	5506	Economy	11800.00
0005435463340	5506	Economy	11800.00
0005432535947	5506	Economy	11800.00
0005435463426	5506	Economy	11800.00
0005435768082	5506	Economy	11800.00
0005435463359	5506	Economy	11800.00
0005434265824	5506	Economy	11800.00
0005435768088	5506	Economy	11800.00
0005435463244	5506	Economy	11800.00
0005435768090	5506	Economy	11800.00
0005435732735	5506	Economy	11800.00
0005435463298	5506	Economy	11800.00
0005435463531	13481	Business	35300.00
0005435767837	13481	Business	35300.00
0005435767476	13481	Business	35300.00
0005435767586	13481	Business	35300.00
0005435767875	13481	Business	35300.00
0005435767833	13481	Business	35300.00
0005435767774	13481	Business	35300.00
0005435735265	13481	Business	35300.00
0005435735259	13481	Business	35300.00
0005435723092	13481	Business	35300.00
0005435735247	13481	Business	35300.00
0005435767596	13481	Economy	11800.00
0005435767368	13481	Economy	11800.00
0005435735257	13481	Economy	11800.00
0005434265895	13481	Economy	11800.00
0005435767709	13481	Economy	11800.00
0005435767715	13481	Economy	11800.00
0005435767968	13481	Economy	11800.00
0005435767367	13481	Economy	11800.00
0005435767691	13481	Economy	11800.00
0005435767895	13481	Economy	11800.00
0005435767674	13481	Economy	11800.00
0005435767520	13481	Economy	11800.00
0005435767724	13481	Economy	11800.00
0005435767723	13481	Economy	11800.00
0005435767707	13481	Economy	11800.00
0005435767517	13481	Economy	11800.00
0005435723083	13481	Economy	11800.00
0005434265894	13481	Economy	11800.00
0005435767593	13481	Economy	11800.00
0005435767760	13481	Economy	11800.00
0005435767980	13481	Economy	11800.00
0005435768106	13481	Economy	11800.00
0005435767532	13481	Economy	11800.00
0005435768109	13481	Economy	11800.00
0005435767524	13481	Economy	11800.00
0005435767608	13481	Economy	11800.00
0005435768110	13481	Economy	11800.00
0005435767592	13481	Economy	11800.00
0005435725721	13481	Economy	11800.00
0005435767477	13481	Economy	11800.00
0005435767531	13481	Economy	11800.00
0005435767597	13481	Economy	11800.00
0005435767381	13481	Economy	11800.00
0005435767607	13481	Economy	11800.00
0005435735235	13481	Economy	11800.00
0005435463528	13481	Economy	11800.00
0005435767979	13481	Economy	11800.00
0005435767657	13481	Economy	11800.00
0005435767407	13481	Economy	12900.00
0005435735246	13481	Economy	11800.00
0005435767655	13481	Economy	11800.00
0005435767610	13481	Economy	11800.00
0005434265897	13481	Economy	11800.00
0005435463529	13481	Economy	11800.00
0005435767725	13481	Economy	11800.00
0005435725703	13481	Economy	11800.00
0005435463530	13481	Economy	11800.00
0005435767595	13481	Economy	11800.00
0005435767624	13481	Economy	11800.00
0005435767583	13481	Economy	11800.00
0005435767894	13481	Economy	11800.00
0005435722111	13481	Economy	11800.00
0005434265896	13481	Economy	11800.00
0005435767605	13481	Economy	11800.00
0005435767731	13481	Economy	11800.00
0005435735244	13481	Economy	11800.00
0005435767820	13481	Economy	11800.00
0005435767682	13481	Economy	11800.00
0005435767759	13481	Economy	11800.00
0005435725730	13481	Economy	11800.00
0005435767836	13481	Economy	11800.00
0005435767708	13481	Economy	11800.00
0005435767819	13481	Economy	11800.00
0005435767525	13481	Economy	11800.00
0005435767775	13481	Economy	11800.00
0005435767675	13481	Economy	11800.00
0005435767732	13481	Economy	11800.00
0005435735264	13481	Economy	11800.00
0005435767690	13481	Economy	11800.00
0005435767824	13481	Economy	11800.00
0005435767676	13481	Economy	11800.00
0005434602955	18647	Economy	3300.00
0005434602954	18647	Economy	3300.00
0005434604966	18649	Economy	3300.00
0005434513661	18649	Economy	3300.00
0005434604977	18649	Economy	3300.00
0005434604996	18649	Economy	3300.00
0005434604978	18649	Economy	3300.00
0005434515046	18649	Economy	3300.00
0005434604993	18649	Economy	3300.00
0005434515027	19208	Economy	3300.00
0005434602980	19208	Economy	3300.00
0005434602979	19208	Economy	3300.00
0005434602981	19208	Economy	3300.00
0005434603026	19208	Economy	3300.00
0005434602978	19208	Economy	3300.00
0005434515030	19208	Economy	3300.00
0005434515026	19208	Economy	3300.00
0005434602982	19208	Economy	3300.00
0005434603027	19208	Economy	3300.00
0005432632874	25101	Business	88300.00
0005432632881	25101	Business	88300.00
0005435846361	25101	Business	88300.00
0005432632891	25101	Business	88300.00
0005432649548	25101	Business	88300.00
0005435844439	25101	Business	88300.00
0005432632863	25101	Business	88300.00
0005432632894	25101	Economy	29400.00
0005432632867	25101	Economy	29400.00
0005432649565	25101	Economy	29400.00
0005432632896	25101	Economy	29400.00
0005435844436	25101	Economy	32400.00
0005432649555	25101	Economy	32400.00
0005432632878	25101	Economy	29400.00
0005435846360	25101	Economy	29400.00
0005435844442	25101	Economy	29400.00
0005432632885	25101	Economy	29400.00
0005432649531	25101	Economy	29400.00
0005435846359	25101	Economy	29400.00
0005432649566	25101	Economy	29400.00
0005432632877	25101	Economy	29400.00
0005432632899	25101	Economy	29400.00
0005432649561	25101	Economy	29400.00
0005432632892	25101	Economy	29400.00
0005432649542	25101	Economy	29400.00
0005432632882	25101	Economy	29400.00
0005432649562	25101	Economy	29400.00
0005435844438	25101	Economy	29400.00
0005432632868	25101	Economy	29400.00
0005435844440	25101	Economy	29400.00
0005432649543	25101	Economy	29400.00
0005432649549	25101	Economy	29400.00
0005432649556	25101	Economy	29400.00
0005435844437	25101	Economy	29400.00
0005432649554	25101	Economy	29400.00
0005435844441	25101	Economy	29400.00
0005432649536	25101	Economy	29400.00
0005432632898	25101	Economy	29400.00
0005432632897	25101	Economy	29400.00
0005432649563	25101	Economy	29400.00
0005435846362	25101	Economy	29400.00
0005432649553	25101	Economy	29400.00
0005432632923	25101	Economy	29400.00
0005432632866	25101	Economy	29400.00
0005432649564	25101	Economy	29400.00
0005432632875	25101	Economy	29400.00
0005433286053	1822	Business	48700.00
0005433009518	1822	Business	48700.00
0005433009563	1822	Business	48700.00
0005433009637	1822	Business	48700.00
0005435097509	1822	Business	48700.00
0005433286084	1822	Business	48700.00
0005433810806	1822	Business	48700.00
0005435097520	1822	Business	48700.00
0005435097519	1822	Business	48700.00
0005433009687	1822	Business	48700.00
0005433810802	1822	Business	48700.00
0005433009572	1822	Business	48700.00
0005433009819	1822	Economy	16200.00
0005435097516	1822	Economy	16200.00
0005433810801	1822	Economy	16200.00
0005433009728	1822	Economy	16200.00
0005435097515	1822	Economy	16200.00
0005433286026	1822	Economy	16200.00
0005433009729	1822	Economy	16200.00
0005433286050	1822	Economy	16200.00
0005433286093	1822	Economy	16200.00
0005433810805	1822	Economy	16200.00
0005433286088	1822	Economy	17900.00
0005433009769	1822	Economy	17900.00
0005433009791	1822	Economy	17900.00
0005433286087	1822	Economy	17900.00
0005433009798	1822	Economy	17900.00
0005435097514	1822	Economy	16200.00
0005433009644	1822	Economy	16200.00
0005433009875	1822	Economy	16200.00
0005435097517	1822	Economy	16200.00
0005433009877	1822	Economy	16200.00
0005435097512	1822	Economy	16200.00
0005433009626	1822	Economy	16200.00
0005435097510	1822	Economy	16200.00
0005433009790	1822	Economy	16200.00
0005433009813	1822	Economy	16200.00
0005433009517	1822	Economy	16200.00
0005433009669	1822	Economy	16200.00
0005433009766	1822	Economy	16200.00
0005433009634	1822	Economy	16200.00
0005433009633	1822	Economy	16200.00
0005433285988	1822	Economy	16200.00
0005433009645	1822	Economy	16200.00
0005433286039	1822	Economy	16200.00
0005433810796	1822	Economy	16200.00
0005433286083	1822	Economy	16200.00
0005433285961	1822	Economy	16200.00
0005433009865	1822	Economy	16200.00
0005433286133	1822	Economy	16200.00
0005433009564	1822	Economy	16200.00
0005433286046	1822	Economy	16200.00
0005433286038	1822	Economy	16200.00
0005433009811	1822	Economy	16200.00
0005433810803	1822	Economy	16200.00
0005433810795	1822	Economy	16200.00
0005435097513	1822	Economy	16200.00
0005433810793	1822	Economy	16200.00
0005433009818	1822	Economy	16200.00
0005433009820	1822	Economy	16200.00
0005435097518	1822	Economy	16200.00
0005433009670	1822	Economy	16200.00
0005433286058	1822	Economy	16200.00
0005433810797	1822	Economy	16200.00
0005433285994	1822	Economy	16200.00
0005433810799	1822	Economy	16200.00
0005433009632	1822	Economy	16200.00
0005433009686	1822	Economy	16200.00
0005433009694	1822	Economy	16200.00
0005433810798	1822	Economy	16200.00
0005433286092	1822	Economy	16200.00
0005435097511	1822	Economy	16200.00
0005433286107	1822	Economy	16200.00
0005435097508	1822	Economy	16200.00
0005433286025	1822	Economy	16200.00
0005433810800	1822	Economy	16200.00
0005433286134	1822	Economy	16200.00
0005433009774	1822	Economy	16200.00
0005433009746	1822	Economy	16200.00
0005433286069	1822	Economy	16200.00
0005433009754	1822	Economy	16200.00
0005433009802	1822	Economy	16200.00
0005433285928	1822	Economy	16200.00
0005433286068	1822	Economy	16200.00
0005433286120	1822	Economy	16200.00
0005433009688	1822	Economy	16200.00
0005433286127	1822	Economy	16200.00
0005433810804	1822	Economy	16200.00
0005433009767	1822	Economy	16200.00
0005433009693	1822	Economy	16200.00
0005433009555	1822	Economy	16200.00
0005435097522	1822	Economy	16200.00
0005433810794	1822	Economy	16200.00
0005432295960	1822	Economy	16200.00
0005433009675	1822	Economy	16200.00
0005433009840	1822	Economy	16200.00
0005435097521	1822	Economy	16200.00
0005433009964	22518	Business	48700.00
0005433286214	22518	Business	48700.00
0005433286222	22518	Business	48700.00
0005433810662	22518	Business	48700.00
0005433286223	22518	Business	48700.00
0005433286219	22518	Business	48700.00
0005433009965	22518	Business	48700.00
0005433286215	22518	Economy	16200.00
0005433286220	22518	Economy	16200.00
0005433810658	22518	Economy	16200.00
0005433009966	22518	Economy	16200.00
0005433810669	22518	Economy	17900.00
0005433009958	22518	Economy	17900.00
0005433009961	22518	Economy	16200.00
0005433009962	22518	Economy	16200.00
0005433009963	22518	Economy	16200.00
0005433810668	22518	Economy	16200.00
0005433009960	22518	Economy	16200.00
0005433286218	22518	Economy	16200.00
0005433009968	22518	Economy	16200.00
0005433810634	22518	Economy	16200.00
0005433286217	22518	Economy	16200.00
0005433009959	22518	Economy	16200.00
0005433286221	22518	Economy	16200.00
0005433286216	22518	Economy	16200.00
0005433810661	22518	Economy	16200.00
0005433009967	22518	Economy	16200.00
0005433810633	22518	Economy	16200.00
0005433810644	22518	Economy	16200.00
0005432756937	25340	Business	83800.00
0005434152827	25340	Business	83800.00
0005432755168	25340	Business	83800.00
0005434153554	25340	Economy	27900.00
0005434153559	25340	Economy	27900.00
0005434152825	25340	Economy	27900.00
0005432755169	25340	Economy	30700.00
0005432756939	25340	Economy	30700.00
0005432756936	25340	Economy	30700.00
0005432755171	25340	Economy	27900.00
0005432756940	25340	Economy	27900.00
0005432756938	25340	Economy	27900.00
0005434153573	25340	Economy	27900.00
0005432755172	25340	Economy	27900.00
0005434153570	25340	Economy	27900.00
0005432755173	25340	Economy	27900.00
0005434152829	25340	Economy	27900.00
0005432756941	25340	Economy	27900.00
0005432756942	25340	Economy	27900.00
0005434152826	25340	Economy	27900.00
0005434152830	25340	Economy	27900.00
0005434152828	25340	Economy	27900.00
0005432755170	25340	Economy	27900.00
0005434152831	25340	Economy	27900.00
0005434152832	25340	Economy	27900.00
0005435283118	5560	Business	99800.00
0005435283142	5560	Business	99800.00
0005433848407	5560	Business	99800.00
0005434173597	5560	Business	99800.00
0005432081698	5560	Business	99800.00
0005433848405	5560	Business	99800.00
0005435282963	5560	Economy	33300.00
0005432081697	5560	Economy	33300.00
0005435283159	5560	Economy	33300.00
0005434173608	5560	Economy	33300.00
0005435283119	5560	Economy	33300.00
0005435283162	5560	Economy	36600.00
0005435283091	5560	Economy	33300.00
0005435283160	5560	Economy	33300.00
0005435283047	5560	Economy	33300.00
0005433848408	5560	Economy	33300.00
0005435283088	5560	Economy	33300.00
0005435283109	5560	Economy	33300.00
0005434173607	5560	Economy	33300.00
0005433848406	5560	Economy	33300.00
0005435283065	5560	Economy	33300.00
0005435283029	5560	Economy	33300.00
0005435283093	5560	Economy	33300.00
0005434173594	5560	Economy	33300.00
0005435283092	5560	Economy	33300.00
0005435283050	5560	Economy	33300.00
0005435282976	5560	Economy	33300.00
0005435283161	5560	Economy	33300.00
0005435283115	5560	Economy	33300.00
0005435283090	5560	Economy	33300.00
0005435283028	5560	Economy	33300.00
0005435283066	5560	Economy	33300.00
0005435283039	5560	Economy	33300.00
0005434173595	5560	Economy	33300.00
0005434173613	5560	Economy	33300.00
0005434173596	5560	Economy	33300.00
0005435283110	5560	Economy	33300.00
0005435283151	5560	Economy	33300.00
0005435283048	5560	Economy	33300.00
0005435283094	5560	Economy	33300.00
0005433848151	13848	Business	99800.00
0005433848005	13848	Business	99800.00
0005433848022	13848	Business	99800.00
0005433847879	13848	Business	99800.00
0005433815512	13848	Business	99800.00
0005433848203	13848	Business	99800.00
0005433848128	13848	Business	99800.00
0005433815487	13848	Business	99800.00
0005433848130	13848	Business	99800.00
0005433847957	13848	Business	99800.00
0005433848058	13848	Economy	33300.00
0005433815486	13848	Economy	33300.00
0005433847834	13848	Economy	33300.00
0005433815496	13848	Economy	33300.00
0005433848060	13848	Economy	33300.00
0005433848100	13848	Economy	33300.00
0005433848052	13848	Economy	36600.00
0005433848213	13848	Economy	36600.00
0005433848172	13848	Economy	36600.00
0005433848261	13848	Economy	33300.00
0005435283250	13848	Economy	33300.00
0005433848175	13848	Economy	33300.00
0005433848099	13848	Economy	33300.00
0005433815498	13848	Economy	33300.00
0005433848174	13848	Economy	33300.00
0005433848097	13848	Economy	33300.00
0005433848057	13848	Economy	33300.00
0005433848209	13848	Economy	33300.00
0005433848211	13848	Economy	33300.00
0005433848061	13848	Economy	33300.00
0005433848168	13848	Economy	33300.00
0005433847811	13848	Economy	33300.00
0005433847833	13848	Economy	33300.00
0005433848243	13848	Economy	33300.00
0005433848068	13848	Economy	33300.00
0005433847933	13848	Economy	33300.00
0005433847956	13848	Economy	33300.00
0005433848098	13848	Economy	33300.00
0005433848260	13848	Economy	33300.00
0005433848003	13848	Economy	33300.00
0005433815490	13848	Economy	33300.00
0005433848113	13848	Economy	33300.00
0005433848176	13848	Economy	33300.00
0005433848212	13848	Economy	33300.00
0005433848208	13848	Economy	33300.00
0005433848085	13848	Economy	33300.00
0005433848184	13848	Economy	33300.00
0005433848006	13848	Economy	33300.00
0005433815497	13848	Economy	33300.00
0005433848129	13848	Economy	33300.00
0005433847878	13848	Economy	33300.00
0005433848173	13848	Economy	33300.00
0005435332545	7801	Economy	16600.00
0005435332585	7801	Economy	16600.00
0005434621181	7801	Economy	15100.00
0005435332614	7801	Economy	15100.00
0005435332558	7801	Economy	15100.00
0005435332604	7801	Economy	15100.00
0005435332602	7801	Economy	15100.00
0005435332569	7801	Economy	15100.00
0005435332590	7801	Economy	15100.00
0005435332570	7801	Economy	15100.00
0005435332603	7801	Economy	15100.00
0005435332609	7801	Economy	15100.00
0005435332544	7801	Economy	15100.00
0005435332617	7801	Economy	15100.00
0005434621098	32973	Economy	15100.00
0005434621094	32973	Economy	15100.00
0005434621074	32973	Economy	15100.00
0005434621116	32973	Economy	15100.00
0005434621141	32973	Economy	15100.00
0005434620972	32973	Economy	15100.00
0005434621106	32973	Economy	15100.00
0005434621054	32973	Economy	15100.00
0005434621112	32973	Economy	15100.00
0005434621055	32973	Economy	15100.00
0005434621050	32973	Economy	15100.00
0005434621111	32973	Economy	15100.00
0005434621140	32973	Economy	15100.00
0005434621089	32973	Economy	15100.00
0005434621049	32973	Economy	15100.00
0005435332642	32973	Economy	15100.00
0005434621093	32973	Economy	15100.00
0005434621117	32973	Economy	15100.00
0005434621097	32973	Economy	15100.00
0005434621070	32973	Economy	15100.00
0005434621082	32973	Economy	15100.00
0005434621095	32973	Economy	15100.00
0005435786363	4306	Business	38000.00
0005435937520	4306	Business	38000.00
0005435786361	4306	Business	38000.00
0005435918787	4306	Business	38000.00
0005435918776	4306	Business	38000.00
0005435937525	4306	Economy	12700.00
0005435786362	4306	Economy	12700.00
0005435918781	4306	Economy	13900.00
0005435786358	4306	Economy	13900.00
0005435786359	4306	Economy	13900.00
0005435918755	4306	Economy	12700.00
0005435918748	4306	Economy	12700.00
0005435937519	4306	Economy	12700.00
0005435937504	4306	Economy	12700.00
0005435918777	4306	Economy	12700.00
0005435918775	4306	Economy	12700.00
0005435918747	4306	Economy	12700.00
0005435937522	4306	Economy	12700.00
0005435918756	4306	Economy	12700.00
0005435918757	4306	Economy	12700.00
0005435786360	4306	Economy	12700.00
0005435787399	27323	Business	38000.00
0005435786026	27323	Business	38000.00
0005435786171	27323	Business	38000.00
0005435786172	27323	Business	38000.00
0005434994248	27323	Business	38000.00
0005435786091	27323	Business	38000.00
0005435786097	27323	Economy	12700.00
0005435786007	27323	Economy	12700.00
0005435785983	27323	Economy	12700.00
0005435786104	27323	Economy	12700.00
0005435786169	27323	Economy	13900.00
0005435785927	27323	Economy	13900.00
0005435786165	27323	Economy	13900.00
0005435787396	27323	Economy	13900.00
0005435786129	27323	Economy	12700.00
0005435787400	27323	Economy	12700.00
0005435918794	27323	Economy	12700.00
0005435786182	27323	Economy	12700.00
0005435785925	27323	Economy	12700.00
0005435787409	27323	Economy	12700.00
0005435785926	27323	Economy	12700.00
0005435786114	27323	Economy	12700.00
0005435786103	27323	Economy	12700.00
0005435786142	27323	Economy	12700.00
0005435786248	27323	Economy	12700.00
0005435787403	27323	Economy	12700.00
0005435786231	27323	Economy	12700.00
0005435786066	27323	Economy	12700.00
0005435786265	27323	Economy	12700.00
0005435786128	27323	Economy	12700.00
0005435786167	27323	Economy	12700.00
0005435918793	27323	Economy	12700.00
0005434994228	27323	Economy	12700.00
0005435786174	27323	Economy	12700.00
0005435786065	27323	Economy	12700.00
0005435786119	27323	Economy	12700.00
0005435786186	27323	Economy	12700.00
0005435787408	27323	Economy	12700.00
0005435786206	27323	Economy	12700.00
0005435786076	27323	Economy	12700.00
0005435786170	27323	Economy	12700.00
0005435785990	27323	Economy	12700.00
0005435786039	27323	Economy	12700.00
0005435786096	27323	Economy	12700.00
0005435786075	27323	Economy	12700.00
0005435787395	27323	Economy	12700.00
0005435937572	27323	Economy	12700.00
0005432569411	4711	Business	40900.00
0005435840447	4711	Business	40900.00
0005432571438	4711	Business	40900.00
0005432461426	4711	Business	40900.00
0005432461425	4711	Economy	15000.00
0005435840471	4711	Economy	15000.00
0005435840425	4711	Economy	13600.00
0005432461428	4711	Economy	13600.00
0005432461420	4711	Economy	13600.00
0005432569409	4711	Economy	13600.00
0005432569412	4711	Economy	13600.00
0005435840448	4711	Economy	13600.00
0005435840414	4711	Economy	13600.00
0005434082642	4711	Economy	13600.00
0005432461424	4711	Economy	13600.00
0005434082645	4711	Economy	13600.00
0005432569415	4711	Economy	13600.00
0005432461417	4711	Economy	13600.00
0005434150179	4711	Economy	13600.00
0005432461422	4711	Economy	13600.00
0005432569414	4711	Economy	13600.00
0005434082640	4711	Economy	13600.00
0005432170586	4711	Economy	13600.00
0005435840415	4711	Economy	13600.00
0005432461427	4711	Economy	13600.00
0005435840394	4711	Economy	13600.00
0005435840402	4711	Economy	13600.00
0005432461419	4711	Economy	13600.00
0005432569410	4711	Economy	13600.00
0005432569413	4711	Economy	13600.00
0005434082644	4711	Economy	13600.00
0005435840393	4711	Economy	13600.00
0005434082646	4711	Economy	13600.00
0005432461423	4711	Economy	13600.00
0005432569408	4711	Economy	13600.00
0005432461418	4711	Economy	13600.00
0005432461421	4711	Economy	13600.00
0005434082643	4711	Economy	13600.00
0005434082641	4711	Economy	13600.00
0005432461429	4711	Economy	13600.00
0005432569166	30552	Business	40900.00
0005433454919	30552	Business	40900.00
0005432569171	30552	Business	40900.00
0005432569044	30552	Business	40900.00
0005432569168	30552	Business	40900.00
0005432461195	30552	Business	40900.00
0005432569146	30552	Business	40900.00
0005434082441	30552	Business	40900.00
0005432569036	30552	Business	40900.00
0005432569095	30552	Business	40900.00
0005432569187	30552	Business	40900.00
0005432461280	30552	Business	40900.00
0005432569020	30552	Business	40900.00
0005432569308	30552	Business	40900.00
0005434082361	30552	Business	40900.00
0005432460982	30552	Business	40900.00
0005432461267	30552	Business	40900.00
0005432461054	30552	Business	40900.00
0005432571415	30552	Economy	15000.00
0005432461281	30552	Economy	15000.00
0005432569195	30552	Economy	15000.00
0005432569300	30552	Economy	13600.00
0005434082359	30552	Economy	13600.00
0005432461124	30552	Economy	13600.00
0005432461024	30552	Economy	13600.00
0005435860640	30552	Economy	13600.00
0005432569007	30552	Economy	13600.00
0005435860639	30552	Economy	13600.00
0005434082424	30552	Economy	13600.00
0005432568867	30552	Economy	13600.00
0005432461031	30552	Economy	13600.00
0005432569094	30552	Economy	13600.00
0005434082360	30552	Economy	13600.00
0005432569106	30552	Economy	13600.00
0005432461282	30552	Economy	13600.00
0005434082398	30552	Economy	13600.00
0005432461193	30552	Economy	13600.00
0005435840532	30552	Economy	13600.00
0005432461119	30552	Economy	13600.00
0005432569149	30552	Economy	13600.00
0005432569215	30552	Economy	13600.00
0005432461120	30552	Economy	13600.00
0005432213709	30552	Economy	13600.00
0005432461257	30552	Economy	13600.00
0005432568957	30552	Economy	13600.00
0005432461377	30552	Economy	13600.00
0005432569228	30552	Economy	13600.00
0005432568919	30552	Economy	13600.00
0005434082535	30552	Economy	13600.00
0005432461227	30552	Economy	13600.00
0005432569226	30552	Economy	13600.00
0005432571404	30552	Economy	13600.00
0005434082456	30552	Economy	13600.00
0005432461134	30552	Economy	13600.00
0005432461192	30552	Economy	13600.00
0005432569273	30552	Economy	13600.00
0005432461155	30552	Economy	13600.00
0005432461316	30552	Economy	13600.00
0005432568991	30552	Economy	13600.00
0005434082425	30552	Economy	13600.00
0005432461254	30552	Economy	13600.00
0005432461264	30552	Economy	13600.00
0005432461256	30552	Economy	13600.00
0005432571408	30552	Economy	13600.00
0005432569323	30552	Economy	13600.00
0005432568958	30552	Economy	13600.00
0005432568959	30552	Economy	13600.00
0005432569135	30552	Economy	13600.00
0005434150234	30552	Economy	13600.00
0005432569169	30552	Economy	13600.00
0005432569019	30552	Economy	13600.00
0005432569216	30552	Economy	13600.00
0005432461022	30552	Economy	13600.00
0005432461378	30552	Economy	13600.00
0005435840533	30552	Economy	13600.00
0005434150230	30552	Economy	13600.00
0005432461239	30552	Economy	13600.00
0005432461096	30552	Economy	13600.00
0005432569134	30552	Economy	13600.00
0005434082423	30552	Economy	13600.00
0005432569210	30552	Economy	13600.00
0005432461122	30552	Economy	13600.00
0005432569066	30552	Economy	13600.00
0005432461240	30552	Economy	13600.00
0005432460981	30552	Economy	13600.00
0005432461217	30552	Economy	13600.00
0005432571416	30552	Economy	13600.00
0005432461253	30552	Economy	13600.00
0005432569191	30552	Economy	13600.00
0005434082518	30552	Economy	13600.00
0005434082500	30552	Economy	13600.00
0005432569227	30552	Economy	15000.00
0005432569250	30552	Economy	13600.00
0005432571405	30552	Economy	13600.00
0005432569133	30552	Economy	13600.00
0005432461081	30552	Economy	15000.00
0005432569275	30552	Economy	13600.00
0005432461053	30552	Economy	13600.00
0005432460923	30552	Economy	13600.00
0005432569236	30552	Economy	13600.00
0005432461075	30552	Economy	13600.00
0005434082366	30552	Economy	13600.00
0005434082446	30552	Economy	13600.00
0005432569015	30552	Economy	13600.00
0005432569147	30552	Economy	13600.00
0005432569237	30552	Economy	13600.00
0005432569262	30552	Economy	13600.00
0005432569148	30552	Economy	13600.00
0005432461196	30552	Economy	13600.00
0005432569249	30552	Economy	13600.00
0005432569307	30552	Economy	13600.00
0005434082381	30552	Economy	13600.00
0005432461135	30552	Economy	13600.00
0005432569170	30552	Economy	13600.00
0005434150231	30552	Economy	13600.00
0005432569189	30552	Economy	13600.00
0005434082495	30552	Economy	13600.00
0005434082363	30552	Economy	13600.00
0005432569235	30552	Economy	13600.00
0005432461172	30552	Economy	13600.00
0005432569253	30552	Economy	13600.00
0005432461379	30552	Economy	13600.00
0005432569104	30552	Economy	13600.00
0005433454920	30552	Economy	13600.00
0005432460884	30552	Economy	13600.00
0005432461050	30552	Economy	13600.00
0005432461041	30552	Economy	13600.00
0005434082397	30552	Economy	13600.00
0005432569310	30552	Economy	13600.00
0005432461226	30552	Economy	13600.00
0005432569107	30552	Economy	13600.00
0005432568824	30552	Economy	13600.00
0005432461154	30552	Economy	13600.00
0005434082353	30552	Economy	13600.00
0005432569261	30552	Economy	13600.00
0005433452791	30552	Economy	13600.00
0005432568932	30552	Economy	13600.00
0005432461049	30552	Economy	13600.00
0005432569119	30552	Economy	13600.00
0005432569079	30552	Economy	13600.00
0005434082517	30552	Economy	13600.00
0005432569118	30552	Economy	13600.00
0005434150233	30552	Economy	13600.00
0005434082339	30552	Economy	13600.00
0005432571406	30552	Economy	13600.00
0005432569054	30552	Economy	13600.00
0005432461076	30552	Economy	13600.00
0005432569080	30552	Economy	13600.00
0005432461244	30552	Economy	13600.00
0005434150232	30552	Economy	13600.00
0005432568968	30552	Economy	13600.00
0005432461023	30552	Economy	13600.00
0005432569043	30552	Economy	13600.00
0005434082483	30552	Economy	13600.00
0005432461255	30552	Economy	13600.00
0005435722102	21177	Economy	9900.00
0005435722118	21177	Economy	9900.00
0005435722119	21177	Economy	9900.00
0005435722116	21177	Economy	9900.00
0005432295960	22771	Economy	8800.00
0005435508617	11088	Business	23600.00
0005435508693	11088	Business	23600.00
0005435508719	11088	Business	23600.00
0005435508722	11088	Business	23600.00
0005435530046	11088	Business	23600.00
0005435097498	11088	Business	23600.00
0005435097499	11088	Economy	7900.00
0005435097497	11088	Economy	7900.00
0005435530065	11088	Economy	7900.00
0005435545984	11088	Economy	7900.00
0005433346078	11088	Economy	7900.00
0005433346071	11088	Economy	7900.00
0005435508699	11088	Economy	7900.00
0005435508735	11088	Economy	7900.00
0005435508698	11088	Economy	7900.00
0005433346075	11088	Economy	7900.00
0005435508784	11088	Economy	7900.00
0005433346069	11088	Economy	7900.00
0005435530086	11088	Economy	8600.00
0005435508726	11088	Economy	7900.00
0005435508651	11088	Economy	7900.00
0005433346072	11088	Economy	7900.00
0005435530050	11088	Economy	7900.00
0005435530067	11088	Economy	7900.00
0005435530097	11088	Economy	7900.00
0005435508734	11088	Economy	7900.00
0005435508620	11088	Economy	7900.00
0005435508621	11088	Economy	7900.00
0005435508636	11088	Economy	7900.00
0005435530153	11088	Economy	7900.00
0005433346070	11088	Economy	7900.00
0005435530087	11088	Economy	7900.00
0005435530154	11088	Economy	7900.00
0005435508739	11088	Economy	7900.00
0005435508727	11088	Economy	7900.00
0005435380416	11088	Economy	7900.00
0005435530062	11088	Economy	7900.00
0005435530069	11088	Economy	7900.00
0005435380415	11088	Economy	7900.00
0005433346077	11088	Economy	7900.00
0005433346079	11088	Economy	7900.00
0005435508765	11088	Economy	7900.00
0005435508616	11088	Economy	7900.00
0005433346080	11088	Economy	7900.00
0005435530126	11088	Economy	7900.00
0005435097496	11088	Economy	7900.00
0005435508783	11088	Economy	7900.00
0005435508649	11088	Economy	7900.00
0005433346074	11088	Economy	7900.00
0005433346076	11088	Economy	7900.00
0005433346081	11088	Economy	7900.00
0005433346068	11088	Economy	7900.00
0005435508738	11088	Economy	7900.00
0005433346073	11088	Economy	7900.00
0005435545983	11088	Economy	7900.00
0005433345672	17105	Business	23600.00
0005433345635	17105	Business	23600.00
0005433344917	17105	Business	23600.00
0005433345466	17105	Business	23600.00
0005433345159	17105	Business	23600.00
0005433345555	17105	Business	23600.00
0005433345653	17105	Business	23600.00
0005433345496	17105	Business	23600.00
0005433345855	17105	Business	23600.00
0005433345151	17105	Business	23600.00
0005435380443	17105	Business	23600.00
0005433345812	17105	Business	23600.00
0005433345527	17105	Economy	7900.00
0005433345066	17105	Economy	7900.00
0005435545973	17105	Economy	7900.00
0005433345402	17105	Economy	7900.00
0005433345542	17105	Economy	7900.00
0005433344875	17105	Economy	7900.00
0005433345652	17105	Economy	7900.00
0005433345871	17105	Economy	7900.00
0005433345333	17105	Economy	7900.00
0005433345568	17105	Economy	7900.00
0005433345111	17105	Economy	7900.00
0005433345506	17105	Economy	7900.00
0005433345593	17105	Economy	7900.00
0005433345548	17105	Economy	7900.00
0005433345646	17105	Economy	7900.00
0005433345738	17105	Economy	7900.00
0005433345570	17105	Economy	7900.00
0005433345514	17105	Economy	7900.00
0005433345430	17105	Economy	7900.00
0005435546000	17105	Economy	7900.00
0005435545974	17105	Economy	7900.00
0005433345563	17105	Economy	7900.00
0005433345253	17105	Economy	7900.00
0005433345483	17105	Economy	7900.00
0005433345261	17105	Economy	7900.00
0005433345562	17105	Economy	7900.00
0005433345301	17105	Economy	7900.00
0005433345656	17105	Economy	7900.00
0005433345372	17105	Economy	7900.00
0005433345816	17105	Economy	7900.00
0005433345618	17105	Economy	7900.00
0005433345037	17105	Economy	7900.00
0005433345323	17105	Economy	7900.00
0005433345359	17105	Economy	7900.00
0005433345622	17105	Economy	7900.00
0005435097419	17105	Economy	7900.00
0005433344873	17105	Economy	8600.00
0005433345370	17105	Economy	8600.00
0005433345259	17105	Economy	8600.00
0005433345794	17105	Economy	8600.00
0005433345908	17105	Economy	8600.00
0005433344874	17105	Economy	7900.00
0005433345508	17105	Economy	7900.00
0005435545999	17105	Economy	7900.00
0005433345507	17105	Economy	7900.00
0005433345482	17105	Economy	7900.00
0005433345645	17105	Economy	7900.00
0005433345842	17105	Economy	7900.00
0005433345174	17105	Economy	7900.00
0005433345196	17105	Economy	7900.00
0005433345634	17105	Economy	7900.00
0005433345431	17105	Economy	7900.00
0005433345367	17105	Economy	7900.00
0005435545998	17105	Economy	7900.00
0005433345492	17105	Economy	7900.00
0005433345302	17105	Economy	7900.00
0005433345617	17105	Economy	7900.00
0005433345209	17105	Economy	7900.00
0005435097435	17105	Economy	7900.00
0005433345817	17105	Economy	7900.00
0005435097452	17105	Economy	7900.00
0005433345389	17105	Economy	7900.00
0005433345569	17105	Economy	7900.00
0005433345800	17105	Economy	7900.00
0005433345457	17105	Economy	7900.00
0005433345221	17105	Economy	7900.00
0005433345731	17105	Economy	7900.00
0005433345392	17105	Economy	7900.00
0005433345735	17105	Economy	7900.00
0005433345778	17105	Economy	7900.00
0005433345737	17105	Economy	7900.00
0005433345346	17105	Economy	7900.00
0005435380442	17105	Economy	7900.00
0005433345777	17105	Economy	7900.00
0005433345429	17105	Economy	7900.00
0005433345393	17105	Economy	7900.00
0005433345252	17105	Economy	7900.00
0005433344713	17105	Economy	7900.00
0005433345697	17105	Economy	7900.00
0005435546001	17105	Economy	7900.00
0005433345564	17105	Economy	7900.00
0005433345495	17105	Economy	7900.00
0005433345671	17105	Economy	7900.00
0005433345872	17105	Economy	7900.00
0005433345078	17105	Economy	7900.00
0005433345815	17105	Economy	7900.00
0005435097418	17105	Economy	7900.00
0005433345811	17105	Economy	7900.00
0005433345870	17105	Economy	7900.00
0005433345547	17105	Economy	7900.00
0005435097434	17105	Economy	7900.00
0005435097451	17105	Economy	7900.00
0005433345519	17105	Economy	7900.00
0005433345376	17105	Economy	7900.00
0005435097440	17105	Economy	7900.00
0005433345412	17105	Economy	7900.00
0005433345369	17105	Economy	7900.00
0005433345484	17105	Economy	7900.00
0005433345814	17105	Economy	7900.00
0005433345277	17105	Economy	7900.00
0005433345480	17105	Economy	7900.00
0005432920398	9113	Business	26600.00
0005432920363	9113	Business	26600.00
0005432920346	9113	Business	26600.00
0005432920435	9113	Business	26600.00
0005432920404	9113	Business	26600.00
0005432920244	9113	Business	26600.00
0005432920345	9113	Business	26600.00
0005433477290	9113	Economy	8900.00
0005432920387	9113	Economy	8900.00
0005432920403	9113	Economy	8900.00
0005432920397	9113	Economy	8900.00
0005432920214	9113	Economy	9800.00
0005432920352	9113	Economy	9800.00
0005432920328	9113	Economy	8900.00
0005433477291	9113	Economy	8900.00
0005432920348	9113	Economy	8900.00
0005433507731	9113	Economy	8900.00
0005434159028	9113	Economy	8900.00
0005432920347	9113	Economy	8900.00
0005433477289	9113	Economy	8900.00
0005432920359	9113	Economy	8900.00
0005432920243	9113	Economy	8900.00
0005432920353	9113	Economy	8900.00
0005432920325	9113	Economy	8900.00
0005432920361	9113	Economy	8900.00
0005433507730	9113	Economy	8900.00
0005432920433	9113	Economy	8900.00
0005434159027	9113	Economy	8900.00
0005433507729	9113	Economy	8900.00
0005432920399	9113	Economy	8900.00
0005432920282	9113	Economy	8900.00
0005432920362	9113	Economy	8900.00
0005432920405	9113	Economy	8900.00
0005432920434	9113	Economy	8900.00
0005432920395	9113	Economy	8900.00
0005432920432	9113	Economy	8900.00
0005433477288	9113	Economy	8900.00
0005432920374	9113	Economy	8900.00
0005432920213	9113	Economy	8900.00
0005432920329	9113	Economy	8900.00
0005433507728	9113	Economy	8900.00
0005433507669	20487	Business	26600.00
0005433477213	20487	Business	26600.00
0005433477135	20487	Business	26600.00
0005433477058	20487	Business	26600.00
0005433507599	20487	Business	26600.00
0005433477127	20487	Business	26600.00
0005433477187	20487	Business	26600.00
0005433477173	20487	Economy	8900.00
0005433477167	20487	Economy	8900.00
0005433477016	20487	Economy	8900.00
0005433477197	20487	Economy	8900.00
0005433477117	20487	Economy	8900.00
0005433477069	20487	Economy	8900.00
0005433507677	20487	Economy	8900.00
0005433507620	20487	Economy	8900.00
0005433507662	20487	Economy	9800.00
0005433481343	20487	Economy	9800.00
0005433477183	20487	Economy	9800.00
0005433477057	20487	Economy	9800.00
0005433481372	20487	Economy	9800.00
0005433477269	20487	Economy	8900.00
0005433477129	20487	Economy	8900.00
0005432920480	20487	Economy	8900.00
0005433477094	20487	Economy	8900.00
0005433477198	20487	Economy	8900.00
0005433477134	20487	Economy	8900.00
0005433481356	20487	Economy	8900.00
0005433477133	20487	Economy	8900.00
0005433477190	20487	Economy	8900.00
0005433477172	20487	Economy	8900.00
0005433481371	20487	Economy	8900.00
0005433477066	20487	Economy	8900.00
0005433477191	20487	Economy	8900.00
0005433481344	20487	Economy	8900.00
0005433477212	20487	Economy	8900.00
0005433477015	20487	Economy	8900.00
0005433477163	20487	Economy	8900.00
0005433477116	20487	Economy	8900.00
0005433507645	20487	Economy	8900.00
0005433477168	20487	Economy	8900.00
0005433477270	20487	Economy	8900.00
0005433477123	20487	Economy	8900.00
0005433477048	20487	Economy	8900.00
0005433477128	20487	Economy	8900.00
0005433481370	20487	Economy	8900.00
0005433507610	20487	Economy	8900.00
0005433477226	20487	Economy	8900.00
0005433477132	20487	Economy	8900.00
0005433477124	20487	Economy	8900.00
0005433477056	20487	Economy	8900.00
0005433477268	20487	Economy	8900.00
0005433477049	20487	Economy	8900.00
0005433507586	20487	Economy	8900.00
0005433477164	20487	Economy	8900.00
0005433477194	20487	Economy	8900.00
0005433477186	20487	Economy	8900.00
0005433507576	20487	Economy	8900.00
0005433507668	20487	Economy	8900.00
0005433477206	20487	Economy	8900.00
0005433477182	20487	Economy	8900.00
0005433477138	20487	Economy	8900.00
0005433481333	20487	Economy	8900.00
0005433477205	20487	Economy	8900.00
0005435179013	10133	Economy	5800.00
0005432394224	10133	Economy	5800.00
0005432394223	10133	Economy	5800.00
0005435179014	10133	Economy	5800.00
0005432396343	18362	Economy	5800.00
0005432396345	18362	Economy	5800.00
0005432396339	18362	Economy	5800.00
0005432396329	18362	Economy	5800.00
0005432400210	18362	Economy	5800.00
0005432396338	18362	Economy	5800.00
0005435127327	11014	Business	9500.00
0005435127320	11014	Business	9500.00
0005435554282	11014	Business	9500.00
0005435626579	11014	Business	9500.00
0005435127158	11014	Business	9500.00
0005435556759	11014	Business	9500.00
0005435626603	11014	Business	9500.00
0005435127465	11014	Business	9500.00
0005435127351	11014	Business	9500.00
0005435554304	11014	Business	9500.00
0005435626586	11014	Economy	3200.00
0005435127388	11014	Economy	3200.00
0005435626596	11014	Economy	3200.00
0005435127387	11014	Economy	3200.00
0005435127464	11014	Economy	3200.00
0005435127379	11014	Economy	3200.00
0005435556760	11014	Economy	3200.00
0005435127280	11014	Economy	3500.00
0005435626611	11014	Economy	3500.00
0005435127330	11014	Economy	3500.00
0005435626570	11014	Economy	3200.00
0005435127357	11014	Economy	3200.00
0005435127123	11014	Economy	3200.00
0005435554293	11014	Economy	3200.00
0005435127489	11014	Economy	3200.00
0005435556758	11014	Economy	3200.00
0005435127122	11014	Economy	3200.00
0005435626529	11014	Economy	3200.00
0005435127312	11014	Economy	3200.00
0005435626620	11014	Economy	3200.00
0005435127274	11014	Economy	3200.00
0005435127132	11014	Economy	3200.00
0005435127286	11014	Economy	3200.00
0005435626536	11014	Economy	3200.00
0005435127288	11014	Economy	3200.00
0005435626569	11014	Economy	3200.00
0005435127328	11014	Economy	3200.00
0005435626581	11014	Economy	3200.00
0005435626631	11014	Economy	3200.00
0005435626630	11014	Economy	3200.00
0005435127378	11014	Economy	3200.00
0005435127262	11014	Economy	3200.00
0005435626601	11014	Economy	3200.00
0005435127364	11014	Economy	3200.00
0005435127462	11014	Economy	3200.00
0005435554306	11014	Economy	3200.00
0005435626561	11014	Economy	3200.00
0005435127356	11014	Economy	3200.00
0005435626610	11014	Economy	3200.00
0005435127321	11014	Economy	3200.00
0005435626560	11014	Economy	3200.00
0005435626582	11014	Economy	3200.00
0005435127285	11014	Economy	3200.00
0005435127366	11014	Economy	3200.00
0005435127322	11014	Economy	3200.00
0005435626547	11014	Economy	3200.00
0005435626622	11014	Economy	3200.00
0005435127131	11014	Economy	3200.00
0005435127271	11014	Economy	3200.00
0005435626492	11014	Economy	3200.00
0005435626577	11014	Economy	3200.00
0005435127313	11014	Economy	3200.00
0005435554292	11014	Economy	3200.00
0005435127287	11014	Economy	3200.00
0005435127214	11014	Economy	3200.00
0005435626633	11014	Economy	3200.00
0005435554307	11014	Economy	3200.00
0005435127215	11014	Economy	3200.00
0005435554305	11014	Economy	3200.00
0005435127016	11014	Economy	3200.00
0005435626578	11014	Economy	3200.00
0005434411879	14759	Business	9500.00
0005434928378	14759	Business	9500.00
0005435127584	14759	Economy	3200.00
0005434928372	14759	Economy	3200.00
0005435626861	14759	Economy	3200.00
0005434411885	14759	Economy	3200.00
0005434411872	14759	Economy	3500.00
0005434411884	14759	Economy	3500.00
0005435127578	14759	Economy	3200.00
0005435127580	14759	Economy	3200.00
0005435127583	14759	Economy	3200.00
0005435626857	14759	Economy	3200.00
0005434411873	14759	Economy	3200.00
0005434411886	14759	Economy	3200.00
0005435626859	14759	Economy	3200.00
0005435127582	14759	Economy	3200.00
0005435626858	14759	Economy	3200.00
0005435626860	14759	Economy	3200.00
0005435127579	14759	Economy	3200.00
0005435127581	14759	Economy	3200.00
0005435127577	14759	Economy	3200.00
0005435626862	14759	Economy	3200.00
0005435443523	7117	Business	86900.00
0005435443536	7117	Business	86900.00
0005435221076	7117	Business	86900.00
0005435443530	7117	Economy	29000.00
0005435178525	7117	Economy	29000.00
0005435443531	7117	Economy	29000.00
0005435443551	7117	Economy	29000.00
0005435443545	7117	Economy	29000.00
0005435443522	7117	Economy	29000.00
0005435443563	7117	Economy	29000.00
0005435443494	7117	Economy	29000.00
0005435179416	7117	Economy	29000.00
0005435179415	7117	Economy	29000.00
0005435443544	7117	Economy	29000.00
0005435443526	7117	Economy	29000.00
0005435443512	7117	Economy	29000.00
0005435179419	7117	Economy	29000.00
0005435221077	7117	Economy	29000.00
0005435443529	7117	Economy	29000.00
0005435443532	7117	Economy	29000.00
0005432394192	27098	Business	86900.00
0005432398285	27098	Business	86900.00
0005435715826	27098	Business	86900.00
0005435715892	27098	Economy	29000.00
0005435715919	27098	Economy	29000.00
0005435715908	27098	Economy	29000.00
0005435715921	27098	Economy	31900.00
0005435715923	27098	Economy	29000.00
0005435178540	27098	Economy	29000.00
0005435715877	27098	Economy	29000.00
0005435715842	27098	Economy	29000.00
0005432398281	27098	Economy	29000.00
0005435715920	27098	Economy	29000.00
0005435715918	27098	Economy	29000.00
0005435715841	27098	Economy	29000.00
0005435715922	27098	Economy	29000.00
0005435715881	27098	Economy	29000.00
0005432398282	27098	Economy	29000.00
0005433060463	2736	Economy	7700.00
0005433060462	2736	Economy	7700.00
0005433060486	2736	Economy	7700.00
0005433060487	2736	Economy	7700.00
0005434085041	28484	Economy	7700.00
0005434085021	28484	Economy	7700.00
0005434085036	28484	Economy	7700.00
0005434085054	28484	Economy	7700.00
0005435541498	11388	Business	20200.00
0005435518363	11388	Business	20200.00
0005435541558	11388	Business	20200.00
0005435518326	11388	Business	20200.00
0005435541566	11388	Business	20200.00
0005435541549	11388	Business	20200.00
0005435541548	11388	Economy	6700.00
0005435518286	11388	Economy	6700.00
0005435518381	11388	Economy	6700.00
0005435518373	11388	Economy	7400.00
0005435541541	11388	Economy	6700.00
0005435518303	11388	Economy	6700.00
0005435541562	11388	Economy	6700.00
0005435518410	11388	Economy	6700.00
0005435518348	11388	Economy	6700.00
0005435518265	11388	Economy	6700.00
0005435518380	11388	Economy	6700.00
0005435518409	11388	Economy	6700.00
0005435518352	11388	Economy	6700.00
0005435541526	11388	Economy	6700.00
0005435541565	11388	Economy	6700.00
0005435541509	11388	Economy	6700.00
0005435541497	11388	Economy	6700.00
0005435518337	11388	Economy	6700.00
0005435518366	11388	Economy	6700.00
0005435541538	11388	Economy	6700.00
0005435518353	11388	Economy	6700.00
0005435541516	11388	Economy	6700.00
0005435541536	11388	Economy	6700.00
0005435518411	11388	Economy	6700.00
0005435518302	11388	Economy	6700.00
0005435518264	11388	Economy	6700.00
0005435541551	11388	Economy	6700.00
0005435541547	11388	Economy	6700.00
0005435541445	11388	Economy	6700.00
0005435541537	11388	Economy	6700.00
0005435541486	11388	Economy	6700.00
0005435541444	11388	Economy	6700.00
0005435541581	11388	Economy	6700.00
0005435541505	11388	Economy	6700.00
0005435530195	22218	Business	20200.00
0005435529896	22218	Economy	7400.00
0005435541641	22218	Economy	6700.00
0005435530193	22218	Economy	6700.00
0005435530192	22218	Economy	6700.00
0005435529894	22218	Economy	6700.00
0005435529895	22218	Economy	6700.00
0005435529897	22218	Economy	6700.00
0005435541642	22218	Economy	6700.00
0005435529893	22218	Economy	6700.00
0005435530194	22218	Economy	6700.00
0005435530191	22218	Economy	6700.00
0005435529892	22218	Economy	6700.00
0005435541643	22218	Economy	6700.00
0005433252219	2280	Business	20200.00
0005434908894	2280	Business	20200.00
0005434908892	2280	Business	20200.00
0005433401061	2280	Business	20200.00
0005433401060	2280	Business	20200.00
0005433401046	2280	Economy	6700.00
0005433252239	2280	Economy	6700.00
0005433252297	2280	Economy	6700.00
0005433252237	2280	Economy	6700.00
0005433401062	2280	Economy	6700.00
0005433401066	2280	Economy	6700.00
0005433252117	2280	Economy	6700.00
0005433252233	2280	Economy	6700.00
0005433252207	2280	Economy	6700.00
0005433401054	2280	Economy	6700.00
0005433252167	2280	Economy	6700.00
0005434908890	2280	Economy	6700.00
0005433252183	2280	Economy	6700.00
0005434908895	2280	Economy	6700.00
0005434908891	2280	Economy	6700.00
0005433252235	2280	Economy	6700.00
0005433252288	2280	Economy	6700.00
0005433252198	2280	Economy	6700.00
0005433252357	2280	Economy	6700.00
0005433252286	2280	Economy	6700.00
0005433252283	2280	Economy	6700.00
0005433252214	2280	Economy	6700.00
0005434908893	2280	Economy	6700.00
0005434908896	2280	Economy	6700.00
0005433252282	2280	Economy	6700.00
0005433252293	2280	Economy	6700.00
0005433252206	2280	Economy	6700.00
0005433252240	2280	Economy	6700.00
0005433252323	2280	Economy	6700.00
0005433252163	2280	Economy	6700.00
0005433252322	2280	Economy	6700.00
0005433401067	2280	Economy	6700.00
0005433252268	2280	Economy	6700.00
0005433252185	2280	Economy	6700.00
0005433252184	2280	Economy	6700.00
0005433252162	2280	Economy	6700.00
0005433252327	2280	Economy	6700.00
0005433401059	2280	Economy	6700.00
0005433252296	2280	Economy	6700.00
0005434908647	25620	Business	20200.00
0005434908518	25620	Business	20200.00
0005433252385	25620	Business	20200.00
0005434908604	25620	Business	20200.00
0005434908569	25620	Business	20200.00
0005434908474	25620	Business	20200.00
0005434908495	25620	Business	20200.00
0005434908354	25620	Business	20200.00
0005434908554	25620	Business	20200.00
0005434908640	25620	Economy	6700.00
0005434908453	25620	Economy	6700.00
0005434908323	25620	Economy	6700.00
0005434908466	25620	Economy	6700.00
0005434908424	25620	Economy	6700.00
0005434908349	25620	Economy	6700.00
0005434908644	25620	Economy	6700.00
0005434908373	25620	Economy	7400.00
0005434908288	25620	Economy	7400.00
0005434908314	25620	Economy	7400.00
0005434908494	25620	Economy	6700.00
0005434908468	25620	Economy	6700.00
0005435787463	25620	Economy	6700.00
0005434908470	25620	Economy	6700.00
0005434908687	25620	Economy	6700.00
0005434908641	25620	Economy	6700.00
0005434908170	25620	Economy	6700.00
0005434908372	25620	Economy	6700.00
0005434908567	25620	Economy	6700.00
0005434908611	25620	Economy	6700.00
0005434908465	25620	Economy	6700.00
0005434908568	25620	Economy	6700.00
0005434908601	25620	Economy	6700.00
0005434908519	25620	Economy	6700.00
0005434908397	25620	Economy	6700.00
0005434908456	25620	Economy	6700.00
0005434908616	25620	Economy	6700.00
0005434908633	25620	Economy	6700.00
0005434908471	25620	Economy	6700.00
0005434908612	25620	Economy	6700.00
0005434908423	25620	Economy	6700.00
0005434908289	25620	Economy	6700.00
0005434908418	25620	Economy	6700.00
0005434908517	25620	Economy	6700.00
0005434908462	25620	Economy	6700.00
0005434908768	25620	Economy	6700.00
0005434908531	25620	Economy	6700.00
0005434908290	25620	Economy	6700.00
0005434908632	25620	Economy	6700.00
0005434908670	25620	Economy	6700.00
0005435787464	25620	Economy	6700.00
0005433252384	25620	Economy	6700.00
0005434908555	25620	Economy	6700.00
0005434908417	25620	Economy	6700.00
0005434908615	25620	Economy	6700.00
0005433252383	25620	Economy	6700.00
0005434908642	25620	Economy	6700.00
0005434908591	25620	Economy	6700.00
0005434908409	25620	Economy	6700.00
0005435787462	25620	Economy	6700.00
0005434908487	25620	Economy	6700.00
0005434908335	25620	Economy	6700.00
0005434908539	25620	Economy	6700.00
0005434908594	25620	Economy	6700.00
0005434908571	25620	Economy	6700.00
0005432862487	2499	Economy	13600.00
0005432621457	2499	Economy	12400.00
0005432862465	2499	Economy	12400.00
0005432862464	2499	Economy	12400.00
0005432862519	2499	Economy	12400.00
0005432621458	2499	Economy	12400.00
0005432862520	2499	Economy	12400.00
0005432621455	2499	Economy	12400.00
0005432862481	2499	Economy	12400.00
0005432862488	2499	Economy	12400.00
0005432621456	2499	Economy	12400.00
0005432862480	2499	Economy	12400.00
0005432621390	28078	Economy	13600.00
0005432621331	28078	Economy	12400.00
0005432621366	28078	Economy	12400.00
0005432621428	28078	Economy	12400.00
0005432621406	28078	Economy	12400.00
0005432621429	28078	Economy	12400.00
0005432621359	28078	Economy	12400.00
0005432621407	28078	Economy	12400.00
0005432621389	28078	Economy	12400.00
0005432621365	28078	Economy	12400.00
0005432621393	28078	Economy	12400.00
0005432621392	28078	Economy	12400.00
0005432621330	28078	Economy	12400.00
0005432621340	28078	Economy	12400.00
0005432621382	28078	Economy	12400.00
0005432621427	28078	Economy	12400.00
0005432621372	28078	Economy	12400.00
0005432621339	28078	Economy	12400.00
0005434097512	11698	Economy	11300.00
0005434097506	11698	Economy	11300.00
0005434097511	11698	Economy	11300.00
0005434552903	32869	Business	89600.00
0005434552914	32869	Business	89600.00
0005434552909	32869	Business	89600.00
0005434552901	32869	Business	89600.00
0005434552908	32869	Business	89600.00
0005434552899	32869	Business	89600.00
0005434552910	32869	Business	89600.00
0005434552906	32869	Business	89600.00
0005434552915	32869	Economy	29900.00
0005434552900	32869	Economy	32800.00
0005434552918	32869	Economy	32800.00
0005434552892	32869	Economy	29900.00
0005434552913	32869	Economy	29900.00
0005434552898	32869	Economy	29900.00
0005434552905	32869	Economy	29900.00
0005434552890	32869	Economy	29900.00
0005434191314	32869	Economy	29900.00
0005434552911	32869	Economy	29900.00
0005434191298	32869	Economy	29900.00
0005434552907	32869	Economy	29900.00
0005434552895	32869	Economy	29900.00
0005434552916	32869	Economy	29900.00
0005434552894	32869	Economy	29900.00
0005434552917	32869	Economy	29900.00
0005434552891	32869	Economy	29900.00
0005434552904	32869	Economy	29900.00
0005434552912	32869	Economy	29900.00
0005434191304	32869	Economy	29900.00
0005434552893	32869	Economy	29900.00
0005434552896	32869	Economy	29900.00
0005434191305	32869	Economy	29900.00
0005434191299	32869	Economy	29900.00
0005434552897	32869	Economy	29900.00
0005434552902	32869	Economy	29900.00
0005433454920	31450	Economy	8400.00
0005433452791	31450	Economy	8400.00
0005433454919	31450	Economy	8400.00
0005433129409	11977	Economy	6600.00
0005434142709	11977	Economy	6600.00
0005434326044	11977	Economy	6600.00
0005434326043	11977	Economy	6600.00
0005434142705	11977	Economy	6600.00
0005433134244	11977	Economy	6600.00
0005434326042	11977	Economy	6600.00
0005434326064	11977	Economy	6600.00
0005433129380	11977	Economy	6600.00
0005434326045	11977	Economy	6600.00
0005433134230	11977	Economy	6600.00
0005433134253	11977	Economy	6600.00
0005433129381	11977	Economy	6600.00
0005434326063	11977	Economy	6600.00
0005433129408	11977	Economy	6600.00
0005434326046	11977	Economy	6600.00
0005433129377	11977	Economy	6600.00
0005433129382	11977	Economy	6600.00
0005434184717	11977	Economy	6600.00
0005434184718	11977	Economy	6600.00
0005434142706	11977	Economy	6600.00
0005434142704	11977	Economy	6600.00
0005433134243	11977	Economy	6600.00
0005434326286	29851	Economy	6600.00
0005433131841	29851	Economy	6600.00
0005434326285	29851	Economy	6600.00
0005433134264	29851	Economy	6600.00
0005435799009	1612	Economy	15700.00
0005435799010	1612	Economy	15700.00
0005435799011	1612	Economy	15700.00
0005435698167	16473	Economy	18100.00
0005435698168	16473	Economy	18100.00
0005435698164	16473	Economy	18100.00
0005435698165	16473	Economy	18100.00
0005435698170	16473	Economy	18100.00
0005435698166	16473	Economy	18100.00
0005435698169	16473	Economy	18100.00
0005435697991	24726	Economy	19900.00
0005435698070	24726	Economy	19900.00
0005435697940	24726	Economy	19900.00
0005435698026	24726	Economy	18100.00
0005435697990	24726	Economy	18100.00
0005435698007	24726	Economy	18100.00
0005435697939	24726	Economy	18100.00
0005435697988	24726	Economy	18100.00
0005435697999	24726	Economy	18100.00
0005435698115	24726	Economy	18100.00
0005435698086	24726	Economy	18100.00
0005435697989	24726	Economy	18100.00
0005435698000	24726	Economy	18100.00
0005435698104	24726	Economy	18100.00
0005435698008	24726	Economy	18100.00
0005435698125	24726	Economy	18100.00
0005435697888	24726	Economy	18100.00
0005433724931	21636	Economy	4400.00
0005432968911	21636	Economy	4400.00
0005433724904	21636	Economy	4400.00
0005433724930	21636	Economy	4400.00
0005432968910	21636	Economy	4400.00
0005433724912	21636	Economy	4400.00
0005434140612	7336	Business	23100.00
0005434140609	7336	Business	23100.00
0005434140621	7336	Economy	7700.00
0005434140611	7336	Economy	8500.00
0005434140624	7336	Economy	8500.00
0005434140616	7336	Economy	7700.00
0005434140610	7336	Economy	7700.00
0005434140619	7336	Economy	7700.00
0005434140615	7336	Economy	7700.00
0005434140618	7336	Economy	7700.00
0005434140614	7336	Economy	7700.00
0005434140623	7336	Economy	7700.00
0005434140622	7336	Economy	7700.00
0005434140617	7336	Economy	7700.00
0005434140620	7336	Economy	7700.00
0005434140613	7336	Economy	7700.00
0005434140320	28562	Business	23100.00
0005434087632	28562	Business	23100.00
0005434140164	28562	Business	23100.00
0005434140021	28562	Business	23100.00
0005434139962	28562	Business	23100.00
0005434139905	28562	Business	23100.00
0005434139525	28562	Business	23100.00
0005434140108	28562	Business	23100.00
0005434140089	28562	Business	23100.00
0005434140450	28562	Business	23100.00
0005434087631	28562	Business	23100.00
0005434140066	28562	Business	23100.00
0005434139990	28562	Economy	7700.00
0005434139896	28562	Economy	7700.00
0005434140249	28562	Economy	7700.00
0005434139859	28562	Economy	7700.00
0005434139726	28562	Economy	7700.00
0005434139614	28562	Economy	7700.00
0005434140063	28562	Economy	7700.00
0005434139860	28562	Economy	7700.00
0005434140109	28562	Economy	7700.00
0005434140099	28562	Economy	7700.00
0005434140029	28562	Economy	8500.00
0005434140346	28562	Economy	8500.00
0005434140039	28562	Economy	8500.00
0005434139998	28562	Economy	8500.00
0005434139524	28562	Economy	8500.00
0005434140258	28562	Economy	7700.00
0005434140148	28562	Economy	7700.00
0005434139712	28562	Economy	7700.00
0005434139968	28562	Economy	7700.00
0005434087627	28562	Economy	7700.00
0005434140217	28562	Economy	7700.00
0005434140215	28562	Economy	7700.00
0005434139868	28562	Economy	7700.00
0005434140045	28562	Economy	7700.00
0005434140415	28562	Economy	7700.00
0005434139759	28562	Economy	7700.00
0005435283593	28562	Economy	7700.00
0005434139872	28562	Economy	7700.00
0005434140003	28562	Economy	7700.00
0005434139829	28562	Economy	7700.00
0005434140128	28562	Economy	7700.00
0005434139961	28562	Economy	7700.00
0005434139847	28562	Economy	7700.00
0005434140216	28562	Economy	7700.00
0005434139851	28562	Economy	7700.00
0005434139993	28562	Economy	7700.00
0005434140449	28562	Economy	7700.00
0005435283597	28562	Economy	7700.00
0005434140100	28562	Economy	7700.00
0005434139919	28562	Economy	7700.00
0005434139997	28562	Economy	7700.00
0005434139920	28562	Economy	7700.00
0005434139895	28562	Economy	7700.00
0005434139760	28562	Economy	7700.00
0005434087630	28562	Economy	7700.00
0005434140211	28562	Economy	7700.00
0005434140065	28562	Economy	7700.00
0005434139831	28562	Economy	7700.00
0005434139705	28562	Economy	7700.00
0005434140064	28562	Economy	7700.00
0005434139937	28562	Economy	7700.00
0005434139969	28562	Economy	7700.00
0005434139469	28562	Economy	7700.00
0005435283595	28562	Economy	7700.00
0005434087611	28562	Economy	7700.00
0005434140123	28562	Economy	7700.00
0005435283592	28562	Economy	7700.00
0005434139523	28562	Economy	7700.00
0005434139763	28562	Economy	7700.00
0005434140073	28562	Economy	7700.00
0005434140136	28562	Economy	7700.00
0005435283591	28562	Economy	7700.00
0005434140055	28562	Economy	7700.00
0005434139989	28562	Economy	7700.00
0005435283596	28562	Economy	7700.00
0005434140044	28562	Economy	7700.00
0005434140056	28562	Economy	7700.00
0005434140122	28562	Economy	7700.00
0005434139938	28562	Economy	7700.00
0005434140129	28562	Economy	7700.00
0005434139727	28562	Economy	7700.00
0005434140072	28562	Economy	7700.00
0005434140046	28562	Economy	7700.00
0005434139830	28562	Economy	7700.00
0005434139999	28562	Economy	7700.00
0005434140011	28562	Economy	7700.00
0005435283594	28562	Economy	7700.00
0005434139967	28562	Economy	7700.00
0005434140012	28562	Economy	7700.00
0005434139865	28562	Economy	7700.00
0005434139882	28562	Economy	7700.00
0005434140147	28562	Economy	7700.00
0005435808532	1912	Economy	23900.00
0005433407691	1912	Economy	21700.00
0005433407692	1912	Economy	21700.00
0005433407670	1912	Economy	21700.00
0005433407669	1912	Economy	21700.00
0005433407675	1912	Economy	21700.00
0005434505102	16725	Economy	7600.00
0005434505149	16725	Economy	7600.00
0005434504992	16725	Economy	7600.00
0005435312882	16725	Economy	7600.00
0005435312883	16725	Economy	6900.00
0005434505072	16725	Economy	6900.00
0005434505147	16725	Economy	6900.00
0005434505140	16725	Economy	6900.00
0005434505116	16725	Economy	6900.00
0005434504993	16725	Economy	6900.00
0005434505115	16725	Economy	6900.00
0005434505258	16725	Economy	6900.00
0005434505101	16725	Economy	6900.00
0005434505035	16725	Economy	6900.00
0005435312885	16725	Economy	6900.00
0005434504922	16725	Economy	6900.00
0005434505134	16725	Economy	6900.00
0005434505056	16725	Economy	6900.00
0005434505148	16725	Economy	6900.00
0005434504991	16725	Economy	6900.00
0005434505039	16725	Economy	6900.00
0005434505220	16725	Economy	6900.00
0005434505059	16725	Economy	6900.00
0005434504929	16725	Economy	6900.00
0005434505244	16725	Economy	6900.00
0005434504822	16725	Economy	6900.00
0005434505057	16725	Economy	6900.00
0005434504956	16725	Economy	6900.00
0005434504821	16725	Economy	6900.00
0005434505060	16725	Economy	6900.00
0005434505145	16725	Economy	6900.00
0005434505014	16725	Economy	6900.00
0005434505038	16725	Economy	6900.00
0005434505207	16725	Economy	6900.00
0005434505049	16725	Economy	6900.00
0005434504958	16725	Economy	6900.00
0005434505077	16725	Economy	6900.00
0005434505206	16725	Economy	6900.00
0005434505141	16725	Economy	6900.00
0005434505121	16725	Economy	6900.00
0005434505146	16725	Economy	6900.00
0005434504715	16725	Economy	6900.00
0005435312884	16725	Economy	6900.00
0005434505305	22922	Economy	7600.00
0005434505303	22922	Economy	7600.00
0005434505314	22922	Economy	6900.00
0005434505313	22922	Economy	6900.00
0005434505312	22922	Economy	6900.00
0005434505308	22922	Economy	6900.00
0005434505310	22922	Economy	6900.00
0005434505311	22922	Economy	6900.00
0005434505309	22922	Economy	6900.00
0005434505306	22922	Economy	6900.00
0005434505301	22922	Economy	6900.00
0005434505304	22922	Economy	6900.00
0005434505302	22922	Economy	6900.00
0005434505307	22922	Economy	6900.00
0005434505315	22922	Economy	6900.00
0005434608401	6502	Economy	17300.00
0005434608398	6502	Economy	17300.00
0005434608402	6502	Economy	17300.00
0005434608400	6502	Economy	17300.00
0005434608407	6502	Economy	17300.00
0005434608403	6502	Economy	17300.00
0005434608399	6502	Economy	17300.00
0005434608406	6502	Economy	17300.00
0005434608404	6502	Economy	17300.00
0005434608405	6502	Economy	17300.00
0005434608363	22495	Economy	19100.00
0005434608366	22495	Economy	19100.00
0005434608367	22495	Economy	19100.00
0005434608360	22495	Economy	19100.00
0005434608378	22495	Economy	17300.00
0005434608368	22495	Economy	17300.00
0005434608377	22495	Economy	17300.00
0005434608371	22495	Economy	17300.00
0005434608373	22495	Economy	17300.00
0005434608384	22495	Economy	17300.00
0005434608369	22495	Economy	17300.00
0005434608362	22495	Economy	17300.00
0005434608382	22495	Economy	17300.00
0005434608380	22495	Economy	17300.00
0005434608379	22495	Economy	17300.00
0005434608393	22495	Economy	17300.00
0005434608375	22495	Economy	17300.00
0005434608361	22495	Economy	17300.00
0005434608374	22495	Economy	17300.00
0005434608370	22495	Economy	17300.00
0005434608376	22495	Economy	17300.00
0005434608381	22495	Economy	17300.00
0005434608383	22495	Economy	17300.00
0005434608394	22495	Economy	17300.00
0005433266969	2223	Economy	7000.00
0005433266951	2223	Economy	7000.00
0005435078793	2223	Economy	7000.00
0005435078794	2223	Economy	7000.00
0005433266953	2223	Economy	7000.00
0005433266924	2223	Economy	7000.00
0005433266952	2223	Economy	7000.00
0005433266933	2223	Economy	7000.00
0005433266954	2223	Economy	7000.00
0005433266934	2223	Economy	7000.00
0005433266944	2223	Economy	7000.00
0005433266947	2223	Economy	7000.00
0005433266950	2223	Economy	7000.00
0005433266943	2223	Economy	7000.00
0005433266915	2223	Economy	7000.00
0005433266946	2223	Economy	7000.00
0005435078740	24374	Economy	7000.00
0005435078739	24374	Economy	7000.00
0005435078695	24374	Economy	7000.00
0005435078767	24374	Economy	7000.00
0005435078751	24374	Economy	7000.00
0005435078715	24374	Economy	7000.00
0005435078752	24374	Economy	7000.00
0005435078714	24374	Economy	7000.00
0005435078750	24374	Economy	7000.00
0005435078713	24374	Economy	7000.00
0005435078738	24374	Economy	7000.00
0005435078696	24374	Economy	7000.00
0005435078702	24374	Economy	7000.00
0005435464556	6660	Economy	10800.00
0005434989126	6660	Economy	10800.00
0005435464559	6660	Economy	9800.00
0005434989125	6660	Economy	9800.00
0005434989122	6660	Economy	9800.00
0005435464558	6660	Economy	9800.00
0005434989129	6660	Economy	9800.00
0005434989128	6660	Economy	9800.00
0005434989120	6660	Economy	9800.00
0005434989123	6660	Economy	9800.00
0005434989119	6660	Economy	9800.00
0005434989130	6660	Economy	9800.00
0005435464557	6660	Economy	9800.00
0005434989118	6660	Economy	9800.00
0005435803353	6660	Economy	9800.00
0005434989127	6660	Economy	9800.00
0005435803354	6660	Economy	9800.00
0005434989124	6660	Economy	9800.00
0005434989121	6660	Economy	9800.00
0005435803330	23610	Economy	9800.00
0005435803332	23610	Economy	9800.00
0005434988987	23610	Economy	9800.00
0005434988914	23610	Economy	9800.00
0005434988966	23610	Economy	9800.00
0005434988972	23610	Economy	9800.00
0005434988951	23610	Economy	9800.00
0005434988968	23610	Economy	9800.00
0005435803331	23610	Economy	9800.00
0005433450610	30476	Economy	3600.00
0005432384336	30476	Economy	3300.00
0005432384338	30476	Economy	3300.00
0005432384339	30476	Economy	3300.00
0005432384337	30476	Economy	3300.00
0005433450609	30476	Economy	3300.00
0005433450465	31312	Business	9900.00
0005432384037	31312	Business	9900.00
0005433450464	31312	Business	9900.00
0005433450516	31312	Business	9900.00
0005432383934	31312	Economy	3300.00
0005433450494	31312	Economy	3300.00
0005433451668	31312	Economy	3300.00
0005432383897	31312	Economy	3300.00
0005433450397	31312	Economy	3300.00
0005432384096	31312	Economy	3300.00
0005432384083	31312	Economy	3600.00
0005433451666	31312	Economy	3600.00
0005432384073	31312	Economy	3600.00
0005432384133	31312	Economy	3300.00
0005432384047	31312	Economy	3300.00
0005432383951	31312	Economy	3300.00
0005433450469	31312	Economy	3300.00
0005432384118	31312	Economy	3300.00
0005433450514	31312	Economy	3300.00
0005433451667	31312	Economy	3300.00
0005432384095	31312	Economy	3300.00
0005432383878	31312	Economy	3300.00
0005432384038	31312	Economy	3300.00
0005433450396	31312	Economy	3300.00
0005432384027	31312	Economy	3300.00
0005432383842	31312	Economy	3300.00
0005433450394	31312	Economy	3300.00
0005432383946	31312	Economy	3300.00
0005432384015	31312	Economy	3300.00
0005432384134	31312	Economy	3300.00
0005432383935	31312	Economy	3300.00
0005432383870	31312	Economy	3300.00
0005433450468	31312	Economy	3300.00
0005432384080	31312	Economy	3300.00
0005432383969	31312	Economy	3300.00
0005433450518	31312	Economy	3300.00
0005433450515	31312	Economy	3300.00
0005432384103	31312	Economy	3300.00
0005433450541	31312	Economy	3300.00
0005432384014	31312	Economy	3300.00
0005432384002	31312	Economy	3300.00
0005432384104	31312	Economy	3300.00
0005432383994	31312	Economy	3300.00
0005432384001	31312	Economy	3300.00
0005432384053	31312	Economy	3300.00
0005435548590	20808	Economy	23800.00
0005435548560	20808	Economy	23800.00
0005435548585	20808	Economy	23800.00
0005433788322	20808	Economy	23800.00
0005433788324	20808	Economy	23800.00
0005433788330	20808	Economy	23800.00
0005435548594	20808	Economy	23800.00
0005433788325	20808	Economy	23800.00
0005433788328	20808	Economy	23800.00
0005435548598	20808	Economy	23800.00
0005435548579	20808	Economy	23800.00
0005433788321	20808	Economy	23800.00
0005433788327	20808	Economy	23800.00
0005435548599	20808	Economy	23800.00
0005435548566	20808	Economy	23800.00
0005435548597	20808	Economy	23800.00
0005435548548	20808	Economy	23800.00
0005433788326	20808	Economy	23800.00
0005435548547	20808	Economy	23800.00
0005435548602	20808	Economy	23800.00
0005435548559	20808	Economy	23800.00
0005435548596	20808	Economy	23800.00
0005433788323	20808	Economy	23800.00
0005433788329	20808	Economy	23800.00
0005435548578	20808	Economy	23800.00
0005433131809	10792	Economy	17100.00
0005433131810	10792	Economy	17100.00
0005433131811	10792	Economy	15600.00
0005433131801	10792	Economy	15600.00
0005435299889	10792	Economy	15600.00
0005435299894	10792	Economy	15600.00
0005435299901	10792	Economy	15600.00
0005433131797	10792	Economy	15600.00
0005433131812	10792	Economy	15600.00
0005435304251	10792	Economy	15600.00
0005435299886	10792	Economy	15600.00
0005435299876	10792	Economy	15600.00
0005433126946	10792	Economy	15600.00
0005433126953	10792	Economy	15600.00
0005433126941	10792	Economy	15600.00
0005433131800	10792	Economy	15600.00
0005435299923	29729	Economy	15600.00
0005434300261	2411	Economy	17200.00
0005434300265	2411	Economy	17200.00
0005433110363	2411	Economy	15700.00
0005433110375	2411	Economy	15700.00
0005433110370	2411	Economy	15700.00
0005433110342	2411	Economy	15700.00
0005433110300	2411	Economy	15700.00
0005434300260	2411	Economy	15700.00
0005434287943	2411	Economy	15700.00
0005433110364	2411	Economy	15700.00
0005434300264	2411	Economy	15700.00
0005434287942	2411	Economy	15700.00
0005433110314	2411	Economy	15700.00
0005433110369	2411	Economy	15700.00
0005434300263	2411	Economy	15700.00
0005434300266	2411	Economy	15700.00
0005432264548	2411	Economy	15700.00
0005433110313	2411	Economy	15700.00
0005434287940	2411	Economy	15700.00
0005433110315	2411	Economy	15700.00
0005434300267	2411	Economy	15700.00
0005433110336	2411	Economy	15700.00
0005433110309	2411	Economy	15700.00
0005434287941	2411	Economy	15700.00
0005434300262	2411	Economy	15700.00
0005433110341	2411	Economy	15700.00
0005433110311	2411	Economy	15700.00
0005433110304	2411	Economy	15700.00
0005434287754	26874	Economy	15700.00
0005434287854	26874	Economy	15700.00
0005434287824	26874	Economy	15700.00
0005434287822	26874	Economy	15700.00
0005434287804	26874	Economy	15700.00
0005434287792	26874	Economy	15700.00
0005434287853	26874	Economy	15700.00
0005434287897	26874	Economy	15700.00
0005434287755	26874	Economy	15700.00
0005434287901	26874	Economy	15700.00
0005434287845	26874	Economy	15700.00
0005434287793	26874	Economy	15700.00
0005434287833	26874	Economy	15700.00
0005434287832	26874	Economy	15700.00
0005434287823	26874	Economy	15700.00
0005434287803	26874	Economy	15700.00
0005435983719	25475	Economy	22800.00
0005434272223	25475	Economy	22800.00
0005434269148	25475	Economy	22800.00
0005434269149	25475	Economy	22800.00
0005434272222	25475	Economy	22800.00
0005435983720	25475	Economy	22800.00
0005435856363	25475	Economy	22800.00
0005435983718	25475	Economy	22800.00
0005434269150	25475	Economy	22800.00
0005435856289	26628	Economy	25000.00
0005435854077	26628	Economy	22800.00
0005434273138	26628	Economy	22800.00
0005434273137	26628	Economy	22800.00
0005434520460	19080	Economy	24600.00
0005434520463	19080	Economy	24600.00
0005434520457	19080	Economy	24600.00
0005435314952	19080	Economy	22300.00
0005434520461	19080	Economy	22300.00
0005434520477	19080	Economy	22300.00
0005434520452	19080	Economy	22300.00
0005434520464	19080	Economy	22300.00
0005434520392	19080	Economy	22300.00
0005434520437	19080	Economy	22300.00
0005434520472	19080	Economy	22300.00
0005434520465	19080	Economy	22300.00
0005434520425	19080	Economy	22300.00
0005434520473	19080	Economy	22300.00
0005434520474	19080	Economy	22300.00
0005434520495	19080	Economy	22300.00
0005435314950	19080	Economy	22300.00
0005434520494	19080	Economy	22300.00
0005434520456	19080	Economy	22300.00
0005434520451	19080	Economy	22300.00
0005435314951	19080	Economy	22300.00
0005434520500	19080	Economy	22300.00
0005434520433	19080	Economy	22300.00
0005434520434	19080	Economy	22300.00
0005434520501	19080	Economy	22300.00
0005434520462	19080	Economy	22300.00
0005434520476	19080	Economy	22300.00
0005434520438	19080	Economy	22300.00
0005433874460	7789	Economy	17400.00
0005433874457	7789	Economy	17400.00
0005433874461	7789	Economy	17400.00
0005433874458	7789	Economy	17400.00
0005433874459	7789	Economy	17400.00
0005433874427	32626	Economy	17400.00
0005433874431	32626	Economy	17400.00
0005433874420	32626	Economy	17400.00
0005433874426	32626	Economy	17400.00
0005433874423	32626	Economy	17400.00
0005433874422	32626	Economy	17400.00
0005433874424	32626	Economy	17400.00
0005433874440	32626	Economy	17400.00
0005433874432	32626	Economy	17400.00
0005433869607	4777	Economy	17600.00
0005435860570	4777	Economy	17600.00
0005433869614	4777	Economy	17600.00
0005435860579	4777	Economy	17600.00
0005433869606	4777	Economy	17600.00
0005433869611	4777	Economy	17600.00
0005435860584	4777	Economy	17600.00
0005433869608	4777	Economy	17600.00
0005433869613	4777	Economy	17600.00
0005435860572	4777	Economy	17600.00
0005433869605	4777	Economy	17600.00
0005435860590	4777	Economy	17600.00
0005433869609	4777	Economy	17600.00
0005433869604	4777	Economy	17600.00
0005433869610	4777	Economy	17600.00
0005435860571	4777	Economy	17600.00
0005433869612	4777	Economy	17600.00
0005435860604	4777	Economy	17600.00
0005433869299	32565	Economy	19400.00
0005433869384	32565	Economy	19400.00
0005433869377	32565	Economy	19400.00
0005433869231	32565	Economy	19400.00
0005433869305	32565	Economy	17600.00
0005433869220	32565	Economy	17600.00
0005433869269	32565	Economy	17600.00
0005433869312	32565	Economy	17600.00
0005433869271	32565	Economy	17600.00
0005433869543	32565	Economy	17600.00
0005433869514	32565	Economy	17600.00
0005433869225	32565	Economy	17600.00
0005433869267	32565	Economy	17600.00
0005435860633	32565	Economy	17600.00
0005433869270	32565	Economy	17600.00
0005433869458	32565	Economy	17600.00
0005433869376	32565	Economy	17600.00
0005433869308	32565	Economy	17600.00
0005433869292	32565	Economy	17600.00
0005433869392	32565	Economy	17600.00
0005433869268	32565	Economy	17600.00
0005433869437	32565	Economy	17600.00
0005433869478	32565	Economy	17600.00
0005433869479	32565	Economy	17600.00
0005433869230	32565	Economy	17600.00
0005433869286	32565	Economy	17600.00
0005433869353	32565	Economy	17600.00
0005433869393	32565	Economy	17600.00
0005433869285	32565	Economy	17600.00
0005435860632	32565	Economy	17600.00
0005433869352	32565	Economy	17600.00
0005433869473	32565	Economy	17600.00
0005433869442	32565	Economy	17600.00
0005433869380	32565	Economy	17600.00
0005433869311	32565	Economy	17600.00
0005433869542	32565	Economy	17600.00
0005433869209	32565	Economy	17600.00
0005433869221	32565	Economy	17600.00
0005433869232	32565	Economy	17600.00
0005433869421	32565	Economy	17600.00
0005435911652	3450	Economy	24800.00
0005435911634	3450	Economy	22600.00
0005435911624	3450	Economy	22600.00
0005435911632	3450	Economy	22600.00
0005435911651	3450	Economy	22600.00
0005435911630	3450	Economy	22600.00
0005434663719	12488	Economy	24800.00
0005434663720	12488	Economy	24800.00
0005434663728	12488	Economy	24800.00
0005434663763	12488	Economy	22600.00
0005434462838	12488	Economy	22600.00
0005434462834	12488	Economy	22600.00
0005434663721	12488	Economy	22600.00
0005434460556	12488	Economy	22600.00
0005434663731	12488	Economy	22600.00
0005434462839	12488	Economy	22600.00
0005434663740	12488	Economy	22600.00
0005434663723	12488	Economy	22600.00
0005434460548	12488	Economy	22600.00
0005434663742	12488	Economy	22600.00
0005434663783	12488	Economy	22600.00
0005434663743	12488	Economy	22600.00
0005434663732	12488	Economy	22600.00
0005434460544	12488	Economy	22600.00
0005434462837	12488	Economy	22600.00
0005434663748	12488	Economy	22600.00
0005434663704	12488	Economy	22600.00
0005434460549	12488	Economy	22600.00
0005434663782	12488	Economy	22600.00
0005434663749	12488	Economy	22600.00
0005434663688	12488	Economy	22600.00
0005434460555	12488	Economy	22600.00
0005434663722	12488	Economy	22600.00
0005434663727	12488	Economy	22600.00
0005434663741	12488	Economy	22600.00
0005434663724	12488	Economy	22600.00
0005434663747	12488	Economy	22600.00
0005433869230	14529	Economy	18500.00
0005435860633	14529	Economy	18500.00
0005433869437	14529	Economy	18500.00
0005433869312	14529	Economy	18500.00
0005433869542	14529	Economy	16800.00
0005433869478	14529	Economy	16800.00
0005433869292	14529	Economy	16800.00
0005433869220	14529	Economy	16800.00
0005433869393	14529	Economy	16800.00
0005433869221	14529	Economy	16800.00
0005433869384	14529	Economy	16800.00
0005433869268	14529	Economy	16800.00
0005433869479	14529	Economy	16800.00
0005433869352	14529	Economy	16800.00
0005433869231	14529	Economy	16800.00
0005433869232	14529	Economy	16800.00
0005433869514	14529	Economy	16800.00
0005433869421	14529	Economy	16800.00
0005433869353	14529	Economy	16800.00
0005433869376	14529	Economy	16800.00
0005433869380	14529	Economy	16800.00
0005433869311	14529	Economy	16800.00
0005435860632	14529	Economy	16800.00
0005433869269	14529	Economy	16800.00
0005433869442	14529	Economy	16800.00
0005433869225	14529	Economy	16800.00
0005433869270	14529	Economy	16800.00
0005433869271	14529	Economy	16800.00
0005433869209	14529	Economy	16800.00
0005433869543	14529	Economy	16800.00
0005433869377	14529	Economy	16800.00
0005433869305	14529	Economy	16800.00
0005433869286	14529	Economy	16800.00
0005433869473	14529	Economy	16800.00
0005433869285	14529	Economy	16800.00
0005433869267	14529	Economy	16800.00
0005433869299	14529	Economy	16800.00
0005433869392	14529	Economy	16800.00
0005433869308	14529	Economy	16800.00
0005433869458	14529	Economy	16800.00
0005433869599	32646	Economy	16800.00
0005435860575	32646	Economy	16800.00
0005433869603	32646	Economy	16800.00
0005435860573	32646	Economy	16800.00
0005433869597	32646	Economy	16800.00
0005433869601	32646	Economy	16800.00
0005433869598	32646	Economy	16800.00
0005433869600	32646	Economy	16800.00
0005435860574	32646	Economy	16800.00
0005435860568	32646	Economy	16800.00
0005433869602	32646	Economy	16800.00
0005432800120	12148	Economy	4900.00
0005432800053	12148	Economy	4900.00
0005432800115	12148	Economy	4400.00
0005432800130	12148	Economy	4400.00
0005432800159	12148	Economy	4400.00
0005432800203	12148	Economy	4400.00
0005432800136	12148	Economy	4400.00
0005432800172	12148	Economy	4400.00
0005432800002	12148	Economy	4400.00
0005432800118	12148	Economy	4400.00
0005432800169	12148	Economy	4400.00
0005432800137	12148	Economy	4400.00
0005432800119	12148	Economy	4400.00
0005432800131	12148	Economy	4400.00
0005432800135	12148	Economy	4400.00
0005432800171	12148	Economy	4400.00
0005432800068	12148	Economy	4400.00
0005432800116	12148	Economy	4400.00
0005432800176	12148	Economy	4400.00
0005432800121	12148	Economy	4400.00
0005432800177	12148	Economy	4400.00
0005432800125	12148	Economy	4400.00
0005432800170	12148	Economy	4400.00
0005432800054	12148	Economy	4400.00
0005432800129	12148	Economy	4400.00
0005432800279	14797	Economy	4900.00
0005432800283	14797	Economy	4400.00
0005432800278	14797	Economy	4400.00
0005432800282	14797	Economy	4400.00
0005432800281	14797	Economy	4400.00
0005432800274	14797	Economy	4400.00
0005432800276	14797	Economy	4400.00
0005432800275	14797	Economy	4400.00
0005432800280	14797	Economy	4400.00
0005432800277	14797	Economy	4400.00
0005435311387	7085	Business	49100.00
0005435311389	7085	Business	49100.00
0005435311342	7085	Business	49100.00
0005434409614	7085	Business	49100.00
0005435293580	7085	Economy	16400.00
0005434409611	7085	Economy	16400.00
0005435293545	7085	Economy	16400.00
0005435311307	7085	Economy	16400.00
0005434409613	7085	Economy	16400.00
0005435311428	7085	Economy	16400.00
0005435293546	7085	Economy	16400.00
0005434300225	7085	Economy	16400.00
0005434409612	7085	Economy	16400.00
0005434300226	7085	Economy	18000.00
0005434300228	7085	Economy	18000.00
0005435311354	7085	Economy	16400.00
0005435311386	7085	Economy	16400.00
0005435293548	7085	Economy	16400.00
0005435311432	7085	Economy	16400.00
0005435293516	7085	Economy	16400.00
0005435293574	7085	Economy	16400.00
0005435311422	7085	Economy	16400.00
0005435293531	7085	Economy	16400.00
0005435293534	7085	Economy	16400.00
0005435311460	7085	Economy	16400.00
0005434300227	7085	Economy	16400.00
0005435293533	7085	Economy	16400.00
0005435311452	7085	Economy	16400.00
0005435311298	7085	Economy	16400.00
0005435311352	7085	Economy	16400.00
0005435293547	7085	Economy	16400.00
0005435293551	7085	Economy	16400.00
0005435293575	7085	Economy	16400.00
0005435311353	7085	Economy	16400.00
0005435293552	7085	Economy	16400.00
0005435311341	7085	Economy	16400.00
0005435293526	7085	Economy	16400.00
0005435293532	7085	Economy	16400.00
0005434409157	26896	Business	49100.00
0005434300138	26896	Business	49100.00
0005434409184	26896	Business	49100.00
0005434409140	26896	Business	49100.00
0005434300135	26896	Business	49100.00
0005434409062	26896	Business	49100.00
0005434409159	26896	Business	49100.00
0005434300029	26896	Business	49100.00
0005434409112	26896	Economy	16400.00
0005434409061	26896	Economy	16400.00
0005434409158	26896	Economy	16400.00
0005434408921	26896	Economy	16400.00
0005434409150	26896	Economy	16400.00
0005434300097	26896	Economy	16400.00
0005434409221	26896	Economy	16400.00
0005434300081	26896	Economy	16400.00
0005435311554	26896	Economy	16400.00
0005435311552	26896	Economy	16400.00
0005434300110	26896	Economy	16400.00
0005434409230	26896	Economy	16400.00
0005434409182	26896	Economy	16400.00
0005434300148	26896	Economy	16400.00
0005434409269	26896	Economy	16400.00
0005434409118	26896	Economy	16400.00
0005434409178	26896	Economy	16400.00
0005434409400	26896	Economy	16400.00
0005434409258	26896	Economy	16400.00
0005434300156	26896	Economy	16400.00
0005434409212	26896	Economy	16400.00
0005434409129	26896	Economy	16400.00
0005434409237	26896	Economy	16400.00
0005434409296	26896	Economy	16400.00
0005434409298	26896	Economy	16400.00
0005434409222	26896	Economy	16400.00
0005434409308	26896	Economy	16400.00
0005434300134	26896	Economy	16400.00
0005434300143	26896	Economy	16400.00
0005434409219	26896	Economy	16400.00
0005434408878	26896	Economy	18000.00
0005434300093	26896	Economy	18000.00
0005434409268	26896	Economy	18000.00
0005434300028	26896	Economy	18000.00
0005434409405	26896	Economy	16400.00
0005434300096	26896	Economy	16400.00
0005434409279	26896	Economy	16400.00
0005434409117	26896	Economy	16400.00
0005434300149	26896	Economy	16400.00
0005434300146	26896	Economy	16400.00
0005434409309	26896	Economy	16400.00
0005434409306	26896	Economy	16400.00
0005434409305	26896	Economy	16400.00
0005434300183	26896	Economy	16400.00
0005434409297	26896	Economy	16400.00
0005434300106	26896	Economy	16400.00
0005434409038	26896	Economy	16400.00
0005434300144	26896	Economy	16400.00
0005434409220	26896	Economy	16400.00
0005435311550	26896	Economy	16400.00
0005434300109	26896	Economy	16400.00
0005435311551	26896	Economy	16400.00
0005434300115	26896	Economy	16400.00
0005434300137	26896	Economy	16400.00
0005434300150	26896	Economy	16400.00
0005434409374	26896	Economy	16400.00
0005434409224	26896	Economy	16400.00
0005434409497	26896	Economy	16400.00
0005434409149	26896	Economy	16400.00
0005434409267	26896	Economy	16400.00
0005432058498	26896	Economy	16400.00
0005434409259	26896	Economy	16400.00
0005434300201	26896	Economy	16400.00
0005434409231	26896	Economy	16400.00
0005434300075	26896	Economy	16400.00
0005434409208	26896	Economy	16400.00
0005434409116	26896	Economy	16400.00
0005434300165	26896	Economy	16400.00
0005434300125	26896	Economy	16400.00
0005434409304	26896	Economy	16400.00
0005434300136	26896	Economy	16400.00
0005434409180	26896	Economy	16400.00
0005435311553	26896	Economy	16400.00
0005434409307	26896	Economy	16400.00
0005434300119	26896	Economy	16400.00
0005434409513	26896	Economy	16400.00
0005434409373	26896	Economy	16400.00
0005434409103	26896	Economy	16400.00
0005435311555	26896	Economy	16400.00
0005434409134	26896	Economy	16400.00
0005434300147	26896	Economy	16400.00
0005434409130	26896	Economy	16400.00
0005432058499	26896	Economy	16400.00
0005434409179	26896	Economy	16400.00
0005434409278	26896	Economy	16400.00
0005434409495	26896	Economy	16400.00
0005435218137	6435	Economy	16500.00
0005435312900	6435	Economy	15000.00
0005432605507	6435	Economy	15000.00
0005432605504	6435	Economy	15000.00
0005435220505	6435	Economy	15000.00
0005432605505	6435	Economy	15000.00
0005432605506	6435	Economy	15000.00
0005435218136	6435	Economy	15000.00
0005432605146	21375	Economy	16500.00
0005432605282	21375	Economy	16500.00
0005432605392	21375	Economy	16500.00
0005432605212	21375	Economy	16500.00
0005434512228	21375	Economy	15000.00
0005432605283	21375	Economy	15000.00
0005432605112	21375	Economy	15000.00
0005432605288	21375	Economy	15000.00
0005432605263	21375	Economy	15000.00
0005435312914	21375	Economy	15000.00
0005432605241	21375	Economy	15000.00
0005432605054	21375	Economy	15000.00
0005432605328	21375	Economy	15000.00
0005432605277	21375	Economy	15000.00
0005432605240	21375	Economy	15000.00
0005432605329	21375	Economy	15000.00
0005435312913	21375	Economy	15000.00
0005432605274	21375	Economy	15000.00
0005432605223	21375	Economy	15000.00
0005432605109	21375	Economy	15000.00
0005432605338	21375	Economy	15000.00
0005432605145	21375	Economy	15000.00
0005432605188	21375	Economy	15000.00
0005432605211	21375	Economy	15000.00
0005432605257	21375	Economy	15000.00
0005432605165	21375	Economy	15000.00
0005432605278	21375	Economy	15000.00
0005432605062	21375	Economy	15000.00
0005432605367	21375	Economy	15000.00
0005432605220	21375	Economy	15000.00
0005434512229	21375	Economy	15000.00
0005432605221	21375	Economy	15000.00
0005432605289	21375	Economy	15000.00
0005432605327	21375	Economy	15000.00
0005432605213	21375	Economy	15000.00
0005432605222	21375	Economy	15000.00
0005432605279	21375	Economy	15000.00
0005432605306	21375	Economy	15000.00
0005432605214	21375	Economy	15000.00
0005434512246	21375	Economy	15000.00
0005432605187	21375	Economy	15000.00
0005432605193	21375	Economy	15000.00
0005432605074	21375	Economy	15000.00
0005432605113	21375	Economy	15000.00
0005432605075	21375	Economy	15000.00
0005434512230	21375	Economy	15000.00
0005432605190	21375	Economy	15000.00
0005434908289	15028	Business	18900.00
0005433252384	15028	Business	18900.00
0005434908314	15028	Business	18900.00
0005434908554	15028	Business	18900.00
0005434908288	15028	Business	18900.00
0005434908487	15028	Business	18900.00
0005434908465	15028	Business	18900.00
0005434908494	15028	Business	18900.00
0005434908519	15028	Economy	6300.00
0005434908604	15028	Economy	6300.00
0005434908335	15028	Economy	6300.00
0005434908768	15028	Economy	6300.00
0005434908611	15028	Economy	6300.00
0005434908453	15028	Economy	6900.00
0005434908531	15028	Economy	6900.00
0005434908418	15028	Economy	6900.00
0005434908632	15028	Economy	6900.00
0005434908170	15028	Economy	6300.00
0005434908601	15028	Economy	6300.00
0005434908616	15028	Economy	6300.00
0005434908456	15028	Economy	6300.00
0005434908423	15028	Economy	6300.00
0005434908373	15028	Economy	6300.00
0005434908349	15028	Economy	6300.00
0005434908409	15028	Economy	6300.00
0005434908462	15028	Economy	6300.00
0005434908568	15028	Economy	6300.00
0005434908687	15028	Economy	6300.00
0005434908495	15028	Economy	6300.00
0005434908468	15028	Economy	6300.00
0005434908471	15028	Economy	6300.00
0005434908647	15028	Economy	6300.00
0005434908670	15028	Economy	6300.00
0005433252383	15028	Economy	6300.00
0005434908594	15028	Economy	6300.00
0005434908615	15028	Economy	6300.00
0005434908518	15028	Economy	6300.00
0005434908517	15028	Economy	6300.00
0005434908372	15028	Economy	6300.00
0005434908290	15028	Economy	6300.00
0005434908591	15028	Economy	6300.00
0005434908555	15028	Economy	6300.00
0005433252385	15028	Economy	6300.00
0005434908640	15028	Economy	6300.00
0005434908539	15028	Economy	6300.00
0005434908323	15028	Economy	6300.00
0005434908571	15028	Economy	6300.00
0005434908567	15028	Economy	6300.00
0005434908466	15028	Economy	6300.00
0005434908642	15028	Economy	6300.00
0005434908397	15028	Economy	6300.00
0005434908633	15028	Economy	6300.00
0005434908569	15028	Economy	6300.00
0005434908641	15028	Economy	6300.00
0005434908424	15028	Economy	6300.00
0005434908612	15028	Economy	6300.00
0005434908644	15028	Economy	6300.00
0005434908354	15028	Economy	6300.00
0005434908474	15028	Economy	6300.00
0005434908470	15028	Economy	6300.00
0005434908417	15028	Economy	6300.00
0005433252258	25834	Business	18900.00
0005433252202	25834	Business	18900.00
0005433252110	25834	Business	18900.00
0005433252228	25834	Business	18900.00
0005434908888	25834	Business	18900.00
0005433252203	25834	Business	18900.00
0005434908874	25834	Business	18900.00
0005434908880	25834	Economy	6300.00
0005434908876	25834	Economy	6300.00
0005433252253	25834	Economy	6300.00
0005434908885	25834	Economy	6300.00
0005434908877	25834	Economy	6300.00
0005434908887	25834	Economy	6900.00
0005433252194	25834	Economy	6900.00
0005433252305	25834	Economy	6900.00
0005433252111	25834	Economy	6300.00
0005434908878	25834	Economy	6300.00
0005434908884	25834	Economy	6300.00
0005433252242	25834	Economy	6300.00
0005433252279	25834	Economy	6300.00
0005434908886	25834	Economy	6300.00
0005433252172	25834	Economy	6300.00
0005433252274	25834	Economy	6300.00
0005434908889	25834	Economy	6300.00
0005433252336	25834	Economy	6300.00
0005434908875	25834	Economy	6300.00
0005433252259	25834	Economy	6300.00
0005433252179	25834	Economy	6300.00
0005433252236	25834	Economy	6300.00
0005433252246	25834	Economy	6300.00
0005433252243	25834	Economy	6300.00
0005433252188	25834	Economy	6300.00
0005433252129	25834	Economy	6300.00
0005434908881	25834	Economy	6300.00
0005433252335	25834	Economy	6300.00
0005433252278	25834	Economy	6300.00
0005433252227	25834	Economy	6300.00
0005433252249	25834	Economy	6300.00
0005434908882	25834	Economy	6300.00
0005433252254	25834	Economy	6300.00
0005434908879	25834	Economy	6300.00
0005433252165	25834	Economy	6300.00
0005433252218	25834	Economy	6300.00
0005433252180	25834	Economy	6300.00
0005433252223	25834	Economy	6300.00
0005433252224	25834	Economy	6300.00
0005433252175	25834	Economy	6300.00
0005433252225	25834	Economy	6300.00
0005433252261	25834	Economy	6300.00
0005433252159	25834	Economy	6300.00
0005434908883	25834	Economy	6300.00
0005433815580	9178	Economy	19900.00
0005434173642	9178	Economy	19900.00
0005433815579	9178	Economy	18100.00
0005434173658	9178	Economy	18100.00
0005434173657	9178	Economy	18100.00
0005433815541	22706	Economy	19900.00
0005433815543	22706	Economy	18100.00
0005433815540	22706	Economy	18100.00
0005433815539	22706	Economy	18100.00
0005433815544	22706	Economy	18100.00
0005433815537	22706	Economy	18100.00
0005433815545	22706	Economy	18100.00
0005433815536	22706	Economy	18100.00
0005435842347	22475	Economy	16400.00
0005435842350	22475	Economy	14900.00
0005432609850	22475	Economy	14900.00
0005435842349	22475	Economy	14900.00
0005435842346	22475	Economy	14900.00
0005432609851	22475	Economy	14900.00
0005432609847	22475	Economy	14900.00
0005435842342	22475	Economy	14900.00
0005432607680	22475	Economy	14900.00
0005432609846	22475	Economy	14900.00
0005435842343	22475	Economy	14900.00
0005432609845	22475	Economy	14900.00
0005432609849	22475	Economy	14900.00
0005432609848	22475	Economy	14900.00
0005432609811	31720	Economy	16400.00
0005432609826	31720	Economy	16400.00
0005432609812	31720	Economy	16400.00
0005432613964	31720	Economy	16400.00
0005435841128	31720	Economy	14900.00
0005432609813	31720	Economy	14900.00
0005432609806	31720	Economy	14900.00
0005432613947	31720	Economy	14900.00
0005432613957	31720	Economy	14900.00
0005432609796	31720	Economy	14900.00
0005432609817	31720	Economy	14900.00
0005432613977	31720	Economy	14900.00
0005432613965	31720	Economy	14900.00
0005432609819	31720	Economy	14900.00
0005432613968	31720	Economy	14900.00
0005432609839	31720	Economy	14900.00
0005432609838	31720	Economy	14900.00
0005432613961	31720	Economy	14900.00
0005432609818	31720	Economy	14900.00
0005435841127	31720	Economy	14900.00
0005432609789	31720	Economy	14900.00
0005432613948	31720	Economy	14900.00
0005432609807	31720	Economy	14900.00
0005432609808	31720	Economy	14900.00
0005432609795	31720	Economy	14900.00
0005432613929	31720	Economy	14900.00
0005432613959	31720	Economy	14900.00
0005435841126	31720	Economy	14900.00
0005432609831	31720	Economy	14900.00
0005432613956	31720	Economy	14900.00
0005432613942	31720	Economy	14900.00
0005432613969	31720	Economy	14900.00
0005432613938	31720	Economy	14900.00
0005432609827	31720	Economy	14900.00
0005432609828	31720	Economy	14900.00
0005432609820	31720	Economy	14900.00
0005432613955	31720	Economy	14900.00
0005433815541	14184	Business	52300.00
0005433810693	14184	Economy	17400.00
0005433810640	14184	Economy	17400.00
0005433009971	14184	Economy	17400.00
0005433815544	14184	Economy	19200.00
0005433815539	14184	Economy	19200.00
0005433810650	14184	Economy	17400.00
0005433810617	14184	Economy	17400.00
0005433815537	14184	Economy	17400.00
0005433009970	14184	Economy	17400.00
0005433810651	14184	Economy	17400.00
0005433810641	14184	Economy	17400.00
0005433810657	14184	Economy	17400.00
0005433810655	14184	Economy	17400.00
0005433815543	14184	Economy	17400.00
0005433810616	14184	Economy	17400.00
0005433815540	14184	Economy	17400.00
0005433815545	14184	Economy	17400.00
0005433815536	14184	Economy	17400.00
0005433810685	14184	Economy	17400.00
0005433009972	14184	Economy	17400.00
0005433810656	14184	Economy	17400.00
0005433009969	14184	Economy	17400.00
0005433810774	22862	Business	52300.00
0005433009605	22862	Business	52300.00
0005433810792	22862	Business	52300.00
0005433810788	22862	Business	52300.00
0005433009785	22862	Business	52300.00
0005433009677	22862	Business	52300.00
0005433009665	22862	Business	52300.00
0005433009750	22862	Business	52300.00
0005433810776	22862	Economy	17400.00
0005433009699	22862	Economy	17400.00
0005433009620	22862	Economy	17400.00
0005433009614	22862	Economy	17400.00
0005433009718	22862	Economy	17400.00
0005433009747	22862	Economy	17400.00
0005433009741	22862	Economy	19200.00
0005434173637	22862	Economy	19200.00
0005433810783	22862	Economy	19200.00
0005433009606	22862	Economy	19200.00
0005433009598	22862	Economy	17400.00
0005434173655	22862	Economy	17400.00
0005434173636	22862	Economy	17400.00
0005433009797	22862	Economy	17400.00
0005433009355	22862	Economy	17400.00
0005433009783	22862	Economy	17400.00
0005433009658	22862	Economy	17400.00
0005433810791	22862	Economy	17400.00
0005433009860	22862	Economy	17400.00
0005433810785	22862	Economy	17400.00
0005433810790	22862	Economy	17400.00
0005433009590	22862	Economy	17400.00
0005433009720	22862	Economy	17400.00
0005433810777	22862	Economy	17400.00
0005433810787	22862	Economy	17400.00
0005433009739	22862	Economy	17400.00
0005433009823	22862	Economy	17400.00
0005433009748	22862	Economy	17400.00
0005433810770	22862	Economy	17400.00
0005433009588	22862	Economy	17400.00
0005433009698	22862	Economy	17400.00
0005433009657	22862	Economy	17400.00
0005434173654	22862	Economy	17400.00
0005433810779	22862	Economy	17400.00
0005433009601	22862	Economy	17400.00
0005433009719	22862	Economy	17400.00
0005433009782	22862	Economy	17400.00
0005433009654	22862	Economy	17400.00
0005433810781	22862	Economy	17400.00
0005433810784	22862	Economy	17400.00
0005433009749	22862	Economy	17400.00
0005433009615	22862	Economy	17400.00
0005433009712	22862	Economy	17400.00
0005433009742	22862	Economy	17400.00
0005433009711	22862	Economy	17400.00
0005433009861	22862	Economy	17400.00
0005433009732	22862	Economy	17400.00
0005433009600	22862	Economy	17400.00
0005433810773	22862	Economy	17400.00
0005433009784	22862	Economy	17400.00
0005433810786	22862	Economy	17400.00
0005433810771	22862	Economy	17400.00
0005434173643	22862	Economy	17400.00
0005433009538	22862	Economy	17400.00
0005433810775	22862	Economy	17400.00
0005433009354	22862	Economy	17400.00
0005433810772	22862	Economy	17400.00
0005433810789	22862	Economy	17400.00
0005433810780	22862	Economy	17400.00
0005433810782	22862	Economy	17400.00
0005433009780	22862	Economy	17400.00
0005433009599	22862	Economy	17400.00
0005433810778	22862	Economy	17400.00
0005434173644	22862	Economy	17400.00
0005434926518	14909	Business	22900.00
0005434926574	14909	Business	22900.00
0005434926509	14909	Business	22900.00
0005434926576	14909	Business	22900.00
0005434926616	14909	Business	22900.00
0005434926542	14909	Economy	7600.00
0005434926583	14909	Economy	7600.00
0005434926551	14909	Economy	7600.00
0005434926445	14909	Economy	7600.00
0005434926571	14909	Economy	7600.00
0005434926447	14909	Economy	7600.00
0005434926476	14909	Economy	8400.00
0005434926546	14909	Economy	8400.00
0005434926625	14909	Economy	8400.00
0005434926567	14909	Economy	7600.00
0005434926382	14909	Economy	7600.00
0005434926383	14909	Economy	7600.00
0005434926613	14909	Economy	7600.00
0005434926611	14909	Economy	7600.00
0005434926594	14909	Economy	7600.00
0005434926540	14909	Economy	7600.00
0005434926450	14909	Economy	7600.00
0005434926584	14909	Economy	7600.00
0005434926386	14909	Economy	7600.00
0005434926517	14909	Economy	7600.00
0005434926429	14909	Economy	7600.00
0005434926446	14909	Economy	7600.00
0005434926587	14909	Economy	7600.00
0005434926508	14909	Economy	7600.00
0005434926507	14909	Economy	7600.00
0005434926588	14909	Economy	7600.00
0005434926495	14909	Economy	7600.00
0005434926595	14909	Economy	7600.00
0005434926589	14909	Economy	7600.00
0005434926568	14909	Economy	7600.00
0005434926545	14909	Economy	7600.00
0005434926427	14909	Economy	7600.00
0005434926449	14909	Economy	7600.00
0005434926614	14909	Economy	7600.00
0005434926539	14909	Economy	7600.00
0005434926557	14909	Economy	7600.00
0005434926590	14909	Economy	7600.00
0005434926522	14909	Economy	7600.00
0005434926381	14909	Economy	7600.00
0005434926516	14909	Economy	7600.00
0005434926369	14909	Economy	7600.00
0005434926612	14909	Economy	7600.00
0005434926515	14909	Economy	7600.00
0005434926852	20546	Business	22900.00
0005434926843	20546	Business	22900.00
0005434926849	20546	Economy	7600.00
0005434926844	20546	Economy	7600.00
0005434926851	20546	Economy	7600.00
0005434926850	20546	Economy	7600.00
0005434926847	20546	Economy	7600.00
0005434926846	20546	Economy	7600.00
0005434926845	20546	Economy	7600.00
0005434926848	20546	Economy	7600.00
0005435999724	15843	Economy	8900.00
0005435999774	15843	Economy	8900.00
0005435999726	15843	Economy	8100.00
0005435999778	15843	Economy	8100.00
0005435999640	15843	Economy	8100.00
0005435999682	15843	Economy	8100.00
0005435999689	15843	Economy	8100.00
0005435999711	15843	Economy	8100.00
0005435999794	15843	Economy	8100.00
0005435999773	15843	Economy	8100.00
0005435999723	15843	Economy	8100.00
0005435999647	15843	Economy	8100.00
0005435999621	15843	Economy	8100.00
0005435999683	15843	Economy	8100.00
0005435999775	15843	Economy	8100.00
0005435999727	15843	Economy	8100.00
0005435999655	15843	Economy	8100.00
0005435999585	15843	Economy	8100.00
0005435999599	15843	Economy	8100.00
0005435999769	15843	Economy	8100.00
0005435999748	15843	Economy	8100.00
0005435999705	15843	Economy	8100.00
0005435999679	15843	Economy	8100.00
0005435999706	15843	Economy	8100.00
0005435999598	15843	Economy	8100.00
0005435999620	15843	Economy	8100.00
0005435999753	15843	Economy	8100.00
0005435999667	15843	Economy	8100.00
0005435488287	19691	Economy	8900.00
0005435999854	19691	Economy	8900.00
0005435488356	19691	Economy	8900.00
0005435488236	19691	Economy	8900.00
0005435488283	19691	Economy	8100.00
0005435488347	19691	Economy	8100.00
0005435999871	19691	Economy	8100.00
0005435488398	19691	Economy	8100.00
0005435488305	19691	Economy	8100.00
0005435488306	19691	Economy	8100.00
0005435488328	19691	Economy	8100.00
0005435999859	19691	Economy	8100.00
0005435488268	19691	Economy	8100.00
0005435488355	19691	Economy	8100.00
0005435488282	19691	Economy	8100.00
0005435488296	19691	Economy	8100.00
0005435488315	19691	Economy	8100.00
0005435488327	19691	Economy	8100.00
0005435999857	19691	Economy	8100.00
0005435488323	19691	Economy	8100.00
0005435488295	19691	Economy	8100.00
0005435488358	19691	Economy	8100.00
0005435488275	19691	Economy	8100.00
0005435488232	19691	Economy	8100.00
0005435488361	19691	Economy	8100.00
0005435999851	19691	Economy	8100.00
0005435999855	19691	Economy	8100.00
0005435999852	19691	Economy	8100.00
0005435488313	19691	Economy	8100.00
0005435488357	19691	Economy	8100.00
0005435488335	19691	Economy	8100.00
0005435488267	19691	Economy	8100.00
0005435999860	19691	Economy	8100.00
0005435488319	19691	Economy	8100.00
0005435488365	19691	Economy	8100.00
0005435488237	19691	Economy	8100.00
0005435488304	19691	Economy	8100.00
0005435999870	19691	Economy	8100.00
0005435488262	19691	Economy	8100.00
0005435999853	19691	Economy	8100.00
0005435999856	19691	Economy	8100.00
0005435488346	19691	Economy	8100.00
0005435488279	19691	Economy	8100.00
0005435999858	19691	Economy	8100.00
0005435488403	19691	Economy	8100.00
0005435488254	19691	Economy	8100.00
0005435488360	19691	Economy	8100.00
0005435999869	19691	Economy	8100.00
0005435488354	19691	Economy	8100.00
0005435473189	5992	Business	199300.00
0005435473215	5992	Business	199300.00
0005435473245	5992	Economy	66400.00
0005435473221	5992	Economy	66400.00
0005435473260	5992	Economy	66400.00
0005435473244	5992	Economy	66400.00
0005435473131	5992	Economy	66400.00
0005435473140	5992	Economy	66400.00
0005435473207	5992	Economy	66400.00
0005435840275	5992	Economy	66400.00
0005435473175	5992	Economy	66400.00
0005435839948	18037	Business	199300.00
0005435840091	18037	Business	199300.00
0005435840249	18037	Business	199300.00
0005435840090	18037	Business	199300.00
0005435840141	18037	Business	199300.00
0005435840186	18037	Business	199300.00
0005435840051	18037	Economy	66400.00
0005435840032	18037	Economy	66400.00
0005435840038	18037	Economy	66400.00
0005435840175	18037	Economy	73100.00
0005435840250	18037	Economy	66400.00
0005432664180	18037	Economy	66400.00
0005432664181	18037	Economy	66400.00
0005435840069	18037	Economy	66400.00
0005435840082	18037	Economy	66400.00
0005435473296	18037	Economy	66400.00
0005435840152	18037	Economy	66400.00
0005435840242	18037	Economy	66400.00
0005432667505	18037	Economy	66400.00
0005435840092	18037	Economy	66400.00
0005432667504	18037	Economy	66400.00
0005435839958	18037	Economy	66400.00
0005435840165	18037	Economy	66400.00
0005435840174	18037	Economy	66400.00
0005435840104	18037	Economy	66400.00
0005435840039	18037	Economy	66400.00
0005432664188	18037	Economy	66400.00
0005435840241	18037	Economy	66400.00
0005435840068	18037	Economy	66400.00
0005435840164	18037	Economy	66400.00
0005435839949	18037	Economy	66400.00
0005435840185	18037	Economy	66400.00
0005435840126	18037	Economy	66400.00
0005435840136	18037	Economy	66400.00
0005432664183	18037	Economy	66400.00
0005432660859	18037	Economy	66400.00
0005433462804	17271	Business	146400.00
0005433463967	17271	Business	146400.00
0005433462808	17271	Business	146400.00
0005433463962	17271	Economy	53700.00
0005433462803	17271	Economy	48800.00
0005433462807	17271	Economy	48800.00
0005433462805	17271	Economy	48800.00
0005433463966	17271	Economy	48800.00
0005433463965	17271	Economy	48800.00
0005433463959	17271	Economy	48800.00
0005433463960	17271	Economy	48800.00
0005433463961	17271	Economy	48800.00
0005433463963	17271	Economy	48800.00
0005433463964	17271	Economy	48800.00
0005433462806	17271	Economy	48800.00
0005433463958	17271	Economy	48800.00
0005433463968	17271	Economy	48800.00
0005435104374	23016	Business	15700.00
0005435097508	23016	Business	15700.00
0005433286092	23016	Business	15700.00
0005435097511	23016	Business	15700.00
0005435104376	23016	Business	15700.00
0005433286068	23016	Business	15700.00
0005433286050	23016	Economy	5200.00
0005435097510	23016	Economy	5200.00
0005435104368	23016	Economy	5200.00
0005433286107	23016	Economy	5200.00
0005435097515	23016	Economy	5200.00
0005435097512	23016	Economy	5200.00
0005433286026	23016	Economy	5200.00
0005435104369	23016	Economy	5200.00
0005433286093	23016	Economy	5200.00
0005435104371	23016	Economy	5200.00
0005435097513	23016	Economy	5200.00
0005435097516	23016	Economy	5200.00
0005433286084	23016	Economy	5200.00
0005433285988	23016	Economy	5200.00
0005433286134	23016	Economy	5200.00
0005433286069	23016	Economy	5700.00
0005435104366	23016	Economy	5700.00
0005435104365	23016	Economy	5200.00
0005435104373	23016	Economy	5200.00
0005435097519	23016	Economy	5200.00
0005433285928	23016	Economy	5200.00
0005435104372	23016	Economy	5200.00
0005435097514	23016	Economy	5200.00
0005433286120	23016	Economy	5200.00
0005435097521	23016	Economy	5200.00
0005435104375	23016	Economy	5200.00
0005433285961	23016	Economy	5200.00
0005433286038	23016	Economy	5200.00
0005435104367	23016	Economy	5200.00
0005435097520	23016	Economy	5200.00
0005433286039	23016	Economy	5200.00
0005435097517	23016	Economy	5200.00
0005433285994	23016	Economy	5200.00
0005433286053	23016	Economy	5200.00
0005433286127	23016	Economy	5200.00
0005435097509	23016	Economy	5200.00
0005435104370	23016	Economy	5200.00
0005433286025	23016	Economy	5200.00
0005433286088	23016	Economy	5200.00
0005435097518	23016	Economy	5200.00
0005435097522	23016	Economy	5200.00
0005433286058	23016	Economy	5200.00
0005433286087	23016	Economy	5200.00
0005433286046	23016	Economy	5200.00
0005433286083	23016	Economy	5200.00
0005433286133	23016	Economy	5200.00
0005435104097	32069	Business	15700.00
0005435104132	32069	Economy	5200.00
0005433286225	32069	Economy	5200.00
0005435104089	32069	Economy	5200.00
0005435104098	32069	Economy	5200.00
0005433286226	32069	Economy	5200.00
0005433286228	32069	Economy	5200.00
0005435104105	32069	Economy	5700.00
0005435104140	32069	Economy	5200.00
0005433286227	32069	Economy	5200.00
0005435104133	32069	Economy	5200.00
0005433286224	32069	Economy	5200.00
0005435104088	32069	Economy	5200.00
0005435104092	32069	Economy	5200.00
0005435104127	32069	Economy	5200.00
0005435104096	32069	Economy	5200.00
0005435104117	32069	Economy	5200.00
0005435104125	32069	Economy	5200.00
0005435104113	32069	Economy	5200.00
0005434069406	30609	Business	42100.00
0005434068952	30609	Business	42100.00
0005432531357	30609	Business	42100.00
0005432531040	30609	Business	42100.00
0005434069334	30609	Business	42100.00
0005432530913	30609	Business	42100.00
0005434069416	30609	Business	42100.00
0005432531716	30609	Business	42100.00
0005434069236	30609	Business	42100.00
0005432531135	30609	Business	42100.00
0005432531273	30609	Comfort	23900.00
0005434069276	30609	Comfort	23900.00
0005434069454	30609	Comfort	23900.00
0005434069594	30609	Comfort	23900.00
0005432429004	30609	Comfort	23900.00
0005434069405	30609	Comfort	23900.00
0005434069524	30609	Comfort	23900.00
0005432530788	30609	Comfort	23900.00
0005432531479	30609	Comfort	23900.00
0005434069155	30609	Comfort	23900.00
0005434069518	30609	Comfort	23900.00
0005432531041	30609	Comfort	23900.00
0005432530496	30609	Comfort	23900.00
0005432535964	30609	Comfort	23900.00
0005434069301	30609	Comfort	23900.00
0005435283552	30609	Comfort	23900.00
0005434069382	30609	Comfort	23900.00
0005432531133	30609	Comfort	23900.00
0005432531302	30609	Comfort	23900.00
0005432531118	30609	Comfort	23900.00
0005434069258	30609	Comfort	23900.00
0005432530914	30609	Comfort	23900.00
0005432531631	30609	Comfort	23900.00
0005432531204	30609	Comfort	23900.00
0005432531195	30609	Comfort	23900.00
0005434069315	30609	Comfort	23900.00
0005432531265	30609	Economy	14000.00
0005434069409	30609	Economy	14000.00
0005432531591	30609	Economy	14000.00
0005432537110	30609	Economy	14000.00
0005432531051	30609	Economy	14000.00
0005435283553	30609	Economy	14000.00
0005432531031	30609	Economy	14000.00
0005432531138	30609	Economy	14000.00
0005432429018	30609	Economy	14000.00
0005434069275	30609	Economy	14000.00
0005432530600	30609	Economy	14000.00
0005434069191	30609	Economy	14000.00
0005432531560	30609	Economy	14000.00
0005432537111	30609	Economy	14000.00
0005434069208	30609	Economy	14000.00
0005432531672	30609	Economy	14000.00
0005434069081	30609	Economy	14000.00
0005434069059	30609	Economy	14000.00
0005432531028	30609	Economy	14000.00
0005432531116	30609	Economy	14000.00
0005434069146	30609	Economy	14000.00
0005434069383	30609	Economy	14000.00
0005432530939	30609	Economy	14000.00
0005434069324	30609	Economy	14000.00
0005432531559	30609	Economy	14000.00
0005432530813	30609	Economy	14000.00
0005434069541	30609	Economy	14000.00
0005432530934	30609	Economy	14000.00
0005432530863	30609	Economy	14000.00
0005434069523	30609	Economy	14000.00
0005434069188	30609	Economy	14000.00
0005432531544	30609	Economy	14000.00
0005432531541	30609	Economy	14000.00
0005432531113	30609	Economy	14000.00
0005432531581	30609	Economy	14000.00
0005434069122	30609	Economy	14000.00
0005435215532	30609	Economy	15400.00
0005432531052	30609	Economy	14000.00
0005432429005	30609	Economy	14000.00
0005434069371	30609	Economy	14000.00
0005432531433	30609	Economy	15400.00
0005432531139	30609	Economy	15400.00
0005434068993	30609	Economy	14000.00
0005434069115	30609	Economy	14000.00
0005434068992	30609	Economy	14000.00
0005435215533	30609	Economy	14000.00
0005434069257	30609	Economy	14000.00
0005432531208	30609	Economy	14000.00
0005432531147	30609	Economy	14000.00
0005432530928	30609	Economy	14000.00
0005432531540	30609	Economy	14000.00
0005434069011	30609	Economy	14000.00
0005432531395	30609	Economy	14000.00
0005434069162	30609	Economy	14000.00
0005432530539	30609	Economy	14000.00
0005432531628	30609	Economy	14000.00
0005432531141	30609	Economy	14000.00
0005432531349	30609	Economy	14000.00
0005432531427	30609	Economy	14000.00
0005432530950	30609	Economy	14000.00
0005434068959	30609	Economy	14000.00
0005434069309	30609	Economy	14000.00
0005432530820	30609	Economy	14000.00
0005434069180	30609	Economy	14000.00
0005432531545	30609	Economy	14000.00
0005434068951	30609	Economy	14000.00
0005432535948	30609	Economy	14000.00
0005434069211	30609	Economy	14000.00
0005434069189	30609	Economy	14000.00
0005432531194	30609	Economy	14000.00
0005434069471	30609	Economy	14000.00
0005432531181	30609	Economy	14000.00
0005432530538	30609	Economy	14000.00
0005434069120	30609	Economy	14000.00
0005432531350	30609	Economy	14000.00
0005432531426	30609	Economy	14000.00
0005432531140	30609	Economy	14000.00
0005432531124	30609	Economy	14000.00
0005435283554	30609	Economy	14000.00
0005432531313	30609	Economy	14000.00
0005434069274	30609	Economy	14000.00
0005432533366	30609	Economy	14000.00
0005432531128	30609	Economy	14000.00
0005434069380	30609	Economy	14000.00
0005432531125	30609	Economy	14000.00
0005434069367	30609	Economy	14000.00
0005434069281	30609	Economy	14000.00
0005434069370	30609	Economy	14000.00
0005432531450	30609	Economy	14000.00
0005434069262	30609	Economy	14000.00
0005434069058	30609	Economy	14000.00
0005434069121	30609	Economy	14000.00
0005432531356	30609	Economy	14000.00
0005432530994	30609	Economy	14000.00
0005432530951	30609	Economy	14000.00
0005434069542	30609	Economy	14000.00
0005434068849	30609	Economy	14000.00
0005434069417	30609	Economy	14000.00
0005432531558	30609	Economy	14000.00
0005434069368	30609	Economy	14000.00
0005434069310	30609	Economy	14000.00
0005434069094	30609	Economy	14000.00
0005432531148	30609	Economy	14000.00
0005432531187	30609	Economy	14000.00
0005434069335	30609	Economy	14000.00
0005432531144	30609	Economy	14000.00
0005432531027	30609	Economy	14000.00
0005432531546	30609	Economy	14000.00
0005432531539	30609	Economy	14000.00
0005432531471	30609	Economy	14000.00
0005434069150	30609	Economy	14000.00
0005432429017	30609	Economy	14000.00
0005432531590	30609	Economy	14000.00
0005432530601	30609	Economy	14000.00
0005432530960	30609	Economy	14000.00
0005432531119	30609	Economy	14000.00
0005432531524	30609	Economy	14000.00
0005432531134	30609	Economy	14000.00
0005432530961	30609	Economy	14000.00
0005432531525	30609	Economy	14000.00
0005432531428	30609	Economy	14000.00
0005432531032	30609	Economy	14000.00
0005432530757	30609	Economy	14000.00
0005434069237	30609	Economy	14000.00
0005432530959	30609	Economy	14000.00
0005432530935	30609	Economy	14000.00
0005434069065	30609	Economy	14000.00
0005432531592	30609	Economy	14000.00
0005434068950	30609	Economy	14000.00
0005434069095	30609	Economy	14000.00
0005432530958	30609	Economy	14000.00
0005432531114	30609	Economy	14000.00
0005432537112	30609	Economy	14000.00
0005432531434	30609	Economy	14000.00
0005434069586	30609	Economy	14000.00
0005434069512	30609	Economy	14000.00
0005434069114	30609	Economy	14000.00
0005434069455	30609	Economy	14000.00
0005432530864	30609	Economy	14000.00
0005434069354	30609	Economy	14000.00
0005434069369	30609	Economy	14000.00
0005435653988	24824	Business	9800.00
0005435654148	24824	Business	9800.00
0005435654086	24824	Business	9800.00
0005435654104	24824	Business	9800.00
0005435653827	24824	Business	9800.00
0005435654245	24824	Business	9800.00
0005435653965	24824	Business	9800.00
0005435654113	24824	Business	9800.00
0005435654266	24824	Business	9800.00
0005435654083	24824	Economy	3300.00
0005435654094	24824	Economy	3300.00
0005435654270	24824	Economy	3300.00
0005435654149	24824	Economy	3300.00
0005435654082	24824	Economy	3300.00
0005435654162	24824	Economy	3300.00
0005435653838	24824	Economy	3600.00
0005435654116	24824	Economy	3600.00
0005435654278	24824	Economy	3600.00
0005435654147	24824	Economy	3600.00
0005435653828	24824	Economy	3300.00
0005435654226	24824	Economy	3300.00
0005435654138	24824	Economy	3300.00
0005435654021	24824	Economy	3300.00
0005435654187	24824	Economy	3300.00
0005435654231	24824	Economy	3300.00
0005435654121	24824	Economy	3300.00
0005435654110	24824	Economy	3300.00
0005435654316	24824	Economy	3300.00
0005435654186	24824	Economy	3300.00
0005435654234	24824	Economy	3300.00
0005435654185	24824	Economy	3300.00
0005435654216	24824	Economy	3300.00
0005435654115	24824	Economy	3300.00
0005435654232	24824	Economy	3300.00
0005435790417	24824	Economy	3300.00
0005435654079	24824	Economy	3300.00
0005435654255	24824	Economy	3300.00
0005435654219	24824	Economy	3300.00
0005435654184	24824	Economy	3300.00
0005435654223	24824	Economy	3300.00
0005435654318	24824	Economy	3300.00
0005435654265	24824	Economy	3300.00
0005435654173	24824	Economy	3300.00
0005435654240	24824	Economy	3300.00
0005435653963	24824	Economy	3300.00
0005435654018	24824	Economy	3300.00
0005435654215	24824	Economy	3300.00
0005435654164	24824	Economy	3300.00
0005435654241	24824	Economy	3300.00
0005435654105	24824	Economy	3300.00
0005435654017	24824	Economy	3300.00
0005435653964	24824	Economy	3300.00
0005435654317	24824	Economy	3300.00
0005435654075	24824	Economy	3300.00
0005435654048	24824	Economy	3300.00
0005435654315	24824	Economy	3300.00
0005435654014	24824	Economy	3300.00
0005435654084	24824	Economy	3300.00
0005435654093	24824	Economy	3300.00
0005435654146	24824	Economy	3300.00
0005434980465	23555	Economy	10500.00
0005434980480	23555	Economy	10500.00
0005434980469	23555	Economy	9500.00
0005434980466	23555	Economy	9500.00
0005434980379	23555	Economy	9500.00
0005434980424	23555	Economy	9500.00
0005434980475	23555	Economy	9500.00
0005435801768	23555	Economy	9500.00
0005434980443	23555	Economy	9500.00
0005434980479	23555	Economy	9500.00
0005434980468	23555	Economy	9500.00
0005434980615	23555	Economy	9500.00
0005434980446	23555	Economy	9500.00
0005434980515	23555	Economy	9500.00
0005434980511	23555	Economy	9500.00
0005435801778	23555	Economy	9500.00
0005434980449	23555	Economy	9500.00
0005434980444	23555	Economy	9500.00
0005434980510	23555	Economy	9500.00
0005434980404	23555	Economy	9500.00
0005434980467	23555	Economy	9500.00
0005435801767	23555	Economy	9500.00
0005434980531	23555	Economy	9500.00
0005435801771	23555	Economy	9500.00
0005434980499	23555	Economy	9500.00
0005434980488	23555	Economy	9500.00
0005434980616	23555	Economy	9500.00
0005433256490	2668	Economy	5300.00
0005434952622	28229	Economy	5300.00
0005433256495	28229	Economy	5300.00
0005434952623	28229	Economy	5300.00
0005434302896	19739	Economy	8700.00
0005434302889	19739	Economy	8700.00
0005434302890	19739	Economy	8700.00
0005434302891	19739	Economy	8700.00
0005434302888	19739	Economy	8700.00
0005434302893	19739	Economy	8700.00
0005434302887	19739	Economy	8700.00
0005434140395	11936	Business	9700.00
0005434140469	11936	Business	9700.00
0005434139996	11936	Business	9700.00
0005434140220	11936	Business	9700.00
0005434140205	11936	Business	9700.00
0005434140351	11936	Business	9700.00
0005434140006	11936	Business	9700.00
0005434140083	11936	Business	9700.00
0005434140191	11936	Business	9700.00
0005434139934	11936	Business	9700.00
0005434139959	11936	Business	9700.00
0005434140273	11936	Business	9700.00
0005434140348	11936	Economy	3200.00
0005434140488	11936	Economy	3200.00
0005434139874	11936	Economy	3200.00
0005434140214	11936	Economy	3200.00
0005434140354	11936	Economy	3200.00
0005434140126	11936	Economy	3200.00
0005434140101	11936	Economy	3200.00
0005434140417	11936	Economy	3200.00
0005434140500	11936	Economy	3200.00
0005434140119	11936	Economy	3200.00
0005434140267	11936	Economy	3500.00
0005434140231	11936	Economy	3500.00
0005434140037	11936	Economy	3500.00
0005434140266	11936	Economy	3500.00
0005434139994	11936	Economy	3200.00
0005434140349	11936	Economy	3200.00
0005434140332	11936	Economy	3200.00
0005434139702	11936	Economy	3200.00
0005434140355	11936	Economy	3200.00
0005434140194	11936	Economy	3200.00
0005434140314	11936	Economy	3200.00
0005434140430	11936	Economy	3200.00
0005434140195	11936	Economy	3200.00
0005434140174	11936	Economy	3200.00
0005434140042	11936	Economy	3200.00
0005434140102	11936	Economy	3200.00
0005434140203	11936	Economy	3200.00
0005434140103	11936	Economy	3200.00
0005434140434	11936	Economy	3200.00
0005434140070	11936	Economy	3200.00
0005434140257	11936	Economy	3200.00
0005434139881	11936	Economy	3200.00
0005434140246	11936	Economy	3200.00
0005434140162	11936	Economy	3200.00
0005434140243	11936	Economy	3200.00
0005434140435	11936	Economy	3200.00
0005434140412	11936	Economy	3200.00
0005434140125	11936	Economy	3200.00
0005434140245	11936	Economy	3200.00
0005434140236	11936	Economy	3200.00
0005434140331	11936	Economy	3200.00
0005434140124	11936	Economy	3200.00
0005434140038	11936	Economy	3200.00
0005434140268	11936	Economy	3200.00
0005434140293	11936	Economy	3200.00
0005434140143	11936	Economy	3200.00
0005434140163	11936	Economy	3200.00
0005434140237	11936	Economy	3200.00
0005434140352	11936	Economy	3200.00
0005434140272	11936	Economy	3200.00
0005434140036	11936	Economy	3200.00
0005434140309	11936	Economy	3200.00
0005434140230	11936	Economy	3200.00
0005434140023	11936	Economy	3200.00
0005434140155	11936	Economy	3200.00
0005434140224	11936	Economy	3200.00
0005434139970	11936	Economy	3200.00
0005434140248	11936	Economy	3200.00
0005434140156	11936	Economy	3200.00
0005434140278	11936	Economy	3200.00
0005434140294	11936	Economy	3200.00
0005434139971	11936	Economy	3200.00
0005434140204	11936	Economy	3200.00
0005434140271	11936	Economy	3200.00
0005434140192	11936	Economy	3200.00
0005434139880	11936	Economy	3200.00
0005434140096	11936	Economy	3200.00
0005434140115	11936	Economy	3200.00
0005434140117	11936	Economy	3200.00
0005434140127	11936	Economy	3200.00
0005434140394	11936	Economy	3200.00
0005434140265	11936	Economy	3200.00
0005434140007	11936	Economy	3200.00
0005434140069	11936	Economy	3200.00
0005434140105	11936	Economy	3200.00
0005434140387	11936	Economy	3200.00
0005434140623	28766	Business	9700.00
0005434140613	28766	Business	9700.00
0005434140616	28766	Economy	3500.00
0005434140617	28766	Economy	3500.00
0005434140624	28766	Economy	3200.00
0005434140615	28766	Economy	3200.00
0005434140609	28766	Economy	3200.00
0005434140620	28766	Economy	3200.00
0005434140611	28766	Economy	3200.00
0005434140619	28766	Economy	3200.00
0005434140621	28766	Economy	3200.00
0005434140614	28766	Economy	3200.00
0005434140618	28766	Economy	3200.00
0005434140622	28766	Economy	3200.00
0005434140612	28766	Economy	3200.00
0005434140610	28766	Economy	3200.00
0005435259874	6778	Economy	9900.00
0005435259877	6778	Economy	9900.00
0005435259873	6778	Economy	9900.00
0005433539124	6778	Economy	9900.00
0005433539094	25013	Economy	10900.00
0005433539078	25013	Economy	9900.00
0005433534546	25013	Economy	9900.00
0005433539067	25013	Economy	9900.00
0005433539068	25013	Economy	9900.00
0005432922629	836	Economy	14600.00
0005432922637	836	Economy	14600.00
0005432922621	836	Economy	14600.00
0005433512198	836	Economy	14600.00
0005432922623	836	Economy	14600.00
0005433512197	836	Economy	14600.00
0005432922622	836	Economy	14600.00
0005433512162	16154	Economy	16100.00
0005433512166	16154	Economy	14600.00
0005433512120	16154	Economy	14600.00
0005433512152	16154	Economy	14600.00
0005433512161	16154	Economy	14600.00
0005435933563	3646	Economy	7900.00
0005435935128	3646	Economy	7200.00
0005435698179	3646	Economy	7200.00
0005435935129	3646	Economy	7200.00
0005435916246	3646	Economy	7200.00
0005435933561	3646	Economy	7200.00
0005435933562	3646	Economy	7200.00
0005435916244	3646	Economy	7200.00
0005435935134	3646	Economy	7200.00
0005435916227	3646	Economy	7200.00
0005435916229	3646	Economy	7200.00
0005435916245	3646	Economy	7200.00
0005435916228	3646	Economy	7200.00
0005435697991	16286	Economy	7200.00
0005435698104	16286	Economy	7200.00
0005434950638	16286	Economy	7200.00
0005435697999	16286	Economy	7200.00
0005435697888	16286	Economy	7200.00
0005435698086	16286	Economy	7200.00
0005435916247	16286	Economy	7200.00
0005435698007	16286	Economy	7200.00
0005435697988	16286	Economy	7200.00
0005435698125	16286	Economy	7200.00
0005435697989	16286	Economy	7200.00
0005435697990	16286	Economy	7200.00
0005435697939	16286	Economy	7200.00
0005435698026	16286	Economy	7200.00
0005434950629	16286	Economy	7200.00
0005435698070	16286	Economy	7200.00
0005435698115	16286	Economy	7200.00
0005435698008	16286	Economy	7200.00
0005435697940	16286	Economy	7200.00
0005434950650	16286	Economy	7200.00
0005434950641	16286	Economy	7200.00
0005434950634	16286	Economy	7200.00
0005435698000	16286	Economy	7200.00
0005435853662	3933	Economy	19300.00
0005432609852	3933	Economy	19300.00
0005435853661	3933	Economy	19300.00
0005435853663	3933	Economy	19300.00
0005435853659	3933	Economy	19300.00
0005435853664	3933	Economy	19300.00
0005435853660	3933	Economy	19300.00
0005435841127	22076	Economy	21300.00
0005432609831	22076	Economy	21300.00
0005432609812	22076	Economy	21300.00
0005432613969	22076	Economy	19300.00
0005432609820	22076	Economy	19300.00
0005432613968	22076	Economy	19300.00
0005432609817	22076	Economy	19300.00
0005432613959	22076	Economy	19300.00
0005435841128	22076	Economy	19300.00
0005432609819	22076	Economy	19300.00
0005432613957	22076	Economy	19300.00
0005434606914	22076	Economy	19300.00
0005434606899	22076	Economy	19300.00
0005432609826	22076	Economy	19300.00
0005432609827	22076	Economy	19300.00
0005432609811	22076	Economy	19300.00
0005432609838	22076	Economy	19300.00
0005432613948	22076	Economy	19300.00
0005432609806	22076	Economy	19300.00
0005432609796	22076	Economy	19300.00
0005432613964	22076	Economy	19300.00
0005433519570	22076	Economy	19300.00
0005432609839	22076	Economy	19300.00
0005432609789	22076	Economy	19300.00
0005433519575	22076	Economy	19300.00
0005434606913	22076	Economy	19300.00
0005432609795	22076	Economy	19300.00
0005432613929	22076	Economy	19300.00
0005432613961	22076	Economy	19300.00
0005434603022	22076	Economy	19300.00
0005432613977	22076	Economy	19300.00
0005433519576	22076	Economy	19300.00
0005433519567	22076	Economy	19300.00
0005432613942	22076	Economy	19300.00
0005432613947	22076	Economy	19300.00
0005433519568	22076	Economy	19300.00
0005432613965	22076	Economy	19300.00
0005432613938	22076	Economy	19300.00
0005432609818	22076	Economy	19300.00
0005432609808	22076	Economy	19300.00
0005435841126	22076	Economy	19300.00
0005432609813	22076	Economy	19300.00
0005432613956	22076	Economy	19300.00
0005434606912	22076	Economy	19300.00
0005432609807	22076	Economy	19300.00
0005432613955	22076	Economy	19300.00
0005432609828	22076	Economy	19300.00
0005434603021	22076	Economy	19300.00
0005433349136	773	Economy	3700.00
0005433349124	773	Economy	3700.00
0005433349133	773	Economy	3700.00
0005433349153	773	Economy	3700.00
0005433349135	773	Economy	3700.00
0005435628814	15906	Economy	3700.00
0005435628819	15906	Economy	3700.00
0005435628815	15906	Economy	3700.00
0005434446592	17197	Economy	7100.00
0005433158190	17197	Economy	7100.00
0005433158184	17197	Economy	7100.00
0005434445312	17577	Economy	7100.00
0005434445306	17577	Economy	7100.00
0005434445313	17577	Economy	7100.00
0005434445301	17577	Economy	7100.00
0005435383262	7889	Economy	5400.00
0005435133200	7889	Economy	5400.00
0005435383268	7889	Economy	5400.00
0005435383284	7889	Economy	5400.00
0005435133199	7889	Economy	5400.00
0005435383296	7889	Economy	5400.00
0005435383263	7889	Economy	5400.00
0005435133136	33077	Economy	5400.00
0005435133176	33077	Economy	5400.00
0005435133135	33077	Economy	5400.00
0005435133162	33077	Economy	5400.00
0005435133179	33077	Economy	5400.00
0005435133153	33077	Economy	5400.00
0005435133177	33077	Economy	5400.00
0005435133160	33077	Economy	5400.00
0005435133174	33077	Economy	5400.00
0005435133161	33077	Economy	5400.00
0005435811230	4401	Business	133200.00
0005435938948	4401	Business	133200.00
0005435938941	4401	Economy	44400.00
0005435811228	4401	Economy	44400.00
0005435938945	4401	Economy	44400.00
0005435938946	4401	Economy	44400.00
0005435811229	4401	Economy	44400.00
0005435811198	29445	Business	133200.00
0005435811194	29445	Business	133200.00
0005435811200	29445	Economy	48800.00
0005435811214	29445	Economy	44400.00
0005435811205	29445	Economy	44400.00
0005435811184	29445	Economy	44400.00
0005435811199	29445	Economy	44400.00
0005435811204	29445	Economy	44400.00
0005435811187	29445	Economy	44400.00
0005435811196	29445	Economy	44400.00
0005435811183	29445	Economy	44400.00
0005435811197	29445	Economy	44400.00
0005435390427	7473	Economy	13800.00
0005435390414	7473	Economy	12500.00
0005435390424	7473	Economy	12500.00
0005435390423	7473	Economy	12500.00
0005435390370	7473	Economy	12500.00
0005435390411	7473	Economy	12500.00
0005435390428	7473	Economy	12500.00
0005435390429	7473	Economy	12500.00
0005435390403	7473	Economy	12500.00
0005435390421	7473	Economy	12500.00
0005435390420	7473	Economy	12500.00
0005435160606	29559	Economy	13800.00
0005435160612	29559	Economy	12500.00
0005435160594	29559	Economy	12500.00
0005435160593	29559	Economy	12500.00
0005435160582	29559	Economy	12500.00
0005435160581	29559	Economy	12500.00
0005435160595	29559	Economy	12500.00
0005432398280	18449	Economy	4900.00
0005432398302	18449	Economy	4900.00
0005432398291	18449	Economy	4900.00
0005432398303	18449	Economy	4900.00
0005432398293	18449	Economy	4900.00
0005432398290	18449	Economy	4900.00
0005435179415	27153	Economy	4900.00
0005435179416	27153	Economy	4900.00
0005435179419	27153	Economy	4900.00
0005435178525	27153	Economy	4900.00
0005434552919	9810	Economy	4400.00
0005434191315	9810	Economy	4400.00
0005434191316	9810	Economy	4400.00
0005435104381	6544	Business	48400.00
0005435104383	6544	Economy	17800.00
0005435104384	6544	Economy	16100.00
0005434505319	6544	Economy	16100.00
0005435104382	6544	Economy	16100.00
0005434504929	22654	Business	48400.00
0005434505220	22654	Business	48400.00
0005435312885	22654	Business	48400.00
0005435104133	22654	Business	48400.00
0005435312884	22654	Business	48400.00
0005435312882	22654	Business	48400.00
0005434504821	22654	Business	48400.00
0005434505077	22654	Economy	16100.00
0005434505141	22654	Economy	16100.00
0005434504993	22654	Economy	16100.00
0005435104088	22654	Economy	16100.00
0005434505116	22654	Economy	16100.00
0005435104113	22654	Economy	16100.00
0005435104140	22654	Economy	16100.00
0005435104092	22654	Economy	16100.00
0005434505140	22654	Economy	17800.00
0005434505244	22654	Economy	17800.00
0005434505059	22654	Economy	17800.00
0005434504956	22654	Economy	16100.00
0005434504958	22654	Economy	16100.00
0005434505057	22654	Economy	16100.00
0005434504922	22654	Economy	16100.00
0005434505148	22654	Economy	16100.00
0005435104089	22654	Economy	16100.00
0005435312883	22654	Economy	16100.00
0005434505038	22654	Economy	16100.00
0005434504715	22654	Economy	16100.00
0005435104127	22654	Economy	16100.00
0005434505134	22654	Economy	16100.00
0005434505039	22654	Economy	16100.00
0005434505049	22654	Economy	16100.00
0005434505102	22654	Economy	16100.00
0005434505072	22654	Economy	16100.00
0005434505101	22654	Economy	16100.00
0005434504992	22654	Economy	16100.00
0005434505207	22654	Economy	16100.00
0005434505115	22654	Economy	16100.00
0005434505258	22654	Economy	16100.00
0005435104117	22654	Economy	16100.00
0005435104125	22654	Economy	16100.00
0005434505146	22654	Economy	16100.00
0005435104105	22654	Economy	16100.00
0005435104098	22654	Economy	16100.00
0005434505056	22654	Economy	16100.00
0005434505206	22654	Economy	16100.00
0005435104097	22654	Economy	16100.00
0005434505060	22654	Economy	16100.00
0005434505014	22654	Economy	16100.00
0005434504991	22654	Economy	16100.00
0005434504822	22654	Economy	16100.00
0005434505121	22654	Economy	16100.00
0005434505145	22654	Economy	16100.00
0005434505147	22654	Economy	16100.00
0005434505149	22654	Economy	16100.00
0005434505035	22654	Economy	16100.00
0005435104096	22654	Economy	16100.00
0005435104132	22654	Economy	16100.00
0005435800150	21310	Economy	16800.00
0005435800147	21310	Economy	15300.00
0005435800158	21310	Economy	15300.00
0005435800155	21310	Economy	15300.00
0005435800148	21310	Economy	15300.00
0005435800153	21310	Economy	15300.00
0005435800146	21310	Economy	15300.00
0005435800152	21310	Economy	15300.00
0005435800156	21310	Economy	15300.00
0005435800145	21310	Economy	15300.00
0005435800151	21310	Economy	15300.00
0005435800159	21310	Economy	15300.00
0005435800154	21310	Economy	15300.00
0005435800157	21310	Economy	15300.00
0005435800160	21310	Economy	15300.00
0005433368765	1655	Business	50000.00
0005433368743	1655	Business	50000.00
0005433368798	1655	Business	50000.00
0005433368864	1655	Business	50000.00
0005433368756	1655	Business	50000.00
0005435654496	1655	Business	50000.00
0005433368913	1655	Business	50000.00
0005433368918	1655	Business	50000.00
0005433368814	1655	Economy	16700.00
0005433368878	1655	Economy	16700.00
0005433368783	1655	Economy	16700.00
0005433368752	1655	Economy	16700.00
0005433368728	1655	Economy	16700.00
0005433368753	1655	Economy	16700.00
0005433368742	1655	Economy	18300.00
0005433368727	1655	Economy	18300.00
0005433368778	1655	Economy	18300.00
0005433368856	1655	Economy	16700.00
0005433368745	1655	Economy	16700.00
0005433368889	1655	Economy	16700.00
0005433368877	1655	Economy	16700.00
0005433368840	1655	Economy	16700.00
0005435654497	1655	Economy	16700.00
0005433368892	1655	Economy	16700.00
0005433368724	1655	Economy	16700.00
0005433368759	1655	Economy	16700.00
0005433368774	1655	Economy	16700.00
0005433368760	1655	Economy	16700.00
0005433368748	1655	Economy	16700.00
0005435654495	1655	Economy	16700.00
0005433368865	1655	Economy	16700.00
0005433368776	1655	Economy	16700.00
0005433368777	1655	Economy	16700.00
0005433368812	1655	Economy	16700.00
0005433368755	1655	Economy	16700.00
0005433368876	1655	Economy	16700.00
0005433368764	1655	Economy	16700.00
0005433368919	1655	Economy	16700.00
0005433368709	1655	Economy	16700.00
0005433368747	1655	Economy	16700.00
0005433368708	1655	Economy	16700.00
0005433368815	1655	Economy	16700.00
0005433368786	1655	Economy	16700.00
0005433368914	1655	Economy	16700.00
0005433368838	1655	Economy	16700.00
0005433368912	1655	Economy	16700.00
0005433368763	1655	Economy	16700.00
0005433368779	1655	Economy	16700.00
0005433368746	1655	Economy	16700.00
0005433368883	1655	Economy	16700.00
0005435654148	21672	Business	50000.00
0005435654164	21672	Business	50000.00
0005435654110	21672	Business	50000.00
0005435654186	21672	Business	50000.00
0005435654082	21672	Business	50000.00
0005435654232	21672	Economy	16700.00
0005435654240	21672	Economy	16700.00
0005435654316	21672	Economy	16700.00
0005435654048	21672	Economy	16700.00
0005435654017	21672	Economy	16700.00
0005435654075	21672	Economy	16700.00
0005435654234	21672	Economy	16700.00
0005435654115	21672	Economy	16700.00
0005435654270	21672	Economy	18300.00
0005435654184	21672	Economy	18300.00
0005435654216	21672	Economy	16700.00
0005435654265	21672	Economy	16700.00
0005435654083	21672	Economy	16700.00
0005435654086	21672	Economy	16700.00
0005435654255	21672	Economy	16700.00
0005435653838	21672	Economy	16700.00
0005435654121	21672	Economy	16700.00
0005435654315	21672	Economy	16700.00
0005435654226	21672	Economy	16700.00
0005435653828	21672	Economy	16700.00
0005435654318	21672	Economy	16700.00
0005435653988	21672	Economy	16700.00
0005435654266	21672	Economy	16700.00
0005435653965	21672	Economy	16700.00
0005435654146	21672	Economy	16700.00
0005435654245	21672	Economy	16700.00
0005435653964	21672	Economy	16700.00
0005435653963	21672	Economy	16700.00
0005435654185	21672	Economy	16700.00
0005435654105	21672	Economy	16700.00
0005435654241	21672	Economy	16700.00
0005435654173	21672	Economy	16700.00
0005435654223	21672	Economy	16700.00
0005435654116	21672	Economy	16700.00
0005435654093	21672	Economy	16700.00
0005435654231	21672	Economy	16700.00
0005435654317	21672	Economy	16700.00
0005435654079	21672	Economy	16700.00
0005435654021	21672	Economy	16700.00
0005435654084	21672	Economy	16700.00
0005435654187	21672	Economy	16700.00
0005435654147	21672	Economy	16700.00
0005435653827	21672	Economy	16700.00
0005435654215	21672	Economy	16700.00
0005435654104	21672	Economy	16700.00
0005435654278	21672	Economy	16700.00
0005435654094	21672	Economy	16700.00
0005435654113	21672	Economy	16700.00
0005435654014	21672	Economy	16700.00
0005435654162	21672	Economy	16700.00
0005435654018	21672	Economy	16700.00
0005435654138	21672	Economy	16700.00
0005435654149	21672	Economy	16700.00
0005435654219	21672	Economy	16700.00
0005433987378	4163	Economy	7200.00
0005433987192	25686	Business	21500.00
0005433987161	25686	Business	21500.00
0005433987350	25686	Business	21500.00
0005433987123	25686	Business	21500.00
0005433987173	25686	Business	21500.00
0005433987120	25686	Business	21500.00
0005433986926	25686	Business	21500.00
0005433987163	25686	Business	21500.00
0005433987241	25686	Business	21500.00
0005433987212	25686	Economy	7200.00
0005433987050	25686	Economy	7200.00
0005433986983	25686	Economy	7200.00
0005433987186	25686	Economy	7200.00
0005433986985	25686	Economy	7200.00
0005433987034	25686	Economy	7200.00
0005433987112	25686	Economy	7200.00
0005433987185	25686	Economy	7900.00
0005433987079	25686	Economy	7900.00
0005433987132	25686	Economy	7200.00
0005433987157	25686	Economy	7200.00
0005433987118	25686	Economy	7200.00
0005433987158	25686	Economy	7200.00
0005433987084	25686	Economy	7200.00
0005433986906	25686	Economy	7200.00
0005433987137	25686	Economy	7200.00
0005433987110	25686	Economy	7200.00
0005433986942	25686	Economy	7200.00
0005433987174	25686	Economy	7200.00
0005433987156	25686	Economy	7200.00
0005433987102	25686	Economy	7200.00
0005433987130	25686	Economy	7200.00
0005433986864	25686	Economy	7200.00
0005433987087	25686	Economy	7200.00
0005433987160	25686	Economy	7200.00
0005433986944	25686	Economy	7200.00
0005433987150	25686	Economy	7200.00
0005433987076	25686	Economy	7200.00
0005433986910	25686	Economy	7200.00
0005433987131	25686	Economy	7200.00
0005433987094	25686	Economy	7200.00
0005433987349	25686	Economy	7200.00
0005433987178	25686	Economy	7200.00
0005433987080	25686	Economy	7200.00
0005433987045	25686	Economy	7200.00
0005435860636	25686	Economy	7200.00
0005433986956	25686	Economy	7200.00
0005433987133	25686	Economy	7200.00
0005433987035	25686	Economy	7200.00
0005433986927	25686	Economy	7200.00
0005435860635	25686	Economy	7200.00
0005433986943	25686	Economy	7200.00
0005433987073	25686	Economy	7200.00
0005433987228	25686	Economy	7200.00
0005433987282	25686	Economy	7200.00
0005433987111	25686	Economy	7200.00
0005433987164	25686	Economy	7200.00
0005433987176	25686	Economy	7200.00
0005433986949	25686	Economy	7200.00
0005433987177	25686	Economy	7200.00
0005433986935	25686	Economy	7200.00
0005435719594	21278	Economy	9400.00
0005435719585	21278	Economy	9400.00
0005435719586	21278	Economy	9400.00
0005433168482	1627	Economy	15500.00
0005433168489	1627	Economy	15500.00
0005433168476	1627	Economy	15500.00
0005433168465	1627	Economy	15500.00
0005434509380	1627	Economy	15500.00
0005433168466	1627	Economy	15500.00
0005433168488	1627	Economy	15500.00
0005433168490	1627	Economy	15500.00
0005433168467	1627	Economy	15500.00
0005433168491	1627	Economy	15500.00
0005432655825	17832	Business	18000.00
0005432655831	17832	Business	18000.00
0005432655822	17832	Business	18000.00
0005432655812	17832	Economy	6000.00
0005432663096	17832	Economy	6000.00
0005432660877	17832	Economy	6000.00
0005432663090	17832	Economy	6000.00
0005432665328	17832	Economy	6600.00
0005432655811	17832	Economy	6600.00
0005432666441	17832	Economy	6000.00
0005434151796	17832	Economy	6000.00
0005432655824	17832	Economy	6000.00
0005432657524	17832	Economy	6000.00
0005432658648	17832	Economy	6000.00
0005432655829	17832	Economy	6000.00
0005432657529	17832	Economy	6000.00
0005432655792	17832	Economy	6000.00
0005432659759	17832	Economy	6000.00
0005432666440	17832	Economy	6000.00
0005432655838	17832	Economy	6000.00
0005432655879	17832	Economy	6000.00
0005432655793	17832	Economy	6000.00
0005432655837	17832	Economy	6000.00
0005432666430	17832	Economy	6000.00
0005432658642	17832	Economy	6000.00
0005432655830	17832	Economy	6000.00
0005432667510	17832	Economy	6000.00
0005432655842	17832	Economy	6000.00
0005432657527	17832	Economy	6000.00
0005432657530	17832	Economy	6000.00
0005432666432	17832	Economy	6000.00
0005432655816	17832	Economy	6000.00
0005432655836	17832	Economy	6000.00
0005432658643	17832	Economy	6000.00
0005432667507	17832	Economy	6000.00
0005432655880	17832	Economy	6000.00
0005432657528	17832	Economy	6000.00
0005432666442	17832	Economy	6000.00
0005432667506	17832	Economy	6000.00
0005432655843	17832	Economy	6000.00
0005432666433	17832	Economy	6000.00
0005432660872	17832	Economy	6000.00
0005432660873	17832	Economy	6000.00
0005432660871	17832	Economy	6000.00
0005432663091	17832	Economy	6000.00
0005432869665	26289	Business	18000.00
0005432869671	26289	Business	18000.00
0005432659770	26289	Business	18000.00
0005432869680	26289	Economy	6000.00
0005432657541	26289	Economy	6000.00
0005432869664	26289	Economy	6000.00
0005432655891	26289	Economy	6000.00
0005432869697	26289	Economy	6000.00
0005432869672	26289	Economy	6000.00
0005432869670	26289	Economy	6000.00
0005432655892	26289	Economy	6000.00
0005432869690	26289	Economy	6000.00
0005432657540	26289	Economy	6000.00
0005432659769	26289	Economy	6000.00
0005432869698	26289	Economy	6000.00
0005432869689	26289	Economy	6000.00
0005432639429	25060	Business	87300.00
0005432639463	25060	Business	87300.00
0005432639363	25060	Business	87300.00
0005432639425	25060	Economy	29100.00
0005432639406	25060	Economy	32000.00
0005432639436	25060	Economy	32000.00
0005432639344	25060	Economy	29100.00
0005432639424	25060	Economy	29100.00
0005432639423	25060	Economy	29100.00
0005432639411	25060	Economy	29100.00
0005432639443	25060	Economy	29100.00
0005432639435	25060	Economy	29100.00
0005432639410	25060	Economy	29100.00
0005432639466	25060	Economy	29100.00
0005432639427	25060	Economy	29100.00
0005432639414	25060	Economy	29100.00
0005432639389	25060	Economy	29100.00
0005432639437	25060	Economy	29100.00
0005432639415	25060	Economy	29100.00
0005432639388	25060	Economy	29100.00
0005432639428	25060	Economy	29100.00
0005432639430	25060	Economy	29100.00
0005432639434	25060	Economy	29100.00
0005432905273	3069	Economy	5900.00
0005432330057	3069	Economy	5400.00
0005433439112	3069	Economy	5400.00
0005432905246	3069	Economy	5400.00
0005432905247	3069	Economy	5400.00
0005432330056	3069	Economy	5400.00
0005433439111	3069	Economy	5400.00
0005432905289	3069	Economy	5400.00
0005432330058	3069	Economy	5400.00
0005432330059	3069	Economy	5400.00
0005432329762	31145	Business	16100.00
0005432329903	31145	Business	16100.00
0005433439040	31145	Business	16100.00
0005432329604	31145	Business	16100.00
0005433439021	31145	Business	16100.00
0005432329914	31145	Business	16100.00
0005432329878	31145	Business	16100.00
0005432329660	31145	Economy	5400.00
0005432329637	31145	Economy	5400.00
0005432329661	31145	Economy	5400.00
0005432329876	31145	Economy	5400.00
0005432329839	31145	Economy	5900.00
0005432329909	31145	Economy	5400.00
0005432329763	31145	Economy	5400.00
0005432329746	31145	Economy	5400.00
0005432329656	31145	Economy	5400.00
0005432329954	31145	Economy	5400.00
0005432329553	31145	Economy	5400.00
0005433439054	31145	Economy	5400.00
0005432329769	31145	Economy	5400.00
0005432329800	31145	Economy	5400.00
0005432329785	31145	Economy	5400.00
0005433439055	31145	Economy	5400.00
0005432329955	31145	Economy	5400.00
0005432329877	31145	Economy	5400.00
0005433439063	31145	Economy	5400.00
0005433439064	31145	Economy	5400.00
0005432329711	31145	Economy	5400.00
0005433439020	31145	Economy	5400.00
0005432329956	31145	Economy	5400.00
0005432329712	31145	Economy	5400.00
0005432329773	31145	Economy	5400.00
0005432329714	31145	Economy	5400.00
0005432329838	31145	Economy	5400.00
0005432329791	31145	Economy	5400.00
0005432848920	31145	Economy	5400.00
0005432329792	31145	Economy	5400.00
0005432329902	31145	Economy	5400.00
0005432329904	31145	Economy	5400.00
0005432329815	31145	Economy	5400.00
0005432329706	31145	Economy	5400.00
0005432329957	31145	Economy	5400.00
0005432329808	31145	Economy	5400.00
0005432329901	31145	Economy	5400.00
0005433439052	31145	Economy	5400.00
0005432329745	31145	Economy	5400.00
0005432329840	31145	Economy	5400.00
0005435488334	6222	Business	124600.00
0005435488423	6222	Business	124600.00
0005435488381	6222	Business	124600.00
0005435488385	6222	Business	124600.00
0005435297230	6222	Business	124600.00
0005435488420	6222	Economy	41500.00
0005435488329	6222	Economy	41500.00
0005435488386	6222	Economy	41500.00
0005435297191	6222	Economy	41500.00
0005435488337	6222	Economy	41500.00
0005435488419	6222	Economy	41500.00
0005435999863	6222	Economy	41500.00
0005435297220	6222	Economy	41500.00
0005435488300	6222	Economy	41500.00
0005435488406	6222	Economy	41500.00
0005435488351	6222	Economy	41500.00
0005435488333	6222	Economy	45700.00
0005435488384	6222	Economy	45700.00
0005435297215	6222	Economy	41500.00
0005435488400	6222	Economy	41500.00
0005435488422	6222	Economy	41500.00
0005435488213	6222	Economy	41500.00
0005435488348	6222	Economy	41500.00
0005435488324	6222	Economy	41500.00
0005435488294	6222	Economy	41500.00
0005435488374	6222	Economy	41500.00
0005435488383	6222	Economy	41500.00
0005435488379	6222	Economy	41500.00
0005435297231	6222	Economy	41500.00
0005435297229	6222	Economy	41500.00
0005435488293	6222	Economy	41500.00
0005435488301	6222	Economy	41500.00
0005435297240	6222	Economy	41500.00
0005435297238	6222	Economy	41500.00
0005435488380	6222	Economy	41500.00
0005435297252	6222	Economy	41500.00
0005435488214	6222	Economy	41500.00
0005435488378	6222	Economy	41500.00
0005435999585	19545	Business	124600.00
0005435297266	19545	Business	124600.00
0005434310085	19545	Business	124600.00
0005434310111	19545	Business	124600.00
0005435999683	19545	Economy	41500.00
0005435999679	19545	Economy	41500.00
0005434310118	19545	Economy	41500.00
0005434310108	19545	Economy	41500.00
0005434310046	19545	Economy	41500.00
0005435999647	19545	Economy	41500.00
0005435297263	19545	Economy	41500.00
0005434310095	19545	Economy	41500.00
0005435999689	19545	Economy	41500.00
0005435999682	19545	Economy	41500.00
0005435999621	19545	Economy	41500.00
0005435999599	19545	Economy	41500.00
0005435999640	19545	Economy	41500.00
0005435999667	19545	Economy	41500.00
0005435999705	19545	Economy	41500.00
0005434310059	19545	Economy	41500.00
0005435999778	19545	Economy	41500.00
0005434310098	19545	Economy	41500.00
0005435999794	19545	Economy	41500.00
0005434310090	19545	Economy	41500.00
0005435999753	19545	Economy	41500.00
0005435999723	19545	Economy	41500.00
0005435999711	19545	Economy	41500.00
0005435297265	19545	Economy	41500.00
0005435999706	19545	Economy	41500.00
0005435999726	19545	Economy	41500.00
0005435999655	19545	Economy	41500.00
0005435999775	19545	Economy	41500.00
0005435999598	19545	Economy	41500.00
0005435999620	19545	Economy	41500.00
0005435999774	19545	Economy	41500.00
0005435999769	19545	Economy	41500.00
0005435999727	19545	Economy	41500.00
0005434310112	19545	Economy	41500.00
0005435999724	19545	Economy	41500.00
0005435999748	19545	Economy	41500.00
0005435297264	19545	Economy	41500.00
0005435999773	19545	Economy	41500.00
0005434310058	19545	Economy	41500.00
0005434310097	19545	Economy	41500.00
0005433158196	13209	Economy	12300.00
0005433157010	13209	Economy	12300.00
0005433158197	13209	Economy	12300.00
0005433158198	13209	Economy	12300.00
0005433157016	13209	Economy	12300.00
0005434444191	13209	Economy	12300.00
0005434444188	13209	Economy	12300.00
0005434444192	13209	Economy	12300.00
0005435508833	1547	Economy	28700.00
0005434566312	1547	Economy	31500.00
0005433186335	1547	Economy	28700.00
0005433186304	1547	Economy	28700.00
0005435502965	1547	Economy	28700.00
0005435502964	1547	Economy	28700.00
0005435502966	1547	Economy	28700.00
0005433186329	1547	Economy	28700.00
0005433186305	1547	Economy	28700.00
0005433186296	1547	Economy	28700.00
0005434566226	20858	Business	86000.00
0005434566264	20858	Business	86000.00
0005435502913	20858	Business	86000.00
0005435529824	20858	Business	86000.00
0005435502821	20858	Business	86000.00
0005435529825	20858	Business	86000.00
0005434566242	20858	Business	86000.00
0005435502909	20858	Business	86000.00
0005434566257	20858	Business	86000.00
0005435545923	20858	Economy	28700.00
0005434566279	20858	Economy	28700.00
0005435502865	20858	Economy	28700.00
0005435502852	20858	Economy	28700.00
0005434191332	20858	Economy	28700.00
0005435502870	20858	Economy	28700.00
0005435529815	20858	Economy	28700.00
0005435529818	20858	Economy	28700.00
0005435529782	20858	Economy	31500.00
0005435545918	20858	Economy	31500.00
0005435545930	20858	Economy	31500.00
0005435529809	20858	Economy	28700.00
0005434566243	20858	Economy	28700.00
0005435529789	20858	Economy	28700.00
0005434191331	20858	Economy	28700.00
0005434566221	20858	Economy	28700.00
0005435502834	20858	Economy	28700.00
0005435529841	20858	Economy	28700.00
0005434566265	20858	Economy	28700.00
0005435529737	20858	Economy	28700.00
0005435502784	20858	Economy	28700.00
0005435502796	20858	Economy	28700.00
0005434566249	20858	Economy	28700.00
0005435529788	20858	Economy	28700.00
0005434566280	20858	Economy	28700.00
0005435529698	20858	Economy	28700.00
0005435502869	20858	Economy	28700.00
0005435502911	20858	Economy	28700.00
0005434566278	20858	Economy	28700.00
0005435502932	20858	Economy	28700.00
0005435529714	20858	Economy	28700.00
0005434566266	20858	Economy	28700.00
0005435502819	20858	Economy	28700.00
0005435529745	20858	Economy	28700.00
0005435529791	20858	Economy	28700.00
0005435502855	20858	Economy	28700.00
0005435502866	20858	Economy	28700.00
0005435529808	20858	Economy	28700.00
0005435545907	20858	Economy	28700.00
0005435529744	20858	Economy	28700.00
0005435545904	20858	Economy	28700.00
0005435529775	20858	Economy	28700.00
0005434566248	20858	Economy	28700.00
0005435529802	20858	Economy	28700.00
0005435545881	20858	Economy	28700.00
0005435545892	20858	Economy	28700.00
0005435529852	20858	Economy	28700.00
0005435502773	20858	Economy	28700.00
0005435529793	20858	Economy	28700.00
0005435502820	20858	Economy	28700.00
0005435502709	20858	Economy	28700.00
0005434566247	20858	Economy	28700.00
0005435545905	20858	Economy	28700.00
0005435545908	20858	Economy	28700.00
0005435529794	20858	Economy	28700.00
0005435545924	20858	Economy	28700.00
0005434566274	20858	Economy	28700.00
0005435502864	20858	Economy	28700.00
0005435502910	20858	Economy	28700.00
0005435931708	3917	Economy	19700.00
0005435931707	3917	Economy	19700.00
0005435931699	3917	Economy	19700.00
0005435931700	3917	Economy	19700.00
0005435153905	21897	Economy	21600.00
0005435153892	21897	Economy	19700.00
0005435153900	21897	Economy	19700.00
0005435153922	21897	Economy	19700.00
0005435153921	21897	Economy	19700.00
0005435142972	21897	Economy	19700.00
0005435153920	21897	Economy	19700.00
0005435153925	21897	Economy	19700.00
0005435142981	21897	Economy	19700.00
0005435153904	21897	Economy	19700.00
0005435142983	21897	Economy	19700.00
0005435225730	7203	Economy	14300.00
0005435225778	7203	Economy	14300.00
0005432629294	7203	Economy	13000.00
0005435225803	7203	Economy	13000.00
0005432629197	28120	Economy	14300.00
0005432629231	28120	Economy	13000.00
0005432629183	28120	Economy	13000.00
0005432629186	28120	Economy	13000.00
0005432629226	28120	Economy	13000.00
0005432629198	28120	Economy	13000.00
0005432629232	28120	Economy	13000.00
0005432629236	28120	Economy	13000.00
0005432629242	28120	Economy	13000.00
0005432629234	28120	Economy	13000.00
0005432629235	28120	Economy	13000.00
0005432629213	28120	Economy	13000.00
0005432629214	28120	Economy	13000.00
0005434268048	8743	Economy	11500.00
0005434268045	8743	Economy	10500.00
0005434268034	8743	Economy	10500.00
0005434268046	8743	Economy	10500.00
0005434268054	8743	Economy	10500.00
0005434268055	8743	Economy	10500.00
0005434268047	8743	Economy	10500.00
0005435960153	15215	Economy	10500.00
0005435477012	15215	Economy	10500.00
0005432873467	1160	Business	115000.00
0005432873445	1160	Economy	38300.00
0005432873457	1160	Economy	38300.00
0005432693969	1160	Economy	38300.00
0005432873461	1160	Economy	38300.00
0005432873469	1160	Economy	38300.00
0005432693968	1160	Economy	38300.00
0005432873443	1160	Economy	38300.00
0005432873444	1160	Economy	38300.00
0005432693871	17488	Business	115000.00
0005432693859	17488	Business	115000.00
0005432693734	17488	Business	115000.00
0005432675518	17488	Business	115000.00
0005432693831	17488	Business	115000.00
0005432675523	17488	Business	115000.00
0005432677671	17488	Economy	38300.00
0005432677684	17488	Economy	38300.00
0005432693704	17488	Economy	38300.00
0005432693828	17488	Economy	42200.00
0005432693733	17488	Economy	38300.00
0005432873504	17488	Economy	42200.00
0005432693897	17488	Economy	38300.00
0005432693922	17488	Economy	38300.00
0005432675543	17488	Economy	38300.00
0005432693916	17488	Economy	38300.00
0005432693718	17488	Economy	38300.00
0005432675502	17488	Economy	38300.00
0005432675453	17488	Economy	38300.00
0005432693766	17488	Economy	38300.00
0005432675462	17488	Economy	38300.00
0005432675522	17488	Economy	38300.00
0005432693787	17488	Economy	38300.00
0005432693858	17488	Economy	38300.00
0005432693872	17488	Economy	38300.00
0005432693782	17488	Economy	38300.00
0005432693873	17488	Economy	38300.00
0005432675469	17488	Economy	38300.00
0005432675542	17488	Economy	38300.00
0005432693759	17488	Economy	38300.00
0005432675510	17488	Economy	38300.00
0005432675563	17488	Economy	38300.00
0005432675454	17488	Economy	38300.00
0005432677659	17488	Economy	38300.00
0005432677683	17488	Economy	38300.00
0005432675463	17488	Economy	38300.00
0005432693860	17488	Economy	38300.00
0005432675411	17488	Economy	38300.00
0005432675538	17488	Economy	38300.00
0005432675535	17488	Economy	38300.00
0005433156967	1119	Economy	15200.00
0005433156987	1119	Economy	15200.00
0005433156968	1119	Economy	13900.00
0005433156986	1119	Economy	13900.00
0005433156979	1119	Economy	13900.00
0005433156978	1119	Economy	13900.00
0005434435527	17283	Economy	15200.00
0005434435561	17283	Economy	15200.00
0005434435604	17283	Economy	13900.00
0005434435605	17283	Economy	13900.00
0005434435520	17283	Economy	13900.00
0005434435599	17283	Economy	13900.00
0005434435526	17283	Economy	13900.00
0005434435565	17283	Economy	13900.00
0005434435601	17283	Economy	13900.00
0005434435535	17283	Economy	13900.00
0005434435603	17283	Economy	13900.00
0005434435571	17283	Economy	13900.00
0005434435553	17283	Economy	13900.00
0005434435570	17283	Economy	13900.00
0005434435559	17283	Economy	13900.00
0005434435602	17283	Economy	13900.00
0005435928252	4081	Economy	8200.00
0005435928260	4081	Economy	7500.00
0005435087063	4081	Economy	7500.00
0005435087019	24429	Economy	8200.00
0005435087018	24429	Economy	8200.00
0005435087031	24429	Economy	8200.00
0005435087015	24429	Economy	7500.00
0005435087003	24429	Economy	7500.00
0005435087034	24429	Economy	7500.00
0005435087017	24429	Economy	7500.00
0005435087026	24429	Economy	7500.00
0005435087002	24429	Economy	7500.00
0005435087032	24429	Economy	7500.00
0005435087016	24429	Economy	7500.00
0005433261843	1309	Business	203300.00
0005433261821	1309	Business	203300.00
0005433261816	1309	Business	203300.00
0005433261806	1309	Economy	74500.00
0005433261736	1309	Economy	74500.00
0005433261817	1309	Economy	67800.00
0005433261818	1309	Economy	67800.00
0005433261828	1309	Economy	67800.00
0005433261794	1309	Economy	67800.00
0005433261819	1309	Economy	67800.00
0005433261820	1309	Economy	67800.00
0005433261758	1309	Economy	67800.00
0005433261800	1309	Economy	67800.00
0005433261844	1309	Economy	67800.00
0005433261823	1309	Economy	67800.00
0005433261845	1309	Economy	67800.00
0005433261824	1309	Economy	67800.00
0005432279338	1309	Economy	67800.00
0005433261829	1309	Economy	67800.00
0005433261830	1309	Economy	67800.00
0005434964642	18251	Business	203300.00
0005434964654	18251	Business	203300.00
0005434964644	18251	Business	203300.00
0005434964776	18251	Business	203300.00
0005434964707	18251	Business	203300.00
0005434964628	18251	Business	203300.00
0005434964636	18251	Business	203300.00
0005434964646	18251	Business	203300.00
0005434964676	18251	Business	203300.00
0005434964736	18251	Economy	74500.00
0005434964701	18251	Economy	67800.00
0005434964702	18251	Economy	67800.00
0005434964645	18251	Economy	67800.00
0005434964694	18251	Economy	67800.00
0005434964690	18251	Economy	67800.00
0005434964741	18251	Economy	67800.00
0005434964632	18251	Economy	67800.00
0005434964672	18251	Economy	67800.00
0005434964660	18251	Economy	67800.00
0005433261866	18251	Economy	67800.00
0005434964708	18251	Economy	67800.00
0005434964728	18251	Economy	67800.00
0005434964588	18251	Economy	67800.00
0005434964641	18251	Economy	67800.00
0005434964637	18251	Economy	67800.00
0005434964689	18251	Economy	67800.00
0005434964664	18251	Economy	67800.00
0005434964627	18251	Economy	67800.00
0005433261868	18251	Economy	67800.00
0005434964669	18251	Economy	67800.00
0005434964732	18251	Economy	67800.00
0005434964682	18251	Economy	67800.00
0005434964656	18251	Economy	67800.00
0005434964768	18251	Economy	67800.00
0005434215910	18251	Economy	67800.00
0005434964686	18251	Economy	67800.00
0005434964704	18251	Economy	67800.00
0005434964638	18251	Economy	74500.00
0005434964735	18251	Economy	67800.00
0005434964643	18251	Economy	67800.00
0005434964751	18251	Economy	74500.00
0005434964671	18251	Economy	67800.00
0005434964651	18251	Economy	67800.00
0005434964653	18251	Economy	67800.00
0005434964659	18251	Economy	67800.00
0005434964626	18251	Economy	67800.00
0005434964633	18251	Economy	67800.00
0005433261867	18251	Economy	67800.00
0005434964618	18251	Economy	67800.00
0005434964687	18251	Economy	67800.00
0005434964587	18251	Economy	67800.00
0005434964670	18251	Economy	67800.00
0005434964775	18251	Economy	67800.00
0005434964652	18251	Economy	67800.00
0005434626239	4865	Economy	14700.00
0005433194921	4865	Economy	16200.00
0005434626240	4865	Economy	16200.00
0005435907619	4865	Economy	14700.00
0005433194959	4865	Economy	14700.00
0005435907593	4865	Economy	14700.00
0005435907592	4865	Economy	14700.00
0005435907640	4865	Economy	14700.00
0005433194918	4865	Economy	14700.00
0005435907628	4865	Economy	14700.00
0005433194950	4865	Economy	14700.00
0005433195016	32892	Economy	14700.00
0005434626218	32892	Economy	16200.00
0005434626221	32892	Economy	16200.00
0005433195017	32892	Economy	16200.00
0005434626197	32892	Economy	14700.00
0005435907656	32892	Economy	14700.00
0005434626228	32892	Economy	14700.00
0005435907654	32892	Economy	14700.00
0005434626211	32892	Economy	14700.00
0005434626222	32892	Economy	14700.00
0005434626213	32892	Economy	14700.00
0005435907655	32892	Economy	14700.00
0005434626219	32892	Economy	14700.00
0005434626212	32892	Economy	14700.00
0005434626229	32892	Economy	14700.00
0005434626217	32892	Economy	14700.00
0005435786070	13801	Economy	3400.00
0005435786221	13801	Economy	3400.00
0005435786181	13801	Economy	3400.00
0005435786127	13801	Economy	3100.00
0005435786195	13801	Economy	3100.00
0005435786211	13801	Economy	3100.00
0005435786193	13801	Economy	3100.00
0005435786106	13801	Economy	3100.00
0005435786059	13801	Economy	3100.00
0005435786135	13801	Economy	3100.00
0005435786267	13801	Economy	3100.00
0005435786060	13801	Economy	3100.00
0005435786192	13801	Economy	3100.00
0005435786197	13801	Economy	3100.00
0005435786156	13801	Economy	3100.00
0005435786180	13801	Economy	3100.00
0005435786266	13801	Economy	3100.00
0005435786185	13801	Economy	3100.00
0005435786241	13801	Economy	3100.00
0005435786226	13801	Economy	3100.00
0005435786319	13801	Economy	3100.00
0005435786236	13801	Economy	3100.00
0005435786118	13801	Economy	3100.00
0005435786038	13801	Economy	3100.00
0005435786043	13801	Economy	3100.00
0005435786196	13801	Economy	3100.00
0005435786126	13801	Economy	3100.00
0005435786123	13801	Economy	3100.00
0005435787402	13801	Economy	3100.00
0005435786198	13801	Economy	3100.00
0005435786122	13801	Economy	3100.00
0005435786212	13801	Economy	3100.00
0005435786124	13801	Economy	3100.00
0005435786157	13801	Economy	3100.00
0005435786071	13801	Economy	3100.00
0005435786125	13801	Economy	3100.00
0005435786258	13801	Economy	3100.00
0005435786090	13801	Economy	3100.00
0005435787401	13801	Economy	3100.00
0005435786105	13801	Economy	3100.00
0005435786320	13801	Economy	3100.00
0005435786173	13801	Economy	3100.00
0005435786358	27424	Economy	3100.00
0005435786362	27424	Economy	3100.00
0005435786361	27424	Economy	3100.00
0005435786360	27424	Economy	3100.00
0005435937504	27424	Economy	3100.00
0005435937519	27424	Economy	3100.00
0005435786359	27424	Economy	3100.00
0005435937522	27424	Economy	3100.00
0005435937520	27424	Economy	3100.00
0005435937525	27424	Economy	3100.00
0005435786363	27424	Economy	3100.00
0005434409234	20266	Business	12000.00
0005434409109	20266	Business	12000.00
0005434409187	20266	Business	12000.00
0005434409262	20266	Business	12000.00
0005434409403	20266	Business	12000.00
0005434408895	20266	Business	12000.00
0005434409504	20266	Business	12000.00
0005434409164	20266	Economy	4000.00
0005434409341	20266	Economy	4000.00
0005434409385	20266	Economy	4000.00
0005434409392	20266	Economy	4000.00
0005434409316	20266	Economy	4000.00
0005434409391	20266	Economy	4000.00
0005434409199	20266	Economy	4000.00
0005434408894	20266	Economy	4400.00
0005434409317	20266	Economy	4400.00
0005434409342	20266	Economy	4400.00
0005434409501	20266	Economy	4400.00
0005434409191	20266	Economy	4400.00
0005434409387	20266	Economy	4000.00
0005434409177	20266	Economy	4000.00
0005434409390	20266	Economy	4000.00
0005434409534	20266	Economy	4000.00
0005434409399	20266	Economy	4000.00
0005434409457	20266	Economy	4000.00
0005435311559	20266	Economy	4000.00
0005434408896	20266	Economy	4000.00
0005434409349	20266	Economy	4000.00
0005434409294	20266	Economy	4000.00
0005434409315	20266	Economy	4000.00
0005434409443	20266	Economy	4000.00
0005434409214	20266	Economy	4000.00
0005434409368	20266	Economy	4000.00
0005434409357	20266	Economy	4000.00
0005434409186	20266	Economy	4000.00
0005432058500	20266	Economy	4000.00
0005434409185	20266	Economy	4000.00
0005434409197	20266	Economy	4000.00
0005434409163	20266	Economy	4000.00
0005434409227	20266	Economy	4000.00
0005434409413	20266	Economy	4000.00
0005434409570	20266	Economy	4000.00
0005434409411	20266	Economy	4000.00
0005434409356	20266	Economy	4000.00
0005434409261	20266	Economy	4000.00
0005434409433	20266	Economy	4000.00
0005434409412	20266	Economy	4000.00
0005434409395	20266	Economy	4000.00
0005434409301	20266	Economy	4000.00
0005434409404	20266	Economy	4000.00
0005434409253	20266	Economy	4000.00
0005434409198	20266	Economy	4000.00
0005434409340	20266	Economy	4000.00
0005434409329	20266	Economy	4000.00
0005434409169	20266	Economy	4000.00
0005434409398	20266	Economy	4000.00
0005434409256	20266	Economy	4000.00
0005435311438	27003	Business	12000.00
0005435311403	27003	Business	12000.00
0005434409616	27003	Economy	4000.00
0005435311514	27003	Economy	4400.00
0005435311424	27003	Economy	4400.00
0005434409617	27003	Economy	4000.00
0005435311392	27003	Economy	4000.00
0005434409619	27003	Economy	4000.00
0005435311421	27003	Economy	4000.00
0005435311427	27003	Economy	4000.00
0005435311478	27003	Economy	4000.00
0005435311426	27003	Economy	4000.00
0005434409618	27003	Economy	4000.00
0005435311401	27003	Economy	4000.00
0005435311407	27003	Economy	4000.00
0005435311436	27003	Economy	4000.00
0005435311402	27003	Economy	4000.00
0005435311358	27003	Economy	4000.00
0005435311393	27003	Economy	4000.00
0005435311513	27003	Economy	4000.00
0005435311479	27003	Economy	4000.00
0005435311433	27003	Economy	4000.00
0005435311346	27003	Economy	4000.00
0005435311512	27003	Economy	4000.00
0005435311417	27003	Economy	4000.00
0005435311418	27003	Economy	4000.00
0005435311434	27003	Economy	4000.00
0005435311355	27003	Economy	4000.00
0005435311425	27003	Economy	4000.00
0005434409615	27003	Economy	4000.00
0005435311388	27003	Economy	4000.00
0005433124463	5713	Business	43300.00
0005433124404	5713	Business	43300.00
0005433124423	5713	Business	43300.00
0005434310185	5713	Business	43300.00
0005433124416	5713	Economy	14400.00
0005435297370	5713	Economy	14400.00
0005434319868	5713	Economy	14400.00
0005433124434	5713	Economy	14400.00
0005433124412	5713	Economy	15900.00
0005433124372	5713	Economy	14400.00
0005434310183	5713	Economy	14400.00
0005435297379	5713	Economy	14400.00
0005433124358	5713	Economy	14400.00
0005435297384	5713	Economy	14400.00
0005433124376	5713	Economy	14400.00
0005433124390	5713	Economy	14400.00
0005433124377	5713	Economy	14400.00
0005435297383	5713	Economy	14400.00
0005433124365	5713	Economy	14400.00
0005433124458	5713	Economy	14400.00
0005435297369	5713	Economy	14400.00
0005434310184	5713	Economy	14400.00
0005433124345	5713	Economy	14400.00
0005433124409	5713	Economy	14400.00
0005433124370	5713	Economy	14400.00
0005433124371	5713	Economy	14400.00
0005433124433	5713	Economy	14400.00
0005433124408	5713	Economy	14400.00
0005434319722	15706	Business	43300.00
0005434319680	15706	Business	43300.00
0005433124553	15706	Economy	14400.00
0005434319775	15706	Economy	15900.00
0005434319747	15706	Economy	15900.00
0005434319773	15706	Economy	14400.00
0005434319758	15706	Economy	14400.00
0005433124554	15706	Economy	14400.00
0005434319750	15706	Economy	14400.00
0005434319731	15706	Economy	14400.00
0005434311267	15706	Economy	14400.00
0005434319774	15706	Economy	14400.00
0005434319802	15706	Economy	14400.00
0005434319767	15706	Economy	14400.00
0005434319749	15706	Economy	14400.00
0005434319760	15706	Economy	14400.00
0005434312372	15706	Economy	14400.00
0005434311271	15706	Economy	14400.00
0005434311263	15706	Economy	14400.00
0005435297398	15706	Economy	14400.00
0005434312368	15706	Economy	14400.00
0005434319772	15706	Economy	14400.00
0005434319748	15706	Economy	14400.00
0005434319715	15706	Economy	14400.00
0005434319776	15706	Economy	14400.00
0005434319716	15706	Economy	14400.00
0005434319753	15706	Economy	14400.00
0005434319761	15706	Economy	14400.00
0005434319704	15706	Economy	14400.00
0005434319823	15706	Economy	14400.00
0005435221534	24968	Economy	17100.00
0005435217766	24968	Economy	17100.00
0005435220381	24968	Economy	17100.00
0005435220375	24968	Economy	15500.00
0005435220382	24968	Economy	15500.00
0005435221533	24968	Economy	15500.00
0005435217761	24968	Economy	15500.00
0005435220374	24968	Economy	15500.00
0005435220368	24968	Economy	15500.00
0005435220369	24968	Economy	15500.00
0005435217767	24968	Economy	15500.00
0005435221532	24968	Economy	15500.00
0005435217764	24968	Economy	15500.00
0005435220358	24968	Economy	15500.00
0005435217765	24968	Economy	15500.00
0005434189322	8972	Economy	27400.00
0005434189332	8972	Economy	24900.00
0005434189321	8972	Economy	24900.00
0005434189330	8972	Economy	24900.00
0005434189323	8972	Economy	24900.00
0005434189331	8972	Economy	24900.00
0005434484529	16621	Economy	24900.00
0005434484493	16621	Economy	24900.00
0005434484527	16621	Economy	24900.00
0005434484521	16621	Economy	24900.00
0005434484528	16621	Economy	24900.00
0005433722391	7547	Economy	3700.00
0005433722392	7547	Economy	3700.00
0005433124554	7547	Economy	3700.00
0005433722388	7547	Economy	3700.00
0005433124553	7547	Economy	3700.00
0005433722398	7547	Economy	3700.00
0005433722399	7547	Economy	3700.00
0005433722355	7547	Economy	3700.00
0005433722370	7547	Economy	3700.00
0005432693972	7548	Business	11100.00
0005433450611	7548	Economy	3700.00
0005432693971	7548	Economy	3700.00
0005432693970	7548	Economy	3700.00
0005432693973	7548	Economy	3700.00
0005433450500	30275	Business	11100.00
0005433450482	30275	Business	11100.00
0005433450481	30275	Business	11100.00
0005433450546	30275	Business	11100.00
0005432693831	30275	Business	11100.00
0005433450484	30275	Business	11100.00
0005432693759	30275	Business	11100.00
0005432693873	30275	Economy	3700.00
0005433450545	30275	Economy	3700.00
0005432693872	30275	Economy	4100.00
0005432693766	30275	Economy	3700.00
0005433450442	30275	Economy	3700.00
0005433450472	30275	Economy	3700.00
0005433450475	30275	Economy	3700.00
0005432693828	30275	Economy	3700.00
0005432693734	30275	Economy	3700.00
0005432693718	30275	Economy	3700.00
0005432693704	30275	Economy	3700.00
0005433450493	30275	Economy	3700.00
0005432693922	30275	Economy	3700.00
0005432693859	30275	Economy	3700.00
0005433450485	30275	Economy	3700.00
0005432693858	30275	Economy	3700.00
0005432693782	30275	Economy	3700.00
0005432693787	30275	Economy	3700.00
0005432693860	30275	Economy	3700.00
0005433450443	30275	Economy	3700.00
0005433450488	30275	Economy	3700.00
0005433450479	30275	Economy	3700.00
0005432693916	30275	Economy	3700.00
0005432693897	30275	Economy	3700.00
0005432693733	30275	Economy	3700.00
0005432693871	30275	Economy	3700.00
0005433450471	30275	Economy	3700.00
0005433450477	30275	Economy	3700.00
0005433450480	30275	Economy	3700.00
0005433450476	30275	Economy	3700.00
0005433450418	30275	Economy	3700.00
0005433124371	30276	Business	11100.00
0005435477031	30276	Business	11100.00
0005433124408	30276	Business	11100.00
0005433124345	30276	Business	11100.00
0005432721482	30276	Business	11100.00
0005432721655	30276	Economy	3700.00
0005435477028	30276	Economy	3700.00
0005432721626	30276	Economy	3700.00
0005432721611	30276	Economy	3700.00
0005432721572	30276	Economy	3700.00
0005435477027	30276	Economy	3700.00
0005432721532	30276	Economy	3700.00
0005434310184	30276	Economy	4100.00
0005433124370	30276	Economy	3700.00
0005433124372	30276	Economy	3700.00
0005433124433	30276	Economy	3700.00
0005432721585	30276	Economy	3700.00
0005433124377	30276	Economy	3700.00
0005433124416	30276	Economy	3700.00
0005435477030	30276	Economy	3700.00
0005435477029	30276	Economy	3700.00
0005432721587	30276	Economy	3700.00
0005433124358	30276	Economy	3700.00
0005433124376	30276	Economy	3700.00
0005432721552	30276	Economy	3700.00
0005432721631	30276	Economy	3700.00
0005432721642	30276	Economy	3700.00
0005433124390	30276	Economy	3700.00
0005435477026	30276	Economy	3700.00
0005434310185	30276	Economy	3700.00
0005432721531	30276	Economy	3700.00
0005432721570	30276	Economy	3700.00
0005432721632	30276	Economy	3700.00
0005433124365	30276	Economy	3700.00
0005432721664	30276	Economy	3700.00
0005433124423	30276	Economy	3700.00
0005433722510	30276	Economy	3700.00
0005433124458	30276	Economy	3700.00
0005433722512	30276	Economy	3700.00
0005432721566	30276	Economy	3700.00
0005433124412	30276	Economy	3700.00
0005432721559	30276	Economy	3700.00
0005433722511	30276	Economy	3700.00
0005432721584	30276	Economy	3700.00
0005432721588	30276	Economy	3700.00
0005433124404	30276	Economy	3700.00
0005433124463	30276	Economy	3700.00
0005433124409	30276	Economy	3700.00
0005434310183	30276	Economy	3700.00
0005433124434	30276	Economy	3700.00
0005432721560	30276	Economy	3700.00
0005432721573	30276	Economy	3700.00
0005433193399	1399	Economy	23500.00
0005432928121	1399	Economy	23500.00
0005433193398	1399	Economy	23500.00
0005432928120	1399	Economy	23500.00
0005432928131	1399	Economy	23500.00
0005432968899	1399	Economy	23500.00
0005433193408	1399	Economy	23500.00
0005432928129	1399	Economy	23500.00
0005433193330	1399	Economy	23500.00
0005432968898	1399	Economy	23500.00
0005432928122	1399	Economy	23500.00
0005433525363	1399	Economy	23500.00
0005434587314	18507	Business	70400.00
0005433525324	18507	Business	70400.00
0005434587315	18507	Business	70400.00
0005433724931	18507	Business	70400.00
0005434587232	18507	Business	70400.00
0005434587255	18507	Business	70400.00
0005434587234	18507	Business	70400.00
0005433525296	18507	Economy	23500.00
0005433525325	18507	Economy	23500.00
0005433525303	18507	Economy	23500.00
0005434587312	18507	Economy	23500.00
0005433724904	18507	Economy	25800.00
0005434587265	18507	Economy	25800.00
0005434587135	18507	Economy	25800.00
0005434587313	18507	Economy	25800.00
0005434587318	18507	Economy	23500.00
0005434587249	18507	Economy	23500.00
0005434587290	18507	Economy	23500.00
0005434587206	18507	Economy	23500.00
0005434587258	18507	Economy	23500.00
0005432968911	18507	Economy	23500.00
0005434587256	18507	Economy	23500.00
0005433525323	18507	Economy	23500.00
0005433525282	18507	Economy	23500.00
0005434587217	18507	Economy	23500.00
0005433724930	18507	Economy	23500.00
0005434587218	18507	Economy	23500.00
0005434587288	18507	Economy	23500.00
0005433525302	18507	Economy	23500.00
0005434587200	18507	Economy	23500.00
0005432968910	18507	Economy	23500.00
0005434515027	18507	Economy	23500.00
0005434587134	18507	Economy	23500.00
0005434587212	18507	Economy	23500.00
0005434587194	18507	Economy	23500.00
0005434515030	18507	Economy	23500.00
0005433724912	18507	Economy	23500.00
0005433525281	18507	Economy	23500.00
0005434515026	18507	Economy	23500.00
0005433525347	18507	Economy	23500.00
0005434587291	18507	Economy	23500.00
0005433525285	18507	Economy	23500.00
0005435302317	11460	Economy	4300.00
0005435302313	11460	Economy	4300.00
0005434345286	11460	Economy	4300.00
0005435302318	11460	Economy	4000.00
0005435305058	11460	Economy	4000.00
0005434345287	11460	Economy	4000.00
0005435302312	11460	Economy	4000.00
0005434345288	11460	Economy	4000.00
0005435302314	11460	Economy	4000.00
0005435302322	11460	Economy	4000.00
0005435302315	11460	Economy	4000.00
0005434345148	29755	Economy	4300.00
0005434345085	29755	Economy	4300.00
0005434345099	29755	Economy	4300.00
0005434345074	29755	Economy	4300.00
0005434345156	29755	Economy	4000.00
0005434345081	29755	Economy	4000.00
0005434345079	29755	Economy	4000.00
0005434344873	29755	Economy	4000.00
0005434344905	29755	Economy	4000.00
0005434345086	29755	Economy	4000.00
0005434344958	29755	Economy	4000.00
0005434345035	29755	Economy	4000.00
0005434345189	29755	Economy	4000.00
0005434344874	29755	Economy	4000.00
0005434345073	29755	Economy	4000.00
0005434142705	29755	Economy	4000.00
0005434345174	29755	Economy	4000.00
0005434345032	29755	Economy	4000.00
0005434345094	29755	Economy	4000.00
0005434345069	29755	Economy	4000.00
0005434142706	29755	Economy	4000.00
0005434344986	29755	Economy	4000.00
0005434345177	29755	Economy	4000.00
0005434344950	29755	Economy	4000.00
0005434345082	29755	Economy	4000.00
0005434142704	29755	Economy	4000.00
0005434345015	29755	Economy	4000.00
0005434345034	29755	Economy	4000.00
0005434344904	29755	Economy	4000.00
0005434345003	29755	Economy	4000.00
0005434345070	29755	Economy	4000.00
0005434345016	29755	Economy	4000.00
0005434345089	29755	Economy	4000.00
0005434345095	29755	Economy	4000.00
0005434345058	29755	Economy	4000.00
0005434345050	29755	Economy	4000.00
0005434345102	29755	Economy	4000.00
0005434345209	29755	Economy	4000.00
0005434345098	29755	Economy	4000.00
0005434345055	29755	Economy	4000.00
0005434345190	29755	Economy	4000.00
0005434345071	29755	Economy	4000.00
0005434345097	29755	Economy	4000.00
0005434344951	29755	Economy	4000.00
0005434344992	29755	Economy	4000.00
0005434345096	29755	Economy	4000.00
0005434142709	29755	Economy	4000.00
0005434345019	29755	Economy	4000.00
0005434344977	29755	Economy	4000.00
0005435825424	1299	Business	199800.00
0005433416030	1299	Business	199800.00
0005433416085	1299	Business	199800.00
0005433416072	1299	Economy	66600.00
0005433416110	1299	Economy	66600.00
0005433416066	1299	Economy	66600.00
0005433416050	1299	Economy	66600.00
0005435825423	1299	Economy	66600.00
0005433416109	1299	Economy	66600.00
0005433416019	1299	Economy	66600.00
0005433416047	1299	Economy	66600.00
0005433416081	1299	Economy	66600.00
0005433416071	1299	Economy	66600.00
0005433416018	1299	Economy	66600.00
0005435825260	17979	Business	199800.00
0005435825286	17979	Business	199800.00
0005435825259	17979	Business	199800.00
0005435825344	17979	Business	199800.00
0005435825312	17979	Economy	66600.00
0005435825292	17979	Economy	73200.00
0005435825353	17979	Economy	73200.00
0005435825303	17979	Economy	73200.00
0005435825291	17979	Economy	66600.00
0005435825376	17979	Economy	66600.00
0005435825321	17979	Economy	66600.00
0005435825405	17979	Economy	66600.00
0005435825305	17979	Economy	66600.00
0005435825287	17979	Economy	66600.00
0005435825302	17979	Economy	66600.00
0005435825258	17979	Economy	66600.00
0005435825352	17979	Economy	66600.00
0005435825304	17979	Economy	66600.00
0005435825257	17979	Economy	66600.00
0005435825325	17979	Economy	66600.00
0005434461710	12573	Economy	13500.00
0005434460566	12573	Economy	13500.00
0005434460565	12573	Economy	13500.00
0005434461709	12573	Economy	13500.00
0005435243442	5638	Business	27800.00
0005435243460	5638	Business	27800.00
0005435243516	5638	Business	27800.00
0005435243484	5638	Business	27800.00
0005435476988	5638	Business	27800.00
0005435476940	5638	Economy	9300.00
0005435243481	5638	Economy	9300.00
0005435476956	5638	Economy	9300.00
0005435243444	5638	Economy	9300.00
0005435243512	5638	Economy	10200.00
0005435243531	5638	Economy	10200.00
0005435243449	5638	Economy	10200.00
0005435626881	5638	Economy	9300.00
0005435476957	5638	Economy	9300.00
0005435243515	5638	Economy	9300.00
0005435476939	5638	Economy	9300.00
0005435626882	5638	Economy	9300.00
0005435243570	5638	Economy	9300.00
0005435243431	5638	Economy	9300.00
0005435243523	5638	Economy	9300.00
0005435476918	5638	Economy	9300.00
0005435243448	5638	Economy	9300.00
0005435243571	5638	Economy	9300.00
0005435243461	5638	Economy	9300.00
0005435243568	5638	Economy	9300.00
0005435243535	5638	Economy	9300.00
0005435243462	5638	Economy	9300.00
0005435476938	5638	Economy	9300.00
0005435243483	5638	Economy	9300.00
0005435243574	5638	Economy	9300.00
0005435243511	5638	Economy	9300.00
0005435243573	5638	Economy	9300.00
0005435243555	5638	Economy	9300.00
0005435476972	5638	Economy	9300.00
0005435243524	5638	Economy	9300.00
0005435243482	5638	Economy	9300.00
0005435476917	5638	Economy	9300.00
0005435626883	5638	Economy	9300.00
0005435243459	5638	Economy	9300.00
0005435243578	5638	Economy	9300.00
0005435476941	5638	Economy	9300.00
0005435243662	15337	Business	27800.00
0005432784931	15337	Business	27800.00
0005432785033	15337	Business	27800.00
0005432784930	15337	Business	27800.00
0005432785001	15337	Business	27800.00
0005432785104	15337	Economy	9300.00
0005432785059	15337	Economy	9300.00
0005432785076	15337	Economy	9300.00
0005435243661	15337	Economy	9300.00
0005432785047	15337	Economy	9300.00
0005435477006	15337	Economy	9300.00
0005432785034	15337	Economy	9300.00
0005432785153	15337	Economy	10200.00
0005432785073	15337	Economy	10200.00
0005435243664	15337	Economy	10200.00
0005432784997	15337	Economy	10200.00
0005432785228	15337	Economy	10200.00
0005432785207	15337	Economy	9300.00
0005432785058	15337	Economy	9300.00
0005432785151	15337	Economy	9300.00
0005432784929	15337	Economy	9300.00
0005432785080	15337	Economy	9300.00
0005432785003	15337	Economy	9300.00
0005435243663	15337	Economy	9300.00
0005432785152	15337	Economy	9300.00
0005432785176	15337	Economy	9300.00
0005432784907	15337	Economy	9300.00
0005432785144	15337	Economy	9300.00
0005432784998	15337	Economy	9300.00
0005432785032	15337	Economy	9300.00
0005432785079	15337	Economy	9300.00
0005432785048	15337	Economy	9300.00
0005432785074	15337	Economy	9300.00
0005432785182	15337	Economy	9300.00
0005432785170	15337	Economy	9300.00
0005432785177	15337	Economy	9300.00
0005432785164	15337	Economy	9300.00
0005432784915	15337	Economy	9300.00
0005432785307	15337	Economy	9300.00
0005432785063	15337	Economy	9300.00
0005432785123	15337	Economy	9300.00
0005432785077	15337	Economy	9300.00
0005432785122	15337	Economy	9300.00
0005432785192	15337	Economy	9300.00
0005432785227	15337	Economy	9300.00
0005432784999	15337	Economy	9300.00
0005432785193	15337	Economy	9300.00
0005435851157	4358	Economy	7000.00
0005435851155	4358	Economy	6300.00
0005435851170	4358	Economy	6300.00
0005435851118	4358	Economy	6300.00
0005435851145	4358	Economy	6300.00
0005435851154	4358	Economy	6300.00
0005435851151	4358	Economy	6300.00
0005435851134	4358	Economy	6300.00
0005435851153	4358	Economy	6300.00
0005435851150	4358	Economy	6300.00
0005435851156	4358	Economy	6300.00
0005434463983	28844	Economy	7000.00
0005432848717	28844	Economy	7000.00
0005432848638	28844	Economy	6300.00
0005432848637	28844	Economy	6300.00
0005434461685	28844	Economy	6300.00
0005432848707	28844	Economy	6300.00
0005434463984	28844	Economy	6300.00
0005432848667	28844	Economy	6300.00
0005434461690	28844	Economy	6300.00
0005434463985	28844	Economy	6300.00
0005434461686	28844	Economy	6300.00
0005432848695	28844	Economy	6300.00
0005432848708	28844	Economy	6300.00
0005432848670	28844	Economy	6300.00
0005432848716	28844	Economy	6300.00
0005434463981	28844	Economy	6300.00
0005432848669	28844	Economy	6300.00
0005432848686	28844	Economy	6300.00
0005434463980	28844	Economy	6300.00
0005435257489	6275	Business	11900.00
0005435257526	6275	Business	11900.00
0005435257482	6275	Business	11900.00
0005435257502	6275	Economy	4000.00
0005432075332	6275	Economy	4000.00
0005435257499	6275	Economy	4000.00
0005434926863	6275	Economy	4000.00
0005435257493	6275	Economy	4000.00
0005435257496	6275	Economy	4000.00
0005435257460	6275	Economy	4000.00
0005435257490	6275	Economy	4000.00
0005435257461	6275	Economy	4000.00
0005435257494	6275	Economy	4000.00
0005435257488	6275	Economy	4000.00
0005434926862	6275	Economy	4000.00
0005434926861	6275	Economy	4000.00
0005435311567	6275	Economy	4000.00
0005434444187	6275	Economy	4000.00
0005435257500	6275	Economy	4000.00
0005435257546	20351	Business	11900.00
0005435257547	20351	Economy	4000.00
0005433497776	20352	Business	11900.00
0005434926478	20352	Business	11900.00
0005433497795	20352	Business	11900.00
0005434926553	20352	Business	11900.00
0005434926479	20352	Business	11900.00
0005434926554	20352	Business	11900.00
0005434926428	20352	Business	11900.00
0005434444101	20352	Business	11900.00
0005433497832	20352	Economy	4000.00
0005433497764	20352	Economy	4000.00
0005433497821	20352	Economy	4000.00
0005433497751	20352	Economy	4000.00
0005434926534	20352	Economy	4000.00
0005434444053	20352	Economy	4000.00
0005434926541	20352	Economy	4000.00
0005434926660	20352	Economy	4000.00
0005434926475	20352	Economy	4000.00
0005433497732	20352	Economy	4400.00
0005434926556	20352	Economy	4400.00
0005434926705	20352	Economy	4400.00
0005434444054	20352	Economy	4000.00
0005433497665	20352	Economy	4000.00
0005433497677	20352	Economy	4000.00
0005434926626	20352	Economy	4000.00
0005434926485	20352	Economy	4000.00
0005434926537	20352	Economy	4000.00
0005434444085	20352	Economy	4000.00
0005434926421	20352	Economy	4000.00
0005434926608	20352	Economy	4000.00
0005433497578	20352	Economy	4000.00
0005433497791	20352	Economy	4000.00
0005434926492	20352	Economy	4000.00
0005434926491	20352	Economy	4000.00
0005434926742	20352	Economy	4000.00
0005434926570	20352	Economy	4000.00
0005434926497	20352	Economy	4000.00
0005433497840	20352	Economy	4000.00
0005433497845	20352	Economy	4000.00
0005434926627	20352	Economy	4000.00
0005433497706	20352	Economy	4000.00
0005434926597	20352	Economy	4000.00
0005433497827	20352	Economy	4000.00
0005434926698	20352	Economy	4000.00
0005434444088	20352	Economy	4000.00
0005434926699	20352	Economy	4000.00
0005434926565	20352	Economy	4000.00
0005433497765	20352	Economy	4000.00
0005434444009	20352	Economy	4000.00
0005434444052	20352	Economy	4000.00
0005434444100	20352	Economy	4000.00
0005434444051	20352	Economy	4000.00
0005434926615	20352	Economy	4000.00
0005433497640	20352	Economy	4000.00
0005434926422	20352	Economy	4000.00
0005434444134	20352	Economy	4000.00
0005434926510	20352	Economy	4000.00
0005433497797	20352	Economy	4000.00
0005433497800	20352	Economy	4000.00
0005434926480	20352	Economy	4000.00
0005434926607	20352	Economy	4000.00
0005434926630	20352	Economy	4000.00
0005433497731	20352	Economy	4000.00
0005434926511	20352	Economy	4000.00
0005434926558	20352	Economy	4000.00
0005434926498	20352	Economy	4000.00
0005433497721	20352	Economy	4000.00
0005434926782	20352	Economy	4000.00
0005434926602	20352	Economy	4000.00
0005434926559	20352	Economy	4000.00
0005434926486	20352	Economy	4000.00
0005434926524	20352	Economy	4000.00
0005433497846	20352	Economy	4000.00
0005434926781	20352	Economy	4000.00
0005432785106	12175	Business	41200.00
0005435243666	12175	Business	41200.00
0005432785037	12175	Business	41200.00
0005432785270	12175	Business	41200.00
0005432785093	12175	Business	41200.00
0005432785225	12175	Business	41200.00
0005432785026	12175	Economy	13700.00
0005432785280	12175	Economy	13700.00
0005432785186	12175	Economy	13700.00
0005432785239	12175	Economy	13700.00
0005432785050	12175	Economy	13700.00
0005432784826	12175	Economy	13700.00
0005432784827	12175	Economy	13700.00
0005435243665	12175	Economy	15100.00
0005432785298	12175	Economy	15100.00
0005432785092	12175	Economy	15100.00
0005432785269	12175	Economy	13700.00
0005432785162	12175	Economy	13700.00
0005432785255	12175	Economy	13700.00
0005432785256	12175	Economy	13700.00
0005432785154	12175	Economy	13700.00
0005432785038	12175	Economy	13700.00
0005432785054	12175	Economy	13700.00
0005432785209	12175	Economy	13700.00
0005432785216	12175	Economy	13700.00
0005432785125	12175	Economy	13700.00
0005432785289	12175	Economy	13700.00
0005432785238	12175	Economy	13700.00
0005432785299	12175	Economy	13700.00
0005432785172	12175	Economy	13700.00
0005432785064	12175	Economy	13700.00
0005432785247	12175	Economy	13700.00
0005432785142	12175	Economy	13700.00
0005432785197	12175	Economy	13700.00
0005432785236	12175	Economy	13700.00
0005432785143	12175	Economy	13700.00
0005432785105	12175	Economy	13700.00
0005432785110	12175	Economy	13700.00
0005432785159	12175	Economy	13700.00
0005432785163	12175	Economy	13700.00
0005432785201	12175	Economy	13700.00
0005432785268	12175	Economy	13700.00
0005432785198	12175	Economy	13700.00
0005432784919	12175	Economy	13700.00
0005432785200	12175	Economy	13700.00
0005432785171	12175	Economy	13700.00
0005435243475	15428	Business	41200.00
0005435243510	15428	Business	41200.00
0005435243528	15428	Business	41200.00
0005435243434	15428	Business	41200.00
0005435243436	15428	Business	41200.00
0005435243544	15428	Economy	13700.00
0005435243493	15428	Economy	13700.00
0005435243440	15428	Economy	13700.00
0005435243587	15428	Economy	15100.00
0005435243441	15428	Economy	13700.00
0005435243498	15428	Economy	13700.00
0005435243487	15428	Economy	13700.00
0005435243467	15428	Economy	13700.00
0005435243504	15428	Economy	13700.00
0005432785362	15428	Economy	13700.00
0005435243485	15428	Economy	13700.00
0005435243408	15428	Economy	13700.00
0005435243468	15428	Economy	13700.00
0005435243409	15428	Economy	13700.00
0005435243407	15428	Economy	13700.00
0005432785364	15428	Economy	13700.00
0005435243404	15428	Economy	13700.00
0005435243435	15428	Economy	13700.00
0005435243403	15428	Economy	13700.00
0005432785366	15428	Economy	13700.00
0005435243420	15428	Economy	13700.00
0005432785365	15428	Economy	13700.00
0005435243499	15428	Economy	13700.00
0005432785363	15428	Economy	13700.00
0005435243508	15428	Economy	13700.00
0005435243527	15428	Economy	13700.00
0005435243389	15428	Economy	13700.00
0005435243533	15428	Economy	13700.00
0005435243486	15428	Economy	13700.00
0005435243419	15428	Economy	13700.00
0005435243586	15428	Economy	13700.00
0005435243509	15428	Economy	13700.00
0005434880246	10101	Business	49700.00
0005434880684	10101	Business	49700.00
0005434880744	10101	Business	49700.00
0005434880227	10101	Business	49700.00
0005434880779	10101	Business	49700.00
0005434880740	10101	Business	49700.00
0005434880804	10101	Business	49700.00
0005434880536	10101	Business	49700.00
0005434880560	10101	Business	49700.00
0005434880343	10101	Business	49700.00
0005434880805	10101	Business	49700.00
0005434880533	10101	Business	49700.00
0005434880426	10101	Business	49700.00
0005434880665	10101	Business	49700.00
0005434880494	10101	Business	49700.00
0005434880500	10101	Business	49700.00
0005434880476	10101	Business	49700.00
0005434880385	10101	Business	49700.00
0005434880581	10101	Business	49700.00
0005434880580	10101	Business	49700.00
0005434880289	10101	Economy	16600.00
0005434880738	10101	Economy	16600.00
0005434880780	10101	Economy	16600.00
0005434880783	10101	Economy	16600.00
0005434880588	10101	Economy	16600.00
0005434880055	10101	Economy	16600.00
0005434880557	10101	Economy	16600.00
0005434880418	10101	Economy	16600.00
0005434880650	10101	Economy	16600.00
0005434880437	10101	Economy	16600.00
0005434880609	10101	Economy	16600.00
0005434880624	10101	Economy	16600.00
0005434880399	10101	Economy	16600.00
0005434880292	10101	Economy	18200.00
0005434880326	10101	Economy	18200.00
0005434880330	10101	Economy	18200.00
0005434880710	10101	Economy	18200.00
0005434880537	10101	Economy	16600.00
0005434880308	10101	Economy	16600.00
0005434880475	10101	Economy	16600.00
0005434880549	10101	Economy	16600.00
0005434880782	10101	Economy	16600.00
0005434880630	10101	Economy	16600.00
0005434880719	10101	Economy	16600.00
0005434880138	10101	Economy	16600.00
0005434880691	10101	Economy	16600.00
0005434880401	10101	Economy	16600.00
0005434880681	10101	Economy	16600.00
0005434880315	10101	Economy	16600.00
0005434880425	10101	Economy	16600.00
0005434880209	10101	Economy	16600.00
0005434880749	10101	Economy	16600.00
0005434880400	10101	Economy	16600.00
0005434880600	10101	Economy	16600.00
0005434880316	10101	Economy	16600.00
0005434880781	10101	Economy	16600.00
0005434880619	10101	Economy	16600.00
0005434880799	10101	Economy	16600.00
0005434880567	10101	Economy	16600.00
0005434880808	10101	Economy	16600.00
0005434880293	10101	Economy	16600.00
0005434880711	10101	Economy	16600.00
0005434880478	10101	Economy	16600.00
0005434879967	10101	Economy	16600.00
0005434880464	10101	Economy	16600.00
0005434758949	10101	Economy	16600.00
0005434880327	10101	Economy	16600.00
0005434880610	10101	Economy	16600.00
0005434880751	10101	Economy	16600.00
0005434880173	10101	Economy	16600.00
0005434880750	10101	Economy	16600.00
0005434880815	10101	Economy	16600.00
0005434880383	10101	Economy	16600.00
0005434880436	10101	Economy	16600.00
0005434880686	10101	Economy	16600.00
0005434880688	10101	Economy	16600.00
0005434880736	10101	Economy	16600.00
0005434880490	10101	Economy	16600.00
0005434880479	10101	Economy	16600.00
0005434880329	10101	Economy	16600.00
0005434880212	10101	Economy	16600.00
0005434880342	10101	Economy	16600.00
0005434880568	10101	Economy	16600.00
0005434880403	10101	Economy	16600.00
0005434880305	10101	Economy	16600.00
0005434880618	10101	Economy	16600.00
0005434880683	10101	Economy	16600.00
0005434880228	10101	Economy	16600.00
0005434880720	10101	Economy	16600.00
0005434880129	10101	Economy	16600.00
0005434880341	10101	Economy	16600.00
0005434880213	10101	Economy	16600.00
0005434880373	10101	Economy	16600.00
0005434880685	10101	Economy	16600.00
0005434880556	10101	Economy	16600.00
0005434880608	10101	Economy	16600.00
0005434880384	10101	Economy	16600.00
0005434880477	10101	Economy	16600.00
0005434880737	10101	Economy	16600.00
0005434880288	10101	Economy	16600.00
0005434880651	10101	Economy	16600.00
0005434880493	10101	Economy	16600.00
0005434880435	10101	Economy	16600.00
0005434880565	10101	Economy	16600.00
0005434880216	10101	Economy	16600.00
0005434880534	10101	Economy	16600.00
0005434880689	10101	Economy	16600.00
0005434880589	10101	Economy	16600.00
0005434880501	10101	Economy	16600.00
0005434880226	10101	Economy	16600.00
0005434880415	10101	Economy	16600.00
0005434758950	10101	Economy	16600.00
0005434758948	10101	Economy	16600.00
0005434880739	10101	Economy	16600.00
0005434880413	10101	Economy	16600.00
0005434880499	10101	Economy	16600.00
0005435914054	14622	Business	49700.00
0005434880986	14622	Business	49700.00
0005435914082	14622	Business	49700.00
0005435914103	14622	Economy	18200.00
0005435914055	14622	Economy	16600.00
0005435914156	14622	Economy	16600.00
0005435914106	14622	Economy	16600.00
0005435914104	14622	Economy	16600.00
0005435914056	14622	Economy	16600.00
0005434880987	14622	Economy	16600.00
0005435914016	14622	Economy	16600.00
0005435914151	14622	Economy	16600.00
0005435914157	14622	Economy	16600.00
0005434880988	14622	Economy	16600.00
0005435914083	14622	Economy	16600.00
0005435914101	14622	Economy	16600.00
0005435914118	14622	Economy	16600.00
0005435914072	14622	Economy	16600.00
0005435914102	14622	Economy	16600.00
0005435914105	14622	Economy	16600.00
0005434910175	14622	Economy	16600.00
0005434252174	9232	Economy	20300.00
0005434252161	9232	Economy	20300.00
0005434252207	9232	Economy	20300.00
0005434252202	9232	Economy	20300.00
0005434252197	9232	Economy	20300.00
0005434252199	9232	Economy	20300.00
0005434252198	9232	Economy	20300.00
0005434252205	9232	Economy	20300.00
0005434252193	9232	Economy	20300.00
0005435660409	24656	Economy	20300.00
0005435660403	24656	Economy	20300.00
0005435660388	24656	Economy	20300.00
0005435660391	24656	Economy	20300.00
0005435660389	24656	Economy	20300.00
0005432967497	2773	Business	33000.00
0005432967578	2773	Business	33000.00
0005432967484	2773	Business	33000.00
0005433681974	2773	Economy	11000.00
0005432967498	2773	Economy	11000.00
0005432967583	2773	Economy	11000.00
0005432967623	2773	Economy	12100.00
0005433681977	2773	Economy	12100.00
0005432967548	2773	Economy	12100.00
0005432967582	2773	Economy	11000.00
0005433681976	2773	Economy	11000.00
0005433681978	2773	Economy	11000.00
0005432967504	2773	Economy	11000.00
0005432967646	2773	Economy	11000.00
0005432967488	2773	Economy	11000.00
0005432967539	2773	Economy	11000.00
0005432967618	2773	Economy	11000.00
0005432967547	2773	Economy	11000.00
0005432967628	2773	Economy	11000.00
0005432967611	2773	Economy	11000.00
0005433681973	2773	Economy	11000.00
0005432967619	2773	Economy	11000.00
0005432967496	2773	Economy	11000.00
0005432967617	2773	Economy	11000.00
0005432967606	2773	Economy	11000.00
0005432967485	2773	Economy	11000.00
0005433681972	2773	Economy	11000.00
0005432967645	2773	Economy	11000.00
0005433681979	2773	Economy	11000.00
0005432967633	2773	Economy	11000.00
0005432967538	2773	Economy	11000.00
0005432967564	2773	Economy	11000.00
0005432967519	2773	Economy	11000.00
0005432967489	2773	Economy	11000.00
0005433681975	2773	Economy	11000.00
0005433681756	29191	Business	33000.00
0005433681780	29191	Business	33000.00
0005433684482	29191	Business	33000.00
0005433681805	29191	Business	33000.00
0005432967686	29191	Business	33000.00
0005433681910	29191	Economy	11000.00
0005433681929	29191	Economy	11000.00
0005433681892	29191	Economy	11000.00
0005433681830	29191	Economy	11000.00
0005433681922	29191	Economy	11000.00
0005433681771	29191	Economy	11000.00
0005433681681	29191	Economy	11000.00
0005433681822	29191	Economy	12100.00
0005433681683	29191	Economy	12100.00
0005433681908	29191	Economy	12100.00
0005433681911	29191	Economy	12100.00
0005433681753	29191	Economy	11000.00
0005433681736	29191	Economy	11000.00
0005433681661	29191	Economy	11000.00
0005433681687	29191	Economy	11000.00
0005433681622	29191	Economy	11000.00
0005433681658	29191	Economy	11000.00
0005433681639	29191	Economy	11000.00
0005433681685	29191	Economy	11000.00
0005433681740	29191	Economy	11000.00
0005433687761	29191	Economy	11000.00
0005433681843	29191	Economy	11000.00
0005433681684	29191	Economy	11000.00
0005433681720	29191	Economy	11000.00
0005433690975	29191	Economy	11000.00
0005433681869	29191	Economy	11000.00
0005433681726	29191	Economy	11000.00
0005433681930	29191	Economy	11000.00
0005433681734	29191	Economy	11000.00
0005433681820	29191	Economy	11000.00
0005432967685	29191	Economy	11000.00
0005433681842	29191	Economy	11000.00
0005433681874	29191	Economy	11000.00
0005433687762	29191	Economy	11000.00
0005433681741	29191	Economy	11000.00
0005433681797	29191	Economy	11000.00
0005433681621	29191	Economy	11000.00
0005433681823	29191	Economy	11000.00
0005433681776	29191	Economy	11000.00
0005433681928	29191	Economy	11000.00
0005433681833	29191	Economy	11000.00
0005433681749	29191	Economy	11000.00
0005433681779	29191	Economy	11000.00
0005433681727	29191	Economy	11000.00
0005433681819	29191	Economy	11000.00
0005433681757	29191	Economy	11000.00
0005433616826	9282	Business	132900.00
0005433616824	9282	Business	132900.00
0005434163829	9282	Business	132900.00
0005433616825	9282	Business	132900.00
0005434163837	9282	Business	132900.00
0005435856352	9282	Economy	48700.00
0005433616827	9282	Economy	48700.00
0005434153566	9282	Economy	44300.00
0005434163827	9282	Economy	44300.00
0005434163858	9282	Economy	44300.00
0005434163818	9282	Economy	44300.00
0005435856351	9282	Economy	44300.00
0005434163853	9282	Economy	44300.00
0005434163828	9282	Economy	44300.00
0005434152835	9282	Economy	44300.00
0005433616823	9282	Economy	44300.00
0005434152843	9282	Economy	44300.00
0005434163859	9282	Economy	44300.00
0005434163826	9282	Economy	44300.00
0005434152844	9282	Economy	48700.00
0005434163845	9282	Economy	44300.00
0005433616822	9282	Economy	48700.00
0005433634825	9282	Economy	44300.00
0005433634828	9282	Economy	44300.00
0005434153567	9282	Economy	44300.00
0005433634824	9282	Economy	44300.00
0005434163836	9282	Economy	44300.00
0005435856336	9282	Economy	44300.00
0005434153580	9282	Economy	44300.00
0005433616821	9282	Economy	44300.00
0005433634826	9282	Economy	44300.00
0005434163838	9282	Economy	44300.00
0005433634827	9282	Economy	44300.00
0005434163854	9282	Economy	44300.00
0005434163817	9282	Economy	44300.00
0005434269157	9282	Economy	44300.00
0005435856346	9282	Economy	44300.00
0005434152836	9282	Economy	44300.00
0005433634823	9282	Economy	44300.00
0005433634663	25215	Business	132900.00
0005433634406	25215	Business	132900.00
0005433616254	25215	Business	132900.00
0005434273137	25215	Business	132900.00
0005433616583	25215	Business	132900.00
0005433578168	25215	Business	132900.00
0005433634677	25215	Business	132900.00
0005433616318	25215	Business	132900.00
0005433578131	25215	Business	132900.00
0005433616350	25215	Business	132900.00
0005433634688	25215	Business	132900.00
0005433634707	25215	Business	132900.00
0005433634606	25215	Business	132900.00
0005433634596	25215	Business	132900.00
0005433616439	25215	Business	132900.00
0005433578165	25215	Business	132900.00
0005433616231	25215	Business	132900.00
0005433578167	25215	Business	132900.00
0005433616658	25215	Business	132900.00
0005433616167	25215	Business	132900.00
0005433616586	25215	Business	132900.00
0005433616478	25215	Business	132900.00
0005433616648	25215	Business	132900.00
0005433616591	25215	Business	132900.00
0005433578127	25215	Economy	48700.00
0005433634498	25215	Economy	48700.00
0005433616699	25215	Economy	48700.00
0005435854087	25215	Economy	48700.00
0005433616356	25215	Economy	44300.00
0005433634655	25215	Economy	44300.00
0005433616438	25215	Economy	44300.00
0005434273138	25215	Economy	44300.00
0005433616384	25215	Economy	44300.00
0005433616587	25215	Economy	44300.00
0005433578130	25215	Economy	44300.00
0005433616671	25215	Economy	44300.00
0005433616680	25215	Economy	44300.00
0005433616630	25215	Economy	44300.00
0005433634594	25215	Economy	44300.00
0005433616602	25215	Economy	44300.00
0005433616481	25215	Economy	44300.00
0005433616535	25215	Economy	44300.00
0005433616752	25215	Economy	44300.00
0005433578126	25215	Economy	44300.00
0005433616536	25215	Economy	44300.00
0005433616553	25215	Economy	44300.00
0005433616584	25215	Economy	44300.00
0005433634628	25215	Economy	44300.00
0005433616274	25215	Economy	44300.00
0005433616637	25215	Economy	44300.00
0005433634672	25215	Economy	44300.00
0005433578128	25215	Economy	44300.00
0005433634505	25215	Economy	44300.00
0005433616417	25215	Economy	44300.00
0005433578169	25215	Economy	44300.00
0005433616269	25215	Economy	44300.00
0005433616428	25215	Economy	44300.00
0005433616479	25215	Economy	44300.00
0005433616355	25215	Economy	44300.00
0005433616572	25215	Economy	44300.00
0005433616548	25215	Economy	44300.00
0005433616233	25215	Economy	44300.00
0005433578159	25215	Economy	44300.00
0005433578117	25215	Economy	44300.00
0005433616549	25215	Economy	44300.00
0005433616333	25215	Economy	44300.00
0005433616640	25215	Economy	44300.00
0005433616423	25215	Economy	44300.00
0005433616304	25215	Economy	44300.00
0005433616787	25215	Economy	44300.00
0005433616338	25215	Economy	44300.00
0005433578119	25215	Economy	44300.00
0005433634654	25215	Economy	44300.00
0005433616526	25215	Economy	44300.00
0005433578166	25215	Economy	44300.00
0005433634708	25215	Economy	44300.00
0005433616272	25215	Economy	44300.00
0005433634560	25215	Economy	48700.00
0005433578163	25215	Economy	48700.00
0005433634660	25215	Economy	44300.00
0005433616643	25215	Economy	44300.00
0005433616440	25215	Economy	44300.00
0005433616273	25215	Economy	44300.00
0005433634706	25215	Economy	48700.00
0005433616427	25215	Economy	44300.00
0005433634697	25215	Economy	44300.00
0005433616353	25215	Economy	44300.00
0005433634629	25215	Economy	44300.00
0005433616404	25215	Economy	44300.00
0005433616137	25215	Economy	44300.00
0005433616634	25215	Economy	44300.00
0005433634679	25215	Economy	44300.00
0005433634499	25215	Economy	44300.00
0005433634676	25215	Economy	44300.00
0005433634727	25215	Economy	44300.00
0005433616392	25215	Economy	44300.00
0005433578164	25215	Economy	44300.00
0005433616385	25215	Economy	44300.00
0005433616270	25215	Economy	44300.00
0005433616636	25215	Economy	44300.00
0005433634539	25215	Economy	44300.00
0005433616547	25215	Economy	44300.00
0005433616510	25215	Economy	44300.00
0005433578129	25215	Economy	44300.00
0005433616645	25215	Economy	44300.00
0005433634405	25215	Economy	44300.00
0005433616354	25215	Economy	44300.00
0005433616190	25215	Economy	44300.00
0005433616232	25215	Economy	44300.00
0005433616588	25215	Economy	44300.00
0005433578118	25215	Economy	44300.00
0005433616255	25215	Economy	44300.00
0005433634575	25215	Economy	44300.00
0005433634689	25215	Economy	44300.00
0005433616518	25215	Economy	44300.00
0005433616539	25215	Economy	44300.00
0005433634474	25215	Economy	44300.00
0005433634528	25215	Economy	44300.00
0005433616511	25215	Economy	44300.00
0005433616554	25215	Economy	44300.00
0005433616303	25215	Economy	44300.00
0005433578170	25215	Economy	44300.00
0005433634680	25215	Economy	44300.00
0005433634671	25215	Economy	44300.00
0005433616297	25215	Economy	44300.00
0005433616519	25215	Economy	44300.00
0005433616191	25215	Economy	44300.00
0005433634578	25215	Economy	44300.00
0005433616585	25215	Economy	44300.00
0005433616403	25215	Economy	44300.00
0005433634460	25215	Economy	44300.00
0005433578078	25215	Economy	44300.00
0005433616376	25215	Economy	44300.00
0005433616601	25215	Economy	44300.00
0005433616657	25215	Economy	44300.00
0005433634664	25215	Economy	44300.00
0005433634595	25215	Economy	44300.00
0005433634696	25215	Economy	44300.00
0005432571415	4207	Business	193100.00
0005435947659	4207	Business	193100.00
0005435947660	4207	Business	193100.00
0005435947565	4207	Business	193100.00
0005435947640	4207	Economy	64400.00
0005435856319	4207	Economy	64400.00
0005435856314	4207	Economy	64400.00
0005435947652	4207	Economy	64400.00
0005435947633	4207	Economy	64400.00
0005435947643	4207	Economy	64400.00
0005435856312	4207	Economy	64400.00
0005432571404	4207	Economy	64400.00
0005435947563	4207	Economy	64400.00
0005432571405	4207	Economy	64400.00
0005434271370	4207	Economy	64400.00
0005435856293	4207	Economy	64400.00
0005432571416	4207	Economy	64400.00
0005432571408	4207	Economy	64400.00
0005432571406	4207	Economy	64400.00
0005435947564	4207	Economy	64400.00
0005435947616	4207	Economy	64400.00
0005435947649	4207	Economy	64400.00
0005435947619	4207	Economy	64400.00
0005435947625	4207	Economy	64400.00
0005435947646	4207	Economy	64400.00
0005435856313	4207	Economy	64400.00
0005435983728	26594	Business	193100.00
0005435986997	26594	Economy	64400.00
0005435986924	26594	Economy	64400.00
0005435986996	26594	Economy	64400.00
0005435986961	26594	Economy	64400.00
0005435986935	26594	Economy	64400.00
0005435947684	26594	Economy	64400.00
0005435986941	26594	Economy	64400.00
0005435983727	26594	Economy	64400.00
0005435986960	26594	Economy	64400.00
0005435986942	26594	Economy	64400.00
0005435986974	26594	Economy	64400.00
0005435986934	26594	Economy	64400.00
0005435987002	26594	Economy	70800.00
0005435986951	26594	Economy	64400.00
0005435986962	26594	Economy	64400.00
0005435987030	26594	Economy	64400.00
0005435986927	26594	Economy	64400.00
0005435987003	26594	Economy	64400.00
0005435986969	26594	Economy	64400.00
0005435986980	26594	Economy	64400.00
0005435986983	26594	Economy	64400.00
0005432949515	343	Business	21500.00
0005432949507	343	Business	21500.00
0005432949506	343	Business	21500.00
0005434326052	343	Business	21500.00
0005433075426	343	Business	21500.00
0005432949524	343	Business	21500.00
0005433075410	343	Business	21500.00
0005434326049	343	Business	21500.00
0005433075431	343	Business	21500.00
0005433129374	343	Business	21500.00
0005433570982	343	Business	21500.00
0005433570984	343	Business	21500.00
0005433075509	343	Business	21500.00
0005433075309	343	Business	21500.00
0005434326050	343	Business	21500.00
0005432949563	343	Business	21500.00
0005433570981	343	Economy	7900.00
0005434326048	343	Economy	7900.00
0005433075409	343	Economy	7900.00
0005433075310	343	Economy	7200.00
0005434088060	343	Economy	7200.00
0005434326047	343	Economy	7200.00
0005433075305	343	Economy	7200.00
0005433075495	343	Economy	7200.00
0005432949516	343	Economy	7200.00
0005433075329	343	Economy	7200.00
0005432949577	343	Economy	7200.00
0005432949496	343	Economy	7200.00
0005432949406	343	Economy	7200.00
0005432949448	343	Economy	7200.00
0005432949408	343	Economy	7200.00
0005432949533	343	Economy	7200.00
0005433570985	343	Economy	7200.00
0005432949495	343	Economy	7200.00
0005433075503	343	Economy	7200.00
0005433134250	343	Economy	7200.00
0005433075306	343	Economy	7200.00
0005432949576	343	Economy	7200.00
0005433570983	343	Economy	7200.00
0005433129373	343	Economy	7200.00
0005433075357	343	Economy	7200.00
0005434088044	343	Economy	7200.00
0005432949447	343	Economy	7200.00
0005433075416	343	Economy	7200.00
0005433075330	343	Economy	7200.00
0005433075399	343	Economy	7200.00
0005433075477	343	Economy	7200.00
0005432949442	343	Economy	7900.00
0005433075308	343	Economy	7900.00
0005433075478	343	Economy	7200.00
0005433929873	343	Economy	7200.00
0005432949374	343	Economy	7200.00
0005433075415	343	Economy	7200.00
0005433075508	343	Economy	7200.00
0005434326051	343	Economy	7200.00
0005432949579	343	Economy	7200.00
0005432949523	343	Economy	7200.00
0005432949386	343	Economy	7200.00
0005432949532	343	Economy	7200.00
0005432949449	343	Economy	7200.00
0005432949456	343	Economy	7200.00
0005432949502	343	Economy	7200.00
0005433075476	343	Economy	7200.00
0005432949501	343	Economy	7200.00
0005433075331	343	Economy	7200.00
0005432949335	343	Economy	7200.00
0005434088059	343	Economy	7200.00
0005432949525	343	Economy	7200.00
0005433075494	343	Economy	7200.00
0005433075452	343	Economy	7200.00
0005433129386	343	Economy	7200.00
0005433075356	343	Economy	7200.00
0005433129372	343	Economy	7200.00
0005433570460	11608	Business	21500.00
0005433570496	11608	Business	21500.00
0005433131843	11608	Business	21500.00
0005433570509	11608	Business	21500.00
0005432949693	11608	Business	21500.00
0005433570530	11608	Business	21500.00
0005433075549	11608	Business	21500.00
0005433570671	11608	Business	21500.00
0005434087962	11608	Business	21500.00
0005433570383	11608	Business	21500.00
0005433570549	11608	Business	21500.00
0005434087964	11608	Business	21500.00
0005433570324	11608	Business	21500.00
0005433570554	11608	Business	21500.00
0005434087956	11608	Business	21500.00
0005433570542	11608	Business	21500.00
0005433570555	11608	Economy	7900.00
0005433570544	11608	Economy	7900.00
0005433570458	11608	Economy	7900.00
0005433570432	11608	Economy	7900.00
0005434087980	11608	Economy	7200.00
0005433570325	11608	Economy	7200.00
0005433570285	11608	Economy	7200.00
0005433570800	11608	Economy	7200.00
0005433570585	11608	Economy	7200.00
0005433570485	11608	Economy	7200.00
0005433570486	11608	Economy	7200.00
0005433570487	11608	Economy	7200.00
0005433570435	11608	Economy	7200.00
0005433570322	11608	Economy	7200.00
0005433570258	11608	Economy	7200.00
0005433570498	11608	Economy	7200.00
0005433570480	11608	Economy	7200.00
0005432949696	11608	Economy	7200.00
0005433570226	11608	Economy	7200.00
0005433570453	11608	Economy	7200.00
0005434087963	11608	Economy	7200.00
0005433570378	11608	Economy	7200.00
0005433570447	11608	Economy	7200.00
0005433570459	11608	Economy	7200.00
0005433570283	11608	Economy	7200.00
0005434087955	11608	Economy	7900.00
0005433570286	11608	Economy	7900.00
0005432949694	11608	Economy	7900.00
0005433570187	11608	Economy	7900.00
0005433570491	11608	Economy	7200.00
0005433570448	11608	Economy	7200.00
0005433570396	11608	Economy	7200.00
0005433570321	11608	Economy	7200.00
0005433570323	11608	Economy	7200.00
0005433570621	11608	Economy	7200.00
0005433570439	11608	Economy	7200.00
0005433570552	11608	Economy	7200.00
0005433131842	11608	Economy	7200.00
0005433570652	11608	Economy	7200.00
0005433570522	11608	Economy	7200.00
0005433570684	11608	Economy	7200.00
0005433570497	11608	Economy	7200.00
0005434087965	11608	Economy	7200.00
0005433570771	11608	Economy	7200.00
0005433570584	11608	Economy	7200.00
0005433570541	11608	Economy	7200.00
0005433570540	11608	Economy	7200.00
0005433570663	11608	Economy	7200.00
0005432949697	11608	Economy	7200.00
0005433570495	11608	Economy	7200.00
0005434087983	11608	Economy	7200.00
0005432949698	11608	Economy	7200.00
0005434088019	11608	Economy	7200.00
0005433570664	11608	Economy	7200.00
0005433570397	11608	Economy	7200.00
0005433570685	11608	Economy	7200.00
0005433570436	11608	Economy	7200.00
0005432949695	11608	Economy	7200.00
0005433570361	11608	Economy	7200.00
0005433570430	11608	Economy	7200.00
0005433570620	11608	Economy	7200.00
0005432949699	11608	Economy	7200.00
0005434087979	11608	Economy	7200.00
0005433570534	11608	Economy	7200.00
0005433570440	11608	Economy	7200.00
0005434733071	10024	Economy	6300.00
0005434733072	10024	Economy	6300.00
0005434733075	10024	Economy	6300.00
0005433817569	13940	Economy	6300.00
0005433817570	13940	Economy	6300.00
0005433817571	13940	Economy	6300.00
0005432985828	2378	Business	184500.00
0005432985919	2378	Business	184500.00
0005432985821	2378	Business	184500.00
0005433435455	2378	Business	184500.00
0005433435403	2378	Business	184500.00
0005432985827	2378	Business	184500.00
0005433435437	2378	Business	184500.00
0005432869693	2378	Business	184500.00
0005433435453	2378	Economy	61500.00
0005432985829	2378	Economy	61500.00
0005433435454	2378	Economy	61500.00
0005433435304	2378	Economy	61500.00
0005432985929	2378	Economy	61500.00
0005435983674	2378	Economy	61500.00
0005433435358	2378	Economy	61500.00
0005433435374	2378	Economy	61500.00
0005433435397	2378	Economy	61500.00
0005432985876	2378	Economy	61500.00
0005433435416	2378	Economy	61500.00
0005434731284	2378	Economy	61500.00
0005432985909	2378	Economy	61500.00
0005432985823	2378	Economy	61500.00
0005432985935	2378	Economy	61500.00
0005433755887	2378	Economy	61500.00
0005433435419	2378	Economy	61500.00
0005433435417	2378	Economy	61500.00
0005432985917	2378	Economy	61500.00
0005433435385	2378	Economy	61500.00
0005432985925	2378	Economy	61500.00
0005433435390	2378	Economy	61500.00
0005433755888	2378	Economy	61500.00
0005432985921	2378	Economy	61500.00
0005435983675	2378	Economy	61500.00
0005432985896	2378	Economy	61500.00
0005432985858	2378	Economy	61500.00
0005432985910	2378	Economy	61500.00
0005433435408	2378	Economy	61500.00
0005432985930	2378	Economy	61500.00
0005433435377	2378	Economy	61500.00
0005432985884	2378	Economy	61500.00
0005433435270	2378	Economy	61500.00
0005433435392	2378	Economy	61500.00
0005432985898	2378	Economy	61500.00
0005433435389	2378	Economy	61500.00
0005433435320	2378	Economy	61500.00
0005432985924	2378	Economy	67700.00
0005432985736	2378	Economy	61500.00
0005432985946	2378	Economy	67700.00
0005433435404	2378	Economy	61500.00
0005432985723	2378	Economy	61500.00
0005433435387	2378	Economy	61500.00
0005432985980	2378	Economy	61500.00
0005432869694	2378	Economy	61500.00
0005432985947	2378	Economy	61500.00
0005434731285	2378	Economy	61500.00
0005433435447	2378	Economy	61500.00
0005433435391	2378	Economy	61500.00
0005433435350	2378	Economy	61500.00
0005432985916	2378	Economy	61500.00
0005433435303	2378	Economy	61500.00
0005432300445	2378	Economy	61500.00
0005433435388	2378	Economy	61500.00
0005432985857	2378	Economy	61500.00
0005434731271	2378	Economy	61500.00
0005432985882	2378	Economy	61500.00
0005432985923	2378	Economy	61500.00
0005433435407	2378	Economy	61500.00
0005433435375	2378	Economy	61500.00
0005433435302	2378	Economy	61500.00
0005433435431	2378	Economy	61500.00
0005432985981	2378	Economy	61500.00
0005433435376	2378	Economy	61500.00
0005432985815	2378	Economy	61500.00
0005432985908	2378	Economy	61500.00
0005432985822	2378	Economy	61500.00
0005433435435	2378	Economy	61500.00
0005433435398	2378	Economy	61500.00
0005433435469	2378	Economy	61500.00
0005433755619	26213	Business	184500.00
0005433755463	26213	Business	184500.00
0005433755503	26213	Business	184500.00
0005435983418	26213	Business	184500.00
0005432655782	26213	Business	184500.00
0005432655780	26213	Business	184500.00
0005433755623	26213	Business	184500.00
0005433755533	26213	Business	184500.00
0005433755684	26213	Business	184500.00
0005433755635	26213	Business	184500.00
0005433755658	26213	Business	184500.00
0005433755736	26213	Business	184500.00
0005433755531	26213	Business	184500.00
0005433755591	26213	Business	184500.00
0005432655857	26213	Business	184500.00
0005433755628	26213	Business	184500.00
0005435983460	26213	Business	184500.00
0005433755590	26213	Business	184500.00
0005433755701	26213	Business	184500.00
0005432986013	26213	Economy	67700.00
0005433755539	26213	Economy	67700.00
0005435983329	26213	Economy	61500.00
0005435983336	26213	Economy	61500.00
0005435983442	26213	Economy	61500.00
0005433755689	26213	Economy	61500.00
0005433755613	26213	Economy	61500.00
0005435983437	26213	Economy	61500.00
0005433766729	26213	Economy	61500.00
0005433755543	26213	Economy	61500.00
0005435983337	26213	Economy	61500.00
0005435983361	26213	Economy	61500.00
0005435983382	26213	Economy	61500.00
0005433755496	26213	Economy	61500.00
0005435983440	26213	Economy	61500.00
0005433766728	26213	Economy	61500.00
0005433755690	26213	Economy	61500.00
0005433755572	26213	Economy	61500.00
0005435983245	26213	Economy	61500.00
0005433755745	26213	Economy	61500.00
0005432655783	26213	Economy	61500.00
0005435983298	26213	Economy	61500.00
0005432986015	26213	Economy	61500.00
0005435983307	26213	Economy	61500.00
0005435983550	26213	Economy	61500.00
0005433755743	26213	Economy	61500.00
0005435983428	26213	Economy	61500.00
0005433755665	26213	Economy	61500.00
0005433755700	26213	Economy	61500.00
0005435983505	26213	Economy	61500.00
0005433755622	26213	Economy	61500.00
0005433755594	26213	Economy	61500.00
0005433755770	26213	Economy	61500.00
0005432655820	26213	Economy	61500.00
0005433755534	26213	Economy	61500.00
0005432986014	26213	Economy	61500.00
0005433755502	26213	Economy	61500.00
0005432986012	26213	Economy	61500.00
0005433766723	26213	Economy	61500.00
0005433755535	26213	Economy	61500.00
0005433755752	26213	Economy	61500.00
0005433755809	26213	Economy	61500.00
0005433755571	26213	Economy	61500.00
0005435983551	26213	Economy	61500.00
0005433755737	26213	Economy	61500.00
0005435983292	26213	Economy	61500.00
0005435983328	26213	Economy	61500.00
0005433755763	26213	Economy	61500.00
0005433435508	26213	Economy	61500.00
0005433755664	26213	Economy	61500.00
0005433755644	26213	Economy	61500.00
0005433764730	26213	Economy	61500.00
0005433755399	26213	Economy	61500.00
0005433755718	26213	Economy	61500.00
0005432655786	26213	Economy	61500.00
0005435983398	26213	Economy	61500.00
0005435983406	26213	Economy	61500.00
0005433755592	26213	Economy	61500.00
0005435983322	26213	Economy	61500.00
0005433755485	26213	Economy	61500.00
0005433755764	26213	Economy	61500.00
0005433755712	26213	Economy	61500.00
0005435983311	26213	Economy	61500.00
0005433755753	26213	Economy	67700.00
0005433755666	26213	Economy	61500.00
0005433755523	26213	Economy	61500.00
0005433755765	26213	Economy	61500.00
0005435983256	26213	Economy	61500.00
0005435983252	26213	Economy	61500.00
0005435983249	26213	Economy	61500.00
0005435983253	26213	Economy	61500.00
0005435983238	26213	Economy	61500.00
0005435983250	26213	Economy	61500.00
0005433755667	26213	Economy	61500.00
0005433755792	26213	Economy	61500.00
0005433766721	26213	Economy	61500.00
0005433755793	26213	Economy	61500.00
0005433755371	26213	Economy	61500.00
0005435983323	26213	Economy	61500.00
0005433755744	26213	Economy	61500.00
0005433755755	26213	Economy	61500.00
0005435983195	26213	Economy	61500.00
0005433755400	26213	Economy	61500.00
0005433755464	26213	Economy	61500.00
0005433755570	26213	Economy	61500.00
0005435983525	26213	Economy	61500.00
0005433755717	26213	Economy	61500.00
0005433755614	26213	Economy	61500.00
0005433755414	26213	Economy	61500.00
0005433755557	26213	Economy	61500.00
0005435983534	26213	Economy	61500.00
0005433755759	26213	Economy	61500.00
0005433755577	26213	Economy	61500.00
0005435983471	26213	Economy	61500.00
0005433755649	26213	Economy	61500.00
0005435983321	26213	Economy	61500.00
0005435983248	26213	Economy	61500.00
0005435983251	26213	Economy	61500.00
0005433755536	26213	Economy	61500.00
0005433755556	26213	Economy	61500.00
0005433755486	26213	Economy	61500.00
0005433755580	26213	Economy	61500.00
0005433755372	26213	Economy	61500.00
0005433764731	26213	Economy	61500.00
0005433755573	26213	Economy	61500.00
0005435983491	26213	Economy	61500.00
0005433755719	26213	Economy	61500.00
0005435983407	26213	Economy	61500.00
0005433755554	26213	Economy	61500.00
0005432655761	26213	Economy	61500.00
0005435983383	26213	Economy	61500.00
0005435983371	26213	Economy	61500.00
0005432869726	26213	Economy	61500.00
0005433755683	26213	Economy	61500.00
0005433755627	26213	Economy	61500.00
0005433152340	1506	Business	38900.00
0005433152341	1506	Business	38900.00
0005433152342	1506	Business	38900.00
0005434376068	1506	Business	38900.00
0005433152346	1506	Business	38900.00
0005434029710	1506	Economy	13000.00
0005433152232	1506	Economy	13000.00
0005434029716	1506	Economy	13000.00
0005433152279	1506	Economy	13000.00
0005433152312	1506	Economy	13000.00
0005433152223	1506	Economy	13000.00
0005433152160	1506	Economy	13000.00
0005433152310	1506	Economy	13000.00
0005433152289	1506	Economy	13000.00
0005433152247	1506	Economy	13000.00
0005433152219	1506	Economy	13000.00
0005433152345	1506	Economy	13000.00
0005434029724	1506	Economy	13000.00
0005433152371	1506	Economy	13000.00
0005434029709	1506	Economy	13000.00
0005433152381	1506	Economy	13000.00
0005434376072	1506	Economy	14300.00
0005433152321	1506	Economy	14300.00
0005433152311	1506	Economy	14300.00
0005434029707	1506	Economy	14300.00
0005434376067	1506	Economy	13000.00
0005433152397	1506	Economy	13000.00
0005433931553	1506	Economy	13000.00
0005433152291	1506	Economy	13000.00
0005433152278	1506	Economy	13000.00
0005433152325	1506	Economy	13000.00
0005433764725	1506	Economy	13000.00
0005433152307	1506	Economy	13000.00
0005434029706	1506	Economy	13000.00
0005433764726	1506	Economy	13000.00
0005433152373	1506	Economy	13000.00
0005433764733	1506	Economy	13000.00
0005433152159	1506	Economy	13000.00
0005433152200	1506	Economy	13000.00
0005433152380	1506	Economy	13000.00
0005434376071	1506	Economy	13000.00
0005434029723	1506	Economy	13000.00
0005433152234	1506	Economy	13000.00
0005434376070	1506	Economy	13000.00
0005433152365	1506	Economy	13000.00
0005433931531	1506	Economy	13000.00
0005434376191	1506	Economy	13000.00
0005433152339	1506	Economy	13000.00
0005433931540	1506	Economy	13000.00
0005433152290	1506	Economy	13000.00
0005433152376	1506	Economy	13000.00
0005433152372	1506	Economy	13000.00
0005434376066	1506	Economy	13000.00
0005434029715	1506	Economy	13000.00
0005434376069	1506	Economy	13000.00
0005433152233	1506	Economy	13000.00
0005434375634	20120	Business	38900.00
0005434375742	20120	Business	38900.00
0005434375875	20120	Business	38900.00
0005434375895	20120	Business	38900.00
0005434375779	20120	Economy	13000.00
0005433152416	20120	Economy	13000.00
0005434375817	20120	Economy	13000.00
0005434375852	20120	Economy	13000.00
0005434375818	20120	Economy	13000.00
0005434375870	20120	Economy	13000.00
0005434375756	20120	Economy	13000.00
0005434375750	20120	Economy	13000.00
0005434375829	20120	Economy	13000.00
0005434375764	20120	Economy	13000.00
0005434375830	20120	Economy	13000.00
0005434375769	20120	Economy	13000.00
0005434375801	20120	Economy	13000.00
0005434375850	20120	Economy	13000.00
0005434375748	20120	Economy	13000.00
0005434375757	20120	Economy	13000.00
0005434375672	20120	Economy	13000.00
0005434375766	20120	Economy	13000.00
0005434375525	20120	Economy	13000.00
0005434375802	20120	Economy	13000.00
0005434375768	20120	Economy	13000.00
0005434375839	20120	Economy	13000.00
0005434375751	20120	Economy	13000.00
0005434375869	20120	Economy	13000.00
0005434375910	20120	Economy	13000.00
0005434375831	20120	Economy	13000.00
0005434375937	20120	Economy	13000.00
0005434375825	20120	Economy	13000.00
0005434375819	20120	Economy	13000.00
0005434375844	20120	Economy	13000.00
0005433261890	499	Business	27500.00
0005433261883	499	Business	27500.00
0005433261957	499	Business	27500.00
0005433261906	499	Business	27500.00
0005433261989	499	Business	27500.00
0005433766757	499	Business	27500.00
0005433766767	499	Business	27500.00
0005433261936	499	Business	27500.00
0005433261991	499	Business	27500.00
0005433261887	499	Economy	10100.00
0005433261935	499	Economy	9200.00
0005433261894	499	Economy	9200.00
0005433261976	499	Economy	9200.00
0005432426069	499	Economy	9200.00
0005433261984	499	Economy	9200.00
0005433261914	499	Economy	9200.00
0005432426071	499	Economy	9200.00
0005434995380	499	Economy	9200.00
0005432426065	499	Economy	9200.00
0005432426076	499	Economy	9200.00
0005433261995	499	Economy	9200.00
0005433261933	499	Economy	9200.00
0005433261907	499	Economy	9200.00
0005433261891	499	Economy	9200.00
0005433262024	499	Economy	9200.00
0005434995381	499	Economy	9200.00
0005433262023	499	Economy	9200.00
0005433157012	499	Economy	9200.00
0005433261999	499	Economy	9200.00
0005432426067	499	Economy	9200.00
0005433261988	499	Economy	9200.00
0005433158201	499	Economy	9200.00
0005433261895	499	Economy	9200.00
0005433261954	499	Economy	9200.00
0005432426072	499	Economy	10100.00
0005433262025	499	Economy	9200.00
0005433261977	499	Economy	9200.00
0005433261978	499	Economy	9200.00
0005432426073	499	Economy	9200.00
0005433261963	499	Economy	9200.00
0005432426074	499	Economy	9200.00
0005433261956	499	Economy	9200.00
0005433261904	499	Economy	9200.00
0005433261898	499	Economy	9200.00
0005433261961	499	Economy	9200.00
0005432426068	499	Economy	9200.00
0005433261908	499	Economy	9200.00
0005433261893	499	Economy	9200.00
0005432426075	499	Economy	9200.00
0005433261932	499	Economy	9200.00
0005433261934	499	Economy	9200.00
0005434995379	499	Economy	9200.00
0005432426066	499	Economy	9200.00
0005432426070	499	Economy	9200.00
0005433262000	499	Economy	9200.00
0005433261962	499	Economy	9200.00
0005433261905	499	Economy	9200.00
0005433262061	12890	Economy	9200.00
0005432425572	12871	Business	27500.00
0005432425504	12871	Business	27500.00
0005432425630	12871	Business	27500.00
0005432425462	12871	Economy	10100.00
0005432425654	12871	Economy	9200.00
0005432425561	12871	Economy	9200.00
0005432425657	12871	Economy	9200.00
0005432425522	12871	Economy	9200.00
0005432425616	12871	Economy	9200.00
0005432425634	12871	Economy	9200.00
0005432425555	12871	Economy	9200.00
0005432425321	12871	Economy	9200.00
0005432425644	12871	Economy	9200.00
0005432425647	12871	Economy	9200.00
0005432425481	12871	Economy	9200.00
0005432425521	12871	Economy	9200.00
0005432425574	12871	Economy	9200.00
0005432425656	12871	Economy	9200.00
0005432425573	12871	Economy	9200.00
0005432425519	12871	Economy	9200.00
0005432425635	12871	Economy	9200.00
0005432425652	12871	Economy	9200.00
0005432425597	12871	Economy	10100.00
0005432425469	12871	Economy	9200.00
0005432425505	12871	Economy	9200.00
0005432425620	12871	Economy	9200.00
0005432425571	12871	Economy	9200.00
0005432425602	12871	Economy	9200.00
0005432425637	12871	Economy	9200.00
0005432425596	12871	Economy	9200.00
0005432425422	12871	Economy	9200.00
0005432425423	12871	Economy	9200.00
0005432425559	12871	Economy	9200.00
0005432425627	12871	Economy	9200.00
0005432425628	12871	Economy	9200.00
0005432425613	12871	Economy	9200.00
0005432425653	12871	Economy	9200.00
0005432425617	12871	Economy	9200.00
0005432425569	12871	Economy	9200.00
0005432425395	12871	Economy	9200.00
0005432425560	12871	Economy	9200.00
0005432425648	12871	Economy	9200.00
0005433058866	431	Business	24500.00
0005433058787	431	Business	24500.00
0005434025697	431	Business	24500.00
0005433058860	431	Business	24500.00
0005433058921	431	Economy	9000.00
0005433058740	431	Economy	8200.00
0005433058867	431	Economy	8200.00
0005433058818	431	Economy	8200.00
0005434735803	431	Economy	8200.00
0005433058923	431	Economy	8200.00
0005434735821	431	Economy	8200.00
0005433684466	431	Economy	8200.00
0005434735812	431	Economy	8200.00
0005433058857	431	Economy	8200.00
0005433058960	431	Economy	8200.00
0005433058833	431	Economy	8200.00
0005434735804	431	Economy	8200.00
0005434032161	431	Economy	8200.00
0005434735831	431	Economy	8200.00
0005433058920	431	Economy	8200.00
0005434025698	431	Economy	8200.00
0005433058911	431	Economy	8200.00
0005433058961	431	Economy	8200.00
0005433058926	431	Economy	8200.00
0005433058883	431	Economy	8200.00
0005433684471	431	Economy	8200.00
0005434028396	431	Economy	8200.00
0005433058912	431	Economy	8200.00
0005433058949	431	Economy	8200.00
0005434735788	431	Economy	9000.00
0005433058946	431	Economy	8200.00
0005433058970	431	Economy	8200.00
0005433058936	431	Economy	9000.00
0005433058715	431	Economy	8200.00
0005433058910	431	Economy	8200.00
0005434735790	431	Economy	8200.00
0005433058922	431	Economy	8200.00
0005433058950	431	Economy	8200.00
0005433058872	431	Economy	8200.00
0005433058758	431	Economy	8200.00
0005433058868	431	Economy	8200.00
0005434735805	431	Economy	8200.00
0005433058871	431	Economy	8200.00
0005434735787	431	Economy	8200.00
0005434735806	431	Economy	8200.00
0005434025136	12654	Business	24500.00
0005434025384	12654	Business	24500.00
0005434025440	12654	Business	24500.00
0005434025438	12654	Business	24500.00
0005434025510	12654	Business	24500.00
0005433059065	12654	Business	24500.00
0005434029724	12654	Business	24500.00
0005434025394	12654	Business	24500.00
0005434025295	12654	Business	24500.00
0005434025395	12654	Economy	9000.00
0005434029715	12654	Economy	9000.00
0005434025312	12654	Economy	8200.00
0005434025090	12654	Economy	8200.00
0005434025357	12654	Economy	8200.00
0005434025310	12654	Economy	8200.00
0005434025511	12654	Economy	8200.00
0005434025370	12654	Economy	8200.00
0005434025333	12654	Economy	8200.00
0005434025456	12654	Economy	8200.00
0005433059067	12654	Economy	8200.00
0005434025529	12654	Economy	8200.00
0005434025365	12654	Economy	8200.00
0005434025548	12654	Economy	8200.00
0005434025193	12654	Economy	8200.00
0005434025200	12654	Economy	8200.00
0005434025528	12654	Economy	8200.00
0005434025422	12654	Economy	8200.00
0005434025089	12654	Economy	8200.00
0005434025518	12654	Economy	8200.00
0005434025420	12654	Economy	8200.00
0005434025119	12654	Economy	8200.00
0005432156493	12654	Economy	8200.00
0005434025315	12654	Economy	8200.00
0005434025475	12654	Economy	8200.00
0005434025281	12654	Economy	8200.00
0005434025562	12654	Economy	8200.00
0005434029710	12654	Economy	8200.00
0005434025524	12654	Economy	8200.00
0005434025451	12654	Economy	8200.00
0005434025516	12654	Economy	8200.00
0005434025284	12654	Economy	8200.00
0005434025520	12654	Economy	8200.00
0005434025341	12654	Economy	8200.00
0005434025249	12654	Economy	8200.00
0005434025555	12654	Economy	8200.00
0005434025419	12654	Economy	8200.00
0005434025385	12654	Economy	8200.00
0005434025502	12654	Economy	9000.00
0005434025309	12654	Economy	8200.00
0005434025421	12654	Economy	8200.00
0005434025069	12654	Economy	8200.00
0005434025031	12654	Economy	8200.00
0005434025651	12654	Economy	8200.00
0005434025359	12654	Economy	8200.00
0005432156492	12654	Economy	8200.00
0005434025543	12654	Economy	8200.00
0005434025033	12654	Economy	8200.00
0005434025561	12654	Economy	8200.00
0005434025032	12654	Economy	8200.00
0005434025343	12654	Economy	8200.00
0005434025525	12654	Economy	8200.00
0005434025457	12654	Economy	8200.00
0005434025393	12654	Economy	8200.00
0005434025494	12654	Economy	8200.00
0005434025280	12654	Economy	8200.00
0005434029723	12654	Economy	8200.00
0005434025157	12654	Economy	8200.00
0005434025418	12654	Economy	8200.00
0005434029709	12654	Economy	8200.00
0005434025535	12654	Economy	8200.00
0005434025335	12654	Economy	8200.00
0005433059066	12654	Economy	8200.00
0005434025192	12654	Economy	8200.00
0005434029706	12654	Economy	8200.00
0005434025386	12654	Economy	8200.00
0005434025439	12654	Economy	8200.00
0005434025334	12654	Economy	8200.00
0005434029716	12654	Economy	8200.00
0005434025400	12654	Economy	8200.00
0005434025377	12654	Economy	8200.00
0005434025544	12654	Economy	8200.00
0005434029707	12654	Economy	8200.00
0005433037797	2144	Business	34700.00
0005433037754	2144	Business	34700.00
0005433926116	2144	Business	34700.00
0005433037510	2144	Business	34700.00
0005433037622	2144	Business	34700.00
0005433037738	2144	Business	34700.00
0005433037612	2144	Business	34700.00
0005433037655	2144	Business	34700.00
0005433037709	2144	Economy	12700.00
0005433037466	2144	Business	34700.00
0005433929884	2144	Economy	12700.00
0005433037796	2144	Economy	12700.00
0005433037572	2144	Economy	11600.00
0005433037693	2144	Economy	11600.00
0005433037503	2144	Economy	11600.00
0005433037465	2144	Economy	11600.00
0005433037650	2144	Economy	11600.00
0005433037531	2144	Economy	11600.00
0005433037511	2144	Economy	11600.00
0005433037666	2144	Economy	11600.00
0005433037640	2144	Economy	11600.00
0005433037621	2144	Economy	11600.00
0005433037517	2144	Economy	11600.00
0005433037736	2144	Economy	11600.00
0005433037638	2144	Economy	11600.00
0005433037692	2144	Economy	11600.00
0005433037532	2144	Economy	11600.00
0005433037707	2144	Economy	11600.00
0005433037464	2144	Economy	11600.00
0005433037611	2144	Economy	11600.00
0005433037441	2144	Economy	11600.00
0005433037410	2144	Economy	11600.00
0005433037658	2144	Economy	11600.00
0005433037604	2144	Economy	11600.00
0005433037695	2144	Economy	11600.00
0005433037557	2144	Economy	11600.00
0005433037620	2144	Economy	11600.00
0005433037700	2144	Economy	11600.00
0005433037694	2144	Economy	11600.00
0005433037735	2144	Economy	11600.00
0005433037627	2144	Economy	12700.00
0005433037484	2144	Economy	11600.00
0005433037525	2144	Economy	11600.00
0005433037684	2144	Economy	11600.00
0005433037764	2144	Economy	11600.00
0005433037649	2144	Economy	11600.00
0005433037765	2144	Economy	11600.00
0005433037559	2144	Economy	11600.00
0005433037516	2144	Economy	11600.00
0005433037742	2144	Economy	11600.00
0005433037737	2144	Economy	11600.00
0005433037605	2144	Economy	11600.00
0005433037526	2144	Economy	11600.00
0005433037623	2144	Economy	11600.00
0005433037442	2144	Economy	11600.00
0005433037708	2144	Economy	11600.00
0005433037657	2144	Economy	11600.00
0005433037701	2144	Economy	11600.00
0005433875431	2144	Economy	11600.00
0005432749838	2144	Economy	11600.00
0005433929897	2144	Economy	11600.00
0005433037639	2144	Economy	11600.00
0005433037633	2144	Economy	11600.00
0005433037601	2144	Economy	11600.00
0005433875430	2144	Economy	11600.00
0005433037502	2144	Economy	11600.00
0005433037656	2144	Economy	11600.00
0005433929885	2144	Economy	11600.00
0005433925528	24092	Business	34700.00
0005433925697	24092	Business	34700.00
0005433925553	24092	Business	34700.00
0005433929714	24092	Business	34700.00
0005433929869	24092	Business	34700.00
0005433925885	24092	Business	34700.00
0005433925590	24092	Business	34700.00
0005433925689	24092	Business	34700.00
0005433925684	24092	Economy	12700.00
0005433925777	24092	Economy	12700.00
0005433925359	24092	Economy	12700.00
0005433931534	24092	Economy	11600.00
0005433925936	24092	Economy	11600.00
0005433925460	24092	Economy	11600.00
0005433929888	24092	Economy	11600.00
0005433875424	24092	Economy	11600.00
0005433925527	24092	Economy	11600.00
0005433925610	24092	Economy	11600.00
0005433925819	24092	Economy	11600.00
0005433925749	24092	Economy	11600.00
0005433925954	24092	Economy	11600.00
0005433925443	24092	Economy	11600.00
0005433925724	24092	Economy	11600.00
0005433925468	24092	Economy	11600.00
0005433925843	24092	Economy	11600.00
0005433925529	24092	Economy	11600.00
0005433925688	24092	Economy	11600.00
0005433925935	24092	Economy	11600.00
0005433925932	24092	Economy	11600.00
0005433925466	24092	Economy	11600.00
0005433925480	24092	Economy	11600.00
0005433929707	24092	Economy	11600.00
0005433925638	24092	Economy	11600.00
0005433925479	24092	Economy	11600.00
0005433929874	24092	Economy	11600.00
0005433931539	24092	Economy	11600.00
0005433929887	24092	Economy	11600.00
0005433925454	24092	Economy	11600.00
0005433925637	24092	Economy	11600.00
0005433925367	24092	Economy	11600.00
0005433925655	24092	Economy	11600.00
0005433925552	24092	Economy	11600.00
0005433926056	24092	Economy	11600.00
0005433925921	24092	Economy	11600.00
0005433037851	24092	Economy	11600.00
0005433931542	24092	Economy	11600.00
0005433925656	24092	Economy	11600.00
0005433925582	24092	Economy	11600.00
0005433925776	24092	Economy	11600.00
0005433037849	24092	Economy	11600.00
0005433037850	24092	Economy	11600.00
0005433925647	24092	Economy	11600.00
0005433926022	24092	Economy	11600.00
0005433925627	24092	Economy	11600.00
0005433925469	24092	Economy	11600.00
0005433925886	24092	Economy	11600.00
0005433925496	24092	Economy	11600.00
0005433925895	24092	Economy	11600.00
0005433925612	24092	Economy	11600.00
0005433931541	24092	Economy	11600.00
0005433925706	24092	Economy	12700.00
0005433925854	24092	Economy	11600.00
0005433931528	24092	Economy	11600.00
0005433925850	24092	Economy	11600.00
0005433925687	24092	Economy	11600.00
0005433925467	24092	Economy	11600.00
0005433925427	24092	Economy	11600.00
0005433925483	24092	Economy	11600.00
0005433925322	24092	Economy	11600.00
0005433925818	24092	Economy	11600.00
0005432206361	24092	Economy	11600.00
0005433925719	24092	Economy	11600.00
0005433925730	24092	Economy	11600.00
0005434175881	24092	Economy	11600.00
0005433925611	24092	Economy	11600.00
0005433925625	24092	Economy	11600.00
0005433925657	24092	Economy	11600.00
0005433931538	24092	Economy	11600.00
0005433925753	24092	Economy	11600.00
0005433931537	24092	Economy	11600.00
0005433925896	24092	Economy	11600.00
0005433925097	24092	Economy	11600.00
0005433925609	24092	Economy	11600.00
0005433926033	24092	Economy	11600.00
0005433929876	24092	Economy	11600.00
0005433925683	24092	Economy	11600.00
0005433925421	24092	Economy	11600.00
0005433925698	24092	Economy	11600.00
0005434175882	24092	Economy	11600.00
0005433925778	24092	Economy	11600.00
0005433929875	24092	Economy	11600.00
0005433875423	24092	Economy	11600.00
0005433925476	24092	Economy	11600.00
0005433925829	24092	Economy	11600.00
0005433931536	24092	Economy	11600.00
0005433925715	24092	Economy	11600.00
0005433925646	24092	Economy	11600.00
0005433929701	24092	Economy	11600.00
0005433925626	24092	Economy	11600.00
0005433925725	24092	Economy	11600.00
0005433925958	24092	Economy	11600.00
0005433181689	252	Business	83700.00
0005433766722	252	Business	83700.00
0005433235879	252	Business	83700.00
0005433131832	252	Business	83700.00
0005433235646	252	Business	83700.00
0005433235831	252	Business	83700.00
0005433235716	252	Business	83700.00
0005433181597	252	Business	83700.00
0005433235824	252	Business	83700.00
0005433235749	252	Business	83700.00
0005433181747	252	Business	83700.00
0005433235676	252	Business	83700.00
0005433181705	252	Comfort	47400.00
0005433111558	252	Comfort	47400.00
0005433235767	252	Comfort	47400.00
0005433235594	252	Comfort	47400.00
0005433181691	252	Comfort	47400.00
0005433235876	252	Comfort	47400.00
0005433131819	252	Comfort	47400.00
0005435142969	252	Comfort	47400.00
0005433181610	252	Comfort	47400.00
0005433126949	252	Comfort	47400.00
0005433235681	252	Comfort	47400.00
0005433235795	252	Comfort	47400.00
0005434729047	252	Economy	27900.00
0005433235890	252	Economy	27900.00
0005433181630	252	Economy	27900.00
0005434729048	252	Economy	27900.00
0005433181690	252	Economy	27900.00
0005433181783	252	Economy	27900.00
0005433235685	252	Economy	27900.00
0005433181703	252	Economy	27900.00
0005433181780	252	Economy	27900.00
0005433181708	252	Economy	27900.00
0005433235675	252	Economy	27900.00
0005433235548	252	Economy	27900.00
0005433181709	252	Economy	27900.00
0005433235866	252	Economy	27900.00
0005434729042	252	Economy	27900.00
0005433131833	252	Economy	27900.00
0005434729046	252	Economy	27900.00
0005433235809	252	Economy	27900.00
0005433235865	252	Economy	27900.00
0005433235549	252	Economy	27900.00
0005433235683	252	Economy	27900.00
0005433181702	252	Economy	27900.00
0005433111553	252	Economy	27900.00
0005434729045	252	Economy	27900.00
0005433181781	252	Economy	27900.00
0005433235670	252	Economy	27900.00
0005433235668	252	Economy	27900.00
0005433235794	252	Economy	27900.00
0005433235710	252	Economy	30700.00
0005433235602	252	Economy	27900.00
0005434552866	252	Economy	30700.00
0005434729044	252	Economy	27900.00
0005433235596	252	Economy	27900.00
0005434729041	252	Economy	27900.00
0005433235564	252	Economy	27900.00
0005434032141	252	Economy	27900.00
0005433181688	252	Economy	27900.00
0005433235781	252	Economy	27900.00
0005433235889	252	Economy	27900.00
0005434729040	252	Economy	27900.00
0005433235888	252	Economy	27900.00
0005433181609	252	Economy	27900.00
0005433290006	252	Economy	27900.00
0005433181753	252	Economy	27900.00
0005433290042	252	Economy	27900.00
0005433235805	252	Economy	27900.00
0005433235669	252	Economy	27900.00
0005433235682	252	Economy	27900.00
0005433235667	252	Economy	27900.00
0005433181710	252	Economy	27900.00
0005433126951	252	Economy	27900.00
0005433181608	252	Economy	27900.00
0005433126958	252	Economy	27900.00
0005433181671	252	Economy	27900.00
0005433235786	252	Economy	27900.00
0005433290015	252	Economy	27900.00
0005433235762	252	Economy	27900.00
0005433235332	252	Economy	27900.00
0005433181685	252	Economy	27900.00
0005433235808	252	Economy	27900.00
0005433181704	252	Economy	27900.00
0005433235717	252	Economy	27900.00
0005433181787	252	Economy	27900.00
0005433113589	252	Economy	27900.00
0005433766747	252	Economy	27900.00
0005433111552	252	Economy	27900.00
0005433235782	252	Economy	27900.00
0005433235891	252	Economy	27900.00
0005433111562	252	Economy	27900.00
0005433181811	252	Economy	27900.00
0005433181786	252	Economy	27900.00
0005433235761	252	Economy	27900.00
0005433235406	252	Economy	27900.00
0005433290043	252	Economy	27900.00
0005433235785	252	Economy	27900.00
0005434552863	252	Economy	30700.00
0005433126950	252	Economy	30700.00
0005433181721	252	Economy	27900.00
0005434729043	252	Economy	27900.00
0005434729039	252	Economy	27900.00
0005433126956	252	Economy	27900.00
0005433235859	252	Economy	27900.00
0005433235684	252	Economy	27900.00
0005433290037	252	Economy	27900.00
0005434032128	252	Economy	27900.00
0005433235546	252	Economy	27900.00
0005434552865	252	Economy	27900.00
0005433235860	252	Economy	27900.00
0005433235577	252	Economy	27900.00
0005433181782	252	Economy	27900.00
0005433290020	252	Economy	27900.00
0005433235600	252	Economy	27900.00
0005433111563	252	Economy	27900.00
0005433235686	252	Economy	27900.00
0005433235842	252	Economy	27900.00
0005433181683	252	Economy	27900.00
0005433131835	252	Economy	27900.00
0005433235595	252	Economy	27900.00
0005433235766	252	Economy	27900.00
0005435142970	252	Economy	27900.00
0005433235885	252	Economy	27900.00
0005434552864	252	Economy	27900.00
0005433290019	252	Economy	27900.00
0005433235746	252	Economy	27900.00
0005433235545	252	Economy	27900.00
0005433290038	252	Economy	27900.00
0005433181785	252	Economy	27900.00
0005434728604	9856	Business	83700.00
0005434552191	9856	Business	83700.00
0005434552408	9856	Business	83700.00
0005434735811	9856	Business	83700.00
0005433236062	9856	Business	83700.00
0005434728510	9856	Business	83700.00
0005434552534	9856	Business	83700.00
0005434728495	9856	Business	83700.00
0005434728447	9856	Business	83700.00
0005434728315	9856	Business	83700.00
0005434552406	9856	Comfort	47400.00
0005434552694	9856	Comfort	47400.00
0005434552619	9856	Comfort	47400.00
0005434728079	9856	Comfort	47400.00
0005434552684	9856	Comfort	47400.00
0005433236063	9856	Comfort	47400.00
0005434728621	9856	Comfort	47400.00
0005434552627	9856	Comfort	47400.00
0005434728521	9856	Comfort	47400.00
0005434552645	9856	Comfort	47400.00
0005433236059	9856	Comfort	47400.00
0005434552503	9856	Comfort	47400.00
0005434728768	9856	Comfort	47400.00
0005433236060	9856	Comfort	47400.00
0005434552593	9856	Comfort	47400.00
0005433236061	9856	Comfort	47400.00
0005434728365	9856	Comfort	47400.00
0005434552405	9856	Comfort	47400.00
0005434728173	9856	Comfort	47400.00
0005434728889	9856	Economy	27900.00
0005434727685	9856	Economy	27900.00
0005434728463	9856	Economy	27900.00
0005434552628	9856	Economy	27900.00
0005435142883	9856	Economy	27900.00
0005434552550	9856	Economy	27900.00
0005434552641	9856	Economy	27900.00
0005434552648	9856	Economy	27900.00
0005434552397	9856	Economy	27900.00
0005434552350	9856	Economy	27900.00
0005434728064	9856	Economy	27900.00
0005434728690	9856	Economy	27900.00
0005435142932	9856	Economy	27900.00
0005434728509	9856	Economy	27900.00
0005434728652	9856	Economy	27900.00
0005434552407	9856	Economy	27900.00
0005434552655	9856	Economy	27900.00
0005434735807	9856	Economy	27900.00
0005434728544	9856	Economy	27900.00
0005434728739	9856	Economy	27900.00
0005433181840	9856	Economy	27900.00
0005434728704	9856	Economy	27900.00
0005434728361	9856	Economy	27900.00
0005434552580	9856	Economy	27900.00
0005433181841	9856	Economy	27900.00
0005434728536	9856	Economy	27900.00
0005434552585	9856	Economy	27900.00
0005434728366	9856	Economy	27900.00
0005434728168	9856	Economy	27900.00
0005434552566	9856	Economy	27900.00
0005434552436	9856	Economy	27900.00
0005434552594	9856	Economy	27900.00
0005434727686	9856	Economy	30700.00
0005434728765	9856	Economy	30700.00
0005434731284	9856	Economy	27900.00
0005434728480	9856	Economy	27900.00
0005434728357	9856	Economy	30700.00
0005434728058	9856	Economy	27900.00
0005434552560	9856	Economy	30700.00
0005434728766	9856	Economy	27900.00
0005434727654	9856	Economy	27900.00
0005434552435	9856	Economy	27900.00
0005434552605	9856	Economy	27900.00
0005434552396	9856	Economy	27900.00
0005434552558	9856	Economy	27900.00
0005434728420	9856	Economy	27900.00
0005434728620	9856	Economy	27900.00
0005434728882	9856	Economy	27900.00
0005434728358	9856	Economy	27900.00
0005434552533	9856	Economy	27900.00
0005434552401	9856	Economy	27900.00
0005434728178	9856	Economy	27900.00
0005434728496	9856	Economy	27900.00
0005434552663	9856	Economy	27900.00
0005434728987	9856	Economy	27900.00
0005434552647	9856	Economy	27900.00
0005434728838	9856	Economy	27900.00
0005434728764	9856	Economy	27900.00
0005434728414	9856	Economy	27900.00
0005435142843	9856	Economy	27900.00
0005433236064	9856	Economy	27900.00
0005434552573	9856	Economy	27900.00
0005434728226	9856	Economy	27900.00
0005434728317	9856	Economy	27900.00
0005434552351	9856	Economy	27900.00
0005434728446	9856	Economy	27900.00
0005434728810	9856	Economy	27900.00
0005434728584	9856	Economy	27900.00
0005434728610	9856	Economy	27900.00
0005434728680	9856	Economy	27900.00
0005434728152	9856	Economy	27900.00
0005434728674	9856	Economy	27900.00
0005434728304	9856	Economy	27900.00
0005434731271	9856	Economy	27900.00
0005434552696	9856	Economy	27900.00
0005434552565	9856	Economy	27900.00
0005434552622	9856	Economy	27900.00
0005434728692	9856	Economy	27900.00
0005434735825	9856	Economy	27900.00
0005434728065	9856	Economy	27900.00
0005434728445	9856	Economy	27900.00
0005434552427	9856	Economy	27900.00
0005434552567	9856	Economy	27900.00
0005434552549	9856	Economy	27900.00
0005434727687	9856	Economy	27900.00
0005434552418	9856	Economy	27900.00
0005434728413	9856	Economy	27900.00
0005434728074	9856	Economy	27900.00
0005434735826	9856	Economy	27900.00
0005434552752	9856	Economy	27900.00
0005435142862	9856	Economy	27900.00
0005434552399	9856	Economy	27900.00
0005434728556	9856	Economy	27900.00
0005434552321	9856	Economy	27900.00
0005434728316	9856	Economy	27900.00
0005434552502	9856	Economy	27900.00
0005434728767	9856	Economy	30700.00
0005434552799	9856	Economy	30700.00
0005434728400	9856	Economy	27900.00
0005434552693	9856	Economy	27900.00
0005434728819	9856	Economy	27900.00
0005434728318	9856	Economy	27900.00
0005434728075	9856	Economy	27900.00
0005434728037	9856	Economy	27900.00
0005434302552	9856	Economy	27900.00
0005434728917	9856	Economy	27900.00
0005434552662	9856	Economy	27900.00
0005434552400	9856	Economy	27900.00
0005434552466	9856	Economy	27900.00
0005434552528	9856	Economy	27900.00
0005433181842	9856	Economy	27900.00
0005434552437	9856	Economy	27900.00
0005434728336	9856	Economy	27900.00
0005434552646	9856	Economy	27900.00
0005434728387	9856	Economy	27900.00
0005435142877	9856	Economy	27900.00
0005434728462	9856	Economy	27900.00
0005434728419	9856	Economy	27900.00
0005434728080	9856	Economy	27900.00
0005434552710	9856	Economy	27900.00
0005434552559	9856	Economy	27900.00
0005434727957	9856	Economy	27900.00
0005434552620	9856	Economy	27900.00
0005434727999	9856	Economy	27900.00
0005434552564	9856	Economy	27900.00
0005434727653	9856	Economy	27900.00
0005434728660	9856	Economy	27900.00
0005434552595	9856	Economy	27900.00
0005434728485	9856	Economy	27900.00
0005434728216	9856	Economy	27900.00
0005434728640	9856	Economy	27900.00
0005434552498	9856	Economy	27900.00
0005434731285	9856	Economy	27900.00
0005434728401	9856	Economy	27900.00
0005434728918	9856	Economy	27900.00
0005434728408	9856	Economy	27900.00
0005434552394	9856	Economy	27900.00
0005434552685	9856	Economy	27900.00
0005434728858	9856	Economy	27900.00
0005434728277	9856	Economy	27900.00
0005434727958	9856	Economy	27900.00
0005434728174	9856	Economy	27900.00
0005434552391	9856	Economy	27900.00
0005434552635	9856	Economy	27900.00
0005435142855	9856	Economy	27900.00
0005434552800	9856	Economy	27900.00
0005435142899	9856	Economy	27900.00
0005434728693	9856	Economy	27900.00
0005434728177	9856	Economy	27900.00
0005434728386	9856	Economy	27900.00
0005434552621	9856	Economy	27900.00
0005434728167	9856	Economy	27900.00
0005434728622	9856	Economy	27900.00
0005434552606	9856	Economy	27900.00
0005434728388	9856	Economy	27900.00
0005435215369	7733	Business	42100.00
0005435283471	7733	Business	42100.00
0005435215187	7733	Business	42100.00
0005434069647	7733	Business	42100.00
0005435215264	7733	Business	42100.00
0005435283461	7733	Business	42100.00
0005435215366	7733	Business	42100.00
0005435215358	7733	Business	42100.00
0005435215253	7733	Comfort	23900.00
0005435215262	7733	Comfort	23900.00
0005435215125	7733	Comfort	23900.00
0005435215204	7733	Comfort	23900.00
0005435214854	7733	Comfort	23900.00
0005435215123	7733	Comfort	23900.00
0005435283472	7733	Comfort	23900.00
0005435215202	7733	Comfort	23900.00
0005432531831	7733	Comfort	23900.00
0005435283502	7733	Comfort	23900.00
0005435215340	7733	Comfort	23900.00
0005435214768	7733	Comfort	23900.00
0005433656748	7733	Comfort	23900.00
0005434069645	7733	Comfort	23900.00
0005435215287	7733	Comfort	23900.00
0005432531834	7733	Economy	14000.00
0005435215284	7733	Economy	14000.00
0005435283470	7733	Economy	14000.00
0005432531830	7733	Economy	14000.00
0005435631045	7733	Economy	14000.00
0005435215374	7733	Economy	14000.00
0005435214995	7733	Economy	14000.00
0005435215283	7733	Economy	14000.00
0005435283473	7733	Economy	14000.00
0005435725719	7733	Economy	14000.00
0005435215208	7733	Economy	14000.00
0005432531841	7733	Economy	14000.00
0005435214715	7733	Economy	14000.00
0005435215251	7733	Economy	14000.00
0005432531836	7733	Economy	14000.00
0005435283450	7733	Economy	14000.00
0005434069648	7733	Economy	14000.00
0005435215383	7733	Economy	14000.00
0005435283434	7733	Economy	15400.00
0005435215278	7733	Economy	14000.00
0005435215019	7733	Economy	15400.00
0005432531833	7733	Economy	15400.00
0005432531829	7733	Economy	14000.00
0005435215341	7733	Economy	14000.00
0005433656745	7733	Economy	14000.00
0005435215395	7733	Economy	14000.00
0005435215210	7733	Economy	14000.00
0005435631030	7733	Economy	14000.00
0005435215188	7733	Economy	14000.00
0005435283445	7733	Economy	14000.00
0005435215252	7733	Economy	14000.00
0005435283459	7733	Economy	14000.00
0005435215289	7733	Economy	14000.00
0005435215319	7733	Economy	14000.00
0005432531837	7733	Economy	14000.00
0005435214769	7733	Economy	14000.00
0005435283446	7733	Economy	14000.00
0005435214996	7733	Economy	14000.00
0005433656747	7733	Economy	14000.00
0005435215124	7733	Economy	14000.00
0005432531840	7733	Economy	14000.00
0005435631031	7733	Economy	14000.00
0005435283488	7733	Economy	14000.00
0005435215269	7733	Economy	14000.00
0005432531832	7733	Economy	14000.00
0005433656746	7733	Economy	14000.00
0005435215147	7733	Economy	14000.00
0005434069646	7733	Economy	14000.00
0005435215209	7733	Economy	14000.00
0005435283448	7733	Economy	14000.00
0005435215396	7733	Economy	14000.00
0005435215032	7733	Economy	14000.00
0005435725724	7733	Economy	15400.00
0005432531835	7733	Economy	15400.00
0005432531839	7733	Economy	15400.00
0005435283460	7733	Economy	15400.00
0005432531838	7733	Economy	14000.00
0005435215268	7733	Economy	14000.00
0005435215126	7733	Economy	14000.00
0005435214955	7733	Economy	14000.00
0005435283458	7733	Economy	14000.00
0005435215177	7733	Economy	14000.00
0005435215373	7733	Economy	14000.00
0005435215265	7733	Economy	14000.00
0005435215368	7733	Economy	14000.00
0005435631033	7733	Economy	14000.00
0005435215033	7733	Economy	14000.00
0005435283489	7733	Economy	14000.00
0005435215367	7733	Economy	14000.00
0005435215382	7733	Economy	14000.00
0005435214858	7733	Economy	14000.00
0005435215464	7733	Economy	14000.00
0005435283447	7733	Economy	14000.00
0005435283500	7733	Economy	14000.00
0005434069649	7733	Economy	14000.00
0005435215465	7733	Economy	14000.00
0005435215497	7733	Economy	14000.00
0005435214907	7733	Economy	14000.00
0005435426454	5357	Business	43100.00
0005434245683	5357	Business	43100.00
0005435426407	5357	Business	43100.00
0005435426656	5357	Business	43100.00
0005435426419	5357	Business	43100.00
0005435551783	5357	Business	43100.00
0005432841066	5357	Business	43100.00
0005434573776	5357	Business	43100.00
0005435426623	5357	Business	43100.00
0005435654505	5357	Business	43100.00
0005434345289	5357	Comfort	24400.00
0005435426619	5357	Comfort	24400.00
0005435426697	5357	Comfort	24400.00
0005434245838	5357	Comfort	24400.00
0005435302320	5357	Comfort	24400.00
0005435654510	5357	Comfort	24400.00
0005432363496	5357	Comfort	24400.00
0005434345296	5357	Comfort	24400.00
0005435426609	5357	Comfort	24400.00
0005435426631	5357	Comfort	24400.00
0005435426658	5357	Comfort	24400.00
0005435426266	5357	Comfort	24400.00
0005434345297	5357	Comfort	24400.00
0005435426504	5357	Comfort	24400.00
0005435654504	5357	Comfort	24400.00
0005432841060	5357	Comfort	24400.00
0005435654509	5357	Economy	14400.00
0005433719207	5357	Economy	14400.00
0005435426596	5357	Economy	14400.00
0005435426676	5357	Economy	14400.00
0005435426447	5357	Economy	14400.00
0005435426643	5357	Economy	14400.00
0005434245699	5357	Economy	14400.00
0005435302311	5357	Economy	14400.00
0005432363505	5357	Economy	14400.00
0005435042903	5357	Economy	14400.00
0005434345293	5357	Economy	14400.00
0005434245655	5357	Economy	14400.00
0005434245740	5357	Economy	14400.00
0005435426289	5357	Economy	14400.00
0005434656601	5357	Economy	14400.00
0005434345291	5357	Economy	14400.00
0005435426707	5357	Economy	14400.00
0005435617048	5357	Economy	14400.00
0005435426573	5357	Economy	14400.00
0005435380420	5357	Economy	14400.00
0005435426483	5357	Economy	14400.00
0005435617045	5357	Economy	14400.00
0005435302305	5357	Economy	14400.00
0005434573775	5357	Economy	14400.00
0005435551784	5357	Economy	14400.00
0005435426461	5357	Economy	14400.00
0005435426706	5357	Economy	14400.00
0005435426469	5357	Economy	14400.00
0005435426372	5357	Economy	14400.00
0005435426206	5357	Economy	15800.00
0005435319762	5357	Economy	15800.00
0005435042917	5357	Economy	14400.00
0005434245781	5357	Economy	15800.00
0005435426171	5357	Economy	14400.00
0005435768109	5357	Economy	14400.00
0005433719227	5357	Economy	14400.00
0005434245802	5357	Economy	14400.00
0005435617051	5357	Economy	14400.00
0005434345295	5357	Economy	14400.00
0005435426702	5357	Economy	14400.00
0005435768106	5357	Economy	14400.00
0005435426486	5357	Economy	14400.00
0005435426382	5357	Economy	14400.00
0005435426429	5357	Economy	14400.00
0005435654508	5357	Economy	14400.00
0005435617046	5357	Economy	14400.00
0005435426470	5357	Economy	14400.00
0005435551785	5357	Economy	14400.00
0005435654511	5357	Economy	14400.00
0005435305073	5357	Economy	14400.00
0005432133660	5357	Economy	14400.00
0005435426502	5357	Economy	14400.00
0005434245698	5357	Economy	14400.00
0005434245801	5357	Economy	14400.00
0005435426580	5357	Economy	14400.00
0005435426572	5357	Economy	14400.00
0005432363499	5357	Economy	14400.00
0005435617050	5357	Economy	14400.00
0005435426695	5357	Economy	14400.00
0005435426620	5357	Economy	14400.00
0005435426417	5357	Economy	14400.00
0005434345292	5357	Economy	14400.00
0005435426696	5357	Economy	14400.00
0005434245600	5357	Economy	14400.00
0005435426524	5357	Economy	14400.00
0005434345294	5357	Economy	14400.00
0005432363506	5357	Economy	14400.00
0005434573774	5357	Economy	14400.00
0005434245599	5357	Economy	15800.00
0005435426729	5357	Economy	15800.00
0005434245718	5357	Economy	15800.00
0005435426610	5357	Economy	14400.00
0005435426758	5357	Economy	14400.00
0005435042905	5357	Economy	14400.00
0005435302319	5357	Economy	14400.00
0005435426462	5357	Economy	14400.00
0005435426308	5357	Economy	14400.00
0005435426525	5357	Economy	14400.00
0005434245643	5357	Economy	14400.00
0005435426418	5357	Economy	14400.00
0005435617047	5357	Economy	14400.00
0005435426433	5357	Economy	14400.00
0005432363497	5357	Economy	14400.00
0005435426673	5357	Economy	14400.00
0005435426744	5357	Economy	14400.00
0005435426503	5357	Economy	14400.00
0005435380424	5357	Economy	14400.00
0005434345290	5357	Economy	14400.00
0005435546239	5357	Economy	14400.00
0005435426371	5357	Economy	14400.00
0005435426585	5357	Economy	14400.00
0005435426633	5357	Economy	14400.00
0005432841061	5357	Economy	14400.00
0005434656606	5357	Economy	14400.00
0005434245647	5357	Economy	14400.00
0005435380423	5357	Economy	14400.00
0005435426680	5357	Economy	14400.00
0005435617049	5357	Economy	14400.00
0005435042904	5357	Economy	14400.00
0005435426674	5357	Economy	14400.00
0005435426351	5357	Economy	14400.00
0005435426757	5357	Economy	14400.00
0005435426207	5357	Economy	14400.00
0005435426578	5357	Economy	14400.00
0005435426626	5357	Economy	14400.00
0005435319822	5357	Economy	14400.00
0005435426759	5357	Economy	14400.00
0005435426657	5357	Economy	14400.00
0005434245630	5357	Economy	14400.00
0005434245619	5357	Economy	14400.00
0005434656600	5357	Economy	14400.00
0005435426621	5357	Economy	14400.00
0005435380425	5357	Economy	14400.00
0005435426511	5357	Economy	14400.00
0005432133661	5357	Economy	14400.00
0005434245833	5357	Economy	14400.00
0005435426675	5357	Economy	14400.00
0005435319799	5357	Economy	14400.00
0005435768110	5357	Economy	14400.00
0005435654520	10919	Business	43100.00
0005435555425	10919	Business	43100.00
0005435615790	10919	Business	43100.00
0005434344940	10919	Business	43100.00
0005435616232	10919	Business	43100.00
0005434573682	10919	Business	43100.00
0005434573675	10919	Business	43100.00
0005435426847	10919	Business	43100.00
0005434345006	10919	Business	43100.00
0005434344908	10919	Business	43100.00
0005434345136	10919	Business	43100.00
0005435616497	10919	Business	43100.00
0005435616685	10919	Business	43100.00
0005434345170	10919	Business	43100.00
0005435616056	10919	Business	43100.00
0005435654519	10919	Comfort	24400.00
0005435616706	10919	Comfort	24400.00
0005435616469	10919	Comfort	24400.00
0005435490308	10919	Comfort	24400.00
0005434344969	10919	Comfort	24400.00
0005435616298	10919	Comfort	24400.00
0005435654518	10919	Comfort	24400.00
0005435616672	10919	Comfort	24400.00
0005434344907	10919	Comfort	24400.00
0005435616233	10919	Comfort	24400.00
0005435616334	10919	Comfort	24400.00
0005434345135	10919	Comfort	24400.00
0005435616068	10919	Comfort	24400.00
0005435616273	10919	Comfort	24400.00
0005435616630	10919	Comfort	24400.00
0005435626882	10919	Comfort	24400.00
0005435626881	10919	Comfort	24400.00
0005434344956	10919	Comfort	24400.00
0005434345064	10919	Comfort	24400.00
0005434345021	10919	Comfort	24400.00
0005435616735	10919	Comfort	24400.00
0005435616665	10919	Comfort	24400.00
0005434345022	10919	Comfort	24400.00
0005435616832	10919	Comfort	24400.00
0005435426848	10919	Comfort	24400.00
0005434345020	10919	Comfort	24400.00
0005435615827	10919	Comfort	24400.00
0005435616639	10919	Comfort	24400.00
0005435616653	10919	Economy	14400.00
0005434573677	10919	Economy	14400.00
0005435616645	10919	Economy	14400.00
0005435490328	10919	Economy	14400.00
0005435097440	10919	Economy	14400.00
0005435380442	10919	Economy	14400.00
0005435626883	10919	Economy	14400.00
0005435615789	10919	Economy	14400.00
0005435616688	10919	Economy	14400.00
0005435616689	10919	Economy	14400.00
0005434345005	10919	Economy	14400.00
0005435616087	10919	Economy	14400.00
0005435768124	10919	Economy	14400.00
0005435616299	10919	Economy	14400.00
0005434344996	10919	Economy	14400.00
0005434344966	10919	Economy	14400.00
0005435616246	10919	Economy	14400.00
0005435616149	10919	Economy	14400.00
0005435616400	10919	Economy	14400.00
0005434573688	10919	Economy	14400.00
0005435616640	10919	Economy	14400.00
0005435616792	10919	Economy	14400.00
0005435616760	10919	Economy	14400.00
0005434344943	10919	Economy	14400.00
0005432165266	10919	Economy	14400.00
0005434573737	10919	Economy	14400.00
0005435616541	10919	Economy	14400.00
0005435097451	10919	Economy	14400.00
0005435616745	10919	Economy	14400.00
0005434573683	10919	Economy	14400.00
0005435380443	10919	Economy	14400.00
0005435616710	10919	Economy	14400.00
0005435616091	10919	Economy	14400.00
0005435616529	10919	Economy	14400.00
0005435616446	10919	Economy	14400.00
0005435616041	10919	Economy	15800.00
0005434573671	10919	Economy	14400.00
0005434345078	10919	Economy	14400.00
0005435555423	10919	Economy	15800.00
0005435616712	10919	Economy	15800.00
0005435616512	10919	Economy	14400.00
0005434573670	10919	Economy	14400.00
0005435616772	10919	Economy	14400.00
0005435616034	10919	Economy	14400.00
0005434344825	10919	Economy	14400.00
0005435616281	10919	Economy	14400.00
0005435615826	10919	Economy	14400.00
0005435616212	10919	Economy	14400.00
0005434345117	10919	Economy	14400.00
0005435097435	10919	Economy	14400.00
0005435615784	10919	Economy	14400.00
0005434573673	10919	Economy	14400.00
0005434344826	10919	Economy	14400.00
0005435616731	10919	Economy	14400.00
0005435616401	10919	Economy	14400.00
0005435616431	10919	Economy	14400.00
0005435490307	10919	Economy	14400.00
0005434573647	10919	Economy	14400.00
0005435616711	10919	Economy	14400.00
0005435616437	10919	Economy	14400.00
0005435616632	10919	Economy	14400.00
0005435616447	10919	Economy	14400.00
0005435616106	10919	Economy	14400.00
0005435616271	10919	Economy	14400.00
0005435616144	10919	Economy	14400.00
0005435616332	10919	Economy	14400.00
0005434345121	10919	Economy	14400.00
0005435654517	10919	Economy	14400.00
0005435616402	10919	Economy	14400.00
0005435616331	10919	Economy	14400.00
0005435616686	10919	Economy	14400.00
0005435616843	10919	Economy	14400.00
0005435616720	10919	Economy	14400.00
0005435615666	10919	Economy	14400.00
0005435616012	10919	Economy	14400.00
0005435616453	10919	Economy	14400.00
0005435616774	10919	Economy	14400.00
0005434345119	10919	Economy	14400.00
0005435616493	10919	Economy	14400.00
0005435097418	10919	Economy	14400.00
0005435616644	10919	Economy	14400.00
0005435616486	10919	Economy	14400.00
0005435491503	10919	Economy	14400.00
0005435097434	10919	Economy	14400.00
0005435616104	10919	Economy	14400.00
0005434344935	10919	Economy	14400.00
0005435616771	10919	Economy	14400.00
0005435319829	10919	Economy	14400.00
0005435616114	10919	Economy	14400.00
0005435616670	10919	Economy	15800.00
0005435616586	10919	Economy	15800.00
0005434344944	10919	Economy	14400.00
0005435616730	10919	Economy	14400.00
0005435616335	10919	Economy	14400.00
0005434345048	10919	Economy	14400.00
0005434573691	10919	Economy	14400.00
0005435616452	10919	Economy	14400.00
0005435616333	10919	Economy	14400.00
0005435616267	10919	Economy	14400.00
0005435616150	10919	Economy	14400.00
0005435616664	10919	Economy	14400.00
0005435616663	10919	Economy	14400.00
0005435616456	10919	Economy	14400.00
0005434573676	10919	Economy	14400.00
0005435654516	10919	Economy	14400.00
0005435426846	10919	Economy	14400.00
0005435491491	10919	Economy	14400.00
0005435491490	10919	Economy	14400.00
0005435616620	10919	Economy	14400.00
0005434344965	10919	Economy	14400.00
0005434345124	10919	Economy	14400.00
0005435616533	10919	Economy	14400.00
0005434345125	10919	Economy	14400.00
0005435768125	10919	Economy	14400.00
0005435616297	10919	Economy	14400.00
0005435616596	10919	Economy	14400.00
0005435616920	10919	Economy	14400.00
0005434345129	10919	Economy	14400.00
0005435616498	10919	Economy	14400.00
0005435617186	10919	Economy	14400.00
0005434245847	10919	Economy	14400.00
0005434344934	10919	Economy	14400.00
0005435616436	10919	Economy	14400.00
0005435555426	10919	Economy	14400.00
0005435097452	10919	Economy	14400.00
0005435617185	10919	Economy	14400.00
0005434573646	10919	Economy	14400.00
0005435616348	10919	Economy	14400.00
0005435616709	10919	Economy	14400.00
0005435616705	10919	Economy	14400.00
0005435616652	10919	Economy	14400.00
0005435616350	10919	Economy	14400.00
0005435490327	10919	Economy	14400.00
0005435616936	10919	Economy	14400.00
0005435097419	10919	Economy	14400.00
0005435616511	10919	Economy	14400.00
0005434344964	10919	Economy	14400.00
0005435616445	10919	Economy	14400.00
0005434345134	10919	Economy	14400.00
0005435616631	10919	Economy	14400.00
0005435616326	10919	Economy	14400.00
0005435616726	10919	Economy	14400.00
0005434344869	10919	Economy	14400.00
0005435490319	10919	Economy	14400.00
0005435616213	10919	Economy	14400.00
0005434245846	10919	Economy	14400.00
0005435616606	10919	Economy	14400.00
0005434345023	10919	Economy	14400.00
0005435616773	10919	Economy	14400.00
0005434311286	3286	Business	18800.00
0005434150233	3286	Business	18800.00
0005432461124	3286	Business	18800.00
0005435860652	3286	Business	18800.00
0005432461192	3286	Business	18800.00
0005435860663	3286	Business	18800.00
0005435856348	3286	Business	18800.00
0005432461172	3286	Business	18800.00
0005432460982	3286	Business	18800.00
0005434182554	3286	Business	18800.00
0005435933569	3286	Business	18800.00
0005434326054	3286	Business	18800.00
0005435860678	3286	Business	18800.00
0005435933568	3286	Business	18800.00
0005435933578	3286	Business	18800.00
0005435999873	3286	Business	18800.00
0005434266044	3286	Business	18800.00
0005435860646	3286	Business	18800.00
0005435142990	3286	Business	18800.00
0005432461255	3286	Business	18800.00
0005435860654	3286	Business	18800.00
0005435933579	3286	Business	18800.00
0005435856338	3286	Economy	6900.00
0005433507732	3286	Economy	6900.00
0005432460884	3286	Economy	6900.00
0005432461240	3286	Economy	6300.00
0005432461280	3286	Economy	6300.00
0005432461217	3286	Economy	6300.00
0005435142973	3286	Economy	6300.00
0005432461195	3286	Economy	6300.00
0005432461154	3286	Economy	6300.00
0005434266040	3286	Economy	6300.00
0005432182371	3286	Economy	6300.00
0005432461122	3286	Economy	6300.00
0005434266047	3286	Economy	6300.00
0005435142974	3286	Economy	6300.00
0005435858703	3286	Economy	6300.00
0005434266041	3286	Economy	6300.00
0005432461227	3286	Economy	6300.00
0005435858710	3286	Economy	6300.00
0005432461031	3286	Economy	6300.00
0005435142971	3286	Economy	6300.00
0005435856335	3286	Economy	6300.00
0005432461024	3286	Economy	6300.00
0005432461254	3286	Economy	6300.00
0005432461022	3286	Economy	6300.00
0005434266043	3286	Economy	6300.00
0005432461135	3286	Economy	6300.00
0005432461054	3286	Economy	6300.00
0005432461378	3286	Economy	6300.00
0005434266045	3286	Economy	6300.00
0005435860653	3286	Economy	6300.00
0005435860657	3286	Economy	6300.00
0005435856340	3286	Economy	6300.00
0005432461196	3286	Economy	6300.00
0005435142985	3286	Economy	6300.00
0005432461281	3286	Economy	6300.00
0005434266050	3286	Economy	6300.00
0005432461316	3286	Economy	6300.00
0005434266039	3286	Economy	6300.00
0005434150231	3286	Economy	6300.00
0005435860664	3286	Economy	6300.00
0005432461264	3286	Economy	6300.00
0005432461076	3286	Economy	6300.00
0005434182555	3286	Economy	6300.00
0005432461155	3286	Economy	6300.00
0005435999872	3286	Economy	6900.00
0005432461081	3286	Economy	6900.00
0005432461282	3286	Economy	6900.00
0005432182370	3286	Economy	6300.00
0005435860673	3286	Economy	6300.00
0005435860658	3286	Economy	6300.00
0005432461041	3286	Economy	6900.00
0005433806410	3286	Economy	6300.00
0005435860645	3286	Economy	6300.00
0005434266046	3286	Economy	6300.00
0005434150230	3286	Economy	6300.00
0005432461379	3286	Economy	6300.00
0005435856339	3286	Economy	6300.00
0005435860662	3286	Economy	6300.00
0005435856341	3286	Economy	6300.00
0005434150234	3286	Economy	6300.00
0005432461120	3286	Economy	6300.00
0005432461096	3286	Economy	6300.00
0005432461049	3286	Economy	6300.00
0005432461050	3286	Economy	6300.00
0005435142982	3286	Economy	6300.00
0005432461053	3286	Economy	6300.00
0005435860675	3286	Economy	6300.00
0005434266048	3286	Economy	6300.00
0005432461193	3286	Economy	6300.00
0005435856337	3286	Economy	6300.00
0005432461256	3286	Economy	6300.00
0005435856350	3286	Economy	6300.00
0005435142979	3286	Economy	6300.00
0005432460981	3286	Economy	6300.00
0005432461075	3286	Economy	6300.00
0005435860672	3286	Economy	6300.00
0005432461377	3286	Economy	6300.00
0005432461257	3286	Economy	6300.00
0005435858700	3286	Economy	6300.00
0005432461244	3286	Economy	6300.00
0005435860650	3286	Economy	6300.00
0005432461023	3286	Economy	6300.00
0005434266049	3286	Economy	6300.00
0005432461267	3286	Economy	6300.00
0005435860644	3286	Economy	6300.00
0005434266042	3286	Economy	6300.00
0005435860655	3286	Economy	6300.00
0005435860670	3286	Economy	6300.00
0005432461239	3286	Economy	6300.00
0005434326053	3286	Economy	6300.00
0005432460923	3286	Economy	6300.00
0005435860656	3286	Economy	6300.00
0005432461253	3286	Economy	6300.00
0005432461119	3286	Economy	6300.00
0005432461226	3286	Economy	6300.00
0005432461134	3286	Economy	6300.00
0005434150232	3286	Economy	6300.00
0005435939979	3287	Business	18800.00
0005435886392	3287	Business	18800.00
0005435886397	3287	Business	18800.00
0005435886506	3287	Business	18800.00
0005435886532	3287	Business	18800.00
0005435886554	3287	Business	18800.00
0005435886709	3287	Business	18800.00
0005435886687	3287	Business	18800.00
0005435886416	3287	Business	18800.00
0005435886572	3287	Business	18800.00
0005435886675	3287	Business	18800.00
0005435886643	3287	Business	18800.00
0005435886644	3287	Business	18800.00
0005435886509	3287	Economy	6300.00
0005435886273	3287	Economy	6300.00
0005435886406	3287	Economy	6300.00
0005435886483	3287	Economy	6300.00
0005435886516	3287	Economy	6300.00
0005435886683	3287	Economy	6300.00
0005435886515	3287	Economy	6300.00
0005435886393	3287	Economy	6300.00
0005435886389	3287	Economy	6300.00
0005435886461	3287	Economy	6300.00
0005435886567	3287	Economy	6300.00
0005435886514	3287	Economy	6300.00
0005435886704	3287	Economy	6300.00
0005435886566	3287	Economy	6300.00
0005435886575	3287	Economy	6300.00
0005435886573	3287	Economy	6300.00
0005435886686	3287	Economy	6300.00
0005435886662	3287	Economy	6300.00
0005435886407	3287	Economy	6300.00
0005435886377	3287	Economy	6300.00
0005435886641	3287	Economy	6300.00
0005435939980	3287	Economy	6300.00
0005435886498	3287	Economy	6300.00
0005435886534	3287	Economy	6300.00
0005435886378	3287	Economy	6300.00
0005435886443	3287	Economy	6300.00
0005435886619	3287	Economy	6300.00
0005435886597	3287	Economy	6900.00
0005435886688	3287	Economy	6900.00
0005435886622	3287	Economy	6900.00
0005435886500	3287	Economy	6300.00
0005435886462	3287	Economy	6300.00
0005435886735	3287	Economy	6300.00
0005435886471	3287	Economy	6300.00
0005435886444	3287	Economy	6300.00
0005435886661	3287	Economy	6300.00
0005435886458	3287	Economy	6300.00
0005435886642	3287	Economy	6300.00
0005435886501	3287	Economy	6300.00
0005435886338	3287	Economy	6300.00
0005435886615	3287	Economy	6300.00
0005435886424	3287	Economy	6300.00
0005435886464	3287	Economy	6300.00
0005435886507	3287	Economy	6300.00
0005435886602	3287	Economy	6300.00
0005435886307	3287	Economy	6300.00
0005435886676	3287	Economy	6300.00
0005435886304	3287	Economy	6300.00
0005435886513	3287	Economy	6300.00
0005435886499	3287	Economy	6300.00
0005435886753	3287	Economy	6300.00
0005435886734	3287	Economy	6300.00
0005435886531	3287	Economy	6300.00
0005435886605	3287	Economy	6300.00
0005435886601	3287	Economy	6300.00
0005435886463	3287	Economy	6300.00
0005435886604	3287	Economy	6300.00
0005435886274	3287	Economy	6300.00
0005435886508	3287	Economy	6300.00
0005433507576	8318	Business	18800.00
0005435933567	8318	Economy	6300.00
0005433507645	8318	Economy	6300.00
0005435886870	8318	Economy	6300.00
0005433507677	8318	Economy	6300.00
0005435886869	8318	Economy	6300.00
0005432461439	8318	Economy	6900.00
0005433507610	8318	Economy	6300.00
0005433507620	8318	Economy	6300.00
0005432461438	8318	Economy	6300.00
0005433507662	8318	Economy	6300.00
0005432461441	8318	Economy	6300.00
0005432461437	8318	Economy	6300.00
0005433507599	8318	Economy	6300.00
0005433507668	8318	Economy	6300.00
0005433507586	8318	Economy	6300.00
0005432461440	8318	Economy	6300.00
0005433507669	8318	Economy	6300.00
0005433634672	8313	Business	18800.00
0005433806254	8313	Business	18800.00
0005433634539	8313	Business	18800.00
0005433634664	8313	Business	18800.00
0005433634671	8313	Business	18800.00
0005433634499	8313	Business	18800.00
0005433634560	8313	Business	18800.00
0005433806264	8313	Business	18800.00
0005433634498	8313	Business	18800.00
0005433634679	8313	Business	18800.00
0005433806243	8313	Business	18800.00
0005433634706	8313	Economy	6900.00
0005433806109	8313	Economy	6900.00
0005433634663	8313	Economy	6900.00
0005433634680	8313	Economy	6900.00
0005434143766	8313	Economy	6900.00
0005433634655	8313	Economy	6300.00
0005433806303	8313	Economy	6300.00
0005435860733	8313	Economy	6300.00
0005433806110	8313	Economy	6300.00
0005433634606	8313	Economy	6300.00
0005434143764	8313	Economy	6300.00
0005434271359	8313	Economy	6300.00
0005433634696	8313	Economy	6300.00
0005434271358	8313	Economy	6300.00
0005433634654	8313	Economy	6300.00
0005433806203	8313	Economy	6300.00
0005433634474	8313	Economy	6300.00
0005433634594	8313	Economy	6300.00
0005433806128	8313	Economy	6300.00
0005433806091	8313	Economy	6300.00
0005434143775	8313	Economy	6300.00
0005433806186	8313	Economy	6300.00
0005433634688	8313	Economy	6300.00
0005433634460	8313	Economy	6300.00
0005433806167	8313	Economy	6300.00
0005434143774	8313	Economy	6300.00
0005433634708	8313	Economy	6300.00
0005434143788	8313	Economy	6300.00
0005433634528	8313	Economy	6300.00
0005433634676	8313	Economy	6300.00
0005433806226	8313	Economy	6300.00
0005433806275	8313	Economy	6300.00
0005434271369	8313	Economy	6300.00
0005433806098	8313	Economy	6300.00
0005435858746	8313	Economy	6300.00
0005433806170	8313	Economy	6300.00
0005433634595	8313	Economy	6900.00
0005433806265	8313	Economy	6900.00
0005435858747	8313	Economy	6900.00
0005433634578	8313	Economy	6300.00
0005433634505	8313	Economy	6300.00
0005433634596	8313	Economy	6900.00
0005434143765	8313	Economy	6300.00
0005433806092	8313	Economy	6300.00
0005433806284	8313	Economy	6300.00
0005433634406	8313	Economy	6300.00
0005433806187	8313	Economy	6300.00
0005433806253	8313	Economy	6300.00
0005433634660	8313	Economy	6300.00
0005433634629	8313	Economy	6300.00
0005433634707	8313	Economy	6300.00
0005433634628	8313	Economy	6300.00
0005435854087	8313	Economy	6300.00
0005433806129	8313	Economy	6300.00
0005433634727	8313	Economy	6300.00
0005434143817	8313	Economy	6300.00
0005433806376	8313	Economy	6300.00
0005433806202	8313	Economy	6300.00
0005433806266	8313	Economy	6300.00
0005433634697	8313	Economy	6300.00
0005434143796	8313	Economy	6300.00
0005433806125	8313	Economy	6300.00
0005433806320	8313	Economy	6300.00
0005433806242	8313	Economy	6300.00
0005434143784	8313	Economy	6300.00
0005433634405	8313	Economy	6300.00
0005434271361	8313	Economy	6300.00
0005433634689	8313	Economy	6300.00
0005433806185	8313	Economy	6300.00
0005433806263	8313	Economy	6300.00
0005434271360	8313	Economy	6300.00
0005433806097	8313	Economy	6300.00
0005433806184	8313	Economy	6300.00
0005433634575	8313	Economy	6300.00
0005433634677	8313	Economy	6300.00
0005433806285	8313	Economy	6300.00
0005433806217	8313	Economy	6300.00
0005434150151	8311	Business	18800.00
0005434150146	8311	Business	18800.00
0005434150144	8311	Economy	6300.00
0005434150161	8311	Economy	6300.00
0005434150178	8311	Economy	6300.00
0005434150169	8311	Economy	6300.00
0005434150150	8311	Economy	6300.00
0005434183621	8311	Economy	6300.00
0005434150142	8311	Economy	6300.00
0005434150160	8311	Economy	6300.00
0005434150152	8311	Economy	6300.00
0005432384341	4680	Business	9900.00
0005433722511	4680	Business	9900.00
0005433453820	4680	Economy	3600.00
0005432384342	4680	Economy	3300.00
0005433722510	4680	Economy	3300.00
0005432384340	4680	Economy	3300.00
0005435477027	4680	Economy	3300.00
0005432728312	4680	Economy	3300.00
0005435477026	4680	Economy	3300.00
0005433195015	4680	Economy	3300.00
0005435477028	4680	Economy	3300.00
0005435477031	4680	Economy	3300.00
0005435477030	4680	Economy	3300.00
0005435477029	4680	Economy	3300.00
0005433722512	4680	Economy	3300.00
0005433451668	30117	Business	9900.00
0005433722365	30117	Business	9900.00
0005433722351	30117	Business	9900.00
0005433194950	30117	Business	9900.00
0005432728258	30117	Business	9900.00
0005432384134	30117	Business	9900.00
0005432384015	30117	Business	9900.00
0005433722367	30117	Economy	3300.00
0005432728232	30117	Economy	3300.00
0005432384047	30117	Economy	3300.00
0005433722354	30117	Economy	3300.00
0005433722375	30117	Economy	3300.00
0005432384038	30117	Economy	3600.00
0005432384095	30117	Economy	3600.00
0005432384083	30117	Economy	3600.00
0005432384002	30117	Economy	3300.00
0005432383951	30117	Economy	3300.00
0005433451667	30117	Economy	3300.00
0005433451666	30117	Economy	3300.00
0005433722356	30117	Economy	3300.00
0005432384001	30117	Economy	3300.00
0005432383878	30117	Economy	3300.00
0005433194918	30117	Economy	3300.00
0005433722362	30117	Economy	3300.00
0005433722368	30117	Economy	3300.00
0005432384037	30117	Economy	3300.00
0005432728249	30117	Economy	3300.00
0005432383934	30117	Economy	3300.00
0005432383946	30117	Economy	3300.00
0005432728260	30117	Economy	3300.00
0005432383969	30117	Economy	3300.00
0005432728256	30117	Economy	3300.00
0005432728251	30117	Economy	3300.00
0005432384073	30117	Economy	3300.00
0005432384053	30117	Economy	3300.00
0005432384118	30117	Economy	3300.00
0005432728236	30117	Economy	3300.00
0005432728292	30117	Economy	3300.00
0005432383842	30117	Economy	3300.00
0005433194959	30117	Economy	3300.00
0005432384103	30117	Economy	3300.00
0005433194921	30117	Economy	3300.00
0005432728231	30117	Economy	3300.00
0005432728250	30117	Economy	3300.00
0005432728226	30117	Economy	3300.00
0005433722369	30117	Economy	3300.00
0005432728283	30117	Economy	3300.00
0005432728252	30117	Economy	3300.00
0005433722361	30117	Economy	3300.00
0005433722376	30117	Economy	3300.00
0005432384133	30117	Economy	3300.00
0005432384096	30117	Economy	3300.00
0005432728284	30117	Economy	3300.00
0005432384027	30117	Economy	3300.00
0005433722366	30117	Economy	3300.00
0005432728235	30117	Economy	3300.00
0005432384104	30117	Economy	3300.00
0005432383870	30117	Economy	3300.00
0005432383994	30117	Economy	3300.00
0005432728257	30117	Economy	3300.00
0005432383897	30117	Economy	3300.00
0005432383935	30117	Economy	3300.00
0005432728242	30117	Economy	3300.00
0005432384014	30117	Economy	3300.00
0005432728259	30117	Economy	3300.00
0005432384080	30117	Economy	3300.00
0005435541648	1751	Business	57200.00
0005432925141	1751	Business	57200.00
0005435541652	1751	Business	57200.00
0005435541650	1751	Economy	19100.00
0005435541647	1751	Economy	19100.00
0005435541649	1751	Economy	19100.00
0005432925167	1751	Economy	19100.00
0005433517168	1751	Economy	19100.00
0005432925155	1751	Economy	19100.00
0005432925151	1751	Economy	19100.00
0005435541651	1751	Economy	19100.00
0005433517167	1751	Economy	19100.00
0005433517166	1751	Economy	19100.00
0005433517107	21987	Business	57200.00
0005435541505	21987	Business	57200.00
0005433517143	21987	Business	57200.00
0005435518366	21987	Business	57200.00
0005435518348	21987	Business	57200.00
0005433517081	21987	Business	57200.00
0005435541536	21987	Business	57200.00
0005435518410	21987	Economy	19100.00
0005433517140	21987	Economy	19100.00
0005435518363	21987	Economy	19100.00
0005435518303	21987	Economy	21000.00
0005435541498	21987	Economy	21000.00
0005435541497	21987	Economy	21000.00
0005435518352	21987	Economy	19100.00
0005435541538	21987	Economy	19100.00
0005435541548	21987	Economy	19100.00
0005435541549	21987	Economy	19100.00
0005435541558	21987	Economy	19100.00
0005435518302	21987	Economy	19100.00
0005435541565	21987	Economy	19100.00
0005435518381	21987	Economy	19100.00
0005435541445	21987	Economy	19100.00
0005435518409	21987	Economy	19100.00
0005435541547	21987	Economy	19100.00
0005435541537	21987	Economy	19100.00
0005433517114	21987	Economy	19100.00
0005435541581	21987	Economy	19100.00
0005433517137	21987	Economy	19100.00
0005435541566	21987	Economy	19100.00
0005433517139	21987	Economy	19100.00
0005433517082	21987	Economy	19100.00
0005435518380	21987	Economy	19100.00
0005433517144	21987	Economy	19100.00
0005435541444	21987	Economy	19100.00
0005435518337	21987	Economy	19100.00
0005435518326	21987	Economy	19100.00
0005435541509	21987	Economy	19100.00
0005435518411	21987	Economy	19100.00
0005435518353	21987	Economy	19100.00
0005433517111	21987	Economy	19100.00
0005435541541	21987	Economy	19100.00
0005435541516	21987	Economy	19100.00
0005435518264	21987	Economy	19100.00
0005433517138	21987	Economy	19100.00
0005435541562	21987	Economy	19100.00
0005435518286	21987	Economy	19100.00
0005435541526	21987	Economy	19100.00
0005433517145	21987	Economy	19100.00
0005433517100	21987	Economy	19100.00
0005433517110	21987	Economy	19100.00
0005435541551	21987	Economy	19100.00
0005435518373	21987	Economy	19100.00
0005433517099	21987	Economy	19100.00
0005435541486	21987	Economy	19100.00
0005435518265	21987	Economy	19100.00
0005435253148	7353	Business	18500.00
0005434459421	7353	Business	18500.00
0005435253211	7353	Business	18500.00
0005435491496	7353	Business	18500.00
0005435253176	7353	Business	18500.00
0005435253101	7353	Economy	6200.00
0005435253150	7353	Economy	6200.00
0005435253151	7353	Economy	6200.00
0005432839939	7353	Economy	6200.00
0005432839938	7353	Economy	6800.00
0005432839940	7353	Economy	6800.00
0005435253039	7353	Economy	6200.00
0005435253134	7353	Economy	6200.00
0005434459422	7353	Economy	6200.00
0005435253041	7353	Economy	6200.00
0005435253175	7353	Economy	6200.00
0005435253105	7353	Economy	6200.00
0005435253122	7353	Economy	6200.00
0005435253149	7353	Economy	6200.00
0005432839937	7353	Economy	6200.00
0005435253040	7353	Economy	6200.00
0005435253141	7353	Economy	6200.00
0005435491498	7353	Economy	6200.00
0005434665015	7353	Economy	6200.00
0005435253123	7353	Economy	6200.00
0005432839747	28947	Business	18500.00
0005432839789	28947	Business	18500.00
0005432839791	28947	Business	18500.00
0005434459243	28947	Business	18500.00
0005434459351	28947	Business	18500.00
0005434459349	28947	Economy	6200.00
0005432839736	28947	Economy	6200.00
0005434459327	28947	Economy	6200.00
0005434459263	28947	Economy	6200.00
0005434459330	28947	Economy	6200.00
0005434459380	28947	Economy	6200.00
0005432839865	28947	Economy	6200.00
0005432839790	28947	Economy	6200.00
0005432839718	28947	Economy	6200.00
0005432839729	28947	Economy	6800.00
0005432839920	28947	Economy	6800.00
0005432839792	28947	Economy	6800.00
0005434459245	28947	Economy	6800.00
0005432839832	28947	Economy	6200.00
0005434459354	28947	Economy	6200.00
0005432839782	28947	Economy	6200.00
0005434459241	28947	Economy	6200.00
0005432839873	28947	Economy	6200.00
0005434459362	28947	Economy	6200.00
0005432839748	28947	Economy	6200.00
0005434459244	28947	Economy	6200.00
0005434459353	28947	Economy	6200.00
0005434459284	28947	Economy	6200.00
0005432839735	28947	Economy	6200.00
0005434459361	28947	Economy	6200.00
0005432839787	28947	Economy	6200.00
0005432839786	28947	Economy	6200.00
0005432823498	28947	Economy	6200.00
0005432839798	28947	Economy	6200.00
0005434459368	28947	Economy	6200.00
0005434459331	28947	Economy	6200.00
0005434459364	28947	Economy	6200.00
0005434459310	28947	Economy	6200.00
0005432839788	28947	Economy	6200.00
0005434459363	28947	Economy	6200.00
0005434459268	28947	Economy	6200.00
0005434459202	28947	Economy	6200.00
0005432839876	28947	Economy	6200.00
0005432839678	28947	Economy	6200.00
0005432839794	28947	Economy	6200.00
0005432823504	28947	Economy	6200.00
0005434459337	28947	Economy	6200.00
0005434459334	28947	Economy	6200.00
0005432839923	28947	Economy	6200.00
0005432839796	28947	Economy	6200.00
0005432839730	28947	Economy	6200.00
0005432839762	28947	Economy	6200.00
0005434459326	28947	Economy	6200.00
0005434459304	28947	Economy	6200.00
0005434459287	28947	Economy	6200.00
0005432839888	28947	Economy	6200.00
0005434459322	28947	Economy	6200.00
0005432839728	28947	Economy	6200.00
0005432839872	28947	Economy	6200.00
0005435999872	8777	Business	145300.00
0005434276183	8777	Economy	48400.00
0005434276175	8777	Economy	48400.00
0005434276181	8777	Economy	48400.00
0005434276190	8777	Economy	48400.00
0005435990834	8777	Economy	48400.00
0005435987065	8777	Economy	48400.00
0005435987066	8777	Economy	48400.00
0005435999873	8777	Economy	48400.00
0005434276174	8777	Economy	48400.00
0005433435532	15730	Business	145300.00
0005435990799	15730	Business	145300.00
0005433435531	15730	Economy	48400.00
0005435990769	15730	Economy	48400.00
0005435990774	15730	Economy	48400.00
0005435990808	15730	Economy	48400.00
0005433476941	20638	Economy	14500.00
0005433476942	20638	Economy	14500.00
0005433476943	20638	Economy	14500.00
0005433476944	20638	Economy	14500.00
0005433476955	30842	Economy	14500.00
0005433476956	30842	Economy	14500.00
0005432427195	30842	Economy	14500.00
0005432427178	30842	Economy	14500.00
0005435177788	6380	Business	36600.00
0005435177727	6380	Business	36600.00
0005434149998	6380	Business	36600.00
0005435177779	6380	Business	36600.00
0005434150032	6380	Economy	12200.00
0005434150036	6380	Economy	12200.00
0005435490327	6380	Economy	12200.00
0005432361772	6380	Economy	12200.00
0005434150038	6380	Economy	12200.00
0005435723100	6380	Economy	12200.00
0005435490328	6380	Economy	12200.00
0005435490319	6380	Economy	12200.00
0005435177797	6380	Economy	12200.00
0005435177754	6380	Economy	12200.00
0005435177733	6380	Economy	12200.00
0005435177760	6380	Economy	12200.00
0005435723095	6380	Economy	12200.00
0005435177717	6380	Economy	12200.00
0005435177696	6380	Economy	12200.00
0005434150037	6380	Economy	13400.00
0005432361771	6380	Economy	13400.00
0005432361773	6380	Economy	12200.00
0005435490308	6380	Economy	12200.00
0005435177827	6380	Economy	12200.00
0005435177759	6380	Economy	12200.00
0005435177819	6380	Economy	12200.00
0005435177828	6380	Economy	12200.00
0005435177721	6380	Economy	12200.00
0005435177808	6380	Economy	12200.00
0005435723099	6380	Economy	12200.00
0005435177820	6380	Economy	12200.00
0005435177747	6380	Economy	12200.00
0005434150024	6380	Economy	12200.00
0005432361774	6380	Economy	12200.00
0005435490307	6380	Economy	12200.00
0005434150035	6380	Economy	12200.00
0005435177774	6380	Economy	12200.00
0005435177718	6380	Economy	12200.00
0005435177803	6380	Economy	12200.00
0005432361722	21001	Business	36600.00
0005432361521	21001	Economy	12200.00
0005432361455	21001	Economy	12200.00
0005432361637	21001	Economy	12200.00
0005432361558	21001	Economy	12200.00
0005435177876	21001	Economy	12200.00
0005432361678	21001	Economy	12200.00
0005432361510	21001	Economy	12200.00
0005432361482	21001	Economy	12200.00
0005432361599	21001	Economy	12200.00
0005432361640	21001	Economy	12200.00
0005432361556	21001	Economy	12200.00
0005432361538	21001	Economy	12200.00
0005432361509	21001	Economy	12200.00
0005432361547	21001	Economy	12200.00
0005432361378	21001	Economy	12200.00
0005432336322	21001	Economy	12200.00
0005432361663	21001	Economy	12200.00
0005432361546	21001	Economy	13400.00
0005432336306	21001	Economy	13400.00
0005432361647	21001	Economy	13400.00
0005432361662	21001	Economy	13400.00
0005432361438	21001	Economy	12200.00
0005432336359	21001	Economy	12200.00
0005432361525	21001	Economy	12200.00
0005432361555	21001	Economy	12200.00
0005432363486	21001	Economy	12200.00
0005432361557	21001	Economy	12200.00
0005432361589	21001	Economy	12200.00
0005432361398	21001	Economy	12200.00
0005432361677	21001	Economy	12200.00
0005432361377	21001	Economy	12200.00
0005432361481	21001	Economy	12200.00
0005432361676	21001	Economy	12200.00
0005432361590	21001	Economy	12200.00
0005435177880	21001	Economy	12200.00
0005432361619	21001	Economy	12200.00
0005432361605	21001	Economy	12200.00
0005432336323	21001	Economy	12200.00
0005435177879	21001	Economy	12200.00
0005432361588	21001	Economy	12200.00
0005432361618	21001	Economy	12200.00
0005432361672	21001	Economy	12200.00
0005435177877	21001	Economy	12200.00
0005432361491	21001	Economy	12200.00
0005432361432	21001	Economy	12200.00
0005432361539	21001	Economy	12200.00
0005432361397	21001	Economy	12200.00
0005432336320	21001	Economy	12200.00
0005432361504	21001	Economy	12200.00
0005435177878	21001	Economy	12200.00
0005432363492	21001	Economy	12200.00
0005432361501	21001	Economy	12200.00
0005432361620	21001	Economy	12200.00
0005432361502	21001	Economy	12200.00
0005432361607	21001	Economy	12200.00
0005434448406	17691	Economy	3400.00
0005434459305	17691	Economy	3400.00
0005434459355	17691	Economy	3100.00
0005434459357	17691	Economy	3100.00
0005434459346	17691	Economy	3100.00
0005434459381	17691	Economy	3100.00
0005434448407	17691	Economy	3100.00
0005434459370	17691	Economy	3100.00
0005434459371	17691	Economy	3100.00
0005434459237	17691	Economy	3100.00
0005434459324	17691	Economy	3100.00
0005434459369	17691	Economy	3100.00
0005434459394	17691	Economy	3100.00
0005434448408	17691	Economy	3100.00
0005434459271	17691	Economy	3100.00
0005434459282	17691	Economy	3100.00
0005434459270	17691	Economy	3100.00
0005434459281	17691	Economy	3100.00
0005434459345	17691	Economy	3100.00
0005434459356	17691	Economy	3100.00
0005434448402	17691	Economy	3100.00
0005434461703	17691	Economy	3100.00
0005434459397	17691	Economy	3100.00
0005434459339	17691	Economy	3100.00
0005434459236	17691	Economy	3100.00
0005434459226	17691	Economy	3100.00
0005434459285	17691	Economy	3100.00
0005434461702	17691	Economy	3100.00
0005434463996	29111	Economy	3100.00
0005434186265	29111	Economy	3100.00
0005434459422	29111	Economy	3100.00
0005434459421	29111	Economy	3100.00
0005434186266	29111	Economy	3100.00
0005435218136	21425	Economy	6600.00
0005432605507	21425	Economy	6600.00
0005432605505	21425	Economy	6600.00
0005432605506	21425	Economy	6600.00
0005435218137	21425	Economy	6600.00
0005432605504	21425	Economy	6600.00
0005435220505	21425	Economy	6600.00
0005432605352	31664	Economy	7300.00
0005432605237	31664	Economy	7300.00
0005432605313	31664	Economy	7300.00
0005432605197	31664	Economy	7300.00
0005432605394	31664	Economy	6600.00
0005432605266	31664	Economy	6600.00
0005432605307	31664	Economy	6600.00
0005432605204	31664	Economy	6600.00
0005432605343	31664	Economy	6600.00
0005432605276	31664	Economy	6600.00
0005432605397	31664	Economy	6600.00
0005432605198	31664	Economy	6600.00
0005432605202	31664	Economy	6600.00
0005432605189	31664	Economy	6600.00
0005432605404	31664	Economy	6600.00
0005432605254	31664	Economy	6600.00
0005432605387	31664	Economy	6600.00
0005432605374	31664	Economy	6600.00
0005432605403	31664	Economy	6600.00
0005432605209	31664	Economy	6600.00
0005432605182	31664	Economy	6600.00
0005432605265	31664	Economy	6600.00
0005432605429	31664	Economy	6600.00
0005432605183	31664	Economy	6600.00
0005432605312	31664	Economy	6600.00
0005432605236	31664	Economy	6600.00
0005432605309	31664	Economy	6600.00
0005432605310	31664	Economy	6600.00
0005432605330	31664	Economy	6600.00
0005432605267	31664	Economy	6600.00
0005432605275	31664	Economy	6600.00
0005432605181	31664	Economy	6600.00
0005432605331	31664	Economy	6600.00
0005432605351	31664	Economy	6600.00
0005432605210	31664	Economy	6600.00
0005432605395	31664	Economy	6600.00
0005435154708	12295	Economy	19500.00
0005433293386	12295	Economy	19500.00
0005433293403	12295	Economy	19500.00
0005433293414	12295	Economy	17800.00
0005435154705	12295	Economy	17800.00
0005433293415	12295	Economy	17800.00
0005433293399	12295	Economy	17800.00
0005433293368	12295	Economy	17800.00
0005433293417	12295	Economy	17800.00
0005435154704	12295	Economy	17800.00
0005433293379	12295	Economy	17800.00
0005435154706	12295	Economy	17800.00
0005433293385	12295	Economy	17800.00
0005433293398	12295	Economy	17800.00
0005433293380	12295	Economy	17800.00
0005433293381	12295	Economy	17800.00
0005435154707	12295	Economy	17800.00
0005433293416	12295	Economy	17800.00
0005433293389	12295	Economy	17800.00
0005433293390	12295	Economy	17800.00
0005434606918	18902	Economy	6600.00
0005434606900	18902	Economy	6600.00
0005434606901	18902	Economy	6600.00
0005434606903	18902	Economy	6600.00
0005435904916	18902	Economy	6600.00
0005434606919	18902	Economy	6600.00
0005434606939	22296	Economy	6600.00
0005434606938	22296	Economy	6600.00
0005432891566	394	Business	44500.00
0005433875420	394	Business	44500.00
0005434151797	394	Business	44500.00
0005433293406	394	Business	44500.00
0005434152861	394	Business	44500.00
0005433293393	394	Business	44500.00
0005432891472	394	Economy	14800.00
0005432891548	394	Economy	14800.00
0005433293392	394	Economy	16300.00
0005434151800	394	Economy	14800.00
0005434151801	394	Economy	14800.00
0005432891576	394	Economy	14800.00
0005433293425	394	Economy	14800.00
0005432891434	394	Economy	14800.00
0005433875419	394	Economy	14800.00
0005432891489	394	Economy	14800.00
0005432891474	394	Economy	14800.00
0005434151798	394	Economy	14800.00
0005432891517	394	Economy	14800.00
0005432891483	394	Economy	14800.00
0005432749852	394	Economy	14800.00
0005432891473	394	Economy	14800.00
0005433293402	394	Economy	14800.00
0005432891450	394	Economy	14800.00
0005432891495	394	Economy	14800.00
0005432891518	394	Economy	14800.00
0005433293429	394	Economy	14800.00
0005432748475	12047	Business	44500.00
0005432753383	12047	Business	44500.00
0005432748569	12047	Business	44500.00
0005435154638	12047	Business	44500.00
0005435154658	12047	Business	44500.00
0005435154654	12047	Business	44500.00
0005435154646	12047	Business	44500.00
0005432748559	12047	Business	44500.00
0005432748592	12047	Business	44500.00
0005432748500	12047	Business	44500.00
0005432748499	12047	Economy	14800.00
0005432748537	12047	Economy	14800.00
0005432748609	12047	Economy	14800.00
0005432748299	12047	Economy	14800.00
0005432748599	12047	Economy	14800.00
0005432748558	12047	Economy	14800.00
0005432748541	12047	Economy	16300.00
0005432748562	12047	Economy	16300.00
0005435154649	12047	Economy	14800.00
0005435154652	12047	Economy	14800.00
0005435154641	12047	Economy	14800.00
0005432748419	12047	Economy	14800.00
0005432748496	12047	Economy	14800.00
0005435154629	12047	Economy	14800.00
0005433293439	12047	Economy	14800.00
0005435154640	12047	Economy	14800.00
0005432748484	12047	Economy	14800.00
0005432748518	12047	Economy	14800.00
0005433293442	12047	Economy	14800.00
0005432748509	12047	Economy	14800.00
0005433293440	12047	Economy	14800.00
0005433293441	12047	Economy	14800.00
0005432748447	12047	Economy	14800.00
0005435154663	12047	Economy	14800.00
0005432748585	12047	Economy	14800.00
0005432748418	12047	Economy	14800.00
0005432748547	12047	Economy	14800.00
0005432748546	12047	Economy	14800.00
0005432748448	12047	Economy	14800.00
0005435154659	12047	Economy	14800.00
0005432748473	12047	Economy	14800.00
0005435154666	12047	Economy	14800.00
0005432748593	12047	Economy	14800.00
0005432748565	12047	Economy	14800.00
0005435154637	12047	Economy	14800.00
0005432748498	12047	Economy	14800.00
0005432748566	12047	Economy	14800.00
0005434152874	12047	Economy	14800.00
0005435154655	12047	Economy	14800.00
0005435154642	12047	Economy	14800.00
0005435154667	12047	Economy	14800.00
0005435154648	12047	Economy	14800.00
0005432748300	12047	Economy	14800.00
0005432756917	12047	Economy	14800.00
0005432748532	12047	Economy	14800.00
0005432756922	12047	Economy	14800.00
0005433293443	12047	Economy	14800.00
0005432748545	12047	Economy	14800.00
0005432928111	18970	Economy	25700.00
0005433531390	32479	Economy	25700.00
0005433527339	32479	Economy	25700.00
0005433525295	32479	Economy	25700.00
0005433531391	32479	Economy	25700.00
0005433525308	32479	Economy	25700.00
0005433531383	32479	Economy	25700.00
0005433525271	32479	Economy	25700.00
0005433525342	32479	Economy	25700.00
0005433525306	32479	Economy	25700.00
0005433525307	32479	Economy	25700.00
0005433531395	32479	Economy	25700.00
0005433531403	32479	Economy	25700.00
0005433531382	32479	Economy	25700.00
0005433525270	32479	Economy	25700.00
0005433525294	32479	Economy	25700.00
0005433531396	32479	Economy	25700.00
0005433531397	32479	Economy	25700.00
0005433525317	32479	Economy	25700.00
0005433531398	32479	Economy	25700.00
0005435375059	5269	Business	84000.00
0005435374763	5269	Business	84000.00
0005435374771	5269	Business	84000.00
0005435375056	5269	Business	84000.00
0005435374837	5269	Business	84000.00
0005435374616	5269	Business	84000.00
0005435374710	5269	Comfort	47600.00
0005435374775	5269	Comfort	47600.00
0005435374966	5269	Comfort	47600.00
0005435375030	5269	Comfort	47600.00
0005435179714	5269	Comfort	47600.00
0005435315046	5269	Comfort	47600.00
0005435374706	5269	Comfort	47600.00
0005435375046	5269	Comfort	47600.00
0005435735264	5269	Comfort	47600.00
0005435315037	5269	Comfort	47600.00
0005434827294	5269	Comfort	47600.00
0005435299891	5269	Comfort	47600.00
0005435735259	5269	Comfort	47600.00
0005435375055	5269	Comfort	47600.00
0005435375072	5269	Economy	28000.00
0005435179017	5269	Economy	28000.00
0005435374985	5269	Economy	28000.00
0005435374984	5269	Economy	28000.00
0005435374819	5269	Economy	28000.00
0005435374564	5269	Economy	28000.00
0005435179018	5269	Economy	28000.00
0005435315021	5269	Economy	28000.00
0005435374762	5269	Economy	28000.00
0005435374774	5269	Economy	28000.00
0005435735247	5269	Economy	28000.00
0005432823499	5269	Economy	28000.00
0005435374776	5269	Economy	28000.00
0005435374797	5269	Economy	28000.00
0005435375053	5269	Economy	28000.00
0005435315047	5269	Economy	28000.00
0005435179708	5269	Economy	28000.00
0005435315019	5269	Economy	28000.00
0005432823491	5269	Economy	28000.00
0005435374725	5269	Economy	28000.00
0005435304258	5269	Economy	28000.00
0005435315076	5269	Economy	28000.00
0005435315051	5269	Economy	30800.00
0005435374659	5269	Economy	28000.00
0005435374867	5269	Economy	30800.00
0005435374683	5269	Economy	28000.00
0005435374947	5269	Economy	28000.00
0005434828774	5269	Economy	28000.00
0005435374658	5269	Economy	28000.00
0005435735244	5269	Economy	28000.00
0005435315050	5269	Economy	28000.00
0005435374684	5269	Economy	28000.00
0005435735246	5269	Economy	28000.00
0005435375057	5269	Economy	28000.00
0005435315056	5269	Economy	28000.00
0005435315108	5269	Economy	28000.00
0005435374874	5269	Economy	28000.00
0005432823495	5269	Economy	28000.00
0005435315005	5269	Economy	28000.00
0005432121755	5269	Economy	28000.00
0005435374962	5269	Economy	28000.00
0005435374773	5269	Economy	28000.00
0005435315045	5269	Economy	28000.00
0005435375031	5269	Economy	28000.00
0005435374993	5269	Economy	28000.00
0005435374782	5269	Economy	28000.00
0005435299888	5269	Economy	28000.00
0005435374903	5269	Economy	28000.00
0005435299890	5269	Economy	28000.00
0005435374724	5269	Economy	28000.00
0005434665026	5269	Economy	28000.00
0005432121754	5269	Economy	28000.00
0005434827292	5269	Economy	28000.00
0005435315048	5269	Economy	28000.00
0005435304249	5269	Economy	28000.00
0005435374726	5269	Economy	28000.00
0005435374765	5269	Economy	28000.00
0005435315038	5269	Economy	28000.00
0005435374998	5269	Economy	28000.00
0005435374705	5269	Economy	28000.00
0005435374938	5269	Economy	28000.00
0005435315023	5269	Economy	28000.00
0005435315107	5269	Economy	28000.00
0005435735265	5269	Economy	28000.00
0005435374784	5269	Economy	28000.00
0005435374680	5269	Economy	28000.00
0005435374845	5269	Economy	28000.00
0005435662001	5269	Economy	28000.00
0005434827295	5269	Economy	28000.00
0005435735257	5269	Economy	28000.00
0005435375029	5269	Economy	28000.00
0005435374997	5269	Economy	28000.00
0005435374909	5269	Economy	28000.00
0005435374942	5269	Economy	28000.00
0005434827293	5269	Economy	28000.00
0005434827296	5269	Economy	28000.00
0005435374990	5269	Economy	28000.00
0005435315036	5269	Economy	28000.00
0005435374657	5269	Economy	28000.00
0005435735235	5269	Economy	28000.00
0005435315035	5269	Economy	28000.00
0005435374760	5269	Economy	28000.00
0005432823500	5269	Economy	28000.00
0005434828775	5269	Economy	28000.00
0005435315073	5269	Economy	28000.00
0005435374606	5269	Economy	28000.00
0005435179709	5269	Economy	28000.00
0005435374679	5269	Economy	28000.00
0005435314993	5269	Economy	28000.00
0005435374781	5269	Economy	28000.00
0005435374848	5269	Economy	28000.00
0005435375052	5269	Economy	28000.00
0005435374948	5269	Economy	28000.00
0005435314994	5269	Economy	28000.00
0005434826516	9912	Business	84000.00
0005434826980	9912	Business	84000.00
0005434558444	9912	Business	84000.00
0005434826971	9912	Business	84000.00
0005434826919	9912	Business	84000.00
0005434826416	9912	Business	84000.00
0005434826670	9912	Business	84000.00
0005434558456	9912	Business	84000.00
0005434826813	9912	Business	84000.00
0005434826824	9912	Comfort	47600.00
0005434826477	9912	Business	84000.00
0005432400213	9912	Comfort	47600.00
0005434826413	9912	Comfort	47600.00
0005434826565	9912	Comfort	47600.00
0005434558436	9912	Comfort	47600.00
0005434826800	9912	Comfort	47600.00
0005432400217	9912	Comfort	47600.00
0005434826578	9912	Comfort	47600.00
0005434826874	9912	Comfort	47600.00
0005434826576	9912	Comfort	47600.00
0005434826665	9912	Comfort	47600.00
0005434826671	9912	Comfort	47600.00
0005432400218	9912	Comfort	47600.00
0005435150311	9912	Comfort	47600.00
0005434558455	9912	Comfort	47600.00
0005434826851	9912	Comfort	47600.00
0005432396336	9912	Comfort	47600.00
0005434826420	9912	Economy	28000.00
0005434826270	9912	Economy	28000.00
0005434826691	9912	Economy	28000.00
0005434826669	9912	Economy	28000.00
0005435662016	9912	Economy	28000.00
0005435150303	9912	Economy	28000.00
0005434826958	9912	Economy	28000.00
0005434826298	9912	Economy	28000.00
0005434826938	9912	Economy	28000.00
0005434826485	9912	Economy	28000.00
0005434826659	9912	Economy	28000.00
0005435150372	9912	Economy	28000.00
0005434826715	9912	Economy	28000.00
0005434826593	9912	Economy	28000.00
0005435150316	9912	Economy	28000.00
0005434826102	9912	Economy	28000.00
0005434826846	9912	Economy	28000.00
0005434826642	9912	Economy	28000.00
0005434826230	9912	Economy	28000.00
0005435299923	9912	Economy	28000.00
0005435150368	9912	Economy	28000.00
0005434826695	9912	Economy	28000.00
0005434826434	9912	Economy	28000.00
0005434827126	9912	Economy	28000.00
0005434826948	9912	Economy	28000.00
0005434826017	9912	Economy	28000.00
0005434826297	9912	Economy	28000.00
0005434826922	9912	Economy	28000.00
0005434558443	9912	Economy	28000.00
0005434831268	9912	Economy	28000.00
0005435315143	9912	Economy	28000.00
0005434826668	9912	Economy	28000.00
0005434826821	9912	Economy	28000.00
0005434826655	9912	Economy	28000.00
0005434826232	9912	Economy	28000.00
0005434826877	9912	Economy	30800.00
0005434827115	9912	Economy	30800.00
0005434826737	9912	Economy	28000.00
0005434826387	9912	Economy	30800.00
0005435150369	9912	Economy	28000.00
0005434826852	9912	Economy	28000.00
0005434827002	9912	Economy	28000.00
0005434826942	9912	Economy	28000.00
0005434826657	9912	Economy	28000.00
0005434826807	9912	Economy	28000.00
0005434826811	9912	Economy	28000.00
0005434826666	9912	Economy	28000.00
0005434558453	9912	Economy	28000.00
0005434826526	9912	Economy	28000.00
0005434826839	9912	Economy	28000.00
0005434826823	9912	Economy	28000.00
0005434826920	9912	Economy	28000.00
0005434826421	9912	Economy	28000.00
0005434826511	9912	Economy	28000.00
0005434827003	9912	Economy	28000.00
0005434826943	9912	Economy	28000.00
0005434826921	9912	Economy	28000.00
0005434558462	9912	Economy	28000.00
0005434826745	9912	Economy	28000.00
0005434826388	9912	Economy	28000.00
0005434826467	9912	Economy	28000.00
0005434826528	9912	Economy	28000.00
0005434826249	9912	Economy	28000.00
0005435150359	9912	Economy	28000.00
0005434826231	9912	Economy	28000.00
0005434826358	9912	Economy	28000.00
0005434827035	9912	Economy	28000.00
0005434826643	9912	Economy	28000.00
0005435150363	9912	Economy	28000.00
0005434826949	9912	Economy	28000.00
0005434827067	9912	Economy	28000.00
0005434826739	9912	Economy	28000.00
0005434826524	9912	Economy	28000.00
0005435150302	9912	Economy	28000.00
0005434826525	9912	Economy	28000.00
0005434665019	9912	Economy	28000.00
0005434826428	9912	Economy	28000.00
0005435150355	9912	Economy	28000.00
0005434558445	9912	Economy	28000.00
0005434826936	9912	Economy	28000.00
0005434826724	9912	Economy	30800.00
0005434826527	9912	Economy	30800.00
0005432396351	9912	Economy	28000.00
0005434826863	9912	Economy	28000.00
0005434826348	9912	Economy	28000.00
0005435150328	9912	Economy	28000.00
0005435386764	9912	Economy	28000.00
0005435150370	9912	Economy	28000.00
0005434826736	9912	Economy	28000.00
0005435375179	9912	Economy	28000.00
0005434558454	9912	Economy	28000.00
0005434826692	9912	Economy	28000.00
0005434827114	9912	Economy	28000.00
0005434826853	9912	Economy	28000.00
0005435150308	9912	Economy	28000.00
0005434826505	9912	Economy	28000.00
0005434826908	9912	Economy	28000.00
0005434831247	9912	Economy	28000.00
0005435386763	9912	Economy	28000.00
0005434665020	9912	Economy	28000.00
0005435150398	9912	Economy	28000.00
0005434826359	9912	Economy	28000.00
0005434826602	9912	Economy	28000.00
0005435150358	9912	Economy	28000.00
0005434826308	9912	Economy	28000.00
0005434826549	9912	Economy	28000.00
0005434826993	9912	Economy	28000.00
0005434826778	9912	Economy	28000.00
0005434826969	9912	Economy	28000.00
0005434826918	9912	Economy	28000.00
0005434826564	9912	Economy	28000.00
0005434826970	9912	Economy	28000.00
0005434826968	9912	Economy	28000.00
0005434826479	9912	Economy	28000.00
0005434665018	9912	Economy	28000.00
0005434826772	9912	Economy	28000.00
0005434826937	9912	Economy	28000.00
0005435375178	9912	Economy	28000.00
0005435315142	9912	Economy	28000.00
0005434826594	9912	Economy	28000.00
0005434826810	9912	Economy	28000.00
0005434827052	9912	Economy	28000.00
0005434826696	9912	Economy	28000.00
0005434826654	9912	Economy	28000.00
0005434827068	9912	Economy	28000.00
0005434826419	9912	Economy	28000.00
0005435662015	9912	Economy	28000.00
0005434826732	9912	Economy	28000.00
0005432396350	9912	Economy	28000.00
0005434826708	9912	Economy	28000.00
0005434826518	9912	Economy	28000.00
0005434826498	9912	Economy	28000.00
0005434826658	9912	Economy	28000.00
0005434826806	9912	Economy	28000.00
0005435083040	6969	Economy	7400.00
0005435083039	6969	Economy	7400.00
0005435790390	6969	Economy	7400.00
0005435082990	26024	Economy	8200.00
0005435790377	26024	Economy	7400.00
0005435082969	26024	Economy	7400.00
0005435790376	26024	Economy	7400.00
0005435790379	26024	Economy	7400.00
0005435790378	26024	Economy	7400.00
0005435790380	26024	Economy	7400.00
0005435082998	26024	Economy	7400.00
0005435082952	26024	Economy	7400.00
0005435082996	26024	Economy	7400.00
0005435082989	26024	Economy	7400.00
0005435790381	26024	Economy	7400.00
0005434757686	9532	Business	32800.00
0005434215740	9532	Business	32800.00
0005434215500	9532	Economy	10900.00
0005434215714	9532	Economy	10900.00
0005434215796	9532	Economy	10900.00
0005434215709	9532	Economy	10900.00
0005434215745	9532	Economy	10900.00
0005434215390	9532	Economy	10900.00
0005434215518	9532	Economy	10900.00
0005434757687	9532	Economy	10900.00
0005434215621	9532	Economy	12000.00
0005434215499	9532	Economy	12000.00
0005434215391	9532	Economy	10900.00
0005434215824	9532	Economy	10900.00
0005434757688	9532	Economy	10900.00
0005434215466	9532	Economy	10900.00
0005434215708	9532	Economy	10900.00
0005434215703	9532	Economy	10900.00
0005434215787	9532	Economy	10900.00
0005434215465	9532	Economy	10900.00
0005434215764	9532	Economy	10900.00
0005434215642	9532	Economy	10900.00
0005434215770	9532	Economy	10900.00
0005434215577	9532	Economy	10900.00
0005434757689	9532	Economy	10900.00
0005434215632	9532	Economy	10900.00
0005434215797	9532	Economy	10900.00
0005434215637	9532	Economy	10900.00
0005434215649	9532	Economy	10900.00
0005434215563	9532	Economy	10900.00
0005434215602	9532	Economy	10900.00
0005434757691	9532	Economy	10900.00
0005434215631	9532	Economy	10900.00
0005434215710	9532	Economy	10900.00
0005434215569	9532	Economy	10900.00
0005434757690	9532	Economy	10900.00
0005434215608	9532	Economy	10900.00
0005434215739	9532	Economy	10900.00
0005434215620	9532	Economy	10900.00
0005434215678	9532	Economy	10900.00
0005434215707	9532	Economy	10900.00
0005434215706	9532	Economy	10900.00
0005434215823	9532	Economy	10900.00
0005434215564	9532	Economy	10900.00
0005434215696	9532	Economy	10900.00
0005434215603	9532	Economy	10900.00
0005434215695	9532	Economy	10900.00
0005434215547	9532	Economy	10900.00
0005434215604	9532	Economy	10900.00
0005434215519	9532	Economy	10900.00
0005434215713	9532	Economy	10900.00
0005434215565	9532	Economy	10900.00
0005434215616	9532	Economy	10900.00
0005434757366	28597	Business	32800.00
0005434757560	28597	Business	32800.00
0005434757410	28597	Business	32800.00
0005434757346	28597	Business	32800.00
0005434757217	28597	Business	32800.00
0005434215896	28597	Business	32800.00
0005434757501	28597	Business	32800.00
0005434757223	28597	Business	32800.00
0005434757309	28597	Economy	10900.00
0005434757475	28597	Economy	10900.00
0005434757419	28597	Economy	10900.00
0005434757487	28597	Economy	10900.00
0005434757470	28597	Economy	10900.00
0005434757493	28597	Economy	10900.00
0005434757222	28597	Economy	10900.00
0005434215901	28597	Economy	12000.00
0005434757287	28597	Economy	10900.00
0005434757339	28597	Economy	10900.00
0005434757347	28597	Economy	10900.00
0005434757216	28597	Economy	10900.00
0005434757380	28597	Economy	10900.00
0005434757345	28597	Economy	10900.00
0005434757484	28597	Economy	10900.00
0005434757349	28597	Economy	10900.00
0005434757252	28597	Economy	10900.00
0005434757552	28597	Economy	10900.00
0005434757512	28597	Economy	10900.00
0005434757488	28597	Economy	10900.00
0005434215899	28597	Economy	10900.00
0005434215900	28597	Economy	10900.00
0005434757317	28597	Economy	10900.00
0005434757318	28597	Economy	10900.00
0005434757365	28597	Economy	10900.00
0005434757350	28597	Economy	10900.00
0005434757308	28597	Economy	10900.00
0005434757423	28597	Economy	10900.00
0005434215898	28597	Economy	10900.00
0005434757494	28597	Economy	10900.00
0005434757251	28597	Economy	10900.00
0005434757483	28597	Economy	10900.00
0005434757505	28597	Economy	10900.00
0005434757469	28597	Economy	10900.00
0005434757513	28597	Economy	10900.00
0005434757343	28597	Economy	10900.00
0005434757319	28597	Economy	10900.00
0005434757381	28597	Economy	10900.00
0005434757561	28597	Economy	10900.00
0005434757299	28597	Economy	10900.00
0005434215895	28597	Economy	10900.00
0005434757485	28597	Economy	10900.00
0005434757474	28597	Economy	10900.00
0005434757264	28597	Economy	10900.00
0005434757480	28597	Economy	10900.00
0005434757399	28597	Economy	10900.00
0005434215897	28597	Economy	10900.00
0005434757409	28597	Economy	10900.00
0005434757411	28597	Economy	10900.00
0005434757559	28597	Economy	10900.00
0005434757288	28597	Economy	10900.00
0005435100189	31813	Economy	8900.00
0005435100195	31813	Economy	8900.00
0005435100188	31813	Economy	8900.00
0005435100196	31813	Economy	8900.00
0005433202715	1998	Economy	20900.00
0005433202667	1998	Economy	20900.00
0005433202707	1998	Economy	19000.00
0005433202706	1998	Economy	19000.00
0005433202722	1998	Economy	19000.00
0005433202708	1998	Economy	19000.00
0005433202752	1998	Economy	19000.00
0005433202704	1998	Economy	19000.00
0005433202726	1998	Economy	19000.00
0005433202672	1998	Economy	19000.00
0005433202721	1998	Economy	19000.00
0005434640105	1998	Economy	19000.00
0005433202723	1998	Economy	19000.00
0005434639903	23298	Economy	20900.00
0005434640045	23298	Economy	20900.00
0005434639862	23298	Economy	20900.00
0005434640044	23298	Economy	20900.00
0005435948356	23298	Economy	19000.00
0005434640041	23298	Economy	19000.00
0005434639981	23298	Economy	19000.00
0005434639929	23298	Economy	19000.00
0005434639962	23298	Economy	19000.00
0005434639970	23298	Economy	19000.00
0005434639973	23298	Economy	19000.00
0005433202796	23298	Economy	19000.00
0005434640012	23298	Economy	19000.00
0005434639975	23298	Economy	19000.00
0005434639882	23298	Economy	19000.00
0005434639891	23298	Economy	19000.00
0005433202793	23298	Economy	19000.00
0005433202795	23298	Economy	19000.00
0005434639974	23298	Economy	19000.00
0005434640040	23298	Economy	19000.00
0005434639937	23298	Economy	19000.00
0005434639968	23298	Economy	19000.00
0005434639971	23298	Economy	19000.00
0005434640033	23298	Economy	19000.00
0005434639982	23298	Economy	19000.00
0005435948351	23298	Economy	19000.00
0005433202797	23298	Economy	19000.00
0005434639939	23298	Economy	19000.00
0005434639887	23298	Economy	19000.00
0005434639886	23298	Economy	19000.00
0005434639861	23298	Economy	19000.00
0005434640011	23298	Economy	19000.00
0005434639969	23298	Economy	19000.00
0005434639910	23298	Economy	19000.00
0005434639885	23298	Economy	19000.00
0005434639938	23298	Economy	19000.00
0005433202794	23298	Economy	19000.00
0005435327078	6045	Business	69700.00
0005435327077	6045	Business	69700.00
0005435327088	6045	Economy	23200.00
0005434601595	6045	Economy	23200.00
0005435327083	6045	Economy	23200.00
0005435327076	6045	Economy	23200.00
0005435327124	6045	Economy	23200.00
0005435327098	6045	Economy	23200.00
0005435327093	6045	Economy	23200.00
0005435327081	6045	Economy	23200.00
0005434601596	6045	Economy	23200.00
0005434601594	6045	Economy	23200.00
0005435327079	6045	Economy	23200.00
0005435327099	6045	Economy	23200.00
0005434601593	6045	Economy	23200.00
0005435327112	6045	Economy	23200.00
0005433527354	18569	Business	69700.00
0005434601431	18569	Business	69700.00
0005433527353	18569	Business	69700.00
0005434601547	18569	Business	69700.00
0005434601515	18569	Business	69700.00
0005433531368	18569	Economy	23200.00
0005434601498	18569	Economy	23200.00
0005434601541	18569	Economy	23200.00
0005434601502	18569	Economy	23200.00
0005434601435	18569	Economy	23200.00
0005434601542	18569	Economy	25600.00
0005434601516	18569	Economy	23200.00
0005434601519	18569	Economy	23200.00
0005433531375	18569	Economy	23200.00
0005434601521	18569	Economy	23200.00
0005433527358	18569	Economy	23200.00
0005433531367	18569	Economy	23200.00
0005434601430	18569	Economy	23200.00
0005434601503	18569	Economy	23200.00
0005433527357	18569	Economy	23200.00
0005434601489	18569	Economy	23200.00
0005434601432	18569	Economy	23200.00
0005433527359	18569	Economy	23200.00
0005434601523	18569	Economy	23200.00
0005434601494	18569	Economy	23200.00
0005434601461	18569	Economy	23200.00
0005434601492	18569	Economy	23200.00
0005434601464	18569	Economy	23200.00
0005434601504	18569	Economy	23200.00
0005433527360	18569	Economy	23200.00
0005434601520	18569	Economy	23200.00
0005434601434	18569	Economy	23200.00
0005433181694	10671	Business	9100.00
0005435314999	10671	Business	9100.00
0005433181762	10671	Business	9100.00
0005433181726	10671	Business	9100.00
0005435315008	10671	Business	9100.00
0005434558613	10671	Business	9100.00
0005433181805	10671	Business	9100.00
0005434757703	10671	Economy	3000.00
0005434552858	10671	Economy	3000.00
0005433181706	10671	Economy	3000.00
0005434552860	10671	Economy	3000.00
0005434552862	10671	Economy	3000.00
0005433181733	10671	Economy	3300.00
0005433181793	10671	Economy	3300.00
0005433181656	10671	Economy	3300.00
0005434757708	10671	Economy	3000.00
0005433181790	10671	Economy	3000.00
0005435315006	10671	Economy	3000.00
0005434757702	10671	Economy	3000.00
0005433181687	10671	Economy	3000.00
0005434757704	10671	Economy	3000.00
0005433181717	10671	Economy	3000.00
0005434552857	10671	Economy	3000.00
0005435315065	10671	Economy	3000.00
0005434757710	10671	Economy	3000.00
0005433181616	10671	Economy	3000.00
0005435315071	10671	Economy	3000.00
0005433181739	10671	Economy	3000.00
0005433181789	10671	Economy	3000.00
0005433181767	10671	Economy	3000.00
0005433181693	10671	Economy	3000.00
0005434757709	10671	Economy	3000.00
0005435315022	10671	Economy	3000.00
0005434558610	10671	Economy	3000.00
0005433181746	10671	Economy	3000.00
0005433181707	10671	Economy	3000.00
0005435314970	10671	Economy	3000.00
0005434757707	10671	Economy	3000.00
0005434757701	10671	Economy	3000.00
0005434558612	10671	Economy	3000.00
0005433181792	10671	Economy	3000.00
0005433181795	10671	Economy	3000.00
0005435314985	10671	Economy	3000.00
0005435315007	10671	Economy	3000.00
0005433181650	10671	Economy	3000.00
0005433181665	10671	Economy	3000.00
0005435314984	10671	Economy	3000.00
0005435315000	10671	Economy	3000.00
0005434558611	10671	Economy	3000.00
0005433181737	10671	Economy	3000.00
0005433181720	10671	Economy	3000.00
0005433181791	10671	Economy	3000.00
0005433181761	10671	Economy	3000.00
0005435315034	10671	Economy	3000.00
0005433181716	10671	Economy	3000.00
0005433181804	10671	Economy	3000.00
0005433181649	10671	Economy	3000.00
0005433181732	10671	Economy	3000.00
0005434552859	10671	Economy	3000.00
0005434552861	10671	Economy	3000.00
0005435315009	10671	Economy	3000.00
0005434558614	10671	Economy	3000.00
0005435315142	27701	Economy	3000.00
0005433181841	27701	Economy	3000.00
0005433181842	27701	Economy	3000.00
0005435315143	27701	Economy	3000.00
0005433181840	27701	Economy	3000.00
0005434552596	27702	Business	9100.00
0005434552785	27702	Business	9100.00
0005434552569	27702	Business	9100.00
0005434552347	27702	Business	9100.00
0005434552448	27702	Business	9100.00
0005434552668	27702	Business	9100.00
0005434552586	27702	Business	9100.00
0005434552768	27702	Business	9100.00
0005434558487	27702	Business	9100.00
0005434552584	27702	Economy	3000.00
0005434552673	27702	Economy	3000.00
0005434552600	27702	Economy	3000.00
0005434552553	27702	Economy	3000.00
0005434552683	27702	Economy	3000.00
0005434552546	27702	Economy	3000.00
0005434552695	27702	Economy	3000.00
0005434554110	27702	Economy	3000.00
0005434552547	27702	Economy	3300.00
0005434552589	27702	Economy	3300.00
0005434552563	27702	Economy	3300.00
0005434552288	27702	Economy	3300.00
0005434552659	27702	Economy	3000.00
0005434558463	27702	Economy	3000.00
0005434552582	27702	Economy	3000.00
0005434552652	27702	Economy	3000.00
0005434552568	27702	Economy	3000.00
0005434552348	27702	Economy	3000.00
0005434552784	27702	Economy	3000.00
0005434552509	27702	Economy	3000.00
0005434552782	27702	Economy	3000.00
0005434552614	27702	Economy	3000.00
0005434552583	27702	Economy	3000.00
0005434552571	27702	Economy	3000.00
0005434552538	27702	Economy	3000.00
0005434552642	27702	Economy	3000.00
0005434558485	27702	Economy	3000.00
0005434552615	27702	Economy	3000.00
0005434552537	27702	Economy	3000.00
0005434552387	27702	Economy	3000.00
0005434552653	27702	Economy	3000.00
0005434554112	27702	Economy	3000.00
0005434552476	27702	Economy	3000.00
0005434552700	27702	Economy	3000.00
0005434552540	27702	Economy	3000.00
0005434558490	27702	Economy	3000.00
0005434552681	27702	Economy	3000.00
0005434552670	27702	Economy	3000.00
0005434552654	27702	Economy	3000.00
0005434552539	27702	Economy	3000.00
0005434552658	27702	Economy	3000.00
0005434552447	27702	Economy	3000.00
0005434552597	27702	Economy	3000.00
0005434552289	27702	Economy	3000.00
0005434552440	27702	Economy	3000.00
0005434558473	27702	Economy	3000.00
0005434552674	27702	Economy	3000.00
0005434552625	27702	Economy	3000.00
0005434552682	27702	Economy	3000.00
0005434552781	27702	Economy	3000.00
0005434552532	27702	Economy	3000.00
0005434558474	27702	Economy	3000.00
0005434552548	27702	Economy	3000.00
0005434552753	27702	Economy	3000.00
0005434552501	27702	Economy	3000.00
0005434552478	27702	Economy	3000.00
0005434554111	27702	Economy	3000.00
0005434552734	27702	Economy	3000.00
0005434552666	27702	Economy	3000.00
0005434552552	27702	Economy	3000.00
0005434552551	27702	Economy	3000.00
0005434552651	27702	Economy	3000.00
0005434558460	27702	Economy	3000.00
0005434552650	27702	Economy	3000.00
0005434552287	27702	Economy	3000.00
0005435254527	6129	Economy	11700.00
0005435254528	6129	Economy	11700.00
0005435254533	6129	Economy	11700.00
0005435254529	6129	Economy	11700.00
0005435254537	6129	Economy	11700.00
0005435254538	6129	Economy	11700.00
0005435254539	6129	Economy	11700.00
0005435254540	6129	Economy	11700.00
0005435254542	19310	Economy	11700.00
0005433459334	19310	Economy	11700.00
0005433459324	19310	Economy	11700.00
0005435254541	19310	Economy	11700.00
0005433459325	19310	Economy	11700.00
0005435254543	19310	Economy	11700.00
0005432136315	6708	Business	51100.00
0005432136316	6708	Business	51100.00
0005435438534	6708	Business	51100.00
0005435438485	6708	Business	51100.00
0005434828757	6708	Business	51100.00
0005435438490	6708	Economy	17000.00
0005435438486	6708	Economy	17000.00
0005435654517	6708	Economy	17000.00
0005435438483	6708	Economy	17000.00
0005435438489	6708	Economy	17000.00
0005435654516	6708	Economy	18700.00
0005435438573	6708	Economy	18700.00
0005435220377	6708	Economy	17000.00
0005435654520	6708	Economy	17000.00
0005435220372	6708	Economy	17000.00
0005435217769	6708	Economy	17000.00
0005435217770	6708	Economy	17000.00
0005435220373	6708	Economy	17000.00
0005434828758	6708	Economy	17000.00
0005435438494	6708	Economy	17000.00
0005435438491	6708	Economy	17000.00
0005435438456	6708	Economy	17000.00
0005435217768	6708	Economy	17000.00
0005435221531	6708	Economy	17000.00
0005435683335	6708	Economy	17000.00
0005435654519	6708	Economy	17000.00
0005435631055	6708	Economy	17000.00
0005432533363	6708	Economy	17000.00
0005435654518	6708	Economy	17000.00
0005435221530	6708	Economy	17000.00
0005435438528	6708	Economy	17000.00
0005435438575	6708	Economy	17000.00
0005435438484	6708	Economy	17000.00
0005435438455	6708	Economy	17000.00
0005432533362	6708	Economy	17000.00
0005435683334	6708	Economy	17000.00
0005435438525	6708	Economy	17000.00
0005435661997	24617	Business	51100.00
0005435631033	24617	Business	51100.00
0005435683150	24617	Business	51100.00
0005435683204	24617	Business	51100.00
0005435683035	24617	Business	51100.00
0005435683072	24617	Business	51100.00
0005435683149	24617	Business	51100.00
0005435662008	24617	Economy	17000.00
0005435661996	24617	Economy	17000.00
0005435220386	24617	Economy	17000.00
0005435438592	24617	Economy	17000.00
0005435683143	24617	Economy	17000.00
0005435683190	24617	Economy	18700.00
0005435683292	24617	Economy	18700.00
0005435631030	24617	Economy	18700.00
0005435683070	24617	Economy	18700.00
0005435682927	24617	Economy	17000.00
0005435220522	24617	Economy	17000.00
0005435683239	24617	Economy	17000.00
0005435683030	24617	Economy	17000.00
0005435683045	24617	Economy	17000.00
0005435683075	24617	Economy	17000.00
0005435683053	24617	Economy	17000.00
0005435683215	24617	Economy	17000.00
0005435219265	24617	Economy	17000.00
0005435683124	24617	Economy	17000.00
0005435654506	24617	Economy	17000.00
0005435683071	24617	Economy	17000.00
0005435683200	24617	Economy	17000.00
0005435631045	24617	Economy	17000.00
0005435719587	24617	Economy	17000.00
0005435719593	24617	Economy	17000.00
0005435719590	24617	Economy	17000.00
0005435654507	24617	Economy	17000.00
0005435683196	24617	Economy	17000.00
0005435683106	24617	Economy	17000.00
0005435683187	24617	Economy	17000.00
0005435683240	24617	Economy	17000.00
0005435683102	24617	Economy	17000.00
0005435683201	24617	Economy	17000.00
0005435438591	24617	Economy	17000.00
0005435220384	24617	Economy	17000.00
0005435631031	24617	Economy	17000.00
0005435220385	24617	Economy	17000.00
0005435127577	11554	Business	26400.00
0005435127578	11554	Economy	8800.00
0005435558162	11554	Economy	8800.00
0005435558160	11554	Economy	8800.00
0005435558163	11554	Economy	8800.00
0005435127582	11554	Economy	8800.00
0005435558147	11554	Economy	8800.00
0005435127584	11554	Economy	8800.00
0005435127581	11554	Economy	8800.00
0005435558161	11554	Economy	8800.00
0005435558146	11554	Economy	8800.00
0005435127583	11554	Economy	8800.00
0005435127580	11554	Economy	8800.00
0005435127579	11554	Economy	8800.00
0005435127333	31870	Business	26400.00
0005435127445	31870	Business	26400.00
0005435127340	31870	Business	26400.00
0005435127335	31870	Business	26400.00
0005435127406	31870	Business	26400.00
0005435127415	31870	Economy	8800.00
0005435127416	31870	Economy	8800.00
0005435127550	31870	Economy	8800.00
0005435127401	31870	Economy	8800.00
0005435127562	31870	Economy	9700.00
0005435106063	31870	Economy	9700.00
0005435127563	31870	Economy	9700.00
0005435127510	31870	Economy	9700.00
0005435127396	31870	Economy	8800.00
0005435127407	31870	Economy	8800.00
0005435127548	31870	Economy	8800.00
0005435127475	31870	Economy	8800.00
0005435106073	31870	Economy	8800.00
0005435127191	31870	Economy	8800.00
0005435127477	31870	Economy	8800.00
0005435127476	31870	Economy	8800.00
0005435127352	31870	Economy	8800.00
0005435127178	31870	Economy	8800.00
0005435127363	31870	Economy	8800.00
0005435127490	31870	Economy	8800.00
0005435127441	31870	Economy	8800.00
0005435127362	31870	Economy	8800.00
0005435127442	31870	Economy	8800.00
0005435127422	31870	Economy	8800.00
0005435127316	31870	Economy	8800.00
0005435127353	31870	Economy	8800.00
0005435127332	31870	Economy	8800.00
0005435127446	31870	Economy	8800.00
0005435127511	31870	Economy	8800.00
0005435127444	31870	Economy	8800.00
0005435127412	31870	Economy	8800.00
0005435127414	31870	Economy	8800.00
0005435127549	31870	Economy	8800.00
0005435127334	31870	Economy	8800.00
0005435127306	31870	Economy	8800.00
0005435106072	31870	Economy	8800.00
0005435127367	31870	Economy	8800.00
0005435127149	31870	Economy	8800.00
0005435127413	31870	Economy	8800.00
0005435732659	13530	Economy	12200.00
0005435732620	13530	Economy	12200.00
0005435732642	13530	Economy	12200.00
0005435732655	13530	Economy	12200.00
0005435732619	13530	Economy	12200.00
0005435732654	13530	Economy	12200.00
0005435732623	13530	Economy	12200.00
0005435732641	13530	Economy	12200.00
0005435732640	13530	Economy	12200.00
0005433399466	13530	Economy	12200.00
0005435732643	13530	Economy	12200.00
0005435725788	19406	Business	36600.00
0005433399178	19406	Business	36600.00
0005433399184	19406	Business	36600.00
0005433399367	19406	Business	36600.00
0005433398825	19406	Economy	12200.00
0005433399067	19406	Economy	12200.00
0005433399231	19406	Economy	12200.00
0005433399257	19406	Economy	12200.00
0005433399347	19406	Economy	13400.00
0005433399329	19406	Economy	13400.00
0005433399076	19406	Economy	12200.00
0005433399198	19406	Economy	12200.00
0005433399339	19406	Economy	12200.00
0005433399324	19406	Economy	12200.00
0005433399193	19406	Economy	12200.00
0005433399183	19406	Economy	12200.00
0005433399197	19406	Economy	12200.00
0005433399042	19406	Economy	12200.00
0005433399270	19406	Economy	12200.00
0005433399176	19406	Economy	12200.00
0005433399252	19406	Economy	12200.00
0005433399348	19406	Economy	12200.00
0005433399338	19406	Economy	12200.00
0005433399126	19406	Economy	12200.00
0005433399397	19406	Economy	12200.00
0005433399204	19406	Economy	12200.00
0005433399328	19406	Economy	12200.00
0005433399217	19406	Economy	12200.00
0005433399132	19406	Economy	12200.00
0005433399239	19406	Economy	12200.00
0005433399275	19406	Economy	12200.00
0005433399161	19406	Economy	12200.00
0005433399166	19406	Economy	12200.00
0005433399127	19406	Economy	12200.00
0005433399353	19406	Economy	12200.00
0005433399260	19406	Economy	12200.00
0005433399218	19406	Economy	12200.00
0005433399066	19406	Economy	12200.00
0005433399182	19406	Economy	12200.00
0005433399240	19406	Economy	12200.00
0005433399264	19406	Economy	12200.00
0005433399192	19406	Economy	12200.00
0005433399369	19406	Economy	12200.00
0005433399349	19406	Economy	12200.00
0005433399396	19406	Economy	12200.00
0005433399199	19406	Economy	12200.00
0005433399276	19406	Economy	12200.00
0005435070308	13133	Business	11300.00
0005435070251	13133	Business	11300.00
0005435925726	13133	Business	11300.00
0005435070484	13133	Business	11300.00
0005435070269	13133	Economy	3800.00
0005435070000	13133	Economy	3800.00
0005435070189	13133	Economy	3800.00
0005435070234	13133	Economy	4100.00
0005435070109	13133	Economy	3800.00
0005435070295	13133	Economy	3800.00
0005435070480	13133	Economy	3800.00
0005435070341	13133	Economy	3800.00
0005435070060	13133	Economy	3800.00
0005435070340	13133	Economy	3800.00
0005435070059	13133	Economy	3800.00
0005435070465	13133	Economy	3800.00
0005435070412	13133	Economy	3800.00
0005435070190	13133	Economy	3800.00
0005435070074	13133	Economy	3800.00
0005435069930	13133	Economy	3800.00
0005435070309	13133	Economy	3800.00
0005435070349	13133	Economy	3800.00
0005435070253	13133	Economy	3800.00
0005435070286	13133	Economy	3800.00
0005435070320	13133	Economy	3800.00
0005435070437	13133	Economy	3800.00
0005435070305	13133	Economy	3800.00
0005435070073	13133	Economy	3800.00
0005435070321	13133	Economy	3800.00
0005435070468	13133	Economy	3800.00
0005435070110	13133	Economy	3800.00
0005435070420	13133	Economy	3800.00
0005435070212	13133	Economy	3800.00
0005435070252	13133	Economy	3800.00
0005435070415	13133	Economy	3800.00
0005435070378	13133	Economy	3800.00
0005435070288	13133	Economy	3800.00
0005435070557	15498	Business	11300.00
0005435070558	15498	Business	11300.00
0005435070562	15498	Business	11300.00
0005435070560	15498	Economy	3800.00
0005435925636	15498	Economy	4100.00
0005435070556	15498	Economy	3800.00
0005435070555	15498	Economy	3800.00
0005435925656	15498	Economy	3800.00
0005435925611	15498	Economy	3800.00
0005435925591	15498	Economy	3800.00
0005435925637	15498	Economy	3800.00
0005435070563	15498	Economy	3800.00
0005435070559	15498	Economy	3800.00
0005435925655	15498	Economy	3800.00
0005435925589	15498	Economy	3800.00
0005435925613	15498	Economy	3800.00
0005435925681	15498	Economy	3800.00
0005435925680	15498	Economy	3800.00
0005435925588	15498	Economy	3800.00
0005435925610	15498	Economy	3800.00
0005435070561	15498	Economy	3800.00
0005435925605	15498	Economy	3800.00
0005435808531	23184	Economy	27100.00
0005433407670	23184	Economy	24700.00
0005433407698	23184	Economy	24700.00
0005435808527	23184	Economy	24700.00
0005435808529	23184	Economy	24700.00
0005433407691	23184	Economy	24700.00
0005433407692	23184	Economy	24700.00
0005433407668	23184	Economy	24700.00
0005433407700	23184	Economy	24700.00
0005433407669	23184	Economy	24700.00
0005433407675	23184	Economy	24700.00
0005435808532	23184	Economy	24700.00
0005435808530	23184	Economy	24700.00
0005433407699	23184	Economy	24700.00
0005435808526	23184	Economy	24700.00
0005435808528	23184	Economy	24700.00
0005434757293	10724	Business	61300.00
0005434757551	10724	Business	61300.00
0005434757452	10724	Business	61300.00
0005434757269	10724	Business	61300.00
0005434757461	10724	Business	61300.00
0005434757422	10724	Economy	20400.00
0005434757355	10724	Economy	20400.00
0005434757509	10724	Economy	20400.00
0005434757359	10724	Economy	22500.00
0005434757508	10724	Economy	22500.00
0005434757304	10724	Economy	20400.00
0005434757500	10724	Economy	20400.00
0005434757421	10724	Economy	20400.00
0005434757354	10724	Economy	20400.00
0005434757398	10724	Economy	20400.00
0005434757294	10724	Economy	20400.00
0005434757498	10724	Economy	20400.00
0005434757418	10724	Economy	20400.00
0005434757378	10724	Economy	20400.00
0005434757420	10724	Economy	20400.00
0005434757439	10724	Economy	20400.00
0005434757400	10724	Economy	20400.00
0005434757329	10724	Economy	20400.00
0005434757507	10724	Economy	20400.00
0005434757268	10724	Economy	20400.00
0005434757550	10724	Economy	20400.00
0005434215904	10724	Economy	20400.00
0005434757486	10724	Economy	20400.00
0005434757144	10724	Economy	20400.00
0005434757270	10724	Economy	20400.00
0005434757451	10724	Economy	20400.00
0005434757479	10724	Economy	20400.00
0005434757303	10724	Economy	20400.00
0005434757497	10724	Economy	20400.00
0005434757440	10724	Economy	20400.00
0005434757538	10724	Economy	20400.00
0005434757330	10724	Economy	20400.00
0005434757412	10724	Economy	20400.00
0005434215902	10724	Economy	20400.00
0005434757257	10724	Economy	20400.00
0005434215903	10724	Economy	20400.00
0005434215587	28705	Business	61300.00
0005434215755	28705	Business	61300.00
0005434215592	28705	Business	61300.00
0005434215639	28705	Business	61300.00
0005434215618	28705	Business	61300.00
0005434215556	28705	Business	61300.00
0005434215590	28705	Economy	20400.00
0005434215570	28705	Economy	20400.00
0005434215520	28705	Economy	20400.00
0005434215619	28705	Economy	20400.00
0005434215682	28705	Economy	22500.00
0005434215615	28705	Economy	22500.00
0005434215392	28705	Economy	22500.00
0005434215557	28705	Economy	20400.00
0005434215722	28705	Economy	20400.00
0005434215483	28705	Economy	20400.00
0005434215384	28705	Economy	20400.00
0005434215723	28705	Economy	20400.00
0005434215489	28705	Economy	20400.00
0005434215383	28705	Economy	20400.00
0005434757685	28705	Economy	20400.00
0005434215591	28705	Economy	20400.00
0005434215694	28705	Economy	20400.00
0005434215663	28705	Economy	20400.00
0005434215655	28705	Economy	20400.00
0005434215481	28705	Economy	20400.00
0005434215548	28705	Economy	20400.00
0005434215599	28705	Economy	20400.00
0005434215744	28705	Economy	20400.00
0005434215683	28705	Economy	20400.00
0005434215685	28705	Economy	20400.00
0005434215807	28705	Economy	20400.00
0005434215576	28705	Economy	20400.00
0005434215513	28705	Economy	20400.00
0005434215385	28705	Economy	20400.00
0005434215684	28705	Economy	20400.00
0005434215730	28705	Economy	20400.00
0005434215661	28705	Economy	20400.00
0005434215386	28705	Economy	20400.00
0005434215687	28705	Economy	20400.00
0005434215808	28705	Economy	20400.00
0005434215452	28705	Economy	20400.00
0005434215617	28705	Economy	20400.00
0005434215659	28705	Economy	20400.00
0005434215546	28705	Economy	20400.00
0005434215573	28705	Economy	20400.00
0005434215704	28705	Economy	20400.00
0005434757684	28705	Economy	20400.00
0005434215540	28705	Economy	20400.00
0005434229924	5450	Business	29500.00
0005434229944	5450	Business	29500.00
0005435377949	5450	Economy	9800.00
0005435041696	5450	Economy	9800.00
0005435377956	5450	Economy	9800.00
0005434229881	5450	Economy	9800.00
0005435377928	5450	Economy	9800.00
0005434229869	5450	Economy	9800.00
0005434229885	5450	Economy	9800.00
0005434229878	5450	Economy	9800.00
0005434230007	5450	Economy	9800.00
0005434229877	5450	Economy	9800.00
0005435377936	5450	Economy	9800.00
0005435377932	5450	Economy	9800.00
0005435377931	5450	Economy	9800.00
0005435041700	5450	Economy	9800.00
0005435041697	5450	Economy	10800.00
0005435377948	5450	Economy	10800.00
0005435041698	5450	Economy	9800.00
0005434229900	5450	Economy	9800.00
0005435007722	5450	Economy	9800.00
0005434229943	5450	Economy	9800.00
0005434229998	5450	Economy	9800.00
0005435007721	5450	Economy	9800.00
0005434229868	5450	Economy	9800.00
0005435377927	5450	Economy	9800.00
0005435041699	5450	Economy	9800.00
0005435377937	5450	Economy	9800.00
0005435377929	5450	Economy	9800.00
0005434230008	5450	Economy	9800.00
0005434230006	5450	Economy	9800.00
0005435377926	5450	Economy	9800.00
0005435007720	5450	Economy	9800.00
0005434229925	5450	Economy	9800.00
0005435041245	12995	Business	29500.00
0005435007659	12995	Business	29500.00
0005435042927	12995	Business	29500.00
0005435041310	12995	Business	29500.00
0005435041563	12995	Business	29500.00
0005435041464	12995	Economy	9800.00
0005435041498	12995	Economy	9800.00
0005435007581	12995	Economy	9800.00
0005435007641	12995	Economy	9800.00
0005435041200	12995	Economy	9800.00
0005435007613	12995	Economy	9800.00
0005435041435	12995	Economy	9800.00
0005435041409	12995	Economy	9800.00
0005435007566	12995	Economy	9800.00
0005435041491	12995	Economy	9800.00
0005435007525	12995	Economy	9800.00
0005435007594	12995	Economy	9800.00
0005435007616	12995	Economy	9800.00
0005435007686	12995	Economy	9800.00
0005435041595	12995	Economy	9800.00
0005435041544	12995	Economy	9800.00
0005435041631	12995	Economy	9800.00
0005435041408	12995	Economy	9800.00
0005435007620	12995	Economy	9800.00
0005435041593	12995	Economy	9800.00
0005435007568	12995	Economy	9800.00
0005435041525	12995	Economy	9800.00
0005435041585	12995	Economy	9800.00
0005435007576	12995	Economy	9800.00
0005435007656	12995	Economy	9800.00
0005435041502	12995	Economy	9800.00
0005435041488	12995	Economy	9800.00
0005435041575	12995	Economy	9800.00
0005435041244	12995	Economy	9800.00
0005435041302	12995	Economy	9800.00
0005435377989	12995	Economy	9800.00
0005435007652	12995	Economy	9800.00
0005435041496	12995	Economy	9800.00
0005435041363	12995	Economy	10800.00
0005435041199	12995	Economy	10800.00
0005435041349	12995	Economy	10800.00
0005435007621	12995	Economy	10800.00
0005435041194	12995	Economy	10800.00
0005435041332	12995	Economy	9800.00
0005435041570	12995	Economy	9800.00
0005435040913	12995	Economy	9800.00
0005435041331	12995	Economy	9800.00
0005435041195	12995	Economy	9800.00
0005435007643	12995	Economy	9800.00
0005435007567	12995	Economy	9800.00
0005435041484	12995	Economy	9800.00
0005435041242	12995	Economy	9800.00
0005435041356	12995	Economy	9800.00
0005435007640	12995	Economy	9800.00
0005435041116	12995	Economy	9800.00
0005435041333	12995	Economy	9800.00
0005435007615	12995	Economy	9800.00
0005435041630	12995	Economy	9800.00
0005434230042	12995	Economy	9800.00
0005435041137	12995	Economy	9800.00
0005435041261	12995	Economy	9800.00
0005435041232	12995	Economy	9800.00
0005435041573	12995	Economy	9800.00
0005434230043	12995	Economy	9800.00
0005435041465	12995	Economy	9800.00
0005435041564	12995	Economy	9800.00
0005435041603	12995	Economy	9800.00
0005435007687	12995	Economy	9800.00
0005435041374	12995	Economy	9800.00
0005435041420	12995	Economy	9800.00
0005435041602	12995	Economy	9800.00
0005435041466	12995	Economy	9800.00
0005435007642	12995	Economy	9800.00
0005435041550	12995	Economy	9800.00
0005435041492	12995	Economy	9800.00
0005435007639	12995	Economy	9800.00
0005435041431	12995	Economy	9800.00
0005435041375	12995	Economy	9800.00
0005435041231	12995	Economy	9800.00
0005435041594	12995	Economy	9800.00
0005435042924	12995	Economy	9800.00
0005435041549	12995	Economy	9800.00
0005435041329	12995	Economy	9800.00
0005435007508	12995	Economy	9800.00
0005435040912	12995	Economy	9800.00
0005435041243	12995	Economy	9800.00
0005435007509	12995	Economy	9800.00
0005435041499	12995	Economy	9800.00
0005435041512	12995	Economy	9800.00
0005435041126	12995	Economy	9800.00
0005435043298	12995	Economy	9800.00
0005435007614	12995	Economy	9800.00
0005435041249	12995	Economy	9800.00
0005435042909	12995	Economy	9800.00
0005435041315	12995	Economy	9800.00
0005435007638	12995	Economy	9800.00
0005435041184	12995	Economy	9800.00
0005435041265	12995	Economy	9800.00
0005435007575	12995	Economy	9800.00
0005435041604	12995	Economy	9800.00
0005435041187	12995	Economy	9800.00
0005435042928	12995	Economy	9800.00
0005435041427	12995	Economy	9800.00
0005435007676	12995	Economy	9800.00
0005435041596	12995	Economy	9800.00
0005435041574	12995	Economy	9800.00
0005434427464	14903	Business	52900.00
0005435554305	14903	Business	52900.00
0005435554307	14903	Business	52900.00
0005434427468	14903	Business	52900.00
0005435554292	14903	Business	52900.00
0005434427470	14903	Business	52900.00
0005435903090	14903	Economy	17600.00
0005434427467	14903	Economy	17600.00
0005435903107	14903	Economy	17600.00
0005435903148	14903	Economy	17600.00
0005434427471	14903	Economy	19400.00
0005435903102	14903	Economy	17600.00
0005435554304	14903	Economy	17600.00
0005435903111	14903	Economy	17600.00
0005435903165	14903	Economy	17600.00
0005435903139	14903	Economy	17600.00
0005435903099	14903	Economy	17600.00
0005435903117	14903	Economy	17600.00
0005432188702	14903	Economy	17600.00
0005434427466	14903	Economy	17600.00
0005435903115	14903	Economy	17600.00
0005435554293	14903	Economy	17600.00
0005434427469	14903	Economy	17600.00
0005435554282	14903	Economy	17600.00
0005435554306	14903	Economy	17600.00
0005435903098	14903	Economy	17600.00
0005434427465	14903	Economy	17600.00
0005435903112	14903	Economy	17600.00
0005432188701	14903	Economy	17600.00
0005434427453	20196	Business	52900.00
0005434427374	20196	Business	52900.00
0005434427305	20196	Business	52900.00
0005434427388	20196	Business	52900.00
0005434427316	20196	Business	52900.00
0005434427263	20196	Economy	17600.00
0005434427306	20196	Economy	19400.00
0005434427324	20196	Economy	19400.00
0005434427391	20196	Economy	17600.00
0005434427279	20196	Economy	17600.00
0005434427251	20196	Economy	17600.00
0005434427376	20196	Economy	17600.00
0005434427416	20196	Economy	17600.00
0005434427321	20196	Economy	17600.00
0005434427311	20196	Economy	17600.00
0005434427375	20196	Economy	17600.00
0005434427346	20196	Economy	17600.00
0005434427406	20196	Economy	17600.00
0005434427390	20196	Economy	17600.00
0005434427417	20196	Economy	17600.00
0005434427310	20196	Economy	17600.00
0005434427320	20196	Economy	17600.00
0005434427418	20196	Economy	17600.00
0005434427252	20196	Economy	17600.00
0005434411890	20196	Economy	17600.00
0005434427349	20196	Economy	17600.00
0005434411875	20196	Economy	17600.00
0005434427439	20196	Economy	17600.00
0005434411876	20196	Economy	17600.00
0005435554329	20196	Economy	17600.00
0005434427315	20196	Economy	17600.00
0005434427323	20196	Economy	17600.00
0005433726159	21661	Business	91700.00
0005433726155	21661	Business	91700.00
0005433726149	21661	Business	91700.00
0005433726139	21661	Economy	30600.00
0005433726142	21661	Economy	30600.00
0005433726131	21661	Economy	30600.00
0005433726157	21661	Economy	30600.00
0005433726158	21661	Economy	33600.00
0005433726141	21661	Economy	33600.00
0005433726160	21661	Economy	30600.00
0005433726132	21661	Economy	30600.00
0005433726134	21661	Economy	30600.00
0005433726145	21661	Economy	30600.00
0005433726146	21661	Economy	30600.00
0005433726156	21661	Economy	30600.00
0005433726133	21661	Economy	30600.00
0005433726137	21661	Economy	30600.00
0005433726152	21661	Economy	30600.00
0005433726147	21661	Economy	30600.00
0005433726154	21661	Economy	30600.00
0005433726153	21661	Economy	30600.00
0005433726148	21661	Economy	30600.00
0005433726140	21661	Economy	30600.00
0005433435316	26501	Business	18500.00
0005433435348	26501	Business	18500.00
0005433435349	26501	Business	18500.00
0005433435252	26501	Business	18500.00
0005433435425	26501	Economy	6200.00
0005433435312	26501	Economy	6200.00
0005433435309	26501	Economy	6200.00
0005433435315	26501	Economy	6200.00
0005433435343	26501	Economy	6200.00
0005433435439	26501	Economy	6800.00
0005433435306	26501	Economy	6200.00
0005433435366	26501	Economy	6200.00
0005433435313	26501	Economy	6200.00
0005433435326	26501	Economy	6200.00
0005433435438	26501	Economy	6200.00
0005433435328	26501	Economy	6200.00
0005432300444	26501	Economy	6200.00
0005433435305	26501	Economy	6200.00
0005433435308	26501	Economy	6200.00
0005433435301	26501	Economy	6200.00
0005432300443	26501	Economy	6200.00
0005433435378	26501	Economy	6200.00
0005433435314	26501	Economy	6200.00
0005433435371	26501	Economy	6200.00
0005435983673	26501	Economy	6200.00
0005433435340	26501	Economy	6200.00
0005433435321	26501	Economy	6200.00
0005432300442	26501	Economy	6200.00
0005433435264	26501	Economy	6200.00
0005433435276	26501	Economy	6200.00
0005433435354	26501	Economy	6200.00
0005433435341	26501	Economy	6200.00
0005433435410	26501	Economy	6200.00
0005434273116	26501	Economy	6200.00
0005433435409	26501	Economy	6200.00
0005435983491	26718	Business	18500.00
0005435983440	26718	Business	18500.00
0005435983442	26718	Business	18500.00
0005435983534	26718	Business	18500.00
0005435983337	26718	Business	18500.00
0005435983525	26718	Business	18500.00
0005435983245	26718	Business	18500.00
0005435983550	26718	Economy	6200.00
0005435983251	26718	Economy	6200.00
0005435983471	26718	Economy	6200.00
0005435983336	26718	Economy	6200.00
0005435983398	26718	Economy	6200.00
0005435983323	26718	Economy	6200.00
0005435983311	26718	Economy	6200.00
0005435983298	26718	Economy	6800.00
0005435983382	26718	Economy	6800.00
0005435983460	26718	Economy	6800.00
0005435983418	26718	Economy	6200.00
0005435983437	26718	Economy	6200.00
0005435983307	26718	Economy	6200.00
0005433435508	26718	Economy	6200.00
0005434270267	26718	Economy	6200.00
0005435983383	26718	Economy	6200.00
0005435983551	26718	Economy	6200.00
0005435983252	26718	Economy	6200.00
0005435983406	26718	Economy	6200.00
0005435983322	26718	Economy	6200.00
0005435983361	26718	Economy	6200.00
0005435983195	26718	Economy	6200.00
0005435983292	26718	Economy	6200.00
0005435983253	26718	Economy	6200.00
0005435983505	26718	Economy	6200.00
0005435983407	26718	Economy	6200.00
0005435983249	26718	Economy	6200.00
0005435983329	26718	Economy	6200.00
0005435983256	26718	Economy	6200.00
0005435983250	26718	Economy	6200.00
0005435983238	26718	Economy	6200.00
0005435983248	26718	Economy	6200.00
0005435983428	26718	Economy	6200.00
0005435983321	26718	Economy	6200.00
0005435983328	26718	Economy	6200.00
0005435983371	26718	Economy	6200.00
0005432858355	3141	Economy	11100.00
0005432858371	3141	Economy	10100.00
0005432858309	3141	Economy	10100.00
0005432858379	3141	Economy	10100.00
0005432858356	3141	Economy	10100.00
0005432858331	3141	Economy	10100.00
0005432858339	3141	Economy	10100.00
0005432858344	3141	Economy	10100.00
0005432858372	3141	Economy	10100.00
0005432858380	3141	Economy	10100.00
0005432584788	3141	Economy	10100.00
0005432584789	3141	Economy	10100.00
0005432858401	3141	Economy	10100.00
0005432858373	3141	Economy	10100.00
0005432584787	3141	Economy	10100.00
0005432584577	31515	Economy	11100.00
0005432584706	31515	Economy	11100.00
0005432584486	31515	Economy	10100.00
0005432584675	31515	Economy	10100.00
0005432584695	31515	Economy	10100.00
0005432584655	31515	Economy	10100.00
0005432584674	31515	Economy	10100.00
0005432584673	31515	Economy	10100.00
0005432584605	31515	Economy	10100.00
0005432584730	31515	Economy	10100.00
0005432584694	31515	Economy	10100.00
0005432584604	31515	Economy	10100.00
0005432584667	31515	Economy	10100.00
0005432584633	31515	Economy	10100.00
0005432584731	31515	Economy	10100.00
0005432584696	31515	Economy	10100.00
0005432584646	31515	Economy	10100.00
0005432584647	31515	Economy	10100.00
0005432584702	31515	Economy	10100.00
0005432584735	31515	Economy	10100.00
0005432584732	31515	Economy	10100.00
0005433255262	901	Economy	7500.00
0005434943617	901	Economy	7500.00
0005434943575	16215	Economy	7500.00
0005433255276	16215	Economy	7500.00
0005434943594	16215	Economy	7500.00
0005434943578	16215	Economy	7500.00
0005433255278	16215	Economy	7500.00
0005434943562	16215	Economy	7500.00
0005434943588	16215	Economy	7500.00
0005434943574	16215	Economy	7500.00
0005433255277	16215	Economy	7500.00
0005434943576	16215	Economy	7500.00
0005433811669	14344	Economy	4400.00
0005433811676	14344	Economy	4400.00
0005433811670	14344	Economy	4400.00
0005433368799	21782	Business	9800.00
0005433368879	21782	Business	9800.00
0005433368711	21782	Business	9800.00
0005433368616	21782	Business	9800.00
0005435654490	21782	Business	9800.00
0005435654489	21782	Business	9800.00
0005433368618	21782	Business	9800.00
0005433368869	21782	Economy	3300.00
0005433368845	21782	Economy	3300.00
0005433368617	21782	Economy	3300.00
0005433368686	21782	Economy	3300.00
0005435654492	21782	Economy	3600.00
0005435654486	21782	Economy	3300.00
0005433368800	21782	Economy	3300.00
0005433368789	21782	Economy	3300.00
0005433368842	21782	Economy	3300.00
0005433368749	21782	Economy	3300.00
0005433368706	21782	Economy	3300.00
0005433368809	21782	Economy	3300.00
0005433368797	21782	Economy	3300.00
0005433368846	21782	Economy	3300.00
0005433368801	21782	Economy	3300.00
0005435654488	21782	Economy	3300.00
0005433368757	21782	Economy	3300.00
0005433368834	21782	Economy	3300.00
0005433368705	21782	Economy	3300.00
0005433368640	21782	Economy	3300.00
0005433368707	21782	Economy	3300.00
0005433368676	21782	Economy	3300.00
0005433368833	21782	Economy	3300.00
0005433368642	21782	Economy	3300.00
0005433368677	21782	Economy	3300.00
0005435654487	21782	Economy	3300.00
0005433368891	21782	Economy	3300.00
0005435654494	21782	Economy	3300.00
0005435654493	21782	Economy	3300.00
0005433368847	21782	Economy	3300.00
0005433368698	21782	Economy	3300.00
0005435654491	21782	Economy	3300.00
0005433368823	21782	Economy	3300.00
0005433368855	21782	Economy	3300.00
0005433368761	21782	Economy	3300.00
0005433368964	21782	Economy	3300.00
0005433368793	21782	Economy	3300.00
0005433368802	21782	Economy	3300.00
0005435858700	9369	Business	186200.00
0005435270030	9369	Business	186200.00
0005433786196	9369	Business	186200.00
0005434273119	9369	Business	186200.00
0005434270263	9369	Business	186200.00
0005435270062	9369	Business	186200.00
0005434171396	9369	Business	186200.00
0005435269975	9369	Business	186200.00
0005435270109	9369	Business	186200.00
0005434270259	9369	Economy	62100.00
0005434171451	9369	Economy	62100.00
0005435270149	9369	Economy	62100.00
0005433786194	9369	Economy	62100.00
0005435270076	9369	Economy	62100.00
0005435269987	9369	Economy	62100.00
0005435270142	9369	Economy	62100.00
0005435269885	9369	Economy	62100.00
0005434270261	9369	Economy	62100.00
0005434171397	9369	Economy	62100.00
0005434151781	9369	Economy	62100.00
0005434270260	9369	Economy	62100.00
0005435270066	9369	Economy	62100.00
0005435270067	9369	Economy	62100.00
0005435858703	9369	Economy	62100.00
0005435270180	9369	Economy	62100.00
0005434171398	9369	Economy	62100.00
0005435270101	9369	Economy	62100.00
0005434171453	9369	Economy	62100.00
0005435270029	9369	Economy	62100.00
0005434273118	9369	Economy	62100.00
0005435270001	9369	Economy	62100.00
0005435270114	9369	Economy	62100.00
0005435269972	9369	Economy	62100.00
0005435269965	9369	Economy	62100.00
0005434171445	9369	Economy	62100.00
0005435270143	9369	Economy	62100.00
0005435270160	9369	Economy	62100.00
0005435270095	9369	Economy	62100.00
0005434270258	9369	Economy	62100.00
0005433786193	9369	Economy	62100.00
0005434171421	9369	Economy	62100.00
0005434270257	9369	Economy	68300.00
0005435269886	9369	Economy	62100.00
0005434270264	9369	Economy	62100.00
0005435269997	9369	Economy	62100.00
0005435270148	9369	Economy	62100.00
0005434171400	9369	Economy	62100.00
0005434171423	9369	Economy	62100.00
0005433786195	9369	Economy	62100.00
0005435270181	9369	Economy	62100.00
0005435270031	9369	Economy	62100.00
0005432666449	9369	Economy	62100.00
0005435858710	9369	Economy	62100.00
0005435270096	9369	Economy	62100.00
0005434171399	9369	Economy	62100.00
0005435270063	9369	Economy	62100.00
0005433806410	9369	Economy	62100.00
0005433786192	9369	Economy	62100.00
0005434171420	9369	Economy	62100.00
0005434171422	9369	Economy	62100.00
0005434171447	9369	Economy	62100.00
0005434171404	9369	Economy	62100.00
0005435269946	9369	Economy	62100.00
0005434273122	9369	Economy	62100.00
0005434171452	9369	Economy	62100.00
0005434151780	9369	Economy	62100.00
0005435270091	9369	Economy	62100.00
0005434270262	9369	Economy	62100.00
0005433786198	9369	Economy	62100.00
0005434171395	9369	Economy	62100.00
0005434171457	9369	Economy	62100.00
0005434171437	9369	Economy	62100.00
0005433786197	9369	Economy	62100.00
0005435270115	9369	Economy	62100.00
0005433785710	26225	Business	186200.00
0005433785815	26225	Business	186200.00
0005435270225	26225	Business	186200.00
0005433806097	26225	Business	186200.00
0005433785767	26225	Business	186200.00
0005433785924	26225	Business	186200.00
0005433785991	26225	Business	186200.00
0005435270224	26225	Business	186200.00
0005433763587	26225	Business	186200.00
0005433785931	26225	Business	186200.00
0005433763565	26225	Business	186200.00
0005433785906	26225	Business	186200.00
0005433763521	26225	Business	186200.00
0005433763571	26225	Business	186200.00
0005433785706	26225	Business	186200.00
0005433763608	26225	Business	186200.00
0005433806167	26225	Business	186200.00
0005433806285	26225	Business	186200.00
0005433763540	26225	Economy	68300.00
0005433785761	26225	Economy	62100.00
0005433806098	26225	Economy	62100.00
0005435270222	26225	Economy	62100.00
0005433785795	26225	Economy	62100.00
0005433785805	26225	Economy	62100.00
0005433806242	26225	Economy	62100.00
0005433806203	26225	Economy	62100.00
0005433806202	26225	Economy	62100.00
0005433786109	26225	Economy	62100.00
0005433785814	26225	Economy	62100.00
0005432657537	26225	Economy	62100.00
0005433785978	26225	Economy	62100.00
0005433785979	26225	Economy	62100.00
0005433785908	26225	Economy	62100.00
0005433806376	26225	Economy	62100.00
0005433785955	26225	Economy	62100.00
0005433763527	26225	Economy	62100.00
0005432659761	26225	Economy	62100.00
0005433786034	26225	Economy	62100.00
0005433786063	26225	Economy	62100.00
0005433785773	26225	Economy	62100.00
0005433763559	26225	Economy	62100.00
0005433785915	26225	Economy	62100.00
0005433763609	26225	Economy	62100.00
0005433806264	26225	Economy	62100.00
0005433763560	26225	Economy	62100.00
0005435858746	26225	Economy	62100.00
0005433806091	26225	Economy	62100.00
0005433785977	26225	Economy	62100.00
0005433785992	26225	Economy	62100.00
0005433785754	26225	Economy	62100.00
0005433806265	26225	Economy	62100.00
0005433785907	26225	Economy	62100.00
0005433785782	26225	Economy	62100.00
0005433806254	26225	Economy	62100.00
0005435858747	26225	Economy	62100.00
0005433806187	26225	Economy	62100.00
0005433785993	26225	Economy	62100.00
0005435270229	26225	Economy	62100.00
0005433785877	26225	Economy	62100.00
0005433763610	26225	Economy	62100.00
0005433806303	26225	Economy	62100.00
0005433806185	26225	Economy	62100.00
0005433806243	26225	Economy	62100.00
0005433763589	26225	Economy	62100.00
0005433785876	26225	Economy	62100.00
0005433785820	26225	Economy	62100.00
0005433785601	26225	Economy	62100.00
0005433785938	26225	Economy	62100.00
0005435270228	26225	Economy	62100.00
0005435270223	26225	Economy	68300.00
0005433785796	26225	Economy	68300.00
0005433806110	26225	Economy	62100.00
0005435270226	26225	Economy	68300.00
0005433785859	26225	Economy	62100.00
0005433763581	26225	Economy	62100.00
0005433806109	26225	Economy	62100.00
0005433785949	26225	Economy	62100.00
0005433806275	26225	Economy	62100.00
0005433806263	26225	Economy	62100.00
0005433763582	26225	Economy	62100.00
0005433806217	26225	Economy	62100.00
0005433763541	26225	Economy	62100.00
0005433806266	26225	Economy	62100.00
0005433786035	26225	Economy	62100.00
0005433806253	26225	Economy	62100.00
0005433785790	26225	Economy	62100.00
0005433785847	26225	Economy	62100.00
0005433785990	26225	Economy	62100.00
0005432666429	26225	Economy	62100.00
0005433786093	26225	Economy	62100.00
0005433785774	26225	Economy	62100.00
0005433785753	26225	Economy	62100.00
0005433786011	26225	Economy	62100.00
0005433785845	26225	Economy	62100.00
0005433806186	26225	Economy	62100.00
0005433806226	26225	Economy	62100.00
0005433806125	26225	Economy	62100.00
0005433763590	26225	Economy	62100.00
0005433763572	26225	Economy	62100.00
0005433806128	26225	Economy	62100.00
0005433806129	26225	Economy	62100.00
0005433763591	26225	Economy	62100.00
0005433806170	26225	Economy	62100.00
0005433806184	26225	Economy	62100.00
0005432657536	26225	Economy	62100.00
0005433785846	26225	Economy	62100.00
0005433785858	26225	Economy	62100.00
0005433806284	26225	Economy	62100.00
0005433785967	26225	Economy	62100.00
0005433785848	26225	Economy	62100.00
0005435270227	26225	Economy	62100.00
0005434269166	26225	Economy	62100.00
0005433806092	26225	Economy	62100.00
0005433785936	26225	Economy	62100.00
0005433786012	26225	Economy	62100.00
0005432659760	26225	Economy	62100.00
0005432657535	26225	Economy	62100.00
0005433806320	26225	Economy	62100.00
0005433785766	26225	Economy	62100.00
0005433786092	26225	Economy	62100.00
0005435929716	4894	Economy	5300.00
0005435929717	4894	Economy	5300.00
0005435929699	4894	Economy	5300.00
0005435929700	4894	Economy	5300.00
0005435929703	4894	Economy	5300.00
0005435929704	4894	Economy	5300.00
0005435929709	4894	Economy	5300.00
0005435135799	33022	Economy	5900.00
0005435135790	33022	Economy	5300.00
0005435135762	33022	Economy	5300.00
0005435135796	33022	Economy	5300.00
0005435135798	33022	Economy	5300.00
0005435135789	33022	Economy	5300.00
0005434218067	9464	Economy	19700.00
0005434218069	9464	Economy	17900.00
0005434218063	9464	Economy	17900.00
0005434218064	9464	Economy	17900.00
0005434218068	9464	Economy	17900.00
0005433987176	24270	Business	36400.00
0005433962138	24270	Business	36400.00
0005433962172	24270	Business	36400.00
0005433962116	24270	Business	36400.00
0005433987178	24270	Business	36400.00
0005433987084	24270	Business	36400.00
0005433962120	24270	Business	36400.00
0005433962269	24270	Business	36400.00
0005433987120	24270	Business	36400.00
0005433987350	24270	Business	36400.00
0005433987164	24270	Business	36400.00
0005433986935	24270	Business	36400.00
0005433986926	24270	Business	36400.00
0005433962171	24270	Business	36400.00
0005433987161	24270	Business	36400.00
0005433987087	24270	Business	36400.00
0005433962196	24270	Business	36400.00
0005433962230	24270	Business	36400.00
0005433962212	24270	Business	36400.00
0005433987150	24270	Economy	13400.00
0005433962211	24270	Economy	13400.00
0005433987349	24270	Economy	13400.00
0005433987186	24270	Economy	12100.00
0005433962215	24270	Economy	12100.00
0005433987185	24270	Economy	12100.00
0005433962197	24270	Economy	12100.00
0005433987156	24270	Economy	12100.00
0005433962246	24270	Economy	12100.00
0005433962316	24270	Economy	12100.00
0005433987045	24270	Economy	12100.00
0005433987163	24270	Economy	12100.00
0005433987035	24270	Economy	12100.00
0005433987228	24270	Economy	12100.00
0005433987158	24270	Economy	12100.00
0005433962092	24270	Economy	12100.00
0005433961892	24270	Economy	12100.00
0005433987073	24270	Economy	12100.00
0005433962091	24270	Economy	12100.00
0005433986906	24270	Economy	12100.00
0005433962132	24270	Economy	12100.00
0005433962188	24270	Economy	12100.00
0005433962117	24270	Economy	12100.00
0005433962089	24270	Economy	12100.00
0005433962187	24270	Economy	12100.00
0005433962140	24270	Economy	12100.00
0005433962105	24270	Economy	12100.00
0005433987212	24270	Economy	12100.00
0005433962317	24270	Economy	12100.00
0005433986949	24270	Economy	12100.00
0005433987050	24270	Economy	12100.00
0005433987118	24270	Economy	12100.00
0005435860636	24270	Economy	12100.00
0005433987130	24270	Economy	12100.00
0005433986956	24270	Economy	12100.00
0005433962206	24270	Economy	12100.00
0005433962234	24270	Economy	12100.00
0005433987110	24270	Economy	12100.00
0005433986942	24270	Economy	12100.00
0005433987111	24270	Economy	12100.00
0005433962243	24270	Economy	12100.00
0005433987102	24270	Economy	12100.00
0005433962285	24270	Economy	12100.00
0005433962144	24270	Economy	12100.00
0005433962156	24270	Economy	12100.00
0005433987079	24270	Economy	12100.00
0005433987131	24270	Economy	12100.00
0005433987177	24270	Economy	12100.00
0005433987241	24270	Economy	12100.00
0005433962143	24270	Economy	12100.00
0005433962110	24270	Economy	12100.00
0005433962218	24270	Economy	12100.00
0005435860635	24270	Economy	12100.00
0005433962109	24270	Economy	12100.00
0005433987160	24270	Economy	12100.00
0005433986983	24270	Economy	12100.00
0005433987123	24270	Economy	12100.00
0005433986864	24270	Economy	12100.00
0005433962314	24270	Economy	12100.00
0005433962270	24270	Economy	12100.00
0005433987282	24270	Economy	13400.00
0005433987112	24270	Economy	12100.00
0005433986910	24270	Economy	12100.00
0005433962251	24270	Economy	13400.00
0005433962124	24270	Economy	13400.00
0005433962145	24270	Economy	12100.00
0005433987080	24270	Economy	12100.00
0005433961893	24270	Economy	12100.00
0005433987157	24270	Economy	12100.00
0005433962279	24270	Economy	12100.00
0005433962127	24270	Economy	12100.00
0005433962159	24270	Economy	12100.00
0005433986944	24270	Economy	12100.00
0005433962104	24270	Economy	12100.00
0005433962069	24270	Economy	12100.00
0005433962278	24270	Economy	12100.00
0005433962148	24270	Economy	12100.00
0005433962037	24270	Economy	12100.00
0005433962286	24270	Economy	12100.00
0005433986943	24270	Economy	12100.00
0005433986927	24270	Economy	12100.00
0005433962252	24270	Economy	12100.00
0005433987132	24270	Economy	12100.00
0005433987076	24270	Economy	12100.00
0005433987094	24270	Economy	12100.00
0005433962292	24270	Economy	12100.00
0005433962295	24270	Economy	12100.00
0005433962182	24270	Economy	12100.00
0005433986985	24270	Economy	12100.00
0005433962184	24270	Economy	12100.00
0005433962313	24270	Economy	12100.00
0005433962221	24270	Economy	12100.00
0005433962114	24270	Economy	12100.00
0005433962248	24270	Economy	12100.00
0005433962302	24270	Economy	12100.00
0005433987133	24270	Economy	12100.00
0005433962139	24270	Economy	12100.00
0005433962183	24270	Economy	12100.00
0005433962149	24270	Economy	12100.00
0005433987173	24270	Economy	12100.00
0005433987174	24270	Economy	12100.00
0005433961891	24270	Economy	12100.00
0005433987192	24270	Economy	12100.00
0005433987137	24270	Economy	12100.00
0005433962125	24270	Economy	12100.00
0005433962280	24270	Economy	12100.00
0005433987034	24270	Economy	12100.00
0005433962751	25961	Business	36400.00
0005433962739	25961	Business	36400.00
0005433987374	25961	Business	36400.00
0005433987376	25961	Economy	12100.00
0005433962734	25961	Economy	12100.00
0005433987375	25961	Economy	12100.00
0005433987377	25961	Economy	12100.00
0005433962747	25961	Economy	12100.00
0005433962743	25961	Economy	12100.00
0005433962736	25961	Economy	12100.00
0005433962733	25961	Economy	12100.00
0005433962746	25961	Economy	12100.00
0005433962744	25961	Economy	12100.00
0005433962737	25961	Economy	12100.00
0005433962750	25961	Economy	12100.00
0005433962740	25961	Economy	12100.00
0005433962745	25961	Economy	12100.00
0005433962731	25961	Economy	12100.00
0005433962735	25961	Economy	12100.00
0005433962738	25961	Economy	12100.00
0005433962741	25961	Economy	12100.00
0005433987373	25961	Economy	12100.00
0005433962749	25961	Economy	12100.00
0005433962742	25961	Economy	12100.00
0005433962748	25961	Economy	12100.00
0005433962732	25961	Economy	12100.00
0005433166247	921	Economy	25400.00
0005434481053	921	Economy	23100.00
0005433166221	921	Economy	23100.00
0005433166239	921	Economy	23100.00
0005433166258	921	Economy	23100.00
0005434481052	921	Economy	23100.00
0005433166266	921	Economy	23100.00
0005433166275	921	Economy	23100.00
0005434480883	16548	Economy	25400.00
0005434480937	16548	Economy	23100.00
0005434480950	16548	Economy	23100.00
0005434480972	16548	Economy	23100.00
0005434480996	16548	Economy	23100.00
0005434480949	16548	Economy	23100.00
0005434480975	16548	Economy	23100.00
0005434480929	16548	Economy	23100.00
0005434481011	16548	Economy	23100.00
0005434480880	16548	Economy	23100.00
0005434480901	16548	Economy	23100.00
0005434480848	16548	Economy	23100.00
0005434480914	16548	Economy	23100.00
0005434480920	16548	Economy	23100.00
0005434480982	16548	Economy	23100.00
0005434480948	16548	Economy	23100.00
0005434480913	16548	Economy	23100.00
0005434480973	16548	Economy	23100.00
0005434480974	16548	Economy	23100.00
0005434480930	16548	Economy	23100.00
0005434480938	16548	Economy	23100.00
0005434480801	16548	Economy	23100.00
0005434480802	16548	Economy	23100.00
0005435386721	10329	Economy	17000.00
0005435142968	10329	Economy	15400.00
0005435386737	10329	Economy	15400.00
0005435150433	10329	Economy	15400.00
0005435386720	10329	Economy	15400.00
0005435150435	10329	Economy	15400.00
0005435150436	10329	Economy	15400.00
0005435150437	10329	Economy	15400.00
0005435386741	10329	Economy	15400.00
0005435386725	10329	Economy	15400.00
0005435150434	10329	Economy	15400.00
0005435386713	10329	Economy	15400.00
0005435142828	21908	Economy	17000.00
0005435150363	21908	Economy	17000.00
0005435150302	21908	Economy	15400.00
0005435142890	21908	Economy	15400.00
0005435150370	21908	Economy	15400.00
0005435150328	21908	Economy	15400.00
0005435150355	21908	Economy	15400.00
0005435150359	21908	Economy	15400.00
0005435150398	21908	Economy	15400.00
0005435142949	21908	Economy	15400.00
0005435150358	21908	Economy	15400.00
0005435142889	21908	Economy	15400.00
0005435142905	21908	Economy	15400.00
0005435150368	21908	Economy	15400.00
0005435142928	21908	Economy	15400.00
0005433290066	21908	Economy	15400.00
0005435150308	21908	Economy	15400.00
0005435142916	21908	Economy	15400.00
0005435150372	21908	Economy	15400.00
0005435142857	21908	Economy	15400.00
0005435142906	21908	Economy	15400.00
0005435142933	21908	Economy	15400.00
0005435386763	21908	Economy	15400.00
0005435142861	21908	Economy	15400.00
0005435150316	21908	Economy	15400.00
0005435142898	21908	Economy	15400.00
0005435142856	21908	Economy	15400.00
0005435142816	21908	Economy	15400.00
0005435386764	21908	Economy	15400.00
0005435142917	21908	Economy	15400.00
0005435150369	21908	Economy	15400.00
0005435150303	21908	Economy	15400.00
0005435150311	21908	Economy	15400.00
0005435502882	11187	Business	57200.00
0005435529871	11187	Business	57200.00
0005435545898	11187	Business	57200.00
0005435529797	11187	Business	57200.00
0005435502826	11187	Business	57200.00
0005435319807	11187	Business	57200.00
0005435545890	11187	Business	57200.00
0005435545887	11187	Economy	19100.00
0005435502845	11187	Economy	19100.00
0005435502860	11187	Economy	19100.00
0005435529706	11187	Economy	19100.00
0005435502898	11187	Economy	21000.00
0005435502861	11187	Economy	21000.00
0005435319813	11187	Economy	21000.00
0005435319812	11187	Economy	19100.00
0005435529810	11187	Economy	19100.00
0005435529795	11187	Economy	19100.00
0005435319806	11187	Economy	19100.00
0005435502881	11187	Economy	19100.00
0005435319788	11187	Economy	19100.00
0005435529774	11187	Economy	19100.00
0005435319771	11187	Economy	19100.00
0005435502825	11187	Economy	19100.00
0005435529781	11187	Economy	19100.00
0005435319772	11187	Economy	19100.00
0005435545891	11187	Economy	19100.00
0005435502810	11187	Economy	19100.00
0005435502897	11187	Economy	19100.00
0005435529777	11187	Economy	19100.00
0005435502901	11187	Economy	19100.00
0005435319773	11187	Economy	19100.00
0005435545928	11187	Economy	19100.00
0005435502809	11187	Economy	19100.00
0005435502808	11187	Economy	19100.00
0005435502798	11187	Economy	19100.00
0005435502919	11187	Economy	19100.00
0005435529828	11187	Economy	19100.00
0005435319808	11187	Economy	19100.00
0005435529776	11187	Economy	19100.00
0005435319793	11187	Economy	19100.00
0005435529780	11187	Economy	19100.00
0005435319787	11187	Economy	19100.00
0005435529719	11187	Economy	19100.00
0005435502908	11187	Economy	19100.00
0005435502749	11187	Economy	19100.00
0005435529759	11187	Economy	19100.00
0005435529843	11187	Economy	19100.00
0005435502936	11187	Economy	19100.00
0005434573665	20925	Business	57200.00
0005434573658	20925	Business	57200.00
0005434573636	20925	Economy	19100.00
0005434573693	20925	Economy	19100.00
0005434573727	20925	Economy	19100.00
0005434573664	20925	Economy	19100.00
0005435508829	20925	Economy	19100.00
0005434573627	20925	Economy	19100.00
0005435502961	20925	Economy	19100.00
0005434573741	20925	Economy	19100.00
0005435508830	20925	Economy	19100.00
0005434573690	20925	Economy	19100.00
0005434573657	20925	Economy	19100.00
0005435508832	20925	Economy	19100.00
0005435502963	20925	Economy	19100.00
0005435502962	20925	Economy	19100.00
0005435508828	20925	Economy	19100.00
0005434573678	20925	Economy	19100.00
0005435508831	20925	Economy	19100.00
0005432693733	2965	Business	10300.00
0005432693831	2965	Business	10300.00
0005432693916	2965	Business	10300.00
0005432693860	2965	Business	10300.00
0005432693922	2965	Economy	3400.00
0005432693734	2965	Economy	3400.00
0005432693859	2965	Economy	3400.00
0005432693766	2965	Economy	3400.00
0005432693897	2965	Economy	3400.00
0005432693872	2965	Economy	3400.00
0005432693871	2965	Economy	3400.00
0005432693873	2965	Economy	3400.00
0005432693718	2965	Economy	3400.00
0005432693858	2965	Economy	3400.00
0005432693759	2965	Economy	3400.00
0005432693787	2965	Economy	3400.00
0005432693704	2965	Economy	3400.00
0005432693828	2965	Economy	3400.00
0005432693782	2965	Economy	3400.00
0005433124345	2964	Business	10300.00
0005433124370	2964	Business	10300.00
0005433124433	2964	Business	10300.00
0005433124371	2964	Economy	3400.00
0005433124423	2964	Economy	3400.00
0005432881201	2964	Economy	3400.00
0005433124365	2964	Economy	3400.00
0005432707510	2964	Economy	3400.00
0005432881167	2964	Economy	3400.00
0005432881192	2964	Economy	3800.00
0005432881189	2964	Economy	3800.00
0005433124390	2964	Economy	3800.00
0005433124416	2964	Economy	3400.00
0005433124434	2964	Economy	3400.00
0005434310183	2964	Economy	3400.00
0005433194972	2964	Economy	3400.00
0005433124409	2964	Economy	3400.00
0005433124372	2964	Economy	3400.00
0005433194954	2964	Economy	3400.00
0005433124412	2964	Economy	3400.00
0005433124377	2964	Economy	3400.00
0005432881193	2964	Economy	3400.00
0005433124376	2964	Economy	3400.00
0005432881190	2964	Economy	3400.00
0005434310185	2964	Economy	3400.00
0005434310184	2964	Economy	3400.00
0005433124404	2964	Economy	3400.00
0005432881122	2964	Economy	3400.00
0005432881217	2964	Economy	3400.00
0005432881188	2964	Economy	3400.00
0005433124458	2964	Economy	3400.00
0005433124358	2964	Economy	3400.00
0005433124463	2964	Economy	3400.00
0005433124408	2964	Economy	3400.00
0005432707442	29971	Business	10300.00
0005433124552	29971	Business	10300.00
0005432693970	29971	Business	10300.00
0005432707410	29971	Business	10300.00
0005432707381	29971	Business	10300.00
0005432707320	29971	Business	10300.00
0005432707411	29971	Economy	3400.00
0005432707472	29971	Economy	3400.00
0005432707412	29971	Economy	3400.00
0005432693971	29971	Economy	3800.00
0005432707432	29971	Economy	3800.00
0005432707473	29971	Economy	3400.00
0005433195015	29971	Economy	3400.00
0005432707391	29971	Economy	3400.00
0005432707338	29971	Economy	3400.00
0005432707453	29971	Economy	3400.00
0005432707358	29971	Economy	3400.00
0005432707422	29971	Economy	3400.00
0005433124551	29971	Economy	3400.00
0005432693973	29971	Economy	3400.00
0005432707445	29971	Economy	3400.00
0005432707452	29971	Economy	3400.00
0005432707401	29971	Economy	3400.00
0005432707421	29971	Economy	3400.00
0005432707382	29971	Economy	3400.00
0005432707459	29971	Economy	3400.00
0005432707361	29971	Economy	3400.00
0005432707466	29971	Economy	3400.00
0005432707402	29971	Economy	3400.00
0005432707392	29971	Economy	3400.00
0005432707454	29971	Economy	3400.00
0005432707444	29971	Economy	3400.00
0005432693972	29971	Economy	3400.00
0005432707460	29971	Economy	3400.00
0005432707437	29971	Economy	3400.00
0005432707486	29971	Economy	3400.00
0005434989120	23683	Economy	3600.00
0005434989128	23683	Economy	3600.00
0005434989118	23683	Economy	3600.00
0005434989123	23683	Economy	3600.00
0005434989119	23683	Economy	3600.00
0005434989130	23683	Economy	3600.00
0005434989122	23683	Economy	3600.00
0005434980677	23683	Economy	3600.00
0005434989126	23683	Economy	3600.00
0005434989125	23683	Economy	3600.00
0005434980676	23683	Economy	3600.00
0005434980675	23683	Economy	3600.00
0005434989129	23683	Economy	3600.00
0005434989127	23683	Economy	3600.00
0005434989121	23683	Economy	3600.00
0005434989124	23683	Economy	3600.00
0005434989030	27521	Economy	4000.00
0005434980551	27521	Economy	4000.00
0005434988988	27521	Economy	3600.00
0005434988991	27521	Economy	3600.00
0005434989021	27521	Economy	3600.00
0005434989016	27521	Economy	3600.00
0005434980452	27521	Economy	3600.00
0005434980439	27521	Economy	3600.00
0005434988974	27521	Economy	3600.00
0005434989003	27521	Economy	3600.00
0005434980441	27521	Economy	3600.00
0005434980440	27521	Economy	3600.00
0005434989004	27521	Economy	3600.00
0005434989000	27521	Economy	3600.00
0005434980494	27521	Economy	3600.00
0005434980593	27521	Economy	3600.00
0005434989028	27521	Economy	3600.00
0005434980451	27521	Economy	3600.00
0005434989010	27521	Economy	3600.00
0005434989007	27521	Economy	3600.00
0005434980423	27521	Economy	3600.00
0005434980420	27521	Economy	3600.00
0005434989011	27521	Economy	3600.00
0005434980535	27521	Economy	3600.00
0005434989002	27521	Economy	3600.00
0005434980495	27521	Economy	3600.00
0005434988960	27521	Economy	3600.00
0005434989005	27521	Economy	3600.00
0005434989027	27521	Economy	3600.00
0005434980456	27521	Economy	3600.00
0005434989001	27521	Economy	3600.00
0005434980562	27521	Economy	3600.00
0005434989031	27521	Economy	3600.00
0005434980536	27521	Economy	3600.00
0005434988990	27521	Economy	3600.00
0005434980478	27521	Economy	3600.00
0005434980445	27521	Economy	3600.00
0005434980561	27521	Economy	3600.00
0005434980557	27521	Economy	3600.00
0005434980546	27521	Economy	3600.00
0005434980533	27521	Economy	3600.00
0005434980491	27521	Economy	3600.00
0005434980496	27521	Economy	3600.00
0005433113578	10274	Economy	19700.00
0005434302552	19617	Economy	19700.00
0005435925632	3565	Business	26900.00
0005435070564	3565	Business	26900.00
0005435070565	3565	Business	26900.00
0005435925616	3565	Economy	9000.00
0005435719126	3565	Economy	9000.00
0005435925594	3565	Economy	9900.00
0005435925618	3565	Economy	9900.00
0005435925648	3565	Economy	9000.00
0005435925598	3565	Economy	9000.00
0005435925621	3565	Economy	9000.00
0005435719125	3565	Economy	9000.00
0005435070566	3565	Economy	9000.00
0005435925595	3565	Economy	9000.00
0005435925629	3565	Economy	9000.00
0005435925657	3565	Economy	9000.00
0005435925612	3565	Economy	9000.00
0005435925633	3565	Economy	9000.00
0005435925628	3565	Economy	9000.00
0005435925654	3565	Economy	9000.00
0005435925644	3565	Economy	9000.00
0005435950304	15303	Business	26900.00
0005435070059	15303	Business	26900.00
0005435070234	15303	Business	26900.00
0005435070420	15303	Business	26900.00
0005435939973	15303	Business	26900.00
0005435070286	15303	Business	26900.00
0005435070320	15303	Economy	9000.00
0005435070251	15303	Economy	9000.00
0005435070412	15303	Economy	9000.00
0005435070295	15303	Economy	9000.00
0005435070415	15303	Economy	9000.00
0005435070321	15303	Economy	9000.00
0005435950303	15303	Economy	9900.00
0005435070269	15303	Economy	9900.00
0005435070309	15303	Economy	9900.00
0005435950316	15303	Economy	9000.00
0005435070341	15303	Economy	9000.00
0005435070484	15303	Economy	9000.00
0005435939971	15303	Economy	9000.00
0005435070074	15303	Economy	9000.00
0005435070437	15303	Economy	9000.00
0005435939974	15303	Economy	9000.00
0005435070480	15303	Economy	9000.00
0005435070212	15303	Economy	9000.00
0005435925726	15303	Economy	9000.00
0005435070305	15303	Economy	9000.00
0005435070110	15303	Economy	9000.00
0005435070189	15303	Economy	9000.00
0005435939972	15303	Economy	9000.00
0005435070340	15303	Economy	9000.00
0005435070000	15303	Economy	9000.00
0005435070349	15303	Economy	9000.00
0005435070253	15303	Economy	9000.00
0005435070468	15303	Economy	9000.00
0005435070378	15303	Economy	9000.00
0005435070288	15303	Economy	9000.00
0005435069930	15303	Economy	9000.00
0005435070190	15303	Economy	9000.00
0005435070308	15303	Economy	9000.00
0005435070109	15303	Economy	9000.00
0005435070060	15303	Economy	9000.00
0005435070073	15303	Economy	9000.00
0005435070465	15303	Economy	9000.00
0005435070252	15303	Economy	9000.00
0005432667501	26447	Economy	5900.00
0005432660857	26447	Economy	5900.00
0005432667502	26447	Economy	5900.00
0005432664189	26447	Economy	5900.00
0005432660866	26447	Economy	5900.00
0005432667503	26447	Economy	5900.00
0005432902062	236	Business	20000.00
0005433103608	236	Business	20000.00
0005433103521	236	Business	20000.00
0005432902078	236	Business	20000.00
0005432920376	236	Business	20000.00
0005432920314	236	Business	20000.00
0005432902094	236	Business	20000.00
0005433103289	236	Business	20000.00
0005432920422	236	Business	20000.00
0005433103284	236	Business	20000.00
0005433103254	236	Business	20000.00
0005433103563	236	Business	20000.00
0005433103513	236	Business	20000.00
0005432920358	236	Business	20000.00
0005433103553	236	Business	20000.00
0005433103480	236	Business	20000.00
0005433103224	236	Economy	7300.00
0005433103596	236	Economy	7300.00
0005433103545	236	Economy	7300.00
0005433103396	236	Economy	7300.00
0005433103503	236	Economy	6700.00
0005433103601	236	Economy	6700.00
0005433103532	236	Economy	6700.00
0005433103607	236	Economy	6700.00
0005433103535	236	Economy	6700.00
0005433103552	236	Economy	6700.00
0005433103530	236	Economy	6700.00
0005432920382	236	Economy	6700.00
0005432920381	236	Economy	6700.00
0005432902036	236	Economy	6700.00
0005432920380	236	Economy	6700.00
0005433103473	236	Economy	6700.00
0005432920377	236	Economy	6700.00
0005433103506	236	Economy	6700.00
0005433103550	236	Economy	6700.00
0005433103500	236	Economy	6700.00
0005433103466	236	Economy	6700.00
0005432920357	236	Economy	6700.00
0005432902040	236	Economy	6700.00
0005432677671	236	Economy	6700.00
0005433103562	236	Economy	6700.00
0005432677659	236	Economy	6700.00
0005433103548	236	Economy	6700.00
0005432902037	236	Economy	6700.00
0005433103464	236	Economy	6700.00
0005433103342	236	Economy	6700.00
0005432902075	236	Economy	6700.00
0005432920424	236	Economy	6700.00
0005432920444	236	Economy	6700.00
0005432920425	236	Economy	6700.00
0005433103395	236	Economy	6700.00
0005433103549	236	Economy	6700.00
0005433103559	236	Economy	6700.00
0005432902035	236	Economy	6700.00
0005433103285	236	Economy	7300.00
0005432920427	236	Economy	7300.00
0005433103292	236	Economy	7300.00
0005432920406	236	Economy	6700.00
0005432902039	236	Economy	6700.00
0005433103465	236	Economy	6700.00
0005432920442	236	Economy	7300.00
0005432902063	236	Economy	6700.00
0005433103512	236	Economy	6700.00
0005433103533	236	Economy	6700.00
0005433103534	236	Economy	6700.00
0005433103443	236	Economy	6700.00
0005433103517	236	Economy	6700.00
0005432902060	236	Economy	6700.00
0005433103516	236	Economy	6700.00
0005433103499	236	Economy	6700.00
0005433103542	236	Economy	6700.00
0005433103492	236	Economy	6700.00
0005433103510	236	Economy	6700.00
0005432677683	236	Economy	6700.00
0005433103602	236	Economy	6700.00
0005432920430	236	Economy	6700.00
0005433103504	236	Economy	6700.00
0005433103589	236	Economy	6700.00
0005432920313	236	Economy	6700.00
0005433103543	236	Economy	6700.00
0005433103511	236	Economy	6700.00
0005433103531	236	Economy	6700.00
0005432677684	236	Economy	6700.00
0005433103176	236	Economy	6700.00
0005433103368	236	Economy	6700.00
0005433103603	236	Economy	6700.00
0005433103522	236	Economy	6700.00
0005432902074	236	Economy	6700.00
0005432920423	236	Economy	6700.00
0005433103363	236	Economy	6700.00
0005432920408	236	Economy	6700.00
0005433103546	236	Economy	6700.00
0005433103525	236	Economy	6700.00
0005433103428	236	Economy	6700.00
0005434157959	235	Business	20000.00
0005434157977	235	Business	20000.00
0005434157979	235	Business	20000.00
0005432753386	235	Business	20000.00
0005434157968	235	Business	20000.00
0005434157967	235	Business	20000.00
0005433477293	235	Business	20000.00
0005434157961	235	Economy	7300.00
0005434157981	235	Economy	7300.00
0005433687754	235	Economy	6700.00
0005432753388	235	Economy	6700.00
0005432753379	235	Economy	6700.00
0005434157969	235	Economy	6700.00
0005434157982	235	Economy	6700.00
0005434153585	235	Economy	6700.00
0005434191330	235	Economy	6700.00
0005432263232	235	Economy	6700.00
0005432263231	235	Economy	6700.00
0005434157963	235	Economy	6700.00
0005434152872	235	Economy	6700.00
0005434157964	235	Economy	6700.00
0005432753371	235	Economy	6700.00
0005435987066	235	Economy	6700.00
0005432756923	235	Economy	6700.00
0005434157976	235	Economy	6700.00
0005432289085	235	Economy	6700.00
0005434157958	235	Economy	6700.00
0005434157978	235	Economy	6700.00
0005434157975	235	Economy	6700.00
0005434157971	235	Economy	6700.00
0005434157965	235	Economy	6700.00
0005434157960	235	Economy	6700.00
0005434157966	235	Economy	6700.00
0005432753380	235	Economy	6700.00
0005434157957	235	Economy	6700.00
0005434152873	235	Economy	6700.00
0005433687760	235	Economy	6700.00
0005434157973	235	Economy	6700.00
0005435987065	235	Economy	6700.00
0005434157962	235	Economy	6700.00
0005434157980	235	Economy	6700.00
0005432289086	235	Economy	6700.00
0005434153586	235	Economy	6700.00
0005433477292	235	Economy	6700.00
0005433690969	235	Economy	6700.00
0005434157970	235	Economy	6700.00
0005433687759	235	Economy	6700.00
0005432753381	235	Economy	6700.00
0005434157983	235	Economy	6700.00
0005432818336	235	Economy	6700.00
0005434157972	235	Economy	6700.00
0005434157974	235	Economy	6700.00
0005433687737	235	Economy	6700.00
0005433477269	8064	Business	20000.00
0005432392084	8064	Business	20000.00
0005434152857	8064	Business	20000.00
0005433103989	8064	Business	20000.00
0005433477190	8064	Business	20000.00
0005433477268	8064	Business	20000.00
0005433477212	8064	Business	20000.00
0005433103987	8064	Business	20000.00
0005433477117	8064	Business	20000.00
0005433435531	8064	Business	20000.00
0005433103993	8064	Business	20000.00
0005432677691	8064	Business	20000.00
0005432021050	8064	Business	20000.00
0005434157717	8064	Economy	7300.00
0005433477163	8064	Economy	6700.00
0005433477058	8064	Economy	6700.00
0005432392085	8064	Economy	6700.00
0005434152858	8064	Economy	6700.00
0005433477186	8064	Economy	6700.00
0005433477069	8064	Economy	6700.00
0005432677692	8064	Economy	6700.00
0005433103990	8064	Economy	6700.00
0005434152860	8064	Economy	6700.00
0005433477270	8064	Economy	6700.00
0005433477164	8064	Economy	6700.00
0005434157722	8064	Economy	6700.00
0005433477205	8064	Economy	6700.00
0005433477194	8064	Economy	6700.00
0005433435532	8064	Economy	6700.00
0005433477134	8064	Economy	6700.00
0005433477213	8064	Economy	6700.00
0005433477206	8064	Economy	6700.00
0005434157716	8064	Economy	6700.00
0005433477128	8064	Economy	6700.00
0005433477197	8064	Economy	6700.00
0005432920480	8064	Economy	6700.00
0005433477167	8064	Economy	6700.00
0005433929897	8064	Economy	7300.00
0005433477226	8064	Economy	7300.00
0005433477015	8064	Economy	6700.00
0005434152859	8064	Economy	7300.00
0005433477123	8064	Economy	6700.00
0005433477056	8064	Economy	6700.00
0005433477172	8064	Economy	6700.00
0005433477048	8064	Economy	6700.00
0005433477173	8064	Economy	6700.00
0005434157718	8064	Economy	6700.00
0005433477168	8064	Economy	6700.00
0005433477198	8064	Economy	6700.00
0005433103991	8064	Economy	6700.00
0005433477182	8064	Economy	6700.00
0005433103992	8064	Economy	6700.00
0005433477187	8064	Economy	6700.00
0005433477135	8064	Economy	6700.00
0005433477116	8064	Economy	6700.00
0005433477138	8064	Economy	6700.00
0005433477133	8064	Economy	6700.00
0005433477132	8064	Economy	6700.00
0005433477127	8064	Economy	6700.00
0005433477124	8064	Economy	6700.00
0005433103988	8064	Economy	6700.00
0005433477183	8064	Economy	6700.00
0005433477129	8064	Economy	6700.00
0005433477016	8064	Economy	6700.00
0005433477066	8064	Economy	6700.00
0005433477049	8064	Economy	6700.00
0005433477094	8064	Economy	6700.00
0005433477057	8064	Economy	6700.00
0005433477191	8064	Economy	6700.00
0005432818225	8063	Business	20000.00
0005432818260	8063	Business	20000.00
0005432818196	8063	Business	20000.00
0005432818232	8063	Business	20000.00
0005432818204	8063	Economy	7300.00
0005432818221	8063	Economy	6700.00
0005432818205	8063	Economy	6700.00
0005432902125	8063	Economy	6700.00
0005432818131	8063	Economy	6700.00
0005432818059	8063	Economy	6700.00
0005432818060	8063	Economy	6700.00
0005432818150	8063	Economy	6700.00
0005432818203	8063	Economy	6700.00
0005432818058	8063	Economy	6700.00
0005432818149	8063	Economy	6700.00
0005432818233	8063	Economy	7300.00
0005432818061	8063	Economy	6700.00
0005432818231	8063	Economy	6700.00
0005432818220	8063	Economy	6700.00
0005432818105	8063	Economy	6700.00
0005432818172	8063	Economy	6700.00
0005432818065	8063	Economy	6700.00
0005433870800	9695	Economy	6900.00
0005434175865	9695	Economy	6900.00
0005434175864	9695	Economy	6900.00
0005433870781	32327	Economy	6900.00
0005435914745	3513	Business	35000.00
0005435903164	3513	Business	35000.00
0005435914752	3513	Business	35000.00
0005435626863	3513	Business	35000.00
0005435626864	3513	Business	35000.00
0005435914105	3513	Business	35000.00
0005435914751	3513	Comfort	19900.00
0005434880988	3513	Comfort	19900.00
0005435903162	3513	Comfort	19900.00
0005434427472	3513	Comfort	19900.00
0005435914151	3513	Comfort	19900.00
0005435903153	3513	Comfort	19900.00
0005432800286	3513	Comfort	19900.00
0005435903150	3513	Comfort	19900.00
0005435903137	3513	Economy	11700.00
0005435914103	3513	Economy	11700.00
0005435127587	3513	Economy	11700.00
0005435841844	3513	Economy	11700.00
0005435903152	3513	Economy	11700.00
0005435626866	3513	Economy	11700.00
0005435903056	3513	Economy	11700.00
0005435903132	3513	Economy	12800.00
0005435903163	3513	Economy	11700.00
0005435903167	3513	Economy	11700.00
0005435914744	3513	Economy	11700.00
0005435914157	3513	Economy	11700.00
0005435914102	3513	Economy	11700.00
0005435841847	3513	Economy	11700.00
0005435914104	3513	Economy	11700.00
0005435914101	3513	Economy	11700.00
0005435903177	3513	Economy	11700.00
0005435914055	3513	Economy	11700.00
0005435127586	3513	Economy	11700.00
0005432800290	3513	Economy	11700.00
0005435914118	3513	Economy	11700.00
0005435841119	3513	Economy	11700.00
0005434938721	3513	Economy	11700.00
0005435903170	3513	Economy	11700.00
0005435903138	3513	Economy	11700.00
0005435127585	3513	Economy	11700.00
0005435914054	3513	Economy	11700.00
0005435903083	3513	Economy	11700.00
0005435914757	3513	Economy	11700.00
0005435841845	3513	Economy	11700.00
0005435626865	3513	Economy	11700.00
0005435914156	3513	Economy	11700.00
0005435914083	3513	Economy	12800.00
0005432800287	3513	Economy	11700.00
0005432800288	3513	Economy	11700.00
0005435903151	3513	Economy	11700.00
0005435903133	3513	Economy	11700.00
0005435903185	3513	Economy	11700.00
0005435914106	3513	Economy	11700.00
0005435914016	3513	Economy	11700.00
0005434880986	3513	Economy	11700.00
0005435903146	3513	Economy	11700.00
0005435626867	3513	Economy	11700.00
0005435914082	3513	Economy	11700.00
0005435903125	3513	Economy	11700.00
0005435903176	3513	Economy	11700.00
0005434880987	3513	Economy	11700.00
0005435914072	3513	Economy	11700.00
0005435914056	3513	Economy	11700.00
0005432800289	3513	Economy	11700.00
0005435914753	3513	Economy	11700.00
0005435903166	3513	Economy	11700.00
0005435903055	3513	Economy	11700.00
0005435903147	3513	Economy	11700.00
0005432800139	14575	Business	35000.00
0005434880464	14575	Business	35000.00
0005434938671	14575	Business	35000.00
0005434880534	14575	Business	35000.00
0005434938640	14575	Business	35000.00
0005434880138	14575	Business	35000.00
0005434880609	14575	Business	35000.00
0005434880494	14575	Business	35000.00
0005435626636	14575	Business	35000.00
0005434880226	14575	Business	35000.00
0005434880549	14575	Business	35000.00
0005434427439	14575	Business	35000.00
0005432800026	14575	Business	35000.00
0005435626632	14575	Business	35000.00
0005435127453	14575	Business	35000.00
0005434880691	14575	Comfort	19900.00
0005434880418	14575	Business	35000.00
0005435127315	14575	Comfort	19900.00
0005434880651	14575	Comfort	19900.00
0005435127278	14575	Comfort	19900.00
0005434938634	14575	Comfort	19900.00
0005434880808	14575	Comfort	19900.00
0005435626541	14575	Comfort	19900.00
0005435626540	14575	Comfort	19900.00
0005434427310	14575	Comfort	19900.00
0005435626679	14575	Comfort	19900.00
0005434427416	14575	Comfort	19900.00
0005434880619	14575	Comfort	19900.00
0005434880710	14575	Comfort	19900.00
0005434880681	14575	Comfort	19900.00
0005434880490	14575	Comfort	19900.00
0005434427417	14575	Comfort	19900.00
0005432800048	14575	Comfort	19900.00
0005434879967	14575	Comfort	19900.00
0005434427375	14575	Comfort	19900.00
0005434880738	14575	Comfort	19900.00
0005434427263	14575	Comfort	19900.00
0005434880173	14575	Comfort	19900.00
0005434880565	14575	Comfort	19900.00
0005435626678	14575	Comfort	19900.00
0005434880537	14575	Comfort	19900.00
0005434938609	14575	Comfort	19900.00
0005432800161	14575	Comfort	19900.00
0005434427388	14575	Comfort	19900.00
0005434880739	14575	Comfort	19900.00
0005435127409	14575	Comfort	19900.00
0005434880308	14575	Comfort	19900.00
0005434880533	14575	Comfort	19900.00
0005435626637	14575	Comfort	19900.00
0005434880720	14575	Economy	11700.00
0005432800179	14575	Economy	11700.00
0005435127276	14575	Economy	11700.00
0005434880684	14575	Economy	11700.00
0005434880685	14575	Economy	11700.00
0005435127452	14575	Economy	11700.00
0005435127302	14575	Economy	11700.00
0005434427374	14575	Economy	11700.00
0005434880630	14575	Economy	11700.00
0005435626662	14575	Economy	11700.00
0005435626658	14575	Economy	11700.00
0005435127337	14575	Economy	11700.00
0005434880557	14575	Economy	11700.00
0005434938594	14575	Economy	11700.00
0005434880719	14575	Economy	11700.00
0005434880650	14575	Economy	11700.00
0005434880499	14575	Economy	11700.00
0005434938654	14575	Economy	11700.00
0005434427251	14575	Economy	11700.00
0005434427349	14575	Economy	11700.00
0005434880500	14575	Economy	11700.00
0005434880475	14575	Economy	11700.00
0005434880227	14575	Economy	11700.00
0005434880342	14575	Economy	11700.00
0005434880289	14575	Economy	11700.00
0005435127410	14575	Economy	11700.00
0005434880744	14575	Economy	11700.00
0005434938627	14575	Economy	11700.00
0005434427311	14575	Economy	11700.00
0005434880383	14575	Economy	11700.00
0005434427306	14575	Economy	11700.00
0005434880343	14575	Economy	11700.00
0005435127345	14575	Economy	11700.00
0005434880476	14575	Economy	11700.00
0005435127259	14575	Economy	11700.00
0005435127347	14575	Economy	11700.00
0005434880610	14575	Economy	11700.00
0005434880804	14575	Economy	11700.00
0005434880618	14575	Economy	11700.00
0005434427305	14575	Economy	11700.00
0005434880750	14575	Economy	12800.00
0005435127370	14575	Economy	12800.00
0005434427321	14575	Economy	11700.00
0005434880315	14575	Economy	11700.00
0005434880689	14575	Economy	11700.00
0005435127348	14575	Economy	12800.00
0005434880665	14575	Economy	11700.00
0005434880403	14575	Economy	12800.00
0005435626666	14575	Economy	11700.00
0005434427324	14575	Economy	11700.00
0005434880401	14575	Economy	11700.00
0005435127346	14575	Economy	11700.00
0005434880815	14575	Economy	11700.00
0005434880624	14575	Economy	11700.00
0005435127254	14575	Economy	11700.00
0005434938673	14575	Economy	11700.00
0005434880736	14575	Economy	11700.00
0005435626588	14575	Economy	11700.00
0005434880536	14575	Economy	11700.00
0005434880683	14575	Economy	11700.00
0005434427376	14575	Economy	11700.00
0005434880600	14575	Economy	11700.00
0005435626587	14575	Economy	11700.00
0005432800100	14575	Economy	11700.00
0005434880055	14575	Economy	11700.00
0005434938675	14575	Economy	11700.00
0005435626688	14575	Economy	11700.00
0005432800234	14575	Economy	11700.00
0005434880478	14575	Economy	11700.00
0005434880493	14575	Economy	11700.00
0005432800166	14575	Economy	11700.00
0005435626663	14575	Economy	11700.00
0005434938662	14575	Economy	11700.00
0005434880501	14575	Economy	11700.00
0005434938610	14575	Economy	11700.00
0005435127314	14575	Economy	11700.00
0005434880779	14575	Economy	11700.00
0005434880212	14575	Economy	11700.00
0005434880740	14575	Economy	11700.00
0005434880326	14575	Economy	11700.00
0005434938653	14575	Economy	11700.00
0005434938616	14575	Economy	11700.00
0005434880228	14575	Economy	11700.00
0005435626670	14575	Economy	11700.00
0005434880316	14575	Economy	11700.00
0005434880400	14575	Economy	11700.00
0005434938626	14575	Economy	11700.00
0005434880385	14575	Economy	11700.00
0005435626657	14575	Economy	11700.00
0005435127277	14575	Economy	11700.00
0005435626680	14575	Economy	11700.00
0005434880581	14575	Economy	11700.00
0005434427418	14575	Economy	11700.00
0005435127260	14575	Economy	11700.00
0005434880213	14575	Economy	11700.00
0005435626635	14575	Economy	11700.00
0005434938676	14575	Economy	11700.00
0005434880246	14575	Economy	11700.00
0005435127454	14575	Economy	11700.00
0005434880399	14575	Economy	11700.00
0005434880608	14575	Economy	11700.00
0005434427316	14575	Economy	11700.00
0005434880293	14575	Economy	11700.00
0005434938669	14575	Economy	11700.00
0005434880783	14575	Economy	11700.00
0005434427391	14575	Economy	11700.00
0005435127305	14575	Economy	11700.00
0005432800198	14575	Economy	11700.00
0005434938684	14575	Economy	11700.00
0005432800049	14575	Economy	11700.00
0005435626681	14575	Economy	11700.00
0005434880479	14575	Economy	11700.00
0005434880751	14575	Economy	11700.00
0005434427279	14575	Economy	11700.00
0005435127253	14575	Economy	11700.00
0005434880568	14575	Economy	11700.00
0005434880799	14575	Economy	11700.00
0005435127375	14575	Economy	11700.00
0005434880329	14575	Economy	11700.00
0005434880477	14575	Economy	11700.00
0005432800027	14575	Economy	11700.00
0005434938545	14575	Economy	11700.00
0005434880425	14575	Economy	11700.00
0005434938642	14575	Economy	11700.00
0005434880737	14575	Economy	11700.00
0005435127336	14575	Economy	11700.00
0005434427323	14575	Economy	12800.00
0005432800242	14575	Economy	12800.00
0005435626627	14575	Economy	12800.00
0005435127402	14575	Economy	11700.00
0005434880413	14575	Economy	11700.00
0005434880436	14575	Economy	11700.00
0005434880567	14575	Economy	11700.00
0005434427320	14575	Economy	11700.00
0005434880560	14575	Economy	11700.00
0005432607653	14575	Economy	11700.00
0005434880426	14575	Economy	11700.00
0005434880209	14575	Economy	11700.00
0005434880216	14575	Economy	11700.00
0005434880288	14575	Economy	11700.00
0005434880688	14575	Economy	11700.00
0005435127279	14575	Economy	11700.00
0005434938661	14575	Economy	11700.00
0005434427453	14575	Economy	11700.00
0005434880589	14575	Economy	11700.00
0005435127344	14575	Economy	11700.00
0005434938597	14575	Economy	11700.00
0005434880305	14575	Economy	11700.00
0005434880341	14575	Economy	11700.00
0005434880292	14575	Economy	11700.00
0005432800127	14575	Economy	11700.00
0005434427346	14575	Economy	11700.00
0005434880556	14575	Economy	11700.00
0005434938674	14575	Economy	11700.00
0005432800114	14575	Economy	11700.00
0005435841852	14575	Economy	11700.00
0005434880588	14575	Economy	11700.00
0005434880327	14575	Economy	11700.00
0005434880780	14575	Economy	11700.00
0005434938672	14575	Economy	11700.00
0005435127291	14575	Economy	11700.00
0005434880711	14575	Economy	11700.00
0005434880437	14575	Economy	11700.00
0005435127326	14575	Economy	11700.00
0005434880782	14575	Economy	11700.00
0005434938635	14575	Economy	11700.00
0005434880373	14575	Economy	11700.00
0005435626638	14575	Economy	11700.00
0005434880129	14575	Economy	11700.00
0005434880384	14575	Economy	11700.00
0005434427252	14575	Economy	11700.00
0005434427390	14575	Economy	11700.00
0005434938655	14575	Economy	11700.00
0005434880805	14575	Economy	11700.00
0005434938617	14575	Economy	11700.00
0005434427406	14575	Economy	11700.00
0005435841851	14575	Economy	11700.00
0005434880415	14575	Economy	11700.00
0005434880330	14575	Economy	11700.00
0005435127179	14575	Economy	11700.00
0005432800165	14575	Economy	11700.00
0005435626677	14575	Economy	11700.00
0005434938641	14575	Economy	11700.00
0005434880580	14575	Economy	11700.00
0005434880686	14575	Economy	11700.00
0005434880781	14575	Economy	11700.00
0005432800160	14575	Economy	11700.00
0005435127386	14575	Economy	11700.00
0005434880435	14575	Economy	11700.00
0005434880749	14575	Economy	11700.00
0005434427315	14575	Economy	11700.00
0005435127304	14575	Economy	11700.00
0005435890043	3616	Economy	14800.00
0005434325985	3616	Economy	14800.00
0005435890044	3616	Economy	14800.00
0005434325948	15605	Economy	16300.00
0005434325927	15605	Economy	16300.00
0005434325950	15605	Economy	14800.00
0005434325941	15605	Economy	14800.00
0005435890076	15605	Economy	14800.00
0005434312389	15605	Economy	14800.00
0005434325955	15605	Economy	14800.00
0005434312390	15605	Economy	14800.00
0005434312387	15605	Economy	14800.00
0005434325940	15605	Economy	14800.00
0005433420628	612	Economy	4100.00
0005435958131	612	Economy	4100.00
0005433420610	612	Economy	4100.00
0005433420621	612	Economy	4100.00
0005433420625	612	Economy	4100.00
0005433420620	612	Economy	4100.00
0005433420608	612	Economy	4100.00
0005433420584	612	Economy	4100.00
0005433420629	612	Economy	4100.00
0005435958035	15210	Economy	4100.00
0005435958054	15210	Economy	4100.00
0005435958059	15210	Economy	4100.00
0005435958065	15210	Economy	4100.00
0005435958097	15210	Economy	4100.00
0005435957989	15210	Economy	4100.00
0005435958094	15210	Economy	4100.00
0005435958096	15210	Economy	4100.00
0005435958064	15210	Economy	4100.00
0005433420650	15210	Economy	4100.00
0005435958080	15210	Economy	4100.00
0005434995345	23998	Business	94000.00
0005434995346	23998	Business	94000.00
0005434995351	23998	Business	94000.00
0005434995339	23998	Economy	31300.00
0005434995350	23998	Economy	31300.00
0005434995340	23998	Economy	31300.00
0005434995341	23998	Economy	31300.00
0005434995343	23998	Economy	31300.00
0005434995344	23998	Economy	31300.00
0005434995347	23998	Economy	31300.00
0005434995352	23998	Economy	31300.00
0005434995353	23998	Economy	31300.00
0005434995342	23998	Economy	31300.00
0005434995349	23998	Economy	31300.00
0005434995348	23998	Economy	31300.00
0005434995335	23998	Economy	31300.00
0005434247213	8938	Economy	10400.00
0005435629449	8938	Economy	10400.00
0005434247205	8938	Economy	10400.00
0005435629444	16085	Economy	10400.00
0005435629443	16085	Economy	10400.00
0005435629442	16085	Economy	10400.00
0005435629441	16085	Economy	10400.00
0005435629440	16085	Economy	10400.00
0005433404995	2849	Business	12600.00
0005433404969	2849	Business	12600.00
0005433404996	2849	Economy	4200.00
0005433404994	2849	Economy	4200.00
0005435797897	2849	Economy	4200.00
0005433405016	2849	Economy	4200.00
0005433404984	2849	Economy	4200.00
0005435797837	29350	Business	12600.00
0005435797834	29350	Business	12600.00
0005435797847	29350	Economy	4200.00
0005435797850	29350	Economy	4200.00
0005435797849	29350	Economy	4200.00
0005435797838	29350	Economy	4200.00
0005435797835	29350	Economy	4200.00
0005435797868	29350	Economy	4200.00
0005435797803	29350	Economy	4200.00
0005435797794	29350	Economy	4200.00
0005435797867	29350	Economy	4200.00
0005435797836	29350	Economy	4200.00
0005435376411	5844	Economy	6800.00
0005434948207	16347	Economy	6800.00
0005434948223	16347	Economy	6800.00
0005434948208	16347	Economy	6800.00
0005434948253	16347	Economy	6800.00
0005434948252	16347	Economy	6800.00
0005433962759	6938	Business	21400.00
0005433962752	6938	Business	21400.00
0005433962753	6938	Business	21400.00
0005433962755	6938	Economy	7800.00
0005433962754	6938	Economy	7100.00
0005435787478	6938	Economy	7100.00
0005433962761	6938	Economy	7100.00
0005433962760	6938	Economy	7100.00
0005433962756	6938	Economy	7100.00
0005435787479	6938	Economy	7100.00
0005433962757	6938	Economy	7100.00
0005433962763	6938	Economy	7100.00
0005433962764	6938	Economy	7100.00
0005433962758	6938	Economy	7100.00
0005433962762	6938	Economy	7100.00
0005433961919	25760	Business	21400.00
0005433961926	25760	Business	21400.00
0005433962258	25760	Business	21400.00
0005433962257	25760	Business	21400.00
0005433962240	25760	Business	21400.00
0005433961956	25760	Business	21400.00
0005433962153	25760	Economy	7100.00
0005433962164	25760	Economy	7100.00
0005433962045	25760	Economy	7100.00
0005433962160	25760	Economy	7100.00
0005433962235	25760	Economy	7100.00
0005433962178	25760	Economy	7100.00
0005433962262	25760	Economy	7100.00
0005433962162	25760	Economy	7100.00
0005433962177	25760	Economy	7800.00
0005433962076	25760	Economy	7800.00
0005433962265	25760	Economy	7800.00
0005433962163	25760	Economy	7800.00
0005433962131	25760	Economy	7800.00
0005433962176	25760	Economy	7100.00
0005433962135	25760	Economy	7100.00
0005433962080	25760	Economy	7100.00
0005433962189	25760	Economy	7100.00
0005433962051	25760	Economy	7100.00
0005433962202	25760	Economy	7100.00
0005433962239	25760	Economy	7100.00
0005433962199	25760	Economy	7100.00
0005433962244	25760	Economy	7100.00
0005433962193	25760	Economy	7100.00
0005433962170	25760	Economy	7100.00
0005433962217	25760	Economy	7100.00
0005433962034	25760	Economy	7100.00
0005433962181	25760	Economy	7100.00
0005433962198	25760	Economy	7100.00
0005433962154	25760	Economy	7100.00
0005433962050	25760	Economy	7100.00
0005433962046	25760	Economy	7100.00
0005433962133	25760	Economy	7100.00
0005433962150	25760	Economy	7100.00
0005433962168	25760	Economy	7100.00
0005433962038	25760	Economy	7100.00
0005433962191	25760	Economy	7100.00
0005433962224	25760	Economy	7100.00
0005433962205	25760	Economy	7100.00
0005433962231	25760	Economy	7100.00
0005433962043	25760	Economy	7100.00
0005433962213	25760	Economy	7100.00
0005433962216	25760	Economy	7100.00
0005433962169	25760	Economy	7100.00
0005433962141	25760	Economy	7100.00
0005433962130	25760	Economy	7100.00
0005433962190	25760	Economy	7100.00
0005433962157	25760	Economy	7100.00
0005433962088	25760	Economy	7100.00
0005433962245	25760	Economy	7100.00
0005433961955	25760	Economy	7100.00
0005433962214	25760	Economy	7100.00
0005433962238	25760	Economy	7100.00
0005433962039	25760	Economy	7100.00
0005435082998	24461	Economy	3900.00
0005435082996	24461	Economy	3900.00
0005435082990	24461	Economy	3900.00
0005435082969	24461	Economy	3900.00
0005435082989	24461	Economy	3900.00
0005435082952	24461	Economy	3900.00
0005435083037	26102	Economy	3900.00
0005435083036	26102	Economy	3900.00
0005435083035	26102	Economy	3900.00
0005435083038	26102	Economy	3900.00
0005434245847	5078	Business	18000.00
0005435286810	5078	Business	18000.00
0005435286796	5078	Business	18000.00
0005435286746	5078	Economy	6600.00
0005435286772	5078	Economy	6000.00
0005435286753	5078	Economy	6000.00
0005434245846	5078	Economy	6000.00
0005435286771	5078	Economy	6000.00
0005435286760	5078	Economy	6000.00
0005435286786	5078	Economy	6000.00
0005435286747	5078	Economy	6000.00
0005433534546	5078	Economy	6000.00
0005435286808	5078	Economy	6000.00
0005435286763	5078	Economy	6000.00
0005435286809	5078	Economy	6000.00
0005435286793	5078	Economy	6000.00
0005435286748	5078	Economy	6000.00
0005435286785	5078	Economy	6000.00
0005435286790	5078	Economy	6000.00
0005433616828	5079	Business	18000.00
0005434230265	5079	Business	18000.00
0005433786197	5079	Business	18000.00
0005432106954	5079	Business	18000.00
0005433786193	5079	Business	18000.00
0005434230253	5079	Economy	6000.00
0005434230261	5079	Economy	6000.00
0005433616830	5079	Economy	6000.00
0005434230270	5079	Economy	6000.00
0005434230255	5079	Economy	6000.00
0005434230267	5079	Economy	6000.00
0005434230252	5079	Economy	6000.00
0005433786192	5079	Economy	6000.00
0005434230266	5079	Economy	6000.00
0005433616829	5079	Economy	6000.00
0005434230260	5079	Economy	6000.00
0005432666449	5079	Economy	6000.00
0005434230258	5079	Economy	6000.00
0005433786195	5079	Economy	6600.00
0005434230259	5079	Economy	6000.00
0005434230262	5079	Economy	6000.00
0005433786198	5079	Economy	6000.00
0005433786194	5079	Economy	6000.00
0005433786196	5079	Economy	6000.00
0005434230257	5079	Economy	6000.00
0005434230264	5079	Economy	6000.00
0005434230256	5079	Economy	6000.00
0005434230268	5079	Economy	6000.00
0005434230263	5079	Economy	6000.00
0005434230269	5079	Economy	6000.00
0005434230254	5079	Economy	6000.00
0005435270125	5081	Business	18000.00
0005435270107	5081	Business	18000.00
0005435270098	5081	Business	18000.00
0005435270155	5081	Business	18000.00
0005435007652	5081	Business	18000.00
0005433815508	5081	Business	18000.00
0005435007508	5081	Business	18000.00
0005435007616	5081	Business	18000.00
0005435007620	5081	Business	18000.00
0005435007641	5081	Business	18000.00
0005435007676	5081	Business	18000.00
0005435007581	5081	Business	18000.00
0005434173635	5081	Economy	6600.00
0005435007509	5081	Economy	6600.00
0005433815503	5081	Economy	6600.00
0005435007594	5081	Economy	6000.00
0005432336322	5081	Economy	6000.00
0005435007687	5081	Economy	6000.00
0005435270072	5081	Economy	6000.00
0005435007642	5081	Economy	6000.00
0005432336306	5081	Economy	6000.00
0005435269927	5081	Economy	6000.00
0005435007659	5081	Economy	6000.00
0005435270105	5081	Economy	6000.00
0005435269971	5081	Economy	6000.00
0005433685569	5081	Economy	6000.00
0005435269945	5081	Economy	6000.00
0005435270073	5081	Economy	6000.00
0005435007638	5081	Economy	6000.00
0005434311267	5081	Economy	6000.00
0005435269959	5081	Economy	6000.00
0005435007566	5081	Economy	6000.00
0005435269990	5081	Economy	6000.00
0005435007639	5081	Economy	6000.00
0005433815489	5081	Economy	6000.00
0005434265898	5081	Economy	6000.00
0005435270007	5081	Economy	6000.00
0005434311263	5081	Economy	6000.00
0005433815515	5081	Economy	6000.00
0005435007621	5081	Economy	6000.00
0005433685567	5081	Economy	6000.00
0005435270099	5081	Economy	6000.00
0005435270134	5081	Economy	6000.00
0005432336320	5081	Economy	6000.00
0005435270075	5081	Economy	6000.00
0005434230042	5081	Economy	6600.00
0005434265899	5081	Economy	6600.00
0005435270079	5081	Economy	6600.00
0005435270097	5081	Economy	6600.00
0005435270006	5081	Economy	6000.00
0005435007613	5081	Economy	6000.00
0005435270135	5081	Economy	6000.00
0005435270049	5081	Economy	6000.00
0005435007576	5081	Economy	6000.00
0005435007640	5081	Economy	6000.00
0005435007567	5081	Economy	6000.00
0005433815504	5081	Economy	6000.00
0005434312372	5081	Economy	6000.00
0005433688855	5081	Economy	6000.00
0005435270100	5081	Economy	6000.00
0005432336359	5081	Economy	6000.00
0005434230043	5081	Economy	6000.00
0005435270184	5081	Economy	6000.00
0005435270078	5081	Economy	6000.00
0005435270005	5081	Economy	6000.00
0005435270183	5081	Economy	6000.00
0005435269935	5081	Economy	6000.00
0005435007525	5081	Economy	6000.00
0005434312368	5081	Economy	6000.00
0005434311271	5081	Economy	6000.00
0005435270061	5081	Economy	6000.00
0005435270146	5081	Economy	6000.00
0005435007615	5081	Economy	6000.00
0005435007568	5081	Economy	6000.00
0005433685568	5081	Economy	6000.00
0005434265900	5081	Economy	6000.00
0005435270113	5081	Economy	6000.00
0005435269970	5081	Economy	6000.00
0005435269952	5081	Economy	6000.00
0005435007656	5081	Economy	6000.00
0005432336323	5081	Economy	6000.00
0005435007686	5081	Economy	6000.00
0005435007614	5081	Economy	6000.00
0005435270154	5081	Economy	6000.00
0005435007575	5081	Economy	6000.00
0005435007643	5081	Economy	6000.00
0005433785991	8512	Business	18000.00
0005433785846	8512	Business	18000.00
0005433785938	8512	Business	18000.00
0005433785706	8512	Business	18000.00
0005433785936	8512	Business	18000.00
0005433785931	8512	Business	18000.00
0005434245751	8512	Business	18000.00
0005433785754	8512	Business	18000.00
0005433785773	8512	Business	18000.00
0005434245654	8512	Business	18000.00
0005433785967	8512	Business	18000.00
0005434245761	8512	Business	18000.00
0005433786093	8512	Economy	6600.00
0005433785990	8512	Economy	6600.00
0005434245809	8512	Economy	6600.00
0005434245775	8512	Economy	6600.00
0005434245788	8512	Economy	6600.00
0005433786109	8512	Economy	6000.00
0005433785908	8512	Economy	6000.00
0005435270224	8512	Economy	6000.00
0005435270222	8512	Economy	6000.00
0005433785814	8512	Economy	6000.00
0005434245744	8512	Economy	6000.00
0005432659760	8512	Economy	6000.00
0005434245707	8512	Economy	6000.00
0005433785978	8512	Economy	6000.00
0005434245746	8512	Economy	6000.00
0005434245724	8512	Economy	6000.00
0005433785907	8512	Economy	6000.00
0005433785782	8512	Economy	6000.00
0005434245798	8512	Economy	6000.00
0005433785790	8512	Economy	6000.00
0005433785753	8512	Economy	6000.00
0005434245747	8512	Economy	6000.00
0005433785796	8512	Economy	6000.00
0005435270223	8512	Economy	6000.00
0005433785949	8512	Economy	6000.00
0005434245762	8512	Economy	6000.00
0005433785876	8512	Economy	6000.00
0005432659761	8512	Economy	6000.00
0005435270225	8512	Economy	6000.00
0005434245748	8512	Economy	6000.00
0005434245760	8512	Economy	6000.00
0005434245769	8512	Economy	6000.00
0005433786034	8512	Economy	6000.00
0005434245810	8512	Economy	6000.00
0005433785859	8512	Economy	6000.00
0005433785774	8512	Economy	6000.00
0005434245752	8512	Economy	6000.00
0005434245750	8512	Economy	6000.00
0005433785955	8512	Economy	6000.00
0005433785761	8512	Economy	6000.00
0005434245749	8512	Economy	6600.00
0005434245601	8512	Economy	6600.00
0005434245637	8512	Economy	6600.00
0005433786092	8512	Economy	6600.00
0005434245726	8512	Economy	6000.00
0005433785845	8512	Economy	6600.00
0005433785858	8512	Economy	6000.00
0005433785795	8512	Economy	6000.00
0005433785977	8512	Economy	6000.00
0005433785710	8512	Economy	6000.00
0005434245725	8512	Economy	6000.00
0005435270228	8512	Economy	6000.00
0005433785815	8512	Economy	6000.00
0005433786012	8512	Economy	6000.00
0005433785820	8512	Economy	6000.00
0005433785979	8512	Economy	6000.00
0005433785924	8512	Economy	6000.00
0005434245695	8512	Economy	6000.00
0005433785993	8512	Economy	6000.00
0005433786011	8512	Economy	6000.00
0005434245768	8512	Economy	6000.00
0005433785848	8512	Economy	6000.00
0005435270226	8512	Economy	6000.00
0005433785766	8512	Economy	6000.00
0005434245774	8512	Economy	6000.00
0005433785805	8512	Economy	6000.00
0005435270229	8512	Economy	6000.00
0005433785915	8512	Economy	6000.00
0005434245765	8512	Economy	6000.00
0005433785877	8512	Economy	6000.00
0005433785992	8512	Economy	6000.00
0005434245787	8512	Economy	6000.00
0005433786063	8512	Economy	6000.00
0005433786035	8512	Economy	6000.00
0005433785767	8512	Economy	6000.00
0005433785601	8512	Economy	6000.00
0005432666429	8512	Economy	6000.00
0005435270227	8512	Economy	6000.00
0005434245636	8512	Economy	6000.00
0005433785847	8512	Economy	6000.00
0005433785906	8512	Economy	6000.00
0005433616591	8511	Business	18000.00
0005433616519	8511	Business	18000.00
0005433616384	8511	Business	18000.00
0005433616481	8511	Business	18000.00
0005433616231	8511	Business	18000.00
0005433616438	8511	Business	18000.00
0005433616403	8511	Business	18000.00
0005433616440	8511	Business	18000.00
0005433616752	8511	Business	18000.00
0005433616630	8511	Business	18000.00
0005433616392	8511	Business	18000.00
0005433616583	8511	Business	18000.00
0005433616297	8511	Business	18000.00
0005433616190	8511	Business	18000.00
0005433616547	8511	Economy	6600.00
0005433616658	8511	Economy	6000.00
0005433616350	8511	Economy	6000.00
0005433616657	8511	Economy	6000.00
0005433616428	8511	Economy	6000.00
0005433616404	8511	Economy	6000.00
0005433616526	8511	Economy	6000.00
0005433616137	8511	Economy	6000.00
0005433616554	8511	Economy	6000.00
0005433616439	8511	Economy	6000.00
0005433616699	8511	Economy	6000.00
0005433616586	8511	Economy	6000.00
0005433616191	8511	Economy	6000.00
0005433616518	8511	Economy	6000.00
0005433616680	8511	Economy	6000.00
0005433616274	8511	Economy	6000.00
0005433616643	8511	Economy	6000.00
0005433616553	8511	Economy	6000.00
0005433616318	8511	Economy	6000.00
0005433616510	8511	Economy	6000.00
0005433616233	8511	Economy	6000.00
0005433616601	8511	Economy	6000.00
0005433616585	8511	Economy	6000.00
0005433616272	8511	Economy	6000.00
0005433616479	8511	Economy	6000.00
0005433616539	8511	Economy	6000.00
0005433616385	8511	Economy	6000.00
0005433616648	8511	Economy	6000.00
0005433616549	8511	Economy	6000.00
0005433616417	8511	Economy	6000.00
0005433616536	8511	Economy	6600.00
0005433616338	8511	Economy	6000.00
0005433616255	8511	Economy	6000.00
0005433616304	8511	Economy	6000.00
0005433616353	8511	Economy	6000.00
0005433616634	8511	Economy	6000.00
0005433616269	8511	Economy	6000.00
0005433616572	8511	Economy	6000.00
0005433616167	8511	Economy	6000.00
0005433616511	8511	Economy	6000.00
0005433616645	8511	Economy	6000.00
0005433616427	8511	Economy	6000.00
0005433616602	8511	Economy	6000.00
0005433616270	8511	Economy	6000.00
0005433616787	8511	Economy	6000.00
0005433616588	8511	Economy	6000.00
0005433616640	8511	Economy	6000.00
0005433616354	8511	Economy	6000.00
0005433616423	8511	Economy	6000.00
0005433616587	8511	Economy	6000.00
0005433616478	8511	Economy	6000.00
0005433616548	8511	Economy	6000.00
0005433616232	8511	Economy	6000.00
0005433616535	8511	Economy	6000.00
0005433616376	8511	Economy	6000.00
0005433616355	8511	Economy	6000.00
0005433616254	8511	Economy	6000.00
0005433616333	8511	Economy	6000.00
0005433616584	8511	Economy	6000.00
0005433616637	8511	Economy	6000.00
0005433616273	8511	Economy	6000.00
0005433616303	8511	Economy	6000.00
0005433616636	8511	Economy	6000.00
0005433616356	8511	Economy	6000.00
0005433616671	8511	Economy	6000.00
0005435551784	8510	Business	18000.00
0005434229878	8510	Business	18000.00
0005434265718	8510	Business	18000.00
0005434229900	8510	Business	18000.00
0005434150035	8510	Business	18000.00
0005434265842	8510	Business	18000.00
0005432035761	8510	Business	18000.00
0005434230008	8510	Business	18000.00
0005434265739	8510	Business	18000.00
0005434265730	8510	Business	18000.00
0005435287047	8510	Business	18000.00
0005434229924	8510	Business	18000.00
0005434173623	8510	Economy	6600.00
0005433815567	8510	Economy	6600.00
0005433815527	8510	Economy	6600.00
0005434265819	8510	Economy	6000.00
0005434173624	8510	Economy	6000.00
0005434150032	8510	Economy	6000.00
0005434149998	8510	Economy	6000.00
0005434229943	8510	Economy	6000.00
0005434265777	8510	Economy	6000.00
0005434265769	8510	Economy	6000.00
0005432035763	8510	Economy	6000.00
0005434229869	8510	Economy	6000.00
0005434265722	8510	Economy	6000.00
0005434229868	8510	Economy	6000.00
0005435287040	8510	Economy	6000.00
0005434265756	8510	Economy	6000.00
0005432035762	8510	Economy	6000.00
0005434265778	8510	Economy	6000.00
0005434265863	8510	Economy	6000.00
0005435287039	8510	Economy	6000.00
0005434265723	8510	Economy	6000.00
0005435287046	8510	Economy	6000.00
0005434229944	8510	Economy	6000.00
0005435287049	8510	Economy	6000.00
0005435287036	8510	Economy	6000.00
0005434229998	8510	Economy	6000.00
0005435287038	8510	Economy	6000.00
0005435007720	8510	Economy	6000.00
0005434150037	8510	Economy	6000.00
0005434173612	8510	Economy	6000.00
0005435551783	8510	Economy	6600.00
0005435551785	8510	Economy	6000.00
0005435287043	8510	Economy	6600.00
0005434150036	8510	Economy	6000.00
0005435287037	8510	Economy	6000.00
0005435287035	8510	Economy	6000.00
0005434230006	8510	Economy	6600.00
0005434150024	8510	Economy	6000.00
0005434265864	8510	Economy	6000.00
0005435287044	8510	Economy	6000.00
0005434265837	8510	Economy	6000.00
0005435287048	8510	Economy	6000.00
0005434173615	8510	Economy	6000.00
0005434265738	8510	Economy	6000.00
0005435007722	8510	Economy	6000.00
0005435287051	8510	Economy	6000.00
0005434265771	8510	Economy	6000.00
0005434265840	8510	Economy	6000.00
0005434229881	8510	Economy	6000.00
0005434150038	8510	Economy	6000.00
0005434173614	8510	Economy	6000.00
0005434265763	8510	Economy	6000.00
0005434265841	8510	Economy	6000.00
0005434265883	8510	Economy	6000.00
0005434265846	8510	Economy	6000.00
0005434230007	8510	Economy	6000.00
0005434265813	8510	Economy	6000.00
0005434229925	8510	Economy	6000.00
0005434229877	8510	Economy	6000.00
0005434173622	8510	Economy	6000.00
0005435287041	8510	Economy	6000.00
0005435287050	8510	Economy	6000.00
0005434265838	8510	Economy	6000.00
0005434265742	8510	Economy	6000.00
0005435007721	8510	Economy	6000.00
0005435287052	8510	Economy	6000.00
0005434265736	8510	Economy	6000.00
0005434229885	8510	Economy	6000.00
0005434265764	8510	Economy	6000.00
0005435287042	8510	Economy	6000.00
0005434173616	8510	Economy	6000.00
0005435287045	8510	Economy	6000.00
0005434265770	8510	Economy	6000.00
0005434640004	12602	Economy	16200.00
0005434640005	12602	Economy	16200.00
0005434639924	12602	Economy	14800.00
0005434640016	12602	Economy	14800.00
0005434640017	12602	Economy	14800.00
0005434640003	12602	Economy	14800.00
0005434639911	12602	Economy	14800.00
0005434640001	12602	Economy	14800.00
0005434639925	12602	Economy	14800.00
0005434640050	12602	Economy	14800.00
0005434640018	12602	Economy	14800.00
0005434639966	12602	Economy	14800.00
0005434640027	12602	Economy	14800.00
0005434639788	12602	Economy	14800.00
0005434639936	12602	Economy	14800.00
0005434639955	12602	Economy	14800.00
0005434639923	12602	Economy	14800.00
0005434640002	12602	Economy	14800.00
0005434639902	12602	Economy	14800.00
0005434639954	12602	Economy	14800.00
0005434640021	12602	Economy	14800.00
0005434640020	12602	Economy	14800.00
0005434639918	12602	Economy	14800.00
0005433202730	23364	Economy	16200.00
0005433202720	23364	Economy	16200.00
0005433202745	23364	Economy	14800.00
0005433202676	23364	Economy	14800.00
0005434640104	23364	Economy	14800.00
0005433202694	23364	Economy	14800.00
0005433202669	23364	Economy	14800.00
0005433202764	23364	Economy	14800.00
0005433202675	23364	Economy	14800.00
0005433202709	23364	Economy	14800.00
0005433202724	23364	Economy	14800.00
0005433202712	23364	Economy	14800.00
0005433202695	23364	Economy	14800.00
0005433202725	23364	Economy	14800.00
0005433202710	23364	Economy	14800.00
0005434640102	23364	Economy	14800.00
0005433202661	23364	Economy	14800.00
0005433202711	23364	Economy	14800.00
0005433202747	23364	Economy	14800.00
0005433202748	23364	Economy	14800.00
0005433202684	23364	Economy	14800.00
0005433202705	23364	Economy	14800.00
0005433202685	23364	Economy	14800.00
0005434640103	23364	Economy	14800.00
0005433202633	23364	Economy	14800.00
0005433202680	23364	Economy	14800.00
0005432384136	21089	Business	18900.00
0005432329955	21089	Business	18900.00
0005432329815	21089	Business	18900.00
0005432384086	21089	Business	18900.00
0005432384275	21089	Business	18900.00
0005432384207	21089	Business	18900.00
0005432329714	21089	Business	18900.00
0005432383975	21089	Business	18900.00
0005432329660	21089	Business	18900.00
0005432329785	21089	Business	18900.00
0005432384012	21089	Business	18900.00
0005432384223	21089	Business	18900.00
0005432384049	21089	Economy	6300.00
0005432329903	21089	Economy	6300.00
0005432384097	21089	Economy	6300.00
0005432384043	21089	Economy	6300.00
0005432329661	21089	Economy	6300.00
0005432384206	21089	Economy	6300.00
0005432384091	21089	Economy	6300.00
0005432329878	21089	Economy	6300.00
0005432384116	21089	Economy	6300.00
0005432329839	21089	Economy	6900.00
0005432329808	21089	Economy	6900.00
0005432329604	21089	Economy	6900.00
0005432329711	21089	Economy	6900.00
0005432329800	21089	Economy	6900.00
0005432329792	21089	Economy	6300.00
0005432384219	21089	Economy	6300.00
0005432329914	21089	Economy	6300.00
0005432384075	21089	Economy	6300.00
0005432384085	21089	Economy	6300.00
0005432384232	21089	Economy	6300.00
0005432384092	21089	Economy	6300.00
0005432384159	21089	Economy	6300.00
0005432329877	21089	Economy	6300.00
0005432384166	21089	Economy	6300.00
0005432329902	21089	Economy	6300.00
0005432383866	21089	Economy	6300.00
0005432384162	21089	Economy	6300.00
0005432848920	21089	Economy	6300.00
0005432384163	21089	Economy	6300.00
0005432329656	21089	Economy	6300.00
0005432329791	21089	Economy	6300.00
0005432384045	21089	Economy	6300.00
0005432384174	21089	Economy	6300.00
0005432384066	21089	Economy	6300.00
0005432329763	21089	Economy	6300.00
0005432384102	21089	Economy	6300.00
0005432329954	21089	Economy	6300.00
0005432329762	21089	Economy	6300.00
0005432384101	21089	Economy	6300.00
0005432329957	21089	Economy	6300.00
0005432384093	21089	Economy	6300.00
0005432329745	21089	Economy	6300.00
0005432329769	21089	Economy	6300.00
0005432384044	21089	Economy	6300.00
0005432384175	21089	Economy	6300.00
0005432329553	21089	Economy	6300.00
0005432384129	21089	Economy	6300.00
0005432329637	21089	Economy	6300.00
0005432329956	21089	Economy	6300.00
0005432384084	21089	Economy	6300.00
0005432384190	21089	Economy	6300.00
0005432384139	21089	Economy	6300.00
0005432384173	21089	Economy	6300.00
0005432329706	21089	Economy	6300.00
0005432384274	21089	Economy	6300.00
0005432384224	21089	Economy	6300.00
0005432384122	21089	Economy	6300.00
0005432384074	21089	Economy	6300.00
0005432384011	21089	Economy	6300.00
0005432384065	21089	Economy	6300.00
0005432384158	21089	Economy	6300.00
0005432384124	21089	Economy	6300.00
0005432384256	21089	Economy	6300.00
0005432329712	21089	Economy	6300.00
0005432384261	21089	Economy	6300.00
0005432329909	21089	Economy	6300.00
0005432384147	21089	Economy	6300.00
0005432329746	21089	Economy	6300.00
0005432329876	21089	Economy	6300.00
0005432329904	21089	Economy	6300.00
0005432384260	21089	Economy	6300.00
0005432329773	21089	Economy	6300.00
0005432329838	21089	Economy	6300.00
0005432329840	21089	Economy	6300.00
0005432384123	21089	Economy	6300.00
0005432329901	21089	Economy	6300.00
0005432848883	31252	Business	18900.00
0005432384337	31252	Business	18900.00
0005432330053	31252	Economy	6300.00
0005432330054	31252	Economy	6300.00
0005432848894	31252	Economy	6900.00
0005432848882	31252	Economy	6300.00
0005432384338	31252	Economy	6300.00
0005432848902	31252	Economy	6300.00
0005432330052	31252	Economy	6300.00
0005432848903	31252	Economy	6300.00
0005432384339	31252	Economy	6300.00
0005432848877	31252	Economy	6300.00
0005432330055	31252	Economy	6300.00
0005432384336	31252	Economy	6300.00
0005432426043	13295	Business	12700.00
0005432426045	13295	Business	12700.00
0005432426063	13295	Business	12700.00
0005432426061	13295	Business	12700.00
0005432426056	13295	Business	12700.00
0005432426046	13295	Economy	4200.00
0005432426048	13295	Economy	4700.00
0005432426055	13295	Economy	4200.00
0005432426054	13295	Economy	4200.00
0005432426047	13295	Economy	4200.00
0005432426059	13295	Economy	4200.00
0005432426062	13295	Economy	4200.00
0005432426060	13295	Economy	4200.00
0005432426050	13295	Economy	4200.00
0005432426051	13295	Economy	4200.00
0005432426064	13295	Economy	4200.00
0005432426052	13295	Economy	4200.00
0005432426049	13295	Economy	4200.00
0005432426058	13295	Economy	4200.00
0005432426057	13295	Economy	4200.00
0005432426044	13295	Economy	4200.00
0005432426053	13295	Economy	4200.00
0005432425481	30752	Business	12700.00
0005432425613	30752	Business	12700.00
0005432425656	30752	Business	12700.00
0005432425596	30752	Business	12700.00
0005432425321	30752	Economy	4200.00
0005432425423	30752	Economy	4200.00
0005432425617	30752	Economy	4200.00
0005432425602	30752	Economy	4200.00
0005432425561	30752	Economy	4700.00
0005432425648	30752	Economy	4700.00
0005432425654	30752	Economy	4700.00
0005432425569	30752	Economy	4200.00
0005432425627	30752	Economy	4200.00
0005432425634	30752	Economy	4200.00
0005432425422	30752	Economy	4200.00
0005432425504	30752	Economy	4200.00
0005432425395	30752	Economy	4200.00
0005432425597	30752	Economy	4200.00
0005432425519	30752	Economy	4200.00
0005432425555	30752	Economy	4200.00
0005432425573	30752	Economy	4200.00
0005432425652	30752	Economy	4200.00
0005432425522	30752	Economy	4200.00
0005432425571	30752	Economy	4200.00
0005432425505	30752	Economy	4200.00
0005432425637	30752	Economy	4200.00
0005432425644	30752	Economy	4200.00
0005432425462	30752	Economy	4200.00
0005432425560	30752	Economy	4200.00
0005432425616	30752	Economy	4200.00
0005432425574	30752	Economy	4200.00
0005432425628	30752	Economy	4200.00
0005432425521	30752	Economy	4200.00
0005432425620	30752	Economy	4200.00
0005432425653	30752	Economy	4200.00
0005432425559	30752	Economy	4200.00
0005432425469	30752	Economy	4200.00
0005432425572	30752	Economy	4200.00
0005432425630	30752	Economy	4200.00
0005432425635	30752	Economy	4200.00
0005432425647	30752	Economy	4200.00
0005432425657	30752	Economy	4200.00
0005432902061	9619	Business	32600.00
0005432901980	9619	Business	32600.00
0005432902015	9619	Business	32600.00
0005434157697	9619	Business	32600.00
0005432289085	9619	Business	32600.00
0005432902026	9619	Business	32600.00
0005432902020	9619	Business	32600.00
0005434186268	9619	Economy	10900.00
0005434157675	9619	Economy	10900.00
0005432901981	9619	Economy	10900.00
0005434157674	9619	Economy	10900.00
0005432902101	9619	Economy	10900.00
0005432902025	9619	Economy	10900.00
0005432902064	9619	Economy	11900.00
0005434157670	9619	Economy	11900.00
0005434157671	9619	Economy	11900.00
0005432902079	9619	Economy	11900.00
0005432902021	9619	Economy	10900.00
0005434157701	9619	Economy	10900.00
0005432902045	9619	Economy	10900.00
0005432902058	9619	Economy	10900.00
0005432902071	9619	Economy	10900.00
0005434186272	9619	Economy	10900.00
0005432902080	9619	Economy	10900.00
0005432902066	9619	Economy	10900.00
0005432902065	9619	Economy	10900.00
0005432902016	9619	Economy	10900.00
0005434186275	9619	Economy	10900.00
0005434157700	9619	Economy	10900.00
0005434157685	9619	Economy	10900.00
0005434157687	9619	Economy	10900.00
0005432902027	9619	Economy	10900.00
0005432289086	9619	Economy	10900.00
0005434186274	9619	Economy	10900.00
0005432818336	9619	Economy	10900.00
0005432902081	9619	Economy	10900.00
0005434157668	9619	Economy	10900.00
0005434186270	9619	Economy	10900.00
0005432902047	9619	Economy	10900.00
0005434157696	9619	Economy	10900.00
0005432818065	28989	Business	32600.00
0005432818149	28989	Business	32600.00
0005432818225	28989	Business	32600.00
0005432818260	28989	Business	32600.00
0005432822406	28989	Economy	10900.00
0005432822412	28989	Economy	10900.00
0005432902125	28989	Economy	11900.00
0005432822403	28989	Economy	10900.00
0005432818233	28989	Economy	10900.00
0005432822411	28989	Economy	10900.00
0005432818196	28989	Economy	10900.00
0005432822394	28989	Economy	10900.00
0005434448399	28989	Economy	10900.00
0005432818172	28989	Economy	10900.00
0005432818203	28989	Economy	10900.00
0005432818105	28989	Economy	10900.00
0005432822379	28989	Economy	10900.00
0005432818058	28989	Economy	10900.00
0005432818131	28989	Economy	10900.00
0005432818060	28989	Economy	10900.00
0005432818220	28989	Economy	10900.00
0005432822388	28989	Economy	10900.00
0005432818061	28989	Economy	10900.00
0005432818205	28989	Economy	10900.00
0005432818204	28989	Economy	10900.00
0005432818221	28989	Economy	10900.00
0005432822405	28989	Economy	10900.00
0005432818231	28989	Economy	10900.00
0005432822404	28989	Economy	10900.00
0005432818150	28989	Economy	10900.00
0005432818059	28989	Economy	10900.00
0005432818232	28989	Economy	10900.00
0005434157715	28989	Economy	10900.00
0005435841847	15104	Economy	11000.00
0005435841844	15104	Economy	11000.00
0005435841119	15104	Economy	11000.00
0005435841845	15104	Economy	11000.00
0005435841852	31562	Economy	11000.00
0005435841851	31562	Economy	11000.00
0005432607653	31562	Economy	11000.00
0005432949300	11872	Business	105900.00
0005432949432	11872	Business	105900.00
0005433570978	11872	Business	105900.00
0005432949259	11872	Business	105900.00
0005432949420	11872	Business	105900.00
0005433570974	11872	Business	105900.00
0005433570967	11872	Business	105900.00
0005432949466	11872	Business	105900.00
0005432949433	11872	Business	105900.00
0005432949521	11872	Business	105900.00
0005432949493	11872	Economy	35300.00
0005432949350	11872	Economy	35300.00
0005432949396	11872	Economy	35300.00
0005432949512	11872	Economy	35300.00
0005432949455	11872	Economy	35300.00
0005432949361	11872	Economy	35300.00
0005432949475	11872	Economy	38800.00
0005433570971	11872	Economy	38800.00
0005432949427	11872	Economy	35300.00
0005432949547	11872	Economy	35300.00
0005432949437	11872	Economy	35300.00
0005432949385	11872	Economy	35300.00
0005433570976	11872	Economy	35300.00
0005432949384	11872	Economy	35300.00
0005432949364	11872	Economy	35300.00
0005433570980	11872	Economy	35300.00
0005433570973	11872	Economy	35300.00
0005433570966	11872	Economy	35300.00
0005432949404	11872	Economy	35300.00
0005433570975	11872	Economy	35300.00
0005432949394	11872	Economy	35300.00
0005432949473	11872	Economy	35300.00
0005432949336	11872	Economy	35300.00
0005432949429	11872	Economy	35300.00
0005432949439	11872	Economy	35300.00
0005432949545	11872	Economy	35300.00
0005433570972	11872	Economy	35300.00
0005432949474	11872	Economy	35300.00
0005432949418	11872	Economy	35300.00
0005433570970	11872	Economy	35300.00
0005433570968	11872	Economy	35300.00
0005433570979	11872	Economy	35300.00
0005432949312	11872	Economy	35300.00
0005432949227	11872	Economy	35300.00
0005433570969	11872	Economy	35300.00
0005433570977	11872	Economy	35300.00
0005432949443	11872	Economy	35300.00
0005432949465	11872	Economy	35300.00
0005432949450	11872	Economy	35300.00
0005432949360	11872	Economy	35300.00
0005432949486	11872	Economy	35300.00
0005432949438	11872	Economy	35300.00
0005432949453	11872	Economy	35300.00
0005432949419	11872	Economy	35300.00
0005432949260	11872	Economy	35300.00
0005432949487	11872	Economy	35300.00
0005433570096	25311	Business	105900.00
0005433570445	25311	Business	105900.00
0005433570311	25311	Business	105900.00
0005433570474	25311	Business	105900.00
0005433570461	25311	Business	105900.00
0005433570391	25311	Business	105900.00
0005433570701	25311	Business	105900.00
0005433570604	25311	Business	105900.00
0005433570499	25311	Business	105900.00
0005433570527	25311	Business	105900.00
0005433570728	25311	Business	105900.00
0005433570608	25311	Business	105900.00
0005433570558	25311	Business	105900.00
0005433570618	25311	Economy	35300.00
0005433570651	25311	Economy	35300.00
0005433570559	25311	Economy	35300.00
0005433570524	25311	Economy	35300.00
0005433570462	25311	Economy	35300.00
0005433570852	25311	Economy	35300.00
0005433570628	25311	Economy	35300.00
0005433570764	25311	Economy	35300.00
0005433570528	25311	Economy	35300.00
0005433570607	25311	Economy	35300.00
0005433570825	25311	Economy	35300.00
0005433570587	25311	Economy	35300.00
0005433570358	25311	Economy	35300.00
0005433570301	25311	Economy	35300.00
0005433570622	25311	Economy	35300.00
0005433570228	25311	Economy	35300.00
0005433570643	25311	Economy	35300.00
0005433570606	25311	Economy	35300.00
0005433570494	25311	Economy	35300.00
0005433570334	25311	Economy	35300.00
0005433570518	25311	Economy	35300.00
0005433570623	25311	Economy	35300.00
0005433570562	25311	Economy	35300.00
0005433570635	25311	Economy	35300.00
0005433570569	25311	Economy	35300.00
0005433570500	25311	Economy	35300.00
0005433570065	25311	Economy	35300.00
0005432949700	25311	Economy	35300.00
0005433570636	25311	Economy	35300.00
0005433570335	25311	Economy	35300.00
0005433570682	25311	Economy	35300.00
0005433570553	25311	Economy	35300.00
0005433570525	25311	Economy	35300.00
0005433570670	25311	Economy	35300.00
0005433570095	25311	Economy	35300.00
0005433570336	25311	Economy	35300.00
0005433570395	25311	Economy	35300.00
0005433570765	25311	Economy	35300.00
0005433570624	25311	Economy	35300.00
0005433570586	25311	Economy	35300.00
0005433570425	25311	Economy	35300.00
0005433570824	25311	Economy	35300.00
0005433570570	25311	Economy	35300.00
0005433570645	25311	Economy	35300.00
0005433570883	25311	Economy	35300.00
0005433570644	25311	Economy	35300.00
0005433570629	25311	Economy	35300.00
0005433570533	25311	Economy	35300.00
0005433570568	25311	Economy	35300.00
0005433570772	25311	Economy	35300.00
0005433570605	25311	Economy	35300.00
0005433570493	25311	Economy	35300.00
0005433570582	25311	Economy	35300.00
0005433570563	25311	Economy	35300.00
0005433927534	27937	Business	105400.00
0005433811670	27937	Economy	35100.00
0005433811672	27937	Economy	35100.00
0005433811662	27937	Economy	35100.00
0005433811659	27937	Economy	35100.00
0005433811668	27937	Economy	35100.00
0005433811665	27937	Economy	35100.00
0005433811676	27937	Economy	35100.00
0005433811660	27937	Economy	38600.00
0005433811661	27937	Economy	35100.00
0005433811678	27937	Economy	35100.00
0005433811658	27937	Economy	35100.00
0005433927539	27937	Economy	35100.00
0005433811666	27937	Economy	35100.00
0005433811679	27937	Economy	35100.00
0005433927536	27937	Economy	35100.00
0005433811669	27937	Economy	35100.00
0005433927535	27937	Economy	35100.00
0005433927538	27937	Economy	35100.00
0005433811671	27937	Economy	35100.00
0005433811667	27937	Economy	35100.00
0005433927537	27937	Economy	35100.00
0005435340656	5410	Business	67200.00
0005435340666	5410	Business	67200.00
0005435340665	5410	Business	67200.00
0005435555426	5410	Economy	22400.00
0005435340682	5410	Economy	22400.00
0005435340585	5410	Economy	22400.00
0005435340584	5410	Economy	22400.00
0005435340648	5410	Economy	22400.00
0005435340631	5410	Economy	22400.00
0005435340667	5410	Economy	22400.00
0005435340597	5410	Economy	22400.00
0005435340646	5410	Economy	22400.00
0005435340655	5410	Economy	22400.00
0005435555423	5410	Economy	22400.00
0005435340626	5410	Economy	22400.00
0005435340589	5410	Economy	22400.00
0005435555425	5410	Economy	22400.00
0005434655411	12559	Business	67200.00
0005434655417	12559	Business	67200.00
0005434655295	12559	Business	67200.00
0005434655457	12559	Business	67200.00
0005435340708	12559	Economy	24600.00
0005434655331	12559	Economy	24600.00
0005434655416	12559	Economy	24600.00
0005434655503	12559	Economy	22400.00
0005434655310	12559	Economy	22400.00
0005434655326	12559	Economy	22400.00
0005434655494	12559	Economy	22400.00
0005434655285	12559	Economy	22400.00
0005434655456	12559	Economy	22400.00
0005434655441	12559	Economy	22400.00
0005434655502	12559	Economy	22400.00
0005434655332	12559	Economy	22400.00
0005434655454	12559	Economy	22400.00
0005434655322	12559	Economy	22400.00
0005434655520	12559	Economy	22400.00
0005434655398	12559	Economy	22400.00
0005434655309	12559	Economy	22400.00
0005434655422	12559	Economy	22400.00
0005434655405	12559	Economy	22400.00
0005434655407	12559	Economy	22400.00
0005434655361	12559	Economy	22400.00
0005434655402	12559	Economy	22400.00
0005434655442	12559	Economy	22400.00
0005434655458	12559	Economy	22400.00
0005434655325	12559	Economy	22400.00
0005434655406	12559	Economy	22400.00
0005434655423	12559	Economy	22400.00
0005434655412	12559	Economy	22400.00
0005432429007	7463	Economy	10700.00
0005432429020	7463	Economy	10700.00
0005435266314	7463	Economy	10700.00
0005433656768	7463	Economy	10700.00
0005435266295	7463	Economy	10700.00
0005433722509	7463	Economy	10700.00
0005435266317	7463	Economy	10700.00
0005435266294	7463	Economy	10700.00
0005435266315	7463	Economy	10700.00
0005433717428	7463	Economy	10700.00
0005432429019	7463	Economy	10700.00
0005433717431	7463	Economy	10700.00
0005435266307	7463	Economy	10700.00
0005432429008	7463	Economy	10700.00
0005435266288	7463	Economy	10700.00
0005433717430	7463	Economy	10700.00
0005433717427	7463	Economy	10700.00
0005435266316	7463	Economy	10700.00
0005435266305	7463	Economy	10700.00
0005435266318	7463	Economy	10700.00
0005435266319	7463	Economy	10700.00
0005435266306	7463	Economy	10700.00
0005433717429	7463	Economy	10700.00
0005433722399	29245	Business	32000.00
0005433717339	29245	Business	32000.00
0005433717338	29245	Business	32000.00
0005433716991	29245	Business	32000.00
0005433717168	29245	Business	32000.00
0005433656747	29245	Business	32000.00
0005433716997	29245	Business	32000.00
0005433717132	29245	Economy	10700.00
0005433717363	29245	Economy	10700.00
0005433722392	29245	Economy	10700.00
0005433717155	29245	Economy	10700.00
0005433717237	29245	Economy	10700.00
0005433717134	29245	Economy	10700.00
0005433722355	29245	Economy	10700.00
0005433717270	29245	Economy	10700.00
0005433717247	29245	Economy	10700.00
0005433719224	29245	Economy	10700.00
0005433717133	29245	Economy	10700.00
0005433722398	29245	Economy	10700.00
0005433717271	29245	Economy	10700.00
0005433717365	29245	Economy	10700.00
0005433717025	29245	Economy	10700.00
0005433656746	29245	Economy	10700.00
0005433717364	29245	Economy	10700.00
0005435546240	29245	Economy	10700.00
0005433722391	29245	Economy	10700.00
0005433716935	29245	Economy	10700.00
0005433717197	29245	Economy	11700.00
0005433719225	29245	Economy	11700.00
0005433685568	29245	Economy	11700.00
0005433722388	29245	Economy	10700.00
0005435266348	29245	Economy	10700.00
0005435266347	29245	Economy	10700.00
0005433656745	29245	Economy	10700.00
0005433717124	29245	Economy	10700.00
0005433717085	29245	Economy	10700.00
0005433717248	29245	Economy	10700.00
0005433717120	29245	Economy	10700.00
0005433719221	29245	Economy	10700.00
0005433717026	29245	Economy	10700.00
0005433717177	29245	Economy	10700.00
0005433717206	29245	Economy	10700.00
0005433717195	29245	Economy	10700.00
0005433656748	29245	Economy	10700.00
0005433717261	29245	Economy	10700.00
0005433719218	29245	Economy	10700.00
0005435266346	29245	Economy	10700.00
0005433719229	29245	Economy	10700.00
0005433685567	29245	Economy	10700.00
0005433717154	29245	Economy	10700.00
0005433717205	29245	Economy	10700.00
0005433717235	29245	Economy	10700.00
0005433717330	29245	Economy	10700.00
0005433722370	29245	Economy	10700.00
0005433717269	29245	Economy	10700.00
0005433717304	29245	Economy	10700.00
0005433688855	29245	Economy	10700.00
0005433717224	29245	Economy	10700.00
0005433717196	29245	Economy	10700.00
0005433685569	29245	Economy	10700.00
0005433719222	29245	Economy	10700.00
0005433717194	29245	Economy	10700.00
0005433717219	29245	Economy	10700.00
0005433717262	29245	Economy	10700.00
0005433717179	29245	Economy	10700.00
0005433717335	29245	Economy	10700.00
0005433717169	29245	Economy	10700.00
0005434182521	8686	Business	36500.00
0005434182489	8686	Business	36500.00
0005434182518	8686	Business	36500.00
0005435860644	8686	Business	36500.00
0005435860652	8686	Business	36500.00
0005434182463	8686	Economy	12200.00
0005435860655	8686	Economy	12200.00
0005435860654	8686	Economy	12200.00
0005434184707	8686	Economy	12200.00
0005434184714	8686	Economy	12200.00
0005435860670	8686	Economy	12200.00
0005434182475	8686	Economy	12200.00
0005435860678	8686	Economy	12200.00
0005435860657	8686	Economy	12200.00
0005434182476	8686	Economy	12200.00
0005435860646	8686	Economy	12200.00
0005434184713	8686	Economy	12200.00
0005435860675	8686	Economy	12200.00
0005435860672	8686	Economy	12200.00
0005435860662	8686	Economy	12200.00
0005434182517	8686	Economy	12200.00
0005435860664	8686	Economy	12200.00
0005434184715	8686	Economy	12200.00
0005434182498	8686	Economy	12200.00
0005434182527	8686	Economy	12200.00
0005435860653	8686	Economy	12200.00
0005435860645	8686	Economy	12200.00
0005435860663	8686	Economy	12200.00
0005435860650	8686	Economy	12200.00
0005435860656	8686	Economy	12200.00
0005434182488	8686	Economy	12200.00
0005434182516	8686	Economy	12200.00
0005435860673	8686	Economy	12200.00
0005435860658	8686	Economy	12200.00
0005434182500	8686	Economy	12200.00
0005434143774	11645	Business	36500.00
0005434143766	11645	Business	36500.00
0005434143784	11645	Economy	12200.00
0005434095608	11645	Economy	12200.00
0005434143775	11645	Economy	12200.00
0005435860733	11645	Economy	12200.00
0005434095566	11645	Economy	13400.00
0005434143764	11645	Economy	13400.00
0005434143817	11645	Economy	12200.00
0005434326286	11645	Economy	12200.00
0005434095571	11645	Economy	12200.00
0005434095667	11645	Economy	12200.00
0005434095565	11645	Economy	12200.00
0005434095640	11645	Economy	12200.00
0005434095625	11645	Economy	12200.00
0005434095591	11645	Economy	12200.00
0005434143796	11645	Economy	12200.00
0005434095592	11645	Economy	12200.00
0005434095616	11645	Economy	12200.00
0005434143788	11645	Economy	12200.00
0005434095637	11645	Economy	12200.00
0005434095666	11645	Economy	12200.00
0005434095639	11645	Economy	12200.00
0005434095567	11645	Economy	12200.00
0005434095624	11645	Economy	12200.00
0005434326285	11645	Economy	12200.00
0005434143765	11645	Economy	12200.00
0005434095578	11645	Economy	12200.00
0005434095636	11645	Economy	12200.00
0005434095675	11645	Economy	12200.00
0005433399239	1434	Business	33000.00
0005433399127	1434	Business	33000.00
0005433399161	1434	Business	33000.00
0005433399067	1434	Business	33000.00
0005433399132	1434	Economy	11000.00
0005433399076	1434	Economy	11000.00
0005432906597	1434	Economy	11000.00
0005433399197	1434	Economy	11000.00
0005433399182	1434	Economy	11000.00
0005433399397	1434	Economy	12100.00
0005433399042	1434	Economy	11000.00
0005433399369	1434	Economy	11000.00
0005433399218	1434	Economy	11000.00
0005433399166	1434	Economy	11000.00
0005433399176	1434	Economy	11000.00
0005433399338	1434	Economy	11000.00
0005433399231	1434	Economy	11000.00
0005433399328	1434	Economy	11000.00
0005433399260	1434	Economy	11000.00
0005433399349	1434	Economy	11000.00
0005433399178	1434	Economy	11000.00
0005433398825	1434	Economy	11000.00
0005433399257	1434	Economy	11000.00
0005433399183	1434	Economy	11000.00
0005433399276	1434	Economy	11000.00
0005433399184	1434	Economy	11000.00
0005433399353	1434	Economy	11000.00
0005433399240	1434	Economy	11000.00
0005433399217	1434	Economy	11000.00
0005433399198	1434	Economy	11000.00
0005433399066	1434	Economy	11000.00
0005433399367	1434	Economy	11000.00
0005433399264	1434	Economy	11000.00
0005433399348	1434	Economy	11000.00
0005433399270	1434	Economy	11000.00
0005433399275	1434	Economy	11000.00
0005433399347	1434	Economy	11000.00
0005433399126	1434	Economy	11000.00
0005433399252	1434	Economy	11000.00
0005433399193	1434	Economy	11000.00
0005435725788	1434	Economy	11000.00
0005433399192	1434	Economy	11000.00
0005433399339	1434	Economy	11000.00
0005433399396	1434	Economy	11000.00
0005433399324	1434	Economy	11000.00
0005433399204	1434	Economy	11000.00
0005433399199	1434	Economy	11000.00
0005433399329	1434	Economy	11000.00
0005435732643	19229	Business	33000.00
0005435732640	19229	Economy	11000.00
0005433457076	19229	Economy	12100.00
0005435732659	19229	Economy	11000.00
0005433457075	19229	Economy	11000.00
0005435732620	19229	Economy	11000.00
0005435732641	19229	Economy	11000.00
0005433457056	19229	Economy	11000.00
0005433457072	19229	Economy	11000.00
0005435732654	19229	Economy	11000.00
0005435732619	19229	Economy	11000.00
0005435732642	19229	Economy	11000.00
0005435732623	19229	Economy	11000.00
0005433399466	19229	Economy	11000.00
0005435732655	19229	Economy	11000.00
0005433457073	19229	Economy	11000.00
0005434444101	17384	Economy	15600.00
0005434444054	17384	Economy	14100.00
0005434444134	17384	Economy	14100.00
0005434444051	17384	Economy	14100.00
0005434444100	17384	Economy	14100.00
0005434444009	17384	Economy	14100.00
0005434444053	17384	Economy	14100.00
0005434444088	17384	Economy	14100.00
0005434444085	17384	Economy	14100.00
0005434444052	17384	Economy	14100.00
0005434444186	20587	Economy	14100.00
0005434444184	20587	Economy	14100.00
0005434444185	20587	Economy	14100.00
0005435377642	7271	Economy	5800.00
0005435377641	7271	Economy	5800.00
0005434183628	4461	Economy	15400.00
0005435893776	4461	Economy	15400.00
0005435893802	4461	Economy	14000.00
0005434183626	4461	Economy	14000.00
0005434183625	4461	Economy	14000.00
0005435893816	4461	Economy	14000.00
0005435893775	4461	Economy	14000.00
0005435893818	4461	Economy	14000.00
0005434183634	4461	Economy	14000.00
0005435893817	4461	Economy	14000.00
0005435893826	4461	Economy	14000.00
0005435893777	4461	Economy	14000.00
0005435893827	4461	Economy	14000.00
0005434183627	4461	Economy	14000.00
0005434352029	29677	Economy	15400.00
0005434352002	29677	Economy	15400.00
0005434326055	29677	Economy	14000.00
0005434352008	29677	Economy	14000.00
0005434352023	29677	Economy	14000.00
0005434351948	29677	Economy	14000.00
0005434351990	29677	Economy	14000.00
0005434326094	29677	Economy	14000.00
0005434352036	29677	Economy	14000.00
0005434351947	29677	Economy	14000.00
0005434352028	29677	Economy	14000.00
0005434352031	29677	Economy	14000.00
0005434351992	29677	Economy	14000.00
0005434352030	29677	Economy	14000.00
0005434352000	29677	Economy	14000.00
0005434326096	29677	Economy	14000.00
0005434326093	29677	Economy	14000.00
0005434352009	29677	Economy	14000.00
0005433345509	1038	Business	30600.00
0005433345924	1038	Business	30600.00
0005433158181	1038	Business	30600.00
0005433345471	1038	Business	30600.00
0005433345565	1038	Business	30600.00
0005433158180	1038	Business	30600.00
0005433345596	1038	Business	30600.00
0005433345923	1038	Business	30600.00
0005433345687	1038	Business	30600.00
0005433158187	1038	Business	30600.00
0005433345715	1038	Business	30600.00
0005433345852	1038	Business	30600.00
0005433345293	1038	Business	30600.00
0005433345438	1038	Business	30600.00
0005433158188	1038	Business	30600.00
0005433345620	1038	Business	30600.00
0005433345470	1038	Business	30600.00
0005433159371	1038	Business	30600.00
0005433345689	1038	Economy	11200.00
0005433345544	1038	Economy	11200.00
0005433345310	1038	Economy	11200.00
0005433345408	1038	Economy	10200.00
0005433345371	1038	Economy	10200.00
0005433345462	1038	Economy	10200.00
0005433345647	1038	Economy	10200.00
0005435546230	1038	Economy	10200.00
0005433345405	1038	Economy	10200.00
0005435546231	1038	Economy	10200.00
0005433345639	1038	Economy	10200.00
0005433344813	1038	Economy	10200.00
0005433345094	1038	Economy	10200.00
0005433345722	1038	Economy	10200.00
0005435545976	1038	Economy	10200.00
0005435546002	1038	Economy	10200.00
0005433345087	1038	Economy	10200.00
0005433345832	1038	Economy	10200.00
0005433345493	1038	Economy	10200.00
0005433345686	1038	Economy	10200.00
0005435545975	1038	Economy	10200.00
0005433345925	1038	Economy	10200.00
0005433345363	1038	Economy	10200.00
0005433345692	1038	Economy	10200.00
0005433345463	1038	Economy	10200.00
0005433345130	1038	Economy	10200.00
0005433345521	1038	Economy	10200.00
0005433345621	1038	Economy	10200.00
0005433345600	1038	Economy	10200.00
0005433345595	1038	Economy	10200.00
0005433345532	1038	Economy	10200.00
0005433345619	1038	Economy	10200.00
0005433345188	1038	Economy	10200.00
0005433345193	1038	Economy	10200.00
0005433345498	1038	Economy	10200.00
0005433345554	1038	Economy	10200.00
0005433345673	1038	Economy	10200.00
0005433345854	1038	Economy	10200.00
0005433345531	1038	Economy	10200.00
0005433345523	1038	Economy	10200.00
0005433345409	1038	Economy	10200.00
0005433345522	1038	Economy	10200.00
0005433345357	1038	Economy	10200.00
0005433345267	1038	Economy	10200.00
0005433345566	1038	Economy	10200.00
0005433345853	1038	Economy	10200.00
0005433345581	1038	Economy	10200.00
0005433269860	1038	Economy	10200.00
0005433345307	1038	Economy	10200.00
0005433345524	1038	Economy	10200.00
0005433345491	1038	Economy	10200.00
0005433345693	1038	Economy	10200.00
0005433345192	1038	Economy	10200.00
0005433345539	1038	Economy	10200.00
0005433345485	1038	Economy	10200.00
0005433345315	1038	Economy	10200.00
0005433345909	1038	Economy	10200.00
0005433344812	1038	Economy	10200.00
0005435092365	1038	Economy	10200.00
0005433345494	1038	Economy	10200.00
0005433345269	1038	Economy	10200.00
0005433345642	1038	Economy	10200.00
0005433345690	1038	Economy	10200.00
0005433345833	1038	Economy	10200.00
0005433345268	1038	Economy	10200.00
0005433345676	1038	Economy	11200.00
0005433345808	1038	Economy	10200.00
0005433345190	1038	Economy	10200.00
0005433345486	1038	Economy	10200.00
0005433345525	1038	Economy	10200.00
0005435546232	1038	Economy	10200.00
0005433345567	1038	Economy	10200.00
0005433345538	1038	Economy	10200.00
0005433345469	1038	Economy	10200.00
0005433159375	1038	Economy	10200.00
0005433345477	1038	Economy	10200.00
0005433345287	1038	Economy	10200.00
0005432293281	1038	Economy	10200.00
0005433345460	1038	Economy	10200.00
0005433345579	1038	Economy	10200.00
0005433345541	1038	Economy	10200.00
0005433159374	1038	Economy	10200.00
0005433345577	1038	Economy	10200.00
0005433345705	1038	Economy	10200.00
0005433345601	1038	Economy	10200.00
0005433345306	1038	Economy	10200.00
0005433345131	1038	Economy	10200.00
0005433345276	1038	Economy	10200.00
0005433345580	1038	Economy	10200.00
0005433345288	1038	Economy	10200.00
0005433345410	1038	Economy	10200.00
0005435546229	1038	Economy	10200.00
0005433345362	1038	Economy	10200.00
0005433345319	1038	Economy	10200.00
0005433345688	1038	Economy	10200.00
0005433345275	1038	Economy	10200.00
0005433345551	1038	Economy	10200.00
0005433159372	1038	Economy	10200.00
0005433345736	1038	Economy	10200.00
0005433345783	1038	Economy	10200.00
0005433345189	1038	Economy	10200.00
0005433345343	1038	Economy	10200.00
0005433345558	1038	Economy	10200.00
0005433345594	1038	Economy	10200.00
0005433345439	1038	Economy	10200.00
0005433345866	1038	Economy	10200.00
0005433345510	1038	Economy	10200.00
0005433345083	1038	Economy	10200.00
0005433344762	1038	Economy	10200.00
0005433345497	1038	Economy	10200.00
0005433345318	1038	Economy	10200.00
0005433345314	1038	Economy	10200.00
0005435508738	17064	Business	30600.00
0005435092342	17064	Business	30600.00
0005435508734	17064	Business	30600.00
0005433346070	17064	Business	30600.00
0005433346080	17064	Business	30600.00
0005435508719	17064	Business	30600.00
0005433269877	17064	Business	30600.00
0005435508693	17064	Business	30600.00
0005433346076	17064	Business	30600.00
0005435508621	17064	Business	30600.00
0005435092313	17064	Business	30600.00
0005433346081	17064	Economy	10200.00
0005435530087	17064	Economy	10200.00
0005435508722	17064	Economy	10200.00
0005435092349	17064	Economy	10200.00
0005433346074	17064	Economy	10200.00
0005435508784	17064	Economy	10200.00
0005435508699	17064	Economy	10200.00
0005433346072	17064	Economy	10200.00
0005435530067	17064	Economy	10200.00
0005435508636	17064	Economy	10200.00
0005435545984	17064	Economy	10200.00
0005433346069	17064	Economy	10200.00
0005435530126	17064	Economy	10200.00
0005435530097	17064	Economy	10200.00
0005435545983	17064	Economy	10200.00
0005434445308	17064	Economy	10200.00
0005435530153	17064	Economy	10200.00
0005433346073	17064	Economy	10200.00
0005435092327	17064	Economy	10200.00
0005435530062	17064	Economy	10200.00
0005433346077	17064	Economy	10200.00
0005433346078	17064	Economy	10200.00
0005435530086	17064	Economy	10200.00
0005435092338	17064	Economy	10200.00
0005435508726	17064	Economy	10200.00
0005435508620	17064	Economy	10200.00
0005435530046	17064	Economy	10200.00
0005434445304	17064	Economy	10200.00
0005435092307	17064	Economy	10200.00
0005433346071	17064	Economy	10200.00
0005435508617	17064	Economy	10200.00
0005435508616	17064	Economy	10200.00
0005435508783	17064	Economy	10200.00
0005435508698	17064	Economy	10200.00
0005435508727	17064	Economy	10200.00
0005435530050	17064	Economy	10200.00
0005435508649	17064	Economy	10200.00
0005435092350	17064	Economy	10200.00
0005435508765	17064	Economy	10200.00
0005435530154	17064	Economy	10200.00
0005435508651	17064	Economy	10200.00
0005435508735	17064	Economy	10200.00
0005435508739	17064	Economy	10200.00
0005433346075	17064	Economy	10200.00
0005435530069	17064	Economy	10200.00
0005433346068	17064	Economy	10200.00
0005434445307	17064	Economy	10200.00
0005435530065	17064	Economy	10200.00
0005435092275	17064	Economy	10200.00
0005433346079	17064	Economy	10200.00
0005435092315	17064	Economy	10200.00
0005434082454	12777	Business	40300.00
0005434082504	12777	Business	40300.00
0005434069237	12777	Business	40300.00
0005434069354	12777	Business	40300.00
0005434069406	12777	Business	40300.00
0005434069335	12777	Business	40300.00
0005434069315	12777	Business	40300.00
0005433989871	12777	Business	40300.00
0005434082385	12777	Business	40300.00
0005434069281	12777	Economy	13400.00
0005434026746	12777	Economy	13400.00
0005434082560	12777	Economy	13400.00
0005434069276	12777	Economy	13400.00
0005434082505	12777	Economy	13400.00
0005434069524	12777	Economy	13400.00
0005434069416	12777	Economy	13400.00
0005434082404	12777	Economy	13400.00
0005434026756	12777	Economy	13400.00
0005434069081	12777	Economy	13400.00
0005434069309	12777	Economy	13400.00
0005435283553	12777	Economy	13400.00
0005434069188	12777	Economy	13400.00
0005434082533	12777	Economy	13400.00
0005434082548	12777	Economy	13400.00
0005434069541	12777	Economy	13400.00
0005435860641	12777	Economy	13400.00
0005434069471	12777	Economy	13400.00
0005434069058	12777	Economy	13400.00
0005434068993	12777	Economy	13400.00
0005434069594	12777	Economy	13400.00
0005434069586	12777	Economy	13400.00
0005434082430	12777	Economy	13400.00
0005433989893	12777	Economy	13400.00
0005434069367	12777	Economy	13400.00
0005434082403	12777	Economy	13400.00
0005434082476	12777	Economy	13400.00
0005434082415	12777	Economy	13400.00
0005434069189	12777	Economy	13400.00
0005434069371	12777	Economy	13400.00
0005434069065	12777	Economy	13400.00
0005434069115	12777	Economy	13400.00
0005434069180	12777	Economy	13400.00
0005434068959	12777	Economy	13400.00
0005434082566	12777	Economy	13400.00
0005434069121	12777	Economy	14800.00
0005434082378	12777	Economy	14800.00
0005434026755	12777	Economy	14800.00
0005433989882	12777	Economy	14800.00
0005434069011	12777	Economy	14800.00
0005434069310	12777	Economy	13400.00
0005434069301	12777	Economy	14800.00
0005434082581	12777	Economy	13400.00
0005434082472	12777	Economy	13400.00
0005434069114	12777	Economy	13400.00
0005434082473	12777	Economy	13400.00
0005434026752	12777	Economy	13400.00
0005434069409	12777	Economy	13400.00
0005434082379	12777	Economy	13400.00
0005434068950	12777	Economy	13400.00
0005433989894	12777	Economy	13400.00
0005434082409	12777	Economy	13400.00
0005434069454	12777	Economy	13400.00
0005435860642	12777	Economy	13400.00
0005434026747	12777	Economy	13400.00
0005434082523	12777	Economy	13400.00
0005434069257	12777	Economy	13400.00
0005434069155	12777	Economy	13400.00
0005434069370	12777	Economy	13400.00
0005434082455	12777	Economy	13400.00
0005434082471	12777	Economy	13400.00
0005434068849	12777	Economy	13400.00
0005434069095	12777	Economy	13400.00
0005434069368	12777	Economy	13400.00
0005434069518	12777	Economy	13400.00
0005434068952	12777	Economy	13400.00
0005435283554	12777	Economy	13400.00
0005434069236	12777	Economy	13400.00
0005434069455	12777	Economy	13400.00
0005434069274	12777	Economy	13400.00
0005434069146	12777	Economy	13400.00
0005434068992	12777	Economy	13400.00
0005434069383	12777	Economy	13400.00
0005434069382	12777	Economy	13400.00
0005434068951	12777	Economy	13400.00
0005434069211	12777	Economy	13400.00
0005434069150	12777	Economy	13400.00
0005434069122	12777	Economy	13400.00
0005434069208	12777	Economy	13400.00
0005434069324	12777	Economy	13400.00
0005434069380	12777	Economy	13400.00
0005434069162	12777	Economy	13400.00
0005434069542	12777	Economy	13400.00
0005434069059	12777	Economy	13400.00
0005434069094	12777	Economy	13400.00
0005433989872	12777	Economy	13400.00
0005434069120	12777	Economy	13400.00
0005433989876	12777	Economy	13400.00
0005434069258	12777	Economy	13400.00
0005435283552	12777	Economy	13400.00
0005434069191	12777	Economy	13400.00
0005434069334	12777	Economy	13400.00
0005434069417	12777	Economy	13400.00
0005434069275	12777	Economy	13400.00
0005434069369	12777	Economy	13400.00
0005434082542	12777	Economy	13400.00
0005434082565	12777	Economy	13400.00
0005434082580	12777	Economy	13400.00
0005434082362	12777	Economy	13400.00
0005434082399	12777	Economy	13400.00
0005434069262	12777	Economy	13400.00
0005434069512	12777	Economy	13400.00
0005434082529	12777	Economy	13400.00
0005434069523	12777	Economy	13400.00
0005434082521	12777	Economy	13400.00
0005434069405	12777	Economy	13400.00
0005434082547	12777	Economy	13400.00
0005432433823	30679	Business	40300.00
0005434082645	30679	Business	40300.00
0005433812953	30679	Business	40300.00
0005434082642	30679	Economy	13400.00
0005435283482	30679	Economy	13400.00
0005435283432	30679	Economy	13400.00
0005433812960	30679	Economy	13400.00
0005433812944	30679	Economy	13400.00
0005433812937	30679	Economy	13400.00
0005434026763	30679	Economy	13400.00
0005434069639	30679	Economy	13400.00
0005434069635	30679	Economy	13400.00
0005432150429	30679	Economy	13400.00
0005433812949	30679	Economy	13400.00
0005434069643	30679	Economy	14800.00
0005433812947	30679	Economy	13400.00
0005435283499	30679	Economy	13400.00
0005435283483	30679	Economy	13400.00
0005432150430	30679	Economy	13400.00
0005434069641	30679	Economy	13400.00
0005434069634	30679	Economy	13400.00
0005433812961	30679	Economy	13400.00
0005434082640	30679	Economy	13400.00
0005432433825	30679	Economy	13400.00
0005434082646	30679	Economy	13400.00
0005434082644	30679	Economy	13400.00
0005435283456	30679	Economy	13400.00
0005434069637	30679	Economy	13400.00
0005433812938	30679	Economy	13400.00
0005434069642	30679	Economy	13400.00
0005434082641	30679	Economy	13400.00
0005432150427	30679	Economy	13400.00
0005433812945	30679	Economy	13400.00
0005434069636	30679	Economy	13400.00
0005432150428	30679	Economy	13400.00
0005433812959	30679	Economy	13400.00
0005432433813	30679	Economy	13400.00
0005435283464	30679	Economy	13400.00
0005434069644	30679	Economy	13400.00
0005434082643	30679	Economy	13400.00
0005434069640	30679	Economy	13400.00
0005434069638	30679	Economy	13400.00
0005435463319	5538	Business	35300.00
0005434265798	5538	Business	35300.00
0005432535929	5538	Business	35300.00
0005434265729	5538	Business	35300.00
0005435463379	5538	Business	35300.00
0005435043313	5538	Business	35300.00
0005434265797	5538	Business	35300.00
0005432535960	5538	Business	35300.00
0005434265629	5538	Business	35300.00
0005435463378	5538	Business	35300.00
0005435463275	5538	Business	35300.00
0005434831272	5538	Business	35300.00
0005434265828	5538	Business	35300.00
0005435463320	5538	Business	35300.00
0005434265707	5538	Business	35300.00
0005435463274	5538	Business	35300.00
0005434265774	5538	Economy	12900.00
0005435463358	5538	Economy	12900.00
0005435463376	5538	Economy	11800.00
0005435463370	5538	Economy	11800.00
0005435768094	5538	Economy	11800.00
0005434265758	5538	Economy	11800.00
0005435463273	5538	Economy	11800.00
0005435732739	5538	Economy	11800.00
0005434265780	5538	Economy	11800.00
0005435463344	5538	Economy	11800.00
0005435463255	5538	Economy	11800.00
0005435463196	5538	Economy	11800.00
0005435463336	5538	Economy	11800.00
0005435463375	5538	Economy	11800.00
0005435463425	5538	Economy	11800.00
0005434265628	5538	Economy	11800.00
0005435723107	5538	Economy	11800.00
0005434265706	5538	Economy	11800.00
0005435463399	5538	Economy	11800.00
0005435768095	5538	Economy	11800.00
0005435463380	5538	Economy	11800.00
0005435463381	5538	Economy	11800.00
0005435768092	5538	Economy	11800.00
0005435463308	5538	Economy	11800.00
0005434265747	5538	Economy	11800.00
0005435463408	5538	Economy	11800.00
0005435723108	5538	Economy	11800.00
0005434265768	5538	Economy	11800.00
0005435463354	5538	Economy	11800.00
0005435463156	5538	Economy	11800.00
0005434265759	5538	Economy	11800.00
0005435463433	5538	Economy	11800.00
0005435732743	5538	Economy	11800.00
0005434265762	5538	Economy	11800.00
0005435463431	5538	Economy	11800.00
0005435732741	5538	Economy	11800.00
0005434265792	5538	Economy	11800.00
0005434265732	5538	Economy	11800.00
0005435463455	5538	Economy	11800.00
0005432535965	5538	Economy	11800.00
0005434265740	5538	Economy	11800.00
0005434265731	5538	Economy	11800.00
0005435463355	5538	Economy	11800.00
0005435043302	5538	Economy	11800.00
0005435768096	5538	Economy	11800.00
0005435463157	5538	Economy	11800.00
0005434265761	5538	Economy	11800.00
0005435732740	5538	Economy	11800.00
0005434831252	5538	Economy	11800.00
0005434265700	5538	Economy	12900.00
0005435735284	5538	Economy	11800.00
0005435043311	5538	Economy	11800.00
0005435768123	5538	Economy	11800.00
0005435463373	5538	Economy	11800.00
0005435463343	5538	Economy	11800.00
0005435732742	5538	Economy	11800.00
0005434265760	5538	Economy	11800.00
0005435463409	5538	Economy	11800.00
0005432535975	5538	Economy	11800.00
0005435463348	5538	Economy	11800.00
0005435463256	5538	Economy	11800.00
0005432535930	5538	Economy	11800.00
0005435732738	5538	Economy	11800.00
0005435463432	5538	Economy	11800.00
0005434265765	5538	Economy	11800.00
0005434265781	5538	Economy	11800.00
0005435463428	5538	Economy	11800.00
0005434265816	5538	Economy	11800.00
0005435463241	5538	Economy	11800.00
0005434265647	5538	Economy	11800.00
0005435463374	5538	Economy	11800.00
0005434265766	5538	Economy	11800.00
0005435463454	5538	Economy	11800.00
0005435463377	5538	Economy	11800.00
0005435043312	5538	Economy	11800.00
0005435463318	5538	Economy	11800.00
0005435725741	5538	Economy	11800.00
0005435463371	5538	Economy	11800.00
0005432535966	5538	Economy	11800.00
0005434265775	5538	Economy	11800.00
0005435768093	5538	Economy	11800.00
0005432535952	5538	Economy	11800.00
0005434265672	5538	Economy	11800.00
0005435463497	5538	Economy	11800.00
0005435767763	13462	Business	35300.00
0005433533387	13462	Business	35300.00
0005435767787	13462	Business	35300.00
0005435767559	13462	Business	35300.00
0005433533415	13462	Business	35300.00
0005433533400	13462	Business	35300.00
0005435767670	13462	Business	35300.00
0005435463532	13462	Business	35300.00
0005435767790	13462	Business	35300.00
0005433529336	13462	Business	35300.00
0005435723099	13462	Business	35300.00
0005435767666	13462	Business	35300.00
0005433529371	13462	Business	35300.00
0005435767652	13462	Business	35300.00
0005435767686	13462	Business	35300.00
0005435767706	13462	Business	35300.00
0005435767539	13462	Business	35300.00
0005435767719	13462	Business	35300.00
0005435767845	13462	Economy	12900.00
0005435767541	13462	Business	35300.00
0005433533392	13462	Economy	12900.00
0005435767640	13462	Economy	12900.00
0005435767698	13462	Economy	12900.00
0005435767226	13462	Economy	11800.00
0005435725719	13462	Economy	11800.00
0005435767843	13462	Economy	11800.00
0005433529366	13462	Economy	11800.00
0005434831288	13462	Economy	11800.00
0005435767660	13462	Economy	11800.00
0005435722118	13462	Economy	11800.00
0005435767553	13462	Economy	11800.00
0005435463534	13462	Economy	11800.00
0005433529368	13462	Economy	11800.00
0005435767776	13462	Economy	11800.00
0005435767783	13462	Economy	11800.00
0005433533381	13462	Economy	11800.00
0005435768019	13462	Economy	11800.00
0005433533406	13462	Economy	11800.00
0005433533384	13462	Economy	11800.00
0005435767981	13462	Economy	11800.00
0005435767996	13462	Economy	11800.00
0005435767916	13462	Economy	11800.00
0005435767653	13462	Economy	11800.00
0005435767735	13462	Economy	11800.00
0005435768118	13462	Economy	11800.00
0005435767854	13462	Economy	11800.00
0005435767887	13462	Economy	11800.00
0005435767768	13462	Economy	11800.00
0005433529339	13462	Economy	11800.00
0005433533401	13462	Economy	11800.00
0005433529367	13462	Economy	11800.00
0005433533394	13462	Economy	11800.00
0005435767736	13462	Economy	11800.00
0005433533414	13462	Economy	11800.00
0005434265900	13462	Economy	11800.00
0005433529337	13462	Economy	11800.00
0005435767934	13462	Economy	11800.00
0005435767734	13462	Economy	11800.00
0005433529357	13462	Economy	11800.00
0005433533413	13462	Economy	11800.00
0005435767855	13462	Economy	11800.00
0005435723100	13462	Economy	11800.00
0005435767770	13462	Economy	11800.00
0005433533409	13462	Economy	11800.00
0005435735250	13462	Economy	11800.00
0005434265898	13462	Economy	11800.00
0005435725724	13462	Economy	11800.00
0005435767750	13462	Economy	11800.00
0005435767941	13462	Economy	11800.00
0005435767861	13462	Economy	11800.00
0005433529349	13462	Economy	11800.00
0005434265899	13462	Economy	11800.00
0005435767687	13462	Economy	11800.00
0005435735249	13462	Economy	11800.00
0005435767956	13462	Economy	11800.00
0005435767808	13462	Economy	11800.00
0005435767688	13462	Economy	11800.00
0005435767955	13462	Economy	11800.00
0005435767890	13462	Economy	11800.00
0005435767555	13462	Economy	11800.00
0005435767620	13462	Economy	11800.00
0005433533391	13462	Economy	11800.00
0005433529350	13462	Economy	11800.00
0005435767891	13462	Economy	11800.00
0005435723095	13462	Economy	11800.00
0005435767329	13462	Economy	12900.00
0005435767502	13462	Economy	11800.00
0005435767809	13462	Economy	11800.00
0005435767747	13462	Economy	12900.00
0005434831290	13462	Economy	12900.00
0005435722119	13462	Economy	11800.00
0005435767844	13462	Economy	11800.00
0005435767755	13462	Economy	11800.00
0005435767710	13462	Economy	11800.00
0005433529338	13462	Economy	11800.00
0005435767651	13462	Economy	11800.00
0005433533380	13462	Economy	11800.00
0005435767694	13462	Economy	11800.00
0005433529354	13462	Economy	11800.00
0005435767816	13462	Economy	11800.00
0005435735248	13462	Economy	11800.00
0005435768018	13462	Economy	11800.00
0005435767671	13462	Economy	11800.00
0005435767540	13462	Economy	11800.00
0005435767988	13462	Economy	11800.00
0005433533402	13462	Economy	11800.00
0005433533390	13462	Economy	11800.00
0005433529369	13462	Economy	11800.00
0005435767851	13462	Economy	11800.00
0005433529361	13462	Economy	11800.00
0005435735260	13462	Economy	11800.00
0005435735240	13462	Economy	11800.00
0005435767828	13462	Economy	11800.00
0005435767643	13462	Economy	11800.00
0005433529356	13462	Economy	11800.00
0005434831289	13462	Economy	11800.00
0005435767772	13462	Economy	11800.00
0005435767328	13462	Economy	11800.00
0005435767754	13462	Economy	11800.00
0005433533399	13462	Economy	11800.00
0005435767466	13462	Economy	11800.00
0005435767907	13462	Economy	11800.00
0005433529370	13462	Economy	11800.00
0005435767560	13462	Economy	11800.00
0005433529355	13462	Economy	11800.00
0005435767874	13462	Economy	11800.00
0005433529351	13462	Economy	11800.00
0005435767773	13462	Economy	11800.00
0005433533398	13462	Economy	11800.00
0005435767544	13462	Economy	11800.00
0005435767588	13462	Economy	11800.00
0005433533412	13462	Economy	11800.00
0005435767658	13462	Economy	11800.00
0005435767788	13462	Economy	11800.00
0005435722102	13462	Economy	11800.00
0005433533397	13462	Economy	11800.00
0005435767523	13462	Economy	11800.00
0005435767619	13462	Economy	11800.00
0005435767642	13462	Economy	11800.00
0005435767866	13462	Economy	11800.00
0005433529352	13462	Economy	11800.00
0005435767625	13462	Economy	11800.00
0005435767522	13462	Economy	11800.00
0005435767860	13462	Economy	11800.00
0005435463533	13462	Economy	11800.00
0005435722116	13462	Economy	11800.00
0005435767769	13462	Economy	11800.00
0005433533393	13462	Economy	11800.00
0005435767859	13462	Economy	11800.00
0005433533386	13462	Economy	11800.00
0005433529365	13462	Economy	11800.00
0005434604974	18679	Economy	3300.00
0005434604995	18679	Economy	3300.00
0005434604994	18679	Economy	3300.00
0005434515034	19181	Economy	3300.00
0005434515033	19181	Economy	3300.00
0005434515035	19181	Economy	3300.00
0005434515040	19181	Economy	3300.00
0005434515039	19181	Economy	3300.00
0005435844407	4116	Business	88300.00
0005435846334	4116	Economy	29400.00
0005435846347	4116	Economy	29400.00
0005435844395	4116	Economy	29400.00
0005435844405	4116	Economy	29400.00
0005435844416	4116	Economy	32400.00
0005435844410	4116	Economy	32400.00
0005432649573	4116	Economy	29400.00
0005435844403	4116	Economy	29400.00
0005435844417	4116	Economy	29400.00
0005435846346	4116	Economy	29400.00
0005435844394	4116	Economy	29400.00
0005435844406	4116	Economy	29400.00
0005435846333	4116	Economy	29400.00
0005435846331	4116	Economy	29400.00
0005435846330	4116	Economy	29400.00
0005435844390	4116	Economy	29400.00
0005433286113	1810	Business	48700.00
0005433009666	1810	Business	48700.00
0005433810809	1810	Business	48700.00
0005433286114	1810	Business	48700.00
0005433286081	1810	Business	48700.00
0005433286073	1810	Business	48700.00
0005433285898	1810	Business	48700.00
0005433009464	1810	Business	48700.00
0005433286145	1810	Business	48700.00
0005433009695	1810	Business	48700.00
0005433286124	1810	Economy	16200.00
0005433009703	1810	Economy	16200.00
0005433009734	1810	Economy	16200.00
0005433286020	1810	Economy	16200.00
0005433009841	1810	Economy	16200.00
0005433009653	1810	Economy	16200.00
0005433009827	1810	Economy	17900.00
0005433810807	1810	Economy	17900.00
0005433009825	1810	Economy	17900.00
0005433286080	1810	Economy	17900.00
0005433009696	1810	Economy	16200.00
0005433009487	1810	Economy	16200.00
0005433009684	1810	Economy	16200.00
0005433286139	1810	Economy	16200.00
0005433009673	1810	Economy	16200.00
0005433009674	1810	Economy	16200.00
0005433286111	1810	Economy	16200.00
0005433009826	1810	Economy	16200.00
0005433286059	1810	Economy	16200.00
0005433286085	1810	Economy	16200.00
0005433009735	1810	Economy	16200.00
0005433286060	1810	Economy	16200.00
0005433810808	1810	Economy	16200.00
0005433009717	1810	Economy	16200.00
0005433009832	1810	Economy	16200.00
0005435097526	1810	Economy	16200.00
0005433009799	1810	Economy	16200.00
0005433285997	1810	Economy	16200.00
0005433286112	1810	Economy	16200.00
0005435732728	1810	Economy	16200.00
0005433009608	1810	Economy	16200.00
0005433286019	1810	Economy	16200.00
0005433009486	1810	Economy	16200.00
0005433286027	1810	Economy	16200.00
0005433009755	1810	Economy	16200.00
0005433286061	1810	Economy	16200.00
0005433009286	1810	Economy	16200.00
0005433286208	1810	Economy	16200.00
0005433286099	1810	Economy	16200.00
0005433285899	1810	Economy	16200.00
0005433009702	1810	Economy	16200.00
0005433009721	1810	Economy	16200.00
0005433286074	1810	Economy	16200.00
0005433286159	1810	Economy	16200.00
0005435732727	1810	Economy	16200.00
0005433286098	1810	Economy	16200.00
0005433009858	1810	Economy	16200.00
0005433009485	1810	Economy	16200.00
0005433009465	1810	Economy	16200.00
0005433286115	1810	Economy	16200.00
0005433286057	1810	Economy	16200.00
0005433009812	1810	Economy	16200.00
0005435097523	1810	Economy	16200.00
0005433009463	1810	Economy	16200.00
0005433810810	1810	Economy	16200.00
0005435097524	1810	Economy	16200.00
0005433286207	1810	Economy	16200.00
0005433009770	1810	Economy	16200.00
0005433009781	1810	Economy	16200.00
0005433009722	1810	Economy	16200.00
0005433009866	1810	Economy	16200.00
0005433009788	1810	Economy	16200.00
0005433009773	1810	Economy	16200.00
0005435732729	1810	Economy	16200.00
0005435097525	1810	Economy	16200.00
0005433009772	1810	Economy	16200.00
0005433009789	1810	Economy	16200.00
0005433810650	22521	Economy	16200.00
0005433810656	22521	Economy	17900.00
0005433810641	22521	Economy	16200.00
0005433810617	22521	Economy	16200.00
0005433810655	22521	Economy	16200.00
0005433810657	22521	Economy	16200.00
0005433810640	22521	Economy	16200.00
0005433810685	22521	Economy	16200.00
0005433286226	22521	Economy	16200.00
0005433286227	22521	Economy	16200.00
0005433286228	22521	Economy	16200.00
0005433810651	22521	Economy	16200.00
0005433009972	22521	Economy	16200.00
0005433286224	22521	Economy	16200.00
0005433810616	22521	Economy	16200.00
0005433009969	22521	Economy	16200.00
0005433009971	22521	Economy	16200.00
0005433009970	22521	Economy	16200.00
0005433810693	22521	Economy	16200.00
0005433286225	22521	Economy	16200.00
0005435283042	5582	Business	99800.00
0005433815565	5582	Business	99800.00
0005435283112	5582	Business	99800.00
0005435283154	5582	Business	99800.00
0005433815566	5582	Business	99800.00
0005434173617	5582	Business	99800.00
0005435283192	5582	Economy	33300.00
0005435283149	5582	Economy	33300.00
0005435282981	5582	Economy	33300.00
0005434173632	5582	Economy	33300.00
0005435283084	5582	Economy	33300.00
0005435283170	5582	Economy	33300.00
0005433848410	5582	Economy	33300.00
0005433848409	5582	Economy	33300.00
0005435283158	5582	Economy	33300.00
0005435283183	5582	Economy	33300.00
0005435283155	5582	Economy	33300.00
0005433815564	5582	Economy	33300.00
0005435283081	5582	Economy	33300.00
0005435283111	5582	Economy	33300.00
0005434173633	5582	Economy	33300.00
0005435283046	5582	Economy	33300.00
0005435283070	5582	Economy	33300.00
0005435283083	5582	Economy	33300.00
0005435283071	5582	Economy	33300.00
0005435283169	5582	Economy	33300.00
0005434173618	5582	Economy	33300.00
0005435283089	5582	Economy	33300.00
0005435283148	5582	Economy	33300.00
0005435283156	5582	Economy	33300.00
0005433815503	13852	Business	99800.00
0005433848273	13852	Business	99800.00
0005433848358	13852	Business	99800.00
0005433848202	13852	Business	99800.00
0005433848170	13852	Business	99800.00
0005433848237	13852	Business	99800.00
0005433848021	13852	Business	99800.00
0005433848027	13852	Business	99800.00
0005433848201	13852	Business	99800.00
0005433848120	13852	Economy	33300.00
0005433848065	13852	Economy	33300.00
0005433847978	13852	Economy	33300.00
0005433848134	13852	Economy	33300.00
0005433848207	13852	Economy	33300.00
0005433848119	13852	Economy	33300.00
0005433847974	13852	Economy	33300.00
0005433848024	13852	Economy	33300.00
0005433848064	13852	Economy	33300.00
0005433848155	13852	Economy	36600.00
0005433848077	13852	Economy	33300.00
0005433848025	13852	Economy	33300.00
0005433848043	13852	Economy	33300.00
0005433848166	13852	Economy	33300.00
0005433848216	13852	Economy	33300.00
0005433848248	13852	Economy	33300.00
0005433847977	13852	Economy	33300.00
0005433848108	13852	Economy	33300.00
0005433848217	13852	Economy	33300.00
0005433848249	13852	Economy	33300.00
0005433848042	13852	Economy	33300.00
0005433847895	13852	Economy	33300.00
0005433848132	13852	Economy	33300.00
0005433848101	13852	Economy	33300.00
0005433848013	13852	Economy	33300.00
0005433848274	13852	Economy	33300.00
0005434173635	13852	Economy	33300.00
0005433848133	13852	Economy	33300.00
0005433848056	13852	Economy	33300.00
0005433848051	13852	Economy	33300.00
0005433815515	13852	Economy	33300.00
0005433847936	13852	Economy	33300.00
0005433848218	13852	Economy	33300.00
0005433848264	13852	Economy	33300.00
0005433848044	13852	Economy	33300.00
0005433848256	13852	Economy	33300.00
0005433848041	13852	Economy	33300.00
0005433847952	13852	Economy	33300.00
0005433848359	13852	Economy	33300.00
0005435283251	13852	Economy	33300.00
0005433815504	13852	Economy	33300.00
0005433815489	13852	Economy	33300.00
0005433848107	13852	Economy	33300.00
0005433815508	13852	Economy	33300.00
0005433848307	13852	Economy	33300.00
0005433848236	13852	Economy	33300.00
0005433848020	13852	Economy	33300.00
0005433848023	13852	Economy	33300.00
0005433848215	13852	Economy	33300.00
0005433848162	13852	Economy	33300.00
0005433848283	13852	Economy	33300.00
0005432003797	13852	Economy	33300.00
0005433848304	13852	Economy	33300.00
0005433848231	13852	Economy	33300.00
0005432112581	7812	Economy	16600.00
0005435332586	7812	Economy	15100.00
0005435332595	7812	Economy	15100.00
0005432112582	7812	Economy	15100.00
0005435332576	7812	Economy	15100.00
0005435332575	7812	Economy	15100.00
0005435332568	7812	Economy	15100.00
0005435332638	7812	Economy	15100.00
0005435332623	7812	Economy	15100.00
0005435332594	7812	Economy	15100.00
0005435332577	7812	Economy	15100.00
0005434621052	32985	Economy	15100.00
0005434621057	32985	Economy	15100.00
0005434621075	32985	Economy	15100.00
0005434621099	32985	Economy	15100.00
0005434621138	32985	Economy	15100.00
0005434621053	32985	Economy	15100.00
0005434621139	32985	Economy	15100.00
0005434621013	32985	Economy	15100.00
0005434621123	32985	Economy	15100.00
0005434621158	32985	Economy	15100.00
0005434621126	32985	Economy	15100.00
0005434621026	32985	Economy	15100.00
0005435332643	32985	Economy	15100.00
0005434621012	32985	Economy	15100.00
0005435918770	4257	Business	38000.00
0005435937509	4257	Economy	12700.00
0005435937516	4257	Economy	13900.00
0005435918778	4257	Economy	13900.00
0005435918767	4257	Economy	12700.00
0005435918780	4257	Economy	12700.00
0005435937543	4257	Economy	12700.00
0005435937475	4257	Economy	12700.00
0005435937474	4257	Economy	12700.00
0005435918771	4257	Economy	12700.00
0005435786364	4257	Economy	12700.00
0005435937526	4257	Economy	12700.00
0005435918784	4257	Economy	12700.00
0005435937524	4257	Economy	12700.00
0005435786367	4257	Economy	12700.00
0005435937506	4257	Economy	12700.00
0005435918779	4257	Economy	12700.00
0005435937517	4257	Economy	12700.00
0005435786365	4257	Economy	12700.00
0005435937518	4257	Economy	12700.00
0005435786366	4257	Economy	12700.00
0005435786179	27293	Business	38000.00
0005435786312	27293	Business	38000.00
0005435786046	27293	Business	38000.00
0005435786151	27293	Business	38000.00
0005434994250	27293	Business	38000.00
0005434994249	27293	Economy	12700.00
0005435785963	27293	Economy	12700.00
0005435786068	27293	Economy	12700.00
0005435786131	27293	Economy	12700.00
0005435786227	27293	Economy	12700.00
0005435786152	27293	Economy	13900.00
0005435786177	27293	Economy	13900.00
0005434994292	27293	Economy	13900.00
0005434994272	27293	Economy	13900.00
0005435786163	27293	Economy	13900.00
0005435786149	27293	Economy	12700.00
0005434994244	27293	Economy	12700.00
0005435786054	27293	Economy	12700.00
0005435786107	27293	Economy	12700.00
0005435786136	27293	Economy	12700.00
0005434994245	27293	Economy	12700.00
0005435937573	27293	Economy	12700.00
0005435786132	27293	Economy	12700.00
0005435786335	27293	Economy	12700.00
0005435786087	27293	Economy	12700.00
0005432195757	27293	Economy	12700.00
0005435786088	27293	Economy	12700.00
0005435786092	27293	Economy	12700.00
0005435786053	27293	Economy	12700.00
0005435786334	27293	Economy	12700.00
0005434994242	27293	Economy	12700.00
0005434994247	27293	Economy	12700.00
0005435786164	27293	Economy	12700.00
0005435786176	27293	Economy	12700.00
0005435786228	27293	Economy	12700.00
0005435786141	27293	Economy	12700.00
0005435786052	27293	Economy	12700.00
0005435786263	27293	Economy	12700.00
0005435786113	27293	Economy	12700.00
0005434994271	27293	Economy	12700.00
0005434082648	4753	Business	40900.00
0005435840462	4753	Business	40900.00
0005435840441	4753	Economy	15000.00
0005432569418	4753	Economy	13600.00
0005432569419	4753	Economy	13600.00
0005432461433	4753	Economy	13600.00
0005434082652	4753	Economy	13600.00
0005432569423	4753	Economy	13600.00
0005432461430	4753	Economy	13600.00
0005434082651	4753	Economy	13600.00
0005432569421	4753	Economy	13600.00
0005434150154	4753	Economy	13600.00
0005432569420	4753	Economy	13600.00
0005435840440	4753	Economy	13600.00
0005434082647	4753	Economy	13600.00
0005435840463	4753	Economy	15000.00
0005434150153	4753	Economy	13600.00
0005432461436	4753	Economy	13600.00
0005435840464	4753	Economy	13600.00
0005435840433	4753	Economy	13600.00
0005435840454	4753	Economy	13600.00
0005435840437	4753	Economy	13600.00
0005432461435	4753	Economy	13600.00
0005432569417	4753	Economy	13600.00
0005434082650	4753	Economy	13600.00
0005432461434	4753	Economy	13600.00
0005435840380	4753	Economy	13600.00
0005432461431	4753	Economy	13600.00
0005432461432	4753	Economy	13600.00
0005432569422	4753	Economy	13600.00
0005432569416	4753	Economy	13600.00
0005434082649	4753	Economy	13600.00
0005432461223	30564	Business	40900.00
0005432569157	30564	Business	40900.00
0005434082403	30564	Business	40900.00
0005432461197	30564	Business	40900.00
0005432569090	30564	Business	40900.00
0005432460957	30564	Business	40900.00
0005434082560	30564	Business	40900.00
0005434082385	30564	Business	40900.00
0005434082379	30564	Business	40900.00
0005432461142	30564	Business	40900.00
0005432461018	30564	Business	40900.00
0005434082378	30564	Business	40900.00
0005434082523	30564	Business	40900.00
0005432569049	30564	Business	40900.00
0005432461084	30564	Business	40900.00
0005434082504	30564	Business	40900.00
0005432568994	30564	Business	40900.00
0005432461174	30564	Business	40900.00
0005432568973	30564	Business	40900.00
0005434082476	30564	Business	40900.00
0005434082473	30564	Economy	15000.00
0005434082533	30564	Economy	15000.00
0005432569050	30564	Economy	15000.00
0005434082542	30564	Economy	13600.00
0005432569269	30564	Economy	13600.00
0005432569270	30564	Economy	13600.00
0005432461046	30564	Economy	13600.00
0005434082566	30564	Economy	13600.00
0005432461222	30564	Economy	13600.00
0005432461092	30564	Economy	13600.00
0005433452794	30564	Economy	13600.00
0005432569092	30564	Economy	13600.00
0005434082415	30564	Economy	13600.00
0005432461270	30564	Economy	13600.00
0005432460849	30564	Economy	13600.00
0005432461232	30564	Economy	13600.00
0005434082505	30564	Economy	13600.00
0005434082362	30564	Economy	13600.00
0005432568876	30564	Economy	13600.00
0005432461250	30564	Economy	13600.00
0005432461252	30564	Economy	13600.00
0005432461289	30564	Economy	13600.00
0005432569290	30564	Economy	13600.00
0005432461045	30564	Economy	13600.00
0005432461070	30564	Economy	13600.00
0005432461383	30564	Economy	13600.00
0005432461326	30564	Economy	13600.00
0005432461005	30564	Economy	13600.00
0005432460910	30564	Economy	13600.00
0005434082581	30564	Economy	13600.00
0005432461246	30564	Economy	13600.00
0005432569132	30564	Economy	13600.00
0005432569218	30564	Economy	13600.00
0005434082521	30564	Economy	13600.00
0005432569145	30564	Economy	13600.00
0005432569287	30564	Economy	13600.00
0005432569033	30564	Economy	13600.00
0005432571434	30564	Economy	13600.00
0005434082399	30564	Economy	13600.00
0005434082404	30564	Economy	13600.00
0005432461069	30564	Economy	13600.00
0005432461283	30564	Economy	13600.00
0005432568972	30564	Economy	13600.00
0005432569245	30564	Economy	13600.00
0005432569286	30564	Economy	13600.00
0005432461218	30564	Economy	13600.00
0005432569058	30564	Economy	13600.00
0005432461059	30564	Economy	13600.00
0005432569265	30564	Economy	13600.00
0005432461224	30564	Economy	13600.00
0005432461166	30564	Economy	13600.00
0005432460958	30564	Economy	13600.00
0005434082548	30564	Economy	13600.00
0005434082547	30564	Economy	13600.00
0005432569125	30564	Economy	13600.00
0005432461173	30564	Economy	13600.00
0005432569288	30564	Economy	13600.00
0005432461121	30564	Economy	13600.00
0005432461180	30564	Economy	13600.00
0005434082409	30564	Economy	13600.00
0005432461247	30564	Economy	13600.00
0005432460911	30564	Economy	13600.00
0005434082565	30564	Economy	13600.00
0005432460848	30564	Economy	13600.00
0005432569034	30564	Economy	13600.00
0005432569268	30564	Economy	13600.00
0005432461290	30564	Economy	13600.00
0005432461062	30564	Economy	13600.00
0005432461141	30564	Economy	13600.00
0005434082430	30564	Economy	15000.00
0005432569238	30564	Economy	13600.00
0005435860641	30564	Economy	13600.00
0005432569031	30564	Economy	15000.00
0005432569089	30564	Economy	15000.00
0005432461211	30564	Economy	13600.00
0005432461043	30564	Economy	13600.00
0005432569222	30564	Economy	13600.00
0005432461251	30564	Economy	13600.00
0005435860642	30564	Economy	13600.00
0005434082471	30564	Economy	13600.00
0005432569173	30564	Economy	13600.00
0005432569255	30564	Economy	13600.00
0005432569217	30564	Economy	13600.00
0005432461113	30564	Economy	13600.00
0005432569213	30564	Economy	13600.00
0005432569093	30564	Economy	13600.00
0005432569158	30564	Economy	13600.00
0005432569160	30564	Economy	13600.00
0005432569030	30564	Economy	13600.00
0005434082454	30564	Economy	13600.00
0005432569244	30564	Economy	13600.00
0005432569276	30564	Economy	13600.00
0005432461230	30564	Economy	13600.00
0005432569152	30564	Economy	13600.00
0005432461171	30564	Economy	13600.00
0005432569214	30564	Economy	13600.00
0005432461233	30564	Economy	13600.00
0005432461341	30564	Economy	13600.00
0005432461067	30564	Economy	13600.00
0005432569051	30564	Economy	13600.00
0005432571409	30564	Economy	13600.00
0005432461231	30564	Economy	13600.00
0005432569156	30564	Economy	13600.00
0005432569289	30564	Economy	13600.00
0005432461058	30564	Economy	13600.00
0005434082472	30564	Economy	13600.00
0005432461044	30564	Economy	13600.00
0005432461126	30564	Economy	13600.00
0005432461083	30564	Economy	13600.00
0005432461019	30564	Economy	13600.00
0005433452790	30564	Economy	13600.00
0005432569144	30564	Economy	13600.00
0005434150236	30564	Economy	13600.00
0005432569035	30564	Economy	13600.00
0005432460956	30564	Economy	13600.00
0005432461143	30564	Economy	13600.00
0005432461060	30564	Economy	13600.00
0005432461130	30564	Economy	13600.00
0005432569059	30564	Economy	13600.00
0005434082529	30564	Economy	13600.00
0005432461105	30564	Economy	13600.00
0005434150235	30564	Economy	13600.00
0005432461265	30564	Economy	13600.00
0005432461287	30564	Economy	13600.00
0005434082580	30564	Economy	13600.00
0005432569252	30564	Economy	13600.00
0005432568922	30564	Economy	13600.00
0005432461288	30564	Economy	13600.00
0005434082455	30564	Economy	13600.00
0005435722105	21191	Economy	9900.00
0005435722117	21191	Economy	9900.00
0005435720163	21191	Economy	9900.00
0005435722103	21191	Economy	9900.00
0005435732728	22797	Economy	8800.00
0005435732729	22797	Economy	8800.00
0005435732727	22797	Economy	8800.00
0005435530107	11131	Business	23600.00
0005435508717	11131	Business	23600.00
0005435530147	11131	Business	23600.00
0005435530112	11131	Business	23600.00
0005435508721	11131	Business	23600.00
0005435530131	11131	Business	23600.00
0005435508724	11131	Business	23600.00
0005435530091	11131	Economy	7900.00
0005435097500	11131	Economy	7900.00
0005435530093	11131	Economy	7900.00
0005433346083	11131	Economy	7900.00
0005433346084	11131	Economy	7900.00
0005435508793	11131	Economy	7900.00
0005435097501	11131	Economy	7900.00
0005435530047	11131	Economy	7900.00
0005435508703	11131	Economy	7900.00
0005435508596	11131	Economy	8600.00
0005435508794	11131	Economy	8600.00
0005435530135	11131	Economy	8600.00
0005435530136	11131	Economy	7900.00
0005435508766	11131	Economy	7900.00
0005435508635	11131	Economy	7900.00
0005435508706	11131	Economy	7900.00
0005435097502	11131	Economy	7900.00
0005435508697	11131	Economy	7900.00
0005435097503	11131	Economy	7900.00
0005435530102	11131	Economy	7900.00
0005435530134	11131	Economy	7900.00
0005435530095	11131	Economy	7900.00
0005435508705	11131	Economy	7900.00
0005435530094	11131	Economy	7900.00
0005435530054	11131	Economy	7900.00
0005435530146	11131	Economy	7900.00
0005435530133	11131	Economy	7900.00
0005435508723	11131	Economy	7900.00
0005435508716	11131	Economy	7900.00
0005435508597	11131	Economy	7900.00
0005435530127	11131	Economy	7900.00
0005435508631	11131	Economy	7900.00
0005435530010	11131	Economy	7900.00
0005435508720	11131	Economy	7900.00
0005435530030	11131	Economy	7900.00
0005435508804	11131	Economy	7900.00
0005435545982	11131	Economy	7900.00
0005433346082	11131	Economy	7900.00
0005435508704	11131	Economy	7900.00
0005433345371	17130	Business	23600.00
0005433345923	17130	Business	23600.00
0005433345315	17130	Business	23600.00
0005433345853	17130	Business	23600.00
0005433345190	17130	Business	23600.00
0005433345287	17130	Business	23600.00
0005433345600	17130	Business	23600.00
0005433345310	17130	Business	23600.00
0005433345693	17130	Business	23600.00
0005433345523	17130	Business	23600.00
0005433345925	17130	Business	23600.00
0005433345620	17130	Business	23600.00
0005433345471	17130	Economy	7900.00
0005433345357	17130	Economy	7900.00
0005433345577	17130	Economy	7900.00
0005435097478	17130	Economy	7900.00
0005433345538	17130	Economy	7900.00
0005433345596	17130	Economy	7900.00
0005433345580	17130	Economy	7900.00
0005435545975	17130	Economy	7900.00
0005433345510	17130	Economy	7900.00
0005433345532	17130	Economy	7900.00
0005433345852	17130	Economy	7900.00
0005433345619	17130	Economy	7900.00
0005433345686	17130	Economy	7900.00
0005433345192	17130	Economy	7900.00
0005433345783	17130	Economy	7900.00
0005433345477	17130	Economy	7900.00
0005435097441	17130	Economy	7900.00
0005433344813	17130	Economy	7900.00
0005433345924	17130	Economy	7900.00
0005433345808	17130	Economy	7900.00
0005433345363	17130	Economy	7900.00
0005433345410	17130	Economy	7900.00
0005433345405	17130	Economy	7900.00
0005433345687	17130	Economy	7900.00
0005433345567	17130	Economy	7900.00
0005433345288	17130	Economy	7900.00
0005432293281	17130	Economy	7900.00
0005433345689	17130	Economy	7900.00
0005435546230	17130	Economy	7900.00
0005433345276	17130	Economy	7900.00
0005433345521	17130	Economy	7900.00
0005433345736	17130	Economy	7900.00
0005435097403	17130	Economy	7900.00
0005433345131	17130	Economy	7900.00
0005433345541	17130	Economy	7900.00
0005435546232	17130	Economy	7900.00
0005433345595	17130	Economy	7900.00
0005435546231	17130	Economy	7900.00
0005435097448	17130	Economy	7900.00
0005435546229	17130	Economy	7900.00
0005433345565	17130	Economy	8600.00
0005435097449	17130	Economy	8600.00
0005433345498	17130	Economy	8600.00
0005433345306	17130	Economy	8600.00
0005433345524	17130	Economy	8600.00
0005433345509	17130	Economy	8600.00
0005435545976	17130	Economy	7900.00
0005435546002	17130	Economy	7900.00
0005433345673	17130	Economy	7900.00
0005433345705	17130	Economy	7900.00
0005433345558	17130	Economy	7900.00
0005433345087	17130	Economy	7900.00
0005433345486	17130	Economy	7900.00
0005433344812	17130	Economy	7900.00
0005433345275	17130	Economy	7900.00
0005433345485	17130	Economy	7900.00
0005433345494	17130	Economy	7900.00
0005433345493	17130	Economy	7900.00
0005433345469	17130	Economy	7900.00
0005435097482	17130	Economy	7900.00
0005433345293	17130	Economy	7900.00
0005433344762	17130	Economy	7900.00
0005433345522	17130	Economy	7900.00
0005435097425	17130	Economy	7900.00
0005433345188	17130	Economy	7900.00
0005433345551	17130	Economy	7900.00
0005433345554	17130	Economy	7900.00
0005433345462	17130	Economy	7900.00
0005433345269	17130	Economy	7900.00
0005433345343	17130	Economy	7900.00
0005433345566	17130	Economy	7900.00
0005433345642	17130	Economy	7900.00
0005433345307	17130	Economy	7900.00
0005433345362	17130	Economy	7900.00
0005433345460	17130	Economy	7900.00
0005435097426	17130	Economy	7900.00
0005433345832	17130	Economy	7900.00
0005433345470	17130	Economy	7900.00
0005433345094	17130	Economy	7900.00
0005433345621	17130	Economy	7900.00
0005433345692	17130	Economy	7900.00
0005433345581	17130	Economy	7900.00
0005433345408	17130	Economy	7900.00
0005433345594	17130	Economy	7900.00
0005433345193	17130	Economy	7900.00
0005433345267	17130	Economy	7900.00
0005433345854	17130	Economy	7900.00
0005433345491	17130	Economy	7900.00
0005433345690	17130	Economy	7900.00
0005433345688	17130	Economy	7900.00
0005433345579	17130	Economy	7900.00
0005435097429	17130	Economy	7900.00
0005433345314	17130	Economy	7900.00
0005433345525	17130	Economy	7900.00
0005433345722	17130	Economy	7900.00
0005433345601	17130	Economy	7900.00
0005433345544	17130	Economy	7900.00
0005433345319	17130	Economy	7900.00
0005433345409	17130	Economy	7900.00
0005433345189	17130	Economy	7900.00
0005433345531	17130	Economy	7900.00
0005433345463	17130	Economy	7900.00
0005433345833	17130	Economy	7900.00
0005433345130	17130	Economy	7900.00
0005433345438	17130	Economy	7900.00
0005433345539	17130	Economy	7900.00
0005433345647	17130	Economy	7900.00
0005433345439	17130	Economy	7900.00
0005433345676	17130	Economy	7900.00
0005433345909	17130	Economy	7900.00
0005433345083	17130	Economy	7900.00
0005433345497	17130	Economy	7900.00
0005433345715	17130	Economy	7900.00
0005433345866	17130	Economy	7900.00
0005433345268	17130	Economy	7900.00
0005433345639	17130	Economy	7900.00
0005433345318	17130	Economy	7900.00
0005434159036	9067	Business	26600.00
0005432920212	9067	Business	26600.00
0005434159031	9067	Business	26600.00
0005432920391	9067	Business	26600.00
0005432920375	9067	Economy	8900.00
0005432920322	9067	Economy	8900.00
0005432920324	9067	Economy	9800.00
0005433507732	9067	Economy	9800.00
0005432920303	9067	Economy	8900.00
0005434159030	9067	Economy	8900.00
0005432920351	9067	Economy	8900.00
0005432920323	9067	Economy	8900.00
0005432920302	9067	Economy	8900.00
0005432920211	9067	Economy	8900.00
0005433477293	9067	Economy	8900.00
0005432920339	9067	Economy	8900.00
0005434159033	9067	Economy	8900.00
0005432920256	9067	Economy	8900.00
0005432920392	9067	Economy	8900.00
0005432920393	9067	Economy	8900.00
0005432920394	9067	Economy	8900.00
0005433477292	9067	Economy	8900.00
0005432920417	9067	Economy	8900.00
0005434159044	9067	Economy	8900.00
0005434159035	9067	Economy	8900.00
0005432920305	9067	Economy	8900.00
0005433507661	20478	Business	26600.00
0005433481360	20478	Business	26600.00
0005433481357	20478	Business	26600.00
0005433507664	20478	Business	26600.00
0005433507720	20478	Business	26600.00
0005432920481	20478	Business	26600.00
0005433507654	20478	Business	26600.00
0005433477184	20478	Economy	8900.00
0005433477195	20478	Economy	8900.00
0005433477101	20478	Economy	8900.00
0005433477169	20478	Economy	8900.00
0005433507689	20478	Economy	8900.00
0005433507691	20478	Economy	8900.00
0005433477007	20478	Economy	8900.00
0005433477120	20478	Economy	8900.00
0005433507655	20478	Economy	9800.00
0005433477211	20478	Economy	8900.00
0005433481339	20478	Economy	8900.00
0005433481358	20478	Economy	8900.00
0005433507665	20478	Economy	8900.00
0005433507638	20478	Economy	8900.00
0005433477185	20478	Economy	8900.00
0005433481375	20478	Economy	8900.00
0005433477262	20478	Economy	8900.00
0005433477171	20478	Economy	8900.00
0005433477085	20478	Economy	8900.00
0005433477241	20478	Economy	8900.00
0005433477240	20478	Economy	8900.00
0005433477086	20478	Economy	8900.00
0005433477136	20478	Economy	8900.00
0005433481338	20478	Economy	8900.00
0005433507695	20478	Economy	8900.00
0005433477019	20478	Economy	8900.00
0005433477052	20478	Economy	8900.00
0005433477155	20478	Economy	8900.00
0005433477225	20478	Economy	8900.00
0005433477100	20478	Economy	8900.00
0005433477263	20478	Economy	8900.00
0005433477201	20478	Economy	8900.00
0005433507696	20478	Economy	8900.00
0005433477020	20478	Economy	8900.00
0005432920482	20478	Economy	8900.00
0005433477202	20478	Economy	8900.00
0005433477179	20478	Economy	8900.00
0005435179010	10176	Economy	5800.00
0005435179710	10176	Economy	5800.00
0005432400213	18315	Economy	5800.00
0005432400217	18315	Economy	5800.00
0005432396351	18315	Economy	5800.00
0005432396350	18315	Economy	5800.00
0005432396336	18315	Economy	5800.00
0005432400218	18315	Economy	5800.00
0005435626681	10968	Business	9500.00
0005435127277	10968	Business	9500.00
0005435626677	10968	Business	9500.00
0005435626679	10968	Business	9500.00
0005435127344	10968	Business	9500.00
0005435127259	10968	Business	9500.00
0005435626658	10968	Business	9500.00
0005435626637	10968	Business	9500.00
0005435556745	10968	Economy	3200.00
0005435626541	10968	Economy	3200.00
0005435127348	10968	Economy	3200.00
0005435626670	10968	Economy	3200.00
0005435626688	10968	Economy	3200.00
0005435626627	10968	Economy	3200.00
0005435554308	10968	Economy	3200.00
0005435127260	10968	Economy	3200.00
0005435127370	10968	Economy	3500.00
0005435127278	10968	Economy	3500.00
0005435127315	10968	Economy	3500.00
0005435127454	10968	Economy	3200.00
0005435127326	10968	Economy	3200.00
0005435556757	10968	Economy	3200.00
0005435626663	10968	Economy	3200.00
0005435127346	10968	Economy	3200.00
0005435127276	10968	Economy	3200.00
0005435626540	10968	Economy	3200.00
0005435626638	10968	Economy	3200.00
0005435127409	10968	Economy	3200.00
0005435626632	10968	Economy	3200.00
0005435127254	10968	Economy	3200.00
0005435556754	10968	Economy	3200.00
0005435127302	10968	Economy	3200.00
0005435127337	10968	Economy	3200.00
0005435626636	10968	Economy	3200.00
0005435127291	10968	Economy	3200.00
0005435127253	10968	Economy	3200.00
0005435127386	10968	Economy	3200.00
0005435127336	10968	Economy	3200.00
0005435556756	10968	Economy	3200.00
0005435127345	10968	Economy	3200.00
0005435127347	10968	Economy	3200.00
0005435127402	10968	Economy	3200.00
0005435626657	10968	Economy	3200.00
0005435626680	10968	Economy	3200.00
0005435127410	10968	Economy	3200.00
0005435626588	10968	Economy	3200.00
0005435626635	10968	Economy	3200.00
0005435127305	10968	Economy	3200.00
0005435626587	10968	Economy	3200.00
0005435127304	10968	Economy	3200.00
0005435127179	10968	Economy	3200.00
0005435626666	10968	Economy	3200.00
0005435626662	10968	Economy	3200.00
0005435556755	10968	Economy	3200.00
0005435626678	10968	Economy	3200.00
0005435127279	10968	Economy	3200.00
0005435127453	10968	Economy	3200.00
0005435127375	10968	Economy	3200.00
0005435127314	10968	Economy	3200.00
0005435127452	10968	Economy	3200.00
0005435127585	14747	Economy	3200.00
0005434411881	14747	Economy	3200.00
0005434411887	14747	Economy	3200.00
0005435626865	14747	Economy	3200.00
0005435626864	14747	Economy	3200.00
0005435626866	14747	Economy	3200.00
0005435127586	14747	Economy	3200.00
0005434411880	14747	Economy	3200.00
0005435626863	14747	Economy	3200.00
0005435127587	14747	Economy	3200.00
0005435626867	14747	Economy	3200.00
0005435179422	7121	Business	86900.00
0005435216649	7121	Business	86900.00
0005435443549	7121	Business	86900.00
0005435216640	7121	Economy	29000.00
0005435216650	7121	Economy	29000.00
0005435443573	7121	Economy	29000.00
0005435179420	7121	Economy	29000.00
0005435221072	7121	Economy	29000.00
0005435216641	7121	Economy	29000.00
0005432400223	7121	Economy	29000.00
0005435443574	7121	Economy	29000.00
0005435179421	7121	Economy	29000.00
0005435216638	7121	Economy	29000.00
0005435443542	7121	Economy	29000.00
0005435219247	7121	Economy	29000.00
0005432398304	7121	Economy	29000.00
0005435178536	7121	Economy	29000.00
0005432398276	27101	Business	86900.00
0005435715868	27101	Business	86900.00
0005432398295	27101	Business	86900.00
0005435715942	27101	Business	86900.00
0005432394188	27101	Business	86900.00
0005432394197	27101	Business	86900.00
0005432398272	27101	Economy	29000.00
0005435715851	27101	Economy	29000.00
0005435715968	27101	Economy	29000.00
0005435715852	27101	Economy	31900.00
0005435216655	27101	Economy	31900.00
0005435715900	27101	Economy	29000.00
0005432398273	27101	Economy	29000.00
0005432394196	27101	Economy	29000.00
0005432398296	27101	Economy	29000.00
0005432394195	27101	Economy	29000.00
0005432398294	27101	Economy	29000.00
0005435715910	27101	Economy	29000.00
0005435715902	27101	Economy	29000.00
0005432394189	27101	Economy	29000.00
0005432398274	27101	Economy	29000.00
0005435216654	27101	Economy	29000.00
0005435715792	27101	Economy	29000.00
0005435715941	27101	Economy	29000.00
0005435217775	27101	Economy	29000.00
0005435216653	27101	Economy	29000.00
0005435715967	27101	Economy	29000.00
0005435218146	27101	Economy	29000.00
0005435715926	27101	Economy	29000.00
0005435217774	27101	Economy	29000.00
0005435715915	27101	Economy	29000.00
0005435715895	27101	Economy	29000.00
0005435715898	27101	Economy	29000.00
0005433060474	2733	Economy	7700.00
0005433060480	2733	Economy	7700.00
0005433060484	2733	Economy	7700.00
0005433060485	2733	Economy	7700.00
0005433060479	2733	Economy	7700.00
0005434085034	28482	Economy	7700.00
0005434085050	28482	Economy	7700.00
0005434085052	28482	Economy	7700.00
0005434085051	28482	Economy	7700.00
0005434085038	28482	Economy	7700.00
0005434085053	28482	Economy	7700.00
0005434085057	28482	Economy	7700.00
0005434085028	28482	Economy	7700.00
0005434085056	28482	Economy	7700.00
0005434085029	28482	Economy	7700.00
0005433060492	28482	Economy	7700.00
0005434085037	28482	Economy	7700.00
0005435548595	11170	Economy	27100.00
0005435548601	11170	Economy	24600.00
0005435548586	11170	Economy	24600.00
0005433788333	11170	Economy	24600.00
0005433788334	11170	Economy	24600.00
0005435548608	11170	Economy	24600.00
0005435548589	11170	Economy	24600.00
0005435548600	11170	Economy	24600.00
0005435548577	11170	Economy	24600.00
0005435548588	11170	Economy	24600.00
0005433788332	11170	Economy	24600.00
0005435548584	11170	Economy	24600.00
0005435548603	11170	Economy	24600.00
0005433788331	11170	Economy	24600.00
0005435548593	11170	Economy	24600.00
0005435548581	11170	Economy	24600.00
0005435548604	11170	Economy	24600.00
0005435548583	11170	Economy	24600.00
0005435548592	11170	Economy	24600.00
0005435548576	11170	Economy	24600.00
0005433788335	11170	Economy	24600.00
0005435548580	11170	Economy	24600.00
0005435548611	11170	Economy	24600.00
0005435548591	11170	Economy	24600.00
0005433788285	20683	Economy	27100.00
0005435548628	20683	Economy	27100.00
0005433788299	20683	Economy	24600.00
0005433788290	20683	Economy	24600.00
0005435548625	20683	Economy	24600.00
0005433788296	20683	Economy	24600.00
0005435548627	20683	Economy	24600.00
0005435548626	20683	Economy	24600.00
0005433788289	20683	Economy	24600.00
0005435541492	11379	Business	20200.00
0005435518423	11379	Business	20200.00
0005435541559	11379	Business	20200.00
0005435518387	11379	Business	20200.00
0005435518386	11379	Business	20200.00
0005435541567	11379	Economy	6700.00
0005435541432	11379	Economy	6700.00
0005435518400	11379	Economy	6700.00
0005435541613	11379	Economy	6700.00
0005435541490	11379	Economy	7400.00
0005435541572	11379	Economy	7400.00
0005435518418	11379	Economy	7400.00
0005435518328	11379	Economy	6700.00
0005435541495	11379	Economy	6700.00
0005435541491	11379	Economy	6700.00
0005435518430	11379	Economy	6700.00
0005435541568	11379	Economy	6700.00
0005435518367	11379	Economy	6700.00
0005435518428	11379	Economy	6700.00
0005435518431	11379	Economy	6700.00
0005435541449	11379	Economy	6700.00
0005435541614	11379	Economy	6700.00
0005435518369	11379	Economy	6700.00
0005435518339	11379	Economy	6700.00
0005435541560	11379	Economy	6700.00
0005435541533	11379	Economy	6700.00
0005435518405	11379	Economy	6700.00
0005435518358	11379	Economy	6700.00
0005435518412	11379	Economy	6700.00
0005435518393	11379	Economy	6700.00
0005435541506	11379	Economy	6700.00
0005435541458	11379	Economy	6700.00
0005435518417	11379	Economy	6700.00
0005435541583	11379	Economy	6700.00
0005435518419	11379	Economy	6700.00
0005435541545	11379	Economy	6700.00
0005435518364	11379	Economy	6700.00
0005435518413	11379	Economy	6700.00
0005435541578	11379	Economy	6700.00
0005435541586	11379	Economy	6700.00
0005435541493	11379	Economy	6700.00
0005435518327	11379	Economy	6700.00
0005435541574	11379	Economy	6700.00
0005435541544	11379	Economy	6700.00
0005435518359	11379	Economy	6700.00
0005435518368	11379	Economy	6700.00
0005435541459	11379	Economy	6700.00
0005435541587	11379	Economy	6700.00
0005435518427	11379	Economy	6700.00
0005435529900	22235	Business	20200.00
0005435541645	22235	Economy	7400.00
0005435541646	22235	Economy	6700.00
0005435529898	22235	Economy	6700.00
0005435530196	22235	Economy	6700.00
0005435541644	22235	Economy	6700.00
0005435530197	22235	Economy	6700.00
0005435529899	22235	Economy	6700.00
0005433252196	2282	Business	20200.00
0005434908897	2282	Business	20200.00
0005433252205	2282	Business	20200.00
0005433252248	2282	Business	20200.00
0005434908899	2282	Economy	6700.00
0005433252312	2282	Economy	6700.00
0005433252277	2282	Economy	6700.00
0005433252285	2282	Economy	6700.00
0005433252260	2282	Economy	6700.00
0005433252363	2282	Economy	6700.00
0005433252291	2282	Economy	6700.00
0005433252324	2282	Economy	6700.00
0005433252325	2282	Economy	6700.00
0005433401056	2282	Economy	6700.00
0005433252251	2282	Economy	6700.00
0005433252197	2282	Economy	6700.00
0005433252192	2282	Economy	6700.00
0005433252364	2282	Economy	6700.00
0005433252153	2282	Economy	6700.00
0005434908898	2282	Economy	6700.00
0005433252193	2282	Economy	6700.00
0005433252195	2282	Economy	6700.00
0005433252275	2282	Economy	6700.00
0005433252204	2282	Economy	6700.00
0005433252250	2282	Economy	6700.00
0005433252238	2282	Economy	6700.00
0005433401052	2282	Economy	6700.00
0005433252314	2282	Economy	6700.00
0005433252276	2282	Economy	6700.00
0005433252262	2282	Economy	6700.00
0005433401065	2282	Economy	6700.00
0005433252273	2282	Economy	6700.00
0005434908551	25589	Business	20200.00
0005434908521	25589	Business	20200.00
0005434908502	25589	Business	20200.00
0005434908308	25589	Business	20200.00
0005434908627	25589	Business	20200.00
0005434908729	25589	Business	20200.00
0005434908572	25589	Business	20200.00
0005434908277	25589	Business	20200.00
0005435787469	25589	Business	20200.00
0005434908588	25589	Business	20200.00
0005434908832	25589	Business	20200.00
0005434908772	25589	Economy	6700.00
0005435787453	25589	Economy	6700.00
0005434908831	25589	Economy	6700.00
0005435787454	25589	Economy	6700.00
0005434908581	25589	Economy	6700.00
0005434908703	25589	Economy	6700.00
0005434908597	25589	Economy	6700.00
0005434908739	25589	Economy	6700.00
0005434908485	25589	Economy	7400.00
0005434908534	25589	Economy	7400.00
0005434908394	25589	Economy	7400.00
0005434908785	25589	Economy	6700.00
0005434908685	25589	Economy	6700.00
0005434908686	25589	Economy	6700.00
0005434908411	25589	Economy	6700.00
0005434908489	25589	Economy	6700.00
0005434908710	25589	Economy	6700.00
0005434908393	25589	Economy	6700.00
0005434908520	25589	Economy	6700.00
0005435787470	25589	Economy	6700.00
0005434908708	25589	Economy	6700.00
0005434908784	25589	Economy	6700.00
0005434908621	25589	Economy	6700.00
0005434908458	25589	Economy	6700.00
0005434908587	25589	Economy	6700.00
0005434908398	25589	Economy	6700.00
0005434908607	25589	Economy	6700.00
0005434908619	25589	Economy	6700.00
0005434908701	25589	Economy	6700.00
0005434908573	25589	Economy	6700.00
0005434908363	25589	Economy	6700.00
0005434908702	25589	Economy	6700.00
0005434908608	25589	Economy	6700.00
0005434908586	25589	Economy	6700.00
0005434908484	25589	Economy	6700.00
0005435787461	25589	Economy	6700.00
0005434908624	25589	Economy	6700.00
0005434908728	25589	Economy	6700.00
0005434908488	25589	Economy	6700.00
0005434908664	25589	Economy	6700.00
0005434908235	25589	Economy	6700.00
0005434908553	25589	Economy	6700.00
0005434908413	25589	Economy	6700.00
0005434908412	25589	Economy	6700.00
0005434908287	25589	Economy	6700.00
0005434908234	25589	Economy	6700.00
0005434908472	25589	Economy	6700.00
0005434908457	25589	Economy	6700.00
0005434908833	25589	Economy	6700.00
0005434908582	25589	Economy	6700.00
0005434908699	25589	Economy	6700.00
0005434908574	25589	Economy	6700.00
0005434908272	25589	Economy	6700.00
0005434908709	25589	Economy	6700.00
0005434908538	25589	Economy	6700.00
0005434908532	25589	Economy	6700.00
0005434908628	25589	Economy	6700.00
0005434908552	25589	Economy	6700.00
0005432862506	2504	Economy	13600.00
0005432862512	2504	Economy	12400.00
0005432862513	2504	Economy	12400.00
0005432621459	2504	Economy	12400.00
0005432862515	2504	Economy	12400.00
0005432862502	2504	Economy	12400.00
0005432862511	2504	Economy	12400.00
0005432862516	2504	Economy	12400.00
0005432862514	2504	Economy	12400.00
0005432862501	2504	Economy	12400.00
0005432862493	2504	Economy	12400.00
0005432621344	28050	Economy	12400.00
0005432621378	28050	Economy	12400.00
0005432621422	28050	Economy	12400.00
0005432621379	28050	Economy	12400.00
0005432621360	28050	Economy	12400.00
0005432621430	28050	Economy	12400.00
0005432621380	28050	Economy	12400.00
0005432621414	28050	Economy	12400.00
0005432621364	28050	Economy	12400.00
0005432621367	28050	Economy	12400.00
0005434097509	11718	Economy	11300.00
0005433452794	31412	Economy	8400.00
0005433452790	31412	Economy	8400.00
0005434142688	11996	Economy	7200.00
0005434326049	11996	Economy	7200.00
0005433129374	11996	Economy	6600.00
0005434326052	11996	Economy	6600.00
0005434326092	11996	Economy	6600.00
0005434326051	11996	Economy	6600.00
0005433129372	11996	Economy	6600.00
0005433134250	11996	Economy	6600.00
0005433129373	11996	Economy	6600.00
0005434326050	11996	Economy	6600.00
0005434326048	11996	Economy	6600.00
0005434142687	11996	Economy	6600.00
0005433129386	11996	Economy	6600.00
0005434326047	11996	Economy	6600.00
0005434326287	29838	Economy	6600.00
0005433131843	29838	Economy	6600.00
0005433131842	29838	Economy	6600.00
0005435798999	21302	Economy	17200.00
0005435799003	21302	Economy	17200.00
0005435798982	21302	Economy	15700.00
0005435799000	21302	Economy	15700.00
0005435798987	21302	Economy	15700.00
0005435798993	21302	Economy	15700.00
0005435799002	21302	Economy	15700.00
0005435798990	21302	Economy	15700.00
0005435799006	21302	Economy	15700.00
0005435799005	21302	Economy	15700.00
0005435799007	21302	Economy	15700.00
0005435798992	21302	Economy	15700.00
0005435798998	21302	Economy	15700.00
0005435799008	21302	Economy	15700.00
0005435799004	21302	Economy	15700.00
0005435798979	21302	Economy	15700.00
0005435798991	21302	Economy	15700.00
0005435798989	21302	Economy	15700.00
0005435798994	21302	Economy	15700.00
0005435798981	21302	Economy	15700.00
0005435798983	21302	Economy	15700.00
0005435799001	21302	Economy	15700.00
0005435798995	21302	Economy	15700.00
0005435698172	16480	Economy	19900.00
0005435698174	16480	Economy	18100.00
0005435698173	16480	Economy	18100.00
0005435698177	16480	Economy	18100.00
0005435935126	16480	Economy	18100.00
0005435698178	16480	Economy	18100.00
0005435935122	16480	Economy	18100.00
0005435698176	16480	Economy	18100.00
0005435698175	16480	Economy	18100.00
0005435935121	16480	Economy	18100.00
0005435935127	16480	Economy	18100.00
0005435698171	16480	Economy	18100.00
0005435698047	24707	Economy	18100.00
0005435698038	24707	Economy	18100.00
0005435698035	24707	Economy	18100.00
0005435698033	24707	Economy	18100.00
0005435697963	24707	Economy	18100.00
0005435698079	24707	Economy	18100.00
0005435698057	24707	Economy	18100.00
0005435697965	24707	Economy	18100.00
0005435698073	24707	Economy	18100.00
0005435698001	24707	Economy	18100.00
0005435698011	24707	Economy	18100.00
0005435697964	24707	Economy	18100.00
0005435698089	24707	Economy	18100.00
0005435698100	24707	Economy	18100.00
0005435698078	24707	Economy	18100.00
0005435698098	24707	Economy	18100.00
0005435698006	24707	Economy	18100.00
0005435698018	24707	Economy	18100.00
0005435698067	24707	Economy	18100.00
0005435698036	24707	Economy	18100.00
0005433724940	18788	Economy	4400.00
0005432968904	18788	Economy	4400.00
0005432968895	18788	Economy	4400.00
0005433724923	21648	Economy	4400.00
0005433724918	21648	Economy	4400.00
0005433724919	21648	Economy	4400.00
0005434140628	7345	Economy	7700.00
0005435283562	7345	Economy	7700.00
0005435283561	7345	Economy	7700.00
0005434140625	7345	Economy	7700.00
0005434140627	7345	Economy	7700.00
0005434140626	7345	Economy	7700.00
0005434140092	28536	Business	23100.00
0005434139928	28536	Business	23100.00
0005434140187	28536	Business	23100.00
0005434140170	28536	Business	23100.00
0005434140200	28536	Business	23100.00
0005434140223	28536	Business	23100.00
0005434140114	28536	Business	23100.00
0005434139978	28536	Business	23100.00
0005434140154	28536	Business	23100.00
0005434140082	28536	Business	23100.00
0005434140030	28536	Business	23100.00
0005434140300	28536	Business	23100.00
0005434139931	28536	Economy	7700.00
0005434087610	28536	Economy	7700.00
0005434140197	28536	Economy	7700.00
0005434139804	28536	Economy	7700.00
0005434139871	28536	Economy	7700.00
0005434139953	28536	Economy	7700.00
0005434139941	28536	Economy	7700.00
0005434139963	28536	Economy	7700.00
0005434140301	28536	Economy	8500.00
0005434139908	28536	Economy	8500.00
0005434140052	28536	Economy	8500.00
0005434087634	28536	Economy	8500.00
0005434139802	28536	Economy	8500.00
0005434140188	28536	Economy	7700.00
0005434140275	28536	Economy	7700.00
0005434087626	28536	Economy	7700.00
0005434140196	28536	Economy	7700.00
0005434139852	28536	Economy	7700.00
0005434087639	28536	Economy	7700.00
0005434140328	28536	Economy	7700.00
0005434140104	28536	Economy	7700.00
0005434139927	28536	Economy	7700.00
0005434139599	28536	Economy	7700.00
0005434140264	28536	Economy	7700.00
0005434140110	28536	Economy	7700.00
0005434140020	28536	Economy	7700.00
0005434139929	28536	Economy	7700.00
0005434140168	28536	Economy	7700.00
0005434140157	28536	Economy	7700.00
0005434140085	28536	Economy	7700.00
0005434140276	28536	Economy	7700.00
0005434139801	28536	Economy	7700.00
0005434140171	28536	Economy	7700.00
0005434139955	28536	Economy	7700.00
0005434140152	28536	Economy	7700.00
0005434140153	28536	Economy	7700.00
0005434139878	28536	Economy	7700.00
0005434140285	28536	Economy	7700.00
0005434140225	28536	Economy	7700.00
0005434140091	28536	Economy	7700.00
0005434140201	28536	Economy	7700.00
0005434140074	28536	Economy	7700.00
0005434140302	28536	Economy	7700.00
0005434139964	28536	Economy	7700.00
0005434140221	28536	Economy	7700.00
0005434140229	28536	Economy	7700.00
0005434140113	28536	Economy	7700.00
0005434140284	28536	Economy	7700.00
0005434140134	28536	Economy	7700.00
0005434140004	28536	Economy	7700.00
0005434140366	28536	Economy	7700.00
0005434140277	28536	Economy	7700.00
0005434140135	28536	Economy	7700.00
0005434140281	28536	Economy	7700.00
0005434139966	28536	Economy	7700.00
0005434139828	28536	Economy	7700.00
0005434140357	28536	Economy	7700.00
0005434140189	28536	Economy	7700.00
0005434140130	28536	Economy	7700.00
0005434140019	28536	Economy	7700.00
0005434140084	28536	Economy	7700.00
0005434140167	28536	Economy	7700.00
0005434140292	28536	Economy	7700.00
0005434140316	28536	Economy	7700.00
0005434140263	28536	Economy	7700.00
0005434140081	28536	Economy	7700.00
0005434087640	28536	Economy	7700.00
0005434140169	28536	Economy	7700.00
0005434139995	28536	Economy	7700.00
0005434139600	28536	Economy	7700.00
0005434087633	28536	Economy	7700.00
0005434139958	28536	Economy	7700.00
0005434139954	28536	Economy	7700.00
0005434140358	28536	Economy	7700.00
0005434139803	28536	Economy	7700.00
0005434140031	28536	Economy	7700.00
0005434140315	28536	Economy	7700.00
0005434139805	28536	Economy	7700.00
0005434140131	28536	Economy	7700.00
0005434140005	28536	Economy	7700.00
0005433407682	1896	Economy	21700.00
0005433407686	1896	Economy	21700.00
0005435808432	23091	Economy	23900.00
0005435808459	23091	Economy	23900.00
0005433407710	23091	Economy	23900.00
0005435808434	23091	Economy	23900.00
0005435808414	23091	Economy	21700.00
0005435808392	23091	Economy	21700.00
0005434610314	23091	Economy	21700.00
0005435808449	23091	Economy	21700.00
0005435808461	23091	Economy	21700.00
0005435808487	23091	Economy	21700.00
0005435808411	23091	Economy	21700.00
0005435808455	23091	Economy	21700.00
0005435808488	23091	Economy	21700.00
0005435808485	23091	Economy	21700.00
0005433407711	23091	Economy	21700.00
0005435808433	23091	Economy	21700.00
0005435808436	23091	Economy	21700.00
0005435808445	23091	Economy	21700.00
0005435808457	23091	Economy	21700.00
0005435808456	23091	Economy	21700.00
0005433407712	23091	Economy	21700.00
0005435808431	23091	Economy	21700.00
0005435808468	23091	Economy	21700.00
0005435808470	23091	Economy	21700.00
0005435808413	23091	Economy	21700.00
0005435808410	23091	Economy	21700.00
0005435808486	23091	Economy	21700.00
0005435808458	23091	Economy	21700.00
0005434610315	23091	Economy	21700.00
0005435808469	23091	Economy	21700.00
0005435808435	23091	Economy	21700.00
0005435808453	23091	Economy	21700.00
0005435808425	23091	Economy	21700.00
0005435808489	23091	Economy	21700.00
0005435808428	23091	Economy	21700.00
0005435808441	23091	Economy	21700.00
0005435808437	23091	Economy	21700.00
0005435808444	23091	Economy	21700.00
0005435808460	23091	Economy	21700.00
0005435312888	16723	Economy	7600.00
0005434505211	16723	Economy	7600.00
0005434505129	16723	Economy	7600.00
0005434505050	16723	Economy	7600.00
0005434505127	16723	Economy	6900.00
0005435312886	16723	Economy	6900.00
0005434505007	16723	Economy	6900.00
0005434505061	16723	Economy	6900.00
0005434505124	16723	Economy	6900.00
0005434505094	16723	Economy	6900.00
0005434505079	16723	Economy	6900.00
0005434504941	16723	Economy	6900.00
0005434505166	16723	Economy	6900.00
0005434504989	16723	Economy	6900.00
0005434505135	16723	Economy	6900.00
0005434505144	16723	Economy	6900.00
0005434505215	16723	Economy	6900.00
0005434505118	16723	Economy	6900.00
0005434505216	16723	Economy	6900.00
0005434504979	16723	Economy	6900.00
0005434505117	16723	Economy	6900.00
0005434505212	16723	Economy	6900.00
0005434505090	16723	Economy	6900.00
0005434504973	16723	Economy	6900.00
0005434505228	16723	Economy	6900.00
0005434505217	16723	Economy	6900.00
0005434505073	16723	Economy	6900.00
0005434505082	16723	Economy	6900.00
0005434504980	16723	Economy	6900.00
0005434505235	16723	Economy	6900.00
0005434505183	16723	Economy	6900.00
0005435312887	16723	Economy	6900.00
0005434505036	16723	Economy	6900.00
0005434505133	16723	Economy	6900.00
0005434505093	16723	Economy	6900.00
0005434505221	16723	Economy	6900.00
0005434505037	16723	Economy	6900.00
0005434505222	16723	Economy	6900.00
0005434505091	16723	Economy	6900.00
0005434505092	16723	Economy	6900.00
0005434505005	16723	Economy	6900.00
0005434505119	16723	Economy	6900.00
0005434505051	16723	Economy	6900.00
0005435312889	16723	Economy	6900.00
0005434504940	16723	Economy	6900.00
0005434505078	16723	Economy	6900.00
0005434505318	22928	Economy	6900.00
0005434505317	22928	Economy	6900.00
0005434505316	22928	Economy	6900.00
0005433266961	2224	Economy	7700.00
0005433266979	2224	Economy	7000.00
0005433266967	2224	Economy	7000.00
0005433266962	2224	Economy	7000.00
0005435078703	24362	Economy	7700.00
0005435078772	24362	Economy	7000.00
0005435078741	24362	Economy	7000.00
0005435078762	24362	Economy	7000.00
0005435078671	24362	Economy	7000.00
0005435078745	24362	Economy	7000.00
0005435078775	24362	Economy	7000.00
0005433266992	24362	Economy	7000.00
0005435078749	24362	Economy	7000.00
0005435078769	24362	Economy	7000.00
0005435078776	24362	Economy	7000.00
0005435078759	24362	Economy	7000.00
0005435078761	24362	Economy	7000.00
0005435078756	24362	Economy	7000.00
0005435078768	24362	Economy	7000.00
0005434989132	6645	Economy	10800.00
0005434989131	6645	Economy	9800.00
0005434988970	23614	Economy	10800.00
0005434988969	23614	Economy	9800.00
0005434989009	23614	Economy	9800.00
0005434988998	23614	Economy	9800.00
0005434988939	23614	Economy	9800.00
0005434988938	23614	Economy	9800.00
0005434988978	23614	Economy	9800.00
0005434988997	23614	Economy	9800.00
0005434988954	23614	Economy	9800.00
0005434988975	23614	Economy	9800.00
0005434988979	23614	Economy	9800.00
0005434988999	23614	Economy	9800.00
0005434988953	23614	Economy	9800.00
0005432384341	30500	Business	9900.00
0005432384340	30500	Economy	3300.00
0005433450611	30500	Economy	3300.00
0005433453820	30500	Economy	3300.00
0005432384342	30500	Economy	3300.00
0005432384249	31316	Business	9900.00
0005433450476	31316	Business	9900.00
0005433450418	31316	Business	9900.00
0005432384029	31316	Business	9900.00
0005433451673	31316	Business	9900.00
0005432384055	31316	Business	9900.00
0005432384117	31316	Business	9900.00
0005432384061	31316	Economy	3300.00
0005432383961	31316	Economy	3300.00
0005432384266	31316	Economy	3300.00
0005432384034	31316	Economy	3300.00
0005432384189	31316	Economy	3300.00
0005432383862	31316	Economy	3600.00
0005432384188	31316	Economy	3600.00
0005432384197	31316	Economy	3600.00
0005432384076	31316	Economy	3300.00
0005433450475	31316	Economy	3300.00
0005432384025	31316	Economy	3300.00
0005433450477	31316	Economy	3300.00
0005432384149	31316	Economy	3300.00
0005432384194	31316	Economy	3300.00
0005432384135	31316	Economy	3300.00
0005432384069	31316	Economy	3300.00
0005432384230	31316	Economy	3300.00
0005432384010	31316	Economy	3300.00
0005433453814	31316	Economy	3300.00
0005432384033	31316	Economy	3300.00
0005433450484	31316	Economy	3300.00
0005433450472	31316	Economy	3300.00
0005432384006	31316	Economy	3300.00
0005433450480	31316	Economy	3300.00
0005432383823	31316	Economy	3300.00
0005432383999	31316	Economy	3300.00
0005432383917	31316	Economy	3300.00
0005433450481	31316	Economy	3300.00
0005432384153	31316	Economy	3300.00
0005433450442	31316	Economy	3300.00
0005432384008	31316	Economy	3300.00
0005432383931	31316	Economy	3300.00
0005433450485	31316	Economy	3300.00
0005432384070	31316	Economy	3300.00
0005432384054	31316	Economy	3300.00
0005432383919	31316	Economy	3300.00
0005432383960	31316	Economy	3300.00
0005432384150	31316	Economy	3300.00
0005433450545	31316	Economy	3300.00
0005433450479	31316	Economy	3300.00
0005433453811	31316	Economy	3300.00
0005433450546	31316	Economy	3300.00
0005432383928	31316	Economy	3300.00
0005432384077	31316	Economy	3300.00
0005433450443	31316	Economy	3300.00
0005433450471	31316	Economy	3300.00
0005433450482	31316	Economy	3300.00
0005432383987	31316	Economy	3300.00
0005432384051	31316	Economy	3300.00
0005432384026	31316	Economy	3300.00
0005432383918	31316	Economy	3300.00
0005432384152	31316	Economy	3300.00
0005432384007	31316	Economy	3300.00
0005432383941	31316	Economy	3300.00
0005433450488	31316	Economy	3300.00
0005433450500	31316	Economy	3300.00
0005433450493	31316	Economy	3300.00
0005432384154	31316	Economy	3300.00
0005432384046	31316	Economy	3300.00
0005432384009	31316	Economy	3300.00
0005432384265	31316	Economy	3300.00
0005432384052	31316	Economy	3300.00
0005433131816	10782	Economy	17100.00
0005433126955	10782	Economy	17100.00
0005435299904	10782	Economy	15600.00
0005433131817	10782	Economy	15600.00
0005435299905	10782	Economy	15600.00
0005435299862	10782	Economy	15600.00
0005435304253	10782	Economy	15600.00
0005433126967	10782	Economy	15600.00
0005433126959	10782	Economy	15600.00
0005435299863	10782	Economy	15600.00
0005435304257	10782	Economy	15600.00
0005433126968	10782	Economy	15600.00
0005435299887	10782	Economy	15600.00
0005433126960	10782	Economy	15600.00
0005435304259	10782	Economy	15600.00
0005433126954	10782	Economy	15600.00
0005433126985	29712	Economy	15600.00
0005434300268	2437	Economy	17200.00
0005434300271	2437	Economy	15700.00
0005433110384	2437	Economy	15700.00
0005433110365	2437	Economy	15700.00
0005433110271	2437	Economy	15700.00
0005434300269	2437	Economy	15700.00
0005434287944	2437	Economy	15700.00
0005433110358	2437	Economy	15700.00
0005434300270	2437	Economy	15700.00
0005433110394	26823	Economy	15700.00
0005434287868	26823	Economy	15700.00
0005434287764	26823	Economy	15700.00
0005434287848	26823	Economy	15700.00
0005434287925	26823	Economy	15700.00
0005433110393	26823	Economy	15700.00
0005434287812	26823	Economy	15700.00
0005434287849	26823	Economy	15700.00
0005433110396	26823	Economy	15700.00
0005433110395	26823	Economy	15700.00
0005434287763	26823	Economy	15700.00
0005434287830	26823	Economy	15700.00
0005434287844	26823	Economy	15700.00
0005434287794	26823	Economy	15700.00
0005434269154	25455	Economy	25000.00
0005434272228	25455	Economy	22800.00
0005434272229	25455	Economy	22800.00
0005435983721	25455	Economy	22800.00
0005434269156	25455	Economy	22800.00
0005435856290	26661	Economy	22800.00
0005435856304	26661	Economy	22800.00
0005435854076	26661	Economy	22800.00
0005435854082	26661	Economy	22800.00
0005435854083	26661	Economy	22800.00
0005435854081	26661	Economy	22800.00
0005435856291	26661	Economy	22800.00
0005435856305	26661	Economy	22800.00
0005435854075	26661	Economy	22800.00
0005435860599	4763	Economy	19400.00
0005435860622	4763	Economy	17600.00
0005435860593	4763	Economy	17600.00
0005435860591	4763	Economy	17600.00
0005435860583	4763	Economy	17600.00
0005435860589	4763	Economy	17600.00
0005435860603	4763	Economy	17600.00
0005435860602	4763	Economy	17600.00
0005435860601	4763	Economy	17600.00
0005435860596	4763	Economy	17600.00
0005435860588	4763	Economy	17600.00
0005435860595	4763	Economy	17600.00
0005433869569	32585	Economy	19400.00
0005433869433	32585	Economy	19400.00
0005435860634	32585	Economy	19400.00
0005433869296	32585	Economy	19400.00
0005433869457	32585	Economy	17600.00
0005433869291	32585	Economy	17600.00
0005433869451	32585	Economy	17600.00
0005433869469	32585	Economy	17600.00
0005433869339	32585	Economy	17600.00
0005433869324	32585	Economy	17600.00
0005433869141	32585	Economy	17600.00
0005433869395	32585	Economy	17600.00
0005433869428	32585	Economy	17600.00
0005433869337	32585	Economy	17600.00
0005433869217	32585	Economy	17600.00
0005433869493	32585	Economy	17600.00
0005433869373	32585	Economy	17600.00
0005433869434	32585	Economy	17600.00
0005433869494	32585	Economy	17600.00
0005433869427	32585	Economy	17600.00
0005433869300	32585	Economy	17600.00
0005433869398	32585	Economy	17600.00
0005433869397	32585	Economy	17600.00
0005433869351	32585	Economy	17600.00
0005433869500	32585	Economy	17600.00
0005433869394	32585	Economy	17600.00
0005433869470	32585	Economy	17600.00
0005433869295	32585	Economy	17600.00
0005433869436	32585	Economy	17600.00
0005433869336	32585	Economy	17600.00
0005435911608	3416	Economy	22600.00
0005434663807	3416	Economy	22600.00
0005435911629	3416	Economy	22600.00
0005434461712	3416	Economy	22600.00
0005435911622	3416	Economy	22600.00
0005434461711	3416	Economy	22600.00
0005435911621	3416	Economy	22600.00
0005434663734	12468	Economy	22600.00
0005434663751	12468	Economy	22600.00
0005434663773	12468	Economy	22600.00
0005434663750	12468	Economy	22600.00
0005434663682	12468	Economy	22600.00
0005434663771	12468	Economy	22600.00
0005434663714	12468	Economy	22600.00
0005433869339	14472	Economy	18500.00
0005433869295	14472	Economy	18500.00
0005433869433	14472	Economy	18500.00
0005433869427	14472	Economy	16800.00
0005433869296	14472	Economy	16800.00
0005433869457	14472	Economy	16800.00
0005433869451	14472	Economy	16800.00
0005433869217	14472	Economy	16800.00
0005433869436	14472	Economy	16800.00
0005433869291	14472	Economy	16800.00
0005433869141	14472	Economy	16800.00
0005433869469	14472	Economy	16800.00
0005435860634	14472	Economy	16800.00
0005433869500	14472	Economy	16800.00
0005433869493	14472	Economy	16800.00
0005433869373	14472	Economy	16800.00
0005433869569	14472	Economy	16800.00
0005433869336	14472	Economy	16800.00
0005433869337	14472	Economy	16800.00
0005433869470	14472	Economy	16800.00
0005433869300	14472	Economy	16800.00
0005433869394	14472	Economy	16800.00
0005433869395	14472	Economy	16800.00
0005433869434	14472	Economy	16800.00
0005433869428	14472	Economy	16800.00
0005433869398	14472	Economy	16800.00
0005433869324	14472	Economy	16800.00
0005433869351	14472	Economy	16800.00
0005433869494	14472	Economy	16800.00
0005433869397	14472	Economy	16800.00
0005433869610	32672	Economy	18500.00
0005435860590	32672	Economy	16800.00
0005433869607	32672	Economy	16800.00
0005435860579	32672	Economy	16800.00
0005433869606	32672	Economy	16800.00
0005435860604	32672	Economy	16800.00
0005433869612	32672	Economy	16800.00
0005433869604	32672	Economy	16800.00
0005433869608	32672	Economy	16800.00
0005435860584	32672	Economy	16800.00
0005433869614	32672	Economy	16800.00
0005435860572	32672	Economy	16800.00
0005433869605	32672	Economy	16800.00
0005433869613	32672	Economy	16800.00
0005435860571	32672	Economy	16800.00
0005433869609	32672	Economy	16800.00
0005433869611	32672	Economy	16800.00
0005435860570	32672	Economy	16800.00
0005432800160	12120	Economy	4400.00
0005432800165	12120	Economy	4400.00
0005432800127	12120	Economy	4400.00
0005432800049	12120	Economy	4400.00
0005432800027	12120	Economy	4400.00
0005432800139	12120	Economy	4400.00
0005432800114	12120	Economy	4400.00
0005432800100	12120	Economy	4400.00
0005432800161	12120	Economy	4400.00
0005432800242	12120	Economy	4400.00
0005432800048	12120	Economy	4400.00
0005432800234	12120	Economy	4400.00
0005432800198	12120	Economy	4400.00
0005432800026	12120	Economy	4400.00
0005432800179	12120	Economy	4400.00
0005432800166	12120	Economy	4400.00
0005432800285	14817	Economy	4400.00
0005432800284	14817	Economy	4400.00
0005435311434	7039	Business	49100.00
0005435311403	7039	Business	49100.00
0005435311513	7039	Business	49100.00
0005435311392	7039	Business	49100.00
0005435311425	7039	Business	49100.00
0005435311424	7039	Economy	16400.00
0005435311421	7039	Economy	16400.00
0005435311438	7039	Economy	16400.00
0005435293583	7039	Economy	16400.00
0005435311401	7039	Economy	16400.00
0005435293504	7039	Economy	16400.00
0005435311418	7039	Economy	16400.00
0005435311358	7039	Economy	16400.00
0005435311436	7039	Economy	16400.00
0005435311402	7039	Economy	16400.00
0005435311417	7039	Economy	16400.00
0005435293542	7039	Economy	16400.00
0005435293562	7039	Economy	16400.00
0005435293502	7039	Economy	16400.00
0005434409617	7039	Economy	16400.00
0005435311355	7039	Economy	16400.00
0005434409619	7039	Economy	18000.00
0005435293541	7039	Economy	16400.00
0005435293503	7039	Economy	16400.00
0005435293564	7039	Economy	16400.00
0005435311388	7039	Economy	16400.00
0005435311426	7039	Economy	16400.00
0005434300229	7039	Economy	16400.00
0005435311514	7039	Economy	16400.00
0005435293543	7039	Economy	16400.00
0005435293553	7039	Economy	16400.00
0005434409616	7039	Economy	16400.00
0005435311478	7039	Economy	16400.00
0005435311407	7039	Economy	16400.00
0005435311433	7039	Economy	16400.00
0005434409615	7039	Economy	16400.00
0005435311512	7039	Economy	16400.00
0005435311346	7039	Economy	16400.00
0005435293579	7039	Economy	16400.00
0005435293561	7039	Economy	16400.00
0005434300231	7039	Economy	16400.00
0005435293584	7039	Economy	16400.00
0005435293595	7039	Economy	16400.00
0005435311427	7039	Economy	16400.00
0005434300230	7039	Economy	16400.00
0005434409618	7039	Economy	16400.00
0005435311393	7039	Economy	16400.00
0005435311479	7039	Economy	16400.00
0005434409155	26891	Business	49100.00
0005434409486	26891	Business	49100.00
0005434409046	26891	Business	49100.00
0005434300169	26891	Business	49100.00
0005434300099	26891	Business	49100.00
0005434409183	26891	Business	49100.00
0005435311556	26891	Business	49100.00
0005434409285	26891	Business	49100.00
0005434409245	26891	Economy	16400.00
0005434409283	26891	Economy	16400.00
0005434300160	26891	Economy	16400.00
0005434409369	26891	Economy	16400.00
0005434409370	26891	Economy	16400.00
0005434409282	26891	Economy	16400.00
0005434409351	26891	Economy	16400.00
0005434409240	26891	Economy	16400.00
0005434409101	26891	Economy	16400.00
0005434300158	26891	Economy	16400.00
0005434409176	26891	Economy	16400.00
0005434409376	26891	Economy	16400.00
0005434300124	26891	Economy	16400.00
0005434409202	26891	Economy	16400.00
0005434409379	26891	Economy	16400.00
0005434409359	26891	Economy	16400.00
0005434409265	26891	Economy	16400.00
0005434300204	26891	Economy	16400.00
0005434409209	26891	Economy	16400.00
0005434409254	26891	Economy	16400.00
0005434300073	26891	Economy	16400.00
0005434409205	26891	Economy	18000.00
0005434300153	26891	Economy	18000.00
0005434409239	26891	Economy	18000.00
0005434409345	26891	Economy	18000.00
0005434409284	26891	Economy	18000.00
0005434409377	26891	Economy	16400.00
0005434300129	26891	Economy	16400.00
0005434409102	26891	Economy	16400.00
0005434300155	26891	Economy	16400.00
0005434409339	26891	Economy	16400.00
0005434409346	26891	Economy	16400.00
0005434409154	26891	Economy	16400.00
0005434409358	26891	Economy	16400.00
0005434409324	26891	Economy	16400.00
0005434409485	26891	Economy	16400.00
0005434408996	26891	Economy	16400.00
0005434409417	26891	Economy	16400.00
0005434409323	26891	Economy	16400.00
0005434300214	26891	Economy	16400.00
0005434409229	26891	Economy	16400.00
0005435311557	26891	Economy	16400.00
0005434300170	26891	Economy	16400.00
0005434409266	26891	Economy	16400.00
0005435311558	26891	Economy	16400.00
0005434409288	26891	Economy	16400.00
0005434409246	26891	Economy	16400.00
0005434409484	26891	Economy	16400.00
0005434409286	26891	Economy	16400.00
0005434409384	26891	Economy	16400.00
0005434409060	26891	Economy	16400.00
0005434408989	26891	Economy	16400.00
0005434300112	26891	Economy	16400.00
0005434408990	26891	Economy	16400.00
0005434408988	26891	Economy	16400.00
0005434409233	26891	Economy	16400.00
0005434409232	26891	Economy	16400.00
0005434409201	26891	Economy	16400.00
0005434409195	26891	Economy	16400.00
0005434409111	26891	Economy	16400.00
0005434409264	26891	Economy	16400.00
0005434409160	26891	Economy	16400.00
0005434409236	26891	Economy	16400.00
0005434409277	26891	Economy	16400.00
0005434409194	26891	Economy	16400.00
0005434409170	26891	Economy	16400.00
0005434409287	26891	Economy	16400.00
0005434300154	26891	Economy	16400.00
0005434300188	26891	Economy	16400.00
0005432605512	6481	Economy	15000.00
0005432605514	6481	Economy	15000.00
0005435218132	6481	Economy	15000.00
0005432605508	6481	Economy	15000.00
0005435220512	6481	Economy	15000.00
0005432605509	6481	Economy	15000.00
0005435220517	6481	Economy	15000.00
0005435218135	6481	Economy	15000.00
0005435220518	6481	Economy	15000.00
0005432605511	6481	Economy	15000.00
0005432605513	6481	Economy	15000.00
0005435220511	6481	Economy	15000.00
0005434512259	6481	Economy	15000.00
0005432605510	6481	Economy	15000.00
0005435220509	6481	Economy	15000.00
0005435218134	6481	Economy	15000.00
0005432605265	21352	Economy	16500.00
0005434512222	21352	Economy	16500.00
0005432605236	21352	Economy	16500.00
0005434512241	21352	Economy	15000.00
0005432605254	21352	Economy	15000.00
0005434512226	21352	Economy	15000.00
0005432605429	21352	Economy	15000.00
0005432605312	21352	Economy	15000.00
0005432605266	21352	Economy	15000.00
0005432605313	21352	Economy	15000.00
0005434512232	21352	Economy	15000.00
0005432605397	21352	Economy	15000.00
0005432605197	21352	Economy	15000.00
0005432605181	21352	Economy	15000.00
0005432605310	21352	Economy	15000.00
0005432605395	21352	Economy	15000.00
0005432605237	21352	Economy	15000.00
0005432605352	21352	Economy	15000.00
0005432605343	21352	Economy	15000.00
0005434512239	21352	Economy	15000.00
0005432605198	21352	Economy	15000.00
0005432605189	21352	Economy	15000.00
0005432605275	21352	Economy	15000.00
0005432605351	21352	Economy	15000.00
0005432605404	21352	Economy	15000.00
0005432605307	21352	Economy	15000.00
0005434512231	21352	Economy	15000.00
0005432605309	21352	Economy	15000.00
0005432605276	21352	Economy	15000.00
0005432605202	21352	Economy	15000.00
0005432605387	21352	Economy	15000.00
0005432605183	21352	Economy	15000.00
0005432605209	21352	Economy	15000.00
0005432605403	21352	Economy	15000.00
0005434512234	21352	Economy	15000.00
0005432605331	21352	Economy	15000.00
0005432605374	21352	Economy	15000.00
0005432605182	21352	Economy	15000.00
0005432605267	21352	Economy	15000.00
0005434512240	21352	Economy	15000.00
0005432605210	21352	Economy	15000.00
0005432605330	21352	Economy	15000.00
0005432605204	21352	Economy	15000.00
0005432605394	21352	Economy	15000.00
0005434908412	14992	Business	18900.00
0005434908739	14992	Business	18900.00
0005434908458	14992	Business	18900.00
0005434908532	14992	Business	18900.00
0005434908574	14992	Business	18900.00
0005434908702	14992	Business	18900.00
0005434908413	14992	Economy	6300.00
0005434908393	14992	Economy	6300.00
0005434908832	14992	Economy	6300.00
0005434908833	14992	Economy	6300.00
0005434908581	14992	Economy	6300.00
0005434908411	14992	Economy	6900.00
0005434908729	14992	Economy	6900.00
0005434908457	14992	Economy	6900.00
0005434908488	14992	Economy	6900.00
0005434908235	14992	Economy	6900.00
0005434908728	14992	Economy	6300.00
0005434908701	14992	Economy	6300.00
0005434908831	14992	Economy	6300.00
0005434908699	14992	Economy	6300.00
0005434908628	14992	Economy	6300.00
0005434908277	14992	Economy	6300.00
0005434908484	14992	Economy	6300.00
0005434908619	14992	Economy	6300.00
0005434908627	14992	Economy	6300.00
0005434908394	14992	Economy	6300.00
0005434908363	14992	Economy	6300.00
0005434908703	14992	Economy	6300.00
0005434908621	14992	Economy	6300.00
0005434908588	14992	Economy	6300.00
0005434908772	14992	Economy	6300.00
0005434908586	14992	Economy	6300.00
0005434908708	14992	Economy	6300.00
0005434908709	14992	Economy	6300.00
0005434908624	14992	Economy	6300.00
0005434908573	14992	Economy	6300.00
0005434908502	14992	Economy	6300.00
0005434908607	14992	Economy	6300.00
0005434908664	14992	Economy	6300.00
0005434908572	14992	Economy	6300.00
0005434908538	14992	Economy	6300.00
0005434908287	14992	Economy	6300.00
0005434908485	14992	Economy	6300.00
0005434908534	14992	Economy	6300.00
0005434908552	14992	Economy	6300.00
0005434908472	14992	Economy	6300.00
0005434908587	14992	Economy	6300.00
0005434908784	14992	Economy	6300.00
0005434908234	14992	Economy	6300.00
0005434908597	14992	Economy	6300.00
0005434908553	14992	Economy	6300.00
0005434908685	14992	Economy	6300.00
0005434908582	14992	Economy	6300.00
0005434908686	14992	Economy	6300.00
0005434908308	14992	Economy	6300.00
0005434908398	14992	Economy	6300.00
0005434908272	14992	Economy	6300.00
0005434908521	14992	Economy	6300.00
0005434908710	14992	Economy	6300.00
0005434908551	14992	Economy	6300.00
0005434908489	14992	Economy	6300.00
0005434908608	14992	Economy	6300.00
0005434908785	14992	Economy	6300.00
0005434908520	14992	Economy	6300.00
0005433252214	25854	Business	18900.00
0005433252219	25854	Business	18900.00
0005433252323	25854	Business	18900.00
0005433252268	25854	Business	18900.00
0005433252183	25854	Business	18900.00
0005433252322	25854	Economy	6300.00
0005434908892	25854	Economy	6300.00
0005433252237	25854	Economy	6300.00
0005433252206	25854	Economy	6300.00
0005433252163	25854	Economy	6300.00
0005434908893	25854	Economy	6300.00
0005433252198	25854	Economy	6300.00
0005433252240	25854	Economy	6300.00
0005433252327	25854	Economy	6300.00
0005433252296	25854	Economy	6300.00
0005434908895	25854	Economy	6300.00
0005433252235	25854	Economy	6300.00
0005433252184	25854	Economy	6300.00
0005433252297	25854	Economy	6300.00
0005433252357	25854	Economy	6300.00
0005434908894	25854	Economy	6300.00
0005433252283	25854	Economy	6300.00
0005433252185	25854	Economy	6300.00
0005433252167	25854	Economy	6300.00
0005433252293	25854	Economy	6300.00
0005434908904	25854	Economy	6300.00
0005433252117	25854	Economy	6300.00
0005433252286	25854	Economy	6300.00
0005433252282	25854	Economy	6300.00
0005433252239	25854	Economy	6300.00
0005433252207	25854	Economy	6300.00
0005434908891	25854	Economy	6300.00
0005433252233	25854	Economy	6300.00
0005434908896	25854	Economy	6300.00
0005433252288	25854	Economy	6300.00
0005434908890	25854	Economy	6300.00
0005433252162	25854	Economy	6300.00
0005434173652	9169	Economy	19900.00
0005433815581	9169	Economy	18100.00
0005433815582	9169	Economy	18100.00
0005433815585	9169	Economy	18100.00
0005433815583	9169	Economy	18100.00
0005434173651	9169	Economy	18100.00
0005434173648	9169	Economy	18100.00
0005433815556	22708	Economy	18100.00
0005433815546	22708	Economy	18100.00
0005433009977	14168	Business	52300.00
0005433810683	14168	Business	52300.00
0005433810714	14168	Business	52300.00
0005433009975	14168	Business	52300.00
0005433815556	14168	Business	52300.00
0005433810680	14168	Economy	17400.00
0005433810695	14168	Economy	17400.00
0005433810682	14168	Economy	17400.00
0005433009973	14168	Economy	17400.00
0005433810675	14168	Economy	17400.00
0005433810756	14168	Economy	19200.00
0005433810713	14168	Economy	17400.00
0005433810757	14168	Economy	17400.00
0005433009974	14168	Economy	17400.00
0005433009976	14168	Economy	17400.00
0005433810663	14168	Economy	17400.00
0005433810726	14168	Economy	17400.00
0005433009981	14168	Economy	17400.00
0005433810674	14168	Economy	17400.00
0005433810712	14168	Economy	17400.00
0005433815546	14168	Economy	17400.00
0005433009980	14168	Economy	17400.00
0005433810725	14168	Economy	17400.00
0005433009978	14168	Economy	17400.00
0005433810679	14168	Economy	17400.00
0005433009979	14168	Economy	17400.00
0005433810704	14168	Economy	17400.00
0005433810694	14168	Economy	17400.00
0005433009865	22844	Business	52300.00
0005433009728	22844	Business	52300.00
0005433009644	22844	Business	52300.00
0005433009572	22844	Business	52300.00
0005433009669	22844	Business	52300.00
0005433009633	22844	Business	52300.00
0005433810796	22844	Business	52300.00
0005433009875	22844	Business	52300.00
0005433009687	22844	Economy	17400.00
0005434173642	22844	Economy	17400.00
0005433009766	22844	Economy	17400.00
0005433009840	22844	Economy	17400.00
0005433009517	22844	Economy	17400.00
0005433009694	22844	Economy	19200.00
0005433009877	22844	Economy	19200.00
0005433009693	22844	Economy	19200.00
0005433810800	22844	Economy	17400.00
0005433009819	22844	Economy	17400.00
0005433009798	22844	Economy	17400.00
0005433810794	22844	Economy	17400.00
0005433009767	22844	Economy	17400.00
0005433009790	22844	Economy	17400.00
0005433009818	22844	Economy	17400.00
0005434173657	22844	Economy	17400.00
0005433009632	22844	Economy	17400.00
0005433009774	22844	Economy	17400.00
0005433810793	22844	Economy	17400.00
0005433009634	22844	Economy	17400.00
0005433810799	22844	Economy	17400.00
0005433009563	22844	Economy	17400.00
0005433009645	22844	Economy	17400.00
0005433009813	22844	Economy	17400.00
0005433009670	22844	Economy	17400.00
0005433810803	22844	Economy	17400.00
0005433810804	22844	Economy	17400.00
0005434173658	22844	Economy	17400.00
0005433009791	22844	Economy	17400.00
0005433009686	22844	Economy	17400.00
0005433815580	22844	Economy	17400.00
0005433009746	22844	Economy	17400.00
0005433810801	22844	Economy	17400.00
0005433009811	22844	Economy	17400.00
0005433009637	22844	Economy	17400.00
0005433009729	22844	Economy	17400.00
0005433810798	22844	Economy	17400.00
0005433009675	22844	Economy	17400.00
0005433009555	22844	Economy	17400.00
0005433810805	22844	Economy	17400.00
0005433009754	22844	Economy	17400.00
0005433810795	22844	Economy	17400.00
0005433009802	22844	Economy	17400.00
0005433009820	22844	Economy	17400.00
0005433009564	22844	Economy	17400.00
0005433009769	22844	Economy	17400.00
0005433009626	22844	Economy	17400.00
0005433810806	22844	Economy	17400.00
0005433810797	22844	Economy	17400.00
0005433815579	22844	Economy	17400.00
0005433810802	22844	Economy	17400.00
0005433009518	22844	Economy	17400.00
0005433009688	22844	Economy	17400.00
0005435719107	15521	Business	85200.00
0005435719104	15521	Business	85200.00
0005435719123	15521	Business	85200.00
0005435719112	15521	Business	85200.00
0005435719105	15521	Economy	28400.00
0005435719116	15521	Economy	28400.00
0005435719103	15521	Economy	31200.00
0005435719117	15521	Economy	31200.00
0005435719102	15521	Economy	28400.00
0005435719110	15521	Economy	28400.00
0005435719109	15521	Economy	28400.00
0005435719115	15521	Economy	28400.00
0005435719099	15521	Economy	28400.00
0005435719108	15521	Economy	28400.00
0005435719106	15521	Economy	28400.00
0005435719121	15521	Economy	28400.00
0005435719098	15521	Economy	28400.00
0005435719119	15521	Economy	28400.00
0005435719124	15521	Economy	28400.00
0005435719120	15521	Economy	28400.00
0005435719122	15521	Economy	28400.00
0005435719114	15521	Economy	28400.00
0005435719118	15521	Economy	28400.00
0005435719101	15521	Economy	28400.00
0005435719100	15521	Economy	28400.00
0005435719111	15521	Economy	28400.00
0005435719113	15521	Economy	28400.00
0005434926511	14963	Business	22900.00
0005434926428	14963	Business	22900.00
0005434926608	14963	Business	22900.00
0005434926480	14963	Business	22900.00
0005434926570	14963	Economy	7600.00
0005434926615	14963	Economy	7600.00
0005434926698	14963	Economy	7600.00
0005434926537	14963	Economy	8400.00
0005434926781	14963	Economy	8400.00
0005434926602	14963	Economy	8400.00
0005434926498	14963	Economy	7600.00
0005434926630	14963	Economy	7600.00
0005434926554	14963	Economy	7600.00
0005434926553	14963	Economy	7600.00
0005434926491	14963	Economy	7600.00
0005434926497	14963	Economy	7600.00
0005434926782	14963	Economy	7600.00
0005434926556	14963	Economy	7600.00
0005434926699	14963	Economy	7600.00
0005434926559	14963	Economy	7600.00
0005434926597	14963	Economy	7600.00
0005434926479	14963	Economy	7600.00
0005434926421	14963	Economy	7600.00
0005434926510	14963	Economy	7600.00
0005434926627	14963	Economy	7600.00
0005434926524	14963	Economy	7600.00
0005434926492	14963	Economy	7600.00
0005434926486	14963	Economy	7600.00
0005434926534	14963	Economy	7600.00
0005434926478	14963	Economy	7600.00
0005434926558	14963	Economy	7600.00
0005434926422	14963	Economy	7600.00
0005434926565	14963	Economy	7600.00
0005434926607	14963	Economy	7600.00
0005434926660	14963	Economy	7600.00
0005434926485	14963	Economy	7600.00
0005434926541	14963	Economy	7600.00
0005434926626	14963	Economy	7600.00
0005434926742	14963	Economy	7600.00
0005434926705	14963	Economy	7600.00
0005434926475	14963	Economy	7600.00
0005434926860	20552	Economy	7600.00
0005434926859	20552	Economy	7600.00
0005434926856	20552	Economy	7600.00
0005434926858	20552	Economy	8400.00
0005434926857	20552	Economy	7600.00
0005434926853	20552	Economy	7600.00
0005434926854	20552	Economy	7600.00
0005434926855	20552	Economy	7600.00
0005435999785	15838	Economy	8900.00
0005435999766	15838	Economy	8100.00
0005435999733	15838	Economy	8100.00
0005435999758	15838	Economy	8100.00
0005435999678	15838	Economy	8100.00
0005435999677	15838	Economy	8100.00
0005435999660	15838	Economy	8100.00
0005435488478	15838	Economy	8100.00
0005435999704	15838	Economy	8100.00
0005435999735	15838	Economy	8100.00
0005435999737	15838	Economy	8100.00
0005435999657	15838	Economy	8100.00
0005435999759	15838	Economy	8100.00
0005435999665	15838	Economy	8100.00
0005435999739	15838	Economy	8100.00
0005435999649	15838	Economy	8100.00
0005435999653	15838	Economy	8100.00
0005435999642	15838	Economy	8100.00
0005435999666	15838	Economy	8100.00
0005435999780	15838	Economy	8100.00
0005435999658	15838	Economy	8100.00
0005435999736	15838	Economy	8100.00
0005435999792	15838	Economy	8100.00
0005435999725	15838	Economy	8100.00
0005435999641	15838	Economy	8100.00
0005435999786	15838	Economy	8100.00
0005435999603	15838	Economy	8100.00
0005435999716	15838	Economy	8100.00
0005435999715	15838	Economy	8100.00
0005435999862	19674	Economy	8900.00
0005435488223	19674	Economy	8100.00
0005435488340	19674	Economy	8100.00
0005435488276	19674	Economy	8100.00
0005435488407	19674	Economy	8100.00
0005435488410	19674	Economy	8100.00
0005435488284	19674	Economy	8100.00
0005435488243	19674	Economy	8100.00
0005435488278	19674	Economy	8100.00
0005435488299	19674	Economy	8100.00
0005435488277	19674	Economy	8100.00
0005435999861	19674	Economy	8100.00
0005435488286	19674	Economy	8100.00
0005435488364	19674	Economy	8100.00
0005435488382	19674	Economy	8100.00
0005435488224	19674	Economy	8100.00
0005435473241	6025	Business	199300.00
0005435473235	6025	Business	199300.00
0005435473209	6025	Business	199300.00
0005435473250	6025	Economy	66400.00
0005435473282	6025	Economy	66400.00
0005435473182	6025	Economy	66400.00
0005435473249	6025	Economy	66400.00
0005435473251	6025	Economy	66400.00
0005435473280	6025	Economy	66400.00
0005432537108	6025	Economy	66400.00
0005435473172	6025	Economy	66400.00
0005435473183	6025	Economy	66400.00
0005435473242	6025	Economy	66400.00
0005435473181	6025	Economy	66400.00
0005435473234	6025	Economy	66400.00
0005435473258	6025	Economy	66400.00
0005435473224	6025	Economy	66400.00
0005435473281	6025	Economy	66400.00
0005432664173	18075	Business	199300.00
0005435840120	18075	Business	199300.00
0005435840163	18075	Business	199300.00
0005435840102	18075	Business	199300.00
0005435840199	18075	Business	199300.00
0005435840139	18075	Business	199300.00
0005435840095	18075	Economy	66400.00
0005435840221	18075	Economy	66400.00
0005435840110	18075	Economy	66400.00
0005432664179	18075	Economy	66400.00
0005435840133	18075	Economy	66400.00
0005435840178	18075	Economy	73100.00
0005435840043	18075	Economy	66400.00
0005435840155	18075	Economy	66400.00
0005435840024	18075	Economy	66400.00
0005435840234	18075	Economy	66400.00
0005435840138	18075	Economy	66400.00
0005432660868	18075	Economy	66400.00
0005435840121	18075	Economy	66400.00
0005432660869	18075	Economy	66400.00
0005435840211	18075	Economy	66400.00
0005435840122	18075	Economy	66400.00
0005435840222	18075	Economy	66400.00
0005435840236	18075	Economy	66400.00
0005435840025	18075	Economy	66400.00
0005432664184	18075	Economy	66400.00
0005435840200	18075	Economy	66400.00
0005435840151	18075	Economy	66400.00
0005435840248	18075	Economy	66400.00
0005432667500	18075	Economy	66400.00
0005435840044	18075	Economy	66400.00
0005435840127	18075	Economy	66400.00
0005435840210	18075	Economy	66400.00
0005435840094	18075	Economy	66400.00
0005435840132	18075	Economy	66400.00
0005435840150	18075	Economy	66400.00
0005435840109	18075	Economy	66400.00
0005435840214	18075	Economy	66400.00
0005435840260	18075	Economy	66400.00
0005435840134	18075	Economy	66400.00
0005435840179	18075	Economy	66400.00
0005435840156	18075	Economy	66400.00
0005435840201	18075	Economy	66400.00
0005433286099	23028	Business	15700.00
0005433286057	23028	Business	15700.00
0005433286019	23028	Business	15700.00
0005435097523	23028	Business	15700.00
0005435097526	23028	Economy	5200.00
0005435104378	23028	Economy	5200.00
0005433286074	23028	Economy	5200.00
0005433286112	23028	Economy	5200.00
0005435097524	23028	Economy	5200.00
0005433286139	23028	Economy	5200.00
0005433286098	23028	Economy	5200.00
0005433286208	23028	Economy	5200.00
0005433286085	23028	Economy	5200.00
0005433286114	23028	Economy	5200.00
0005433286145	23028	Economy	5700.00
0005433286081	23028	Economy	5200.00
0005433286159	23028	Economy	5200.00
0005433285997	23028	Economy	5200.00
0005435104377	23028	Economy	5200.00
0005433286060	23028	Economy	5200.00
0005433285899	23028	Economy	5200.00
0005433286080	23028	Economy	5200.00
0005433286113	23028	Economy	5200.00
0005433286124	23028	Economy	5200.00
0005435097525	23028	Economy	5200.00
0005433286061	23028	Economy	5200.00
0005435104380	23028	Economy	5200.00
0005433286073	23028	Economy	5200.00
0005433286207	23028	Economy	5200.00
0005433286020	23028	Economy	5200.00
0005433286027	23028	Economy	5200.00
0005433286115	23028	Economy	5200.00
0005433286111	23028	Economy	5200.00
0005435104379	23028	Economy	5200.00
0005433285898	23028	Economy	5200.00
0005433286059	23028	Economy	5200.00
0005435104159	32040	Business	15700.00
0005435104166	32040	Business	15700.00
0005435104316	32040	Business	15700.00
0005435104218	32040	Business	15700.00
0005435104265	32040	Business	15700.00
0005435104173	32040	Business	15700.00
0005435104228	32040	Economy	5200.00
0005435104095	32040	Economy	5200.00
0005435104151	32040	Economy	5200.00
0005435104082	32040	Economy	5200.00
0005435104257	32040	Economy	5200.00
0005435104135	32040	Economy	5200.00
0005435104167	32040	Economy	5700.00
0005435104297	32040	Economy	5200.00
0005435104156	32040	Economy	5200.00
0005435104224	32040	Economy	5200.00
0005435104137	32040	Economy	5200.00
0005435104219	32040	Economy	5200.00
0005435104315	32040	Economy	5200.00
0005435104150	32040	Economy	5200.00
0005433286229	32040	Economy	5200.00
0005435104160	32040	Economy	5200.00
0005433112394	1480	Business	150400.00
0005433112395	1480	Business	150400.00
0005432802639	1480	Business	150400.00
0005433112400	1480	Business	150400.00
0005432802641	1480	Business	150400.00
0005433112405	1480	Business	150400.00
0005432892812	1480	Business	150400.00
0005432892796	1480	Business	150400.00
0005432802630	1480	Economy	50100.00
0005432892800	1480	Economy	50100.00
0005433112397	1480	Economy	50100.00
0005432892809	1480	Economy	50100.00
0005432892810	1480	Economy	50100.00
0005432892814	1480	Economy	55200.00
0005433112396	1480	Economy	50100.00
0005433112401	1480	Economy	50100.00
0005432802628	1480	Economy	50100.00
0005432892797	1480	Economy	50100.00
0005432802633	1480	Economy	50100.00
0005432802634	1480	Economy	50100.00
0005432802642	1480	Economy	50100.00
0005433112393	1480	Economy	50100.00
0005432802638	1480	Economy	50100.00
0005432892799	1480	Economy	50100.00
0005432802643	1480	Economy	50100.00
0005432892808	1480	Economy	50100.00
0005432892813	1480	Economy	50100.00
0005432892819	1480	Economy	50100.00
0005432802629	1480	Economy	50100.00
0005432802636	1480	Economy	50100.00
0005432892820	1480	Economy	50100.00
0005432802640	1480	Economy	50100.00
0005433112398	1480	Economy	50100.00
0005432802627	1480	Economy	50100.00
0005432802632	1480	Economy	50100.00
0005432892801	1480	Economy	50100.00
0005433112403	1480	Economy	50100.00
0005432892795	1480	Economy	50100.00
0005432802637	1480	Economy	50100.00
0005432802631	1480	Economy	50100.00
0005433112404	1480	Economy	50100.00
0005432802635	1480	Economy	50100.00
0005432892811	1480	Economy	50100.00
0005433112402	1480	Economy	50100.00
0005433475792	23875	Economy	13500.00
0005433475799	23875	Economy	13500.00
0005433475813	23875	Economy	12300.00
0005433475818	23875	Economy	12300.00
0005433475806	23875	Economy	12300.00
0005433475808	23875	Economy	12300.00
0005433475801	23875	Economy	12300.00
0005433475793	23875	Economy	12300.00
0005433475800	23875	Economy	12300.00
0005433475805	23875	Economy	12300.00
0005433475819	23875	Economy	12300.00
0005433475791	23875	Economy	12300.00
0005433475804	23875	Economy	12300.00
0005434069148	30587	Business	42100.00
0005432531467	30587	Business	42100.00
0005432531568	30587	Business	42100.00
0005432531117	30587	Business	42100.00
0005432531529	30587	Business	42100.00
0005432531531	30587	Business	42100.00
0005434069442	30587	Business	42100.00
0005434069221	30587	Business	42100.00
0005432531123	30587	Business	42100.00
0005432531593	30587	Business	42100.00
0005432531063	30587	Business	42100.00
0005434069376	30587	Business	42100.00
0005432531503	30587	Business	42100.00
0005432533368	30587	Business	42100.00
0005432531242	30587	Comfort	23900.00
0005434069401	30587	Comfort	23900.00
0005432531472	30587	Comfort	23900.00
0005434069302	30587	Comfort	23900.00
0005434069332	30587	Comfort	23900.00
0005432531247	30587	Comfort	23900.00
0005432531243	30587	Comfort	23900.00
0005432530762	30587	Comfort	23900.00
0005432531260	30587	Comfort	23900.00
0005432531465	30587	Comfort	23900.00
0005432531339	30587	Comfort	23900.00
0005432531573	30587	Comfort	23900.00
0005432531605	30587	Comfort	23900.00
0005432530735	30587	Comfort	23900.00
0005432531453	30587	Economy	14000.00
0005432531501	30587	Economy	14000.00
0005434069337	30587	Economy	14000.00
0005432530932	30587	Economy	14000.00
0005432530760	30587	Economy	14000.00
0005434069234	30587	Economy	14000.00
0005432530878	30587	Economy	14000.00
0005432531469	30587	Economy	14000.00
0005434069377	30587	Economy	14000.00
0005432531414	30587	Economy	14000.00
0005434069507	30587	Economy	14000.00
0005432530364	30587	Economy	14000.00
0005432531647	30587	Economy	14000.00
0005432531248	30587	Economy	14000.00
0005432531646	30587	Economy	14000.00
0005432531502	30587	Economy	14000.00
0005434069222	30587	Economy	14000.00
0005432531505	30587	Economy	14000.00
0005432531189	30587	Economy	14000.00
0005432530899	30587	Economy	14000.00
0005432531368	30587	Economy	14000.00
0005432531494	30587	Economy	14000.00
0005432531098	30587	Economy	14000.00
0005432531180	30587	Economy	14000.00
0005432531567	30587	Economy	14000.00
0005434069161	30587	Economy	14000.00
0005434069443	30587	Economy	14000.00
0005434069268	30587	Economy	14000.00
0005434069295	30587	Economy	14000.00
0005432531595	30587	Economy	14000.00
0005432531579	30587	Economy	15400.00
0005432531390	30587	Economy	15400.00
0005432530805	30587	Economy	14000.00
0005432531530	30587	Economy	15400.00
0005434069271	30587	Economy	14000.00
0005432530900	30587	Economy	14000.00
0005435215534	30587	Economy	14000.00
0005432531271	30587	Economy	14000.00
0005434069272	30587	Economy	14000.00
0005434069235	30587	Economy	14000.00
0005432530982	30587	Economy	14000.00
0005432530734	30587	Economy	14000.00
0005432531603	30587	Economy	14000.00
0005434069363	30587	Economy	14000.00
0005432531002	30587	Economy	14000.00
0005432531325	30587	Economy	14000.00
0005432531233	30587	Economy	14000.00
0005432531473	30587	Economy	14000.00
0005434069440	30587	Economy	14000.00
0005432530901	30587	Economy	14000.00
0005432531269	30587	Economy	14000.00
0005434069407	30587	Economy	14000.00
0005432531406	30587	Economy	14000.00
0005432530808	30587	Economy	14000.00
0005434069311	30587	Economy	14000.00
0005434069452	30587	Economy	14000.00
0005434069254	30587	Economy	14000.00
0005432533367	30587	Economy	14000.00
0005432531415	30587	Economy	14000.00
0005432531660	30587	Economy	14000.00
0005432531644	30587	Economy	14000.00
0005432531659	30587	Economy	14000.00
0005432531594	30587	Economy	14000.00
0005434069341	30587	Economy	14000.00
0005432530780	30587	Economy	14000.00
0005432530842	30587	Economy	14000.00
0005434069441	30587	Economy	14000.00
0005432531518	30587	Economy	14000.00
0005432530761	30587	Economy	14000.00
0005434069543	30587	Economy	14000.00
0005432531609	30587	Economy	14000.00
0005434069336	30587	Economy	14000.00
0005432531399	30587	Economy	14000.00
0005434069378	30587	Economy	14000.00
0005434069466	30587	Economy	14000.00
0005432535955	30587	Economy	14000.00
0005432537113	30587	Economy	14000.00
0005434069303	30587	Economy	14000.00
0005432531500	30587	Economy	14000.00
0005432530924	30587	Economy	14000.00
0005434069508	30587	Economy	15400.00
0005434069226	30587	Economy	15400.00
0005432531158	30587	Economy	14000.00
0005434069166	30587	Economy	14000.00
0005432531188	30587	Economy	14000.00
0005432531036	30587	Economy	14000.00
0005434069259	30587	Economy	14000.00
0005434068996	30587	Economy	14000.00
0005432531645	30587	Economy	14000.00
0005432531658	30587	Economy	14000.00
0005434069255	30587	Economy	14000.00
0005434069151	30587	Economy	14000.00
0005432531389	30587	Economy	14000.00
0005432531468	30587	Economy	14000.00
0005432537109	30587	Economy	14000.00
0005432531604	30587	Economy	14000.00
0005434068966	30587	Economy	14000.00
0005432531528	30587	Economy	14000.00
0005434069031	30587	Economy	14000.00
0005434069289	30587	Economy	14000.00
0005434069294	30587	Economy	14000.00
0005434069510	30587	Economy	14000.00
0005434069278	30587	Economy	14000.00
0005434069493	30587	Economy	14000.00
0005434069260	30587	Economy	14000.00
0005432533364	30587	Economy	14000.00
0005434069015	30587	Economy	14000.00
0005432531464	30587	Economy	14000.00
0005432531596	30587	Economy	14000.00
0005435215535	30587	Economy	14000.00
0005434069227	30587	Economy	14000.00
0005434069327	30587	Economy	14000.00
0005432535954	30587	Economy	14000.00
0005432531413	30587	Economy	14000.00
0005434069212	30587	Economy	14000.00
0005432531108	30587	Economy	14000.00
0005432530925	30587	Economy	14000.00
0005432531270	30587	Economy	14000.00
0005432535953	30587	Economy	14000.00
0005432530804	30587	Economy	14000.00
0005434069398	30587	Economy	14000.00
0005434069296	30587	Economy	14000.00
0005432531355	30587	Economy	14000.00
0005432531062	30587	Economy	14000.00
0005432531153	30587	Economy	14000.00
0005432530933	30587	Economy	14000.00
0005432531407	30587	Economy	14000.00
0005432530652	30587	Economy	14000.00
0005435654283	24863	Business	9800.00
0005435654183	24863	Business	9800.00
0005435654246	24863	Business	9800.00
0005435654073	24863	Business	9800.00
0005435654225	24863	Economy	3300.00
0005435654247	24863	Economy	3300.00
0005435654319	24863	Economy	3300.00
0005435654304	24863	Economy	3300.00
0005435654166	24863	Economy	3300.00
0005435654109	24863	Economy	3600.00
0005435654206	24863	Economy	3600.00
0005435654257	24863	Economy	3300.00
0005435654310	24863	Economy	3300.00
0005435654026	24863	Economy	3300.00
0005435654221	24863	Economy	3300.00
0005435654167	24863	Economy	3300.00
0005435654203	24863	Economy	3300.00
0005435654067	24863	Economy	3300.00
0005435654282	24863	Economy	3300.00
0005435654101	24863	Economy	3300.00
0005435654261	24863	Economy	3300.00
0005435654220	24863	Economy	3300.00
0005435654091	24863	Economy	3300.00
0005435654252	24863	Economy	3300.00
0005435654174	24863	Economy	3300.00
0005435654145	24863	Economy	3300.00
0005435654329	24863	Economy	3300.00
0005435654072	24863	Economy	3300.00
0005435654193	24863	Economy	3300.00
0005435654025	24863	Economy	3300.00
0005435654024	24863	Economy	3300.00
0005435654139	24863	Economy	3300.00
0005435654144	24863	Economy	3300.00
0005435654177	24863	Economy	3300.00
0005435654464	24863	Economy	3300.00
0005435654071	24863	Economy	3300.00
0005435654258	24863	Economy	3300.00
0005435654069	24863	Economy	3300.00
0005435654068	24863	Economy	3300.00
0005435654256	24863	Economy	3300.00
0005435654057	24863	Economy	3300.00
0005435654422	24863	Economy	3300.00
0005435654092	24863	Economy	3300.00
0005435654299	24863	Economy	3300.00
0005435653846	24863	Economy	3300.00
0005434980494	23583	Economy	10500.00
0005435801772	23583	Economy	10500.00
0005434980561	23583	Economy	9500.00
0005434980536	23583	Economy	9500.00
0005434980423	23583	Economy	9500.00
0005434980551	23583	Economy	9500.00
0005434980533	23583	Economy	9500.00
0005434980491	23583	Economy	9500.00
0005434980452	23583	Economy	9500.00
0005434980445	23583	Economy	9500.00
0005434980420	23583	Economy	9500.00
0005434980557	23583	Economy	9500.00
0005434980562	23583	Economy	9500.00
0005434980535	23583	Economy	9500.00
0005435801773	23583	Economy	9500.00
0005434980546	23583	Economy	9500.00
0005434980496	23583	Economy	9500.00
0005434980593	23583	Economy	9500.00
0005434980441	23583	Economy	9500.00
0005434980456	23583	Economy	9500.00
0005434980451	23583	Economy	9500.00
0005434980439	23583	Economy	9500.00
0005434980478	23583	Economy	9500.00
0005434980495	23583	Economy	9500.00
0005434980440	23583	Economy	9500.00
0005434952625	28281	Economy	5300.00
0005434952611	28281	Economy	5300.00
0005434952620	28281	Economy	5300.00
0005434952624	28281	Economy	5300.00
0005434952619	28281	Economy	5300.00
0005434952610	28281	Economy	5300.00
0005434952621	28281	Economy	5300.00
0005434952628	28281	Economy	5300.00
0005434302892	19749	Economy	8700.00
0005434302897	19749	Economy	8700.00
0005434302895	19749	Economy	8700.00
0005434302902	19749	Economy	8700.00
0005433112397	20038	Economy	8700.00
0005433112405	20038	Economy	8700.00
0005433112400	20038	Economy	8700.00
0005433112403	20038	Economy	8700.00
0005433112393	20038	Economy	8700.00
0005433112394	20038	Economy	8700.00
0005433112402	20038	Economy	8700.00
0005433112398	20038	Economy	8700.00
0005433112404	20038	Economy	8700.00
0005433112396	20038	Economy	8700.00
0005433112395	20038	Economy	8700.00
0005433112401	20038	Economy	8700.00
0005434140219	11970	Business	9700.00
0005434140026	11970	Business	9700.00
0005434139818	11970	Business	9700.00
0005434140305	11970	Business	9700.00
0005434140543	11970	Business	9700.00
0005434140487	11970	Business	9700.00
0005434140458	11970	Business	9700.00
0005434140335	11970	Business	9700.00
0005434140353	11970	Business	9700.00
0005434140269	11970	Economy	3200.00
0005434140111	11970	Economy	3200.00
0005434140467	11970	Economy	3200.00
0005434140490	11970	Economy	3200.00
0005434140403	11970	Economy	3200.00
0005434140603	11970	Economy	3200.00
0005434140407	11970	Economy	3200.00
0005434140451	11970	Economy	3500.00
0005434140409	11970	Economy	3500.00
0005434140035	11970	Economy	3500.00
0005434140317	11970	Economy	3500.00
0005434140298	11970	Economy	3500.00
0005434140288	11970	Economy	3200.00
0005434140142	11970	Economy	3200.00
0005434140048	11970	Economy	3200.00
0005434140425	11970	Economy	3200.00
0005434140015	11970	Economy	3200.00
0005434140367	11970	Economy	3200.00
0005434140344	11970	Economy	3200.00
0005434140334	11970	Economy	3200.00
0005434140579	11970	Economy	3200.00
0005434140280	11970	Economy	3200.00
0005434140549	11970	Economy	3200.00
0005434140406	11970	Economy	3200.00
0005434140261	11970	Economy	3200.00
0005434139944	11970	Economy	3200.00
0005434140410	11970	Economy	3200.00
0005434139992	11970	Economy	3200.00
0005434140262	11970	Economy	3200.00
0005434140024	11970	Economy	3200.00
0005434139974	11970	Economy	3200.00
0005434140304	11970	Economy	3200.00
0005434140323	11970	Economy	3200.00
0005434139973	11970	Economy	3200.00
0005434139678	11970	Economy	3200.00
0005434140468	11970	Economy	3200.00
0005434140453	11970	Economy	3200.00
0005434139897	11970	Economy	3200.00
0005434140448	11970	Economy	3200.00
0005434139893	11970	Economy	3200.00
0005434139817	11970	Economy	3200.00
0005434140279	11970	Economy	3200.00
0005434140256	11970	Economy	3200.00
0005434140420	11970	Economy	3200.00
0005434140025	11970	Economy	3200.00
0005434140050	11970	Economy	3200.00
0005434140322	11970	Economy	3200.00
0005434140299	11970	Economy	3200.00
0005434140350	11970	Economy	3200.00
0005434140165	11970	Economy	3200.00
0005434140218	11970	Economy	3200.00
0005434139945	11970	Economy	3200.00
0005434140456	11970	Economy	3200.00
0005434140186	11970	Economy	3200.00
0005434140542	11970	Economy	3200.00
0005434140078	11970	Economy	3200.00
0005434140049	11970	Economy	3200.00
0005434140392	11970	Economy	3200.00
0005434140414	11970	Economy	3200.00
0005434140255	11970	Economy	3200.00
0005434140343	11970	Economy	3200.00
0005434140445	11970	Economy	3200.00
0005434140093	11970	Economy	3200.00
0005434140077	11970	Economy	3200.00
0005434140226	11970	Economy	3200.00
0005434140345	11970	Economy	3200.00
0005434140250	11970	Economy	3200.00
0005434140375	11970	Economy	3200.00
0005434140166	11970	Economy	3200.00
0005434139892	11970	Economy	3200.00
0005434140080	11970	Economy	3200.00
0005434140580	11970	Economy	3200.00
0005434140222	11970	Economy	3200.00
0005434140306	11970	Economy	3200.00
0005434140510	11970	Economy	3200.00
0005434139883	11970	Economy	3200.00
0005434140295	11970	Economy	3200.00
0005434140442	11970	Economy	3200.00
0005434140625	28741	Economy	3200.00
0005434140627	28741	Economy	3200.00
0005434140628	28741	Economy	3200.00
0005434140626	28741	Economy	3200.00
0005435312867	6578	Economy	23000.00
0005435312873	6578	Economy	23000.00
0005435312872	6578	Economy	20900.00
0005435312865	6578	Economy	20900.00
0005435312862	6578	Economy	20900.00
0005435312860	6578	Economy	20900.00
0005435312864	6578	Economy	20900.00
0005434466611	6578	Economy	20900.00
0005435312870	6578	Economy	20900.00
0005435312869	6578	Economy	20900.00
0005435259886	6803	Economy	9900.00
0005435259848	6803	Economy	9900.00
0005433539090	25009	Economy	9900.00
0005433539088	25009	Economy	9900.00
0005433534557	25009	Economy	9900.00
0005433534550	25009	Economy	9900.00
0005433539062	25009	Economy	9900.00
0005433539102	25009	Economy	9900.00
0005433534558	25009	Economy	9900.00
0005433539095	25009	Economy	9900.00
0005433539072	25009	Economy	9900.00
0005433539096	25009	Economy	9900.00
0005432922625	822	Economy	14600.00
0005432922626	822	Economy	14600.00
0005432922624	822	Economy	14600.00
0005432922633	822	Economy	14600.00
0005432922631	822	Economy	14600.00
0005432922632	822	Economy	14600.00
0005432922627	822	Economy	14600.00
0005433512156	16156	Economy	14600.00
0005433512155	16156	Economy	14600.00
0005433512176	16156	Economy	14600.00
0005435852650	4042	Economy	13500.00
0005435852649	4042	Economy	12300.00
0005435852648	4042	Economy	12300.00
0005435935123	3666	Economy	7900.00
0005435935130	3666	Economy	7200.00
0005435935114	3666	Economy	7200.00
0005435933565	3666	Economy	7200.00
0005435916231	3666	Economy	7200.00
0005435935125	3666	Economy	7200.00
0005435935124	3666	Economy	7200.00
0005435698079	16262	Economy	7900.00
0005435698078	16262	Economy	7900.00
0005435698033	16262	Economy	7200.00
0005435698006	16262	Economy	7200.00
0005435697964	16262	Economy	7200.00
0005435698035	16262	Economy	7200.00
0005435698067	16262	Economy	7200.00
0005435698098	16262	Economy	7200.00
0005434950631	16262	Economy	7200.00
0005435698100	16262	Economy	7200.00
0005434950653	16262	Economy	7200.00
0005435698089	16262	Economy	7200.00
0005435698073	16262	Economy	7200.00
0005435698036	16262	Economy	7200.00
0005435698018	16262	Economy	7200.00
0005435698011	16262	Economy	7200.00
0005435697965	16262	Economy	7200.00
0005434950645	16262	Economy	7200.00
0005435698047	16262	Economy	7200.00
0005435698001	16262	Economy	7200.00
0005434950652	16262	Economy	7200.00
0005435697963	16262	Economy	7200.00
0005435698038	16262	Economy	7200.00
0005435698057	16262	Economy	7200.00
0005435842345	3991	Economy	19300.00
0005433519578	22059	Economy	21300.00
0005433519543	22059	Economy	19300.00
0005433519577	22059	Economy	19300.00
0005433519589	22059	Economy	19300.00
0005433519580	22059	Economy	19300.00
0005434606918	22059	Economy	19300.00
0005433519581	22059	Economy	19300.00
0005434606901	22059	Economy	19300.00
0005434606903	22059	Economy	19300.00
0005435904916	22059	Economy	19300.00
0005434606900	22059	Economy	19300.00
0005434606919	22059	Economy	19300.00
0005433349131	756	Economy	3700.00
0005433349137	756	Economy	3700.00
0005433349152	756	Economy	3700.00
0005433349154	756	Economy	3700.00
0005433349145	756	Economy	3700.00
0005435628806	15960	Economy	3700.00
0005435628807	15960	Economy	3700.00
0005435628805	15960	Economy	3700.00
0005433158181	17228	Economy	7100.00
0005433158188	17228	Economy	7100.00
0005433159372	17228	Economy	7100.00
0005433159371	17228	Economy	7100.00
0005433158187	17228	Economy	7100.00
0005433159375	17228	Economy	7100.00
0005433158180	17228	Economy	7100.00
0005433159374	17228	Economy	7100.00
0005434445292	17603	Economy	7100.00
0005435133182	33102	Economy	5900.00
0005435133167	33102	Economy	5400.00
0005435133088	33102	Economy	5400.00
0005435133155	33102	Economy	5400.00
0005435133188	33102	Economy	5400.00
0005435133142	33102	Economy	5400.00
0005435133187	33102	Economy	5400.00
0005435390437	7497	Economy	12500.00
0005435390404	7497	Economy	12500.00
0005435390394	7497	Economy	12500.00
0005435390436	7497	Economy	12500.00
0005435160613	29571	Economy	13800.00
0005435160597	29571	Economy	12500.00
0005435160618	29571	Economy	12500.00
0005435160603	29571	Economy	12500.00
0005435160585	29571	Economy	12500.00
0005435160596	29571	Economy	12500.00
0005435160617	29571	Economy	12500.00
0005435160604	29571	Economy	12500.00
0005435160614	29571	Economy	12500.00
0005435160586	29571	Economy	12500.00
0005432398299	18463	Economy	4900.00
0005432394209	18463	Economy	4900.00
0005432394212	18463	Economy	4900.00
0005432398284	18463	Economy	4900.00
0005432398298	18463	Economy	4900.00
0005432394205	18463	Economy	4900.00
0005432398283	18463	Economy	4900.00
0005432400223	27156	Economy	4900.00
0005435178536	27156	Economy	4900.00
0005435179420	27156	Economy	4900.00
0005435179421	27156	Economy	4900.00
0005435179422	27156	Economy	4900.00
0005432398304	27156	Economy	4900.00
0005432866188	2251	Business	87300.00
0005432639505	2251	Business	87300.00
0005432866187	2251	Economy	29100.00
0005432866201	2251	Economy	29100.00
0005432639502	2251	Economy	32000.00
0005432866211	2251	Economy	32000.00
0005432866204	2251	Economy	29100.00
0005432866202	2251	Economy	29100.00
0005432866199	2251	Economy	29100.00
0005432866177	2251	Economy	29100.00
0005432866154	2251	Economy	29100.00
0005432866195	2251	Economy	29100.00
0005432866198	2251	Economy	29100.00
0005432639503	2251	Economy	29100.00
0005432866184	2251	Economy	29100.00
0005432639506	2251	Economy	29100.00
0005432866158	2251	Economy	29100.00
0005432866153	2251	Economy	29100.00
0005432866186	2251	Economy	29100.00
0005432866210	2251	Economy	29100.00
0005432866161	2251	Economy	29100.00
0005432866185	2251	Economy	29100.00
0005432866190	2251	Economy	29100.00
0005432866194	2251	Economy	29100.00
0005432866203	2251	Economy	29100.00
0005432866169	2251	Economy	29100.00
0005432866200	2251	Economy	29100.00
0005432639504	2251	Economy	29100.00
0005434191310	9781	Economy	4400.00
0005434191317	9781	Economy	4400.00
0005434191318	9781	Economy	4400.00
0005434191311	9781	Economy	4400.00
0005435104385	6517	Business	48400.00
0005435104386	6517	Economy	16100.00
0005435104387	6517	Economy	16100.00
0005434505320	6517	Economy	16100.00
0005435104095	22677	Business	48400.00
0005434505127	22677	Business	48400.00
0005435104160	22677	Business	48400.00
0005434504980	22677	Business	48400.00
0005434505119	22677	Business	48400.00
0005435104159	22677	Business	48400.00
0005434505082	22677	Business	48400.00
0005435104166	22677	Business	48400.00
0005435104228	22677	Business	48400.00
0005434504973	22677	Economy	16100.00
0005434504989	22677	Economy	16100.00
0005434505216	22677	Economy	16100.00
0005434505135	22677	Economy	16100.00
0005434505228	22677	Economy	16100.00
0005435104219	22677	Economy	16100.00
0005434505093	22677	Economy	16100.00
0005434505094	22677	Economy	16100.00
0005435312886	22677	Economy	17800.00
0005434505051	22677	Economy	17800.00
0005434504941	22677	Economy	17800.00
0005434505222	22677	Economy	17800.00
0005435104082	22677	Economy	16100.00
0005434505036	22677	Economy	16100.00
0005434505091	22677	Economy	16100.00
0005434504979	22677	Economy	16100.00
0005435104316	22677	Economy	16100.00
0005435104224	22677	Economy	16100.00
0005435104151	22677	Economy	16100.00
0005434505078	22677	Economy	16100.00
0005435104137	22677	Economy	16100.00
0005435104150	22677	Economy	16100.00
0005434505144	22677	Economy	16100.00
0005434505050	22677	Economy	16100.00
0005434505005	22677	Economy	16100.00
0005435104297	22677	Economy	16100.00
0005434505037	22677	Economy	16100.00
0005434505007	22677	Economy	16100.00
0005434505217	22677	Economy	16100.00
0005434505118	22677	Economy	16100.00
0005435104265	22677	Economy	16100.00
0005434504940	22677	Economy	16100.00
0005434505211	22677	Economy	16100.00
0005434505090	22677	Economy	16100.00
0005435104156	22677	Economy	16100.00
0005435104218	22677	Economy	16100.00
0005435104257	22677	Economy	16100.00
0005434505079	22677	Economy	16100.00
0005434505183	22677	Economy	16100.00
0005435104173	22677	Economy	16100.00
0005435312887	22677	Economy	16100.00
0005435104135	22677	Economy	16100.00
0005434505215	22677	Economy	16100.00
0005435104167	22677	Economy	16100.00
0005435104315	22677	Economy	16100.00
0005435312888	22677	Economy	16100.00
0005434505061	22677	Economy	16100.00
0005434505124	22677	Economy	16100.00
0005434505129	22677	Economy	16100.00
0005434505221	22677	Economy	16100.00
0005434505235	22677	Economy	16100.00
0005434505166	22677	Economy	16100.00
0005434505133	22677	Economy	16100.00
0005434505073	22677	Economy	16100.00
0005435312889	22677	Economy	16100.00
0005434505212	22677	Economy	16100.00
0005434505117	22677	Economy	16100.00
0005434505092	22677	Economy	16100.00
0005435800176	6425	Economy	16800.00
0005435800178	6425	Economy	15300.00
0005435800179	6425	Economy	15300.00
0005435800175	6425	Economy	15300.00
0005435800177	6425	Economy	15300.00
0005435800180	6425	Economy	15300.00
0005433368769	1686	Business	50000.00
0005433368832	1686	Business	50000.00
0005433368722	1686	Business	50000.00
0005433368901	1686	Economy	16700.00
0005433368924	1686	Economy	16700.00
0005433368691	1686	Economy	16700.00
0005433368851	1686	Economy	16700.00
0005433368863	1686	Economy	18300.00
0005433368905	1686	Economy	18300.00
0005433368720	1686	Economy	16700.00
0005433368900	1686	Economy	16700.00
0005433368957	1686	Economy	16700.00
0005433368873	1686	Economy	16700.00
0005433368682	1686	Economy	16700.00
0005433368850	1686	Economy	16700.00
0005433368923	1686	Economy	16700.00
0005433368958	1686	Economy	16700.00
0005433368715	1686	Economy	16700.00
0005433368811	1686	Economy	16700.00
0005433368790	1686	Economy	16700.00
0005433368854	1686	Economy	16700.00
0005433368885	1686	Economy	16700.00
0005433368884	1686	Economy	16700.00
0005433368721	1686	Economy	16700.00
0005433368938	1686	Economy	16700.00
0005435790411	1686	Economy	16700.00
0005433368828	1686	Economy	16700.00
0005433368910	1686	Economy	16700.00
0005433368886	1686	Economy	16700.00
0005433368907	1686	Economy	16700.00
0005435654166	21677	Business	50000.00
0005435654464	21677	Business	50000.00
0005435654261	21677	Business	50000.00
0005435654256	21677	Business	50000.00
0005435654422	21677	Business	50000.00
0005435654310	21677	Economy	16700.00
0005435654144	21677	Economy	16700.00
0005435654025	21677	Economy	16700.00
0005435654203	21677	Economy	16700.00
0005435654329	21677	Economy	16700.00
0005435654139	21677	Economy	18300.00
0005435653846	21677	Economy	18300.00
0005435654252	21677	Economy	16700.00
0005435654167	21677	Economy	16700.00
0005435654319	21677	Economy	16700.00
0005435654283	21677	Economy	16700.00
0005435654091	21677	Economy	16700.00
0005435654145	21677	Economy	16700.00
0005435654069	21677	Economy	16700.00
0005435654221	21677	Economy	16700.00
0005435654177	21677	Economy	16700.00
0005435654258	21677	Economy	16700.00
0005435654304	21677	Economy	16700.00
0005435654071	21677	Economy	16700.00
0005435654067	21677	Economy	16700.00
0005435654109	21677	Economy	16700.00
0005435654299	21677	Economy	16700.00
0005435654057	21677	Economy	16700.00
0005435654220	21677	Economy	16700.00
0005435654068	21677	Economy	16700.00
0005435654193	21677	Economy	16700.00
0005435654246	21677	Economy	16700.00
0005435654072	21677	Economy	16700.00
0005435654092	21677	Economy	16700.00
0005435654206	21677	Economy	16700.00
0005435654174	21677	Economy	16700.00
0005435654183	21677	Economy	16700.00
0005435654247	21677	Economy	16700.00
0005435654101	21677	Economy	16700.00
0005435654257	21677	Economy	16700.00
0005435654073	21677	Economy	16700.00
0005435654024	21677	Economy	16700.00
0005435654282	21677	Economy	16700.00
0005435654225	21677	Economy	16700.00
0005435654026	21677	Economy	16700.00
0005435627123	23789	Economy	11200.00
0005435312881	23229	Economy	23000.00
0005434466577	23229	Economy	23000.00
0005434466578	23229	Economy	20900.00
0005434466586	23229	Economy	20900.00
0005434466592	23229	Economy	20900.00
0005435312880	23229	Economy	20900.00
0005434466583	23229	Economy	20900.00
0005434466600	23229	Economy	20900.00
0005434466587	23229	Economy	20900.00
0005434466574	23229	Economy	20900.00
0005434466590	23229	Economy	20900.00
0005434466589	23229	Economy	20900.00
0005433987379	4139	Economy	7200.00
0005433986972	25644	Business	21500.00
0005433987230	25644	Business	21500.00
0005433987107	25644	Business	21500.00
0005433987294	25644	Business	21500.00
0005433986866	25644	Business	21500.00
0005433986852	25644	Economy	7200.00
0005433987056	25644	Economy	7200.00
0005433986925	25644	Economy	7200.00
0005433987245	25644	Economy	7200.00
0005433987136	25644	Economy	7200.00
0005433987109	25644	Economy	7900.00
0005433987159	25644	Economy	7900.00
0005433987250	25644	Economy	7200.00
0005433986977	25644	Economy	7200.00
0005433987135	25644	Economy	7200.00
0005433987143	25644	Economy	7200.00
0005433987046	25644	Economy	7200.00
0005433987225	25644	Economy	7200.00
0005433987234	25644	Economy	7200.00
0005433987062	25644	Economy	7200.00
0005433987061	25644	Economy	7200.00
0005433987108	25644	Economy	7200.00
0005433987206	25644	Economy	7200.00
0005433986865	25644	Economy	7200.00
0005433987168	25644	Economy	7200.00
0005433987115	25644	Economy	7200.00
0005433987113	25644	Economy	7200.00
0005433987190	25644	Economy	7200.00
0005435788832	25644	Economy	7200.00
0005433987092	25644	Economy	7200.00
0005433987015	25644	Economy	7200.00
0005433987194	25644	Economy	7200.00
0005433986973	25644	Economy	7200.00
0005433987063	25644	Economy	7200.00
0005433987155	25644	Economy	7200.00
0005433987229	25644	Economy	7200.00
0005433987199	25644	Economy	7200.00
0005433987214	25644	Economy	7200.00
0005433987014	25644	Economy	7200.00
0005433987095	25644	Economy	7200.00
0005433987189	25644	Economy	7200.00
0005433987149	25644	Economy	7200.00
0005433987059	25644	Economy	7200.00
0005433987114	25644	Economy	7200.00
0005433987169	25644	Economy	7200.00
0005433987207	25644	Economy	7200.00
0005433986937	25644	Economy	7200.00
0005433987167	25644	Economy	7200.00
0005433986999	25644	Economy	7200.00
0005435720858	21288	Economy	10400.00
0005435720861	21288	Economy	9400.00
0005435720857	21288	Economy	9400.00
0005435719592	21288	Economy	9400.00
0005435719595	21288	Economy	9400.00
0005435720860	21288	Economy	9400.00
0005435719596	21288	Economy	9400.00
0005434509364	21331	Economy	17000.00
0005434509331	21331	Economy	15500.00
0005434509349	21331	Economy	15500.00
0005434509338	21331	Economy	15500.00
0005434509360	21331	Economy	15500.00
0005434509362	21331	Economy	15500.00
0005434509352	21331	Economy	15500.00
0005434509351	21331	Economy	15500.00
0005434509361	21331	Economy	15500.00
0005434509371	21331	Economy	15500.00
0005432658644	17847	Business	18000.00
0005432655848	17847	Business	18000.00
0005432657519	17847	Business	18000.00
0005432657520	17847	Business	18000.00
0005432665317	17847	Economy	6000.00
0005432663076	17847	Economy	6000.00
0005432657518	17847	Economy	6000.00
0005432665318	17847	Economy	6000.00
0005432664192	17847	Economy	6600.00
0005432661987	17847	Economy	6000.00
0005432667512	17847	Economy	6000.00
0005432655810	17847	Economy	6000.00
0005432655852	17847	Economy	6000.00
0005432667513	17847	Economy	6000.00
0005432655849	17847	Economy	6000.00
0005432655833	17847	Economy	6000.00
0005432661965	17847	Economy	6000.00
0005432664195	17847	Economy	6000.00
0005432664191	17847	Economy	6000.00
0005432659758	17847	Economy	6000.00
0005432667508	17847	Economy	6000.00
0005432657517	17847	Economy	6000.00
0005432665333	17847	Economy	6000.00
0005432667511	17847	Economy	6000.00
0005432655821	17847	Economy	6000.00
0005432667514	17847	Economy	6000.00
0005432655840	17847	Economy	6000.00
0005432661988	17847	Economy	6000.00
0005432655832	17847	Economy	6000.00
0005432657522	17847	Economy	6000.00
0005432665316	17847	Economy	6000.00
0005432869700	26312	Economy	6000.00
0005432869681	26312	Economy	6000.00
0005432869699	26312	Economy	6600.00
0005432869659	26312	Economy	6000.00
0005434151780	26312	Economy	6000.00
0005432666449	26312	Economy	6000.00
0005434151781	26312	Economy	6000.00
0005432869663	26312	Economy	6000.00
0005432869712	26312	Economy	6000.00
0005432330062	3118	Business	16100.00
0005432905264	3118	Economy	5400.00
0005432848889	3118	Economy	5400.00
0005432848891	3118	Economy	5400.00
0005432848890	3118	Economy	5900.00
0005432330061	3118	Economy	5900.00
0005432848872	3118	Economy	5400.00
0005432848906	3118	Economy	5400.00
0005432848899	3118	Economy	5400.00
0005432330060	3118	Economy	5400.00
0005432848900	3118	Economy	5400.00
0005432848901	3118	Economy	5400.00
0005432329922	31143	Business	16100.00
0005432329849	31143	Business	16100.00
0005432848923	31143	Business	16100.00
0005432329787	31143	Business	16100.00
0005433439044	31143	Business	16100.00
0005433439095	31143	Economy	5400.00
0005432329946	31143	Economy	5400.00
0005432329694	31143	Economy	5400.00
0005433439084	31143	Economy	5400.00
0005432848925	31143	Economy	5400.00
0005433439085	31143	Economy	5400.00
0005432329941	31143	Economy	5900.00
0005432848922	31143	Economy	5900.00
0005432329895	31143	Economy	5400.00
0005432329662	31143	Economy	5400.00
0005432329709	31143	Economy	5400.00
0005432329831	31143	Economy	5400.00
0005432329836	31143	Economy	5400.00
0005432329833	31143	Economy	5400.00
0005432329768	31143	Economy	5400.00
0005432329920	31143	Economy	5400.00
0005432329830	31143	Economy	5400.00
0005433439041	31143	Economy	5400.00
0005432329880	31143	Economy	5400.00
0005432848924	31143	Economy	5400.00
0005432329850	31143	Economy	5400.00
0005433439082	31143	Economy	5400.00
0005433439093	31143	Economy	5400.00
0005432329708	31143	Economy	5400.00
0005433439094	31143	Economy	5400.00
0005432329721	31143	Economy	5400.00
0005433439065	31143	Economy	5400.00
0005432329790	31143	Economy	5400.00
0005432329953	31143	Economy	5400.00
0005433439043	31143	Economy	5400.00
0005432848921	31143	Economy	5400.00
0005432329921	31143	Economy	5400.00
0005432329767	31143	Economy	5400.00
0005432329796	31143	Economy	5400.00
0005433439032	31143	Economy	5400.00
0005432329832	31143	Economy	5400.00
0005432330022	31143	Economy	5400.00
0005432329834	31143	Economy	5400.00
0005432329814	31143	Economy	5400.00
0005432329801	31143	Economy	5400.00
0005432329960	31143	Economy	5400.00
0005432329695	31143	Economy	5400.00
0005433439096	31143	Economy	5400.00
0005435488396	6226	Business	124600.00
0005435488349	6226	Business	124600.00
0005435488404	6226	Business	124600.00
0005435488395	6226	Economy	41500.00
0005435488405	6226	Economy	41500.00
0005435999864	6226	Economy	45700.00
0005435297227	6226	Economy	41500.00
0005435488437	6226	Economy	41500.00
0005435488345	6226	Economy	41500.00
0005435488417	6226	Economy	41500.00
0005435488438	6226	Economy	41500.00
0005435488427	6226	Economy	41500.00
0005435488426	6226	Economy	41500.00
0005435297228	6226	Economy	41500.00
0005435488389	6226	Economy	41500.00
0005435297216	6226	Economy	41500.00
0005434310127	19577	Business	124600.00
0005434310126	19577	Economy	41500.00
0005435999733	19577	Economy	41500.00
0005435999786	19577	Economy	41500.00
0005435999758	19577	Economy	41500.00
0005435999725	19577	Economy	41500.00
0005435488478	19577	Economy	41500.00
0005435999792	19577	Economy	41500.00
0005435999665	19577	Economy	41500.00
0005435999657	19577	Economy	41500.00
0005434310093	19577	Economy	41500.00
0005435999642	19577	Economy	41500.00
0005435999653	19577	Economy	41500.00
0005435999666	19577	Economy	41500.00
0005435999785	19577	Economy	41500.00
0005434310083	19577	Economy	41500.00
0005435999660	19577	Economy	41500.00
0005435297267	19577	Economy	41500.00
0005435999641	19577	Economy	41500.00
0005435999766	19577	Economy	41500.00
0005435999739	19577	Economy	41500.00
0005435999736	19577	Economy	41500.00
0005435999658	19577	Economy	41500.00
0005434310103	19577	Economy	41500.00
0005435999716	19577	Economy	41500.00
0005435999715	19577	Economy	41500.00
0005435999780	19577	Economy	41500.00
0005435999678	19577	Economy	41500.00
0005435999704	19577	Economy	41500.00
0005435999677	19577	Economy	41500.00
0005435999603	19577	Economy	41500.00
0005434310115	19577	Economy	41500.00
0005434310128	19577	Economy	41500.00
0005435999737	19577	Economy	41500.00
0005435999735	19577	Economy	41500.00
0005434310076	19577	Economy	41500.00
0005435999649	19577	Economy	41500.00
0005434310135	19577	Economy	41500.00
0005435999759	19577	Economy	41500.00
0005434446568	17550	Economy	12300.00
0005434446573	17550	Economy	12300.00
0005433186372	1580	Business	86000.00
0005433186343	1580	Business	86000.00
0005433186331	1580	Economy	28700.00
0005433186324	1580	Economy	28700.00
0005433186369	1580	Economy	28700.00
0005433186371	1580	Economy	28700.00
0005433186338	1580	Economy	28700.00
0005433186330	1580	Economy	28700.00
0005433186327	1580	Economy	28700.00
0005433186334	1580	Economy	28700.00
0005433186318	1580	Economy	28700.00
0005435529759	20897	Business	86000.00
0005435545887	20897	Business	86000.00
0005435529706	20897	Business	86000.00
0005434566261	20897	Business	86000.00
0005434566260	20897	Economy	28700.00
0005434566309	20897	Economy	28700.00
0005435502882	20897	Economy	28700.00
0005435502861	20897	Economy	28700.00
0005435529871	20897	Economy	28700.00
0005435529780	20897	Economy	31500.00
0005435529774	20897	Economy	31500.00
0005435529797	20897	Economy	31500.00
0005435502825	20897	Economy	28700.00
0005435545890	20897	Economy	28700.00
0005434566275	20897	Economy	28700.00
0005435502919	20897	Economy	28700.00
0005435502826	20897	Economy	28700.00
0005435502810	20897	Economy	28700.00
0005435502860	20897	Economy	28700.00
0005434566251	20897	Economy	28700.00
0005434566252	20897	Economy	28700.00
0005435529719	20897	Economy	28700.00
0005435502808	20897	Economy	28700.00
0005435545891	20897	Economy	28700.00
0005434566231	20897	Economy	28700.00
0005435529795	20897	Economy	28700.00
0005435502749	20897	Economy	28700.00
0005434566250	20897	Economy	28700.00
0005435502936	20897	Economy	28700.00
0005435502881	20897	Economy	28700.00
0005435502908	20897	Economy	28700.00
0005435502898	20897	Economy	28700.00
0005435502845	20897	Economy	28700.00
0005435502901	20897	Economy	28700.00
0005434566288	20897	Economy	28700.00
0005434566287	20897	Economy	28700.00
0005435502798	20897	Economy	28700.00
0005435502897	20897	Economy	28700.00
0005435529776	20897	Economy	28700.00
0005435529777	20897	Economy	28700.00
0005435545928	20897	Economy	28700.00
0005435529843	20897	Economy	28700.00
0005435545898	20897	Economy	28700.00
0005435502809	20897	Economy	28700.00
0005435529828	20897	Economy	28700.00
0005435529810	20897	Economy	28700.00
0005435529781	20897	Economy	28700.00
0005435931701	3888	Economy	19700.00
0005435931697	3888	Economy	19700.00
0005435153906	21898	Economy	21600.00
0005435153928	21898	Economy	19700.00
0005435153884	21898	Economy	19700.00
0005435153926	21898	Economy	19700.00
0005435153927	21898	Economy	19700.00
0005435153907	21898	Economy	19700.00
0005435153908	21898	Economy	19700.00
0005435225795	7210	Economy	13000.00
0005435225785	7210	Economy	13000.00
0005435225792	7210	Economy	13000.00
0005435225791	7210	Economy	13000.00
0005435225763	7210	Economy	13000.00
0005435225790	7210	Economy	13000.00
0005435225793	7210	Economy	13000.00
0005432629295	7210	Economy	13000.00
0005432629221	28141	Economy	14300.00
0005432629247	28141	Economy	13000.00
0005432629212	28141	Economy	13000.00
0005432629220	28141	Economy	13000.00
0005432629246	28141	Economy	13000.00
0005432629207	28141	Economy	13000.00
0005432629243	28141	Economy	13000.00
0005432629259	28141	Economy	13000.00
0005432629211	28141	Economy	13000.00
0005432629208	28141	Economy	13000.00
0005435939979	8732	Economy	11500.00
0005434268037	8732	Economy	10500.00
0005434268038	8732	Economy	10500.00
0005434268039	8732	Economy	10500.00
0005434268040	8732	Economy	10500.00
0005435939980	8732	Economy	10500.00
0005435960148	15247	Economy	11500.00
0005435960164	15247	Economy	10500.00
0005435960163	15247	Economy	10500.00
0005435960149	15247	Economy	10500.00
0005435960152	15247	Economy	10500.00
0005435960155	15247	Economy	10500.00
0005432873484	1176	Business	115000.00
0005432693971	1176	Economy	38300.00
0005432693972	1176	Economy	42200.00
0005432693970	1176	Economy	38300.00
0005432677691	1176	Economy	38300.00
0005432693973	1176	Economy	38300.00
0005432873485	1176	Economy	38300.00
0005432873490	1176	Economy	38300.00
0005432677692	1176	Economy	38300.00
0005432873489	1176	Economy	38300.00
0005432675557	17511	Business	115000.00
0005432693843	17511	Business	115000.00
0005432693854	17511	Business	115000.00
0005432693806	17511	Business	115000.00
0005432693796	17511	Business	115000.00
0005432677679	17511	Business	115000.00
0005432693863	17511	Economy	38300.00
0005432693890	17511	Economy	38300.00
0005432693902	17511	Economy	38300.00
0005432677680	17511	Economy	38300.00
0005432693898	17511	Economy	38300.00
0005432693842	17511	Economy	38300.00
0005432693862	17511	Economy	42200.00
0005432677670	17511	Economy	38300.00
0005432675540	17511	Economy	38300.00
0005432693886	17511	Economy	38300.00
0005432693715	17511	Economy	38300.00
0005432693824	17511	Economy	38300.00
0005432693875	17511	Economy	38300.00
0005432693773	17511	Economy	38300.00
0005432693789	17511	Economy	38300.00
0005432693830	17511	Economy	38300.00
0005432693794	17511	Economy	38300.00
0005432693800	17511	Economy	38300.00
0005432677672	17511	Economy	38300.00
0005432693874	17511	Economy	38300.00
0005432693807	17511	Economy	38300.00
0005432675558	17511	Economy	38300.00
0005432693788	17511	Economy	38300.00
0005432693925	17511	Economy	38300.00
0005432693899	17511	Economy	38300.00
0005432677668	17511	Economy	38300.00
0005432693823	17511	Economy	38300.00
0005432693864	17511	Economy	38300.00
0005432693855	17511	Economy	38300.00
0005432693784	17511	Economy	38300.00
0005432677675	17511	Economy	38300.00
0005432677669	17511	Economy	38300.00
0005432677664	17511	Economy	38300.00
0005432693795	17511	Economy	38300.00
0005432693776	17511	Economy	38300.00
0005432677677	17511	Economy	38300.00
0005432693688	17511	Economy	38300.00
0005433156983	1115	Economy	15200.00
0005433156961	1115	Economy	15200.00
0005433156992	1115	Economy	15200.00
0005433156993	1115	Economy	13900.00
0005433156969	1115	Economy	13900.00
0005433156980	1115	Economy	13900.00
0005433156981	1115	Economy	13900.00
0005433156970	1115	Economy	13900.00
0005433156976	1115	Economy	13900.00
0005433156994	1115	Economy	13900.00
0005433156982	1115	Economy	13900.00
0005433156977	1115	Economy	13900.00
0005434435568	17327	Economy	15200.00
0005434435624	17327	Economy	15200.00
0005434435573	17327	Economy	13900.00
0005434435567	17327	Economy	13900.00
0005434435572	17327	Economy	13900.00
0005434435569	17327	Economy	13900.00
0005434435594	17327	Economy	13900.00
0005434435566	17327	Economy	13900.00
0005434435591	17327	Economy	13900.00
0005434435592	17327	Economy	13900.00
0005435928259	4090	Economy	7500.00
0005435087042	24423	Economy	7500.00
0005435087022	24423	Economy	7500.00
0005435087028	24423	Economy	7500.00
0005435087029	24423	Economy	7500.00
0005435087010	24423	Economy	7500.00
0005433373743	2457	Business	86800.00
0005433373762	2457	Economy	28900.00
0005433373769	2457	Economy	28900.00
0005433373721	2457	Economy	28900.00
0005433373724	2457	Economy	28900.00
0005433373763	2457	Economy	28900.00
0005433373725	2457	Economy	28900.00
0005433373757	2457	Economy	28900.00
0005433373713	2457	Economy	28900.00
0005433373756	2457	Economy	28900.00
0005433373796	2457	Economy	28900.00
0005433373780	2457	Economy	28900.00
0005433373777	2457	Economy	28900.00
0005433373781	2457	Economy	28900.00
0005435706830	27044	Business	86800.00
0005435706805	27044	Business	86800.00
0005435706831	27044	Business	86800.00
0005435706841	27044	Economy	28900.00
0005435706832	27044	Economy	28900.00
0005435706793	27044	Economy	31800.00
0005435706807	27044	Economy	28900.00
0005435706794	27044	Economy	28900.00
0005435706777	27044	Economy	28900.00
0005435706770	27044	Economy	28900.00
0005433373804	27044	Economy	28900.00
0005433373806	27044	Economy	28900.00
0005433373805	27044	Economy	28900.00
0005435706819	27044	Economy	28900.00
0005435706818	27044	Economy	28900.00
0005435706738	27044	Economy	28900.00
0005435706821	27044	Economy	28900.00
0005435706754	27044	Economy	28900.00
0005435706798	27044	Economy	28900.00
0005435706783	27044	Economy	28900.00
0005435706834	27044	Economy	28900.00
0005435706775	27044	Economy	28900.00
0005435706711	27044	Economy	28900.00
0005435706672	27044	Economy	28900.00
0005435706736	27044	Economy	28900.00
0005435706806	27044	Economy	28900.00
0005435706786	27044	Economy	28900.00
0005435706826	27044	Economy	28900.00
0005435706776	27044	Economy	28900.00
0005435706755	27044	Economy	28900.00
0005435706751	27044	Economy	28900.00
0005435706671	27044	Economy	28900.00
0005435706761	27044	Economy	28900.00
0005435706769	27044	Economy	28900.00
0005435907639	4835	Economy	14700.00
0005433194954	4835	Economy	14700.00
0005435907634	4835	Economy	14700.00
0005435907638	4835	Economy	14700.00
0005433194972	4835	Economy	14700.00
0005435907633	4835	Economy	14700.00
0005435907632	4835	Economy	14700.00
0005434626201	32897	Economy	14700.00
0005434626186	32897	Economy	14700.00
0005434626187	32897	Economy	14700.00
0005434626207	32897	Economy	14700.00
0005434626208	32897	Economy	14700.00
0005435786166	13754	Economy	3400.00
0005435786233	13754	Economy	3400.00
0005435786240	13754	Economy	3400.00
0005435786271	13754	Economy	3400.00
0005435786237	13754	Economy	3100.00
0005435786273	13754	Economy	3100.00
0005435786238	13754	Economy	3100.00
0005435787397	13754	Economy	3100.00
0005435786286	13754	Economy	3100.00
0005435786284	13754	Economy	3100.00
0005435787410	13754	Economy	3100.00
0005435786134	13754	Economy	3100.00
0005435786202	13754	Economy	3100.00
0005435786069	13754	Economy	3100.00
0005435786189	13754	Economy	3100.00
0005435786285	13754	Economy	3100.00
0005435786287	13754	Economy	3100.00
0005435786188	13754	Economy	3100.00
0005435786245	13754	Economy	3100.00
0005435786253	13754	Economy	3100.00
0005435786112	13754	Economy	3100.00
0005435786220	13754	Economy	3100.00
0005435786111	13754	Economy	3100.00
0005435786230	13754	Economy	3100.00
0005435786249	13754	Economy	3100.00
0005435786041	13754	Economy	3100.00
0005435786250	13754	Economy	3100.00
0005435786203	13754	Economy	3100.00
0005435786255	13754	Economy	3100.00
0005435786260	13754	Economy	3100.00
0005435786232	13754	Economy	3100.00
0005435787411	13754	Economy	3100.00
0005435786229	13754	Economy	3100.00
0005435786239	13754	Economy	3100.00
0005435786194	13754	Economy	3100.00
0005435786254	13754	Economy	3100.00
0005435937518	27422	Economy	3400.00
0005435937516	27422	Economy	3100.00
0005435786365	27422	Economy	3100.00
0005435937524	27422	Economy	3100.00
0005435937506	27422	Economy	3100.00
0005435786367	27422	Economy	3100.00
0005435937474	27422	Economy	3100.00
0005435937509	27422	Economy	3100.00
0005435937475	27422	Economy	3100.00
0005435786364	27422	Economy	3100.00
0005435786366	27422	Economy	3100.00
0005435937543	27422	Economy	3100.00
0005435937526	27422	Economy	3100.00
0005435937517	27422	Economy	3100.00
0005434409300	20304	Business	12000.00
0005434409451	20304	Business	12000.00
0005434409263	20304	Business	12000.00
0005434409533	20304	Business	12000.00
0005434409333	20304	Business	12000.00
0005434409226	20304	Business	12000.00
0005434409350	20304	Business	12000.00
0005434409487	20304	Business	12000.00
0005434409402	20304	Business	12000.00
0005434409314	20304	Economy	4000.00
0005434409407	20304	Economy	4000.00
0005434409386	20304	Economy	4000.00
0005434409512	20304	Economy	4400.00
0005434409326	20304	Economy	4400.00
0005434409375	20304	Economy	4400.00
0005434409436	20304	Economy	4000.00
0005434409352	20304	Economy	4000.00
0005434409445	20304	Economy	4000.00
0005434409469	20304	Economy	4000.00
0005434409299	20304	Economy	4000.00
0005434409334	20304	Economy	4000.00
0005434409126	20304	Economy	4000.00
0005434409419	20304	Economy	4000.00
0005434409444	20304	Economy	4000.00
0005434409418	20304	Economy	4000.00
0005434409472	20304	Economy	4000.00
0005434409530	20304	Economy	4000.00
0005434409397	20304	Economy	4000.00
0005434409228	20304	Economy	4000.00
0005434409473	20304	Economy	4000.00
0005434409335	20304	Economy	4000.00
0005434409276	20304	Economy	4000.00
0005434409321	20304	Economy	4000.00
0005434409217	20304	Economy	4000.00
0005434408953	20304	Economy	4000.00
0005434409437	20304	Economy	4000.00
0005434409525	20304	Economy	4000.00
0005434409332	20304	Economy	4000.00
0005434408952	20304	Economy	4000.00
0005434409476	20304	Economy	4000.00
0005434409396	20304	Economy	4000.00
0005434409410	20304	Economy	4000.00
0005434409322	20304	Economy	4000.00
0005434409449	20304	Economy	4000.00
0005434409442	20304	Economy	4000.00
0005435311451	26972	Economy	4000.00
0005435311435	26972	Economy	4000.00
0005435311411	26972	Economy	4000.00
0005435311373	26972	Economy	4000.00
0005435311524	26972	Economy	4000.00
0005435311444	26972	Economy	4000.00
0005435311497	26972	Economy	4000.00
0005435311450	26972	Economy	4000.00
0005435311297	26972	Economy	4000.00
0005435311429	26972	Economy	4000.00
0005435311372	26972	Economy	4000.00
0005435311459	26972	Economy	4000.00
0005435311475	26972	Economy	4000.00
0005435311458	26972	Economy	4000.00
0005433124445	5709	Business	43300.00
0005435297392	5709	Business	43300.00
0005435297366	5709	Business	43300.00
0005433124500	5709	Business	43300.00
0005433124447	5709	Economy	14400.00
0005433124332	5709	Economy	14400.00
0005433124380	5709	Economy	14400.00
0005433124441	5709	Economy	15900.00
0005433124501	5709	Economy	15900.00
0005433124506	5709	Economy	15900.00
0005435297377	5709	Economy	14400.00
0005433124448	5709	Economy	14400.00
0005435297378	5709	Economy	14400.00
0005433124452	5709	Economy	14400.00
0005433124440	5709	Economy	14400.00
0005433124391	5709	Economy	14400.00
0005433124392	5709	Economy	14400.00
0005435297385	5709	Economy	14400.00
0005433124446	5709	Economy	14400.00
0005433124444	5709	Economy	14400.00
0005433124461	5709	Economy	14400.00
0005433124354	5709	Economy	14400.00
0005435297364	5709	Economy	14400.00
0005433124507	5709	Economy	14400.00
0005433124435	5709	Economy	14400.00
0005433124460	5709	Economy	14400.00
0005435297386	5709	Economy	14400.00
0005433124353	5709	Economy	14400.00
0005433124468	5709	Economy	14400.00
0005434319822	15691	Business	43300.00
0005434319723	15691	Economy	15900.00
0005434319777	15691	Economy	14400.00
0005434312376	15691	Economy	14400.00
0005435297401	15691	Economy	14400.00
0005434319762	15691	Economy	14400.00
0005434312373	15691	Economy	14400.00
0005434319739	15691	Economy	14400.00
0005435297400	15691	Economy	14400.00
0005434319754	15691	Economy	14400.00
0005435297399	15691	Economy	14400.00
0005434319790	15691	Economy	14400.00
0005434319726	15691	Economy	14400.00
0005434189337	8999	Economy	24900.00
0005435903222	8999	Economy	24900.00
0005434189333	8999	Economy	24900.00
0005434189338	8999	Economy	24900.00
0005434189336	8999	Economy	24900.00
0005434189334	8999	Economy	24900.00
0005434484519	16626	Economy	27400.00
0005434484525	16626	Economy	24900.00
0005434484524	16626	Economy	24900.00
0005434484520	16626	Economy	24900.00
0005434484530	16626	Economy	24900.00
0005434484526	16626	Economy	24900.00
0005434484505	16626	Economy	24900.00
0005433722377	7678	Business	11100.00
0005435229657	7678	Business	11100.00
0005433722385	7678	Business	11100.00
0005433722383	7678	Business	11100.00
0005433722400	7678	Economy	3700.00
0005433722386	7678	Economy	3700.00
0005435229654	7678	Economy	3700.00
0005433722381	7678	Economy	3700.00
0005433722382	7678	Economy	3700.00
0005433722380	7678	Economy	3700.00
0005435229655	7678	Economy	3700.00
0005433722387	7678	Economy	3700.00
0005432721691	7682	Economy	3700.00
0005432693864	30293	Business	11100.00
0005432693784	30293	Business	11100.00
0005433450537	30293	Business	11100.00
0005432693890	30293	Business	11100.00
0005432693788	30293	Business	11100.00
0005433450453	30293	Economy	3700.00
0005433450529	30293	Economy	3700.00
0005432693806	30293	Economy	3700.00
0005432693925	30293	Economy	3700.00
0005433450555	30293	Economy	3700.00
0005432693898	30293	Economy	3700.00
0005433450462	30293	Economy	4100.00
0005433450554	30293	Economy	4100.00
0005432693875	30293	Economy	3700.00
0005432693874	30293	Economy	3700.00
0005432693823	30293	Economy	3700.00
0005433450512	30293	Economy	3700.00
0005432693824	30293	Economy	3700.00
0005432693843	30293	Economy	3700.00
0005432693902	30293	Economy	3700.00
0005432693807	30293	Economy	3700.00
0005432693830	30293	Economy	3700.00
0005432693789	30293	Economy	3700.00
0005432693862	30293	Economy	3700.00
0005432693688	30293	Economy	3700.00
0005433450530	30293	Economy	3700.00
0005433450594	30293	Economy	3700.00
0005433450513	30293	Economy	3700.00
0005432693795	30293	Economy	3700.00
0005432693854	30293	Economy	3700.00
0005432693794	30293	Economy	3700.00
0005433450540	30293	Economy	3700.00
0005432693855	30293	Economy	3700.00
0005432693796	30293	Economy	3700.00
0005432693842	30293	Economy	3700.00
0005432693800	30293	Economy	3700.00
0005432693715	30293	Economy	3700.00
0005432693863	30293	Economy	3700.00
0005433450427	30293	Economy	3700.00
0005433450556	30293	Economy	3700.00
0005433450524	30293	Economy	3700.00
0005433450586	30293	Economy	3700.00
0005432693776	30293	Economy	3700.00
0005432693886	30293	Economy	3700.00
0005432693899	30293	Economy	3700.00
0005432693773	30293	Economy	3700.00
0005433450509	30293	Economy	3700.00
0005433124461	30294	Business	11100.00
0005433124354	30294	Business	11100.00
0005433124506	30294	Business	11100.00
0005433124501	30294	Business	11100.00
0005433124435	30294	Business	11100.00
0005432721613	30294	Economy	3700.00
0005433124441	30294	Economy	3700.00
0005432721615	30294	Economy	3700.00
0005433124507	30294	Economy	3700.00
0005432721592	30294	Economy	3700.00
0005432721513	30294	Economy	3700.00
0005433124446	30294	Economy	3700.00
0005433124353	30294	Economy	3700.00
0005433722513	30294	Economy	4100.00
0005432721474	30294	Economy	4100.00
0005433124500	30294	Economy	3700.00
0005432721565	30294	Economy	3700.00
0005433124460	30294	Economy	3700.00
0005433124448	30294	Economy	3700.00
0005433124468	30294	Economy	3700.00
0005432721596	30294	Economy	3700.00
0005432721649	30294	Economy	3700.00
0005432721627	30294	Economy	3700.00
0005433124380	30294	Economy	3700.00
0005433124391	30294	Economy	3700.00
0005432721557	30294	Economy	3700.00
0005433124445	30294	Economy	3700.00
0005432721514	30294	Economy	3700.00
0005432721593	30294	Economy	3700.00
0005433124452	30294	Economy	3700.00
0005432721656	30294	Economy	3700.00
0005433124440	30294	Economy	3700.00
0005432721614	30294	Economy	3700.00
0005433124392	30294	Economy	3700.00
0005432721619	30294	Economy	3700.00
0005433124447	30294	Economy	3700.00
0005433722514	30294	Economy	3700.00
0005433124332	30294	Economy	3700.00
0005432721558	30294	Economy	3700.00
0005433124444	30294	Economy	3700.00
0005432721630	30294	Economy	3700.00
0005432721633	30294	Economy	3700.00
0005432721629	30294	Economy	3700.00
0005434587362	1392	Business	70400.00
0005432928136	1392	Business	70400.00
0005432928119	1392	Business	70400.00
0005433193410	1392	Economy	23500.00
0005433193382	1392	Economy	23500.00
0005434587363	1392	Economy	23500.00
0005433193394	1392	Economy	23500.00
0005433193395	1392	Economy	23500.00
0005432928141	1392	Economy	23500.00
0005432968902	1392	Economy	23500.00
0005433193432	1392	Economy	23500.00
0005432968903	1392	Economy	23500.00
0005433193433	1392	Economy	23500.00
0005433525317	18539	Business	70400.00
0005433525271	18539	Business	70400.00
0005434515039	18539	Business	70400.00
0005433525294	18539	Economy	23500.00
0005433525306	18539	Economy	23500.00
0005434587252	18539	Economy	23500.00
0005434515033	18539	Economy	23500.00
0005434587272	18539	Economy	23500.00
0005434587226	18539	Economy	23500.00
0005433724923	18539	Economy	23500.00
0005434587289	18539	Economy	23500.00
0005434515040	18539	Economy	23500.00
0005433525270	18539	Economy	23500.00
0005434587253	18539	Economy	23500.00
0005433724919	18539	Economy	23500.00
0005434515034	18539	Economy	23500.00
0005433193446	18539	Economy	23500.00
0005433525307	18539	Economy	23500.00
0005433525295	18539	Economy	23500.00
0005434587187	18539	Economy	23500.00
0005434587251	18539	Economy	23500.00
0005434587307	18539	Economy	23500.00
0005434587280	18539	Economy	23500.00
0005433525308	18539	Economy	23500.00
0005433724918	18539	Economy	23500.00
0005434515035	18539	Economy	23500.00
0005434587188	18539	Economy	23500.00
0005433525342	18539	Economy	23500.00
0005435302320	11459	Economy	4300.00
0005434345295	11459	Economy	4000.00
0005434345289	11459	Economy	4000.00
0005435302305	11459	Economy	4000.00
0005434345291	11459	Economy	4000.00
0005435302319	11459	Economy	4000.00
0005434345292	11459	Economy	4000.00
0005434345293	11459	Economy	4000.00
0005435302311	11459	Economy	4000.00
0005434345296	11459	Economy	4000.00
0005434345290	11459	Economy	4000.00
0005434345294	11459	Economy	4000.00
0005434345297	11459	Economy	4000.00
0005435305073	11459	Economy	4000.00
0005434345159	29749	Economy	4300.00
0005434344975	29749	Economy	4300.00
0005434345144	29749	Economy	4300.00
0005434345110	29749	Economy	4300.00
0005434344990	29749	Economy	4000.00
0005434345185	29749	Economy	4000.00
0005434345029	29749	Economy	4000.00
0005434345024	29749	Economy	4000.00
0005434345210	29749	Economy	4000.00
0005434344976	29749	Economy	4000.00
0005434345109	29749	Economy	4000.00
0005434345137	29749	Economy	4000.00
0005434345147	29749	Economy	4000.00
0005434345149	29749	Economy	4000.00
0005434345028	29749	Economy	4000.00
0005434345225	29749	Economy	4000.00
0005434345186	29749	Economy	4000.00
0005434142688	29749	Economy	4000.00
0005434345143	29749	Economy	4000.00
0005434142687	29749	Economy	4000.00
0005434345014	29749	Economy	4000.00
0005434345060	29749	Economy	4000.00
0005434345103	29749	Economy	4000.00
0005434345066	29749	Economy	4000.00
0005434345053	29749	Economy	4000.00
0005434345205	29749	Economy	4000.00
0005434344989	29749	Economy	4000.00
0005434345226	29749	Economy	4000.00
0005434345104	29749	Economy	4000.00
0005434345206	29749	Economy	4000.00
0005434345033	29749	Economy	4000.00
0005434345027	29749	Economy	4000.00
0005434344991	29749	Economy	4000.00
0005434345194	29749	Economy	4000.00
0005434345065	29749	Economy	4000.00
0005434345025	29749	Economy	4000.00
0005434345059	29749	Economy	4000.00
0005434345150	29749	Economy	4000.00
0005433416108	1307	Business	199800.00
0005435825427	1307	Business	199800.00
0005433416097	1307	Economy	66600.00
0005435825426	1307	Economy	66600.00
0005433416096	1307	Economy	66600.00
0005433416094	1307	Economy	66600.00
0005435825425	1307	Economy	66600.00
0005433416112	1307	Economy	66600.00
0005433416103	1307	Economy	66600.00
0005433416098	1307	Economy	66600.00
0005433416095	1307	Economy	66600.00
0005433416080	1307	Economy	66600.00
0005435825341	17992	Business	199800.00
0005435825357	17992	Business	199800.00
0005435825265	17992	Business	199800.00
0005435825343	17992	Business	199800.00
0005435825232	17992	Economy	66600.00
0005435825347	17992	Economy	66600.00
0005435825329	17992	Economy	66600.00
0005435825316	17992	Economy	73200.00
0005435825266	17992	Economy	73200.00
0005435825330	17992	Economy	66600.00
0005435825300	17992	Economy	66600.00
0005435825253	17992	Economy	66600.00
0005435825306	17992	Economy	66600.00
0005435825348	17992	Economy	66600.00
0005435825296	17992	Economy	66600.00
0005435825317	17992	Economy	66600.00
0005435825315	17992	Economy	66600.00
0005435825233	17992	Economy	66600.00
0005435825356	17992	Economy	66600.00
0005435825342	17992	Economy	66600.00
0005435825331	17992	Economy	66600.00
0005435825301	17992	Economy	66600.00
0005435476954	5645	Business	27800.00
0005435476995	5645	Business	27800.00
0005435243553	5645	Business	27800.00
0005435243402	5645	Business	27800.00
0005435476967	5645	Business	27800.00
0005435243393	5645	Business	27800.00
0005435243600	5645	Business	27800.00
0005435476962	5645	Business	27800.00
0005435476950	5645	Business	27800.00
0005435476989	5645	Economy	9300.00
0005435476987	5645	Economy	9300.00
0005435243506	5645	Economy	9300.00
0005435950048	5645	Economy	9300.00
0005435476949	5645	Economy	10200.00
0005435476968	5645	Economy	10200.00
0005435476966	5645	Economy	9300.00
0005435243401	5645	Economy	9300.00
0005435476946	5645	Economy	9300.00
0005435243382	5645	Economy	9300.00
0005435243488	5645	Economy	9300.00
0005435243545	5645	Economy	9300.00
0005435243507	5645	Economy	9300.00
0005435476953	5645	Economy	9300.00
0005435243550	5645	Economy	9300.00
0005435476955	5645	Economy	9300.00
0005435243489	5645	Economy	9300.00
0005432785367	5645	Economy	9300.00
0005435243604	5645	Economy	9300.00
0005432785368	5645	Economy	9300.00
0005435243551	5645	Economy	9300.00
0005435243392	5645	Economy	9300.00
0005435243490	5645	Economy	9300.00
0005435243560	5645	Economy	9300.00
0005435243605	5645	Economy	9300.00
0005435243542	5645	Economy	9300.00
0005435243503	5645	Economy	9300.00
0005435243505	5645	Economy	9300.00
0005435243543	5645	Economy	9300.00
0005435243552	5645	Economy	9300.00
0005435950047	5645	Economy	9300.00
0005435950046	5645	Economy	9300.00
0005432785268	15359	Business	27800.00
0005432785280	15359	Business	27800.00
0005432785270	15359	Business	27800.00
0005435243665	15359	Business	27800.00
0005435477008	15359	Business	27800.00
0005432785037	15359	Business	27800.00
0005432785172	15359	Business	27800.00
0005432785299	15359	Business	27800.00
0005435243666	15359	Economy	9300.00
0005432784827	15359	Economy	9300.00
0005432785106	15359	Economy	9300.00
0005432784826	15359	Economy	9300.00
0005432785198	15359	Economy	9300.00
0005432785289	15359	Economy	9300.00
0005432785171	15359	Economy	10200.00
0005432785064	15359	Economy	10200.00
0005432785201	15359	Economy	10200.00
0005435477007	15359	Economy	10200.00
0005432785143	15359	Economy	9300.00
0005432785163	15359	Economy	9300.00
0005432785142	15359	Economy	9300.00
0005435950045	15359	Economy	9300.00
0005432785239	15359	Economy	9300.00
0005432785026	15359	Economy	9300.00
0005432785050	15359	Economy	9300.00
0005432785236	15359	Economy	9300.00
0005432785110	15359	Economy	9300.00
0005432785298	15359	Economy	9300.00
0005432785256	15359	Economy	9300.00
0005432785225	15359	Economy	9300.00
0005432785054	15359	Economy	9300.00
0005432785216	15359	Economy	9300.00
0005432785247	15359	Economy	9300.00
0005432784919	15359	Economy	9300.00
0005432785093	15359	Economy	9300.00
0005432785200	15359	Economy	9300.00
0005432785038	15359	Economy	9300.00
0005432785255	15359	Economy	9300.00
0005432785159	15359	Economy	9300.00
0005432785238	15359	Economy	9300.00
0005432785186	15359	Economy	9300.00
0005432785154	15359	Economy	9300.00
0005432785269	15359	Economy	9300.00
0005432785125	15359	Economy	9300.00
0005432785105	15359	Economy	9300.00
0005432785209	15359	Economy	9300.00
0005432785197	15359	Economy	9300.00
0005435950026	15359	Economy	9300.00
0005432785092	15359	Economy	9300.00
0005432785162	15359	Economy	9300.00
0005435851143	4347	Economy	7000.00
0005435851161	4347	Economy	6300.00
0005435851158	4347	Economy	6300.00
0005435851133	4347	Economy	6300.00
0005435851178	4347	Economy	6300.00
0005435851159	4347	Economy	6300.00
0005435851144	4347	Economy	6300.00
0005435851147	4347	Economy	6300.00
0005435851149	4347	Economy	6300.00
0005435851162	4347	Economy	6300.00
0005435851180	4347	Economy	6300.00
0005435851179	4347	Economy	6300.00
0005435851122	4347	Economy	6300.00
0005432848671	28838	Economy	7000.00
0005434461703	28838	Economy	6300.00
0005432848690	28838	Economy	6300.00
0005432848683	28838	Economy	6300.00
0005432848685	28838	Economy	6300.00
0005432848672	28838	Economy	6300.00
0005432848677	28838	Economy	6300.00
0005432848719	28838	Economy	6300.00
0005432848673	28838	Economy	6300.00
0005432848682	28838	Economy	6300.00
0005432848678	28838	Economy	6300.00
0005434461702	28838	Economy	6300.00
0005432848720	28838	Economy	6300.00
0005432848691	28838	Economy	6300.00
0005435257505	6337	Economy	4000.00
0005435257520	6337	Economy	4000.00
0005435257517	6337	Economy	4000.00
0005435257533	6337	Economy	4000.00
0005435257516	6337	Economy	4000.00
0005434926864	6337	Economy	4000.00
0005435257506	6337	Economy	4000.00
0005435257544	6337	Economy	4000.00
0005435257485	6337	Economy	4000.00
0005435257447	6337	Economy	4000.00
0005434926866	6337	Economy	4000.00
0005434926865	6337	Economy	4000.00
0005435257484	6337	Economy	4000.00
0005433497817	20358	Business	11900.00
0005433497604	20358	Business	11900.00
0005434444120	20358	Business	11900.00
0005434926650	20358	Business	11900.00
0005433497847	20358	Business	11900.00
0005433497793	20358	Business	11900.00
0005434926601	20358	Business	11900.00
0005434926521	20358	Business	11900.00
0005434926633	20358	Business	11900.00
0005434926789	20358	Economy	4000.00
0005434444099	20358	Economy	4000.00
0005433497773	20358	Economy	4000.00
0005433497849	20358	Economy	4000.00
0005434926716	20358	Economy	4000.00
0005433497718	20358	Economy	4000.00
0005434926717	20358	Economy	4000.00
0005433497854	20358	Economy	4400.00
0005434926793	20358	Economy	4400.00
0005433497719	20358	Economy	4400.00
0005433497837	20358	Economy	4400.00
0005433497792	20358	Economy	4400.00
0005434926535	20358	Economy	4000.00
0005434926648	20358	Economy	4000.00
0005434926581	20358	Economy	4000.00
0005433497714	20358	Economy	4000.00
0005434926651	20358	Economy	4000.00
0005434444079	20358	Economy	4000.00
0005433497811	20358	Economy	4000.00
0005434926676	20358	Economy	4000.00
0005433497876	20358	Economy	4000.00
0005434926610	20358	Economy	4000.00
0005433497815	20358	Economy	4000.00
0005434926663	20358	Economy	4000.00
0005433497848	20358	Economy	4000.00
0005434926504	20358	Economy	4000.00
0005434926665	20358	Economy	4000.00
0005434444127	20358	Economy	4000.00
0005434926501	20358	Economy	4000.00
0005433497799	20358	Economy	4000.00
0005434444151	20358	Economy	4000.00
0005433497838	20358	Economy	4000.00
0005433497702	20358	Economy	4000.00
0005434444133	20358	Economy	4000.00
0005434926770	20358	Economy	4000.00
0005434926544	20358	Economy	4000.00
0005433497798	20358	Economy	4000.00
0005434926664	20358	Economy	4000.00
0005434926675	20358	Economy	4000.00
0005434926695	20358	Economy	4000.00
0005434926696	20358	Economy	4000.00
0005434926691	20358	Economy	4000.00
0005434926649	20358	Economy	4000.00
0005434926578	20358	Economy	4000.00
0005433497778	20358	Economy	4000.00
0005433497715	20358	Economy	4000.00
0005434926609	20358	Economy	4000.00
0005434926580	20358	Economy	4000.00
0005434926577	20358	Economy	4000.00
0005434926708	20358	Economy	4000.00
0005434926694	20358	Economy	4000.00
0005433497819	20358	Economy	4000.00
0005433497875	20358	Economy	4000.00
0005433497871	20358	Economy	4000.00
0005434926723	20358	Economy	4000.00
0005434926661	20358	Economy	4000.00
0005434444135	20358	Economy	4000.00
0005434444077	20358	Economy	4000.00
0005434926718	20358	Economy	4000.00
0005434444147	20358	Economy	4000.00
0005434444148	20358	Economy	4000.00
0005434926790	20358	Economy	4000.00
0005434926707	20358	Economy	4000.00
0005433497774	20358	Economy	4000.00
0005433497790	20358	Economy	4000.00
0005433497818	20358	Economy	4000.00
0005434926666	20358	Economy	4000.00
0005434444146	20358	Economy	4000.00
0005434926715	20358	Economy	4000.00
0005433497775	20358	Economy	4000.00
0005432785129	12195	Business	41200.00
0005432785021	12195	Business	41200.00
0005432785222	12195	Business	41200.00
0005432785006	12195	Business	41200.00
0005432785057	12195	Business	41200.00
0005432785305	12195	Business	41200.00
0005432785020	12195	Business	41200.00
0005432785133	12195	Business	41200.00
0005432785264	12195	Economy	13700.00
0005432785306	12195	Economy	13700.00
0005432785149	12195	Economy	13700.00
0005432785139	12195	Economy	13700.00
0005432785008	12195	Economy	13700.00
0005432785107	12195	Economy	13700.00
0005432785145	12195	Economy	15100.00
0005432785334	12195	Economy	15100.00
0005432785208	12195	Economy	15100.00
0005432785166	12195	Economy	15100.00
0005432785128	12195	Economy	13700.00
0005432785146	12195	Economy	13700.00
0005432785189	12195	Economy	13700.00
0005432785089	12195	Economy	13700.00
0005432785194	12195	Economy	13700.00
0005432785253	12195	Economy	13700.00
0005432785126	12195	Economy	13700.00
0005432785112	12195	Economy	13700.00
0005432785191	12195	Economy	13700.00
0005432785147	12195	Economy	13700.00
0005432785127	12195	Economy	13700.00
0005432785234	12195	Economy	13700.00
0005432785022	12195	Economy	13700.00
0005432785217	12195	Economy	13700.00
0005432785004	12195	Economy	13700.00
0005432784948	12195	Economy	13700.00
0005432785007	12195	Economy	13700.00
0005432784940	12195	Economy	13700.00
0005432784981	12195	Economy	13700.00
0005432785025	12195	Economy	13700.00
0005432785258	12195	Economy	13700.00
0005432785279	12195	Economy	13700.00
0005432785262	12195	Economy	13700.00
0005432785263	12195	Economy	13700.00
0005432785252	12195	Economy	13700.00
0005432785113	12195	Economy	13700.00
0005432785005	12195	Economy	13700.00
0005432785328	12195	Economy	13700.00
0005432785115	12195	Economy	13700.00
0005432785017	12195	Economy	13700.00
0005432784949	12195	Economy	13700.00
0005432785229	12195	Economy	13700.00
0005432785221	12195	Economy	13700.00
0005432785023	12195	Economy	13700.00
0005432785287	12195	Economy	13700.00
0005432785116	12195	Economy	13700.00
0005432785090	12195	Economy	13700.00
0005432785101	12195	Economy	13700.00
0005432785102	12195	Economy	13700.00
0005432784982	12195	Economy	13700.00
0005432785288	12195	Economy	13700.00
0005432785087	12195	Economy	13700.00
0005432785204	12195	Economy	13700.00
0005432785148	12195	Economy	13700.00
0005432785205	12195	Economy	13700.00
0005432785265	12195	Economy	13700.00
0005435243462	15425	Business	41200.00
0005435243459	15425	Business	41200.00
0005435243555	15425	Business	41200.00
0005435243570	15425	Business	41200.00
0005435243568	15425	Economy	13700.00
0005435243482	15425	Economy	15100.00
0005435243511	15425	Economy	15100.00
0005435243574	15425	Economy	13700.00
0005435243461	15425	Economy	13700.00
0005435243515	15425	Economy	13700.00
0005435243512	15425	Economy	13700.00
0005435243481	15425	Economy	13700.00
0005435243483	15425	Economy	13700.00
0005435243449	15425	Economy	13700.00
0005435243578	15425	Economy	13700.00
0005435243442	15425	Economy	13700.00
0005435243484	15425	Economy	13700.00
0005435243573	15425	Economy	13700.00
0005435243531	15425	Economy	13700.00
0005435243448	15425	Economy	13700.00
0005435243571	15425	Economy	13700.00
0005435243524	15425	Economy	13700.00
0005435243516	15425	Economy	13700.00
0005435243431	15425	Economy	13700.00
0005435243444	15425	Economy	13700.00
0005435243460	15425	Economy	13700.00
0005435243535	15425	Economy	13700.00
0005435243523	15425	Economy	13700.00
0005434880916	10107	Business	49700.00
0005434880467	10107	Business	49700.00
0005434880858	10107	Business	49700.00
0005434880735	10107	Business	49700.00
0005434880713	10107	Business	49700.00
0005434880859	10107	Business	49700.00
0005434758954	10107	Business	49700.00
0005434880539	10107	Business	49700.00
0005434880648	10107	Business	49700.00
0005434880637	10107	Business	49700.00
0005434880574	10107	Business	49700.00
0005434880721	10107	Business	49700.00
0005434880446	10107	Business	49700.00
0005434880820	10107	Business	49700.00
0005434880522	10107	Business	49700.00
0005434880903	10107	Business	49700.00
0005434880564	10107	Business	49700.00
0005434880662	10107	Economy	16600.00
0005434880741	10107	Economy	16600.00
0005434880810	10107	Economy	16600.00
0005434880830	10107	Economy	16600.00
0005434880798	10107	Economy	16600.00
0005434880444	10107	Economy	16600.00
0005434880794	10107	Economy	16600.00
0005434758955	10107	Economy	16600.00
0005434880673	10107	Economy	16600.00
0005434880636	10107	Economy	16600.00
0005434880559	10107	Economy	18200.00
0005434880915	10107	Economy	18200.00
0005434880956	10107	Economy	16600.00
0005434758958	10107	Economy	16600.00
0005434880758	10107	Economy	16600.00
0005434880233	10107	Economy	16600.00
0005434880647	10107	Economy	16600.00
0005434880767	10107	Economy	16600.00
0005434880510	10107	Economy	16600.00
0005434880661	10107	Economy	16600.00
0005434758953	10107	Economy	16600.00
0005434880870	10107	Economy	16600.00
0005434880787	10107	Economy	16600.00
0005434880468	10107	Economy	16600.00
0005434880811	10107	Economy	16600.00
0005434880392	10107	Economy	16600.00
0005434880573	10107	Economy	16600.00
0005434880763	10107	Economy	16600.00
0005434880727	10107	Economy	16600.00
0005434880445	10107	Economy	16600.00
0005434880887	10107	Economy	16600.00
0005434880638	10107	Economy	16600.00
0005434880957	10107	Economy	16600.00
0005434880232	10107	Economy	16600.00
0005434880459	10107	Economy	16600.00
0005434880527	10107	Economy	16600.00
0005434880795	10107	Economy	16600.00
0005434880558	10107	Economy	16600.00
0005434880639	10107	Economy	16600.00
0005434880491	10107	Economy	16600.00
0005434880541	10107	Economy	16600.00
0005434880698	10107	Economy	16600.00
0005434880857	10107	Economy	16600.00
0005434880778	10107	Economy	16600.00
0005434880504	10107	Economy	16600.00
0005434880438	10107	Economy	16600.00
0005434880821	10107	Economy	16600.00
0005434880546	10107	Economy	16600.00
0005434880703	10107	Economy	16600.00
0005434880796	10107	Economy	16600.00
0005434880509	10107	Economy	16600.00
0005434880492	10107	Economy	16600.00
0005434880700	10107	Economy	16600.00
0005434880542	10107	Economy	16600.00
0005434880694	10107	Economy	16600.00
0005434880706	10107	Economy	16600.00
0005434880940	10107	Economy	16600.00
0005434880545	10107	Economy	16600.00
0005434880460	10107	Economy	16600.00
0005434880705	10107	Economy	16600.00
0005434880756	10107	Economy	16600.00
0005434880234	10107	Economy	16600.00
0005434880882	10107	Economy	16600.00
0005434880809	10107	Economy	16600.00
0005434880605	10107	Economy	16600.00
0005434880451	10107	Economy	16600.00
0005434880410	10107	Economy	16600.00
0005434880829	10107	Economy	16600.00
0005434880837	10107	Economy	16600.00
0005434880838	10107	Economy	16600.00
0005434880595	10107	Economy	16600.00
0005434880699	10107	Economy	16600.00
0005435914068	14637	Business	49700.00
0005435914028	14637	Business	49700.00
0005434880991	14637	Business	49700.00
0005435914124	14637	Business	49700.00
0005435914115	14637	Economy	16600.00
0005434910178	14637	Economy	16600.00
0005435914091	14637	Economy	16600.00
0005435914078	14637	Economy	16600.00
0005435914134	14637	Economy	16600.00
0005435914133	14637	Economy	16600.00
0005435914132	14637	Economy	16600.00
0005435914074	14637	Economy	16600.00
0005435914027	14637	Economy	16600.00
0005435914114	14637	Economy	16600.00
0005435914075	14637	Economy	16600.00
0005434880989	14637	Economy	16600.00
0005435914069	14637	Economy	16600.00
0005434880990	14637	Economy	16600.00
0005434252210	9259	Economy	20300.00
0005435933578	9259	Economy	20300.00
0005434252209	9259	Economy	20300.00
0005434252165	9259	Economy	20300.00
0005434252127	9259	Economy	20300.00
0005435933568	9259	Economy	20300.00
0005435933569	9259	Economy	20300.00
0005434252206	9259	Economy	20300.00
0005434252168	9259	Economy	20300.00
0005435933579	9259	Economy	20300.00
0005434252170	9259	Economy	20300.00
0005435660413	24644	Economy	22400.00
0005435660437	24644	Economy	22400.00
0005435660417	24644	Economy	22400.00
0005435660418	24644	Economy	20300.00
0005435660433	24644	Economy	20300.00
0005435933560	24644	Economy	20300.00
0005435660360	24644	Economy	20300.00
0005435660419	24644	Economy	20300.00
0005435660436	24644	Economy	20300.00
0005435660408	24644	Economy	20300.00
0005435660402	24644	Economy	20300.00
0005435660416	24644	Economy	20300.00
0005435660452	24644	Economy	20300.00
0005435660438	24644	Economy	20300.00
0005432967601	2764	Business	33000.00
0005432967638	2764	Business	33000.00
0005432967600	2764	Business	33000.00
0005432967663	2764	Economy	11000.00
0005432967637	2764	Economy	11000.00
0005432967639	2764	Economy	11000.00
0005432967472	2764	Economy	11000.00
0005432967544	2764	Economy	11000.00
0005432967501	2764	Economy	11000.00
0005432967605	2764	Economy	11000.00
0005432967556	2764	Economy	11000.00
0005432967585	2764	Economy	11000.00
0005432967598	2764	Economy	11000.00
0005432967581	2764	Economy	11000.00
0005432967629	2764	Economy	11000.00
0005432967602	2764	Economy	11000.00
0005432967558	2764	Economy	11000.00
0005432967626	2764	Economy	11000.00
0005432967603	2764	Economy	11000.00
0005432967553	2764	Economy	11000.00
0005432967604	2764	Economy	11000.00
0005432967649	2764	Economy	11000.00
0005432967627	2764	Economy	11000.00
0005433681844	29168	Business	33000.00
0005433681770	29168	Business	33000.00
0005433684477	29168	Business	33000.00
0005433681760	29168	Business	33000.00
0005433681807	29168	Economy	11000.00
0005433681826	29168	Economy	11000.00
0005433681852	29168	Economy	11000.00
0005433681764	29168	Economy	11000.00
0005433681887	29168	Economy	12100.00
0005433681846	29168	Economy	12100.00
0005433681795	29168	Economy	11000.00
0005433681631	29168	Economy	11000.00
0005433681804	29168	Economy	11000.00
0005433681821	29168	Economy	11000.00
0005433681630	29168	Economy	11000.00
0005433681900	29168	Economy	11000.00
0005433690974	29168	Economy	11000.00
0005433681531	29168	Economy	11000.00
0005433681739	29168	Economy	11000.00
0005433690984	29168	Economy	11000.00
0005433681880	29168	Economy	11000.00
0005433681719	29168	Economy	11000.00
0005433684470	29168	Economy	11000.00
0005433681845	29168	Economy	11000.00
0005433681545	29168	Economy	11000.00
0005433681781	29168	Economy	11000.00
0005433681863	29168	Economy	11000.00
0005433681898	29168	Economy	11000.00
0005433681862	29168	Economy	11000.00
0005433681711	29168	Economy	11000.00
0005433687751	29168	Economy	11000.00
0005433681899	29168	Economy	11000.00
0005433681765	29168	Economy	11000.00
0005433681769	29168	Economy	11000.00
0005433681816	29168	Economy	11000.00
0005433684469	29168	Economy	11000.00
0005433681761	29168	Economy	11000.00
0005435856338	9293	Business	132900.00
0005435856335	9293	Business	132900.00
0005435856340	9293	Business	132900.00
0005434163822	9293	Business	132900.00
0005434272230	9293	Business	132900.00
0005434163824	9293	Economy	44300.00
0005434153579	9293	Economy	44300.00
0005434153583	9293	Economy	44300.00
0005435856350	9293	Economy	44300.00
0005434163855	9293	Economy	44300.00
0005434153560	9293	Economy	44300.00
0005434152847	9293	Economy	44300.00
0005433616830	9293	Economy	44300.00
0005434152848	9293	Economy	44300.00
0005435856348	9293	Economy	44300.00
0005435856339	9293	Economy	48700.00
0005433578206	9293	Economy	44300.00
0005435856341	9293	Economy	44300.00
0005435983722	9293	Economy	44300.00
0005434163823	9293	Economy	44300.00
0005434163857	9293	Economy	44300.00
0005435856337	9293	Economy	44300.00
0005433616828	9293	Economy	44300.00
0005433616829	9293	Economy	44300.00
0005434163856	9293	Economy	44300.00
0005433616485	25252	Business	132900.00
0005433634603	25252	Business	132900.00
0005433634734	25252	Business	132900.00
0005433634668	25252	Business	132900.00
0005433578149	25252	Business	132900.00
0005433616560	25252	Business	132900.00
0005433634715	25252	Business	132900.00
0005433616351	25252	Business	132900.00
0005433634651	25252	Business	132900.00
0005433634716	25252	Business	132900.00
0005433616631	25252	Business	132900.00
0005433634565	25252	Business	132900.00
0005433634563	25252	Business	132900.00
0005433578174	25252	Business	132900.00
0005433616082	25252	Business	132900.00
0005433616618	25252	Economy	48700.00
0005433634681	25252	Economy	48700.00
0005433616619	25252	Economy	48700.00
0005433616603	25252	Economy	48700.00
0005433616521	25252	Economy	44300.00
0005433616465	25252	Economy	44300.00
0005433616466	25252	Economy	44300.00
0005433616727	25252	Economy	44300.00
0005433634754	25252	Economy	44300.00
0005433616596	25252	Economy	44300.00
0005433616388	25252	Economy	44300.00
0005433634741	25252	Economy	44300.00
0005433616387	25252	Economy	44300.00
0005433634740	25252	Economy	44300.00
0005433634733	25252	Economy	44300.00
0005433634804	25252	Economy	44300.00
0005433634742	25252	Economy	44300.00
0005433616026	25252	Economy	44300.00
0005433634678	25252	Economy	44300.00
0005433616486	25252	Economy	44300.00
0005433634718	25252	Economy	44300.00
0005433616081	25252	Economy	44300.00
0005433634709	25252	Economy	44300.00
0005433634667	25252	Economy	44300.00
0005433634566	25252	Economy	44300.00
0005433616453	25252	Economy	44300.00
0005433616328	25252	Economy	44300.00
0005433616544	25252	Economy	44300.00
0005433578162	25252	Economy	44300.00
0005433578135	25252	Economy	44300.00
0005433616234	25252	Economy	44300.00
0005433578161	25252	Economy	44300.00
0005433616463	25252	Economy	44300.00
0005433616531	25252	Economy	44300.00
0005433616308	25252	Economy	44300.00
0005433616522	25252	Economy	44300.00
0005433578134	25252	Economy	44300.00
0005433634753	25252	Economy	44300.00
0005433616455	25252	Economy	44300.00
0005433634649	25252	Economy	44300.00
0005433634610	25252	Economy	48700.00
0005433616515	25252	Economy	48700.00
0005433616514	25252	Economy	44300.00
0005433634549	25252	Economy	44300.00
0005433616525	25252	Economy	44300.00
0005433616462	25252	Economy	48700.00
0005433634562	25252	Economy	44300.00
0005433634717	25252	Economy	44300.00
0005433634625	25252	Economy	44300.00
0005433616606	25252	Economy	44300.00
0005433616532	25252	Economy	44300.00
0005433616429	25252	Economy	44300.00
0005433616718	25252	Economy	44300.00
0005433634695	25252	Economy	44300.00
0005433634652	25252	Economy	44300.00
0005433616464	25252	Economy	44300.00
0005433616513	25252	Economy	44300.00
0005433578144	25252	Economy	44300.00
0005433616558	25252	Economy	44300.00
0005433616559	25252	Economy	44300.00
0005433616552	25252	Economy	44300.00
0005433634752	25252	Economy	44300.00
0005433578143	25252	Economy	44300.00
0005433616189	25252	Economy	44300.00
0005433578056	25252	Economy	44300.00
0005433616180	25252	Economy	44300.00
0005433578145	25252	Economy	44300.00
0005433616327	25252	Economy	44300.00
0005433616454	25252	Economy	44300.00
0005433616461	25252	Economy	44300.00
0005433634675	25252	Economy	44300.00
0005433634743	25252	Economy	44300.00
0005433616626	25252	Economy	44300.00
0005433634744	25252	Economy	44300.00
0005433616717	25252	Economy	44300.00
0005433616487	25252	Economy	44300.00
0005433616307	25252	Economy	44300.00
0005433634658	25252	Economy	44300.00
0005434271369	4235	Business	193100.00
0005435787402	4235	Economy	64400.00
0005434271360	4235	Economy	64400.00
0005435787401	4235	Economy	64400.00
0005435856323	4235	Economy	64400.00
0005435856326	4235	Economy	64400.00
0005435947655	4235	Economy	64400.00
0005435947664	4235	Economy	70800.00
0005432571409	4235	Economy	64400.00
0005435947658	4235	Economy	64400.00
0005432571434	4235	Economy	64400.00
0005435947634	4235	Economy	64400.00
0005435856322	4235	Economy	64400.00
0005435947654	4235	Economy	64400.00
0005435947665	4235	Economy	64400.00
0005434271361	4235	Economy	64400.00
0005434271358	4235	Economy	64400.00
0005434271359	4235	Economy	64400.00
0005435986988	26603	Business	193100.00
0005435986979	26603	Business	193100.00
0005435987004	26603	Economy	64400.00
0005435477033	26603	Economy	64400.00
0005435986970	26603	Economy	64400.00
0005435986992	26603	Economy	64400.00
0005435986978	26603	Economy	64400.00
0005435986958	26603	Economy	64400.00
0005435477032	26603	Economy	64400.00
0005435987029	26603	Economy	64400.00
0005435477034	26603	Economy	64400.00
0005435986986	26603	Economy	64400.00
0005433075507	337	Business	21500.00
0005432949621	337	Business	21500.00
0005433929876	337	Business	21500.00
0005432949504	337	Business	21500.00
0005433570987	337	Business	21500.00
0005433075490	337	Business	21500.00
0005432949568	337	Business	21500.00
0005432949582	337	Business	21500.00
0005433075437	337	Business	21500.00
0005433075427	337	Business	21500.00
0005433075451	337	Economy	7900.00
0005433075510	337	Economy	7900.00
0005432949407	337	Economy	7900.00
0005433134246	337	Economy	7900.00
0005432949617	337	Economy	7200.00
0005433075502	337	Economy	7200.00
0005432949499	337	Economy	7200.00
0005432949444	337	Economy	7200.00
0005432949470	337	Economy	7200.00
0005432949619	337	Economy	7200.00
0005433134249	337	Economy	7200.00
0005433570986	337	Economy	7200.00
0005433929869	337	Economy	7200.00
0005433075433	337	Economy	7200.00
0005432949622	337	Economy	7200.00
0005433075467	337	Economy	7200.00
0005433075465	337	Economy	7200.00
0005433134256	337	Economy	7200.00
0005433075371	337	Economy	7200.00
0005432949573	337	Economy	7200.00
0005433075435	337	Economy	7200.00
0005432949539	337	Economy	7200.00
0005432949605	337	Economy	7200.00
0005432949468	337	Economy	7200.00
0005433075526	337	Economy	7200.00
0005432949618	337	Economy	7200.00
0005432949510	337	Economy	7200.00
0005432949606	337	Economy	7200.00
0005433075350	337	Economy	7200.00
0005432949569	337	Economy	7200.00
0005433929875	337	Economy	7200.00
0005432949550	337	Economy	7200.00
0005433134245	337	Economy	7200.00
0005433075506	337	Economy	7200.00
0005433929874	337	Economy	7900.00
0005433075343	337	Economy	7900.00
0005432949400	337	Economy	7200.00
0005433075466	337	Economy	7200.00
0005432949511	337	Economy	7200.00
0005433075480	337	Economy	7200.00
0005433075523	337	Economy	7200.00
0005432949498	337	Economy	7200.00
0005432949471	337	Economy	7200.00
0005432949395	337	Economy	7200.00
0005432949620	337	Economy	7200.00
0005432949482	337	Economy	7200.00
0005432949546	337	Economy	7200.00
0005433129399	337	Economy	7200.00
0005432949538	337	Economy	7200.00
0005433134255	337	Economy	7200.00
0005433570988	337	Economy	7200.00
0005432949430	337	Economy	7200.00
0005432949472	337	Economy	7200.00
0005433075432	337	Economy	7200.00
0005433075464	337	Economy	7200.00
0005432949505	337	Economy	7200.00
0005433075527	337	Economy	7200.00
0005432949301	337	Economy	7200.00
0005433075436	337	Economy	7200.00
0005432949509	337	Economy	7200.00
0005433570587	11584	Business	21500.00
0005433570607	11584	Business	21500.00
0005433570635	11584	Business	21500.00
0005433570065	11584	Business	21500.00
0005433570606	11584	Business	21500.00
0005433570570	11584	Business	21500.00
0005433570772	11584	Business	21500.00
0005433570701	11584	Business	21500.00
0005433570825	11584	Business	21500.00
0005433570636	11584	Business	21500.00
0005433570518	11584	Business	21500.00
0005433570622	11584	Economy	7900.00
0005433570445	11584	Economy	7900.00
0005433570568	11584	Economy	7200.00
0005433570852	11584	Economy	7900.00
0005434088011	11584	Economy	7200.00
0005434087995	11584	Economy	7200.00
0005433570608	11584	Economy	7200.00
0005434087947	11584	Economy	7200.00
0005433570335	11584	Economy	7200.00
0005433570391	11584	Economy	7200.00
0005433570425	11584	Economy	7200.00
0005433570527	11584	Economy	7200.00
0005434087939	11584	Economy	7200.00
0005433570651	11584	Economy	7200.00
0005433570525	11584	Economy	7200.00
0005433570301	11584	Economy	7200.00
0005434087994	11584	Economy	7200.00
0005433570883	11584	Economy	7200.00
0005433570096	11584	Economy	7200.00
0005433570765	11584	Economy	7200.00
0005433570524	11584	Economy	7200.00
0005434087985	11584	Economy	7200.00
0005433570528	11584	Economy	7200.00
0005433570558	11584	Economy	7200.00
0005433570563	11584	Economy	7200.00
0005433570623	11584	Economy	7200.00
0005433570334	11584	Economy	7200.00
0005433570764	11584	Economy	7200.00
0005433570728	11584	Economy	7200.00
0005433570582	11584	Economy	7900.00
0005433570629	11584	Economy	7900.00
0005433570461	11584	Economy	7200.00
0005433570559	11584	Economy	7900.00
0005433570336	11584	Economy	7200.00
0005433570604	11584	Economy	7200.00
0005432949700	11584	Economy	7200.00
0005433570553	11584	Economy	7200.00
0005433570228	11584	Economy	7200.00
0005433570395	11584	Economy	7200.00
0005433570500	11584	Economy	7200.00
0005434087967	11584	Economy	7200.00
0005434087942	11584	Economy	7200.00
0005434087934	11584	Economy	7200.00
0005434087993	11584	Economy	7200.00
0005434087950	11584	Economy	7200.00
0005433570095	11584	Economy	7200.00
0005434087941	11584	Economy	7200.00
0005433570493	11584	Economy	7200.00
0005433570358	11584	Economy	7200.00
0005433570474	11584	Economy	7200.00
0005433570644	11584	Economy	7200.00
0005433570499	11584	Economy	7200.00
0005433570311	11584	Economy	7200.00
0005433570682	11584	Economy	7200.00
0005433570605	11584	Economy	7200.00
0005433570569	11584	Economy	7200.00
0005434087961	11584	Economy	7200.00
0005433570586	11584	Economy	7200.00
0005433570494	11584	Economy	7200.00
0005433570645	11584	Economy	7200.00
0005433570624	11584	Economy	7200.00
0005433570643	11584	Economy	7200.00
0005434087935	11584	Economy	7200.00
0005434087940	11584	Economy	7200.00
0005434087936	11584	Economy	7200.00
0005433570628	11584	Economy	7200.00
0005433570618	11584	Economy	7200.00
0005433570670	11584	Economy	7200.00
0005433570562	11584	Economy	7200.00
0005433570462	11584	Economy	7200.00
0005433570824	11584	Economy	7200.00
0005433570533	11584	Economy	7200.00
0005434733081	9982	Economy	6300.00
0005433817560	13982	Economy	6300.00
0005433435445	2360	Business	184500.00
0005432985948	2360	Business	184500.00
0005433435402	2360	Business	184500.00
0005432869679	2360	Business	184500.00
0005433435460	2360	Business	184500.00
0005432869688	2360	Business	184500.00
0005432985863	2360	Business	184500.00
0005433435405	2360	Business	184500.00
0005433435362	2360	Business	184500.00
0005433435333	2360	Business	184500.00
0005432869691	2360	Business	184500.00
0005433435363	2360	Business	184500.00
0005432985903	2360	Economy	67700.00
0005432985847	2360	Economy	67700.00
0005432226242	2360	Economy	61500.00
0005432869686	2360	Economy	61500.00
0005433435279	2360	Economy	61500.00
0005433435399	2360	Economy	61500.00
0005433435339	2360	Economy	61500.00
0005433435450	2360	Economy	61500.00
0005435983676	2360	Economy	61500.00
0005432869678	2360	Economy	61500.00
0005433435383	2360	Economy	61500.00
0005433435482	2360	Economy	61500.00
0005433435467	2360	Economy	61500.00
0005432869709	2360	Economy	61500.00
0005434731261	2360	Economy	61500.00
0005432985986	2360	Economy	61500.00
0005432985987	2360	Economy	61500.00
0005432985864	2360	Economy	61500.00
0005434731287	2360	Economy	61500.00
0005432985836	2360	Economy	61500.00
0005435983677	2360	Economy	61500.00
0005432985918	2360	Economy	61500.00
0005432985825	2360	Economy	61500.00
0005433435338	2360	Economy	61500.00
0005432985902	2360	Economy	61500.00
0005432869677	2360	Economy	61500.00
0005433435421	2360	Economy	61500.00
0005432985837	2360	Economy	61500.00
0005432869696	2360	Economy	61500.00
0005432985835	2360	Economy	61500.00
0005433435400	2360	Economy	61500.00
0005433435449	2360	Economy	61500.00
0005432985911	2360	Economy	61500.00
0005433435384	2360	Economy	61500.00
0005432985912	2360	Economy	61500.00
0005433435451	2360	Economy	61500.00
0005432985812	2360	Economy	61500.00
0005433435351	2360	Economy	61500.00
0005433435361	2360	Economy	61500.00
0005432869685	2360	Economy	61500.00
0005432869704	2360	Economy	61500.00
0005432985846	2360	Economy	61500.00
0005433435380	2360	Economy	61500.00
0005432985901	2360	Economy	61500.00
0005432985826	2360	Economy	61500.00
0005433435461	2360	Economy	61500.00
0005432985969	2360	Economy	61500.00
0005432985795	2360	Economy	61500.00
0005432869687	2360	Economy	61500.00
0005432655880	26217	Business	184500.00
0005432986016	26217	Business	184500.00
0005433766759	26217	Business	184500.00
0005435983422	26217	Business	184500.00
0005435983420	26217	Business	184500.00
0005433755625	26217	Business	184500.00
0005435983088	26217	Business	184500.00
0005433755498	26217	Business	184500.00
0005433755650	26217	Business	184500.00
0005435983512	26217	Business	184500.00
0005433755576	26217	Business	184500.00
0005433766760	26217	Business	184500.00
0005435983154	26217	Economy	67700.00
0005435983089	26217	Economy	61500.00
0005433755785	26217	Economy	61500.00
0005432655792	26217	Economy	61500.00
0005433755767	26217	Economy	61500.00
0005432986018	26217	Economy	61500.00
0005433755758	26217	Economy	61500.00
0005432655816	26217	Economy	61500.00
0005435983549	26217	Economy	61500.00
0005433755715	26217	Economy	61500.00
0005435983155	26217	Economy	61500.00
0005435983462	26217	Economy	61500.00
0005435983445	26217	Economy	61500.00
0005435983538	26217	Economy	61500.00
0005435983278	26217	Economy	61500.00
0005435983627	26217	Economy	61500.00
0005433764734	26217	Economy	61500.00
0005435983396	26217	Economy	61500.00
0005432986017	26217	Economy	61500.00
0005433755296	26217	Economy	61500.00
0005433755778	26217	Economy	61500.00
0005432655836	26217	Economy	61500.00
0005435983413	26217	Economy	61500.00
0005435983306	26217	Economy	61500.00
0005435983340	26217	Economy	61500.00
0005435983571	26217	Economy	61500.00
0005432655812	26217	Economy	61500.00
0005432655843	26217	Economy	61500.00
0005435983223	26217	Economy	61500.00
0005433766758	26217	Economy	61500.00
0005433755698	26217	Economy	61500.00
0005433766739	26217	Economy	61500.00
0005435983459	26217	Economy	61500.00
0005435983019	26217	Economy	61500.00
0005435983487	26217	Economy	61500.00
0005433755497	26217	Economy	61500.00
0005433755629	26217	Economy	61500.00
0005435983446	26217	Economy	61500.00
0005433755768	26217	Economy	61500.00
0005435983444	26217	Economy	61500.00
0005435983272	26217	Economy	61500.00
0005435983277	26217	Economy	61500.00
0005433755779	26217	Economy	61500.00
0005432655830	26217	Economy	61500.00
0005433766724	26217	Economy	61500.00
0005433755716	26217	Economy	61500.00
0005435983572	26217	Economy	61500.00
0005433755272	26217	Economy	61500.00
0005432655831	26217	Economy	61500.00
0005433755777	26217	Economy	61500.00
0005433755295	26217	Economy	61500.00
0005435983230	26217	Economy	61500.00
0005435983090	26217	Economy	61500.00
0005433766733	26217	Economy	61500.00
0005435983339	26217	Economy	61500.00
0005432655822	26217	Economy	61500.00
0005434376169	26217	Economy	61500.00
0005432655842	26217	Economy	61500.00
0005435983436	26217	Economy	61500.00
0005435983561	26217	Economy	61500.00
0005433755566	26217	Economy	61500.00
0005432655879	26217	Economy	61500.00
0005433766740	26217	Economy	61500.00
0005433755786	26217	Economy	61500.00
0005433755808	26217	Economy	61500.00
0005435983412	26217	Economy	61500.00
0005435983421	26217	Economy	61500.00
0005435983488	26217	Economy	61500.00
0005433755465	26217	Economy	61500.00
0005432655829	26217	Economy	61500.00
0005433766735	26217	Economy	61500.00
0005435983415	26217	Economy	61500.00
0005435983384	26217	Economy	61500.00
0005433755760	26217	Economy	61500.00
0005435983312	26217	Economy	61500.00
0005433755273	26217	Economy	61500.00
0005432655837	26217	Economy	61500.00
0005433755294	26217	Economy	61500.00
0005435983497	26217	Economy	61500.00
0005432655793	26217	Economy	61500.00
0005433766734	26217	Economy	61500.00
0005433755677	26217	Economy	61500.00
0005433755870	26217	Economy	61500.00
0005433435509	26217	Economy	61500.00
0005435983626	26217	Economy	61500.00
0005435983385	26217	Economy	61500.00
0005432655838	26217	Economy	61500.00
0005432655811	26217	Economy	61500.00
0005435983414	26217	Economy	61500.00
0005435983222	26217	Economy	61500.00
0005432655824	26217	Economy	61500.00
0005432655825	26217	Economy	61500.00
0005433152374	1542	Business	38900.00
0005433152385	1542	Economy	13000.00
0005433152338	1542	Economy	13000.00
0005433152335	1542	Economy	13000.00
0005433931538	1542	Economy	13000.00
0005433152336	1542	Economy	13000.00
0005433152356	1542	Economy	13000.00
0005433152367	1542	Economy	13000.00
0005433931536	1542	Economy	14300.00
0005434029719	1542	Economy	14300.00
0005433152208	1542	Economy	14300.00
0005433152271	1542	Economy	14300.00
0005433152301	1542	Economy	13000.00
0005433152329	1542	Economy	13000.00
0005434029718	1542	Economy	13000.00
0005433152210	1542	Economy	13000.00
0005433764731	1542	Economy	13000.00
0005433152386	1542	Economy	13000.00
0005433152209	1542	Economy	13000.00
0005433152398	1542	Economy	13000.00
0005433931542	1542	Economy	13000.00
0005433931534	1542	Economy	13000.00
0005433931537	1542	Economy	13000.00
0005433931528	1542	Economy	13000.00
0005433152368	1542	Economy	13000.00
0005433152269	1542	Economy	13000.00
0005433152350	1542	Economy	13000.00
0005433152270	1542	Economy	13000.00
0005433764730	1542	Economy	13000.00
0005433152298	1542	Economy	13000.00
0005433931539	1542	Economy	13000.00
0005433931541	1542	Economy	13000.00
0005433152361	1542	Economy	13000.00
0005434375660	20129	Business	38900.00
0005434375773	20129	Business	38900.00
0005434375719	20129	Business	38900.00
0005434375715	20129	Business	38900.00
0005434375900	20129	Business	38900.00
0005434375996	20129	Economy	13000.00
0005434375938	20129	Economy	13000.00
0005434375919	20129	Economy	13000.00
0005434375911	20129	Economy	13000.00
0005434375776	20129	Economy	13000.00
0005434375803	20129	Economy	13000.00
0005434376002	20129	Economy	13000.00
0005434375777	20129	Economy	13000.00
0005434376185	20129	Economy	13000.00
0005434375939	20129	Economy	13000.00
0005434375886	20129	Economy	13000.00
0005434375720	20129	Economy	13000.00
0005434375791	20129	Economy	13000.00
0005434375563	20129	Economy	13000.00
0005434375846	20129	Economy	14300.00
0005434376230	20129	Economy	14300.00
0005434375994	20129	Economy	14300.00
0005434375746	20129	Economy	13000.00
0005434375853	20129	Economy	13000.00
0005434375804	20129	Economy	13000.00
0005434375892	20129	Economy	13000.00
0005434375986	20129	Economy	13000.00
0005434375972	20129	Economy	13000.00
0005434375966	20129	Economy	13000.00
0005434375626	20129	Economy	13000.00
0005434375778	20129	Economy	13000.00
0005434375879	20129	Economy	13000.00
0005434375854	20129	Economy	13000.00
0005434375770	20129	Economy	13000.00
0005434375897	20129	Economy	13000.00
0005434376012	20129	Economy	13000.00
0005434375891	20129	Economy	13000.00
0005434375790	20129	Economy	13000.00
0005434375971	20129	Economy	13000.00
0005434375795	20129	Economy	13000.00
0005434375909	20129	Economy	13000.00
0005434375985	20129	Economy	13000.00
0005434375877	20129	Economy	13000.00
0005434375912	20129	Economy	13000.00
0005434375842	20129	Economy	13000.00
0005434375987	20129	Economy	13000.00
0005434375449	20129	Economy	13000.00
0005434375901	20129	Economy	13000.00
0005434375908	20129	Economy	13000.00
0005434375845	20129	Economy	13000.00
0005434375896	20129	Economy	13000.00
0005434375918	20129	Economy	13000.00
0005434375843	20129	Economy	13000.00
0005433158205	538	Business	27500.00
0005433158199	538	Business	27500.00
0005433262026	538	Business	27500.00
0005433261916	538	Business	27500.00
0005433261903	538	Business	27500.00
0005433262012	538	Business	27500.00
0005433261889	538	Economy	9200.00
0005433261993	538	Economy	9200.00
0005432426077	538	Economy	9200.00
0005433261915	538	Economy	9200.00
0005433157013	538	Economy	9200.00
0005434444193	538	Economy	9200.00
0005433261902	538	Economy	9200.00
0005433157014	538	Economy	9200.00
0005433262040	538	Economy	9200.00
0005433261931	538	Economy	9200.00
0005433261925	538	Economy	9200.00
0005433261917	538	Economy	9200.00
0005433261926	538	Economy	9200.00
0005433261982	538	Economy	10100.00
0005433261929	538	Economy	9200.00
0005433158204	538	Economy	9200.00
0005433261901	538	Economy	9200.00
0005433262007	538	Economy	9200.00
0005433157015	538	Economy	9200.00
0005434995382	538	Economy	9200.00
0005433261930	538	Economy	9200.00
0005433261880	538	Economy	9200.00
0005433261983	538	Economy	9200.00
0005433261994	538	Economy	9200.00
0005433262062	12944	Economy	10100.00
0005434446568	12944	Economy	9200.00
0005434446573	12944	Economy	9200.00
0005432425586	12919	Business	27500.00
0005432425563	12919	Business	27500.00
0005432425501	12919	Business	27500.00
0005432425629	12919	Business	27500.00
0005432425672	12919	Business	27500.00
0005432425587	12919	Business	27500.00
0005432425633	12919	Business	27500.00
0005432425673	12919	Economy	10100.00
0005432425624	12919	Economy	10100.00
0005432425557	12919	Economy	9200.00
0005432425640	12919	Economy	9200.00
0005432425658	12919	Economy	9200.00
0005432425661	12919	Economy	9200.00
0005432425599	12919	Economy	9200.00
0005432425641	12919	Economy	9200.00
0005432425618	12919	Economy	9200.00
0005432425651	12919	Economy	9200.00
0005432425539	12919	Economy	9200.00
0005432425593	12919	Economy	9200.00
0005432425689	12919	Economy	9200.00
0005432425540	12919	Economy	9200.00
0005432425669	12919	Economy	9200.00
0005432425667	12919	Economy	9200.00
0005432425679	12919	Economy	9200.00
0005432425623	12919	Economy	9200.00
0005432425696	12919	Economy	9200.00
0005432425697	12919	Economy	10100.00
0005432425409	12919	Economy	9200.00
0005432425642	12919	Economy	9200.00
0005432425683	12919	Economy	9200.00
0005432425699	12919	Economy	9200.00
0005432425556	12919	Economy	9200.00
0005432425671	12919	Economy	9200.00
0005432425600	12919	Economy	9200.00
0005432425670	12919	Economy	9200.00
0005432425625	12919	Economy	9200.00
0005432425408	12919	Economy	9200.00
0005432425489	12919	Economy	9200.00
0005432425479	12919	Economy	9200.00
0005432425659	12919	Economy	9200.00
0005432425655	12919	Economy	9200.00
0005432425666	12919	Economy	9200.00
0005432425583	12919	Economy	9200.00
0005432425638	12919	Economy	9200.00
0005432425502	12919	Economy	9200.00
0005432425698	12919	Economy	9200.00
0005432425695	12919	Economy	9200.00
0005432425660	12919	Economy	9200.00
0005432425601	12919	Economy	9200.00
0005433058897	481	Business	24500.00
0005433058773	481	Business	24500.00
0005433684482	481	Business	24500.00
0005433058848	481	Business	24500.00
0005434025700	481	Economy	8200.00
0005434025699	481	Economy	8200.00
0005433058801	481	Economy	8200.00
0005433058985	481	Economy	8200.00
0005433929707	481	Economy	8200.00
0005433058972	481	Economy	8200.00
0005433058903	481	Economy	8200.00
0005434735807	481	Economy	8200.00
0005433058931	481	Economy	8200.00
0005432235862	481	Economy	8200.00
0005433058904	481	Economy	8200.00
0005433058896	481	Economy	8200.00
0005433059019	481	Economy	8200.00
0005433059005	481	Economy	8200.00
0005433058772	481	Economy	8200.00
0005433929701	481	Economy	8200.00
0005434025701	481	Economy	8200.00
0005433058984	481	Economy	9000.00
0005433058982	481	Economy	8200.00
0005433058774	481	Economy	8200.00
0005434735825	481	Economy	8200.00
0005433929714	481	Economy	8200.00
0005433059004	481	Economy	8200.00
0005433058669	481	Economy	8200.00
0005434735826	481	Economy	8200.00
0005434735811	481	Economy	8200.00
0005433058802	481	Economy	8200.00
0005434025478	12700	Business	24500.00
0005434032146	12700	Business	24500.00
0005434025586	12700	Business	24500.00
0005434025602	12700	Business	24500.00
0005434025410	12700	Business	24500.00
0005434025477	12700	Business	24500.00
0005434025373	12700	Business	24500.00
0005434025412	12700	Business	24500.00
0005434025587	12700	Business	24500.00
0005434025351	12700	Business	24500.00
0005434025500	12700	Economy	9000.00
0005434025560	12700	Economy	9000.00
0005434025226	12700	Economy	8200.00
0005434025499	12700	Economy	8200.00
0005434025580	12700	Economy	8200.00
0005434025378	12700	Economy	8200.00
0005434025285	12700	Economy	8200.00
0005434025406	12700	Economy	8200.00
0005434025445	12700	Economy	8200.00
0005434025368	12700	Economy	8200.00
0005434025476	12700	Economy	8200.00
0005434028365	12700	Economy	8200.00
0005434025623	12700	Economy	8200.00
0005434025328	12700	Economy	8200.00
0005434025493	12700	Economy	8200.00
0005434025330	12700	Economy	8200.00
0005434025565	12700	Economy	8200.00
0005434025667	12700	Economy	8200.00
0005434028386	12700	Economy	8200.00
0005434025628	12700	Economy	8200.00
0005434025485	12700	Economy	8200.00
0005434029718	12700	Economy	8200.00
0005434025583	12700	Economy	8200.00
0005434025455	12700	Economy	8200.00
0005434025173	12700	Economy	8200.00
0005434025492	12700	Economy	8200.00
0005434025443	12700	Economy	8200.00
0005434028367	12700	Economy	8200.00
0005434025329	12700	Economy	8200.00
0005434029719	12700	Economy	8200.00
0005434025352	12700	Economy	9000.00
0005434025413	12700	Economy	9000.00
0005434025342	12700	Economy	8200.00
0005434025596	12700	Economy	8200.00
0005434025563	12700	Economy	8200.00
0005434025622	12700	Economy	8200.00
0005434025470	12700	Economy	8200.00
0005434028384	12700	Economy	8200.00
0005434028366	12700	Economy	8200.00
0005434025441	12700	Economy	8200.00
0005434025537	12700	Economy	8200.00
0005434025374	12700	Economy	8200.00
0005434025498	12700	Economy	8200.00
0005434025444	12700	Economy	8200.00
0005434025484	12700	Economy	8200.00
0005434032149	12700	Economy	8200.00
0005434025521	12700	Economy	8200.00
0005434025634	12700	Economy	8200.00
0005434032140	12700	Economy	8200.00
0005434032133	12700	Economy	8200.00
0005434025564	12700	Economy	8200.00
0005434025588	12700	Economy	8200.00
0005434025595	12700	Economy	8200.00
0005434025411	12700	Economy	8200.00
0005434025627	12700	Economy	8200.00
0005434025536	12700	Economy	8200.00
0005434025369	12700	Economy	8200.00
0005434025172	12700	Economy	8200.00
0005434025585	12700	Economy	8200.00
0005434032130	12700	Economy	8200.00
0005434028387	12700	Economy	8200.00
0005433037641	2111	Business	34700.00
0005433926117	2111	Business	34700.00
0005433037467	2111	Business	34700.00
0005433037398	2111	Business	34700.00
0005433037729	2111	Business	34700.00
0005433037570	2111	Business	34700.00
0005433037635	2111	Business	34700.00
0005433037593	2111	Economy	12700.00
0005433037456	2111	Economy	11600.00
0005433037569	2111	Economy	11600.00
0005433926120	2111	Economy	11600.00
0005433037567	2111	Economy	11600.00
0005433037817	2111	Economy	11600.00
0005434028365	2111	Economy	11600.00
0005433037714	2111	Economy	11600.00
0005433037681	2111	Economy	11600.00
0005434376185	2111	Economy	11600.00
0005433037528	2111	Economy	11600.00
0005434028384	2111	Economy	11600.00
0005433037664	2111	Economy	11600.00
0005433037634	2111	Economy	11600.00
0005433037665	2111	Economy	11600.00
0005433037592	2111	Economy	11600.00
0005433037713	2111	Economy	11600.00
0005433037648	2111	Economy	11600.00
0005433037626	2111	Economy	11600.00
0005433037618	2111	Economy	11600.00
0005434028387	2111	Economy	11600.00
0005433037642	2111	Economy	11600.00
0005433037584	2111	Economy	11600.00
0005433037617	2111	Economy	11600.00
0005433037789	2111	Economy	11600.00
0005433037818	2111	Economy	11600.00
0005433037429	2111	Economy	11600.00
0005433926118	2111	Economy	11600.00
0005434028367	2111	Economy	11600.00
0005433037675	2111	Economy	11600.00
0005433926119	2111	Economy	11600.00
0005434028366	2111	Economy	11600.00
0005433037779	2111	Economy	12700.00
0005434028386	2111	Economy	12700.00
0005433037552	2111	Economy	11600.00
0005433037630	2111	Economy	11600.00
0005433037591	2111	Economy	11600.00
0005433037663	2111	Economy	11600.00
0005433929898	2111	Economy	11600.00
0005433037715	2111	Economy	11600.00
0005433037790	2111	Economy	11600.00
0005433037455	2111	Economy	11600.00
0005433037583	2111	Economy	11600.00
0005433037791	2111	Economy	11600.00
0005433037529	2111	Economy	11600.00
0005433037637	2111	Economy	11600.00
0005433037537	2111	Economy	11600.00
0005433037619	2111	Economy	11600.00
0005433037631	2111	Economy	11600.00
0005433037819	2111	Economy	11600.00
0005433037636	2111	Economy	11600.00
0005433037571	2111	Economy	11600.00
0005433926006	24104	Business	34700.00
0005433925834	24104	Business	34700.00
0005433925867	24104	Business	34700.00
0005433925946	24104	Business	34700.00
0005433925550	24104	Business	34700.00
0005433925721	24104	Business	34700.00
0005433925817	24104	Business	34700.00
0005433925493	24104	Business	34700.00
0005433925653	24104	Business	34700.00
0005433926046	24104	Business	34700.00
0005433925844	24104	Business	34700.00
0005433037855	24104	Business	34700.00
0005433926054	24104	Business	34700.00
0005433925579	24104	Business	34700.00
0005433925449	24104	Business	34700.00
0005433925622	24104	Business	34700.00
0005433037852	24104	Economy	12700.00
0005433925996	24104	Economy	11600.00
0005433925505	24104	Economy	11600.00
0005433925690	24104	Economy	11600.00
0005433925628	24104	Economy	11600.00
0005433925533	24104	Economy	11600.00
0005433925785	24104	Economy	11600.00
0005433925855	24104	Economy	11600.00
0005433929723	24104	Economy	11600.00
0005433925750	24104	Economy	11600.00
0005433925548	24104	Economy	11600.00
0005433925864	24104	Economy	11600.00
0005433925964	24104	Economy	11600.00
0005433925914	24104	Economy	11600.00
0005433037856	24104	Economy	11600.00
0005433925835	24104	Economy	11600.00
0005433925677	24104	Economy	11600.00
0005433925541	24104	Economy	11600.00
0005433925997	24104	Economy	11600.00
0005433925542	24104	Economy	11600.00
0005433925339	24104	Economy	11600.00
0005433925876	24104	Economy	11600.00
0005433037854	24104	Economy	11600.00
0005433931548	24104	Economy	11600.00
0005433925831	24104	Economy	11600.00
0005433926068	24104	Economy	11600.00
0005433926021	24104	Economy	11600.00
0005433925720	24104	Economy	11600.00
0005433037857	24104	Economy	11600.00
0005433925975	24104	Economy	11600.00
0005433875408	24104	Economy	11600.00
0005433925760	24104	Economy	11600.00
0005433925551	24104	Economy	11600.00
0005433925667	24104	Economy	11600.00
0005433925786	24104	Economy	11600.00
0005433925652	24104	Economy	11600.00
0005433925889	24104	Economy	11600.00
0005433925759	24104	Economy	11600.00
0005433925578	24104	Economy	11600.00
0005433875426	24104	Economy	11600.00
0005433925607	24104	Economy	11600.00
0005433925909	24104	Economy	11600.00
0005433925949	24104	Economy	11600.00
0005433929722	24104	Economy	11600.00
0005433925738	24104	Economy	11600.00
0005433925309	24104	Economy	11600.00
0005433925890	24104	Economy	11600.00
0005433925351	24104	Economy	11600.00
0005433925911	24104	Economy	12700.00
0005433925766	24104	Economy	12700.00
0005433925433	24104	Economy	11600.00
0005433925606	24104	Economy	12700.00
0005433925629	24104	Economy	11600.00
0005432749853	24104	Economy	11600.00
0005433925678	24104	Economy	11600.00
0005433925845	24104	Economy	11600.00
0005433925761	24104	Economy	11600.00
0005433925788	24104	Economy	11600.00
0005433925792	24104	Economy	11600.00
0005433925522	24104	Economy	11600.00
0005433925998	24104	Economy	11600.00
0005433925791	24104	Economy	11600.00
0005433925534	24104	Economy	11600.00
0005433925767	24104	Economy	11600.00
0005433925549	24104	Economy	11600.00
0005433925871	24104	Economy	11600.00
0005433925669	24104	Economy	11600.00
0005433925685	24104	Economy	11600.00
0005433925340	24104	Economy	11600.00
0005433925616	24104	Economy	11600.00
0005433925475	24104	Economy	11600.00
0005433037853	24104	Economy	11600.00
0005433925849	24104	Economy	11600.00
0005433925905	24104	Economy	11600.00
0005433925912	24104	Economy	11600.00
0005433925960	24104	Economy	11600.00
0005433925650	24104	Economy	11600.00
0005433925668	24104	Economy	11600.00
0005433925945	24104	Economy	11600.00
0005433925547	24104	Economy	11600.00
0005433925751	24104	Economy	11600.00
0005433925814	24104	Economy	11600.00
0005433113593	246	Business	83700.00
0005433181695	246	Business	83700.00
0005433235381	246	Business	83700.00
0005433235814	246	Business	83700.00
0005433290031	246	Business	83700.00
0005433181711	246	Business	83700.00
0005433113591	246	Business	83700.00
0005433235825	246	Comfort	47400.00
0005433181764	246	Comfort	47400.00
0005433235819	246	Comfort	47400.00
0005433235836	246	Comfort	47400.00
0005433235886	246	Comfort	47400.00
0005433235822	246	Comfort	47400.00
0005433766728	246	Comfort	47400.00
0005433235711	246	Comfort	47400.00
0005433235793	246	Comfort	47400.00
0005433181735	246	Comfort	47400.00
0005433235929	246	Comfort	47400.00
0005433235628	246	Comfort	47400.00
0005433235851	246	Economy	27900.00
0005433181815	246	Economy	27900.00
0005433181778	246	Economy	27900.00
0005433235896	246	Economy	27900.00
0005433290041	246	Economy	27900.00
0005433126952	246	Economy	27900.00
0005433290017	246	Economy	27900.00
0005433181800	246	Economy	27900.00
0005433235466	246	Economy	27900.00
0005433126970	246	Economy	27900.00
0005433181714	246	Economy	27900.00
0005433766723	246	Economy	27900.00
0005433235894	246	Economy	27900.00
0005433235823	246	Economy	27900.00
0005433235802	246	Economy	27900.00
0005433290023	246	Economy	27900.00
0005433235690	246	Economy	27900.00
0005433290036	246	Economy	27900.00
0005433235973	246	Economy	27900.00
0005433290018	246	Economy	27900.00
0005433290054	246	Economy	27900.00
0005433235839	246	Economy	27900.00
0005433766729	246	Economy	27900.00
0005433111564	246	Economy	27900.00
0005433235666	246	Economy	27900.00
0005433766721	246	Economy	27900.00
0005434729050	246	Economy	27900.00
0005433235918	246	Economy	27900.00
0005433181734	246	Economy	27900.00
0005433235734	246	Economy	27900.00
0005433181611	246	Economy	27900.00
0005433236006	246	Economy	27900.00
0005433111559	246	Economy	27900.00
0005433235826	246	Economy	27900.00
0005433235712	246	Economy	27900.00
0005433235897	246	Economy	30700.00
0005433235629	246	Economy	27900.00
0005433235800	246	Economy	30700.00
0005433126969	246	Economy	27900.00
0005433235838	246	Economy	27900.00
0005433181799	246	Economy	27900.00
0005434729051	246	Economy	27900.00
0005434729049	246	Economy	27900.00
0005433235919	246	Economy	27900.00
0005433235912	246	Economy	27900.00
0005433235835	246	Economy	27900.00
0005433181771	246	Economy	27900.00
0005433235874	246	Economy	27900.00
0005433235382	246	Economy	27900.00
0005433235727	246	Economy	27900.00
0005433131830	246	Economy	27900.00
0005434729052	246	Economy	27900.00
0005433235757	246	Economy	27900.00
0005433235751	246	Economy	27900.00
0005433181798	246	Economy	27900.00
0005434729053	246	Economy	27900.00
0005433181763	246	Economy	27900.00
0005433235801	246	Economy	27900.00
0005433181741	246	Economy	27900.00
0005434728583	9865	Business	83700.00
0005434728021	9865	Business	83700.00
0005434728100	9865	Business	83700.00
0005434552614	9865	Business	83700.00
0005434728477	9865	Business	83700.00
0005434728515	9865	Business	83700.00
0005434728537	9865	Business	83700.00
0005434728774	9865	Business	83700.00
0005434735834	9865	Business	83700.00
0005434552582	9865	Business	83700.00
0005434728454	9865	Business	83700.00
0005434552625	9865	Business	83700.00
0005434552537	9865	Business	83700.00
0005434728897	9865	Business	83700.00
0005434728644	9865	Business	83700.00
0005434552673	9865	Business	83700.00
0005434727841	9865	Comfort	47400.00
0005434728738	9865	Business	83700.00
0005434728881	9865	Comfort	47400.00
0005434728476	9865	Comfort	47400.00
0005434552653	9865	Comfort	47400.00
0005434728617	9865	Comfort	47400.00
0005434727840	9865	Comfort	47400.00
0005434728312	9865	Comfort	47400.00
0005434552289	9865	Comfort	47400.00
0005434728876	9865	Comfort	47400.00
0005434552548	9865	Comfort	47400.00
0005434728614	9865	Comfort	47400.00
0005434728669	9865	Comfort	47400.00
0005434552596	9865	Comfort	47400.00
0005434728279	9865	Comfort	47400.00
0005435142890	9865	Comfort	47400.00
0005434728481	9865	Comfort	47400.00
0005435142857	9865	Comfort	47400.00
0005433126985	9865	Comfort	47400.00
0005434728608	9865	Comfort	47400.00
0005434728653	9865	Comfort	47400.00
0005435142917	9865	Comfort	47400.00
0005434728609	9865	Economy	27900.00
0005434728637	9865	Economy	27900.00
0005434728654	9865	Economy	27900.00
0005434032162	9865	Economy	27900.00
0005434552553	9865	Economy	27900.00
0005434727818	9865	Economy	27900.00
0005434728274	9865	Economy	27900.00
0005434728749	9865	Economy	27900.00
0005434728618	9865	Economy	27900.00
0005434735833	9865	Economy	27900.00
0005434728646	9865	Economy	27900.00
0005434552288	9865	Economy	27900.00
0005435142856	9865	Economy	27900.00
0005434728215	9865	Economy	27900.00
0005434728456	9865	Economy	27900.00
0005434728268	9865	Economy	27900.00
0005434728793	9865	Economy	27900.00
0005434728581	9865	Economy	27900.00
0005434728262	9865	Economy	27900.00
0005434552597	9865	Economy	27900.00
0005434552584	9865	Economy	27900.00
0005434728466	9865	Economy	27900.00
0005434728661	9865	Economy	27900.00
0005434728461	9865	Economy	27900.00
0005434728615	9865	Economy	27900.00
0005434552571	9865	Economy	27900.00
0005434728249	9865	Economy	27900.00
0005434728577	9865	Economy	27900.00
0005434728862	9865	Economy	27900.00
0005434727966	9865	Economy	27900.00
0005434552782	9865	Economy	27900.00
0005434552753	9865	Economy	27900.00
0005434728913	9865	Economy	27900.00
0005434552695	9865	Economy	27900.00
0005434552476	9865	Economy	27900.00
0005434552532	9865	Economy	27900.00
0005434728550	9865	Economy	27900.00
0005434302562	9865	Economy	27900.00
0005434735795	9865	Economy	27900.00
0005434728470	9865	Economy	27900.00
0005434728460	9865	Economy	30700.00
0005434728735	9865	Economy	30700.00
0005434552447	9865	Economy	27900.00
0005435142916	9865	Economy	27900.00
0005434728744	9865	Economy	30700.00
0005434728342	9865	Economy	30700.00
0005434728276	9865	Economy	27900.00
0005434552642	9865	Economy	30700.00
0005434552652	9865	Economy	27900.00
0005434552682	9865	Economy	27900.00
0005434552478	9865	Economy	27900.00
0005434728656	9865	Economy	27900.00
0005434728578	9865	Economy	27900.00
0005433236066	9865	Economy	27900.00
0005434728788	9865	Economy	27900.00
0005434728071	9865	Economy	27900.00
0005434552681	9865	Economy	27900.00
0005434552600	9865	Economy	27900.00
0005435142949	9865	Economy	27900.00
0005434728596	9865	Economy	27900.00
0005434728898	9865	Economy	27900.00
0005434728741	9865	Economy	27900.00
0005434728399	9865	Economy	27900.00
0005434728806	9865	Economy	27900.00
0005434552659	9865	Economy	27900.00
0005434552387	9865	Economy	27900.00
0005434728257	9865	Economy	27900.00
0005434728601	9865	Economy	27900.00
0005434552654	9865	Economy	27900.00
0005435142906	9865	Economy	27900.00
0005434552670	9865	Economy	27900.00
0005434552583	9865	Economy	27900.00
0005434728368	9865	Economy	27900.00
0005434728736	9865	Economy	27900.00
0005434728755	9865	Economy	27900.00
0005434302549	9865	Economy	27900.00
0005434728293	9865	Economy	27900.00
0005434728727	9865	Economy	27900.00
0005434728327	9865	Economy	27900.00
0005434728805	9865	Economy	27900.00
0005434728743	9865	Economy	27900.00
0005434728455	9865	Economy	27900.00
0005434735800	9865	Economy	27900.00
0005434302569	9865	Economy	27900.00
0005434552440	9865	Economy	27900.00
0005434552563	9865	Economy	27900.00
0005434728616	9865	Economy	27900.00
0005434728235	9865	Economy	27900.00
0005434728582	9865	Economy	27900.00
0005434552785	9865	Economy	27900.00
0005435142928	9865	Economy	27900.00
0005434728645	9865	Economy	27900.00
0005434728682	9865	Economy	27900.00
0005434728418	9865	Economy	27900.00
0005434552674	9865	Economy	27900.00
0005434552448	9865	Economy	27900.00
0005434727967	9865	Economy	27900.00
0005434552651	9865	Economy	27900.00
0005434552734	9865	Economy	27900.00
0005435142861	9865	Economy	27900.00
0005434552781	9865	Economy	27900.00
0005434552287	9865	Economy	27900.00
0005434728587	9865	Economy	27900.00
0005434728817	9865	Economy	27900.00
0005434728825	9865	Economy	27900.00
0005434728526	9865	Economy	27900.00
0005434728070	9865	Economy	27900.00
0005434728593	9865	Economy	27900.00
0005434728263	9865	Economy	27900.00
0005434728684	9865	Economy	27900.00
0005434728570	9865	Economy	27900.00
0005434728576	9865	Economy	27900.00
0005434728468	9865	Economy	27900.00
0005434728549	9865	Economy	27900.00
0005434728555	9865	Economy	27900.00
0005434552568	9865	Economy	27900.00
0005434728269	9865	Economy	27900.00
0005434728306	9865	Economy	30700.00
0005434731287	9865	Economy	30700.00
0005434728588	9865	Economy	27900.00
0005434728756	9865	Economy	27900.00
0005434552768	9865	Economy	27900.00
0005434728528	9865	Economy	27900.00
0005434728649	9865	Economy	27900.00
0005433290066	9865	Economy	27900.00
0005434728737	9865	Economy	27900.00
0005434552552	9865	Economy	27900.00
0005434728740	9865	Economy	27900.00
0005434552658	9865	Economy	27900.00
0005435142828	9865	Economy	27900.00
0005434728525	9865	Economy	27900.00
0005434728072	9865	Economy	27900.00
0005434728471	9865	Economy	27900.00
0005434552589	9865	Economy	27900.00
0005434728341	9865	Economy	27900.00
0005434552347	9865	Economy	27900.00
0005434552784	9865	Economy	27900.00
0005434728815	9865	Economy	27900.00
0005434728482	9865	Economy	27900.00
0005432199445	9865	Economy	27900.00
0005434728000	9865	Economy	27900.00
0005434552501	9865	Economy	27900.00
0005434552650	9865	Economy	27900.00
0005435142816	9865	Economy	27900.00
0005434728398	9865	Economy	27900.00
0005434728824	9865	Economy	27900.00
0005434728469	9865	Economy	27900.00
0005433236065	9865	Economy	27900.00
0005434728911	9865	Economy	27900.00
0005434552348	9865	Economy	27900.00
0005434552547	9865	Economy	27900.00
0005434728264	9865	Economy	27900.00
0005434552666	9865	Economy	27900.00
0005434552540	9865	Economy	27900.00
0005434552668	9865	Economy	27900.00
0005434728667	9865	Economy	27900.00
0005434728417	9865	Economy	27900.00
0005435142889	9865	Economy	27900.00
0005434302550	9865	Economy	27900.00
0005435142933	9865	Economy	27900.00
0005434552683	9865	Economy	27900.00
0005434552569	9865	Economy	27900.00
0005434728789	9865	Economy	27900.00
0005434552546	9865	Economy	27900.00
0005434728732	9865	Economy	27900.00
0005434728258	9865	Economy	27900.00
0005434728280	9865	Economy	27900.00
0005435142898	9865	Economy	27900.00
0005434552615	9865	Economy	27900.00
0005434728707	9865	Economy	27900.00
0005434728478	9865	Economy	27900.00
0005435142905	9865	Economy	27900.00
0005434735809	9865	Economy	27900.00
0005434728039	9865	Economy	27900.00
0005434728655	9865	Economy	27900.00
0005434552586	9865	Economy	27900.00
0005434735808	9865	Economy	27900.00
0005434552551	9865	Economy	27900.00
0005434552700	9865	Economy	27900.00
0005434552509	9865	Economy	27900.00
0005434728514	9865	Economy	27900.00
0005434552538	9865	Economy	27900.00
0005434728451	9865	Economy	27900.00
0005434728742	9865	Economy	27900.00
0005434728816	9865	Economy	27900.00
0005434302551	9865	Economy	27900.00
0005434728612	9865	Economy	27900.00
0005434731261	9865	Economy	27900.00
0005434728804	9865	Economy	27900.00
0005434552539	9865	Economy	27900.00
0005435215242	7745	Business	42100.00
0005435283462	7745	Business	42100.00
0005435215250	7745	Business	42100.00
0005435215359	7745	Business	42100.00
0005435215236	7745	Business	42100.00
0005435215330	7745	Business	42100.00
0005435283463	7745	Comfort	23900.00
0005435215424	7745	Comfort	23900.00
0005433656751	7745	Comfort	23900.00
0005435215337	7745	Comfort	23900.00
0005435215022	7745	Comfort	23900.00
0005435215442	7745	Comfort	23900.00
0005432531842	7745	Comfort	23900.00
0005435215008	7745	Comfort	23900.00
0005435215023	7745	Comfort	23900.00
0005435215085	7745	Economy	14000.00
0005435215181	7745	Economy	14000.00
0005435215429	7745	Economy	14000.00
0005435215207	7745	Economy	14000.00
0005435215169	7745	Economy	14000.00
0005435215111	7745	Economy	14000.00
0005435725723	7745	Economy	14000.00
0005435215365	7745	Economy	14000.00
0005433656753	7745	Economy	14000.00
0005435283490	7745	Economy	14000.00
0005435215370	7745	Economy	14000.00
0005435215224	7745	Economy	15400.00
0005435215419	7745	Economy	14000.00
0005432429034	7745	Economy	15400.00
0005435215247	7745	Economy	15400.00
0005435283496	7745	Economy	15400.00
0005435283514	7745	Economy	14000.00
0005435215364	7745	Economy	14000.00
0005435215418	7745	Economy	14000.00
0005435215196	7745	Economy	14000.00
0005435215050	7745	Economy	14000.00
0005435215344	7745	Economy	14000.00
0005435283507	7745	Economy	14000.00
0005432531844	7745	Economy	14000.00
0005435214840	7745	Economy	14000.00
0005435283426	7745	Economy	14000.00
0005435215108	7745	Economy	14000.00
0005435215149	7745	Economy	14000.00
0005435215336	7745	Economy	14000.00
0005435215058	7745	Economy	14000.00
0005435215276	7745	Economy	14000.00
0005435215148	7745	Economy	14000.00
0005435215375	7745	Economy	14000.00
0005435215107	7745	Economy	14000.00
0005435215275	7745	Economy	15400.00
0005435215421	7745	Economy	15400.00
0005435283491	7745	Economy	14000.00
0005435215443	7745	Economy	14000.00
0005435215170	7745	Economy	14000.00
0005435215237	7745	Economy	14000.00
0005435215277	7745	Economy	14000.00
0005435215024	7745	Economy	14000.00
0005435215402	7745	Economy	14000.00
0005435215049	7745	Economy	14000.00
0005432531843	7745	Economy	14000.00
0005435631038	7745	Economy	14000.00
0005435725722	7745	Economy	14000.00
0005435215180	7745	Economy	14000.00
0005435215110	7745	Economy	14000.00
0005435215243	7745	Economy	14000.00
0005435215477	7745	Economy	14000.00
0005435215109	7745	Economy	14000.00
0005435215238	7745	Economy	14000.00
0005433656760	7745	Economy	14000.00
0005435215106	7745	Economy	14000.00
0005435283513	7745	Economy	14000.00
0005433656757	7745	Economy	14000.00
0005435214841	7745	Economy	14000.00
0005435426807	5358	Business	43100.00
0005435302323	5358	Business	43100.00
0005434245746	5358	Business	43100.00
0005435426813	5358	Business	43100.00
0005435617057	5358	Business	43100.00
0005435426664	5358	Business	43100.00
0005435426806	5358	Business	43100.00
0005435305074	5358	Business	43100.00
0005435426663	5358	Business	43100.00
0005432363486	5358	Comfort	24400.00
0005435380421	5358	Comfort	24400.00
0005435426677	5358	Comfort	24400.00
0005435426487	5358	Comfort	24400.00
0005435617053	5358	Comfort	24400.00
0005434245725	5358	Comfort	24400.00
0005435426703	5358	Comfort	24400.00
0005434573777	5358	Comfort	24400.00
0005435426544	5358	Comfort	24400.00
0005434245787	5358	Comfort	24400.00
0005435305063	5358	Comfort	24400.00
0005435426451	5358	Comfort	24400.00
0005435426185	5358	Comfort	24400.00
0005435426570	5358	Comfort	24400.00
0005435426531	5358	Economy	14400.00
0005435426639	5358	Economy	14400.00
0005435042924	5358	Economy	14400.00
0005434245707	5358	Economy	14400.00
0005434345298	5358	Economy	14400.00
0005435426398	5358	Economy	14400.00
0005435426519	5358	Economy	14400.00
0005435426488	5358	Economy	14400.00
0005434245765	5358	Economy	14400.00
0005435426715	5358	Economy	14400.00
0005435426666	5358	Economy	14400.00
0005435768118	5358	Economy	14400.00
0005434245744	5358	Economy	14400.00
0005434245762	5358	Economy	14400.00
0005435426641	5358	Economy	14400.00
0005434245601	5358	Economy	14400.00
0005433719218	5358	Economy	14400.00
0005434245695	5358	Economy	14400.00
0005434245761	5358	Economy	14400.00
0005434245654	5358	Economy	14400.00
0005435426414	5358	Economy	14400.00
0005435426420	5358	Economy	14400.00
0005434245768	5358	Economy	14400.00
0005435426640	5358	Economy	15800.00
0005435426453	5358	Economy	15800.00
0005435319800	5358	Economy	14400.00
0005434245750	5358	Economy	14400.00
0005435426678	5358	Economy	14400.00
0005435426393	5358	Economy	14400.00
0005435042909	5358	Economy	14400.00
0005434245788	5358	Economy	14400.00
0005435426543	5358	Economy	14400.00
0005435305055	5358	Economy	14400.00
0005435426496	5358	Economy	14400.00
0005435302334	5358	Economy	14400.00
0005435546240	5358	Economy	14400.00
0005435042928	5358	Economy	14400.00
0005434245774	5358	Economy	14400.00
0005433719229	5358	Economy	14400.00
0005435426808	5358	Economy	14400.00
0005435426583	5358	Economy	14400.00
0005434245726	5358	Economy	14400.00
0005433719221	5358	Economy	14400.00
0005435426716	5358	Economy	14400.00
0005434245747	5358	Economy	14400.00
0005434245724	5358	Economy	14400.00
0005435426186	5358	Economy	14400.00
0005435426560	5358	Economy	14400.00
0005435426559	5358	Economy	14400.00
0005435380422	5358	Economy	14400.00
0005434245748	5358	Economy	14400.00
0005435426789	5358	Economy	14400.00
0005435617056	5358	Economy	14400.00
0005435654507	5358	Economy	14400.00
0005435426725	5358	Economy	14400.00
0005434245798	5358	Economy	14400.00
0005435380433	5358	Economy	14400.00
0005435426665	5358	Economy	14400.00
0005435654506	5358	Economy	14400.00
0005434245810	5358	Economy	14400.00
0005433719222	5358	Economy	14400.00
0005434245751	5358	Economy	14400.00
0005435426474	5358	Economy	14400.00
0005435426358	5358	Economy	14400.00
0005435380418	5358	Economy	14400.00
0005434245752	5358	Economy	14400.00
0005434245775	5358	Economy	14400.00
0005435617055	5358	Economy	14400.00
0005435426649	5358	Economy	14400.00
0005435426399	5358	Economy	14400.00
0005435617054	5358	Economy	14400.00
0005434245769	5358	Economy	14400.00
0005432363492	5358	Economy	14400.00
0005434245749	5358	Economy	14400.00
0005435426624	5358	Economy	14400.00
0005434245809	5358	Economy	14400.00
0005434245636	5358	Economy	14400.00
0005434245637	5358	Economy	14400.00
0005433719224	5358	Economy	14400.00
0005435426708	5358	Economy	14400.00
0005435426452	5358	Economy	14400.00
0005433719225	5358	Economy	14400.00
0005435426642	5358	Economy	14400.00
0005435380401	5358	Economy	14400.00
0005435426542	5358	Economy	14400.00
0005435617052	5358	Economy	14400.00
0005435426471	5358	Economy	14400.00
0005434245760	5358	Economy	14400.00
0005435319801	5358	Economy	14400.00
0005435426475	5358	Economy	14400.00
0005435042927	5358	Economy	14400.00
0005435426589	5358	Economy	14400.00
0005435426644	5358	Economy	14400.00
0005435616872	10887	Business	43100.00
0005435616633	10887	Business	43100.00
0005435616713	10887	Business	43100.00
0005435616422	10887	Business	43100.00
0005434573727	10887	Business	43100.00
0005435616781	10887	Business	43100.00
0005435616341	10887	Business	43100.00
0005435555421	10887	Business	43100.00
0005435097449	10887	Business	43100.00
0005434345095	10887	Business	43100.00
0005435616019	10887	Comfort	24400.00
0005435616598	10887	Comfort	24400.00
0005435616448	10887	Comfort	24400.00
0005435097403	10887	Comfort	24400.00
0005435616810	10887	Comfort	24400.00
0005435616727	10887	Comfort	24400.00
0005434345094	10887	Comfort	24400.00
0005435616992	10887	Comfort	24400.00
0005435616794	10887	Comfort	24400.00
0005434345069	10887	Comfort	24400.00
0005435616879	10887	Comfort	24400.00
0005434345097	10887	Comfort	24400.00
0005434345190	10887	Comfort	24400.00
0005434573636	10887	Comfort	24400.00
0005435616580	10887	Comfort	24400.00
0005434345058	10887	Comfort	24400.00
0005435616729	10887	Comfort	24400.00
0005434344958	10887	Comfort	24400.00
0005435426851	10887	Comfort	24400.00
0005434345177	10887	Comfort	24400.00
0005435097425	10887	Economy	14400.00
0005435616816	10887	Comfort	24400.00
0005435616856	10887	Economy	14400.00
0005435616993	10887	Economy	14400.00
0005435616841	10887	Economy	14400.00
0005434573741	10887	Economy	14400.00
0005434344950	10887	Economy	14400.00
0005435616857	10887	Economy	14400.00
0005435616460	10887	Economy	14400.00
0005435097441	10887	Economy	14400.00
0005435616579	10887	Economy	14400.00
0005434345016	10887	Economy	14400.00
0005435616376	10887	Economy	14400.00
0005435555415	10887	Economy	14400.00
0005435616470	10887	Economy	14400.00
0005435616528	10887	Economy	14400.00
0005435426850	10887	Economy	14400.00
0005435616624	10887	Economy	14400.00
0005434345081	10887	Economy	14400.00
0005434344905	10887	Economy	14400.00
0005435616949	10887	Economy	14400.00
0005434344951	10887	Economy	14400.00
0005434345102	10887	Economy	14400.00
0005435616782	10887	Economy	14400.00
0005435616197	10887	Economy	14400.00
0005435490323	10887	Economy	14400.00
0005434573678	10887	Economy	14400.00
0005435616339	10887	Economy	14400.00
0005435616513	10887	Economy	14400.00
0005435616196	10887	Economy	14400.00
0005435616060	10887	Economy	14400.00
0005434573664	10887	Economy	14400.00
0005435491505	10887	Economy	14400.00
0005434345055	10887	Economy	14400.00
0005435616354	10887	Economy	14400.00
0005435616353	10887	Economy	15800.00
0005435491497	10887	Economy	14400.00
0005435616051	10887	Economy	15800.00
0005434345050	10887	Economy	14400.00
0005435546237	10887	Economy	14400.00
0005435616725	10887	Economy	15800.00
0005435616020	10887	Economy	14400.00
0005435616591	10887	Economy	14400.00
0005434573657	10887	Economy	14400.00
0005435616515	10887	Economy	14400.00
0005435617187	10887	Economy	14400.00
0005434573658	10887	Economy	14400.00
0005435616950	10887	Economy	14400.00
0005435616678	10887	Economy	14400.00
0005434345082	10887	Economy	14400.00
0005435490326	10887	Economy	14400.00
0005435616523	10887	Economy	14400.00
0005435616287	10887	Economy	14400.00
0005434573665	10887	Economy	14400.00
0005435616589	10887	Economy	14400.00
0005434345174	10887	Economy	14400.00
0005435616052	10887	Economy	14400.00
0005435097429	10887	Economy	14400.00
0005435616054	10887	Economy	14400.00
0005435616945	10887	Economy	14400.00
0005435490322	10887	Economy	14400.00
0005435616525	10887	Economy	14400.00
0005434573627	10887	Economy	14400.00
0005435616881	10887	Economy	14400.00
0005434344992	10887	Economy	14400.00
0005434345098	10887	Economy	14400.00
0005435616634	10887	Economy	14400.00
0005435616842	10887	Economy	14400.00
0005435616718	10887	Economy	14400.00
0005434573693	10887	Economy	14400.00
0005435616751	10887	Economy	14400.00
0005435616375	10887	Economy	14400.00
0005434345085	10887	Economy	14400.00
0005435616766	10887	Economy	14400.00
0005435617191	10887	Economy	14400.00
0005434345032	10887	Economy	14400.00
0005435616603	10887	Economy	14400.00
0005435616679	10887	Economy	14400.00
0005435616649	10887	Economy	14400.00
0005435616817	10887	Economy	14400.00
0005435616524	10887	Economy	14400.00
0005435616535	10887	Economy	14400.00
0005434345034	10887	Economy	14400.00
0005435617188	10887	Economy	14400.00
0005435097448	10887	Economy	14400.00
0005435616266	10887	Economy	14400.00
0005434345003	10887	Economy	14400.00
0005435616871	10887	Economy	14400.00
0005435616103	10887	Economy	14400.00
0005435616602	10887	Economy	14400.00
0005434345074	10887	Economy	14400.00
0005435616858	10887	Economy	14400.00
0005435616680	10887	Economy	14400.00
0005434345086	10887	Economy	14400.00
0005435097482	10887	Economy	15800.00
0005435616815	10887	Economy	15800.00
0005435616734	10887	Economy	15800.00
0005435616578	10887	Economy	15800.00
0005435616635	10887	Economy	15800.00
0005434344874	10887	Economy	14400.00
0005435097426	10887	Economy	14400.00
0005435616671	10887	Economy	14400.00
0005435616696	10887	Economy	14400.00
0005435616811	10887	Economy	14400.00
0005434345070	10887	Economy	14400.00
0005435616870	10887	Economy	14400.00
0005435097478	10887	Economy	14400.00
0005435615622	10887	Economy	14400.00
0005435490297	10887	Economy	14400.00
0005434345019	10887	Economy	14400.00
0005435616677	10887	Economy	14400.00
0005435616660	10887	Economy	14400.00
0005434345096	10887	Economy	14400.00
0005435616433	10887	Economy	14400.00
0005435616795	10887	Economy	14400.00
0005434345079	10887	Economy	14400.00
0005435616733	10887	Economy	14400.00
0005435616421	10887	Economy	14400.00
0005435616434	10887	Economy	14400.00
0005434344873	10887	Economy	14400.00
0005435490321	10887	Economy	14400.00
0005435616514	10887	Economy	14400.00
0005435616919	10887	Economy	14400.00
0005435616530	10887	Economy	14400.00
0005435616377	10887	Economy	14400.00
0005434344977	10887	Economy	14400.00
0005435616912	10887	Economy	14400.00
0005434345148	10887	Economy	14400.00
0005435616785	10887	Economy	14400.00
0005435616018	10887	Economy	14400.00
0005434345015	10887	Economy	14400.00
0005435617196	10887	Economy	14400.00
0005434345156	10887	Economy	14400.00
0005435616053	10887	Economy	14400.00
0005434345099	10887	Economy	14400.00
0005435616404	10887	Economy	14400.00
0005435616547	10887	Economy	14400.00
0005434345209	10887	Economy	14400.00
0005434344986	10887	Economy	14400.00
0005435426849	10887	Economy	14400.00
0005435616438	10887	Economy	14400.00
0005435616566	10887	Economy	14400.00
0005435616042	10887	Economy	14400.00
0005434344904	10887	Economy	14400.00
0005434345071	10887	Economy	14400.00
0005435615621	10887	Economy	14400.00
0005434573690	10887	Economy	14400.00
0005434345089	10887	Economy	14400.00
0005435616546	10887	Economy	14400.00
0005434345189	10887	Economy	14400.00
0005435616257	10887	Economy	14400.00
0005435616643	10887	Economy	14400.00
0005434345035	10887	Economy	14400.00
0005435616403	10887	Economy	14400.00
0005434345073	10887	Economy	14400.00
0005434245848	10887	Economy	14400.00
0005435856342	3308	Business	18800.00
0005432182372	3308	Business	18800.00
0005432460956	3308	Business	18800.00
0005434326094	3308	Business	18800.00
0005435860683	3308	Business	18800.00
0005432461222	3308	Business	18800.00
0005432461223	3308	Business	18800.00
0005435858702	3308	Business	18800.00
0005432461197	3308	Business	18800.00
0005432461019	3308	Business	18800.00
0005432461060	3308	Business	18800.00
0005435142981	3308	Business	18800.00
0005432461252	3308	Business	18800.00
0005435860684	3308	Business	18800.00
0005432461126	3308	Business	18800.00
0005432461062	3308	Business	18800.00
0005432461043	3308	Business	18800.00
0005432461383	3308	Economy	6900.00
0005434150236	3308	Economy	6900.00
0005432461143	3308	Economy	6900.00
0005432461232	3308	Economy	6300.00
0005432461270	3308	Economy	6300.00
0005435858729	3308	Economy	6300.00
0005432460910	3308	Economy	6300.00
0005435860699	3308	Economy	6300.00
0005435860677	3308	Economy	6300.00
0005432461218	3308	Economy	6300.00
0005432461290	3308	Economy	6300.00
0005432461018	3308	Economy	6300.00
0005435860715	3308	Economy	6300.00
0005432461171	3308	Economy	6300.00
0005432461289	3308	Economy	6300.00
0005435933572	3308	Economy	6300.00
0005432461283	3308	Economy	6300.00
0005432461045	3308	Economy	6300.00
0005435142983	3308	Economy	6300.00
0005435860700	3308	Economy	6300.00
0005432461113	3308	Economy	6300.00
0005435858707	3308	Economy	6300.00
0005434326055	3308	Economy	6300.00
0005432461231	3308	Economy	6300.00
0005435856345	3308	Economy	6300.00
0005434266053	3308	Economy	6300.00
0005432461121	3308	Economy	6300.00
0005432461251	3308	Economy	6300.00
0005432461058	3308	Economy	6300.00
0005432461142	3308	Economy	6300.00
0005432461174	3308	Economy	6300.00
0005432460957	3308	Economy	6300.00
0005434326096	3308	Economy	6300.00
0005432461092	3308	Economy	6300.00
0005435142972	3308	Economy	6300.00
0005432461130	3308	Economy	6300.00
0005432461288	3308	Economy	6300.00
0005434312389	3308	Economy	6300.00
0005434326093	3308	Economy	6300.00
0005432182373	3308	Economy	6300.00
0005435858708	3308	Economy	6900.00
0005432461046	3308	Economy	6900.00
0005432461180	3308	Economy	6900.00
0005432461224	3308	Economy	6300.00
0005434312387	3308	Economy	6900.00
0005435860676	3308	Economy	6300.00
0005432461141	3308	Economy	6300.00
0005432461005	3308	Economy	6900.00
0005432461070	3308	Economy	6300.00
0005432461233	3308	Economy	6300.00
0005432461069	3308	Economy	6300.00
0005434266052	3308	Economy	6300.00
0005432461326	3308	Economy	6300.00
0005432461083	3308	Economy	6300.00
0005432461247	3308	Economy	6300.00
0005432461287	3308	Economy	6300.00
0005432461105	3308	Economy	6300.00
0005432460911	3308	Economy	6300.00
0005432460958	3308	Economy	6300.00
0005435858701	3308	Economy	6300.00
0005432461211	3308	Economy	6300.00
0005434266051	3308	Economy	6300.00
0005432460849	3308	Economy	6300.00
0005435860674	3308	Economy	6300.00
0005435860669	3308	Economy	6300.00
0005432461341	3308	Economy	6300.00
0005432461265	3308	Economy	6300.00
0005433634829	3308	Economy	6300.00
0005432461044	3308	Economy	6300.00
0005432461067	3308	Economy	6300.00
0005432461059	3308	Economy	6300.00
0005432461250	3308	Economy	6300.00
0005432461246	3308	Economy	6300.00
0005434150235	3308	Economy	6300.00
0005434312390	3308	Economy	6300.00
0005432461166	3308	Economy	6300.00
0005432460848	3308	Economy	6300.00
0005432461084	3308	Economy	6300.00
0005432461173	3308	Economy	6300.00
0005432461230	3308	Economy	6300.00
0005435856344	3308	Economy	6300.00
0005435860680	3308	Economy	6300.00
0005433634830	3308	Economy	6300.00
0005435886549	3309	Business	18800.00
0005435886745	3309	Business	18800.00
0005435886439	3309	Business	18800.00
0005435886381	3309	Business	18800.00
0005435886372	3309	Business	18800.00
0005435886613	3309	Business	18800.00
0005435886632	3309	Business	18800.00
0005435903222	3309	Business	18800.00
0005435886512	3309	Business	18800.00
0005435886674	3309	Business	18800.00
0005435886440	3309	Business	18800.00
0005435886671	3309	Business	18800.00
0005435886763	3309	Economy	6900.00
0005435886762	3309	Economy	6300.00
0005435886715	3309	Economy	6300.00
0005435886438	3309	Economy	6300.00
0005435886838	3309	Economy	6300.00
0005435886346	3309	Economy	6300.00
0005435886525	3309	Economy	6300.00
0005435886650	3309	Economy	6300.00
0005435886437	3309	Economy	6300.00
0005435886371	3309	Economy	6300.00
0005435886716	3309	Economy	6300.00
0005435886562	3309	Economy	6300.00
0005435886746	3309	Economy	6300.00
0005435886797	3309	Economy	6300.00
0005435886772	3309	Economy	6300.00
0005435886689	3309	Economy	6300.00
0005435886571	3309	Economy	6300.00
0005435886748	3309	Economy	6300.00
0005435886839	3309	Economy	6300.00
0005435886764	3309	Economy	6300.00
0005435886840	3309	Economy	6900.00
0005435886608	3309	Economy	6900.00
0005435886611	3309	Economy	6300.00
0005435886796	3309	Economy	6300.00
0005435886456	3309	Economy	6300.00
0005435886634	3309	Economy	6300.00
0005435886460	3309	Economy	6300.00
0005435886732	3309	Economy	6300.00
0005435886646	3309	Economy	6300.00
0005435886543	3309	Economy	6300.00
0005435886741	3309	Economy	6300.00
0005435886459	3309	Economy	6300.00
0005435886441	3309	Economy	6300.00
0005435886574	3309	Economy	6300.00
0005435886785	3309	Economy	6300.00
0005435886519	3309	Economy	6300.00
0005435886731	3309	Economy	6300.00
0005435886690	3309	Economy	6300.00
0005435886768	3309	Economy	6300.00
0005435886672	3309	Economy	6300.00
0005435886627	3309	Economy	6300.00
0005435886587	3309	Economy	6300.00
0005435886633	3309	Economy	6300.00
0005435886607	3309	Economy	6300.00
0005435886477	3309	Economy	6300.00
0005435886666	3309	Economy	6300.00
0005435886373	3309	Economy	6300.00
0005433507664	8324	Business	18800.00
0005432461442	8324	Business	18800.00
0005433507638	8324	Business	18800.00
0005433507655	8324	Business	18800.00
0005433507654	8324	Economy	6900.00
0005433507720	8324	Business	18800.00
0005435886871	8324	Economy	6300.00
0005433507696	8324	Economy	6300.00
0005433507691	8324	Economy	6300.00
0005433507661	8324	Economy	6300.00
0005433507689	8324	Economy	6300.00
0005432461443	8324	Economy	6300.00
0005433507695	8324	Economy	6300.00
0005433507665	8324	Economy	6300.00
0005432461444	8324	Economy	6300.00
0005433806229	8331	Business	18800.00
0005433806235	8331	Business	18800.00
0005433806244	8331	Business	18800.00
0005433806352	8331	Business	18800.00
0005433806236	8331	Business	18800.00
0005434143771	8331	Business	18800.00
0005433806324	8331	Business	18800.00
0005433806155	8331	Business	18800.00
0005433806294	8331	Business	18800.00
0005433634678	8331	Economy	6900.00
0005433806245	8331	Economy	6900.00
0005433806311	8331	Economy	6900.00
0005433634675	8331	Economy	6300.00
0005433634651	8331	Economy	6300.00
0005433806310	8331	Economy	6300.00
0005433806256	8331	Economy	6300.00
0005433806224	8331	Economy	6300.00
0005434143791	8331	Economy	6300.00
0005433806276	8331	Economy	6300.00
0005433806042	8331	Economy	6300.00
0005433634549	8331	Economy	6300.00
0005433634716	8331	Economy	6300.00
0005433806257	8331	Economy	6300.00
0005434143805	8331	Economy	6300.00
0005433634715	8331	Economy	6300.00
0005433634733	8331	Economy	6300.00
0005433634695	8331	Economy	6300.00
0005433806228	8331	Economy	6300.00
0005433634652	8331	Economy	6300.00
0005433634565	8331	Economy	6300.00
0005434271366	8331	Economy	6300.00
0005433806206	8331	Economy	6300.00
0005433806342	8331	Economy	6300.00
0005433634718	8331	Economy	6300.00
0005433806154	8331	Economy	6300.00
0005433634741	8331	Economy	6300.00
0005433806356	8331	Economy	6300.00
0005433806259	8331	Economy	6300.00
0005433634563	8331	Economy	6300.00
0005434271368	8331	Economy	6300.00
0005433634804	8331	Economy	6300.00
0005433634610	8331	Economy	6300.00
0005434143770	8331	Economy	6900.00
0005433806293	8331	Economy	6300.00
0005434143790	8331	Economy	6300.00
0005433634603	8331	Economy	6300.00
0005433634744	8331	Economy	6300.00
0005433634742	8331	Economy	6300.00
0005433634717	8331	Economy	6300.00
0005433634658	8331	Economy	6300.00
0005433806183	8331	Economy	6300.00
0005434271365	8331	Economy	6300.00
0005434143773	8331	Economy	6300.00
0005433806341	8331	Economy	6300.00
0005433634754	8331	Economy	6300.00
0005433634668	8331	Economy	6300.00
0005433806205	8331	Economy	6300.00
0005434143753	8331	Economy	6300.00
0005433806323	8331	Economy	6300.00
0005434143780	8331	Economy	6300.00
0005433634752	8331	Economy	6300.00
0005433634566	8331	Economy	6300.00
0005434143772	8331	Economy	6300.00
0005433634649	8331	Economy	6300.00
0005433806158	8331	Economy	6300.00
0005433634667	8331	Economy	6300.00
0005433806115	8331	Economy	6300.00
0005433634709	8331	Economy	6300.00
0005434271367	8331	Economy	6300.00
0005433634562	8331	Economy	6300.00
0005433806043	8331	Economy	6300.00
0005433806277	8331	Economy	6300.00
0005433634743	8331	Economy	6300.00
0005433634625	8331	Economy	6300.00
0005433634734	8331	Economy	6300.00
0005433634740	8331	Economy	6300.00
0005433634681	8331	Economy	6300.00
0005433634753	8331	Economy	6300.00
0005433806351	8331	Economy	6300.00
0005433806156	8331	Economy	6300.00
0005434183635	8336	Business	18800.00
0005434183637	8336	Economy	6900.00
0005434150155	8336	Economy	6300.00
0005434150165	8336	Economy	6300.00
0005434183636	8336	Economy	6300.00
0005434150145	8336	Economy	6300.00
0005434150207	8336	Economy	6300.00
0005434150166	8336	Economy	6300.00
0005434150167	8336	Economy	6300.00
0005434230045	8336	Economy	6300.00
0005434150208	8336	Economy	6300.00
0005433722513	4573	Economy	3300.00
0005433195016	4573	Economy	3300.00
0005432728313	4573	Economy	3300.00
0005433195017	4573	Economy	3300.00
0005433722514	4573	Economy	3300.00
0005433453814	30234	Business	9900.00
0005432384008	30234	Business	9900.00
0005432384153	30234	Business	9900.00
0005432384077	30234	Business	9900.00
0005432728295	30234	Business	9900.00
0005432383919	30234	Business	9900.00
0005432728297	30234	Business	9900.00
0005433722388	30234	Business	9900.00
0005432384265	30234	Business	9900.00
0005432384061	30234	Business	9900.00
0005432383823	30234	Business	9900.00
0005432728233	30234	Economy	3300.00
0005433722391	30234	Economy	3300.00
0005432384135	30234	Economy	3300.00
0005432728275	30234	Economy	3300.00
0005432384025	30234	Economy	3300.00
0005432384194	30234	Economy	3300.00
0005432383931	30234	Economy	3300.00
0005432383862	30234	Economy	3300.00
0005432384150	30234	Economy	3300.00
0005433722355	30234	Economy	3600.00
0005432728274	30234	Economy	3600.00
0005432384069	30234	Economy	3300.00
0005432728273	30234	Economy	3300.00
0005432728272	30234	Economy	3300.00
0005432384189	30234	Economy	3300.00
0005432383961	30234	Economy	3300.00
0005432384052	30234	Economy	3300.00
0005432384034	30234	Economy	3300.00
0005432728224	30234	Economy	3300.00
0005433194972	30234	Economy	3300.00
0005432728265	30234	Economy	3300.00
0005432384046	30234	Economy	3300.00
0005432384026	30234	Economy	3300.00
0005432728244	30234	Economy	3300.00
0005432728276	30234	Economy	3300.00
0005432384230	30234	Economy	3300.00
0005432384152	30234	Economy	3300.00
0005432384070	30234	Economy	3300.00
0005432384009	30234	Economy	3300.00
0005432728271	30234	Economy	3300.00
0005432384054	30234	Economy	3300.00
0005432383999	30234	Economy	3300.00
0005432384188	30234	Economy	3300.00
0005432383960	30234	Economy	3300.00
0005433722399	30234	Economy	3300.00
0005432384249	30234	Economy	3300.00
0005432384010	30234	Economy	3300.00
0005432384076	30234	Economy	3300.00
0005432384154	30234	Economy	3300.00
0005432383928	30234	Economy	3300.00
0005432728243	30234	Economy	3300.00
0005432384117	30234	Economy	3300.00
0005432384197	30234	Economy	3300.00
0005432384149	30234	Economy	3300.00
0005432383987	30234	Economy	3300.00
0005432384051	30234	Economy	3300.00
0005432384266	30234	Economy	3300.00
0005432384006	30234	Economy	3300.00
0005432384029	30234	Economy	3300.00
0005432383918	30234	Economy	3300.00
0005433722398	30234	Economy	3300.00
0005432383917	30234	Economy	3300.00
0005433451673	30234	Economy	3300.00
0005432383941	30234	Economy	3300.00
0005433453811	30234	Economy	3300.00
0005433722370	30234	Economy	3300.00
0005432384033	30234	Economy	3300.00
0005433194954	30234	Economy	3300.00
0005432384055	30234	Economy	3300.00
0005433722392	30234	Economy	3300.00
0005432384007	30234	Economy	3300.00
0005432294561	1765	Business	57200.00
0005432925162	1765	Economy	19100.00
0005432925158	1765	Economy	19100.00
0005435530199	1765	Economy	19100.00
0005432925163	1765	Economy	19100.00
0005432925157	1765	Economy	19100.00
0005432925156	1765	Economy	19100.00
0005435530200	1765	Economy	19100.00
0005435530198	1765	Economy	19100.00
0005435518428	21996	Business	57200.00
0005435541533	21996	Business	57200.00
0005435541495	21996	Business	57200.00
0005435518369	21996	Business	57200.00
0005433517113	21996	Business	57200.00
0005435518412	21996	Business	57200.00
0005435518368	21996	Economy	19100.00
0005435541506	21996	Economy	19100.00
0005435518359	21996	Economy	19100.00
0005435518400	21996	Economy	19100.00
0005435518386	21996	Economy	19100.00
0005435518327	21996	Economy	19100.00
0005435541432	21996	Economy	19100.00
0005435518367	21996	Economy	21000.00
0005435518364	21996	Economy	19100.00
0005435541578	21996	Economy	19100.00
0005435541560	21996	Economy	19100.00
0005435541458	21996	Economy	19100.00
0005435518417	21996	Economy	19100.00
0005435541587	21996	Economy	19100.00
0005435518423	21996	Economy	19100.00
0005435518328	21996	Economy	19100.00
0005435518418	21996	Economy	19100.00
0005435518358	21996	Economy	19100.00
0005433517141	21996	Economy	19100.00
0005435541586	21996	Economy	19100.00
0005435541559	21996	Economy	19100.00
0005435518339	21996	Economy	19100.00
0005435541614	21996	Economy	19100.00
0005435518430	21996	Economy	19100.00
0005435541613	21996	Economy	19100.00
0005435518419	21996	Economy	19100.00
0005433517117	21996	Economy	19100.00
0005435541545	21996	Economy	19100.00
0005433517116	21996	Economy	19100.00
0005435541459	21996	Economy	19100.00
0005435518387	21996	Economy	19100.00
0005435541544	21996	Economy	19100.00
0005435518427	21996	Economy	19100.00
0005435541490	21996	Economy	19100.00
0005435541491	21996	Economy	19100.00
0005435518393	21996	Economy	19100.00
0005435541572	21996	Economy	19100.00
0005435541449	21996	Economy	19100.00
0005435541574	21996	Economy	19100.00
0005433517152	21996	Economy	19100.00
0005435541492	21996	Economy	19100.00
0005435518405	21996	Economy	19100.00
0005435541567	21996	Economy	19100.00
0005433517118	21996	Economy	19100.00
0005435541493	21996	Economy	19100.00
0005435518431	21996	Economy	19100.00
0005435541568	21996	Economy	19100.00
0005435541583	21996	Economy	19100.00
0005435518413	21996	Economy	19100.00
0005435491490	7355	Business	18500.00
0005435253160	7355	Business	18500.00
0005435253196	7355	Business	18500.00
0005435253203	7355	Business	18500.00
0005434665019	7355	Economy	6200.00
0005434665020	7355	Economy	6200.00
0005435253195	7355	Economy	6200.00
0005435253184	7355	Economy	6200.00
0005435253183	7355	Economy	6200.00
0005435253144	7355	Economy	6200.00
0005435491491	7355	Economy	6200.00
0005435253161	7355	Economy	6200.00
0005435491503	7355	Economy	6200.00
0005435253173	7355	Economy	6200.00
0005435253163	7355	Economy	6200.00
0005434665018	7355	Economy	6200.00
0005435253133	7355	Economy	6200.00
0005435253145	7355	Economy	6200.00
0005432839941	7355	Economy	6200.00
0005432839842	28924	Business	18500.00
0005432839875	28924	Business	18500.00
0005432839879	28924	Business	18500.00
0005434459270	28924	Business	18500.00
0005434459271	28924	Business	18500.00
0005432839815	28924	Business	18500.00
0005434459226	28924	Business	18500.00
0005435253222	28924	Economy	6200.00
0005434459305	28924	Economy	6200.00
0005434459356	28924	Economy	6800.00
0005434459370	28924	Economy	6200.00
0005432839874	28924	Economy	6200.00
0005434459281	28924	Economy	6200.00
0005434459236	28924	Economy	6200.00
0005434459237	28924	Economy	6200.00
0005432839814	28924	Economy	6200.00
0005432841063	28924	Economy	6200.00
0005432841062	28924	Economy	6200.00
0005434459285	28924	Economy	6200.00
0005434459346	28924	Economy	6200.00
0005434459371	28924	Economy	6200.00
0005434459381	28924	Economy	6200.00
0005432839893	28924	Economy	6200.00
0005432839820	28924	Economy	6200.00
0005434459397	28924	Economy	6200.00
0005434459345	28924	Economy	6200.00
0005434459369	28924	Economy	6200.00
0005432839818	28924	Economy	6200.00
0005435253221	28924	Economy	6200.00
0005432839793	28924	Economy	6200.00
0005432839799	28924	Economy	6200.00
0005434459282	28924	Economy	6200.00
0005434459355	28924	Economy	6200.00
0005432839895	28924	Economy	6200.00
0005432839805	28924	Economy	6200.00
0005432839822	28924	Economy	6200.00
0005434459357	28924	Economy	6200.00
0005432839819	28924	Economy	6200.00
0005434459324	28924	Economy	6200.00
0005434459339	28924	Economy	6200.00
0005432839894	28924	Economy	6200.00
0005434459394	28924	Economy	6200.00
0005434276178	8800	Business	145300.00
0005434276179	8800	Economy	48400.00
0005434276189	8800	Economy	48400.00
0005435990797	15716	Economy	48400.00
0005435990801	15716	Economy	53300.00
0005435990811	15716	Economy	48400.00
0005435990806	15716	Economy	48400.00
0005435990805	15716	Economy	48400.00
0005435990794	15716	Economy	48400.00
0005435990800	15716	Economy	48400.00
0005435990791	15716	Economy	48400.00
0005435990792	15716	Economy	48400.00
0005435990793	15716	Economy	48400.00
0005432909435	2097	Economy	13300.00
0005432909407	2097	Economy	12100.00
0005432909422	2097	Economy	12100.00
0005432909410	2097	Economy	12100.00
0005432909432	2097	Economy	12100.00
0005432909436	2097	Economy	12100.00
0005432909443	23854	Economy	13300.00
0005433468565	23854	Economy	13300.00
0005433468566	23854	Economy	13300.00
0005432909440	23854	Economy	12100.00
0005432909444	23854	Economy	12100.00
0005433468518	23854	Economy	12100.00
0005433468536	23854	Economy	12100.00
0005433468559	23854	Economy	12100.00
0005433468576	23854	Economy	12100.00
0005433468556	23854	Economy	12100.00
0005433468516	23854	Economy	12100.00
0005432909441	23854	Economy	12100.00
0005433468564	23854	Economy	12100.00
0005433468535	23854	Economy	12100.00
0005433468544	23854	Economy	12100.00
0005432909442	23854	Economy	12100.00
0005433468552	23854	Economy	12100.00
0005433468558	23854	Economy	12100.00
0005433468534	23854	Economy	12100.00
0005433468563	23854	Economy	12100.00
0005433468567	23854	Economy	12100.00
0005433468551	23854	Economy	12100.00
0005433468547	23854	Economy	12100.00
0005433468553	23854	Economy	12100.00
0005433468550	23854	Economy	12100.00
0005433468541	23854	Economy	12100.00
0005433468560	23854	Economy	12100.00
0005433468533	23854	Economy	12100.00
0005433468543	23854	Economy	12100.00
0005433468575	23854	Economy	12100.00
0005434150011	6389	Business	36600.00
0005435490322	6389	Business	36600.00
0005435177855	6389	Business	36600.00
0005434150060	6389	Business	36600.00
0005435490321	6389	Business	36600.00
0005435177839	6389	Economy	12200.00
0005435177853	6389	Economy	12200.00
0005434149996	6389	Economy	12200.00
0005435177816	6389	Economy	12200.00
0005435177818	6389	Economy	12200.00
0005434150012	6389	Economy	12200.00
0005435490326	6389	Economy	12200.00
0005435177806	6389	Economy	12200.00
0005435177817	6389	Economy	12200.00
0005434149982	6389	Economy	12200.00
0005435177845	6389	Economy	12200.00
0005435177846	6389	Economy	12200.00
0005435490323	6389	Economy	12200.00
0005435177769	6389	Economy	12200.00
0005435177815	6389	Economy	12200.00
0005435723097	6389	Economy	13400.00
0005435723096	6389	Economy	12200.00
0005434150062	6389	Economy	12200.00
0005435177852	6389	Economy	12200.00
0005435177770	6389	Economy	12200.00
0005434150048	6389	Economy	12200.00
0005435177854	6389	Economy	12200.00
0005434150003	6389	Economy	12200.00
0005435177830	6389	Economy	12200.00
0005435177805	6389	Economy	12200.00
0005435490297	6389	Economy	12200.00
0005435177740	6389	Economy	12200.00
0005434150061	6389	Economy	12200.00
0005435177680	6389	Economy	12200.00
0005435723098	6389	Economy	12200.00
0005434150004	6389	Economy	12200.00
0005434149997	6389	Economy	12200.00
0005435177833	6389	Economy	12200.00
0005434150056	6389	Economy	12200.00
0005435177767	6389	Economy	12200.00
0005435177685	6389	Economy	12200.00
0005435177835	6389	Economy	12200.00
0005432336318	21035	Business	36600.00
0005432361469	21035	Business	36600.00
0005432336335	21035	Business	36600.00
0005432361583	21035	Business	36600.00
0005432361586	21035	Business	36600.00
0005432361584	21035	Economy	12200.00
0005432361614	21035	Economy	12200.00
0005432361738	21035	Economy	12200.00
0005432361545	21035	Economy	12200.00
0005432361422	21035	Economy	12200.00
0005432361642	21035	Economy	12200.00
0005432361617	21035	Economy	12200.00
0005432361615	21035	Economy	12200.00
0005432361508	21035	Economy	12200.00
0005432361553	21035	Economy	12200.00
0005432361660	21035	Economy	12200.00
0005432363508	21035	Economy	12200.00
0005432361565	21035	Economy	12200.00
0005432336326	21035	Economy	12200.00
0005432336319	21035	Economy	12200.00
0005432361475	21035	Economy	12200.00
0005432336343	21035	Economy	12200.00
0005432361612	21035	Economy	12200.00
0005432361611	21035	Economy	12200.00
0005432361468	21035	Economy	12200.00
0005432336356	21035	Economy	12200.00
0005432361567	21035	Economy	13400.00
0005432361661	21035	Economy	13400.00
0005432361616	21035	Economy	12200.00
0005432336348	21035	Economy	12200.00
0005432361277	21035	Economy	12200.00
0005432361696	21035	Economy	12200.00
0005432361400	21035	Economy	12200.00
0005432336345	21035	Economy	12200.00
0005432336357	21035	Economy	12200.00
0005432336352	21035	Economy	12200.00
0005432336333	21035	Economy	12200.00
0005432361552	21035	Economy	12200.00
0005432363490	21035	Economy	12200.00
0005432361651	21035	Economy	12200.00
0005432363507	21035	Economy	12200.00
0005432361566	21035	Economy	12200.00
0005432361652	21035	Economy	12200.00
0005432361639	21035	Economy	12200.00
0005432361610	21035	Economy	12200.00
0005432361572	21035	Economy	12200.00
0005432361585	21035	Economy	12200.00
0005432361601	21035	Economy	12200.00
0005432361478	21035	Economy	12200.00
0005432361573	21035	Economy	12200.00
0005432336332	21035	Economy	12200.00
0005432336342	21035	Economy	12200.00
0005432361624	21035	Economy	12200.00
0005432361459	21035	Economy	12200.00
0005432361631	21035	Economy	12200.00
0005432336307	21035	Economy	12200.00
0005432361476	21035	Economy	12200.00
0005432361551	21035	Economy	12200.00
0005432361700	21035	Economy	12200.00
0005434459312	17702	Economy	3400.00
0005434459321	17702	Economy	3400.00
0005434461707	17702	Economy	3400.00
0005434459252	17702	Economy	3400.00
0005434459319	17702	Economy	3100.00
0005434448385	17702	Economy	3100.00
0005434463989	17702	Economy	3100.00
0005434448384	17702	Economy	3100.00
0005434459365	17702	Economy	3100.00
0005434459320	17702	Economy	3100.00
0005434459386	17702	Economy	3100.00
0005434459385	17702	Economy	3100.00
0005434461694	17702	Economy	3100.00
0005434463990	17702	Economy	3100.00
0005434448401	17702	Economy	3100.00
0005434448398	17702	Economy	3100.00
0005434459384	17702	Economy	3100.00
0005434459376	17702	Economy	3100.00
0005434459286	17702	Economy	3100.00
0005434459276	17702	Economy	3100.00
0005434459313	17702	Economy	3100.00
0005434459387	17702	Economy	3100.00
0005434459379	17702	Economy	3100.00
0005434459344	17702	Economy	3100.00
0005434459323	17702	Economy	3100.00
0005434463988	17702	Economy	3100.00
0005434463991	17702	Economy	3100.00
0005434459378	17702	Economy	3100.00
0005434459358	17702	Economy	3100.00
0005434459238	17702	Economy	3100.00
0005434459352	17702	Economy	3100.00
0005434186274	29094	Economy	3100.00
0005434186268	29094	Economy	3100.00
0005434186272	29094	Economy	3100.00
0005434186275	29094	Economy	3100.00
0005434186270	29094	Economy	3100.00
0005435220512	21466	Economy	6600.00
0005432605509	21466	Economy	6600.00
0005432605508	21466	Economy	6600.00
0005432605513	21466	Economy	6600.00
0005432605511	21466	Economy	6600.00
0005435220509	21466	Economy	6600.00
0005435220511	21466	Economy	6600.00
0005435218132	21466	Economy	6600.00
0005432605510	21466	Economy	6600.00
0005432605514	21466	Economy	6600.00
0005435220518	21466	Economy	6600.00
0005435220517	21466	Economy	6600.00
0005432605512	21466	Economy	6600.00
0005435218134	21466	Economy	6600.00
0005435218135	21466	Economy	6600.00
0005432605294	31691	Economy	7300.00
0005432605305	31691	Economy	7300.00
0005432605375	31691	Economy	7300.00
0005432605340	31691	Economy	6600.00
0005432605320	31691	Economy	6600.00
0005432605371	31691	Economy	6600.00
0005432605417	31691	Economy	6600.00
0005432605325	31691	Economy	6600.00
0005432605110	31691	Economy	6600.00
0005432605319	31691	Economy	6600.00
0005432605346	31691	Economy	6600.00
0005432605304	31691	Economy	6600.00
0005432605111	31691	Economy	6600.00
0005432605297	31691	Economy	6600.00
0005432605345	31691	Economy	6600.00
0005432605384	31691	Economy	6600.00
0005432605239	31691	Economy	6600.00
0005432605454	31691	Economy	6600.00
0005432605341	31691	Economy	6600.00
0005432605333	31691	Economy	6600.00
0005432605359	31691	Economy	6600.00
0005432605360	31691	Economy	6600.00
0005432605408	31691	Economy	6600.00
0005432605326	31691	Economy	6600.00
0005432605365	31691	Economy	6600.00
0005432605335	31691	Economy	6600.00
0005432605334	31691	Economy	6600.00
0005432605296	31691	Economy	6600.00
0005432605418	31691	Economy	6600.00
0005432605303	31691	Economy	6600.00
0005432605339	31691	Economy	6600.00
0005432605295	31691	Economy	6600.00
0005435154651	29610	Economy	19500.00
0005435154656	29610	Economy	17800.00
0005435154660	29610	Economy	17800.00
0005435154644	29610	Economy	17800.00
0005435154665	29610	Economy	17800.00
0005435154650	29610	Economy	17800.00
0005435154657	29610	Economy	17800.00
0005435154643	29610	Economy	17800.00
0005435154664	29610	Economy	17800.00
0005433293444	29610	Economy	17800.00
0005435154645	29610	Economy	17800.00
0005435154689	29610	Economy	17800.00
0005435154668	29610	Economy	17800.00
0005435154673	29610	Economy	17800.00
0005435154669	29610	Economy	17800.00
0005435154636	29610	Economy	17800.00
0005435257336	6672	Economy	14000.00
0005435257335	6672	Economy	12700.00
0005435257370	6672	Economy	12700.00
0005435257334	6672	Economy	12700.00
0005435257371	6672	Economy	12700.00
0005435257347	6672	Economy	12700.00
0005435257364	6672	Economy	12700.00
0005435257363	6672	Economy	12700.00
0005433473463	23899	Economy	14000.00
0005433473424	23899	Economy	14000.00
0005433473517	23899	Economy	12700.00
0005433473500	23899	Economy	12700.00
0005433473473	23899	Economy	12700.00
0005433473510	23899	Economy	12700.00
0005433473516	23899	Economy	12700.00
0005433473462	23899	Economy	12700.00
0005433473479	23899	Economy	12700.00
0005435257390	23899	Economy	12700.00
0005433473527	23899	Economy	12700.00
0005433473472	23899	Economy	12700.00
0005433473481	23899	Economy	12700.00
0005433473490	23899	Economy	12700.00
0005433473526	23899	Economy	12700.00
0005433473512	23899	Economy	12700.00
0005433473514	23899	Economy	12700.00
0005433473509	23899	Economy	12700.00
0005433473513	23899	Economy	12700.00
0005433473521	23899	Economy	12700.00
0005433473491	23899	Economy	12700.00
0005433473477	23899	Economy	12700.00
0005433473486	23899	Economy	12700.00
0005433473518	23899	Economy	12700.00
0005433473470	23899	Economy	12700.00
0005433473499	23899	Economy	12700.00
0005433473476	23899	Economy	12700.00
0005433473528	23899	Economy	12700.00
0005433473511	23899	Economy	12700.00
0005434606928	18821	Economy	6600.00
0005434606902	18821	Economy	6600.00
0005435904730	18821	Economy	6600.00
0005434606915	18821	Economy	6600.00
0005434603023	18821	Economy	6600.00
0005434606916	18821	Economy	6600.00
0005435904474	3857	Economy	24900.00
0005435904459	3857	Economy	24900.00
0005435904488	3857	Economy	22600.00
0005435904723	3857	Economy	22600.00
0005435904461	3857	Economy	22600.00
0005435904460	3857	Economy	22600.00
0005435904468	3857	Economy	22600.00
0005435904464	3857	Economy	22600.00
0005435904473	3857	Economy	22600.00
0005435904465	3857	Economy	22600.00
0005435904487	3857	Economy	22600.00
0005435904466	3857	Economy	22600.00
0005434604995	19045	Economy	24900.00
0005434602970	19045	Economy	22600.00
0005434522545	19045	Economy	22600.00
0005434604994	19045	Economy	22600.00
0005434522546	19045	Economy	22600.00
0005434604966	19045	Economy	22600.00
0005434602961	19045	Economy	22600.00
0005434604974	19045	Economy	22600.00
0005434604977	19045	Economy	22600.00
0005434522540	19045	Economy	22600.00
0005434602954	19045	Economy	22600.00
0005434604993	19045	Economy	22600.00
0005434522544	19045	Economy	22600.00
0005434522536	19045	Economy	22600.00
0005434522534	19045	Economy	22600.00
0005434602962	19045	Economy	22600.00
0005434522539	19045	Economy	22600.00
0005434604996	19045	Economy	22600.00
0005434604978	19045	Economy	22600.00
0005434602955	19045	Economy	22600.00
0005434522523	19045	Economy	22600.00
0005434602966	19045	Economy	22600.00
0005434602965	19045	Economy	22600.00
0005432748683	402	Business	44500.00
0005432891422	402	Business	44500.00
0005432891557	402	Business	44500.00
0005433293408	402	Business	44500.00
0005433293409	402	Economy	14800.00
0005433293396	402	Economy	14800.00
0005434152859	402	Economy	14800.00
0005432891536	402	Economy	14800.00
0005433293413	402	Economy	14800.00
0005432891526	402	Economy	14800.00
0005432891515	402	Economy	14800.00
0005432891516	402	Economy	14800.00
0005434152858	402	Economy	14800.00
0005432891556	402	Economy	14800.00
0005432891555	402	Economy	14800.00
0005432891533	402	Economy	14800.00
0005432891534	402	Economy	14800.00
0005433293412	402	Economy	14800.00
0005432891508	402	Economy	14800.00
0005433293405	402	Economy	14800.00
0005432891535	402	Economy	14800.00
0005432891509	402	Economy	14800.00
0005432891423	402	Economy	14800.00
0005433875424	402	Economy	14800.00
0005434152857	402	Economy	14800.00
0005433293422	402	Economy	14800.00
0005432891481	402	Economy	14800.00
0005434152860	402	Economy	14800.00
0005433875423	402	Economy	14800.00
0005432748485	12092	Business	44500.00
0005432748619	12092	Business	44500.00
0005432748577	12092	Business	44500.00
0005432748483	12092	Business	44500.00
0005432753387	12092	Business	44500.00
0005432756934	12092	Economy	14800.00
0005432756932	12092	Economy	14800.00
0005432748633	12092	Economy	14800.00
0005432756924	12092	Economy	16300.00
0005432756926	12092	Economy	16300.00
0005432748527	12092	Economy	14800.00
0005432748600	12092	Economy	14800.00
0005432753393	12092	Economy	14800.00
0005432749848	12092	Economy	14800.00
0005432748613	12092	Economy	14800.00
0005432748618	12092	Economy	14800.00
0005432748630	12092	Economy	14800.00
0005432748622	12092	Economy	14800.00
0005432756925	12092	Economy	14800.00
0005432748536	12092	Economy	14800.00
0005432748623	12092	Economy	14800.00
0005432748354	12092	Economy	14800.00
0005432753391	12092	Economy	14800.00
0005432753392	12092	Economy	14800.00
0005432753398	12092	Economy	14800.00
0005432748612	12092	Economy	14800.00
0005432753389	12092	Economy	14800.00
0005432756920	12092	Economy	14800.00
0005432753395	12092	Economy	14800.00
0005432749847	12092	Economy	14800.00
0005432748595	12092	Economy	14800.00
0005432748610	12092	Economy	14800.00
0005432756933	12092	Economy	14800.00
0005432748601	12092	Economy	14800.00
0005435627123	12092	Economy	14800.00
0005432749849	12092	Economy	14800.00
0005432748353	12092	Economy	14800.00
0005432928122	18962	Economy	25700.00
0005432928120	18962	Economy	25700.00
0005432928129	18962	Economy	25700.00
0005432928121	18962	Economy	25700.00
0005433525363	18962	Economy	25700.00
0005432928131	18962	Economy	25700.00
0005433531387	32500	Economy	25700.00
0005433525339	32500	Economy	25700.00
0005433525315	32500	Economy	25700.00
0005433525326	32500	Economy	25700.00
0005433525297	32500	Economy	25700.00
0005433527355	32500	Economy	25700.00
0005433525298	32500	Economy	25700.00
0005433525337	32500	Economy	25700.00
0005433525288	32500	Economy	25700.00
0005433531386	32500	Economy	25700.00
0005433525287	32500	Economy	25700.00
0005433525318	32500	Economy	25700.00
0005433525332	32500	Economy	25700.00
0005433527365	32500	Economy	25700.00
0005433525335	32500	Economy	25700.00
0005433525336	32500	Economy	25700.00
0005433531388	32500	Economy	25700.00
0005433525327	32500	Economy	25700.00
0005435179019	5263	Business	84000.00
0005435374828	5263	Business	84000.00
0005435374714	5263	Comfort	47600.00
0005435315078	5263	Comfort	47600.00
0005435374999	5263	Comfort	47600.00
0005435735250	5263	Comfort	47600.00
0005435374934	5263	Comfort	47600.00
0005435375133	5263	Comfort	47600.00
0005435374897	5263	Comfort	47600.00
0005434558615	5263	Comfort	47600.00
0005435374678	5263	Comfort	47600.00
0005435299881	5263	Comfort	47600.00
0005435374873	5263	Comfort	47600.00
0005435386703	5263	Comfort	47600.00
0005435375047	5263	Comfort	47600.00
0005435374965	5263	Economy	28000.00
0005435375094	5263	Comfort	47600.00
0005435375023	5263	Economy	28000.00
0005435374940	5263	Economy	28000.00
0005435374941	5263	Economy	28000.00
0005435374992	5263	Economy	28000.00
0005432121757	5263	Economy	28000.00
0005435315061	5263	Economy	28000.00
0005434558617	5263	Economy	28000.00
0005432823504	5263	Economy	28000.00
0005435374963	5263	Economy	28000.00
0005432121756	5263	Economy	28000.00
0005435375135	5263	Economy	28000.00
0005435315058	5263	Economy	28000.00
0005435374891	5263	Economy	28000.00
0005435374833	5263	Economy	28000.00
0005435374831	5263	Economy	28000.00
0005435374973	5263	Economy	28000.00
0005435374919	5263	Economy	28000.00
0005435375048	5263	Economy	28000.00
0005435375130	5263	Economy	28000.00
0005435304256	5263	Economy	28000.00
0005435315085	5263	Economy	30800.00
0005434831289	5263	Economy	28000.00
0005435374812	5263	Economy	28000.00
0005435374823	5263	Economy	28000.00
0005435375027	5263	Economy	28000.00
0005435735249	5263	Economy	28000.00
0005435315084	5263	Economy	28000.00
0005434831288	5263	Economy	28000.00
0005435304243	5263	Economy	28000.00
0005435374477	5263	Economy	28000.00
0005435375131	5263	Economy	28000.00
0005435315094	5263	Economy	28000.00
0005434558616	5263	Economy	28000.00
0005435374830	5263	Economy	28000.00
0005435735240	5263	Economy	28000.00
0005435314964	5263	Economy	28000.00
0005434831290	5263	Economy	28000.00
0005435386704	5263	Economy	28000.00
0005435735260	5263	Economy	28000.00
0005435386747	5263	Economy	28000.00
0005435374822	5263	Economy	28000.00
0005435315079	5263	Economy	28000.00
0005435374956	5263	Economy	28000.00
0005435374921	5263	Economy	28000.00
0005435386745	5263	Economy	28000.00
0005435374894	5263	Economy	28000.00
0005435661996	5263	Economy	28000.00
0005435375134	5263	Economy	28000.00
0005435375129	5263	Economy	28000.00
0005435315014	5263	Economy	30800.00
0005435374701	5263	Economy	30800.00
0005435661997	5263	Economy	30800.00
0005435374478	5263	Economy	28000.00
0005435374677	5263	Economy	28000.00
0005435374918	5263	Economy	28000.00
0005435299882	5263	Economy	28000.00
0005435662008	5263	Economy	28000.00
0005435315080	5263	Economy	28000.00
0005432823498	5263	Economy	28000.00
0005435375000	5263	Economy	28000.00
0005435386717	5263	Economy	28000.00
0005435374893	5263	Economy	28000.00
0005435374866	5263	Economy	28000.00
0005435374702	5263	Economy	28000.00
0005435304244	5263	Economy	28000.00
0005435374928	5263	Economy	28000.00
0005435735248	5263	Economy	28000.00
0005435386716	5263	Economy	28000.00
0005435374872	5263	Economy	28000.00
0005435374937	5263	Economy	28000.00
0005435374917	5263	Economy	28000.00
0005435315049	5263	Economy	28000.00
0005435179020	5263	Economy	28000.00
0005435375080	5263	Economy	28000.00
0005435315015	5263	Economy	28000.00
0005435374653	5263	Economy	28000.00
0005434826768	9923	Business	84000.00
0005434826859	9923	Business	84000.00
0005434827160	9923	Business	84000.00
0005434826760	9923	Business	84000.00
0005435150325	9923	Business	84000.00
0005432400215	9923	Business	84000.00
0005434826320	9923	Business	84000.00
0005434826535	9923	Business	84000.00
0005434826819	9923	Business	84000.00
0005434826686	9923	Business	84000.00
0005434826781	9923	Business	84000.00
0005435150380	9923	Business	84000.00
0005434826776	9923	Comfort	47600.00
0005435150396	9923	Comfort	47600.00
0005435150354	9923	Comfort	47600.00
0005434827025	9923	Comfort	47600.00
0005434826648	9923	Comfort	47600.00
0005434826838	9923	Comfort	47600.00
0005434826755	9923	Comfort	47600.00
0005434558485	9923	Comfort	47600.00
0005435150292	9923	Comfort	47600.00
0005434827116	9923	Comfort	47600.00
0005434558463	9923	Comfort	47600.00
0005434826248	9923	Comfort	47600.00
0005434827137	9923	Comfort	47600.00
0005434826610	9923	Comfort	47600.00
0005434826617	9923	Comfort	47600.00
0005434826476	9923	Comfort	47600.00
0005434826563	9923	Comfort	47600.00
0005434826714	9923	Comfort	47600.00
0005434826775	9923	Comfort	47600.00
0005434826400	9923	Economy	28000.00
0005435150429	9923	Economy	28000.00
0005434826979	9923	Economy	28000.00
0005434826433	9923	Economy	28000.00
0005435150353	9923	Economy	28000.00
0005434826663	9923	Economy	28000.00
0005434831278	9923	Economy	28000.00
0005434826887	9923	Economy	28000.00
0005434826756	9923	Economy	28000.00
0005434827161	9923	Economy	28000.00
0005434826616	9923	Economy	28000.00
0005434831260	9923	Economy	28000.00
0005434827023	9923	Economy	28000.00
0005434558473	9923	Economy	28000.00
0005434826796	9923	Economy	28000.00
0005434826536	9923	Economy	28000.00
0005434826953	9923	Economy	28000.00
0005434826721	9923	Economy	28000.00
0005434558474	9923	Economy	28000.00
0005434826865	9923	Economy	30800.00
0005434827210	9923	Economy	30800.00
0005434826901	9923	Economy	28000.00
0005434826321	9923	Economy	28000.00
0005434827042	9923	Economy	30800.00
0005434826951	9923	Economy	28000.00
0005434831279	9923	Economy	28000.00
0005434826427	9923	Economy	28000.00
0005432396348	9923	Economy	28000.00
0005434826888	9923	Economy	28000.00
0005434558490	9923	Economy	28000.00
0005434558487	9923	Economy	28000.00
0005435150382	9923	Economy	28000.00
0005435150428	9923	Economy	28000.00
0005434826892	9923	Economy	28000.00
0005434826496	9923	Economy	28000.00
0005434826322	9923	Economy	28000.00
0005434826566	9923	Economy	28000.00
0005434826705	9923	Economy	28000.00
0005434826579	9923	Economy	28000.00
0005435150412	9923	Economy	28000.00
0005434827198	9923	Economy	28000.00
0005434826710	9923	Economy	28000.00
0005434826820	9923	Economy	28000.00
0005434826664	9923	Economy	28000.00
0005434826726	9923	Economy	28000.00
0005434827197	9923	Economy	28000.00
0005434826495	9923	Economy	28000.00
0005434826876	9923	Economy	28000.00
0005434826902	9923	Economy	28000.00
0005434826875	9923	Economy	28000.00
0005434826841	9923	Economy	28000.00
0005434827011	9923	Economy	28000.00
0005434826889	9923	Economy	28000.00
0005435150395	9923	Economy	28000.00
0005434826933	9923	Economy	28000.00
0005434831262	9923	Economy	28000.00
0005434826711	9923	Economy	28000.00
0005434826712	9923	Economy	28000.00
0005434826771	9923	Economy	28000.00
0005434826946	9923	Economy	28000.00
0005434826667	9923	Economy	28000.00
0005434826257	9923	Economy	28000.00
0005434826489	9923	Economy	28000.00
0005434827024	9923	Economy	28000.00
0005434826842	9923	Economy	28000.00
0005432400214	9923	Economy	28000.00
0005435150422	9923	Economy	28000.00
0005434826978	9923	Economy	28000.00
0005434826508	9923	Economy	28000.00
0005434826725	9923	Economy	28000.00
0005434826861	9923	Economy	28000.00
0005434826401	9923	Economy	30800.00
0005434826954	9923	Economy	30800.00
0005434826627	9923	Economy	30800.00
0005435150393	9923	Economy	30800.00
0005434826962	9923	Economy	28000.00
0005434826618	9923	Economy	28000.00
0005435150421	9923	Economy	28000.00
0005434826770	9923	Economy	28000.00
0005434826586	9923	Economy	28000.00
0005434826647	9923	Economy	28000.00
0005434826720	9923	Economy	28000.00
0005434826780	9923	Economy	28000.00
0005434826860	9923	Economy	28000.00
0005434827006	9923	Economy	28000.00
0005434826717	9923	Economy	28000.00
0005434826782	9923	Economy	28000.00
0005434827010	9923	Economy	28000.00
0005435150366	9923	Economy	28000.00
0005435150324	9923	Economy	28000.00
0005434826567	9923	Economy	28000.00
0005434826904	9923	Economy	28000.00
0005434826762	9923	Economy	28000.00
0005434827026	9923	Economy	28000.00
0005434826326	9923	Economy	28000.00
0005434826903	9923	Economy	28000.00
0005434826789	9923	Economy	28000.00
0005434826633	9923	Economy	28000.00
0005434826542	9923	Economy	28000.00
0005434826818	9923	Economy	28000.00
0005434826716	9923	Economy	28000.00
0005432396349	9923	Economy	28000.00
0005435150394	9923	Economy	28000.00
0005434826247	9923	Economy	28000.00
0005434827005	9923	Economy	28000.00
0005435150411	9923	Economy	28000.00
0005434826774	9923	Economy	28000.00
0005434826632	9923	Economy	28000.00
0005434558460	9923	Economy	28000.00
0005434826704	9923	Economy	28000.00
0005434826568	9923	Economy	28000.00
0005435377993	6977	Economy	7400.00
0005435083013	25988	Economy	7400.00
0005435082994	25988	Economy	7400.00
0005435082993	25988	Economy	7400.00
0005435790384	25988	Economy	7400.00
0005435082981	25988	Economy	7400.00
0005435790386	25988	Economy	7400.00
0005435082986	25988	Economy	7400.00
0005435083007	25988	Economy	7400.00
0005435082982	25988	Economy	7400.00
0005435083015	25988	Economy	7400.00
0005435083014	25988	Economy	7400.00
0005435083006	25988	Economy	7400.00
0005434215688	9549	Business	32800.00
0005434215677	9549	Business	32800.00
0005434215725	9549	Business	32800.00
0005434215566	9549	Business	32800.00
0005434215575	9549	Economy	10900.00
0005434215866	9549	Economy	10900.00
0005434215717	9549	Economy	10900.00
0005434215530	9549	Economy	12000.00
0005434215550	9549	Economy	12000.00
0005434215643	9549	Economy	12000.00
0005434215484	9549	Economy	12000.00
0005434215728	9549	Economy	10900.00
0005434215758	9549	Economy	10900.00
0005434215633	9549	Economy	10900.00
0005434215689	9549	Economy	10900.00
0005434215718	9549	Economy	10900.00
0005434215805	9549	Economy	10900.00
0005434215549	9549	Economy	10900.00
0005434215804	9549	Economy	10900.00
0005434215751	9549	Economy	10900.00
0005434215724	9549	Economy	10900.00
0005434757693	9549	Economy	10900.00
0005434215830	9549	Economy	10900.00
0005434215715	9549	Economy	10900.00
0005434215512	9549	Economy	10900.00
0005434215674	9549	Economy	10900.00
0005434215612	9549	Economy	10900.00
0005434215767	9549	Economy	10900.00
0005434215622	9549	Economy	10900.00
0005434215716	9549	Economy	10900.00
0005434215729	9549	Economy	10900.00
0005434215485	9549	Economy	10900.00
0005434215768	9549	Economy	10900.00
0005434215747	9549	Economy	10900.00
0005434757694	9549	Economy	10900.00
0005434215554	9549	Economy	10900.00
0005434215765	9549	Economy	10900.00
0005434757695	9549	Economy	10900.00
0005434215529	9549	Economy	10900.00
0005434215841	9549	Economy	10900.00
0005434215842	9549	Economy	10900.00
0005434215865	9549	Economy	10900.00
0005434215399	9549	Economy	10900.00
0005434215493	9549	Economy	10900.00
0005434215781	9549	Economy	10900.00
0005434757692	9549	Economy	10900.00
0005434757486	28606	Business	32800.00
0005434757330	28606	Business	32800.00
0005434757452	28606	Business	32800.00
0005434757378	28606	Economy	10900.00
0005434757509	28606	Economy	10900.00
0005434757479	28606	Economy	10900.00
0005434757269	28606	Economy	12000.00
0005434757354	28606	Economy	12000.00
0005434757329	28606	Economy	12000.00
0005434757257	28606	Economy	10900.00
0005434757359	28606	Economy	10900.00
0005434757304	28606	Economy	10900.00
0005434757412	28606	Economy	10900.00
0005434757461	28606	Economy	10900.00
0005434757420	28606	Economy	10900.00
0005434215904	28606	Economy	10900.00
0005434757303	28606	Economy	10900.00
0005434757550	28606	Economy	10900.00
0005434757451	28606	Economy	10900.00
0005434215903	28606	Economy	10900.00
0005434757293	28606	Economy	10900.00
0005434757421	28606	Economy	10900.00
0005434757497	28606	Economy	10900.00
0005434757418	28606	Economy	10900.00
0005434757498	28606	Economy	10900.00
0005434757294	28606	Economy	10900.00
0005434757268	28606	Economy	10900.00
0005434757422	28606	Economy	10900.00
0005434757538	28606	Economy	10900.00
0005434757500	28606	Economy	10900.00
0005434757355	28606	Economy	10900.00
0005434757508	28606	Economy	10900.00
0005434757270	28606	Economy	10900.00
0005434757400	28606	Economy	10900.00
0005434757398	28606	Economy	10900.00
0005434757439	28606	Economy	10900.00
0005434757440	28606	Economy	10900.00
0005434757144	28606	Economy	10900.00
0005434757507	28606	Economy	10900.00
0005434757551	28606	Economy	10900.00
0005434215902	28606	Economy	10900.00
0005434760262	10862	Economy	8900.00
0005435100201	31810	Economy	8900.00
0005433202754	1962	Economy	20900.00
0005433202681	1962	Economy	19000.00
0005433202729	1962	Economy	19000.00
0005433202718	1962	Economy	19000.00
0005434640106	1962	Economy	19000.00
0005433202717	1962	Economy	19000.00
0005433202753	1962	Economy	19000.00
0005433202738	1962	Economy	19000.00
0005433202746	1962	Economy	19000.00
0005433202719	1962	Economy	19000.00
0005433202737	1962	Economy	19000.00
0005434640002	23279	Economy	20900.00
0005434639911	23279	Economy	20900.00
0005434639923	23279	Economy	19000.00
0005434640016	23279	Economy	19000.00
0005434639902	23279	Economy	19000.00
0005434639955	23279	Economy	19000.00
0005434640005	23279	Economy	19000.00
0005434639924	23279	Economy	19000.00
0005434640004	23279	Economy	19000.00
0005434640020	23279	Economy	19000.00
0005434640027	23279	Economy	19000.00
0005434639788	23279	Economy	19000.00
0005434639918	23279	Economy	19000.00
0005434640018	23279	Economy	19000.00
0005434640003	23279	Economy	19000.00
0005434639936	23279	Economy	19000.00
0005435948360	23279	Economy	19000.00
0005434639925	23279	Economy	19000.00
0005434639966	23279	Economy	19000.00
0005434640050	23279	Economy	19000.00
0005434640017	23279	Economy	19000.00
0005434640021	23279	Economy	19000.00
0005434639954	23279	Economy	19000.00
0005434640001	23279	Economy	19000.00
0005435327120	6049	Business	69700.00
0005434601597	6049	Business	69700.00
0005435327097	6049	Economy	23200.00
0005435327091	6049	Economy	25600.00
0005435327127	6049	Economy	23200.00
0005435327051	6049	Economy	23200.00
0005435327119	6049	Economy	23200.00
0005435327121	6049	Economy	23200.00
0005435327092	6049	Economy	23200.00
0005435327118	6049	Economy	23200.00
0005435327102	6049	Economy	23200.00
0005434601468	18576	Business	69700.00
0005434601452	18576	Business	69700.00
0005434601539	18576	Economy	23200.00
0005434601527	18576	Economy	23200.00
0005434601393	18576	Economy	23200.00
0005433531391	18576	Economy	23200.00
0005434601421	18576	Economy	25600.00
0005434601411	18576	Economy	23200.00
0005434601472	18576	Economy	23200.00
0005434601548	18576	Economy	23200.00
0005434601528	18576	Economy	23200.00
0005434601413	18576	Economy	23200.00
0005434601473	18576	Economy	23200.00
0005434601509	18576	Economy	23200.00
0005433531396	18576	Economy	23200.00
0005434601394	18576	Economy	23200.00
0005434601490	18576	Economy	23200.00
0005433531395	18576	Economy	23200.00
0005434601538	18576	Economy	23200.00
0005434601412	18576	Economy	23200.00
0005434601440	18576	Economy	23200.00
0005433531382	18576	Economy	23200.00
0005433531397	18576	Economy	23200.00
0005433531383	18576	Economy	23200.00
0005433531390	18576	Economy	23200.00
0005433531398	18576	Economy	23200.00
0005434601419	18576	Economy	23200.00
0005433531403	18576	Economy	23200.00
0005434601488	18576	Economy	23200.00
0005434601508	18576	Economy	23200.00
0005434601540	18576	Economy	23200.00
0005433527339	18576	Economy	23200.00
0005435315037	10566	Business	9100.00
0005433181780	10566	Business	9100.00
0005435315021	10566	Business	9100.00
0005433181688	10566	Business	9100.00
0005435315036	10566	Business	9100.00
0005435315073	10566	Business	9100.00
0005433181690	10566	Economy	3000.00
0005433181685	10566	Economy	3000.00
0005435315076	10566	Economy	3000.00
0005434552863	10566	Economy	3000.00
0005433181691	10566	Economy	3300.00
0005433181597	10566	Economy	3300.00
0005435315038	10566	Economy	3300.00
0005433181610	10566	Economy	3300.00
0005433181704	10566	Economy	3000.00
0005435315056	10566	Economy	3000.00
0005433181783	10566	Economy	3000.00
0005434552865	10566	Economy	3000.00
0005433181608	10566	Economy	3000.00
0005433181708	10566	Economy	3000.00
0005433181703	10566	Economy	3000.00
0005433181747	10566	Economy	3000.00
0005433181786	10566	Economy	3000.00
0005433181787	10566	Economy	3000.00
0005435314994	10566	Economy	3000.00
0005433181702	10566	Economy	3000.00
0005435315005	10566	Economy	3000.00
0005433181609	10566	Economy	3000.00
0005435315048	10566	Economy	3000.00
0005434552864	10566	Economy	3000.00
0005433181781	10566	Economy	3000.00
0005433181710	10566	Economy	3000.00
0005435315107	10566	Economy	3000.00
0005433181689	10566	Economy	3000.00
0005433181630	10566	Economy	3000.00
0005434757706	10566	Economy	3000.00
0005435315046	10566	Economy	3000.00
0005435315019	10566	Economy	3000.00
0005433181671	10566	Economy	3000.00
0005433181782	10566	Economy	3000.00
0005435315047	10566	Economy	3000.00
0005434552866	10566	Economy	3000.00
0005433181721	10566	Economy	3000.00
0005435315051	10566	Economy	3000.00
0005435315023	10566	Economy	3000.00
0005433181683	10566	Economy	3000.00
0005435315108	10566	Economy	3000.00
0005433181753	10566	Economy	3000.00
0005435315050	10566	Economy	3000.00
0005433181705	10566	Economy	3000.00
0005435315045	10566	Economy	3000.00
0005433181785	10566	Economy	3000.00
0005433181811	10566	Economy	3000.00
0005433181709	10566	Economy	3000.00
0005435314993	10566	Economy	3000.00
0005435315035	10566	Economy	3000.00
0005434554117	27665	Business	9100.00
0005434558486	27665	Business	9100.00
0005434552740	27665	Business	9100.00
0005434552590	27665	Business	9100.00
0005434558528	27665	Business	9100.00
0005434558489	27665	Business	9100.00
0005434552514	27665	Business	9100.00
0005434558522	27665	Business	9100.00
0005434558472	27665	Economy	3000.00
0005434558481	27665	Economy	3300.00
0005434558468	27665	Economy	3300.00
0005434558519	27665	Economy	3300.00
0005434552678	27665	Economy	3000.00
0005434558551	27665	Economy	3000.00
0005434558601	27665	Economy	3000.00
0005434552523	27665	Economy	3000.00
0005434558504	27665	Economy	3000.00
0005434552725	27665	Economy	3000.00
0005434552690	27665	Economy	3000.00
0005434552730	27665	Economy	3000.00
0005434552844	27665	Economy	3000.00
0005434552688	27665	Economy	3000.00
0005434558583	27665	Economy	3000.00
0005434558581	27665	Economy	3000.00
0005434558482	27665	Economy	3000.00
0005434552442	27665	Economy	3000.00
0005434552612	27665	Economy	3000.00
0005434558582	27665	Economy	3000.00
0005434552607	27665	Economy	3000.00
0005434552608	27665	Economy	3000.00
0005434552741	27665	Economy	3000.00
0005434558505	27665	Economy	3000.00
0005434552677	27665	Economy	3000.00
0005434552739	27665	Economy	3000.00
0005434558484	27665	Economy	3000.00
0005434558514	27665	Economy	3000.00
0005434558497	27665	Economy	3000.00
0005434552495	27665	Economy	3000.00
0005434552731	27665	Economy	3000.00
0005434558600	27665	Economy	3000.00
0005434552634	27665	Economy	3000.00
0005434552689	27665	Economy	3000.00
0005434558547	27665	Economy	3000.00
0005434552718	27665	Economy	3000.00
0005434552749	27665	Economy	3000.00
0005434552611	27665	Economy	3000.00
0005434552764	27665	Economy	3000.00
0005434558510	27665	Economy	3000.00
0005434552729	27665	Economy	3000.00
0005434552775	27665	Economy	3000.00
0005434552353	27665	Economy	3000.00
0005434558483	27665	Economy	3000.00
0005434552719	27665	Economy	3000.00
0005434552515	27665	Economy	3000.00
0005435254525	6128	Economy	11700.00
0005435254530	6128	Economy	11700.00
0005433459332	19327	Economy	11700.00
0005433459331	19327	Economy	11700.00
0005435438540	6756	Business	51100.00
0005435438556	6756	Economy	17000.00
0005435438557	6756	Economy	17000.00
0005435683336	6756	Economy	18700.00
0005435220378	6756	Economy	17000.00
0005435220370	6756	Economy	17000.00
0005435438533	6756	Economy	17000.00
0005435790418	6756	Economy	17000.00
0005435438548	6756	Economy	17000.00
0005435438570	6756	Economy	17000.00
0005435662016	6756	Economy	17000.00
0005435438543	6756	Economy	17000.00
0005435438564	6756	Economy	17000.00
0005435662015	6756	Economy	17000.00
0005435438542	6756	Economy	17000.00
0005435438555	6756	Economy	17000.00
0005435220376	6756	Economy	17000.00
0005435438505	6756	Economy	17000.00
0005435438549	6756	Economy	17000.00
0005435438563	6756	Economy	17000.00
0005432533366	6756	Economy	17000.00
0005435438576	6756	Economy	17000.00
0005435220371	6756	Economy	17000.00
0005435683157	24620	Business	51100.00
0005435683197	24620	Business	51100.00
0005435683290	24620	Business	51100.00
0005435683087	24620	Business	51100.00
0005435683198	24620	Economy	17000.00
0005435683181	24620	Economy	17000.00
0005435683289	24620	Economy	17000.00
0005435662004	24620	Economy	17000.00
0005435683230	24620	Economy	17000.00
0005435683281	24620	Economy	17000.00
0005435719585	24620	Economy	17000.00
0005435683282	24620	Economy	18700.00
0005435683136	24620	Economy	17000.00
0005435683258	24620	Economy	17000.00
0005435683250	24620	Economy	17000.00
0005435719594	24620	Economy	17000.00
0005435682997	24620	Economy	17000.00
0005435683160	24620	Economy	17000.00
0005435654513	24620	Economy	17000.00
0005435683018	24620	Economy	17000.00
0005435683180	24620	Economy	17000.00
0005435631038	24620	Economy	17000.00
0005435683259	24620	Economy	17000.00
0005435683185	24620	Economy	17000.00
0005435683135	24620	Economy	17000.00
0005435683094	24620	Economy	17000.00
0005435683158	24620	Economy	17000.00
0005435683294	24620	Economy	17000.00
0005435683069	24620	Economy	17000.00
0005435683269	24620	Economy	17000.00
0005435683113	24620	Economy	17000.00
0005435683093	24620	Economy	17000.00
0005435683194	24620	Economy	17000.00
0005435683219	24620	Economy	17000.00
0005435683184	24620	Economy	17000.00
0005435719586	24620	Economy	17000.00
0005435683156	24620	Economy	17000.00
0005435683080	24620	Economy	17000.00
0005435662005	24620	Economy	17000.00
0005435683242	24620	Economy	17000.00
0005435683241	24620	Economy	17000.00
0005435683145	24620	Economy	17000.00
0005435558156	11529	Business	26400.00
0005435558155	11529	Economy	8800.00
0005435127587	11529	Economy	8800.00
0005435127586	11529	Economy	8800.00
0005435127585	11529	Economy	8800.00
0005435127519	31889	Business	26400.00
0005435127424	31889	Business	26400.00
0005435127461	31889	Business	26400.00
0005435127399	31889	Business	26400.00
0005435127404	31889	Business	26400.00
0005435127438	31889	Economy	8800.00
0005435127485	31889	Economy	8800.00
0005435127325	31889	Economy	8800.00
0005435127281	31889	Economy	8800.00
0005435127448	31889	Economy	8800.00
0005435127447	31889	Economy	9700.00
0005435127486	31889	Economy	8800.00
0005435127400	31889	Economy	8800.00
0005435127463	31889	Economy	8800.00
0005435127419	31889	Economy	8800.00
0005435127516	31889	Economy	8800.00
0005435127395	31889	Economy	8800.00
0005435127437	31889	Economy	8800.00
0005435127536	31889	Economy	8800.00
0005435127433	31889	Economy	8800.00
0005435127420	31889	Economy	8800.00
0005435127418	31889	Economy	8800.00
0005435127405	31889	Economy	8800.00
0005435127369	31889	Economy	8800.00
0005435127284	31889	Economy	8800.00
0005435127361	31889	Economy	8800.00
0005435127324	31889	Economy	8800.00
0005435127323	31889	Economy	8800.00
0005435127256	31889	Economy	8800.00
0005435127394	31889	Economy	8800.00
0005435127372	31889	Economy	8800.00
0005435127472	31889	Economy	8800.00
0005435098609	31889	Economy	8800.00
0005435127434	31889	Economy	8800.00
0005435127460	31889	Economy	8800.00
0005435127524	31889	Economy	8800.00
0005435127427	31889	Economy	8800.00
0005435127421	31889	Economy	8800.00
0005435127297	31889	Economy	8800.00
0005435127517	31889	Economy	8800.00
0005435127478	31889	Economy	8800.00
0005435127371	31889	Economy	8800.00
0005435732621	13561	Business	36600.00
0005435732690	13561	Business	36600.00
0005435732638	13561	Business	36600.00
0005435732651	13561	Business	36600.00
0005435732660	13561	Economy	12200.00
0005435732646	13561	Economy	12200.00
0005435732665	13561	Economy	13400.00
0005435732691	13561	Economy	13400.00
0005435732666	13561	Economy	12200.00
0005435732702	13561	Economy	12200.00
0005435732637	13561	Economy	12200.00
0005435732689	13561	Economy	12200.00
0005435732639	13561	Economy	12200.00
0005435732667	13561	Economy	12200.00
0005435732650	13561	Economy	12200.00
0005435732688	13561	Economy	12200.00
0005435732701	13561	Economy	12200.00
0005435732661	13561	Economy	12200.00
0005435732647	13561	Economy	12200.00
0005435732648	13561	Economy	12200.00
0005433399320	19425	Business	36600.00
0005433399151	19425	Business	36600.00
0005433399142	19425	Business	36600.00
0005433399318	19425	Business	36600.00
0005433399271	19425	Economy	12200.00
0005433399241	19425	Economy	13400.00
0005433399392	19425	Economy	12200.00
0005433399418	19425	Economy	12200.00
0005433399234	19425	Economy	12200.00
0005433399366	19425	Economy	12200.00
0005433399355	19425	Economy	12200.00
0005433399405	19425	Economy	12200.00
0005433399122	19425	Economy	12200.00
0005433399407	19425	Economy	12200.00
0005433399180	19425	Economy	12200.00
0005433399393	19425	Economy	12200.00
0005433399301	19425	Economy	12200.00
0005433399237	19425	Economy	12200.00
0005433399238	19425	Economy	12200.00
0005433399169	19425	Economy	12200.00
0005433399233	19425	Economy	12200.00
0005433399300	19425	Economy	12200.00
0005433399364	19425	Economy	12200.00
0005433399408	19425	Economy	12200.00
0005433399319	19425	Economy	12200.00
0005433399179	19425	Economy	12200.00
0005435070138	13150	Business	11300.00
0005435070381	13150	Business	11300.00
0005435070266	13150	Economy	3800.00
0005435070262	13150	Economy	3800.00
0005435070435	13150	Economy	3800.00
0005435070237	13150	Economy	3800.00
0005435070032	13150	Economy	3800.00
0005435070448	13150	Economy	4100.00
0005435070289	13150	Economy	4100.00
0005435070483	13150	Economy	4100.00
0005435070414	13150	Economy	3800.00
0005435070538	13150	Economy	3800.00
0005435070370	13150	Economy	3800.00
0005435070137	13150	Economy	3800.00
0005435070342	13150	Economy	3800.00
0005435070371	13150	Economy	3800.00
0005435070214	13150	Economy	3800.00
0005435070447	13150	Economy	3800.00
0005435070482	13150	Economy	3800.00
0005435070100	13150	Economy	3800.00
0005435070446	13150	Economy	3800.00
0005435070113	13150	Economy	3800.00
0005435070407	13150	Economy	3800.00
0005435070422	13150	Economy	3800.00
0005435070229	13150	Economy	3800.00
0005435070177	13150	Economy	3800.00
0005435070502	13150	Economy	3800.00
0005435070215	13150	Economy	3800.00
0005435070230	13150	Economy	3800.00
0005435070112	13150	Economy	3800.00
0005435070160	13150	Economy	3800.00
0005435070272	13150	Economy	3800.00
0005435070236	13150	Economy	3800.00
0005435070228	13150	Economy	3800.00
0005435070475	13150	Economy	3800.00
0005435070265	13150	Economy	3800.00
0005435070474	13150	Economy	3800.00
0005435070101	13150	Economy	3800.00
0005435070549	13150	Economy	3800.00
0005435070178	13150	Economy	3800.00
0005435070431	13150	Economy	3800.00
0005435925621	15459	Business	11300.00
0005435925657	15459	Economy	4100.00
0005435925598	15459	Economy	4100.00
0005435925628	15459	Economy	3800.00
0005435925618	15459	Economy	3800.00
0005435925633	15459	Economy	3800.00
0005435925612	15459	Economy	3800.00
0005435925616	15459	Economy	3800.00
0005435925594	15459	Economy	3800.00
0005435925629	15459	Economy	3800.00
0005435925632	15459	Economy	3800.00
0005435070565	15459	Economy	3800.00
0005435925644	15459	Economy	3800.00
0005435925654	15459	Economy	3800.00
0005435925648	15459	Economy	3800.00
0005435070566	15459	Economy	3800.00
0005435070564	15459	Economy	3800.00
0005435925595	15459	Economy	3800.00
0005435808438	29486	Economy	27100.00
0005435808491	29486	Economy	27100.00
0005435808405	29486	Economy	24700.00
0005435808472	29486	Economy	24700.00
0005435808406	29486	Economy	24700.00
0005435808443	29486	Economy	24700.00
0005435808442	29486	Economy	24700.00
0005435808471	29486	Economy	24700.00
0005435808424	29486	Economy	24700.00
0005435808480	29486	Economy	24700.00
0005435808482	29486	Economy	24700.00
0005435808498	29486	Economy	24700.00
0005435808418	29486	Economy	24700.00
0005435808481	29486	Economy	24700.00
0005435808448	29486	Economy	24700.00
0005435808463	29486	Economy	24700.00
0005435808462	29486	Economy	24700.00
0005435808490	29486	Economy	24700.00
0005435808479	29486	Economy	24700.00
0005435808499	29486	Economy	24700.00
0005434757385	10714	Business	61300.00
0005434757569	10714	Business	61300.00
0005434757336	10714	Business	61300.00
0005434757464	10714	Business	61300.00
0005434757462	10714	Business	61300.00
0005434757272	10714	Business	61300.00
0005434757455	10714	Economy	20400.00
0005434757504	10714	Economy	20400.00
0005434757506	10714	Economy	20400.00
0005434757322	10714	Economy	22500.00
0005434757404	10714	Economy	22500.00
0005434757334	10714	Economy	20400.00
0005434757325	10714	Economy	20400.00
0005434757482	10714	Economy	20400.00
0005434757502	10714	Economy	20400.00
0005434757443	10714	Economy	20400.00
0005434757335	10714	Economy	20400.00
0005434757313	10714	Economy	20400.00
0005434757454	10714	Economy	20400.00
0005434757457	10714	Economy	20400.00
0005434757441	10714	Economy	20400.00
0005434757446	10714	Economy	20400.00
0005434757456	10714	Economy	20400.00
0005434757333	10714	Economy	20400.00
0005434757556	10714	Economy	20400.00
0005434757472	10714	Economy	20400.00
0005434757453	10714	Economy	20400.00
0005434757384	10714	Economy	20400.00
0005434757467	10714	Economy	20400.00
0005434757581	10714	Economy	20400.00
0005434757495	10714	Economy	20400.00
0005434757517	10714	Economy	20400.00
0005434757326	10714	Economy	20400.00
0005434757553	10714	Economy	20400.00
0005434757337	10714	Economy	20400.00
0005434757554	10714	Economy	20400.00
0005434757321	10714	Economy	20400.00
0005434757463	10714	Economy	20400.00
0005434757442	10714	Economy	20400.00
0005434757496	10714	Economy	20400.00
0005434757273	10714	Economy	20400.00
0005434757608	10714	Economy	20400.00
0005434757563	10714	Economy	20400.00
0005434757403	10714	Economy	20400.00
0005434757314	10714	Economy	20400.00
0005434215649	28700	Business	61300.00
0005434215713	28700	Business	61300.00
0005434215518	28700	Business	61300.00
0005434757687	28700	Business	61300.00
0005434215797	28700	Business	61300.00
0005434215787	28700	Business	61300.00
0005434215608	28700	Business	61300.00
0005434215577	28700	Economy	20400.00
0005434215714	28700	Economy	20400.00
0005434215466	28700	Economy	20400.00
0005434215709	28700	Economy	20400.00
0005434215616	28700	Economy	20400.00
0005434215796	28700	Economy	22500.00
0005434215707	28700	Economy	22500.00
0005434215631	28700	Economy	20400.00
0005434215632	28700	Economy	20400.00
0005434757686	28700	Economy	20400.00
0005434215565	28700	Economy	20400.00
0005434215739	28700	Economy	20400.00
0005434215547	28700	Economy	20400.00
0005434215390	28700	Economy	20400.00
0005434757689	28700	Economy	20400.00
0005434215710	28700	Economy	20400.00
0005434215602	28700	Economy	20400.00
0005434215519	28700	Economy	20400.00
0005434215678	28700	Economy	20400.00
0005434215703	28700	Economy	20400.00
0005434215564	28700	Economy	20400.00
0005434757691	28700	Economy	20400.00
0005434215500	28700	Economy	20400.00
0005434215637	28700	Economy	20400.00
0005434215465	28700	Economy	20400.00
0005434215696	28700	Economy	20400.00
0005434215770	28700	Economy	20400.00
0005434215563	28700	Economy	20400.00
0005434215695	28700	Economy	20400.00
0005434215745	28700	Economy	20400.00
0005434215621	28700	Economy	20400.00
0005434215642	28700	Economy	20400.00
0005434215391	28700	Economy	20400.00
0005434215764	28700	Economy	20400.00
0005434757690	28700	Economy	20400.00
0005434215706	28700	Economy	20400.00
0005434215740	28700	Economy	20400.00
0005434215499	28700	Economy	20400.00
0005434215603	28700	Economy	20400.00
0005434215824	28700	Economy	20400.00
0005434215708	28700	Economy	20400.00
0005434757688	28700	Economy	20400.00
0005434215620	28700	Economy	20400.00
0005434215569	28700	Economy	20400.00
0005434215823	28700	Economy	20400.00
0005434215604	28700	Economy	20400.00
0005434229879	5467	Business	29500.00
0005434229970	5467	Business	29500.00
0005435377933	5467	Economy	9800.00
0005434230001	5467	Economy	9800.00
0005434229995	5467	Economy	9800.00
0005434229920	5467	Economy	9800.00
0005434229991	5467	Economy	9800.00
0005434229999	5467	Economy	9800.00
0005434229984	5467	Economy	9800.00
0005434229915	5467	Economy	9800.00
0005435377957	5467	Economy	9800.00
0005434229969	5467	Economy	9800.00
0005434230000	5467	Economy	9800.00
0005435041701	5467	Economy	9800.00
0005434229990	5467	Economy	9800.00
0005434229880	5467	Economy	9800.00
0005434229996	5467	Economy	9800.00
0005434229933	5467	Economy	9800.00
0005434229992	5467	Economy	9800.00
0005435377953	5467	Economy	9800.00
0005435377934	5467	Economy	9800.00
0005434229909	5467	Economy	9800.00
0005434229919	5467	Economy	9800.00
0005434229907	5467	Economy	9800.00
0005435377958	5467	Economy	9800.00
0005434229946	5467	Economy	9800.00
0005434229968	5467	Economy	9800.00
0005434229908	5467	Economy	9800.00
0005435041230	12996	Business	29500.00
0005435041541	12996	Business	29500.00
0005435007629	12996	Business	29500.00
0005435041327	12996	Economy	9800.00
0005435041540	12996	Economy	9800.00
0005435043307	12996	Economy	9800.00
0005435041422	12996	Economy	9800.00
0005435041599	12996	Economy	9800.00
0005435041274	12996	Economy	9800.00
0005435041156	12996	Economy	9800.00
0005435041399	12996	Economy	9800.00
0005435041446	12996	Economy	9800.00
0005435041459	12996	Economy	9800.00
0005435007668	12996	Economy	9800.00
0005435041312	12996	Economy	9800.00
0005435041344	12996	Economy	9800.00
0005435041340	12996	Economy	9800.00
0005435041561	12996	Economy	9800.00
0005435007691	12996	Economy	9800.00
0005435041287	12996	Economy	9800.00
0005435007677	12996	Economy	10800.00
0005435041280	12996	Economy	10800.00
0005435041421	12996	Economy	10800.00
0005435042929	12996	Economy	9800.00
0005435041500	12996	Economy	9800.00
0005435041292	12996	Economy	9800.00
0005435041619	12996	Economy	9800.00
0005435042922	12996	Economy	9800.00
0005435041461	12996	Economy	9800.00
0005435041460	12996	Economy	9800.00
0005435041584	12996	Economy	9800.00
0005435041351	12996	Economy	9800.00
0005435041214	12996	Economy	9800.00
0005435041343	12996	Economy	9800.00
0005435041185	12996	Economy	9800.00
0005435041398	12996	Economy	9800.00
0005435041560	12996	Economy	9800.00
0005435041462	12996	Economy	9800.00
0005435041213	12996	Economy	9800.00
0005435007571	12996	Economy	9800.00
0005435041618	12996	Economy	9800.00
0005435007570	12996	Economy	9800.00
0005435041569	12996	Economy	9800.00
0005435041548	12996	Economy	9800.00
0005435041229	12996	Economy	9800.00
0005435041314	12996	Economy	9800.00
0005435041158	12996	Economy	9800.00
0005435041463	12996	Economy	9800.00
0005435042930	12996	Economy	9800.00
0005435041328	12996	Economy	9800.00
0005435007688	12996	Economy	9800.00
0005435041643	12996	Economy	9800.00
0005435041281	12996	Economy	9800.00
0005435007667	12996	Economy	9800.00
0005435042923	12996	Economy	9800.00
0005435041501	12996	Economy	9800.00
0005435041527	12996	Economy	9800.00
0005435041157	12996	Economy	9800.00
0005435041218	12996	Economy	9800.00
0005435041426	12996	Economy	9800.00
0005435041605	12996	Economy	9800.00
0005435041526	12996	Economy	9800.00
0005435007690	12996	Economy	9800.00
0005435041645	12996	Economy	9800.00
0005435041539	12996	Economy	9800.00
0005435903150	14863	Business	52900.00
0005435903185	14863	Business	52900.00
0005435903137	14863	Economy	17600.00
0005434427472	14863	Economy	19400.00
0005435903153	14863	Economy	19400.00
0005435903163	14863	Economy	19400.00
0005435903138	14863	Economy	17600.00
0005435903162	14863	Economy	17600.00
0005435903151	14863	Economy	17600.00
0005435903083	14863	Economy	17600.00
0005435903132	14863	Economy	17600.00
0005435903147	14863	Economy	17600.00
0005435903170	14863	Economy	17600.00
0005435903133	14863	Economy	17600.00
0005435903167	14863	Economy	17600.00
0005435903146	14863	Economy	17600.00
0005435903176	14863	Economy	17600.00
0005435903177	14863	Economy	17600.00
0005435903056	14863	Economy	17600.00
0005435903166	14863	Economy	17600.00
0005435903164	14863	Economy	17600.00
0005435903055	14863	Economy	17600.00
0005435903125	14863	Economy	17600.00
0005435554308	14863	Economy	17600.00
0005435903152	14863	Economy	17600.00
0005434427413	20233	Business	52900.00
0005434427319	20233	Business	52900.00
0005434427401	20233	Business	52900.00
0005434427389	20233	Economy	17600.00
0005434427409	20233	Economy	17600.00
0005434411896	20233	Economy	17600.00
0005434427356	20233	Economy	17600.00
0005434427372	20233	Economy	17600.00
0005434427371	20233	Economy	19400.00
0005434427327	20233	Economy	19400.00
0005434427332	20233	Economy	17600.00
0005434427328	20233	Economy	17600.00
0005434411898	20233	Economy	17600.00
0005434427425	20233	Economy	17600.00
0005434427357	20233	Economy	17600.00
0005434427408	20233	Economy	17600.00
0005434427329	20233	Economy	17600.00
0005434427333	20233	Economy	17600.00
0005434427297	20233	Economy	17600.00
0005434427317	20233	Economy	17600.00
0005434427398	20233	Economy	17600.00
0005434427284	20233	Economy	17600.00
0005434427421	20233	Economy	17600.00
0005434427303	20233	Economy	17600.00
0005434427358	20233	Economy	17600.00
0005434411889	20233	Economy	17600.00
0005434427274	20233	Economy	17600.00
0005434427399	20233	Economy	17600.00
0005434427378	20233	Economy	17600.00
0005434427304	20233	Economy	17600.00
0005434427218	20233	Economy	17600.00
0005434427405	20233	Economy	17600.00
0005434427318	20233	Economy	17600.00
0005434427217	20233	Economy	17600.00
0005434427273	20233	Economy	17600.00
0005434427403	20233	Economy	17600.00
0005434411897	20233	Economy	17600.00
0005434411899	20233	Economy	17600.00
0005434523835	28005	Economy	35600.00
0005434559116	28005	Economy	35600.00
0005434559148	28005	Economy	35600.00
0005434559120	28005	Economy	35600.00
0005434523818	28005	Economy	35600.00
0005434559132	28005	Economy	35600.00
0005434523830	28005	Economy	39200.00
0005434559146	28005	Economy	39200.00
0005434559131	28005	Economy	39200.00
0005434559125	28005	Economy	35600.00
0005434559145	28005	Economy	35600.00
0005434559113	28005	Economy	35600.00
0005434523831	28005	Economy	35600.00
0005434559134	28005	Economy	35600.00
0005434523819	28005	Economy	35600.00
0005434559133	28005	Economy	35600.00
0005434559149	28005	Economy	35600.00
0005434523827	28005	Economy	35600.00
0005434559121	28005	Economy	35600.00
0005434559150	28005	Economy	35600.00
0005434559151	28005	Economy	35600.00
0005434559135	28005	Economy	35600.00
0005434523834	28005	Economy	35600.00
0005433435454	26505	Business	18500.00
0005433435388	26505	Business	18500.00
0005433435391	26505	Business	18500.00
0005433435437	26505	Business	18500.00
0005433435447	26505	Business	18500.00
0005433435270	26505	Business	18500.00
0005433435407	26505	Business	18500.00
0005434270260	26505	Economy	6200.00
0005433435397	26505	Economy	6200.00
0005433435435	26505	Economy	6200.00
0005434273119	26505	Economy	6200.00
0005433435398	26505	Economy	6200.00
0005433435350	26505	Economy	6800.00
0005433435389	26505	Economy	6800.00
0005433435376	26505	Economy	6800.00
0005433435302	26505	Economy	6200.00
0005433435320	26505	Economy	6200.00
0005433435304	26505	Economy	6200.00
0005433435392	26505	Economy	6200.00
0005435983675	26505	Economy	6200.00
0005433435358	26505	Economy	6200.00
0005433435387	26505	Economy	6200.00
0005433435453	26505	Economy	6200.00
0005435983674	26505	Economy	6200.00
0005433435455	26505	Economy	6200.00
0005434270262	26505	Economy	6200.00
0005433435404	26505	Economy	6200.00
0005434270257	26505	Economy	6200.00
0005433435419	26505	Economy	6200.00
0005433435390	26505	Economy	6200.00
0005433435303	26505	Economy	6200.00
0005433435375	26505	Economy	6200.00
0005433435417	26505	Economy	6200.00
0005433435377	26505	Economy	6200.00
0005433435374	26505	Economy	6200.00
0005434273122	26505	Economy	6200.00
0005433435431	26505	Economy	6200.00
0005433435385	26505	Economy	6200.00
0005432300445	26505	Economy	6200.00
0005433435403	26505	Economy	6200.00
0005433435416	26505	Economy	6200.00
0005434270258	26505	Economy	6200.00
0005434270261	26505	Economy	6200.00
0005433435408	26505	Economy	6200.00
0005434270259	26505	Economy	6200.00
0005434270263	26505	Economy	6200.00
0005433435469	26505	Economy	6200.00
0005434273118	26505	Economy	6200.00
0005434270264	26505	Economy	6200.00
0005435983512	26728	Business	18500.00
0005435983538	26728	Business	18500.00
0005435983414	26728	Business	18500.00
0005435983384	26728	Business	18500.00
0005435983549	26728	Business	18500.00
0005435983497	26728	Business	18500.00
0005435983420	26728	Business	18500.00
0005433435509	26728	Economy	6200.00
0005435983413	26728	Economy	6200.00
0005435983626	26728	Economy	6200.00
0005435983571	26728	Economy	6800.00
0005435983385	26728	Economy	6200.00
0005435983339	26728	Economy	6200.00
0005435983488	26728	Economy	6200.00
0005435983436	26728	Economy	6200.00
0005435983396	26728	Economy	6200.00
0005435983230	26728	Economy	6200.00
0005435983312	26728	Economy	6200.00
0005435983223	26728	Economy	6200.00
0005435983422	26728	Economy	6200.00
0005435983272	26728	Economy	6200.00
0005435983222	26728	Economy	6200.00
0005435983154	26728	Economy	6200.00
0005435983444	26728	Economy	6200.00
0005435983445	26728	Economy	6200.00
0005435983572	26728	Economy	6200.00
0005435983561	26728	Economy	6200.00
0005435983627	26728	Economy	6200.00
0005435983278	26728	Economy	6200.00
0005435983088	26728	Economy	6200.00
0005435983421	26728	Economy	6200.00
0005435983306	26728	Economy	6200.00
0005435983462	26728	Economy	6200.00
0005435983019	26728	Economy	6200.00
0005435983412	26728	Economy	6200.00
0005435983090	26728	Economy	6200.00
0005435983089	26728	Economy	6200.00
0005435983487	26728	Economy	6200.00
0005435983446	26728	Economy	6200.00
0005435983415	26728	Economy	6200.00
0005435983155	26728	Economy	6200.00
0005435983459	26728	Economy	6200.00
0005435983340	26728	Economy	6200.00
0005435983277	26728	Economy	6200.00
0005433686689	29272	Economy	21000.00
0005433689967	29272	Economy	21000.00
0005433689968	29272	Economy	19100.00
0005433686688	29272	Economy	19100.00
0005433689964	29272	Economy	19100.00
0005433689960	29272	Economy	19100.00
0005433686690	29272	Economy	19100.00
0005433689961	29272	Economy	19100.00
0005433689965	29272	Economy	19100.00
0005433689959	29272	Economy	19100.00
0005432858397	3170	Economy	11100.00
0005432858378	3170	Economy	11100.00
0005432858398	3170	Economy	11100.00
0005432858370	3170	Economy	10100.00
0005432858364	3170	Economy	10100.00
0005432858392	3170	Economy	10100.00
0005432858386	3170	Economy	10100.00
0005432858325	3170	Economy	10100.00
0005432858385	3170	Economy	10100.00
0005432858369	3170	Economy	10100.00
0005432858324	3170	Economy	10100.00
0005432584628	31492	Economy	11100.00
0005432584728	31492	Economy	10100.00
0005432584722	31492	Economy	10100.00
0005432584666	31492	Economy	10100.00
0005432584669	31492	Economy	10100.00
0005432584629	31492	Economy	10100.00
0005432584664	31492	Economy	10100.00
0005432584769	31492	Economy	10100.00
0005432584712	31492	Economy	10100.00
0005432584699	31492	Economy	10100.00
0005432584643	31492	Economy	10100.00
0005432584627	31492	Economy	10100.00
0005432584670	31492	Economy	10100.00
0005432584721	31492	Economy	10100.00
0005432584681	31492	Economy	10100.00
0005432584665	31492	Economy	10100.00
0005432584680	31492	Economy	10100.00
0005433255266	887	Economy	8300.00
0005433255237	887	Economy	7500.00
0005433255238	887	Economy	7500.00
0005433255239	887	Economy	7500.00
0005433255254	887	Economy	7500.00
0005434943610	16192	Economy	8300.00
0005434943595	16192	Economy	7500.00
0005434943612	16192	Economy	7500.00
0005434943596	16192	Economy	7500.00
0005434943611	16192	Economy	7500.00
0005434943572	16192	Economy	7500.00
0005434943573	16192	Economy	7500.00
0005433927540	14391	Economy	4400.00
0005433811675	14391	Economy	4400.00
0005433368779	21760	Business	9800.00
0005433368814	21760	Business	9800.00
0005433368919	21760	Business	9800.00
0005433368748	21760	Business	9800.00
0005433368765	21760	Business	9800.00
0005433368753	21760	Economy	3300.00
0005435654497	21760	Economy	3300.00
0005433368745	21760	Economy	3300.00
0005433368746	21760	Economy	3300.00
0005433368913	21760	Economy	3300.00
0005433368728	21760	Economy	3600.00
0005433368838	21760	Economy	3300.00
0005433368778	21760	Economy	3300.00
0005433368747	21760	Economy	3300.00
0005433368912	21760	Economy	3300.00
0005433368876	21760	Economy	3300.00
0005433368883	21760	Economy	3300.00
0005433368812	21760	Economy	3300.00
0005433368877	21760	Economy	3300.00
0005433368727	21760	Economy	3300.00
0005433368798	21760	Economy	3300.00
0005433368918	21760	Economy	3300.00
0005433368760	21760	Economy	3300.00
0005433368914	21760	Economy	3300.00
0005433368783	21760	Economy	3300.00
0005433368840	21760	Economy	3300.00
0005433368892	21760	Economy	3300.00
0005433368709	21760	Economy	3300.00
0005433368763	21760	Economy	3300.00
0005433368708	21760	Economy	3300.00
0005433368774	21760	Economy	3300.00
0005433368742	21760	Economy	3300.00
0005433368815	21760	Economy	3300.00
0005433368724	21760	Economy	3300.00
0005433368865	21760	Economy	3300.00
0005433368856	21760	Economy	3300.00
0005433368864	21760	Economy	3300.00
0005433368756	21760	Economy	3300.00
0005433368776	21760	Economy	3300.00
0005435654495	21760	Economy	3300.00
0005433368878	21760	Economy	3300.00
0005435654496	21760	Economy	3300.00
0005433368752	21760	Economy	3300.00
0005433368889	21760	Economy	3300.00
0005433368764	21760	Economy	3300.00
0005433368777	21760	Economy	3300.00
0005433368759	21760	Economy	3300.00
0005433368743	21760	Economy	3300.00
0005433368786	21760	Economy	3300.00
0005433368755	21760	Economy	3300.00
0005434171391	9366	Business	186200.00
0005435270006	9366	Business	186200.00
0005434171429	9366	Business	186200.00
0005435270135	9366	Business	186200.00
0005435270005	9366	Business	186200.00
0005435270146	9366	Business	186200.00
0005435270155	9366	Business	186200.00
0005434171435	9366	Business	186200.00
0005435270079	9366	Business	186200.00
0005435858729	9366	Economy	68300.00
0005434171428	9366	Economy	68300.00
0005435270073	9366	Economy	62100.00
0005435270107	9366	Economy	62100.00
0005435270154	9366	Economy	62100.00
0005435270100	9366	Economy	62100.00
0005435269927	9366	Economy	62100.00
0005434273125	9366	Economy	62100.00
0005435269990	9366	Economy	62100.00
0005435270098	9366	Economy	62100.00
0005435270134	9366	Economy	62100.00
0005435270061	9366	Economy	62100.00
0005435269935	9366	Economy	62100.00
0005435270049	9366	Economy	62100.00
0005435270075	9366	Economy	62100.00
0005434273115	9366	Economy	62100.00
0005435270007	9366	Economy	62100.00
0005435270072	9366	Economy	62100.00
0005435270113	9366	Economy	62100.00
0005435269959	9366	Economy	62100.00
0005433786199	9366	Economy	62100.00
0005435270184	9366	Economy	62100.00
0005435269952	9366	Economy	68300.00
0005434171436	9366	Economy	62100.00
0005435269945	9366	Economy	62100.00
0005435270078	9366	Economy	62100.00
0005435270183	9366	Economy	62100.00
0005435270105	9366	Economy	62100.00
0005434151793	9366	Economy	62100.00
0005434273111	9366	Economy	62100.00
0005435270099	9366	Economy	62100.00
0005435269971	9366	Economy	62100.00
0005435858707	9366	Economy	62100.00
0005435270097	9366	Economy	62100.00
0005435858708	9366	Economy	62100.00
0005433786200	9366	Economy	62100.00
0005434171414	9366	Economy	62100.00
0005435270125	9366	Economy	62100.00
0005435858701	9366	Economy	62100.00
0005434171469	9366	Economy	62100.00
0005434151786	9366	Economy	62100.00
0005433786201	9366	Economy	62100.00
0005435858702	9366	Economy	62100.00
0005435269970	9366	Economy	62100.00
0005433806042	26223	Business	186200.00
0005433806259	26223	Business	186200.00
0005433806356	26223	Business	186200.00
0005432657527	26223	Business	186200.00
0005433785917	26223	Business	186200.00
0005433786180	26223	Business	186200.00
0005433806235	26223	Business	186200.00
0005433806257	26223	Business	186200.00
0005433785810	26223	Business	186200.00
0005433763617	26223	Business	186200.00
0005433785842	26223	Business	186200.00
0005433763601	26223	Economy	68300.00
0005433806244	26223	Economy	68300.00
0005433785866	26223	Economy	68300.00
0005433786054	26223	Economy	62100.00
0005433786064	26223	Economy	62100.00
0005433785828	26223	Economy	62100.00
0005433806293	26223	Economy	62100.00
0005433786179	26223	Economy	62100.00
0005433785996	26223	Economy	62100.00
0005433785970	26223	Economy	62100.00
0005433763556	26223	Economy	62100.00
0005433806352	26223	Economy	62100.00
0005432666430	26223	Economy	62100.00
0005433763505	26223	Economy	62100.00
0005433785856	26223	Economy	62100.00
0005433786003	26223	Economy	62100.00
0005433806245	26223	Economy	62100.00
0005432663090	26223	Economy	62100.00
0005433786127	26223	Economy	62100.00
0005432666433	26223	Economy	62100.00
0005433763576	26223	Economy	62100.00
0005433785880	26223	Economy	62100.00
0005433806342	26223	Economy	62100.00
0005433806294	26223	Economy	62100.00
0005434270267	26223	Economy	62100.00
0005433806256	26223	Economy	62100.00
0005433806228	26223	Economy	62100.00
0005432666442	26223	Economy	62100.00
0005433786049	26223	Economy	62100.00
0005432666441	26223	Economy	62100.00
0005432657529	26223	Economy	62100.00
0005433806311	26223	Economy	62100.00
0005433806310	26223	Economy	62100.00
0005433763618	26223	Economy	62100.00
0005433806277	26223	Economy	62100.00
0005433763588	26223	Economy	62100.00
0005434151796	26223	Economy	62100.00
0005432666440	26223	Economy	62100.00
0005433785871	26223	Economy	62100.00
0005433763526	26223	Economy	62100.00
0005433785713	26223	Economy	62100.00
0005433785911	26223	Economy	62100.00
0005433806351	26223	Economy	62100.00
0005433785878	26223	Economy	62100.00
0005433785950	26223	Economy	62100.00
0005433785851	26223	Economy	62100.00
0005432663091	26223	Economy	62100.00
0005433785784	26223	Economy	62100.00
0005433806043	26223	Economy	62100.00
0005433785891	26223	Economy	62100.00
0005433785862	26223	Economy	62100.00
0005433785867	26223	Economy	62100.00
0005433785844	26223	Economy	62100.00
0005433785946	26223	Economy	62100.00
0005433785872	26223	Economy	62100.00
0005433763575	26223	Economy	68300.00
0005433785932	26223	Economy	68300.00
0005433806236	26223	Economy	62100.00
0005433785861	26223	Economy	62100.00
0005433806154	26223	Economy	62100.00
0005433785935	26223	Economy	62100.00
0005433785895	26223	Economy	62100.00
0005433806158	26223	Economy	62100.00
0005433785865	26223	Economy	62100.00
0005433785951	26223	Economy	62100.00
0005433785888	26223	Economy	62100.00
0005433785890	26223	Economy	62100.00
0005433806156	26223	Economy	62100.00
0005433786009	26223	Economy	62100.00
0005433785826	26223	Economy	62100.00
0005433806155	26223	Economy	62100.00
0005433806276	26223	Economy	62100.00
0005433785879	26223	Economy	62100.00
0005433785857	26223	Economy	62100.00
0005432657530	26223	Economy	62100.00
0005433806224	26223	Economy	62100.00
0005432666432	26223	Economy	62100.00
0005433785843	26223	Economy	62100.00
0005433785912	26223	Economy	62100.00
0005433806183	26223	Economy	62100.00
0005433786085	26223	Economy	62100.00
0005433806341	26223	Economy	62100.00
0005433786010	26223	Economy	62100.00
0005433763504	26223	Economy	62100.00
0005433785811	26223	Economy	62100.00
0005433785884	26223	Economy	62100.00
0005433806115	26223	Economy	62100.00
0005433806205	26223	Economy	62100.00
0005433785887	26223	Economy	62100.00
0005432657528	26223	Economy	62100.00
0005433785816	26223	Economy	62100.00
0005433806206	26223	Economy	62100.00
0005433785933	26223	Economy	62100.00
0005433785868	26223	Economy	62100.00
0005432657524	26223	Economy	62100.00
0005432663096	26223	Economy	62100.00
0005433785821	26223	Economy	62100.00
0005433806324	26223	Economy	62100.00
0005433785822	26223	Economy	62100.00
0005433806229	26223	Economy	62100.00
0005432659759	26223	Economy	62100.00
0005433806323	26223	Economy	62100.00
0005433763555	26223	Economy	62100.00
0005433785712	26223	Economy	62100.00
0005435929711	4908	Economy	5300.00
0005435929712	4908	Economy	5300.00
0005435135795	33037	Economy	5300.00
0005435135774	33037	Economy	5300.00
0005435135792	33037	Economy	5300.00
0005435135775	33037	Economy	5300.00
0005434218081	9506	Economy	17900.00
0005434218057	9506	Economy	17900.00
0005434218066	9506	Economy	17900.00
0005434983419	27356	Economy	17900.00
0005434983424	27356	Economy	17900.00
0005434983420	27356	Economy	17900.00
0005433986937	24265	Business	36400.00
0005433987169	24265	Business	36400.00
0005433987095	24265	Business	36400.00
0005433961962	24265	Business	36400.00
0005433962102	24265	Business	36400.00
0005433962250	24265	Business	36400.00
0005433987225	24265	Business	36400.00
0005433987061	24265	Business	36400.00
0005433962015	24265	Business	36400.00
0005433962400	24265	Business	36400.00
0005433987109	24265	Economy	13400.00
0005433962372	24265	Economy	13400.00
0005433962249	24265	Economy	12100.00
0005433962403	24265	Economy	12100.00
0005433962195	24265	Economy	12100.00
0005433962309	24265	Economy	12100.00
0005433987046	24265	Economy	12100.00
0005433987294	24265	Economy	12100.00
0005433962373	24265	Economy	12100.00
0005433987113	24265	Economy	12100.00
0005433962173	24265	Economy	12100.00
0005433962291	24265	Economy	12100.00
0005433987214	24265	Economy	12100.00
0005433987063	24265	Economy	12100.00
0005433987250	24265	Economy	12100.00
0005433987143	24265	Economy	12100.00
0005433962192	24265	Economy	12100.00
0005433962283	24265	Economy	12100.00
0005433962305	24265	Economy	12100.00
0005433962308	24265	Economy	12100.00
0005433962261	24265	Economy	12100.00
0005433987108	24265	Economy	12100.00
0005433987015	24265	Economy	12100.00
0005433962233	24265	Economy	12100.00
0005433962232	24265	Economy	12100.00
0005433986852	24265	Economy	12100.00
0005433987168	24265	Economy	12100.00
0005433987229	24265	Economy	12100.00
0005433987155	24265	Economy	12100.00
0005433962346	24265	Economy	12100.00
0005433987230	24265	Economy	12100.00
0005433962325	24265	Economy	12100.00
0005433962263	24265	Economy	12100.00
0005433986925	24265	Economy	12100.00
0005433962209	24265	Economy	12100.00
0005433987149	24265	Economy	12100.00
0005433962113	24265	Economy	12100.00
0005433962328	24265	Economy	12100.00
0005433961948	24265	Economy	12100.00
0005433987189	24265	Economy	12100.00
0005433962284	24265	Economy	12100.00
0005433962161	24265	Economy	12100.00
0005433962318	24265	Economy	12100.00
0005433962407	24265	Economy	12100.00
0005433986999	24265	Economy	12100.00
0005433987234	24265	Economy	12100.00
0005433962260	24265	Economy	12100.00
0005433962155	24265	Economy	12100.00
0005433962347	24265	Economy	12100.00
0005433962378	24265	Economy	12100.00
0005433987245	24265	Economy	12100.00
0005433962277	24265	Economy	12100.00
0005433962179	24265	Economy	12100.00
0005433962358	24265	Economy	12100.00
0005433987014	24265	Economy	13400.00
0005433962357	24265	Economy	13400.00
0005433987059	24265	Economy	12100.00
0005433962241	24265	Economy	12100.00
0005433987190	24265	Economy	12100.00
0005433987135	24265	Economy	12100.00
0005433986865	24265	Economy	12100.00
0005433962398	24265	Economy	12100.00
0005433986972	24265	Economy	12100.00
0005433961963	24265	Economy	12100.00
0005433962208	24265	Economy	12100.00
0005433962339	24265	Economy	12100.00
0005433962399	24265	Economy	12100.00
0005433987056	24265	Economy	12100.00
0005433987199	24265	Economy	12100.00
0005433962340	24265	Economy	12100.00
0005433962282	24265	Economy	12100.00
0005433986973	24265	Economy	12100.00
0005433986866	24265	Economy	12100.00
0005433986977	24265	Economy	12100.00
0005433962158	24265	Economy	12100.00
0005433987136	24265	Economy	12100.00
0005433962345	24265	Economy	12100.00
0005433962310	24265	Economy	12100.00
0005433987206	24265	Economy	12100.00
0005433987194	24265	Economy	12100.00
0005433987062	24265	Economy	12100.00
0005433987092	24265	Economy	12100.00
0005433987115	24265	Economy	12100.00
0005433987207	24265	Economy	12100.00
0005433962108	24265	Economy	12100.00
0005433987107	24265	Economy	12100.00
0005433987159	24265	Economy	12100.00
0005433962402	24265	Economy	12100.00
0005433962281	24265	Economy	12100.00
0005433987114	24265	Economy	12100.00
0005433962374	24265	Economy	12100.00
0005433987167	24265	Economy	12100.00
0005433962175	24265	Economy	12100.00
0005433962320	24265	Economy	12100.00
0005433962764	25917	Business	36400.00
0005433962755	25917	Business	36400.00
0005433962758	25917	Economy	12100.00
0005433962753	25917	Economy	12100.00
0005433987378	25917	Economy	12100.00
0005433962756	25917	Economy	12100.00
0005433962759	25917	Economy	12100.00
0005433962757	25917	Economy	12100.00
0005433962760	25917	Economy	12100.00
0005433962761	25917	Economy	12100.00
0005433962763	25917	Economy	13400.00
0005433962752	25917	Economy	12100.00
0005433962754	25917	Economy	12100.00
0005433962762	25917	Economy	12100.00
0005433166238	916	Economy	25400.00
0005433166269	916	Economy	25400.00
0005433166237	916	Economy	25400.00
0005433166261	916	Economy	23100.00
0005433166260	916	Economy	23100.00
0005433166218	916	Economy	23100.00
0005433166235	916	Economy	23100.00
0005433166249	916	Economy	23100.00
0005433166262	916	Economy	23100.00
0005433166265	916	Economy	23100.00
0005433166220	916	Economy	23100.00
0005433166219	916	Economy	23100.00
0005433166236	916	Economy	23100.00
0005433166234	916	Economy	23100.00
0005433166233	916	Economy	23100.00
0005433166253	916	Economy	23100.00
0005433166209	916	Economy	23100.00
0005433166208	916	Economy	23100.00
0005434481054	916	Economy	23100.00
0005434481006	16585	Economy	25400.00
0005434480917	16585	Economy	25400.00
0005434481004	16585	Economy	23100.00
0005434480954	16585	Economy	23100.00
0005434480964	16585	Economy	23100.00
0005434480945	16585	Economy	23100.00
0005434480966	16585	Economy	23100.00
0005434481001	16585	Economy	23100.00
0005434480942	16585	Economy	23100.00
0005434480903	16585	Economy	23100.00
0005434481009	16585	Economy	23100.00
0005434480969	16585	Economy	23100.00
0005434480952	16585	Economy	23100.00
0005434481005	16585	Economy	23100.00
0005434481031	16585	Economy	23100.00
0005434480870	16585	Economy	23100.00
0005434480904	16585	Economy	23100.00
0005434480968	16585	Economy	23100.00
0005434481021	16585	Economy	23100.00
0005434480944	16585	Economy	23100.00
0005434480990	16585	Economy	23100.00
0005434481027	16585	Economy	23100.00
0005434480918	16585	Economy	23100.00
0005434481022	16585	Economy	23100.00
0005434480943	16585	Economy	23100.00
0005434481010	16585	Economy	23100.00
0005434480836	16585	Economy	23100.00
0005433872565	32560	Economy	17200.00
0005433872576	32560	Economy	17200.00
0005433872587	32560	Economy	17200.00
0005433872559	32560	Economy	17200.00
0005433872570	32560	Economy	17200.00
0005433872573	32560	Economy	17200.00
0005433872578	32560	Economy	17200.00
0005433872580	32560	Economy	17200.00
0005433872569	32560	Economy	17200.00
0005433872586	32560	Economy	17200.00
0005433872585	32560	Economy	17200.00
0005433872562	32560	Economy	17200.00
0005433872577	32560	Economy	17200.00
0005433872572	32560	Economy	17200.00
0005433872561	32560	Economy	17200.00
0005433872558	32560	Economy	17200.00
0005433290019	10318	Economy	15400.00
0005433290042	10318	Economy	15400.00
0005435142970	10318	Economy	15400.00
0005433290037	10318	Economy	15400.00
0005433290020	10318	Economy	15400.00
0005433290006	10318	Economy	15400.00
0005435142969	10318	Economy	15400.00
0005433290015	10318	Economy	15400.00
0005433290043	10318	Economy	15400.00
0005433290038	10318	Economy	15400.00
0005435142901	21918	Economy	17000.00
0005435150411	21918	Economy	17000.00
0005435150428	21918	Economy	17000.00
0005435150325	21918	Economy	15400.00
0005435142929	21918	Economy	15400.00
0005435142849	21918	Economy	15400.00
0005435150394	21918	Economy	15400.00
0005435150393	21918	Economy	15400.00
0005435150396	21918	Economy	15400.00
0005435142910	21918	Economy	15400.00
0005435142891	21918	Economy	15400.00
0005435150412	21918	Economy	15400.00
0005435142918	21918	Economy	15400.00
0005435150380	21918	Economy	15400.00
0005435150395	21918	Economy	15400.00
0005435142863	21918	Economy	15400.00
0005435142851	21918	Economy	15400.00
0005435142884	21918	Economy	15400.00
0005435142921	21918	Economy	15400.00
0005435150324	21918	Economy	15400.00
0005435150429	21918	Economy	15400.00
0005435150292	21918	Economy	15400.00
0005435150366	21918	Economy	15400.00
0005435150422	21918	Economy	15400.00
0005435142872	21918	Economy	15400.00
0005435150354	21918	Economy	15400.00
0005435142895	21918	Economy	15400.00
0005435142909	21918	Economy	15400.00
0005435150353	21918	Economy	15400.00
0005433290067	21918	Economy	15400.00
0005435142850	21918	Economy	15400.00
0005435150421	21918	Economy	15400.00
0005435150382	21918	Economy	15400.00
0005435502854	11209	Business	57200.00
0005435529760	11209	Business	57200.00
0005434573776	11209	Business	57200.00
0005435502832	11209	Business	57200.00
0005435529833	11209	Business	57200.00
0005435502915	11209	Business	57200.00
0005435529816	11209	Business	57200.00
0005435529750	11209	Economy	19100.00
0005435545951	11209	Economy	19100.00
0005435529805	11209	Economy	19100.00
0005435529827	11209	Economy	19100.00
0005434573774	11209	Economy	21000.00
0005435502793	11209	Economy	21000.00
0005434573775	11209	Economy	21000.00
0005435319762	11209	Economy	19100.00
0005435529784	11209	Economy	19100.00
0005435502801	11209	Economy	19100.00
0005435502886	11209	Economy	19100.00
0005435529735	11209	Economy	19100.00
0005435529751	11209	Economy	19100.00
0005435529806	11209	Economy	19100.00
0005435545931	11209	Economy	19100.00
0005435502904	11209	Economy	19100.00
0005435529769	11209	Economy	19100.00
0005435319822	11209	Economy	19100.00
0005435529807	11209	Economy	19100.00
0005435529817	11209	Economy	19100.00
0005435529832	11209	Economy	19100.00
0005435319799	11209	Economy	19100.00
0005435529778	11209	Economy	19100.00
0005435502853	11209	Economy	19100.00
0005435529856	11209	Economy	19100.00
0005435545932	11209	Economy	19100.00
0005435545906	11209	Economy	19100.00
0005435529734	11209	Economy	19100.00
0005435529838	11209	Economy	19100.00
0005435529761	11209	Economy	19100.00
0005435502868	11209	Economy	19100.00
0005435529770	11209	Economy	19100.00
0005435545946	11209	Economy	19100.00
0005435502965	20926	Business	57200.00
0005434573721	20926	Business	57200.00
0005434573720	20926	Economy	21000.00
0005434573751	20926	Economy	21000.00
0005434573687	20926	Economy	19100.00
0005434573705	20926	Economy	19100.00
0005434573696	20926	Economy	19100.00
0005434573713	20926	Economy	19100.00
0005434573750	20926	Economy	19100.00
0005434573742	20926	Economy	19100.00
0005434573697	20926	Economy	19100.00
0005434573698	20926	Economy	19100.00
0005434573704	20926	Economy	19100.00
0005434573699	20926	Economy	19100.00
0005435502966	20926	Economy	19100.00
0005435508833	20926	Economy	19100.00
0005434573733	20926	Economy	19100.00
0005435502964	20926	Economy	19100.00
0005434573728	20926	Economy	19100.00
0005432693899	3018	Business	10300.00
0005432693795	3018	Business	10300.00
0005432693842	3018	Business	10300.00
0005432693925	3018	Business	10300.00
0005432693902	3018	Economy	3400.00
0005432693862	3018	Economy	3400.00
0005432693874	3018	Economy	3400.00
0005432693843	3018	Economy	3400.00
0005432693784	3018	Economy	3400.00
0005432693855	3018	Economy	3800.00
0005432693715	3018	Economy	3400.00
0005432693773	3018	Economy	3400.00
0005432693807	3018	Economy	3400.00
0005432693875	3018	Economy	3400.00
0005432693776	3018	Economy	3400.00
0005432693863	3018	Economy	3400.00
0005432693800	3018	Economy	3400.00
0005432693830	3018	Economy	3400.00
0005432693823	3018	Economy	3400.00
0005432693890	3018	Economy	3400.00
0005432693854	3018	Economy	3400.00
0005432693898	3018	Economy	3400.00
0005432693806	3018	Economy	3400.00
0005432693824	3018	Economy	3400.00
0005432693788	3018	Economy	3400.00
0005432693789	3018	Economy	3400.00
0005432693796	3018	Economy	3400.00
0005432693794	3018	Economy	3400.00
0005432693688	3018	Economy	3400.00
0005432693886	3018	Economy	3400.00
0005432693864	3018	Economy	3400.00
0005432881211	3020	Business	10300.00
0005433124392	3020	Business	10300.00
0005433194951	3020	Business	10300.00
0005433194973	3020	Business	10300.00
0005433124440	3020	Business	10300.00
0005433124444	3020	Business	10300.00
0005433124452	3020	Economy	3400.00
0005433124501	3020	Economy	3400.00
0005433194944	3020	Economy	3400.00
0005433124353	3020	Economy	3400.00
0005433124507	3020	Economy	3400.00
0005433124441	3020	Economy	3400.00
0005433124380	3020	Economy	3400.00
0005433194943	3020	Economy	3800.00
0005432881197	3020	Economy	3400.00
0005433194927	3020	Economy	3400.00
0005433124447	3020	Economy	3400.00
0005432881230	3020	Economy	3400.00
0005432881181	3020	Economy	3400.00
0005433124446	3020	Economy	3400.00
0005433124468	3020	Economy	3400.00
0005432881172	3020	Economy	3400.00
0005432881231	3020	Economy	3400.00
0005433124445	3020	Economy	3400.00
0005433124460	3020	Economy	3400.00
0005432881151	3020	Economy	3400.00
0005432881195	3020	Economy	3400.00
0005432881196	3020	Economy	3400.00
0005433124448	3020	Economy	3400.00
0005432881153	3020	Economy	3400.00
0005433195007	3020	Economy	3400.00
0005433124435	3020	Economy	3400.00
0005433124332	3020	Economy	3400.00
0005432881238	3020	Economy	3400.00
0005433124500	3020	Economy	3400.00
0005432881160	3020	Economy	3400.00
0005433124461	3020	Economy	3400.00
0005432881129	3020	Economy	3400.00
0005433124391	3020	Economy	3400.00
0005432881180	3020	Economy	3400.00
0005433124506	3020	Economy	3400.00
0005432881182	3020	Economy	3400.00
0005433124354	3020	Economy	3400.00
0005432881208	3020	Economy	3400.00
0005432881239	3020	Economy	3400.00
0005432707369	29963	Business	10300.00
0005432707379	29963	Business	10300.00
0005433124553	29963	Business	10300.00
0005433124554	29963	Business	10300.00
0005432707362	29963	Economy	3400.00
0005433195017	29963	Economy	3800.00
0005432881249	29963	Economy	3400.00
0005433195016	29963	Economy	3400.00
0005432707501	29963	Economy	3400.00
0005432707316	29963	Economy	3400.00
0005432707371	29963	Economy	3400.00
0005432707433	29963	Economy	3400.00
0005432707372	29963	Economy	3400.00
0005432707441	29963	Economy	3400.00
0005432707317	29963	Economy	3400.00
0005432707395	29963	Economy	3400.00
0005432707398	29963	Economy	3400.00
0005432707463	29963	Economy	3400.00
0005432707389	29963	Economy	3400.00
0005432707380	29963	Economy	3400.00
0005432707397	29963	Economy	3400.00
0005432707434	29963	Economy	3400.00
0005432707390	29963	Economy	3400.00
0005432707439	29963	Economy	3400.00
0005432707436	29963	Economy	3400.00
0005432707464	29963	Economy	3400.00
0005432707443	29963	Economy	3400.00
0005432707440	29963	Economy	3400.00
0005432707396	29963	Economy	3400.00
0005434989132	23673	Economy	3600.00
0005434989131	23673	Economy	3600.00
0005434988977	27560	Economy	4000.00
0005434988982	27560	Economy	4000.00
0005434980457	27560	Economy	4000.00
0005434988981	27560	Economy	4000.00
0005434980493	27560	Economy	3600.00
0005434980558	27560	Economy	3600.00
0005434980485	27560	Economy	3600.00
0005434980543	27560	Economy	3600.00
0005434980580	27560	Economy	3600.00
0005434980571	27560	Economy	3600.00
0005434988964	27560	Economy	3600.00
0005434980514	27560	Economy	3600.00
0005434980505	27560	Economy	3600.00
0005434980416	27560	Economy	3600.00
0005434980573	27560	Economy	3600.00
0005434980613	27560	Economy	3600.00
0005434980492	27560	Economy	3600.00
0005434980442	27560	Economy	3600.00
0005434980458	27560	Economy	3600.00
0005434980502	27560	Economy	3600.00
0005434980522	27560	Economy	3600.00
0005434980417	27560	Economy	3600.00
0005434980509	27560	Economy	3600.00
0005434980568	27560	Economy	3600.00
0005434980477	27560	Economy	3600.00
0005434980567	27560	Economy	3600.00
0005434988996	27560	Economy	3600.00
0005434980572	27560	Economy	3600.00
0005434988971	27560	Economy	3600.00
0005434980523	27560	Economy	3600.00
0005434980529	27560	Economy	3600.00
0005434980516	27560	Economy	3600.00
0005434988993	27560	Economy	3600.00
0005434980549	27560	Economy	3600.00
0005434980579	27560	Economy	3600.00
0005434988963	27560	Economy	3600.00
0005434980548	27560	Economy	3600.00
0005434988980	27560	Economy	3600.00
0005434988992	27560	Economy	3600.00
0005434980460	27560	Economy	3600.00
0005434980603	27560	Economy	3600.00
0005434980614	27560	Economy	3600.00
0005434989006	27560	Economy	3600.00
0005434980517	27560	Economy	3600.00
0005434980484	27560	Economy	3600.00
0005434980604	27560	Economy	3600.00
0005434980490	27560	Economy	3600.00
0005434980340	27560	Economy	3600.00
0005434980550	27560	Economy	3600.00
0005433111558	10261	Economy	19700.00
0005433113589	10261	Economy	19700.00
0005433111562	10261	Economy	19700.00
0005433111553	10261	Economy	19700.00
0005433111563	10261	Economy	19700.00
0005433111552	10261	Economy	19700.00
0005434302562	19605	Economy	19700.00
0005434302550	19605	Economy	19700.00
0005434302551	19605	Economy	19700.00
0005434302569	19605	Economy	19700.00
0005434302549	19605	Economy	19700.00
0005435925642	3550	Business	26900.00
0005435925651	3550	Business	26900.00
0005435925687	3550	Business	26900.00
0005435925684	3550	Economy	9000.00
0005435925666	3550	Economy	9000.00
0005435939944	3550	Economy	9900.00
0005435925592	3550	Economy	9000.00
0005435070568	3550	Economy	9000.00
0005435925667	3550	Economy	9000.00
0005435925668	3550	Economy	9000.00
0005435925567	3550	Economy	9000.00
0005435925568	3550	Economy	9000.00
0005435925675	3550	Economy	9000.00
0005435925688	3550	Economy	9000.00
0005435070567	3550	Economy	9000.00
0005435925686	3550	Economy	9000.00
0005435939943	3550	Economy	9000.00
0005435939939	3550	Economy	9000.00
0005435925689	3550	Economy	9000.00
0005435925676	3550	Economy	9000.00
0005435925682	3550	Economy	9000.00
0005435925669	3550	Economy	9000.00
0005435925641	3550	Economy	9000.00
0005435925658	3550	Economy	9000.00
0005435925659	3550	Economy	9000.00
0005435925665	3550	Economy	9000.00
0005435070230	15291	Business	26900.00
0005435070482	15291	Business	26900.00
0005435070289	15291	Business	26900.00
0005435070032	15291	Business	26900.00
0005435070502	15291	Business	26900.00
0005435070342	15291	Economy	9000.00
0005435070228	15291	Economy	9000.00
0005435070431	15291	Economy	9000.00
0005435070446	15291	Economy	9000.00
0005435070262	15291	Economy	9000.00
0005435070177	15291	Economy	9900.00
0005435070160	15291	Economy	9000.00
0005435070214	15291	Economy	9000.00
0005435070538	15291	Economy	9000.00
0005435070422	15291	Economy	9000.00
0005435070448	15291	Economy	9000.00
0005435070137	15291	Economy	9000.00
0005435070112	15291	Economy	9000.00
0005435950307	15291	Economy	9000.00
0005435070272	15291	Economy	9000.00
0005435070138	15291	Economy	9000.00
0005435070178	15291	Economy	9000.00
0005435070371	15291	Economy	9000.00
0005435950331	15291	Economy	9000.00
0005435070549	15291	Economy	9000.00
0005435070407	15291	Economy	9000.00
0005435070215	15291	Economy	9000.00
0005435070229	15291	Economy	9000.00
0005435070435	15291	Economy	9000.00
0005435070265	15291	Economy	9000.00
0005435070370	15291	Economy	9000.00
0005435070414	15291	Economy	9000.00
0005435070237	15291	Economy	9000.00
0005435070266	15291	Economy	9000.00
0005435070100	15291	Economy	9000.00
0005435070236	15291	Economy	9000.00
0005435070474	15291	Economy	9000.00
0005435939976	15291	Economy	9000.00
0005435939975	15291	Economy	9000.00
0005435070447	15291	Economy	9000.00
0005435070475	15291	Economy	9000.00
0005435070381	15291	Economy	9000.00
0005435070101	15291	Economy	9000.00
0005435950326	15291	Economy	9000.00
0005435070113	15291	Economy	9000.00
0005435070483	15291	Economy	9000.00
0005432667506	26418	Economy	5900.00
0005432667510	26418	Economy	5900.00
0005432660871	26418	Economy	5900.00
0005432660872	26418	Economy	5900.00
0005432660877	26418	Economy	5900.00
0005432660873	26418	Economy	5900.00
0005432667507	26418	Economy	5900.00
0005433103485	198	Business	20000.00
0005432920409	198	Business	20000.00
0005433103600	198	Business	20000.00
0005433103564	198	Business	20000.00
0005433103381	198	Business	20000.00
0005432902098	198	Business	20000.00
0005433103507	198	Business	20000.00
0005433103392	198	Business	20000.00
0005432920446	198	Business	20000.00
0005432677677	198	Business	20000.00
0005433103568	198	Business	20000.00
0005433103557	198	Business	20000.00
0005432920456	198	Business	20000.00
0005433103380	198	Business	20000.00
0005432677675	198	Economy	7300.00
0005433103458	198	Business	20000.00
0005433103647	198	Economy	7300.00
0005433103587	198	Economy	7300.00
0005432902030	198	Economy	7300.00
0005432920437	198	Economy	7300.00
0005433103419	198	Economy	6700.00
0005433103606	198	Economy	6700.00
0005432920413	198	Economy	6700.00
0005433103618	198	Economy	6700.00
0005432920410	198	Economy	6700.00
0005432677664	198	Economy	6700.00
0005432920386	198	Economy	6700.00
0005433103631	198	Economy	6700.00
0005432902022	198	Economy	6700.00
0005433103475	198	Economy	6700.00
0005433103387	198	Economy	6700.00
0005433103189	198	Economy	6700.00
0005432920396	198	Economy	6700.00
0005433103190	198	Economy	6700.00
0005433103635	198	Economy	6700.00
0005433103588	198	Economy	6700.00
0005433103382	198	Economy	6700.00
0005433103591	198	Economy	6700.00
0005433103605	198	Economy	6700.00
0005433103468	198	Economy	6700.00
0005433103577	198	Economy	6700.00
0005433103454	198	Economy	6700.00
0005433103556	198	Economy	6700.00
0005433103583	198	Economy	6700.00
0005433103585	198	Economy	6700.00
0005433103526	198	Economy	6700.00
0005433103626	198	Economy	6700.00
0005432920429	198	Economy	6700.00
0005432902102	198	Economy	6700.00
0005432920418	198	Economy	6700.00
0005433103391	198	Economy	6700.00
0005432920463	198	Economy	6700.00
0005432920315	198	Economy	6700.00
0005432920462	198	Economy	6700.00
0005432902052	198	Economy	6700.00
0005433103544	198	Economy	6700.00
0005433103393	198	Economy	6700.00
0005432920428	198	Economy	6700.00
0005432920472	198	Economy	6700.00
0005433103467	198	Economy	6700.00
0005433103640	198	Economy	7300.00
0005433103501	198	Economy	7300.00
0005433103515	198	Economy	7300.00
0005432677668	198	Economy	7300.00
0005433103578	198	Economy	6700.00
0005432920445	198	Economy	6700.00
0005433103547	198	Economy	6700.00
0005432677680	198	Economy	6700.00
0005432677669	198	Economy	7300.00
0005432920388	198	Economy	6700.00
0005433103579	198	Economy	6700.00
0005432902113	198	Economy	6700.00
0005432902044	198	Economy	6700.00
0005433103356	198	Economy	6700.00
0005433103567	198	Economy	6700.00
0005433103484	198	Economy	6700.00
0005433103519	198	Economy	6700.00
0005433103474	198	Economy	6700.00
0005433103569	198	Economy	6700.00
0005433103641	198	Economy	6700.00
0005432920316	198	Economy	6700.00
0005432920407	198	Economy	6700.00
0005432920412	198	Economy	6700.00
0005433103630	198	Economy	6700.00
0005433103453	198	Economy	6700.00
0005433103586	198	Economy	6700.00
0005433103555	198	Economy	6700.00
0005433103514	198	Economy	6700.00
0005432677670	198	Economy	6700.00
0005432902051	198	Economy	6700.00
0005433103456	198	Economy	6700.00
0005433103551	198	Economy	6700.00
0005433103584	198	Economy	6700.00
0005432920440	198	Economy	6700.00
0005433103455	198	Economy	6700.00
0005433103565	198	Economy	6700.00
0005432920378	198	Economy	6700.00
0005433103471	198	Economy	6700.00
0005433103604	198	Economy	6700.00
0005433103622	198	Economy	6700.00
0005432920447	198	Economy	6700.00
0005432677679	198	Economy	6700.00
0005432902057	198	Economy	6700.00
0005433103529	198	Economy	6700.00
0005433103621	198	Economy	6700.00
0005433103540	198	Economy	6700.00
0005432902091	198	Economy	6700.00
0005433103390	198	Economy	6700.00
0005432920390	198	Economy	6700.00
0005432677672	198	Economy	6700.00
0005432920389	198	Economy	6700.00
0005433103520	198	Economy	6700.00
0005433103632	198	Economy	6700.00
0005432920448	198	Economy	6700.00
0005433477296	197	Business	20000.00
0005434152874	197	Business	20000.00
0005432263234	197	Business	20000.00
0005434157987	197	Business	20000.00
0005434175881	197	Business	20000.00
0005434157988	197	Economy	7300.00
0005433687761	197	Economy	6700.00
0005434157986	197	Economy	6700.00
0005433929887	197	Economy	6700.00
0005432756922	197	Economy	6700.00
0005434191331	197	Economy	6700.00
0005434191332	197	Economy	6700.00
0005432263237	197	Economy	6700.00
0005432756917	197	Economy	6700.00
0005434157984	197	Economy	6700.00
0005434215910	197	Economy	6700.00
0005432263236	197	Economy	6700.00
0005433687762	197	Economy	6700.00
0005433690975	197	Economy	6700.00
0005433929888	197	Economy	6700.00
0005432263235	197	Economy	6700.00
0005432753383	197	Economy	6700.00
0005434175882	197	Economy	6700.00
0005433477295	197	Economy	6700.00
0005434157985	197	Economy	6700.00
0005433477294	197	Economy	6700.00
0005432263233	197	Economy	6700.00
0005433690991	8149	Business	20000.00
0005433104003	8149	Business	20000.00
0005433103996	8149	Business	20000.00
0005433104002	8149	Business	20000.00
0005433690989	8149	Business	20000.00
0005433477136	8149	Economy	7300.00
0005433103997	8149	Economy	7300.00
0005433690990	8149	Economy	6700.00
0005433104004	8149	Economy	6700.00
0005433477225	8149	Economy	6700.00
0005433690988	8149	Economy	6700.00
0005433477101	8149	Economy	6700.00
0005434152862	8149	Economy	6700.00
0005434157719	8149	Economy	6700.00
0005433477052	8149	Economy	6700.00
0005434157727	8149	Economy	6700.00
0005433477120	8149	Economy	6700.00
0005434157720	8149	Economy	6700.00
0005432920481	8149	Economy	6700.00
0005433477155	8149	Economy	6700.00
0005433477263	8149	Economy	6700.00
0005433477195	8149	Economy	6700.00
0005434028400	8149	Economy	6700.00
0005433477202	8149	Economy	6700.00
0005433477241	8149	Economy	6700.00
0005433477262	8149	Economy	6700.00
0005433477184	8149	Economy	6700.00
0005433477100	8149	Economy	6700.00
0005433103998	8149	Economy	6700.00
0005434157726	8149	Economy	7300.00
0005433103994	8149	Economy	7300.00
0005433104000	8149	Economy	7300.00
0005433103995	8149	Economy	6700.00
0005433477185	8149	Economy	7300.00
0005433477179	8149	Economy	6700.00
0005434152863	8149	Economy	6700.00
0005433477211	8149	Economy	6700.00
0005433477240	8149	Economy	6700.00
0005433929898	8149	Economy	6700.00
0005433477007	8149	Economy	6700.00
0005433104005	8149	Economy	6700.00
0005433104006	8149	Economy	6700.00
0005432920482	8149	Economy	6700.00
0005433477019	8149	Economy	6700.00
0005433477171	8149	Economy	6700.00
0005433103999	8149	Economy	6700.00
0005433104001	8149	Economy	6700.00
0005433477020	8149	Economy	6700.00
0005433104007	8149	Economy	6700.00
0005433477201	8149	Economy	6700.00
0005433477169	8149	Economy	6700.00
0005434152864	8149	Economy	6700.00
0005433477085	8149	Economy	6700.00
0005433477086	8149	Economy	6700.00
0005434157721	8149	Economy	6700.00
0005432818246	8150	Business	20000.00
0005432818265	8150	Business	20000.00
0005432818075	8150	Business	20000.00
0005432818210	8150	Business	20000.00
0005432818166	8150	Economy	7300.00
0005432818307	8150	Economy	6700.00
0005432818226	8150	Economy	6700.00
0005432818152	8150	Economy	6700.00
0005432818249	8150	Economy	6700.00
0005432818256	8150	Economy	6700.00
0005432818301	8150	Economy	6700.00
0005432818251	8150	Economy	6700.00
0005432818193	8150	Economy	6700.00
0005432818302	8150	Economy	6700.00
0005432818266	8150	Economy	6700.00
0005432818215	8150	Economy	6700.00
0005432818247	8150	Economy	6700.00
0005432818268	8150	Economy	6700.00
0005432818091	8150	Economy	6700.00
0005432818192	8150	Economy	6700.00
0005432818197	8150	Economy	6700.00
0005432818227	8150	Economy	6700.00
0005432818252	8150	Economy	6700.00
0005432818184	8150	Economy	6700.00
0005432818185	8150	Economy	6700.00
0005432818191	8150	Economy	6700.00
0005432818092	8150	Economy	6700.00
0005432818300	8150	Economy	6700.00
0005432818250	8150	Economy	6700.00
0005434175856	9660	Economy	6900.00
0005434175862	9660	Economy	6900.00
0005434175857	9660	Economy	6900.00
0005434175861	9660	Economy	6900.00
0005434175868	9660	Economy	6900.00
0005434175855	9660	Economy	6900.00
0005434175854	9660	Economy	6900.00
0005435914758	3519	Business	35000.00
0005435914765	3519	Business	35000.00
0005434427474	3519	Comfort	19900.00
0005435903188	3519	Comfort	19900.00
0005434880991	3519	Comfort	19900.00
0005435914740	3519	Comfort	19900.00
0005434880989	3519	Comfort	19900.00
0005434427475	3519	Economy	11700.00
0005435127588	3519	Economy	11700.00
0005435914068	3519	Economy	11700.00
0005435626870	3519	Economy	11700.00
0005435903187	3519	Economy	11700.00
0005435914133	3519	Economy	11700.00
0005435914074	3519	Economy	11700.00
0005435914114	3519	Economy	11700.00
0005435914078	3519	Economy	11700.00
0005435914134	3519	Economy	11700.00
0005435903173	3519	Economy	12800.00
0005435914742	3519	Economy	11700.00
0005435903143	3519	Economy	11700.00
0005435914027	3519	Economy	11700.00
0005435626868	3519	Economy	11700.00
0005434880990	3519	Economy	11700.00
0005435914132	3519	Economy	11700.00
0005434427473	3519	Economy	11700.00
0005435914115	3519	Economy	11700.00
0005435914766	3519	Economy	11700.00
0005435841842	3519	Economy	11700.00
0005435903186	3519	Economy	11700.00
0005435903172	3519	Economy	11700.00
0005435914741	3519	Economy	11700.00
0005435914075	3519	Economy	11700.00
0005435626869	3519	Economy	11700.00
0005435626871	3519	Economy	11700.00
0005435914069	3519	Economy	11700.00
0005435903136	3519	Economy	11700.00
0005435903178	3519	Economy	11700.00
0005435914091	3519	Economy	11700.00
0005435914124	3519	Economy	11700.00
0005435903191	3519	Economy	11700.00
0005435841843	3519	Economy	11700.00
0005435914028	3519	Economy	11700.00
0005435626614	14539	Business	35000.00
0005435127548	14539	Business	35000.00
0005435626613	14539	Business	35000.00
0005434938685	14539	Business	35000.00
0005434427356	14539	Business	35000.00
0005434427425	14539	Business	35000.00
0005434880829	14539	Business	35000.00
0005434880234	14539	Business	35000.00
0005432800147	14539	Business	35000.00
0005434880446	14539	Business	35000.00
0005435127477	14539	Business	35000.00
0005435127340	14539	Business	35000.00
0005434427329	14539	Business	35000.00
0005434880795	14539	Business	35000.00
0005435626616	14539	Business	35000.00
0005434427413	14539	Comfort	19900.00
0005434880713	14539	Comfort	19900.00
0005434880559	14539	Comfort	19900.00
0005435127333	14539	Comfort	19900.00
0005435127362	14539	Comfort	19900.00
0005435127316	14539	Comfort	19900.00
0005435127191	14539	Comfort	19900.00
0005432800245	14539	Comfort	19900.00
0005435626629	14539	Comfort	19900.00
0005434880915	14539	Comfort	19900.00
0005434880903	14539	Comfort	19900.00
0005432800199	14539	Comfort	19900.00
0005434880451	14539	Comfort	19900.00
0005434880574	14539	Comfort	19900.00
0005434880662	14539	Comfort	19900.00
0005432800151	14539	Comfort	19900.00
0005432800266	14539	Comfort	19900.00
0005434880445	14539	Comfort	19900.00
0005434880820	14539	Comfort	19900.00
0005435626532	14539	Comfort	19900.00
0005434938588	14539	Comfort	19900.00
0005434880859	14539	Comfort	19900.00
0005434427317	14539	Comfort	19900.00
0005434880796	14539	Comfort	19900.00
0005435127511	14539	Comfort	19900.00
0005432800244	14539	Comfort	19900.00
0005434938686	14539	Comfort	19900.00
0005434427357	14539	Economy	11700.00
0005434427304	14539	Economy	11700.00
0005434880940	14539	Economy	11700.00
0005434880673	14539	Economy	11700.00
0005435127415	14539	Economy	11700.00
0005435127444	14539	Economy	11700.00
0005434880467	14539	Economy	11700.00
0005435626615	14539	Economy	11700.00
0005434880798	14539	Economy	11700.00
0005432800112	14539	Economy	11700.00
0005435626612	14539	Economy	11700.00
0005434427217	14539	Economy	11700.00
0005432611795	14539	Economy	11700.00
0005434880492	14539	Economy	11700.00
0005432800204	14539	Economy	11700.00
0005432800233	14539	Economy	11700.00
0005434880459	14539	Economy	11700.00
0005434880699	14539	Economy	11700.00
0005432800228	14539	Economy	11700.00
0005435127335	14539	Economy	11700.00
0005432800194	14539	Economy	11700.00
0005435626604	14539	Economy	11700.00
0005434880546	14539	Economy	11700.00
0005434880698	14539	Economy	11700.00
0005435127332	14539	Economy	11700.00
0005432800224	14539	Economy	11700.00
0005434880541	14539	Economy	11700.00
0005434880233	14539	Economy	11700.00
0005434880809	14539	Economy	11700.00
0005434427328	14539	Economy	11700.00
0005434427358	14539	Economy	11700.00
0005435127416	14539	Economy	11700.00
0005434880638	14539	Economy	11700.00
0005435127401	14539	Economy	11700.00
0005434427398	14539	Economy	11700.00
0005434880522	14539	Economy	11700.00
0005435127352	14539	Economy	11700.00
0005432800200	14539	Economy	11700.00
0005432800241	14539	Economy	11700.00
0005434880504	14539	Economy	11700.00
0005434427332	14539	Economy	11700.00
0005432800236	14539	Economy	11700.00
0005434427403	14539	Economy	12800.00
0005435127550	14539	Economy	11700.00
0005434427318	14539	Economy	12800.00
0005432800223	14539	Economy	11700.00
0005434880778	14539	Economy	11700.00
0005434427284	14539	Economy	11700.00
0005434880694	14539	Economy	12800.00
0005432800178	14539	Economy	11700.00
0005435127549	14539	Economy	12800.00
0005435626628	14539	Economy	11700.00
0005435127446	14539	Economy	11700.00
0005432800102	14539	Economy	11700.00
0005434880444	14539	Economy	11700.00
0005434880882	14539	Economy	11700.00
0005434880639	14539	Economy	11700.00
0005434938636	14539	Economy	11700.00
0005435626645	14539	Economy	11700.00
0005434880392	14539	Economy	11700.00
0005435127441	14539	Economy	11700.00
0005434880767	14539	Economy	11700.00
0005435127406	14539	Economy	11700.00
0005432611798	14539	Economy	11700.00
0005432800144	14539	Economy	11700.00
0005435626651	14539	Economy	11700.00
0005434427409	14539	Economy	11700.00
0005434880870	14539	Economy	11700.00
0005434880637	14539	Economy	11700.00
0005434880647	14539	Economy	11700.00
0005434880721	14539	Economy	11700.00
0005434880661	14539	Economy	11700.00
0005432800146	14539	Economy	11700.00
0005432800168	14539	Economy	11700.00
0005434880595	14539	Economy	11700.00
0005434880468	14539	Economy	11700.00
0005434427297	14539	Economy	11700.00
0005434880838	14539	Economy	11700.00
0005434427421	14539	Economy	11700.00
0005434880510	14539	Economy	11700.00
0005432800208	14539	Economy	11700.00
0005434880756	14539	Economy	11700.00
0005434880491	14539	Economy	11700.00
0005432800265	14539	Economy	11700.00
0005434427303	14539	Economy	11700.00
0005434880573	14539	Economy	11700.00
0005435127149	14539	Economy	11700.00
0005434427327	14539	Economy	11700.00
0005432800229	14539	Economy	11700.00
0005435127367	14539	Economy	11700.00
0005434427274	14539	Economy	11700.00
0005432800101	14539	Economy	11700.00
0005434427319	14539	Economy	11700.00
0005435127563	14539	Economy	11700.00
0005435626650	14539	Economy	11700.00
0005435626572	14539	Economy	11700.00
0005434880887	14539	Economy	11700.00
0005434880830	14539	Economy	11700.00
0005434938630	14539	Economy	11700.00
0005434427273	14539	Economy	11700.00
0005435127475	14539	Economy	11700.00
0005434880858	14539	Economy	11700.00
0005432800145	14539	Economy	11700.00
0005434880810	14539	Economy	11700.00
0005434880703	14539	Economy	11700.00
0005434880787	14539	Economy	11700.00
0005434427401	14539	Economy	11700.00
0005434880542	14539	Economy	11700.00
0005434880636	14539	Economy	11700.00
0005432607676	14539	Economy	11700.00
0005434880410	14539	Economy	11700.00
0005434427218	14539	Economy	11700.00
0005434427405	14539	Economy	11700.00
0005434427389	14539	Economy	11700.00
0005435626648	14539	Economy	11700.00
0005434427378	14539	Economy	11700.00
0005434880605	14539	Economy	11700.00
0005432800113	14539	Economy	11700.00
0005434880539	14539	Economy	11700.00
0005434880957	14539	Economy	11700.00
0005435626619	14539	Economy	12800.00
0005435127178	14539	Economy	12800.00
0005432611794	14539	Economy	11700.00
0005435626605	14539	Economy	11700.00
0005432800230	14539	Economy	11700.00
0005434880460	14539	Economy	11700.00
0005434880558	14539	Economy	11700.00
0005435127353	14539	Economy	11700.00
0005434880758	14539	Economy	11700.00
0005434427371	14539	Economy	11700.00
0005434880509	14539	Economy	11700.00
0005432800232	14539	Economy	11700.00
0005434880763	14539	Economy	11700.00
0005435127407	14539	Economy	11700.00
0005434880837	14539	Economy	11700.00
0005434938620	14539	Economy	11700.00
0005435626571	14539	Economy	11700.00
0005434880705	14539	Economy	11700.00
0005435127412	14539	Economy	11700.00
0005432800167	14539	Economy	11700.00
0005435626531	14539	Economy	11700.00
0005434880545	14539	Economy	11700.00
0005435626646	14539	Economy	11700.00
0005434880727	14539	Economy	11700.00
0005434880956	14539	Economy	11700.00
0005435127413	14539	Economy	11700.00
0005432800111	14539	Economy	11700.00
0005432800207	14539	Economy	11700.00
0005432800240	14539	Economy	11700.00
0005434880811	14539	Economy	11700.00
0005434427333	14539	Economy	11700.00
0005435127490	14539	Economy	11700.00
0005434880648	14539	Economy	11700.00
0005435626643	14539	Economy	11700.00
0005435127476	14539	Economy	11700.00
0005435127414	14539	Economy	11700.00
0005435127306	14539	Economy	11700.00
0005432800225	14539	Economy	11700.00
0005434880527	14539	Economy	11700.00
0005435127334	14539	Economy	11700.00
0005435127442	14539	Economy	11700.00
0005435626533	14539	Economy	11700.00
0005434880700	14539	Economy	11700.00
0005434880232	14539	Economy	11700.00
0005432800152	14539	Economy	11700.00
0005434427399	14539	Economy	11700.00
0005434880741	14539	Economy	11700.00
0005434427408	14539	Economy	11700.00
0005435127445	14539	Economy	11700.00
0005435127363	14539	Economy	11700.00
0005435127510	14539	Economy	11700.00
0005434880794	14539	Economy	11700.00
0005435127422	14539	Economy	11700.00
0005432800157	14539	Economy	11700.00
0005434938631	14539	Economy	11700.00
0005434880916	14539	Economy	11700.00
0005434938637	14539	Economy	11700.00
0005435127562	14539	Economy	11700.00
0005434880857	14539	Economy	11700.00
0005434880706	14539	Economy	11700.00
0005434880821	14539	Economy	11700.00
0005434880438	14539	Economy	11700.00
0005434938592	14539	Economy	11700.00
0005434880735	14539	Economy	11700.00
0005434880564	14539	Economy	11700.00
0005435127396	14539	Economy	11700.00
0005434427372	14539	Economy	11700.00
0005435890052	3606	Economy	14800.00
0005435890054	3606	Economy	14800.00
0005435890060	3606	Economy	14800.00
0005435890051	3606	Economy	14800.00
0005435890039	3606	Economy	14800.00
0005435890053	3606	Economy	14800.00
0005434325986	3606	Economy	14800.00
0005434325965	15613	Economy	16300.00
0005434311288	15613	Economy	14800.00
0005434325922	15613	Economy	14800.00
0005434325935	15613	Economy	14800.00
0005434325956	15613	Economy	14800.00
0005434312392	15613	Economy	14800.00
0005434325963	15613	Economy	14800.00
0005434325925	15613	Economy	14800.00
0005434325926	15613	Economy	14800.00
0005434325966	15613	Economy	14800.00
0005434325957	15613	Economy	14800.00
0005434325978	15613	Economy	14800.00
0005434325967	15613	Economy	14800.00
0005434325921	15613	Economy	14800.00
0005434325974	15613	Economy	14800.00
0005433420639	639	Economy	4500.00
0005433420581	639	Economy	4100.00
0005433420611	639	Economy	4100.00
0005433420635	639	Economy	4100.00
0005433420631	639	Economy	4100.00
0005433420633	639	Economy	4100.00
0005433420624	639	Economy	4100.00
0005433420614	639	Economy	4100.00
0005433420636	639	Economy	4100.00
0005433420582	639	Economy	4100.00
0005433420640	639	Economy	4100.00
0005433420622	639	Economy	4100.00
0005433420638	639	Economy	4100.00
0005433420630	639	Economy	4100.00
0005433420612	639	Economy	4100.00
0005435958081	15184	Economy	4100.00
0005435958130	15184	Economy	4100.00
0005435958100	15184	Economy	4100.00
0005435958045	15184	Economy	4100.00
0005435958082	15184	Economy	4100.00
0005435958070	15184	Economy	4100.00
0005434247214	8892	Economy	10400.00
0005434247215	8892	Economy	10400.00
0005434247219	8892	Economy	10400.00
0005434096792	11820	Economy	14700.00
0005434096790	11820	Economy	13400.00
0005434096789	11820	Economy	13400.00
0005434096788	11820	Economy	13400.00
0005434096795	11820	Economy	13400.00
0005434096791	11820	Economy	13400.00
0005434096793	11820	Economy	13400.00
0005434096800	11820	Economy	13400.00
0005434096794	11820	Economy	13400.00
0005435933530	4424	Economy	13400.00
0005435163389	4424	Economy	12200.00
0005435163388	4424	Economy	12200.00
0005435933538	4424	Economy	12200.00
0005435933528	4424	Economy	12200.00
0005435933543	4424	Economy	12200.00
0005435163368	29513	Economy	13400.00
0005435163372	29513	Economy	12200.00
0005435163355	29513	Economy	12200.00
0005435163338	29513	Economy	12200.00
0005435163378	29513	Economy	12200.00
0005435163374	29513	Economy	12200.00
0005435163356	29513	Economy	12200.00
0005435163347	29513	Economy	12200.00
0005435163346	29513	Economy	12200.00
0005435163369	29513	Economy	12200.00
0005435163351	29513	Economy	12200.00
0005435163379	29513	Economy	12200.00
0005435163375	29513	Economy	12200.00
0005433405009	2827	Business	12600.00
0005433405021	2827	Economy	4200.00
0005433404966	2827	Economy	4200.00
0005433404965	2827	Economy	4200.00
0005433405023	2827	Economy	4200.00
0005433405000	2827	Economy	4200.00
0005433404997	2827	Economy	4200.00
0005433404999	2827	Economy	4200.00
0005433404998	2827	Economy	4200.00
0005433404979	2827	Economy	4200.00
0005433405008	2827	Economy	4200.00
0005433405006	2827	Economy	4200.00
0005435797816	29336	Business	12600.00
0005435797878	29336	Business	12600.00
0005435797865	29336	Economy	4200.00
0005435797869	29336	Economy	4200.00
0005435797866	29336	Economy	4200.00
0005435797831	29336	Economy	4200.00
0005435797886	29336	Economy	4200.00
0005435376424	5842	Economy	6800.00
0005434948268	5735	Economy	6800.00
0005434948266	5735	Economy	6800.00
0005434948267	5735	Economy	6800.00
0005434948259	16355	Economy	6800.00
0005434948244	16355	Economy	6800.00
0005434948243	16355	Economy	6800.00
0005434948249	16355	Economy	6800.00
0005434948221	16355	Economy	6800.00
0005434948258	16355	Economy	6800.00
0005433962767	6895	Business	21400.00
0005433962770	6895	Economy	7100.00
0005433962772	6895	Economy	7800.00
0005433962771	6895	Economy	7800.00
0005433962768	6895	Economy	7100.00
0005433962769	6895	Economy	7100.00
0005433962765	6895	Economy	7100.00
0005433962766	6895	Economy	7100.00
0005433962773	6895	Economy	7100.00
0005433962314	25787	Business	21400.00
0005433962230	25787	Business	21400.00
0005433962218	25787	Business	21400.00
0005433962196	25787	Business	21400.00
0005433962279	25787	Business	21400.00
0005433962109	25787	Business	21400.00
0005433962037	25787	Economy	7100.00
0005433962246	25787	Economy	7100.00
0005433962091	25787	Economy	7100.00
0005433962270	25787	Economy	7100.00
0005433962156	25787	Economy	7100.00
0005433962292	25787	Economy	7100.00
0005433962212	25787	Economy	7800.00
0005433962144	25787	Economy	7800.00
0005433962125	25787	Economy	7800.00
0005433962117	25787	Economy	7800.00
0005433962302	25787	Economy	7100.00
0005433962280	25787	Economy	7100.00
0005433962313	25787	Economy	7100.00
0005433962149	25787	Economy	7100.00
0005433962206	25787	Economy	7100.00
0005433962116	25787	Economy	7100.00
0005433962089	25787	Economy	7100.00
0005433962127	25787	Economy	7100.00
0005433962145	25787	Economy	7100.00
0005433962159	25787	Economy	7100.00
0005433962317	25787	Economy	7100.00
0005433962124	25787	Economy	7100.00
0005433961893	25787	Economy	7100.00
0005433962172	25787	Economy	7100.00
0005433962285	25787	Economy	7100.00
0005433962248	25787	Economy	7100.00
0005433962139	25787	Economy	7100.00
0005433962105	25787	Economy	7100.00
0005433962197	25787	Economy	7100.00
0005433962316	25787	Economy	7100.00
0005433962269	25787	Economy	7100.00
0005433962243	25787	Economy	7100.00
0005433962183	25787	Economy	7100.00
0005433962143	25787	Economy	7100.00
0005433962251	25787	Economy	7100.00
0005433962132	25787	Economy	7100.00
0005433962148	25787	Economy	7100.00
0005433962252	25787	Economy	7100.00
0005433962120	25787	Economy	7100.00
0005433962278	25787	Economy	7100.00
0005433962234	25787	Economy	7100.00
0005433962092	25787	Economy	7100.00
0005433961892	25787	Economy	7100.00
0005433962215	25787	Economy	7100.00
0005433962140	25787	Economy	7100.00
0005433962221	25787	Economy	7100.00
0005433962114	25787	Economy	7100.00
0005433962171	25787	Economy	7100.00
0005433962188	25787	Economy	7100.00
0005433962069	25787	Economy	7100.00
0005433962286	25787	Economy	7100.00
0005433962182	25787	Economy	7100.00
0005433962211	25787	Economy	7100.00
0005433961891	25787	Economy	7100.00
0005433962104	25787	Economy	7100.00
0005433962110	25787	Economy	7100.00
0005433962187	25787	Economy	7100.00
0005433962138	25787	Economy	7100.00
0005433962184	25787	Economy	7100.00
0005433962295	25787	Economy	7100.00
0005435083013	24496	Economy	3900.00
0005435083015	24496	Economy	3900.00
0005435082981	24496	Economy	3900.00
0005435082994	24496	Economy	3900.00
0005435083007	24496	Economy	3900.00
0005435082993	24496	Economy	3900.00
0005435082986	24496	Economy	3900.00
0005435083006	24496	Economy	3900.00
0005435083014	24496	Economy	3900.00
0005435082982	24496	Economy	3900.00
0005435083039	26124	Economy	3900.00
0005435083040	26124	Economy	3900.00
0005435286792	5169	Business	18000.00
0005435286759	5169	Business	18000.00
0005435286784	5169	Business	18000.00
0005435286782	5169	Economy	6000.00
0005435286805	5169	Economy	6000.00
0005434245848	5169	Economy	6000.00
0005435286794	5169	Economy	6000.00
0005435286779	5169	Economy	6000.00
0005435286783	5169	Economy	6000.00
0005435286833	5169	Economy	6000.00
0005433534557	5169	Economy	6000.00
0005435286758	5169	Economy	6600.00
0005435286843	5169	Economy	6000.00
0005433534550	5169	Economy	6000.00
0005435286814	5169	Economy	6000.00
0005435286815	5169	Economy	6000.00
0005435286795	5169	Economy	6000.00
0005435286878	5169	Economy	6000.00
0005435286791	5169	Economy	6000.00
0005433534558	5169	Economy	6000.00
0005435286773	5169	Economy	6000.00
0005434230274	5222	Business	18000.00
0005433786201	5222	Economy	6000.00
0005434230273	5222	Economy	6000.00
0005434230272	5222	Economy	6000.00
0005434230276	5222	Economy	6000.00
0005434230271	5222	Economy	6000.00
0005434230278	5222	Economy	6000.00
0005434230277	5222	Economy	6000.00
0005433786199	5222	Economy	6600.00
0005434230275	5222	Economy	6000.00
0005432106955	5222	Economy	6000.00
0005432106956	5222	Economy	6000.00
0005433786200	5222	Economy	6000.00
0005432336319	5012	Business	18000.00
0005432336333	5012	Business	18000.00
0005435269944	5012	Business	18000.00
0005433815476	5012	Business	18000.00
0005435269994	5012	Business	18000.00
0005434312373	5012	Business	18000.00
0005434265901	5012	Business	18000.00
0005432336348	5012	Business	18000.00
0005434265902	5012	Business	18000.00
0005435270147	5012	Economy	6000.00
0005435270177	5012	Economy	6000.00
0005432336352	5012	Economy	6000.00
0005435270173	5012	Economy	6000.00
0005433815575	5012	Economy	6000.00
0005435270002	5012	Economy	6000.00
0005435007570	5012	Economy	6000.00
0005435270011	5012	Economy	6000.00
0005435270028	5012	Economy	6000.00
0005435007667	5012	Economy	6000.00
0005433815499	5012	Economy	6000.00
0005435270127	5012	Economy	6000.00
0005435007571	5012	Economy	6000.00
0005433815510	5012	Economy	6000.00
0005433688864	5012	Economy	6000.00
0005433815521	5012	Economy	6000.00
0005433688851	5012	Economy	6000.00
0005435007629	5012	Economy	6000.00
0005432336343	5012	Economy	6000.00
0005435270126	5012	Economy	6000.00
0005435270157	5012	Economy	6000.00
0005435270068	5012	Economy	6000.00
0005435007691	5012	Economy	6600.00
0005435270156	5012	Economy	6000.00
0005433688863	5012	Economy	6000.00
0005432336318	5012	Economy	6000.00
0005435270108	5012	Economy	6000.00
0005435007688	5012	Economy	6000.00
0005432336345	5012	Economy	6000.00
0005432336335	5012	Economy	6000.00
0005434312376	5012	Economy	6000.00
0005435270003	5012	Economy	6000.00
0005435269955	5012	Economy	6000.00
0005435269912	5012	Economy	6000.00
0005435007668	5012	Economy	6000.00
0005432336342	5012	Economy	6000.00
0005433685572	5012	Economy	6000.00
0005435007677	5012	Economy	6000.00
0005435270159	5012	Economy	6000.00
0005432336332	5012	Economy	6000.00
0005433685571	5012	Economy	6000.00
0005435270010	5012	Economy	6000.00
0005435270088	5012	Economy	6000.00
0005435269956	5012	Economy	6000.00
0005432336307	5012	Economy	6000.00
0005435270124	5012	Economy	6000.00
0005432336357	5012	Economy	6000.00
0005432336356	5012	Economy	6000.00
0005432336326	5012	Economy	6000.00
0005435007690	5012	Economy	6000.00
0005432663090	8477	Business	18000.00
0005433785810	8477	Business	18000.00
0005433785784	8477	Business	18000.00
0005434245703	8477	Business	18000.00
0005433785857	8477	Business	18000.00
0005434245704	8477	Business	18000.00
0005434245675	8477	Business	18000.00
0005433785862	8477	Business	18000.00
0005433786085	8477	Business	18000.00
0005433785867	8477	Business	18000.00
0005434245742	8477	Business	18000.00
0005434245720	8477	Business	18000.00
0005433785816	8477	Economy	6600.00
0005433785879	8477	Economy	6600.00
0005434245727	8477	Economy	6600.00
0005433785917	8477	Economy	6600.00
0005433786127	8477	Economy	6000.00
0005433785888	8477	Economy	6000.00
0005433785851	8477	Economy	6000.00
0005434245759	8477	Economy	6000.00
0005433785911	8477	Economy	6000.00
0005433785856	8477	Economy	6000.00
0005433785891	8477	Economy	6000.00
0005433785868	8477	Economy	6000.00
0005434245755	8477	Economy	6000.00
0005433786064	8477	Economy	6000.00
0005433786049	8477	Economy	6000.00
0005433785811	8477	Economy	6000.00
0005433785821	8477	Economy	6000.00
0005433785872	8477	Economy	6000.00
0005433785951	8477	Economy	6000.00
0005433785828	8477	Economy	6000.00
0005433785866	8477	Economy	6000.00
0005434245779	8477	Economy	6000.00
0005433785890	8477	Economy	6000.00
0005433785887	8477	Economy	6000.00
0005434245794	8477	Economy	6000.00
0005434245796	8477	Economy	6000.00
0005433786180	8477	Economy	6000.00
0005434245715	8477	Economy	6000.00
0005433785946	8477	Economy	6000.00
0005434245757	8477	Economy	6000.00
0005433785713	8477	Economy	6000.00
0005433785842	8477	Economy	6000.00
0005433785933	8477	Economy	6000.00
0005433785880	8477	Economy	6000.00
0005433785822	8477	Economy	6000.00
0005432663091	8477	Economy	6000.00
0005432666440	8477	Economy	6000.00
0005432666430	8477	Economy	6600.00
0005432659759	8477	Economy	6600.00
0005433785871	8477	Economy	6600.00
0005433785878	8477	Economy	6600.00
0005433786054	8477	Economy	6000.00
0005434245786	8477	Economy	6000.00
0005433785950	8477	Economy	6600.00
0005433786010	8477	Economy	6000.00
0005434245818	8477	Economy	6000.00
0005434245785	8477	Economy	6000.00
0005433785932	8477	Economy	6000.00
0005434245795	8477	Economy	6000.00
0005433785844	8477	Economy	6000.00
0005433785970	8477	Economy	6000.00
0005434245741	8477	Economy	6000.00
0005434245839	8477	Economy	6000.00
0005433786009	8477	Economy	6000.00
0005433785865	8477	Economy	6000.00
0005434245758	8477	Economy	6000.00
0005434245674	8477	Economy	6000.00
0005432663096	8477	Economy	6000.00
0005433785843	8477	Economy	6000.00
0005432666433	8477	Economy	6000.00
0005433785912	8477	Economy	6000.00
0005434245754	8477	Economy	6000.00
0005433785861	8477	Economy	6000.00
0005433786003	8477	Economy	6000.00
0005432666432	8477	Economy	6000.00
0005433785826	8477	Economy	6000.00
0005433785895	8477	Economy	6000.00
0005433786179	8477	Economy	6000.00
0005433785712	8477	Economy	6000.00
0005433785884	8477	Economy	6000.00
0005432666441	8477	Economy	6000.00
0005433785996	8477	Economy	6000.00
0005434245817	8477	Economy	6000.00
0005432666442	8477	Economy	6000.00
0005433785935	8477	Economy	6000.00
0005434245673	8477	Economy	6000.00
0005433616558	8476	Business	18000.00
0005433616082	8476	Business	18000.00
0005433616081	8476	Business	18000.00
0005433616606	8476	Business	18000.00
0005433616388	8476	Business	18000.00
0005433616466	8476	Business	18000.00
0005433616631	8476	Economy	6600.00
0005433616486	8476	Economy	6600.00
0005433616308	8476	Economy	6600.00
0005433616465	8476	Economy	6000.00
0005433616461	8476	Economy	6000.00
0005433616515	8476	Economy	6000.00
0005433616532	8476	Economy	6000.00
0005433616560	8476	Economy	6000.00
0005433616453	8476	Economy	6000.00
0005433616727	8476	Economy	6000.00
0005433616596	8476	Economy	6000.00
0005433616559	8476	Economy	6000.00
0005433616525	8476	Economy	6000.00
0005433616521	8476	Economy	6000.00
0005433616462	8476	Economy	6000.00
0005433616514	8476	Economy	6000.00
0005433616531	8476	Economy	6000.00
0005433616234	8476	Economy	6000.00
0005433616513	8476	Economy	6000.00
0005433616387	8476	Economy	6600.00
0005433616626	8476	Economy	6600.00
0005433616189	8476	Economy	6600.00
0005433616026	8476	Economy	6000.00
0005433616485	8476	Economy	6000.00
0005433616619	8476	Economy	6000.00
0005433616429	8476	Economy	6000.00
0005433616552	8476	Economy	6000.00
0005433616180	8476	Economy	6000.00
0005433616487	8476	Economy	6000.00
0005433616328	8476	Economy	6000.00
0005433616603	8476	Economy	6000.00
0005433616718	8476	Economy	6000.00
0005433616522	8476	Economy	6000.00
0005433616618	8476	Economy	6000.00
0005433616307	8476	Economy	6000.00
0005433616717	8476	Economy	6000.00
0005433616327	8476	Economy	6000.00
0005433616463	8476	Economy	6000.00
0005433616464	8476	Economy	6000.00
0005433616455	8476	Economy	6000.00
0005433616544	8476	Economy	6000.00
0005433616351	8476	Economy	6000.00
0005433616454	8476	Economy	6000.00
0005434150048	8475	Business	18000.00
0005434265787	8475	Business	18000.00
0005434229933	8475	Business	18000.00
0005434229995	8475	Business	18000.00
0005435287053	8475	Business	18000.00
0005434265833	8475	Business	18000.00
0005434265743	8475	Business	18000.00
0005434265808	8475	Business	18000.00
0005434173621	8475	Business	18000.00
0005434229968	8475	Business	18000.00
0005434150011	8475	Business	18000.00
0005435477012	8475	Economy	6600.00
0005434265820	8475	Business	18000.00
0005434265745	8475	Economy	6600.00
0005434173626	8475	Economy	6600.00
0005434265817	8475	Economy	6000.00
0005434265807	8475	Economy	6000.00
0005435287054	8475	Economy	6000.00
0005434229969	8475	Economy	6000.00
0005434229920	8475	Economy	6000.00
0005434265783	8475	Economy	6000.00
0005434265867	8475	Economy	6000.00
0005434149982	8475	Economy	6000.00
0005434265818	8475	Economy	6000.00
0005434265802	8475	Economy	6000.00
0005434265786	8475	Economy	6000.00
0005434229915	8475	Economy	6000.00
0005434230000	8475	Economy	6000.00
0005434229996	8475	Economy	6000.00
0005434229909	8475	Economy	6000.00
0005434265850	8475	Economy	6000.00
0005434150003	8475	Economy	6000.00
0005434265784	8475	Economy	6000.00
0005434265809	8475	Economy	6000.00
0005434265673	8475	Economy	6000.00
0005434230001	8475	Economy	6600.00
0005434229990	8475	Economy	6000.00
0005434265803	8475	Economy	6000.00
0005434149997	8475	Economy	6600.00
0005434150062	8475	Economy	6000.00
0005434229880	8475	Economy	6000.00
0005434265744	8475	Economy	6000.00
0005434150004	8475	Economy	6000.00
0005434265849	8475	Economy	6000.00
0005434149996	8475	Economy	6000.00
0005434229992	8475	Economy	6000.00
0005434229999	8475	Economy	6000.00
0005434150012	8475	Economy	6000.00
0005434229908	8475	Economy	6000.00
0005434229879	8475	Economy	6000.00
0005434229970	8475	Economy	6000.00
0005434229919	8475	Economy	6000.00
0005434150056	8475	Economy	6000.00
0005434150061	8475	Economy	6000.00
0005434229946	8475	Economy	6000.00
0005434229991	8475	Economy	6000.00
0005434229907	8475	Economy	6000.00
0005434265810	8475	Economy	6000.00
0005434150060	8475	Economy	6000.00
0005434229984	8475	Economy	6000.00
0005434173627	8475	Economy	6000.00
0005434265796	8475	Economy	6000.00
0005434640060	12623	Economy	16200.00
0005434640048	12623	Economy	14800.00
0005434640028	12623	Economy	14800.00
0005434639995	12623	Economy	14800.00
0005434639965	12623	Economy	14800.00
0005434639930	12623	Economy	14800.00
0005434639998	12623	Economy	14800.00
0005434639996	12623	Economy	14800.00
0005434639948	12623	Economy	14800.00
0005434639943	12623	Economy	14800.00
0005434640013	12623	Economy	14800.00
0005434639957	12623	Economy	14800.00
0005434639964	12623	Economy	14800.00
0005434640015	12623	Economy	14800.00
0005434639999	12623	Economy	14800.00
0005434639963	12623	Economy	14800.00
0005434639944	12623	Economy	14800.00
0005434640014	12623	Economy	14800.00
0005434640046	12623	Economy	14800.00
0005434639993	12623	Economy	14800.00
0005434639992	12623	Economy	14800.00
0005434639949	12623	Economy	14800.00
0005434639984	12623	Economy	14800.00
0005434639997	12623	Economy	14800.00
0005434639956	12623	Economy	14800.00
0005434640059	12623	Economy	14800.00
0005434639994	12623	Economy	14800.00
0005434640047	12623	Economy	14800.00
0005433202706	23390	Economy	16200.00
0005433202726	23390	Economy	14800.00
0005433202672	23390	Economy	14800.00
0005433202704	23390	Economy	14800.00
0005433202721	23390	Economy	14800.00
0005433202667	23390	Economy	14800.00
0005433202715	23390	Economy	14800.00
0005433202752	23390	Economy	14800.00
0005433202708	23390	Economy	14800.00
0005433202722	23390	Economy	14800.00
0005433202723	23390	Economy	14800.00
0005433202707	23390	Economy	14800.00
0005434640105	23390	Economy	14800.00
0005432384247	21077	Business	18900.00
0005432384200	21077	Business	18900.00
0005432384199	21077	Business	18900.00
0005432329895	21077	Business	18900.00
0005432329708	21077	Business	18900.00
0005432329801	21077	Business	18900.00
0005432329850	21077	Business	18900.00
0005432383962	21077	Business	18900.00
0005432384178	21077	Business	18900.00
0005432329953	21077	Business	18900.00
0005432329796	21077	Business	18900.00
0005432383986	21077	Economy	6300.00
0005432329920	21077	Economy	6300.00
0005432384126	21077	Economy	6300.00
0005432384144	21077	Economy	6300.00
0005432329834	21077	Economy	6300.00
0005432329790	21077	Economy	6900.00
0005432384191	21077	Economy	6900.00
0005432329836	21077	Economy	6900.00
0005432329694	21077	Economy	6300.00
0005432384059	21077	Economy	6300.00
0005432384146	21077	Economy	6300.00
0005432329941	21077	Economy	6300.00
0005432848923	21077	Economy	6300.00
0005432329832	21077	Economy	6300.00
0005432329946	21077	Economy	6300.00
0005432329768	21077	Economy	6300.00
0005432329831	21077	Economy	6300.00
0005432383963	21077	Economy	6300.00
0005432329767	21077	Economy	6300.00
0005432384268	21077	Economy	6300.00
0005432383993	21077	Economy	6300.00
0005432329921	21077	Economy	6300.00
0005432329880	21077	Economy	6300.00
0005432384208	21077	Economy	6300.00
0005432329960	21077	Economy	6300.00
0005432848925	21077	Economy	6300.00
0005432384094	21077	Economy	6300.00
0005432384127	21077	Economy	6300.00
0005432384048	21077	Economy	6300.00
0005432384168	21077	Economy	6300.00
0005432384145	21077	Economy	6300.00
0005432329922	21077	Economy	6300.00
0005432848922	21077	Economy	6300.00
0005432329721	21077	Economy	6300.00
0005432329849	21077	Economy	6300.00
0005432329662	21077	Economy	6300.00
0005432384105	21077	Economy	6300.00
0005432330022	21077	Economy	6300.00
0005432383997	21077	Economy	6300.00
0005432384079	21077	Economy	6300.00
0005432384078	21077	Economy	6300.00
0005432384130	21077	Economy	6300.00
0005432384209	21077	Economy	6300.00
0005432384171	21077	Economy	6300.00
0005432329787	21077	Economy	6300.00
0005432384143	21077	Economy	6300.00
0005432384090	21077	Economy	6300.00
0005432384269	21077	Economy	6300.00
0005432329695	21077	Economy	6300.00
0005432384121	21077	Economy	6300.00
0005432383996	21077	Economy	6300.00
0005432848924	21077	Economy	6300.00
0005432848921	21077	Economy	6300.00
0005432329814	21077	Economy	6300.00
0005432329709	21077	Economy	6300.00
0005432329830	21077	Economy	6300.00
0005432384089	21077	Economy	6300.00
0005432384192	21077	Economy	6300.00
0005432329833	21077	Economy	6300.00
0005432384340	31225	Business	18900.00
0005432384342	31225	Economy	6900.00
0005432330057	31225	Economy	6300.00
0005432330056	31225	Economy	6300.00
0005432330059	31225	Economy	6300.00
0005432330058	31225	Economy	6300.00
0005432384341	31225	Economy	6300.00
0005432954148	2470	Business	89600.00
0005432954147	2470	Business	89600.00
0005432954169	2470	Economy	29900.00
0005432954142	2470	Economy	29900.00
0005432954146	2470	Economy	32800.00
0005432954144	2470	Economy	29900.00
0005432954125	2470	Economy	29900.00
0005432954165	2470	Economy	29900.00
0005432954182	2470	Economy	29900.00
0005432954156	2470	Economy	29900.00
0005432954145	2470	Economy	29900.00
0005432954091	2470	Economy	29900.00
0005432954137	2470	Economy	29900.00
0005432954166	2470	Economy	29900.00
0005432954168	2470	Economy	29900.00
0005432954198	27585	Business	89600.00
0005433642675	27585	Business	89600.00
0005432954197	27585	Business	89600.00
0005433642728	27585	Business	89600.00
0005433642742	27585	Business	89600.00
0005433642704	27585	Business	89600.00
0005433642688	27585	Business	89600.00
0005433642705	27585	Business	89600.00
0005433642690	27585	Business	89600.00
0005433642738	27585	Economy	29900.00
0005433642680	27585	Economy	29900.00
0005433642703	27585	Economy	29900.00
0005433642706	27585	Economy	29900.00
0005433642660	27585	Economy	32800.00
0005433642727	27585	Economy	32800.00
0005433642670	27585	Economy	29900.00
0005433642699	27585	Economy	29900.00
0005433642646	27585	Economy	29900.00
0005433642667	27585	Economy	29900.00
0005433642731	27585	Economy	29900.00
0005433642666	27585	Economy	29900.00
0005433642730	27585	Economy	29900.00
0005433642701	27585	Economy	29900.00
0005433642714	27585	Economy	29900.00
0005433642729	27585	Economy	29900.00
0005432954196	27585	Economy	29900.00
0005433642726	27585	Economy	29900.00
0005433642760	27585	Economy	29900.00
0005433642702	27585	Economy	29900.00
0005433642735	27585	Economy	29900.00
0005433642732	27585	Economy	29900.00
0005433642739	27585	Economy	29900.00
0005433642661	27585	Economy	29900.00
0005432954199	27585	Economy	29900.00
0005433642707	27585	Economy	29900.00
0005433642650	27585	Economy	29900.00
0005433642645	27585	Economy	29900.00
0005433642689	27585	Economy	29900.00
0005433642722	27585	Economy	29900.00
0005433642673	27585	Economy	29900.00
0005433642755	27585	Economy	29900.00
0005433642737	27585	Economy	29900.00
0005433642698	27585	Economy	29900.00
0005433642629	27585	Economy	29900.00
0005433642723	27585	Economy	29900.00
0005433642734	27585	Economy	29900.00
0005433642725	27585	Economy	29900.00
0005433642649	27585	Economy	29900.00
0005432426066	13318	Economy	4200.00
0005432426070	13318	Economy	4200.00
0005432426068	13318	Economy	4700.00
0005432426073	13318	Economy	4700.00
0005432426071	13318	Economy	4200.00
0005432426069	13318	Economy	4200.00
0005432426065	13318	Economy	4200.00
0005432426072	13318	Economy	4200.00
0005432426067	13318	Economy	4200.00
0005432426074	13318	Economy	4200.00
0005432426076	13318	Economy	4200.00
0005432426075	13318	Economy	4200.00
0005432425661	30767	Business	12700.00
0005432425689	30767	Business	12700.00
0005432425669	30767	Business	12700.00
0005432425556	30767	Business	12700.00
0005432425642	30767	Business	12700.00
0005432425600	30767	Business	12700.00
0005432425629	30767	Business	12700.00
0005432425557	30767	Business	12700.00
0005432425671	30767	Economy	4200.00
0005432425540	30767	Economy	4200.00
0005432425673	30767	Economy	4200.00
0005432425641	30767	Economy	4700.00
0005432425683	30767	Economy	4700.00
0005432425583	30767	Economy	4200.00
0005432425489	30767	Economy	4200.00
0005432425586	30767	Economy	4200.00
0005432425679	30767	Economy	4200.00
0005432425698	30767	Economy	4200.00
0005432425601	30767	Economy	4200.00
0005432425672	30767	Economy	4200.00
0005432425658	30767	Economy	4200.00
0005432425599	30767	Economy	4200.00
0005432425618	30767	Economy	4200.00
0005432425666	30767	Economy	4200.00
0005432425539	30767	Economy	4200.00
0005432425409	30767	Economy	4200.00
0005432425408	30767	Economy	4200.00
0005432425695	30767	Economy	4200.00
0005432425563	30767	Economy	4200.00
0005432425625	30767	Economy	4200.00
0005432425659	30767	Economy	4200.00
0005432425638	30767	Economy	4200.00
0005432425502	30767	Economy	4200.00
0005432425660	30767	Economy	4200.00
0005432425593	30767	Economy	4200.00
0005432425655	30767	Economy	4200.00
0005432425696	30767	Economy	4200.00
0005432425651	30767	Economy	4200.00
0005432425670	30767	Economy	4200.00
0005432425623	30767	Economy	4200.00
0005432425640	30767	Economy	4200.00
0005432425587	30767	Economy	4200.00
0005432425667	30767	Economy	4200.00
0005432425501	30767	Economy	4200.00
0005432425624	30767	Economy	4200.00
0005432425699	30767	Economy	4200.00
0005432425697	30767	Economy	4200.00
0005432425633	30767	Economy	4200.00
0005432425479	30767	Economy	4200.00
0005432902063	9585	Economy	10900.00
0005434157708	9585	Economy	10900.00
0005434157679	9585	Economy	10900.00
0005432902062	9585	Economy	10900.00
0005432902060	9585	Economy	10900.00
0005434157709	9585	Economy	10900.00
0005432902040	9585	Economy	10900.00
0005434157681	9585	Economy	10900.00
0005432902039	9585	Economy	10900.00
0005432902037	9585	Economy	10900.00
0005434157678	9585	Economy	10900.00
0005432902035	9585	Economy	10900.00
0005432902094	9585	Economy	10900.00
0005434157683	9585	Economy	10900.00
0005434157680	9585	Economy	10900.00
0005434157684	9585	Economy	10900.00
0005434157677	9585	Economy	10900.00
0005434157682	9585	Economy	10900.00
0005432902078	9585	Economy	10900.00
0005432822435	9585	Economy	10900.00
0005432902075	9585	Economy	10900.00
0005432902036	9585	Economy	10900.00
0005432902074	9585	Economy	10900.00
0005432818091	28978	Business	32600.00
0005432818092	28978	Business	32600.00
0005432818265	28978	Business	32600.00
0005432818215	28978	Business	32600.00
0005432818152	28978	Economy	10900.00
0005432818307	28978	Economy	10900.00
0005432818249	28978	Economy	10900.00
0005432818166	28978	Economy	11900.00
0005432818227	28978	Economy	11900.00
0005432822368	28978	Economy	11900.00
0005432818266	28978	Economy	10900.00
0005434448402	28978	Economy	10900.00
0005432818256	28978	Economy	10900.00
0005432818252	28978	Economy	10900.00
0005432818251	28978	Economy	10900.00
0005432822389	28978	Economy	10900.00
0005432818250	28978	Economy	10900.00
0005432822386	28978	Economy	10900.00
0005434448408	28978	Economy	10900.00
0005432818197	28978	Economy	10900.00
0005432818210	28978	Economy	10900.00
0005432818302	28978	Economy	10900.00
0005434448406	28978	Economy	10900.00
0005432818191	28978	Economy	10900.00
0005432818192	28978	Economy	10900.00
0005432818193	28978	Economy	10900.00
0005432818300	28978	Economy	10900.00
0005432822390	28978	Economy	10900.00
0005432818301	28978	Economy	10900.00
0005434448407	28978	Economy	10900.00
0005432818184	28978	Economy	10900.00
0005432818268	28978	Economy	10900.00
0005432818247	28978	Economy	10900.00
0005432818246	28978	Economy	10900.00
0005432822385	28978	Economy	10900.00
0005432822407	28978	Economy	10900.00
0005432818185	28978	Economy	10900.00
0005432818075	28978	Economy	10900.00
0005432818226	28978	Economy	10900.00
0005435841842	15134	Economy	11000.00
0005435841843	15134	Economy	11000.00
0005432611795	31542	Economy	11000.00
0005432611798	31542	Economy	11000.00
0005432611794	31542	Economy	11000.00
0005432607676	31542	Economy	11000.00
0005432949523	11878	Business	105900.00
0005432949448	11878	Business	105900.00
0005432949408	11878	Business	105900.00
0005432949501	11878	Business	105900.00
0005432949502	11878	Economy	35300.00
0005432949495	11878	Economy	35300.00
0005433570983	11878	Economy	35300.00
0005432949386	11878	Economy	35300.00
0005432949507	11878	Economy	35300.00
0005432949533	11878	Economy	38800.00
0005432949456	11878	Economy	35300.00
0005432949406	11878	Economy	35300.00
0005432949532	11878	Economy	35300.00
0005432949496	11878	Economy	35300.00
0005432949515	11878	Economy	35300.00
0005432949516	11878	Economy	35300.00
0005433570981	11878	Economy	35300.00
0005432949525	11878	Economy	35300.00
0005433570984	11878	Economy	35300.00
0005432949576	11878	Economy	35300.00
0005432949524	11878	Economy	35300.00
0005432949442	11878	Economy	35300.00
0005432949506	11878	Economy	35300.00
0005432949449	11878	Economy	35300.00
0005433570985	11878	Economy	35300.00
0005433570982	11878	Economy	35300.00
0005432949579	11878	Economy	35300.00
0005432949577	11878	Economy	35300.00
0005432949374	11878	Economy	35300.00
0005432949563	11878	Economy	35300.00
0005432949335	11878	Economy	35300.00
0005432949447	11878	Economy	35300.00
0005433570745	25320	Business	105900.00
0005433570441	25320	Business	105900.00
0005433570456	25320	Business	105900.00
0005433570470	25320	Business	105900.00
0005433570858	25320	Business	105900.00
0005433570193	25320	Business	105900.00
0005433570719	25320	Business	105900.00
0005433570505	25320	Business	105900.00
0005433570400	25320	Business	105900.00
0005433570602	25320	Business	105900.00
0005433570455	25320	Economy	35300.00
0005433570571	25320	Economy	35300.00
0005433570615	25320	Economy	35300.00
0005433570523	25320	Economy	35300.00
0005433570431	25320	Economy	35300.00
0005433570659	25320	Economy	35300.00
0005433570309	25320	Economy	35300.00
0005433570515	25320	Economy	35300.00
0005433570362	25320	Economy	35300.00
0005433570627	25320	Economy	35300.00
0005433570814	25320	Economy	35300.00
0005433570508	25320	Economy	38800.00
0005433570717	25320	Economy	38800.00
0005433570641	25320	Economy	38800.00
0005433570843	25320	Economy	35300.00
0005433570374	25320	Economy	35300.00
0005433570714	25320	Economy	35300.00
0005433570660	25320	Economy	35300.00
0005433570738	25320	Economy	35300.00
0005433570811	25320	Economy	35300.00
0005433570715	25320	Economy	35300.00
0005433570238	25320	Economy	35300.00
0005433570632	25320	Economy	35300.00
0005433570600	25320	Economy	35300.00
0005433570678	25320	Economy	35300.00
0005433570640	25320	Economy	35300.00
0005433570419	25320	Economy	35300.00
0005433570237	25320	Economy	35300.00
0005433570579	25320	Economy	35300.00
0005433570593	25320	Economy	35300.00
0005433570373	25320	Economy	35300.00
0005433570423	25320	Economy	35300.00
0005433570818	25320	Economy	35300.00
0005433570483	25320	Economy	35300.00
0005433570412	25320	Economy	35300.00
0005433570469	25320	Economy	35300.00
0005433570827	25320	Economy	35300.00
0005433570328	25320	Economy	35300.00
0005433570732	25320	Economy	35300.00
0005433570716	25320	Economy	35300.00
0005433570490	25320	Economy	35300.00
0005433570592	25320	Economy	35300.00
0005433570718	25320	Economy	35300.00
0005433570756	25320	Economy	35300.00
0005433570478	25320	Economy	35300.00
0005433570535	25320	Economy	35300.00
0005433570633	25320	Economy	35300.00
0005433570420	25320	Economy	35300.00
0005433570667	25320	Economy	35300.00
0005433570572	25320	Economy	35300.00
0005433570668	25320	Economy	35300.00
0005433570741	25320	Economy	35300.00
0005433570529	25320	Economy	35300.00
0005433570674	25320	Economy	35300.00
0005433570399	25320	Economy	35300.00
0005433570484	25320	Economy	35300.00
0005433570853	25320	Economy	35300.00
0005433570642	25320	Economy	35300.00
0005433570625	25320	Economy	35300.00
0005433570744	25320	Economy	35300.00
0005433570575	25320	Economy	35300.00
0005433570721	25320	Economy	35300.00
0005433570815	25320	Economy	35300.00
0005433570514	25320	Economy	35300.00
0005435340617	5400	Business	67200.00
0005435340670	5400	Economy	22400.00
0005435340671	5400	Economy	22400.00
0005435340643	5400	Economy	22400.00
0005435340610	5400	Economy	24600.00
0005435340602	5400	Economy	22400.00
0005435340641	5400	Economy	22400.00
0005435340638	5400	Economy	22400.00
0005435555421	5400	Economy	22400.00
0005435555415	5400	Economy	22400.00
0005435340672	5400	Economy	22400.00
0005435340679	5400	Economy	22400.00
0005434655440	12550	Business	67200.00
0005434655415	12550	Business	67200.00
0005434655474	12550	Business	67200.00
0005434655373	12550	Economy	22400.00
0005434655512	12550	Economy	24600.00
0005434656596	12550	Economy	24600.00
0005434655448	12550	Economy	24600.00
0005434655455	12550	Economy	22400.00
0005434655468	12550	Economy	22400.00
0005434655447	12550	Economy	22400.00
0005434655513	12550	Economy	22400.00
0005434655388	12550	Economy	22400.00
0005434655469	12550	Economy	22400.00
0005434655372	12550	Economy	22400.00
0005434655462	12550	Economy	22400.00
0005435340709	12550	Economy	22400.00
0005434655352	12550	Economy	22400.00
0005434655432	12550	Economy	22400.00
0005434655381	12550	Economy	22400.00
0005434655387	12550	Economy	22400.00
0005434655354	12550	Economy	22400.00
0005434656611	12550	Economy	22400.00
0005434656610	12550	Economy	22400.00
0005434655445	12550	Economy	22400.00
0005434655382	12550	Economy	22400.00
0005435266320	7457	Business	32000.00
0005432429005	7457	Economy	10700.00
0005432429018	7457	Economy	10700.00
0005433722510	7457	Economy	10700.00
0005435266267	7457	Economy	10700.00
0005432429004	7457	Economy	10700.00
0005433722511	7457	Economy	10700.00
0005435266332	7457	Economy	11700.00
0005433722512	7457	Economy	10700.00
0005432429017	7457	Economy	10700.00
0005433717432	7457	Economy	10700.00
0005435266304	7457	Economy	10700.00
0005435266301	7457	Economy	10700.00
0005435266286	7457	Economy	10700.00
0005433717385	29241	Business	32000.00
0005433717384	29241	Business	32000.00
0005433722383	29241	Business	32000.00
0005433717263	29241	Business	32000.00
0005433685572	29241	Business	32000.00
0005433717317	29241	Business	32000.00
0005433717293	29241	Business	32000.00
0005433688863	29241	Economy	10700.00
0005433717074	29241	Economy	10700.00
0005433717144	29241	Economy	10700.00
0005433722380	29241	Economy	10700.00
0005433717229	29241	Economy	10700.00
0005433717234	29241	Economy	10700.00
0005433717126	29241	Economy	10700.00
0005433722377	29241	Economy	10700.00
0005433717221	29241	Economy	10700.00
0005433688851	29241	Economy	10700.00
0005433717315	29241	Economy	10700.00
0005433717337	29241	Economy	10700.00
0005433717108	29241	Economy	10700.00
0005433717414	29241	Economy	10700.00
0005433656751	29241	Economy	10700.00
0005433717265	29241	Economy	10700.00
0005433717258	29241	Economy	10700.00
0005433722385	29241	Economy	11700.00
0005433688864	29241	Economy	10700.00
0005433717207	29241	Economy	11700.00
0005433717343	29241	Economy	10700.00
0005433717268	29241	Economy	10700.00
0005433722381	29241	Economy	10700.00
0005433717241	29241	Economy	10700.00
0005433717045	29241	Economy	10700.00
0005433717254	29241	Economy	10700.00
0005433717187	29241	Economy	10700.00
0005432429034	29241	Economy	10700.00
0005435546241	29241	Economy	10700.00
0005433656757	29241	Economy	10700.00
0005433717175	29241	Economy	10700.00
0005433717228	29241	Economy	10700.00
0005433722382	29241	Economy	10700.00
0005433717253	29241	Economy	10700.00
0005433717143	29241	Economy	10700.00
0005433716913	29241	Economy	10700.00
0005433717184	29241	Economy	10700.00
0005433656753	29241	Economy	10700.00
0005433685571	29241	Economy	10700.00
0005433717208	29241	Economy	10700.00
0005433717098	29241	Economy	10700.00
0005433717141	29241	Economy	10700.00
0005433717109	29241	Economy	10700.00
0005433717390	29241	Economy	10700.00
0005433722400	29241	Economy	10700.00
0005433722386	29241	Economy	10700.00
0005433717342	29241	Economy	10700.00
0005433656760	29241	Economy	10700.00
0005433717316	29241	Economy	10700.00
0005433717411	29241	Economy	10700.00
0005435546242	29241	Economy	10700.00
0005433717264	29241	Economy	10700.00
0005433717174	29241	Economy	10700.00
0005433717214	29241	Economy	10700.00
0005433717222	29241	Economy	10700.00
0005433722387	29241	Economy	10700.00
0005434182495	8661	Business	36500.00
0005435860674	8661	Business	36500.00
0005434182520	8661	Business	36500.00
0005435860699	8661	Business	36500.00
0005435860700	8661	Economy	12200.00
0005435860684	8661	Economy	12200.00
0005434182497	8661	Economy	12200.00
0005435860677	8661	Economy	13400.00
0005434184721	8661	Economy	12200.00
0005434182510	8661	Economy	12200.00
0005435860669	8661	Economy	12200.00
0005434184722	8661	Economy	12200.00
0005434184723	8661	Economy	12200.00
0005435860715	8661	Economy	12200.00
0005434182519	8661	Economy	12200.00
0005435860680	8661	Economy	12200.00
0005435860676	8661	Economy	12200.00
0005434182509	8661	Economy	12200.00
0005434182501	8661	Economy	12200.00
0005435860683	8661	Economy	12200.00
0005434182491	8661	Economy	12200.00
0005434095678	11678	Business	36500.00
0005434143753	11678	Business	36500.00
0005434143805	11678	Business	36500.00
0005434143771	11678	Business	36500.00
0005434143780	11678	Economy	12200.00
0005434095642	11678	Economy	13400.00
0005434143790	11678	Economy	13400.00
0005434143772	11678	Economy	12200.00
0005434143791	11678	Economy	12200.00
0005434095635	11678	Economy	12200.00
0005434095634	11678	Economy	12200.00
0005434095694	11678	Economy	12200.00
0005434095679	11678	Economy	12200.00
0005434095618	11678	Economy	12200.00
0005434095684	11678	Economy	12200.00
0005434095621	11678	Economy	12200.00
0005434095620	11678	Economy	12200.00
0005434143770	11678	Economy	12200.00
0005434095613	11678	Economy	12200.00
0005434095641	11678	Economy	12200.00
0005434095660	11678	Economy	12200.00
0005434095685	11678	Economy	12200.00
0005434326287	11678	Economy	12200.00
0005434143773	11678	Economy	12200.00
0005433399179	1472	Business	33000.00
0005433399364	1472	Business	33000.00
0005433399271	1472	Business	33000.00
0005433399122	1472	Business	33000.00
0005433399366	1472	Business	33000.00
0005433399407	1472	Business	33000.00
0005433399408	1472	Economy	12100.00
0005433399300	1472	Economy	11000.00
0005433399233	1472	Economy	11000.00
0005433399318	1472	Economy	11000.00
0005433399355	1472	Economy	11000.00
0005433399238	1472	Economy	11000.00
0005433399237	1472	Economy	11000.00
0005433399405	1472	Economy	11000.00
0005433399319	1472	Economy	11000.00
0005433399418	1472	Economy	11000.00
0005433399142	1472	Economy	11000.00
0005433399241	1472	Economy	11000.00
0005433399151	1472	Economy	11000.00
0005433399393	1472	Economy	11000.00
0005433399169	1472	Economy	11000.00
0005433399301	1472	Economy	11000.00
0005433399180	1472	Economy	11000.00
0005433399320	1472	Economy	11000.00
0005433399392	1472	Economy	11000.00
0005433399234	1472	Economy	11000.00
0005435732688	19276	Business	33000.00
0005435732661	19276	Business	33000.00
0005435732637	19276	Business	33000.00
0005435732639	19276	Economy	11000.00
0005435732647	19276	Economy	11000.00
0005435732666	19276	Economy	12100.00
0005435732650	19276	Economy	11000.00
0005435732667	19276	Economy	11000.00
0005435732648	19276	Economy	11000.00
0005433457083	19276	Economy	11000.00
0005435732646	19276	Economy	11000.00
0005435732638	19276	Economy	11000.00
0005433457086	19276	Economy	11000.00
0005435732660	19276	Economy	11000.00
0005435732665	19276	Economy	11000.00
0005435732691	19276	Economy	11000.00
0005435732621	19276	Economy	11000.00
0005435732701	19276	Economy	11000.00
0005435732702	19276	Economy	11000.00
0005435732651	19276	Economy	11000.00
0005435732689	19276	Economy	11000.00
0005435732690	19276	Economy	11000.00
0005434444099	17365	Economy	14100.00
0005434444147	17365	Economy	14100.00
0005434444079	17365	Economy	14100.00
0005434444146	17365	Economy	14100.00
0005434444148	17365	Economy	14100.00
0005434444127	17365	Economy	14100.00
0005434444151	17365	Economy	14100.00
0005434444133	17365	Economy	14100.00
0005434444077	17365	Economy	14100.00
0005434444135	17365	Economy	14100.00
0005434444120	17365	Economy	14100.00
0005435311567	20567	Economy	15600.00
0005434444187	20567	Economy	14100.00
0005434954708	28359	Economy	5800.00
0005434183621	4507	Economy	15400.00
0005435893806	4507	Economy	15400.00
0005435893820	4507	Economy	14000.00
0005435893795	4507	Economy	14000.00
0005435893794	4507	Economy	14000.00
0005435893819	4507	Economy	14000.00
0005435893825	4507	Economy	14000.00
0005435893821	4507	Economy	14000.00
0005434352040	29629	Economy	14000.00
0005434352041	29629	Economy	14000.00
0005434352032	29629	Economy	14000.00
0005434326102	29629	Economy	14000.00
0005434326056	29629	Economy	14000.00
0005434351964	29629	Economy	14000.00
0005434352022	29629	Economy	14000.00
0005434352039	29629	Economy	14000.00
0005434352004	29629	Economy	14000.00
0005434352017	29629	Economy	14000.00
0005434352042	29629	Economy	14000.00
0005434352021	29629	Economy	14000.00
0005434352027	29629	Economy	14000.00
0005434352003	29629	Economy	14000.00
0005434351971	29629	Economy	14000.00
0005434326103	29629	Economy	14000.00
0005433345732	1052	Business	30600.00
0005433345771	1052	Business	30600.00
0005433345461	1052	Business	30600.00
0005433345475	1052	Business	30600.00
0005433345913	1052	Business	30600.00
0005433345856	1052	Business	30600.00
0005433345938	1052	Business	30600.00
0005433345488	1052	Business	30600.00
0005433345681	1052	Business	30600.00
0005433345937	1052	Business	30600.00
0005433345649	1052	Business	30600.00
0005433345487	1052	Economy	11200.00
0005433345476	1052	Economy	11200.00
0005433345584	1052	Economy	10200.00
0005433345857	1052	Economy	10200.00
0005433345702	1052	Economy	10200.00
0005433345723	1052	Economy	10200.00
0005433345876	1052	Economy	10200.00
0005433345742	1052	Economy	10200.00
0005433345481	1052	Economy	10200.00
0005433345056	1052	Economy	10200.00
0005433345733	1052	Economy	10200.00
0005433345473	1052	Economy	10200.00
0005433345449	1052	Economy	10200.00
0005433345603	1052	Economy	10200.00
0005433345703	1052	Economy	10200.00
0005433345679	1052	Economy	10200.00
0005433345847	1052	Economy	10200.00
0005433345725	1052	Economy	10200.00
0005433345781	1052	Economy	10200.00
0005433345762	1052	Economy	10200.00
0005433345875	1052	Economy	10200.00
0005433345720	1052	Economy	10200.00
0005433345328	1052	Economy	10200.00
0005435092367	1052	Economy	10200.00
0005433345661	1052	Economy	10200.00
0005433345896	1052	Economy	10200.00
0005433345397	1052	Economy	10200.00
0005433345724	1052	Economy	10200.00
0005435092366	1052	Economy	10200.00
0005433345740	1052	Economy	10200.00
0005433345605	1052	Economy	10200.00
0005433345602	1052	Economy	10200.00
0005433345682	1052	Economy	10200.00
0005433345677	1052	Economy	10200.00
0005433345790	1052	Economy	11200.00
0005433345543	1052	Economy	10200.00
0005433345201	1052	Economy	10200.00
0005433345741	1052	Economy	11200.00
0005433269855	1052	Economy	10200.00
0005433345836	1052	Economy	10200.00
0005433345182	1052	Economy	10200.00
0005433345474	1052	Economy	10200.00
0005433345823	1052	Economy	10200.00
0005433159370	1052	Economy	10200.00
0005433345659	1052	Economy	10200.00
0005433345660	1052	Economy	10200.00
0005433345415	1052	Economy	10200.00
0005433345662	1052	Economy	10200.00
0005433345858	1052	Economy	10200.00
0005433345416	1052	Economy	10200.00
0005433345472	1052	Economy	10200.00
0005433345829	1052	Economy	10200.00
0005433345772	1052	Economy	10200.00
0005433345899	1052	Economy	10200.00
0005433345625	1052	Economy	10200.00
0005433345704	1052	Economy	10200.00
0005433345779	1052	Economy	10200.00
0005433345830	1052	Economy	10200.00
0005433345751	1052	Economy	10200.00
0005433345587	1052	Economy	10200.00
0005433345784	1052	Economy	10200.00
0005433345358	1052	Economy	10200.00
0005433345202	1052	Economy	10200.00
0005433345571	1052	Economy	10200.00
0005433345423	1052	Economy	10200.00
0005433345513	1052	Economy	10200.00
0005433345900	1052	Economy	10200.00
0005433345515	1052	Economy	10200.00
0005433269878	17058	Business	30600.00
0005435508705	17058	Business	30600.00
0005435092309	17058	Business	30600.00
0005435092335	17058	Business	30600.00
0005435092337	17058	Business	30600.00
0005435530107	17058	Business	30600.00
0005434445301	17058	Business	30600.00
0005435530136	17058	Economy	11200.00
0005435508793	17058	Economy	10200.00
0005435092311	17058	Economy	10200.00
0005433346084	17058	Economy	10200.00
0005435092324	17058	Economy	10200.00
0005435508794	17058	Economy	10200.00
0005435508596	17058	Economy	10200.00
0005435508724	17058	Economy	10200.00
0005435092330	17058	Economy	10200.00
0005435508635	17058	Economy	10200.00
0005435508720	17058	Economy	10200.00
0005435508597	17058	Economy	10200.00
0005435508631	17058	Economy	10200.00
0005435092316	17058	Economy	10200.00
0005435508717	17058	Economy	10200.00
0005435092308	17058	Economy	10200.00
0005435530054	17058	Economy	10200.00
0005435530112	17058	Economy	10200.00
0005435092331	17058	Economy	10200.00
0005435092351	17058	Economy	10200.00
0005435092340	17058	Economy	10200.00
0005435530047	17058	Economy	10200.00
0005435508723	17058	Economy	10200.00
0005435530094	17058	Economy	10200.00
0005435530091	17058	Economy	10200.00
0005434445306	17058	Economy	10200.00
0005435530030	17058	Economy	10200.00
0005435530147	17058	Economy	10200.00
0005435508766	17058	Economy	10200.00
0005435530102	17058	Economy	10200.00
0005435508697	17058	Economy	10200.00
0005433269879	17058	Economy	10200.00
0005435530133	17058	Economy	10200.00
0005435092336	17058	Economy	10200.00
0005435530135	17058	Economy	10200.00
0005435508721	17058	Economy	10200.00
0005435092310	17058	Economy	11200.00
0005435530127	17058	Economy	10200.00
0005435530146	17058	Economy	10200.00
0005434445312	17058	Economy	10200.00
0005434445313	17058	Economy	10200.00
0005435508716	17058	Economy	10200.00
0005435530093	17058	Economy	10200.00
0005435508804	17058	Economy	10200.00
0005435545982	17058	Economy	10200.00
0005433346083	17058	Economy	10200.00
0005433346082	17058	Economy	10200.00
0005435530131	17058	Economy	10200.00
0005435508703	17058	Economy	10200.00
0005435508704	17058	Economy	10200.00
0005435508706	17058	Economy	10200.00
0005435092354	17058	Economy	10200.00
0005435530010	17058	Economy	10200.00
0005435092296	17058	Economy	10200.00
0005435530095	17058	Economy	10200.00
0005435530134	17058	Economy	10200.00
0005432852058	1346	Business	101000.00
0005432852056	1346	Business	101000.00
0005432390485	1346	Business	101000.00
0005432852066	1346	Economy	33700.00
0005432852036	1346	Economy	33700.00
0005432852074	1346	Economy	33700.00
0005432852060	1346	Economy	33700.00
0005432392085	1346	Economy	33700.00
0005432852059	1346	Economy	33700.00
0005432852073	1346	Economy	33700.00
0005432852065	1346	Economy	33700.00
0005432852038	1346	Economy	33700.00
0005432852061	1346	Economy	33700.00
0005432852057	1346	Economy	33700.00
0005432392084	1346	Economy	33700.00
0005432390486	1346	Economy	33700.00
0005432852068	1346	Economy	33700.00
0005432852055	1346	Economy	33700.00
0005432852053	1346	Economy	33700.00
0005432852072	1346	Economy	33700.00
0005434082444	12818	Business	40300.00
0005434082453	12818	Business	40300.00
0005434082490	12818	Business	40300.00
0005434069227	12818	Business	40300.00
0005434082520	12818	Business	40300.00
0005434069493	12818	Business	40300.00
0005434069332	12818	Business	40300.00
0005434069272	12818	Business	40300.00
0005434069327	12818	Business	40300.00
0005434069407	12818	Business	40300.00
0005434069031	12818	Economy	13400.00
0005434069452	12818	Economy	13400.00
0005434069376	12818	Economy	13400.00
0005434069398	12818	Economy	13400.00
0005434069235	12818	Economy	13400.00
0005434069294	12818	Economy	13400.00
0005434082552	12818	Economy	13400.00
0005434082489	12818	Economy	13400.00
0005434082474	12818	Economy	13400.00
0005434069166	12818	Economy	13400.00
0005434069303	12818	Economy	13400.00
0005434082550	12818	Economy	13400.00
0005434082551	12818	Economy	13400.00
0005433989887	12818	Economy	13400.00
0005434082539	12818	Economy	13400.00
0005434069302	12818	Economy	13400.00
0005434082576	12818	Economy	13400.00
0005434069296	12818	Economy	13400.00
0005434082442	12818	Economy	13400.00
0005434082450	12818	Economy	13400.00
0005434069271	12818	Economy	13400.00
0005434068966	12818	Economy	13400.00
0005434069259	12818	Economy	13400.00
0005434082519	12818	Economy	13400.00
0005434069295	12818	Economy	14800.00
0005434082432	12818	Economy	14800.00
0005434069278	12818	Economy	14800.00
0005434069401	12818	Economy	14800.00
0005434069221	12818	Economy	14800.00
0005434069268	12818	Economy	14800.00
0005434069226	12818	Economy	13400.00
0005434082563	12818	Economy	13400.00
0005434069255	12818	Economy	13400.00
0005434069441	12818	Economy	13400.00
0005434082485	12818	Economy	13400.00
0005434069337	12818	Economy	13400.00
0005434069148	12818	Economy	13400.00
0005434082525	12818	Economy	13400.00
0005434069443	12818	Economy	13400.00
0005434082298	12818	Economy	13400.00
0005434069015	12818	Economy	13400.00
0005434069311	12818	Economy	13400.00
0005434069254	12818	Economy	13400.00
0005434069440	12818	Economy	13400.00
0005434069510	12818	Economy	13400.00
0005434082591	12818	Economy	13400.00
0005434082445	12818	Economy	13400.00
0005434082469	12818	Economy	13400.00
0005434069508	12818	Economy	13400.00
0005434082526	12818	Economy	13400.00
0005434069260	12818	Economy	13400.00
0005434069442	12818	Economy	13400.00
0005434069341	12818	Economy	13400.00
0005434069543	12818	Economy	13400.00
0005434082584	12818	Economy	13400.00
0005434069363	12818	Economy	13400.00
0005434082622	12818	Economy	13400.00
0005434082431	12818	Economy	13400.00
0005434082532	12818	Economy	13400.00
0005434069378	12818	Economy	13400.00
0005434082592	12818	Economy	13400.00
0005434069507	12818	Economy	13400.00
0005434069151	12818	Economy	13400.00
0005434069377	12818	Economy	13400.00
0005434069336	12818	Economy	13400.00
0005434082621	12818	Economy	13400.00
0005434069212	12818	Economy	13400.00
0005434082475	12818	Economy	13400.00
0005434026750	12818	Economy	13400.00
0005434069289	12818	Economy	13400.00
0005434069234	12818	Economy	13400.00
0005434069161	12818	Economy	13400.00
0005434068996	12818	Economy	13400.00
0005434069222	12818	Economy	13400.00
0005434069466	12818	Economy	13400.00
0005434082486	12818	Economy	13400.00
0005434082543	12818	Economy	13400.00
0005435283461	30694	Business	40300.00
0005435283473	30694	Business	40300.00
0005435283472	30694	Business	40300.00
0005432433824	30694	Economy	13400.00
0005435283488	30694	Economy	13400.00
0005434069647	30694	Economy	13400.00
0005435283447	30694	Economy	13400.00
0005435283434	30694	Economy	13400.00
0005434082650	30694	Economy	13400.00
0005435283448	30694	Economy	13400.00
0005435283460	30694	Economy	13400.00
0005435283450	30694	Economy	13400.00
0005432433829	30694	Economy	13400.00
0005435283446	30694	Economy	13400.00
0005432433820	30694	Economy	13400.00
0005435283458	30694	Economy	13400.00
0005435283459	30694	Economy	13400.00
0005434082649	30694	Economy	13400.00
0005435283489	30694	Economy	13400.00
0005434069648	30694	Economy	13400.00
0005434082651	30694	Economy	13400.00
0005434069645	30694	Economy	13400.00
0005432433811	30694	Economy	13400.00
0005434082647	30694	Economy	13400.00
0005435283471	30694	Economy	13400.00
0005435283470	30694	Economy	13400.00
0005434082648	30694	Economy	13400.00
0005434069649	30694	Economy	13400.00
0005434069646	30694	Economy	13400.00
0005435283500	30694	Economy	13400.00
0005435283445	30694	Economy	13400.00
0005434082652	30694	Economy	13400.00
0005435283502	30694	Economy	13400.00
0005434265738	5491	Business	35300.00
0005434265864	5491	Business	35300.00
0005435463347	5491	Business	35300.00
0005435463496	5491	Business	35300.00
0005434265769	5491	Business	35300.00
0005435463435	5491	Business	35300.00
0005435463388	5491	Business	35300.00
0005432535948	5491	Business	35300.00
0005435463429	5491	Business	35300.00
0005435463475	5491	Economy	12900.00
0005435768125	5491	Business	35300.00
0005434265718	5491	Economy	12900.00
0005435463346	5491	Economy	11800.00
0005434265742	5491	Economy	11800.00
0005434265756	5491	Economy	11800.00
0005435463278	5491	Economy	11800.00
0005435463495	5491	Economy	11800.00
0005434265723	5491	Economy	11800.00
0005435768124	5491	Economy	11800.00
0005435463330	5491	Economy	11800.00
0005435463387	5491	Economy	11800.00
0005434265840	5491	Economy	11800.00
0005434265883	5491	Economy	11800.00
0005434265736	5491	Economy	11800.00
0005435463242	5491	Economy	11800.00
0005435463471	5491	Economy	11800.00
0005435463333	5491	Economy	11800.00
0005435463365	5491	Economy	11800.00
0005435463329	5491	Economy	11800.00
0005435617186	5491	Economy	11800.00
0005434265819	5491	Economy	11800.00
0005435463407	5491	Economy	11800.00
0005434265770	5491	Economy	11800.00
0005435617185	5491	Economy	11800.00
0005435463205	5491	Economy	11800.00
0005434265730	5491	Economy	11800.00
0005435463412	5491	Economy	11800.00
0005435463398	5491	Economy	11800.00
0005435463411	5491	Economy	11800.00
0005434265722	5491	Economy	11800.00
0005434265837	5491	Economy	11800.00
0005435463324	5491	Economy	11800.00
0005434265739	5491	Economy	12900.00
0005435463291	5491	Economy	11800.00
0005435463312	5491	Economy	11800.00
0005434265838	5491	Economy	11800.00
0005435463247	5491	Economy	11800.00
0005435043298	5491	Economy	11800.00
0005435463206	5491	Economy	11800.00
0005434831247	5491	Economy	11800.00
0005435463322	5491	Economy	11800.00
0005434265777	5491	Economy	11800.00
0005434265846	5491	Economy	11800.00
0005434265778	5491	Economy	11800.00
0005435463470	5491	Economy	11800.00
0005435463323	5491	Economy	11800.00
0005435463372	5491	Economy	11800.00
0005435463421	5491	Economy	11800.00
0005434265771	5491	Economy	11800.00
0005434265863	5491	Economy	11800.00
0005432535964	5491	Economy	11800.00
0005434831268	5491	Economy	11800.00
0005434265764	5491	Economy	11800.00
0005434265841	5491	Economy	11800.00
0005435463277	5491	Economy	11800.00
0005435463413	5491	Economy	11800.00
0005434265813	5491	Economy	11800.00
0005435463332	5491	Economy	11800.00
0005434265842	5491	Economy	11800.00
0005435463389	5491	Economy	11800.00
0005435463410	5491	Economy	11800.00
0005434265763	5491	Economy	11800.00
0005435767714	13474	Business	35300.00
0005435767974	13474	Business	35300.00
0005435767995	13474	Business	35300.00
0005435767847	13474	Business	35300.00
0005435767952	13474	Business	35300.00
0005435767931	13474	Business	35300.00
0005435723096	13474	Business	35300.00
0005435767881	13474	Business	35300.00
0005435767951	13474	Business	35300.00
0005435735262	13474	Business	35300.00
0005435767923	13474	Business	35300.00
0005435767932	13474	Business	35300.00
0005435767669	13474	Business	35300.00
0005435767726	13474	Business	35300.00
0005435722105	13474	Business	35300.00
0005434265902	13474	Business	35300.00
0005435767879	13474	Economy	11800.00
0005435767713	13474	Economy	11800.00
0005435767681	13474	Economy	11800.00
0005435767796	13474	Economy	11800.00
0005435767936	13474	Economy	11800.00
0005435768103	13474	Economy	11800.00
0005435767950	13474	Economy	11800.00
0005435767800	13474	Economy	11800.00
0005435767902	13474	Economy	11800.00
0005435725722	13474	Economy	11800.00
0005435767933	13474	Economy	11800.00
0005435767673	13474	Economy	11800.00
0005435725723	13474	Economy	11800.00
0005435767989	13474	Economy	11800.00
0005435722117	13474	Economy	11800.00
0005435768105	13474	Economy	11800.00
0005435767802	13474	Economy	11800.00
0005435767758	13474	Economy	11800.00
0005435720163	13474	Economy	11800.00
0005435768041	13474	Economy	11800.00
0005435767889	13474	Economy	11800.00
0005435767813	13474	Economy	11800.00
0005435735239	13474	Economy	11800.00
0005435767711	13474	Economy	11800.00
0005435767689	13474	Economy	11800.00
0005435768031	13474	Economy	11800.00
0005435735261	13474	Economy	11800.00
0005435767499	13474	Economy	11800.00
0005435767920	13474	Economy	11800.00
0005435767712	13474	Economy	11800.00
0005435723098	13474	Economy	11800.00
0005435767757	13474	Economy	11800.00
0005435723097	13474	Economy	11800.00
0005435767743	13474	Economy	11800.00
0005435767901	13474	Economy	11800.00
0005435767558	13474	Economy	11800.00
0005435767557	13474	Economy	11800.00
0005435735238	13474	Economy	11800.00
0005435767501	13474	Economy	11800.00
0005435767958	13474	Economy	11800.00
0005435767938	13474	Economy	11800.00
0005435767930	13474	Economy	11800.00
0005435767922	13474	Economy	11800.00
0005435768104	13474	Economy	11800.00
0005434265901	13474	Economy	11800.00
0005435767919	13474	Economy	11800.00
0005435767680	13474	Economy	11800.00
0005435722103	13474	Economy	11800.00
0005435767829	13474	Economy	11800.00
0005435767786	13474	Economy	11800.00
0005435767888	13474	Economy	11800.00
0005435735263	13474	Economy	11800.00
0005435767535	13474	Economy	11800.00
0005435767500	13474	Economy	11800.00
0005435767518	13474	Economy	11800.00
0005435768042	13474	Economy	11800.00
0005435767967	13474	Economy	11800.00
0005435767880	13474	Economy	11800.00
0005435767797	13474	Economy	11800.00
0005434602960	18713	Economy	3300.00
0005434602959	18713	Economy	3300.00
0005434602971	18713	Economy	3300.00
0005434602958	18713	Economy	3300.00
0005434515042	19157	Economy	3300.00
0005432649558	25086	Business	88300.00
0005432649546	25086	Business	88300.00
0005432649539	25086	Business	88300.00
0005432649528	25086	Economy	29400.00
0005432649545	25086	Economy	29400.00
0005432649560	25086	Economy	32400.00
0005432649527	25086	Economy	29400.00
0005432649538	25086	Economy	29400.00
0005432649532	25086	Economy	29400.00
0005432649547	25086	Economy	29400.00
0005432649533	25086	Economy	29400.00
0005432649557	25086	Economy	29400.00
0005433286148	1859	Business	48700.00
0005433009894	1859	Business	48700.00
0005433286149	1859	Business	48700.00
0005433286064	1859	Business	48700.00
0005433009869	1859	Business	48700.00
0005433810814	1859	Business	48700.00
0005433810811	1859	Business	48700.00
0005435097528	1859	Business	48700.00
0005433009641	1859	Business	48700.00
0005433009844	1859	Business	48700.00
0005433810812	1859	Economy	16200.00
0005433009691	1859	Economy	16200.00
0005433009751	1859	Economy	16200.00
0005433286077	1859	Economy	16200.00
0005433286182	1859	Economy	16200.00
0005433009888	1859	Economy	16200.00
0005433009548	1859	Economy	16200.00
0005433009493	1859	Economy	16200.00
0005433009891	1859	Economy	17900.00
0005433009848	1859	Economy	17900.00
0005433009679	1859	Economy	17900.00
0005433009762	1859	Economy	17900.00
0005433009874	1859	Economy	16200.00
0005433009925	1859	Economy	16200.00
0005433286130	1859	Economy	16200.00
0005433009842	1859	Economy	16200.00
0005433286101	1859	Economy	16200.00
0005433009930	1859	Economy	16200.00
0005433810816	1859	Economy	16200.00
0005433009929	1859	Economy	16200.00
0005433009725	1859	Economy	16200.00
0005433009805	1859	Economy	16200.00
0005433286044	1859	Economy	16200.00
0005433286072	1859	Economy	16200.00
0005433286158	1859	Economy	16200.00
0005433009886	1859	Economy	16200.00
0005433285978	1859	Economy	16200.00
0005433286181	1859	Economy	16200.00
0005433286119	1859	Economy	16200.00
0005433009870	1859	Economy	16200.00
0005433009892	1859	Economy	16200.00
0005433009856	1859	Economy	16200.00
0005433286117	1859	Economy	16200.00
0005433286041	1859	Economy	16200.00
0005433810813	1859	Economy	16200.00
0005435097529	1859	Economy	16200.00
0005433810818	1859	Economy	16200.00
0005433009859	1859	Economy	16200.00
0005433286118	1859	Economy	16200.00
0005433009494	1859	Economy	16200.00
0005433286199	1859	Economy	16200.00
0005433009803	1859	Economy	16200.00
0005433810815	1859	Economy	16200.00
0005433286109	1859	Economy	16200.00
0005433286062	1859	Economy	16200.00
0005433009753	1859	Economy	16200.00
0005433009843	1859	Economy	16200.00
0005433810817	1859	Economy	16200.00
0005433286102	1859	Economy	16200.00
0005433009893	1859	Economy	16200.00
0005433009768	1859	Economy	16200.00
0005433009887	1859	Economy	16200.00
0005433009724	1859	Economy	16200.00
0005433009775	1859	Economy	16200.00
0005433009885	1859	Economy	16200.00
0005433009752	1859	Economy	16200.00
0005433009804	1859	Economy	16200.00
0005433009763	1859	Economy	16200.00
0005433009776	1859	Economy	16200.00
0005433286150	1859	Economy	16200.00
0005433285951	1859	Economy	16200.00
0005433009810	1859	Economy	16200.00
0005433009817	1859	Economy	16200.00
0005435732726	1859	Economy	16200.00
0005433009795	1859	Economy	16200.00
0005435732730	1859	Economy	16200.00
0005433285999	1859	Economy	16200.00
0005435097527	1859	Economy	16200.00
0005433286071	1859	Economy	16200.00
0005433009642	1859	Economy	16200.00
0005433009974	22539	Business	48700.00
0005433009976	22539	Business	48700.00
0005433009977	22539	Business	48700.00
0005433810756	22539	Business	48700.00
0005433810714	22539	Business	48700.00
0005433810679	22539	Business	48700.00
0005433810680	22539	Economy	16200.00
0005433810725	22539	Economy	16200.00
0005433286229	22539	Economy	16200.00
0005433810726	22539	Economy	16200.00
0005433810757	22539	Economy	16200.00
0005433009973	22539	Economy	16200.00
0005433810663	22539	Economy	16200.00
0005433009975	22539	Economy	16200.00
0005433009981	22539	Economy	16200.00
0005433810712	22539	Economy	16200.00
0005433810683	22539	Economy	16200.00
0005433810713	22539	Economy	16200.00
0005433009980	22539	Economy	16200.00
0005433810695	22539	Economy	16200.00
0005433810674	22539	Economy	16200.00
0005433810704	22539	Economy	16200.00
0005433810694	22539	Economy	16200.00
0005433009978	22539	Economy	16200.00
0005433009979	22539	Economy	16200.00
0005433810682	22539	Economy	16200.00
0005433810675	22539	Economy	16200.00
0005432755156	12288	Business	83800.00
0005432755150	12288	Business	83800.00
0005432751610	12288	Business	83800.00
0005432755152	12288	Business	83800.00
0005432751593	12288	Economy	27900.00
0005432751603	12288	Economy	27900.00
0005432751594	12288	Economy	27900.00
0005432751609	12288	Economy	30700.00
0005432755162	12288	Economy	30700.00
0005432755153	12288	Economy	30700.00
0005432755155	12288	Economy	27900.00
0005432755149	12288	Economy	27900.00
0005432755148	12288	Economy	27900.00
0005432751599	12288	Economy	27900.00
0005432751598	12288	Economy	27900.00
0005432751608	12288	Economy	27900.00
0005432755136	12288	Economy	27900.00
0005432751621	12288	Economy	27900.00
0005432751597	12288	Economy	27900.00
0005432751619	12288	Economy	27900.00
0005432751620	12288	Economy	27900.00
0005432755151	12288	Economy	27900.00
0005435283173	5600	Business	99800.00
0005435282972	5600	Business	99800.00
0005435283130	5600	Business	99800.00
0005434173616	5600	Business	99800.00
0005435283138	5600	Business	99800.00
0005433848412	5600	Economy	33300.00
0005435283214	5600	Economy	33300.00
0005433848411	5600	Economy	33300.00
0005435283145	5600	Economy	33300.00
0005435283073	5600	Economy	33300.00
0005435283135	5600	Economy	33300.00
0005434173623	5600	Economy	33300.00
0005435283139	5600	Economy	36600.00
0005433815567	5600	Economy	33300.00
0005435282973	5600	Economy	33300.00
0005434173622	5600	Economy	33300.00
0005435283168	5600	Economy	33300.00
0005435283025	5600	Economy	33300.00
0005435283131	5600	Economy	33300.00
0005435283129	5600	Economy	33300.00
0005435283189	5600	Economy	33300.00
0005435283117	5600	Economy	33300.00
0005435283146	5600	Economy	33300.00
0005433815527	5600	Economy	33300.00
0005435283106	5600	Economy	33300.00
0005435283086	5600	Economy	33300.00
0005434173615	5600	Economy	33300.00
0005434173624	5600	Economy	33300.00
0005435283136	5600	Economy	33300.00
0005434173614	5600	Economy	33300.00
0005434173612	5600	Economy	33300.00
0005435283166	5600	Economy	33300.00
0005433848067	13830	Business	99800.00
0005433848368	13830	Business	99800.00
0005433848279	13830	Business	99800.00
0005433848145	13830	Business	99800.00
0005433848282	13830	Business	99800.00
0005433848146	13830	Business	99800.00
0005433848089	13830	Business	99800.00
0005433815575	13830	Business	99800.00
0005433848152	13830	Business	99800.00
0005433848088	13830	Business	99800.00
0005433848272	13830	Economy	33300.00
0005433848277	13830	Economy	33300.00
0005433815476	13830	Economy	33300.00
0005435283253	13830	Economy	33300.00
0005433848228	13830	Economy	33300.00
0005433848127	13830	Economy	33300.00
0005433847959	13830	Economy	33300.00
0005433848195	13830	Economy	33300.00
0005433848220	13830	Economy	36600.00
0005433848266	13830	Economy	36600.00
0005433848048	13830	Economy	33300.00
0005433848054	13830	Economy	33300.00
0005433848182	13830	Economy	33300.00
0005433848036	13830	Economy	33300.00
0005433848336	13830	Economy	33300.00
0005433848302	13830	Economy	33300.00
0005433848106	13830	Economy	33300.00
0005433848367	13830	Economy	33300.00
0005435283252	13830	Economy	33300.00
0005433848221	13830	Economy	33300.00
0005433848280	13830	Economy	33300.00
0005433848263	13830	Economy	33300.00
0005433815510	13830	Economy	33300.00
0005433848341	13830	Economy	33300.00
0005433848239	13830	Economy	33300.00
0005433848267	13830	Economy	33300.00
0005433848303	13830	Economy	33300.00
0005433848229	13830	Economy	33300.00
0005433848334	13830	Economy	33300.00
0005433848094	13830	Economy	33300.00
0005433848219	13830	Economy	33300.00
0005433848325	13830	Economy	33300.00
0005433815521	13830	Economy	33300.00
0005433848223	13830	Economy	33300.00
0005433848189	13830	Economy	33300.00
0005433848281	13830	Economy	33300.00
0005433848011	13830	Economy	33300.00
0005433848366	13830	Economy	33300.00
0005433848333	13830	Economy	33300.00
0005433848238	13830	Economy	33300.00
0005433848185	13830	Economy	33300.00
0005433848335	13830	Economy	33300.00
0005433848258	13830	Economy	33300.00
0005433848276	13830	Economy	33300.00
0005433815499	13830	Economy	33300.00
0005433848079	13830	Economy	33300.00
0005433848271	13830	Economy	33300.00
0005433848206	13830	Economy	33300.00
0005433848308	13830	Economy	33300.00
0005433847958	13830	Economy	33300.00
0005433848010	13830	Economy	33300.00
0005433848055	13830	Economy	33300.00
0005433848326	13830	Economy	33300.00
0005434621182	7832	Economy	16600.00
0005435332634	7832	Economy	16600.00
0005435332610	7832	Economy	15100.00
0005435332628	7832	Economy	15100.00
0005435332611	7832	Economy	15100.00
0005434621183	7832	Economy	15100.00
0005435332619	7832	Economy	15100.00
0005435332633	7832	Economy	15100.00
0005435332616	7832	Economy	15100.00
0005435332574	7832	Economy	15100.00
0005435332630	7832	Economy	15100.00
0005435332629	7832	Economy	15100.00
0005434621151	32972	Economy	16600.00
0005434621142	32972	Economy	15100.00
0005434621129	32972	Economy	15100.00
0005434621135	32972	Economy	15100.00
0005434621051	32972	Economy	15100.00
0005435332644	32972	Economy	15100.00
0005435332645	32972	Economy	15100.00
0005434621146	32972	Economy	15100.00
0005434621136	32972	Economy	15100.00
0005434621064	32972	Economy	15100.00
0005434621063	32972	Economy	15100.00
0005434621096	32972	Economy	15100.00
0005434621150	32972	Economy	15100.00
0005434621145	32972	Economy	15100.00
0005435918788	4304	Business	38000.00
0005435983727	4304	Business	38000.00
0005435937553	4304	Economy	12700.00
0005435937563	4304	Economy	13900.00
0005435918765	4304	Economy	12700.00
0005435937530	4304	Economy	12700.00
0005435918764	4304	Economy	12700.00
0005435937514	4304	Economy	12700.00
0005435918760	4304	Economy	12700.00
0005435937548	4304	Economy	12700.00
0005435918791	4304	Economy	12700.00
0005435937515	4304	Economy	12700.00
0005435937523	4304	Economy	12700.00
0005435937521	4304	Economy	12700.00
0005435937531	4304	Economy	12700.00
0005435983728	4304	Economy	12700.00
0005435918792	4304	Economy	12700.00
0005434994241	27284	Business	38000.00
0005435786198	27284	Business	38000.00
0005435786156	27284	Business	38000.00
0005434994257	27284	Business	38000.00
0005435786320	27284	Business	38000.00
0005435786236	27284	Business	38000.00
0005435786192	27284	Business	38000.00
0005434994299	27284	Business	38000.00
0005435786135	27284	Business	38000.00
0005434994263	27284	Economy	12700.00
0005435786319	27284	Economy	12700.00
0005435786071	27284	Economy	12700.00
0005435786123	27284	Economy	12700.00
0005434994280	27284	Economy	12700.00
0005434994262	27284	Economy	12700.00
0005435786258	27284	Economy	13900.00
0005434994256	27284	Economy	13900.00
0005435786193	27284	Economy	12700.00
0005434994264	27284	Economy	12700.00
0005435787401	27284	Economy	12700.00
0005435786118	27284	Economy	12700.00
0005434994240	27284	Economy	12700.00
0005434994279	27284	Economy	12700.00
0005435786043	27284	Economy	12700.00
0005435786241	27284	Economy	12700.00
0005435786211	27284	Economy	12700.00
0005434994281	27284	Economy	12700.00
0005434994295	27284	Economy	12700.00
0005434994285	27284	Economy	12700.00
0005435786059	27284	Economy	12700.00
0005435786173	27284	Economy	12700.00
0005435786124	27284	Economy	12700.00
0005435786126	27284	Economy	12700.00
0005435786185	27284	Economy	12700.00
0005435786195	27284	Economy	12700.00
0005435786157	27284	Economy	12700.00
0005435786060	27284	Economy	12700.00
0005435786038	27284	Economy	12700.00
0005435786266	27284	Economy	12700.00
0005435786127	27284	Economy	12700.00
0005435786180	27284	Economy	12700.00
0005435786212	27284	Economy	12700.00
0005435786267	27284	Economy	12700.00
0005435786226	27284	Economy	12700.00
0005435786070	27284	Economy	12700.00
0005434994270	27284	Economy	12700.00
0005435786196	27284	Economy	12700.00
0005435786181	27284	Economy	12700.00
0005435786090	27284	Economy	12700.00
0005435786105	27284	Economy	12700.00
0005434994282	27284	Economy	12700.00
0005435786197	27284	Economy	12700.00
0005435786122	27284	Economy	12700.00
0005435786125	27284	Economy	12700.00
0005435786221	27284	Economy	12700.00
0005435786106	27284	Economy	12700.00
0005435787402	27284	Economy	12700.00
0005434150152	4739	Business	40900.00
0005435840429	4739	Business	40900.00
0005432461437	4739	Business	40900.00
0005432461438	4739	Business	40900.00
0005434150178	4739	Business	40900.00
0005435840492	4739	Business	40900.00
0005435840518	4739	Business	40900.00
0005434559195	4739	Business	40900.00
0005434150161	4739	Economy	15000.00
0005435840446	4739	Economy	13600.00
0005435840523	4739	Economy	13600.00
0005434150151	4739	Economy	13600.00
0005435840475	4739	Economy	13600.00
0005434150150	4739	Economy	13600.00
0005434150169	4739	Economy	13600.00
0005435840439	4739	Economy	13600.00
0005435840476	4739	Economy	13600.00
0005435840517	4739	Economy	13600.00
0005435840501	4739	Economy	13600.00
0005434559194	4739	Economy	13600.00
0005434150144	4739	Economy	13600.00
0005434150142	4739	Economy	13600.00
0005432569425	4739	Economy	13600.00
0005434150160	4739	Economy	13600.00
0005435840390	4739	Economy	13600.00
0005434150146	4739	Economy	13600.00
0005434559193	4739	Economy	13600.00
0005432461441	4739	Economy	13600.00
0005435840453	4739	Economy	13600.00
0005435840465	4739	Economy	13600.00
0005432569426	4739	Economy	13600.00
0005432569424	4739	Economy	13600.00
0005435840500	4739	Economy	13600.00
0005435840474	4739	Economy	13600.00
0005435840417	4739	Economy	13600.00
0005435840522	4739	Economy	13600.00
0005432461440	4739	Economy	13600.00
0005435840524	4739	Economy	13600.00
0005432461439	4739	Economy	13600.00
0005435840428	4739	Economy	13600.00
0005432569427	4739	Economy	13600.00
0005435840534	30566	Business	40900.00
0005434082442	30566	Business	40900.00
0005432461371	30566	Business	40900.00
0005432569274	30566	Business	40900.00
0005432461146	30566	Business	40900.00
0005432569194	30566	Business	40900.00
0005432571422	30566	Business	40900.00
0005432569314	30566	Business	40900.00
0005434559120	30566	Business	40900.00
0005432461147	30566	Business	40900.00
0005434559113	30566	Business	40900.00
0005432569292	30566	Business	40900.00
0005433726147	30566	Business	40900.00
0005434082445	30566	Business	40900.00
0005432461337	30566	Business	40900.00
0005433726153	30566	Business	40900.00
0005432460967	30566	Economy	15000.00
0005434082474	30566	Economy	15000.00
0005432461016	30566	Economy	15000.00
0005434559151	30566	Economy	15000.00
0005432571427	30566	Economy	13600.00
0005434559133	30566	Economy	13600.00
0005432569322	30566	Economy	13600.00
0005432461179	30566	Economy	13600.00
0005433454925	30566	Economy	13600.00
0005433726156	30566	Economy	13600.00
0005432569348	30566	Economy	13600.00
0005434082621	30566	Economy	13600.00
0005434082486	30566	Economy	13600.00
0005433726133	30566	Economy	13600.00
0005434559132	30566	Economy	13600.00
0005433726158	30566	Economy	13600.00
0005433726139	30566	Economy	13600.00
0005434082469	30566	Economy	13600.00
0005432569075	30566	Economy	13600.00
0005434082444	30566	Economy	13600.00
0005432461183	30566	Economy	13600.00
0005432461285	30566	Economy	13600.00
0005432569291	30566	Economy	13600.00
0005434150237	30566	Economy	13600.00
0005432571420	30566	Economy	13600.00
0005432461275	30566	Economy	13600.00
0005434082551	30566	Economy	13600.00
0005434082489	30566	Economy	13600.00
0005432569225	30566	Economy	13600.00
0005432569329	30566	Economy	13600.00
0005432569284	30566	Economy	13600.00
0005432569368	30566	Economy	13600.00
0005433726140	30566	Economy	13600.00
0005432569342	30566	Economy	13600.00
0005433726157	30566	Economy	13600.00
0005433726148	30566	Economy	13600.00
0005434082453	30566	Economy	13600.00
0005432569264	30566	Economy	13600.00
0005433726146	30566	Economy	13600.00
0005432569167	30566	Economy	13600.00
0005432461185	30566	Economy	13600.00
0005434082584	30566	Economy	13600.00
0005434082519	30566	Economy	13600.00
0005433726145	30566	Economy	13600.00
0005434559150	30566	Economy	13600.00
0005434082622	30566	Economy	13600.00
0005432569211	30566	Economy	13600.00
0005432461213	30566	Economy	13600.00
0005432569224	30566	Economy	13600.00
0005434082563	30566	Economy	13600.00
0005432461170	30566	Economy	13600.00
0005432571423	30566	Economy	13600.00
0005433726141	30566	Economy	13600.00
0005432569347	30566	Economy	13600.00
0005434082543	30566	Economy	13600.00
0005434082532	30566	Economy	13600.00
0005432461342	30566	Economy	13600.00
0005434559134	30566	Economy	13600.00
0005432461317	30566	Economy	13600.00
0005432571421	30566	Economy	13600.00
0005432461177	30566	Economy	13600.00
0005434082525	30566	Economy	13600.00
0005433454926	30566	Economy	13600.00
0005432571424	30566	Economy	13600.00
0005434082576	30566	Economy	13600.00
0005432569188	30566	Economy	13600.00
0005432569263	30566	Economy	13600.00
0005433726154	30566	Economy	13600.00
0005434559145	30566	Economy	13600.00
0005434082485	30566	Economy	13600.00
0005434082475	30566	Economy	13600.00
0005434559121	30566	Economy	13600.00
0005432569176	30566	Economy	13600.00
0005434082526	30566	Economy	15000.00
0005433726132	30566	Economy	13600.00
0005434082490	30566	Economy	13600.00
0005434082432	30566	Economy	15000.00
0005432569105	30566	Economy	15000.00
0005432461178	30566	Economy	13600.00
0005433726137	30566	Economy	13600.00
0005432569177	30566	Economy	13600.00
0005432569281	30566	Economy	13600.00
0005434082520	30566	Economy	13600.00
0005432569372	30566	Economy	13600.00
0005432461015	30566	Economy	13600.00
0005434559116	30566	Economy	13600.00
0005434559146	30566	Economy	13600.00
0005434082592	30566	Economy	13600.00
0005432569349	30566	Economy	13600.00
0005432461228	30566	Economy	13600.00
0005432461353	30566	Economy	13600.00
0005434082450	30566	Economy	13600.00
0005432569330	30566	Economy	13600.00
0005433454931	30566	Economy	13600.00
0005433726159	30566	Economy	13600.00
0005432461276	30566	Economy	13600.00
0005432569220	30566	Economy	13600.00
0005432461052	30566	Economy	13600.00
0005432569320	30566	Economy	13600.00
0005432569221	30566	Economy	13600.00
0005434082552	30566	Economy	13600.00
0005432461372	30566	Economy	13600.00
0005432569306	30566	Economy	13600.00
0005434082591	30566	Economy	13600.00
0005432461318	30566	Economy	13600.00
0005432461243	30566	Economy	13600.00
0005432213710	30566	Economy	13600.00
0005432461338	30566	Economy	13600.00
0005433726160	30566	Economy	13600.00
0005434559131	30566	Economy	13600.00
0005432213711	30566	Economy	13600.00
0005434082550	30566	Economy	13600.00
0005432569212	30566	Economy	13600.00
0005433726142	30566	Economy	13600.00
0005433726149	30566	Economy	13600.00
0005434559125	30566	Economy	13600.00
0005434082539	30566	Economy	13600.00
0005433452781	30566	Economy	13600.00
0005433726152	30566	Economy	13600.00
0005434082431	30566	Economy	13600.00
0005432461051	30566	Economy	13600.00
0005432569370	30566	Economy	13600.00
0005433726134	30566	Economy	13600.00
0005434150238	30566	Economy	13600.00
0005432461194	30566	Economy	13600.00
0005433726155	30566	Economy	13600.00
0005433726131	30566	Economy	13600.00
0005434082298	30566	Economy	13600.00
0005432461245	30566	Economy	13600.00
0005434559148	30566	Economy	13600.00
0005432569369	30566	Economy	13600.00
0005432461212	30566	Economy	13600.00
0005432569285	30566	Economy	13600.00
0005434559149	30566	Economy	13600.00
0005434559135	30566	Economy	13600.00
0005435720165	21120	Economy	9900.00
0005435722113	21120	Economy	9900.00
0005435720159	21120	Economy	9900.00
0005435720160	21120	Economy	9900.00
0005435722112	21120	Economy	9900.00
0005435720161	21120	Economy	9900.00
0005435720164	21120	Economy	9900.00
0005435732730	22759	Economy	8800.00
0005435732726	22759	Economy	8800.00
0005435508725	11076	Business	23600.00
0005435508708	11076	Business	23600.00
0005435508707	11076	Business	23600.00
0005435380424	11076	Economy	7900.00
0005435508751	11076	Economy	7900.00
0005435530099	11076	Economy	7900.00
0005435508760	11076	Economy	7900.00
0005433346085	11076	Economy	7900.00
0005435530163	11076	Economy	7900.00
0005435545991	11076	Economy	7900.00
0005435380423	11076	Economy	7900.00
0005435530041	11076	Economy	7900.00
0005435508772	11076	Economy	7900.00
0005435530056	11076	Economy	8600.00
0005435508759	11076	Economy	7900.00
0005435508758	11076	Economy	7900.00
0005435530117	11076	Economy	7900.00
0005435530128	11076	Economy	7900.00
0005435508687	11076	Economy	7900.00
0005435508691	11076	Economy	7900.00
0005435508688	11076	Economy	7900.00
0005435508686	11076	Economy	7900.00
0005435508801	11076	Economy	7900.00
0005435530188	11076	Economy	7900.00
0005435530113	11076	Economy	7900.00
0005435508690	11076	Economy	7900.00
0005435380420	11076	Economy	7900.00
0005433346086	11076	Economy	7900.00
0005435508650	11076	Economy	7900.00
0005435530048	11076	Economy	7900.00
0005435508673	11076	Economy	7900.00
0005433346087	11076	Economy	7900.00
0005435380425	11076	Economy	7900.00
0005435530159	11076	Economy	7900.00
0005435508820	11076	Economy	7900.00
0005433345182	17098	Business	23600.00
0005433345725	17098	Business	23600.00
0005433345415	17098	Business	23600.00
0005433345704	17098	Business	23600.00
0005433345724	17098	Business	23600.00
0005433345202	17098	Business	23600.00
0005433345472	17098	Business	23600.00
0005435097471	17098	Business	23600.00
0005433345416	17098	Economy	7900.00
0005433345742	17098	Economy	7900.00
0005433345896	17098	Economy	7900.00
0005433345781	17098	Economy	7900.00
0005433345823	17098	Economy	7900.00
0005433345571	17098	Economy	7900.00
0005433345733	17098	Economy	7900.00
0005433345661	17098	Economy	7900.00
0005433345836	17098	Economy	7900.00
0005433345751	17098	Economy	7900.00
0005435097458	17098	Economy	7900.00
0005433345858	17098	Economy	7900.00
0005433345790	17098	Economy	7900.00
0005433345937	17098	Economy	7900.00
0005433345723	17098	Economy	7900.00
0005433345876	17098	Economy	7900.00
0005433345771	17098	Economy	7900.00
0005433345662	17098	Economy	7900.00
0005433345732	17098	Economy	7900.00
0005433345515	17098	Economy	7900.00
0005433345830	17098	Economy	7900.00
0005433345649	17098	Economy	8600.00
0005433345481	17098	Economy	8600.00
0005433345702	17098	Economy	8600.00
0005433345475	17098	Economy	7900.00
0005433345875	17098	Economy	7900.00
0005435097460	17098	Economy	7900.00
0005433345449	17098	Economy	7900.00
0005433345899	17098	Economy	7900.00
0005433345328	17098	Economy	7900.00
0005433345720	17098	Economy	7900.00
0005435097472	17098	Economy	7900.00
0005433345857	17098	Economy	7900.00
0005435097433	17098	Economy	7900.00
0005433345625	17098	Economy	7900.00
0005433345423	17098	Economy	7900.00
0005433345605	17098	Economy	7900.00
0005433345602	17098	Economy	7900.00
0005433345474	17098	Economy	7900.00
0005435097455	17098	Economy	7900.00
0005433345829	17098	Economy	7900.00
0005433345740	17098	Economy	7900.00
0005433345741	17098	Economy	7900.00
0005433345938	17098	Economy	7900.00
0005433345900	17098	Economy	7900.00
0005433345487	17098	Economy	7900.00
0005433345681	17098	Economy	7900.00
0005433345201	17098	Economy	7900.00
0005433345703	17098	Economy	7900.00
0005433345358	17098	Economy	7900.00
0005433345784	17098	Economy	7900.00
0005435097459	17098	Economy	7900.00
0005433345473	17098	Economy	7900.00
0005433345847	17098	Economy	7900.00
0005433345659	17098	Economy	7900.00
0005433345603	17098	Economy	7900.00
0005433345461	17098	Economy	7900.00
0005433345397	17098	Economy	7900.00
0005433345056	17098	Economy	7900.00
0005433345584	17098	Economy	7900.00
0005433345513	17098	Economy	7900.00
0005433345772	17098	Economy	7900.00
0005433345913	17098	Economy	7900.00
0005435097473	17098	Economy	7900.00
0005433345587	17098	Economy	7900.00
0005433345679	17098	Economy	7900.00
0005433345779	17098	Economy	7900.00
0005433345856	17098	Economy	7900.00
0005433345762	17098	Economy	7900.00
0005433345682	17098	Economy	7900.00
0005433345476	17098	Economy	7900.00
0005433345660	17098	Economy	7900.00
0005433345488	17098	Economy	7900.00
0005433345677	17098	Economy	7900.00
0005433345543	17098	Economy	7900.00
0005432920425	9083	Business	26600.00
0005432920381	9083	Business	26600.00
0005432920430	9083	Business	26600.00
0005432920314	9083	Business	26600.00
0005432920424	9083	Economy	8900.00
0005432920376	9083	Economy	8900.00
0005432920423	9083	Economy	8900.00
0005432920380	9083	Economy	8900.00
0005432920313	9083	Economy	8900.00
0005434159038	9083	Economy	8900.00
0005432920442	9083	Economy	8900.00
0005432920427	9083	Economy	8900.00
0005432920357	9083	Economy	8900.00
0005434159024	9083	Economy	8900.00
0005432920382	9083	Economy	8900.00
0005434159053	9083	Economy	8900.00
0005433477294	9083	Economy	8900.00
0005433477296	9083	Economy	8900.00
0005432920358	9083	Economy	8900.00
0005432920406	9083	Economy	8900.00
0005432920377	9083	Economy	8900.00
0005434159052	9083	Economy	8900.00
0005434159039	9083	Economy	8900.00
0005432920408	9083	Economy	8900.00
0005432920444	9083	Economy	8900.00
0005432920422	9083	Economy	8900.00
0005433477295	9083	Economy	8900.00
0005433477209	20470	Business	26600.00
0005433507688	20470	Business	26600.00
0005433477153	20470	Business	26600.00
0005433477158	20470	Business	26600.00
0005433477250	20470	Business	26600.00
0005433477125	20470	Economy	8900.00
0005433481348	20470	Economy	8900.00
0005433507711	20470	Economy	8900.00
0005433477180	20470	Economy	8900.00
0005433477232	20470	Economy	9800.00
0005433507649	20470	Economy	9800.00
0005433477121	20470	Economy	9800.00
0005433477088	20470	Economy	8900.00
0005433507651	20470	Economy	8900.00
0005433477139	20470	Economy	8900.00
0005433477219	20470	Economy	8900.00
0005433507653	20470	Economy	8900.00
0005433481353	20470	Economy	8900.00
0005433477118	20470	Economy	8900.00
0005433507679	20470	Economy	8900.00
0005433477281	20470	Economy	8900.00
0005433477089	20470	Economy	8900.00
0005433477248	20470	Economy	8900.00
0005433507690	20470	Economy	8900.00
0005433507648	20470	Economy	8900.00
0005433477280	20470	Economy	8900.00
0005433507706	20470	Economy	8900.00
0005433481383	20470	Economy	8900.00
0005433477231	20470	Economy	8900.00
0005433477140	20470	Economy	8900.00
0005433507699	20470	Economy	8900.00
0005433477282	20470	Economy	8900.00
0005433477119	20470	Economy	8900.00
0005433477181	20470	Economy	8900.00
0005433477256	20470	Economy	8900.00
0005433477152	20470	Economy	8900.00
0005433507646	20470	Economy	8900.00
0005433507685	20470	Economy	8900.00
0005433507687	20470	Economy	8900.00
0005433481349	20470	Economy	8900.00
0005433477192	20470	Economy	8900.00
0005433481382	20470	Economy	8900.00
0005433477151	20470	Economy	8900.00
0005433507712	20470	Economy	8900.00
0005433507647	20470	Economy	8900.00
0005433477144	20470	Economy	8900.00
0005433477122	20470	Economy	8900.00
0005433507686	20470	Economy	8900.00
0005433507676	20470	Economy	8900.00
0005433507650	20470	Economy	8900.00
0005435179714	10141	Economy	5800.00
0005435179708	10141	Economy	5800.00
0005435179018	10141	Economy	5800.00
0005435179017	10141	Economy	5800.00
0005435179709	10141	Economy	5800.00
0005432396349	18279	Economy	5800.00
0005432396348	18279	Economy	5800.00
0005432400214	18279	Economy	5800.00
0005432400215	18279	Economy	5800.00
0005435554297	10994	Business	9500.00
0005435626572	10994	Business	9500.00
0005435127490	10994	Business	9500.00
0005435127446	10994	Business	9500.00
0005435127412	10994	Business	9500.00
0005435626531	10994	Business	9500.00
0005435127306	10994	Business	9500.00
0005435127407	10994	Economy	3200.00
0005435127510	10994	Economy	3200.00
0005435127442	10994	Economy	3200.00
0005435626604	10994	Economy	3200.00
0005435626619	10994	Economy	3200.00
0005435127332	10994	Economy	3200.00
0005435127422	10994	Economy	3200.00
0005435626532	10994	Economy	3200.00
0005435127550	10994	Economy	3500.00
0005435127334	10994	Economy	3500.00
0005435626613	10994	Economy	3200.00
0005435127406	10994	Economy	3200.00
0005435626643	10994	Economy	3200.00
0005435127548	10994	Economy	3200.00
0005435127563	10994	Economy	3200.00
0005435626628	10994	Economy	3200.00
0005435127149	10994	Economy	3200.00
0005435127363	10994	Economy	3200.00
0005435127353	10994	Economy	3200.00
0005435626612	10994	Economy	3200.00
0005435554320	10994	Economy	3200.00
0005435127562	10994	Economy	3200.00
0005435127444	10994	Economy	3200.00
0005435626614	10994	Economy	3200.00
0005435127415	10994	Economy	3200.00
0005435127477	10994	Economy	3200.00
0005435127413	10994	Economy	3200.00
0005435127414	10994	Economy	3200.00
0005435626605	10994	Economy	3200.00
0005435127340	10994	Economy	3200.00
0005435127445	10994	Economy	3200.00
0005435626616	10994	Economy	3200.00
0005435554296	10994	Economy	3200.00
0005435127441	10994	Economy	3200.00
0005435127316	10994	Economy	3200.00
0005435127191	10994	Economy	3200.00
0005435626629	10994	Economy	3200.00
0005435626646	10994	Economy	3200.00
0005435127416	10994	Economy	3200.00
0005435127401	10994	Economy	3200.00
0005435127335	10994	Economy	3200.00
0005435626571	10994	Economy	3200.00
0005435127476	10994	Economy	3200.00
0005435626648	10994	Economy	3200.00
0005435626533	10994	Economy	3200.00
0005435127362	10994	Economy	3200.00
0005435127396	10994	Economy	3200.00
0005435626645	10994	Economy	3200.00
0005435626615	10994	Economy	3200.00
0005435127352	10994	Economy	3200.00
0005435127178	10994	Economy	3200.00
0005435127549	10994	Economy	3200.00
0005435626650	10994	Economy	3200.00
0005435127367	10994	Economy	3200.00
0005435127475	10994	Economy	3200.00
0005435626651	10994	Economy	3200.00
0005435127511	10994	Economy	3200.00
0005435127333	10994	Economy	3200.00
0005434411875	14689	Business	9500.00
0005435626868	14689	Business	9500.00
0005435554329	14689	Economy	3200.00
0005434411876	14689	Economy	3200.00
0005434411890	14689	Economy	3200.00
0005435626870	14689	Economy	3200.00
0005435626869	14689	Economy	3200.00
0005435626871	14689	Economy	3200.00
0005435127588	14689	Economy	3200.00
0005435219251	7094	Business	86900.00
0005435221074	7094	Economy	29000.00
0005435221080	7094	Economy	29000.00
0005435443566	7094	Economy	29000.00
0005435179423	7094	Economy	29000.00
0005435443553	7094	Economy	29000.00
0005435443562	7094	Economy	29000.00
0005435443565	7094	Economy	29000.00
0005435179424	7094	Economy	29000.00
0005435221073	7094	Economy	29000.00
0005435219252	7094	Economy	29000.00
0005435443541	7094	Economy	29000.00
0005435219258	7094	Economy	29000.00
0005435715930	27092	Business	86900.00
0005432398302	27092	Business	86900.00
0005432398280	27092	Economy	29000.00
0005435715903	27092	Economy	31900.00
0005435715931	27092	Economy	29000.00
0005435715914	27092	Economy	29000.00
0005435715913	27092	Economy	29000.00
0005435715869	27092	Economy	29000.00
0005435715878	27092	Economy	29000.00
0005435715901	27092	Economy	29000.00
0005432398291	27092	Economy	29000.00
0005432398303	27092	Economy	29000.00
0005432398293	27092	Economy	29000.00
0005432398290	27092	Economy	29000.00
0005435715879	27092	Economy	29000.00
0005433060482	2719	Economy	7700.00
0005433060481	2719	Economy	7700.00
0005434085064	2719	Economy	7700.00
0005434085065	2719	Economy	7700.00
0005433060483	2719	Economy	7700.00
0005434085058	28490	Economy	7700.00
0005435541534	11371	Business	20200.00
0005435541577	11371	Business	20200.00
0005435541535	11371	Economy	6700.00
0005435541564	11371	Economy	6700.00
0005435541494	11371	Economy	6700.00
0005435518362	11371	Economy	7400.00
0005435518340	11371	Economy	6700.00
0005435518341	11371	Economy	6700.00
0005435541631	11371	Economy	6700.00
0005435541543	11371	Economy	6700.00
0005435541630	11371	Economy	6700.00
0005435518439	11371	Economy	6700.00
0005435518370	11371	Economy	6700.00
0005435541478	11371	Economy	6700.00
0005435518371	11371	Economy	6700.00
0005435518406	11371	Economy	6700.00
0005435541525	11371	Economy	6700.00
0005435518372	11371	Economy	6700.00
0005435518375	11371	Economy	6700.00
0005435541479	11371	Economy	6700.00
0005435518365	11371	Economy	6700.00
0005435541650	22216	Business	20200.00
0005435541651	22216	Economy	7400.00
0005435541647	22216	Economy	6700.00
0005435541649	22216	Economy	6700.00
0005435541652	22216	Economy	6700.00
0005435541648	22216	Economy	6700.00
0005433252300	2309	Business	20200.00
0005433252349	2309	Business	20200.00
0005433252318	2309	Economy	6700.00
0005433252340	2309	Economy	7400.00
0005433252311	2309	Economy	7400.00
0005433252359	2309	Economy	6700.00
0005433252358	2309	Economy	6700.00
0005433252265	2309	Economy	6700.00
0005433252316	2309	Economy	6700.00
0005433252317	2309	Economy	6700.00
0005433252267	2309	Economy	6700.00
0005433252284	2309	Economy	6700.00
0005433252329	2309	Economy	6700.00
0005433252337	2309	Economy	6700.00
0005434908900	2309	Economy	6700.00
0005433252326	2309	Economy	6700.00
0005433252348	2309	Economy	6700.00
0005433252266	2309	Economy	6700.00
0005433252245	2309	Economy	6700.00
0005433252234	2309	Economy	6700.00
0005433401070	2309	Economy	6700.00
0005433252346	2309	Economy	6700.00
0005433252270	2309	Economy	6700.00
0005434908901	2309	Economy	6700.00
0005433252301	2309	Economy	6700.00
0005433252302	2309	Economy	6700.00
0005433252181	2309	Economy	6700.00
0005433252212	2309	Economy	6700.00
0005433252345	2309	Economy	6700.00
0005434908476	25596	Business	20200.00
0005435787467	25596	Business	20200.00
0005434908636	25596	Business	20200.00
0005434908580	25596	Business	20200.00
0005434908562	25596	Business	20200.00
0005434908689	25596	Business	20200.00
0005434908680	25596	Economy	6700.00
0005434908741	25596	Economy	6700.00
0005434908727	25596	Economy	6700.00
0005434908578	25596	Economy	6700.00
0005434908722	25596	Economy	6700.00
0005434908794	25596	Economy	6700.00
0005434908764	25596	Economy	6700.00
0005434908662	25596	Economy	7400.00
0005434908593	25596	Economy	7400.00
0005434908524	25596	Economy	7400.00
0005435787466	25596	Economy	7400.00
0005434908576	25596	Economy	6700.00
0005434908681	25596	Economy	6700.00
0005434908688	25596	Economy	6700.00
0005434908491	25596	Economy	6700.00
0005434908725	25596	Economy	6700.00
0005434908637	25596	Economy	6700.00
0005434908665	25596	Economy	6700.00
0005434908451	25596	Economy	6700.00
0005434908609	25596	Economy	6700.00
0005434908525	25596	Economy	6700.00
0005434908557	25596	Economy	6700.00
0005434908326	25596	Economy	6700.00
0005434908602	25596	Economy	6700.00
0005434908698	25596	Economy	6700.00
0005434908650	25596	Economy	6700.00
0005434908666	25596	Economy	6700.00
0005434908579	25596	Economy	6700.00
0005434908420	25596	Economy	6700.00
0005433252387	25596	Economy	6700.00
0005434908721	25596	Economy	6700.00
0005434908726	25596	Economy	6700.00
0005434908795	25596	Economy	6700.00
0005434908618	25596	Economy	6700.00
0005434908561	25596	Economy	6700.00
0005434908475	25596	Economy	6700.00
0005434908634	25596	Economy	6700.00
0005433252386	25596	Economy	6700.00
0005434908438	25596	Economy	6700.00
0005434908845	25596	Economy	6700.00
0005434908449	25596	Economy	6700.00
0005435787465	25596	Economy	6700.00
0005434908846	25596	Economy	6700.00
0005434908625	25596	Economy	6700.00
0005434908740	25596	Economy	6700.00
0005434908592	25596	Economy	6700.00
0005434908421	25596	Economy	6700.00
0005434908617	25596	Economy	6700.00
0005434908327	25596	Economy	6700.00
0005434908490	25596	Economy	6700.00
0005434908577	25596	Economy	6700.00
0005434908461	25596	Economy	6700.00
0005434908654	25596	Economy	6700.00
0005434908575	25596	Economy	6700.00
0005434908691	25596	Economy	6700.00
0005434908319	25596	Economy	6700.00
0005434908482	25596	Economy	6700.00
0005434908443	25596	Economy	6700.00
0005434908439	25596	Economy	6700.00
0005434908663	25596	Economy	6700.00
0005432621370	28053	Economy	13600.00
0005432621413	28053	Economy	13600.00
0005432621434	28053	Economy	12400.00
0005432621368	28053	Economy	12400.00
0005432621400	28053	Economy	12400.00
0005432621371	28053	Economy	12400.00
0005432621348	28053	Economy	12400.00
0005432621401	28053	Economy	12400.00
0005432621391	28053	Economy	12400.00
0005432621433	28053	Economy	12400.00
0005432621369	28053	Economy	12400.00
0005432621411	28053	Economy	12400.00
0005434097501	11772	Economy	11300.00
0005434097502	11772	Economy	11300.00
0005434097505	11772	Economy	11300.00
0005434097504	11772	Economy	11300.00
0005433454925	31362	Economy	8400.00
0005433452781	31362	Economy	8400.00
0005433454926	31362	Economy	8400.00
0005433454931	31362	Economy	8400.00
0005434184713	12000	Economy	6600.00
0005433134255	12000	Economy	6600.00
0005433129399	12000	Economy	6600.00
0005434184715	12000	Economy	6600.00
0005434142715	12000	Economy	6600.00
0005433134249	12000	Economy	6600.00
0005434184714	12000	Economy	6600.00
0005434184707	12000	Economy	6600.00
0005434142716	12000	Economy	6600.00
0005433134256	12000	Economy	6600.00
0005433134246	12000	Economy	6600.00
0005433134245	12000	Economy	6600.00
0005434326289	29835	Economy	6600.00
0005435935129	16448	Economy	18100.00
0005435935134	16448	Economy	18100.00
0005435933562	16448	Economy	18100.00
0005435933561	16448	Economy	18100.00
0005435933563	16448	Economy	18100.00
0005435935128	16448	Economy	18100.00
0005435698179	16448	Economy	18100.00
0005435698039	24687	Economy	19900.00
0005435697934	24687	Economy	19900.00
0005435697973	24687	Economy	19900.00
0005435698118	24687	Economy	19900.00
0005435698062	24687	Economy	18100.00
0005435698071	24687	Economy	18100.00
0005435698054	24687	Economy	18100.00
0005435698112	24687	Economy	18100.00
0005435698037	24687	Economy	18100.00
0005435698003	24687	Economy	18100.00
0005435698010	24687	Economy	18100.00
0005435698012	24687	Economy	18100.00
0005435697933	24687	Economy	18100.00
0005435698097	24687	Economy	18100.00
0005435698009	24687	Economy	18100.00
0005435698110	24687	Economy	18100.00
0005435698004	24687	Economy	18100.00
0005435698096	24687	Economy	18100.00
0005435698119	24687	Economy	18100.00
0005435698080	24687	Economy	18100.00
0005435698058	24687	Economy	18100.00
0005435698099	24687	Economy	18100.00
0005435698072	24687	Economy	18100.00
0005435698120	24687	Economy	18100.00
0005435698063	24687	Economy	18100.00
0005435698142	24687	Economy	18100.00
0005435697972	24687	Economy	18100.00
0005435698141	24687	Economy	18100.00
0005435698111	24687	Economy	18100.00
0005435698137	24687	Economy	18100.00
0005432968899	18792	Economy	4400.00
0005432968898	18792	Economy	4400.00
0005433724933	21609	Economy	4400.00
0005433724907	21609	Economy	4400.00
0005433724934	21609	Economy	4400.00
0005434140163	28547	Business	23100.00
0005434140214	28547	Business	23100.00
0005434140243	28547	Business	23100.00
0005434140125	28547	Business	23100.00
0005434140038	28547	Business	23100.00
0005434140351	28547	Business	23100.00
0005434140126	28547	Business	23100.00
0005434140155	28547	Business	23100.00
0005434140006	28547	Business	23100.00
0005434140156	28547	Business	23100.00
0005434140124	28547	Business	23100.00
0005434087636	28547	Economy	7700.00
0005434139959	28547	Economy	7700.00
0005434140294	28547	Economy	7700.00
0005434140267	28547	Economy	7700.00
0005434140332	28547	Economy	7700.00
0005434140220	28547	Economy	7700.00
0005434140266	28547	Economy	7700.00
0005434140435	28547	Economy	7700.00
0005434140070	28547	Economy	7700.00
0005434140273	28547	Economy	7700.00
0005434140231	28547	Economy	8500.00
0005434140203	28547	Economy	8500.00
0005434140192	28547	Economy	8500.00
0005434140257	28547	Economy	8500.00
0005434140387	28547	Economy	7700.00
0005434139970	28547	Economy	7700.00
0005434140083	28547	Economy	7700.00
0005434087645	28547	Economy	7700.00
0005434140245	28547	Economy	7700.00
0005434140272	28547	Economy	7700.00
0005434140268	28547	Economy	7700.00
0005434140354	28547	Economy	7700.00
0005434140331	28547	Economy	7700.00
0005434140394	28547	Economy	7700.00
0005434140488	28547	Economy	7700.00
0005434139874	28547	Economy	7700.00
0005434140101	28547	Economy	7700.00
0005434140105	28547	Economy	7700.00
0005434139994	28547	Economy	7700.00
0005434140348	28547	Economy	7700.00
0005434140115	28547	Economy	7700.00
0005434087646	28547	Economy	7700.00
0005434140007	28547	Economy	7700.00
0005434140248	28547	Economy	7700.00
0005434140119	28547	Economy	7700.00
0005434140162	28547	Economy	7700.00
0005434139880	28547	Economy	7700.00
0005434140434	28547	Economy	7700.00
0005434140191	28547	Economy	7700.00
0005434140278	28547	Economy	7700.00
0005434140195	28547	Economy	7700.00
0005434140417	28547	Economy	7700.00
0005434140395	28547	Economy	7700.00
0005434140102	28547	Economy	7700.00
0005434140309	28547	Economy	7700.00
0005434140412	28547	Economy	7700.00
0005434140174	28547	Economy	7700.00
0005434140205	28547	Economy	7700.00
0005434140036	28547	Economy	7700.00
0005434140236	28547	Economy	7700.00
0005434140194	28547	Economy	7700.00
0005434140204	28547	Economy	7700.00
0005434139702	28547	Economy	7700.00
0005434139881	28547	Economy	7700.00
0005434140314	28547	Economy	7700.00
0005434140430	28547	Economy	7700.00
0005434140293	28547	Economy	7700.00
0005434139996	28547	Economy	7700.00
0005434140237	28547	Economy	7700.00
0005434140127	28547	Economy	7700.00
0005434140352	28547	Economy	7700.00
0005434140500	28547	Economy	7700.00
0005434140230	28547	Economy	7700.00
0005434140069	28547	Economy	7700.00
0005434140096	28547	Economy	7700.00
0005434140117	28547	Economy	7700.00
0005434140037	28547	Economy	7700.00
0005434140023	28547	Economy	7700.00
0005434140469	28547	Economy	7700.00
0005434140265	28547	Economy	7700.00
0005434140103	28547	Economy	7700.00
0005434140143	28547	Economy	7700.00
0005434140042	28547	Economy	7700.00
0005434140224	28547	Economy	7700.00
0005434139971	28547	Economy	7700.00
0005434140349	28547	Economy	7700.00
0005434087635	28547	Economy	7700.00
0005434139934	28547	Economy	7700.00
0005434140271	28547	Economy	7700.00
0005434140246	28547	Economy	7700.00
0005434140355	28547	Economy	7700.00
0005433407697	1897	Economy	21700.00
0005433407685	1897	Economy	21700.00
0005433407702	1897	Economy	21700.00
0005433407683	1897	Economy	21700.00
0005433407684	1897	Economy	21700.00
0005434610331	23072	Economy	21700.00
0005434610318	23072	Economy	21700.00
0005434610317	23072	Economy	21700.00
0005434505174	16707	Economy	7600.00
0005434505110	16707	Economy	7600.00
0005434504960	16707	Economy	7600.00
0005434505105	16707	Economy	6900.00
0005434505168	16707	Economy	6900.00
0005434505240	16707	Economy	6900.00
0005434504974	16707	Economy	6900.00
0005434505157	16707	Economy	6900.00
0005434505175	16707	Economy	6900.00
0005434505139	16707	Economy	6900.00
0005434505125	16707	Economy	6900.00
0005434505126	16707	Economy	6900.00
0005434505219	16707	Economy	6900.00
0005434505176	16707	Economy	6900.00
0005434504975	16707	Economy	6900.00
0005434505138	16707	Economy	6900.00
0005434505218	16707	Economy	6900.00
0005434505241	16707	Economy	6900.00
0005434505015	16707	Economy	6900.00
0005434505104	16707	Economy	6900.00
0005434505098	16707	Economy	6900.00
0005434505106	16707	Economy	6900.00
0005434505156	16707	Economy	6900.00
0005434505128	16707	Economy	6900.00
0005434505019	16707	Economy	6900.00
0005434505016	16707	Economy	6900.00
0005434504963	16707	Economy	6900.00
0005434505068	16707	Economy	6900.00
0005434505096	16707	Economy	6900.00
0005434505108	16707	Economy	6900.00
0005434505273	16707	Economy	6900.00
0005434505181	16707	Economy	6900.00
0005434505020	16707	Economy	6900.00
0005434505107	16707	Economy	6900.00
0005434505170	16707	Economy	6900.00
0005434505319	22888	Economy	6900.00
0005433266960	2176	Economy	7700.00
0005433266980	2176	Economy	7700.00
0005433266964	2176	Economy	7000.00
0005433266963	2176	Economy	7000.00
0005433266959	2176	Economy	7000.00
0005433266935	2176	Economy	7000.00
0005433266958	2176	Economy	7000.00
0005433266936	2176	Economy	7000.00
0005433266965	2176	Economy	7000.00
0005433266973	2176	Economy	7000.00
0005433266966	2176	Economy	7000.00
0005435078731	24333	Economy	7700.00
0005435078722	24333	Economy	7700.00
0005435078743	24333	Economy	7000.00
0005435078753	24333	Economy	7000.00
0005435078763	24333	Economy	7000.00
0005435078723	24333	Economy	7000.00
0005435078742	24333	Economy	7000.00
0005435078694	24333	Economy	7000.00
0005435078755	24333	Economy	7000.00
0005435078754	24333	Economy	7000.00
0005435078737	24333	Economy	7000.00
0005435078748	24333	Economy	7000.00
0005435078697	24333	Economy	7000.00
0005435078736	24333	Economy	7000.00
0005435078724	24333	Economy	7000.00
0005435078686	24333	Economy	7000.00
0005434989133	6638	Economy	9800.00
0005434989134	6638	Economy	9800.00
0005434989010	23644	Economy	10800.00
0005434989005	23644	Economy	9800.00
0005435803347	23644	Economy	9800.00
0005434989000	23644	Economy	9800.00
0005434988974	23644	Economy	9800.00
0005434989002	23644	Economy	9800.00
0005434989031	23644	Economy	9800.00
0005435803348	23644	Economy	9800.00
0005434989007	23644	Economy	9800.00
0005434988990	23644	Economy	9800.00
0005434989016	23644	Economy	9800.00
0005434989003	23644	Economy	9800.00
0005434989004	23644	Economy	9800.00
0005434988960	23644	Economy	9800.00
0005434989030	23644	Economy	9800.00
0005434988991	23644	Economy	9800.00
0005434989021	23644	Economy	9800.00
0005434989027	23644	Economy	9800.00
0005434989028	23644	Economy	9800.00
0005434989011	23644	Economy	9800.00
0005434988988	23644	Economy	9800.00
0005434989001	23644	Economy	9800.00
0005432384260	31337	Business	9900.00
0005432384065	31337	Business	9900.00
0005432384011	31337	Business	9900.00
0005433450530	31337	Business	9900.00
0005432384049	31337	Business	9900.00
0005432384136	31337	Business	9900.00
0005433453819	31337	Business	9900.00
0005433450540	31337	Economy	3300.00
0005432384043	31337	Economy	3300.00
0005433450427	31337	Economy	3300.00
0005433450556	31337	Economy	3300.00
0005433450554	31337	Economy	3300.00
0005432384012	31337	Economy	3300.00
0005432384275	31337	Economy	3300.00
0005432384084	31337	Economy	3600.00
0005432384219	31337	Economy	3600.00
0005433450586	31337	Economy	3600.00
0005432384261	31337	Economy	3600.00
0005433450509	31337	Economy	3600.00
0005432384162	31337	Economy	3300.00
0005432384175	31337	Economy	3300.00
0005432384224	31337	Economy	3300.00
0005433453804	31337	Economy	3300.00
0005432384091	31337	Economy	3300.00
0005432384207	31337	Economy	3300.00
0005432383975	31337	Economy	3300.00
0005433450594	31337	Economy	3300.00
0005433450453	31337	Economy	3300.00
0005433450462	31337	Economy	3300.00
0005432384139	31337	Economy	3300.00
0005432384256	31337	Economy	3300.00
0005432384045	31337	Economy	3300.00
0005432384163	31337	Economy	3300.00
0005432384074	31337	Economy	3300.00
0005433450529	31337	Economy	3300.00
0005433450524	31337	Economy	3300.00
0005432384116	31337	Economy	3300.00
0005432384158	31337	Economy	3300.00
0005433451669	31337	Economy	3300.00
0005432384190	31337	Economy	3300.00
0005432384206	31337	Economy	3300.00
0005432384174	31337	Economy	3300.00
0005432384166	31337	Economy	3300.00
0005432384232	31337	Economy	3300.00
0005432384173	31337	Economy	3300.00
0005432384086	31337	Economy	3300.00
0005432384044	31337	Economy	3300.00
0005432384102	31337	Economy	3300.00
0005432384075	31337	Economy	3300.00
0005432384129	31337	Economy	3300.00
0005432384101	31337	Economy	3300.00
0005432384147	31337	Economy	3300.00
0005433450555	31337	Economy	3300.00
0005432384093	31337	Economy	3300.00
0005432383866	31337	Economy	3300.00
0005432384085	31337	Economy	3300.00
0005433450512	31337	Economy	3300.00
0005432384124	31337	Economy	3300.00
0005432384092	31337	Economy	3300.00
0005433450537	31337	Economy	3300.00
0005432384123	31337	Economy	3300.00
0005432384159	31337	Economy	3300.00
0005432384223	31337	Economy	3300.00
0005432384122	31337	Economy	3300.00
0005432384097	31337	Economy	3300.00
0005433450513	31337	Economy	3300.00
0005432384066	31337	Economy	3300.00
0005432384274	31337	Economy	3300.00
0005433788335	20832	Economy	26200.00
0005435548583	20832	Economy	26200.00
0005435548581	20832	Economy	26200.00
0005435548593	20832	Economy	23800.00
0005433788334	20832	Economy	23800.00
0005433788333	20832	Economy	23800.00
0005435548603	20832	Economy	23800.00
0005435548577	20832	Economy	23800.00
0005433788331	20832	Economy	23800.00
0005433788332	20832	Economy	23800.00
0005435548600	20832	Economy	23800.00
0005435548611	20832	Economy	23800.00
0005435548589	20832	Economy	23800.00
0005435548595	20832	Economy	23800.00
0005435548576	20832	Economy	23800.00
0005435548591	20832	Economy	23800.00
0005435548580	20832	Economy	23800.00
0005435548586	20832	Economy	23800.00
0005435548588	20832	Economy	23800.00
0005435548601	20832	Economy	23800.00
0005435548608	20832	Economy	23800.00
0005435548604	20832	Economy	23800.00
0005435548592	20832	Economy	23800.00
0005435548584	20832	Economy	23800.00
0005433788313	26467	Economy	26200.00
0005433788310	26467	Economy	23800.00
0005433788294	26467	Economy	23800.00
0005433788284	26467	Economy	23800.00
0005433788320	26467	Economy	23800.00
0005433788297	26467	Economy	23800.00
0005433788312	26467	Economy	23800.00
0005433788319	26467	Economy	23800.00
0005433788295	26467	Economy	23800.00
0005433788300	26467	Economy	23800.00
0005433788311	26467	Economy	23800.00
0005433788318	26467	Economy	23800.00
0005433131832	10769	Economy	17100.00
0005435304258	10769	Economy	17100.00
0005433131819	10769	Economy	15600.00
0005433126958	10769	Economy	15600.00
0005433126950	10769	Economy	15600.00
0005435299888	10769	Economy	15600.00
0005435304249	10769	Economy	15600.00
0005435299890	10769	Economy	15600.00
0005433126951	10769	Economy	15600.00
0005433131835	10769	Economy	15600.00
0005435299891	10769	Economy	15600.00
0005433131833	10769	Economy	15600.00
0005433126956	10769	Economy	15600.00
0005433126949	10769	Economy	15600.00
0005433110387	2390	Economy	15700.00
0005433110379	2390	Economy	15700.00
0005433110378	2390	Economy	15700.00
0005433110372	2390	Economy	15700.00
0005433110381	2390	Economy	15700.00
0005433110355	2390	Economy	15700.00
0005433110349	2390	Economy	15700.00
0005433110389	2390	Economy	15700.00
0005433110354	2390	Economy	15700.00
0005434287855	26857	Economy	17200.00
0005434287798	26857	Economy	15700.00
0005434287869	26857	Economy	15700.00
0005434287809	26857	Economy	15700.00
0005434287889	26857	Economy	15700.00
0005434287856	26857	Economy	15700.00
0005434287888	26857	Economy	15700.00
0005434287865	26857	Economy	15700.00
0005434287741	26857	Economy	15700.00
0005434287736	26857	Economy	15700.00
0005434287878	26857	Economy	15700.00
0005434287864	26857	Economy	15700.00
0005434287890	26857	Economy	15700.00
0005434287886	26857	Economy	15700.00
0005434287874	26857	Economy	15700.00
0005434287885	26857	Economy	15700.00
0005434287884	26857	Economy	15700.00
0005434287857	26857	Economy	15700.00
0005434287892	26857	Economy	15700.00
0005434287797	26857	Economy	15700.00
0005434287858	26857	Economy	15700.00
0005434287843	26857	Economy	15700.00
0005434287863	26857	Economy	15700.00
0005434287870	26857	Economy	15700.00
0005434287873	26857	Economy	15700.00
0005434287875	26857	Economy	15700.00
0005434269157	25494	Economy	25000.00
0005435854080	26644	Economy	25000.00
0005435856311	26644	Economy	22800.00
0005435856316	26644	Economy	22800.00
0005435856315	26644	Economy	22800.00
0005435856310	26644	Economy	22800.00
0005435856297	26644	Economy	22800.00
0005435856294	26644	Economy	22800.00
0005435856296	26644	Economy	22800.00
0005435314916	6109	Economy	24600.00
0005434520515	6109	Economy	24600.00
0005435314940	6109	Economy	22300.00
0005435314944	6109	Economy	22300.00
0005435314917	6109	Economy	22300.00
0005435314934	6109	Economy	22300.00
0005435314939	6109	Economy	22300.00
0005434520516	6109	Economy	22300.00
0005435314936	6109	Economy	22300.00
0005435314943	6109	Economy	22300.00
0005435314920	6109	Economy	22300.00
0005435314919	6109	Economy	22300.00
0005435314935	6109	Economy	22300.00
0005435314914	6109	Economy	22300.00
0005435314941	6109	Economy	22300.00
0005434520517	6109	Economy	22300.00
0005435314915	6109	Economy	22300.00
0005435314927	6109	Economy	22300.00
0005433651103	7161	Business	89800.00
0005433651109	7161	Business	89800.00
0005435263791	7161	Business	89800.00
0005433651101	7161	Business	89800.00
0005435263798	7161	Business	89800.00
0005435263813	7161	Economy	29900.00
0005435263802	7161	Economy	29900.00
0005435263781	7161	Economy	29900.00
0005435263772	7161	Economy	29900.00
0005435263823	7161	Economy	32900.00
0005435263774	7161	Economy	29900.00
0005433651102	7161	Economy	29900.00
0005433651105	7161	Economy	29900.00
0005435263777	7161	Economy	29900.00
0005433651104	7161	Economy	29900.00
0005435263780	7161	Economy	29900.00
0005435263790	7161	Economy	29900.00
0005435263814	7161	Economy	29900.00
0005435263816	7161	Economy	29900.00
0005433651108	7161	Economy	29900.00
0005435263812	7161	Economy	29900.00
0005435263799	7161	Economy	29900.00
0005435263792	7161	Economy	29900.00
0005435263820	7161	Economy	29900.00
0005435263815	7161	Economy	29900.00
0005435263800	7161	Economy	29900.00
0005435263786	7161	Economy	29900.00
0005435263795	7161	Economy	29900.00
0005435263775	7161	Economy	29900.00
0005433651107	7161	Economy	29900.00
0005435263773	7161	Economy	29900.00
0005433651106	7161	Economy	29900.00
0005433651037	27631	Business	89800.00
0005433651016	27631	Business	89800.00
0005433651056	27631	Business	89800.00
0005433651096	27631	Business	89800.00
0005433651009	27631	Economy	29900.00
0005433651001	27631	Economy	29900.00
0005433651012	27631	Economy	29900.00
0005433650995	27631	Economy	29900.00
0005433651068	27631	Economy	29900.00
0005433651038	27631	Economy	32900.00
0005433651032	27631	Economy	32900.00
0005433651002	27631	Economy	32900.00
0005433651062	27631	Economy	32900.00
0005433651066	27631	Economy	29900.00
0005433651069	27631	Economy	29900.00
0005433651021	27631	Economy	29900.00
0005433650922	27631	Economy	29900.00
0005433651011	27631	Economy	29900.00
0005433651048	27631	Economy	29900.00
0005433650997	27631	Economy	29900.00
0005433651043	27631	Economy	29900.00
0005433651060	27631	Economy	29900.00
0005433651063	27631	Economy	29900.00
0005433651040	27631	Economy	29900.00
0005433651022	27631	Economy	29900.00
0005433651044	27631	Economy	29900.00
0005433651015	27631	Economy	29900.00
0005433651029	27631	Economy	29900.00
0005433651010	27631	Economy	29900.00
0005433650958	27631	Economy	29900.00
0005433650978	27631	Economy	29900.00
0005433651031	27631	Economy	29900.00
0005433651064	27631	Economy	29900.00
0005433650988	27631	Economy	29900.00
0005433651017	27631	Economy	29900.00
0005433650994	27631	Economy	29900.00
0005433651035	27631	Economy	29900.00
0005435263839	27631	Economy	29900.00
0005433651045	27631	Economy	29900.00
0005433650998	27631	Economy	29900.00
0005433651008	27631	Economy	29900.00
0005433651013	27631	Economy	29900.00
0005433650963	27631	Economy	29900.00
0005433650989	27631	Economy	29900.00
0005433650999	27631	Economy	29900.00
0005433651057	27631	Economy	29900.00
0005435263838	27631	Economy	29900.00
0005433651061	27631	Economy	29900.00
0005435860610	4779	Economy	19400.00
0005435860617	4779	Economy	17600.00
0005435860594	4779	Economy	17600.00
0005435860608	4779	Economy	17600.00
0005435860597	4779	Economy	17600.00
0005435860609	4779	Economy	17600.00
0005435860598	4779	Economy	17600.00
0005433869615	4779	Economy	17600.00
0005433869497	32580	Economy	19400.00
0005433869385	32580	Economy	19400.00
0005433869475	32580	Economy	19400.00
0005433869367	32580	Economy	19400.00
0005433869523	32580	Economy	17600.00
0005433869301	32580	Economy	17600.00
0005433869419	32580	Economy	17600.00
0005433869480	32580	Economy	17600.00
0005433869290	32580	Economy	17600.00
0005433869289	32580	Economy	17600.00
0005433869389	32580	Economy	17600.00
0005433869381	32580	Economy	17600.00
0005433869498	32580	Economy	17600.00
0005433869400	32580	Economy	17600.00
0005433869346	32580	Economy	17600.00
0005433869446	32580	Economy	17600.00
0005433869464	32580	Economy	17600.00
0005433869368	32580	Economy	17600.00
0005433869487	32580	Economy	17600.00
0005433869481	32580	Economy	17600.00
0005433869435	32580	Economy	17600.00
0005433869455	32580	Economy	17600.00
0005433869508	32580	Economy	17600.00
0005433869471	32580	Economy	17600.00
0005433869504	32580	Economy	17600.00
0005433869413	32580	Economy	17600.00
0005433869386	32580	Economy	17600.00
0005433869401	32580	Economy	17600.00
0005433869547	32580	Economy	17600.00
0005433869366	32580	Economy	17600.00
0005433869417	32580	Economy	17600.00
0005433869420	32580	Economy	17600.00
0005433869476	32580	Economy	17600.00
0005433869307	32580	Economy	17600.00
0005433869544	32580	Economy	17600.00
0005433869505	32580	Economy	17600.00
0005435911643	3442	Economy	22600.00
0005435911616	3442	Economy	22600.00
0005435911644	3442	Economy	22600.00
0005434663726	12469	Economy	24800.00
0005434663769	12469	Economy	24800.00
0005434663768	12469	Economy	22600.00
0005434663746	12469	Economy	22600.00
0005434663737	12469	Economy	22600.00
0005434663785	12469	Economy	22600.00
0005434663738	12469	Economy	22600.00
0005435911666	12469	Economy	22600.00
0005434663775	12469	Economy	22600.00
0005435911665	12469	Economy	22600.00
0005434663754	12469	Economy	22600.00
0005434663725	12469	Economy	22600.00
0005433869476	14502	Economy	18500.00
0005433869481	14502	Economy	18500.00
0005433869420	14502	Economy	16800.00
0005433869487	14502	Economy	16800.00
0005433869446	14502	Economy	16800.00
0005433869301	14502	Economy	16800.00
0005433869504	14502	Economy	16800.00
0005433869401	14502	Economy	16800.00
0005433869413	14502	Economy	16800.00
0005433869386	14502	Economy	16800.00
0005433869508	14502	Economy	16800.00
0005433869480	14502	Economy	16800.00
0005433869307	14502	Economy	16800.00
0005433869417	14502	Economy	16800.00
0005433869435	14502	Economy	16800.00
0005433869455	14502	Economy	16800.00
0005433869389	14502	Economy	16800.00
0005433869368	14502	Economy	16800.00
0005433869464	14502	Economy	16800.00
0005433869498	14502	Economy	16800.00
0005433869367	14502	Economy	16800.00
0005433869523	14502	Economy	16800.00
0005433869381	14502	Economy	16800.00
0005433869400	14502	Economy	16800.00
0005433869475	14502	Economy	16800.00
0005433869290	14502	Economy	16800.00
0005433869366	14502	Economy	16800.00
0005433869385	14502	Economy	16800.00
0005433869547	14502	Economy	16800.00
0005433869497	14502	Economy	16800.00
0005433869419	14502	Economy	16800.00
0005433869505	14502	Economy	16800.00
0005433869289	14502	Economy	16800.00
0005433869346	14502	Economy	16800.00
0005433869544	14502	Economy	16800.00
0005433869471	14502	Economy	16800.00
0005435860603	32681	Economy	18500.00
0005435860593	32681	Economy	16800.00
0005435860591	32681	Economy	16800.00
0005435860599	32681	Economy	16800.00
0005435860589	32681	Economy	16800.00
0005435860601	32681	Economy	16800.00
0005435860622	32681	Economy	16800.00
0005435860595	32681	Economy	16800.00
0005435860602	32681	Economy	16800.00
0005435860583	32681	Economy	16800.00
0005435860588	32681	Economy	16800.00
0005435860596	32681	Economy	16800.00
0005432800152	12147	Economy	4900.00
0005432800208	12147	Economy	4900.00
0005432800194	12147	Economy	4900.00
0005432800245	12147	Economy	4900.00
0005432800224	12147	Economy	4400.00
0005432800240	12147	Economy	4400.00
0005432800145	12147	Economy	4400.00
0005432800265	12147	Economy	4400.00
0005432800157	12147	Economy	4400.00
0005432800223	12147	Economy	4400.00
0005432800167	12147	Economy	4400.00
0005432800199	12147	Economy	4400.00
0005432800232	12147	Economy	4400.00
0005432800178	12147	Economy	4400.00
0005432800113	12147	Economy	4400.00
0005432800102	12147	Economy	4400.00
0005432800151	12147	Economy	4400.00
0005432800146	12147	Economy	4400.00
0005432800144	12147	Economy	4400.00
0005432800244	12147	Economy	4400.00
0005432800241	12147	Economy	4400.00
0005432800230	12147	Economy	4400.00
0005432800147	12147	Economy	4400.00
0005432800225	12147	Economy	4400.00
0005432800200	12147	Economy	4400.00
0005432800111	12147	Economy	4400.00
0005432800101	12147	Economy	4400.00
0005432800266	12147	Economy	4400.00
0005432800236	12147	Economy	4400.00
0005432800168	12147	Economy	4400.00
0005432800112	12147	Economy	4400.00
0005432800233	12147	Economy	4400.00
0005432800229	12147	Economy	4400.00
0005432800204	12147	Economy	4400.00
0005432800228	12147	Economy	4400.00
0005432800207	12147	Economy	4400.00
0005432800287	14779	Economy	4400.00
0005432800289	14779	Economy	4400.00
0005432800288	14779	Economy	4400.00
0005432800286	14779	Economy	4400.00
0005432800290	14779	Economy	4400.00
0005435293618	7063	Business	49100.00
0005435311458	7063	Economy	16400.00
0005434300232	7063	Economy	16400.00
0005435311297	7063	Economy	16400.00
0005435311429	7063	Economy	16400.00
0005435293604	7063	Economy	16400.00
0005435293563	7063	Economy	16400.00
0005435311372	7063	Economy	16400.00
0005435311451	7063	Economy	16400.00
0005435311435	7063	Economy	16400.00
0005435311450	7063	Economy	16400.00
0005435311524	7063	Economy	16400.00
0005435311373	7063	Economy	18000.00
0005435293599	7063	Economy	16400.00
0005435293499	7063	Economy	16400.00
0005435311459	7063	Economy	16400.00
0005435293566	7063	Economy	16400.00
0005435293592	7063	Economy	16400.00
0005435311497	7063	Economy	16400.00
0005435311411	7063	Economy	16400.00
0005435311475	7063	Economy	16400.00
0005435293555	7063	Economy	16400.00
0005435311444	7063	Economy	16400.00
0005435293557	7063	Economy	16400.00
0005435293598	7063	Economy	16400.00
0005434409262	26888	Business	49100.00
0005434300105	26888	Business	49100.00
0005434409261	26888	Business	49100.00
0005434300215	26888	Business	49100.00
0005434409185	26888	Business	49100.00
0005434409411	26888	Business	49100.00
0005434409316	26888	Business	49100.00
0005434408896	26888	Business	49100.00
0005434409391	26888	Business	49100.00
0005434409403	26888	Business	49100.00
0005434409443	26888	Economy	16400.00
0005434409191	26888	Economy	16400.00
0005434409534	26888	Economy	16400.00
0005434409356	26888	Economy	16400.00
0005434300133	26888	Economy	16400.00
0005434409349	26888	Economy	16400.00
0005434409169	26888	Economy	16400.00
0005434409404	26888	Economy	16400.00
0005434409256	26888	Economy	16400.00
0005434300127	26888	Economy	16400.00
0005434300151	26888	Economy	16400.00
0005434409357	26888	Economy	16400.00
0005434409294	26888	Economy	16400.00
0005434408894	26888	Economy	16400.00
0005434300189	26888	Economy	16400.00
0005434409214	26888	Economy	16400.00
0005434300171	26888	Economy	16400.00
0005434409341	26888	Economy	16400.00
0005434300086	26888	Economy	16400.00
0005434409501	26888	Economy	16400.00
0005434409398	26888	Economy	16400.00
0005434300145	26888	Economy	16400.00
0005434409457	26888	Economy	18000.00
0005434300168	26888	Economy	18000.00
0005434409187	26888	Economy	18000.00
0005435311559	26888	Economy	16400.00
0005434409329	26888	Economy	16400.00
0005434300179	26888	Economy	16400.00
0005434409385	26888	Economy	16400.00
0005434409413	26888	Economy	16400.00
0005434409197	26888	Economy	16400.00
0005434300191	26888	Economy	16400.00
0005434409177	26888	Economy	16400.00
0005434409164	26888	Economy	16400.00
0005434409109	26888	Economy	16400.00
0005434409433	26888	Economy	16400.00
0005434300132	26888	Economy	16400.00
0005434409390	26888	Economy	16400.00
0005434409387	26888	Economy	16400.00
0005434409570	26888	Economy	16400.00
0005434409253	26888	Economy	16400.00
0005434300104	26888	Economy	16400.00
0005434300087	26888	Economy	16400.00
0005434300190	26888	Economy	16400.00
0005434409395	26888	Economy	16400.00
0005434409186	26888	Economy	16400.00
0005434409317	26888	Economy	16400.00
0005434409412	26888	Economy	16400.00
0005434409198	26888	Economy	16400.00
0005434409301	26888	Economy	16400.00
0005434409315	26888	Economy	16400.00
0005434408895	26888	Economy	16400.00
0005434300210	26888	Economy	16400.00
0005434409163	26888	Economy	16400.00
0005434409227	26888	Economy	16400.00
0005434300180	26888	Economy	16400.00
0005434409399	26888	Economy	16400.00
0005434409504	26888	Economy	16400.00
0005434409234	26888	Economy	16400.00
0005434409392	26888	Economy	16400.00
0005434300053	26888	Economy	16400.00
0005434409340	26888	Economy	16400.00
0005434409368	26888	Economy	16400.00
0005432058500	26888	Economy	16400.00
0005434409199	26888	Economy	16400.00
0005434409342	26888	Economy	16400.00
0005435218144	6454	Economy	16500.00
0005435220515	6454	Economy	15000.00
0005435312904	6454	Economy	15000.00
0005432605515	6454	Economy	15000.00
0005435220516	6454	Economy	15000.00
0005435218143	6454	Economy	15000.00
0005435312905	6454	Economy	15000.00
0005435220514	6454	Economy	15000.00
0005435221553	6454	Economy	15000.00
0005432605359	21350	Economy	16500.00
0005432605335	21350	Economy	16500.00
0005432605384	21350	Economy	15000.00
0005432605294	21350	Economy	15000.00
0005432605111	21350	Economy	15000.00
0005432605339	21350	Economy	15000.00
0005432605325	21350	Economy	15000.00
0005432605320	21350	Economy	15000.00
0005432605408	21350	Economy	15000.00
0005434512252	21350	Economy	15000.00
0005432605360	21350	Economy	15000.00
0005432605326	21350	Economy	15000.00
0005432605305	21350	Economy	15000.00
0005432605303	21350	Economy	15000.00
0005432605340	21350	Economy	15000.00
0005432605375	21350	Economy	15000.00
0005432605333	21350	Economy	15000.00
0005432605297	21350	Economy	15000.00
0005432605334	21350	Economy	15000.00
0005434512251	21350	Economy	15000.00
0005432605418	21350	Economy	15000.00
0005432605371	21350	Economy	15000.00
0005432605345	21350	Economy	15000.00
0005432605454	21350	Economy	15000.00
0005432605239	21350	Economy	15000.00
0005432605365	21350	Economy	15000.00
0005432605417	21350	Economy	15000.00
0005432605346	21350	Economy	15000.00
0005432605295	21350	Economy	15000.00
0005432605110	21350	Economy	15000.00
0005432605341	21350	Economy	15000.00
0005432605304	21350	Economy	15000.00
0005432605319	21350	Economy	15000.00
0005434512250	21350	Economy	15000.00
0005432605296	21350	Economy	15000.00
0005434908319	15004	Business	18900.00
0005434908443	15004	Business	18900.00
0005434908609	15004	Business	18900.00
0005434908525	15004	Business	18900.00
0005434908618	15004	Business	18900.00
0005434908741	15004	Business	18900.00
0005434908740	15004	Business	18900.00
0005434908579	15004	Business	18900.00
0005434908663	15004	Business	18900.00
0005434908662	15004	Business	18900.00
0005434908637	15004	Economy	6300.00
0005434908666	15004	Economy	6300.00
0005434908650	15004	Economy	6300.00
0005434908575	15004	Economy	6300.00
0005434908727	15004	Economy	6300.00
0005434908557	15004	Economy	6900.00
0005434908421	15004	Economy	6900.00
0005434908691	15004	Economy	6900.00
0005434908461	15004	Economy	6900.00
0005433252386	15004	Economy	6300.00
0005434908634	15004	Economy	6300.00
0005434908327	15004	Economy	6300.00
0005434908578	15004	Economy	6300.00
0005433252387	15004	Economy	6300.00
0005434908726	15004	Economy	6300.00
0005434908794	15004	Economy	6300.00
0005434908475	15004	Economy	6300.00
0005434908602	15004	Economy	6300.00
0005434908846	15004	Economy	6300.00
0005434908680	15004	Economy	6300.00
0005434908576	15004	Economy	6300.00
0005434908689	15004	Economy	6300.00
0005434908580	15004	Economy	6300.00
0005434908482	15004	Economy	6300.00
0005434908764	15004	Economy	6300.00
0005434908795	15004	Economy	6300.00
0005434908439	15004	Economy	6300.00
0005434908577	15004	Economy	6300.00
0005434908326	15004	Economy	6300.00
0005434908654	15004	Economy	6300.00
0005434908561	15004	Economy	6300.00
0005434908490	15004	Economy	6300.00
0005434908721	15004	Economy	6300.00
0005434908636	15004	Economy	6300.00
0005434908592	15004	Economy	6300.00
0005434908524	15004	Economy	6300.00
0005434908476	15004	Economy	6300.00
0005434908562	15004	Economy	6300.00
0005434908845	15004	Economy	6300.00
0005434908725	15004	Economy	6300.00
0005434908665	15004	Economy	6300.00
0005434908491	15004	Economy	6300.00
0005434908617	15004	Economy	6300.00
0005434908698	15004	Economy	6300.00
0005434908451	15004	Economy	6300.00
0005434908438	15004	Economy	6300.00
0005434908449	15004	Economy	6300.00
0005434908688	15004	Economy	6300.00
0005434908681	15004	Economy	6300.00
0005434908625	15004	Economy	6300.00
0005434908420	15004	Economy	6300.00
0005434908722	15004	Economy	6300.00
0005434908593	15004	Economy	6300.00
0005433252248	25828	Business	18900.00
0005433252275	25828	Business	18900.00
0005433252262	25828	Business	18900.00
0005433252314	25828	Business	18900.00
0005434908899	25828	Business	18900.00
0005433252312	25828	Business	18900.00
0005433252291	25828	Business	18900.00
0005433252324	25828	Economy	6300.00
0005434908898	25828	Economy	6300.00
0005433252193	25828	Economy	6300.00
0005433252273	25828	Economy	6900.00
0005433252285	25828	Economy	6900.00
0005433252250	25828	Economy	6300.00
0005433252205	25828	Economy	6300.00
0005433252153	25828	Economy	6300.00
0005433252192	25828	Economy	6300.00
0005433252238	25828	Economy	6300.00
0005433252196	25828	Economy	6300.00
0005433252197	25828	Economy	6300.00
0005433252204	25828	Economy	6300.00
0005433252325	25828	Economy	6300.00
0005433252195	25828	Economy	6300.00
0005433252277	25828	Economy	6300.00
0005434908897	25828	Economy	6300.00
0005433252364	25828	Economy	6300.00
0005433252260	25828	Economy	6300.00
0005433252251	25828	Economy	6300.00
0005433252363	25828	Economy	6300.00
0005433252276	25828	Economy	6300.00
0005434173645	9182	Economy	18100.00
0005433815547	22753	Economy	18100.00
0005433815551	22753	Economy	18100.00
0005433815548	22753	Economy	18100.00
0005434171514	22753	Economy	18100.00
0005434171513	22753	Economy	18100.00
0005433815554	22753	Economy	18100.00
0005433810677	14178	Economy	17400.00
0005433815551	14178	Economy	17400.00
0005433810719	14178	Economy	19200.00
0005433810705	14178	Economy	17400.00
0005433810667	14178	Economy	17400.00
0005434171514	14178	Economy	17400.00
0005433815554	14178	Economy	17400.00
0005433810743	14178	Economy	17400.00
0005433815548	14178	Economy	17400.00
0005434171513	14178	Economy	17400.00
0005433810670	14178	Economy	17400.00
0005433810730	14178	Economy	17400.00
0005433810691	14178	Economy	17400.00
0005433815547	14178	Economy	17400.00
0005433009982	14178	Economy	17400.00
0005433810672	14178	Economy	17400.00
0005433810676	14178	Economy	17400.00
0005433009983	14178	Economy	17400.00
0005433810671	14178	Economy	17400.00
0005433009770	22839	Business	52300.00
0005433810810	22839	Business	52300.00
0005433009286	22839	Business	52300.00
0005433810808	22839	Business	52300.00
0005433815582	22839	Business	52300.00
0005433009827	22839	Business	52300.00
0005433009735	22839	Business	52300.00
0005433009825	22839	Business	52300.00
0005433009487	22839	Business	52300.00
0005433009695	22839	Economy	17400.00
0005433009463	22839	Economy	17400.00
0005433009673	22839	Economy	17400.00
0005433009717	22839	Economy	19200.00
0005433009789	22839	Economy	19200.00
0005433009653	22839	Economy	17400.00
0005433815585	22839	Economy	17400.00
0005433009464	22839	Economy	17400.00
0005433009486	22839	Economy	17400.00
0005433009799	22839	Economy	17400.00
0005433009485	22839	Economy	17400.00
0005433009832	22839	Economy	17400.00
0005433009841	22839	Economy	17400.00
0005433009734	22839	Economy	17400.00
0005433009755	22839	Economy	17400.00
0005433009858	22839	Economy	17400.00
0005433009666	22839	Economy	17400.00
0005433810807	22839	Economy	17400.00
0005433009812	22839	Economy	17400.00
0005434173648	22839	Economy	17400.00
0005433009722	22839	Economy	17400.00
0005433009773	22839	Economy	17400.00
0005433009465	22839	Economy	17400.00
0005434173652	22839	Economy	17400.00
0005433009684	22839	Economy	17400.00
0005433009702	22839	Economy	17400.00
0005433009781	22839	Economy	17400.00
0005433815581	22839	Economy	17400.00
0005433009674	22839	Economy	17400.00
0005433009696	22839	Economy	17400.00
0005433009721	22839	Economy	17400.00
0005433009866	22839	Economy	17400.00
0005433810809	22839	Economy	17400.00
0005433009608	22839	Economy	17400.00
0005433009826	22839	Economy	17400.00
0005433009788	22839	Economy	17400.00
0005433815583	22839	Economy	17400.00
0005433009703	22839	Economy	17400.00
0005434173651	22839	Economy	17400.00
0005433009772	22839	Economy	17400.00
0005435719062	27119	Business	85200.00
0005435719026	27119	Business	85200.00
0005435719039	27119	Business	85200.00
0005435719085	27119	Business	85200.00
0005435719090	27119	Business	85200.00
0005435719050	27119	Business	85200.00
0005435719040	27119	Business	85200.00
0005435719046	27119	Business	85200.00
0005435719014	27119	Business	85200.00
0005435719059	27119	Business	85200.00
0005435719052	27119	Economy	28400.00
0005435719066	27119	Economy	28400.00
0005435719095	27119	Economy	28400.00
0005435719047	27119	Economy	31200.00
0005435719091	27119	Economy	31200.00
0005435719051	27119	Economy	31200.00
0005435719036	27119	Economy	28400.00
0005435719056	27119	Economy	28400.00
0005435719053	27119	Economy	28400.00
0005435719033	27119	Economy	28400.00
0005435719081	27119	Economy	28400.00
0005435719069	27119	Economy	28400.00
0005435719035	27119	Economy	28400.00
0005435719057	27119	Economy	28400.00
0005435719072	27119	Economy	28400.00
0005435719086	27119	Economy	28400.00
0005435719082	27119	Economy	28400.00
0005435719064	27119	Economy	28400.00
0005435719094	27119	Economy	28400.00
0005435719055	27119	Economy	28400.00
0005435719041	27119	Economy	28400.00
0005435719088	27119	Economy	28400.00
0005435719092	27119	Economy	28400.00
0005435719076	27119	Economy	28400.00
0005435719003	27119	Economy	28400.00
0005435719038	27119	Economy	28400.00
0005435719037	27119	Economy	28400.00
0005435719060	27119	Economy	28400.00
0005435719045	27119	Economy	28400.00
0005435719013	27119	Economy	28400.00
0005435719020	27119	Economy	28400.00
0005435719063	27119	Economy	28400.00
0005435719089	27119	Economy	28400.00
0005435719065	27119	Economy	28400.00
0005435719032	27119	Economy	28400.00
0005435719077	27119	Economy	28400.00
0005435719080	27119	Economy	28400.00
0005435719021	27119	Economy	28400.00
0005435719087	27119	Economy	28400.00
0005435719084	27119	Economy	28400.00
0005434926610	14923	Business	22900.00
0005434926723	14923	Business	22900.00
0005434926789	14923	Business	22900.00
0005434926663	14923	Business	22900.00
0005434926708	14923	Business	22900.00
0005434926580	14923	Business	22900.00
0005434926649	14923	Business	22900.00
0005434926521	14923	Economy	7600.00
0005434926770	14923	Economy	7600.00
0005434926716	14923	Economy	7600.00
0005434926665	14923	Economy	8400.00
0005434926581	14923	Economy	7600.00
0005434926633	14923	Economy	7600.00
0005434926544	14923	Economy	7600.00
0005434926577	14923	Economy	7600.00
0005434926676	14923	Economy	7600.00
0005434926601	14923	Economy	7600.00
0005434926661	14923	Economy	7600.00
0005434926651	14923	Economy	7600.00
0005434926666	14923	Economy	7600.00
0005434926715	14923	Economy	7600.00
0005434926694	14923	Economy	7600.00
0005434926718	14923	Economy	7600.00
0005434926675	14923	Economy	7600.00
0005434926790	14923	Economy	7600.00
0005434926793	14923	Economy	7600.00
0005434926648	14923	Economy	7600.00
0005434926501	14923	Economy	7600.00
0005434926691	14923	Economy	7600.00
0005434926664	14923	Economy	7600.00
0005434926696	14923	Economy	7600.00
0005434926535	14923	Economy	7600.00
0005434926695	14923	Economy	7600.00
0005434926504	14923	Economy	7600.00
0005434926717	14923	Economy	7600.00
0005434926578	14923	Economy	7600.00
0005434926707	14923	Economy	7600.00
0005434926650	14923	Economy	7600.00
0005434926609	14923	Economy	7600.00
0005434926861	20518	Business	22900.00
0005434926863	20518	Economy	8400.00
0005434926862	20518	Economy	7600.00
0005435999814	15835	Economy	8900.00
0005435999771	15835	Economy	8900.00
0005435999756	15835	Economy	8900.00
0005435999813	15835	Economy	8100.00
0005435999806	15835	Economy	8100.00
0005435999815	15835	Economy	8100.00
0005435999768	15835	Economy	8100.00
0005435999654	15835	Economy	8100.00
0005435999767	15835	Economy	8100.00
0005435999821	15835	Economy	8100.00
0005435999638	15835	Economy	8100.00
0005435999757	15835	Economy	8100.00
0005435999693	15835	Economy	8100.00
0005435999755	15835	Economy	8100.00
0005435999729	15835	Economy	8100.00
0005435999596	15835	Economy	8100.00
0005435999762	15835	Economy	8100.00
0005435999633	15835	Economy	8100.00
0005435999744	15835	Economy	8100.00
0005435999743	15835	Economy	8100.00
0005435999671	15835	Economy	8100.00
0005435999752	15835	Economy	8100.00
0005435999685	15835	Economy	8100.00
0005435999754	15835	Economy	8100.00
0005435999674	15835	Economy	8100.00
0005435488348	19675	Economy	8900.00
0005435488351	19675	Economy	8100.00
0005435488329	19675	Economy	8100.00
0005435488213	19675	Economy	8100.00
0005435488337	19675	Economy	8100.00
0005435488214	19675	Economy	8100.00
0005435488383	19675	Economy	8100.00
0005435488334	19675	Economy	8100.00
0005435488294	19675	Economy	8100.00
0005435488423	19675	Economy	8100.00
0005435488381	19675	Economy	8100.00
0005435488379	19675	Economy	8100.00
0005435488300	19675	Economy	8100.00
0005435488374	19675	Economy	8100.00
0005435488333	19675	Economy	8100.00
0005435488301	19675	Economy	8100.00
0005435488384	19675	Economy	8100.00
0005435488400	19675	Economy	8100.00
0005435488293	19675	Economy	8100.00
0005435488378	19675	Economy	8100.00
0005435488386	19675	Economy	8100.00
0005435488385	19675	Economy	8100.00
0005435999863	19675	Economy	8100.00
0005435488419	19675	Economy	8100.00
0005435488380	19675	Economy	8100.00
0005435488420	19675	Economy	8100.00
0005435488324	19675	Economy	8100.00
0005435488406	19675	Economy	8100.00
0005435488422	19675	Economy	8100.00
0005435473230	6001	Business	199300.00
0005435473167	6001	Business	199300.00
0005435473231	6001	Business	199300.00
0005435473218	6001	Business	199300.00
0005435473273	6001	Business	199300.00
0005435473208	6001	Business	199300.00
0005435473219	6001	Economy	66400.00
0005435473274	6001	Economy	66400.00
0005432537111	6001	Economy	73100.00
0005432658654	6001	Economy	66400.00
0005435473267	6001	Economy	66400.00
0005435473180	6001	Economy	66400.00
0005435473229	6001	Economy	66400.00
0005432537112	6001	Economy	66400.00
0005435473195	6001	Economy	66400.00
0005432658655	6001	Economy	66400.00
0005432537110	6001	Economy	66400.00
0005435473262	6001	Economy	66400.00
0005435473220	6001	Economy	66400.00
0005435840276	6001	Economy	66400.00
0005435473178	6001	Economy	66400.00
0005435473177	6001	Economy	66400.00
0005435473197	6001	Economy	66400.00
0005435473223	6001	Economy	66400.00
0005435473254	6001	Economy	66400.00
0005435840083	18033	Business	199300.00
0005432660857	18033	Economy	66400.00
0005435840100	18033	Economy	66400.00
0005435840204	18033	Economy	66400.00
0005435840213	18033	Economy	73100.00
0005432667501	18033	Economy	66400.00
0005432667502	18033	Economy	66400.00
0005432660866	18033	Economy	66400.00
0005435840239	18033	Economy	66400.00
0005435840217	18033	Economy	66400.00
0005435840144	18033	Economy	66400.00
0005435840202	18033	Economy	66400.00
0005435840160	18033	Economy	66400.00
0005435840216	18033	Economy	66400.00
0005435840159	18033	Economy	66400.00
0005432664189	18033	Economy	66400.00
0005435840157	18033	Economy	66400.00
0005435840212	18033	Economy	66400.00
0005435840203	18033	Economy	66400.00
0005432667503	18033	Economy	66400.00
0005435840143	18033	Economy	66400.00
0005433462773	19914	Business	146400.00
0005433460484	19914	Business	146400.00
0005433460485	19914	Business	146400.00
0005433462779	19914	Business	146400.00
0005433460467	19914	Economy	53700.00
0005433460480	19914	Economy	53700.00
0005433462802	19914	Economy	48800.00
0005433462801	19914	Economy	48800.00
0005433460475	19914	Economy	48800.00
0005433460476	19914	Economy	48800.00
0005433460460	19914	Economy	48800.00
0005433462780	19914	Economy	48800.00
0005433462790	19914	Economy	48800.00
0005433460490	19914	Economy	48800.00
0005433460488	19914	Economy	48800.00
0005433460487	19914	Economy	48800.00
0005433460473	19914	Economy	48800.00
0005433462789	19914	Economy	48800.00
0005433462795	19914	Economy	48800.00
0005433462798	19914	Economy	48800.00
0005433460479	19914	Economy	48800.00
0005433460489	19914	Economy	48800.00
0005433460477	19914	Economy	48800.00
0005433462788	19914	Economy	53700.00
0005433460464	19914	Economy	48800.00
0005433462785	19914	Economy	48800.00
0005433460468	19914	Economy	48800.00
0005433460482	19914	Economy	48800.00
0005433462781	19914	Economy	48800.00
0005433462774	19914	Economy	48800.00
0005433462775	19914	Economy	48800.00
0005433460478	19914	Economy	48800.00
0005433462796	19914	Economy	48800.00
0005433286101	23015	Business	15700.00
0005433286150	23015	Business	15700.00
0005433286072	23015	Business	15700.00
0005433286062	23015	Economy	5200.00
0005433286148	23015	Economy	5200.00
0005435104383	23015	Economy	5200.00
0005433286071	23015	Economy	5200.00
0005433286149	23015	Economy	5200.00
0005433286130	23015	Economy	5200.00
0005433286044	23015	Economy	5200.00
0005435104384	23015	Economy	5200.00
0005435104381	23015	Economy	5700.00
0005433286041	23015	Economy	5200.00
0005433286102	23015	Economy	5200.00
0005433286109	23015	Economy	5200.00
0005433286158	23015	Economy	5200.00
0005435097527	23015	Economy	5200.00
0005433285999	23015	Economy	5200.00
0005435097529	23015	Economy	5200.00
0005433285951	23015	Economy	5200.00
0005433286117	23015	Economy	5200.00
0005433286119	23015	Economy	5200.00
0005433286077	23015	Economy	5200.00
0005435104382	23015	Economy	5200.00
0005433286064	23015	Economy	5200.00
0005433286181	23015	Economy	5200.00
0005433286199	23015	Economy	5200.00
0005433286118	23015	Economy	5200.00
0005433286182	23015	Economy	5200.00
0005435097528	23015	Economy	5200.00
0005433285978	23015	Economy	5200.00
0005435104204	32096	Economy	5200.00
0005435104199	32096	Economy	5200.00
0005435104152	32096	Economy	5200.00
0005435104153	32096	Economy	5200.00
0005435104205	32096	Economy	5200.00
0005435104161	32096	Economy	5200.00
0005435104172	32096	Economy	5200.00
0005435104165	32096	Economy	5200.00
0005435104206	32096	Economy	5200.00
0005435104177	32096	Economy	5200.00
0005435104176	32096	Economy	5200.00
0005435104170	32096	Economy	5200.00
0005435104164	32096	Economy	5200.00
0005435104171	32096	Economy	5200.00
0005435104158	32096	Economy	5200.00
0005435104186	32096	Economy	5200.00
0005435104157	32096	Economy	5200.00
0005435104194	32096	Economy	5200.00
0005435104154	32096	Economy	5200.00
0005434302888	19944	Business	150400.00
0005432802594	19944	Business	150400.00
0005434302883	19944	Business	150400.00
0005434302896	19944	Business	150400.00
0005433112422	19944	Business	150400.00
0005434302890	19944	Business	150400.00
0005432892823	19944	Business	150400.00
0005432892824	19944	Economy	50100.00
0005434302877	19944	Economy	50100.00
0005433111567	19944	Economy	50100.00
0005433111566	19944	Economy	50100.00
0005432892821	19944	Economy	50100.00
0005434302878	19944	Economy	50100.00
0005434302880	19944	Economy	50100.00
0005432802619	19944	Economy	55200.00
0005432802598	19944	Economy	55200.00
0005433112419	19944	Economy	55200.00
0005433112423	19944	Economy	55200.00
0005432802616	19944	Economy	50100.00
0005434302881	19944	Economy	50100.00
0005432892822	19944	Economy	50100.00
0005432802624	19944	Economy	50100.00
0005432802625	19944	Economy	50100.00
0005432802574	19944	Economy	50100.00
0005434302884	19944	Economy	50100.00
0005434302879	19944	Economy	50100.00
0005432802575	19944	Economy	50100.00
0005434302893	19944	Economy	50100.00
0005432802605	19944	Economy	50100.00
0005433112421	19944	Economy	50100.00
0005432802595	19944	Economy	50100.00
0005432802593	19944	Economy	50100.00
0005432802577	19944	Economy	50100.00
0005434302885	19944	Economy	50100.00
0005432802614	19944	Economy	50100.00
0005432802608	19944	Economy	50100.00
0005434302886	19944	Economy	50100.00
0005432802626	19944	Economy	50100.00
0005432802612	19944	Economy	50100.00
0005433112420	19944	Economy	50100.00
0005432802597	19944	Economy	50100.00
0005432892825	19944	Economy	50100.00
0005433111565	19944	Economy	50100.00
0005432802613	19944	Economy	50100.00
0005432802609	19944	Economy	50100.00
0005432802610	19944	Economy	50100.00
0005432802618	19944	Economy	50100.00
0005432802573	19944	Economy	50100.00
0005432802596	19944	Economy	50100.00
0005432802578	19944	Economy	50100.00
0005434302889	19944	Economy	50100.00
0005434302887	19944	Economy	50100.00
0005432802599	19944	Economy	50100.00
0005434302891	19944	Economy	50100.00
0005433111568	19944	Economy	50100.00
0005434302882	19944	Economy	50100.00
0005432802592	19944	Economy	50100.00
0005432531458	30623	Business	42100.00
0005434069326	30623	Business	42100.00
0005432531574	30623	Business	42100.00
0005432531172	30623	Business	42100.00
0005432531583	30623	Business	42100.00
0005432531328	30623	Business	42100.00
0005432531165	30623	Business	42100.00
0005432531509	30623	Business	42100.00
0005432531765	30623	Business	42100.00
0005432531675	30623	Business	42100.00
0005432531449	30623	Business	42100.00
0005432531673	30623	Business	42100.00
0005432531612	30623	Business	42100.00
0005434069207	30623	Business	42100.00
0005432531275	30623	Business	42100.00
0005432531423	30623	Business	42100.00
0005432535961	30623	Comfort	23900.00
0005432530910	30623	Comfort	23900.00
0005432530955	30623	Comfort	23900.00
0005432531459	30623	Comfort	23900.00
0005434069358	30623	Comfort	23900.00
0005434069325	30623	Comfort	23900.00
0005432533365	30623	Comfort	23900.00
0005434069476	30623	Comfort	23900.00
0005434069359	30623	Comfort	23900.00
0005432537107	30623	Comfort	23900.00
0005432531424	30623	Comfort	23900.00
0005432530916	30623	Comfort	23900.00
0005432531299	30623	Comfort	23900.00
0005432531493	30623	Economy	14000.00
0005434069571	30623	Economy	14000.00
0005432530388	30623	Economy	14000.00
0005432531085	30623	Economy	14000.00
0005432531438	30623	Economy	14000.00
0005434069421	30623	Economy	14000.00
0005432531651	30623	Economy	14000.00
0005432531552	30623	Economy	14000.00
0005434069084	30623	Economy	14000.00
0005432533374	30623	Economy	14000.00
0005434069463	30623	Economy	14000.00
0005432531292	30623	Economy	14000.00
0005434069318	30623	Economy	14000.00
0005432531307	30623	Economy	14000.00
0005432531650	30623	Economy	14000.00
0005432531237	30623	Economy	14000.00
0005432531335	30623	Economy	14000.00
0005432531336	30623	Economy	14000.00
0005434069413	30623	Economy	14000.00
0005432531232	30623	Economy	14000.00
0005432531460	30623	Economy	14000.00
0005434069534	30623	Economy	14000.00
0005432531439	30623	Economy	14000.00
0005432531606	30623	Economy	14000.00
0005432531322	30623	Economy	14000.00
0005434069321	30623	Economy	15400.00
0005432537106	30623	Economy	14000.00
0005432537120	30623	Economy	14000.00
0005432531492	30623	Economy	14000.00
0005434069361	30623	Economy	14000.00
0005432531236	30623	Economy	14000.00
0005434069604	30623	Economy	14000.00
0005434069478	30623	Economy	14000.00
0005432531091	30623	Economy	14000.00
0005432531553	30623	Economy	14000.00
0005432531075	30623	Economy	14000.00
0005432531274	30623	Economy	14000.00
0005432531627	30623	Economy	14000.00
0005432531095	30623	Economy	14000.00
0005432531382	30623	Economy	14000.00
0005434069477	30623	Economy	14000.00
0005432531694	30623	Economy	14000.00
0005432531527	30623	Economy	14000.00
0005434069317	30623	Economy	14000.00
0005434069515	30623	Economy	14000.00
0005434069384	30623	Economy	14000.00
0005432531582	30623	Economy	14000.00
0005432531519	30623	Economy	14000.00
0005432530909	30623	Economy	14000.00
0005432531229	30623	Economy	14000.00
0005432531649	30623	Economy	14000.00
0005432531329	30623	Economy	14000.00
0005432535962	30623	Economy	14000.00
0005432531405	30623	Economy	14000.00
0005434069625	30623	Economy	14000.00
0005432531611	30623	Economy	14000.00
0005434069320	30623	Economy	14000.00
0005432531688	30623	Economy	14000.00
0005432531526	30623	Economy	14000.00
0005432531510	30623	Economy	14000.00
0005434069597	30623	Economy	14000.00
0005434069187	30623	Economy	14000.00
0005434069138	30623	Economy	14000.00
0005432531377	30623	Economy	14000.00
0005432531626	30623	Economy	14000.00
0005434069340	30623	Economy	14000.00
0005432531687	30623	Economy	14000.00
0005432531171	30623	Economy	14000.00
0005434069559	30623	Economy	14000.00
0005432531755	30623	Economy	14000.00
0005432531572	30623	Economy	14000.00
0005432531086	30623	Economy	14000.00
0005432531419	30623	Economy	14000.00
0005432531238	30623	Economy	14000.00
0005432531293	30623	Economy	14000.00
0005434069319	30623	Economy	15400.00
0005434069438	30623	Economy	15400.00
0005432531323	30623	Economy	15400.00
0005432531381	30623	Economy	14000.00
0005432531164	30623	Economy	14000.00
0005432535943	30623	Economy	14000.00
0005432531173	30623	Economy	14000.00
0005432531705	30623	Economy	14000.00
0005434069360	30623	Economy	14000.00
0005434069420	30623	Economy	14000.00
0005432531613	30623	Economy	14000.00
0005434069535	30623	Economy	14000.00
0005432533375	30623	Economy	14000.00
0005432531155	30623	Economy	14000.00
0005432531461	30623	Economy	14000.00
0005432531178	30623	Economy	14000.00
0005432531508	30623	Economy	14000.00
0005432531766	30623	Economy	14000.00
0005434069552	30623	Economy	14000.00
0005432531154	30623	Economy	14000.00
0005432531276	30623	Economy	14000.00
0005434069362	30623	Economy	14000.00
0005434069190	30623	Economy	14000.00
0005432531261	30623	Economy	14000.00
0005434069316	30623	Economy	14000.00
0005434069551	30623	Economy	14000.00
0005432530977	30623	Economy	14000.00
0005432531584	30623	Economy	14000.00
0005432531166	30623	Economy	14000.00
0005434069624	30623	Economy	14000.00
0005434069577	30623	Economy	14000.00
0005434069209	30623	Economy	14000.00
0005432531035	30623	Economy	14000.00
0005432531087	30623	Economy	14000.00
0005434069277	30623	Economy	14000.00
0005432531378	30623	Economy	14000.00
0005434069352	30623	Economy	14000.00
0005434069511	30623	Economy	14000.00
0005432531674	30623	Economy	14000.00
0005432531422	30623	Economy	14000.00
0005432531179	30623	Economy	14000.00
0005432531475	30623	Economy	14000.00
0005432533373	30623	Economy	14000.00
0005434069514	30623	Economy	14000.00
0005432531767	30623	Economy	14000.00
0005434069558	30623	Economy	14000.00
0005432531618	30623	Economy	14000.00
0005435654396	24831	Business	9800.00
0005435654143	24831	Business	9800.00
0005435654303	24831	Business	9800.00
0005435654233	24831	Business	9800.00
0005435654063	24831	Business	9800.00
0005435654212	24831	Business	9800.00
0005435654264	24831	Business	9800.00
0005435654345	24831	Economy	3300.00
0005435654134	24831	Economy	3300.00
0005435654154	24831	Economy	3300.00
0005435654043	24831	Economy	3300.00
0005435654249	24831	Economy	3300.00
0005435654211	24831	Economy	3300.00
0005435654311	24831	Economy	3300.00
0005435654191	24831	Economy	3600.00
0005435654023	24831	Economy	3600.00
0005435654213	24831	Economy	3600.00
0005435654160	24831	Economy	3600.00
0005435654373	24831	Economy	3300.00
0005435654331	24831	Economy	3300.00
0005435654163	24831	Economy	3300.00
0005435654276	24831	Economy	3300.00
0005435654136	24831	Economy	3300.00
0005435654335	24831	Economy	3300.00
0005435654339	24831	Economy	3300.00
0005435654058	24831	Economy	3300.00
0005435654312	24831	Economy	3300.00
0005435654377	24831	Economy	3300.00
0005435654239	24831	Economy	3300.00
0005435654263	24831	Economy	3300.00
0005435654159	24831	Economy	3300.00
0005435654062	24831	Economy	3300.00
0005435654153	24831	Economy	3300.00
0005435654397	24831	Economy	3300.00
0005435654180	24831	Economy	3300.00
0005435654135	24831	Economy	3300.00
0005435790418	24831	Economy	3300.00
0005435654205	24831	Economy	3300.00
0005435654275	24831	Economy	3300.00
0005435654131	24831	Economy	3300.00
0005435654340	24831	Economy	3300.00
0005435654372	24831	Economy	3300.00
0005435654170	24831	Economy	3300.00
0005435654161	24831	Economy	3300.00
0005435654280	24831	Economy	3300.00
0005435654269	24831	Economy	3300.00
0005435654376	24831	Economy	3300.00
0005435654165	24831	Economy	3300.00
0005435654204	24831	Economy	3300.00
0005435654238	24831	Economy	3300.00
0005435654262	24831	Economy	3300.00
0005435654061	24831	Economy	3300.00
0005435654330	24831	Economy	3300.00
0005435654022	24831	Economy	3300.00
0005435654281	24831	Economy	3300.00
0005434980678	2024	Economy	9500.00
0005434980340	23554	Economy	10500.00
0005434980485	23554	Economy	10500.00
0005434980549	23554	Economy	10500.00
0005434980579	23554	Economy	9500.00
0005434980460	23554	Economy	9500.00
0005434980580	23554	Economy	9500.00
0005435801777	23554	Economy	9500.00
0005434980416	23554	Economy	9500.00
0005434980442	23554	Economy	9500.00
0005434980568	23554	Economy	9500.00
0005434980603	23554	Economy	9500.00
0005434980558	23554	Economy	9500.00
0005434980490	23554	Economy	9500.00
0005434980573	23554	Economy	9500.00
0005435801770	23554	Economy	9500.00
0005434980614	23554	Economy	9500.00
0005434980502	23554	Economy	9500.00
0005434980523	23554	Economy	9500.00
0005434980522	23554	Economy	9500.00
0005434980572	23554	Economy	9500.00
0005434980604	23554	Economy	9500.00
0005434980613	23554	Economy	9500.00
0005434980505	23554	Economy	9500.00
0005434980550	23554	Economy	9500.00
0005434980548	23554	Economy	9500.00
0005434980516	23554	Economy	9500.00
0005434980567	23554	Economy	9500.00
0005434980492	23554	Economy	9500.00
0005434980477	23554	Economy	9500.00
0005434980493	23554	Economy	9500.00
0005434980417	23554	Economy	9500.00
0005434980543	23554	Economy	9500.00
0005434980571	23554	Economy	9500.00
0005434980529	23554	Economy	9500.00
0005434980484	23554	Economy	9500.00
0005434980517	23554	Economy	9500.00
0005434980509	23554	Economy	9500.00
0005434980457	23554	Economy	9500.00
0005434980458	23554	Economy	9500.00
0005434980514	23554	Economy	9500.00
0005433256481	2587	Economy	5300.00
0005433256488	2587	Economy	5300.00
0005433256472	2587	Economy	5300.00
0005434952629	28294	Economy	5300.00
0005434952636	28294	Economy	5300.00
0005434952631	28294	Economy	5300.00
0005434952630	28294	Economy	5300.00
0005434952635	28294	Economy	5300.00
0005433112424	19757	Economy	8700.00
0005433112425	19757	Economy	8700.00
0005434140491	11920	Business	9700.00
0005434140497	11920	Business	9700.00
0005434139899	11920	Business	9700.00
0005434140437	11920	Business	9700.00
0005434140515	11920	Business	9700.00
0005434140489	11920	Business	9700.00
0005434140483	11920	Business	9700.00
0005434140364	11920	Business	9700.00
0005434140565	11920	Business	9700.00
0005434140477	11920	Business	9700.00
0005434140481	11920	Economy	3200.00
0005434140312	11920	Economy	3200.00
0005434140286	11920	Economy	3200.00
0005434140190	11920	Economy	3200.00
0005434140212	11920	Economy	3200.00
0005434139838	11920	Economy	3200.00
0005434140516	11920	Economy	3200.00
0005434140464	11920	Economy	3200.00
0005434140436	11920	Economy	3500.00
0005434140043	11920	Economy	3500.00
0005434140319	11920	Economy	3500.00
0005434140365	11920	Economy	3500.00
0005434140501	11920	Economy	3200.00
0005434140330	11920	Economy	3200.00
0005434140381	11920	Economy	3200.00
0005434140413	11920	Economy	3200.00
0005434140496	11920	Economy	3200.00
0005434140368	11920	Economy	3200.00
0005434140241	11920	Economy	3200.00
0005434140208	11920	Economy	3200.00
0005434140209	11920	Economy	3200.00
0005434140479	11920	Economy	3200.00
0005434140502	11920	Economy	3200.00
0005434140297	11920	Economy	3200.00
0005434140140	11920	Economy	3200.00
0005434140132	11920	Economy	3200.00
0005434140176	11920	Economy	3200.00
0005434140347	11920	Economy	3200.00
0005434140116	11920	Economy	3200.00
0005434140139	11920	Economy	3200.00
0005434140390	11920	Economy	3200.00
0005434140079	11920	Economy	3200.00
0005434140494	11920	Economy	3200.00
0005434140274	11920	Economy	3200.00
0005434140207	11920	Economy	3200.00
0005434140552	11920	Economy	3200.00
0005434140133	11920	Economy	3200.00
0005434140360	11920	Economy	3200.00
0005434140465	11920	Economy	3200.00
0005434140386	11920	Economy	3200.00
0005434140251	11920	Economy	3200.00
0005434140405	11920	Economy	3200.00
0005434140492	11920	Economy	3200.00
0005434140363	11920	Economy	3200.00
0005434140206	11920	Economy	3200.00
0005434140061	11920	Economy	3200.00
0005434140296	11920	Economy	3200.00
0005434140443	11920	Economy	3200.00
0005434140474	11920	Economy	3200.00
0005434140308	11920	Economy	3200.00
0005434140075	11920	Economy	3200.00
0005434140411	11920	Economy	3200.00
0005434140495	11920	Economy	3200.00
0005434140480	11920	Economy	3200.00
0005434140177	11920	Economy	3200.00
0005434140380	11920	Economy	3200.00
0005434140287	11920	Economy	3200.00
0005434140071	11920	Economy	3200.00
0005434140210	11920	Economy	3200.00
0005434140076	11920	Economy	3200.00
0005434140313	11920	Economy	3200.00
0005434140213	11920	Economy	3200.00
0005434140466	11920	Economy	3200.00
0005434140307	11920	Economy	3200.00
0005434140183	11920	Economy	3200.00
0005434140388	11920	Economy	3200.00
0005434140566	11920	Economy	3200.00
0005434140244	11920	Economy	3200.00
0005434140359	11920	Economy	3200.00
0005434140329	11920	Economy	3200.00
0005434140385	11920	Economy	3200.00
0005434140318	11920	Economy	3200.00
0005435259876	6772	Economy	9900.00
0005435259871	6772	Economy	9900.00
0005435259865	6772	Economy	9900.00
0005435259880	6772	Economy	9900.00
0005433534549	24995	Economy	10900.00
0005433534542	24995	Economy	9900.00
0005433534548	24995	Economy	9900.00
0005433534541	24995	Economy	9900.00
0005433534551	24995	Economy	9900.00
0005433539105	24995	Economy	9900.00
0005433534554	24995	Economy	9900.00
0005433512179	16169	Economy	16100.00
0005433512178	16169	Economy	14600.00
0005433512171	16169	Economy	14600.00
0005433512173	16169	Economy	14600.00
0005433512174	16169	Economy	14600.00
0005433512175	16169	Economy	14600.00
0005433512184	16169	Economy	14600.00
0005433512172	16169	Economy	14600.00
0005433512170	16169	Economy	14600.00
0005435916243	3656	Economy	7200.00
0005435697933	16279	Economy	7900.00
0005435698118	16279	Economy	7900.00
0005435698010	16279	Economy	7900.00
0005435698080	16279	Economy	7900.00
0005435698141	16279	Economy	7200.00
0005435698004	16279	Economy	7200.00
0005435698054	16279	Economy	7200.00
0005435698099	16279	Economy	7200.00
0005435698063	16279	Economy	7200.00
0005435698009	16279	Economy	7200.00
0005435697972	16279	Economy	7200.00
0005435698119	16279	Economy	7200.00
0005435698142	16279	Economy	7200.00
0005435698039	16279	Economy	7200.00
0005435698012	16279	Economy	7200.00
0005435698071	16279	Economy	7200.00
0005434950648	16279	Economy	7200.00
0005435698112	16279	Economy	7200.00
0005435698058	16279	Economy	7200.00
0005435698072	16279	Economy	7200.00
0005435698003	16279	Economy	7200.00
0005435698037	16279	Economy	7200.00
0005435698097	16279	Economy	7200.00
0005435697973	16279	Economy	7200.00
0005434950644	16279	Economy	7200.00
0005435697934	16279	Economy	7200.00
0005435698062	16279	Economy	7200.00
0005435698137	16279	Economy	7200.00
0005435698096	16279	Economy	7200.00
0005435698110	16279	Economy	7200.00
0005435698111	16279	Economy	7200.00
0005435698120	16279	Economy	7200.00
0005435841490	3938	Economy	19300.00
0005435841492	3938	Economy	19300.00
0005435904913	3938	Economy	19300.00
0005435853666	3938	Economy	19300.00
0005435841491	3938	Economy	19300.00
0005435904909	3938	Economy	19300.00
0005435853665	3938	Economy	19300.00
0005434606916	22079	Economy	21300.00
0005434606902	22079	Economy	21300.00
0005433519571	22079	Economy	19300.00
0005433519574	22079	Economy	19300.00
0005434606928	22079	Economy	19300.00
0005435904730	22079	Economy	19300.00
0005433519573	22079	Economy	19300.00
0005434606915	22079	Economy	19300.00
0005434603023	22079	Economy	19300.00
0005433519572	22079	Economy	19300.00
0005433349139	777	Economy	3700.00
0005433349150	777	Economy	3700.00
0005433349149	777	Economy	3700.00
0005433349138	777	Economy	3700.00
0005435628830	15994	Economy	3700.00
0005435628828	15994	Economy	3700.00
0005435628829	15994	Economy	3700.00
0005435628813	15994	Economy	3700.00
0005435628812	15994	Economy	3700.00
0005433159370	17258	Economy	7100.00
0005434445303	17667	Economy	7100.00
0005434445310	17667	Economy	7100.00
0005435383298	7914	Economy	5400.00
0005435383307	7914	Economy	5400.00
0005435383275	7914	Economy	5400.00
0005435383301	7914	Economy	5400.00
0005435383302	7914	Economy	5400.00
0005435383291	7914	Economy	5400.00
0005435383308	7914	Economy	5400.00
0005435133163	33107	Economy	5900.00
0005435133164	33107	Economy	5400.00
0005435133173	33107	Economy	5400.00
0005435133180	33107	Economy	5400.00
0005435133178	33107	Economy	5400.00
0005435133140	33107	Economy	5400.00
0005435133130	33107	Economy	5400.00
0005435133181	33107	Economy	5400.00
0005435133165	33107	Economy	5400.00
0005435133143	33107	Economy	5400.00
0005435390405	7496	Economy	13800.00
0005435390426	7496	Economy	12500.00
0005435390417	7496	Economy	12500.00
0005435390416	7496	Economy	12500.00
0005435160589	29572	Economy	13800.00
0005435160591	29572	Economy	12500.00
0005435160615	29572	Economy	12500.00
0005435160605	29572	Economy	12500.00
0005435390441	29572	Economy	12500.00
0005435160590	29572	Economy	12500.00
0005435160616	29572	Economy	12500.00
0005432394219	18468	Economy	4900.00
0005432398292	18468	Economy	4900.00
0005432394194	18468	Economy	4900.00
0005432394220	18468	Economy	4900.00
0005435179424	27159	Economy	4900.00
0005435179423	27159	Economy	4900.00
0005432663108	21844	Business	92200.00
0005432664211	21844	Business	92200.00
0005432664201	21844	Business	92200.00
0005432664202	21844	Economy	30700.00
0005432663107	21844	Economy	30700.00
0005432664204	21844	Economy	30700.00
0005432664205	21844	Economy	30700.00
0005432661994	21844	Economy	30700.00
0005432663101	21844	Economy	33800.00
0005432663102	21844	Economy	30700.00
0005432661992	21844	Economy	30700.00
0005432661993	21844	Economy	30700.00
0005432664209	21844	Economy	30700.00
0005432663110	21844	Economy	30700.00
0005432664208	21844	Economy	30700.00
0005432664203	21844	Economy	30700.00
0005432663109	21844	Economy	30700.00
0005432663105	21844	Economy	30700.00
0005432663111	21844	Economy	30700.00
0005432664206	21844	Economy	30700.00
0005432663106	21844	Economy	30700.00
0005432661991	21844	Economy	30700.00
0005432661989	21844	Economy	30700.00
0005432663103	21844	Economy	30700.00
0005432661990	21844	Economy	30700.00
0005432664210	21844	Economy	30700.00
0005432664207	21844	Economy	30700.00
0005432661995	21844	Economy	30700.00
0005432663104	21844	Economy	30700.00
0005435104389	6559	Business	48400.00
0005435104388	6559	Economy	16100.00
0005434505110	22655	Business	48400.00
0005435104171	22655	Business	48400.00
0005434505181	22655	Business	48400.00
0005434505139	22655	Business	48400.00
0005434505107	22655	Business	48400.00
0005435104177	22655	Business	48400.00
0005435104157	22655	Business	48400.00
0005434505126	22655	Business	48400.00
0005434505273	22655	Economy	16100.00
0005434505128	22655	Economy	16100.00
0005434505098	22655	Economy	16100.00
0005435104194	22655	Economy	16100.00
0005434505157	22655	Economy	16100.00
0005435104165	22655	Economy	16100.00
0005434505138	22655	Economy	17800.00
0005434505105	22655	Economy	17800.00
0005435104176	22655	Economy	17800.00
0005434505020	22655	Economy	16100.00
0005435104204	22655	Economy	16100.00
0005435104206	22655	Economy	16100.00
0005435104170	22655	Economy	16100.00
0005435104161	22655	Economy	16100.00
0005434505125	22655	Economy	16100.00
0005435104158	22655	Economy	16100.00
0005434505104	22655	Economy	16100.00
0005434505019	22655	Economy	16100.00
0005434505096	22655	Economy	16100.00
0005434504963	22655	Economy	16100.00
0005435104152	22655	Economy	16100.00
0005434505106	22655	Economy	16100.00
0005434505174	22655	Economy	16100.00
0005434505241	22655	Economy	16100.00
0005434505218	22655	Economy	16100.00
0005434505108	22655	Economy	16100.00
0005434504974	22655	Economy	16100.00
0005435104205	22655	Economy	16100.00
0005434505015	22655	Economy	16100.00
0005434505240	22655	Economy	16100.00
0005434505170	22655	Economy	16100.00
0005435104199	22655	Economy	16100.00
0005434505175	22655	Economy	16100.00
0005434505176	22655	Economy	16100.00
0005434505068	22655	Economy	16100.00
0005435104164	22655	Economy	16100.00
0005435104186	22655	Economy	16100.00
0005435104172	22655	Economy	16100.00
0005434505219	22655	Economy	16100.00
0005435104154	22655	Economy	16100.00
0005434504975	22655	Economy	16100.00
0005434505156	22655	Economy	16100.00
0005435104153	22655	Economy	16100.00
0005434504960	22655	Economy	16100.00
0005434505016	22655	Economy	16100.00
0005434505168	22655	Economy	16100.00
0005433368836	1649	Business	50000.00
0005433368928	1649	Business	50000.00
0005433368888	1649	Business	50000.00
0005433368948	1649	Business	50000.00
0005433368926	1649	Business	50000.00
0005433368795	1649	Business	50000.00
0005433368730	1649	Business	50000.00
0005433368839	1649	Economy	16700.00
0005433368917	1649	Economy	16700.00
0005433368843	1649	Economy	16700.00
0005433368867	1649	Economy	16700.00
0005433368925	1649	Economy	18300.00
0005433368733	1649	Economy	18300.00
0005433368874	1649	Economy	16700.00
0005433368697	1649	Economy	16700.00
0005433368902	1649	Economy	16700.00
0005433368862	1649	Economy	16700.00
0005433368908	1649	Economy	16700.00
0005433368796	1649	Economy	16700.00
0005433368895	1649	Economy	16700.00
0005433368807	1649	Economy	16700.00
0005433368806	1649	Economy	16700.00
0005433368868	1649	Economy	16700.00
0005433368896	1649	Economy	16700.00
0005433368881	1649	Economy	16700.00
0005433368861	1649	Economy	16700.00
0005433368947	1649	Economy	16700.00
0005433368808	1649	Economy	16700.00
0005433368738	1649	Economy	16700.00
0005433368835	1649	Economy	16700.00
0005433368816	1649	Economy	16700.00
0005433368899	1649	Economy	16700.00
0005433368875	1649	Economy	16700.00
0005433368837	1649	Economy	16700.00
0005433368718	1649	Economy	16700.00
0005433368714	1649	Economy	16700.00
0005433368817	1649	Economy	16700.00
0005433368734	1649	Economy	16700.00
0005433368933	1649	Economy	16700.00
0005433368929	1649	Economy	16700.00
0005433368794	1649	Economy	16700.00
0005433368911	1649	Economy	16700.00
0005433368927	1649	Economy	16700.00
0005435654161	21712	Business	50000.00
0005435654396	21712	Business	50000.00
0005435654061	21712	Business	50000.00
0005435654397	21712	Business	50000.00
0005435654330	21712	Business	50000.00
0005435654377	21712	Business	50000.00
0005435654331	21712	Economy	16700.00
0005435654134	21712	Economy	16700.00
0005435654335	21712	Economy	16700.00
0005435654239	21712	Economy	16700.00
0005435654281	21712	Economy	18300.00
0005435654204	21712	Economy	18300.00
0005435654205	21712	Economy	16700.00
0005435654276	21712	Economy	16700.00
0005435654372	21712	Economy	16700.00
0005435654311	21712	Economy	16700.00
0005435654143	21712	Economy	16700.00
0005435654373	21712	Economy	16700.00
0005435654213	21712	Economy	16700.00
0005435654165	21712	Economy	16700.00
0005435654043	21712	Economy	16700.00
0005435654153	21712	Economy	16700.00
0005435654135	21712	Economy	16700.00
0005435654312	21712	Economy	16700.00
0005435654163	21712	Economy	16700.00
0005435654180	21712	Economy	16700.00
0005435654269	21712	Economy	16700.00
0005435654022	21712	Economy	16700.00
0005435654023	21712	Economy	16700.00
0005435654238	21712	Economy	16700.00
0005435654249	21712	Economy	16700.00
0005435654154	21712	Economy	16700.00
0005435654131	21712	Economy	16700.00
0005435654233	21712	Economy	16700.00
0005435654280	21712	Economy	16700.00
0005435654136	21712	Economy	16700.00
0005435654263	21712	Economy	16700.00
0005435654303	21712	Economy	16700.00
0005435654345	21712	Economy	16700.00
0005435654376	21712	Economy	16700.00
0005435654211	21712	Economy	16700.00
0005435654159	21712	Economy	16700.00
0005435654212	21712	Economy	16700.00
0005435654191	21712	Economy	16700.00
0005435654264	21712	Economy	16700.00
0005435654063	21712	Economy	16700.00
0005435654058	21712	Economy	16700.00
0005435654275	21712	Economy	16700.00
0005435654062	21712	Economy	16700.00
0005435654170	21712	Economy	16700.00
0005435654262	21712	Economy	16700.00
0005435654340	21712	Economy	16700.00
0005435654339	21712	Economy	16700.00
0005435654160	21712	Economy	16700.00
0005435627130	23783	Economy	11200.00
0005433987195	25640	Business	21500.00
0005433987265	25640	Business	21500.00
0005433987278	25640	Business	21500.00
0005433987022	25640	Business	21500.00
0005433986882	25640	Business	21500.00
0005433986930	25640	Business	21500.00
0005433987170	25640	Business	21500.00
0005433987304	25640	Business	21500.00
0005433986979	25640	Business	21500.00
0005435788840	25640	Economy	7200.00
0005435788839	25640	Economy	7200.00
0005433987153	25640	Economy	7200.00
0005433987226	25640	Economy	7200.00
0005433987145	25640	Economy	7900.00
0005433987081	25640	Economy	7900.00
0005433987343	25640	Economy	7900.00
0005433986980	25640	Economy	7200.00
0005433987069	25640	Economy	7200.00
0005433987154	25640	Economy	7200.00
0005433987342	25640	Economy	7200.00
0005433987119	25640	Economy	7200.00
0005433987277	25640	Economy	7200.00
0005433987303	25640	Economy	7200.00
0005433987140	25640	Economy	7200.00
0005433987341	25640	Economy	7200.00
0005433987151	25640	Economy	7200.00
0005433987184	25640	Economy	7200.00
0005433987128	25640	Economy	7200.00
0005433987179	25640	Economy	7200.00
0005433987264	25640	Economy	7200.00
0005433987054	25640	Economy	7200.00
0005433987055	25640	Economy	7200.00
0005433987364	25640	Economy	7200.00
0005433987232	25640	Economy	7200.00
0005433987205	25640	Economy	7200.00
0005433987335	25640	Economy	7200.00
0005433987021	25640	Economy	7200.00
0005433987227	25640	Economy	7200.00
0005433987222	25640	Economy	7200.00
0005433987129	25640	Economy	7200.00
0005433987144	25640	Economy	7200.00
0005433987338	25640	Economy	7200.00
0005435788841	25640	Economy	7200.00
0005435720852	21246	Economy	9400.00
0005435720855	21246	Economy	9400.00
0005435720856	21246	Economy	9400.00
0005435720849	21246	Economy	9400.00
0005434190458	9016	Economy	23600.00
0005434512260	9016	Economy	23600.00
0005434516141	9016	Economy	23600.00
0005434190456	9016	Economy	23600.00
0005434190457	9016	Economy	23600.00
0005434512261	9016	Economy	23600.00
0005434190450	9016	Economy	23600.00
0005432667509	17857	Business	18000.00
0005432663086	17857	Business	18000.00
0005432664200	17857	Business	18000.00
0005432655881	17857	Business	18000.00
0005432655853	17857	Business	18000.00
0005432655806	17857	Economy	6000.00
0005432660875	17857	Economy	6000.00
0005432655851	17857	Economy	6600.00
0005432655868	17857	Economy	6000.00
0005432657525	17857	Economy	6000.00
0005432663099	17857	Economy	6000.00
0005432663087	17857	Economy	6000.00
0005432666438	17857	Economy	6000.00
0005432655807	17857	Economy	6000.00
0005432657526	17857	Economy	6000.00
0005432663088	17857	Economy	6000.00
0005432664199	17857	Economy	6000.00
0005432655856	17857	Economy	6000.00
0005432664193	17857	Economy	6000.00
0005432655823	17857	Economy	6000.00
0005432660876	17857	Economy	6000.00
0005432655809	17857	Economy	6000.00
0005432655855	17857	Economy	6000.00
0005432655861	17857	Economy	6000.00
0005432659764	17857	Economy	6000.00
0005432664198	17857	Economy	6000.00
0005432661975	17857	Economy	6000.00
0005432664194	17857	Economy	6000.00
0005432658651	17857	Economy	6000.00
0005432660880	17857	Economy	6000.00
0005432655808	17857	Economy	6000.00
0005432655827	17857	Economy	6000.00
0005432655867	17857	Economy	6000.00
0005432659768	17857	Economy	6000.00
0005432666437	17857	Economy	6000.00
0005432655835	17857	Economy	6000.00
0005432660878	17857	Economy	6000.00
0005432655886	17857	Economy	6000.00
0005432660879	17857	Economy	6000.00
0005432665327	17857	Economy	6000.00
0005434151786	26321	Business	18000.00
0005432869694	26321	Economy	6000.00
0005432869693	26321	Economy	6000.00
0005434151793	26321	Economy	6000.00
0005432905293	3114	Economy	5400.00
0005432905280	3114	Economy	5400.00
0005432905294	3114	Economy	5400.00
0005432905281	3114	Economy	5400.00
0005432848908	3114	Economy	5400.00
0005432848895	3114	Economy	5400.00
0005432848907	3114	Economy	5400.00
0005432905272	3114	Economy	5400.00
0005432330063	3114	Economy	5400.00
0005432905271	3114	Economy	5400.00
0005432848896	3114	Economy	5400.00
0005432848909	3114	Economy	5400.00
0005432329898	31117	Business	16100.00
0005432329675	31117	Business	16100.00
0005433439048	31117	Business	16100.00
0005432329982	31117	Business	16100.00
0005432329961	31117	Business	16100.00
0005432329868	31117	Business	16100.00
0005432329858	31117	Economy	5400.00
0005432329788	31117	Economy	5400.00
0005433439047	31117	Economy	5400.00
0005432329910	31117	Economy	5400.00
0005432329972	31117	Economy	5400.00
0005432329872	31117	Economy	5900.00
0005432330002	31117	Economy	5900.00
0005432330017	31117	Economy	5400.00
0005432329764	31117	Economy	5400.00
0005432329862	31117	Economy	5400.00
0005432329918	31117	Economy	5400.00
0005432329912	31117	Economy	5400.00
0005432329905	31117	Economy	5400.00
0005433439059	31117	Economy	5400.00
0005432329869	31117	Economy	5400.00
0005432329983	31117	Economy	5400.00
0005432329911	31117	Economy	5400.00
0005432329813	31117	Economy	5400.00
0005432329919	31117	Economy	5400.00
0005433439033	31117	Economy	5400.00
0005432329843	31117	Economy	5400.00
0005432329765	31117	Economy	5400.00
0005432329738	31117	Economy	5400.00
0005432329755	31117	Economy	5400.00
0005432329657	31117	Economy	5400.00
0005432329950	31117	Economy	5400.00
0005432329819	31117	Economy	5400.00
0005432329859	31117	Economy	5400.00
0005432329707	31117	Economy	5400.00
0005432329804	31117	Economy	5400.00
0005432329757	31117	Economy	5400.00
0005432329881	31117	Economy	5400.00
0005432330003	31117	Economy	5400.00
0005432329863	31117	Economy	5400.00
0005432329962	31117	Economy	5400.00
0005432329803	31117	Economy	5400.00
0005432329861	31117	Economy	5400.00
0005432329817	31117	Economy	5400.00
0005432329963	31117	Economy	5400.00
0005432330018	31117	Economy	5400.00
0005432329871	31117	Economy	5400.00
0005432329756	31117	Economy	5400.00
0005433439081	31117	Economy	5400.00
0005432329865	31117	Economy	5400.00
0005435488413	6217	Business	124600.00
0005435297260	6217	Business	124600.00
0005435488368	6217	Economy	41500.00
0005435488433	6217	Economy	41500.00
0005435488445	6217	Economy	41500.00
0005435297259	6217	Economy	41500.00
0005435488465	6217	Economy	41500.00
0005435488456	6217	Economy	45700.00
0005435488375	6217	Economy	41500.00
0005435488458	6217	Economy	41500.00
0005435297247	6217	Economy	41500.00
0005435488412	6217	Economy	41500.00
0005435488373	6217	Economy	41500.00
0005435297249	6217	Economy	41500.00
0005435488449	6217	Economy	41500.00
0005435488457	6217	Economy	41500.00
0005435297237	6217	Economy	41500.00
0005435297236	6217	Economy	41500.00
0005435488320	6217	Economy	41500.00
0005435488359	6217	Economy	41500.00
0005435297248	6217	Economy	41500.00
0005435488350	6217	Economy	41500.00
0005435297235	6217	Economy	41500.00
0005435297234	6217	Economy	41500.00
0005434310114	19539	Business	124600.00
0005434310125	19539	Business	124600.00
0005435999654	19539	Business	124600.00
0005435999754	19539	Economy	41500.00
0005435999685	19539	Economy	41500.00
0005435999633	19539	Economy	41500.00
0005434310067	19539	Economy	41500.00
0005435999762	19539	Economy	41500.00
0005435999757	19539	Economy	41500.00
0005434310077	19539	Economy	41500.00
0005434310066	19539	Economy	41500.00
0005435999729	19539	Economy	41500.00
0005435999821	19539	Economy	41500.00
0005435999771	19539	Economy	41500.00
0005435999674	19539	Economy	45700.00
0005435999806	19539	Economy	45700.00
0005435999671	19539	Economy	41500.00
0005435999638	19539	Economy	41500.00
0005435999756	19539	Economy	41500.00
0005435999693	19539	Economy	41500.00
0005434310134	19539	Economy	41500.00
0005435999743	19539	Economy	41500.00
0005435999813	19539	Economy	41500.00
0005435999767	19539	Economy	41500.00
0005435999815	19539	Economy	41500.00
0005435999744	19539	Economy	41500.00
0005435999768	19539	Economy	41500.00
0005435999755	19539	Economy	41500.00
0005435999814	19539	Economy	41500.00
0005434310088	19539	Economy	41500.00
0005435999596	19539	Economy	41500.00
0005434310138	19539	Economy	41500.00
0005434310133	19539	Economy	41500.00
0005435999752	19539	Economy	41500.00
0005433186348	1583	Business	86000.00
0005433186342	1583	Economy	28700.00
0005433186347	1583	Economy	28700.00
0005433186346	1583	Economy	28700.00
0005433186355	1583	Economy	28700.00
0005433186350	1583	Economy	28700.00
0005435529806	20887	Business	86000.00
0005434566273	20887	Business	86000.00
0005435529769	20887	Business	86000.00
0005435529734	20887	Business	86000.00
0005435502801	20887	Business	86000.00
0005435529750	20887	Business	86000.00
0005435529832	20887	Economy	28700.00
0005435545946	20887	Economy	28700.00
0005435529817	20887	Economy	28700.00
0005435529751	20887	Economy	28700.00
0005435502853	20887	Economy	28700.00
0005435529827	20887	Economy	31500.00
0005435502868	20887	Economy	31500.00
0005435502886	20887	Economy	28700.00
0005435545932	20887	Economy	28700.00
0005435529805	20887	Economy	28700.00
0005434566298	20887	Economy	28700.00
0005434566253	20887	Economy	28700.00
0005435529856	20887	Economy	28700.00
0005435529770	20887	Economy	28700.00
0005434566267	20887	Economy	28700.00
0005435545906	20887	Economy	28700.00
0005435545951	20887	Economy	28700.00
0005435529761	20887	Economy	28700.00
0005435502854	20887	Economy	28700.00
0005435502832	20887	Economy	28700.00
0005435529833	20887	Economy	28700.00
0005434566299	20887	Economy	28700.00
0005435502904	20887	Economy	28700.00
0005434566246	20887	Economy	28700.00
0005435502793	20887	Economy	28700.00
0005435529838	20887	Economy	28700.00
0005435529778	20887	Economy	28700.00
0005435545931	20887	Economy	28700.00
0005435529784	20887	Economy	28700.00
0005435529735	20887	Economy	28700.00
0005435529807	20887	Economy	28700.00
0005435529760	20887	Economy	28700.00
0005435502915	20887	Economy	28700.00
0005435529816	20887	Economy	28700.00
0005434230045	3876	Economy	19700.00
0005435931709	3876	Economy	19700.00
0005435931695	3876	Economy	19700.00
0005435142998	21899	Economy	19700.00
0005435142989	21899	Economy	19700.00
0005435153916	21899	Economy	19700.00
0005435142988	21899	Economy	19700.00
0005435142999	21899	Economy	19700.00
0005435143000	21899	Economy	19700.00
0005435225794	7220	Economy	14300.00
0005435225789	7220	Economy	13000.00
0005435225782	7220	Economy	13000.00
0005435225764	7220	Economy	13000.00
0005435225780	7220	Economy	13000.00
0005432629296	7220	Economy	13000.00
0005435225783	7220	Economy	13000.00
0005435225804	7220	Economy	13000.00
0005435225784	7220	Economy	13000.00
0005432629264	28116	Economy	14300.00
0005432629254	28116	Economy	13000.00
0005432629248	28116	Economy	13000.00
0005432629228	28116	Economy	13000.00
0005432629256	28116	Economy	13000.00
0005432629251	28116	Economy	13000.00
0005432629253	28116	Economy	13000.00
0005432629274	28116	Economy	13000.00
0005432629252	28116	Economy	13000.00
0005432629270	28116	Economy	13000.00
0005432629227	28116	Economy	13000.00
0005432629257	28116	Economy	13000.00
0005434268035	8760	Economy	10500.00
0005435960162	15222	Economy	10500.00
0005435960141	15222	Economy	10500.00
0005432873487	1165	Business	115000.00
0005432873468	1165	Economy	38300.00
0005432873488	1165	Economy	38300.00
0005432675567	17461	Business	115000.00
0005432675560	17461	Business	115000.00
0005432693695	17461	Business	115000.00
0005432677665	17461	Business	115000.00
0005432675561	17461	Business	115000.00
0005432693697	17461	Business	115000.00
0005432675507	17461	Business	115000.00
0005432675549	17461	Business	115000.00
0005432693798	17461	Business	115000.00
0005432693827	17461	Economy	38300.00
0005432693767	17461	Economy	38300.00
0005432693893	17461	Economy	38300.00
0005432675483	17461	Economy	38300.00
0005432675566	17461	Economy	38300.00
0005432693815	17461	Economy	38300.00
0005432693866	17461	Economy	42200.00
0005432675484	17461	Economy	42200.00
0005432693813	17461	Economy	42200.00
0005432693965	17461	Economy	38300.00
0005432675548	17461	Economy	38300.00
0005432675508	17461	Economy	38300.00
0005432675559	17461	Economy	38300.00
0005432693933	17461	Economy	38300.00
0005432693846	17461	Economy	38300.00
0005432693892	17461	Economy	38300.00
0005432677657	17461	Economy	38300.00
0005432693737	17461	Economy	38300.00
0005432675541	17461	Economy	38300.00
0005432693895	17461	Economy	38300.00
0005432693847	17461	Economy	38300.00
0005432693799	17461	Economy	38300.00
0005432693867	17461	Economy	38300.00
0005432677688	17461	Economy	38300.00
0005432677658	17461	Economy	38300.00
0005432675568	17461	Economy	38300.00
0005432675547	17461	Economy	38300.00
0005432693814	17461	Economy	38300.00
0005432675509	17461	Economy	38300.00
0005432693896	17461	Economy	38300.00
0005432693696	17461	Economy	38300.00
0005433157003	1128	Economy	15200.00
0005433156989	1128	Economy	13900.00
0005434435564	17311	Economy	15200.00
0005434435525	17311	Economy	15200.00
0005434435621	17311	Economy	13900.00
0005434435583	17311	Economy	13900.00
0005434435536	17311	Economy	13900.00
0005434435582	17311	Economy	13900.00
0005434435613	17311	Economy	13900.00
0005435928289	4054	Economy	8200.00
0005435928275	4054	Economy	7500.00
0005435928263	4054	Economy	7500.00
0005435928276	4054	Economy	7500.00
0005435928283	4054	Economy	7500.00
0005435928278	4054	Economy	7500.00
0005435087005	24412	Economy	8200.00
0005435087037	24412	Economy	8200.00
0005435087011	24412	Economy	7500.00
0005435087027	24412	Economy	7500.00
0005435087048	24412	Economy	7500.00
0005435087054	24412	Economy	7500.00
0005435087039	24412	Economy	7500.00
0005435087040	24412	Economy	7500.00
0005435087038	24412	Economy	7500.00
0005435087047	24412	Economy	7500.00
0005435551709	11057	Business	144300.00
0005435551752	11057	Business	144300.00
0005435098598	11057	Business	144300.00
0005435551719	11057	Business	144300.00
0005435551734	11057	Business	144300.00
0005435551753	11057	Economy	52900.00
0005435654509	11057	Economy	48100.00
0005435654512	11057	Economy	48100.00
0005435654504	11057	Economy	48100.00
0005435654508	11057	Economy	48100.00
0005435098607	11057	Economy	48100.00
0005435654507	11057	Economy	48100.00
0005435551735	11057	Economy	48100.00
0005435098599	11057	Economy	48100.00
0005435551741	11057	Economy	48100.00
0005435551720	11057	Economy	48100.00
0005435551730	11057	Economy	48100.00
0005435551737	11057	Economy	48100.00
0005435654505	11057	Economy	48100.00
0005435551738	11057	Economy	48100.00
0005435654506	11057	Economy	48100.00
0005435551751	11057	Economy	48100.00
0005435551736	11057	Economy	48100.00
0005435551729	11057	Economy	48100.00
0005435551759	11057	Economy	48100.00
0005435098606	11057	Economy	48100.00
0005435654510	11057	Economy	48100.00
0005435654511	11057	Economy	48100.00
0005435551745	11057	Economy	48100.00
0005435098604	11057	Economy	48100.00
0005435551743	11057	Economy	48100.00
0005435098605	11057	Economy	48100.00
0005435098603	11057	Economy	48100.00
0005435098609	11057	Economy	48100.00
0005435551742	11057	Economy	48100.00
0005435551713	11057	Economy	48100.00
0005435098617	17017	Economy	48100.00
0005435654522	17017	Economy	48100.00
0005435654521	17017	Economy	48100.00
0005435654523	17017	Economy	48100.00
0005434964713	18250	Business	203300.00
0005434964617	18250	Business	203300.00
0005434964684	18250	Economy	67800.00
0005434964722	18250	Economy	67800.00
0005434964757	18250	Economy	67800.00
0005434964781	18250	Economy	67800.00
0005434964714	18250	Economy	67800.00
0005434964711	18250	Economy	67800.00
0005434964770	18250	Economy	67800.00
0005434964621	18250	Economy	67800.00
0005434964739	18250	Economy	67800.00
0005434964717	18250	Economy	67800.00
0005434964780	18250	Economy	67800.00
0005434964723	18250	Economy	67800.00
0005434964688	18250	Economy	67800.00
0005434964759	18250	Economy	67800.00
0005434964710	18250	Economy	67800.00
0005434964718	18250	Economy	67800.00
0005434964746	18250	Economy	67800.00
0005434964750	18250	Economy	67800.00
0005434964740	18250	Economy	67800.00
0005434964782	18250	Economy	74500.00
0005434964679	18250	Economy	67800.00
0005434964695	18250	Economy	67800.00
0005434964703	18250	Economy	67800.00
0005434964731	18250	Economy	67800.00
0005434964622	18250	Economy	67800.00
0005434964730	18250	Economy	67800.00
0005434964712	18250	Economy	67800.00
0005434964716	18250	Economy	67800.00
0005433195007	4839	Business	44200.00
0005433194927	4839	Business	44200.00
0005435907622	4839	Economy	16200.00
0005433194944	4839	Economy	14700.00
0005433194951	4839	Economy	14700.00
0005433194943	4839	Economy	14700.00
0005433194973	4839	Economy	14700.00
0005434626236	32915	Business	44200.00
0005434626234	32915	Economy	14700.00
0005434626215	32915	Economy	14700.00
0005434626214	32915	Economy	14700.00
0005434626188	32915	Economy	14700.00
0005434626189	32915	Economy	14700.00
0005434626225	32915	Economy	14700.00
0005434626224	32915	Economy	14700.00
0005435786208	13767	Economy	3400.00
0005435786218	13767	Economy	3400.00
0005435786246	13767	Economy	3100.00
0005435786354	13767	Economy	3100.00
0005435786199	13767	Economy	3100.00
0005435786272	13767	Economy	3100.00
0005435786204	13767	Economy	3100.00
0005435786148	13767	Economy	3100.00
0005435786296	13767	Economy	3100.00
0005435786264	13767	Economy	3100.00
0005435786318	13767	Economy	3100.00
0005435786281	13767	Economy	3100.00
0005435786209	13767	Economy	3100.00
0005435787407	13767	Economy	3100.00
0005435787398	13767	Economy	3100.00
0005435786219	13767	Economy	3100.00
0005435786355	13767	Economy	3100.00
0005435786259	13767	Economy	3100.00
0005435787404	13767	Economy	3100.00
0005435786274	13767	Economy	3100.00
0005435786270	13767	Economy	3100.00
0005435786297	13767	Economy	3100.00
0005435786210	13767	Economy	3100.00
0005435786301	13767	Economy	3100.00
0005435937521	27453	Economy	3100.00
0005435937553	27453	Economy	3100.00
0005435937563	27453	Economy	3100.00
0005435937548	27453	Economy	3100.00
0005435983727	27453	Economy	3100.00
0005435937515	27453	Economy	3100.00
0005435937523	27453	Economy	3100.00
0005435937514	27453	Economy	3100.00
0005435983728	27453	Economy	3100.00
0005435937531	27453	Economy	3100.00
0005435937530	27453	Economy	3100.00
0005434409427	20270	Business	12000.00
0005434409108	20270	Business	12000.00
0005434409460	20270	Business	12000.00
0005434409218	20270	Business	12000.00
0005434409482	20270	Business	12000.00
0005434409479	20270	Business	12000.00
0005434409450	20270	Economy	4000.00
0005434409425	20270	Economy	4000.00
0005434409353	20270	Economy	4000.00
0005434409426	20270	Economy	4000.00
0005434409248	20270	Economy	4400.00
0005434409354	20270	Economy	4400.00
0005434409414	20270	Economy	4400.00
0005434409424	20270	Economy	4400.00
0005434409249	20270	Economy	4000.00
0005434409510	20270	Economy	4000.00
0005434409416	20270	Economy	4000.00
0005434409430	20270	Economy	4000.00
0005434409549	20270	Economy	4000.00
0005434409318	20270	Economy	4000.00
0005434409589	20270	Economy	4000.00
0005434409423	20270	Economy	4000.00
0005434409389	20270	Economy	4000.00
0005434409415	20270	Economy	4000.00
0005434409355	20270	Economy	4000.00
0005434409529	20270	Economy	4000.00
0005434409303	20270	Economy	4000.00
0005434409528	20270	Economy	4000.00
0005434409319	20270	Economy	4000.00
0005434409550	20270	Economy	4000.00
0005434409454	20270	Economy	4000.00
0005434409461	20270	Economy	4000.00
0005434409463	20270	Economy	4000.00
0005434409481	20270	Economy	4000.00
0005434409480	20270	Economy	4000.00
0005434409507	20270	Economy	4000.00
0005434409453	20270	Economy	4000.00
0005434409477	20270	Economy	4000.00
0005434409458	20270	Economy	4000.00
0005434409438	20270	Economy	4000.00
0005434409431	20270	Economy	4000.00
0005434409496	20270	Economy	4000.00
0005434409388	20270	Economy	4000.00
0005434409367	20270	Economy	4000.00
0005434409406	20270	Economy	4000.00
0005434409121	20270	Economy	4000.00
0005434409588	20270	Economy	4000.00
0005434409511	20270	Economy	4000.00
0005434409459	20270	Economy	4000.00
0005434409478	20270	Economy	4000.00
0005434409462	20270	Economy	4000.00
0005434409464	20270	Economy	4000.00
0005435311439	26999	Business	12000.00
0005435311484	26999	Business	12000.00
0005435311440	26999	Economy	4000.00
0005435311382	26999	Economy	4000.00
0005435311483	26999	Economy	4000.00
0005435311485	26999	Economy	4000.00
0005435311454	26999	Economy	4000.00
0005435311486	26999	Economy	4000.00
0005435311487	26999	Economy	4000.00
0005435311457	26999	Economy	4000.00
0005435311455	26999	Economy	4000.00
0005435311527	26999	Economy	4000.00
0005435311381	26999	Economy	4000.00
0005435311495	26999	Economy	4000.00
0005435311488	26999	Economy	4000.00
0005435311419	26999	Economy	4000.00
0005435311456	26999	Economy	4000.00
0005435311470	26999	Economy	4000.00
0005435311494	26999	Economy	4000.00
0005435311493	26999	Economy	4000.00
0005435311464	26999	Economy	4000.00
0005433124451	5706	Business	43300.00
0005433124479	5706	Economy	14400.00
0005435297371	5706	Economy	14400.00
0005433124518	5706	Economy	14400.00
0005435297391	5706	Economy	14400.00
0005433124457	5706	Economy	14400.00
0005435297382	5706	Economy	14400.00
0005433124426	5706	Economy	14400.00
0005433124480	5706	Economy	14400.00
0005433124400	5706	Economy	14400.00
0005433124401	5706	Economy	14400.00
0005433124489	5706	Economy	14400.00
0005433124487	5706	Economy	14400.00
0005433124486	5706	Economy	14400.00
0005433124498	5706	Economy	14400.00
0005435297368	5706	Economy	14400.00
0005433124430	5706	Economy	14400.00
0005433124482	5706	Economy	14400.00
0005433124469	5706	Economy	14400.00
0005435297365	5706	Economy	14400.00
0005433124429	5706	Economy	14400.00
0005433124405	5706	Economy	14400.00
0005435297372	5706	Economy	14400.00
0005433124481	5706	Economy	14400.00
0005434319744	15692	Business	43300.00
0005434319820	15692	Business	43300.00
0005434319712	15692	Economy	14400.00
0005434319794	15692	Economy	14400.00
0005434319778	15692	Economy	14400.00
0005434319829	15692	Economy	14400.00
0005434319795	15692	Economy	14400.00
0005434311278	15692	Economy	15900.00
0005434319755	15692	Economy	15900.00
0005434319756	15692	Economy	15900.00
0005434319735	15692	Economy	14400.00
0005434319796	15692	Economy	14400.00
0005434319699	15692	Economy	14400.00
0005434319821	15692	Economy	14400.00
0005434319734	15692	Economy	14400.00
0005434319780	15692	Economy	14400.00
0005434319701	15692	Economy	14400.00
0005434319729	15692	Economy	14400.00
0005434319793	15692	Economy	14400.00
0005434319746	15692	Economy	14400.00
0005434319757	15692	Economy	14400.00
0005434319786	15692	Economy	14400.00
0005434319787	15692	Economy	14400.00
0005435297402	15692	Economy	14400.00
0005434319797	15692	Economy	14400.00
0005434312377	15692	Economy	14400.00
0005434319733	15692	Economy	14400.00
0005435220376	24985	Economy	17100.00
0005435217768	24985	Economy	15500.00
0005435220373	24985	Economy	15500.00
0005435220370	24985	Economy	15500.00
0005435220372	24985	Economy	15500.00
0005435217770	24985	Economy	15500.00
0005435221530	24985	Economy	15500.00
0005435220371	24985	Economy	15500.00
0005435221531	24985	Economy	15500.00
0005435220377	24985	Economy	15500.00
0005435220378	24985	Economy	15500.00
0005435217769	24985	Economy	15500.00
0005434189293	8981	Economy	27400.00
0005434189326	8981	Economy	24900.00
0005434505326	8981	Economy	24900.00
0005434505325	8981	Economy	24900.00
0005434189325	8981	Economy	24900.00
0005435903225	8981	Economy	24900.00
0005434484507	16616	Economy	27400.00
0005434484538	16616	Economy	24900.00
0005434484540	16616	Economy	24900.00
0005434484537	16616	Economy	24900.00
0005434484506	16616	Economy	24900.00
0005433722424	7638	Business	11100.00
0005433722394	7638	Business	11100.00
0005433722395	7638	Business	11100.00
0005433722358	7638	Business	11100.00
0005433722393	7638	Economy	3700.00
0005433722359	7638	Economy	3700.00
0005433722384	7638	Economy	3700.00
0005433722423	7638	Economy	4100.00
0005435229652	7638	Economy	3700.00
0005435229653	7638	Economy	3700.00
0005433722409	7638	Economy	3700.00
0005433722396	7638	Economy	3700.00
0005433722407	7638	Economy	3700.00
0005435229656	7638	Economy	3700.00
0005433722360	7638	Economy	3700.00
0005433722422	7638	Economy	3700.00
0005433722371	7638	Economy	3700.00
0005433722374	7638	Economy	3700.00
0005433450612	7636	Economy	3700.00
0005432693814	30305	Business	11100.00
0005432693697	30305	Business	11100.00
0005432693767	30305	Business	11100.00
0005433450549	30305	Business	11100.00
0005433450547	30305	Economy	3700.00
0005432693798	30305	Economy	3700.00
0005433450551	30305	Economy	3700.00
0005432693933	30305	Economy	3700.00
0005433450521	30305	Economy	3700.00
0005432693896	30305	Economy	4100.00
0005433450438	30305	Economy	4100.00
0005433450562	30305	Economy	3700.00
0005433450573	30305	Economy	3700.00
0005433450483	30305	Economy	3700.00
0005432693813	30305	Economy	3700.00
0005432693895	30305	Economy	3700.00
0005433450581	30305	Economy	3700.00
0005432693893	30305	Economy	3700.00
0005433450585	30305	Economy	3700.00
0005432693846	30305	Economy	3700.00
0005432693815	30305	Economy	3700.00
0005433450578	30305	Economy	3700.00
0005432693965	30305	Economy	3700.00
0005433450439	30305	Economy	3700.00
0005432693799	30305	Economy	3700.00
0005433450548	30305	Economy	3700.00
0005432693847	30305	Economy	3700.00
0005432693867	30305	Economy	3700.00
0005432693696	30305	Economy	3700.00
0005432693892	30305	Economy	3700.00
0005432693866	30305	Economy	3700.00
0005432693695	30305	Economy	3700.00
0005432693827	30305	Economy	3700.00
0005432693737	30305	Economy	3700.00
0005432721647	30306	Business	11100.00
0005433124480	30306	Business	11100.00
0005433124486	30306	Business	11100.00
0005433124400	30306	Business	11100.00
0005432721579	30306	Business	11100.00
0005435477034	30306	Business	11100.00
0005432721625	30306	Economy	3700.00
0005432721669	30306	Economy	3700.00
0005432721646	30306	Economy	3700.00
0005432721624	30306	Economy	3700.00
0005432721670	30306	Economy	4100.00
0005433124429	30306	Economy	4100.00
0005435477032	30306	Economy	4100.00
0005433124518	30306	Economy	3700.00
0005433722515	30306	Economy	3700.00
0005433124498	30306	Economy	3700.00
0005432721533	30306	Economy	3700.00
0005432721605	30306	Economy	3700.00
0005435477033	30306	Economy	3700.00
0005433124469	30306	Economy	3700.00
0005433124481	30306	Economy	3700.00
0005433124430	30306	Economy	3700.00
0005432721591	30306	Economy	3700.00
0005433124451	30306	Economy	3700.00
0005433124482	30306	Economy	3700.00
0005432721671	30306	Economy	3700.00
0005433124401	30306	Economy	3700.00
0005432721654	30306	Economy	3700.00
0005432721675	30306	Economy	3700.00
0005433124405	30306	Economy	3700.00
0005432721659	30306	Economy	3700.00
0005433124426	30306	Economy	3700.00
0005433124489	30306	Economy	3700.00
0005433124487	30306	Economy	3700.00
0005432721657	30306	Economy	3700.00
0005433124479	30306	Economy	3700.00
0005432721578	30306	Economy	3700.00
0005432721602	30306	Economy	3700.00
0005433124457	30306	Economy	3700.00
0005433193421	1376	Business	70400.00
0005433193427	1376	Business	70400.00
0005433193418	1376	Business	70400.00
0005432928133	1376	Business	70400.00
0005433525364	1376	Economy	23500.00
0005432928139	1376	Economy	25800.00
0005433193423	1376	Economy	23500.00
0005432928132	1376	Economy	23500.00
0005433193422	1376	Economy	23500.00
0005433193396	1376	Economy	23500.00
0005432928123	1376	Economy	23500.00
0005432928117	1376	Economy	23500.00
0005433193374	1376	Economy	23500.00
0005433193397	1376	Economy	23500.00
0005433193419	1376	Economy	23500.00
0005433193415	1376	Economy	23500.00
0005432928138	1376	Economy	23500.00
0005432928118	1376	Economy	23500.00
0005433193403	1376	Economy	23500.00
0005432928124	1376	Economy	23500.00
0005433193414	1376	Economy	23500.00
0005432928140	1376	Economy	23500.00
0005432928127	1376	Economy	23500.00
0005434587304	18542	Business	70400.00
0005433525339	18542	Business	70400.00
0005433525326	18542	Business	70400.00
0005434587334	18542	Business	70400.00
0005433525315	18542	Business	70400.00
0005434515042	18542	Business	70400.00
0005433525335	18542	Economy	23500.00
0005434587308	18542	Economy	23500.00
0005433525318	18542	Economy	23500.00
0005434587303	18542	Economy	23500.00
0005433525336	18542	Economy	25800.00
0005433525288	18542	Economy	23500.00
0005434587302	18542	Economy	23500.00
0005433525298	18542	Economy	23500.00
0005433724907	18542	Economy	23500.00
0005433724933	18542	Economy	23500.00
0005434587309	18542	Economy	23500.00
0005433525337	18542	Economy	23500.00
0005434587245	18542	Economy	23500.00
0005434587267	18542	Economy	23500.00
0005433724934	18542	Economy	23500.00
0005433525287	18542	Economy	23500.00
0005433525327	18542	Economy	23500.00
0005434587224	18542	Economy	23500.00
0005434587213	18542	Economy	23500.00
0005433525332	18542	Economy	23500.00
0005434587246	18542	Economy	23500.00
0005434587305	18542	Economy	23500.00
0005433525297	18542	Economy	23500.00
0005434587285	18542	Economy	23500.00
0005434587319	18542	Economy	23500.00
0005434587238	18542	Economy	23500.00
0005434587237	18542	Economy	23500.00
0005435305074	11461	Economy	4300.00
0005434345298	11461	Economy	4300.00
0005435302323	11461	Economy	4000.00
0005435302334	11461	Economy	4000.00
0005435305063	11461	Economy	4000.00
0005435305055	11461	Economy	4000.00
0005435551771	11461	Economy	4000.00
0005434345222	29798	Economy	4300.00
0005434345252	29798	Economy	4300.00
0005434345043	29798	Economy	4300.00
0005434345152	29798	Economy	4000.00
0005434345198	29798	Economy	4000.00
0005434345160	29798	Economy	4000.00
0005434345122	29798	Economy	4000.00
0005434345171	29798	Economy	4000.00
0005434345133	29798	Economy	4000.00
0005434344949	29798	Economy	4000.00
0005434345128	29798	Economy	4000.00
0005434345161	29798	Economy	4000.00
0005434142716	29798	Economy	4000.00
0005434345200	29798	Economy	4000.00
0005434345049	29798	Economy	4000.00
0005434345227	29798	Economy	4000.00
0005434345167	29798	Economy	4000.00
0005434345107	29798	Economy	4000.00
0005434345092	29798	Economy	4000.00
0005434345077	29798	Economy	4000.00
0005434345201	29798	Economy	4000.00
0005434344936	29798	Economy	4000.00
0005434345140	29798	Economy	4000.00
0005434345153	29798	Economy	4000.00
0005434345076	29798	Economy	4000.00
0005434345173	29798	Economy	4000.00
0005434345042	29798	Economy	4000.00
0005434345105	29798	Economy	4000.00
0005434345197	29798	Economy	4000.00
0005434345013	29798	Economy	4000.00
0005434345151	29798	Economy	4000.00
0005434345012	29798	Economy	4000.00
0005434345172	29798	Economy	4000.00
0005434345093	29798	Economy	4000.00
0005434345164	29798	Economy	4000.00
0005434142715	29798	Economy	4000.00
0005434345199	29798	Economy	4000.00
0005433416114	1286	Business	199800.00
0005433416126	1286	Economy	66600.00
0005433416105	1286	Economy	66600.00
0005433416115	1286	Economy	66600.00
0005433416125	1286	Economy	66600.00
0005433416118	1286	Economy	66600.00
0005433416120	1286	Economy	66600.00
0005433416031	1286	Economy	66600.00
0005433416117	1286	Economy	66600.00
0005433416032	1286	Economy	66600.00
0005433416106	1286	Economy	66600.00
0005433416113	1286	Economy	66600.00
0005433416033	1286	Economy	66600.00
0005433416116	1286	Economy	66600.00
0005435825369	18006	Business	199800.00
0005435825378	18006	Business	199800.00
0005435825377	18006	Business	199800.00
0005435825326	18006	Business	199800.00
0005435825336	18006	Business	199800.00
0005435825363	18006	Business	199800.00
0005435825360	18006	Economy	66600.00
0005435825413	18006	Economy	66600.00
0005435825406	18006	Economy	66600.00
0005435825382	18006	Economy	66600.00
0005435825393	18006	Economy	66600.00
0005435825370	18006	Economy	66600.00
0005435825285	18006	Economy	66600.00
0005435825337	18006	Economy	66600.00
0005435825320	18006	Economy	66600.00
0005435825284	18006	Economy	66600.00
0005434460550	17517	Economy	14800.00
0005434460559	17517	Economy	13500.00
0005434462841	17517	Economy	13500.00
0005434462840	17517	Economy	13500.00
0005434462853	17517	Economy	13500.00
0005434460552	17517	Economy	13500.00
0005434462850	17517	Economy	13500.00
0005434460557	17517	Economy	13500.00
0005434460551	17517	Economy	13500.00
0005434462842	17517	Economy	13500.00
0005434462848	17517	Economy	13500.00
0005434462847	17517	Economy	13500.00
0005434462844	17517	Economy	13500.00
0005434460558	17517	Economy	13500.00
0005434460564	17517	Economy	13500.00
0005434462836	17517	Economy	13500.00
0005434460547	17517	Economy	13500.00
0005434462852	17517	Economy	13500.00
0005434460563	17517	Economy	13500.00
0005435243624	5639	Business	27800.00
0005435243497	5639	Business	27800.00
0005435243593	5639	Business	27800.00
0005432785370	5639	Business	27800.00
0005435243541	5639	Economy	9300.00
0005435476931	5639	Economy	9300.00
0005435243476	5639	Economy	9300.00
0005435243530	5639	Economy	9300.00
0005435243525	5639	Economy	9300.00
0005435243540	5639	Economy	9300.00
0005435243501	5639	Economy	10200.00
0005435243513	5639	Economy	10200.00
0005435243594	5639	Economy	10200.00
0005432785369	5639	Economy	9300.00
0005435243473	5639	Economy	9300.00
0005435243500	5639	Economy	9300.00
0005435243588	5639	Economy	9300.00
0005435243582	5639	Economy	9300.00
0005435476964	5639	Economy	9300.00
0005435243474	5639	Economy	9300.00
0005435243514	5639	Economy	9300.00
0005435243595	5639	Economy	9300.00
0005435243581	5639	Economy	9300.00
0005435243554	5639	Economy	9300.00
0005435476981	5639	Economy	9300.00
0005435243610	5639	Economy	9300.00
0005435476969	5639	Economy	9300.00
0005435243631	5639	Economy	9300.00
0005435243632	5639	Economy	9300.00
0005435243526	5639	Economy	9300.00
0005435476970	5639	Economy	9300.00
0005435243529	5639	Economy	9300.00
0005435476910	5639	Economy	9300.00
0005435243638	5639	Economy	9300.00
0005435476965	5639	Economy	9300.00
0005435243577	5639	Economy	9300.00
0005435476909	5639	Economy	9300.00
0005435950000	15373	Business	27800.00
0005432785189	15373	Business	27800.00
0005432785102	15373	Business	27800.00
0005432785288	15373	Business	27800.00
0005432785090	15373	Business	27800.00
0005432785166	15373	Business	27800.00
0005432785221	15373	Business	27800.00
0005432785147	15373	Business	27800.00
0005432784949	15373	Business	27800.00
0005432785253	15373	Economy	9300.00
0005432785126	15373	Economy	9300.00
0005435950013	15373	Economy	9300.00
0005432785089	15373	Economy	9300.00
0005435949989	15373	Economy	9300.00
0005432785023	15373	Economy	9300.00
0005432785146	15373	Economy	9300.00
0005432785127	15373	Economy	10200.00
0005432785139	15373	Economy	10200.00
0005432785279	15373	Economy	10200.00
0005432785258	15373	Economy	10200.00
0005432785107	15373	Economy	9300.00
0005432785191	15373	Economy	9300.00
0005435949988	15373	Economy	9300.00
0005432785204	15373	Economy	9300.00
0005432784982	15373	Economy	9300.00
0005432785222	15373	Economy	9300.00
0005432784948	15373	Economy	9300.00
0005432785264	15373	Economy	9300.00
0005432785217	15373	Economy	9300.00
0005432785005	15373	Economy	9300.00
0005432785007	15373	Economy	9300.00
0005432785006	15373	Economy	9300.00
0005432785004	15373	Economy	9300.00
0005432785020	15373	Economy	9300.00
0005432785116	15373	Economy	9300.00
0005432785208	15373	Economy	9300.00
0005432785025	15373	Economy	9300.00
0005435950022	15373	Economy	9300.00
0005432785115	15373	Economy	9300.00
0005432785305	15373	Economy	9300.00
0005432785287	15373	Economy	9300.00
0005432785145	15373	Economy	9300.00
0005432785265	15373	Economy	9300.00
0005432785205	15373	Economy	9300.00
0005432785148	15373	Economy	9300.00
0005432785262	15373	Economy	9300.00
0005432785113	15373	Economy	9300.00
0005435949999	15373	Economy	9300.00
0005432785112	15373	Economy	9300.00
0005432785128	15373	Economy	9300.00
0005432785229	15373	Economy	9300.00
0005432784940	15373	Economy	9300.00
0005432785017	15373	Economy	9300.00
0005435950014	15373	Economy	9300.00
0005432785194	15373	Economy	9300.00
0005432785101	15373	Economy	9300.00
0005432785133	15373	Economy	9300.00
0005432785328	15373	Economy	9300.00
0005432785057	15373	Economy	9300.00
0005432784981	15373	Economy	9300.00
0005432785008	15373	Economy	9300.00
0005432785149	15373	Economy	9300.00
0005435950021	15373	Economy	9300.00
0005432785021	15373	Economy	9300.00
0005432785306	15373	Economy	9300.00
0005432785234	15373	Economy	9300.00
0005435949984	15373	Economy	9300.00
0005432785129	15373	Economy	9300.00
0005435950007	15373	Economy	9300.00
0005432785263	15373	Economy	9300.00
0005432785022	15373	Economy	9300.00
0005432785087	15373	Economy	9300.00
0005432785252	15373	Economy	9300.00
0005432785334	15373	Economy	9300.00
0005435851176	4395	Economy	7000.00
0005435851173	4395	Economy	6300.00
0005435851152	4395	Economy	6300.00
0005435851146	4395	Economy	6300.00
0005435851139	4395	Economy	6300.00
0005435851137	4395	Economy	6300.00
0005435851172	4395	Economy	6300.00
0005432848684	28890	Economy	7000.00
0005434461694	28890	Economy	6300.00
0005432848711	28890	Economy	6300.00
0005432848700	28890	Economy	6300.00
0005434463989	28890	Economy	6300.00
0005432848701	28890	Economy	6300.00
0005434461707	28890	Economy	6300.00
0005434463991	28890	Economy	6300.00
0005434463988	28890	Economy	6300.00
0005432848710	28890	Economy	6300.00
0005432848702	28890	Economy	6300.00
0005434463990	28890	Economy	6300.00
0005432848689	28890	Economy	6300.00
0005432848703	28890	Economy	6300.00
0005432848663	28890	Economy	6300.00
0005432848699	28890	Economy	6300.00
0005435257518	6287	Business	11900.00
0005435257513	6287	Economy	4000.00
0005435311564	6287	Economy	4000.00
0005435257423	6287	Economy	4000.00
0005435257491	6287	Economy	4000.00
0005435257503	6287	Economy	4000.00
0005435257528	6287	Economy	4000.00
0005435311563	6287	Economy	4000.00
0005435257507	6287	Economy	4000.00
0005435311565	6287	Economy	4000.00
0005435257527	6287	Economy	4000.00
0005435257529	6287	Economy	4000.00
0005435257515	6287	Economy	4000.00
0005435257514	6287	Economy	4000.00
0005435257519	6287	Economy	4000.00
0005435311566	6287	Economy	4000.00
0005433497766	20412	Business	11900.00
0005434926763	20412	Business	11900.00
0005433497734	20412	Business	11900.00
0005434926807	20412	Business	11900.00
0005434926523	20412	Business	11900.00
0005434444143	20412	Business	11900.00
0005433497872	20412	Business	11900.00
0005434926749	20412	Business	11900.00
0005433497803	20412	Business	11900.00
0005434926569	20412	Business	11900.00
0005434926690	20412	Economy	4000.00
0005434926762	20412	Economy	4000.00
0005433497877	20412	Economy	4000.00
0005434926776	20412	Economy	4000.00
0005434926692	20412	Economy	4000.00
0005434926502	20412	Economy	4000.00
0005434926555	20412	Economy	4000.00
0005434926438	20412	Economy	4400.00
0005434444140	20412	Economy	4400.00
0005434926677	20412	Economy	4400.00
0005434926681	20412	Economy	4000.00
0005434444145	20412	Economy	4000.00
0005434926728	20412	Economy	4000.00
0005434926667	20412	Economy	4000.00
0005434926752	20412	Economy	4000.00
0005433497856	20412	Economy	4000.00
0005434926668	20412	Economy	4000.00
0005434926701	20412	Economy	4000.00
0005433497804	20412	Economy	4000.00
0005434926729	20412	Economy	4000.00
0005434926678	20412	Economy	4000.00
0005434926646	20412	Economy	4000.00
0005434926719	20412	Economy	4000.00
0005433497808	20412	Economy	4000.00
0005434926647	20412	Economy	4000.00
0005433497783	20412	Economy	4000.00
0005434926636	20412	Economy	4000.00
0005433497802	20412	Economy	4000.00
0005434926682	20412	Economy	4000.00
0005434926686	20412	Economy	4000.00
0005433497750	20412	Economy	4000.00
0005433497829	20412	Economy	4000.00
0005434926659	20412	Economy	4000.00
0005434926622	20412	Economy	4000.00
0005434444041	20412	Economy	4000.00
0005434926772	20412	Economy	4000.00
0005434926655	20412	Economy	4000.00
0005433497814	20412	Economy	4000.00
0005434926572	20412	Economy	4000.00
0005434926673	20412	Economy	4000.00
0005434926656	20412	Economy	4000.00
0005433497861	20412	Economy	4000.00
0005434926734	20412	Economy	4000.00
0005434926771	20412	Economy	4000.00
0005434926482	20412	Economy	4000.00
0005434926499	20412	Economy	4000.00
0005433497878	20412	Economy	4000.00
0005434926761	20412	Economy	4000.00
0005434926500	20412	Economy	4000.00
0005434926662	20412	Economy	4000.00
0005434926672	20412	Economy	4000.00
0005434444144	20412	Economy	4000.00
0005434926669	20412	Economy	4000.00
0005433497784	20412	Economy	4000.00
0005434926657	20412	Economy	4000.00
0005434926621	20412	Economy	4000.00
0005434444066	20412	Economy	4000.00
0005434926700	20412	Economy	4000.00
0005433497770	20412	Economy	4000.00
0005433497828	20412	Economy	4000.00
0005434926573	20412	Economy	4000.00
0005433497805	20412	Economy	4000.00
0005433497855	20412	Economy	4000.00
0005433497834	20412	Economy	4000.00
0005432785277	12210	Business	41200.00
0005432785118	12210	Business	41200.00
0005432785233	12210	Business	41200.00
0005432785158	12210	Business	41200.00
0005432785311	12210	Economy	13700.00
0005432785313	12210	Economy	13700.00
0005432785249	12210	Economy	13700.00
0005432785219	12210	Economy	13700.00
0005432785212	12210	Economy	13700.00
0005432785117	12210	Economy	13700.00
0005432785346	12210	Economy	13700.00
0005432785314	12210	Economy	13700.00
0005432785218	12210	Economy	13700.00
0005432785156	12210	Economy	13700.00
0005432785241	12210	Economy	13700.00
0005432785235	12210	Economy	13700.00
0005432785161	12210	Economy	13700.00
0005432785150	12210	Economy	13700.00
0005432785190	12210	Economy	13700.00
0005432785075	12210	Economy	13700.00
0005432785245	12210	Economy	13700.00
0005432785220	12210	Economy	13700.00
0005432785196	12210	Economy	13700.00
0005432785155	12210	Economy	13700.00
0005432785312	12210	Economy	13700.00
0005432785213	12210	Economy	13700.00
0005432785244	12210	Economy	13700.00
0005432785302	12210	Economy	13700.00
0005432785130	12210	Economy	13700.00
0005432785278	12210	Economy	13700.00
0005432785131	12210	Economy	13700.00
0005432785167	12210	Economy	13700.00
0005432785215	12210	Economy	13700.00
0005432785214	12210	Economy	13700.00
0005432785266	12210	Economy	13700.00
0005432785267	12210	Economy	13700.00
0005432785160	12210	Economy	13700.00
0005432785242	12210	Economy	13700.00
0005432785367	15422	Business	41200.00
0005435243505	15422	Business	41200.00
0005435243560	15422	Economy	13700.00
0005435243490	15422	Economy	13700.00
0005435243382	15422	Economy	15100.00
0005435243402	15422	Economy	13700.00
0005435243545	15422	Economy	13700.00
0005435243392	15422	Economy	13700.00
0005435243401	15422	Economy	13700.00
0005435243543	15422	Economy	13700.00
0005435243393	15422	Economy	13700.00
0005435243506	15422	Economy	13700.00
0005435243550	15422	Economy	13700.00
0005435243489	15422	Economy	13700.00
0005432785368	15422	Economy	13700.00
0005435243604	15422	Economy	13700.00
0005435243600	15422	Economy	13700.00
0005435243488	15422	Economy	13700.00
0005435243605	15422	Economy	13700.00
0005435243507	15422	Economy	13700.00
0005435243542	15422	Economy	13700.00
0005435243553	15422	Economy	13700.00
0005435243552	15422	Economy	13700.00
0005435243551	15422	Economy	13700.00
0005435243503	15422	Economy	13700.00
0005434880898	10071	Business	49700.00
0005434880505	10071	Business	49700.00
0005434880867	10071	Business	49700.00
0005434880280	10071	Business	49700.00
0005434880627	10071	Business	49700.00
0005434880850	10071	Business	49700.00
0005434880530	10071	Business	49700.00
0005434880576	10071	Business	49700.00
0005434880649	10071	Business	49700.00
0005434880800	10071	Business	49700.00
0005434880891	10071	Business	49700.00
0005434880270	10071	Economy	16600.00
0005434880865	10071	Economy	16600.00
0005434880352	10071	Economy	16600.00
0005434880654	10071	Economy	16600.00
0005434880569	10071	Economy	16600.00
0005434880920	10071	Economy	16600.00
0005434880442	10071	Economy	16600.00
0005434880939	10071	Economy	16600.00
0005434880899	10071	Economy	18200.00
0005434880753	10071	Economy	18200.00
0005434880892	10071	Economy	16600.00
0005434880667	10071	Economy	16600.00
0005434880575	10071	Economy	16600.00
0005434880420	10071	Economy	16600.00
0005434880745	10071	Economy	16600.00
0005434880663	10071	Economy	16600.00
0005434880716	10071	Economy	16600.00
0005434880803	10071	Economy	16600.00
0005434880281	10071	Economy	16600.00
0005434880951	10071	Economy	16600.00
0005434880628	10071	Economy	16600.00
0005434880282	10071	Economy	16600.00
0005434880843	10071	Economy	16600.00
0005434758956	10071	Economy	16600.00
0005434880596	10071	Economy	16600.00
0005434880922	10071	Economy	16600.00
0005434880764	10071	Economy	16600.00
0005434880441	10071	Economy	16600.00
0005434880690	10071	Economy	16600.00
0005434880836	10071	Economy	16600.00
0005434880597	10071	Economy	16600.00
0005434880746	10071	Economy	16600.00
0005434880529	10071	Economy	16600.00
0005434880349	10071	Economy	16600.00
0005434880421	10071	Economy	16600.00
0005434880422	10071	Economy	16600.00
0005434880687	10071	Economy	16600.00
0005434880877	10071	Economy	16600.00
0005434758957	10071	Economy	16600.00
0005434880878	10071	Economy	16600.00
0005434880761	10071	Economy	16600.00
0005434880839	10071	Economy	16600.00
0005434880626	10071	Economy	16600.00
0005434880419	10071	Economy	16600.00
0005434880461	10071	Economy	16600.00
0005434880623	10071	Economy	16600.00
0005434880897	10071	Economy	16600.00
0005434880730	10071	Economy	16600.00
0005434880868	10071	Economy	16600.00
0005434880921	10071	Economy	16600.00
0005434880852	10071	Economy	16600.00
0005435914216	10071	Economy	16600.00
0005434880731	10071	Economy	16600.00
0005434880271	10071	Economy	16600.00
0005434880752	10071	Economy	16600.00
0005434880571	10071	Economy	16600.00
0005434880629	10071	Economy	16600.00
0005434880353	10071	Economy	16600.00
0005434880901	10071	Economy	16600.00
0005434880722	10071	Economy	16600.00
0005434880860	10071	Economy	16600.00
0005434880682	10071	Economy	16600.00
0005435914063	14609	Business	49700.00
0005435914198	14609	Business	49700.00
0005435914144	14609	Business	49700.00
0005435914127	14609	Economy	16600.00
0005435914143	14609	Economy	16600.00
0005435914199	14609	Economy	16600.00
0005435914128	14609	Economy	16600.00
0005435914060	14609	Economy	16600.00
0005435914126	14609	Economy	16600.00
0005435914155	14609	Economy	16600.00
0005435914152	14609	Economy	16600.00
0005435914059	14609	Economy	16600.00
0005435914112	14609	Economy	16600.00
0005435914088	14609	Economy	16600.00
0005435914125	14609	Economy	16600.00
0005435914119	14609	Economy	16600.00
0005435914062	14609	Economy	16600.00
0005435914058	14609	Economy	16600.00
0005434252204	9245	Economy	22400.00
0005434252191	9245	Economy	22400.00
0005434252240	9245	Economy	20300.00
0005434252229	9245	Economy	20300.00
0005434252203	9245	Economy	20300.00
0005435933572	9245	Economy	20300.00
0005434252224	9245	Economy	20300.00
0005434252234	9245	Economy	20300.00
0005434252233	9245	Economy	20300.00
0005434252241	9245	Economy	20300.00
0005434252172	9245	Economy	20300.00
0005434252216	9245	Economy	20300.00
0005434252232	9245	Economy	20300.00
0005435660456	24663	Economy	20300.00
0005435660431	24663	Economy	20300.00
0005435660454	24663	Economy	20300.00
0005435660430	24663	Economy	20300.00
0005435660458	24663	Economy	20300.00
0005435660453	24663	Economy	20300.00
0005435660392	24663	Economy	20300.00
0005432967550	2811	Business	33000.00
0005432967669	2811	Business	33000.00
0005432967491	2811	Business	33000.00
0005432967577	2811	Business	33000.00
0005433690988	2811	Business	33000.00
0005432967535	2811	Business	33000.00
0005432967610	2811	Business	33000.00
0005432967673	2811	Economy	11000.00
0005432967574	2811	Economy	11000.00
0005432967566	2811	Economy	12100.00
0005432967671	2811	Economy	11000.00
0005432967536	2811	Economy	11000.00
0005432967652	2811	Economy	11000.00
0005432967632	2811	Economy	11000.00
0005433690991	2811	Economy	11000.00
0005432967653	2811	Economy	11000.00
0005432967492	2811	Economy	11000.00
0005432967540	2811	Economy	11000.00
0005432967631	2811	Economy	11000.00
0005432967534	2811	Economy	11000.00
0005432967567	2811	Economy	11000.00
0005432967670	2811	Economy	11000.00
0005432967622	2811	Economy	11000.00
0005433690990	2811	Economy	11000.00
0005432967668	2811	Economy	11000.00
0005432967612	2811	Economy	11000.00
0005433690989	2811	Economy	11000.00
0005432967616	2811	Economy	11000.00
0005432967549	2811	Economy	11000.00
0005433681792	29172	Business	33000.00
0005433681934	29172	Business	33000.00
0005433681849	29172	Business	33000.00
0005433681870	29172	Business	33000.00
0005433681838	29172	Economy	11000.00
0005433681750	29172	Economy	11000.00
0005433681895	29172	Economy	11000.00
0005433681953	29172	Economy	11000.00
0005433681909	29172	Economy	11000.00
0005433681796	29172	Economy	12100.00
0005433684478	29172	Economy	12100.00
0005433681837	29172	Economy	11000.00
0005433681793	29172	Economy	11000.00
0005433681782	29172	Economy	11000.00
0005433681882	29172	Economy	11000.00
0005433681789	29172	Economy	11000.00
0005433681788	29172	Economy	11000.00
0005433681840	29172	Economy	11000.00
0005433681877	29172	Economy	11000.00
0005433681886	29172	Economy	11000.00
0005433681839	29172	Economy	11000.00
0005433681850	29172	Economy	11000.00
0005433681867	29172	Economy	11000.00
0005433681871	29172	Economy	11000.00
0005433687749	29172	Economy	11000.00
0005433681794	29172	Economy	11000.00
0005433681921	29172	Economy	11000.00
0005433681872	29172	Economy	11000.00
0005433681853	29172	Economy	11000.00
0005433681851	29172	Economy	11000.00
0005433681861	29172	Economy	11000.00
0005433681933	29172	Economy	11000.00
0005433681725	29172	Economy	11000.00
0005433681935	29172	Economy	11000.00
0005433681664	29172	Economy	11000.00
0005433681925	29172	Economy	11000.00
0005433681773	29172	Economy	11000.00
0005433684472	29172	Economy	11000.00
0005433681881	29172	Economy	11000.00
0005433681772	29172	Economy	11000.00
0005433690978	29172	Economy	11000.00
0005433681873	29172	Economy	11000.00
0005433681868	29172	Economy	11000.00
0005433681920	29172	Economy	11000.00
0005433681954	29172	Economy	11000.00
0005433681747	29172	Economy	11000.00
0005433687758	29172	Economy	11000.00
0005435856345	9277	Business	132900.00
0005434152834	9277	Business	132900.00
0005434163873	9277	Business	132900.00
0005435856342	9277	Business	132900.00
0005434163835	9277	Business	132900.00
0005434153565	9277	Business	132900.00
0005434153571	9277	Business	132900.00
0005434272226	9277	Business	132900.00
0005434163847	9277	Economy	48700.00
0005433634829	9277	Economy	44300.00
0005434152840	9277	Economy	44300.00
0005434163877	9277	Economy	44300.00
0005434153564	9277	Economy	44300.00
0005434153574	9277	Economy	44300.00
0005435856344	9277	Economy	44300.00
0005434153575	9277	Economy	44300.00
0005434163834	9277	Economy	44300.00
0005434152833	9277	Economy	44300.00
0005434163833	9277	Economy	44300.00
0005434163878	9277	Economy	44300.00
0005434163862	9277	Economy	44300.00
0005434163876	9277	Economy	44300.00
0005434153578	9277	Economy	44300.00
0005433634830	9277	Economy	44300.00
0005434163846	9277	Economy	44300.00
0005434163841	9277	Economy	44300.00
0005433616712	25266	Business	132900.00
0005433616468	25266	Business	132900.00
0005433616562	25266	Business	132900.00
0005433634589	25266	Business	132900.00
0005432751610	25266	Business	132900.00
0005433616664	25266	Business	132900.00
0005433616495	25266	Business	132900.00
0005433616675	25266	Business	132900.00
0005433616493	25266	Business	132900.00
0005433616242	25266	Business	132900.00
0005433634726	25266	Business	132900.00
0005433616707	25266	Business	132900.00
0005433616517	25266	Business	132900.00
0005433634699	25266	Business	132900.00
0005433616766	25266	Business	132900.00
0005433634588	25266	Business	132900.00
0005433634670	25266	Business	132900.00
0005433616357	25266	Business	132900.00
0005432755149	25266	Business	132900.00
0005433634683	25266	Business	132900.00
0005433634591	25266	Business	132900.00
0005433616697	25266	Economy	48700.00
0005433616523	25266	Economy	48700.00
0005433616545	25266	Economy	48700.00
0005433634762	25266	Economy	44300.00
0005433634669	25266	Economy	44300.00
0005432755150	25266	Economy	44300.00
0005433616622	25266	Economy	44300.00
0005433616569	25266	Economy	44300.00
0005433634626	25266	Economy	44300.00
0005432751593	25266	Economy	44300.00
0005433616665	25266	Economy	44300.00
0005432751621	25266	Economy	44300.00
0005433616507	25266	Economy	44300.00
0005432751599	25266	Economy	44300.00
0005433616577	25266	Economy	44300.00
0005433616492	25266	Economy	44300.00
0005433616580	25266	Economy	44300.00
0005433616348	25266	Economy	44300.00
0005433616530	25266	Economy	44300.00
0005433634620	25266	Economy	44300.00
0005433616724	25266	Economy	44300.00
0005433578138	25266	Economy	44300.00
0005433634513	25266	Economy	44300.00
0005433616494	25266	Economy	44300.00
0005433616576	25266	Economy	44300.00
0005432755162	25266	Economy	44300.00
0005432751619	25266	Economy	44300.00
0005432751620	25266	Economy	44300.00
0005432751594	25266	Economy	44300.00
0005433634748	25266	Economy	44300.00
0005433634725	25266	Economy	44300.00
0005432751608	25266	Economy	44300.00
0005433616700	25266	Economy	44300.00
0005433578139	25266	Economy	44300.00
0005432755151	25266	Economy	44300.00
0005432751598	25266	Economy	44300.00
0005433616768	25266	Economy	44300.00
0005433616705	25266	Economy	44300.00
0005433634698	25266	Economy	44300.00
0005433634799	25266	Economy	44300.00
0005433616616	25266	Economy	44300.00
0005433616491	25266	Economy	44300.00
0005433634690	25266	Economy	44300.00
0005433616609	25266	Economy	44300.00
0005433634787	25266	Economy	44300.00
0005433634514	25266	Economy	44300.00
0005433616527	25266	Economy	44300.00
0005433616663	25266	Economy	44300.00
0005433616565	25266	Economy	48700.00
0005433616561	25266	Economy	48700.00
0005433616608	25266	Economy	48700.00
0005433616175	25266	Economy	44300.00
0005432755153	25266	Economy	44300.00
0005433616701	25266	Economy	44300.00
0005433616744	25266	Economy	48700.00
0005433634682	25266	Economy	44300.00
0005432751609	25266	Economy	44300.00
0005432755136	25266	Economy	44300.00
0005433616674	25266	Economy	44300.00
0005433634635	25266	Economy	44300.00
0005432751597	25266	Economy	44300.00
0005433634650	25266	Economy	44300.00
0005433616739	25266	Economy	44300.00
0005433616483	25266	Economy	44300.00
0005433616437	25266	Economy	44300.00
0005433616568	25266	Economy	44300.00
0005433616249	25266	Economy	44300.00
0005433616595	25266	Economy	44300.00
0005433616460	25266	Economy	44300.00
0005433634684	25266	Economy	44300.00
0005433616617	25266	Economy	44300.00
0005433616745	25266	Economy	44300.00
0005433634764	25266	Economy	44300.00
0005433616746	25266	Economy	44300.00
0005433634634	25266	Economy	44300.00
0005433616482	25266	Economy	44300.00
0005433634800	25266	Economy	44300.00
0005433616686	25266	Economy	44300.00
0005432755155	25266	Economy	44300.00
0005433634786	25266	Economy	44300.00
0005433616503	25266	Economy	44300.00
0005433616241	25266	Economy	44300.00
0005433634636	25266	Economy	44300.00
0005433616615	25266	Economy	44300.00
0005432755148	25266	Economy	44300.00
0005433616157	25266	Economy	44300.00
0005433616467	25266	Economy	44300.00
0005433616564	25266	Economy	44300.00
0005433616767	25266	Economy	44300.00
0005433634685	25266	Economy	44300.00
0005432755156	25266	Economy	44300.00
0005432755152	25266	Economy	44300.00
0005432751603	25266	Economy	44300.00
0005433616557	25266	Economy	44300.00
0005433634637	25266	Economy	44300.00
0005433634724	25266	Economy	44300.00
0005432571424	4214	Business	193100.00
0005435856309	4214	Business	193100.00
0005435856308	4214	Economy	64400.00
0005435947657	4214	Economy	64400.00
0005435787410	4214	Economy	64400.00
0005435987063	4214	Economy	64400.00
0005434271367	4214	Economy	64400.00
0005432571421	4214	Economy	64400.00
0005432571423	4214	Economy	64400.00
0005432571427	4214	Economy	64400.00
0005434273138	4214	Economy	64400.00
0005435787411	4214	Economy	64400.00
0005434271368	4214	Economy	64400.00
0005435947597	4214	Economy	64400.00
0005435787397	4214	Economy	64400.00
0005435947645	4214	Economy	64400.00
0005434271366	4214	Economy	70800.00
0005435947608	4214	Economy	70800.00
0005435856307	4214	Economy	64400.00
0005432571422	4214	Economy	64400.00
0005432571420	4214	Economy	64400.00
0005435947639	4214	Economy	64400.00
0005435947653	4214	Economy	64400.00
0005434271365	4214	Economy	64400.00
0005435856324	4214	Economy	64400.00
0005434273137	4214	Economy	64400.00
0005435986987	26560	Business	193100.00
0005435986964	26560	Business	193100.00
0005435986976	26560	Economy	64400.00
0005435986957	26560	Economy	64400.00
0005435986995	26560	Economy	64400.00
0005435987015	26560	Economy	64400.00
0005435986998	26560	Economy	64400.00
0005435987012	26560	Economy	64400.00
0005435986977	26560	Economy	64400.00
0005435986965	26560	Economy	64400.00
0005435987014	26560	Economy	64400.00
0005435987021	26560	Economy	64400.00
0005435987016	26560	Economy	64400.00
0005435987013	26560	Economy	64400.00
0005432949604	330	Business	21500.00
0005433134248	330	Business	21500.00
0005432949589	330	Business	21500.00
0005433129403	330	Business	21500.00
0005432949398	330	Business	21500.00
0005433075417	330	Business	21500.00
0005433075386	330	Economy	7900.00
0005432949566	330	Economy	7900.00
0005433134262	330	Economy	7200.00
0005433075499	330	Economy	7200.00
0005432949346	330	Economy	7200.00
0005432949591	330	Economy	7200.00
0005433075482	330	Economy	7200.00
0005432949452	330	Economy	7200.00
0005432949609	330	Economy	7200.00
0005433134259	330	Economy	7200.00
0005433075516	330	Economy	7200.00
0005432949575	330	Economy	7200.00
0005432949679	330	Economy	7200.00
0005433134247	330	Economy	7200.00
0005433134258	330	Economy	7200.00
0005433075414	330	Economy	7200.00
0005432949567	330	Economy	7200.00
0005432949593	330	Economy	7200.00
0005433075455	330	Economy	7200.00
0005432949378	330	Economy	7200.00
0005432949445	330	Economy	7900.00
0005432949377	330	Economy	7900.00
0005434088045	330	Economy	7200.00
0005433075460	330	Economy	7200.00
0005432949537	330	Economy	7900.00
0005432949480	330	Economy	7200.00
0005433075483	330	Economy	7200.00
0005432949467	330	Economy	7200.00
0005432949536	330	Economy	7200.00
0005433570990	330	Economy	7200.00
0005432949399	330	Economy	7200.00
0005433075454	330	Economy	7200.00
0005433075486	330	Economy	7200.00
0005432949592	330	Economy	7200.00
0005433075453	330	Economy	7200.00
0005434088046	330	Economy	7200.00
0005433075418	330	Economy	7200.00
0005432949451	330	Economy	7200.00
0005432949481	330	Economy	7200.00
0005432949494	330	Economy	7200.00
0005433075515	330	Economy	7200.00
0005432949610	330	Economy	7200.00
0005433075459	330	Economy	7200.00
0005433075470	330	Economy	7200.00
0005433075517	330	Economy	7200.00
0005432949588	330	Economy	7200.00
0005433075500	330	Economy	7200.00
0005433570989	330	Economy	7200.00
0005433129397	330	Economy	7200.00
0005433075332	330	Economy	7200.00
0005432949551	330	Economy	7200.00
0005433075501	330	Economy	7200.00
0005433570399	11566	Business	21500.00
0005433570714	11566	Business	21500.00
0005433570615	11566	Business	21500.00
0005433570593	11566	Business	21500.00
0005434088053	11566	Business	21500.00
0005433570470	11566	Business	21500.00
0005433570193	11566	Business	21500.00
0005434326034	11566	Business	21500.00
0005434087957	11566	Business	21500.00
0005433570505	11566	Business	21500.00
0005433570633	11566	Business	21500.00
0005433570490	11566	Economy	7900.00
0005434087937	11566	Economy	7900.00
0005434088054	11566	Economy	7200.00
0005434087931	11566	Economy	7200.00
0005433570640	11566	Economy	7200.00
0005433570858	11566	Economy	7200.00
0005434087952	11566	Economy	7200.00
0005433570362	11566	Economy	7200.00
0005433570373	11566	Economy	7200.00
0005433570237	11566	Economy	7200.00
0005433570853	11566	Economy	7200.00
0005433570642	11566	Economy	7200.00
0005433570238	11566	Economy	7200.00
0005433570756	11566	Economy	7200.00
0005433570625	11566	Economy	7200.00
0005433570420	11566	Economy	7200.00
0005434087951	11566	Economy	7200.00
0005434087930	11566	Economy	7200.00
0005433570400	11566	Economy	7200.00
0005433570374	11566	Economy	7200.00
0005433570579	11566	Economy	7200.00
0005433570514	11566	Economy	7200.00
0005433570328	11566	Economy	7200.00
0005433570745	11566	Economy	7200.00
0005433570423	11566	Economy	7200.00
0005433570309	11566	Economy	7200.00
0005433570674	11566	Economy	7200.00
0005433570659	11566	Economy	7200.00
0005433570827	11566	Economy	7200.00
0005433570719	11566	Economy	7200.00
0005434326039	11566	Economy	7200.00
0005434326035	11566	Economy	7200.00
0005434087999	11566	Economy	7200.00
0005433570419	11566	Economy	7200.00
0005433570469	11566	Economy	7200.00
0005433570441	11566	Economy	7200.00
0005433570678	11566	Economy	7200.00
0005433570716	11566	Economy	7200.00
0005433570483	11566	Economy	7200.00
0005433570741	11566	Economy	7200.00
0005433570660	11566	Economy	7200.00
0005433570600	11566	Economy	7200.00
0005433570456	11566	Economy	7200.00
0005433570811	11566	Economy	7900.00
0005434088016	11566	Economy	7900.00
0005433570717	11566	Economy	7200.00
0005433570572	11566	Economy	7200.00
0005433570718	11566	Economy	7200.00
0005433570592	11566	Economy	7900.00
0005433570818	11566	Economy	7200.00
0005433570668	11566	Economy	7200.00
0005433570667	11566	Economy	7200.00
0005433570571	11566	Economy	7200.00
0005433570815	11566	Economy	7200.00
0005434087944	11566	Economy	7200.00
0005433570455	11566	Economy	7200.00
0005434326019	11566	Economy	7200.00
0005433570575	11566	Economy	7200.00
0005433570744	11566	Economy	7200.00
0005433570523	11566	Economy	7200.00
0005434088052	11566	Economy	7200.00
0005434326033	11566	Economy	7200.00
0005433570484	11566	Economy	7200.00
0005433570641	11566	Economy	7200.00
0005433570715	11566	Economy	7200.00
0005433570627	11566	Economy	7200.00
0005433570721	11566	Economy	7200.00
0005433570431	11566	Economy	7200.00
0005434087932	11566	Economy	7200.00
0005433570529	11566	Economy	7200.00
0005433570478	11566	Economy	7200.00
0005433570632	11566	Economy	7200.00
0005433570535	11566	Economy	7200.00
0005433570515	11566	Economy	7200.00
0005434087974	11566	Economy	7200.00
0005433570814	11566	Economy	7200.00
0005433570508	11566	Economy	7200.00
0005433570412	11566	Economy	7200.00
0005433570738	11566	Economy	7200.00
0005433570732	11566	Economy	7200.00
0005433570602	11566	Economy	7200.00
0005434088006	11566	Economy	7200.00
0005433570843	11566	Economy	7200.00
0005434733080	10060	Economy	6300.00
0005434733084	10060	Economy	6300.00
0005433817568	13908	Economy	6300.00
0005432985905	2352	Business	184500.00
0005432869716	2352	Business	184500.00
0005434731277	2352	Business	184500.00
0005434731266	2352	Business	184500.00
0005434731279	2352	Business	184500.00
0005432869701	2352	Business	184500.00
0005433435292	2352	Business	184500.00
0005433435406	2352	Business	184500.00
0005432985906	2352	Business	184500.00
0005432985762	2352	Economy	67700.00
0005432985936	2352	Economy	61500.00
0005432226244	2352	Economy	61500.00
0005432985994	2352	Economy	61500.00
0005432985895	2352	Economy	61500.00
0005433435415	2352	Economy	61500.00
0005432869715	2352	Economy	61500.00
0005432985998	2352	Economy	61500.00
0005434731278	2352	Economy	61500.00
0005432985907	2352	Economy	61500.00
0005432869657	2352	Economy	61500.00
0005432869692	2352	Economy	61500.00
0005432985761	2352	Economy	61500.00
0005432985894	2352	Economy	61500.00
0005433435429	2352	Economy	61500.00
0005432869702	2352	Economy	61500.00
0005434731267	2352	Economy	61500.00
0005432985922	2352	Economy	61500.00
0005433435443	2352	Economy	61500.00
0005434376164	2352	Economy	61500.00
0005433435475	2352	Economy	67700.00
0005434731272	2352	Economy	61500.00
0005432985972	2352	Economy	61500.00
0005432985963	2352	Economy	61500.00
0005433435444	2352	Economy	61500.00
0005432985920	2352	Economy	61500.00
0005432226243	2352	Economy	61500.00
0005433435414	2352	Economy	61500.00
0005434731286	2352	Economy	61500.00
0005434731276	2352	Economy	61500.00
0005433435396	2352	Economy	61500.00
0005433435476	2352	Economy	61500.00
0005434731275	2352	Economy	61500.00
0005435983393	26186	Business	184500.00
0005435983377	26186	Business	184500.00
0005433755532	26186	Business	184500.00
0005435983560	26186	Business	184500.00
0005433755676	26186	Business	184500.00
0005433755640	26186	Business	184500.00
0005435983378	26186	Business	184500.00
0005435983623	26186	Business	184500.00
0005435983456	26186	Business	184500.00
0005435983389	26186	Business	184500.00
0005435983499	26186	Business	184500.00
0005435983404	26186	Business	184500.00
0005435983574	26186	Business	184500.00
0005435983591	26186	Business	184500.00
0005435983524	26186	Economy	67700.00
0005433755707	26186	Business	184500.00
0005433755621	26186	Economy	67700.00
0005435983580	26186	Economy	61500.00
0005433755651	26186	Economy	61500.00
0005433766737	26186	Economy	61500.00
0005435983481	26186	Economy	61500.00
0005433755705	26186	Economy	61500.00
0005433755711	26186	Economy	61500.00
0005433755693	26186	Economy	61500.00
0005433755740	26186	Economy	61500.00
0005433755626	26186	Economy	61500.00
0005433766741	26186	Economy	61500.00
0005435983464	26186	Economy	61500.00
0005433755766	26186	Economy	61500.00
0005435983640	26186	Economy	61500.00
0005433755741	26186	Economy	61500.00
0005433755748	26186	Economy	61500.00
0005435983458	26186	Economy	61500.00
0005435983465	26186	Economy	61500.00
0005434376170	26186	Economy	61500.00
0005435983621	26186	Economy	61500.00
0005433755799	26186	Economy	61500.00
0005433755630	26186	Economy	61500.00
0005433755680	26186	Economy	61500.00
0005435983416	26186	Economy	61500.00
0005435983410	26186	Economy	61500.00
0005433755610	26186	Economy	61500.00
0005433755738	26186	Economy	61500.00
0005432655833	26186	Economy	61500.00
0005433755600	26186	Economy	61500.00
0005433755721	26186	Economy	61500.00
0005432655810	26186	Economy	61500.00
0005435983622	26186	Economy	61500.00
0005432655852	26186	Economy	61500.00
0005433755731	26186	Economy	61500.00
0005435983489	26186	Economy	61500.00
0005433755703	26186	Economy	61500.00
0005435983441	26186	Economy	61500.00
0005433755681	26186	Economy	61500.00
0005433755639	26186	Economy	61500.00
0005435983417	26186	Economy	61500.00
0005433755685	26186	Economy	61500.00
0005435983301	26186	Economy	61500.00
0005434731293	26186	Economy	61500.00
0005433755746	26186	Economy	61500.00
0005433766746	26186	Economy	61500.00
0005435983609	26186	Economy	61500.00
0005433755706	26186	Economy	61500.00
0005433755788	26186	Economy	61500.00
0005432655832	26186	Economy	61500.00
0005433755780	26186	Economy	67700.00
0005433755704	26186	Economy	61500.00
0005435983598	26186	Economy	67700.00
0005433755694	26186	Economy	67700.00
0005435983392	26186	Economy	61500.00
0005433755729	26186	Economy	61500.00
0005433755652	26186	Economy	61500.00
0005433755730	26186	Economy	61500.00
0005435983411	26186	Economy	61500.00
0005433755607	26186	Economy	61500.00
0005433755675	26186	Economy	61500.00
0005433755691	26186	Economy	61500.00
0005433755722	26186	Economy	61500.00
0005435983473	26186	Economy	61500.00
0005433755782	26186	Economy	61500.00
0005433755708	26186	Economy	61500.00
0005435983555	26186	Economy	61500.00
0005434376171	26186	Economy	61500.00
0005435983350	26186	Economy	61500.00
0005433766745	26186	Economy	61500.00
0005435983556	26186	Economy	61500.00
0005435983455	26186	Economy	61500.00
0005435983518	26186	Economy	61500.00
0005435983585	26186	Economy	61500.00
0005432655840	26186	Economy	61500.00
0005432655821	26186	Economy	61500.00
0005435983480	26186	Economy	61500.00
0005433755608	26186	Economy	61500.00
0005435983300	26186	Economy	61500.00
0005433755595	26186	Economy	61500.00
0005433764732	26186	Economy	61500.00
0005433755840	26186	Economy	61500.00
0005435983390	26186	Economy	61500.00
0005435983388	26186	Economy	61500.00
0005432655848	26186	Economy	61500.00
0005435983457	26186	Economy	61500.00
0005433755692	26186	Economy	61500.00
0005435983579	26186	Economy	61500.00
0005432655849	26186	Economy	61500.00
0005435983639	26186	Economy	61500.00
0005433755762	26186	Economy	61500.00
0005435983403	26186	Economy	61500.00
0005433755798	26186	Economy	61500.00
0005433766736	26186	Economy	61500.00
0005433755787	26186	Economy	61500.00
0005435983391	26186	Economy	61500.00
0005433755739	26186	Economy	61500.00
0005433152309	1524	Business	38900.00
0005433152266	1524	Business	38900.00
0005433152348	1524	Economy	13000.00
0005433152176	1524	Economy	13000.00
0005433764734	1524	Economy	13000.00
0005433152294	1524	Economy	13000.00
0005433152387	1524	Economy	13000.00
0005433152359	1524	Economy	13000.00
0005433152337	1524	Economy	13000.00
0005433152297	1524	Economy	13000.00
0005433152174	1524	Economy	13000.00
0005433931548	1524	Economy	13000.00
0005433152330	1524	Economy	13000.00
0005433152360	1524	Economy	13000.00
0005434029717	1524	Economy	13000.00
0005434376169	1524	Economy	13000.00
0005433152186	1524	Economy	13000.00
0005433152255	1524	Economy	13000.00
0005433152175	1524	Economy	13000.00
0005433152315	1524	Economy	13000.00
0005433152256	1524	Economy	13000.00
0005433152293	1524	Economy	13000.00
0005433152366	1524	Economy	13000.00
0005433152347	1524	Economy	13000.00
0005433152331	1524	Economy	13000.00
0005433152308	1524	Economy	13000.00
0005434375857	20144	Business	38900.00
0005434375936	20144	Business	38900.00
0005434375868	20144	Economy	13000.00
0005434375961	20144	Economy	13000.00
0005434375812	20144	Economy	13000.00
0005434375772	20144	Economy	13000.00
0005434375928	20144	Economy	13000.00
0005434375889	20144	Economy	13000.00
0005434375680	20144	Economy	13000.00
0005434375763	20144	Economy	13000.00
0005434376164	20144	Economy	13000.00
0005434375890	20144	Economy	13000.00
0005434375862	20144	Economy	13000.00
0005434376043	20144	Economy	13000.00
0005434375960	20144	Economy	14300.00
0005434375858	20144	Economy	14300.00
0005434375872	20144	Economy	14300.00
0005434375856	20144	Economy	13000.00
0005434375982	20144	Economy	13000.00
0005434375913	20144	Economy	13000.00
0005434376017	20144	Economy	13000.00
0005434375771	20144	Economy	13000.00
0005434375861	20144	Economy	13000.00
0005434376063	20144	Economy	13000.00
0005434375920	20144	Economy	13000.00
0005434375893	20144	Economy	13000.00
0005434375859	20144	Economy	13000.00
0005434375871	20144	Economy	13000.00
0005434375883	20144	Economy	13000.00
0005432056407	20144	Economy	13000.00
0005434375813	20144	Economy	13000.00
0005434375927	20144	Economy	13000.00
0005434375867	20144	Economy	13000.00
0005434375990	20144	Economy	13000.00
0005434375887	20144	Economy	13000.00
0005434375873	20144	Economy	13000.00
0005434375957	20144	Economy	13000.00
0005434376044	20144	Economy	13000.00
0005434375711	20144	Economy	13000.00
0005434375679	20144	Economy	13000.00
0005434376018	20144	Economy	13000.00
0005433261922	553	Business	27500.00
0005433158202	553	Business	27500.00
0005433158203	553	Business	27500.00
0005433766759	553	Business	27500.00
0005433261985	553	Business	27500.00
0005435949870	553	Business	27500.00
0005433766760	553	Business	27500.00
0005433262011	553	Economy	10100.00
0005433261968	553	Economy	9200.00
0005433766758	553	Economy	9200.00
0005433261967	553	Economy	9200.00
0005433262034	553	Economy	9200.00
0005433261910	553	Economy	9200.00
0005433262004	553	Economy	9200.00
0005433261923	553	Economy	9200.00
0005434444190	553	Economy	9200.00
0005433261951	553	Economy	10100.00
0005433261884	553	Economy	9200.00
0005433262014	553	Economy	9200.00
0005433261992	553	Economy	9200.00
0005434444189	553	Economy	9200.00
0005433262010	553	Economy	9200.00
0005432426078	553	Economy	9200.00
0005433262063	12839	Business	27500.00
0005433262064	12839	Economy	9200.00
0005432425776	12853	Business	27500.00
0005432425592	12853	Business	27500.00
0005432425703	12853	Business	27500.00
0005432425743	12853	Business	27500.00
0005432425778	12853	Business	27500.00
0005432425719	12853	Business	27500.00
0005432425665	12853	Business	27500.00
0005432425753	12853	Business	27500.00
0005432425636	12853	Business	27500.00
0005432425668	12853	Business	27500.00
0005432425718	12853	Economy	10100.00
0005432425523	12853	Economy	9200.00
0005432425730	12853	Economy	9200.00
0005432425794	12853	Economy	9200.00
0005432425763	12853	Economy	9200.00
0005432425615	12853	Economy	9200.00
0005432425598	12853	Economy	9200.00
0005432425626	12853	Economy	9200.00
0005432425766	12853	Economy	9200.00
0005432425688	12853	Economy	9200.00
0005432425731	12853	Economy	9200.00
0005432425564	12853	Economy	9200.00
0005432425777	12853	Economy	9200.00
0005432425754	12853	Economy	9200.00
0005432425725	12853	Economy	9200.00
0005432425716	12853	Economy	9200.00
0005432425609	12853	Economy	9200.00
0005432425711	12853	Economy	9200.00
0005432425693	12853	Economy	9200.00
0005432425639	12853	Economy	10100.00
0005432425643	12853	Economy	9200.00
0005432425786	12853	Economy	9200.00
0005432425724	12853	Economy	9200.00
0005432425744	12853	Economy	9200.00
0005432425686	12853	Economy	9200.00
0005432425767	12853	Economy	9200.00
0005432425765	12853	Economy	9200.00
0005432425782	12853	Economy	9200.00
0005432425610	12853	Economy	9200.00
0005432425551	12853	Economy	9200.00
0005432425438	12853	Economy	9200.00
0005432425694	12853	Economy	9200.00
0005432425685	12853	Economy	9200.00
0005432425729	12853	Economy	9200.00
0005432425582	12853	Economy	9200.00
0005432425550	12853	Economy	9200.00
0005432425591	12853	Economy	9200.00
0005432425818	12853	Economy	9200.00
0005432425788	12853	Economy	9200.00
0005432425390	12853	Economy	9200.00
0005432425692	12853	Economy	9200.00
0005432425726	12853	Economy	9200.00
0005433058941	466	Business	24500.00
0005434735834	466	Business	24500.00
0005434735809	466	Business	24500.00
0005434735800	466	Economy	9000.00
0005434735795	466	Business	24500.00
0005434735833	466	Economy	9000.00
0005433059011	466	Economy	8200.00
0005433058885	466	Economy	8200.00
0005433059007	466	Economy	8200.00
0005433059023	466	Economy	8200.00
0005433059025	466	Economy	8200.00
0005433059039	466	Economy	8200.00
0005433058986	466	Economy	8200.00
0005433058978	466	Economy	8200.00
0005433058988	466	Economy	8200.00
0005433059006	466	Economy	8200.00
0005433929723	466	Economy	8200.00
0005433058967	466	Economy	8200.00
0005433059022	466	Economy	8200.00
0005434028400	466	Economy	8200.00
0005433059026	466	Economy	8200.00
0005433058989	466	Economy	8200.00
0005433684470	466	Economy	8200.00
0005433929722	466	Economy	8200.00
0005433058942	466	Economy	8200.00
0005433058935	466	Economy	8200.00
0005433058962	466	Economy	8200.00
0005433059012	466	Economy	8200.00
0005433058938	466	Economy	8200.00
0005433058846	466	Economy	8200.00
0005433058798	466	Economy	8200.00
0005434376230	466	Economy	8200.00
0005433058981	466	Economy	8200.00
0005434735808	466	Economy	8200.00
0005433058886	466	Economy	8200.00
0005433684477	466	Economy	8200.00
0005433058992	466	Economy	8200.00
0005433684469	466	Economy	8200.00
0005434032162	466	Economy	8200.00
0005433058995	466	Economy	8200.00
0005433058980	466	Economy	8200.00
0005433058963	466	Economy	8200.00
0005433058830	466	Economy	8200.00
0005433059024	466	Economy	8200.00
0005433059056	466	Economy	8200.00
0005433059038	466	Economy	8200.00
0005433058993	466	Economy	8200.00
0005433058979	466	Economy	8200.00
0005433058990	466	Economy	8200.00
0005433058987	466	Economy	8200.00
0005434025461	12669	Business	24500.00
0005434025650	12669	Business	24500.00
0005434028381	12669	Business	24500.00
0005434025581	12669	Business	24500.00
0005434025372	12669	Business	24500.00
0005434025547	12669	Business	24500.00
0005434032137	12669	Business	24500.00
0005434025416	12669	Economy	9000.00
0005434025497	12669	Economy	8200.00
0005434025496	12669	Economy	8200.00
0005434025417	12669	Economy	8200.00
0005434025407	12669	Economy	8200.00
0005434025433	12669	Economy	8200.00
0005434025388	12669	Economy	8200.00
0005434032147	12669	Economy	8200.00
0005434025558	12669	Economy	8200.00
0005434025367	12669	Economy	8200.00
0005434025463	12669	Economy	8200.00
0005434025590	12669	Economy	8200.00
0005434025618	12669	Economy	8200.00
0005434025446	12669	Economy	8200.00
0005434025568	12669	Economy	8200.00
0005434032143	12669	Economy	8200.00
0005434025279	12669	Economy	8200.00
0005434025490	12669	Economy	8200.00
0005434029717	12669	Economy	8200.00
0005434025387	12669	Economy	9000.00
0005434032138	12669	Economy	8200.00
0005434032142	12669	Economy	8200.00
0005434025666	12669	Economy	8200.00
0005434025491	12669	Economy	8200.00
0005434028379	12669	Economy	8200.00
0005434025464	12669	Economy	8200.00
0005434025278	12669	Economy	8200.00
0005434032148	12669	Economy	8200.00
0005434025292	12669	Economy	8200.00
0005434025508	12669	Economy	8200.00
0005434025442	12669	Economy	8200.00
0005434032151	12669	Economy	8200.00
0005434032144	12669	Economy	8200.00
0005434032145	12669	Economy	8200.00
0005434025414	12669	Economy	8200.00
0005434025415	12669	Economy	8200.00
0005434025589	12669	Economy	8200.00
0005433529390	13821	Economy	37200.00
0005433533411	32444	Business	111600.00
0005433529372	32444	Business	111600.00
0005433529378	32444	Economy	37200.00
0005433529348	32444	Economy	37200.00
0005433529358	32444	Economy	37200.00
0005433529347	32444	Economy	37200.00
0005433533410	32444	Economy	37200.00
0005433529360	32444	Economy	37200.00
0005433533396	32444	Economy	37200.00
0005433533416	32444	Economy	37200.00
0005433533407	32444	Economy	37200.00
0005433529359	32444	Economy	37200.00
0005433533395	32444	Economy	37200.00
0005433533408	32444	Economy	37200.00
0005433533417	32444	Economy	37200.00
0005433037725	2117	Business	34700.00
0005433037724	2117	Business	34700.00
0005433037585	2117	Business	34700.00
0005433037577	2117	Business	34700.00
0005434028381	2117	Business	34700.00
0005433929899	2117	Business	34700.00
0005433037574	2117	Business	34700.00
0005432749847	2117	Economy	12700.00
0005433037413	2117	Economy	11600.00
0005433037568	2117	Economy	11600.00
0005433037514	2117	Economy	11600.00
0005433037719	2117	Economy	11600.00
0005433037683	2117	Economy	11600.00
0005433037469	2117	Economy	11600.00
0005433037489	2117	Economy	11600.00
0005433037651	2117	Economy	11600.00
0005433037690	2117	Economy	11600.00
0005433037668	2117	Economy	11600.00
0005432749848	2117	Economy	11600.00
0005433037606	2117	Economy	11600.00
0005433037706	2117	Economy	11600.00
0005433037645	2117	Economy	11600.00
0005433037743	2117	Economy	11600.00
0005433037644	2117	Economy	12700.00
0005433037586	2117	Economy	11600.00
0005433037682	2117	Economy	11600.00
0005433037488	2117	Economy	11600.00
0005434028379	2117	Economy	11600.00
0005432749849	2117	Economy	11600.00
0005433037744	2117	Economy	11600.00
0005433037777	2117	Economy	11600.00
0005433037718	2117	Economy	11600.00
0005433037778	2117	Economy	11600.00
0005433037751	2117	Economy	11600.00
0005433037667	2117	Economy	11600.00
0005433037507	2117	Economy	11600.00
0005433037746	2117	Economy	11600.00
0005433037774	2117	Economy	11600.00
0005433037750	2117	Economy	11600.00
0005433925934	24125	Business	34700.00
0005433925434	24125	Business	34700.00
0005433925857	24125	Business	34700.00
0005433925491	24125	Business	34700.00
0005433926071	24125	Business	34700.00
0005433925562	24125	Business	34700.00
0005433925623	24125	Business	34700.00
0005433925986	24125	Business	34700.00
0005433925435	24125	Business	34700.00
0005433925887	24125	Business	34700.00
0005433925754	24125	Business	34700.00
0005433929880	24125	Business	34700.00
0005433925686	24125	Economy	12700.00
0005433925858	24125	Economy	11600.00
0005433925988	24125	Economy	11600.00
0005433925833	24125	Economy	11600.00
0005433925990	24125	Economy	11600.00
0005433925919	24125	Economy	11600.00
0005433925619	24125	Economy	11600.00
0005433925513	24125	Economy	11600.00
0005433925700	24125	Economy	11600.00
0005432206362	24125	Economy	11600.00
0005433925743	24125	Economy	11600.00
0005433925989	24125	Economy	11600.00
0005433925634	24125	Economy	11600.00
0005433929870	24125	Economy	11600.00
0005433925839	24125	Economy	11600.00
0005433925441	24125	Economy	11600.00
0005433925830	24125	Economy	11600.00
0005433925748	24125	Economy	11600.00
0005433925940	24125	Economy	11600.00
0005433925941	24125	Economy	11600.00
0005433925583	24125	Economy	11600.00
0005433925492	24125	Economy	11600.00
0005433926050	24125	Economy	11600.00
0005433925512	24125	Economy	11600.00
0005433925980	24125	Economy	11600.00
0005433925630	24125	Economy	11600.00
0005433925825	24125	Economy	11600.00
0005433926009	24125	Economy	11600.00
0005433925900	24125	Economy	11600.00
0005433925881	24125	Economy	11600.00
0005433925490	24125	Economy	11600.00
0005433925899	24125	Economy	11600.00
0005433929871	24125	Economy	11600.00
0005433926081	24125	Economy	11600.00
0005433925420	24125	Economy	11600.00
0005433925977	24125	Economy	11600.00
0005433925566	24125	Economy	11600.00
0005433925757	24125	Economy	11600.00
0005433925770	24125	Economy	11600.00
0005433925726	24125	Economy	11600.00
0005433925993	24125	Economy	11600.00
0005433925970	24125	Economy	11600.00
0005433925820	24125	Economy	11600.00
0005433925926	24125	Economy	11600.00
0005433925894	24125	Economy	11600.00
0005433931556	24125	Economy	11600.00
0005433931557	24125	Economy	11600.00
0005433925893	24125	Economy	12700.00
0005433925758	24125	Economy	12700.00
0005433925559	24125	Economy	11600.00
0005433929882	24125	Economy	11600.00
0005433925939	24125	Economy	11600.00
0005433925640	24125	Economy	11600.00
0005433925639	24125	Economy	11600.00
0005433925586	24125	Economy	11600.00
0005433925781	24125	Economy	11600.00
0005433925821	24125	Economy	11600.00
0005433925618	24125	Economy	11600.00
0005433929879	24125	Economy	11600.00
0005433925978	24125	Economy	11600.00
0005433925369	24125	Economy	11600.00
0005433925615	24125	Economy	11600.00
0005433929872	24125	Economy	11600.00
0005433925614	24125	Economy	11600.00
0005433925735	24125	Economy	11600.00
0005433925906	24125	Economy	11600.00
0005433926010	24125	Economy	11600.00
0005433925561	24125	Economy	11600.00
0005433929881	24125	Economy	11600.00
0005433925752	24125	Economy	11600.00
0005433925368	24125	Economy	11600.00
0005433925880	24125	Economy	11600.00
0005433929712	24125	Economy	11600.00
0005433925635	24125	Economy	11600.00
0005433926086	24125	Economy	11600.00
0005433925933	24125	Economy	11600.00
0005433929721	24125	Economy	11600.00
0005433929711	24125	Economy	11600.00
0005433926078	24125	Economy	11600.00
0005433235807	296	Business	83700.00
0005433235926	296	Business	83700.00
0005433235844	296	Business	83700.00
0005433131820	296	Business	83700.00
0005433235936	296	Business	83700.00
0005433290058	296	Business	83700.00
0005433113590	296	Business	83700.00
0005433131805	296	Business	83700.00
0005433235927	296	Comfort	47400.00
0005434032149	296	Comfort	47400.00
0005433235892	296	Comfort	47400.00
0005433235580	296	Comfort	47400.00
0005433181697	296	Comfort	47400.00
0005433181723	296	Comfort	47400.00
0005433235798	296	Comfort	47400.00
0005433181808	296	Comfort	47400.00
0005434032140	296	Comfort	47400.00
0005433181836	296	Economy	27900.00
0005433766735	296	Economy	27900.00
0005433181729	296	Economy	27900.00
0005433181824	296	Economy	27900.00
0005433290060	296	Economy	27900.00
0005433235905	296	Economy	27900.00
0005433131834	296	Economy	27900.00
0005433290040	296	Economy	27900.00
0005433235964	296	Economy	27900.00
0005433113596	296	Economy	27900.00
0005433235799	296	Economy	27900.00
0005433181722	296	Economy	27900.00
0005433131831	296	Economy	27900.00
0005433235730	296	Economy	27900.00
0005433235875	296	Economy	27900.00
0005433235735	296	Economy	27900.00
0005433235948	296	Economy	27900.00
0005434032130	296	Economy	27900.00
0005433290049	296	Economy	27900.00
0005433131814	296	Economy	27900.00
0005433290061	296	Economy	30700.00
0005433235932	296	Economy	30700.00
0005433235719	296	Economy	30700.00
0005433235965	296	Economy	27900.00
0005433181727	296	Economy	27900.00
0005433181835	296	Economy	27900.00
0005433235906	296	Economy	27900.00
0005433235539	296	Economy	27900.00
0005433290039	296	Economy	27900.00
0005433181777	296	Economy	27900.00
0005433235763	296	Economy	27900.00
0005433181772	296	Economy	27900.00
0005433290046	296	Economy	27900.00
0005433181819	296	Economy	27900.00
0005433126975	296	Economy	27900.00
0005433235967	296	Economy	27900.00
0005433181758	296	Economy	27900.00
0005433766740	296	Economy	27900.00
0005433235579	296	Economy	27900.00
0005433766724	296	Economy	27900.00
0005433235736	296	Economy	27900.00
0005433235949	296	Economy	27900.00
0005433235756	296	Economy	27900.00
0005433235737	296	Economy	27900.00
0005433181718	296	Economy	27900.00
0005433181773	296	Economy	27900.00
0005433181696	296	Economy	27900.00
0005433181759	296	Economy	27900.00
0005433236007	296	Economy	27900.00
0005433766739	296	Economy	27900.00
0005433290016	296	Economy	27900.00
0005433235660	296	Economy	27900.00
0005433235784	296	Economy	27900.00
0005433111551	296	Economy	30700.00
0005433235933	296	Economy	27900.00
0005433235758	296	Economy	27900.00
0005433235963	296	Economy	27900.00
0005433235972	296	Economy	27900.00
0005433181825	296	Economy	27900.00
0005433235928	296	Economy	27900.00
0005433235998	296	Economy	27900.00
0005433766734	296	Economy	27900.00
0005433290032	296	Economy	27900.00
0005433113595	296	Economy	27900.00
0005433131804	296	Economy	27900.00
0005433235909	296	Economy	27900.00
0005433181754	296	Economy	27900.00
0005433131824	296	Economy	27900.00
0005433290057	296	Economy	27900.00
0005433181760	296	Economy	27900.00
0005433181743	296	Economy	27900.00
0005433766733	296	Economy	27900.00
0005433235985	296	Economy	27900.00
0005433131813	296	Economy	27900.00
0005433235691	296	Economy	27900.00
0005433236047	296	Economy	27900.00
0005434032133	296	Economy	27900.00
0005433235893	296	Economy	27900.00
0005433235783	296	Economy	27900.00
0005434032146	296	Economy	27900.00
0005433235659	296	Economy	27900.00
0005433290033	296	Economy	27900.00
0005433181728	296	Economy	27900.00
0005434728853	9827	Business	83700.00
0005434731272	9827	Business	83700.00
0005435142918	9827	Business	83700.00
0005434728775	9827	Business	83700.00
0005434728842	9827	Business	83700.00
0005434728539	9827	Business	83700.00
0005434552740	9827	Business	83700.00
0005434728624	9827	Business	83700.00
0005434728626	9827	Comfort	47400.00
0005434728522	9827	Comfort	47400.00
0005434731275	9827	Comfort	47400.00
0005434728945	9827	Comfort	47400.00
0005434728217	9827	Comfort	47400.00
0005434728691	9827	Comfort	47400.00
0005434728932	9827	Comfort	47400.00
0005434552689	9827	Comfort	47400.00
0005434728647	9827	Comfort	47400.00
0005434552718	9827	Comfort	47400.00
0005435142901	9827	Comfort	47400.00
0005434728648	9827	Comfort	47400.00
0005434728734	9827	Comfort	47400.00
0005434552730	9827	Comfort	47400.00
0005434728390	9827	Comfort	47400.00
0005434728795	9827	Comfort	47400.00
0005435142895	9827	Comfort	47400.00
0005434728439	9827	Comfort	47400.00
0005434552775	9827	Comfort	47400.00
0005434728933	9827	Comfort	47400.00
0005434552690	9827	Comfort	47400.00
0005434728964	9827	Economy	27900.00
0005434552607	9827	Economy	27900.00
0005434728323	9827	Economy	27900.00
0005434731278	9827	Economy	27900.00
0005434728602	9827	Economy	27900.00
0005434728538	9827	Economy	27900.00
0005434728671	9827	Economy	27900.00
0005434731277	9827	Economy	27900.00
0005434731266	9827	Economy	27900.00
0005434728381	9827	Economy	27900.00
0005434728545	9827	Economy	27900.00
0005434552611	9827	Economy	27900.00
0005434728868	9827	Economy	27900.00
0005434728431	9827	Economy	27900.00
0005434552442	9827	Economy	27900.00
0005434552514	9827	Economy	27900.00
0005435142863	9827	Economy	27900.00
0005434728629	9827	Economy	27900.00
0005434728869	9827	Economy	27900.00
0005434728879	9827	Economy	27900.00
0005434552608	9827	Economy	27900.00
0005435142921	9827	Economy	27900.00
0005434552731	9827	Economy	27900.00
0005434728818	9827	Economy	27900.00
0005434728863	9827	Economy	30700.00
0005434728678	9827	Economy	30700.00
0005434552678	9827	Economy	27900.00
0005434728449	9827	Economy	30700.00
0005434728598	9827	Economy	27900.00
0005434728919	9827	Economy	30700.00
0005434728529	9827	Economy	27900.00
0005434729049	9827	Economy	27900.00
0005434728934	9827	Economy	27900.00
0005434728698	9827	Economy	27900.00
0005434728625	9827	Economy	27900.00
0005434728670	9827	Economy	27900.00
0005434728944	9827	Economy	27900.00
0005434302566	9827	Economy	27900.00
0005434728681	9827	Economy	27900.00
0005434552764	9827	Economy	27900.00
0005434728492	9827	Economy	27900.00
0005434552749	9827	Economy	27900.00
0005434552353	9827	Economy	27900.00
0005434728794	9827	Economy	27900.00
0005434552612	9827	Economy	27900.00
0005434728628	9827	Economy	27900.00
0005435142872	9827	Economy	27900.00
0005434728726	9827	Economy	27900.00
0005434728475	9827	Economy	27900.00
0005434728729	9827	Economy	27900.00
0005434731267	9827	Economy	27900.00
0005434729015	9827	Economy	27900.00
0005434728686	9827	Economy	27900.00
0005434728218	9827	Economy	27900.00
0005433236067	9827	Economy	27900.00
0005434728769	9827	Economy	27900.00
0005435142884	9827	Economy	27900.00
0005434735832	9827	Economy	27900.00
0005435142910	9827	Economy	27900.00
0005435142849	9827	Economy	27900.00
0005434552741	9827	Economy	27900.00
0005434552729	9827	Economy	27900.00
0005434728713	9827	Economy	27900.00
0005434302572	9827	Economy	27900.00
0005435142909	9827	Economy	27900.00
0005434552725	9827	Economy	27900.00
0005434552590	9827	Economy	27900.00
0005434728920	9827	Economy	27900.00
0005434731276	9827	Economy	27900.00
0005434728720	9827	Economy	27900.00
0005433290067	9827	Economy	27900.00
0005434731286	9827	Economy	27900.00
0005434552523	9827	Economy	27900.00
0005434728776	9827	Economy	27900.00
0005434552739	9827	Economy	27900.00
0005434728878	9827	Economy	30700.00
0005434728677	9827	Economy	27900.00
0005434728877	9827	Economy	27900.00
0005434552634	9827	Economy	27900.00
0005434728843	9827	Economy	27900.00
0005434552495	9827	Economy	27900.00
0005434728974	9827	Economy	27900.00
0005435142891	9827	Economy	27900.00
0005434552844	9827	Economy	27900.00
0005434552688	9827	Economy	27900.00
0005434728546	9827	Economy	27900.00
0005434728705	9827	Economy	27900.00
0005434728745	9827	Economy	27900.00
0005435142929	9827	Economy	27900.00
0005435142851	9827	Economy	27900.00
0005434735813	9827	Economy	27900.00
0005434728861	9827	Economy	27900.00
0005434728560	9827	Economy	27900.00
0005434728831	9827	Economy	27900.00
0005434728295	9827	Economy	27900.00
0005435142850	9827	Economy	27900.00
0005434728752	9827	Economy	27900.00
0005434728627	9827	Economy	27900.00
0005434552515	9827	Economy	27900.00
0005434728146	9827	Economy	27900.00
0005434728530	9827	Economy	27900.00
0005434728448	9827	Economy	27900.00
0005434728921	9827	Economy	27900.00
0005434728697	9827	Economy	27900.00
0005434728484	9827	Economy	27900.00
0005433236068	9827	Economy	27900.00
0005434728474	9827	Economy	27900.00
0005434731279	9827	Economy	27900.00
0005434552719	9827	Economy	27900.00
0005434728856	9827	Economy	27900.00
0005434728746	9827	Economy	27900.00
0005434302555	9827	Economy	27900.00
0005434728724	9827	Economy	27900.00
0005434552677	9827	Economy	27900.00
0005435215389	7752	Business	42100.00
0005435215342	7752	Business	42100.00
0005435215314	7752	Business	42100.00
0005435215298	7752	Business	42100.00
0005435215322	7752	Business	42100.00
0005435215339	7752	Business	42100.00
0005435215357	7752	Business	42100.00
0005435215042	7752	Comfort	23900.00
0005435283441	7752	Comfort	23900.00
0005435215415	7752	Comfort	23900.00
0005435283443	7752	Comfort	23900.00
0005435215171	7752	Comfort	23900.00
0005432531845	7752	Comfort	23900.00
0005432150431	7752	Comfort	23900.00
0005435215041	7752	Comfort	23900.00
0005435215311	7752	Comfort	23900.00
0005435215441	7752	Comfort	23900.00
0005435283503	7752	Comfort	23900.00
0005435283494	7752	Comfort	23900.00
0005435283479	7752	Comfort	23900.00
0005435215408	7752	Comfort	23900.00
0005435215352	7752	Comfort	23900.00
0005435215323	7752	Economy	14000.00
0005435215205	7752	Economy	14000.00
0005435631042	7752	Economy	14000.00
0005435725733	7752	Economy	14000.00
0005435215381	7752	Economy	14000.00
0005435215321	7752	Economy	14000.00
0005435215254	7752	Economy	14000.00
0005435215191	7752	Economy	14000.00
0005435215475	7752	Economy	14000.00
0005435215300	7752	Economy	14000.00
0005435215146	7752	Economy	14000.00
0005435215241	7752	Economy	14000.00
0005435283480	7752	Economy	14000.00
0005435215281	7752	Economy	14000.00
0005435215409	7752	Economy	14000.00
0005435215190	7752	Economy	14000.00
0005435215476	7752	Economy	14000.00
0005435215154	7752	Economy	14000.00
0005433656763	7752	Economy	14000.00
0005435283528	7752	Economy	14000.00
0005435725734	7752	Economy	14000.00
0005435283529	7752	Economy	14000.00
0005435215239	7752	Economy	14000.00
0005433656762	7752	Economy	14000.00
0005435215349	7752	Economy	14000.00
0005435283481	7752	Economy	14000.00
0005435725727	7752	Economy	14000.00
0005435215100	7752	Economy	14000.00
0005435215215	7752	Economy	14000.00
0005435215338	7752	Economy	14000.00
0005435215416	7752	Economy	14000.00
0005435725729	7752	Economy	14000.00
0005432531846	7752	Economy	14000.00
0005435215380	7752	Economy	14000.00
0005435215286	7752	Economy	14000.00
0005435215478	7752	Economy	14000.00
0005435725736	7752	Economy	14000.00
0005435215355	7752	Economy	14000.00
0005435215426	7752	Economy	14000.00
0005435215391	7752	Economy	14000.00
0005435215390	7752	Economy	14000.00
0005435631046	7752	Economy	14000.00
0005435215313	7752	Economy	14000.00
0005435215153	7752	Economy	14000.00
0005435215131	7752	Economy	14000.00
0005435725735	7752	Economy	14000.00
0005435215285	7752	Economy	14000.00
0005435215312	7752	Economy	14000.00
0005433656754	7752	Economy	14000.00
0005435215348	7752	Economy	14000.00
0005435215347	7752	Economy	14000.00
0005435215437	7752	Economy	14000.00
0005435283442	7752	Economy	14000.00
0005435215440	7752	Economy	14000.00
0005435725732	7752	Economy	14000.00
0005435215155	7752	Economy	14000.00
0005435215255	7752	Economy	14000.00
0005433656761	7752	Economy	14000.00
0005432150432	7752	Economy	14000.00
0005435215231	7752	Economy	14000.00
0005435283457	7752	Economy	14000.00
0005435215299	7752	Economy	14000.00
0005435215266	7752	Economy	14000.00
0005435725728	7752	Economy	14000.00
0005435215240	7752	Economy	14000.00
0005435215263	7752	Economy	14000.00
0005435215132	7752	Economy	14000.00
0005435283498	7752	Economy	14000.00
0005435283497	7752	Economy	14000.00
0005435215425	7752	Economy	14000.00
0005434245757	5313	Business	43100.00
0005435426603	5313	Business	43100.00
0005435319810	5313	Business	43100.00
0005435302326	5313	Business	43100.00
0005435617059	5313	Business	43100.00
0005435426579	5313	Business	43100.00
0005434245674	5313	Business	43100.00
0005434245727	5313	Business	43100.00
0005434245742	5313	Business	43100.00
0005435617058	5313	Business	43100.00
0005435426709	5313	Business	43100.00
0005434245720	5313	Comfort	24400.00
0005434245704	5313	Comfort	24400.00
0005435426719	5313	Comfort	24400.00
0005435305060	5313	Comfort	24400.00
0005435426587	5313	Comfort	24400.00
0005435426558	5313	Comfort	24400.00
0005435426747	5313	Comfort	24400.00
0005434245759	5313	Comfort	24400.00
0005434245795	5313	Comfort	24400.00
0005435426557	5313	Comfort	24400.00
0005434245755	5313	Comfort	24400.00
0005435426710	5313	Comfort	24400.00
0005435546242	5313	Economy	14400.00
0005435042923	5313	Economy	14400.00
0005434245796	5313	Economy	14400.00
0005435426651	5313	Economy	14400.00
0005435426711	5313	Economy	14400.00
0005435426617	5313	Economy	14400.00
0005435305062	5313	Economy	14400.00
0005434656596	5313	Economy	14400.00
0005434245786	5313	Economy	14400.00
0005435426586	5313	Economy	14400.00
0005434245818	5313	Economy	14400.00
0005435426745	5313	Economy	14400.00
0005435426546	5313	Economy	14400.00
0005435426705	5313	Economy	14400.00
0005435617060	5313	Economy	14400.00
0005434656611	5313	Economy	15800.00
0005435551786	5313	Economy	15800.00
0005434245715	5313	Economy	14400.00
0005434245839	5313	Economy	14400.00
0005435426618	5313	Economy	14400.00
0005435768104	5313	Economy	14400.00
0005435426684	5313	Economy	14400.00
0005435426556	5313	Economy	14400.00
0005434245817	5313	Economy	14400.00
0005435426261	5313	Economy	14400.00
0005435302325	5313	Economy	14400.00
0005434245741	5313	Economy	14400.00
0005435546241	5313	Economy	14400.00
0005435768103	5313	Economy	14400.00
0005435305065	5313	Economy	14400.00
0005435042922	5313	Economy	14400.00
0005435302332	5313	Economy	14400.00
0005435042930	5313	Economy	14400.00
0005435042929	5313	Economy	14400.00
0005435426787	5313	Economy	14400.00
0005432841062	5313	Economy	14400.00
0005435426704	5313	Economy	14400.00
0005435302330	5313	Economy	14400.00
0005435305071	5313	Economy	14400.00
0005435302328	5313	Economy	14400.00
0005432363490	5313	Economy	14400.00
0005435426791	5313	Economy	14400.00
0005434245785	5313	Economy	14400.00
0005434245779	5313	Economy	14400.00
0005435302333	5313	Economy	15800.00
0005434656610	5313	Economy	14400.00
0005435426788	5313	Economy	14400.00
0005435426622	5313	Economy	14400.00
0005435426402	5313	Economy	14400.00
0005435305072	5313	Economy	14400.00
0005435426783	5313	Economy	14400.00
0005435305069	5313	Economy	14400.00
0005434245675	5313	Economy	14400.00
0005435426545	5313	Economy	14400.00
0005432363507	5313	Economy	14400.00
0005435426530	5313	Economy	14400.00
0005435426782	5313	Economy	14400.00
0005435302329	5313	Economy	14400.00
0005435380440	5313	Economy	14400.00
0005435319791	5313	Economy	14400.00
0005435426650	5313	Economy	14400.00
0005435654513	5313	Economy	14400.00
0005435380419	5313	Economy	14400.00
0005432363508	5313	Economy	14400.00
0005435305064	5313	Economy	14400.00
0005435426653	5313	Economy	14400.00
0005435426529	5313	Economy	14400.00
0005435426679	5313	Economy	14400.00
0005434245794	5313	Economy	14400.00
0005435302331	5313	Economy	14400.00
0005435305059	5313	Economy	14400.00
0005435426192	5313	Economy	14400.00
0005435426764	5313	Economy	14400.00
0005435319811	5313	Economy	14400.00
0005432841063	5313	Economy	14400.00
0005434245673	5313	Economy	14400.00
0005434245754	5313	Economy	14400.00
0005435426790	5313	Economy	14400.00
0005435426612	5313	Economy	14400.00
0005435768105	5313	Economy	14400.00
0005434245758	5313	Economy	14400.00
0005434245703	5313	Economy	14400.00
0005434345029	10900	Business	43100.00
0005435616867	10900	Business	43100.00
0005435616666	10900	Business	43100.00
0005435616976	10900	Business	43100.00
0005435616492	10900	Business	43100.00
0005434345186	10900	Business	43100.00
0005434573742	10900	Business	43100.00
0005434573751	10900	Business	43100.00
0005435616956	10900	Business	43100.00
0005435616698	10900	Business	43100.00
0005435616905	10900	Business	43100.00
0005434345103	10900	Business	43100.00
0005434573687	10900	Business	43100.00
0005434573705	10900	Business	43100.00
0005435616491	10900	Business	43100.00
0005435616370	10900	Comfort	24400.00
0005435426854	10900	Comfort	24400.00
0005435616930	10900	Comfort	24400.00
0005434344989	10900	Comfort	24400.00
0005435616714	10900	Comfort	24400.00
0005434345065	10900	Comfort	24400.00
0005434573720	10900	Comfort	24400.00
0005434345025	10900	Comfort	24400.00
0005434345014	10900	Comfort	24400.00
0005434345110	10900	Comfort	24400.00
0005434345225	10900	Comfort	24400.00
0005435616599	10900	Comfort	24400.00
0005434345149	10900	Comfort	24400.00
0005435616619	10900	Economy	14400.00
0005435616457	10900	Economy	14400.00
0005434345060	10900	Economy	14400.00
0005435616625	10900	Economy	14400.00
0005434345137	10900	Economy	14400.00
0005434573704	10900	Economy	14400.00
0005435616629	10900	Economy	14400.00
0005435616764	10900	Economy	14400.00
0005435616655	10900	Economy	14400.00
0005435097473	10900	Economy	14400.00
0005435097458	10900	Economy	14400.00
0005435616477	10900	Economy	14400.00
0005435616777	10900	Economy	14400.00
0005434345206	10900	Economy	14400.00
0005434573750	10900	Economy	14400.00
0005435616687	10900	Economy	14400.00
0005434345205	10900	Economy	14400.00
0005435616371	10900	Economy	14400.00
0005435617192	10900	Economy	14400.00
0005435616860	10900	Economy	14400.00
0005435426853	10900	Economy	14400.00
0005435616572	10900	Economy	14400.00
0005434344990	10900	Economy	14400.00
0005435616797	10900	Economy	14400.00
0005434573697	10900	Economy	14400.00
0005434345053	10900	Economy	14400.00
0005434345226	10900	Economy	14400.00
0005434573733	10900	Economy	14400.00
0005435616878	10900	Economy	15800.00
0005435616661	10900	Economy	15800.00
0005435616955	10900	Economy	14400.00
0005435616823	10900	Economy	14400.00
0005435616770	10900	Economy	14400.00
0005435617189	10900	Economy	14400.00
0005434345150	10900	Economy	14400.00
0005435097433	10900	Economy	14400.00
0005434344975	10900	Economy	14400.00
0005435616929	10900	Economy	14400.00
0005435616557	10900	Economy	14400.00
0005435426856	10900	Economy	14400.00
0005435616722	10900	Economy	14400.00
0005435616923	10900	Economy	14400.00
0005435616765	10900	Economy	14400.00
0005435616637	10900	Economy	14400.00
0005435490330	10900	Economy	14400.00
0005435616607	10900	Economy	14400.00
0005435616822	10900	Economy	14400.00
0005435616897	10900	Economy	14400.00
0005434345185	10900	Economy	14400.00
0005434344991	10900	Economy	14400.00
0005435616907	10900	Economy	14400.00
0005434345210	10900	Economy	14400.00
0005435616697	10900	Economy	14400.00
0005435616583	10900	Economy	14400.00
0005435426852	10900	Economy	14400.00
0005435616778	10900	Economy	14400.00
0005435616938	10900	Economy	14400.00
0005435616478	10900	Economy	14400.00
0005435616544	10900	Economy	14400.00
0005434573698	10900	Economy	14400.00
0005434345144	10900	Economy	14400.00
0005435616801	10900	Economy	14400.00
0005435616821	10900	Economy	14400.00
0005434573721	10900	Economy	14400.00
0005435616918	10900	Economy	14400.00
0005435616604	10900	Economy	14400.00
0005435616556	10900	Economy	14400.00
0005435616861	10900	Economy	14400.00
0005434345033	10900	Economy	14400.00
0005435616937	10900	Economy	14400.00
0005435616647	10900	Economy	14400.00
0005435097471	10900	Economy	14400.00
0005434345027	10900	Economy	14400.00
0005434345147	10900	Economy	14400.00
0005434573699	10900	Economy	14400.00
0005434345194	10900	Economy	14400.00
0005435616476	10900	Economy	14400.00
0005434345059	10900	Economy	14400.00
0005434573713	10900	Economy	14400.00
0005435616605	10900	Economy	14400.00
0005433719242	10900	Economy	14400.00
0005435490332	10900	Economy	15800.00
0005435097460	10900	Economy	15800.00
0005435616906	10900	Economy	15800.00
0005435616924	10900	Economy	14400.00
0005434345104	10900	Economy	14400.00
0005435616882	10900	Economy	14400.00
0005435616873	10900	Economy	14400.00
0005435616558	10900	Economy	14400.00
0005434345159	10900	Economy	14400.00
0005435616582	10900	Economy	14400.00
0005434344976	10900	Economy	14400.00
0005435616551	10900	Economy	14400.00
0005434345028	10900	Economy	14400.00
0005434573696	10900	Economy	14400.00
0005435097472	10900	Economy	14400.00
0005435616416	10900	Economy	14400.00
0005435490333	10900	Economy	14400.00
0005434573728	10900	Economy	14400.00
0005435616877	10900	Economy	14400.00
0005435616576	10900	Economy	14400.00
0005435097459	10900	Economy	14400.00
0005435616862	10900	Economy	14400.00
0005435616654	10900	Economy	14400.00
0005435616896	10900	Economy	14400.00
0005435616833	10900	Economy	14400.00
0005435426855	10900	Economy	14400.00
0005434345066	10900	Economy	14400.00
0005435616479	10900	Economy	14400.00
0005434345024	10900	Economy	14400.00
0005435616618	10900	Economy	14400.00
0005435616475	10900	Economy	14400.00
0005435616427	10900	Economy	14400.00
0005435617241	10900	Economy	14400.00
0005435616575	10900	Economy	14400.00
0005435616480	10900	Economy	14400.00
0005434345109	10900	Economy	14400.00
0005435097455	10900	Economy	14400.00
0005435490334	10900	Economy	14400.00
0005435616719	10900	Economy	14400.00
0005434345143	10900	Economy	14400.00
0005435616573	10900	Economy	14400.00
0005432461177	3326	Business	18800.00
0005435933582	3326	Business	18800.00
0005434312392	3326	Business	18800.00
0005435860692	3326	Business	18800.00
0005435858709	3326	Business	18800.00
0005435860693	3326	Business	18800.00
0005435860694	3326	Business	18800.00
0005435858712	3326	Business	18800.00
0005432461228	3326	Business	18800.00
0005435933584	3326	Business	18800.00
0005432461051	3326	Business	18800.00
0005432461372	3326	Business	18800.00
0005435860708	3326	Business	18800.00
0005435860691	3326	Economy	6900.00
0005435933576	3326	Economy	6900.00
0005432461016	3326	Economy	6300.00
0005435860660	3326	Economy	6300.00
0005432461337	3326	Economy	6300.00
0005432461146	3326	Economy	6300.00
0005434150237	3326	Economy	6300.00
0005435860681	3326	Economy	6300.00
0005432461285	3326	Economy	6300.00
0005432461015	3326	Economy	6300.00
0005435856353	3326	Economy	6300.00
0005432461245	3326	Economy	6300.00
0005434326103	3326	Economy	6300.00
0005432461178	3326	Economy	6300.00
0005433806411	3326	Economy	6300.00
0005434505326	3326	Economy	6300.00
0005432461371	3326	Economy	6300.00
0005435860659	3326	Economy	6300.00
0005432461275	3326	Economy	6300.00
0005432461338	3326	Economy	6300.00
0005435858699	3326	Economy	6300.00
0005432461213	3326	Economy	6300.00
0005435933583	3326	Economy	6300.00
0005434311288	3326	Economy	6300.00
0005434266054	3326	Economy	6900.00
0005435858711	3326	Economy	6900.00
0005432461147	3326	Economy	6900.00
0005432460967	3326	Economy	6900.00
0005434266055	3326	Economy	6300.00
0005434326102	3326	Economy	6300.00
0005432461170	3326	Economy	6300.00
0005434150238	3326	Economy	6300.00
0005435860707	3326	Economy	6300.00
0005432461318	3326	Economy	6300.00
0005432461276	3326	Economy	6300.00
0005432461052	3326	Economy	6300.00
0005432461194	3326	Economy	6300.00
0005435860679	3326	Economy	6300.00
0005432461212	3326	Economy	6300.00
0005435933574	3326	Economy	6300.00
0005432461342	3326	Economy	6300.00
0005435856355	3326	Economy	6300.00
0005434326056	3326	Economy	6300.00
0005432461243	3326	Economy	6300.00
0005432461353	3326	Economy	6300.00
0005432461183	3326	Economy	6300.00
0005434505325	3326	Economy	6300.00
0005432461185	3326	Economy	6300.00
0005432461179	3326	Economy	6300.00
0005435860720	3326	Economy	6300.00
0005432461317	3326	Economy	6300.00
0005435856354	3326	Economy	6300.00
0005435933586	3326	Economy	6300.00
0005435886552	3327	Business	18800.00
0005435886694	3327	Business	18800.00
0005435886680	3327	Business	18800.00
0005435886579	3327	Business	18800.00
0005435886553	3327	Business	18800.00
0005435886546	3327	Business	18800.00
0005435886670	3327	Business	18800.00
0005435886385	3327	Business	18800.00
0005435886714	3327	Business	18800.00
0005435886789	3327	Business	18800.00
0005435886629	3327	Business	18800.00
0005435886781	3327	Business	18800.00
0005435886647	3327	Economy	6900.00
0005435886593	3327	Economy	6300.00
0005435886705	3327	Economy	6300.00
0005435886469	3327	Economy	6300.00
0005435886696	3327	Economy	6300.00
0005435886831	3327	Economy	6300.00
0005435886701	3327	Economy	6300.00
0005435886435	3327	Economy	6300.00
0005435886706	3327	Economy	6300.00
0005435886724	3327	Economy	6300.00
0005435886631	3327	Economy	6300.00
0005435886544	3327	Economy	6300.00
0005435886630	3327	Economy	6300.00
0005435886677	3327	Economy	6300.00
0005435886551	3327	Economy	6300.00
0005435886793	3327	Economy	6300.00
0005435886752	3327	Economy	6300.00
0005435886774	3327	Economy	6300.00
0005435886592	3327	Economy	6300.00
0005435886280	3327	Economy	6300.00
0005435886740	3327	Economy	6300.00
0005435886521	3327	Economy	6300.00
0005435886812	3327	Economy	6300.00
0005435886545	3327	Economy	6900.00
0005435933558	3327	Economy	6300.00
0005435886659	3327	Economy	6300.00
0005435886660	3327	Economy	6300.00
0005435886713	3327	Economy	6300.00
0005435886557	3327	Economy	6300.00
0005435886472	3327	Economy	6300.00
0005435886648	3327	Economy	6300.00
0005435886639	3327	Economy	6300.00
0005435886725	3327	Economy	6300.00
0005435886450	3327	Economy	6300.00
0005435886282	3327	Economy	6300.00
0005435886558	3327	Economy	6300.00
0005435886691	3327	Economy	6300.00
0005435886695	3327	Economy	6300.00
0005435886468	3327	Economy	6300.00
0005435886281	3327	Economy	6300.00
0005435886681	3327	Economy	6300.00
0005435886679	3327	Economy	6300.00
0005435886528	3327	Economy	6300.00
0005435886775	3327	Economy	6300.00
0005435886638	3327	Economy	6300.00
0005435886577	3327	Economy	6300.00
0005435903225	3327	Economy	6300.00
0005435886645	3327	Economy	6300.00
0005435886598	3327	Economy	6300.00
0005435886578	3327	Economy	6300.00
0005435886782	3327	Economy	6300.00
0005435886361	3327	Economy	6300.00
0005435886678	3327	Economy	6300.00
0005433507653	8307	Business	18800.00
0005433507711	8307	Business	18800.00
0005432461445	8307	Business	18800.00
0005433507650	8307	Business	18800.00
0005433507686	8307	Economy	6900.00
0005433507651	8307	Economy	6900.00
0005433507706	8307	Economy	6300.00
0005433507688	8307	Economy	6300.00
0005433507646	8307	Economy	6300.00
0005433507676	8307	Economy	6300.00
0005432461446	8307	Economy	6300.00
0005433507699	8307	Economy	6300.00
0005433507648	8307	Economy	6300.00
0005433507690	8307	Economy	6300.00
0005433507687	8307	Economy	6300.00
0005433507685	8307	Economy	6300.00
0005433507649	8307	Economy	6300.00
0005433507647	8307	Economy	6300.00
0005433507679	8307	Economy	6300.00
0005433507712	8307	Economy	6300.00
0005435886872	8307	Economy	6300.00
0005435933560	8307	Economy	6300.00
0005433634684	8310	Business	18800.00
0005433634635	8310	Business	18800.00
0005433634787	8310	Business	18800.00
0005433806260	8310	Business	18800.00
0005434143782	8310	Business	18800.00
0005433634724	8310	Business	18800.00
0005433806312	8310	Business	18800.00
0005433806334	8310	Business	18800.00
0005433634690	8310	Business	18800.00
0005433634698	8310	Business	18800.00
0005433634636	8310	Business	18800.00
0005434143769	8310	Business	18800.00
0005433806287	8310	Business	18800.00
0005433806347	8310	Business	18800.00
0005434143768	8310	Economy	6900.00
0005433806159	8310	Economy	6900.00
0005434143823	8310	Economy	6900.00
0005434271362	8310	Economy	6900.00
0005433806330	8310	Economy	6300.00
0005434143758	8310	Economy	6300.00
0005433806299	8310	Economy	6300.00
0005433634800	8310	Economy	6300.00
0005433806180	8310	Economy	6300.00
0005434143778	8310	Economy	6300.00
0005433634634	8310	Economy	6300.00
0005433634786	8310	Economy	6300.00
0005433634799	8310	Economy	6300.00
0005433634682	8310	Economy	6300.00
0005434143824	8310	Economy	6300.00
0005433634650	8310	Economy	6300.00
0005433634670	8310	Economy	6300.00
0005433806255	8310	Economy	6300.00
0005433634685	8310	Economy	6300.00
0005433806297	8310	Economy	6300.00
0005434143777	8310	Economy	6300.00
0005433806218	8310	Economy	6300.00
0005433634683	8310	Economy	6300.00
0005433634637	8310	Economy	6300.00
0005433634725	8310	Economy	6300.00
0005433634589	8310	Economy	6300.00
0005433634762	8310	Economy	6300.00
0005435858748	8310	Economy	6900.00
0005433806286	8310	Economy	6900.00
0005433634514	8310	Economy	6300.00
0005433634620	8310	Economy	6900.00
0005434143759	8310	Economy	6300.00
0005433806298	8310	Economy	6300.00
0005434143783	8310	Economy	6300.00
0005433806223	8310	Economy	6300.00
0005433806313	8310	Economy	6300.00
0005433806373	8310	Economy	6300.00
0005433806314	8310	Economy	6300.00
0005433806240	8310	Economy	6300.00
0005433806346	8310	Economy	6300.00
0005433634748	8310	Economy	6300.00
0005433634699	8310	Economy	6300.00
0005433634513	8310	Economy	6300.00
0005433634626	8310	Economy	6300.00
0005434143803	8310	Economy	6300.00
0005434143799	8310	Economy	6300.00
0005433806162	8310	Economy	6300.00
0005433634726	8310	Economy	6300.00
0005433806372	8310	Economy	6300.00
0005433634588	8310	Economy	6300.00
0005433634669	8310	Economy	6300.00
0005433634591	8310	Economy	6300.00
0005433806252	8310	Economy	6300.00
0005433806040	8310	Economy	6300.00
0005434143779	8310	Economy	6300.00
0005433634764	8310	Economy	6300.00
0005433806329	8310	Economy	6300.00
0005434183633	8312	Business	18800.00
0005434150196	8312	Business	18800.00
0005434273138	8312	Business	18800.00
0005434183631	8312	Economy	6900.00
0005434265977	8312	Economy	6900.00
0005434183632	8312	Economy	6300.00
0005434265920	8312	Economy	6300.00
0005434150172	8312	Economy	6300.00
0005434266022	8312	Economy	6300.00
0005434150195	8312	Economy	6300.00
0005434265922	8312	Economy	6300.00
0005434265993	8312	Economy	6300.00
0005434266011	8312	Economy	6300.00
0005434265921	8312	Economy	6300.00
0005434273137	8312	Economy	6300.00
0005434150197	8312	Economy	6300.00
0005434265957	8312	Economy	6300.00
0005434150158	8312	Economy	6300.00
0005434266027	8312	Economy	6300.00
0005434150156	8312	Economy	6300.00
0005434265976	8312	Economy	6300.00
0005435477032	4584	Economy	3300.00
0005433722515	4584	Economy	3300.00
0005435477034	4584	Economy	3300.00
0005435477033	4584	Economy	3300.00
0005432384011	30140	Business	9900.00
0005432384207	30140	Business	9900.00
0005432728286	30140	Business	9900.00
0005432728288	30140	Business	9900.00
0005432384091	30140	Business	9900.00
0005432728301	30140	Business	9900.00
0005432384097	30140	Business	9900.00
0005432384075	30140	Business	9900.00
0005432728241	30140	Business	9900.00
0005432384129	30140	Business	9900.00
0005432384232	30140	Economy	3300.00
0005433453804	30140	Economy	3300.00
0005432384147	30140	Economy	3300.00
0005433722381	30140	Economy	3300.00
0005432384101	30140	Economy	3300.00
0005432384224	30140	Economy	3300.00
0005432384093	30140	Economy	3300.00
0005433194951	30140	Economy	3300.00
0005432384256	30140	Economy	3300.00
0005432384012	30140	Economy	3600.00
0005432384066	30140	Economy	3600.00
0005432384092	30140	Economy	3600.00
0005433194927	30140	Economy	3600.00
0005432728302	30140	Economy	3300.00
0005432384158	30140	Economy	3300.00
0005432728287	30140	Economy	3300.00
0005432384084	30140	Economy	3300.00
0005432384274	30140	Economy	3300.00
0005433451669	30140	Economy	3300.00
0005432384116	30140	Economy	3300.00
0005432384074	30140	Economy	3300.00
0005432728293	30140	Economy	3300.00
0005432384086	30140	Economy	3300.00
0005432728253	30140	Economy	3300.00
0005433195007	30140	Economy	3300.00
0005433453819	30140	Economy	3300.00
0005433722377	30140	Economy	3300.00
0005433722386	30140	Economy	3300.00
0005433722400	30140	Economy	3300.00
0005432384124	30140	Economy	3300.00
0005433194944	30140	Economy	3300.00
0005433722387	30140	Economy	3300.00
0005432384065	30140	Economy	3300.00
0005432384206	30140	Economy	3300.00
0005433194973	30140	Economy	3300.00
0005432384136	30140	Economy	3300.00
0005432384162	30140	Economy	3300.00
0005432384175	30140	Economy	3300.00
0005432384261	30140	Economy	3300.00
0005432384043	30140	Economy	3300.00
0005432384122	30140	Economy	3300.00
0005432383866	30140	Economy	3300.00
0005432728219	30140	Economy	3300.00
0005432384219	30140	Economy	3300.00
0005432384123	30140	Economy	3300.00
0005433722380	30140	Economy	3300.00
0005432383975	30140	Economy	3300.00
0005432384049	30140	Economy	3300.00
0005432384174	30140	Economy	3300.00
0005432384045	30140	Economy	3300.00
0005432384085	30140	Economy	3300.00
0005432384260	30140	Economy	3300.00
0005432384190	30140	Economy	3300.00
0005432384166	30140	Economy	3300.00
0005433194943	30140	Economy	3300.00
0005433722383	30140	Economy	3300.00
0005432384275	30140	Economy	3300.00
0005432384044	30140	Economy	3300.00
0005432384173	30140	Economy	3300.00
0005432728294	30140	Economy	3300.00
0005433722382	30140	Economy	3300.00
0005432384102	30140	Economy	3300.00
0005432384159	30140	Economy	3300.00
0005432384223	30140	Economy	3300.00
0005433722385	30140	Economy	3300.00
0005432384139	30140	Economy	3300.00
0005432384163	30140	Economy	3300.00
0005432925164	1761	Business	57200.00
0005435541653	1761	Economy	19100.00
0005432925169	1761	Economy	19100.00
0005432925168	1761	Economy	19100.00
0005435541564	21976	Business	57200.00
0005435541534	21976	Business	57200.00
0005435518439	21976	Business	57200.00
0005435541525	21976	Economy	19100.00
0005435518365	21976	Economy	21000.00
0005435541478	21976	Economy	19100.00
0005435541543	21976	Economy	19100.00
0005435541630	21976	Economy	19100.00
0005435541535	21976	Economy	19100.00
0005433517148	21976	Economy	19100.00
0005435541577	21976	Economy	19100.00
0005435518372	21976	Economy	19100.00
0005433517147	21976	Economy	19100.00
0005435541479	21976	Economy	19100.00
0005435541631	21976	Economy	19100.00
0005433517146	21976	Economy	19100.00
0005435518375	21976	Economy	19100.00
0005435518371	21976	Economy	19100.00
0005435518370	21976	Economy	19100.00
0005435518341	21976	Economy	19100.00
0005433517158	21976	Economy	19100.00
0005433517125	21976	Economy	19100.00
0005435518362	21976	Economy	19100.00
0005435518406	21976	Economy	19100.00
0005435518340	21976	Economy	19100.00
0005435541494	21976	Economy	19100.00
0005435491505	7376	Business	18500.00
0005435253155	7376	Economy	6200.00
0005435491497	7376	Economy	6200.00
0005435253208	7376	Economy	6200.00
0005434459423	7376	Economy	6200.00
0005435253189	7376	Economy	6200.00
0005435253153	7376	Economy	6200.00
0005435253188	7376	Economy	6200.00
0005435253154	7376	Economy	6200.00
0005435253146	7376	Economy	6200.00
0005435253158	7376	Economy	6200.00
0005435253180	7376	Economy	6200.00
0005432839890	28937	Business	18500.00
0005434459312	28937	Business	18500.00
0005432839864	28937	Business	18500.00
0005434459238	28937	Business	18500.00
0005434459352	28937	Business	18500.00
0005434459344	28937	Business	18500.00
0005434459319	28937	Business	18500.00
0005434459385	28937	Business	18500.00
0005432839883	28937	Economy	6200.00
0005434459387	28937	Economy	6200.00
0005434459321	28937	Economy	6200.00
0005432839880	28937	Economy	6200.00
0005434459313	28937	Economy	6200.00
0005434459276	28937	Economy	6200.00
0005432839866	28937	Economy	6200.00
0005432839836	28937	Economy	6800.00
0005432839829	28937	Economy	6800.00
0005434459323	28937	Economy	6200.00
0005434459320	28937	Economy	6200.00
0005432839889	28937	Economy	6200.00
0005432839899	28937	Economy	6200.00
0005434459379	28937	Economy	6200.00
0005432839863	28937	Economy	6200.00
0005432839859	28937	Economy	6200.00
0005432839900	28937	Economy	6200.00
0005434459386	28937	Economy	6200.00
0005432839784	28937	Economy	6200.00
0005434459358	28937	Economy	6200.00
0005434459376	28937	Economy	6200.00
0005434459384	28937	Economy	6200.00
0005432839708	28937	Economy	6200.00
0005432841069	28937	Economy	6200.00
0005432823502	28937	Economy	6200.00
0005434459286	28937	Economy	6200.00
0005432839843	28937	Economy	6200.00
0005434459378	28937	Economy	6200.00
0005434459252	28937	Economy	6200.00
0005434459365	28937	Economy	6200.00
0005434276194	8801	Business	145300.00
0005434276173	8801	Business	145300.00
0005434276195	8801	Business	145300.00
0005434276172	8801	Economy	48400.00
0005434276184	8801	Economy	48400.00
0005434276186	8801	Economy	48400.00
0005434276193	8801	Economy	48400.00
0005434276192	8801	Economy	48400.00
0005434276191	8801	Economy	48400.00
0005434276185	8801	Economy	48400.00
0005435990795	15767	Economy	48400.00
0005435990825	15767	Economy	48400.00
0005435990810	15767	Economy	48400.00
0005433476948	20626	Economy	14500.00
0005433476951	20626	Economy	14500.00
0005433476950	20626	Economy	14500.00
0005435177851	6400	Business	36600.00
0005434150057	6400	Business	36600.00
0005434150046	6400	Business	36600.00
0005435177782	6400	Economy	12200.00
0005435490333	6400	Economy	12200.00
0005435177825	6400	Economy	12200.00
0005435177822	6400	Economy	12200.00
0005435177823	6400	Economy	12200.00
0005435177824	6400	Economy	12200.00
0005435177840	6400	Economy	12200.00
0005435177756	6400	Economy	12200.00
0005435177829	6400	Economy	12200.00
0005435177841	6400	Economy	13400.00
0005434150045	6400	Economy	13400.00
0005435490334	6400	Economy	13400.00
0005435490332	6400	Economy	12200.00
0005435177834	6400	Economy	12200.00
0005435177861	6400	Economy	12200.00
0005435490330	6400	Economy	12200.00
0005435177786	6400	Economy	12200.00
0005435177792	6400	Economy	12200.00
0005435177787	6400	Economy	12200.00
0005435177789	6400	Economy	12200.00
0005435177793	6400	Economy	12200.00
0005434150049	6400	Economy	12200.00
0005435177798	6400	Economy	12200.00
0005435177771	6400	Economy	12200.00
0005435177697	6400	Economy	12200.00
0005434150053	6400	Economy	12200.00
0005435177811	6400	Economy	12200.00
0005435177838	6400	Economy	12200.00
0005432361681	20988	Business	36600.00
0005432361751	20988	Business	36600.00
0005432361537	20988	Business	36600.00
0005432336361	20988	Business	36600.00
0005432336339	20988	Business	36600.00
0005432361622	20988	Business	36600.00
0005432361604	20988	Economy	12200.00
0005432361630	20988	Economy	12200.00
0005432361628	20988	Economy	12200.00
0005432361674	20988	Economy	12200.00
0005432361544	20988	Economy	12200.00
0005432336340	20988	Economy	12200.00
0005432361563	20988	Economy	12200.00
0005432336358	20988	Economy	12200.00
0005432361750	20988	Economy	12200.00
0005432361533	20988	Economy	12200.00
0005432361532	20988	Economy	12200.00
0005432361540	20988	Economy	12200.00
0005432361559	20988	Economy	12200.00
0005432361736	20988	Economy	12200.00
0005432361560	20988	Economy	12200.00
0005432361682	20988	Economy	12200.00
0005432361543	20988	Economy	12200.00
0005432361621	20988	Economy	12200.00
0005432361713	20988	Economy	12200.00
0005432361742	20988	Economy	12200.00
0005432361636	20988	Economy	12200.00
0005432361743	20988	Economy	12200.00
0005432336375	20988	Economy	12200.00
0005432361725	20988	Economy	12200.00
0005432336362	20988	Economy	12200.00
0005432363501	20988	Economy	13400.00
0005432361744	20988	Economy	13400.00
0005432361562	20988	Economy	13400.00
0005432363500	20988	Economy	12200.00
0005432361653	20988	Economy	12200.00
0005432336329	20988	Economy	12200.00
0005432361635	20988	Economy	12200.00
0005432361623	20988	Economy	12200.00
0005432361715	20988	Economy	12200.00
0005432361629	20988	Economy	12200.00
0005432361522	20988	Economy	12200.00
0005432361699	20988	Economy	12200.00
0005432363511	20988	Economy	12200.00
0005432361727	20988	Economy	12200.00
0005432361536	20988	Economy	12200.00
0005432361596	20988	Economy	12200.00
0005432361683	20988	Economy	12200.00
0005432363503	20988	Economy	12200.00
0005432361603	20988	Economy	12200.00
0005432363493	20988	Economy	12200.00
0005432363510	20988	Economy	12200.00
0005432361437	20988	Economy	12200.00
0005432336353	20988	Economy	12200.00
0005432361541	20988	Economy	12200.00
0005432361735	20988	Economy	12200.00
0005432363502	20988	Economy	12200.00
0005432361554	20988	Economy	12200.00
0005432361595	20988	Economy	12200.00
0005432361675	20988	Economy	12200.00
0005432361714	20988	Economy	12200.00
0005432361561	20988	Economy	12200.00
0005432361606	20988	Economy	12200.00
0005434459342	17741	Economy	3400.00
0005434459392	17741	Economy	3400.00
0005434461706	17741	Economy	3400.00
0005434463995	17741	Economy	3100.00
0005434463994	17741	Economy	3100.00
0005434461698	17741	Economy	3100.00
0005434459325	17741	Economy	3100.00
0005434448411	17741	Economy	3100.00
0005434459382	17741	Economy	3100.00
0005434459372	17741	Economy	3100.00
0005434459377	17741	Economy	3100.00
0005434459414	17741	Economy	3100.00
0005434186286	17741	Economy	3100.00
0005434461697	17741	Economy	3100.00
0005434459340	17741	Economy	3100.00
0005434463982	17741	Economy	3100.00
0005434459328	17741	Economy	3100.00
0005434459419	17741	Economy	3100.00
0005434459359	17741	Economy	3100.00
0005434459420	17741	Economy	3100.00
0005434459360	17741	Economy	3100.00
0005434459350	17741	Economy	3100.00
0005434459390	17741	Economy	3100.00
0005434448412	17741	Economy	3100.00
0005434459329	17741	Economy	3100.00
0005434459423	29104	Economy	3100.00
0005435220514	21431	Economy	6600.00
0005432605515	21431	Economy	6600.00
0005435221553	21431	Economy	6600.00
0005435218143	21431	Economy	6600.00
0005435218144	21431	Economy	6600.00
0005435220516	21431	Economy	6600.00
0005435220515	21431	Economy	6600.00
0005432605196	31670	Economy	7300.00
0005432605443	31670	Economy	7300.00
0005432605362	31670	Economy	6600.00
0005432605342	31670	Economy	6600.00
0005432605377	31670	Economy	6600.00
0005432605466	31670	Economy	6600.00
0005432605424	31670	Economy	6600.00
0005432605363	31670	Economy	6600.00
0005432605379	31670	Economy	6600.00
0005432605361	31670	Economy	6600.00
0005432605315	31670	Economy	6600.00
0005432605317	31670	Economy	6600.00
0005432605344	31670	Economy	6600.00
0005432605378	31670	Economy	6600.00
0005432605364	31670	Economy	6600.00
0005432605358	31670	Economy	6600.00
0005432605311	31670	Economy	6600.00
0005432605477	31670	Economy	6600.00
0005432605376	31670	Economy	6600.00
0005432605427	31670	Economy	6600.00
0005432605425	31670	Economy	6600.00
0005432605357	31670	Economy	6600.00
0005432605287	31670	Economy	6600.00
0005432605442	31670	Economy	6600.00
0005432605316	31670	Economy	6600.00
0005432605195	31670	Economy	6600.00
0005432605478	31670	Economy	6600.00
0005432605391	31670	Economy	6600.00
0005432605318	31670	Economy	6600.00
0005432605401	31670	Economy	6600.00
0005432605285	31670	Economy	6600.00
0005432605332	31670	Economy	6600.00
0005432605441	31670	Economy	6600.00
0005432605431	31670	Economy	6600.00
0005432605426	31670	Economy	6600.00
0005432605372	31670	Economy	6600.00
0005432605373	31670	Economy	6600.00
0005432605390	31670	Economy	6600.00
0005432605286	31670	Economy	6600.00
0005432605370	31670	Economy	6600.00
0005432605385	31670	Economy	6600.00
0005432605388	31670	Economy	6600.00
0005432605400	31670	Economy	6600.00
0005433293413	12311	Economy	17800.00
0005433293396	12311	Economy	17800.00
0005433293429	12311	Economy	17800.00
0005433293422	12311	Economy	17800.00
0005433293393	12311	Economy	17800.00
0005433293425	12311	Economy	17800.00
0005433293405	12311	Economy	17800.00
0005433293406	12311	Economy	17800.00
0005433293408	12311	Economy	17800.00
0005433293412	12311	Economy	17800.00
0005433293402	12311	Economy	17800.00
0005433293409	12311	Economy	17800.00
0005433293392	12311	Economy	17800.00
0005434606935	18890	Economy	6600.00
0005434606930	18890	Economy	6600.00
0005434606920	18890	Economy	6600.00
0005434606931	18890	Economy	6600.00
0005434606929	18890	Economy	6600.00
0005434606917	18890	Economy	6600.00
0005434606921	18890	Economy	6600.00
0005433293371	406	Business	44500.00
0005432891523	406	Business	44500.00
0005432891551	406	Business	44500.00
0005432891521	406	Business	44500.00
0005432891485	406	Economy	14800.00
0005432891532	406	Economy	14800.00
0005433293430	406	Economy	14800.00
0005432749853	406	Economy	16300.00
0005434152864	406	Economy	14800.00
0005432891552	406	Economy	14800.00
0005433875408	406	Economy	14800.00
0005432891550	406	Economy	14800.00
0005432891504	406	Economy	14800.00
0005432891540	406	Economy	14800.00
0005432891524	406	Economy	14800.00
0005432891476	406	Economy	14800.00
0005433293420	406	Economy	14800.00
0005433293372	406	Economy	14800.00
0005433875426	406	Economy	14800.00
0005432891505	406	Economy	14800.00
0005432891520	406	Economy	14800.00
0005432891525	406	Economy	14800.00
0005432891490	406	Economy	14800.00
0005434152862	406	Economy	14800.00
0005432891499	406	Economy	14800.00
0005433293431	406	Economy	14800.00
0005432891486	406	Economy	14800.00
0005434152863	406	Economy	14800.00
0005432891528	406	Economy	14800.00
0005432748684	406	Economy	14800.00
0005433293401	406	Economy	14800.00
0005433293397	406	Economy	14800.00
0005433293404	406	Economy	14800.00
0005435154650	12045	Business	44500.00
0005435154657	12045	Business	44500.00
0005432748626	12045	Business	44500.00
0005432748510	12045	Business	44500.00
0005432748603	12045	Business	44500.00
0005432748631	12045	Business	44500.00
0005432748461	12045	Business	44500.00
0005432749841	12045	Business	44500.00
0005432748657	12045	Economy	14800.00
0005435154656	12045	Economy	14800.00
0005435154645	12045	Economy	14800.00
0005432753376	12045	Economy	14800.00
0005432749840	12045	Economy	14800.00
0005432748627	12045	Economy	16300.00
0005432753378	12045	Economy	16300.00
0005432748574	12045	Economy	14800.00
0005432748653	12045	Economy	14800.00
0005432748654	12045	Economy	14800.00
0005432749836	12045	Economy	14800.00
0005435154644	12045	Economy	14800.00
0005432748643	12045	Economy	14800.00
0005432753399	12045	Economy	14800.00
0005432748611	12045	Economy	14800.00
0005435154665	12045	Economy	14800.00
0005435627130	12045	Economy	14800.00
0005435154689	12045	Economy	14800.00
0005432748580	12045	Economy	14800.00
0005435154669	12045	Economy	14800.00
0005432748533	12045	Economy	14800.00
0005432749837	12045	Economy	14800.00
0005432748531	12045	Economy	14800.00
0005432753377	12045	Economy	14800.00
0005432748556	12045	Economy	14800.00
0005432748508	12045	Economy	14800.00
0005435154651	12045	Economy	14800.00
0005432748497	12045	Economy	14800.00
0005435154664	12045	Economy	14800.00
0005433293444	12045	Economy	14800.00
0005432748628	12045	Economy	14800.00
0005435154673	12045	Economy	14800.00
0005435154643	12045	Economy	14800.00
0005432748552	12045	Economy	14800.00
0005432748534	12045	Economy	14800.00
0005432748652	12045	Economy	14800.00
0005435154660	12045	Economy	14800.00
0005432748644	12045	Economy	14800.00
0005432748668	12045	Economy	14800.00
0005435154668	12045	Economy	14800.00
0005432748581	12045	Economy	14800.00
0005432748560	12045	Economy	14800.00
0005432748557	12045	Economy	14800.00
0005435154636	12045	Economy	14800.00
0005432756935	12045	Economy	14800.00
0005432928141	18981	Economy	25700.00
0005432928136	18981	Economy	25700.00
0005432928119	18981	Economy	25700.00
0005433527336	32477	Economy	25700.00
0005433531377	32477	Economy	25700.00
0005433531378	32477	Economy	25700.00
0005433525334	32477	Economy	25700.00
0005433525341	32477	Economy	25700.00
0005433531389	32477	Economy	25700.00
0005433527367	32477	Economy	25700.00
0005433531392	32477	Economy	25700.00
0005433525320	32477	Economy	25700.00
0005435374982	5287	Business	84000.00
0005435374936	5287	Business	84000.00
0005435374785	5287	Business	84000.00
0005435374935	5287	Business	84000.00
0005435304261	5287	Business	84000.00
0005435375109	5287	Business	84000.00
0005435386728	5287	Business	84000.00
0005435374879	5287	Business	84000.00
0005435299896	5287	Comfort	47600.00
0005435375064	5287	Comfort	47600.00
0005435735263	5287	Comfort	47600.00
0005435375011	5287	Comfort	47600.00
0005435375065	5287	Comfort	47600.00
0005435374829	5287	Comfort	47600.00
0005435375097	5287	Comfort	47600.00
0005435315099	5287	Comfort	47600.00
0005435304255	5287	Comfort	47600.00
0005435735239	5287	Comfort	47600.00
0005435374952	5287	Economy	28000.00
0005435374605	5287	Economy	28000.00
0005435315082	5287	Economy	28000.00
0005435299893	5287	Economy	28000.00
0005435386756	5287	Economy	28000.00
0005435315060	5287	Economy	28000.00
0005435374922	5287	Economy	28000.00
0005435315097	5287	Economy	28000.00
0005435315004	5287	Economy	28000.00
0005434558618	5287	Economy	28000.00
0005435375104	5287	Economy	28000.00
0005435374604	5287	Economy	28000.00
0005434827298	5287	Economy	28000.00
0005435374946	5287	Economy	28000.00
0005435375037	5287	Economy	28000.00
0005435735238	5287	Economy	28000.00
0005435374815	5287	Economy	28000.00
0005435386749	5287	Economy	28000.00
0005435304262	5287	Economy	28000.00
0005435315096	5287	Economy	30800.00
0005435374994	5287	Economy	28000.00
0005435375028	5287	Economy	28000.00
0005435374751	5287	Economy	28000.00
0005435386748	5287	Economy	28000.00
0005435662004	5287	Economy	28000.00
0005435315064	5287	Economy	28000.00
0005435374825	5287	Economy	28000.00
0005435374750	5287	Economy	28000.00
0005435315017	5287	Economy	28000.00
0005435735261	5287	Economy	28000.00
0005435315098	5287	Economy	28000.00
0005435386736	5287	Economy	28000.00
0005435315063	5287	Economy	28000.00
0005435662005	5287	Economy	28000.00
0005435374826	5287	Economy	28000.00
0005435374796	5287	Economy	28000.00
0005435374896	5287	Economy	28000.00
0005435315081	5287	Economy	28000.00
0005435374969	5287	Economy	28000.00
0005435374838	5287	Economy	28000.00
0005435315003	5287	Economy	28000.00
0005435315095	5287	Economy	28000.00
0005435315069	5287	Economy	28000.00
0005435315053	5287	Economy	28000.00
0005435375096	5287	Economy	28000.00
0005435374651	5287	Economy	28000.00
0005435375063	5287	Economy	28000.00
0005435375081	5287	Economy	28000.00
0005435375078	5287	Economy	28000.00
0005435375058	5287	Economy	28000.00
0005435374824	5287	Economy	28000.00
0005435386729	5287	Economy	28000.00
0005435386755	5287	Economy	28000.00
0005435374816	5287	Economy	28000.00
0005435375098	5287	Economy	28000.00
0005435315016	5287	Economy	28000.00
0005435374895	5287	Economy	28000.00
0005435299895	5287	Economy	28000.00
0005435735262	5287	Economy	28000.00
0005435375099	5287	Economy	28000.00
0005435314979	5287	Economy	28000.00
0005435374788	5287	Economy	28000.00
0005435375105	5287	Economy	28000.00
0005435386757	5287	Economy	28000.00
0005435374864	5287	Economy	28000.00
0005435315074	5287	Economy	28000.00
0005435304266	5287	Economy	28000.00
0005435375075	5287	Economy	28000.00
0005435315002	5287	Economy	28000.00
0005435299900	5287	Economy	28000.00
0005435374914	5287	Economy	28000.00
0005435375143	5287	Economy	28000.00
0005435374945	5287	Economy	28000.00
0005435375002	5287	Economy	28000.00
0005435375074	5287	Economy	28000.00
0005435375089	5287	Economy	28000.00
0005435386735	5287	Economy	28000.00
0005435375113	5287	Economy	28000.00
0005434827297	5287	Economy	28000.00
0005435386730	5287	Economy	28000.00
0005435315059	5287	Economy	28000.00
0005435374981	5287	Economy	28000.00
0005435386758	5287	Economy	28000.00
0005435374883	5287	Economy	28000.00
0005435299899	5287	Economy	28000.00
0005435304248	5287	Economy	28000.00
0005434826832	9884	Business	84000.00
0005434826884	9884	Business	84000.00
0005434558484	9884	Business	84000.00
0005434827066	9884	Business	84000.00
0005434558522	9884	Business	84000.00
0005434826833	9884	Business	84000.00
0005434827171	9884	Business	84000.00
0005434665017	9884	Business	84000.00
0005434558472	9884	Business	84000.00
0005435315144	9884	Business	84000.00
0005434558600	9884	Comfort	47600.00
0005434826849	9884	Comfort	47600.00
0005434827034	9884	Comfort	47600.00
0005434826897	9884	Comfort	47600.00
0005434827127	9884	Comfort	47600.00
0005434831282	9884	Comfort	47600.00
0005434826757	9884	Comfort	47600.00
0005434558481	9884	Comfort	47600.00
0005434826910	9884	Comfort	47600.00
0005434826906	9884	Comfort	47600.00
0005432400208	9884	Comfort	47600.00
0005434826935	9884	Comfort	47600.00
0005434826894	9884	Comfort	47600.00
0005434826779	9884	Comfort	47600.00
0005434827004	9884	Comfort	47600.00
0005434827199	9884	Comfort	47600.00
0005434826934	9884	Comfort	47600.00
0005434831275	9884	Comfort	47600.00
0005434826728	9884	Comfort	47600.00
0005434827056	9884	Comfort	47600.00
0005434826893	9884	Comfort	47600.00
0005435179428	9884	Economy	28000.00
0005434826965	9884	Economy	28000.00
0005434826872	9884	Economy	28000.00
0005434826224	9884	Economy	28000.00
0005435150402	9884	Economy	28000.00
0005434826912	9884	Economy	28000.00
0005434558482	9884	Economy	28000.00
0005434826900	9884	Economy	28000.00
0005434826624	9884	Economy	28000.00
0005435150385	9884	Economy	28000.00
0005434826758	9884	Economy	28000.00
0005434827221	9884	Economy	28000.00
0005434558551	9884	Economy	28000.00
0005434827170	9884	Economy	28000.00
0005434826764	9884	Economy	28000.00
0005434831274	9884	Economy	28000.00
0005434826730	9884	Economy	28000.00
0005434827097	9884	Economy	28000.00
0005434826988	9884	Economy	28000.00
0005434826675	9884	Economy	28000.00
0005434827013	9884	Economy	28000.00
0005434828768	9884	Economy	28000.00
0005434826786	9884	Economy	28000.00
0005434831276	9884	Economy	30800.00
0005434826787	9884	Economy	28000.00
0005434828767	9884	Economy	28000.00
0005434558483	9884	Economy	30800.00
0005434827057	9884	Economy	30800.00
0005434558489	9884	Economy	28000.00
0005434826856	9884	Economy	28000.00
0005434831269	9884	Economy	28000.00
0005432400207	9884	Economy	28000.00
0005434827151	9884	Economy	28000.00
0005434558514	9884	Economy	28000.00
0005434826987	9884	Economy	28000.00
0005434558486	9884	Economy	28000.00
0005434558519	9884	Economy	28000.00
0005434826972	9884	Economy	28000.00
0005434827050	9884	Economy	28000.00
0005434827128	9884	Economy	28000.00
0005434826929	9884	Economy	28000.00
0005435150381	9884	Economy	28000.00
0005434827096	9884	Economy	28000.00
0005434826418	9884	Economy	28000.00
0005434826873	9884	Economy	28000.00
0005434831273	9884	Economy	28000.00
0005434826911	9884	Economy	28000.00
0005434826829	9884	Economy	28000.00
0005434558497	9884	Economy	28000.00
0005434558547	9884	Economy	28000.00
0005434826928	9884	Economy	28000.00
0005435150403	9884	Economy	28000.00
0005434826848	9884	Economy	28000.00
0005434831271	9884	Economy	28000.00
0005434826763	9884	Economy	28000.00
0005434826623	9884	Economy	28000.00
0005434558528	9884	Economy	28000.00
0005434665022	9884	Economy	28000.00
0005434827062	9884	Economy	28000.00
0005434826788	9884	Economy	28000.00
0005434827019	9884	Economy	28000.00
0005435150387	9884	Economy	28000.00
0005434826402	9884	Economy	28000.00
0005434826866	9884	Economy	30800.00
0005434827220	9884	Economy	28000.00
0005434826683	9884	Economy	28000.00
0005434826828	9884	Economy	28000.00
0005434826977	9884	Economy	28000.00
0005434558582	9884	Economy	28000.00
0005434827027	9884	Economy	28000.00
0005434827230	9884	Economy	28000.00
0005434826637	9884	Economy	28000.00
0005434558504	9884	Economy	28000.00
0005434826727	9884	Economy	28000.00
0005435150371	9884	Economy	28000.00
0005434826831	9884	Economy	28000.00
0005434827061	9884	Economy	28000.00
0005435150408	9884	Economy	28000.00
0005434826805	9884	Economy	28000.00
0005434826381	9884	Economy	28000.00
0005435150386	9884	Economy	28000.00
0005434558505	9884	Economy	28000.00
0005434826613	9884	Economy	28000.00
0005434827167	9884	Economy	28000.00
0005435150409	9884	Economy	28000.00
0005434558510	9884	Economy	28000.00
0005434558581	9884	Economy	28000.00
0005434826830	9884	Economy	28000.00
0005434826729	9884	Economy	28000.00
0005434827150	9884	Economy	28000.00
0005434827063	9884	Economy	28000.00
0005434558583	9884	Economy	28000.00
0005434826517	9884	Economy	28000.00
0005434826738	9884	Economy	28000.00
0005434826417	9884	Economy	28000.00
0005434831270	9884	Economy	28000.00
0005434827166	9884	Economy	28000.00
0005434828763	9884	Economy	28000.00
0005434558468	9884	Economy	28000.00
0005434558601	9884	Economy	28000.00
0005435377991	7007	Economy	7400.00
0005435377992	7007	Economy	7400.00
0005435082999	25992	Economy	8200.00
0005435083029	25992	Economy	7400.00
0005435083000	25992	Economy	7400.00
0005435083005	25992	Economy	7400.00
0005435082958	25992	Economy	7400.00
0005435083004	25992	Economy	7400.00
0005434215736	9529	Business	32800.00
0005434215699	9529	Business	32800.00
0005434215679	9529	Business	32800.00
0005434215748	9529	Business	32800.00
0005434215595	9529	Business	32800.00
0005434215836	9529	Business	32800.00
0005434215625	9529	Business	32800.00
0005434215611	9529	Economy	10900.00
0005434215756	9529	Economy	10900.00
0005434215727	9529	Economy	12000.00
0005434215675	9529	Economy	12000.00
0005434215676	9529	Economy	12000.00
0005434215753	9529	Economy	12000.00
0005434215752	9529	Economy	10900.00
0005434215735	9529	Economy	10900.00
0005434215680	9529	Economy	10900.00
0005434215525	9529	Economy	10900.00
0005434215662	9529	Economy	10900.00
0005434215757	9529	Economy	10900.00
0005434215641	9529	Economy	10900.00
0005434215640	9529	Economy	10900.00
0005434215660	9529	Economy	10900.00
0005434215838	9529	Economy	10900.00
0005434215656	9529	Economy	10900.00
0005434215422	9529	Economy	10900.00
0005434215657	9529	Economy	10900.00
0005434215837	9529	Economy	10900.00
0005434215726	9529	Economy	10900.00
0005434215806	9529	Economy	10900.00
0005434215754	9529	Economy	10900.00
0005434215658	9529	Economy	10900.00
0005434215673	9529	Economy	10900.00
0005434215734	9529	Economy	10900.00
0005434215737	9529	Economy	10900.00
0005434757321	28603	Business	32800.00
0005434757333	28603	Business	32800.00
0005434757456	28603	Business	32800.00
0005434757554	28603	Business	32800.00
0005434757563	28603	Business	32800.00
0005434757403	28603	Business	32800.00
0005434757581	28603	Economy	10900.00
0005434757472	28603	Economy	10900.00
0005434757457	28603	Economy	10900.00
0005434757462	28603	Economy	10900.00
0005434757506	28603	Economy	12000.00
0005434757556	28603	Economy	12000.00
0005434757337	28603	Economy	12000.00
0005434757325	28603	Economy	12000.00
0005434757443	28603	Economy	10900.00
0005434757446	28603	Economy	10900.00
0005434757517	28603	Economy	10900.00
0005434757272	28603	Economy	10900.00
0005434757326	28603	Economy	10900.00
0005434757441	28603	Economy	10900.00
0005434757273	28603	Economy	10900.00
0005434757313	28603	Economy	10900.00
0005434757314	28603	Economy	10900.00
0005434757322	28603	Economy	10900.00
0005434757335	28603	Economy	10900.00
0005434757453	28603	Economy	10900.00
0005434757334	28603	Economy	10900.00
0005434757464	28603	Economy	10900.00
0005434757442	28603	Economy	10900.00
0005434757336	28603	Economy	10900.00
0005434757463	28603	Economy	10900.00
0005434757467	28603	Economy	10900.00
0005434757455	28603	Economy	10900.00
0005434757495	28603	Economy	10900.00
0005434757496	28603	Economy	10900.00
0005434757502	28603	Economy	10900.00
0005434757608	28603	Economy	10900.00
0005434757385	28603	Economy	10900.00
0005434757553	28603	Economy	10900.00
0005434757454	28603	Economy	10900.00
0005434757384	28603	Economy	10900.00
0005434757569	28603	Economy	10900.00
0005434757404	28603	Economy	10900.00
0005434757504	28603	Economy	10900.00
0005434757482	28603	Economy	10900.00
0005434760255	10859	Economy	8900.00
0005434760254	10859	Economy	8900.00
0005435100203	31790	Economy	8900.00
0005435100202	31790	Economy	8900.00
0005433202769	1974	Economy	20900.00
0005433202768	1974	Economy	20900.00
0005433202744	1974	Economy	19000.00
0005433202767	1974	Economy	19000.00
0005433202743	1974	Economy	19000.00
0005433202763	1974	Economy	19000.00
0005434640107	1974	Economy	19000.00
0005433202731	1974	Economy	19000.00
0005433202770	1974	Economy	19000.00
0005433202728	1974	Economy	19000.00
0005433202765	1974	Economy	19000.00
0005434640108	1974	Economy	19000.00
0005433202714	1974	Economy	19000.00
0005433202766	1974	Economy	19000.00
0005434639956	23259	Economy	20900.00
0005434640047	23259	Economy	20900.00
0005434639943	23259	Economy	20900.00
0005434640014	23259	Economy	19000.00
0005434639995	23259	Economy	19000.00
0005434640059	23259	Economy	19000.00
0005434640013	23259	Economy	19000.00
0005434639999	23259	Economy	19000.00
0005434640028	23259	Economy	19000.00
0005434639998	23259	Economy	19000.00
0005435948359	23259	Economy	19000.00
0005434639944	23259	Economy	19000.00
0005434639949	23259	Economy	19000.00
0005434639963	23259	Economy	19000.00
0005434639984	23259	Economy	19000.00
0005434639997	23259	Economy	19000.00
0005434639957	23259	Economy	19000.00
0005434640060	23259	Economy	19000.00
0005434639965	23259	Economy	19000.00
0005434639996	23259	Economy	19000.00
0005434639992	23259	Economy	19000.00
0005434639964	23259	Economy	19000.00
0005434639993	23259	Economy	19000.00
0005434639930	23259	Economy	19000.00
0005434639948	23259	Economy	19000.00
0005435948366	23259	Economy	19000.00
0005435948364	23259	Economy	19000.00
0005434640015	23259	Economy	19000.00
0005434639994	23259	Economy	19000.00
0005435948358	23259	Economy	19000.00
0005435948365	23259	Economy	19000.00
0005434640048	23259	Economy	19000.00
0005434640046	23259	Economy	19000.00
0005435327117	6060	Economy	23200.00
0005435327103	6060	Economy	23200.00
0005435327104	6060	Economy	25600.00
0005435327105	6060	Economy	23200.00
0005435327126	6060	Economy	23200.00
0005434601599	6060	Economy	23200.00
0005435327082	6060	Economy	23200.00
0005434601598	6060	Economy	23200.00
0005435327125	6060	Economy	23200.00
0005434601545	18584	Business	69700.00
0005434601578	18584	Business	69700.00
0005434601529	18584	Business	69700.00
0005434601565	18584	Economy	23200.00
0005433531388	18584	Economy	23200.00
0005434601526	18584	Economy	25600.00
0005434601566	18584	Economy	25600.00
0005434601563	18584	Economy	23200.00
0005434601568	18584	Economy	23200.00
0005434601455	18584	Economy	23200.00
0005433531387	18584	Economy	23200.00
0005434601512	18584	Economy	23200.00
0005433531386	18584	Economy	23200.00
0005434601554	18584	Economy	23200.00
0005434601513	18584	Economy	23200.00
0005434601447	18584	Economy	23200.00
0005434601524	18584	Economy	23200.00
0005434601471	18584	Economy	23200.00
0005434601448	18584	Economy	23200.00
0005434601525	18584	Economy	23200.00
0005434601564	18584	Economy	23200.00
0005434601567	18584	Economy	23200.00
0005433527355	18584	Economy	23200.00
0005434601449	18584	Economy	23200.00
0005433527365	18584	Economy	23200.00
0005434601530	18584	Economy	23200.00
0005433181735	10573	Business	9100.00
0005433181815	10573	Business	9100.00
0005433181778	10573	Business	9100.00
0005435315085	10573	Economy	3000.00
0005435315015	10573	Economy	3000.00
0005433181763	10573	Economy	3000.00
0005435315049	10573	Economy	3300.00
0005433181764	10573	Economy	3000.00
0005433181714	10573	Economy	3000.00
0005433181741	10573	Economy	3000.00
0005435315061	10573	Economy	3000.00
0005435315078	10573	Economy	3000.00
0005435315094	10573	Economy	3000.00
0005435315079	10573	Economy	3000.00
0005433181611	10573	Economy	3000.00
0005433181711	10573	Economy	3000.00
0005435315014	10573	Economy	3000.00
0005433181734	10573	Economy	3000.00
0005434558617	10573	Economy	3000.00
0005435315084	10573	Economy	3000.00
0005433181798	10573	Economy	3000.00
0005433181799	10573	Economy	3000.00
0005435315080	10573	Economy	3000.00
0005433181771	10573	Economy	3000.00
0005435314964	10573	Economy	3000.00
0005434558615	10573	Economy	3000.00
0005433181695	10573	Economy	3000.00
0005434558616	10573	Economy	3000.00
0005435315058	10573	Economy	3000.00
0005433181800	10573	Economy	3000.00
0005435315144	27684	Economy	3000.00
0005434552632	27683	Business	9100.00
0005434552506	27683	Business	9100.00
0005434558534	27683	Business	9100.00
0005434552609	27683	Business	9100.00
0005434552630	27683	Business	9100.00
0005434552409	27683	Business	9100.00
0005434558479	27683	Business	9100.00
0005434558544	27683	Business	9100.00
0005434552771	27683	Business	9100.00
0005434558498	27683	Economy	3000.00
0005434552629	27683	Economy	3000.00
0005434558506	27683	Economy	3000.00
0005434552572	27683	Economy	3000.00
0005434552497	27683	Economy	3000.00
0005434552520	27683	Economy	3000.00
0005434552649	27683	Economy	3300.00
0005434552601	27683	Economy	3300.00
0005434552610	27683	Economy	3300.00
0005434552709	27683	Economy	3000.00
0005434552835	27683	Economy	3000.00
0005434552713	27683	Economy	3000.00
0005434552618	27683	Economy	3000.00
0005434552617	27683	Economy	3000.00
0005434554114	27683	Economy	3000.00
0005434552761	27683	Economy	3000.00
0005434552393	27683	Economy	3000.00
0005434552815	27683	Economy	3000.00
0005434552672	27683	Economy	3000.00
0005434552762	27683	Economy	3000.00
0005434552496	27683	Economy	3000.00
0005434552816	27683	Economy	3000.00
0005434552644	27683	Economy	3000.00
0005434558535	27683	Economy	3000.00
0005434552640	27683	Economy	3000.00
0005434552636	27683	Economy	3000.00
0005434552774	27683	Economy	3000.00
0005434552759	27683	Economy	3000.00
0005434552671	27683	Economy	3000.00
0005434558529	27683	Economy	3000.00
0005434552735	27683	Economy	3000.00
0005434558507	27683	Economy	3000.00
0005434552772	27683	Economy	3000.00
0005434558499	27683	Economy	3000.00
0005434552817	27683	Economy	3000.00
0005434552410	27683	Economy	3000.00
0005434552639	27683	Economy	3000.00
0005434554121	27683	Economy	3000.00
0005434552751	27683	Economy	3000.00
0005434552669	27683	Economy	3000.00
0005434552773	27683	Economy	3000.00
0005434552834	27683	Economy	3000.00
0005434552742	27683	Economy	3000.00
0005434552660	27683	Economy	3000.00
0005434552699	27683	Economy	3000.00
0005434552521	27683	Economy	3000.00
0005434552763	27683	Economy	3000.00
0005434552837	27683	Economy	3000.00
0005434552631	27683	Economy	3000.00
0005434552638	27683	Economy	3000.00
0005434552714	27683	Economy	3000.00
0005434552637	27683	Economy	3000.00
0005433459336	19332	Economy	11700.00
0005433459338	19332	Economy	11700.00
0005433459335	19332	Economy	11700.00
0005433459339	19332	Economy	11700.00
0005435438567	6715	Business	51100.00
0005435438566	6715	Business	51100.00
0005435438552	6715	Business	51100.00
0005435438568	6715	Business	51100.00
0005435438554	6715	Economy	17000.00
0005435438547	6715	Economy	17000.00
0005435438546	6715	Economy	17000.00
0005432533364	6715	Economy	18700.00
0005435438524	6715	Economy	18700.00
0005435438581	6715	Economy	17000.00
0005432533367	6715	Economy	17000.00
0005432533368	6715	Economy	17000.00
0005435217763	6715	Economy	17000.00
0005435220366	6715	Economy	17000.00
0005435438537	6715	Economy	17000.00
0005435438536	6715	Economy	17000.00
0005435438577	6715	Economy	17000.00
0005435438535	6715	Economy	17000.00
0005435438553	6715	Economy	17000.00
0005435683078	24623	Business	51100.00
0005435720861	24623	Business	51100.00
0005435683267	24623	Business	51100.00
0005435683217	24623	Business	51100.00
0005435719596	24623	Business	51100.00
0005435683247	24623	Business	51100.00
0005435683235	24623	Business	51100.00
0005435631042	24623	Business	51100.00
0005435683203	24623	Economy	17000.00
0005435683302	24623	Economy	17000.00
0005435683214	24623	Economy	17000.00
0005435683061	24623	Economy	18700.00
0005435683165	24623	Economy	18700.00
0005435683280	24623	Economy	18700.00
0005435683233	24623	Economy	17000.00
0005435720857	24623	Economy	17000.00
0005435683223	24623	Economy	17000.00
0005435720860	24623	Economy	17000.00
0005435683296	24623	Economy	17000.00
0005435683199	24623	Economy	17000.00
0005435683120	24623	Economy	17000.00
0005435683179	24623	Economy	17000.00
0005435683164	24623	Economy	17000.00
0005435683288	24623	Economy	17000.00
0005435720858	24623	Economy	17000.00
0005435683128	24623	Economy	17000.00
0005435683236	24623	Economy	17000.00
0005435683260	24623	Economy	17000.00
0005435683274	24623	Economy	17000.00
0005435683246	24623	Economy	17000.00
0005435683076	24623	Economy	17000.00
0005435682919	24623	Economy	17000.00
0005435683096	24623	Economy	17000.00
0005435683188	24623	Economy	17000.00
0005435683129	24623	Economy	17000.00
0005435683234	24623	Economy	17000.00
0005435683091	24623	Economy	17000.00
0005435683171	24623	Economy	17000.00
0005435719592	24623	Economy	17000.00
0005435683232	24623	Economy	17000.00
0005435683297	24623	Economy	17000.00
0005435683249	24623	Economy	17000.00
0005435683218	24623	Economy	17000.00
0005435683257	24623	Economy	17000.00
0005435683245	24623	Economy	17000.00
0005435683266	24623	Economy	17000.00
0005435683170	24623	Economy	17000.00
0005435683303	24623	Economy	17000.00
0005435719595	24623	Economy	17000.00
0005435683202	24623	Economy	17000.00
0005435683092	24623	Economy	17000.00
0005435631046	24623	Economy	17000.00
0005435127588	11525	Economy	8800.00
0005435127309	31874	Business	26400.00
0005435127382	31874	Business	26400.00
0005435127518	31874	Business	26400.00
0005435127355	31874	Economy	8800.00
0005435098608	31874	Economy	8800.00
0005435127456	31874	Economy	8800.00
0005435106065	31874	Economy	8800.00
0005435127507	31874	Economy	8800.00
0005435127506	31874	Economy	9700.00
0005435127493	31874	Economy	9700.00
0005435127532	31874	Economy	8800.00
0005435106064	31874	Economy	8800.00
0005435127469	31874	Economy	8800.00
0005435127383	31874	Economy	8800.00
0005435127380	31874	Economy	8800.00
0005435127308	31874	Economy	8800.00
0005435127470	31874	Economy	8800.00
0005435127484	31874	Economy	8800.00
0005435127457	31874	Economy	8800.00
0005435127298	31874	Economy	8800.00
0005435127435	31874	Economy	8800.00
0005435127381	31874	Economy	8800.00
0005435127392	31874	Economy	8800.00
0005435127547	31874	Economy	8800.00
0005435127354	31874	Economy	8800.00
0005435127436	31874	Economy	8800.00
0005435127408	31874	Economy	8800.00
0005435127432	31874	Economy	8800.00
0005435127503	31874	Economy	8800.00
0005435127504	31874	Economy	8800.00
0005435127520	31874	Economy	8800.00
0005435127502	31874	Economy	8800.00
0005435127458	31874	Economy	8800.00
0005435127417	31874	Economy	8800.00
0005435732633	13555	Business	36600.00
0005435732649	13555	Economy	12200.00
0005435732671	13555	Economy	12200.00
0005435732677	13555	Economy	12200.00
0005435732631	13555	Economy	12200.00
0005435732669	13555	Economy	12200.00
0005435732679	13555	Economy	12200.00
0005435732673	13555	Economy	12200.00
0005435732699	13555	Economy	12200.00
0005435732680	13555	Economy	12200.00
0005435732676	13555	Economy	12200.00
0005435732662	13555	Economy	12200.00
0005435732632	13555	Economy	12200.00
0005433399314	19377	Business	36600.00
0005433399124	19377	Business	36600.00
0005433399341	19377	Business	36600.00
0005433399362	19377	Business	36600.00
0005433399297	19377	Business	36600.00
0005433399342	19377	Economy	12200.00
0005433399201	19377	Economy	12200.00
0005433399389	19377	Economy	12200.00
0005433399361	19377	Economy	12200.00
0005433399236	19377	Economy	12200.00
0005433399422	19377	Economy	12200.00
0005433399265	19377	Economy	12200.00
0005433399245	19377	Economy	12200.00
0005433399332	19377	Economy	12200.00
0005433399337	19377	Economy	12200.00
0005433399272	19377	Economy	12200.00
0005433399229	19377	Economy	12200.00
0005433399266	19377	Economy	12200.00
0005433399365	19377	Economy	12200.00
0005433399225	19377	Economy	12200.00
0005433399333	19377	Economy	12200.00
0005433399315	19377	Economy	12200.00
0005433399244	19377	Economy	12200.00
0005433399363	19377	Economy	12200.00
0005433399376	19377	Economy	12200.00
0005433399253	19377	Economy	12200.00
0005433399118	19377	Economy	12200.00
0005433399298	19377	Economy	12200.00
0005433399437	19377	Economy	12200.00
0005433399327	19377	Economy	12200.00
0005433399311	19377	Economy	12200.00
0005433399378	19377	Economy	12200.00
0005433399381	19377	Economy	12200.00
0005433399386	19377	Economy	12200.00
0005433399267	19377	Economy	12200.00
0005433399317	19377	Economy	12200.00
0005435070404	13185	Business	11300.00
0005435070376	13185	Business	11300.00
0005435070394	13185	Business	11300.00
0005435070119	13185	Business	11300.00
0005435070256	13185	Business	11300.00
0005435070345	13185	Business	11300.00
0005435070257	13185	Economy	3800.00
0005435070294	13185	Economy	3800.00
0005435070550	13185	Economy	3800.00
0005435070494	13185	Economy	3800.00
0005435070366	13185	Economy	3800.00
0005435070367	13185	Economy	4100.00
0005435070406	13185	Economy	4100.00
0005435070120	13185	Economy	3800.00
0005435070315	13185	Economy	3800.00
0005435070314	13185	Economy	3800.00
0005435070335	13185	Economy	3800.00
0005435070445	13185	Economy	3800.00
0005435070429	13185	Economy	3800.00
0005435070379	13185	Economy	3800.00
0005435070338	13185	Economy	3800.00
0005435070434	13185	Economy	3800.00
0005435070227	13185	Economy	3800.00
0005435070424	13185	Economy	3800.00
0005435070324	13185	Economy	3800.00
0005435070471	13185	Economy	3800.00
0005435070478	13185	Economy	3800.00
0005435070459	13185	Economy	3800.00
0005435070504	13185	Economy	3800.00
0005435070438	13185	Economy	3800.00
0005435070460	13185	Economy	3800.00
0005435070282	13185	Economy	3800.00
0005435070493	13185	Economy	3800.00
0005435070380	13185	Economy	3800.00
0005435070479	13185	Economy	3800.00
0005435070377	13185	Economy	3800.00
0005435070542	13185	Economy	3800.00
0005435070462	13185	Economy	3800.00
0005435070332	13185	Economy	3800.00
0005435070444	13185	Economy	3800.00
0005435070461	13185	Economy	3800.00
0005435070425	13185	Economy	3800.00
0005435070339	13185	Economy	3800.00
0005435070313	13185	Economy	3800.00
0005435070364	13185	Economy	3800.00
0005435070375	13185	Economy	3800.00
0005435925665	15463	Business	11300.00
0005435925686	15463	Business	11300.00
0005435925658	15463	Business	11300.00
0005435925682	15463	Business	11300.00
0005435925666	15463	Business	11300.00
0005435925688	15463	Economy	3800.00
0005435070567	15463	Economy	3800.00
0005435925687	15463	Economy	3800.00
0005435070568	15463	Economy	4100.00
0005435925669	15463	Economy	3800.00
0005435925641	15463	Economy	3800.00
0005435925684	15463	Economy	3800.00
0005435925642	15463	Economy	3800.00
0005435925667	15463	Economy	3800.00
0005435925567	15463	Economy	3800.00
0005435925659	15463	Economy	3800.00
0005435925568	15463	Economy	3800.00
0005435925689	15463	Economy	3800.00
0005435925592	15463	Economy	3800.00
0005435925668	15463	Economy	3800.00
0005435925676	15463	Economy	3800.00
0005435925675	15463	Economy	3800.00
0005435925651	15463	Economy	3800.00
0005433407702	23175	Economy	27100.00
0005433407683	23175	Economy	24700.00
0005433407697	23175	Economy	24700.00
0005433407684	23175	Economy	24700.00
0005433407685	23175	Economy	24700.00
0005433407682	23175	Economy	24700.00
0005433407686	23175	Economy	24700.00
0005434757607	10702	Business	61300.00
0005434757525	10702	Business	61300.00
0005434757523	10702	Business	61300.00
0005434757571	10702	Business	61300.00
0005434757620	10702	Business	61300.00
0005434757471	10702	Business	61300.00
0005434757564	10702	Business	61300.00
0005434757379	10702	Business	61300.00
0005434757585	10702	Business	61300.00
0005434757519	10702	Business	61300.00
0005434757582	10702	Economy	20400.00
0005434757541	10702	Economy	20400.00
0005434757492	10702	Economy	20400.00
0005434757673	10702	Economy	22500.00
0005434757646	10702	Economy	22500.00
0005434757477	10702	Economy	20400.00
0005434757520	10702	Economy	20400.00
0005434757431	10702	Economy	20400.00
0005434757436	10702	Economy	20400.00
0005434757628	10702	Economy	20400.00
0005434757645	10702	Economy	20400.00
0005434757642	10702	Economy	20400.00
0005434757522	10702	Economy	20400.00
0005434757643	10702	Economy	20400.00
0005434757306	10702	Economy	20400.00
0005434757535	10702	Economy	20400.00
0005434757305	10702	Economy	20400.00
0005434757468	10702	Economy	20400.00
0005434757438	10702	Economy	20400.00
0005434757672	10702	Economy	20400.00
0005434757432	10702	Economy	20400.00
0005434757606	10702	Economy	20400.00
0005434757338	10702	Economy	20400.00
0005434757586	10702	Economy	20400.00
0005434757565	10702	Economy	20400.00
0005434757544	10702	Economy	20400.00
0005434757570	10702	Economy	20400.00
0005434757465	10702	Economy	20400.00
0005434757476	10702	Economy	20400.00
0005434757389	10702	Economy	20400.00
0005434757298	10702	Economy	20400.00
0005434757521	10702	Economy	20400.00
0005434757627	10702	Economy	20400.00
0005434757545	10702	Economy	20400.00
0005434757437	10702	Economy	20400.00
0005434215549	28684	Business	61300.00
0005434215529	28684	Business	61300.00
0005434215747	28684	Business	61300.00
0005434215554	28684	Business	61300.00
0005434215715	28684	Business	61300.00
0005434215622	28684	Economy	20400.00
0005434215767	28684	Economy	20400.00
0005434215765	28684	Economy	20400.00
0005434215758	28684	Economy	20400.00
0005434215781	28684	Economy	20400.00
0005434215729	28684	Economy	22500.00
0005434215530	28684	Economy	20400.00
0005434215688	28684	Economy	20400.00
0005434757693	28684	Economy	20400.00
0005434215717	28684	Economy	20400.00
0005434215399	28684	Economy	20400.00
0005434215768	28684	Economy	20400.00
0005434215751	28684	Economy	20400.00
0005434215725	28684	Economy	20400.00
0005434215612	28684	Economy	20400.00
0005434215865	28684	Economy	20400.00
0005434215842	28684	Economy	20400.00
0005434215566	28684	Economy	20400.00
0005434215804	28684	Economy	20400.00
0005434215728	28684	Economy	20400.00
0005434215716	28684	Economy	20400.00
0005434215512	28684	Economy	20400.00
0005434215830	28684	Economy	20400.00
0005434215718	28684	Economy	20400.00
0005434757694	28684	Economy	20400.00
0005434215724	28684	Economy	20400.00
0005434215677	28684	Economy	20400.00
0005434215841	28684	Economy	20400.00
0005434215689	28684	Economy	20400.00
0005434215805	28684	Economy	20400.00
0005434215575	28684	Economy	20400.00
0005434215866	28684	Economy	20400.00
0005434215493	28684	Economy	20400.00
0005434215633	28684	Economy	20400.00
0005434215674	28684	Economy	20400.00
0005434215643	28684	Economy	20400.00
0005434215485	28684	Economy	20400.00
0005434757692	28684	Economy	20400.00
0005434215550	28684	Economy	20400.00
0005434757695	28684	Economy	20400.00
0005434215484	28684	Economy	20400.00
0005434229963	5476	Business	29500.00
0005434229964	5476	Business	29500.00
0005435735280	5476	Business	29500.00
0005435377939	5476	Economy	9800.00
0005434229965	5476	Economy	9800.00
0005435735282	5476	Economy	9800.00
0005434229961	5476	Economy	9800.00
0005434230013	5476	Economy	9800.00
0005434229960	5476	Economy	9800.00
0005434229937	5476	Economy	9800.00
0005434229940	5476	Economy	9800.00
0005435377972	5476	Economy	10800.00
0005434229938	5476	Economy	9800.00
0005434229987	5476	Economy	9800.00
0005435377960	5476	Economy	9800.00
0005434229993	5476	Economy	9800.00
0005434229988	5476	Economy	9800.00
0005434229926	5476	Economy	9800.00
0005434229962	5476	Economy	9800.00
0005434229930	5476	Economy	9800.00
0005434229855	5476	Economy	9800.00
0005434229929	5476	Economy	9800.00
0005434229854	5476	Economy	9800.00
0005435377930	5476	Economy	9800.00
0005435735281	5476	Economy	9800.00
0005434230005	5476	Economy	9800.00
0005434230012	5476	Economy	9800.00
0005435041497	12948	Business	29500.00
0005435041477	12948	Business	29500.00
0005435041657	12948	Business	29500.00
0005435041337	12948	Business	29500.00
0005435041412	12948	Business	29500.00
0005435041637	12948	Economy	9800.00
0005435041566	12948	Economy	9800.00
0005435007701	12948	Economy	9800.00
0005435041411	12948	Economy	9800.00
0005435377990	12948	Economy	9800.00
0005435041404	12948	Economy	9800.00
0005435041454	12948	Economy	9800.00
0005435041559	12948	Economy	9800.00
0005435041205	12948	Economy	9800.00
0005435007628	12948	Economy	9800.00
0005435007605	12948	Economy	9800.00
0005435041430	12948	Economy	9800.00
0005435041353	12948	Economy	9800.00
0005435041330	12948	Economy	9800.00
0005435041226	12948	Economy	9800.00
0005435041567	12948	Economy	9800.00
0005435041278	12948	Economy	9800.00
0005435041545	12948	Economy	9800.00
0005435042933	12948	Economy	9800.00
0005435043308	12948	Economy	9800.00
0005435007610	12948	Economy	9800.00
0005435041646	12948	Economy	9800.00
0005435007679	12948	Economy	9800.00
0005435041513	12948	Economy	9800.00
0005435041519	12948	Economy	9800.00
0005435041370	12948	Economy	9800.00
0005435041172	12948	Economy	10800.00
0005435041568	12948	Economy	10800.00
0005435007684	12948	Economy	10800.00
0005435041627	12948	Economy	10800.00
0005435007700	12948	Economy	9800.00
0005435041514	12948	Economy	9800.00
0005435041614	12948	Economy	9800.00
0005435041379	12948	Economy	9800.00
0005435041425	12948	Economy	9800.00
0005435007685	12948	Economy	9800.00
0005435041227	12948	Economy	9800.00
0005435007644	12948	Economy	9800.00
0005435041352	12948	Economy	9800.00
0005435042932	12948	Economy	9800.00
0005435007692	12948	Economy	9800.00
0005435041597	12948	Economy	9800.00
0005435041441	12948	Economy	9800.00
0005435041647	12948	Economy	9800.00
0005435042931	12948	Economy	9800.00
0005435041299	12948	Economy	9800.00
0005435041380	12948	Economy	9800.00
0005435041239	12948	Economy	9800.00
0005435041419	12948	Economy	9800.00
0005435041503	12948	Economy	9800.00
0005435007674	12948	Economy	9800.00
0005435041494	12948	Economy	9800.00
0005435007703	12948	Economy	9800.00
0005435041636	12948	Economy	9800.00
0005435041628	12948	Economy	9800.00
0005435041558	12948	Economy	9800.00
0005435041495	12948	Economy	9800.00
0005435041403	12948	Economy	9800.00
0005435041316	12948	Economy	9800.00
0005435041455	12948	Economy	9800.00
0005435041298	12948	Economy	9800.00
0005435041429	12948	Economy	9800.00
0005435041206	12948	Economy	9800.00
0005435041442	12948	Economy	9800.00
0005435041490	12948	Economy	9800.00
0005435041565	12948	Economy	9800.00
0005435007611	12948	Economy	9800.00
0005435041523	12948	Economy	9800.00
0005435041529	12948	Economy	9800.00
0005435007702	12948	Economy	9800.00
0005435041557	12948	Economy	9800.00
0005435041598	12948	Economy	9800.00
0005435041632	12948	Economy	9800.00
0005435041413	12948	Economy	9800.00
0005435903178	14897	Business	52900.00
0005435903188	14897	Business	52900.00
0005435903186	14897	Business	52900.00
0005435903172	14897	Economy	17600.00
0005435554320	14897	Economy	17600.00
0005434427474	14897	Economy	17600.00
0005435903143	14897	Economy	17600.00
0005435554296	14897	Economy	17600.00
0005435903173	14897	Economy	17600.00
0005434427475	14897	Economy	17600.00
0005434427473	14897	Economy	17600.00
0005435554297	14897	Economy	17600.00
0005435903187	14897	Economy	17600.00
0005435903136	14897	Economy	17600.00
0005435903191	14897	Economy	17600.00
0005434411888	20213	Business	52900.00
0005434427268	20213	Economy	17600.00
0005434427366	20213	Economy	17600.00
0005434427419	20213	Economy	17600.00
0005434411883	20213	Economy	17600.00
0005434427393	20213	Economy	17600.00
0005434427335	20213	Economy	17600.00
0005434427392	20213	Economy	17600.00
0005434427334	20213	Economy	17600.00
0005434427420	20213	Economy	17600.00
0005434427422	20213	Economy	17600.00
0005434427438	20213	Economy	17600.00
0005434427365	20213	Economy	17600.00
0005434427410	20213	Economy	17600.00
0005434411882	20213	Economy	17600.00
0005434427426	20213	Economy	17600.00
0005434427267	20213	Economy	17600.00
0005434427437	20213	Economy	17600.00
0005434427322	20213	Economy	17600.00
0005432462568	30890	Business	106800.00
0005432462563	30890	Business	106800.00
0005432462562	30890	Business	106800.00
0005432462561	30890	Economy	35600.00
0005432462569	30890	Economy	35600.00
0005434559193	30890	Economy	35600.00
0005432462560	30890	Economy	35600.00
0005434559194	30890	Economy	35600.00
0005432462567	30890	Economy	35600.00
0005434559195	30890	Economy	39200.00
0005432462566	30890	Economy	35600.00
0005434559191	30890	Economy	35600.00
0005434559192	30890	Economy	35600.00
0005433435461	26533	Business	18500.00
0005433435333	26533	Business	18500.00
0005433435399	26533	Business	18500.00
0005433435482	26533	Economy	6200.00
0005433435363	26533	Economy	6200.00
0005434273115	26533	Economy	6200.00
0005433435339	26533	Economy	6200.00
0005433435351	26533	Economy	6800.00
0005433435361	26533	Economy	6200.00
0005433435460	26533	Economy	6200.00
0005435983677	26533	Economy	6200.00
0005433435421	26533	Economy	6200.00
0005433435338	26533	Economy	6200.00
0005433435405	26533	Economy	6200.00
0005433435380	26533	Economy	6200.00
0005434273111	26533	Economy	6200.00
0005434273125	26533	Economy	6200.00
0005433435383	26533	Economy	6200.00
0005433435400	26533	Economy	6200.00
0005433435362	26533	Economy	6200.00
0005433435449	26533	Economy	6200.00
0005433435279	26533	Economy	6200.00
0005435983676	26533	Economy	6200.00
0005433435445	26533	Economy	6200.00
0005433435467	26533	Economy	6200.00
0005433435402	26533	Economy	6200.00
0005433435384	26533	Economy	6200.00
0005433435451	26533	Economy	6200.00
0005433435450	26533	Economy	6200.00
0005435983458	26720	Business	18500.00
0005435983518	26720	Business	18500.00
0005435983392	26720	Business	18500.00
0005435983404	26720	Economy	6200.00
0005435983640	26720	Economy	6200.00
0005435983480	26720	Economy	6200.00
0005435983388	26720	Economy	6200.00
0005435983416	26720	Economy	6200.00
0005435983403	26720	Economy	6200.00
0005435983411	26720	Economy	6200.00
0005435983393	26720	Economy	6800.00
0005435983623	26720	Economy	6800.00
0005435983481	26720	Economy	6800.00
0005435983301	26720	Economy	6200.00
0005435983524	26720	Economy	6200.00
0005435983489	26720	Economy	6200.00
0005435983473	26720	Economy	6200.00
0005435983378	26720	Economy	6200.00
0005435983417	26720	Economy	6200.00
0005435983377	26720	Economy	6200.00
0005435983389	26720	Economy	6200.00
0005435983585	26720	Economy	6200.00
0005435983622	26720	Economy	6200.00
0005435983560	26720	Economy	6200.00
0005435983441	26720	Economy	6200.00
0005435983391	26720	Economy	6200.00
0005435983410	26720	Economy	6200.00
0005435983350	26720	Economy	6200.00
0005435983555	26720	Economy	6200.00
0005435983455	26720	Economy	6200.00
0005435983556	26720	Economy	6200.00
0005435983464	26720	Economy	6200.00
0005435983465	26720	Economy	6200.00
0005435983609	26720	Economy	6200.00
0005435983456	26720	Economy	6200.00
0005435983300	26720	Economy	6200.00
0005435983457	26720	Economy	6200.00
0005435983574	26720	Economy	6200.00
0005435983579	26720	Economy	6200.00
0005435983390	26720	Economy	6200.00
0005435983598	26720	Economy	6200.00
0005435983621	26720	Economy	6200.00
0005435983499	26720	Economy	6200.00
0005435983591	26720	Economy	6200.00
0005435983639	26720	Economy	6200.00
0005435983580	26720	Economy	6200.00
0005432858377	3156	Economy	10100.00
0005432858391	3156	Economy	10100.00
0005432858376	3156	Economy	10100.00
0005432858350	3156	Economy	10100.00
0005432858345	3156	Economy	10100.00
0005432858351	3156	Economy	10100.00
0005432584762	31494	Economy	11100.00
0005432584753	31494	Economy	11100.00
0005432584786	31494	Economy	11100.00
0005432584553	31494	Economy	10100.00
0005432584726	31494	Economy	10100.00
0005432584739	31494	Economy	10100.00
0005432584752	31494	Economy	10100.00
0005432584719	31494	Economy	10100.00
0005432584763	31494	Economy	10100.00
0005432584607	31494	Economy	10100.00
0005432584785	31494	Economy	10100.00
0005432584677	31494	Economy	10100.00
0005432584718	31494	Economy	10100.00
0005432584725	31494	Economy	10100.00
0005432584720	31494	Economy	10100.00
0005432584606	31494	Economy	10100.00
0005432584764	31494	Economy	10100.00
0005433255255	883	Economy	8300.00
0005433255256	883	Economy	7500.00
0005433255261	883	Economy	7500.00
0005433255267	883	Economy	7500.00
0005433255279	16230	Economy	7500.00
0005434943579	16230	Economy	7500.00
0005434943589	16230	Economy	7500.00
0005434943606	16230	Economy	7500.00
0005433654959	27609	Business	90500.00
0005433654922	27609	Business	90500.00
0005433654936	27609	Business	90500.00
0005433654918	27609	Economy	30200.00
0005435858697	27609	Economy	30200.00
0005433654931	27609	Economy	30200.00
0005433654927	27609	Economy	30200.00
0005433654920	27609	Economy	30200.00
0005433654961	27609	Economy	30200.00
0005433654948	27609	Economy	30200.00
0005433654965	27609	Economy	33200.00
0005433654962	27609	Economy	33200.00
0005433654954	27609	Economy	30200.00
0005433654960	27609	Economy	30200.00
0005433654977	27609	Economy	30200.00
0005435858695	27609	Economy	30200.00
0005433654937	27609	Economy	30200.00
0005433654945	27609	Economy	30200.00
0005433654968	27609	Economy	30200.00
0005433654929	27609	Economy	30200.00
0005433654926	27609	Economy	30200.00
0005433654967	27609	Economy	30200.00
0005433654953	27609	Economy	30200.00
0005433654963	27609	Economy	30200.00
0005433654978	27609	Economy	30200.00
0005433654944	27609	Economy	30200.00
0005433654919	27609	Economy	30200.00
0005433654955	27609	Economy	30200.00
0005433654966	27609	Economy	30200.00
0005433654956	27609	Economy	30200.00
0005433654935	27609	Economy	30200.00
0005433654958	27609	Economy	30200.00
0005435858696	27609	Economy	30200.00
0005433654952	27609	Economy	30200.00
0005433654982	27609	Economy	30200.00
0005433811677	14435	Economy	4400.00
0005433811673	14435	Economy	4400.00
0005433368901	21763	Business	9800.00
0005433368721	21763	Business	9800.00
0005433368790	21763	Business	9800.00
0005433368850	21763	Economy	3300.00
0005433368910	21763	Economy	3300.00
0005433368907	21763	Economy	3300.00
0005433368691	21763	Economy	3600.00
0005433368863	21763	Economy	3300.00
0005433368854	21763	Economy	3300.00
0005433368923	21763	Economy	3300.00
0005433368851	21763	Economy	3300.00
0005433368828	21763	Economy	3300.00
0005433368722	21763	Economy	3300.00
0005433368886	21763	Economy	3300.00
0005433368769	21763	Economy	3300.00
0005433368873	21763	Economy	3300.00
0005433368832	21763	Economy	3300.00
0005433368957	21763	Economy	3300.00
0005433368938	21763	Economy	3300.00
0005433368958	21763	Economy	3300.00
0005433368715	21763	Economy	3300.00
0005433368682	21763	Economy	3300.00
0005433368924	21763	Economy	3300.00
0005433368885	21763	Economy	3300.00
0005433368905	21763	Economy	3300.00
0005433368884	21763	Economy	3300.00
0005433368900	21763	Economy	3300.00
0005433368811	21763	Economy	3300.00
0005433368720	21763	Economy	3300.00
0005435270177	9357	Business	186200.00
0005435270157	9357	Business	186200.00
0005435270147	9357	Business	186200.00
0005435270159	9357	Business	186200.00
0005433806411	9357	Economy	68300.00
0005435270003	9357	Economy	62100.00
0005435270011	9357	Economy	62100.00
0005434273120	9357	Economy	62100.00
0005435270028	9357	Economy	62100.00
0005434273121	9357	Economy	62100.00
0005435269956	9357	Economy	62100.00
0005435270010	9357	Economy	62100.00
0005435269912	9357	Economy	62100.00
0005435269994	9357	Economy	62100.00
0005435270108	9357	Economy	62100.00
0005435270002	9357	Economy	62100.00
0005432666450	9357	Economy	62100.00
0005434171443	9357	Economy	62100.00
0005435858712	9357	Economy	62100.00
0005434171458	9357	Economy	62100.00
0005435270068	9357	Economy	62100.00
0005434171405	9357	Economy	62100.00
0005435858709	9357	Economy	68300.00
0005435270156	9357	Economy	62100.00
0005434171442	9357	Economy	62100.00
0005435270124	9357	Economy	62100.00
0005434171459	9357	Economy	62100.00
0005434171441	9357	Economy	62100.00
0005434171444	9357	Economy	62100.00
0005435269955	9357	Economy	62100.00
0005435270127	9357	Economy	62100.00
0005435269944	9357	Economy	62100.00
0005435270126	9357	Economy	62100.00
0005434171450	9357	Economy	62100.00
0005435270088	9357	Economy	62100.00
0005435858711	9357	Economy	62100.00
0005435858699	9357	Economy	62100.00
0005435270173	9357	Economy	62100.00
0005433785831	26254	Business	186200.00
0005433785902	26254	Business	186200.00
0005433806346	26254	Business	186200.00
0005433806286	26254	Business	186200.00
0005433806373	26254	Business	186200.00
0005433785929	26254	Business	186200.00
0005433806372	26254	Business	186200.00
0005433785960	26254	Business	186200.00
0005432657518	26254	Business	186200.00
0005435858748	26254	Business	186200.00
0005433785971	26254	Economy	68300.00
0005433806329	26254	Economy	62100.00
0005433806040	26254	Economy	62100.00
0005433785798	26254	Economy	62100.00
0005433785994	26254	Economy	62100.00
0005433786098	26254	Economy	62100.00
0005433806330	26254	Economy	62100.00
0005433806240	26254	Economy	62100.00
0005433785809	26254	Economy	62100.00
0005433786055	26254	Economy	62100.00
0005433785952	26254	Economy	62100.00
0005433786046	26254	Economy	62100.00
0005433786045	26254	Economy	62100.00
0005433806313	26254	Economy	62100.00
0005433785873	26254	Economy	62100.00
0005433763586	26254	Economy	62100.00
0005433786030	26254	Economy	62100.00
0005433763525	26254	Economy	62100.00
0005433786069	26254	Economy	62100.00
0005433806287	26254	Economy	62100.00
0005433785940	26254	Economy	62100.00
0005432657517	26254	Economy	62100.00
0005433763595	26254	Economy	62100.00
0005433763532	26254	Economy	62100.00
0005433785997	26254	Economy	62100.00
0005433806334	26254	Economy	62100.00
0005433806312	26254	Economy	62100.00
0005433785903	26254	Economy	62100.00
0005433806298	26254	Economy	62100.00
0005433806252	26254	Economy	62100.00
0005433806299	26254	Economy	62100.00
0005433785830	26254	Economy	62100.00
0005433763579	26254	Economy	62100.00
0005433785995	26254	Economy	62100.00
0005433786060	26254	Economy	62100.00
0005433785969	26254	Economy	62100.00
0005433806223	26254	Economy	62100.00
0005432657519	26254	Economy	62100.00
0005433786139	26254	Economy	62100.00
0005433786029	26254	Economy	62100.00
0005433786062	26254	Economy	62100.00
0005432657522	26254	Economy	68300.00
0005433786066	26254	Economy	62100.00
0005433785930	26254	Economy	62100.00
0005433806297	26254	Economy	68300.00
0005433806255	26254	Economy	62100.00
0005433786083	26254	Economy	62100.00
0005433786065	26254	Economy	62100.00
0005433785998	26254	Economy	62100.00
0005433806314	26254	Economy	62100.00
0005433785883	26254	Economy	62100.00
0005433763619	26254	Economy	62100.00
0005432657520	26254	Economy	62100.00
0005433785752	26254	Economy	62100.00
0005433763557	26254	Economy	62100.00
0005432659758	26254	Economy	62100.00
0005432663076	26254	Economy	62100.00
0005433785939	26254	Economy	62100.00
0005433806159	26254	Economy	62100.00
0005433763580	26254	Economy	62100.00
0005433786084	26254	Economy	62100.00
0005433786047	26254	Economy	62100.00
0005433785789	26254	Economy	62100.00
0005433786073	26254	Economy	62100.00
0005433806260	26254	Economy	62100.00
0005433806218	26254	Economy	62100.00
0005433806347	26254	Economy	62100.00
0005433786138	26254	Economy	62100.00
0005433806180	26254	Economy	62100.00
0005433785959	26254	Economy	62100.00
0005433786059	26254	Economy	62100.00
0005433785972	26254	Economy	62100.00
0005433763531	26254	Economy	62100.00
0005433806162	26254	Economy	62100.00
0005433785853	26254	Economy	62100.00
0005433786061	26254	Economy	62100.00
0005434218079	9505	Economy	17900.00
0005434218093	9505	Economy	17900.00
0005434218092	9505	Economy	17900.00
0005434218078	9505	Economy	17900.00
0005434983422	27339	Economy	17900.00
0005434983426	27339	Economy	17900.00
0005434983427	27339	Economy	17900.00
0005433962424	24248	Business	36400.00
0005433987140	24248	Business	36400.00
0005433962343	24248	Business	36400.00
0005433986980	24248	Business	36400.00
0005433962242	24248	Business	36400.00
0005433962219	24248	Business	36400.00
0005433962237	24248	Business	36400.00
0005433987304	24248	Business	36400.00
0005433962459	24248	Business	36400.00
0005433962267	24248	Business	36400.00
0005433962204	24248	Economy	13400.00
0005433987222	24248	Economy	13400.00
0005433962480	24248	Economy	12100.00
0005433962366	24248	Economy	12100.00
0005433962401	24248	Economy	12100.00
0005433962307	24248	Economy	12100.00
0005433962414	24248	Economy	12100.00
0005433962337	24248	Economy	12100.00
0005433962392	24248	Economy	12100.00
0005433987343	24248	Economy	12100.00
0005433962293	24248	Economy	12100.00
0005433962300	24248	Economy	12100.00
0005433986979	24248	Economy	12100.00
0005433962247	24248	Economy	12100.00
0005433987128	24248	Economy	12100.00
0005433962341	24248	Economy	12100.00
0005433987119	24248	Economy	12100.00
0005433962487	24248	Economy	12100.00
0005433987226	24248	Economy	12100.00
0005433962413	24248	Economy	12100.00
0005433987364	24248	Economy	12100.00
0005433987154	24248	Economy	12100.00
0005433987278	24248	Economy	12100.00
0005433962227	24248	Economy	12100.00
0005433962207	24248	Economy	12100.00
0005433987179	24248	Economy	12100.00
0005433987335	24248	Economy	12100.00
0005433987264	24248	Economy	12100.00
0005433962364	24248	Economy	12100.00
0005433987232	24248	Economy	12100.00
0005433962299	24248	Economy	12100.00
0005433962296	24248	Economy	12100.00
0005433987338	24248	Economy	12100.00
0005433987227	24248	Economy	12100.00
0005433962304	24248	Economy	12100.00
0005433987022	24248	Economy	12100.00
0005433962303	24248	Economy	12100.00
0005433987069	24248	Economy	12100.00
0005433987153	24248	Economy	12100.00
0005433987055	24248	Economy	12100.00
0005433962333	24248	Economy	12100.00
0005433962342	24248	Economy	12100.00
0005433961929	24248	Economy	12100.00
0005433962099	24248	Economy	12100.00
0005433987303	24248	Economy	12100.00
0005433962254	24248	Economy	12100.00
0005433987205	24248	Economy	12100.00
0005433986930	24248	Economy	12100.00
0005433987145	24248	Economy	13400.00
0005433987265	24248	Economy	13400.00
0005433987129	24248	Economy	12100.00
0005433987341	24248	Economy	12100.00
0005433962458	24248	Economy	12100.00
0005433962253	24248	Economy	12100.00
0005433962363	24248	Economy	12100.00
0005433987342	24248	Economy	12100.00
0005433962334	24248	Economy	12100.00
0005433987151	24248	Economy	12100.00
0005433962350	24248	Economy	12100.00
0005433962375	24248	Economy	12100.00
0005433962394	24248	Economy	12100.00
0005433962203	24248	Economy	12100.00
0005433962266	24248	Economy	12100.00
0005433962210	24248	Economy	12100.00
0005433987277	24248	Economy	12100.00
0005433962229	24248	Economy	12100.00
0005433962321	24248	Economy	12100.00
0005433962425	24248	Economy	12100.00
0005433962376	24248	Economy	12100.00
0005433987170	24248	Economy	12100.00
0005433962255	24248	Economy	12100.00
0005433987184	24248	Economy	12100.00
0005433962220	24248	Economy	12100.00
0005433962067	24248	Economy	12100.00
0005433987081	24248	Economy	12100.00
0005433962226	24248	Economy	12100.00
0005433962268	24248	Economy	12100.00
0005433987195	24248	Economy	12100.00
0005433962365	24248	Economy	12100.00
0005433962351	24248	Economy	12100.00
0005433962301	24248	Economy	12100.00
0005433987021	24248	Economy	12100.00
0005433962423	24248	Economy	12100.00
0005433987144	24248	Economy	12100.00
0005433962437	24248	Economy	12100.00
0005433962294	24248	Economy	12100.00
0005433986882	24248	Economy	12100.00
0005433962390	24248	Economy	12100.00
0005433961930	24248	Economy	12100.00
0005433962447	24248	Economy	12100.00
0005433987054	24248	Economy	12100.00
0005433962772	25904	Business	36400.00
0005433987379	25904	Business	36400.00
0005433962766	25904	Business	36400.00
0005433962769	25904	Business	36400.00
0005433962768	25904	Economy	12100.00
0005433962770	25904	Economy	12100.00
0005433962767	25904	Economy	12100.00
0005433962773	25904	Economy	12100.00
0005433962765	25904	Economy	12100.00
0005433962771	25904	Economy	12100.00
0005433166288	969	Economy	25400.00
0005433166271	969	Economy	23100.00
0005433166246	969	Economy	23100.00
0005433166284	969	Economy	23100.00
0005433166273	969	Economy	23100.00
0005433166243	969	Economy	23100.00
0005433166272	969	Economy	23100.00
0005433166217	969	Economy	23100.00
0005433166201	969	Economy	23100.00
0005434481055	969	Economy	23100.00
0005433166202	969	Economy	23100.00
0005433166216	969	Economy	23100.00
0005433166285	969	Economy	23100.00
0005433166231	969	Economy	23100.00
0005434481056	969	Economy	23100.00
0005434480999	16561	Economy	25400.00
0005434480994	16561	Economy	23100.00
0005434480985	16561	Economy	23100.00
0005434480997	16561	Economy	23100.00
0005434480946	16561	Economy	23100.00
0005434480947	16561	Economy	23100.00
0005434480941	16561	Economy	23100.00
0005434480963	16561	Economy	23100.00
0005434481000	16561	Economy	23100.00
0005434480899	16561	Economy	23100.00
0005434480998	16561	Economy	23100.00
0005434480989	16561	Economy	23100.00
0005434481026	16561	Economy	23100.00
0005435386747	10331	Economy	17000.00
0005433290054	10331	Economy	15400.00
0005435386716	10331	Economy	15400.00
0005433290036	10331	Economy	15400.00
0005433290041	10331	Economy	15400.00
0005435386717	10331	Economy	15400.00
0005433290018	10331	Economy	15400.00
0005435386703	10331	Economy	15400.00
0005433290023	10331	Economy	15400.00
0005433290031	10331	Economy	15400.00
0005435386745	10331	Economy	15400.00
0005435386704	10331	Economy	15400.00
0005433290017	10331	Economy	15400.00
0005435150403	21933	Economy	17000.00
0005435150381	21933	Economy	17000.00
0005435150386	21933	Economy	17000.00
0005435142915	21933	Economy	15400.00
0005435142930	21933	Economy	15400.00
0005435150371	21933	Economy	15400.00
0005435150402	21933	Economy	15400.00
0005435142914	21933	Economy	15400.00
0005435150409	21933	Economy	15400.00
0005435142925	21933	Economy	15400.00
0005435142924	21933	Economy	15400.00
0005435142902	21933	Economy	15400.00
0005435142926	21933	Economy	15400.00
0005435150387	21933	Economy	15400.00
0005435150408	21933	Economy	15400.00
0005435150385	21933	Economy	15400.00
0005435142907	21933	Economy	15400.00
0005435142885	21933	Economy	15400.00
0005435545940	11236	Business	57200.00
0005435529823	11236	Business	57200.00
0005435545934	11236	Business	57200.00
0005435502895	11236	Business	57200.00
0005435529813	11236	Business	57200.00
0005435529822	11236	Business	57200.00
0005435502879	11236	Business	57200.00
0005435545926	11236	Business	57200.00
0005435545963	11236	Business	57200.00
0005435529754	11236	Economy	19100.00
0005435529826	11236	Economy	19100.00
0005435545925	11236	Economy	19100.00
0005435502840	11236	Economy	21000.00
0005435545919	11236	Economy	21000.00
0005435545933	11236	Economy	19100.00
0005435502800	11236	Economy	19100.00
0005435545920	11236	Economy	19100.00
0005435502871	11236	Economy	19100.00
0005435502921	11236	Economy	19100.00
0005435529799	11236	Economy	19100.00
0005435502948	11236	Economy	19100.00
0005435529763	11236	Economy	19100.00
0005435502935	11236	Economy	19100.00
0005435502818	11236	Economy	19100.00
0005435545922	11236	Economy	19100.00
0005435529798	11236	Economy	19100.00
0005435545941	11236	Economy	19100.00
0005435529837	11236	Economy	19100.00
0005435502922	11236	Economy	19100.00
0005435502902	11236	Economy	19100.00
0005435529814	11236	Economy	19100.00
0005435502889	11236	Economy	19100.00
0005435545954	11236	Economy	19100.00
0005435502746	11236	Economy	19100.00
0005435502947	11236	Economy	19100.00
0005435529857	11236	Economy	19100.00
0005435502903	11236	Economy	19100.00
0005435529803	11236	Economy	19100.00
0005435502799	11236	Economy	19100.00
0005435529865	11236	Economy	19100.00
0005435529882	11236	Economy	19100.00
0005434573777	11236	Economy	19100.00
0005435529755	11236	Economy	19100.00
0005435502896	11236	Economy	19100.00
0005435319800	11236	Economy	19100.00
0005435319801	11236	Economy	19100.00
0005435502928	11236	Economy	19100.00
0005435502812	11236	Economy	19100.00
0005435545947	11236	Economy	19100.00
0005435529883	11236	Economy	19100.00
0005435545921	11236	Economy	19100.00
0005435529811	11236	Economy	19100.00
0005435529821	11236	Economy	19100.00
0005434573710	20907	Economy	21000.00
0005434573716	20907	Economy	19100.00
0005434573722	20907	Economy	19100.00
0005434573726	20907	Economy	19100.00
0005434573738	20907	Economy	19100.00
0005434573695	20907	Economy	19100.00
0005434573743	20907	Economy	19100.00
0005434573706	20907	Economy	19100.00
0005434573715	20907	Economy	19100.00
0005434573746	20907	Economy	19100.00
0005433927495	24310	Economy	18800.00
0005433927508	24310	Economy	17100.00
0005433927492	24310	Economy	17100.00
0005433927512	24310	Economy	17100.00
0005433927504	24310	Economy	17100.00
0005433927503	24310	Economy	17100.00
0005433927511	24310	Economy	17100.00
0005433683401	29280	Economy	17100.00
0005433683404	29280	Economy	17100.00
0005433683400	29280	Economy	17100.00
0005432693965	3065	Business	10300.00
0005432693798	3065	Business	10300.00
0005432693866	3065	Economy	3400.00
0005432693799	3065	Economy	3400.00
0005432693697	3065	Economy	3400.00
0005432693846	3065	Economy	3400.00
0005432693892	3065	Economy	3400.00
0005432693933	3065	Economy	3400.00
0005432693814	3065	Economy	3400.00
0005432693737	3065	Economy	3400.00
0005432693867	3065	Economy	3400.00
0005432693827	3065	Economy	3400.00
0005432693813	3065	Economy	3400.00
0005432693847	3065	Economy	3400.00
0005432693895	3065	Economy	3400.00
0005432693815	3065	Economy	3400.00
0005432693893	3065	Economy	3400.00
0005432693696	3065	Economy	3400.00
0005432693695	3065	Economy	3400.00
0005432693896	3065	Economy	3400.00
0005432693767	3065	Economy	3400.00
0005433124457	3061	Business	10300.00
0005433124401	3061	Business	10300.00
0005433194976	3061	Business	10300.00
0005433194948	3061	Business	10300.00
0005433194958	3061	Economy	3400.00
0005433194988	3061	Economy	3400.00
0005433194947	3061	Economy	3800.00
0005433194955	3061	Economy	3400.00
0005433124479	3061	Economy	3400.00
0005433124451	3061	Economy	3400.00
0005432881205	3061	Economy	3400.00
0005433124518	3061	Economy	3400.00
0005433194969	3061	Economy	3400.00
0005433124487	3061	Economy	3400.00
0005432881204	3061	Economy	3400.00
0005433124426	3061	Economy	3400.00
0005433124405	3061	Economy	3400.00
0005433194974	3061	Economy	3400.00
0005433124480	3061	Economy	3400.00
0005433124469	3061	Economy	3400.00
0005432881109	3061	Economy	3400.00
0005432881200	3061	Economy	3400.00
0005433124430	3061	Economy	3400.00
0005433124400	3061	Economy	3400.00
0005432881173	3061	Economy	3400.00
0005432881170	3061	Economy	3400.00
0005433124481	3061	Economy	3400.00
0005432881215	3061	Economy	3400.00
0005433194968	3061	Economy	3400.00
0005433194987	3061	Economy	3400.00
0005433124498	3061	Economy	3400.00
0005433124486	3061	Economy	3400.00
0005433124489	3061	Economy	3400.00
0005433124429	3061	Economy	3400.00
0005433124482	3061	Economy	3400.00
0005433194931	3061	Economy	3400.00
0005432707480	30083	Economy	3400.00
0005432707469	30083	Economy	3400.00
0005432707467	30083	Economy	3400.00
0005432707483	30083	Economy	3400.00
0005432707494	30083	Economy	3400.00
0005432707438	30083	Economy	3400.00
0005434989134	23687	Economy	3600.00
0005434989133	23687	Economy	3600.00
0005434988989	27531	Economy	4000.00
0005434989029	27531	Economy	4000.00
0005434980606	27531	Economy	4000.00
0005434980528	27531	Economy	3600.00
0005434980590	27531	Economy	3600.00
0005434980470	27531	Economy	3600.00
0005434980589	27531	Economy	3600.00
0005434980627	27531	Economy	3600.00
0005434980540	27531	Economy	3600.00
0005434980520	27531	Economy	3600.00
0005434980625	27531	Economy	3600.00
0005434989022	27531	Economy	3600.00
0005434980521	27531	Economy	3600.00
0005434980646	27531	Economy	3600.00
0005434980649	27531	Economy	3600.00
0005434980553	27531	Economy	3600.00
0005434980552	27531	Economy	3600.00
0005434980541	27531	Economy	3600.00
0005434980507	27531	Economy	3600.00
0005434980599	27531	Economy	3600.00
0005434980600	27531	Economy	3600.00
0005434989026	27531	Economy	3600.00
0005434980595	27531	Economy	3600.00
0005434988961	27531	Economy	3600.00
0005434980645	27531	Economy	3600.00
0005434989008	27531	Economy	3600.00
0005434989038	27531	Economy	3600.00
0005434988926	27531	Economy	3600.00
0005434980519	27531	Economy	3600.00
0005434988976	27531	Economy	3600.00
0005434980569	27531	Economy	3600.00
0005434980588	27531	Economy	3600.00
0005434989023	27531	Economy	3600.00
0005434980570	27531	Economy	3600.00
0005434980586	27531	Economy	3600.00
0005434980585	27531	Economy	3600.00
0005434980508	27531	Economy	3600.00
0005434980607	27531	Economy	3600.00
0005434980497	27531	Economy	3600.00
0005434989039	27531	Economy	3600.00
0005434980471	27531	Economy	3600.00
0005433111559	10249	Economy	21600.00
0005433113593	10249	Economy	19700.00
0005433113591	10249	Economy	19700.00
0005433111564	10249	Economy	19700.00
0005434302555	19607	Economy	19700.00
0005434302566	19607	Economy	19700.00
0005434302572	19607	Economy	19700.00
0005435925677	3552	Business	26900.00
0005435925678	3552	Business	26900.00
0005435925660	3552	Business	26900.00
0005435925664	3552	Economy	9000.00
0005435925692	3552	Economy	9000.00
0005435939945	3552	Economy	9000.00
0005435070570	3552	Economy	9000.00
0005435925706	3552	Economy	9000.00
0005435939946	3552	Economy	9000.00
0005435925671	3552	Economy	9000.00
0005435070569	3552	Economy	9000.00
0005435925622	3552	Economy	9000.00
0005435070572	3552	Economy	9000.00
0005435925634	3552	Economy	9000.00
0005435925653	3552	Economy	9000.00
0005435925707	3552	Economy	9000.00
0005435939935	3552	Economy	9000.00
0005435925670	3552	Economy	9000.00
0005435939953	3552	Economy	9000.00
0005435070571	3552	Economy	9000.00
0005435719063	15309	Business	26900.00
0005435070338	15309	Business	26900.00
0005435719003	15309	Business	26900.00
0005435719069	15309	Business	26900.00
0005435070542	15309	Business	26900.00
0005435719041	15309	Business	26900.00
0005435719045	15309	Business	26900.00
0005435719086	15309	Business	26900.00
0005435070379	15309	Business	26900.00
0005435070294	15309	Business	26900.00
0005435070404	15309	Business	26900.00
0005435719035	15309	Business	26900.00
0005435719038	15309	Economy	9000.00
0005435719040	15309	Economy	9000.00
0005435719091	15309	Economy	9000.00
0005435719072	15309	Economy	9000.00
0005435070434	15309	Economy	9000.00
0005435719065	15309	Economy	9000.00
0005435070462	15309	Economy	9000.00
0005435719087	15309	Economy	9000.00
0005435070478	15309	Economy	9000.00
0005435719090	15309	Economy	9000.00
0005435719037	15309	Economy	9900.00
0005435070377	15309	Economy	9900.00
0005435070314	15309	Economy	9900.00
0005435719088	15309	Economy	9900.00
0005435719047	15309	Economy	9900.00
0005435070324	15309	Economy	9000.00
0005435719066	15309	Economy	9000.00
0005435719084	15309	Economy	9000.00
0005435070494	15309	Economy	9000.00
0005435070380	15309	Economy	9000.00
0005435719026	15309	Economy	9000.00
0005435719076	15309	Economy	9000.00
0005435070445	15309	Economy	9000.00
0005435070461	15309	Economy	9000.00
0005435070256	15309	Economy	9000.00
0005435070315	15309	Economy	9000.00
0005435719080	15309	Economy	9000.00
0005435719036	15309	Economy	9000.00
0005435070364	15309	Economy	9000.00
0005435719094	15309	Economy	9000.00
0005435070282	15309	Economy	9000.00
0005435070406	15309	Economy	9000.00
0005435719077	15309	Economy	9000.00
0005435719046	15309	Economy	9000.00
0005435719021	15309	Economy	9000.00
0005435719033	15309	Economy	9000.00
0005435719052	15309	Economy	9000.00
0005435070335	15309	Economy	9000.00
0005435070459	15309	Economy	9000.00
0005435719051	15309	Economy	9000.00
0005435719053	15309	Economy	9000.00
0005435719095	15309	Economy	9000.00
0005435719060	15309	Economy	9000.00
0005435070471	15309	Economy	9000.00
0005435070257	15309	Economy	9000.00
0005435719050	15309	Economy	9000.00
0005435070394	15309	Economy	9000.00
0005435719014	15309	Economy	9000.00
0005435070345	15309	Economy	9000.00
0005435070479	15309	Economy	9000.00
0005435070504	15309	Economy	9000.00
0005435719059	15309	Economy	9000.00
0005435070120	15309	Economy	9000.00
0005435719064	15309	Economy	9000.00
0005435719020	15309	Economy	9000.00
0005435719082	15309	Economy	9000.00
0005435070332	15309	Economy	9000.00
0005435719039	15309	Economy	9000.00
0005435070424	15309	Economy	9000.00
0005435719055	15309	Economy	9000.00
0005435070376	15309	Economy	9000.00
0005435070313	15309	Economy	9000.00
0005435070339	15309	Economy	9000.00
0005435719085	15309	Economy	9000.00
0005435070227	15309	Economy	9000.00
0005435719013	15309	Economy	9000.00
0005435719081	15309	Economy	9000.00
0005435070493	15309	Economy	9000.00
0005435719089	15309	Economy	9000.00
0005435719056	15309	Economy	9000.00
0005435070367	15309	Economy	9000.00
0005435070429	15309	Economy	9000.00
0005435070438	15309	Economy	9000.00
0005435070425	15309	Economy	9000.00
0005435070550	15309	Economy	9000.00
0005435070366	15309	Economy	9000.00
0005435070460	15309	Economy	9000.00
0005435719062	15309	Economy	9000.00
0005435719032	15309	Economy	9000.00
0005435719092	15309	Economy	9000.00
0005435070444	15309	Economy	9000.00
0005435070375	15309	Economy	9000.00
0005435719057	15309	Economy	9000.00
0005435070119	15309	Economy	9000.00
0005432658655	18184	Economy	5900.00
0005432658654	18184	Economy	5900.00
0005432667511	26401	Economy	5900.00
0005432667513	26401	Economy	5900.00
0005432667514	26401	Economy	5900.00
0005432664195	26401	Economy	5900.00
0005432667508	26401	Economy	5900.00
0005432664191	26401	Economy	5900.00
0005432664192	26401	Economy	5900.00
0005432667512	26401	Economy	5900.00
0005432920471	169	Business	20000.00
0005432677658	169	Business	20000.00
0005432920431	169	Business	20000.00
0005432920469	169	Business	20000.00
0005433103669	169	Business	20000.00
0005433103582	169	Business	20000.00
0005433103748	169	Business	20000.00
0005433103709	169	Business	20000.00
0005432902090	169	Business	20000.00
0005433103695	169	Business	20000.00
0005433103770	169	Business	20000.00
0005433103644	169	Business	20000.00
0005432920338	169	Business	20000.00
0005432677665	169	Business	20000.00
0005433103597	169	Business	20000.00
0005432920331	169	Business	20000.00
0005432902116	169	Business	20000.00
0005433103749	169	Business	20000.00
0005432677657	169	Economy	7300.00
0005433103933	169	Economy	7300.00
0005433103742	169	Economy	7300.00
0005433103896	169	Economy	7300.00
0005433103472	169	Economy	6700.00
0005433103593	169	Economy	6700.00
0005433103973	169	Economy	6700.00
0005433103833	169	Economy	6700.00
0005432920453	169	Economy	6700.00
0005433103645	169	Economy	6700.00
0005432920438	169	Economy	6700.00
0005433103643	169	Economy	6700.00
0005433103508	169	Economy	6700.00
0005433103698	169	Economy	6700.00
0005433103537	169	Economy	6700.00
0005433103494	169	Economy	6700.00
0005433103743	169	Economy	6700.00
0005433103747	169	Economy	6700.00
0005432392068	169	Economy	6700.00
0005433103697	169	Economy	6700.00
0005433103936	169	Economy	6700.00
0005432920426	169	Economy	6700.00
0005433103935	169	Economy	6700.00
0005433103416	169	Economy	6700.00
0005433103572	169	Economy	6700.00
0005433103541	169	Economy	6700.00
0005433103729	169	Economy	6700.00
0005433103662	169	Economy	6700.00
0005432902046	169	Economy	6700.00
0005432392055	169	Economy	6700.00
0005433103737	169	Economy	6700.00
0005433103810	169	Economy	6700.00
0005433103570	169	Economy	6700.00
0005432920411	169	Economy	6700.00
0005433103902	169	Economy	6700.00
0005433103614	169	Economy	6700.00
0005433103668	169	Economy	6700.00
0005433103598	169	Economy	6700.00
0005433103509	169	Economy	6700.00
0005432920379	169	Economy	6700.00
0005433103624	169	Economy	6700.00
0005432920402	169	Economy	6700.00
0005433103505	169	Economy	6700.00
0005433103617	169	Economy	6700.00
0005433103430	169	Economy	6700.00
0005433103868	169	Economy	6700.00
0005433103573	169	Economy	6700.00
0005433103718	169	Economy	7300.00
0005432920439	169	Economy	7300.00
0005432677688	169	Economy	7300.00
0005433103554	169	Economy	6700.00
0005433103654	169	Economy	6700.00
0005433103777	169	Economy	6700.00
0005433103785	169	Economy	6700.00
0005433103616	169	Economy	7300.00
0005433103625	169	Economy	6700.00
0005433103664	169	Economy	6700.00
0005432392071	169	Economy	6700.00
0005433103449	169	Economy	6700.00
0005433103901	169	Economy	6700.00
0005433103415	169	Economy	6700.00
0005432392073	169	Economy	6700.00
0005433103867	169	Economy	6700.00
0005433103719	169	Economy	6700.00
0005433103812	169	Economy	6700.00
0005433103528	169	Economy	6700.00
0005433103615	169	Economy	6700.00
0005433103634	169	Economy	6700.00
0005432902087	169	Economy	6700.00
0005433103663	169	Economy	6700.00
0005433103661	169	Economy	6700.00
0005432920364	169	Economy	6700.00
0005433103580	169	Economy	6700.00
0005433103835	169	Economy	6700.00
0005433103779	169	Economy	6700.00
0005433103864	169	Economy	6700.00
0005432920400	169	Economy	6700.00
0005433103417	169	Economy	6700.00
0005433103627	169	Economy	6700.00
0005433103823	169	Economy	6700.00
0005433103934	169	Economy	6700.00
0005433103796	169	Economy	6700.00
0005433103653	169	Economy	6700.00
0005433103581	169	Economy	6700.00
0005433103527	169	Economy	6700.00
0005432920441	169	Economy	6700.00
0005433103670	169	Economy	6700.00
0005432920419	169	Economy	6700.00
0005432902053	169	Economy	6700.00
0005433103684	169	Economy	6700.00
0005432920470	169	Economy	6700.00
0005433103704	169	Economy	6700.00
0005433103736	169	Economy	6700.00
0005433103623	169	Economy	6700.00
0005432392072	169	Economy	6700.00
0005433103642	169	Economy	6700.00
0005433103710	169	Economy	6700.00
0005433103732	169	Economy	6700.00
0005432902089	169	Economy	6700.00
0005433103809	169	Economy	6700.00
0005432902088	169	Economy	6700.00
0005433103792	169	Economy	6700.00
0005432902033	169	Economy	6700.00
0005432902114	169	Economy	6700.00
0005432756924	168	Business	20000.00
0005432753387	168	Economy	7300.00
0005432756926	168	Economy	7300.00
0005432756932	168	Economy	6700.00
0005434157989	168	Economy	6700.00
0005433690984	168	Economy	6700.00
0005432756934	168	Economy	6700.00
0005433690974	168	Economy	6700.00
0005432756920	168	Economy	6700.00
0005432753398	168	Economy	6700.00
0005432753395	168	Economy	6700.00
0005432756925	168	Economy	6700.00
0005432756933	168	Economy	6700.00
0005433687751	168	Economy	6700.00
0005432753389	168	Economy	6700.00
0005432753393	168	Economy	6700.00
0005432753391	168	Economy	6700.00
0005432753392	168	Economy	6700.00
0005433477280	8093	Business	20000.00
0005434151805	8093	Business	20000.00
0005433477121	8093	Business	20000.00
0005433477180	8093	Business	20000.00
0005433477151	8093	Business	20000.00
0005433477248	8093	Business	20000.00
0005433477144	8093	Economy	7300.00
0005433477118	8093	Economy	7300.00
0005434157723	8093	Economy	6700.00
0005433477192	8093	Economy	6700.00
0005434151803	8093	Economy	6700.00
0005434157729	8093	Economy	6700.00
0005433477125	8093	Economy	6700.00
0005433477139	8093	Economy	6700.00
0005433477089	8093	Economy	6700.00
0005433477232	8093	Economy	6700.00
0005433477209	8093	Economy	6700.00
0005433477152	8093	Economy	6700.00
0005433477256	8093	Economy	6700.00
0005433477281	8093	Economy	6700.00
0005433929899	8093	Economy	6700.00
0005434151820	8093	Economy	6700.00
0005433477250	8093	Economy	6700.00
0005433477122	8093	Economy	6700.00
0005433477140	8093	Economy	6700.00
0005433104008	8093	Economy	6700.00
0005433477219	8093	Economy	6700.00
0005434151806	8093	Economy	6700.00
0005433477119	8093	Economy	6700.00
0005433477153	8093	Economy	6700.00
0005433477088	8093	Economy	6700.00
0005433477158	8093	Economy	6700.00
0005434151804	8093	Economy	6700.00
0005433477181	8093	Economy	6700.00
0005433477231	8093	Economy	6700.00
0005434151807	8093	Economy	6700.00
0005434151808	8093	Economy	6700.00
0005433477282	8093	Economy	6700.00
0005432818153	8095	Business	20000.00
0005432818248	8095	Business	20000.00
0005432818156	8095	Economy	7300.00
0005432818271	8095	Economy	7300.00
0005432818295	8095	Economy	7300.00
0005432818293	8095	Economy	6700.00
0005432818218	8095	Economy	6700.00
0005432818154	8095	Economy	6700.00
0005432818155	8095	Economy	6700.00
0005432818262	8095	Economy	6700.00
0005432818187	8095	Economy	7300.00
0005432818270	8095	Economy	6700.00
0005432818327	8095	Economy	6700.00
0005432818219	8095	Economy	6700.00
0005432818272	8095	Economy	6700.00
0005432818292	8095	Economy	6700.00
0005432818216	8095	Economy	6700.00
0005434175871	9680	Economy	6900.00
0005434175867	9680	Economy	6900.00
0005433870793	32358	Economy	6900.00
0005435914126	3478	Comfort	19900.00
0005435914152	3478	Comfort	19900.00
0005435914750	3478	Comfort	19900.00
0005435914060	3478	Comfort	19900.00
0005435914155	3478	Comfort	19900.00
0005435914088	3478	Comfort	19900.00
0005435903189	3478	Economy	11700.00
0005435914058	3478	Economy	11700.00
0005435903175	3478	Economy	11700.00
0005435914127	3478	Economy	11700.00
0005435914763	3478	Economy	11700.00
0005435914062	3478	Economy	11700.00
0005435903156	3478	Economy	11700.00
0005435903182	3478	Economy	11700.00
0005435914119	3478	Economy	11700.00
0005435914063	3478	Economy	12800.00
0005435914125	3478	Economy	11700.00
0005435914144	3478	Economy	11700.00
0005435914112	3478	Economy	11700.00
0005435903174	3478	Economy	11700.00
0005435127589	3478	Economy	11700.00
0005435914143	3478	Economy	11700.00
0005435903190	3478	Economy	11700.00
0005435903134	3478	Economy	11700.00
0005435903135	3478	Economy	11700.00
0005435914198	3478	Economy	11700.00
0005435914059	3478	Economy	11700.00
0005435903168	3478	Economy	11700.00
0005435903126	3478	Economy	11700.00
0005435903181	3478	Economy	11700.00
0005435626872	3478	Economy	11700.00
0005435914128	3478	Economy	11700.00
0005435127590	3478	Economy	11700.00
0005435914199	3478	Economy	11700.00
0005434880627	14544	Business	35000.00
0005434880878	14544	Business	35000.00
0005434938633	14544	Business	35000.00
0005432800149	14544	Business	35000.00
0005435626644	14544	Business	35000.00
0005435127427	14544	Business	35000.00
0005435127324	14544	Business	35000.00
0005435626687	14544	Business	35000.00
0005434427410	14544	Business	35000.00
0005434938692	14544	Business	35000.00
0005435127284	14544	Business	35000.00
0005432800210	14544	Business	35000.00
0005434880731	14544	Business	35000.00
0005434880850	14544	Comfort	19900.00
0005434880575	14544	Comfort	19900.00
0005434938657	14544	Comfort	19900.00
0005435127433	14544	Comfort	19900.00
0005435127420	14544	Comfort	19900.00
0005434880920	14544	Comfort	19900.00
0005435127517	14544	Comfort	19900.00
0005434880922	14544	Comfort	19900.00
0005435127404	14544	Comfort	19900.00
0005432800188	14544	Comfort	19900.00
0005432800239	14544	Comfort	19900.00
0005435127424	14544	Comfort	19900.00
0005435127472	14544	Comfort	19900.00
0005435626655	14544	Comfort	19900.00
0005434427419	14544	Comfort	19900.00
0005435127463	14544	Comfort	19900.00
0005434880576	14544	Comfort	19900.00
0005434880421	14544	Comfort	19900.00
0005435127395	14544	Comfort	19900.00
0005434880901	14544	Comfort	19900.00
0005435127281	14544	Comfort	19900.00
0005434880629	14544	Comfort	19900.00
0005435626682	14544	Comfort	19900.00
0005435127434	14544	Economy	11700.00
0005434880867	14544	Economy	11700.00
0005434880441	14544	Economy	11700.00
0005434880753	14544	Economy	11700.00
0005435127437	14544	Economy	11700.00
0005435127323	14544	Economy	11700.00
0005434880422	14544	Economy	11700.00
0005434938546	14544	Economy	11700.00
0005434880898	14544	Economy	11700.00
0005435127361	14544	Economy	11700.00
0005435626634	14544	Economy	11700.00
0005435626640	14544	Economy	11700.00
0005434427426	14544	Economy	11700.00
0005434427420	14544	Economy	11700.00
0005434880746	14544	Economy	11700.00
0005432800103	14544	Economy	11700.00
0005432800221	14544	Economy	11700.00
0005434880530	14544	Economy	11700.00
0005434427366	14544	Economy	11700.00
0005434880281	14544	Economy	11700.00
0005434880667	14544	Economy	11700.00
0005434880682	14544	Economy	11700.00
0005432800202	14544	Economy	11700.00
0005434880597	14544	Economy	11700.00
0005435127369	14544	Economy	11700.00
0005434880839	14544	Economy	11700.00
0005435127524	14544	Economy	11700.00
0005432800264	14544	Economy	11700.00
0005434880951	14544	Economy	11700.00
0005435127399	14544	Economy	11700.00
0005434880282	14544	Economy	11700.00
0005435127400	14544	Economy	12800.00
0005432800238	14544	Economy	11700.00
0005434880649	14544	Economy	11700.00
0005435626623	14544	Economy	11700.00
0005435127405	14544	Economy	11700.00
0005435127372	14544	Economy	11700.00
0005434427268	14544	Economy	11700.00
0005434427334	14544	Economy	11700.00
0005434938649	14544	Economy	11700.00
0005434427438	14544	Economy	11700.00
0005435127486	14544	Economy	11700.00
0005432800259	14544	Economy	11700.00
0005434427392	14544	Economy	11700.00
0005432800148	14544	Economy	11700.00
0005434880442	14544	Economy	11700.00
0005434880899	14544	Economy	11700.00
0005434880761	14544	Economy	11700.00
0005434880654	14544	Economy	11700.00
0005435626647	14544	Economy	11700.00
0005434427335	14544	Economy	11700.00
0005435127536	14544	Economy	11700.00
0005434938547	14544	Economy	11700.00
0005434427422	14544	Economy	11700.00
0005434938696	14544	Economy	11700.00
0005435626642	14544	Economy	11700.00
0005434880349	14544	Economy	11700.00
0005432611807	14544	Economy	11700.00
0005435127447	14544	Economy	11700.00
0005434880852	14544	Economy	11700.00
0005434880690	14544	Economy	11700.00
0005435626712	14544	Economy	11700.00
0005435626699	14544	Economy	11700.00
0005435626671	14544	Economy	11700.00
0005434880596	14544	Economy	11700.00
0005434880892	14544	Economy	11700.00
0005435626701	14544	Economy	11700.00
0005435127418	14544	Economy	11700.00
0005434880722	14544	Economy	11700.00
0005434938689	14544	Economy	11700.00
0005435626696	14544	Economy	11700.00
0005432611808	14544	Economy	11700.00
0005434880868	14544	Economy	11700.00
0005435626683	14544	Economy	11700.00
0005434938648	14544	Economy	11700.00
0005434880270	14544	Economy	11700.00
0005435626724	14544	Economy	11700.00
0005435127325	14544	Economy	11700.00
0005434880843	14544	Economy	11700.00
0005434938670	14544	Economy	11700.00
0005434880280	14544	Economy	11700.00
0005434880271	14544	Economy	11700.00
0005435626544	14544	Economy	11700.00
0005434880716	14544	Economy	11700.00
0005435127460	14544	Economy	11700.00
0005434880569	14544	Economy	11700.00
0005435626686	14544	Economy	11700.00
0005435914216	14544	Economy	11700.00
0005434938628	14544	Economy	11700.00
0005434880353	14544	Economy	11700.00
0005434938645	14544	Economy	11700.00
0005434427267	14544	Economy	11700.00
0005432800260	14544	Economy	12800.00
0005434880628	14544	Economy	12800.00
0005434880803	14544	Economy	12800.00
0005434880877	14544	Economy	12800.00
0005435626703	14544	Economy	11700.00
0005435127485	14544	Economy	11700.00
0005434880800	14544	Economy	11700.00
0005434880623	14544	Economy	11700.00
0005434938658	14544	Economy	11700.00
0005435626695	14544	Economy	11700.00
0005434880865	14544	Economy	11700.00
0005435127519	14544	Economy	11700.00
0005434938659	14544	Economy	11700.00
0005435127421	14544	Economy	11700.00
0005435127297	14544	Economy	11700.00
0005435626656	14544	Economy	11700.00
0005434880420	14544	Economy	11700.00
0005434880836	14544	Economy	11700.00
0005434880891	14544	Economy	11700.00
0005434427437	14544	Economy	11700.00
0005434427393	14544	Economy	11700.00
0005435626700	14544	Economy	11700.00
0005432800277	14544	Economy	11700.00
0005434880730	14544	Economy	11700.00
0005432800187	14544	Economy	11700.00
0005434427322	14544	Economy	11700.00
0005432800222	14544	Economy	11700.00
0005434880745	14544	Economy	11700.00
0005434880752	14544	Economy	11700.00
0005435127461	14544	Economy	11700.00
0005435626639	14544	Economy	11700.00
0005434880939	14544	Economy	11700.00
0005434880571	14544	Economy	11700.00
0005435626545	14544	Economy	11700.00
0005434880687	14544	Economy	11700.00
0005432800104	14544	Economy	11700.00
0005435626597	14544	Economy	11700.00
0005435127371	14544	Economy	11700.00
0005434880505	14544	Economy	11700.00
0005435127394	14544	Economy	11700.00
0005435127478	14544	Economy	11700.00
0005435127448	14544	Economy	11700.00
0005434880529	14544	Economy	11700.00
0005434880663	14544	Economy	11700.00
0005435127419	14544	Economy	11700.00
0005435626690	14544	Economy	11700.00
0005434880352	14544	Economy	11700.00
0005432800217	14544	Economy	11700.00
0005434880626	14544	Economy	11700.00
0005434880897	14544	Economy	11700.00
0005435127256	14544	Economy	11700.00
0005435626661	14544	Economy	11700.00
0005435626659	14544	Economy	11700.00
0005432800195	14544	Economy	11700.00
0005434880461	14544	Economy	11700.00
0005435626621	14544	Economy	11700.00
0005434880419	14544	Economy	11700.00
0005434427365	14544	Economy	11700.00
0005435626693	14544	Economy	11700.00
0005435127438	14544	Economy	11700.00
0005434880860	14544	Economy	11700.00
0005434880921	14544	Economy	11700.00
0005432800164	14544	Economy	11700.00
0005435127516	14544	Economy	11700.00
0005434880764	14544	Economy	11700.00
0005435890061	3596	Economy	14800.00
0005435890026	3596	Economy	14800.00
0005435890063	3596	Economy	14800.00
0005435890062	3596	Economy	14800.00
0005435890038	3596	Economy	14800.00
0005434325918	15622	Economy	16300.00
0005434312393	15622	Economy	16300.00
0005434325973	15622	Economy	14800.00
0005434312394	15622	Economy	14800.00
0005434325980	15622	Economy	14800.00
0005434325979	15622	Economy	14800.00
0005434325975	15622	Economy	14800.00
0005434312395	15622	Economy	14800.00
0005434325917	15622	Economy	14800.00
0005434312396	15622	Economy	14800.00
0005434312391	15622	Economy	14800.00
0005433420642	633	Economy	4100.00
0005433420643	633	Economy	4100.00
0005433420644	633	Economy	4100.00
0005435958027	15178	Economy	4100.00
0005435958104	15178	Economy	4100.00
0005435958107	15178	Economy	4100.00
0005435958101	15178	Economy	4100.00
0005435958113	15178	Economy	4100.00
0005435958106	15178	Economy	4100.00
0005435958028	15178	Economy	4100.00
0005435958052	15178	Economy	4100.00
0005435958092	15178	Economy	4100.00
0005434995366	6701	Economy	31300.00
0005434247201	8848	Economy	10400.00
0005434247218	8848	Economy	10400.00
0005434247217	8848	Economy	10400.00
0005434247220	8848	Economy	10400.00
0005435629439	16048	Economy	10400.00
0005435629445	16048	Economy	10400.00
0005434467831	4018	Economy	21200.00
0005434467830	4018	Economy	21200.00
0005434467815	23216	Economy	21200.00
0005434467813	23216	Economy	21200.00
0005434467814	23216	Economy	21200.00
0005434467810	23216	Economy	21200.00
0005434467827	23216	Economy	21200.00
0005432646379	6839	Business	87700.00
0005432646378	6839	Business	87700.00
0005435229593	6839	Economy	29200.00
0005435229598	6839	Economy	32200.00
0005435229617	6839	Economy	29200.00
0005435229613	6839	Economy	29200.00
0005435229632	6839	Economy	29200.00
0005435229599	6839	Economy	29200.00
0005435229631	6839	Economy	29200.00
0005435229622	6839	Economy	29200.00
0005435229587	6839	Economy	29200.00
0005435229610	6839	Economy	29200.00
0005435229620	6839	Economy	29200.00
0005435229570	6839	Economy	29200.00
0005435229594	6839	Economy	29200.00
0005435229608	6839	Economy	29200.00
0005435229588	6839	Economy	29200.00
0005435229589	6839	Economy	29200.00
0005435229567	6839	Economy	29200.00
0005432646273	25110	Business	87700.00
0005432646280	25110	Business	87700.00
0005432646290	25110	Business	87700.00
0005435229642	25110	Business	87700.00
0005432646320	25110	Business	87700.00
0005432646255	25110	Business	87700.00
0005432646292	25110	Economy	29200.00
0005432646283	25110	Economy	29200.00
0005432646360	25110	Economy	29200.00
0005432646305	25110	Economy	32200.00
0005432646281	25110	Economy	32200.00
0005432646298	25110	Economy	32200.00
0005432646311	25110	Economy	29200.00
0005432646341	25110	Economy	29200.00
0005432646284	25110	Economy	29200.00
0005432646285	25110	Economy	29200.00
0005432646296	25110	Economy	29200.00
0005432646203	25110	Economy	29200.00
0005432646303	25110	Economy	29200.00
0005432646309	25110	Economy	29200.00
0005432646297	25110	Economy	29200.00
0005432646306	25110	Economy	29200.00
0005432646286	25110	Economy	29200.00
0005432646323	25110	Economy	29200.00
0005432646300	25110	Economy	29200.00
0005432646324	25110	Economy	29200.00
0005435229643	25110	Economy	29200.00
0005432646291	25110	Economy	29200.00
0005432646274	25110	Economy	29200.00
0005432646302	25110	Economy	29200.00
0005432646295	25110	Economy	29200.00
0005432646359	25110	Economy	29200.00
0005432646322	25110	Economy	29200.00
0005432646293	25110	Economy	29200.00
0005432646301	25110	Economy	29200.00
0005432646361	25110	Economy	29200.00
0005432646304	25110	Economy	29200.00
0005432646321	25110	Economy	29200.00
0005432646272	25110	Economy	29200.00
0005432646289	25110	Economy	29200.00
0005432646328	25110	Economy	29200.00
0005432646332	25110	Economy	29200.00
0005432646316	25110	Economy	29200.00
0005432646312	25110	Economy	29200.00
0005432646282	25110	Economy	29200.00
0005432646347	25110	Economy	29200.00
0005432646363	25110	Economy	29200.00
0005432646315	25110	Economy	29200.00
0005432646314	25110	Economy	29200.00
0005432646287	25110	Economy	29200.00
0005432646299	25110	Economy	29200.00
0005432646356	25110	Economy	29200.00
0005432646313	25110	Economy	29200.00
0005432646294	25110	Economy	29200.00
0005432646331	25110	Economy	29200.00
0005433405017	2864	Business	12600.00
0005433405019	2864	Economy	4200.00
0005433405018	2864	Economy	4200.00
0005433405022	2864	Economy	4200.00
0005433404991	2864	Economy	4200.00
0005433405014	2864	Economy	4200.00
0005433405013	2864	Economy	4200.00
0005433404992	2864	Economy	4200.00
0005435797880	29303	Business	12600.00
0005435797875	29303	Business	12600.00
0005435797892	29303	Economy	4200.00
0005435797890	29303	Economy	4200.00
0005435797874	29303	Economy	4600.00
0005435797855	29303	Economy	4600.00
0005435797853	29303	Economy	4600.00
0005435797870	29303	Economy	4200.00
0005435797879	29303	Economy	4200.00
0005435797861	29303	Economy	4200.00
0005435797873	29303	Economy	4200.00
0005435797860	29303	Economy	4200.00
0005435797852	29303	Economy	4200.00
0005435376426	5760	Economy	6800.00
0005435376425	5760	Economy	6800.00
0005435376430	5760	Economy	6800.00
0005435376423	5760	Economy	6800.00
0005435376431	5760	Economy	6800.00
0005435376427	5760	Economy	6800.00
0005434948229	16362	Economy	6800.00
0005434948260	16362	Economy	6800.00
0005434948241	16362	Economy	6800.00
0005434948227	16362	Economy	6800.00
0005434948240	16362	Economy	6800.00
0005434948261	16362	Economy	6800.00
0005434948215	16362	Economy	6800.00
0005433962309	25726	Business	21400.00
0005433962283	25726	Business	21400.00
0005433962310	25726	Business	21400.00
0005433961963	25726	Business	21400.00
0005433962378	25726	Business	21400.00
0005433962232	25726	Business	21400.00
0005433962400	25726	Economy	7100.00
0005433962403	25726	Economy	7100.00
0005433962179	25726	Economy	7100.00
0005433962261	25726	Economy	7100.00
0005433961962	25726	Economy	7100.00
0005433962281	25726	Economy	7100.00
0005433962347	25726	Economy	7800.00
0005433962308	25726	Economy	7800.00
0005433962339	25726	Economy	7100.00
0005433962155	25726	Economy	7100.00
0005433962192	25726	Economy	7100.00
0005433962357	25726	Economy	7100.00
0005433962325	25726	Economy	7100.00
0005433962291	25726	Economy	7100.00
0005433962260	25726	Economy	7100.00
0005433962345	25726	Economy	7100.00
0005433962208	25726	Economy	7100.00
0005433962305	25726	Economy	7100.00
0005433962241	25726	Economy	7100.00
0005433962158	25726	Economy	7100.00
0005433962407	25726	Economy	7100.00
0005433962320	25726	Economy	7100.00
0005433962398	25726	Economy	7100.00
0005433962263	25726	Economy	7100.00
0005433962102	25726	Economy	7100.00
0005433962113	25726	Economy	7100.00
0005433962175	25726	Economy	7100.00
0005433962399	25726	Economy	7100.00
0005433962284	25726	Economy	7100.00
0005433962250	25726	Economy	7100.00
0005433962328	25726	Economy	7100.00
0005433962340	25726	Economy	7100.00
0005433962282	25726	Economy	7100.00
0005433962209	25726	Economy	7100.00
0005433962346	25726	Economy	7100.00
0005433962161	25726	Economy	7100.00
0005433962249	25726	Economy	7100.00
0005433962358	25726	Economy	7100.00
0005433962173	25726	Economy	7100.00
0005433962108	25726	Economy	7100.00
0005433962402	25726	Economy	7100.00
0005433962233	25726	Economy	7100.00
0005433962195	25726	Economy	7100.00
0005433962373	25726	Economy	7100.00
0005433962374	25726	Economy	7100.00
0005433961948	25726	Economy	7100.00
0005433962015	25726	Economy	7100.00
0005433962372	25726	Economy	7100.00
0005433962277	25726	Economy	7100.00
0005433962318	25726	Economy	7100.00
0005435083000	24535	Economy	3900.00
0005435083005	24535	Economy	3900.00
0005435082958	24535	Economy	3900.00
0005435083029	24535	Economy	3900.00
0005435082999	24535	Economy	3900.00
0005435083004	24535	Economy	3900.00
0005435377993	26045	Economy	3900.00
0005435286884	5112	Business	18000.00
0005435286776	5112	Business	18000.00
0005435286788	5112	Business	18000.00
0005435286930	5112	Business	18000.00
0005435286775	5112	Business	18000.00
0005435286820	5112	Business	18000.00
0005435286823	5112	Business	18000.00
0005435286910	5112	Business	18000.00
0005433534541	5112	Business	18000.00
0005435287050	5112	Business	18000.00
0005435286911	5112	Economy	6600.00
0005435286944	5112	Economy	6600.00
0005435286787	5112	Economy	6000.00
0005435286917	5112	Economy	6000.00
0005435286859	5112	Economy	6000.00
0005435286875	5112	Economy	6000.00
0005435286867	5112	Economy	6000.00
0005435286929	5112	Economy	6000.00
0005435286928	5112	Economy	6000.00
0005435286883	5112	Economy	6000.00
0005435286798	5112	Economy	6000.00
0005435286821	5112	Economy	6000.00
0005435286848	5112	Economy	6000.00
0005435286827	5112	Economy	6000.00
0005435286860	5112	Economy	6000.00
0005433534554	5112	Economy	6600.00
0005433534551	5112	Economy	6600.00
0005435286918	5112	Economy	6000.00
0005435286866	5112	Economy	6000.00
0005435286839	5112	Economy	6000.00
0005435286799	5112	Economy	6000.00
0005435286838	5112	Economy	6000.00
0005435286926	5112	Economy	6000.00
0005433534549	5112	Economy	6000.00
0005435286919	5112	Economy	6000.00
0005435286927	5112	Economy	6000.00
0005435287024	5112	Economy	6000.00
0005435286857	5112	Economy	6000.00
0005435286822	5112	Economy	6000.00
0005435286876	5112	Economy	6000.00
0005435286879	5112	Economy	6000.00
0005433534542	5112	Economy	6000.00
0005433534548	5112	Economy	6000.00
0005435286826	5112	Economy	6000.00
0005434230283	5111	Business	18000.00
0005434230287	5111	Economy	6000.00
0005434230286	5111	Economy	6000.00
0005432666450	5111	Economy	6000.00
0005434230285	5111	Economy	6000.00
0005434230279	5111	Economy	6600.00
0005434230282	5111	Economy	6000.00
0005434230280	5111	Economy	6000.00
0005434230281	5111	Economy	6000.00
0005434230284	5111	Economy	6000.00
0005435007703	5108	Business	18000.00
0005435270165	5108	Business	18000.00
0005432336361	5108	Business	18000.00
0005432336375	5108	Business	18000.00
0005435007628	5108	Business	18000.00
0005435007685	5108	Business	18000.00
0005435007679	5108	Business	18000.00
0005435270150	5108	Business	18000.00
0005435270038	5108	Business	18000.00
0005433815507	5108	Economy	6000.00
0005435270111	5108	Economy	6000.00
0005435007692	5108	Economy	6000.00
0005435270123	5108	Economy	6000.00
0005435007701	5108	Economy	6000.00
0005434265903	5108	Economy	6000.00
0005435270172	5108	Economy	6000.00
0005434311278	5108	Economy	6000.00
0005432336358	5108	Economy	6000.00
0005435270185	5108	Economy	6000.00
0005435270050	5108	Economy	6000.00
0005435270064	5108	Economy	6000.00
0005435007702	5108	Economy	6000.00
0005435270182	5108	Economy	6000.00
0005432336362	5108	Economy	6000.00
0005435270118	5108	Economy	6000.00
0005435270035	5108	Economy	6000.00
0005435270187	5108	Economy	6600.00
0005435007700	5108	Economy	6600.00
0005433688867	5108	Economy	6000.00
0005435007610	5108	Economy	6600.00
0005435007605	5108	Economy	6000.00
0005435270036	5108	Economy	6000.00
0005434312377	5108	Economy	6000.00
0005435007674	5108	Economy	6000.00
0005434265904	5108	Economy	6000.00
0005435007684	5108	Economy	6000.00
0005435270219	5108	Economy	6000.00
0005432336329	5108	Economy	6000.00
0005435007611	5108	Economy	6000.00
0005435270210	5108	Economy	6000.00
0005433688866	5108	Economy	6000.00
0005432336339	5108	Economy	6000.00
0005435270163	5108	Economy	6000.00
0005432336353	5108	Economy	6000.00
0005435007644	5108	Economy	6000.00
0005432336340	5108	Economy	6000.00
0005433815506	5108	Economy	6000.00
0005435270162	5108	Economy	6000.00
0005435269983	5108	Economy	6000.00
0005435270112	5108	Economy	6000.00
0005433785994	8442	Business	18000.00
0005434245676	8442	Business	18000.00
0005433786060	8442	Business	18000.00
0005434245770	8442	Business	18000.00
0005433786045	8442	Business	18000.00
0005434245745	8442	Business	18000.00
0005433785939	8442	Business	18000.00
0005434245729	8442	Business	18000.00
0005433785998	8442	Economy	6600.00
0005434245782	8442	Economy	6600.00
0005433785789	8442	Economy	6600.00
0005434245602	8442	Economy	6600.00
0005434245623	8442	Economy	6000.00
0005434245677	8442	Economy	6000.00
0005433786138	8442	Economy	6000.00
0005434245713	8442	Economy	6000.00
0005433785809	8442	Economy	6000.00
0005433786069	8442	Economy	6000.00
0005433786066	8442	Economy	6000.00
0005433786073	8442	Economy	6000.00
0005433785952	8442	Economy	6000.00
0005433786098	8442	Economy	6000.00
0005434245819	8442	Economy	6000.00
0005432663076	8442	Economy	6000.00
0005433785971	8442	Economy	6000.00
0005433786055	8442	Economy	6000.00
0005433785995	8442	Economy	6000.00
0005433786059	8442	Economy	6000.00
0005434245756	8442	Economy	6600.00
0005433785903	8442	Economy	6600.00
0005433786139	8442	Economy	6600.00
0005433786061	8442	Economy	6000.00
0005434245776	8442	Economy	6000.00
0005433786062	8442	Economy	6000.00
0005433786065	8442	Economy	6000.00
0005432659758	8442	Economy	6000.00
0005433785940	8442	Economy	6000.00
0005433785883	8442	Economy	6000.00
0005434245753	8442	Economy	6000.00
0005433785972	8442	Economy	6000.00
0005433786083	8442	Economy	6000.00
0005433785929	8442	Economy	6000.00
0005433786047	8442	Economy	6000.00
0005433785902	8442	Economy	6000.00
0005434245684	8442	Economy	6000.00
0005433786030	8442	Economy	6000.00
0005433785873	8442	Economy	6000.00
0005433785960	8442	Economy	6000.00
0005433786046	8442	Economy	6000.00
0005433785798	8442	Economy	6000.00
0005433785969	8442	Economy	6000.00
0005433786029	8442	Economy	6000.00
0005433785930	8442	Economy	6000.00
0005434245784	8442	Economy	6000.00
0005433785997	8442	Economy	6000.00
0005433786084	8442	Economy	6000.00
0005434245728	8442	Economy	6000.00
0005434245622	8442	Economy	6000.00
0005433785853	8442	Economy	6000.00
0005433785831	8442	Economy	6000.00
0005433785959	8442	Economy	6000.00
0005433785752	8442	Economy	6000.00
0005433785830	8442	Economy	6000.00
0005433616675	8441	Business	18000.00
0005433616507	8441	Business	18000.00
0005433616700	8441	Business	18000.00
0005433616745	8441	Business	18000.00
0005433616568	8441	Business	18000.00
0005433616527	8441	Business	18000.00
0005433616744	8441	Business	18000.00
0005433616663	8441	Business	18000.00
0005433616565	8441	Business	18000.00
0005433616766	8441	Economy	6600.00
0005433616357	8441	Economy	6600.00
0005433616595	8441	Economy	6600.00
0005433616767	8441	Economy	6600.00
0005433616523	8441	Economy	6600.00
0005433616492	8441	Economy	6000.00
0005433616157	8441	Economy	6000.00
0005433616622	8441	Economy	6000.00
0005433616707	8441	Economy	6000.00
0005433616493	8441	Economy	6000.00
0005433616564	8441	Economy	6000.00
0005433616674	8441	Economy	6000.00
0005433616348	8441	Economy	6000.00
0005433616460	8441	Economy	6000.00
0005433616616	8441	Economy	6000.00
0005433616609	8441	Economy	6000.00
0005433616724	8441	Economy	6000.00
0005433616739	8441	Economy	6000.00
0005433616482	8441	Economy	6000.00
0005433616712	8441	Economy	6000.00
0005433616576	8441	Economy	6000.00
0005433616557	8441	Economy	6000.00
0005433616467	8441	Economy	6000.00
0005433616569	8441	Economy	6000.00
0005433616562	8441	Economy	6600.00
0005433616503	8441	Economy	6600.00
0005433616705	8441	Economy	6600.00
0005433616561	8441	Economy	6600.00
0005433616491	8441	Economy	6600.00
0005433616494	8441	Economy	6000.00
0005433616577	8441	Economy	6000.00
0005433616686	8441	Economy	6000.00
0005433616615	8441	Economy	6000.00
0005433616468	8441	Economy	6000.00
0005433616746	8441	Economy	6000.00
0005433616697	8441	Economy	6000.00
0005433616495	8441	Economy	6000.00
0005433616249	8441	Economy	6000.00
0005433616580	8441	Economy	6000.00
0005433616617	8441	Economy	6000.00
0005433616175	8441	Economy	6000.00
0005433616665	8441	Economy	6000.00
0005433616437	8441	Economy	6000.00
0005433616517	8441	Economy	6000.00
0005433616545	8441	Economy	6000.00
0005433616483	8441	Economy	6000.00
0005433616768	8441	Economy	6000.00
0005433616242	8441	Economy	6000.00
0005433616664	8441	Economy	6000.00
0005433616701	8441	Economy	6000.00
0005433616608	8441	Economy	6000.00
0005433616530	8441	Economy	6000.00
0005433616241	8441	Economy	6000.00
0005434265811	8440	Business	18000.00
0005434229962	8440	Business	18000.00
0005434229965	8440	Business	18000.00
0005434265891	8440	Business	18000.00
0005435287055	8440	Business	18000.00
0005434229961	8440	Business	18000.00
0005434265827	8440	Business	18000.00
0005434230013	8440	Business	18000.00
0005434265790	8440	Economy	6600.00
0005434150057	8440	Economy	6000.00
0005434229926	8440	Economy	6000.00
0005434265767	8440	Economy	6000.00
0005434229937	8440	Economy	6000.00
0005435551786	8440	Economy	6000.00
0005434150053	8440	Economy	6000.00
0005434265812	8440	Economy	6000.00
0005434265890	8440	Economy	6000.00
0005434229940	8440	Economy	6000.00
0005434229993	8440	Economy	6000.00
0005434229960	8440	Economy	6000.00
0005435287057	8440	Economy	6000.00
0005434229930	8440	Economy	6000.00
0005434229938	8440	Economy	6000.00
0005434229963	8440	Economy	6000.00
0005434230005	8440	Economy	6000.00
0005434229988	8440	Economy	6600.00
0005434150046	8440	Economy	6600.00
0005434265830	8440	Economy	6000.00
0005434150045	8440	Economy	6000.00
0005434229854	8440	Economy	6000.00
0005434229929	8440	Economy	6000.00
0005435287056	8440	Economy	6000.00
0005434229987	8440	Economy	6000.00
0005434265831	8440	Economy	6000.00
0005434229855	8440	Economy	6000.00
0005434173634	8440	Economy	6000.00
0005434150049	8440	Economy	6000.00
0005434229964	8440	Economy	6000.00
0005434265782	8440	Economy	6000.00
0005434265804	8440	Economy	6000.00
0005434265832	8440	Economy	6000.00
0005434173629	8440	Economy	6000.00
0005434230012	8440	Economy	6000.00
0005434265793	8440	Economy	6000.00
0005434639961	12627	Economy	16200.00
0005434640053	12627	Economy	14800.00
0005434639989	12627	Economy	14800.00
0005434640034	12627	Economy	14800.00
0005434640056	12627	Economy	14800.00
0005434640103	12627	Economy	14800.00
0005434640102	12627	Economy	14800.00
0005434640024	12627	Economy	14800.00
0005434640026	12627	Economy	14800.00
0005434639960	12627	Economy	14800.00
0005434639988	12627	Economy	14800.00
0005434640052	12627	Economy	14800.00
0005434639987	12627	Economy	14800.00
0005433202798	12627	Economy	14800.00
0005434640029	12627	Economy	14800.00
0005434639906	12627	Economy	14800.00
0005433202799	12627	Economy	14800.00
0005434640051	12627	Economy	14800.00
0005433202719	23353	Economy	14800.00
0005433202753	23353	Economy	14800.00
0005433202681	23353	Economy	14800.00
0005433202729	23353	Economy	14800.00
0005433202718	23353	Economy	14800.00
0005433202746	23353	Economy	14800.00
0005433202738	23353	Economy	14800.00
0005433202754	23353	Economy	14800.00
0005433202717	23353	Economy	14800.00
0005434640106	23353	Economy	14800.00
0005433202737	23353	Economy	14800.00
0005432329765	21066	Business	18900.00
0005432329868	21066	Business	18900.00
0005432329788	21066	Business	18900.00
0005432329764	21066	Business	18900.00
0005432329755	21066	Business	18900.00
0005432329865	21066	Business	18900.00
0005432384239	21066	Business	18900.00
0005432384298	21066	Business	18900.00
0005432384250	21066	Business	18900.00
0005432329859	21066	Business	18900.00
0005432384179	21066	Economy	6300.00
0005432329707	21066	Economy	6300.00
0005432329757	21066	Economy	6300.00
0005432329871	21066	Economy	6300.00
0005432329862	21066	Economy	6300.00
0005432329738	21066	Economy	6300.00
0005432384259	21066	Economy	6900.00
0005432329861	21066	Economy	6900.00
0005432384237	21066	Economy	6900.00
0005432384193	21066	Economy	6900.00
0005432384220	21066	Economy	6300.00
0005432384238	21066	Economy	6300.00
0005432384292	21066	Economy	6300.00
0005432384125	21066	Economy	6300.00
0005432329819	21066	Economy	6300.00
0005432329983	21066	Economy	6300.00
0005432329911	21066	Economy	6300.00
0005432384283	21066	Economy	6300.00
0005432384185	21066	Economy	6300.00
0005432329803	21066	Economy	6300.00
0005432329961	21066	Economy	6300.00
0005432330002	21066	Economy	6300.00
0005432384128	21066	Economy	6300.00
0005432329756	21066	Economy	6300.00
0005432329963	21066	Economy	6300.00
0005432330017	21066	Economy	6300.00
0005432384167	21066	Economy	6300.00
0005432329817	21066	Economy	6300.00
0005432384107	21066	Economy	6300.00
0005432384235	21066	Economy	6300.00
0005432384287	21066	Economy	6300.00
0005432384263	21066	Economy	6300.00
0005432329858	21066	Economy	6300.00
0005432329804	21066	Economy	6300.00
0005432329905	21066	Economy	6300.00
0005432330018	21066	Economy	6300.00
0005432330003	21066	Economy	6300.00
0005432384246	21066	Economy	6300.00
0005432329869	21066	Economy	6300.00
0005432329962	21066	Economy	6300.00
0005432384184	21066	Economy	6300.00
0005432384187	21066	Economy	6300.00
0005432329918	21066	Economy	6300.00
0005432329872	21066	Economy	6300.00
0005432329863	21066	Economy	6300.00
0005432384120	21066	Economy	6300.00
0005432329813	21066	Economy	6300.00
0005432329982	21066	Economy	6300.00
0005432329657	21066	Economy	6300.00
0005432383957	21066	Economy	6300.00
0005432329972	21066	Economy	6300.00
0005432329881	21066	Economy	6300.00
0005432384282	21066	Economy	6300.00
0005432384262	21066	Economy	6300.00
0005432329898	21066	Economy	6300.00
0005432384297	21066	Economy	6300.00
0005432384164	21066	Economy	6300.00
0005432384291	21066	Economy	6300.00
0005432384151	21066	Economy	6300.00
0005432384201	21066	Economy	6300.00
0005432329843	21066	Economy	6300.00
0005432329675	21066	Economy	6300.00
0005432384165	21066	Economy	6300.00
0005432329912	21066	Economy	6300.00
0005432329910	21066	Economy	6300.00
0005432329950	21066	Economy	6300.00
0005432384210	21066	Economy	6300.00
0005432384236	21066	Economy	6300.00
0005432384227	21066	Economy	6300.00
0005432329919	21066	Economy	6300.00
0005432384106	21066	Economy	6300.00
0005432848900	31256	Business	18900.00
0005432330060	31256	Business	18900.00
0005432848889	31256	Economy	6300.00
0005432848906	31256	Economy	6900.00
0005432330061	31256	Economy	6300.00
0005432848891	31256	Economy	6300.00
0005432848890	31256	Economy	6300.00
0005432848899	31256	Economy	6300.00
0005432848901	31256	Economy	6300.00
0005432330062	31256	Economy	6300.00
0005432848872	31256	Economy	6300.00
0005432462583	13356	Economy	4200.00
0005432426077	13356	Economy	4200.00
0005432425665	30742	Business	12700.00
0005432425794	30742	Business	12700.00
0005432425729	30742	Business	12700.00
0005432425763	30742	Business	12700.00
0005432425725	30742	Business	12700.00
0005432425615	30742	Business	12700.00
0005432425610	30742	Business	12700.00
0005432425438	30742	Business	12700.00
0005432425551	30742	Economy	4200.00
0005432425726	30742	Economy	4200.00
0005432425582	30742	Economy	4200.00
0005432425788	30742	Economy	4200.00
0005432425767	30742	Economy	4200.00
0005432425765	30742	Economy	4700.00
0005432425564	30742	Economy	4700.00
0005432425703	30742	Economy	4700.00
0005432425626	30742	Economy	4700.00
0005432425390	30742	Economy	4200.00
0005432425668	30742	Economy	4200.00
0005432425694	30742	Economy	4200.00
0005432425786	30742	Economy	4200.00
0005432425718	30742	Economy	4200.00
0005432425782	30742	Economy	4200.00
0005432425591	30742	Economy	4200.00
0005432425776	30742	Economy	4200.00
0005432425693	30742	Economy	4200.00
0005432425778	30742	Economy	4200.00
0005432425711	30742	Economy	4200.00
0005432425731	30742	Economy	4200.00
0005432425724	30742	Economy	4200.00
0005432425523	30742	Economy	4200.00
0005432425743	30742	Economy	4200.00
0005432425643	30742	Economy	4200.00
0005432425686	30742	Economy	4200.00
0005432425688	30742	Economy	4200.00
0005432425753	30742	Economy	4200.00
0005432425550	30742	Economy	4200.00
0005432425730	30742	Economy	4200.00
0005432425636	30742	Economy	4200.00
0005432425744	30742	Economy	4200.00
0005432425592	30742	Economy	4200.00
0005432425754	30742	Economy	4200.00
0005432425766	30742	Economy	4200.00
0005432425609	30742	Economy	4200.00
0005432425598	30742	Economy	4200.00
0005432425685	30742	Economy	4200.00
0005432425777	30742	Economy	4200.00
0005432425719	30742	Economy	4200.00
0005432425692	30742	Economy	4200.00
0005432425716	30742	Economy	4200.00
0005432425818	30742	Economy	4200.00
0005432425639	30742	Economy	4200.00
0005432902113	9607	Business	32600.00
0005432902052	9607	Business	32600.00
0005432902051	9607	Business	32600.00
0005432902091	9607	Economy	10900.00
0005432902044	9607	Economy	10900.00
0005434186273	9607	Economy	10900.00
0005434157635	9607	Economy	10900.00
0005432902057	9607	Economy	10900.00
0005432902030	9607	Economy	10900.00
0005432902098	9607	Economy	10900.00
0005432902022	9607	Economy	10900.00
0005432902102	9607	Economy	10900.00
0005434157710	9607	Economy	10900.00
0005434448401	29011	Business	32600.00
0005432818292	29011	Business	32600.00
0005434448385	29011	Business	32600.00
0005432818270	29011	Business	32600.00
0005432818248	29011	Business	32600.00
0005432818218	29011	Economy	10900.00
0005432818153	29011	Economy	10900.00
0005432818293	29011	Economy	10900.00
0005432822373	29011	Economy	10900.00
0005432822374	29011	Economy	11900.00
0005432818262	29011	Economy	10900.00
0005432822397	29011	Economy	10900.00
0005432818216	29011	Economy	10900.00
0005432818272	29011	Economy	10900.00
0005432818327	29011	Economy	10900.00
0005432818156	29011	Economy	10900.00
0005432818187	29011	Economy	10900.00
0005432822419	29011	Economy	10900.00
0005432818219	29011	Economy	10900.00
0005434448384	29011	Economy	10900.00
0005432818271	29011	Economy	10900.00
0005432818154	29011	Economy	10900.00
0005432818295	29011	Economy	10900.00
0005432822398	29011	Economy	10900.00
0005434448398	29011	Economy	10900.00
0005432822387	29011	Economy	10900.00
0005432818155	29011	Economy	10900.00
0005432611807	31612	Economy	11000.00
0005432611808	31612	Economy	11000.00
0005432949605	11863	Business	105900.00
0005432949582	11863	Business	105900.00
0005432949539	11863	Business	105900.00
0005432949407	11863	Business	105900.00
0005432949444	11863	Business	105900.00
0005432949499	11863	Business	105900.00
0005432949573	11863	Business	105900.00
0005432949569	11863	Business	105900.00
0005432949468	11863	Economy	35300.00
0005432949606	11863	Economy	38800.00
0005432949568	11863	Economy	38800.00
0005432949395	11863	Economy	35300.00
0005432949498	11863	Economy	35300.00
0005432949470	11863	Economy	35300.00
0005432949550	11863	Economy	35300.00
0005432949620	11863	Economy	35300.00
0005432949472	11863	Economy	35300.00
0005432949400	11863	Economy	35300.00
0005432949505	11863	Economy	35300.00
0005432949471	11863	Economy	35300.00
0005432949301	11863	Economy	35300.00
0005433570987	11863	Economy	35300.00
0005432949617	11863	Economy	35300.00
0005432949546	11863	Economy	35300.00
0005432949482	11863	Economy	35300.00
0005432949504	11863	Economy	35300.00
0005432949618	11863	Economy	35300.00
0005432949538	11863	Economy	35300.00
0005433570986	11863	Economy	35300.00
0005432949510	11863	Economy	35300.00
0005432949621	11863	Economy	35300.00
0005432949619	11863	Economy	35300.00
0005432949511	11863	Economy	35300.00
0005432949430	11863	Economy	35300.00
0005432949622	11863	Economy	35300.00
0005433570988	11863	Economy	35300.00
0005432949509	11863	Economy	35300.00
0005433570733	25321	Business	105900.00
0005433570751	25321	Business	105900.00
0005433570501	25321	Business	105900.00
0005433570473	25321	Business	105900.00
0005433570442	25321	Business	105900.00
0005433570672	25321	Business	105900.00
0005433570364	25321	Business	105900.00
0005433570781	25321	Business	105900.00
0005433570630	25321	Business	105900.00
0005433570799	25321	Business	105900.00
0005433570443	25321	Business	105900.00
0005433570762	25321	Business	105900.00
0005433570526	25321	Business	105900.00
0005433570711	25321	Business	105900.00
0005433570574	25321	Economy	35300.00
0005433570903	25321	Economy	35300.00
0005433570948	25321	Economy	35300.00
0005433570797	25321	Economy	35300.00
0005433570557	25321	Economy	35300.00
0005433570688	25321	Economy	35300.00
0005433570761	25321	Economy	35300.00
0005433570851	25321	Economy	35300.00
0005433570601	25321	Economy	35300.00
0005433570754	25321	Economy	35300.00
0005433570637	25321	Economy	38800.00
0005433570510	25321	Economy	38800.00
0005433570796	25321	Economy	35300.00
0005433570789	25321	Economy	35300.00
0005433570550	25321	Economy	35300.00
0005433570472	25321	Economy	35300.00
0005433570729	25321	Economy	35300.00
0005433570904	25321	Economy	35300.00
0005433570702	25321	Economy	35300.00
0005433570634	25321	Economy	35300.00
0005433570551	25321	Economy	35300.00
0005433570734	25321	Economy	35300.00
0005433570905	25321	Economy	35300.00
0005433570700	25321	Economy	35300.00
0005433570669	25321	Economy	35300.00
0005433570790	25321	Economy	35300.00
0005433570878	25321	Economy	35300.00
0005433570467	25321	Economy	35300.00
0005433570433	25321	Economy	35300.00
0005433570798	25321	Economy	35300.00
0005433570504	25321	Economy	35300.00
0005433570794	25321	Economy	35300.00
0005433570657	25321	Economy	35300.00
0005433570791	25321	Economy	35300.00
0005433570576	25321	Economy	35300.00
0005433570475	25321	Economy	35300.00
0005433570692	25321	Economy	35300.00
0005433570658	25321	Economy	35300.00
0005433570816	25321	Economy	35300.00
0005433570680	25321	Economy	35300.00
0005433570648	25321	Economy	35300.00
0005433570835	25321	Economy	35300.00
0005433570708	25321	Economy	35300.00
0005433570689	25321	Economy	35300.00
0005433570834	25321	Economy	35300.00
0005433570598	25321	Economy	35300.00
0005433570687	25321	Economy	35300.00
0005433570735	25321	Economy	35300.00
0005433570699	25321	Economy	35300.00
0005433570577	25321	Economy	35300.00
0005433570929	25321	Economy	35300.00
0005433570703	25321	Economy	35300.00
0005433570887	25321	Economy	35300.00
0005433570365	25321	Economy	35300.00
0005433570704	25321	Economy	35300.00
0005433570617	25321	Economy	35300.00
0005433570366	25321	Economy	35300.00
0005433570886	25321	Economy	35300.00
0005433570363	25321	Economy	35300.00
0005433570693	25321	Economy	35300.00
0005433570573	25321	Economy	35300.00
0005432430956	30822	Business	117400.00
0005433812968	30822	Business	117400.00
0005432430946	30822	Business	117400.00
0005434026755	30822	Business	117400.00
0005432430973	30822	Business	117400.00
0005432430954	30822	Economy	39100.00
0005432430960	30822	Economy	39100.00
0005434026756	30822	Economy	43000.00
0005432430955	30822	Economy	39100.00
0005432430957	30822	Economy	39100.00
0005432430951	30822	Economy	39100.00
0005432430969	30822	Economy	39100.00
0005432430968	30822	Economy	39100.00
0005434026747	30822	Economy	39100.00
0005432430939	30822	Economy	39100.00
0005432430958	30822	Economy	39100.00
0005434026752	30822	Economy	39100.00
0005434026750	30822	Economy	39100.00
0005434026746	30822	Economy	39100.00
0005432430967	30822	Economy	39100.00
0005432430959	30822	Economy	39100.00
0005435340652	5415	Economy	22400.00
0005435340614	5415	Economy	24600.00
0005435340654	5415	Economy	24600.00
0005435340659	5415	Economy	22400.00
0005435340637	5415	Economy	22400.00
0005435340676	5415	Economy	22400.00
0005435340651	5415	Economy	22400.00
0005435340702	5415	Economy	22400.00
0005435340613	5415	Economy	22400.00
0005435340674	5415	Economy	22400.00
0005435340653	5415	Economy	22400.00
0005435340595	5415	Economy	22400.00
0005435340701	5415	Economy	22400.00
0005434655446	12517	Business	67200.00
0005434655470	12517	Economy	22400.00
0005434655488	12517	Economy	22400.00
0005434655497	12517	Economy	22400.00
0005434655471	12517	Economy	22400.00
0005434655427	12517	Economy	22400.00
0005434655230	12517	Economy	24600.00
0005434656605	12517	Economy	22400.00
0005434655452	12517	Economy	22400.00
0005434655472	12517	Economy	22400.00
0005434655498	12517	Economy	22400.00
0005434655392	12517	Economy	22400.00
0005434655428	12517	Economy	22400.00
0005434655460	12517	Economy	22400.00
0005434655473	12517	Economy	22400.00
0005434655489	12517	Economy	22400.00
0005434655453	12517	Economy	22400.00
0005434655391	12517	Economy	22400.00
0005434655490	12517	Economy	22400.00
0005434655421	12517	Economy	22400.00
0005434655231	12517	Economy	22400.00
0005434655493	12517	Economy	22400.00
0005434655390	12517	Economy	22400.00
0005435266322	7470	Economy	10700.00
0005433722514	7470	Economy	10700.00
0005435266303	7470	Economy	10700.00
0005435266313	7470	Economy	10700.00
0005435266323	7470	Economy	10700.00
0005435266328	7470	Economy	10700.00
0005435546237	7470	Economy	10700.00
0005433722513	7470	Economy	10700.00
0005433656761	29255	Business	32000.00
0005433717256	29255	Business	32000.00
0005433717266	29255	Business	32000.00
0005433717305	29255	Business	32000.00
0005433717336	29255	Economy	10700.00
0005433717273	29255	Economy	10700.00
0005433717215	29255	Economy	10700.00
0005433717320	29255	Economy	10700.00
0005433717243	29255	Economy	10700.00
0005433717300	29255	Economy	10700.00
0005433719210	29255	Economy	10700.00
0005433719231	29255	Economy	10700.00
0005433717245	29255	Economy	10700.00
0005433717127	29255	Economy	10700.00
0005433717292	29255	Economy	10700.00
0005433722395	29255	Economy	10700.00
0005433722359	29255	Economy	10700.00
0005433722384	29255	Economy	10700.00
0005433717257	29255	Economy	10700.00
0005433717231	29255	Economy	10700.00
0005433717296	29255	Economy	10700.00
0005433717240	29255	Economy	10700.00
0005433722407	29255	Economy	10700.00
0005433717244	29255	Economy	11700.00
0005433722358	29255	Economy	10700.00
0005433717396	29255	Economy	11700.00
0005433717397	29255	Economy	10700.00
0005433717426	29255	Economy	10700.00
0005433656754	29255	Economy	10700.00
0005433722371	29255	Economy	10700.00
0005433688867	29255	Economy	10700.00
0005433656763	29255	Economy	10700.00
0005433717314	29255	Economy	10700.00
0005433717309	29255	Economy	10700.00
0005433717347	29255	Economy	10700.00
0005433717406	29255	Economy	10700.00
0005433722424	29255	Economy	10700.00
0005433722394	29255	Economy	10700.00
0005433717277	29255	Economy	10700.00
0005433717216	29255	Economy	10700.00
0005433722393	29255	Economy	10700.00
0005433717097	29255	Economy	10700.00
0005433717389	29255	Economy	10700.00
0005433717176	29255	Economy	10700.00
0005433717267	29255	Economy	10700.00
0005433688866	29255	Economy	10700.00
0005433722396	29255	Economy	10700.00
0005433717276	29255	Economy	10700.00
0005433717117	29255	Economy	10700.00
0005433722374	29255	Economy	10700.00
0005433717213	29255	Economy	10700.00
0005433722409	29255	Economy	10700.00
0005433717359	29255	Economy	10700.00
0005433722423	29255	Economy	10700.00
0005433717118	29255	Economy	10700.00
0005433717299	29255	Economy	10700.00
0005433722360	29255	Economy	10700.00
0005433717217	29255	Economy	10700.00
0005433717301	29255	Economy	10700.00
0005433717280	29255	Economy	10700.00
0005433717220	29255	Economy	10700.00
0005433717140	29255	Economy	10700.00
0005433717272	29255	Economy	10700.00
0005433656762	29255	Economy	10700.00
0005433717319	29255	Economy	10700.00
0005433722422	29255	Economy	10700.00
0005434182502	8678	Business	36500.00
0005435860692	8678	Business	36500.00
0005435860720	8678	Business	36500.00
0005434182503	8678	Economy	12200.00
0005435860707	8678	Economy	12200.00
0005435860693	8678	Economy	13400.00
0005434182513	8678	Economy	12200.00
0005434182542	8678	Economy	12200.00
0005434182543	8678	Economy	12200.00
0005434184727	8678	Economy	12200.00
0005435860691	8678	Economy	12200.00
0005435860708	8678	Economy	12200.00
0005435860681	8678	Economy	12200.00
0005434182523	8678	Economy	12200.00
0005435860694	8678	Economy	12200.00
0005434182508	8678	Economy	12200.00
0005435860659	8678	Economy	12200.00
0005434182530	8678	Economy	12200.00
0005435860679	8678	Economy	12200.00
0005435860660	8678	Economy	12200.00
0005434184726	8678	Economy	12200.00
0005434143759	11641	Business	36500.00
0005434143758	11641	Business	36500.00
0005434143778	11641	Business	36500.00
0005434143823	11641	Economy	12200.00
0005434095610	11641	Economy	12200.00
0005434143782	11641	Economy	12200.00
0005434095617	11641	Economy	12200.00
0005434143824	11641	Economy	13400.00
0005434095659	11641	Economy	12200.00
0005434143779	11641	Economy	12200.00
0005434326289	11641	Economy	12200.00
0005434095672	11641	Economy	12200.00
0005434095665	11641	Economy	12200.00
0005434143768	11641	Economy	12200.00
0005434143799	11641	Economy	12200.00
0005434095691	11641	Economy	12200.00
0005434095609	11641	Economy	12200.00
0005434095615	11641	Economy	12200.00
0005434143803	11641	Economy	12200.00
0005434143777	11641	Economy	12200.00
0005434143769	11641	Economy	12200.00
0005434095687	11641	Economy	12200.00
0005434095588	11641	Economy	12200.00
0005434143783	11641	Economy	12200.00
0005434095614	11641	Economy	12200.00
0005433399389	1438	Business	33000.00
0005433399253	1438	Business	33000.00
0005433399118	1438	Business	33000.00
0005433399272	1438	Economy	11000.00
0005433399363	1438	Economy	11000.00
0005433399378	1438	Economy	11000.00
0005433399317	1438	Economy	11000.00
0005433399311	1438	Economy	12100.00
0005433399362	1438	Economy	11000.00
0005433399437	1438	Economy	11000.00
0005433399365	1438	Economy	11000.00
0005433399327	1438	Economy	11000.00
0005433399376	1438	Economy	11000.00
0005433399341	1438	Economy	11000.00
0005433399225	1438	Economy	11000.00
0005433399342	1438	Economy	11000.00
0005433399381	1438	Economy	11000.00
0005433399297	1438	Economy	11000.00
0005432906596	1438	Economy	11000.00
0005433399315	1438	Economy	11000.00
0005433399265	1438	Economy	11000.00
0005433399201	1438	Economy	11000.00
0005433399332	1438	Economy	11000.00
0005433399266	1438	Economy	11000.00
0005433399244	1438	Economy	11000.00
0005433399361	1438	Economy	11000.00
0005433399333	1438	Economy	11000.00
0005433399298	1438	Economy	11000.00
0005433399267	1438	Economy	11000.00
0005433399422	1438	Economy	11000.00
0005433399337	1438	Economy	11000.00
0005433399229	1438	Economy	11000.00
0005433399314	1438	Economy	11000.00
0005433399386	1438	Economy	11000.00
0005433399245	1438	Economy	11000.00
0005433399124	1438	Economy	11000.00
0005432906602	1438	Economy	11000.00
0005433399236	1438	Economy	11000.00
0005435732671	19258	Business	33000.00
0005435732673	19258	Economy	11000.00
0005435732669	19258	Economy	11000.00
0005435732677	19258	Economy	11000.00
0005435732680	19258	Economy	11000.00
0005435732631	19258	Economy	11000.00
0005435732632	19258	Economy	11000.00
0005435732633	19258	Economy	11000.00
0005435732699	19258	Economy	11000.00
0005435732662	19258	Economy	11000.00
0005435732679	19258	Economy	11000.00
0005435732676	19258	Economy	11000.00
0005435732649	19258	Economy	11000.00
0005434444145	17336	Economy	14100.00
0005434444140	17336	Economy	14100.00
0005434444144	17336	Economy	14100.00
0005434444143	17336	Economy	14100.00
0005434444041	17336	Economy	14100.00
0005434444066	17336	Economy	14100.00
0005435377643	7229	Economy	5800.00
0005434954701	28352	Economy	5800.00
0005434954712	28352	Economy	5800.00
0005434954716	28352	Economy	5800.00
0005434954715	28352	Economy	5800.00
0005434954713	28352	Economy	5800.00
0005434954714	28352	Economy	5800.00
0005434954710	28352	Economy	5800.00
0005434954709	28352	Economy	5800.00
0005434183637	4460	Economy	14000.00
0005435893824	4460	Economy	14000.00
0005435893815	4460	Economy	14000.00
0005435893836	4460	Economy	14000.00
0005435893829	4460	Economy	14000.00
0005434183636	4460	Economy	14000.00
0005435893835	4460	Economy	14000.00
0005435893823	4460	Economy	14000.00
0005434183635	4460	Economy	14000.00
0005435893828	4460	Economy	14000.00
0005434352011	29659	Economy	14000.00
0005434326058	29659	Economy	14000.00
0005434326059	29659	Economy	14000.00
0005433345674	1056	Business	30600.00
0005433269866	1056	Business	30600.00
0005433345787	1056	Business	30600.00
0005433345976	1056	Business	30600.00
0005433346024	1056	Business	30600.00
0005433345707	1056	Business	30600.00
0005433345658	1056	Business	30600.00
0005433345342	1056	Business	30600.00
0005433345616	1056	Business	30600.00
0005433345973	1056	Business	30600.00
0005433345792	1056	Economy	11200.00
0005433345453	1056	Economy	11200.00
0005433345765	1056	Economy	10200.00
0005433345801	1056	Economy	10200.00
0005433345805	1056	Economy	10200.00
0005433345465	1056	Economy	10200.00
0005433346026	1056	Economy	10200.00
0005433345665	1056	Economy	10200.00
0005433345710	1056	Economy	10200.00
0005433345435	1056	Economy	10200.00
0005433158191	1056	Economy	10200.00
0005433345540	1056	Economy	10200.00
0005433345609	1056	Economy	10200.00
0005433345631	1056	Economy	10200.00
0005433345607	1056	Economy	10200.00
0005433345608	1056	Economy	10200.00
0005433345626	1056	Economy	10200.00
0005433345354	1056	Economy	10200.00
0005433345546	1056	Economy	10200.00
0005433345711	1056	Economy	10200.00
0005433345743	1056	Economy	10200.00
0005433345992	1056	Economy	10200.00
0005433345975	1056	Economy	10200.00
0005433345791	1056	Economy	10200.00
0005433345809	1056	Economy	10200.00
0005433345958	1056	Economy	10200.00
0005433345355	1056	Economy	10200.00
0005433345888	1056	Economy	10200.00
0005433345998	1056	Economy	10200.00
0005433345501	1056	Economy	10200.00
0005433345991	1056	Economy	10200.00
0005433345999	1056	Economy	10200.00
0005433345721	1056	Economy	10200.00
0005433345718	1056	Economy	10200.00
0005433159357	1056	Economy	10200.00
0005433345889	1056	Economy	10200.00
0005433345559	1056	Economy	10200.00
0005433345813	1056	Economy	10200.00
0005433269870	1056	Economy	10200.00
0005433345666	1056	Economy	10200.00
0005433345685	1056	Economy	10200.00
0005433269864	1056	Economy	10200.00
0005433345848	1056	Economy	11200.00
0005433345914	1056	Economy	11200.00
0005433345941	1056	Economy	10200.00
0005433345610	1056	Economy	10200.00
0005433345648	1056	Economy	10200.00
0005433345154	1056	Economy	10200.00
0005433345675	1056	Economy	10200.00
0005433345356	1056	Economy	10200.00
0005433345203	1056	Economy	10200.00
0005433345840	1056	Economy	10200.00
0005433345867	1056	Economy	10200.00
0005433345630	1056	Economy	10200.00
0005433345796	1056	Economy	10200.00
0005433345799	1056	Economy	10200.00
0005433345764	1056	Economy	10200.00
0005433345678	1056	Economy	10200.00
0005433345890	1056	Economy	10200.00
0005433345490	1056	Economy	10200.00
0005433345533	1056	Economy	10200.00
0005433345545	1056	Economy	10200.00
0005433345322	1056	Economy	10200.00
0005433345353	1056	Economy	10200.00
0005433345712	1056	Economy	10200.00
0005433345464	1056	Economy	10200.00
0005433345668	1056	Economy	10200.00
0005433345804	1056	Economy	10200.00
0005433345940	1056	Economy	10200.00
0005435546003	1056	Economy	10200.00
0005433346025	1056	Economy	10200.00
0005433346000	1056	Economy	10200.00
0005433345744	1056	Economy	10200.00
0005433345452	1056	Economy	10200.00
0005433345627	1056	Economy	10200.00
0005435092360	17021	Business	30600.00
0005435530048	17021	Business	30600.00
0005433460478	17021	Business	30600.00
0005435508707	17021	Business	30600.00
0005435508759	17021	Business	30600.00
0005435530099	17021	Business	30600.00
0005433460477	17021	Business	30600.00
0005433460468	17021	Economy	10200.00
0005435092355	17021	Economy	10200.00
0005433462773	17021	Economy	10200.00
0005433462774	17021	Economy	10200.00
0005433460484	17021	Economy	10200.00
0005433462781	17021	Economy	10200.00
0005435545991	17021	Economy	10200.00
0005433346085	17021	Economy	10200.00
0005435092332	17021	Economy	10200.00
0005433462795	17021	Economy	10200.00
0005435508688	17021	Economy	10200.00
0005434445292	17021	Economy	10200.00
0005435530117	17021	Economy	10200.00
0005435508690	17021	Economy	10200.00
0005433460489	17021	Economy	10200.00
0005435092322	17021	Economy	10200.00
0005435092344	17021	Economy	10200.00
0005435508758	17021	Economy	10200.00
0005435530163	17021	Economy	10200.00
0005433462775	17021	Economy	10200.00
0005433462788	17021	Economy	10200.00
0005435530159	17021	Economy	10200.00
0005433462780	17021	Economy	10200.00
0005433460490	17021	Economy	10200.00
0005433462790	17021	Economy	10200.00
0005435530041	17021	Economy	10200.00
0005435508691	17021	Economy	10200.00
0005435508686	17021	Economy	10200.00
0005435508687	17021	Economy	10200.00
0005433462779	17021	Economy	10200.00
0005435530056	17021	Economy	10200.00
0005435508708	17021	Economy	10200.00
0005433460464	17021	Economy	10200.00
0005433460480	17021	Economy	10200.00
0005433460488	17021	Economy	10200.00
0005433460460	17021	Economy	11200.00
0005433460473	17021	Economy	10200.00
0005433462796	17021	Economy	11200.00
0005435508751	17021	Economy	10200.00
0005435508650	17021	Economy	10200.00
0005435092359	17021	Economy	10200.00
0005433462802	17021	Economy	10200.00
0005433346087	17021	Economy	10200.00
0005435508673	17021	Economy	10200.00
0005435092343	17021	Economy	10200.00
0005435530188	17021	Economy	10200.00
0005433460476	17021	Economy	10200.00
0005433460479	17021	Economy	10200.00
0005433460467	17021	Economy	10200.00
0005435508772	17021	Economy	10200.00
0005435530128	17021	Economy	10200.00
0005433460482	17021	Economy	10200.00
0005433462798	17021	Economy	10200.00
0005433460485	17021	Economy	10200.00
0005433460475	17021	Economy	10200.00
0005433460487	17021	Economy	10200.00
0005433462785	17021	Economy	10200.00
0005435530113	17021	Economy	10200.00
0005435508801	17021	Economy	10200.00
0005433346086	17021	Economy	10200.00
0005435508760	17021	Economy	10200.00
0005433462801	17021	Economy	10200.00
0005433462789	17021	Economy	10200.00
0005435508725	17021	Economy	10200.00
0005435508820	17021	Economy	10200.00
0005432390429	18265	Business	101000.00
0005432390390	18265	Business	101000.00
0005432390437	18265	Business	101000.00
0005432390424	18265	Business	101000.00
0005432390420	18265	Business	101000.00
0005432390442	18265	Business	101000.00
0005432392071	18265	Business	101000.00
0005432390393	18265	Business	101000.00
0005432390391	18265	Economy	33700.00
0005432390453	18265	Economy	33700.00
0005432390454	18265	Economy	33700.00
0005432392068	18265	Economy	33700.00
0005432390418	18265	Economy	33700.00
0005432390443	18265	Economy	37000.00
0005432390430	18265	Economy	33700.00
0005432392055	18265	Economy	33700.00
0005432390423	18265	Economy	33700.00
0005432390446	18265	Economy	33700.00
0005432390389	18265	Economy	33700.00
0005432390447	18265	Economy	33700.00
0005432390441	18265	Economy	33700.00
0005432390445	18265	Economy	33700.00
0005432390435	18265	Economy	33700.00
0005432390448	18265	Economy	33700.00
0005432390406	18265	Economy	33700.00
0005432390432	18265	Economy	33700.00
0005432392072	18265	Economy	33700.00
0005432390404	18265	Economy	33700.00
0005432390444	18265	Economy	33700.00
0005432390434	18265	Economy	33700.00
0005432390455	18265	Economy	33700.00
0005432390388	18265	Economy	33700.00
0005432390405	18265	Economy	33700.00
0005432390402	18265	Economy	33700.00
0005432392073	18265	Economy	33700.00
0005432390456	18265	Economy	33700.00
0005432390457	18265	Economy	33700.00
0005432390440	18265	Economy	33700.00
0005432390460	18265	Economy	33700.00
0005432390438	18265	Economy	33700.00
0005432390433	18265	Economy	33700.00
0005432390421	18265	Economy	33700.00
0005432390436	18265	Economy	33700.00
0005432390439	18265	Economy	33700.00
0005432390431	18265	Economy	33700.00
0005432390386	18265	Economy	33700.00
0005434082508	12787	Business	40300.00
0005434069552	12787	Business	40300.00
0005434069352	12787	Business	40300.00
0005434069558	12787	Business	40300.00
0005434069187	12787	Business	40300.00
0005434082625	12787	Business	40300.00
0005434069209	12787	Business	40300.00
0005434069320	12787	Economy	13400.00
0005434069358	12787	Economy	13400.00
0005434069597	12787	Economy	13400.00
0005434069384	12787	Economy	13400.00
0005434069577	12787	Economy	13400.00
0005434069326	12787	Economy	13400.00
0005434069340	12787	Economy	13400.00
0005434069318	12787	Economy	13400.00
0005434069361	12787	Economy	13400.00
0005434069138	12787	Economy	13400.00
0005434082527	12787	Economy	13400.00
0005434082553	12787	Economy	13400.00
0005434082421	12787	Economy	13400.00
0005434082554	12787	Economy	13400.00
0005434069511	12787	Economy	13400.00
0005434069514	12787	Economy	13400.00
0005434069321	12787	Economy	13400.00
0005434069359	12787	Economy	13400.00
0005434069477	12787	Economy	14800.00
0005434069207	12787	Economy	14800.00
0005434082599	12787	Economy	14800.00
0005434082479	12787	Economy	14800.00
0005434082408	12787	Economy	14800.00
0005434082512	12787	Economy	13400.00
0005434069625	12787	Economy	13400.00
0005434069463	12787	Economy	13400.00
0005434069478	12787	Economy	13400.00
0005434069476	12787	Economy	13400.00
0005434082493	12787	Economy	13400.00
0005434069325	12787	Economy	13400.00
0005434082513	12787	Economy	13400.00
0005434069190	12787	Economy	13400.00
0005434082589	12787	Economy	13400.00
0005434069319	12787	Economy	13400.00
0005434069551	12787	Economy	13400.00
0005434069317	12787	Economy	13400.00
0005434082459	12787	Economy	13400.00
0005434026745	12787	Economy	13400.00
0005434069362	12787	Economy	13400.00
0005434082464	12787	Economy	13400.00
0005434069515	12787	Economy	13400.00
0005434069421	12787	Economy	13400.00
0005434069438	12787	Economy	13400.00
0005434069360	12787	Economy	13400.00
0005434082595	12787	Economy	13400.00
0005434069277	12787	Economy	13400.00
0005434082420	12787	Economy	13400.00
0005434069084	12787	Economy	13400.00
0005433989892	12787	Economy	13400.00
0005434069535	12787	Economy	13400.00
0005434082574	12787	Economy	13400.00
0005434082534	12787	Economy	13400.00
0005434069624	12787	Economy	13400.00
0005434082494	12787	Economy	13400.00
0005434069534	12787	Economy	13400.00
0005434082492	12787	Economy	13400.00
0005434069604	12787	Economy	13400.00
0005434069316	12787	Economy	13400.00
0005434069559	12787	Economy	13400.00
0005434069413	12787	Economy	13400.00
0005434069420	12787	Economy	13400.00
0005434069571	12787	Economy	13400.00
0005434082463	12787	Economy	13400.00
0005434082510	12787	Economy	13400.00
0005434082509	12787	Economy	13400.00
0005432433802	30647	Business	40300.00
0005432433815	30647	Economy	13400.00
0005435283463	30647	Economy	13400.00
0005435283496	30647	Economy	13400.00
0005435283507	30647	Economy	13400.00
0005435283491	30647	Economy	13400.00
0005435283462	30647	Economy	13400.00
0005435283426	30647	Economy	13400.00
0005432433814	30647	Economy	13400.00
0005435283513	30647	Economy	13400.00
0005435283514	30647	Economy	13400.00
0005435283490	30647	Economy	13400.00
0005432433822	30647	Economy	13400.00
0005433685593	9041	Economy	17600.00
0005432535954	5536	Business	35300.00
0005434265849	5536	Business	35300.00
0005434265817	5536	Business	35300.00
0005435463449	5536	Business	35300.00
0005435463436	5536	Business	35300.00
0005434265743	5536	Business	35300.00
0005435463419	5536	Business	35300.00
0005434265744	5536	Economy	12900.00
0005434265783	5536	Economy	11800.00
0005435463450	5536	Economy	11800.00
0005434265745	5536	Economy	11800.00
0005435463299	5536	Economy	11800.00
0005435463459	5536	Economy	11800.00
0005435463400	5536	Economy	11800.00
0005435463464	5536	Economy	11800.00
0005435617196	5536	Economy	11800.00
0005435463418	5536	Economy	11800.00
0005434831260	5536	Economy	11800.00
0005435463406	5536	Economy	11800.00
0005435463520	5536	Economy	11800.00
0005435463505	5536	Economy	11800.00
0005435463490	5536	Economy	11800.00
0005434265786	5536	Economy	11800.00
0005435463473	5536	Economy	11800.00
0005435463465	5536	Economy	11800.00
0005434265850	5536	Economy	11800.00
0005434831278	5536	Economy	11800.00
0005434265673	5536	Economy	11800.00
0005435463316	5536	Economy	11800.00
0005432535955	5536	Economy	11800.00
0005434265867	5536	Economy	11800.00
0005435463491	5536	Economy	11800.00
0005435463430	5536	Economy	11800.00
0005435617191	5536	Economy	11800.00
0005435463287	5536	Economy	11800.00
0005434265802	5536	Economy	11800.00
0005435617187	5536	Economy	11800.00
0005434265784	5536	Economy	11800.00
0005434265796	5536	Economy	11800.00
0005435043307	5536	Economy	11800.00
0005435463448	5536	Economy	11800.00
0005432535953	5536	Economy	11800.00
0005435617188	5536	Economy	11800.00
0005435463521	5536	Economy	11800.00
0005435463420	5536	Economy	11800.00
0005435463522	5536	Economy	11800.00
0005434265810	5536	Economy	11800.00
0005435463405	5536	Economy	11800.00
0005434265803	5536	Economy	11800.00
0005434265833	5536	Economy	11800.00
0005434265808	5536	Economy	11800.00
0005435463404	5536	Economy	11800.00
0005435463506	5536	Economy	11800.00
0005435463300	5536	Economy	11800.00
0005434831262	5536	Economy	11800.00
0005435463499	5536	Economy	11800.00
0005434265820	5536	Economy	11800.00
0005435768097	5536	Economy	11800.00
0005434265818	5536	Economy	11800.00
0005434265807	5536	Economy	11800.00
0005434265809	5536	Economy	11800.00
0005434265787	5536	Economy	11800.00
0005434831279	5536	Economy	11800.00
0005435463401	5536	Economy	11800.00
0005435768072	13478	Business	35300.00
0005435767700	13478	Business	35300.00
0005435768061	13478	Business	35300.00
0005435767942	13478	Business	35300.00
0005435722113	13478	Business	35300.00
0005435767908	13478	Business	35300.00
0005435767857	13478	Business	35300.00
0005435767909	13478	Business	35300.00
0005435725728	13478	Business	35300.00
0005435768119	13478	Business	35300.00
0005435768001	13478	Business	35300.00
0005435767703	13478	Business	35300.00
0005435767702	13478	Economy	12900.00
0005435725727	13478	Economy	12900.00
0005435767733	13478	Economy	11800.00
0005435725733	13478	Economy	11800.00
0005435767791	13478	Economy	11800.00
0005435735273	13478	Economy	11800.00
0005435768120	13478	Economy	11800.00
0005435767885	13478	Economy	11800.00
0005435767986	13478	Economy	11800.00
0005435767892	13478	Economy	11800.00
0005435767814	13478	Economy	11800.00
0005435767704	13478	Economy	11800.00
0005435767730	13478	Economy	11800.00
0005435767635	13478	Economy	11800.00
0005435720161	13478	Economy	11800.00
0005435767856	13478	Economy	11800.00
0005435725732	13478	Economy	11800.00
0005435735271	13478	Economy	11800.00
0005435735251	13478	Economy	11800.00
0005435735282	13478	Economy	11800.00
0005435735280	13478	Economy	11800.00
0005435767835	13478	Economy	11800.00
0005435767807	13478	Economy	11800.00
0005434265903	13478	Economy	11800.00
0005435768036	13478	Economy	11800.00
0005435767701	13478	Economy	11800.00
0005435767815	13478	Economy	11800.00
0005435767838	13478	Economy	11800.00
0005435767959	13478	Economy	11800.00
0005435767644	13478	Economy	11800.00
0005435767692	13478	Economy	11800.00
0005435767840	13478	Economy	11800.00
0005435767832	13478	Economy	11800.00
0005435768002	13478	Economy	11800.00
0005435720159	13478	Economy	11800.00
0005435725729	13478	Economy	11800.00
0005435767871	13478	Economy	11800.00
0005435735252	13478	Economy	11800.00
0005435735272	13478	Economy	11800.00
0005435720165	13478	Economy	11800.00
0005435767960	13478	Economy	11800.00
0005435767903	13478	Economy	11800.00
0005435720164	13478	Economy	11800.00
0005435735281	13478	Economy	11800.00
0005435767948	13478	Economy	11800.00
0005435767876	13478	Economy	12900.00
0005435767978	13478	Economy	11800.00
0005435767852	13478	Economy	11800.00
0005435767893	13478	Economy	11800.00
0005435725734	13478	Economy	11800.00
0005435725736	13478	Economy	11800.00
0005435768071	13478	Economy	11800.00
0005435767987	13478	Economy	11800.00
0005435768053	13478	Economy	11800.00
0005434265904	13478	Economy	11800.00
0005435767928	13478	Economy	11800.00
0005435767801	13478	Economy	11800.00
0005435767872	13478	Economy	11800.00
0005435725735	13478	Economy	11800.00
0005435722112	13478	Economy	11800.00
0005435767949	13478	Economy	11800.00
0005435720160	13478	Economy	11800.00
0005435767904	13478	Economy	11800.00
0005435767911	13478	Economy	11800.00
0005435767823	13478	Economy	11800.00
0005435768054	13478	Economy	11800.00
0005435767873	13478	Economy	11800.00
0005435767953	13478	Economy	11800.00
0005435767839	13478	Economy	11800.00
0005435767877	13478	Economy	11800.00
0005435767729	13478	Economy	11800.00
0005435767727	13478	Economy	11800.00
0005435767884	13478	Economy	11800.00
0005435767929	13478	Economy	11800.00
0005435767961	13478	Economy	11800.00
0005435767915	13478	Economy	11800.00
0005435767943	13478	Economy	11800.00
0005435767636	13478	Economy	11800.00
0005435767728	13478	Economy	11800.00
0005435767910	13478	Economy	11800.00
0005434602957	18714	Economy	3300.00
0005434602967	18714	Economy	3300.00
0005434602969	18714	Economy	3300.00
0005434602972	18714	Economy	3300.00
0005434602973	18714	Economy	3300.00
0005434604986	18709	Economy	3300.00
0005434604984	18709	Economy	3300.00
0005434604999	18709	Economy	3300.00
0005434604987	18709	Economy	3300.00
0005434604985	18709	Economy	3300.00
0005434604991	18709	Economy	3300.00
0005434604968	18709	Economy	3300.00
0005434604990	18709	Economy	3300.00
0005434604997	18709	Economy	3300.00
0005434604998	18709	Economy	3300.00
0005435904723	19125	Economy	3300.00
0005435904487	19125	Economy	3300.00
0005435904488	19125	Economy	3300.00
0005434515031	19125	Economy	3300.00
0005433009931	1806	Business	48700.00
0005433009851	1806	Business	48700.00
0005433009937	1806	Business	48700.00
0005433286144	1806	Business	48700.00
0005433009883	1806	Business	48700.00
0005433009919	1806	Business	48700.00
0005433286177	1806	Business	48700.00
0005433009906	1806	Business	48700.00
0005433009738	1806	Economy	16200.00
0005433009736	1806	Economy	16200.00
0005433009821	1806	Economy	16200.00
0005433286110	1806	Economy	16200.00
0005433009787	1806	Economy	16200.00
0005433286100	1806	Economy	17900.00
0005433009953	1806	Economy	17900.00
0005433810819	1806	Economy	17900.00
0005433009639	1806	Economy	17900.00
0005433009640	1806	Economy	16200.00
0005433009942	1806	Economy	16200.00
0005433286131	1806	Economy	16200.00
0005433009710	1806	Economy	16200.00
0005433009792	1806	Economy	16200.00
0005433009585	1806	Economy	16200.00
0005433009727	1806	Economy	16200.00
0005433009852	1806	Economy	16200.00
0005433286067	1806	Economy	16200.00
0005433009952	1806	Economy	16200.00
0005433286030	1806	Economy	16200.00
0005433286196	1806	Economy	16200.00
0005433009814	1806	Economy	16200.00
0005433009923	1806	Economy	16200.00
0005433286122	1806	Economy	16200.00
0005433009709	1806	Economy	16200.00
0005433009920	1806	Economy	16200.00
0005433286091	1806	Economy	16200.00
0005433009849	1806	Economy	16200.00
0005433009793	1806	Economy	16200.00
0005433009941	1806	Economy	16200.00
0005433009890	1806	Economy	16200.00
0005433009786	1806	Economy	16200.00
0005433286151	1806	Economy	16200.00
0005433286137	1806	Economy	16200.00
0005433009909	1806	Economy	16200.00
0005433286029	1806	Economy	16200.00
0005433286089	1806	Economy	16200.00
0005433009737	1806	Economy	16200.00
0005433009689	1806	Economy	16200.00
0005433009586	1806	Economy	16200.00
0005433009800	1806	Economy	16200.00
0005433009834	1806	Economy	16200.00
0005433009801	1806	Economy	16200.00
0005433009850	1806	Economy	16200.00
0005433009660	1806	Economy	16200.00
0005433009871	1806	Economy	16200.00
0005433286152	1806	Economy	16200.00
0005433009631	1806	Economy	16200.00
0005433009939	1806	Economy	16200.00
0005433009910	1806	Economy	16200.00
0005433286090	1806	Economy	16200.00
0005433286138	1806	Economy	16200.00
0005433009982	22557	Business	48700.00
0005433810705	22557	Economy	16200.00
0005433810671	22557	Economy	17900.00
0005433810667	22557	Economy	16200.00
0005433810670	22557	Economy	16200.00
0005433810719	22557	Economy	16200.00
0005433810730	22557	Economy	16200.00
0005433810691	22557	Economy	16200.00
0005433810677	22557	Economy	16200.00
0005433810672	22557	Economy	16200.00
0005433810743	22557	Economy	16200.00
0005433810676	22557	Economy	16200.00
0005433009983	22557	Economy	16200.00
0005434153567	25339	Business	83800.00
0005434153566	25339	Business	83800.00
0005434153572	25339	Economy	27900.00
0005434152838	25339	Economy	27900.00
0005434153569	25339	Economy	30700.00
0005434152836	25339	Economy	27900.00
0005434152848	25339	Economy	27900.00
0005434152847	25339	Economy	27900.00
0005434153579	25339	Economy	27900.00
0005434152844	25339	Economy	27900.00
0005434152843	25339	Economy	27900.00
0005434152835	25339	Economy	27900.00
0005434153583	25339	Economy	27900.00
0005434152837	25339	Economy	27900.00
0005434152839	25339	Economy	27900.00
0005434153580	25339	Economy	27900.00
0005434153560	25339	Economy	27900.00
0005435283186	5571	Business	99800.00
0005435283195	5571	Business	99800.00
0005435283101	5571	Business	99800.00
0005435283164	5571	Business	99800.00
0005435283207	5571	Business	99800.00
0005434173621	5571	Economy	33300.00
0005435283205	5571	Economy	33300.00
0005434173627	5571	Economy	33300.00
0005435283219	5571	Economy	33300.00
0005435283123	5571	Economy	33300.00
0005435283147	5571	Economy	36600.00
0005434173626	5571	Economy	36600.00
0005435283150	5571	Economy	33300.00
0005435283103	5571	Economy	33300.00
0005435283196	5571	Economy	33300.00
0005435283188	5571	Economy	33300.00
0005435283206	5571	Economy	33300.00
0005435283153	5571	Economy	33300.00
0005435283124	5571	Economy	33300.00
0005435283179	5571	Economy	33300.00
0005435283165	5571	Economy	33300.00
0005435283180	5571	Economy	33300.00
0005435283104	5571	Economy	33300.00
0005435283152	5571	Economy	33300.00
0005435283178	5571	Economy	33300.00
0005435283194	5571	Economy	33300.00
0005435283137	5571	Economy	33300.00
0005435283197	5571	Economy	33300.00
0005435283187	5571	Economy	33300.00
0005433848074	13861	Business	99800.00
0005433848306	13861	Business	99800.00
0005433848232	13861	Business	99800.00
0005433848265	13861	Business	99800.00
0005433848337	13861	Business	99800.00
0005433848059	13861	Business	99800.00
0005433815507	13861	Economy	33300.00
0005433848035	13861	Economy	33300.00
0005433848298	13861	Economy	33300.00
0005433848177	13861	Economy	33300.00
0005433815506	13861	Economy	33300.00
0005433848122	13861	Economy	33300.00
0005433848138	13861	Economy	33300.00
0005433848028	13861	Economy	33300.00
0005433847857	13861	Economy	33300.00
0005433848075	13861	Economy	33300.00
0005433848078	13861	Economy	33300.00
0005433848123	13861	Economy	33300.00
0005433848178	13861	Economy	33300.00
0005433848322	13861	Economy	33300.00
0005433848073	13861	Economy	33300.00
0005433848293	13861	Economy	33300.00
0005433848227	13861	Economy	33300.00
0005433848285	13861	Economy	33300.00
0005433848250	13861	Economy	33300.00
0005433848376	13861	Economy	33300.00
0005433848016	13861	Economy	33300.00
0005433848324	13861	Economy	33300.00
0005433848284	13861	Economy	33300.00
0005433848029	13861	Economy	33300.00
0005433848017	13861	Economy	33300.00
0005433848275	13861	Economy	33300.00
0005433848214	13861	Economy	33300.00
0005433848360	13861	Economy	33300.00
0005433848329	13861	Economy	33300.00
0005433848109	13861	Economy	33300.00
0005433848233	13861	Economy	33300.00
0005433847861	13861	Economy	33300.00
0005433848179	13861	Economy	33300.00
0005433848226	13861	Economy	33300.00
0005433847981	13861	Economy	33300.00
0005435332608	7797	Economy	16600.00
0005435332612	7797	Economy	15100.00
0005435332601	7797	Economy	15100.00
0005435332631	7797	Economy	15100.00
0005435332613	7797	Economy	15100.00
0005435332599	7797	Economy	15100.00
0005435332600	7797	Economy	15100.00
0005434621107	32997	Economy	15100.00
0005434621127	32997	Economy	15100.00
0005434621168	32997	Economy	15100.00
0005434621167	32997	Economy	15100.00
0005434621084	32997	Economy	15100.00
0005434621102	32997	Economy	15100.00
0005434621091	32997	Economy	15100.00
0005434621085	32997	Economy	15100.00
0005434621130	32997	Economy	15100.00
0005434621043	32997	Economy	15100.00
0005434621083	32997	Economy	15100.00
0005434621115	32997	Economy	15100.00
0005434621149	32997	Economy	15100.00
0005434621092	32997	Economy	15100.00
0005434621131	32997	Economy	15100.00
0005434621090	32997	Economy	15100.00
0005434621101	32997	Economy	15100.00
0005435937549	4315	Economy	12700.00
0005435918768	4315	Economy	12700.00
0005435937542	4315	Economy	12700.00
0005435918782	4315	Economy	12700.00
0005435937536	4315	Economy	12700.00
0005435937513	4315	Economy	12700.00
0005435937482	4315	Economy	12700.00
0005435937535	4315	Economy	12700.00
0005435918783	4315	Economy	12700.00
0005435918769	4315	Economy	12700.00
0005435786189	27317	Business	38000.00
0005434994260	27317	Business	38000.00
0005435787411	27317	Business	38000.00
0005435786287	27317	Business	38000.00
0005435786260	27317	Business	38000.00
0005434994253	27317	Economy	12700.00
0005435786254	27317	Economy	12700.00
0005435786134	27317	Economy	12700.00
0005435786203	27317	Economy	12700.00
0005435786239	27317	Economy	13900.00
0005435786194	27317	Economy	13900.00
0005435786285	27317	Economy	13900.00
0005435786202	27317	Economy	13900.00
0005435787410	27317	Economy	12700.00
0005434994301	27317	Economy	12700.00
0005435786240	27317	Economy	12700.00
0005435786166	27317	Economy	12700.00
0005435786253	27317	Economy	12700.00
0005434994251	27317	Economy	12700.00
0005435786232	27317	Economy	12700.00
0005434994284	27317	Economy	12700.00
0005435786188	27317	Economy	12700.00
0005435786249	27317	Economy	12700.00
0005435786250	27317	Economy	12700.00
0005435786273	27317	Economy	12700.00
0005434994303	27317	Economy	12700.00
0005435786245	27317	Economy	12700.00
0005434994277	27317	Economy	12700.00
0005435786255	27317	Economy	12700.00
0005435786237	27317	Economy	12700.00
0005434994283	27317	Economy	12700.00
0005434994291	27317	Economy	12700.00
0005435787397	27317	Economy	12700.00
0005435786229	27317	Economy	12700.00
0005435786230	27317	Economy	12700.00
0005435786238	27317	Economy	12700.00
0005435786220	27317	Economy	12700.00
0005434994288	27317	Economy	12700.00
0005435786041	27317	Economy	12700.00
0005435786112	27317	Economy	12700.00
0005434994278	27317	Economy	12700.00
0005434994302	27317	Economy	12700.00
0005435786111	27317	Economy	12700.00
0005435786284	27317	Economy	12700.00
0005435786271	27317	Economy	12700.00
0005435786286	27317	Economy	12700.00
0005435786233	27317	Economy	12700.00
0005435786069	27317	Economy	12700.00
0005435840461	4733	Business	40900.00
0005432461442	4733	Business	40900.00
0005434150145	4733	Business	40900.00
0005435840456	4733	Business	40900.00
0005432461443	4733	Business	40900.00
0005434150208	4733	Economy	15000.00
0005432461444	4733	Economy	13600.00
0005434150166	4733	Economy	13600.00
0005434150167	4733	Economy	13600.00
0005432569428	4733	Economy	13600.00
0005434150155	4733	Economy	13600.00
0005435840434	4733	Economy	13600.00
0005435840499	4733	Economy	13600.00
0005435840457	4733	Economy	13600.00
0005435840520	4733	Economy	13600.00
0005435840413	4733	Economy	13600.00
0005435840438	4733	Economy	15000.00
0005434150165	4733	Economy	13600.00
0005434150207	4733	Economy	13600.00
0005435840460	4733	Economy	13600.00
0005435840521	4733	Economy	13600.00
0005435840452	4733	Economy	13600.00
0005435840455	4733	Economy	13600.00
0005435840485	4733	Economy	13600.00
0005435840401	4733	Economy	13600.00
0005435840416	4733	Economy	13600.00
0005434082509	30538	Business	40900.00
0005432569397	30538	Business	40900.00
0005432569138	30538	Business	40900.00
0005432461202	30538	Business	40900.00
0005434082492	30538	Business	40900.00
0005432461366	30538	Business	40900.00
0005432569193	30538	Business	40900.00
0005434082421	30538	Business	40900.00
0005432569257	30538	Business	40900.00
0005434082513	30538	Business	40900.00
0005432461402	30538	Business	40900.00
0005432569373	30538	Economy	15000.00
0005432569185	30538	Economy	15000.00
0005432461294	30538	Economy	15000.00
0005432569353	30538	Economy	15000.00
0005434082574	30538	Economy	13600.00
0005432461101	30538	Economy	13600.00
0005432461284	30538	Economy	13600.00
0005432569251	30538	Economy	13600.00
0005434082527	30538	Economy	13600.00
0005432461295	30538	Economy	13600.00
0005432569142	30538	Economy	13600.00
0005432461398	30538	Economy	13600.00
0005432569312	30538	Economy	13600.00
0005432569256	30538	Economy	13600.00
0005432461167	30538	Economy	13600.00
0005432569100	30538	Economy	13600.00
0005432461273	30538	Economy	13600.00
0005434082408	30538	Economy	13600.00
0005432461331	30538	Economy	13600.00
0005432461274	30538	Economy	13600.00
0005434082599	30538	Economy	13600.00
0005432461382	30538	Economy	13600.00
0005434082464	30538	Economy	13600.00
0005434082459	30538	Economy	13600.00
0005434082479	30538	Economy	13600.00
0005432569324	30538	Economy	13600.00
0005434082512	30538	Economy	13600.00
0005432569365	30538	Economy	13600.00
0005432569415	30538	Economy	13600.00
0005432569192	30538	Economy	13600.00
0005432461397	30538	Economy	13600.00
0005432569311	30538	Economy	13600.00
0005432461293	30538	Economy	13600.00
0005432461190	30538	Economy	13600.00
0005434082493	30538	Economy	13600.00
0005432569309	30538	Economy	13600.00
0005432461138	30538	Economy	13600.00
0005432461201	30538	Economy	13600.00
0005432461219	30538	Economy	13600.00
0005432569139	30538	Economy	13600.00
0005434082534	30538	Economy	13600.00
0005432461266	30538	Economy	13600.00
0005432569101	30538	Economy	13600.00
0005434082553	30538	Economy	13600.00
0005432461334	30538	Economy	13600.00
0005432569364	30538	Economy	13600.00
0005432461305	30538	Economy	13600.00
0005434082420	30538	Economy	13600.00
0005432461333	30538	Economy	13600.00
0005432569204	30538	Economy	13600.00
0005432461168	30538	Economy	13600.00
0005432461198	30538	Economy	13600.00
0005432461234	30538	Economy	13600.00
0005432461100	30538	Economy	13600.00
0005432461102	30538	Economy	13600.00
0005432569136	30538	Economy	13600.00
0005434082589	30538	Economy	13600.00
0005432569099	30538	Economy	13600.00
0005434082508	30538	Economy	13600.00
0005432569293	30538	Economy	13600.00
0005432461367	30538	Economy	13600.00
0005432461220	30538	Economy	13600.00
0005434082494	30538	Economy	13600.00
0005434082595	30538	Economy	13600.00
0005432569366	30538	Economy	13600.00
0005432461401	30538	Economy	13600.00
0005432569317	30538	Economy	13600.00
0005433454930	30538	Economy	13600.00
0005434082463	30538	Economy	13600.00
0005432569318	30538	Economy	13600.00
0005432569279	30538	Economy	13600.00
0005432461400	30538	Economy	13600.00
0005432569351	30538	Economy	13600.00
0005432461203	30538	Economy	13600.00
0005432569098	30538	Economy	13600.00
0005432461399	30538	Economy	13600.00
0005432569378	30538	Economy	13600.00
0005432569186	30538	Economy	13600.00
0005432461200	30538	Economy	13600.00
0005432461292	30538	Economy	13600.00
0005432461272	30538	Economy	13600.00
0005432461108	30538	Economy	13600.00
0005432569067	30538	Economy	13600.00
0005432569350	30538	Economy	13600.00
0005432569367	30538	Economy	13600.00
0005432569278	30538	Economy	13600.00
0005432569316	30538	Economy	13600.00
0005432461325	30538	Economy	13600.00
0005432461169	30538	Economy	13600.00
0005432461123	30538	Economy	13600.00
0005434082625	30538	Economy	13600.00
0005434082554	30538	Economy	13600.00
0005432461332	30538	Economy	13600.00
0005434082510	30538	Economy	13600.00
0005432571417	30538	Economy	13600.00
0005432569301	30538	Economy	13600.00
0005432569280	30538	Economy	13600.00
0005435530080	11080	Business	23600.00
0005435530152	11080	Business	23600.00
0005433346089	11080	Business	23600.00
0005435530098	11080	Business	23600.00
0005435530084	11080	Business	23600.00
0005435530085	11080	Business	23600.00
0005433346088	11080	Business	23600.00
0005435530073	11080	Business	23600.00
0005435380401	11080	Economy	7900.00
0005435508741	11080	Economy	7900.00
0005433346090	11080	Economy	7900.00
0005435530043	11080	Economy	7900.00
0005435530170	11080	Economy	7900.00
0005435530044	11080	Economy	7900.00
0005435530116	11080	Economy	7900.00
0005435530176	11080	Economy	7900.00
0005435530177	11080	Economy	7900.00
0005435530072	11080	Economy	7900.00
0005435530101	11080	Economy	7900.00
0005435508746	11080	Economy	7900.00
0005435530125	11080	Economy	7900.00
0005435508802	11080	Economy	7900.00
0005435530100	11080	Economy	7900.00
0005435508694	11080	Economy	7900.00
0005435508680	11080	Economy	7900.00
0005435530103	11080	Economy	7900.00
0005435508767	11080	Economy	7900.00
0005435508728	11080	Economy	8600.00
0005435508777	11080	Economy	8600.00
0005435530118	11080	Economy	7900.00
0005435380422	11080	Economy	7900.00
0005435530130	11080	Economy	7900.00
0005435530138	11080	Economy	7900.00
0005435380421	11080	Economy	7900.00
0005435380418	11080	Economy	7900.00
0005435530120	11080	Economy	7900.00
0005435380433	11080	Economy	7900.00
0005435530139	11080	Economy	7900.00
0005435508742	11080	Economy	7900.00
0005435530119	11080	Economy	7900.00
0005435530150	11080	Economy	7900.00
0005435508679	11080	Economy	7900.00
0005435530115	11080	Economy	7900.00
0005435530129	11080	Economy	7900.00
0005435508761	11080	Economy	7900.00
0005435508757	11080	Economy	7900.00
0005435530164	11080	Economy	7900.00
0005435530142	11080	Economy	7900.00
0005435530114	11080	Economy	7900.00
0005435530186	11080	Economy	7900.00
0005435530066	11080	Economy	7900.00
0005435508768	11080	Economy	7900.00
0005435530191	11080	Economy	7900.00
0005435508747	11080	Economy	7900.00
0005435097465	17126	Business	23600.00
0005433345764	17126	Business	23600.00
0005433345796	17126	Business	23600.00
0005433345973	17126	Business	23600.00
0005433345975	17126	Business	23600.00
0005433345342	17126	Business	23600.00
0005433345765	17126	Business	23600.00
0005433345889	17126	Business	23600.00
0005433345799	17126	Business	23600.00
0005433345608	17126	Business	23600.00
0005433345743	17126	Economy	7900.00
0005433345356	17126	Economy	7900.00
0005433345665	17126	Economy	7900.00
0005435097427	17126	Economy	7900.00
0005433345607	17126	Economy	7900.00
0005433345452	17126	Economy	7900.00
0005433345490	17126	Economy	7900.00
0005433345610	17126	Economy	7900.00
0005433345791	17126	Economy	7900.00
0005433345707	17126	Economy	7900.00
0005433345890	17126	Economy	7900.00
0005433345711	17126	Economy	7900.00
0005433345609	17126	Economy	7900.00
0005433345648	17126	Economy	7900.00
0005433345867	17126	Economy	7900.00
0005433345804	17126	Economy	7900.00
0005435097487	17126	Economy	7900.00
0005433345674	17126	Economy	7900.00
0005433345710	17126	Economy	7900.00
0005433345848	17126	Economy	7900.00
0005433345322	17126	Economy	7900.00
0005433345998	17126	Economy	7900.00
0005433346000	17126	Economy	7900.00
0005433345154	17126	Economy	7900.00
0005433345744	17126	Economy	7900.00
0005435546003	17126	Economy	7900.00
0005433345435	17126	Economy	7900.00
0005435097466	17126	Economy	7900.00
0005433345354	17126	Economy	7900.00
0005433345616	17126	Economy	8600.00
0005433345801	17126	Economy	8600.00
0005433345805	17126	Economy	8600.00
0005435097446	17126	Economy	8600.00
0005435097464	17126	Economy	7900.00
0005433345540	17126	Economy	7900.00
0005433345453	17126	Economy	7900.00
0005433345545	17126	Economy	7900.00
0005433345992	17126	Economy	7900.00
0005433345658	17126	Economy	7900.00
0005435097428	17126	Economy	7900.00
0005433345940	17126	Economy	7900.00
0005435097456	17126	Economy	7900.00
0005433345976	17126	Economy	7900.00
0005433345630	17126	Economy	7900.00
0005433345631	17126	Economy	7900.00
0005433345685	17126	Economy	7900.00
0005435097476	17126	Economy	7900.00
0005433345813	17126	Economy	7900.00
0005433346024	17126	Economy	7900.00
0005433345712	17126	Economy	7900.00
0005433345626	17126	Economy	7900.00
0005433345546	17126	Economy	7900.00
0005435097457	17126	Economy	7900.00
0005433345666	17126	Economy	7900.00
0005433345627	17126	Economy	7900.00
0005433345792	17126	Economy	7900.00
0005433345809	17126	Economy	7900.00
0005433345888	17126	Economy	7900.00
0005433345678	17126	Economy	7900.00
0005435097453	17126	Economy	7900.00
0005433345721	17126	Economy	7900.00
0005433345668	17126	Economy	7900.00
0005433345533	17126	Economy	7900.00
0005435097439	17126	Economy	7900.00
0005433346025	17126	Economy	7900.00
0005433345464	17126	Economy	7900.00
0005435097454	17126	Economy	7900.00
0005433345353	17126	Economy	7900.00
0005433346026	17126	Economy	7900.00
0005433345675	17126	Economy	7900.00
0005435097488	17126	Economy	7900.00
0005433345999	17126	Economy	7900.00
0005433345914	17126	Economy	7900.00
0005433345203	17126	Economy	7900.00
0005433345559	17126	Economy	7900.00
0005433345355	17126	Economy	7900.00
0005433345958	17126	Economy	7900.00
0005433345941	17126	Economy	7900.00
0005433345991	17126	Economy	7900.00
0005433345501	17126	Economy	7900.00
0005433345718	17126	Economy	7900.00
0005433345465	17126	Economy	7900.00
0005433345787	17126	Economy	7900.00
0005433345840	17126	Economy	7900.00
0005435097436	17126	Economy	7900.00
0005434159029	9091	Business	26600.00
0005432920428	9091	Business	26600.00
0005432920440	9091	Economy	8900.00
0005432920388	9091	Economy	8900.00
0005432920407	9091	Economy	8900.00
0005432920456	9091	Economy	8900.00
0005432920446	9091	Economy	9800.00
0005432920429	9091	Economy	9800.00
0005432920448	9091	Economy	8900.00
0005434159042	9091	Economy	8900.00
0005432920409	9091	Economy	8900.00
0005432920315	9091	Economy	8900.00
0005432920445	9091	Economy	8900.00
0005434159023	9091	Economy	8900.00
0005432920437	9091	Economy	8900.00
0005432920410	9091	Economy	8900.00
0005432920316	9091	Economy	8900.00
0005432920378	9091	Economy	8900.00
0005434159046	9091	Economy	8900.00
0005432920390	9091	Economy	8900.00
0005432920462	9091	Economy	8900.00
0005432920463	9091	Economy	8900.00
0005432920386	9091	Economy	8900.00
0005432920389	9091	Economy	8900.00
0005432920418	9091	Economy	8900.00
0005432920472	9091	Economy	8900.00
0005432920447	9091	Economy	8900.00
0005434159051	9091	Economy	8900.00
0005432920412	9091	Economy	8900.00
0005432920413	9091	Economy	8900.00
0005432920396	9091	Economy	8900.00
0005433477265	20460	Business	26600.00
0005433477266	20460	Business	26600.00
0005433477147	20460	Business	26600.00
0005433477092	20460	Business	26600.00
0005433507680	20460	Business	26600.00
0005433477131	20460	Business	26600.00
0005433477230	20460	Business	26600.00
0005433507674	20460	Economy	8900.00
0005433507682	20460	Economy	8900.00
0005433477229	20460	Economy	8900.00
0005433477274	20460	Economy	8900.00
0005433507697	20460	Economy	8900.00
0005433477126	20460	Economy	8900.00
0005433507683	20460	Economy	9800.00
0005433507660	20460	Economy	9800.00
0005433507727	20460	Economy	9800.00
0005433481385	20460	Economy	9800.00
0005433507614	20460	Economy	8900.00
0005433507652	20460	Economy	8900.00
0005433477170	20460	Economy	8900.00
0005433477143	20460	Economy	8900.00
0005433477228	20460	Economy	8900.00
0005433481373	20460	Economy	8900.00
0005433477224	20460	Economy	8900.00
0005433477210	20460	Economy	8900.00
0005433477068	20460	Economy	8900.00
0005433507634	20460	Economy	8900.00
0005433477217	20460	Economy	8900.00
0005433477279	20460	Economy	8900.00
0005433477146	20460	Economy	8900.00
0005433481386	20460	Economy	8900.00
0005433507684	20460	Economy	8900.00
0005433507635	20460	Economy	8900.00
0005433477145	20460	Economy	8900.00
0005433477071	20460	Economy	8900.00
0005433477244	20460	Economy	8900.00
0005433507675	20460	Economy	8900.00
0005433477223	20460	Economy	8900.00
0005433477148	20460	Economy	8900.00
0005433477108	20460	Economy	8900.00
0005433477222	20460	Economy	8900.00
0005433507673	20460	Economy	8900.00
0005433481374	20460	Economy	8900.00
0005433507670	20460	Economy	8900.00
0005433477218	20460	Economy	8900.00
0005435179019	10238	Economy	5800.00
0005435179020	10238	Economy	5800.00
0005432400207	18349	Economy	5800.00
0005432400208	18349	Economy	5800.00
0005435179428	18349	Economy	5800.00
0005435127448	11023	Business	9500.00
0005435127405	11023	Business	9500.00
0005435127427	11023	Business	9500.00
0005435127361	11023	Business	9500.00
0005435626686	11023	Business	9500.00
0005435127371	11023	Business	9500.00
0005435127424	11023	Business	9500.00
0005435626642	11023	Business	9500.00
0005435127395	11023	Business	9500.00
0005435626724	11023	Business	9500.00
0005435626545	11023	Economy	3200.00
0005435626661	11023	Economy	3200.00
0005435626621	11023	Economy	3200.00
0005435127297	11023	Economy	3200.00
0005435626623	11023	Economy	3200.00
0005435127517	11023	Economy	3200.00
0005435127472	11023	Economy	3200.00
0005435127372	11023	Economy	3200.00
0005435127256	11023	Economy	3500.00
0005435127438	11023	Economy	3500.00
0005435127486	11023	Economy	3500.00
0005435556763	11023	Economy	3500.00
0005435127519	11023	Economy	3500.00
0005435127461	11023	Economy	3200.00
0005435626695	11023	Economy	3200.00
0005435626640	11023	Economy	3200.00
0005435127404	11023	Economy	3200.00
0005435626693	11023	Economy	3200.00
0005435626699	11023	Economy	3200.00
0005435626639	11023	Economy	3200.00
0005435626659	11023	Economy	3200.00
0005435626690	11023	Economy	3200.00
0005435127394	11023	Economy	3200.00
0005435626683	11023	Economy	3200.00
0005435127419	11023	Economy	3200.00
0005435626696	11023	Economy	3200.00
0005435127516	11023	Economy	3200.00
0005435626634	11023	Economy	3200.00
0005435127284	11023	Economy	3200.00
0005435127399	11023	Economy	3200.00
0005435626700	11023	Economy	3200.00
0005435127433	11023	Economy	3200.00
0005435127478	11023	Economy	3200.00
0005435626701	11023	Economy	3200.00
0005435127323	11023	Economy	3200.00
0005435127325	11023	Economy	3200.00
0005435626703	11023	Economy	3200.00
0005435127324	11023	Economy	3200.00
0005435626655	11023	Economy	3200.00
0005435554299	11023	Economy	3200.00
0005435127463	11023	Economy	3200.00
0005435127400	11023	Economy	3200.00
0005435127369	11023	Economy	3200.00
0005435626682	11023	Economy	3200.00
0005435626597	11023	Economy	3200.00
0005435127447	11023	Economy	3200.00
0005435626544	11023	Economy	3200.00
0005435127485	11023	Economy	3200.00
0005435127281	11023	Economy	3200.00
0005435127437	11023	Economy	3200.00
0005435626671	11023	Economy	3200.00
0005435127524	11023	Economy	3200.00
0005435626712	11023	Economy	3200.00
0005435127420	11023	Economy	3200.00
0005435127460	11023	Economy	3200.00
0005435626656	11023	Economy	3200.00
0005435554298	11023	Economy	3200.00
0005435626687	11023	Economy	3200.00
0005435554315	11023	Economy	3200.00
0005435626644	11023	Economy	3200.00
0005435127418	11023	Economy	3200.00
0005435626647	11023	Economy	3200.00
0005435127536	11023	Economy	3200.00
0005435127421	11023	Economy	3200.00
0005435127434	11023	Economy	3200.00
0005434928377	14704	Business	9500.00
0005435127590	14704	Business	9500.00
0005434928376	14704	Business	9500.00
0005434411889	14704	Economy	3200.00
0005435127589	14704	Economy	3200.00
0005434411898	14704	Economy	3200.00
0005435626872	14704	Economy	3200.00
0005434411896	14704	Economy	3200.00
0005434411897	14704	Economy	3200.00
0005434411899	14704	Economy	3200.00
0005435443533	7138	Business	86900.00
0005435443557	7138	Economy	29000.00
0005435443558	7138	Economy	29000.00
0005435216637	7138	Economy	31900.00
0005435443575	7138	Economy	29000.00
0005435219254	7138	Economy	29000.00
0005435443550	7138	Economy	29000.00
0005435219255	7138	Economy	29000.00
0005435443576	7138	Economy	29000.00
0005435178537	7138	Economy	29000.00
0005435216636	7138	Economy	29000.00
0005435443577	7138	Economy	29000.00
0005432394212	27045	Business	86900.00
0005435715947	27045	Business	86900.00
0005435715907	27045	Business	86900.00
0005435715835	27045	Economy	29000.00
0005432394209	27045	Economy	29000.00
0005432398299	27045	Economy	31900.00
0005435715887	27045	Economy	29000.00
0005435715948	27045	Economy	29000.00
0005435715872	27045	Economy	29000.00
0005432398283	27045	Economy	29000.00
0005435715871	27045	Economy	29000.00
0005432394205	27045	Economy	29000.00
0005435715853	27045	Economy	29000.00
0005432398298	27045	Economy	29000.00
0005435715888	27045	Economy	29000.00
0005432398284	27045	Economy	29000.00
0005435715876	27045	Economy	29000.00
0005435715870	27045	Economy	29000.00
0005435715939	27045	Economy	29000.00
0005433060476	2728	Economy	7700.00
0005433060475	2728	Economy	7700.00
0005435844388	25204	Economy	29000.00
0005435844417	25204	Economy	29000.00
0005435844400	25204	Economy	26400.00
0005435844403	25204	Economy	26400.00
0005435844399	25204	Economy	26400.00
0005435844413	25204	Economy	26400.00
0005435844406	25204	Economy	26400.00
0005435844398	25204	Economy	26400.00
0005435844394	25204	Economy	26400.00
0005435844416	25204	Economy	26400.00
0005435844401	25204	Economy	26400.00
0005435844390	25204	Economy	26400.00
0005435844397	25204	Economy	26400.00
0005435844396	25204	Economy	26400.00
0005432632941	25204	Economy	26400.00
0005432632944	25204	Economy	26400.00
0005435844405	25204	Economy	26400.00
0005435844395	25204	Economy	26400.00
0005432632942	25204	Economy	26400.00
0005435844410	25204	Economy	26400.00
0005432632943	25204	Economy	26400.00
0005435844407	25204	Economy	26400.00
0005432632895	28161	Economy	29000.00
0005432632893	28161	Economy	29000.00
0005432632884	28161	Economy	26400.00
0005432632910	28161	Economy	26400.00
0005432632890	28161	Economy	26400.00
0005432632919	28161	Economy	26400.00
0005432632927	28161	Economy	26400.00
0005432632883	28161	Economy	26400.00
0005432632861	28161	Economy	26400.00
0005432632907	28161	Economy	26400.00
0005432632900	28161	Economy	26400.00
0005432632906	28161	Economy	26400.00
0005432632928	28161	Economy	26400.00
0005432632925	28161	Economy	26400.00
0005432632901	28161	Economy	26400.00
0005432632911	28161	Economy	26400.00
0005432632888	28161	Economy	26400.00
0005432632921	28161	Economy	26400.00
0005432632889	28161	Economy	26400.00
0005432632913	28161	Economy	26400.00
0005432632926	28161	Economy	26400.00
0005432632940	28161	Economy	26400.00
0005432632886	28161	Economy	26400.00
0005432632920	28161	Economy	26400.00
0005432632912	28161	Economy	26400.00
0005432632924	28161	Economy	26400.00
0005432632887	28161	Economy	26400.00
0005432632876	28161	Economy	26400.00
0005435518435	11361	Business	20200.00
0005435518426	11361	Business	20200.00
0005435541529	11361	Business	20200.00
0005435518336	11361	Business	20200.00
0005435518448	11361	Economy	6700.00
0005435541607	11361	Economy	6700.00
0005435541584	11361	Economy	6700.00
0005435518394	11361	Economy	6700.00
0005435518334	11361	Economy	6700.00
0005435541484	11361	Economy	6700.00
0005435518356	11361	Economy	6700.00
0005435518389	11361	Economy	6700.00
0005435518390	11361	Economy	6700.00
0005435518355	11361	Economy	6700.00
0005435518351	11361	Economy	6700.00
0005435518383	11361	Economy	6700.00
0005435518335	11361	Economy	6700.00
0005435518395	11361	Economy	6700.00
0005435541528	11361	Economy	6700.00
0005435541600	11361	Economy	6700.00
0005435518354	11361	Economy	6700.00
0005435541521	11361	Economy	6700.00
0005435518452	11361	Economy	6700.00
0005435518408	11361	Economy	6700.00
0005435518407	11361	Economy	6700.00
0005435518416	11361	Economy	6700.00
0005435541612	11361	Economy	6700.00
0005435541621	11361	Economy	6700.00
0005435541520	11361	Economy	6700.00
0005435541599	11361	Economy	6700.00
0005435541488	11361	Economy	6700.00
0005435518449	11361	Economy	6700.00
0005435541598	11361	Economy	6700.00
0005435541606	11361	Economy	6700.00
0005435541592	11361	Economy	6700.00
0005435518425	11361	Economy	6700.00
0005435518301	11361	Economy	6700.00
0005432294561	22227	Business	20200.00
0005435530198	22227	Economy	6700.00
0005435530199	22227	Economy	6700.00
0005435530200	22227	Economy	6700.00
0005433252320	2276	Business	20200.00
0005433252264	2276	Business	20200.00
0005433252352	2276	Business	20200.00
0005433252232	2276	Business	20200.00
0005433252298	2276	Business	20200.00
0005433252354	2276	Business	20200.00
0005433252371	2276	Economy	6700.00
0005433252269	2276	Economy	6700.00
0005433252133	2276	Economy	6700.00
0005433252351	2276	Economy	6700.00
0005433252171	2276	Economy	6700.00
0005433252263	2276	Economy	6700.00
0005434908902	2276	Economy	6700.00
0005433252310	2276	Economy	6700.00
0005433252307	2276	Economy	6700.00
0005433252361	2276	Economy	6700.00
0005433252256	2276	Economy	6700.00
0005433252299	2276	Economy	6700.00
0005433252306	2276	Economy	6700.00
0005433401068	2276	Economy	6700.00
0005433401069	2276	Economy	6700.00
0005433252308	2276	Economy	6700.00
0005433252244	2276	Economy	6700.00
0005433252257	2276	Economy	6700.00
0005433252380	2276	Economy	6700.00
0005433252309	2276	Economy	6700.00
0005433252328	2276	Economy	6700.00
0005434908483	25621	Business	20200.00
0005434908600	25621	Business	20200.00
0005434908622	25621	Business	20200.00
0005434908793	25621	Business	20200.00
0005434908667	25621	Business	20200.00
0005434908706	25621	Economy	6700.00
0005434908852	25621	Economy	6700.00
0005434908755	25621	Economy	6700.00
0005434908503	25621	Economy	7400.00
0005434908780	25621	Economy	7400.00
0005434908530	25621	Economy	7400.00
0005434908668	25621	Economy	7400.00
0005434908692	25621	Economy	6700.00
0005434908570	25621	Economy	6700.00
0005434908541	25621	Economy	6700.00
0005434908802	25621	Economy	6700.00
0005434908693	25621	Economy	6700.00
0005434908613	25621	Economy	6700.00
0005434908310	25621	Economy	6700.00
0005434908614	25621	Economy	6700.00
0005434908704	25621	Economy	6700.00
0005434908504	25621	Economy	6700.00
0005434908678	25621	Economy	6700.00
0005434908827	25621	Economy	6700.00
0005434908309	25621	Economy	6700.00
0005434908853	25621	Economy	6700.00
0005434908718	25621	Economy	6700.00
0005434908756	25621	Economy	6700.00
0005434908672	25621	Economy	6700.00
0005434908529	25621	Economy	6700.00
0005434908620	25621	Economy	6700.00
0005434908705	25621	Economy	6700.00
0005434908599	25621	Economy	6700.00
0005434908509	25621	Economy	6700.00
0005434908515	25621	Economy	6700.00
0005434908750	25621	Economy	6700.00
0005434908513	25621	Economy	6700.00
0005434908623	25621	Economy	6700.00
0005434908512	25621	Economy	6700.00
0005434908700	25621	Economy	6700.00
0005434908719	25621	Economy	6700.00
0005434908514	25621	Economy	6700.00
0005434908828	25621	Economy	6700.00
0005432862510	2507	Economy	12400.00
0005432862509	2507	Economy	12400.00
0005432862507	2507	Economy	12400.00
0005432862508	2507	Economy	12400.00
0005432862504	2507	Economy	12400.00
0005432621396	28086	Economy	12400.00
0005432621416	28086	Economy	12400.00
0005432621415	28086	Economy	12400.00
0005432621395	28086	Economy	12400.00
0005432621399	28086	Economy	12400.00
0005432621419	28086	Economy	12400.00
0005432621335	28086	Economy	12400.00
0005434097510	11745	Economy	11300.00
0005433454930	31418	Economy	8400.00
0005433134258	12020	Economy	7200.00
0005434142722	12020	Economy	6600.00
0005433134262	12020	Economy	6600.00
0005434184721	12020	Economy	6600.00
0005434184722	12020	Economy	6600.00
0005433134259	12020	Economy	6600.00
0005433129403	12020	Economy	6600.00
0005434142721	12020	Economy	6600.00
0005433134247	12020	Economy	6600.00
0005433134248	12020	Economy	6600.00
0005434184723	12020	Economy	6600.00
0005433129397	12020	Economy	6600.00
0005434326288	29845	Economy	6600.00
0005434326291	29845	Economy	6600.00
0005434326033	29845	Economy	6600.00
0005434326039	29845	Economy	6600.00
0005434326292	29845	Economy	6600.00
0005434326284	29845	Economy	6600.00
0005434326035	29845	Economy	6600.00
0005434326034	29845	Economy	6600.00
0005434326290	29845	Economy	6600.00
0005434326296	29845	Economy	6600.00
0005434326019	29845	Economy	6600.00
0005435935125	16469	Economy	19900.00
0005435935124	16469	Economy	18100.00
0005435935123	16469	Economy	18100.00
0005435935114	16469	Economy	18100.00
0005435935130	16469	Economy	18100.00
0005435933565	16469	Economy	18100.00
0005435698053	24737	Economy	19900.00
0005435698052	24737	Economy	19900.00
0005435698083	24737	Economy	18100.00
0005435698077	24737	Economy	18100.00
0005435698060	24737	Economy	18100.00
0005435698117	24737	Economy	18100.00
0005435698135	24737	Economy	18100.00
0005435698152	24737	Economy	18100.00
0005435698056	24737	Economy	18100.00
0005435698122	24737	Economy	18100.00
0005435698025	24737	Economy	18100.00
0005435698075	24737	Economy	18100.00
0005435698106	24737	Economy	18100.00
0005435698084	24737	Economy	18100.00
0005435698048	24737	Economy	18100.00
0005435698149	24737	Economy	18100.00
0005435698030	24737	Economy	18100.00
0005435698013	24737	Economy	18100.00
0005435698151	24737	Economy	18100.00
0005435698093	24737	Economy	18100.00
0005435698029	24737	Economy	18100.00
0005435698024	24737	Economy	18100.00
0005435698094	24737	Economy	18100.00
0005435698146	24737	Economy	18100.00
0005435698116	24737	Economy	18100.00
0005435698095	24737	Economy	18100.00
0005435698068	24737	Economy	18100.00
0005435698061	24737	Economy	18100.00
0005435698027	24737	Economy	18100.00
0005435698028	24737	Economy	18100.00
0005435698148	24737	Economy	18100.00
0005435698023	24737	Economy	18100.00
0005435698055	24737	Economy	18100.00
0005435698085	24737	Economy	18100.00
0005435698136	24737	Economy	18100.00
0005432968903	18780	Economy	4400.00
0005432968902	18780	Economy	4400.00
0005433724920	21630	Economy	4400.00
0005433724928	21630	Economy	4400.00
0005433724929	21630	Economy	4400.00
0005435283566	7341	Economy	8500.00
0005435283565	7341	Economy	7700.00
0005434087642	28558	Business	23100.00
0005434140024	28558	Business	23100.00
0005434139944	28558	Business	23100.00
0005434140218	28558	Business	23100.00
0005434140334	28558	Business	23100.00
0005434140299	28558	Business	23100.00
0005434140166	28558	Business	23100.00
0005434140015	28558	Business	23100.00
0005434140186	28558	Business	23100.00
0005434140322	28558	Business	23100.00
0005434140279	28558	Economy	7700.00
0005434140425	28558	Economy	7700.00
0005434140490	28558	Economy	7700.00
0005434140510	28558	Economy	7700.00
0005434140295	28558	Economy	7700.00
0005434140410	28558	Economy	7700.00
0005434140226	28558	Economy	7700.00
0005434140142	28558	Economy	7700.00
0005434140035	28558	Economy	7700.00
0005434140579	28558	Economy	8500.00
0005434140219	28558	Economy	8500.00
0005434140288	28558	Economy	8500.00
0005434139992	28558	Economy	8500.00
0005434140367	28558	Economy	8500.00
0005434140255	28558	Economy	7700.00
0005434140603	28558	Economy	7700.00
0005434140304	28558	Economy	7700.00
0005434140467	28558	Economy	7700.00
0005434140343	28558	Economy	7700.00
0005434140222	28558	Economy	7700.00
0005434140445	28558	Economy	7700.00
0005434140420	28558	Economy	7700.00
0005434140306	28558	Economy	7700.00
0005434140403	28558	Economy	7700.00
0005434140542	28558	Economy	7700.00
0005434140409	28558	Economy	7700.00
0005434140080	28558	Economy	7700.00
0005434139945	28558	Economy	7700.00
0005434140262	28558	Economy	7700.00
0005434140250	28558	Economy	7700.00
0005434139818	28558	Economy	7700.00
0005434140448	28558	Economy	7700.00
0005434140335	28558	Economy	7700.00
0005434140344	28558	Economy	7700.00
0005434140298	28558	Economy	7700.00
0005434140025	28558	Economy	7700.00
0005434140048	28558	Economy	7700.00
0005434140451	28558	Economy	7700.00
0005434139817	28558	Economy	7700.00
0005434140049	28558	Economy	7700.00
0005434140392	28558	Economy	7700.00
0005434140487	28558	Economy	7700.00
0005434140375	28558	Economy	7700.00
0005434140078	28558	Economy	7700.00
0005434140350	28558	Economy	7700.00
0005434140261	28558	Economy	7700.00
0005434140543	28558	Economy	7700.00
0005434140165	28558	Economy	7700.00
0005434139893	28558	Economy	7700.00
0005434140111	28558	Economy	7700.00
0005434140093	28558	Economy	7700.00
0005434140323	28558	Economy	7700.00
0005434139678	28558	Economy	7700.00
0005434140456	28558	Economy	7700.00
0005434139892	28558	Economy	7700.00
0005434140353	28558	Economy	7700.00
0005434139973	28558	Economy	7700.00
0005434140050	28558	Economy	7700.00
0005434140305	28558	Economy	7700.00
0005434140407	28558	Economy	7700.00
0005434139897	28558	Economy	7700.00
0005434139883	28558	Economy	7700.00
0005434140345	28558	Economy	7700.00
0005434140458	28558	Economy	7700.00
0005434140468	28558	Economy	7700.00
0005434140442	28558	Economy	7700.00
0005434140580	28558	Economy	7700.00
0005434140317	28558	Economy	7700.00
0005434139974	28558	Economy	7700.00
0005434140026	28558	Economy	7700.00
0005434140256	28558	Economy	7700.00
0005434140453	28558	Economy	7700.00
0005434140077	28558	Economy	7700.00
0005434140406	28558	Economy	7700.00
0005434140414	28558	Economy	7700.00
0005434140269	28558	Economy	7700.00
0005434087643	28558	Economy	7700.00
0005434140549	28558	Economy	7700.00
0005434140280	28558	Economy	7700.00
0005435808499	23112	Economy	23900.00
0005435808482	23112	Economy	23900.00
0005435808418	23112	Economy	23900.00
0005435808490	23112	Economy	21700.00
0005435808491	23112	Economy	21700.00
0005435808463	23112	Economy	21700.00
0005435808448	23112	Economy	21700.00
0005435808442	23112	Economy	21700.00
0005435808498	23112	Economy	21700.00
0005435808480	23112	Economy	21700.00
0005435808443	23112	Economy	21700.00
0005435808481	23112	Economy	21700.00
0005435808471	23112	Economy	21700.00
0005435808438	23112	Economy	21700.00
0005435808405	23112	Economy	21700.00
0005435808479	23112	Economy	21700.00
0005434610322	23112	Economy	21700.00
0005435808406	23112	Economy	21700.00
0005435808462	23112	Economy	21700.00
0005434610323	23112	Economy	21700.00
0005435808472	23112	Economy	21700.00
0005435808424	23112	Economy	21700.00
0005434505320	22937	Economy	6900.00
0005433266975	2182	Economy	7000.00
0005433266986	2182	Economy	7000.00
0005433266957	2182	Economy	7000.00
0005433266968	2182	Economy	7000.00
0005433266956	2182	Economy	7000.00
0005433266955	2182	Economy	7000.00
0005435078735	24349	Economy	7700.00
0005435078784	24349	Economy	7700.00
0005435078746	24349	Economy	7000.00
0005435078781	24349	Economy	7000.00
0005435078785	24349	Economy	7000.00
0005435078757	24349	Economy	7000.00
0005435078771	24349	Economy	7000.00
0005435078758	24349	Economy	7000.00
0005435078747	24349	Economy	7000.00
0005435078780	24349	Economy	7000.00
0005434989135	6616	Economy	9800.00
0005434988963	23590	Economy	10800.00
0005435803344	23590	Economy	9800.00
0005434988982	23590	Economy	9800.00
0005434988980	23590	Economy	9800.00
0005435803345	23590	Economy	9800.00
0005434988964	23590	Economy	9800.00
0005434988993	23590	Economy	9800.00
0005434988996	23590	Economy	9800.00
0005434988971	23590	Economy	9800.00
0005434988981	23590	Economy	9800.00
0005435803341	23590	Economy	9800.00
0005435803342	23590	Economy	9800.00
0005435803340	23590	Economy	9800.00
0005435803343	23590	Economy	9800.00
0005434988977	23590	Economy	9800.00
0005434989006	23590	Economy	9800.00
0005435803349	23590	Economy	9800.00
0005434988992	23590	Economy	9800.00
0005433450612	30486	Economy	3300.00
0005432384143	31301	Business	9900.00
0005432384094	31301	Business	9900.00
0005432384089	31301	Business	9900.00
0005433450438	31301	Economy	3300.00
0005432383993	31301	Economy	3300.00
0005432384208	31301	Economy	3300.00
0005433451677	31301	Economy	3600.00
0005433450521	31301	Economy	3600.00
0005433450547	31301	Economy	3600.00
0005432384268	31301	Economy	3600.00
0005432384126	31301	Economy	3600.00
0005432384059	31301	Economy	3300.00
0005432383986	31301	Economy	3300.00
0005433450573	31301	Economy	3300.00
0005432384105	31301	Economy	3300.00
0005432383963	31301	Economy	3300.00
0005432384171	31301	Economy	3300.00
0005432384247	31301	Economy	3300.00
0005432384199	31301	Economy	3300.00
0005432383962	31301	Economy	3300.00
0005432384079	31301	Economy	3300.00
0005432384121	31301	Economy	3300.00
0005432384168	31301	Economy	3300.00
0005432383996	31301	Economy	3300.00
0005432384269	31301	Economy	3300.00
0005433450551	31301	Economy	3300.00
0005432384145	31301	Economy	3300.00
0005433450585	31301	Economy	3300.00
0005432384191	31301	Economy	3300.00
0005432384078	31301	Economy	3300.00
0005432384127	31301	Economy	3300.00
0005432384146	31301	Economy	3300.00
0005432384209	31301	Economy	3300.00
0005432384144	31301	Economy	3300.00
0005433450483	31301	Economy	3300.00
0005432383997	31301	Economy	3300.00
0005432384048	31301	Economy	3300.00
0005432384090	31301	Economy	3300.00
0005433450549	31301	Economy	3300.00
0005433450439	31301	Economy	3300.00
0005432384130	31301	Economy	3300.00
0005433450578	31301	Economy	3300.00
0005433451678	31301	Economy	3300.00
0005432384192	31301	Economy	3300.00
0005432384200	31301	Economy	3300.00
0005433450581	31301	Economy	3300.00
0005433453818	31301	Economy	3300.00
0005432384178	31301	Economy	3300.00
0005433450548	31301	Economy	3300.00
0005433450562	31301	Economy	3300.00
0005433126952	10786	Economy	15600.00
0005433131830	10786	Economy	15600.00
0005435304243	10786	Economy	15600.00
0005435304256	10786	Economy	15600.00
0005433126969	10786	Economy	15600.00
0005435304244	10786	Economy	15600.00
0005435299882	10786	Economy	15600.00
0005435299881	10786	Economy	15600.00
0005433126970	10786	Economy	15600.00
0005433129413	29703	Economy	15600.00
0005433110388	2415	Economy	15700.00
0005433110357	2415	Economy	15700.00
0005433110340	2415	Economy	15700.00
0005433110353	2415	Economy	15700.00
0005433110373	2415	Economy	15700.00
0005433110385	2415	Economy	15700.00
0005433110374	2415	Economy	15700.00
0005434287877	26839	Economy	15700.00
0005434287898	26839	Economy	15700.00
0005434287900	26839	Economy	15700.00
0005434287904	26839	Economy	15700.00
0005434287782	26839	Economy	15700.00
0005434287899	26839	Economy	15700.00
0005434287846	26839	Economy	15700.00
0005434287887	26839	Economy	15700.00
0005434287750	26839	Economy	15700.00
0005434272230	25501	Economy	25000.00
0005435983722	25501	Economy	22800.00
0005435856293	26627	Economy	25000.00
0005435856314	26627	Economy	22800.00
0005435856319	26627	Economy	22800.00
0005435856312	26627	Economy	22800.00
0005435856313	26627	Economy	22800.00
0005435860624	4765	Economy	19400.00
0005435860625	4765	Economy	17600.00
0005435860577	4765	Economy	17600.00
0005433869616	4765	Economy	17600.00
0005433869617	4765	Economy	17600.00
0005435860612	4765	Economy	17600.00
0005435860616	4765	Economy	17600.00
0005433869530	32593	Economy	19400.00
0005433869536	32593	Economy	19400.00
0005433869558	32593	Economy	17600.00
0005433869342	32593	Economy	17600.00
0005433869467	32593	Economy	17600.00
0005433869499	32593	Economy	17600.00
0005433869331	32593	Economy	17600.00
0005433869554	32593	Economy	17600.00
0005433869524	32593	Economy	17600.00
0005433869553	32593	Economy	17600.00
0005433869412	32593	Economy	17600.00
0005433869560	32593	Economy	17600.00
0005433869501	32593	Economy	17600.00
0005433869521	32593	Economy	17600.00
0005433869330	32593	Economy	17600.00
0005433869345	32593	Economy	17600.00
0005433869379	32593	Economy	17600.00
0005433869486	32593	Economy	17600.00
0005433869535	32593	Economy	17600.00
0005433869559	32593	Economy	17600.00
0005433869485	32593	Economy	17600.00
0005433869357	32593	Economy	17600.00
0005433869408	32593	Economy	17600.00
0005433869515	32593	Economy	17600.00
0005433869520	32593	Economy	17600.00
0005433869580	32593	Economy	17600.00
0005433869407	32593	Economy	17600.00
0005433869341	32593	Economy	17600.00
0005435911656	3424	Economy	24800.00
0005435911627	3424	Economy	24800.00
0005435911645	3424	Economy	22600.00
0005435911617	3424	Economy	22600.00
0005435911647	3424	Economy	22600.00
0005435911637	3424	Economy	22600.00
0005435911646	3424	Economy	22600.00
0005435911628	3424	Economy	22600.00
0005435911648	3424	Economy	22600.00
0005435911655	3424	Economy	22600.00
0005434663788	12462	Economy	22600.00
0005434663776	12462	Economy	22600.00
0005434663787	12462	Economy	22600.00
0005434663770	12462	Economy	22600.00
0005434663772	12462	Economy	22600.00
0005434663796	12462	Economy	22600.00
0005433869536	14514	Economy	18500.00
0005433869559	14514	Economy	18500.00
0005433869560	14514	Economy	18500.00
0005433869357	14514	Economy	16800.00
0005433869535	14514	Economy	16800.00
0005433869501	14514	Economy	16800.00
0005433869412	14514	Economy	16800.00
0005433869408	14514	Economy	16800.00
0005433869521	14514	Economy	16800.00
0005433869520	14514	Economy	16800.00
0005433869554	14514	Economy	16800.00
0005433869345	14514	Economy	16800.00
0005433869499	14514	Economy	16800.00
0005433869342	14514	Economy	16800.00
0005433869485	14514	Economy	16800.00
0005433869467	14514	Economy	16800.00
0005433869331	14514	Economy	16800.00
0005433869515	14514	Economy	16800.00
0005433869486	14514	Economy	16800.00
0005433869524	14514	Economy	16800.00
0005433869553	14514	Economy	16800.00
0005433869580	14514	Economy	16800.00
0005433869341	14514	Economy	16800.00
0005433869379	14514	Economy	16800.00
0005433869407	14514	Economy	16800.00
0005433869530	14514	Economy	16800.00
0005433869558	14514	Economy	16800.00
0005433869330	14514	Economy	16800.00
0005435860608	32649	Economy	18500.00
0005435860609	32649	Economy	18500.00
0005435860617	32649	Economy	16800.00
0005435860597	32649	Economy	16800.00
0005435860598	32649	Economy	16800.00
0005435860594	32649	Economy	16800.00
0005435860610	32649	Economy	16800.00
0005433869615	32649	Economy	16800.00
0005432800217	12140	Economy	4900.00
0005432800260	12140	Economy	4400.00
0005432800187	12140	Economy	4400.00
0005432800164	12140	Economy	4400.00
0005432800264	12140	Economy	4400.00
0005432800103	12140	Economy	4400.00
0005432800221	12140	Economy	4400.00
0005432800148	12140	Economy	4400.00
0005432800149	12140	Economy	4400.00
0005432800195	12140	Economy	4400.00
0005432800277	12140	Economy	4400.00
0005432800239	12140	Economy	4400.00
0005432800238	12140	Economy	4400.00
0005432800259	12140	Economy	4400.00
0005432800202	12140	Economy	4400.00
0005432800222	12140	Economy	4400.00
0005432800188	12140	Economy	4400.00
0005432800210	12140	Economy	4400.00
0005432800104	12140	Economy	4400.00
0005435311464	7075	Business	49100.00
0005435311493	7075	Business	49100.00
0005435311483	7075	Economy	16400.00
0005435311439	7075	Economy	16400.00
0005435311494	7075	Economy	16400.00
0005435311487	7075	Economy	16400.00
0005435311495	7075	Economy	16400.00
0005435311455	7075	Economy	16400.00
0005435311484	7075	Economy	16400.00
0005435311470	7075	Economy	16400.00
0005435311381	7075	Economy	16400.00
0005435311457	7075	Economy	16400.00
0005435311485	7075	Economy	16400.00
0005435311527	7075	Economy	16400.00
0005435311382	7075	Economy	16400.00
0005435293590	7075	Economy	16400.00
0005435311419	7075	Economy	16400.00
0005435311456	7075	Economy	16400.00
0005434300233	7075	Economy	16400.00
0005435293577	7075	Economy	16400.00
0005435293578	7075	Economy	16400.00
0005435311440	7075	Economy	16400.00
0005435311488	7075	Economy	16400.00
0005435311454	7075	Economy	16400.00
0005435293591	7075	Economy	16400.00
0005435311486	7075	Economy	16400.00
0005434300177	26929	Business	49100.00
0005434300193	26929	Business	49100.00
0005434409375	26929	Business	49100.00
0005434409326	26929	Business	49100.00
0005434409402	26929	Business	49100.00
0005434409449	26929	Business	49100.00
0005434409444	26929	Economy	16400.00
0005434409350	26929	Economy	16400.00
0005434409445	26929	Economy	16400.00
0005434409410	26929	Economy	16400.00
0005434300166	26929	Economy	16400.00
0005434409126	26929	Economy	16400.00
0005434300212	26929	Economy	16400.00
0005434408952	26929	Economy	16400.00
0005434409397	26929	Economy	16400.00
0005434409436	26929	Economy	16400.00
0005434300203	26929	Economy	16400.00
0005434409451	26929	Economy	16400.00
0005434409512	26929	Economy	16400.00
0005434409299	26929	Economy	16400.00
0005434409217	26929	Economy	16400.00
0005434409300	26929	Economy	16400.00
0005434409263	26929	Economy	16400.00
0005434409332	26929	Economy	16400.00
0005434300178	26929	Economy	18000.00
0005434409407	26929	Economy	18000.00
0005434409473	26929	Economy	18000.00
0005434409333	26929	Economy	16400.00
0005434409322	26929	Economy	16400.00
0005434409476	26929	Economy	16400.00
0005434408953	26929	Economy	16400.00
0005434300181	26929	Economy	16400.00
0005434409469	26929	Economy	16400.00
0005434409418	26929	Economy	16400.00
0005434409321	26929	Economy	16400.00
0005434409472	26929	Economy	16400.00
0005434300182	26929	Economy	16400.00
0005434409335	26929	Economy	16400.00
0005434409525	26929	Economy	16400.00
0005434300216	26929	Economy	16400.00
0005434409442	26929	Economy	16400.00
0005434409533	26929	Economy	16400.00
0005434409334	26929	Economy	16400.00
0005434409314	26929	Economy	16400.00
0005434300194	26929	Economy	16400.00
0005434409352	26929	Economy	16400.00
0005434409276	26929	Economy	16400.00
0005434409396	26929	Economy	16400.00
0005434300167	26929	Economy	16400.00
0005434409437	26929	Economy	16400.00
0005434409530	26929	Economy	16400.00
0005434409228	26929	Economy	16400.00
0005434300175	26929	Economy	16400.00
0005434409386	26929	Economy	16400.00
0005434409487	26929	Economy	16400.00
0005434409419	26929	Economy	16400.00
0005434409226	26929	Economy	16400.00
0005435312906	6467	Economy	16500.00
0005435218131	6467	Economy	16500.00
0005435218130	6467	Economy	15000.00
0005435220513	6467	Economy	15000.00
0005432605517	6467	Economy	15000.00
0005435218138	6467	Economy	15000.00
0005435312907	6467	Economy	15000.00
0005432605516	6467	Economy	15000.00
0005435312910	6467	Economy	15000.00
0005432605518	6467	Economy	15000.00
0005435220519	6467	Economy	15000.00
0005435218142	6467	Economy	15000.00
0005432605427	21378	Economy	16500.00
0005432605344	21378	Economy	16500.00
0005432605311	21378	Economy	16500.00
0005432605358	21378	Economy	15000.00
0005432605478	21378	Economy	15000.00
0005432605426	21378	Economy	15000.00
0005432605388	21378	Economy	15000.00
0005432605196	21378	Economy	15000.00
0005432605441	21378	Economy	15000.00
0005432605378	21378	Economy	15000.00
0005432605477	21378	Economy	15000.00
0005432605357	21378	Economy	15000.00
0005432605442	21378	Economy	15000.00
0005432605376	21378	Economy	15000.00
0005432605443	21378	Economy	15000.00
0005432605379	21378	Economy	15000.00
0005432605342	21378	Economy	15000.00
0005432605315	21378	Economy	15000.00
0005432605363	21378	Economy	15000.00
0005432605316	21378	Economy	15000.00
0005432605424	21378	Economy	15000.00
0005432605377	21378	Economy	15000.00
0005432605361	21378	Economy	15000.00
0005432605401	21378	Economy	15000.00
0005432605391	21378	Economy	15000.00
0005432605195	21378	Economy	15000.00
0005432605390	21378	Economy	15000.00
0005432605370	21378	Economy	15000.00
0005432605372	21378	Economy	15000.00
0005432605287	21378	Economy	15000.00
0005432605425	21378	Economy	15000.00
0005432605318	21378	Economy	15000.00
0005432605466	21378	Economy	15000.00
0005432605285	21378	Economy	15000.00
0005432605317	21378	Economy	15000.00
0005432605286	21378	Economy	15000.00
0005432605373	21378	Economy	15000.00
0005432605431	21378	Economy	15000.00
0005432605385	21378	Economy	15000.00
0005432605332	21378	Economy	15000.00
0005432605400	21378	Economy	15000.00
0005432605362	21378	Economy	15000.00
0005432605364	21378	Economy	15000.00
0005434908600	14982	Business	18900.00
0005434908570	14982	Business	18900.00
0005434908672	14982	Business	18900.00
0005434908706	14982	Business	18900.00
0005434908529	14982	Business	18900.00
0005434908828	14982	Business	18900.00
0005434908700	14982	Business	18900.00
0005434908622	14982	Economy	6300.00
0005434908692	14982	Economy	6300.00
0005434908530	14982	Economy	6300.00
0005434908483	14982	Economy	6900.00
0005434908623	14982	Economy	6300.00
0005434908513	14982	Economy	6300.00
0005434908309	14982	Economy	6300.00
0005434908541	14982	Economy	6300.00
0005434908512	14982	Economy	6300.00
0005434908599	14982	Economy	6300.00
0005434908827	14982	Economy	6300.00
0005434908719	14982	Economy	6300.00
0005434908853	14982	Economy	6300.00
0005434908793	14982	Economy	6300.00
0005434908613	14982	Economy	6300.00
0005434908504	14982	Economy	6300.00
0005434908503	14982	Economy	6300.00
0005434908852	14982	Economy	6300.00
0005434908668	14982	Economy	6300.00
0005434908756	14982	Economy	6300.00
0005434908667	14982	Economy	6300.00
0005434908514	14982	Economy	6300.00
0005434908614	14982	Economy	6300.00
0005434908509	14982	Economy	6300.00
0005434908705	14982	Economy	6300.00
0005434908310	14982	Economy	6300.00
0005434908678	14982	Economy	6300.00
0005434908704	14982	Economy	6300.00
0005434908620	14982	Economy	6300.00
0005434908693	14982	Economy	6300.00
0005434908780	14982	Economy	6300.00
0005434908755	14982	Economy	6300.00
0005434908515	14982	Economy	6300.00
0005434908802	14982	Economy	6300.00
0005434908718	14982	Economy	6300.00
0005434908750	14982	Economy	6300.00
0005433252267	25847	Business	18900.00
0005433252348	25847	Business	18900.00
0005433252266	25847	Business	18900.00
0005434908901	25847	Business	18900.00
0005433252300	25847	Economy	6300.00
0005433252265	25847	Economy	6300.00
0005433252358	25847	Economy	6900.00
0005433252329	25847	Economy	6900.00
0005433252234	25847	Economy	6300.00
0005433252326	25847	Economy	6300.00
0005433252318	25847	Economy	6300.00
0005433252245	25847	Economy	6300.00
0005433252337	25847	Economy	6300.00
0005433252302	25847	Economy	6300.00
0005433252359	25847	Economy	6300.00
0005433252316	25847	Economy	6300.00
0005433252311	25847	Economy	6300.00
0005433252301	25847	Economy	6300.00
0005433252317	25847	Economy	6300.00
0005433252345	25847	Economy	6300.00
0005433252284	25847	Economy	6300.00
0005433252181	25847	Economy	6300.00
0005433252212	25847	Economy	6300.00
0005434908900	25847	Economy	6300.00
0005433252340	25847	Economy	6300.00
0005433252346	25847	Economy	6300.00
0005433252349	25847	Economy	6300.00
0005433252270	25847	Economy	6300.00
0005434173653	9185	Economy	18100.00
0005434173660	9185	Economy	18100.00
0005433815553	22749	Economy	18100.00
0005433815552	22749	Economy	18100.00
0005433815542	22749	Economy	18100.00
0005435842348	22474	Economy	14900.00
0005435842345	22474	Economy	14900.00
0005432609852	22474	Economy	14900.00
0005432609841	31716	Economy	16400.00
0005432609832	31716	Economy	16400.00
0005432609834	31716	Economy	16400.00
0005432613972	31716	Economy	14900.00
0005432613962	31716	Economy	14900.00
0005432609822	31716	Economy	14900.00
0005432609842	31716	Economy	14900.00
0005432613953	31716	Economy	14900.00
0005432609821	31716	Economy	14900.00
0005432613958	31716	Economy	14900.00
0005432613963	31716	Economy	14900.00
0005432609844	31716	Economy	14900.00
0005432613973	31716	Economy	14900.00
0005432609830	31716	Economy	14900.00
0005432609829	31716	Economy	14900.00
0005432609824	31716	Economy	14900.00
0005432609823	31716	Economy	14900.00
0005432613952	31716	Economy	14900.00
0005432613970	31716	Economy	14900.00
0005432613967	31716	Economy	14900.00
0005432609825	31716	Economy	14900.00
0005432613971	31716	Economy	14900.00
0005432613954	31716	Economy	14900.00
0005432609840	31716	Economy	14900.00
0005432609833	31716	Economy	14900.00
0005433810702	14209	Business	52300.00
0005433810696	14209	Business	52300.00
0005433810699	14209	Business	52300.00
0005433810710	14209	Business	52300.00
0005433810727	14209	Business	52300.00
0005433810684	14209	Business	52300.00
0005433815552	14209	Economy	17400.00
0005433810692	14209	Economy	17400.00
0005433810689	14209	Economy	17400.00
0005433810768	14209	Economy	17400.00
0005433810700	14209	Economy	17400.00
0005433810715	14209	Economy	17400.00
0005433815553	14209	Economy	17400.00
0005433810688	14209	Economy	17400.00
0005433810769	14209	Economy	17400.00
0005433810706	14209	Economy	17400.00
0005433810673	14209	Economy	17400.00
0005433810709	14209	Economy	17400.00
0005433810703	14209	Economy	17400.00
0005433810697	14209	Economy	17400.00
0005433810698	14209	Economy	17400.00
0005433815542	14209	Economy	17400.00
0005433810690	14209	Economy	17400.00
0005433810716	14209	Economy	17400.00
0005433810687	14209	Economy	17400.00
0005433810817	22850	Business	52300.00
0005433009776	22850	Business	52300.00
0005433009724	22850	Business	52300.00
0005433009762	22850	Business	52300.00
0005433009775	22850	Business	52300.00
0005433810818	22850	Business	52300.00
0005433009892	22850	Business	52300.00
0005433810814	22850	Business	52300.00
0005433009691	22850	Business	52300.00
0005433009763	22850	Economy	17400.00
0005433009493	22850	Economy	17400.00
0005433009925	22850	Economy	17400.00
0005433009810	22850	Economy	17400.00
0005433009887	22850	Economy	17400.00
0005433009548	22850	Economy	19200.00
0005433009856	22850	Economy	19200.00
0005433009870	22850	Economy	17400.00
0005433009843	22850	Economy	17400.00
0005433009725	22850	Economy	17400.00
0005433009874	22850	Economy	17400.00
0005433009886	22850	Economy	17400.00
0005433009641	22850	Economy	17400.00
0005433009869	22850	Economy	17400.00
0005433009795	22850	Economy	17400.00
0005433009679	22850	Economy	17400.00
0005433810816	22850	Economy	17400.00
0005433009642	22850	Economy	17400.00
0005433009842	22850	Economy	17400.00
0005433810813	22850	Economy	17400.00
0005433009752	22850	Economy	17400.00
0005433009494	22850	Economy	17400.00
0005433009929	22850	Economy	17400.00
0005433009894	22850	Economy	17400.00
0005433810811	22850	Economy	17400.00
0005433009753	22850	Economy	17400.00
0005433009817	22850	Economy	17400.00
0005433810815	22850	Economy	17400.00
0005433009804	22850	Economy	17400.00
0005433009885	22850	Economy	17400.00
0005433009805	22850	Economy	17400.00
0005433009891	22850	Economy	17400.00
0005433009888	22850	Economy	17400.00
0005433009848	22850	Economy	17400.00
0005433810812	22850	Economy	17400.00
0005433009803	22850	Economy	17400.00
0005433009859	22850	Economy	17400.00
0005433009768	22850	Economy	17400.00
0005433009751	22850	Economy	17400.00
0005433009844	22850	Economy	17400.00
0005433009930	22850	Economy	17400.00
0005434173645	22850	Economy	17400.00
0005433009893	22850	Economy	17400.00
0005434926622	14949	Business	22900.00
0005434926749	14949	Business	22900.00
0005434926728	14949	Business	22900.00
0005434926700	14949	Business	22900.00
0005434926555	14949	Business	22900.00
0005434926621	14949	Business	22900.00
0005434926682	14949	Business	22900.00
0005434926681	14949	Business	22900.00
0005434926678	14949	Economy	7600.00
0005434926523	14949	Economy	7600.00
0005434926752	14949	Economy	7600.00
0005434926656	14949	Economy	7600.00
0005434926669	14949	Economy	8400.00
0005434926500	14949	Economy	8400.00
0005434926667	14949	Economy	8400.00
0005434926776	14949	Economy	7600.00
0005434926690	14949	Economy	7600.00
0005434926729	14949	Economy	7600.00
0005434926672	14949	Economy	7600.00
0005434926673	14949	Economy	7600.00
0005434926573	14949	Economy	7600.00
0005434926807	14949	Economy	7600.00
0005434926646	14949	Economy	7600.00
0005434926572	14949	Economy	7600.00
0005434926761	14949	Economy	7600.00
0005434926438	14949	Economy	7600.00
0005434926655	14949	Economy	7600.00
0005434926647	14949	Economy	7600.00
0005434926771	14949	Economy	7600.00
0005434926686	14949	Economy	7600.00
0005434926482	14949	Economy	7600.00
0005434926719	14949	Economy	7600.00
0005434926659	14949	Economy	7600.00
0005434926762	14949	Economy	7600.00
0005434926502	14949	Economy	7600.00
0005434926668	14949	Economy	7600.00
0005434926569	14949	Economy	7600.00
0005434926636	14949	Economy	7600.00
0005434926772	14949	Economy	7600.00
0005434926701	14949	Economy	7600.00
0005434926734	14949	Economy	7600.00
0005434926763	14949	Economy	7600.00
0005434926692	14949	Economy	7600.00
0005434926662	14949	Economy	7600.00
0005434926657	14949	Economy	7600.00
0005434926677	14949	Economy	7600.00
0005434926499	14949	Economy	7600.00
0005434926866	20528	Business	22900.00
0005434926864	20528	Economy	7600.00
0005434926865	20528	Economy	7600.00
0005435999713	15829	Economy	8900.00
0005435999824	15829	Economy	8100.00
0005435999701	15829	Economy	8100.00
0005435999699	15829	Economy	8100.00
0005435999688	15829	Economy	8100.00
0005435999702	15829	Economy	8100.00
0005435999843	15829	Economy	8100.00
0005435999868	15829	Economy	8100.00
0005435999783	15829	Economy	8100.00
0005435999700	15829	Economy	8100.00
0005435999741	15829	Economy	8100.00
0005435999825	15829	Economy	8100.00
0005435999853	15829	Economy	8100.00
0005435999747	15829	Economy	8100.00
0005435999721	15829	Economy	8100.00
0005435999839	15829	Economy	8100.00
0005435999687	15829	Economy	8100.00
0005435999770	15829	Economy	8100.00
0005435999787	15829	Economy	8100.00
0005435999659	15829	Economy	8100.00
0005435999854	15829	Economy	8100.00
0005435999844	15829	Economy	8100.00
0005435999734	15829	Economy	8100.00
0005435999864	19669	Economy	8900.00
0005435488389	19669	Economy	8900.00
0005435488438	19669	Economy	8100.00
0005435488427	19669	Economy	8100.00
0005435488404	19669	Economy	8100.00
0005435488437	19669	Economy	8100.00
0005435488405	19669	Economy	8100.00
0005435488345	19669	Economy	8100.00
0005435488349	19669	Economy	8100.00
0005435488426	19669	Economy	8100.00
0005435488417	19669	Economy	8100.00
0005435488396	19669	Economy	8100.00
0005435488395	19669	Economy	8100.00
0005435473263	6000	Business	199300.00
0005435473261	6000	Business	199300.00
0005435617241	6000	Business	199300.00
0005435473255	6000	Economy	66400.00
0005432537113	6000	Economy	66400.00
0005435473271	6000	Economy	73100.00
0005435473257	6000	Economy	66400.00
0005432537109	6000	Economy	66400.00
0005435473226	6000	Economy	66400.00
0005435473270	6000	Economy	66400.00
0005435473256	6000	Economy	66400.00
0005435473203	6000	Economy	66400.00
0005435473279	6000	Economy	66400.00
0005432667506	18063	Business	199300.00
0005435840162	18063	Business	199300.00
0005435840264	18063	Business	199300.00
0005435840145	18063	Business	199300.00
0005435840196	18063	Economy	66400.00
0005435840233	18063	Economy	66400.00
0005435840114	18063	Economy	73100.00
0005435840205	18063	Economy	66400.00
0005435840262	18063	Economy	66400.00
0005435840227	18063	Economy	66400.00
0005435840161	18063	Economy	66400.00
0005435840206	18063	Economy	66400.00
0005432660871	18063	Economy	66400.00
0005435840177	18063	Economy	66400.00
0005435840192	18063	Economy	66400.00
0005432660872	18063	Economy	66400.00
0005432667510	18063	Economy	66400.00
0005432660873	18063	Economy	66400.00
0005435840238	18063	Economy	66400.00
0005435840116	18063	Economy	66400.00
0005435840188	18063	Economy	66400.00
0005435840223	18063	Economy	66400.00
0005432667507	18063	Economy	66400.00
0005432660877	18063	Economy	66400.00
0005435840117	18063	Economy	66400.00
0005435840237	18063	Economy	66400.00
0005433286100	23054	Business	15700.00
0005433286122	23054	Economy	5200.00
0005433286137	23054	Economy	5200.00
0005433286110	23054	Economy	5200.00
0005433286091	23054	Economy	5200.00
0005433286131	23054	Economy	5200.00
0005433286151	23054	Economy	5200.00
0005435104386	23054	Economy	5200.00
0005433286177	23054	Economy	5200.00
0005433286089	23054	Economy	5200.00
0005435104385	23054	Economy	5200.00
0005433286090	23054	Economy	5200.00
0005433286144	23054	Economy	5200.00
0005433286152	23054	Economy	5200.00
0005433286030	23054	Economy	5200.00
0005433286196	23054	Economy	5200.00
0005433286029	23054	Economy	5200.00
0005433286138	23054	Economy	5200.00
0005433286067	23054	Economy	5200.00
0005435104387	23054	Economy	5200.00
0005435104201	32058	Business	15700.00
0005435104311	32058	Business	15700.00
0005435104232	32058	Economy	5200.00
0005435104147	32058	Economy	5200.00
0005435104225	32058	Economy	5200.00
0005435104273	32058	Economy	5200.00
0005435104312	32058	Economy	5200.00
0005435104235	32058	Economy	5200.00
0005435104291	32058	Economy	5200.00
0005435104355	32058	Economy	5200.00
0005435104226	32058	Economy	5200.00
0005435104258	32058	Economy	5700.00
0005435104155	32058	Economy	5200.00
0005435104185	32058	Economy	5200.00
0005435104252	32058	Economy	5200.00
0005435104188	32058	Economy	5200.00
0005435104354	32058	Economy	5200.00
0005435104259	32058	Economy	5200.00
0005435104190	32058	Economy	5200.00
0005435104187	32058	Economy	5200.00
0005435104236	32058	Economy	5200.00
0005435104211	32058	Economy	5200.00
0005435380444	32058	Economy	5200.00
0005435104274	32058	Economy	5200.00
0005435104200	32058	Economy	5200.00
0005435104322	32058	Economy	5200.00
0005435104239	32058	Economy	5200.00
0005435104209	32058	Economy	5200.00
0005435104189	32058	Economy	5200.00
0005435104210	32058	Economy	5200.00
0005435104242	32058	Economy	5200.00
0005435104241	32058	Economy	5200.00
0005435104240	32058	Economy	5200.00
0005435104227	32058	Economy	5200.00
0005435104253	32058	Economy	5200.00
0005435104182	32058	Economy	5200.00
0005435104148	32058	Economy	5200.00
0005435104251	32058	Economy	5200.00
0005433475822	23864	Economy	12300.00
0005433475820	23864	Economy	12300.00
0005433475821	23864	Economy	12300.00
0005433475823	23864	Economy	12300.00
0005433475825	23864	Economy	12300.00
0005433475816	23864	Economy	12300.00
0005433475809	23864	Economy	12300.00
0005433475824	23864	Economy	12300.00
0005434069513	30630	Business	42100.00
0005432531254	30630	Business	42100.00
0005432535967	30630	Business	42100.00
0005432531543	30630	Business	42100.00
0005434069470	30630	Business	42100.00
0005434069500	30630	Business	42100.00
0005434069465	30630	Business	42100.00
0005432531021	30630	Business	42100.00
0005434069469	30630	Business	42100.00
0005432531023	30630	Business	42100.00
0005432531561	30630	Business	42100.00
0005432531212	30630	Comfort	23900.00
0005432531362	30630	Comfort	23900.00
0005432531343	30630	Comfort	23900.00
0005432531683	30630	Comfort	23900.00
0005432531600	30630	Comfort	23900.00
0005432531440	30630	Comfort	23900.00
0005432531512	30630	Comfort	23900.00
0005432535957	30630	Comfort	23900.00
0005434069562	30630	Comfort	23900.00
0005432531333	30630	Comfort	23900.00
0005434069347	30630	Comfort	23900.00
0005432531495	30630	Comfort	23900.00
0005432535972	30630	Comfort	23900.00
0005432531482	30630	Comfort	23900.00
0005434069599	30630	Economy	14000.00
0005432531670	30630	Economy	14000.00
0005432531326	30630	Comfort	23900.00
0005434069181	30630	Economy	14000.00
0005432531347	30630	Economy	14000.00
0005434069269	30630	Economy	14000.00
0005432429013	30630	Economy	14000.00
0005432531664	30630	Economy	14000.00
0005434069265	30630	Economy	14000.00
0005432531663	30630	Economy	14000.00
0005432531001	30630	Economy	14000.00
0005434069379	30630	Economy	14000.00
0005434069364	30630	Economy	14000.00
0005432531386	30630	Economy	14000.00
0005432535969	30630	Economy	14000.00
0005432531653	30630	Economy	14000.00
0005432531542	30630	Economy	14000.00
0005432531211	30630	Economy	14000.00
0005432531455	30630	Economy	14000.00
0005435215537	30630	Economy	14000.00
0005432531435	30630	Economy	14000.00
0005434069503	30630	Economy	14000.00
0005432531710	30630	Economy	14000.00
0005434069460	30630	Economy	14000.00
0005432531392	30630	Economy	14000.00
0005432531272	30630	Economy	14000.00
0005432531348	30630	Economy	14000.00
0005434069509	30630	Economy	14000.00
0005432531681	30630	Economy	15400.00
0005432531700	30630	Economy	14000.00
0005432531548	30630	Economy	14000.00
0005434069400	30630	Economy	14000.00
0005432531639	30630	Economy	14000.00
0005432531342	30630	Economy	14000.00
0005434069243	30630	Economy	14000.00
0005434069182	30630	Economy	14000.00
0005432531624	30630	Economy	14000.00
0005432531742	30630	Economy	14000.00
0005432429012	30630	Economy	14000.00
0005434069346	30630	Economy	14000.00
0005432531361	30630	Economy	14000.00
0005434069399	30630	Economy	14000.00
0005434069402	30630	Economy	14000.00
0005432531587	30630	Economy	14000.00
0005432531244	30630	Economy	14000.00
0005432531523	30630	Economy	14000.00
0005434069287	30630	Economy	14000.00
0005432531511	30630	Economy	14000.00
0005432531259	30630	Economy	14000.00
0005432531739	30630	Economy	14000.00
0005432531707	30630	Economy	14000.00
0005434069273	30630	Economy	14000.00
0005432531391	30630	Economy	14000.00
0005432531411	30630	Economy	14000.00
0005434069498	30630	Economy	14000.00
0005434069461	30630	Economy	14000.00
0005432531713	30630	Economy	14000.00
0005432531638	30630	Economy	14000.00
0005434069107	30630	Economy	14000.00
0005432531210	30630	Economy	14000.00
0005434069108	30630	Economy	14000.00
0005432535959	30630	Economy	14000.00
0005432531436	30630	Economy	14000.00
0005434069330	30630	Economy	14000.00
0005434069459	30630	Economy	14000.00
0005432531692	30630	Economy	14000.00
0005434069312	30630	Economy	14000.00
0005432531520	30630	Economy	14000.00
0005432531360	30630	Economy	14000.00
0005432531522	30630	Economy	14000.00
0005434069494	30630	Economy	14000.00
0005432531341	30630	Economy	15400.00
0005432531555	30630	Economy	15400.00
0005434069502	30630	Economy	15400.00
0005434069501	30630	Economy	14000.00
0005432531648	30630	Economy	14000.00
0005434069288	30630	Economy	14000.00
0005434069566	30630	Economy	14000.00
0005432531383	30630	Economy	14000.00
0005434069419	30630	Economy	14000.00
0005434069306	30630	Economy	14000.00
0005432531706	30630	Economy	14000.00
0005432531785	30630	Economy	14000.00
0005432535971	30630	Economy	14000.00
0005432531708	30630	Economy	14000.00
0005432531241	30630	Economy	14000.00
0005434069210	30630	Economy	14000.00
0005434069565	30630	Economy	14000.00
0005432531575	30630	Economy	14000.00
0005432531588	30630	Economy	14000.00
0005434069403	30630	Economy	14000.00
0005432531255	30630	Economy	14000.00
0005432531393	30630	Economy	14000.00
0005432531496	30630	Economy	14000.00
0005434069629	30630	Economy	14000.00
0005435215536	30630	Economy	14000.00
0005434069473	30630	Economy	14000.00
0005432531394	30630	Economy	14000.00
0005434069250	30630	Economy	14000.00
0005432531285	30630	Economy	14000.00
0005432531777	30630	Economy	14000.00
0005434069474	30630	Economy	14000.00
0005432531297	30630	Economy	14000.00
0005432531743	30630	Economy	14000.00
0005434069410	30630	Economy	14000.00
0005434069230	30630	Economy	14000.00
0005432531024	30630	Economy	14000.00
0005434069435	30630	Economy	14000.00
0005432531625	30630	Economy	14000.00
0005434069505	30630	Economy	14000.00
0005432531586	30630	Economy	14000.00
0005434069434	30630	Economy	14000.00
0005434069266	30630	Economy	14000.00
0005432531770	30630	Economy	14000.00
0005435654046	24847	Business	9800.00
0005435654350	24847	Business	9800.00
0005435654047	24847	Business	9800.00
0005435654366	24847	Business	9800.00
0005435654285	24847	Economy	3300.00
0005435654470	24847	Economy	3300.00
0005435654468	24847	Economy	3600.00
0005435654208	24847	Economy	3600.00
0005435654301	24847	Economy	3300.00
0005435654288	24847	Economy	3300.00
0005435654469	24847	Economy	3300.00
0005435654313	24847	Economy	3300.00
0005435654465	24847	Economy	3300.00
0005435654178	24847	Economy	3300.00
0005435654045	24847	Economy	3300.00
0005435654351	24847	Economy	3300.00
0005435654117	24847	Economy	3300.00
0005435654302	24847	Economy	3300.00
0005435654314	24847	Economy	3300.00
0005435654471	24847	Economy	3300.00
0005435654279	24847	Economy	3300.00
0005435654218	24847	Economy	3300.00
0005435654308	24847	Economy	3300.00
0005435654207	24847	Economy	3300.00
0005435654332	24847	Economy	3300.00
0005435654217	24847	Economy	3300.00
0005435654367	24847	Economy	3300.00
0005435654287	24847	Economy	3300.00
0005435654476	24847	Economy	3300.00
0005435654267	24847	Economy	3300.00
0005435654222	24847	Economy	3300.00
0005435654415	24847	Economy	3300.00
0005435949834	23311	Economy	20600.00
0005435949844	23311	Economy	18700.00
0005435949859	23311	Economy	18700.00
0005435949851	23311	Economy	18700.00
0005435949857	23311	Economy	18700.00
0005435949846	23311	Economy	18700.00
0005435949850	23311	Economy	18700.00
0005435949856	23311	Economy	18700.00
0005435949845	23311	Economy	18700.00
0005435949843	23311	Economy	18700.00
0005435949858	23311	Economy	18700.00
0005435949869	23311	Economy	18700.00
0005434980599	23526	Economy	10500.00
0005434980595	23526	Economy	10500.00
0005434980625	23526	Economy	9500.00
0005434980606	23526	Economy	9500.00
0005434980507	23526	Economy	9500.00
0005434980528	23526	Economy	9500.00
0005434980497	23526	Economy	9500.00
0005434980519	23526	Economy	9500.00
0005434980586	23526	Economy	9500.00
0005435801775	23526	Economy	9500.00
0005434980508	23526	Economy	9500.00
0005434980520	23526	Economy	9500.00
0005434980590	23526	Economy	9500.00
0005435801776	23526	Economy	9500.00
0005434980569	23526	Economy	9500.00
0005434980541	23526	Economy	9500.00
0005434980521	23526	Economy	9500.00
0005434980552	23526	Economy	9500.00
0005434980646	23526	Economy	9500.00
0005434980585	23526	Economy	9500.00
0005434980600	23526	Economy	9500.00
0005434980589	23526	Economy	9500.00
0005434980645	23526	Economy	9500.00
0005434980553	23526	Economy	9500.00
0005434980570	23526	Economy	9500.00
0005434980540	23526	Economy	9500.00
0005434980470	23526	Economy	9500.00
0005434980627	23526	Economy	9500.00
0005434980471	23526	Economy	9500.00
0005434980588	23526	Economy	9500.00
0005435801780	23526	Economy	9500.00
0005434980607	23526	Economy	9500.00
0005434980649	23526	Economy	9500.00
0005433256489	2566	Economy	5300.00
0005434302899	19767	Economy	8700.00
0005434302900	19767	Economy	8700.00
0005434302901	19767	Economy	8700.00
0005434302894	19767	Economy	8700.00
0005434140427	11911	Business	9700.00
0005434140484	11911	Business	9700.00
0005434140022	11911	Business	9700.00
0005434140556	11911	Business	9700.00
0005434140606	11911	Business	9700.00
0005434140333	11911	Business	9700.00
0005434140546	11911	Economy	3200.00
0005434140150	11911	Economy	3200.00
0005434140424	11911	Economy	3200.00
0005434140514	11911	Economy	3200.00
0005434140325	11911	Economy	3200.00
0005434140067	11911	Economy	3200.00
0005434140373	11911	Economy	3500.00
0005434140282	11911	Economy	3500.00
0005434140503	11911	Economy	3500.00
0005434140511	11911	Economy	3200.00
0005434140513	11911	Economy	3200.00
0005434140400	11911	Economy	3200.00
0005434140530	11911	Economy	3200.00
0005434140540	11911	Economy	3200.00
0005434140567	11911	Economy	3200.00
0005434140040	11911	Economy	3200.00
0005434140240	11911	Economy	3200.00
0005434140587	11911	Economy	3200.00
0005434140581	11911	Economy	3200.00
0005434140151	11911	Economy	3200.00
0005434140399	11911	Economy	3200.00
0005434140532	11911	Economy	3200.00
0005434140599	11911	Economy	3200.00
0005434140512	11911	Economy	3200.00
0005434140254	11911	Economy	3200.00
0005434140402	11911	Economy	3200.00
0005434140247	11911	Economy	3200.00
0005434140421	11911	Economy	3200.00
0005434139909	11911	Economy	3200.00
0005434140531	11911	Economy	3200.00
0005434140506	11911	Economy	3200.00
0005434140289	11911	Economy	3200.00
0005434140583	11911	Economy	3200.00
0005434140239	11911	Economy	3200.00
0005434140582	11911	Economy	3200.00
0005434140283	11911	Economy	3200.00
0005434140324	11911	Economy	3200.00
0005434140527	11911	Economy	3200.00
0005434140235	11911	Economy	3200.00
0005434140068	11911	Economy	3200.00
0005434140585	11911	Economy	3200.00
0005434140470	11911	Economy	3200.00
0005434140227	11911	Economy	3200.00
0005434140584	11911	Economy	3200.00
0005434140193	11911	Economy	3200.00
0005434140372	11911	Economy	3200.00
0005434139910	11911	Economy	3200.00
0005434140175	11911	Economy	3200.00
0005434140426	11911	Economy	3200.00
0005435312868	6576	Economy	20900.00
0005435312871	6576	Economy	20900.00
0005435312875	6576	Economy	20900.00
0005434516136	19096	Economy	26000.00
0005434513655	19096	Economy	26000.00
0005434516123	19096	Economy	23600.00
0005434516122	19096	Economy	23600.00
0005434516137	19096	Economy	23600.00
0005434513646	19096	Economy	23600.00
0005434513654	19096	Economy	23600.00
0005434513639	19096	Economy	23600.00
0005434516135	19096	Economy	23600.00
0005434513656	19096	Economy	23600.00
0005434513657	19096	Economy	23600.00
0005434516133	19096	Economy	23600.00
0005434513640	19096	Economy	23600.00
0005434516134	19096	Economy	23600.00
0005434190464	19096	Economy	23600.00
0005434516125	19096	Economy	23600.00
0005435259878	6782	Economy	9900.00
0005435259866	6782	Economy	9900.00
0005435259879	6782	Economy	9900.00
0005435259872	6782	Economy	9900.00
0005433534552	25025	Economy	10900.00
0005433539081	25025	Economy	9900.00
0005433539114	25025	Economy	9900.00
0005433539116	25025	Economy	9900.00
0005433539101	25025	Economy	9900.00
0005433539079	25025	Economy	9900.00
0005433539115	25025	Economy	9900.00
0005433539080	25025	Economy	9900.00
0005433534562	25025	Economy	9900.00
0005433539089	25025	Economy	9900.00
0005433512194	16162	Economy	14600.00
0005433512195	16162	Economy	14600.00
0005433512169	16162	Economy	14600.00
0005435916239	3675	Economy	7200.00
0005435916230	3675	Economy	7200.00
0005435933566	3675	Economy	7200.00
0005435916240	3675	Economy	7200.00
0005435916235	3675	Economy	7200.00
0005435698061	16276	Economy	7900.00
0005435698116	16276	Economy	7900.00
0005435698027	16276	Economy	7900.00
0005435698013	16276	Economy	7200.00
0005435698028	16276	Economy	7200.00
0005435698095	16276	Economy	7200.00
0005435698085	16276	Economy	7200.00
0005435698122	16276	Economy	7200.00
0005435698025	16276	Economy	7200.00
0005435698023	16276	Economy	7200.00
0005435698060	16276	Economy	7200.00
0005435698084	16276	Economy	7200.00
0005435698135	16276	Economy	7200.00
0005435698029	16276	Economy	7200.00
0005435698117	16276	Economy	7200.00
0005435698075	16276	Economy	7200.00
0005435698136	16276	Economy	7200.00
0005435698146	16276	Economy	7200.00
0005435698083	16276	Economy	7200.00
0005435698052	16276	Economy	7200.00
0005435698151	16276	Economy	7200.00
0005435698077	16276	Economy	7200.00
0005435698149	16276	Economy	7200.00
0005435698068	16276	Economy	7200.00
0005435698056	16276	Economy	7200.00
0005435698094	16276	Economy	7200.00
0005435698148	16276	Economy	7200.00
0005435698055	16276	Economy	7200.00
0005435698024	16276	Economy	7200.00
0005435698048	16276	Economy	7200.00
0005435698152	16276	Economy	7200.00
0005435698053	16276	Economy	7200.00
0005435698106	16276	Economy	7200.00
0005434950657	16276	Economy	7200.00
0005434950651	16276	Economy	7200.00
0005435698093	16276	Economy	7200.00
0005435698030	16276	Economy	7200.00
0005434950656	16276	Economy	7200.00
0005435841488	3966	Economy	21300.00
0005435841489	3966	Economy	19300.00
0005435853657	3966	Economy	19300.00
0005435904915	3966	Economy	19300.00
0005435904721	3966	Economy	19300.00
0005432609833	22072	Economy	21300.00
0005434606921	22072	Economy	19300.00
0005432609832	22072	Economy	19300.00
0005432609821	22072	Economy	19300.00
0005434606931	22072	Economy	19300.00
0005432609844	22072	Economy	19300.00
0005433519585	22072	Economy	19300.00
0005432609823	22072	Economy	19300.00
0005434606917	22072	Economy	19300.00
0005432609842	22072	Economy	19300.00
0005432609841	22072	Economy	19300.00
0005432609825	22072	Economy	19300.00
0005434606935	22072	Economy	19300.00
0005432613963	22072	Economy	19300.00
0005432613954	22072	Economy	19300.00
0005432613953	22072	Economy	19300.00
0005432613962	22072	Economy	19300.00
0005432609824	22072	Economy	19300.00
0005434606929	22072	Economy	19300.00
0005432609840	22072	Economy	19300.00
0005432613958	22072	Economy	19300.00
0005432613971	22072	Economy	19300.00
0005432613970	22072	Economy	19300.00
0005432613973	22072	Economy	19300.00
0005434606930	22072	Economy	19300.00
0005432609830	22072	Economy	19300.00
0005432609822	22072	Economy	19300.00
0005432609834	22072	Economy	19300.00
0005433519582	22072	Economy	19300.00
0005432613967	22072	Economy	19300.00
0005434606920	22072	Economy	19300.00
0005432613972	22072	Economy	19300.00
0005432609829	22072	Economy	19300.00
0005433519579	22072	Economy	19300.00
0005432613952	22072	Economy	19300.00
0005433349151	729	Economy	3700.00
0005433349162	729	Economy	3700.00
0005433349159	729	Economy	3700.00
0005433349160	729	Economy	3700.00
0005433349155	729	Economy	3700.00
0005435628825	15983	Economy	3700.00
0005435628823	15983	Economy	3700.00
0005435628824	15983	Economy	3700.00
0005435628826	15983	Economy	3700.00
0005433159357	17180	Economy	7100.00
0005433158191	17180	Economy	7100.00
0005434445314	17605	Economy	7100.00
0005434445309	17605	Economy	7100.00
0005434445319	17605	Economy	7100.00
0005434445320	17605	Economy	7100.00
0005434445322	17605	Economy	7100.00
0005434445311	17605	Economy	7100.00
0005435383300	7864	Economy	5400.00
0005435383299	7864	Economy	5400.00
0005435383295	7864	Economy	5400.00
0005435383306	7864	Economy	5400.00
0005435133186	33097	Economy	5400.00
0005435133148	33097	Economy	5400.00
0005435133147	33097	Economy	5400.00
0005435938956	4396	Business	133200.00
0005435938957	4396	Business	133200.00
0005435938955	4396	Economy	44400.00
0005435811232	4396	Economy	44400.00
0005435938953	4396	Economy	44400.00
0005435811231	4396	Economy	44400.00
0005435938952	4396	Economy	44400.00
0005435938954	4396	Economy	44400.00
0005435811186	29434	Business	133200.00
0005435811180	29434	Business	133200.00
0005435811195	29434	Economy	44400.00
0005435811217	29434	Economy	44400.00
0005435811210	29434	Economy	44400.00
0005435811218	29434	Economy	44400.00
0005435811179	29434	Economy	44400.00
0005435811188	29434	Economy	44400.00
0005435811191	29434	Economy	44400.00
0005435811209	29434	Economy	44400.00
0005435390422	7512	Economy	12500.00
0005435160611	29587	Economy	13800.00
0005435160619	29587	Economy	12500.00
0005435160622	29587	Economy	12500.00
0005435160572	29587	Economy	12500.00
0005435160620	29587	Economy	12500.00
0005435160592	29587	Economy	12500.00
0005435160573	29587	Economy	12500.00
0005432394216	18453	Economy	4900.00
0005432394215	18453	Economy	4900.00
0005432394213	18453	Economy	4900.00
0005432394214	18453	Economy	4900.00
0005435178537	27162	Economy	4900.00
0005432866193	2244	Business	87300.00
0005432866205	2244	Business	87300.00
0005432866170	2244	Business	87300.00
0005432866171	2244	Economy	32000.00
0005432866197	2244	Economy	29100.00
0005432866163	2244	Economy	29100.00
0005432866212	2244	Economy	29100.00
0005432866208	2244	Economy	29100.00
0005432866196	2244	Economy	29100.00
0005432639507	2244	Economy	29100.00
0005432866206	2244	Economy	29100.00
0005432866156	2244	Economy	29100.00
0005432866213	2244	Economy	29100.00
0005432866215	2244	Economy	29100.00
0005432866214	2244	Economy	29100.00
0005435104185	22671	Business	48400.00
0005435104147	22671	Business	48400.00
0005435104188	22671	Business	48400.00
0005435104355	22671	Business	48400.00
0005435104273	22671	Economy	16100.00
0005435104274	22671	Economy	16100.00
0005435104354	22671	Economy	16100.00
0005435104211	22671	Economy	17800.00
0005435104225	22671	Economy	17800.00
0005435104200	22671	Economy	17800.00
0005435104235	22671	Economy	16100.00
0005435380444	22671	Economy	16100.00
0005435104155	22671	Economy	16100.00
0005435104322	22671	Economy	16100.00
0005435104311	22671	Economy	16100.00
0005435104201	22671	Economy	16100.00
0005435104232	22671	Economy	16100.00
0005435104226	22671	Economy	16100.00
0005435104251	22671	Economy	16100.00
0005435104190	22671	Economy	16100.00
0005435104252	22671	Economy	16100.00
0005435104291	22671	Economy	16100.00
0005435104258	22671	Economy	16100.00
0005435104239	22671	Economy	16100.00
0005435104210	22671	Economy	16100.00
0005435104242	22671	Economy	16100.00
0005435104236	22671	Economy	16100.00
0005435104240	22671	Economy	16100.00
0005435104148	22671	Economy	16100.00
0005435104209	22671	Economy	16100.00
0005435104259	22671	Economy	16100.00
0005435104187	22671	Economy	16100.00
0005435104312	22671	Economy	16100.00
0005435104189	22671	Economy	16100.00
0005435104227	22671	Economy	16100.00
0005435104253	22671	Economy	16100.00
0005435104182	22671	Economy	16100.00
0005435104241	22671	Economy	16100.00
0005433368893	1645	Business	50000.00
0005433368967	1645	Business	50000.00
0005433368894	1645	Economy	16700.00
0005433368909	1645	Economy	16700.00
0005433368968	1645	Economy	16700.00
0005433368848	1645	Economy	16700.00
0005433368945	1645	Economy	16700.00
0005433368963	1645	Economy	16700.00
0005433368966	1645	Economy	16700.00
0005433368870	1645	Economy	16700.00
0005433368831	1645	Economy	16700.00
0005433368830	1645	Economy	16700.00
0005433368829	1645	Economy	16700.00
0005435654498	1645	Economy	16700.00
0005435654332	21670	Business	50000.00
0005435654302	21670	Business	50000.00
0005435654117	21670	Business	50000.00
0005435654222	21670	Business	50000.00
0005435654285	21670	Economy	16700.00
0005435654218	21670	Economy	16700.00
0005435654465	21670	Economy	16700.00
0005435654046	21670	Economy	16700.00
0005435654208	21670	Economy	16700.00
0005435654217	21670	Economy	18300.00
0005435654314	21670	Economy	18300.00
0005435654366	21670	Economy	16700.00
0005435654350	21670	Economy	16700.00
0005435654045	21670	Economy	16700.00
0005435654308	21670	Economy	16700.00
0005435654279	21670	Economy	16700.00
0005435654415	21670	Economy	16700.00
0005435654367	21670	Economy	16700.00
0005435654178	21670	Economy	16700.00
0005435654287	21670	Economy	16700.00
0005435654288	21670	Economy	16700.00
0005435654047	21670	Economy	16700.00
0005435654351	21670	Economy	16700.00
0005435654469	21670	Economy	16700.00
0005435654476	21670	Economy	16700.00
0005435654471	21670	Economy	16700.00
0005435654470	21670	Economy	16700.00
0005435654468	21670	Economy	16700.00
0005435654313	21670	Economy	16700.00
0005435654267	21670	Economy	16700.00
0005435654301	21670	Economy	16700.00
0005435654207	21670	Economy	16700.00
0005435627131	23792	Economy	11200.00
0005435627132	23792	Economy	11200.00
0005435627129	23792	Economy	11200.00
0005434466595	23243	Economy	20900.00
0005434466602	23243	Economy	20900.00
0005434466570	23243	Economy	20900.00
0005434466596	23243	Economy	20900.00
0005434466585	23243	Economy	20900.00
0005434466598	23243	Economy	20900.00
0005434466597	23243	Economy	20900.00
0005434466601	23243	Economy	20900.00
0005433987239	25636	Business	21500.00
0005433987086	25636	Business	21500.00
0005433987093	25636	Business	21500.00
0005433987358	25636	Business	21500.00
0005433987085	25636	Economy	7200.00
0005433987204	25636	Economy	7200.00
0005433987324	25636	Economy	7200.00
0005433987274	25636	Economy	7900.00
0005433987124	25636	Economy	7200.00
0005433987166	25636	Economy	7200.00
0005433987165	25636	Economy	7200.00
0005433987240	25636	Economy	7200.00
0005433987332	25636	Economy	7200.00
0005433987337	25636	Economy	7200.00
0005433987352	25636	Economy	7200.00
0005433987047	25636	Economy	7200.00
0005433987172	25636	Economy	7200.00
0005433987248	25636	Economy	7200.00
0005433987258	25636	Economy	7200.00
0005433987267	25636	Economy	7200.00
0005433987280	25636	Economy	7200.00
0005433987306	25636	Economy	7200.00
0005433987305	25636	Economy	7200.00
0005433987308	25636	Economy	7200.00
0005433987249	25636	Economy	7200.00
0005433987220	25636	Economy	7200.00
0005433987259	25636	Economy	7200.00
0005433987196	25636	Economy	7200.00
0005433987307	25636	Economy	7200.00
0005433987263	25636	Economy	7200.00
0005433987175	25636	Economy	7200.00
0005433987033	25636	Economy	7200.00
0005433987106	25636	Economy	7200.00
0005433987251	25636	Economy	7200.00
0005433987125	25636	Economy	7200.00
0005433987351	25636	Economy	7200.00
0005433987121	25636	Economy	7200.00
0005433987089	25636	Economy	7200.00
0005433987371	25636	Economy	7200.00
0005433987213	25636	Economy	7200.00
0005433987323	25636	Economy	7200.00
0005433987273	25636	Economy	7200.00
0005433987138	25636	Economy	7200.00
0005433987219	25636	Economy	7200.00
0005433987180	25636	Economy	7200.00
0005433987243	25636	Economy	7200.00
0005433463951	19924	Business	201300.00
0005433461643	19924	Business	201300.00
0005433463942	19924	Business	201300.00
0005433463948	19924	Business	201300.00
0005433461639	19924	Business	201300.00
0005433461641	19924	Business	201300.00
0005433463944	19924	Business	201300.00
0005433463949	19924	Economy	73800.00
0005433461627	19924	Economy	67100.00
0005433461651	19924	Economy	67100.00
0005433461642	19924	Economy	67100.00
0005433461636	19924	Economy	67100.00
0005433463953	19924	Economy	67100.00
0005433463954	19924	Economy	67100.00
0005433463956	19924	Economy	67100.00
0005433463955	19924	Economy	67100.00
0005433461637	19924	Economy	67100.00
0005433461635	19924	Economy	67100.00
0005433461638	19924	Economy	67100.00
0005433463943	19924	Economy	67100.00
0005433461633	19924	Economy	67100.00
0005433463946	19924	Economy	67100.00
0005433463947	19924	Economy	67100.00
0005433463952	19924	Economy	67100.00
0005433463933	19924	Economy	67100.00
0005433461630	19924	Economy	67100.00
0005433461628	19924	Economy	67100.00
0005433461634	19924	Economy	67100.00
0005433463945	19924	Economy	67100.00
0005433463950	19924	Economy	67100.00
0005433461629	19924	Economy	67100.00
0005433463939	19924	Economy	67100.00
0005433461640	19924	Economy	67100.00
0005435719598	21268	Economy	9400.00
0005435719599	21268	Economy	9400.00
0005433168471	1623	Economy	15500.00
0005433168470	1623	Economy	15500.00
0005434509381	1623	Economy	15500.00
0005433168486	1623	Economy	15500.00
0005433168474	1623	Economy	15500.00
0005433168487	1623	Economy	15500.00
0005433168484	1623	Economy	15500.00
0005433168475	1623	Economy	15500.00
0005433168483	1623	Economy	15500.00
0005433168477	1623	Economy	15500.00
0005433168492	1623	Economy	15500.00
0005433168478	1623	Economy	15500.00
0005433168485	1623	Economy	15500.00
0005432665332	17871	Business	18000.00
0005432664196	17871	Business	18000.00
0005432661980	17871	Business	18000.00
0005432655797	17871	Business	18000.00
0005432658649	17871	Business	18000.00
0005432655846	17871	Economy	6000.00
0005432655854	17871	Economy	6000.00
0005432655847	17871	Economy	6600.00
0005432665331	17871	Economy	6000.00
0005432663097	17871	Economy	6000.00
0005432659763	17871	Economy	6000.00
0005432655884	17871	Economy	6000.00
0005432655841	17871	Economy	6000.00
0005432664197	17871	Economy	6000.00
0005432655844	17871	Economy	6000.00
0005432661979	17871	Economy	6000.00
0005432659762	17871	Economy	6000.00
0005432655845	17871	Economy	6000.00
0005432660870	17871	Economy	6000.00
0005432655873	17871	Economy	6000.00
0005432655883	17871	Economy	6000.00
0005432663092	17871	Economy	6000.00
0005432657532	17871	Economy	6000.00
0005432655874	17871	Economy	6000.00
0005432655850	17871	Economy	6000.00
0005432657531	17871	Economy	6000.00
0005432869688	26332	Business	18000.00
0005432663102	26332	Business	18000.00
0005432663104	26332	Business	18000.00
0005432661991	26332	Business	18000.00
0005432663111	26332	Economy	6000.00
0005432664204	26332	Economy	6000.00
0005432663107	26332	Economy	6000.00
0005432869685	26332	Economy	6000.00
0005432658654	26332	Economy	6000.00
0005432663101	26332	Economy	6600.00
0005432663103	26332	Economy	6600.00
0005432658655	26332	Economy	6600.00
0005432664209	26332	Economy	6600.00
0005432869679	26332	Economy	6000.00
0005432664201	26332	Economy	6000.00
0005432664203	26332	Economy	6000.00
0005432663110	26332	Economy	6000.00
0005432661994	26332	Economy	6000.00
0005432869687	26332	Economy	6000.00
0005432664208	26332	Economy	6000.00
0005432869678	26332	Economy	6000.00
0005432869696	26332	Economy	6000.00
0005432664206	26332	Economy	6000.00
0005432663108	26332	Economy	6000.00
0005432664205	26332	Economy	6000.00
0005432664210	26332	Economy	6000.00
0005432869691	26332	Economy	6000.00
0005432661989	26332	Economy	6000.00
0005432661995	26332	Economy	6000.00
0005432869677	26332	Economy	6000.00
0005432661992	26332	Economy	6000.00
0005432869704	26332	Economy	6000.00
0005432664202	26332	Economy	6000.00
0005432661993	26332	Economy	6000.00
0005432869686	26332	Economy	6000.00
0005432869709	26332	Economy	6000.00
0005432663106	26332	Economy	6000.00
0005432661990	26332	Economy	6000.00
0005432664207	26332	Economy	6000.00
0005432664211	26332	Economy	6000.00
0005432663105	26332	Economy	6000.00
0005432666450	26332	Economy	6000.00
0005432663109	26332	Economy	6000.00
0005432639407	25069	Business	87300.00
0005432639471	25069	Business	87300.00
0005432639457	25069	Business	87300.00
0005432639470	25069	Business	87300.00
0005432639456	25069	Business	87300.00
0005432639377	25069	Economy	29100.00
0005432639472	25069	Economy	32000.00
0005432639409	25069	Economy	29100.00
0005432639390	25069	Economy	29100.00
0005432639469	25069	Economy	29100.00
0005432639426	25069	Economy	29100.00
0005432639464	25069	Economy	29100.00
0005432639494	25069	Economy	29100.00
0005432639408	25069	Economy	29100.00
0005432639474	25069	Economy	29100.00
0005432639391	25069	Economy	29100.00
0005432639501	25069	Economy	29100.00
0005432639453	25069	Economy	29100.00
0005432866220	25069	Economy	29100.00
0005432639476	25069	Economy	29100.00
0005432639465	25069	Economy	29100.00
0005432639378	25069	Economy	29100.00
0005432639460	25069	Economy	29100.00
0005432639500	25069	Economy	29100.00
0005432905287	3101	Economy	5900.00
0005432905286	3101	Economy	5400.00
0005432848874	3101	Economy	5400.00
0005432905277	3101	Economy	5400.00
0005432329977	31155	Business	16100.00
0005432329947	31155	Business	16100.00
0005432329884	31155	Business	16100.00
0005433439046	31155	Business	16100.00
0005432329825	31155	Business	16100.00
0005433439100	31155	Economy	5400.00
0005433439099	31155	Economy	5400.00
0005432329882	31155	Economy	5400.00
0005432329976	31155	Economy	5400.00
0005432329933	31155	Economy	5900.00
0005432329822	31155	Economy	5900.00
0005432329864	31155	Economy	5900.00
0005432329733	31155	Economy	5400.00
0005432329887	31155	Economy	5400.00
0005432329816	31155	Economy	5400.00
0005432329867	31155	Economy	5400.00
0005432330051	31155	Economy	5400.00
0005432329774	31155	Economy	5400.00
0005432329934	31155	Economy	5400.00
0005432329948	31155	Economy	5400.00
0005432329866	31155	Economy	5400.00
0005432329857	31155	Economy	5400.00
0005432330035	31155	Economy	5400.00
0005432329883	31155	Economy	5400.00
0005433439058	31155	Economy	5400.00
0005432329732	31155	Economy	5400.00
0005433439057	31155	Economy	5400.00
0005432329888	31155	Economy	5400.00
0005432330007	31155	Economy	5400.00
0005432329985	31155	Economy	5400.00
0005432329935	31155	Economy	5400.00
0005432329984	31155	Economy	5400.00
0005435488446	6197	Business	124600.00
0005435488447	6197	Business	124600.00
0005435488399	6197	Economy	41500.00
0005435488472	6197	Economy	41500.00
0005435297245	6197	Economy	41500.00
0005435488387	6197	Economy	41500.00
0005435488421	6197	Economy	41500.00
0005435488442	6197	Economy	41500.00
0005435488339	6197	Economy	45700.00
0005435488363	6197	Economy	41500.00
0005435488415	6197	Economy	41500.00
0005435488455	6197	Economy	41500.00
0005435488443	6197	Economy	41500.00
0005435488362	6197	Economy	41500.00
0005435488388	6197	Economy	41500.00
0005435488338	6197	Economy	41500.00
0005435488377	6197	Economy	41500.00
0005435488369	6197	Economy	41500.00
0005435488450	6197	Economy	41500.00
0005435488376	6197	Economy	41500.00
0005435488370	6197	Economy	41500.00
0005435999787	19570	Business	124600.00
0005435999687	19570	Business	124600.00
0005435999699	19570	Economy	41500.00
0005435999700	19570	Economy	41500.00
0005435999701	19570	Economy	41500.00
0005435999824	19570	Economy	41500.00
0005435999702	19570	Economy	41500.00
0005435999825	19570	Economy	41500.00
0005435999734	19570	Economy	41500.00
0005435999843	19570	Economy	45700.00
0005434310075	19570	Economy	45700.00
0005435999741	19570	Economy	45700.00
0005435999688	19570	Economy	41500.00
0005435999783	19570	Economy	41500.00
0005435999854	19570	Economy	41500.00
0005435999659	19570	Economy	41500.00
0005435999713	19570	Economy	41500.00
0005435999721	19570	Economy	41500.00
0005435999770	19570	Economy	41500.00
0005435999839	19570	Economy	41500.00
0005435999853	19570	Economy	41500.00
0005435999844	19570	Economy	41500.00
0005435999747	19570	Economy	41500.00
0005433157015	13218	Economy	13600.00
0005433158203	13218	Economy	13600.00
0005433157014	13218	Economy	12300.00
0005434444193	13218	Economy	12300.00
0005434444189	13218	Economy	12300.00
0005433158205	13218	Economy	12300.00
0005433157012	13218	Economy	12300.00
0005433158204	13218	Economy	12300.00
0005433158199	13218	Economy	12300.00
0005434444190	13218	Economy	12300.00
0005433158201	13218	Economy	12300.00
0005433157013	13218	Economy	12300.00
0005433158202	13218	Economy	12300.00
0005434446587	17543	Economy	12300.00
0005434446584	17543	Economy	12300.00
0005434446585	17543	Economy	12300.00
0005434446583	17543	Economy	12300.00
0005433186341	1568	Business	86000.00
0005433186353	1568	Business	86000.00
0005433186339	1568	Economy	31500.00
0005433186360	1568	Economy	31500.00
0005433186359	1568	Economy	28700.00
0005433186344	1568	Economy	28700.00
0005433186345	1568	Economy	28700.00
0005433186368	1568	Economy	28700.00
0005433186340	1568	Economy	28700.00
0005433186361	1568	Economy	28700.00
0005433186362	1568	Economy	28700.00
0005433186358	1568	Economy	28700.00
0005434566302	20848	Business	86000.00
0005435545941	20848	Business	86000.00
0005435529798	20848	Business	86000.00
0005435529811	20848	Business	86000.00
0005435529882	20848	Business	86000.00
0005435529799	20848	Business	86000.00
0005435502922	20848	Business	86000.00
0005435545925	20848	Business	86000.00
0005435545947	20848	Economy	28700.00
0005435502928	20848	Economy	28700.00
0005435529754	20848	Economy	28700.00
0005435502889	20848	Economy	28700.00
0005435529813	20848	Economy	28700.00
0005435529814	20848	Economy	31500.00
0005435545954	20848	Economy	31500.00
0005434566297	20848	Economy	31500.00
0005435545921	20848	Economy	28700.00
0005435502896	20848	Economy	28700.00
0005434566286	20848	Economy	28700.00
0005435502948	20848	Economy	28700.00
0005435502800	20848	Economy	28700.00
0005435529837	20848	Economy	28700.00
0005435502879	20848	Economy	28700.00
0005435545934	20848	Economy	28700.00
0005435529883	20848	Economy	28700.00
0005435529865	20848	Economy	28700.00
0005434566289	20848	Economy	28700.00
0005435502947	20848	Economy	28700.00
0005435502921	20848	Economy	28700.00
0005435529821	20848	Economy	28700.00
0005435529803	20848	Economy	28700.00
0005435502902	20848	Economy	28700.00
0005434566285	20848	Economy	28700.00
0005435529755	20848	Economy	28700.00
0005435545920	20848	Economy	28700.00
0005435529823	20848	Economy	28700.00
0005435545963	20848	Economy	28700.00
0005435529763	20848	Economy	28700.00
0005435529822	20848	Economy	28700.00
0005435529857	20848	Economy	28700.00
0005435502895	20848	Economy	28700.00
0005435545919	20848	Economy	28700.00
0005435529826	20848	Economy	28700.00
0005435502871	20848	Economy	28700.00
0005435502903	20848	Economy	28700.00
0005434566300	20848	Economy	28700.00
0005434566301	20848	Economy	28700.00
0005435502799	20848	Economy	28700.00
0005435545940	20848	Economy	28700.00
0005435545926	20848	Economy	28700.00
0005435545933	20848	Economy	28700.00
0005435502746	20848	Economy	28700.00
0005435545922	20848	Economy	28700.00
0005435502840	20848	Economy	28700.00
0005435502812	20848	Economy	28700.00
0005435502818	20848	Economy	28700.00
0005435502935	20848	Economy	28700.00
0005435931702	3912	Economy	19700.00
0005435153903	21900	Economy	21600.00
0005435142997	21900	Economy	19700.00
0005435153942	21900	Economy	19700.00
0005435142996	21900	Economy	19700.00
0005435153929	21900	Economy	19700.00
0005435153941	21900	Economy	19700.00
0005435153930	21900	Economy	19700.00
0005435153924	21900	Economy	19700.00
0005435153901	21900	Economy	19700.00
0005435153923	21900	Economy	19700.00
0005435225786	7169	Economy	13000.00
0005435225806	7169	Economy	13000.00
0005432629273	28134	Economy	13000.00
0005432629241	28134	Economy	13000.00
0005432629258	28134	Economy	13000.00
0005432629240	28134	Economy	13000.00
0005432629272	28134	Economy	13000.00
0005432629292	28134	Economy	13000.00
0005432629285	28134	Economy	13000.00
0005432629293	28134	Economy	13000.00
0005432629281	28134	Economy	13000.00
0005432629286	28134	Economy	13000.00
0005434268061	8768	Economy	10500.00
0005435960161	15227	Economy	11500.00
0005435960156	15227	Economy	10500.00
0005435960157	15227	Economy	10500.00
0005432873480	1191	Business	115000.00
0005432873477	1191	Economy	38300.00
0005432873479	1191	Economy	38300.00
0005432873478	1191	Economy	38300.00
0005432873494	1191	Economy	38300.00
0005432873476	1191	Economy	38300.00
0005432873491	1191	Economy	38300.00
0005432873493	1191	Economy	38300.00
0005432675534	17476	Business	115000.00
0005432693942	17476	Business	115000.00
0005432693943	17476	Business	115000.00
0005432677678	17476	Business	115000.00
0005432693926	17476	Business	115000.00
0005432693927	17476	Business	115000.00
0005432693848	17476	Business	115000.00
0005432675556	17476	Business	115000.00
0005432677681	17476	Economy	38300.00
0005432693816	17476	Economy	38300.00
0005432675571	17476	Economy	38300.00
0005432693736	17476	Economy	38300.00
0005432693777	17476	Economy	38300.00
0005432693783	17476	Economy	38300.00
0005432675551	17476	Economy	38300.00
0005432693745	17476	Economy	38300.00
0005432693903	17476	Economy	38300.00
0005432693735	17476	Economy	38300.00
0005432675532	17476	Economy	38300.00
0005432693953	17476	Economy	38300.00
0005432675516	17476	Economy	38300.00
0005432675533	17476	Economy	38300.00
0005432675555	17476	Economy	38300.00
0005432675544	17476	Economy	38300.00
0005432693909	17476	Economy	38300.00
0005432675520	17476	Economy	38300.00
0005432675539	17476	Economy	38300.00
0005432693923	17476	Economy	38300.00
0005432693853	17476	Economy	38300.00
0005432693906	17476	Economy	38300.00
0005432675517	17476	Economy	38300.00
0005432693964	17476	Economy	38300.00
0005432693920	17476	Economy	38300.00
0005432693905	17476	Economy	38300.00
0005432693939	17476	Economy	38300.00
0005432675565	17476	Economy	38300.00
0005432675562	17476	Economy	38300.00
0005432675531	17476	Economy	38300.00
0005432693952	17476	Economy	38300.00
0005432677682	17476	Economy	38300.00
0005433156964	1148	Economy	13900.00
0005433156991	1148	Economy	13900.00
0005433156971	1148	Economy	13900.00
0005433156990	1148	Economy	13900.00
0005433157001	1148	Economy	13900.00
0005433156965	1148	Economy	13900.00
0005433156988	1148	Economy	13900.00
0005434435521	17322	Economy	15200.00
0005434435596	17322	Economy	13900.00
0005434435597	17322	Economy	13900.00
0005434435575	17322	Economy	13900.00
0005434435618	17322	Economy	13900.00
0005434435627	17322	Economy	13900.00
0005434435619	17322	Economy	13900.00
0005434435577	17322	Economy	13900.00
0005434435510	17322	Economy	13900.00
0005434435581	17322	Economy	13900.00
0005434435622	17322	Economy	13900.00
0005434435626	17322	Economy	13900.00
0005434435511	17322	Economy	13900.00
0005434435558	17322	Economy	13900.00
0005434435606	17322	Economy	13900.00
0005434435598	17322	Economy	13900.00
0005434435617	17322	Economy	13900.00
0005434435580	17322	Economy	13900.00
0005434435625	17322	Economy	13900.00
0005434435579	17322	Economy	13900.00
0005434435574	17322	Economy	13900.00
0005435928287	4102	Economy	7500.00
0005435928256	4102	Economy	7500.00
0005435928288	4102	Economy	7500.00
0005435928286	4102	Economy	7500.00
0005435928280	4102	Economy	7500.00
0005435087055	24408	Economy	7500.00
0005435087052	24408	Economy	7500.00
0005435087036	24408	Economy	7500.00
0005435087053	24408	Economy	7500.00
0005435087033	24408	Economy	7500.00
0005435087020	24408	Economy	7500.00
0005435087043	24408	Economy	7500.00
0005435087021	24408	Economy	7500.00
0005433373748	2455	Business	86800.00
0005433373776	2455	Economy	31800.00
0005433373779	2455	Economy	28900.00
0005433373795	2455	Economy	28900.00
0005433373764	2455	Economy	28900.00
0005433373765	2455	Economy	28900.00
0005433373790	2455	Economy	28900.00
0005433373745	2455	Economy	28900.00
0005433373770	2455	Economy	28900.00
0005433373800	2455	Economy	28900.00
0005433373771	2455	Economy	28900.00
0005433373766	2455	Economy	28900.00
0005433373782	2455	Economy	28900.00
0005433373791	2455	Economy	28900.00
0005433373767	2455	Economy	28900.00
0005433373778	2455	Economy	28900.00
0005435706836	27041	Business	86800.00
0005435706808	27041	Business	86800.00
0005435706837	27041	Economy	28900.00
0005435706747	27041	Economy	28900.00
0005435706801	27041	Economy	31800.00
0005435706843	27041	Economy	31800.00
0005435706835	27041	Economy	31800.00
0005435706782	27041	Economy	28900.00
0005435706825	27041	Economy	28900.00
0005435706785	27041	Economy	28900.00
0005435706840	27041	Economy	28900.00
0005435706854	27041	Economy	28900.00
0005435706791	27041	Economy	28900.00
0005435706746	27041	Economy	28900.00
0005435706799	27041	Economy	28900.00
0005435706790	27041	Economy	28900.00
0005435706842	27041	Economy	28900.00
0005435706839	27041	Economy	28900.00
0005435706824	27041	Economy	28900.00
0005435706838	27041	Economy	28900.00
0005435706817	27041	Economy	28900.00
0005435706804	27041	Economy	28900.00
0005435706784	27041	Economy	28900.00
0005433261776	1331	Business	203300.00
0005433261837	1331	Business	203300.00
0005433261832	1331	Economy	67800.00
0005433261863	1331	Economy	67800.00
0005433261855	1331	Economy	67800.00
0005433261853	1331	Economy	67800.00
0005433261841	1331	Economy	67800.00
0005433261796	1331	Economy	67800.00
0005433261864	1331	Economy	67800.00
0005433261777	1331	Economy	67800.00
0005433261782	1331	Economy	67800.00
0005433261854	1331	Economy	67800.00
0005433261783	1331	Economy	67800.00
0005433261833	1331	Economy	67800.00
0005433261835	1331	Economy	67800.00
0005433261838	1331	Economy	67800.00
0005433261842	1331	Economy	67800.00
0005433261807	1331	Economy	67800.00
0005433261867	1331	Economy	67800.00
0005433261797	1331	Economy	67800.00
0005433261866	1331	Economy	67800.00
0005433261808	1331	Economy	67800.00
0005433261802	1331	Economy	67800.00
0005433261836	1331	Economy	67800.00
0005433194948	4874	Business	44200.00
0005435907647	4874	Business	44200.00
0005433194968	4874	Business	44200.00
0005433194947	4874	Economy	14700.00
0005435907648	4874	Economy	14700.00
0005433194974	4874	Economy	14700.00
0005433194969	4874	Economy	14700.00
0005433194955	4874	Economy	14700.00
0005435907646	4874	Economy	14700.00
0005433194958	4874	Economy	14700.00
0005433194976	4874	Economy	14700.00
0005433194931	4874	Economy	14700.00
0005433194987	4874	Economy	14700.00
0005433194988	4874	Economy	14700.00
0005434626233	32916	Economy	14700.00
0005434626232	32916	Economy	14700.00
0005435786282	13779	Economy	3400.00
0005435786300	13779	Economy	3400.00
0005435786178	13779	Economy	3400.00
0005435786150	13779	Economy	3400.00
0005435786222	13779	Economy	3100.00
0005435786261	13779	Economy	3100.00
0005435786277	13779	Economy	3100.00
0005435786322	13779	Economy	3100.00
0005435786283	13779	Economy	3100.00
0005435786295	13779	Economy	3100.00
0005435786321	13779	Economy	3100.00
0005435786257	13779	Economy	3100.00
0005435786288	13779	Economy	3100.00
0005435786323	13779	Economy	3100.00
0005435786314	13779	Economy	3100.00
0005435786256	13779	Economy	3100.00
0005435786244	13779	Economy	3100.00
0005435786313	13779	Economy	3100.00
0005435786276	13779	Economy	3100.00
0005435786311	13779	Economy	3100.00
0005435786290	13779	Economy	3100.00
0005435786289	13779	Economy	3100.00
0005435786247	13779	Economy	3100.00
0005435937549	27407	Economy	3400.00
0005435937536	27407	Economy	3100.00
0005435937542	27407	Economy	3100.00
0005435937482	27407	Economy	3100.00
0005435937513	27407	Economy	3100.00
0005435937535	27407	Economy	3100.00
0005434409516	20295	Business	12000.00
0005434409601	20295	Business	12000.00
0005434409468	20295	Business	12000.00
0005434409295	20295	Business	12000.00
0005434409270	20295	Economy	4000.00
0005434409521	20295	Economy	4000.00
0005435311562	20295	Economy	4000.00
0005434409491	20295	Economy	4000.00
0005434409488	20295	Economy	4000.00
0005434409493	20295	Economy	4400.00
0005434409420	20295	Economy	4400.00
0005434409421	20295	Economy	4000.00
0005434409475	20295	Economy	4000.00
0005434409556	20295	Economy	4000.00
0005434409490	20295	Economy	4000.00
0005434409560	20295	Economy	4000.00
0005434409569	20295	Economy	4000.00
0005435311561	20295	Economy	4000.00
0005434409452	20295	Economy	4000.00
0005434409467	20295	Economy	4000.00
0005434409260	20295	Economy	4000.00
0005434409422	20295	Economy	4000.00
0005434409559	20295	Economy	4000.00
0005434409557	20295	Economy	4000.00
0005434409489	20295	Economy	4000.00
0005434409366	20295	Economy	4000.00
0005435311560	20295	Economy	4000.00
0005434409320	20295	Economy	4000.00
0005434409327	20295	Economy	4000.00
0005434409328	20295	Economy	4000.00
0005434409494	20295	Economy	4000.00
0005434409394	20295	Economy	4000.00
0005434409365	20295	Economy	4000.00
0005434409492	20295	Economy	4000.00
0005434409336	20295	Economy	4000.00
0005434409552	20295	Economy	4000.00
0005434409393	20295	Economy	4000.00
0005434409498	20295	Economy	4000.00
0005435311473	26973	Business	12000.00
0005435311500	26973	Business	12000.00
0005435311548	26973	Business	12000.00
0005435311471	26973	Economy	4000.00
0005435311467	26973	Economy	4400.00
0005435311499	26973	Economy	4000.00
0005435311540	26973	Economy	4000.00
0005435311542	26973	Economy	4000.00
0005435311518	26973	Economy	4000.00
0005435311448	26973	Economy	4000.00
0005435311472	26973	Economy	4000.00
0005435311468	26973	Economy	4000.00
0005435311541	26973	Economy	4000.00
0005435311366	26973	Economy	4000.00
0005435311519	26973	Economy	4000.00
0005435311496	26973	Economy	4000.00
0005435311547	26973	Economy	4000.00
0005435311528	26973	Economy	4000.00
0005435311482	26973	Economy	4000.00
0005435311504	26973	Economy	4000.00
0005435311480	26973	Economy	4000.00
0005435311461	26973	Economy	4000.00
0005435311505	26973	Economy	4000.00
0005435311441	26973	Economy	4000.00
0005435297387	5702	Business	43300.00
0005433124427	5702	Business	43300.00
0005433124471	5702	Business	43300.00
0005433124470	5702	Economy	14400.00
0005433124493	5702	Economy	14400.00
0005433124508	5702	Economy	14400.00
0005433124492	5702	Economy	14400.00
0005433124428	5702	Economy	14400.00
0005435297367	5702	Economy	14400.00
0005435297373	5702	Economy	14400.00
0005435297374	5702	Economy	14400.00
0005435297389	5702	Economy	14400.00
0005433124450	5702	Economy	14400.00
0005433124485	5702	Economy	14400.00
0005433124449	5702	Economy	14400.00
0005434319825	15705	Business	43300.00
0005434319781	15705	Economy	15900.00
0005434312375	15705	Economy	15900.00
0005434319842	15705	Economy	14400.00
0005434319808	15705	Economy	14400.00
0005434319834	15705	Economy	14400.00
0005434312374	15705	Economy	14400.00
0005434319792	15705	Economy	14400.00
0005434319782	15705	Economy	14400.00
0005434319791	15705	Economy	14400.00
0005434319839	15705	Economy	14400.00
0005434319766	15705	Economy	14400.00
0005434319809	15705	Economy	14400.00
0005435903227	8975	Economy	24900.00
0005434189328	8975	Economy	24900.00
0005435903228	8975	Economy	24900.00
0005434189329	8975	Economy	24900.00
0005434484542	8975	Economy	24900.00
0005435903234	8975	Economy	24900.00
0005434484518	16651	Economy	24900.00
0005434484522	16651	Economy	24900.00
0005434484517	16651	Economy	24900.00
0005433722434	7565	Business	11100.00
0005433722401	7565	Business	11100.00
0005433722412	7565	Business	11100.00
0005435229659	7565	Economy	3700.00
0005433722405	7565	Economy	3700.00
0005433722408	7565	Economy	4100.00
0005433722406	7565	Economy	4100.00
0005433722470	7565	Economy	3700.00
0005433722373	7565	Economy	3700.00
0005433722435	7565	Economy	3700.00
0005433722428	7565	Economy	3700.00
0005433722463	7565	Economy	3700.00
0005433722433	7565	Economy	3700.00
0005433722429	7565	Economy	3700.00
0005433722462	7565	Economy	3700.00
0005433722484	7565	Economy	3700.00
0005433722389	7565	Economy	3700.00
0005433722415	7565	Economy	3700.00
0005433722471	7565	Economy	3700.00
0005435229658	7565	Economy	3700.00
0005433722440	7565	Economy	3700.00
0005433722403	7565	Economy	3700.00
0005433722443	7565	Economy	3700.00
0005433722439	7565	Economy	3700.00
0005433722372	7565	Economy	3700.00
0005433722402	7565	Economy	3700.00
0005433722390	7565	Economy	3700.00
0005433450525	30320	Business	11100.00
0005432693939	30320	Business	11100.00
0005433450571	30320	Business	11100.00
0005433450584	30320	Business	11100.00
0005432693735	30320	Business	11100.00
0005433450596	30320	Business	11100.00
0005433450528	30320	Economy	3700.00
0005432693964	30320	Economy	3700.00
0005433450574	30320	Economy	3700.00
0005433450598	30320	Economy	3700.00
0005432693777	30320	Economy	3700.00
0005432693906	30320	Economy	4100.00
0005433450526	30320	Economy	4100.00
0005432693736	30320	Economy	4100.00
0005433450601	30320	Economy	3700.00
0005432693953	30320	Economy	3700.00
0005432693905	30320	Economy	3700.00
0005433450510	30320	Economy	3700.00
0005433450550	30320	Economy	3700.00
0005432693943	30320	Economy	3700.00
0005433450572	30320	Economy	3700.00
0005432693909	30320	Economy	3700.00
0005433450544	30320	Economy	3700.00
0005433450553	30320	Economy	3700.00
0005432693926	30320	Economy	3700.00
0005432693942	30320	Economy	3700.00
0005433450552	30320	Economy	3700.00
0005432693816	30320	Economy	3700.00
0005433450542	30320	Economy	3700.00
0005432693848	30320	Economy	3700.00
0005432693920	30320	Economy	3700.00
0005432693923	30320	Economy	3700.00
0005433450523	30320	Economy	3700.00
0005432693853	30320	Economy	3700.00
0005433450559	30320	Economy	3700.00
0005433450543	30320	Economy	3700.00
0005432693903	30320	Economy	3700.00
0005433450590	30320	Economy	3700.00
0005432693783	30320	Economy	3700.00
0005433450527	30320	Economy	3700.00
0005432693952	30320	Economy	3700.00
0005432693745	30320	Economy	3700.00
0005433450536	30320	Economy	3700.00
0005433450583	30320	Economy	3700.00
0005433450577	30320	Economy	3700.00
0005433450558	30320	Economy	3700.00
0005433450511	30320	Economy	3700.00
0005432693927	30320	Economy	3700.00
0005433450487	30320	Economy	3700.00
0005433450606	30320	Economy	3700.00
0005433450535	30320	Economy	3700.00
0005432721672	30321	Business	11100.00
0005432721673	30321	Business	11100.00
0005432721610	30321	Business	11100.00
0005432721546	30321	Business	11100.00
0005433124493	30321	Economy	3700.00
0005432721640	30321	Economy	3700.00
0005432721674	30321	Economy	3700.00
0005432721661	30321	Economy	4100.00
0005432721662	30321	Economy	4100.00
0005433124450	30321	Economy	3700.00
0005432721641	30321	Economy	3700.00
0005432721628	30321	Economy	3700.00
0005433124508	30321	Economy	3700.00
0005433124427	30321	Economy	3700.00
0005433124470	30321	Economy	3700.00
0005432721547	30321	Economy	3700.00
0005433124485	30321	Economy	3700.00
0005433124471	30321	Economy	3700.00
0005433124428	30321	Economy	3700.00
0005432721648	30321	Economy	3700.00
0005433124492	30321	Economy	3700.00
0005433124449	30321	Economy	3700.00
0005432721634	30321	Economy	3700.00
0005432721639	30321	Economy	3700.00
0005432721676	30321	Economy	3700.00
0005432721609	30321	Economy	3700.00
0005432968901	1360	Business	70400.00
0005433193424	1360	Business	70400.00
0005433193426	1360	Business	70400.00
0005433193442	1360	Economy	23500.00
0005433193342	1360	Economy	23500.00
0005432968900	1360	Economy	23500.00
0005433193425	1360	Economy	23500.00
0005433193420	1360	Economy	23500.00
0005433193405	1360	Economy	23500.00
0005433193385	1360	Economy	23500.00
0005433193443	1360	Economy	23500.00
0005432928137	1360	Economy	23500.00
0005433193406	1360	Economy	23500.00
0005433724928	18497	Business	70400.00
0005434587300	18497	Business	70400.00
0005434587343	18497	Business	70400.00
0005434587310	18497	Economy	25800.00
0005434587273	18497	Economy	25800.00
0005434587322	18497	Economy	23500.00
0005434587337	18497	Economy	23500.00
0005433724929	18497	Economy	23500.00
0005434587311	18497	Economy	23500.00
0005433724920	18497	Economy	23500.00
0005433525334	18497	Economy	23500.00
0005433525320	18497	Economy	23500.00
0005434587321	18497	Economy	23500.00
0005434515031	18497	Economy	23500.00
0005434587221	18497	Economy	23500.00
0005434587324	18497	Economy	23500.00
0005434587297	18497	Economy	23500.00
0005434587264	18497	Economy	23500.00
0005434587225	18497	Economy	23500.00
0005434587259	18497	Economy	23500.00
0005434587260	18497	Economy	23500.00
0005434587274	18497	Economy	23500.00
0005433525341	18497	Economy	23500.00
0005435305069	11441	Economy	4300.00
0005435305071	11441	Economy	4300.00
0005435305064	11441	Economy	4300.00
0005435302332	11441	Economy	4000.00
0005435302325	11441	Economy	4000.00
0005435302333	11441	Economy	4000.00
0005435302328	11441	Economy	4000.00
0005435305062	11441	Economy	4000.00
0005435305059	11441	Economy	4000.00
0005435302326	11441	Economy	4000.00
0005435305060	11441	Economy	4000.00
0005435302329	11441	Economy	4000.00
0005435302330	11441	Economy	4000.00
0005435305072	11441	Economy	4000.00
0005435302331	11441	Economy	4000.00
0005435305065	11441	Economy	4000.00
0005434345256	29792	Economy	4300.00
0005434142721	29792	Economy	4300.00
0005434345154	29792	Economy	4000.00
0005434345244	29792	Economy	4000.00
0005434345168	29792	Economy	4000.00
0005434345219	29792	Economy	4000.00
0005434345182	29792	Economy	4000.00
0005434345211	29792	Economy	4000.00
0005434345183	29792	Economy	4000.00
0005434142722	29792	Economy	4000.00
0005434345120	29792	Economy	4000.00
0005434345231	29792	Economy	4000.00
0005434345038	29792	Economy	4000.00
0005434345116	29792	Economy	4000.00
0005434345207	29792	Economy	4000.00
0005434345243	29792	Economy	4000.00
0005434345208	29792	Economy	4000.00
0005434345157	29792	Economy	4000.00
0005434345261	29792	Economy	4000.00
0005434345139	29792	Economy	4000.00
0005434345146	29792	Economy	4000.00
0005434345051	29792	Economy	4000.00
0005434345138	29792	Economy	4000.00
0005434345181	29792	Economy	4000.00
0005434345255	29792	Economy	4000.00
0005434345130	29792	Economy	4000.00
0005434345220	29792	Economy	4000.00
0005434345115	29792	Economy	4000.00
0005434345217	29792	Economy	4000.00
0005434345196	29792	Economy	4000.00
0005434345145	29792	Economy	4000.00
0005434345218	29792	Economy	4000.00
0005434345260	29792	Economy	4000.00
0005433416089	1257	Business	199800.00
0005433416124	1257	Economy	66600.00
0005433416130	1257	Economy	66600.00
0005433416088	1257	Economy	66600.00
0005433416076	1257	Economy	66600.00
0005433416107	1257	Economy	66600.00
0005433416087	1257	Economy	66600.00
0005433416129	1257	Economy	66600.00
0005433416077	1257	Economy	66600.00
0005435825334	18015	Business	199800.00
0005435825384	18015	Business	199800.00
0005435825374	18015	Business	199800.00
0005435825332	18015	Economy	66600.00
0005435825269	18015	Economy	66600.00
0005435825383	18015	Economy	66600.00
0005435825333	18015	Economy	73200.00
0005435825359	18015	Economy	66600.00
0005435825403	18015	Economy	66600.00
0005435825270	18015	Economy	66600.00
0005435825338	18015	Economy	66600.00
0005435825340	18015	Economy	66600.00
0005435825372	18015	Economy	66600.00
0005435825373	18015	Economy	66600.00
0005435825339	18015	Economy	66600.00
0005435825242	18015	Economy	66600.00
0005435825255	18015	Economy	66600.00
0005435825243	18015	Economy	66600.00
0005435476933	5641	Business	27800.00
0005435476985	5641	Business	27800.00
0005435243623	5641	Business	27800.00
0005435243585	5641	Business	27800.00
0005435243611	5641	Economy	9300.00
0005435243567	5641	Economy	9300.00
0005435243559	5641	Economy	9300.00
0005435243466	5641	Economy	9300.00
0005435243597	5641	Economy	9300.00
0005435476934	5641	Economy	9300.00
0005435243634	5641	Economy	9300.00
0005435243558	5641	Economy	9300.00
0005435243627	5641	Economy	9300.00
0005435476973	5641	Economy	9300.00
0005435243566	5641	Economy	9300.00
0005435476943	5641	Economy	9300.00
0005435243465	5641	Economy	9300.00
0005435243657	5641	Economy	9300.00
0005435476986	5641	Economy	9300.00
0005435476945	5641	Economy	9300.00
0005435243565	5641	Economy	9300.00
0005435243656	5641	Economy	9300.00
0005435476958	5641	Economy	9300.00
0005435243521	5641	Economy	9300.00
0005432785196	15369	Business	27800.00
0005435950006	15369	Business	27800.00
0005432785302	15369	Business	27800.00
0005432785244	15369	Business	27800.00
0005432785117	15369	Business	27800.00
0005432785312	15369	Business	27800.00
0005432785245	15369	Business	27800.00
0005432785314	15369	Business	27800.00
0005435950053	15369	Economy	9300.00
0005435949997	15369	Economy	9300.00
0005432785218	15369	Economy	9300.00
0005435949998	15369	Economy	9300.00
0005435950018	15369	Economy	9300.00
0005435950017	15369	Economy	10200.00
0005432785156	15369	Economy	10200.00
0005432785131	15369	Economy	10200.00
0005435949985	15369	Economy	9300.00
0005432785266	15369	Economy	9300.00
0005432785118	15369	Economy	9300.00
0005432785267	15369	Economy	9300.00
0005435950031	15369	Economy	9300.00
0005432785167	15369	Economy	9300.00
0005432785277	15369	Economy	9300.00
0005432785130	15369	Economy	9300.00
0005432785346	15369	Economy	9300.00
0005432785233	15369	Economy	9300.00
0005435950011	15369	Economy	9300.00
0005432785212	15369	Economy	9300.00
0005432785278	15369	Economy	9300.00
0005432785161	15369	Economy	9300.00
0005432785311	15369	Economy	9300.00
0005432785150	15369	Economy	9300.00
0005432785220	15369	Economy	9300.00
0005432785249	15369	Economy	9300.00
0005435949986	15369	Economy	9300.00
0005435949993	15369	Economy	9300.00
0005432785075	15369	Economy	9300.00
0005432785160	15369	Economy	9300.00
0005432785214	15369	Economy	9300.00
0005432785242	15369	Economy	9300.00
0005432785213	15369	Economy	9300.00
0005435949990	15369	Economy	9300.00
0005435950033	15369	Economy	9300.00
0005435950028	15369	Economy	9300.00
0005432785215	15369	Economy	9300.00
0005435950010	15369	Economy	9300.00
0005432785313	15369	Economy	9300.00
0005432785158	15369	Economy	9300.00
0005432785155	15369	Economy	9300.00
0005432785219	15369	Economy	9300.00
0005435950027	15369	Economy	9300.00
0005432785235	15369	Economy	9300.00
0005432785190	15369	Economy	9300.00
0005435950038	15369	Economy	9300.00
0005432785241	15369	Economy	9300.00
0005435949994	15369	Economy	9300.00
0005435851169	4353	Economy	6300.00
0005435851171	4353	Economy	6300.00
0005434461698	28854	Economy	6300.00
0005432848714	28854	Economy	6300.00
0005432848687	28854	Economy	6300.00
0005432848688	28854	Economy	6300.00
0005434463982	28854	Economy	6300.00
0005434461706	28854	Economy	6300.00
0005434463995	28854	Economy	6300.00
0005432848698	28854	Economy	6300.00
0005434463994	28854	Economy	6300.00
0005434461697	28854	Economy	6300.00
0005435257540	6249	Business	11900.00
0005435257476	6249	Economy	4000.00
0005435257521	6249	Economy	4000.00
0005435257475	6249	Economy	4400.00
0005435257498	6249	Economy	4400.00
0005435257497	6249	Economy	4000.00
0005435257512	6249	Economy	4000.00
0005434444149	20376	Business	11900.00
0005434444111	20376	Business	11900.00
0005434926637	20376	Business	11900.00
0005434926552	20376	Business	11900.00
0005434444082	20376	Business	11900.00
0005434444129	20376	Business	11900.00
0005434926765	20376	Business	11900.00
0005434444107	20376	Economy	4000.00
0005434926827	20376	Economy	4000.00
0005434444154	20376	Economy	4000.00
0005434926586	20376	Economy	4000.00
0005433497851	20376	Economy	4000.00
0005434926791	20376	Economy	4000.00
0005433497787	20376	Economy	4000.00
0005434926724	20376	Economy	4000.00
0005434444094	20376	Economy	4400.00
0005433497824	20376	Economy	4400.00
0005433497881	20376	Economy	4400.00
0005434444138	20376	Economy	4400.00
0005434444102	20376	Economy	4400.00
0005434926730	20376	Economy	4000.00
0005434926731	20376	Economy	4000.00
0005433497885	20376	Economy	4000.00
0005434444141	20376	Economy	4000.00
0005434926744	20376	Economy	4000.00
0005434926532	20376	Economy	4000.00
0005433497806	20376	Economy	4000.00
0005433497882	20376	Economy	4000.00
0005434444110	20376	Economy	4000.00
0005434444104	20376	Economy	4000.00
0005434444080	20376	Economy	4000.00
0005433497786	20376	Economy	4000.00
0005434444105	20376	Economy	4000.00
0005434926703	20376	Economy	4000.00
0005434444166	20376	Economy	4000.00
0005434444155	20376	Economy	4000.00
0005433497844	20376	Economy	4000.00
0005433497807	20376	Economy	4000.00
0005434444106	20376	Economy	4000.00
0005434444139	20376	Economy	4000.00
0005434926585	20376	Economy	4000.00
0005433497841	20376	Economy	4000.00
0005434926531	20376	Economy	4000.00
0005433497843	20376	Economy	4000.00
0005434926743	20376	Economy	4000.00
0005434926596	20376	Economy	4000.00
0005434444150	20376	Economy	4000.00
0005434444103	20376	Economy	4000.00
0005433497801	20376	Economy	4000.00
0005434926773	20376	Economy	4000.00
0005434926806	20376	Economy	4000.00
0005434926780	20376	Economy	4000.00
0005434926787	20376	Economy	4000.00
0005434444095	20376	Economy	4000.00
0005433497842	20376	Economy	4000.00
0005434926788	20376	Economy	4000.00
0005434444130	20376	Economy	4000.00
0005434926726	20376	Economy	4000.00
0005434926785	20376	Economy	4000.00
0005434926826	20376	Economy	4000.00
0005434444136	20376	Economy	4000.00
0005434926784	20376	Economy	4000.00
0005434444142	20376	Economy	4000.00
0005434926530	20376	Economy	4000.00
0005434444081	20376	Economy	4000.00
0005434926697	20376	Economy	4000.00
0005432785248	12200	Business	41200.00
0005432785173	12200	Business	41200.00
0005432785181	12200	Business	41200.00
0005432785274	12200	Business	41200.00
0005435243669	12200	Business	41200.00
0005432785187	12200	Business	41200.00
0005432785097	12200	Business	41200.00
0005432785188	12200	Economy	13700.00
0005435243668	12200	Economy	13700.00
0005432785240	12200	Economy	13700.00
0005432785203	12200	Economy	13700.00
0005432785272	12200	Economy	13700.00
0005432785295	12200	Economy	15100.00
0005432785232	12200	Economy	15100.00
0005432785273	12200	Economy	15100.00
0005432785199	12200	Economy	15100.00
0005432785157	12200	Economy	15100.00
0005432785319	12200	Economy	13700.00
0005432785224	12200	Economy	13700.00
0005435243667	12200	Economy	13700.00
0005432785351	12200	Economy	13700.00
0005432785195	12200	Economy	13700.00
0005432785309	12200	Economy	13700.00
0005432785271	12200	Economy	13700.00
0005432785098	12200	Economy	13700.00
0005432785206	12200	Economy	13700.00
0005432785114	12200	Economy	13700.00
0005432785276	12200	Economy	13700.00
0005432785202	12200	Economy	13700.00
0005432785352	12200	Economy	13700.00
0005432784977	12200	Economy	13700.00
0005432785184	12200	Economy	13700.00
0005432785275	12200	Economy	13700.00
0005432785285	12200	Economy	13700.00
0005432785310	12200	Economy	13700.00
0005432785246	12200	Economy	13700.00
0005432785237	12200	Economy	13700.00
0005432785286	12200	Economy	13700.00
0005432785320	12200	Economy	13700.00
0005432785293	12200	Economy	13700.00
0005432785294	12200	Economy	13700.00
0005432785353	12200	Economy	13700.00
0005432785296	12200	Economy	13700.00
0005432785350	12200	Economy	13700.00
0005435243525	15419	Business	41200.00
0005435243593	15419	Business	41200.00
0005435243514	15419	Business	41200.00
0005435243638	15419	Business	41200.00
0005435243540	15419	Economy	13700.00
0005435243582	15419	Economy	13700.00
0005432785370	15419	Economy	13700.00
0005435243513	15419	Economy	13700.00
0005435243476	15419	Economy	15100.00
0005435243473	15419	Economy	13700.00
0005435243588	15419	Economy	13700.00
0005435243474	15419	Economy	13700.00
0005435243500	15419	Economy	13700.00
0005435243594	15419	Economy	13700.00
0005435243581	15419	Economy	13700.00
0005435243554	15419	Economy	13700.00
0005432785369	15419	Economy	13700.00
0005435243529	15419	Economy	13700.00
0005435243530	15419	Economy	13700.00
0005435243624	15419	Economy	13700.00
0005435243541	15419	Economy	13700.00
0005435243526	15419	Economy	13700.00
0005435243501	15419	Economy	13700.00
0005435243595	15419	Economy	13700.00
0005435243610	15419	Economy	13700.00
0005435243497	15419	Economy	13700.00
0005435243631	15419	Economy	13700.00
0005435243632	15419	Economy	13700.00
0005435243577	15419	Economy	13700.00
0005434880695	10076	Business	49700.00
0005434880635	10076	Business	49700.00
0005434880814	10076	Business	49700.00
0005434880551	10076	Business	49700.00
0005434880715	10076	Business	49700.00
0005434880708	10076	Business	49700.00
0005434880842	10076	Business	49700.00
0005434880847	10076	Business	49700.00
0005434880812	10076	Business	49700.00
0005434880861	10076	Business	49700.00
0005434880908	10076	Business	49700.00
0005434880712	10076	Business	49700.00
0005434880918	10076	Business	49700.00
0005434880725	10076	Business	49700.00
0005434880871	10076	Business	49700.00
0005434880924	10076	Business	49700.00
0005434880625	10076	Business	49700.00
0005434880757	10076	Economy	16600.00
0005434880846	10076	Economy	16600.00
0005434880641	10076	Economy	16600.00
0005434880907	10076	Economy	16600.00
0005434880958	10076	Economy	16600.00
0005434880759	10076	Economy	16600.00
0005434880862	10076	Economy	18200.00
0005434880840	10076	Economy	16600.00
0005434880823	10076	Economy	16600.00
0005434880886	10076	Economy	16600.00
0005434880895	10076	Economy	16600.00
0005434880552	10076	Economy	16600.00
0005434880889	10076	Economy	16600.00
0005434880606	10076	Economy	16600.00
0005434880883	10076	Economy	16600.00
0005434880726	10076	Economy	16600.00
0005434880584	10076	Economy	16600.00
0005434880607	10076	Economy	16600.00
0005434880976	10076	Economy	16600.00
0005434880856	10076	Economy	16600.00
0005434880873	10076	Economy	16600.00
0005434880755	10076	Economy	16600.00
0005434880906	10076	Economy	16600.00
0005434880825	10076	Economy	16600.00
0005434880743	10076	Economy	16600.00
0005434880816	10076	Economy	16600.00
0005434880506	10076	Economy	16600.00
0005434880930	10076	Economy	16600.00
0005434880702	10076	Economy	16600.00
0005434880634	10076	Economy	16600.00
0005434880874	10076	Economy	16600.00
0005434880942	10076	Economy	16600.00
0005434880633	10076	Economy	16600.00
0005434880855	10076	Economy	16600.00
0005434880943	10076	Economy	16600.00
0005434880550	10076	Economy	16600.00
0005434880884	10076	Economy	16600.00
0005434880704	10076	Economy	16600.00
0005434880926	10076	Economy	16600.00
0005434880944	10076	Economy	16600.00
0005434880724	10076	Economy	16600.00
0005434880841	10076	Economy	16600.00
0005434880822	10076	Economy	16600.00
0005434880863	10076	Economy	16600.00
0005434880885	10076	Economy	16600.00
0005434880945	10076	Economy	16600.00
0005434880872	10076	Economy	16600.00
0005434880946	10076	Economy	16600.00
0005434880813	10076	Economy	16600.00
0005434880896	10076	Economy	16600.00
0005434880923	10076	Economy	16600.00
0005434880890	10076	Economy	16600.00
0005435914135	14638	Business	49700.00
0005435914192	14638	Business	49700.00
0005435914206	14638	Business	49700.00
0005435914197	14638	Business	49700.00
0005435914179	14638	Business	49700.00
0005435914177	14638	Business	49700.00
0005435914191	14638	Economy	16600.00
0005435914171	14638	Economy	18200.00
0005435914098	14638	Economy	16600.00
0005435914196	14638	Economy	18200.00
0005435914200	14638	Economy	16600.00
0005435914148	14638	Economy	16600.00
0005435914195	14638	Economy	16600.00
0005435914149	14638	Economy	16600.00
0005435914099	14638	Economy	16600.00
0005435914150	14638	Economy	16600.00
0005435914139	14638	Economy	16600.00
0005435914190	14638	Economy	16600.00
0005435914160	14638	Economy	16600.00
0005435914163	14638	Economy	16600.00
0005435914138	14638	Economy	16600.00
0005435914162	14638	Economy	16600.00
0005435914178	14638	Economy	16600.00
0005435914161	14638	Economy	16600.00
0005435914194	14638	Economy	16600.00
0005434252223	9219	Economy	20300.00
0005434252230	9219	Economy	20300.00
0005435933558	9219	Economy	20300.00
0005435933586	9219	Economy	20300.00
0005435933583	9219	Economy	20300.00
0005435933582	9219	Economy	20300.00
0005435933584	9219	Economy	20300.00
0005435933576	9219	Economy	20300.00
0005434252242	9219	Economy	20300.00
0005435933574	9219	Economy	20300.00
0005434252231	9219	Economy	20300.00
0005435660420	24638	Economy	22400.00
0005435660448	24638	Economy	20300.00
0005435660424	24638	Economy	20300.00
0005435660449	24638	Economy	20300.00
0005435660376	24638	Economy	20300.00
0005435660429	24638	Economy	20300.00
0005435660425	24638	Economy	20300.00
0005435660406	24638	Economy	20300.00
0005432967655	2823	Business	33000.00
0005432967634	2823	Business	33000.00
0005432967677	2823	Business	33000.00
0005432967650	2823	Economy	11000.00
0005432967662	2823	Economy	11000.00
0005432967657	2823	Economy	11000.00
0005432967499	2823	Economy	11000.00
0005432967651	2823	Economy	11000.00
0005432967658	2823	Economy	11000.00
0005432967500	2823	Economy	11000.00
0005432967635	2823	Economy	11000.00
0005433681927	29154	Business	33000.00
0005433681967	29154	Business	33000.00
0005433681783	29154	Business	33000.00
0005433681775	29154	Economy	11000.00
0005433681859	29154	Economy	11000.00
0005433681919	29154	Economy	11000.00
0005433681858	29154	Economy	11000.00
0005433687750	29154	Economy	11000.00
0005433690979	29154	Economy	12100.00
0005433681912	29154	Economy	12100.00
0005433681949	29154	Economy	11000.00
0005433681940	29154	Economy	11000.00
0005433681943	29154	Economy	11000.00
0005433681972	29154	Economy	11000.00
0005433681913	29154	Economy	11000.00
0005433684476	29154	Economy	11000.00
0005433681952	29154	Economy	11000.00
0005433681817	29154	Economy	11000.00
0005433681945	29154	Economy	11000.00
0005433681857	29154	Economy	11000.00
0005433681939	29154	Economy	11000.00
0005433681777	29154	Economy	11000.00
0005433687752	29154	Economy	11000.00
0005433681818	29154	Economy	11000.00
0005433681841	29154	Economy	11000.00
0005433681938	29154	Economy	11000.00
0005433681832	29154	Economy	11000.00
0005433681784	29154	Economy	11000.00
0005434272235	9320	Business	132900.00
0005434152842	9320	Economy	44300.00
0005434269153	9320	Economy	44300.00
0005434152846	9320	Economy	44300.00
0005434272227	9320	Economy	44300.00
0005434152841	9320	Economy	44300.00
0005434163872	9320	Economy	44300.00
0005435856355	9320	Economy	44300.00
0005435856353	9320	Economy	44300.00
0005435856354	9320	Economy	44300.00
0005434269152	9320	Economy	44300.00
0005433634806	25233	Business	132900.00
0005433616654	25233	Business	132900.00
0005433634693	25233	Business	132900.00
0005433616322	25233	Business	132900.00
0005433616667	25233	Business	132900.00
0005433616509	25233	Business	132900.00
0005433616555	25233	Business	132900.00
0005433634767	25233	Business	132900.00
0005433616390	25233	Business	132900.00
0005433634805	25233	Business	132900.00
0005433634719	25233	Business	132900.00
0005433634772	25233	Business	132900.00
0005433616673	25233	Business	132900.00
0005433616426	25233	Business	132900.00
0005433616696	25233	Business	132900.00
0005433616772	25233	Business	132900.00
0005433634735	25233	Business	132900.00
0005433616709	25233	Economy	48700.00
0005433634722	25233	Economy	48700.00
0005433616261	25233	Economy	48700.00
0005433578147	25233	Economy	48700.00
0005433578148	25233	Economy	48700.00
0005433616653	25233	Economy	44300.00
0005433616398	25233	Economy	44300.00
0005433616613	25233	Economy	44300.00
0005433634701	25233	Economy	44300.00
0005433634768	25233	Economy	44300.00
0005433616421	25233	Economy	44300.00
0005433616763	25233	Economy	44300.00
0005433616692	25233	Economy	44300.00
0005433634728	25233	Economy	44300.00
0005433634757	25233	Economy	44300.00
0005433616501	25233	Economy	44300.00
0005433634736	25233	Economy	44300.00
0005433616708	25233	Economy	44300.00
0005433616542	25233	Economy	44300.00
0005433616567	25233	Economy	44300.00
0005433616621	25233	Economy	44300.00
0005433634756	25233	Economy	44300.00
0005433616573	25233	Economy	44300.00
0005433616620	25233	Economy	44300.00
0005433634711	25233	Economy	44300.00
0005433578140	25233	Economy	44300.00
0005433616541	25233	Economy	44300.00
0005433616771	25233	Economy	44300.00
0005433616262	25233	Economy	44300.00
0005433578189	25233	Economy	44300.00
0005433634567	25233	Economy	44300.00
0005433616399	25233	Economy	44300.00
0005433616730	25233	Economy	44300.00
0005433616597	25233	Economy	44300.00
0005433616598	25233	Economy	44300.00
0005433578177	25233	Economy	44300.00
0005433616389	25233	Economy	44300.00
0005433616628	25233	Economy	44300.00
0005433578200	25233	Economy	44300.00
0005433616655	25233	Economy	48700.00
0005433616661	25233	Economy	48700.00
0005433634778	25233	Economy	48700.00
0005433616607	25233	Economy	48700.00
0005433616397	25233	Economy	44300.00
0005433634632	25233	Economy	44300.00
0005433578199	25233	Economy	44300.00
0005433616500	25233	Economy	44300.00
0005433634692	25233	Economy	44300.00
0005433578155	25233	Economy	44300.00
0005433616476	25233	Economy	44300.00
0005433616681	25233	Economy	44300.00
0005433634802	25233	Economy	44300.00
0005433578160	25233	Economy	44300.00
0005433616747	25233	Economy	44300.00
0005433616682	25233	Economy	44300.00
0005433634807	25233	Economy	44300.00
0005433616614	25233	Economy	44300.00
0005433616629	25233	Economy	44300.00
0005433634653	25233	Economy	44300.00
0005433578146	25233	Economy	44300.00
0005433634694	25233	Economy	44300.00
0005433616574	25233	Economy	44300.00
0005433616506	25233	Economy	44300.00
0005433616508	25233	Economy	44300.00
0005433616575	25233	Economy	44300.00
0005433634710	25233	Economy	44300.00
0005433616651	25233	Economy	44300.00
0005433578171	25233	Economy	44300.00
0005433616810	25233	Economy	44300.00
0005433578154	25233	Economy	44300.00
0005433634779	25233	Economy	44300.00
0005433616731	25233	Economy	44300.00
0005433634700	25233	Economy	44300.00
0005433616741	25233	Economy	44300.00
0005433634721	25233	Economy	44300.00
0005433616313	25233	Economy	44300.00
0005433616817	25233	Economy	44300.00
0005433616540	25233	Economy	44300.00
0005433634633	25233	Economy	44300.00
0005433634812	25233	Economy	44300.00
0005435947613	4224	Business	193100.00
0005435787398	4224	Business	193100.00
0005435947631	4224	Business	193100.00
0005435947605	4224	Business	193100.00
0005435854086	4224	Business	193100.00
0005435947642	4224	Economy	64400.00
0005435854085	4224	Economy	64400.00
0005435947622	4224	Economy	64400.00
0005435947661	4224	Economy	64400.00
0005435947656	4224	Economy	64400.00
0005435947630	4224	Economy	64400.00
0005435947641	4224	Economy	64400.00
0005435787404	4224	Economy	64400.00
0005435947607	4224	Economy	64400.00
0005435787407	4224	Economy	64400.00
0005435947672	4224	Economy	64400.00
0005435947632	4224	Economy	64400.00
0005434271362	4224	Economy	64400.00
0005435947662	4224	Economy	64400.00
0005435947637	4224	Economy	64400.00
0005432571417	4224	Economy	64400.00
0005435947650	4224	Economy	64400.00
0005435854078	4224	Economy	64400.00
0005435947606	4224	Economy	64400.00
0005435947604	4224	Economy	64400.00
0005435854079	4224	Economy	64400.00
0005435947614	4224	Economy	64400.00
0005435947638	4224	Economy	64400.00
0005435987008	26583	Business	193100.00
0005435986968	26583	Economy	64400.00
0005435986971	26583	Economy	64400.00
0005435987018	26583	Economy	64400.00
0005435987042	26583	Economy	70800.00
0005435987023	26583	Economy	64400.00
0005435986933	26583	Economy	64400.00
0005435987044	26583	Economy	64400.00
0005435987009	26583	Economy	64400.00
0005435986956	26583	Economy	64400.00
0005435987043	26583	Economy	64400.00
0005435986982	26583	Economy	64400.00
0005435986937	26583	Economy	64400.00
0005432949527	323	Business	21500.00
0005432949586	323	Business	21500.00
0005432949613	323	Business	21500.00
0005432949548	323	Business	21500.00
0005432949522	323	Business	21500.00
0005433075439	323	Business	21500.00
0005433929881	323	Business	21500.00
0005433075396	323	Business	21500.00
0005433134254	323	Business	21500.00
0005433075522	323	Economy	7900.00
0005433929872	323	Economy	7200.00
0005432949650	323	Economy	7200.00
0005433134257	323	Economy	7200.00
0005432949562	323	Economy	7200.00
0005432949469	323	Economy	7200.00
0005432949534	323	Economy	7200.00
0005433075539	323	Economy	7200.00
0005432949552	323	Economy	7200.00
0005433129387	323	Economy	7200.00
0005433075424	323	Economy	7200.00
0005432949602	323	Economy	7200.00
0005432949535	323	Economy	7200.00
0005432949614	323	Economy	7200.00
0005433129406	323	Economy	7200.00
0005432949489	323	Economy	7200.00
0005433075493	323	Economy	7200.00
0005432949559	323	Economy	7200.00
0005432949558	323	Economy	7200.00
0005433075471	323	Economy	7200.00
0005432949587	323	Economy	7200.00
0005433929870	323	Economy	7200.00
0005433134261	323	Economy	7200.00
0005433129405	323	Economy	7900.00
0005433075447	323	Economy	7900.00
0005433929871	323	Economy	7200.00
0005433075485	323	Economy	7200.00
0005432949596	323	Economy	7200.00
0005433075438	323	Economy	7200.00
0005433075472	323	Economy	7200.00
0005432949570	323	Economy	7200.00
0005432949601	323	Economy	7200.00
0005432949526	323	Economy	7200.00
0005432949490	323	Economy	7200.00
0005432949572	323	Economy	7200.00
0005432949561	323	Economy	7200.00
0005433075537	323	Economy	7200.00
0005433075425	323	Economy	7200.00
0005433075479	323	Economy	7200.00
0005433075538	323	Economy	7200.00
0005433075541	323	Economy	7200.00
0005432949595	323	Economy	7200.00
0005433929880	323	Economy	7200.00
0005433075536	323	Economy	7200.00
0005433075473	323	Economy	7200.00
0005432949557	323	Economy	7200.00
0005432949549	323	Economy	7200.00
0005433929882	323	Economy	7200.00
0005433929879	323	Economy	7200.00
0005433570878	11574	Business	21500.00
0005434326020	11574	Business	21500.00
0005433570762	11574	Business	21500.00
0005433570761	11574	Business	21500.00
0005433570657	11574	Business	21500.00
0005433570637	11574	Business	21500.00
0005433570751	11574	Business	21500.00
0005433570557	11574	Business	21500.00
0005433570887	11574	Business	21500.00
0005433570733	11574	Business	21500.00
0005433570601	11574	Business	21500.00
0005433570702	11574	Business	21500.00
0005433570472	11574	Business	21500.00
0005433570365	11574	Business	21500.00
0005433570442	11574	Economy	7900.00
0005433570704	11574	Economy	7200.00
0005433570797	11574	Economy	7200.00
0005433570903	11574	Economy	7200.00
0005433570551	11574	Economy	7200.00
0005433570729	11574	Economy	7200.00
0005434088036	11574	Economy	7200.00
0005433570754	11574	Economy	7200.00
0005433570680	11574	Economy	7200.00
0005433570735	11574	Economy	7200.00
0005433570672	11574	Economy	7200.00
0005433570658	11574	Economy	7200.00
0005433570574	11574	Economy	7200.00
0005433570366	11574	Economy	7200.00
0005433570475	11574	Economy	7200.00
0005434087990	11574	Economy	7200.00
0005433570798	11574	Economy	7200.00
0005433570573	11574	Economy	7200.00
0005433570948	11574	Economy	7200.00
0005433570703	11574	Economy	7200.00
0005433570364	11574	Economy	7200.00
0005433570816	11574	Economy	7200.00
0005434087978	11574	Economy	7200.00
0005433570692	11574	Economy	7200.00
0005433570467	11574	Economy	7200.00
0005434088013	11574	Economy	7200.00
0005433570617	11574	Economy	7200.00
0005433570648	11574	Economy	7200.00
0005433570693	11574	Economy	7200.00
0005433570576	11574	Economy	7200.00
0005433570363	11574	Economy	7200.00
0005434087991	11574	Economy	7200.00
0005434326022	11574	Economy	7200.00
0005433570433	11574	Economy	7200.00
0005433570598	11574	Economy	7200.00
0005433570473	11574	Economy	7200.00
0005434087953	11574	Economy	7200.00
0005433570526	11574	Economy	7200.00
0005434326021	11574	Economy	7200.00
0005433570550	11574	Economy	7200.00
0005433570794	11574	Economy	7900.00
0005433570699	11574	Economy	7900.00
0005433570577	11574	Economy	7900.00
0005433570851	11574	Economy	7200.00
0005434088009	11574	Economy	7200.00
0005433570700	11574	Economy	7200.00
0005433570634	11574	Economy	7200.00
0005433570835	11574	Economy	7900.00
0005434088050	11574	Economy	7200.00
0005433570796	11574	Economy	7200.00
0005433570904	11574	Economy	7200.00
0005433570711	11574	Economy	7200.00
0005434087954	11574	Economy	7200.00
0005434088005	11574	Economy	7200.00
0005433570630	11574	Economy	7200.00
0005433570734	11574	Economy	7200.00
0005433134265	11574	Economy	7200.00
0005434088051	11574	Economy	7200.00
0005433570834	11574	Economy	7200.00
0005433570687	11574	Economy	7200.00
0005433570688	11574	Economy	7200.00
0005433570669	11574	Economy	7200.00
0005433570501	11574	Economy	7200.00
0005433570905	11574	Economy	7200.00
0005434088029	11574	Economy	7200.00
0005434326024	11574	Economy	7200.00
0005433570799	11574	Economy	7200.00
0005433570781	11574	Economy	7200.00
0005434088008	11574	Economy	7200.00
0005434088010	11574	Economy	7200.00
0005433570504	11574	Economy	7200.00
0005434088014	11574	Economy	7200.00
0005433570708	11574	Economy	7200.00
0005434326023	11574	Economy	7200.00
0005433570689	11574	Economy	7200.00
0005433570443	11574	Economy	7200.00
0005433570789	11574	Economy	7200.00
0005433570510	11574	Economy	7200.00
0005434326018	11574	Economy	7200.00
0005433570886	11574	Economy	7200.00
0005433570791	11574	Economy	7200.00
0005434087977	11574	Economy	7200.00
0005433570929	11574	Economy	7200.00
0005433570790	11574	Economy	7200.00
0005434733074	10052	Economy	6300.00
0005434733077	10052	Economy	6300.00
0005434733078	10052	Economy	6300.00
0005433817567	13933	Economy	6300.00
0005433817574	13933	Economy	6300.00
0005432985944	2368	Business	184500.00
0005432985989	2368	Business	184500.00
0005433435448	2368	Business	184500.00
0005433435436	2368	Business	184500.00
0005433435401	2368	Business	184500.00
0005432985983	2368	Economy	67700.00
0005434376167	2368	Economy	61500.00
0005432985982	2368	Economy	61500.00
0005433435486	2368	Economy	61500.00
0005432985873	2368	Economy	61500.00
0005432869705	2368	Economy	61500.00
0005433435440	2368	Economy	61500.00
0005432985939	2368	Economy	61500.00
0005433435420	2368	Economy	61500.00
0005433435487	2368	Economy	61500.00
0005432869695	2368	Economy	61500.00
0005432985979	2368	Economy	61500.00
0005432985957	2368	Economy	61500.00
0005432985945	2368	Economy	61500.00
0005432985770	2368	Economy	61500.00
0005433435474	2368	Economy	61500.00
0005432985941	2368	Economy	61500.00
0005432985899	2368	Economy	61500.00
0005433435456	2368	Economy	61500.00
0005432985960	2368	Economy	61500.00
0005433435481	2368	Economy	61500.00
0005434731290	2368	Economy	61500.00
0005432985900	2368	Economy	61500.00
0005433435430	2368	Economy	61500.00
0005432869707	2368	Economy	61500.00
0005432985961	2368	Economy	61500.00
0005432985958	2368	Economy	61500.00
0005432985926	2368	Economy	61500.00
0005432985942	2368	Economy	61500.00
0005433435432	2368	Economy	61500.00
0005433435434	2368	Economy	61500.00
0005432985940	2368	Economy	61500.00
0005433435494	2368	Economy	61500.00
0005432985988	2368	Economy	61500.00
0005432985959	2368	Economy	61500.00
0005432985938	2368	Economy	61500.00
0005433435457	2368	Economy	61500.00
0005433435422	2368	Economy	61500.00
0005433435433	2368	Economy	61500.00
0005433435493	2368	Economy	61500.00
0005432985992	2368	Economy	61500.00
0005432869708	2368	Economy	61500.00
0005432985962	2368	Economy	61500.00
0005432869676	2368	Economy	61500.00
0005433435332	2368	Economy	61500.00
0005432869714	2368	Economy	61500.00
0005432869706	2368	Economy	61500.00
0005432985771	2368	Economy	61500.00
0005433435463	2368	Economy	61500.00
0005432869713	2368	Economy	61500.00
0005432985872	2368	Economy	61500.00
0005432985839	2368	Economy	61500.00
0005433766744	26211	Business	184500.00
0005433755834	26211	Business	184500.00
0005435983590	26211	Business	184500.00
0005433755823	26211	Business	184500.00
0005433755661	26211	Business	184500.00
0005433755851	26211	Business	184500.00
0005433755521	26211	Business	184500.00
0005433755829	26211	Business	184500.00
0005432655809	26211	Business	184500.00
0005433755800	26211	Business	184500.00
0005435983498	26211	Business	184500.00
0005435983430	26211	Business	184500.00
0005435983399	26211	Business	184500.00
0005435983363	26211	Business	184500.00
0005433755820	26211	Business	184500.00
0005433755783	26211	Business	184500.00
0005433755728	26211	Business	184500.00
0005433755868	26211	Business	184500.00
0005432655823	26211	Business	184500.00
0005433755846	26211	Economy	67700.00
0005435983536	26211	Economy	61500.00
0005435983533	26211	Economy	61500.00
0005432655808	26211	Economy	61500.00
0005435983373	26211	Economy	61500.00
0005435983469	26211	Economy	61500.00
0005435983542	26211	Economy	61500.00
0005433755878	26211	Economy	61500.00
0005435983470	26211	Economy	61500.00
0005435983557	26211	Economy	61500.00
0005432655807	26211	Economy	61500.00
0005435983432	26211	Economy	61500.00
0005433755818	26211	Economy	61500.00
0005432655856	26211	Economy	61500.00
0005435983482	26211	Economy	61500.00
0005435983466	26211	Economy	61500.00
0005435983351	26211	Economy	61500.00
0005432655827	26211	Economy	61500.00
0005435983475	26211	Economy	61500.00
0005435983509	26211	Economy	61500.00
0005433755812	26211	Economy	61500.00
0005435983631	26211	Economy	61500.00
0005432655867	26211	Economy	61500.00
0005433755816	26211	Economy	61500.00
0005435983514	26211	Economy	61500.00
0005433766743	26211	Economy	61500.00
0005433755605	26211	Economy	61500.00
0005433766763	26211	Economy	61500.00
0005433755877	26211	Economy	61500.00
0005435983483	26211	Economy	61500.00
0005433755830	26211	Economy	61500.00
0005435983517	26211	Economy	61500.00
0005433755815	26211	Economy	61500.00
0005435983372	26211	Economy	61500.00
0005435983510	26211	Economy	61500.00
0005433755869	26211	Economy	61500.00
0005433766766	26211	Economy	61500.00
0005435983501	26211	Economy	61500.00
0005433755542	26211	Economy	61500.00
0005432655881	26211	Economy	61500.00
0005433755749	26211	Economy	61500.00
0005435983607	26211	Economy	61500.00
0005435983543	26211	Economy	61500.00
0005435983603	26211	Economy	61500.00
0005433755541	26211	Economy	61500.00
0005435983601	26211	Economy	61500.00
0005435983526	26211	Economy	61500.00
0005433755849	26211	Economy	61500.00
0005433755819	26211	Economy	61500.00
0005433755855	26211	Economy	61500.00
0005433755659	26211	Economy	61500.00
0005435983431	26211	Economy	61500.00
0005433755672	26211	Economy	61500.00
0005435983537	26211	Economy	61500.00
0005435983355	26211	Economy	61500.00
0005433766742	26211	Economy	61500.00
0005435983520	26211	Economy	61500.00
0005435983521	26211	Economy	61500.00
0005433755471	26211	Economy	61500.00
0005433755833	26211	Economy	61500.00
0005432655861	26211	Economy	61500.00
0005433755850	26211	Economy	61500.00
0005433755657	26211	Economy	67700.00
0005435983608	26211	Economy	67700.00
0005433766752	26211	Economy	61500.00
0005433755656	26211	Economy	61500.00
0005432655835	26211	Economy	61500.00
0005435983569	26211	Economy	61500.00
0005435983535	26211	Economy	61500.00
0005435983492	26211	Economy	61500.00
0005435983506	26211	Economy	61500.00
0005435983362	26211	Economy	61500.00
0005435983596	26211	Economy	61500.00
0005435983507	26211	Economy	61500.00
0005432655886	26211	Economy	61500.00
0005435983553	26211	Economy	61500.00
0005435983600	26211	Economy	61500.00
0005435983479	26211	Economy	61500.00
0005435983632	26211	Economy	61500.00
0005433755761	26211	Economy	61500.00
0005435983516	26211	Economy	61500.00
0005432655806	26211	Economy	61500.00
0005433755784	26211	Economy	61500.00
0005433755750	26211	Economy	61500.00
0005433755879	26211	Economy	61500.00
0005435983527	26211	Economy	61500.00
0005435983454	26211	Economy	61500.00
0005432655853	26211	Economy	61500.00
0005435983375	26211	Economy	61500.00
0005435983508	26211	Economy	61500.00
0005433755857	26211	Economy	61500.00
0005435983523	26211	Economy	61500.00
0005433766762	26211	Economy	61500.00
0005432655855	26211	Economy	61500.00
0005433755606	26211	Economy	61500.00
0005433755660	26211	Economy	61500.00
0005433755814	26211	Economy	61500.00
0005432655868	26211	Economy	61500.00
0005433764735	26211	Economy	61500.00
0005433755856	26211	Economy	61500.00
0005435983493	26211	Economy	61500.00
0005433766765	26211	Economy	61500.00
0005432655851	26211	Economy	61500.00
0005435983468	26211	Economy	61500.00
0005435983474	26211	Economy	61500.00
0005433152392	1519	Business	38900.00
0005433152401	1519	Business	38900.00
0005433152323	1519	Business	38900.00
0005434029722	1519	Business	38900.00
0005434029728	1519	Economy	13000.00
0005433152353	1519	Economy	13000.00
0005433152389	1519	Economy	13000.00
0005433152390	1519	Economy	13000.00
0005434029720	1519	Economy	13000.00
0005433152352	1519	Economy	13000.00
0005433152391	1519	Economy	13000.00
0005433152369	1519	Economy	13000.00
0005433931557	1519	Economy	13000.00
0005434376171	1519	Economy	13000.00
0005433764732	1519	Economy	13000.00
0005433152362	1519	Economy	13000.00
0005433152388	1519	Economy	14300.00
0005434029727	1519	Economy	13000.00
0005434376170	1519	Economy	13000.00
0005434029721	1519	Economy	13000.00
0005433152379	1519	Economy	13000.00
0005433931556	1519	Economy	13000.00
0005433152399	1519	Economy	13000.00
0005433152354	1519	Economy	13000.00
0005433152322	1519	Economy	13000.00
0005434376229	20155	Business	38900.00
0005434375929	20155	Business	38900.00
0005434375878	20155	Business	38900.00
0005434375999	20155	Business	38900.00
0005434375774	20155	Economy	13000.00
0005434376167	20155	Economy	13000.00
0005434375989	20155	Economy	13000.00
0005434376231	20155	Economy	13000.00
0005434376000	20155	Economy	13000.00
0005434375851	20155	Economy	13000.00
0005434375950	20155	Economy	13000.00
0005434375973	20155	Economy	13000.00
0005434375977	20155	Economy	13000.00
0005434375741	20155	Economy	13000.00
0005433152417	20155	Economy	13000.00
0005434375874	20155	Economy	13000.00
0005434375775	20155	Economy	13000.00
0005434375903	20155	Economy	13000.00
0005434375978	20155	Economy	13000.00
0005434376184	20155	Economy	13000.00
0005434375974	20155	Economy	14300.00
0005434376189	20155	Economy	14300.00
0005434375915	20155	Economy	13000.00
0005434375951	20155	Economy	13000.00
0005434375820	20155	Economy	13000.00
0005434375959	20155	Economy	13000.00
0005434375930	20155	Economy	13000.00
0005434376180	20155	Economy	13000.00
0005434375881	20155	Economy	13000.00
0005434375993	20155	Economy	13000.00
0005434375907	20155	Economy	13000.00
0005434375821	20155	Economy	13000.00
0005434376182	20155	Economy	13000.00
0005434375880	20155	Economy	13000.00
0005434376181	20155	Economy	13000.00
0005434375876	20155	Economy	13000.00
0005434376013	20155	Economy	13000.00
0005434375992	20155	Economy	13000.00
0005434375976	20155	Economy	13000.00
0005434375991	20155	Economy	13000.00
0005434376228	20155	Economy	13000.00
0005433262018	559	Business	27500.00
0005433261981	559	Business	27500.00
0005433261945	559	Business	27500.00
0005433261941	559	Business	27500.00
0005433261928	559	Economy	10100.00
0005433261944	559	Economy	9200.00
0005433262002	559	Economy	9200.00
0005433157011	559	Economy	9200.00
0005433261927	559	Economy	9200.00
0005433262028	559	Economy	9200.00
0005433261950	559	Economy	9200.00
0005433261969	559	Economy	10100.00
0005433261942	559	Economy	9200.00
0005433261899	559	Economy	9200.00
0005433261986	559	Economy	9200.00
0005433262003	559	Economy	9200.00
0005433262009	559	Economy	9200.00
0005433261958	559	Economy	9200.00
0005433261970	559	Economy	9200.00
0005433261971	559	Economy	9200.00
0005433262019	559	Economy	9200.00
0005433262008	559	Economy	9200.00
0005433261946	559	Economy	9200.00
0005434446587	12835	Business	27500.00
0005434446585	12835	Economy	10100.00
0005434446584	12835	Economy	9200.00
0005434446583	12835	Economy	9200.00
0005432425631	12918	Business	27500.00
0005432425741	12918	Business	27500.00
0005432425770	12918	Business	27500.00
0005432425680	12918	Business	27500.00
0005432425737	12918	Business	27500.00
0005432425745	12918	Business	27500.00
0005432425809	12918	Business	27500.00
0005432425676	12918	Business	27500.00
0005432425860	12918	Business	27500.00
0005432425735	12918	Business	27500.00
0005432425832	12918	Business	27500.00
0005432425706	12918	Business	27500.00
0005432425824	12918	Business	27500.00
0005432425768	12918	Economy	10100.00
0005432425717	12918	Economy	10100.00
0005432425746	12918	Economy	9200.00
0005432425783	12918	Economy	9200.00
0005432425700	12918	Economy	9200.00
0005432425795	12918	Economy	9200.00
0005432425862	12918	Economy	9200.00
0005432425797	12918	Economy	9200.00
0005432425632	12918	Economy	9200.00
0005432425707	12918	Economy	9200.00
0005432425710	12918	Economy	9200.00
0005432425816	12918	Economy	9200.00
0005432425799	12918	Economy	9200.00
0005432425851	12918	Economy	9200.00
0005432425798	12918	Economy	9200.00
0005432425727	12918	Economy	9200.00
0005432425740	12918	Economy	9200.00
0005432425759	12918	Economy	9200.00
0005432425728	12918	Economy	9200.00
0005432425733	12918	Economy	9200.00
0005432425678	12918	Economy	9200.00
0005432425772	12918	Economy	9200.00
0005432425831	12918	Economy	9200.00
0005432425771	12918	Economy	9200.00
0005432425817	12918	Economy	9200.00
0005432425708	12918	Economy	9200.00
0005432425709	12918	Economy	10100.00
0005432425796	12918	Economy	10100.00
0005432425649	12918	Economy	10100.00
0005432425650	12918	Economy	9200.00
0005432425836	12918	Economy	10100.00
0005432425803	12918	Economy	9200.00
0005432425774	12918	Economy	9200.00
0005432425841	12918	Economy	9200.00
0005432425732	12918	Economy	9200.00
0005432425681	12918	Economy	9200.00
0005432425590	12918	Economy	9200.00
0005432425769	12918	Economy	9200.00
0005432425713	12918	Economy	9200.00
0005432425773	12918	Economy	9200.00
0005432425589	12918	Economy	9200.00
0005432425859	12918	Economy	9200.00
0005432425785	12918	Economy	9200.00
0005432425684	12918	Economy	9200.00
0005432425852	12918	Economy	9200.00
0005432425682	12918	Economy	9200.00
0005432425793	12918	Economy	9200.00
0005432425712	12918	Economy	9200.00
0005432425864	12918	Economy	9200.00
0005432425780	12918	Economy	9200.00
0005432425842	12918	Economy	9200.00
0005432425677	12918	Economy	9200.00
0005432425775	12918	Economy	9200.00
0005432425779	12918	Economy	9200.00
0005432425853	12918	Economy	9200.00
0005432425863	12918	Economy	9200.00
0005432425764	12918	Economy	9200.00
0005432425790	12918	Economy	9200.00
0005432425858	12918	Economy	9200.00
0005433929721	446	Business	24500.00
0005433058968	446	Business	24500.00
0005433058853	446	Economy	9000.00
0005433059046	446	Economy	8200.00
0005433059031	446	Economy	8200.00
0005434735832	446	Economy	8200.00
0005433058828	446	Economy	8200.00
0005433059036	446	Economy	8200.00
0005433929711	446	Economy	8200.00
0005433059032	446	Economy	8200.00
0005433059030	446	Economy	8200.00
0005433059042	446	Economy	8200.00
0005433058999	446	Economy	8200.00
0005433058829	446	Economy	8200.00
0005433059045	446	Economy	8200.00
0005433058913	446	Economy	8200.00
0005433058852	446	Economy	8200.00
0005433058969	446	Economy	8200.00
0005433929712	446	Economy	8200.00
0005433684478	446	Economy	8200.00
0005433058854	446	Economy	8200.00
0005433058927	446	Economy	8200.00
0005433058788	446	Economy	8200.00
0005433684472	446	Economy	8200.00
0005433058964	446	Economy	9000.00
0005433058824	446	Economy	8200.00
0005433059037	446	Economy	8200.00
0005434735813	446	Economy	8200.00
0005433058932	446	Economy	8200.00
0005433058939	446	Economy	8200.00
0005434025633	12653	Business	24500.00
0005434032134	12653	Business	24500.00
0005434025642	12653	Business	24500.00
0005434025594	12653	Business	24500.00
0005434025538	12653	Business	24500.00
0005434025452	12653	Economy	9000.00
0005434025593	12653	Economy	9000.00
0005434025398	12653	Economy	8200.00
0005434025566	12653	Economy	8200.00
0005434032136	12653	Economy	8200.00
0005434025616	12653	Economy	8200.00
0005434025582	12653	Economy	8200.00
0005434029728	12653	Economy	8200.00
0005434025435	12653	Economy	8200.00
0005434025584	12653	Economy	8200.00
0005434025615	12653	Economy	8200.00
0005434025453	12653	Economy	8200.00
0005434029722	12653	Economy	8200.00
0005434025505	12653	Economy	8200.00
0005434029721	12653	Economy	8200.00
0005434032135	12653	Economy	8200.00
0005434025474	12653	Economy	8200.00
0005434032154	12653	Economy	8200.00
0005434025454	12653	Economy	8200.00
0005434025488	12653	Economy	8200.00
0005434025652	12653	Economy	8200.00
0005434025522	12653	Economy	8200.00
0005434025592	12653	Economy	8200.00
0005434025598	12653	Economy	8200.00
0005434025519	12653	Economy	8200.00
0005434025534	12653	Economy	8200.00
0005434025641	12653	Economy	8200.00
0005434025579	12653	Economy	8200.00
0005434025232	12653	Economy	9000.00
0005434025645	12653	Economy	8200.00
0005434029727	12653	Economy	8200.00
0005434025523	12653	Economy	8200.00
0005434025597	12653	Economy	8200.00
0005434029720	12653	Economy	8200.00
0005434025624	12653	Economy	8200.00
0005434025466	12653	Economy	8200.00
0005434025460	12653	Economy	8200.00
0005434025429	12653	Economy	8200.00
0005434032152	12653	Economy	8200.00
0005434025669	12653	Economy	8200.00
0005434025632	12653	Economy	8200.00
0005434028383	12653	Economy	8200.00
0005434025619	12653	Economy	8200.00
0005433037747	2137	Business	34700.00
0005433037795	2137	Business	34700.00
0005433037722	2137	Business	34700.00
0005433037826	2137	Business	34700.00
0005433037676	2137	Business	34700.00
0005433037723	2137	Business	34700.00
0005433037801	2137	Business	34700.00
0005433037794	2137	Business	34700.00
0005434376180	2137	Business	34700.00
0005434028383	2137	Business	34700.00
0005433037771	2137	Economy	12700.00
0005433037524	2137	Economy	11600.00
0005434376189	2137	Economy	11600.00
0005432749840	2137	Economy	11600.00
0005433037711	2137	Economy	11600.00
0005433037434	2137	Economy	11600.00
0005434088054	2137	Economy	11600.00
0005433037773	2137	Economy	11600.00
0005433037599	2137	Economy	11600.00
0005434376184	2137	Economy	11600.00
0005433037704	2137	Economy	11600.00
0005433037835	2137	Economy	11600.00
0005433037781	2137	Economy	11600.00
0005433037755	2137	Economy	11600.00
0005433037575	2137	Economy	11600.00
0005433037730	2137	Economy	11600.00
0005433037783	2137	Economy	11600.00
0005433037792	2137	Economy	11600.00
0005433037767	2137	Economy	11600.00
0005433037646	2137	Economy	11600.00
0005432749837	2137	Economy	11600.00
0005433926121	2137	Economy	11600.00
0005433037784	2137	Economy	11600.00
0005433037509	2137	Economy	11600.00
0005433037720	2137	Economy	11600.00
0005433037578	2137	Economy	11600.00
0005434088052	2137	Economy	11600.00
0005434088053	2137	Economy	11600.00
0005433037435	2137	Economy	11600.00
0005433037691	2137	Economy	11600.00
0005434376182	2137	Economy	11600.00
0005432749836	2137	Economy	11600.00
0005434376181	2137	Economy	11600.00
0005433037803	2137	Economy	11600.00
0005433037761	2137	Economy	11600.00
0005433037576	2137	Economy	11600.00
0005433037721	2137	Economy	11600.00
0005433037523	2137	Economy	11600.00
0005433926123	2137	Economy	11600.00
0005433037705	2137	Economy	11600.00
0005432749841	2137	Economy	11600.00
0005433037775	2137	Economy	11600.00
0005433926122	2137	Economy	11600.00
0005433037731	2137	Economy	11600.00
0005433037769	2137	Economy	11600.00
0005433037793	2137	Economy	11600.00
0005433926034	24138	Business	34700.00
0005433926037	24138	Business	34700.00
0005433925953	24138	Business	34700.00
0005433926076	24138	Business	34700.00
0005433925863	24138	Business	34700.00
0005433925952	24138	Business	34700.00
0005433925807	24138	Business	34700.00
0005433925837	24138	Business	34700.00
0005433925923	24138	Business	34700.00
0005433926075	24138	Business	34700.00
0005433926017	24138	Economy	12700.00
0005433926085	24138	Economy	11600.00
0005433925665	24138	Economy	11600.00
0005433925824	24138	Economy	11600.00
0005433926025	24138	Economy	11600.00
0005433929718	24138	Economy	11600.00
0005433925822	24138	Economy	11600.00
0005433926005	24138	Economy	11600.00
0005433926001	24138	Economy	11600.00
0005433926039	24138	Economy	11600.00
0005433925802	24138	Economy	11600.00
0005433925836	24138	Economy	11600.00
0005433925897	24138	Economy	11600.00
0005433925666	24138	Economy	11600.00
0005433926074	24138	Economy	11600.00
0005433925902	24138	Economy	11600.00
0005433926016	24138	Economy	11600.00
0005433925968	24138	Economy	11600.00
0005433925798	24138	Economy	11600.00
0005433925992	24138	Economy	11600.00
0005433925524	24138	Economy	11600.00
0005433925999	24138	Economy	11600.00
0005433926026	24138	Economy	11600.00
0005433926023	24138	Economy	11600.00
0005433926073	24138	Economy	11600.00
0005433926031	24138	Economy	11600.00
0005433925525	24138	Economy	11600.00
0005433926004	24138	Economy	11600.00
0005433925803	24138	Economy	11600.00
0005433925799	24138	Economy	11600.00
0005433925554	24138	Economy	11600.00
0005433925840	24138	Economy	11600.00
0005433931551	24138	Economy	11600.00
0005433925942	24138	Economy	11600.00
0005433925898	24138	Economy	11600.00
0005433925937	24138	Economy	11600.00
0005433931549	24138	Economy	11600.00
0005433926024	24138	Economy	11600.00
0005433926000	24138	Economy	11600.00
0005433931544	24138	Economy	12700.00
0005433925832	24138	Economy	12700.00
0005433925442	24138	Economy	11600.00
0005433925929	24138	Economy	11600.00
0005433925499	24138	Economy	11600.00
0005433929715	24138	Economy	11600.00
0005433925928	24138	Economy	11600.00
0005433925951	24138	Economy	11600.00
0005433925915	24138	Economy	11600.00
0005433925924	24138	Economy	11600.00
0005433925838	24138	Economy	11600.00
0005433925884	24138	Economy	11600.00
0005433925883	24138	Economy	11600.00
0005433925982	24138	Economy	11600.00
0005433925805	24138	Economy	11600.00
0005433926052	24138	Economy	11600.00
0005433925841	24138	Economy	11600.00
0005433925920	24138	Economy	11600.00
0005433926003	24138	Economy	11600.00
0005433925930	24138	Economy	11600.00
0005433926072	24138	Economy	11600.00
0005433926020	24138	Economy	11600.00
0005433925571	24138	Economy	11600.00
0005433925692	24138	Economy	11600.00
0005433925804	24138	Economy	11600.00
0005433925862	24138	Economy	11600.00
0005433925969	24138	Economy	11600.00
0005433931550	24138	Economy	11600.00
0005433925570	24138	Economy	11600.00
0005433925808	24138	Economy	11600.00
0005433925572	24138	Economy	11600.00
0005433926019	24138	Economy	11600.00
0005433235721	299	Business	83700.00
0005433126944	299	Business	83700.00
0005434729058	299	Business	83700.00
0005434729054	299	Business	83700.00
0005433126945	299	Business	83700.00
0005433235803	299	Business	83700.00
0005434032137	299	Business	83700.00
0005433235900	299	Comfort	47400.00
0005433290047	299	Business	83700.00
0005433235739	299	Comfort	47400.00
0005433235834	299	Comfort	47400.00
0005433235930	299	Comfort	47400.00
0005433236009	299	Comfort	47400.00
0005433181822	299	Comfort	47400.00
0005433235796	299	Comfort	47400.00
0005433766736	299	Economy	27900.00
0005433131821	299	Economy	27900.00
0005433235797	299	Economy	27900.00
0005433181701	299	Economy	27900.00
0005434032143	299	Economy	27900.00
0005433235733	299	Economy	27900.00
0005433235999	299	Economy	27900.00
0005433235870	299	Economy	27900.00
0005434032138	299	Economy	27900.00
0005433181784	299	Economy	27900.00
0005433766746	299	Economy	27900.00
0005433235962	299	Economy	27900.00
0005433181823	299	Economy	27900.00
0005433236033	299	Economy	27900.00
0005433235829	299	Economy	27900.00
0005433131827	299	Economy	27900.00
0005433235772	299	Economy	27900.00
0005433181748	299	Economy	27900.00
0005433766737	299	Economy	27900.00
0005433235821	299	Economy	27900.00
0005433236021	299	Economy	30700.00
0005433235728	299	Economy	27900.00
0005433235778	299	Economy	27900.00
0005434729056	299	Economy	27900.00
0005433131828	299	Economy	27900.00
0005433235996	299	Economy	27900.00
0005433126964	299	Economy	27900.00
0005434032151	299	Economy	27900.00
0005433181788	299	Economy	27900.00
0005433290056	299	Economy	27900.00
0005434729055	299	Economy	27900.00
0005433236020	299	Economy	27900.00
0005433131829	299	Economy	27900.00
0005433235986	299	Economy	27900.00
0005433235777	299	Economy	27900.00
0005433235987	299	Economy	27900.00
0005433290048	299	Economy	27900.00
0005433235966	299	Economy	27900.00
0005433235958	299	Economy	27900.00
0005433235601	299	Economy	27900.00
0005433181713	299	Economy	27900.00
0005433126972	299	Economy	27900.00
0005434032144	299	Economy	27900.00
0005433111555	299	Economy	27900.00
0005433181821	299	Economy	27900.00
0005433181751	299	Economy	27900.00
0005434731293	299	Economy	27900.00
0005433181752	299	Economy	27900.00
0005434552868	299	Economy	27900.00
0005433235923	299	Economy	27900.00
0005433181756	299	Economy	27900.00
0005433235957	299	Economy	27900.00
0005433290050	299	Economy	27900.00
0005433111557	299	Economy	27900.00
0005433126973	299	Economy	27900.00
0005433235911	299	Economy	27900.00
0005433235931	299	Economy	27900.00
0005433111556	299	Economy	27900.00
0005433290027	299	Economy	27900.00
0005433235861	299	Economy	27900.00
0005433766741	299	Economy	30700.00
0005433235708	299	Economy	30700.00
0005434032147	299	Economy	27900.00
0005434032142	299	Economy	27900.00
0005433235732	299	Economy	27900.00
0005433290026	299	Economy	27900.00
0005433235806	299	Economy	27900.00
0005433235945	299	Economy	27900.00
0005433235787	299	Economy	27900.00
0005433236032	299	Economy	27900.00
0005433181776	299	Economy	27900.00
0005433181712	299	Economy	27900.00
0005433235855	299	Economy	27900.00
0005433181755	299	Economy	27900.00
0005434032148	299	Economy	27900.00
0005433235830	299	Economy	27900.00
0005433126982	299	Economy	27900.00
0005433235971	299	Economy	27900.00
0005433766745	299	Economy	27900.00
0005433235997	299	Economy	27900.00
0005433290053	299	Economy	27900.00
0005433290052	299	Economy	27900.00
0005433235854	299	Economy	27900.00
0005433126961	299	Economy	27900.00
0005433236034	299	Economy	27900.00
0005434552867	299	Economy	27900.00
0005433235862	299	Economy	27900.00
0005433290035	299	Economy	27900.00
0005434032145	299	Economy	27900.00
0005434729057	299	Economy	27900.00
0005433235901	299	Economy	27900.00
0005434552709	9823	Business	83700.00
0005434552672	9823	Business	83700.00
0005434728791	9823	Business	83700.00
0005435142925	9823	Business	83700.00
0005434728834	9823	Business	83700.00
0005434728700	9823	Business	83700.00
0005434731290	9823	Business	83700.00
0005434728797	9823	Business	83700.00
0005434728634	9823	Business	83700.00
0005434552617	9823	Business	83700.00
0005434728841	9823	Business	83700.00
0005434552660	9823	Comfort	47400.00
0005434728711	9823	Comfort	47400.00
0005434728237	9823	Comfort	47400.00
0005434552609	9823	Comfort	47400.00
0005434552835	9823	Comfort	47400.00
0005434728395	9823	Comfort	47400.00
0005434728543	9823	Comfort	47400.00
0005434728613	9823	Comfort	47400.00
0005434728542	9823	Comfort	47400.00
0005434552669	9823	Comfort	47400.00
0005434552632	9823	Comfort	47400.00
0005434728672	9823	Comfort	47400.00
0005434728435	9823	Comfort	47400.00
0005434552815	9823	Comfort	47400.00
0005434728916	9823	Comfort	47400.00
0005433129413	9823	Comfort	47400.00
0005434728926	9823	Comfort	47400.00
0005434302568	9823	Comfort	47400.00
0005434728641	9823	Comfort	47400.00
0005434728840	9823	Comfort	47400.00
0005434552637	9823	Comfort	47400.00
0005434552644	9823	Comfort	47400.00
0005434735837	9823	Comfort	47400.00
0005434728635	9823	Comfort	47400.00
0005434552761	9823	Economy	27900.00
0005434728925	9823	Economy	27900.00
0005434552506	9823	Economy	27900.00
0005434728285	9823	Economy	27900.00
0005434552639	9823	Economy	27900.00
0005434552759	9823	Economy	27900.00
0005434728866	9823	Economy	27900.00
0005434552714	9823	Economy	27900.00
0005434302577	9823	Economy	27900.00
0005434728571	9823	Economy	27900.00
0005434552572	9823	Economy	27900.00
0005434728779	9823	Economy	27900.00
0005434728848	9823	Economy	27900.00
0005434728695	9823	Economy	27900.00
0005434728924	9823	Economy	27900.00
0005434728149	9823	Economy	27900.00
0005434552630	9823	Economy	27900.00
0005435142907	9823	Economy	27900.00
0005434728753	9823	Economy	27900.00
0005434552638	9823	Economy	27900.00
0005434552751	9823	Economy	27900.00
0005434728148	9823	Economy	27900.00
0005434728642	9823	Economy	27900.00
0005434728983	9823	Economy	30700.00
0005434728778	9823	Economy	27900.00
0005434728777	9823	Economy	27900.00
0005434728937	9823	Economy	30700.00
0005434552713	9823	Economy	30700.00
0005434552640	9823	Economy	27900.00
0005434728443	9823	Economy	27900.00
0005434728636	9823	Economy	27900.00
0005434728394	9823	Economy	27900.00
0005434728633	9823	Economy	27900.00
0005434728559	9823	Economy	27900.00
0005434728914	9823	Economy	27900.00
0005434728699	9823	Economy	27900.00
0005434728822	9823	Economy	27900.00
0005434728508	9823	Economy	27900.00
0005434728867	9823	Economy	27900.00
0005434552771	9823	Economy	27900.00
0005434728901	9823	Economy	27900.00
0005434728511	9823	Economy	27900.00
0005435142926	9823	Economy	27900.00
0005434728715	9823	Economy	27900.00
0005434552817	9823	Economy	27900.00
0005434728286	9823	Economy	27900.00
0005434728643	9823	Economy	27900.00
0005434728459	9823	Economy	27900.00
0005434728859	9823	Economy	27900.00
0005434552837	9823	Economy	27900.00
0005434728728	9823	Economy	27900.00
0005434552601	9823	Economy	27900.00
0005434728694	9823	Economy	27900.00
0005434727768	9823	Economy	27900.00
0005434728830	9823	Economy	27900.00
0005434728938	9823	Economy	27900.00
0005434728915	9823	Economy	27900.00
0005434552774	9823	Economy	27900.00
0005434552610	9823	Economy	27900.00
0005434552520	9823	Economy	27900.00
0005434728305	9823	Economy	27900.00
0005434552763	9823	Economy	27900.00
0005434552497	9823	Economy	27900.00
0005434728572	9823	Economy	27900.00
0005434728364	9823	Economy	27900.00
0005434552699	9823	Economy	27900.00
0005434735830	9823	Economy	27900.00
0005434552496	9823	Economy	27900.00
0005435142924	9823	Economy	27900.00
0005434728718	9823	Economy	27900.00
0005435142930	9823	Economy	27900.00
0005434302565	9823	Economy	27900.00
0005434728712	9823	Economy	27900.00
0005434728442	9823	Economy	27900.00
0005434552742	9823	Economy	27900.00
0005434728860	9823	Economy	27900.00
0005434735829	9823	Economy	27900.00
0005434552636	9823	Economy	27900.00
0005434735836	9823	Economy	30700.00
0005434552735	9823	Economy	30700.00
0005434728833	9823	Economy	30700.00
0005434728787	9823	Economy	27900.00
0005434728561	9823	Economy	27900.00
0005434729017	9823	Economy	27900.00
0005434552671	9823	Economy	27900.00
0005434728580	9823	Economy	27900.00
0005434552772	9823	Economy	27900.00
0005434728771	9823	Economy	27900.00
0005434552773	9823	Economy	27900.00
0005434552631	9823	Economy	27900.00
0005434552629	9823	Economy	27900.00
0005435142885	9823	Economy	27900.00
0005434728472	9823	Economy	27900.00
0005434552649	9823	Economy	27900.00
0005434728786	9823	Economy	27900.00
0005435142902	9823	Economy	27900.00
0005434728946	9823	Economy	27900.00
0005434728731	9823	Economy	27900.00
0005434728473	9823	Economy	27900.00
0005434728847	9823	Economy	27900.00
0005434729016	9823	Economy	27900.00
0005434552834	9823	Economy	27900.00
0005434552521	9823	Economy	27900.00
0005434728507	9823	Economy	27900.00
0005434728630	9823	Economy	27900.00
0005435142915	9823	Economy	27900.00
0005435142914	9823	Economy	27900.00
0005434728719	9823	Economy	27900.00
0005434552816	9823	Economy	27900.00
0005434552618	9823	Economy	27900.00
0005434728730	9823	Economy	27900.00
0005434302580	9823	Economy	27900.00
0005434552409	9823	Economy	27900.00
0005434728619	9823	Economy	27900.00
0005434728716	9823	Economy	27900.00
0005434728823	9823	Economy	27900.00
0005434552762	9823	Economy	27900.00
0005434728662	9823	Economy	27900.00
0005434552410	9823	Economy	27900.00
0005434728283	9823	Economy	27900.00
0005434728434	9823	Economy	27900.00
0005434552393	9823	Economy	27900.00
0005434728832	9823	Economy	27900.00
0005435215305	7756	Business	42100.00
0005435215362	7756	Business	42100.00
0005435215260	7756	Business	42100.00
0005435215431	7756	Business	42100.00
0005435215335	7756	Business	42100.00
0005435215228	7756	Business	42100.00
0005435283484	7756	Business	42100.00
0005435725731	7756	Business	42100.00
0005435215406	7756	Comfort	23900.00
0005435283522	7756	Comfort	23900.00
0005435283475	7756	Comfort	23900.00
0005435283466	7756	Comfort	23900.00
0005435283467	7756	Comfort	23900.00
0005435215470	7756	Economy	14000.00
0005435215316	7756	Economy	14000.00
0005435215295	7756	Economy	14000.00
0005435725726	7756	Economy	14000.00
0005435283510	7756	Economy	14000.00
0005435215377	7756	Economy	14000.00
0005435283504	7756	Economy	14000.00
0005435215488	7756	Economy	14000.00
0005435215363	7756	Economy	14000.00
0005435215413	7756	Economy	15400.00
0005435215320	7756	Economy	15400.00
0005435215354	7756	Economy	14000.00
0005435283521	7756	Economy	14000.00
0005435215404	7756	Economy	14000.00
0005435725709	7756	Economy	14000.00
0005435283512	7756	Economy	14000.00
0005435215376	7756	Economy	14000.00
0005435215371	7756	Economy	14000.00
0005435283523	7756	Economy	14000.00
0005435215455	7756	Economy	14000.00
0005435215353	7756	Economy	14000.00
0005435215436	7756	Economy	14000.00
0005435215071	7756	Economy	14000.00
0005435215469	7756	Economy	15400.00
0005435215185	7756	Economy	14000.00
0005435283501	7756	Economy	14000.00
0005435215489	7756	Economy	14000.00
0005435215372	7756	Economy	14000.00
0005435725707	7756	Economy	14000.00
0005435215310	7756	Economy	14000.00
0005435215345	7756	Economy	14000.00
0005435215356	7756	Economy	14000.00
0005435215315	7756	Economy	14000.00
0005435215186	7756	Economy	14000.00
0005435215259	7756	Economy	14000.00
0005435283511	7756	Economy	14000.00
0005435725725	7756	Economy	14000.00
0005432070082	7756	Economy	14000.00
0005435215140	7756	Economy	14000.00
0005435725720	7756	Economy	14000.00
0005435283465	7756	Economy	14000.00
0005435215294	7756	Economy	14000.00
0005435215184	7756	Economy	14000.00
0005435215499	7756	Economy	14000.00
0005435215258	7756	Economy	14000.00
0005435725708	7756	Economy	14000.00
0005434656605	5349	Business	43100.00
0005435426833	5349	Business	43100.00
0005435426724	5349	Business	43100.00
0005434245782	5349	Business	43100.00
0005434245753	5349	Business	43100.00
0005434245745	5349	Business	43100.00
0005435305079	5349	Business	43100.00
0005435426669	5349	Comfort	24400.00
0005435426723	5349	Comfort	24400.00
0005435319797	5349	Comfort	24400.00
0005435305077	5349	Comfort	24400.00
0005435380432	5349	Comfort	24400.00
0005435042931	5349	Comfort	24400.00
0005432363501	5349	Comfort	24400.00
0005434245728	5349	Comfort	24400.00
0005434245713	5349	Comfort	24400.00
0005434245819	5349	Comfort	24400.00
0005435305080	5349	Comfort	24400.00
0005435319796	5349	Comfort	24400.00
0005434245729	5349	Economy	14400.00
0005435426735	5349	Economy	14400.00
0005435426779	5349	Economy	14400.00
0005435426727	5349	Economy	14400.00
0005435042932	5349	Economy	14400.00
0005435426802	5349	Economy	14400.00
0005435426594	5349	Economy	14400.00
0005435426801	5349	Economy	14400.00
0005435426765	5349	Economy	14400.00
0005435380426	5349	Economy	14400.00
0005435380427	5349	Economy	14400.00
0005435426671	5349	Economy	14400.00
0005435426751	5349	Economy	14400.00
0005435426345	5349	Economy	14400.00
0005434245756	5349	Economy	14400.00
0005435426720	5349	Economy	14400.00
0005433719210	5349	Economy	14400.00
0005435426753	5349	Economy	14400.00
0005435426731	5349	Economy	14400.00
0005435426713	5349	Economy	14400.00
0005434245602	5349	Economy	14400.00
0005434245676	5349	Economy	14400.00
0005435426726	5349	Economy	14400.00
0005435426780	5349	Economy	14400.00
0005435426661	5349	Economy	14400.00
0005435042933	5349	Economy	14400.00
0005435426732	5349	Economy	14400.00
0005434245776	5349	Economy	14400.00
0005434245770	5349	Economy	14400.00
0005434245784	5349	Economy	14400.00
0005435768120	5349	Economy	14400.00
0005435426825	5349	Economy	14400.00
0005435302327	5349	Economy	14400.00
0005434245684	5349	Economy	14400.00
0005432363502	5349	Economy	14400.00
0005435305078	5349	Economy	14400.00
0005434245622	5349	Economy	14400.00
0005434245623	5349	Economy	14400.00
0005435426733	5349	Economy	14400.00
0005434573779	5349	Economy	15800.00
0005435426754	5349	Economy	14400.00
0005432363511	5349	Economy	14400.00
0005435380431	5349	Economy	14400.00
0005435426607	5349	Economy	14400.00
0005435426668	5349	Economy	14400.00
0005435426736	5349	Economy	14400.00
0005432363503	5349	Economy	14400.00
0005435426832	5349	Economy	14400.00
0005435426748	5349	Economy	14400.00
0005435426752	5349	Economy	14400.00
0005432363510	5349	Economy	14400.00
0005435426577	5349	Economy	14400.00
0005434573778	5349	Economy	14400.00
0005435768119	5349	Economy	14400.00
0005432841069	5349	Economy	14400.00
0005432363500	5349	Economy	14400.00
0005435426760	5349	Economy	14400.00
0005435426766	5349	Economy	14400.00
0005433719231	5349	Economy	14400.00
0005435426606	5349	Economy	14400.00
0005435426683	5349	Economy	14400.00
0005434245677	5349	Economy	14400.00
0005432363493	5349	Economy	14400.00
0005434345042	10893	Business	43100.00
0005434345173	10893	Business	43100.00
0005435097488	10893	Business	43100.00
0005435616592	10893	Business	43100.00
0005435654522	10893	Business	43100.00
0005435616532	10893	Business	43100.00
0005435616940	10893	Business	43100.00
0005435616656	10893	Business	43100.00
0005434345092	10893	Business	43100.00
0005434345197	10893	Comfort	24400.00
0005435616676	10893	Comfort	24400.00
0005435616531	10893	Comfort	24400.00
0005434345152	10893	Comfort	24400.00
0005434345160	10893	Comfort	24400.00
0005435616728	10893	Comfort	24400.00
0005434345076	10893	Comfort	24400.00
0005434573726	10893	Comfort	24400.00
0005435616601	10893	Comfort	24400.00
0005435097428	10893	Comfort	24400.00
0005434345164	10893	Comfort	24400.00
0005434344936	10893	Comfort	24400.00
0005435097453	10893	Comfort	24400.00
0005434345161	10893	Comfort	24400.00
0005435616673	10893	Comfort	24400.00
0005435616648	10893	Comfort	24400.00
0005435097446	10893	Comfort	24400.00
0005434345199	10893	Comfort	24400.00
0005435097427	10893	Comfort	24400.00
0005435490331	10893	Economy	14400.00
0005435654523	10893	Economy	14400.00
0005435617195	10893	Economy	14400.00
0005435616982	10893	Economy	14400.00
0005435097439	10893	Economy	14400.00
0005435097456	10893	Economy	14400.00
0005434573695	10893	Economy	14400.00
0005435616732	10893	Economy	14400.00
0005435616536	10893	Economy	14400.00
0005435097465	10893	Economy	14400.00
0005435097436	10893	Economy	14400.00
0005434345153	10893	Economy	14400.00
0005434345227	10893	Economy	14400.00
0005435616868	10893	Economy	14400.00
0005435616504	10893	Economy	14400.00
0005434573722	10893	Economy	14400.00
0005434345012	10893	Economy	14400.00
0005435616567	10893	Economy	14400.00
0005434573706	10893	Economy	14400.00
0005434573746	10893	Economy	14400.00
0005434345133	10893	Economy	14400.00
0005435616986	10893	Economy	14400.00
0005434345077	10893	Economy	14400.00
0005435616874	10893	Economy	14400.00
0005435654521	10893	Economy	14400.00
0005435617017	10893	Economy	14400.00
0005435616755	10893	Economy	14400.00
0005435616812	10893	Economy	14400.00
0005435616465	10893	Economy	14400.00
0005435616662	10893	Economy	14400.00
0005434573738	10893	Economy	14400.00
0005435616642	10893	Economy	14400.00
0005434345128	10893	Economy	14400.00
0005434345252	10893	Economy	14400.00
0005435617016	10893	Economy	14400.00
0005434345222	10893	Economy	14400.00
0005435097476	10893	Economy	14400.00
0005435097464	10893	Economy	14400.00
0005435616615	10893	Economy	14400.00
0005435616577	10893	Economy	14400.00
0005434344949	10893	Economy	14400.00
0005435616813	10893	Economy	14400.00
0005435616724	10893	Economy	14400.00
0005435616050	10893	Economy	14400.00
0005435616488	10893	Economy	14400.00
0005434573710	10893	Economy	14400.00
0005435616987	10893	Economy	14400.00
0005434345013	10893	Economy	14400.00
0005435616165	10893	Economy	14400.00
0005434345172	10893	Economy	14400.00
0005435616701	10893	Economy	14400.00
0005435616939	10893	Economy	14400.00
0005435097457	10893	Economy	14400.00
0005434345049	10893	Economy	14400.00
0005435491502	10893	Economy	14400.00
0005434345107	10893	Economy	14400.00
0005435616890	10893	Economy	14400.00
0005435616545	10893	Economy	14400.00
0005435616617	10893	Economy	14400.00
0005435616916	10893	Economy	14400.00
0005435616616	10893	Economy	14400.00
0005435616825	10893	Economy	14400.00
0005434345167	10893	Economy	14400.00
0005435616636	10893	Economy	14400.00
0005435490338	10893	Economy	14400.00
0005435615988	10893	Economy	14400.00
0005434573743	10893	Economy	14400.00
0005435616587	10893	Economy	15800.00
0005435617190	10893	Economy	15800.00
0005434345140	10893	Economy	15800.00
0005434345198	10893	Economy	15800.00
0005435616641	10893	Economy	14400.00
0005434345122	10893	Economy	14400.00
0005435617197	10893	Economy	14400.00
0005434345043	10893	Economy	14400.00
0005434345200	10893	Economy	14400.00
0005435616791	10893	Economy	14400.00
0005435616611	10893	Economy	14400.00
0005435616979	10893	Economy	14400.00
0005435616900	10893	Economy	14400.00
0005435616899	10893	Economy	14400.00
0005435097487	10893	Economy	14400.00
0005434345171	10893	Economy	14400.00
0005435490339	10893	Economy	14400.00
0005434573715	10893	Economy	14400.00
0005435616682	10893	Economy	14400.00
0005435616717	10893	Economy	14400.00
0005435616754	10893	Economy	14400.00
0005434345105	10893	Economy	14400.00
0005435491499	10893	Economy	14400.00
0005435616612	10893	Economy	14400.00
0005435616675	10893	Economy	14400.00
0005434345151	10893	Economy	14400.00
0005435491500	10893	Economy	14400.00
0005434345093	10893	Economy	14400.00
0005435616195	10893	Economy	14400.00
0005435491504	10893	Economy	14400.00
0005435616700	10893	Economy	14400.00
0005435616588	10893	Economy	14400.00
0005435097466	10893	Economy	14400.00
0005435097454	10893	Economy	14400.00
0005434573716	10893	Economy	14400.00
0005435490313	10893	Economy	14400.00
0005435616852	10893	Economy	14400.00
0005435616928	10893	Economy	14400.00
0005434345201	10893	Economy	14400.00
0005435617203	10893	Economy	14400.00
0005435616921	10893	Economy	14400.00
0005435142988	3350	Business	18800.00
0005435858726	3350	Business	18800.00
0005432461123	3350	Business	18800.00
0005435858706	3350	Business	18800.00
0005432461169	3350	Business	18800.00
0005435860690	3350	Business	18800.00
0005435142998	3350	Business	18800.00
0005432461138	3350	Business	18800.00
0005435860661	3350	Business	18800.00
0005432461202	3350	Business	18800.00
0005435854088	3350	Business	18800.00
0005432461190	3350	Business	18800.00
0005435858737	3350	Economy	6900.00
0005435933585	3350	Economy	6900.00
0005432461292	3350	Economy	6900.00
0005435142989	3350	Economy	6900.00
0005434312393	3350	Economy	6300.00
0005432461102	3350	Economy	6300.00
0005435143000	3350	Economy	6300.00
0005435933581	3350	Economy	6300.00
0005435860711	3350	Economy	6300.00
0005435860702	3350	Economy	6300.00
0005432461266	3350	Economy	6300.00
0005435856347	3350	Economy	6300.00
0005432461201	3350	Economy	6300.00
0005433806412	3350	Economy	6300.00
0005432461382	3350	Economy	6300.00
0005432461284	3350	Economy	6300.00
0005434326059	3350	Economy	6300.00
0005432461108	3350	Economy	6300.00
0005434312391	3350	Economy	6300.00
0005432461305	3350	Economy	6300.00
0005435858739	3350	Economy	6300.00
0005435858715	3350	Economy	6300.00
0005435858738	3350	Economy	6300.00
0005432461399	3350	Economy	6300.00
0005434312395	3350	Economy	6300.00
0005432461220	3350	Economy	6300.00
0005435860671	3350	Economy	6300.00
0005435860701	3350	Economy	6300.00
0005434312396	3350	Economy	6300.00
0005432461168	3350	Economy	6900.00
0005432461325	3350	Economy	6900.00
0005432461402	3350	Economy	6900.00
0005432461203	3350	Economy	6900.00
0005432461332	3350	Economy	6300.00
0005434312394	3350	Economy	6300.00
0005432461400	3350	Economy	6300.00
0005435860668	3350	Economy	6300.00
0005435933575	3350	Economy	6900.00
0005432461334	3350	Economy	6300.00
0005432461366	3350	Economy	6300.00
0005432461367	3350	Economy	6300.00
0005435933573	3350	Economy	6300.00
0005432461333	3350	Economy	6300.00
0005432461294	3350	Economy	6300.00
0005435860713	3350	Economy	6300.00
0005435858733	3350	Economy	6300.00
0005435856356	3350	Economy	6300.00
0005432461274	3350	Economy	6300.00
0005434326058	3350	Economy	6300.00
0005432461295	3350	Economy	6300.00
0005432461273	3350	Economy	6300.00
0005432461198	3350	Economy	6300.00
0005435854090	3350	Economy	6300.00
0005432461293	3350	Economy	6300.00
0005432461200	3350	Economy	6300.00
0005435860682	3350	Economy	6300.00
0005432461234	3350	Economy	6300.00
0005432461100	3350	Economy	6300.00
0005435858732	3350	Economy	6300.00
0005432461401	3350	Economy	6300.00
0005432461397	3350	Economy	6300.00
0005435860712	3350	Economy	6300.00
0005432461167	3350	Economy	6300.00
0005435142999	3350	Economy	6300.00
0005432461272	3350	Economy	6300.00
0005432461101	3350	Economy	6300.00
0005435860689	3350	Economy	6300.00
0005432461331	3350	Economy	6300.00
0005432461398	3350	Economy	6300.00
0005432461219	3350	Economy	6300.00
0005435886360	3351	Business	18800.00
0005435886711	3351	Business	18800.00
0005435886776	3351	Business	18800.00
0005435886692	3351	Business	18800.00
0005435886738	3351	Business	18800.00
0005435886663	3351	Business	18800.00
0005435886809	3351	Business	18800.00
0005435886718	3351	Economy	6300.00
0005435886710	3351	Economy	6300.00
0005435886727	3351	Economy	6300.00
0005435886624	3351	Economy	6300.00
0005435886728	3351	Economy	6300.00
0005435886612	3351	Economy	6300.00
0005435903227	3351	Economy	6300.00
0005435886693	3351	Economy	6300.00
0005435886767	3351	Economy	6300.00
0005435903234	3351	Economy	6300.00
0005435886730	3351	Economy	6300.00
0005435939978	3351	Economy	6300.00
0005435886533	3351	Economy	6300.00
0005435886603	3351	Economy	6300.00
0005435886717	3351	Economy	6300.00
0005435886830	3351	Economy	6300.00
0005435886816	3351	Economy	6300.00
0005435886729	3351	Economy	6300.00
0005435886486	3351	Economy	6300.00
0005435886380	3351	Economy	6300.00
0005435903228	3351	Economy	6300.00
0005435886832	3351	Economy	6900.00
0005435886626	3351	Economy	6900.00
0005435886833	3351	Economy	6300.00
0005435886576	3351	Economy	6300.00
0005435886811	3351	Economy	6300.00
0005435886594	3351	Economy	6300.00
0005435886810	3351	Economy	6300.00
0005435886739	3351	Economy	6300.00
0005435886777	3351	Economy	6300.00
0005435886736	3351	Economy	6300.00
0005435886750	3351	Economy	6300.00
0005435886771	3351	Economy	6300.00
0005435886563	3351	Economy	6300.00
0005435886487	3351	Economy	6300.00
0005435886808	3351	Economy	6300.00
0005435886807	3351	Economy	6300.00
0005435886708	3351	Economy	6300.00
0005435886625	3351	Economy	6300.00
0005435886721	3351	Economy	6300.00
0005435886664	3351	Economy	6300.00
0005435886759	3351	Economy	6300.00
0005435886520	3351	Economy	6300.00
0005435886497	3351	Economy	6300.00
0005435886465	3351	Economy	6300.00
0005435939977	3351	Economy	6300.00
0005435886524	3351	Economy	6300.00
0005433507635	8319	Business	18800.00
0005433507680	8319	Economy	6900.00
0005433507683	8319	Economy	6300.00
0005433507614	8319	Economy	6300.00
0005435886873	8319	Economy	6300.00
0005433507670	8319	Economy	6300.00
0005433507727	8319	Economy	6300.00
0005433507634	8319	Economy	6300.00
0005433507673	8319	Economy	6300.00
0005433507652	8319	Economy	6900.00
0005433507697	8319	Economy	6300.00
0005433507674	8319	Economy	6300.00
0005433507684	8319	Economy	6300.00
0005433507682	8319	Economy	6300.00
0005433507660	8319	Economy	6300.00
0005433507675	8319	Economy	6300.00
0005434271372	8317	Business	18800.00
0005433634779	8317	Business	18800.00
0005433634812	8317	Business	18800.00
0005433634700	8317	Business	18800.00
0005433634728	8317	Business	18800.00
0005433806343	8317	Business	18800.00
0005433634807	8317	Business	18800.00
0005433634757	8317	Business	18800.00
0005434143800	8317	Economy	6900.00
0005433634692	8317	Economy	6900.00
0005434143798	8317	Economy	6900.00
0005433634802	8317	Economy	6300.00
0005433634711	8317	Economy	6300.00
0005433806327	8317	Economy	6300.00
0005433806278	8317	Economy	6300.00
0005433634633	8317	Economy	6300.00
0005433634778	8317	Economy	6300.00
0005433634693	8317	Economy	6300.00
0005433634767	8317	Economy	6300.00
0005434143793	8317	Economy	6300.00
0005434143801	8317	Economy	6300.00
0005433634653	8317	Economy	6300.00
0005433634805	8317	Economy	6300.00
0005433806380	8317	Economy	6300.00
0005434143806	8317	Economy	6300.00
0005434271373	8317	Economy	6300.00
0005434271364	8317	Economy	6300.00
0005434271371	8317	Economy	6900.00
0005434143802	8317	Economy	6300.00
0005433806328	8317	Economy	6300.00
0005433634735	8317	Economy	6300.00
0005433634719	8317	Economy	6300.00
0005434271375	8317	Economy	6300.00
0005433634756	8317	Economy	6300.00
0005434143809	8317	Economy	6300.00
0005433634722	8317	Economy	6300.00
0005433634736	8317	Economy	6300.00
0005434143807	8317	Economy	6300.00
0005433634694	8317	Economy	6300.00
0005433806318	8317	Economy	6300.00
0005433806216	8317	Economy	6300.00
0005434271374	8317	Economy	6300.00
0005433634567	8317	Economy	6300.00
0005433634710	8317	Economy	6300.00
0005433634632	8317	Economy	6300.00
0005434143781	8317	Economy	6300.00
0005434143843	8317	Economy	6300.00
0005434143808	8317	Economy	6300.00
0005433806215	8317	Economy	6300.00
0005433634701	8317	Economy	6300.00
0005433634772	8317	Economy	6300.00
0005433634768	8317	Economy	6300.00
0005433634806	8317	Economy	6300.00
0005433634721	8317	Economy	6300.00
0005434271363	8317	Economy	6300.00
0005434143785	8317	Economy	6300.00
0005434143797	8317	Economy	6300.00
0005433806281	8317	Economy	6300.00
0005434265968	8315	Business	18800.00
0005434265969	8315	Business	18800.00
0005434150174	8315	Economy	6300.00
0005434265958	8315	Economy	6300.00
0005434150164	8315	Economy	6300.00
0005434183638	8315	Economy	6300.00
0005434265938	8315	Economy	6300.00
0005434265937	8315	Economy	6300.00
0005434265940	8315	Economy	6300.00
0005434183639	8315	Economy	6300.00
0005434150182	8315	Economy	6300.00
0005434150211	8315	Economy	6300.00
0005434150199	8315	Economy	6300.00
0005434265932	8315	Economy	6300.00
0005434150173	8315	Economy	6300.00
0005434265947	8315	Economy	6900.00
0005434265955	8315	Economy	6900.00
0005434150162	8315	Economy	6300.00
0005434150206	8315	Economy	6300.00
0005434150181	8315	Economy	6300.00
0005434150221	8315	Economy	6300.00
0005434265973	8315	Economy	6300.00
0005434150163	8315	Economy	6300.00
0005434150180	8315	Economy	6300.00
0005434150212	8315	Economy	6300.00
0005434265939	8315	Economy	6300.00
0005434230046	8315	Economy	6300.00
0005434265948	8315	Economy	6300.00
0005432384343	4534	Economy	3300.00
0005433194974	30092	Business	9900.00
0005432728254	30092	Business	9900.00
0005432383962	30092	Business	9900.00
0005433722374	30092	Business	9900.00
0005432384059	30092	Business	9900.00
0005433722395	30092	Business	9900.00
0005433194976	30092	Business	9900.00
0005433722424	30092	Business	9900.00
0005433194948	30092	Business	9900.00
0005433722423	30092	Business	9900.00
0005433194988	30092	Economy	3300.00
0005433722360	30092	Economy	3300.00
0005432384171	30092	Economy	3300.00
0005433722371	30092	Economy	3300.00
0005433722394	30092	Economy	3300.00
0005432384247	30092	Economy	3300.00
0005432384144	30092	Economy	3300.00
0005433722358	30092	Economy	3300.00
0005432384127	30092	Economy	3600.00
0005432384209	30092	Economy	3600.00
0005432384079	30092	Economy	3600.00
0005433722359	30092	Economy	3300.00
0005432383993	30092	Economy	3300.00
0005433194947	30092	Economy	3300.00
0005432384126	30092	Economy	3300.00
0005433194958	30092	Economy	3300.00
0005432384089	30092	Economy	3300.00
0005433194955	30092	Economy	3300.00
0005432384178	30092	Economy	3300.00
0005432384269	30092	Economy	3300.00
0005432384146	30092	Economy	3300.00
0005433722407	30092	Economy	3300.00
0005432384168	30092	Economy	3300.00
0005432383997	30092	Economy	3300.00
0005432384191	30092	Economy	3300.00
0005433194969	30092	Economy	3300.00
0005433722396	30092	Economy	3300.00
0005433722409	30092	Economy	3300.00
0005432384105	30092	Economy	3300.00
0005432384208	30092	Economy	3300.00
0005432728289	30092	Economy	3300.00
0005432384090	30092	Economy	3300.00
0005433453818	30092	Economy	3300.00
0005433722422	30092	Economy	3300.00
0005432383996	30092	Economy	3300.00
0005432384143	30092	Economy	3300.00
0005432384192	30092	Economy	3300.00
0005432384048	30092	Economy	3300.00
0005432728291	30092	Economy	3300.00
0005432728255	30092	Economy	3300.00
0005433451677	30092	Economy	3300.00
0005432384121	30092	Economy	3300.00
0005432728290	30092	Economy	3300.00
0005432384078	30092	Economy	3300.00
0005433194968	30092	Economy	3300.00
0005432384200	30092	Economy	3300.00
0005432384094	30092	Economy	3300.00
0005432383986	30092	Economy	3300.00
0005432728245	30092	Economy	3300.00
0005432384130	30092	Economy	3300.00
0005433194931	30092	Economy	3300.00
0005432383963	30092	Economy	3300.00
0005433451678	30092	Economy	3300.00
0005433722384	30092	Economy	3300.00
0005432384199	30092	Economy	3300.00
0005433194987	30092	Economy	3300.00
0005432384145	30092	Economy	3300.00
0005433722393	30092	Economy	3300.00
0005432384268	30092	Economy	3300.00
0005432925178	1745	Business	57200.00
0005435529901	1745	Economy	21000.00
0005432925176	1745	Economy	19100.00
0005432925177	1745	Economy	19100.00
0005432925166	1745	Economy	19100.00
0005435518426	21982	Business	57200.00
0005435541520	21982	Business	57200.00
0005435541607	21982	Business	57200.00
0005435541528	21982	Business	57200.00
0005435518334	21982	Business	57200.00
0005435518356	21982	Economy	19100.00
0005435541592	21982	Economy	19100.00
0005435518389	21982	Economy	19100.00
0005433517149	21982	Economy	19100.00
0005435518335	21982	Economy	19100.00
0005433517134	21982	Economy	21000.00
0005435541612	21982	Economy	21000.00
0005435518354	21982	Economy	21000.00
0005435541599	21982	Economy	19100.00
0005435518407	21982	Economy	19100.00
0005433517136	21982	Economy	19100.00
0005435518449	21982	Economy	19100.00
0005435518435	21982	Economy	19100.00
0005435541488	21982	Economy	19100.00
0005435541600	21982	Economy	19100.00
0005435518355	21982	Economy	19100.00
0005435518395	21982	Economy	19100.00
0005435518336	21982	Economy	19100.00
0005435541521	21982	Economy	19100.00
0005435518383	21982	Economy	19100.00
0005435518452	21982	Economy	19100.00
0005435518390	21982	Economy	19100.00
0005435541621	21982	Economy	19100.00
0005435541529	21982	Economy	19100.00
0005435518408	21982	Economy	19100.00
0005435541606	21982	Economy	19100.00
0005435518425	21982	Economy	19100.00
0005435518394	21982	Economy	19100.00
0005435518301	21982	Economy	19100.00
0005433517135	21982	Economy	19100.00
0005435541484	21982	Economy	19100.00
0005435518448	21982	Economy	19100.00
0005435518351	21982	Economy	19100.00
0005435541584	21982	Economy	19100.00
0005435518416	21982	Economy	19100.00
0005435541598	21982	Economy	19100.00
0005435253209	7380	Business	18500.00
0005435253202	7380	Business	18500.00
0005435253204	7380	Business	18500.00
0005435253186	7380	Economy	6200.00
0005435253126	7380	Economy	6800.00
0005435253194	7380	Economy	6200.00
0005435253187	7380	Economy	6200.00
0005435253167	7380	Economy	6200.00
0005434665017	7380	Economy	6200.00
0005435253178	7380	Economy	6200.00
0005435253185	7380	Economy	6200.00
0005435253179	7380	Economy	6200.00
0005435253201	7380	Economy	6200.00
0005434665022	7380	Economy	6200.00
0005435253212	7380	Economy	6200.00
0005435253182	7380	Economy	6200.00
0005432839930	28925	Business	18500.00
0005432839837	28925	Business	18500.00
0005434459382	28925	Business	18500.00
0005432839813	28925	Business	18500.00
0005434459328	28925	Business	18500.00
0005432839914	28925	Economy	6200.00
0005434459420	28925	Economy	6200.00
0005434459390	28925	Economy	6200.00
0005434459359	28925	Economy	6200.00
0005434459372	28925	Economy	6200.00
0005432839910	28925	Economy	6200.00
0005434459377	28925	Economy	6200.00
0005432839909	28925	Economy	6200.00
0005432839915	28925	Economy	6200.00
0005434459325	28925	Economy	6200.00
0005432823506	28925	Economy	6200.00
0005432839826	28925	Economy	6200.00
0005432839785	28925	Economy	6200.00
0005432839905	28925	Economy	6200.00
0005432839878	28925	Economy	6200.00
0005432839928	28925	Economy	6200.00
0005432839927	28925	Economy	6200.00
0005432823505	28925	Economy	6200.00
0005432839913	28925	Economy	6200.00
0005434459360	28925	Economy	6200.00
0005434459414	28925	Economy	6200.00
0005434459392	28925	Economy	6200.00
0005434459329	28925	Economy	6200.00
0005432839929	28925	Economy	6200.00
0005434459340	28925	Economy	6200.00
0005432839838	28925	Economy	6200.00
0005434459419	28925	Economy	6200.00
0005434459342	28925	Economy	6200.00
0005432839850	28925	Economy	6200.00
0005432839839	28925	Economy	6200.00
0005434459350	28925	Economy	6200.00
0005432841070	28925	Economy	6200.00
0005432839937	28925	Economy	6200.00
0005432839938	28925	Economy	6200.00
0005434276177	8778	Economy	48400.00
0005434276176	8778	Economy	48400.00
0005432427187	30860	Economy	15900.00
0005432427203	30860	Economy	14500.00
0005432427199	30860	Economy	14500.00
0005432427198	30860	Economy	14500.00
0005432427204	30860	Economy	14500.00
0005432427193	30860	Economy	14500.00
0005432427201	30860	Economy	14500.00
0005432427197	30860	Economy	14500.00
0005432427202	30860	Economy	14500.00
0005433468540	23831	Economy	13300.00
0005433468599	23831	Economy	13300.00
0005433468574	23831	Economy	12100.00
0005433468580	23831	Economy	12100.00
0005433468572	23831	Economy	12100.00
0005433468586	23831	Economy	12100.00
0005433468582	23831	Economy	12100.00
0005433468581	23831	Economy	12100.00
0005433468573	23831	Economy	12100.00
0005433468579	23831	Economy	12100.00
0005433468571	23831	Economy	12100.00
0005433468546	23831	Economy	12100.00
0005433468568	23831	Economy	12100.00
0005433468592	23831	Economy	12100.00
0005433468600	23831	Economy	12100.00
0005433468545	23831	Economy	12100.00
0005434150074	6396	Business	36600.00
0005434150050	6396	Business	36600.00
0005435177856	6396	Business	36600.00
0005435723093	6396	Economy	12200.00
0005435177755	6396	Economy	12200.00
0005434150047	6396	Economy	12200.00
0005435177865	6396	Economy	12200.00
0005435177761	6396	Economy	12200.00
0005434150059	6396	Economy	12200.00
0005435490313	6396	Economy	12200.00
0005435177812	6396	Economy	12200.00
0005435723101	6396	Economy	12200.00
0005435177842	6396	Economy	12200.00
0005435177795	6396	Economy	12200.00
0005435490331	6396	Economy	13400.00
0005435177821	6396	Economy	12200.00
0005435177843	6396	Economy	12200.00
0005434150058	6396	Economy	12200.00
0005435177832	6396	Economy	12200.00
0005435177796	6396	Economy	12200.00
0005434150016	6396	Economy	12200.00
0005434150073	6396	Economy	12200.00
0005435490339	6396	Economy	12200.00
0005434150015	6396	Economy	12200.00
0005435177799	6396	Economy	12200.00
0005435490338	6396	Economy	12200.00
0005434150066	6396	Economy	12200.00
0005435177864	6396	Economy	12200.00
0005435177849	6396	Economy	12200.00
0005432361668	21024	Business	36600.00
0005432363504	21024	Business	36600.00
0005432361707	21024	Business	36600.00
0005432336369	21024	Business	36600.00
0005432361708	21024	Economy	12200.00
0005432361496	21024	Economy	12200.00
0005432363516	21024	Economy	12200.00
0005432361650	21024	Economy	12200.00
0005432361706	21024	Economy	12200.00
0005432363515	21024	Economy	12200.00
0005432361597	21024	Economy	12200.00
0005432336363	21024	Economy	12200.00
0005432361692	21024	Economy	12200.00
0005432361705	21024	Economy	12200.00
0005432336370	21024	Economy	12200.00
0005432361497	21024	Economy	12200.00
0005432361613	21024	Economy	12200.00
0005432361694	21024	Economy	12200.00
0005432361703	21024	Economy	12200.00
0005432336374	21024	Economy	12200.00
0005432361734	21024	Economy	12200.00
0005432336364	21024	Economy	12200.00
0005432361574	21024	Economy	12200.00
0005432361489	21024	Economy	12200.00
0005432361649	21024	Economy	12200.00
0005432361575	21024	Economy	12200.00
0005432361685	21024	Economy	12200.00
0005432336384	21024	Economy	12200.00
0005432336355	21024	Economy	12200.00
0005432361693	21024	Economy	12200.00
0005432361695	21024	Economy	12200.00
0005432361710	21024	Economy	12200.00
0005432361718	21024	Economy	12200.00
0005432361709	21024	Economy	12200.00
0005432336354	21024	Economy	12200.00
0005432361719	21024	Economy	12200.00
0005432336291	21024	Economy	12200.00
0005432361638	21024	Economy	12200.00
0005432361490	21024	Economy	12200.00
0005432361749	21024	Economy	12200.00
0005434459399	17706	Economy	3100.00
0005434448415	17706	Economy	3100.00
0005434459391	17706	Economy	3100.00
0005434448413	17706	Economy	3100.00
0005434448403	17706	Economy	3100.00
0005434461699	17706	Economy	3100.00
0005434459374	17706	Economy	3100.00
0005434461701	17706	Economy	3100.00
0005434448414	17706	Economy	3100.00
0005434461700	17706	Economy	3100.00
0005434459338	17706	Economy	3100.00
0005434459403	17706	Economy	3100.00
0005434186273	29119	Economy	3100.00
0005432661949	21829	Business	185300.00
0005432661963	21829	Business	185300.00
0005432658620	21829	Business	185300.00
0005432665311	21829	Business	185300.00
0005432661972	21829	Business	185300.00
0005432665319	21829	Business	185300.00
0005432661956	21829	Business	185300.00
0005432661955	21829	Business	185300.00
0005432658641	21829	Economy	61800.00
0005432661959	21829	Economy	61800.00
0005432661967	21829	Economy	61800.00
0005432658624	21829	Economy	61800.00
0005432665315	21829	Economy	61800.00
0005432661969	21829	Economy	61800.00
0005432661957	21829	Economy	67900.00
0005432665312	21829	Economy	67900.00
0005432661947	21829	Economy	67900.00
0005432661958	21829	Economy	61800.00
0005432665323	21829	Economy	61800.00
0005432658630	21829	Economy	61800.00
0005432658639	21829	Economy	61800.00
0005432658635	21829	Economy	61800.00
0005432658622	21829	Economy	61800.00
0005432665314	21829	Economy	61800.00
0005432665307	21829	Economy	61800.00
0005432661964	21829	Economy	61800.00
0005432661971	21829	Economy	61800.00
0005432665309	21829	Economy	61800.00
0005432658631	21829	Economy	61800.00
0005432661966	21829	Economy	61800.00
0005432661968	21829	Economy	61800.00
0005432658621	21829	Economy	61800.00
0005432665310	21829	Economy	61800.00
0005432658640	21829	Economy	61800.00
0005432661962	21829	Economy	61800.00
0005432658637	21829	Economy	61800.00
0005432661948	21829	Economy	61800.00
0005432661973	21829	Economy	61800.00
0005432658633	21829	Economy	61800.00
0005432661970	21829	Economy	61800.00
0005432661954	21829	Economy	61800.00
0005432658618	21829	Economy	61800.00
0005432661961	21829	Economy	61800.00
0005432658629	21829	Economy	61800.00
0005432665306	21829	Economy	61800.00
0005432658634	21829	Economy	61800.00
0005432665308	21829	Economy	61800.00
0005432661974	21829	Economy	61800.00
0005432658625	21829	Economy	61800.00
0005432658636	21829	Economy	61800.00
0005432658619	21829	Economy	61800.00
0005432665322	21829	Economy	61800.00
0005432658638	21829	Economy	61800.00
0005432665299	21829	Economy	61800.00
0005435218142	21430	Economy	7300.00
0005432605517	21430	Economy	6600.00
0005435218131	21430	Economy	6600.00
0005435218138	21430	Economy	6600.00
0005435220513	21430	Economy	6600.00
0005435218130	21430	Economy	6600.00
0005432605516	21430	Economy	6600.00
0005432605518	21430	Economy	6600.00
0005435220519	21430	Economy	6600.00
0005432605224	31662	Economy	7300.00
0005432605472	31662	Economy	7300.00
0005432605460	31662	Economy	7300.00
0005432605448	31662	Economy	6600.00
0005432605476	31662	Economy	6600.00
0005432605430	31662	Economy	6600.00
0005432605355	31662	Economy	6600.00
0005432605475	31662	Economy	6600.00
0005432605461	31662	Economy	6600.00
0005432605437	31662	Economy	6600.00
0005432605455	31662	Economy	6600.00
0005432605255	31662	Economy	6600.00
0005432605366	31662	Economy	6600.00
0005432605421	31662	Economy	6600.00
0005432605420	31662	Economy	6600.00
0005432605301	31662	Economy	6600.00
0005432605423	31662	Economy	6600.00
0005432605337	31662	Economy	6600.00
0005432605474	31662	Economy	6600.00
0005432605410	31662	Economy	6600.00
0005432605438	31662	Economy	6600.00
0005432605436	31662	Economy	6600.00
0005432605308	31662	Economy	6600.00
0005432605411	31662	Economy	6600.00
0005432605393	31662	Economy	6600.00
0005432605398	31662	Economy	6600.00
0005432605435	31662	Economy	6600.00
0005432605399	31662	Economy	6600.00
0005432605336	31662	Economy	6600.00
0005432605419	31662	Economy	6600.00
0005432605302	31662	Economy	6600.00
0005432605389	31662	Economy	6600.00
0005432605353	31662	Economy	6600.00
0005432605368	31662	Economy	6600.00
0005432605471	31662	Economy	6600.00
0005432605462	31662	Economy	6600.00
0005435154676	29608	Economy	17800.00
0005435154670	29608	Economy	17800.00
0005435154690	29608	Economy	17800.00
0005435154700	29608	Economy	17800.00
0005435154675	29608	Economy	17800.00
0005435257369	6686	Economy	14000.00
0005435257368	6686	Economy	14000.00
0005435257367	6686	Economy	12700.00
0005435257373	6686	Economy	12700.00
0005435257389	6686	Economy	12700.00
0005435257374	6686	Economy	12700.00
0005435257387	6686	Economy	12700.00
0005435257365	6686	Economy	12700.00
0005435257388	6686	Economy	12700.00
0005435257376	6686	Economy	12700.00
0005433473507	23887	Economy	14000.00
0005433473515	23887	Economy	14000.00
0005433473520	23887	Economy	12700.00
0005433473519	23887	Economy	12700.00
0005433473506	23887	Economy	12700.00
0005433473483	23887	Economy	12700.00
0005433473502	23887	Economy	12700.00
0005433473496	23887	Economy	12700.00
0005433473504	23887	Economy	12700.00
0005433473503	23887	Economy	12700.00
0005433473501	23887	Economy	12700.00
0005433473497	23887	Economy	12700.00
0005433473535	23887	Economy	12700.00
0005433473534	23887	Economy	12700.00
0005433473488	23887	Economy	12700.00
0005433473487	23887	Economy	12700.00
0005433473531	23887	Economy	12700.00
0005433473498	23887	Economy	12700.00
0005433473484	23887	Economy	12700.00
0005433473489	23887	Economy	12700.00
0005433473530	23887	Economy	12700.00
0005434606922	18896	Economy	6600.00
0005435904909	22291	Economy	6600.00
0005435904913	22291	Economy	6600.00
0005435904467	3861	Economy	22600.00
0005434602972	19057	Economy	24900.00
0005434602967	19057	Economy	24900.00
0005434605004	19057	Economy	24900.00
0005434605005	19057	Economy	22600.00
0005434604990	19057	Economy	22600.00
0005434602971	19057	Economy	22600.00
0005434522547	19057	Economy	22600.00
0005434604985	19057	Economy	22600.00
0005434602969	19057	Economy	22600.00
0005434604987	19057	Economy	22600.00
0005434604984	19057	Economy	22600.00
0005434522553	19057	Economy	22600.00
0005434605006	19057	Economy	22600.00
0005434602959	19057	Economy	22600.00
0005434604968	19057	Economy	22600.00
0005434602958	19057	Economy	22600.00
0005434604999	19057	Economy	22600.00
0005434522548	19057	Economy	22600.00
0005434602957	19057	Economy	22600.00
0005434604989	19057	Economy	22600.00
0005434522537	19057	Economy	22600.00
0005434604998	19057	Economy	22600.00
0005434522514	19057	Economy	22600.00
0005434604997	19057	Economy	22600.00
0005434604991	19057	Economy	22600.00
0005434604986	19057	Economy	22600.00
0005434602973	19057	Economy	22600.00
0005434604988	19057	Economy	22600.00
0005434602960	19057	Economy	22600.00
0005434151804	413	Economy	14800.00
0005434151807	413	Economy	14800.00
0005434151806	413	Economy	14800.00
0005432891537	413	Economy	16300.00
0005433293418	413	Economy	14800.00
0005432891522	413	Economy	14800.00
0005434151820	413	Economy	14800.00
0005433293421	413	Economy	14800.00
0005432891559	413	Economy	14800.00
0005434151803	413	Economy	14800.00
0005432891519	413	Economy	14800.00
0005432891562	413	Economy	14800.00
0005432891502	413	Economy	14800.00
0005433293434	413	Economy	14800.00
0005432891571	413	Economy	14800.00
0005433293411	413	Economy	14800.00
0005434151805	413	Economy	14800.00
0005434151808	413	Economy	14800.00
0005433293400	413	Economy	14800.00
0005432891501	413	Economy	14800.00
0005432748417	12036	Business	44500.00
0005432753390	12036	Business	44500.00
0005435627131	12036	Business	44500.00
0005432748637	12036	Business	44500.00
0005432748665	12036	Business	44500.00
0005432749844	12036	Economy	14800.00
0005432748676	12036	Economy	14800.00
0005432748415	12036	Economy	14800.00
0005432748416	12036	Economy	14800.00
0005432748629	12036	Economy	14800.00
0005432749845	12036	Economy	14800.00
0005432748482	12036	Economy	14800.00
0005432748636	12036	Economy	14800.00
0005432748659	12036	Economy	14800.00
0005432748614	12036	Economy	14800.00
0005432748524	12036	Economy	14800.00
0005432756936	12036	Economy	14800.00
0005432748632	12036	Economy	14800.00
0005435627129	12036	Economy	14800.00
0005432748666	12036	Economy	14800.00
0005432748667	12036	Economy	14800.00
0005432748621	12036	Economy	14800.00
0005432756918	12036	Economy	14800.00
0005435627132	12036	Economy	14800.00
0005432748615	12036	Economy	14800.00
0005432748620	12036	Economy	14800.00
0005432748641	12036	Economy	14800.00
0005432928132	18969	Economy	28200.00
0005432928133	18969	Economy	25700.00
0005432928140	18969	Economy	25700.00
0005432928123	18969	Economy	25700.00
0005432928127	18969	Economy	25700.00
0005433525364	18969	Economy	25700.00
0005432928139	18969	Economy	25700.00
0005432928124	18969	Economy	25700.00
0005432928118	18969	Economy	25700.00
0005432928138	18969	Economy	25700.00
0005432928117	18969	Economy	25700.00
0005433525293	32517	Economy	28200.00
0005433525316	32517	Economy	28200.00
0005433531402	32517	Economy	25700.00
0005433531399	32517	Economy	25700.00
0005433525353	32517	Economy	25700.00
0005433525292	32517	Economy	25700.00
0005433525333	32517	Economy	25700.00
0005433531401	32517	Economy	25700.00
0005433525351	32517	Economy	25700.00
0005433531400	32517	Economy	25700.00
0005433527363	32517	Economy	25700.00
0005433525300	32517	Economy	25700.00
0005433525349	32517	Economy	25700.00
0005433525350	32517	Economy	25700.00
0005433525355	32517	Economy	25700.00
0005433525354	32517	Economy	25700.00
0005433531394	32517	Economy	25700.00
0005433525311	32517	Economy	25700.00
0005433525358	32517	Economy	25700.00
0005433525352	32517	Economy	25700.00
0005433525299	32517	Economy	25700.00
0005433525348	32517	Economy	25700.00
0005435179023	5264	Business	84000.00
0005435375110	5264	Business	84000.00
0005435374943	5264	Business	84000.00
0005435735273	5264	Business	84000.00
0005435315020	5264	Business	84000.00
0005435304263	5264	Business	84000.00
0005435374975	5264	Business	84000.00
0005435304275	5264	Business	84000.00
0005435374732	5264	Business	84000.00
0005435315114	5264	Business	84000.00
0005435386752	5264	Comfort	47600.00
0005435304269	5264	Comfort	47600.00
0005435374974	5264	Comfort	47600.00
0005435374988	5264	Comfort	47600.00
0005435374640	5264	Comfort	47600.00
0005435374860	5264	Comfort	47600.00
0005435374690	5264	Comfort	47600.00
0005435374949	5264	Comfort	47600.00
0005435299914	5264	Comfort	47600.00
0005435375102	5264	Comfort	47600.00
0005435375126	5264	Comfort	47600.00
0005435386740	5264	Economy	28000.00
0005435375127	5264	Economy	28000.00
0005432823502	5264	Economy	28000.00
0005435299892	5264	Economy	28000.00
0005435386726	5264	Economy	28000.00
0005435375003	5264	Economy	28000.00
0005435179717	5264	Economy	28000.00
0005435374910	5264	Economy	28000.00
0005435386739	5264	Economy	28000.00
0005435179022	5264	Economy	28000.00
0005435299915	5264	Economy	28000.00
0005435374991	5264	Economy	28000.00
0005435315122	5264	Economy	28000.00
0005435315092	5264	Economy	30800.00
0005435315091	5264	Economy	28000.00
0005435315103	5264	Economy	28000.00
0005435374955	5264	Economy	28000.00
0005435375170	5264	Economy	28000.00
0005435179015	5264	Economy	28000.00
0005435304264	5264	Economy	28000.00
0005435735252	5264	Economy	28000.00
0005435315068	5264	Economy	28000.00
0005435179011	5264	Economy	28000.00
0005435374951	5264	Economy	28000.00
0005435375172	5264	Economy	28000.00
0005435375093	5264	Economy	28000.00
0005435375092	5264	Economy	28000.00
0005435304265	5264	Economy	28000.00
0005435386727	5264	Economy	28000.00
0005435375124	5264	Economy	28000.00
0005435374989	5264	Economy	28000.00
0005435374954	5264	Economy	28000.00
0005435315113	5264	Economy	28000.00
0005435375162	5264	Economy	28000.00
0005435315093	5264	Economy	28000.00
0005435299906	5264	Economy	30800.00
0005435179016	5264	Economy	30800.00
0005435315070	5264	Economy	28000.00
0005435374932	5264	Economy	28000.00
0005435375125	5264	Economy	28000.00
0005435375038	5264	Economy	28000.00
0005435315066	5264	Economy	28000.00
0005435375022	5264	Economy	28000.00
0005435375150	5264	Economy	28000.00
0005435374933	5264	Economy	28000.00
0005435304270	5264	Economy	28000.00
0005435374731	5264	Economy	28000.00
0005435315052	5264	Economy	28000.00
0005435735271	5264	Economy	28000.00
0005435374976	5264	Economy	28000.00
0005435374944	5264	Economy	28000.00
0005435375171	5264	Economy	28000.00
0005435304260	5264	Economy	28000.00
0005435735272	5264	Economy	28000.00
0005435735251	5264	Economy	28000.00
0005435179718	5264	Economy	28000.00
0005435375069	5264	Economy	28000.00
0005435304274	5264	Economy	28000.00
0005434827121	9897	Business	84000.00
0005434826638	9897	Business	84000.00
0005434826857	9897	Business	84000.00
0005432396347	9897	Business	84000.00
0005434827225	9897	Business	84000.00
0005434827153	9897	Business	84000.00
0005432400220	9897	Business	84000.00
0005434827008	9897	Business	84000.00
0005434558534	9897	Business	84000.00
0005434827000	9897	Business	84000.00
0005434558507	9897	Business	84000.00
0005434827111	9897	Business	84000.00
0005434827229	9897	Business	84000.00
0005435315147	9897	Comfort	47600.00
0005434826759	9897	Comfort	47600.00
0005434827064	9897	Comfort	47600.00
0005434827139	9897	Comfort	47600.00
0005434827200	9897	Comfort	47600.00
0005434827091	9897	Comfort	47600.00
0005434826850	9897	Comfort	47600.00
0005434558544	9897	Comfort	47600.00
0005434826731	9897	Comfort	47600.00
0005434826837	9897	Comfort	47600.00
0005434827058	9897	Comfort	47600.00
0005434826927	9897	Economy	28000.00
0005434826871	9897	Comfort	47600.00
0005434826896	9897	Economy	28000.00
0005434826639	9897	Economy	28000.00
0005434826998	9897	Economy	28000.00
0005432396346	9897	Economy	28000.00
0005434826641	9897	Economy	28000.00
0005435150388	9897	Economy	28000.00
0005434827118	9897	Economy	28000.00
0005434827122	9897	Economy	28000.00
0005434827232	9897	Economy	28000.00
0005434826843	9897	Economy	28000.00
0005434665010	9897	Economy	28000.00
0005434826983	9897	Economy	28000.00
0005434827269	9897	Economy	28000.00
0005434827092	9897	Economy	28000.00
0005434827138	9897	Economy	28000.00
0005434826947	9897	Economy	28000.00
0005434826932	9897	Economy	28000.00
0005434827073	9897	Economy	28000.00
0005434826650	9897	Economy	30800.00
0005434827075	9897	Economy	28000.00
0005435150345	9897	Economy	30800.00
0005434827086	9897	Economy	28000.00
0005434826909	9897	Economy	28000.00
0005434558529	9897	Economy	28000.00
0005434827110	9897	Economy	28000.00
0005434827173	9897	Economy	28000.00
0005434826976	9897	Economy	28000.00
0005434826982	9897	Economy	28000.00
0005434827113	9897	Economy	28000.00
0005434826975	9897	Economy	28000.00
0005434827177	9897	Economy	28000.00
0005434826926	9897	Economy	28000.00
0005434826869	9897	Economy	28000.00
0005434827169	9897	Economy	28000.00
0005434826858	9897	Economy	28000.00
0005434826802	9897	Economy	28000.00
0005434826990	9897	Economy	28000.00
0005434826703	9897	Economy	28000.00
0005434665021	9897	Economy	28000.00
0005435315145	9897	Economy	28000.00
0005434826673	9897	Economy	28000.00
0005434827107	9897	Economy	28000.00
0005434827074	9897	Economy	28000.00
0005434826836	9897	Economy	28000.00
0005434827119	9897	Economy	28000.00
0005435315146	9897	Economy	28000.00
0005434827060	9897	Economy	28000.00
0005434558499	9897	Economy	28000.00
0005434826883	9897	Economy	28000.00
0005434826905	9897	Economy	28000.00
0005434827152	9897	Economy	28000.00
0005434826640	9897	Economy	28000.00
0005434558535	9897	Economy	28000.00
0005434826835	9897	Economy	28000.00
0005434558506	9897	Economy	28000.00
0005434827007	9897	Economy	28000.00
0005434827148	9897	Economy	28000.00
0005434558479	9897	Economy	28000.00
0005434827172	9897	Economy	28000.00
0005434826870	9897	Economy	28000.00
0005434826925	9897	Economy	28000.00
0005434827106	9897	Economy	28000.00
0005434826834	9897	Economy	28000.00
0005434665016	9897	Economy	28000.00
0005432400221	9897	Economy	28000.00
0005434826931	9897	Economy	28000.00
0005434827016	9897	Economy	28000.00
0005434826957	9897	Economy	28000.00
0005434827072	9897	Economy	28000.00
0005434827195	9897	Economy	28000.00
0005434826801	9897	Economy	28000.00
0005434827186	9897	Economy	28000.00
0005434826862	9897	Economy	28000.00
0005434827147	9897	Economy	28000.00
0005435150390	9897	Economy	28000.00
0005434826812	9897	Economy	28000.00
0005434558498	9897	Economy	28000.00
0005434827168	9897	Economy	28000.00
0005434827237	9897	Economy	28000.00
0005434827076	9897	Economy	28000.00
0005435083031	25998	Economy	8200.00
0005435082965	25998	Economy	7400.00
0005435083009	25998	Economy	7400.00
0005435083016	25998	Economy	7400.00
0005435082997	25998	Economy	7400.00
0005434215749	9546	Business	32800.00
0005434215648	9546	Business	32800.00
0005434215839	9546	Business	32800.00
0005434215605	9546	Economy	10900.00
0005434215761	9546	Economy	10900.00
0005434215732	9546	Economy	10900.00
0005434215686	9546	Economy	12000.00
0005434215777	9546	Economy	12000.00
0005434215776	9546	Economy	12000.00
0005434215790	9546	Economy	10900.00
0005434215782	9546	Economy	10900.00
0005434215697	9546	Economy	10900.00
0005434215825	9546	Economy	10900.00
0005434215698	9546	Economy	10900.00
0005434215583	9546	Economy	10900.00
0005434215778	9546	Economy	10900.00
0005434215779	9546	Economy	10900.00
0005434215795	9546	Economy	10900.00
0005434215760	9546	Economy	10900.00
0005434215766	9546	Economy	10900.00
0005434215788	9546	Economy	10900.00
0005434215733	9546	Economy	10900.00
0005434215719	9546	Economy	10900.00
0005434215762	9546	Economy	10900.00
0005434215810	9546	Economy	10900.00
0005434215731	9546	Economy	10900.00
0005434215811	9546	Economy	10900.00
0005434215763	9546	Economy	10900.00
0005434215817	9546	Economy	10900.00
0005434215857	9546	Economy	10900.00
0005434215812	9546	Economy	10900.00
0005434757525	28624	Business	32800.00
0005434757643	28624	Business	32800.00
0005434757468	28624	Business	32800.00
0005434757437	28624	Business	32800.00
0005434757627	28624	Business	32800.00
0005434757564	28624	Economy	10900.00
0005434757565	28624	Economy	10900.00
0005434757673	28624	Economy	10900.00
0005434757492	28624	Economy	10900.00
0005434757477	28624	Economy	12000.00
0005434757305	28624	Economy	12000.00
0005434757620	28624	Economy	10900.00
0005434757545	28624	Economy	10900.00
0005434757628	28624	Economy	10900.00
0005434757535	28624	Economy	10900.00
0005434757541	28624	Economy	10900.00
0005434757379	28624	Economy	10900.00
0005434757465	28624	Economy	10900.00
0005434757586	28624	Economy	10900.00
0005434757646	28624	Economy	10900.00
0005434757471	28624	Economy	10900.00
0005434757476	28624	Economy	10900.00
0005434757438	28624	Economy	10900.00
0005434757585	28624	Economy	10900.00
0005434757522	28624	Economy	10900.00
0005434757436	28624	Economy	10900.00
0005434757672	28624	Economy	10900.00
0005434757432	28624	Economy	10900.00
0005434757519	28624	Economy	10900.00
0005434757306	28624	Economy	10900.00
0005434757521	28624	Economy	10900.00
0005434757431	28624	Economy	10900.00
0005434757298	28624	Economy	10900.00
0005434757520	28624	Economy	10900.00
0005434757607	28624	Economy	10900.00
0005434757571	28624	Economy	10900.00
0005434757642	28624	Economy	10900.00
0005434757523	28624	Economy	10900.00
0005434757389	28624	Economy	10900.00
0005434757570	28624	Economy	10900.00
0005434757338	28624	Economy	10900.00
0005434757645	28624	Economy	10900.00
0005434757582	28624	Economy	10900.00
0005434757544	28624	Economy	10900.00
0005434757606	28624	Economy	10900.00
0005434760264	10846	Economy	8900.00
0005434760265	10846	Economy	8900.00
0005434760266	10846	Economy	8900.00
0005433202693	1992	Economy	19000.00
0005433202702	1992	Economy	19000.00
0005432290726	1992	Economy	19000.00
0005433202751	1992	Economy	19000.00
0005434639961	23300	Economy	20900.00
0005435948363	23300	Economy	20900.00
0005434640053	23300	Economy	19000.00
0005434640024	23300	Economy	19000.00
0005435948362	23300	Economy	19000.00
0005434640029	23300	Economy	19000.00
0005434639988	23300	Economy	19000.00
0005434639960	23300	Economy	19000.00
0005434639987	23300	Economy	19000.00
0005434640051	23300	Economy	19000.00
0005434640052	23300	Economy	19000.00
0005434639989	23300	Economy	19000.00
0005434640026	23300	Economy	19000.00
0005434640103	23300	Economy	19000.00
0005434640034	23300	Economy	19000.00
0005434640056	23300	Economy	19000.00
0005433202798	23300	Economy	19000.00
0005434639906	23300	Economy	19000.00
0005433202799	23300	Economy	19000.00
0005434640102	23300	Economy	19000.00
0005435327109	6079	Business	69700.00
0005435327128	6079	Economy	23200.00
0005435327108	6079	Economy	25600.00
0005435327065	6079	Economy	23200.00
0005435327071	6079	Economy	23200.00
0005435327072	6079	Economy	23200.00
0005435327132	6079	Economy	23200.00
0005435327113	6079	Economy	23200.00
0005435327073	6079	Economy	23200.00
0005435327137	6079	Economy	23200.00
0005435327110	6079	Economy	23200.00
0005435327114	6079	Economy	23200.00
0005435327052	6079	Economy	23200.00
0005435327130	6079	Economy	23200.00
0005434601573	18592	Business	69700.00
0005433531392	18592	Business	69700.00
0005434601581	18592	Business	69700.00
0005433527367	18592	Business	69700.00
0005434601518	18592	Business	69700.00
0005434601459	18592	Economy	23200.00
0005434601531	18592	Economy	25600.00
0005434601510	18592	Economy	23200.00
0005434601559	18592	Economy	23200.00
0005434601517	18592	Economy	23200.00
0005433531377	18592	Economy	23200.00
0005434601499	18592	Economy	23200.00
0005433531378	18592	Economy	23200.00
0005434601533	18592	Economy	23200.00
0005434601572	18592	Economy	23200.00
0005434601532	18592	Economy	23200.00
0005434601571	18592	Economy	23200.00
0005434601500	18592	Economy	23200.00
0005433531389	18592	Economy	23200.00
0005434601501	18592	Economy	23200.00
0005433527336	18592	Economy	23200.00
0005434601576	18592	Economy	23200.00
0005433181723	10605	Business	9100.00
0005435315053	10605	Business	9100.00
0005435315069	10605	Business	9100.00
0005435315099	10605	Business	9100.00
0005433181696	10605	Business	9100.00
0005433181819	10605	Business	9100.00
0005435315074	10605	Business	9100.00
0005433181824	10605	Economy	3000.00
0005435315063	10605	Economy	3000.00
0005433181760	10605	Economy	3000.00
0005435315096	10605	Economy	3000.00
0005435315095	10605	Economy	3000.00
0005435315002	10605	Economy	3300.00
0005433181825	10605	Economy	3000.00
0005433181697	10605	Economy	3000.00
0005435315060	10605	Economy	3000.00
0005435315064	10605	Economy	3000.00
0005433181836	10605	Economy	3000.00
0005433181722	10605	Economy	3000.00
0005433181718	10605	Economy	3000.00
0005435315003	10605	Economy	3000.00
0005435315059	10605	Economy	3000.00
0005433181808	10605	Economy	3000.00
0005433181758	10605	Economy	3000.00
0005435315017	10605	Economy	3000.00
0005433181754	10605	Economy	3000.00
0005435315004	10605	Economy	3000.00
0005433181729	10605	Economy	3000.00
0005433181728	10605	Economy	3000.00
0005435315016	10605	Economy	3000.00
0005435315082	10605	Economy	3000.00
0005435315098	10605	Economy	3000.00
0005433181743	10605	Economy	3000.00
0005433181773	10605	Economy	3000.00
0005433181727	10605	Economy	3000.00
0005433181777	10605	Economy	3000.00
0005433181759	10605	Economy	3000.00
0005433181772	10605	Economy	3000.00
0005433181835	10605	Economy	3000.00
0005434558618	10605	Economy	3000.00
0005435314979	10605	Economy	3000.00
0005435315097	10605	Economy	3000.00
0005435315081	10605	Economy	3000.00
0005435315147	27740	Economy	3000.00
0005435315145	27740	Economy	3000.00
0005435315146	27740	Economy	3000.00
0005434558492	27742	Business	9100.00
0005434552826	27742	Business	9100.00
0005434552579	27742	Business	9100.00
0005434552705	27742	Business	9100.00
0005434558527	27742	Business	9100.00
0005434558542	27742	Business	9100.00
0005434552587	27742	Business	9100.00
0005434558538	27742	Business	9100.00
0005434552616	27742	Economy	3000.00
0005434552748	27742	Economy	3000.00
0005434552821	27742	Economy	3000.00
0005434558540	27742	Economy	3000.00
0005434552750	27742	Economy	3300.00
0005434552712	27742	Economy	3300.00
0005434558532	27742	Economy	3300.00
0005434552802	27742	Economy	3000.00
0005434552704	27742	Economy	3000.00
0005434558509	27742	Economy	3000.00
0005434552777	27742	Economy	3000.00
0005434552624	27742	Economy	3000.00
0005434552733	27742	Economy	3000.00
0005434552745	27742	Economy	3000.00
0005434558552	27742	Economy	3000.00
0005434552623	27742	Economy	3000.00
0005434558586	27742	Economy	3000.00
0005434552588	27742	Economy	3000.00
0005434552746	27742	Economy	3000.00
0005434558493	27742	Economy	3000.00
0005434558536	27742	Economy	3000.00
0005434552581	27742	Economy	3000.00
0005434558546	27742	Economy	3000.00
0005434558525	27742	Economy	3000.00
0005434552827	27742	Economy	3000.00
0005434552703	27742	Economy	3000.00
0005434558580	27742	Economy	3000.00
0005434558539	27742	Economy	3000.00
0005434552707	27742	Economy	3000.00
0005434552732	27742	Economy	3000.00
0005434552776	27742	Economy	3000.00
0005434558592	27742	Economy	3000.00
0005434558516	27742	Economy	3000.00
0005434558541	27742	Economy	3000.00
0005434552578	27742	Economy	3000.00
0005434552686	27742	Economy	3000.00
0005434552728	27742	Economy	3000.00
0005434552796	27742	Economy	3000.00
0005434552804	27742	Economy	3000.00
0005434552706	27742	Economy	3000.00
0005434558559	27742	Economy	3000.00
0005434558526	27742	Economy	3000.00
0005434552793	27742	Economy	3000.00
0005434558537	27742	Economy	3000.00
0005434552792	27742	Economy	3000.00
0005434552847	27742	Economy	3000.00
0005434552820	27742	Economy	3000.00
0005434552711	27742	Economy	3000.00
0005434552708	27742	Economy	3000.00
0005434558553	27742	Economy	3000.00
0005435254524	6173	Economy	11700.00
0005435217775	6709	Business	51100.00
0005435438474	6709	Business	51100.00
0005435438539	6709	Economy	17000.00
0005432533374	6709	Economy	17000.00
0005435438504	6709	Economy	18700.00
0005434828768	6709	Economy	17000.00
0005435654521	6709	Economy	17000.00
0005434828763	6709	Economy	17000.00
0005432533373	6709	Economy	17000.00
0005435654522	6709	Economy	17000.00
0005432533375	6709	Economy	17000.00
0005435438587	6709	Economy	17000.00
0005432533365	6709	Economy	17000.00
0005435438473	6709	Economy	17000.00
0005435438503	6709	Economy	17000.00
0005435438562	6709	Economy	17000.00
0005434828767	6709	Economy	17000.00
0005435217771	6709	Economy	17000.00
0005435654523	6709	Economy	17000.00
0005435683140	24614	Business	51100.00
0005435683312	24614	Business	51100.00
0005435683224	24614	Economy	17000.00
0005435720852	24614	Economy	17000.00
0005435720849	24614	Economy	18700.00
0005435683276	24614	Economy	18700.00
0005435683275	24614	Economy	18700.00
0005435683299	24614	Economy	17000.00
0005435683159	24614	Economy	17000.00
0005435683261	24614	Economy	17000.00
0005435720856	24614	Economy	17000.00
0005435682939	24614	Economy	17000.00
0005435683300	24614	Economy	17000.00
0005435683225	24614	Economy	17000.00
0005435683273	24614	Economy	17000.00
0005435683031	24614	Economy	17000.00
0005435683248	24614	Economy	17000.00
0005435683301	24614	Economy	17000.00
0005435683141	24614	Economy	17000.00
0005435683226	24614	Economy	17000.00
0005435683206	24614	Economy	17000.00
0005435683252	24614	Economy	17000.00
0005435683295	24614	Economy	17000.00
0005435720855	24614	Economy	17000.00
0005435662007	24614	Economy	17000.00
0005435683251	24614	Economy	17000.00
0005435683263	24614	Economy	17000.00
0005435683221	24614	Economy	17000.00
0005435683256	24614	Economy	17000.00
0005435683277	24614	Economy	17000.00
0005435683220	24614	Economy	17000.00
0005435683262	24614	Economy	17000.00
0005435127590	11546	Economy	8800.00
0005435127589	11546	Economy	8800.00
0005435098617	11546	Economy	8800.00
0005435127466	31888	Business	26400.00
0005435127537	31888	Economy	9700.00
0005435127449	31888	Economy	9700.00
0005435127551	31888	Economy	8800.00
0005435127431	31888	Economy	8800.00
0005435127473	31888	Economy	8800.00
0005435127495	31888	Economy	8800.00
0005435127467	31888	Economy	8800.00
0005435127505	31888	Economy	8800.00
0005435127423	31888	Economy	8800.00
0005435106069	31888	Economy	8800.00
0005435127479	31888	Economy	8800.00
0005435127450	31888	Economy	8800.00
0005435127474	31888	Economy	8800.00
0005435127459	31888	Economy	8800.00
0005435127498	31888	Economy	8800.00
0005435127397	31888	Economy	8800.00
0005435127471	31888	Economy	8800.00
0005435127497	31888	Economy	8800.00
0005435127488	31888	Economy	8800.00
0005435127398	31888	Economy	8800.00
0005435127425	31888	Economy	8800.00
0005435127338	31888	Economy	8800.00
0005435127451	31888	Economy	8800.00
0005435127443	31888	Economy	8800.00
0005435127509	31888	Economy	8800.00
0005435127496	31888	Economy	8800.00
0005435732708	13547	Business	36600.00
0005435732658	13547	Business	36600.00
0005435732686	13547	Business	36600.00
0005435732674	13547	Economy	12200.00
0005435732697	13547	Economy	12200.00
0005435732707	13547	Economy	12200.00
0005435732694	13547	Economy	12200.00
0005435732675	13547	Economy	12200.00
0005435732698	13547	Economy	12200.00
0005435732709	13547	Economy	12200.00
0005435732617	13547	Economy	12200.00
0005435732657	13547	Economy	12200.00
0005435732687	13547	Economy	12200.00
0005435732616	13547	Economy	12200.00
0005433399402	19414	Business	36600.00
0005433399279	19414	Business	36600.00
0005433399390	19414	Business	36600.00
0005433399368	19414	Business	36600.00
0005433399374	19414	Business	36600.00
0005433399139	19414	Economy	12200.00
0005433399462	19414	Economy	12200.00
0005433399352	19414	Economy	12200.00
0005433399187	19414	Economy	12200.00
0005433399343	19414	Economy	13400.00
0005433399138	19414	Economy	12200.00
0005433399453	19414	Economy	12200.00
0005433399140	19414	Economy	12200.00
0005433399375	19414	Economy	12200.00
0005433399382	19414	Economy	12200.00
0005433399346	19414	Economy	12200.00
0005433399251	19414	Economy	12200.00
0005433399262	19414	Economy	12200.00
0005433399277	19414	Economy	12200.00
0005433399391	19414	Economy	12200.00
0005433399403	19414	Economy	12200.00
0005433399224	19414	Economy	12200.00
0005433399446	19414	Economy	12200.00
0005433399186	19414	Economy	12200.00
0005433399323	19414	Economy	12200.00
0005433399137	19414	Economy	12200.00
0005433399344	19414	Economy	12200.00
0005433399383	19414	Economy	12200.00
0005433399322	19414	Economy	12200.00
0005433399250	19414	Economy	12200.00
0005433399226	19414	Economy	12200.00
0005433399441	19414	Economy	12200.00
0005433399227	19414	Economy	12200.00
0005433399280	19414	Economy	12200.00
0005433399310	19414	Economy	12200.00
0005433399261	19414	Economy	12200.00
0005435070450	13171	Business	11300.00
0005435070523	13171	Business	11300.00
0005435925727	13171	Business	11300.00
0005435070398	13171	Business	11300.00
0005435070442	13171	Business	11300.00
0005435070350	13171	Economy	3800.00
0005435070501	13171	Economy	3800.00
0005435070500	13171	Economy	3800.00
0005435070337	13171	Economy	3800.00
0005435070539	13171	Economy	4100.00
0005435070387	13171	Economy	4100.00
0005435070499	13171	Economy	3800.00
0005435070393	13171	Economy	3800.00
0005435070469	13171	Economy	3800.00
0005435949870	13171	Economy	3800.00
0005435070517	13171	Economy	3800.00
0005435070443	13171	Economy	3800.00
0005435070362	13171	Economy	3800.00
0005435070352	13171	Economy	3800.00
0005435070451	13171	Economy	3800.00
0005435070397	13171	Economy	3800.00
0005435070472	13171	Economy	3800.00
0005435070486	13171	Economy	3800.00
0005435070473	13171	Economy	3800.00
0005435070319	13171	Economy	3800.00
0005435070351	13171	Economy	3800.00
0005435070485	13171	Economy	3800.00
0005435070403	13171	Economy	3800.00
0005435070516	13171	Economy	3800.00
0005435070399	13171	Economy	3800.00
0005435070411	13171	Economy	3800.00
0005435070421	13171	Economy	3800.00
0005435070453	13171	Economy	3800.00
0005435070439	13171	Economy	3800.00
0005435070522	13171	Economy	3800.00
0005435070572	15497	Business	11300.00
0005435925670	15497	Business	11300.00
0005435925707	15497	Economy	3800.00
0005435925678	15497	Economy	4100.00
0005435070569	15497	Economy	3800.00
0005435925653	15497	Economy	3800.00
0005435925660	15497	Economy	3800.00
0005435925664	15497	Economy	3800.00
0005435925706	15497	Economy	3800.00
0005435925634	15497	Economy	3800.00
0005435925677	15497	Economy	3800.00
0005435070571	15497	Economy	3800.00
0005435070570	15497	Economy	3800.00
0005435925622	15497	Economy	3800.00
0005435925692	15497	Economy	3800.00
0005435925671	15497	Economy	3800.00
0005435808466	29476	Economy	24700.00
0005435808492	29476	Economy	24700.00
0005435808501	29476	Economy	24700.00
0005435808467	29476	Economy	24700.00
0005435808478	29476	Economy	24700.00
0005435808452	29476	Economy	24700.00
0005435808496	29476	Economy	24700.00
0005435808450	29476	Economy	24700.00
0005435808446	29476	Economy	24700.00
0005435808447	29476	Economy	24700.00
0005435808477	29476	Economy	24700.00
0005435808497	29476	Economy	24700.00
0005435808451	29476	Economy	24700.00
0005435808515	29476	Economy	24700.00
0005434757566	10682	Business	61300.00
0005434757644	10682	Business	61300.00
0005434757572	10682	Business	61300.00
0005434757568	10682	Business	61300.00
0005434757648	10682	Business	61300.00
0005434757473	10682	Economy	20400.00
0005434757625	10682	Economy	20400.00
0005434757577	10682	Economy	22500.00
0005434757524	10682	Economy	22500.00
0005434757402	10682	Economy	20400.00
0005434757427	10682	Economy	20400.00
0005434757540	10682	Economy	20400.00
0005434757647	10682	Economy	20400.00
0005434757576	10682	Economy	20400.00
0005434757401	10682	Economy	20400.00
0005434757489	10682	Economy	20400.00
0005434757588	10682	Economy	20400.00
0005434757536	10682	Economy	20400.00
0005434757542	10682	Economy	20400.00
0005434757611	10682	Economy	20400.00
0005434757616	10682	Economy	20400.00
0005434757393	10682	Economy	20400.00
0005434757617	10682	Economy	20400.00
0005434757587	10682	Economy	20400.00
0005434215658	28665	Business	61300.00
0005434215679	28665	Business	61300.00
0005434215675	28665	Business	61300.00
0005434215748	28665	Business	61300.00
0005434215735	28665	Business	61300.00
0005434215736	28665	Business	61300.00
0005434215422	28665	Economy	20400.00
0005434215727	28665	Economy	20400.00
0005434215611	28665	Economy	20400.00
0005434215699	28665	Economy	22500.00
0005434215837	28665	Economy	20400.00
0005434215806	28665	Economy	20400.00
0005434215838	28665	Economy	20400.00
0005434215641	28665	Economy	20400.00
0005434215676	28665	Economy	20400.00
0005434215673	28665	Economy	20400.00
0005434215753	28665	Economy	20400.00
0005434215656	28665	Economy	20400.00
0005434215625	28665	Economy	20400.00
0005434215680	28665	Economy	20400.00
0005434215756	28665	Economy	20400.00
0005434215595	28665	Economy	20400.00
0005434215657	28665	Economy	20400.00
0005434215757	28665	Economy	20400.00
0005434215660	28665	Economy	20400.00
0005434215734	28665	Economy	20400.00
0005434215640	28665	Economy	20400.00
0005434215752	28665	Economy	20400.00
0005434215737	28665	Economy	20400.00
0005434215836	28665	Economy	20400.00
0005434215525	28665	Economy	20400.00
0005434215662	28665	Economy	20400.00
0005434215726	28665	Economy	20400.00
0005434215754	28665	Economy	20400.00
0005434229975	5442	Business	29500.00
0005435377941	5442	Business	29500.00
0005434229985	5442	Business	29500.00
0005434229921	5442	Economy	9800.00
0005434229852	5442	Economy	9800.00
0005434230002	5442	Economy	9800.00
0005434229973	5442	Economy	9800.00
0005434229851	5442	Economy	9800.00
0005434229974	5442	Economy	9800.00
0005434229972	5442	Economy	9800.00
0005435377950	5442	Economy	9800.00
0005435377942	5442	Economy	9800.00
0005434229941	5442	Economy	9800.00
0005434229978	5442	Economy	9800.00
0005434229971	5442	Economy	9800.00
0005435377943	5442	Economy	9800.00
0005434229983	5442	Economy	9800.00
0005434229939	5442	Economy	9800.00
0005435377954	5442	Economy	9800.00
0005435377951	5442	Economy	9800.00
0005434229922	5442	Economy	9800.00
0005434229931	5442	Economy	9800.00
0005435377988	5442	Economy	9800.00
0005434229947	5442	Economy	9800.00
0005434229942	5442	Economy	9800.00
0005435377955	5442	Economy	9800.00
0005435041358	12961	Business	29500.00
0005435007654	12961	Business	29500.00
0005435041650	12961	Business	29500.00
0005435041489	12961	Business	29500.00
0005435041673	12961	Business	29500.00
0005435041271	12961	Business	29500.00
0005435007650	12961	Economy	9800.00
0005435041534	12961	Economy	9800.00
0005435041392	12961	Economy	9800.00
0005435041552	12961	Economy	9800.00
0005435007633	12961	Economy	9800.00
0005435041505	12961	Economy	9800.00
0005435007655	12961	Economy	9800.00
0005435041609	12961	Economy	9800.00
0005435041583	12961	Economy	9800.00
0005435041444	12961	Economy	9800.00
0005435041675	12961	Economy	9800.00
0005435007657	12961	Economy	9800.00
0005435007645	12961	Economy	9800.00
0005435041577	12961	Economy	9800.00
0005435041608	12961	Economy	9800.00
0005435041518	12961	Economy	9800.00
0005435041506	12961	Economy	9800.00
0005435041689	12961	Economy	9800.00
0005435007651	12961	Economy	9800.00
0005435041551	12961	Economy	10800.00
0005435041520	12961	Economy	9800.00
0005435041474	12961	Economy	9800.00
0005435041493	12961	Economy	9800.00
0005435041582	12961	Economy	9800.00
0005435041542	12961	Economy	9800.00
0005435041357	12961	Economy	9800.00
0005435007653	12961	Economy	9800.00
0005435041638	12961	Economy	9800.00
0005435007672	12961	Economy	9800.00
0005435041664	12961	Economy	9800.00
0005435041515	12961	Economy	9800.00
0005435041475	12961	Economy	9800.00
0005435041476	12961	Economy	9800.00
0005435041639	12961	Economy	9800.00
0005435043304	12961	Economy	9800.00
0005435041445	12961	Economy	9800.00
0005435041578	12961	Economy	9800.00
0005435041652	12961	Economy	9800.00
0005435041653	12961	Economy	9800.00
0005435007678	12961	Economy	9800.00
0005435007634	12961	Economy	9800.00
0005435007618	12961	Economy	9800.00
0005435007658	12961	Economy	9800.00
0005435041458	12961	Economy	9800.00
0005435041641	12961	Economy	9800.00
0005435007617	12961	Economy	9800.00
0005435041428	12961	Economy	9800.00
0005435041533	12961	Economy	9800.00
0005435041359	12961	Economy	9800.00
0005435041674	12961	Economy	9800.00
0005435041395	12961	Economy	9800.00
0005435903189	14900	Business	52900.00
0005435554299	14900	Economy	17600.00
0005435903135	14900	Economy	17600.00
0005435903174	14900	Economy	17600.00
0005435903182	14900	Economy	17600.00
0005435903156	14900	Economy	17600.00
0005435903168	14900	Economy	17600.00
0005435903175	14900	Economy	17600.00
0005435554315	14900	Economy	17600.00
0005435554298	14900	Economy	17600.00
0005435903190	14900	Economy	17600.00
0005435903134	14900	Economy	17600.00
0005435903126	14900	Economy	17600.00
0005435903181	14900	Economy	17600.00
0005434427350	20224	Business	52900.00
0005434427370	20224	Business	52900.00
0005434427442	20224	Economy	17600.00
0005434427373	20224	Economy	19400.00
0005434427452	20224	Economy	17600.00
0005434427428	20224	Economy	17600.00
0005434427347	20224	Economy	17600.00
0005434427351	20224	Economy	17600.00
0005434427441	20224	Economy	17600.00
0005434427348	20224	Economy	17600.00
0005434427337	20224	Economy	17600.00
0005434427423	20224	Economy	17600.00
0005434427443	20224	Economy	17600.00
0005434427424	20224	Economy	17600.00
0005434427427	20224	Economy	17600.00
0005434427411	20224	Economy	17600.00
0005433435444	26548	Business	18500.00
0005433435415	26548	Economy	6200.00
0005434273121	26548	Economy	6800.00
0005433435292	26548	Economy	6800.00
0005433435476	26548	Economy	6200.00
0005433435406	26548	Economy	6200.00
0005434273120	26548	Economy	6200.00
0005433435475	26548	Economy	6200.00
0005433435396	26548	Economy	6200.00
0005433435414	26548	Economy	6200.00
0005433435443	26548	Economy	6200.00
0005433435429	26548	Economy	6200.00
0005435983603	26707	Business	18500.00
0005435983351	26707	Business	18500.00
0005435983516	26707	Business	18500.00
0005435983363	26707	Business	18500.00
0005435983537	26707	Business	18500.00
0005435983468	26707	Economy	6200.00
0005435983590	26707	Economy	6200.00
0005435983492	26707	Economy	6200.00
0005435983526	26707	Economy	6200.00
0005435983557	26707	Economy	6200.00
0005435983536	26707	Economy	6200.00
0005435983355	26707	Economy	6200.00
0005435983608	26707	Economy	6800.00
0005435983466	26707	Economy	6800.00
0005435983569	26707	Economy	6800.00
0005435983482	26707	Economy	6800.00
0005435983632	26707	Economy	6200.00
0005435983533	26707	Economy	6200.00
0005435983470	26707	Economy	6200.00
0005435983517	26707	Economy	6200.00
0005435983454	26707	Economy	6200.00
0005435983607	26707	Economy	6200.00
0005435983535	26707	Economy	6200.00
0005435983521	26707	Economy	6200.00
0005435983483	26707	Economy	6200.00
0005435983596	26707	Economy	6200.00
0005435983474	26707	Economy	6200.00
0005435983430	26707	Economy	6200.00
0005435983479	26707	Economy	6200.00
0005435983432	26707	Economy	6200.00
0005435983601	26707	Economy	6200.00
0005435983372	26707	Economy	6200.00
0005435983501	26707	Economy	6200.00
0005435983527	26707	Economy	6200.00
0005435983508	26707	Economy	6200.00
0005435983431	26707	Economy	6200.00
0005435983362	26707	Economy	6200.00
0005435983475	26707	Economy	6200.00
0005435983509	26707	Economy	6200.00
0005435983506	26707	Economy	6200.00
0005435983373	26707	Economy	6200.00
0005435983631	26707	Economy	6200.00
0005435983507	26707	Economy	6200.00
0005435983493	26707	Economy	6200.00
0005435983375	26707	Economy	6200.00
0005435983542	26707	Economy	6200.00
0005435983523	26707	Economy	6200.00
0005435983520	26707	Economy	6200.00
0005435983510	26707	Economy	6200.00
0005435983498	26707	Economy	6200.00
0005435983399	26707	Economy	6200.00
0005435983543	26707	Economy	6200.00
0005435983514	26707	Economy	6200.00
0005435983469	26707	Economy	6200.00
0005435983553	26707	Economy	6200.00
0005435983600	26707	Economy	6200.00
0005432858393	3155	Economy	11100.00
0005432858367	3155	Economy	10100.00
0005432858394	3155	Economy	10100.00
0005432858390	3155	Economy	10100.00
0005432858384	3155	Economy	10100.00
0005432858389	3155	Economy	10100.00
0005432858366	3155	Economy	10100.00
0005432858395	3155	Economy	10100.00
0005432858352	3155	Economy	10100.00
0005432584689	31467	Economy	11100.00
0005432584724	31467	Economy	11100.00
0005432584738	31467	Economy	11100.00
0005432584765	31467	Economy	10100.00
0005432584723	31467	Economy	10100.00
0005432584771	31467	Economy	10100.00
0005432584668	31467	Economy	10100.00
0005432584736	31467	Economy	10100.00
0005432584727	31467	Economy	10100.00
0005432584737	31467	Economy	10100.00
0005432584690	31467	Economy	10100.00
0005432584729	31467	Economy	10100.00
0005432584772	31467	Economy	10100.00
0005432584691	31467	Economy	10100.00
0005432584717	31467	Economy	10100.00
0005432584758	31467	Economy	10100.00
0005433255260	880	Economy	7500.00
0005433255265	880	Economy	7500.00
0005434943570	16206	Economy	7500.00
0005434943559	16206	Economy	7500.00
0005434943597	16206	Economy	7500.00
0005434943571	16206	Economy	7500.00
0005434943613	16206	Economy	7500.00
0005434943603	16206	Economy	7500.00
0005434943616	16206	Economy	7500.00
0005435858681	4330	Business	90500.00
0005435858673	4330	Economy	30200.00
0005435858667	4330	Economy	30200.00
0005435858658	4330	Economy	30200.00
0005433654988	4330	Economy	33200.00
0005433654989	4330	Economy	30200.00
0005435858669	4330	Economy	30200.00
0005435858644	4330	Economy	30200.00
0005435858670	4330	Economy	30200.00
0005435858683	4330	Economy	30200.00
0005435858664	4330	Economy	30200.00
0005435858672	4330	Economy	30200.00
0005435858678	4330	Economy	30200.00
0005435858685	4330	Economy	30200.00
0005435858659	4330	Economy	30200.00
0005435858668	4330	Economy	30200.00
0005435858684	4330	Economy	30200.00
0005433811684	14412	Economy	4400.00
0005433368896	21770	Business	9800.00
0005433368925	21770	Business	9800.00
0005433368794	21770	Business	9800.00
0005433368816	21770	Business	9800.00
0005433368714	21770	Business	9800.00
0005433368926	21770	Business	9800.00
0005433368875	21770	Economy	3300.00
0005433368902	21770	Economy	3300.00
0005433368718	21770	Economy	3300.00
0005433368734	21770	Economy	3300.00
0005433368837	21770	Economy	3300.00
0005433368730	21770	Economy	3300.00
0005433368888	21770	Economy	3300.00
0005433368835	21770	Economy	3300.00
0005433368947	21770	Economy	3300.00
0005433368795	21770	Economy	3300.00
0005433368836	21770	Economy	3300.00
0005433368899	21770	Economy	3300.00
0005433368928	21770	Economy	3300.00
0005433368697	21770	Economy	3300.00
0005433368911	21770	Economy	3300.00
0005433368806	21770	Economy	3300.00
0005433368738	21770	Economy	3300.00
0005433368895	21770	Economy	3300.00
0005433368927	21770	Economy	3300.00
0005433368948	21770	Economy	3300.00
0005433368808	21770	Economy	3300.00
0005433368839	21770	Economy	3300.00
0005433368862	21770	Economy	3300.00
0005433368867	21770	Economy	3300.00
0005433368861	21770	Economy	3300.00
0005433368796	21770	Economy	3300.00
0005433368881	21770	Economy	3300.00
0005433368933	21770	Economy	3300.00
0005433368868	21770	Economy	3300.00
0005433368733	21770	Economy	3300.00
0005433368917	21770	Economy	3300.00
0005433368807	21770	Economy	3300.00
0005433368908	21770	Economy	3300.00
0005433368817	21770	Economy	3300.00
0005433368929	21770	Economy	3300.00
0005433368874	21770	Economy	3300.00
0005433368843	21770	Economy	3300.00
0005435858732	9353	Business	186200.00
0005435858706	9353	Business	186200.00
0005434171439	9353	Business	186200.00
0005434151784	9353	Business	186200.00
0005435858726	9353	Business	186200.00
0005435270150	9353	Business	186200.00
0005435270064	9353	Business	186200.00
0005434151783	9353	Business	186200.00
0005435270162	9353	Business	186200.00
0005433806412	9353	Business	186200.00
0005434171463	9353	Economy	68300.00
0005435270210	9353	Economy	68300.00
0005435270118	9353	Economy	62100.00
0005435270036	9353	Economy	62100.00
0005434151787	9353	Economy	62100.00
0005434151779	9353	Economy	62100.00
0005434171438	9353	Economy	62100.00
0005435270111	9353	Economy	62100.00
0005434151776	9353	Economy	62100.00
0005434151790	9353	Economy	62100.00
0005435858737	9353	Economy	62100.00
0005434270265	9353	Economy	62100.00
0005434171446	9353	Economy	62100.00
0005434151777	9353	Economy	62100.00
0005435270163	9353	Economy	62100.00
0005434151788	9353	Economy	62100.00
0005434273123	9353	Economy	62100.00
0005435858715	9353	Economy	62100.00
0005435270038	9353	Economy	62100.00
0005435270123	9353	Economy	62100.00
0005434151782	9353	Economy	62100.00
0005434151785	9353	Economy	62100.00
0005435858738	9353	Economy	62100.00
0005435270035	9353	Economy	62100.00
0005435858739	9353	Economy	62100.00
0005434171418	9353	Economy	62100.00
0005435270185	9353	Economy	62100.00
0005435270112	9353	Economy	62100.00
0005435270182	9353	Economy	62100.00
0005435270165	9353	Economy	62100.00
0005434171434	9353	Economy	62100.00
0005434171440	9353	Economy	62100.00
0005435269983	9353	Economy	62100.00
0005435270219	9353	Economy	62100.00
0005435270187	9353	Economy	62100.00
0005435270050	9353	Economy	62100.00
0005434151789	9353	Economy	62100.00
0005435858733	9353	Economy	62100.00
0005434171425	9353	Economy	62100.00
0005434151778	9353	Economy	62100.00
0005434171417	9353	Economy	62100.00
0005435270172	9353	Economy	62100.00
0005433785914	26276	Business	186200.00
0005433785958	26276	Business	186200.00
0005433763596	26276	Business	186200.00
0005433786153	26276	Business	186200.00
0005433806216	26276	Business	186200.00
0005433786095	26276	Business	186200.00
0005432657525	26276	Business	186200.00
0005433786039	26276	Business	186200.00
0005433785886	26276	Business	186200.00
0005433786121	26276	Business	186200.00
0005433785838	26276	Economy	68300.00
0005433785849	26276	Economy	62100.00
0005433806278	26276	Economy	62100.00
0005433785850	26276	Economy	62100.00
0005433806318	26276	Economy	62100.00
0005432663087	26276	Economy	62100.00
0005432663099	26276	Economy	62100.00
0005432663088	26276	Economy	62100.00
0005433785956	26276	Economy	62100.00
0005433806328	26276	Economy	62100.00
0005433785988	26276	Economy	62100.00
0005432663086	26276	Economy	62100.00
0005433785870	26276	Economy	62100.00
0005433806343	26276	Economy	62100.00
0005433785975	26276	Economy	62100.00
0005432659764	26276	Economy	62100.00
0005433786042	26276	Economy	62100.00
0005433785875	26276	Economy	62100.00
0005433785717	26276	Economy	62100.00
0005432666438	26276	Economy	62100.00
0005433785989	26276	Economy	62100.00
0005433763597	26276	Economy	62100.00
0005433785976	26276	Economy	62100.00
0005433786038	26276	Economy	62100.00
0005433786026	26276	Economy	62100.00
0005433806380	26276	Economy	62100.00
0005433763585	26276	Economy	62100.00
0005433785941	26276	Economy	68300.00
0005433785882	26276	Economy	62100.00
0005433786043	26276	Economy	62100.00
0005432666437	26276	Economy	62100.00
0005433785966	26276	Economy	62100.00
0005433763570	26276	Economy	62100.00
0005433806281	26276	Economy	62100.00
0005433786041	26276	Economy	62100.00
0005433763629	26276	Economy	62100.00
0005433786017	26276	Economy	62100.00
0005432657526	26276	Economy	62100.00
0005433786188	26276	Economy	62100.00
0005433786147	26276	Economy	62100.00
0005433786027	26276	Economy	62100.00
0005433786148	26276	Economy	62100.00
0005433786115	26276	Economy	62100.00
0005433763628	26276	Economy	62100.00
0005433763627	26276	Economy	62100.00
0005433786033	26276	Economy	62100.00
0005433785999	26276	Economy	62100.00
0005432659768	26276	Economy	62100.00
0005433806215	26276	Economy	62100.00
0005433806327	26276	Economy	62100.00
0005433786112	26276	Economy	62100.00
0005433785885	26276	Economy	62100.00
0005433786152	26276	Economy	62100.00
0005435929719	4895	Economy	5300.00
0005435929718	4895	Economy	5300.00
0005435135802	33054	Economy	5300.00
0005435135801	33054	Economy	5300.00
0005434218083	9474	Economy	17900.00
0005434218082	9474	Economy	17900.00
0005434218075	9474	Economy	17900.00
0005434983407	27382	Economy	17900.00
0005434983408	27382	Economy	17900.00
0005433987089	24269	Business	36400.00
0005433987196	24269	Business	36400.00
0005433987267	24269	Business	36400.00
0005433962186	24269	Business	36400.00
0005433962298	24269	Business	36400.00
0005433962272	24269	Business	36400.00
0005433962367	24269	Business	36400.00
0005433962576	24269	Business	36400.00
0005433962519	24269	Business	36400.00
0005433987371	24269	Business	36400.00
0005433962531	24269	Business	36400.00
0005433962419	24269	Business	36400.00
0005433987307	24269	Business	36400.00
0005433987220	24269	Business	36400.00
0005433962379	24269	Business	36400.00
0005433987085	24269	Business	36400.00
0005433962323	24269	Business	36400.00
0005433962610	24269	Business	36400.00
0005433962542	24269	Business	36400.00
0005433962588	24269	Economy	13400.00
0005433987239	24269	Economy	13400.00
0005433962335	24269	Economy	13400.00
0005433962362	24269	Economy	12100.00
0005433987280	24269	Economy	12100.00
0005433962553	24269	Economy	12100.00
0005433962594	24269	Economy	12100.00
0005433987248	24269	Economy	12100.00
0005433987219	24269	Economy	12100.00
0005433962583	24269	Economy	12100.00
0005433987258	24269	Economy	12100.00
0005433962185	24269	Economy	12100.00
0005433962297	24269	Economy	12100.00
0005433987305	24269	Economy	12100.00
0005433962472	24269	Economy	12100.00
0005433962574	24269	Economy	12100.00
0005433987251	24269	Economy	12100.00
0005433987306	24269	Economy	12100.00
0005433987263	24269	Economy	12100.00
0005433962597	24269	Economy	12100.00
0005433962201	24269	Economy	12100.00
0005433987352	24269	Economy	12100.00
0005433987358	24269	Economy	12100.00
0005433962552	24269	Economy	12100.00
0005433962306	24269	Economy	12100.00
0005433987121	24269	Economy	12100.00
0005433987259	24269	Economy	12100.00
0005433987033	24269	Economy	12100.00
0005433962380	24269	Economy	12100.00
0005433962596	24269	Economy	12100.00
0005433962336	24269	Economy	12100.00
0005433962289	24269	Economy	12100.00
0005433987308	24269	Economy	12100.00
0005433962126	24269	Economy	12100.00
0005433962352	24269	Economy	12100.00
0005433962454	24269	Economy	12100.00
0005433962471	24269	Economy	12100.00
0005433962222	24269	Economy	12100.00
0005433962324	24269	Economy	12100.00
0005433962319	24269	Economy	12100.00
0005433962271	24269	Economy	12100.00
0005433962274	24269	Economy	12100.00
0005433962353	24269	Economy	12100.00
0005433987351	24269	Economy	12100.00
0005433987093	24269	Economy	12100.00
0005433987086	24269	Economy	12100.00
0005433962534	24269	Economy	12100.00
0005433962575	24269	Economy	12100.00
0005433962463	24269	Economy	12100.00
0005433962180	24269	Economy	12100.00
0005433962550	24269	Economy	13400.00
0005433962223	24269	Economy	13400.00
0005433987180	24269	Economy	12100.00
0005433962200	24269	Economy	13400.00
0005433987165	24269	Economy	12100.00
0005433962477	24269	Economy	12100.00
0005433962387	24269	Economy	12100.00
0005433962451	24269	Economy	12100.00
0005433987125	24269	Economy	12100.00
0005433962450	24269	Economy	12100.00
0005433987249	24269	Economy	12100.00
0005433962595	24269	Economy	12100.00
0005433962467	24269	Economy	12100.00
0005433962455	24269	Economy	12100.00
0005433987337	24269	Economy	12100.00
0005433962288	24269	Economy	12100.00
0005433987047	24269	Economy	12100.00
0005433987274	24269	Economy	12100.00
0005433962368	24269	Economy	12100.00
0005433987106	24269	Economy	12100.00
0005433987273	24269	Economy	12100.00
0005433987323	24269	Economy	12100.00
0005433962517	24269	Economy	12100.00
0005433962312	24269	Economy	12100.00
0005433987240	24269	Economy	12100.00
0005433987204	24269	Economy	12100.00
0005433962225	24269	Economy	12100.00
0005433962273	24269	Economy	12100.00
0005433987243	24269	Economy	12100.00
0005433962457	24269	Economy	12100.00
0005433962429	24269	Economy	12100.00
0005433962449	24269	Economy	12100.00
0005433987124	24269	Economy	12100.00
0005433987175	24269	Economy	12100.00
0005433962493	24269	Economy	12100.00
0005433987213	24269	Economy	12100.00
0005433987138	24269	Economy	12100.00
0005433987172	24269	Economy	12100.00
0005433962464	24269	Economy	12100.00
0005433962441	24269	Economy	12100.00
0005433962418	24269	Economy	12100.00
0005433987166	24269	Economy	12100.00
0005433987324	24269	Economy	12100.00
0005433962311	24269	Economy	12100.00
0005433962381	24269	Economy	12100.00
0005433962609	24269	Economy	12100.00
0005433987332	24269	Economy	12100.00
0005433166270	974	Economy	23100.00
0005434481023	16605	Economy	25400.00
0005434480978	16605	Economy	25400.00
0005434481002	16605	Economy	25400.00
0005434480923	16605	Economy	23100.00
0005434480953	16605	Economy	23100.00
0005434480991	16605	Economy	23100.00
0005434480979	16605	Economy	23100.00
0005434480916	16605	Economy	23100.00
0005434480993	16605	Economy	23100.00
0005434481003	16605	Economy	23100.00
0005434480980	16605	Economy	23100.00
0005434481041	16605	Economy	23100.00
0005434481014	16605	Economy	23100.00
0005434480976	16605	Economy	23100.00
0005434480981	16605	Economy	23100.00
0005434480922	16605	Economy	23100.00
0005434480965	16605	Economy	23100.00
0005434481015	16605	Economy	23100.00
0005434480977	16605	Economy	23100.00
0005433872564	32552	Economy	17200.00
0005433872579	32552	Economy	17200.00
0005433872575	32552	Economy	17200.00
0005433872574	32552	Economy	17200.00
0005433290057	10327	Economy	17000.00
0005435386729	10327	Economy	17000.00
0005435386748	10327	Economy	15400.00
0005435386736	10327	Economy	15400.00
0005435386749	10327	Economy	15400.00
0005435386730	10327	Economy	15400.00
0005433290058	10327	Economy	15400.00
0005433290039	10327	Economy	15400.00
0005433290033	10327	Economy	15400.00
0005435386758	10327	Economy	15400.00
0005433290040	10327	Economy	15400.00
0005433290046	10327	Economy	15400.00
0005433290060	10327	Economy	15400.00
0005433290016	10327	Economy	15400.00
0005435386757	10327	Economy	15400.00
0005433290049	10327	Economy	15400.00
0005435386735	10327	Economy	15400.00
0005435386755	10327	Economy	15400.00
0005433290032	10327	Economy	15400.00
0005433290061	10327	Economy	15400.00
0005435386756	10327	Economy	15400.00
0005435386728	10327	Economy	15400.00
0005435150388	21948	Economy	17000.00
0005435142957	21948	Economy	17000.00
0005435142947	21948	Economy	15400.00
0005435142956	21948	Economy	15400.00
0005435142927	21948	Economy	15400.00
0005435150345	21948	Economy	15400.00
0005435142903	21948	Economy	15400.00
0005435150390	21948	Economy	15400.00
0005435142904	21948	Economy	15400.00
0005435142946	21948	Economy	15400.00
0005435142937	21948	Economy	15400.00
0005435142931	21948	Economy	15400.00
0005435319810	11238	Business	57200.00
0005435502925	11238	Business	57200.00
0005435529863	11238	Business	57200.00
0005435529766	11238	Business	57200.00
0005435502918	11238	Business	57200.00
0005435502856	11238	Business	57200.00
0005435529864	11238	Economy	19100.00
0005435502858	11238	Economy	19100.00
0005435319811	11238	Economy	19100.00
0005435502933	11238	Economy	19100.00
0005435545964	11238	Economy	19100.00
0005435529870	11238	Economy	19100.00
0005435545968	11238	Economy	19100.00
0005435529800	11238	Economy	19100.00
0005435529765	11238	Economy	21000.00
0005435529783	11238	Economy	21000.00
0005435529878	11238	Economy	21000.00
0005435545956	11238	Economy	21000.00
0005435502923	11238	Economy	19100.00
0005435545938	11238	Economy	19100.00
0005435529830	11238	Economy	19100.00
0005435545944	11238	Economy	19100.00
0005435319791	11238	Economy	19100.00
0005435529872	11238	Economy	19100.00
0005435502884	11238	Economy	19100.00
0005435502931	11238	Economy	19100.00
0005435502926	11238	Economy	19100.00
0005435502885	11238	Economy	19100.00
0005435502930	11238	Economy	19100.00
0005435529820	11238	Economy	19100.00
0005435502857	11238	Economy	19100.00
0005435529829	11238	Economy	19100.00
0005435529771	11238	Economy	19100.00
0005435529855	11238	Economy	19100.00
0005435529804	11238	Economy	19100.00
0005435502872	11238	Economy	19100.00
0005435502875	11238	Economy	19100.00
0005435529785	11238	Economy	19100.00
0005435502883	11238	Economy	19100.00
0005435529801	11238	Economy	19100.00
0005435545959	11238	Economy	19100.00
0005435502887	11238	Economy	19100.00
0005435529736	11238	Economy	19100.00
0005435529875	11238	Economy	19100.00
0005435545965	11238	Economy	19100.00
0005435545927	11238	Economy	19100.00
0005435529819	11238	Economy	19100.00
0005435529849	11238	Economy	19100.00
0005435529762	11238	Economy	19100.00
0005435502934	11238	Economy	19100.00
0005435529879	11238	Economy	19100.00
0005435529869	11238	Economy	19100.00
0005435502945	11238	Economy	19100.00
0005435529848	11238	Economy	19100.00
0005435529772	11238	Economy	19100.00
0005435502924	11238	Economy	19100.00
0005435545945	11238	Economy	19100.00
0005435545955	11238	Economy	19100.00
0005435502863	11238	Economy	19100.00
0005435502899	11238	Economy	19100.00
0005435502907	11238	Economy	19100.00
0005434573729	20946	Business	57200.00
0005434573703	20946	Business	57200.00
0005434573707	20946	Economy	21000.00
0005434573679	20946	Economy	19100.00
0005434573681	20946	Economy	19100.00
0005434573734	20946	Economy	19100.00
0005434573680	20946	Economy	19100.00
0005434573758	20946	Economy	19100.00
0005434573731	20946	Economy	19100.00
0005434573714	20946	Economy	19100.00
0005432693952	2937	Business	10300.00
0005432693745	2937	Business	10300.00
0005432693953	2937	Business	10300.00
0005432693926	2937	Business	10300.00
0005432693906	2937	Economy	3400.00
0005432693736	2937	Economy	3800.00
0005432693909	2937	Economy	3400.00
0005432693927	2937	Economy	3400.00
0005432693853	2937	Economy	3400.00
0005432693943	2937	Economy	3400.00
0005432693735	2937	Economy	3400.00
0005432693848	2937	Economy	3400.00
0005432693920	2937	Economy	3400.00
0005432693905	2937	Economy	3400.00
0005432693777	2937	Economy	3400.00
0005432693939	2937	Economy	3400.00
0005432693816	2937	Economy	3400.00
0005432693942	2937	Economy	3400.00
0005432693783	2937	Economy	3400.00
0005432693903	2937	Economy	3400.00
0005432693964	2937	Economy	3400.00
0005432693923	2937	Economy	3400.00
0005433124485	2930	Business	10300.00
0005433124492	2930	Business	10300.00
0005433124427	2930	Business	10300.00
0005433194960	2930	Business	10300.00
0005433124508	2930	Business	10300.00
0005432881212	2930	Economy	3400.00
0005433194970	2930	Economy	3400.00
0005433194980	2930	Economy	3800.00
0005433194993	2930	Economy	3400.00
0005433194971	2930	Economy	3400.00
0005433194930	2930	Economy	3400.00
0005432881229	2930	Economy	3400.00
0005433194933	2930	Economy	3400.00
0005433194979	2930	Economy	3400.00
0005433194934	2930	Economy	3400.00
0005432881168	2930	Economy	3400.00
0005432881210	2930	Economy	3400.00
0005432881169	2930	Economy	3400.00
0005433124450	2930	Economy	3400.00
0005432881233	2930	Economy	3400.00
0005433124471	2930	Economy	3400.00
0005432881234	2930	Economy	3400.00
0005433124470	2930	Economy	3400.00
0005432881232	2930	Economy	3400.00
0005433124493	2930	Economy	3400.00
0005433124428	2930	Economy	3400.00
0005433194949	2930	Economy	3400.00
0005433124449	2930	Economy	3400.00
0005433194929	2930	Economy	3400.00
0005432707305	29924	Business	10300.00
0005432707419	29924	Business	10300.00
0005432707471	29924	Business	10300.00
0005432707431	29924	Economy	3400.00
0005432707462	29924	Economy	3400.00
0005432707488	29924	Economy	3400.00
0005432707418	29924	Economy	3800.00
0005432707490	29924	Economy	3800.00
0005432707474	29924	Economy	3400.00
0005432707491	29924	Economy	3400.00
0005432707487	29924	Economy	3400.00
0005432707489	29924	Economy	3400.00
0005432707470	29924	Economy	3400.00
0005432707493	29924	Economy	3400.00
0005432707468	29924	Economy	3400.00
0005432707406	29924	Economy	3400.00
0005432707407	29924	Economy	3400.00
0005432707461	29924	Economy	3400.00
0005432707492	29924	Economy	3400.00
0005432707417	29924	Economy	3400.00
0005434980678	23652	Economy	3600.00
0005434989135	23652	Economy	3600.00
0005434989012	27536	Economy	4000.00
0005434988994	27536	Economy	4000.00
0005434980563	27536	Economy	4000.00
0005434989020	27536	Economy	4000.00
0005434980591	27536	Economy	3600.00
0005434989013	27536	Economy	3600.00
0005434989086	27536	Economy	3600.00
0005434980525	27536	Economy	3600.00
0005434989034	27536	Economy	3600.00
0005434989074	27536	Economy	3600.00
0005434988983	27536	Economy	3600.00
0005434989073	27536	Economy	3600.00
0005434989024	27536	Economy	3600.00
0005434980612	27536	Economy	3600.00
0005434980581	27536	Economy	3600.00
0005434989081	27536	Economy	3600.00
0005434988995	27536	Economy	3600.00
0005434980629	27536	Economy	3600.00
0005434980644	27536	Economy	3600.00
0005434989050	27536	Economy	3600.00
0005434989019	27536	Economy	3600.00
0005434980530	27536	Economy	3600.00
0005434989014	27536	Economy	3600.00
0005434989036	27536	Economy	3600.00
0005434980547	27536	Economy	3600.00
0005434980574	27536	Economy	3600.00
0005434989068	27536	Economy	3600.00
0005434980621	27536	Economy	3600.00
0005434980564	27536	Economy	3600.00
0005434989015	27536	Economy	3600.00
0005434980582	27536	Economy	3600.00
0005434989067	27536	Economy	3600.00
0005434989066	27536	Economy	3600.00
0005434989025	27536	Economy	3600.00
0005434980565	27536	Economy	3600.00
0005434989077	27536	Economy	3600.00
0005434980500	27536	Economy	3600.00
0005434989037	27536	Economy	3600.00
0005434989043	27536	Economy	3600.00
0005434988984	27536	Economy	3600.00
0005434989053	27536	Economy	3600.00
0005434980596	27536	Economy	3600.00
0005434980633	27536	Economy	3600.00
0005434989052	27536	Economy	3600.00
0005433113596	10248	Economy	19700.00
0005433113595	10248	Economy	19700.00
0005433113590	10248	Economy	19700.00
0005433111551	10248	Economy	19700.00
0005434302568	19613	Economy	19700.00
0005434302580	19613	Economy	19700.00
0005434302577	19613	Economy	19700.00
0005434302565	19613	Economy	19700.00
0005435925697	3530	Business	26900.00
0005435925673	3530	Business	26900.00
0005435925721	3530	Business	26900.00
0005435925696	3530	Business	26900.00
0005435925631	3530	Economy	9000.00
0005435925722	3530	Economy	9000.00
0005435939955	3530	Economy	9000.00
0005435939954	3530	Economy	9000.00
0005435925683	3530	Economy	9000.00
0005435925672	3530	Economy	9000.00
0005435070517	15301	Business	26900.00
0005435950333	15301	Business	26900.00
0005435950308	15301	Business	26900.00
0005435070362	15301	Economy	9000.00
0005435070421	15301	Economy	9000.00
0005435070486	15301	Economy	9000.00
0005435070442	15301	Economy	9000.00
0005435070351	15301	Economy	9000.00
0005435070539	15301	Economy	9000.00
0005435950332	15301	Economy	9900.00
0005435070387	15301	Economy	9000.00
0005435070453	15301	Economy	9000.00
0005435950319	15301	Economy	9000.00
0005435070443	15301	Economy	9000.00
0005435070397	15301	Economy	9000.00
0005435925727	15301	Economy	9000.00
0005435070469	15301	Economy	9000.00
0005435950315	15301	Economy	9000.00
0005435070500	15301	Economy	9000.00
0005435070472	15301	Economy	9000.00
0005435070403	15301	Economy	9000.00
0005435070501	15301	Economy	9000.00
0005435070451	15301	Economy	9000.00
0005435070473	15301	Economy	9000.00
0005435950328	15301	Economy	9000.00
0005435070393	15301	Economy	9000.00
0005435070450	15301	Economy	9000.00
0005435070516	15301	Economy	9000.00
0005435070522	15301	Economy	9000.00
0005435070485	15301	Economy	9000.00
0005435070411	15301	Economy	9000.00
0005435070398	15301	Economy	9000.00
0005435070499	15301	Economy	9000.00
0005435070523	15301	Economy	9000.00
0005435950327	15301	Economy	9000.00
0005435070350	15301	Economy	9000.00
0005435070399	15301	Economy	9000.00
0005435950309	15301	Economy	9000.00
0005435070319	15301	Economy	9000.00
0005435070439	15301	Economy	9000.00
0005435070352	15301	Economy	9000.00
0005435070337	15301	Economy	9000.00
0005435950298	15301	Economy	9000.00
0005435950324	15301	Economy	9000.00
0005435950325	15301	Economy	9000.00
0005435950329	15301	Economy	9000.00
0005432664200	26422	Economy	5900.00
0005432660876	26422	Economy	5900.00
0005432660879	26422	Economy	5900.00
0005432664198	26422	Economy	5900.00
0005432660878	26422	Economy	5900.00
0005432664199	26422	Economy	5900.00
0005432667509	26422	Economy	5900.00
0005432664193	26422	Economy	5900.00
0005432664194	26422	Economy	5900.00
0005432660875	26422	Economy	5900.00
0005432660880	26422	Economy	5900.00
0005433103818	143	Business	20000.00
0005433103825	143	Business	20000.00
0005433103801	143	Business	20000.00
0005433435516	143	Business	20000.00
0005433103829	143	Business	20000.00
0005433103561	143	Business	20000.00
0005433435527	143	Business	20000.00
0005433103726	143	Business	20000.00
0005433103740	143	Business	20000.00
0005433103772	143	Business	20000.00
0005432902083	143	Business	20000.00
0005433103895	143	Business	20000.00
0005433103452	143	Business	20000.00
0005433103791	143	Business	20000.00
0005433103619	143	Business	20000.00
0005432920415	143	Business	20000.00
0005433103875	143	Business	20000.00
0005433103445	143	Business	20000.00
0005433103524	143	Business	20000.00
0005433103845	143	Business	20000.00
0005433103828	143	Economy	7300.00
0005433103673	143	Economy	7300.00
0005433103739	143	Economy	6700.00
0005432920443	143	Economy	6700.00
0005433103760	143	Economy	6700.00
0005432677681	143	Economy	6700.00
0005433103917	143	Economy	6700.00
0005433103738	143	Economy	6700.00
0005433103830	143	Economy	6700.00
0005433103450	143	Economy	6700.00
0005432677678	143	Economy	6700.00
0005433103488	143	Economy	6700.00
0005432920297	143	Economy	6700.00
0005433103832	143	Economy	6700.00
0005433103590	143	Economy	6700.00
0005433103518	143	Economy	6700.00
0005432920414	143	Economy	6700.00
0005432920296	143	Economy	6700.00
0005433103831	143	Economy	6700.00
0005433435528	143	Economy	6700.00
0005433103487	143	Economy	6700.00
0005433103716	143	Economy	6700.00
0005432902084	143	Economy	6700.00
0005433103612	143	Economy	6700.00
0005432902107	143	Economy	6700.00
0005433103681	143	Economy	6700.00
0005433103678	143	Economy	6700.00
0005432902095	143	Economy	6700.00
0005433435523	143	Economy	6700.00
0005433103421	143	Economy	6700.00
0005433103523	143	Economy	6700.00
0005433103571	143	Economy	6700.00
0005433103883	143	Economy	6700.00
0005433103912	143	Economy	6700.00
0005433103911	143	Economy	6700.00
0005433103566	143	Economy	6700.00
0005433103846	143	Economy	6700.00
0005432920449	143	Economy	6700.00
0005433103771	143	Economy	7300.00
0005433103976	143	Economy	7300.00
0005433103834	143	Economy	7300.00
0005433103620	143	Economy	6700.00
0005432902085	143	Economy	6700.00
0005433103674	143	Economy	6700.00
0005433103685	143	Economy	6700.00
0005433103717	143	Economy	7300.00
0005433103879	143	Economy	6700.00
0005433103560	143	Economy	6700.00
0005433103446	143	Economy	6700.00
0005433103675	143	Economy	6700.00
0005433103802	143	Economy	6700.00
0005433103592	143	Economy	6700.00
0005433103652	143	Economy	6700.00
0005433103822	143	Economy	6700.00
0005433103651	143	Economy	6700.00
0005433103876	143	Economy	6700.00
0005433103613	143	Economy	6700.00
0005432920455	143	Economy	6700.00
0005433103220	143	Economy	6700.00
0005433103536	143	Economy	6700.00
0005433103648	143	Economy	6700.00
0005433103844	143	Economy	6700.00
0005433103915	143	Economy	6700.00
0005433103683	143	Economy	6700.00
0005433103711	143	Economy	6700.00
0005433103793	143	Economy	6700.00
0005433103686	143	Economy	6700.00
0005432902096	143	Economy	6700.00
0005433103741	143	Economy	6700.00
0005433103900	143	Economy	6700.00
0005433103451	143	Economy	6700.00
0005433103871	143	Economy	6700.00
0005433103679	143	Economy	6700.00
0005433103884	143	Economy	6700.00
0005433103916	143	Economy	6700.00
0005433435510	143	Economy	6700.00
0005433435524	143	Economy	6700.00
0005433103855	143	Economy	6700.00
0005433103788	143	Economy	6700.00
0005433103689	143	Economy	6700.00
0005433103815	143	Economy	6700.00
0005433103826	143	Economy	6700.00
0005432677682	143	Economy	6700.00
0005433103712	143	Economy	6700.00
0005433477297	138	Business	20000.00
0005434157992	138	Business	20000.00
0005434157993	138	Economy	7300.00
0005434157990	138	Economy	7300.00
0005432753399	138	Economy	7300.00
0005432756935	138	Economy	6700.00
0005434157991	138	Economy	6700.00
0005432753376	138	Economy	6700.00
0005433690978	138	Economy	6700.00
0005433687758	138	Economy	6700.00
0005432753377	138	Economy	6700.00
0005432753378	138	Economy	7300.00
0005432263238	138	Economy	6700.00
0005433687749	138	Economy	6700.00
0005433477108	7923	Business	20000.00
0005433477230	7923	Business	20000.00
0005433477071	7923	Business	20000.00
0005433477222	7923	Business	20000.00
0005433477210	7923	Business	20000.00
0005434157752	7923	Business	20000.00
0005434157740	7923	Business	20000.00
0005434151813	7923	Business	20000.00
0005434157741	7923	Business	20000.00
0005433477228	7923	Business	20000.00
0005433477148	7923	Economy	6700.00
0005433477279	7923	Economy	6700.00
0005433477143	7923	Economy	6700.00
0005434157730	7923	Economy	6700.00
0005433477126	7923	Economy	6700.00
0005433477224	7923	Economy	6700.00
0005433477092	7923	Economy	6700.00
0005433477265	7923	Economy	6700.00
0005433477147	7923	Economy	6700.00
0005433477223	7923	Economy	6700.00
0005434157739	7923	Economy	7300.00
0005433477244	7923	Economy	6700.00
0005434157748	7923	Economy	6700.00
0005433477068	7923	Economy	6700.00
0005434151815	7923	Economy	6700.00
0005434157734	7923	Economy	6700.00
0005433104010	7923	Economy	6700.00
0005433477266	7923	Economy	6700.00
0005433477170	7923	Economy	6700.00
0005434157735	7923	Economy	6700.00
0005433477145	7923	Economy	6700.00
0005433104009	7923	Economy	6700.00
0005434157749	7923	Economy	6700.00
0005433477274	7923	Economy	6700.00
0005433477146	7923	Economy	6700.00
0005434157751	7923	Economy	6700.00
0005433477131	7923	Economy	6700.00
0005434151814	7923	Economy	6700.00
0005433477218	7923	Economy	6700.00
0005434157733	7923	Economy	6700.00
0005434151812	7923	Economy	6700.00
0005433477229	7923	Economy	6700.00
0005433477217	7923	Economy	6700.00
0005432818285	7922	Business	20000.00
0005434513639	7922	Business	20000.00
0005434513640	7922	Economy	6700.00
0005432818170	7922	Economy	6700.00
0005432818286	7922	Economy	6700.00
0005432818239	7922	Economy	6700.00
0005432818171	7922	Economy	6700.00
0005432818299	7922	Economy	6700.00
0005432818230	7922	Economy	6700.00
0005434513646	7922	Economy	6700.00
0005432818238	7922	Economy	6700.00
0005432818287	7922	Economy	6700.00
0005432818303	7922	Economy	6700.00
0005432818280	7922	Economy	6700.00
0005434513656	7922	Economy	6700.00
0005434513655	7922	Economy	6700.00
0005434513654	7922	Economy	6700.00
0005432818296	7922	Economy	6700.00
0005432818277	7922	Economy	6700.00
0005432818298	7922	Economy	6700.00
0005432818276	7922	Economy	6700.00
0005434513657	7922	Economy	6700.00
0005432818288	7922	Economy	6700.00
0005432818332	7922	Economy	6700.00
0005432818259	7922	Economy	6700.00
0005432818294	7922	Economy	6700.00
0005434175863	9688	Economy	6900.00
0005433870784	32331	Economy	6900.00
0005433870771	32331	Economy	6900.00
0005433870792	32331	Economy	6900.00
0005433870783	32331	Economy	6900.00
0005433870791	32331	Economy	6900.00
0005433870789	32331	Economy	6900.00
0005433870782	32331	Economy	6900.00
0005435914178	3493	Business	35000.00
0005435914190	3493	Business	35000.00
0005435914171	3493	Business	35000.00
0005435914192	3493	Comfort	19900.00
0005435903205	3493	Comfort	19900.00
0005435914139	3493	Comfort	19900.00
0005435903206	3493	Comfort	19900.00
0005435914138	3493	Comfort	19900.00
0005435914162	3493	Comfort	19900.00
0005435903180	3493	Comfort	19900.00
0005435914196	3493	Economy	11700.00
0005435903199	3493	Economy	11700.00
0005435914160	3493	Economy	11700.00
0005435914161	3493	Economy	11700.00
0005435903197	3493	Economy	11700.00
0005435914206	3493	Economy	11700.00
0005435903192	3493	Economy	11700.00
0005435914179	3493	Economy	11700.00
0005435903214	3493	Economy	11700.00
0005435914150	3493	Economy	11700.00
0005435914163	3493	Economy	11700.00
0005435903198	3493	Economy	11700.00
0005435914195	3493	Economy	11700.00
0005435914194	3493	Economy	11700.00
0005435914191	3493	Economy	11700.00
0005435914135	3493	Economy	11700.00
0005435914764	3493	Economy	11700.00
0005435903207	3493	Economy	11700.00
0005435914098	3493	Economy	11700.00
0005435914200	3493	Economy	11700.00
0005435914149	3493	Economy	11700.00
0005435914148	3493	Economy	11700.00
0005435914099	3493	Economy	11700.00
0005435903184	3493	Economy	11700.00
0005435914748	3493	Economy	11700.00
0005435903213	3493	Economy	11700.00
0005435914749	3493	Economy	11700.00
0005435914177	3493	Economy	11700.00
0005435914197	3493	Economy	11700.00
0005435626685	14592	Business	35000.00
0005434880872	14592	Business	35000.00
0005434938691	14592	Business	35000.00
0005435626697	14592	Business	35000.00
0005434880942	14592	Business	35000.00
0005434880886	14592	Business	35000.00
0005434880550	14592	Business	35000.00
0005435626812	14592	Business	35000.00
0005434938681	14592	Business	35000.00
0005434880841	14592	Business	35000.00
0005435127354	14592	Business	35000.00
0005435626740	14592	Business	35000.00
0005432611818	14592	Business	35000.00
0005435626707	14592	Comfort	19900.00
0005435626641	14592	Comfort	19900.00
0005432800226	14592	Comfort	19900.00
0005434880896	14592	Comfort	19900.00
0005434880874	14592	Comfort	19900.00
0005435127504	14592	Comfort	19900.00
0005434427411	14592	Comfort	19900.00
0005434880943	14592	Comfort	19900.00
0005434880861	14592	Comfort	19900.00
0005432611809	14592	Comfort	19900.00
0005434938607	14592	Comfort	19900.00
0005434938632	14592	Comfort	19900.00
0005435127469	14592	Comfort	19900.00
0005435626668	14592	Comfort	19900.00
0005435626717	14592	Comfort	19900.00
0005432611817	14592	Comfort	19900.00
0005434938690	14592	Comfort	19900.00
0005434880926	14592	Comfort	19900.00
0005432611815	14592	Comfort	19900.00
0005434880895	14592	Economy	11700.00
0005434880816	14592	Economy	11700.00
0005434880712	14592	Economy	11700.00
0005434880755	14592	Economy	11700.00
0005434427441	14592	Economy	11700.00
0005434880551	14592	Economy	11700.00
0005434880633	14592	Economy	11700.00
0005434427348	14592	Economy	11700.00
0005435127532	14592	Economy	11700.00
0005434880908	14592	Economy	11700.00
0005434938694	14592	Economy	11700.00
0005434880607	14592	Economy	11700.00
0005435127298	14592	Economy	11700.00
0005434880890	14592	Economy	11700.00
0005434880884	14592	Economy	11700.00
0005434880814	14592	Economy	11700.00
0005435127408	14592	Economy	11700.00
0005434880606	14592	Economy	11700.00
0005434938698	14592	Economy	11700.00
0005434880702	14592	Economy	11700.00
0005434880889	14592	Economy	11700.00
0005434880944	14592	Economy	11700.00
0005434880842	14592	Economy	11700.00
0005432800213	14592	Economy	11700.00
0005435626728	14592	Economy	11700.00
0005434880634	14592	Economy	11700.00
0005434880726	14592	Economy	11700.00
0005435626691	14592	Economy	11700.00
0005435127381	14592	Economy	11700.00
0005434427373	14592	Economy	11700.00
0005434880863	14592	Economy	11700.00
0005434880812	14592	Economy	11700.00
0005432800190	14592	Economy	11700.00
0005434880725	14592	Economy	11700.00
0005434880695	14592	Economy	11700.00
0005435127457	14592	Economy	11700.00
0005435127436	14592	Economy	11700.00
0005434880946	14592	Economy	11700.00
0005434880625	14592	Economy	11700.00
0005434880635	14592	Economy	12800.00
0005435127456	14592	Economy	11700.00
0005435626771	14592	Economy	12800.00
0005435626669	14592	Economy	12800.00
0005435127435	14592	Economy	11700.00
0005435127380	14592	Economy	11700.00
0005435127484	14592	Economy	11700.00
0005432607677	14592	Economy	11700.00
0005435626810	14592	Economy	11700.00
0005434427428	14592	Economy	11700.00
0005434427443	14592	Economy	11700.00
0005435127520	14592	Economy	11700.00
0005434427442	14592	Economy	11700.00
0005435626754	14592	Economy	11700.00
0005435626684	14592	Economy	11700.00
0005432611803	14592	Economy	11700.00
0005434427347	14592	Economy	11700.00
0005434880743	14592	Economy	11700.00
0005434880918	14592	Economy	11700.00
0005434427427	14592	Economy	11700.00
0005435626738	14592	Economy	11700.00
0005432800256	14592	Economy	11700.00
0005434880856	14592	Economy	11700.00
0005435127518	14592	Economy	11700.00
0005435626811	14592	Economy	11700.00
0005432800274	14592	Economy	11700.00
0005435626755	14592	Economy	11700.00
0005434938682	14592	Economy	11700.00
0005434938608	14592	Economy	11700.00
0005434427351	14592	Economy	11700.00
0005435127309	14592	Economy	11700.00
0005434938719	14592	Economy	11700.00
0005432800181	14592	Economy	11700.00
0005434880924	14592	Economy	11700.00
0005434880825	14592	Economy	11700.00
0005434880906	14592	Economy	11700.00
0005432611810	14592	Economy	11700.00
0005435626672	14592	Economy	11700.00
0005432611816	14592	Economy	11700.00
0005434427452	14592	Economy	11700.00
0005434427424	14592	Economy	11700.00
0005434880907	14592	Economy	11700.00
0005435626780	14592	Economy	11700.00
0005435626716	14592	Economy	11700.00
0005434880823	14592	Economy	11700.00
0005434938697	14592	Economy	11700.00
0005434880759	14592	Economy	11700.00
0005435626667	14592	Economy	11700.00
0005435626675	14592	Economy	11700.00
0005435626702	14592	Economy	11700.00
0005434880885	14592	Economy	11700.00
0005434427350	14592	Economy	11700.00
0005434427370	14592	Economy	11700.00
0005435626713	14592	Economy	11700.00
0005435127458	14592	Economy	11700.00
0005435127432	14592	Economy	11700.00
0005435127547	14592	Economy	11700.00
0005435127355	14592	Economy	11700.00
0005434880855	14592	Economy	11700.00
0005434880871	14592	Economy	11700.00
0005435127507	14592	Economy	12800.00
0005434938693	14592	Economy	12800.00
0005434427337	14592	Economy	12800.00
0005432800182	14592	Economy	12800.00
0005435127470	14592	Economy	11700.00
0005434880873	14592	Economy	11700.00
0005434880923	14592	Economy	11700.00
0005432607675	14592	Economy	11700.00
0005434880552	14592	Economy	11700.00
0005434880847	14592	Economy	11700.00
0005434938687	14592	Economy	11700.00
0005434938716	14592	Economy	11700.00
0005435626674	14592	Economy	11700.00
0005435626723	14592	Economy	11700.00
0005432800191	14592	Economy	11700.00
0005434880945	14592	Economy	11700.00
0005432800227	14592	Economy	11700.00
0005435127383	14592	Economy	11700.00
0005435626720	14592	Economy	11700.00
0005434427423	14592	Economy	11700.00
0005434880862	14592	Economy	11700.00
0005435127506	14592	Economy	11700.00
0005434880840	14592	Economy	11700.00
0005434880757	14592	Economy	11700.00
0005432800192	14592	Economy	11700.00
0005434880958	14592	Economy	11700.00
0005435626721	14592	Economy	11700.00
0005434880641	14592	Economy	11700.00
0005432611804	14592	Economy	11700.00
0005435626820	14592	Economy	11700.00
0005435626735	14592	Economy	11700.00
0005434938701	14592	Economy	11700.00
0005435127493	14592	Economy	11700.00
0005432800220	14592	Economy	11700.00
0005435626654	14592	Economy	11700.00
0005435127392	14592	Economy	11700.00
0005435626803	14592	Economy	11700.00
0005432800189	14592	Economy	11700.00
0005434880883	14592	Economy	11700.00
0005434880822	14592	Economy	11700.00
0005434880976	14592	Economy	11700.00
0005434880813	14592	Economy	11700.00
0005435626804	14592	Economy	11700.00
0005434880704	14592	Economy	11700.00
0005434880930	14592	Economy	11700.00
0005434880584	14592	Economy	11700.00
0005435127502	14592	Economy	11700.00
0005434938688	14592	Economy	11700.00
0005435626826	14592	Economy	11700.00
0005434880715	14592	Economy	11700.00
0005435626819	14592	Economy	11700.00
0005434880708	14592	Economy	11700.00
0005435127308	14592	Economy	11700.00
0005435127417	14592	Economy	11700.00
0005435127382	14592	Economy	11700.00
0005435626737	14592	Economy	11700.00
0005432800193	14592	Economy	11700.00
0005434880846	14592	Economy	11700.00
0005434880506	14592	Economy	11700.00
0005434880724	14592	Economy	11700.00
0005435127503	14592	Economy	11700.00
0005435626736	14592	Economy	11700.00
0005435890033	3590	Economy	14800.00
0005435890064	3590	Economy	14800.00
0005434325969	15633	Economy	14800.00
0005434325977	15633	Economy	14800.00
0005434311285	15633	Economy	14800.00
0005434311284	15633	Economy	14800.00
0005433420593	655	Economy	4100.00
0005433420592	655	Economy	4100.00
0005433420634	655	Economy	4100.00
0005433420619	655	Economy	4100.00
0005433420647	655	Economy	4100.00
0005435958087	15189	Economy	4500.00
0005435958103	15189	Economy	4500.00
0005435958071	15189	Economy	4100.00
0005435958110	15189	Economy	4100.00
0005435958050	15189	Economy	4100.00
0005435958109	15189	Economy	4100.00
0005435958051	15189	Economy	4100.00
0005435958060	15189	Economy	4100.00
0005435958061	15189	Economy	4100.00
0005435958115	15189	Economy	4100.00
0005435216639	27260	Economy	28100.00
0005435221073	27260	Economy	28100.00
0005435219251	27260	Economy	25500.00
0005435216636	27260	Economy	25500.00
0005435216637	27260	Economy	25500.00
0005435219254	27260	Economy	25500.00
0005435219247	27260	Economy	25500.00
0005435221082	27260	Economy	25500.00
0005435216638	27260	Economy	25500.00
0005435221074	27260	Economy	25500.00
0005435221072	27260	Economy	25500.00
0005435216651	27260	Economy	25500.00
0005435216645	27260	Economy	25500.00
0005435219253	27260	Economy	25500.00
0005435219258	27260	Economy	25500.00
0005435216652	27260	Economy	25500.00
0005435216650	27260	Economy	25500.00
0005435221080	27260	Economy	25500.00
0005435219259	27260	Economy	25500.00
0005435216641	27260	Economy	25500.00
0005435221081	27260	Economy	25500.00
0005435216649	27260	Economy	25500.00
0005435216640	27260	Economy	25500.00
0005435219255	27260	Economy	25500.00
0005435219252	27260	Economy	25500.00
0005434247221	8884	Economy	10400.00
0005434247216	8884	Economy	10400.00
0005435163391	4427	Economy	13400.00
0005435933549	4427	Economy	12200.00
0005435933550	4427	Economy	12200.00
0005435163390	4427	Economy	12200.00
0005435933539	4427	Economy	12200.00
0005433405031	2861	Business	12600.00
0005433405025	2861	Business	12600.00
0005433405007	2861	Business	12600.00
0005433405015	2861	Economy	4200.00
0005433405005	2861	Economy	4600.00
0005433405028	2861	Economy	4200.00
0005433405001	2861	Economy	4200.00
0005433405002	2861	Economy	4200.00
0005435797895	29305	Business	12600.00
0005435797881	29305	Economy	4200.00
0005435797887	29305	Economy	4200.00
0005435797894	29305	Economy	4200.00
0005435797864	29305	Economy	4200.00
0005435797843	29305	Economy	4200.00
0005435376421	5796	Economy	6800.00
0005435376420	5796	Economy	6800.00
0005434948256	16372	Economy	6800.00
0005434948257	16372	Economy	6800.00
0005434948212	16372	Economy	6800.00
0005434948250	16372	Economy	6800.00
0005434948247	16372	Economy	6800.00
0005434948262	16372	Economy	6800.00
0005434948251	16372	Economy	6800.00
0005434948213	16372	Economy	6800.00
0005434948246	16372	Economy	6800.00
0005433962207	25700	Business	21400.00
0005433962247	25700	Business	21400.00
0005433962375	25700	Business	21400.00
0005433962487	25700	Business	21400.00
0005433962401	25700	Business	21400.00
0005433962226	25700	Business	21400.00
0005433962304	25700	Business	21400.00
0005433962366	25700	Business	21400.00
0005433962392	25700	Business	21400.00
0005433962341	25700	Economy	7100.00
0005433962307	25700	Economy	7100.00
0005433962204	25700	Economy	7100.00
0005433962296	25700	Economy	7100.00
0005433962300	25700	Economy	7100.00
0005433962229	25700	Economy	7100.00
0005433962301	25700	Economy	7100.00
0005433962363	25700	Economy	7800.00
0005433962394	25700	Economy	7800.00
0005433962480	25700	Economy	7800.00
0005433962414	25700	Economy	7800.00
0005433962293	25700	Economy	7100.00
0005433962437	25700	Economy	7100.00
0005433962266	25700	Economy	7100.00
0005433962267	25700	Economy	7100.00
0005433962365	25700	Economy	7100.00
0005433962334	25700	Economy	7100.00
0005433962337	25700	Economy	7100.00
0005433962255	25700	Economy	7100.00
0005433962351	25700	Economy	7100.00
0005433962459	25700	Economy	7100.00
0005433962364	25700	Economy	7100.00
0005433962423	25700	Economy	7100.00
0005433962220	25700	Economy	7100.00
0005433962299	25700	Economy	7100.00
0005433962254	25700	Economy	7100.00
0005433962425	25700	Economy	7100.00
0005433962219	25700	Economy	7100.00
0005433962424	25700	Economy	7100.00
0005433962203	25700	Economy	7100.00
0005433962227	25700	Economy	7100.00
0005433962242	25700	Economy	7100.00
0005433962447	25700	Economy	7100.00
0005433962268	25700	Economy	7100.00
0005433962342	25700	Economy	7100.00
0005433962303	25700	Economy	7100.00
0005433962210	25700	Economy	7100.00
0005433962253	25700	Economy	7100.00
0005433962376	25700	Economy	7100.00
0005433962343	25700	Economy	7100.00
0005433961929	25700	Economy	7100.00
0005433962294	25700	Economy	7100.00
0005433962390	25700	Economy	7100.00
0005433962237	25700	Economy	7100.00
0005433961930	25700	Economy	7100.00
0005433962458	25700	Economy	7100.00
0005433962321	25700	Economy	7100.00
0005433962350	25700	Economy	7100.00
0005433962099	25700	Economy	7100.00
0005433962067	25700	Economy	7100.00
0005433962413	25700	Economy	7100.00
0005433962333	25700	Economy	7100.00
0005435083009	24554	Economy	3900.00
0005435082965	24554	Economy	3900.00
0005435082997	24554	Economy	3900.00
0005435083016	24554	Economy	3900.00
0005435083031	24554	Economy	3900.00
0005435377992	26083	Economy	3900.00
0005435377991	26083	Economy	3900.00
0005435286931	4941	Business	18000.00
0005435286959	4941	Business	18000.00
0005435286894	4941	Business	18000.00
0005435286935	4941	Business	18000.00
0005435426860	4941	Business	18000.00
0005435286765	4941	Business	18000.00
0005435286836	4941	Business	18000.00
0005435286764	4941	Business	18000.00
0005435286840	4941	Economy	6600.00
0005433534552	4941	Economy	6000.00
0005435286870	4941	Economy	6000.00
0005435286967	4941	Economy	6000.00
0005435286999	4941	Economy	6000.00
0005435286895	4941	Economy	6000.00
0005435286998	4941	Economy	6000.00
0005435286912	4941	Economy	6000.00
0005435286913	4941	Economy	6000.00
0005435286972	4941	Economy	6000.00
0005435286873	4941	Economy	6000.00
0005435286925	4941	Economy	6000.00
0005435286818	4941	Economy	6000.00
0005435286892	4941	Economy	6000.00
0005435286842	4941	Economy	6000.00
0005435286941	4941	Economy	6000.00
0005435286834	4941	Economy	6000.00
0005435286872	4941	Economy	6000.00
0005435286893	4941	Economy	6000.00
0005435286874	4941	Economy	6000.00
0005435286871	4941	Economy	6000.00
0005435286766	4941	Economy	6000.00
0005435286950	4941	Economy	6000.00
0005435286923	4941	Economy	6000.00
0005435286762	4941	Economy	6000.00
0005433534562	4941	Economy	6600.00
0005435286835	4941	Economy	6600.00
0005435286951	4941	Economy	6000.00
0005435286789	4941	Economy	6000.00
0005435286819	4941	Economy	6000.00
0005435287025	4941	Economy	6000.00
0005435286968	4941	Economy	6000.00
0005435286971	4941	Economy	6000.00
0005435426858	4941	Economy	6000.00
0005435286849	4941	Economy	6000.00
0005435286922	4941	Economy	6000.00
0005435286924	4941	Economy	6000.00
0005435286896	4941	Economy	6000.00
0005435286943	4941	Economy	6000.00
0005435286940	4941	Economy	6000.00
0005435286812	4941	Economy	6000.00
0005435286841	4941	Economy	6000.00
0005435286970	4941	Economy	6000.00
0005435286885	4941	Economy	6000.00
0005435732731	5241	Business	18000.00
0005435007645	5241	Business	18000.00
0005435270178	5241	Business	18000.00
0005432336355	5241	Business	18000.00
0005435270161	5241	Business	18000.00
0005435270034	5241	Business	18000.00
0005435007634	5241	Business	18000.00
0005435270141	5241	Business	18000.00
0005433815517	5241	Business	18000.00
0005435270144	5241	Business	18000.00
0005435007658	5241	Economy	6600.00
0005435270153	5241	Economy	6600.00
0005435270104	5241	Economy	6600.00
0005435270166	5241	Economy	6600.00
0005433815516	5241	Economy	6600.00
0005432336370	5241	Economy	6000.00
0005435007653	5241	Economy	6000.00
0005433685579	5241	Economy	6000.00
0005435007654	5241	Economy	6000.00
0005435007657	5241	Economy	6000.00
0005435270139	5241	Economy	6000.00
0005435270032	5241	Economy	6000.00
0005435270024	5241	Economy	6000.00
0005432336291	5241	Economy	6000.00
0005435270116	5241	Economy	6000.00
0005435007672	5241	Economy	6000.00
0005435270071	5241	Economy	6000.00
0005432336374	5241	Economy	6000.00
0005435270194	5241	Economy	6000.00
0005433815513	5241	Economy	6000.00
0005435007618	5241	Economy	6000.00
0005435270009	5241	Economy	6000.00
0005435007655	5241	Economy	6000.00
0005435269934	5241	Economy	6000.00
0005435007650	5241	Economy	6000.00
0005435270008	5241	Economy	6000.00
0005435007651	5241	Economy	6000.00
0005435270056	5241	Economy	6000.00
0005435007617	5241	Economy	6000.00
0005435270179	5241	Economy	6000.00
0005432336364	5241	Economy	6000.00
0005435270145	5241	Economy	6000.00
0005435270140	5241	Economy	6000.00
0005432336354	5241	Economy	6000.00
0005432336384	5241	Economy	6000.00
0005435270133	5241	Economy	6000.00
0005435270169	5241	Economy	6000.00
0005435270117	5241	Economy	6000.00
0005434312375	5241	Economy	6000.00
0005435732732	5241	Economy	6000.00
0005433685580	5241	Economy	6000.00
0005435270033	5241	Economy	6000.00
0005435270196	5241	Economy	6000.00
0005435270158	5241	Economy	6000.00
0005432336363	5241	Economy	6000.00
0005435270130	5241	Economy	6000.00
0005435270195	5241	Economy	6000.00
0005435007678	5241	Economy	6000.00
0005432336369	5241	Economy	6000.00
0005434312374	5241	Economy	6000.00
0005435007633	5241	Economy	6000.00
0005433785882	8412	Business	18000.00
0005433785988	8412	Business	18000.00
0005433785838	8412	Business	18000.00
0005433786033	8412	Business	18000.00
0005433785850	8412	Business	18000.00
0005434245813	8412	Business	18000.00
0005434245814	8412	Business	18000.00
0005433786188	8412	Business	18000.00
0005432663099	8412	Business	18000.00
0005434245766	8412	Business	18000.00
0005433785976	8412	Business	18000.00
0005433785975	8412	Economy	6000.00
0005433785989	8412	Economy	6000.00
0005433785886	8412	Economy	6000.00
0005433785999	8412	Economy	6000.00
0005433786152	8412	Economy	6000.00
0005433785849	8412	Economy	6000.00
0005433786038	8412	Economy	6000.00
0005432663087	8412	Economy	6000.00
0005433785875	8412	Economy	6000.00
0005434245772	8412	Economy	6000.00
0005433786147	8412	Economy	6000.00
0005434245702	8412	Economy	6000.00
0005433786039	8412	Economy	6000.00
0005432659768	8412	Economy	6000.00
0005432659764	8412	Economy	6000.00
0005434245723	8412	Economy	6000.00
0005433786121	8412	Economy	6000.00
0005432666437	8412	Economy	6000.00
0005433785885	8412	Economy	6000.00
0005433785956	8412	Economy	6000.00
0005433786095	8412	Economy	6000.00
0005433786148	8412	Economy	6000.00
0005433785717	8412	Economy	6000.00
0005433786112	8412	Economy	6600.00
0005433785870	8412	Economy	6000.00
0005434245837	8412	Economy	6000.00
0005433785941	8412	Economy	6000.00
0005433786041	8412	Economy	6000.00
0005434245771	8412	Economy	6000.00
0005433786042	8412	Economy	6000.00
0005432666438	8412	Economy	6000.00
0005434245706	8412	Economy	6000.00
0005433786043	8412	Economy	6000.00
0005433786027	8412	Economy	6000.00
0005433786153	8412	Economy	6000.00
0005433785914	8412	Economy	6000.00
0005433786115	8412	Economy	6000.00
0005432663086	8412	Economy	6000.00
0005434245767	8412	Economy	6000.00
0005433786026	8412	Economy	6000.00
0005432663088	8412	Economy	6000.00
0005433785966	8412	Economy	6000.00
0005434245701	8412	Economy	6000.00
0005433785958	8412	Economy	6000.00
0005434245797	8412	Economy	6000.00
0005433786017	8412	Economy	6000.00
0005433616597	8411	Business	18000.00
0005433616509	8411	Business	18000.00
0005433616653	8411	Business	18000.00
0005433616567	8411	Business	18000.00
0005433616261	8411	Business	18000.00
0005433616313	8411	Business	18000.00
0005433616629	8411	Business	18000.00
0005433616810	8411	Business	18000.00
0005433616763	8411	Economy	6600.00
0005433616598	8411	Economy	6600.00
0005433616673	8411	Economy	6600.00
0005433616322	8411	Economy	6000.00
0005433616476	8411	Economy	6000.00
0005433616500	8411	Economy	6000.00
0005433616681	8411	Economy	6000.00
0005433616398	8411	Economy	6000.00
0005433616731	8411	Economy	6000.00
0005433616262	8411	Economy	6000.00
0005433616667	8411	Economy	6000.00
0005433616741	8411	Economy	6000.00
0005433616399	8411	Economy	6000.00
0005433616426	8411	Economy	6000.00
0005433616651	8411	Economy	6000.00
0005433616389	8411	Economy	6000.00
0005433616621	8411	Economy	6000.00
0005433616620	8411	Economy	6000.00
0005433616501	8411	Economy	6000.00
0005433616508	8411	Economy	6000.00
0005433616421	8411	Economy	6000.00
0005434230050	8411	Economy	6000.00
0005433616747	8411	Economy	6000.00
0005433616540	8411	Economy	6000.00
0005433616575	8411	Economy	6600.00
0005433616613	8411	Economy	6600.00
0005433616708	8411	Economy	6000.00
0005433616772	8411	Economy	6000.00
0005433616542	8411	Economy	6000.00
0005433616655	8411	Economy	6000.00
0005433616730	8411	Economy	6000.00
0005433616654	8411	Economy	6000.00
0005433616541	8411	Economy	6000.00
0005433616628	8411	Economy	6000.00
0005433616607	8411	Economy	6000.00
0005433616817	8411	Economy	6000.00
0005433616696	8411	Economy	6000.00
0005433616709	8411	Economy	6000.00
0005433616692	8411	Economy	6000.00
0005433616397	8411	Economy	6000.00
0005433616661	8411	Economy	6000.00
0005433616506	8411	Economy	6000.00
0005433616574	8411	Economy	6000.00
0005433616614	8411	Economy	6000.00
0005433616573	8411	Economy	6000.00
0005433616771	8411	Economy	6000.00
0005433616390	8411	Economy	6000.00
0005433616682	8411	Economy	6000.00
0005433616555	8411	Economy	6000.00
0005434229972	8410	Business	18000.00
0005434150058	8410	Business	18000.00
0005434150016	8410	Business	18000.00
0005434229851	8410	Business	18000.00
0005434265854	8410	Business	18000.00
0005434150050	8410	Business	18000.00
0005434229974	8410	Economy	6600.00
0005434265857	8410	Economy	6600.00
0005434229947	8410	Economy	6000.00
0005434265873	8410	Economy	6000.00
0005434229921	8410	Economy	6000.00
0005434265856	8410	Economy	6000.00
0005434265822	8410	Economy	6000.00
0005434150066	8410	Economy	6000.00
0005434229978	8410	Economy	6000.00
0005434265855	8410	Economy	6000.00
0005434150015	8410	Economy	6000.00
0005434173631	8410	Economy	6000.00
0005434229983	8410	Economy	6000.00
0005434265821	8410	Economy	6000.00
0005434265791	8410	Economy	6000.00
0005434173625	8410	Economy	6000.00
0005434229941	8410	Economy	6000.00
0005434150073	8410	Economy	6000.00
0005434265795	8410	Economy	6600.00
0005434265845	8410	Economy	6000.00
0005434265829	8410	Economy	6000.00
0005434150059	8410	Economy	6000.00
0005434229973	8410	Economy	6000.00
0005434265836	8410	Economy	6000.00
0005434229922	8410	Economy	6000.00
0005434229939	8410	Economy	6000.00
0005434229931	8410	Economy	6000.00
0005434265776	8410	Economy	6000.00
0005434150047	8410	Economy	6000.00
0005434229971	8410	Economy	6000.00
0005434229975	8410	Economy	6000.00
0005434229985	8410	Economy	6000.00
0005434265794	8410	Economy	6000.00
0005434265757	8410	Economy	6000.00
0005434173630	8410	Economy	6000.00
0005434229852	8410	Economy	6000.00
0005434265879	8410	Economy	6000.00
0005434229942	8410	Economy	6000.00
0005434230002	8410	Economy	6000.00
0005434150074	8410	Economy	6000.00
0005434640036	12607	Economy	16200.00
0005434640035	12607	Economy	14800.00
0005434639952	12607	Economy	14800.00
0005434640087	12607	Economy	14800.00
0005434640025	12607	Economy	14800.00
0005434639947	12607	Economy	14800.00
0005434640079	12607	Economy	14800.00
0005434639945	12607	Economy	14800.00
0005434640088	12607	Economy	14800.00
0005434640072	12607	Economy	14800.00
0005434640000	12607	Economy	14800.00
0005434639951	12607	Economy	14800.00
0005434640023	12607	Economy	14800.00
0005434640071	12607	Economy	14800.00
0005434640080	12607	Economy	14800.00
0005434640064	12607	Economy	14800.00
0005434639946	12607	Economy	14800.00
0005433202768	23359	Economy	16200.00
0005433202767	23359	Economy	14800.00
0005433202714	23359	Economy	14800.00
0005433202766	23359	Economy	14800.00
0005433202770	23359	Economy	14800.00
0005434640107	23359	Economy	14800.00
0005433202728	23359	Economy	14800.00
0005434640108	23359	Economy	14800.00
0005433202731	23359	Economy	14800.00
0005433202744	23359	Economy	14800.00
0005433202769	23359	Economy	14800.00
0005433202765	23359	Economy	14800.00
0005433202743	23359	Economy	14800.00
0005433202763	23359	Economy	14800.00
0005432384204	21055	Business	18900.00
0005432384072	21055	Business	18900.00
0005432384234	21055	Business	18900.00
0005432384172	21055	Business	18900.00
0005432329732	21055	Business	18900.00
0005432384202	21055	Business	18900.00
0005432329882	21055	Economy	6300.00
0005432329976	21055	Economy	6300.00
0005432384279	21055	Economy	6300.00
0005432329888	21055	Economy	6300.00
0005432384241	21055	Economy	6300.00
0005432384169	21055	Economy	6900.00
0005432330035	21055	Economy	6900.00
0005432329935	21055	Economy	6900.00
0005432329883	21055	Economy	6300.00
0005432329822	21055	Economy	6300.00
0005432384233	21055	Economy	6300.00
0005432384131	21055	Economy	6300.00
0005432329816	21055	Economy	6300.00
0005432329947	21055	Economy	6300.00
0005432329825	21055	Economy	6300.00
0005432384264	21055	Economy	6300.00
0005432329733	21055	Economy	6300.00
0005432329774	21055	Economy	6300.00
0005432329948	21055	Economy	6300.00
0005432384211	21055	Economy	6300.00
0005432384198	21055	Economy	6300.00
0005432384148	21055	Economy	6300.00
0005432329977	21055	Economy	6300.00
0005432384281	21055	Economy	6300.00
0005432384132	21055	Economy	6300.00
0005432330051	21055	Economy	6300.00
0005432329985	21055	Economy	6300.00
0005432329866	21055	Economy	6300.00
0005432384195	21055	Economy	6300.00
0005432384170	21055	Economy	6300.00
0005432329934	21055	Economy	6300.00
0005432384280	21055	Economy	6300.00
0005432329864	21055	Economy	6300.00
0005432329984	21055	Economy	6300.00
0005432329887	21055	Economy	6300.00
0005432384114	21055	Economy	6300.00
0005432384205	21055	Economy	6300.00
0005432329933	21055	Economy	6300.00
0005432330007	21055	Economy	6300.00
0005432384296	21055	Economy	6300.00
0005432384271	21055	Economy	6300.00
0005432329884	21055	Economy	6300.00
0005432329857	21055	Economy	6300.00
0005432329867	21055	Economy	6300.00
0005432384157	21055	Economy	6300.00
0005432384252	21055	Economy	6300.00
0005432384240	21055	Economy	6300.00
0005432384253	21055	Economy	6300.00
0005432848907	31242	Business	18900.00
0005432848896	31242	Economy	6300.00
0005432848908	31242	Economy	6900.00
0005432848895	31242	Economy	6300.00
0005432848909	31242	Economy	6300.00
0005432330063	31242	Economy	6300.00
0005432954185	2489	Business	89600.00
0005432954143	2489	Economy	32800.00
0005432954152	2489	Economy	29900.00
0005432954159	2489	Economy	29900.00
0005432954157	2489	Economy	29900.00
0005432954163	2489	Economy	29900.00
0005432954183	2489	Economy	29900.00
0005432954161	2489	Economy	29900.00
0005432954130	2489	Economy	29900.00
0005432954162	2489	Economy	29900.00
0005432954135	2489	Economy	29900.00
0005432954164	2489	Economy	29900.00
0005432954175	2489	Economy	29900.00
0005432954184	2489	Economy	29900.00
0005432954154	2489	Economy	29900.00
0005432954158	2489	Economy	29900.00
0005432954151	2489	Economy	29900.00
0005433642771	27579	Business	89600.00
0005433642695	27579	Economy	29900.00
0005432954200	27579	Economy	29900.00
0005433642746	27579	Economy	29900.00
0005433642773	27579	Economy	32800.00
0005433642694	27579	Economy	32800.00
0005433642766	27579	Economy	29900.00
0005433642756	27579	Economy	29900.00
0005433642691	27579	Economy	29900.00
0005433642770	27579	Economy	29900.00
0005433642745	27579	Economy	29900.00
0005433642758	27579	Economy	29900.00
0005433642716	27579	Economy	29900.00
0005433642724	27579	Economy	29900.00
0005433642697	27579	Economy	29900.00
0005433642759	27579	Economy	29900.00
0005433642768	27579	Economy	29900.00
0005433642696	27579	Economy	29900.00
0005433642743	27579	Economy	29900.00
0005432954201	27579	Economy	29900.00
0005433642757	27579	Economy	29900.00
0005433642744	27579	Economy	29900.00
0005433642717	27579	Economy	29900.00
0005433642715	27579	Economy	29900.00
0005433642733	27579	Economy	29900.00
0005432426078	13369	Business	12700.00
0005432425862	30707	Business	12700.00
0005432425824	30707	Business	12700.00
0005432425864	30707	Business	12700.00
0005432425852	30707	Business	12700.00
0005432425682	30707	Business	12700.00
0005432425783	30707	Business	12700.00
0005432425853	30707	Business	12700.00
0005432425797	30707	Business	12700.00
0005432425732	30707	Business	12700.00
0005432425775	30707	Economy	4200.00
0005432425746	30707	Economy	4200.00
0005432425589	30707	Economy	4200.00
0005432425707	30707	Economy	4200.00
0005432425842	30707	Economy	4200.00
0005432425764	30707	Economy	4200.00
0005432425735	30707	Economy	4200.00
0005432425836	30707	Economy	4200.00
0005432425700	30707	Economy	4200.00
0005432425677	30707	Economy	4700.00
0005432425785	30707	Economy	4700.00
0005432425650	30707	Economy	4700.00
0005432425790	30707	Economy	4700.00
0005432425631	30707	Economy	4700.00
0005432425774	30707	Economy	4200.00
0005432425770	30707	Economy	4200.00
0005432425859	30707	Economy	4200.00
0005432425858	30707	Economy	4200.00
0005432425851	30707	Economy	4200.00
0005432425772	30707	Economy	4200.00
0005432425733	30707	Economy	4200.00
0005432425741	30707	Economy	4200.00
0005432425710	30707	Economy	4200.00
0005432425759	30707	Economy	4200.00
0005432425793	30707	Economy	4200.00
0005432425684	30707	Economy	4200.00
0005432425809	30707	Economy	4200.00
0005432425831	30707	Economy	4200.00
0005432425681	30707	Economy	4200.00
0005432425832	30707	Economy	4200.00
0005432425706	30707	Economy	4200.00
0005432425860	30707	Economy	4200.00
0005432425678	30707	Economy	4200.00
0005432425796	30707	Economy	4200.00
0005432425863	30707	Economy	4200.00
0005432425708	30707	Economy	4200.00
0005432425768	30707	Economy	4200.00
0005432425798	30707	Economy	4200.00
0005432425745	30707	Economy	4200.00
0005432425780	30707	Economy	4200.00
0005432425590	30707	Economy	4200.00
0005432425728	30707	Economy	4200.00
0005432425649	30707	Economy	4200.00
0005432425717	30707	Economy	4200.00
0005432425817	30707	Economy	4200.00
0005432425799	30707	Economy	4200.00
0005432425816	30707	Economy	4200.00
0005432425773	30707	Economy	4200.00
0005432425841	30707	Economy	4200.00
0005432425779	30707	Economy	4200.00
0005432425795	30707	Economy	4200.00
0005432425803	30707	Economy	4200.00
0005432425740	30707	Economy	4200.00
0005432425712	30707	Economy	4200.00
0005432425680	30707	Economy	4200.00
0005432425676	30707	Economy	4200.00
0005432425632	30707	Economy	4200.00
0005432425737	30707	Economy	4200.00
0005432425771	30707	Economy	4200.00
0005432425713	30707	Economy	4200.00
0005432425709	30707	Economy	4200.00
0005432425727	30707	Economy	4200.00
0005432425769	30707	Economy	4200.00
0005432902046	9595	Business	32600.00
0005434186277	9595	Business	32600.00
0005432902090	9595	Business	32600.00
0005432902087	9595	Economy	10900.00
0005434157715	9595	Economy	10900.00
0005432902033	9595	Economy	11900.00
0005432902116	9595	Economy	11900.00
0005434157693	9595	Economy	10900.00
0005432902114	9595	Economy	10900.00
0005434186279	9595	Economy	10900.00
0005434186284	9595	Economy	10900.00
0005434186283	9595	Economy	10900.00
0005434186278	9595	Economy	10900.00
0005432902088	9595	Economy	10900.00
0005432902053	9595	Economy	10900.00
0005434157705	9595	Economy	10900.00
0005434157699	9595	Economy	10900.00
0005434186276	9595	Economy	10900.00
0005434186282	9595	Economy	10900.00
0005434157698	9595	Economy	10900.00
0005432902089	9595	Economy	10900.00
0005432818296	28998	Business	32600.00
0005432818259	28998	Business	32600.00
0005432822417	28998	Business	32600.00
0005432818294	28998	Business	32600.00
0005434448412	28998	Business	32600.00
0005432818238	28998	Economy	10900.00
0005432818285	28998	Economy	11900.00
0005432818276	28998	Economy	10900.00
0005432818239	28998	Economy	10900.00
0005432822410	28998	Economy	10900.00
0005432818171	28998	Economy	10900.00
0005432822384	28998	Economy	10900.00
0005432818287	28998	Economy	10900.00
0005432822424	28998	Economy	10900.00
0005432818332	28998	Economy	10900.00
0005434186286	28998	Economy	10900.00
0005432818277	28998	Economy	10900.00
0005432818170	28998	Economy	10900.00
0005432818298	28998	Economy	10900.00
0005432818288	28998	Economy	10900.00
0005432818230	28998	Economy	10900.00
0005432822416	28998	Economy	10900.00
0005432818299	28998	Economy	10900.00
0005432818286	28998	Economy	10900.00
0005434448411	28998	Economy	10900.00
0005432818280	28998	Economy	10900.00
0005432818303	28998	Economy	10900.00
0005432611804	31600	Economy	11000.00
0005432611810	31600	Economy	11000.00
0005432611816	31600	Economy	11000.00
0005432611818	31600	Economy	11000.00
0005432611817	31600	Economy	11000.00
0005432607675	31600	Economy	11000.00
0005432607677	31600	Economy	11000.00
0005432611809	31600	Economy	11000.00
0005432611803	31600	Economy	11000.00
0005432611815	31600	Economy	11000.00
0005432949537	11834	Business	105900.00
0005432949481	11834	Business	105900.00
0005432949551	11834	Economy	35300.00
0005433570989	11834	Economy	35300.00
0005432949566	11834	Economy	35300.00
0005432949346	11834	Economy	35300.00
0005432949536	11834	Economy	35300.00
0005432949610	11834	Economy	38800.00
0005432949588	11834	Economy	35300.00
0005432949589	11834	Economy	35300.00
0005432949378	11834	Economy	35300.00
0005432949567	11834	Economy	35300.00
0005432949494	11834	Economy	35300.00
0005432949452	11834	Economy	35300.00
0005432949399	11834	Economy	35300.00
0005432949592	11834	Economy	35300.00
0005432949591	11834	Economy	35300.00
0005432949609	11834	Economy	35300.00
0005432949575	11834	Economy	35300.00
0005432949398	11834	Economy	35300.00
0005433570990	11834	Economy	35300.00
0005432949604	11834	Economy	35300.00
0005432949593	11834	Economy	35300.00
0005432949467	11834	Economy	35300.00
0005432949451	11834	Economy	35300.00
0005432949445	11834	Economy	35300.00
0005432949377	11834	Economy	35300.00
0005432949480	11834	Economy	35300.00
0005432949679	11834	Economy	35300.00
0005433570616	25304	Business	105900.00
0005433570710	25304	Business	105900.00
0005433570879	25304	Business	105900.00
0005433570299	25304	Business	105900.00
0005433570742	25304	Business	105900.00
0005433570502	25304	Business	105900.00
0005433570724	25304	Business	105900.00
0005433570918	25304	Business	105900.00
0005433570757	25304	Business	105900.00
0005433570537	25304	Business	105900.00
0005433570776	25304	Business	105900.00
0005433570826	25304	Economy	35300.00
0005433570590	25304	Economy	35300.00
0005433570705	25304	Economy	35300.00
0005433570300	25304	Economy	35300.00
0005433570589	25304	Economy	35300.00
0005433570938	25304	Economy	35300.00
0005433570750	25304	Economy	35300.00
0005433570556	25304	Economy	35300.00
0005433570870	25304	Economy	35300.00
0005433570591	25304	Economy	38800.00
0005433570864	25304	Economy	35300.00
0005433570785	25304	Economy	38800.00
0005433570939	25304	Economy	35300.00
0005433570720	25304	Economy	35300.00
0005433570784	25304	Economy	35300.00
0005433570654	25304	Economy	35300.00
0005433570507	25304	Economy	35300.00
0005433570752	25304	Economy	35300.00
0005433570743	25304	Economy	35300.00
0005433570538	25304	Economy	35300.00
0005433570895	25304	Economy	35300.00
0005433570819	25304	Economy	35300.00
0005433570876	25304	Economy	35300.00
0005433570813	25304	Economy	35300.00
0005433570506	25304	Economy	35300.00
0005433570769	25304	Economy	35300.00
0005433570731	25304	Economy	35300.00
0005433570770	25304	Economy	35300.00
0005433570446	25304	Economy	35300.00
0005433570820	25304	Economy	35300.00
0005433570539	25304	Economy	35300.00
0005433570863	25304	Economy	35300.00
0005433570677	25304	Economy	35300.00
0005433570768	25304	Economy	35300.00
0005433570650	25304	Economy	35300.00
0005433570727	25304	Economy	35300.00
0005433570709	25304	Economy	35300.00
0005433570854	25304	Economy	35300.00
0005433570679	25304	Economy	35300.00
0005433570722	25304	Economy	35300.00
0005433570775	25304	Economy	35300.00
0005433570894	25304	Economy	35300.00
0005433570580	25304	Economy	35300.00
0005433570503	25304	Economy	35300.00
0005433570649	25304	Economy	35300.00
0005433570809	25304	Economy	35300.00
0005433570871	25304	Economy	35300.00
0005433570665	25304	Economy	35300.00
0005433570910	25304	Economy	35300.00
0005433570755	25304	Economy	35300.00
0005433570777	25304	Economy	35300.00
0005433570482	25304	Economy	35300.00
0005433570581	25304	Economy	35300.00
0005433570653	25304	Economy	35300.00
0005433570513	25304	Economy	35300.00
0005433570723	25304	Economy	35300.00
0005433570686	25304	Economy	35300.00
0005433812964	14470	Business	117400.00
0005433812958	14470	Business	117400.00
0005433808478	14470	Business	117400.00
0005433808471	14470	Business	117400.00
0005433808477	14470	Business	117400.00
0005433808463	14470	Business	117400.00
0005433812962	14470	Economy	39100.00
0005433808484	14470	Economy	39100.00
0005433808474	14470	Economy	39100.00
0005433808450	14470	Economy	39100.00
0005433812954	14470	Economy	39100.00
0005433808472	14470	Economy	39100.00
0005433808476	14470	Economy	39100.00
0005433812957	14470	Economy	39100.00
0005433812956	14470	Economy	39100.00
0005433808475	14470	Economy	39100.00
0005433808482	14470	Economy	39100.00
0005433808465	14470	Economy	39100.00
0005433808470	14470	Economy	39100.00
0005433808481	14470	Economy	39100.00
0005433812963	14470	Economy	39100.00
0005435340658	5379	Business	67200.00
0005435340660	5379	Economy	24600.00
0005435340650	5379	Economy	24600.00
0005435340695	5379	Economy	22400.00
0005435340678	5379	Economy	22400.00
0005435340697	5379	Economy	22400.00
0005435340693	5379	Economy	22400.00
0005435340696	5379	Economy	22400.00
0005435340680	5379	Economy	22400.00
0005435340657	5379	Economy	22400.00
0005435340692	5379	Economy	22400.00
0005435340703	5379	Economy	22400.00
0005435340669	5379	Economy	22400.00
0005435340691	5379	Economy	22400.00
0005435340649	5379	Economy	22400.00
0005435340668	5379	Economy	22400.00
0005435340647	5379	Economy	22400.00
0005435340685	5379	Economy	22400.00
0005435340686	5379	Economy	22400.00
0005434655475	12514	Business	67200.00
0005434655535	12514	Business	67200.00
0005434655425	12514	Business	67200.00
0005434655540	12514	Economy	22400.00
0005434655444	12514	Economy	22400.00
0005434655459	12514	Economy	22400.00
0005434655536	12514	Economy	24600.00
0005434655436	12514	Economy	22400.00
0005434655451	12514	Economy	22400.00
0005434656612	12514	Economy	22400.00
0005434655507	12514	Economy	22400.00
0005434655424	12514	Economy	22400.00
0005434655466	12514	Economy	22400.00
0005434655414	12514	Economy	22400.00
0005434656603	12514	Economy	22400.00
0005434655511	12514	Economy	22400.00
0005434655477	12514	Economy	22400.00
0005434655476	12514	Economy	22400.00
0005434655389	12514	Economy	22400.00
0005434655486	12514	Economy	22400.00
0005434655450	12514	Economy	22400.00
0005434655514	12514	Economy	22400.00
0005434655413	12514	Economy	22400.00
0005434655487	12514	Economy	22400.00
0005435266311	7471	Economy	10700.00
0005433722515	7471	Economy	10700.00
0005433719242	7471	Economy	10700.00
0005435266329	7471	Economy	10700.00
0005435266338	7471	Economy	10700.00
0005435266312	7471	Economy	10700.00
0005433717380	29229	Business	32000.00
0005433719219	29229	Business	32000.00
0005433722390	29229	Business	32000.00
0005433717227	29229	Business	32000.00
0005433717298	29229	Business	32000.00
0005433722434	29229	Economy	10700.00
0005433717424	29229	Economy	10700.00
0005433717302	29229	Economy	10700.00
0005433717288	29229	Economy	10700.00
0005433717367	29229	Economy	10700.00
0005433717183	29229	Economy	10700.00
0005433717366	29229	Economy	10700.00
0005433722401	29229	Economy	10700.00
0005433717345	29229	Economy	10700.00
0005433685580	29229	Economy	10700.00
0005433717393	29229	Economy	10700.00
0005433717287	29229	Economy	10700.00
0005433722439	29229	Economy	10700.00
0005433722389	29229	Economy	10700.00
0005433722435	29229	Economy	10700.00
0005433717379	29229	Economy	10700.00
0005433717246	29229	Economy	10700.00
0005433717368	29229	Economy	10700.00
0005433722462	29229	Economy	10700.00
0005433717290	29229	Economy	10700.00
0005433719236	29229	Economy	11700.00
0005433685579	29229	Economy	10700.00
0005433717303	29229	Economy	11700.00
0005433722403	29229	Economy	11700.00
0005433722484	29229	Economy	11700.00
0005433722428	29229	Economy	10700.00
0005433717371	29229	Economy	10700.00
0005433722412	29229	Economy	10700.00
0005433717350	29229	Economy	10700.00
0005433717412	29229	Economy	10700.00
0005433722408	29229	Economy	10700.00
0005433722373	29229	Economy	10700.00
0005433717340	29229	Economy	10700.00
0005433722405	29229	Economy	10700.00
0005433722440	29229	Economy	10700.00
0005433717190	29229	Economy	10700.00
0005433717191	29229	Economy	10700.00
0005433717289	29229	Economy	10700.00
0005433722443	29229	Economy	10700.00
0005433722463	29229	Economy	10700.00
0005433722471	29229	Economy	10700.00
0005433717192	29229	Economy	10700.00
0005433717193	29229	Economy	10700.00
0005433717172	29229	Economy	10700.00
0005433722402	29229	Economy	10700.00
0005433719223	29229	Economy	10700.00
0005433722372	29229	Economy	10700.00
0005433722433	29229	Economy	10700.00
0005433717344	29229	Economy	10700.00
0005433717349	29229	Economy	10700.00
0005433722470	29229	Economy	10700.00
0005433722406	29229	Economy	10700.00
0005433717218	29229	Economy	10700.00
0005433717286	29229	Economy	10700.00
0005433722429	29229	Economy	10700.00
0005433722415	29229	Economy	10700.00
0005434182525	8674	Business	36500.00
0005435860661	8674	Business	36500.00
0005435860713	8674	Business	36500.00
0005435860702	8674	Economy	12200.00
0005435860690	8674	Economy	13400.00
0005435860671	8674	Economy	12200.00
0005434182535	8674	Economy	12200.00
0005434182538	8674	Economy	12200.00
0005434182539	8674	Economy	12200.00
0005434182537	8674	Economy	12200.00
0005435860668	8674	Economy	12200.00
0005434182526	8674	Economy	12200.00
0005435860712	8674	Economy	12200.00
0005434182512	8674	Economy	12200.00
0005434182536	8674	Economy	12200.00
0005435860682	8674	Economy	12200.00
0005435860701	8674	Economy	12200.00
0005435860689	8674	Economy	12200.00
0005435860711	8674	Economy	12200.00
0005434095653	11628	Business	36500.00
0005434095663	11628	Business	36500.00
0005434095656	11628	Economy	12200.00
0005434143798	11628	Economy	12200.00
0005434143802	11628	Economy	12200.00
0005434095677	11628	Economy	12200.00
0005434326288	11628	Economy	12200.00
0005434143800	11628	Economy	13400.00
0005434095643	11628	Economy	12200.00
0005434143793	11628	Economy	12200.00
0005434326284	11628	Economy	12200.00
0005434095676	11628	Economy	12200.00
0005434095686	11628	Economy	12200.00
0005434326291	11628	Economy	12200.00
0005434095654	11628	Economy	12200.00
0005434143807	11628	Economy	12200.00
0005434095692	11628	Economy	12200.00
0005434143781	11628	Economy	12200.00
0005434095657	11628	Economy	12200.00
0005434095658	11628	Economy	12200.00
0005434143801	11628	Economy	12200.00
0005434143806	11628	Economy	12200.00
0005434326290	11628	Economy	12200.00
0005434143843	11628	Economy	12200.00
0005434143809	11628	Economy	12200.00
0005434095671	11628	Economy	12200.00
0005434143785	11628	Economy	12200.00
0005434326296	11628	Economy	12200.00
0005434095652	11628	Economy	12200.00
0005434143808	11628	Economy	12200.00
0005434143797	11628	Economy	12200.00
0005434326292	11628	Economy	12200.00
0005433399251	1463	Business	33000.00
0005433399383	1463	Business	33000.00
0005433399310	1463	Business	33000.00
0005433399226	1463	Business	33000.00
0005432906604	1463	Business	33000.00
0005433399139	1463	Economy	11000.00
0005433399187	1463	Economy	11000.00
0005432906605	1463	Economy	11000.00
0005433399403	1463	Economy	11000.00
0005433399391	1463	Economy	11000.00
0005433399344	1463	Economy	11000.00
0005433399140	1463	Economy	12100.00
0005433399346	1463	Economy	12100.00
0005433399402	1463	Economy	12100.00
0005433399262	1463	Economy	11000.00
0005433399138	1463	Economy	11000.00
0005433399280	1463	Economy	11000.00
0005433399323	1463	Economy	11000.00
0005433399250	1463	Economy	11000.00
0005433399186	1463	Economy	11000.00
0005433399279	1463	Economy	11000.00
0005433399224	1463	Economy	11000.00
0005433399375	1463	Economy	11000.00
0005432906603	1463	Economy	11000.00
0005433399277	1463	Economy	11000.00
0005433399343	1463	Economy	11000.00
0005433399261	1463	Economy	11000.00
0005432906601	1463	Economy	11000.00
0005432906590	1463	Economy	11000.00
0005433399374	1463	Economy	11000.00
0005433399352	1463	Economy	11000.00
0005433399446	1463	Economy	11000.00
0005433399137	1463	Economy	11000.00
0005433399368	1463	Economy	11000.00
0005433399322	1463	Economy	11000.00
0005433399390	1463	Economy	11000.00
0005432906599	1463	Economy	11000.00
0005433399227	1463	Economy	11000.00
0005433399441	1463	Economy	11000.00
0005433399453	1463	Economy	11000.00
0005433399382	1463	Economy	11000.00
0005433399462	1463	Economy	11000.00
0005435732675	19248	Business	33000.00
0005435732686	19248	Business	33000.00
0005435732709	19248	Economy	11000.00
0005435732708	19248	Economy	11000.00
0005435732687	19248	Economy	11000.00
0005435732657	19248	Economy	11000.00
0005435732698	19248	Economy	11000.00
0005435732616	19248	Economy	11000.00
0005435732617	19248	Economy	11000.00
0005435732697	19248	Economy	11000.00
0005435732694	19248	Economy	11000.00
0005433457087	19248	Economy	11000.00
0005435732658	19248	Economy	11000.00
0005435732674	19248	Economy	11000.00
0005435732707	19248	Economy	11000.00
0005434444081	17376	Economy	15600.00
0005434444154	17376	Economy	15600.00
0005434444130	17376	Economy	14100.00
0005434444141	17376	Economy	14100.00
0005434444111	17376	Economy	14100.00
0005434444138	17376	Economy	14100.00
0005434444136	17376	Economy	14100.00
0005434444082	17376	Economy	14100.00
0005434444094	17376	Economy	14100.00
0005434444104	17376	Economy	14100.00
0005434444139	17376	Economy	14100.00
0005434444166	17376	Economy	14100.00
0005434444102	17376	Economy	14100.00
0005434444129	17376	Economy	14100.00
0005434444149	17376	Economy	14100.00
0005434444155	17376	Economy	14100.00
0005434444103	17376	Economy	14100.00
0005434444110	17376	Economy	14100.00
0005434444107	17376	Economy	14100.00
0005434444105	17376	Economy	14100.00
0005434444142	17376	Economy	14100.00
0005434444106	17376	Economy	14100.00
0005434444095	17376	Economy	14100.00
0005434444150	17376	Economy	14100.00
0005434444080	17376	Economy	14100.00
0005435311565	20568	Economy	14100.00
0005435311563	20568	Economy	14100.00
0005435311566	20568	Economy	14100.00
0005435311564	20568	Economy	14100.00
0005434954720	28357	Economy	5800.00
0005434954717	28357	Economy	5800.00
0005434954719	28357	Economy	5800.00
0005434954718	28357	Economy	5800.00
0005434183631	4476	Economy	14000.00
0005434183632	4476	Economy	14000.00
0005434183633	4476	Economy	14000.00
0005434326057	29630	Economy	14000.00
0005434352058	29630	Economy	14000.00
0005434351991	29630	Economy	14000.00
0005434352037	29630	Economy	14000.00
0005434352038	29630	Economy	14000.00
0005434352057	29630	Economy	14000.00
0005434351993	29630	Economy	14000.00
0005434352054	29630	Economy	14000.00
0005433346006	1053	Business	30600.00
0005433158185	1053	Business	30600.00
0005433345920	1053	Business	30600.00
0005433158189	1053	Business	30600.00
0005433158186	1053	Business	30600.00
0005433345695	1053	Business	30600.00
0005433345730	1053	Business	30600.00
0005433345669	1053	Business	30600.00
0005433345260	1053	Business	30600.00
0005433345881	1053	Business	30600.00
0005433345841	1053	Economy	11200.00
0005433158183	1053	Economy	10200.00
0005433345979	1053	Economy	10200.00
0005433345930	1053	Economy	10200.00
0005433345529	1053	Economy	10200.00
0005433345534	1053	Economy	10200.00
0005433345535	1053	Economy	10200.00
0005433345503	1053	Economy	10200.00
0005433345968	1053	Economy	10200.00
0005433345489	1053	Economy	10200.00
0005433345572	1053	Economy	10200.00
0005433345821	1053	Economy	10200.00
0005433345922	1053	Economy	10200.00
0005433345952	1053	Economy	10200.00
0005433345961	1053	Economy	10200.00
0005433345957	1053	Economy	10200.00
0005433345444	1053	Economy	10200.00
0005433345919	1053	Economy	10200.00
0005433345691	1053	Economy	10200.00
0005433345443	1053	Economy	10200.00
0005433345835	1053	Economy	10200.00
0005433345651	1053	Economy	10200.00
0005433345877	1053	Economy	10200.00
0005433345845	1053	Economy	10200.00
0005433345407	1053	Economy	10200.00
0005433345793	1053	Economy	10200.00
0005433345990	1053	Economy	10200.00
0005433345950	1053	Economy	10200.00
0005433345502	1053	Economy	10200.00
0005433345977	1053	Economy	10200.00
0005433345755	1053	Economy	10200.00
0005433345873	1053	Economy	10200.00
0005433345520	1053	Economy	10200.00
0005433345895	1053	Economy	10200.00
0005433345632	1053	Economy	10200.00
0005433345754	1053	Economy	10200.00
0005433345837	1053	Economy	10200.00
0005433345946	1053	Economy	10200.00
0005433345931	1053	Economy	10200.00
0005433345752	1053	Economy	10200.00
0005433345670	1053	Economy	10200.00
0005433345862	1053	Economy	10200.00
0005433345949	1053	Economy	10200.00
0005433345891	1053	Economy	10200.00
0005433345887	1053	Economy	10200.00
0005433345822	1053	Economy	11200.00
0005433345445	1053	Economy	10200.00
0005433345654	1053	Economy	10200.00
0005433345395	1053	Economy	10200.00
0005433345880	1053	Economy	10200.00
0005433345865	1053	Economy	10200.00
0005433345696	1053	Economy	10200.00
0005433345965	1053	Economy	10200.00
0005433345826	1053	Economy	10200.00
0005433345598	1053	Economy	10200.00
0005433346033	1053	Economy	10200.00
0005433346032	1053	Economy	10200.00
0005433345528	1053	Economy	10200.00
0005433345753	1053	Economy	10200.00
0005433345038	1053	Economy	10200.00
0005433345863	1053	Economy	10200.00
0005433345874	1053	Economy	10200.00
0005433345406	1053	Economy	10200.00
0005433345789	1053	Economy	10200.00
0005433345929	1053	Economy	10200.00
0005433345782	1053	Economy	10200.00
0005433345633	1053	Economy	10200.00
0005433344979	1053	Economy	10200.00
0005433345709	1053	Economy	10200.00
0005433345599	1053	Economy	10200.00
0005435092346	17036	Business	30600.00
0005435508768	17036	Business	30600.00
0005435530085	17036	Business	30600.00
0005435092347	17036	Business	30600.00
0005435530100	17036	Business	30600.00
0005435508694	17036	Business	30600.00
0005435530130	17036	Business	30600.00
0005435508680	17036	Business	30600.00
0005435530115	17036	Business	30600.00
0005433346089	17036	Business	30600.00
0005435508757	17036	Economy	11200.00
0005435530164	17036	Economy	10200.00
0005435530066	17036	Economy	10200.00
0005435530125	17036	Economy	10200.00
0005435092348	17036	Economy	10200.00
0005435530139	17036	Economy	10200.00
0005435530191	17036	Economy	10200.00
0005435530186	17036	Economy	10200.00
0005435530129	17036	Economy	10200.00
0005434445303	17036	Economy	10200.00
0005435530103	17036	Economy	10200.00
0005435508777	17036	Economy	10200.00
0005435530142	17036	Economy	10200.00
0005435530177	17036	Economy	10200.00
0005435508746	17036	Economy	10200.00
0005435508679	17036	Economy	10200.00
0005433346090	17036	Economy	10200.00
0005435530080	17036	Economy	10200.00
0005435530152	17036	Economy	10200.00
0005435530114	17036	Economy	10200.00
0005435508802	17036	Economy	10200.00
0005435508742	17036	Economy	10200.00
0005435530116	17036	Economy	10200.00
0005435530119	17036	Economy	10200.00
0005435530101	17036	Economy	10200.00
0005435530073	17036	Economy	10200.00
0005435508767	17036	Economy	10200.00
0005435508747	17036	Economy	10200.00
0005435530043	17036	Economy	10200.00
0005433346088	17036	Economy	11200.00
0005435530098	17036	Economy	10200.00
0005435530072	17036	Economy	10200.00
0005435508761	17036	Economy	10200.00
0005435530044	17036	Economy	10200.00
0005435530118	17036	Economy	10200.00
0005435508741	17036	Economy	10200.00
0005435530170	17036	Economy	10200.00
0005435530138	17036	Economy	10200.00
0005434445310	17036	Economy	10200.00
0005435530084	17036	Economy	10200.00
0005435508728	17036	Economy	10200.00
0005435530120	17036	Economy	10200.00
0005435530176	17036	Economy	10200.00
0005435530150	17036	Economy	10200.00
0005434082597	12799	Business	40300.00
0005434082480	12799	Business	40300.00
0005434082482	12799	Business	40300.00
0005434082558	12799	Business	40300.00
0005434069181	12799	Business	40300.00
0005434082514	12799	Business	40300.00
0005434069347	12799	Business	40300.00
0005434069599	12799	Business	40300.00
0005434069505	12799	Economy	13400.00
0005434069400	12799	Economy	13400.00
0005434082619	12799	Economy	13400.00
0005434069107	12799	Economy	13400.00
0005434026751	12799	Economy	13400.00
0005434069494	12799	Economy	13400.00
0005434069330	12799	Economy	13400.00
0005434082507	12799	Economy	13400.00
0005434082531	12799	Economy	13400.00
0005434069629	12799	Economy	13400.00
0005434082618	12799	Economy	13400.00
0005434069474	12799	Economy	13400.00
0005434069269	12799	Economy	13400.00
0005434069410	12799	Economy	13400.00
0005434082578	12799	Economy	13400.00
0005434069470	12799	Economy	13400.00
0005434069243	12799	Economy	13400.00
0005434069402	12799	Economy	13400.00
0005434069461	12799	Economy	13400.00
0005434069399	12799	Economy	13400.00
0005434069379	12799	Economy	13400.00
0005434069460	12799	Economy	13400.00
0005434069346	12799	Economy	13400.00
0005434069364	12799	Economy	13400.00
0005434082559	12799	Economy	13400.00
0005434082586	12799	Economy	14800.00
0005434069465	12799	Economy	14800.00
0005434082613	12799	Economy	14800.00
0005434069469	12799	Economy	14800.00
0005434069419	12799	Economy	14800.00
0005434082530	12799	Economy	13400.00
0005434082577	12799	Economy	13400.00
0005434082596	12799	Economy	13400.00
0005434069435	12799	Economy	13400.00
0005434069500	12799	Economy	13400.00
0005434069565	12799	Economy	13400.00
0005434069265	12799	Economy	13400.00
0005434069312	12799	Economy	13400.00
0005434069501	12799	Economy	13400.00
0005434082546	12799	Economy	13400.00
0005434082545	12799	Economy	13400.00
0005434069306	12799	Economy	13400.00
0005434082458	12799	Economy	13400.00
0005434082598	12799	Economy	13400.00
0005434069502	12799	Economy	13400.00
0005434082572	12799	Economy	13400.00
0005434069566	12799	Economy	13400.00
0005434082516	12799	Economy	13400.00
0005434069250	12799	Economy	13400.00
0005434082498	12799	Economy	13400.00
0005434069182	12799	Economy	13400.00
0005434069509	12799	Economy	13400.00
0005434069513	12799	Economy	13400.00
0005434069459	12799	Economy	13400.00
0005434082590	12799	Economy	13400.00
0005434069210	12799	Economy	13400.00
0005434069287	12799	Economy	13400.00
0005434082506	12799	Economy	13400.00
0005434069230	12799	Economy	13400.00
0005434069498	12799	Economy	13400.00
0005434069562	12799	Economy	13400.00
0005434069273	12799	Economy	13400.00
0005434069266	12799	Economy	13400.00
0005434069434	12799	Economy	13400.00
0005434069108	12799	Economy	13400.00
0005434082515	12799	Economy	13400.00
0005434069503	12799	Economy	13400.00
0005434069403	12799	Economy	13400.00
0005434082561	12799	Economy	13400.00
0005434082557	12799	Economy	13400.00
0005434082499	12799	Economy	13400.00
0005434082481	12799	Economy	13400.00
0005434069473	12799	Economy	13400.00
0005434069288	12799	Economy	13400.00
0005432433834	30661	Business	40300.00
0005432433837	30661	Business	40300.00
0005435283479	30661	Business	40300.00
0005432433827	30661	Economy	13400.00
0005435283481	30661	Economy	13400.00
0005435283441	30661	Economy	13400.00
0005435283457	30661	Economy	13400.00
0005432150432	30661	Economy	13400.00
0005435283443	30661	Economy	13400.00
0005432433828	30661	Economy	13400.00
0005432433835	30661	Economy	13400.00
0005435283528	30661	Economy	14800.00
0005435283498	30661	Economy	13400.00
0005432150431	30661	Economy	13400.00
0005435283503	30661	Economy	13400.00
0005435283480	30661	Economy	13400.00
0005435283494	30661	Economy	13400.00
0005435283442	30661	Economy	13400.00
0005435283497	30661	Economy	13400.00
0005432433838	30661	Economy	13400.00
0005435283529	30661	Economy	13400.00
0005433689967	19366	Economy	17600.00
0005433689965	19366	Economy	17600.00
0005433686688	19366	Economy	17600.00
0005433689968	19366	Economy	17600.00
0005433689959	19366	Economy	17600.00
0005433689960	19366	Economy	17600.00
0005433686690	19366	Economy	17600.00
0005433686689	19366	Economy	17600.00
0005433689961	19366	Economy	17600.00
0005433689964	19366	Economy	17600.00
0005434831273	5519	Business	35300.00
0005435463403	5519	Business	35300.00
0005435463447	5519	Business	35300.00
0005434265891	5519	Business	35300.00
0005435463481	5519	Business	35300.00
0005432140692	5519	Business	35300.00
0005435463516	5519	Economy	11800.00
0005434831270	5519	Economy	11800.00
0005435463446	5519	Economy	11800.00
0005434265832	5519	Economy	11800.00
0005434831269	5519	Economy	11800.00
0005435463460	5519	Economy	11800.00
0005434265782	5519	Economy	11800.00
0005434265793	5519	Economy	11800.00
0005435463480	5519	Economy	11800.00
0005435463509	5519	Economy	11800.00
0005435463414	5519	Economy	11800.00
0005434265790	5519	Economy	11800.00
0005434265767	5519	Economy	11800.00
0005434831271	5519	Economy	11800.00
0005434265890	5519	Economy	11800.00
0005432535943	5519	Economy	11800.00
0005434831282	5519	Economy	11800.00
0005434831276	5519	Economy	11800.00
0005434265830	5519	Economy	11800.00
0005435463461	5519	Economy	11800.00
0005434831274	5519	Economy	11800.00
0005434265812	5519	Economy	11800.00
0005434265827	5519	Economy	11800.00
0005434265804	5519	Economy	11800.00
0005434265831	5519	Economy	11800.00
0005435463321	5519	Economy	11800.00
0005432535961	5519	Economy	11800.00
0005434265811	5519	Economy	11800.00
0005435463517	5519	Economy	11800.00
0005435463484	5519	Economy	11800.00
0005432535962	5519	Economy	11800.00
0005435617189	5519	Economy	11800.00
0005432140691	5519	Economy	11800.00
0005435463494	5519	Economy	11800.00
0005435043308	5519	Economy	11800.00
0005434831275	5519	Economy	11800.00
0005435463515	5519	Economy	11800.00
0005435463283	5519	Economy	11800.00
0005435463415	5519	Economy	11800.00
0005435463526	5519	Economy	11800.00
0005435617192	5519	Economy	11800.00
0005435768000	13453	Business	35300.00
0005435767999	13453	Business	35300.00
0005435767918	13453	Business	35300.00
0005435767826	13453	Business	35300.00
0005433533408	13453	Business	35300.00
0005435725720	13453	Business	35300.00
0005433529378	13453	Business	35300.00
0005433529347	13453	Business	35300.00
0005435767924	13453	Business	35300.00
0005433533396	13453	Business	35300.00
0005433533395	13453	Business	35300.00
0005435767827	13453	Business	35300.00
0005435723093	13453	Business	35300.00
0005435767921	13453	Business	35300.00
0005435767825	13453	Economy	12900.00
0005433533417	13453	Economy	11800.00
0005435768021	13453	Economy	11800.00
0005435767846	13453	Economy	11800.00
0005435767994	13453	Economy	11800.00
0005435725726	13453	Economy	11800.00
0005435767993	13453	Economy	11800.00
0005435767863	13453	Economy	11800.00
0005435767842	13453	Economy	11800.00
0005435725709	13453	Economy	11800.00
0005435767782	13453	Economy	11800.00
0005435767777	13453	Economy	11800.00
0005435767778	13453	Economy	11800.00
0005435767957	13453	Economy	11800.00
0005435767868	13453	Economy	11800.00
0005435768040	13453	Economy	11800.00
0005435767882	13453	Economy	11800.00
0005433533410	13453	Economy	11800.00
0005435768004	13453	Economy	11800.00
0005435767841	13453	Economy	11800.00
0005435767906	13453	Economy	11800.00
0005435768024	13453	Economy	11800.00
0005435767811	13453	Economy	11800.00
0005435767983	13453	Economy	11800.00
0005435767705	13453	Economy	11800.00
0005435767668	13453	Economy	11800.00
0005435768112	13453	Economy	11800.00
0005435725707	13453	Economy	11800.00
0005433529372	13453	Economy	11800.00
0005435723101	13453	Economy	11800.00
0005435732731	13453	Economy	11800.00
0005435767896	13453	Economy	11800.00
0005435767862	13453	Economy	11800.00
0005435768079	13453	Economy	11800.00
0005433529348	13453	Economy	11800.00
0005435768039	13453	Economy	11800.00
0005433529360	13453	Economy	11800.00
0005435767899	13453	Economy	11800.00
0005435768080	13453	Economy	11800.00
0005435767771	13453	Economy	11800.00
0005435725731	13453	Economy	11800.00
0005435767898	13453	Economy	11800.00
0005435767883	13453	Economy	12900.00
0005435768026	13453	Economy	12900.00
0005435768074	13453	Economy	11800.00
0005435735267	13453	Economy	11800.00
0005435768022	13453	Economy	11800.00
0005435767985	13453	Economy	11800.00
0005435768020	13453	Economy	11800.00
0005433533411	13453	Economy	11800.00
0005435767940	13453	Economy	11800.00
0005435767992	13453	Economy	11800.00
0005435767984	13453	Economy	11800.00
0005435767937	13453	Economy	11800.00
0005435767982	13453	Economy	11800.00
0005435767858	13453	Economy	11800.00
0005435735258	13453	Economy	11800.00
0005433533407	13453	Economy	11800.00
0005433529359	13453	Economy	11800.00
0005435725725	13453	Economy	11800.00
0005435767964	13453	Economy	11800.00
0005433529358	13453	Economy	11800.00
0005435768081	13453	Economy	11800.00
0005435767785	13453	Economy	11800.00
0005435735256	13453	Economy	11800.00
0005435767900	13453	Economy	11800.00
0005435768073	13453	Economy	11800.00
0005435768012	13453	Economy	11800.00
0005435768027	13453	Economy	11800.00
0005435735254	13453	Economy	11800.00
0005435732732	13453	Economy	11800.00
0005435767939	13453	Economy	11800.00
0005435767917	13453	Economy	11800.00
0005435725708	13453	Economy	11800.00
0005435768023	13453	Economy	11800.00
0005435767897	13453	Economy	11800.00
0005435767905	13453	Economy	11800.00
0005433533416	13453	Economy	11800.00
0005435768025	13453	Economy	11800.00
0005435768111	13453	Economy	11800.00
0005435767505	13453	Economy	11800.00
0005435767667	13453	Economy	11800.00
0005435767977	13453	Economy	11800.00
0005435767867	13453	Economy	11800.00
0005435735266	13453	Economy	11800.00
0005434605004	18701	Economy	3300.00
0005434605006	18701	Economy	3300.00
0005434605005	18701	Economy	3300.00
0005434604988	18701	Economy	3300.00
0005434604989	18701	Economy	3300.00
0005434515038	19110	Economy	3300.00
0005434515037	19110	Economy	3300.00
0005434515045	19110	Economy	3300.00
0005434515044	19110	Economy	3300.00
0005434515043	19110	Economy	3300.00
0005432649575	4128	Business	88300.00
0005432649574	4128	Economy	29400.00
0005435846344	4128	Economy	32400.00
0005435844412	4128	Economy	29400.00
0005435844411	4128	Economy	29400.00
0005435846353	4128	Economy	29400.00
0005435844408	4128	Economy	29400.00
0005435846351	4128	Economy	29400.00
0005435844415	4128	Economy	29400.00
0005435846345	4128	Economy	29400.00
0005435844414	4128	Economy	29400.00
0005435846337	4128	Economy	29400.00
0005435846349	4128	Economy	29400.00
0005435844404	4128	Economy	29400.00
0005435846342	4128	Economy	29400.00
0005435844419	4128	Economy	29400.00
0005435844409	4128	Economy	29400.00
0005435844418	4128	Economy	29400.00
0005435846343	4128	Economy	29400.00
0005432632945	4128	Economy	29400.00
0005433009822	1860	Business	48700.00
0005433286075	1860	Business	48700.00
0005433286047	1860	Business	48700.00
0005433810822	1860	Business	48700.00
0005433009757	1860	Business	48700.00
0005433009853	1860	Business	48700.00
0005433009867	1860	Business	48700.00
0005433286203	1860	Business	48700.00
0005433286157	1860	Economy	16200.00
0005433286178	1860	Economy	16200.00
0005433009806	1860	Economy	16200.00
0005433009868	1860	Economy	16200.00
0005433009816	1860	Economy	16200.00
0005433286106	1860	Economy	16200.00
0005433009933	1860	Economy	17900.00
0005433009807	1860	Economy	17900.00
0005433009880	1860	Economy	17900.00
0005433286076	1860	Economy	16200.00
0005433009833	1860	Economy	16200.00
0005433009662	1860	Economy	16200.00
0005433286185	1860	Economy	16200.00
0005433009879	1860	Economy	16200.00
0005433009765	1860	Economy	16200.00
0005433009683	1860	Economy	16200.00
0005433286094	1860	Economy	16200.00
0005433009756	1860	Economy	16200.00
0005433009873	1860	Economy	16200.00
0005433286184	1860	Economy	16200.00
0005433286183	1860	Economy	16200.00
0005433009911	1860	Economy	16200.00
0005433286210	1860	Economy	16200.00
0005433009924	1860	Economy	16200.00
0005433286179	1860	Economy	16200.00
0005433286171	1860	Economy	16200.00
0005433009878	1860	Economy	16200.00
0005433009831	1860	Economy	16200.00
0005433009881	1860	Economy	16200.00
0005433009839	1860	Economy	16200.00
0005433009794	1860	Economy	16200.00
0005433286172	1860	Economy	16200.00
0005433286218	1860	Economy	16200.00
0005433009900	1860	Economy	16200.00
0005433286132	1860	Economy	16200.00
0005433286123	1860	Economy	16200.00
0005433286153	1860	Economy	16200.00
0005433009872	1860	Economy	16200.00
0005433286201	1860	Economy	16200.00
0005433009934	1860	Economy	16200.00
0005433810820	1860	Economy	16200.00
0005433286213	1860	Economy	16200.00
0005433009815	1860	Economy	16200.00
0005433810821	1860	Economy	16200.00
0005433009682	1860	Economy	16200.00
0005433009764	1860	Economy	16200.00
0005433810715	22575	Business	48700.00
0005433810706	22575	Business	48700.00
0005433810709	22575	Economy	16200.00
0005433810716	22575	Economy	16200.00
0005433810688	22575	Economy	16200.00
0005433810692	22575	Economy	16200.00
0005433810696	22575	Economy	16200.00
0005433810727	22575	Economy	16200.00
0005433810700	22575	Economy	17900.00
0005433810702	22575	Economy	17900.00
0005433810689	22575	Economy	16200.00
0005433810769	22575	Economy	16200.00
0005433810687	22575	Economy	16200.00
0005433810698	22575	Economy	16200.00
0005433810673	22575	Economy	16200.00
0005433810699	22575	Economy	16200.00
0005433810768	22575	Economy	16200.00
0005433810690	22575	Economy	16200.00
0005433810697	22575	Economy	16200.00
0005433810710	22575	Economy	16200.00
0005433810703	22575	Economy	16200.00
0005433810684	22575	Economy	16200.00
0005435283227	5594	Business	99800.00
0005434173634	5594	Business	99800.00
0005435283157	5594	Economy	33300.00
0005435283228	5594	Economy	36600.00
0005435283181	5594	Economy	33300.00
0005435283133	5594	Economy	33300.00
0005435283114	5594	Economy	33300.00
0005434173629	5594	Economy	33300.00
0005435283185	5594	Economy	33300.00
0005435283113	5594	Economy	33300.00
0005435283211	5594	Economy	33300.00
0005435283226	5594	Economy	33300.00
0005435283198	5594	Economy	33300.00
0005435283204	5594	Economy	33300.00
0005435283125	5594	Economy	33300.00
0005435283232	5594	Economy	33300.00
0005435283182	5594	Economy	33300.00
0005435283208	5594	Economy	33300.00
0005435283233	5594	Economy	33300.00
0005435283126	5594	Economy	33300.00
0005433848309	13864	Business	99800.00
0005433848200	13864	Business	99800.00
0005433848186	13864	Business	99800.00
0005433848294	13864	Business	99800.00
0005433848125	13864	Business	99800.00
0005433848375	13864	Business	99800.00
0005433848291	13864	Business	99800.00
0005433815517	13864	Business	99800.00
0005433848312	13864	Business	99800.00
0005433848199	13864	Business	99800.00
0005433848245	13864	Business	99800.00
0005433848342	13864	Economy	33300.00
0005433848193	13864	Economy	33300.00
0005433848292	13864	Economy	33300.00
0005433848310	13864	Economy	33300.00
0005433848330	13864	Economy	33300.00
0005433848246	13864	Economy	36600.00
0005433848259	13864	Economy	33300.00
0005433848347	13864	Economy	33300.00
0005433848247	13864	Economy	33300.00
0005433848388	13864	Economy	33300.00
0005433848142	13864	Economy	33300.00
0005433848139	13864	Economy	33300.00
0005433848393	13864	Economy	33300.00
0005433848295	13864	Economy	33300.00
0005433848171	13864	Economy	33300.00
0005433848257	13864	Economy	33300.00
0005433848251	13864	Economy	33300.00
0005433848150	13864	Economy	33300.00
0005433848374	13864	Economy	33300.00
0005433848196	13864	Economy	33300.00
0005433848343	13864	Economy	33300.00
0005433848124	13864	Economy	33300.00
0005433815513	13864	Economy	33300.00
0005433848323	13864	Economy	33300.00
0005433848392	13864	Economy	33300.00
0005433848076	13864	Economy	33300.00
0005433848313	13864	Economy	33300.00
0005433815516	13864	Economy	33300.00
0005433848346	13864	Economy	33300.00
0005433848141	13864	Economy	33300.00
0005433848314	13864	Economy	33300.00
0005433848140	13864	Economy	33300.00
0005435332641	7820	Economy	15100.00
0005435332589	7820	Economy	15100.00
0005435332624	7820	Economy	15100.00
0005435332640	7820	Economy	15100.00
0005435332615	7820	Economy	15100.00
0005435332587	7820	Economy	15100.00
0005435332593	7820	Economy	15100.00
0005435332592	7820	Economy	15100.00
0005435332591	7820	Economy	15100.00
0005435332625	7820	Economy	15100.00
0005435332618	7820	Economy	15100.00
0005435332588	7820	Economy	15100.00
0005434621147	32953	Economy	16600.00
0005434621071	32953	Economy	15100.00
0005434621080	32953	Economy	15100.00
0005434621081	32953	Economy	15100.00
0005434621156	32953	Economy	15100.00
0005434621121	32953	Economy	15100.00
0005434621148	32953	Economy	15100.00
0005434621143	32953	Economy	15100.00
0005434621144	32953	Economy	15100.00
0005434621100	32953	Economy	15100.00
0005434621010	32953	Economy	15100.00
0005434621169	32953	Economy	15100.00
0005434621161	32953	Economy	15100.00
0005435937534	4270	Business	38000.00
0005435918785	4270	Business	38000.00
0005435937537	4270	Economy	12700.00
0005435937547	4270	Economy	12700.00
0005435937551	4270	Economy	12700.00
0005435937528	4270	Economy	12700.00
0005435937508	4270	Economy	12700.00
0005435937544	4270	Economy	12700.00
0005435937538	4270	Economy	12700.00
0005435918794	4270	Economy	12700.00
0005435937507	4270	Economy	12700.00
0005435918786	4270	Economy	12700.00
0005435937529	4270	Economy	12700.00
0005435786270	27311	Business	38000.00
0005435786354	27311	Business	38000.00
0005435786199	27311	Business	38000.00
0005434994252	27311	Business	38000.00
0005434994289	27311	Economy	12700.00
0005435787407	27311	Economy	12700.00
0005435786148	27311	Economy	12700.00
0005435786259	27311	Economy	13900.00
0005435787404	27311	Economy	12700.00
0005435786264	27311	Economy	12700.00
0005435786272	27311	Economy	12700.00
0005435786218	27311	Economy	12700.00
0005435786296	27311	Economy	12700.00
0005434994294	27311	Economy	12700.00
0005435786297	27311	Economy	12700.00
0005434994293	27311	Economy	12700.00
0005435786318	27311	Economy	12700.00
0005435786274	27311	Economy	12700.00
0005435786204	27311	Economy	12700.00
0005435786208	27311	Economy	12700.00
0005435786301	27311	Economy	12700.00
0005435786246	27311	Economy	12700.00
0005435786210	27311	Economy	12700.00
0005435786281	27311	Economy	12700.00
0005434994298	27311	Economy	12700.00
0005434994290	27311	Economy	12700.00
0005435786219	27311	Economy	12700.00
0005434994297	27311	Economy	12700.00
0005435786209	27311	Economy	12700.00
0005435787398	27311	Economy	12700.00
0005435786355	27311	Economy	12700.00
0005435840436	4752	Business	40900.00
0005435840481	4752	Business	40900.00
0005435840490	4752	Business	40900.00
0005432461446	4752	Business	40900.00
0005434150156	4752	Economy	13600.00
0005435840423	4752	Economy	13600.00
0005432461445	4752	Economy	13600.00
0005434150158	4752	Economy	13600.00
0005434150196	4752	Economy	13600.00
0005435840482	4752	Economy	13600.00
0005432569430	4752	Economy	13600.00
0005432569429	4752	Economy	13600.00
0005434150195	4752	Economy	13600.00
0005434150172	4752	Economy	13600.00
0005435840466	4752	Economy	13600.00
0005434150197	4752	Economy	13600.00
0005435840435	4752	Economy	13600.00
0005435840511	4752	Economy	13600.00
0005432461322	30574	Business	40900.00
0005434082514	30574	Business	40900.00
0005432569277	30574	Business	40900.00
0005432569180	30574	Business	40900.00
0005432461301	30574	Business	40900.00
0005434082458	30574	Business	40900.00
0005434082586	30574	Business	40900.00
0005432461304	30574	Business	40900.00
0005434082507	30574	Business	40900.00
0005432461339	30574	Business	40900.00
0005432461303	30574	Business	40900.00
0005432461320	30574	Business	40900.00
0005432461208	30574	Business	40900.00
0005434082618	30574	Economy	15000.00
0005434082516	30574	Economy	15000.00
0005432569325	30574	Economy	15000.00
0005432569386	30574	Economy	13600.00
0005432461125	30574	Economy	13600.00
0005432461414	30574	Economy	13600.00
0005434082506	30574	Economy	13600.00
0005432461238	30574	Economy	13600.00
0005432569336	30574	Economy	13600.00
0005434082545	30574	Economy	13600.00
0005434082597	30574	Economy	13600.00
0005434082557	30574	Economy	13600.00
0005432461242	30574	Economy	13600.00
0005434082590	30574	Economy	13600.00
0005432569198	30574	Economy	13600.00
0005432461315	30574	Economy	13600.00
0005432461388	30574	Economy	13600.00
0005432569340	30574	Economy	13600.00
0005432569332	30574	Economy	13600.00
0005433452795	30574	Economy	13600.00
0005432569161	30574	Economy	13600.00
0005432571419	30574	Economy	13600.00
0005434082515	30574	Economy	13600.00
0005432569197	30574	Economy	13600.00
0005432569315	30574	Economy	13600.00
0005432569327	30574	Economy	13600.00
0005432569241	30574	Economy	13600.00
0005432569328	30574	Economy	13600.00
0005432569172	30574	Economy	13600.00
0005434082578	30574	Economy	13600.00
0005434082561	30574	Economy	13600.00
0005432569352	30574	Economy	13600.00
0005432461207	30574	Economy	13600.00
0005434082619	30574	Economy	13600.00
0005432569229	30574	Economy	13600.00
0005432461415	30574	Economy	13600.00
0005432461206	30574	Economy	13600.00
0005432461151	30574	Economy	13600.00
0005432461237	30574	Economy	13600.00
0005432461396	30574	Economy	13600.00
0005432461329	30574	Economy	13600.00
0005432569393	30574	Economy	13600.00
0005432569388	30574	Economy	13600.00
0005434082481	30574	Economy	13600.00
0005432569296	30574	Economy	13600.00
0005432569338	30574	Economy	13600.00
0005432569246	30574	Economy	13600.00
0005432461314	30574	Economy	13600.00
0005432569339	30574	Economy	13600.00
0005432461279	30574	Economy	15000.00
0005432461209	30574	Economy	13600.00
0005434082482	30574	Economy	15000.00
0005432569326	30574	Economy	15000.00
0005432569344	30574	Economy	13600.00
0005434082546	30574	Economy	13600.00
0005434082598	30574	Economy	13600.00
0005432569331	30574	Economy	13600.00
0005432569389	30574	Economy	13600.00
0005434082572	30574	Economy	13600.00
0005434082577	30574	Economy	13600.00
0005434082558	30574	Economy	13600.00
0005432569266	30574	Economy	13600.00
0005432461131	30574	Economy	13600.00
0005432461152	30574	Economy	13600.00
0005432461260	30574	Economy	13600.00
0005432461268	30574	Economy	13600.00
0005434082480	30574	Economy	13600.00
0005432569343	30574	Economy	13600.00
0005432461360	30574	Economy	13600.00
0005432461321	30574	Economy	13600.00
0005432461241	30574	Economy	13600.00
0005434082498	30574	Economy	13600.00
0005432569297	30574	Economy	13600.00
0005432569267	30574	Economy	13600.00
0005432571438	30574	Economy	13600.00
0005434082531	30574	Economy	13600.00
0005432569302	30574	Economy	13600.00
0005432460932	30574	Economy	13600.00
0005432569337	30574	Economy	13600.00
0005432569196	30574	Economy	13600.00
0005434082499	30574	Economy	13600.00
0005434082613	30574	Economy	13600.00
0005432461319	30574	Economy	13600.00
0005432461335	30574	Economy	13600.00
0005434082530	30574	Economy	13600.00
0005432569181	30574	Economy	13600.00
0005432569162	30574	Economy	13600.00
0005432569401	30574	Economy	13600.00
0005432569371	30574	Economy	13600.00
0005434082559	30574	Economy	13600.00
0005432461291	30574	Economy	13600.00
0005432461362	30574	Economy	13600.00
0005432461343	30574	Economy	13600.00
0005434082596	30574	Economy	13600.00
0005435722115	21156	Economy	9900.00
0005435722114	21156	Economy	9900.00
0005435508743	11078	Business	23600.00
0005435530182	11078	Business	23600.00
0005435508771	11078	Economy	7900.00
0005435530106	11078	Economy	7900.00
0005435545992	11078	Economy	7900.00
0005435530132	11078	Economy	7900.00
0005435530156	11078	Economy	7900.00
0005435530144	11078	Economy	7900.00
0005435530179	11078	Economy	7900.00
0005435530137	11078	Economy	7900.00
0005435530145	11078	Economy	7900.00
0005435380419	11078	Economy	7900.00
0005435508778	11078	Economy	7900.00
0005435508826	11078	Economy	8600.00
0005435508813	11078	Economy	8600.00
0005435380440	11078	Economy	7900.00
0005435530143	11078	Economy	7900.00
0005435508740	11078	Economy	7900.00
0005435508732	11078	Economy	7900.00
0005435530155	11078	Economy	7900.00
0005433346092	11078	Economy	7900.00
0005435530183	11078	Economy	7900.00
0005435508770	11078	Economy	7900.00
0005435545990	11078	Economy	7900.00
0005435545985	11078	Economy	7900.00
0005435508695	11078	Economy	7900.00
0005435508829	11078	Economy	7900.00
0005435545988	11078	Economy	7900.00
0005435545986	11078	Economy	7900.00
0005435545989	11078	Economy	7900.00
0005435545987	11078	Economy	7900.00
0005435530141	11078	Economy	7900.00
0005433346091	11078	Economy	7900.00
0005435097462	17119	Business	23600.00
0005433345632	17119	Business	23600.00
0005433345887	17119	Business	23600.00
0005433345919	17119	Business	23600.00
0005433345873	17119	Business	23600.00
0005433345444	17119	Business	23600.00
0005433345572	17119	Business	23600.00
0005433345931	17119	Business	23600.00
0005433345407	17119	Business	23600.00
0005433345782	17119	Economy	7900.00
0005433345845	17119	Economy	7900.00
0005433345957	17119	Economy	7900.00
0005435097470	17119	Economy	7900.00
0005433345529	17119	Economy	7900.00
0005433345755	17119	Economy	7900.00
0005433345929	17119	Economy	7900.00
0005433345950	17119	Economy	7900.00
0005433345752	17119	Economy	7900.00
0005433345528	17119	Economy	7900.00
0005433345753	17119	Economy	7900.00
0005435097469	17119	Economy	7900.00
0005433345952	17119	Economy	7900.00
0005433345534	17119	Economy	7900.00
0005433345670	17119	Economy	7900.00
0005433345979	17119	Economy	7900.00
0005433345863	17119	Economy	7900.00
0005433345598	17119	Economy	7900.00
0005433345965	17119	Economy	7900.00
0005433345730	17119	Economy	7900.00
0005433345709	17119	Economy	7900.00
0005433345990	17119	Economy	7900.00
0005433345968	17119	Economy	7900.00
0005433345445	17119	Economy	7900.00
0005433345406	17119	Economy	8600.00
0005433345880	17119	Economy	8600.00
0005433345821	17119	Economy	8600.00
0005433345260	17119	Economy	8600.00
0005433345535	17119	Economy	8600.00
0005433345874	17119	Economy	7900.00
0005433345949	17119	Economy	7900.00
0005433345489	17119	Economy	7900.00
0005433345841	17119	Economy	7900.00
0005433345961	17119	Economy	7900.00
0005433345895	17119	Economy	7900.00
0005435097447	17119	Economy	7900.00
0005433345865	17119	Economy	7900.00
0005433345651	17119	Economy	7900.00
0005433345789	17119	Economy	7900.00
0005433345862	17119	Economy	7900.00
0005433345922	17119	Economy	7900.00
0005435097485	17119	Economy	7900.00
0005433345502	17119	Economy	7900.00
0005433345669	17119	Economy	7900.00
0005433345835	17119	Economy	7900.00
0005433345754	17119	Economy	7900.00
0005433345633	17119	Economy	7900.00
0005433345696	17119	Economy	7900.00
0005433345946	17119	Economy	7900.00
0005433345930	17119	Economy	7900.00
0005433345038	17119	Economy	7900.00
0005433345822	17119	Economy	7900.00
0005433345654	17119	Economy	7900.00
0005433345691	17119	Economy	7900.00
0005433345826	17119	Economy	7900.00
0005433345977	17119	Economy	7900.00
0005433345881	17119	Economy	7900.00
0005433345695	17119	Economy	7900.00
0005435097463	17119	Economy	7900.00
0005433345891	17119	Economy	7900.00
0005435097483	17119	Economy	7900.00
0005433345793	17119	Economy	7900.00
0005435097484	17119	Economy	7900.00
0005433345520	17119	Economy	7900.00
0005433345503	17119	Economy	7900.00
0005433346033	17119	Economy	7900.00
0005433345599	17119	Economy	7900.00
0005433345395	17119	Economy	7900.00
0005433346032	17119	Economy	7900.00
0005433345443	17119	Economy	7900.00
0005433346006	17119	Economy	7900.00
0005433345877	17119	Economy	7900.00
0005433345837	17119	Economy	7900.00
0005433344979	17119	Economy	7900.00
0005433345920	17119	Economy	7900.00
0005434159056	9072	Economy	8900.00
0005434159048	9072	Economy	8900.00
0005432920331	9072	Economy	8900.00
0005432920400	9072	Economy	8900.00
0005432920453	9072	Economy	8900.00
0005432920419	9072	Economy	9800.00
0005432920431	9072	Economy	9800.00
0005432920470	9072	Economy	8900.00
0005432920438	9072	Economy	8900.00
0005432920426	9072	Economy	8900.00
0005434159049	9072	Economy	8900.00
0005432920402	9072	Economy	8900.00
0005433477297	9072	Economy	8900.00
0005432920364	9072	Economy	8900.00
0005434159040	9072	Economy	8900.00
0005432920411	9072	Economy	8900.00
0005432920471	9072	Economy	8900.00
0005432920441	9072	Economy	8900.00
0005434159055	9072	Economy	8900.00
0005432920338	9072	Economy	8900.00
0005432920439	9072	Economy	8900.00
0005432920469	9072	Economy	8900.00
0005432920379	9072	Economy	8900.00
0005434159045	9072	Economy	8900.00
0005434159059	9072	Economy	8900.00
0005433477233	20451	Business	26600.00
0005433477109	20451	Business	26600.00
0005433477095	20451	Economy	8900.00
0005433477162	20451	Economy	8900.00
0005433507632	20451	Economy	9800.00
0005433477161	20451	Economy	8900.00
0005433481368	20451	Economy	8900.00
0005433481369	20451	Economy	8900.00
0005433507657	20451	Economy	8900.00
0005433477084	20451	Economy	8900.00
0005433481381	20451	Economy	8900.00
0005433507678	20451	Economy	8900.00
0005433477154	20451	Economy	8900.00
0005433507663	20451	Economy	8900.00
0005433507656	20451	Economy	8900.00
0005433477251	20451	Economy	8900.00
0005433481377	20451	Economy	8900.00
0005433481378	20451	Economy	8900.00
0005433507718	20451	Economy	8900.00
0005433507588	20451	Economy	8900.00
0005433507700	20451	Economy	8900.00
0005433507717	20451	Economy	8900.00
0005433477044	20451	Economy	8900.00
0005433481380	20451	Economy	8900.00
0005433481376	20451	Economy	8900.00
0005432400221	18377	Economy	5800.00
0005432396347	18377	Economy	5800.00
0005432400220	18377	Economy	5800.00
0005432396346	18377	Economy	5800.00
0005435626735	10938	Business	9500.00
0005435626826	10938	Business	9500.00
0005435127408	10938	Business	9500.00
0005435626811	10938	Business	9500.00
0005435626667	10938	Business	9500.00
0005435626720	10938	Business	9500.00
0005435127469	10938	Business	9500.00
0005435127432	10938	Business	9500.00
0005435127383	10938	Business	9500.00
0005435127309	10938	Economy	3200.00
0005435554313	10938	Economy	3200.00
0005435127298	10938	Economy	3200.00
0005435626685	10938	Economy	3200.00
0005435626716	10938	Economy	3200.00
0005435127382	10938	Economy	3200.00
0005435127520	10938	Economy	3200.00
0005435127456	10938	Economy	3500.00
0005435626810	10938	Economy	3500.00
0005435626755	10938	Economy	3500.00
0005435626707	10938	Economy	3200.00
0005435127436	10938	Economy	3200.00
0005435127518	10938	Economy	3200.00
0005435127493	10938	Economy	3200.00
0005435626668	10938	Economy	3200.00
0005435626684	10938	Economy	3200.00
0005435127506	10938	Economy	3200.00
0005435626669	10938	Economy	3200.00
0005435127417	10938	Economy	3200.00
0005435626740	10938	Economy	3200.00
0005435127457	10938	Economy	3200.00
0005435626654	10938	Economy	3200.00
0005435127380	10938	Economy	3200.00
0005435554328	10938	Economy	3200.00
0005435626736	10938	Economy	3200.00
0005435626771	10938	Economy	3200.00
0005435626691	10938	Economy	3200.00
0005435626737	10938	Economy	3200.00
0005435127458	10938	Economy	3200.00
0005435127381	10938	Economy	3200.00
0005435626738	10938	Economy	3200.00
0005435626674	10938	Economy	3200.00
0005435626675	10938	Economy	3200.00
0005435626641	10938	Economy	3200.00
0005435626697	10938	Economy	3200.00
0005435127547	10938	Economy	3200.00
0005435626804	10938	Economy	3200.00
0005435127484	10938	Economy	3200.00
0005435626723	10938	Economy	3200.00
0005435626819	10938	Economy	3200.00
0005435626728	10938	Economy	3200.00
0005435554302	10938	Economy	3200.00
0005435127507	10938	Economy	3200.00
0005435127502	10938	Economy	3200.00
0005435626780	10938	Economy	3200.00
0005435127504	10938	Economy	3200.00
0005435127532	10938	Economy	3200.00
0005435626672	10938	Economy	3200.00
0005435626812	10938	Economy	3200.00
0005435127355	10938	Economy	3200.00
0005435626754	10938	Economy	3200.00
0005435127435	10938	Economy	3200.00
0005435127392	10938	Economy	3200.00
0005435626721	10938	Economy	3200.00
0005435127354	10938	Economy	3200.00
0005435626820	10938	Economy	3200.00
0005435626717	10938	Economy	3200.00
0005435127503	10938	Economy	3200.00
0005435626803	10938	Economy	3200.00
0005435127470	10938	Economy	3200.00
0005435554303	10938	Economy	3200.00
0005435127308	10938	Economy	3200.00
0005435626713	10938	Economy	3200.00
0005435626702	10938	Economy	3200.00
0005434411883	14732	Business	9500.00
0005434411882	14732	Business	9500.00
0005434928375	14732	Business	9500.00
0005434928373	14732	Economy	3200.00
0005434411888	14732	Economy	3200.00
0005434928380	14732	Economy	3200.00
0005434928374	14732	Economy	3200.00
0005435219259	7106	Business	86900.00
0005435216645	7106	Business	86900.00
0005435178534	7106	Business	86900.00
0005435443564	7106	Business	86900.00
0005435216652	7106	Economy	29000.00
0005435221081	7106	Economy	29000.00
0005435178535	7106	Economy	29000.00
0005435178530	7106	Economy	31900.00
0005435443580	7106	Economy	29000.00
0005435443571	7106	Economy	29000.00
0005435216651	7106	Economy	29000.00
0005435178533	7106	Economy	29000.00
0005435178532	7106	Economy	29000.00
0005435221082	7106	Economy	29000.00
0005435178531	7106	Economy	29000.00
0005435178529	7106	Economy	29000.00
0005435216639	7106	Economy	29000.00
0005435443552	7106	Economy	29000.00
0005435443570	7106	Economy	29000.00
0005435219253	7106	Economy	29000.00
0005432394220	27076	Economy	29000.00
0005432394219	27076	Economy	29000.00
0005432398292	27076	Economy	31900.00
0005435715934	27076	Economy	31900.00
0005435715933	27076	Economy	29000.00
0005435715949	27076	Economy	29000.00
0005435715935	27076	Economy	29000.00
0005435715925	27076	Economy	29000.00
0005435715945	27076	Economy	29000.00
0005435715880	27076	Economy	29000.00
0005435715815	27076	Economy	29000.00
0005435715929	27076	Economy	29000.00
0005432394194	27076	Economy	29000.00
0005433060491	2724	Economy	7700.00
0005435548622	11177	Economy	27100.00
0005435548617	11177	Economy	24600.00
0005435548582	11177	Economy	24600.00
0005435548615	11177	Economy	24600.00
0005435548616	11177	Economy	24600.00
0005435548614	11177	Economy	24600.00
0005435548587	11177	Economy	24600.00
0005435548624	11177	Economy	24600.00
0005435548613	11177	Economy	24600.00
0005433788297	20682	Economy	24600.00
0005433788294	20682	Economy	24600.00
0005433788312	20682	Economy	24600.00
0005433788310	20682	Economy	24600.00
0005433788307	20682	Economy	24600.00
0005433788303	20682	Economy	24600.00
0005433788305	20682	Economy	24600.00
0005433788284	20682	Economy	24600.00
0005433788330	20682	Economy	24600.00
0005433788329	20682	Economy	24600.00
0005433788295	20682	Economy	24600.00
0005433788311	20682	Economy	24600.00
0005433788298	20682	Economy	24600.00
0005433788319	20682	Economy	24600.00
0005433788300	20682	Economy	24600.00
0005433788308	20682	Economy	24600.00
0005433788318	20682	Economy	24600.00
0005433788313	20682	Economy	24600.00
0005433788320	20682	Economy	24600.00
0005433788304	20682	Economy	24600.00
0005435518433	11377	Business	20200.00
0005435518401	11377	Business	20200.00
0005435518420	11377	Business	20200.00
0005435518388	11377	Business	20200.00
0005435541633	11377	Economy	6700.00
0005435518360	11377	Economy	6700.00
0005435518432	11377	Economy	6700.00
0005435518414	11377	Economy	7400.00
0005435541632	11377	Economy	7400.00
0005435518338	11377	Economy	7400.00
0005435541608	11377	Economy	6700.00
0005435541518	11377	Economy	6700.00
0005435518377	11377	Economy	6700.00
0005435541519	11377	Economy	6700.00
0005435518384	11377	Economy	6700.00
0005435541569	11377	Economy	6700.00
0005435518421	11377	Economy	6700.00
0005435541628	11377	Economy	6700.00
0005435518319	11377	Economy	6700.00
0005435518415	11377	Economy	6700.00
0005435518438	11377	Economy	6700.00
0005435541575	11377	Economy	6700.00
0005435541629	11377	Economy	6700.00
0005435541597	11377	Economy	6700.00
0005435518385	11377	Economy	6700.00
0005435541582	11377	Economy	6700.00
0005435541653	22271	Economy	6700.00
0005433252230	2266	Business	20200.00
0005433252174	2266	Economy	6700.00
0005433252247	2266	Economy	7400.00
0005433252362	2266	Economy	6700.00
0005433252315	2266	Economy	6700.00
0005433252217	2266	Economy	6700.00
0005433252334	2266	Economy	6700.00
0005433252353	2266	Economy	6700.00
0005433252333	2266	Economy	6700.00
0005433252344	2266	Economy	6700.00
0005433252319	2266	Economy	6700.00
0005433252313	2266	Economy	6700.00
0005433252231	2266	Economy	6700.00
0005433252330	2266	Economy	6700.00
0005433252303	2266	Economy	6700.00
0005433252347	2266	Economy	6700.00
0005433252338	2266	Economy	6700.00
0005433252229	2266	Economy	6700.00
0005434908584	25579	Business	20200.00
0005434908565	25579	Business	20200.00
0005434908480	25579	Business	20200.00
0005434908626	25579	Business	20200.00
0005434908730	25579	Economy	6700.00
0005434908558	25579	Economy	6700.00
0005434908837	25579	Economy	6700.00
0005434908590	25579	Economy	6700.00
0005434908744	25579	Economy	7400.00
0005434908818	25579	Economy	7400.00
0005434908454	25579	Economy	6700.00
0005434908752	25579	Economy	6700.00
0005434908643	25579	Economy	6700.00
0005434908669	25579	Economy	6700.00
0005434908425	25579	Economy	6700.00
0005434908789	25579	Economy	6700.00
0005434908652	25579	Economy	6700.00
0005434908762	25579	Economy	6700.00
0005434908815	25579	Economy	6700.00
0005434908583	25579	Economy	6700.00
0005434908770	25579	Economy	6700.00
0005434908683	25579	Economy	6700.00
0005434908655	25579	Economy	6700.00
0005434908589	25579	Economy	6700.00
0005434908656	25579	Economy	6700.00
0005434908653	25579	Economy	6700.00
0005434908651	25579	Economy	6700.00
0005434908455	25579	Economy	6700.00
0005434908546	25579	Economy	6700.00
0005434908481	25579	Economy	6700.00
0005435787468	25579	Economy	6700.00
0005434908359	25579	Economy	6700.00
0005434908360	25579	Economy	6700.00
0005434908684	25579	Economy	6700.00
0005434908459	25579	Economy	6700.00
0005434908819	25579	Economy	6700.00
0005434908731	25579	Economy	6700.00
0005434908773	25579	Economy	6700.00
0005434908717	25579	Economy	6700.00
0005435787460	25579	Economy	6700.00
0005432862523	2537	Economy	13600.00
0005432862524	2537	Economy	12400.00
0005432862521	2537	Economy	12400.00
0005432862527	2537	Economy	12400.00
0005432862528	2537	Economy	12400.00
0005432621447	28037	Economy	13600.00
0005432621448	28037	Economy	12400.00
0005432621423	28037	Economy	12400.00
0005432621412	28037	Economy	12400.00
0005432621424	28037	Economy	12400.00
0005434097508	11730	Economy	11300.00
0005433452795	31387	Economy	8400.00
0005434184727	11999	Economy	7200.00
0005433134257	11999	Economy	6600.00
0005434142719	11999	Economy	6600.00
0005434142720	11999	Economy	6600.00
0005433134261	11999	Economy	6600.00
0005433129406	11999	Economy	6600.00
0005433129405	11999	Economy	6600.00
0005433134254	11999	Economy	6600.00
0005434184726	11999	Economy	6600.00
0005433129387	11999	Economy	6600.00
0005434142713	11999	Economy	6600.00
0005434326023	29814	Economy	6600.00
0005434326301	29814	Economy	6600.00
0005433134265	29814	Economy	6600.00
0005434326088	29814	Economy	6600.00
0005434326020	29814	Economy	6600.00
0005434326022	29814	Economy	6600.00
0005435551771	29814	Economy	6600.00
0005434326018	29814	Economy	6600.00
0005434326087	29814	Economy	6600.00
0005434326024	29814	Economy	6600.00
0005434326021	29814	Economy	6600.00
0005435698130	24691	Economy	19900.00
0005435698121	24691	Economy	18100.00
0005435698059	24691	Economy	18100.00
0005435698049	24691	Economy	18100.00
0005435698065	24691	Economy	18100.00
0005435698165	24691	Economy	18100.00
0005435698147	24691	Economy	18100.00
0005435698139	24691	Economy	18100.00
0005435698066	24691	Economy	18100.00
0005435698064	24691	Economy	18100.00
0005435698164	24691	Economy	18100.00
0005435698134	24691	Economy	18100.00
0005435698166	24691	Economy	18100.00
0005435697985	24691	Economy	18100.00
0005435283596	7303	Economy	7700.00
0005435283587	7303	Economy	7700.00
0005435283593	7303	Economy	7700.00
0005435283592	7303	Economy	7700.00
0005434140491	28571	Business	23100.00
0005434140405	28571	Business	23100.00
0005434140190	28571	Business	23100.00
0005434140139	28571	Business	23100.00
0005434140210	28571	Business	23100.00
0005434140364	28571	Business	23100.00
0005434140359	28571	Business	23100.00
0005434140437	28571	Business	23100.00
0005434140436	28571	Business	23100.00
0005434140287	28571	Business	23100.00
0005434140443	28571	Business	23100.00
0005434140516	28571	Economy	7700.00
0005434087649	28571	Economy	7700.00
0005434087650	28571	Economy	7700.00
0005434140501	28571	Economy	7700.00
0005434140319	28571	Economy	7700.00
0005434140241	28571	Economy	7700.00
0005434140381	28571	Economy	7700.00
0005434140329	28571	Economy	7700.00
0005434140390	28571	Economy	8500.00
0005434140318	28571	Economy	8500.00
0005434140251	28571	Economy	8500.00
0005434139899	28571	Economy	7700.00
0005434140209	28571	Economy	7700.00
0005434140496	28571	Economy	7700.00
0005434140213	28571	Economy	7700.00
0005434140565	28571	Economy	7700.00
0005434140347	28571	Economy	7700.00
0005434140502	28571	Economy	7700.00
0005434140481	28571	Economy	7700.00
0005434140133	28571	Economy	7700.00
0005434140365	28571	Economy	7700.00
0005434140207	28571	Economy	7700.00
0005434140286	28571	Economy	7700.00
0005434140360	28571	Economy	7700.00
0005434140132	28571	Economy	7700.00
0005434140140	28571	Economy	7700.00
0005434140380	28571	Economy	7700.00
0005434140330	28571	Economy	7700.00
0005434140177	28571	Economy	7700.00
0005434140312	28571	Economy	7700.00
0005434140296	28571	Economy	7700.00
0005434140465	28571	Economy	7700.00
0005434140307	28571	Economy	7700.00
0005434140208	28571	Economy	7700.00
0005434140479	28571	Economy	7700.00
0005434140071	28571	Economy	7700.00
0005434140464	28571	Economy	7700.00
0005434140297	28571	Economy	7700.00
0005434087652	28571	Economy	7700.00
0005434140477	28571	Economy	7700.00
0005434140483	28571	Economy	7700.00
0005434140274	28571	Economy	7700.00
0005434087644	28571	Economy	7700.00
0005434140489	28571	Economy	7700.00
0005434140043	28571	Economy	7700.00
0005434140176	28571	Economy	7700.00
0005434140076	28571	Economy	7700.00
0005434139838	28571	Economy	7700.00
0005434140474	28571	Economy	7700.00
0005434140552	28571	Economy	7700.00
0005434140466	28571	Economy	7700.00
0005434140386	28571	Economy	7700.00
0005434140183	28571	Economy	7700.00
0005434140566	28571	Economy	7700.00
0005434140075	28571	Economy	7700.00
0005434140061	28571	Economy	7700.00
0005434140368	28571	Economy	7700.00
0005434140212	28571	Economy	7700.00
0005434140079	28571	Economy	7700.00
0005434140480	28571	Economy	7700.00
0005434140494	28571	Economy	7700.00
0005434140206	28571	Economy	7700.00
0005434140308	28571	Economy	7700.00
0005434140515	28571	Economy	7700.00
0005434140244	28571	Economy	7700.00
0005434140413	28571	Economy	7700.00
0005434140495	28571	Economy	7700.00
0005434140388	28571	Economy	7700.00
0005434140411	28571	Economy	7700.00
0005434140363	28571	Economy	7700.00
0005434140492	28571	Economy	7700.00
0005434140497	28571	Economy	7700.00
0005434140116	28571	Economy	7700.00
0005434140313	28571	Economy	7700.00
0005434140385	28571	Economy	7700.00
0005433407688	1927	Economy	23900.00
0005433407709	1927	Economy	21700.00
0005433407703	1927	Economy	21700.00
0005433407707	1927	Economy	21700.00
0005435808533	1927	Economy	21700.00
0005433407704	1927	Economy	21700.00
0005433407708	1927	Economy	21700.00
0005433407687	1927	Economy	21700.00
0005434610325	23101	Economy	21700.00
0005434610324	23101	Economy	21700.00
0005434505150	16677	Economy	7600.00
0005434505161	16677	Economy	7600.00
0005434505202	16677	Economy	7600.00
0005434504950	16677	Economy	7600.00
0005434505179	16677	Economy	6900.00
0005434505236	16677	Economy	6900.00
0005434505160	16677	Economy	6900.00
0005434505123	16677	Economy	6900.00
0005434505247	16677	Economy	6900.00
0005434505248	16677	Economy	6900.00
0005434505234	16677	Economy	6900.00
0005434504858	16677	Economy	6900.00
0005434505097	16677	Economy	6900.00
0005434505229	16677	Economy	6900.00
0005434505232	16677	Economy	6900.00
0005434505231	16677	Economy	6900.00
0005434505265	16677	Economy	6900.00
0005434505066	16677	Economy	6900.00
0005434505142	16677	Economy	6900.00
0005434505180	16677	Economy	6900.00
0005434505253	16677	Economy	6900.00
0005434505024	16677	Economy	6900.00
0005434505237	16677	Economy	6900.00
0005434505205	16677	Economy	6900.00
0005434505185	16677	Economy	6900.00
0005434505246	16677	Economy	6900.00
0005434505249	16677	Economy	6900.00
0005434505186	16677	Economy	6900.00
0005434505122	16677	Economy	6900.00
0005434505230	16677	Economy	6900.00
0005434505130	16677	Economy	6900.00
0005434505089	16677	Economy	6900.00
0005434505195	16677	Economy	6900.00
0005434505085	16677	Economy	6900.00
0005434505182	16677	Economy	6900.00
0005434505238	16677	Economy	6900.00
0005434505143	16677	Economy	6900.00
0005434505120	16677	Economy	6900.00
0005434505025	16677	Economy	6900.00
0005434505151	16677	Economy	6900.00
0005434505075	16677	Economy	6900.00
0005434505076	16677	Economy	6900.00
0005434505032	16677	Economy	6900.00
0005434505250	16677	Economy	6900.00
0005434505074	16677	Economy	6900.00
0005434505245	16677	Economy	6900.00
0005434505252	16677	Economy	6900.00
0005434505172	16677	Economy	6900.00
0005434505194	16677	Economy	6900.00
0005434505184	16677	Economy	6900.00
0005433266941	2226	Economy	7000.00
0005433266974	2226	Economy	7000.00
0005433266988	2226	Economy	7000.00
0005433266970	2226	Economy	7000.00
0005435078719	24354	Economy	7700.00
0005435078701	24354	Economy	7000.00
0005435078783	24354	Economy	7000.00
0005435078782	24354	Economy	7000.00
0005435078720	24354	Economy	7000.00
0005435078729	24354	Economy	7000.00
0005435078730	24354	Economy	7000.00
0005435078721	24354	Economy	7000.00
0005435464560	6634	Economy	9800.00
0005435464561	6634	Economy	9800.00
0005435464554	6634	Economy	9800.00
0005434988976	23589	Economy	10800.00
0005434989039	23589	Economy	9800.00
0005434989026	23589	Economy	9800.00
0005434988926	23589	Economy	9800.00
0005434989022	23589	Economy	9800.00
0005434989029	23589	Economy	9800.00
0005434988989	23589	Economy	9800.00
0005434989023	23589	Economy	9800.00
0005434989008	23589	Economy	9800.00
0005435803339	23589	Economy	9800.00
0005434988961	23589	Economy	9800.00
0005434989038	23589	Economy	9800.00
0005432384343	30501	Economy	3300.00
0005433450535	31315	Business	9900.00
0005432384106	31315	Business	9900.00
0005432384236	31315	Business	9900.00
0005432384193	31315	Business	9900.00
0005433450596	31315	Business	9900.00
0005432384167	31315	Business	9900.00
0005433450590	31315	Business	9900.00
0005433451676	31315	Business	9900.00
0005432384227	31315	Business	9900.00
0005432384125	31315	Economy	3300.00
0005433450543	31315	Economy	3300.00
0005433450598	31315	Economy	3300.00
0005432384246	31315	Economy	3300.00
0005432384210	31315	Economy	3300.00
0005432384287	31315	Economy	3300.00
0005433451674	31315	Economy	3300.00
0005432384238	31315	Economy	3300.00
0005432383957	31315	Economy	3300.00
0005433450577	31315	Economy	3600.00
0005432384187	31315	Economy	3600.00
0005433450542	31315	Economy	3600.00
0005433450525	31315	Economy	3600.00
0005433450544	31315	Economy	3300.00
0005432384297	31315	Economy	3300.00
0005432384185	31315	Economy	3300.00
0005432384250	31315	Economy	3300.00
0005433450571	31315	Economy	3300.00
0005433450559	31315	Economy	3300.00
0005432384298	31315	Economy	3300.00
0005433450550	31315	Economy	3300.00
0005432384282	31315	Economy	3300.00
0005432384164	31315	Economy	3300.00
0005433453820	31315	Economy	3300.00
0005432384220	31315	Economy	3300.00
0005433450601	31315	Economy	3300.00
0005432384259	31315	Economy	3300.00
0005432384263	31315	Economy	3300.00
0005432384237	31315	Economy	3300.00
0005432384239	31315	Economy	3300.00
0005433453810	31315	Economy	3300.00
0005433450572	31315	Economy	3300.00
0005432384107	31315	Economy	3300.00
0005433450527	31315	Economy	3300.00
0005432384120	31315	Economy	3300.00
0005432384184	31315	Economy	3300.00
0005433450511	31315	Economy	3300.00
0005432384151	31315	Economy	3300.00
0005432384128	31315	Economy	3300.00
0005433451672	31315	Economy	3300.00
0005433450583	31315	Economy	3300.00
0005432384292	31315	Economy	3300.00
0005433450584	31315	Economy	3300.00
0005432384165	31315	Economy	3300.00
0005433450510	31315	Economy	3300.00
0005433450536	31315	Economy	3300.00
0005433450552	31315	Economy	3300.00
0005433450553	31315	Economy	3300.00
0005433450523	31315	Economy	3300.00
0005433450526	31315	Economy	3300.00
0005433450606	31315	Economy	3300.00
0005432384291	31315	Economy	3300.00
0005432384235	31315	Economy	3300.00
0005433450528	31315	Economy	3300.00
0005433450487	31315	Economy	3300.00
0005432384201	31315	Economy	3300.00
0005433450558	31315	Economy	3300.00
0005432384179	31315	Economy	3300.00
0005432384262	31315	Economy	3300.00
0005433451675	31315	Economy	3300.00
0005433450574	31315	Economy	3300.00
0005432384283	31315	Economy	3300.00
0005433788303	26478	Economy	26200.00
0005433788308	26478	Economy	26200.00
0005433788307	26478	Economy	26200.00
0005433788298	26478	Economy	23800.00
0005433788330	26478	Economy	23800.00
0005433788304	26478	Economy	23800.00
0005433788329	26478	Economy	23800.00
0005433788305	26478	Economy	23800.00
0005433131820	10748	Economy	17100.00
0005435299896	10748	Economy	17100.00
0005435304261	10748	Economy	15600.00
0005435299899	10748	Economy	15600.00
0005435304248	10748	Economy	15600.00
0005433131804	10748	Economy	15600.00
0005435299893	10748	Economy	15600.00
0005433126975	10748	Economy	15600.00
0005433131834	10748	Economy	15600.00
0005433131805	10748	Economy	15600.00
0005433131814	10748	Economy	15600.00
0005435304262	10748	Economy	15600.00
0005433131831	10748	Economy	15600.00
0005435299895	10748	Economy	15600.00
0005433131813	10748	Economy	15600.00
0005435304266	10748	Economy	15600.00
0005433131824	10748	Economy	15600.00
0005435299900	10748	Economy	15600.00
0005435304255	10748	Economy	15600.00
0005433110391	2385	Economy	15700.00
0005433110380	2385	Economy	15700.00
0005433110366	2385	Economy	15700.00
0005434287883	26835	Economy	17200.00
0005434287829	26835	Economy	17200.00
0005434287906	26835	Economy	15700.00
0005434287929	26835	Economy	15700.00
0005434287828	26835	Economy	15700.00
0005434287806	26835	Economy	15700.00
0005434287881	26835	Economy	15700.00
0005434287903	26835	Economy	15700.00
0005434287893	26835	Economy	15700.00
0005434287907	26835	Economy	15700.00
0005434287842	26835	Economy	15700.00
0005434287905	26835	Economy	15700.00
0005434287894	26835	Economy	15700.00
0005434300263	26835	Economy	15700.00
0005434287805	26835	Economy	15700.00
0005434287896	26835	Economy	15700.00
0005434272226	25495	Economy	22800.00
0005435983717	26626	Economy	22800.00
0005435983712	26626	Economy	22800.00
0005435856326	26626	Economy	22800.00
0005435856322	26626	Economy	22800.00
0005435856323	26626	Economy	22800.00
0005434520469	19076	Economy	24600.00
0005434520482	19076	Economy	24600.00
0005434520449	19076	Economy	22300.00
0005434520492	19076	Economy	22300.00
0005434520479	19076	Economy	22300.00
0005434520475	19076	Economy	22300.00
0005434520450	19076	Economy	22300.00
0005434520499	19076	Economy	22300.00
0005434520454	19076	Economy	22300.00
0005434520458	19076	Economy	22300.00
0005434520483	19076	Economy	22300.00
0005434520498	19076	Economy	22300.00
0005434520485	19076	Economy	22300.00
0005434520459	19076	Economy	22300.00
0005434520453	19076	Economy	22300.00
0005434520493	19076	Economy	22300.00
0005434520480	19076	Economy	22300.00
0005434520497	19076	Economy	22300.00
0005434520466	19076	Economy	22300.00
0005434520489	19076	Economy	22300.00
0005434520496	19076	Economy	22300.00
0005433874454	32633	Economy	19200.00
0005433874433	32633	Economy	17400.00
0005433874444	32633	Economy	17400.00
0005433874441	32633	Economy	17400.00
0005433874438	32633	Economy	17400.00
0005433874443	32633	Economy	17400.00
0005433874453	32633	Economy	17400.00
0005433874439	32633	Economy	17400.00
0005433874442	32633	Economy	17400.00
0005433874455	32633	Economy	17400.00
0005435860614	4810	Economy	17600.00
0005435860611	4810	Economy	17600.00
0005435860613	4810	Economy	17600.00
0005433869509	32563	Economy	19400.00
0005433869483	32563	Economy	19400.00
0005433869513	32563	Economy	17600.00
0005433869572	32563	Economy	17600.00
0005433869555	32563	Economy	17600.00
0005433869526	32563	Economy	17600.00
0005433869510	32563	Economy	17600.00
0005433869502	32563	Economy	17600.00
0005433869532	32563	Economy	17600.00
0005433869450	32563	Economy	17600.00
0005433869484	32563	Economy	17600.00
0005433869575	32563	Economy	17600.00
0005433869534	32563	Economy	17600.00
0005433869447	32563	Economy	17600.00
0005433869525	32563	Economy	17600.00
0005433869574	32563	Economy	17600.00
0005433869477	32563	Economy	17600.00
0005433869409	32563	Economy	17600.00
0005433869531	32563	Economy	17600.00
0005433869449	32563	Economy	17600.00
0005433869511	32563	Economy	17600.00
0005433869356	32563	Economy	17600.00
0005433869546	32563	Economy	17600.00
0005433869431	32563	Economy	17600.00
0005433869448	32563	Economy	17600.00
0005433869482	32563	Economy	17600.00
0005433869492	32563	Economy	17600.00
0005433869432	32563	Economy	17600.00
0005433869528	32563	Economy	17600.00
0005433869563	32563	Economy	17600.00
0005433869443	32563	Economy	17600.00
0005433869533	32563	Economy	17600.00
0005433869453	32563	Economy	17600.00
0005433869372	32563	Economy	17600.00
0005433869527	32563	Economy	17600.00
0005433869396	32563	Economy	17600.00
0005433869512	32563	Economy	17600.00
0005433869573	32563	Economy	17600.00
0005435911653	3411	Economy	22600.00
0005435911654	3411	Economy	22600.00
0005435911658	3411	Economy	22600.00
0005435911650	3411	Economy	22600.00
0005435911649	3411	Economy	22600.00
0005435911659	3411	Economy	22600.00
0005434663718	12449	Economy	24800.00
0005434462842	12449	Economy	24800.00
0005434462841	12449	Economy	22600.00
0005434460558	12449	Economy	22600.00
0005434663778	12449	Economy	22600.00
0005434663766	12449	Economy	22600.00
0005434462847	12449	Economy	22600.00
0005434663717	12449	Economy	22600.00
0005434663790	12449	Economy	22600.00
0005434462853	12449	Economy	22600.00
0005434663777	12449	Economy	22600.00
0005434462840	12449	Economy	22600.00
0005434460557	12449	Economy	22600.00
0005434663764	12449	Economy	22600.00
0005434663779	12449	Economy	22600.00
0005434460550	12449	Economy	22600.00
0005434460552	12449	Economy	22600.00
0005434462852	12449	Economy	22600.00
0005434663780	12449	Economy	22600.00
0005434460559	12449	Economy	22600.00
0005434460563	12449	Economy	22600.00
0005434663767	12449	Economy	22600.00
0005434460547	12449	Economy	22600.00
0005434462844	12449	Economy	22600.00
0005434460564	12449	Economy	22600.00
0005434663716	12449	Economy	22600.00
0005434462836	12449	Economy	22600.00
0005434462848	12449	Economy	22600.00
0005434462850	12449	Economy	22600.00
0005434460551	12449	Economy	22600.00
0005434663774	12449	Economy	22600.00
0005434663712	12449	Economy	22600.00
0005433869513	14519	Economy	18500.00
0005433869492	14519	Economy	18500.00
0005433869510	14519	Economy	16800.00
0005433869563	14519	Economy	16800.00
0005433869532	14519	Economy	16800.00
0005433869533	14519	Economy	16800.00
0005433869509	14519	Economy	16800.00
0005433869573	14519	Economy	16800.00
0005433869409	14519	Economy	16800.00
0005433869525	14519	Economy	16800.00
0005433869396	14519	Economy	16800.00
0005433869449	14519	Economy	16800.00
0005433869477	14519	Economy	16800.00
0005433869450	14519	Economy	16800.00
0005433869431	14519	Economy	16800.00
0005433869372	14519	Economy	16800.00
0005433869528	14519	Economy	16800.00
0005433869447	14519	Economy	16800.00
0005433869511	14519	Economy	16800.00
0005433869555	14519	Economy	16800.00
0005433869572	14519	Economy	16800.00
0005433869356	14519	Economy	16800.00
0005433869484	14519	Economy	16800.00
0005433869443	14519	Economy	16800.00
0005433869453	14519	Economy	16800.00
0005433869448	14519	Economy	16800.00
0005433869526	14519	Economy	16800.00
0005433869546	14519	Economy	16800.00
0005433869534	14519	Economy	16800.00
0005433869531	14519	Economy	16800.00
0005433869574	14519	Economy	16800.00
0005433869483	14519	Economy	16800.00
0005433869432	14519	Economy	16800.00
0005433869502	14519	Economy	16800.00
0005433869527	14519	Economy	16800.00
0005433869512	14519	Economy	16800.00
0005433869482	14519	Economy	16800.00
0005433869575	14519	Economy	16800.00
0005435860577	32644	Economy	18500.00
0005435860612	32644	Economy	16800.00
0005435860624	32644	Economy	16800.00
0005433869617	32644	Economy	16800.00
0005433869616	32644	Economy	16800.00
0005435860625	32644	Economy	16800.00
0005435860616	32644	Economy	16800.00
0005432800189	12152	Economy	4400.00
0005432800190	12152	Economy	4400.00
0005432800227	12152	Economy	4400.00
0005432800182	12152	Economy	4400.00
0005432800191	12152	Economy	4400.00
0005432800226	12152	Economy	4400.00
0005432800220	12152	Economy	4400.00
0005432800256	12152	Economy	4400.00
0005432800192	12152	Economy	4400.00
0005432800193	12152	Economy	4400.00
0005432800274	12152	Economy	4400.00
0005432800213	12152	Economy	4400.00
0005432800181	12152	Economy	4400.00
0005435311496	7030	Business	49100.00
0005435311500	7030	Business	49100.00
0005435311461	7030	Business	49100.00
0005435311519	7030	Economy	16400.00
0005435311472	7030	Economy	16400.00
0005435293609	7030	Economy	16400.00
0005435311471	7030	Economy	16400.00
0005435293581	7030	Economy	16400.00
0005435311473	7030	Economy	16400.00
0005435311441	7030	Economy	16400.00
0005435293623	7030	Economy	16400.00
0005435311467	7030	Economy	18000.00
0005435311542	7030	Economy	18000.00
0005435311468	7030	Economy	18000.00
0005435311448	7030	Economy	16400.00
0005435311541	7030	Economy	16400.00
0005435311482	7030	Economy	16400.00
0005435311499	7030	Economy	16400.00
0005435311540	7030	Economy	16400.00
0005435311547	7030	Economy	16400.00
0005435293620	7030	Economy	16400.00
0005435311504	7030	Economy	16400.00
0005435311548	7030	Economy	16400.00
0005435311518	7030	Economy	16400.00
0005435311528	7030	Economy	16400.00
0005435311505	7030	Economy	16400.00
0005435293582	7030	Economy	16400.00
0005435311480	7030	Economy	16400.00
0005435311366	7030	Economy	16400.00
0005434409477	26923	Business	49100.00
0005434409550	26923	Business	49100.00
0005434409427	26923	Business	49100.00
0005434409415	26923	Business	49100.00
0005434409453	26923	Business	49100.00
0005434409353	26923	Economy	16400.00
0005434300207	26923	Economy	16400.00
0005434300159	26923	Economy	16400.00
0005434409430	26923	Economy	16400.00
0005434300184	26923	Economy	16400.00
0005434409388	26923	Economy	16400.00
0005434409423	26923	Economy	16400.00
0005434409121	26923	Economy	16400.00
0005434409459	26923	Economy	16400.00
0005434409589	26923	Economy	16400.00
0005434409480	26923	Economy	16400.00
0005434300208	26923	Economy	16400.00
0005434409367	26923	Economy	16400.00
0005434409319	26923	Economy	16400.00
0005434409424	26923	Economy	16400.00
0005434409218	26923	Economy	16400.00
0005434409406	26923	Economy	16400.00
0005434409249	26923	Economy	16400.00
0005434409479	26923	Economy	16400.00
0005434409426	26923	Economy	16400.00
0005434409482	26923	Economy	18000.00
0005434409248	26923	Economy	18000.00
0005434409549	26923	Economy	16400.00
0005434409318	26923	Economy	16400.00
0005434409431	26923	Economy	16400.00
0005434409458	26923	Economy	16400.00
0005434409464	26923	Economy	16400.00
0005434409425	26923	Economy	16400.00
0005434409389	26923	Economy	16400.00
0005434409478	26923	Economy	16400.00
0005434409108	26923	Economy	16400.00
0005434409481	26923	Economy	16400.00
0005434409510	26923	Economy	16400.00
0005434409461	26923	Economy	16400.00
0005434409528	26923	Economy	16400.00
0005434409460	26923	Economy	16400.00
0005434409462	26923	Economy	16400.00
0005434409529	26923	Economy	16400.00
0005434409303	26923	Economy	16400.00
0005434409416	26923	Economy	16400.00
0005434409450	26923	Economy	16400.00
0005434409454	26923	Economy	16400.00
0005434409438	26923	Economy	16400.00
0005434409414	26923	Economy	16400.00
0005434409354	26923	Economy	16400.00
0005434300213	26923	Economy	16400.00
0005434409588	26923	Economy	16400.00
0005434300196	26923	Economy	16400.00
0005434409507	26923	Economy	16400.00
0005434409511	26923	Economy	16400.00
0005434409496	26923	Economy	16400.00
0005434409463	26923	Economy	16400.00
0005434300197	26923	Economy	16400.00
0005434409355	26923	Economy	16400.00
0005432605353	21399	Economy	16500.00
0005432605436	21399	Economy	16500.00
0005432605398	21399	Economy	16500.00
0005432605410	21399	Economy	15000.00
0005434512242	21399	Economy	15000.00
0005432605336	21399	Economy	15000.00
0005434512236	21399	Economy	15000.00
0005432605471	21399	Economy	15000.00
0005432605438	21399	Economy	15000.00
0005432605421	21399	Economy	15000.00
0005434512257	21399	Economy	15000.00
0005432605308	21399	Economy	15000.00
0005432605399	21399	Economy	15000.00
0005432605462	21399	Economy	15000.00
0005432605423	21399	Economy	15000.00
0005432605366	21399	Economy	15000.00
0005432605460	21399	Economy	15000.00
0005432605302	21399	Economy	15000.00
0005432605389	21399	Economy	15000.00
0005432605448	21399	Economy	15000.00
0005432605419	21399	Economy	15000.00
0005432605224	21399	Economy	15000.00
0005432605411	21399	Economy	15000.00
0005432605393	21399	Economy	15000.00
0005434512255	21399	Economy	15000.00
0005432605474	21399	Economy	15000.00
0005432605355	21399	Economy	15000.00
0005434512243	21399	Economy	15000.00
0005432605368	21399	Economy	15000.00
0005434512254	21399	Economy	15000.00
0005434512258	21399	Economy	15000.00
0005432605472	21399	Economy	15000.00
0005434512256	21399	Economy	15000.00
0005432605435	21399	Economy	15000.00
0005432605430	21399	Economy	15000.00
0005432605255	21399	Economy	15000.00
0005432605475	21399	Economy	15000.00
0005432605337	21399	Economy	15000.00
0005432605455	21399	Economy	15000.00
0005432605461	21399	Economy	15000.00
0005432605476	21399	Economy	15000.00
0005432605437	21399	Economy	15000.00
0005432605301	21399	Economy	15000.00
0005432605420	21399	Economy	15000.00
0005434512237	21399	Economy	15000.00
0005434908590	15006	Business	18900.00
0005434908652	15006	Business	18900.00
0005434908425	15006	Economy	6300.00
0005434908815	15006	Economy	6300.00
0005434908770	15006	Economy	6300.00
0005434908481	15006	Economy	6300.00
0005434908837	15006	Economy	6300.00
0005434908626	15006	Economy	6900.00
0005434908643	15006	Economy	6900.00
0005434908459	15006	Economy	6900.00
0005434908819	15006	Economy	6300.00
0005434908583	15006	Economy	6300.00
0005434908656	15006	Economy	6300.00
0005434908584	15006	Economy	6300.00
0005434908762	15006	Economy	6300.00
0005434908651	15006	Economy	6300.00
0005434908546	15006	Economy	6300.00
0005434908589	15006	Economy	6300.00
0005434908684	15006	Economy	6300.00
0005434908789	15006	Economy	6300.00
0005434908818	15006	Economy	6300.00
0005434908744	15006	Economy	6300.00
0005434908717	15006	Economy	6300.00
0005434908455	15006	Economy	6300.00
0005434908454	15006	Economy	6300.00
0005434908653	15006	Economy	6300.00
0005434908730	15006	Economy	6300.00
0005434908683	15006	Economy	6300.00
0005434908752	15006	Economy	6300.00
0005434908565	15006	Economy	6300.00
0005434908731	15006	Economy	6300.00
0005434908359	15006	Economy	6300.00
0005434908655	15006	Economy	6300.00
0005434908558	15006	Economy	6300.00
0005434908480	15006	Economy	6300.00
0005434908773	15006	Economy	6300.00
0005434908360	15006	Economy	6300.00
0005434908669	15006	Economy	6300.00
0005433252263	25875	Business	18900.00
0005433252352	25875	Business	18900.00
0005433252308	25875	Business	18900.00
0005433252232	25875	Business	18900.00
0005433252310	25875	Business	18900.00
0005433252171	25875	Economy	6300.00
0005434908902	25875	Economy	6300.00
0005433252257	25875	Economy	6300.00
0005433252320	25875	Economy	6300.00
0005433252361	25875	Economy	6300.00
0005433252244	25875	Economy	6300.00
0005433252264	25875	Economy	6300.00
0005433252309	25875	Economy	6300.00
0005433252354	25875	Economy	6300.00
0005433252307	25875	Economy	6300.00
0005433252306	25875	Economy	6300.00
0005433252133	25875	Economy	6300.00
0005433252299	25875	Economy	6300.00
0005433252298	25875	Economy	6300.00
0005433252351	25875	Economy	6300.00
0005433252269	25875	Economy	6300.00
0005433252371	25875	Economy	6300.00
0005433252256	25875	Economy	6300.00
0005433252328	25875	Economy	6300.00
0005433252380	25875	Economy	6300.00
0005434173650	9137	Economy	18100.00
0005433815538	22740	Economy	19900.00
0005433810678	14173	Economy	17400.00
0005433810735	14173	Economy	19200.00
0005433810701	14173	Economy	17400.00
0005433815538	14173	Economy	17400.00
0005433810749	14173	Economy	17400.00
0005433009941	22849	Business	52300.00
0005433009849	22849	Business	52300.00
0005433009631	22849	Business	52300.00
0005433009890	22849	Economy	17400.00
0005433009800	22849	Economy	17400.00
0005433009910	22849	Economy	17400.00
0005433009939	22849	Economy	17400.00
0005433009931	22849	Economy	17400.00
0005433009942	22849	Economy	17400.00
0005434173660	22849	Economy	17400.00
0005433009923	22849	Economy	17400.00
0005433009952	22849	Economy	19200.00
0005433009792	22849	Economy	19200.00
0005434173653	22849	Economy	17400.00
0005433009850	22849	Economy	17400.00
0005433009786	22849	Economy	17400.00
0005433009586	22849	Economy	17400.00
0005433009821	22849	Economy	17400.00
0005433009851	22849	Economy	17400.00
0005433009937	22849	Economy	17400.00
0005433009814	22849	Economy	17400.00
0005433810819	22849	Economy	17400.00
0005433009953	22849	Economy	17400.00
0005433009801	22849	Economy	17400.00
0005433009660	22849	Economy	17400.00
0005433009852	22849	Economy	17400.00
0005433009738	22849	Economy	17400.00
0005433009919	22849	Economy	17400.00
0005433009709	22849	Economy	17400.00
0005433009737	22849	Economy	17400.00
0005433009920	22849	Economy	17400.00
0005433009834	22849	Economy	17400.00
0005433009639	22849	Economy	17400.00
0005433009793	22849	Economy	17400.00
0005433009640	22849	Economy	17400.00
0005433009585	22849	Economy	17400.00
0005433009736	22849	Economy	17400.00
0005433009689	22849	Economy	17400.00
0005433009710	22849	Economy	17400.00
0005433009871	22849	Economy	17400.00
0005433009727	22849	Economy	17400.00
0005433009906	22849	Economy	17400.00
0005433009787	22849	Economy	17400.00
0005433009909	22849	Economy	17400.00
0005433009883	22849	Economy	17400.00
0005434926788	14912	Business	22900.00
0005434926784	14912	Economy	7600.00
0005434926730	14912	Economy	7600.00
0005434926780	14912	Economy	7600.00
0005434926637	14912	Economy	7600.00
0005434926596	14912	Economy	8400.00
0005434926530	14912	Economy	8400.00
0005434926765	14912	Economy	7600.00
0005434926731	14912	Economy	7600.00
0005434926827	14912	Economy	7600.00
0005434926787	14912	Economy	7600.00
0005434926697	14912	Economy	7600.00
0005434926785	14912	Economy	7600.00
0005434926743	14912	Economy	7600.00
0005434926724	14912	Economy	7600.00
0005434926552	14912	Economy	7600.00
0005434926744	14912	Economy	7600.00
0005434926726	14912	Economy	7600.00
0005434926585	14912	Economy	7600.00
0005434926791	14912	Economy	7600.00
0005434926826	14912	Economy	7600.00
0005434926806	14912	Economy	7600.00
0005434926532	14912	Economy	7600.00
0005434926586	14912	Economy	7600.00
0005434926531	14912	Economy	7600.00
0005434926703	14912	Economy	7600.00
0005434926773	14912	Economy	7600.00
0005435999760	15824	Economy	8900.00
0005435999692	15824	Economy	8900.00
0005435999717	15824	Economy	8100.00
0005435999828	15824	Economy	8100.00
0005435999797	15824	Economy	8100.00
0005435999865	15824	Economy	8100.00
0005435999807	15824	Economy	8100.00
0005435999795	15824	Economy	8100.00
0005435999742	15824	Economy	8100.00
0005435999826	15824	Economy	8100.00
0005435999761	15824	Economy	8100.00
0005435999668	15824	Economy	8100.00
0005435999681	15824	Economy	8100.00
0005435999788	15824	Economy	8100.00
0005435999680	15824	Economy	8100.00
0005435999831	15824	Economy	8100.00
0005435999669	15824	Economy	8100.00
0005435999850	15824	Economy	8100.00
0005435999791	15824	Economy	8100.00
0005435999779	15824	Economy	8100.00
0005435999789	15824	Economy	8100.00
0005435999790	15824	Economy	8100.00
0005435999866	15824	Economy	8100.00
0005435999776	15824	Economy	8100.00
0005435999802	15824	Economy	8100.00
0005435999798	15824	Economy	8100.00
0005435999763	15824	Economy	8100.00
0005435488413	19713	Economy	8900.00
0005435488449	19713	Economy	8100.00
0005435488457	19713	Economy	8100.00
0005435488412	19713	Economy	8100.00
0005435488359	19713	Economy	8100.00
0005435488375	19713	Economy	8100.00
0005435488373	19713	Economy	8100.00
0005435488456	19713	Economy	8100.00
0005435488368	19713	Economy	8100.00
0005435488445	19713	Economy	8100.00
0005435488433	19713	Economy	8100.00
0005435488458	19713	Economy	8100.00
0005435488320	19713	Economy	8100.00
0005435488465	19713	Economy	8100.00
0005435488350	19713	Economy	8100.00
0005435473243	6031	Business	199300.00
0005435473266	6031	Economy	73100.00
0005432537106	6031	Economy	66400.00
0005435473246	6031	Economy	66400.00
0005432537107	6031	Economy	66400.00
0005435473247	6031	Economy	66400.00
0005432537120	6031	Economy	66400.00
0005435473265	6031	Economy	66400.00
0005435840220	18076	Business	199300.00
0005432667513	18076	Business	199300.00
0005435840219	18076	Economy	66400.00
0005432664192	18076	Economy	73100.00
0005432667512	18076	Economy	73100.00
0005435840246	18076	Economy	66400.00
0005435840245	18076	Economy	66400.00
0005435840252	18076	Economy	66400.00
0005435840247	18076	Economy	66400.00
0005435840198	18076	Economy	66400.00
0005435840253	18076	Economy	66400.00
0005432667508	18076	Economy	66400.00
0005435840195	18076	Economy	66400.00
0005432667511	18076	Economy	66400.00
0005435840140	18076	Economy	66400.00
0005435840197	18076	Economy	66400.00
0005435840176	18076	Economy	66400.00
0005432664191	18076	Economy	66400.00
0005435840215	18076	Economy	66400.00
0005435840218	18076	Economy	66400.00
0005435840193	18076	Economy	66400.00
0005435840194	18076	Economy	66400.00
0005432667514	18076	Economy	66400.00
0005432664195	18076	Economy	66400.00
0005435104388	23020	Business	15700.00
0005433286178	23020	Business	15700.00
0005433286179	23020	Business	15700.00
0005433286106	23020	Business	15700.00
0005433286201	23020	Economy	5200.00
0005433286213	23020	Economy	5200.00
0005433286094	23020	Economy	5200.00
0005433286153	23020	Economy	5200.00
0005433286123	23020	Economy	5200.00
0005433286157	23020	Economy	5200.00
0005433286075	23020	Economy	5200.00
0005435104389	23020	Economy	5200.00
0005433286132	23020	Economy	5700.00
0005433286185	23020	Economy	5200.00
0005433286172	23020	Economy	5200.00
0005433286047	23020	Economy	5200.00
0005433286210	23020	Economy	5200.00
0005433286203	23020	Economy	5200.00
0005433286076	23020	Economy	5200.00
0005433286218	23020	Economy	5200.00
0005433286171	23020	Economy	5200.00
0005433286184	23020	Economy	5200.00
0005433286183	23020	Economy	5200.00
0005435104281	32061	Business	15700.00
0005435104169	32061	Business	15700.00
0005435104220	32061	Business	15700.00
0005435104216	32061	Business	15700.00
0005435104231	32061	Economy	5200.00
0005435104271	32061	Economy	5200.00
0005435104308	32061	Economy	5200.00
0005435104222	32061	Economy	5200.00
0005435104296	32061	Economy	5200.00
0005435104175	32061	Economy	5200.00
0005435104285	32061	Economy	5700.00
0005435104268	32061	Economy	5200.00
0005435104294	32061	Economy	5200.00
0005435104217	32061	Economy	5200.00
0005435104301	32061	Economy	5200.00
0005435104270	32061	Economy	5200.00
0005435104230	32061	Economy	5200.00
0005435104267	32061	Economy	5200.00
0005435104136	32061	Economy	5200.00
0005435104162	32061	Economy	5200.00
0005435104168	32061	Economy	5200.00
0005435104295	32061	Economy	5200.00
0005435104118	32061	Economy	5200.00
0005435104303	32061	Economy	5200.00
0005435104298	32061	Economy	5200.00
0005435104214	32061	Economy	5200.00
0005435104299	32061	Economy	5200.00
0005435104174	32061	Economy	5200.00
0005435104212	32061	Economy	5200.00
0005435104279	32061	Economy	5200.00
0005435104221	32061	Economy	5200.00
0005432531470	30608	Business	42100.00
0005432531090	30608	Business	42100.00
0005432531517	30608	Business	42100.00
0005432531437	30608	Business	42100.00
0005434069423	30608	Business	42100.00
0005432537115	30608	Business	42100.00
0005434069392	30608	Business	42100.00
0005432531797	30608	Business	42100.00
0005432531637	30608	Business	42100.00
0005434069282	30608	Business	42100.00
0005432531354	30608	Business	42100.00
0005432531477	30608	Comfort	23900.00
0005432531566	30608	Comfort	23900.00
0005432531410	30608	Comfort	23900.00
0005432531668	30608	Comfort	23900.00
0005434069437	30608	Comfort	23900.00
0005432531661	30608	Comfort	23900.00
0005432531203	30608	Comfort	23900.00
0005434069415	30608	Comfort	23900.00
0005434069390	30608	Comfort	23900.00
0005432531598	30608	Comfort	23900.00
0005432531643	30608	Comfort	23900.00
0005434069499	30608	Comfort	23900.00
0005432531337	30608	Comfort	23900.00
0005432531451	30608	Comfort	23900.00
0005432531654	30608	Comfort	23900.00
0005434069386	30608	Comfort	23900.00
0005432531723	30608	Comfort	23900.00
0005432531798	30608	Comfort	23900.00
0005432531385	30608	Comfort	23900.00
0005434069396	30608	Comfort	23900.00
0005434069472	30608	Economy	14000.00
0005434069430	30608	Economy	14000.00
0005434069414	30608	Economy	14000.00
0005432531452	30608	Economy	14000.00
0005432531044	30608	Economy	14000.00
0005432531738	30608	Economy	14000.00
0005432531481	30608	Economy	14000.00
0005434069169	30608	Economy	14000.00
0005434069395	30608	Economy	14000.00
0005434069616	30608	Economy	14000.00
0005432531662	30608	Economy	14000.00
0005432531732	30608	Economy	14000.00
0005432531820	30608	Economy	14000.00
0005432531429	30608	Economy	14000.00
0005432533370	30608	Economy	14000.00
0005432531417	30608	Economy	14000.00
0005432531704	30608	Economy	14000.00
0005434069397	30608	Economy	14000.00
0005432531353	30608	Economy	14000.00
0005432531388	30608	Economy	14000.00
0005434069308	30608	Economy	14000.00
0005432531536	30608	Economy	14000.00
0005432531690	30608	Economy	14000.00
0005434069422	30608	Economy	14000.00
0005432531642	30608	Economy	14000.00
0005432531623	30608	Economy	14000.00
0005434069536	30608	Economy	14000.00
0005432531828	30608	Economy	14000.00
0005434069555	30608	Economy	15400.00
0005432531655	30608	Economy	14000.00
0005432531316	30608	Economy	15400.00
0005432531804	30608	Economy	15400.00
0005434069424	30608	Economy	14000.00
0005434069284	30608	Economy	14000.00
0005432537118	30608	Economy	14000.00
0005432531821	30608	Economy	14000.00
0005432531286	30608	Economy	14000.00
0005432531725	30608	Economy	14000.00
0005432531418	30608	Economy	14000.00
0005432531443	30608	Economy	14000.00
0005432531480	30608	Economy	14000.00
0005432531534	30608	Economy	14000.00
0005432531162	30608	Economy	14000.00
0005432531554	30608	Economy	14000.00
0005432531409	30608	Economy	14000.00
0005432535973	30608	Economy	14000.00
0005432531802	30608	Economy	14000.00
0005434069643	30608	Economy	14000.00
0005434069445	30608	Economy	14000.00
0005432531287	30608	Economy	14000.00
0005432531599	30608	Economy	14000.00
0005434069578	30608	Economy	14000.00
0005432531562	30608	Economy	14000.00
0005432531442	30608	Economy	14000.00
0005432531387	30608	Economy	14000.00
0005432531657	30608	Economy	14000.00
0005434069457	30608	Economy	14000.00
0005432531537	30608	Economy	14000.00
0005432531614	30608	Economy	14000.00
0005434069283	30608	Economy	14000.00
0005432531724	30608	Economy	14000.00
0005432531784	30608	Economy	14000.00
0005434069300	30608	Economy	14000.00
0005434069537	30608	Economy	14000.00
0005432531803	30608	Economy	14000.00
0005432531822	30608	Economy	14000.00
0005434069357	30608	Economy	14000.00
0005432531817	30608	Economy	14000.00
0005432531689	30608	Economy	14000.00
0005432531491	30608	Economy	14000.00
0005434069253	30608	Economy	14000.00
0005432531666	30608	Economy	14000.00
0005432531703	30608	Economy	14000.00
0005432531795	30608	Economy	14000.00
0005434069393	30608	Economy	14000.00
0005434069394	30608	Economy	14000.00
0005432531487	30608	Economy	14000.00
0005432531656	30608	Economy	14000.00
0005432531563	30608	Economy	14000.00
0005434069532	30608	Economy	15400.00
0005432531632	30608	Economy	15400.00
0005432531549	30608	Economy	15400.00
0005432429026	30608	Economy	14000.00
0005434069206	30608	Economy	14000.00
0005434069307	30608	Economy	14000.00
0005432531412	30608	Economy	14000.00
0005432531408	30608	Economy	14000.00
0005432531538	30608	Economy	14000.00
0005432531420	30608	Economy	14000.00
0005432531610	30608	Economy	14000.00
0005432531597	30608	Economy	14000.00
0005434069246	30608	Economy	14000.00
0005432533372	30608	Economy	14000.00
0005434069556	30608	Economy	14000.00
0005434069453	30608	Economy	14000.00
0005432531416	30608	Economy	14000.00
0005432531478	30608	Economy	14000.00
0005432531718	30608	Economy	14000.00
0005434069389	30608	Economy	14000.00
0005432531616	30608	Economy	14000.00
0005432531556	30608	Economy	14000.00
0005432531565	30608	Economy	14000.00
0005432531633	30608	Economy	14000.00
0005432531324	30608	Economy	14000.00
0005432531564	30608	Economy	14000.00
0005434069168	30608	Economy	14000.00
0005432537119	30608	Economy	14000.00
0005432531535	30608	Economy	14000.00
0005432531376	30608	Economy	14000.00
0005434069245	30608	Economy	14000.00
0005432531462	30608	Economy	14000.00
0005434069456	30608	Economy	14000.00
0005434069617	30608	Economy	14000.00
0005434069242	30608	Economy	14000.00
0005432531161	30608	Economy	14000.00
0005432531463	30608	Economy	14000.00
0005434069170	30608	Economy	14000.00
0005434069163	30608	Economy	14000.00
0005432531667	30608	Economy	14000.00
0005434069439	30608	Economy	14000.00
0005434069391	30608	Economy	14000.00
0005432531384	30608	Economy	14000.00
0005432531557	30608	Economy	14000.00
0005432429025	30608	Economy	14000.00
0005432531488	30608	Economy	14000.00
0005432429027	30608	Economy	14000.00
0005435654370	24860	Business	9800.00
0005435654171	24860	Business	9800.00
0005435654293	24860	Business	9800.00
0005435654392	24860	Economy	3300.00
0005435654300	24860	Economy	3300.00
0005435654290	24860	Economy	3300.00
0005435654365	24860	Economy	3300.00
0005435654253	24860	Economy	3300.00
0005435654172	24860	Economy	3300.00
0005435654472	24860	Economy	3300.00
0005435654291	24860	Economy	3300.00
0005435654378	24860	Economy	3300.00
0005435654124	24860	Economy	3300.00
0005435654393	24860	Economy	3300.00
0005435654371	24860	Economy	3300.00
0005435654418	24860	Economy	3300.00
0005435654369	24860	Economy	3300.00
0005435654398	24860	Economy	3300.00
0005435654425	24860	Economy	3300.00
0005435654379	24860	Economy	3300.00
0005435654292	24860	Economy	3300.00
0005435654364	24860	Economy	3300.00
0005435654307	24860	Economy	3300.00
0005435654390	24860	Economy	3300.00
0005435654473	24860	Economy	3300.00
0005435654399	24860	Economy	3300.00
0005435654391	24860	Economy	3300.00
0005435654380	24860	Economy	3300.00
0005434980582	23530	Economy	10500.00
0005434980574	23530	Economy	10500.00
0005434980621	23530	Economy	10500.00
0005434980591	23530	Economy	9500.00
0005434980629	23530	Economy	9500.00
0005434980565	23530	Economy	9500.00
0005434980547	23530	Economy	9500.00
0005434980581	23530	Economy	9500.00
0005434980563	23530	Economy	9500.00
0005434980530	23530	Economy	9500.00
0005434980633	23530	Economy	9500.00
0005434980596	23530	Economy	9500.00
0005434980644	23530	Economy	9500.00
0005434980525	23530	Economy	9500.00
0005434980564	23530	Economy	9500.00
0005434980612	23530	Economy	9500.00
0005434980500	23530	Economy	9500.00
0005433256485	2565	Economy	5300.00
0005433256487	2565	Economy	5300.00
0005433256491	2565	Economy	5300.00
0005433256486	2565	Economy	5300.00
0005434302906	19777	Economy	8700.00
0005434302907	19777	Economy	8700.00
0005434140173	11922	Business	9700.00
0005434140454	11922	Business	9700.00
0005434140562	11922	Business	9700.00
0005434140504	11922	Business	9700.00
0005434140521	11922	Business	9700.00
0005434140057	11922	Business	9700.00
0005434140303	11922	Business	9700.00
0005434140398	11922	Business	9700.00
0005434140252	11922	Business	9700.00
0005434140059	11922	Economy	3200.00
0005434140374	11922	Economy	3200.00
0005434140457	11922	Economy	3200.00
0005434140341	11922	Economy	3200.00
0005434140463	11922	Economy	3200.00
0005434140478	11922	Economy	3200.00
0005434140418	11922	Economy	3500.00
0005434140419	11922	Economy	3500.00
0005434140340	11922	Economy	3500.00
0005434140112	11922	Economy	3200.00
0005434140058	11922	Economy	3200.00
0005434140505	11922	Economy	3200.00
0005434140508	11922	Economy	3200.00
0005434140486	11922	Economy	3200.00
0005434140563	11922	Economy	3200.00
0005434140577	11922	Economy	3200.00
0005434140507	11922	Economy	3200.00
0005434140473	11922	Economy	3200.00
0005434140428	11922	Economy	3200.00
0005434140569	11922	Economy	3200.00
0005434140088	11922	Economy	3200.00
0005434140423	11922	Economy	3200.00
0005434140452	11922	Economy	3200.00
0005434140172	11922	Economy	3200.00
0005434140384	11922	Economy	3200.00
0005434140431	11922	Economy	3200.00
0005434140441	11922	Economy	3200.00
0005434140536	11922	Economy	3200.00
0005434140369	11922	Economy	3200.00
0005434140576	11922	Economy	3200.00
0005434140087	11922	Economy	3200.00
0005434140535	11922	Economy	3200.00
0005434140429	11922	Economy	3200.00
0005434140291	11922	Economy	3200.00
0005434140440	11922	Economy	3200.00
0005434140575	11922	Economy	3200.00
0005434140432	11922	Economy	3200.00
0005434140499	11922	Economy	3200.00
0005434140408	11922	Economy	3200.00
0005434140370	11922	Economy	3200.00
0005434140238	11922	Economy	3200.00
0005434140356	11922	Economy	3200.00
0005434140290	11922	Economy	3200.00
0005434140568	11922	Economy	3200.00
0005434140498	11922	Economy	3200.00
0005435283596	28722	Economy	3200.00
0005435283592	28722	Economy	3200.00
0005435283587	28722	Economy	3200.00
0005435283593	28722	Economy	3200.00
0005435259885	6802	Economy	9900.00
0005435259884	6802	Economy	9900.00
0005435259887	6802	Economy	9900.00
0005433539082	25005	Economy	10900.00
0005433539083	25005	Economy	9900.00
0005433534556	25005	Economy	9900.00
0005433539119	25005	Economy	9900.00
0005433534561	25005	Economy	9900.00
0005433539117	25005	Economy	9900.00
0005433539118	25005	Economy	9900.00
0005433539120	25005	Economy	9900.00
0005432922634	803	Economy	14600.00
0005432922635	803	Economy	14600.00
0005433512177	16132	Economy	16100.00
0005433512192	16132	Economy	14600.00
0005433512193	16132	Economy	14600.00
0005433512191	16132	Economy	14600.00
0005435852643	4023	Economy	12300.00
0005435852644	4023	Economy	12300.00
0005435852651	4023	Economy	12300.00
0005434950642	16309	Economy	7900.00
0005435698065	16309	Economy	7200.00
0005435698165	16309	Economy	7200.00
0005434950643	16309	Economy	7200.00
0005435698066	16309	Economy	7200.00
0005435697985	16309	Economy	7200.00
0005435698139	16309	Economy	7200.00
0005435698147	16309	Economy	7200.00
0005435698166	16309	Economy	7200.00
0005434950658	16309	Economy	7200.00
0005434950659	16309	Economy	7200.00
0005435698134	16309	Economy	7200.00
0005435698121	16309	Economy	7200.00
0005435698064	16309	Economy	7200.00
0005435698049	16309	Economy	7200.00
0005435698059	16309	Economy	7200.00
0005435698130	16309	Economy	7200.00
0005435698164	16309	Economy	7200.00
0005435904910	3977	Economy	21300.00
0005435841493	3977	Economy	19300.00
0005435842351	3977	Economy	19300.00
0005435842352	3977	Economy	19300.00
0005434606922	22070	Economy	19300.00
0005433519588	22070	Economy	19300.00
0005433349157	727	Economy	3700.00
0005433349156	727	Economy	3700.00
0005433349161	727	Economy	3700.00
0005433349158	727	Economy	3700.00
0005435628821	15929	Economy	3700.00
0005435628818	15929	Economy	3700.00
0005433158185	17199	Economy	7100.00
0005433158189	17199	Economy	7100.00
0005433158186	17199	Economy	7100.00
0005433158183	17199	Economy	7100.00
0005434445317	17572	Economy	7100.00
0005434445318	17572	Economy	7100.00
0005434445325	17572	Economy	7100.00
0005434445323	17572	Economy	7100.00
0005434445324	17572	Economy	7100.00
0005435383282	7872	Economy	5900.00
0005435383283	7872	Economy	5400.00
0005435383289	7872	Economy	5400.00
0005435383288	7872	Economy	5400.00
0005435383297	7872	Economy	5400.00
0005435133189	33119	Economy	5400.00
0005435133154	33119	Economy	5400.00
0005435133185	33119	Economy	5400.00
0005435133159	33119	Economy	5400.00
0005435390432	7486	Economy	13800.00
0005435390433	7486	Economy	12500.00
0005435390434	7486	Economy	12500.00
0005435390438	7486	Economy	12500.00
0005435390425	7486	Economy	12500.00
0005435390419	7486	Economy	12500.00
0005435160621	29583	Economy	13800.00
0005435160574	29583	Economy	12500.00
0005435160610	29583	Economy	12500.00
0005432394217	18464	Economy	4900.00
0005432398279	18464	Economy	4900.00
0005432394218	18464	Economy	4900.00
0005432394207	18464	Economy	4900.00
0005432398301	18464	Economy	4900.00
0005432394210	18464	Economy	4900.00
0005432394211	18464	Economy	4900.00
0005432394208	18464	Economy	4900.00
0005435178533	27164	Economy	4900.00
0005435178535	27164	Economy	4900.00
0005435178529	27164	Economy	4900.00
0005435178531	27164	Economy	4900.00
0005435178534	27164	Economy	4900.00
0005435178530	27164	Economy	4900.00
0005435178532	27164	Economy	4900.00
0005435104279	22669	Business	48400.00
0005434505076	22669	Business	48400.00
0005435104162	22669	Business	48400.00
0005435104296	22669	Business	48400.00
0005434505185	22669	Business	48400.00
0005435104169	22669	Business	48400.00
0005434505238	22669	Business	48400.00
0005435104294	22669	Business	48400.00
0005434505184	22669	Business	48400.00
0005434505089	22669	Business	48400.00
0005434505179	22669	Economy	16100.00
0005434505195	22669	Economy	16100.00
0005435104267	22669	Economy	16100.00
0005434505252	22669	Economy	16100.00
0005434505237	22669	Economy	16100.00
0005434505123	22669	Economy	16100.00
0005434505246	22669	Economy	16100.00
0005435104298	22669	Economy	16100.00
0005434505075	22669	Economy	16100.00
0005435104118	22669	Economy	16100.00
0005435104271	22669	Economy	17800.00
0005434505236	22669	Economy	17800.00
0005435104281	22669	Economy	16100.00
0005434505151	22669	Economy	16100.00
0005435104230	22669	Economy	16100.00
0005434505205	22669	Economy	16100.00
0005435104285	22669	Economy	16100.00
0005435104295	22669	Economy	16100.00
0005435104299	22669	Economy	16100.00
0005435104212	22669	Economy	16100.00
0005434505249	22669	Economy	16100.00
0005435104308	22669	Economy	16100.00
0005435104221	22669	Economy	16100.00
0005435104303	22669	Economy	16100.00
0005435104216	22669	Economy	16100.00
0005434505066	22669	Economy	16100.00
0005435104214	22669	Economy	16100.00
0005434505025	22669	Economy	16100.00
0005434505247	22669	Economy	16100.00
0005435104220	22669	Economy	16100.00
0005434505248	22669	Economy	16100.00
0005434505130	22669	Economy	16100.00
0005434505120	22669	Economy	16100.00
0005434505245	22669	Economy	16100.00
0005434505229	22669	Economy	16100.00
0005434505182	22669	Economy	16100.00
0005434504858	22669	Economy	16100.00
0005435104174	22669	Economy	16100.00
0005434505231	22669	Economy	16100.00
0005435104217	22669	Economy	16100.00
0005435104268	22669	Economy	16100.00
0005434505172	22669	Economy	16100.00
0005434505230	22669	Economy	16100.00
0005434505160	22669	Economy	16100.00
0005434505202	22669	Economy	16100.00
0005434505122	22669	Economy	16100.00
0005435104136	22669	Economy	16100.00
0005435104222	22669	Economy	16100.00
0005434505032	22669	Economy	16100.00
0005435104231	22669	Economy	16100.00
0005434505194	22669	Economy	16100.00
0005434505253	22669	Economy	16100.00
0005435104168	22669	Economy	16100.00
0005434505186	22669	Economy	16100.00
0005434505074	22669	Economy	16100.00
0005434505024	22669	Economy	16100.00
0005434505085	22669	Economy	16100.00
0005434505250	22669	Economy	16100.00
0005434505150	22669	Economy	16100.00
0005434504950	22669	Economy	16100.00
0005434505234	22669	Economy	16100.00
0005434505232	22669	Economy	16100.00
0005434505097	22669	Economy	16100.00
0005434505142	22669	Economy	16100.00
0005435104270	22669	Economy	16100.00
0005434505143	22669	Economy	16100.00
0005435104175	22669	Economy	16100.00
0005434505265	22669	Economy	16100.00
0005434505161	22669	Economy	16100.00
0005435104301	22669	Economy	16100.00
0005434505180	22669	Economy	16100.00
0005433368946	1663	Business	50000.00
0005433368976	1663	Business	50000.00
0005433368939	1663	Business	50000.00
0005433368930	1663	Economy	16700.00
0005433368931	1663	Economy	18300.00
0005433368943	1663	Economy	16700.00
0005433368940	1663	Economy	16700.00
0005433368841	1663	Economy	16700.00
0005433368904	1663	Economy	16700.00
0005433368731	1663	Economy	16700.00
0005433368941	1663	Economy	16700.00
0005433368897	1663	Economy	16700.00
0005433368932	1663	Economy	16700.00
0005433368903	1663	Economy	16700.00
0005433368849	1663	Economy	16700.00
0005435654370	21683	Business	50000.00
0005435654364	21683	Business	50000.00
0005435654391	21683	Business	50000.00
0005435654365	21683	Business	50000.00
0005435654425	21683	Business	50000.00
0005435654291	21683	Business	50000.00
0005435654290	21683	Business	50000.00
0005435654473	21683	Business	50000.00
0005435654378	21683	Economy	16700.00
0005435654392	21683	Economy	16700.00
0005435654379	21683	Economy	16700.00
0005435654398	21683	Economy	18300.00
0005435654124	21683	Economy	16700.00
0005435654369	21683	Economy	16700.00
0005435654390	21683	Economy	16700.00
0005435654253	21683	Economy	16700.00
0005435654380	21683	Economy	16700.00
0005435654292	21683	Economy	16700.00
0005435654171	21683	Economy	16700.00
0005435654371	21683	Economy	16700.00
0005435654293	21683	Economy	16700.00
0005435654172	21683	Economy	16700.00
0005435654300	21683	Economy	16700.00
0005435654418	21683	Economy	16700.00
0005435654399	21683	Economy	16700.00
0005435654393	21683	Economy	16700.00
0005435654472	21683	Economy	16700.00
0005435654307	21683	Economy	16700.00
0005433987381	4192	Economy	7200.00
0005433987380	4192	Economy	7200.00
0005433986952	25688	Business	21500.00
0005433987221	25688	Business	21500.00
0005433987201	25688	Business	21500.00
0005433987271	25688	Business	21500.00
0005433987365	25688	Business	21500.00
0005433987275	25688	Business	21500.00
0005433987256	25688	Economy	7200.00
0005433987233	25688	Economy	7200.00
0005433987197	25688	Economy	7200.00
0005433987360	25688	Economy	7200.00
0005433987283	25688	Economy	7200.00
0005433987317	25688	Economy	7200.00
0005433987200	25688	Economy	7900.00
0005433987088	25688	Economy	7900.00
0005433987279	25688	Economy	7900.00
0005433987359	25688	Economy	7900.00
0005433987301	25688	Economy	7900.00
0005433987202	25688	Economy	7200.00
0005433987291	25688	Economy	7200.00
0005433987298	25688	Economy	7200.00
0005433986992	25688	Economy	7200.00
0005433987171	25688	Economy	7200.00
0005433987237	25688	Economy	7200.00
0005433987242	25688	Economy	7200.00
0005433987134	25688	Economy	7200.00
0005433987331	25688	Economy	7200.00
0005433987310	25688	Economy	7200.00
0005433987297	25688	Economy	7200.00
0005433987315	25688	Economy	7200.00
0005433987299	25688	Economy	7200.00
0005433987244	25688	Economy	7200.00
0005433987182	25688	Economy	7200.00
0005433987292	25688	Economy	7200.00
0005433987257	25688	Economy	7200.00
0005433987285	25688	Economy	7200.00
0005433986991	25688	Economy	7200.00
0005433987181	25688	Economy	7200.00
0005433987288	25688	Economy	7200.00
0005433987354	25688	Economy	7200.00
0005433987146	25688	Economy	7200.00
0005433987276	25688	Economy	7200.00
0005433987082	25688	Economy	7200.00
0005433987198	25688	Economy	7200.00
0005433987236	25688	Economy	7200.00
0005433987290	25688	Economy	7200.00
0005433987309	25688	Economy	7200.00
0005433987269	25688	Economy	7200.00
0005433987272	25688	Economy	7200.00
0005433987361	25688	Economy	7200.00
0005433987366	25688	Economy	7200.00
0005435719603	21258	Economy	9400.00
0005435719597	21258	Economy	9400.00
0005435719604	21258	Economy	9400.00
0005435719605	21258	Economy	9400.00
0005434509372	21322	Economy	17000.00
0005434509363	21322	Economy	17000.00
0005434509347	21322	Economy	15500.00
0005434509345	21322	Economy	15500.00
0005434509343	21322	Economy	15500.00
0005434509355	21322	Economy	15500.00
0005434509369	21322	Economy	15500.00
0005434509366	21322	Economy	15500.00
0005434509344	21322	Economy	15500.00
0005434509367	21322	Economy	15500.00
0005434509378	21322	Economy	15500.00
0005434509370	21322	Economy	15500.00
0005434509353	21322	Economy	15500.00
0005434509373	21322	Economy	15500.00
0005434509346	21322	Economy	15500.00
0005434509365	21322	Economy	15500.00
0005434509354	21322	Economy	15500.00
0005434509348	21322	Economy	15500.00
0005434509368	21322	Economy	15500.00
0005432655864	17866	Business	18000.00
0005432655865	17866	Business	18000.00
0005432658650	17866	Economy	6000.00
0005432661978	17866	Economy	6000.00
0005432655869	17866	Economy	6600.00
0005432659766	17866	Economy	6000.00
0005432661983	17866	Economy	6000.00
0005432657533	17866	Economy	6000.00
0005432655866	17866	Economy	6000.00
0005432657534	17866	Economy	6000.00
0005432655859	17866	Economy	6000.00
0005432659767	17866	Economy	6000.00
0005432655863	17866	Economy	6000.00
0005432659753	17866	Economy	6000.00
0005432655862	17866	Economy	6000.00
0005432664190	17866	Economy	6000.00
0005432659757	17866	Economy	6000.00
0005434151783	26290	Business	18000.00
0005434151779	26290	Economy	6000.00
0005434151782	26290	Economy	6000.00
0005434151777	26290	Economy	6000.00
0005434151790	26290	Economy	6000.00
0005434151787	26290	Economy	6000.00
0005434151778	26290	Economy	6000.00
0005434151776	26290	Economy	6000.00
0005434151785	26290	Economy	6000.00
0005432869702	26290	Economy	6000.00
0005434151784	26290	Economy	6000.00
0005432869716	26290	Economy	6000.00
0005432869657	26290	Economy	6000.00
0005432869715	26290	Economy	6000.00
0005434151789	26290	Economy	6000.00
0005432869701	26290	Economy	6000.00
0005434151788	26290	Economy	6000.00
0005432869692	26290	Economy	6000.00
0005432905285	3083	Business	16100.00
0005432905290	3083	Economy	5400.00
0005432848886	3083	Economy	5400.00
0005432905279	3083	Economy	5400.00
0005433439088	31115	Business	16100.00
0005433439083	31115	Business	16100.00
0005432329875	31115	Business	16100.00
0005432329940	31115	Business	16100.00
0005432330008	31115	Economy	5400.00
0005432329873	31115	Economy	5400.00
0005432329952	31115	Economy	5400.00
0005432329828	31115	Economy	5400.00
0005432329968	31115	Economy	5400.00
0005432329937	31115	Economy	5900.00
0005432329939	31115	Economy	5900.00
0005432329938	31115	Economy	5400.00
0005432330001	31115	Economy	5400.00
0005432330025	31115	Economy	5400.00
0005432329986	31115	Economy	5400.00
0005432329936	31115	Economy	5400.00
0005432330000	31115	Economy	5400.00
0005433439078	31115	Economy	5400.00
0005432329943	31115	Economy	5400.00
0005432329987	31115	Economy	5400.00
0005432329906	31115	Economy	5400.00
0005432329890	31115	Economy	5400.00
0005432329874	31115	Economy	5400.00
0005432329969	31115	Economy	5400.00
0005432329959	31115	Economy	5400.00
0005432330029	31115	Economy	5400.00
0005432329886	31115	Economy	5400.00
0005432329973	31115	Economy	5400.00
0005432329958	31115	Economy	5400.00
0005432329964	31115	Economy	5400.00
0005432330053	31115	Economy	5400.00
0005432329829	31115	Economy	5400.00
0005432329889	31115	Economy	5400.00
0005433439087	31115	Economy	5400.00
0005432329965	31115	Economy	5400.00
0005435488414	6218	Business	124600.00
0005435297226	6218	Business	124600.00
0005435488432	6218	Economy	41500.00
0005435488459	6218	Economy	41500.00
0005435488462	6218	Economy	41500.00
0005435297221	6218	Economy	41500.00
0005435297254	6218	Economy	41500.00
0005435488411	6218	Economy	41500.00
0005435488393	6218	Economy	41500.00
0005435297256	6218	Economy	41500.00
0005435488394	6218	Economy	41500.00
0005435488416	6218	Economy	41500.00
0005435297255	6218	Economy	41500.00
0005435488431	6218	Economy	41500.00
0005435297253	6218	Economy	41500.00
0005435297243	6218	Economy	41500.00
0005434310110	19556	Business	124600.00
0005435999779	19556	Business	124600.00
0005435999850	19556	Economy	41500.00
0005435999828	19556	Economy	41500.00
0005435999669	19556	Economy	41500.00
0005435999742	19556	Economy	41500.00
0005435999831	19556	Economy	41500.00
0005435999802	19556	Economy	41500.00
0005435999776	19556	Economy	41500.00
0005434310101	19556	Economy	41500.00
0005434310094	19556	Economy	41500.00
0005435999761	19556	Economy	41500.00
0005435999668	19556	Economy	41500.00
0005435999807	19556	Economy	41500.00
0005435999681	19556	Economy	41500.00
0005434310136	19556	Economy	41500.00
0005434310131	19556	Economy	41500.00
0005434310100	19556	Economy	41500.00
0005434310099	19556	Economy	41500.00
0005434310123	19556	Economy	41500.00
0005435999692	19556	Economy	45700.00
0005435999826	19556	Economy	41500.00
0005435999789	19556	Economy	41500.00
0005435999791	19556	Economy	41500.00
0005434310116	19556	Economy	41500.00
0005434310102	19556	Economy	41500.00
0005435999680	19556	Economy	41500.00
0005435999798	19556	Economy	41500.00
0005434310109	19556	Economy	41500.00
0005435999797	19556	Economy	41500.00
0005435999763	19556	Economy	41500.00
0005435999795	19556	Economy	41500.00
0005435999717	19556	Economy	41500.00
0005435999788	19556	Economy	41500.00
0005435999790	19556	Economy	41500.00
0005435999760	19556	Economy	41500.00
0005433186337	1584	Economy	28700.00
0005433186373	1584	Economy	28700.00
0005433186336	1584	Economy	28700.00
0005433186356	1584	Economy	28700.00
0005433186367	1584	Economy	28700.00
0005435502968	1584	Economy	28700.00
0005435502967	1584	Economy	28700.00
0005433186374	1584	Economy	28700.00
0005433186357	1584	Economy	28700.00
0005433186366	1584	Economy	28700.00
0005433186365	1584	Economy	28700.00
0005433186354	1584	Economy	28700.00
0005435529829	20881	Business	86000.00
0005435502945	20881	Business	86000.00
0005435529870	20881	Business	86000.00
0005434566296	20881	Business	86000.00
0005435545955	20881	Business	86000.00
0005435529879	20881	Business	86000.00
0005435502887	20881	Business	86000.00
0005435529869	20881	Business	86000.00
0005435502924	20881	Business	86000.00
0005435502884	20881	Business	86000.00
0005435529783	20881	Economy	28700.00
0005435529864	20881	Economy	28700.00
0005435529762	20881	Economy	28700.00
0005435502934	20881	Economy	28700.00
0005435502858	20881	Economy	28700.00
0005435529849	20881	Economy	28700.00
0005434566259	20881	Economy	28700.00
0005434566293	20881	Economy	31500.00
0005434566303	20881	Economy	31500.00
0005435545938	20881	Economy	31500.00
0005435502863	20881	Economy	28700.00
0005435545968	20881	Economy	28700.00
0005435529804	20881	Economy	28700.00
0005435502872	20881	Economy	28700.00
0005435502926	20881	Economy	28700.00
0005435545964	20881	Economy	28700.00
0005434566277	20881	Economy	28700.00
0005435529800	20881	Economy	28700.00
0005435529766	20881	Economy	28700.00
0005435529872	20881	Economy	28700.00
0005435502918	20881	Economy	28700.00
0005435502907	20881	Economy	28700.00
0005434566240	20881	Economy	28700.00
0005434566295	20881	Economy	28700.00
0005435502885	20881	Economy	28700.00
0005435529771	20881	Economy	28700.00
0005435529848	20881	Economy	28700.00
0005434566307	20881	Economy	28700.00
0005435502931	20881	Economy	28700.00
0005435502925	20881	Economy	28700.00
0005435545944	20881	Economy	28700.00
0005435545956	20881	Economy	28700.00
0005435545945	20881	Economy	28700.00
0005434566241	20881	Economy	28700.00
0005435529820	20881	Economy	28700.00
0005435545927	20881	Economy	28700.00
0005434566292	20881	Economy	28700.00
0005435529830	20881	Economy	28700.00
0005435502899	20881	Economy	28700.00
0005435529855	20881	Economy	28700.00
0005435529878	20881	Economy	28700.00
0005435529765	20881	Economy	28700.00
0005435529863	20881	Economy	28700.00
0005435545959	20881	Economy	28700.00
0005434566306	20881	Economy	28700.00
0005434566276	20881	Economy	28700.00
0005435529801	20881	Economy	28700.00
0005435502883	20881	Economy	28700.00
0005434566294	20881	Economy	28700.00
0005435502857	20881	Economy	28700.00
0005435502875	20881	Economy	28700.00
0005435545965	20881	Economy	28700.00
0005435529819	20881	Economy	28700.00
0005434566258	20881	Economy	28700.00
0005435502933	20881	Economy	28700.00
0005435529772	20881	Economy	28700.00
0005434566291	20881	Economy	28700.00
0005435529785	20881	Economy	28700.00
0005435529875	20881	Economy	28700.00
0005435502923	20881	Economy	28700.00
0005434566308	20881	Economy	28700.00
0005435502930	20881	Economy	28700.00
0005435502856	20881	Economy	28700.00
0005435529736	20881	Economy	28700.00
0005434230046	3919	Economy	19700.00
0005435931706	3919	Economy	19700.00
0005435931705	3919	Economy	19700.00
0005435153914	21901	Economy	21600.00
0005435153931	21901	Economy	21600.00
0005435153913	21901	Economy	19700.00
0005435153915	21901	Economy	19700.00
0005435142992	21901	Economy	19700.00
0005435142991	21901	Economy	19700.00
0005435153936	21901	Economy	19700.00
0005435153935	21901	Economy	19700.00
0005435142984	21901	Economy	19700.00
0005435142993	21901	Economy	19700.00
0005435225801	7205	Economy	13000.00
0005435225802	7205	Economy	13000.00
0005435225798	7205	Economy	13000.00
0005435225813	7205	Economy	13000.00
0005435225797	7205	Economy	13000.00
0005435225796	7205	Economy	13000.00
0005435225805	7205	Economy	13000.00
0005435225812	7205	Economy	13000.00
0005432629261	28124	Economy	13000.00
0005432629262	28124	Economy	13000.00
0005432629288	28124	Economy	13000.00
0005432629210	28124	Economy	13000.00
0005432629260	28124	Economy	13000.00
0005434268044	8729	Economy	10500.00
0005435939978	8729	Economy	10500.00
0005435939977	8729	Economy	10500.00
0005435960158	15243	Economy	10500.00
0005435960144	15243	Economy	10500.00
0005432873486	1215	Business	115000.00
0005432873482	1215	Economy	38300.00
0005432873483	1215	Economy	38300.00
0005432693820	17467	Business	115000.00
0005432693841	17467	Business	115000.00
0005432693912	17467	Business	115000.00
0005432693829	17467	Business	115000.00
0005432675553	17467	Business	115000.00
0005432693832	17467	Economy	38300.00
0005432693779	17467	Economy	38300.00
0005432693852	17467	Economy	42200.00
0005432693900	17467	Economy	42200.00
0005432693911	17467	Economy	38300.00
0005432675573	17467	Economy	38300.00
0005432693910	17467	Economy	38300.00
0005432693826	17467	Economy	38300.00
0005432693891	17467	Economy	38300.00
0005432693913	17467	Economy	38300.00
0005432693960	17467	Economy	38300.00
0005432675537	17467	Economy	38300.00
0005432693917	17467	Economy	38300.00
0005432675514	17467	Economy	38300.00
0005432693889	17467	Economy	38300.00
0005432693840	17467	Economy	38300.00
0005432693914	17467	Economy	38300.00
0005432693825	17467	Economy	38300.00
0005432675564	17467	Economy	38300.00
0005432677676	17467	Economy	38300.00
0005432675513	17467	Economy	38300.00
0005432677685	17467	Economy	38300.00
0005432675574	17467	Economy	38300.00
0005432675552	17467	Economy	38300.00
0005432693959	17467	Economy	38300.00
0005432675550	17467	Economy	38300.00
0005432693901	17467	Economy	38300.00
0005432693963	17467	Economy	38300.00
0005432693941	17467	Economy	38300.00
0005434435615	17315	Economy	15200.00
0005434435610	17315	Economy	13900.00
0005434435609	17315	Economy	13900.00
0005434435560	17315	Economy	13900.00
0005434435630	17315	Economy	13900.00
0005434435628	17315	Economy	13900.00
0005435928285	4056	Economy	7500.00
0005435928270	4056	Economy	7500.00
0005435928265	4056	Economy	7500.00
0005435928267	4056	Economy	7500.00
0005435087035	24397	Economy	8200.00
0005435087024	24397	Economy	8200.00
0005435087051	24397	Economy	7500.00
0005435087045	24397	Economy	7500.00
0005435087025	24397	Economy	7500.00
0005433194993	4818	Business	44200.00
0005433194934	4818	Economy	14700.00
0005433194970	4818	Economy	14700.00
0005433194929	4818	Economy	14700.00
0005433194949	4818	Economy	14700.00
0005435907643	4818	Economy	14700.00
0005433194980	4818	Economy	14700.00
0005433194979	4818	Economy	14700.00
0005435907618	4818	Economy	14700.00
0005435907645	4818	Economy	14700.00
0005433194960	4818	Economy	14700.00
0005433194971	4818	Economy	14700.00
0005435907644	4818	Economy	14700.00
0005435907617	4818	Economy	14700.00
0005433194930	4818	Economy	14700.00
0005433194933	4818	Economy	14700.00
0005434626237	32919	Business	44200.00
0005434626220	32919	Economy	14700.00
0005434626235	32919	Economy	14700.00
0005435786225	13755	Economy	3400.00
0005435786213	13755	Economy	3400.00
0005435786235	13755	Economy	3100.00
0005435786207	13755	Economy	3100.00
0005435786214	13755	Economy	3100.00
0005435786035	13755	Economy	3100.00
0005435786251	13755	Economy	3100.00
0005435786223	13755	Economy	3100.00
0005435786161	13755	Economy	3100.00
0005435786339	13755	Economy	3100.00
0005435786034	13755	Economy	3100.00
0005435786234	13755	Economy	3100.00
0005435786183	13755	Economy	3100.00
0005435786294	13755	Economy	3100.00
0005435786304	13755	Economy	3100.00
0005435786315	13755	Economy	3100.00
0005435786316	13755	Economy	3100.00
0005435786160	13755	Economy	3100.00
0005435786252	13755	Economy	3100.00
0005435786262	13755	Economy	3100.00
0005435786317	13755	Economy	3100.00
0005435786292	13755	Economy	3100.00
0005435786303	13755	Economy	3100.00
0005435786293	13755	Economy	3100.00
0005435786224	13755	Economy	3100.00
0005435786278	13755	Economy	3100.00
0005435786344	13755	Economy	3100.00
0005435937551	27414	Economy	3400.00
0005435937544	27414	Economy	3100.00
0005435937529	27414	Economy	3100.00
0005435937547	27414	Economy	3100.00
0005435937538	27414	Economy	3100.00
0005435937534	27414	Economy	3100.00
0005435937507	27414	Economy	3100.00
0005435937508	27414	Economy	3100.00
0005435937528	27414	Economy	3100.00
0005435937537	27414	Economy	3100.00
0005434409527	20262	Business	12000.00
0005434409447	20262	Business	12000.00
0005434409555	20262	Business	12000.00
0005434409441	20262	Business	12000.00
0005434409331	20262	Economy	4000.00
0005434409364	20262	Economy	4000.00
0005434409508	20262	Economy	4000.00
0005434409439	20262	Economy	4400.00
0005434409470	20262	Economy	4400.00
0005434409583	20262	Economy	4400.00
0005434409428	20262	Economy	4000.00
0005434409432	20262	Economy	4000.00
0005434409546	20262	Economy	4000.00
0005434409551	20262	Economy	4000.00
0005434409553	20262	Economy	4000.00
0005434409554	20262	Economy	4000.00
0005434409371	20262	Economy	4000.00
0005434409591	20262	Economy	4000.00
0005434409483	20262	Economy	4000.00
0005434409068	20262	Economy	4000.00
0005434409519	20262	Economy	4000.00
0005434409362	20262	Economy	4000.00
0005434409440	20262	Economy	4000.00
0005434409448	20262	Economy	4000.00
0005434409347	20262	Economy	4000.00
0005434409446	20262	Economy	4000.00
0005434409348	20262	Economy	4000.00
0005434409361	20262	Economy	4000.00
0005434409471	20262	Economy	4000.00
0005435311537	27017	Business	12000.00
0005435311506	27017	Business	12000.00
0005435311523	27017	Business	12000.00
0005435311445	27017	Business	12000.00
0005435311515	27017	Economy	4000.00
0005435311442	27017	Economy	4000.00
0005435311463	27017	Economy	4400.00
0005435311503	27017	Economy	4000.00
0005435311553	27017	Economy	4000.00
0005435311466	27017	Economy	4000.00
0005435311362	27017	Economy	4000.00
0005435311522	27017	Economy	4000.00
0005435311449	27017	Economy	4000.00
0005435311498	27017	Economy	4000.00
0005435311443	27017	Economy	4000.00
0005435311465	27017	Economy	4000.00
0005435311533	27017	Economy	4000.00
0005435311446	27017	Economy	4000.00
0005433124467	5699	Business	43300.00
0005433124510	5699	Business	43300.00
0005433124495	5699	Business	43300.00
0005435297394	5699	Economy	14400.00
0005433124438	5699	Economy	14400.00
0005433124535	5699	Economy	14400.00
0005433124536	5699	Economy	14400.00
0005433124499	5699	Economy	14400.00
0005433124436	5699	Economy	14400.00
0005433124474	5699	Economy	14400.00
0005433124473	5699	Economy	14400.00
0005433124511	5699	Economy	14400.00
0005433124512	5699	Economy	14400.00
0005433124476	5699	Economy	14400.00
0005433124439	5699	Economy	14400.00
0005433124472	5699	Economy	14400.00
0005433124496	5699	Economy	14400.00
0005435297381	5699	Economy	14400.00
0005433124475	5699	Economy	14400.00
0005433124519	5699	Economy	14400.00
0005434319819	15664	Business	43300.00
0005434311277	15664	Business	43300.00
0005434311273	15664	Economy	14400.00
0005434310164	15664	Economy	14400.00
0005434310161	15664	Economy	14400.00
0005434319863	15664	Economy	14400.00
0005434319765	15664	Economy	14400.00
0005434319857	15664	Economy	14400.00
0005434319837	15664	Economy	14400.00
0005434319788	15664	Economy	14400.00
0005434311274	15664	Economy	14400.00
0005434310160	15664	Economy	14400.00
0005434319838	15664	Economy	14400.00
0005434310159	15664	Economy	14400.00
0005434319804	15664	Economy	14400.00
0005434319803	15664	Economy	14400.00
0005434311276	15664	Economy	14400.00
0005434319769	15664	Economy	14400.00
0005434319858	15664	Economy	14400.00
0005434310162	15664	Economy	14400.00
0005434189339	9008	Economy	24900.00
0005434189340	9008	Economy	24900.00
0005434189335	9008	Economy	24900.00
0005434484515	16665	Economy	24900.00
0005433722451	7553	Economy	3700.00
0005433722414	7553	Economy	3700.00
0005434310164	7553	Economy	3700.00
0005434310162	7553	Economy	3700.00
0005433722458	7553	Economy	3700.00
0005434310160	7553	Economy	3700.00
0005433722427	7553	Economy	3700.00
0005433722447	7553	Economy	4100.00
0005433722397	7553	Economy	3700.00
0005433722419	7553	Economy	3700.00
0005433722461	7553	Economy	3700.00
0005433722460	7553	Economy	3700.00
0005434310161	7553	Economy	3700.00
0005433722432	7553	Economy	3700.00
0005435229651	7553	Economy	3700.00
0005433722473	7553	Economy	3700.00
0005433722457	7553	Economy	3700.00
0005434310159	7553	Economy	3700.00
0005433722459	7553	Economy	3700.00
0005433722404	7553	Economy	3700.00
0005433722501	7553	Economy	3700.00
0005432693910	30270	Business	11100.00
0005432693941	30270	Business	11100.00
0005432693959	30270	Business	11100.00
0005432693900	30270	Economy	3700.00
0005433450608	30270	Economy	3700.00
0005433450582	30270	Economy	3700.00
0005433450565	30270	Economy	3700.00
0005432693891	30270	Economy	3700.00
0005432693829	30270	Economy	3700.00
0005432693960	30270	Economy	3700.00
0005432693825	30270	Economy	3700.00
0005432693852	30270	Economy	3700.00
0005432693832	30270	Economy	3700.00
0005432693889	30270	Economy	3700.00
0005433450564	30270	Economy	3700.00
0005433450520	30270	Economy	3700.00
0005433450497	30270	Economy	3700.00
0005432693963	30270	Economy	3700.00
0005433450534	30270	Economy	3700.00
0005433450595	30270	Economy	3700.00
0005432693901	30270	Economy	3700.00
0005432693841	30270	Economy	3700.00
0005432693820	30270	Economy	3700.00
0005432693913	30270	Economy	3700.00
0005432693779	30270	Economy	3700.00
0005432693840	30270	Economy	3700.00
0005433450579	30270	Economy	3700.00
0005433450533	30270	Economy	3700.00
0005433450498	30270	Economy	3700.00
0005432693826	30270	Economy	3700.00
0005433450592	30270	Economy	3700.00
0005433450607	30270	Economy	3700.00
0005432693917	30270	Economy	3700.00
0005432693911	30270	Economy	3700.00
0005433450519	30270	Economy	3700.00
0005432693912	30270	Economy	3700.00
0005432693914	30270	Economy	3700.00
0005433450504	30270	Economy	3700.00
0005433124535	30338	Business	11100.00
0005432721668	30338	Business	11100.00
0005433124512	30338	Business	11100.00
0005433124510	30338	Business	11100.00
0005432721658	30338	Economy	3700.00
0005432721618	30338	Economy	3700.00
0005433124439	30338	Economy	3700.00
0005433124536	30338	Economy	4100.00
0005433124475	30338	Economy	3700.00
0005433124436	30338	Economy	3700.00
0005433124496	30338	Economy	3700.00
0005433124476	30338	Economy	3700.00
0005432721677	30338	Economy	3700.00
0005433124473	30338	Economy	3700.00
0005433124511	30338	Economy	3700.00
0005433124474	30338	Economy	3700.00
0005433124472	30338	Economy	3700.00
0005432721650	30338	Economy	3700.00
0005432721686	30338	Economy	3700.00
0005433124467	30338	Economy	3700.00
0005432721563	30338	Economy	3700.00
0005433124495	30338	Economy	3700.00
0005433124519	30338	Economy	3700.00
0005432721687	30338	Economy	3700.00
0005433124438	30338	Economy	3700.00
0005433124499	30338	Economy	3700.00
0005432721680	30338	Economy	3700.00
0005433193439	1387	Business	70400.00
0005433193428	1387	Business	70400.00
0005433193404	1387	Business	70400.00
0005432928135	1387	Economy	23500.00
0005433193416	1387	Economy	23500.00
0005432928143	1387	Economy	23500.00
0005433193377	1387	Economy	23500.00
0005433193429	1387	Economy	23500.00
0005433193430	1387	Economy	23500.00
0005432928110	1387	Economy	23500.00
0005432928142	1387	Economy	23500.00
0005433193438	1387	Economy	23500.00
0005433193441	1387	Economy	23500.00
0005432928144	1387	Economy	23500.00
0005432928134	1387	Economy	23500.00
0005433193378	1387	Economy	23500.00
0005433193411	1387	Economy	23500.00
0005433193417	1387	Economy	23500.00
0005433193440	1387	Economy	23500.00
0005433193409	1387	Economy	23500.00
0005434587358	18515	Business	70400.00
0005433525353	18515	Business	70400.00
0005434587329	18515	Business	70400.00
0005433525293	18515	Business	70400.00
0005433525358	18515	Economy	23500.00
0005433525348	18515	Economy	23500.00
0005434587293	18515	Economy	23500.00
0005433525316	18515	Economy	23500.00
0005434587330	18515	Economy	23500.00
0005434587355	18515	Economy	23500.00
0005434587323	18515	Economy	25800.00
0005434587352	18515	Economy	25800.00
0005434587279	18515	Economy	25800.00
0005433525292	18515	Economy	25800.00
0005433525355	18515	Economy	23500.00
0005434515037	18515	Economy	23500.00
0005434587357	18515	Economy	23500.00
0005433525333	18515	Economy	23500.00
0005433525349	18515	Economy	23500.00
0005433525299	18515	Economy	23500.00
0005434587263	18515	Economy	23500.00
0005434587241	18515	Economy	23500.00
0005433525350	18515	Economy	23500.00
0005433525351	18515	Economy	23500.00
0005433525352	18515	Economy	23500.00
0005433525300	18515	Economy	23500.00
0005434587294	18515	Economy	23500.00
0005434515045	18515	Economy	23500.00
0005434587278	18515	Economy	23500.00
0005433525311	18515	Economy	23500.00
0005434515038	18515	Economy	23500.00
0005433525354	18515	Economy	23500.00
0005434515044	18515	Economy	23500.00
0005434587356	18515	Economy	23500.00
0005434587317	18515	Economy	23500.00
0005434587320	18515	Economy	23500.00
0005434515043	18515	Economy	23500.00
0005434587354	18515	Economy	23500.00
0005435305078	11438	Economy	4000.00
0005435305080	11438	Economy	4000.00
0005435305077	11438	Economy	4000.00
0005435302327	11438	Economy	4000.00
0005435305079	11438	Economy	4000.00
0005434345178	29753	Economy	4300.00
0005434345179	29753	Economy	4300.00
0005434345224	29753	Economy	4300.00
0005434345263	29753	Economy	4000.00
0005434345195	29753	Economy	4000.00
0005434344998	29753	Economy	4000.00
0005434345281	29753	Economy	4000.00
0005434344999	29753	Economy	4000.00
0005434142719	29753	Economy	4000.00
0005434345202	29753	Economy	4000.00
0005434345279	29753	Economy	4000.00
0005434345166	29753	Economy	4000.00
0005434345075	29753	Economy	4000.00
0005434345044	29753	Economy	4000.00
0005434345165	29753	Economy	4000.00
0005434142713	29753	Economy	4000.00
0005434345045	29753	Economy	4000.00
0005434345158	29753	Economy	4000.00
0005434345280	29753	Economy	4000.00
0005434345155	29753	Economy	4000.00
0005434142720	29753	Economy	4000.00
0005434345203	29753	Economy	4000.00
0005433416127	1285	Economy	66600.00
0005433416079	1285	Economy	66600.00
0005433416119	1285	Economy	66600.00
0005433416101	1285	Economy	66600.00
0005433416102	1285	Economy	66600.00
0005435825311	17989	Business	199800.00
0005435825309	17989	Economy	66600.00
0005435825371	17989	Economy	66600.00
0005435825396	17989	Economy	66600.00
0005435825375	17989	Economy	66600.00
0005435825314	17989	Economy	66600.00
0005435825380	17989	Economy	66600.00
0005435825196	17989	Economy	66600.00
0005435825379	17989	Economy	66600.00
0005434461712	12569	Economy	13500.00
0005434461711	12569	Economy	13500.00
0005435243592	5635	Business	27800.00
0005435243591	5635	Business	27800.00
0005435476980	5635	Business	27800.00
0005435243520	5635	Business	27800.00
0005435243653	5635	Business	27800.00
0005435243561	5635	Economy	9300.00
0005435243548	5635	Economy	9300.00
0005435243519	5635	Economy	9300.00
0005435476979	5635	Economy	9300.00
0005435243612	5635	Economy	9300.00
0005435243625	5635	Economy	10200.00
0005435243546	5635	Economy	10200.00
0005435243563	5635	Economy	10200.00
0005435476993	5635	Economy	9300.00
0005435243562	5635	Economy	9300.00
0005435243613	5635	Economy	9300.00
0005435243633	5635	Economy	9300.00
0005435243549	5635	Economy	9300.00
0005435243614	5635	Economy	9300.00
0005435476959	5635	Economy	9300.00
0005435243643	5635	Economy	9300.00
0005435243645	5635	Economy	9300.00
0005435476990	5635	Economy	9300.00
0005435243622	5635	Economy	9300.00
0005435476976	5635	Economy	9300.00
0005435243575	5635	Economy	9300.00
0005435243617	5635	Economy	9300.00
0005435243564	5635	Economy	9300.00
0005435243607	5635	Economy	9300.00
0005435476974	5635	Economy	9300.00
0005435243576	5635	Economy	9300.00
0005435476975	5635	Economy	9300.00
0005435243619	5635	Economy	9300.00
0005435243654	5635	Economy	9300.00
0005435476994	5635	Economy	9300.00
0005432785173	15342	Business	27800.00
0005432785350	15342	Business	27800.00
0005432785293	15342	Business	27800.00
0005432785097	15342	Business	27800.00
0005432785246	15342	Business	27800.00
0005432785248	15342	Business	27800.00
0005432785224	15342	Business	27800.00
0005432785286	15342	Economy	9300.00
0005432785310	15342	Economy	9300.00
0005432785353	15342	Economy	9300.00
0005432785271	15342	Economy	9300.00
0005432785098	15342	Economy	9300.00
0005435950040	15342	Economy	9300.00
0005432784977	15342	Economy	9300.00
0005432785240	15342	Economy	10200.00
0005432785351	15342	Economy	10200.00
0005432785184	15342	Economy	10200.00
0005435243669	15342	Economy	10200.00
0005435949982	15342	Economy	9300.00
0005435950029	15342	Economy	9300.00
0005432785276	15342	Economy	9300.00
0005432785272	15342	Economy	9300.00
0005432785275	15342	Economy	9300.00
0005435950030	15342	Economy	9300.00
0005432785181	15342	Economy	9300.00
0005432785352	15342	Economy	9300.00
0005432785203	15342	Economy	9300.00
0005432785188	15342	Economy	9300.00
0005432785295	15342	Economy	9300.00
0005435950041	15342	Economy	9300.00
0005432785114	15342	Economy	9300.00
0005432785237	15342	Economy	9300.00
0005432785195	15342	Economy	9300.00
0005432785187	15342	Economy	9300.00
0005432785273	15342	Economy	9300.00
0005432785274	15342	Economy	9300.00
0005435950005	15342	Economy	9300.00
0005432785319	15342	Economy	9300.00
0005432785157	15342	Economy	9300.00
0005432785206	15342	Economy	9300.00
0005432785296	15342	Economy	9300.00
0005432785294	15342	Economy	9300.00
0005435950039	15342	Economy	9300.00
0005435243667	15342	Economy	9300.00
0005432785309	15342	Economy	9300.00
0005432785199	15342	Economy	9300.00
0005432785232	15342	Economy	9300.00
0005435949983	15342	Economy	9300.00
0005432785320	15342	Economy	9300.00
0005432785202	15342	Economy	9300.00
0005432785285	15342	Economy	9300.00
0005435950004	15342	Economy	9300.00
0005435243668	15342	Economy	9300.00
0005435851167	4337	Economy	7000.00
0005435851148	4337	Economy	6300.00
0005435851168	4337	Economy	6300.00
0005435851166	4337	Economy	6300.00
0005432848724	28831	Economy	7000.00
0005432848664	28831	Economy	6300.00
0005434461701	28831	Economy	6300.00
0005434461700	28831	Economy	6300.00
0005432848706	28831	Economy	6300.00
0005434461699	28831	Economy	6300.00
0005435257509	6351	Business	11900.00
0005435257523	6351	Economy	4000.00
0005435257508	6351	Economy	4000.00
0005435257474	6351	Economy	4000.00
0005435257535	6351	Economy	4000.00
0005435257522	6351	Economy	4000.00
0005435257534	6351	Economy	4000.00
0005435257524	6351	Economy	4000.00
0005434444123	20391	Business	11900.00
0005434926795	20391	Business	11900.00
0005433497760	20391	Business	11900.00
0005434926721	20391	Business	11900.00
0005434926618	20391	Business	11900.00
0005433497771	20391	Business	11900.00
0005434926712	20391	Business	11900.00
0005433497835	20391	Business	11900.00
0005433497870	20391	Business	11900.00
0005434926641	20391	Economy	4000.00
0005434444156	20391	Economy	4000.00
0005434444157	20391	Economy	4000.00
0005434444086	20391	Economy	4000.00
0005434926693	20391	Economy	4000.00
0005434444160	20391	Economy	4000.00
0005434926619	20391	Economy	4000.00
0005434926680	20391	Economy	4400.00
0005434926769	20391	Economy	4400.00
0005433497869	20391	Economy	4400.00
0005434926560	20391	Economy	4000.00
0005434926738	20391	Economy	4000.00
0005433497836	20391	Economy	4000.00
0005434926792	20391	Economy	4000.00
0005434926774	20391	Economy	4000.00
0005434926679	20391	Economy	4000.00
0005434926768	20391	Economy	4000.00
0005434444126	20391	Economy	4000.00
0005434444124	20391	Economy	4000.00
0005433497762	20391	Economy	4000.00
0005434926764	20391	Economy	4000.00
0005434444128	20391	Economy	4000.00
0005434444118	20391	Economy	4000.00
0005434926778	20391	Economy	4000.00
0005434926645	20391	Economy	4000.00
0005434926831	20391	Economy	4000.00
0005434444119	20391	Economy	4000.00
0005434926737	20391	Economy	4000.00
0005433497772	20391	Economy	4000.00
0005433497860	20391	Economy	4000.00
0005434926624	20391	Economy	4000.00
0005434926620	20391	Economy	4000.00
0005433497890	20391	Economy	4000.00
0005434444125	20391	Economy	4000.00
0005434926720	20391	Economy	4000.00
0005434926775	20391	Economy	4000.00
0005434444161	20391	Economy	4000.00
0005434926709	20391	Economy	4000.00
0005434926838	20391	Economy	4000.00
0005434926628	20391	Economy	4000.00
0005433497761	20391	Economy	4000.00
0005434926561	20391	Economy	4000.00
0005434926704	20391	Economy	4000.00
0005434444117	20391	Economy	4000.00
0005435375182	20391	Economy	4000.00
0005434444087	20391	Economy	4000.00
0005434926722	20391	Economy	4000.00
0005434926710	20391	Economy	4000.00
0005434926529	20391	Economy	4000.00
0005434926740	20391	Economy	4000.00
0005434444122	20391	Economy	4000.00
0005434926623	20391	Economy	4000.00
0005434926654	20391	Economy	4000.00
0005434444116	20391	Economy	4000.00
0005434926739	20391	Economy	4000.00
0005435375181	20391	Economy	4000.00
0005434444121	20391	Economy	4000.00
0005434926689	20391	Economy	4000.00
0005433497887	20391	Economy	4000.00
0005434926644	20391	Economy	4000.00
0005434926687	20391	Economy	4000.00
0005432785324	12178	Business	41200.00
0005432785226	12178	Business	41200.00
0005432785323	12178	Economy	13700.00
0005432785259	12178	Economy	15100.00
0005432785260	12178	Economy	13700.00
0005432785261	12178	Economy	13700.00
0005432785281	12178	Economy	13700.00
0005432785355	12178	Economy	13700.00
0005432785254	12178	Economy	13700.00
0005432785250	12178	Economy	13700.00
0005432785348	12178	Economy	13700.00
0005432785211	12178	Economy	13700.00
0005432785243	12178	Economy	13700.00
0005432785231	12178	Economy	13700.00
0005432785210	12178	Economy	13700.00
0005432785308	12178	Economy	13700.00
0005432785230	12178	Economy	13700.00
0005432785251	12178	Economy	13700.00
0005435243567	15417	Business	41200.00
0005435243585	15417	Economy	13700.00
0005435243611	15417	Economy	13700.00
0005435243565	15417	Economy	13700.00
0005435243627	15417	Economy	13700.00
0005435243559	15417	Economy	13700.00
0005435243656	15417	Economy	13700.00
0005435243465	15417	Economy	13700.00
0005435243634	15417	Economy	13700.00
0005435243597	15417	Economy	13700.00
0005435243566	15417	Economy	13700.00
0005435243466	15417	Economy	13700.00
0005435243623	15417	Economy	13700.00
0005435243521	15417	Economy	13700.00
0005435243558	15417	Economy	13700.00
0005435243657	15417	Economy	13700.00
0005434880640	10090	Business	49700.00
0005434880777	10090	Business	49700.00
0005434880937	10090	Business	49700.00
0005434880562	10090	Business	49700.00
0005434880902	10090	Business	49700.00
0005434880732	10090	Business	49700.00
0005434880854	10090	Business	49700.00
0005434880773	10090	Business	49700.00
0005434880827	10090	Economy	16600.00
0005434880642	10090	Economy	16600.00
0005434880817	10090	Economy	16600.00
0005434880962	10090	Economy	16600.00
0005434880644	10090	Economy	16600.00
0005434880881	10090	Economy	18200.00
0005434880723	10090	Economy	16600.00
0005434880866	10090	Economy	16600.00
0005434880869	10090	Economy	16600.00
0005434880566	10090	Economy	16600.00
0005434880965	10090	Economy	16600.00
0005434880766	10090	Economy	16600.00
0005434880561	10090	Economy	16600.00
0005434880929	10090	Economy	16600.00
0005434880734	10090	Economy	16600.00
0005434880961	10090	Economy	16600.00
0005434880818	10090	Economy	16600.00
0005434880765	10090	Economy	16600.00
0005434880826	10090	Economy	16600.00
0005434880971	10090	Economy	16600.00
0005434880563	10090	Economy	16600.00
0005434880696	10090	Economy	16600.00
0005434880786	10090	Economy	16600.00
0005434880693	10090	Economy	16600.00
0005434880785	10090	Economy	16600.00
0005434880928	10090	Economy	16600.00
0005434880853	10090	Economy	16600.00
0005434880964	10090	Economy	16600.00
0005434880692	10090	Economy	16600.00
0005434880664	10090	Economy	16600.00
0005434880919	10090	Economy	16600.00
0005434880938	10090	Economy	16600.00
0005434880784	10090	Economy	16600.00
0005434880733	10090	Economy	16600.00
0005434880359	10090	Economy	16600.00
0005434880518	10090	Economy	16600.00
0005434880963	10090	Economy	16600.00
0005434880876	10090	Economy	16600.00
0005434880697	10090	Economy	16600.00
0005434880714	10090	Economy	16600.00
0005435914167	14626	Business	49700.00
0005435914185	14626	Business	49700.00
0005434910182	14626	Economy	16600.00
0005435914079	14626	Economy	18200.00
0005435914097	14626	Economy	16600.00
0005435914080	14626	Economy	16600.00
0005435914201	14626	Economy	16600.00
0005435914147	14626	Economy	16600.00
0005435914203	14626	Economy	16600.00
0005435914146	14626	Economy	16600.00
0005435914186	14626	Economy	16600.00
0005435914096	14626	Economy	16600.00
0005435914166	14626	Economy	16600.00
0005435914202	14626	Economy	16600.00
0005435914145	14626	Economy	16600.00
0005434910177	14626	Economy	16600.00
0005435933581	9223	Economy	22400.00
0005434252221	9223	Economy	22400.00
0005435933575	9223	Economy	22400.00
0005434252222	9223	Economy	20300.00
0005434252236	9223	Economy	20300.00
0005434252211	9223	Economy	20300.00
0005435933585	9223	Economy	20300.00
0005435933573	9223	Economy	20300.00
0005435660399	24641	Economy	22400.00
0005435660446	24641	Economy	22400.00
0005435660443	24641	Economy	20300.00
0005435660428	24641	Economy	20300.00
0005435660445	24641	Economy	20300.00
0005435660421	24641	Economy	20300.00
0005435660400	24641	Economy	20300.00
0005435660412	24641	Economy	20300.00
0005435660442	24641	Economy	20300.00
0005432967614	2794	Business	33000.00
0005432967624	2794	Economy	11000.00
0005432967613	2794	Economy	12100.00
0005432967625	2794	Economy	11000.00
0005432967644	2794	Economy	11000.00
0005432967676	2794	Economy	11000.00
0005432967643	2794	Economy	11000.00
0005432967542	2794	Economy	11000.00
0005432967636	2794	Economy	11000.00
0005433690983	29196	Business	33000.00
0005433681897	29196	Business	33000.00
0005433681890	29196	Business	33000.00
0005433681894	29196	Economy	11000.00
0005433681893	29196	Economy	11000.00
0005433681829	29196	Economy	11000.00
0005433681888	29196	Economy	11000.00
0005433681976	29196	Economy	11000.00
0005433681916	29196	Economy	12100.00
0005433690982	29196	Economy	12100.00
0005433690985	29196	Economy	12100.00
0005433681941	29196	Economy	11000.00
0005433681923	29196	Economy	11000.00
0005433681962	29196	Economy	11000.00
0005433681883	29196	Economy	11000.00
0005433681891	29196	Economy	11000.00
0005433681906	29196	Economy	11000.00
0005433690981	29196	Economy	11000.00
0005433684480	29196	Economy	11000.00
0005433681889	29196	Economy	11000.00
0005433690986	29196	Economy	11000.00
0005433684481	29196	Economy	11000.00
0005433684474	29196	Economy	11000.00
0005433681907	29196	Economy	11000.00
0005433681942	29196	Economy	11000.00
0005433681975	29196	Economy	11000.00
0005433684475	29196	Economy	11000.00
0005433681917	29196	Economy	11000.00
0005433684479	29196	Economy	11000.00
0005433681896	29196	Economy	11000.00
0005433681814	29196	Economy	11000.00
0005433681815	29196	Economy	11000.00
0005433681813	29196	Economy	11000.00
0005433681831	29196	Economy	11000.00
0005433681763	29196	Economy	11000.00
0005433681762	29196	Economy	11000.00
0005434163865	9287	Business	132900.00
0005434163881	9287	Economy	44300.00
0005434163869	9287	Economy	44300.00
0005434163885	9287	Economy	44300.00
0005434272231	9287	Economy	44300.00
0005434153568	9287	Economy	44300.00
0005435856356	9287	Economy	44300.00
0005435854088	9287	Economy	44300.00
0005434163866	9287	Economy	44300.00
0005434163868	9287	Economy	44300.00
0005434269161	9287	Economy	44300.00
0005435856347	9287	Economy	44300.00
0005435854090	9287	Economy	44300.00
0005434269159	9287	Economy	44300.00
0005434152845	9287	Economy	44300.00
0005433616755	25239	Business	132900.00
0005433616790	25239	Business	132900.00
0005433616498	25239	Business	132900.00
0005435983717	25239	Business	132900.00
0005433616795	25239	Business	132900.00
0005433634661	25239	Business	132900.00
0005435983712	25239	Business	132900.00
0005433634808	25239	Business	132900.00
0005433616706	25239	Business	132900.00
0005433634656	25239	Business	132900.00
0005433634783	25239	Business	132900.00
0005433616793	25239	Business	132900.00
0005433616624	25239	Business	132900.00
0005433616711	25239	Business	132900.00
0005433616605	25239	Business	132900.00
0005433616749	25239	Business	132900.00
0005433616589	25239	Business	132900.00
0005433616722	25239	Economy	48700.00
0005433616497	25239	Economy	48700.00
0005433616782	25239	Economy	44300.00
0005433634782	25239	Economy	44300.00
0005433634814	25239	Economy	44300.00
0005433616748	25239	Economy	44300.00
0005433616599	25239	Economy	44300.00
0005433616776	25239	Economy	44300.00
0005433616781	25239	Economy	44300.00
0005433616496	25239	Economy	44300.00
0005433616719	25239	Economy	44300.00
0005433634759	25239	Economy	44300.00
0005433616625	25239	Economy	44300.00
0005433616759	25239	Economy	44300.00
0005433616698	25239	Economy	44300.00
0005433616435	25239	Economy	44300.00
0005433634751	25239	Economy	44300.00
0005433616660	25239	Economy	44300.00
0005433616612	25239	Economy	44300.00
0005433616786	25239	Economy	44300.00
0005433634760	25239	Economy	44300.00
0005433616785	25239	Economy	44300.00
0005433616405	25239	Economy	44300.00
0005433634714	25239	Economy	48700.00
0005433616652	25239	Economy	48700.00
0005433578186	25239	Economy	48700.00
0005433616714	25239	Economy	44300.00
0005433616434	25239	Economy	44300.00
0005433578179	25239	Economy	44300.00
0005433616784	25239	Economy	44300.00
0005433616792	25239	Economy	44300.00
0005433616644	25239	Economy	44300.00
0005433578172	25239	Economy	44300.00
0005433616646	25239	Economy	44300.00
0005433616783	25239	Economy	44300.00
0005433634713	25239	Economy	44300.00
0005433616647	25239	Economy	44300.00
0005433616723	25239	Economy	44300.00
0005433616760	25239	Economy	44300.00
0005433616678	25239	Economy	44300.00
0005433616632	25239	Economy	44300.00
0005433616288	25239	Economy	44300.00
0005433616794	25239	Economy	44300.00
0005433616679	25239	Economy	44300.00
0005433616639	25239	Economy	44300.00
0005433578185	25239	Economy	44300.00
0005433578181	25239	Economy	44300.00
0005433634770	25239	Economy	44300.00
0005433634769	25239	Economy	44300.00
0005433578173	25239	Economy	44300.00
0005433616633	25239	Economy	44300.00
0005433634720	25239	Economy	44300.00
0005433616710	25239	Economy	44300.00
0005435947621	4202	Business	193100.00
0005435856327	4202	Business	193100.00
0005434273131	4202	Business	193100.00
0005435947684	4202	Economy	70800.00
0005435947594	4202	Economy	64400.00
0005434271363	4202	Economy	64400.00
0005435947620	4202	Economy	64400.00
0005434273132	4202	Economy	64400.00
0005434271372	4202	Economy	64400.00
0005434271375	4202	Economy	64400.00
0005435947624	4202	Economy	64400.00
0005435856317	4202	Economy	64400.00
0005434271374	4202	Economy	64400.00
0005435854087	4202	Economy	64400.00
0005434273134	4202	Economy	64400.00
0005435856325	4202	Economy	64400.00
0005435947666	4202	Economy	64400.00
0005432571419	4202	Economy	64400.00
0005435947623	4202	Economy	64400.00
0005434271373	4202	Economy	64400.00
0005434271371	4202	Economy	64400.00
0005434271364	4202	Economy	64400.00
0005435947667	4202	Economy	64400.00
0005434273133	4202	Economy	64400.00
0005435947644	4202	Economy	64400.00
0005432571438	4202	Economy	64400.00
0005435856318	4202	Economy	64400.00
0005435986999	26578	Business	193100.00
0005435986940	26578	Business	193100.00
0005435987020	26578	Business	193100.00
0005435987045	26578	Economy	70800.00
0005435987053	26578	Economy	70800.00
0005435987034	26578	Economy	64400.00
0005435987019	26578	Economy	64400.00
0005435987035	26578	Economy	64400.00
0005435987017	26578	Economy	64400.00
0005435987054	26578	Economy	64400.00
0005435987055	26578	Economy	64400.00
0005435987037	26578	Economy	64400.00
0005433075429	316	Business	21500.00
0005433075497	316	Business	21500.00
0005433075519	316	Business	21500.00
0005432949616	316	Business	21500.00
0005433075468	316	Business	21500.00
0005432949633	316	Business	21500.00
0005432949658	316	Business	21500.00
0005432949599	316	Business	21500.00
0005432949657	316	Business	21500.00
0005432949529	316	Business	21500.00
0005433075428	316	Business	21500.00
0005433129401	316	Business	21500.00
0005433075469	316	Economy	7900.00
0005433075458	316	Economy	7900.00
0005432949615	316	Economy	7200.00
0005432949362	316	Economy	7200.00
0005433075434	316	Economy	7200.00
0005432949632	316	Economy	7200.00
0005432949634	316	Economy	7200.00
0005433075430	316	Economy	7200.00
0005432949457	316	Economy	7200.00
0005432949637	316	Economy	7200.00
0005433075521	316	Economy	7200.00
0005432949363	316	Economy	7200.00
0005432949652	316	Economy	7200.00
0005432949638	316	Economy	7200.00
0005432949612	316	Economy	7200.00
0005432949607	316	Economy	7200.00
0005433075518	316	Economy	7200.00
0005432949660	316	Economy	7200.00
0005433129392	316	Economy	7200.00
0005432949328	316	Economy	7200.00
0005432949623	316	Economy	7200.00
0005432949530	316	Economy	7200.00
0005432949555	316	Economy	7200.00
0005432949631	316	Economy	7200.00
0005432949628	316	Economy	7900.00
0005432949458	316	Economy	7900.00
0005432949556	316	Economy	7200.00
0005433129400	316	Economy	7900.00
0005433129391	316	Economy	7200.00
0005433075457	316	Economy	7200.00
0005433075511	316	Economy	7200.00
0005432949574	316	Economy	7200.00
0005432949636	316	Economy	7200.00
0005433075440	316	Economy	7200.00
0005432949488	316	Economy	7200.00
0005433075498	316	Economy	7200.00
0005433075481	316	Economy	7200.00
0005433075456	316	Economy	7200.00
0005433075444	316	Economy	7200.00
0005432949643	316	Economy	7200.00
0005432949611	316	Economy	7200.00
0005433134260	316	Economy	7200.00
0005433075411	316	Economy	7200.00
0005432949540	316	Economy	7200.00
0005432949541	316	Economy	7200.00
0005432949671	316	Economy	7200.00
0005432949571	316	Economy	7200.00
0005432949600	316	Economy	7200.00
0005432949627	316	Economy	7200.00
0005433075520	316	Economy	7200.00
0005432949666	316	Economy	7200.00
0005433129402	316	Economy	7200.00
0005432949531	316	Economy	7200.00
0005432949651	316	Economy	7200.00
0005432949665	316	Economy	7200.00
0005432949659	316	Economy	7200.00
0005433570653	11604	Business	21500.00
0005433570879	11604	Business	21500.00
0005433570727	11604	Business	21500.00
0005433570871	11604	Business	21500.00
0005434088004	11604	Business	21500.00
0005434087959	11604	Business	21500.00
0005433570769	11604	Business	21500.00
0005433570710	11604	Business	21500.00
0005433570784	11604	Business	21500.00
0005433570894	11604	Business	21500.00
0005433570723	11604	Business	21500.00
0005433570446	11604	Business	21500.00
0005433570757	11604	Business	21500.00
0005434087989	11604	Business	21500.00
0005433570863	11604	Business	21500.00
0005434087960	11604	Business	21500.00
0005433570854	11604	Business	21500.00
0005433570616	11604	Economy	7900.00
0005433570776	11604	Business	21500.00
0005433570910	11604	Economy	7900.00
0005433570580	11604	Economy	7900.00
0005434088034	11604	Economy	7200.00
0005433570870	11604	Economy	7900.00
0005433570826	11604	Economy	7200.00
0005433570503	11604	Economy	7200.00
0005434087968	11604	Economy	7200.00
0005433570722	11604	Economy	7200.00
0005433570590	11604	Economy	7200.00
0005434087971	11604	Economy	7200.00
0005433570506	11604	Economy	7200.00
0005433570649	11604	Economy	7200.00
0005433570785	11604	Economy	7200.00
0005433570743	11604	Economy	7200.00
0005433570731	11604	Economy	7200.00
0005434088042	11604	Economy	7200.00
0005433570938	11604	Economy	7200.00
0005433570686	11604	Economy	7200.00
0005433570556	11604	Economy	7200.00
0005433570538	11604	Economy	7200.00
0005433570591	11604	Economy	7200.00
0005433570502	11604	Economy	7200.00
0005433570709	11604	Economy	7200.00
0005433570752	11604	Economy	7200.00
0005434087997	11604	Economy	7200.00
0005433570770	11604	Economy	7200.00
0005433570768	11604	Economy	7200.00
0005433570654	11604	Economy	7200.00
0005433570939	11604	Economy	7200.00
0005433570299	11604	Economy	7200.00
0005433570775	11604	Economy	7200.00
0005434326045	11604	Economy	7200.00
0005433570507	11604	Economy	7200.00
0005434088022	11604	Economy	7200.00
0005434088018	11604	Economy	7900.00
0005434088002	11604	Economy	7900.00
0005434088012	11604	Economy	7900.00
0005434087958	11604	Economy	7900.00
0005433570482	11604	Economy	7900.00
0005433570650	11604	Economy	7200.00
0005433570539	11604	Economy	7200.00
0005433570742	11604	Economy	7900.00
0005433570513	11604	Economy	7200.00
0005434326036	11604	Economy	7200.00
0005434088003	11604	Economy	7200.00
0005434088001	11604	Economy	7200.00
0005433570820	11604	Economy	7200.00
0005433570895	11604	Economy	7200.00
0005434326038	11604	Economy	7200.00
0005434087972	11604	Economy	7200.00
0005433570677	11604	Economy	7200.00
0005434326013	11604	Economy	7200.00
0005434087996	11604	Economy	7200.00
0005433570819	11604	Economy	7200.00
0005433570300	11604	Economy	7200.00
0005433570724	11604	Economy	7200.00
0005434088027	11604	Economy	7200.00
0005433570876	11604	Economy	7200.00
0005433570750	11604	Economy	7200.00
0005433570918	11604	Economy	7200.00
0005433570581	11604	Economy	7200.00
0005434326026	11604	Economy	7200.00
0005433570813	11604	Economy	7200.00
0005433570755	11604	Economy	7200.00
0005433570679	11604	Economy	7200.00
0005433570537	11604	Economy	7200.00
0005433570864	11604	Economy	7200.00
0005434087973	11604	Economy	7200.00
0005433570589	11604	Economy	7200.00
0005434088039	11604	Economy	7200.00
0005433570705	11604	Economy	7200.00
0005433570809	11604	Economy	7200.00
0005434087982	11604	Economy	7200.00
0005433570720	11604	Economy	7200.00
0005433570777	11604	Economy	7200.00
0005434087966	11604	Economy	7200.00
0005433570665	11604	Economy	7200.00
0005434733079	9944	Economy	6300.00
0005434731281	2328	Business	184500.00
0005433435472	2328	Business	184500.00
0005433435418	2328	Business	184500.00
0005434731280	2328	Economy	67700.00
0005434376166	2328	Economy	61500.00
0005432985978	2328	Economy	61500.00
0005432985859	2328	Economy	61500.00
0005433435346	2328	Economy	61500.00
0005433435446	2328	Economy	61500.00
0005432985984	2328	Economy	61500.00
0005433435462	2328	Economy	61500.00
0005433435427	2328	Economy	61500.00
0005432985928	2328	Economy	61500.00
0005433435393	2328	Economy	61500.00
0005433435459	2328	Economy	61500.00
0005432986009	2328	Economy	61500.00
0005432985927	2328	Economy	61500.00
0005433435345	2328	Economy	61500.00
0005432869710	2328	Economy	61500.00
0005434731282	2328	Economy	61500.00
0005433435426	2328	Economy	61500.00
0005432985956	2328	Economy	61500.00
0005432986006	2328	Economy	61500.00
0005432985985	2328	Economy	61500.00
0005432985977	2328	Economy	61500.00
0005433435394	2328	Economy	61500.00
0005434731289	2328	Economy	61500.00
0005433435471	2328	Economy	61500.00
0005432985868	2328	Economy	61500.00
0005433435428	2328	Economy	61500.00
0005433755699	26175	Business	184500.00
0005435983547	26175	Business	184500.00
0005433766749	26175	Business	184500.00
0005432655797	26175	Business	184500.00
0005435983316	26175	Business	184500.00
0005435983504	26175	Business	184500.00
0005435983387	26175	Business	184500.00
0005435983649	26175	Business	184500.00
0005435983573	26175	Business	184500.00
0005433755633	26175	Business	184500.00
0005435983587	26175	Business	184500.00
0005433755754	26175	Economy	67700.00
0005435983467	26175	Economy	67700.00
0005433755720	26175	Economy	61500.00
0005432655884	26175	Economy	61500.00
0005435983434	26175	Economy	61500.00
0005432655850	26175	Economy	61500.00
0005433755806	26175	Economy	61500.00
0005433755853	26175	Economy	61500.00
0005435983409	26175	Economy	61500.00
0005433755883	26175	Economy	61500.00
0005435983435	26175	Economy	61500.00
0005435983641	26175	Economy	61500.00
0005435983463	26175	Economy	61500.00
0005433755813	26175	Economy	61500.00
0005433755839	26175	Economy	61500.00
0005435983565	26175	Economy	61500.00
0005433766748	26175	Economy	61500.00
0005435983643	26175	Economy	61500.00
0005435983584	26175	Economy	61500.00
0005435983568	26175	Economy	61500.00
0005433766764	26175	Economy	61500.00
0005432655883	26175	Economy	61500.00
0005433766738	26175	Economy	61500.00
0005433755852	26175	Economy	61500.00
0005435983633	26175	Economy	61500.00
0005435983648	26175	Economy	61500.00
0005435983570	26175	Economy	61500.00
0005433755882	26175	Economy	61500.00
0005432655847	26175	Economy	61500.00
0005433755802	26175	Economy	61500.00
0005432655874	26175	Economy	61500.00
0005435983630	26175	Economy	61500.00
0005433755805	26175	Economy	61500.00
0005433755490	26175	Economy	61500.00
0005433755751	26175	Economy	61500.00
0005435983408	26175	Economy	61500.00
0005433755642	26175	Economy	61500.00
0005432655854	26175	Economy	61500.00
0005433755733	26175	Economy	61500.00
0005432655873	26175	Economy	61500.00
0005433755838	26175	Economy	67700.00
0005432655844	26175	Economy	61500.00
0005432655845	26175	Economy	61500.00
0005433755835	26175	Economy	61500.00
0005435983586	26175	Economy	61500.00
0005433755803	26175	Economy	61500.00
0005433755837	26175	Economy	61500.00
0005435983613	26175	Economy	61500.00
0005435983629	26175	Economy	61500.00
0005435983583	26175	Economy	61500.00
0005435983315	26175	Economy	61500.00
0005432655841	26175	Economy	61500.00
0005432655846	26175	Economy	61500.00
0005435983552	26175	Economy	61500.00
0005433755756	26175	Economy	61500.00
0005435983566	26175	Economy	61500.00
0005433755687	26175	Economy	61500.00
0005435983644	26175	Economy	61500.00
0005435983400	26175	Economy	61500.00
0005435983314	26175	Economy	61500.00
0005433755804	26175	Economy	61500.00
0005433755845	26175	Economy	61500.00
0005433755634	26175	Economy	61500.00
0005433755697	26175	Economy	61500.00
0005435983532	26175	Economy	61500.00
0005435983472	26175	Economy	61500.00
0005435983614	26175	Economy	61500.00
0005435983401	26175	Economy	61500.00
0005435983546	26175	Economy	61500.00
0005433755801	26175	Economy	61500.00
0005435983605	26175	Economy	61500.00
0005433755790	26175	Economy	61500.00
0005433755491	26175	Economy	61500.00
0005433152404	1488	Business	38900.00
0005433152251	1488	Business	38900.00
0005433931544	1488	Economy	13000.00
0005433152407	1488	Economy	13000.00
0005433152415	1488	Economy	13000.00
0005433152378	1488	Economy	13000.00
0005433152302	1488	Economy	13000.00
0005433931549	1488	Economy	13000.00
0005433764735	1488	Economy	13000.00
0005433152324	1488	Economy	13000.00
0005433931550	1488	Economy	13000.00
0005433152299	1488	Economy	13000.00
0005433152405	1488	Economy	13000.00
0005433152403	1488	Economy	14300.00
0005433152250	1488	Economy	13000.00
0005433152406	1488	Economy	13000.00
0005433152303	1488	Economy	13000.00
0005433152320	1488	Economy	13000.00
0005433931551	1488	Economy	13000.00
0005433152300	1488	Economy	13000.00
0005433152377	1488	Economy	13000.00
0005433152249	1488	Economy	13000.00
0005433152319	1488	Economy	13000.00
0005433152355	1488	Economy	13000.00
0005433461639	20154	Business	38900.00
0005434376237	20154	Business	38900.00
0005434375943	20154	Business	38900.00
0005434376015	20154	Business	38900.00
0005433461628	20154	Business	38900.00
0005433463933	20154	Business	38900.00
0005434375708	20154	Economy	13000.00
0005434376232	20154	Economy	13000.00
0005434375814	20154	Economy	13000.00
0005434376054	20154	Economy	13000.00
0005433463950	20154	Economy	13000.00
0005433461636	20154	Economy	13000.00
0005433463947	20154	Economy	13000.00
0005434375988	20154	Economy	13000.00
0005434375707	20154	Economy	13000.00
0005434375956	20154	Economy	13000.00
0005434376166	20154	Economy	13000.00
0005434375754	20154	Economy	13000.00
0005433461638	20154	Economy	13000.00
0005433463956	20154	Economy	13000.00
0005434375980	20154	Economy	13000.00
0005434375826	20154	Economy	13000.00
0005433463943	20154	Economy	13000.00
0005433463949	20154	Economy	13000.00
0005433461642	20154	Economy	13000.00
0005434376239	20154	Economy	13000.00
0005433463944	20154	Economy	13000.00
0005434375888	20154	Economy	13000.00
0005434375833	20154	Economy	13000.00
0005433461651	20154	Economy	13000.00
0005433463954	20154	Economy	13000.00
0005434376183	20154	Economy	13000.00
0005433463939	20154	Economy	13000.00
0005434376187	20154	Economy	14300.00
0005434375709	20154	Economy	14300.00
0005434376053	20154	Economy	14300.00
0005434375931	20154	Economy	14300.00
0005433461629	20154	Economy	14300.00
0005434376040	20154	Economy	13000.00
0005434375834	20154	Economy	13000.00
0005434375979	20154	Economy	13000.00
0005434375984	20154	Economy	13000.00
0005434376019	20154	Economy	13000.00
0005434375906	20154	Economy	13000.00
0005434375882	20154	Economy	13000.00
0005433463942	20154	Economy	13000.00
0005434375955	20154	Economy	13000.00
0005433463948	20154	Economy	13000.00
0005434376020	20154	Economy	13000.00
0005434375898	20154	Economy	13000.00
0005434376238	20154	Economy	13000.00
0005434375949	20154	Economy	13000.00
0005434375706	20154	Economy	13000.00
0005433463955	20154	Economy	13000.00
0005433463946	20154	Economy	13000.00
0005433463951	20154	Economy	13000.00
0005433463945	20154	Economy	13000.00
0005433461637	20154	Economy	13000.00
0005434376041	20154	Economy	13000.00
0005434375788	20154	Economy	13000.00
0005434375942	20154	Economy	13000.00
0005433463952	20154	Economy	13000.00
0005433461635	20154	Economy	13000.00
0005434375815	20154	Economy	13000.00
0005434376039	20154	Economy	13000.00
0005433461633	20154	Economy	13000.00
0005434375899	20154	Economy	13000.00
0005433463953	20154	Economy	13000.00
0005434375932	20154	Economy	13000.00
0005433461640	20154	Economy	13000.00
0005433461627	20154	Economy	13000.00
0005433461641	20154	Economy	13000.00
0005433461630	20154	Economy	13000.00
0005434376186	20154	Economy	13000.00
0005434375755	20154	Economy	13000.00
0005433461634	20154	Economy	13000.00
0005433461643	20154	Economy	13000.00
0005434376233	20154	Economy	13000.00
0005434376234	20154	Economy	13000.00
0005434376055	20154	Economy	13000.00
0005433262059	600	Business	27500.00
0005433157020	600	Business	27500.00
0005433262060	600	Business	27500.00
0005433262006	600	Business	27500.00
0005433158200	600	Economy	10100.00
0005433262029	600	Economy	9200.00
0005433262013	600	Economy	9200.00
0005433157021	600	Economy	9200.00
0005433262016	600	Economy	9200.00
0005433157019	600	Economy	9200.00
0005433262031	600	Economy	9200.00
0005433262021	600	Economy	9200.00
0005433766763	600	Economy	9200.00
0005433766762	600	Economy	9200.00
0005433766765	600	Economy	9200.00
0005433766766	600	Economy	9200.00
0005433157022	600	Economy	9200.00
0005433262015	600	Economy	9200.00
0005433262030	600	Economy	9200.00
0005433261913	600	Economy	9200.00
0005433262027	600	Economy	9200.00
0005432425747	12875	Business	27500.00
0005432425925	12875	Business	27500.00
0005432425856	12875	Business	27500.00
0005432425855	12875	Business	27500.00
0005432425952	12875	Business	27500.00
0005432425871	12875	Business	27500.00
0005432425789	12875	Business	27500.00
0005432425953	12875	Business	27500.00
0005432425879	12875	Business	27500.00
0005432425787	12875	Business	27500.00
0005432425762	12875	Economy	10100.00
0005432425916	12875	Economy	9200.00
0005432425838	12875	Economy	9200.00
0005432425847	12875	Economy	9200.00
0005432425575	12875	Economy	9200.00
0005432425662	12875	Economy	9200.00
0005432425876	12875	Economy	9200.00
0005432425975	12875	Economy	9200.00
0005432425721	12875	Economy	9200.00
0005432425755	12875	Economy	9200.00
0005432425674	12875	Economy	9200.00
0005432425723	12875	Economy	9200.00
0005432425734	12875	Economy	9200.00
0005432425720	12875	Economy	9200.00
0005432425813	12875	Economy	9200.00
0005432425908	12875	Economy	9200.00
0005432425812	12875	Economy	9200.00
0005432425802	12875	Economy	9200.00
0005432425701	12875	Economy	9200.00
0005432425760	12875	Economy	9200.00
0005432425937	12875	Economy	9200.00
0005432425880	12875	Economy	9200.00
0005432425751	12875	Economy	9200.00
0005432425850	12875	Economy	9200.00
0005432425846	12875	Economy	10100.00
0005432426025	12875	Economy	10100.00
0005432425938	12875	Economy	9200.00
0005432425974	12875	Economy	9200.00
0005432425761	12875	Economy	10100.00
0005432425921	12875	Economy	9200.00
0005432425739	12875	Economy	9200.00
0005432425752	12875	Economy	9200.00
0005432425687	12875	Economy	9200.00
0005432425815	12875	Economy	9200.00
0005432426011	12875	Economy	9200.00
0005432425857	12875	Economy	9200.00
0005432425756	12875	Economy	9200.00
0005432425867	12875	Economy	9200.00
0005432425814	12875	Economy	9200.00
0005432425909	12875	Economy	9200.00
0005432426014	12875	Economy	9200.00
0005432425992	12875	Economy	9200.00
0005432425840	12875	Economy	9200.00
0005432425663	12875	Economy	9200.00
0005432426054	12875	Economy	9200.00
0005432425920	12875	Economy	9200.00
0005432425899	12875	Economy	9200.00
0005432425722	12875	Economy	9200.00
0005432425926	12875	Economy	9200.00
0005432425904	12875	Economy	9200.00
0005432425664	12875	Economy	9200.00
0005432425845	12875	Economy	9200.00
0005432425861	12875	Economy	9200.00
0005432425811	12875	Economy	9200.00
0005432425702	12875	Economy	9200.00
0005432425868	12875	Economy	9200.00
0005433058817	464	Business	24500.00
0005433059003	464	Business	24500.00
0005434376228	464	Business	24500.00
0005433058983	464	Business	24500.00
0005434735829	464	Business	24500.00
0005434735837	464	Economy	8200.00
0005433059040	464	Economy	8200.00
0005433058997	464	Economy	8200.00
0005434376231	464	Economy	8200.00
0005433058996	464	Economy	8200.00
0005433684476	464	Economy	8200.00
0005433058893	464	Economy	8200.00
0005433929715	464	Economy	8200.00
0005433059041	464	Economy	8200.00
0005433058816	464	Economy	8200.00
0005434735830	464	Economy	8200.00
0005434735836	464	Economy	9000.00
0005433059044	464	Economy	9000.00
0005433059017	464	Economy	8200.00
0005433058952	464	Economy	8200.00
0005433929718	464	Economy	8200.00
0005434376229	464	Economy	8200.00
0005434032153	12672	Business	24500.00
0005434025639	12672	Business	24500.00
0005434025620	12672	Business	24500.00
0005434025483	12672	Business	24500.00
0005434025601	12672	Business	24500.00
0005434025293	12672	Business	24500.00
0005434025636	12672	Business	24500.00
0005434025607	12672	Business	24500.00
0005434025425	12672	Economy	9000.00
0005434025611	12672	Economy	9000.00
0005434025604	12672	Economy	8200.00
0005434025609	12672	Economy	8200.00
0005434025573	12672	Economy	8200.00
0005434025399	12672	Economy	8200.00
0005434025617	12672	Economy	8200.00
0005434028388	12672	Economy	8200.00
0005434025637	12672	Economy	8200.00
0005434025606	12672	Economy	8200.00
0005434025605	12672	Economy	8200.00
0005434025542	12672	Economy	8200.00
0005434025487	12672	Economy	8200.00
0005434025621	12672	Economy	8200.00
0005434025610	12672	Economy	8200.00
0005434025591	12672	Economy	8200.00
0005434025539	12672	Economy	8200.00
0005434025647	12672	Economy	8200.00
0005434025504	12672	Economy	8200.00
0005434025517	12672	Economy	8200.00
0005434025697	12672	Economy	8200.00
0005434025489	12672	Economy	8200.00
0005434025603	12672	Economy	8200.00
0005434025434	12672	Economy	8200.00
0005434025648	12672	Economy	8200.00
0005434028394	12672	Economy	8200.00
0005434025599	12672	Economy	8200.00
0005434025646	12672	Economy	8200.00
0005434025608	12672	Economy	8200.00
0005434025640	12672	Economy	8200.00
0005434025503	12672	Economy	8200.00
0005434025426	12672	Economy	8200.00
0005434025600	12672	Economy	8200.00
0005434025638	12672	Economy	8200.00
0005434025294	12672	Economy	8200.00
0005433037759	2167	Business	34700.00
0005433037776	2167	Business	34700.00
0005433037712	2167	Business	34700.00
0005433037733	2167	Business	34700.00
0005432749844	2167	Business	34700.00
0005434088051	2167	Economy	12700.00
0005433037762	2167	Economy	12700.00
0005433037740	2167	Economy	11600.00
0005434376183	2167	Economy	11600.00
0005432749845	2167	Economy	11600.00
0005434028394	2167	Economy	11600.00
0005433037734	2167	Economy	11600.00
0005433037832	2167	Economy	11600.00
0005433037805	2167	Economy	11600.00
0005433037597	2167	Economy	11600.00
0005433037680	2167	Economy	11600.00
0005433037812	2167	Economy	11600.00
0005433037688	2167	Economy	11600.00
0005434028388	2167	Economy	11600.00
0005433037732	2167	Economy	11600.00
0005433037717	2167	Economy	11600.00
0005433037679	2167	Economy	11600.00
0005433037780	2167	Economy	11600.00
0005433037806	2167	Economy	11600.00
0005433037825	2167	Economy	11600.00
0005433037833	2167	Economy	12700.00
0005434088050	2167	Economy	11600.00
0005433037674	2167	Economy	11600.00
0005433037768	2167	Economy	11600.00
0005433037670	2167	Economy	11600.00
0005434376186	2167	Economy	11600.00
0005433037687	2167	Economy	11600.00
0005433037760	2167	Economy	11600.00
0005433037842	2167	Economy	11600.00
0005433037739	2167	Economy	11600.00
0005433037686	2167	Economy	11600.00
0005433037763	2167	Economy	11600.00
0005433037669	2167	Economy	11600.00
0005434376187	2167	Economy	11600.00
0005433037782	2167	Economy	11600.00
0005433037716	2167	Economy	11600.00
0005433931545	24111	Business	34700.00
0005433926045	24111	Business	34700.00
0005433926057	24111	Business	34700.00
0005433931547	24111	Business	34700.00
0005433925712	24111	Business	34700.00
0005433925866	24111	Business	34700.00
0005433925745	24111	Business	34700.00
0005433925972	24111	Economy	12700.00
0005433925574	24111	Business	34700.00
0005433926047	24111	Economy	12700.00
0005433925744	24111	Economy	11600.00
0005433925973	24111	Economy	11600.00
0005433929724	24111	Economy	11600.00
0005433929720	24111	Economy	11600.00
0005433925823	24111	Economy	11600.00
0005433925713	24111	Economy	11600.00
0005433925868	24111	Economy	11600.00
0005433925734	24111	Economy	11600.00
0005433926051	24111	Economy	11600.00
0005433925888	24111	Economy	11600.00
0005433926103	24111	Economy	11600.00
0005433925971	24111	Economy	11600.00
0005433926070	24111	Economy	11600.00
0005433925575	24111	Economy	11600.00
0005433925944	24111	Economy	11600.00
0005433925733	24111	Economy	11600.00
0005433925882	24111	Economy	12700.00
0005433925943	24111	Economy	11600.00
0005433925768	24111	Economy	11600.00
0005433929727	24111	Economy	11600.00
0005433925732	24111	Economy	11600.00
0005433925708	24111	Economy	11600.00
0005433929729	24111	Economy	11600.00
0005433925938	24111	Economy	11600.00
0005433875425	24111	Economy	11600.00
0005433925731	24111	Economy	11600.00
0005433929728	24111	Economy	11600.00
0005433931558	24111	Economy	11600.00
0005433931546	24111	Economy	11600.00
0005433926044	24111	Economy	11600.00
0005433926064	24111	Economy	11600.00
0005433925660	24111	Economy	11600.00
0005433926104	24111	Economy	11600.00
0005433931559	24111	Economy	11600.00
0005433925865	24111	Economy	11600.00
0005433925991	24111	Economy	11600.00
0005433235858	248	Business	83700.00
0005433235947	248	Business	83700.00
0005433290063	248	Comfort	47400.00
0005433126966	248	Comfort	47400.00
0005433181736	248	Comfort	47400.00
0005433181794	248	Comfort	47400.00
0005433236042	248	Comfort	47400.00
0005433181837	248	Comfort	47400.00
0005434032134	248	Comfort	47400.00
0005433235857	248	Comfort	47400.00
0005433181839	248	Comfort	47400.00
0005433181820	248	Comfort	47400.00
0005433290066	248	Economy	27900.00
0005433235993	248	Economy	27900.00
0005433235811	248	Economy	27900.00
0005433181810	248	Economy	27900.00
0005433235943	248	Economy	27900.00
0005433235989	248	Economy	27900.00
0005433235944	248	Economy	27900.00
0005433290044	248	Economy	27900.00
0005433235899	248	Economy	27900.00
0005433290064	248	Economy	27900.00
0005433236040	248	Economy	30700.00
0005433235764	248	Economy	27900.00
0005433766743	248	Economy	27900.00
0005433181814	248	Economy	27900.00
0005433290045	248	Economy	27900.00
0005434032136	248	Economy	27900.00
0005433235853	248	Economy	27900.00
0005433290051	248	Economy	27900.00
0005433235908	248	Economy	27900.00
0005433126965	248	Economy	27900.00
0005433766752	248	Economy	27900.00
0005433235850	248	Economy	27900.00
0005433235954	248	Economy	27900.00
0005433235653	248	Economy	27900.00
0005434032135	248	Economy	27900.00
0005433126977	248	Economy	27900.00
0005433766742	248	Economy	27900.00
0005433181809	248	Economy	27900.00
0005433235672	248	Economy	27900.00
0005433235955	248	Economy	27900.00
0005433235877	248	Economy	27900.00
0005433766744	248	Economy	27900.00
0005433235991	248	Economy	27900.00
0005433235920	248	Economy	27900.00
0005433235984	248	Economy	27900.00
0005433235856	248	Economy	27900.00
0005433235671	248	Economy	27900.00
0005433111554	248	Economy	27900.00
0005433236041	248	Economy	27900.00
0005433126978	248	Economy	27900.00
0005433235953	248	Economy	27900.00
0005434032152	248	Economy	27900.00
0005433236043	248	Economy	27900.00
0005433290062	248	Economy	27900.00
0005433181742	248	Economy	27900.00
0005433235652	248	Economy	27900.00
0005433235988	248	Economy	27900.00
0005433235992	248	Economy	27900.00
0005433235765	248	Economy	27900.00
0005433235812	248	Economy	27900.00
0005433235950	248	Economy	27900.00
0005434032154	248	Economy	27900.00
0005434728573	9843	Business	83700.00
0005434731281	9843	Business	83700.00
0005434728929	9843	Business	83700.00
0005434728685	9843	Business	83700.00
0005434552705	9843	Business	83700.00
0005434728903	9843	Business	83700.00
0005434728952	9843	Business	83700.00
0005434728534	9843	Business	83700.00
0005434728886	9843	Business	83700.00
0005434552745	9843	Business	83700.00
0005434728883	9843	Comfort	47400.00
0005434728757	9843	Comfort	47400.00
0005434552750	9843	Comfort	47400.00
0005434728923	9843	Comfort	47400.00
0005434552793	9843	Comfort	47400.00
0005434552616	9843	Comfort	47400.00
0005434731282	9843	Comfort	47400.00
0005434728780	9843	Comfort	47400.00
0005434728880	9843	Comfort	47400.00
0005434728760	9843	Comfort	47400.00
0005434552776	9843	Comfort	47400.00
0005434728902	9843	Comfort	47400.00
0005434302563	9843	Economy	27900.00
0005434552746	9843	Comfort	47400.00
0005434728309	9843	Economy	27900.00
0005434552792	9843	Economy	27900.00
0005434728599	9843	Economy	27900.00
0005435142957	9843	Economy	27900.00
0005434552579	9843	Economy	27900.00
0005434552821	9843	Economy	27900.00
0005434728955	9843	Economy	27900.00
0005434728981	9843	Economy	27900.00
0005434552708	9843	Economy	27900.00
0005434552748	9843	Economy	27900.00
0005434552686	9843	Economy	27900.00
0005434552796	9843	Economy	27900.00
0005434728977	9843	Economy	27900.00
0005434731289	9843	Economy	27900.00
0005434728733	9843	Economy	27900.00
0005434552804	9843	Economy	27900.00
0005434728975	9843	Economy	27900.00
0005435142931	9843	Economy	27900.00
0005434728939	9843	Economy	27900.00
0005434552711	9843	Economy	27900.00
0005434552728	9843	Economy	27900.00
0005434728994	9843	Economy	27900.00
0005435142903	9843	Economy	27900.00
0005435142946	9843	Economy	30700.00
0005434728821	9843	Economy	27900.00
0005434552733	9843	Economy	27900.00
0005434729011	9843	Economy	27900.00
0005434728979	9843	Economy	27900.00
0005434728310	9843	Economy	27900.00
0005434728562	9843	Economy	27900.00
0005434735820	9843	Economy	27900.00
0005434728659	9843	Economy	27900.00
0005434728452	9843	Economy	27900.00
0005434735824	9843	Economy	27900.00
0005434728714	9843	Economy	27900.00
0005434728954	9843	Economy	27900.00
0005434728750	9843	Economy	27900.00
0005434728953	9843	Economy	27900.00
0005434728828	9843	Economy	27900.00
0005434728959	9843	Economy	27900.00
0005434728676	9843	Economy	27900.00
0005434302581	9843	Economy	27900.00
0005434552703	9843	Economy	27900.00
0005434552624	9843	Economy	27900.00
0005434302578	9843	Economy	27900.00
0005435142927	9843	Economy	27900.00
0005434552712	9843	Economy	27900.00
0005434728935	9843	Economy	27900.00
0005434728985	9843	Economy	27900.00
0005434302564	9843	Economy	27900.00
0005435142956	9843	Economy	27900.00
0005434552827	9843	Economy	27900.00
0005434552588	9843	Economy	27900.00
0005434552706	9843	Economy	27900.00
0005434728421	9843	Economy	27900.00
0005434728761	9843	Economy	27900.00
0005434728829	9843	Economy	27900.00
0005434728922	9843	Economy	27900.00
0005434552587	9843	Economy	30700.00
0005434552820	9843	Economy	30700.00
0005434552732	9843	Economy	30700.00
0005434735819	9843	Economy	27900.00
0005434728763	9843	Economy	27900.00
0005434552802	9843	Economy	27900.00
0005434728927	9843	Economy	27900.00
0005435142937	9843	Economy	27900.00
0005435142947	9843	Economy	27900.00
0005434728980	9843	Economy	27900.00
0005434728973	9843	Economy	27900.00
0005434728523	9843	Economy	27900.00
0005434552847	9843	Economy	27900.00
0005434552707	9843	Economy	27900.00
0005434728524	9843	Economy	27900.00
0005434728054	9843	Economy	27900.00
0005434728792	9843	Economy	27900.00
0005434728904	9843	Economy	27900.00
0005434728754	9843	Economy	27900.00
0005435142904	9843	Economy	27900.00
0005434728675	9843	Economy	27900.00
0005434728563	9843	Economy	27900.00
0005434735822	9843	Economy	27900.00
0005434552581	9843	Economy	27900.00
0005434728535	9843	Economy	27900.00
0005434728820	9843	Economy	27900.00
0005434552826	9843	Economy	27900.00
0005434552704	9843	Economy	27900.00
0005434728961	9843	Economy	27900.00
0005434552578	9843	Economy	27900.00
0005434728839	9843	Economy	27900.00
0005434728852	9843	Economy	27900.00
0005434728603	9843	Economy	27900.00
0005434728790	9843	Economy	27900.00
0005434728453	9843	Economy	27900.00
0005434731280	9843	Economy	27900.00
0005434728905	9843	Economy	27900.00
0005434728900	9843	Economy	27900.00
0005434552777	9843	Economy	27900.00
0005434729000	9843	Economy	27900.00
0005434728422	9843	Economy	27900.00
0005434728972	9843	Economy	27900.00
0005434552623	9843	Economy	27900.00
0005434728943	9843	Economy	27900.00
0005435215114	7724	Business	42100.00
0005435215496	7724	Business	42100.00
0005435283535	7724	Comfort	23900.00
0005435215160	7724	Comfort	23900.00
0005435215361	7724	Comfort	23900.00
0005435215515	7724	Comfort	23900.00
0005433656756	7724	Comfort	23900.00
0005435283527	7724	Comfort	23900.00
0005435283517	7724	Comfort	23900.00
0005435283505	7724	Comfort	23900.00
0005435215432	7724	Comfort	23900.00
0005435215434	7724	Economy	14000.00
0005435215397	7724	Economy	14000.00
0005435215417	7724	Economy	14000.00
0005435215328	7724	Economy	14000.00
0005435215461	7724	Economy	14000.00
0005435215514	7724	Economy	14000.00
0005435215411	7724	Economy	14000.00
0005435631039	7724	Economy	14000.00
0005435215407	7724	Economy	15400.00
0005435283506	7724	Economy	14000.00
0005435215161	7724	Economy	14000.00
0005435215452	7724	Economy	14000.00
0005435215503	7724	Economy	14000.00
0005435215410	7724	Economy	14000.00
0005435215473	7724	Economy	14000.00
0005435215462	7724	Economy	14000.00
0005435283526	7724	Economy	14000.00
0005435215504	7724	Economy	14000.00
0005435215420	7724	Economy	14000.00
0005435215466	7724	Economy	14000.00
0005435215456	7724	Economy	14000.00
0005435631047	7724	Economy	14000.00
0005435283495	7724	Economy	14000.00
0005435215399	7724	Economy	14000.00
0005435725738	7724	Economy	14000.00
0005435215502	7724	Economy	15400.00
0005435283538	7724	Economy	14000.00
0005435725737	7724	Economy	14000.00
0005435283474	7724	Economy	14000.00
0005435215360	7724	Economy	14000.00
0005435215453	7724	Economy	14000.00
0005435283468	7724	Economy	14000.00
0005435215474	7724	Economy	14000.00
0005435283539	7724	Economy	14000.00
0005435283487	7724	Economy	14000.00
0005435215398	7724	Economy	14000.00
0005435215471	7724	Economy	14000.00
0005435215334	7724	Economy	14000.00
0005435283516	7724	Economy	14000.00
0005435426691	5361	Business	43100.00
0005435302337	5361	Business	43100.00
0005434245837	5361	Business	43100.00
0005435319821	5361	Business	43100.00
0005435426645	5361	Comfort	24400.00
0005435302321	5361	Comfort	24400.00
0005435426775	5361	Comfort	24400.00
0005435426823	5361	Comfort	24400.00
0005435426699	5361	Comfort	24400.00
0005432363516	5361	Comfort	24400.00
0005435319820	5361	Comfort	24400.00
0005435426756	5361	Economy	14400.00
0005435380417	5361	Economy	14400.00
0005435426476	5361	Economy	14400.00
0005435380439	5361	Economy	14400.00
0005435426816	5361	Economy	14400.00
0005435426824	5361	Economy	14400.00
0005432841070	5361	Economy	14400.00
0005435426730	5361	Economy	14400.00
0005435426786	5361	Economy	14400.00
0005435305068	5361	Economy	14400.00
0005432363504	5361	Economy	14400.00
0005435426613	5361	Economy	14400.00
0005435426784	5361	Economy	14400.00
0005432363515	5361	Economy	14400.00
0005435319794	5361	Economy	14400.00
0005435950053	5361	Economy	14400.00
0005435426774	5361	Economy	14400.00
0005435305075	5361	Economy	14400.00
0005435319819	5361	Economy	14400.00
0005434656612	5361	Economy	14400.00
0005435426819	5361	Economy	14400.00
0005434245702	5361	Economy	14400.00
0005435768112	5361	Economy	14400.00
0005434245771	5361	Economy	14400.00
0005434245723	5361	Economy	14400.00
0005433719219	5361	Economy	14400.00
0005435426814	5361	Economy	14400.00
0005435426773	5361	Economy	14400.00
0005435380438	5361	Economy	14400.00
0005434245706	5361	Economy	14400.00
0005435426728	5361	Economy	14400.00
0005435426714	5361	Economy	14400.00
0005435380429	5361	Economy	14400.00
0005434656603	5361	Economy	14400.00
0005435426746	5361	Economy	14400.00
0005434245814	5361	Economy	14400.00
0005435426432	5361	Economy	14400.00
0005435426776	5361	Economy	15800.00
0005434245813	5361	Economy	15800.00
0005434245767	5361	Economy	14400.00
0005434245701	5361	Economy	14400.00
0005435426615	5361	Economy	14400.00
0005435319816	5361	Economy	14400.00
0005435319795	5361	Economy	14400.00
0005434245772	5361	Economy	14400.00
0005435319814	5361	Economy	14400.00
0005435319826	5361	Economy	14400.00
0005435426646	5361	Economy	14400.00
0005435426688	5361	Economy	14400.00
0005435426686	5361	Economy	14400.00
0005435426698	5361	Economy	14400.00
0005435305076	5361	Economy	14400.00
0005435305070	5361	Economy	14400.00
0005435768111	5361	Economy	14400.00
0005433719236	5361	Economy	14400.00
0005435426614	5361	Economy	14400.00
0005433719223	5361	Economy	14400.00
0005435380437	5361	Economy	14400.00
0005434245766	5361	Economy	14400.00
0005435319815	5361	Economy	14400.00
0005434245797	5361	Economy	14400.00
0005435097483	10880	Business	43100.00
0005434345182	10880	Business	43100.00
0005435616776	10880	Business	43100.00
0005435616960	10880	Business	43100.00
0005434345115	10880	Business	43100.00
0005435490320	10880	Comfort	24400.00
0005434345154	10880	Comfort	24400.00
0005434345207	10880	Comfort	24400.00
0005435616931	10880	Comfort	24400.00
0005435616968	10880	Comfort	24400.00
0005435490324	10880	Comfort	24400.00
0005435616883	10880	Comfort	24400.00
0005435616614	10880	Comfort	24400.00
0005435616902	10880	Comfort	24400.00
0005434345038	10880	Comfort	24400.00
0005435097470	10880	Comfort	24400.00
0005435616775	10880	Comfort	24400.00
0005435617210	10880	Comfort	24400.00
0005434345220	10880	Comfort	24400.00
0005434573731	10880	Comfort	24400.00
0005435616455	10880	Comfort	24400.00
0005435617020	10880	Comfort	24400.00
0005435616967	10880	Comfort	24400.00
0005435616799	10880	Comfort	24400.00
0005434345145	10880	Economy	14400.00
0005435616638	10880	Comfort	24400.00
0005435616756	10880	Economy	14400.00
0005435616683	10880	Economy	14400.00
0005435616863	10880	Economy	14400.00
0005435097484	10880	Economy	14400.00
0005435616702	10880	Economy	14400.00
0005434345211	10880	Economy	14400.00
0005435616527	10880	Economy	14400.00
0005434345157	10880	Economy	14400.00
0005434345219	10880	Economy	14400.00
0005434345256	10880	Economy	14400.00
0005435617015	10880	Economy	14400.00
0005435426857	10880	Economy	14400.00
0005435616932	10880	Economy	14400.00
0005435617004	10880	Economy	14400.00
0005435616622	10880	Economy	14400.00
0005435490325	10880	Economy	14400.00
0005435617001	10880	Economy	14400.00
0005435616952	10880	Economy	14400.00
0005434345208	10880	Economy	14400.00
0005435616623	10880	Economy	15800.00
0005434345051	10880	Economy	14400.00
0005435616384	10880	Economy	14400.00
0005435616650	10880	Economy	14400.00
0005435616951	10880	Economy	14400.00
0005435616884	10880	Economy	14400.00
0005435616721	10880	Economy	14400.00
0005435616901	10880	Economy	14400.00
0005435616786	10880	Economy	14400.00
0005435617006	10880	Economy	14400.00
0005435551773	10880	Economy	14400.00
0005435616386	10880	Economy	14400.00
0005434345138	10880	Economy	14400.00
0005435616800	10880	Economy	14400.00
0005435616783	10880	Economy	14400.00
0005434345130	10880	Economy	14400.00
0005435616830	10880	Economy	14400.00
0005435616651	10880	Economy	14400.00
0005434573681	10880	Economy	14400.00
0005434345260	10880	Economy	14400.00
0005435097463	10880	Economy	14400.00
0005435616684	10880	Economy	14400.00
0005434345120	10880	Economy	14400.00
0005435097447	10880	Economy	14400.00
0005435616831	10880	Economy	14400.00
0005435616621	10880	Economy	14400.00
0005434345146	10880	Economy	14400.00
0005435616454	10880	Economy	14400.00
0005435555429	10880	Economy	14400.00
0005435097469	10880	Economy	14400.00
0005435617211	10880	Economy	14400.00
0005434345116	10880	Economy	14400.00
0005435490329	10880	Economy	14400.00
0005435617025	10880	Economy	14400.00
0005434345139	10880	Economy	14400.00
0005434345168	10880	Economy	14400.00
0005435616443	10880	Economy	14400.00
0005435616787	10880	Economy	14400.00
0005434573729	10880	Economy	14400.00
0005434345261	10880	Economy	14400.00
0005434345218	10880	Economy	14400.00
0005435616742	10880	Economy	14400.00
0005435491501	10880	Economy	14400.00
0005435616597	10880	Economy	14400.00
0005435616699	10880	Economy	14400.00
0005435616757	10880	Economy	15800.00
0005434345183	10880	Economy	14400.00
0005434345255	10880	Economy	14400.00
0005435616864	10880	Economy	14400.00
0005434345217	10880	Economy	14400.00
0005434573714	10880	Economy	14400.00
0005434345181	10880	Economy	14400.00
0005435616387	10880	Economy	14400.00
0005435617024	10880	Economy	14400.00
0005435616910	10880	Economy	14400.00
0005434573703	10880	Economy	14400.00
0005434345196	10880	Economy	14400.00
0005435616385	10880	Economy	14400.00
0005435616526	10880	Economy	14400.00
0005435616835	10880	Economy	14400.00
0005434573734	10880	Economy	14400.00
0005435616828	10880	Economy	14400.00
0005435617021	10880	Economy	14400.00
0005435097462	10880	Economy	14400.00
0005435616239	10880	Economy	14400.00
0005435616798	10880	Economy	14400.00
0005435616723	10880	Economy	14400.00
0005435617243	10880	Economy	14400.00
0005435616824	10880	Economy	14400.00
0005435616880	10880	Economy	14400.00
0005434573679	10880	Economy	14400.00
0005434573680	10880	Economy	14400.00
0005435616834	10880	Economy	14400.00
0005435555427	10880	Economy	14400.00
0005435616668	10880	Economy	14400.00
0005434573707	10880	Economy	14400.00
0005434345243	10880	Economy	14400.00
0005435616941	10880	Economy	14400.00
0005434345244	10880	Economy	14400.00
0005435617193	10880	Economy	14400.00
0005435097485	10880	Economy	14400.00
0005435616995	10880	Economy	14400.00
0005435616865	10880	Economy	14400.00
0005435616361	10880	Economy	14400.00
0005435555428	10880	Economy	14400.00
0005435616238	10880	Economy	14400.00
0005434345231	10880	Economy	14400.00
0005434573758	10880	Economy	14400.00
0005435617005	10880	Economy	14400.00
0005435616869	10880	Economy	14400.00
0005435616845	10880	Economy	14400.00
0005435616903	10880	Economy	14400.00
0005435616935	10880	Economy	14400.00
0005435617242	10880	Economy	14400.00
0005435854092	3369	Business	18800.00
0005432461209	3369	Business	18800.00
0005435142996	3369	Business	18800.00
0005432461343	3369	Business	18800.00
0005435858704	3369	Business	18800.00
0005432461151	3369	Business	18800.00
0005435858705	3369	Business	18800.00
0005435860686	3369	Business	18800.00
0005434326057	3369	Business	18800.00
0005435860704	3369	Business	18800.00
0005435860714	3369	Business	18800.00
0005435854094	3369	Business	18800.00
0005432461362	3369	Economy	6900.00
0005435854093	3369	Economy	6900.00
0005432461241	3369	Economy	6300.00
0005432461314	3369	Economy	6300.00
0005432461242	3369	Economy	6300.00
0005432461415	3369	Economy	6300.00
0005434311285	3369	Economy	6300.00
0005435860703	3369	Economy	6300.00
0005432461304	3369	Economy	6300.00
0005432461360	3369	Economy	6300.00
0005432461131	3369	Economy	6300.00
0005432460932	3369	Economy	6300.00
0005432461322	3369	Economy	6300.00
0005435860649	3369	Economy	6300.00
0005435860647	3369	Economy	6300.00
0005434311284	3369	Economy	6300.00
0005432461321	3369	Economy	6300.00
0005432461237	3369	Economy	6300.00
0005432461207	3369	Economy	6300.00
0005435142997	3369	Economy	6300.00
0005432461320	3369	Economy	6300.00
0005432461152	3369	Economy	6300.00
0005432461268	3369	Economy	6300.00
0005434266056	3369	Economy	6300.00
0005432461396	3369	Economy	6300.00
0005435933571	3369	Economy	6300.00
0005432461303	3369	Economy	6300.00
0005435860651	3369	Economy	6300.00
0005432461291	3369	Economy	6300.00
0005432461339	3369	Economy	6300.00
0005435860665	3369	Economy	6900.00
0005435860705	3369	Economy	6300.00
0005432461208	3369	Economy	6300.00
0005432461260	3369	Economy	6300.00
0005435860687	3369	Economy	6300.00
0005432461329	3369	Economy	6300.00
0005432461414	3369	Economy	6300.00
0005432461125	3369	Economy	6300.00
0005435860667	3369	Economy	6300.00
0005432461238	3369	Economy	6300.00
0005432461279	3369	Economy	6300.00
0005435860648	3369	Economy	6300.00
0005435933580	3369	Economy	6300.00
0005434266057	3369	Economy	6300.00
0005435856349	3369	Economy	6300.00
0005435858721	3369	Economy	6300.00
0005432461315	3369	Economy	6300.00
0005435860730	3369	Economy	6300.00
0005432461301	3369	Economy	6300.00
0005432461206	3369	Economy	6300.00
0005432461319	3369	Economy	6300.00
0005432461335	3369	Economy	6300.00
0005435860666	3369	Economy	6300.00
0005435860706	3369	Economy	6300.00
0005435933570	3369	Economy	6300.00
0005432461388	3369	Economy	6300.00
0005435886703	3370	Business	18800.00
0005435886757	3370	Business	18800.00
0005435886485	3370	Business	18800.00
0005435886419	3370	Business	18800.00
0005435886618	3370	Business	18800.00
0005435886821	3370	Business	18800.00
0005435886779	3370	Business	18800.00
0005435886596	3370	Business	18800.00
0005435886758	3370	Business	18800.00
0005435886484	3370	Business	18800.00
0005435886770	3370	Business	18800.00
0005435886827	3370	Economy	6300.00
0005435886655	3370	Economy	6300.00
0005435886595	3370	Economy	6300.00
0005435886559	3370	Economy	6300.00
0005435886635	3370	Economy	6300.00
0005435886522	3370	Economy	6300.00
0005435886697	3370	Economy	6300.00
0005435886684	3370	Economy	6300.00
0005435886742	3370	Economy	6300.00
0005435886673	3370	Economy	6300.00
0005435886617	3370	Economy	6300.00
0005435886765	3370	Economy	6300.00
0005435886857	3370	Economy	6300.00
0005435886685	3370	Economy	6300.00
0005435886700	3370	Economy	6300.00
0005435886668	3370	Economy	6300.00
0005435886425	3370	Economy	6300.00
0005435886749	3370	Economy	6300.00
0005435886454	3370	Economy	6300.00
0005435886614	3370	Economy	6900.00
0005435886769	3370	Economy	6900.00
0005435886653	3370	Economy	6300.00
0005435886636	3370	Economy	6300.00
0005435886719	3370	Economy	6300.00
0005435886658	3370	Economy	6300.00
0005435886798	3370	Economy	6300.00
0005435886737	3370	Economy	6300.00
0005435886766	3370	Economy	6300.00
0005435886667	3370	Economy	6300.00
0005435886523	3370	Economy	6300.00
0005435886669	3370	Economy	6300.00
0005435886743	3370	Economy	6300.00
0005435886720	3370	Economy	6300.00
0005433507588	8333	Business	18800.00
0005433507717	8333	Business	18800.00
0005433507656	8333	Business	18800.00
0005433507718	8333	Business	18800.00
0005435886875	8333	Economy	6900.00
0005433507657	8333	Economy	6300.00
0005433507663	8333	Economy	6300.00
0005435886874	8333	Economy	6300.00
0005433507678	8333	Economy	6300.00
0005433507632	8333	Economy	6300.00
0005433507700	8333	Economy	6300.00
0005434143789	8329	Business	18800.00
0005433806331	8329	Business	18800.00
0005433806389	8329	Business	18800.00
0005433806363	8329	Business	18800.00
0005433806248	8329	Business	18800.00
0005433806349	8329	Business	18800.00
0005433806393	8329	Business	18800.00
0005433634770	8329	Economy	6900.00
0005433806362	8329	Economy	6900.00
0005433806300	8329	Economy	6300.00
0005433806267	8329	Economy	6300.00
0005433634751	8329	Economy	6300.00
0005433806340	8329	Economy	6300.00
0005434143819	8329	Economy	6300.00
0005433634713	8329	Economy	6300.00
0005433806250	8329	Economy	6300.00
0005433634782	8329	Economy	6300.00
0005433806377	8329	Economy	6300.00
0005433634769	8329	Economy	6300.00
0005433806315	8329	Economy	6300.00
0005433806319	8329	Economy	6300.00
0005433806295	8329	Economy	6300.00
0005433806358	8329	Economy	6300.00
0005434143821	8329	Economy	6300.00
0005434143816	8329	Economy	6300.00
0005433806269	8329	Economy	6300.00
0005433634714	8329	Economy	6300.00
0005433634656	8329	Economy	6300.00
0005434143833	8329	Economy	6900.00
0005433806388	8329	Economy	6300.00
0005433806337	8329	Economy	6900.00
0005433634814	8329	Economy	6300.00
0005433634808	8329	Economy	6300.00
0005433806321	8329	Economy	6300.00
0005433806359	8329	Economy	6300.00
0005433634783	8329	Economy	6300.00
0005433806306	8329	Economy	6300.00
0005433806368	8329	Economy	6300.00
0005433806307	8329	Economy	6300.00
0005433806322	8329	Economy	6300.00
0005434143767	8329	Economy	6300.00
0005433806405	8329	Economy	6300.00
0005433634760	8329	Economy	6300.00
0005433806249	8329	Economy	6300.00
0005433806404	8329	Economy	6300.00
0005434143844	8329	Economy	6300.00
0005433634661	8329	Economy	6300.00
0005433634720	8329	Economy	6300.00
0005433806268	8329	Economy	6300.00
0005433806339	8329	Economy	6300.00
0005433634759	8329	Economy	6300.00
0005433806332	8329	Economy	6300.00
0005434143804	8329	Economy	6300.00
0005434143776	8329	Economy	6300.00
0005433806375	8329	Economy	6300.00
0005433806350	8329	Economy	6300.00
0005434150183	8327	Business	18800.00
0005434265970	8327	Business	18800.00
0005434265961	8327	Business	18800.00
0005434150171	8327	Business	18800.00
0005434265990	8327	Business	18800.00
0005434273134	8327	Business	18800.00
0005434150149	8327	Business	18800.00
0005434265991	8327	Economy	6300.00
0005434265934	8327	Economy	6300.00
0005434265935	8327	Economy	6300.00
0005434273133	8327	Economy	6300.00
0005434150159	8327	Economy	6300.00
0005434150205	8327	Economy	6300.00
0005434266024	8327	Economy	6300.00
0005434150148	8327	Economy	6300.00
0005434265915	8327	Economy	6300.00
0005434265916	8327	Economy	6300.00
0005434265945	8327	Economy	6300.00
0005434150218	8327	Economy	6300.00
0005434265962	8327	Economy	6900.00
0005434273132	8327	Economy	6300.00
0005434265999	8327	Economy	6300.00
0005434266046	8327	Economy	6300.00
0005434150184	8327	Economy	6300.00
0005434150219	8327	Economy	6300.00
0005434265992	8327	Economy	6300.00
0005434265933	8327	Economy	6300.00
0005434273131	8327	Economy	6300.00
0005434266023	8327	Economy	6300.00
0005434150204	8327	Economy	6300.00
0005434265936	8327	Economy	6300.00
0005434265988	8327	Economy	6300.00
0005434265956	8327	Economy	6300.00
0005434266008	8327	Economy	6300.00
0005434150147	8327	Economy	6300.00
0005434265987	8327	Economy	6300.00
0005434265944	8327	Economy	6300.00
0005433722402	30097	Business	9900.00
0005432384167	30097	Business	9900.00
0005433722415	30097	Business	9900.00
0005432728279	30097	Business	9900.00
0005432384151	30097	Business	9900.00
0005433722470	30097	Business	9900.00
0005433194934	30097	Business	9900.00
0005433722439	30097	Business	9900.00
0005432384262	30097	Business	9900.00
0005432384259	30097	Economy	3300.00
0005433722373	30097	Economy	3300.00
0005433453810	30097	Economy	3300.00
0005432384237	30097	Economy	3300.00
0005432384236	30097	Economy	3300.00
0005433194949	30097	Economy	3300.00
0005432384282	30097	Economy	3300.00
0005433194980	30097	Economy	3300.00
0005433722433	30097	Economy	3300.00
0005432384297	30097	Economy	3600.00
0005433722435	30097	Economy	3600.00
0005433722462	30097	Economy	3600.00
0005432384250	30097	Economy	3600.00
0005433453820	30097	Economy	3600.00
0005432384238	30097	Economy	3300.00
0005433451672	30097	Economy	3300.00
0005433722389	30097	Economy	3300.00
0005432383957	30097	Economy	3300.00
0005432384185	30097	Economy	3300.00
0005433451676	30097	Economy	3300.00
0005433194960	30097	Economy	3300.00
0005433451674	30097	Economy	3300.00
0005432384210	30097	Economy	3300.00
0005433194933	30097	Economy	3300.00
0005433722372	30097	Economy	3300.00
0005432384125	30097	Economy	3300.00
0005432384184	30097	Economy	3300.00
0005433194993	30097	Economy	3300.00
0005433722408	30097	Economy	3300.00
0005432384107	30097	Economy	3300.00
0005433722405	30097	Economy	3300.00
0005433194929	30097	Economy	3300.00
0005433194979	30097	Economy	3300.00
0005432384298	30097	Economy	3300.00
0005432728266	30097	Economy	3300.00
0005433722403	30097	Economy	3300.00
0005432384235	30097	Economy	3300.00
0005433722434	30097	Economy	3300.00
0005432384179	30097	Economy	3300.00
0005432384263	30097	Economy	3300.00
0005432728299	30097	Economy	3300.00
0005433722471	30097	Economy	3300.00
0005432384287	30097	Economy	3300.00
0005432384283	30097	Economy	3300.00
0005433722443	30097	Economy	3300.00
0005432728298	30097	Economy	3300.00
0005433722390	30097	Economy	3300.00
0005433722484	30097	Economy	3300.00
0005432384246	30097	Economy	3300.00
0005433194970	30097	Economy	3300.00
0005433722440	30097	Economy	3300.00
0005433722406	30097	Economy	3300.00
0005433722428	30097	Economy	3300.00
0005433194971	30097	Economy	3300.00
0005432384291	30097	Economy	3300.00
0005432384227	30097	Economy	3300.00
0005433722429	30097	Economy	3300.00
0005432384187	30097	Economy	3300.00
0005432384106	30097	Economy	3300.00
0005432384165	30097	Economy	3300.00
0005432384193	30097	Economy	3300.00
0005433722412	30097	Economy	3300.00
0005432728267	30097	Economy	3300.00
0005432384201	30097	Economy	3300.00
0005433722401	30097	Economy	3300.00
0005432384292	30097	Economy	3300.00
0005432384239	30097	Economy	3300.00
0005433194930	30097	Economy	3300.00
0005432384164	30097	Economy	3300.00
0005432384128	30097	Economy	3300.00
0005432728300	30097	Economy	3300.00
0005432384120	30097	Economy	3300.00
0005433722463	30097	Economy	3300.00
0005432728280	30097	Economy	3300.00
0005433451675	30097	Economy	3300.00
0005432384220	30097	Economy	3300.00
0005432925174	1732	Economy	19100.00
0005432925165	1732	Economy	19100.00
0005432925173	1732	Economy	19100.00
0005433517151	21999	Business	57200.00
0005435518438	21999	Business	57200.00
0005435541628	21999	Business	57200.00
0005435518384	21999	Business	57200.00
0005435518433	21999	Business	57200.00
0005435541519	21999	Business	57200.00
0005435518401	21999	Economy	19100.00
0005435518421	21999	Economy	19100.00
0005435518415	21999	Economy	19100.00
0005435541633	21999	Economy	19100.00
0005435541582	21999	Economy	21000.00
0005435518388	21999	Economy	21000.00
0005433517150	21999	Economy	19100.00
0005435541569	21999	Economy	19100.00
0005435518385	21999	Economy	19100.00
0005435518338	21999	Economy	19100.00
0005435518377	21999	Economy	19100.00
0005435541575	21999	Economy	19100.00
0005433517124	21999	Economy	19100.00
0005435541518	21999	Economy	19100.00
0005433517123	21999	Economy	19100.00
0005435541597	21999	Economy	19100.00
0005435518414	21999	Economy	19100.00
0005435541608	21999	Economy	19100.00
0005435541629	21999	Economy	19100.00
0005435541632	21999	Economy	19100.00
0005435518360	21999	Economy	19100.00
0005435518420	21999	Economy	19100.00
0005433517122	21999	Economy	19100.00
0005435518319	21999	Economy	19100.00
0005435518432	21999	Economy	19100.00
0005435253140	7374	Economy	6200.00
0005435253177	7374	Economy	6800.00
0005435491500	7374	Economy	6800.00
0005435253214	7374	Economy	6200.00
0005435253165	7374	Economy	6200.00
0005435253210	7374	Economy	6200.00
0005435491502	7374	Economy	6200.00
0005434665021	7374	Economy	6200.00
0005435253213	7374	Economy	6200.00
0005434665016	7374	Economy	6200.00
0005435491499	7374	Economy	6200.00
0005434665010	7374	Economy	6200.00
0005435253139	7374	Economy	6200.00
0005435491504	7374	Economy	6200.00
0005435253166	7374	Economy	6200.00
0005434459399	28951	Business	18500.00
0005432839885	28951	Business	18500.00
0005434459403	28951	Economy	6200.00
0005432839933	28951	Economy	6200.00
0005432839884	28951	Economy	6800.00
0005432839911	28951	Economy	6800.00
0005432839922	28951	Economy	6200.00
0005432839870	28951	Economy	6200.00
0005434459338	28951	Economy	6200.00
0005434459374	28951	Economy	6200.00
0005432841072	28951	Economy	6200.00
0005432839897	28951	Economy	6200.00
0005432839840	28951	Economy	6200.00
0005432839738	28951	Economy	6200.00
0005432839871	28951	Economy	6200.00
0005434459391	28951	Economy	6200.00
0005432839896	28951	Economy	6200.00
0005432839934	28951	Economy	6200.00
0005432839932	28951	Economy	6200.00
0005432841071	28951	Economy	6200.00
0005432839841	28951	Economy	6200.00
0005432839904	28951	Economy	6200.00
0005432839921	28951	Economy	6200.00
0005433435523	8805	Economy	48400.00
0005433435527	8805	Economy	48400.00
0005433435528	8805	Economy	53300.00
0005433435516	8805	Economy	48400.00
0005433435510	8805	Economy	48400.00
0005433435524	8805	Economy	48400.00
0005435990815	15751	Economy	48400.00
0005435990822	15751	Economy	48400.00
0005435990823	15751	Economy	48400.00
0005435990816	15751	Economy	48400.00
0005435990809	15751	Economy	48400.00
0005432909428	2095	Economy	12100.00
0005432909421	2095	Economy	12100.00
0005432909427	2095	Economy	12100.00
0005432909411	2095	Economy	12100.00
0005432909420	2095	Economy	12100.00
0005432909424	2095	Economy	12100.00
0005432909423	2095	Economy	12100.00
0005435177847	6362	Business	36600.00
0005435490329	6362	Business	36600.00
0005434150040	6362	Business	36600.00
0005435490320	6362	Business	36600.00
0005434150039	6362	Economy	12200.00
0005435177858	6362	Economy	12200.00
0005434150041	6362	Economy	12200.00
0005435177801	6362	Economy	12200.00
0005435490325	6362	Economy	13400.00
0005434150069	6362	Economy	12200.00
0005434150068	6362	Economy	12200.00
0005434150075	6362	Economy	12200.00
0005435177800	6362	Economy	12200.00
0005435177809	6362	Economy	12200.00
0005434150052	6362	Economy	12200.00
0005434150051	6362	Economy	12200.00
0005435177810	6362	Economy	12200.00
0005435177848	6362	Economy	12200.00
0005435490324	6362	Economy	12200.00
0005432361570	21034	Business	36600.00
0005432336371	21034	Business	36600.00
0005432336331	21034	Business	36600.00
0005432361688	21034	Business	36600.00
0005432361679	21034	Business	36600.00
0005432361568	21034	Economy	12200.00
0005432361731	21034	Economy	12200.00
0005432361702	21034	Economy	12200.00
0005432361331	21034	Economy	12200.00
0005432361673	21034	Economy	12200.00
0005432361687	21034	Economy	12200.00
0005432336367	21034	Economy	12200.00
0005432336365	21034	Economy	12200.00
0005432336368	21034	Economy	12200.00
0005432336328	21034	Economy	12200.00
0005432361564	21034	Economy	13400.00
0005432361684	21034	Economy	13400.00
0005432361711	21034	Economy	12200.00
0005432361717	21034	Economy	12200.00
0005432361644	21034	Economy	12200.00
0005432336372	21034	Economy	12200.00
0005432361332	21034	Economy	12200.00
0005432361716	21034	Economy	12200.00
0005432361648	21034	Economy	12200.00
0005432361643	21034	Economy	12200.00
0005432336366	21034	Economy	12200.00
0005432361760	21034	Economy	12200.00
0005432361569	21034	Economy	12200.00
0005432361726	21034	Economy	12200.00
0005432361712	21034	Economy	12200.00
0005432361531	21034	Economy	12200.00
0005434459411	17700	Economy	3400.00
0005434459388	17700	Economy	3400.00
0005434459408	17700	Economy	3100.00
0005434459389	17700	Economy	3100.00
0005434461704	17700	Economy	3100.00
0005434459336	17700	Economy	3100.00
0005434459335	17700	Economy	3100.00
0005434448417	17700	Economy	3100.00
0005434463993	17700	Economy	3100.00
0005434459395	17700	Economy	3100.00
0005434459396	17700	Economy	3100.00
0005434459398	17700	Economy	3100.00
0005434448418	17700	Economy	3100.00
0005434459402	17700	Economy	3100.00
0005434463992	17700	Economy	3100.00
0005434448416	17700	Economy	3100.00
0005434459413	17700	Economy	3100.00
0005434459393	17700	Economy	3100.00
0005434186283	29099	Economy	3100.00
0005434186279	29099	Economy	3100.00
0005434186284	29099	Economy	3100.00
0005434186277	29099	Economy	3100.00
0005434186278	29099	Economy	3100.00
0005434186282	29099	Economy	3100.00
0005434186276	29099	Economy	3100.00
0005432605356	31685	Economy	7300.00
0005432605463	31685	Economy	7300.00
0005432605348	31685	Economy	6600.00
0005432605199	31685	Economy	6600.00
0005432605456	31685	Economy	6600.00
0005432605444	31685	Economy	6600.00
0005432605300	31685	Economy	6600.00
0005432605299	31685	Economy	6600.00
0005432605281	31685	Economy	6600.00
0005432605465	31685	Economy	6600.00
0005432605380	31685	Economy	6600.00
0005432605445	31685	Economy	6600.00
0005432605504	31685	Economy	6600.00
0005432605457	31685	Economy	6600.00
0005432605450	31685	Economy	6600.00
0005432605407	31685	Economy	6600.00
0005432605350	31685	Economy	6600.00
0005432605409	31685	Economy	6600.00
0005432605381	31685	Economy	6600.00
0005432605464	31685	Economy	6600.00
0005432605449	31685	Economy	6600.00
0005432605382	31685	Economy	6600.00
0005432605322	31685	Economy	6600.00
0005434606932	18892	Economy	6600.00
0005434606924	18892	Economy	6600.00
0005434603025	18892	Economy	6600.00
0005434603024	18892	Economy	6600.00
0005434606923	18892	Economy	6600.00
0005435904915	22381	Economy	6600.00
0005435904721	22381	Economy	6600.00
0005432891578	419	Business	44500.00
0005433293423	419	Business	44500.00
0005432891573	419	Business	44500.00
0005432891568	419	Business	44500.00
0005434151814	419	Economy	14800.00
0005433293427	419	Economy	14800.00
0005432891569	419	Economy	14800.00
0005432891513	419	Economy	16300.00
0005434151813	419	Economy	14800.00
0005433293410	419	Economy	14800.00
0005432891574	419	Economy	14800.00
0005434151815	419	Economy	14800.00
0005433293388	419	Economy	14800.00
0005433293428	419	Economy	14800.00
0005434151812	419	Economy	14800.00
0005433293387	419	Economy	14800.00
0005432891543	419	Economy	14800.00
0005432891512	419	Economy	14800.00
0005433293424	419	Economy	14800.00
0005435154670	12052	Business	44500.00
0005432748589	12052	Business	44500.00
0005432748681	12052	Economy	14800.00
0005435154700	12052	Economy	14800.00
0005435154690	12052	Economy	16300.00
0005432748520	12052	Economy	16300.00
0005432753384	12052	Economy	16300.00
0005432748575	12052	Economy	16300.00
0005432748675	12052	Economy	14800.00
0005432748504	12052	Economy	14800.00
0005432748634	12052	Economy	14800.00
0005432756930	12052	Economy	14800.00
0005432748588	12052	Economy	14800.00
0005432756931	12052	Economy	14800.00
0005432753385	12052	Economy	14800.00
0005432748502	12052	Economy	14800.00
0005432748423	12052	Economy	14800.00
0005435154675	12052	Economy	14800.00
0005432748503	12052	Economy	14800.00
0005432753396	12052	Economy	14800.00
0005432753397	12052	Economy	14800.00
0005435154676	12052	Economy	14800.00
0005432748519	12052	Economy	14800.00
0005432748605	12052	Economy	14800.00
0005432748635	12052	Economy	14800.00
0005432749846	12052	Economy	14800.00
0005432748604	12052	Economy	14800.00
0005432756929	12052	Economy	14800.00
0005432928137	18972	Economy	25700.00
0005433527364	32496	Economy	25700.00
0005433527369	32496	Economy	25700.00
0005433527370	32496	Economy	25700.00
0005433527368	32496	Economy	25700.00
0005433525356	32496	Economy	25700.00
0005433527371	32496	Economy	25700.00
0005433525346	32496	Economy	25700.00
0005435375137	5243	Business	84000.00
0005435374959	5243	Business	84000.00
0005435374906	5243	Business	84000.00
0005435375095	5243	Business	84000.00
0005435375020	5243	Business	84000.00
0005435374846	5243	Business	84000.00
0005435315083	5243	Comfort	47600.00
0005435375117	5243	Comfort	47600.00
0005435375019	5243	Comfort	47600.00
0005435374967	5243	Comfort	47600.00
0005435375120	5243	Comfort	47600.00
0005435375042	5243	Comfort	47600.00
0005435375085	5243	Comfort	47600.00
0005435315077	5243	Comfort	47600.00
0005435375015	5243	Comfort	47600.00
0005435375071	5243	Economy	28000.00
0005432823506	5243	Economy	28000.00
0005435299885	5243	Economy	28000.00
0005435315062	5243	Economy	28000.00
0005435315135	5243	Economy	28000.00
0005435375145	5243	Economy	28000.00
0005435375024	5243	Economy	28000.00
0005435375041	5243	Economy	28000.00
0005435375128	5243	Economy	28000.00
0005435299912	5243	Economy	30800.00
0005435375017	5243	Economy	28000.00
0005435374875	5243	Economy	28000.00
0005435735258	5243	Economy	28000.00
0005435315088	5243	Economy	28000.00
0005435735254	5243	Economy	28000.00
0005435375051	5243	Economy	28000.00
0005435374960	5243	Economy	28000.00
0005435662007	5243	Economy	28000.00
0005435375118	5243	Economy	28000.00
0005435374849	5243	Economy	28000.00
0005435375106	5243	Economy	28000.00
0005435315139	5243	Economy	28000.00
0005435735256	5243	Economy	28000.00
0005435299911	5243	Economy	30800.00
0005435735266	5243	Economy	30800.00
0005435315134	5243	Economy	28000.00
0005435375044	5243	Economy	28000.00
0005435375084	5243	Economy	28000.00
0005435375043	5243	Economy	28000.00
0005435315089	5243	Economy	28000.00
0005435375050	5243	Economy	28000.00
0005435735267	5243	Economy	28000.00
0005435386753	5243	Economy	28000.00
0005432823505	5243	Economy	28000.00
0005435375119	5243	Economy	28000.00
0005435374876	5243	Economy	28000.00
0005435386746	5243	Economy	28000.00
0005435375016	5243	Economy	28000.00
0005435375025	5243	Economy	28000.00
0005435315090	5243	Economy	28000.00
0005435375083	5243	Economy	28000.00
0005435375054	5243	Economy	28000.00
0005435374925	5243	Economy	28000.00
0005435375049	5243	Economy	28000.00
0005435375144	5243	Economy	28000.00
0005435375101	5243	Economy	28000.00
0005434827174	9930	Business	84000.00
0005434558539	9930	Business	84000.00
0005434827078	9930	Business	84000.00
0005434558516	9930	Business	84000.00
0005435150405	9930	Business	84000.00
0005432396342	9930	Business	84000.00
0005434827143	9930	Business	84000.00
0005434826981	9930	Business	84000.00
0005434828762	9930	Business	84000.00
0005434828771	9930	Business	84000.00
0005434827080	9930	Business	84000.00
0005434827270	9930	Business	84000.00
0005434826984	9930	Business	84000.00
0005434831277	9930	Business	84000.00
0005434826826	9930	Business	84000.00
0005434826754	9930	Business	84000.00
0005434827135	9930	Comfort	47600.00
0005435150356	9930	Comfort	47600.00
0005434827129	9930	Comfort	47600.00
0005434558537	9930	Comfort	47600.00
0005434827098	9930	Comfort	47600.00
0005434558541	9930	Comfort	47600.00
0005434827103	9930	Comfort	47600.00
0005434827079	9930	Comfort	47600.00
0005434827134	9930	Comfort	47600.00
0005434827141	9930	Comfort	47600.00
0005434827228	9930	Comfort	47600.00
0005434827206	9930	Comfort	47600.00
0005435150397	9930	Comfort	47600.00
0005434827193	9930	Comfort	47600.00
0005434558559	9930	Comfort	47600.00
0005434827204	9930	Comfort	47600.00
0005434827149	9930	Comfort	47600.00
0005434827120	9930	Economy	28000.00
0005434826923	9930	Economy	28000.00
0005435150384	9930	Economy	28000.00
0005434826985	9930	Economy	28000.00
0005435150425	9930	Economy	28000.00
0005434826825	9930	Economy	28000.00
0005435150404	9930	Economy	28000.00
0005434827233	9930	Economy	28000.00
0005434558540	9930	Economy	28000.00
0005434827102	9930	Economy	28000.00
0005434827276	9930	Economy	28000.00
0005434826913	9930	Economy	28000.00
0005434826961	9930	Economy	28000.00
0005434827216	9930	Economy	28000.00
0005434827109	9930	Economy	28000.00
0005434826907	9930	Economy	28000.00
0005434827227	9930	Economy	28000.00
0005434826882	9930	Economy	28000.00
0005434827217	9930	Economy	28000.00
0005434827145	9930	Economy	28000.00
0005434558553	9930	Economy	28000.00
0005434558546	9930	Economy	28000.00
0005434826960	9930	Economy	28000.00
0005434558538	9930	Economy	30800.00
0005434831286	9930	Economy	28000.00
0005434827286	9930	Economy	28000.00
0005434827083	9930	Economy	28000.00
0005434826991	9930	Economy	28000.00
0005434827215	9930	Economy	28000.00
0005434827030	9930	Economy	28000.00
0005434827051	9930	Economy	28000.00
0005434827071	9930	Economy	28000.00
0005434827089	9930	Economy	28000.00
0005434558532	9930	Economy	28000.00
0005434827028	9930	Economy	28000.00
0005435150406	9930	Economy	28000.00
0005434826974	9930	Economy	28000.00
0005434558580	9930	Economy	28000.00
0005434827205	9930	Economy	28000.00
0005434826644	9930	Economy	28000.00
0005434827203	9930	Economy	28000.00
0005435150423	9930	Economy	28000.00
0005434827196	9930	Economy	28000.00
0005435150424	9930	Economy	28000.00
0005434827224	9930	Economy	28000.00
0005434831264	9930	Economy	28000.00
0005434827099	9930	Economy	28000.00
0005434558586	9930	Economy	28000.00
0005432396355	9930	Economy	28000.00
0005434558552	9930	Economy	28000.00
0005434826992	9930	Economy	28000.00
0005434827144	9930	Economy	28000.00
0005434558536	9930	Economy	28000.00
0005435150383	9930	Economy	28000.00
0005434558525	9930	Economy	28000.00
0005435150343	9930	Economy	28000.00
0005434558526	9930	Economy	28000.00
0005434826753	9930	Economy	28000.00
0005432400219	9930	Economy	28000.00
0005434826973	9930	Economy	28000.00
0005434827226	9930	Economy	28000.00
0005434558492	9930	Economy	28000.00
0005434558542	9930	Economy	28000.00
0005434827133	9930	Economy	28000.00
0005434558493	9930	Economy	28000.00
0005434558527	9930	Economy	28000.00
0005434558592	9930	Economy	28000.00
0005434827178	9930	Economy	28000.00
0005434827095	9930	Economy	28000.00
0005434827029	9930	Economy	28000.00
0005434827108	9930	Economy	28000.00
0005434827142	9930	Economy	28000.00
0005434827112	9930	Economy	28000.00
0005434827140	9930	Economy	28000.00
0005434831285	9930	Economy	28000.00
0005434826426	9930	Economy	28000.00
0005434827184	9930	Economy	28000.00
0005434558509	9930	Economy	28000.00
0005434665012	9930	Economy	28000.00
0005435150357	9930	Economy	28000.00
0005434827070	9930	Economy	28000.00
0005432400216	9930	Economy	28000.00
0005434826895	9930	Economy	28000.00
0005435083002	25979	Economy	8200.00
0005435083033	25979	Economy	7400.00
0005435083023	25979	Economy	7400.00
0005435083012	25979	Economy	7400.00
0005435083011	25979	Economy	7400.00
0005435083030	25979	Economy	7400.00
0005435083001	25979	Economy	7400.00
0005435083035	25979	Economy	7400.00
0005435083003	25979	Economy	7400.00
0005435790387	25979	Economy	7400.00
0005434215644	9573	Business	32800.00
0005434215742	9573	Business	32800.00
0005434215769	9573	Business	32800.00
0005434215665	9573	Economy	10900.00
0005434215666	9573	Economy	10900.00
0005434215571	9573	Economy	10900.00
0005434215833	9573	Economy	12000.00
0005434215759	9573	Economy	12000.00
0005434215858	9573	Economy	10900.00
0005434215772	9573	Economy	10900.00
0005434215799	9573	Economy	10900.00
0005434215848	9573	Economy	10900.00
0005434215832	9573	Economy	10900.00
0005434215818	9573	Economy	10900.00
0005434215800	9573	Economy	10900.00
0005434215652	9573	Economy	10900.00
0005434215840	9573	Economy	10900.00
0005434215816	9573	Economy	10900.00
0005434215746	9573	Economy	10900.00
0005434215780	9573	Economy	10900.00
0005434215743	9573	Economy	10900.00
0005434215798	9573	Economy	10900.00
0005434215741	9573	Economy	10900.00
0005434215771	9573	Economy	10900.00
0005434215651	9573	Economy	10900.00
0005434215650	9573	Economy	10900.00
0005434215664	9573	Economy	10900.00
0005434215789	9573	Economy	10900.00
0005434757576	28592	Business	32800.00
0005434757611	28592	Business	32800.00
0005434757577	28592	Economy	10900.00
0005434757489	28592	Economy	10900.00
0005434757536	28592	Economy	10900.00
0005434757473	28592	Economy	10900.00
0005434757566	28592	Economy	10900.00
0005434757524	28592	Economy	10900.00
0005434757647	28592	Economy	10900.00
0005434757572	28592	Economy	10900.00
0005434757648	28592	Economy	10900.00
0005434757616	28592	Economy	10900.00
0005434757644	28592	Economy	10900.00
0005434757401	28592	Economy	10900.00
0005434757393	28592	Economy	10900.00
0005434757540	28592	Economy	10900.00
0005434757625	28592	Economy	10900.00
0005434757568	28592	Economy	10900.00
0005434757587	28592	Economy	10900.00
0005434757402	28592	Economy	10900.00
0005434757617	28592	Economy	10900.00
0005434757588	28592	Economy	10900.00
0005434757542	28592	Economy	10900.00
0005434757427	28592	Economy	10900.00
0005434760256	10856	Economy	8900.00
0005434760257	10856	Economy	8900.00
0005435100205	31788	Economy	8900.00
0005435100209	31788	Economy	8900.00
0005433202779	2002	Economy	20900.00
0005433202736	2002	Economy	19000.00
0005433202781	2002	Economy	19000.00
0005433202759	2002	Economy	19000.00
0005433202749	2002	Economy	19000.00
0005433202784	2002	Economy	19000.00
0005433202741	2002	Economy	19000.00
0005433202786	2002	Economy	19000.00
0005433202783	2002	Economy	19000.00
0005433202734	2002	Economy	19000.00
0005433202785	2002	Economy	19000.00
0005433202780	2002	Economy	19000.00
0005433202761	2002	Economy	19000.00
0005433202735	2002	Economy	19000.00
0005433202755	2002	Economy	19000.00
0005433202716	2002	Economy	19000.00
0005433202795	2002	Economy	19000.00
0005433202742	2002	Economy	19000.00
0005433202787	2002	Economy	19000.00
0005433202788	2002	Economy	19000.00
0005434640035	23255	Economy	20900.00
0005434640079	23255	Economy	20900.00
0005434640036	23255	Economy	20900.00
0005434639951	23255	Economy	19000.00
0005434639947	23255	Economy	19000.00
0005434640064	23255	Economy	19000.00
0005434639946	23255	Economy	19000.00
0005434640072	23255	Economy	19000.00
0005434640023	23255	Economy	19000.00
0005434640087	23255	Economy	19000.00
0005434640088	23255	Economy	19000.00
0005434640000	23255	Economy	19000.00
0005434640025	23255	Economy	19000.00
0005434640071	23255	Economy	19000.00
0005435948357	23255	Economy	19000.00
0005435948361	23255	Economy	19000.00
0005434640080	23255	Economy	19000.00
0005434639952	23255	Economy	19000.00
0005434639945	23255	Economy	19000.00
0005435327131	6089	Business	69700.00
0005435327111	6089	Economy	23200.00
0005435327138	6089	Economy	23200.00
0005435327116	6089	Economy	23200.00
0005435327086	6089	Economy	23200.00
0005435327141	6089	Economy	23200.00
0005435327122	6089	Economy	23200.00
0005435327115	6089	Economy	23200.00
0005433531402	18601	Business	69700.00
0005433531401	18601	Business	69700.00
0005434601543	18601	Business	69700.00
0005434601522	18601	Economy	23200.00
0005434601550	18601	Economy	25600.00
0005434601562	18601	Economy	23200.00
0005434601544	18601	Economy	23200.00
0005434601497	18601	Economy	23200.00
0005434601590	18601	Economy	23200.00
0005434601553	18601	Economy	23200.00
0005434601583	18601	Economy	23200.00
0005434601589	18601	Economy	23200.00
0005433531394	18601	Economy	23200.00
0005434601591	18601	Economy	23200.00
0005433531399	18601	Economy	23200.00
0005433531400	18601	Economy	23200.00
0005433527363	18601	Economy	23200.00
0005434601584	18601	Economy	23200.00
0005434601514	18601	Economy	23200.00
0005434601493	18601	Economy	23200.00
0005434601496	18601	Economy	23200.00
0005434601560	18601	Economy	23200.00
0005434601561	18601	Economy	23200.00
0005435315068	10604	Business	9100.00
0005435315091	10604	Economy	3000.00
0005435315113	10604	Economy	3000.00
0005433181784	10604	Economy	3000.00
0005435315066	10604	Economy	3300.00
0005433181751	10604	Economy	3300.00
0005433181713	10604	Economy	3300.00
0005435315122	10604	Economy	3300.00
0005435315093	10604	Economy	3000.00
0005433181712	10604	Economy	3000.00
0005433181701	10604	Economy	3000.00
0005433181776	10604	Economy	3000.00
0005433181822	10604	Economy	3000.00
0005433181755	10604	Economy	3000.00
0005435315092	10604	Economy	3000.00
0005435315114	10604	Economy	3000.00
0005435315103	10604	Economy	3000.00
0005434552867	10604	Economy	3000.00
0005433181821	10604	Economy	3000.00
0005433181748	10604	Economy	3000.00
0005435315020	10604	Economy	3000.00
0005435315052	10604	Economy	3000.00
0005434552868	10604	Economy	3000.00
0005433181788	10604	Economy	3000.00
0005433181823	10604	Economy	3000.00
0005433181752	10604	Economy	3000.00
0005435315070	10604	Economy	3000.00
0005433181756	10604	Economy	3000.00
0005434552822	27666	Business	9100.00
0005434552664	27666	Business	9100.00
0005434552722	27666	Business	9100.00
0005434552755	27666	Business	9100.00
0005434558533	27666	Business	9100.00
0005434552770	27666	Business	9100.00
0005434552853	27666	Economy	3000.00
0005434552754	27666	Economy	3000.00
0005434558550	27666	Economy	3000.00
0005434558554	27666	Economy	3000.00
0005434552854	27666	Economy	3000.00
0005434558560	27666	Economy	3300.00
0005434552788	27666	Economy	3300.00
0005434558571	27666	Economy	3300.00
0005434558512	27666	Economy	3000.00
0005434552855	27666	Economy	3000.00
0005434552665	27666	Economy	3000.00
0005434552698	27666	Economy	3000.00
0005434558513	27666	Economy	3000.00
0005434552643	27666	Economy	3000.00
0005434558593	27666	Economy	3000.00
0005434552743	27666	Economy	3000.00
0005434552852	27666	Economy	3000.00
0005434558531	27666	Economy	3000.00
0005434558564	27666	Economy	3000.00
0005434552831	27666	Economy	3000.00
0005434558566	27666	Economy	3000.00
0005434558561	27666	Economy	3000.00
0005434558556	27666	Economy	3000.00
0005434558524	27666	Economy	3000.00
0005434552805	27666	Economy	3000.00
0005434558477	27666	Economy	3000.00
0005434552840	27666	Economy	3000.00
0005434558565	27666	Economy	3000.00
0005434558548	27666	Economy	3000.00
0005434558567	27666	Economy	3000.00
0005434558578	27666	Economy	3000.00
0005434558478	27666	Economy	3000.00
0005434558575	27666	Economy	3000.00
0005434552832	27666	Economy	3000.00
0005434552633	27666	Economy	3000.00
0005434552789	27666	Economy	3000.00
0005434552561	27666	Economy	3000.00
0005434558488	27666	Economy	3000.00
0005434552801	27666	Economy	3000.00
0005434558576	27666	Economy	3000.00
0005434558476	27666	Economy	3000.00
0005434552866	27666	Economy	3000.00
0005434558598	27666	Economy	3000.00
0005434558555	27666	Economy	3000.00
0005434558508	27666	Economy	3000.00
0005434558585	27666	Economy	3000.00
0005434552814	27666	Economy	3000.00
0005434558511	27666	Economy	3000.00
0005434558591	27666	Economy	3000.00
0005434552562	27666	Economy	3000.00
0005433459341	19321	Economy	11700.00
0005433459340	19321	Economy	11700.00
0005435438582	6762	Business	51100.00
0005435438521	6762	Business	51100.00
0005435438583	6762	Economy	17000.00
0005435438578	6762	Economy	17000.00
0005435438523	6762	Economy	17000.00
0005435438561	6762	Economy	17000.00
0005435221535	6762	Economy	17000.00
0005435438560	6762	Economy	17000.00
0005435438574	6762	Economy	17000.00
0005435438558	6762	Economy	17000.00
0005435438522	6762	Economy	17000.00
0005435438559	6762	Economy	17000.00
0005435662010	24579	Business	51100.00
0005435683271	24579	Economy	17000.00
0005435683119	24579	Economy	18700.00
0005435683283	24579	Economy	18700.00
0005435683211	24579	Economy	18700.00
0005435683285	24579	Economy	17000.00
0005435631039	24579	Economy	17000.00
0005435683243	24579	Economy	17000.00
0005435683195	24579	Economy	17000.00
0005435719599	24579	Economy	17000.00
0005435683284	24579	Economy	17000.00
0005435662012	24579	Economy	17000.00
0005435683244	24579	Economy	17000.00
0005435683183	24579	Economy	17000.00
0005435683210	24579	Economy	17000.00
0005435683209	24579	Economy	17000.00
0005435654515	24579	Economy	17000.00
0005435683278	24579	Economy	17000.00
0005435719598	24579	Economy	17000.00
0005435662011	24579	Economy	17000.00
0005435631047	24579	Economy	17000.00
0005435683309	24579	Economy	17000.00
0005435683310	24579	Economy	17000.00
0005435558154	11507	Economy	8800.00
0005435558157	11507	Economy	8800.00
0005435558153	11507	Economy	8800.00
0005435127318	31885	Business	26400.00
0005435127565	31885	Business	26400.00
0005435127523	31885	Business	26400.00
0005435127411	31885	Business	26400.00
0005435098612	31885	Business	26400.00
0005435127556	31885	Economy	8800.00
0005435127521	31885	Economy	8800.00
0005435127522	31885	Economy	8800.00
0005435127525	31885	Economy	8800.00
0005435127319	31885	Economy	9700.00
0005435127512	31885	Economy	8800.00
0005435127515	31885	Economy	8800.00
0005435127528	31885	Economy	8800.00
0005435127529	31885	Economy	8800.00
0005435127555	31885	Economy	8800.00
0005435127331	31885	Economy	8800.00
0005435127508	31885	Economy	8800.00
0005435732700	13519	Economy	12200.00
0005435732710	13519	Economy	12200.00
0005435732652	13519	Economy	13400.00
0005435732714	13519	Economy	12200.00
0005435732715	13519	Economy	12200.00
0005435732711	13519	Economy	12200.00
0005435732668	13519	Economy	12200.00
0005435732692	13519	Economy	12200.00
0005433399331	19376	Business	36600.00
0005433399423	19376	Business	36600.00
0005433399330	19376	Business	36600.00
0005433399357	19376	Business	36600.00
0005433399398	19376	Business	36600.00
0005433399400	19376	Economy	12200.00
0005433399269	19376	Economy	12200.00
0005433399450	19376	Economy	12200.00
0005433399456	19376	Economy	13400.00
0005433399452	19376	Economy	13400.00
0005433399345	19376	Economy	12200.00
0005433399370	19376	Economy	12200.00
0005433399399	19376	Economy	12200.00
0005433399309	19376	Economy	12200.00
0005433399336	19376	Economy	12200.00
0005433399326	19376	Economy	12200.00
0005433399321	19376	Economy	12200.00
0005433399429	19376	Economy	12200.00
0005433399284	19376	Economy	12200.00
0005433399417	19376	Economy	12200.00
0005433399307	19376	Economy	12200.00
0005433399308	19376	Economy	12200.00
0005433399424	19376	Economy	12200.00
0005433399449	19376	Economy	12200.00
0005433399463	19376	Economy	12200.00
0005433399442	19376	Economy	12200.00
0005433399195	19376	Economy	12200.00
0005433399443	19376	Economy	12200.00
0005433399428	19376	Economy	12200.00
0005433399228	19376	Economy	12200.00
0005433399356	19376	Economy	12200.00
0005433399325	19376	Economy	12200.00
0005433399425	19376	Economy	12200.00
0005435070488	13158	Business	11300.00
0005435070537	13158	Business	11300.00
0005435070503	13158	Economy	3800.00
0005435070401	13158	Economy	4100.00
0005435070436	13158	Economy	3800.00
0005435070454	13158	Economy	3800.00
0005435070410	13158	Economy	3800.00
0005435070495	13158	Economy	3800.00
0005435070430	13158	Economy	3800.00
0005435070515	13158	Economy	3800.00
0005435070409	13158	Economy	3800.00
0005435070408	13158	Economy	3800.00
0005435070449	13158	Economy	3800.00
0005435070273	13158	Economy	3800.00
0005435070476	13158	Economy	3800.00
0005435070402	13158	Economy	3800.00
0005435070477	13158	Economy	3800.00
0005435070514	13158	Economy	3800.00
0005435070382	13158	Economy	3800.00
0005435925696	15476	Economy	3800.00
0005435925672	15476	Economy	4100.00
0005435925683	15476	Economy	3800.00
0005435925721	15476	Economy	3800.00
0005435925673	15476	Economy	3800.00
0005435925631	15476	Economy	3800.00
0005435925697	15476	Economy	3800.00
0005435925722	15476	Economy	3800.00
0005434757567	10738	Business	61300.00
0005434757626	10738	Business	61300.00
0005434757447	10738	Business	61300.00
0005434757539	10738	Business	61300.00
0005434757590	10738	Business	61300.00
0005434757543	10738	Business	61300.00
0005434757562	10738	Economy	20400.00
0005434757594	10738	Economy	20400.00
0005434757528	10738	Economy	20400.00
0005434757584	10738	Economy	22500.00
0005434757619	10738	Economy	22500.00
0005434757558	10738	Economy	20400.00
0005434757640	10738	Economy	20400.00
0005434757573	10738	Economy	20400.00
0005434757459	10738	Economy	20400.00
0005434757637	10738	Economy	20400.00
0005434757557	10738	Economy	20400.00
0005434757466	10738	Economy	20400.00
0005434757458	10738	Economy	20400.00
0005434757583	10738	Economy	20400.00
0005434757397	10738	Economy	20400.00
0005434757530	10738	Economy	20400.00
0005434757499	10738	Economy	20400.00
0005434757547	10738	Economy	20400.00
0005434757589	10738	Economy	20400.00
0005434757529	10738	Economy	20400.00
0005434757448	10738	Economy	20400.00
0005434757595	10738	Economy	20400.00
0005434215779	28663	Business	61300.00
0005434215697	28663	Business	61300.00
0005434215782	28663	Business	61300.00
0005434215839	28663	Economy	20400.00
0005434215719	28663	Economy	20400.00
0005434215788	28663	Economy	22500.00
0005434215583	28663	Economy	20400.00
0005434215817	28663	Economy	20400.00
0005434215732	28663	Economy	20400.00
0005434215731	28663	Economy	20400.00
0005434215790	28663	Economy	20400.00
0005434215749	28663	Economy	20400.00
0005434215766	28663	Economy	20400.00
0005434215686	28663	Economy	20400.00
0005434215762	28663	Economy	20400.00
0005434215825	28663	Economy	20400.00
0005434215648	28663	Economy	20400.00
0005434215763	28663	Economy	20400.00
0005434215776	28663	Economy	20400.00
0005434215812	28663	Economy	20400.00
0005434215810	28663	Economy	20400.00
0005434215733	28663	Economy	20400.00
0005434215605	28663	Economy	20400.00
0005434215777	28663	Economy	20400.00
0005434215778	28663	Economy	20400.00
0005434215857	28663	Economy	20400.00
0005434215811	28663	Economy	20400.00
0005434215760	28663	Economy	20400.00
0005434215761	28663	Economy	20400.00
0005434215698	28663	Economy	20400.00
0005434215795	28663	Economy	20400.00
0005434229979	5480	Business	29500.00
0005434230014	5480	Business	29500.00
0005435377981	5480	Business	29500.00
0005434229967	5480	Economy	9800.00
0005434230024	5480	Economy	9800.00
0005434229980	5480	Economy	9800.00
0005434230023	5480	Economy	9800.00
0005435377969	5480	Economy	9800.00
0005435377973	5480	Economy	9800.00
0005435377959	5480	Economy	9800.00
0005434230019	5480	Economy	9800.00
0005435377975	5480	Economy	10800.00
0005435377970	5480	Economy	9800.00
0005434230020	5480	Economy	9800.00
0005434229966	5480	Economy	9800.00
0005434230021	5480	Economy	9800.00
0005435377963	5480	Economy	9800.00
0005435377974	5480	Economy	9800.00
0005434229997	5480	Economy	9800.00
0005434230018	5480	Economy	9800.00
0005435041402	12993	Business	29500.00
0005435041624	12993	Business	29500.00
0005435007696	12993	Business	29500.00
0005435007665	12993	Business	29500.00
0005435041448	12993	Business	29500.00
0005435041644	12993	Business	29500.00
0005435007715	12993	Economy	9800.00
0005435041586	12993	Economy	9800.00
0005435007624	12993	Economy	9800.00
0005435041666	12993	Economy	9800.00
0005435007695	12993	Economy	9800.00
0005435041479	12993	Economy	9800.00
0005435043310	12993	Economy	9800.00
0005435041393	12993	Economy	9800.00
0005435041642	12993	Economy	9800.00
0005435041516	12993	Economy	9800.00
0005435007637	12993	Economy	9800.00
0005435041348	12993	Economy	9800.00
0005435043309	12993	Economy	9800.00
0005435041394	12993	Economy	9800.00
0005435041486	12993	Economy	9800.00
0005435041510	12993	Economy	9800.00
0005435041447	12993	Economy	10800.00
0005435041622	12993	Economy	10800.00
0005435041401	12993	Economy	10800.00
0005435007623	12993	Economy	10800.00
0005435041405	12993	Economy	9800.00
0005435041587	12993	Economy	9800.00
0005435041504	12993	Economy	9800.00
0005435007636	12993	Economy	9800.00
0005435041535	12993	Economy	9800.00
0005435007662	12993	Economy	9800.00
0005435041678	12993	Economy	9800.00
0005435041517	12993	Economy	9800.00
0005435041667	12993	Economy	9800.00
0005435041400	12993	Economy	9800.00
0005435041612	12993	Economy	9800.00
0005435041613	12993	Economy	9800.00
0005435007664	12993	Economy	9800.00
0005435041606	12993	Economy	9800.00
0005435041521	12993	Economy	9800.00
0005435041611	12993	Economy	9800.00
0005435007666	12993	Economy	9800.00
0005435041623	12993	Economy	9800.00
0005435042926	12993	Economy	9800.00
0005435041607	12993	Economy	9800.00
0005435007697	12993	Economy	9800.00
0005435007717	12993	Economy	9800.00
0005435041482	12993	Economy	9800.00
0005435041576	12993	Economy	9800.00
0005435041485	12993	Economy	9800.00
0005435007683	12993	Economy	9800.00
0005435041522	12993	Economy	9800.00
0005435007682	12993	Economy	9800.00
0005435903197	14893	Business	52900.00
0005435554313	14893	Economy	19400.00
0005435903213	14893	Economy	17600.00
0005435903207	14893	Economy	17600.00
0005435903199	14893	Economy	17600.00
0005435903192	14893	Economy	17600.00
0005435903198	14893	Economy	17600.00
0005435903205	14893	Economy	17600.00
0005435903206	14893	Economy	17600.00
0005435554328	14893	Economy	17600.00
0005435554302	14893	Economy	17600.00
0005435903180	14893	Economy	17600.00
0005435903184	14893	Economy	17600.00
0005435903214	14893	Economy	17600.00
0005435554303	14893	Economy	17600.00
0005434411894	20218	Business	52900.00
0005434427404	20218	Economy	17600.00
0005434427407	20218	Economy	19400.00
0005434427444	20218	Economy	19400.00
0005434427384	20218	Economy	17600.00
0005434427436	20218	Economy	17600.00
0005434411895	20218	Economy	17600.00
0005434427383	20218	Economy	17600.00
0005434427397	20218	Economy	17600.00
0005434427470	20218	Economy	17600.00
0005434427446	20218	Economy	17600.00
0005434427447	20218	Economy	17600.00
0005434427469	20218	Economy	17600.00
0005434427463	20218	Economy	17600.00
0005433435481	26541	Business	18500.00
0005433435487	26541	Business	18500.00
0005433435420	26541	Economy	6200.00
0005433435463	26541	Economy	6200.00
0005433435430	26541	Economy	6200.00
0005433435433	26541	Economy	6200.00
0005433435493	26541	Economy	6200.00
0005433435436	26541	Economy	6200.00
0005434270265	26541	Economy	6200.00
0005433435486	26541	Economy	6200.00
0005433435494	26541	Economy	6200.00
0005433435457	26541	Economy	6200.00
0005433435456	26541	Economy	6200.00
0005433435432	26541	Economy	6200.00
0005433435422	26541	Economy	6200.00
0005433435440	26541	Economy	6200.00
0005433435401	26541	Economy	6200.00
0005433435332	26541	Economy	6200.00
0005433435448	26541	Economy	6200.00
0005433435434	26541	Economy	6200.00
0005434273123	26541	Economy	6200.00
0005433435474	26541	Economy	6200.00
0005435983409	26703	Business	18500.00
0005435983586	26703	Business	18500.00
0005435983613	26703	Economy	6200.00
0005435983570	26703	Economy	6200.00
0005435983573	26703	Economy	6200.00
0005435983316	26703	Economy	6200.00
0005435983568	26703	Economy	6800.00
0005435983546	26703	Economy	6200.00
0005435983565	26703	Economy	6200.00
0005435983566	26703	Economy	6200.00
0005435983532	26703	Economy	6200.00
0005435983552	26703	Economy	6200.00
0005435983547	26703	Economy	6200.00
0005435983614	26703	Economy	6200.00
0005435983630	26703	Economy	6200.00
0005435983629	26703	Economy	6200.00
0005435983605	26703	Economy	6200.00
0005435983315	26703	Economy	6200.00
0005435983633	26703	Economy	6200.00
0005435983504	26703	Economy	6200.00
0005435983649	26703	Economy	6200.00
0005435983641	26703	Economy	6200.00
0005435983387	26703	Economy	6200.00
0005435983644	26703	Economy	6200.00
0005435983435	26703	Economy	6200.00
0005435983643	26703	Economy	6200.00
0005435983587	26703	Economy	6200.00
0005435983467	26703	Economy	6200.00
0005435983648	26703	Economy	6200.00
0005435983463	26703	Economy	6200.00
0005435983584	26703	Economy	6200.00
0005435983472	26703	Economy	6200.00
0005435983401	26703	Economy	6200.00
0005435983408	26703	Economy	6200.00
0005435983400	26703	Economy	6200.00
0005435983434	26703	Economy	6200.00
0005435983583	26703	Economy	6200.00
0005435983314	26703	Economy	6200.00
0005432858407	3152	Economy	11100.00
0005432858365	3152	Economy	10100.00
0005432858368	3152	Economy	10100.00
0005432858404	3152	Economy	10100.00
0005432858403	3152	Economy	10100.00
0005432584740	31504	Economy	11100.00
0005432584747	31504	Economy	10100.00
0005432584734	31504	Economy	10100.00
0005432584707	31504	Economy	10100.00
0005432584778	31504	Economy	10100.00
0005432584733	31504	Economy	10100.00
0005432584751	31504	Economy	10100.00
0005432584745	31504	Economy	10100.00
0005432584744	31504	Economy	10100.00
0005432584748	31504	Economy	10100.00
0005432584788	31504	Economy	10100.00
0005432584766	31504	Economy	10100.00
0005432584746	31504	Economy	10100.00
0005432584789	31504	Economy	10100.00
0005433255272	869	Economy	8300.00
0005433255273	869	Economy	7500.00
0005434943601	16220	Economy	7500.00
0005434943587	16220	Economy	7500.00
0005434943615	16220	Economy	7500.00
0005434943586	16220	Economy	7500.00
0005434943602	16220	Economy	7500.00
0005434943608	16220	Economy	7500.00
0005434943614	16220	Economy	7500.00
0005434943607	16220	Economy	7500.00
0005434943585	16220	Economy	7500.00
0005433811686	14355	Economy	4400.00
0005433368830	21761	Business	9800.00
0005433368831	21761	Business	9800.00
0005435790413	21761	Business	9800.00
0005433368967	21761	Economy	3300.00
0005433368945	21761	Economy	3600.00
0005435654498	21761	Economy	3600.00
0005435790415	21761	Economy	3300.00
0005433368870	21761	Economy	3300.00
0005433368909	21761	Economy	3300.00
0005433368894	21761	Economy	3300.00
0005433368968	21761	Economy	3300.00
0005433368829	21761	Economy	3300.00
0005433368963	21761	Economy	3300.00
0005435790414	21761	Economy	3300.00
0005433368966	21761	Economy	3300.00
0005433368893	21761	Economy	3300.00
0005433368848	21761	Economy	3300.00
0005435270056	9335	Business	186200.00
0005434171448	9335	Business	186200.00
0005434270266	9335	Business	186200.00
0005435270033	9335	Business	186200.00
0005435858704	9335	Business	186200.00
0005434171461	9335	Business	186200.00
0005435270179	9335	Economy	62100.00
0005434171449	9335	Economy	62100.00
0005435270144	9335	Economy	62100.00
0005435270034	9335	Economy	62100.00
0005435270008	9335	Economy	62100.00
0005435858705	9335	Economy	62100.00
0005435270178	9335	Economy	62100.00
0005435270071	9335	Economy	62100.00
0005435270158	9335	Economy	62100.00
0005435270117	9335	Economy	62100.00
0005435270194	9335	Economy	62100.00
0005435270133	9335	Economy	62100.00
0005435270145	9335	Economy	62100.00
0005435270139	9335	Economy	62100.00
0005434171460	9335	Economy	62100.00
0005434171431	9335	Economy	62100.00
0005434171462	9335	Economy	62100.00
0005435269934	9335	Economy	62100.00
0005435270169	9335	Economy	62100.00
0005435270141	9335	Economy	62100.00
0005435270140	9335	Economy	62100.00
0005435270024	9335	Economy	62100.00
0005434171464	9335	Economy	62100.00
0005435270130	9335	Economy	62100.00
0005435270166	9335	Economy	62100.00
0005435270032	9335	Economy	62100.00
0005435270195	9335	Economy	62100.00
0005435270161	9335	Economy	62100.00
0005435270116	9335	Economy	62100.00
0005435270104	9335	Economy	62100.00
0005435270196	9335	Economy	62100.00
0005435270153	9335	Economy	62100.00
0005435270009	9335	Economy	62100.00
0005435858721	9335	Economy	62100.00
0005433763569	26235	Business	186200.00
0005433806295	26235	Business	186200.00
0005433786080	26235	Business	186200.00
0005433786107	26235	Business	186200.00
0005433785918	26235	Business	186200.00
0005432659762	26235	Business	186200.00
0005433806269	26235	Business	186200.00
0005432663097	26235	Business	186200.00
0005433763622	26235	Business	186200.00
0005433806249	26235	Business	186200.00
0005433786076	26235	Business	186200.00
0005433785947	26235	Business	186200.00
0005433786154	26235	Economy	68300.00
0005433806389	26235	Economy	62100.00
0005433763621	26235	Economy	62100.00
0005432657531	26235	Economy	62100.00
0005433785874	26235	Economy	62100.00
0005433806375	26235	Economy	62100.00
0005433806300	26235	Economy	62100.00
0005433806306	26235	Economy	62100.00
0005433806267	26235	Economy	62100.00
0005433763598	26235	Economy	62100.00
0005433786122	26235	Economy	62100.00
0005433786151	26235	Economy	62100.00
0005433806404	26235	Economy	62100.00
0005433806321	26235	Economy	62100.00
0005433806331	26235	Economy	62100.00
0005433806250	26235	Economy	62100.00
0005433806248	26235	Economy	62100.00
0005433786150	26235	Economy	62100.00
0005433786077	26235	Economy	62100.00
0005433763605	26235	Economy	62100.00
0005433786110	26235	Economy	62100.00
0005433806332	26235	Economy	62100.00
0005433786143	26235	Economy	62100.00
0005433786149	26235	Economy	62100.00
0005433786116	26235	Economy	62100.00
0005433763624	26235	Economy	62100.00
0005433763620	26235	Economy	62100.00
0005433786019	26235	Economy	62100.00
0005433806339	26235	Economy	62100.00
0005433806349	26235	Economy	62100.00
0005433806359	26235	Economy	62100.00
0005433786086	26235	Economy	68300.00
0005433806322	26235	Economy	62100.00
0005433786087	26235	Economy	62100.00
0005433806307	26235	Economy	62100.00
0005433786142	26235	Economy	62100.00
0005433785980	26235	Economy	62100.00
0005433786103	26235	Economy	62100.00
0005433806363	26235	Economy	62100.00
0005433786117	26235	Economy	62100.00
0005432659763	26235	Economy	62100.00
0005432657532	26235	Economy	62100.00
0005433806388	26235	Economy	62100.00
0005433806337	26235	Economy	62100.00
0005433806368	26235	Economy	62100.00
0005433806340	26235	Economy	62100.00
0005433806268	26235	Economy	62100.00
0005433786102	26235	Economy	62100.00
0005433806315	26235	Economy	62100.00
0005433806377	26235	Economy	62100.00
0005433806350	26235	Economy	62100.00
0005433806358	26235	Economy	62100.00
0005433806393	26235	Economy	62100.00
0005433763623	26235	Economy	62100.00
0005433785948	26235	Economy	62100.00
0005433806362	26235	Economy	62100.00
0005433786018	26235	Economy	62100.00
0005432663092	26235	Economy	62100.00
0005433786111	26235	Economy	62100.00
0005433806319	26235	Economy	62100.00
0005433806405	26235	Economy	62100.00
0005433786028	26235	Economy	62100.00
0005435929721	4921	Economy	5300.00
0005435135803	33021	Economy	5300.00
0005434218080	9497	Economy	17900.00
0005434218085	9497	Economy	17900.00
0005434218089	9497	Economy	17900.00
0005434218076	9497	Economy	17900.00
0005434218084	9497	Economy	17900.00
0005434983417	27359	Economy	19700.00
0005434983430	27359	Economy	17900.00
0005434983416	27359	Economy	17900.00
0005434983429	27359	Economy	17900.00
0005433962507	24254	Business	36400.00
0005433962395	24254	Business	36400.00
0005433986992	24254	Business	36400.00
0005433962638	24254	Business	36400.00
0005433962264	24254	Business	36400.00
0005433962385	24254	Business	36400.00
0005433962174	24254	Business	36400.00
0005433962348	24254	Business	36400.00
0005433962228	24254	Business	36400.00
0005433987244	24254	Business	36400.00
0005433987299	24254	Business	36400.00
0005433986991	24254	Business	36400.00
0005433962527	24254	Business	36400.00
0005433962637	24254	Business	36400.00
0005433962338	24254	Business	36400.00
0005433987221	24254	Business	36400.00
0005433962432	24254	Business	36400.00
0005433962359	24254	Business	36400.00
0005433962554	24254	Economy	13400.00
0005433987291	24254	Economy	12100.00
0005433987309	24254	Economy	13400.00
0005433987290	24254	Economy	12100.00
0005433962546	24254	Economy	12100.00
0005433962290	24254	Economy	12100.00
0005433987298	24254	Economy	12100.00
0005433962582	24254	Economy	12100.00
0005433987331	24254	Economy	12100.00
0005433987283	24254	Economy	12100.00
0005433962391	24254	Economy	12100.00
0005433962427	24254	Economy	12100.00
0005433962571	24254	Economy	12100.00
0005433987279	24254	Economy	12100.00
0005433987202	24254	Economy	12100.00
0005433987292	24254	Economy	12100.00
0005433987256	24254	Economy	12100.00
0005433962497	24254	Economy	12100.00
0005433987201	24254	Economy	12100.00
0005433987197	24254	Economy	12100.00
0005433962482	24254	Economy	12100.00
0005433962384	24254	Economy	12100.00
0005433987310	24254	Economy	12100.00
0005433962486	24254	Economy	12100.00
0005433962635	24254	Economy	12100.00
0005433962389	24254	Economy	12100.00
0005433962442	24254	Economy	12100.00
0005433962259	24254	Economy	12100.00
0005433962393	24254	Economy	12100.00
0005433962428	24254	Economy	12100.00
0005433962617	24254	Economy	12100.00
0005433962287	24254	Economy	12100.00
0005433987271	24254	Economy	12100.00
0005433987171	24254	Economy	12100.00
0005433987200	24254	Economy	12100.00
0005433962421	24254	Economy	12100.00
0005433962649	24254	Economy	12100.00
0005433987285	24254	Economy	12100.00
0005433962408	24254	Economy	12100.00
0005433987361	24254	Economy	12100.00
0005433962641	24254	Economy	12100.00
0005433962639	24254	Economy	12100.00
0005433987275	24254	Economy	12100.00
0005433962488	24254	Economy	12100.00
0005433962383	24254	Economy	12100.00
0005433987301	24254	Economy	12100.00
0005433962591	24254	Economy	12100.00
0005433962642	24254	Economy	12100.00
0005433962322	24254	Economy	12100.00
0005433987360	24254	Economy	12100.00
0005433962481	24254	Economy	12100.00
0005433962409	24254	Economy	12100.00
0005433962498	24254	Economy	12100.00
0005433962431	24254	Economy	12100.00
0005433962535	24254	Economy	12100.00
0005433987366	24254	Economy	12100.00
0005433962631	24254	Economy	12100.00
0005433962587	24254	Economy	12100.00
0005433987198	24254	Economy	12100.00
0005433962618	24254	Economy	12100.00
0005433986952	24254	Economy	12100.00
0005433962581	24254	Economy	13400.00
0005433987288	24254	Economy	13400.00
0005433962543	24254	Economy	12100.00
0005433987088	24254	Economy	12100.00
0005433962526	24254	Economy	13400.00
0005433987297	24254	Economy	12100.00
0005433962643	24254	Economy	12100.00
0005433962377	24254	Economy	12100.00
0005433962523	24254	Economy	12100.00
0005433987354	24254	Economy	12100.00
0005433987365	24254	Economy	12100.00
0005433987359	24254	Economy	12100.00
0005433987257	24254	Economy	12100.00
0005433962315	24254	Economy	12100.00
0005433962483	24254	Economy	12100.00
0005433962616	24254	Economy	12100.00
0005433962386	24254	Economy	12100.00
0005433962468	24254	Economy	12100.00
0005433962396	24254	Economy	12100.00
0005433962446	24254	Economy	12100.00
0005433962360	24254	Economy	12100.00
0005433962430	24254	Economy	12100.00
0005433987082	24254	Economy	12100.00
0005433987181	24254	Economy	12100.00
0005433962559	24254	Economy	12100.00
0005433962331	24254	Economy	12100.00
0005433987317	24254	Economy	12100.00
0005433962460	24254	Economy	12100.00
0005433962422	24254	Economy	12100.00
0005433962644	24254	Economy	12100.00
0005433962236	24254	Economy	12100.00
0005433962465	24254	Economy	12100.00
0005433962167	24254	Economy	12100.00
0005433987236	24254	Economy	12100.00
0005433987237	24254	Economy	12100.00
0005433962492	24254	Economy	12100.00
0005433962524	24254	Economy	12100.00
0005433962584	24254	Economy	12100.00
0005433962508	24254	Economy	12100.00
0005433962592	24254	Economy	12100.00
0005433962615	24254	Economy	12100.00
0005433987134	24254	Economy	12100.00
0005433987269	24254	Economy	12100.00
0005433987146	24254	Economy	12100.00
0005433962636	24254	Economy	12100.00
0005433987182	24254	Economy	12100.00
0005433987276	24254	Economy	12100.00
0005433962448	24254	Economy	12100.00
0005433962489	24254	Economy	12100.00
0005433987315	24254	Economy	12100.00
0005433962547	24254	Economy	12100.00
0005433962332	24254	Economy	12100.00
0005433962456	24254	Economy	12100.00
0005433987272	24254	Economy	12100.00
0005433987242	24254	Economy	12100.00
0005433987233	24254	Economy	12100.00
0005434908903	25932	Economy	12100.00
0005433166259	937	Economy	23100.00
0005434480900	16581	Economy	25400.00
0005434481013	16581	Economy	23100.00
0005434480984	16581	Economy	23100.00
0005434481019	16581	Economy	23100.00
0005434481020	16581	Economy	23100.00
0005434481012	16581	Economy	23100.00
0005434480983	16581	Economy	23100.00
0005434481034	16581	Economy	23100.00
0005434481033	16581	Economy	23100.00
0005433166289	16581	Economy	23100.00
0005434480962	16581	Economy	23100.00
0005433290048	10361	Economy	17000.00
0005433290047	10361	Economy	17000.00
0005435386752	10361	Economy	15400.00
0005433290056	10361	Economy	15400.00
0005435386740	10361	Economy	15400.00
0005435386739	10361	Economy	15400.00
0005435386727	10361	Economy	15400.00
0005433290026	10361	Economy	15400.00
0005433290052	10361	Economy	15400.00
0005433290050	10361	Economy	15400.00
0005433290027	10361	Economy	15400.00
0005433290035	10361	Economy	15400.00
0005433290053	10361	Economy	15400.00
0005435386726	10361	Economy	15400.00
0005435150406	21909	Economy	15400.00
0005435142936	21909	Economy	15400.00
0005435150343	21909	Economy	15400.00
0005435150425	21909	Economy	15400.00
0005435150405	21909	Economy	15400.00
0005435150404	21909	Economy	15400.00
0005435142943	21909	Economy	15400.00
0005435142940	21909	Economy	15400.00
0005435142935	21909	Economy	15400.00
0005435150397	21909	Economy	15400.00
0005435150356	21909	Economy	15400.00
0005435150357	21909	Economy	15400.00
0005435150423	21909	Economy	15400.00
0005435142892	21909	Economy	15400.00
0005435150424	21909	Economy	15400.00
0005435142934	21909	Economy	15400.00
0005435150383	21909	Economy	15400.00
0005435142967	21909	Economy	15400.00
0005435150384	21909	Economy	15400.00
0005435529858	11204	Business	57200.00
0005435502906	11204	Business	57200.00
0005435502905	11204	Business	57200.00
0005435502880	11204	Business	57200.00
0005435529885	11204	Economy	19100.00
0005435529831	11204	Economy	19100.00
0005435319797	11204	Economy	19100.00
0005435545917	11204	Economy	19100.00
0005435545939	11204	Economy	19100.00
0005435502888	11204	Economy	19100.00
0005435529867	11204	Economy	19100.00
0005435529847	11204	Economy	19100.00
0005435502914	11204	Economy	19100.00
0005435502949	11204	Economy	19100.00
0005435502877	11204	Economy	19100.00
0005435502944	11204	Economy	19100.00
0005435502890	11204	Economy	19100.00
0005434573779	11204	Economy	19100.00
0005435319796	11204	Economy	19100.00
0005435529886	11204	Economy	19100.00
0005435529877	11204	Economy	19100.00
0005435545916	11204	Economy	19100.00
0005435502876	11204	Economy	19100.00
0005435529873	11204	Economy	19100.00
0005435502920	11204	Economy	19100.00
0005435545942	11204	Economy	19100.00
0005435502873	11204	Economy	19100.00
0005435529866	11204	Economy	19100.00
0005435545886	11204	Economy	19100.00
0005435502874	11204	Economy	19100.00
0005435502891	11204	Economy	19100.00
0005434573778	11204	Economy	19100.00
0005434573739	20959	Business	57200.00
0005434573723	20959	Economy	19100.00
0005434573708	20959	Economy	19100.00
0005434573753	20959	Economy	19100.00
0005434573709	20959	Economy	19100.00
0005434573740	20959	Economy	19100.00
0005434573724	20959	Economy	19100.00
0005434573694	20959	Economy	19100.00
0005434573735	20959	Economy	19100.00
0005434573700	20959	Economy	19100.00
0005434573766	20959	Economy	19100.00
0005434573768	20959	Economy	19100.00
0005434573701	20959	Economy	19100.00
0005434573725	20959	Economy	19100.00
0005432693891	2994	Business	10300.00
0005432693820	2994	Economy	3400.00
0005432693910	2994	Economy	3400.00
0005432693901	2994	Economy	3400.00
0005432693959	2994	Economy	3800.00
0005432693841	2994	Economy	3400.00
0005432693911	2994	Economy	3400.00
0005432693963	2994	Economy	3400.00
0005432693914	2994	Economy	3400.00
0005432693826	2994	Economy	3400.00
0005432693917	2994	Economy	3400.00
0005432693900	2994	Economy	3400.00
0005432693913	2994	Economy	3400.00
0005432693825	2994	Economy	3400.00
0005432693941	2994	Economy	3400.00
0005432693832	2994	Economy	3400.00
0005432693852	2994	Economy	3400.00
0005432693779	2994	Economy	3400.00
0005432693912	2994	Economy	3400.00
0005432693960	2994	Economy	3400.00
0005432693840	2994	Economy	3400.00
0005432693829	2994	Economy	3400.00
0005432693889	2994	Economy	3400.00
0005433194963	3043	Business	10300.00
0005433194945	3043	Business	10300.00
0005433124512	3043	Business	10300.00
0005433124511	3043	Business	10300.00
0005433194946	3043	Business	10300.00
0005432881174	3043	Economy	3400.00
0005432881216	3043	Economy	3400.00
0005433194992	3043	Economy	3400.00
0005432881209	3043	Economy	3400.00
0005432881224	3043	Economy	3400.00
0005432881221	3043	Economy	3400.00
0005433124439	3043	Economy	3400.00
0005433124510	3043	Economy	3400.00
0005433194937	3043	Economy	3800.00
0005433124495	3043	Economy	3400.00
0005432881198	3043	Economy	3400.00
0005434300263	3043	Economy	3400.00
0005433194996	3043	Economy	3400.00
0005433195003	3043	Economy	3400.00
0005433124438	3043	Economy	3400.00
0005433124499	3043	Economy	3400.00
0005433194939	3043	Economy	3400.00
0005433124476	3043	Economy	3400.00
0005433124496	3043	Economy	3400.00
0005433194936	3043	Economy	3400.00
0005433194923	3043	Economy	3400.00
0005433124519	3043	Economy	3400.00
0005433124474	3043	Economy	3400.00
0005433194978	3043	Economy	3400.00
0005433195002	3043	Economy	3400.00
0005433194924	3043	Economy	3400.00
0005433194932	3043	Economy	3400.00
0005432881202	3043	Economy	3400.00
0005433124436	3043	Economy	3400.00
0005433124473	3043	Economy	3400.00
0005432881241	3043	Economy	3400.00
0005433194938	3043	Economy	3400.00
0005433124472	3043	Economy	3400.00
0005433124467	3043	Economy	3400.00
0005432881223	3043	Economy	3400.00
0005433194977	3043	Economy	3400.00
0005432881225	3043	Economy	3400.00
0005433124536	3043	Economy	3400.00
0005433124475	3043	Economy	3400.00
0005432881242	3043	Economy	3400.00
0005433124535	3043	Economy	3400.00
0005432881191	3043	Economy	3400.00
0005432707500	30043	Business	10300.00
0005432707495	30043	Economy	3800.00
0005432707497	30043	Economy	3800.00
0005432707394	30043	Economy	3400.00
0005432707510	30043	Economy	3400.00
0005432707506	30043	Economy	3400.00
0005432707447	30043	Economy	3400.00
0005432707446	30043	Economy	3400.00
0005432707458	30043	Economy	3400.00
0005434989056	27556	Economy	4000.00
0005434980639	27556	Economy	4000.00
0005434989018	27556	Economy	4000.00
0005434980559	27556	Economy	4000.00
0005434980577	27556	Economy	3600.00
0005434980537	27556	Economy	3600.00
0005434980663	27556	Economy	3600.00
0005434980632	27556	Economy	3600.00
0005434980643	27556	Economy	3600.00
0005434980670	27556	Economy	3600.00
0005434980587	27556	Economy	3600.00
0005434980575	27556	Economy	3600.00
0005434980622	27556	Economy	3600.00
0005434980624	27556	Economy	3600.00
0005434988986	27556	Economy	3600.00
0005434988985	27556	Economy	3600.00
0005434980631	27556	Economy	3600.00
0005434989078	27556	Economy	3600.00
0005434980623	27556	Economy	3600.00
0005434980583	27556	Economy	3600.00
0005434989051	27556	Economy	3600.00
0005434989093	27556	Economy	3600.00
0005434989106	27556	Economy	3600.00
0005434980597	27556	Economy	3600.00
0005434980605	27556	Economy	3600.00
0005434989017	27556	Economy	3600.00
0005434980578	27556	Economy	3600.00
0005434989071	27556	Economy	3600.00
0005434989075	27556	Economy	3600.00
0005434989095	27556	Economy	3600.00
0005434989059	27556	Economy	3600.00
0005434980592	27556	Economy	3600.00
0005434989094	27556	Economy	3600.00
0005434980610	27556	Economy	3600.00
0005434980662	27556	Economy	3600.00
0005434980598	27556	Economy	3600.00
0005434980504	27556	Economy	3600.00
0005434989070	27556	Economy	3600.00
0005434980545	27556	Economy	3600.00
0005434989035	27556	Economy	3600.00
0005434980576	27556	Economy	3600.00
0005434980503	27556	Economy	3600.00
0005434988962	27556	Economy	3600.00
0005433111555	10272	Economy	19700.00
0005433111556	10272	Economy	19700.00
0005433111557	10272	Economy	19700.00
0005434302581	19589	Economy	19700.00
0005434302564	19589	Economy	19700.00
0005434302578	19589	Economy	19700.00
0005434302563	19589	Economy	19700.00
0005435925647	3561	Business	26900.00
0005435925693	3561	Business	26900.00
0005435925698	3561	Business	26900.00
0005435925652	3561	Business	26900.00
0005435939956	3561	Economy	9000.00
0005435925645	3561	Economy	9000.00
0005435925694	3561	Economy	9000.00
0005435925685	3561	Economy	9000.00
0005435925719	3561	Economy	9000.00
0005435925646	3561	Economy	9000.00
0005435925699	3561	Economy	9000.00
0005435925712	3561	Economy	9000.00
0005435925718	3561	Economy	9000.00
0005435925723	3561	Economy	9000.00
0005435925690	3561	Economy	9000.00
0005435925713	3561	Economy	9000.00
0005435939957	3561	Economy	9000.00
0005435939961	3561	Economy	9000.00
0005435070409	15319	Business	26900.00
0005435950334	15319	Business	26900.00
0005435070410	15319	Business	26900.00
0005435070514	15319	Business	26900.00
0005435070436	15319	Business	26900.00
0005435070477	15319	Economy	9000.00
0005435070488	15319	Economy	9000.00
0005435950320	15319	Economy	9900.00
0005435070449	15319	Economy	9000.00
0005435070402	15319	Economy	9000.00
0005435070503	15319	Economy	9000.00
0005435950337	15319	Economy	9000.00
0005435070273	15319	Economy	9000.00
0005435070476	15319	Economy	9000.00
0005435070495	15319	Economy	9000.00
0005435950310	15319	Economy	9000.00
0005435070537	15319	Economy	9000.00
0005435950330	15319	Economy	9000.00
0005435950335	15319	Economy	9000.00
0005435070515	15319	Economy	9000.00
0005435070408	15319	Economy	9000.00
0005435070454	15319	Economy	9000.00
0005435070430	15319	Economy	9000.00
0005435070401	15319	Economy	9000.00
0005435070382	15319	Economy	9000.00
0005432664197	26387	Economy	5900.00
0005432664196	26387	Economy	5900.00
0005432660870	26387	Economy	5900.00
0005433103595	44	Business	20000.00
0005432677676	44	Business	20000.00
0005433435525	44	Business	20000.00
0005433103658	44	Business	20000.00
0005433103969	44	Business	20000.00
0005433103982	44	Business	20000.00
0005433103693	44	Business	20000.00
0005433103766	44	Business	20000.00
0005433103768	44	Business	20000.00
0005433103940	44	Business	20000.00
0005433103824	44	Business	20000.00
0005433103696	44	Business	20000.00
0005433103794	44	Business	20000.00
0005433103853	44	Business	20000.00
0005433103691	44	Economy	7300.00
0005433103930	44	Economy	7300.00
0005432920460	44	Economy	7300.00
0005433103657	44	Economy	7300.00
0005433103790	44	Economy	6700.00
0005433103752	44	Economy	6700.00
0005433103980	44	Economy	6700.00
0005433103932	44	Economy	6700.00
0005433103667	44	Economy	6700.00
0005432920457	44	Economy	6700.00
0005433103735	44	Economy	6700.00
0005432920468	44	Economy	6700.00
0005433103842	44	Economy	6700.00
0005432902097	44	Economy	6700.00
0005433103725	44	Economy	6700.00
0005433103958	44	Economy	6700.00
0005433103756	44	Economy	6700.00
0005433103502	44	Economy	6700.00
0005433103892	44	Economy	6700.00
0005433103913	44	Economy	6700.00
0005433103865	44	Economy	6700.00
0005433103692	44	Economy	6700.00
0005433103939	44	Economy	6700.00
0005433103720	44	Economy	6700.00
0005433103762	44	Economy	6700.00
0005433103878	44	Economy	6700.00
0005432902105	44	Economy	6700.00
0005433103981	44	Economy	6700.00
0005433103646	44	Economy	6700.00
0005433103866	44	Economy	6700.00
0005433103893	44	Economy	6700.00
0005433435521	44	Economy	6700.00
0005433103687	44	Economy	6700.00
0005433103639	44	Economy	6700.00
0005433435517	44	Economy	6700.00
0005433103817	44	Economy	6700.00
0005433103599	44	Economy	6700.00
0005433103789	44	Economy	6700.00
0005433103827	44	Economy	6700.00
0005433103688	44	Economy	6700.00
0005433103447	44	Economy	6700.00
0005433103914	44	Economy	6700.00
0005432920450	44	Economy	6700.00
0005432902100	44	Economy	7300.00
0005433103795	44	Economy	7300.00
0005432920474	44	Economy	6700.00
0005433103594	44	Economy	6700.00
0005433103666	44	Economy	6700.00
0005433103750	44	Economy	6700.00
0005433103448	44	Economy	6700.00
0005433103891	44	Economy	6700.00
0005433103690	44	Economy	6700.00
0005432920461	44	Economy	6700.00
0005433103903	44	Economy	6700.00
0005433103765	44	Economy	6700.00
0005432902076	44	Economy	6700.00
0005432920458	44	Economy	6700.00
0005433103764	44	Economy	6700.00
0005433103637	44	Economy	6700.00
0005433103769	44	Economy	6700.00
0005433103804	44	Economy	6700.00
0005433103754	44	Economy	6700.00
0005433103751	44	Economy	6700.00
0005432920459	44	Economy	6700.00
0005433435529	44	Economy	6700.00
0005433435526	44	Economy	6700.00
0005433103838	44	Economy	6700.00
0005433103724	44	Economy	6700.00
0005433103659	44	Economy	6700.00
0005432902099	44	Economy	6700.00
0005433103931	44	Economy	6700.00
0005433103987	44	Economy	6700.00
0005433103767	44	Economy	6700.00
0005432902112	44	Economy	6700.00
0005433103665	44	Economy	6700.00
0005433103924	44	Economy	6700.00
0005433103680	44	Economy	6700.00
0005432920454	44	Economy	6700.00
0005433103854	44	Economy	6700.00
0005433103984	44	Economy	6700.00
0005432902077	44	Economy	6700.00
0005433103873	44	Economy	6700.00
0005432677685	44	Economy	6700.00
0005433103753	44	Economy	6700.00
0005433103699	44	Economy	6700.00
0005433103761	44	Economy	6700.00
0005433103638	44	Economy	6700.00
0005432902092	44	Economy	6700.00
0005433103694	44	Economy	6700.00
0005432753390	39	Business	20000.00
0005433687750	39	Business	20000.00
0005433690979	39	Business	20000.00
0005433687752	39	Economy	7300.00
0005432756918	39	Economy	6700.00
0005432756936	39	Economy	6700.00
0005433477084	8058	Business	20000.00
0005434157818	8058	Business	20000.00
0005434157808	8058	Business	20000.00
0005434157765	8058	Business	20000.00
0005433477251	8058	Business	20000.00
0005434157786	8058	Business	20000.00
0005434152868	8058	Economy	7300.00
0005434157774	8058	Economy	7300.00
0005433477162	8058	Economy	6700.00
0005433477161	8058	Economy	6700.00
0005434157807	8058	Economy	6700.00
0005434157815	8058	Economy	6700.00
0005434151819	8058	Economy	6700.00
0005434157776	8058	Economy	6700.00
0005434157825	8058	Economy	6700.00
0005434157764	8058	Economy	6700.00
0005433477154	8058	Economy	6700.00
0005434157826	8058	Economy	6700.00
0005434157728	8058	Economy	6700.00
0005434157737	8058	Economy	6700.00
0005434157773	8058	Economy	6700.00
0005434157775	8058	Economy	6700.00
0005434157732	8058	Economy	6700.00
0005434157812	8058	Economy	6700.00
0005434157795	8058	Economy	6700.00
0005434157835	8058	Economy	7300.00
0005433477233	8058	Economy	6700.00
0005434157787	8058	Economy	7300.00
0005434157803	8058	Economy	6700.00
0005434157738	8058	Economy	6700.00
0005434157824	8058	Economy	6700.00
0005434157772	8058	Economy	6700.00
0005434157804	8058	Economy	6700.00
0005434157811	8058	Economy	6700.00
0005434157763	8058	Economy	6700.00
0005434157736	8058	Economy	6700.00
0005434157817	8058	Economy	6700.00
0005434157731	8058	Economy	6700.00
0005433477109	8058	Economy	6700.00
0005434157800	8058	Economy	6700.00
0005434151818	8058	Economy	6700.00
0005433477044	8058	Economy	6700.00
0005433477095	8058	Economy	6700.00
0005432818237	8048	Economy	7300.00
0005432818315	8048	Economy	6700.00
0005432818309	8048	Economy	6700.00
0005432818306	8048	Economy	6700.00
0005432818214	8048	Economy	6700.00
0005432818281	8048	Economy	6700.00
0005432818324	8048	Economy	6700.00
0005432818304	8048	Economy	6700.00
0005432818305	8048	Economy	6700.00
0005432818311	8048	Economy	6700.00
0005432818310	8048	Economy	6700.00
0005432818201	8048	Economy	6700.00
0005432818234	8048	Economy	6700.00
0005432818273	8048	Economy	6700.00
0005432818213	8048	Economy	6700.00
0005432818245	8048	Economy	6700.00
0005432818244	8048	Economy	6700.00
0005435914203	3483	Business	35000.00
0005435903196	3483	Comfort	19900.00
0005435914201	3483	Comfort	19900.00
0005435914145	3483	Comfort	19900.00
0005435914080	3483	Comfort	19900.00
0005435903193	3483	Comfort	19900.00
0005435914096	3483	Comfort	19900.00
0005435841122	3483	Economy	11700.00
0005435914079	3483	Economy	11700.00
0005435914097	3483	Economy	11700.00
0005435903140	3483	Economy	11700.00
0005435903179	3483	Economy	11700.00
0005435914768	3483	Economy	11700.00
0005435914147	3483	Economy	11700.00
0005435903155	3483	Economy	11700.00
0005435914767	3483	Economy	11700.00
0005435903154	3483	Economy	11700.00
0005435903195	3483	Economy	11700.00
0005435914756	3483	Economy	11700.00
0005435914769	3483	Economy	11700.00
0005435914760	3483	Economy	11700.00
0005435914761	3483	Economy	11700.00
0005435914186	3483	Economy	12800.00
0005435914770	3483	Economy	11700.00
0005435914762	3483	Economy	11700.00
0005435841126	3483	Economy	11700.00
0005435914202	3483	Economy	11700.00
0005435914167	3483	Economy	11700.00
0005435903194	3483	Economy	11700.00
0005435841124	3483	Economy	11700.00
0005435914166	3483	Economy	11700.00
0005435914146	3483	Economy	11700.00
0005435914185	3483	Economy	11700.00
0005435841125	3483	Economy	11700.00
0005434880869	14580	Business	35000.00
0005432800262	14580	Business	35000.00
0005434880693	14580	Business	35000.00
0005432800247	14580	Business	35000.00
0005434880692	14580	Business	35000.00
0005434880518	14580	Business	35000.00
0005434880563	14580	Business	35000.00
0005435626844	14580	Business	35000.00
0005435127431	14580	Comfort	19900.00
0005435127423	14580	Comfort	19900.00
0005434880854	14580	Comfort	19900.00
0005435626725	14580	Comfort	19900.00
0005434880786	14580	Comfort	19900.00
0005434880827	14580	Comfort	19900.00
0005434938683	14580	Comfort	19900.00
0005434880696	14580	Comfort	19900.00
0005434880963	14580	Comfort	19900.00
0005434880561	14580	Comfort	19900.00
0005435127471	14580	Comfort	19900.00
0005435626758	14580	Comfort	19900.00
0005432800231	14580	Comfort	19900.00
0005435626773	14580	Comfort	19900.00
0005434880866	14580	Comfort	19900.00
0005434938604	14580	Comfort	19900.00
0005435626775	14580	Economy	11700.00
0005434427407	14580	Economy	11700.00
0005435626709	14580	Economy	11700.00
0005435626801	14580	Economy	11700.00
0005435626706	14580	Economy	11700.00
0005434880766	14580	Economy	11700.00
0005432800246	14580	Economy	11700.00
0005435626792	14580	Economy	11700.00
0005435127467	14580	Economy	11700.00
0005435127551	14580	Economy	11700.00
0005434427436	14580	Economy	11700.00
0005432611813	14580	Economy	11700.00
0005434880644	14580	Economy	11700.00
0005435626704	14580	Economy	11700.00
0005435127509	14580	Economy	11700.00
0005434880732	14580	Economy	11700.00
0005434880784	14580	Economy	11700.00
0005434938652	14580	Economy	11700.00
0005434427397	14580	Economy	11700.00
0005434427383	14580	Economy	11700.00
0005432800258	14580	Economy	11700.00
0005434880664	14580	Economy	11700.00
0005435127488	14580	Economy	11700.00
0005434880642	14580	Economy	11700.00
0005434938663	14580	Economy	11700.00
0005434427470	14580	Economy	11700.00
0005434427446	14580	Economy	11700.00
0005434880971	14580	Economy	11700.00
0005432611814	14580	Economy	11700.00
0005434880818	14580	Economy	11700.00
0005435127338	14580	Economy	12800.00
0005435127397	14580	Economy	11700.00
0005432607674	14580	Economy	11700.00
0005434427447	14580	Economy	11700.00
0005434880773	14580	Economy	11700.00
0005435626708	14580	Economy	11700.00
0005435626742	14580	Economy	11700.00
0005434880785	14580	Economy	11700.00
0005432607673	14580	Economy	11700.00
0005435127450	14580	Economy	11700.00
0005432800218	14580	Economy	11700.00
0005435626791	14580	Economy	11700.00
0005435127443	14580	Economy	11700.00
0005434427384	14580	Economy	11700.00
0005435626777	14580	Economy	11700.00
0005434880359	14580	Economy	11700.00
0005434880777	14580	Economy	11700.00
0005435626830	14580	Economy	11700.00
0005434427404	14580	Economy	11700.00
0005435626729	14580	Economy	11700.00
0005432800235	14580	Economy	11700.00
0005434880562	14580	Economy	11700.00
0005434880965	14580	Economy	11700.00
0005435127498	14580	Economy	11700.00
0005435626676	14580	Economy	11700.00
0005434880928	14580	Economy	11700.00
0005435626741	14580	Economy	11700.00
0005434880937	14580	Economy	11700.00
0005435127425	14580	Economy	11700.00
0005432607662	14580	Economy	11700.00
0005434880876	14580	Economy	11700.00
0005435127473	14580	Economy	11700.00
0005435626765	14580	Economy	11700.00
0005434880566	14580	Economy	11700.00
0005434880938	14580	Economy	11700.00
0005435626617	14580	Economy	11700.00
0005434938666	14580	Economy	11700.00
0005435626781	14580	Economy	11700.00
0005435626750	14580	Economy	11700.00
0005435626829	14580	Economy	11700.00
0005434880902	14580	Economy	11700.00
0005435127537	14580	Economy	11700.00
0005434880817	14580	Economy	11700.00
0005434880929	14580	Economy	11700.00
0005435127449	14580	Economy	11700.00
0005434880881	14580	Economy	11700.00
0005435626776	14580	Economy	11700.00
0005434880734	14580	Economy	11700.00
0005435127479	14580	Economy	11700.00
0005434880733	14580	Economy	11700.00
0005434880961	14580	Economy	11700.00
0005435127466	14580	Economy	11700.00
0005434938702	14580	Economy	11700.00
0005435626828	14580	Economy	11700.00
0005435626759	14580	Economy	12800.00
0005434938703	14580	Economy	11700.00
0005435626749	14580	Economy	11700.00
0005432607663	14580	Economy	11700.00
0005432800243	14580	Economy	11700.00
0005434880723	14580	Economy	11700.00
0005434427469	14580	Economy	11700.00
0005435127495	14580	Economy	11700.00
0005435626660	14580	Economy	11700.00
0005435626757	14580	Economy	11700.00
0005435626705	14580	Economy	11700.00
0005435127459	14580	Economy	11700.00
0005434880826	14580	Economy	11700.00
0005434880962	14580	Economy	11700.00
0005435626731	14580	Economy	11700.00
0005434938605	14580	Economy	11700.00
0005434880714	14580	Economy	11700.00
0005434427463	14580	Economy	11700.00
0005432800263	14580	Economy	11700.00
0005435127497	14580	Economy	11700.00
0005435626790	14580	Economy	11700.00
0005435626618	14580	Economy	11700.00
0005435626710	14580	Economy	11700.00
0005434880964	14580	Economy	11700.00
0005435127451	14580	Economy	11700.00
0005434880697	14580	Economy	11700.00
0005435127496	14580	Economy	11700.00
0005432800216	14580	Economy	11700.00
0005435127505	14580	Economy	11700.00
0005432800215	14580	Economy	11700.00
0005434880919	14580	Economy	11700.00
0005432800206	14580	Economy	11700.00
0005435626774	14580	Economy	11700.00
0005434880853	14580	Economy	11700.00
0005434938606	14580	Economy	11700.00
0005434427444	14580	Economy	11700.00
0005435127474	14580	Economy	11700.00
0005432800214	14580	Economy	11700.00
0005434880640	14580	Economy	11700.00
0005432800261	14580	Economy	11700.00
0005434880765	14580	Economy	11700.00
0005435626698	14580	Economy	11700.00
0005435626730	14580	Economy	11700.00
0005435127398	14580	Economy	11700.00
0005435626752	14580	Economy	11700.00
0005435890049	3586	Economy	14800.00
0005434312397	15641	Economy	16300.00
0005434312398	15641	Economy	14800.00
0005434325938	15641	Economy	14800.00
0005434325981	15641	Economy	14800.00
0005433420627	641	Economy	4100.00
0005435958122	15182	Economy	4100.00
0005435958111	15182	Economy	4100.00
0005435958075	15182	Economy	4100.00
0005435958098	15182	Economy	4100.00
0005435958089	15182	Economy	4100.00
0005435958095	15182	Economy	4100.00
0005435958126	15182	Economy	4100.00
0005435958105	15182	Economy	4100.00
0005435958118	15182	Economy	4100.00
0005435958127	15182	Economy	4100.00
0005435958077	15182	Economy	4100.00
0005435958117	15182	Economy	4100.00
0005435958084	15182	Economy	4100.00
0005435958099	15182	Economy	4100.00
0005435958088	15182	Economy	4100.00
0005435426858	8916	Economy	10400.00
0005435426860	8916	Economy	10400.00
0005435163371	29526	Economy	13400.00
0005435163367	29526	Economy	12200.00
0005435163380	29526	Economy	12200.00
0005435163370	29526	Economy	12200.00
0005435163363	29526	Economy	12200.00
0005435163364	29526	Economy	12200.00
0005435163365	29526	Economy	12200.00
0005435163354	29526	Economy	12200.00
0005435163362	29526	Economy	12200.00
0005435163387	29526	Economy	12200.00
0005433405024	2855	Economy	4200.00
0005433404993	2855	Economy	4200.00
0005433404986	2855	Economy	4200.00
0005435797872	29333	Economy	4200.00
0005435797863	29333	Economy	4200.00
0005435797871	29333	Economy	4200.00
0005435797884	29333	Economy	4200.00
0005435797862	29333	Economy	4200.00
0005434948263	16380	Economy	6800.00
0005433962336	25738	Business	21400.00
0005433962576	25738	Business	21400.00
0005433962274	25738	Business	21400.00
0005433962289	25738	Business	21400.00
0005433962449	25738	Business	21400.00
0005433962297	25738	Business	21400.00
0005433962271	25738	Business	21400.00
0005433962552	25738	Business	21400.00
0005433962471	25738	Business	21400.00
0005433962472	25738	Business	21400.00
0005433962312	25738	Business	21400.00
0005433962180	25738	Economy	7100.00
0005433962463	25738	Economy	7100.00
0005433962583	25738	Economy	7100.00
0005433962200	25738	Economy	7100.00
0005433962594	25738	Economy	7100.00
0005433962553	25738	Economy	7100.00
0005433962362	25738	Economy	7800.00
0005433962311	25738	Economy	7800.00
0005433962450	25738	Economy	7800.00
0005433962477	25738	Economy	7800.00
0005433962306	25738	Economy	7100.00
0005433962223	25738	Economy	7100.00
0005433962574	25738	Economy	7100.00
0005433962272	25738	Economy	7100.00
0005433962451	25738	Economy	7100.00
0005433962419	25738	Economy	7100.00
0005433962610	25738	Economy	7100.00
0005433962517	25738	Economy	7100.00
0005433962542	25738	Economy	7100.00
0005433962353	25738	Economy	7100.00
0005433962454	25738	Economy	7100.00
0005433962381	25738	Economy	7100.00
0005433962588	25738	Economy	7100.00
0005433962288	25738	Economy	7100.00
0005433962597	25738	Economy	7100.00
0005433962534	25738	Economy	7100.00
0005433962126	25738	Economy	7100.00
0005433962352	25738	Economy	7100.00
0005433962273	25738	Economy	7100.00
0005433962335	25738	Economy	7100.00
0005433962323	25738	Economy	7100.00
0005433962457	25738	Economy	7100.00
0005433962575	25738	Economy	7100.00
0005433962367	25738	Economy	7100.00
0005433962368	25738	Economy	7100.00
0005433962324	25738	Economy	7100.00
0005433962519	25738	Economy	7100.00
0005433962201	25738	Economy	7100.00
0005433962298	25738	Economy	7100.00
0005433962380	25738	Economy	7100.00
0005433962609	25738	Economy	7100.00
0005433962319	25738	Economy	7100.00
0005433962467	25738	Economy	7100.00
0005433962186	25738	Economy	7100.00
0005433962596	25738	Economy	7100.00
0005433962418	25738	Economy	7100.00
0005433962387	25738	Economy	7100.00
0005433962550	25738	Economy	7100.00
0005433962222	25738	Economy	7100.00
0005433962225	25738	Economy	7100.00
0005433962595	25738	Economy	7100.00
0005433962493	25738	Economy	7100.00
0005433962379	25738	Economy	7100.00
0005433962464	25738	Economy	7100.00
0005433962429	25738	Economy	7100.00
0005433962185	25738	Economy	7100.00
0005433962531	25738	Economy	7100.00
0005433962441	25738	Economy	7100.00
0005433962455	25738	Economy	7100.00
0005435083003	24525	Economy	3900.00
0005435083001	24525	Economy	3900.00
0005435083035	24525	Economy	3900.00
0005435083011	24525	Economy	3900.00
0005435083033	24525	Economy	3900.00
0005435083030	24525	Economy	3900.00
0005435083012	24525	Economy	3900.00
0005435083002	24525	Economy	3900.00
0005435083023	24525	Economy	3900.00
0005435286945	5068	Business	18000.00
0005435286770	5068	Business	18000.00
0005435286831	5068	Business	18000.00
0005435286830	5068	Business	18000.00
0005435286828	5068	Business	18000.00
0005435286988	5068	Business	18000.00
0005435287004	5068	Business	18000.00
0005435286832	5068	Business	18000.00
0005435287043	5068	Business	18000.00
0005435287037	5068	Business	18000.00
0005435287008	5068	Business	18000.00
0005435287010	5068	Economy	6600.00
0005435287036	5068	Economy	6600.00
0005435287009	5068	Economy	6000.00
0005435286891	5068	Economy	6000.00
0005435286768	5068	Economy	6000.00
0005435286900	5068	Economy	6000.00
0005435286954	5068	Economy	6000.00
0005435286858	5068	Economy	6000.00
0005435286897	5068	Economy	6000.00
0005435286829	5068	Economy	6000.00
0005435286906	5068	Economy	6000.00
0005435286955	5068	Economy	6000.00
0005435287044	5068	Economy	6000.00
0005435286863	5068	Economy	6000.00
0005433534556	5068	Economy	6000.00
0005435287023	5068	Economy	6000.00
0005435287003	5068	Economy	6000.00
0005435286890	5068	Economy	6000.00
0005435286844	5068	Economy	6000.00
0005435286909	5068	Economy	6000.00
0005435286965	5068	Economy	6000.00
0005435286816	5068	Economy	6000.00
0005435286850	5068	Economy	6000.00
0005435286769	5068	Economy	6000.00
0005435286982	5068	Economy	6000.00
0005435286837	5068	Economy	6000.00
0005433534561	5068	Economy	6000.00
0005435551773	5068	Economy	6000.00
0005434230288	5069	Economy	6000.00
0005435270077	5071	Business	18000.00
0005435007717	5071	Business	18000.00
0005432336371	5071	Business	18000.00
0005435270164	5071	Business	18000.00
0005435270106	5071	Business	18000.00
0005435007666	5071	Business	18000.00
0005435007683	5071	Business	18000.00
0005435007682	5071	Business	18000.00
0005432336331	5071	Business	18000.00
0005435270020	5071	Economy	6600.00
0005432336372	5071	Economy	6000.00
0005433815576	5071	Economy	6000.00
0005432336328	5071	Economy	6000.00
0005435270094	5071	Economy	6000.00
0005433815579	5071	Economy	6000.00
0005435007696	5071	Economy	6000.00
0005435007695	5071	Economy	6000.00
0005433815520	5071	Economy	6000.00
0005432336367	5071	Economy	6000.00
0005432336365	5071	Economy	6000.00
0005434311276	5071	Economy	6000.00
0005434311277	5071	Economy	6000.00
0005433685566	5071	Economy	6000.00
0005435270213	5071	Economy	6000.00
0005435270216	5071	Economy	6000.00
0005435270208	5071	Economy	6000.00
0005435270190	5071	Economy	6000.00
0005435270021	5071	Economy	6000.00
0005433815511	5071	Economy	6000.00
0005435007664	5071	Economy	6000.00
0005435270093	5071	Economy	6000.00
0005435270019	5071	Economy	6000.00
0005435270209	5071	Economy	6000.00
0005435270199	5071	Economy	6600.00
0005434311273	5071	Economy	6000.00
0005435270215	5071	Economy	6000.00
0005435007697	5071	Economy	6000.00
0005435270188	5071	Economy	6000.00
0005435007636	5071	Economy	6000.00
0005435007637	5071	Economy	6000.00
0005432336366	5071	Economy	6000.00
0005435007623	5071	Economy	6000.00
0005435270201	5071	Economy	6000.00
0005435007662	5071	Economy	6000.00
0005435007665	5071	Economy	6000.00
0005433815524	5071	Economy	6000.00
0005435270189	5071	Economy	6000.00
0005435270092	5071	Economy	6000.00
0005435270128	5071	Economy	6000.00
0005432336368	5071	Economy	6000.00
0005433815577	5071	Economy	6000.00
0005435007624	5071	Economy	6000.00
0005435007715	5071	Economy	6000.00
0005433815580	5071	Economy	6000.00
0005434311274	5071	Economy	6000.00
0005434245815	8377	Business	18000.00
0005433786018	8377	Business	18000.00
0005432663092	8377	Business	18000.00
0005434245778	8377	Business	18000.00
0005434245845	8377	Business	18000.00
0005432659762	8377	Business	18000.00
0005433786102	8377	Business	18000.00
0005434245805	8377	Business	18000.00
0005433786087	8377	Business	18000.00
0005433786028	8377	Economy	6600.00
0005433786116	8377	Economy	6600.00
0005433785948	8377	Economy	6600.00
0005433786143	8377	Economy	6000.00
0005433785874	8377	Economy	6000.00
0005433786076	8377	Economy	6000.00
0005433786019	8377	Economy	6000.00
0005433786080	8377	Economy	6000.00
0005434245793	8377	Economy	6000.00
0005433786077	8377	Economy	6000.00
0005433785980	8377	Economy	6000.00
0005434245812	8377	Economy	6000.00
0005434245836	8377	Economy	6000.00
0005433786111	8377	Economy	6000.00
0005433786154	8377	Economy	6000.00
0005434245806	8377	Economy	6000.00
0005434245834	8377	Economy	6000.00
0005433786117	8377	Economy	6600.00
0005434245821	8377	Economy	6000.00
0005434245730	8377	Economy	6000.00
0005434245808	8377	Economy	6000.00
0005432663097	8377	Economy	6000.00
0005433786149	8377	Economy	6000.00
0005433786086	8377	Economy	6000.00
0005433786122	8377	Economy	6000.00
0005433786110	8377	Economy	6000.00
0005433785947	8377	Economy	6000.00
0005433786107	8377	Economy	6000.00
0005432659763	8377	Economy	6000.00
0005434245803	8377	Economy	6000.00
0005434245811	8377	Economy	6000.00
0005433786151	8377	Economy	6000.00
0005434245822	8377	Economy	6000.00
0005434245843	8377	Economy	6000.00
0005434245807	8377	Economy	6000.00
0005434245708	8377	Economy	6000.00
0005434245844	8377	Economy	6000.00
0005434245773	8377	Economy	6000.00
0005433786142	8377	Economy	6000.00
0005434245804	8377	Economy	6000.00
0005433785918	8377	Economy	6000.00
0005433786103	8377	Economy	6000.00
0005434245777	8377	Economy	6000.00
0005433786150	8377	Economy	6000.00
0005433616288	8376	Business	18000.00
0005433616405	8376	Business	18000.00
0005433616624	8376	Business	18000.00
0005433616781	8376	Business	18000.00
0005433616710	8376	Business	18000.00
0005433616646	8376	Business	18000.00
0005433616678	8376	Business	18000.00
0005433616660	8376	Business	18000.00
0005433616652	8376	Business	18000.00
0005434230066	8376	Business	18000.00
0005433616632	8376	Business	18000.00
0005433616759	8376	Business	18000.00
0005433616633	8376	Economy	6600.00
0005433616760	8376	Economy	6600.00
0005433616644	8376	Economy	6600.00
0005433616792	8376	Economy	6000.00
0005433616496	8376	Economy	6000.00
0005434230075	8376	Economy	6000.00
0005433616776	8376	Economy	6000.00
0005433616755	8376	Economy	6000.00
0005433616599	8376	Economy	6000.00
0005434230072	8376	Economy	6000.00
0005433616722	8376	Economy	6000.00
0005433616793	8376	Economy	6000.00
0005434230073	8376	Economy	6000.00
0005433616698	8376	Economy	6000.00
0005433616749	8376	Economy	6000.00
0005433616625	8376	Economy	6000.00
0005433616783	8376	Economy	6000.00
0005433616498	8376	Economy	6000.00
0005433616714	8376	Economy	6000.00
0005433616605	8376	Economy	6000.00
0005433616748	8376	Economy	6000.00
0005433616589	8376	Economy	6000.00
0005434230067	8376	Economy	6600.00
0005433616782	8376	Economy	6000.00
0005433616706	8376	Economy	6000.00
0005434230063	8376	Economy	6000.00
0005433616639	8376	Economy	6000.00
0005433616719	8376	Economy	6000.00
0005433616790	8376	Economy	6000.00
0005433616711	8376	Economy	6000.00
0005433616723	8376	Economy	6000.00
0005434230082	8376	Economy	6000.00
0005433616786	8376	Economy	6000.00
0005433616679	8376	Economy	6000.00
0005433616434	8376	Economy	6000.00
0005433616794	8376	Economy	6000.00
0005434230074	8376	Economy	6000.00
0005433616795	8376	Economy	6000.00
0005433616497	8376	Economy	6000.00
0005433616784	8376	Economy	6000.00
0005433616785	8376	Economy	6000.00
0005433616435	8376	Economy	6000.00
0005433616647	8376	Economy	6000.00
0005433616612	8376	Economy	6000.00
0005434229997	8375	Business	18000.00
0005434229980	8375	Business	18000.00
0005434230023	8375	Business	18000.00
0005434229967	8375	Business	18000.00
0005434230024	8375	Business	18000.00
0005434230020	8375	Business	18000.00
0005434265721	8375	Business	18000.00
0005434230014	8375	Economy	6600.00
0005434173628	8375	Economy	6000.00
0005434265872	8375	Economy	6000.00
0005434265814	8375	Economy	6000.00
0005434265853	8375	Economy	6000.00
0005434265893	8375	Economy	6000.00
0005434265869	8375	Economy	6000.00
0005434230019	8375	Economy	6000.00
0005434150052	8375	Economy	6000.00
0005434265851	8375	Economy	6000.00
0005434265858	8375	Economy	6000.00
0005434265860	8375	Economy	6000.00
0005434150051	8375	Economy	6000.00
0005434150041	8375	Economy	6000.00
0005434150039	8375	Economy	6000.00
0005434265835	8375	Economy	6600.00
0005434229966	8375	Economy	6600.00
0005434265870	8375	Economy	6000.00
0005434230021	8375	Economy	6600.00
0005434150069	8375	Economy	6000.00
0005434265852	8375	Economy	6000.00
0005434229979	8375	Economy	6000.00
0005434265884	8375	Economy	6000.00
0005434265871	8375	Economy	6000.00
0005434230018	8375	Economy	6000.00
0005434150040	8375	Economy	6000.00
0005434265859	8375	Economy	6000.00
0005434150068	8375	Economy	6000.00
0005434265868	8375	Economy	6000.00
0005434150075	8375	Economy	6000.00
0005434640061	12590	Economy	14800.00
0005434639986	12590	Economy	14800.00
0005434640010	12590	Economy	14800.00
0005434640070	12590	Economy	14800.00
0005434640073	12590	Economy	14800.00
0005434640009	12590	Economy	14800.00
0005434639985	12590	Economy	14800.00
0005434640042	12590	Economy	14800.00
0005434640069	12590	Economy	14800.00
0005434640062	12590	Economy	14800.00
0005434640074	12590	Economy	14800.00
0005434640043	12590	Economy	14800.00
0005434640008	12590	Economy	14800.00
0005434640030	12590	Economy	14800.00
0005434640039	12590	Economy	14800.00
0005434640037	12590	Economy	14800.00
0005432290726	23349	Economy	14800.00
0005433202693	23349	Economy	14800.00
0005433202702	23349	Economy	14800.00
0005433202751	23349	Economy	14800.00
0005432384176	21070	Business	18900.00
0005432330025	21070	Business	18900.00
0005432384110	21070	Business	18900.00
0005432384215	21070	Business	18900.00
0005432384109	21070	Business	18900.00
0005432384111	21070	Business	18900.00
0005432384229	21070	Business	18900.00
0005432329829	21070	Business	18900.00
0005432329958	21070	Business	18900.00
0005432329965	21070	Economy	6300.00
0005432329938	21070	Economy	6300.00
0005432330008	21070	Economy	6300.00
0005432329874	21070	Economy	6300.00
0005432384196	21070	Economy	6300.00
0005432384307	21070	Economy	6300.00
0005432384108	21070	Economy	6300.00
0005432384228	21070	Economy	6300.00
0005432384180	21070	Economy	6300.00
0005432329889	21070	Economy	6900.00
0005432329968	21070	Economy	6900.00
0005432330001	21070	Economy	6900.00
0005432329952	21070	Economy	6300.00
0005432329940	21070	Economy	6300.00
0005432384177	21070	Economy	6300.00
0005432329873	21070	Economy	6300.00
0005432329875	21070	Economy	6300.00
0005432329939	21070	Economy	6300.00
0005432329886	21070	Economy	6300.00
0005432384248	21070	Economy	6300.00
0005432330029	21070	Economy	6300.00
0005432384141	21070	Economy	6300.00
0005432384113	21070	Economy	6300.00
0005432329906	21070	Economy	6300.00
0005432329973	21070	Economy	6300.00
0005432329964	21070	Economy	6300.00
0005432384222	21070	Economy	6300.00
0005432384140	21070	Economy	6300.00
0005432384112	21070	Economy	6300.00
0005432329890	21070	Economy	6300.00
0005432330053	21070	Economy	6300.00
0005432329937	21070	Economy	6300.00
0005432384161	21070	Economy	6300.00
0005432329987	21070	Economy	6300.00
0005432384231	21070	Economy	6300.00
0005432384258	21070	Economy	6300.00
0005432384257	21070	Economy	6300.00
0005432329828	21070	Economy	6300.00
0005432329986	21070	Economy	6300.00
0005432329959	21070	Economy	6300.00
0005432329943	21070	Economy	6300.00
0005432329936	21070	Economy	6300.00
0005432384243	21070	Economy	6300.00
0005432384221	21070	Economy	6300.00
0005432384294	21070	Economy	6300.00
0005432384290	21070	Economy	6300.00
0005432329969	21070	Economy	6300.00
0005432384181	21070	Economy	6300.00
0005432330000	21070	Economy	6300.00
0005432384186	21070	Economy	6300.00
0005432384293	21070	Economy	6300.00
0005432384343	31226	Economy	6900.00
0005432848874	31226	Economy	6300.00
0005432425880	30778	Business	12700.00
0005432425687	30778	Business	12700.00
0005432425752	30778	Business	12700.00
0005432425721	30778	Business	12700.00
0005432425871	30778	Business	12700.00
0005432425722	30778	Business	12700.00
0005432425938	30778	Business	12700.00
0005432426025	30778	Business	12700.00
0005432425840	30778	Business	12700.00
0005432425920	30778	Business	12700.00
0005432425857	30778	Economy	4200.00
0005432425952	30778	Economy	4200.00
0005432426014	30778	Economy	4200.00
0005432425663	30778	Economy	4200.00
0005432425701	30778	Economy	4200.00
0005432425847	30778	Economy	4200.00
0005432425811	30778	Economy	4700.00
0005432425926	30778	Economy	4700.00
0005432425850	30778	Economy	4700.00
0005432425899	30778	Economy	4200.00
0005432425747	30778	Economy	4200.00
0005432425802	30778	Economy	4200.00
0005432425755	30778	Economy	4200.00
0005432425908	30778	Economy	4200.00
0005432425814	30778	Economy	4200.00
0005432425974	30778	Economy	4200.00
0005432425861	30778	Economy	4200.00
0005432425937	30778	Economy	4200.00
0005432425845	30778	Economy	4200.00
0005432425879	30778	Economy	4200.00
0005432425575	30778	Economy	4200.00
0005432425702	30778	Economy	4200.00
0005432425921	30778	Economy	4200.00
0005432425953	30778	Economy	4200.00
0005432425846	30778	Economy	4200.00
0005432425720	30778	Economy	4200.00
0005432425723	30778	Economy	4200.00
0005432425855	30778	Economy	4200.00
0005432425992	30778	Economy	4200.00
0005432425876	30778	Economy	4200.00
0005432425815	30778	Economy	4200.00
0005432425751	30778	Economy	4200.00
0005432425762	30778	Economy	4200.00
0005432425916	30778	Economy	4200.00
0005432425674	30778	Economy	4200.00
0005432425909	30778	Economy	4200.00
0005432425789	30778	Economy	4200.00
0005432425868	30778	Economy	4200.00
0005432425838	30778	Economy	4200.00
0005432425813	30778	Economy	4200.00
0005432425761	30778	Economy	4200.00
0005432426054	30778	Economy	4200.00
0005432425812	30778	Economy	4200.00
0005432425739	30778	Economy	4200.00
0005432425787	30778	Economy	4200.00
0005432425734	30778	Economy	4200.00
0005432425867	30778	Economy	4200.00
0005432425975	30778	Economy	4200.00
0005432425662	30778	Economy	4200.00
0005432425760	30778	Economy	4200.00
0005432425664	30778	Economy	4200.00
0005432425756	30778	Economy	4200.00
0005432426011	30778	Economy	4200.00
0005432425904	30778	Economy	4200.00
0005432425856	30778	Economy	4200.00
0005432425925	30778	Economy	4200.00
0005432902084	9588	Business	32600.00
0005434186281	9588	Business	32600.00
0005434157703	9588	Business	32600.00
0005432902083	9588	Economy	10900.00
0005434157695	9588	Economy	11900.00
0005434186285	9588	Economy	10900.00
0005432902107	9588	Economy	10900.00
0005432902095	9588	Economy	10900.00
0005434157702	9588	Economy	10900.00
0005432902096	9588	Economy	10900.00
0005434157711	9588	Economy	10900.00
0005432902085	9588	Economy	10900.00
0005432822395	28991	Business	32600.00
0005434448413	28991	Business	32600.00
0005432818306	28991	Business	32600.00
0005432822427	28991	Economy	10900.00
0005432818281	28991	Economy	10900.00
0005432818213	28991	Economy	10900.00
0005432822425	28991	Economy	10900.00
0005432818214	28991	Economy	11900.00
0005434448414	28991	Economy	11900.00
0005432818237	28991	Economy	10900.00
0005432822426	28991	Economy	10900.00
0005432818311	28991	Economy	10900.00
0005432818234	28991	Economy	10900.00
0005432822420	28991	Economy	10900.00
0005432822396	28991	Economy	10900.00
0005432818315	28991	Economy	10900.00
0005434448415	28991	Economy	10900.00
0005432818304	28991	Economy	10900.00
0005432818273	28991	Economy	10900.00
0005432818310	28991	Economy	10900.00
0005432818305	28991	Economy	10900.00
0005434448403	28991	Economy	10900.00
0005432822429	28991	Economy	10900.00
0005432818245	28991	Economy	10900.00
0005432822428	28991	Economy	10900.00
0005432818201	28991	Economy	10900.00
0005432822421	28991	Economy	10900.00
0005432818309	28991	Economy	10900.00
0005432818324	28991	Economy	10900.00
0005432822383	28991	Economy	10900.00
0005432818244	28991	Economy	10900.00
0005435841126	15066	Economy	11000.00
0005435841124	15066	Economy	11000.00
0005435841122	15066	Economy	11000.00
0005435841125	15066	Economy	11000.00
0005432607674	31547	Economy	11000.00
0005432611813	31547	Economy	11000.00
0005432607662	31547	Economy	11000.00
0005432607663	31547	Economy	11000.00
0005432611814	31547	Economy	11000.00
0005432607673	31547	Economy	11000.00
0005432949595	11857	Business	105900.00
0005432949526	11857	Business	105900.00
0005432949557	11857	Economy	35300.00
0005432949586	11857	Economy	35300.00
0005432949561	11857	Economy	35300.00
0005432949552	11857	Economy	38800.00
0005432949469	11857	Economy	38800.00
0005432949587	11857	Economy	35300.00
0005432949602	11857	Economy	35300.00
0005432949522	11857	Economy	35300.00
0005432949559	11857	Economy	35300.00
0005432949601	11857	Economy	35300.00
0005432949558	11857	Economy	35300.00
0005432949549	11857	Economy	35300.00
0005432949527	11857	Economy	35300.00
0005432949572	11857	Economy	35300.00
0005432949548	11857	Economy	35300.00
0005432949570	11857	Economy	35300.00
0005432949613	11857	Economy	35300.00
0005432949535	11857	Economy	35300.00
0005432949562	11857	Economy	35300.00
0005432949489	11857	Economy	35300.00
0005432949490	11857	Economy	35300.00
0005432949614	11857	Economy	35300.00
0005432949596	11857	Economy	35300.00
0005432949650	11857	Economy	35300.00
0005432949534	11857	Economy	35300.00
0005433570804	25275	Business	105900.00
0005433570805	25275	Business	105900.00
0005433570646	25275	Business	105900.00
0005433570867	25275	Business	105900.00
0005433570788	25275	Business	105900.00
0005433570767	25275	Business	105900.00
0005433570909	25275	Business	105900.00
0005433570848	25275	Business	105900.00
0005433570810	25275	Business	105900.00
0005433570803	25275	Economy	35300.00
0005433570836	25275	Economy	35300.00
0005433570901	25275	Economy	35300.00
0005433570666	25275	Economy	35300.00
0005433570837	25275	Economy	35300.00
0005433570647	25275	Economy	35300.00
0005433570873	25275	Economy	35300.00
0005433570766	25275	Economy	35300.00
0005433570846	25275	Economy	38800.00
0005433570655	25275	Economy	35300.00
0005433570611	25275	Economy	35300.00
0005433570683	25275	Economy	35300.00
0005433570690	25275	Economy	35300.00
0005433570707	25275	Economy	35300.00
0005433570859	25275	Economy	35300.00
0005433570861	25275	Economy	35300.00
0005433570849	25275	Economy	35300.00
0005433570795	25275	Economy	35300.00
0005433570857	25275	Economy	35300.00
0005433570656	25275	Economy	35300.00
0005433570626	25275	Economy	35300.00
0005433570845	25275	Economy	35300.00
0005433570696	25275	Economy	35300.00
0005433570872	25275	Economy	35300.00
0005433570902	25275	Economy	35300.00
0005433570774	25275	Economy	35300.00
0005433570778	25275	Economy	35300.00
0005433570792	25275	Economy	35300.00
0005433570614	25275	Economy	35300.00
0005433570802	25275	Economy	35300.00
0005433570982	25275	Economy	35300.00
0005433570471	25275	Economy	35300.00
0005433570793	25275	Economy	35300.00
0005433570613	25275	Economy	35300.00
0005433570787	25275	Economy	35300.00
0005433570548	25275	Economy	35300.00
0005433570850	25275	Economy	35300.00
0005433570681	25275	Economy	35300.00
0005433570691	25275	Economy	35300.00
0005433570638	25275	Economy	35300.00
0005433570786	25275	Economy	35300.00
0005433570639	25275	Economy	35300.00
0005433570706	25275	Economy	35300.00
0005433570695	25275	Economy	35300.00
0005433570610	25275	Economy	35300.00
0005433570896	25275	Economy	35300.00
0005433570773	25275	Economy	35300.00
0005435340683	5412	Economy	22400.00
0005435555427	5412	Economy	24600.00
0005435555429	5412	Economy	22400.00
0005435340684	5412	Economy	22400.00
0005435555428	5412	Economy	22400.00
0005435340677	5412	Economy	22400.00
0005434655484	12508	Business	67200.00
0005434655355	12508	Business	67200.00
0005434655508	12508	Economy	22400.00
0005434655541	12508	Economy	22400.00
0005434655467	12508	Economy	24600.00
0005434655479	12508	Economy	22400.00
0005434655485	12508	Economy	22400.00
0005434655357	12508	Economy	22400.00
0005434655542	12508	Economy	22400.00
0005434655478	12508	Economy	22400.00
0005434655495	12508	Economy	22400.00
0005434655431	12508	Economy	22400.00
0005434655356	12508	Economy	22400.00
0005432429012	7416	Business	32000.00
0005432429013	7416	Business	32000.00
0005435266335	7416	Economy	10700.00
0005435266324	7416	Economy	10700.00
0005435266331	7416	Economy	10700.00
0005433717375	29237	Business	32000.00
0005433717403	29237	Business	32000.00
0005433722457	29237	Business	32000.00
0005433722397	29237	Business	32000.00
0005433717239	29237	Business	32000.00
0005433717382	29237	Business	32000.00
0005433656756	29237	Economy	10700.00
0005433722501	29237	Economy	10700.00
0005433722404	29237	Economy	10700.00
0005433719235	29237	Economy	10700.00
0005433722460	29237	Economy	10700.00
0005433722414	29237	Economy	10700.00
0005433722447	29237	Economy	10700.00
0005433722461	29237	Economy	10700.00
0005433722473	29237	Economy	10700.00
0005433722451	29237	Economy	10700.00
0005433717306	29237	Economy	11700.00
0005433717394	29237	Economy	11700.00
0005433685566	29237	Economy	10700.00
0005433717238	29237	Economy	10700.00
0005433722459	29237	Economy	10700.00
0005433717422	29237	Economy	10700.00
0005433717404	29237	Economy	10700.00
0005433717392	29237	Economy	10700.00
0005433717355	29237	Economy	10700.00
0005433722427	29237	Economy	10700.00
0005433717391	29237	Economy	10700.00
0005433717259	29237	Economy	10700.00
0005433717307	29237	Economy	10700.00
0005433717308	29237	Economy	10700.00
0005433722458	29237	Economy	10700.00
0005433717170	29237	Economy	10700.00
0005433717413	29237	Economy	10700.00
0005433717171	29237	Economy	10700.00
0005433722419	29237	Economy	10700.00
0005433717381	29237	Economy	10700.00
0005433719228	29237	Economy	10700.00
0005433717383	29237	Economy	10700.00
0005433717354	29237	Economy	10700.00
0005433717372	29237	Economy	10700.00
0005433722432	29237	Economy	10700.00
0005433717376	29237	Economy	10700.00
0005435860704	8658	Business	36500.00
0005435860667	8658	Business	36500.00
0005435860666	8658	Economy	12200.00
0005435860648	8658	Economy	13400.00
0005434184719	8658	Economy	13400.00
0005434182524	8658	Economy	12200.00
0005435860703	8658	Economy	12200.00
0005435860705	8658	Economy	12200.00
0005434182531	8658	Economy	12200.00
0005435860730	8658	Economy	12200.00
0005434182528	8658	Economy	12200.00
0005435860647	8658	Economy	12200.00
0005435860687	8658	Economy	12200.00
0005434182533	8658	Economy	12200.00
0005435860665	8658	Economy	12200.00
0005435860686	8658	Economy	12200.00
0005435860706	8658	Economy	12200.00
0005435860649	8658	Economy	12200.00
0005434184716	8658	Economy	12200.00
0005434182545	8658	Economy	12200.00
0005434184720	8658	Economy	12200.00
0005434182511	8658	Economy	12200.00
0005435860651	8658	Economy	12200.00
0005434182532	8658	Economy	12200.00
0005435860714	8658	Economy	12200.00
0005434143819	11675	Business	36500.00
0005434143767	11675	Business	36500.00
0005434143844	11675	Economy	12200.00
0005434095629	11675	Economy	12200.00
0005434143789	11675	Economy	12200.00
0005434326087	11675	Economy	13400.00
0005434326301	11675	Economy	12200.00
0005434095645	11675	Economy	12200.00
0005434095646	11675	Economy	12200.00
0005434143776	11675	Economy	12200.00
0005434143833	11675	Economy	12200.00
0005434095651	11675	Economy	12200.00
0005434143816	11675	Economy	12200.00
0005434143821	11675	Economy	12200.00
0005434095650	11675	Economy	12200.00
0005434095683	11675	Economy	12200.00
0005434143804	11675	Economy	12200.00
0005434326088	11675	Economy	12200.00
0005433399370	1413	Business	33000.00
0005433399331	1413	Business	33000.00
0005433399269	1413	Business	33000.00
0005433399443	1413	Business	33000.00
0005433399428	1413	Business	33000.00
0005433399424	1413	Economy	11000.00
0005433399417	1413	Economy	11000.00
0005433399400	1413	Economy	11000.00
0005433399325	1413	Economy	11000.00
0005433399356	1413	Economy	11000.00
0005433399463	1413	Economy	12100.00
0005433399452	1413	Economy	11000.00
0005433399425	1413	Economy	11000.00
0005433399336	1413	Economy	11000.00
0005433399345	1413	Economy	11000.00
0005433399326	1413	Economy	11000.00
0005433399330	1413	Economy	11000.00
0005433399228	1413	Economy	11000.00
0005433399309	1413	Economy	11000.00
0005433399442	1413	Economy	11000.00
0005433399399	1413	Economy	11000.00
0005433399195	1413	Economy	11000.00
0005433399450	1413	Economy	11000.00
0005433399307	1413	Economy	11000.00
0005433399308	1413	Economy	11000.00
0005433399429	1413	Economy	11000.00
0005433399284	1413	Economy	11000.00
0005433399449	1413	Economy	11000.00
0005433399321	1413	Economy	11000.00
0005433399423	1413	Economy	11000.00
0005433399456	1413	Economy	11000.00
0005433399357	1413	Economy	11000.00
0005433399398	1413	Economy	11000.00
0005435732700	19234	Business	33000.00
0005435732715	19234	Business	33000.00
0005435732714	19234	Business	33000.00
0005433457081	19234	Economy	11000.00
0005435732692	19234	Economy	11000.00
0005435732668	19234	Economy	11000.00
0005433457084	19234	Economy	12100.00
0005433457080	19234	Economy	11000.00
0005435732652	19234	Economy	11000.00
0005435732710	19234	Economy	11000.00
0005435732711	19234	Economy	11000.00
0005433457082	19234	Economy	11000.00
0005434444160	17380	Economy	15600.00
0005434444086	17380	Economy	15600.00
0005434444123	17380	Economy	15600.00
0005434444122	17380	Economy	14100.00
0005434444161	17380	Economy	14100.00
0005434444119	17380	Economy	14100.00
0005434444116	17380	Economy	14100.00
0005434444124	17380	Economy	14100.00
0005434444125	17380	Economy	14100.00
0005434444118	17380	Economy	14100.00
0005434444087	17380	Economy	14100.00
0005434444157	17380	Economy	14100.00
0005434444117	17380	Economy	14100.00
0005434444126	17380	Economy	14100.00
0005434444156	17380	Economy	14100.00
0005434444121	17380	Economy	14100.00
0005434444128	17380	Economy	14100.00
0005435893837	4491	Economy	14000.00
0005434183638	4491	Economy	14000.00
0005435893838	4491	Economy	14000.00
0005435893834	4491	Economy	14000.00
0005434183639	4491	Economy	14000.00
0005434326061	29668	Economy	14000.00
0005434352010	29668	Economy	14000.00
0005434326060	29668	Economy	14000.00
0005434352063	29668	Economy	14000.00
0005434352062	29668	Economy	14000.00
0005433345970	1042	Business	30600.00
0005433345746	1042	Business	30600.00
0005433269854	1042	Business	30600.00
0005433345878	1042	Business	30600.00
0005433345850	1042	Business	30600.00
0005433345907	1042	Business	30600.00
0005433345728	1042	Business	30600.00
0005433346003	1042	Economy	11200.00
0005433345698	1042	Economy	11200.00
0005433345948	1042	Economy	11200.00
0005433345758	1042	Economy	10200.00
0005433345967	1042	Economy	10200.00
0005433346004	1042	Economy	10200.00
0005433345928	1042	Economy	10200.00
0005433345750	1042	Economy	10200.00
0005433345818	1042	Economy	10200.00
0005433346039	1042	Economy	10200.00
0005433346041	1042	Economy	10200.00
0005433345834	1042	Economy	10200.00
0005433345499	1042	Economy	10200.00
0005433345729	1042	Economy	10200.00
0005433345955	1042	Economy	10200.00
0005433345699	1042	Economy	10200.00
0005433345974	1042	Economy	10200.00
0005433346008	1042	Economy	10200.00
0005433345708	1042	Economy	10200.00
0005433159376	1042	Economy	10200.00
0005433345868	1042	Economy	10200.00
0005433269865	1042	Economy	10200.00
0005433345798	1042	Economy	10200.00
0005433345663	1042	Economy	10200.00
0005433345747	1042	Economy	10200.00
0005433345864	1042	Economy	10200.00
0005433345757	1042	Economy	10200.00
0005433345788	1042	Economy	10200.00
0005433345981	1042	Economy	10200.00
0005433345869	1042	Economy	10200.00
0005433345969	1042	Economy	10200.00
0005433345844	1042	Economy	10200.00
0005433345664	1042	Economy	10200.00
0005433345820	1042	Economy	10200.00
0005433345851	1042	Economy	10200.00
0005433269843	1042	Economy	10200.00
0005433345500	1042	Economy	10200.00
0005433345956	1042	Economy	10200.00
0005433345745	1042	Economy	10200.00
0005433345843	1042	Economy	10200.00
0005433345797	1042	Economy	10200.00
0005433345763	1042	Economy	11200.00
0005433345985	1042	Economy	10200.00
0005433345893	1042	Economy	10200.00
0005433345684	1042	Economy	10200.00
0005433158195	1042	Economy	10200.00
0005433159373	1042	Economy	10200.00
0005433345879	1042	Economy	10200.00
0005433345819	1042	Economy	10200.00
0005433345980	1042	Economy	10200.00
0005433346005	1042	Economy	10200.00
0005433345749	1042	Economy	10200.00
0005433345748	1042	Economy	10200.00
0005433345882	1042	Economy	10200.00
0005433345719	1042	Economy	10200.00
0005433345886	1042	Economy	10200.00
0005433345810	1042	Economy	10200.00
0005433345643	1042	Economy	10200.00
0005433345966	1042	Economy	10200.00
0005433345898	1042	Economy	10200.00
0005433346035	1042	Economy	10200.00
0005433269842	1042	Economy	10200.00
0005433345828	1042	Economy	10200.00
0005433345892	1042	Economy	10200.00
0005433346040	1042	Economy	10200.00
0005435530144	17061	Business	30600.00
0005435545988	17061	Business	30600.00
0005435530182	17061	Business	30600.00
0005435092352	17061	Business	30600.00
0005435530137	17061	Economy	10200.00
0005435092357	17061	Economy	10200.00
0005435545989	17061	Economy	10200.00
0005435545987	17061	Economy	10200.00
0005434445314	17061	Economy	10200.00
0005435092358	17061	Economy	10200.00
0005435508826	17061	Economy	10200.00
0005435545990	17061	Economy	10200.00
0005434445319	17061	Economy	10200.00
0005435530106	17061	Economy	10200.00
0005434445320	17061	Economy	10200.00
0005433346091	17061	Economy	10200.00
0005435508743	17061	Economy	10200.00
0005435530156	17061	Economy	10200.00
0005435508813	17061	Economy	10200.00
0005435530143	17061	Economy	10200.00
0005434445309	17061	Economy	10200.00
0005435530179	17061	Economy	10200.00
0005433346092	17061	Economy	10200.00
0005435508695	17061	Economy	10200.00
0005434445322	17061	Economy	10200.00
0005435508770	17061	Economy	10200.00
0005435508732	17061	Economy	10200.00
0005435530155	17061	Economy	10200.00
0005435092339	17061	Economy	10200.00
0005435545992	17061	Economy	10200.00
0005435508778	17061	Economy	10200.00
0005435530145	17061	Economy	10200.00
0005435545985	17061	Economy	10200.00
0005435530183	17061	Economy	10200.00
0005435508771	17061	Economy	10200.00
0005435508740	17061	Economy	10200.00
0005434445311	17061	Economy	10200.00
0005435545986	17061	Economy	10200.00
0005435530132	17061	Economy	10200.00
0005435508829	17061	Economy	10200.00
0005435530141	17061	Economy	10200.00
0005434082330	12780	Business	40300.00
0005434069246	12780	Business	40300.00
0005434069643	12780	Business	40300.00
0005434069537	12780	Business	40300.00
0005434082605	12780	Business	40300.00
0005434069391	12780	Business	40300.00
0005434082375	12780	Business	40300.00
0005434069422	12780	Economy	13400.00
0005434069163	12780	Economy	13400.00
0005434069445	12780	Economy	13400.00
0005434069556	12780	Economy	13400.00
0005434069456	12780	Economy	13400.00
0005434069397	12780	Economy	13400.00
0005434069357	12780	Economy	13400.00
0005434069430	12780	Economy	13400.00
0005434069616	12780	Economy	13400.00
0005434069424	12780	Economy	13400.00
0005434069414	12780	Economy	13400.00
0005434082374	12780	Economy	13400.00
0005434082633	12780	Economy	13400.00
0005434069423	12780	Economy	13400.00
0005434069532	12780	Economy	13400.00
0005434082602	12780	Economy	13400.00
0005434069169	12780	Economy	13400.00
0005434069170	12780	Economy	13400.00
0005434069386	12780	Economy	13400.00
0005434069453	12780	Economy	13400.00
0005433989898	12780	Economy	13400.00
0005434069499	12780	Economy	13400.00
0005434082487	12780	Economy	13400.00
0005434082593	12780	Economy	13400.00
0005434069253	12780	Economy	13400.00
0005434069393	12780	Economy	13400.00
0005433989895	12780	Economy	14800.00
0005434069242	12780	Economy	14800.00
0005434069284	12780	Economy	13400.00
0005434069392	12780	Economy	13400.00
0005434082579	12780	Economy	13400.00
0005434082628	12780	Economy	13400.00
0005434082617	12780	Economy	13400.00
0005434069307	12780	Economy	13400.00
0005434082583	12780	Economy	13400.00
0005434069282	12780	Economy	13400.00
0005434069283	12780	Economy	13400.00
0005434069555	12780	Economy	13400.00
0005434069390	12780	Economy	13400.00
0005434082528	12780	Economy	13400.00
0005434069394	12780	Economy	13400.00
0005434069578	12780	Economy	13400.00
0005434069617	12780	Economy	13400.00
0005433989896	12780	Economy	13400.00
0005434082608	12780	Economy	13400.00
0005434069437	12780	Economy	13400.00
0005434069206	12780	Economy	13400.00
0005434082575	12780	Economy	13400.00
0005434069472	12780	Economy	13400.00
0005434069308	12780	Economy	13400.00
0005434069457	12780	Economy	13400.00
0005434069300	12780	Economy	13400.00
0005434069395	12780	Economy	13400.00
0005434069245	12780	Economy	13400.00
0005434082604	12780	Economy	13400.00
0005434069396	12780	Economy	13400.00
0005434082573	12780	Economy	13400.00
0005434082562	12780	Economy	13400.00
0005434082549	12780	Economy	13400.00
0005434069389	12780	Economy	13400.00
0005434069439	12780	Economy	13400.00
0005434069415	12780	Economy	13400.00
0005434069536	12780	Economy	13400.00
0005434069168	12780	Economy	13400.00
0005435283510	30690	Business	40300.00
0005435283511	30690	Business	40300.00
0005432433836	30690	Economy	13400.00
0005435283504	30690	Economy	13400.00
0005433812963	30690	Economy	13400.00
0005435283521	30690	Economy	13400.00
0005433812954	30690	Economy	13400.00
0005435283501	30690	Economy	13400.00
0005433812964	30690	Economy	13400.00
0005435283466	30690	Economy	13400.00
0005433812958	30690	Economy	13400.00
0005435283465	30690	Economy	13400.00
0005433812957	30690	Economy	13400.00
0005435283512	30690	Economy	13400.00
0005435283475	30690	Economy	13400.00
0005435283467	30690	Economy	13400.00
0005433812956	30690	Economy	13400.00
0005435283522	30690	Economy	13400.00
0005433812962	30690	Economy	13400.00
0005435283523	30690	Economy	13400.00
0005435283484	30690	Economy	13400.00
0005435463513	5533	Business	35300.00
0005434265836	5533	Business	35300.00
0005435463512	5533	Business	35300.00
0005434265845	5533	Business	35300.00
0005434265795	5533	Business	35300.00
0005435463335	5533	Business	35300.00
0005435463504	5533	Business	35300.00
0005435617190	5533	Business	35300.00
0005435463476	5533	Business	35300.00
0005434265757	5533	Economy	12900.00
0005434265879	5533	Economy	11800.00
0005435463353	5533	Economy	11800.00
0005432535969	5533	Economy	11800.00
0005432535967	5533	Economy	11800.00
0005434265821	5533	Economy	11800.00
0005432535957	5533	Economy	11800.00
0005435463510	5533	Economy	11800.00
0005432535972	5533	Economy	11800.00
0005435617195	5533	Economy	11800.00
0005432535971	5533	Economy	11800.00
0005435463434	5533	Economy	11800.00
0005434265822	5533	Economy	11800.00
0005435463361	5533	Economy	11800.00
0005435463488	5533	Economy	11800.00
0005435463164	5533	Economy	11800.00
0005435617197	5533	Economy	11800.00
0005435463441	5533	Economy	11800.00
0005434265794	5533	Economy	11800.00
0005435463511	5533	Economy	11800.00
0005434265856	5533	Economy	11800.00
0005435463489	5533	Economy	11800.00
0005434265854	5533	Economy	11800.00
0005435463384	5533	Economy	11800.00
0005434265857	5533	Economy	11800.00
0005435617203	5533	Economy	11800.00
0005434265776	5533	Economy	11800.00
0005432535959	5533	Economy	11800.00
0005435043304	5533	Economy	11800.00
0005434265855	5533	Economy	11800.00
0005434265791	5533	Economy	11800.00
0005434265829	5533	Economy	11800.00
0005435463502	5533	Economy	11800.00
0005435463457	5533	Economy	11800.00
0005434265873	5533	Economy	11800.00
0005435735255	13452	Business	35300.00
0005435767954	13452	Business	35300.00
0005435767803	13452	Business	35300.00
0005435768115	13452	Economy	11800.00
0005435768076	13452	Economy	11800.00
0005435767997	13452	Economy	11800.00
0005435735269	13452	Economy	11800.00
0005435768037	13452	Economy	11800.00
0005435768055	13452	Economy	11800.00
0005435768069	13452	Economy	11800.00
0005435767972	13452	Economy	11800.00
0005435767817	13452	Economy	11800.00
0005435722114	13452	Economy	11800.00
0005435767638	13452	Economy	11800.00
0005435767831	13452	Economy	11800.00
0005435768113	13452	Economy	11800.00
0005435767869	13452	Economy	11800.00
0005435768060	13452	Economy	11800.00
0005435725737	13452	Economy	11800.00
0005435767677	13452	Economy	11800.00
0005435767990	13452	Economy	11800.00
0005435735270	13452	Economy	12900.00
0005435768075	13452	Economy	11800.00
0005435767798	13452	Economy	11800.00
0005435767870	13452	Economy	11800.00
0005435768048	13452	Economy	11800.00
0005435767925	13452	Economy	11800.00
0005435722115	13452	Economy	11800.00
0005435767853	13452	Economy	11800.00
0005435767926	13452	Economy	11800.00
0005435767637	13452	Economy	11800.00
0005435767927	13452	Economy	11800.00
0005435767795	13452	Economy	11800.00
0005435767991	13452	Economy	11800.00
0005435767998	13452	Economy	11800.00
0005435767794	13452	Economy	11800.00
0005435725738	13452	Economy	11800.00
0005435767830	13452	Economy	11800.00
0005435768114	13452	Economy	11800.00
0005435767799	13452	Economy	11800.00
0005435767947	13452	Economy	11800.00
0005435768058	13452	Economy	11800.00
0005435768059	13452	Economy	11800.00
0005435767946	13452	Economy	11800.00
0005434515041	19162	Economy	3300.00
0005432632887	25080	Business	88300.00
0005432632889	25080	Business	88300.00
0005432632928	25080	Business	88300.00
0005432632913	25080	Economy	29400.00
0005432632926	25080	Economy	29400.00
0005432632883	25080	Economy	29400.00
0005432632925	25080	Economy	29400.00
0005432632910	25080	Economy	32400.00
0005432632895	25080	Economy	32400.00
0005432632900	25080	Economy	29400.00
0005432632907	25080	Economy	29400.00
0005432632920	25080	Economy	29400.00
0005432632893	25080	Economy	29400.00
0005432632884	25080	Economy	29400.00
0005432632927	25080	Economy	29400.00
0005432649559	25080	Economy	29400.00
0005432649570	25080	Economy	29400.00
0005432632940	25080	Economy	29400.00
0005432649544	25080	Economy	29400.00
0005432632890	25080	Economy	29400.00
0005432632861	25080	Economy	29400.00
0005432632906	25080	Economy	29400.00
0005432649552	25080	Economy	29400.00
0005432632912	25080	Economy	29400.00
0005432649569	25080	Economy	29400.00
0005432632876	25080	Economy	29400.00
0005432632924	25080	Economy	29400.00
0005432632919	25080	Economy	29400.00
0005432632886	25080	Economy	29400.00
0005432632921	25080	Economy	29400.00
0005432632901	25080	Economy	29400.00
0005432632888	25080	Economy	29400.00
0005432632911	25080	Economy	29400.00
0005433009907	1883	Business	48700.00
0005433009968	1883	Business	48700.00
0005433009904	1883	Business	48700.00
0005433009921	1883	Economy	16200.00
0005433286160	1883	Economy	16200.00
0005433009835	1883	Economy	16200.00
0005433009903	1883	Economy	16200.00
0005433286037	1883	Economy	17900.00
0005433009962	1883	Economy	17900.00
0005433286194	1883	Economy	16200.00
0005433009863	1883	Economy	16200.00
0005433286147	1883	Economy	16200.00
0005433009862	1883	Economy	16200.00
0005433286198	1883	Economy	16200.00
0005433286141	1883	Economy	16200.00
0005433009777	1883	Economy	16200.00
0005433286128	1883	Economy	16200.00
0005433286036	1883	Economy	16200.00
0005433009963	1883	Economy	16200.00
0005433009908	1883	Economy	16200.00
0005433009905	1883	Economy	16200.00
0005433009824	1883	Economy	16200.00
0005433009838	1883	Economy	16200.00
0005433286135	1883	Economy	16200.00
0005433009779	1883	Economy	16200.00
0005433009966	1883	Economy	16200.00
0005433009950	1883	Economy	16200.00
0005433009836	1883	Economy	16200.00
0005433286206	1883	Economy	16200.00
0005433009951	1883	Economy	16200.00
0005433286154	1883	Economy	16200.00
0005433009864	1883	Economy	16200.00
0005433009837	1883	Economy	16200.00
0005433286136	1883	Economy	16200.00
0005433286140	1883	Economy	16200.00
0005433009938	1883	Economy	16200.00
0005433286035	1883	Economy	16200.00
0005433286176	1883	Economy	16200.00
0005433009855	1883	Economy	16200.00
0005433009778	1883	Economy	16200.00
0005433286205	1883	Economy	16200.00
0005433810701	22587	Business	48700.00
0005433810735	22587	Economy	16200.00
0005433810678	22587	Economy	16200.00
0005433810749	22587	Economy	16200.00
0005435283224	5579	Business	99800.00
0005435283210	5579	Business	99800.00
0005435283116	5579	Business	99800.00
0005435283248	5579	Business	99800.00
0005435283200	5579	Economy	33300.00
0005435283184	5579	Business	99800.00
0005435283199	5579	Economy	36600.00
0005435283249	5579	Economy	33300.00
0005435283202	5579	Economy	33300.00
0005435283143	5579	Economy	33300.00
0005435283221	5579	Economy	33300.00
0005435283240	5579	Economy	33300.00
0005434173625	5579	Economy	33300.00
0005434173631	5579	Economy	33300.00
0005434173630	5579	Economy	33300.00
0005435283218	5579	Economy	33300.00
0005435283220	5579	Economy	33300.00
0005435283201	5579	Economy	33300.00
0005435283174	5579	Economy	33300.00
0005435283239	5579	Economy	33300.00
0005435283190	5579	Economy	33300.00
0005433815524	13872	Business	99800.00
0005433815579	13872	Business	99800.00
0005433848331	13872	Business	99800.00
0005433848118	13872	Business	99800.00
0005433848365	13872	Business	99800.00
0005433848241	13872	Business	99800.00
0005433848297	13872	Business	99800.00
0005433848204	13872	Business	99800.00
0005433848300	13872	Economy	33300.00
0005433815520	13872	Economy	33300.00
0005433848328	13872	Economy	33300.00
0005433848287	13872	Economy	33300.00
0005433848315	13872	Economy	33300.00
0005435283254	13872	Economy	33300.00
0005433848224	13872	Economy	33300.00
0005433848288	13872	Economy	33300.00
0005433848355	13872	Economy	33300.00
0005433815580	13872	Economy	33300.00
0005433848348	13872	Economy	33300.00
0005433848299	13872	Economy	33300.00
0005433848316	13872	Economy	33300.00
0005433848338	13872	Economy	33300.00
0005433848311	13872	Economy	33300.00
0005433848289	13872	Economy	33300.00
0005433848159	13872	Economy	33300.00
0005433848394	13872	Economy	33300.00
0005433848332	13872	Economy	33300.00
0005433848354	13872	Economy	33300.00
0005433848225	13872	Economy	33300.00
0005433848117	13872	Economy	33300.00
0005433848296	13872	Economy	33300.00
0005433815577	13872	Economy	33300.00
0005433848317	13872	Economy	33300.00
0005433815511	13872	Economy	33300.00
0005433848252	13872	Economy	33300.00
0005433815576	13872	Economy	33300.00
0005433848356	13872	Economy	33300.00
0005433848147	13872	Economy	33300.00
0005433848390	13872	Economy	33300.00
0005433848305	13872	Economy	33300.00
0005433848382	13872	Economy	33300.00
0005433848290	13872	Economy	33300.00
0005433848381	13872	Economy	33300.00
0005433848364	13872	Economy	33300.00
0005433848363	13872	Economy	33300.00
0005433848242	13872	Economy	33300.00
0005435332642	7816	Economy	15100.00
0005435332622	7816	Economy	15100.00
0005435332620	7816	Economy	15100.00
0005435332621	7816	Economy	15100.00
0005434621160	32944	Economy	16600.00
0005434621128	32944	Economy	16600.00
0005434621159	32944	Economy	15100.00
0005434621179	32944	Economy	15100.00
0005434621137	32944	Economy	15100.00
0005434621119	32944	Economy	15100.00
0005434621134	32944	Economy	15100.00
0005434621120	32944	Economy	15100.00
0005434621152	32944	Economy	15100.00
0005434621157	32944	Economy	15100.00
0005434621171	32944	Economy	15100.00
0005434621170	32944	Economy	15100.00
0005435937567	4259	Business	38000.00
0005435937539	4259	Business	38000.00
0005435937564	4259	Economy	12700.00
0005435918789	4259	Economy	12700.00
0005435937570	4259	Economy	12700.00
0005435937568	4259	Economy	12700.00
0005435937565	4259	Economy	12700.00
0005435918790	4259	Economy	12700.00
0005435937569	4259	Economy	12700.00
0005435937550	4259	Economy	12700.00
0005435786276	27330	Business	38000.00
0005435786321	27330	Business	38000.00
0005435786282	27330	Business	38000.00
0005435786290	27330	Business	38000.00
0005435786257	27330	Business	38000.00
0005434994268	27330	Economy	12700.00
0005435786300	27330	Economy	12700.00
0005434994306	27330	Economy	12700.00
0005435786311	27330	Economy	13900.00
0005435786322	27330	Economy	12700.00
0005435786178	27330	Economy	12700.00
0005435786261	27330	Economy	12700.00
0005435786247	27330	Economy	12700.00
0005434994300	27330	Economy	12700.00
0005435786244	27330	Economy	12700.00
0005435786288	27330	Economy	12700.00
0005435786256	27330	Economy	12700.00
0005434994286	27330	Economy	12700.00
0005435786323	27330	Economy	12700.00
0005435786289	27330	Economy	12700.00
0005435786283	27330	Economy	12700.00
0005435786295	27330	Economy	12700.00
0005435786314	27330	Economy	12700.00
0005434994276	27330	Economy	12700.00
0005434994287	27330	Economy	12700.00
0005435786277	27330	Economy	12700.00
0005434994308	27330	Economy	12700.00
0005434994307	27330	Economy	12700.00
0005435786150	27330	Economy	12700.00
0005434994267	27330	Economy	12700.00
0005435786222	27330	Economy	12700.00
0005434994269	27330	Economy	12700.00
0005434994275	27330	Economy	12700.00
0005435786313	27330	Economy	12700.00
0005434994266	27330	Economy	12700.00
0005435840459	4747	Economy	15000.00
0005434150212	4747	Economy	13600.00
0005434150221	4747	Economy	13600.00
0005435840504	4747	Economy	13600.00
0005435840509	4747	Economy	13600.00
0005434150199	4747	Economy	13600.00
0005434150180	4747	Economy	13600.00
0005434150173	4747	Economy	13600.00
0005435840450	4747	Economy	13600.00
0005434150182	4747	Economy	13600.00
0005434150174	4747	Economy	13600.00
0005434150164	4747	Economy	13600.00
0005435840503	4747	Economy	13600.00
0005434150181	4747	Economy	13600.00
0005435840442	4747	Economy	13600.00
0005435840491	4747	Economy	13600.00
0005435840444	4747	Economy	15000.00
0005434150163	4747	Economy	13600.00
0005435840451	4747	Economy	13600.00
0005435840508	4747	Economy	13600.00
0005434150206	4747	Economy	13600.00
0005435840502	4747	Economy	13600.00
0005434150162	4747	Economy	13600.00
0005435840443	4747	Economy	13600.00
0005435840531	4747	Economy	13600.00
0005435840458	4747	Economy	13600.00
0005435840488	4747	Economy	13600.00
0005434150211	4747	Economy	13600.00
0005432569282	30529	Business	40900.00
0005434082575	30529	Business	40900.00
0005432569374	30529	Business	40900.00
0005432569175	30529	Business	40900.00
0005432569206	30529	Business	40900.00
0005432461204	30529	Business	40900.00
0005433452792	30529	Business	40900.00
0005434082633	30529	Business	40900.00
0005434082608	30529	Business	40900.00
0005432571425	30529	Economy	13600.00
0005432569335	30529	Economy	13600.00
0005434082330	30529	Economy	13600.00
0005432571435	30529	Economy	13600.00
0005432569356	30529	Economy	13600.00
0005434082617	30529	Economy	13600.00
0005432569385	30529	Economy	13600.00
0005432569387	30529	Economy	13600.00
0005434082579	30529	Economy	13600.00
0005432569123	30529	Economy	13600.00
0005434082605	30529	Economy	13600.00
0005432569124	30529	Economy	13600.00
0005432461389	30529	Economy	13600.00
0005432569200	30529	Economy	13600.00
0005432569375	30529	Economy	13600.00
0005434082604	30529	Economy	13600.00
0005432461032	30529	Economy	13600.00
0005432461300	30529	Economy	13600.00
0005432569202	30529	Economy	13600.00
0005432569183	30529	Economy	13600.00
0005434082583	30529	Economy	13600.00
0005432461428	30529	Economy	13600.00
0005434082374	30529	Economy	13600.00
0005433452793	30529	Economy	13600.00
0005432569408	30529	Economy	13600.00
0005432461351	30529	Economy	13600.00
0005432461349	30529	Economy	13600.00
0005432461160	30529	Economy	13600.00
0005433454924	30529	Economy	13600.00
0005432571426	30529	Economy	13600.00
0005432461403	30529	Economy	13600.00
0005434082628	30529	Economy	13600.00
0005432569258	30529	Economy	13600.00
0005432461324	30529	Economy	13600.00
0005432571436	30529	Economy	13600.00
0005432571437	30529	Economy	13600.00
0005434082562	30529	Economy	13600.00
0005432461258	30529	Economy	13600.00
0005432569174	30529	Economy	13600.00
0005432569304	30529	Economy	13600.00
0005432461429	30529	Economy	13600.00
0005432461030	30529	Economy	13600.00
0005432461159	30529	Economy	13600.00
0005432461302	30529	Economy	15000.00
0005432461409	30529	Economy	13600.00
0005432461262	30529	Economy	13600.00
0005433454923	30529	Economy	13600.00
0005432461370	30529	Economy	13600.00
0005432569259	30529	Economy	13600.00
0005432571430	30529	Economy	13600.00
0005434082528	30529	Economy	13600.00
0005432461261	30529	Economy	13600.00
0005432461263	30529	Economy	13600.00
0005432461352	30529	Economy	13600.00
0005434082375	30529	Economy	13600.00
0005432569203	30529	Economy	13600.00
0005434082549	30529	Economy	13600.00
0005432461259	30529	Economy	13600.00
0005434082593	30529	Economy	13600.00
0005434082602	30529	Economy	13600.00
0005432461205	30529	Economy	13600.00
0005432461348	30529	Economy	13600.00
0005432569298	30529	Economy	13600.00
0005432461404	30529	Economy	13600.00
0005432569184	30529	Economy	13600.00
0005432569283	30529	Economy	13600.00
0005432461419	30529	Economy	13600.00
0005434082487	30529	Economy	13600.00
0005432461359	30529	Economy	13600.00
0005434082573	30529	Economy	13600.00
0005435720162	21203	Economy	9900.00
0005435720166	21203	Economy	9900.00
0005435725751	13710	Economy	9700.00
0005435725750	13710	Economy	8800.00
0005435725749	13710	Economy	8800.00
0005435725747	13710	Economy	8800.00
0005435725748	13710	Economy	8800.00
0005435725752	13710	Economy	8800.00
0005435725753	13710	Economy	8800.00
0005435530089	11129	Economy	7900.00
0005435530167	11129	Economy	7900.00
0005435530175	11129	Economy	7900.00
0005435508764	11129	Economy	7900.00
0005435508815	11129	Economy	7900.00
0005435508749	11129	Economy	7900.00
0005435508780	11129	Economy	7900.00
0005435530166	11129	Economy	7900.00
0005435380431	11129	Economy	7900.00
0005435508806	11129	Economy	7900.00
0005435530121	11129	Economy	7900.00
0005435530168	11129	Economy	7900.00
0005435530122	11129	Economy	8600.00
0005435508661	11129	Economy	7900.00
0005435508810	11129	Economy	7900.00
0005435546000	11129	Economy	7900.00
0005435530151	11129	Economy	7900.00
0005435530169	11129	Economy	7900.00
0005435530088	11129	Economy	7900.00
0005435508790	11129	Economy	7900.00
0005435508748	11129	Economy	7900.00
0005435508786	11129	Economy	7900.00
0005435530189	11129	Economy	7900.00
0005435530162	11129	Economy	7900.00
0005435508803	11129	Economy	7900.00
0005435508809	11129	Economy	7900.00
0005435508729	11129	Economy	7900.00
0005435530148	11129	Economy	7900.00
0005435530173	11129	Economy	7900.00
0005435530174	11129	Economy	7900.00
0005435530140	11129	Economy	7900.00
0005435508805	11129	Economy	7900.00
0005435530123	11129	Economy	7900.00
0005435380427	11129	Economy	7900.00
0005435380426	11129	Economy	7900.00
0005435380432	11129	Economy	7900.00
0005435508763	11129	Economy	7900.00
0005433345967	17080	Business	23600.00
0005433345810	17080	Business	23600.00
0005433345818	17080	Business	23600.00
0005433346035	17080	Business	23600.00
0005433345844	17080	Business	23600.00
0005433345878	17080	Business	23600.00
0005433345757	17080	Economy	7900.00
0005433345747	17080	Economy	7900.00
0005433345956	17080	Economy	7900.00
0005433345748	17080	Economy	7900.00
0005435097461	17080	Economy	7900.00
0005433345955	17080	Economy	7900.00
0005433345798	17080	Economy	7900.00
0005433345985	17080	Economy	7900.00
0005433345750	17080	Economy	7900.00
0005435097479	17080	Economy	7900.00
0005435097490	17080	Economy	7900.00
0005433346004	17080	Economy	7900.00
0005433345893	17080	Economy	7900.00
0005433345834	17080	Economy	7900.00
0005433345928	17080	Economy	7900.00
0005433345797	17080	Economy	7900.00
0005433345886	17080	Economy	7900.00
0005433346005	17080	Economy	7900.00
0005433345728	17080	Economy	7900.00
0005433346003	17080	Economy	7900.00
0005433345980	17080	Economy	7900.00
0005433345719	17080	Economy	7900.00
0005433345820	17080	Economy	7900.00
0005433345499	17080	Economy	7900.00
0005433346040	17080	Economy	8600.00
0005433345643	17080	Economy	8600.00
0005435097477	17080	Economy	8600.00
0005433345864	17080	Economy	7900.00
0005433345788	17080	Economy	7900.00
0005433345868	17080	Economy	7900.00
0005433345500	17080	Economy	7900.00
0005433345969	17080	Economy	7900.00
0005433345892	17080	Economy	7900.00
0005433345746	17080	Economy	7900.00
0005433345974	17080	Economy	7900.00
0005433345966	17080	Economy	7900.00
0005433345970	17080	Economy	7900.00
0005433345850	17080	Economy	7900.00
0005433345664	17080	Economy	7900.00
0005433345843	17080	Economy	7900.00
0005433346039	17080	Economy	7900.00
0005433345948	17080	Economy	7900.00
0005433346008	17080	Economy	7900.00
0005433345749	17080	Economy	7900.00
0005435097480	17080	Economy	7900.00
0005435097489	17080	Economy	7900.00
0005433345763	17080	Economy	7900.00
0005433345879	17080	Economy	7900.00
0005433345729	17080	Economy	7900.00
0005433345981	17080	Economy	7900.00
0005433345882	17080	Economy	7900.00
0005433345869	17080	Economy	7900.00
0005433345851	17080	Economy	7900.00
0005433345819	17080	Economy	7900.00
0005433345663	17080	Economy	7900.00
0005433345684	17080	Economy	7900.00
0005433345699	17080	Economy	7900.00
0005433345745	17080	Economy	7900.00
0005433345708	17080	Economy	7900.00
0005433346041	17080	Economy	7900.00
0005433345758	17080	Economy	7900.00
0005433345698	17080	Economy	7900.00
0005433345898	17080	Economy	7900.00
0005433345828	17080	Economy	7900.00
0005433345907	17080	Economy	7900.00
0005434159054	9065	Business	26600.00
0005434159047	9065	Business	26600.00
0005432920415	9065	Economy	8900.00
0005432920449	9065	Economy	8900.00
0005432920443	9065	Economy	8900.00
0005432920297	9065	Economy	8900.00
0005434159041	9065	Economy	8900.00
0005432920414	9065	Economy	8900.00
0005432920455	9065	Economy	8900.00
0005432920296	9065	Economy	8900.00
0005433477176	20444	Business	26600.00
0005433477166	20444	Business	26600.00
0005433477203	20444	Business	26600.00
0005433477175	20444	Economy	8900.00
0005433477243	20444	Economy	8900.00
0005433477283	20444	Economy	9800.00
0005433477253	20444	Economy	9800.00
0005433477272	20444	Economy	8900.00
0005433477238	20444	Economy	8900.00
0005433477137	20444	Economy	8900.00
0005433477227	20444	Economy	8900.00
0005433507692	20444	Economy	8900.00
0005433507694	20444	Economy	8900.00
0005433481362	20444	Economy	8900.00
0005433477199	20444	Economy	8900.00
0005433477236	20444	Economy	8900.00
0005433477174	20444	Economy	8900.00
0005433477286	20444	Economy	8900.00
0005433477200	20444	Economy	8900.00
0005433477220	20444	Economy	8900.00
0005433477237	20444	Economy	8900.00
0005433481361	20444	Economy	8900.00
0005433477273	20444	Economy	8900.00
0005433477165	20444	Economy	8900.00
0005433507731	20444	Economy	8900.00
0005433507701	20444	Economy	8900.00
0005433507715	20444	Economy	8900.00
0005433477267	20444	Economy	8900.00
0005433507730	20444	Economy	8900.00
0005433477287	20444	Economy	8900.00
0005433477221	20444	Economy	8900.00
0005433507693	20444	Economy	8900.00
0005433507716	20444	Economy	8900.00
0005433507721	20444	Economy	8900.00
0005433507714	20444	Economy	8900.00
0005433477239	20444	Economy	8900.00
0005433477271	20444	Economy	8900.00
0005433507705	20444	Economy	8900.00
0005435179016	10189	Economy	5800.00
0005435179718	10189	Economy	5800.00
0005435179022	10189	Economy	5800.00
0005435179717	10189	Economy	5800.00
0005435179011	10189	Economy	5800.00
0005435179023	10189	Economy	5800.00
0005435179015	10189	Economy	5800.00
0005432396355	18291	Economy	5800.00
0005432396342	18291	Economy	5800.00
0005432400216	18291	Economy	5800.00
0005432400219	18291	Economy	5800.00
0005435626741	10959	Business	9500.00
0005435626742	10959	Business	9500.00
0005435626676	10959	Business	9500.00
0005435626774	10959	Business	9500.00
0005435626698	10959	Business	9500.00
0005435626791	10959	Business	9500.00
0005435626781	10959	Business	9500.00
0005435626730	10959	Business	9500.00
0005435127338	10959	Business	9500.00
0005435127537	10959	Business	9500.00
0005435554325	10959	Economy	3200.00
0005435626749	10959	Economy	3200.00
0005435127449	10959	Economy	3200.00
0005435556762	10959	Economy	3200.00
0005435626828	10959	Economy	3200.00
0005435127498	10959	Economy	3200.00
0005435127505	10959	Economy	3500.00
0005435626773	10959	Economy	3500.00
0005435626765	10959	Economy	3500.00
0005435127450	10959	Economy	3200.00
0005435127443	10959	Economy	3200.00
0005435127495	10959	Economy	3200.00
0005435626759	10959	Economy	3200.00
0005435626750	10959	Economy	3200.00
0005435626775	10959	Economy	3200.00
0005435626706	10959	Economy	3200.00
0005435626752	10959	Economy	3200.00
0005435626704	10959	Economy	3200.00
0005435626731	10959	Economy	3200.00
0005435626792	10959	Economy	3200.00
0005435127473	10959	Economy	3200.00
0005435127466	10959	Economy	3200.00
0005435127496	10959	Economy	3200.00
0005435626829	10959	Economy	3200.00
0005435626757	10959	Economy	3200.00
0005435626710	10959	Economy	3200.00
0005435127474	10959	Economy	3200.00
0005435626830	10959	Economy	3200.00
0005435626618	10959	Economy	3200.00
0005435127431	10959	Economy	3200.00
0005435127471	10959	Economy	3200.00
0005435127509	10959	Economy	3200.00
0005435127467	10959	Economy	3200.00
0005435127497	10959	Economy	3200.00
0005435626729	10959	Economy	3200.00
0005435626790	10959	Economy	3200.00
0005435626660	10959	Economy	3200.00
0005435626725	10959	Economy	3200.00
0005435127479	10959	Economy	3200.00
0005435127459	10959	Economy	3200.00
0005435626617	10959	Economy	3200.00
0005435556761	10959	Economy	3200.00
0005435626801	10959	Economy	3200.00
0005435127451	10959	Economy	3200.00
0005435626776	10959	Economy	3200.00
0005435626705	10959	Economy	3200.00
0005435127425	10959	Economy	3200.00
0005435127488	10959	Economy	3200.00
0005435626844	10959	Economy	3200.00
0005435127551	10959	Economy	3200.00
0005435626709	10959	Economy	3200.00
0005435626777	10959	Economy	3200.00
0005435626708	10959	Economy	3200.00
0005435626758	10959	Economy	3200.00
0005435127423	10959	Economy	3200.00
0005435127397	10959	Economy	3200.00
0005435554324	10959	Economy	3200.00
0005435127398	10959	Economy	3200.00
0005434928381	14714	Economy	3200.00
0005435179427	7119	Economy	29000.00
0005435443582	7119	Economy	29000.00
0005435221078	7119	Economy	29000.00
0005435219248	7119	Economy	29000.00
0005435443579	7119	Economy	29000.00
0005435179426	7119	Economy	29000.00
0005435178539	7119	Economy	29000.00
0005435221079	7119	Economy	29000.00
0005435715889	27072	Economy	29000.00
0005435715951	27072	Economy	29000.00
0005435715953	27072	Economy	31900.00
0005432394214	27072	Economy	29000.00
0005432394213	27072	Economy	29000.00
0005435715952	27072	Economy	29000.00
0005432394216	27072	Economy	29000.00
0005435715890	27072	Economy	29000.00
0005435715954	27072	Economy	29000.00
0005435715896	27072	Economy	29000.00
0005435715938	27072	Economy	29000.00
0005432394215	27072	Economy	29000.00
0005435715950	27072	Economy	29000.00
0005435715955	27072	Economy	29000.00
0005433060489	2749	Economy	7700.00
0005433060488	2749	Economy	7700.00
0005434085048	28501	Economy	7700.00
0005434085063	28501	Economy	7700.00
0005434085049	28501	Economy	7700.00
0005434085062	28501	Economy	7700.00
0005434085055	28501	Economy	7700.00
0005435518403	11400	Business	20200.00
0005435518455	11400	Business	20200.00
0005435518399	11400	Business	20200.00
0005435541605	11400	Economy	6700.00
0005435541508	11400	Economy	7400.00
0005435518429	11400	Economy	7400.00
0005435541604	11400	Economy	7400.00
0005435518396	11400	Economy	6700.00
0005435518391	11400	Economy	6700.00
0005435541555	11400	Economy	6700.00
0005435541618	11400	Economy	6700.00
0005435541576	11400	Economy	6700.00
0005435541603	11400	Economy	6700.00
0005435518442	11400	Economy	6700.00
0005435541550	11400	Economy	6700.00
0005435518333	11400	Economy	6700.00
0005435518379	11400	Economy	6700.00
0005435518398	11400	Economy	6700.00
0005435518402	11400	Economy	6700.00
0005435541552	11400	Economy	6700.00
0005435518397	11400	Economy	6700.00
0005435541573	11400	Economy	6700.00
0005435541616	11400	Economy	6700.00
0005435541556	11400	Economy	6700.00
0005435518378	11400	Economy	6700.00
0005435546226	11400	Economy	6700.00
0005435541637	11400	Economy	6700.00
0005435541636	11400	Economy	6700.00
0005435518441	11400	Economy	6700.00
0005435541571	11400	Economy	6700.00
0005435541635	11400	Economy	6700.00
0005435541634	11400	Economy	6700.00
0005435518440	11400	Economy	6700.00
0005435518392	11400	Economy	6700.00
0005435541623	11400	Economy	6700.00
0005435518332	11400	Economy	6700.00
0005435541563	11400	Economy	6700.00
0005435541638	11400	Economy	6700.00
0005435541617	11400	Economy	6700.00
0005435529901	22219	Economy	6700.00
0005433252331	2301	Business	20200.00
0005433252341	2301	Business	20200.00
0005433252332	2301	Economy	6700.00
0005433252343	2301	Economy	6700.00
0005433252350	2301	Economy	7400.00
0005433252355	2301	Economy	6700.00
0005433252294	2301	Economy	6700.00
0005433252366	2301	Economy	6700.00
0005433252342	2301	Economy	6700.00
0005433252213	2301	Economy	6700.00
0005433252295	2301	Economy	6700.00
0005433252372	2301	Economy	6700.00
0005434908658	25617	Business	20200.00
0005434908674	25617	Business	20200.00
0005434908871	25617	Business	20200.00
0005434908606	25617	Business	20200.00
0005434908816	25617	Business	20200.00
0005434908808	25617	Business	20200.00
0005434908810	25617	Business	20200.00
0005434908817	25617	Business	20200.00
0005434908824	25617	Business	20200.00
0005434908676	25617	Business	20200.00
0005434908649	25617	Economy	6700.00
0005434908638	25617	Economy	6700.00
0005434908713	25617	Economy	6700.00
0005434908679	25617	Economy	6700.00
0005434908813	25617	Economy	6700.00
0005434908610	25617	Economy	6700.00
0005434908671	25617	Economy	7400.00
0005434908760	25617	Economy	7400.00
0005434908825	25617	Economy	7400.00
0005434908811	25617	Economy	7400.00
0005434908630	25617	Economy	6700.00
0005434908749	25617	Economy	6700.00
0005434908862	25617	Economy	6700.00
0005434908743	25617	Economy	6700.00
0005434908645	25617	Economy	6700.00
0005434908788	25617	Economy	6700.00
0005434908694	25617	Economy	6700.00
0005434908732	25617	Economy	6700.00
0005434908648	25617	Economy	6700.00
0005434908823	25617	Economy	6700.00
0005434908861	25617	Economy	6700.00
0005434908733	25617	Economy	6700.00
0005434908812	25617	Economy	6700.00
0005434908781	25617	Economy	6700.00
0005434908675	25617	Economy	6700.00
0005435787471	25617	Economy	6700.00
0005434908716	25617	Economy	6700.00
0005434908809	25617	Economy	6700.00
0005434908657	25617	Economy	6700.00
0005434908854	25617	Economy	6700.00
0005434908776	25617	Economy	6700.00
0005434908720	25617	Economy	6700.00
0005434908820	25617	Economy	6700.00
0005434908747	25617	Economy	6700.00
0005434908759	25617	Economy	6700.00
0005435787472	25617	Economy	6700.00
0005434908629	25617	Economy	6700.00
0005434908742	25617	Economy	6700.00
0005434908695	25617	Economy	6700.00
0005434908872	25617	Economy	6700.00
0005434908677	25617	Economy	6700.00
0005434908860	25617	Economy	6700.00
0005434908803	25617	Economy	6700.00
0005434908696	25617	Economy	6700.00
0005434908787	25617	Economy	6700.00
0005434908859	25617	Economy	6700.00
0005434908858	25617	Economy	6700.00
0005434908697	25617	Economy	6700.00
0005432862522	2533	Economy	12400.00
0005432621442	28047	Economy	12400.00
0005432621381	28047	Economy	12400.00
0005432621410	28047	Economy	12400.00
0005432621435	28047	Economy	12400.00
0005432621439	28047	Economy	12400.00
0005432621443	28047	Economy	12400.00
0005432621436	28047	Economy	12400.00
0005432621387	28047	Economy	12400.00
0005432621349	28047	Economy	12400.00
0005434097513	11748	Economy	11300.00
0005434097514	11748	Economy	11300.00
0005433454923	31434	Economy	8400.00
0005433452793	31434	Economy	8400.00
0005433452792	31434	Economy	8400.00
0005433454924	31434	Economy	8400.00
0005434142714	12018	Economy	7200.00
0005433129401	12018	Economy	6600.00
0005433129392	12018	Economy	6600.00
0005433129391	12018	Economy	6600.00
0005433129402	12018	Economy	6600.00
0005433134260	12018	Economy	6600.00
0005433129400	12018	Economy	6600.00
0005434326036	29836	Economy	6600.00
0005434326086	29836	Economy	6600.00
0005434326038	29836	Economy	6600.00
0005434326045	29836	Economy	6600.00
0005434326013	29836	Economy	6600.00
0005434326298	29836	Economy	6600.00
0005434326026	29836	Economy	6600.00
0005434326297	29836	Economy	6600.00
0005435933566	16488	Economy	18100.00
0005435698155	24741	Economy	19900.00
0005435698076	24741	Economy	18100.00
0005435698131	24741	Economy	18100.00
0005435698133	24741	Economy	18100.00
0005435698124	24741	Economy	18100.00
0005435698105	24741	Economy	18100.00
0005435698143	24741	Economy	18100.00
0005435698132	24741	Economy	18100.00
0005435698158	24741	Economy	18100.00
0005435698162	24741	Economy	18100.00
0005435698123	24741	Economy	18100.00
0005435698091	24741	Economy	18100.00
0005435698107	24741	Economy	18100.00
0005435698113	24741	Economy	18100.00
0005435698127	24741	Economy	18100.00
0005435698126	24741	Economy	18100.00
0005432968901	18804	Economy	4400.00
0005432968900	18804	Economy	4400.00
0005433724936	21620	Economy	4400.00
0005433724925	21620	Economy	4400.00
0005433724924	21620	Economy	4400.00
0005433724935	21620	Economy	4400.00
0005435283595	7340	Economy	7700.00
0005435283573	7340	Economy	7700.00
0005434140399	28579	Business	23100.00
0005434140606	28579	Business	23100.00
0005434140227	28579	Business	23100.00
0005434140333	28579	Business	23100.00
0005434140324	28579	Business	23100.00
0005434140427	28579	Business	23100.00
0005434140372	28579	Business	23100.00
0005434140283	28579	Economy	7700.00
0005434140540	28579	Economy	7700.00
0005434140583	28579	Economy	7700.00
0005434140511	28579	Economy	7700.00
0005434140531	28579	Economy	7700.00
0005434139909	28579	Economy	7700.00
0005434140193	28579	Economy	8500.00
0005434140067	28579	Economy	7700.00
0005434140424	28579	Economy	7700.00
0005434140503	28579	Economy	7700.00
0005434087638	28579	Economy	7700.00
0005434140254	28579	Economy	7700.00
0005434140556	28579	Economy	7700.00
0005434140150	28579	Economy	7700.00
0005434140532	28579	Economy	7700.00
0005434140599	28579	Economy	7700.00
0005434140426	28579	Economy	7700.00
0005434087637	28579	Economy	7700.00
0005434140513	28579	Economy	7700.00
0005434087653	28579	Economy	7700.00
0005434140512	28579	Economy	7700.00
0005434140247	28579	Economy	7700.00
0005434140585	28579	Economy	7700.00
0005434140402	28579	Economy	7700.00
0005434140240	28579	Economy	7700.00
0005434140581	28579	Economy	7700.00
0005434140373	28579	Economy	7700.00
0005434140068	28579	Economy	7700.00
0005434140235	28579	Economy	7700.00
0005434140175	28579	Economy	7700.00
0005434140567	28579	Economy	7700.00
0005434140530	28579	Economy	7700.00
0005434140582	28579	Economy	7700.00
0005434140239	28579	Economy	7700.00
0005434140527	28579	Economy	7700.00
0005434140584	28579	Economy	7700.00
0005434140040	28579	Economy	7700.00
0005434087647	28579	Economy	7700.00
0005434140484	28579	Economy	7700.00
0005434140546	28579	Economy	7700.00
0005434140514	28579	Economy	7700.00
0005434140470	28579	Economy	7700.00
0005434140282	28579	Economy	7700.00
0005434140421	28579	Economy	7700.00
0005434140325	28579	Economy	7700.00
0005434140587	28579	Economy	7700.00
0005434140022	28579	Economy	7700.00
0005434140506	28579	Economy	7700.00
0005434140400	28579	Economy	7700.00
0005434140151	28579	Economy	7700.00
0005434139910	28579	Economy	7700.00
0005434140289	28579	Economy	7700.00
0005433407706	1938	Economy	23900.00
0005433407701	1938	Economy	21700.00
0005435808466	23102	Economy	23900.00
0005435808515	23102	Economy	23900.00
0005435808497	23102	Economy	21700.00
0005434610335	23102	Economy	21700.00
0005435808496	23102	Economy	21700.00
0005435808492	23102	Economy	21700.00
0005435808501	23102	Economy	21700.00
0005435808450	23102	Economy	21700.00
0005435808452	23102	Economy	21700.00
0005434610321	23102	Economy	21700.00
0005434610337	23102	Economy	21700.00
0005434610329	23102	Economy	21700.00
0005435808447	23102	Economy	21700.00
0005434610336	23102	Economy	21700.00
0005435808467	23102	Economy	21700.00
0005435808477	23102	Economy	21700.00
0005435808478	23102	Economy	21700.00
0005435808446	23102	Economy	21700.00
0005435808451	23102	Economy	21700.00
0005434610330	23102	Economy	21700.00
0005434505284	16709	Economy	7600.00
0005434505204	16709	Economy	7600.00
0005434505226	16709	Economy	7600.00
0005434505262	16709	Economy	6900.00
0005434505131	16709	Economy	6900.00
0005434505100	16709	Economy	6900.00
0005434505256	16709	Economy	6900.00
0005434505277	16709	Economy	6900.00
0005434505099	16709	Economy	6900.00
0005434505042	16709	Economy	6900.00
0005434505188	16709	Economy	6900.00
0005434505114	16709	Economy	6900.00
0005434505261	16709	Economy	6900.00
0005434505270	16709	Economy	6900.00
0005434505318	16709	Economy	6900.00
0005434505044	16709	Economy	6900.00
0005434505208	16709	Economy	6900.00
0005434505279	16709	Economy	6900.00
0005434505214	16709	Economy	6900.00
0005434505159	16709	Economy	6900.00
0005434505132	16709	Economy	6900.00
0005434505285	16709	Economy	6900.00
0005434505292	16709	Economy	6900.00
0005434505043	16709	Economy	6900.00
0005434505201	16709	Economy	6900.00
0005434505113	16709	Economy	6900.00
0005434505257	16709	Economy	6900.00
0005434505278	16709	Economy	6900.00
0005434505251	16709	Economy	6900.00
0005434505187	16709	Economy	6900.00
0005433266976	2217	Economy	7000.00
0005433266978	2217	Economy	7000.00
0005433266977	2217	Economy	7000.00
0005435078760	24371	Economy	7700.00
0005435078766	24371	Economy	7700.00
0005435078687	24371	Economy	7000.00
0005435078733	24371	Economy	7000.00
0005435078764	24371	Economy	7000.00
0005435078765	24371	Economy	7000.00
0005435078732	24371	Economy	7000.00
0005435078734	24371	Economy	7000.00
0005435078688	24371	Economy	7000.00
0005434989034	23600	Economy	10800.00
0005434989037	23600	Economy	10800.00
0005434989024	23600	Economy	10800.00
0005434989081	23600	Economy	10800.00
0005434989066	23600	Economy	9800.00
0005434989053	23600	Economy	9800.00
0005434989025	23600	Economy	9800.00
0005434989014	23600	Economy	9800.00
0005434989052	23600	Economy	9800.00
0005434989043	23600	Economy	9800.00
0005434988994	23600	Economy	9800.00
0005434989050	23600	Economy	9800.00
0005434989068	23600	Economy	9800.00
0005434989036	23600	Economy	9800.00
0005434989015	23600	Economy	9800.00
0005435803336	23600	Economy	9800.00
0005434989086	23600	Economy	9800.00
0005434989020	23600	Economy	9800.00
0005434989074	23600	Economy	9800.00
0005434988983	23600	Economy	9800.00
0005434988995	23600	Economy	9800.00
0005434989019	23600	Economy	9800.00
0005434989077	23600	Economy	9800.00
0005434989067	23600	Economy	9800.00
0005434989013	23600	Economy	9800.00
0005434988984	23600	Economy	9800.00
0005434989073	23600	Economy	9800.00
0005434989012	23600	Economy	9800.00
0005432384072	31290	Business	9900.00
0005433450520	31290	Business	9900.00
0005432384240	31290	Business	9900.00
0005433450497	31290	Business	9900.00
0005432384252	31290	Business	9900.00
0005433450592	31290	Economy	3300.00
0005433450607	31290	Economy	3600.00
0005432384205	31290	Economy	3300.00
0005432384170	31290	Economy	3300.00
0005432384172	31290	Economy	3300.00
0005432384296	31290	Economy	3300.00
0005433450579	31290	Economy	3300.00
0005432384195	31290	Economy	3300.00
0005432384253	31290	Economy	3300.00
0005432384202	31290	Economy	3300.00
0005433450564	31290	Economy	3300.00
0005433450533	31290	Economy	3300.00
0005432384204	31290	Economy	3300.00
0005432384234	31290	Economy	3300.00
0005432384169	31290	Economy	3300.00
0005432384198	31290	Economy	3300.00
0005432384157	31290	Economy	3300.00
0005433450519	31290	Economy	3300.00
0005433450608	31290	Economy	3300.00
0005432384279	31290	Economy	3300.00
0005432384241	31290	Economy	3300.00
0005432384281	31290	Economy	3300.00
0005432384114	31290	Economy	3300.00
0005432384280	31290	Economy	3300.00
0005433450498	31290	Economy	3300.00
0005432384233	31290	Economy	3300.00
0005433450595	31290	Economy	3300.00
0005432384148	31290	Economy	3300.00
0005432384211	31290	Economy	3300.00
0005433450565	31290	Economy	3300.00
0005432384131	31290	Economy	3300.00
0005432384132	31290	Economy	3300.00
0005432384264	31290	Economy	3300.00
0005433450534	31290	Economy	3300.00
0005433450504	31290	Economy	3300.00
0005433450582	31290	Economy	3300.00
0005432384271	31290	Economy	3300.00
0005435304260	10751	Economy	17100.00
0005435299892	10751	Economy	15600.00
0005433126972	10751	Economy	15600.00
0005435304270	10751	Economy	15600.00
0005435304264	10751	Economy	15600.00
0005435304275	10751	Economy	15600.00
0005433126945	10751	Economy	15600.00
0005433131829	10751	Economy	15600.00
0005435299914	10751	Economy	15600.00
0005433131827	10751	Economy	15600.00
0005433126961	10751	Economy	15600.00
0005435304265	10751	Economy	15600.00
0005433131828	10751	Economy	15600.00
0005433126964	10751	Economy	15600.00
0005433131821	10751	Economy	15600.00
0005435299915	10751	Economy	15600.00
0005435304263	10751	Economy	15600.00
0005433126944	10751	Economy	15600.00
0005433126982	10751	Economy	15600.00
0005435304269	10751	Economy	15600.00
0005433126973	10751	Economy	15600.00
0005435299906	10751	Economy	15600.00
0005435304274	10751	Economy	15600.00
0005433110390	2421	Economy	15700.00
0005433110383	2421	Economy	15700.00
0005434287910	26870	Economy	17200.00
0005434287923	26870	Economy	17200.00
0005434287909	26870	Economy	17200.00
0005434287918	26870	Economy	15700.00
0005434287872	26870	Economy	15700.00
0005434287831	26870	Economy	15700.00
0005434287916	26870	Economy	15700.00
0005434300234	26870	Economy	15700.00
0005434287911	26870	Economy	15700.00
0005434287908	26870	Economy	15700.00
0005434287891	26870	Economy	15700.00
0005434287926	26870	Economy	15700.00
0005434287915	26870	Economy	15700.00
0005434300245	26870	Economy	15700.00
0005434287825	26870	Economy	15700.00
0005434287917	26870	Economy	15700.00
0005434287827	26870	Economy	15700.00
0005434287859	26870	Economy	15700.00
0005434287914	26870	Economy	15700.00
0005434287850	26870	Economy	15700.00
0005434287924	26870	Economy	15700.00
0005434287880	26870	Economy	15700.00
0005434300244	26870	Economy	15700.00
0005434287912	26870	Economy	15700.00
0005434287919	26870	Economy	15700.00
0005434272227	25487	Economy	22800.00
0005434269152	25487	Economy	22800.00
0005434272235	25487	Economy	22800.00
0005434269153	25487	Economy	22800.00
0005435983710	26639	Economy	25000.00
0005435983713	26639	Economy	25000.00
0005435856324	26639	Economy	22800.00
0005435856307	26639	Economy	22800.00
0005435856308	26639	Economy	22800.00
0005435856309	26639	Economy	22800.00
0005435263837	7151	Business	89800.00
0005435263822	7151	Business	89800.00
0005435263827	7151	Business	89800.00
0005435263836	7151	Economy	29900.00
0005435263821	7151	Economy	29900.00
0005435263807	7151	Economy	29900.00
0005435263803	7151	Economy	29900.00
0005435263801	7151	Economy	32900.00
0005435263805	7151	Economy	29900.00
0005435263819	7151	Economy	29900.00
0005435263833	7151	Economy	29900.00
0005435263818	7151	Economy	29900.00
0005435263808	7151	Economy	29900.00
0005435263832	7151	Economy	29900.00
0005435263835	7151	Economy	29900.00
0005435263806	7151	Economy	29900.00
0005435263793	7151	Economy	29900.00
0005435263797	7151	Economy	29900.00
0005435263817	7151	Economy	29900.00
0005435860600	4757	Economy	17600.00
0005435860631	4757	Economy	17600.00
0005435860626	4757	Economy	17600.00
0005433869507	32616	Economy	19400.00
0005433869452	32616	Economy	19400.00
0005433869472	32616	Economy	17600.00
0005433869462	32616	Economy	17600.00
0005433869459	32616	Economy	17600.00
0005433869583	32616	Economy	17600.00
0005433869519	32616	Economy	17600.00
0005433869474	32616	Economy	17600.00
0005433869456	32616	Economy	17600.00
0005433869548	32616	Economy	17600.00
0005433869463	32616	Economy	17600.00
0005433869581	32616	Economy	17600.00
0005433869538	32616	Economy	17600.00
0005433869582	32616	Economy	17600.00
0005433869465	32616	Economy	17600.00
0005433869468	32616	Economy	17600.00
0005433869460	32616	Economy	17600.00
0005433869549	32616	Economy	17600.00
0005433869602	32616	Economy	17600.00
0005433869566	32616	Economy	17600.00
0005433869488	32616	Economy	17600.00
0005433869585	32616	Economy	17600.00
0005433869387	32616	Economy	17600.00
0005433869461	32616	Economy	17600.00
0005433869429	32616	Economy	17600.00
0005433869557	32616	Economy	17600.00
0005433869567	32616	Economy	17600.00
0005435911657	3409	Economy	22600.00
0005434663795	12457	Economy	24800.00
0005434663800	12457	Economy	22600.00
0005434663792	12457	Economy	22600.00
0005434663784	12457	Economy	22600.00
0005434663765	12457	Economy	22600.00
0005434663791	12457	Economy	22600.00
0005434663789	12457	Economy	22600.00
0005433869460	14506	Economy	18500.00
0005433869462	14506	Economy	18500.00
0005433869456	14506	Economy	16800.00
0005433869488	14506	Economy	16800.00
0005433869585	14506	Economy	16800.00
0005433869566	14506	Economy	16800.00
0005433869583	14506	Economy	16800.00
0005433869602	14506	Economy	16800.00
0005433869465	14506	Economy	16800.00
0005433869548	14506	Economy	16800.00
0005433869538	14506	Economy	16800.00
0005433869472	14506	Economy	16800.00
0005433869519	14506	Economy	16800.00
0005433869581	14506	Economy	16800.00
0005433869507	14506	Economy	16800.00
0005433869549	14506	Economy	16800.00
0005433869468	14506	Economy	16800.00
0005433869387	14506	Economy	16800.00
0005433869429	14506	Economy	16800.00
0005433869452	14506	Economy	16800.00
0005433869459	14506	Economy	16800.00
0005433869557	14506	Economy	16800.00
0005433869474	14506	Economy	16800.00
0005433869463	14506	Economy	16800.00
0005433869567	14506	Economy	16800.00
0005433869582	14506	Economy	16800.00
0005433869461	14506	Economy	16800.00
0005435860614	32674	Economy	16800.00
0005435860613	32674	Economy	16800.00
0005435860611	32674	Economy	16800.00
0005432800235	12129	Economy	4900.00
0005432800247	12129	Economy	4400.00
0005432800261	12129	Economy	4400.00
0005432800206	12129	Economy	4400.00
0005432800214	12129	Economy	4400.00
0005432800262	12129	Economy	4400.00
0005432800218	12129	Economy	4400.00
0005432800263	12129	Economy	4400.00
0005432800216	12129	Economy	4400.00
0005432800246	12129	Economy	4400.00
0005432800215	12129	Economy	4400.00
0005432800231	12129	Economy	4400.00
0005432800243	12129	Economy	4400.00
0005432800258	12129	Economy	4400.00
0005435311506	7051	Business	49100.00
0005435293628	7051	Economy	16400.00
0005435311466	7051	Economy	16400.00
0005435311445	7051	Economy	16400.00
0005435311515	7051	Economy	16400.00
0005435311553	7051	Economy	16400.00
0005435311503	7051	Economy	16400.00
0005435293627	7051	Economy	16400.00
0005435311443	7051	Economy	18000.00
0005435311537	7051	Economy	18000.00
0005435311463	7051	Economy	16400.00
0005435293597	7051	Economy	16400.00
0005435311522	7051	Economy	16400.00
0005435311442	7051	Economy	16400.00
0005435311533	7051	Economy	16400.00
0005435311498	7051	Economy	16400.00
0005435293601	7051	Economy	16400.00
0005435311446	7051	Economy	16400.00
0005435311523	7051	Economy	16400.00
0005435311465	7051	Economy	16400.00
0005435311449	7051	Economy	16400.00
0005435311362	7051	Economy	16400.00
0005435293606	7051	Economy	16400.00
0005434409569	26900	Business	49100.00
0005435311560	26900	Business	49100.00
0005434409394	26900	Economy	16400.00
0005434409393	26900	Economy	16400.00
0005434409498	26900	Economy	16400.00
0005434409488	26900	Economy	16400.00
0005434409559	26900	Economy	16400.00
0005434300219	26900	Economy	16400.00
0005434409452	26900	Economy	16400.00
0005434409601	26900	Economy	16400.00
0005434409260	26900	Economy	16400.00
0005434409494	26900	Economy	16400.00
0005434409366	26900	Economy	16400.00
0005434409492	26900	Economy	16400.00
0005434409493	26900	Economy	16400.00
0005434409420	26900	Economy	16400.00
0005434409328	26900	Economy	16400.00
0005434409467	26900	Economy	18000.00
0005434409521	26900	Economy	18000.00
0005435311561	26900	Economy	18000.00
0005434409475	26900	Economy	18000.00
0005434409468	26900	Economy	16400.00
0005434409295	26900	Economy	16400.00
0005434409320	26900	Economy	16400.00
0005434409560	26900	Economy	16400.00
0005434409327	26900	Economy	16400.00
0005434409556	26900	Economy	16400.00
0005434409489	26900	Economy	16400.00
0005434409490	26900	Economy	16400.00
0005434409516	26900	Economy	16400.00
0005434409365	26900	Economy	16400.00
0005434409421	26900	Economy	16400.00
0005434300223	26900	Economy	16400.00
0005434409270	26900	Economy	16400.00
0005434409422	26900	Economy	16400.00
0005434409557	26900	Economy	16400.00
0005434300222	26900	Economy	16400.00
0005434409336	26900	Economy	16400.00
0005435311562	26900	Economy	16400.00
0005434409552	26900	Economy	16400.00
0005434409491	26900	Economy	16400.00
0005435218145	6469	Economy	15000.00
0005435221555	6469	Economy	15000.00
0005435221554	6469	Economy	15000.00
0005432605299	21340	Economy	16500.00
0005432605348	21340	Economy	16500.00
0005432605456	21340	Economy	15000.00
0005432605445	21340	Economy	15000.00
0005432605380	21340	Economy	15000.00
0005432605300	21340	Economy	15000.00
0005432605444	21340	Economy	15000.00
0005432605381	21340	Economy	15000.00
0005432605450	21340	Economy	15000.00
0005432605449	21340	Economy	15000.00
0005432605457	21340	Economy	15000.00
0005432605350	21340	Economy	15000.00
0005432605281	21340	Economy	15000.00
0005432605504	21340	Economy	15000.00
0005432605382	21340	Economy	15000.00
0005432605463	21340	Economy	15000.00
0005432605464	21340	Economy	15000.00
0005432605199	21340	Economy	15000.00
0005432605465	21340	Economy	15000.00
0005432605356	21340	Economy	15000.00
0005432605409	21340	Economy	15000.00
0005432605322	21340	Economy	15000.00
0005434512238	21340	Economy	15000.00
0005432605407	21340	Economy	15000.00
0005434908679	15026	Business	18900.00
0005434908816	15026	Business	18900.00
0005434908812	15026	Business	18900.00
0005434908638	15026	Business	18900.00
0005434908787	15026	Business	18900.00
0005434908811	15026	Economy	6300.00
0005434908743	15026	Economy	6300.00
0005434908813	15026	Economy	6300.00
0005434908809	15026	Economy	6300.00
0005434908675	15026	Economy	6300.00
0005434908810	15026	Economy	6300.00
0005434908871	15026	Economy	6300.00
0005434908645	15026	Economy	6300.00
0005434908674	15026	Economy	6900.00
0005434908649	15026	Economy	6300.00
0005434908742	15026	Economy	6300.00
0005434908676	15026	Economy	6300.00
0005434908677	15026	Economy	6300.00
0005434908720	15026	Economy	6300.00
0005434908858	15026	Economy	6300.00
0005434908694	15026	Economy	6300.00
0005434908696	15026	Economy	6300.00
0005434908820	15026	Economy	6300.00
0005434908749	15026	Economy	6300.00
0005434908671	15026	Economy	6300.00
0005434908825	15026	Economy	6300.00
0005434908713	15026	Economy	6300.00
0005434908903	15026	Economy	6300.00
0005434908823	15026	Economy	6300.00
0005434908747	15026	Economy	6300.00
0005434908732	15026	Economy	6300.00
0005434908657	15026	Economy	6300.00
0005434908606	15026	Economy	6300.00
0005434908658	15026	Economy	6300.00
0005434908760	15026	Economy	6300.00
0005434908695	15026	Economy	6300.00
0005434908859	15026	Economy	6300.00
0005434908824	15026	Economy	6300.00
0005434908629	15026	Economy	6300.00
0005434908648	15026	Economy	6300.00
0005434908630	15026	Economy	6300.00
0005434908610	15026	Economy	6300.00
0005434908872	15026	Economy	6300.00
0005434908817	15026	Economy	6300.00
0005434908803	15026	Economy	6300.00
0005434908759	15026	Economy	6300.00
0005434908788	15026	Economy	6300.00
0005434908862	15026	Economy	6300.00
0005434908776	15026	Economy	6300.00
0005434908781	15026	Economy	6300.00
0005434908733	15026	Economy	6300.00
0005434908808	15026	Economy	6300.00
0005434908854	15026	Economy	6300.00
0005434908716	15026	Economy	6300.00
0005434908860	15026	Economy	6300.00
0005434908861	15026	Economy	6300.00
0005434908697	15026	Economy	6300.00
0005433252303	25856	Business	18900.00
0005433252247	25856	Business	18900.00
0005433252347	25856	Business	18900.00
0005433252319	25856	Business	18900.00
0005433252362	25856	Economy	6900.00
0005433252315	25856	Economy	6300.00
0005433252344	25856	Economy	6300.00
0005433252217	25856	Economy	6300.00
0005433252333	25856	Economy	6300.00
0005433252334	25856	Economy	6300.00
0005433252174	25856	Economy	6300.00
0005433252231	25856	Economy	6300.00
0005433252338	25856	Economy	6300.00
0005433252230	25856	Economy	6300.00
0005433252313	25856	Economy	6300.00
0005433252229	25856	Economy	6300.00
0005433252330	25856	Economy	6300.00
0005433252353	25856	Economy	6300.00
0005434173646	9148	Economy	19900.00
0005434173667	9148	Economy	18100.00
0005434173666	9148	Economy	18100.00
0005434173662	9148	Economy	18100.00
0005434173665	9148	Economy	18100.00
0005434173663	9148	Economy	18100.00
0005434173659	9148	Economy	18100.00
0005434173656	9148	Economy	18100.00
0005434173647	9148	Economy	18100.00
0005433815558	22712	Economy	18100.00
0005433815559	22712	Economy	18100.00
0005433810733	14169	Business	52300.00
0005433815558	14169	Business	52300.00
0005433810729	14169	Economy	17400.00
0005433815559	14169	Economy	17400.00
0005433810747	14169	Economy	17400.00
0005433810748	14169	Economy	17400.00
0005433810755	14169	Economy	17400.00
0005433810778	14169	Economy	17400.00
0005433810736	14169	Economy	17400.00
0005433810724	14169	Economy	17400.00
0005433810686	14169	Economy	17400.00
0005433810734	14169	Economy	17400.00
0005433810728	14169	Economy	17400.00
0005433810758	14169	Economy	17400.00
0005433009924	22842	Business	52300.00
0005433009911	22842	Business	52300.00
0005433009933	22842	Business	52300.00
0005433009833	22842	Business	52300.00
0005433009815	22842	Economy	17400.00
0005433009868	22842	Economy	17400.00
0005433009878	22842	Economy	17400.00
0005433810822	22842	Economy	17400.00
0005433009880	22842	Economy	17400.00
0005433009900	22842	Economy	17400.00
0005433009822	22842	Economy	19200.00
0005433810821	22842	Economy	17400.00
0005433009816	22842	Economy	17400.00
0005433009807	22842	Economy	17400.00
0005433009765	22842	Economy	17400.00
0005433009683	22842	Economy	17400.00
0005433009839	22842	Economy	17400.00
0005433009756	22842	Economy	17400.00
0005433009853	22842	Economy	17400.00
0005433009831	22842	Economy	17400.00
0005433009881	22842	Economy	17400.00
0005433009806	22842	Economy	17400.00
0005433009682	22842	Economy	17400.00
0005434173650	22842	Economy	17400.00
0005433009879	22842	Economy	17400.00
0005433009934	22842	Economy	17400.00
0005433009873	22842	Economy	17400.00
0005433009662	22842	Economy	17400.00
0005433009872	22842	Economy	17400.00
0005433009757	22842	Economy	17400.00
0005433009764	22842	Economy	17400.00
0005433810820	22842	Economy	17400.00
0005433009794	22842	Economy	17400.00
0005433009867	22842	Economy	17400.00
0005434926618	14944	Business	22900.00
0005434926792	14944	Business	22900.00
0005434926679	14944	Business	22900.00
0005434926628	14944	Business	22900.00
0005434926737	14944	Business	22900.00
0005434926740	14944	Business	22900.00
0005434926712	14944	Business	22900.00
0005434926560	14944	Economy	7600.00
0005434926795	14944	Economy	7600.00
0005434926738	14944	Economy	8400.00
0005434926721	14944	Economy	8400.00
0005434926641	14944	Economy	8400.00
0005434926768	14944	Economy	7600.00
0005434926778	14944	Economy	7600.00
0005434926704	14944	Economy	7600.00
0005434926838	14944	Economy	7600.00
0005434926775	14944	Economy	7600.00
0005434926680	14944	Economy	7600.00
0005434926769	14944	Economy	7600.00
0005434926644	14944	Economy	7600.00
0005434926722	14944	Economy	7600.00
0005434926624	14944	Economy	7600.00
0005434926654	14944	Economy	7600.00
0005434926693	14944	Economy	7600.00
0005434926774	14944	Economy	7600.00
0005435375181	14944	Economy	7600.00
0005434926720	14944	Economy	7600.00
0005434926529	14944	Economy	7600.00
0005434926623	14944	Economy	7600.00
0005434926687	14944	Economy	7600.00
0005434926710	14944	Economy	7600.00
0005434926739	14944	Economy	7600.00
0005434926620	14944	Economy	7600.00
0005434926709	14944	Economy	7600.00
0005434926831	14944	Economy	7600.00
0005434926561	14944	Economy	7600.00
0005435375182	14944	Economy	7600.00
0005434926764	14944	Economy	7600.00
0005434926645	14944	Economy	7600.00
0005434926689	14944	Economy	7600.00
0005434926619	14944	Economy	7600.00
0005435999849	15818	Economy	8900.00
0005435999684	15818	Economy	8100.00
0005435999803	15818	Economy	8100.00
0005435999730	15818	Economy	8100.00
0005435999867	15818	Economy	8100.00
0005435999765	15818	Economy	8100.00
0005435999836	15818	Economy	8100.00
0005435999732	15818	Economy	8100.00
0005435999746	15818	Economy	8100.00
0005435999837	15818	Economy	8100.00
0005435999764	15818	Economy	8100.00
0005435999784	15818	Economy	8100.00
0005435999838	15818	Economy	8100.00
0005435999731	15818	Economy	8100.00
0005435999777	15818	Economy	8100.00
0005435999811	15818	Economy	8100.00
0005435999816	15818	Economy	8100.00
0005435488370	19682	Economy	8100.00
0005435488338	19682	Economy	8100.00
0005435488443	19682	Economy	8100.00
0005435488446	19682	Economy	8100.00
0005435488388	19682	Economy	8100.00
0005435488455	19682	Economy	8100.00
0005435488376	19682	Economy	8100.00
0005435488339	19682	Economy	8100.00
0005435488377	19682	Economy	8100.00
0005435488387	19682	Economy	8100.00
0005435488447	19682	Economy	8100.00
0005435488362	19682	Economy	8100.00
0005435488442	19682	Economy	8100.00
0005435488363	19682	Economy	8100.00
0005435488415	19682	Economy	8100.00
0005435488399	19682	Economy	8100.00
0005435488369	19682	Economy	8100.00
0005435488472	19682	Economy	8100.00
0005435488421	19682	Economy	8100.00
0005435488450	19682	Economy	8100.00
0005435617242	5986	Business	199300.00
0005435473277	5986	Business	199300.00
0005435473236	5986	Business	199300.00
0005435473278	5986	Economy	66400.00
0005435473253	5986	Economy	66400.00
0005435473239	5986	Economy	66400.00
0005435473276	5986	Economy	66400.00
0005435473202	5986	Economy	66400.00
0005435617243	5986	Economy	66400.00
0005435473286	5986	Economy	66400.00
0005435473240	5986	Economy	66400.00
0005435473275	5986	Economy	66400.00
0005435473222	5986	Economy	66400.00
0005435473264	5986	Economy	66400.00
0005435473237	5986	Economy	66400.00
0005435473252	5986	Economy	66400.00
0005435473287	5986	Economy	66400.00
0005435473238	5986	Economy	66400.00
0005432660879	18046	Business	199300.00
0005432664199	18046	Business	199300.00
0005435840232	18046	Business	199300.00
0005435840158	18046	Business	199300.00
0005432660876	18046	Business	199300.00
0005435840259	18046	Business	199300.00
0005435840225	18046	Business	199300.00
0005435840182	18046	Economy	66400.00
0005435840231	18046	Economy	66400.00
0005432667509	18046	Economy	66400.00
0005435840230	18046	Economy	66400.00
0005432660875	18046	Economy	73100.00
0005435840171	18046	Economy	66400.00
0005435840106	18046	Economy	66400.00
0005432660880	18046	Economy	66400.00
0005432664194	18046	Economy	66400.00
0005435473297	18046	Economy	66400.00
0005435840148	18046	Economy	66400.00
0005435840229	18046	Economy	66400.00
0005435840251	18046	Economy	66400.00
0005435840226	18046	Economy	66400.00
0005432664193	18046	Economy	66400.00
0005432664198	18046	Economy	66400.00
0005435840170	18046	Economy	66400.00
0005435840149	18046	Economy	66400.00
0005432664200	18046	Economy	66400.00
0005432660878	18046	Economy	66400.00
0005433286036	23033	Economy	5200.00
0005433286160	23033	Economy	5200.00
0005433286154	23033	Economy	5700.00
0005433286037	23033	Economy	5200.00
0005433286206	23033	Economy	5200.00
0005433286205	23033	Economy	5200.00
0005433286194	23033	Economy	5200.00
0005433286198	23033	Economy	5200.00
0005433286141	23033	Economy	5200.00
0005433286135	23033	Economy	5200.00
0005433286176	23033	Economy	5200.00
0005433286128	23033	Economy	5200.00
0005433286035	23033	Economy	5200.00
0005433286136	23033	Economy	5200.00
0005433286140	23033	Economy	5200.00
0005433286147	23033	Economy	5200.00
0005435104339	32066	Business	15700.00
0005435104321	32066	Economy	5200.00
0005435104334	32066	Economy	5200.00
0005435104329	32066	Economy	5200.00
0005435104277	32066	Economy	5200.00
0005435104163	32066	Economy	5200.00
0005435104313	32066	Economy	5200.00
0005435104191	32066	Economy	5200.00
0005435104278	32066	Economy	5200.00
0005435104215	32066	Economy	5200.00
0005435104353	32066	Economy	5200.00
0005435104288	32066	Economy	5200.00
0005435104266	32066	Economy	5700.00
0005435104342	32066	Economy	5700.00
0005435104306	32066	Economy	5200.00
0005435104319	32066	Economy	5200.00
0005435104292	32066	Economy	5200.00
0005435104192	32066	Economy	5200.00
0005435104146	32066	Economy	5200.00
0005435104314	32066	Economy	5200.00
0005435104234	32066	Economy	5200.00
0005435104233	32066	Economy	5200.00
0005435104330	32066	Economy	5200.00
0005435104300	32066	Economy	5200.00
0005435104203	32066	Economy	5200.00
0005435104198	32066	Economy	5200.00
0005435104197	32066	Economy	5200.00
0005435104149	32066	Economy	5200.00
0005435104280	32066	Economy	5200.00
0005435104183	32066	Economy	5200.00
0005435104202	32066	Economy	5200.00
0005435104302	32066	Economy	5200.00
0005435104286	32066	Economy	5200.00
0005435104325	32066	Economy	5200.00
0005435104208	32066	Economy	5200.00
0005433475802	23872	Economy	13500.00
0005433475803	23872	Economy	12300.00
0005433475832	23872	Economy	12300.00
0005433475826	23872	Economy	12300.00
0005433475831	23872	Economy	12300.00
0005432531768	30612	Business	42100.00
0005434069585	30612	Business	42100.00
0005432531456	30612	Business	42100.00
0005434069568	30612	Business	42100.00
0005434069572	30612	Business	42100.00
0005432530777	30612	Business	42100.00
0005432531585	30612	Business	42100.00
0005432531787	30612	Business	42100.00
0005434069488	30612	Business	42100.00
0005434069506	30612	Comfort	23900.00
0005432531421	30612	Comfort	23900.00
0005434069550	30612	Comfort	23900.00
0005434069298	30612	Comfort	23900.00
0005432531641	30612	Comfort	23900.00
0005434069436	30612	Comfort	23900.00
0005434069530	30612	Comfort	23900.00
0005432531695	30612	Comfort	23900.00
0005432531371	30612	Comfort	23900.00
0005432531550	30612	Comfort	23900.00
0005434069522	30612	Comfort	23900.00
0005434069214	30612	Comfort	23900.00
0005434069606	30612	Comfort	23900.00
0005432429029	30612	Comfort	23900.00
0005432531794	30612	Comfort	23900.00
0005434069623	30612	Comfort	23900.00
0005434069595	30612	Comfort	23900.00
0005434069588	30612	Comfort	23900.00
0005432531715	30612	Economy	14000.00
0005434069447	30612	Economy	14000.00
0005434069567	30612	Economy	14000.00
0005434069516	30612	Economy	14000.00
0005434069548	30612	Economy	14000.00
0005432531769	30612	Economy	14000.00
0005434069603	30612	Economy	14000.00
0005432531731	30612	Economy	14000.00
0005432531740	30612	Economy	14000.00
0005434069517	30612	Economy	14000.00
0005432531441	30612	Economy	14000.00
0005432531252	30612	Economy	14000.00
0005434069201	30612	Economy	14000.00
0005432531764	30612	Economy	14000.00
0005434069539	30612	Economy	14000.00
0005434069381	30612	Economy	14000.00
0005434069490	30612	Economy	14000.00
0005432531589	30612	Economy	14000.00
0005432535970	30612	Economy	14000.00
0005434069446	30612	Economy	14000.00
0005432531580	30612	Economy	14000.00
0005434069560	30612	Economy	14000.00
0005432531303	30612	Economy	14000.00
0005432531749	30612	Economy	14000.00
0005434069538	30612	Economy	15400.00
0005432531719	30612	Economy	14000.00
0005432429024	30612	Economy	14000.00
0005434069418	30612	Economy	14000.00
0005434069428	30612	Economy	14000.00
0005432531699	30612	Economy	14000.00
0005434069480	30612	Economy	14000.00
0005434069329	30612	Economy	14000.00
0005434069297	30612	Economy	14000.00
0005434069600	30612	Economy	14000.00
0005432533371	30612	Economy	14000.00
0005434069608	30612	Economy	14000.00
0005434069521	30612	Economy	14000.00
0005434069487	30612	Economy	14000.00
0005434069458	30612	Economy	14000.00
0005432531447	30612	Economy	14000.00
0005432531677	30612	Economy	14000.00
0005434069233	30612	Economy	14000.00
0005432530776	30612	Economy	14000.00
0005432531619	30612	Economy	14000.00
0005432531513	30612	Economy	14000.00
0005432531751	30612	Economy	14000.00
0005432531521	30612	Economy	14000.00
0005434069605	30612	Economy	14000.00
0005434069531	30612	Economy	14000.00
0005434069549	30612	Economy	14000.00
0005432429023	30612	Economy	14000.00
0005432531701	30612	Economy	14000.00
0005432531635	30612	Economy	14000.00
0005434069642	30612	Economy	14000.00
0005434069561	30612	Economy	14000.00
0005434069232	30612	Economy	14000.00
0005434069596	30612	Economy	14000.00
0005432531686	30612	Economy	14000.00
0005434069205	30612	Economy	14000.00
0005432531711	30612	Economy	14000.00
0005434069345	30612	Economy	14000.00
0005432531741	30612	Economy	14000.00
0005434069425	30612	Economy	14000.00
0005432530896	30612	Economy	14000.00
0005432533377	30612	Economy	14000.00
0005434069546	30612	Economy	15400.00
0005432531370	30612	Economy	14000.00
0005432531551	30612	Economy	14000.00
0005432531504	30612	Economy	14000.00
0005434069448	30612	Economy	14000.00
0005432531620	30612	Economy	14000.00
0005432531829	30612	Economy	14000.00
0005434069426	30612	Economy	14000.00
0005434069429	30612	Economy	14000.00
0005434069540	30612	Economy	14000.00
0005432531685	30612	Economy	14000.00
0005434069404	30612	Economy	14000.00
0005432531514	30612	Economy	14000.00
0005432429028	30612	Economy	14000.00
0005434069607	30612	Economy	14000.00
0005432533361	30612	Economy	14000.00
0005432531026	30612	Economy	14000.00
0005434069270	30612	Economy	14000.00
0005434069579	30612	Economy	14000.00
0005432535979	30612	Economy	14000.00
0005432531748	30612	Economy	14000.00
0005432531730	30612	Economy	14000.00
0005434069547	30612	Economy	14000.00
0005434069353	30612	Economy	14000.00
0005432531696	30612	Economy	14000.00
0005432531334	30612	Economy	14000.00
0005432531304	30612	Economy	14000.00
0005434069584	30612	Economy	14000.00
0005434069202	30612	Economy	14000.00
0005432533378	30612	Economy	14000.00
0005434069408	30612	Economy	14000.00
0005432429022	30612	Economy	14000.00
0005434069215	30612	Economy	14000.00
0005434069581	30612	Economy	14000.00
0005434069203	30612	Economy	14000.00
0005432531747	30612	Economy	14000.00
0005432531830	30612	Economy	14000.00
0005432531615	30612	Economy	14000.00
0005434069491	30612	Economy	14000.00
0005432531025	30612	Economy	14000.00
0005432531819	30612	Economy	14000.00
0005434069602	30612	Economy	14000.00
0005434069631	30612	Economy	14000.00
0005435654188	24849	Business	9800.00
0005435654386	24849	Business	9800.00
0005435654326	24849	Business	9800.00
0005435654408	24849	Business	9800.00
0005435654321	24849	Business	9800.00
0005435654404	24849	Business	9800.00
0005435654362	24849	Economy	3300.00
0005435654450	24849	Economy	3300.00
0005435654294	24849	Economy	3300.00
0005435654437	24849	Economy	3300.00
0005435654237	24849	Economy	3600.00
0005435654436	24849	Economy	3300.00
0005435654248	24849	Economy	3300.00
0005435654381	24849	Economy	3300.00
0005435654349	24849	Economy	3300.00
0005435654405	24849	Economy	3300.00
0005435654286	24849	Economy	3300.00
0005435654438	24849	Economy	3300.00
0005435654354	24849	Economy	3300.00
0005435654229	24849	Economy	3300.00
0005435654460	24849	Economy	3300.00
0005435654334	24849	Economy	3300.00
0005435654410	24849	Economy	3300.00
0005435654324	24849	Economy	3300.00
0005435654189	24849	Economy	3300.00
0005435654323	24849	Economy	3300.00
0005435654348	24849	Economy	3300.00
0005435654361	24849	Economy	3300.00
0005435654382	24849	Economy	3300.00
0005435654439	24849	Economy	3300.00
0005435654320	24849	Economy	3300.00
0005435654353	24849	Economy	3300.00
0005435654230	24849	Economy	3300.00
0005435654466	24849	Economy	3300.00
0005435654325	24849	Economy	3300.00
0005435654347	24849	Economy	3300.00
0005435654333	24849	Economy	3300.00
0005434980537	23532	Economy	10500.00
0005434980623	23532	Economy	10500.00
0005434980632	23532	Economy	10500.00
0005434980577	23532	Economy	10500.00
0005434980663	23532	Economy	9500.00
0005434980631	23532	Economy	9500.00
0005434980575	23532	Economy	9500.00
0005434980503	23532	Economy	9500.00
0005434980597	23532	Economy	9500.00
0005434980624	23532	Economy	9500.00
0005434980639	23532	Economy	9500.00
0005434980504	23532	Economy	9500.00
0005434980559	23532	Economy	9500.00
0005434980643	23532	Economy	9500.00
0005434980578	23532	Economy	9500.00
0005434980610	23532	Economy	9500.00
0005434980662	23532	Economy	9500.00
0005434980545	23532	Economy	9500.00
0005434980670	23532	Economy	9500.00
0005434980622	23532	Economy	9500.00
0005434980592	23532	Economy	9500.00
0005434980583	23532	Economy	9500.00
0005434980576	23532	Economy	9500.00
0005434980605	23532	Economy	9500.00
0005434980587	23532	Economy	9500.00
0005434980598	23532	Economy	9500.00
0005434952634	28273	Economy	5300.00
0005434302905	19789	Economy	8700.00
0005434302903	19789	Economy	8700.00
0005434140433	11941	Business	9700.00
0005434140376	11941	Business	9700.00
0005434140181	11941	Business	9700.00
0005434140182	11941	Business	9700.00
0005434140054	11941	Business	9700.00
0005434140253	11941	Economy	3200.00
0005434140554	11941	Economy	3200.00
0005434140311	11941	Economy	3200.00
0005434140393	11941	Economy	3200.00
0005434140180	11941	Economy	3500.00
0005434140493	11941	Economy	3200.00
0005434140378	11941	Economy	3200.00
0005434140377	11941	Economy	3200.00
0005434140528	11941	Economy	3200.00
0005434140391	11941	Economy	3200.00
0005434140564	11941	Economy	3200.00
0005434140310	11941	Economy	3200.00
0005434140416	11941	Economy	3200.00
0005434140383	11941	Economy	3200.00
0005434140382	11941	Economy	3200.00
0005434140572	11941	Economy	3200.00
0005434140379	11941	Economy	3200.00
0005434140461	11941	Economy	3200.00
0005434140321	11941	Economy	3200.00
0005434140534	11941	Economy	3200.00
0005434140553	11941	Economy	3200.00
0005434140401	11941	Economy	3200.00
0005434140342	11941	Economy	3200.00
0005434140571	11941	Economy	3200.00
0005434140533	11941	Economy	3200.00
0005434140518	11941	Economy	3200.00
0005434140517	11941	Economy	3200.00
0005434140555	11941	Economy	3200.00
0005434140529	11941	Economy	3200.00
0005434140559	11941	Economy	3200.00
0005435283573	28720	Economy	3200.00
0005435283595	28720	Economy	3200.00
0005435312876	6588	Economy	20900.00
0005435312878	6588	Economy	20900.00
0005435312879	6588	Economy	20900.00
0005435312877	6588	Economy	20900.00
0005435312859	6588	Economy	20900.00
0005433539106	25037	Economy	9900.00
0005433534559	25037	Economy	9900.00
0005433539111	25037	Economy	9900.00
0005433539107	25037	Economy	9900.00
0005433539108	25037	Economy	9900.00
0005433534560	25037	Economy	9900.00
0005433539110	25037	Economy	9900.00
0005432922639	831	Economy	14600.00
0005432922640	831	Economy	14600.00
0005433512188	16134	Economy	14600.00
0005433512167	16134	Economy	14600.00
0005433512187	16134	Economy	14600.00
0005435935132	3669	Economy	7200.00
0005435933564	3669	Economy	7200.00
0005435698113	16257	Economy	7900.00
0005435698155	16257	Economy	7200.00
0005435698124	16257	Economy	7200.00
0005434950661	16257	Economy	7200.00
0005434950649	16257	Economy	7200.00
0005435698162	16257	Economy	7200.00
0005435698107	16257	Economy	7200.00
0005435698132	16257	Economy	7200.00
0005435698143	16257	Economy	7200.00
0005434950640	16257	Economy	7200.00
0005434950639	16257	Economy	7200.00
0005435698158	16257	Economy	7200.00
0005435698127	16257	Economy	7200.00
0005435698091	16257	Economy	7200.00
0005434950660	16257	Economy	7200.00
0005435698133	16257	Economy	7200.00
0005435698105	16257	Economy	7200.00
0005435698131	16257	Economy	7200.00
0005435698076	16257	Economy	7200.00
0005435698123	16257	Economy	7200.00
0005435698126	16257	Economy	7200.00
0005435904914	3964	Economy	19300.00
0005434606923	22074	Economy	19300.00
0005433519583	22074	Economy	19300.00
0005434603025	22074	Economy	19300.00
0005434606932	22074	Economy	19300.00
0005434606924	22074	Economy	19300.00
0005433519584	22074	Economy	19300.00
0005434603024	22074	Economy	19300.00
0005433349163	693	Economy	3700.00
0005433349147	693	Economy	3700.00
0005433349166	693	Economy	3700.00
0005433349164	693	Economy	3700.00
0005433349146	693	Economy	3700.00
0005433349167	693	Economy	3700.00
0005433349165	693	Economy	3700.00
0005433349140	693	Economy	3700.00
0005433349141	693	Economy	3700.00
0005433349148	693	Economy	3700.00
0005435628827	15935	Economy	3700.00
0005435628820	15935	Economy	3700.00
0005433159373	17227	Economy	7100.00
0005433159376	17227	Economy	7100.00
0005433158195	17227	Economy	7100.00
0005434445316	17594	Economy	7100.00
0005434445315	17594	Economy	7100.00
0005435383303	7886	Economy	5900.00
0005435383305	7886	Economy	5400.00
0005435383304	7886	Economy	5400.00
0005435133193	33081	Economy	5400.00
0005435133192	33081	Economy	5400.00
0005435133191	33081	Economy	5400.00
0005435133197	33081	Economy	5400.00
0005435133175	33081	Economy	5400.00
0005435938960	4399	Economy	48800.00
0005435938958	4399	Economy	44400.00
0005435938961	4399	Economy	44400.00
0005435938962	4399	Economy	44400.00
0005435811213	29451	Business	133200.00
0005435811224	29451	Business	133200.00
0005435811212	29451	Economy	44400.00
0005435811206	29451	Economy	44400.00
0005435811208	29451	Economy	44400.00
0005435811216	29451	Economy	44400.00
0005435811225	29451	Economy	44400.00
0005435811207	29451	Economy	44400.00
0005435390440	7506	Economy	12500.00
0005432398304	18455	Economy	4900.00
0005435179426	27167	Economy	4900.00
0005435179427	27167	Economy	4900.00
0005435178539	27167	Economy	4900.00
0005432866216	2232	Economy	32000.00
0005432866219	2232	Economy	29100.00
0005434191321	9754	Economy	4400.00
0005434191327	9754	Economy	4400.00
0005434191320	9754	Economy	4400.00
0005434191326	9754	Economy	4400.00
0005432665320	26489	Business	92200.00
0005432665327	26489	Business	92200.00
0005432658642	26489	Economy	30700.00
0005432665318	26489	Economy	30700.00
0005432658649	26489	Economy	30700.00
0005432658632	26489	Economy	30700.00
0005432658645	26489	Economy	33800.00
0005432661987	26489	Economy	30700.00
0005432661978	26489	Economy	30700.00
0005432665324	26489	Economy	30700.00
0005432658648	26489	Economy	30700.00
0005432658647	26489	Economy	30700.00
0005432658643	26489	Economy	30700.00
0005432661979	26489	Economy	30700.00
0005432665333	26489	Economy	30700.00
0005432661980	26489	Economy	30700.00
0005432665332	26489	Economy	30700.00
0005432661965	26489	Economy	30700.00
0005432665316	26489	Economy	30700.00
0005432658651	26489	Economy	30700.00
0005432661988	26489	Economy	30700.00
0005432661983	26489	Economy	30700.00
0005432665317	26489	Economy	30700.00
0005432665328	26489	Economy	30700.00
0005432665331	26489	Economy	30700.00
0005432658650	26489	Economy	30700.00
0005432661975	26489	Economy	30700.00
0005432665325	26489	Economy	30700.00
0005432661960	26489	Economy	30700.00
0005432665321	26489	Economy	30700.00
0005432658644	26489	Economy	30700.00
0005432665326	26489	Economy	30700.00
0005435312883	6531	Business	48400.00
0005435104330	22653	Business	48400.00
0005434505318	22653	Business	48400.00
0005434505100	22653	Business	48400.00
0005435104191	22653	Business	48400.00
0005434505277	22653	Business	48400.00
0005434505113	22653	Business	48400.00
0005435104334	22653	Business	48400.00
0005434505044	22653	Business	48400.00
0005434505042	22653	Economy	16100.00
0005435104278	22653	Economy	16100.00
0005435104286	22653	Economy	16100.00
0005435104163	22653	Economy	16100.00
0005435104198	22653	Economy	16100.00
0005435104183	22653	Economy	17800.00
0005435104292	22653	Economy	17800.00
0005435104146	22653	Economy	17800.00
0005435104277	22653	Economy	17800.00
0005434505099	22653	Economy	16100.00
0005435104234	22653	Economy	16100.00
0005435104314	22653	Economy	16100.00
0005434505188	22653	Economy	16100.00
0005435104215	22653	Economy	16100.00
0005435104203	22653	Economy	16100.00
0005434505226	22653	Economy	16100.00
0005434505279	22653	Economy	16100.00
0005434505214	22653	Economy	16100.00
0005434505261	22653	Economy	16100.00
0005434505284	22653	Economy	16100.00
0005435104149	22653	Economy	16100.00
0005435104300	22653	Economy	16100.00
0005434505208	22653	Economy	16100.00
0005435104280	22653	Economy	16100.00
0005434505292	22653	Economy	16100.00
0005435104233	22653	Economy	16100.00
0005435104321	22653	Economy	16100.00
0005435104202	22653	Economy	16100.00
0005435104313	22653	Economy	16100.00
0005434505251	22653	Economy	16100.00
0005434505270	22653	Economy	16100.00
0005435104208	22653	Economy	16100.00
0005435104325	22653	Economy	16100.00
0005435104319	22653	Economy	16100.00
0005435104288	22653	Economy	16100.00
0005434505043	22653	Economy	16100.00
0005435104197	22653	Economy	16100.00
0005434505132	22653	Economy	16100.00
0005435104353	22653	Economy	16100.00
0005435104342	22653	Economy	16100.00
0005434505201	22653	Economy	16100.00
0005434505204	22653	Economy	16100.00
0005434505262	22653	Economy	16100.00
0005434505285	22653	Economy	16100.00
0005434505159	22653	Economy	16100.00
0005435104306	22653	Economy	16100.00
0005434505187	22653	Economy	16100.00
0005434505256	22653	Economy	16100.00
0005435104302	22653	Economy	16100.00
0005434505257	22653	Economy	16100.00
0005434505131	22653	Economy	16100.00
0005435104329	22653	Economy	16100.00
0005434505114	22653	Economy	16100.00
0005434505278	22653	Economy	16100.00
0005435104192	22653	Economy	16100.00
0005435104339	22653	Economy	16100.00
0005435104266	22653	Economy	16100.00
0005433368934	1682	Business	50000.00
0005433368950	1682	Economy	16700.00
0005433368973	1682	Economy	16700.00
0005433368951	1682	Economy	16700.00
0005433368970	1682	Economy	16700.00
0005433368949	1682	Economy	16700.00
0005433368916	1682	Economy	16700.00
0005433368971	1682	Economy	16700.00
0005433368972	1682	Economy	16700.00
0005435654436	21692	Business	50000.00
0005435654437	21692	Business	50000.00
0005435654347	21692	Business	50000.00
0005435654404	21692	Business	50000.00
0005435654410	21692	Business	50000.00
0005435654333	21692	Business	50000.00
0005435654354	21692	Economy	16700.00
0005435654334	21692	Economy	18300.00
0005435654361	21692	Economy	18300.00
0005435654408	21692	Economy	16700.00
0005435654229	21692	Economy	16700.00
0005435654320	21692	Economy	16700.00
0005435654237	21692	Economy	16700.00
0005435654326	21692	Economy	16700.00
0005435654188	21692	Economy	16700.00
0005435654248	21692	Economy	16700.00
0005435790411	21692	Economy	16700.00
0005435654460	21692	Economy	16700.00
0005435654324	21692	Economy	16700.00
0005435654230	21692	Economy	16700.00
0005435654321	21692	Economy	16700.00
0005435654349	21692	Economy	16700.00
0005435654438	21692	Economy	16700.00
0005435654362	21692	Economy	16700.00
0005435654381	21692	Economy	16700.00
0005435654386	21692	Economy	16700.00
0005435654325	21692	Economy	16700.00
0005435654405	21692	Economy	16700.00
0005435654286	21692	Economy	16700.00
0005435654353	21692	Economy	16700.00
0005435654466	21692	Economy	16700.00
0005435790405	21692	Economy	16700.00
0005435654294	21692	Economy	16700.00
0005435654189	21692	Economy	16700.00
0005435654450	21692	Economy	16700.00
0005435654323	21692	Economy	16700.00
0005435654439	21692	Economy	16700.00
0005435654348	21692	Economy	16700.00
0005435654382	21692	Economy	16700.00
0005435627134	23791	Economy	11200.00
0005435627133	23791	Economy	11200.00
0005434466594	23219	Economy	20900.00
0005434466599	23219	Economy	20900.00
0005434466610	23219	Economy	20900.00
0005434466591	23219	Economy	20900.00
0005434466588	23219	Economy	20900.00
0005434466593	23219	Economy	20900.00
0005433987099	25638	Business	21500.00
0005433987003	25638	Business	21500.00
0005433987203	25638	Economy	7200.00
0005433987231	25638	Economy	7200.00
0005433987100	25638	Economy	7200.00
0005433987223	25638	Economy	7900.00
0005433987235	25638	Economy	7200.00
0005433987284	25638	Economy	7200.00
0005433987139	25638	Economy	7200.00
0005433987316	25638	Economy	7200.00
0005433987216	25638	Economy	7200.00
0005433987355	25638	Economy	7200.00
0005433987333	25638	Economy	7200.00
0005433987208	25638	Economy	7200.00
0005433987142	25638	Economy	7200.00
0005433987004	25638	Economy	7200.00
0005433987218	25638	Economy	7200.00
0005433986987	25638	Economy	7200.00
0005433987238	25638	Economy	7200.00
0005433986988	25638	Economy	7200.00
0005433987325	25638	Economy	7200.00
0005433987209	25638	Economy	7200.00
0005433987286	25638	Economy	7200.00
0005433987378	25638	Economy	7200.00
0005433987326	25638	Economy	7200.00
0005433987191	25638	Economy	7200.00
0005433987268	25638	Economy	7200.00
0005433987101	25638	Economy	7200.00
0005433987348	25638	Economy	7200.00
0005433987224	25638	Economy	7200.00
0005433987287	25638	Economy	7200.00
0005433987347	25638	Economy	7200.00
0005433987217	25638	Economy	7200.00
0005435719602	21277	Economy	9400.00
0005435720859	21277	Economy	9400.00
0005433168480	1626	Economy	17000.00
0005433168493	1626	Economy	15500.00
0005432663095	17842	Business	18000.00
0005432655890	17842	Business	18000.00
0005432655875	17842	Business	18000.00
0005432655889	17842	Business	18000.00
0005432655858	17842	Economy	6000.00
0005432655888	17842	Economy	6000.00
0005432655887	17842	Economy	6600.00
0005432655876	17842	Economy	6000.00
0005432658646	17842	Economy	6000.00
0005432661992	17842	Economy	6000.00
0005432663094	17842	Economy	6000.00
0005432660874	17842	Economy	6000.00
0005432663098	17842	Economy	6000.00
0005432663089	17842	Economy	6000.00
0005432655882	17842	Economy	6000.00
0005432665335	17842	Economy	6000.00
0005432665329	17842	Economy	6000.00
0005432663093	17842	Economy	6000.00
0005432665330	17842	Economy	6000.00
0005432665334	17842	Economy	6000.00
0005432661993	17842	Economy	6000.00
0005432869706	26330	Business	18000.00
0005432869714	26330	Business	18000.00
0005432869713	26330	Economy	6000.00
0005432869708	26330	Economy	6000.00
0005432869676	26330	Economy	6000.00
0005432869707	26330	Economy	6000.00
0005432869695	26330	Economy	6000.00
0005432869705	26330	Economy	6000.00
0005432639451	25063	Business	87300.00
0005432639477	25063	Economy	29100.00
0005432639482	25063	Economy	29100.00
0005432639467	25063	Economy	29100.00
0005432639459	25063	Economy	29100.00
0005432639478	25063	Economy	29100.00
0005432639455	25063	Economy	29100.00
0005432639492	25063	Economy	29100.00
0005432639493	25063	Economy	29100.00
0005432639473	25063	Economy	29100.00
0005432639452	25063	Economy	29100.00
0005432639481	25063	Economy	29100.00
0005432639458	25063	Economy	29100.00
0005432848916	3104	Business	16100.00
0005432905295	3104	Economy	5400.00
0005432905276	3104	Economy	5400.00
0005432905292	3104	Economy	5400.00
0005432848915	3104	Economy	5400.00
0005432905282	3104	Economy	5400.00
0005432905283	3104	Economy	5400.00
0005432905284	3104	Economy	5400.00
0005432329999	31100	Business	16100.00
0005433439080	31100	Business	16100.00
0005432330036	31100	Business	16100.00
0005432329993	31100	Business	16100.00
0005432330026	31100	Business	16100.00
0005432329945	31100	Economy	5400.00
0005432329771	31100	Economy	5400.00
0005433439086	31100	Economy	5400.00
0005432329870	31100	Economy	5900.00
0005432329770	31100	Economy	5900.00
0005432329892	31100	Economy	5400.00
0005432329944	31100	Economy	5400.00
0005433439071	31100	Economy	5400.00
0005432329891	31100	Economy	5400.00
0005432329932	31100	Economy	5400.00
0005432330011	31100	Economy	5400.00
0005432329860	31100	Economy	5400.00
0005432329979	31100	Economy	5400.00
0005432329894	31100	Economy	5400.00
0005433439101	31100	Economy	5400.00
0005432329930	31100	Economy	5400.00
0005432329916	31100	Economy	5400.00
0005432329844	31100	Economy	5400.00
0005432330052	31100	Economy	5400.00
0005432330028	31100	Economy	5400.00
0005432329810	31100	Economy	5400.00
0005432329978	31100	Economy	5400.00
0005432329907	31100	Economy	5400.00
0005433439068	31100	Economy	5400.00
0005433439072	31100	Economy	5400.00
0005432329995	31100	Economy	5400.00
0005432329994	31100	Economy	5400.00
0005432329917	31100	Economy	5400.00
0005433439070	31100	Economy	5400.00
0005432329885	31100	Economy	5400.00
0005432330027	31100	Economy	5400.00
0005432330049	31100	Economy	5400.00
0005433439050	31100	Economy	5400.00
0005432329893	31100	Economy	5400.00
0005433439069	31100	Economy	5400.00
0005432329931	31100	Economy	5400.00
0005432329845	31100	Economy	5400.00
0005432330048	31100	Economy	5400.00
0005432330021	31100	Economy	5400.00
0005432329900	31100	Economy	5400.00
0005432329908	31100	Economy	5400.00
0005435488466	6202	Business	124600.00
0005435488435	6202	Business	124600.00
0005435297262	6202	Business	124600.00
0005435488452	6202	Business	124600.00
0005435297241	6202	Economy	41500.00
0005435488451	6202	Economy	41500.00
0005435297258	6202	Economy	41500.00
0005435488418	6202	Economy	41500.00
0005435488401	6202	Economy	41500.00
0005435488439	6202	Economy	45700.00
0005435488470	6202	Economy	45700.00
0005435297261	6202	Economy	45700.00
0005435297242	6202	Economy	41500.00
0005435488397	6202	Economy	41500.00
0005435488392	6202	Economy	41500.00
0005435488429	6202	Economy	41500.00
0005435297244	6202	Economy	41500.00
0005435488471	6202	Economy	41500.00
0005435488453	6202	Economy	41500.00
0005435488460	6202	Economy	41500.00
0005435488454	6202	Economy	41500.00
0005435999764	19526	Business	124600.00
0005435999838	19526	Business	124600.00
0005435999837	19526	Business	124600.00
0005434310105	19526	Economy	41500.00
0005435999836	19526	Economy	41500.00
0005435999849	19526	Economy	41500.00
0005435999730	19526	Economy	41500.00
0005435999811	19526	Economy	41500.00
0005434310142	19526	Economy	41500.00
0005435999731	19526	Economy	45700.00
0005434310140	19526	Economy	45700.00
0005435999777	19526	Economy	41500.00
0005435999732	19526	Economy	41500.00
0005435999816	19526	Economy	41500.00
0005434310124	19526	Economy	41500.00
0005435999684	19526	Economy	41500.00
0005435999803	19526	Economy	41500.00
0005434310132	19526	Economy	41500.00
0005435999784	19526	Economy	41500.00
0005435999746	19526	Economy	41500.00
0005435999765	19526	Economy	41500.00
0005434310104	19526	Economy	41500.00
0005434310106	19526	Economy	41500.00
0005434310113	19526	Economy	41500.00
0005433157020	13212	Economy	13600.00
0005433157021	13212	Economy	13600.00
0005433157011	13212	Economy	12300.00
0005433157019	13212	Economy	12300.00
0005433157022	13212	Economy	12300.00
0005433158200	13212	Economy	12300.00
0005433186349	1560	Business	86000.00
0005435502873	20889	Business	86000.00
0005435502874	20889	Business	86000.00
0005435545886	20889	Business	86000.00
0005435502880	20889	Business	86000.00
0005434566263	20889	Economy	28700.00
0005435545917	20889	Economy	28700.00
0005434566290	20889	Economy	31500.00
0005435502914	20889	Economy	31500.00
0005435529831	20889	Economy	28700.00
0005435502906	20889	Economy	28700.00
0005435502949	20889	Economy	28700.00
0005435502920	20889	Economy	28700.00
0005435502877	20889	Economy	28700.00
0005435529867	20889	Economy	28700.00
0005435502876	20889	Economy	28700.00
0005435529873	20889	Economy	28700.00
0005435529877	20889	Economy	28700.00
0005435529858	20889	Economy	28700.00
0005435545916	20889	Economy	28700.00
0005435545939	20889	Economy	28700.00
0005435529885	20889	Economy	28700.00
0005435545942	20889	Economy	28700.00
0005435529886	20889	Economy	28700.00
0005435502888	20889	Economy	28700.00
0005435502944	20889	Economy	28700.00
0005435502891	20889	Economy	28700.00
0005435502890	20889	Economy	28700.00
0005435529847	20889	Economy	28700.00
0005434566262	20889	Economy	28700.00
0005435529866	20889	Economy	28700.00
0005435502905	20889	Economy	28700.00
0005435931703	3887	Economy	19700.00
0005435931704	3887	Economy	19700.00
0005435153939	21902	Economy	19700.00
0005435153919	21902	Economy	19700.00
0005435142994	21902	Economy	19700.00
0005435143003	21902	Economy	19700.00
0005435153917	21902	Economy	19700.00
0005435143001	21902	Economy	19700.00
0005435153933	21902	Economy	19700.00
0005435142995	21902	Economy	19700.00
0005435143002	21902	Economy	19700.00
0005435153932	21902	Economy	19700.00
0005435225810	7182	Economy	14300.00
0005435225799	7182	Economy	13000.00
0005435225788	7182	Economy	13000.00
0005435225807	7182	Economy	13000.00
0005435225808	7182	Economy	13000.00
0005432629269	28151	Economy	14300.00
0005432629238	28151	Economy	13000.00
0005432629249	28151	Economy	13000.00
0005432629268	28151	Economy	13000.00
0005432629294	28151	Economy	13000.00
0005432629287	28151	Economy	13000.00
0005432629250	28151	Economy	13000.00
0005432629237	28151	Economy	13000.00
0005432629267	28151	Economy	13000.00
0005434268056	8711	Economy	10500.00
0005435960168	15214	Economy	10500.00
0005432873504	1179	Economy	38300.00
0005432873492	1179	Economy	42200.00
0005432873472	1179	Economy	38300.00
0005432873481	1179	Economy	38300.00
0005432693881	17458	Business	115000.00
0005432675581	17458	Business	115000.00
0005432693921	17458	Economy	38300.00
0005432693954	17458	Economy	38300.00
0005432677673	17458	Economy	38300.00
0005432677674	17458	Economy	38300.00
0005432675521	17458	Economy	38300.00
0005432675582	17458	Economy	38300.00
0005432693878	17458	Economy	38300.00
0005432693931	17458	Economy	38300.00
0005432675580	17458	Economy	38300.00
0005432693918	17458	Economy	38300.00
0005432693877	17458	Economy	38300.00
0005432693894	17458	Economy	38300.00
0005432693932	17458	Economy	38300.00
0005432677692	17458	Economy	38300.00
0005432677691	17458	Economy	38300.00
0005432693880	17458	Economy	38300.00
0005433156997	1141	Economy	13900.00
0005433156984	1141	Economy	13900.00
0005433156998	1141	Economy	13900.00
0005434435614	17326	Economy	13900.00
0005434435595	17326	Economy	13900.00
0005435928277	4080	Economy	8200.00
0005435928291	4080	Economy	7500.00
0005435928290	4080	Economy	7500.00
0005435928271	4080	Economy	7500.00
0005435087049	24434	Economy	8200.00
0005435087050	24434	Economy	7500.00
0005435087046	24434	Economy	7500.00
0005435087060	24434	Economy	7500.00
0005435087030	24434	Economy	7500.00
0005435551746	11067	Economy	48100.00
0005435098612	11067	Economy	48100.00
0005435551740	11067	Economy	48100.00
0005435098608	11067	Economy	48100.00
0005435551758	11067	Economy	48100.00
0005435551770	11067	Economy	48100.00
0005435551726	11067	Economy	48100.00
0005435654513	11067	Economy	48100.00
0005435551739	11067	Economy	48100.00
0005435551725	11067	Economy	48100.00
0005433373799	2465	Business	86800.00
0005433373751	2465	Business	86800.00
0005433373758	2465	Business	86800.00
0005433373783	2465	Economy	28900.00
0005433373785	2465	Economy	28900.00
0005433373786	2465	Economy	28900.00
0005433373768	2465	Economy	28900.00
0005433373787	2465	Economy	28900.00
0005433373784	2465	Economy	28900.00
0005435706823	27029	Business	86800.00
0005435706867	27029	Business	86800.00
0005435706833	27029	Economy	28900.00
0005435706849	27029	Economy	31800.00
0005435706863	27029	Economy	31800.00
0005435706816	27029	Economy	31800.00
0005435706820	27029	Economy	31800.00
0005435706771	27029	Economy	28900.00
0005435706811	27029	Economy	28900.00
0005435706827	27029	Economy	28900.00
0005435706860	27029	Economy	28900.00
0005435706864	27029	Economy	28900.00
0005435706856	27029	Economy	28900.00
0005435706810	27029	Economy	28900.00
0005435706828	27029	Economy	28900.00
0005435706809	27029	Economy	28900.00
0005435706848	27029	Economy	28900.00
0005435706847	27029	Economy	28900.00
0005435706855	27029	Economy	28900.00
0005435706822	27029	Economy	28900.00
0005435706815	27029	Economy	28900.00
0005433261868	1320	Business	203300.00
0005433261809	1320	Business	203300.00
0005433261861	1320	Business	203300.00
0005433261852	1320	Business	203300.00
0005433261810	1320	Economy	67800.00
0005433261839	1320	Economy	67800.00
0005433261827	1320	Economy	67800.00
0005433261840	1320	Economy	67800.00
0005433261811	1320	Economy	67800.00
0005433261849	1320	Economy	67800.00
0005433261846	1320	Economy	67800.00
0005433261826	1320	Economy	67800.00
0005434964769	18239	Business	203300.00
0005434964748	18239	Business	203300.00
0005434964734	18239	Business	203300.00
0005434964743	18239	Economy	74500.00
0005434964719	18239	Economy	67800.00
0005434964729	18239	Economy	67800.00
0005434964753	18239	Economy	67800.00
0005434964767	18239	Economy	67800.00
0005434964619	18239	Economy	67800.00
0005434964699	18239	Economy	67800.00
0005434964721	18239	Economy	67800.00
0005434964754	18239	Economy	67800.00
0005434964760	18239	Economy	67800.00
0005434964715	18239	Economy	67800.00
0005434964785	18239	Economy	67800.00
0005434964655	18239	Economy	67800.00
0005434964725	18239	Economy	67800.00
0005434964752	18239	Economy	67800.00
0005434964620	18239	Economy	67800.00
0005434964700	18239	Economy	67800.00
0005434964783	18239	Economy	67800.00
0005434964763	18239	Economy	67800.00
0005434964724	18239	Economy	67800.00
0005434964786	18239	Economy	67800.00
0005434964747	18239	Economy	67800.00
0005434964766	18239	Economy	67800.00
0005434964744	18239	Economy	67800.00
0005434964745	18239	Economy	67800.00
0005434964756	18239	Economy	67800.00
0005434964755	18239	Economy	67800.00
0005434964720	18239	Economy	67800.00
0005434964788	18239	Economy	67800.00
0005434964742	18239	Economy	67800.00
0005434964733	18239	Economy	67800.00
0005434964683	18239	Economy	67800.00
0005434964761	18239	Economy	67800.00
0005434964749	18239	Economy	67800.00
0005434964765	18239	Economy	67800.00
0005434964784	18239	Economy	67800.00
0005433194936	4826	Business	44200.00
0005433195002	4826	Economy	14700.00
0005433194992	4826	Economy	14700.00
0005433194978	4826	Economy	14700.00
0005435907649	4826	Economy	16200.00
0005433194945	4826	Economy	16200.00
0005435907650	4826	Economy	16200.00
0005433194977	4826	Economy	14700.00
0005433194996	4826	Economy	14700.00
0005433194924	4826	Economy	14700.00
0005433194939	4826	Economy	14700.00
0005433194963	4826	Economy	14700.00
0005433194932	4826	Economy	14700.00
0005433194937	4826	Economy	14700.00
0005435907635	4826	Economy	14700.00
0005433195003	4826	Economy	14700.00
0005433194938	4826	Economy	14700.00
0005433194946	4826	Economy	14700.00
0005433194923	4826	Economy	14700.00
0005434626223	32935	Economy	14700.00
0005434626227	32935	Economy	14700.00
0005434626226	32935	Economy	14700.00
0005435786326	13789	Economy	3400.00
0005435786168	13789	Economy	3100.00
0005435786216	13789	Economy	3100.00
0005435786146	13789	Economy	3100.00
0005435937574	13789	Economy	3100.00
0005435786298	13789	Economy	3100.00
0005435786329	13789	Economy	3100.00
0005435787406	13789	Economy	3100.00
0005435786327	13789	Economy	3100.00
0005435786302	13789	Economy	3100.00
0005435786153	13789	Economy	3100.00
0005435786342	13789	Economy	3100.00
0005435786215	13789	Economy	3100.00
0005435786353	13789	Economy	3100.00
0005435786328	13789	Economy	3100.00
0005435786217	13789	Economy	3100.00
0005435787405	13789	Economy	3100.00
0005435786343	13789	Economy	3100.00
0005435786145	13789	Economy	3100.00
0005435786341	13789	Economy	3100.00
0005435786243	13789	Economy	3100.00
0005435786337	13789	Economy	3100.00
0005435937564	27420	Economy	3400.00
0005435937568	27420	Economy	3100.00
0005435937570	27420	Economy	3100.00
0005435937567	27420	Economy	3100.00
0005435937550	27420	Economy	3100.00
0005435937565	27420	Economy	3100.00
0005435937539	27420	Economy	3100.00
0005435937569	27420	Economy	3100.00
0005434409509	20305	Business	12000.00
0005434409585	20305	Business	12000.00
0005434409609	20305	Business	12000.00
0005434409618	20305	Business	12000.00
0005434409586	20305	Business	12000.00
0005434409619	20305	Economy	4000.00
0005434409614	20305	Economy	4000.00
0005434409381	20305	Economy	4000.00
0005434409542	20305	Economy	4000.00
0005434409568	20305	Economy	4000.00
0005434409536	20305	Economy	4000.00
0005434409520	20305	Economy	4000.00
0005434409617	20305	Economy	4000.00
0005434409541	20305	Economy	4000.00
0005434409382	20305	Economy	4000.00
0005434409506	20305	Economy	4000.00
0005434409590	20305	Economy	4000.00
0005434409584	20305	Economy	4000.00
0005434409610	20305	Economy	4000.00
0005434409544	20305	Economy	4000.00
0005434409380	20305	Economy	4000.00
0005434409573	20305	Economy	4000.00
0005434409592	20305	Economy	4000.00
0005434409607	20305	Economy	4000.00
0005434409613	20305	Economy	4000.00
0005434409500	20305	Economy	4000.00
0005434409505	20305	Economy	4000.00
0005434409540	20305	Economy	4000.00
0005434409537	20305	Economy	4000.00
0005434409580	20305	Economy	4000.00
0005434409429	20305	Economy	4000.00
0005434409545	20305	Economy	4000.00
0005434409531	20305	Economy	4000.00
0005434409579	20305	Economy	4000.00
0005434409499	20305	Economy	4000.00
0005434409608	20305	Economy	4000.00
0005435311511	26994	Business	12000.00
0005435311508	26994	Business	12000.00
0005435311453	26994	Business	12000.00
0005435311423	26994	Economy	4000.00
0005435311481	26994	Economy	4400.00
0005435311532	26994	Economy	4400.00
0005435311516	26994	Economy	4000.00
0005435311477	26994	Economy	4000.00
0005435311509	26994	Economy	4000.00
0005435311474	26994	Economy	4000.00
0005435311510	26994	Economy	4000.00
0005435311545	26994	Economy	4000.00
0005435311507	26994	Economy	4000.00
0005435311521	26994	Economy	4000.00
0005435311546	26994	Economy	4000.00
0005435311462	26994	Economy	4000.00
0005435311550	26994	Economy	4000.00
0005435311517	26994	Economy	4000.00
0005435311544	26994	Economy	4000.00
0005433124538	5694	Business	43300.00
0005433124552	5694	Business	43300.00
0005435297390	5694	Business	43300.00
0005433124484	5694	Business	43300.00
0005433124483	5694	Economy	14400.00
0005435297393	5694	Economy	14400.00
0005433124502	5694	Economy	15900.00
0005433124531	5694	Economy	14400.00
0005433124529	5694	Economy	14400.00
0005433124521	5694	Economy	14400.00
0005433124514	5694	Economy	14400.00
0005435297375	5694	Economy	14400.00
0005433124527	5694	Economy	14400.00
0005433124532	5694	Economy	14400.00
0005433124513	5694	Economy	14400.00
0005435297402	5694	Economy	14400.00
0005433124503	5694	Economy	14400.00
0005433124520	5694	Economy	14400.00
0005435297397	5694	Economy	14400.00
0005433124523	5694	Economy	14400.00
0005433124515	5694	Economy	14400.00
0005433124526	5694	Economy	14400.00
0005434319833	15662	Business	43300.00
0005434310153	15662	Business	43300.00
0005434310154	15662	Business	43300.00
0005434312378	15662	Economy	14400.00
0005434312382	15662	Economy	14400.00
0005434319813	15662	Economy	14400.00
0005434319783	15662	Economy	14400.00
0005434310175	15662	Economy	14400.00
0005434319836	15662	Economy	14400.00
0005434319800	15662	Economy	14400.00
0005434319826	15662	Economy	14400.00
0005434319810	15662	Economy	14400.00
0005434310151	15662	Economy	14400.00
0005434319849	15662	Economy	14400.00
0005434310152	15662	Economy	14400.00
0005434312384	15662	Economy	14400.00
0005434319768	15662	Economy	14400.00
0005434319827	15662	Economy	14400.00
0005434319811	15662	Economy	14400.00
0005434319828	15662	Economy	14400.00
0005434312383	15662	Economy	14400.00
0005434319799	15662	Economy	14400.00
0005434312385	15662	Economy	14400.00
0005434311272	15662	Economy	14400.00
0005435221535	24984	Economy	15500.00
0005435217775	24984	Economy	15500.00
0005435217771	24984	Economy	15500.00
0005435217763	24984	Economy	15500.00
0005435220366	24984	Economy	15500.00
0005435903229	9007	Economy	27400.00
0005435903226	9007	Economy	24900.00
0005434189344	9007	Economy	24900.00
0005434484532	16614	Economy	27400.00
0005434484531	16614	Economy	27400.00
0005434310154	7691	Business	11100.00
0005435229650	7691	Business	11100.00
0005433722449	7691	Business	11100.00
0005434310151	7691	Economy	3700.00
0005433722378	7691	Economy	3700.00
0005433722467	7691	Economy	3700.00
0005433722425	7691	Economy	4100.00
0005433722472	7691	Economy	4100.00
0005433722469	7691	Economy	4100.00
0005433722450	7691	Economy	3700.00
0005433722411	7691	Economy	3700.00
0005433722441	7691	Economy	3700.00
0005433722498	7691	Economy	3700.00
0005435477027	7691	Economy	3700.00
0005433722468	7691	Economy	3700.00
0005433722364	7691	Economy	3700.00
0005433722497	7691	Economy	3700.00
0005435477014	7691	Economy	3700.00
0005433722410	7691	Economy	3700.00
0005434310175	7691	Economy	3700.00
0005435477013	7691	Economy	3700.00
0005433722442	7691	Economy	3700.00
0005433722363	7691	Economy	3700.00
0005435477026	7691	Economy	3700.00
0005434310152	7691	Economy	3700.00
0005434310153	7691	Economy	3700.00
0005433722430	7691	Economy	3700.00
0005433722496	7691	Economy	3700.00
0005433722379	7691	Economy	3700.00
0005432693932	30352	Business	11100.00
0005432693921	30352	Business	11100.00
0005433450575	30352	Economy	3700.00
0005432693954	30352	Economy	3700.00
0005433450560	30352	Economy	3700.00
0005432693931	30352	Economy	4100.00
0005433450538	30352	Economy	3700.00
0005432693918	30352	Economy	3700.00
0005433450576	30352	Economy	3700.00
0005432693877	30352	Economy	3700.00
0005433450569	30352	Economy	3700.00
0005432693881	30352	Economy	3700.00
0005432693880	30352	Economy	3700.00
0005433450561	30352	Economy	3700.00
0005433450570	30352	Economy	3700.00
0005432693878	30352	Economy	3700.00
0005432693894	30352	Economy	3700.00
0005433124502	30353	Business	11100.00
0005433124527	30353	Business	11100.00
0005433124552	30353	Business	11100.00
0005433124513	30353	Business	11100.00
0005433124532	30353	Economy	3700.00
0005433124515	30353	Economy	3700.00
0005432721667	30353	Economy	3700.00
0005432721685	30353	Economy	3700.00
0005433124538	30353	Economy	3700.00
0005433124521	30353	Economy	3700.00
0005432721679	30353	Economy	3700.00
0005432721636	30353	Economy	3700.00
0005433124520	30353	Economy	3700.00
0005432721666	30353	Economy	3700.00
0005433124483	30353	Economy	3700.00
0005433124484	30353	Economy	3700.00
0005433124529	30353	Economy	3700.00
0005433124526	30353	Economy	3700.00
0005432721645	30353	Economy	3700.00
0005433124514	30353	Economy	3700.00
0005433124531	30353	Economy	3700.00
0005433124503	30353	Economy	3700.00
0005432721660	30353	Economy	3700.00
0005433124523	30353	Economy	3700.00
0005433193376	1355	Business	70400.00
0005433193434	1355	Economy	23500.00
0005433193402	1355	Economy	25800.00
0005433193413	1355	Economy	23500.00
0005433193435	1355	Economy	23500.00
0005433193412	1355	Economy	23500.00
0005432928128	1355	Economy	23500.00
0005433193431	1355	Economy	23500.00
0005434515041	18527	Business	70400.00
0005434587316	18527	Business	70400.00
0005434587340	18527	Business	70400.00
0005433724925	18527	Economy	23500.00
0005434587299	18527	Economy	23500.00
0005433525356	18527	Economy	23500.00
0005434587292	18527	Economy	23500.00
0005433525346	18527	Economy	23500.00
0005433724924	18527	Economy	23500.00
0005434587339	18527	Economy	23500.00
0005434587359	18527	Economy	23500.00
0005434587346	18527	Economy	23500.00
0005433724936	18527	Economy	23500.00
0005434587270	18527	Economy	23500.00
0005434587338	18527	Economy	23500.00
0005433724935	18527	Economy	23500.00
0005434587328	18527	Economy	23500.00
0005434587353	18527	Economy	23500.00
0005434587271	18527	Economy	23500.00
0005434587327	18527	Economy	23500.00
0005434587345	18527	Economy	23500.00
0005434587298	18527	Economy	23500.00
0005434587342	18527	Economy	23500.00
0005434587344	18527	Economy	23500.00
0005435305076	11442	Economy	4000.00
0005435305070	11442	Economy	4000.00
0005435302337	11442	Economy	4000.00
0005435302321	11442	Economy	4000.00
0005435305068	11442	Economy	4000.00
0005435305075	11442	Economy	4000.00
0005434345275	29783	Economy	4300.00
0005434345193	29783	Economy	4300.00
0005434345250	29783	Economy	4000.00
0005434345249	29783	Economy	4000.00
0005434345163	29783	Economy	4000.00
0005434142714	29783	Economy	4000.00
0005434345169	29783	Economy	4000.00
0005434345265	29783	Economy	4000.00
0005434345188	29783	Economy	4000.00
0005434345232	29783	Economy	4000.00
0005434345241	29783	Economy	4000.00
0005434345131	29783	Economy	4000.00
0005434345274	29783	Economy	4000.00
0005434345273	29783	Economy	4000.00
0005434345266	29783	Economy	4000.00
0005434345215	29783	Economy	4000.00
0005434345271	29783	Economy	4000.00
0005434345184	29783	Economy	4000.00
0005434345187	29783	Economy	4000.00
0005434345192	29783	Economy	4000.00
0005434345287	29783	Economy	4000.00
0005434345267	29783	Economy	4000.00
0005434345132	29783	Economy	4000.00
0005434345126	29783	Economy	4000.00
0005434345240	29783	Economy	4000.00
0005434345191	29783	Economy	4000.00
0005434345123	29783	Economy	4000.00
0005434345056	29783	Economy	4000.00
0005434345223	29783	Economy	4000.00
0005434345272	29783	Economy	4000.00
0005434345216	29783	Economy	4000.00
0005434345204	29783	Economy	4000.00
0005434345239	29783	Economy	4000.00
0005434345242	29783	Economy	4000.00
0005433416111	1291	Business	199800.00
0005433416131	1291	Economy	66600.00
0005433416069	1291	Economy	66600.00
0005433416068	1291	Economy	66600.00
0005435825335	17986	Business	199800.00
0005435825386	17986	Business	199800.00
0005435825415	17986	Business	199800.00
0005435825394	17986	Business	199800.00
0005435825414	17986	Economy	66600.00
0005435825408	17986	Economy	66600.00
0005435825358	17986	Economy	73200.00
0005435825385	17986	Economy	66600.00
0005435825362	17986	Economy	66600.00
0005435825361	17986	Economy	66600.00
0005435825381	17986	Economy	66600.00
0005435825349	17986	Economy	66600.00
0005435825409	17986	Economy	66600.00
0005434462846	17522	Economy	14800.00
0005434462849	17522	Economy	13500.00
0005434462843	17522	Economy	13500.00
0005434460566	17522	Economy	13500.00
0005434460561	17522	Economy	13500.00
0005434460562	17522	Economy	13500.00
0005434462855	17522	Economy	13500.00
0005434462854	17522	Economy	13500.00
0005434462851	17522	Economy	13500.00
0005434462845	17522	Economy	13500.00
0005434460565	17522	Economy	13500.00
0005434460560	17522	Economy	13500.00
0005435243615	5646	Business	27800.00
0005435243589	5646	Business	27800.00
0005435476983	5646	Economy	9300.00
0005435243534	5646	Economy	10200.00
0005435243598	5646	Economy	9300.00
0005435243621	5646	Economy	9300.00
0005435626884	5646	Economy	9300.00
0005435243637	5646	Economy	9300.00
0005435476984	5646	Economy	9300.00
0005435243569	5646	Economy	9300.00
0005435476963	5646	Economy	9300.00
0005435243618	5646	Economy	9300.00
0005435243556	5646	Economy	9300.00
0005435243532	5646	Economy	9300.00
0005435476947	5646	Economy	9300.00
0005435476996	5646	Economy	9300.00
0005435243616	5646	Economy	9300.00
0005435243590	5646	Economy	9300.00
0005435243599	5646	Economy	9300.00
0005435243596	5646	Economy	9300.00
0005432785260	15361	Business	27800.00
0005432785323	15361	Business	27800.00
0005435950024	15361	Economy	9300.00
0005432785210	15361	Economy	9300.00
0005432785231	15361	Economy	9300.00
0005432785243	15361	Economy	10200.00
0005435949995	15361	Economy	10200.00
0005435949980	15361	Economy	10200.00
0005432785250	15361	Economy	10200.00
0005432785251	15361	Economy	9300.00
0005432785211	15361	Economy	9300.00
0005432785348	15361	Economy	9300.00
0005432785324	15361	Economy	9300.00
0005432785355	15361	Economy	9300.00
0005435949996	15361	Economy	9300.00
0005432785281	15361	Economy	9300.00
0005432785308	15361	Economy	9300.00
0005432785226	15361	Economy	9300.00
0005432785254	15361	Economy	9300.00
0005435950002	15361	Economy	9300.00
0005435950025	15361	Economy	9300.00
0005435949987	15361	Economy	9300.00
0005432785259	15361	Economy	9300.00
0005432785261	15361	Economy	9300.00
0005435950023	15361	Economy	9300.00
0005435950003	15361	Economy	9300.00
0005432785230	15361	Economy	9300.00
0005435851181	4340	Economy	6300.00
0005435851185	4340	Economy	6300.00
0005435851184	4340	Economy	6300.00
0005435851160	4340	Economy	6300.00
0005432848680	28880	Economy	7000.00
0005434463992	28880	Economy	6300.00
0005432848718	28880	Economy	6300.00
0005432848715	28880	Economy	6300.00
0005432848679	28880	Economy	6300.00
0005432848704	28880	Economy	6300.00
0005434463993	28880	Economy	6300.00
0005432848722	28880	Economy	6300.00
0005432848705	28880	Economy	6300.00
0005432848694	28880	Economy	6300.00
0005432848725	28880	Economy	6300.00
0005434461704	28880	Economy	6300.00
0005432848721	28880	Economy	6300.00
0005435257530	6324	Economy	4000.00
0005435257536	6324	Economy	4000.00
0005435257501	6324	Economy	4000.00
0005435257539	6324	Economy	4000.00
0005434926767	20400	Business	11900.00
0005434926786	20400	Business	11900.00
0005434926794	20400	Business	11900.00
0005433497892	20400	Business	11900.00
0005434926711	20400	Business	11900.00
0005434926674	20400	Economy	4000.00
0005434926748	20400	Economy	4000.00
0005434926638	20400	Economy	4000.00
0005434926747	20400	Economy	4000.00
0005434926683	20400	Economy	4000.00
0005434926777	20400	Economy	4400.00
0005434926685	20400	Economy	4400.00
0005434926818	20400	Economy	4000.00
0005433497859	20400	Economy	4000.00
0005434926702	20400	Economy	4000.00
0005434926643	20400	Economy	4000.00
0005434926671	20400	Economy	4000.00
0005434926820	20400	Economy	4000.00
0005434926684	20400	Economy	4000.00
0005434926640	20400	Economy	4000.00
0005434926745	20400	Economy	4000.00
0005434926714	20400	Economy	4000.00
0005434926635	20400	Economy	4000.00
0005434926843	20400	Economy	4000.00
0005434926639	20400	Economy	4000.00
0005434926713	20400	Economy	4000.00
0005434926670	20400	Economy	4000.00
0005434926634	20400	Economy	4000.00
0005434926798	20400	Economy	4000.00
0005434926766	20400	Economy	4000.00
0005434926860	20400	Economy	4000.00
0005434926830	20400	Economy	4000.00
0005434926736	20400	Economy	4000.00
0005434444175	20400	Economy	4000.00
0005434926727	20400	Economy	4000.00
0005434444176	20400	Economy	4000.00
0005433497864	20400	Economy	4000.00
0005434926642	20400	Economy	4000.00
0005434926746	20400	Economy	4000.00
0005434926706	20400	Economy	4000.00
0005434444159	20400	Economy	4000.00
0005434926758	20400	Economy	4000.00
0005434926658	20400	Economy	4000.00
0005434926819	20400	Economy	4000.00
0005432785291	12198	Business	41200.00
0005432785301	12198	Economy	13700.00
0005432785330	12198	Economy	13700.00
0005432785347	12198	Economy	13700.00
0005432785322	12198	Economy	15100.00
0005432785282	12198	Economy	15100.00
0005432785257	12198	Economy	13700.00
0005432785344	12198	Economy	13700.00
0005432785321	12198	Economy	13700.00
0005432785292	12198	Economy	13700.00
0005432785364	12198	Economy	13700.00
0005432785284	12198	Economy	13700.00
0005432785333	12198	Economy	13700.00
0005432785343	12198	Economy	13700.00
0005432785303	12198	Economy	13700.00
0005432785365	12198	Economy	13700.00
0005432785223	12198	Economy	13700.00
0005432785329	12198	Economy	13700.00
0005432785283	12198	Economy	13700.00
0005432785349	12198	Economy	13700.00
0005435243654	15414	Business	41200.00
0005435243643	15414	Business	41200.00
0005435243546	15414	Business	41200.00
0005435243617	15414	Economy	13700.00
0005435243645	15414	Economy	13700.00
0005435243612	15414	Economy	13700.00
0005435243562	15414	Economy	15100.00
0005435243619	15414	Economy	15100.00
0005435243625	15414	Economy	13700.00
0005435243613	15414	Economy	13700.00
0005435243614	15414	Economy	13700.00
0005435243607	15414	Economy	13700.00
0005435243653	15414	Economy	13700.00
0005435243633	15414	Economy	13700.00
0005435243576	15414	Economy	13700.00
0005435243563	15414	Economy	13700.00
0005435243548	15414	Economy	13700.00
0005435243561	15414	Economy	13700.00
0005435243549	15414	Economy	13700.00
0005435243622	15414	Economy	13700.00
0005435243591	15414	Economy	13700.00
0005435243592	15414	Economy	13700.00
0005435243575	15414	Economy	13700.00
0005435243564	15414	Economy	13700.00
0005435243519	15414	Economy	13700.00
0005435243520	15414	Economy	13700.00
0005434880913	10108	Business	49700.00
0005434880894	10108	Business	49700.00
0005434880904	10108	Business	49700.00
0005434880953	10108	Business	49700.00
0005434880659	10108	Business	49700.00
0005434880935	10108	Economy	16600.00
0005434880620	10108	Economy	16600.00
0005434880674	10108	Economy	16600.00
0005434880660	10108	Economy	16600.00
0005434880888	10108	Economy	16600.00
0005434880671	10108	Economy	16600.00
0005434880914	10108	Economy	16600.00
0005434880621	10108	Economy	18200.00
0005434880927	10108	Economy	16600.00
0005434880975	10108	Economy	16600.00
0005434880670	10108	Economy	16600.00
0005434880833	10108	Economy	16600.00
0005434880788	10108	Economy	16600.00
0005434880960	10108	Economy	16600.00
0005434880835	10108	Economy	16600.00
0005434880645	10108	Economy	16600.00
0005434880487	10108	Economy	16600.00
0005434880791	10108	Economy	16600.00
0005434880981	10108	Economy	16600.00
0005434880760	10108	Economy	16600.00
0005434880824	10108	Economy	16600.00
0005434880776	10108	Economy	16600.00
0005434880622	10108	Economy	16600.00
0005434880676	10108	Economy	16600.00
0005434880675	10108	Economy	16600.00
0005434880789	10108	Economy	16600.00
0005434880774	10108	Economy	16600.00
0005434880775	10108	Economy	16600.00
0005435914142	14598	Business	49700.00
0005435914107	14598	Business	49700.00
0005435914172	14598	Business	49700.00
0005435914213	14598	Business	49700.00
0005434910176	14598	Economy	16600.00
0005435914108	14598	Economy	16600.00
0005435914117	14598	Economy	18200.00
0005435914204	14598	Economy	16600.00
0005435914212	14598	Economy	16600.00
0005435914169	14598	Economy	16600.00
0005435914182	14598	Economy	16600.00
0005435914121	14598	Economy	16600.00
0005435914077	14598	Economy	16600.00
0005435914159	14598	Economy	16600.00
0005435914116	14598	Economy	16600.00
0005435914173	14598	Economy	16600.00
0005435914214	14598	Economy	16600.00
0005435914181	14598	Economy	16600.00
0005435914141	14598	Economy	16600.00
0005435914170	14598	Economy	16600.00
0005435914076	14598	Economy	16600.00
0005435914158	14598	Economy	16600.00
0005435914187	14598	Economy	16600.00
0005435914140	14598	Economy	16600.00
0005435914211	14598	Economy	16600.00
0005435914180	14598	Economy	16600.00
0005435914100	14598	Economy	16600.00
0005435914215	14598	Economy	16600.00
0005434252237	9256	Economy	20300.00
0005435933571	9256	Economy	20300.00
0005434252215	9256	Economy	20300.00
0005435933570	9256	Economy	20300.00
0005434252228	9256	Economy	20300.00
0005435933580	9256	Economy	20300.00
0005435660455	24631	Economy	22400.00
0005435660447	24631	Economy	20300.00
0005435660444	24631	Economy	20300.00
0005435660450	24631	Economy	20300.00
0005432967642	2798	Business	33000.00
0005432967674	2798	Economy	11000.00
0005432967641	2798	Economy	11000.00
0005432967659	2798	Economy	11000.00
0005432967452	2798	Economy	11000.00
0005432967647	2798	Economy	11000.00
0005432967607	2798	Economy	11000.00
0005432967648	2798	Economy	11000.00
0005432967608	2798	Economy	11000.00
0005432967609	2798	Economy	11000.00
0005433681918	29144	Business	33000.00
0005433681936	29144	Economy	11000.00
0005433681956	29144	Economy	11000.00
0005433681847	29144	Economy	11000.00
0005433681932	29144	Economy	11000.00
0005433681937	29144	Economy	11000.00
0005433681950	29144	Economy	11000.00
0005433681964	29144	Economy	11000.00
0005433681931	29144	Economy	11000.00
0005435854092	9291	Business	132900.00
0005434272234	9291	Business	132900.00
0005434163851	9291	Business	132900.00
0005434163850	9291	Economy	44300.00
0005435854093	9291	Economy	44300.00
0005434163871	9291	Economy	44300.00
0005434153577	9291	Economy	44300.00
0005434163879	9291	Economy	44300.00
0005435856349	9291	Economy	48700.00
0005434163880	9291	Economy	44300.00
0005434163863	9291	Economy	44300.00
0005434153576	9291	Economy	44300.00
0005434163864	9291	Economy	44300.00
0005435854094	9291	Economy	44300.00
0005434163886	9291	Economy	44300.00
0005434269158	9291	Economy	44300.00
0005433634745	25225	Business	132900.00
0005433634773	25225	Business	132900.00
0005433616743	25225	Business	132900.00
0005433634687	25225	Business	132900.00
0005433578204	25225	Business	132900.00
0005433634781	25225	Business	132900.00
0005433634829	25225	Business	132900.00
0005433616780	25225	Business	132900.00
0005433616814	25225	Business	132900.00
0005433616563	25225	Business	132900.00
0005433616683	25225	Economy	48700.00
0005433634749	25225	Economy	48700.00
0005433634604	25225	Economy	44300.00
0005433578191	25225	Economy	44300.00
0005433578136	25225	Economy	44300.00
0005433578137	25225	Economy	44300.00
0005433616610	25225	Economy	44300.00
0005433616756	25225	Economy	44300.00
0005433634686	25225	Economy	44300.00
0005433616611	25225	Economy	44300.00
0005433616788	25225	Economy	44300.00
0005435983710	25225	Economy	44300.00
0005433578180	25225	Economy	44300.00
0005433578190	25225	Economy	44300.00
0005433616736	25225	Economy	44300.00
0005433616668	25225	Economy	44300.00
0005433616669	25225	Economy	44300.00
0005433616693	25225	Economy	44300.00
0005433634777	25225	Economy	44300.00
0005433616750	25225	Economy	44300.00
0005433616761	25225	Economy	48700.00
0005433616800	25225	Economy	48700.00
0005433616735	25225	Economy	48700.00
0005433616670	25225	Economy	48700.00
0005433578184	25225	Economy	44300.00
0005433616702	25225	Economy	44300.00
0005433634774	25225	Economy	44300.00
0005433634732	25225	Economy	48700.00
0005433578205	25225	Economy	44300.00
0005433634763	25225	Economy	44300.00
0005433616789	25225	Economy	44300.00
0005433634755	25225	Economy	44300.00
0005433634830	25225	Economy	44300.00
0005433616590	25225	Economy	44300.00
0005433616690	25225	Economy	44300.00
0005433616757	25225	Economy	44300.00
0005435983713	25225	Economy	44300.00
0005433616546	25225	Economy	44300.00
0005433634780	25225	Economy	44300.00
0005433616662	25225	Economy	44300.00
0005433616691	25225	Economy	44300.00
0005433616533	25225	Economy	44300.00
0005433634761	25225	Economy	44300.00
0005433634746	25225	Economy	44300.00
0005433578182	25225	Economy	44300.00
0005433616534	25225	Economy	44300.00
0005433616713	25225	Economy	44300.00
0005433616623	25225	Economy	44300.00
0005433634703	25225	Economy	44300.00
0005433616728	25225	Economy	44300.00
0005433616729	25225	Economy	44300.00
0005433616512	25225	Economy	44300.00
0005433616677	25225	Economy	44300.00
0005433616672	25225	Economy	44300.00
0005433616638	25225	Economy	44300.00
0005433616734	25225	Economy	44300.00
0005433578183	25225	Economy	44300.00
0005433616676	25225	Economy	44300.00
0005433616684	25225	Economy	44300.00
0005435947651	4243	Business	193100.00
0005432571430	4243	Business	193100.00
0005435947674	4243	Business	193100.00
0005435854084	4243	Business	193100.00
0005432571426	4243	Economy	64400.00
0005435947673	4243	Economy	64400.00
0005435947626	4243	Economy	64400.00
0005432571435	4243	Economy	64400.00
0005435856330	4243	Economy	64400.00
0005432571425	4243	Economy	64400.00
0005435947647	4243	Economy	64400.00
0005435856329	4243	Economy	64400.00
0005435947627	4243	Economy	64400.00
0005435947670	4243	Economy	70800.00
0005435856328	4243	Economy	64400.00
0005432571436	4243	Economy	64400.00
0005435947671	4243	Economy	64400.00
0005432571437	4243	Economy	64400.00
0005435947648	4243	Economy	64400.00
0005432949585	309	Business	21500.00
0005433075505	309	Business	21500.00
0005433134252	309	Business	21500.00
0005432949640	309	Business	21500.00
0005432949654	309	Business	21500.00
0005433075528	309	Business	21500.00
0005432949646	309	Business	21500.00
0005432949603	309	Business	21500.00
0005432949584	309	Business	21500.00
0005432949594	309	Economy	7900.00
0005433075461	309	Economy	7200.00
0005433075474	309	Economy	7200.00
0005433075489	309	Economy	7200.00
0005433129410	309	Economy	7200.00
0005433129407	309	Economy	7200.00
0005432949565	309	Economy	7200.00
0005432949514	309	Economy	7200.00
0005432949581	309	Economy	7200.00
0005433075484	309	Economy	7200.00
0005432949641	309	Economy	7200.00
0005432949518	309	Economy	7200.00
0005432949629	309	Economy	7200.00
0005432949630	309	Economy	7200.00
0005433075462	309	Economy	7200.00
0005433134251	309	Economy	7900.00
0005432949663	309	Economy	7200.00
0005432949662	309	Economy	7200.00
0005433075535	309	Economy	7200.00
0005432949681	309	Economy	7200.00
0005433075448	309	Economy	7200.00
0005432949655	309	Economy	7200.00
0005432949520	309	Economy	7200.00
0005432949680	309	Economy	7200.00
0005433129395	309	Economy	7200.00
0005432949645	309	Economy	7200.00
0005432949528	309	Economy	7200.00
0005432949517	309	Economy	7200.00
0005433075504	309	Economy	7200.00
0005433075475	309	Economy	7200.00
0005432949639	309	Economy	7200.00
0005432949508	309	Economy	7200.00
0005432949653	309	Economy	7200.00
0005433075514	309	Economy	7200.00
0005432949513	309	Economy	7200.00
0005432949519	309	Economy	7200.00
0005433075540	309	Economy	7200.00
0005432949580	309	Economy	7200.00
0005432949564	309	Economy	7200.00
0005433129411	309	Economy	7200.00
0005433570638	11613	Business	21500.00
0005433570656	11613	Business	21500.00
0005433570896	11613	Business	21500.00
0005433570639	11613	Business	21500.00
0005433570901	11613	Business	21500.00
0005433570909	11613	Business	21500.00
0005433570681	11613	Business	21500.00
0005433570982	11613	Economy	7900.00
0005433570647	11613	Economy	7200.00
0005433570805	11613	Economy	7200.00
0005433570837	11613	Economy	7200.00
0005433570613	11613	Economy	7200.00
0005433570683	11613	Economy	7200.00
0005433570614	11613	Economy	7200.00
0005434326025	11613	Economy	7200.00
0005434088059	11613	Economy	7200.00
0005433570850	11613	Economy	7200.00
0005433570792	11613	Economy	7200.00
0005433570836	11613	Economy	7200.00
0005434088032	11613	Economy	7200.00
0005433570774	11613	Economy	7200.00
0005433570787	11613	Economy	7200.00
0005433570859	11613	Economy	7200.00
0005433570803	11613	Economy	7200.00
0005433570778	11613	Economy	7200.00
0005433570873	11613	Economy	7200.00
0005433570786	11613	Economy	7200.00
0005433570795	11613	Economy	7200.00
0005433570773	11613	Economy	7200.00
0005434087970	11613	Economy	7200.00
0005434088035	11613	Economy	7200.00
0005433570793	11613	Economy	7200.00
0005433570696	11613	Economy	7200.00
0005433570810	11613	Economy	7200.00
0005433570706	11613	Economy	7900.00
0005434087984	11613	Economy	7900.00
0005433570695	11613	Economy	7900.00
0005434088025	11613	Economy	7900.00
0005433570690	11613	Economy	7200.00
0005433570867	11613	Economy	7200.00
0005433570626	11613	Economy	7200.00
0005434326015	11613	Economy	7200.00
0005434088060	11613	Economy	7200.00
0005434088033	11613	Economy	7200.00
0005433570666	11613	Economy	7200.00
0005433570861	11613	Economy	7200.00
0005433570902	11613	Economy	7200.00
0005433570872	11613	Economy	7200.00
0005434088028	11613	Economy	7200.00
0005434326041	11613	Economy	7200.00
0005433570610	11613	Economy	7200.00
0005434087969	11613	Economy	7200.00
0005434088026	11613	Economy	7200.00
0005433570707	11613	Economy	7200.00
0005433570848	11613	Economy	7200.00
0005434326040	11613	Economy	7200.00
0005433570611	11613	Economy	7200.00
0005433570849	11613	Economy	7200.00
0005433570766	11613	Economy	7200.00
0005433570788	11613	Economy	7200.00
0005433570804	11613	Economy	7200.00
0005433570802	11613	Economy	7200.00
0005433570655	11613	Economy	7200.00
0005433570767	11613	Economy	7200.00
0005433570646	11613	Economy	7200.00
0005433570548	11613	Economy	7200.00
0005433570471	11613	Economy	7200.00
0005434088020	11613	Economy	7200.00
0005433570691	11613	Economy	7200.00
0005434088021	11613	Economy	7200.00
0005433570846	11613	Economy	7200.00
0005433570857	11613	Economy	7200.00
0005433570845	11613	Economy	7200.00
0005434731283	2367	Business	184500.00
0005432985934	2367	Economy	67700.00
0005432985892	2367	Economy	61500.00
0005432985971	2367	Economy	61500.00
0005432985954	2367	Economy	61500.00
0005432985893	2367	Economy	61500.00
0005434731270	2367	Economy	61500.00
0005433435441	2367	Economy	61500.00
0005432985964	2367	Economy	61500.00
0005434376165	2367	Economy	61500.00
0005432985933	2367	Economy	61500.00
0005433435442	2367	Economy	61500.00
0005433435424	2367	Economy	67700.00
0005433435395	2367	Economy	61500.00
0005433435423	2367	Economy	61500.00
0005434376168	2367	Economy	61500.00
0005433435484	2367	Economy	61500.00
0005433435492	2367	Economy	61500.00
0005433435500	2367	Economy	61500.00
0005433435501	2367	Economy	61500.00
0005434731288	2367	Economy	61500.00
0005433435485	2367	Economy	61500.00
0005432985970	2367	Economy	61500.00
0005432986011	2367	Economy	61500.00
0005432985973	2367	Economy	61500.00
0005433435499	2367	Economy	61500.00
0005433435483	2367	Economy	61500.00
0005433766750	26214	Business	184500.00
0005433755862	26214	Business	184500.00
0005433755559	26214	Business	184500.00
0005433755864	26214	Business	184500.00
0005435983427	26214	Business	184500.00
0005433755727	26214	Business	184500.00
0005435983545	26214	Business	184500.00
0005435983528	26214	Business	184500.00
0005435983502	26214	Economy	67700.00
0005433755847	26214	Economy	61500.00
0005432655869	26214	Economy	61500.00
0005435983503	26214	Economy	61500.00
0005435983529	26214	Economy	61500.00
0005433755826	26214	Economy	61500.00
0005435983589	26214	Economy	61500.00
0005433755828	26214	Economy	61500.00
0005433766761	26214	Economy	61500.00
0005433755776	26214	Economy	61500.00
0005433755771	26214	Economy	61500.00
0005435983602	26214	Economy	61500.00
0005432655859	26214	Economy	61500.00
0005433755817	26214	Economy	61500.00
0005435983657	26214	Economy	61500.00
0005435983674	26214	Economy	61500.00
0005433755848	26214	Economy	61500.00
0005433755781	26214	Economy	61500.00
0005435983577	26214	Economy	61500.00
0005435983558	26214	Economy	61500.00
0005433755795	26214	Economy	61500.00
0005433755854	26214	Economy	61500.00
0005433755881	26214	Economy	61500.00
0005435983515	26214	Economy	61500.00
0005432655866	26214	Economy	61500.00
0005435983530	26214	Economy	61500.00
0005433755880	26214	Economy	61500.00
0005435983449	26214	Economy	61500.00
0005435983562	26214	Economy	61500.00
0005432655864	26214	Economy	61500.00
0005435983513	26214	Economy	61500.00
0005433755732	26214	Economy	61500.00
0005435983544	26214	Economy	61500.00
0005435983594	26214	Economy	61500.00
0005435983559	26214	Economy	61500.00
0005435983511	26214	Economy	61500.00
0005435983637	26214	Economy	61500.00
0005433755772	26214	Economy	61500.00
0005435983531	26214	Economy	61500.00
0005435983576	26214	Economy	67700.00
0005433755827	26214	Economy	67700.00
0005435983500	26214	Economy	61500.00
0005433755875	26214	Economy	61500.00
0005433755794	26214	Economy	61500.00
0005433755876	26214	Economy	61500.00
0005435983578	26214	Economy	61500.00
0005435983563	26214	Economy	61500.00
0005433755797	26214	Economy	61500.00
0005435983662	26214	Economy	61500.00
0005433755734	26214	Economy	61500.00
0005433755558	26214	Economy	61500.00
0005435983628	26214	Economy	61500.00
0005433755735	26214	Economy	61500.00
0005435983548	26214	Economy	61500.00
0005433755620	26214	Economy	61500.00
0005432655865	26214	Economy	61500.00
0005433755796	26214	Economy	61500.00
0005433755821	26214	Economy	61500.00
0005432655862	26214	Economy	61500.00
0005433755866	26214	Economy	61500.00
0005432655863	26214	Economy	61500.00
0005433755865	26214	Economy	61500.00
0005435983486	26214	Economy	61500.00
0005435983575	26214	Economy	61500.00
0005435983450	26214	Economy	61500.00
0005433755726	26214	Economy	61500.00
0005435983666	26214	Economy	61500.00
0005435983485	26214	Economy	61500.00
0005433931545	1504	Business	38900.00
0005433152370	1504	Economy	13000.00
0005433931546	1504	Economy	13000.00
0005433152396	1504	Economy	13000.00
0005433931559	1504	Economy	13000.00
0005433152400	1504	Economy	13000.00
0005433931547	1504	Economy	13000.00
0005433931558	1504	Economy	13000.00
0005433152394	1504	Economy	13000.00
0005434375983	20124	Business	38900.00
0005434376056	20124	Business	38900.00
0005434376005	20124	Business	38900.00
0005434376038	20124	Business	38900.00
0005434375945	20124	Business	38900.00
0005434376009	20124	Economy	13000.00
0005434376028	20124	Economy	13000.00
0005434375981	20124	Economy	13000.00
0005434376003	20124	Economy	13000.00
0005434376165	20124	Economy	13000.00
0005434375998	20124	Economy	13000.00
0005434376001	20124	Economy	13000.00
0005434375958	20124	Economy	13000.00
0005434375953	20124	Economy	13000.00
0005434375860	20124	Economy	13000.00
0005434376026	20124	Economy	13000.00
0005434376052	20124	Economy	13000.00
0005434375855	20124	Economy	13000.00
0005434375952	20124	Economy	13000.00
0005434375954	20124	Economy	13000.00
0005434376027	20124	Economy	13000.00
0005434376008	20124	Economy	13000.00
0005434376064	20124	Economy	13000.00
0005434376004	20124	Economy	13000.00
0005434376029	20124	Economy	13000.00
0005434375921	20124	Economy	13000.00
0005434376168	20124	Economy	13000.00
0005434375940	20124	Economy	13000.00
0005434376190	20124	Economy	13000.00
0005434376051	20124	Economy	13000.00
0005434376050	20124	Economy	13000.00
0005433261972	579	Business	27500.00
0005433261973	579	Economy	10100.00
0005433157018	579	Business	27500.00
0005433262033	579	Economy	9200.00
0005433261966	579	Economy	9200.00
0005433261998	579	Economy	9200.00
0005433261990	579	Economy	9200.00
0005433261924	579	Economy	9200.00
0005433261965	579	Economy	9200.00
0005433157017	579	Economy	9200.00
0005433262020	579	Economy	10100.00
0005433262049	579	Economy	9200.00
0005433261997	579	Economy	9200.00
0005433261974	579	Economy	9200.00
0005433261975	579	Economy	9200.00
0005433766764	579	Economy	9200.00
0005433262054	579	Economy	9200.00
0005433261996	579	Economy	9200.00
0005433262051	579	Economy	9200.00
0005433262032	579	Economy	9200.00
0005433262048	579	Economy	9200.00
0005434995370	12857	Economy	9200.00
0005432425823	12873	Business	27500.00
0005432425749	12873	Business	27500.00
0005432425877	12873	Business	27500.00
0005432425882	12873	Business	27500.00
0005432425805	12873	Business	27500.00
0005432425903	12873	Business	27500.00
0005432425804	12873	Business	27500.00
0005432425973	12873	Business	27500.00
0005432425964	12873	Economy	10100.00
0005432426020	12873	Economy	10100.00
0005432425922	12873	Economy	9200.00
0005432425820	12873	Economy	9200.00
0005432425885	12873	Economy	9200.00
0005432426007	12873	Economy	9200.00
0005432425704	12873	Economy	9200.00
0005432425675	12873	Economy	9200.00
0005432425988	12873	Economy	9200.00
0005432425889	12873	Economy	9200.00
0005432425915	12873	Economy	9200.00
0005432425806	12873	Economy	9200.00
0005432425828	12873	Economy	9200.00
0005432425995	12873	Economy	9200.00
0005432425844	12873	Economy	9200.00
0005432425750	12873	Economy	9200.00
0005432425827	12873	Economy	9200.00
0005432425945	12873	Economy	9200.00
0005432425902	12873	Economy	9200.00
0005432426053	12873	Economy	9200.00
0005432425854	12873	Economy	9200.00
0005432425932	12873	Economy	9200.00
0005432425622	12873	Economy	9200.00
0005432425579	12873	Economy	9200.00
0005432425705	12873	Economy	9200.00
0005432425972	12873	Economy	9200.00
0005432425829	12873	Economy	9200.00
0005432426035	12873	Economy	10100.00
0005432426021	12873	Economy	10100.00
0005432425837	12873	Economy	10100.00
0005432426006	12873	Economy	9200.00
0005432425888	12873	Economy	9200.00
0005432425819	12873	Economy	9200.00
0005432425980	12873	Economy	9200.00
0005432425822	12873	Economy	9200.00
0005432425924	12873	Economy	9200.00
0005432425748	12873	Economy	9200.00
0005432425933	12873	Economy	9200.00
0005432425791	12873	Economy	9200.00
0005432426041	12873	Economy	9200.00
0005432426040	12873	Economy	9200.00
0005432425784	12873	Economy	9200.00
0005432425969	12873	Economy	9200.00
0005432425878	12873	Economy	9200.00
0005432425621	12873	Economy	9200.00
0005432425971	12873	Economy	9200.00
0005432425968	12873	Economy	9200.00
0005432425830	12873	Economy	9200.00
0005432425934	12873	Economy	9200.00
0005432425869	12873	Economy	9200.00
0005432426076	12873	Economy	9200.00
0005432426036	12873	Economy	9200.00
0005432425715	12873	Economy	9200.00
0005432425848	12873	Economy	9200.00
0005432425849	12873	Economy	9200.00
0005432426057	12873	Economy	9200.00
0005432425580	12873	Economy	9200.00
0005432425958	12873	Economy	9200.00
0005432425792	12873	Economy	9200.00
0005432425714	12873	Economy	9200.00
0005432425873	12873	Economy	9200.00
0005432425928	12873	Economy	9200.00
0005432425736	12873	Economy	9200.00
0005432425979	12873	Economy	9200.00
0005432425870	12873	Economy	9200.00
0005433059066	456	Business	24500.00
0005433059001	456	Business	24500.00
0005433929729	456	Business	24500.00
0005433059058	456	Business	24500.00
0005433059047	456	Economy	9000.00
0005433058998	456	Economy	9000.00
0005434376239	456	Economy	8200.00
0005433684480	456	Economy	8200.00
0005434376237	456	Economy	8200.00
0005433059027	456	Economy	8200.00
0005433929727	456	Economy	8200.00
0005433929720	456	Economy	8200.00
0005434735822	456	Economy	8200.00
0005433684481	456	Economy	8200.00
0005433059000	456	Economy	8200.00
0005433059016	456	Economy	8200.00
0005434376232	456	Economy	8200.00
0005434735819	456	Economy	8200.00
0005433684474	456	Economy	8200.00
0005433058994	456	Economy	9000.00
0005433684479	456	Economy	8200.00
0005434735820	456	Economy	8200.00
0005433058947	456	Economy	8200.00
0005433929724	456	Economy	8200.00
0005433059020	456	Economy	8200.00
0005434376238	456	Economy	8200.00
0005433684475	456	Economy	8200.00
0005434735824	456	Economy	8200.00
0005434376233	456	Economy	8200.00
0005433058971	456	Economy	8200.00
0005433929728	456	Economy	8200.00
0005433059015	456	Economy	8200.00
0005434376234	456	Economy	8200.00
0005434025567	12660	Business	24500.00
0005434025570	12660	Business	24500.00
0005434025660	12660	Business	24500.00
0005434025549	12660	Economy	9000.00
0005434025346	12660	Economy	8200.00
0005434025532	12660	Economy	8200.00
0005434025347	12660	Economy	8200.00
0005434025625	12660	Economy	8200.00
0005434025674	12660	Economy	8200.00
0005434025501	12660	Economy	8200.00
0005434025515	12660	Economy	8200.00
0005434025626	12660	Economy	8200.00
0005434025348	12660	Economy	8200.00
0005434032150	12660	Economy	8200.00
0005434025631	12660	Economy	8200.00
0005434025531	12660	Economy	8200.00
0005434025350	12660	Economy	9000.00
0005434025569	12660	Economy	8200.00
0005434028392	12660	Economy	8200.00
0005434025545	12660	Economy	8200.00
0005434025613	12660	Economy	8200.00
0005434028393	12660	Economy	8200.00
0005434025690	12660	Economy	8200.00
0005434025471	12660	Economy	8200.00
0005434025689	12660	Economy	8200.00
0005434025546	12660	Economy	8200.00
0005434025649	12660	Economy	8200.00
0005434025661	12660	Economy	8200.00
0005434025688	12660	Economy	8200.00
0005434025349	12660	Economy	8200.00
0005434025659	12660	Economy	8200.00
0005434025672	12660	Economy	8200.00
0005434025671	12660	Economy	8200.00
0005434025472	12660	Economy	8200.00
0005433037816	2123	Business	34700.00
0005434028392	2123	Business	34700.00
0005433037589	2123	Business	34700.00
0005433037814	2123	Business	34700.00
0005433037828	2123	Business	34700.00
0005433037827	2123	Economy	12700.00
0005433037811	2123	Economy	11600.00
0005434028393	2123	Economy	11600.00
0005433037710	2123	Economy	11600.00
0005433037588	2123	Economy	11600.00
0005434376190	2123	Economy	11600.00
0005433037807	2123	Economy	11600.00
0005432749846	2123	Economy	11600.00
0005433037756	2123	Economy	11600.00
0005433037772	2123	Economy	11600.00
0005433037798	2123	Economy	11600.00
0005433037843	2123	Economy	11600.00
0005433037653	2123	Economy	11600.00
0005433037813	2123	Economy	11600.00
0005433037757	2123	Economy	11600.00
0005433037590	2123	Economy	11600.00
0005433037839	2123	Economy	11600.00
0005433037745	2123	Economy	11600.00
0005433926061	24101	Business	34700.00
0005433929719	24101	Business	34700.00
0005433925737	24101	Business	34700.00
0005433926114	24101	Business	34700.00
0005433925957	24101	Business	34700.00
0005433926102	24101	Business	34700.00
0005433925809	24101	Business	34700.00
0005433926115	24101	Business	34700.00
0005433925870	24101	Business	34700.00
0005433925981	24101	Business	34700.00
0005433925976	24101	Business	34700.00
0005433925965	24101	Economy	12700.00
0005433925966	24101	Economy	12700.00
0005433925878	24101	Economy	11600.00
0005433925962	24101	Economy	11600.00
0005433926089	24101	Economy	11600.00
0005433925641	24101	Economy	11600.00
0005433925961	24101	Economy	11600.00
0005433926032	24101	Economy	11600.00
0005433926041	24101	Economy	11600.00
0005433925675	24101	Economy	11600.00
0005433926018	24101	Economy	11600.00
0005433925682	24101	Economy	11600.00
0005433926002	24101	Economy	11600.00
0005433925974	24101	Economy	11600.00
0005433925869	24101	Economy	11600.00
0005433929725	24101	Economy	11600.00
0005433925879	24101	Economy	11600.00
0005433925995	24101	Economy	11600.00
0005433925853	24101	Economy	11600.00
0005433926110	24101	Economy	11600.00
0005433926042	24101	Economy	11600.00
0005433929890	24101	Economy	11600.00
0005433925947	24101	Economy	11600.00
0005433925908	24101	Economy	11600.00
0005433926079	24101	Economy	11600.00
0005433925910	24101	Economy	11600.00
0005433929895	24101	Economy	11600.00
0005433926011	24101	Economy	11600.00
0005433926080	24101	Economy	11600.00
0005433925589	24101	Economy	11600.00
0005433931554	24101	Economy	11600.00
0005433925877	24101	Economy	11600.00
0005433926088	24101	Economy	11600.00
0005433926014	24101	Economy	11600.00
0005433925681	24101	Economy	11600.00
0005433926077	24101	Economy	11600.00
0005433926058	24101	Economy	11600.00
0005433926043	24101	Economy	11600.00
0005433929891	24101	Economy	11600.00
0005433926101	24101	Economy	11600.00
0005433925810	24101	Economy	11600.00
0005433925967	24101	Economy	11600.00
0005433926093	24101	Economy	11600.00
0005433925963	24101	Economy	11600.00
0005433925994	24101	Economy	11600.00
0005433926040	24101	Economy	11600.00
0005433926012	24101	Economy	11600.00
0005433926013	24101	Economy	11600.00
0005433235867	280	Business	83700.00
0005433766738	280	Business	83700.00
0005433235939	280	Business	83700.00
0005433181779	280	Business	83700.00
0005433235917	280	Business	83700.00
0005433131836	280	Business	83700.00
0005433181796	280	Business	83700.00
0005433290059	280	Business	83700.00
0005433181813	280	Business	83700.00
0005433181738	280	Business	83700.00
0005434032153	280	Comfort	47400.00
0005433235868	280	Comfort	47400.00
0005433181802	280	Comfort	47400.00
0005433181765	280	Comfort	47400.00
0005433113594	280	Comfort	47400.00
0005433236049	280	Comfort	47400.00
0005433236005	280	Comfort	47400.00
0005433181803	280	Comfort	47400.00
0005433235903	280	Comfort	47400.00
0005433235848	280	Economy	27900.00
0005433235981	280	Economy	27900.00
0005433235884	280	Economy	27900.00
0005433235872	280	Economy	27900.00
0005433236013	280	Economy	27900.00
0005433235951	280	Economy	27900.00
0005433235970	280	Economy	27900.00
0005433766748	280	Economy	27900.00
0005433235849	280	Economy	27900.00
0005433235904	280	Economy	27900.00
0005433236012	280	Economy	27900.00
0005433235956	280	Economy	27900.00
0005433235940	280	Economy	27900.00
0005433235902	280	Economy	27900.00
0005433236014	280	Economy	27900.00
0005433181797	280	Economy	27900.00
0005433235873	280	Economy	27900.00
0005433235934	280	Economy	27900.00
0005433236064	280	Economy	27900.00
0005433235982	280	Economy	27900.00
0005433131843	280	Economy	27900.00
0005433235952	280	Economy	27900.00
0005433235969	280	Economy	27900.00
0005433181725	280	Economy	27900.00
0005433181828	280	Economy	27900.00
0005433290022	280	Economy	27900.00
0005433235921	280	Economy	27900.00
0005433766749	280	Economy	27900.00
0005433181829	280	Economy	27900.00
0005433236061	280	Economy	27900.00
0005433235863	280	Economy	27900.00
0005433126974	280	Economy	27900.00
0005433126979	280	Economy	27900.00
0005433181812	280	Economy	27900.00
0005433235922	280	Economy	27900.00
0005433236050	280	Economy	27900.00
0005433236063	280	Economy	27900.00
0005433181801	280	Economy	27900.00
0005433235938	280	Economy	27900.00
0005433235871	280	Economy	27900.00
0005433131842	280	Economy	27900.00
0005433181818	280	Economy	27900.00
0005433236062	280	Economy	27900.00
0005433181715	280	Economy	27900.00
0005433236023	280	Economy	27900.00
0005433290021	280	Economy	27900.00
0005433235974	280	Economy	27900.00
0005433235935	280	Economy	27900.00
0005433131837	280	Economy	27900.00
0005433290055	280	Economy	27900.00
0005434728888	9830	Business	83700.00
0005434728567	9830	Business	83700.00
0005434728701	9830	Business	83700.00
0005434552801	9830	Business	83700.00
0005434728963	9830	Business	83700.00
0005434728931	9830	Business	83700.00
0005434552643	9830	Business	83700.00
0005434552664	9830	Comfort	47400.00
0005434728429	9830	Comfort	47400.00
0005434728770	9830	Comfort	47400.00
0005434735816	9830	Comfort	47400.00
0005434731283	9830	Comfort	47400.00
0005434728884	9830	Comfort	47400.00
0005434735817	9830	Comfort	47400.00
0005434728564	9830	Comfort	47400.00
0005435142936	9830	Comfort	47400.00
0005434552852	9830	Comfort	47400.00
0005434728951	9830	Comfort	47400.00
0005434735828	9830	Comfort	47400.00
0005434735815	9830	Economy	27900.00
0005434728982	9830	Economy	27900.00
0005434728566	9830	Economy	27900.00
0005434728930	9830	Economy	27900.00
0005435142934	9830	Economy	27900.00
0005435142940	9830	Economy	27900.00
0005435142892	9830	Economy	27900.00
0005434552822	9830	Economy	27900.00
0005434728962	9830	Economy	27900.00
0005434728565	9830	Economy	27900.00
0005434552831	9830	Economy	27900.00
0005434731270	9830	Economy	27900.00
0005434729014	9830	Economy	27900.00
0005434728807	9830	Economy	27900.00
0005434728808	9830	Economy	30700.00
0005434552853	9830	Economy	27900.00
0005434728976	9830	Economy	27900.00
0005434302579	9830	Economy	27900.00
0005434728855	9830	Economy	27900.00
0005435142943	9830	Economy	27900.00
0005434728990	9830	Economy	27900.00
0005434728948	9830	Economy	27900.00
0005434552722	9830	Economy	27900.00
0005434728956	9830	Economy	27900.00
0005434728912	9830	Economy	27900.00
0005434729047	9830	Economy	27900.00
0005434728590	9830	Economy	27900.00
0005434731288	9830	Economy	27900.00
0005434552561	9830	Economy	27900.00
0005434552840	9830	Economy	27900.00
0005434552866	9830	Economy	27900.00
0005434728896	9830	Economy	27900.00
0005434728991	9830	Economy	27900.00
0005434552754	9830	Economy	27900.00
0005434728430	9830	Economy	27900.00
0005434728252	9830	Economy	27900.00
0005434302573	9830	Economy	27900.00
0005434729003	9830	Economy	27900.00
0005434729038	9830	Economy	27900.00
0005434729048	9830	Economy	27900.00
0005434728899	9830	Economy	27900.00
0005434728871	9830	Economy	27900.00
0005435142967	9830	Economy	27900.00
0005434728551	9830	Economy	27900.00
0005434728910	9830	Economy	27900.00
0005434728370	9830	Economy	30700.00
0005434552770	9830	Economy	30700.00
0005434728885	9830	Economy	27900.00
0005434552698	9830	Economy	27900.00
0005434552814	9830	Economy	27900.00
0005434728611	9830	Economy	27900.00
0005434552633	9830	Economy	27900.00
0005434728574	9830	Economy	27900.00
0005434552855	9830	Economy	27900.00
0005434728909	9830	Economy	27900.00
0005434552854	9830	Economy	27900.00
0005434728575	9830	Economy	27900.00
0005434728940	9830	Economy	27900.00
0005434735838	9830	Economy	27900.00
0005434552789	9830	Economy	27900.00
0005434728870	9830	Economy	27900.00
0005434728809	9830	Economy	27900.00
0005434552832	9830	Economy	27900.00
0005434728837	9830	Economy	27900.00
0005434735818	9830	Economy	27900.00
0005434552743	9830	Economy	27900.00
0005434552665	9830	Economy	27900.00
0005435142935	9830	Economy	27900.00
0005434552755	9830	Economy	27900.00
0005434552805	9830	Economy	27900.00
0005434552788	9830	Economy	27900.00
0005434735827	9830	Economy	27900.00
0005434552562	9830	Economy	27900.00
0005434735814	9830	Economy	27900.00
0005435725739	7743	Business	42100.00
0005435215468	7743	Business	42100.00
0005435283518	7743	Business	42100.00
0005435215472	7743	Business	42100.00
0005435283485	7743	Comfort	23900.00
0005435283508	7743	Comfort	23900.00
0005435215439	7743	Comfort	23900.00
0005435215513	7743	Comfort	23900.00
0005435283469	7743	Comfort	23900.00
0005435215445	7743	Comfort	23900.00
0005435215326	7743	Economy	14000.00
0005435215480	7743	Economy	14000.00
0005435283547	7743	Economy	14000.00
0005435215483	7743	Economy	14000.00
0005435283534	7743	Economy	14000.00
0005435215510	7743	Economy	14000.00
0005435283549	7743	Economy	14000.00
0005435215303	7743	Economy	14000.00
0005435283476	7743	Economy	14000.00
0005435215379	7743	Economy	15400.00
0005435283550	7743	Economy	14000.00
0005435215512	7743	Economy	14000.00
0005435215511	7743	Economy	14000.00
0005435283492	7743	Economy	14000.00
0005435215454	7743	Economy	14000.00
0005435215182	7743	Economy	14000.00
0005435215327	7743	Economy	14000.00
0005435215435	7743	Economy	14000.00
0005435215387	7743	Economy	14000.00
0005435283478	7743	Economy	14000.00
0005435215463	7743	Economy	14000.00
0005435215433	7743	Economy	14000.00
0005435283533	7743	Economy	14000.00
0005435215523	7743	Economy	14000.00
0005435215378	7743	Economy	14000.00
0005433656755	7743	Economy	14000.00
0005435283548	7743	Economy	15400.00
0005435215386	7743	Economy	15400.00
0005435215302	7743	Economy	14000.00
0005433656765	7743	Economy	14000.00
0005435283486	7743	Economy	14000.00
0005435215518	7743	Economy	14000.00
0005435215325	7743	Economy	14000.00
0005435215444	7743	Economy	14000.00
0005433656764	7743	Economy	14000.00
0005435215495	7743	Economy	14000.00
0005435215267	7743	Economy	14000.00
0005435283477	7743	Economy	14000.00
0005435215412	7743	Economy	14000.00
0005435215467	7743	Economy	14000.00
0005435215324	7743	Economy	14000.00
0005435215438	7743	Economy	14000.00
0005435283493	7743	Economy	14000.00
0005435631050	7743	Economy	14000.00
0005434245845	5350	Business	43100.00
0005435426822	5350	Business	43100.00
0005434245843	5350	Business	43100.00
0005435426846	5350	Business	43100.00
0005434245803	5350	Business	43100.00
0005435426796	5350	Business	43100.00
0005435426741	5350	Business	43100.00
0005434245821	5350	Comfort	24400.00
0005434245806	5350	Comfort	24400.00
0005434245793	5350	Comfort	24400.00
0005435426821	5350	Comfort	24400.00
0005435426840	5350	Comfort	24400.00
0005435426689	5350	Comfort	24400.00
0005435426805	5350	Comfort	24400.00
0005434245844	5350	Comfort	24400.00
0005435426547	5350	Comfort	24400.00
0005435426548	5350	Comfort	24400.00
0005433719228	5350	Comfort	24400.00
0005435426694	5350	Economy	14400.00
0005435426690	5350	Economy	14400.00
0005435426810	5350	Economy	14400.00
0005435426829	5350	Economy	14400.00
0005435426797	5350	Economy	14400.00
0005435426845	5350	Economy	14400.00
0005435426762	5350	Economy	14400.00
0005435426660	5350	Economy	14400.00
0005432841071	5350	Economy	14400.00
0005434245773	5350	Economy	14400.00
0005434245730	5350	Economy	14400.00
0005434245811	5350	Economy	14400.00
0005435302336	5350	Economy	14400.00
0005435426838	5350	Economy	14400.00
0005435305066	5350	Economy	14400.00
0005434245807	5350	Economy	14400.00
0005435426738	5350	Economy	14400.00
0005435426781	5350	Economy	14400.00
0005435426798	5350	Economy	14400.00
0005434245812	5350	Economy	14400.00
0005433719235	5350	Economy	14400.00
0005434245822	5350	Economy	14400.00
0005435302335	5350	Economy	14400.00
0005435426844	5350	Economy	14400.00
0005434245836	5350	Economy	14400.00
0005435768114	5350	Economy	14400.00
0005434245815	5350	Economy	14400.00
0005435426740	5350	Economy	14400.00
0005435768115	5350	Economy	14400.00
0005435768113	5350	Economy	14400.00
0005435302300	5350	Economy	14400.00
0005435654515	5350	Economy	14400.00
0005434245805	5350	Economy	14400.00
0005434245834	5350	Economy	14400.00
0005434245708	5350	Economy	14400.00
0005435380430	5350	Economy	15800.00
0005435426662	5350	Economy	14400.00
0005435305081	5350	Economy	14400.00
0005435426761	5350	Economy	14400.00
0005435426742	5350	Economy	14400.00
0005435305067	5350	Economy	14400.00
0005435426763	5350	Economy	14400.00
0005435042926	5350	Economy	14400.00
0005434245777	5350	Economy	14400.00
0005434245804	5350	Economy	14400.00
0005435426820	5350	Economy	14400.00
0005434245808	5350	Economy	14400.00
0005434245778	5350	Economy	14400.00
0005432841072	5350	Economy	14400.00
0005435426795	5350	Economy	14400.00
0005435426600	5350	Economy	14400.00
0005435616768	10889	Business	43100.00
0005435616748	10889	Business	43100.00
0005434345195	10889	Business	43100.00
0005435616927	10889	Business	43100.00
0005434573700	10889	Business	43100.00
0005435616398	10889	Business	43100.00
0005435616892	10889	Business	43100.00
0005435616909	10889	Comfort	24400.00
0005434345202	10889	Comfort	24400.00
0005435616926	10889	Comfort	24400.00
0005434345280	10889	Comfort	24400.00
0005435616767	10889	Comfort	24400.00
0005435097477	10889	Comfort	24400.00
0005435617039	10889	Comfort	24400.00
0005435616691	10889	Comfort	24400.00
0005435616779	10889	Comfort	24400.00
0005435616397	10889	Comfort	24400.00
0005435616808	10889	Comfort	24400.00
0005435490336	10889	Comfort	24400.00
0005434573739	10889	Comfort	24400.00
0005435616449	10889	Comfort	24400.00
0005435617206	10889	Comfort	24400.00
0005435616849	10889	Comfort	24400.00
0005435616988	10889	Comfort	24400.00
0005434345155	10889	Comfort	24400.00
0005434345045	10889	Comfort	24400.00
0005435616744	10889	Economy	14400.00
0005435616807	10889	Economy	14400.00
0005435616806	10889	Economy	14400.00
0005435616996	10889	Economy	14400.00
0005434345166	10889	Economy	14400.00
0005435616997	10889	Economy	14400.00
0005434573709	10889	Economy	14400.00
0005435490337	10889	Economy	14400.00
0005434345044	10889	Economy	14400.00
0005434573724	10889	Economy	14400.00
0005434344999	10889	Economy	14400.00
0005435617012	10889	Economy	14400.00
0005435097479	10889	Economy	14400.00
0005435616959	10889	Economy	14400.00
0005435616814	10889	Economy	14400.00
0005434344998	10889	Economy	14400.00
0005435616646	10889	Economy	14400.00
0005435616891	10889	Economy	14400.00
0005435616922	10889	Economy	14400.00
0005435617198	10889	Economy	14400.00
0005435097461	10889	Economy	14400.00
0005435616948	10889	Economy	14400.00
0005435616942	10889	Economy	14400.00
0005434345263	10889	Economy	14400.00
0005435617022	10889	Economy	14400.00
0005434345178	10889	Economy	14400.00
0005435617011	10889	Economy	14400.00
0005434345203	10889	Economy	14400.00
0005435616962	10889	Economy	14400.00
0005435617212	10889	Economy	14400.00
0005434573735	10889	Economy	14400.00
0005435555424	10889	Economy	14400.00
0005435616908	10889	Economy	14400.00
0005435616859	10889	Economy	14400.00
0005434573740	10889	Economy	14400.00
0005434345279	10889	Economy	14400.00
0005435616954	10889	Economy	14400.00
0005435616953	10889	Economy	14400.00
0005435617199	10889	Economy	14400.00
0005434573753	10889	Economy	14400.00
0005434345281	10889	Economy	14400.00
0005435616780	10889	Economy	14400.00
0005435616747	10889	Economy	14400.00
0005435616838	10889	Economy	14400.00
0005434573768	10889	Economy	14400.00
0005435626884	10889	Economy	14400.00
0005435097480	10889	Economy	15800.00
0005434345075	10889	Economy	14400.00
0005435616613	10889	Economy	14400.00
0005434573701	10889	Economy	14400.00
0005434573725	10889	Economy	14400.00
0005434345158	10889	Economy	14400.00
0005435616911	10889	Economy	14400.00
0005434345179	10889	Economy	14400.00
0005435616913	10889	Economy	14400.00
0005435616609	10889	Economy	14400.00
0005435616925	10889	Economy	14400.00
0005435616851	10889	Economy	14400.00
0005435616904	10889	Economy	14400.00
0005435617010	10889	Economy	14400.00
0005435616610	10889	Economy	14400.00
0005434345165	10889	Economy	14400.00
0005435097489	10889	Economy	14400.00
0005435616839	10889	Economy	14400.00
0005434345224	10889	Economy	14400.00
0005435617029	10889	Economy	14400.00
0005434573694	10889	Economy	14400.00
0005435616681	10889	Economy	14400.00
0005434573766	10889	Economy	14400.00
0005434573723	10889	Economy	14400.00
0005435616793	10889	Economy	14400.00
0005434573708	10889	Economy	14400.00
0005435617013	10889	Economy	14400.00
0005435097490	10889	Economy	14400.00
0005435617213	10889	Economy	14400.00
0005435617205	10889	Economy	14400.00
0005435616743	10889	Economy	14400.00
0005435860725	3395	Business	18800.00
0005432461403	3395	Business	18800.00
0005432461348	3395	Business	18800.00
0005432461030	3395	Business	18800.00
0005435858725	3395	Business	18800.00
0005432461324	3395	Business	18800.00
0005432461258	3395	Economy	6300.00
0005432461370	3395	Economy	6300.00
0005432461160	3395	Economy	6300.00
0005434312397	3395	Economy	6300.00
0005432461428	3395	Economy	6300.00
0005432461429	3395	Economy	6300.00
0005435860710	3395	Economy	6300.00
0005435858713	3395	Economy	6300.00
0005432461259	3395	Economy	6300.00
0005432461359	3395	Economy	6300.00
0005435860716	3395	Economy	6300.00
0005435858740	3395	Economy	6300.00
0005435856362	3395	Economy	6300.00
0005432461351	3395	Economy	6300.00
0005434326061	3395	Economy	6300.00
0005432461404	3395	Economy	6300.00
0005435860685	3395	Economy	6300.00
0005435860723	3395	Economy	6300.00
0005435142992	3395	Economy	6300.00
0005435933577	3395	Economy	6900.00
0005434312398	3395	Economy	6900.00
0005435858731	3395	Economy	6300.00
0005432461352	3395	Economy	6300.00
0005432461261	3395	Economy	6900.00
0005435858714	3395	Economy	6300.00
0005435860695	3395	Economy	6300.00
0005432461032	3395	Economy	6300.00
0005432461300	3395	Economy	6300.00
0005432461419	3395	Economy	6300.00
0005435860724	3395	Economy	6300.00
0005435858716	3395	Economy	6300.00
0005432461205	3395	Economy	6300.00
0005435858717	3395	Economy	6300.00
0005435142993	3395	Economy	6300.00
0005435858730	3395	Economy	6300.00
0005432461204	3395	Economy	6300.00
0005432461389	3395	Economy	6300.00
0005435858724	3395	Economy	6300.00
0005435142991	3395	Economy	6300.00
0005432461349	3395	Economy	6300.00
0005432461302	3395	Economy	6300.00
0005432461262	3395	Economy	6300.00
0005432461159	3395	Economy	6300.00
0005435142984	3395	Economy	6300.00
0005435860717	3395	Economy	6300.00
0005432461409	3395	Economy	6300.00
0005434326060	3395	Economy	6300.00
0005432461263	3395	Economy	6300.00
0005435886868	3396	Business	18800.00
0005435886817	3396	Business	18800.00
0005435886588	3396	Economy	6900.00
0005435886836	3396	Economy	6300.00
0005435903229	3396	Economy	6300.00
0005435886455	3396	Economy	6300.00
0005435886787	3396	Economy	6300.00
0005435886847	3396	Economy	6300.00
0005435886800	3396	Economy	6300.00
0005435886698	3396	Economy	6300.00
0005435886654	3396	Economy	6300.00
0005435886859	3396	Economy	6300.00
0005435886417	3396	Economy	6300.00
0005435886790	3396	Economy	6300.00
0005435886822	3396	Economy	6300.00
0005435886837	3396	Economy	6300.00
0005435886620	3396	Economy	6300.00
0005435886621	3396	Economy	6300.00
0005435886801	3396	Economy	6300.00
0005435886707	3396	Economy	6900.00
0005435886788	3396	Economy	6300.00
0005435903226	3396	Economy	6300.00
0005435886829	3396	Economy	6300.00
0005435886616	3396	Economy	6300.00
0005435886590	3396	Economy	6300.00
0005435933557	3396	Economy	6300.00
0005435886589	3396	Economy	6300.00
0005435886773	3396	Economy	6300.00
0005433507721	8271	Business	18800.00
0005433507693	8271	Business	18800.00
0005433507705	8271	Economy	6300.00
0005433507730	8271	Economy	6300.00
0005433507714	8271	Economy	6300.00
0005433507701	8271	Economy	6300.00
0005433507715	8271	Economy	6300.00
0005433507692	8271	Economy	6900.00
0005433507716	8271	Economy	6300.00
0005433507731	8271	Economy	6300.00
0005433507694	8271	Economy	6300.00
0005433634687	8272	Business	18800.00
0005433806400	8272	Business	18800.00
0005433806401	8272	Business	18800.00
0005433806387	8272	Business	18800.00
0005433634732	8272	Business	18800.00
0005433806381	8272	Business	18800.00
0005433634830	8272	Business	18800.00
0005433806338	8272	Business	18800.00
0005434143822	8272	Economy	6900.00
0005433806289	8272	Economy	6900.00
0005433634773	8272	Economy	6900.00
0005433806371	8272	Economy	6300.00
0005433634746	8272	Economy	6300.00
0005433806290	8272	Economy	6300.00
0005433634761	8272	Economy	6300.00
0005433634749	8272	Economy	6300.00
0005434143859	8272	Economy	6300.00
0005434143757	8272	Economy	6300.00
0005433634781	8272	Economy	6300.00
0005433806291	8272	Economy	6300.00
0005434143852	8272	Economy	6300.00
0005433806364	8272	Economy	6300.00
0005433806374	8272	Economy	6300.00
0005433806366	8272	Economy	6900.00
0005433634780	8272	Economy	6900.00
0005433634774	8272	Economy	6300.00
0005433806406	8272	Economy	6300.00
0005434143846	8272	Economy	6300.00
0005433634777	8272	Economy	6300.00
0005434143820	8272	Economy	6300.00
0005433634686	8272	Economy	6300.00
0005433634604	8272	Economy	6300.00
0005433634703	8272	Economy	6300.00
0005434143842	8272	Economy	6300.00
0005433634755	8272	Economy	6300.00
0005433806292	8272	Economy	6300.00
0005433806326	8272	Economy	6300.00
0005433806325	8272	Economy	6300.00
0005434143756	8272	Economy	6300.00
0005433806296	8272	Economy	6300.00
0005433806336	8272	Economy	6300.00
0005433634829	8272	Economy	6300.00
0005433634745	8272	Economy	6300.00
0005433806385	8272	Economy	6300.00
0005433806409	8272	Economy	6300.00
0005433806370	8272	Economy	6300.00
0005433634763	8272	Economy	6300.00
0005433806348	8272	Economy	6300.00
0005433806191	8272	Economy	6300.00
0005433806365	8272	Economy	6300.00
0005434265965	8274	Business	18800.00
0005434266039	8274	Business	18800.00
0005434265930	8274	Business	18800.00
0005434266002	8274	Business	18800.00
0005434265985	8274	Economy	6900.00
0005434265978	8274	Economy	6300.00
0005434150186	8274	Economy	6300.00
0005434150185	8274	Economy	6300.00
0005434150232	8274	Economy	6300.00
0005434265980	8274	Economy	6300.00
0005434265959	8274	Economy	6300.00
0005434265967	8274	Economy	6300.00
0005434266003	8274	Economy	6300.00
0005434265966	8274	Economy	6300.00
0005434265986	8274	Economy	6300.00
0005434150168	8274	Economy	6300.00
0005434150222	8274	Economy	6900.00
0005434182548	8274	Economy	6300.00
0005434266004	8274	Economy	6300.00
0005434265941	8274	Economy	6300.00
0005434265925	8274	Economy	6300.00
0005434265995	8274	Economy	6300.00
0005434265929	8274	Economy	6300.00
0005434265924	8274	Economy	6300.00
0005434265931	8274	Economy	6300.00
0005434265996	8274	Economy	6300.00
0005434265926	8274	Economy	6300.00
0005434150220	8274	Economy	6300.00
0005433194938	30177	Business	9900.00
0005432384264	30177	Business	9900.00
0005433722397	30177	Business	9900.00
0005433194996	30177	Business	9900.00
0005432384132	30177	Business	9900.00
0005432384169	30177	Business	9900.00
0005432384234	30177	Business	9900.00
0005434300263	30177	Economy	3300.00
0005432384157	30177	Economy	3300.00
0005433722427	30177	Economy	3300.00
0005433722451	30177	Economy	3300.00
0005433722457	30177	Economy	3300.00
0005433194977	30177	Economy	3300.00
0005432384281	30177	Economy	3600.00
0005432728264	30177	Economy	3600.00
0005432728310	30177	Economy	3600.00
0005433722404	30177	Economy	3600.00
0005432728263	30177	Economy	3600.00
0005433195002	30177	Economy	3300.00
0005433722414	30177	Economy	3300.00
0005432384204	30177	Economy	3300.00
0005433722432	30177	Economy	3300.00
0005433722501	30177	Economy	3300.00
0005432384279	30177	Economy	3300.00
0005433194936	30177	Economy	3300.00
0005432384148	30177	Economy	3300.00
0005433194963	30177	Economy	3300.00
0005433194978	30177	Economy	3300.00
0005432384170	30177	Economy	3300.00
0005433722447	30177	Economy	3300.00
0005432384198	30177	Economy	3300.00
0005432728285	30177	Economy	3300.00
0005432728282	30177	Economy	3300.00
0005432384202	30177	Economy	3300.00
0005433722460	30177	Economy	3300.00
0005432384240	30177	Economy	3300.00
0005433194923	30177	Economy	3300.00
0005433194945	30177	Economy	3300.00
0005433194939	30177	Economy	3300.00
0005433195003	30177	Economy	3300.00
0005433194924	30177	Economy	3300.00
0005432384195	30177	Economy	3300.00
0005432384072	30177	Economy	3300.00
0005432384271	30177	Economy	3300.00
0005432384241	30177	Economy	3300.00
0005432384211	30177	Economy	3300.00
0005432384253	30177	Economy	3300.00
0005432384296	30177	Economy	3300.00
0005433722459	30177	Economy	3300.00
0005433722473	30177	Economy	3300.00
0005433722461	30177	Economy	3300.00
0005433194946	30177	Economy	3300.00
0005433194992	30177	Economy	3300.00
0005433194932	30177	Economy	3300.00
0005432384172	30177	Economy	3300.00
0005433194937	30177	Economy	3300.00
0005432384131	30177	Economy	3300.00
0005432384280	30177	Economy	3300.00
0005432384205	30177	Economy	3300.00
0005432384114	30177	Economy	3300.00
0005432728309	30177	Economy	3300.00
0005432384252	30177	Economy	3300.00
0005432384233	30177	Economy	3300.00
0005432728262	30177	Economy	3300.00
0005433722458	30177	Economy	3300.00
0005433722419	30177	Economy	3300.00
0005432728261	30177	Economy	3300.00
0005432728308	30177	Economy	3300.00
0005432925171	1711	Business	57200.00
0005432925170	1711	Economy	19100.00
0005433517162	22010	Business	57200.00
0005435541604	22010	Business	57200.00
0005435541571	22010	Business	57200.00
0005435518441	22010	Business	57200.00
0005435541618	22010	Business	57200.00
0005435518399	22010	Economy	19100.00
0005435541617	22010	Economy	19100.00
0005435518440	22010	Economy	19100.00
0005435541616	22010	Economy	19100.00
0005435541556	22010	Economy	19100.00
0005435541508	22010	Economy	21000.00
0005435541603	22010	Economy	21000.00
0005433517164	22010	Economy	19100.00
0005433517129	22010	Economy	19100.00
0005435518391	22010	Economy	19100.00
0005435541550	22010	Economy	19100.00
0005435541635	22010	Economy	19100.00
0005435518333	22010	Economy	19100.00
0005435518398	22010	Economy	19100.00
0005435518429	22010	Economy	19100.00
0005435518392	22010	Economy	19100.00
0005435541623	22010	Economy	19100.00
0005435518396	22010	Economy	19100.00
0005435541573	22010	Economy	19100.00
0005435541638	22010	Economy	19100.00
0005433517161	22010	Economy	19100.00
0005435541637	22010	Economy	19100.00
0005433517160	22010	Economy	19100.00
0005435541605	22010	Economy	19100.00
0005435518397	22010	Economy	19100.00
0005433517119	22010	Economy	19100.00
0005435518378	22010	Economy	19100.00
0005433517159	22010	Economy	19100.00
0005435541552	22010	Economy	19100.00
0005435518332	22010	Economy	19100.00
0005433517163	22010	Economy	19100.00
0005435541634	22010	Economy	19100.00
0005435541555	22010	Economy	19100.00
0005435518442	22010	Economy	19100.00
0005435541563	22010	Economy	19100.00
0005435518402	22010	Economy	19100.00
0005435541636	22010	Economy	19100.00
0005435546226	22010	Economy	19100.00
0005435518379	22010	Economy	19100.00
0005435518403	22010	Economy	19100.00
0005433517155	22010	Economy	19100.00
0005435518455	22010	Economy	19100.00
0005435541576	22010	Economy	19100.00
0005435253168	7407	Business	18500.00
0005435253215	7407	Business	18500.00
0005434665012	7407	Business	18500.00
0005435253216	7407	Economy	6200.00
0005435253217	7407	Economy	6200.00
0005435253197	7407	Economy	6200.00
0005435253169	7407	Economy	6200.00
0005435491501	7407	Economy	6200.00
0005435253218	7407	Economy	6200.00
0005432839919	28903	Business	18500.00
0005434459398	28903	Business	18500.00
0005432839908	28903	Economy	6200.00
0005432839907	28903	Economy	6200.00
0005434459388	28903	Economy	6200.00
0005434459393	28903	Economy	6200.00
0005432839931	28903	Economy	6200.00
0005434459335	28903	Economy	6200.00
0005432823503	28903	Economy	6200.00
0005434459389	28903	Economy	6200.00
0005434459408	28903	Economy	6200.00
0005434459396	28903	Economy	6200.00
0005432839925	28903	Economy	6200.00
0005434459336	28903	Economy	6200.00
0005434459413	28903	Economy	6200.00
0005434459395	28903	Economy	6200.00
0005432839881	28903	Economy	6200.00
0005434459411	28903	Economy	6200.00
0005432839912	28903	Economy	6200.00
0005434459402	28903	Economy	6200.00
0005432839926	28903	Economy	6200.00
0005433435517	8818	Business	145300.00
0005434276188	8818	Economy	48400.00
0005433435525	8818	Economy	48400.00
0005433435521	8818	Economy	48400.00
0005433435529	8818	Economy	48400.00
0005434276187	8818	Economy	48400.00
0005433435526	8818	Economy	48400.00
0005435990817	15748	Business	145300.00
0005435990818	15748	Business	145300.00
0005435990820	15748	Economy	48400.00
0005435990821	15748	Economy	48400.00
0005435990830	15748	Economy	48400.00
0005435990829	15748	Economy	48400.00
0005432427208	30839	Economy	15900.00
0005432427206	30839	Economy	14500.00
0005432427200	30839	Economy	14500.00
0005432427205	30839	Economy	14500.00
0005432427207	30839	Economy	14500.00
0005433468570	23843	Economy	13300.00
0005433468605	23843	Economy	12100.00
0005433468593	23843	Economy	12100.00
0005433468578	23843	Economy	12100.00
0005433468603	23843	Economy	12100.00
0005433468569	23843	Economy	12100.00
0005433468557	23843	Economy	12100.00
0005433468589	23843	Economy	12100.00
0005433468591	23843	Economy	12100.00
0005433468604	23843	Economy	12100.00
0005433468577	23843	Economy	12100.00
0005433468590	23843	Economy	12100.00
0005435177794	6394	Business	36600.00
0005434150027	6394	Business	36600.00
0005435177732	6394	Business	36600.00
0005435177871	6394	Business	36600.00
0005434150067	6394	Economy	12200.00
0005435177877	6394	Economy	12200.00
0005435490337	6394	Economy	12200.00
0005435177862	6394	Economy	12200.00
0005435177802	6394	Economy	12200.00
0005435177870	6394	Economy	13400.00
0005434150028	6394	Economy	12200.00
0005435177863	6394	Economy	12200.00
0005434150026	6394	Economy	12200.00
0005434150034	6394	Economy	12200.00
0005434150033	6394	Economy	12200.00
0005435490336	6394	Economy	12200.00
0005435177876	6394	Economy	12200.00
0005435177878	6394	Economy	12200.00
0005435177857	6394	Economy	12200.00
0005432361666	21010	Business	36600.00
0005432363512	21010	Business	36600.00
0005432361667	21010	Economy	12200.00
0005432361600	21010	Economy	12200.00
0005432361748	21010	Economy	12200.00
0005432361506	21010	Economy	12200.00
0005432361656	21010	Economy	13400.00
0005432336373	21010	Economy	13400.00
0005432361701	21010	Economy	12200.00
0005432361608	21010	Economy	12200.00
0005432361686	21010	Economy	12200.00
0005432361739	21010	Economy	12200.00
0005432363509	21010	Economy	12200.00
0005432361609	21010	Economy	12200.00
0005432361655	21010	Economy	12200.00
0005432336376	21010	Economy	12200.00
0005432361507	21010	Economy	12200.00
0005432361659	21010	Economy	12200.00
0005432361732	21010	Economy	12200.00
0005432336382	21010	Economy	12200.00
0005432361747	21010	Economy	12200.00
0005432336377	21010	Economy	12200.00
0005432361737	21010	Economy	12200.00
0005432361654	21010	Economy	12200.00
0005432361770	21010	Economy	12200.00
0005434459401	17715	Economy	3100.00
0005434461709	17715	Economy	3100.00
0005434459418	17715	Economy	3100.00
0005434461710	17715	Economy	3100.00
0005434459417	17715	Economy	3100.00
0005434459412	17715	Economy	3100.00
0005434448409	17715	Economy	3100.00
0005434448405	17715	Economy	3100.00
0005434448410	17715	Economy	3100.00
0005434186285	29077	Economy	3100.00
0005434186281	29077	Economy	3100.00
0005432664214	6490	Business	185300.00
0005432664213	6490	Economy	61800.00
0005432664215	6490	Economy	61800.00
0005432664212	6490	Economy	61800.00
0005432661997	6490	Economy	61800.00
0005432661996	6490	Economy	61800.00
0005435221554	21420	Economy	6600.00
0005435221555	21420	Economy	6600.00
0005435218145	21420	Economy	6600.00
0005432605412	31703	Economy	6600.00
0005432605386	31703	Economy	6600.00
0005432605434	31703	Economy	6600.00
0005432605489	31703	Economy	6600.00
0005432605402	31703	Economy	6600.00
0005432605446	31703	Economy	6600.00
0005432605483	31703	Economy	6600.00
0005432605497	31703	Economy	6600.00
0005432605354	31703	Economy	6600.00
0005432605447	31703	Economy	6600.00
0005432605349	31703	Economy	6600.00
0005432605433	31703	Economy	6600.00
0005432605485	31703	Economy	6600.00
0005432605383	31703	Economy	6600.00
0005432605432	31703	Economy	6600.00
0005432605369	31703	Economy	6600.00
0005432605498	31703	Economy	6600.00
0005432605298	31703	Economy	6600.00
0005433293411	12308	Economy	19500.00
0005433293421	12308	Economy	17800.00
0005433293400	12308	Economy	17800.00
0005433293387	12308	Economy	17800.00
0005433293434	12308	Economy	17800.00
0005433293404	12308	Economy	17800.00
0005433293430	12308	Economy	17800.00
0005433293410	12308	Economy	17800.00
0005433293420	12308	Economy	17800.00
0005433293428	12308	Economy	17800.00
0005433293423	12308	Economy	17800.00
0005433293431	12308	Economy	17800.00
0005433293427	12308	Economy	17800.00
0005433293371	12308	Economy	17800.00
0005433293397	12308	Economy	17800.00
0005433293401	12308	Economy	17800.00
0005433293418	12308	Economy	17800.00
0005433293372	12308	Economy	17800.00
0005433293388	12308	Economy	17800.00
0005433293424	12308	Economy	17800.00
0005433473495	23902	Economy	12700.00
0005433473524	23902	Economy	12700.00
0005433473525	23902	Economy	12700.00
0005433473494	23902	Economy	12700.00
0005433473505	23902	Economy	12700.00
0005434606926	18904	Economy	6600.00
0005434606927	18904	Economy	6600.00
0005434606925	18904	Economy	6600.00
0005435904910	22359	Economy	6600.00
0005435904472	3848	Economy	24900.00
0005435904479	3848	Economy	22600.00
0005435904728	3848	Economy	22600.00
0005435904470	3848	Economy	22600.00
0005435904726	3848	Economy	22600.00
0005435904491	3848	Economy	22600.00
0005435904471	3848	Economy	22600.00
0005435904478	3848	Economy	22600.00
0005435904489	3848	Economy	22600.00
0005435904727	3848	Economy	22600.00
0005434522549	19060	Economy	22600.00
0005434522551	19060	Economy	22600.00
0005434522550	19060	Economy	22600.00
0005434522542	19060	Economy	22600.00
0005434605000	19060	Economy	22600.00
0005434522552	19060	Economy	22600.00
0005434522556	19060	Economy	22600.00
0005432891549	426	Economy	16300.00
0005433293435	426	Economy	16300.00
0005434152868	426	Economy	16300.00
0005433293407	426	Economy	16300.00
0005433875425	426	Economy	14800.00
0005433293419	426	Economy	14800.00
0005433293426	426	Economy	14800.00
0005432891553	426	Economy	14800.00
0005434151819	426	Economy	14800.00
0005434151818	426	Economy	14800.00
0005432748487	12067	Business	44500.00
0005435627133	12067	Economy	14800.00
0005432748663	12067	Economy	16300.00
0005432748656	12067	Economy	14800.00
0005432748677	12067	Economy	14800.00
0005432748673	12067	Economy	14800.00
0005432748648	12067	Economy	14800.00
0005432748655	12067	Economy	14800.00
0005435627134	12067	Economy	14800.00
0005432748658	12067	Economy	14800.00
0005432748678	12067	Economy	14800.00
0005432748625	12067	Economy	14800.00
0005432748486	12067	Economy	14800.00
0005432748624	12067	Economy	14800.00
0005432748638	12067	Economy	14800.00
0005432756937	12067	Economy	14800.00
0005432756938	12067	Economy	14800.00
0005432928110	18974	Economy	25700.00
0005432928134	18974	Economy	25700.00
0005432928142	18974	Economy	25700.00
0005432928135	18974	Economy	25700.00
0005432928143	18974	Economy	25700.00
0005432928144	18974	Economy	25700.00
0005433525319	32473	Economy	25700.00
0005433525331	32473	Economy	25700.00
0005433525363	32473	Economy	25700.00
0005433527374	32473	Economy	25700.00
0005433525330	32473	Economy	25700.00
0005433525345	32473	Economy	25700.00
0005435375152	5258	Business	84000.00
0005435315039	5258	Business	84000.00
0005435299909	5258	Business	84000.00
0005435375070	5258	Business	84000.00
0005435662012	5258	Business	84000.00
0005435386743	5258	Business	84000.00
0005435375123	5258	Business	84000.00
0005435375010	5258	Comfort	47600.00
0005435735270	5258	Comfort	47600.00
0005435375160	5258	Comfort	47600.00
0005435179712	5258	Comfort	47600.00
0005435375141	5258	Comfort	47600.00
0005435374912	5258	Comfort	47600.00
0005435375116	5258	Comfort	47600.00
0005435375086	5258	Comfort	47600.00
0005435662010	5258	Comfort	47600.00
0005435662011	5258	Economy	28000.00
0005435179711	5258	Economy	28000.00
0005435299908	5258	Economy	28000.00
0005435374927	5258	Economy	28000.00
0005435299907	5258	Economy	28000.00
0005435374853	5258	Economy	28000.00
0005435375136	5258	Economy	28000.00
0005435315121	5258	Economy	28000.00
0005435179021	5258	Economy	28000.00
0005435304267	5258	Economy	28000.00
0005435375100	5258	Economy	28000.00
0005435375008	5258	Economy	30800.00
0005435374950	5258	Economy	30800.00
0005435375176	5258	Economy	28000.00
0005435299910	5258	Economy	28000.00
0005435374987	5258	Economy	28000.00
0005435375108	5258	Economy	28000.00
0005435374926	5258	Economy	28000.00
0005435374953	5258	Economy	28000.00
0005435315040	5258	Economy	28000.00
0005435179716	5258	Economy	28000.00
0005435315057	5258	Economy	28000.00
0005435375114	5258	Economy	28000.00
0005435374964	5258	Economy	28000.00
0005435374983	5258	Economy	28000.00
0005435375111	5258	Economy	28000.00
0005435315072	5258	Economy	28000.00
0005435304268	5258	Economy	28000.00
0005435375090	5258	Economy	28000.00
0005435299919	5258	Economy	28000.00
0005435299918	5258	Economy	28000.00
0005435386744	5258	Economy	28000.00
0005435375132	5258	Economy	28000.00
0005435374911	5258	Economy	30800.00
0005435375142	5258	Economy	28000.00
0005435735255	5258	Economy	28000.00
0005435375021	5258	Economy	28000.00
0005435375107	5258	Economy	28000.00
0005435315115	5258	Economy	28000.00
0005435375163	5258	Economy	28000.00
0005435315109	5258	Economy	28000.00
0005435375168	5258	Economy	28000.00
0005435374913	5258	Economy	28000.00
0005435315075	5258	Economy	28000.00
0005435386754	5258	Economy	28000.00
0005435315125	5258	Economy	28000.00
0005435375177	5258	Economy	28000.00
0005435375161	5258	Economy	28000.00
0005435375009	5258	Economy	28000.00
0005435179713	5258	Economy	28000.00
0005435375175	5258	Economy	28000.00
0005435374986	5258	Economy	28000.00
0005435179715	5258	Economy	28000.00
0005435735269	5258	Economy	28000.00
0005435375112	5258	Economy	28000.00
0005435375115	5258	Economy	28000.00
0005435315110	5258	Economy	28000.00
0005435304271	5258	Economy	28000.00
0005435375169	5258	Economy	28000.00
0005435375147	5258	Economy	28000.00
0005435315086	5258	Economy	28000.00
0005434826885	9881	Business	84000.00
0005434827090	9881	Business	84000.00
0005434826898	9881	Business	84000.00
0005435150414	9881	Business	84000.00
0005434826899	9881	Business	84000.00
0005434826790	9881	Business	84000.00
0005434826886	9881	Business	84000.00
0005434827158	9881	Comfort	47600.00
0005434558578	9881	Comfort	47600.00
0005434827046	9881	Comfort	47600.00
0005434827136	9881	Comfort	47600.00
0005434826822	9881	Comfort	47600.00
0005434827241	9881	Comfort	47600.00
0005434558560	9881	Comfort	47600.00
0005434827082	9881	Comfort	47600.00
0005434827045	9881	Comfort	47600.00
0005434558478	9881	Comfort	47600.00
0005434826996	9881	Comfort	47600.00
0005434826690	9881	Comfort	47600.00
0005434827207	9881	Comfort	47600.00
0005434827157	9881	Economy	28000.00
0005434826845	9881	Economy	28000.00
0005434558575	9881	Economy	28000.00
0005434827085	9881	Economy	28000.00
0005435150417	9881	Economy	28000.00
0005434558513	9881	Economy	28000.00
0005434827259	9881	Economy	28000.00
0005434826722	9881	Economy	28000.00
0005434827081	9881	Economy	28000.00
0005434826945	9881	Economy	28000.00
0005434827021	9881	Economy	28000.00
0005434827088	9881	Economy	28000.00
0005434558567	9881	Economy	28000.00
0005432396353	9881	Economy	28000.00
0005432396354	9881	Economy	28000.00
0005434558571	9881	Economy	28000.00
0005434827022	9881	Economy	28000.00
0005434826944	9881	Economy	28000.00
0005434558554	9881	Economy	28000.00
0005434827209	9881	Economy	30800.00
0005434827047	9881	Economy	28000.00
0005434827260	9881	Economy	30800.00
0005434826793	9881	Economy	28000.00
0005434558576	9881	Economy	28000.00
0005434828773	9881	Economy	28000.00
0005434827208	9881	Economy	28000.00
0005434826765	9881	Economy	28000.00
0005434828772	9881	Economy	28000.00
0005434827146	9881	Economy	28000.00
0005434826941	9881	Economy	28000.00
0005434558477	9881	Economy	28000.00
0005434558561	9881	Economy	28000.00
0005434558565	9881	Economy	28000.00
0005434558585	9881	Economy	28000.00
0005434558548	9881	Economy	28000.00
0005435150389	9881	Economy	28000.00
0005434558555	9881	Economy	28000.00
0005434558511	9881	Economy	28000.00
0005434558566	9881	Economy	28000.00
0005434827069	9881	Economy	28000.00
0005434827159	9881	Economy	28000.00
0005434827001	9881	Economy	28000.00
0005435150413	9881	Economy	28000.00
0005434827242	9881	Economy	28000.00
0005434558593	9881	Economy	28000.00
0005434827048	9881	Economy	28000.00
0005434558512	9881	Economy	28000.00
0005435150415	9881	Economy	28000.00
0005434826939	9881	Economy	28000.00
0005434826766	9881	Economy	28000.00
0005434558531	9881	Economy	28000.00
0005434826986	9881	Economy	28000.00
0005434827188	9881	Economy	28000.00
0005434558524	9881	Economy	28000.00
0005434558508	9881	Economy	28000.00
0005434826997	9881	Economy	28000.00
0005434831280	9881	Economy	28000.00
0005434827240	9881	Economy	30800.00
0005434826767	9881	Economy	28000.00
0005434827234	9881	Economy	28000.00
0005434826940	9881	Economy	28000.00
0005434827077	9881	Economy	28000.00
0005434827189	9881	Economy	28000.00
0005434558533	9881	Economy	28000.00
0005434826795	9881	Economy	28000.00
0005434826748	9881	Economy	28000.00
0005434827235	9881	Economy	28000.00
0005434827012	9881	Economy	28000.00
0005434826844	9881	Economy	28000.00
0005434558476	9881	Economy	28000.00
0005434558488	9881	Economy	28000.00
0005434826723	9881	Economy	28000.00
0005434558550	9881	Economy	28000.00
0005434558556	9881	Economy	28000.00
0005434826794	9881	Economy	28000.00
0005434827020	9881	Economy	28000.00
0005434827117	9881	Economy	28000.00
0005434827094	9881	Economy	28000.00
0005434558564	9881	Economy	28000.00
0005434558591	9881	Economy	28000.00
0005434826890	9881	Economy	28000.00
0005435150407	9881	Economy	28000.00
0005434827087	9881	Economy	28000.00
0005434558598	9881	Economy	28000.00
0005435083025	26011	Economy	7400.00
0005435083008	26011	Economy	7400.00
0005435082988	26011	Economy	7400.00
0005435082987	26011	Economy	7400.00
0005435083028	26011	Economy	7400.00
0005434215701	9524	Business	32800.00
0005434215750	9524	Business	32800.00
0005434215705	9524	Economy	10900.00
0005434215885	9524	Economy	10900.00
0005434215827	9524	Economy	12000.00
0005434215793	9524	Economy	10900.00
0005434215849	9524	Economy	10900.00
0005434215700	9524	Economy	10900.00
0005434215850	9524	Economy	10900.00
0005434215886	9524	Economy	10900.00
0005434215721	9524	Economy	10900.00
0005434215783	9524	Economy	10900.00
0005434215720	9524	Economy	10900.00
0005434215803	9524	Economy	10900.00
0005434215802	9524	Economy	10900.00
0005434215826	9524	Economy	10900.00
0005434757619	28627	Business	32800.00
0005434757466	28627	Business	32800.00
0005434757448	28627	Business	32800.00
0005434757562	28627	Economy	10900.00
0005434757590	28627	Economy	10900.00
0005434757529	28627	Economy	10900.00
0005434757458	28627	Economy	12000.00
0005434757397	28627	Economy	10900.00
0005434757530	28627	Economy	10900.00
0005434757543	28627	Economy	10900.00
0005434757595	28627	Economy	10900.00
0005434757539	28627	Economy	10900.00
0005434757640	28627	Economy	10900.00
0005434757558	28627	Economy	10900.00
0005434757567	28627	Economy	10900.00
0005434757547	28627	Economy	10900.00
0005434757594	28627	Economy	10900.00
0005434757528	28627	Economy	10900.00
0005434757583	28627	Economy	10900.00
0005434757589	28627	Economy	10900.00
0005434757459	28627	Economy	10900.00
0005434757573	28627	Economy	10900.00
0005434757557	28627	Economy	10900.00
0005434757637	28627	Economy	10900.00
0005434757499	28627	Economy	10900.00
0005434757447	28627	Economy	10900.00
0005434757626	28627	Economy	10900.00
0005434757584	28627	Economy	10900.00
0005433202777	1966	Economy	19000.00
0005433202740	1966	Economy	19000.00
0005433202739	1966	Economy	19000.00
0005433202796	1966	Economy	19000.00
0005433202727	1966	Economy	19000.00
0005433202775	1966	Economy	19000.00
0005433202797	1966	Economy	19000.00
0005433202760	1966	Economy	19000.00
0005433202750	1966	Economy	19000.00
0005433202774	1966	Economy	19000.00
0005433202782	1966	Economy	19000.00
0005433202776	1966	Economy	19000.00
0005434639986	23270	Economy	20900.00
0005434640061	23270	Economy	19000.00
0005434640030	23270	Economy	19000.00
0005434640037	23270	Economy	19000.00
0005434640074	23270	Economy	19000.00
0005434640069	23270	Economy	19000.00
0005434640073	23270	Economy	19000.00
0005434640010	23270	Economy	19000.00
0005434639985	23270	Economy	19000.00
0005434640009	23270	Economy	19000.00
0005434640042	23270	Economy	19000.00
0005434640039	23270	Economy	19000.00
0005434640070	23270	Economy	19000.00
0005434640043	23270	Economy	19000.00
0005434640062	23270	Economy	19000.00
0005434640008	23270	Economy	19000.00
0005435327136	6059	Economy	23200.00
0005435327100	6059	Economy	23200.00
0005435327135	6059	Economy	23200.00
0005433527370	18610	Economy	23200.00
0005434601536	18610	Economy	23200.00
0005433527369	18610	Economy	25600.00
0005434601555	18610	Economy	23200.00
0005434601551	18610	Economy	23200.00
0005433527371	18610	Economy	23200.00
0005434601586	18610	Economy	23200.00
0005434601556	18610	Economy	23200.00
0005434601537	18610	Economy	23200.00
0005434601557	18610	Economy	23200.00
0005433527364	18610	Economy	23200.00
0005434601582	18610	Economy	23200.00
0005434601585	18610	Economy	23200.00
0005434601460	18610	Economy	23200.00
0005433527368	18610	Economy	23200.00
0005433181814	10648	Economy	3000.00
0005433181820	10648	Economy	3000.00
0005433181809	10648	Economy	3300.00
0005435315139	10648	Economy	3000.00
0005435315134	10648	Economy	3000.00
0005433181736	10648	Economy	3000.00
0005435315088	10648	Economy	3000.00
0005433181839	10648	Economy	3000.00
0005435315135	10648	Economy	3000.00
0005435315083	10648	Economy	3000.00
0005433181794	10648	Economy	3000.00
0005435315090	10648	Economy	3000.00
0005433181742	10648	Economy	3000.00
0005433181837	10648	Economy	3000.00
0005435315077	10648	Economy	3000.00
0005435315089	10648	Economy	3000.00
0005435315062	10648	Economy	3000.00
0005433181810	10648	Economy	3000.00
0005434558503	27703	Business	9100.00
0005434552680	27703	Business	9100.00
0005434552779	27703	Business	9100.00
0005434552697	27703	Business	9100.00
0005434558614	27703	Business	9100.00
0005434552812	27703	Economy	3000.00
0005434552813	27703	Economy	3000.00
0005434552819	27703	Economy	3000.00
0005434552823	27703	Economy	3300.00
0005434558562	27703	Economy	3000.00
0005434552808	27703	Economy	3000.00
0005434558501	27703	Economy	3000.00
0005434552692	27703	Economy	3000.00
0005434552744	27703	Economy	3000.00
0005434552724	27703	Economy	3000.00
0005434552679	27703	Economy	3000.00
0005434558610	27703	Economy	3000.00
0005434558603	27703	Economy	3000.00
0005434552676	27703	Economy	3000.00
0005434558563	27703	Economy	3000.00
0005434552791	27703	Economy	3000.00
0005434558521	27703	Economy	3000.00
0005434552809	27703	Economy	3000.00
0005434552723	27703	Economy	3000.00
0005434552824	27703	Economy	3000.00
0005434552790	27703	Economy	3000.00
0005434552830	27703	Economy	3000.00
0005434552783	27703	Economy	3000.00
0005434558609	27703	Economy	3000.00
0005434552810	27703	Economy	3000.00
0005434552829	27703	Economy	3000.00
0005434552811	27703	Economy	3000.00
0005434558611	27703	Economy	3000.00
0005434558607	27703	Economy	3000.00
0005434552778	27703	Economy	3000.00
0005434552828	27703	Economy	3000.00
0005434558613	27703	Economy	3000.00
0005434558520	27703	Economy	3000.00
0005434558549	27703	Economy	3000.00
0005434552675	27703	Economy	3000.00
0005434552747	27703	Economy	3000.00
0005434552780	27703	Economy	3000.00
0005434552807	27703	Economy	3000.00
0005434558502	27703	Economy	3000.00
0005434552825	27703	Economy	3000.00
0005433459333	19315	Economy	11700.00
0005433459345	19315	Economy	11700.00
0005434828762	6718	Business	51100.00
0005432533372	6718	Business	51100.00
0005435438569	6718	Economy	18700.00
0005435220383	6718	Economy	17000.00
0005434828771	6718	Economy	17000.00
0005435220384	6718	Economy	17000.00
0005435220385	6718	Economy	17000.00
0005435438588	6718	Economy	17000.00
0005435438584	6718	Economy	17000.00
0005435217772	6718	Economy	17000.00
0005435217773	6718	Economy	17000.00
0005435438571	6718	Economy	17000.00
0005435438572	6718	Economy	17000.00
0005432533370	6718	Economy	17000.00
0005435719604	24588	Business	51100.00
0005435683137	24588	Business	51100.00
0005435683311	24588	Business	51100.00
0005435683228	24588	Business	51100.00
0005435683291	24588	Business	51100.00
0005435790413	24588	Business	51100.00
0005435683305	24588	Business	51100.00
0005435683328	24588	Business	51100.00
0005435683161	24588	Economy	17000.00
0005435683231	24588	Economy	17000.00
0005435683174	24588	Economy	17000.00
0005435631050	24588	Economy	18700.00
0005435683333	24588	Economy	17000.00
0005435683279	24588	Economy	17000.00
0005435683327	24588	Economy	17000.00
0005435683176	24588	Economy	17000.00
0005435683253	24588	Economy	17000.00
0005435790414	24588	Economy	17000.00
0005435683254	24588	Economy	17000.00
0005435683227	24588	Economy	17000.00
0005435683162	24588	Economy	17000.00
0005435683175	24588	Economy	17000.00
0005435719605	24588	Economy	17000.00
0005435719603	24588	Economy	17000.00
0005435683270	24588	Economy	17000.00
0005435683304	24588	Economy	17000.00
0005435683177	24588	Economy	17000.00
0005435683255	24588	Economy	17000.00
0005435719597	24588	Economy	17000.00
0005435662002	24588	Economy	17000.00
0005435683173	24588	Economy	17000.00
0005435683268	24588	Economy	17000.00
0005435790415	24588	Economy	17000.00
0005435127541	31882	Business	26400.00
0005435098615	31882	Business	26400.00
0005435127430	31882	Business	26400.00
0005435127545	31882	Economy	8800.00
0005435127557	31882	Economy	8800.00
0005435106071	31882	Economy	8800.00
0005435127527	31882	Economy	8800.00
0005435127538	31882	Economy	8800.00
0005435106070	31882	Economy	8800.00
0005435127491	31882	Economy	8800.00
0005435127553	31882	Economy	8800.00
0005435127554	31882	Economy	8800.00
0005435127540	31882	Economy	8800.00
0005435127492	31882	Economy	8800.00
0005435127480	31882	Economy	8800.00
0005435127531	31882	Economy	8800.00
0005435127539	31882	Economy	8800.00
0005435127558	31882	Economy	8800.00
0005435127569	31882	Economy	8800.00
0005435098613	31882	Economy	8800.00
0005435106068	31882	Economy	8800.00
0005435127429	31882	Economy	8800.00
0005435098614	31882	Economy	8800.00
0005435127526	31882	Economy	8800.00
0005435732727	13528	Business	36600.00
0005435732706	13528	Economy	12200.00
0005435732703	13528	Economy	12200.00
0005435732693	13528	Economy	12200.00
0005433399384	19397	Business	36600.00
0005433399448	19397	Business	36600.00
0005433399415	19397	Business	36600.00
0005433399461	19397	Business	36600.00
0005433399291	19397	Economy	12200.00
0005433399454	19397	Economy	12200.00
0005433399371	19397	Economy	13400.00
0005433399394	19397	Economy	12200.00
0005433399406	19397	Economy	12200.00
0005433399455	19397	Economy	12200.00
0005433399409	19397	Economy	12200.00
0005433399385	19397	Economy	12200.00
0005433399354	19397	Economy	12200.00
0005433399295	19397	Economy	12200.00
0005433399410	19397	Economy	12200.00
0005433399283	19397	Economy	12200.00
0005433399372	19397	Economy	12200.00
0005433399282	19397	Economy	12200.00
0005433399281	19397	Economy	12200.00
0005433399358	19397	Economy	12200.00
0005435070533	13167	Business	11300.00
0005435070385	13167	Economy	3800.00
0005435070363	13167	Economy	3800.00
0005435070498	13167	Economy	3800.00
0005435070386	13167	Economy	3800.00
0005435070497	13167	Economy	3800.00
0005435070529	13167	Economy	3800.00
0005435070383	13167	Economy	3800.00
0005435070512	13167	Economy	3800.00
0005435070496	13167	Economy	3800.00
0005435070487	13167	Economy	3800.00
0005435070458	13167	Economy	3800.00
0005435070509	13167	Economy	3800.00
0005435070470	13167	Economy	3800.00
0005435070541	13167	Economy	3800.00
0005435925699	15479	Business	11300.00
0005435925652	15479	Business	11300.00
0005435925723	15479	Business	11300.00
0005435925693	15479	Economy	3800.00
0005435925647	15479	Economy	4100.00
0005435925694	15479	Economy	4100.00
0005435925690	15479	Economy	3800.00
0005435925685	15479	Economy	3800.00
0005435925698	15479	Economy	3800.00
0005435925713	15479	Economy	3800.00
0005435925646	15479	Economy	3800.00
0005435925719	15479	Economy	3800.00
0005435925712	15479	Economy	3800.00
0005435925718	15479	Economy	3800.00
0005435925645	15479	Economy	3800.00
0005433407704	23195	Economy	27100.00
0005433407701	23195	Economy	24700.00
0005433407688	23195	Economy	24700.00
0005433407703	23195	Economy	24700.00
0005433407687	23195	Economy	24700.00
0005433407707	23195	Economy	24700.00
0005433407709	23195	Economy	24700.00
0005435808533	23195	Economy	24700.00
0005433407706	23195	Economy	24700.00
0005433407708	23195	Economy	24700.00
0005434757598	10695	Business	61300.00
0005434757609	10695	Business	61300.00
0005434757527	10695	Business	61300.00
0005434757657	10695	Business	61300.00
0005434757601	10695	Economy	20400.00
0005434757600	10695	Economy	20400.00
0005434757548	10695	Economy	20400.00
0005434757679	10695	Economy	20400.00
0005434757503	10695	Economy	22500.00
0005434757549	10695	Economy	22500.00
0005434757656	10695	Economy	20400.00
0005434757634	10695	Economy	20400.00
0005434757653	10695	Economy	20400.00
0005434757639	10695	Economy	20400.00
0005434757591	10695	Economy	20400.00
0005434757351	10695	Economy	20400.00
0005434757481	10695	Economy	20400.00
0005434757450	10695	Economy	20400.00
0005434757624	10695	Economy	20400.00
0005434757638	10695	Economy	20400.00
0005434757683	10695	Economy	20400.00
0005434757579	10695	Economy	20400.00
0005434757599	10695	Economy	20400.00
0005434757652	10695	Economy	20400.00
0005434757658	10695	Economy	20400.00
0005434757635	10695	Economy	20400.00
0005434757526	10695	Economy	20400.00
0005434757610	10695	Economy	20400.00
0005434215651	28654	Business	61300.00
0005434215665	28654	Business	61300.00
0005434215666	28654	Economy	20400.00
0005434215833	28654	Economy	20400.00
0005434215798	28654	Economy	22500.00
0005434215746	28654	Economy	22500.00
0005434215789	28654	Economy	20400.00
0005434215743	28654	Economy	20400.00
0005434215664	28654	Economy	20400.00
0005434215769	28654	Economy	20400.00
0005434215840	28654	Economy	20400.00
0005434215772	28654	Economy	20400.00
0005434215759	28654	Economy	20400.00
0005434215571	28654	Economy	20400.00
0005434215771	28654	Economy	20400.00
0005434215780	28654	Economy	20400.00
0005434215644	28654	Economy	20400.00
0005434215818	28654	Economy	20400.00
0005434215650	28654	Economy	20400.00
0005434215816	28654	Economy	20400.00
0005434215742	28654	Economy	20400.00
0005434215799	28654	Economy	20400.00
0005434215832	28654	Economy	20400.00
0005434215800	28654	Economy	20400.00
0005434215848	28654	Economy	20400.00
0005434215741	28654	Economy	20400.00
0005434215858	28654	Economy	20400.00
0005434215652	28654	Economy	20400.00
0005435735279	5437	Economy	9800.00
0005434230009	5437	Economy	9800.00
0005434229982	5437	Economy	9800.00
0005434229981	5437	Economy	9800.00
0005435377966	5437	Economy	9800.00
0005435377967	5437	Economy	9800.00
0005434230040	5437	Economy	9800.00
0005435377964	5437	Economy	9800.00
0005435377971	5437	Economy	9800.00
0005434230042	5437	Economy	9800.00
0005435377968	5437	Economy	9800.00
0005434230041	5437	Economy	9800.00
0005434229989	5437	Economy	9800.00
0005435041633	12998	Business	29500.00
0005435041450	12998	Business	29500.00
0005435041588	12998	Business	29500.00
0005435041572	12998	Business	29500.00
0005435041665	12998	Business	29500.00
0005435041663	12998	Business	29500.00
0005435041553	12998	Economy	9800.00
0005435043305	12998	Economy	9800.00
0005435041555	12998	Economy	9800.00
0005435041625	12998	Economy	9800.00
0005435041472	12998	Economy	9800.00
0005435041397	12998	Economy	9800.00
0005435043306	12998	Economy	9800.00
0005435041451	12998	Economy	10800.00
0005435041452	12998	Economy	10800.00
0005435041686	12998	Economy	9800.00
0005435041480	12998	Economy	9800.00
0005435041649	12998	Economy	9800.00
0005435041589	12998	Economy	9800.00
0005435041659	12998	Economy	9800.00
0005435041648	12998	Economy	9800.00
0005435041592	12998	Economy	9800.00
0005435041600	12998	Economy	9800.00
0005435041670	12998	Economy	9800.00
0005435041414	12998	Economy	9800.00
0005435007548	12998	Economy	9800.00
0005435041554	12998	Economy	9800.00
0005435041616	12998	Economy	9800.00
0005435041687	12998	Economy	9800.00
0005435041471	12998	Economy	9800.00
0005435041293	12998	Economy	9800.00
0005435007719	12998	Economy	9800.00
0005435007661	12998	Economy	9800.00
0005435007675	12998	Economy	9800.00
0005435007681	12998	Economy	9800.00
0005435041601	12998	Economy	9800.00
0005435041580	12998	Economy	9800.00
0005435041415	12998	Economy	9800.00
0005435041668	12998	Economy	9800.00
0005435041669	12998	Economy	9800.00
0005435041581	12998	Economy	9800.00
0005435041416	12998	Economy	9800.00
0005435041571	12998	Economy	9800.00
0005435041470	12998	Economy	9800.00
0005435041615	12998	Economy	9800.00
0005435007718	12998	Economy	9800.00
0005435903195	14857	Business	52900.00
0005435903154	14857	Business	52900.00
0005435903193	14857	Economy	19400.00
0005435903179	14857	Economy	17600.00
0005435903194	14857	Economy	17600.00
0005435903155	14857	Economy	17600.00
0005435554325	14857	Economy	17600.00
0005435554324	14857	Economy	17600.00
0005435903140	14857	Economy	17600.00
0005435903196	14857	Economy	17600.00
0005434427449	20220	Business	52900.00
0005434427415	20220	Economy	17600.00
0005434427445	20220	Economy	19400.00
0005434427433	20220	Economy	17600.00
0005434427431	20220	Economy	17600.00
0005434427430	20220	Economy	17600.00
0005434427457	20220	Economy	17600.00
0005434427450	20220	Economy	17600.00
0005434427448	20220	Economy	17600.00
0005434427429	20220	Economy	17600.00
0005434427412	20220	Economy	17600.00
0005434427414	20220	Economy	17600.00
0005434427396	20220	Economy	17600.00
0005434559154	28008	Business	106800.00
0005434559126	28008	Business	106800.00
0005434523838	28008	Business	106800.00
0005434559137	28008	Economy	35600.00
0005434559157	28008	Economy	35600.00
0005434523832	28008	Economy	35600.00
0005434559163	28008	Economy	35600.00
0005434559155	28008	Economy	35600.00
0005434559122	28008	Economy	35600.00
0005434559170	28008	Economy	35600.00
0005434523837	28008	Economy	35600.00
0005434559123	28008	Economy	35600.00
0005434559160	28008	Economy	35600.00
0005434559136	28008	Economy	35600.00
0005434559158	28008	Economy	35600.00
0005434559127	28008	Economy	35600.00
0005434559144	28008	Economy	35600.00
0005434559164	28008	Economy	35600.00
0005434559128	28008	Economy	35600.00
0005434559130	28008	Economy	35600.00
0005434559176	28008	Economy	35600.00
0005434559181	28008	Economy	35600.00
0005434559162	28008	Economy	35600.00
0005434559156	28008	Economy	35600.00
0005434523840	28008	Economy	35600.00
0005434559129	28008	Economy	35600.00
0005434559140	28008	Economy	35600.00
0005434523839	28008	Economy	35600.00
0005434523841	28008	Economy	35600.00
0005434559161	28008	Economy	35600.00
0005434559147	28008	Economy	35600.00
0005432462570	30889	Economy	35600.00
0005432462575	30889	Economy	35600.00
0005432462571	30889	Economy	35600.00
0005432462576	30889	Economy	35600.00
0005432462572	30889	Economy	35600.00
0005432462573	30889	Economy	35600.00
0005433435418	26521	Business	18500.00
0005433435472	26521	Economy	6200.00
0005433435393	26521	Economy	6200.00
0005433435459	26521	Economy	6800.00
0005433435471	26521	Economy	6800.00
0005433435427	26521	Economy	6800.00
0005433435426	26521	Economy	6200.00
0005433435346	26521	Economy	6200.00
0005433435394	26521	Economy	6200.00
0005433435462	26521	Economy	6200.00
0005433435345	26521	Economy	6200.00
0005433435446	26521	Economy	6200.00
0005433435428	26521	Economy	6200.00
0005434270266	26521	Economy	6200.00
0005435983666	26686	Business	18500.00
0005435983563	26686	Business	18500.00
0005435983602	26686	Business	18500.00
0005435983575	26686	Economy	6200.00
0005435983485	26686	Economy	6200.00
0005435983515	26686	Economy	6200.00
0005435983562	26686	Economy	6800.00
0005435983531	26686	Economy	6800.00
0005435983577	26686	Economy	6800.00
0005435983674	26686	Economy	6200.00
0005435983628	26686	Economy	6200.00
0005435983548	26686	Economy	6200.00
0005435983578	26686	Economy	6200.00
0005435983558	26686	Economy	6200.00
0005435983559	26686	Economy	6200.00
0005435983427	26686	Economy	6200.00
0005435983528	26686	Economy	6200.00
0005435983530	26686	Economy	6200.00
0005435983511	26686	Economy	6200.00
0005435983503	26686	Economy	6200.00
0005435983589	26686	Economy	6200.00
0005435983657	26686	Economy	6200.00
0005435983502	26686	Economy	6200.00
0005435983500	26686	Economy	6200.00
0005435983529	26686	Economy	6200.00
0005435983637	26686	Economy	6200.00
0005435983545	26686	Economy	6200.00
0005435983576	26686	Economy	6200.00
0005435983662	26686	Economy	6200.00
0005435983544	26686	Economy	6200.00
0005435983594	26686	Economy	6200.00
0005435983449	26686	Economy	6200.00
0005435983486	26686	Economy	6200.00
0005435983513	26686	Economy	6200.00
0005435983450	26686	Economy	6200.00
0005433686691	29259	Economy	19100.00
0005433686681	29259	Economy	19100.00
0005433686680	29259	Economy	19100.00
0005433686678	29259	Economy	19100.00
0005433686686	29259	Economy	19100.00
0005433686687	29259	Economy	19100.00
0005433686685	29259	Economy	19100.00
0005433686679	29259	Economy	19100.00
0005433686692	29259	Economy	19100.00
0005433689963	29259	Economy	19100.00
0005433686697	29259	Economy	19100.00
0005433686696	29259	Economy	19100.00
0005432858396	3150	Economy	10100.00
0005432858402	3150	Economy	10100.00
0005432584775	31501	Economy	10100.00
0005432584757	31501	Economy	10100.00
0005432584743	31501	Economy	10100.00
0005432584774	31501	Economy	10100.00
0005432584768	31501	Economy	10100.00
0005432584767	31501	Economy	10100.00
0005432584773	31501	Economy	10100.00
0005432584759	31501	Economy	10100.00
0005432584756	31501	Economy	10100.00
0005432584760	31501	Economy	10100.00
0005432584761	31501	Economy	10100.00
0005433255271	913	Economy	7500.00
0005434943580	16222	Economy	7500.00
0005435999868	19646	Economy	29700.00
0005435999865	19646	Economy	29700.00
0005435999866	19646	Economy	29700.00
0005435999867	19646	Economy	29700.00
0005433654985	27610	Business	90500.00
0005433654957	27610	Business	90500.00
0005433654980	27610	Business	90500.00
0005433654972	27610	Economy	30200.00
0005433654949	27610	Economy	30200.00
0005433654971	27610	Economy	33200.00
0005433654973	27610	Economy	30200.00
0005433654974	27610	Economy	30200.00
0005433654987	27610	Economy	30200.00
0005433654986	27610	Economy	30200.00
0005433654975	27610	Economy	30200.00
0005433654979	27610	Economy	30200.00
0005433811683	14441	Economy	4400.00
0005433811674	14441	Economy	4400.00
0005433811685	14441	Economy	4400.00
0005433368931	21781	Business	9800.00
0005433368897	21781	Economy	3300.00
0005433368932	21781	Economy	3600.00
0005433368841	21781	Economy	3300.00
0005433368941	21781	Economy	3300.00
0005433368930	21781	Economy	3300.00
0005433368946	21781	Economy	3300.00
0005433368943	21781	Economy	3300.00
0005433368903	21781	Economy	3300.00
0005433368904	21781	Economy	3300.00
0005433368939	21781	Economy	3300.00
0005433368849	21781	Economy	3300.00
0005433368940	21781	Economy	3300.00
0005433368731	21781	Economy	3300.00
0005433368976	21781	Economy	3300.00
0005435270209	9371	Business	186200.00
0005435270208	9371	Business	186200.00
0005435270189	9371	Business	186200.00
0005435858714	9371	Economy	68300.00
0005435270021	9371	Economy	62100.00
0005435270106	9371	Economy	62100.00
0005434151791	9371	Economy	62100.00
0005435270128	9371	Economy	62100.00
0005434151792	9371	Economy	62100.00
0005435858740	9371	Economy	62100.00
0005435858730	9371	Economy	62100.00
0005435270094	9371	Economy	62100.00
0005435858716	9371	Economy	62100.00
0005435270215	9371	Economy	62100.00
0005435270213	9371	Economy	62100.00
0005435270164	9371	Economy	62100.00
0005435858731	9371	Economy	62100.00
0005435270199	9371	Economy	62100.00
0005435858724	9371	Economy	62100.00
0005435270190	9371	Economy	62100.00
0005435270216	9371	Economy	62100.00
0005435270092	9371	Economy	62100.00
0005435858713	9371	Economy	62100.00
0005435858725	9371	Economy	62100.00
0005435270188	9371	Economy	62100.00
0005435270201	9371	Economy	62100.00
0005435858717	9371	Economy	62100.00
0005435270019	9371	Economy	62100.00
0005435270093	9371	Economy	62100.00
0005435270077	9371	Economy	62100.00
0005435270020	9371	Economy	62100.00
0005433786183	26269	Business	186200.00
0005433786144	26269	Business	186200.00
0005433786032	26269	Business	186200.00
0005433806326	26269	Business	186200.00
0005433785983	26269	Business	186200.00
0005433806289	26269	Business	186200.00
0005433806374	26269	Business	186200.00
0005433806400	26269	Business	186200.00
0005433806385	26269	Business	186200.00
0005433786172	26269	Business	186200.00
0005433785981	26269	Business	186200.00
0005433806325	26269	Business	186200.00
0005433785964	26269	Business	186200.00
0005433786134	26269	Economy	68300.00
0005433806371	26269	Economy	62100.00
0005433786158	26269	Economy	62100.00
0005432657533	26269	Economy	62100.00
0005432659767	26269	Economy	62100.00
0005433763614	26269	Economy	62100.00
0005433786182	26269	Economy	62100.00
0005433806364	26269	Economy	62100.00
0005433786024	26269	Economy	62100.00
0005433806290	26269	Economy	62100.00
0005433786128	26269	Economy	62100.00
0005433786167	26269	Economy	62100.00
0005433786031	26269	Economy	62100.00
0005432657534	26269	Economy	62100.00
0005433786040	26269	Economy	62100.00
0005433785965	26269	Economy	62100.00
0005433786097	26269	Economy	62100.00
0005433806409	26269	Economy	62100.00
0005432659757	26269	Economy	62100.00
0005433786057	26269	Economy	62100.00
0005433786072	26269	Economy	62100.00
0005433806296	26269	Economy	62100.00
0005433806191	26269	Economy	62100.00
0005433786056	26269	Economy	62100.00
0005433786025	26269	Economy	62100.00
0005432659753	26269	Economy	62100.00
0005433785916	26269	Economy	62100.00
0005433806292	26269	Economy	62100.00
0005433806336	26269	Economy	62100.00
0005433806401	26269	Economy	62100.00
0005433785945	26269	Economy	62100.00
0005433786173	26269	Economy	62100.00
0005433806348	26269	Economy	62100.00
0005433806387	26269	Economy	62100.00
0005433785982	26269	Economy	62100.00
0005433806406	26269	Economy	62100.00
0005433786036	26269	Economy	62100.00
0005433763606	26269	Economy	62100.00
0005433785925	26269	Economy	62100.00
0005433763611	26269	Economy	62100.00
0005433763626	26269	Economy	62100.00
0005433786160	26269	Economy	62100.00
0005433786082	26269	Economy	62100.00
0005433786168	26269	Economy	62100.00
0005432659766	26269	Economy	62100.00
0005433785926	26269	Economy	62100.00
0005433763625	26269	Economy	62100.00
0005433786192	26269	Economy	62100.00
0005433786094	26269	Economy	62100.00
0005433786159	26269	Economy	62100.00
0005433786193	26269	Economy	62100.00
0005433786169	26269	Economy	62100.00
0005433806366	26269	Economy	62100.00
0005433786071	26269	Economy	62100.00
0005433806370	26269	Economy	62100.00
0005433806365	26269	Economy	62100.00
0005433806291	26269	Economy	62100.00
0005433806381	26269	Economy	62100.00
0005433806338	26269	Economy	62100.00
0005433786037	26269	Economy	62100.00
0005433786044	26269	Economy	62100.00
0005434218087	9465	Economy	17900.00
0005434218086	9465	Economy	17900.00
0005433962276	24289	Business	36400.00
0005433962470	24289	Business	36400.00
0005433987209	24289	Business	36400.00
0005433987378	24289	Business	36400.00
0005433987191	24289	Business	36400.00
0005433962648	24289	Business	36400.00
0005433962382	24289	Business	36400.00
0005433987203	24289	Business	36400.00
0005433962516	24289	Business	36400.00
0005433962578	24289	Business	36400.00
0005433962613	24289	Business	36400.00
0005433962652	24289	Business	36400.00
0005433987100	24289	Business	36400.00
0005433987208	24289	Business	36400.00
0005433962327	24289	Economy	13400.00
0005433962438	24289	Economy	13400.00
0005433987333	24289	Economy	12100.00
0005433962435	24289	Economy	12100.00
0005433962436	24289	Economy	12100.00
0005433986987	24289	Economy	12100.00
0005433962504	24289	Economy	12100.00
0005433987316	24289	Economy	12100.00
0005433962479	24289	Economy	12100.00
0005433962614	24289	Economy	12100.00
0005433962629	24289	Economy	12100.00
0005433962439	24289	Economy	12100.00
0005433987101	24289	Economy	12100.00
0005433987216	24289	Economy	12100.00
0005433962620	24289	Economy	12100.00
0005433962679	24289	Economy	12100.00
0005433962682	24289	Economy	12100.00
0005433962673	24289	Economy	12100.00
0005433962699	24289	Economy	12100.00
0005433962671	24289	Economy	12100.00
0005433962434	24289	Economy	12100.00
0005433962557	24289	Economy	12100.00
0005433962476	24289	Economy	12100.00
0005433986988	24289	Economy	12100.00
0005433987099	24289	Economy	12100.00
0005433962551	24289	Economy	12100.00
0005433962688	24289	Economy	12100.00
0005433987238	24289	Economy	12100.00
0005433987231	24289	Economy	12100.00
0005433962694	24289	Economy	12100.00
0005433962361	24289	Economy	12100.00
0005433962608	24289	Economy	12100.00
0005433962354	24289	Economy	12100.00
0005433962568	24289	Economy	12100.00
0005433987326	24289	Economy	12100.00
0005433962656	24289	Economy	12100.00
0005433962510	24289	Economy	12100.00
0005433987218	24289	Economy	12100.00
0005433962556	24289	Economy	12100.00
0005433987286	24289	Economy	12100.00
0005433962502	24289	Economy	12100.00
0005433987003	24289	Economy	12100.00
0005433987004	24289	Economy	12100.00
0005433987217	24289	Economy	12100.00
0005433987139	24289	Economy	12100.00
0005433987223	24289	Economy	13400.00
0005433962500	24289	Economy	13400.00
0005433987284	24289	Economy	12100.00
0005433987347	24289	Economy	13400.00
0005433962590	24289	Economy	12100.00
0005433962721	24289	Economy	12100.00
0005433962722	24289	Economy	12100.00
0005433962632	24289	Economy	12100.00
0005433962478	24289	Economy	12100.00
0005433962651	24289	Economy	12100.00
0005433962572	24289	Economy	12100.00
0005433962548	24289	Economy	12100.00
0005433962522	24289	Economy	12100.00
0005433962496	24289	Economy	12100.00
0005433962344	24289	Economy	12100.00
0005433962469	24289	Economy	12100.00
0005433962549	24289	Economy	12100.00
0005433962511	24289	Economy	12100.00
0005433962737	24289	Economy	12100.00
0005433962410	24289	Economy	12100.00
0005433962356	24289	Economy	12100.00
0005433962503	24289	Economy	12100.00
0005433962577	24289	Economy	12100.00
0005433987142	24289	Economy	12100.00
0005433962573	24289	Economy	12100.00
0005433962499	24289	Economy	12100.00
0005433962693	24289	Economy	12100.00
0005433962443	24289	Economy	12100.00
0005433962670	24289	Economy	12100.00
0005433987224	24289	Economy	12100.00
0005433962733	24289	Economy	12100.00
0005433962672	24289	Economy	12100.00
0005433962485	24289	Economy	12100.00
0005433962732	24289	Economy	12100.00
0005433962505	24289	Economy	12100.00
0005433962569	24289	Economy	12100.00
0005433987287	24289	Economy	12100.00
0005433987325	24289	Economy	12100.00
0005433987348	24289	Economy	12100.00
0005433962355	24289	Economy	12100.00
0005433962738	24289	Economy	12100.00
0005433962612	24289	Economy	12100.00
0005433962743	24289	Economy	12100.00
0005433987235	24289	Economy	12100.00
0005433987355	24289	Economy	12100.00
0005433962506	24289	Economy	12100.00
0005433987268	24289	Economy	12100.00
0005433987380	25937	Economy	12100.00
0005433987381	25937	Economy	12100.00
0005433166254	965	Economy	23100.00
0005433166257	965	Economy	23100.00
0005433166278	965	Economy	23100.00
0005433166280	965	Economy	23100.00
0005433166277	965	Economy	23100.00
0005433166255	965	Economy	23100.00
0005433166256	965	Economy	23100.00
0005434481047	16559	Economy	23100.00
0005434481017	16559	Economy	23100.00
0005434481032	16559	Economy	23100.00
0005434481048	16559	Economy	23100.00
0005434481016	16559	Economy	23100.00
0005433290064	10355	Economy	17000.00
0005433290044	10355	Economy	15400.00
0005433290045	10355	Economy	15400.00
0005433290051	10355	Economy	15400.00
0005433290066	10355	Economy	15400.00
0005433290062	10355	Economy	15400.00
0005435386753	10355	Economy	15400.00
0005433290063	10355	Economy	15400.00
0005435386746	10355	Economy	15400.00
0005435150417	21930	Economy	15400.00
0005435142945	21930	Economy	15400.00
0005435150389	21930	Economy	15400.00
0005435150415	21930	Economy	15400.00
0005435142948	21930	Economy	15400.00
0005435150414	21930	Economy	15400.00
0005435142959	21930	Economy	15400.00
0005435150413	21930	Economy	15400.00
0005435142944	21930	Economy	15400.00
0005435142964	21930	Economy	15400.00
0005435142961	21930	Economy	15400.00
0005435142960	21930	Economy	15400.00
0005435150407	21930	Economy	15400.00
0005435529844	11225	Business	57200.00
0005435319816	11225	Business	57200.00
0005435545943	11225	Business	57200.00
0005435502958	11225	Business	57200.00
0005435545935	11225	Business	57200.00
0005435502938	11225	Economy	19100.00
0005435502900	11225	Economy	19100.00
0005435319820	11225	Economy	19100.00
0005435502954	11225	Economy	19100.00
0005435502927	11225	Economy	21000.00
0005435545976	11225	Economy	21000.00
0005435545914	11225	Economy	21000.00
0005435529868	11225	Economy	21000.00
0005435502955	11225	Economy	19100.00
0005435529835	11225	Economy	19100.00
0005435502939	11225	Economy	19100.00
0005435529881	11225	Economy	19100.00
0005435529836	11225	Economy	19100.00
0005435502946	11225	Economy	19100.00
0005435502867	11225	Economy	19100.00
0005435502844	11225	Economy	19100.00
0005435502841	11225	Economy	19100.00
0005435502916	11225	Economy	19100.00
0005435319795	11225	Economy	19100.00
0005435545936	11225	Economy	19100.00
0005435319814	11225	Economy	19100.00
0005435529846	11225	Economy	19100.00
0005435502843	11225	Economy	19100.00
0005435319794	11225	Economy	19100.00
0005435319815	11225	Economy	19100.00
0005435319826	11225	Economy	19100.00
0005435319821	11225	Economy	19100.00
0005435545937	11225	Economy	19100.00
0005435502917	11225	Economy	19100.00
0005435502957	11225	Economy	19100.00
0005435545960	11225	Economy	19100.00
0005435529842	11225	Economy	19100.00
0005435529850	11225	Economy	19100.00
0005435545915	11225	Economy	19100.00
0005435545975	11225	Economy	19100.00
0005435319819	11225	Economy	19100.00
0005435529845	11225	Economy	19100.00
0005435529840	11225	Economy	19100.00
0005434573759	20930	Business	57200.00
0005434573719	20930	Business	57200.00
0005434573736	20930	Economy	19100.00
0005435502967	20930	Economy	21000.00
0005434573749	20930	Economy	19100.00
0005435502968	20930	Economy	19100.00
0005434573730	20930	Economy	19100.00
0005434573686	20930	Economy	19100.00
0005434573732	20930	Economy	19100.00
0005434573748	20930	Economy	19100.00
0005434573760	20930	Economy	19100.00
0005434573717	20930	Economy	19100.00
0005434573747	20930	Economy	19100.00
0005434573718	20930	Economy	19100.00
0005434573744	20930	Economy	19100.00
0005432693918	3016	Business	10300.00
0005432693878	3016	Business	10300.00
0005432693881	3016	Business	10300.00
0005432693877	3016	Economy	3400.00
0005432693921	3016	Economy	3400.00
0005432693880	3016	Economy	3800.00
0005432693894	3016	Economy	3400.00
0005432693932	3016	Economy	3400.00
0005432693954	3016	Economy	3400.00
0005432693931	3016	Economy	3400.00
0005433194956	3044	Business	10300.00
0005433194940	3044	Business	10300.00
0005432881226	3044	Business	10300.00
0005433194966	3044	Business	10300.00
0005433124502	3044	Business	10300.00
0005433124483	3044	Business	10300.00
0005434300234	3044	Economy	3400.00
0005433124538	3044	Economy	3400.00
0005432881213	3044	Economy	3400.00
0005432881246	3044	Economy	3400.00
0005433194957	3044	Economy	3400.00
0005433124532	3044	Economy	3400.00
0005432881244	3044	Economy	3400.00
0005433194997	3044	Economy	3400.00
0005434300245	3044	Economy	3400.00
0005432881222	3044	Economy	3400.00
0005433124531	3044	Economy	3400.00
0005433194961	3044	Economy	3400.00
0005433194935	3044	Economy	3400.00
0005432881243	3044	Economy	3400.00
0005433124503	3044	Economy	3400.00
0005433194998	3044	Economy	3400.00
0005433124514	3044	Economy	3400.00
0005433124527	3044	Economy	3400.00
0005433124515	3044	Economy	3400.00
0005434300244	3044	Economy	3400.00
0005432881247	3044	Economy	3400.00
0005432881203	3044	Economy	3400.00
0005433124520	3044	Economy	3400.00
0005433124529	3044	Economy	3400.00
0005433124513	3044	Economy	3400.00
0005433124521	3044	Economy	3400.00
0005433124552	3044	Economy	3400.00
0005433124526	3044	Economy	3400.00
0005433124484	3044	Economy	3400.00
0005433124523	3044	Economy	3400.00
0005432881248	3044	Economy	3400.00
0005433194962	3044	Economy	3400.00
0005434310164	30031	Business	10300.00
0005432707496	30031	Business	10300.00
0005432707508	30031	Economy	3800.00
0005432707476	30031	Economy	3400.00
0005432707475	30031	Economy	3400.00
0005434310160	30031	Economy	3400.00
0005434310161	30031	Economy	3400.00
0005434310162	30031	Economy	3400.00
0005432707509	30031	Economy	3400.00
0005432707502	30031	Economy	3400.00
0005434310159	30031	Economy	3400.00
0005434980601	27548	Economy	4000.00
0005434989048	27548	Economy	4000.00
0005434989092	27548	Economy	3600.00
0005434989113	27548	Economy	3600.00
0005434989080	27548	Economy	3600.00
0005434989112	27548	Economy	3600.00
0005434980661	27548	Economy	3600.00
0005434989055	27548	Economy	3600.00
0005434980642	27548	Economy	3600.00
0005434989040	27548	Economy	3600.00
0005434989049	27548	Economy	3600.00
0005434989058	27548	Economy	3600.00
0005434980652	27548	Economy	3600.00
0005434980653	27548	Economy	3600.00
0005434989057	27548	Economy	3600.00
0005434989103	27548	Economy	3600.00
0005434989065	27548	Economy	3600.00
0005434989045	27548	Economy	3600.00
0005434980654	27548	Economy	3600.00
0005434980560	27548	Economy	3600.00
0005434980524	27548	Economy	3600.00
0005434989032	27548	Economy	3600.00
0005434989042	27548	Economy	3600.00
0005434980518	27548	Economy	3600.00
0005434980628	27548	Economy	3600.00
0005434980651	27548	Economy	3600.00
0005434989044	27548	Economy	3600.00
0005434980611	27548	Economy	3600.00
0005434989064	27548	Economy	3600.00
0005434989063	27548	Economy	3600.00
0005433111554	10298	Economy	19700.00
0005434302579	19588	Economy	19700.00
0005434302573	19588	Economy	19700.00
0005435939963	3569	Business	26900.00
0005435925609	3569	Business	26900.00
0005435939927	3569	Business	26900.00
0005435925691	3569	Economy	9000.00
0005435939950	3569	Economy	9000.00
0005435925695	3569	Economy	9000.00
0005435925630	3569	Economy	9000.00
0005435939925	3569	Economy	9000.00
0005435925705	3569	Economy	9000.00
0005435925710	3569	Economy	9000.00
0005435939964	3569	Economy	9000.00
0005435925709	3569	Economy	9000.00
0005435939926	3569	Economy	9000.00
0005435939965	3569	Economy	9000.00
0005435925608	3569	Economy	9000.00
0005435070496	15329	Business	26900.00
0005435950322	15329	Economy	9000.00
0005435070386	15329	Economy	9900.00
0005435950317	15329	Economy	9900.00
0005435070385	15329	Economy	9000.00
0005435950318	15329	Economy	9000.00
0005435070363	15329	Economy	9000.00
0005435950336	15329	Economy	9000.00
0005435070512	15329	Economy	9000.00
0005435070541	15329	Economy	9000.00
0005435070498	15329	Economy	9000.00
0005435070383	15329	Economy	9000.00
0005435950321	15329	Economy	9000.00
0005435070529	15329	Economy	9000.00
0005435070533	15329	Economy	9000.00
0005435070470	15329	Economy	9000.00
0005435070509	15329	Economy	9000.00
0005435070487	15329	Economy	9000.00
0005435070458	15329	Economy	9000.00
0005435950323	15329	Economy	9000.00
0005435070497	15329	Economy	9000.00
0005432664190	26392	Economy	5900.00
0005433103869	196	Business	20000.00
0005433103650	196	Business	20000.00
0005433103897	196	Business	20000.00
0005433103811	196	Business	20000.00
0005432902082	196	Business	20000.00
0005432902106	196	Business	20000.00
0005433104000	196	Business	20000.00
0005433103820	196	Business	20000.00
0005433103757	196	Business	20000.00
0005432920466	196	Business	20000.00
0005433103763	196	Business	20000.00
0005432902093	196	Business	20000.00
0005433103633	196	Business	20000.00
0005433104008	196	Business	20000.00
0005433103870	196	Business	20000.00
0005432902119	196	Business	20000.00
0005432902041	196	Economy	7300.00
0005432902121	196	Economy	7300.00
0005433103814	196	Economy	7300.00
0005433103758	196	Economy	7300.00
0005432920452	196	Economy	6700.00
0005433103713	196	Economy	6700.00
0005433103782	196	Economy	6700.00
0005433103938	196	Economy	6700.00
0005432902120	196	Economy	6700.00
0005432920464	196	Economy	6700.00
0005433103942	196	Economy	6700.00
0005433103837	196	Economy	6700.00
0005433103714	196	Economy	6700.00
0005432902117	196	Economy	6700.00
0005433103649	196	Economy	6700.00
0005433103886	196	Economy	6700.00
0005433103943	196	Economy	6700.00
0005433103655	196	Economy	6700.00
0005433103609	196	Economy	6700.00
0005433435531	196	Economy	6700.00
0005433435515	196	Economy	6700.00
0005433103908	196	Economy	6700.00
0005432677674	196	Economy	6700.00
0005433103852	196	Economy	6700.00
0005433103759	196	Economy	6700.00
0005433103821	196	Economy	6700.00
0005433435513	196	Economy	6700.00
0005433103885	196	Economy	6700.00
0005432920465	196	Economy	6700.00
0005433103576	196	Economy	6700.00
0005433435532	196	Economy	6700.00
0005433103783	196	Economy	6700.00
0005433103656	196	Economy	7300.00
0005433103746	196	Economy	7300.00
0005433103744	196	Economy	7300.00
0005433103920	196	Economy	6700.00
0005433103843	196	Economy	6700.00
0005433103715	196	Economy	6700.00
0005433103610	196	Economy	6700.00
0005433103836	196	Economy	6700.00
0005433103819	196	Economy	6700.00
0005433435512	196	Economy	6700.00
0005433103671	196	Economy	6700.00
0005433103636	196	Economy	6700.00
0005433103755	196	Economy	6700.00
0005433103721	196	Economy	6700.00
0005433103972	196	Economy	6700.00
0005432677673	196	Economy	6700.00
0005432902118	196	Economy	6700.00
0005432920477	196	Economy	6700.00
0005432677691	196	Economy	6700.00
0005433103611	196	Economy	6700.00
0005432677692	196	Economy	6700.00
0005433103803	196	Economy	6700.00
0005432902125	196	Economy	6700.00
0005432920451	196	Economy	6700.00
0005432902115	196	Economy	6700.00
0005433103937	196	Economy	6700.00
0005433103672	196	Economy	6700.00
0005433103703	196	Economy	6700.00
0005433103977	196	Economy	6700.00
0005433103745	196	Economy	6700.00
0005432753385	76	Business	20000.00
0005433690985	76	Business	20000.00
0005433690982	76	Economy	6700.00
0005433690983	76	Economy	6700.00
0005432756930	76	Economy	6700.00
0005433690986	76	Economy	6700.00
0005432753397	76	Economy	6700.00
0005432753396	76	Economy	6700.00
0005432756931	76	Economy	6700.00
0005432756929	76	Economy	6700.00
0005432753384	76	Economy	6700.00
0005433690981	76	Economy	6700.00
0005434157806	8116	Business	20000.00
0005433477221	8116	Business	20000.00
0005434157831	8116	Business	20000.00
0005433477287	8116	Business	20000.00
0005434157810	8116	Business	20000.00
0005433477237	8116	Business	20000.00
0005433477272	8116	Business	20000.00
0005434157981	8116	Business	20000.00
0005434157757	8116	Business	20000.00
0005434157840	8116	Business	20000.00
0005433477165	8116	Business	20000.00
0005434157755	8116	Business	20000.00
0005433477283	8116	Economy	7300.00
0005434157754	8116	Economy	7300.00
0005434157782	8116	Economy	7300.00
0005434157830	8116	Economy	6700.00
0005434157886	8116	Economy	6700.00
0005433477286	8116	Economy	6700.00
0005434157967	8116	Economy	6700.00
0005434151809	8116	Economy	6700.00
0005434157845	8116	Economy	6700.00
0005434157753	8116	Economy	6700.00
0005434157761	8116	Economy	6700.00
0005434157885	8116	Economy	6700.00
0005434157884	8116	Economy	6700.00
0005434157899	8116	Economy	6700.00
0005434157788	8116	Economy	6700.00
0005434157805	8116	Economy	6700.00
0005433477238	8116	Economy	6700.00
0005433477176	8116	Economy	6700.00
0005434157793	8116	Economy	6700.00
0005434157906	8116	Economy	6700.00
0005434152874	8116	Economy	6700.00
0005433477273	8116	Economy	6700.00
0005434157758	8116	Economy	6700.00
0005433477220	8116	Economy	6700.00
0005433477200	8116	Economy	6700.00
0005434157856	8116	Economy	6700.00
0005433477174	8116	Economy	6700.00
0005434157790	8116	Economy	6700.00
0005434157839	8116	Economy	6700.00
0005433477199	8116	Economy	6700.00
0005433477175	8116	Economy	7300.00
0005434157792	8116	Economy	7300.00
0005434157809	8116	Economy	7300.00
0005434157947	8116	Economy	6700.00
0005433477166	8116	Economy	7300.00
0005434157918	8116	Economy	6700.00
0005434157819	8116	Economy	6700.00
0005434157785	8116	Economy	6700.00
0005434157957	8116	Economy	6700.00
0005434157987	8116	Economy	6700.00
0005433477236	8116	Economy	6700.00
0005434157813	8116	Economy	6700.00
0005434157789	8116	Economy	6700.00
0005434157848	8116	Economy	6700.00
0005434157897	8116	Economy	6700.00
0005433477253	8116	Economy	6700.00
0005433477271	8116	Economy	6700.00
0005433477227	8116	Economy	6700.00
0005433477239	8116	Economy	6700.00
0005434157855	8116	Economy	6700.00
0005433477137	8116	Economy	6700.00
0005434157966	8116	Economy	6700.00
0005434157766	8116	Economy	6700.00
0005434157798	8116	Economy	6700.00
0005434157872	8116	Economy	6700.00
0005434157725	8116	Economy	6700.00
0005434157777	8116	Economy	6700.00
0005433477203	8116	Economy	6700.00
0005434157762	8116	Economy	6700.00
0005434157942	8116	Economy	6700.00
0005433477267	8116	Economy	6700.00
0005434157778	8116	Economy	6700.00
0005433477243	8116	Economy	6700.00
0005434157919	8116	Economy	6700.00
0005434157943	8116	Economy	6700.00
0005434157857	8116	Economy	6700.00
0005434157971	8116	Economy	6700.00
0005434157724	8116	Economy	6700.00
0005434157832	8116	Economy	6700.00
0005434157883	8116	Economy	6700.00
0005434157783	8116	Economy	6700.00
0005434157946	8116	Economy	6700.00
0005432818194	8117	Business	20000.00
0005432818274	8117	Economy	6700.00
0005432818240	8117	Economy	6700.00
0005432818195	8117	Economy	6700.00
0005432818290	8117	Economy	6700.00
0005432818269	8117	Economy	6700.00
0005432818275	8117	Economy	6700.00
0005432818267	8117	Economy	6700.00
0005432818289	8117	Economy	6700.00
0005434175869	9689	Economy	6900.00
0005434175870	9689	Economy	6900.00
0005433870798	32339	Economy	6900.00
0005433870799	32339	Economy	6900.00
0005435903202	3515	Business	35000.00
0005435914180	3515	Business	35000.00
0005435914159	3515	Business	35000.00
0005435914076	3515	Comfort	19900.00
0005435914775	3515	Comfort	19900.00
0005435914187	3515	Comfort	19900.00
0005435914170	3515	Comfort	19900.00
0005435914121	3515	Comfort	19900.00
0005435914182	3515	Comfort	19900.00
0005435914211	3515	Comfort	19900.00
0005435914108	3515	Comfort	19900.00
0005435914173	3515	Economy	11700.00
0005435914777	3515	Economy	11700.00
0005435914212	3515	Economy	11700.00
0005435903204	3515	Economy	11700.00
0005435914158	3515	Economy	11700.00
0005435914141	3515	Economy	11700.00
0005435914142	3515	Economy	11700.00
0005435903216	3515	Economy	11700.00
0005435914116	3515	Economy	11700.00
0005435914077	3515	Economy	11700.00
0005435914214	3515	Economy	11700.00
0005435914117	3515	Economy	11700.00
0005435914215	3515	Economy	11700.00
0005435903200	3515	Economy	11700.00
0005435914169	3515	Economy	11700.00
0005435914181	3515	Economy	11700.00
0005435903201	3515	Economy	11700.00
0005435903203	3515	Economy	11700.00
0005435914100	3515	Economy	11700.00
0005435914213	3515	Economy	11700.00
0005435914776	3515	Economy	11700.00
0005435914204	3515	Economy	11700.00
0005435903142	3515	Economy	11700.00
0005435914172	3515	Economy	11700.00
0005435914140	3515	Economy	11700.00
0005435841121	3515	Economy	11700.00
0005435914107	3515	Economy	11700.00
0005434880621	14564	Business	35000.00
0005435127522	14564	Business	35000.00
0005435626816	14564	Business	35000.00
0005434880927	14564	Business	35000.00
0005435127555	14564	Business	35000.00
0005435127521	14564	Business	35000.00
0005432607669	14564	Business	35000.00
0005434938700	14564	Business	35000.00
0005432800273	14564	Business	35000.00
0005435626817	14564	Business	35000.00
0005434880913	14564	Comfort	19900.00
0005434427457	14564	Comfort	19900.00
0005435626840	14564	Comfort	19900.00
0005435626783	14564	Comfort	19900.00
0005432800237	14564	Comfort	19900.00
0005434880824	14564	Comfort	19900.00
0005432800254	14564	Comfort	19900.00
0005434938718	14564	Comfort	19900.00
0005435626835	14564	Comfort	19900.00
0005434880788	14564	Comfort	19900.00
0005434880791	14564	Comfort	19900.00
0005435626664	14564	Comfort	19900.00
0005432611799	14564	Comfort	19900.00
0005434427431	14564	Economy	11700.00
0005434880776	14564	Economy	11700.00
0005432800255	14564	Economy	11700.00
0005434880894	14564	Economy	11700.00
0005434427415	14564	Economy	11700.00
0005434880487	14564	Economy	11700.00
0005435626711	14564	Economy	11700.00
0005435626624	14564	Economy	11700.00
0005434880914	14564	Economy	11700.00
0005434880960	14564	Economy	11700.00
0005435127525	14564	Economy	11700.00
0005435626849	14564	Economy	11700.00
0005434880620	14564	Economy	11700.00
0005434938708	14564	Economy	11700.00
0005435127331	14564	Economy	11700.00
0005435626852	14564	Economy	11700.00
0005432800267	14564	Economy	11700.00
0005435127411	14564	Economy	11700.00
0005435626827	14564	Economy	11700.00
0005434880675	14564	Economy	11700.00
0005435626626	14564	Economy	11700.00
0005435626836	14564	Economy	11700.00
0005434427414	14564	Economy	11700.00
0005434427449	14564	Economy	11700.00
0005434880774	14564	Economy	11700.00
0005435626743	14564	Economy	11700.00
0005434427450	14564	Economy	11700.00
0005435127529	14564	Economy	11700.00
0005435626779	14564	Economy	11700.00
0005432611805	14564	Economy	11700.00
0005434880676	14564	Economy	11700.00
0005435626784	14564	Economy	11700.00
0005434938650	14564	Economy	11700.00
0005435626718	14564	Economy	11700.00
0005432800219	14564	Economy	11700.00
0005435127512	14564	Economy	11700.00
0005434880775	14564	Economy	11700.00
0005435626649	14564	Economy	11700.00
0005434880671	14564	Economy	11700.00
0005435626768	14564	Economy	11700.00
0005435626747	14564	Economy	11700.00
0005435626625	14564	Economy	11700.00
0005435127523	14564	Economy	11700.00
0005435626806	14564	Economy	11700.00
0005435626789	14564	Economy	11700.00
0005434938651	14564	Economy	11700.00
0005434427396	14564	Economy	11700.00
0005434880904	14564	Economy	11700.00
0005435626807	14564	Economy	11700.00
0005432800281	14564	Economy	11700.00
0005432800249	14564	Economy	11700.00
0005434880953	14564	Economy	11700.00
0005435127565	14564	Economy	11700.00
0005434880833	14564	Economy	11700.00
0005432607668	14564	Economy	11700.00
0005435127508	14564	Economy	11700.00
0005435626821	14564	Economy	11700.00
0005432800282	14564	Economy	11700.00
0005434427448	14564	Economy	11700.00
0005434427429	14564	Economy	11700.00
0005434880760	14564	Economy	11700.00
0005434880670	14564	Economy	11700.00
0005434880674	14564	Economy	12800.00
0005435626665	14564	Economy	12800.00
0005435626769	14564	Economy	12800.00
0005432800251	14564	Economy	11700.00
0005435626673	14564	Economy	11700.00
0005435626797	14564	Economy	11700.00
0005432800280	14564	Economy	11700.00
0005434880981	14564	Economy	11700.00
0005432607670	14564	Economy	11700.00
0005435626714	14564	Economy	11700.00
0005434427430	14564	Economy	11700.00
0005435127319	14564	Economy	11700.00
0005435127515	14564	Economy	11700.00
0005432800250	14564	Economy	11700.00
0005435626778	14564	Economy	11700.00
0005434427433	14564	Economy	11700.00
0005435626719	14564	Economy	11700.00
0005434427412	14564	Economy	11700.00
0005434880645	14564	Economy	11700.00
0005432611806	14564	Economy	11700.00
0005432800278	14564	Economy	11700.00
0005434880888	14564	Economy	11700.00
0005434880789	14564	Economy	11700.00
0005432800268	14564	Economy	11700.00
0005435127556	14564	Economy	11700.00
0005434880622	14564	Economy	11700.00
0005435127528	14564	Economy	11700.00
0005434880975	14564	Economy	11700.00
0005432611812	14564	Economy	11700.00
0005434880660	14564	Economy	11700.00
0005435626692	14564	Economy	11700.00
0005435626746	14564	Economy	11700.00
0005434880659	14564	Economy	11700.00
0005435127318	14564	Economy	11700.00
0005434880935	14564	Economy	11700.00
0005435626805	14564	Economy	11700.00
0005435626689	14564	Economy	11700.00
0005432800283	14564	Economy	11700.00
0005432611811	14564	Economy	11700.00
0005434880835	14564	Economy	11700.00
0005435626822	14564	Economy	11700.00
0005434938709	14564	Economy	11700.00
0005434427445	14564	Economy	11700.00
0005434938717	14564	Economy	11700.00
0005435626833	14564	Economy	11700.00
0005435890069	3584	Economy	16300.00
0005435890072	3584	Economy	14800.00
0005435890070	3584	Economy	14800.00
0005435890059	3584	Economy	14800.00
0005435890075	3584	Economy	14800.00
0005435890058	3584	Economy	14800.00
0005434325982	15590	Economy	16300.00
0005434325984	15590	Economy	14800.00
0005434325945	15590	Economy	14800.00
0005434325944	15590	Economy	14800.00
0005434325983	15590	Economy	14800.00
0005434325972	15590	Economy	14800.00
0005434311291	15590	Economy	14800.00
0005433420632	638	Economy	4100.00
0005433420649	638	Economy	4100.00
0005433420648	638	Economy	4100.00
0005435958090	15161	Economy	4500.00
0005435958072	15161	Economy	4100.00
0005435958078	15161	Economy	4100.00
0005435958121	15161	Economy	4100.00
0005435958125	15161	Economy	4100.00
0005435958120	15161	Economy	4100.00
0005435958112	15161	Economy	4100.00
0005435629448	16116	Economy	10400.00
0005435629446	16116	Economy	10400.00
0005435629447	16116	Economy	10400.00
0005434096801	11831	Economy	14700.00
0005434096797	11831	Economy	13400.00
0005434096805	11831	Economy	13400.00
0005434096804	11831	Economy	13400.00
0005434096799	11831	Economy	13400.00
0005434096798	11831	Economy	13400.00
0005432646354	25119	Business	87700.00
0005432646350	25119	Business	87700.00
0005432646344	25119	Business	87700.00
0005432646339	25119	Business	87700.00
0005432646307	25119	Economy	29200.00
0005432646373	25119	Economy	29200.00
0005432646345	25119	Economy	32200.00
0005432646365	25119	Economy	32200.00
0005432646308	25119	Economy	32200.00
0005432646352	25119	Economy	29200.00
0005432646353	25119	Economy	29200.00
0005432646337	25119	Economy	29200.00
0005432646351	25119	Economy	29200.00
0005432646349	25119	Economy	29200.00
0005432646375	25119	Economy	29200.00
0005432646340	25119	Economy	29200.00
0005432646343	25119	Economy	29200.00
0005432646348	25119	Economy	29200.00
0005432646376	25119	Economy	29200.00
0005432646377	25119	Economy	29200.00
0005432646342	25119	Economy	29200.00
0005432646364	25119	Economy	29200.00
0005432646334	25119	Economy	29200.00
0005432646362	25119	Economy	29200.00
0005432646330	25119	Economy	29200.00
0005432646329	25119	Economy	29200.00
0005432646355	25119	Economy	29200.00
0005432646366	25119	Economy	29200.00
0005432646333	25119	Economy	29200.00
0005433404988	2880	Economy	4200.00
0005433404989	2880	Economy	4200.00
0005433405027	2880	Economy	4200.00
0005433405030	2880	Economy	4200.00
0005435797885	29345	Economy	4200.00
0005435376429	5801	Economy	6800.00
0005434948264	16388	Economy	6800.00
0005433962486	25779	Business	21400.00
0005433962384	25779	Business	21400.00
0005433962383	25779	Business	21400.00
0005433962584	25779	Business	21400.00
0005433962421	25779	Business	21400.00
0005433962543	25779	Business	21400.00
0005433962315	25779	Business	21400.00
0005433962377	25779	Business	21400.00
0005433962649	25779	Business	21400.00
0005433962492	25779	Business	21400.00
0005433962571	25779	Business	21400.00
0005433962236	25779	Business	21400.00
0005433962617	25779	Economy	7100.00
0005433962427	25779	Economy	7100.00
0005433962483	25779	Economy	7100.00
0005433962631	25779	Economy	7100.00
0005433962264	25779	Economy	7100.00
0005433962396	25779	Economy	7100.00
0005433962635	25779	Economy	7100.00
0005433962456	25779	Economy	7100.00
0005433962482	25779	Economy	7100.00
0005433962615	25779	Economy	7800.00
0005433962498	25779	Economy	7800.00
0005433962460	25779	Economy	7800.00
0005433962524	25779	Economy	7100.00
0005433962393	25779	Economy	7100.00
0005433962488	25779	Economy	7100.00
0005433962468	25779	Economy	7100.00
0005433962546	25779	Economy	7100.00
0005433962409	25779	Economy	7100.00
0005433962422	25779	Economy	7100.00
0005433962167	25779	Economy	7100.00
0005433962523	25779	Economy	7100.00
0005433962332	25779	Economy	7100.00
0005433962228	25779	Economy	7100.00
0005433962359	25779	Economy	7100.00
0005433962592	25779	Economy	7100.00
0005433962290	25779	Economy	7100.00
0005433962489	25779	Economy	7100.00
0005433962360	25779	Economy	7100.00
0005433962481	25779	Economy	7100.00
0005433962174	25779	Economy	7100.00
0005433962637	25779	Economy	7100.00
0005433962448	25779	Economy	7100.00
0005433962638	25779	Economy	7100.00
0005433962432	25779	Economy	7100.00
0005433962526	25779	Economy	7100.00
0005433962643	25779	Economy	7100.00
0005433962430	25779	Economy	7100.00
0005433962287	25779	Economy	7100.00
0005433962644	25779	Economy	7100.00
0005433962581	25779	Economy	7100.00
0005433962508	25779	Economy	7100.00
0005433962386	25779	Economy	7100.00
0005433962259	25779	Economy	7100.00
0005433962465	25779	Economy	7100.00
0005433962547	25779	Economy	7100.00
0005433962497	25779	Economy	7100.00
0005433962642	25779	Economy	7100.00
0005433962431	25779	Economy	7100.00
0005433962582	25779	Economy	7100.00
0005433962389	25779	Economy	7100.00
0005433962636	25779	Economy	7100.00
0005433962391	25779	Economy	7100.00
0005433962331	25779	Economy	7100.00
0005433962535	25779	Economy	7100.00
0005433962442	25779	Economy	7100.00
0005433962639	25779	Economy	7100.00
0005433962591	25779	Economy	7100.00
0005433962527	25779	Economy	7100.00
0005433962616	25779	Economy	7100.00
0005433962395	25779	Economy	7100.00
0005433962554	25779	Economy	7100.00
0005433962338	25779	Economy	7100.00
0005433962641	25779	Economy	7100.00
0005433962587	25779	Economy	7100.00
0005433962408	25779	Economy	7100.00
0005433962322	25779	Economy	7100.00
0005433962446	25779	Economy	7100.00
0005433962385	25779	Economy	7100.00
0005433962618	25779	Economy	7100.00
0005433962428	25779	Economy	7100.00
0005433962348	25779	Economy	7100.00
0005433962559	25779	Economy	7100.00
0005433962507	25779	Economy	7100.00
0005435082988	24499	Economy	3900.00
0005435083028	24499	Economy	3900.00
0005435083008	24499	Economy	3900.00
0005435083025	24499	Economy	3900.00
0005435082987	24499	Economy	3900.00
0005435286904	4937	Business	18000.00
0005435286907	4937	Business	18000.00
0005433534560	4937	Business	18000.00
0005435286936	4937	Business	18000.00
0005435286817	4937	Economy	6600.00
0005435286882	4937	Economy	6000.00
0005435286984	4937	Economy	6000.00
0005435286969	4937	Economy	6000.00
0005433534559	4937	Economy	6000.00
0005435286977	4937	Economy	6000.00
0005435286976	4937	Economy	6000.00
0005435286804	4937	Economy	6000.00
0005435286813	4937	Economy	6000.00
0005435286949	4937	Economy	6000.00
0005435286986	4937	Economy	6600.00
0005435286934	4937	Economy	6600.00
0005435286908	4937	Economy	6000.00
0005435286902	4937	Economy	6000.00
0005435286933	4937	Economy	6000.00
0005435286958	4937	Economy	6000.00
0005435286957	4937	Economy	6000.00
0005435286956	4937	Economy	6000.00
0005435286953	4937	Economy	6000.00
0005435286797	4937	Economy	6000.00
0005435286932	4937	Economy	6000.00
0005435286985	4937	Economy	6000.00
0005435286905	4937	Economy	6000.00
0005435286869	4937	Economy	6000.00
0005435286903	4937	Economy	6000.00
0005435286868	4937	Economy	6000.00
0005435007548	5045	Business	18000.00
0005434312378	5045	Business	18000.00
0005434312382	5045	Business	18000.00
0005433685588	5045	Economy	6000.00
0005435007661	5045	Economy	6000.00
0005433685574	5045	Economy	6000.00
0005432336377	5045	Economy	6000.00
0005433815514	5045	Economy	6000.00
0005432336376	5045	Economy	6000.00
0005432336373	5045	Economy	6000.00
0005434312383	5045	Economy	6000.00
0005435007681	5045	Economy	6000.00
0005433815574	5045	Economy	6000.00
0005435007675	5045	Economy	6000.00
0005433685589	5045	Economy	6000.00
0005435270193	5045	Economy	6000.00
0005435007718	5045	Economy	6000.00
0005435007719	5045	Economy	6000.00
0005435270204	5045	Economy	6000.00
0005434311272	5045	Economy	6000.00
0005434312384	5045	Economy	6000.00
0005435270174	5045	Economy	6000.00
0005435270212	5045	Economy	6000.00
0005434312385	5045	Economy	6000.00
0005435270211	5045	Economy	6000.00
0005432336382	5045	Economy	6000.00
0005435270202	5045	Economy	6000.00
0005435270122	5045	Economy	6000.00
0005435270214	5045	Economy	6000.00
0005435270200	5045	Economy	6000.00
0005435270203	5045	Economy	6000.00
0005434245825	8349	Business	18000.00
0005433786173	8349	Business	18000.00
0005433786040	8349	Business	18000.00
0005433786072	8349	Economy	6600.00
0005433785926	8349	Economy	6600.00
0005433786182	8349	Economy	6000.00
0005433786056	8349	Economy	6000.00
0005433786144	8349	Economy	6000.00
0005433786159	8349	Economy	6000.00
0005432659766	8349	Economy	6000.00
0005433785945	8349	Economy	6000.00
0005433786057	8349	Economy	6000.00
0005433786134	8349	Economy	6000.00
0005434245832	8349	Economy	6000.00
0005433785916	8349	Economy	6000.00
0005433786097	8349	Economy	6000.00
0005434245840	8349	Economy	6000.00
0005433786160	8349	Economy	6000.00
0005434245790	8349	Economy	6000.00
0005433785964	8349	Economy	6000.00
0005433786036	8349	Economy	6000.00
0005433786032	8349	Economy	6000.00
0005432659753	8349	Economy	6600.00
0005434245831	8349	Economy	6000.00
0005433786168	8349	Economy	6000.00
0005432659767	8349	Economy	6000.00
0005433785982	8349	Economy	6000.00
0005433785965	8349	Economy	6600.00
0005434245789	8349	Economy	6000.00
0005433786044	8349	Economy	6000.00
0005433785983	8349	Economy	6000.00
0005433786128	8349	Economy	6000.00
0005433786025	8349	Economy	6000.00
0005433786169	8349	Economy	6000.00
0005433786037	8349	Economy	6000.00
0005433786082	8349	Economy	6000.00
0005433785981	8349	Economy	6000.00
0005433786172	8349	Economy	6000.00
0005433786192	8349	Economy	6000.00
0005433786094	8349	Economy	6000.00
0005433786158	8349	Economy	6000.00
0005433786024	8349	Economy	6000.00
0005433786071	8349	Economy	6000.00
0005432659757	8349	Economy	6000.00
0005434245826	8349	Economy	6000.00
0005433786193	8349	Economy	6000.00
0005433786167	8349	Economy	6000.00
0005433786031	8349	Economy	6000.00
0005433785925	8349	Economy	6000.00
0005433786183	8349	Economy	6000.00
0005433616729	8348	Business	18000.00
0005434230138	8348	Business	18000.00
0005433616563	8348	Business	18000.00
0005434230125	8348	Business	18000.00
0005433616623	8348	Business	18000.00
0005434230104	8348	Business	18000.00
0005434230108	8348	Business	18000.00
0005434230200	8348	Business	18000.00
0005433616690	8348	Business	18000.00
0005434230106	8348	Business	18000.00
0005433616638	8348	Business	18000.00
0005434230185	8348	Business	18000.00
0005433616676	8348	Business	18000.00
0005433616750	8348	Business	18000.00
0005433616756	8348	Business	18000.00
0005434230057	8348	Economy	6600.00
0005433616691	8348	Economy	6600.00
0005434230061	8348	Economy	6000.00
0005434230102	8348	Economy	6000.00
0005434230107	8348	Economy	6000.00
0005434230184	8348	Economy	6000.00
0005434230112	8348	Economy	6000.00
0005433616736	8348	Economy	6000.00
0005434230181	8348	Economy	6000.00
0005433616546	8348	Economy	6000.00
0005434230097	8348	Economy	6000.00
0005433616611	8348	Economy	6000.00
0005434230183	8348	Economy	6000.00
0005433616728	8348	Economy	6000.00
0005433616610	8348	Economy	6000.00
0005433616735	8348	Economy	6000.00
0005434230058	8348	Economy	6000.00
0005433616533	8348	Economy	6000.00
0005433616684	8348	Economy	6000.00
0005434230129	8348	Economy	6000.00
0005433616757	8348	Economy	6000.00
0005434230088	8348	Economy	6000.00
0005433616788	8348	Economy	6000.00
0005433616670	8348	Economy	6000.00
0005434230098	8348	Economy	6000.00
0005433616669	8348	Economy	6000.00
0005434230076	8348	Economy	6000.00
0005434230101	8348	Economy	6000.00
0005434230123	8348	Economy	6000.00
0005434230078	8348	Economy	6600.00
0005433616761	8348	Economy	6600.00
0005433616743	8348	Economy	6600.00
0005433616800	8348	Economy	6000.00
0005434230069	8348	Economy	6000.00
0005433616512	8348	Economy	6600.00
0005433616534	8348	Economy	6000.00
0005434230054	8348	Economy	6000.00
0005433616693	8348	Economy	6000.00
0005434230060	8348	Economy	6000.00
0005434230070	8348	Economy	6000.00
0005433616677	8348	Economy	6000.00
0005433616702	8348	Economy	6000.00
0005434230124	8348	Economy	6000.00
0005434230113	8348	Economy	6000.00
0005433616814	8348	Economy	6000.00
0005434230150	8348	Economy	6000.00
0005433616789	8348	Economy	6000.00
0005433616668	8348	Economy	6000.00
0005433616713	8348	Economy	6000.00
0005434230089	8348	Economy	6000.00
0005433616590	8348	Economy	6000.00
0005434230137	8348	Economy	6000.00
0005434230130	8348	Economy	6000.00
0005433616672	8348	Economy	6000.00
0005434230068	8348	Economy	6000.00
0005433616683	8348	Economy	6000.00
0005433616734	8348	Economy	6000.00
0005434230055	8348	Economy	6000.00
0005433616662	8348	Economy	6000.00
0005433616780	8348	Economy	6000.00
0005434230109	8348	Economy	6000.00
0005434230077	8348	Economy	6000.00
0005434150067	8347	Business	18000.00
0005435287058	8347	Business	18000.00
0005434230040	8347	Business	18000.00
0005434150028	8347	Business	18000.00
0005434229989	8347	Business	18000.00
0005434265847	8347	Business	18000.00
0005434265881	8347	Business	18000.00
0005434229981	8347	Economy	6600.00
0005434265825	8347	Economy	6600.00
0005434150034	8347	Economy	6000.00
0005434230042	8347	Economy	6000.00
0005434150027	8347	Economy	6000.00
0005434229982	8347	Economy	6000.00
0005434230009	8347	Economy	6000.00
0005434265848	8347	Economy	6000.00
0005434230041	8347	Economy	6000.00
0005434265844	8347	Economy	6000.00
0005434150033	8347	Economy	6600.00
0005434150026	8347	Economy	6000.00
0005434265826	8347	Economy	6000.00
0005434265896	8347	Economy	6000.00
0005434265897	8347	Economy	6000.00
0005434265839	8347	Economy	6000.00
0005434265865	8347	Economy	6000.00
0005434265843	8347	Economy	6000.00
0005434640057	12631	Economy	16200.00
0005434640067	12631	Economy	16200.00
0005434640082	12631	Economy	16200.00
0005434640081	12631	Economy	14800.00
0005434640066	12631	Economy	14800.00
0005434639928	12631	Economy	14800.00
0005434639979	12631	Economy	14800.00
0005434639978	12631	Economy	14800.00
0005434639927	12631	Economy	14800.00
0005434639991	12631	Economy	14800.00
0005434640076	12631	Economy	14800.00
0005434640058	12631	Economy	14800.00
0005434640075	12631	Economy	14800.00
0005434640063	12631	Economy	14800.00
0005434640077	12631	Economy	14800.00
0005434639990	12631	Economy	14800.00
0005434639980	12631	Economy	14800.00
0005433202742	23393	Economy	16200.00
0005433202787	23393	Economy	14800.00
0005433202788	23393	Economy	14800.00
0005433202734	23393	Economy	14800.00
0005433202736	23393	Economy	14800.00
0005433202716	23393	Economy	14800.00
0005433202783	23393	Economy	14800.00
0005433202780	23393	Economy	14800.00
0005433202741	23393	Economy	14800.00
0005433202735	23393	Economy	14800.00
0005433202785	23393	Economy	14800.00
0005433202779	23393	Economy	14800.00
0005433202749	23393	Economy	14800.00
0005433202784	23393	Economy	14800.00
0005433202761	23393	Economy	14800.00
0005433202755	23393	Economy	14800.00
0005433202781	23393	Economy	14800.00
0005433202795	23393	Economy	14800.00
0005433202786	23393	Economy	14800.00
0005433202759	23393	Economy	14800.00
0005432329870	21094	Business	18900.00
0005432384270	21094	Business	18900.00
0005432329944	21094	Business	18900.00
0005432329907	21094	Business	18900.00
0005432330011	21094	Business	18900.00
0005432384339	21094	Business	18900.00
0005432329900	21094	Business	18900.00
0005432329932	21094	Business	18900.00
0005432330027	21094	Business	18900.00
0005432384310	21094	Economy	6300.00
0005432329844	21094	Economy	6300.00
0005432329945	21094	Economy	6300.00
0005432329916	21094	Economy	6300.00
0005432384156	21094	Economy	6900.00
0005432384276	21094	Economy	6900.00
0005432384142	21094	Economy	6900.00
0005432384244	21094	Economy	6300.00
0005432384203	21094	Economy	6300.00
0005432329885	21094	Economy	6300.00
0005432329930	21094	Economy	6300.00
0005432330052	21094	Economy	6300.00
0005432329894	21094	Economy	6300.00
0005432329999	21094	Economy	6300.00
0005432329891	21094	Economy	6300.00
0005432330049	21094	Economy	6300.00
0005432330021	21094	Economy	6300.00
0005432384138	21094	Economy	6300.00
0005432329917	21094	Economy	6300.00
0005432330026	21094	Economy	6300.00
0005432329993	21094	Economy	6300.00
0005432384272	21094	Economy	6300.00
0005432329893	21094	Economy	6300.00
0005432330048	21094	Economy	6300.00
0005432329770	21094	Economy	6300.00
0005432384216	21094	Economy	6300.00
0005432384119	21094	Economy	6300.00
0005432329810	21094	Economy	6300.00
0005432384217	21094	Economy	6300.00
0005432330036	21094	Economy	6300.00
0005432384155	21094	Economy	6300.00
0005432384137	21094	Economy	6300.00
0005432329978	21094	Economy	6300.00
0005432329771	21094	Economy	6300.00
0005432329995	21094	Economy	6300.00
0005432384255	21094	Economy	6300.00
0005432384267	21094	Economy	6300.00
0005432329931	21094	Economy	6300.00
0005432329979	21094	Economy	6300.00
0005432384245	21094	Economy	6300.00
0005432329860	21094	Economy	6300.00
0005432330028	21094	Economy	6300.00
0005432384277	21094	Economy	6300.00
0005432329845	21094	Economy	6300.00
0005432329908	21094	Economy	6300.00
0005432329892	21094	Economy	6300.00
0005432329994	21094	Economy	6300.00
0005432384312	21094	Economy	6300.00
0005432384273	21094	Economy	6300.00
0005432384218	21094	Economy	6300.00
0005432848886	31231	Economy	6300.00
0005433642710	27602	Business	89600.00
0005433642749	27602	Business	89600.00
0005433642712	27602	Business	89600.00
0005433642718	27602	Business	89600.00
0005433642752	27602	Economy	29900.00
0005433642764	27602	Economy	29900.00
0005433642748	27602	Economy	29900.00
0005433642754	27602	Economy	32800.00
0005433642774	27602	Economy	29900.00
0005433642747	27602	Economy	29900.00
0005433642762	27602	Economy	29900.00
0005433642772	27602	Economy	29900.00
0005433642765	27602	Economy	29900.00
0005433642753	27602	Economy	29900.00
0005433642719	27602	Economy	29900.00
0005433642769	27602	Economy	29900.00
0005433642736	27602	Economy	29900.00
0005433642763	27602	Economy	29900.00
0005433642711	27602	Economy	29900.00
0005433642761	27602	Economy	29900.00
0005432425822	30782	Business	12700.00
0005432425995	30782	Business	12700.00
0005432426057	30782	Business	12700.00
0005432425837	30782	Business	12700.00
0005432425934	30782	Business	12700.00
0005432426041	30782	Business	12700.00
0005432425964	30782	Business	12700.00
0005432425704	30782	Economy	4200.00
0005432426020	30782	Economy	4200.00
0005432425791	30782	Economy	4200.00
0005432425979	30782	Economy	4200.00
0005432425828	30782	Economy	4200.00
0005432425928	30782	Economy	4200.00
0005432425885	30782	Economy	4200.00
0005432425969	30782	Economy	4200.00
0005432425889	30782	Economy	4700.00
0005432425924	30782	Economy	4700.00
0005432426007	30782	Economy	4700.00
0005432425715	30782	Economy	4700.00
0005432425675	30782	Economy	4200.00
0005432425806	30782	Economy	4200.00
0005432425580	30782	Economy	4200.00
0005432425823	30782	Economy	4200.00
0005432425849	30782	Economy	4200.00
0005432425714	30782	Economy	4200.00
0005432425748	30782	Economy	4200.00
0005432425829	30782	Economy	4200.00
0005432425705	30782	Economy	4200.00
0005432425848	30782	Economy	4200.00
0005432425972	30782	Economy	4200.00
0005432425902	30782	Economy	4200.00
0005432425784	30782	Economy	4200.00
0005432425805	30782	Economy	4200.00
0005432426006	30782	Economy	4200.00
0005432425882	30782	Economy	4200.00
0005432426040	30782	Economy	4200.00
0005432426036	30782	Economy	4200.00
0005432425621	30782	Economy	4200.00
0005432425736	30782	Economy	4200.00
0005432425579	30782	Economy	4200.00
0005432425844	30782	Economy	4200.00
0005432425622	30782	Economy	4200.00
0005432425792	30782	Economy	4200.00
0005432426076	30782	Economy	4200.00
0005432425878	30782	Economy	4200.00
0005432425819	30782	Economy	4200.00
0005432425958	30782	Economy	4200.00
0005432426021	30782	Economy	4200.00
0005432425804	30782	Economy	4200.00
0005432425933	30782	Economy	4200.00
0005432425877	30782	Economy	4200.00
0005432425932	30782	Economy	4200.00
0005432425973	30782	Economy	4200.00
0005432425873	30782	Economy	4200.00
0005432425888	30782	Economy	4200.00
0005432425971	30782	Economy	4200.00
0005432425870	30782	Economy	4200.00
0005432425980	30782	Economy	4200.00
0005432425869	30782	Economy	4200.00
0005432425750	30782	Economy	4200.00
0005432426053	30782	Economy	4200.00
0005432425968	30782	Economy	4200.00
0005432425903	30782	Economy	4200.00
0005432425820	30782	Economy	4200.00
0005432425988	30782	Economy	4200.00
0005432425827	30782	Economy	4200.00
0005432425915	30782	Economy	4200.00
0005432426035	30782	Economy	4200.00
0005432425749	30782	Economy	4200.00
0005432425922	30782	Economy	4200.00
0005432425854	30782	Economy	4200.00
0005432425830	30782	Economy	4200.00
0005432425945	30782	Economy	4200.00
0005432902112	9627	Business	32600.00
0005432902097	9627	Economy	10900.00
0005432902092	9627	Economy	10900.00
0005432902099	9627	Economy	10900.00
0005432902077	9627	Economy	10900.00
0005432902105	9627	Economy	10900.00
0005432902100	9627	Economy	10900.00
0005432902076	9627	Economy	10900.00
0005434157692	9627	Economy	10900.00
0005434448418	28963	Business	32600.00
0005432818290	28963	Business	32600.00
0005432818289	28963	Economy	10900.00
0005432818194	28963	Economy	10900.00
0005432818269	28963	Economy	11900.00
0005432818240	28963	Economy	10900.00
0005432818275	28963	Economy	10900.00
0005434448416	28963	Economy	10900.00
0005432822431	28963	Economy	10900.00
0005432818267	28963	Economy	10900.00
0005432822423	28963	Economy	10900.00
0005432818195	28963	Economy	10900.00
0005434448417	28963	Economy	10900.00
0005432818274	28963	Economy	10900.00
0005432822422	28963	Economy	10900.00
0005435841121	15061	Economy	11000.00
0005432607669	31626	Economy	11000.00
0005432611805	31626	Economy	11000.00
0005432611811	31626	Economy	11000.00
0005432611799	31626	Economy	11000.00
0005432607668	31626	Economy	11000.00
0005432611806	31626	Economy	11000.00
0005432607670	31626	Economy	11000.00
0005432611812	31626	Economy	11000.00
0005432949666	11868	Business	105900.00
0005432949529	11868	Business	105900.00
0005432949328	11868	Business	105900.00
0005432949574	11868	Business	105900.00
0005432949658	11868	Business	105900.00
0005432949657	11868	Business	105900.00
0005432949616	11868	Business	105900.00
0005432949530	11868	Business	105900.00
0005432949600	11868	Economy	35300.00
0005432949633	11868	Economy	35300.00
0005432949488	11868	Economy	35300.00
0005432949631	11868	Economy	35300.00
0005432949612	11868	Economy	35300.00
0005432949623	11868	Economy	38800.00
0005432949652	11868	Economy	38800.00
0005432949627	11868	Economy	35300.00
0005432949632	11868	Economy	35300.00
0005432949638	11868	Economy	35300.00
0005432949615	11868	Economy	35300.00
0005432949555	11868	Economy	35300.00
0005432949607	11868	Economy	35300.00
0005432949636	11868	Economy	35300.00
0005432949556	11868	Economy	35300.00
0005432949628	11868	Economy	35300.00
0005432949660	11868	Economy	35300.00
0005432949651	11868	Economy	35300.00
0005432949571	11868	Economy	35300.00
0005432949363	11868	Economy	35300.00
0005432949540	11868	Economy	35300.00
0005432949611	11868	Economy	35300.00
0005432949637	11868	Economy	35300.00
0005432949634	11868	Economy	35300.00
0005432949457	11868	Economy	35300.00
0005432949665	11868	Economy	35300.00
0005432949458	11868	Economy	35300.00
0005432949541	11868	Economy	35300.00
0005432949659	11868	Economy	35300.00
0005432949362	11868	Economy	35300.00
0005432949671	11868	Economy	35300.00
0005432949531	11868	Economy	35300.00
0005432949599	11868	Economy	35300.00
0005432949643	11868	Economy	35300.00
0005433570512	25322	Business	105900.00
0005433570945	25322	Business	105900.00
0005433570821	25322	Economy	35300.00
0005433570511	25322	Economy	35300.00
0005433570856	25322	Economy	35300.00
0005433570812	25322	Economy	35300.00
0005433570847	25322	Economy	35300.00
0005433570822	25322	Economy	38800.00
0005433570962	25322	Economy	38800.00
0005433570619	25322	Economy	35300.00
0005433570739	25322	Economy	35300.00
0005433570758	25322	Economy	35300.00
0005433570880	25322	Economy	35300.00
0005433570875	25322	Economy	35300.00
0005433570842	25322	Economy	35300.00
0005433570936	25322	Economy	35300.00
0005433570694	25322	Economy	35300.00
0005433570746	25322	Economy	35300.00
0005433570661	25322	Economy	35300.00
0005433570808	25322	Economy	35300.00
0005433570807	25322	Economy	35300.00
0005433570955	25322	Economy	35300.00
0005433570877	25322	Economy	35300.00
0005433570943	25322	Economy	35300.00
0005433570944	25322	Economy	35300.00
0005433570740	25322	Economy	35300.00
0005433570841	25322	Economy	35300.00
0005433570898	25322	Economy	35300.00
0005433570759	25322	Economy	35300.00
0005433570891	25322	Economy	35300.00
0005433570833	25322	Economy	35300.00
0005433570860	25322	Economy	35300.00
0005433570806	25322	Economy	35300.00
0005435555424	5402	Business	67200.00
0005435340700	5402	Business	67200.00
0005435340705	5402	Business	67200.00
0005435340644	5402	Economy	22400.00
0005435340699	5402	Economy	22400.00
0005435340630	5402	Economy	22400.00
0005435340704	5402	Economy	22400.00
0005435340681	5402	Economy	22400.00
0005435340645	5402	Economy	22400.00
0005435340698	5402	Economy	22400.00
0005434656615	12516	Business	67200.00
0005434655510	12516	Economy	22400.00
0005434655482	12516	Economy	22400.00
0005434655515	12516	Economy	24600.00
0005434656613	12516	Economy	22400.00
0005434656614	12516	Economy	22400.00
0005434655516	12516	Economy	22400.00
0005434655530	12516	Economy	22400.00
0005434655420	12516	Economy	22400.00
0005434655483	12516	Economy	22400.00
0005434655506	12516	Economy	22400.00
0005434655509	12516	Economy	22400.00
0005434655435	12516	Economy	22400.00
0005434655449	12516	Economy	22400.00
0005435266336	7453	Business	32000.00
0005435266326	7453	Business	32000.00
0005435266345	7453	Economy	10700.00
0005432429025	7453	Economy	10700.00
0005432429027	7453	Economy	10700.00
0005435266341	7453	Economy	10700.00
0005435266342	7453	Economy	10700.00
0005435266344	7453	Economy	10700.00
0005432429026	7453	Economy	10700.00
0005435266327	7453	Economy	10700.00
0005433717033	29205	Business	32000.00
0005433722496	29205	Business	32000.00
0005433722498	29205	Business	32000.00
0005433719232	29205	Business	32000.00
0005433717334	29205	Business	32000.00
0005433722425	29205	Economy	10700.00
0005433722410	29205	Economy	10700.00
0005433717048	29205	Economy	10700.00
0005433722472	29205	Economy	10700.00
0005433722450	29205	Economy	10700.00
0005433656755	29205	Economy	10700.00
0005433722469	29205	Economy	10700.00
0005433717346	29205	Economy	10700.00
0005433685574	29205	Economy	10700.00
0005433717080	29205	Economy	10700.00
0005433685588	29205	Economy	10700.00
0005433722442	29205	Economy	10700.00
0005433717079	29205	Economy	10700.00
0005433717049	29205	Economy	11700.00
0005433717351	29205	Economy	10700.00
0005433685589	29205	Economy	10700.00
0005433656765	29205	Economy	10700.00
0005433717012	29205	Economy	10700.00
0005433717032	29205	Economy	10700.00
0005433722449	29205	Economy	10700.00
0005433717279	29205	Economy	10700.00
0005433722379	29205	Economy	10700.00
0005433717358	29205	Economy	10700.00
0005433722364	29205	Economy	10700.00
0005433717278	29205	Economy	10700.00
0005433722467	29205	Economy	10700.00
0005433722441	29205	Economy	10700.00
0005433722378	29205	Economy	10700.00
0005433717352	29205	Economy	10700.00
0005433717388	29205	Economy	10700.00
0005433656764	29205	Economy	10700.00
0005433717357	29205	Economy	10700.00
0005433722430	29205	Economy	10700.00
0005433717356	29205	Economy	10700.00
0005433722497	29205	Economy	10700.00
0005433717386	29205	Economy	10700.00
0005433717333	29205	Economy	10700.00
0005433717387	29205	Economy	10700.00
0005433719230	29205	Economy	10700.00
0005433722411	29205	Economy	10700.00
0005433717157	29205	Economy	10700.00
0005433722468	29205	Economy	10700.00
0005433722363	29205	Economy	10700.00
0005434182496	8670	Business	36500.00
0005435860717	8670	Business	36500.00
0005435860710	8670	Business	36500.00
0005434182547	8670	Economy	12200.00
0005435860695	8670	Economy	13400.00
0005435860685	8670	Economy	13400.00
0005434182550	8670	Economy	12200.00
0005434182549	8670	Economy	12200.00
0005435860716	8670	Economy	12200.00
0005435860725	8670	Economy	12200.00
0005435860723	8670	Economy	12200.00
0005434182534	8670	Economy	12200.00
0005434184724	8670	Economy	12200.00
0005434182546	8670	Economy	12200.00
0005435860724	8670	Economy	12200.00
0005434143846	11653	Business	36500.00
0005434143822	11653	Business	36500.00
0005434143820	11653	Economy	13400.00
0005434143757	11653	Economy	12200.00
0005434326298	11653	Economy	12200.00
0005434095704	11653	Economy	12200.00
0005434326297	11653	Economy	12200.00
0005434326086	11653	Economy	12200.00
0005434143852	11653	Economy	12200.00
0005434143756	11653	Economy	12200.00
0005434095689	11653	Economy	12200.00
0005434095690	11653	Economy	12200.00
0005434143842	11653	Economy	12200.00
0005434095693	11653	Economy	12200.00
0005434143859	11653	Economy	12200.00
0005433399281	1448	Business	33000.00
0005433399415	1448	Business	33000.00
0005433399291	1448	Economy	11000.00
0005433399406	1448	Economy	11000.00
0005433399455	1448	Economy	11000.00
0005433399372	1448	Economy	12100.00
0005433399448	1448	Economy	12100.00
0005433399295	1448	Economy	11000.00
0005433399410	1448	Economy	11000.00
0005433399394	1448	Economy	11000.00
0005433399358	1448	Economy	11000.00
0005433399282	1448	Economy	11000.00
0005433399385	1448	Economy	11000.00
0005433399461	1448	Economy	11000.00
0005433399454	1448	Economy	11000.00
0005433399371	1448	Economy	11000.00
0005433399354	1448	Economy	11000.00
0005433399283	1448	Economy	11000.00
0005433399409	1448	Economy	11000.00
0005433399384	1448	Economy	11000.00
0005435732706	19253	Business	33000.00
0005435732703	19253	Economy	11000.00
0005435732727	19253	Economy	11000.00
0005435732693	19253	Economy	11000.00
0005433457088	19253	Economy	11000.00
0005434444176	17364	Economy	14100.00
0005434444159	17364	Economy	14100.00
0005434444175	17364	Economy	14100.00
0005434954711	28326	Economy	5800.00
0005435893832	4501	Economy	14000.00
0005435893831	4501	Economy	14000.00
0005435893833	4501	Economy	14000.00
0005434352024	29632	Economy	14000.00
0005434352049	29632	Economy	14000.00
0005434352055	29632	Economy	14000.00
0005434352056	29632	Economy	14000.00
0005434352025	29632	Economy	14000.00
0005434326062	29632	Economy	14000.00
0005434352050	29632	Economy	14000.00
0005434352048	29632	Economy	14000.00
0005434352026	29632	Economy	14000.00
0005434326099	29632	Economy	14000.00
0005434326108	29632	Economy	14000.00
0005434326109	29632	Economy	14000.00
0005434352014	29632	Economy	14000.00
0005433345983	1092	Business	30600.00
0005433269872	1092	Business	30600.00
0005433269875	1092	Business	30600.00
0005433345987	1092	Business	30600.00
0005433345935	1092	Business	30600.00
0005433269871	1092	Business	30600.00
0005433269876	1092	Business	30600.00
0005433345947	1092	Business	30600.00
0005433345883	1092	Economy	10200.00
0005433345759	1092	Economy	10200.00
0005433345827	1092	Economy	10200.00
0005433345972	1092	Economy	10200.00
0005433345657	1092	Economy	10200.00
0005433345902	1092	Economy	10200.00
0005433345942	1092	Economy	10200.00
0005433345962	1092	Economy	10200.00
0005433345936	1092	Economy	10200.00
0005433346007	1092	Economy	10200.00
0005433345982	1092	Economy	10200.00
0005433346044	1092	Economy	10200.00
0005433345590	1092	Economy	10200.00
0005433345943	1092	Economy	10200.00
0005433345803	1092	Economy	10200.00
0005433345912	1092	Economy	10200.00
0005433346030	1092	Economy	10200.00
0005433345655	1092	Economy	10200.00
0005433345860	1092	Economy	10200.00
0005433269873	1092	Economy	10200.00
0005433345905	1092	Economy	10200.00
0005433345366	1092	Economy	10200.00
0005433345915	1092	Economy	10200.00
0005433345641	1092	Economy	10200.00
0005433345917	1092	Economy	11200.00
0005433345636	1092	Economy	10200.00
0005433345963	1092	Economy	10200.00
0005433345766	1092	Economy	10200.00
0005433345911	1092	Economy	10200.00
0005433345334	1092	Economy	10200.00
0005433345727	1092	Economy	10200.00
0005433345775	1092	Economy	10200.00
0005433345916	1092	Economy	10200.00
0005433346031	1092	Economy	10200.00
0005433345861	1092	Economy	10200.00
0005433345884	1092	Economy	10200.00
0005433345760	1092	Economy	10200.00
0005433345726	1092	Economy	10200.00
0005433345971	1092	Economy	10200.00
0005433345637	1092	Economy	10200.00
0005433345894	1092	Economy	10200.00
0005433345903	1092	Economy	10200.00
0005433345640	1092	Economy	10200.00
0005433345951	1092	Economy	10200.00
0005433345859	1092	Economy	10200.00
0005435508748	17046	Business	30600.00
0005435508749	17046	Business	30600.00
0005435530089	17046	Economy	11200.00
0005435530123	17046	Economy	10200.00
0005435508764	17046	Economy	10200.00
0005435508809	17046	Economy	10200.00
0005435530167	17046	Economy	10200.00
0005435546000	17046	Economy	10200.00
0005435508815	17046	Economy	10200.00
0005435508763	17046	Economy	10200.00
0005435530168	17046	Economy	10200.00
0005435530148	17046	Economy	10200.00
0005435530121	17046	Economy	10200.00
0005435508786	17046	Economy	10200.00
0005435508780	17046	Economy	10200.00
0005435508790	17046	Economy	10200.00
0005434445318	17046	Economy	10200.00
0005435508810	17046	Economy	10200.00
0005434445325	17046	Economy	10200.00
0005435508806	17046	Economy	10200.00
0005435508661	17046	Economy	10200.00
0005435530162	17046	Economy	10200.00
0005435530088	17046	Economy	10200.00
0005435530169	17046	Economy	11200.00
0005435530122	17046	Economy	10200.00
0005435530166	17046	Economy	10200.00
0005435530174	17046	Economy	10200.00
0005434445317	17046	Economy	10200.00
0005434445323	17046	Economy	10200.00
0005435508729	17046	Economy	10200.00
0005435530175	17046	Economy	10200.00
0005435508803	17046	Economy	10200.00
0005435530151	17046	Economy	10200.00
0005435092356	17046	Economy	10200.00
0005435530173	17046	Economy	10200.00
0005435530189	17046	Economy	10200.00
0005434445324	17046	Economy	10200.00
0005435530140	17046	Economy	10200.00
0005435508805	17046	Economy	10200.00
0005432852017	1348	Business	101000.00
0005432852096	1348	Business	101000.00
0005432852097	1348	Business	101000.00
0005432852064	1348	Business	101000.00
0005432852076	1348	Economy	33700.00
0005432852086	1348	Economy	33700.00
0005432852077	1348	Economy	33700.00
0005432852067	1348	Economy	37000.00
0005432852098	1348	Economy	37000.00
0005432852081	1348	Economy	37000.00
0005432852071	1348	Economy	33700.00
0005432852075	1348	Economy	33700.00
0005432852062	1348	Economy	33700.00
0005432852087	1348	Economy	33700.00
0005432852084	1348	Economy	33700.00
0005432852063	1348	Economy	33700.00
0005432852083	1348	Economy	33700.00
0005432852078	1348	Economy	33700.00
0005432852085	1348	Economy	33700.00
0005432852080	1348	Economy	33700.00
0005432852082	1348	Economy	33700.00
0005434082588	12804	Business	40300.00
0005434069595	12804	Business	40300.00
0005434069215	12804	Business	40300.00
0005434069425	12804	Business	40300.00
0005434069480	12804	Business	40300.00
0005434069605	12804	Business	40300.00
0005434069579	12804	Business	40300.00
0005433989904	12804	Business	40300.00
0005434069491	12804	Business	40300.00
0005434069631	12804	Business	40300.00
0005434082620	12804	Economy	13400.00
0005434069623	12804	Economy	13400.00
0005434069584	12804	Economy	13400.00
0005434069546	12804	Economy	13400.00
0005434069404	12804	Economy	13400.00
0005434069568	12804	Economy	13400.00
0005434069642	12804	Economy	13400.00
0005434069345	12804	Economy	13400.00
0005434082644	12804	Economy	13400.00
0005434069596	12804	Economy	13400.00
0005434069381	12804	Economy	13400.00
0005434069298	12804	Economy	13400.00
0005434082643	12804	Economy	13400.00
0005434069490	12804	Economy	13400.00
0005434069585	12804	Economy	13400.00
0005434082600	12804	Economy	13400.00
0005434082478	12804	Economy	13400.00
0005434069436	12804	Economy	13400.00
0005434069426	12804	Economy	13400.00
0005434069429	12804	Economy	13400.00
0005434069539	12804	Economy	13400.00
0005434069560	12804	Economy	13400.00
0005434069233	12804	Economy	13400.00
0005434082582	12804	Economy	13400.00
0005434082601	12804	Economy	13400.00
0005434069214	12804	Economy	13400.00
0005434082538	12804	Economy	13400.00
0005434069201	12804	Economy	14800.00
0005434069447	12804	Economy	14800.00
0005434069572	12804	Economy	14800.00
0005434069521	12804	Economy	13400.00
0005434069232	12804	Economy	13400.00
0005434069448	12804	Economy	13400.00
0005434069203	12804	Economy	13400.00
0005434069588	12804	Economy	13400.00
0005434069540	12804	Economy	13400.00
0005434069516	12804	Economy	13400.00
0005434069418	12804	Economy	13400.00
0005434069202	12804	Economy	13400.00
0005434069550	12804	Economy	13400.00
0005434069329	12804	Economy	13400.00
0005434069606	12804	Economy	13400.00
0005434069488	12804	Economy	13400.00
0005434082477	12804	Economy	13400.00
0005434069531	12804	Economy	13400.00
0005434069548	12804	Economy	13400.00
0005434069602	12804	Economy	13400.00
0005434082587	12804	Economy	13400.00
0005434082609	12804	Economy	13400.00
0005434069297	12804	Economy	13400.00
0005434069567	12804	Economy	13400.00
0005434069446	12804	Economy	13400.00
0005434069428	12804	Economy	13400.00
0005434026744	12804	Economy	13400.00
0005434069517	12804	Economy	13400.00
0005434069270	12804	Economy	13400.00
0005434069603	12804	Economy	13400.00
0005434069530	12804	Economy	13400.00
0005434082626	12804	Economy	13400.00
0005434069458	12804	Economy	13400.00
0005434069522	12804	Economy	13400.00
0005434069581	12804	Economy	13400.00
0005434069408	12804	Economy	13400.00
0005434069561	12804	Economy	13400.00
0005434069600	12804	Economy	13400.00
0005434069205	12804	Economy	13400.00
0005434069608	12804	Economy	13400.00
0005434069547	12804	Economy	13400.00
0005434069549	12804	Economy	13400.00
0005434082491	12804	Economy	13400.00
0005434069487	12804	Economy	13400.00
0005434082615	12804	Economy	13400.00
0005434069353	12804	Economy	13400.00
0005434069506	12804	Economy	13400.00
0005434082616	12804	Economy	13400.00
0005434069538	12804	Economy	13400.00
0005434069607	12804	Economy	13400.00
0005434082594	12804	Economy	13400.00
0005435283535	30643	Business	40300.00
0005435283538	30643	Economy	13400.00
0005435283505	30643	Economy	13400.00
0005435283539	30643	Economy	13400.00
0005435283487	30643	Economy	13400.00
0005432433830	30643	Economy	13400.00
0005435283526	30643	Economy	13400.00
0005435283468	30643	Economy	13400.00
0005435283517	30643	Economy	13400.00
0005432433831	30643	Economy	13400.00
0005435283495	30643	Economy	13400.00
0005435283527	30643	Economy	13400.00
0005435283506	30643	Economy	13400.00
0005435283516	30643	Economy	13400.00
0005435283474	30643	Economy	13400.00
0005434265884	5487	Business	35300.00
0005432535973	5487	Business	35300.00
0005435463392	5487	Business	35300.00
0005434265870	5487	Business	35300.00
0005434265893	5487	Business	35300.00
0005434265869	5487	Economy	12900.00
0005434265871	5487	Economy	11800.00
0005435463477	5487	Economy	11800.00
0005435463503	5487	Economy	11800.00
0005434265860	5487	Economy	11800.00
0005435043309	5487	Economy	11800.00
0005434265858	5487	Economy	11800.00
0005435463483	5487	Economy	11800.00
0005435617210	5487	Economy	11800.00
0005434265814	5487	Economy	11800.00
0005435463462	5487	Economy	11800.00
0005435463487	5487	Economy	11800.00
0005435617211	5487	Economy	11800.00
0005434831286	5487	Economy	11800.00
0005435463478	5487	Economy	11800.00
0005434265853	5487	Economy	11800.00
0005434265851	5487	Economy	11800.00
0005434831264	5487	Economy	11800.00
0005435463391	5487	Economy	11800.00
0005435463498	5487	Economy	11800.00
0005434265872	5487	Economy	11800.00
0005434831277	5487	Economy	11800.00
0005435463485	5487	Economy	11800.00
0005435463479	5487	Economy	11800.00
0005435463467	5487	Economy	11800.00
0005434265835	5487	Economy	11800.00
0005435463458	5487	Economy	11800.00
0005435463422	5487	Economy	11800.00
0005435463466	5487	Economy	11800.00
0005435463463	5487	Economy	11800.00
0005435463527	5487	Economy	11800.00
0005434265868	5487	Economy	11800.00
0005434265852	5487	Economy	11800.00
0005435617193	5487	Economy	11800.00
0005435043310	5487	Economy	11800.00
0005435463486	5487	Economy	11800.00
0005434265721	5487	Economy	11800.00
0005434265859	5487	Economy	11800.00
0005434831285	5487	Economy	11800.00
0005435767944	13467	Business	35300.00
0005435735279	13467	Business	35300.00
0005435768066	13467	Business	35300.00
0005435725739	13467	Business	35300.00
0005435720162	13467	Economy	12900.00
0005435767738	13467	Economy	12900.00
0005435767752	13467	Economy	11800.00
0005435768052	13467	Economy	11800.00
0005435767975	13467	Economy	11800.00
0005435767912	13467	Economy	11800.00
0005435767935	13467	Economy	11800.00
0005435768068	13467	Economy	11800.00
0005435767753	13467	Economy	11800.00
0005435768010	13467	Economy	11800.00
0005435768077	13467	Economy	11800.00
0005435768014	13467	Economy	11800.00
0005435767721	13467	Economy	11800.00
0005435768043	13467	Economy	11800.00
0005435767945	13467	Economy	11800.00
0005435767751	13467	Economy	11800.00
0005435768009	13467	Economy	11800.00
0005435768015	13467	Economy	11800.00
0005435768091	13467	Economy	11800.00
0005435768007	13467	Economy	11800.00
0005435720166	13467	Economy	12900.00
0005435768011	13467	Economy	11800.00
0005435767537	13467	Economy	11800.00
0005435767722	13467	Economy	11800.00
0005435768013	13467	Economy	11800.00
0005435768067	13467	Economy	11800.00
0005435767969	13467	Economy	11800.00
0005435768044	13467	Economy	11800.00
0005435767913	13467	Economy	11800.00
0005435768050	13467	Economy	11800.00
0005435767914	13467	Economy	11800.00
0005435767536	13467	Economy	11800.00
0005435767793	13467	Economy	11800.00
0005435767976	13467	Economy	11800.00
0005435767834	13467	Economy	11800.00
0005434602976	18640	Economy	3300.00
0005434602975	18640	Economy	3300.00
0005434602968	18640	Economy	3300.00
0005434605000	18639	Economy	3300.00
0005435844432	4109	Business	88300.00
0005435846350	4109	Business	88300.00
0005435844426	4109	Business	88300.00
0005435844428	4109	Economy	29400.00
0005435844425	4109	Economy	29400.00
0005435844431	4109	Economy	32400.00
0005435844436	4109	Economy	32400.00
0005435846348	4109	Economy	29400.00
0005435844430	4109	Economy	29400.00
0005435846357	4109	Economy	29400.00
0005435846358	4109	Economy	29400.00
0005435844435	4109	Economy	29400.00
0005435846352	4109	Economy	29400.00
0005435844427	4109	Economy	29400.00
0005435844422	4109	Economy	29400.00
0005435844420	4109	Economy	29400.00
0005435844393	4109	Economy	29400.00
0005435844429	4109	Economy	29400.00
0005435844423	4109	Economy	29400.00
0005435844442	4109	Economy	29400.00
0005433286216	1802	Business	48700.00
0005433009898	1802	Business	48700.00
0005433009845	1802	Business	48700.00
0005433009956	1802	Business	48700.00
0005433009969	1802	Business	48700.00
0005433009897	1802	Business	48700.00
0005433009884	1802	Business	48700.00
0005433009970	1802	Economy	16200.00
0005433009912	1802	Economy	16200.00
0005433286146	1802	Economy	16200.00
0005433009857	1802	Economy	16200.00
0005433286174	1802	Economy	17900.00
0005433009913	1802	Economy	16200.00
0005433286193	1802	Economy	16200.00
0005433286192	1802	Economy	16200.00
0005433009680	1802	Economy	16200.00
0005433009730	1802	Economy	16200.00
0005433009731	1802	Economy	16200.00
0005433286173	1802	Economy	16200.00
0005433009957	1802	Economy	16200.00
0005433009846	1802	Economy	16200.00
0005433009681	1802	Economy	16200.00
0005433286189	1802	Economy	16200.00
0005433286202	1802	Economy	16200.00
0005433286188	1802	Economy	16200.00
0005433009678	1802	Economy	16200.00
0005433286161	1802	Economy	16200.00
0005433009896	1802	Economy	16200.00
0005433009899	1802	Economy	16200.00
0005433286162	1802	Economy	16200.00
0005433286191	1802	Economy	16200.00
0005433286215	1802	Economy	16200.00
0005433286175	1802	Economy	16200.00
0005433286190	1802	Economy	16200.00
0005433009876	1802	Economy	16200.00
0005433009847	1802	Economy	16200.00
0005433810758	22603	Business	48700.00
0005433810736	22603	Economy	16200.00
0005433810686	22603	Economy	16200.00
0005435725747	22603	Economy	17900.00
0005433810728	22603	Economy	16200.00
0005435725748	22603	Economy	16200.00
0005433810734	22603	Economy	16200.00
0005433810747	22603	Economy	16200.00
0005433810724	22603	Economy	16200.00
0005435725749	22603	Economy	16200.00
0005435725753	22603	Economy	16200.00
0005433810755	22603	Economy	16200.00
0005433810733	22603	Economy	16200.00
0005433810729	22603	Economy	16200.00
0005433810778	22603	Economy	16200.00
0005435725752	22603	Economy	16200.00
0005435725751	22603	Economy	16200.00
0005433810748	22603	Economy	16200.00
0005435725750	22603	Economy	16200.00
0005432755147	12280	Business	83800.00
0005432755158	12280	Economy	27900.00
0005432751613	12280	Economy	27900.00
0005432755159	12280	Economy	30700.00
0005432755157	12280	Economy	30700.00
0005432755164	12280	Economy	30700.00
0005432755154	12280	Economy	27900.00
0005432755161	12280	Economy	27900.00
0005432755166	12280	Economy	27900.00
0005432755165	12280	Economy	27900.00
0005432755167	12280	Economy	27900.00
0005432755145	12280	Economy	27900.00
0005432751611	12280	Economy	27900.00
0005432751618	12280	Economy	27900.00
0005432755146	12280	Economy	27900.00
0005432751612	12280	Economy	27900.00
0005432755163	12280	Economy	27900.00
0005432751616	12280	Economy	27900.00
0005435283193	5561	Business	99800.00
0005435283167	5561	Business	99800.00
0005435283209	5561	Business	99800.00
0005435283212	5561	Business	99800.00
0005435283191	5561	Economy	33300.00
0005435283163	5561	Economy	33300.00
0005434173628	5561	Economy	33300.00
0005435283230	5561	Economy	33300.00
0005435283231	5561	Economy	33300.00
0005433848377	13833	Business	99800.00
0005433848349	13833	Business	99800.00
0005433848269	13833	Business	99800.00
0005433848378	13833	Business	99800.00
0005433848350	13833	Economy	33300.00
0005433848370	13833	Economy	36600.00
0005433848369	13833	Economy	33300.00
0005433815574	13833	Economy	33300.00
0005433848389	13833	Economy	33300.00
0005433848278	13833	Economy	33300.00
0005433848268	13833	Economy	33300.00
0005433848357	13833	Economy	33300.00
0005433848320	13833	Economy	33300.00
0005433848361	13833	Economy	33300.00
0005433815514	13833	Economy	33300.00
0005433848321	13833	Economy	33300.00
0005435332607	7853	Economy	15100.00
0005435332626	7853	Economy	15100.00
0005435332644	7853	Economy	15100.00
0005435332627	7853	Economy	15100.00
0005435332645	7853	Economy	15100.00
0005434621176	32958	Economy	16600.00
0005434621178	32958	Economy	15100.00
0005434621180	32958	Economy	15100.00
0005434621166	32958	Economy	15100.00
0005434621103	32958	Economy	15100.00
0005434621177	32958	Economy	15100.00
0005434621163	32958	Economy	15100.00
0005434621125	32958	Economy	15100.00
0005434621124	32958	Economy	15100.00
0005434621105	32958	Economy	15100.00
0005434621175	32958	Economy	15100.00
0005434621104	32958	Economy	15100.00
0005435937554	4314	Business	38000.00
0005435937555	4314	Economy	12700.00
0005435937566	4314	Economy	12700.00
0005435937533	4314	Economy	12700.00
0005435937561	4314	Economy	12700.00
0005435937532	4314	Economy	12700.00
0005435786183	27321	Business	38000.00
0005435786315	27321	Business	38000.00
0005435786235	27321	Business	38000.00
0005435786161	27321	Business	38000.00
0005435786160	27321	Economy	12700.00
0005435786035	27321	Economy	12700.00
0005435786214	27321	Economy	12700.00
0005435786339	27321	Economy	12700.00
0005435786344	27321	Economy	12700.00
0005435786294	27321	Economy	12700.00
0005435786034	27321	Economy	12700.00
0005435786262	27321	Economy	12700.00
0005435786213	27321	Economy	12700.00
0005435786207	27321	Economy	12700.00
0005435786304	27321	Economy	12700.00
0005435786223	27321	Economy	12700.00
0005435786303	27321	Economy	12700.00
0005435786234	27321	Economy	12700.00
0005435786278	27321	Economy	12700.00
0005435786292	27321	Economy	12700.00
0005435786251	27321	Economy	12700.00
0005435786224	27321	Economy	12700.00
0005435786252	27321	Economy	12700.00
0005435786293	27321	Economy	12700.00
0005435786316	27321	Economy	12700.00
0005435786225	27321	Economy	12700.00
0005435786317	27321	Economy	12700.00
0005434994304	27321	Economy	12700.00
0005435860640	4744	Business	40900.00
0005434150219	4744	Business	40900.00
0005434150147	4744	Business	40900.00
0005435840484	4744	Business	40900.00
0005435840526	4744	Business	40900.00
0005435840483	4744	Economy	15000.00
0005435840505	4744	Economy	15000.00
0005434150171	4744	Economy	13600.00
0005435840489	4744	Economy	13600.00
0005435840472	4744	Economy	13600.00
0005435840431	4744	Economy	13600.00
0005435840507	4744	Economy	13600.00
0005434150148	4744	Economy	13600.00
0005434150159	4744	Economy	13600.00
0005435840480	4744	Economy	13600.00
0005435840525	4744	Economy	13600.00
0005434150218	4744	Economy	13600.00
0005435840516	4744	Economy	13600.00
0005434150204	4744	Economy	13600.00
0005435840506	4744	Economy	13600.00
0005434150184	4744	Economy	13600.00
0005435840519	4744	Economy	13600.00
0005434150149	4744	Economy	13600.00
0005434150205	4744	Economy	13600.00
0005434150183	4744	Economy	13600.00
0005435840430	4744	Economy	13600.00
0005435840530	4744	Economy	13600.00
0005435860642	4744	Economy	13600.00
0005435840473	4744	Economy	13600.00
0005432461357	30522	Business	40900.00
0005434559181	30522	Business	40900.00
0005433454932	30522	Business	40900.00
0005434559161	30522	Business	40900.00
0005432569390	30522	Business	40900.00
0005432461427	30522	Business	40900.00
0005432461296	30522	Business	40900.00
0005432461345	30522	Business	40900.00
0005432461344	30522	Business	40900.00
0005432461407	30522	Business	40900.00
0005434559163	30522	Business	40900.00
0005434559127	30522	Business	40900.00
0005434559160	30522	Business	40900.00
0005432461420	30522	Economy	13600.00
0005432569359	30522	Economy	13600.00
0005432569363	30522	Economy	13600.00
0005434082620	30522	Economy	13600.00
0005432461380	30522	Economy	13600.00
0005434082616	30522	Economy	13600.00
0005434082644	30522	Economy	13600.00
0005434559140	30522	Economy	13600.00
0005432569418	30522	Economy	13600.00
0005434559147	30522	Economy	13600.00
0005434559154	30522	Economy	13600.00
0005434082538	30522	Economy	13600.00
0005432461395	30522	Economy	13600.00
0005432461306	30522	Economy	13600.00
0005434559164	30522	Economy	13600.00
0005434082587	30522	Economy	13600.00
0005434559126	30522	Economy	13600.00
0005432569394	30522	Economy	13600.00
0005432461358	30522	Economy	13600.00
0005432569243	30522	Economy	13600.00
0005434082477	30522	Economy	13600.00
0005434082600	30522	Economy	13600.00
0005434559176	30522	Economy	13600.00
0005432461425	30522	Economy	13600.00
0005434559156	30522	Economy	13600.00
0005432461298	30522	Economy	13600.00
0005434559130	30522	Economy	13600.00
0005432461307	30522	Economy	13600.00
0005432461374	30522	Economy	13600.00
0005434559129	30522	Economy	13600.00
0005432461309	30522	Economy	13600.00
0005434559144	30522	Economy	13600.00
0005432461210	30522	Economy	13600.00
0005434082478	30522	Economy	13600.00
0005432461426	30522	Economy	13600.00
0005434082491	30522	Economy	13600.00
0005432569382	30522	Economy	15000.00
0005432569391	30522	Economy	13600.00
0005432569360	30522	Economy	13600.00
0005434082588	30522	Economy	13600.00
0005433454928	30522	Economy	15000.00
0005432461384	30522	Economy	15000.00
0005434559155	30522	Economy	13600.00
0005432461423	30522	Economy	13600.00
0005432461308	30522	Economy	13600.00
0005434082609	30522	Economy	13600.00
0005432569396	30522	Economy	13600.00
0005434559128	30522	Economy	13600.00
0005434559122	30522	Economy	13600.00
0005434559123	30522	Economy	13600.00
0005434082582	30522	Economy	13600.00
0005434082643	30522	Economy	13600.00
0005433454927	30522	Economy	13600.00
0005432461129	30522	Economy	13600.00
0005432569358	30522	Economy	13600.00
0005432569319	30522	Economy	13600.00
0005434559162	30522	Economy	13600.00
0005434559158	30522	Economy	13600.00
0005432569357	30522	Economy	13600.00
0005433454933	30522	Economy	13600.00
0005432569305	30522	Economy	13600.00
0005434559137	30522	Economy	13600.00
0005432569395	30522	Economy	13600.00
0005432569242	30522	Economy	13600.00
0005432461199	30522	Economy	13600.00
0005434559157	30522	Economy	13600.00
0005432461340	30522	Economy	13600.00
0005434082601	30522	Economy	13600.00
0005434082594	30522	Economy	13600.00
0005432461424	30522	Economy	13600.00
0005434082626	30522	Economy	13600.00
0005432461128	30522	Economy	13600.00
0005434559136	30522	Economy	13600.00
0005432569413	30522	Economy	13600.00
0005434559170	30522	Economy	13600.00
0005434082615	30522	Economy	13600.00
0005432569414	30522	Economy	13600.00
0005432569341	30522	Economy	13600.00
0005435722122	21185	Economy	9900.00
0005435722121	21185	Economy	9900.00
0005435725772	13699	Economy	8800.00
0005435725760	13699	Economy	8800.00
0005435725759	13699	Economy	8800.00
0005435725774	13699	Economy	8800.00
0005435725765	13699	Economy	8800.00
0005435725769	13699	Economy	8800.00
0005435725764	13699	Economy	8800.00
0005435725775	13699	Economy	8800.00
0005435508819	11107	Business	23600.00
0005435508818	11107	Business	23600.00
0005435545994	11107	Business	23600.00
0005435545993	11107	Business	23600.00
0005435508808	11107	Economy	7900.00
0005435508769	11107	Economy	7900.00
0005435508750	11107	Economy	7900.00
0005435508799	11107	Economy	7900.00
0005435508792	11107	Economy	7900.00
0005435508791	11107	Economy	7900.00
0005435380438	11107	Economy	7900.00
0005435530178	11107	Economy	7900.00
0005435380417	11107	Economy	7900.00
0005435530160	11107	Economy	7900.00
0005435530165	11107	Economy	7900.00
0005435508762	11107	Economy	8600.00
0005435508785	11107	Economy	7900.00
0005435530161	11107	Economy	7900.00
0005435530092	11107	Economy	7900.00
0005435545999	11107	Economy	7900.00
0005435508774	11107	Economy	7900.00
0005435530158	11107	Economy	7900.00
0005435508814	11107	Economy	7900.00
0005435508798	11107	Economy	7900.00
0005435508825	11107	Economy	7900.00
0005435508773	11107	Economy	7900.00
0005435380429	11107	Economy	7900.00
0005435508800	11107	Economy	7900.00
0005435380439	11107	Economy	7900.00
0005435380437	11107	Economy	7900.00
0005435508776	11107	Economy	7900.00
0005435545995	11107	Economy	7900.00
0005435508775	11107	Economy	7900.00
0005435545998	11107	Economy	7900.00
0005435508811	11107	Economy	7900.00
0005433345947	17121	Business	23600.00
0005433345982	17121	Business	23600.00
0005433345963	17121	Business	23600.00
0005433346030	17121	Business	23600.00
0005433345883	17121	Business	23600.00
0005433345972	17121	Economy	7900.00
0005433345636	17121	Economy	7900.00
0005433346044	17121	Economy	7900.00
0005433345775	17121	Economy	7900.00
0005433345334	17121	Economy	7900.00
0005433345971	17121	Economy	7900.00
0005433345366	17121	Economy	7900.00
0005433345894	17121	Economy	7900.00
0005433345760	17121	Economy	7900.00
0005433345962	17121	Economy	7900.00
0005433346007	17121	Economy	7900.00
0005433345912	17121	Economy	7900.00
0005435097481	17121	Economy	7900.00
0005433345859	17121	Economy	7900.00
0005433345727	17121	Economy	7900.00
0005433345861	17121	Economy	8600.00
0005433345641	17121	Economy	8600.00
0005433345903	17121	Economy	8600.00
0005433345987	17121	Economy	7900.00
0005435097475	17121	Economy	7900.00
0005433345911	17121	Economy	7900.00
0005433345759	17121	Economy	7900.00
0005433346031	17121	Economy	7900.00
0005433345637	17121	Economy	7900.00
0005433345905	17121	Economy	7900.00
0005433345915	17121	Economy	7900.00
0005433345902	17121	Economy	7900.00
0005433345943	17121	Economy	7900.00
0005433345590	17121	Economy	7900.00
0005435097467	17121	Economy	7900.00
0005433345936	17121	Economy	7900.00
0005435097474	17121	Economy	7900.00
0005433345640	17121	Economy	7900.00
0005433345766	17121	Economy	7900.00
0005433345951	17121	Economy	7900.00
0005433345726	17121	Economy	7900.00
0005435097495	17121	Economy	7900.00
0005433345657	17121	Economy	7900.00
0005435097494	17121	Economy	7900.00
0005433345917	17121	Economy	7900.00
0005433345916	17121	Economy	7900.00
0005435097468	17121	Economy	7900.00
0005433345884	17121	Economy	7900.00
0005433345860	17121	Economy	7900.00
0005433345935	17121	Economy	7900.00
0005433345983	17121	Economy	7900.00
0005433345803	17121	Economy	7900.00
0005433345942	17121	Economy	7900.00
0005433345655	17121	Economy	7900.00
0005433345827	17121	Economy	7900.00
0005432920454	9096	Economy	8900.00
0005432920460	9096	Economy	8900.00
0005432920459	9096	Economy	9800.00
0005432920474	9096	Economy	8900.00
0005432920468	9096	Economy	8900.00
0005432920457	9096	Economy	8900.00
0005432920450	9096	Economy	8900.00
0005432920458	9096	Economy	8900.00
0005432920461	9096	Economy	8900.00
0005433477208	20436	Business	26600.00
0005433507729	20436	Economy	8900.00
0005433507704	20436	Economy	8900.00
0005433477207	20436	Economy	8900.00
0005433477264	20436	Economy	8900.00
0005433481379	20436	Economy	8900.00
0005433507703	20436	Economy	8900.00
0005433477258	20436	Economy	8900.00
0005433507713	20436	Economy	8900.00
0005433477257	20436	Economy	8900.00
0005433477261	20436	Economy	8900.00
0005433507702	20436	Economy	8900.00
0005433507613	20436	Economy	8900.00
0005433507722	20436	Economy	8900.00
0005432396354	18369	Economy	5800.00
0005432396353	18369	Economy	5800.00
0005435626805	11043	Business	9500.00
0005435626807	11043	Business	9500.00
0005435626852	11043	Business	9500.00
0005435127522	11043	Business	9500.00
0005435626747	11043	Business	9500.00
0005435626714	11043	Business	9500.00
0005435626649	11043	Business	9500.00
0005435626711	11043	Business	9500.00
0005435127556	11043	Business	9500.00
0005435626833	11043	Economy	3200.00
0005435626849	11043	Economy	3200.00
0005435626718	11043	Economy	3200.00
0005435626827	11043	Economy	3200.00
0005435626768	11043	Economy	3200.00
0005435626835	11043	Economy	3200.00
0005435626784	11043	Economy	3500.00
0005435626665	11043	Economy	3500.00
0005435626806	11043	Economy	3500.00
0005435127331	11043	Economy	3500.00
0005435127508	11043	Economy	3500.00
0005435127515	11043	Economy	3200.00
0005435626817	11043	Economy	3200.00
0005435127565	11043	Economy	3200.00
0005435127525	11043	Economy	3200.00
0005435626746	11043	Economy	3200.00
0005435626719	11043	Economy	3200.00
0005435626692	11043	Economy	3200.00
0005435626625	11043	Economy	3200.00
0005435127512	11043	Economy	3200.00
0005435127523	11043	Economy	3200.00
0005435626769	11043	Economy	3200.00
0005435626789	11043	Economy	3200.00
0005435127411	11043	Economy	3200.00
0005435626664	11043	Economy	3200.00
0005435127528	11043	Economy	3200.00
0005435626797	11043	Economy	3200.00
0005435127319	11043	Economy	3200.00
0005435626821	11043	Economy	3200.00
0005435626779	11043	Economy	3200.00
0005435127521	11043	Economy	3200.00
0005435127555	11043	Economy	3200.00
0005435626836	11043	Economy	3200.00
0005435626743	11043	Economy	3200.00
0005435626624	11043	Economy	3200.00
0005435626689	11043	Economy	3200.00
0005435626822	11043	Economy	3200.00
0005435127529	11043	Economy	3200.00
0005435626783	11043	Economy	3200.00
0005435626816	11043	Economy	3200.00
0005435554314	11043	Economy	3200.00
0005435554309	11043	Economy	3200.00
0005435626840	11043	Economy	3200.00
0005435626778	11043	Economy	3200.00
0005435626626	11043	Economy	3200.00
0005435127318	11043	Economy	3200.00
0005435626673	11043	Economy	3200.00
0005434411895	14684	Economy	3200.00
0005434411894	14684	Economy	3200.00
0005435216642	7129	Economy	29000.00
0005435219261	7129	Economy	29000.00
0005435443581	7129	Economy	29000.00
0005435216644	7129	Economy	29000.00
0005435219262	7129	Economy	29000.00
0005435443567	7129	Economy	29000.00
0005435178538	7129	Economy	29000.00
0005435216643	7129	Economy	29000.00
0005435219263	7129	Economy	29000.00
0005435443572	7129	Economy	29000.00
0005435216646	7129	Economy	29000.00
0005435715971	27047	Business	86900.00
0005435715962	27047	Business	86900.00
0005435715961	27047	Economy	29000.00
0005435715957	27047	Economy	29000.00
0005435715940	27047	Economy	29000.00
0005435715965	27047	Economy	31900.00
0005432398301	27047	Economy	29000.00
0005435715964	27047	Economy	29000.00
0005432394210	27047	Economy	29000.00
0005435715924	27047	Economy	29000.00
0005432398279	27047	Economy	29000.00
0005432394218	27047	Economy	29000.00
0005432394208	27047	Economy	29000.00
0005432394217	27047	Economy	29000.00
0005435715867	27047	Economy	29000.00
0005435715960	27047	Economy	29000.00
0005435715936	27047	Economy	29000.00
0005435715937	27047	Economy	29000.00
0005432394207	27047	Economy	29000.00
0005432394211	27047	Economy	29000.00
0005435715899	27047	Economy	29000.00
0005434085059	28503	Economy	7700.00
0005435844409	25198	Economy	26400.00
0005435844411	25198	Economy	26400.00
0005432632945	25198	Economy	26400.00
0005435844408	25198	Economy	26400.00
0005435844418	25198	Economy	26400.00
0005435844415	25198	Economy	26400.00
0005435844412	25198	Economy	26400.00
0005435844414	25198	Economy	26400.00
0005435844419	25198	Economy	26400.00
0005435844404	25198	Economy	26400.00
0005432632930	28167	Economy	26400.00
0005432632936	28167	Economy	26400.00
0005432632931	28167	Economy	26400.00
0005432632908	28167	Economy	26400.00
0005432632917	28167	Economy	26400.00
0005432632903	28167	Economy	26400.00
0005432632918	28167	Economy	26400.00
0005432632933	28167	Economy	26400.00
0005432632904	28167	Economy	26400.00
0005432632934	28167	Economy	26400.00
0005432632929	28167	Economy	26400.00
0005432632909	28167	Economy	26400.00
0005432632922	28167	Economy	26400.00
0005432632932	28167	Economy	26400.00
0005435541624	11414	Business	20200.00
0005435541627	11414	Economy	6700.00
0005435541640	11414	Economy	6700.00
0005435541639	11414	Economy	7400.00
0005435541601	11414	Economy	6700.00
0005435518446	11414	Economy	6700.00
0005435541557	11414	Economy	6700.00
0005435518447	11414	Economy	6700.00
0005435541625	11414	Economy	6700.00
0005435518437	11414	Economy	6700.00
0005435541611	11414	Economy	6700.00
0005435546227	11414	Economy	6700.00
0005435518404	11414	Economy	6700.00
0005435518445	11414	Economy	6700.00
0005435541615	11414	Economy	6700.00
0005435518434	11414	Economy	6700.00
0005435541642	11414	Economy	6700.00
0005435541643	11414	Economy	6700.00
0005435541610	11414	Economy	6700.00
0005435518436	11414	Economy	6700.00
0005435541602	11414	Economy	6700.00
0005433252376	2274	Business	20200.00
0005433252321	2274	Economy	6700.00
0005433252365	2274	Economy	6700.00
0005433252369	2274	Economy	6700.00
0005433252377	2274	Economy	6700.00
0005433252368	2274	Economy	6700.00
0005433252367	2274	Economy	6700.00
0005433252339	2274	Economy	6700.00
0005434908801	25587	Business	20200.00
0005434908631	25587	Business	20200.00
0005434908841	25587	Economy	6700.00
0005434908660	25587	Economy	6700.00
0005434908889	25587	Economy	6700.00
0005434908769	25587	Economy	7400.00
0005434908765	25587	Economy	7400.00
0005434908800	25587	Economy	6700.00
0005434908734	25587	Economy	6700.00
0005434908639	25587	Economy	6700.00
0005434908869	25587	Economy	6700.00
0005434908799	25587	Economy	6700.00
0005434908840	25587	Economy	6700.00
0005434908738	25587	Economy	6700.00
0005434908682	25587	Economy	6700.00
0005434908766	25587	Economy	6700.00
0005434908661	25587	Economy	6700.00
0005434908879	25587	Economy	6700.00
0005434908746	25587	Economy	6700.00
0005434908646	25587	Economy	6700.00
0005434908767	25587	Economy	6700.00
0005434908821	25587	Economy	6700.00
0005434908690	25587	Economy	6700.00
0005434908707	25587	Economy	6700.00
0005434908807	25587	Economy	6700.00
0005434908556	25587	Economy	6700.00
0005434908868	25587	Economy	6700.00
0005432621425	28035	Economy	12400.00
0005432621377	28035	Economy	12400.00
0005432621450	28035	Economy	12400.00
0005432621426	28035	Economy	12400.00
0005432621408	28035	Economy	12400.00
0005432621449	28035	Economy	12400.00
0005432621409	28035	Economy	12400.00
0005432621453	28035	Economy	12400.00
0005433454927	31449	Economy	8400.00
0005433454928	31449	Economy	8400.00
0005433454933	31449	Economy	8400.00
0005433454932	31449	Economy	8400.00
0005434142718	12016	Economy	7200.00
0005434142727	12016	Economy	6600.00
0005433129407	12016	Economy	6600.00
0005434184720	12016	Economy	6600.00
0005433129395	12016	Economy	6600.00
0005433134251	12016	Economy	6600.00
0005434184719	12016	Economy	6600.00
0005433129411	12016	Economy	6600.00
0005433134252	12016	Economy	6600.00
0005434184716	12016	Economy	6600.00
0005433129410	12016	Economy	6600.00
0005434326025	29860	Economy	7200.00
0005434326040	29860	Economy	7200.00
0005434326041	29860	Economy	6600.00
0005434326015	29860	Economy	6600.00
0005434326302	29860	Economy	6600.00
0005434326089	29860	Economy	6600.00
0005435698140	24695	Economy	18100.00
0005435698050	24695	Economy	18100.00
0005435698156	24695	Economy	18100.00
0005435698172	24695	Economy	18100.00
0005435698109	24695	Economy	18100.00
0005435698170	24695	Economy	18100.00
0005435698160	24695	Economy	18100.00
0005435698159	24695	Economy	18100.00
0005435698144	24695	Economy	18100.00
0005435698163	24695	Economy	18100.00
0005435698173	24695	Economy	18100.00
0005435698169	24695	Economy	18100.00
0005435698161	24695	Economy	18100.00
0005435698088	24695	Economy	18100.00
0005435698145	24695	Economy	18100.00
0005435698129	24695	Economy	18100.00
0005435698087	24695	Economy	18100.00
0005435698128	24695	Economy	18100.00
0005435698051	24695	Economy	18100.00
0005435698171	24695	Economy	18100.00
0005433724932	21624	Economy	4400.00
0005433724926	21624	Economy	4400.00
0005433724937	21624	Economy	4400.00
0005433724938	21624	Economy	4400.00
0005433724939	21624	Economy	4400.00
0005435283575	7304	Economy	7700.00
0005435283582	7304	Economy	7700.00
0005435283583	7304	Economy	7700.00
0005435283594	7304	Economy	7700.00
0005435283584	7304	Economy	7700.00
0005434140238	28527	Business	23100.00
0005434140569	28527	Business	23100.00
0005434140457	28527	Business	23100.00
0005434140452	28527	Business	23100.00
0005434140341	28527	Business	23100.00
0005434140521	28527	Business	23100.00
0005434140059	28527	Economy	7700.00
0005434140440	28527	Economy	7700.00
0005434140562	28527	Economy	7700.00
0005434140575	28527	Economy	7700.00
0005434140384	28527	Economy	7700.00
0005434140087	28527	Economy	7700.00
0005434140058	28527	Economy	7700.00
0005434140463	28527	Economy	8500.00
0005434140408	28527	Economy	8500.00
0005434140112	28527	Economy	7700.00
0005434140576	28527	Economy	7700.00
0005434140478	28527	Economy	7700.00
0005434140291	28527	Economy	7700.00
0005434140563	28527	Economy	7700.00
0005434140088	28527	Economy	7700.00
0005434087651	28527	Economy	7700.00
0005434140504	28527	Economy	7700.00
0005434140535	28527	Economy	7700.00
0005434140536	28527	Economy	7700.00
0005434140454	28527	Economy	7700.00
0005434140356	28527	Economy	7700.00
0005434140432	28527	Economy	7700.00
0005434140505	28527	Economy	7700.00
0005434140374	28527	Economy	7700.00
0005434140370	28527	Economy	7700.00
0005434140173	28527	Economy	7700.00
0005434140340	28527	Economy	7700.00
0005434140473	28527	Economy	7700.00
0005434140419	28527	Economy	7700.00
0005434140499	28527	Economy	7700.00
0005434140423	28527	Economy	7700.00
0005434140428	28527	Economy	7700.00
0005434140431	28527	Economy	7700.00
0005434140252	28527	Economy	7700.00
0005434140508	28527	Economy	7700.00
0005434140568	28527	Economy	7700.00
0005434087654	28527	Economy	7700.00
0005434140441	28527	Economy	7700.00
0005434140486	28527	Economy	7700.00
0005434140369	28527	Economy	7700.00
0005434140429	28527	Economy	7700.00
0005434087655	28527	Economy	7700.00
0005434140057	28527	Economy	7700.00
0005434140577	28527	Economy	7700.00
0005434140290	28527	Economy	7700.00
0005434140418	28527	Economy	7700.00
0005434140172	28527	Economy	7700.00
0005434140498	28527	Economy	7700.00
0005434140507	28527	Economy	7700.00
0005434140398	28527	Economy	7700.00
0005434140303	28527	Economy	7700.00
0005433407711	1905	Economy	21700.00
0005433407710	1905	Economy	21700.00
0005433407690	1905	Economy	21700.00
0005434505224	16727	Economy	7600.00
0005434505213	16727	Economy	6900.00
0005434505137	16727	Economy	6900.00
0005434505192	16727	Economy	6900.00
0005434505243	16727	Economy	6900.00
0005434505233	16727	Economy	6900.00
0005434505171	16727	Economy	6900.00
0005434505242	16727	Economy	6900.00
0005434505227	16727	Economy	6900.00
0005434505162	16727	Economy	6900.00
0005434505163	16727	Economy	6900.00
0005434505167	16727	Economy	6900.00
0005434505280	16727	Economy	6900.00
0005434505281	16727	Economy	6900.00
0005434505203	16727	Economy	6900.00
0005434505193	16727	Economy	6900.00
0005434505136	16727	Economy	6900.00
0005434505259	16727	Economy	6900.00
0005434505255	16727	Economy	6900.00
0005434505287	16727	Economy	6900.00
0005434505283	16727	Economy	6900.00
0005434505260	16727	Economy	6900.00
0005434505294	16727	Economy	6900.00
0005434505225	16727	Economy	6900.00
0005434505191	16727	Economy	6900.00
0005433266981	2184	Economy	7700.00
0005433266983	2184	Economy	7000.00
0005433266982	2184	Economy	7000.00
0005433266987	2184	Economy	7000.00
0005435078786	24369	Economy	7000.00
0005435078779	24369	Economy	7000.00
0005434989018	23593	Economy	10800.00
0005434989075	23593	Economy	9800.00
0005435803346	23593	Economy	9800.00
0005434989095	23593	Economy	9800.00
0005434989093	23593	Economy	9800.00
0005434989056	23593	Economy	9800.00
0005434988962	23593	Economy	9800.00
0005434989106	23593	Economy	9800.00
0005434989017	23593	Economy	9800.00
0005434989059	23593	Economy	9800.00
0005434988986	23593	Economy	9800.00
0005434989035	23593	Economy	9800.00
0005434989051	23593	Economy	9800.00
0005434989094	23593	Economy	9800.00
0005434989078	23593	Economy	9800.00
0005434989071	23593	Economy	9800.00
0005434988985	23593	Economy	9800.00
0005434989070	23593	Economy	9800.00
0005432384176	31287	Business	9900.00
0005433450561	31287	Business	9900.00
0005433453816	31287	Business	9900.00
0005432384294	31287	Business	9900.00
0005433450575	31287	Business	9900.00
0005433450538	31287	Business	9900.00
0005432384307	31287	Business	9900.00
0005432384228	31287	Economy	3300.00
0005432384222	31287	Economy	3300.00
0005433450576	31287	Economy	3300.00
0005432384290	31287	Economy	3600.00
0005432384258	31287	Economy	3600.00
0005432384221	31287	Economy	3600.00
0005432384257	31287	Economy	3300.00
0005432384110	31287	Economy	3300.00
0005433450569	31287	Economy	3300.00
0005432384180	31287	Economy	3300.00
0005432384215	31287	Economy	3300.00
0005432384243	31287	Economy	3300.00
0005432384140	31287	Economy	3300.00
0005432384141	31287	Economy	3300.00
0005432384181	31287	Economy	3300.00
0005432384111	31287	Economy	3300.00
0005432384161	31287	Economy	3300.00
0005432384109	31287	Economy	3300.00
0005432384186	31287	Economy	3300.00
0005433453815	31287	Economy	3300.00
0005432384231	31287	Economy	3300.00
0005432384113	31287	Economy	3300.00
0005432384229	31287	Economy	3300.00
0005433450570	31287	Economy	3300.00
0005432384293	31287	Economy	3300.00
0005432384248	31287	Economy	3300.00
0005433450560	31287	Economy	3300.00
0005432384108	31287	Economy	3300.00
0005432384112	31287	Economy	3300.00
0005433453817	31287	Economy	3300.00
0005432384177	31287	Economy	3300.00
0005432384196	31287	Economy	3300.00
0005433788301	26465	Economy	26200.00
0005433788302	26465	Economy	23800.00
0005433788316	26465	Economy	23800.00
0005433788317	26465	Economy	23800.00
0005433788306	26465	Economy	23800.00
0005435299912	10749	Economy	15600.00
0005435299885	10749	Economy	15600.00
0005433126978	10749	Economy	15600.00
0005433126977	10749	Economy	15600.00
0005435299911	10749	Economy	15600.00
0005433126965	10749	Economy	15600.00
0005433126966	10749	Economy	15600.00
0005433110395	2440	Economy	15700.00
0005433110396	2440	Economy	15700.00
0005434300250	26836	Economy	17200.00
0005434300248	26836	Economy	17200.00
0005434300237	26836	Economy	15700.00
0005434300269	26836	Economy	15700.00
0005434300257	26836	Economy	15700.00
0005434300265	26836	Economy	15700.00
0005434287931	26836	Economy	15700.00
0005434300255	26836	Economy	15700.00
0005434300247	26836	Economy	15700.00
0005434287930	26836	Economy	15700.00
0005434287895	26836	Economy	15700.00
0005434300256	26836	Economy	15700.00
0005434287932	26836	Economy	15700.00
0005434287882	26836	Economy	15700.00
0005434300251	26836	Economy	15700.00
0005434300254	26836	Economy	15700.00
0005434300252	26836	Economy	15700.00
0005434287933	26836	Economy	15700.00
0005434287927	26836	Economy	15700.00
0005434269159	25481	Economy	22800.00
0005434269161	25481	Economy	22800.00
0005434272231	25481	Economy	22800.00
0005435854086	26652	Economy	22800.00
0005435854078	26652	Economy	22800.00
0005435854085	26652	Economy	22800.00
0005435854079	26652	Economy	22800.00
0005435983703	26652	Economy	22800.00
0005435314942	6108	Economy	22300.00
0005435314931	6108	Economy	22300.00
0005435314932	6108	Economy	22300.00
0005435314933	6108	Economy	22300.00
0005435314937	6108	Economy	22300.00
0005435314947	6108	Economy	22300.00
0005435314948	6108	Economy	22300.00
0005435314946	6108	Economy	22300.00
0005435314938	6108	Economy	22300.00
0005435314950	6108	Economy	22300.00
0005433651082	27626	Business	89800.00
0005433651100	27626	Business	89800.00
0005433651036	27626	Business	89800.00
0005433651097	27626	Business	89800.00
0005433651073	27626	Economy	29900.00
0005433651072	27626	Economy	29900.00
0005433651081	27626	Economy	29900.00
0005433650980	27626	Economy	29900.00
0005433651076	27626	Economy	29900.00
0005433651053	27626	Economy	32900.00
0005433651055	27626	Economy	32900.00
0005433651059	27626	Economy	29900.00
0005433651071	27626	Economy	29900.00
0005433650946	27626	Economy	29900.00
0005433651091	27626	Economy	29900.00
0005433650985	27626	Economy	29900.00
0005433650945	27626	Economy	29900.00
0005433651034	27626	Economy	29900.00
0005433651098	27626	Economy	29900.00
0005433651058	27626	Economy	29900.00
0005433651067	27626	Economy	29900.00
0005433651033	27626	Economy	29900.00
0005433650984	27626	Economy	29900.00
0005435263840	27626	Economy	29900.00
0005433650947	27626	Economy	29900.00
0005433651047	27626	Economy	29900.00
0005433651050	27626	Economy	29900.00
0005433651079	27626	Economy	29900.00
0005433651030	27626	Economy	29900.00
0005433651093	27626	Economy	29900.00
0005433651078	27626	Economy	29900.00
0005433650996	27626	Economy	29900.00
0005433651094	27626	Economy	29900.00
0005433651052	27626	Economy	29900.00
0005433651039	27626	Economy	29900.00
0005433651051	27626	Economy	29900.00
0005433651026	27626	Economy	29900.00
0005433651090	27626	Economy	29900.00
0005433650986	27626	Economy	29900.00
0005433651099	27626	Economy	29900.00
0005433651070	27626	Economy	29900.00
0005433651065	27626	Economy	29900.00
0005433651046	27626	Economy	29900.00
0005433651042	27626	Economy	29900.00
0005433651054	27626	Economy	29900.00
0005433651049	27626	Economy	29900.00
0005433651080	27626	Economy	29900.00
0005433651074	27626	Economy	29900.00
0005433651000	27626	Economy	29900.00
0005433651077	27626	Economy	29900.00
0005433651089	27626	Economy	29900.00
0005433650987	27626	Economy	29900.00
0005433651075	27626	Economy	29900.00
0005435860606	4786	Economy	19400.00
0005435860605	4786	Economy	17600.00
0005435860629	4786	Economy	17600.00
0005435860607	4786	Economy	17600.00
0005433869562	32596	Economy	19400.00
0005433869378	32596	Economy	19400.00
0005433869496	32596	Economy	17600.00
0005433869402	32596	Economy	17600.00
0005433869592	32596	Economy	17600.00
0005433869591	32596	Economy	17600.00
0005433869537	32596	Economy	17600.00
0005433869516	32596	Economy	17600.00
0005433869518	32596	Economy	17600.00
0005433869586	32596	Economy	17600.00
0005433869596	32596	Economy	17600.00
0005433869564	32596	Economy	17600.00
0005433869391	32596	Economy	17600.00
0005433869561	32596	Economy	17600.00
0005433869545	32596	Economy	17600.00
0005433869411	32596	Economy	17600.00
0005433869418	32596	Economy	17600.00
0005433869489	32596	Economy	17600.00
0005433869517	32596	Economy	17600.00
0005433869495	32596	Economy	17600.00
0005433869565	32596	Economy	17600.00
0005433869403	32596	Economy	17600.00
0005433869551	32596	Economy	17600.00
0005433869390	32596	Economy	17600.00
0005433869539	32596	Economy	17600.00
0005433869540	32596	Economy	17600.00
0005433869550	32596	Economy	17600.00
0005433869587	32596	Economy	17600.00
0005435911664	3439	Economy	22600.00
0005435911666	3439	Economy	22600.00
0005435911662	3439	Economy	22600.00
0005435911663	3439	Economy	22600.00
0005435911660	3439	Economy	22600.00
0005435911665	3439	Economy	22600.00
0005434663798	12463	Economy	22600.00
0005434663786	12463	Economy	22600.00
0005434663799	12463	Economy	22600.00
0005433869596	14505	Economy	18500.00
0005433869403	14505	Economy	18500.00
0005433869591	14505	Economy	16800.00
0005433869540	14505	Economy	16800.00
0005433869411	14505	Economy	16800.00
0005433869391	14505	Economy	16800.00
0005433869496	14505	Economy	16800.00
0005433869561	14505	Economy	16800.00
0005433869539	14505	Economy	16800.00
0005433869402	14505	Economy	16800.00
0005433869390	14505	Economy	16800.00
0005433869564	14505	Economy	16800.00
0005433869587	14505	Economy	16800.00
0005433869586	14505	Economy	16800.00
0005433869517	14505	Economy	16800.00
0005433869495	14505	Economy	16800.00
0005433869516	14505	Economy	16800.00
0005433869537	14505	Economy	16800.00
0005433869592	14505	Economy	16800.00
0005433869562	14505	Economy	16800.00
0005433869551	14505	Economy	16800.00
0005433869489	14505	Economy	16800.00
0005433869545	14505	Economy	16800.00
0005433869378	14505	Economy	16800.00
0005433869418	14505	Economy	16800.00
0005433869518	14505	Economy	16800.00
0005433869565	14505	Economy	16800.00
0005433869550	14505	Economy	16800.00
0005435860626	32651	Economy	16800.00
0005435860631	32651	Economy	16800.00
0005435860600	32651	Economy	16800.00
0005432800251	12117	Economy	4900.00
0005432800250	12117	Economy	4900.00
0005432800280	12117	Economy	4400.00
0005432800273	12117	Economy	4400.00
0005432800219	12117	Economy	4400.00
0005432800255	12117	Economy	4400.00
0005432800281	12117	Economy	4400.00
0005432800282	12117	Economy	4400.00
0005432800268	12117	Economy	4400.00
0005432800267	12117	Economy	4400.00
0005432800278	12117	Economy	4400.00
0005432800283	12117	Economy	4400.00
0005432800237	12117	Economy	4400.00
0005432800254	12117	Economy	4400.00
0005432800249	12117	Economy	4400.00
0005435293611	7068	Business	49100.00
0005435293613	7068	Business	49100.00
0005435311510	7068	Economy	16400.00
0005435311546	7068	Economy	16400.00
0005435311477	7068	Economy	16400.00
0005435293616	7068	Economy	16400.00
0005435311474	7068	Economy	16400.00
0005435311453	7068	Economy	16400.00
0005435311462	7068	Economy	16400.00
0005435311507	7068	Economy	16400.00
0005435311517	7068	Economy	16400.00
0005435293617	7068	Economy	16400.00
0005435311508	7068	Economy	16400.00
0005435311532	7068	Economy	16400.00
0005435311511	7068	Economy	16400.00
0005435293619	7068	Economy	16400.00
0005435311481	7068	Economy	16400.00
0005435311423	7068	Economy	16400.00
0005435311516	7068	Economy	16400.00
0005435293612	7068	Economy	16400.00
0005435311544	7068	Economy	16400.00
0005435311521	7068	Economy	16400.00
0005435311509	7068	Economy	16400.00
0005435293600	7068	Economy	16400.00
0005435311545	7068	Economy	16400.00
0005435311550	7068	Economy	16400.00
0005434409068	26935	Business	49100.00
0005434409361	26935	Business	49100.00
0005434300209	26935	Business	49100.00
0005434300176	26935	Business	49100.00
0005434409591	26935	Economy	16400.00
0005434409441	26935	Economy	16400.00
0005434409446	26935	Economy	16400.00
0005434409583	26935	Economy	16400.00
0005434409553	26935	Economy	16400.00
0005434409432	26935	Economy	16400.00
0005434409448	26935	Economy	16400.00
0005434409439	26935	Economy	18000.00
0005434409519	26935	Economy	18000.00
0005434409371	26935	Economy	16400.00
0005434409527	26935	Economy	16400.00
0005434409551	26935	Economy	16400.00
0005434409546	26935	Economy	16400.00
0005434409471	26935	Economy	16400.00
0005434300227	26935	Economy	16400.00
0005434409470	26935	Economy	16400.00
0005434409440	26935	Economy	16400.00
0005434300202	26935	Economy	16400.00
0005434300228	26935	Economy	16400.00
0005434409447	26935	Economy	16400.00
0005434409508	26935	Economy	16400.00
0005434409483	26935	Economy	16400.00
0005434409348	26935	Economy	16400.00
0005434409554	26935	Economy	16400.00
0005434300187	26935	Economy	16400.00
0005434409347	26935	Economy	16400.00
0005434409428	26935	Economy	16400.00
0005434409362	26935	Economy	16400.00
0005434409555	26935	Economy	16400.00
0005434409331	26935	Economy	16400.00
0005434409364	26935	Economy	16400.00
0005435221556	6450	Economy	15000.00
0005435220521	6450	Economy	15000.00
0005435220520	6450	Economy	15000.00
0005435312911	6450	Economy	15000.00
0005435312912	6450	Economy	15000.00
0005432605386	21388	Economy	15000.00
0005434512235	21388	Economy	15000.00
0005432605433	21388	Economy	15000.00
0005432605447	21388	Economy	15000.00
0005432605369	21388	Economy	15000.00
0005432605432	21388	Economy	15000.00
0005434512249	21388	Economy	15000.00
0005432605383	21388	Economy	15000.00
0005432605489	21388	Economy	15000.00
0005432605498	21388	Economy	15000.00
0005432605402	21388	Economy	15000.00
0005432605434	21388	Economy	15000.00
0005432605354	21388	Economy	15000.00
0005432605497	21388	Economy	15000.00
0005432605349	21388	Economy	15000.00
0005432605298	21388	Economy	15000.00
0005432605446	21388	Economy	15000.00
0005432605412	21388	Economy	15000.00
0005432605485	21388	Economy	15000.00
0005434512248	21388	Economy	15000.00
0005432605483	21388	Economy	15000.00
0005434908841	14979	Business	18900.00
0005434908799	14979	Business	18900.00
0005434908868	14979	Business	18900.00
0005434908660	14979	Business	18900.00
0005434908765	14979	Business	18900.00
0005434908639	14979	Economy	6300.00
0005434908801	14979	Economy	6300.00
0005434908690	14979	Economy	6300.00
0005434908807	14979	Economy	6300.00
0005434908646	14979	Economy	6300.00
0005434908734	14979	Economy	6900.00
0005434908769	14979	Economy	6300.00
0005434908746	14979	Economy	6300.00
0005434908869	14979	Economy	6300.00
0005434908840	14979	Economy	6300.00
0005434908661	14979	Economy	6300.00
0005434908821	14979	Economy	6300.00
0005434908800	14979	Economy	6300.00
0005434908766	14979	Economy	6300.00
0005434908889	14979	Economy	6300.00
0005434908767	14979	Economy	6300.00
0005434908682	14979	Economy	6300.00
0005434908707	14979	Economy	6300.00
0005434908556	14979	Economy	6300.00
0005434908879	14979	Economy	6300.00
0005434908631	14979	Economy	6300.00
0005434908738	14979	Economy	6300.00
0005433252332	25871	Business	18900.00
0005433252341	25871	Economy	6300.00
0005433252372	25871	Economy	6300.00
0005433252331	25871	Economy	6300.00
0005433252343	25871	Economy	6300.00
0005433252342	25871	Economy	6300.00
0005433252213	25871	Economy	6300.00
0005433252355	25871	Economy	6300.00
0005433252350	25871	Economy	6300.00
0005433252295	25871	Economy	6300.00
0005433252366	25871	Economy	6300.00
0005433252294	25871	Economy	6300.00
0005434173661	9183	Economy	18100.00
0005434173664	9183	Economy	18100.00
0005433815584	22729	Economy	18100.00
0005433815549	22729	Economy	18100.00
0005433815550	22729	Economy	18100.00
0005433815562	22729	Economy	18100.00
0005433815584	14151	Business	52300.00
0005433810739	14151	Economy	17400.00
0005433810731	14151	Economy	17400.00
0005433810762	14151	Economy	17400.00
0005433815562	14151	Economy	17400.00
0005433810732	14151	Economy	17400.00
0005433815549	14151	Economy	17400.00
0005433810738	14151	Economy	17400.00
0005433815550	14151	Economy	17400.00
0005433810746	14151	Economy	17400.00
0005433810711	14151	Economy	17400.00
0005433009778	22841	Business	52300.00
0005434173656	22841	Business	52300.00
0005433009921	22841	Business	52300.00
0005434173646	22841	Economy	17400.00
0005433009779	22841	Economy	17400.00
0005434173647	22841	Economy	17400.00
0005433009908	22841	Economy	17400.00
0005433009777	22841	Economy	17400.00
0005433009968	22841	Economy	17400.00
0005433009903	22841	Economy	17400.00
0005433009950	22841	Economy	19200.00
0005434173666	22841	Economy	17400.00
0005433009862	22841	Economy	17400.00
0005433009864	22841	Economy	17400.00
0005434173659	22841	Economy	17400.00
0005433009963	22841	Economy	17400.00
0005434173665	22841	Economy	17400.00
0005433009938	22841	Economy	17400.00
0005433009824	22841	Economy	17400.00
0005433009863	22841	Economy	17400.00
0005433009837	22841	Economy	17400.00
0005433009835	22841	Economy	17400.00
0005433009962	22841	Economy	17400.00
0005434173663	22841	Economy	17400.00
0005434173662	22841	Economy	17400.00
0005433009951	22841	Economy	17400.00
0005433009855	22841	Economy	17400.00
0005433009966	22841	Economy	17400.00
0005433009838	22841	Economy	17400.00
0005434173667	22841	Economy	17400.00
0005433009907	22841	Economy	17400.00
0005433009836	22841	Economy	17400.00
0005433009904	22841	Economy	17400.00
0005433009905	22841	Economy	17400.00
0005434926683	14950	Business	22900.00
0005434926766	14950	Business	22900.00
0005434926658	14950	Business	22900.00
0005434926830	14950	Business	22900.00
0005434926777	14950	Economy	7600.00
0005434926798	14950	Economy	7600.00
0005434926685	14950	Economy	7600.00
0005434926819	14950	Economy	7600.00
0005434926786	14950	Economy	7600.00
0005434926747	14950	Economy	8400.00
0005434926638	14950	Economy	8400.00
0005434926860	14950	Economy	8400.00
0005434926746	14950	Economy	7600.00
0005434926670	14950	Economy	7600.00
0005434926640	14950	Economy	7600.00
0005434926820	14950	Economy	7600.00
0005434926794	14950	Economy	7600.00
0005434926843	14950	Economy	7600.00
0005434926674	14950	Economy	7600.00
0005434926758	14950	Economy	7600.00
0005434926736	14950	Economy	7600.00
0005434926643	14950	Economy	7600.00
0005434926706	14950	Economy	7600.00
0005434926684	14950	Economy	7600.00
0005434926642	14950	Economy	7600.00
0005434926634	14950	Economy	7600.00
0005434926748	14950	Economy	7600.00
0005434926635	14950	Economy	7600.00
0005434926745	14950	Economy	7600.00
0005434926727	14950	Economy	7600.00
0005434926714	14950	Economy	7600.00
0005434926818	14950	Economy	7600.00
0005434926671	14950	Economy	7600.00
0005434926711	14950	Economy	7600.00
0005434926767	14950	Economy	7600.00
0005434926639	14950	Economy	7600.00
0005434926713	14950	Economy	7600.00
0005434926702	14950	Economy	7600.00
0005435999830	15814	Economy	8900.00
0005435999820	15814	Economy	8100.00
0005435999804	15814	Economy	8100.00
0005435999846	15814	Economy	8100.00
0005435999800	15814	Economy	8100.00
0005435999827	15814	Economy	8100.00
0005435999823	15814	Economy	8100.00
0005435999822	15814	Economy	8100.00
0005435999819	15814	Economy	8100.00
0005435999751	15814	Economy	8100.00
0005435999805	15814	Economy	8100.00
0005435999810	15814	Economy	8100.00
0005435999745	15814	Economy	8100.00
0005435999801	15814	Economy	8100.00
0005435999847	15814	Economy	8100.00
0005435999829	15814	Economy	8100.00
0005435999845	15814	Economy	8100.00
0005435999809	15814	Economy	8100.00
0005435488431	19706	Economy	8100.00
0005435488432	19706	Economy	8100.00
0005435488459	19706	Economy	8100.00
0005435488394	19706	Economy	8100.00
0005435488393	19706	Economy	8100.00
0005435488411	19706	Economy	8100.00
0005435488414	19706	Economy	8100.00
0005435488462	19706	Economy	8100.00
0005435488416	19706	Economy	8100.00
0005432537118	6026	Business	199300.00
0005435473269	6026	Business	199300.00
0005435473283	6026	Business	199300.00
0005432537119	6026	Economy	66400.00
0005435473268	6026	Economy	66400.00
0005432537115	6026	Economy	66400.00
0005435473272	6026	Economy	66400.00
0005435473284	6026	Economy	66400.00
0005435840263	18077	Business	199300.00
0005435840244	18077	Business	199300.00
0005435840272	18077	Economy	66400.00
0005435840228	18077	Economy	66400.00
0005432660870	18077	Economy	66400.00
0005435840265	18077	Economy	66400.00
0005435840266	18077	Economy	66400.00
0005435840243	18077	Economy	66400.00
0005435840274	18077	Economy	66400.00
0005432664196	18077	Economy	66400.00
0005435840257	18077	Economy	66400.00
0005432664197	18077	Economy	66400.00
0005435840267	18077	Economy	66400.00
0005435840258	18077	Economy	66400.00
0005435840240	18077	Economy	66400.00
0005433286192	23036	Economy	5200.00
0005433286190	23036	Economy	5200.00
0005433286216	23036	Economy	5200.00
0005433286175	23036	Economy	5200.00
0005433286146	23036	Economy	5200.00
0005433286191	23036	Economy	5200.00
0005433286173	23036	Economy	5200.00
0005433286161	23036	Economy	5200.00
0005433286193	23036	Economy	5200.00
0005433286189	23036	Economy	5200.00
0005433286215	23036	Economy	5200.00
0005433286162	23036	Economy	5200.00
0005433286202	23036	Economy	5200.00
0005433286174	23036	Economy	5200.00
0005433286188	23036	Economy	5200.00
0005435104328	32060	Business	15700.00
0005435104359	32060	Business	15700.00
0005435104318	32060	Business	15700.00
0005435104361	32060	Economy	5200.00
0005435104264	32060	Economy	5200.00
0005435104276	32060	Economy	5200.00
0005435104360	32060	Economy	5200.00
0005435104262	32060	Economy	5200.00
0005435104246	32060	Economy	5200.00
0005435097511	32060	Economy	5200.00
0005435104317	32060	Economy	5200.00
0005435104333	32060	Economy	5200.00
0005435104178	32060	Economy	5200.00
0005435104307	32060	Economy	5200.00
0005435104249	32060	Economy	5200.00
0005435104275	32060	Economy	5200.00
0005435104248	32060	Economy	5700.00
0005435097510	32060	Economy	5200.00
0005435104180	32060	Economy	5200.00
0005435104237	32060	Economy	5200.00
0005435104343	32060	Economy	5200.00
0005435104261	32060	Economy	5200.00
0005435104193	32060	Economy	5200.00
0005435104213	32060	Economy	5200.00
0005435104263	32060	Economy	5200.00
0005435104346	32060	Economy	5200.00
0005435104247	32060	Economy	5200.00
0005435104179	32060	Economy	5200.00
0005435104184	32060	Economy	5200.00
0005435104238	32060	Economy	5200.00
0005435104282	32060	Economy	5200.00
0005432531735	30578	Business	42100.00
0005432531757	30578	Business	42100.00
0005432531340	30578	Business	42100.00
0005432531759	30578	Business	42100.00
0005434069486	30578	Business	42100.00
0005434069554	30578	Comfort	23900.00
0005434069533	30578	Comfort	23900.00
0005434069365	30578	Comfort	23900.00
0005432531671	30578	Comfort	23900.00
0005432531403	30578	Comfort	23900.00
0005432531634	30578	Comfort	23900.00
0005432531810	30578	Comfort	23900.00
0005434069639	30578	Comfort	23900.00
0005432537116	30578	Comfort	23900.00
0005432531745	30578	Economy	14000.00
0005434069497	30578	Economy	14000.00
0005434069570	30578	Economy	14000.00
0005432531665	30578	Economy	14000.00
0005432531734	30578	Economy	14000.00
0005434069304	30578	Economy	14000.00
0005432531783	30578	Economy	14000.00
0005432531806	30578	Economy	14000.00
0005432535978	30578	Economy	14000.00
0005432531720	30578	Economy	14000.00
0005432537117	30578	Economy	14000.00
0005432531752	30578	Economy	14000.00
0005434069619	30578	Economy	14000.00
0005432531754	30578	Economy	14000.00
0005434069489	30578	Economy	14000.00
0005432531805	30578	Economy	14000.00
0005432531746	30578	Economy	14000.00
0005434069492	30578	Economy	14000.00
0005434069620	30578	Economy	14000.00
0005432531758	30578	Economy	14000.00
0005432531789	30578	Economy	14000.00
0005434069634	30578	Economy	14000.00
0005432535977	30578	Economy	14000.00
0005434069529	30578	Economy	14000.00
0005432531607	30578	Economy	14000.00
0005432531779	30578	Economy	14000.00
0005432531679	30578	Economy	14000.00
0005434069610	30578	Economy	14000.00
0005432531402	30578	Economy	14000.00
0005434069526	30578	Economy	14000.00
0005432531811	30578	Economy	14000.00
0005432531684	30578	Economy	14000.00
0005432531753	30578	Economy	15400.00
0005434069569	30578	Economy	15400.00
0005434069564	30578	Economy	14000.00
0005432531515	30578	Economy	14000.00
0005432531721	30578	Economy	14000.00
0005432531744	30578	Economy	14000.00
0005432531680	30578	Economy	14000.00
0005432531801	30578	Economy	14000.00
0005432531712	30578	Economy	14000.00
0005434069299	30578	Economy	14000.00
0005432531404	30578	Economy	14000.00
0005434069615	30578	Economy	14000.00
0005434069449	30578	Economy	14000.00
0005434069479	30578	Economy	14000.00
0005432531682	30578	Economy	14000.00
0005432531722	30578	Economy	14000.00
0005434069366	30578	Economy	14000.00
0005434069527	30578	Economy	14000.00
0005432531809	30578	Economy	14000.00
0005434069635	30578	Economy	14000.00
0005432535968	30578	Economy	14000.00
0005434069618	30578	Economy	14000.00
0005435654419	24829	Business	9800.00
0005435654342	24829	Business	9800.00
0005435654298	24829	Business	9800.00
0005435654432	24829	Business	9800.00
0005435654420	24829	Business	9800.00
0005435654296	24829	Business	9800.00
0005435654244	24829	Business	9800.00
0005435654426	24829	Economy	3300.00
0005435654336	24829	Economy	3300.00
0005435654309	24829	Economy	3600.00
0005435654433	24829	Economy	3600.00
0005435654453	24829	Economy	3300.00
0005435654360	24829	Economy	3300.00
0005435654338	24829	Economy	3300.00
0005435654375	24829	Economy	3300.00
0005435654272	24829	Economy	3300.00
0005435654427	24829	Economy	3300.00
0005435654394	24829	Economy	3300.00
0005435654352	24829	Economy	3300.00
0005435654374	24829	Economy	3300.00
0005435654395	24829	Economy	3300.00
0005435654297	24829	Economy	3300.00
0005435654484	24829	Economy	3300.00
0005435654431	24829	Economy	3300.00
0005435654210	24829	Economy	3300.00
0005435654209	24829	Economy	3300.00
0005435654357	24829	Economy	3300.00
0005435654305	24829	Economy	3300.00
0005435654457	24829	Economy	3300.00
0005435654306	24829	Economy	3300.00
0005435654337	24829	Economy	3300.00
0005435654243	24829	Economy	3300.00
0005435654254	24829	Economy	3300.00
0005435654250	24829	Economy	3300.00
0005435654343	24829	Economy	3300.00
0005435654456	24829	Economy	3300.00
0005435654214	24829	Economy	3300.00
0005435654273	24829	Economy	3300.00
0005435654251	24829	Economy	3300.00
0005435654344	24829	Economy	3300.00
0005435654477	24829	Economy	3300.00
0005435654430	24829	Economy	3300.00
0005435654271	24829	Economy	3300.00
0005435949864	23317	Economy	20600.00
0005435949863	23317	Economy	18700.00
0005435949854	23317	Economy	18700.00
0005435949866	23317	Economy	18700.00
0005435949860	23317	Economy	18700.00
0005435949853	23317	Economy	18700.00
0005435949867	23317	Economy	18700.00
0005435949855	23317	Economy	18700.00
0005434980642	23560	Economy	10500.00
0005434980628	23560	Economy	9500.00
0005434980524	23560	Economy	9500.00
0005434980661	23560	Economy	9500.00
0005434980653	23560	Economy	9500.00
0005434980518	23560	Economy	9500.00
0005434980611	23560	Economy	9500.00
0005434980654	23560	Economy	9500.00
0005434980560	23560	Economy	9500.00
0005434980651	23560	Economy	9500.00
0005434980601	23560	Economy	9500.00
0005434980652	23560	Economy	9500.00
0005433256495	2652	Economy	5300.00
0005434302898	19797	Economy	8700.00
0005434140612	11921	Business	9700.00
0005434140485	11921	Business	9700.00
0005434140589	11921	Business	9700.00
0005434140590	11921	Business	9700.00
0005434140608	11921	Business	9700.00
0005434140522	11921	Economy	3200.00
0005434140623	11921	Economy	3200.00
0005434140551	11921	Economy	3200.00
0005434140607	11921	Economy	3200.00
0005434140574	11921	Economy	3200.00
0005434140524	11921	Economy	3500.00
0005434140601	11921	Economy	3500.00
0005434140422	11921	Economy	3200.00
0005434140573	11921	Economy	3200.00
0005434140570	11921	Economy	3200.00
0005434140439	11921	Economy	3200.00
0005434140602	11921	Economy	3200.00
0005434140158	11921	Economy	3200.00
0005434140523	11921	Economy	3200.00
0005434140545	11921	Economy	3200.00
0005434140624	11921	Economy	3200.00
0005434140475	11921	Economy	3200.00
0005434140541	11921	Economy	3200.00
0005434140482	11921	Economy	3200.00
0005434140525	11921	Economy	3200.00
0005434140526	11921	Economy	3200.00
0005434140613	11921	Economy	3200.00
0005434140544	11921	Economy	3200.00
0005434140460	11921	Economy	3200.00
0005434140600	11921	Economy	3200.00
0005434140438	11921	Economy	3200.00
0005434140550	11921	Economy	3200.00
0005434140476	11921	Economy	3200.00
0005434140509	11921	Economy	3200.00
0005434140471	11921	Economy	3200.00
0005435283584	28738	Economy	3200.00
0005435283575	28738	Economy	3200.00
0005435283594	28738	Economy	3500.00
0005435283583	28738	Economy	3200.00
0005435283582	28738	Economy	3200.00
0005434513660	19104	Economy	23600.00
0005434513661	19104	Economy	23600.00
0005434516140	19104	Economy	23600.00
0005434513658	19104	Economy	23600.00
0005434516139	19104	Economy	23600.00
0005434513659	19104	Economy	23600.00
0005434513652	19104	Economy	23600.00
0005434516138	19104	Economy	23600.00
0005434513651	19104	Economy	23600.00
0005433539122	24999	Economy	10900.00
0005433539103	24999	Economy	9900.00
0005433539121	24999	Economy	9900.00
0005432922636	826	Economy	14600.00
0005433512196	16152	Economy	16100.00
0005433512180	16152	Economy	14600.00
0005435852653	4044	Economy	12300.00
0005435935135	3663	Economy	7900.00
0005435935133	3663	Economy	7200.00
0005435935136	3663	Economy	7200.00
0005435698140	16275	Economy	7200.00
0005435698145	16275	Economy	7200.00
0005435698171	16275	Economy	7200.00
0005435698172	16275	Economy	7200.00
0005435698128	16275	Economy	7200.00
0005435698109	16275	Economy	7200.00
0005435698173	16275	Economy	7200.00
0005435698170	16275	Economy	7200.00
0005435698129	16275	Economy	7200.00
0005435698050	16275	Economy	7200.00
0005435698159	16275	Economy	7200.00
0005435698169	16275	Economy	7200.00
0005435698087	16275	Economy	7200.00
0005435698156	16275	Economy	7200.00
0005435698144	16275	Economy	7200.00
0005435698163	16275	Economy	7200.00
0005435698161	16275	Economy	7200.00
0005435698051	16275	Economy	7200.00
0005435698088	16275	Economy	7200.00
0005435698160	16275	Economy	7200.00
0005435904912	3953	Economy	19300.00
0005435904911	3953	Economy	19300.00
0005433519592	22035	Economy	19300.00
0005434606925	22035	Economy	19300.00
0005434606927	22035	Economy	19300.00
0005434606926	22035	Economy	19300.00
0005433519591	22035	Economy	19300.00
0005435628822	15899	Economy	3700.00
0005435383287	7888	Economy	5900.00
0005435383286	7888	Economy	5400.00
0005435383285	7888	Economy	5400.00
0005435133168	33066	Economy	5400.00
0005435133195	33066	Economy	5400.00
0005435133169	33066	Economy	5400.00
0005435133194	33066	Economy	5400.00
0005435133196	33066	Economy	5400.00
0005435390435	7495	Economy	12500.00
0005435160623	29580	Economy	12500.00
0005432394222	18475	Economy	4900.00
0005432394221	18475	Economy	4900.00
0005435178538	27170	Economy	4900.00
0005434191322	9756	Economy	4400.00
0005434191323	9756	Economy	4400.00
0005434191319	9756	Economy	4400.00
0005435104318	22639	Business	48400.00
0005435104184	22639	Business	48400.00
0005434505192	22639	Business	48400.00
0005435104249	22639	Business	48400.00
0005434505213	22639	Business	48400.00
0005434505162	22639	Business	48400.00
0005435104282	22639	Business	48400.00
0005434505167	22639	Business	48400.00
0005435104180	22639	Business	48400.00
0005434505137	22639	Business	48400.00
0005434505203	22639	Economy	16100.00
0005435104360	22639	Economy	16100.00
0005434505163	22639	Economy	16100.00
0005434505259	22639	Economy	16100.00
0005434505294	22639	Economy	16100.00
0005434505280	22639	Economy	16100.00
0005434505233	22639	Economy	16100.00
0005435104213	22639	Economy	16100.00
0005434505227	22639	Economy	17800.00
0005434505243	22639	Economy	17800.00
0005434505193	22639	Economy	17800.00
0005435104246	22639	Economy	16100.00
0005435104264	22639	Economy	16100.00
0005434505242	22639	Economy	16100.00
0005435104261	22639	Economy	16100.00
0005435104238	22639	Economy	16100.00
0005434505287	22639	Economy	16100.00
0005435104276	22639	Economy	16100.00
0005435104178	22639	Economy	16100.00
0005435104346	22639	Economy	16100.00
0005434505225	22639	Economy	16100.00
0005434505281	22639	Economy	16100.00
0005434505136	22639	Economy	16100.00
0005434505283	22639	Economy	16100.00
0005435104275	22639	Economy	16100.00
0005434505260	22639	Economy	16100.00
0005435104328	22639	Economy	16100.00
0005435104307	22639	Economy	16100.00
0005435104359	22639	Economy	16100.00
0005435104179	22639	Economy	16100.00
0005434505255	22639	Economy	16100.00
0005435104263	22639	Economy	16100.00
0005435104247	22639	Economy	16100.00
0005435104248	22639	Economy	16100.00
0005435104361	22639	Economy	16100.00
0005435104343	22639	Economy	16100.00
0005435104237	22639	Economy	16100.00
0005435104193	22639	Economy	16100.00
0005435104333	22639	Economy	16100.00
0005435104317	22639	Economy	16100.00
0005435104262	22639	Economy	16100.00
0005434505191	22639	Economy	16100.00
0005434505224	22639	Economy	16100.00
0005434505171	22639	Economy	16100.00
0005433368936	1693	Economy	16700.00
0005433368953	1693	Economy	16700.00
0005433368898	1693	Economy	16700.00
0005433368975	1693	Economy	16700.00
0005433368965	1693	Economy	16700.00
0005433368952	1693	Economy	16700.00
0005433368935	1693	Economy	16700.00
0005433368920	1693	Economy	16700.00
0005433368942	1693	Economy	16700.00
0005433368906	1693	Economy	16700.00
0005433368866	1693	Economy	16700.00
0005435654419	21710	Business	50000.00
0005435654433	21710	Business	50000.00
0005435790409	21710	Business	50000.00
0005435654251	21710	Business	50000.00
0005435654357	21710	Economy	16700.00
0005435654395	21710	Economy	16700.00
0005435654336	21710	Economy	16700.00
0005435654343	21710	Economy	18300.00
0005435654214	21710	Economy	18300.00
0005435654375	21710	Economy	18300.00
0005435654309	21710	Economy	16700.00
0005435654420	21710	Economy	16700.00
0005435654298	21710	Economy	16700.00
0005435654296	21710	Economy	16700.00
0005435654305	21710	Economy	16700.00
0005435654272	21710	Economy	16700.00
0005435654484	21710	Economy	16700.00
0005435654431	21710	Economy	16700.00
0005435654432	21710	Economy	16700.00
0005435790408	21710	Economy	16700.00
0005435654374	21710	Economy	16700.00
0005435654344	21710	Economy	16700.00
0005435654209	21710	Economy	16700.00
0005435654352	21710	Economy	16700.00
0005435654210	21710	Economy	16700.00
0005435654426	21710	Economy	16700.00
0005435654244	21710	Economy	16700.00
0005435654250	21710	Economy	16700.00
0005435654271	21710	Economy	16700.00
0005435654306	21710	Economy	16700.00
0005435654360	21710	Economy	16700.00
0005435654254	21710	Economy	16700.00
0005435654342	21710	Economy	16700.00
0005435654453	21710	Economy	16700.00
0005435654297	21710	Economy	16700.00
0005435654338	21710	Economy	16700.00
0005435654394	21710	Economy	16700.00
0005435654477	21710	Economy	16700.00
0005435654243	21710	Economy	16700.00
0005435654337	21710	Economy	16700.00
0005435654430	21710	Economy	16700.00
0005435654457	21710	Economy	16700.00
0005435654273	21710	Economy	16700.00
0005435654427	21710	Economy	16700.00
0005435654456	21710	Economy	16700.00
0005435860635	4145	Economy	7200.00
0005435860636	4145	Economy	7200.00
0005433987270	25643	Business	21500.00
0005433987344	25643	Economy	7900.00
0005433987367	25643	Economy	7200.00
0005433987328	25643	Economy	7200.00
0005433987247	25643	Economy	7200.00
0005433987345	25643	Economy	7200.00
0005433987362	25643	Economy	7200.00
0005433987363	25643	Economy	7200.00
0005433987368	25643	Economy	7200.00
0005433987320	25643	Economy	7200.00
0005433987346	25643	Economy	7200.00
0005433987353	25643	Economy	7200.00
0005433987329	25643	Economy	7200.00
0005433987266	25643	Economy	7200.00
0005433987246	25643	Economy	7200.00
0005433987281	25643	Economy	7200.00
0005434509380	21316	Economy	17000.00
0005434509375	21316	Economy	17000.00
0005434509374	21316	Economy	15500.00
0005432666449	17817	Business	18000.00
0005432660881	17817	Business	18000.00
0005432665336	17817	Economy	6000.00
0005432661985	17817	Economy	6000.00
0005432655885	17817	Economy	6000.00
0005432660882	17817	Economy	6000.00
0005432666448	17817	Economy	6000.00
0005432661986	17817	Economy	6000.00
0005432655860	17817	Economy	6000.00
0005432666447	17817	Economy	6000.00
0005434151791	26301	Business	18000.00
0005432869710	26301	Economy	6000.00
0005434151792	26301	Economy	6000.00
0005432905291	3093	Economy	5400.00
0005432329981	31116	Business	16100.00
0005433439113	31116	Business	16100.00
0005433439066	31116	Economy	5400.00
0005432330024	31116	Economy	5400.00
0005433439090	31116	Economy	5400.00
0005432329971	31116	Economy	5400.00
0005432330044	31116	Economy	5900.00
0005432330045	31116	Economy	5900.00
0005432330010	31116	Economy	5400.00
0005432329991	31116	Economy	5400.00
0005432329970	31116	Economy	5400.00
0005433439075	31116	Economy	5400.00
0005433439112	31116	Economy	5400.00
0005432330059	31116	Economy	5400.00
0005432330050	31116	Economy	5400.00
0005432330043	31116	Economy	5400.00
0005433439092	31116	Economy	5400.00
0005433439089	31116	Economy	5400.00
0005433439067	31116	Economy	5400.00
0005432329980	31116	Economy	5400.00
0005432330023	31116	Economy	5400.00
0005432329929	31116	Economy	5400.00
0005432329992	31116	Economy	5400.00
0005432330046	31116	Economy	5400.00
0005433439102	31116	Economy	5400.00
0005432329990	31116	Economy	5400.00
0005433439091	31116	Economy	5400.00
0005432329949	31116	Economy	5400.00
0005435488366	6193	Business	124600.00
0005435488474	6193	Economy	41500.00
0005435488391	6193	Economy	41500.00
0005435488425	6193	Economy	41500.00
0005435488428	6193	Economy	41500.00
0005435488434	6193	Economy	41500.00
0005435488424	6193	Economy	41500.00
0005435488367	6193	Economy	41500.00
0005435488475	6193	Economy	41500.00
0005435999810	19536	Business	124600.00
0005435999830	19536	Economy	41500.00
0005435999847	19536	Economy	41500.00
0005434310143	19536	Economy	41500.00
0005435999804	19536	Economy	41500.00
0005434310144	19536	Economy	41500.00
0005435999751	19536	Economy	41500.00
0005435999846	19536	Economy	41500.00
0005435999805	19536	Economy	41500.00
0005435999801	19536	Economy	41500.00
0005434310120	19536	Economy	41500.00
0005435999829	19536	Economy	41500.00
0005435999819	19536	Economy	45700.00
0005435999823	19536	Economy	41500.00
0005435999827	19536	Economy	41500.00
0005434310119	19536	Economy	41500.00
0005435999820	19536	Economy	41500.00
0005435999809	19536	Economy	41500.00
0005435999745	19536	Economy	41500.00
0005435999822	19536	Economy	41500.00
0005434310137	19536	Economy	41500.00
0005435999845	19536	Economy	41500.00
0005435999800	19536	Economy	41500.00
0005434446567	17557	Economy	13600.00
0005434446578	17557	Economy	12300.00
0005434446582	17557	Economy	12300.00
0005434446579	17557	Economy	12300.00
0005434446589	17557	Economy	12300.00
0005433186375	1601	Business	86000.00
0005433186370	1601	Business	86000.00
0005435545914	20871	Business	86000.00
0005435529845	20871	Business	86000.00
0005434566270	20871	Business	86000.00
0005434566305	20871	Business	86000.00
0005435529842	20871	Business	86000.00
0005435502954	20871	Business	86000.00
0005435502939	20871	Business	86000.00
0005435502844	20871	Economy	28700.00
0005434566268	20871	Economy	28700.00
0005435545943	20871	Economy	28700.00
0005435502843	20871	Economy	31500.00
0005435502946	20871	Economy	31500.00
0005435529850	20871	Economy	28700.00
0005435502927	20871	Economy	28700.00
0005435545976	20871	Economy	28700.00
0005435529835	20871	Economy	28700.00
0005435545960	20871	Economy	28700.00
0005435529846	20871	Economy	28700.00
0005435545935	20871	Economy	28700.00
0005435502867	20871	Economy	28700.00
0005435502957	20871	Economy	28700.00
0005435529844	20871	Economy	28700.00
0005435502917	20871	Economy	28700.00
0005434566269	20871	Economy	28700.00
0005434566304	20871	Economy	28700.00
0005435529868	20871	Economy	28700.00
0005435502938	20871	Economy	28700.00
0005435502841	20871	Economy	28700.00
0005435529836	20871	Economy	28700.00
0005435545937	20871	Economy	28700.00
0005435502955	20871	Economy	28700.00
0005435545975	20871	Economy	28700.00
0005435502916	20871	Economy	28700.00
0005435545936	20871	Economy	28700.00
0005435529840	20871	Economy	28700.00
0005435502900	20871	Economy	28700.00
0005435502958	20871	Economy	28700.00
0005435529881	20871	Economy	28700.00
0005435545915	20871	Economy	28700.00
0005435153937	21903	Economy	19700.00
0005435153938	21903	Economy	19700.00
0005435153934	21903	Economy	19700.00
0005435225773	7185	Economy	13000.00
0005435225811	7185	Economy	13000.00
0005432629266	28139	Economy	13000.00
0005432629283	28139	Economy	13000.00
0005432629275	28139	Economy	13000.00
0005432629276	28139	Economy	13000.00
0005432629277	28139	Economy	13000.00
0005432629265	28139	Economy	13000.00
0005432629282	28139	Economy	13000.00
0005434268049	8747	Economy	11500.00
0005432873503	1185	Economy	38300.00
0005432873502	1185	Economy	38300.00
0005432693915	17462	Business	115000.00
0005432693928	17462	Business	115000.00
0005432675583	17462	Economy	38300.00
0005432693948	17462	Economy	38300.00
0005432693879	17462	Economy	42200.00
0005432693971	17462	Economy	42200.00
0005432675577	17462	Economy	38300.00
0005432693966	17462	Economy	38300.00
0005432675570	17462	Economy	38300.00
0005432693929	17462	Economy	38300.00
0005432675572	17462	Economy	38300.00
0005432693947	17462	Economy	38300.00
0005432693967	17462	Economy	38300.00
0005432693876	17462	Economy	38300.00
0005432693935	17462	Economy	38300.00
0005432677686	17462	Economy	38300.00
0005432677687	17462	Economy	38300.00
0005432693930	17462	Economy	38300.00
0005432693934	17462	Economy	38300.00
0005432693936	17462	Economy	38300.00
0005433157008	1099	Economy	13900.00
0005433157005	1099	Economy	13900.00
0005433157009	1099	Economy	13900.00
0005434435638	1099	Economy	13900.00
0005433156995	1099	Economy	13900.00
0005433157002	1099	Economy	13900.00
0005434435629	17319	Economy	13900.00
0005434435612	17319	Economy	13900.00
0005435928274	4100	Economy	7500.00
0005435928272	4100	Economy	7500.00
0005435928273	4100	Economy	7500.00
0005435928281	4100	Economy	7500.00
0005435928282	4100	Economy	7500.00
0005435087058	24417	Economy	7500.00
0005433194962	4861	Business	44200.00
0005435907651	4861	Business	44200.00
0005433194966	4861	Economy	14700.00
0005435907652	4861	Economy	14700.00
0005433194997	4861	Economy	14700.00
0005433194956	4861	Economy	14700.00
0005433194998	4861	Economy	14700.00
0005433194935	4861	Economy	14700.00
0005435907653	4861	Economy	14700.00
0005433194961	4861	Economy	14700.00
0005433194940	4861	Economy	14700.00
0005433194957	4861	Economy	14700.00
0005434626238	32930	Economy	14700.00
0005435786324	13787	Economy	3400.00
0005435786279	13787	Economy	3100.00
0005435786242	13787	Economy	3100.00
0005435786338	13787	Economy	3100.00
0005435786325	13787	Economy	3100.00
0005435786308	13787	Economy	3100.00
0005435786310	13787	Economy	3100.00
0005435786307	13787	Economy	3100.00
0005435786162	13787	Economy	3100.00
0005435786305	13787	Economy	3100.00
0005435786280	13787	Economy	3100.00
0005435786309	13787	Economy	3100.00
0005435786187	13787	Economy	3100.00
0005435786330	13787	Economy	3100.00
0005435786306	13787	Economy	3100.00
0005435937566	27449	Economy	3100.00
0005435937554	27449	Economy	3100.00
0005435937555	27449	Economy	3100.00
0005435937533	27449	Economy	3100.00
0005435937561	27449	Economy	3100.00
0005435937532	27449	Economy	3100.00
0005434409503	20256	Business	12000.00
0005434409565	20256	Economy	4000.00
0005434409612	20256	Economy	4000.00
0005434409563	20256	Economy	4000.00
0005434409603	20256	Economy	4000.00
0005434409409	20256	Economy	4400.00
0005434409383	20256	Economy	4400.00
0005434409535	20256	Economy	4000.00
0005434409532	20256	Economy	4000.00
0005434409465	20256	Economy	4000.00
0005434409502	20256	Economy	4000.00
0005434409578	20256	Economy	4000.00
0005434409408	20256	Economy	4000.00
0005434409576	20256	Economy	4000.00
0005434409474	20256	Economy	4000.00
0005434409562	20256	Economy	4000.00
0005434409575	20256	Economy	4000.00
0005434409566	20256	Economy	4000.00
0005434409564	20256	Economy	4000.00
0005434409604	20256	Economy	4000.00
0005434409561	20256	Economy	4000.00
0005434409574	20256	Economy	4000.00
0005434409606	20256	Economy	4000.00
0005435311492	26964	Business	12000.00
0005435311491	26964	Economy	4000.00
0005435311526	26964	Economy	4000.00
0005435311501	26964	Economy	4400.00
0005435311447	26964	Economy	4000.00
0005435311502	26964	Economy	4000.00
0005435311476	26964	Economy	4000.00
0005435311525	26964	Economy	4000.00
0005433124546	5690	Economy	14400.00
0005433124505	5690	Economy	14400.00
0005433124534	5690	Economy	15900.00
0005435297398	5690	Economy	14400.00
0005433124547	5690	Economy	14400.00
0005433124420	5690	Economy	14400.00
0005433124550	5690	Economy	14400.00
0005433124524	5690	Economy	14400.00
0005433124490	5690	Economy	14400.00
0005433124491	5690	Economy	14400.00
0005433124533	5690	Economy	14400.00
0005433124545	5690	Economy	14400.00
0005433124494	5690	Economy	14400.00
0005433124419	5690	Economy	14400.00
0005435297401	5690	Economy	14400.00
0005433124478	5690	Economy	14400.00
0005435297380	5690	Economy	14400.00
0005433124504	5690	Economy	14400.00
0005433124525	5690	Economy	14400.00
0005434319814	15663	Business	43300.00
0005434312381	15663	Economy	14400.00
0005434319850	15663	Economy	15900.00
0005434319805	15663	Economy	14400.00
0005434319830	15663	Economy	14400.00
0005434319816	15663	Economy	14400.00
0005434319812	15663	Economy	14400.00
0005434310180	15663	Economy	14400.00
0005434319807	15663	Economy	14400.00
0005434319852	15663	Economy	14400.00
0005434319815	15663	Economy	14400.00
0005434319851	15663	Economy	14400.00
0005434312379	15663	Economy	14400.00
0005434319806	15663	Economy	14400.00
0005434319835	15663	Economy	14400.00
0005434319865	15663	Economy	14400.00
0005434311275	15663	Economy	14400.00
0005434319817	15663	Economy	14400.00
0005434319831	15663	Economy	14400.00
0005434310155	15663	Economy	14400.00
0005434312380	15663	Economy	14400.00
0005434319853	15663	Economy	14400.00
0005435903232	8967	Economy	27400.00
0005435903231	8967	Economy	24900.00
0005435903233	8967	Economy	24900.00
0005434189341	8967	Economy	24900.00
0005434484534	16666	Economy	27400.00
0005434484536	16666	Economy	27400.00
0005434484535	16666	Economy	24900.00
0005434484533	16666	Economy	24900.00
0005435477017	7692	Business	11100.00
0005433722464	7692	Business	11100.00
0005433722504	7692	Business	11100.00
0005433722454	7692	Business	11100.00
0005433722426	7692	Economy	3700.00
0005433722480	7692	Economy	3700.00
0005435477016	7692	Economy	3700.00
0005433722465	7692	Economy	4100.00
0005433722466	7692	Economy	3700.00
0005433722479	7692	Economy	3700.00
0005433722492	7692	Economy	3700.00
0005433722445	7692	Economy	3700.00
0005433722494	7692	Economy	3700.00
0005433722446	7692	Economy	3700.00
0005433722431	7692	Economy	3700.00
0005435477020	7692	Economy	3700.00
0005433722478	7692	Economy	3700.00
0005434310155	7692	Economy	3700.00
0005435477023	7692	Economy	3700.00
0005435477019	7692	Economy	3700.00
0005433722493	7692	Economy	3700.00
0005433722489	7692	Economy	3700.00
0005434310180	7692	Economy	3700.00
0005433722483	7692	Economy	3700.00
0005435477018	7692	Economy	3700.00
0005433722502	7692	Economy	3700.00
0005433722490	7692	Economy	3700.00
0005432693936	30370	Business	11100.00
0005433450610	30370	Business	11100.00
0005433450591	30370	Business	11100.00
0005433450587	30370	Economy	3700.00
0005432693879	30370	Economy	3700.00
0005432693915	30370	Economy	4100.00
0005432693930	30370	Economy	4100.00
0005432693967	30370	Economy	3700.00
0005432693934	30370	Economy	3700.00
0005432693876	30370	Economy	3700.00
0005432693929	30370	Economy	3700.00
0005432693971	30370	Economy	3700.00
0005432693948	30370	Economy	3700.00
0005432693928	30370	Economy	3700.00
0005433450566	30370	Economy	3700.00
0005432693966	30370	Economy	3700.00
0005433450568	30370	Economy	3700.00
0005433450599	30370	Economy	3700.00
0005432693947	30370	Economy	3700.00
0005433450593	30370	Economy	3700.00
0005433450609	30370	Economy	3700.00
0005432693935	30370	Economy	3700.00
0005433450567	30370	Economy	3700.00
0005433124504	30371	Business	11100.00
0005433124525	30371	Business	11100.00
0005433124534	30371	Economy	3700.00
0005433124545	30371	Economy	3700.00
0005433124505	30371	Economy	4100.00
0005433124494	30371	Economy	3700.00
0005432721689	30371	Economy	3700.00
0005432721665	30371	Economy	3700.00
0005433124490	30371	Economy	3700.00
0005433124524	30371	Economy	3700.00
0005433124491	30371	Economy	3700.00
0005433124419	30371	Economy	3700.00
0005433124533	30371	Economy	3700.00
0005433124478	30371	Economy	3700.00
0005432721688	30371	Economy	3700.00
0005433124550	30371	Economy	3700.00
0005433124546	30371	Economy	3700.00
0005432721653	30371	Economy	3700.00
0005433124547	30371	Economy	3700.00
0005432721690	30371	Economy	3700.00
0005433124420	30371	Economy	3700.00
0005432968907	1379	Business	70400.00
0005432968906	1379	Economy	23500.00
0005432968909	1379	Economy	23500.00
0005432968908	1379	Economy	23500.00
0005433724939	18552	Business	70400.00
0005433525319	18552	Economy	23500.00
0005433724938	18552	Economy	23500.00
0005433724926	18552	Economy	23500.00
0005434587336	18552	Economy	23500.00
0005434587335	18552	Economy	23500.00
0005433724932	18552	Economy	25800.00
0005433525345	18552	Economy	23500.00
0005433525330	18552	Economy	23500.00
0005433525331	18552	Economy	23500.00
0005434587360	18552	Economy	23500.00
0005434587361	18552	Economy	23500.00
0005434587331	18552	Economy	23500.00
0005433525363	18552	Economy	23500.00
0005434587332	18552	Economy	23500.00
0005433724937	18552	Economy	23500.00
0005435302336	11476	Economy	4300.00
0005435305081	11476	Economy	4300.00
0005435305067	11476	Economy	4000.00
0005435302300	11476	Economy	4000.00
0005435302335	11476	Economy	4000.00
0005435305066	11476	Economy	4000.00
0005434345180	29769	Economy	4300.00
0005434345283	29769	Economy	4000.00
0005434345213	29769	Economy	4000.00
0005434142718	29769	Economy	4000.00
0005434345046	29769	Economy	4000.00
0005434345175	29769	Economy	4000.00
0005434345230	29769	Economy	4000.00
0005434345284	29769	Economy	4000.00
0005434345176	29769	Economy	4000.00
0005434345162	29769	Economy	4000.00
0005434345264	29769	Economy	4000.00
0005434345221	29769	Economy	4000.00
0005434345212	29769	Economy	4000.00
0005434345253	29769	Economy	4000.00
0005434345254	29769	Economy	4000.00
0005434142727	29769	Economy	4000.00
0005434345047	29769	Economy	4000.00
0005434345229	29769	Economy	4000.00
0005433416128	1280	Economy	66600.00
0005435825402	18003	Business	199800.00
0005435825391	18003	Economy	66600.00
0005435825418	18003	Economy	66600.00
0005435825388	18003	Economy	66600.00
0005435825417	18003	Economy	66600.00
0005435825410	18003	Economy	66600.00
0005435825411	18003	Economy	66600.00
0005435825422	18003	Economy	66600.00
0005435825364	18003	Economy	66600.00
0005435825365	18003	Economy	66600.00
0005435825412	18003	Economy	66600.00
0005435825389	18003	Economy	66600.00
0005435825404	18003	Economy	66600.00
0005435825390	18003	Economy	66600.00
0005435243608	5656	Business	27800.00
0005435243629	5656	Economy	9300.00
0005435243640	5656	Economy	9300.00
0005435243644	5656	Economy	10200.00
0005435476978	5656	Economy	9300.00
0005435243655	5656	Economy	9300.00
0005435243609	5656	Economy	9300.00
0005435243557	5656	Economy	9300.00
0005435476998	5656	Economy	9300.00
0005435476997	5656	Economy	9300.00
0005435476977	5656	Economy	9300.00
0005435243606	5656	Economy	9300.00
0005435476982	5656	Economy	9300.00
0005435950016	15381	Business	27800.00
0005435950037	15381	Business	27800.00
0005432785303	15381	Economy	9300.00
0005432785347	15381	Economy	9300.00
0005432785333	15381	Economy	9300.00
0005432785301	15381	Economy	10200.00
0005432785349	15381	Economy	10200.00
0005435949991	15381	Economy	9300.00
0005432785330	15381	Economy	9300.00
0005435950015	15381	Economy	9300.00
0005432785321	15381	Economy	9300.00
0005432785292	15381	Economy	9300.00
0005435950036	15381	Economy	9300.00
0005432785223	15381	Economy	9300.00
0005432785291	15381	Economy	9300.00
0005432785257	15381	Economy	9300.00
0005432785343	15381	Economy	9300.00
0005432785329	15381	Economy	9300.00
0005432785365	15381	Economy	9300.00
0005432785282	15381	Economy	9300.00
0005432785364	15381	Economy	9300.00
0005432785284	15381	Economy	9300.00
0005432785283	15381	Economy	9300.00
0005435949992	15381	Economy	9300.00
0005432785322	15381	Economy	9300.00
0005432785344	15381	Economy	9300.00
0005435950012	15381	Economy	9300.00
0005435851164	4393	Economy	6300.00
0005435851163	4393	Economy	6300.00
0005434461710	28882	Economy	6300.00
0005434461709	28882	Economy	6300.00
0005434444174	20417	Business	11900.00
0005434926841	20417	Business	11900.00
0005434444170	20417	Business	11900.00
0005434926804	20417	Business	11900.00
0005434444167	20417	Economy	4000.00
0005434926632	20417	Economy	4000.00
0005434926817	20417	Economy	4000.00
0005434926801	20417	Economy	4400.00
0005434926812	20417	Economy	4400.00
0005434926829	20417	Economy	4000.00
0005434444182	20417	Economy	4000.00
0005433497867	20417	Economy	4000.00
0005434926842	20417	Economy	4000.00
0005434926811	20417	Economy	4000.00
0005434444172	20417	Economy	4000.00
0005434926836	20417	Economy	4000.00
0005434926834	20417	Economy	4000.00
0005433497884	20417	Economy	4000.00
0005434926833	20417	Economy	4000.00
0005434444169	20417	Economy	4000.00
0005434926802	20417	Economy	4000.00
0005434926631	20417	Economy	4000.00
0005433497883	20417	Economy	4000.00
0005434926605	20417	Economy	4000.00
0005434444173	20417	Economy	4000.00
0005434926593	20417	Economy	4000.00
0005433497889	20417	Economy	4000.00
0005434444171	20417	Economy	4000.00
0005434926859	20417	Economy	4000.00
0005433497888	20417	Economy	4000.00
0005434926805	20417	Economy	4000.00
0005434926803	20417	Economy	4000.00
0005434444168	20417	Economy	4000.00
0005434926839	20417	Economy	4000.00
0005434926837	20417	Economy	4000.00
0005433497868	20417	Economy	4000.00
0005434926725	20417	Economy	4000.00
0005433497891	20417	Economy	4000.00
0005434926835	20417	Economy	4000.00
0005434926592	20417	Economy	4000.00
0005434926756	20417	Economy	4000.00
0005434444183	20417	Economy	4000.00
0005434926783	20417	Economy	4000.00
0005432785368	12187	Business	41200.00
0005432785354	12187	Economy	13700.00
0005432785304	12187	Economy	15100.00
0005432785185	12187	Economy	13700.00
0005432785331	12187	Economy	13700.00
0005432785336	12187	Economy	13700.00
0005432785332	12187	Economy	13700.00
0005432785358	12187	Economy	13700.00
0005432785367	12187	Economy	13700.00
0005432785339	12187	Economy	13700.00
0005432785345	12187	Economy	13700.00
0005432785340	12187	Economy	13700.00
0005435243596	15411	Business	41200.00
0005435243569	15411	Business	41200.00
0005435243590	15411	Economy	13700.00
0005435243615	15411	Economy	13700.00
0005435243618	15411	Economy	13700.00
0005435243589	15411	Economy	13700.00
0005435243637	15411	Economy	13700.00
0005435243599	15411	Economy	13700.00
0005435243532	15411	Economy	13700.00
0005435243621	15411	Economy	13700.00
0005435243616	15411	Economy	13700.00
0005435243534	15411	Economy	13700.00
0005435243556	15411	Economy	13700.00
0005435243598	15411	Economy	13700.00
0005434880807	10118	Business	49700.00
0005434880864	10118	Business	49700.00
0005434880934	10118	Economy	16600.00
0005434880797	10118	Economy	16600.00
0005434880834	10118	Economy	18200.00
0005434880771	10118	Economy	18200.00
0005434880933	10118	Economy	16600.00
0005434880932	10118	Economy	16600.00
0005434880917	10118	Economy	16600.00
0005434880806	10118	Economy	16600.00
0005434880845	10118	Economy	16600.00
0005434880519	10118	Economy	16600.00
0005434880790	10118	Economy	16600.00
0005434880772	10118	Economy	16600.00
0005434880848	10118	Economy	16600.00
0005434880632	10118	Economy	16600.00
0005434880931	10118	Economy	16600.00
0005434880521	10118	Economy	16600.00
0005434880844	10118	Economy	16600.00
0005434880520	10118	Economy	16600.00
0005434880936	10118	Economy	16600.00
0005434880950	10118	Economy	16600.00
0005434880941	10118	Economy	16600.00
0005434880770	10118	Economy	16600.00
0005434880966	10118	Economy	16600.00
0005435914164	14643	Business	49700.00
0005435914165	14643	Business	49700.00
0005435914130	14643	Business	49700.00
0005435914189	14643	Business	49700.00
0005435914131	14643	Economy	16600.00
0005435933577	9257	Economy	22400.00
0005434252238	9257	Economy	20300.00
0005434252219	9257	Economy	20300.00
0005434252243	9257	Economy	20300.00
0005434252220	9257	Economy	20300.00
0005435933557	9257	Economy	20300.00
0005434252244	9257	Economy	20300.00
0005435660465	24668	Economy	20300.00
0005435660460	24668	Economy	20300.00
0005435660407	24668	Economy	20300.00
0005435660411	24668	Economy	20300.00
0005435660451	24668	Economy	20300.00
0005435660461	24668	Economy	20300.00
0005435660463	24668	Economy	20300.00
0005435660410	24668	Economy	20300.00
0005435660462	24668	Economy	20300.00
0005432967683	2775	Business	33000.00
0005432967656	2775	Business	33000.00
0005432967682	2775	Economy	12100.00
0005432967672	2775	Economy	11000.00
0005432967620	2775	Economy	11000.00
0005432967630	2775	Economy	11000.00
0005432967681	2775	Economy	11000.00
0005432967640	2775	Economy	11000.00
0005432967661	2775	Economy	11000.00
0005432967660	2775	Economy	11000.00
0005433681875	29188	Business	33000.00
0005433681955	29188	Business	33000.00
0005433681924	29188	Business	33000.00
0005433681978	29188	Business	33000.00
0005433681963	29188	Business	33000.00
0005433681866	29188	Economy	12100.00
0005433681969	29188	Economy	11000.00
0005433681903	29188	Economy	11000.00
0005433681946	29188	Economy	11000.00
0005433681876	29188	Economy	11000.00
0005433681979	29188	Economy	11000.00
0005433681902	29188	Economy	11000.00
0005433681951	29188	Economy	11000.00
0005433681966	29188	Economy	11000.00
0005433681968	29188	Economy	11000.00
0005433681905	29188	Economy	11000.00
0005433681904	29188	Economy	11000.00
0005433681944	29188	Economy	11000.00
0005433681965	29188	Economy	11000.00
0005434272238	9288	Business	132900.00
0005434269160	9288	Business	132900.00
0005434163887	9288	Economy	44300.00
0005434269163	9288	Economy	44300.00
0005434163882	9288	Economy	44300.00
0005434272237	9288	Economy	44300.00
0005434163875	9288	Economy	44300.00
0005434163884	9288	Economy	44300.00
0005434163867	9288	Economy	44300.00
0005434272236	9288	Economy	44300.00
0005434153584	9288	Economy	44300.00
0005434163874	9288	Economy	44300.00
0005434269164	9288	Economy	44300.00
0005434163883	9288	Economy	44300.00
0005435856362	9288	Economy	44300.00
0005432755146	25257	Business	132900.00
0005433634794	25257	Business	132900.00
0005433634796	25257	Business	132900.00
0005432755157	25257	Business	132900.00
0005433634788	25257	Business	132900.00
0005433616811	25257	Business	132900.00
0005435983703	25257	Business	132900.00
0005432755164	25257	Business	132900.00
0005433616726	25257	Economy	48700.00
0005433634819	25257	Economy	44300.00
0005433616659	25257	Economy	44300.00
0005433616695	25257	Economy	44300.00
0005433616737	25257	Economy	44300.00
0005433616740	25257	Economy	44300.00
0005433634811	25257	Economy	44300.00
0005433634818	25257	Economy	44300.00
0005433616704	25257	Economy	44300.00
0005432755159	25257	Economy	44300.00
0005433616777	25257	Economy	44300.00
0005433634820	25257	Economy	44300.00
0005433616524	25257	Economy	44300.00
0005432755163	25257	Economy	44300.00
0005433616732	25257	Economy	44300.00
0005432751611	25257	Economy	44300.00
0005432755158	25257	Economy	44300.00
0005433616733	25257	Economy	44300.00
0005433634810	25257	Economy	44300.00
0005433616827	25257	Economy	44300.00
0005433616715	25257	Economy	44300.00
0005432751612	25257	Economy	44300.00
0005433634817	25257	Economy	44300.00
0005433616537	25257	Economy	44300.00
0005433616806	25257	Economy	44300.00
0005433634647	25257	Economy	48700.00
0005432755147	25257	Economy	48700.00
0005432751618	25257	Economy	48700.00
0005433634712	25257	Economy	48700.00
0005432755167	25257	Economy	44300.00
0005433616642	25257	Economy	44300.00
0005433634785	25257	Economy	44300.00
0005433634776	25257	Economy	44300.00
0005432755161	25257	Economy	44300.00
0005432751616	25257	Economy	44300.00
0005432755145	25257	Economy	44300.00
0005433634809	25257	Economy	44300.00
0005432755166	25257	Economy	44300.00
0005433634775	25257	Economy	44300.00
0005433616758	25257	Economy	44300.00
0005432755154	25257	Economy	44300.00
0005433634789	25257	Economy	44300.00
0005432755165	25257	Economy	44300.00
0005433616778	25257	Economy	44300.00
0005433616694	25257	Economy	44300.00
0005433616805	25257	Economy	44300.00
0005432751613	25257	Economy	44300.00
0005435947681	4197	Business	193100.00
0005435947683	4197	Business	193100.00
0005435947680	4197	Business	193100.00
0005435947677	4197	Business	193100.00
0005435477026	4197	Economy	64400.00
0005435947682	4197	Economy	64400.00
0005435947676	4197	Economy	64400.00
0005435477014	4197	Economy	64400.00
0005435947678	4197	Economy	64400.00
0005435787405	4197	Economy	64400.00
0005435477013	4197	Economy	64400.00
0005435787406	4197	Economy	64400.00
0005435477027	4197	Economy	64400.00
0005435987048	26566	Business	193100.00
0005435987031	26566	Business	193100.00
0005435987057	26566	Business	193100.00
0005435986928	26566	Economy	64400.00
0005435987027	26566	Economy	64400.00
0005435987052	26566	Economy	64400.00
0005435960173	26566	Economy	64400.00
0005435987041	26566	Economy	64400.00
0005435987025	26566	Economy	64400.00
0005435986930	26566	Economy	64400.00
0005435960171	26566	Economy	64400.00
0005435987033	26566	Economy	64400.00
0005435986929	26566	Economy	64400.00
0005435987047	26566	Economy	64400.00
0005435987007	26566	Economy	64400.00
0005435987026	26566	Economy	64400.00
0005435987000	26566	Economy	64400.00
0005435960172	26566	Economy	64400.00
0005435987046	26566	Economy	64400.00
0005435987051	26566	Economy	64400.00
0005435987006	26566	Economy	64400.00
0005435987028	26566	Economy	64400.00
0005435987024	26566	Economy	64400.00
0005435987036	26566	Economy	64400.00
0005435987040	26566	Economy	64400.00
0005435987032	26566	Economy	64400.00
0005435987001	26566	Economy	64400.00
0005435987056	26566	Economy	64400.00
0005433075513	314	Business	21500.00
0005433075529	314	Business	21500.00
0005433129404	314	Business	21500.00
0005432949648	314	Business	21500.00
0005432949608	314	Business	21500.00
0005432949542	314	Economy	7900.00
0005432949649	314	Economy	7200.00
0005433075543	314	Economy	7200.00
0005432949503	314	Economy	7200.00
0005432949675	314	Economy	7200.00
0005432949543	314	Economy	7200.00
0005432949544	314	Economy	7200.00
0005432949689	314	Economy	7200.00
0005432949644	314	Economy	7200.00
0005432949686	314	Economy	7200.00
0005432949674	314	Economy	7200.00
0005433075533	314	Economy	7200.00
0005433075534	314	Economy	7200.00
0005433075524	314	Economy	7200.00
0005433075525	314	Economy	7200.00
0005432949661	314	Economy	7200.00
0005433075531	314	Economy	7200.00
0005433075544	314	Economy	7200.00
0005432949624	314	Economy	7900.00
0005433134263	314	Economy	7900.00
0005432949694	314	Economy	7200.00
0005432949626	314	Economy	7200.00
0005432949553	314	Economy	7200.00
0005432949673	314	Economy	7200.00
0005433075492	314	Economy	7200.00
0005432949578	314	Economy	7200.00
0005432949560	314	Economy	7200.00
0005433075488	314	Economy	7200.00
0005433075542	314	Economy	7200.00
0005433129398	314	Economy	7200.00
0005432949690	314	Economy	7200.00
0005433075491	314	Economy	7200.00
0005433075512	314	Economy	7200.00
0005432949687	314	Economy	7200.00
0005433075487	314	Economy	7200.00
0005433075530	314	Economy	7200.00
0005433075549	314	Economy	7200.00
0005432949625	314	Economy	7200.00
0005433570898	11587	Business	21500.00
0005433570860	11587	Business	21500.00
0005433570962	11587	Business	21500.00
0005433570856	11587	Business	21500.00
0005433570694	11587	Business	21500.00
0005433570877	11587	Business	21500.00
0005433570661	11587	Business	21500.00
0005434088044	11587	Business	21500.00
0005433570945	11587	Business	21500.00
0005434326037	11587	Business	21500.00
0005433570955	11587	Economy	7200.00
0005433570759	11587	Economy	7200.00
0005433570944	11587	Economy	7200.00
0005433570936	11587	Economy	7200.00
0005433570807	11587	Economy	7200.00
0005433570806	11587	Economy	7200.00
0005433570812	11587	Economy	7200.00
0005433570880	11587	Economy	7200.00
0005434087981	11587	Economy	7200.00
0005433570821	11587	Economy	7200.00
0005433570512	11587	Economy	7200.00
0005433570841	11587	Economy	7200.00
0005434088007	11587	Economy	7200.00
0005433570891	11587	Economy	7900.00
0005433570808	11587	Economy	7200.00
0005434326012	11587	Economy	7200.00
0005433570943	11587	Economy	7200.00
0005433570619	11587	Economy	7200.00
0005433570833	11587	Economy	7200.00
0005433570739	11587	Economy	7200.00
0005434087998	11587	Economy	7200.00
0005433570822	11587	Economy	7200.00
0005433570746	11587	Economy	7200.00
0005433570875	11587	Economy	7200.00
0005433570740	11587	Economy	7200.00
0005434088000	11587	Economy	7200.00
0005434088038	11587	Economy	7200.00
0005433570842	11587	Economy	7200.00
0005433570758	11587	Economy	7200.00
0005433570847	11587	Economy	7200.00
0005434088037	11587	Economy	7200.00
0005433570511	11587	Economy	7200.00
0005434733085	9966	Economy	6300.00
0005433817576	13890	Economy	6300.00
0005433817577	13890	Economy	6300.00
0005433817573	13890	Economy	6300.00
0005433817575	13890	Economy	6300.00
0005432985968	2377	Business	184500.00
0005433435498	2377	Business	184500.00
0005433435495	2377	Business	184500.00
0005432986000	2377	Business	184500.00
0005432985952	2377	Economy	67700.00
0005432986005	2377	Economy	61500.00
0005432985996	2377	Economy	61500.00
0005433435506	2377	Economy	61500.00
0005432985949	2377	Economy	61500.00
0005432985967	2377	Economy	61500.00
0005433435488	2377	Economy	61500.00
0005433435497	2377	Economy	61500.00
0005432869703	2377	Economy	61500.00
0005432869717	2377	Economy	61500.00
0005433435507	2377	Economy	61500.00
0005432985999	2377	Economy	61500.00
0005432985951	2377	Economy	61500.00
0005433435452	2377	Economy	67700.00
0005432985995	2377	Economy	61500.00
0005432869718	2377	Economy	61500.00
0005433435468	2377	Economy	61500.00
0005433435458	2377	Economy	61500.00
0005433435496	2377	Economy	61500.00
0005432985950	2377	Economy	61500.00
0005432655875	26215	Business	184500.00
0005435983650	26215	Business	184500.00
0005435983664	26215	Business	184500.00
0005432655882	26215	Business	184500.00
0005432655876	26215	Business	184500.00
0005435983424	26215	Economy	61500.00
0005433755843	26215	Economy	61500.00
0005433755842	26215	Economy	61500.00
0005432655889	26215	Economy	61500.00
0005433755860	26215	Economy	61500.00
0005433755873	26215	Economy	61500.00
0005432655858	26215	Economy	61500.00
0005433755648	26215	Economy	61500.00
0005432655890	26215	Economy	61500.00
0005435983665	26215	Economy	61500.00
0005433766753	26215	Economy	61500.00
0005433755841	26215	Economy	61500.00
0005433755831	26215	Economy	61500.00
0005432655888	26215	Economy	61500.00
0005432655887	26215	Economy	61500.00
0005435983617	26215	Economy	61500.00
0005435983616	26215	Economy	61500.00
0005435983425	26215	Economy	61500.00
0005435983653	26215	Economy	61500.00
0005435983619	26215	Economy	61500.00
0005433755807	26215	Economy	61500.00
0005435983618	26215	Economy	61500.00
0005433755757	26215	Economy	67700.00
0005433755858	26215	Economy	61500.00
0005435983620	26215	Economy	61500.00
0005433755859	26215	Economy	61500.00
0005433755647	26215	Economy	61500.00
0005435983595	26215	Economy	61500.00
0005435983592	26215	Economy	61500.00
0005435983567	26215	Economy	61500.00
0005435983638	26215	Economy	61500.00
0005435983673	26215	Economy	61500.00
0005434029726	1520	Economy	13000.00
0005433152412	1520	Economy	13000.00
0005433152413	1520	Economy	13000.00
0005433152393	1520	Economy	14300.00
0005433152364	1520	Economy	13000.00
0005433152384	1520	Economy	13000.00
0005433931554	1520	Economy	13000.00
0005433152363	1520	Economy	13000.00
0005434375969	20118	Business	38900.00
0005434376235	20118	Business	38900.00
0005434375914	20118	Business	38900.00
0005434376033	20118	Business	38900.00
0005434376178	20118	Economy	13000.00
0005434376191	20118	Economy	13000.00
0005434376046	20118	Economy	13000.00
0005434376058	20118	Economy	13000.00
0005434375947	20118	Economy	13000.00
0005434375840	20118	Economy	13000.00
0005434376025	20118	Economy	14300.00
0005434375970	20118	Economy	14300.00
0005434375946	20118	Economy	13000.00
0005434376007	20118	Economy	13000.00
0005434376032	20118	Economy	13000.00
0005434376035	20118	Economy	13000.00
0005434376188	20118	Economy	13000.00
0005434376037	20118	Economy	13000.00
0005434376057	20118	Economy	13000.00
0005434375838	20118	Economy	13000.00
0005434376036	20118	Economy	13000.00
0005434375944	20118	Economy	13000.00
0005434375964	20118	Economy	13000.00
0005434376016	20118	Economy	13000.00
0005434376047	20118	Economy	13000.00
0005434376179	20118	Economy	13000.00
0005434376045	20118	Economy	13000.00
0005434375965	20118	Economy	13000.00
0005434376014	20118	Economy	13000.00
0005433262052	497	Business	27500.00
0005433262039	497	Economy	9200.00
0005433262038	497	Economy	9200.00
0005433262017	497	Economy	9200.00
0005433766761	497	Economy	9200.00
0005433262022	497	Economy	9200.00
0005433262053	497	Economy	9200.00
0005434446589	12917	Business	27500.00
0005434995381	12917	Economy	9200.00
0005434995369	12917	Economy	9200.00
0005434995367	12917	Economy	9200.00
0005434446582	12917	Economy	9200.00
0005434446567	12917	Economy	9200.00
0005434446578	12917	Economy	9200.00
0005434995368	12917	Economy	9200.00
0005434446579	12917	Economy	9200.00
0005432426037	12916	Business	27500.00
0005432425993	12916	Business	27500.00
0005432425821	12916	Business	27500.00
0005432426009	12916	Business	27500.00
0005432425887	12916	Business	27500.00
0005432425960	12916	Business	27500.00
0005432425987	12916	Business	27500.00
0005432426073	12916	Business	27500.00
0005432425962	12916	Business	27500.00
0005432425881	12916	Business	27500.00
0005432426044	12916	Business	27500.00
0005432425907	12916	Business	27500.00
0005432426016	12916	Economy	10100.00
0005432426067	12916	Economy	10100.00
0005432425959	12916	Economy	10100.00
0005432425967	12916	Economy	9200.00
0005432425825	12916	Economy	9200.00
0005432426045	12916	Economy	9200.00
0005432425985	12916	Economy	9200.00
0005432425981	12916	Economy	9200.00
0005432425963	12916	Economy	9200.00
0005432425826	12916	Economy	9200.00
0005432425957	12916	Economy	9200.00
0005432425527	12916	Economy	9200.00
0005432425843	12916	Economy	9200.00
0005432426010	12916	Economy	9200.00
0005432425905	12916	Economy	9200.00
0005432425892	12916	Economy	9200.00
0005432426072	12916	Economy	9200.00
0005432425970	12916	Economy	10100.00
0005432425965	12916	Economy	10100.00
0005432426004	12916	Economy	10100.00
0005432425910	12916	Economy	10100.00
0005432425890	12916	Economy	9200.00
0005432425738	12916	Economy	9200.00
0005432426038	12916	Economy	9200.00
0005432425961	12916	Economy	9200.00
0005432425954	12916	Economy	9200.00
0005432425872	12916	Economy	9200.00
0005432425966	12916	Economy	9200.00
0005432425528	12916	Economy	9200.00
0005432425906	12916	Economy	9200.00
0005432425989	12916	Economy	9200.00
0005432425886	12916	Economy	9200.00
0005432425942	12916	Economy	9200.00
0005432425810	12916	Economy	9200.00
0005432426005	12916	Economy	9200.00
0005432425911	12916	Economy	9200.00
0005432425986	12916	Economy	9200.00
0005432426048	12916	Economy	9200.00
0005432426029	12916	Economy	9200.00
0005433059028	457	Business	24500.00
0005433059054	457	Economy	9000.00
0005433929725	457	Economy	8200.00
0005433059035	457	Economy	8200.00
0005434735838	457	Economy	8200.00
0005433059051	457	Economy	8200.00
0005433059029	457	Economy	8200.00
0005433058928	457	Economy	8200.00
0005434735828	457	Economy	8200.00
0005433059048	457	Economy	8200.00
0005433059033	457	Economy	8200.00
0005434735815	457	Economy	8200.00
0005434735817	457	Economy	9000.00
0005434735816	457	Economy	9000.00
0005433059055	457	Economy	8200.00
0005433059018	457	Economy	8200.00
0005433929719	457	Economy	8200.00
0005433059050	457	Economy	8200.00
0005434735814	457	Economy	8200.00
0005433059034	457	Economy	8200.00
0005433059049	457	Economy	8200.00
0005434735827	457	Economy	8200.00
0005434735818	457	Economy	8200.00
0005433059065	457	Economy	8200.00
0005434025694	12675	Business	24500.00
0005434025668	12675	Business	24500.00
0005434025687	12675	Business	24500.00
0005434025658	12675	Economy	9000.00
0005434025575	12675	Economy	8200.00
0005434025574	12675	Economy	8200.00
0005434029726	12675	Economy	8200.00
0005434025686	12675	Economy	8200.00
0005434025506	12675	Economy	8200.00
0005434025691	12675	Economy	8200.00
0005434025450	12675	Economy	8200.00
0005434025695	12675	Economy	8200.00
0005434025220	12675	Economy	9000.00
0005434028398	12675	Economy	8200.00
0005434025698	12675	Economy	8200.00
0005434025221	12675	Economy	8200.00
0005434025509	12675	Economy	8200.00
0005434025612	12675	Economy	8200.00
0005434025614	12675	Economy	8200.00
0005433529386	32450	Business	111600.00
0005433533418	32450	Economy	37200.00
0005433533421	32450	Economy	37200.00
0005433529373	32450	Economy	37200.00
0005433529385	32450	Economy	37200.00
0005433529387	32450	Economy	37200.00
0005433529379	32450	Economy	37200.00
0005433533422	32450	Economy	37200.00
0005433529380	32450	Economy	37200.00
0005433533405	32450	Economy	37200.00
0005433529374	32450	Economy	37200.00
0005433529382	32450	Economy	37200.00
0005433529362	32450	Economy	37200.00
0005433529381	32450	Economy	37200.00
0005433529364	32450	Economy	37200.00
0005433529383	32450	Economy	37200.00
0005433529363	32450	Economy	37200.00
0005433037787	2155	Business	34700.00
0005433037808	2155	Business	34700.00
0005433037753	2155	Business	34700.00
0005434376178	2155	Business	34700.00
0005433037785	2155	Business	34700.00
0005433037766	2155	Business	34700.00
0005433037726	2155	Economy	11600.00
0005434088059	2155	Economy	11600.00
0005433037800	2155	Economy	11600.00
0005434175878	2155	Economy	11600.00
0005433037758	2155	Economy	11600.00
0005433037841	2155	Economy	11600.00
0005434376191	2155	Economy	11600.00
0005433037820	2155	Economy	11600.00
0005433037728	2155	Economy	11600.00
0005433037821	2155	Economy	11600.00
0005434376179	2155	Economy	11600.00
0005433037804	2155	Economy	11600.00
0005433037822	2155	Economy	11600.00
0005433037802	2155	Economy	11600.00
0005434175880	2155	Economy	12700.00
0005433037840	2155	Economy	12700.00
0005434175879	2155	Economy	12700.00
0005433037786	2155	Economy	11600.00
0005434088060	2155	Economy	11600.00
0005433037788	2155	Economy	11600.00
0005433037831	2155	Economy	11600.00
0005433037628	2155	Economy	11600.00
0005433037770	2155	Economy	11600.00
0005433037752	2155	Economy	11600.00
0005433037727	2155	Economy	11600.00
0005433037847	2155	Economy	11600.00
0005434376188	2155	Economy	11600.00
0005433037836	2155	Economy	11600.00
0005433926027	24133	Business	34700.00
0005433875428	24133	Business	34700.00
0005433925918	24133	Business	34700.00
0005433875427	24133	Economy	11600.00
0005433925827	24133	Economy	11600.00
0005433925872	24133	Economy	11600.00
0005433929877	24133	Economy	11600.00
0005433875429	24133	Economy	11600.00
0005433925873	24133	Economy	11600.00
0005433929886	24133	Economy	11600.00
0005433925917	24133	Economy	11600.00
0005433925907	24133	Economy	11600.00
0005433926098	24133	Economy	11600.00
0005433929878	24133	Economy	12700.00
0005433925931	24133	Economy	11600.00
0005433926028	24133	Economy	11600.00
0005433926030	24133	Economy	11600.00
0005433926067	24133	Economy	11600.00
0005433925916	24133	Economy	11600.00
0005433926066	24133	Economy	11600.00
0005433925892	24133	Economy	11600.00
0005433925806	24133	Economy	11600.00
0005433926029	24133	Economy	11600.00
0005433926090	24133	Economy	11600.00
0005433926065	24133	Economy	11600.00
0005433925979	24133	Economy	11600.00
0005433181827	291	Business	83700.00
0005433235895	291	Business	83700.00
0005433235959	291	Business	83700.00
0005433235968	291	Comfort	47400.00
0005433126971	291	Comfort	47400.00
0005433236039	291	Comfort	47400.00
0005433181766	291	Economy	27900.00
0005433235916	291	Economy	27900.00
0005433181750	291	Economy	27900.00
0005433235995	291	Economy	27900.00
0005433236019	291	Economy	27900.00
0005433181826	291	Economy	27900.00
0005433236048	291	Economy	30700.00
0005433235990	291	Economy	27900.00
0005433126981	291	Economy	30700.00
0005433126963	291	Economy	27900.00
0005433113598	291	Economy	27900.00
0005433236053	291	Economy	27900.00
0005433235961	291	Economy	27900.00
0005433131840	291	Economy	27900.00
0005433235994	291	Economy	27900.00
0005433235960	291	Economy	27900.00
0005433235983	291	Economy	27900.00
0005434032150	291	Economy	27900.00
0005433131839	291	Economy	27900.00
0005433126980	291	Economy	30700.00
0005433235925	291	Economy	27900.00
0005433236018	291	Economy	27900.00
0005433181807	291	Economy	27900.00
0005433235790	291	Economy	27900.00
0005433766750	291	Economy	27900.00
0005433181806	291	Economy	27900.00
0005433235887	291	Economy	27900.00
0005433236036	291	Economy	27900.00
0005433236015	291	Economy	27900.00
0005433290065	291	Economy	27900.00
0005434728993	9876	Business	83700.00
0005434302570	9876	Business	83700.00
0005434728865	9876	Business	83700.00
0005434729030	9876	Business	83700.00
0005434728895	9876	Business	83700.00
0005434729031	9876	Business	83700.00
0005434552697	9876	Business	83700.00
0005434728892	9876	Comfort	47400.00
0005434552828	9876	Comfort	47400.00
0005434552783	9876	Comfort	47400.00
0005434552823	9876	Comfort	47400.00
0005434728891	9876	Comfort	47400.00
0005434302574	9876	Comfort	47400.00
0005435142944	9876	Comfort	47400.00
0005434728687	9876	Comfort	47400.00
0005434552675	9876	Economy	27900.00
0005435142960	9876	Economy	27900.00
0005434729026	9876	Economy	27900.00
0005434552723	9876	Economy	27900.00
0005434728706	9876	Economy	27900.00
0005434552679	9876	Economy	27900.00
0005434729019	9876	Economy	27900.00
0005434552779	9876	Economy	27900.00
0005434728673	9876	Economy	27900.00
0005434728970	9876	Economy	27900.00
0005434728950	9876	Economy	27900.00
0005434728857	9876	Economy	27900.00
0005434735823	9876	Economy	27900.00
0005435142964	9876	Economy	27900.00
0005434552808	9876	Economy	27900.00
0005434552824	9876	Economy	27900.00
0005434728854	9876	Economy	30700.00
0005435142945	9876	Economy	27900.00
0005434728988	9876	Economy	27900.00
0005434552778	9876	Economy	27900.00
0005434552747	9876	Economy	27900.00
0005434728986	9876	Economy	27900.00
0005434552812	9876	Economy	27900.00
0005434728894	9876	Economy	27900.00
0005434552744	9876	Economy	27900.00
0005434728969	9876	Economy	27900.00
0005434728874	9876	Economy	27900.00
0005434728875	9876	Economy	27900.00
0005434728688	9876	Economy	27900.00
0005434728989	9876	Economy	27900.00
0005434728893	9876	Economy	27900.00
0005434728908	9876	Economy	27900.00
0005434728992	9876	Economy	27900.00
0005434552813	9876	Economy	27900.00
0005434728949	9876	Economy	27900.00
0005434552724	9876	Economy	27900.00
0005434728782	9876	Economy	27900.00
0005434729027	9876	Economy	27900.00
0005434728784	9876	Economy	27900.00
0005434302571	9876	Economy	27900.00
0005434728890	9876	Economy	27900.00
0005434552780	9876	Economy	27900.00
0005434728664	9876	Economy	27900.00
0005434728781	9876	Economy	27900.00
0005434552811	9876	Economy	27900.00
0005434552829	9876	Economy	27900.00
0005434552790	9876	Economy	30700.00
0005434728864	9876	Economy	30700.00
0005434728998	9876	Economy	27900.00
0005434728947	9876	Economy	27900.00
0005434552830	9876	Economy	27900.00
0005434552819	9876	Economy	27900.00
0005434729009	9876	Economy	27900.00
0005434728785	9876	Economy	27900.00
0005434729046	9876	Economy	27900.00
0005434552809	9876	Economy	27900.00
0005434552692	9876	Economy	27900.00
0005434735835	9876	Economy	27900.00
0005434552810	9876	Economy	27900.00
0005435142959	9876	Economy	27900.00
0005434728663	9876	Economy	27900.00
0005434552676	9876	Economy	27900.00
0005434552791	9876	Economy	27900.00
0005434729018	9876	Economy	27900.00
0005434729010	9876	Economy	27900.00
0005434552680	9876	Economy	27900.00
0005434729028	9876	Economy	27900.00
0005434552807	9876	Economy	27900.00
0005434728783	9876	Economy	27900.00
0005434552825	9876	Economy	27900.00
0005435142961	9876	Economy	27900.00
0005434728689	9876	Economy	27900.00
0005435142948	9876	Economy	27900.00
0005433656758	7750	Economy	14000.00
0005435283551	7750	Economy	15400.00
0005435215493	7750	Economy	14000.00
0005433656759	7750	Economy	14000.00
0005435725740	7750	Economy	14000.00
0005435215392	7750	Economy	14000.00
0005435215446	7750	Economy	14000.00
0005435215447	7750	Economy	14000.00
0005435215400	7750	Economy	14000.00
0005435215532	7750	Economy	14000.00
0005435215529	7750	Economy	14000.00
0005435215346	7750	Economy	14000.00
0005435215332	7750	Economy	14000.00
0005435215430	7750	Economy	15400.00
0005435215487	7750	Economy	14000.00
0005433656767	7750	Economy	14000.00
0005435215486	7750	Economy	14000.00
0005433656766	7750	Economy	14000.00
0005435215388	7750	Economy	14000.00
0005435215401	7750	Economy	14000.00
0005435215485	7750	Economy	14000.00
0005435215333	7750	Economy	14000.00
0005435215331	7750	Economy	14000.00
0005435426803	5326	Business	43100.00
0005435426849	5326	Business	43100.00
0005434245826	5326	Business	43100.00
0005433719232	5326	Comfort	24400.00
0005434245840	5326	Comfort	24400.00
0005435380435	5326	Economy	14400.00
0005435426792	5326	Economy	14400.00
0005433719230	5326	Economy	14400.00
0005434245789	5326	Economy	15800.00
0005434245790	5326	Economy	14400.00
0005435380434	5326	Economy	14400.00
0005434656613	5326	Economy	14400.00
0005435319804	5326	Economy	14400.00
0005434245825	5326	Economy	14400.00
0005435426739	5326	Economy	14400.00
0005435426785	5326	Economy	14400.00
0005435319828	5326	Economy	14400.00
0005432363512	5326	Economy	14400.00
0005435426750	5326	Economy	14400.00
0005435426815	5326	Economy	14400.00
0005434656615	5326	Economy	14400.00
0005435426767	5326	Economy	14400.00
0005435426843	5326	Economy	14400.00
0005432363509	5326	Economy	14400.00
0005435426793	5326	Economy	14400.00
0005434245832	5326	Economy	14400.00
0005434245831	5326	Economy	14400.00
0005435426768	5326	Economy	14400.00
0005434656614	5326	Economy	14400.00
0005435319805	5326	Economy	14400.00
0005435426755	5326	Economy	14400.00
0005435616809	10883	Business	43100.00
0005435616707	10883	Business	43100.00
0005435616508	10883	Business	43100.00
0005435616510	10883	Business	43100.00
0005435097475	10883	Business	43100.00
0005435616405	10883	Comfort	24400.00
0005434345187	10883	Comfort	24400.00
0005434573717	10883	Comfort	24400.00
0005435616837	10883	Comfort	24400.00
0005435616789	10883	Comfort	24400.00
0005435616482	10883	Comfort	24400.00
0005434345274	10883	Comfort	24400.00
0005434345192	10883	Comfort	24400.00
0005435616943	10883	Comfort	24400.00
0005435616829	10883	Comfort	24400.00
0005435616933	10883	Comfort	24400.00
0005435617043	10883	Comfort	24400.00
0005435616994	10883	Comfort	24400.00
0005434345188	10883	Comfort	24400.00
0005435616971	10883	Comfort	24400.00
0005435616848	10883	Economy	14400.00
0005435616970	10883	Economy	14400.00
0005434345271	10883	Economy	14400.00
0005434345184	10883	Economy	14400.00
0005435097474	10883	Economy	14400.00
0005435617009	10883	Economy	14400.00
0005435616826	10883	Economy	14400.00
0005435617050	10883	Economy	14400.00
0005434345241	10883	Economy	14400.00
0005434573748	10883	Economy	14400.00
0005434345215	10883	Economy	14400.00
0005435616790	10883	Economy	14400.00
0005434345126	10883	Economy	14400.00
0005434345169	10883	Economy	14400.00
0005435616991	10883	Economy	14400.00
0005434573719	10883	Economy	14400.00
0005435617023	10883	Economy	14400.00
0005434345250	10883	Economy	14400.00
0005435616989	10883	Economy	14400.00
0005435551781	10883	Economy	14400.00
0005435617048	10883	Economy	14400.00
0005435616893	10883	Economy	14400.00
0005435616875	10883	Economy	14400.00
0005435097495	10883	Economy	14400.00
0005435616876	10883	Economy	14400.00
0005435616914	10883	Economy	15800.00
0005435491509	10883	Economy	15800.00
0005434345163	10883	Economy	14400.00
0005435616963	10883	Economy	14400.00
0005435616917	10883	Economy	14400.00
0005434573730	10883	Economy	14400.00
0005435616802	10883	Economy	14400.00
0005435616407	10883	Economy	14400.00
0005435616966	10883	Economy	14400.00
0005435097494	10883	Economy	14400.00
0005435616898	10883	Economy	14400.00
0005434345287	10883	Economy	14400.00
0005435616895	10883	Economy	14400.00
0005434345232	10883	Economy	14400.00
0005435616803	10883	Economy	14400.00
0005435616889	10883	Economy	14400.00
0005435616978	10883	Economy	14400.00
0005435616965	10883	Economy	14400.00
0005434345272	10883	Economy	14400.00
0005435616847	10883	Economy	14400.00
0005435616521	10883	Economy	14400.00
0005434345267	10883	Economy	14400.00
0005435617018	10883	Economy	14400.00
0005435616805	10883	Economy	14400.00
0005435616406	10883	Economy	14400.00
0005434345204	10883	Economy	14400.00
0005435616522	10883	Economy	14400.00
0005434573732	10883	Economy	14400.00
0005435616804	10883	Economy	14400.00
0005434345242	10883	Economy	14400.00
0005434345193	10883	Economy	14400.00
0005434345249	10883	Economy	14400.00
0005435616846	10883	Economy	14400.00
0005434573736	10883	Economy	14400.00
0005434345191	10883	Economy	14400.00
0005435097467	10883	Economy	14400.00
0005434345273	10883	Economy	14400.00
0005434345056	10883	Economy	14400.00
0005435616715	10883	Economy	14400.00
0005435097481	10883	Economy	14400.00
0005435616820	10883	Economy	14400.00
0005435616894	10883	Economy	14400.00
0005435616716	10883	Economy	14400.00
0005434573760	10883	Economy	14400.00
0005434345240	10883	Economy	14400.00
0005434345123	10883	Economy	14400.00
0005435616708	10883	Economy	14400.00
0005434345131	10883	Economy	14400.00
0005434573718	10883	Economy	14400.00
0005435616964	10883	Economy	14400.00
0005434345239	10883	Economy	14400.00
0005435616915	10883	Economy	14400.00
0005435617038	10883	Economy	14400.00
0005435616946	10883	Economy	14400.00
0005435617049	10883	Economy	14400.00
0005435616509	10883	Economy	14400.00
0005435616827	10883	Economy	14400.00
0005435616746	10883	Economy	14400.00
0005434345265	10883	Economy	14400.00
0005434573759	10883	Economy	14400.00
0005434573749	10883	Economy	14400.00
0005435616944	10883	Economy	14400.00
0005435616840	10883	Economy	14400.00
0005434573747	10883	Economy	14400.00
0005434345266	10883	Economy	14400.00
0005435551782	10883	Economy	14400.00
0005434345223	10883	Economy	14400.00
0005435546238	10883	Economy	14400.00
0005434573686	10883	Economy	14400.00
0005434345132	10883	Economy	14400.00
0005435616692	10883	Economy	14400.00
0005434345275	10883	Economy	14400.00
0005435097468	10883	Economy	14400.00
0005435617051	10883	Economy	14400.00
0005435616975	10883	Economy	14400.00
0005435616481	10883	Economy	14400.00
0005434573744	10883	Economy	14400.00
0005435491508	10883	Economy	14400.00
0005434345216	10883	Economy	14400.00
0005432461306	3376	Business	18800.00
0005435856360	3376	Business	18800.00
0005434326108	3376	Business	18800.00
0005435860697	3376	Business	18800.00
0005434326109	3376	Economy	6900.00
0005432461308	3376	Economy	6900.00
0005435860696	3376	Economy	6900.00
0005432461423	3376	Economy	6900.00
0005435858719	3376	Economy	6300.00
0005435858720	3376	Economy	6300.00
0005435858718	3376	Economy	6300.00
0005434326099	3376	Economy	6300.00
0005432461357	3376	Economy	6300.00
0005432461129	3376	Economy	6300.00
0005435142995	3376	Economy	6300.00
0005432461374	3376	Economy	6300.00
0005432461128	3376	Economy	6300.00
0005432461309	3376	Economy	6300.00
0005432461358	3376	Economy	6300.00
0005435143003	3376	Economy	6300.00
0005435860698	3376	Economy	6300.00
0005435143001	3376	Economy	6300.00
0005432461199	3376	Economy	6300.00
0005432461344	3376	Economy	6300.00
0005432461340	3376	Economy	6300.00
0005432461345	3376	Economy	6300.00
0005435143002	3376	Economy	6300.00
0005432461425	3376	Economy	6300.00
0005432461384	3376	Economy	6300.00
0005432461307	3376	Economy	6300.00
0005432461424	3376	Economy	6300.00
0005435856361	3376	Economy	6300.00
0005432461427	3376	Economy	6300.00
0005432461426	3376	Economy	6300.00
0005434326062	3376	Economy	6300.00
0005432461420	3376	Economy	6300.00
0005435856363	3376	Economy	6300.00
0005432461296	3376	Economy	6300.00
0005435856359	3376	Economy	6300.00
0005432461298	3376	Economy	6300.00
0005432461395	3376	Economy	6300.00
0005435142994	3376	Economy	6300.00
0005432461380	3376	Economy	6300.00
0005434311291	3376	Economy	6300.00
0005435858735	3376	Economy	6300.00
0005435860721	3376	Economy	6300.00
0005432461210	3376	Economy	6300.00
0005432461407	3376	Economy	6300.00
0005435860722	3376	Economy	6300.00
0005435886856	3375	Business	18800.00
0005435886826	3375	Business	18800.00
0005435886815	3375	Business	18800.00
0005435886858	3375	Business	18800.00
0005435886756	3375	Business	18800.00
0005435886792	3375	Business	18800.00
0005435886778	3375	Business	18800.00
0005435886665	3375	Business	18800.00
0005435886867	3375	Business	18800.00
0005435886848	3375	Business	18800.00
0005435886744	3375	Business	18800.00
0005435886754	3375	Economy	6900.00
0005435886865	3375	Economy	6300.00
0005435886652	3375	Economy	6300.00
0005435886429	3375	Economy	6300.00
0005435886803	3375	Economy	6300.00
0005435886819	3375	Economy	6300.00
0005435886795	3375	Economy	6300.00
0005435886824	3375	Economy	6300.00
0005435886786	3375	Economy	6300.00
0005435886849	3375	Economy	6300.00
0005435886651	3375	Economy	6300.00
0005435886825	3375	Economy	6300.00
0005435886866	3375	Economy	6300.00
0005435886640	3375	Economy	6300.00
0005435886794	3375	Economy	6300.00
0005435886755	3375	Economy	6900.00
0005435933556	3375	Economy	6900.00
0005435886820	3375	Economy	6300.00
0005435886804	3375	Economy	6300.00
0005435903231	3375	Economy	6300.00
0005435886823	3375	Economy	6300.00
0005435903233	3375	Economy	6300.00
0005435903232	3375	Economy	6300.00
0005435886799	3375	Economy	6300.00
0005433507722	8289	Business	18800.00
0005433507713	8289	Economy	6300.00
0005433507704	8289	Economy	6300.00
0005433507729	8289	Economy	6300.00
0005433507702	8289	Economy	6900.00
0005433507613	8289	Economy	6300.00
0005433507703	8289	Economy	6300.00
0005433634775	8296	Business	18800.00
0005433634811	8296	Business	18800.00
0005433634796	8296	Business	18800.00
0005434143792	8296	Business	18800.00
0005434143825	8296	Business	18800.00
0005433806333	8296	Business	18800.00
0005433806361	8296	Business	18800.00
0005433634788	8296	Business	18800.00
0005434143813	8296	Economy	6900.00
0005434143811	8296	Economy	6300.00
0005433634712	8296	Economy	6300.00
0005434143830	8296	Economy	6300.00
0005433806407	8296	Economy	6300.00
0005434143836	8296	Economy	6300.00
0005434143827	8296	Economy	6300.00
0005433806399	8296	Economy	6300.00
0005434143826	8296	Economy	6300.00
0005433634809	8296	Economy	6300.00
0005434143812	8296	Economy	6300.00
0005433634789	8296	Economy	6300.00
0005433806246	8296	Economy	6300.00
0005434143814	8296	Economy	6300.00
0005433806408	8296	Economy	6300.00
0005434143831	8296	Economy	6300.00
0005433806316	8296	Economy	6300.00
0005433634785	8296	Economy	6900.00
0005434143810	8296	Economy	6300.00
0005433634819	8296	Economy	6300.00
0005434143755	8296	Economy	6300.00
0005433634820	8296	Economy	6300.00
0005434143815	8296	Economy	6300.00
0005433634776	8296	Economy	6300.00
0005433806357	8296	Economy	6300.00
0005434143828	8296	Economy	6300.00
0005433806367	8296	Economy	6300.00
0005433634647	8296	Economy	6300.00
0005433634818	8296	Economy	6300.00
0005433634794	8296	Economy	6300.00
0005433806344	8296	Economy	6300.00
0005434143835	8296	Economy	6300.00
0005433634817	8296	Economy	6300.00
0005433806382	8296	Economy	6300.00
0005433634810	8296	Economy	6300.00
0005433806345	8296	Economy	6300.00
0005434143829	8296	Economy	6300.00
0005434150190	8297	Business	18800.00
0005434265917	8297	Business	18800.00
0005434150233	8297	Business	18800.00
0005434265919	8297	Business	18800.00
0005434150200	8297	Business	18800.00
0005434150201	8297	Business	18800.00
0005434150225	8297	Business	18800.00
0005434150175	8297	Business	18800.00
0005434150143	8297	Business	18800.00
0005434265954	8297	Economy	6900.00
0005434265994	8297	Economy	6900.00
0005434265918	8297	Economy	6300.00
0005434265963	8297	Economy	6300.00
0005434265953	8297	Economy	6300.00
0005434266019	8297	Economy	6300.00
0005434265998	8297	Economy	6300.00
0005434150176	8297	Economy	6300.00
0005434265989	8297	Economy	6300.00
0005434150229	8297	Economy	6300.00
0005434266001	8297	Economy	6300.00
0005434266000	8297	Economy	6300.00
0005434265928	8297	Economy	6300.00
0005434266018	8297	Economy	6300.00
0005434265974	8297	Economy	6300.00
0005434150224	8297	Economy	6300.00
0005434266038	8297	Economy	6900.00
0005434150228	8297	Economy	6300.00
0005434150177	8297	Economy	6300.00
0005434266009	8297	Economy	6300.00
0005434265964	8297	Economy	6300.00
0005434150202	8297	Economy	6300.00
0005434230044	8297	Economy	6300.00
0005434265946	8297	Economy	6300.00
0005434265997	8297	Economy	6300.00
0005434265971	8297	Economy	6300.00
0005434266010	8297	Economy	6300.00
0005434266017	8297	Economy	6300.00
0005434266047	8297	Economy	6300.00
0005434150216	8297	Economy	6300.00
0005434266012	8297	Economy	6300.00
0005434265927	8297	Economy	6300.00
0005434150215	8297	Economy	6300.00
0005434265975	8297	Economy	6300.00
0005434265972	8297	Economy	6300.00
0005434150214	8297	Economy	6300.00
0005434266028	8297	Economy	6300.00
0005433722442	30175	Business	9900.00
0005433722430	30175	Business	9900.00
0005432384180	30175	Business	9900.00
0005433194935	30175	Business	9900.00
0005432384229	30175	Business	9900.00
0005432384221	30175	Business	9900.00
0005433722497	30175	Business	9900.00
0005433194998	30175	Business	9900.00
0005434300244	30175	Economy	3300.00
0005434300234	30175	Economy	3300.00
0005432384215	30175	Economy	3300.00
0005432384141	30175	Economy	3300.00
0005432384176	30175	Economy	3300.00
0005433194961	30175	Economy	3300.00
0005433722411	30175	Economy	3600.00
0005432384110	30175	Economy	3600.00
0005432384294	30175	Economy	3300.00
0005432384186	30175	Economy	3300.00
0005433194997	30175	Economy	3300.00
0005432384196	30175	Economy	3300.00
0005432384248	30175	Economy	3300.00
0005432728307	30175	Economy	3300.00
0005433722425	30175	Economy	3300.00
0005432728296	30175	Economy	3300.00
0005433722363	30175	Economy	3300.00
0005435477026	30175	Economy	3300.00
0005433722441	30175	Economy	3300.00
0005433722468	30175	Economy	3300.00
0005432384243	30175	Economy	3300.00
0005433453816	30175	Economy	3300.00
0005432384258	30175	Economy	3300.00
0005433722449	30175	Economy	3300.00
0005433722498	30175	Economy	3300.00
0005432728303	30175	Economy	3300.00
0005433722410	30175	Economy	3300.00
0005433722450	30175	Economy	3300.00
0005434300245	30175	Economy	3300.00
0005433722472	30175	Economy	3300.00
0005432728278	30175	Economy	3300.00
0005433194962	30175	Economy	3300.00
0005432384112	30175	Economy	3300.00
0005432384307	30175	Economy	3300.00
0005433722467	30175	Economy	3300.00
0005432384228	30175	Economy	3300.00
0005433194956	30175	Economy	3300.00
0005433722378	30175	Economy	3300.00
0005432384257	30175	Economy	3300.00
0005433194957	30175	Economy	3300.00
0005432384108	30175	Economy	3300.00
0005432384290	30175	Economy	3300.00
0005432384109	30175	Economy	3300.00
0005432384181	30175	Economy	3300.00
0005433722496	30175	Economy	3300.00
0005433194940	30175	Economy	3300.00
0005432384161	30175	Economy	3300.00
0005433722379	30175	Economy	3300.00
0005432384140	30175	Economy	3300.00
0005435477027	30175	Economy	3300.00
0005432384113	30175	Economy	3300.00
0005433453815	30175	Economy	3300.00
0005435477014	30175	Economy	3300.00
0005432384177	30175	Economy	3300.00
0005432728277	30175	Economy	3300.00
0005433722364	30175	Economy	3300.00
0005433722469	30175	Economy	3300.00
0005433194966	30175	Economy	3300.00
0005435477013	30175	Economy	3300.00
0005432384231	30175	Economy	3300.00
0005432384222	30175	Economy	3300.00
0005433453817	30175	Economy	3300.00
0005432384293	30175	Economy	3300.00
0005432384111	30175	Economy	3300.00
0005433517131	21983	Business	57200.00
0005433517132	21983	Business	57200.00
0005435541624	21983	Business	57200.00
0005435541615	21983	Economy	19100.00
0005435541627	21983	Economy	21000.00
0005435541601	21983	Economy	21000.00
0005433517133	21983	Economy	21000.00
0005435541602	21983	Economy	19100.00
0005435518445	21983	Economy	19100.00
0005433517165	21983	Economy	19100.00
0005435541611	21983	Economy	19100.00
0005435518437	21983	Economy	19100.00
0005435541640	21983	Economy	19100.00
0005435541625	21983	Economy	19100.00
0005435541643	21983	Economy	19100.00
0005435518434	21983	Economy	19100.00
0005435518404	21983	Economy	19100.00
0005435541639	21983	Economy	19100.00
0005435546227	21983	Economy	19100.00
0005435541557	21983	Economy	19100.00
0005435518447	21983	Economy	19100.00
0005435541610	21983	Economy	19100.00
0005435518436	21983	Economy	19100.00
0005435541642	21983	Economy	19100.00
0005435518446	21983	Economy	19100.00
0005435253198	7408	Business	18500.00
0005435253172	7408	Economy	6200.00
0005435253170	7408	Economy	6800.00
0005435253207	7408	Economy	6800.00
0005435253205	7408	Economy	6200.00
0005435253171	7408	Economy	6200.00
0005435253200	7408	Economy	6200.00
0005435253206	7408	Economy	6200.00
0005432839936	28950	Economy	6200.00
0005432839898	28950	Economy	6200.00
0005432839901	28950	Economy	6200.00
0005434459412	28950	Economy	6200.00
0005432839935	28950	Economy	6200.00
0005434459417	28950	Economy	6200.00
0005432841073	28950	Economy	6200.00
0005434459418	28950	Economy	6200.00
0005434459401	28950	Economy	6200.00
0005432839924	28950	Economy	6200.00
0005433435512	8780	Business	145300.00
0005434276196	8780	Economy	48400.00
0005433435532	8780	Economy	48400.00
0005433435531	8780	Economy	48400.00
0005433435515	8780	Economy	48400.00
0005433435513	8780	Economy	48400.00
0005435990819	15735	Business	145300.00
0005435990813	15735	Economy	48400.00
0005435990812	15735	Economy	48400.00
0005435990828	15735	Economy	48400.00
0005435723107	6397	Economy	12200.00
0005434150078	6397	Economy	12200.00
0005434150080	6397	Economy	12200.00
0005435177869	6397	Economy	12200.00
0005434150077	6397	Economy	12200.00
0005434150079	6397	Economy	12200.00
0005435177880	6397	Economy	12200.00
0005435177844	6397	Economy	12200.00
0005435177868	6397	Economy	12200.00
0005435177860	6397	Economy	12200.00
0005435177879	6397	Economy	12200.00
0005435723108	6397	Economy	12200.00
0005432361746	21036	Business	36600.00
0005432361740	21036	Business	36600.00
0005432336346	21036	Business	36600.00
0005432361689	21036	Economy	12200.00
0005432361724	21036	Economy	12200.00
0005432361690	21036	Economy	12200.00
0005432363514	21036	Economy	12200.00
0005432361664	21036	Economy	12200.00
0005432361755	21036	Economy	12200.00
0005432361698	21036	Economy	12200.00
0005432336383	21036	Economy	12200.00
0005432336379	21036	Economy	12200.00
0005432361757	21036	Economy	12200.00
0005432361758	21036	Economy	13400.00
0005432361745	21036	Economy	13400.00
0005432361704	21036	Economy	12200.00
0005432361733	21036	Economy	12200.00
0005432361634	21036	Economy	12200.00
0005432361691	21036	Economy	12200.00
0005432336378	21036	Economy	12200.00
0005432361756	21036	Economy	12200.00
0005432361721	21036	Economy	12200.00
0005432361759	21036	Economy	12200.00
0005432361665	21036	Economy	12200.00
0005432363513	21036	Economy	12200.00
0005432361697	21036	Economy	12200.00
0005432361723	21036	Economy	12200.00
0005432336380	21036	Economy	12200.00
0005432361764	21036	Economy	12200.00
0005432361720	21036	Economy	12200.00
0005434459407	17696	Economy	3400.00
0005434459400	17696	Economy	3100.00
0005434459367	17696	Economy	3100.00
0005434459422	17696	Economy	3100.00
0005434461708	17696	Economy	3100.00
0005434459404	17696	Economy	3100.00
0005434459421	17696	Economy	3100.00
0005434459375	17696	Economy	3100.00
0005434459406	17696	Economy	3100.00
0005434459366	17696	Economy	3100.00
0005435220521	21468	Economy	6600.00
0005435220520	21468	Economy	6600.00
0005435221556	21468	Economy	6600.00
0005432605405	31692	Economy	7300.00
0005432605428	31692	Economy	7300.00
0005432605416	31692	Economy	7300.00
0005432605396	31692	Economy	6600.00
0005432605406	31692	Economy	6600.00
0005432605469	31692	Economy	6600.00
0005432605452	31692	Economy	6600.00
0005432605453	31692	Economy	6600.00
0005435154672	29615	Economy	19500.00
0005435154707	29615	Economy	17800.00
0005435154699	29615	Economy	17800.00
0005435154681	29615	Economy	17800.00
0005435154680	29615	Economy	17800.00
0005435154682	29615	Economy	17800.00
0005435154661	29615	Economy	17800.00
0005435154686	29615	Economy	17800.00
0005435154683	29615	Economy	17800.00
0005435154685	29615	Economy	17800.00
0005435154687	29615	Economy	17800.00
0005435154684	29615	Economy	17800.00
0005435154674	29615	Economy	17800.00
0005435154703	29615	Economy	17800.00
0005435154696	29615	Economy	17800.00
0005435154671	29615	Economy	17800.00
0005435154688	29615	Economy	17800.00
0005435154698	29615	Economy	17800.00
0005435257377	6684	Economy	12700.00
0005435257379	6684	Economy	12700.00
0005435257378	6684	Economy	12700.00
0005435257385	6684	Economy	12700.00
0005435257381	6684	Economy	12700.00
0005434606933	18873	Economy	6600.00
0005435904914	22329	Economy	6600.00
0005432891565	367	Business	44500.00
0005432891567	367	Business	44500.00
0005434151809	367	Business	44500.00
0005432891592	367	Business	44500.00
0005432891591	367	Economy	14800.00
0005432891572	367	Economy	14800.00
0005433293436	367	Economy	14800.00
0005434152874	367	Economy	14800.00
0005432891575	367	Economy	14800.00
0005433293442	367	Economy	14800.00
0005432891570	367	Economy	14800.00
0005432891544	367	Economy	14800.00
0005432748647	12049	Business	44500.00
0005432748650	12049	Economy	14800.00
0005432749850	12049	Economy	14800.00
0005432748608	12049	Economy	14800.00
0005432748674	12049	Economy	14800.00
0005432748594	12049	Economy	14800.00
0005432748639	12049	Economy	14800.00
0005432748640	12049	Economy	14800.00
0005432748576	12049	Economy	14800.00
0005432749851	12049	Economy	14800.00
0005432928128	18967	Economy	25700.00
0005433525361	32468	Economy	25700.00
0005433525321	32468	Economy	25700.00
0005433525362	32468	Economy	25700.00
0005433525338	32468	Economy	25700.00
0005433525322	32468	Economy	25700.00
0005433527375	32468	Economy	25700.00
0005435315141	5257	Business	84000.00
0005435375122	5257	Comfort	47600.00
0005435375068	5257	Comfort	47600.00
0005435386751	5257	Comfort	47600.00
0005435315142	5257	Comfort	47600.00
0005435299922	5257	Comfort	47600.00
0005435375026	5257	Comfort	47600.00
0005435315143	5257	Comfort	47600.00
0005435375103	5257	Comfort	47600.00
0005435315111	5257	Economy	28000.00
0005435375121	5257	Economy	28000.00
0005435304272	5257	Economy	28000.00
0005435375045	5257	Economy	28000.00
0005435375087	5257	Economy	28000.00
0005435375005	5257	Economy	30800.00
0005435315112	5257	Economy	28000.00
0005435315124	5257	Economy	28000.00
0005435315127	5257	Economy	28000.00
0005435304273	5257	Economy	28000.00
0005435375006	5257	Economy	28000.00
0005435315140	5257	Economy	28000.00
0005435375082	5257	Economy	28000.00
0005435374847	5257	Economy	28000.00
0005435386742	5257	Economy	30800.00
0005432823503	5257	Economy	28000.00
0005435386750	5257	Economy	28000.00
0005435299921	5257	Economy	28000.00
0005435375067	5257	Economy	28000.00
0005435375088	5257	Economy	28000.00
0005435662002	5257	Economy	28000.00
0005435375079	5257	Economy	28000.00
0005435315126	5257	Economy	28000.00
0005435375140	5257	Economy	28000.00
0005435375146	5257	Economy	28000.00
0005435315123	5257	Economy	28000.00
0005435375151	5257	Economy	28000.00
0005435315087	5257	Economy	28000.00
0005434827211	9918	Business	84000.00
0005434826531	9918	Business	84000.00
0005432396358	9918	Business	84000.00
0005434827287	9918	Business	84000.00
0005434827231	9918	Business	84000.00
0005434831281	9918	Business	84000.00
0005434827100	9918	Business	84000.00
0005434558502	9918	Business	84000.00
0005434827163	9918	Comfort	47600.00
0005434827248	9918	Comfort	47600.00
0005434826891	9918	Comfort	47600.00
0005434827164	9918	Comfort	47600.00
0005434558613	9918	Comfort	47600.00
0005434827275	9918	Comfort	47600.00
0005434827246	9918	Comfort	47600.00
0005434558603	9918	Economy	28000.00
0005434558609	9918	Economy	28000.00
0005434827223	9918	Economy	28000.00
0005434558607	9918	Economy	28000.00
0005434558501	9918	Economy	28000.00
0005434827255	9918	Economy	28000.00
0005435150400	9918	Economy	28000.00
0005434827294	9918	Economy	28000.00
0005434827181	9918	Economy	28000.00
0005434827053	9918	Economy	28000.00
0005434826966	9918	Economy	30800.00
0005434827247	9918	Economy	28000.00
0005434827212	9918	Economy	28000.00
0005434558520	9918	Economy	28000.00
0005434826967	9918	Economy	28000.00
0005434827043	9918	Economy	28000.00
0005435150430	9918	Economy	28000.00
0005434827187	9918	Economy	28000.00
0005432396352	9918	Economy	28000.00
0005434558563	9918	Economy	28000.00
0005434827176	9918	Economy	28000.00
0005434827239	9918	Economy	28000.00
0005434826847	9918	Economy	28000.00
0005434558614	9918	Economy	28000.00
0005434827009	9918	Economy	28000.00
0005434827180	9918	Economy	28000.00
0005434831284	9918	Economy	28000.00
0005434826532	9918	Economy	28000.00
0005434827249	9918	Economy	28000.00
0005434827101	9918	Economy	28000.00
0005434558611	9918	Economy	28000.00
0005434827040	9918	Economy	28000.00
0005434827175	9918	Economy	28000.00
0005434827179	9918	Economy	28000.00
0005434827084	9918	Economy	28000.00
0005434827156	9918	Economy	28000.00
0005434827162	9918	Economy	28000.00
0005434831283	9918	Economy	28000.00
0005434665023	9918	Economy	28000.00
0005434558503	9918	Economy	28000.00
0005434827274	9918	Economy	28000.00
0005435150399	9918	Economy	28000.00
0005434827273	9918	Economy	28000.00
0005434558549	9918	Economy	28000.00
0005434831287	9918	Economy	28000.00
0005434827093	9918	Economy	28000.00
0005434558610	9918	Economy	28000.00
0005434827131	9918	Economy	28000.00
0005434558521	9918	Economy	28000.00
0005434558562	9918	Economy	28000.00
0005434827044	9918	Economy	28000.00
0005434827041	9918	Economy	28000.00
0005434827165	9918	Economy	28000.00
0005435083021	25969	Economy	8200.00
0005435083022	25969	Economy	8200.00
0005435083037	25969	Economy	8200.00
0005435083020	25969	Economy	8200.00
0005435082991	25969	Economy	7400.00
0005435083018	25969	Economy	7400.00
0005435082992	25969	Economy	7400.00
0005435083019	25969	Economy	7400.00
0005435790389	25969	Economy	7400.00
0005435083017	25969	Economy	7400.00
0005435083038	25969	Economy	7400.00
0005435083010	25969	Economy	7400.00
0005435083032	25969	Economy	7400.00
0005435790388	25969	Economy	7400.00
0005434215903	9567	Business	32800.00
0005434215774	9567	Business	32800.00
0005434215855	9567	Business	32800.00
0005434215867	9567	Business	32800.00
0005434215813	9567	Business	32800.00
0005434215864	9567	Economy	10900.00
0005434215878	9567	Economy	10900.00
0005434215853	9567	Economy	10900.00
0005434215875	9567	Economy	10900.00
0005434215859	9567	Economy	12000.00
0005434215860	9567	Economy	10900.00
0005434215834	9567	Economy	10900.00
0005434215835	9567	Economy	10900.00
0005434215845	9567	Economy	10900.00
0005434215847	9567	Economy	10900.00
0005434215785	9567	Economy	10900.00
0005434215861	9567	Economy	10900.00
0005434215773	9567	Economy	10900.00
0005434215862	9567	Economy	10900.00
0005434215786	9567	Economy	10900.00
0005434215844	9567	Economy	10900.00
0005434215868	9567	Economy	10900.00
0005434215843	9567	Economy	10900.00
0005434215904	9567	Economy	10900.00
0005434215820	9567	Economy	10900.00
0005434215871	9567	Economy	10900.00
0005434215892	9567	Economy	10900.00
0005434215854	9567	Economy	10900.00
0005434215863	9567	Economy	10900.00
0005434215874	9567	Economy	10900.00
0005434215831	9567	Economy	10900.00
0005434757652	28623	Business	32800.00
0005434757610	28623	Business	32800.00
0005434757635	28623	Business	32800.00
0005434757657	28623	Economy	10900.00
0005434757638	28623	Economy	12000.00
0005434757609	28623	Economy	12000.00
0005434757549	28623	Economy	10900.00
0005434757503	28623	Economy	10900.00
0005434757653	28623	Economy	10900.00
0005434757679	28623	Economy	10900.00
0005434757639	28623	Economy	10900.00
0005434757658	28623	Economy	10900.00
0005434757579	28623	Economy	10900.00
0005434757600	28623	Economy	10900.00
0005434757450	28623	Economy	10900.00
0005434757683	28623	Economy	10900.00
0005434757526	28623	Economy	10900.00
0005434757591	28623	Economy	10900.00
0005434757599	28623	Economy	10900.00
0005434757598	28623	Economy	10900.00
0005434757548	28623	Economy	10900.00
0005434757481	28623	Economy	10900.00
0005434757351	28623	Economy	10900.00
0005434757601	28623	Economy	10900.00
0005434757656	28623	Economy	10900.00
0005434757634	28623	Economy	10900.00
0005434757624	28623	Economy	10900.00
0005434757527	28623	Economy	10900.00
0005435100206	31822	Economy	8900.00
0005435100207	31822	Economy	8900.00
0005433202758	2009	Economy	19000.00
0005433202771	2009	Economy	19000.00
0005433202772	2009	Economy	19000.00
0005434639980	23284	Economy	20900.00
0005434640077	23284	Economy	20900.00
0005434639979	23284	Economy	19000.00
0005434640076	23284	Economy	19000.00
0005434639978	23284	Economy	19000.00
0005434639991	23284	Economy	19000.00
0005434640058	23284	Economy	19000.00
0005434640057	23284	Economy	19000.00
0005434639927	23284	Economy	19000.00
0005434639990	23284	Economy	19000.00
0005434640082	23284	Economy	19000.00
0005434640066	23284	Economy	19000.00
0005434639928	23284	Economy	19000.00
0005434640075	23284	Economy	19000.00
0005434640081	23284	Economy	19000.00
0005434640067	23284	Economy	19000.00
0005434640063	23284	Economy	19000.00
0005435327129	6037	Business	69700.00
0005435327101	6037	Business	69700.00
0005435327123	6037	Business	69700.00
0005435327133	6037	Economy	23200.00
0005434601574	18557	Economy	23200.00
0005434601577	18557	Economy	23200.00
0005434601558	18557	Economy	23200.00
0005433527374	18557	Economy	23200.00
0005434601592	18557	Economy	23200.00
0005434601579	18557	Economy	23200.00
0005435315115	10675	Business	9100.00
0005433181796	10675	Business	9100.00
0005433181818	10675	Business	9100.00
0005433181779	10675	Economy	3000.00
0005433181725	10675	Economy	3000.00
0005435315075	10675	Economy	3000.00
0005433181828	10675	Economy	3000.00
0005435315072	10675	Economy	3000.00
0005433181829	10675	Economy	3300.00
0005435315109	10675	Economy	3300.00
0005433181802	10675	Economy	3000.00
0005433181812	10675	Economy	3000.00
0005435315086	10675	Economy	3000.00
0005435315121	10675	Economy	3000.00
0005435315039	10675	Economy	3000.00
0005435315125	10675	Economy	3000.00
0005435315057	10675	Economy	3000.00
0005433181715	10675	Economy	3000.00
0005433181765	10675	Economy	3000.00
0005433181803	10675	Economy	3000.00
0005434757712	10675	Economy	3000.00
0005433181738	10675	Economy	3000.00
0005433181813	10675	Economy	3000.00
0005433181801	10675	Economy	3000.00
0005433181797	10675	Economy	3000.00
0005435315110	10675	Economy	3000.00
0005435315040	10675	Economy	3000.00
0005434552444	27691	Business	9100.00
0005434558515	27691	Business	9100.00
0005434552806	27691	Economy	3000.00
0005434558597	27691	Economy	3000.00
0005434552786	27691	Economy	3000.00
0005434558500	27691	Economy	3300.00
0005434552720	27691	Economy	3000.00
0005434552798	27691	Economy	3000.00
0005434558523	27691	Economy	3000.00
0005434552765	27691	Economy	3000.00
0005434552760	27691	Economy	3000.00
0005434558577	27691	Economy	3000.00
0005434558558	27691	Economy	3000.00
0005434552727	27691	Economy	3000.00
0005434558605	27691	Economy	3000.00
0005434552726	27691	Economy	3000.00
0005434558543	27691	Economy	3000.00
0005434558545	27691	Economy	3000.00
0005434558608	27691	Economy	3000.00
0005434552787	27691	Economy	3000.00
0005434558604	27691	Economy	3000.00
0005434558557	27691	Economy	3000.00
0005434552797	27691	Economy	3000.00
0005434558584	27691	Economy	3000.00
0005434552443	27691	Economy	3000.00
0005434552756	27691	Economy	3000.00
0005433459347	19309	Economy	11700.00
0005432533361	6759	Business	51100.00
0005432533378	6759	Business	51100.00
0005434828773	6759	Business	51100.00
0005435220380	6759	Business	51100.00
0005432533377	6759	Economy	17000.00
0005435217774	6759	Economy	18700.00
0005435220379	6759	Economy	17000.00
0005434828772	6759	Economy	17000.00
0005435438590	6759	Economy	17000.00
0005432533371	6759	Economy	17000.00
0005435438565	6759	Economy	17000.00
0005435438586	6759	Economy	17000.00
0005435719602	24570	Business	51100.00
0005435683317	24570	Economy	17000.00
0005435720859	24570	Economy	17000.00
0005435683264	24570	Economy	17000.00
0005435683326	24570	Economy	17000.00
0005435662006	24570	Economy	17000.00
0005435683293	24570	Economy	17000.00
0005435683319	24570	Economy	17000.00
0005435683318	24570	Economy	17000.00
0005435683298	24570	Economy	17000.00
0005435662003	24570	Economy	17000.00
0005435683329	24570	Economy	17000.00
0005435558159	11530	Economy	8800.00
0005435558158	11530	Economy	8800.00
0005435127499	31861	Business	26400.00
0005435127561	31861	Business	26400.00
0005435127530	31861	Economy	8800.00
0005435127577	31861	Economy	8800.00
0005435127482	31861	Economy	9700.00
0005435127403	31861	Economy	9700.00
0005435127500	31861	Economy	8800.00
0005435127560	31861	Economy	8800.00
0005435127584	31861	Economy	8800.00
0005435127535	31861	Economy	8800.00
0005435127533	31861	Economy	8800.00
0005435127566	31861	Economy	8800.00
0005435106067	31861	Economy	8800.00
0005435127483	31861	Economy	8800.00
0005435127494	31861	Economy	8800.00
0005435127481	31861	Economy	8800.00
0005435127582	31861	Economy	8800.00
0005435127571	31861	Economy	8800.00
0005435127468	31861	Economy	8800.00
0005435127573	31861	Economy	8800.00
0005435127583	31861	Economy	8800.00
0005435106066	31861	Economy	8800.00
0005435127534	31861	Economy	8800.00
0005435127570	31861	Economy	8800.00
0005435127501	31861	Economy	8800.00
0005435127572	31861	Economy	8800.00
0005435732683	13511	Business	36600.00
0005435732678	13511	Economy	12200.00
0005435732723	13511	Economy	12200.00
0005435732682	13511	Economy	12200.00
0005435732672	13511	Economy	12200.00
0005435732724	13511	Economy	12200.00
0005435732705	13511	Economy	12200.00
0005433399401	19402	Business	36600.00
0005433399438	19402	Business	36600.00
0005433399439	19402	Economy	12200.00
0005433399360	19402	Economy	12200.00
0005433399427	19402	Economy	12200.00
0005433399413	19402	Economy	12200.00
0005433399411	19402	Economy	12200.00
0005433399412	19402	Economy	12200.00
0005433399255	19402	Economy	12200.00
0005433399359	19402	Economy	12200.00
0005433399379	19402	Economy	12200.00
0005433399458	19402	Economy	12200.00
0005433399414	19402	Economy	12200.00
0005433399306	19402	Economy	12200.00
0005433399380	19402	Economy	12200.00
0005433399305	19402	Economy	12200.00
0005435070557	13164	Business	11300.00
0005435070358	13164	Business	11300.00
0005435070562	13164	Economy	3800.00
0005435070440	13164	Economy	3800.00
0005435070547	13164	Economy	4100.00
0005435070534	13164	Economy	3800.00
0005435070552	13164	Economy	3800.00
0005435070530	13164	Economy	3800.00
0005435070481	13164	Economy	3800.00
0005435070531	13164	Economy	3800.00
0005435070373	13164	Economy	3800.00
0005435070556	13164	Economy	3800.00
0005435070532	13164	Economy	3800.00
0005435070548	13164	Economy	3800.00
0005435070519	13164	Economy	3800.00
0005435070348	13164	Economy	3800.00
0005435070374	13164	Economy	3800.00
0005435925608	15504	Economy	3800.00
0005435925630	15504	Economy	3800.00
0005435925691	15504	Economy	3800.00
0005435925609	15504	Economy	3800.00
0005435925710	15504	Economy	3800.00
0005435925695	15504	Economy	3800.00
0005435925705	15504	Economy	3800.00
0005435925709	15504	Economy	3800.00
0005435808494	29500	Economy	24700.00
0005435808500	29500	Economy	24700.00
0005435808504	29500	Economy	24700.00
0005435808495	29500	Economy	24700.00
0005435808521	29500	Economy	24700.00
0005435808493	29500	Economy	24700.00
0005435808503	29500	Economy	24700.00
0005435808505	29500	Economy	24700.00
0005435808506	29500	Economy	24700.00
0005435808511	29500	Economy	24700.00
0005435808524	29500	Economy	24700.00
0005435808502	29500	Economy	24700.00
0005434757602	10687	Business	61300.00
0005434757603	10687	Business	61300.00
0005434757629	10687	Business	61300.00
0005434757649	10687	Business	61300.00
0005434757669	10687	Business	61300.00
0005434757386	10687	Economy	20400.00
0005434757592	10687	Economy	20400.00
0005434757651	10687	Economy	20400.00
0005434757668	10687	Economy	22500.00
0005434757618	10687	Economy	20400.00
0005434757593	10687	Economy	20400.00
0005434757650	10687	Economy	20400.00
0005434757655	10687	Economy	20400.00
0005434757633	10687	Economy	20400.00
0005434757615	10687	Economy	20400.00
0005434757636	10687	Economy	20400.00
0005434757405	10687	Economy	20400.00
0005434757387	10687	Economy	20400.00
0005434757654	10687	Economy	20400.00
0005434757578	10687	Economy	20400.00
0005434757682	10687	Economy	20400.00
0005434757514	10687	Economy	20400.00
0005434757681	10687	Economy	20400.00
0005434757674	10687	Economy	20400.00
0005434757630	10687	Economy	20400.00
0005434757406	10687	Economy	20400.00
0005434757490	10687	Economy	20400.00
0005434757604	10687	Economy	20400.00
0005434757478	10687	Economy	20400.00
0005434215721	28651	Business	61300.00
0005434215886	28651	Business	61300.00
0005434215803	28651	Economy	20400.00
0005434215793	28651	Economy	20400.00
0005434215783	28651	Economy	20400.00
0005434215850	28651	Economy	20400.00
0005434215705	28651	Economy	20400.00
0005434215720	28651	Economy	20400.00
0005434215849	28651	Economy	20400.00
0005434215750	28651	Economy	20400.00
0005434215802	28651	Economy	20400.00
0005434215701	28651	Economy	20400.00
0005434215826	28651	Economy	20400.00
0005434215885	28651	Economy	20400.00
0005434215827	28651	Economy	20400.00
0005434215700	28651	Economy	20400.00
0005434229954	5445	Business	29500.00
0005434229957	5445	Business	29500.00
0005434230034	5445	Economy	9800.00
0005434229994	5445	Economy	9800.00
0005435377945	5445	Economy	9800.00
0005434229958	5445	Economy	9800.00
0005434230022	5445	Economy	9800.00
0005434230033	5445	Economy	10800.00
0005435377976	5445	Economy	9800.00
0005434229956	5445	Economy	9800.00
0005435377947	5445	Economy	9800.00
0005434229955	5445	Economy	9800.00
0005434230032	5445	Economy	9800.00
0005434230015	5445	Economy	9800.00
0005435377944	5445	Economy	9800.00
0005435377946	5445	Economy	9800.00
0005434230016	5445	Economy	9800.00
0005435377977	5445	Economy	9800.00
0005435377952	5445	Economy	9800.00
0005435041655	12999	Business	29500.00
0005435007704	12999	Economy	9800.00
0005435007705	12999	Economy	9800.00
0005435041654	12999	Economy	9800.00
0005435041635	12999	Economy	9800.00
0005435041538	12999	Economy	9800.00
0005435042937	12999	Economy	9800.00
0005435007713	12999	Economy	9800.00
0005435042938	12999	Economy	10800.00
0005435041440	12999	Economy	9800.00
0005435007714	12999	Economy	9800.00
0005435041556	12999	Economy	9800.00
0005435042925	12999	Economy	9800.00
0005435042936	12999	Economy	9800.00
0005435007721	12999	Economy	9800.00
0005435007694	12999	Economy	9800.00
0005435007722	12999	Economy	9800.00
0005435041634	12999	Economy	9800.00
0005435007693	12999	Economy	9800.00
0005435041262	12999	Economy	9800.00
0005435041617	12999	Economy	9800.00
0005435041610	12999	Economy	9800.00
0005435007660	12999	Economy	9800.00
0005435041671	12999	Economy	9800.00
0005435041263	12999	Economy	9800.00
0005435554309	14885	Business	52900.00
0005435903202	14885	Economy	17600.00
0005435903204	14885	Economy	19400.00
0005435903142	14885	Economy	17600.00
0005435903201	14885	Economy	17600.00
0005435554314	14885	Economy	17600.00
0005435903203	14885	Economy	17600.00
0005435903216	14885	Economy	17600.00
0005435903200	14885	Economy	17600.00
0005434427382	20217	Business	52900.00
0005434427394	20217	Business	52900.00
0005434427454	20217	Economy	17600.00
0005434427467	20217	Economy	17600.00
0005434427468	20217	Economy	17600.00
0005434427456	20217	Economy	17600.00
0005434427434	20217	Economy	17600.00
0005434427455	20217	Economy	17600.00
0005433435485	26498	Business	18500.00
0005433435424	26498	Business	18500.00
0005433435441	26498	Economy	6200.00
0005433435442	26498	Economy	6200.00
0005433435500	26498	Economy	6800.00
0005433435395	26498	Economy	6800.00
0005433435501	26498	Economy	6200.00
0005433435423	26498	Economy	6200.00
0005433435483	26498	Economy	6200.00
0005433435484	26498	Economy	6200.00
0005433435499	26498	Economy	6200.00
0005433435492	26498	Economy	6200.00
0005435983618	26723	Business	18500.00
0005435983424	26723	Business	18500.00
0005435983620	26723	Economy	6200.00
0005435983664	26723	Economy	6200.00
0005435983616	26723	Economy	6200.00
0005435983592	26723	Economy	6800.00
0005435983425	26723	Economy	6800.00
0005435983619	26723	Economy	6200.00
0005435983617	26723	Economy	6200.00
0005435983650	26723	Economy	6200.00
0005435983595	26723	Economy	6200.00
0005435983638	26723	Economy	6200.00
0005435983665	26723	Economy	6200.00
0005435983673	26723	Economy	6200.00
0005435983653	26723	Economy	6200.00
0005435983567	26723	Economy	6200.00
0005433685593	19507	Economy	19100.00
0005432858406	3163	Economy	10100.00
0005432858408	3163	Economy	10100.00
0005432858388	3163	Economy	10100.00
0005432858387	3163	Economy	10100.00
0005432858410	3163	Economy	10100.00
0005432858409	3163	Economy	10100.00
0005432584776	31465	Economy	10100.00
0005432584777	31465	Economy	10100.00
0005432584779	31465	Economy	10100.00
0005434943617	16201	Economy	7500.00
0005435858679	4318	Business	90500.00
0005435858671	4318	Business	90500.00
0005435858677	4318	Business	90500.00
0005435858692	4318	Economy	30200.00
0005435858676	4318	Economy	30200.00
0005435858693	4318	Economy	33200.00
0005435858665	4318	Economy	30200.00
0005435858682	4318	Economy	30200.00
0005435858691	4318	Economy	30200.00
0005435858694	4318	Economy	30200.00
0005435858674	4318	Economy	30200.00
0005435858675	4318	Economy	30200.00
0005435858690	4318	Economy	30200.00
0005433811687	14347	Economy	4400.00
0005433811688	14347	Economy	4400.00
0005433368949	21742	Business	9800.00
0005433368951	21742	Business	9800.00
0005433368916	21742	Business	9800.00
0005433368934	21742	Economy	3300.00
0005433368970	21742	Economy	3300.00
0005433368950	21742	Economy	3300.00
0005433368971	21742	Economy	3300.00
0005433368972	21742	Economy	3300.00
0005433368973	21742	Economy	3300.00
0005435270200	9383	Business	186200.00
0005435270174	9383	Economy	62100.00
0005435270193	9383	Economy	62100.00
0005434171411	9383	Economy	62100.00
0005435270212	9383	Economy	62100.00
0005435858720	9383	Economy	62100.00
0005435270211	9383	Economy	62100.00
0005435858719	9383	Economy	62100.00
0005435270122	9383	Economy	62100.00
0005435858718	9383	Economy	62100.00
0005435858735	9383	Economy	62100.00
0005434171409	9383	Economy	62100.00
0005435270214	9383	Economy	62100.00
0005435270204	9383	Economy	62100.00
0005435270203	9383	Economy	62100.00
0005434171410	9383	Economy	62100.00
0005435270202	9383	Economy	62100.00
0005433763599	26253	Business	186200.00
0005433786126	26253	Business	186200.00
0005433786021	26253	Business	186200.00
0005433786140	26253	Business	186200.00
0005433806333	26253	Business	186200.00
0005433786074	26253	Business	186200.00
0005433786070	26253	Business	186200.00
0005433806344	26253	Business	186200.00
0005433786124	26253	Business	186200.00
0005433786186	26253	Business	186200.00
0005433786181	26253	Economy	62100.00
0005433806407	26253	Economy	62100.00
0005433763615	26253	Economy	62100.00
0005433785973	26253	Economy	62100.00
0005433806399	26253	Economy	62100.00
0005433786089	26253	Economy	62100.00
0005433806361	26253	Economy	62100.00
0005433786123	26253	Economy	62100.00
0005433786078	26253	Economy	62100.00
0005433786100	26253	Economy	62100.00
0005433786125	26253	Economy	62100.00
0005433786006	26253	Economy	62100.00
0005432663095	26253	Economy	62100.00
0005433786101	26253	Economy	62100.00
0005433763616	26253	Economy	62100.00
0005433786052	26253	Economy	62100.00
0005433806246	26253	Economy	62100.00
0005432663093	26253	Economy	62100.00
0005433806316	26253	Economy	62100.00
0005433786048	26253	Economy	62100.00
0005433806382	26253	Economy	62100.00
0005433786104	26253	Economy	62100.00
0005433786178	26253	Economy	68300.00
0005433786099	26253	Economy	62100.00
0005433785944	26253	Economy	62100.00
0005433786015	26253	Economy	68300.00
0005433785986	26253	Economy	62100.00
0005433786075	26253	Economy	62100.00
0005433806345	26253	Economy	62100.00
0005433786053	26253	Economy	62100.00
0005433786105	26253	Economy	62100.00
0005433786141	26253	Economy	62100.00
0005433786170	26253	Economy	62100.00
0005433786120	26253	Economy	62100.00
0005433785987	26253	Economy	62100.00
0005433806357	26253	Economy	62100.00
0005433786005	26253	Economy	62100.00
0005433806367	26253	Economy	62100.00
0005433786145	26253	Economy	62100.00
0005433785889	26253	Economy	62100.00
0005432663094	26253	Economy	62100.00
0005433786079	26253	Economy	62100.00
0005432663089	26253	Economy	62100.00
0005432663098	26253	Economy	62100.00
0005433786020	26253	Economy	62100.00
0005433806408	26253	Economy	62100.00
0005433786171	26253	Economy	62100.00
0005433786106	26253	Economy	62100.00
0005433785974	26253	Economy	62100.00
0005433786088	26253	Economy	62100.00
0005433786118	26253	Economy	62100.00
0005433786014	26253	Economy	62100.00
0005433786119	26253	Economy	62100.00
0005435929722	4916	Economy	5300.00
0005435929720	4916	Economy	5300.00
0005435135806	33023	Economy	5900.00
0005435135807	33023	Economy	5300.00
0005434218070	9462	Economy	17900.00
0005434218091	9462	Economy	17900.00
0005434218088	9462	Economy	17900.00
0005434218090	9462	Economy	17900.00
0005434983428	27375	Economy	17900.00
0005433962326	24238	Business	36400.00
0005433962404	24238	Business	36400.00
0005433987367	24238	Business	36400.00
0005433987344	24238	Business	36400.00
0005433962714	24238	Business	36400.00
0005433962475	24238	Business	36400.00
0005433962697	24238	Business	36400.00
0005433962420	24238	Business	36400.00
0005433962619	24238	Business	36400.00
0005433962558	24238	Business	36400.00
0005433987281	24238	Business	36400.00
0005433987345	24238	Business	36400.00
0005433987320	24238	Economy	13400.00
0005433962567	24238	Economy	12100.00
0005433962433	24238	Economy	12100.00
0005433987266	24238	Economy	12100.00
0005433962589	24238	Economy	12100.00
0005433962405	24238	Economy	12100.00
0005433962411	24238	Economy	12100.00
0005433962646	24238	Economy	12100.00
0005433962536	24238	Economy	12100.00
0005433962579	24238	Economy	12100.00
0005433962661	24238	Economy	12100.00
0005433962256	24238	Economy	12100.00
0005433987329	24238	Economy	12100.00
0005433962484	24238	Economy	12100.00
0005433962692	24238	Economy	12100.00
0005433962415	24238	Economy	12100.00
0005433962462	24238	Economy	12100.00
0005433962406	24238	Economy	12100.00
0005433987368	24238	Economy	12100.00
0005433962690	24238	Economy	12100.00
0005433987247	24238	Economy	12100.00
0005433962544	24238	Economy	12100.00
0005433962440	24238	Economy	12100.00
0005433962562	24238	Economy	12100.00
0005433962474	24238	Economy	12100.00
0005433962566	24238	Economy	12100.00
0005433962653	24238	Economy	12100.00
0005433987246	24238	Economy	12100.00
0005433962655	24238	Economy	12100.00
0005433962627	24238	Economy	12100.00
0005433962602	24238	Economy	12100.00
0005433962560	24238	Economy	12100.00
0005433987328	24238	Economy	13400.00
0005433962461	24238	Economy	13400.00
0005433962412	24238	Economy	12100.00
0005433962564	24238	Economy	12100.00
0005433962532	24238	Economy	12100.00
0005433962490	24238	Economy	12100.00
0005433962537	24238	Economy	12100.00
0005433962417	24238	Economy	12100.00
0005433962349	24238	Economy	12100.00
0005433987363	24238	Economy	12100.00
0005433962513	24238	Economy	12100.00
0005433987353	24238	Economy	12100.00
0005433987362	24238	Economy	12100.00
0005433962633	24238	Economy	12100.00
0005433962426	24238	Economy	12100.00
0005433962563	24238	Economy	12100.00
0005433962565	24238	Economy	12100.00
0005433962561	24238	Economy	12100.00
0005433962533	24238	Economy	12100.00
0005433962634	24238	Economy	12100.00
0005433962691	24238	Economy	12100.00
0005433962521	24238	Economy	12100.00
0005433962622	24238	Economy	12100.00
0005433987270	24238	Economy	12100.00
0005433987346	24238	Economy	12100.00
0005433962416	24238	Economy	12100.00
0005433962647	24238	Economy	12100.00
0005433962628	24238	Economy	12100.00
0005433962675	24238	Economy	12100.00
0005433166286	922	Economy	25400.00
0005433166281	922	Economy	23100.00
0005433166282	922	Economy	23100.00
0005433166274	922	Economy	23100.00
0005433166283	922	Economy	23100.00
0005434481050	16567	Economy	25400.00
0005434481051	16567	Economy	23100.00
0005434481028	16567	Economy	23100.00
0005434481038	16567	Economy	23100.00
0005434481039	16567	Economy	23100.00
0005434481025	16567	Economy	23100.00
0005434481024	16567	Economy	23100.00
0005434481029	16567	Economy	23100.00
0005434481049	16567	Economy	23100.00
0005434481030	16567	Economy	23100.00
0005434481018	16567	Economy	23100.00
0005433872581	32550	Economy	19000.00
0005433872584	32550	Economy	17200.00
0005433872583	32550	Economy	17200.00
0005433872582	32550	Economy	17200.00
0005435386743	10356	Economy	17000.00
0005433290055	10356	Economy	15400.00
0005433290021	10356	Economy	15400.00
0005433290059	10356	Economy	15400.00
0005433290022	10356	Economy	15400.00
0005435386744	10356	Economy	15400.00
0005435386754	10356	Economy	15400.00
0005435142939	21955	Economy	17000.00
0005435150430	21955	Economy	15400.00
0005435150400	21955	Economy	15400.00
0005435150399	21955	Economy	15400.00
0005435142938	21955	Economy	15400.00
0005435545950	11184	Business	57200.00
0005435502950	11184	Business	57200.00
0005435545974	11184	Economy	19100.00
0005435502940	11184	Economy	19100.00
0005435502956	11184	Economy	19100.00
0005435529854	11184	Economy	19100.00
0005435529853	11184	Economy	19100.00
0005435502951	11184	Economy	19100.00
0005435529834	11184	Economy	19100.00
0005435502941	11184	Economy	19100.00
0005435545948	11184	Economy	19100.00
0005435545957	11184	Economy	19100.00
0005435545973	11184	Economy	19100.00
0005434573712	20948	Economy	19100.00
0005434573767	20948	Economy	19100.00
0005434573711	20948	Economy	19100.00
0005434573761	20948	Economy	19100.00
0005434573754	20948	Economy	19100.00
0005433927506	24311	Economy	18800.00
0005433927507	24311	Economy	17100.00
0005433927505	24311	Economy	17100.00
0005433927515	24311	Economy	17100.00
0005433927510	24311	Economy	17100.00
0005433683412	29292	Economy	18800.00
0005433683418	29292	Economy	17100.00
0005433683411	29292	Economy	17100.00
0005433683408	29292	Economy	17100.00
0005433683414	29292	Economy	17100.00
0005433683413	29292	Economy	17100.00
0005433683417	29292	Economy	17100.00
0005433683410	29292	Economy	17100.00
0005432693879	2923	Business	10300.00
0005432693948	2923	Business	10300.00
0005432693936	2923	Business	10300.00
0005432693967	2923	Economy	3400.00
0005432693930	2923	Economy	3400.00
0005432693934	2923	Economy	3400.00
0005432693915	2923	Economy	3400.00
0005432693876	2923	Economy	3400.00
0005432693971	2923	Economy	3400.00
0005432693966	2923	Economy	3400.00
0005432693929	2923	Economy	3400.00
0005432693935	2923	Economy	3400.00
0005432693947	2923	Economy	3400.00
0005432693928	2923	Economy	3400.00
0005433124420	2922	Business	10300.00
0005433124490	2922	Business	10300.00
0005433124525	2922	Business	10300.00
0005433195011	2922	Business	10300.00
0005433124478	2922	Business	10300.00
0005434300251	2922	Economy	3400.00
0005433124505	2922	Economy	3400.00
0005433195008	2922	Economy	3400.00
0005434300255	2922	Economy	3800.00
0005434300250	2922	Economy	3800.00
0005433194967	2922	Economy	3800.00
0005433194989	2922	Economy	3400.00
0005433124504	2922	Economy	3400.00
0005433124494	2922	Economy	3400.00
0005432881219	2922	Economy	3400.00
0005434300265	2922	Economy	3400.00
0005433124533	2922	Economy	3400.00
0005434300237	2922	Economy	3400.00
0005433124550	2922	Economy	3400.00
0005433195009	2922	Economy	3400.00
0005433194965	2922	Economy	3400.00
0005433124491	2922	Economy	3400.00
0005433194964	2922	Economy	3400.00
0005433195006	2922	Economy	3400.00
0005433124546	2922	Economy	3400.00
0005434300252	2922	Economy	3400.00
0005432881220	2922	Economy	3400.00
0005434300254	2922	Economy	3400.00
0005433194990	2922	Economy	3400.00
0005433124534	2922	Economy	3400.00
0005433195005	2922	Economy	3400.00
0005433124524	2922	Economy	3400.00
0005434300269	2922	Economy	3400.00
0005433195010	2922	Economy	3400.00
0005433124419	2922	Economy	3400.00
0005434300257	2922	Economy	3400.00
0005434300256	2922	Economy	3400.00
0005434300247	2922	Economy	3400.00
0005433124547	2922	Economy	3400.00
0005433124545	2922	Economy	3400.00
0005434300248	2922	Economy	3400.00
0005432707498	30000	Economy	3400.00
0005434310152	30000	Economy	3800.00
0005432707485	30000	Economy	3400.00
0005434310151	30000	Economy	3400.00
0005434310154	30000	Economy	3400.00
0005434310175	30000	Economy	3400.00
0005434310153	30000	Economy	3400.00
0005434989096	27533	Economy	4000.00
0005434980620	27533	Economy	4000.00
0005434980650	27533	Economy	3600.00
0005434980657	27533	Economy	3600.00
0005434989124	27533	Economy	3600.00
0005434980635	27533	Economy	3600.00
0005434989104	27533	Economy	3600.00
0005434989098	27533	Economy	3600.00
0005434980618	27533	Economy	3600.00
0005434980634	27533	Economy	3600.00
0005434989101	27533	Economy	3600.00
0005434989041	27533	Economy	3600.00
0005434980630	27533	Economy	3600.00
0005434980647	27533	Economy	3600.00
0005434980648	27533	Economy	3600.00
0005434980659	27533	Economy	3600.00
0005434980636	27533	Economy	3600.00
0005434989089	27533	Economy	3600.00
0005434989061	27533	Economy	3600.00
0005434989115	27533	Economy	3600.00
0005434989062	27533	Economy	3600.00
0005434989102	27533	Economy	3600.00
0005434980566	27533	Economy	3600.00
0005434989085	27533	Economy	3600.00
0005434989076	27533	Economy	3600.00
0005434980637	27533	Economy	3600.00
0005434989097	27533	Economy	3600.00
0005434980619	27533	Economy	3600.00
0005434989033	27533	Economy	3600.00
0005434989110	27533	Economy	3600.00
0005434980656	27533	Economy	3600.00
0005434980658	27533	Economy	3600.00
0005434980677	27533	Economy	3600.00
0005434989060	27533	Economy	3600.00
0005433113594	10273	Economy	19700.00
0005434302574	19638	Economy	19700.00
0005434302571	19638	Economy	19700.00
0005434302570	19638	Economy	19700.00
0005435939966	3536	Business	26900.00
0005435925702	3536	Business	26900.00
0005435939967	3536	Economy	9900.00
0005435925700	3536	Economy	9900.00
0005435939960	3536	Economy	9000.00
0005435939968	3536	Economy	9000.00
0005435925704	3536	Economy	9000.00
0005435925662	3536	Economy	9000.00
0005435925663	3536	Economy	9000.00
0005435939962	3536	Economy	9000.00
0005435925661	3536	Economy	9000.00
0005435070552	15311	Business	26900.00
0005435070534	15311	Business	26900.00
0005435070547	15311	Economy	9000.00
0005435070530	15311	Economy	9900.00
0005435070531	15311	Economy	9000.00
0005435950314	15311	Economy	9000.00
0005435070373	15311	Economy	9000.00
0005435070481	15311	Economy	9000.00
0005435070532	15311	Economy	9000.00
0005435070557	15311	Economy	9000.00
0005435070358	15311	Economy	9000.00
0005435070440	15311	Economy	9000.00
0005435070556	15311	Economy	9000.00
0005435070348	15311	Economy	9000.00
0005435070548	15311	Economy	9000.00
0005435070562	15311	Economy	9000.00
0005435070374	15311	Economy	9000.00
0005435070519	15311	Economy	9000.00
0005432660874	26421	Economy	5900.00
0005433103786	111	Business	20000.00
0005432677686	111	Business	20000.00
0005433104006	111	Business	20000.00
0005433103701	111	Business	20000.00
0005433103923	111	Business	20000.00
0005433103816	111	Business	20000.00
0005432677687	111	Business	20000.00
0005433103968	111	Business	20000.00
0005432392080	111	Business	20000.00
0005432902110	111	Business	20000.00
0005433103733	111	Business	20000.00
0005432392081	111	Business	20000.00
0005433435522	111	Business	20000.00
0005433103983	111	Business	20000.00
0005433103986	111	Business	20000.00
0005433103731	111	Business	20000.00
0005432392079	111	Business	20000.00
0005433103798	111	Economy	7300.00
0005433103774	111	Economy	7300.00
0005433103728	111	Economy	7300.00
0005433103705	111	Economy	6700.00
0005433103539	111	Economy	6700.00
0005433103538	111	Economy	6700.00
0005433103847	111	Economy	6700.00
0005433103700	111	Economy	6700.00
0005433103949	111	Economy	6700.00
0005433103991	111	Economy	6700.00
0005433435514	111	Economy	6700.00
0005433103808	111	Economy	6700.00
0005432920416	111	Economy	6700.00
0005433104005	111	Economy	6700.00
0005433104003	111	Economy	6700.00
0005433103856	111	Economy	6700.00
0005432392069	111	Economy	6700.00
0005433103894	111	Economy	6700.00
0005432392077	111	Economy	6700.00
0005433103872	111	Economy	6700.00
0005433103956	111	Economy	6700.00
0005433103787	111	Economy	6700.00
0005432902109	111	Economy	6700.00
0005433104010	111	Economy	6700.00
0005433104002	111	Economy	6700.00
0005433103904	111	Economy	6700.00
0005432902123	111	Economy	6700.00
0005432392078	111	Economy	6700.00
0005432920479	111	Economy	6700.00
0005433103841	111	Economy	6700.00
0005433103863	111	Economy	6700.00
0005433103850	111	Economy	6700.00
0005432920467	111	Economy	7300.00
0005433103807	111	Economy	7300.00
0005433103706	111	Economy	7300.00
0005433439113	111	Economy	6700.00
0005433103974	111	Economy	6700.00
0005432392074	111	Economy	7300.00
0005433103975	111	Economy	6700.00
0005433435511	111	Economy	6700.00
0005433103858	111	Economy	6700.00
0005432920421	111	Economy	6700.00
0005432920436	111	Economy	6700.00
0005433103859	111	Economy	6700.00
0005432902122	111	Economy	6700.00
0005433103906	111	Economy	6700.00
0005433103985	111	Economy	6700.00
0005433103797	111	Economy	6700.00
0005432902108	111	Economy	6700.00
0005433103880	111	Economy	6700.00
0005432920475	111	Economy	6700.00
0005432902111	111	Economy	6700.00
0005433103907	111	Economy	6700.00
0005432920420	111	Economy	6700.00
0005433103773	111	Economy	6700.00
0005433103628	111	Economy	6700.00
0005433104001	111	Economy	6700.00
0005432902124	111	Economy	6700.00
0005433104009	111	Economy	6700.00
0005433104004	111	Economy	6700.00
0005433103857	111	Economy	6700.00
0005433103775	111	Economy	6700.00
0005433103629	111	Economy	6700.00
0005432392076	111	Economy	6700.00
0005432392075	111	Economy	6700.00
0005433103947	111	Economy	6700.00
0005433103776	111	Economy	6700.00
0005433103948	111	Economy	6700.00
0005434028398	111	Economy	6700.00
0005432756937	112	Economy	6700.00
0005432756938	112	Economy	6700.00
0005433929890	112	Economy	6700.00
0005433929895	112	Economy	6700.00
0005433929891	112	Economy	6700.00
0005434157866	8124	Business	20000.00
0005434157926	8124	Business	20000.00
0005434157912	8124	Business	20000.00
0005434157921	8124	Business	20000.00
0005434175880	8124	Business	20000.00
0005434157895	8124	Business	20000.00
0005434157834	8124	Business	20000.00
0005434157833	8124	Business	20000.00
0005434157890	8124	Economy	7300.00
0005434157969	8124	Economy	6700.00
0005434157747	8124	Economy	6700.00
0005434157877	8124	Economy	6700.00
0005434151816	8124	Economy	6700.00
0005434151810	8124	Economy	6700.00
0005434157846	8124	Economy	6700.00
0005434157887	8124	Economy	6700.00
0005434151817	8124	Economy	6700.00
0005434157873	8124	Economy	6700.00
0005433477207	8124	Economy	6700.00
0005434157861	8124	Economy	6700.00
0005433477257	8124	Economy	6700.00
0005434157744	8124	Economy	6700.00
0005434157961	8124	Economy	6700.00
0005434157745	8124	Economy	6700.00
0005434157900	8124	Economy	6700.00
0005434175878	8124	Economy	6700.00
0005434157867	8124	Economy	6700.00
0005434157925	8124	Economy	6700.00
0005433477208	8124	Economy	6700.00
0005434157914	8124	Economy	7300.00
0005434157860	8124	Economy	6700.00
0005434157891	8124	Economy	6700.00
0005434157878	8124	Economy	6700.00
0005434157964	8124	Economy	7300.00
0005434157781	8124	Economy	6700.00
0005433477258	8124	Economy	6700.00
0005434157847	8124	Economy	6700.00
0005434157750	8124	Economy	6700.00
0005434157960	8124	Economy	6700.00
0005434157915	8124	Economy	6700.00
0005434157836	8124	Economy	6700.00
0005434175879	8124	Economy	6700.00
0005434157759	8124	Economy	6700.00
0005434157760	8124	Economy	6700.00
0005434157868	8124	Economy	6700.00
0005434157746	8124	Economy	6700.00
0005433477261	8124	Economy	6700.00
0005434157869	8124	Economy	6700.00
0005434157965	8124	Economy	6700.00
0005434157779	8124	Economy	6700.00
0005433477264	8124	Economy	6700.00
0005434152867	8124	Economy	6700.00
0005434157814	8124	Economy	6700.00
0005432818318	8111	Business	20000.00
0005432818312	8111	Business	20000.00
0005432818308	8111	Business	20000.00
0005434513658	8111	Economy	6700.00
0005432818317	8111	Economy	6700.00
0005434513661	8111	Economy	6700.00
0005432818297	8111	Economy	6700.00
0005432818323	8111	Economy	6700.00
0005434513651	8111	Economy	6700.00
0005432818278	8111	Economy	6700.00
0005432818321	8111	Economy	6700.00
0005434513659	8111	Economy	7300.00
0005434513652	8111	Economy	6700.00
0005434513660	8111	Economy	6700.00
0005432818333	8111	Economy	6700.00
0005432818243	8111	Economy	6700.00
0005432818316	8111	Economy	6700.00
0005432818242	8111	Economy	6700.00
0005433870797	32362	Economy	6900.00
0005433870800	32362	Economy	6900.00
0005435914771	3501	Business	35000.00
0005435841123	3501	Business	35000.00
0005435914164	3501	Business	35000.00
0005435914778	3501	Comfort	19900.00
0005435914779	3501	Comfort	19900.00
0005435914773	3501	Comfort	19900.00
0005435914189	3501	Economy	11700.00
0005435903218	3501	Economy	11700.00
0005435914130	3501	Economy	11700.00
0005435841128	3501	Economy	11700.00
0005435914131	3501	Economy	11700.00
0005435914759	3501	Economy	11700.00
0005435914165	3501	Economy	11700.00
0005435841127	3501	Economy	11700.00
0005435914772	3501	Economy	11700.00
0005434938704	14579	Business	35000.00
0005435127553	14579	Business	35000.00
0005434880950	14579	Business	35000.00
0005432800197	14579	Business	35000.00
0005434880933	14579	Business	35000.00
0005435626744	14579	Business	35000.00
0005435127539	14579	Comfort	19900.00
0005434880790	14579	Comfort	19900.00
0005434427456	14579	Comfort	19900.00
0005435626802	14579	Comfort	19900.00
0005435127491	14579	Comfort	19900.00
0005435626748	14579	Comfort	19900.00
0005435626841	14579	Comfort	19900.00
0005434880864	14579	Economy	11700.00
0005435127554	14579	Economy	11700.00
0005435626857	14579	Economy	11700.00
0005435626793	14579	Economy	11700.00
0005434880772	14579	Economy	11700.00
0005432800180	14579	Economy	11700.00
0005434427434	14579	Economy	11700.00
0005435127492	14579	Economy	11700.00
0005435127480	14579	Economy	11700.00
0005434880806	14579	Economy	11700.00
0005434880848	14579	Economy	11700.00
0005435626652	14579	Economy	11700.00
0005434427382	14579	Economy	11700.00
0005435626785	14579	Economy	11700.00
0005435626798	14579	Economy	11700.00
0005434427394	14579	Economy	12800.00
0005434938720	14579	Economy	11700.00
0005434427455	14579	Economy	11700.00
0005435127541	14579	Economy	11700.00
0005435127569	14579	Economy	11700.00
0005434938706	14579	Economy	11700.00
0005435626772	14579	Economy	11700.00
0005435626653	14579	Economy	11700.00
0005434427454	14579	Economy	11700.00
0005434880521	14579	Economy	11700.00
0005435626809	14579	Economy	11700.00
0005434880931	14579	Economy	11700.00
0005435127430	14579	Economy	11700.00
0005434880834	14579	Economy	11700.00
0005435626763	14579	Economy	11700.00
0005434880519	14579	Economy	11700.00
0005434880771	14579	Economy	11700.00
0005434880520	14579	Economy	11700.00
0005435626824	14579	Economy	11700.00
0005434938705	14579	Economy	11700.00
0005434427467	14579	Economy	11700.00
0005435626788	14579	Economy	11700.00
0005434880934	14579	Economy	11700.00
0005435127527	14579	Economy	11700.00
0005435127557	14579	Economy	11700.00
0005434427468	14579	Economy	11700.00
0005434880844	14579	Economy	12800.00
0005434880845	14579	Economy	12800.00
0005435626762	14579	Economy	11700.00
0005435626814	14579	Economy	11700.00
0005435127545	14579	Economy	11700.00
0005435626808	14579	Economy	11700.00
0005435626860	14579	Economy	11700.00
0005434880966	14579	Economy	11700.00
0005435626745	14579	Economy	11700.00
0005435127531	14579	Economy	11700.00
0005434880917	14579	Economy	11700.00
0005435626813	14579	Economy	11700.00
0005435626856	14579	Economy	11700.00
0005434880932	14579	Economy	11700.00
0005435127538	14579	Economy	11700.00
0005434880770	14579	Economy	11700.00
0005434880632	14579	Economy	11700.00
0005435127558	14579	Economy	11700.00
0005432800248	14579	Economy	11700.00
0005434880941	14579	Economy	11700.00
0005435626851	14579	Economy	11700.00
0005435127526	14579	Economy	11700.00
0005432800196	14579	Economy	11700.00
0005435127429	14579	Economy	11700.00
0005435626815	14579	Economy	11700.00
0005435127540	14579	Economy	11700.00
0005434880936	14579	Economy	11700.00
0005434938712	14579	Economy	11700.00
0005434880797	14579	Economy	11700.00
0005434880807	14579	Economy	11700.00
0005435890068	3630	Economy	14800.00
0005435890066	3630	Economy	14800.00
0005435890067	3630	Economy	14800.00
0005435890065	3630	Economy	14800.00
0005434325976	15645	Economy	14800.00
0005434311290	15645	Economy	14800.00
0005434311289	15645	Economy	14800.00
0005434325968	15645	Economy	14800.00
0005433420646	632	Economy	4100.00
0005433420641	632	Economy	4100.00
0005433420645	632	Economy	4100.00
0005435958124	15186	Economy	4500.00
0005435958123	15186	Economy	4100.00
0005435958108	15186	Economy	4100.00
0005435958128	15186	Economy	4100.00
0005435219248	27256	Economy	28100.00
0005435219256	27256	Economy	25500.00
0005435219262	27256	Economy	25500.00
0005435216646	27256	Economy	25500.00
0005435219263	27256	Economy	25500.00
0005435219261	27256	Economy	25500.00
0005435216642	27256	Economy	25500.00
0005435221079	27256	Economy	25500.00
0005435221078	27256	Economy	25500.00
0005435216644	27256	Economy	25500.00
0005435216643	27256	Economy	25500.00
0005435629450	16006	Economy	10400.00
0005434467824	23210	Economy	21200.00
0005434467826	23210	Economy	21200.00
0005434467828	23210	Economy	21200.00
0005434467825	23210	Economy	21200.00
0005434467816	23210	Economy	21200.00
0005434467817	23210	Economy	21200.00
0005435933554	4447	Economy	13400.00
0005435933552	4447	Economy	12200.00
0005435933548	4447	Economy	12200.00
0005435933555	4447	Economy	12200.00
0005435933551	4447	Economy	12200.00
0005435163381	29509	Economy	12200.00
0005435163373	29509	Economy	12200.00
0005435163383	29509	Economy	12200.00
0005435163376	29509	Economy	12200.00
0005435163382	29509	Economy	12200.00
0005435229615	6842	Business	87700.00
0005435229625	6842	Business	87700.00
0005435229637	6842	Business	87700.00
0005435229612	6842	Economy	29200.00
0005435229627	6842	Economy	29200.00
0005435229629	6842	Economy	29200.00
0005435229626	6842	Economy	32200.00
0005435229624	6842	Economy	29200.00
0005435229628	6842	Economy	29200.00
0005435229618	6842	Economy	29200.00
0005435229619	6842	Economy	29200.00
0005435229611	6842	Economy	29200.00
0005435229621	6842	Economy	29200.00
0005435229630	6842	Economy	29200.00
0005435229616	6842	Economy	29200.00
0005435229614	6842	Economy	29200.00
0005435229623	6842	Economy	29200.00
0005433405034	2869	Economy	4200.00
0005433405035	2869	Economy	4200.00
0005435797877	29324	Economy	4200.00
0005435797883	29324	Economy	4200.00
0005435797893	29324	Economy	4200.00
0005435797882	29324	Economy	4200.00
0005435376419	5809	Economy	6800.00
0005435376428	5809	Economy	6800.00
0005433962648	25804	Business	21400.00
0005433962476	25804	Business	21400.00
0005433962499	25804	Business	21400.00
0005433962382	25804	Business	21400.00
0005433962276	25804	Business	21400.00
0005433962578	25804	Business	21400.00
0005433962434	25804	Business	21400.00
0005433962590	25804	Business	21400.00
0005433962469	25804	Business	21400.00
0005433962502	25804	Business	21400.00
0005433962573	25804	Economy	7100.00
0005433962435	25804	Economy	7100.00
0005433962511	25804	Economy	7100.00
0005433962479	25804	Economy	7100.00
0005433962522	25804	Economy	7100.00
0005433962500	25804	Economy	7100.00
0005433962738	25804	Economy	7100.00
0005433962693	25804	Economy	7100.00
0005433962679	25804	Economy	7100.00
0005433962436	25804	Economy	7800.00
0005433962505	25804	Economy	7800.00
0005433962608	25804	Economy	7800.00
0005433962504	25804	Economy	7100.00
0005433962557	25804	Economy	7100.00
0005433962673	25804	Economy	7100.00
0005433962569	25804	Economy	7100.00
0005433962551	25804	Economy	7100.00
0005433962722	25804	Economy	7100.00
0005433962516	25804	Economy	7100.00
0005433962485	25804	Economy	7100.00
0005433962721	25804	Economy	7100.00
0005433962682	25804	Economy	7100.00
0005433962438	25804	Economy	7100.00
0005433962470	25804	Economy	7100.00
0005433962548	25804	Economy	7100.00
0005433962356	25804	Economy	7100.00
0005433962478	25804	Economy	7100.00
0005433962556	25804	Economy	7100.00
0005433962410	25804	Economy	7100.00
0005433962656	25804	Economy	7100.00
0005433962632	25804	Economy	7100.00
0005433962651	25804	Economy	7100.00
0005433962568	25804	Economy	7100.00
0005433962361	25804	Economy	7100.00
0005433962733	25804	Economy	7100.00
0005433962620	25804	Economy	7100.00
0005433962439	25804	Economy	7100.00
0005433962612	25804	Economy	7100.00
0005433962354	25804	Economy	7100.00
0005433962355	25804	Economy	7100.00
0005433962672	25804	Economy	7100.00
0005433962688	25804	Economy	7100.00
0005433962652	25804	Economy	7100.00
0005433962699	25804	Economy	7100.00
0005433962549	25804	Economy	7100.00
0005433962613	25804	Economy	7100.00
0005433962344	25804	Economy	7100.00
0005433962671	25804	Economy	7100.00
0005433962737	25804	Economy	7100.00
0005433962506	25804	Economy	7100.00
0005433962743	25804	Economy	7100.00
0005433962670	25804	Economy	7100.00
0005433962732	25804	Economy	7100.00
0005433962614	25804	Economy	7100.00
0005433962443	25804	Economy	7100.00
0005433962577	25804	Economy	7100.00
0005433962496	25804	Economy	7100.00
0005433962503	25804	Economy	7100.00
0005433962694	25804	Economy	7100.00
0005433962327	25804	Economy	7100.00
0005433962572	25804	Economy	7100.00
0005433962510	25804	Economy	7100.00
0005433962629	25804	Economy	7100.00
0005435083010	24474	Economy	3900.00
0005435083017	24474	Economy	3900.00
0005435082991	24474	Economy	3900.00
0005435083019	24474	Economy	3900.00
0005435082992	24474	Economy	3900.00
0005435083018	24474	Economy	3900.00
0005435083021	24474	Economy	3900.00
0005435083020	24474	Economy	3900.00
0005435083038	24474	Economy	3900.00
0005435083037	24474	Economy	3900.00
0005435083032	24474	Economy	3900.00
0005435083022	24474	Economy	3900.00
0005435286963	5009	Business	18000.00
0005435286803	5009	Business	18000.00
0005435286851	5009	Business	18000.00
0005435286864	5009	Business	18000.00
0005435477010	5009	Business	18000.00
0005435551782	5009	Business	18000.00
0005435286981	5009	Economy	6600.00
0005435287026	5009	Economy	6000.00
0005435286939	5009	Economy	6000.00
0005435286898	5009	Economy	6000.00
0005435286979	5009	Economy	6000.00
0005435477009	5009	Economy	6000.00
0005435286861	5009	Economy	6000.00
0005435286947	5009	Economy	6000.00
0005435286824	5009	Economy	6000.00
0005435287028	5009	Economy	6000.00
0005435286846	5009	Economy	6000.00
0005435286847	5009	Economy	6000.00
0005435287057	5009	Economy	6000.00
0005435286865	5009	Economy	6000.00
0005435287027	5009	Economy	6000.00
0005435286801	5009	Economy	6000.00
0005435286825	5009	Economy	6000.00
0005435287040	5009	Economy	6000.00
0005435286946	5009	Economy	6000.00
0005435287020	5009	Economy	6000.00
0005435286845	5009	Economy	6000.00
0005435287022	5009	Economy	6000.00
0005435286852	5009	Economy	6000.00
0005435286991	5009	Economy	6000.00
0005435286938	5009	Economy	6000.00
0005435286964	5009	Economy	6000.00
0005435286915	5009	Economy	6000.00
0005435286978	5009	Economy	6000.00
0005435287013	5009	Economy	6000.00
0005435286767	5009	Economy	6000.00
0005435286980	5009	Economy	6000.00
0005435287021	5009	Economy	6000.00
0005435286916	5009	Economy	6000.00
0005435551781	5009	Economy	6000.00
0005435286802	5009	Economy	6000.00
0005435286962	5009	Economy	6000.00
0005433685590	5000	Business	18000.00
0005435270170	5000	Business	18000.00
0005435270171	5000	Business	18000.00
0005433815523	5000	Business	18000.00
0005435270110	5000	Business	18000.00
0005434311275	5000	Business	18000.00
0005434312380	5000	Business	18000.00
0005435007714	5000	Business	18000.00
0005434312379	5000	Economy	6600.00
0005433685586	5000	Economy	6000.00
0005435007713	5000	Economy	6000.00
0005435270217	5000	Economy	6000.00
0005435007660	5000	Economy	6000.00
0005433815518	5000	Economy	6000.00
0005433688865	5000	Economy	6000.00
0005433815527	5000	Economy	6000.00
0005435007704	5000	Economy	6000.00
0005435007694	5000	Economy	6000.00
0005432336380	5000	Economy	6000.00
0005435007693	5000	Economy	6000.00
0005435270221	5000	Economy	6000.00
0005435270186	5000	Economy	6000.00
0005433815522	5000	Economy	6000.00
0005435270152	5000	Economy	6000.00
0005435732733	5000	Economy	6000.00
0005432336379	5000	Economy	6000.00
0005435270198	5000	Economy	6000.00
0005435270151	5000	Economy	6000.00
0005435270131	5000	Economy	6600.00
0005433685585	5000	Economy	6000.00
0005435270132	5000	Economy	6000.00
0005434312381	5000	Economy	6000.00
0005435270175	5000	Economy	6000.00
0005435007721	5000	Economy	6000.00
0005435270102	5000	Economy	6000.00
0005435007705	5000	Economy	6000.00
0005435270220	5000	Economy	6000.00
0005435270176	5000	Economy	6000.00
0005435007722	5000	Economy	6000.00
0005435270218	5000	Economy	6000.00
0005432336346	5000	Economy	6000.00
0005433685584	5000	Economy	6000.00
0005435270103	5000	Economy	6000.00
0005433815509	5000	Economy	6000.00
0005433815519	5000	Economy	6000.00
0005432336378	5000	Economy	6000.00
0005435270197	5000	Economy	6000.00
0005435270129	5000	Economy	6000.00
0005432336383	5000	Economy	6000.00
0005433786181	8391	Business	18000.00
0005433785974	8391	Business	18000.00
0005433785973	8391	Business	18000.00
0005433785987	8391	Business	18000.00
0005433786105	8391	Business	18000.00
0005433786141	8391	Business	18000.00
0005434245780	8391	Business	18000.00
0005433786052	8391	Business	18000.00
0005433786079	8391	Business	18000.00
0005433786020	8391	Economy	6600.00
0005433786178	8391	Economy	6600.00
0005433786006	8391	Economy	6600.00
0005433786074	8391	Economy	6000.00
0005433786125	8391	Economy	6000.00
0005433786088	8391	Economy	6000.00
0005434245820	8391	Economy	6000.00
0005433786021	8391	Economy	6000.00
0005433786101	8391	Economy	6000.00
0005433786048	8391	Economy	6000.00
0005432663089	8391	Economy	6000.00
0005433786118	8391	Economy	6000.00
0005433786089	8391	Economy	6000.00
0005432663093	8391	Economy	6000.00
0005433786053	8391	Economy	6000.00
0005434245842	8391	Economy	6000.00
0005432663098	8391	Economy	6000.00
0005433786145	8391	Economy	6000.00
0005432663094	8391	Economy	6600.00
0005433786170	8391	Economy	6600.00
0005433786070	8391	Economy	6600.00
0005433786106	8391	Economy	6000.00
0005433786099	8391	Economy	6000.00
0005433785889	8391	Economy	6000.00
0005433786015	8391	Economy	6000.00
0005434245841	8391	Economy	6000.00
0005433785986	8391	Economy	6000.00
0005433786104	8391	Economy	6000.00
0005433785944	8391	Economy	6000.00
0005433786171	8391	Economy	6000.00
0005433786119	8391	Economy	6000.00
0005433786014	8391	Economy	6000.00
0005433786140	8391	Economy	6000.00
0005433786078	8391	Economy	6000.00
0005433786126	8391	Economy	6000.00
0005433786075	8391	Economy	6000.00
0005432663095	8391	Economy	6000.00
0005433786100	8391	Economy	6000.00
0005433786005	8391	Economy	6000.00
0005433786124	8391	Economy	6000.00
0005434245764	8391	Economy	6000.00
0005433786186	8391	Economy	6000.00
0005433786120	8391	Economy	6000.00
0005433786123	8391	Economy	6000.00
0005434230194	8393	Business	18000.00
0005433616806	8393	Business	18000.00
0005434230192	8393	Business	18000.00
0005433616642	8393	Business	18000.00
0005434230261	8393	Business	18000.00
0005434230149	8393	Business	18000.00
0005434230103	8393	Business	18000.00
0005434230255	8393	Business	18000.00
0005433616811	8393	Business	18000.00
0005434230191	8393	Business	18000.00
0005434230206	8393	Business	18000.00
0005434230131	8393	Economy	6600.00
0005434230119	8393	Economy	6600.00
0005433616733	8393	Economy	6000.00
0005434230165	8393	Economy	6000.00
0005433616726	8393	Economy	6000.00
0005433616695	8393	Economy	6000.00
0005434230257	8393	Economy	6000.00
0005434230173	8393	Economy	6000.00
0005433616659	8393	Economy	6000.00
0005434230196	8393	Economy	6000.00
0005433616704	8393	Economy	6000.00
0005434230144	8393	Economy	6000.00
0005434230195	8393	Economy	6000.00
0005433616732	8393	Economy	6000.00
0005434230167	8393	Economy	6000.00
0005433616758	8393	Economy	6000.00
0005434230147	8393	Economy	6000.00
0005434230091	8393	Economy	6000.00
0005434230211	8393	Economy	6000.00
0005433616777	8393	Economy	6000.00
0005433616694	8393	Economy	6000.00
0005434230259	8393	Economy	6000.00
0005434230168	8393	Economy	6000.00
0005433616537	8393	Economy	6000.00
0005434230204	8393	Economy	6000.00
0005433616805	8393	Economy	6000.00
0005434230053	8393	Economy	6000.00
0005434230268	8393	Economy	6000.00
0005434230118	8393	Economy	6000.00
0005434230086	8393	Economy	6000.00
0005434230283	8393	Economy	6000.00
0005434230059	8393	Economy	6000.00
0005433616737	8393	Economy	6000.00
0005434230163	8393	Economy	6000.00
0005434230056	8393	Economy	6000.00
0005434230178	8393	Economy	6000.00
0005434230114	8393	Economy	6000.00
0005434230177	8393	Economy	6600.00
0005434230176	8393	Economy	6600.00
0005434230166	8393	Economy	6600.00
0005434230164	8393	Economy	6600.00
0005433616827	8393	Economy	6000.00
0005434230266	8393	Economy	6000.00
0005434230205	8393	Economy	6000.00
0005434230256	8393	Economy	6600.00
0005434230284	8393	Economy	6000.00
0005434230071	8393	Economy	6000.00
0005434230085	8393	Economy	6000.00
0005434230105	8393	Economy	6000.00
0005433616524	8393	Economy	6000.00
0005434230158	8393	Economy	6000.00
0005434230087	8393	Economy	6000.00
0005434230193	8393	Economy	6000.00
0005434230207	8393	Economy	6000.00
0005434230052	8393	Economy	6000.00
0005434230143	8393	Economy	6000.00
0005433616715	8393	Economy	6000.00
0005434230083	8393	Economy	6000.00
0005434230133	8393	Economy	6000.00
0005434230172	8393	Economy	6000.00
0005434230203	8393	Economy	6000.00
0005434230174	8393	Economy	6000.00
0005433616740	8393	Economy	6000.00
0005434230182	8393	Economy	6000.00
0005434230160	8393	Economy	6000.00
0005434230258	8393	Economy	6000.00
0005434230115	8393	Economy	6000.00
0005434230084	8393	Economy	6000.00
0005434230148	8393	Economy	6000.00
0005434230051	8393	Economy	6000.00
0005434230134	8393	Economy	6000.00
0005434230282	8393	Economy	6000.00
0005433616778	8393	Economy	6000.00
0005434230117	8393	Economy	6000.00
0005434230210	8393	Economy	6000.00
0005434230126	8393	Economy	6000.00
0005434230236	8393	Economy	6000.00
0005434230034	8397	Business	18000.00
0005434150077	8397	Business	18000.00
0005434150079	8397	Business	18000.00
0005435629448	8397	Business	18000.00
0005435629447	8397	Economy	6600.00
0005434150080	8397	Economy	6000.00
0005434265900	8397	Economy	6000.00
0005434265862	8397	Economy	6000.00
0005434230016	8397	Economy	6000.00
0005434229958	8397	Economy	6000.00
0005435629446	8397	Economy	6000.00
0005434230033	8397	Economy	6000.00
0005434150078	8397	Economy	6000.00
0005435960168	8397	Economy	6600.00
0005434265877	8397	Economy	6000.00
0005434265899	8397	Economy	6000.00
0005434265882	8397	Economy	6000.00
0005434230015	8397	Economy	6000.00
0005434229956	8397	Economy	6000.00
0005434230032	8397	Economy	6000.00
0005434265878	8397	Economy	6000.00
0005434265866	8397	Economy	6000.00
0005434229957	8397	Economy	6000.00
0005434230022	8397	Economy	6000.00
0005434229954	8397	Economy	6000.00
0005434229994	8397	Economy	6000.00
0005434229955	8397	Economy	6000.00
0005434640104	12592	Economy	16200.00
0005434640085	12592	Economy	16200.00
0005434640055	12592	Economy	16200.00
0005434640094	12592	Economy	14800.00
0005434640101	12592	Economy	14800.00
0005434640095	12592	Economy	14800.00
0005434640054	12592	Economy	14800.00
0005434640089	12592	Economy	14800.00
0005434639977	12592	Economy	14800.00
0005434640007	12592	Economy	14800.00
0005434639976	12592	Economy	14800.00
0005434640086	12592	Economy	14800.00
0005434640100	12592	Economy	14800.00
0005434640108	12592	Economy	14800.00
0005434640107	12592	Economy	14800.00
0005433202777	23371	Economy	16200.00
0005433202782	23371	Economy	14800.00
0005433202760	23371	Economy	14800.00
0005433202775	23371	Economy	14800.00
0005433202796	23371	Economy	14800.00
0005433202776	23371	Economy	14800.00
0005433202739	23371	Economy	14800.00
0005433202727	23371	Economy	14800.00
0005433202750	23371	Economy	14800.00
0005433202740	23371	Economy	14800.00
0005433202774	23371	Economy	14800.00
0005433202797	23371	Economy	14800.00
0005432329929	21107	Business	18900.00
0005432384182	21107	Business	18900.00
0005432330044	21107	Economy	6300.00
0005432384251	21107	Economy	6300.00
0005432330045	21107	Economy	6300.00
0005432329970	21107	Economy	6900.00
0005432384316	21107	Economy	6900.00
0005432330024	21107	Economy	6900.00
0005432384318	21107	Economy	6300.00
0005432330050	21107	Economy	6300.00
0005432384299	21107	Economy	6300.00
0005432329981	21107	Economy	6300.00
0005432329980	21107	Economy	6300.00
0005432329949	21107	Economy	6300.00
0005432330023	21107	Economy	6300.00
0005432329971	21107	Economy	6300.00
0005432384295	21107	Economy	6300.00
0005432330043	21107	Economy	6300.00
0005432330010	21107	Economy	6300.00
0005432384317	21107	Economy	6300.00
0005432384284	21107	Economy	6300.00
0005432329990	21107	Economy	6300.00
0005432384242	21107	Economy	6300.00
0005432330059	21107	Economy	6300.00
0005432329992	21107	Economy	6300.00
0005432384319	21107	Economy	6300.00
0005432384183	21107	Economy	6300.00
0005432384254	21107	Economy	6300.00
0005432384324	21107	Economy	6300.00
0005432330046	21107	Economy	6300.00
0005432329991	21107	Economy	6300.00
0005432848915	31269	Economy	6300.00
0005432848916	31269	Economy	6300.00
0005432954153	2482	Business	89600.00
0005432954180	2482	Economy	29900.00
0005432954171	2482	Economy	29900.00
0005432954167	2482	Economy	29900.00
0005432954186	2482	Economy	29900.00
0005432954170	2482	Economy	29900.00
0005432954195	2482	Economy	29900.00
0005432954174	2482	Economy	29900.00
0005432954190	2482	Economy	29900.00
0005432954191	2482	Economy	29900.00
0005432954160	2482	Economy	29900.00
0005432954150	2482	Economy	29900.00
0005432954181	2482	Economy	29900.00
0005432426072	30743	Business	12700.00
0005432425957	30743	Business	12700.00
0005432426010	30743	Business	12700.00
0005432425987	30743	Business	12700.00
0005432425981	30743	Business	12700.00
0005432425967	30743	Business	12700.00
0005432425843	30743	Business	12700.00
0005432425962	30743	Economy	4200.00
0005432425528	30743	Economy	4200.00
0005432425911	30743	Economy	4200.00
0005432425906	30743	Economy	4200.00
0005432425905	30743	Economy	4200.00
0005432425887	30743	Economy	4700.00
0005432425886	30743	Economy	4200.00
0005432426073	30743	Economy	4200.00
0005432425810	30743	Economy	4200.00
0005432425966	30743	Economy	4200.00
0005432425910	30743	Economy	4200.00
0005432426005	30743	Economy	4200.00
0005432425960	30743	Economy	4200.00
0005432425959	30743	Economy	4200.00
0005432425825	30743	Economy	4200.00
0005432425738	30743	Economy	4200.00
0005432426048	30743	Economy	4200.00
0005432425892	30743	Economy	4200.00
0005432425826	30743	Economy	4200.00
0005432425881	30743	Economy	4200.00
0005432426067	30743	Economy	4200.00
0005432425872	30743	Economy	4200.00
0005432426038	30743	Economy	4200.00
0005432425985	30743	Economy	4200.00
0005432425965	30743	Economy	4200.00
0005432426037	30743	Economy	4200.00
0005432426044	30743	Economy	4200.00
0005432426029	30743	Economy	4200.00
0005432425986	30743	Economy	4200.00
0005432426004	30743	Economy	4200.00
0005432426016	30743	Economy	4200.00
0005432425527	30743	Economy	4200.00
0005432425993	30743	Economy	4200.00
0005432426045	30743	Economy	4200.00
0005432425907	30743	Economy	4200.00
0005432425961	30743	Economy	4200.00
0005432425821	30743	Economy	4200.00
0005432425942	30743	Economy	4200.00
0005432425970	30743	Economy	4200.00
0005432425963	30743	Economy	4200.00
0005432425890	30743	Economy	4200.00
0005432426009	30743	Economy	4200.00
0005432425954	30743	Economy	4200.00
0005432425989	30743	Economy	4200.00
0005432902115	9631	Business	32600.00
0005432902106	9631	Business	32600.00
0005432902121	9631	Economy	10900.00
0005432902093	9631	Economy	11900.00
0005434157712	9631	Economy	10900.00
0005432902041	9631	Economy	10900.00
0005434157704	9631	Economy	10900.00
0005432902119	9631	Economy	10900.00
0005432902120	9631	Economy	10900.00
0005432902125	9631	Economy	10900.00
0005432902117	9631	Economy	10900.00
0005432902082	9631	Economy	10900.00
0005432902118	9631	Economy	10900.00
0005432818297	29009	Business	32600.00
0005432818316	29009	Business	32600.00
0005432822408	29009	Business	32600.00
0005434448405	29009	Business	32600.00
0005432818243	29009	Business	32600.00
0005432822409	29009	Economy	10900.00
0005432818333	29009	Economy	11900.00
0005432818317	29009	Economy	10900.00
0005432818278	29009	Economy	10900.00
0005432818242	29009	Economy	10900.00
0005432822434	29009	Economy	10900.00
0005432818312	29009	Economy	10900.00
0005432818308	29009	Economy	10900.00
0005432822432	29009	Economy	10900.00
0005432818323	29009	Economy	10900.00
0005434448410	29009	Economy	10900.00
0005432818318	29009	Economy	10900.00
0005432822433	29009	Economy	10900.00
0005432818321	29009	Economy	10900.00
0005434448409	29009	Economy	10900.00
0005435841123	15125	Economy	11000.00
0005435841127	15125	Economy	11000.00
0005435841128	15125	Economy	11000.00
0005432949629	11841	Business	105900.00
0005432949663	11841	Business	105900.00
0005432949528	11841	Business	105900.00
0005432949641	11841	Business	105900.00
0005432949662	11841	Business	105900.00
0005432949513	11841	Business	105900.00
0005432949640	11841	Economy	35300.00
0005432949517	11841	Economy	35300.00
0005432949680	11841	Economy	35300.00
0005432949508	11841	Economy	35300.00
0005432949585	11841	Economy	38800.00
0005432949653	11841	Economy	35300.00
0005432949645	11841	Economy	35300.00
0005432949603	11841	Economy	35300.00
0005432949565	11841	Economy	35300.00
0005432949654	11841	Economy	35300.00
0005432949520	11841	Economy	35300.00
0005432949655	11841	Economy	35300.00
0005432949584	11841	Economy	35300.00
0005432949639	11841	Economy	35300.00
0005432949519	11841	Economy	35300.00
0005432949518	11841	Economy	35300.00
0005432949514	11841	Economy	35300.00
0005432949580	11841	Economy	35300.00
0005432949564	11841	Economy	35300.00
0005432949594	11841	Economy	35300.00
0005432949646	11841	Economy	35300.00
0005432949581	11841	Economy	35300.00
0005432949630	11841	Economy	35300.00
0005432949681	11841	Economy	35300.00
0005433570964	25325	Business	105900.00
0005433570947	25325	Business	105900.00
0005433570817	25325	Business	105900.00
0005433570926	25325	Business	105900.00
0005433570913	25325	Business	105900.00
0005433570698	25325	Business	105900.00
0005433570890	25325	Business	105900.00
0005433570597	25325	Economy	35300.00
0005433570915	25325	Economy	35300.00
0005433570760	25325	Economy	35300.00
0005433570676	25325	Economy	35300.00
0005433570697	25325	Economy	38800.00
0005433570783	25325	Economy	35300.00
0005433570942	25325	Economy	35300.00
0005433570737	25325	Economy	35300.00
0005433570779	25325	Economy	35300.00
0005433570780	25325	Economy	35300.00
0005433570713	25325	Economy	35300.00
0005433570747	25325	Economy	35300.00
0005433570889	25325	Economy	35300.00
0005433570869	25325	Economy	35300.00
0005433570981	25325	Economy	35300.00
0005433570899	25325	Economy	35300.00
0005433570855	25325	Economy	35300.00
0005433570596	25325	Economy	35300.00
0005433570914	25325	Economy	35300.00
0005433570832	25325	Economy	35300.00
0005433570675	25325	Economy	35300.00
0005433570927	25325	Economy	35300.00
0005433570801	25325	Economy	35300.00
0005433570782	25325	Economy	35300.00
0005433570916	25325	Economy	35300.00
0005433570823	25325	Economy	35300.00
0005433570881	25325	Economy	35300.00
0005433570941	25325	Economy	35300.00
0005433570736	25325	Economy	35300.00
0005433570932	25325	Economy	35300.00
0005433570917	25325	Economy	35300.00
0005433808486	14471	Business	117400.00
0005433808485	14471	Economy	39100.00
0005433808480	14471	Economy	39100.00
0005433808479	14471	Economy	39100.00
0005433808461	14471	Economy	39100.00
0005433808462	14471	Economy	39100.00
0005433808483	14471	Economy	39100.00
0005433812966	14471	Economy	39100.00
0005432430964	30836	Business	117400.00
0005432430966	30836	Business	117400.00
0005432430972	30836	Economy	39100.00
0005432430971	30836	Economy	39100.00
0005434026745	30836	Economy	39100.00
0005434026744	30836	Economy	39100.00
0005432430963	30836	Economy	39100.00
0005434026751	30836	Economy	39100.00
0005432430970	30836	Economy	39100.00
0005432430965	30836	Economy	39100.00
0005435340708	5408	Economy	24600.00
0005435340706	5408	Economy	22400.00
0005435340707	5408	Economy	22400.00
0005434655480	12513	Business	67200.00
0005434655532	12513	Business	67200.00
0005434655534	12513	Business	67200.00
0005434655481	12513	Economy	22400.00
0005434655517	12513	Economy	22400.00
0005434655526	12513	Economy	22400.00
0005434655527	12513	Economy	24600.00
0005434655496	12513	Economy	24600.00
0005434655533	12513	Economy	24600.00
0005434655528	12513	Economy	22400.00
0005434655531	12513	Economy	22400.00
0005434655524	12513	Economy	22400.00
0005434655518	12513	Economy	22400.00
0005434655525	12513	Economy	22400.00
0005434655529	12513	Economy	22400.00
0005432429022	7412	Economy	10700.00
0005432429029	7412	Economy	10700.00
0005435266343	7412	Economy	10700.00
0005432429028	7412	Economy	10700.00
0005432429023	7412	Economy	10700.00
0005435266333	7412	Economy	10700.00
0005432429024	7412	Economy	10700.00
0005433722431	29243	Business	32000.00
0005433719239	29243	Business	32000.00
0005433717398	29243	Business	32000.00
0005433717415	29243	Business	32000.00
0005433722492	29243	Business	32000.00
0005433717353	29243	Business	32000.00
0005433722479	29243	Business	32000.00
0005433719233	29243	Economy	10700.00
0005433722483	29243	Economy	10700.00
0005433656758	29243	Economy	10700.00
0005433719226	29243	Economy	10700.00
0005433719234	29243	Economy	10700.00
0005433656759	29243	Economy	10700.00
0005433685590	29243	Economy	10700.00
0005433722504	29243	Economy	10700.00
0005433722502	29243	Economy	10700.00
0005433717310	29243	Economy	10700.00
0005433722494	29243	Economy	10700.00
0005433722446	29243	Economy	10700.00
0005433722454	29243	Economy	10700.00
0005433717322	29243	Economy	10700.00
0005433685584	29243	Economy	10700.00
0005433717401	29243	Economy	10700.00
0005433722480	29243	Economy	10700.00
0005433722465	29243	Economy	11700.00
0005433717294	29243	Economy	11700.00
0005433717321	29243	Economy	10700.00
0005433717341	29243	Economy	10700.00
0005433722445	29243	Economy	10700.00
0005433685586	29243	Economy	10700.00
0005433717285	29243	Economy	10700.00
0005433656767	29243	Economy	10700.00
0005433685585	29243	Economy	10700.00
0005433717405	29243	Economy	10700.00
0005433722478	29243	Economy	10700.00
0005433722489	29243	Economy	10700.00
0005433722426	29243	Economy	10700.00
0005433717428	29243	Economy	10700.00
0005433722490	29243	Economy	10700.00
0005433717400	29243	Economy	10700.00
0005433688865	29243	Economy	10700.00
0005433722493	29243	Economy	10700.00
0005433722464	29243	Economy	10700.00
0005433656766	29243	Economy	10700.00
0005433722466	29243	Economy	10700.00
0005433717402	29243	Economy	10700.00
0005433717311	29243	Economy	10700.00
0005433717429	29243	Economy	10700.00
0005434184725	8679	Economy	12200.00
0005435860722	8679	Economy	12200.00
0005434182544	8679	Economy	12200.00
0005435860696	8679	Economy	12200.00
0005435860697	8679	Economy	12200.00
0005435860698	8679	Economy	12200.00
0005434182529	8679	Economy	12200.00
0005435860721	8679	Economy	12200.00
0005434143812	11658	Business	36500.00
0005434143810	11658	Business	36500.00
0005434143830	11658	Business	36500.00
0005434095697	11658	Economy	12200.00
0005434143815	11658	Economy	12200.00
0005434326302	11658	Economy	12200.00
0005434095682	11658	Economy	13400.00
0005434143829	11658	Economy	13400.00
0005434143835	11658	Economy	12200.00
0005434095626	11658	Economy	12200.00
0005434095701	11658	Economy	12200.00
0005434143828	11658	Economy	12200.00
0005434143792	11658	Economy	12200.00
0005434143836	11658	Economy	12200.00
0005434143813	11658	Economy	12200.00
0005434143811	11658	Economy	12200.00
0005434095702	11658	Economy	12200.00
0005434095698	11658	Economy	12200.00
0005434143826	11658	Economy	12200.00
0005434095681	11658	Economy	12200.00
0005434095700	11658	Economy	12200.00
0005434143827	11658	Economy	12200.00
0005434326089	11658	Economy	12200.00
0005434095703	11658	Economy	12200.00
0005434143755	11658	Economy	12200.00
0005434143825	11658	Economy	12200.00
0005434143814	11658	Economy	12200.00
0005434143831	11658	Economy	12200.00
0005434095680	11658	Economy	12200.00
0005433399412	1433	Business	33000.00
0005433399413	1433	Business	33000.00
0005433399380	1433	Business	33000.00
0005433399438	1433	Business	33000.00
0005433399360	1433	Economy	11000.00
0005433399359	1433	Economy	11000.00
0005433399379	1433	Economy	12100.00
0005433399439	1433	Economy	11000.00
0005433399411	1433	Economy	11000.00
0005433399305	1433	Economy	11000.00
0005433399427	1433	Economy	11000.00
0005433399414	1433	Economy	11000.00
0005433399458	1433	Economy	11000.00
0005433399306	1433	Economy	11000.00
0005432906607	1433	Economy	11000.00
0005433399255	1433	Economy	11000.00
0005432906608	1433	Economy	11000.00
0005432906606	1433	Economy	11000.00
0005433399401	1433	Economy	11000.00
0005432906609	1433	Economy	11000.00
0005435732723	19237	Business	33000.00
0005435732705	19237	Economy	11000.00
0005435732672	19237	Economy	11000.00
0005435732678	19237	Economy	12100.00
0005435732682	19237	Economy	11000.00
0005435732724	19237	Economy	11000.00
0005435732683	19237	Economy	11000.00
0005434444171	17333	Economy	14100.00
0005434444168	17333	Economy	14100.00
0005434444183	17333	Economy	14100.00
0005434444167	17333	Economy	14100.00
0005434444172	17333	Economy	14100.00
0005434444173	17333	Economy	14100.00
0005434444169	17333	Economy	14100.00
0005434444182	17333	Economy	14100.00
0005434444170	17333	Economy	14100.00
0005434444174	17333	Economy	14100.00
0005435377644	7261	Economy	5800.00
0005435377645	7261	Economy	5800.00
0005434182548	4481	Economy	14000.00
0005434326100	29673	Economy	15400.00
0005434326101	29673	Economy	14000.00
0005434352053	29673	Economy	14000.00
0005433346058	1043	Business	30600.00
0005433346027	1043	Business	30600.00
0005433345680	1043	Business	30600.00
0005433345959	1043	Business	30600.00
0005433345996	1043	Economy	10200.00
0005433345910	1043	Economy	10200.00
0005433345807	1043	Economy	10200.00
0005433345953	1043	Economy	10200.00
0005433346012	1043	Economy	10200.00
0005433346083	1043	Economy	10200.00
0005433269877	1043	Economy	10200.00
0005433345846	1043	Economy	10200.00
0005433345773	1043	Economy	10200.00
0005433345825	1043	Economy	10200.00
0005433345776	1043	Economy	10200.00
0005433345960	1043	Economy	10200.00
0005433345824	1043	Economy	10200.00
0005433345918	1043	Economy	10200.00
0005433345997	1043	Economy	10200.00
0005433345785	1043	Economy	10200.00
0005433345795	1043	Economy	11200.00
0005433345964	1043	Economy	10200.00
0005433346010	1043	Economy	10200.00
0005433345553	1043	Economy	10200.00
0005433345552	1043	Economy	10200.00
0005433346009	1043	Economy	10200.00
0005433345806	1043	Economy	10200.00
0005433345939	1043	Economy	10200.00
0005433345786	1043	Economy	10200.00
0005433345927	1043	Economy	10200.00
0005433269874	1043	Economy	10200.00
0005433346034	1043	Economy	10200.00
0005433269867	1043	Economy	10200.00
0005433345993	1043	Economy	10200.00
0005433345944	1043	Economy	10200.00
0005433345897	1043	Economy	10200.00
0005433345954	1043	Economy	10200.00
0005433345694	1043	Economy	10200.00
0005433346011	1043	Economy	10200.00
0005433345774	1043	Economy	10200.00
0005435545993	17051	Business	30600.00
0005435530165	17051	Business	30600.00
0005435508811	17051	Business	30600.00
0005435530178	17051	Business	30600.00
0005435508814	17051	Business	30600.00
0005435508775	17051	Business	30600.00
0005435508750	17051	Business	30600.00
0005435092361	17051	Economy	11200.00
0005435545994	17051	Economy	10200.00
0005435092363	17051	Economy	10200.00
0005435508819	17051	Economy	10200.00
0005435545995	17051	Economy	10200.00
0005435508800	17051	Economy	10200.00
0005435508762	17051	Economy	10200.00
0005435545998	17051	Economy	10200.00
0005435508773	17051	Economy	10200.00
0005435508774	17051	Economy	10200.00
0005435092362	17051	Economy	10200.00
0005434445315	17051	Economy	10200.00
0005434445316	17051	Economy	10200.00
0005435530092	17051	Economy	10200.00
0005435508792	17051	Economy	10200.00
0005435530158	17051	Economy	10200.00
0005435508776	17051	Economy	10200.00
0005435508785	17051	Economy	11200.00
0005435508791	17051	Economy	11200.00
0005435508808	17051	Economy	10200.00
0005435508799	17051	Economy	10200.00
0005435092364	17051	Economy	10200.00
0005435508769	17051	Economy	10200.00
0005435508798	17051	Economy	10200.00
0005435530160	17051	Economy	10200.00
0005435508818	17051	Economy	10200.00
0005435530161	17051	Economy	10200.00
0005435545999	17051	Economy	10200.00
0005435508825	17051	Economy	10200.00
0005432390398	18273	Business	101000.00
0005432390450	18273	Business	101000.00
0005432390468	18273	Business	101000.00
0005432390426	18273	Business	101000.00
0005432390471	18273	Business	101000.00
0005432390399	18273	Business	101000.00
0005432390478	18273	Economy	33700.00
0005432392069	18273	Economy	33700.00
0005432390458	18273	Economy	33700.00
0005432390470	18273	Economy	33700.00
0005432390462	18273	Economy	33700.00
0005432392077	18273	Economy	33700.00
0005432390459	18273	Economy	37000.00
0005432390400	18273	Economy	37000.00
0005432392074	18273	Economy	33700.00
0005432390385	18273	Economy	33700.00
0005432390466	18273	Economy	33700.00
0005432392076	18273	Economy	33700.00
0005432390481	18273	Economy	33700.00
0005432390451	18273	Economy	33700.00
0005432390452	18273	Economy	33700.00
0005432390449	18273	Economy	33700.00
0005432392080	18273	Economy	33700.00
0005432392078	18273	Economy	33700.00
0005432390467	18273	Economy	33700.00
0005432390469	18273	Economy	33700.00
0005432392081	18273	Economy	33700.00
0005432390483	18273	Economy	33700.00
0005432392075	18273	Economy	33700.00
0005432390401	18273	Economy	33700.00
0005432390461	18273	Economy	33700.00
0005432390472	18273	Economy	33700.00
0005432390477	18273	Economy	33700.00
0005432390473	18273	Economy	33700.00
0005432390463	18273	Economy	33700.00
0005432390482	18273	Economy	33700.00
0005432392079	18273	Economy	33700.00
0005432390394	18273	Economy	33700.00
0005434069564	12801	Business	40300.00
0005434069619	12801	Business	40300.00
0005434069569	12801	Business	40300.00
0005434082569	12801	Business	40300.00
0005434069299	12801	Business	40300.00
0005434069366	12801	Economy	13400.00
0005434069497	12801	Economy	13400.00
0005434082611	12801	Economy	13400.00
0005434069492	12801	Economy	13400.00
0005434082606	12801	Economy	13400.00
0005433989889	12801	Economy	13400.00
0005434069610	12801	Economy	13400.00
0005434069635	12801	Economy	13400.00
0005434069489	12801	Economy	13400.00
0005434082568	12801	Economy	13400.00
0005434069620	12801	Economy	13400.00
0005434069526	12801	Economy	13400.00
0005434069618	12801	Economy	13400.00
0005434069527	12801	Economy	13400.00
0005434082637	12801	Economy	13400.00
0005434082567	12801	Economy	13400.00
0005434069365	12801	Economy	13400.00
0005434069615	12801	Economy	13400.00
0005434082627	12801	Economy	13400.00
0005434069570	12801	Economy	13400.00
0005434082571	12801	Economy	13400.00
0005434069479	12801	Economy	13400.00
0005434082540	12801	Economy	13400.00
0005434069449	12801	Economy	13400.00
0005434082541	12801	Economy	13400.00
0005434069639	12801	Economy	13400.00
0005434082640	12801	Economy	13400.00
0005434082629	12801	Economy	13400.00
0005434069486	12801	Economy	13400.00
0005434082610	12801	Economy	13400.00
0005434082630	12801	Economy	13400.00
0005434026762	12801	Economy	13400.00
0005434082544	12801	Economy	13400.00
0005434069634	12801	Economy	13400.00
0005433989888	12801	Economy	13400.00
0005434082570	12801	Economy	13400.00
0005434069533	12801	Economy	13400.00
0005434069529	12801	Economy	13400.00
0005434069304	12801	Economy	13400.00
0005434069554	12801	Economy	13400.00
0005434082638	12801	Economy	13400.00
0005435283550	30686	Business	40300.00
0005435860642	30686	Business	40300.00
0005435283547	30686	Business	40300.00
0005435283492	30686	Business	40300.00
0005435283493	30686	Economy	13400.00
0005435283469	30686	Economy	13400.00
0005435283478	30686	Economy	13400.00
0005435283534	30686	Economy	13400.00
0005435860640	30686	Economy	13400.00
0005435283485	30686	Economy	13400.00
0005435283477	30686	Economy	13400.00
0005435283533	30686	Economy	13400.00
0005435283518	30686	Economy	13400.00
0005435283549	30686	Economy	13400.00
0005435283508	30686	Economy	13400.00
0005435283476	30686	Economy	13400.00
0005435283548	30686	Economy	13400.00
0005435283486	30686	Economy	13400.00
0005433686678	19360	Economy	17600.00
0005433686685	19360	Economy	17600.00
0005433686691	19360	Economy	17600.00
0005433686697	19360	Economy	17600.00
0005433686687	19360	Economy	17600.00
0005433686681	19360	Economy	17600.00
0005433686680	19360	Economy	17600.00
0005433689963	19360	Economy	17600.00
0005433686679	19360	Economy	17600.00
0005433686686	19360	Economy	17600.00
0005433686696	19360	Economy	17600.00
0005433686692	19360	Economy	17600.00
0005434265843	5541	Business	35300.00
0005432535970	5541	Business	35300.00
0005435043305	5541	Economy	11800.00
0005434265847	5541	Economy	11800.00
0005435463501	5541	Economy	11800.00
0005434265881	5541	Economy	11800.00
0005435617198	5541	Economy	11800.00
0005432535979	5541	Economy	11800.00
0005434265865	5541	Economy	11800.00
0005435617212	5541	Economy	11800.00
0005435043306	5541	Economy	11800.00
0005435463523	5541	Economy	11800.00
0005434265825	5541	Economy	11800.00
0005435617205	5541	Economy	11800.00
0005435617213	5541	Economy	11800.00
0005434265897	5541	Economy	11800.00
0005435617199	5541	Economy	11800.00
0005435463500	5541	Economy	11800.00
0005435463453	5541	Economy	11800.00
0005434265826	5541	Economy	11800.00
0005435617206	5541	Economy	11800.00
0005434265896	5541	Economy	11800.00
0005435463533	5541	Economy	11800.00
0005435463514	5541	Economy	11800.00
0005434265848	5541	Economy	11800.00
0005435463427	5541	Economy	11800.00
0005435463424	5541	Economy	11800.00
0005434265844	5541	Economy	11800.00
0005434265839	5541	Economy	11800.00
0005435463519	5541	Economy	11800.00
0005434831280	5541	Economy	11800.00
0005435735276	13499	Business	35300.00
0005435768088	13499	Business	35300.00
0005435735274	13499	Business	35300.00
0005435723107	13499	Business	35300.00
0005435735277	13499	Business	35300.00
0005435768028	13499	Business	35300.00
0005435722122	13499	Business	35300.00
0005435735278	13499	Economy	11800.00
0005435722121	13499	Economy	11800.00
0005435732733	13499	Economy	11800.00
0005435723108	13499	Economy	11800.00
0005435768035	13499	Economy	11800.00
0005435735275	13499	Economy	11800.00
0005435768070	13499	Economy	11800.00
0005435768008	13499	Economy	11800.00
0005435768065	13499	Economy	11800.00
0005435768032	13499	Economy	11800.00
0005435768017	13499	Economy	11800.00
0005435768087	13499	Economy	11800.00
0005435768005	13499	Economy	11800.00
0005435768089	13499	Economy	11800.00
0005435768016	13499	Economy	11800.00
0005435768029	13499	Economy	11800.00
0005435767878	13499	Economy	11800.00
0005435768030	13499	Economy	11800.00
0005435725740	13499	Economy	11800.00
0005435768117	13499	Economy	11800.00
0005435768078	13499	Economy	11800.00
0005435768116	13499	Economy	11800.00
0005434602981	18749	Economy	3300.00
0005434602974	18749	Economy	3300.00
0005434602978	18749	Economy	3300.00
0005434602977	18749	Economy	3300.00
0005434604992	18753	Economy	3300.00
0005434605003	18753	Economy	3300.00
0005435904728	19221	Economy	3300.00
0005435904727	19221	Economy	3300.00
0005435904726	19221	Economy	3300.00
0005435904489	19221	Economy	3300.00
0005435904491	19221	Economy	3300.00
0005432649567	25077	Business	88300.00
0005432632903	25077	Business	88300.00
0005432649568	25077	Economy	29400.00
0005432632904	25077	Economy	29400.00
0005432632931	25077	Economy	29400.00
0005432632930	25077	Economy	29400.00
0005432632909	25077	Economy	29400.00
0005432632918	25077	Economy	29400.00
0005432632932	25077	Economy	29400.00
0005432632908	25077	Economy	29400.00
0005432632917	25077	Economy	29400.00
0005432632929	25077	Economy	29400.00
0005432632934	25077	Economy	29400.00
0005432649571	25077	Economy	29400.00
0005432632922	25077	Economy	29400.00
0005432632936	25077	Economy	29400.00
0005432632933	25077	Economy	29400.00
0005432649572	25077	Economy	29400.00
0005433286221	1779	Business	48700.00
0005433286187	1779	Business	48700.00
0005433009961	1779	Business	48700.00
0005433009955	1779	Business	48700.00
0005433009828	1779	Business	48700.00
0005433286164	1779	Economy	16200.00
0005433286168	1779	Economy	16200.00
0005433286165	1779	Economy	16200.00
0005433009974	1779	Economy	17900.00
0005433286167	1779	Economy	16200.00
0005433009829	1779	Economy	16200.00
0005433009917	1779	Economy	16200.00
0005433009975	1779	Economy	16200.00
0005433286214	1779	Economy	16200.00
0005433009918	1779	Economy	16200.00
0005433009889	1779	Economy	16200.00
0005433009932	1779	Economy	16200.00
0005433286186	1779	Economy	16200.00
0005433009895	1779	Economy	16200.00
0005433009947	1779	Economy	16200.00
0005433009973	1779	Economy	16200.00
0005433009948	1779	Economy	16200.00
0005433286155	1779	Economy	16200.00
0005433286220	1779	Economy	16200.00
0005433286180	1779	Economy	16200.00
0005433810746	22623	Business	48700.00
0005435097510	22623	Business	48700.00
0005433810732	22623	Economy	16200.00
0005435725772	22623	Economy	16200.00
0005433810711	22623	Economy	16200.00
0005435725774	22623	Economy	16200.00
0005435097511	22623	Economy	16200.00
0005435725764	22623	Economy	17900.00
0005435725759	22623	Economy	16200.00
0005435725769	22623	Economy	16200.00
0005435725775	22623	Economy	16200.00
0005433810738	22623	Economy	16200.00
0005435725760	22623	Economy	16200.00
0005433810762	22623	Economy	16200.00
0005435725765	22623	Economy	16200.00
0005433810739	22623	Economy	16200.00
0005433810731	22623	Economy	16200.00
0005434153568	25345	Business	83800.00
0005434153577	25345	Business	83800.00
0005434153578	25345	Economy	27900.00
0005434153571	25345	Economy	30700.00
0005434153574	25345	Economy	30700.00
0005434152834	25345	Economy	27900.00
0005434153565	25345	Economy	27900.00
0005434152842	25345	Economy	27900.00
0005434152845	25345	Economy	27900.00
0005434152840	25345	Economy	27900.00
0005434152846	25345	Economy	27900.00
0005434152841	25345	Economy	27900.00
0005434153576	25345	Economy	27900.00
0005434153564	25345	Economy	27900.00
0005434152833	25345	Economy	27900.00
0005434153575	25345	Economy	27900.00
0005435283171	5553	Business	99800.00
0005435283215	5553	Business	99800.00
0005435283242	5553	Business	99800.00
0005435283217	5553	Economy	33300.00
0005435283241	5553	Economy	33300.00
0005435283203	5553	Economy	33300.00
0005435283250	5553	Economy	33300.00
0005435283243	5553	Economy	33300.00
0005433815518	13868	Business	99800.00
0005433848400	13868	Business	99800.00
0005433815522	13868	Business	99800.00
0005433848372	13868	Business	99800.00
0005433848396	13868	Economy	33300.00
0005433848406	13868	Economy	33300.00
0005433848384	13868	Economy	33300.00
0005433848352	13868	Economy	33300.00
0005433848351	13868	Economy	33300.00
0005433848402	13868	Economy	33300.00
0005433848192	13868	Economy	33300.00
0005433815523	13868	Economy	33300.00
0005433848401	13868	Economy	33300.00
0005433848383	13868	Economy	33300.00
0005433815509	13868	Economy	33300.00
0005433815527	13868	Economy	33300.00
0005433848395	13868	Economy	33300.00
0005433815519	13868	Economy	33300.00
0005433848379	13868	Economy	33300.00
0005433848198	13868	Economy	33300.00
0005433848197	13868	Economy	33300.00
0005433848407	13868	Economy	33300.00
0005433848380	13868	Economy	33300.00
0005433848387	13868	Economy	33300.00
0005433848339	13868	Economy	33300.00
0005435332639	7818	Economy	15100.00
0005434621173	32964	Economy	15100.00
0005434621172	32964	Economy	15100.00
0005434621122	32964	Economy	15100.00
0005434621155	32964	Economy	15100.00
0005434621154	32964	Economy	15100.00
0005434621153	32964	Economy	15100.00
0005434621165	32964	Economy	15100.00
0005435937557	4311	Economy	12700.00
0005435937556	4311	Economy	12700.00
0005435937562	4311	Economy	12700.00
0005435937560	4311	Economy	12700.00
0005434994273	27324	Economy	12700.00
0005435786298	27324	Economy	13900.00
0005435786326	27324	Economy	12700.00
0005435937574	27324	Economy	12700.00
0005435787406	27324	Economy	12700.00
0005435786215	27324	Economy	12700.00
0005435786216	27324	Economy	12700.00
0005435786302	27324	Economy	12700.00
0005435786145	27324	Economy	12700.00
0005435787405	27324	Economy	12700.00
0005435786243	27324	Economy	12700.00
0005435786353	27324	Economy	12700.00
0005435786343	27324	Economy	12700.00
0005435786153	27324	Economy	12700.00
0005435786337	27324	Economy	12700.00
0005435786146	27324	Economy	12700.00
0005435786328	27324	Economy	12700.00
0005435786217	27324	Economy	12700.00
0005435786329	27324	Economy	12700.00
0005435786342	27324	Economy	12700.00
0005435786168	27324	Economy	12700.00
0005435786341	27324	Economy	12700.00
0005435786327	27324	Economy	12700.00
0005435840512	4748	Economy	13600.00
0005434150168	4748	Economy	13600.00
0005435840470	4748	Economy	13600.00
0005434150185	4748	Economy	13600.00
0005435840493	4748	Economy	13600.00
0005434150222	4748	Economy	13600.00
0005435860639	4748	Economy	13600.00
0005434150186	4748	Economy	15000.00
0005435860637	4748	Economy	13600.00
0005435840513	4748	Economy	13600.00
0005435840514	4748	Economy	13600.00
0005434150220	4748	Economy	13600.00
0005435840469	4748	Economy	13600.00
0005435840432	4748	Economy	13600.00
0005434150232	4748	Economy	13600.00
0005434082570	30533	Business	40900.00
0005434082540	30533	Business	40900.00
0005434082606	30533	Business	40900.00
0005432571431	30533	Business	40900.00
0005432461394	30533	Business	40900.00
0005434082610	30533	Business	40900.00
0005434082638	30533	Business	40900.00
0005432461354	30533	Business	40900.00
0005432461327	30533	Business	40900.00
0005432569154	30533	Business	40900.00
0005434082567	30533	Business	40900.00
0005432461369	30533	Economy	15000.00
0005432461408	30533	Economy	13600.00
0005432571433	30533	Economy	13600.00
0005432461323	30533	Economy	13600.00
0005432571432	30533	Economy	13600.00
0005432461347	30533	Economy	13600.00
0005432461392	30533	Economy	13600.00
0005432461411	30533	Economy	13600.00
0005432461368	30533	Economy	13600.00
0005432569354	30533	Economy	13600.00
0005432461416	30533	Economy	13600.00
0005432569333	30533	Economy	13600.00
0005432569294	30533	Economy	13600.00
0005432461297	30533	Economy	13600.00
0005432461350	30533	Economy	13600.00
0005432569398	30533	Economy	13600.00
0005432569362	30533	Economy	13600.00
0005432461433	30533	Economy	13600.00
0005432461356	30533	Economy	13600.00
0005432569313	30533	Economy	13600.00
0005432569153	30533	Economy	13600.00
0005434082571	30533	Economy	13600.00
0005434082541	30533	Economy	13600.00
0005432461364	30533	Economy	13600.00
0005432569377	30533	Economy	13600.00
0005434082637	30533	Economy	13600.00
0005432461355	30533	Economy	13600.00
0005432569392	30533	Economy	13600.00
0005432569334	30533	Economy	13600.00
0005432461299	30533	Economy	13600.00
0005432569412	30533	Economy	13600.00
0005432461361	30533	Economy	15000.00
0005433454934	30533	Economy	13600.00
0005434082568	30533	Economy	13600.00
0005434082629	30533	Economy	13600.00
0005432461346	30533	Economy	13600.00
0005432461376	30533	Economy	13600.00
0005434082611	30533	Economy	13600.00
0005432461393	30533	Economy	13600.00
0005432461410	30533	Economy	13600.00
0005434082640	30533	Economy	13600.00
0005432569295	30533	Economy	13600.00
0005434082569	30533	Economy	13600.00
0005432569402	30533	Economy	13600.00
0005432461336	30533	Economy	13600.00
0005432461390	30533	Economy	13600.00
0005432461373	30533	Economy	13600.00
0005434082630	30533	Economy	13600.00
0005434082544	30533	Economy	13600.00
0005432569299	30533	Economy	13600.00
0005432569361	30533	Economy	13600.00
0005432571428	30533	Economy	13600.00
0005432461363	30533	Economy	13600.00
0005434082627	30533	Economy	13600.00
0005432569355	30533	Economy	13600.00
0005435722120	21144	Economy	9900.00
0005435720167	21144	Economy	9900.00
0005435725779	13727	Economy	9700.00
0005435725768	13727	Economy	8800.00
0005435725754	13727	Economy	8800.00
0005435725757	13727	Economy	8800.00
0005435725766	13727	Economy	8800.00
0005435725756	13727	Economy	8800.00
0005435725755	13727	Economy	8800.00
0005435725763	13727	Economy	8800.00
0005435725767	13727	Economy	8800.00
0005435508737	11087	Business	23600.00
0005435508787	11087	Economy	7900.00
0005435530180	11087	Economy	7900.00
0005435530172	11087	Economy	7900.00
0005435508788	11087	Economy	7900.00
0005435530195	11087	Economy	7900.00
0005435508779	11087	Economy	8600.00
0005435380430	11087	Economy	7900.00
0005435508736	11087	Economy	7900.00
0005435508795	11087	Economy	7900.00
0005435530181	11087	Economy	7900.00
0005435530171	11087	Economy	7900.00
0005435508796	11087	Economy	7900.00
0005435508755	11087	Economy	7900.00
0005435546002	11087	Economy	7900.00
0005435508789	11087	Economy	7900.00
0005435508797	11087	Economy	7900.00
0005435508782	11087	Economy	7900.00
0005435508756	11087	Economy	7900.00
0005435530190	11087	Economy	7900.00
0005433345806	17138	Business	23600.00
0005433345776	17138	Business	23600.00
0005433346012	17138	Economy	7900.00
0005433345927	17138	Economy	7900.00
0005433345918	17138	Economy	7900.00
0005433345774	17138	Economy	7900.00
0005433345795	17138	Economy	7900.00
0005435097493	17138	Economy	7900.00
0005433345997	17138	Economy	7900.00
0005433345846	17138	Economy	8600.00
0005433345552	17138	Economy	8600.00
0005433345993	17138	Economy	8600.00
0005433346058	17138	Economy	7900.00
0005433345785	17138	Economy	7900.00
0005433346010	17138	Economy	7900.00
0005433346083	17138	Economy	7900.00
0005433345824	17138	Economy	7900.00
0005433345553	17138	Economy	7900.00
0005433345773	17138	Economy	7900.00
0005433345694	17138	Economy	7900.00
0005433345960	17138	Economy	7900.00
0005433345964	17138	Economy	7900.00
0005433345897	17138	Economy	7900.00
0005433345939	17138	Economy	7900.00
0005433345786	17138	Economy	7900.00
0005433345910	17138	Economy	7900.00
0005433346011	17138	Economy	7900.00
0005433345954	17138	Economy	7900.00
0005433345944	17138	Economy	7900.00
0005433345680	17138	Economy	7900.00
0005433345959	17138	Economy	7900.00
0005433346034	17138	Economy	7900.00
0005433345953	17138	Economy	7900.00
0005433345807	17138	Economy	7900.00
0005433346009	17138	Economy	7900.00
0005433345996	17138	Economy	7900.00
0005433346027	17138	Economy	7900.00
0005433345825	17138	Economy	7900.00
0005432920466	9119	Business	26600.00
0005434159060	9119	Economy	8900.00
0005432920477	9119	Economy	8900.00
0005432920451	9119	Economy	8900.00
0005432920464	9119	Economy	8900.00
0005432920452	9119	Economy	8900.00
0005432920465	9119	Economy	8900.00
0005433477196	20434	Business	26600.00
0005433477216	20434	Business	26600.00
0005433477214	20434	Economy	9800.00
0005433507709	20434	Economy	9800.00
0005433477249	20434	Economy	8900.00
0005433477235	20434	Economy	8900.00
0005433477260	20434	Economy	8900.00
0005433507723	20434	Economy	8900.00
0005433477277	20434	Economy	8900.00
0005433477252	20434	Economy	8900.00
0005433507708	20434	Economy	8900.00
0005433477234	20434	Economy	8900.00
0005433477259	20434	Economy	8900.00
0005433477245	20434	Economy	8900.00
0005433477275	20434	Economy	8900.00
0005433481384	20434	Economy	8900.00
0005433507710	20434	Economy	8900.00
0005433477215	20434	Economy	8900.00
0005433477276	20434	Economy	8900.00
0005433477278	20434	Economy	8900.00
0005435179713	10197	Economy	5800.00
0005435179711	10197	Economy	5800.00
0005435179021	10197	Economy	5800.00
0005435179712	10197	Economy	5800.00
0005435179715	10197	Economy	5800.00
0005435179716	10197	Economy	5800.00
0005432396358	18386	Economy	5800.00
0005432396352	18386	Economy	5800.00
0005435626851	10955	Business	9500.00
0005435554327	10955	Business	9500.00
0005435626856	10955	Business	9500.00
0005435626857	10955	Business	9500.00
0005435626762	10955	Business	9500.00
0005435127492	10955	Business	9500.00
0005435626748	10955	Business	9500.00
0005435127527	10955	Business	9500.00
0005435127491	10955	Business	9500.00
0005435626744	10955	Economy	3200.00
0005435554326	10955	Economy	3200.00
0005435626808	10955	Economy	3200.00
0005435626798	10955	Economy	3200.00
0005435127558	10955	Economy	3200.00
0005435127554	10955	Economy	3500.00
0005435127429	10955	Economy	3500.00
0005435127526	10955	Economy	3500.00
0005435626785	10955	Economy	3200.00
0005435127480	10955	Economy	3200.00
0005435127557	10955	Economy	3200.00
0005435127539	10955	Economy	3200.00
0005435626824	10955	Economy	3200.00
0005435127553	10955	Economy	3200.00
0005435626745	10955	Economy	3200.00
0005435127531	10955	Economy	3200.00
0005435626652	10955	Economy	3200.00
0005435127430	10955	Economy	3200.00
0005435127545	10955	Economy	3200.00
0005435626763	10955	Economy	3200.00
0005435127538	10955	Economy	3200.00
0005435626772	10955	Economy	3200.00
0005435626788	10955	Economy	3200.00
0005435626813	10955	Economy	3200.00
0005435127569	10955	Economy	3200.00
0005435626841	10955	Economy	3200.00
0005435127541	10955	Economy	3200.00
0005435626653	10955	Economy	3200.00
0005435626815	10955	Economy	3200.00
0005435127540	10955	Economy	3200.00
0005435626793	10955	Economy	3200.00
0005435626809	10955	Economy	3200.00
0005435626814	10955	Economy	3200.00
0005435626860	10955	Economy	3200.00
0005435626802	10955	Economy	3200.00
0005435443587	7103	Economy	29000.00
0005435219256	7103	Economy	29000.00
0005435443586	7103	Economy	29000.00
0005435715927	27094	Economy	29000.00
0005432398304	27094	Economy	29000.00
0005435715958	27094	Economy	29000.00
0005435715969	27094	Economy	29000.00
0005435715928	27094	Economy	29000.00
0005435715946	27094	Economy	29000.00
0005435715916	27094	Economy	29000.00
0005435715932	27094	Economy	29000.00
0005435715917	27094	Economy	29000.00
0005435715970	27094	Economy	29000.00
0005435715959	27094	Economy	29000.00
0005433060490	2730	Economy	7700.00
0005435518424	11375	Business	20200.00
0005435541580	11375	Business	20200.00
0005435546228	11375	Economy	6700.00
0005435518422	11375	Economy	6700.00
0005435518382	11375	Economy	6700.00
0005435541626	11375	Economy	6700.00
0005435541579	11375	Economy	6700.00
0005433252373	2317	Business	20200.00
0005433252385	2317	Economy	6700.00
0005433252378	2317	Economy	6700.00
0005433252374	2317	Economy	6700.00
0005433252356	2317	Economy	6700.00
0005433252379	2317	Economy	6700.00
0005433252387	2317	Economy	6700.00
0005433252360	2317	Economy	6700.00
0005434908771	25594	Business	20200.00
0005434908775	25594	Business	20200.00
0005434908848	25594	Business	20200.00
0005434908790	25594	Economy	6700.00
0005434908876	25594	Economy	6700.00
0005434908865	25594	Economy	6700.00
0005434908847	25594	Economy	6700.00
0005434908337	25594	Economy	7400.00
0005434908635	25594	Economy	6700.00
0005434908851	25594	Economy	6700.00
0005434908659	25594	Economy	6700.00
0005434908763	25594	Economy	6700.00
0005434908774	25594	Economy	6700.00
0005434908753	25594	Economy	6700.00
0005434908796	25594	Economy	6700.00
0005435787475	25594	Economy	6700.00
0005434908724	25594	Economy	6700.00
0005434908885	25594	Economy	6700.00
0005434908757	25594	Economy	6700.00
0005434908843	25594	Economy	6700.00
0005434908873	25594	Economy	6700.00
0005434908797	25594	Economy	6700.00
0005434908761	25594	Economy	6700.00
0005434908754	25594	Economy	6700.00
0005434908758	25594	Economy	6700.00
0005434908798	25594	Economy	6700.00
0005434908867	25594	Economy	6700.00
0005434908434	25594	Economy	6700.00
0005434908884	25594	Economy	6700.00
0005434908875	25594	Economy	6700.00
0005434908866	25594	Economy	6700.00
0005434908804	25594	Economy	6700.00
0005434908874	25594	Economy	6700.00
0005432862526	2547	Economy	12400.00
0005432621451	28057	Economy	13600.00
0005432621444	28057	Economy	12400.00
0005432621445	28057	Economy	12400.00
0005432621437	28057	Economy	12400.00
0005432621457	28057	Economy	12400.00
0005432621441	28057	Economy	12400.00
0005432621452	28057	Economy	12400.00
0005432621322	28057	Economy	12400.00
0005432621458	28057	Economy	12400.00
0005432621454	28057	Economy	12400.00
0005432621440	28057	Economy	12400.00
0005432621438	28057	Economy	12400.00
0005433454934	31351	Economy	8400.00
0005434142728	11988	Economy	7200.00
0005434142711	11988	Economy	6600.00
0005434142725	11988	Economy	6600.00
0005434142726	11988	Economy	6600.00
0005433129404	11988	Economy	6600.00
0005434142717	11988	Economy	6600.00
0005434142712	11988	Economy	6600.00
0005434184724	11988	Economy	6600.00
0005434142710	11988	Economy	6600.00
0005434142724	11988	Economy	6600.00
0005434182550	11988	Economy	6600.00
0005434182549	11988	Economy	6600.00
0005433129398	11988	Economy	6600.00
0005434142723	11988	Economy	6600.00
0005433134263	11988	Economy	6600.00
0005434326293	29855	Economy	7200.00
0005434326295	29855	Economy	7200.00
0005434326012	29855	Economy	6600.00
0005434326037	29855	Economy	6600.00
0005434326294	29855	Economy	6600.00
0005435935132	16477	Economy	19900.00
0005435933564	16477	Economy	18100.00
0005435698175	24698	Economy	18100.00
0005435698074	24698	Economy	18100.00
0005435698101	24698	Economy	18100.00
0005435698090	24698	Economy	18100.00
0005435698102	24698	Economy	18100.00
0005435698174	24698	Economy	18100.00
0005435698138	24698	Economy	18100.00
0005433724927	21622	Economy	4400.00
0005435283569	7343	Business	23100.00
0005435283570	7343	Business	23100.00
0005435283563	7343	Economy	7700.00
0005435283578	7343	Economy	7700.00
0005435283574	7343	Economy	7700.00
0005435283577	7343	Economy	7700.00
0005435283564	7343	Economy	7700.00
0005434140393	28581	Business	23100.00
0005434140382	28581	Business	23100.00
0005434140383	28581	Business	23100.00
0005434140401	28581	Economy	7700.00
0005434140416	28581	Economy	7700.00
0005434140572	28581	Economy	7700.00
0005434140518	28581	Economy	8500.00
0005434140559	28581	Economy	8500.00
0005434140571	28581	Economy	7700.00
0005434140310	28581	Economy	7700.00
0005434140321	28581	Economy	7700.00
0005434140377	28581	Economy	7700.00
0005434140342	28581	Economy	7700.00
0005434140376	28581	Economy	7700.00
0005434140379	28581	Economy	7700.00
0005434140564	28581	Economy	7700.00
0005434140054	28581	Economy	7700.00
0005434140529	28581	Economy	7700.00
0005434140311	28581	Economy	7700.00
0005434140378	28581	Economy	7700.00
0005434140555	28581	Economy	7700.00
0005434140391	28581	Economy	7700.00
0005434140533	28581	Economy	7700.00
0005434140181	28581	Economy	7700.00
0005434140517	28581	Economy	7700.00
0005434140180	28581	Economy	7700.00
0005434140461	28581	Economy	7700.00
0005434140534	28581	Economy	7700.00
0005434140182	28581	Economy	7700.00
0005434140554	28581	Economy	7700.00
0005434140553	28581	Economy	7700.00
0005434140433	28581	Economy	7700.00
0005434140493	28581	Economy	7700.00
0005434140528	28581	Economy	7700.00
0005434140253	28581	Economy	7700.00
0005433407696	1917	Economy	21700.00
0005433407695	1917	Economy	21700.00
0005434610334	23105	Economy	21700.00
0005434505307	16698	Economy	7600.00
0005434505200	16698	Economy	7600.00
0005434505306	16698	Economy	6900.00
0005434505196	16698	Economy	6900.00
0005434505199	16698	Economy	6900.00
0005434505153	16698	Economy	6900.00
0005434505152	16698	Economy	6900.00
0005434505272	16698	Economy	6900.00
0005434505286	16698	Economy	6900.00
0005434505275	16698	Economy	6900.00
0005434505295	16698	Economy	6900.00
0005434505271	16698	Economy	6900.00
0005434505268	16698	Economy	6900.00
0005434505269	16698	Economy	6900.00
0005434505274	16698	Economy	6900.00
0005434505263	16698	Economy	6900.00
0005434505264	16698	Economy	6900.00
0005434505198	16698	Economy	6900.00
0005434505197	16698	Economy	6900.00
0005435312883	22881	Economy	6900.00
0005433266985	2207	Economy	7000.00
0005435078790	24360	Economy	7000.00
0005435078777	24360	Economy	7000.00
0005435078788	24360	Economy	7000.00
0005435078787	24360	Economy	7000.00
0005435078773	24360	Economy	7000.00
0005435078778	24360	Economy	7000.00
0005435078728	24360	Economy	7000.00
0005435078791	24360	Economy	7000.00
0005435078789	24360	Economy	7000.00
0005435464565	6627	Economy	9800.00
0005435464563	6627	Economy	9800.00
0005435464566	6627	Economy	9800.00
0005434989080	23632	Economy	10800.00
0005434989063	23632	Economy	10800.00
0005434989044	23632	Economy	9800.00
0005434989045	23632	Economy	9800.00
0005434989057	23632	Economy	9800.00
0005434989064	23632	Economy	9800.00
0005434989048	23632	Economy	9800.00
0005434989055	23632	Economy	9800.00
0005434989040	23632	Economy	9800.00
0005434989112	23632	Economy	9800.00
0005435803352	23632	Economy	9800.00
0005434989058	23632	Economy	9800.00
0005434989065	23632	Economy	9800.00
0005434989092	23632	Economy	9800.00
0005434989113	23632	Economy	9800.00
0005434989049	23632	Economy	9800.00
0005434989032	23632	Economy	9800.00
0005434989042	23632	Economy	9800.00
0005434989103	23632	Economy	9800.00
0005432384138	31289	Business	9900.00
0005433450567	31289	Business	9900.00
0005432384245	31289	Business	9900.00
0005432384270	31289	Business	9900.00
0005432384156	31289	Economy	3300.00
0005432384155	31289	Economy	3300.00
0005432384276	31289	Economy	3600.00
0005432384119	31289	Economy	3600.00
0005432384244	31289	Economy	3300.00
0005433450609	31289	Economy	3300.00
0005433450591	31289	Economy	3300.00
0005432384217	31289	Economy	3300.00
0005432384267	31289	Economy	3300.00
0005433450587	31289	Economy	3300.00
0005432384339	31289	Economy	3300.00
0005432384255	31289	Economy	3300.00
0005432384277	31289	Economy	3300.00
0005432384272	31289	Economy	3300.00
0005432384312	31289	Economy	3300.00
0005433450568	31289	Economy	3300.00
0005432384142	31289	Economy	3300.00
0005433450610	31289	Economy	3300.00
0005433450593	31289	Economy	3300.00
0005432384137	31289	Economy	3300.00
0005432384218	31289	Economy	3300.00
0005432384310	31289	Economy	3300.00
0005432384216	31289	Economy	3300.00
0005433450599	31289	Economy	3300.00
0005432384273	31289	Economy	3300.00
0005432384203	31289	Economy	3300.00
0005433450566	31289	Economy	3300.00
0005435548613	20815	Economy	26200.00
0005435548614	20815	Economy	23800.00
0005435548624	20815	Economy	23800.00
0005435548587	20815	Economy	23800.00
0005435548616	20815	Economy	23800.00
0005435548582	20815	Economy	23800.00
0005435548622	20815	Economy	23800.00
0005435548615	20815	Economy	23800.00
0005435548617	20815	Economy	23800.00
0005435299918	10746	Economy	17100.00
0005433131837	10746	Economy	17100.00
0005435299910	10746	Economy	15600.00
0005435299907	10746	Economy	15600.00
0005435299919	10746	Economy	15600.00
0005435304268	10746	Economy	15600.00
0005435304267	10746	Economy	15600.00
0005433126974	10746	Economy	15600.00
0005435299908	10746	Economy	15600.00
0005433131842	10746	Economy	15600.00
0005435299909	10746	Economy	15600.00
0005433126979	10746	Economy	15600.00
0005433131836	10746	Economy	15600.00
0005433131843	10746	Economy	15600.00
0005435304271	10746	Economy	15600.00
0005433110382	2433	Economy	17200.00
0005434287940	26858	Economy	15700.00
0005434300267	26858	Economy	15700.00
0005434300266	26858	Economy	15700.00
0005434272234	25482	Economy	25000.00
0005434269158	25482	Economy	22800.00
0005435983709	26666	Economy	25000.00
0005435856317	26666	Economy	22800.00
0005435856327	26666	Economy	22800.00
0005435856318	26666	Economy	22800.00
0005435983720	26666	Economy	22800.00
0005435854087	26666	Economy	22800.00
0005435856325	26666	Economy	22800.00
0005435983719	26666	Economy	22800.00
0005434520515	19071	Economy	24600.00
0005434520488	19071	Economy	24600.00
0005434520484	19071	Economy	22300.00
0005434520502	19071	Economy	22300.00
0005434520478	19071	Economy	22300.00
0005434520516	19071	Economy	22300.00
0005434520513	19071	Economy	22300.00
0005434520486	19071	Economy	22300.00
0005434520517	19071	Economy	22300.00
0005434520503	19071	Economy	22300.00
0005434520511	19071	Economy	22300.00
0005434520512	19071	Economy	22300.00
0005434520490	19071	Economy	22300.00
0005434520510	19071	Economy	22300.00
0005434520455	19071	Economy	22300.00
0005434520448	19071	Economy	22300.00
0005434520514	19071	Economy	22300.00
0005434520491	19071	Economy	22300.00
0005434520487	19071	Economy	22300.00
0005433874437	32637	Economy	17400.00
0005433874452	32637	Economy	17400.00
0005433874436	32637	Economy	17400.00
0005433874461	32637	Economy	17400.00
0005433874460	32637	Economy	17400.00
0005433874459	32637	Economy	17400.00
0005433874458	32637	Economy	17400.00
0005433874456	32637	Economy	17400.00
0005433874451	32637	Economy	17400.00
0005433874450	32637	Economy	17400.00
0005433874449	32637	Economy	17400.00
0005435860627	4801	Economy	17600.00
0005435860630	4801	Economy	17600.00
0005435860628	4801	Economy	17600.00
0005435860615	4801	Economy	17600.00
0005433869541	32597	Economy	19400.00
0005433869579	32597	Economy	17600.00
0005433869608	32597	Economy	17600.00
0005433869556	32597	Economy	17600.00
0005433869430	32597	Economy	17600.00
0005433869594	32597	Economy	17600.00
0005433869603	32597	Economy	17600.00
0005433869595	32597	Economy	17600.00
0005433869576	32597	Economy	17600.00
0005433869598	32597	Economy	17600.00
0005433869503	32597	Economy	17600.00
0005433869578	32597	Economy	17600.00
0005433869593	32597	Economy	17600.00
0005433869426	32597	Economy	17600.00
0005433869577	32597	Economy	17600.00
0005433869552	32597	Economy	17600.00
0005434663806	12448	Economy	24800.00
0005434462851	12448	Economy	24800.00
0005434663793	12448	Economy	24800.00
0005434462854	12448	Economy	22600.00
0005434462855	12448	Economy	22600.00
0005434462846	12448	Economy	22600.00
0005434663807	12448	Economy	22600.00
0005434462843	12448	Economy	22600.00
0005434663794	12448	Economy	22600.00
0005434460565	12448	Economy	22600.00
0005434462845	12448	Economy	22600.00
0005434460561	12448	Economy	22600.00
0005434460566	12448	Economy	22600.00
0005434460560	12448	Economy	22600.00
0005434663804	12448	Economy	22600.00
0005434460562	12448	Economy	22600.00
0005434462849	12448	Economy	22600.00
0005433869576	14500	Economy	18500.00
0005433869426	14500	Economy	16800.00
0005433869503	14500	Economy	16800.00
0005433869598	14500	Economy	16800.00
0005433869430	14500	Economy	16800.00
0005433869577	14500	Economy	16800.00
0005433869593	14500	Economy	16800.00
0005433869578	14500	Economy	16800.00
0005433869556	14500	Economy	16800.00
0005433869552	14500	Economy	16800.00
0005433869595	14500	Economy	16800.00
0005433869608	14500	Economy	16800.00
0005433869541	14500	Economy	16800.00
0005433869603	14500	Economy	16800.00
0005433869579	14500	Economy	16800.00
0005433869594	14500	Economy	16800.00
0005435860629	32678	Economy	16800.00
0005435860605	32678	Economy	16800.00
0005435860606	32678	Economy	16800.00
0005435860607	32678	Economy	16800.00
0005432800197	12112	Economy	4400.00
0005432800180	12112	Economy	4400.00
0005432800196	12112	Economy	4400.00
0005432800248	12112	Economy	4400.00
0005435293608	7067	Business	49100.00
0005435293570	7067	Economy	16400.00
0005435311491	7067	Economy	16400.00
0005435311501	7067	Economy	16400.00
0005435311502	7067	Economy	16400.00
0005435293571	7067	Economy	16400.00
0005435293589	7067	Economy	16400.00
0005435311492	7067	Economy	18000.00
0005435293607	7067	Economy	16400.00
0005435311526	7067	Economy	16400.00
0005435293610	7067	Economy	16400.00
0005435311447	7067	Economy	16400.00
0005435311525	7067	Economy	16400.00
0005435293588	7067	Economy	16400.00
0005435311476	7067	Economy	16400.00
0005435293621	7067	Economy	16400.00
0005435293605	7067	Economy	16400.00
0005434409614	26884	Business	49100.00
0005434300205	26884	Economy	16400.00
0005434409619	26884	Economy	16400.00
0005434409590	26884	Economy	16400.00
0005434409613	26884	Economy	16400.00
0005434409536	26884	Economy	16400.00
0005434300218	26884	Economy	16400.00
0005434409500	26884	Economy	16400.00
0005434409545	26884	Economy	16400.00
0005434409506	26884	Economy	16400.00
0005434409607	26884	Economy	16400.00
0005434409568	26884	Economy	16400.00
0005434300229	26884	Economy	16400.00
0005434409584	26884	Economy	16400.00
0005434409541	26884	Economy	18000.00
0005434409542	26884	Economy	18000.00
0005434409585	26884	Economy	16400.00
0005434409617	26884	Economy	16400.00
0005434409509	26884	Economy	16400.00
0005434409531	26884	Economy	16400.00
0005434300195	26884	Economy	16400.00
0005434409499	26884	Economy	16400.00
0005434409380	26884	Economy	16400.00
0005434409610	26884	Economy	16400.00
0005434409573	26884	Economy	16400.00
0005434409537	26884	Economy	16400.00
0005434409429	26884	Economy	16400.00
0005434300206	26884	Economy	16400.00
0005434300217	26884	Economy	16400.00
0005434409586	26884	Economy	16400.00
0005434409520	26884	Economy	16400.00
0005434409618	26884	Economy	16400.00
0005434300226	26884	Economy	16400.00
0005434300220	26884	Economy	16400.00
0005434409505	26884	Economy	16400.00
0005434409592	26884	Economy	16400.00
0005434409381	26884	Economy	16400.00
0005434409609	26884	Economy	16400.00
0005434409540	26884	Economy	16400.00
0005434300211	26884	Economy	16400.00
0005434409579	26884	Economy	16400.00
0005434409544	26884	Economy	16400.00
0005434409382	26884	Economy	16400.00
0005434409580	26884	Economy	16400.00
0005434409608	26884	Economy	16400.00
0005435312908	6451	Economy	15000.00
0005432605469	21372	Economy	16500.00
0005432605406	21372	Economy	15000.00
0005432605396	21372	Economy	15000.00
0005432605452	21372	Economy	15000.00
0005432605416	21372	Economy	15000.00
0005432605405	21372	Economy	15000.00
0005432605453	21372	Economy	15000.00
0005434512247	21372	Economy	15000.00
0005432605428	21372	Economy	15000.00
0005434908874	14974	Business	18900.00
0005434908884	14974	Business	18900.00
0005434908790	14974	Business	18900.00
0005434908843	14974	Business	18900.00
0005434908434	14974	Economy	6300.00
0005434908875	14974	Economy	6300.00
0005434908885	14974	Economy	6300.00
0005434908771	14974	Economy	6300.00
0005434908724	14974	Economy	6900.00
0005434908797	14974	Economy	6900.00
0005434908635	14974	Economy	6900.00
0005434908798	14974	Economy	6300.00
0005434908753	14974	Economy	6300.00
0005434908775	14974	Economy	6300.00
0005434908847	14974	Economy	6300.00
0005434908865	14974	Economy	6300.00
0005434908659	14974	Economy	6300.00
0005434908867	14974	Economy	6300.00
0005434908851	14974	Economy	6300.00
0005434908757	14974	Economy	6300.00
0005434908876	14974	Economy	6300.00
0005434908337	14974	Economy	6300.00
0005434908804	14974	Economy	6300.00
0005434908774	14974	Economy	6300.00
0005434908866	14974	Economy	6300.00
0005434908873	14974	Economy	6300.00
0005434908754	14974	Economy	6300.00
0005434908758	14974	Economy	6300.00
0005434908763	14974	Economy	6300.00
0005434908848	14974	Economy	6300.00
0005434908796	14974	Economy	6300.00
0005434908761	14974	Economy	6300.00
0005433252377	25823	Economy	6300.00
0005433252321	25823	Economy	6300.00
0005433252339	25823	Economy	6300.00
0005433252365	25823	Economy	6300.00
0005433252376	25823	Economy	6300.00
0005433252369	25823	Economy	6300.00
0005433252368	25823	Economy	6300.00
0005433252367	25823	Economy	6300.00
0005433815555	22722	Economy	18100.00
0005433815563	22722	Economy	18100.00
0005433815557	22722	Economy	18100.00
0005433815567	22722	Economy	18100.00
0005435841489	22469	Economy	16400.00
0005435841493	22469	Economy	14900.00
0005435841490	22469	Economy	14900.00
0005435841491	22469	Economy	14900.00
0005435841488	22469	Economy	14900.00
0005435841492	22469	Economy	14900.00
0005435842351	22469	Economy	14900.00
0005435842352	22469	Economy	14900.00
0005432609836	31719	Economy	14900.00
0005432613982	31719	Economy	14900.00
0005432609837	31719	Economy	14900.00
0005432609843	31719	Economy	14900.00
0005432613975	31719	Economy	14900.00
0005432609845	31719	Economy	14900.00
0005432613981	31719	Economy	14900.00
0005432609848	31719	Economy	14900.00
0005432613966	31719	Economy	14900.00
0005432613974	31719	Economy	14900.00
0005432609846	31719	Economy	14900.00
0005432609835	31719	Economy	14900.00
0005432609849	31719	Economy	14900.00
0005433810763	14180	Business	52300.00
0005433810681	14180	Business	52300.00
0005433810718	14180	Business	52300.00
0005433810816	14180	Economy	17400.00
0005433815567	14180	Economy	17400.00
0005433810750	14180	Economy	19200.00
0005433810717	14180	Economy	19200.00
0005433810772	14180	Economy	17400.00
0005433810737	14180	Economy	17400.00
0005433810742	14180	Economy	17400.00
0005433810815	14180	Economy	17400.00
0005433810761	14180	Economy	17400.00
0005433815555	14180	Economy	17400.00
0005433815557	14180	Economy	17400.00
0005433810751	14180	Economy	17400.00
0005433810741	14180	Economy	17400.00
0005433810803	14180	Economy	17400.00
0005433810810	14180	Economy	17400.00
0005433810764	14180	Economy	17400.00
0005433810784	14180	Economy	17400.00
0005433815563	14180	Economy	17400.00
0005433810754	14180	Economy	17400.00
0005433810782	14180	Economy	17400.00
0005433810740	14180	Economy	17400.00
0005433009730	22821	Business	52300.00
0005433009731	22821	Business	52300.00
0005433009680	22821	Business	52300.00
0005434173664	22821	Economy	17400.00
0005433009847	22821	Economy	17400.00
0005433009845	22821	Economy	19200.00
0005433009899	22821	Economy	17400.00
0005433009957	22821	Economy	17400.00
0005433009956	22821	Economy	17400.00
0005433009857	22821	Economy	17400.00
0005433009678	22821	Economy	17400.00
0005433009913	22821	Economy	17400.00
0005434173661	22821	Economy	17400.00
0005433009896	22821	Economy	17400.00
0005433009898	22821	Economy	17400.00
0005433009884	22821	Economy	17400.00
0005433009970	22821	Economy	17400.00
0005433009681	22821	Economy	17400.00
0005433009846	22821	Economy	17400.00
0005433009969	22821	Economy	17400.00
0005433009897	22821	Economy	17400.00
0005433009912	22821	Economy	17400.00
0005433009876	22821	Economy	17400.00
0005434926834	14960	Business	22900.00
0005434926829	14960	Business	22900.00
0005434926842	14960	Economy	7600.00
0005434926802	14960	Economy	7600.00
0005434926859	14960	Economy	7600.00
0005434926841	14960	Economy	7600.00
0005434926605	14960	Economy	7600.00
0005434926817	14960	Economy	7600.00
0005434926805	14960	Economy	7600.00
0005434926812	14960	Economy	7600.00
0005434926593	14960	Economy	7600.00
0005434926783	14960	Economy	7600.00
0005434926836	14960	Economy	7600.00
0005434926803	14960	Economy	7600.00
0005434926839	14960	Economy	7600.00
0005434926725	14960	Economy	7600.00
0005434926837	14960	Economy	7600.00
0005434926811	14960	Economy	7600.00
0005434926592	14960	Economy	7600.00
0005434926631	14960	Economy	7600.00
0005434926833	14960	Economy	7600.00
0005434926756	14960	Economy	7600.00
0005434926632	14960	Economy	7600.00
0005434926835	14960	Economy	7600.00
0005434926804	14960	Economy	7600.00
0005434926801	14960	Economy	7600.00
0005435999833	15810	Economy	8900.00
0005435999812	15810	Economy	8900.00
0005435999832	15810	Economy	8100.00
0005435999856	15810	Economy	8100.00
0005435999738	15810	Economy	8100.00
0005435999869	15810	Economy	8100.00
0005435999772	15810	Economy	8100.00
0005435999796	15810	Economy	8100.00
0005435999834	15810	Economy	8100.00
0005435999840	15810	Economy	8100.00
0005435999870	15810	Economy	8100.00
0005435999808	15810	Economy	8100.00
0005435488460	19687	Economy	8900.00
0005435488429	19687	Economy	8900.00
0005435488418	19687	Economy	8100.00
0005435488470	19687	Economy	8100.00
0005435488392	19687	Economy	8100.00
0005435488471	19687	Economy	8100.00
0005435488397	19687	Economy	8100.00
0005435488452	19687	Economy	8100.00
0005435488401	19687	Economy	8100.00
0005435488439	19687	Economy	8100.00
0005435488466	19687	Economy	8100.00
0005435488454	19687	Economy	8100.00
0005435488453	19687	Economy	8100.00
0005435488451	19687	Economy	8100.00
0005435488435	19687	Economy	8100.00
0005435473292	6009	Economy	66400.00
0005435473232	6009	Economy	66400.00
0005435473259	6009	Economy	66400.00
0005435473227	6009	Economy	66400.00
0005435473291	6009	Economy	66400.00
0005435473233	6009	Economy	66400.00
0005435473228	6009	Economy	66400.00
0005435840273	18067	Business	199300.00
0005435840224	18067	Economy	66400.00
0005435840268	18067	Economy	66400.00
0005435840256	18067	Economy	66400.00
0005432664190	18067	Economy	66400.00
0005435840184	18067	Economy	66400.00
0005433286220	23055	Business	15700.00
0005433286164	23055	Business	15700.00
0005433286186	23055	Economy	5200.00
0005433286168	23055	Economy	5200.00
0005433286167	23055	Economy	5200.00
0005433286155	23055	Economy	5200.00
0005433286187	23055	Economy	5200.00
0005433286165	23055	Economy	5700.00
0005433286221	23055	Economy	5200.00
0005433286214	23055	Economy	5200.00
0005433286180	23055	Economy	5200.00
0005435104195	32088	Business	15700.00
0005435104283	32088	Business	15700.00
0005435104181	32088	Economy	5200.00
0005435104290	32088	Economy	5200.00
0005435104323	32088	Economy	5700.00
0005435104196	32088	Economy	5700.00
0005435104244	32088	Economy	5200.00
0005435104327	32088	Economy	5200.00
0005435104326	32088	Economy	5200.00
0005435104223	32088	Economy	5200.00
0005435104284	32088	Economy	5200.00
0005435104289	32088	Economy	5200.00
0005435104243	32088	Economy	5200.00
0005435104260	32088	Economy	5200.00
0005435104250	32088	Economy	5200.00
0005435104245	32088	Economy	5200.00
0005435104345	32088	Economy	5200.00
0005432531640	30599	Business	42100.00
0005434069387	30599	Business	42100.00
0005432531396	30599	Business	42100.00
0005432531834	30599	Business	42100.00
0005432531678	30599	Comfort	23900.00
0005434069292	30599	Comfort	23900.00
0005432531497	30599	Comfort	23900.00
0005434069574	30599	Comfort	23900.00
0005434069613	30599	Comfort	23900.00
0005432531636	30599	Comfort	23900.00
0005434069467	30599	Economy	14000.00
0005432535976	30599	Economy	14000.00
0005432429021	30599	Economy	14000.00
0005432531774	30599	Economy	14000.00
0005434069468	30599	Economy	14000.00
0005432531506	30599	Economy	14000.00
0005432531843	30599	Economy	14000.00
0005434069646	30599	Economy	14000.00
0005432531709	30599	Economy	14000.00
0005432531702	30599	Economy	14000.00
0005434069484	30599	Economy	14000.00
0005432531842	30599	Economy	14000.00
0005432531676	30599	Economy	14000.00
0005432531499	30599	Economy	14000.00
0005434069647	30599	Economy	14000.00
0005432531818	30599	Economy	14000.00
0005434069575	30599	Economy	14000.00
0005434069544	30599	Economy	14000.00
0005434069621	30599	Economy	14000.00
0005434069351	30599	Economy	14000.00
0005432531832	30599	Economy	14000.00
0005434069483	30599	Economy	14000.00
0005432531790	30599	Economy	15400.00
0005434069350	30599	Economy	14000.00
0005434069648	30599	Economy	14000.00
0005432531791	30599	Economy	14000.00
0005432531831	30599	Economy	14000.00
0005434069580	30599	Economy	14000.00
0005432531507	30599	Economy	14000.00
0005432531775	30599	Economy	14000.00
0005432429030	30599	Economy	14000.00
0005434069645	30599	Economy	14000.00
0005432535974	30599	Economy	14000.00
0005434069614	30599	Economy	14000.00
0005432429034	30599	Economy	14000.00
0005432531737	30599	Economy	14000.00
0005432533369	30599	Economy	14000.00
0005432531833	30599	Economy	14000.00
0005432531498	30599	Economy	14000.00
0005434069573	30599	Economy	14000.00
0005435654401	24870	Business	9800.00
0005435654428	24870	Business	9800.00
0005435654434	24870	Business	9800.00
0005435654368	24870	Business	9800.00
0005435654455	24870	Business	9800.00
0005435654424	24870	Business	9800.00
0005435654490	24870	Business	9800.00
0005435654459	24870	Economy	3300.00
0005435654327	24870	Economy	3300.00
0005435654355	24870	Economy	3300.00
0005435654480	24870	Economy	3300.00
0005435654341	24870	Economy	3300.00
0005435654491	24870	Economy	3600.00
0005435654452	24870	Economy	3600.00
0005435654417	24870	Economy	3300.00
0005435654403	24870	Economy	3300.00
0005435654449	24870	Economy	3300.00
0005435654435	24870	Economy	3300.00
0005435654416	24870	Economy	3300.00
0005435654487	24870	Economy	3300.00
0005435654289	24870	Economy	3300.00
0005435654493	24870	Economy	3300.00
0005435654242	24870	Economy	3300.00
0005435654454	24870	Economy	3300.00
0005435654485	24870	Economy	3300.00
0005435654423	24870	Economy	3300.00
0005435654451	24870	Economy	3300.00
0005435654295	24870	Economy	3300.00
0005435654486	24870	Economy	3300.00
0005435654192	24870	Economy	3300.00
0005435654483	24870	Economy	3300.00
0005435654407	24870	Economy	3300.00
0005435654328	24870	Economy	3300.00
0005434980636	23562	Economy	10500.00
0005434980647	23562	Economy	9500.00
0005434980656	23562	Economy	9500.00
0005434980658	23562	Economy	9500.00
0005434980657	23562	Economy	9500.00
0005434980618	23562	Economy	9500.00
0005434980659	23562	Economy	9500.00
0005434980566	23562	Economy	9500.00
0005434980634	23562	Economy	9500.00
0005435801779	23562	Economy	9500.00
0005434980635	23562	Economy	9500.00
0005434980637	23562	Economy	9500.00
0005434980677	23562	Economy	9500.00
0005434980619	23562	Economy	9500.00
0005434980620	23562	Economy	9500.00
0005434980648	23562	Economy	9500.00
0005434980630	23562	Economy	9500.00
0005434980650	23562	Economy	9500.00
0005434952632	28240	Economy	5300.00
0005434140593	11932	Business	9700.00
0005434140620	11932	Business	9700.00
0005434140538	11932	Business	9700.00
0005434140614	11932	Business	9700.00
0005434140234	11932	Economy	3200.00
0005434140520	11932	Economy	3200.00
0005434140628	11932	Economy	3500.00
0005434140616	11932	Economy	3500.00
0005434140233	11932	Economy	3200.00
0005434140472	11932	Economy	3200.00
0005434140610	11932	Economy	3200.00
0005434140519	11932	Economy	3200.00
0005434140397	11932	Economy	3200.00
0005434140232	11932	Economy	3200.00
0005434140447	11932	Economy	3200.00
0005434140617	11932	Economy	3200.00
0005434140548	11932	Economy	3200.00
0005434140444	11932	Economy	3200.00
0005434140446	11932	Economy	3200.00
0005434140547	11932	Economy	3200.00
0005434140396	11932	Economy	3200.00
0005434140586	11932	Economy	3200.00
0005434140539	11932	Economy	3200.00
0005434140462	11932	Economy	3200.00
0005434140537	11932	Economy	3200.00
0005434140558	11932	Economy	3200.00
0005434140404	11932	Economy	3200.00
0005435283578	28734	Economy	3500.00
0005435283577	28734	Economy	3200.00
0005435283570	28734	Economy	3200.00
0005435283574	28734	Economy	3200.00
0005435283569	28734	Economy	3200.00
0005433539109	25007	Economy	9900.00
0005433539112	25007	Economy	9900.00
0005433539113	25007	Economy	9900.00
0005433539123	25007	Economy	9900.00
0005433512186	16150	Economy	14600.00
0005433512185	16150	Economy	14600.00
0005433512183	16150	Economy	14600.00
0005433512181	16150	Economy	14600.00
0005433512182	16150	Economy	14600.00
0005435935131	3658	Economy	7200.00
0005435698174	16292	Economy	7200.00
0005435698175	16292	Economy	7200.00
0005435698138	16292	Economy	7200.00
0005435698101	16292	Economy	7200.00
0005435698074	16292	Economy	7200.00
0005435698090	16292	Economy	7200.00
0005435698102	16292	Economy	7200.00
0005432613974	22042	Economy	21300.00
0005432609837	22042	Economy	19300.00
0005432609849	22042	Economy	19300.00
0005432609848	22042	Economy	19300.00
0005432613966	22042	Economy	19300.00
0005432613982	22042	Economy	19300.00
0005434606933	22042	Economy	19300.00
0005432609843	22042	Economy	19300.00
0005432609836	22042	Economy	19300.00
0005432609845	22042	Economy	19300.00
0005432609835	22042	Economy	19300.00
0005432609846	22042	Economy	19300.00
0005432613975	22042	Economy	19300.00
0005432613981	22042	Economy	19300.00
0005434444188	17564	Economy	7100.00
0005435938963	4410	Economy	44400.00
0005435938964	4410	Economy	44400.00
0005435938965	4410	Economy	44400.00
0005435938959	4410	Economy	44400.00
0005435811227	29432	Economy	44400.00
0005435811229	29432	Economy	44400.00
0005435811219	29432	Economy	44400.00
0005435811228	29432	Economy	44400.00
0005435811215	29432	Economy	44400.00
0005435811230	29432	Economy	44400.00
0005435811220	29432	Economy	44400.00
0005435811226	29432	Economy	44400.00
0005432398297	18431	Economy	4900.00
0005432394224	18431	Economy	4900.00
0005432394223	18431	Economy	4900.00
0005435312886	6543	Economy	16100.00
0005435312884	6543	Economy	16100.00
0005435312885	6543	Economy	16100.00
0005435312887	6543	Economy	16100.00
0005434505269	22686	Business	48400.00
0005435104195	22686	Business	48400.00
0005435104181	22686	Business	48400.00
0005434505307	22686	Economy	16100.00
0005435104244	22686	Economy	16100.00
0005435104283	22686	Economy	16100.00
0005435104284	22686	Economy	16100.00
0005434505198	22686	Economy	17800.00
0005434505274	22686	Economy	17800.00
0005434505264	22686	Economy	16100.00
0005434505196	22686	Economy	16100.00
0005435104345	22686	Economy	16100.00
0005434505286	22686	Economy	16100.00
0005435104245	22686	Economy	16100.00
0005434505153	22686	Economy	16100.00
0005434505272	22686	Economy	16100.00
0005435104289	22686	Economy	16100.00
0005434505268	22686	Economy	16100.00
0005435104250	22686	Economy	16100.00
0005434505263	22686	Economy	16100.00
0005435104290	22686	Economy	16100.00
0005435104223	22686	Economy	16100.00
0005435104243	22686	Economy	16100.00
0005434505271	22686	Economy	16100.00
0005434505152	22686	Economy	16100.00
0005435104327	22686	Economy	16100.00
0005434505197	22686	Economy	16100.00
0005435104260	22686	Economy	16100.00
0005435104196	22686	Economy	16100.00
0005435104326	22686	Economy	16100.00
0005434505275	22686	Economy	16100.00
0005434505199	22686	Economy	16100.00
0005434505295	22686	Economy	16100.00
0005434505200	22686	Economy	16100.00
0005434505306	22686	Economy	16100.00
0005435104323	22686	Economy	16100.00
0005433368959	1671	Business	50000.00
0005433368922	1671	Economy	16700.00
0005433368961	1671	Economy	16700.00
0005433368979	1671	Economy	18300.00
0005433368921	1671	Economy	18300.00
0005433368982	1671	Economy	16700.00
0005433368981	1671	Economy	16700.00
0005433368980	1671	Economy	16700.00
0005433368962	1671	Economy	16700.00
0005433368944	1671	Economy	16700.00
0005435654428	21669	Business	50000.00
0005435654289	21669	Business	50000.00
0005435654449	21669	Business	50000.00
0005435654480	21669	Business	50000.00
0005435654452	21669	Business	50000.00
0005435654491	21669	Economy	16700.00
0005435654459	21669	Economy	16700.00
0005435654423	21669	Economy	16700.00
0005435654401	21669	Economy	16700.00
0005435654493	21669	Economy	16700.00
0005435654368	21669	Economy	18300.00
0005435654451	21669	Economy	18300.00
0005435654192	21669	Economy	16700.00
0005435654295	21669	Economy	16700.00
0005435654455	21669	Economy	16700.00
0005435654403	21669	Economy	16700.00
0005435654486	21669	Economy	16700.00
0005435654487	21669	Economy	16700.00
0005435654483	21669	Economy	16700.00
0005435654490	21669	Economy	16700.00
0005435654434	21669	Economy	16700.00
0005435654328	21669	Economy	16700.00
0005435654454	21669	Economy	16700.00
0005435654341	21669	Economy	16700.00
0005435654435	21669	Economy	16700.00
0005435654407	21669	Economy	16700.00
0005435654355	21669	Economy	16700.00
0005435654485	21669	Economy	16700.00
0005435654416	21669	Economy	16700.00
0005435654242	21669	Economy	16700.00
0005435654327	21669	Economy	16700.00
0005435654417	21669	Economy	16700.00
0005435654424	21669	Economy	16700.00
0005433987141	25675	Business	21500.00
0005433987311	25675	Business	21500.00
0005433987254	25675	Business	21500.00
0005433987334	25675	Economy	7200.00
0005433987321	25675	Economy	7200.00
0005433987327	25675	Economy	7200.00
0005433987314	25675	Economy	7200.00
0005433987193	25675	Economy	7200.00
0005433987312	25675	Economy	7200.00
0005433987322	25675	Economy	7200.00
0005433987260	25675	Economy	7200.00
0005433987313	25675	Economy	7200.00
0005433987370	25675	Economy	7200.00
0005433987369	25675	Economy	7200.00
0005433987374	25675	Economy	7200.00
0005433987215	25675	Economy	7200.00
0005435719601	21286	Economy	9400.00
0005435719600	21286	Economy	9400.00
0005432664210	17841	Business	18000.00
0005432655877	17841	Economy	6000.00
0005432667515	17841	Economy	6000.00
0005432667516	17841	Economy	6000.00
0005432666446	17841	Economy	6000.00
0005432663100	17841	Economy	6000.00
0005432655872	17841	Economy	6000.00
0005432661984	17841	Economy	6000.00
0005432664209	17841	Economy	6000.00
0005432655871	17841	Economy	6000.00
0005432664211	17841	Economy	6000.00
0005432666444	17841	Economy	6000.00
0005432666445	17841	Economy	6000.00
0005432655878	17841	Economy	6000.00
0005432639479	25062	Business	87300.00
0005432639495	25062	Economy	29100.00
0005432639496	25062	Economy	29100.00
0005432639449	25062	Economy	29100.00
0005432639480	25062	Economy	29100.00
0005432639499	25062	Economy	29100.00
0005432639475	25062	Economy	29100.00
0005432639491	25062	Economy	29100.00
0005432639454	25062	Economy	29100.00
0005432639487	25062	Economy	29100.00
0005432639498	25062	Economy	29100.00
0005432639450	25062	Economy	29100.00
0005432639490	25062	Economy	29100.00
0005432639485	25062	Economy	29100.00
0005432639484	25062	Economy	29100.00
0005432639489	25062	Economy	29100.00
0005432639483	25062	Economy	29100.00
0005432639488	25062	Economy	29100.00
0005432848914	3096	Business	16100.00
0005432848919	3096	Economy	5400.00
0005432848910	3096	Economy	5400.00
0005432848918	3096	Economy	5400.00
0005432848913	3096	Economy	5400.00
0005432329974	31098	Business	16100.00
0005432330030	31098	Economy	5400.00
0005432329975	31098	Economy	5400.00
0005433439106	31098	Economy	5400.00
0005432330013	31098	Economy	5400.00
0005432329942	31098	Economy	5400.00
0005432330014	31098	Economy	5400.00
0005435488448	6182	Economy	41500.00
0005435488372	6182	Economy	41500.00
0005435488478	6182	Economy	41500.00
0005435488371	6182	Economy	41500.00
0005435488402	6182	Economy	41500.00
0005435488408	6182	Economy	41500.00
0005435488444	6182	Economy	41500.00
0005434310130	19529	Business	124600.00
0005434310129	19529	Economy	41500.00
0005435999808	19529	Economy	41500.00
0005434310080	19529	Economy	41500.00
0005434310146	19529	Economy	41500.00
0005434310147	19529	Economy	41500.00
0005435999856	19529	Economy	41500.00
0005435999833	19529	Economy	41500.00
0005435999812	19529	Economy	41500.00
0005435999832	19529	Economy	41500.00
0005435999738	19529	Economy	41500.00
0005435999834	19529	Economy	41500.00
0005435999772	19529	Economy	41500.00
0005435999796	19529	Economy	41500.00
0005435999840	19529	Economy	41500.00
0005433157018	13200	Economy	12300.00
0005433157017	13200	Economy	12300.00
0005433186363	1569	Economy	28700.00
0005433186352	1569	Economy	28700.00
0005433186364	1569	Economy	28700.00
0005435545973	20901	Business	86000.00
0005435529854	20901	Economy	28700.00
0005435545957	20901	Economy	28700.00
0005435529834	20901	Economy	28700.00
0005435502956	20901	Economy	31500.00
0005434566281	20901	Economy	31500.00
0005434566282	20901	Economy	28700.00
0005435502940	20901	Economy	28700.00
0005435502951	20901	Economy	28700.00
0005435545974	20901	Economy	28700.00
0005435545950	20901	Economy	28700.00
0005435502950	20901	Economy	28700.00
0005434566283	20901	Economy	28700.00
0005435529853	20901	Economy	28700.00
0005435545948	20901	Economy	28700.00
0005434566284	20901	Economy	28700.00
0005435502941	20901	Economy	28700.00
0005435931698	3916	Economy	21600.00
0005435931713	3916	Economy	19700.00
0005435931712	3916	Economy	19700.00
0005435931711	3916	Economy	19700.00
0005435931710	3916	Economy	19700.00
0005435931714	3916	Economy	19700.00
0005434230044	3916	Economy	19700.00
0005435225800	7225	Economy	13000.00
0005435225809	7225	Economy	13000.00
0005432629278	28128	Economy	13000.00
0005435477009	8753	Economy	10500.00
0005434268058	8753	Economy	10500.00
0005435477010	8753	Economy	10500.00
0005434268057	8753	Economy	10500.00
0005432873499	1195	Business	115000.00
0005432873495	1195	Economy	38300.00
0005432873498	1195	Economy	38300.00
0005432873496	1195	Economy	38300.00
0005432693957	17513	Business	115000.00
0005432675579	17513	Business	115000.00
0005432693958	17513	Economy	38300.00
0005432693968	17513	Economy	42200.00
0005432693924	17513	Economy	38300.00
0005432693950	17513	Economy	38300.00
0005432675578	17513	Economy	38300.00
0005432693969	17513	Economy	38300.00
0005432693940	17513	Economy	38300.00
0005432693882	17513	Economy	38300.00
0005432693937	17513	Economy	38300.00
0005432693949	17513	Economy	38300.00
0005433157007	1155	Economy	13900.00
0005433157006	1155	Economy	13900.00
0005433157004	1155	Economy	13900.00
0005434435634	17329	Economy	15200.00
0005434435611	17329	Economy	13900.00
0005434435635	17329	Economy	13900.00
0005434435633	17329	Economy	13900.00
0005434435623	17329	Economy	13900.00
0005435087057	24406	Economy	7500.00
0005434215910	1329	Economy	67800.00
0005433261851	1329	Economy	67800.00
0005433261848	1329	Economy	67800.00
0005433261862	1329	Economy	67800.00
0005433261847	1329	Economy	67800.00
0005433261825	1329	Economy	74500.00
0005433261860	1329	Economy	67800.00
0005433261859	1329	Economy	67800.00
0005433261850	1329	Economy	67800.00
0005433261865	1329	Economy	67800.00
0005434964771	18241	Business	203300.00
0005434964790	18241	Business	203300.00
0005434964738	18241	Business	203300.00
0005434964778	18241	Economy	67800.00
0005434964773	18241	Economy	67800.00
0005434964774	18241	Economy	67800.00
0005434964772	18241	Economy	67800.00
0005434964737	18241	Economy	67800.00
0005434964777	18241	Economy	67800.00
0005435907642	4872	Business	44200.00
0005433194990	4872	Business	44200.00
0005433194965	4872	Business	44200.00
0005433195011	4872	Economy	14700.00
0005433194967	4872	Economy	14700.00
0005433195009	4872	Economy	14700.00
0005433195008	4872	Economy	14700.00
0005433195006	4872	Economy	14700.00
0005433195010	4872	Economy	14700.00
0005433194989	4872	Economy	14700.00
0005433194964	4872	Economy	14700.00
0005433195005	4872	Economy	14700.00
0005434626240	32929	Economy	14700.00
0005434626239	32929	Economy	14700.00
0005435786356	13762	Economy	3400.00
0005435786367	13762	Economy	3100.00
0005435786345	13762	Economy	3100.00
0005435786352	13762	Economy	3100.00
0005435786348	13762	Economy	3100.00
0005435786336	13762	Economy	3100.00
0005435786269	13762	Economy	3100.00
0005435787412	13762	Economy	3100.00
0005435786351	13762	Economy	3100.00
0005435786275	13762	Economy	3100.00
0005435786357	13762	Economy	3100.00
0005435786268	13762	Economy	3100.00
0005435937562	27432	Economy	3100.00
0005435937560	27432	Economy	3100.00
0005435937556	27432	Economy	3100.00
0005435937557	27432	Economy	3100.00
0005434409572	20307	Business	12000.00
0005434409571	20307	Business	12000.00
0005434409596	20307	Business	12000.00
0005434409517	20307	Economy	4000.00
0005434409567	20307	Economy	4000.00
0005434409523	20307	Economy	4000.00
0005434409522	20307	Economy	4000.00
0005434409582	20307	Economy	4000.00
0005434409518	20307	Economy	4000.00
0005434409524	20307	Economy	4000.00
0005434409526	20307	Economy	4000.00
0005434409543	20307	Economy	4000.00
0005434409593	20307	Economy	4000.00
0005434409538	20307	Economy	4000.00
0005434409615	20307	Economy	4000.00
0005434409597	20307	Economy	4000.00
0005434409616	20307	Economy	4000.00
0005434409539	20307	Economy	4000.00
0005434409581	20307	Economy	4000.00
0005434409577	20307	Economy	4000.00
0005435311536	27009	Business	12000.00
0005435311554	27009	Economy	4000.00
0005435311490	27009	Economy	4400.00
0005435311520	27009	Economy	4000.00
0005435311489	27009	Economy	4000.00
0005435311531	27009	Economy	4000.00
0005435311555	27009	Economy	4000.00
0005435311556	27009	Economy	4000.00
0005435311543	27009	Economy	4000.00
0005433124488	5686	Business	43300.00
0005433124542	5686	Business	43300.00
0005433124541	5686	Economy	14400.00
0005435297376	5686	Economy	15900.00
0005433124454	5686	Economy	14400.00
0005433124497	5686	Economy	14400.00
0005433124509	5686	Economy	14400.00
0005433124453	5686	Economy	14400.00
0005433124459	5686	Economy	14400.00
0005434319861	15659	Business	43300.00
0005434310150	15659	Business	43300.00
0005434310176	15659	Business	43300.00
0005434319862	15659	Economy	14400.00
0005434319866	15659	Economy	14400.00
0005434319846	15659	Economy	14400.00
0005434319845	15659	Economy	14400.00
0005434311281	15659	Economy	14400.00
0005434310185	15659	Economy	14400.00
0005434319818	15659	Economy	14400.00
0005434310169	15659	Economy	14400.00
0005434319841	15659	Economy	14400.00
0005434310184	15659	Economy	14400.00
0005434310171	15659	Economy	14400.00
0005434310170	15659	Economy	14400.00
0005434310156	15659	Economy	14400.00
0005434310177	15659	Economy	14400.00
0005434319864	15659	Economy	14400.00
0005434319860	15659	Economy	14400.00
0005434319824	15659	Economy	14400.00
0005434310157	15659	Economy	14400.00
0005434310165	15659	Economy	14400.00
0005434319843	15659	Economy	14400.00
0005434310158	15659	Economy	14400.00
0005434319859	15659	Economy	14400.00
0005434319844	15659	Economy	14400.00
0005435220379	24964	Economy	15500.00
0005435220384	24964	Economy	15500.00
0005435217772	24964	Economy	15500.00
0005435220380	24964	Economy	15500.00
0005435220385	24964	Economy	15500.00
0005435220383	24964	Economy	15500.00
0005435217774	24964	Economy	15500.00
0005435217773	24964	Economy	15500.00
0005435903230	8989	Economy	24900.00
0005434484539	16663	Economy	24900.00
0005434310150	7688	Business	11100.00
0005435477030	7688	Business	11100.00
0005435477015	7688	Business	11100.00
0005434310170	7688	Economy	3700.00
0005435477029	7688	Economy	3700.00
0005434310169	7688	Economy	3700.00
0005434310177	7688	Economy	3700.00
0005434310171	7688	Economy	3700.00
0005434310158	7688	Economy	4100.00
0005433722436	7688	Economy	4100.00
0005435477031	7688	Economy	3700.00
0005433722474	7688	Economy	3700.00
0005433722413	7688	Economy	3700.00
0005433722421	7688	Economy	3700.00
0005434310157	7688	Economy	3700.00
0005434310185	7688	Economy	3700.00
0005433722499	7688	Economy	3700.00
0005434310184	7688	Economy	3700.00
0005435477028	7688	Economy	3700.00
0005434310176	7688	Economy	3700.00
0005433722509	7688	Economy	3700.00
0005434310165	7688	Economy	3700.00
0005433722500	7688	Economy	3700.00
0005434310156	7688	Economy	3700.00
0005435477022	7688	Economy	3700.00
0005433722475	7688	Economy	3700.00
0005433450603	30389	Business	11100.00
0005432693924	30389	Business	11100.00
0005432693882	30389	Economy	3700.00
0005433450557	30389	Economy	3700.00
0005432693950	30389	Economy	3700.00
0005433450605	30389	Economy	3700.00
0005433450580	30389	Economy	3700.00
0005432693968	30389	Economy	3700.00
0005432693937	30389	Economy	3700.00
0005432693958	30389	Economy	3700.00
0005432693957	30389	Economy	3700.00
0005433450602	30389	Economy	3700.00
0005432693969	30389	Economy	3700.00
0005433450597	30389	Economy	3700.00
0005432693949	30389	Economy	3700.00
0005432693940	30389	Economy	3700.00
0005433124497	30390	Business	11100.00
0005432721681	30390	Economy	3700.00
0005433124542	30390	Economy	3700.00
0005433124541	30390	Economy	3700.00
0005433124509	30390	Economy	3700.00
0005432721691	30390	Economy	3700.00
0005433124453	30390	Economy	3700.00
0005432721682	30390	Economy	3700.00
0005433124454	30390	Economy	3700.00
0005433124459	30390	Economy	3700.00
0005433124488	30390	Economy	3700.00
0005432928145	1364	Business	70400.00
0005433193446	1364	Business	70400.00
0005432968905	1364	Business	70400.00
0005432928147	1364	Economy	23500.00
0005432928146	1364	Economy	23500.00
0005432928148	1364	Economy	23500.00
0005433193445	1364	Economy	23500.00
0005433193444	1364	Economy	23500.00
0005432928130	1364	Economy	23500.00
0005433193437	1364	Economy	23500.00
0005434587349	18531	Business	70400.00
0005434587333	18531	Economy	23500.00
0005433525362	18531	Economy	23500.00
0005433525322	18531	Economy	23500.00
0005434587347	18531	Economy	23500.00
0005433525321	18531	Economy	23500.00
0005434587348	18531	Economy	23500.00
0005433525361	18531	Economy	23500.00
0005433724927	18531	Economy	23500.00
0005433525338	18531	Economy	23500.00
0005434142717	29762	Economy	4300.00
0005434142726	29762	Economy	4000.00
0005434345234	29762	Economy	4000.00
0005434345245	29762	Economy	4000.00
0005434345291	29762	Economy	4000.00
0005434142724	29762	Economy	4000.00
0005434142723	29762	Economy	4000.00
0005434345290	29762	Economy	4000.00
0005434345248	29762	Economy	4000.00
0005434345282	29762	Economy	4000.00
0005434345288	29762	Economy	4000.00
0005434142710	29762	Economy	4000.00
0005434345237	29762	Economy	4000.00
0005434142711	29762	Economy	4000.00
0005434142725	29762	Economy	4000.00
0005434345228	29762	Economy	4000.00
0005434345238	29762	Economy	4000.00
0005434345246	29762	Economy	4000.00
0005434345247	29762	Economy	4000.00
0005434345118	29762	Economy	4000.00
0005434345233	29762	Economy	4000.00
0005434142712	29762	Economy	4000.00
0005434345262	29762	Economy	4000.00
0005434142728	29762	Economy	4000.00
0005435825425	18031	Business	199800.00
0005435825400	18031	Business	199800.00
0005435825407	18031	Economy	66600.00
0005435825401	18031	Economy	73200.00
0005435825416	18031	Economy	66600.00
0005435825387	18031	Economy	66600.00
0005435825426	18031	Economy	66600.00
0005435825420	18031	Economy	66600.00
0005435243536	5618	Business	27800.00
0005435626885	5618	Business	27800.00
0005435243636	5618	Business	27800.00
0005435243620	5618	Economy	9300.00
0005435243602	5618	Economy	9300.00
0005435243635	5618	Economy	9300.00
0005435243662	5618	Economy	9300.00
0005435243572	5618	Economy	9300.00
0005435626886	5618	Economy	9300.00
0005435243666	5618	Economy	9300.00
0005435243626	5618	Economy	9300.00
0005435476991	5618	Economy	9300.00
0005435243663	5618	Economy	9300.00
0005435243661	5618	Economy	9300.00
0005435243603	5618	Economy	9300.00
0005435477006	5618	Economy	9300.00
0005435243601	5618	Economy	9300.00
0005435243665	5618	Economy	9300.00
0005435243652	5618	Economy	9300.00
0005435243630	5618	Economy	9300.00
0005435243639	5618	Economy	9300.00
0005435243664	5618	Economy	9300.00
0005435243651	5618	Economy	9300.00
0005435476999	5618	Economy	9300.00
0005432785358	15375	Business	27800.00
0005432785339	15375	Business	27800.00
0005432785336	15375	Business	27800.00
0005432785304	15375	Economy	9300.00
0005432785340	15375	Economy	10200.00
0005432785331	15375	Economy	9300.00
0005432785367	15375	Economy	9300.00
0005432785354	15375	Economy	9300.00
0005432785332	15375	Economy	9300.00
0005432785368	15375	Economy	9300.00
0005432785185	15375	Economy	9300.00
0005432785345	15375	Economy	9300.00
0005435950054	15375	Economy	9300.00
0005432848723	28856	Economy	7000.00
0005434461708	28856	Economy	6300.00
0005432848713	28856	Economy	6300.00
0005432848712	28856	Economy	6300.00
0005435375180	6334	Business	11900.00
0005435257537	6334	Economy	4000.00
0005435257538	6334	Economy	4000.00
0005434926846	20311	Business	11900.00
0005433497852	20311	Business	11900.00
0005434926796	20311	Business	11900.00
0005434926828	20311	Economy	4000.00
0005433497850	20311	Economy	4000.00
0005434926779	20311	Economy	4000.00
0005434926825	20311	Economy	4400.00
0005433497874	20311	Economy	4400.00
0005434926797	20311	Economy	4000.00
0005434444178	20311	Economy	4000.00
0005434926845	20311	Economy	4000.00
0005434926629	20311	Economy	4000.00
0005434444162	20311	Economy	4000.00
0005433497879	20311	Economy	4000.00
0005434926753	20311	Economy	4000.00
0005434926617	20311	Economy	4000.00
0005434926823	20311	Economy	4000.00
0005434926653	20311	Economy	4000.00
0005434444132	20311	Economy	4000.00
0005434444180	20311	Economy	4000.00
0005434926824	20311	Economy	4000.00
0005434926754	20311	Economy	4000.00
0005434444131	20311	Economy	4000.00
0005433497880	20311	Economy	4000.00
0005434926759	20311	Economy	4000.00
0005434926844	20311	Economy	4000.00
0005434926757	20311	Economy	4000.00
0005433497863	20311	Economy	4000.00
0005434926652	20311	Economy	4000.00
0005434926847	20311	Economy	4000.00
0005433497873	20311	Economy	4000.00
0005434444163	20311	Economy	4000.00
0005434926688	20311	Economy	4000.00
0005434926810	20311	Economy	4000.00
0005434926741	20311	Economy	4000.00
0005433497862	20311	Economy	4000.00
0005434926760	20311	Economy	4000.00
0005434926816	20311	Economy	4000.00
0005434444177	20311	Economy	4000.00
0005434926855	20311	Economy	4000.00
0005434926832	20311	Economy	4000.00
0005434926755	20311	Economy	4000.00
0005432785318	12170	Business	41200.00
0005432785335	12170	Business	41200.00
0005432785361	12170	Economy	13700.00
0005432785290	12170	Economy	13700.00
0005432785326	12170	Economy	13700.00
0005432785325	12170	Economy	13700.00
0005432785317	12170	Economy	13700.00
0005432785327	12170	Economy	13700.00
0005432785165	12170	Economy	13700.00
0005432785360	12170	Economy	13700.00
0005435243640	15408	Business	41200.00
0005435243557	15408	Economy	13700.00
0005435243609	15408	Economy	13700.00
0005435243608	15408	Economy	13700.00
0005435243606	15408	Economy	13700.00
0005435243655	15408	Economy	13700.00
0005435243644	15408	Economy	13700.00
0005435243629	15408	Economy	13700.00
0005434880954	10105	Business	49700.00
0005434880905	10105	Economy	16600.00
0005434758963	10105	Economy	16600.00
0005434880973	10105	Economy	18200.00
0005434758964	10105	Economy	16600.00
0005434880875	10105	Economy	16600.00
0005434880985	10105	Economy	16600.00
0005434758959	10105	Economy	16600.00
0005434880972	10105	Economy	16600.00
0005434880912	10105	Economy	16600.00
0005434880984	10105	Economy	16600.00
0005434880851	10105	Economy	16600.00
0005434880979	10105	Economy	16600.00
0005434880955	10105	Economy	16600.00
0005434880911	10105	Economy	16600.00
0005434758960	10105	Economy	16600.00
0005435914120	14611	Business	49700.00
0005435914183	14611	Business	49700.00
0005435914154	14611	Economy	16600.00
0005434910181	14611	Economy	16600.00
0005434910179	14611	Economy	18200.00
0005435914209	14611	Economy	16600.00
0005435914193	14611	Economy	16600.00
0005435914153	14611	Economy	16600.00
0005435914205	14611	Economy	16600.00
0005434910180	14611	Economy	16600.00
0005435933556	9224	Economy	20300.00
0005434252245	9224	Economy	20300.00
0005434252239	9224	Economy	20300.00
0005435660464	24682	Economy	20300.00
0005432967680	2776	Business	33000.00
0005432967679	2776	Economy	11000.00
0005432967667	2776	Economy	11000.00
0005433681836	29185	Business	33000.00
0005433681835	29185	Economy	11000.00
0005433681958	29185	Economy	12100.00
0005433681977	29185	Economy	11000.00
0005433687764	29185	Economy	11000.00
0005433681806	29185	Economy	11000.00
0005433681957	29185	Economy	11000.00
0005433681834	29185	Economy	11000.00
0005433681812	29185	Economy	11000.00
0005435856360	9304	Business	132900.00
0005434269162	9304	Business	132900.00
0005435856359	9304	Business	132900.00
0005435856361	9304	Economy	44300.00
0005434163861	9304	Economy	44300.00
0005434163860	9304	Economy	44300.00
0005435856363	9304	Economy	44300.00
0005434269165	9304	Economy	44300.00
0005434163870	9304	Economy	44300.00
0005433616753	25255	Business	132900.00
0005433634729	25255	Business	132900.00
0005433616769	25255	Business	132900.00
0005433616826	25255	Business	132900.00
0005433616754	25255	Business	132900.00
0005433616816	25255	Business	132900.00
0005433578193	25255	Business	132900.00
0005433616801	25255	Business	132900.00
0005433616635	25255	Economy	48700.00
0005433578124	25255	Economy	44300.00
0005433634730	25255	Economy	44300.00
0005433616770	25255	Economy	44300.00
0005433616720	25255	Economy	44300.00
0005433616721	25255	Economy	44300.00
0005433578192	25255	Economy	44300.00
0005435983720	25255	Economy	44300.00
0005433616809	25255	Economy	44300.00
0005433634723	25255	Economy	44300.00
0005433634758	25255	Economy	44300.00
0005433616773	25255	Economy	44300.00
0005433634784	25255	Economy	44300.00
0005433634801	25255	Economy	44300.00
0005433616751	25255	Economy	44300.00
0005433634738	25255	Economy	44300.00
0005433616687	25255	Economy	44300.00
0005433634747	25255	Economy	44300.00
0005435983709	25255	Economy	48700.00
0005435983719	25255	Economy	48700.00
0005433634824	25255	Economy	44300.00
0005433616716	25255	Economy	44300.00
0005433616802	25255	Economy	44300.00
0005433616604	25255	Economy	44300.00
0005433616703	25255	Economy	44300.00
0005433616502	25255	Economy	44300.00
0005433616799	25255	Economy	44300.00
0005433616821	25255	Economy	44300.00
0005433616666	25255	Economy	44300.00
0005433634821	25255	Economy	44300.00
0005433634791	25255	Economy	44300.00
0005433616820	25255	Economy	44300.00
0005433634739	25255	Economy	44300.00
0005433634793	25255	Economy	44300.00
0005433616808	25255	Economy	44300.00
0005433634792	25255	Economy	44300.00
0005433634737	25255	Economy	44300.00
0005433634771	25255	Economy	44300.00
0005433616641	25255	Economy	44300.00
0005433616689	25255	Economy	44300.00
0005433616815	25255	Economy	44300.00
0005433616688	25255	Economy	44300.00
0005435947675	4240	Business	193100.00
0005435947669	4240	Economy	70800.00
0005435477023	4240	Economy	64400.00
0005432571432	4240	Economy	64400.00
0005435477019	4240	Economy	64400.00
0005435947668	4240	Economy	64400.00
0005435477020	4240	Economy	64400.00
0005432571428	4240	Economy	64400.00
0005432571433	4240	Economy	64400.00
0005435477018	4240	Economy	64400.00
0005435477016	4240	Economy	64400.00
0005432571431	4240	Economy	70800.00
0005435477017	4240	Economy	64400.00
0005435987061	26586	Business	193100.00
0005435987022	26586	Economy	64400.00
0005435987049	26586	Economy	64400.00
0005435987039	26586	Economy	64400.00
0005435987038	26586	Economy	64400.00
0005435987050	26586	Economy	64400.00
0005435987062	26586	Economy	64400.00
0005432949678	325	Business	21500.00
0005432949642	325	Business	21500.00
0005433929878	325	Economy	7900.00
0005433075463	325	Economy	7900.00
0005432949676	325	Economy	7200.00
0005432949688	325	Economy	7200.00
0005432949669	325	Economy	7200.00
0005432949668	325	Economy	7200.00
0005432949647	325	Economy	7200.00
0005432949583	325	Economy	7200.00
0005432949590	325	Economy	7200.00
0005432949677	325	Economy	7200.00
0005432949667	325	Economy	7200.00
0005432949664	325	Economy	7200.00
0005432949670	325	Economy	7200.00
0005433929877	325	Economy	7200.00
0005432949691	325	Economy	7200.00
0005433570697	11611	Business	21500.00
0005434088024	11611	Business	21500.00
0005433570782	11611	Business	21500.00
0005433570869	11611	Business	21500.00
0005433570698	11611	Business	21500.00
0005433570780	11611	Business	21500.00
0005433570916	11611	Business	21500.00
0005433570675	11611	Business	21500.00
0005433570801	11611	Business	21500.00
0005433570597	11611	Economy	7900.00
0005433570881	11611	Economy	7200.00
0005433570855	11611	Economy	7200.00
0005434088030	11611	Economy	7200.00
0005433570915	11611	Economy	7200.00
0005433570783	11611	Economy	7200.00
0005434088015	11611	Economy	7200.00
0005433570981	11611	Economy	7200.00
0005433570832	11611	Economy	7200.00
0005433570823	11611	Economy	7200.00
0005433570889	11611	Economy	7200.00
0005433570596	11611	Economy	7200.00
0005434088017	11611	Economy	7200.00
0005433570737	11611	Economy	7200.00
0005433570917	11611	Economy	7200.00
0005434088023	11611	Economy	7200.00
0005433570964	11611	Economy	7200.00
0005434326042	11611	Economy	7200.00
0005433570890	11611	Economy	7200.00
0005433570927	11611	Economy	7200.00
0005433570817	11611	Economy	7200.00
0005434088031	11611	Economy	7900.00
0005433570760	11611	Economy	7900.00
0005433570747	11611	Economy	7200.00
0005433570947	11611	Economy	7200.00
0005433570932	11611	Economy	7200.00
0005433570913	11611	Economy	7200.00
0005433570941	11611	Economy	7200.00
0005433570914	11611	Economy	7200.00
0005434326014	11611	Economy	7200.00
0005433570926	11611	Economy	7200.00
0005433570676	11611	Economy	7200.00
0005433570779	11611	Economy	7200.00
0005433570899	11611	Economy	7200.00
0005434326028	11611	Economy	7200.00
0005434087992	11611	Economy	7200.00
0005433570942	11611	Economy	7200.00
0005433570736	11611	Economy	7200.00
0005433570713	11611	Economy	7200.00
0005434733083	9946	Economy	6300.00
0005434733082	9946	Economy	6300.00
0005433435491	2320	Business	184500.00
0005432985990	2320	Business	184500.00
0005432985997	2320	Business	184500.00
0005433435504	2320	Economy	61500.00
0005433435473	2320	Economy	61500.00
0005433435464	2320	Economy	61500.00
0005432869719	2320	Economy	61500.00
0005432869711	2320	Economy	61500.00
0005432986016	2320	Economy	61500.00
0005432986008	2320	Economy	61500.00
0005432985991	2320	Economy	61500.00
0005433755872	26161	Business	184500.00
0005435983495	26161	Business	184500.00
0005435983654	26161	Business	184500.00
0005433755885	26161	Business	184500.00
0005435983612	26161	Economy	67700.00
0005435983615	26161	Economy	61500.00
0005435983554	26161	Economy	61500.00
0005432655885	26161	Economy	61500.00
0005435983582	26161	Economy	61500.00
0005435983438	26161	Economy	61500.00
0005435983611	26161	Economy	61500.00
0005435983439	26161	Economy	61500.00
0005433755773	26161	Economy	61500.00
0005435983634	26161	Economy	61500.00
0005433766751	26161	Economy	61500.00
0005435983655	26161	Economy	61500.00
0005433755774	26161	Economy	61500.00
0005433755825	26161	Economy	61500.00
0005433755775	26161	Economy	61500.00
0005435983606	26161	Economy	61500.00
0005433755871	26161	Economy	61500.00
0005435983581	26161	Economy	61500.00
0005435983624	26161	Economy	61500.00
0005433755844	26161	Economy	61500.00
0005435983453	26161	Economy	61500.00
0005433755824	26161	Economy	61500.00
0005435983625	26161	Economy	61500.00
0005435983494	26161	Economy	61500.00
0005432655860	26161	Economy	61500.00
0005433755688	26161	Economy	61500.00
0005435983604	26161	Economy	61500.00
0005433755886	26161	Economy	61500.00
0005435983661	26161	Economy	61500.00
0005433152402	1536	Economy	13000.00
0005433152417	1536	Economy	13000.00
0005433152334	1536	Economy	13000.00
0005433152333	1536	Economy	13000.00
0005434376010	20133	Business	38900.00
0005434375975	20133	Business	38900.00
0005434376034	20133	Business	38900.00
0005434376011	20133	Economy	13000.00
0005434375925	20133	Economy	13000.00
0005434376048	20133	Economy	13000.00
0005434375926	20133	Economy	13000.00
0005434376049	20133	Economy	13000.00
0005434375995	20133	Economy	13000.00
0005434376236	20133	Economy	13000.00
0005433262047	522	Economy	10100.00
0005433262035	522	Economy	9200.00
0005433262046	522	Economy	9200.00
0005433262044	522	Economy	9200.00
0005433262045	522	Economy	9200.00
0005434995382	12865	Economy	9200.00
0005434995371	12865	Economy	9200.00
0005434995373	12865	Economy	9200.00
0005432425781	12937	Business	27500.00
0005432426058	12937	Business	27500.00
0005432425976	12937	Business	27500.00
0005432426071	12937	Business	27500.00
0005432426078	12937	Business	27500.00
0005432425927	12937	Business	27500.00
0005432425835	12937	Economy	10100.00
0005432425645	12937	Economy	9200.00
0005432425646	12937	Economy	9200.00
0005432425808	12937	Economy	9200.00
0005432425917	12937	Economy	9200.00
0005432425912	12937	Economy	9200.00
0005432426032	12937	Economy	9200.00
0005432425978	12937	Economy	9200.00
0005432425994	12937	Economy	9200.00
0005432425931	12937	Economy	9200.00
0005432426031	12937	Economy	9200.00
0005432425941	12937	Economy	9200.00
0005432425923	12937	Economy	9200.00
0005432425834	12937	Economy	9200.00
0005432425893	12937	Economy	9200.00
0005432425913	12937	Economy	9200.00
0005432425833	12937	Economy	9200.00
0005432425891	12937	Economy	9200.00
0005432426033	12937	Economy	9200.00
0005432425690	12937	Economy	9200.00
0005432425984	12937	Economy	9200.00
0005432425977	12937	Economy	9200.00
0005432426023	12937	Economy	9200.00
0005432425742	12937	Economy	9200.00
0005432425956	12937	Economy	9200.00
0005432425896	12937	Economy	9200.00
0005432425898	12937	Economy	9200.00
0005432425950	12937	Economy	9200.00
0005432425895	12937	Economy	9200.00
0005432425894	12937	Economy	9200.00
0005432425947	12937	Economy	9200.00
0005432426059	12937	Economy	9200.00
0005432426030	12937	Economy	9200.00
0005432426051	12937	Economy	9200.00
0005432425874	12937	Economy	9200.00
0005432425949	12937	Economy	9200.00
0005432425914	12937	Economy	9200.00
0005432425930	12937	Economy	9200.00
0005432425955	12937	Economy	9200.00
0005432426024	12937	Economy	9200.00
0005432425691	12937	Economy	9200.00
0005432425946	12937	Economy	9200.00
0005432426015	12937	Economy	9200.00
0005433059063	428	Business	24500.00
0005433059062	428	Business	24500.00
0005434735823	428	Business	24500.00
0005434376235	428	Economy	8200.00
0005433059061	428	Economy	8200.00
0005433059067	428	Economy	8200.00
0005433059043	428	Economy	8200.00
0005434735835	428	Economy	8200.00
0005433058991	428	Economy	8200.00
0005434028396	12661	Business	24500.00
0005434025664	12661	Business	24500.00
0005434025673	12661	Business	24500.00
0005434025663	12661	Business	24500.00
0005434025644	12661	Business	24500.00
0005434025675	12661	Economy	8200.00
0005434025550	12661	Economy	8200.00
0005434025578	12661	Economy	8200.00
0005434028395	12661	Economy	8200.00
0005434025482	12661	Economy	8200.00
0005434025630	12661	Economy	8200.00
0005434025629	12661	Economy	8200.00
0005434025653	12661	Economy	8200.00
0005434032158	12661	Economy	8200.00
0005433037851	2121	Business	34700.00
0005432749851	2121	Economy	11600.00
0005434175874	2121	Economy	11600.00
0005433037850	2121	Economy	11600.00
0005434028395	2121	Economy	11600.00
0005432749850	2121	Economy	11600.00
0005433037838	2121	Economy	11600.00
0005434175875	2121	Economy	11600.00
0005434028396	2121	Economy	11600.00
0005434175872	2121	Economy	11600.00
0005433037829	2121	Economy	11600.00
0005433037848	2121	Economy	11600.00
0005434175873	2121	Economy	11600.00
0005433037849	2121	Economy	11600.00
0005433037830	2121	Economy	11600.00
0005433926094	24139	Business	34700.00
0005433926120	24139	Business	34700.00
0005433926119	24139	Business	34700.00
0005433926116	24139	Economy	12700.00
0005433926118	24139	Economy	11600.00
0005433925901	24139	Economy	11600.00
0005433926083	24139	Economy	11600.00
0005433926087	24139	Economy	11600.00
0005433925709	24139	Economy	11600.00
0005433926035	24139	Economy	11600.00
0005433926036	24139	Economy	11600.00
0005433929892	24139	Economy	11600.00
0005433929730	24139	Economy	11600.00
0005433926084	24139	Economy	11600.00
0005433926059	24139	Economy	11600.00
0005433929893	24139	Economy	11600.00
0005433925642	24139	Economy	11600.00
0005433926111	24139	Economy	11600.00
0005433929898	24139	Economy	11600.00
0005433926082	24139	Economy	11600.00
0005433236008	257	Business	83700.00
0005433235980	257	Business	83700.00
0005433236045	257	Comfort	47400.00
0005433236004	257	Comfort	47400.00
0005433131838	257	Comfort	47400.00
0005433235978	257	Comfort	47400.00
0005433181833	257	Economy	27900.00
0005433236028	257	Economy	27900.00
0005433236031	257	Economy	27900.00
0005433235924	257	Economy	27900.00
0005433235977	257	Economy	27900.00
0005433236026	257	Economy	30700.00
0005433235914	257	Economy	27900.00
0005433236011	257	Economy	27900.00
0005433113597	257	Economy	27900.00
0005433236003	257	Economy	27900.00
0005433236027	257	Economy	27900.00
0005433235979	257	Economy	27900.00
0005433236002	257	Economy	27900.00
0005433766753	257	Economy	27900.00
0005433236001	257	Economy	27900.00
0005433236046	257	Economy	27900.00
0005433235913	257	Economy	27900.00
0005433235915	257	Economy	27900.00
0005433181834	257	Economy	27900.00
0005433181832	257	Economy	27900.00
0005433236010	257	Economy	27900.00
0005433235976	257	Economy	27900.00
0005433181768	257	Economy	27900.00
0005433236044	257	Economy	27900.00
0005434302576	9868	Business	83700.00
0005434729005	9868	Business	83700.00
0005434302575	9868	Business	83700.00
0005434728942	9868	Business	83700.00
0005434728997	9868	Business	83700.00
0005434552797	9868	Business	83700.00
0005434728747	9868	Business	83700.00
0005434729006	9868	Business	83700.00
0005434728850	9868	Comfort	47400.00
0005434728846	9868	Comfort	47400.00
0005434552787	9868	Comfort	47400.00
0005434728966	9868	Comfort	47400.00
0005434728907	9868	Comfort	47400.00
0005434728657	9868	Comfort	47400.00
0005434728965	9868	Comfort	47400.00
0005434552760	9868	Economy	27900.00
0005434552720	9868	Economy	27900.00
0005434728748	9868	Economy	27900.00
0005434735843	9868	Economy	27900.00
0005435142939	9868	Economy	27900.00
0005434552756	9868	Economy	27900.00
0005434552726	9868	Economy	30700.00
0005434552765	9868	Economy	27900.00
0005434728844	9868	Economy	27900.00
0005434729002	9868	Economy	27900.00
0005434729022	9868	Economy	27900.00
0005434735844	9868	Economy	27900.00
0005434552443	9868	Economy	27900.00
0005434729023	9868	Economy	27900.00
0005434552727	9868	Economy	27900.00
0005434728936	9868	Economy	27900.00
0005434728887	9868	Economy	27900.00
0005434728906	9868	Economy	27900.00
0005434552786	9868	Economy	27900.00
0005434728967	9868	Economy	27900.00
0005434552798	9868	Economy	27900.00
0005434735842	9868	Economy	27900.00
0005434728845	9868	Economy	27900.00
0005434728971	9868	Economy	27900.00
0005434728835	9868	Economy	27900.00
0005434728941	9868	Economy	27900.00
0005434728978	9868	Economy	27900.00
0005435142938	9868	Economy	27900.00
0005434728836	9868	Economy	27900.00
0005434728849	9868	Economy	27900.00
0005434728827	9868	Economy	27900.00
0005434728968	9868	Economy	27900.00
0005434729007	9868	Economy	27900.00
0005434735841	9868	Economy	27900.00
0005434728658	9868	Economy	27900.00
0005434729001	9868	Economy	27900.00
0005434552806	9868	Economy	27900.00
0005434552444	9868	Economy	27900.00
0005434729013	9868	Economy	27900.00
0005435215509	7774	Business	42100.00
0005435215385	7774	Comfort	23900.00
0005435215450	7774	Comfort	23900.00
0005435215451	7774	Comfort	23900.00
0005435215405	7774	Economy	14000.00
0005435283530	7774	Economy	14000.00
0005435215517	7774	Economy	14000.00
0005435215459	7774	Economy	14000.00
0005435215403	7774	Economy	14000.00
0005435215506	7774	Economy	14000.00
0005435215423	7774	Economy	14000.00
0005435215498	7774	Economy	14000.00
0005435215490	7774	Economy	14000.00
0005435215427	7774	Economy	14000.00
0005435215449	7774	Economy	14000.00
0005435215384	7774	Economy	14000.00
0005435215422	7774	Economy	14000.00
0005435631049	7774	Economy	14000.00
0005435631048	7774	Economy	14000.00
0005435215524	7774	Economy	14000.00
0005435215458	7774	Economy	14000.00
0005435215505	7774	Economy	14000.00
0005435631052	7774	Economy	14000.00
0005435215460	7774	Economy	14000.00
0005435215494	7774	Economy	14000.00
0005435283531	7774	Economy	14000.00
0005435631051	7774	Economy	14000.00
0005435215448	7774	Economy	14000.00
0005435283552	7774	Economy	14000.00
0005435042936	5335	Business	43100.00
0005432363513	5335	Business	43100.00
0005435426770	5335	Comfort	24400.00
0005435319829	5335	Comfort	24400.00
0005435426771	5335	Comfort	24400.00
0005435426812	5335	Economy	14400.00
0005435768116	5335	Economy	14400.00
0005435426828	5335	Economy	14400.00
0005432363514	5335	Economy	14400.00
0005435042937	5335	Economy	14400.00
0005435042925	5335	Economy	14400.00
0005433719234	5335	Economy	14400.00
0005433719226	5335	Economy	14400.00
0005435380443	5335	Economy	14400.00
0005434245820	5335	Economy	14400.00
0005434245780	5335	Economy	14400.00
0005435426777	5335	Economy	14400.00
0005435426826	5335	Economy	14400.00
0005433719239	5335	Economy	14400.00
0005434245842	5335	Economy	14400.00
0005433719233	5335	Economy	14400.00
0005435426794	5335	Economy	14400.00
0005435426772	5335	Economy	14400.00
0005435426809	5335	Economy	14400.00
0005434245841	5335	Economy	14400.00
0005435042938	5335	Economy	14400.00
0005435426827	5335	Economy	14400.00
0005435426611	5335	Economy	14400.00
0005435426841	5335	Economy	14400.00
0005435768117	5335	Economy	14400.00
0005435426842	5335	Economy	14400.00
0005432841073	5335	Economy	14400.00
0005435426778	5335	Economy	14400.00
0005435380436	5335	Economy	14400.00
0005434245764	5335	Economy	14400.00
0005434345175	10890	Business	43100.00
0005434345180	10890	Business	43100.00
0005434573761	10890	Business	43100.00
0005435616990	10890	Business	43100.00
0005435616957	10890	Comfort	24400.00
0005434573767	10890	Comfort	24400.00
0005435490335	10890	Comfort	24400.00
0005435617027	10890	Comfort	24400.00
0005434573712	10890	Comfort	24400.00
0005435616739	10890	Comfort	24400.00
0005435616983	10890	Economy	14400.00
0005434345229	10890	Economy	14400.00
0005435617000	10890	Economy	14400.00
0005434345213	10890	Economy	14400.00
0005435616738	10890	Economy	14400.00
0005435491507	10890	Economy	14400.00
0005435616853	10890	Economy	14400.00
0005435616977	10890	Economy	14400.00
0005435546239	10890	Economy	15800.00
0005435616999	10890	Economy	15800.00
0005435616934	10890	Economy	14400.00
0005434345176	10890	Economy	14400.00
0005434345212	10890	Economy	14400.00
0005435617036	10890	Economy	14400.00
0005434345047	10890	Economy	14400.00
0005435616973	10890	Economy	14400.00
0005435616844	10890	Economy	14400.00
0005434573754	10890	Economy	14400.00
0005435616866	10890	Economy	14400.00
0005434345046	10890	Economy	14400.00
0005435097493	10890	Economy	14400.00
0005434345254	10890	Economy	14400.00
0005435616947	10890	Economy	14400.00
0005434573711	10890	Economy	14400.00
0005434345253	10890	Economy	14400.00
0005434345264	10890	Economy	14400.00
0005435617037	10890	Economy	14400.00
0005435617202	10890	Economy	14400.00
0005435616998	10890	Economy	14400.00
0005435617019	10890	Economy	14400.00
0005435626886	10890	Economy	14400.00
0005435617040	10890	Economy	14400.00
0005435616958	10890	Economy	15800.00
0005435617026	10890	Economy	14400.00
0005435491506	10890	Economy	14400.00
0005434345221	10890	Economy	14400.00
0005435617028	10890	Economy	14400.00
0005435616974	10890	Economy	14400.00
0005434345283	10890	Economy	14400.00
0005435616984	10890	Economy	14400.00
0005435616985	10890	Economy	14400.00
0005435616972	10890	Economy	14400.00
0005434345230	10890	Economy	14400.00
0005435626885	10890	Economy	14400.00
0005434345162	10890	Economy	14400.00
0005435551775	10890	Economy	14400.00
0005435546240	10890	Economy	14400.00
0005434345284	10890	Economy	14400.00
0005435491495	10890	Economy	14400.00
0005432461297	3346	Business	18800.00
0005432461410	3346	Business	18800.00
0005432461392	3346	Business	18800.00
0005432461433	3346	Business	18800.00
0005432461354	3346	Business	18800.00
0005432461336	3346	Business	18800.00
0005435860727	3346	Business	18800.00
0005432461323	3346	Economy	6900.00
0005432461394	3346	Economy	6300.00
0005434311290	3346	Economy	6300.00
0005432461356	3346	Economy	6300.00
0005435860726	3346	Economy	6300.00
0005432461364	3346	Economy	6300.00
0005432461350	3346	Economy	6300.00
0005432461361	3346	Economy	6300.00
0005432461355	3346	Economy	6300.00
0005432461347	3346	Economy	6300.00
0005432461393	3346	Economy	6300.00
0005434326100	3346	Economy	6300.00
0005432461363	3346	Economy	6900.00
0005432461346	3346	Economy	6900.00
0005435860719	3346	Economy	6900.00
0005432461327	3346	Economy	6300.00
0005435858743	3346	Economy	6300.00
0005432461373	3346	Economy	6300.00
0005432461411	3346	Economy	6300.00
0005432461390	3346	Economy	6300.00
0005432461408	3346	Economy	6300.00
0005432461416	3346	Economy	6300.00
0005434326101	3346	Economy	6300.00
0005432461376	3346	Economy	6300.00
0005435860732	3346	Economy	6300.00
0005434311289	3346	Economy	6300.00
0005435860688	3346	Economy	6300.00
0005432461368	3346	Economy	6300.00
0005432461369	3346	Economy	6300.00
0005432461299	3346	Economy	6300.00
0005435886853	3345	Business	18800.00
0005435886470	3345	Business	18800.00
0005435886851	3345	Business	18800.00
0005435886850	3345	Business	18800.00
0005435886699	3345	Business	18800.00
0005435886852	3345	Business	18800.00
0005435886864	3345	Economy	6900.00
0005435886747	3345	Economy	6900.00
0005435903230	3345	Economy	6300.00
0005435886805	3345	Economy	6300.00
0005435886863	3345	Economy	6300.00
0005435886843	3345	Economy	6300.00
0005435886818	3345	Economy	6300.00
0005435886791	3345	Economy	6300.00
0005435886845	3345	Economy	6300.00
0005435886783	3345	Economy	6300.00
0005435933559	3345	Economy	6300.00
0005435886844	3345	Economy	6300.00
0005435886751	3345	Economy	6300.00
0005435886722	3345	Economy	6300.00
0005435886802	3345	Economy	6300.00
0005435886784	3345	Economy	6300.00
0005435886723	3345	Economy	6300.00
0005435886828	3345	Economy	6300.00
0005435886846	3345	Economy	6300.00
0005433507723	8306	Economy	6300.00
0005433507710	8306	Economy	6300.00
0005435629450	8306	Economy	6300.00
0005433507708	8306	Economy	6300.00
0005433507709	8306	Economy	6300.00
0005433806335	8217	Business	18800.00
0005433634738	8217	Business	18800.00
0005433806402	8217	Business	18800.00
0005433634723	8217	Business	18800.00
0005433634747	8217	Business	18800.00
0005433634821	8217	Economy	6300.00
0005433634730	8217	Economy	6300.00
0005433634784	8217	Economy	6300.00
0005433806378	8217	Economy	6300.00
0005433634824	8217	Economy	6300.00
0005433634737	8217	Economy	6300.00
0005433806390	8217	Economy	6300.00
0005433634793	8217	Economy	6300.00
0005434143754	8217	Economy	6900.00
0005433634739	8217	Economy	6300.00
0005433634729	8217	Economy	6300.00
0005433634758	8217	Economy	6300.00
0005433806403	8217	Economy	6300.00
0005433634792	8217	Economy	6300.00
0005433806392	8217	Economy	6300.00
0005434143761	8217	Economy	6300.00
0005434143760	8217	Economy	6300.00
0005433806396	8217	Economy	6300.00
0005433634801	8217	Economy	6300.00
0005434143840	8217	Economy	6300.00
0005433634771	8217	Economy	6300.00
0005433634791	8217	Economy	6300.00
0005433806391	8217	Economy	6300.00
0005434150198	8309	Business	18800.00
0005434265952	8309	Business	18800.00
0005434266013	8309	Business	18800.00
0005434265923	8309	Business	18800.00
0005434150188	8309	Economy	6900.00
0005434266029	8309	Economy	6300.00
0005434150226	8309	Economy	6300.00
0005434150227	8309	Economy	6300.00
0005434265960	8309	Economy	6300.00
0005434266020	8309	Economy	6300.00
0005434150187	8309	Economy	6300.00
0005434266021	8309	Economy	6300.00
0005434266007	8309	Economy	6300.00
0005434150236	8309	Economy	6300.00
0005434266006	8309	Economy	6300.00
0005434265979	8309	Economy	6300.00
0005434266032	8309	Economy	6300.00
0005434266033	8309	Economy	6300.00
0005434266044	8309	Economy	6300.00
0005434266040	8309	Economy	6300.00
0005434266015	8309	Economy	6300.00
0005434265949	8309	Economy	6300.00
0005434150189	8309	Economy	6300.00
0005434266016	8309	Economy	6300.00
0005434266005	8309	Economy	6300.00
0005434266014	8309	Economy	6300.00
0005434266045	8309	Economy	6300.00
0005434150157	8309	Economy	6300.00
0005432384310	30268	Business	9900.00
0005433722502	30268	Business	9900.00
0005433722504	30268	Business	9900.00
0005434300265	30268	Business	9900.00
0005432728269	30268	Business	9900.00
0005432384255	30268	Business	9900.00
0005433722426	30268	Business	9900.00
0005435477020	30268	Business	9900.00
0005432384142	30268	Business	9900.00
0005433722466	30268	Business	9900.00
0005433722489	30268	Business	9900.00
0005433195005	30268	Economy	3300.00
0005433722492	30268	Economy	3300.00
0005434300247	30268	Economy	3300.00
0005433722479	30268	Economy	3300.00
0005432384276	30268	Economy	3300.00
0005433722445	30268	Economy	3300.00
0005432728268	30268	Economy	3300.00
0005432384137	30268	Economy	3600.00
0005433194989	30268	Economy	3600.00
0005432384277	30268	Economy	3600.00
0005435477018	30268	Economy	3600.00
0005432384156	30268	Economy	3300.00
0005433722483	30268	Economy	3300.00
0005434300237	30268	Economy	3300.00
0005432728270	30268	Economy	3300.00
0005435477016	30268	Economy	3300.00
0005432384138	30268	Economy	3300.00
0005435477019	30268	Economy	3300.00
0005433195011	30268	Economy	3300.00
0005433722480	30268	Economy	3300.00
0005432728281	30268	Economy	3300.00
0005432384218	30268	Economy	3300.00
0005435477023	30268	Economy	3300.00
0005433722490	30268	Economy	3300.00
0005433194990	30268	Economy	3300.00
0005432384119	30268	Economy	3300.00
0005432384267	30268	Economy	3300.00
0005432384216	30268	Economy	3300.00
0005433195010	30268	Economy	3300.00
0005434300250	30268	Economy	3300.00
0005433194964	30268	Economy	3300.00
0005432728313	30268	Economy	3300.00
0005432384339	30268	Economy	3300.00
0005432384245	30268	Economy	3300.00
0005432384270	30268	Economy	3300.00
0005434300254	30268	Economy	3300.00
0005433195009	30268	Economy	3300.00
0005432384155	30268	Economy	3300.00
0005432384273	30268	Economy	3300.00
0005433722431	30268	Economy	3300.00
0005434300252	30268	Economy	3300.00
0005433722464	30268	Economy	3300.00
0005433194967	30268	Economy	3300.00
0005433722494	30268	Economy	3300.00
0005434300256	30268	Economy	3300.00
0005434300269	30268	Economy	3300.00
0005432384203	30268	Economy	3300.00
0005433722465	30268	Economy	3300.00
0005433195006	30268	Economy	3300.00
0005433194965	30268	Economy	3300.00
0005432384244	30268	Economy	3300.00
0005434300251	30268	Economy	3300.00
0005433722478	30268	Economy	3300.00
0005434300257	30268	Economy	3300.00
0005432384312	30268	Economy	3300.00
0005435477017	30268	Economy	3300.00
0005434300255	30268	Economy	3300.00
0005433722493	30268	Economy	3300.00
0005434300248	30268	Economy	3300.00
0005433195008	30268	Economy	3300.00
0005432384217	30268	Economy	3300.00
0005433722454	30268	Economy	3300.00
0005433722446	30268	Economy	3300.00
0005432384272	30268	Economy	3300.00
0005435518424	22005	Economy	19100.00
0005435546228	22005	Economy	19100.00
0005435541626	22005	Economy	19100.00
0005435518382	22005	Economy	19100.00
0005435541579	22005	Economy	19100.00
0005433517142	22005	Economy	19100.00
0005435518422	22005	Economy	19100.00
0005435541580	22005	Economy	19100.00
0005435491508	7378	Business	18500.00
0005435253222	7378	Business	18500.00
0005434665023	7378	Economy	6200.00
0005435491509	7378	Economy	6200.00
0005435253219	7378	Economy	6200.00
0005435253221	7378	Economy	6200.00
0005434459421	28899	Business	18500.00
0005432839846	28899	Economy	6800.00
0005432839844	28899	Economy	6800.00
0005434459406	28899	Economy	6200.00
0005434459422	28899	Economy	6200.00
0005434459367	28899	Economy	6200.00
0005434459404	28899	Economy	6200.00
0005434459375	28899	Economy	6200.00
0005434459400	28899	Economy	6200.00
0005432839940	28899	Economy	6200.00
0005434459366	28899	Economy	6200.00
0005432839845	28899	Economy	6200.00
0005432839939	28899	Economy	6200.00
0005432839918	28899	Economy	6200.00
0005434459407	28899	Economy	6200.00
0005433435522	8785	Economy	48400.00
0005433435511	8785	Economy	48400.00
0005433435514	8785	Economy	48400.00
0005435990824	15740	Business	145300.00
0005435987064	15740	Economy	48400.00
0005435990826	15740	Economy	48400.00
0005435990827	15740	Economy	48400.00
0005433476953	20639	Economy	14500.00
0005433476954	20639	Economy	14500.00
0005433476952	20639	Economy	14500.00
0005432427209	30849	Economy	14500.00
0005435177859	6370	Business	36600.00
0005435177867	6370	Economy	12200.00
0005435490335	6370	Economy	12200.00
0005435177866	6370	Economy	12200.00
0005434150064	6370	Economy	12200.00
0005435723102	6370	Economy	12200.00
0005434150063	6370	Economy	12200.00
0005434150065	6370	Economy	12200.00
0005432361754	21004	Economy	12200.00
0005432361766	21004	Economy	12200.00
0005432361762	21004	Economy	12200.00
0005432361761	21004	Economy	12200.00
0005432336381	21004	Economy	12200.00
0005432361671	21004	Economy	12200.00
0005432361632	21004	Economy	12200.00
0005432361730	21004	Economy	12200.00
0005432361741	21004	Economy	12200.00
0005432361633	21004	Economy	12200.00
0005432361728	21004	Economy	12200.00
0005432361752	21004	Economy	12200.00
0005432361765	21004	Economy	12200.00
0005432361753	21004	Economy	12200.00
0005434459415	17737	Economy	3100.00
0005434459409	17737	Economy	3100.00
0005434461705	17737	Economy	3100.00
0005434459405	17737	Economy	3100.00
0005434459410	17737	Economy	3100.00
0005434463996	17737	Economy	3100.00
0005432605486	31686	Economy	7300.00
0005432605467	31686	Economy	7300.00
0005432605422	31686	Economy	6600.00
0005432605495	31686	Economy	6600.00
0005432605468	31686	Economy	6600.00
0005432605413	31686	Economy	6600.00
0005432605451	31686	Economy	6600.00
0005432605491	31686	Economy	6600.00
0005432605484	31686	Economy	6600.00
0005432605482	31686	Economy	6600.00
0005432605510	31686	Economy	6600.00
0005432605511	31686	Economy	6600.00
0005432605505	31686	Economy	6600.00
0005432605512	31686	Economy	6600.00
0005432605481	31686	Economy	6600.00
0005432605347	31686	Economy	6600.00
0005433293435	12294	Economy	17800.00
0005433293407	12294	Economy	17800.00
0005433293426	12294	Economy	17800.00
0005433293436	12294	Economy	17800.00
0005433293419	12294	Economy	17800.00
0005433293442	12294	Economy	17800.00
0005434606938	18822	Economy	6600.00
0005434603027	18822	Economy	6600.00
0005434603026	18822	Economy	6600.00
0005435904911	22385	Economy	6600.00
0005435904912	22385	Economy	6600.00
0005432891545	410	Business	44500.00
0005433875428	410	Business	44500.00
0005434151810	410	Business	44500.00
0005434151817	410	Economy	16300.00
0005432891546	410	Economy	14800.00
0005433875427	410	Economy	14800.00
0005433293441	410	Economy	14800.00
0005433875429	410	Economy	14800.00
0005433293438	410	Economy	14800.00
0005432891558	410	Economy	14800.00
0005434152867	410	Economy	14800.00
0005432891554	410	Economy	14800.00
0005432891547	410	Economy	14800.00
0005433293437	410	Economy	14800.00
0005434151816	410	Economy	14800.00
0005433293440	410	Economy	14800.00
0005432748670	12051	Business	44500.00
0005435154696	12051	Business	44500.00
0005432748669	12051	Business	44500.00
0005432748664	12051	Business	44500.00
0005435154685	12051	Economy	14800.00
0005435154671	12051	Economy	16300.00
0005435154688	12051	Economy	16300.00
0005435154703	12051	Economy	16300.00
0005432748679	12051	Economy	14800.00
0005435154681	12051	Economy	14800.00
0005435154698	12051	Economy	14800.00
0005435154674	12051	Economy	14800.00
0005435154707	12051	Economy	14800.00
0005435154684	12051	Economy	14800.00
0005432748671	12051	Economy	14800.00
0005435154687	12051	Economy	14800.00
0005435154682	12051	Economy	14800.00
0005432748684	12051	Economy	14800.00
0005432748598	12051	Economy	14800.00
0005432748651	12051	Economy	14800.00
0005435154699	12051	Economy	14800.00
0005435154686	12051	Economy	14800.00
0005435154672	12051	Economy	14800.00
0005435154680	12051	Economy	14800.00
0005435154661	12051	Economy	14800.00
0005432748672	12051	Economy	14800.00
0005435154683	12051	Economy	14800.00
0005432748645	12051	Economy	14800.00
0005432748680	12051	Economy	14800.00
0005433527366	32495	Economy	25700.00
0005433527352	32495	Economy	25700.00
0005433527351	32495	Economy	25700.00
0005433531404	32495	Economy	25700.00
0005435299913	5253	Business	84000.00
0005435375166	5253	Business	84000.00
0005435662006	5253	Business	84000.00
0005435375077	5253	Business	84000.00
0005435375139	5253	Comfort	47600.00
0005435315130	5253	Comfort	47600.00
0005435375165	5253	Comfort	47600.00
0005435735277	5253	Comfort	47600.00
0005435315100	5253	Comfort	47600.00
0005435374957	5253	Comfort	47600.00
0005435315102	5253	Economy	28000.00
0005435735274	5253	Economy	28000.00
0005435375138	5253	Economy	28000.00
0005435735278	5253	Economy	28000.00
0005435374977	5253	Economy	28000.00
0005435315133	5253	Economy	28000.00
0005435375013	5253	Economy	28000.00
0005435735276	5253	Economy	28000.00
0005435374968	5253	Economy	28000.00
0005435662003	5253	Economy	28000.00
0005435315137	5253	Economy	28000.00
0005435375076	5253	Economy	28000.00
0005435315136	5253	Economy	28000.00
0005435315131	5253	Economy	30800.00
0005435375066	5253	Economy	28000.00
0005435315101	5253	Economy	28000.00
0005435315138	5253	Economy	28000.00
0005435375167	5253	Economy	28000.00
0005435374958	5253	Economy	28000.00
0005435735275	5253	Economy	28000.00
0005435315132	5253	Economy	28000.00
0005434827262	9887	Business	84000.00
0005434558597	9887	Business	84000.00
0005434827194	9887	Business	84000.00
0005434827290	9887	Business	84000.00
0005435150410	9887	Business	84000.00
0005434558523	9887	Comfort	47600.00
0005434827191	9887	Comfort	47600.00
0005434827280	9887	Comfort	47600.00
0005434558543	9887	Comfort	47600.00
0005434827213	9887	Economy	28000.00
0005434827289	9887	Economy	28000.00
0005434827222	9887	Economy	28000.00
0005434827279	9887	Economy	28000.00
0005434827182	9887	Economy	28000.00
0005434827190	9887	Economy	28000.00
0005434827202	9887	Economy	28000.00
0005434827201	9887	Economy	28000.00
0005434827214	9887	Economy	28000.00
0005434827130	9887	Economy	28000.00
0005434827065	9887	Economy	28000.00
0005434827261	9887	Economy	28000.00
0005434827236	9887	Economy	28000.00
0005434558515	9887	Economy	28000.00
0005434558584	9887	Economy	28000.00
0005434558605	9887	Economy	28000.00
0005434827257	9887	Economy	28000.00
0005435150416	9887	Economy	28000.00
0005434558557	9887	Economy	28000.00
0005434558608	9887	Economy	28000.00
0005434827256	9887	Economy	28000.00
0005434558545	9887	Economy	28000.00
0005434827192	9887	Economy	28000.00
0005434558604	9887	Economy	28000.00
0005434827244	9887	Economy	28000.00
0005434827238	9887	Economy	28000.00
0005434827245	9887	Economy	28000.00
0005434665026	9887	Economy	28000.00
0005434826994	9887	Economy	28000.00
0005434558558	9887	Economy	28000.00
0005434827132	9887	Economy	28000.00
0005434558500	9887	Economy	28000.00
0005435150418	9887	Economy	28000.00
0005434827243	9887	Economy	28000.00
0005434558577	9887	Economy	28000.00
0005434826995	9887	Economy	28000.00
0005435083024	25984	Economy	7400.00
0005435083034	25984	Economy	7400.00
0005435790390	25984	Economy	7400.00
0005434215873	9571	Business	32800.00
0005434215872	9571	Business	32800.00
0005434215775	9571	Business	32800.00
0005434215819	9571	Business	32800.00
0005434215801	9571	Economy	10900.00
0005434215856	9571	Economy	10900.00
0005434215702	9571	Economy	10900.00
0005434215784	9571	Economy	12000.00
0005434215792	9571	Economy	10900.00
0005434215881	9571	Economy	10900.00
0005434215815	9571	Economy	10900.00
0005434215814	9571	Economy	10900.00
0005434215898	9571	Economy	10900.00
0005434215899	9571	Economy	10900.00
0005434215794	9571	Economy	10900.00
0005434215893	9571	Economy	10900.00
0005434215738	9571	Economy	10900.00
0005434215846	9571	Economy	10900.00
0005434215809	9571	Economy	10900.00
0005434215791	9571	Economy	10900.00
0005434757593	28619	Business	32800.00
0005434757655	28619	Business	32800.00
0005434757682	28619	Business	32800.00
0005434757669	28619	Business	32800.00
0005434757650	28619	Economy	10900.00
0005434757649	28619	Economy	10900.00
0005434757633	28619	Economy	10900.00
0005434757630	28619	Economy	10900.00
0005434757602	28619	Economy	10900.00
0005434757636	28619	Economy	10900.00
0005434757681	28619	Economy	10900.00
0005434757615	28619	Economy	10900.00
0005434757478	28619	Economy	10900.00
0005434757674	28619	Economy	10900.00
0005434757603	28619	Economy	10900.00
0005434757406	28619	Economy	10900.00
0005434757490	28619	Economy	10900.00
0005434757668	28619	Economy	10900.00
0005434757629	28619	Economy	10900.00
0005434757592	28619	Economy	10900.00
0005434757514	28619	Economy	10900.00
0005434757618	28619	Economy	10900.00
0005434757386	28619	Economy	10900.00
0005434757604	28619	Economy	10900.00
0005434757651	28619	Economy	10900.00
0005434757654	28619	Economy	10900.00
0005434757578	28619	Economy	10900.00
0005434757387	28619	Economy	10900.00
0005434757405	28619	Economy	10900.00
0005435100208	31793	Economy	9800.00
0005435100211	31793	Economy	8900.00
0005435100210	31793	Economy	8900.00
0005433202792	1989	Economy	19000.00
0005433202791	1989	Economy	19000.00
0005433202773	1989	Economy	19000.00
0005433202762	1989	Economy	19000.00
0005434640108	23253	Economy	20900.00
0005434640055	23253	Economy	19000.00
0005434639977	23253	Economy	19000.00
0005434640095	23253	Economy	19000.00
0005434640086	23253	Economy	19000.00
0005434640107	23253	Economy	19000.00
0005434640101	23253	Economy	19000.00
0005434640089	23253	Economy	19000.00
0005434639976	23253	Economy	19000.00
0005434640085	23253	Economy	19000.00
0005434640100	23253	Economy	19000.00
0005434640007	23253	Economy	19000.00
0005434640054	23253	Economy	19000.00
0005434640094	23253	Economy	19000.00
0005434640104	23253	Economy	19000.00
0005435327134	6076	Economy	23200.00
0005434601594	18605	Business	69700.00
0005434601569	18605	Economy	23200.00
0005434601549	18605	Economy	23200.00
0005434601575	18605	Economy	23200.00
0005434601593	18605	Economy	23200.00
0005434601580	18605	Economy	23200.00
0005434601588	18605	Economy	23200.00
0005433527375	18605	Economy	23200.00
0005434601587	18605	Economy	23200.00
0005435315112	10627	Business	9100.00
0005435315140	10627	Economy	3000.00
0005433181766	10627	Economy	3000.00
0005435315141	10627	Economy	3000.00
0005434757711	10627	Economy	3000.00
0005435315142	10627	Economy	3000.00
0005435315087	10627	Economy	3000.00
0005435315111	10627	Economy	3000.00
0005435315127	10627	Economy	3000.00
0005435315143	10627	Economy	3000.00
0005435315124	10627	Economy	3000.00
0005433181750	10627	Economy	3000.00
0005433181806	10627	Economy	3000.00
0005433181807	10627	Economy	3000.00
0005433181826	10627	Economy	3000.00
0005435315126	10627	Economy	3000.00
0005435315123	10627	Economy	3000.00
0005433181827	10627	Economy	3000.00
0005434552864	27675	Business	9100.00
0005434552863	27675	Business	9100.00
0005434552738	27675	Economy	3000.00
0005434558602	27675	Economy	3000.00
0005434552736	27675	Economy	3300.00
0005434552667	27675	Economy	3000.00
0005434552850	27675	Economy	3000.00
0005434558587	27675	Economy	3000.00
0005434558594	27675	Economy	3000.00
0005434552721	27675	Economy	3000.00
0005434552849	27675	Economy	3000.00
0005434552841	27675	Economy	3000.00
0005434552803	27675	Economy	3000.00
0005434554122	27675	Economy	3000.00
0005434552848	27675	Economy	3000.00
0005434558568	27675	Economy	3000.00
0005434552758	27675	Economy	3000.00
0005434552865	27675	Economy	3000.00
0005434552833	27675	Economy	3000.00
0005434552769	27675	Economy	3000.00
0005434552851	27675	Economy	3000.00
0005434554123	27675	Economy	3000.00
0005434558569	27675	Economy	3000.00
0005434552757	27675	Economy	3000.00
0005434552737	27675	Economy	3000.00
0005434558579	27675	Economy	3000.00
0005435438580	6734	Economy	17000.00
0005435438585	6734	Economy	17000.00
0005435438579	6734	Economy	17000.00
0005435662013	24587	Business	51100.00
0005435631049	24587	Business	51100.00
0005435631052	24587	Economy	17000.00
0005435662014	24587	Economy	17000.00
0005435683272	24587	Economy	18700.00
0005435683287	24587	Economy	17000.00
0005435631048	24587	Economy	17000.00
0005435654523	24587	Economy	17000.00
0005435683286	24587	Economy	17000.00
0005435631051	24587	Economy	17000.00
0005435683308	24587	Economy	17000.00
0005435127568	31864	Business	26400.00
0005435127514	31864	Business	26400.00
0005435127580	31864	Economy	8800.00
0005435127487	31864	Economy	8800.00
0005435127513	31864	Economy	8800.00
0005435127575	31864	Economy	8800.00
0005435127543	31864	Economy	8800.00
0005435127544	31864	Economy	8800.00
0005435127564	31864	Economy	8800.00
0005435127552	31864	Economy	8800.00
0005435127542	31864	Economy	8800.00
0005435127587	31864	Economy	8800.00
0005435127576	31864	Economy	8800.00
0005435127581	31864	Economy	8800.00
0005435732722	13560	Economy	12200.00
0005435732720	13560	Economy	12200.00
0005435732721	13560	Economy	12200.00
0005435732695	13560	Economy	12200.00
0005435732713	13560	Economy	12200.00
0005435732696	13560	Economy	12200.00
0005435732712	13560	Economy	12200.00
0005435732719	13560	Economy	12200.00
0005433399426	19426	Business	36600.00
0005433399445	19426	Economy	13400.00
0005433399416	19426	Economy	13400.00
0005433399395	19426	Economy	13400.00
0005433399451	19426	Economy	12200.00
0005433399430	19426	Economy	12200.00
0005433399434	19426	Economy	12200.00
0005433399435	19426	Economy	12200.00
0005433399419	19426	Economy	12200.00
0005433399431	19426	Economy	12200.00
0005433399444	19426	Economy	12200.00
0005433399373	19426	Economy	12200.00
0005435070508	13182	Business	11300.00
0005435070518	13182	Economy	3800.00
0005435070561	13182	Economy	3800.00
0005435070455	13182	Economy	4100.00
0005435070457	13182	Economy	4100.00
0005435070565	13182	Economy	3800.00
0005435070524	13182	Economy	3800.00
0005435070456	13182	Economy	3800.00
0005435070564	13182	Economy	3800.00
0005435070452	13182	Economy	3800.00
0005435070535	13182	Economy	3800.00
0005435070419	13182	Economy	3800.00
0005435070543	13182	Economy	3800.00
0005435070566	13182	Economy	3800.00
0005435070546	13182	Economy	3800.00
0005435925700	15494	Economy	3800.00
0005435925702	15494	Economy	3800.00
0005435925663	15494	Economy	3800.00
0005435925662	15494	Economy	3800.00
0005435925704	15494	Economy	3800.00
0005435925661	15494	Economy	3800.00
0005433407695	23193	Economy	24700.00
0005433407690	23193	Economy	24700.00
0005433407696	23193	Economy	24700.00
0005433407710	23193	Economy	24700.00
0005433407711	23193	Economy	24700.00
0005434757622	10705	Business	61300.00
0005434757666	10705	Economy	20400.00
0005434757621	10705	Economy	20400.00
0005434757516	10705	Economy	22500.00
0005434757515	10705	Economy	22500.00
0005434757632	10705	Economy	22500.00
0005434757631	10705	Economy	20400.00
0005434757687	10705	Economy	20400.00
0005434757575	10705	Economy	20400.00
0005434757574	10705	Economy	20400.00
0005434757612	10705	Economy	20400.00
0005434757580	10705	Economy	20400.00
0005434757688	10705	Economy	20400.00
0005434757623	10705	Economy	20400.00
0005434757675	10705	Economy	20400.00
0005434757613	10705	Economy	20400.00
0005434215785	28679	Business	61300.00
0005434215874	28679	Business	61300.00
0005434215871	28679	Business	61300.00
0005434215813	28679	Business	61300.00
0005434215867	28679	Economy	20400.00
0005434215868	28679	Economy	20400.00
0005434215862	28679	Economy	20400.00
0005434215854	28679	Economy	22500.00
0005434215904	28679	Economy	20400.00
0005434215834	28679	Economy	20400.00
0005434215903	28679	Economy	20400.00
0005434215843	28679	Economy	20400.00
0005434215875	28679	Economy	20400.00
0005434215859	28679	Economy	20400.00
0005434215861	28679	Economy	20400.00
0005434215878	28679	Economy	20400.00
0005434215853	28679	Economy	20400.00
0005434215864	28679	Economy	20400.00
0005434215786	28679	Economy	20400.00
0005434215774	28679	Economy	20400.00
0005434215845	28679	Economy	20400.00
0005434215855	28679	Economy	20400.00
0005434215860	28679	Economy	20400.00
0005434215844	28679	Economy	20400.00
0005434215835	28679	Economy	20400.00
0005434215863	28679	Economy	20400.00
0005434215820	28679	Economy	20400.00
0005434215847	28679	Economy	20400.00
0005434215773	28679	Economy	20400.00
0005434215892	28679	Economy	20400.00
0005434215831	28679	Economy	20400.00
0005434230017	5429	Economy	9800.00
0005435042934	12957	Business	29500.00
0005435041531	12957	Business	29500.00
0005435041651	12957	Business	29500.00
0005435041543	12957	Business	29500.00
0005435041661	12957	Economy	9800.00
0005435041629	12957	Economy	9800.00
0005435041562	12957	Economy	9800.00
0005435041688	12957	Economy	9800.00
0005435007710	12957	Economy	9800.00
0005435041676	12957	Economy	9800.00
0005435041532	12957	Economy	9800.00
0005435041682	12957	Economy	9800.00
0005435041530	12957	Economy	9800.00
0005435041579	12957	Economy	9800.00
0005435007711	12957	Economy	9800.00
0005435041528	12957	Economy	9800.00
0005435041524	12957	Economy	9800.00
0005435007709	12957	Economy	9800.00
0005435042935	12957	Economy	9800.00
0005435007699	12957	Economy	9800.00
0005435007712	12957	Economy	9800.00
0005435041660	12957	Economy	9800.00
0005435041626	12957	Economy	9800.00
0005435041656	12957	Economy	9800.00
0005435041640	12957	Economy	9800.00
0005435041677	12957	Economy	9800.00
0005435041487	12957	Economy	9800.00
0005435041681	12957	Economy	9800.00
0005435041697	12957	Economy	9800.00
0005435041701	12957	Economy	9800.00
0005435007689	12957	Economy	9800.00
0005435554326	14870	Economy	17600.00
0005435554327	14870	Economy	17600.00
0005435903218	14870	Economy	17600.00
0005434427461	20214	Business	52900.00
0005434427460	20214	Economy	17600.00
0005434427451	20214	Economy	17600.00
0005434427402	20214	Economy	17600.00
0005434427440	20214	Economy	17600.00
0005434427435	20214	Economy	17600.00
0005433726168	21657	Economy	30600.00
0005433726144	21657	Economy	30600.00
0005433726151	21657	Economy	30600.00
0005433726143	21657	Economy	30600.00
0005433726150	21657	Economy	30600.00
0005433726169	21657	Economy	30600.00
0005433726164	21657	Economy	30600.00
0005433726170	21657	Economy	30600.00
0005433726165	21657	Economy	30600.00
0005433435497	26519	Business	18500.00
0005433435452	26519	Business	18500.00
0005433435468	26519	Business	18500.00
0005433435495	26519	Business	18500.00
0005433435496	26519	Economy	6800.00
0005433435506	26519	Economy	6200.00
0005433435488	26519	Economy	6200.00
0005433435507	26519	Economy	6200.00
0005433435498	26519	Economy	6200.00
0005433435458	26519	Economy	6200.00
0005435983615	26711	Business	18500.00
0005435983439	26711	Economy	6200.00
0005435983612	26711	Economy	6200.00
0005435983438	26711	Economy	6200.00
0005435983554	26711	Economy	6200.00
0005435983581	26711	Economy	6200.00
0005435983655	26711	Economy	6800.00
0005435983611	26711	Economy	6200.00
0005435983634	26711	Economy	6200.00
0005435983625	26711	Economy	6200.00
0005435983661	26711	Economy	6200.00
0005435983624	26711	Economy	6200.00
0005435983604	26711	Economy	6200.00
0005435983606	26711	Economy	6200.00
0005435983453	26711	Economy	6200.00
0005435983654	26711	Economy	6200.00
0005435983495	26711	Economy	6200.00
0005435983582	26711	Economy	6200.00
0005435983494	26711	Economy	6200.00
0005432858399	3172	Economy	10100.00
0005432858405	3172	Economy	10100.00
0005432858400	3172	Economy	10100.00
0005432584713	31517	Economy	10100.00
0005432584781	31517	Economy	10100.00
0005432584780	31517	Economy	10100.00
0005433255270	876	Economy	7500.00
0005433255264	876	Economy	7500.00
0005433811682	14446	Economy	4400.00
0005433811680	14446	Economy	4400.00
0005433811681	14446	Economy	4400.00
0005433811691	14446	Economy	4400.00
0005435790418	21728	Economy	3300.00
0005433368942	21728	Economy	3300.00
0005433368952	21728	Economy	3300.00
0005433368906	21728	Economy	3300.00
0005433368975	21728	Economy	3300.00
0005433368898	21728	Economy	3300.00
0005433368965	21728	Economy	3300.00
0005433368953	21728	Economy	3300.00
0005433368920	21728	Economy	3300.00
0005435790416	21728	Economy	3300.00
0005433368935	21728	Economy	3300.00
0005433368866	21728	Economy	3300.00
0005433368936	21728	Economy	3300.00
0005435270221	9368	Business	186200.00
0005435270132	9368	Business	186200.00
0005435270171	9368	Business	186200.00
0005435858743	9368	Business	186200.00
0005435270102	9368	Business	186200.00
0005435270197	9368	Economy	62100.00
0005435270152	9368	Economy	62100.00
0005435270176	9368	Economy	62100.00
0005435270217	9368	Economy	62100.00
0005435270198	9368	Economy	62100.00
0005435270186	9368	Economy	62100.00
0005435270220	9368	Economy	62100.00
0005435270151	9368	Economy	62100.00
0005435270103	9368	Economy	62100.00
0005435270170	9368	Economy	62100.00
0005435270218	9368	Economy	62100.00
0005435270129	9368	Economy	62100.00
0005435270175	9368	Economy	62100.00
0005434151796	9368	Economy	62100.00
0005435270110	9368	Economy	62100.00
0005435270131	9368	Economy	62100.00
0005433806390	26247	Business	186200.00
0005433786185	26247	Business	186200.00
0005433786156	26247	Economy	68300.00
0005433786002	26247	Economy	62100.00
0005433786091	26247	Economy	62100.00
0005433786129	26247	Economy	62100.00
0005433786155	26247	Economy	62100.00
0005433786050	26247	Economy	62100.00
0005433806402	26247	Economy	62100.00
0005433786130	26247	Economy	62100.00
0005433806391	26247	Economy	62100.00
0005433786191	26247	Economy	62100.00
0005433763613	26247	Economy	62100.00
0005433786096	26247	Economy	62100.00
0005433763612	26247	Economy	62100.00
0005433786157	26247	Economy	62100.00
0005433806396	26247	Economy	62100.00
0005433806335	26247	Economy	68300.00
0005433786187	26247	Economy	62100.00
0005432666449	26247	Economy	68300.00
0005433806403	26247	Economy	62100.00
0005433786146	26247	Economy	62100.00
0005433786189	26247	Economy	62100.00
0005432666447	26247	Economy	62100.00
0005433786114	26247	Economy	62100.00
0005433786051	26247	Economy	62100.00
0005433763600	26247	Economy	62100.00
0005433786090	26247	Economy	62100.00
0005432666448	26247	Economy	62100.00
0005433786133	26247	Economy	62100.00
0005433786136	26247	Economy	62100.00
0005433786013	26247	Economy	62100.00
0005433786113	26247	Economy	62100.00
0005433786132	26247	Economy	62100.00
0005433806378	26247	Economy	62100.00
0005433786004	26247	Economy	62100.00
0005433806392	26247	Economy	62100.00
0005433786131	26247	Economy	62100.00
0005435135808	33024	Economy	5300.00
0005435135809	33024	Economy	5300.00
0005433962545	24284	Business	36400.00
0005433962654	24284	Business	36400.00
0005433962388	24284	Business	36400.00
0005433962611	24284	Business	36400.00
0005433962445	24284	Business	36400.00
0005433962495	24284	Economy	13400.00
0005433987322	24284	Economy	12100.00
0005433962275	24284	Economy	12100.00
0005433962726	24284	Economy	12100.00
0005433962538	24284	Economy	12100.00
0005433962689	24284	Economy	12100.00
0005433962674	24284	Economy	12100.00
0005433962757	24284	Economy	12100.00
0005433962698	24284	Economy	12100.00
0005433987327	24284	Economy	12100.00
0005433962762	24284	Economy	12100.00
0005433962742	24284	Economy	12100.00
0005433962680	24284	Economy	12100.00
0005433962539	24284	Economy	12100.00
0005433962630	24284	Economy	12100.00
0005433987370	24284	Economy	12100.00
0005433987314	24284	Economy	12100.00
0005433962444	24284	Economy	12100.00
0005433987313	24284	Economy	12100.00
0005433987141	24284	Economy	12100.00
0005433962518	24284	Economy	12100.00
0005433987254	24284	Economy	12100.00
0005433987193	24284	Economy	12100.00
0005433962515	24284	Economy	12100.00
0005433987369	24284	Economy	12100.00
0005433962371	24284	Economy	12100.00
0005433962621	24284	Economy	12100.00
0005433962501	24284	Economy	12100.00
0005433962452	24284	Economy	13400.00
0005433962540	24284	Economy	13400.00
0005433962330	24284	Economy	12100.00
0005433962741	24284	Economy	12100.00
0005433962724	24284	Economy	12100.00
0005433962593	24284	Economy	12100.00
0005433962494	24284	Economy	12100.00
0005433962369	24284	Economy	12100.00
0005433962706	24284	Economy	12100.00
0005433962329	24284	Economy	12100.00
0005433962370	24284	Economy	12100.00
0005433962453	24284	Economy	12100.00
0005433962667	24284	Economy	12100.00
0005433987312	24284	Economy	12100.00
0005433962580	24284	Economy	12100.00
0005433962514	24284	Economy	12100.00
0005433962194	24284	Economy	12100.00
0005433987374	24284	Economy	12100.00
0005433987334	24284	Economy	12100.00
0005433962603	24284	Economy	12100.00
0005433962520	24284	Economy	12100.00
0005433987321	24284	Economy	12100.00
0005433962512	24284	Economy	12100.00
0005433962662	24284	Economy	12100.00
0005433962723	24284	Economy	12100.00
0005433962716	24284	Economy	12100.00
0005433987260	24284	Economy	12100.00
0005433962725	24284	Economy	12100.00
0005433987215	24284	Economy	12100.00
0005433987311	24284	Economy	12100.00
0005433962660	24284	Economy	12100.00
0005434908904	25945	Economy	12100.00
0005435860635	25945	Economy	12100.00
0005435860636	25945	Economy	12100.00
0005433166244	963	Economy	25400.00
0005433166276	963	Economy	23100.00
0005434480987	16578	Economy	25400.00
0005434481040	16578	Economy	23100.00
0005434480988	16578	Economy	23100.00
0005434481035	16578	Economy	23100.00
0005434481045	16578	Economy	23100.00
0005434481042	16578	Economy	23100.00
0005434481036	16578	Economy	23100.00
0005434481043	16578	Economy	23100.00
0005434480986	16578	Economy	23100.00
0005434481037	16578	Economy	23100.00
0005435386751	10348	Economy	15400.00
0005433290065	10348	Economy	15400.00
0005435386742	10348	Economy	15400.00
0005435386750	10348	Economy	15400.00
0005435142941	21967	Economy	15400.00
0005435142953	21967	Economy	15400.00
0005435142952	21967	Economy	15400.00
0005435142969	21967	Economy	15400.00
0005435142954	21967	Economy	15400.00
0005435150418	21967	Economy	15400.00
0005435142942	21967	Economy	15400.00
0005435142955	21967	Economy	15400.00
0005435150416	21967	Economy	15400.00
0005435142958	21967	Economy	15400.00
0005435150410	21967	Economy	15400.00
0005435529859	11197	Business	57200.00
0005435319805	11197	Business	57200.00
0005435545969	11197	Business	57200.00
0005435529893	11197	Business	57200.00
0005435529890	11197	Business	57200.00
0005435529892	11197	Business	57200.00
0005435319804	11197	Economy	19100.00
0005435545953	11197	Economy	19100.00
0005435529891	11197	Economy	19100.00
0005435502962	11197	Economy	21000.00
0005435529888	11197	Economy	21000.00
0005435529851	11197	Economy	21000.00
0005435529861	11197	Economy	19100.00
0005435529860	11197	Economy	19100.00
0005435502912	11197	Economy	19100.00
0005435545958	11197	Economy	19100.00
0005435545962	11197	Economy	19100.00
0005435529862	11197	Economy	19100.00
0005435545970	11197	Economy	19100.00
0005435545952	11197	Economy	19100.00
0005435529896	11197	Economy	19100.00
0005435529880	11197	Economy	19100.00
0005435502929	11197	Economy	19100.00
0005435545971	11197	Economy	19100.00
0005435502961	11197	Economy	19100.00
0005435529889	11197	Economy	19100.00
0005435319828	11197	Economy	19100.00
0005435545961	11197	Economy	19100.00
0005435545967	11197	Economy	19100.00
0005435502943	11197	Economy	19100.00
0005435529897	11197	Economy	19100.00
0005434573764	20919	Business	57200.00
0005434573763	20919	Economy	19100.00
0005434573762	20919	Economy	19100.00
0005434573765	20919	Economy	19100.00
0005434573757	20919	Economy	19100.00
0005432693969	3064	Economy	3400.00
0005432693882	3064	Economy	3800.00
0005432693957	3064	Economy	3400.00
0005432693949	3064	Economy	3400.00
0005432693937	3064	Economy	3400.00
0005432693924	3064	Economy	3400.00
0005432693950	3064	Economy	3400.00
0005432693958	3064	Economy	3400.00
0005432693940	3064	Economy	3400.00
0005432693968	3064	Economy	3400.00
0005433124459	3055	Business	10300.00
0005433124541	3055	Economy	3400.00
0005433194985	3055	Economy	3400.00
0005433124453	3055	Economy	3800.00
0005433194952	3055	Economy	3400.00
0005432881227	3055	Economy	3400.00
0005432881218	3055	Economy	3400.00
0005433124497	3055	Economy	3400.00
0005433124509	3055	Economy	3400.00
0005433194983	3055	Economy	3400.00
0005433124454	3055	Economy	3400.00
0005433194975	3055	Economy	3400.00
0005432881237	3055	Economy	3400.00
0005433194953	3055	Economy	3400.00
0005433194995	3055	Economy	3400.00
0005433194994	3055	Economy	3400.00
0005433124488	3055	Economy	3400.00
0005433124542	3055	Economy	3400.00
0005432881228	3055	Economy	3400.00
0005434300266	3055	Economy	3400.00
0005434300267	3055	Economy	3400.00
0005433195004	3055	Economy	3400.00
0005433194984	3055	Economy	3400.00
0005432707484	30049	Business	10300.00
0005434310155	30049	Economy	3400.00
0005432707479	30049	Economy	3400.00
0005432707478	30049	Economy	3400.00
0005434310180	30049	Economy	3400.00
0005432707507	30049	Economy	3400.00
0005432707499	30049	Economy	3400.00
0005434980584	27541	Economy	4000.00
0005434980671	27541	Economy	4000.00
0005434980638	27541	Economy	3600.00
0005434980617	27541	Economy	3600.00
0005434989084	27541	Economy	3600.00
0005434980626	27541	Economy	3600.00
0005434989079	27541	Economy	3600.00
0005434989072	27541	Economy	3600.00
0005434989082	27541	Economy	3600.00
0005434980608	27541	Economy	3600.00
0005434989083	27541	Economy	3600.00
0005434980609	27541	Economy	3600.00
0005434989114	27541	Economy	3600.00
0005434989105	27541	Economy	3600.00
0005434980672	27541	Economy	3600.00
0005434980542	27541	Economy	3600.00
0005433113598	10252	Economy	19700.00
0005434302575	19585	Economy	19700.00
0005434302576	19585	Economy	19700.00
0005435925679	3543	Business	26900.00
0005435925720	3543	Economy	9000.00
0005435925714	3543	Economy	9000.00
0005435939936	3543	Economy	9000.00
0005435925715	3543	Economy	9000.00
0005435925701	3543	Economy	9000.00
0005435939969	3543	Economy	9000.00
0005435939952	3543	Economy	9000.00
0005435939970	3543	Economy	9000.00
0005435925708	3543	Economy	9000.00
0005435070535	15306	Business	26900.00
0005435070564	15306	Business	26900.00
0005435070543	15306	Business	26900.00
0005435070546	15306	Economy	9000.00
0005435950341	15306	Economy	9000.00
0005435070508	15306	Economy	9900.00
0005435950342	15306	Economy	9900.00
0005435070452	15306	Economy	9000.00
0005435070455	15306	Economy	9000.00
0005435070419	15306	Economy	9000.00
0005435070524	15306	Economy	9000.00
0005435070561	15306	Economy	9000.00
0005435070518	15306	Economy	9000.00
0005435070565	15306	Economy	9000.00
0005435070456	15306	Economy	9000.00
0005435070566	15306	Economy	9000.00
0005435070457	15306	Economy	9000.00
0005432660881	26439	Economy	5900.00
0005432660882	26439	Economy	5900.00
0005433103723	178	Business	20000.00
0005432920481	178	Business	20000.00
0005433103677	178	Business	20000.00
0005433103953	178	Business	20000.00
0005433103888	178	Business	20000.00
0005433103978	178	Business	20000.00
0005433103805	178	Business	20000.00
0005433103995	178	Business	20000.00
0005432902086	178	Business	20000.00
0005433103994	178	Business	20000.00
0005433103999	178	Business	20000.00
0005433103905	178	Economy	7300.00
0005433103851	178	Economy	7300.00
0005432902104	178	Economy	6700.00
0005433103889	178	Economy	6700.00
0005433103707	178	Economy	6700.00
0005433103558	178	Economy	6700.00
0005433103708	178	Economy	6700.00
0005433103998	178	Economy	6700.00
0005433103780	178	Economy	6700.00
0005433103862	178	Economy	6700.00
0005433103929	178	Economy	6700.00
0005433103660	178	Economy	6700.00
0005433103951	178	Economy	6700.00
0005432920473	178	Economy	6700.00
0005433103778	178	Economy	6700.00
0005433103734	178	Economy	6700.00
0005433103950	178	Economy	6700.00
0005433103730	178	Economy	6700.00
0005433103919	178	Economy	6700.00
0005432902103	178	Economy	6700.00
0005433103676	178	Economy	6700.00
0005433103887	178	Economy	6700.00
0005433103952	178	Economy	6700.00
0005433103860	178	Economy	6700.00
0005433103979	178	Economy	6700.00
0005433103848	178	Economy	7300.00
0005433103918	178	Economy	6700.00
0005433103861	178	Economy	6700.00
0005433103971	178	Economy	6700.00
0005433103928	178	Economy	6700.00
0005433103944	178	Economy	6700.00
0005432920318	178	Economy	6700.00
0005433103970	178	Economy	6700.00
0005433103849	178	Economy	6700.00
0005433103941	178	Economy	6700.00
0005433103806	178	Economy	6700.00
0005433103997	178	Economy	6700.00
0005433103722	178	Economy	6700.00
0005433103781	178	Economy	6700.00
0005433103945	178	Economy	6700.00
0005433103784	178	Economy	6700.00
0005433103702	178	Economy	6700.00
0005433103959	178	Economy	6700.00
0005433103882	178	Economy	6700.00
0005433929886	179	Economy	6700.00
0005434157851	8077	Business	20000.00
0005434157903	8077	Business	20000.00
0005434157968	8077	Business	20000.00
0005434157768	8077	Business	20000.00
0005434157972	8077	Business	20000.00
0005434157893	8077	Business	20000.00
0005434157859	8077	Business	20000.00
0005434157937	8077	Business	20000.00
0005434157985	8077	Business	20000.00
0005434157853	8077	Business	20000.00
0005434157983	8077	Business	20000.00
0005433477245	8077	Business	20000.00
0005434157858	8077	Business	20000.00
0005434157849	8077	Economy	7300.00
0005433477196	8077	Economy	7300.00
0005433477252	8077	Economy	7300.00
0005434157837	8077	Economy	6700.00
0005434157982	8077	Economy	6700.00
0005434157881	8077	Economy	6700.00
0005433477259	8077	Economy	6700.00
0005434157892	8077	Economy	6700.00
0005434157922	8077	Economy	6700.00
0005434157822	8077	Economy	6700.00
0005434157936	8077	Economy	6700.00
0005434157802	8077	Economy	6700.00
0005434157927	8077	Economy	6700.00
0005433477249	8077	Economy	6700.00
0005433477234	8077	Economy	6700.00
0005434157784	8077	Economy	6700.00
0005434157796	8077	Economy	6700.00
0005433477275	8077	Economy	6700.00
0005434157901	8077	Economy	6700.00
0005434157791	8077	Economy	6700.00
0005434157794	8077	Economy	6700.00
0005434157954	8077	Economy	6700.00
0005434157951	8077	Economy	6700.00
0005434157928	8077	Economy	6700.00
0005434215910	8077	Economy	6700.00
0005434157850	8077	Economy	6700.00
0005433477235	8077	Economy	6700.00
0005433477214	8077	Economy	6700.00
0005433477276	8077	Economy	7300.00
0005434157929	8077	Economy	6700.00
0005434157933	8077	Economy	6700.00
0005434157864	8077	Economy	6700.00
0005434157823	8077	Economy	6700.00
0005434157865	8077	Economy	6700.00
0005433477278	8077	Economy	6700.00
0005434157924	8077	Economy	6700.00
0005434157854	8077	Economy	6700.00
0005434175874	8077	Economy	6700.00
0005433477277	8077	Economy	6700.00
0005434157940	8077	Economy	6700.00
0005434157852	8077	Economy	6700.00
0005434175875	8077	Economy	6700.00
0005434157930	8077	Economy	6700.00
0005434157843	8077	Economy	6700.00
0005434157973	8077	Economy	6700.00
0005434175873	8077	Economy	6700.00
0005434157880	8077	Economy	6700.00
0005434157821	8077	Economy	6700.00
0005434175872	8077	Economy	6700.00
0005433477216	8077	Economy	6700.00
0005434157797	8077	Economy	6700.00
0005434157909	8077	Economy	6700.00
0005434157844	8077	Economy	6700.00
0005435987064	8077	Economy	6700.00
0005433477260	8077	Economy	6700.00
0005434157879	8077	Economy	6700.00
0005434157801	8077	Economy	6700.00
0005434157941	8077	Economy	6700.00
0005433477215	8077	Economy	6700.00
0005434157894	8077	Economy	6700.00
0005434157767	8077	Economy	6700.00
0005432818325	8074	Business	20000.00
0005432818330	8074	Business	20000.00
0005432818322	8074	Business	20000.00
0005432818282	8074	Economy	7300.00
0005432818326	8074	Economy	6700.00
0005432818335	8074	Economy	6700.00
0005432818284	8074	Economy	6700.00
0005432818241	8074	Economy	6700.00
0005432818283	8074	Economy	6700.00
0005432818313	8074	Economy	6700.00
0005432818331	8074	Economy	6700.00
0005432818291	8074	Economy	6700.00
0005432818314	8074	Economy	6700.00
0005433870790	32363	Economy	6900.00
0005435841850	3482	Business	35000.00
0005435914209	3482	Comfort	19900.00
0005435914193	3482	Comfort	19900.00
0005435914754	3482	Comfort	19900.00
0005435914183	3482	Economy	11700.00
0005435841849	3482	Economy	11700.00
0005435914755	3482	Economy	11700.00
0005435914153	3482	Economy	11700.00
0005435914205	3482	Economy	11700.00
0005435914154	3482	Economy	11700.00
0005435903219	3482	Economy	11700.00
0005435914120	3482	Economy	11700.00
0005435841848	3482	Economy	11700.00
0005435903211	3482	Economy	11700.00
0005434880911	14588	Business	35000.00
0005435626838	14588	Business	35000.00
0005435626837	14588	Business	35000.00
0005435626694	14588	Comfort	19900.00
0005435127482	14588	Comfort	19900.00
0005435626842	14588	Comfort	19900.00
0005434938714	14588	Comfort	19900.00
0005435127499	14588	Comfort	19900.00
0005434880979	14588	Comfort	19900.00
0005434938680	14588	Comfort	19900.00
0005435626799	14588	Comfort	19900.00
0005435626871	14588	Comfort	19900.00
0005435626767	14588	Economy	11700.00
0005435626843	14588	Economy	11700.00
0005435626751	14588	Economy	11700.00
0005432800271	14588	Economy	11700.00
0005432607664	14588	Economy	11700.00
0005435127577	14588	Economy	11700.00
0005435127560	14588	Economy	11700.00
0005435626861	14588	Economy	11700.00
0005435626722	14588	Economy	11700.00
0005432800270	14588	Economy	11700.00
0005432607678	14588	Economy	11700.00
0005435127571	14588	Economy	11700.00
0005434938715	14588	Economy	11700.00
0005435626782	14588	Economy	11700.00
0005435127481	14588	Economy	11700.00
0005434880972	14588	Economy	11700.00
0005435626800	14588	Economy	11700.00
0005435626727	14588	Economy	11700.00
0005435626787	14588	Economy	12800.00
0005434880912	14588	Economy	11700.00
0005435127534	14588	Economy	12800.00
0005434938699	14588	Economy	11700.00
0005435127572	14588	Economy	11700.00
0005434938707	14588	Economy	11700.00
0005434880985	14588	Economy	11700.00
0005435127582	14588	Economy	11700.00
0005434880984	14588	Economy	11700.00
0005435127468	14588	Economy	11700.00
0005435127403	14588	Economy	11700.00
0005434427435	14588	Economy	11700.00
0005434427461	14588	Economy	11700.00
0005432800288	14588	Economy	11700.00
0005435127584	14588	Economy	11700.00
0005434427440	14588	Economy	11700.00
0005434880875	14588	Economy	11700.00
0005435127494	14588	Economy	11700.00
0005434880851	14588	Economy	11700.00
0005435127500	14588	Economy	11700.00
0005434938713	14588	Economy	11700.00
0005435626867	14588	Economy	11700.00
0005435127533	14588	Economy	11700.00
0005432607679	14588	Economy	11700.00
0005435127561	14588	Economy	11700.00
0005432800279	14588	Economy	11700.00
0005435626795	14588	Economy	11700.00
0005435626753	14588	Economy	11700.00
0005435626726	14588	Economy	11700.00
0005434427402	14588	Economy	11700.00
0005432800269	14588	Economy	11700.00
0005435127501	14588	Economy	11700.00
0005435127483	14588	Economy	12800.00
0005434880905	14588	Economy	12800.00
0005432607665	14588	Economy	11700.00
0005435626715	14588	Economy	11700.00
0005435626786	14588	Economy	11700.00
0005435127573	14588	Economy	11700.00
0005435626862	14588	Economy	11700.00
0005435127566	14588	Economy	11700.00
0005435127530	14588	Economy	11700.00
0005435127535	14588	Economy	11700.00
0005435626870	14588	Economy	11700.00
0005435626858	14588	Economy	11700.00
0005435626796	14588	Economy	11700.00
0005435626794	14588	Economy	11700.00
0005432800272	14588	Economy	11700.00
0005434880973	14588	Economy	11700.00
0005434427460	14588	Economy	11700.00
0005434880955	14588	Economy	11700.00
0005434880954	14588	Economy	11700.00
0005434427451	14588	Economy	11700.00
0005435626834	14588	Economy	11700.00
0005435127583	14588	Economy	11700.00
0005435127570	14588	Economy	11700.00
0005435626825	14588	Economy	11700.00
0005435890055	3585	Economy	16300.00
0005435890074	3585	Economy	14800.00
0005435890056	3585	Economy	14800.00
0005435890073	3585	Economy	14800.00
0005435890057	3585	Economy	14800.00
0005435958116	15188	Economy	4100.00
0005435958119	15188	Economy	4100.00
0005435958114	15188	Economy	4100.00
0005435958129	15188	Economy	4100.00
0005434995356	23996	Economy	31300.00
0005434995365	23996	Economy	31300.00
0005434995362	23996	Economy	31300.00
0005434995359	23996	Economy	31300.00
0005434995358	23996	Economy	31300.00
0005434995361	23996	Economy	34500.00
0005434995355	23996	Economy	31300.00
0005434995364	23996	Economy	31300.00
0005434995360	23996	Economy	31300.00
0005434995354	23996	Economy	31300.00
0005434995357	23996	Economy	31300.00
0005434995363	23996	Economy	31300.00
0005433405026	2858	Business	12600.00
0005433405020	2858	Business	12600.00
0005433405011	2858	Economy	4200.00
0005433405012	2858	Economy	4200.00
0005435797891	29325	Economy	4200.00
0005435376432	5816	Economy	6800.00
0005434948267	16402	Economy	6800.00
0005434948266	16402	Economy	6800.00
0005434948268	16402	Economy	6800.00
0005433962566	25703	Business	21400.00
0005433962633	25703	Business	21400.00
0005433962256	25703	Business	21400.00
0005433962690	25703	Business	21400.00
0005433962589	25703	Business	21400.00
0005433962411	25703	Business	21400.00
0005433962416	25703	Business	21400.00
0005433962647	25703	Business	21400.00
0005433962405	25703	Economy	7100.00
0005433962420	25703	Economy	7100.00
0005433962484	25703	Economy	7100.00
0005433962622	25703	Economy	7100.00
0005433962426	25703	Economy	7100.00
0005433962544	25703	Economy	7800.00
0005433962475	25703	Economy	7800.00
0005433962563	25703	Economy	7800.00
0005433962565	25703	Economy	7100.00
0005433962627	25703	Economy	7100.00
0005433962560	25703	Economy	7100.00
0005433962619	25703	Economy	7100.00
0005433962561	25703	Economy	7100.00
0005433962564	25703	Economy	7100.00
0005433962462	25703	Economy	7100.00
0005433962634	25703	Economy	7100.00
0005433962653	25703	Economy	7100.00
0005433962349	25703	Economy	7100.00
0005433962490	25703	Economy	7100.00
0005433962474	25703	Economy	7100.00
0005433962415	25703	Economy	7100.00
0005433962567	25703	Economy	7100.00
0005433962691	25703	Economy	7100.00
0005433962655	25703	Economy	7100.00
0005433962537	25703	Economy	7100.00
0005433962646	25703	Economy	7100.00
0005433962562	25703	Economy	7100.00
0005433962326	25703	Economy	7100.00
0005433962602	25703	Economy	7100.00
0005433962412	25703	Economy	7100.00
0005433962440	25703	Economy	7100.00
0005433962536	25703	Economy	7100.00
0005433962533	25703	Economy	7100.00
0005433962579	25703	Economy	7100.00
0005433962417	25703	Economy	7100.00
0005433962461	25703	Economy	7100.00
0005433962513	25703	Economy	7100.00
0005433962661	25703	Economy	7100.00
0005433962628	25703	Economy	7100.00
0005433962404	25703	Economy	7100.00
0005433962558	25703	Economy	7100.00
0005433962714	25703	Economy	7100.00
0005433962521	25703	Economy	7100.00
0005433962692	25703	Economy	7100.00
0005433962406	25703	Economy	7100.00
0005433962697	25703	Economy	7100.00
0005433962532	25703	Economy	7100.00
0005433962433	25703	Economy	7100.00
0005433962675	25703	Economy	7100.00
0005435083024	24542	Economy	3900.00
0005435083034	24542	Economy	3900.00
0005435287042	5157	Business	18000.00
0005435286853	5157	Business	18000.00
0005435286889	5157	Business	18000.00
0005435287035	5157	Business	18000.00
0005435286921	5157	Business	18000.00
0005435286914	5157	Economy	6600.00
0005435286862	5157	Economy	6000.00
0005435286989	5157	Economy	6000.00
0005435286948	5157	Economy	6000.00
0005435287014	5157	Economy	6000.00
0005435286942	5157	Economy	6000.00
0005435286995	5157	Economy	6000.00
0005435551775	5157	Economy	6000.00
0005435287055	5157	Economy	6000.00
0005435287016	5157	Economy	6000.00
0005435286996	5157	Economy	6000.00
0005435287019	5157	Economy	6600.00
0005435286877	5157	Economy	6000.00
0005435286975	5157	Economy	6000.00
0005435286920	5157	Economy	6000.00
0005435286994	5157	Economy	6000.00
0005435287031	5157	Economy	6000.00
0005435287015	5157	Economy	6000.00
0005435286901	5157	Economy	6000.00
0005435426859	5157	Economy	6000.00
0005435286811	5157	Economy	6000.00
0005435287018	5157	Economy	6000.00
0005435287056	5157	Economy	6000.00
0005435007699	5166	Business	18000.00
0005435732738	5166	Economy	6000.00
0005435270226	5166	Economy	6000.00
0005435270223	5166	Economy	6000.00
0005435007711	5166	Economy	6000.00
0005435007710	5166	Economy	6000.00
0005435270224	5166	Economy	6000.00
0005435007709	5166	Economy	6000.00
0005432336381	5166	Economy	6000.00
0005435270192	5166	Economy	6000.00
0005435270225	5166	Economy	6000.00
0005433685583	5166	Economy	6000.00
0005433815578	5166	Economy	6000.00
0005434311281	5166	Economy	6000.00
0005435007712	5166	Economy	6600.00
0005435270120	5166	Economy	6000.00
0005435270191	5166	Economy	6000.00
0005435732739	5166	Economy	6000.00
0005435007689	5166	Economy	6000.00
0005435270121	5166	Economy	6000.00
0005433786185	8450	Business	18000.00
0005433786155	8450	Business	18000.00
0005433786132	8450	Economy	6600.00
0005433786133	8450	Economy	6000.00
0005433786129	8450	Economy	6000.00
0005433786187	8450	Economy	6000.00
0005434245830	8450	Economy	6000.00
0005433786191	8450	Economy	6000.00
0005433786013	8450	Economy	6000.00
0005432666448	8450	Economy	6000.00
0005433786090	8450	Economy	6000.00
0005433786114	8450	Economy	6000.00
0005433786189	8450	Economy	6000.00
0005433786130	8450	Economy	6000.00
0005432666447	8450	Economy	6000.00
0005433786004	8450	Economy	6600.00
0005433786146	8450	Economy	6600.00
0005433786091	8450	Economy	6000.00
0005432666449	8450	Economy	6000.00
0005433786002	8450	Economy	6000.00
0005433786156	8450	Economy	6000.00
0005433786136	8450	Economy	6000.00
0005433786113	8450	Economy	6000.00
0005433786096	8450	Economy	6000.00
0005434245829	8450	Economy	6000.00
0005433786050	8450	Economy	6000.00
0005433786051	8450	Economy	6000.00
0005433786157	8450	Economy	6000.00
0005433786131	8450	Economy	6000.00
0005434230099	8451	Business	18000.00
0005433616716	8451	Business	18000.00
0005433616815	8451	Business	18000.00
0005434230253	8451	Business	18000.00
0005433616666	8451	Business	18000.00
0005433616770	8451	Business	18000.00
0005433616801	8451	Business	18000.00
0005434230226	8451	Business	18000.00
0005434230065	8451	Business	18000.00
0005434230222	8451	Business	18000.00
0005433616720	8451	Economy	6600.00
0005433616821	8451	Economy	6600.00
0005434230111	8451	Economy	6600.00
0005434230269	8451	Economy	6000.00
0005434230279	8451	Economy	6000.00
0005434230157	8451	Economy	6000.00
0005434230116	8451	Economy	6000.00
0005434230233	8451	Economy	6000.00
0005434230062	8451	Economy	6000.00
0005434230234	8451	Economy	6000.00
0005434230209	8451	Economy	6000.00
0005434230171	8451	Economy	6000.00
0005433616754	8451	Economy	6000.00
0005434230208	8451	Economy	6000.00
0005434230250	8451	Economy	6000.00
0005433616808	8451	Economy	6000.00
0005433616826	8451	Economy	6000.00
0005434230224	8451	Economy	6000.00
0005434230225	8451	Economy	6000.00
0005434230180	8451	Economy	6000.00
0005434230223	8451	Economy	6000.00
0005434230170	8451	Economy	6000.00
0005433616604	8451	Economy	6000.00
0005434230139	8451	Economy	6000.00
0005433616703	8451	Economy	6000.00
0005434230095	8451	Economy	6000.00
0005434230096	8451	Economy	6000.00
0005434230140	8451	Economy	6000.00
0005433616635	8451	Economy	6000.00
0005433616641	8451	Economy	6000.00
0005434230141	8451	Economy	6000.00
0005434230100	8451	Economy	6600.00
0005434230254	8451	Economy	6000.00
0005434230237	8451	Economy	6000.00
0005433616502	8451	Economy	6000.00
0005434230064	8451	Economy	6000.00
0005433616688	8451	Economy	6000.00
0005434230248	8451	Economy	6000.00
0005434230161	8451	Economy	6000.00
0005433616816	8451	Economy	6000.00
0005434230110	8451	Economy	6000.00
0005434230231	8451	Economy	6000.00
0005433616689	8451	Economy	6000.00
0005434230156	8451	Economy	6000.00
0005433616773	8451	Economy	6000.00
0005434230094	8451	Economy	6000.00
0005434230271	8451	Economy	6000.00
0005433616751	8451	Economy	6000.00
0005433616753	8451	Economy	6000.00
0005433616687	8451	Economy	6000.00
0005434230162	8451	Economy	6000.00
0005434230127	8451	Economy	6000.00
0005434230232	8451	Economy	6000.00
0005433616809	8451	Economy	6000.00
0005433616799	8451	Economy	6000.00
0005433616721	8451	Economy	6000.00
0005434230246	8451	Economy	6000.00
0005434230202	8451	Economy	6000.00
0005434230251	8451	Economy	6000.00
0005434230247	8451	Economy	6000.00
0005433616802	8451	Economy	6000.00
0005433616769	8451	Economy	6000.00
0005433616820	8451	Economy	6000.00
0005434230201	8451	Economy	6000.00
0005434230142	8451	Economy	6000.00
0005434265875	8452	Business	18000.00
0005434265892	8452	Business	18000.00
0005434265876	8452	Business	18000.00
0005434230017	8452	Economy	6000.00
0005434150064	8452	Economy	6000.00
0005434150065	8452	Economy	6600.00
0005434150063	8452	Economy	6000.00
0005434265874	8452	Economy	6000.00
0005434265861	8452	Economy	6000.00
0005434640022	12624	Economy	16200.00
0005434640097	12624	Economy	14800.00
0005434640065	12624	Economy	14800.00
0005434640090	12624	Economy	14800.00
0005434640019	12624	Economy	14800.00
0005434640096	12624	Economy	14800.00
0005434640105	12624	Economy	14800.00
0005434640078	12624	Economy	14800.00
0005433202772	23366	Economy	16200.00
0005433202771	23366	Economy	14800.00
0005433202758	23366	Economy	14800.00
0005432384328	21062	Business	18900.00
0005432384301	21062	Business	18900.00
0005432384212	21062	Economy	6300.00
0005432384326	21062	Economy	6300.00
0005432384225	21062	Economy	6300.00
0005432384315	21062	Economy	6900.00
0005432384226	21062	Economy	6300.00
0005432330014	21062	Economy	6300.00
0005432384300	21062	Economy	6300.00
0005432330030	21062	Economy	6300.00
0005432384285	21062	Economy	6300.00
0005432329974	21062	Economy	6300.00
0005432384322	21062	Economy	6300.00
0005432329975	21062	Economy	6300.00
0005432384214	21062	Economy	6300.00
0005432384327	21062	Economy	6300.00
0005432384309	21062	Economy	6300.00
0005432384213	21062	Economy	6300.00
0005432384286	21062	Economy	6300.00
0005432384323	21062	Economy	6300.00
0005432384314	21062	Economy	6300.00
0005432384098	21062	Economy	6300.00
0005432329942	21062	Economy	6300.00
0005432384329	21062	Economy	6300.00
0005432330013	21062	Economy	6300.00
0005432384338	21062	Economy	6300.00
0005432425917	30812	Business	12700.00
0005432426024	30812	Business	12700.00
0005432425994	30812	Business	12700.00
0005432426032	30812	Business	12700.00
0005432425912	30812	Business	12700.00
0005432425949	30812	Business	12700.00
0005432426078	30812	Business	12700.00
0005432426015	30812	Economy	4200.00
0005432425947	30812	Economy	4200.00
0005432425891	30812	Economy	4200.00
0005432426023	30812	Economy	4200.00
0005432425956	30812	Economy	4200.00
0005432425895	30812	Economy	4700.00
0005432425930	30812	Economy	4200.00
0005432433842	30812	Economy	4200.00
0005432426030	30812	Economy	4200.00
0005432426051	30812	Economy	4200.00
0005432425913	30812	Economy	4200.00
0005432433841	30812	Economy	4200.00
0005432426059	30812	Economy	4200.00
0005432425914	30812	Economy	4200.00
0005432426058	30812	Economy	4200.00
0005432425691	30812	Economy	4200.00
0005432425742	30812	Economy	4200.00
0005432426031	30812	Economy	4200.00
0005432425833	30812	Economy	4200.00
0005432425835	30812	Economy	4200.00
0005432426033	30812	Economy	4200.00
0005432425874	30812	Economy	4200.00
0005432425941	30812	Economy	4200.00
0005432425976	30812	Economy	4200.00
0005432462582	30812	Economy	4200.00
0005432425950	30812	Economy	4200.00
0005432425690	30812	Economy	4200.00
0005432425984	30812	Economy	4200.00
0005432425896	30812	Economy	4200.00
0005432425946	30812	Economy	4200.00
0005432425893	30812	Economy	4200.00
0005432425927	30812	Economy	4200.00
0005432425646	30812	Economy	4200.00
0005432425894	30812	Economy	4200.00
0005432426071	30812	Economy	4200.00
0005432425955	30812	Economy	4200.00
0005432425977	30812	Economy	4200.00
0005432425834	30812	Economy	4200.00
0005432425808	30812	Economy	4200.00
0005432425781	30812	Economy	4200.00
0005432425923	30812	Economy	4200.00
0005432425898	30812	Economy	4200.00
0005432425931	30812	Economy	4200.00
0005432425645	30812	Economy	4200.00
0005432425978	30812	Economy	4200.00
0005432902109	9597	Business	32600.00
0005432902123	9597	Economy	10900.00
0005432902110	9597	Economy	10900.00
0005432902122	9597	Economy	10900.00
0005432902124	9597	Economy	10900.00
0005432902108	9597	Economy	10900.00
0005432902111	9597	Economy	10900.00
0005434157707	9597	Economy	10900.00
0005434157706	9597	Economy	10900.00
0005432818291	28988	Business	32600.00
0005432818241	28988	Business	32600.00
0005432822430	28988	Business	32600.00
0005432818313	28988	Economy	10900.00
0005432818284	28988	Economy	10900.00
0005432818330	28988	Economy	11900.00
0005432818283	28988	Economy	10900.00
0005432822418	28988	Economy	10900.00
0005432818325	28988	Economy	10900.00
0005432818314	28988	Economy	10900.00
0005432818331	28988	Economy	10900.00
0005432818322	28988	Economy	10900.00
0005432818326	28988	Economy	10900.00
0005432818335	28988	Economy	10900.00
0005432818282	28988	Economy	10900.00
0005435841849	15030	Economy	11000.00
0005435841850	15030	Economy	11000.00
0005435841848	15030	Economy	11000.00
0005432607678	31584	Economy	11000.00
0005432607665	31584	Economy	11000.00
0005432607679	31584	Economy	11000.00
0005432607664	31584	Economy	11000.00
0005432949661	11832	Business	105900.00
0005432949503	11832	Business	105900.00
0005432949578	11832	Business	105900.00
0005432949686	11832	Business	105900.00
0005432949544	11832	Economy	35300.00
0005432949675	11832	Economy	35300.00
0005432949649	11832	Economy	38800.00
0005432949626	11832	Economy	38800.00
0005432949687	11832	Economy	35300.00
0005432949690	11832	Economy	35300.00
0005432949608	11832	Economy	35300.00
0005432949560	11832	Economy	35300.00
0005432949689	11832	Economy	35300.00
0005432949625	11832	Economy	35300.00
0005432949542	11832	Economy	35300.00
0005432949673	11832	Economy	35300.00
0005432949694	11832	Economy	35300.00
0005432949674	11832	Economy	35300.00
0005432949543	11832	Economy	35300.00
0005432949644	11832	Economy	35300.00
0005432949553	11832	Economy	35300.00
0005432949624	11832	Economy	35300.00
0005432949648	11832	Economy	35300.00
0005433570830	25277	Business	105900.00
0005433570958	25277	Business	105900.00
0005433570911	25277	Business	105900.00
0005433570972	25277	Business	105900.00
0005433570933	25277	Business	105900.00
0005433570839	25277	Economy	35300.00
0005433570931	25277	Economy	35300.00
0005433570980	25277	Economy	35300.00
0005433570940	25277	Economy	35300.00
0005433570868	25277	Economy	35300.00
0005433570840	25277	Economy	35300.00
0005433570831	25277	Economy	35300.00
0005433570924	25277	Economy	38800.00
0005433570937	25277	Economy	35300.00
0005433570844	25277	Economy	35300.00
0005433570919	25277	Economy	35300.00
0005433570973	25277	Economy	35300.00
0005433570928	25277	Economy	35300.00
0005433570906	25277	Economy	35300.00
0005433570884	25277	Economy	35300.00
0005433570920	25277	Economy	35300.00
0005433570907	25277	Economy	35300.00
0005433570934	25277	Economy	35300.00
0005433570838	25277	Economy	35300.00
0005433570763	25277	Economy	35300.00
0005433570829	25277	Economy	35300.00
0005433570866	25277	Economy	35300.00
0005433570874	25277	Economy	35300.00
0005433570930	25277	Economy	35300.00
0005433570921	25277	Economy	35300.00
0005433570956	25277	Economy	35300.00
0005433570959	25277	Economy	35300.00
0005433570888	25277	Economy	35300.00
0005433811683	27941	Business	105400.00
0005433811688	27941	Business	105400.00
0005433811684	27941	Economy	35100.00
0005433811674	27941	Economy	35100.00
0005433811680	27941	Economy	35100.00
0005433811673	27941	Economy	35100.00
0005433927540	27941	Economy	35100.00
0005433811677	27941	Economy	35100.00
0005433811686	27941	Economy	38600.00
0005433811691	27941	Economy	38600.00
0005433811685	27941	Economy	38600.00
0005433811675	27941	Economy	35100.00
0005433811682	27941	Economy	35100.00
0005433811687	27941	Economy	35100.00
0005433811681	27941	Economy	35100.00
0005435340662	5390	Economy	22400.00
0005435340694	5390	Economy	22400.00
0005435340663	5390	Economy	22400.00
0005435266340	7467	Business	32000.00
0005435266325	7467	Economy	10700.00
0005435266334	7467	Economy	10700.00
0005435546238	7467	Economy	10700.00
0005433685583	29240	Business	32000.00
0005433717417	29240	Business	32000.00
0005433717361	29240	Economy	10700.00
0005433722474	29240	Economy	10700.00
0005433722436	29240	Economy	10700.00
0005433722509	29240	Economy	11700.00
0005433722499	29240	Economy	10700.00
0005433722475	29240	Economy	10700.00
0005433722421	29240	Economy	10700.00
0005433722413	29240	Economy	10700.00
0005433717399	29240	Economy	10700.00
0005433717362	29240	Economy	10700.00
0005433722500	29240	Economy	10700.00
0005433717360	29240	Economy	10700.00
0005433717348	29240	Economy	10700.00
0005433717331	29240	Economy	10700.00
0005433717332	29240	Economy	10700.00
0005433717416	29240	Economy	10700.00
0005434182553	8702	Business	36500.00
0005434182552	8702	Business	36500.00
0005435860732	8702	Business	36500.00
0005435860727	8702	Economy	13400.00
0005434182540	8702	Economy	12200.00
0005435860688	8702	Economy	12200.00
0005434182551	8702	Economy	12200.00
0005435860726	8702	Economy	12200.00
0005435860719	8702	Economy	12200.00
0005434095649	11673	Business	36500.00
0005434095706	11673	Business	36500.00
0005434326294	11673	Business	36500.00
0005434095699	11673	Economy	12200.00
0005434143840	11673	Economy	13400.00
0005434326295	11673	Economy	13400.00
0005434095707	11673	Economy	13400.00
0005434095705	11673	Economy	12200.00
0005434143761	11673	Economy	12200.00
0005434143754	11673	Economy	12200.00
0005434326293	11673	Economy	12200.00
0005434143760	11673	Economy	12200.00
0005433399435	1461	Economy	11000.00
0005433399445	1461	Economy	11000.00
0005433399373	1461	Economy	12100.00
0005433399430	1461	Economy	12100.00
0005433399416	1461	Economy	11000.00
0005433399426	1461	Economy	11000.00
0005433399444	1461	Economy	11000.00
0005433399451	1461	Economy	11000.00
0005433399419	1461	Economy	11000.00
0005433399431	1461	Economy	11000.00
0005433399395	1461	Economy	11000.00
0005433399434	1461	Economy	11000.00
0005435732722	19270	Economy	11000.00
0005435732712	19270	Economy	12100.00
0005435732696	19270	Economy	11000.00
0005435732721	19270	Economy	11000.00
0005435732719	19270	Economy	11000.00
0005435732720	19270	Economy	11000.00
0005435732713	19270	Economy	11000.00
0005435732695	19270	Economy	11000.00
0005434444131	17383	Economy	15600.00
0005434444162	17383	Economy	15600.00
0005434444163	17383	Economy	14100.00
0005434444180	17383	Economy	14100.00
0005434444177	17383	Economy	14100.00
0005434444132	17383	Economy	14100.00
0005434444178	17383	Economy	14100.00
0005434352064	29667	Economy	15400.00
0005434352061	29667	Economy	14000.00
0005434326064	29667	Economy	14000.00
0005434326095	29667	Economy	14000.00
0005434326063	29667	Economy	14000.00
0005434326107	29667	Economy	14000.00
0005433346043	1082	Business	30600.00
0005433345761	1082	Business	30600.00
0005433345904	1082	Business	30600.00
0005433345802	1082	Economy	11200.00
0005433345700	1082	Economy	10200.00
0005433345885	1082	Economy	10200.00
0005433345770	1082	Economy	10200.00
0005433345901	1082	Economy	10200.00
0005433345717	1082	Economy	10200.00
0005433345831	1082	Economy	10200.00
0005433346042	1082	Economy	10200.00
0005433346049	1082	Economy	10200.00
0005433346038	1082	Economy	10200.00
0005433346001	1082	Economy	10200.00
0005433345988	1082	Economy	10200.00
0005433346017	1082	Economy	10200.00
0005433345986	1082	Economy	10200.00
0005433346002	1082	Economy	10200.00
0005433346047	1082	Economy	10200.00
0005433345716	1082	Economy	10200.00
0005433345769	1082	Economy	10200.00
0005433346048	1082	Economy	10200.00
0005435092365	17042	Business	30600.00
0005435530190	17042	Business	30600.00
0005435508787	17042	Economy	10200.00
0005435508756	17042	Economy	10200.00
0005435530195	17042	Economy	10200.00
0005435530172	17042	Economy	10200.00
0005435508797	17042	Economy	10200.00
0005435508796	17042	Economy	10200.00
0005435546002	17042	Economy	10200.00
0005435530171	17042	Economy	10200.00
0005435508736	17042	Economy	10200.00
0005435508795	17042	Economy	10200.00
0005435530181	17042	Economy	10200.00
0005435508789	17042	Economy	10200.00
0005435530180	17042	Economy	11200.00
0005435508737	17042	Economy	10200.00
0005435508782	17042	Economy	10200.00
0005435508755	17042	Economy	10200.00
0005435508788	17042	Economy	10200.00
0005435508779	17042	Economy	10200.00
0005434082556	12766	Business	40300.00
0005434069484	12766	Business	40300.00
0005434069483	12766	Economy	13400.00
0005434082624	12766	Economy	13400.00
0005434069575	12766	Economy	13400.00
0005434069544	12766	Economy	13400.00
0005434069574	12766	Economy	13400.00
0005434082631	12766	Economy	14800.00
0005434069350	12766	Economy	14800.00
0005434069621	12766	Economy	13400.00
0005434082623	12766	Economy	13400.00
0005434069645	12766	Economy	13400.00
0005434082607	12766	Economy	13400.00
0005434026760	12766	Economy	13400.00
0005434069467	12766	Economy	13400.00
0005433989897	12766	Economy	13400.00
0005434069646	12766	Economy	13400.00
0005434069613	12766	Economy	13400.00
0005434069614	12766	Economy	13400.00
0005434082603	12766	Economy	13400.00
0005434069292	12766	Economy	13400.00
0005434069647	12766	Economy	13400.00
0005433989903	12766	Economy	13400.00
0005434069648	12766	Economy	13400.00
0005434069387	12766	Economy	13400.00
0005433989902	12766	Economy	13400.00
0005434069351	12766	Economy	13400.00
0005434069468	12766	Economy	13400.00
0005434082647	12766	Economy	13400.00
0005434082632	12766	Economy	13400.00
0005434082639	12766	Economy	13400.00
0005434069573	12766	Economy	13400.00
0005434069580	12766	Economy	13400.00
0005433812966	30666	Economy	13400.00
0005432433832	30666	Economy	13400.00
0005435283551	30666	Economy	13400.00
0005435860637	30666	Economy	13400.00
0005435860639	30666	Economy	13400.00
0005435463482	5489	Business	35300.00
0005435463507	5489	Economy	12900.00
0005435463518	5489	Economy	11800.00
0005434831284	5489	Economy	11800.00
0005434265899	5489	Economy	11800.00
0005432535968	5489	Economy	11800.00
0005434265866	5489	Economy	11800.00
0005435463474	5489	Economy	11800.00
0005434831283	5489	Economy	11800.00
0005434831287	5489	Economy	11800.00
0005435463456	5489	Economy	11800.00
0005434265877	5489	Economy	11800.00
0005434265878	5489	Economy	11800.00
0005434831281	5489	Economy	11800.00
0005434265862	5489	Economy	11800.00
0005432535977	5489	Economy	11800.00
0005435463493	5489	Economy	11800.00
0005434265882	5489	Economy	11800.00
0005435463508	5489	Economy	11800.00
0005435463492	5489	Economy	11800.00
0005432535978	5489	Economy	11800.00
0005434265900	5489	Economy	11800.00
0005433529373	13493	Business	35300.00
0005433529374	13493	Business	35300.00
0005433529363	13493	Business	35300.00
0005435767966	13493	Business	35300.00
0005433533418	13493	Business	35300.00
0005433529364	13493	Business	35300.00
0005433529387	13493	Business	35300.00
0005435768082	13493	Business	35300.00
0005433529385	13493	Business	35300.00
0005435768084	13493	Business	35300.00
0005435722120	13493	Economy	11800.00
0005435768038	13493	Economy	11800.00
0005435768123	13493	Economy	11800.00
0005433533421	13493	Economy	11800.00
0005435768003	13493	Economy	11800.00
0005435768122	13493	Economy	11800.00
0005433529380	13493	Economy	11800.00
0005435723102	13493	Economy	11800.00
0005433529383	13493	Economy	11800.00
0005433533405	13493	Economy	11800.00
0005435767973	13493	Economy	11800.00
0005435768064	13493	Economy	11800.00
0005435768062	13493	Economy	11800.00
0005435735268	13493	Economy	11800.00
0005435732739	13493	Economy	11800.00
0005433529386	13493	Economy	11800.00
0005435768063	13493	Economy	11800.00
0005433529362	13493	Economy	11800.00
0005435767965	13493	Economy	11800.00
0005435768086	13493	Economy	11800.00
0005433529379	13493	Economy	11800.00
0005433529381	13493	Economy	11800.00
0005435768006	13493	Economy	11800.00
0005435767971	13493	Economy	11800.00
0005435767970	13493	Economy	11800.00
0005435768083	13493	Economy	11800.00
0005435720167	13493	Economy	11800.00
0005433533422	13493	Economy	11800.00
0005435732738	13493	Economy	11800.00
0005433529382	13493	Economy	11800.00
0005434602979	18730	Economy	3300.00
0005434602980	18730	Economy	3300.00
0005434605002	18731	Economy	3300.00
0005434605001	18731	Economy	3300.00
0005435846356	4111	Business	88300.00
0005435844440	4111	Business	88300.00
0005435846361	4111	Economy	29400.00
0005435844433	4111	Economy	32400.00
0005435844424	4111	Economy	29400.00
0005435844421	4111	Economy	29400.00
0005435846354	4111	Economy	29400.00
0005435844434	4111	Economy	29400.00
0005435844437	4111	Economy	29400.00
0005435844439	4111	Economy	29400.00
0005435846355	4111	Economy	29400.00
0005435846362	4111	Economy	29400.00
0005433009949	1877	Business	48700.00
0005433286195	1877	Economy	16200.00
0005433009915	1877	Economy	16200.00
0005433009854	1877	Economy	17900.00
0005433009914	1877	Economy	16200.00
0005433009926	1877	Economy	16200.00
0005433286228	1877	Economy	16200.00
0005433286143	1877	Economy	16200.00
0005433009902	1877	Economy	16200.00
0005433009916	1877	Economy	16200.00
0005433009958	1877	Economy	16200.00
0005433009945	1877	Economy	16200.00
0005433009960	1877	Economy	16200.00
0005433286116	1877	Economy	16200.00
0005433286212	1877	Economy	16200.00
0005433009946	1877	Economy	16200.00
0005433286219	1877	Economy	16200.00
0005433009976	1877	Economy	16200.00
0005433009959	1877	Economy	16200.00
0005433009901	1877	Economy	16200.00
0005433009882	1877	Economy	16200.00
0005435725756	22513	Business	48700.00
0005433810763	22513	Business	48700.00
0005433810750	22513	Business	48700.00
0005433810761	22513	Economy	16200.00
0005433810764	22513	Economy	16200.00
0005435725754	22513	Economy	16200.00
0005435725757	22513	Economy	17900.00
0005433810740	22513	Economy	16200.00
0005435725767	22513	Economy	16200.00
0005435725768	22513	Economy	16200.00
0005433810717	22513	Economy	16200.00
0005435725755	22513	Economy	16200.00
0005435725779	22513	Economy	16200.00
0005433810772	22513	Economy	16200.00
0005433810737	22513	Economy	16200.00
0005433810810	22513	Economy	16200.00
0005433810754	22513	Economy	16200.00
0005433810751	22513	Economy	16200.00
0005433810742	22513	Economy	16200.00
0005433810718	22513	Economy	16200.00
0005433810741	22513	Economy	16200.00
0005435725763	22513	Economy	16200.00
0005433810815	22513	Economy	16200.00
0005433810816	22513	Economy	16200.00
0005433810784	22513	Economy	16200.00
0005435725766	22513	Economy	16200.00
0005433810803	22513	Economy	16200.00
0005433810782	22513	Economy	16200.00
0005433810681	22513	Economy	16200.00
0005435283225	5566	Business	99800.00
0005435283229	5566	Economy	33300.00
0005435283245	5566	Economy	33300.00
0005435283238	5566	Economy	33300.00
0005435283234	5566	Economy	33300.00
0005435283237	5566	Economy	33300.00
0005435283246	5566	Economy	33300.00
0005435283235	5566	Economy	33300.00
0005435283236	5566	Economy	33300.00
0005435283251	5566	Economy	33300.00
0005435283244	5566	Economy	33300.00
0005433848386	13849	Business	99800.00
0005433848405	13849	Economy	33300.00
0005433848398	13849	Economy	33300.00
0005433848362	13849	Economy	33300.00
0005433848408	13849	Economy	33300.00
0005433848397	13849	Economy	33300.00
0005433848409	13849	Economy	33300.00
0005433848385	13849	Economy	33300.00
0005433815578	13849	Economy	33300.00
0005433848301	13849	Economy	33300.00
0005433848327	13849	Economy	33300.00
0005435332643	7840	Economy	15100.00
0005434621162	32946	Economy	15100.00
0005434621164	32946	Economy	15100.00
0005434621133	32946	Economy	15100.00
0005434621132	32946	Economy	15100.00
0005435937558	4296	Business	38000.00
0005435937571	4296	Economy	12700.00
0005435918793	4296	Economy	12700.00
0005435937573	4296	Economy	12700.00
0005435937559	4296	Economy	12700.00
0005435786280	27322	Business	38000.00
0005435786308	27322	Business	38000.00
0005435786305	27322	Business	38000.00
0005434994309	27322	Business	38000.00
0005435786324	27322	Business	38000.00
0005435786310	27322	Economy	12700.00
0005435786242	27322	Economy	12700.00
0005435786306	27322	Economy	12700.00
0005435786338	27322	Economy	12700.00
0005435786187	27322	Economy	12700.00
0005435786162	27322	Economy	12700.00
0005435786309	27322	Economy	12700.00
0005435786307	27322	Economy	12700.00
0005435786330	27322	Economy	12700.00
0005435786279	27322	Economy	12700.00
0005435786325	27322	Economy	12700.00
0005434150224	4707	Business	40900.00
0005434150233	4707	Business	40900.00
0005435840498	4707	Business	40900.00
0005435840478	4707	Business	40900.00
0005435960172	4707	Business	40900.00
0005434150225	4707	Economy	15000.00
0005434150176	4707	Economy	13600.00
0005434150201	4707	Economy	13600.00
0005435960173	4707	Economy	13600.00
0005434150228	4707	Economy	13600.00
0005434150200	4707	Economy	13600.00
0005434150190	4707	Economy	13600.00
0005435840496	4707	Economy	13600.00
0005434150143	4707	Economy	13600.00
0005434150175	4707	Economy	13600.00
0005435860638	4707	Economy	13600.00
0005435840494	4707	Economy	13600.00
0005435840479	4707	Economy	13600.00
0005435840497	4707	Economy	13600.00
0005435840487	4707	Economy	13600.00
0005434150215	4707	Economy	13600.00
0005434150177	4707	Economy	13600.00
0005435840468	4707	Economy	13600.00
0005435840445	4707	Economy	13600.00
0005435840495	4707	Economy	13600.00
0005434150202	4707	Economy	13600.00
0005434150216	4707	Economy	13600.00
0005435960171	4707	Economy	13600.00
0005435840510	4707	Economy	13600.00
0005435840477	4707	Economy	13600.00
0005435840467	4707	Economy	13600.00
0005435840486	4707	Economy	13600.00
0005434150229	4707	Economy	13600.00
0005434150214	4707	Economy	13600.00
0005432461365	30518	Business	40900.00
0005432461271	30518	Business	40900.00
0005432461313	30518	Economy	15000.00
0005432461434	30518	Economy	15000.00
0005434082607	30518	Economy	15000.00
0005432569379	30518	Economy	13600.00
0005432569345	30518	Economy	13600.00
0005432569376	30518	Economy	13600.00
0005432461422	30518	Economy	13600.00
0005432569384	30518	Economy	13600.00
0005432569346	30518	Economy	13600.00
0005432571429	30518	Economy	13600.00
0005432461421	30518	Economy	13600.00
0005432569381	30518	Economy	13600.00
0005434082632	30518	Economy	13600.00
0005432461216	30518	Economy	13600.00
0005432461387	30518	Economy	13600.00
0005432461312	30518	Economy	13600.00
0005434082631	30518	Economy	13600.00
0005432461381	30518	Economy	13600.00
0005434082603	30518	Economy	13600.00
0005434082624	30518	Economy	13600.00
0005432461412	30518	Economy	15000.00
0005432461435	30518	Economy	13600.00
0005433452796	30518	Economy	13600.00
0005434082639	30518	Economy	13600.00
0005432569380	30518	Economy	13600.00
0005432569383	30518	Economy	13600.00
0005432569404	30518	Economy	13600.00
0005434082556	30518	Economy	13600.00
0005432569321	30518	Economy	13600.00
0005432461430	30518	Economy	13600.00
0005432569403	30518	Economy	13600.00
0005434082647	30518	Economy	13600.00
0005434082623	30518	Economy	13600.00
0005432461391	30518	Economy	13600.00
0005432461330	30518	Economy	13600.00
0005435725770	13745	Economy	9700.00
0005435725787	13745	Economy	8800.00
0005435725782	13745	Economy	8800.00
0005435725786	13745	Economy	8800.00
0005435725758	13745	Economy	8800.00
0005435725781	13745	Economy	8800.00
0005435725777	13745	Economy	8800.00
0005435725783	13745	Economy	8800.00
0005435725778	13745	Economy	8800.00
0005435725771	13745	Economy	8800.00
0005435530197	11113	Economy	7900.00
0005435380434	11113	Economy	7900.00
0005435380435	11113	Economy	8600.00
0005435530196	11113	Economy	7900.00
0005435508812	11113	Economy	7900.00
0005433345717	17127	Business	23600.00
0005433345700	17127	Economy	7900.00
0005433346017	17127	Economy	7900.00
0005433346042	17127	Economy	7900.00
0005433345904	17127	Economy	7900.00
0005433346001	17127	Economy	7900.00
0005435097499	17127	Economy	7900.00
0005433345802	17127	Economy	7900.00
0005433345769	17127	Economy	7900.00
0005435097492	17127	Economy	7900.00
0005433345885	17127	Economy	7900.00
0005433346038	17127	Economy	7900.00
0005433346047	17127	Economy	7900.00
0005433345901	17127	Economy	7900.00
0005433345761	17127	Economy	7900.00
0005433345770	17127	Economy	7900.00
0005435097491	17127	Economy	7900.00
0005433345986	17127	Economy	7900.00
0005433345831	17127	Economy	7900.00
0005433345716	17127	Economy	7900.00
0005433346043	17127	Economy	7900.00
0005433346002	17127	Economy	7900.00
0005433345988	17127	Economy	7900.00
0005433346049	17127	Economy	7900.00
0005433346048	17127	Economy	7900.00
0005432920475	9108	Economy	8900.00
0005432920416	9108	Economy	8900.00
0005432920467	9108	Economy	8900.00
0005432920479	9108	Economy	8900.00
0005432920420	9108	Economy	8900.00
0005432920436	9108	Economy	8900.00
0005432920421	9108	Economy	8900.00
0005433477290	20449	Business	26600.00
0005433477254	20449	Economy	8900.00
0005433477255	20449	Economy	8900.00
0005433507724	20449	Economy	8900.00
0005433507698	20449	Economy	8900.00
0005433477289	20449	Economy	8900.00
0005433477293	20449	Economy	8900.00
0005433477288	20449	Economy	8900.00
0005433477291	20449	Economy	8900.00
0005433507725	20449	Economy	8900.00
0005433477292	20449	Economy	8900.00
0005433477204	20449	Economy	8900.00
0005435556765	11026	Business	9500.00
0005435127566	11026	Business	9500.00
0005435626794	11026	Business	9500.00
0005435626837	11026	Business	9500.00
0005435626727	11026	Business	9500.00
0005435626795	11026	Business	9500.00
0005435626871	11026	Business	9500.00
0005435127494	11026	Business	9500.00
0005435556764	11026	Business	9500.00
0005435626858	11026	Economy	3200.00
0005435127481	11026	Economy	3200.00
0005435127582	11026	Economy	3200.00
0005435127500	11026	Economy	3200.00
0005435127573	11026	Economy	3500.00
0005435626786	11026	Economy	3500.00
0005435127577	11026	Economy	3500.00
0005435127584	11026	Economy	3500.00
0005435626726	11026	Economy	3200.00
0005435127561	11026	Economy	3200.00
0005435554322	11026	Economy	3200.00
0005435626753	11026	Economy	3200.00
0005435626870	11026	Economy	3200.00
0005435127499	11026	Economy	3200.00
0005435127501	11026	Economy	3200.00
0005435626767	11026	Economy	3200.00
0005435127530	11026	Economy	3200.00
0005435127570	11026	Economy	3200.00
0005435626861	11026	Economy	3200.00
0005435626825	11026	Economy	3200.00
0005435626862	11026	Economy	3200.00
0005435127572	11026	Economy	3200.00
0005435626799	11026	Economy	3200.00
0005435626838	11026	Economy	3200.00
0005435127483	11026	Economy	3200.00
0005435626796	11026	Economy	3200.00
0005435626842	11026	Economy	3200.00
0005435127535	11026	Economy	3200.00
0005435626834	11026	Economy	3200.00
0005435626722	11026	Economy	3200.00
0005435626800	11026	Economy	3200.00
0005435127403	11026	Economy	3200.00
0005435127583	11026	Economy	3200.00
0005435127571	11026	Economy	3200.00
0005435626843	11026	Economy	3200.00
0005435626751	11026	Economy	3200.00
0005435127468	11026	Economy	3200.00
0005435127560	11026	Economy	3200.00
0005435626715	11026	Economy	3200.00
0005435127482	11026	Economy	3200.00
0005435626694	11026	Economy	3200.00
0005435554323	11026	Economy	3200.00
0005435554321	11026	Economy	3200.00
0005435626867	11026	Economy	3200.00
0005435626787	11026	Economy	3200.00
0005435127533	11026	Economy	3200.00
0005435127534	11026	Economy	3200.00
0005435626782	11026	Economy	3200.00
0005435443578	7116	Business	86900.00
0005435443569	7116	Business	86900.00
0005435216647	7116	Economy	29000.00
0005435219260	7116	Economy	29000.00
0005435216648	7116	Economy	29000.00
0005435443561	7116	Economy	29000.00
0005432394221	27080	Economy	29000.00
0005435715963	27080	Economy	29000.00
0005435715966	27080	Economy	29000.00
0005432394222	27080	Economy	29000.00
0005434085060	28524	Economy	7700.00
0005434085061	28524	Economy	7700.00
0005434085064	28524	Economy	7700.00
0005434085065	28524	Economy	7700.00
0005435548620	11172	Economy	27100.00
0005435548607	11172	Economy	24600.00
0005435548619	11172	Economy	24600.00
0005435548625	11172	Economy	24600.00
0005435548621	11172	Economy	24600.00
0005435548618	11172	Economy	24600.00
0005435548606	11172	Economy	24600.00
0005435548612	11172	Economy	24600.00
0005435548605	11172	Economy	24600.00
0005433788317	20676	Economy	27100.00
0005433788316	20676	Economy	24600.00
0005433788306	20676	Economy	24600.00
0005433788301	20676	Economy	24600.00
0005433788302	20676	Economy	24600.00
0005435541619	11368	Business	20200.00
0005435541593	11368	Business	20200.00
0005435518453	11368	Economy	6700.00
0005435541645	11368	Economy	6700.00
0005435518459	11368	Economy	6700.00
0005435541650	11368	Economy	6700.00
0005435541646	11368	Economy	6700.00
0005435546224	11368	Economy	6700.00
0005435518444	11368	Economy	6700.00
0005435546225	11368	Economy	6700.00
0005435518460	11368	Economy	6700.00
0005435518443	11368	Economy	6700.00
0005435541644	11368	Economy	6700.00
0005435541622	11368	Economy	6700.00
0005435518458	11368	Economy	6700.00
0005435546230	11368	Economy	6700.00
0005433252383	2278	Economy	6700.00
0005433252375	2278	Economy	6700.00
0005433252384	2278	Economy	6700.00
0005434908748	25578	Business	20200.00
0005434908901	25578	Economy	6700.00
0005434908507	25578	Economy	6700.00
0005435787474	25578	Economy	6700.00
0005434908792	25578	Economy	6700.00
0005434908745	25578	Economy	6700.00
0005434908881	25578	Economy	6700.00
0005434908822	25578	Economy	6700.00
0005435787473	25578	Economy	6700.00
0005434908857	25578	Economy	6700.00
0005434908826	25578	Economy	6700.00
0005434908900	25578	Economy	6700.00
0005434908791	25578	Economy	6700.00
0005434908836	25578	Economy	6700.00
0005434908751	25578	Economy	6700.00
0005434908712	25578	Economy	6700.00
0005434908783	25578	Economy	6700.00
0005434908786	25578	Economy	6700.00
0005434908814	25578	Economy	6700.00
0005432621459	28039	Economy	12400.00
0005433452796	31413	Economy	8400.00
0005434184725	11974	Economy	6600.00
0005434326014	29829	Economy	7200.00
0005434326300	29829	Economy	6600.00
0005434326299	29829	Economy	6600.00
0005434326042	29829	Economy	6600.00
0005434326028	29829	Economy	6600.00
0005435935136	16478	Economy	19900.00
0005435935133	16478	Economy	18100.00
0005435935135	16478	Economy	18100.00
0005435698081	24716	Economy	18100.00
0005435698157	24716	Economy	18100.00
0005435698082	24716	Economy	18100.00
0005435698092	24716	Economy	18100.00
0005435698167	24716	Economy	18100.00
0005435698168	24716	Economy	18100.00
0005435698108	24716	Economy	18100.00
0005432968909	18806	Economy	4400.00
0005432968906	18806	Economy	4400.00
0005432968907	18806	Economy	4400.00
0005432968908	18806	Economy	4400.00
0005435283579	7319	Economy	7700.00
0005434140550	28568	Business	23100.00
0005434140601	28568	Business	23100.00
0005434140471	28568	Business	23100.00
0005434140544	28568	Business	23100.00
0005434140607	28568	Economy	7700.00
0005434140573	28568	Economy	8500.00
0005434140482	28568	Economy	8500.00
0005434140612	28568	Economy	7700.00
0005434140545	28568	Economy	7700.00
0005434140590	28568	Economy	7700.00
0005434140608	28568	Economy	7700.00
0005434140522	28568	Economy	7700.00
0005434140509	28568	Economy	7700.00
0005434140624	28568	Economy	7700.00
0005434140460	28568	Economy	7700.00
0005434140551	28568	Economy	7700.00
0005434140526	28568	Economy	7700.00
0005434140476	28568	Economy	7700.00
0005434140475	28568	Economy	7700.00
0005434140524	28568	Economy	7700.00
0005434140485	28568	Economy	7700.00
0005434140439	28568	Economy	7700.00
0005434140574	28568	Economy	7700.00
0005434140589	28568	Economy	7700.00
0005434140600	28568	Economy	7700.00
0005434140570	28568	Economy	7700.00
0005434140623	28568	Economy	7700.00
0005434140613	28568	Economy	7700.00
0005434140438	28568	Economy	7700.00
0005434140523	28568	Economy	7700.00
0005434140422	28568	Economy	7700.00
0005434140541	28568	Economy	7700.00
0005434140602	28568	Economy	7700.00
0005434140158	28568	Economy	7700.00
0005434140525	28568	Economy	7700.00
0005433407694	1944	Economy	21700.00
0005433407693	1944	Economy	21700.00
0005433407712	1944	Economy	21700.00
0005435808500	23110	Economy	23900.00
0005435808493	23110	Economy	21700.00
0005435808511	23110	Economy	21700.00
0005435808494	23110	Economy	21700.00
0005435808502	23110	Economy	21700.00
0005435808495	23110	Economy	21700.00
0005435808505	23110	Economy	21700.00
0005435808524	23110	Economy	21700.00
0005435808504	23110	Economy	21700.00
0005435808506	23110	Economy	21700.00
0005435808503	23110	Economy	21700.00
0005435808521	23110	Economy	21700.00
0005434505177	16688	Economy	6900.00
0005434505311	16688	Economy	6900.00
0005434505314	16688	Economy	6900.00
0005434505290	16688	Economy	6900.00
0005434505312	16688	Economy	6900.00
0005434505189	16688	Economy	6900.00
0005434505266	16688	Economy	6900.00
0005434505288	16688	Economy	6900.00
0005434505315	16688	Economy	6900.00
0005434505178	16688	Economy	6900.00
0005434505267	16688	Economy	6900.00
0005434505313	16688	Economy	6900.00
0005434505190	16688	Economy	6900.00
0005433266984	2180	Economy	7700.00
0005433266991	2180	Economy	7700.00
0005433266992	2180	Economy	7000.00
0005433266989	2180	Economy	7000.00
0005435803350	23617	Economy	9800.00
0005434989097	23617	Economy	9800.00
0005434989061	23617	Economy	9800.00
0005434989089	23617	Economy	9800.00
0005434989102	23617	Economy	9800.00
0005434989062	23617	Economy	9800.00
0005434989124	23617	Economy	9800.00
0005434989085	23617	Economy	9800.00
0005434989060	23617	Economy	9800.00
0005434989096	23617	Economy	9800.00
0005434989101	23617	Economy	9800.00
0005434989098	23617	Economy	9800.00
0005434989104	23617	Economy	9800.00
0005434989041	23617	Economy	9800.00
0005434989110	23617	Economy	9800.00
0005434989076	23617	Economy	9800.00
0005434989033	23617	Economy	9800.00
0005434989115	23617	Economy	9800.00
0005432384316	31325	Business	9900.00
0005432384319	31325	Business	9900.00
0005432384324	31325	Economy	3300.00
0005432384183	31325	Economy	3300.00
0005432384318	31325	Economy	3600.00
0005432384242	31325	Economy	3300.00
0005432384254	31325	Economy	3300.00
0005432384317	31325	Economy	3300.00
0005433450557	31325	Economy	3300.00
0005433450580	31325	Economy	3300.00
0005433450603	31325	Economy	3300.00
0005432384299	31325	Economy	3300.00
0005433450602	31325	Economy	3300.00
0005432384182	31325	Economy	3300.00
0005433450605	31325	Economy	3300.00
0005433450597	31325	Economy	3300.00
0005432384284	31325	Economy	3300.00
0005432384251	31325	Economy	3300.00
0005432384295	31325	Economy	3300.00
0005435304272	10767	Economy	17100.00
0005433126971	10767	Economy	17100.00
0005433126981	10767	Economy	15600.00
0005433126980	10767	Economy	15600.00
0005435304273	10767	Economy	15600.00
0005433131839	10767	Economy	15600.00
0005435299922	10767	Economy	15600.00
0005433126963	10767	Economy	15600.00
0005433131840	10767	Economy	15600.00
0005435299921	10767	Economy	15600.00
0005433110386	2388	Economy	15700.00
0005434300242	26867	Economy	17200.00
0005434300235	26867	Economy	15700.00
0005434287943	26867	Economy	15700.00
0005434300258	26867	Economy	15700.00
0005434300236	26867	Economy	15700.00
0005434300243	26867	Economy	15700.00
0005434287944	26867	Economy	15700.00
0005434287902	26867	Economy	15700.00
0005434300259	26867	Economy	15700.00
0005434287942	26867	Economy	15700.00
0005434287928	26867	Economy	15700.00
0005434300246	26867	Economy	15700.00
0005434287938	26867	Economy	15700.00
0005434300253	26867	Economy	15700.00
0005434272237	25443	Economy	25000.00
0005434272238	25443	Economy	25000.00
0005434269164	25443	Economy	22800.00
0005434269160	25443	Economy	22800.00
0005434272236	25443	Economy	22800.00
0005434269163	25443	Economy	22800.00
0005435983707	26675	Economy	22800.00
0005435856330	26675	Economy	22800.00
0005435856328	26675	Economy	22800.00
0005435983718	26675	Economy	22800.00
0005435983705	26675	Economy	22800.00
0005435854084	26675	Economy	22800.00
0005435983708	26675	Economy	22800.00
0005435983704	26675	Economy	22800.00
0005435983706	26675	Economy	22800.00
0005435856329	26675	Economy	22800.00
0005435860620	4812	Economy	17600.00
0005435860633	4812	Economy	17600.00
0005435860632	4812	Economy	17600.00
0005435860634	4812	Economy	17600.00
0005435860621	4812	Economy	17600.00
0005433869466	32590	Economy	19400.00
0005433869589	32590	Economy	17600.00
0005433869571	32590	Economy	17600.00
0005433869590	32590	Economy	17600.00
0005433869568	32590	Economy	17600.00
0005433869570	32590	Economy	17600.00
0005434663803	12472	Economy	22600.00
0005433869589	14516	Economy	16800.00
0005433869570	14516	Economy	16800.00
0005433869466	14516	Economy	16800.00
0005433869590	14516	Economy	16800.00
0005433869571	14516	Economy	16800.00
0005433869568	14516	Economy	16800.00
0005435860628	32666	Economy	18500.00
0005435860615	32666	Economy	16800.00
0005435860630	32666	Economy	16800.00
0005435860627	32666	Economy	16800.00
0005432800271	12110	Economy	4400.00
0005432800272	12110	Economy	4400.00
0005432800270	12110	Economy	4400.00
0005432800279	12110	Economy	4400.00
0005432800269	12110	Economy	4400.00
0005432800288	12110	Economy	4400.00
0005435311536	7060	Economy	16400.00
0005435311555	7060	Economy	16400.00
0005435311490	7060	Economy	16400.00
0005435293614	7060	Economy	16400.00
0005435293615	7060	Economy	16400.00
0005435311531	7060	Economy	16400.00
0005435311556	7060	Economy	16400.00
0005435311543	7060	Economy	16400.00
0005435293573	7060	Economy	16400.00
0005435293572	7060	Economy	16400.00
0005435311520	7060	Economy	16400.00
0005435311489	7060	Economy	16400.00
0005435311554	7060	Economy	16400.00
0005434409575	26940	Business	49100.00
0005434409409	26940	Business	49100.00
0005434409564	26940	Business	49100.00
0005434409408	26940	Business	49100.00
0005434409502	26940	Economy	16400.00
0005434409383	26940	Economy	16400.00
0005434409604	26940	Economy	16400.00
0005434409465	26940	Economy	16400.00
0005434409474	26940	Economy	16400.00
0005434409576	26940	Economy	16400.00
0005434409566	26940	Economy	16400.00
0005434409532	26940	Economy	16400.00
0005434409578	26940	Economy	16400.00
0005434409503	26940	Economy	16400.00
0005434409603	26940	Economy	16400.00
0005434409612	26940	Economy	16400.00
0005434409535	26940	Economy	16400.00
0005434409562	26940	Economy	16400.00
0005434409561	26940	Economy	16400.00
0005434409606	26940	Economy	16400.00
0005434409563	26940	Economy	16400.00
0005434409574	26940	Economy	16400.00
0005434409565	26940	Economy	16400.00
0005435312909	6459	Economy	15000.00
0005432605481	21387	Economy	16500.00
0005432605422	21387	Economy	16500.00
0005432605347	21387	Economy	15000.00
0005432605413	21387	Economy	15000.00
0005432605505	21387	Economy	15000.00
0005432605495	21387	Economy	15000.00
0005432605512	21387	Economy	15000.00
0005432605486	21387	Economy	15000.00
0005432605467	21387	Economy	15000.00
0005432605468	21387	Economy	15000.00
0005432605451	21387	Economy	15000.00
0005432605482	21387	Economy	15000.00
0005432605484	21387	Economy	15000.00
0005432605510	21387	Economy	15000.00
0005432605491	21387	Economy	15000.00
0005432605511	21387	Economy	15000.00
0005434908904	15023	Business	18900.00
0005434908792	15023	Business	18900.00
0005434908900	15023	Economy	6300.00
0005434908745	15023	Economy	6300.00
0005434908857	15023	Economy	6900.00
0005434908783	15023	Economy	6300.00
0005434908791	15023	Economy	6300.00
0005434908507	15023	Economy	6300.00
0005434908881	15023	Economy	6300.00
0005434908751	15023	Economy	6300.00
0005434908822	15023	Economy	6300.00
0005434908786	15023	Economy	6300.00
0005434908836	15023	Economy	6300.00
0005434908748	15023	Economy	6300.00
0005434908814	15023	Economy	6300.00
0005434908901	15023	Economy	6300.00
0005434908712	15023	Economy	6300.00
0005434908826	15023	Economy	6300.00
0005433252356	25851	Business	18900.00
0005433252379	25851	Economy	6900.00
0005433252373	25851	Economy	6300.00
0005433252374	25851	Economy	6300.00
0005433252385	25851	Economy	6300.00
0005433252378	25851	Economy	6300.00
0005433252387	25851	Economy	6300.00
0005433252360	25851	Economy	6300.00
0005433810723	14177	Business	52300.00
0005433810760	14177	Economy	17400.00
0005433810804	14177	Economy	19200.00
0005433810793	14177	Economy	17400.00
0005433810807	14177	Economy	17400.00
0005433810786	14177	Economy	17400.00
0005433810753	14177	Economy	17400.00
0005433810767	14177	Economy	17400.00
0005433810779	14177	Economy	17400.00
0005433810780	14177	Economy	17400.00
0005433810722	14177	Economy	17400.00
0005433810773	14177	Economy	17400.00
0005433810795	14177	Economy	17400.00
0005433810791	14177	Economy	17400.00
0005433810796	14177	Economy	17400.00
0005433810808	14177	Economy	17400.00
0005433810752	14177	Economy	17400.00
0005433810785	14177	Economy	17400.00
0005433810794	14177	Economy	17400.00
0005433810798	14177	Economy	17400.00
0005433009918	22876	Economy	17400.00
0005433009974	22876	Economy	17400.00
0005433009932	22876	Economy	19200.00
0005433009895	22876	Economy	19200.00
0005433009917	22876	Economy	17400.00
0005433009973	22876	Economy	17400.00
0005433009975	22876	Economy	17400.00
0005433009955	22876	Economy	17400.00
0005433009961	22876	Economy	17400.00
0005433009829	22876	Economy	17400.00
0005433009947	22876	Economy	17400.00
0005433009948	22876	Economy	17400.00
0005433009889	22876	Economy	17400.00
0005433009828	22876	Economy	17400.00
0005434926797	14943	Business	22900.00
0005434926688	14943	Business	22900.00
0005434926759	14943	Business	22900.00
0005434926741	14943	Business	22900.00
0005434926832	14943	Economy	7600.00
0005434926844	14943	Economy	7600.00
0005434926845	14943	Economy	7600.00
0005434926823	14943	Economy	7600.00
0005434926825	14943	Economy	8400.00
0005434926760	14943	Economy	7600.00
0005434926753	14943	Economy	7600.00
0005434926847	14943	Economy	7600.00
0005434926629	14943	Economy	7600.00
0005434926824	14943	Economy	7600.00
0005434926828	14943	Economy	7600.00
0005434926855	14943	Economy	7600.00
0005434926754	14943	Economy	7600.00
0005434926652	14943	Economy	7600.00
0005434926810	14943	Economy	7600.00
0005434926796	14943	Economy	7600.00
0005434926755	14943	Economy	7600.00
0005434926846	14943	Economy	7600.00
0005434926653	14943	Economy	7600.00
0005434926757	14943	Economy	7600.00
0005434926816	14943	Economy	7600.00
0005434926779	14943	Economy	7600.00
0005434926617	14943	Economy	7600.00
0005435999782	15805	Economy	8900.00
0005435999871	15805	Economy	8100.00
0005435999781	15805	Economy	8100.00
0005435999799	15805	Economy	8100.00
0005435999862	15805	Economy	8100.00
0005435999848	15805	Economy	8100.00
0005435488428	19716	Economy	8900.00
0005435488424	19716	Economy	8900.00
0005435488366	19716	Economy	8100.00
0005435488367	19716	Economy	8100.00
0005435488425	19716	Economy	8100.00
0005435488475	19716	Economy	8100.00
0005435488434	19716	Economy	8100.00
0005435488474	19716	Economy	8100.00
0005435488391	19716	Economy	8100.00
0005435473295	6029	Business	199300.00
0005435473288	6029	Economy	66400.00
0005435473290	6029	Economy	66400.00
0005432537117	6029	Economy	66400.00
0005435473289	6029	Economy	66400.00
0005432537116	6029	Economy	66400.00
0005435473293	6029	Economy	66400.00
0005435473294	6029	Economy	66400.00
0005435840275	18087	Business	199300.00
0005435840270	18087	Economy	66400.00
0005435840269	18087	Economy	66400.00
0005435840235	18087	Economy	66400.00
0005432660874	18087	Economy	66400.00
0005433286219	23024	Economy	5200.00
0005433286228	23024	Economy	5200.00
0005433286116	23024	Economy	5200.00
0005433286195	23024	Economy	5200.00
0005433286143	23024	Economy	5200.00
0005433286212	23024	Economy	5200.00
0005435104341	32099	Business	15700.00
0005435104340	32099	Business	15700.00
0005435104374	32099	Business	15700.00
0005435104337	32099	Economy	5200.00
0005435104254	32099	Economy	5200.00
0005435104365	32099	Economy	5200.00
0005435104293	32099	Economy	5200.00
0005435097517	32099	Economy	5200.00
0005435104356	32099	Economy	5200.00
0005435097516	32099	Economy	5200.00
0005435097505	32099	Economy	5700.00
0005435104256	32099	Economy	5200.00
0005435104377	32099	Economy	5200.00
0005435104366	32099	Economy	5200.00
0005435104344	32099	Economy	5200.00
0005435104357	32099	Economy	5200.00
0005435104336	32099	Economy	5200.00
0005435097506	32099	Economy	5200.00
0005435104207	32099	Economy	5200.00
0005435104255	32099	Economy	5200.00
0005435097512	32099	Economy	5200.00
0005433112413	1476	Business	150400.00
0005433112416	1476	Business	150400.00
0005432892816	1476	Business	150400.00
0005433112417	1476	Business	150400.00
0005433112411	1476	Economy	50100.00
0005432892815	1476	Economy	50100.00
0005433112415	1476	Economy	55200.00
0005433112414	1476	Economy	50100.00
0005433112418	1476	Economy	50100.00
0005432892817	1476	Economy	50100.00
0005433112408	1476	Economy	50100.00
0005433112409	1476	Economy	50100.00
0005433112412	1476	Economy	50100.00
0005433112410	1476	Economy	50100.00
0005432892818	1476	Economy	50100.00
0005433475830	23865	Economy	12300.00
0005433475829	23865	Economy	12300.00
0005433475828	23865	Economy	12300.00
0005433475835	23865	Economy	12300.00
0005433475817	23865	Economy	12300.00
0005434069589	30601	Business	42100.00
0005434069587	30601	Business	42100.00
0005434069444	30601	Business	42100.00
0005434069633	30601	Business	42100.00
0005434069649	30601	Comfort	23900.00
0005434069525	30601	Comfort	23900.00
0005432531838	30601	Comfort	23900.00
0005434069504	30601	Comfort	23900.00
0005434069432	30601	Comfort	23900.00
0005434069563	30601	Economy	14000.00
0005432531814	30601	Economy	14000.00
0005432531800	30601	Economy	14000.00
0005432531717	30601	Economy	14000.00
0005432533376	30601	Economy	14000.00
0005432531698	30601	Economy	14000.00
0005432531776	30601	Economy	14000.00
0005434069576	30601	Economy	14000.00
0005432531792	30601	Economy	14000.00
0005432531839	30601	Economy	14000.00
0005434069609	30601	Economy	14000.00
0005432531808	30601	Economy	14000.00
0005434069583	30601	Economy	14000.00
0005432531807	30601	Economy	14000.00
0005432537123	30601	Economy	14000.00
0005434069636	30601	Economy	15400.00
0005434069528	30601	Economy	14000.00
0005434069349	30601	Economy	14000.00
0005432531793	30601	Economy	14000.00
0005432531827	30601	Economy	14000.00
0005432531841	30601	Economy	14000.00
0005434069630	30601	Economy	14000.00
0005432531771	30601	Economy	14000.00
0005432531726	30601	Economy	14000.00
0005432531788	30601	Economy	14000.00
0005434069590	30601	Economy	14000.00
0005434069582	30601	Economy	14000.00
0005432531149	30601	Economy	14000.00
0005432531697	30601	Economy	14000.00
0005432531733	30601	Economy	14000.00
0005432531813	30601	Economy	14000.00
0005432531150	30601	Economy	14000.00
0005432531693	30601	Economy	14000.00
0005434069348	30601	Economy	14000.00
0005434069431	30601	Economy	14000.00
0005434069433	30601	Economy	14000.00
0005432531727	30601	Economy	14000.00
0005432531799	30601	Economy	14000.00
0005432531448	30601	Economy	14000.00
0005434069553	30601	Economy	14000.00
0005432531812	30601	Economy	14000.00
0005432531474	30601	Economy	14000.00
0005432531143	30601	Economy	14000.00
0005432531840	30601	Economy	14000.00
0005435654462	24818	Business	9800.00
0005435654463	24818	Economy	3300.00
0005435654478	24818	Economy	3300.00
0005435654429	24818	Economy	3600.00
0005435654461	24818	Economy	3600.00
0005435654322	24818	Economy	3300.00
0005435654389	24818	Economy	3300.00
0005435654495	24818	Economy	3300.00
0005435654447	24818	Economy	3300.00
0005435654441	24818	Economy	3300.00
0005435654448	24818	Economy	3300.00
0005435654412	24818	Economy	3300.00
0005435654388	24818	Economy	3300.00
0005435654479	24818	Economy	3300.00
0005435654440	24818	Economy	3300.00
0005435654387	24818	Economy	3300.00
0005435654421	24818	Economy	3300.00
0005435654284	24818	Economy	3300.00
0005435654406	24818	Economy	3300.00
0005435654446	24818	Economy	3300.00
0005435654409	24818	Economy	3300.00
0005435654400	24818	Economy	3300.00
0005434980626	23528	Economy	10500.00
0005434980584	23528	Economy	9500.00
0005434980608	23528	Economy	9500.00
0005434980638	23528	Economy	9500.00
0005434980609	23528	Economy	9500.00
0005434980542	23528	Economy	9500.00
0005434980671	23528	Economy	9500.00
0005434980672	23528	Economy	9500.00
0005434980617	23528	Economy	9500.00
0005433256494	2556	Economy	5300.00
0005433256492	2556	Economy	5300.00
0005433256493	2556	Economy	5300.00
0005434302908	19816	Economy	8700.00
0005434302909	19816	Economy	8700.00
0005433112414	20074	Economy	8700.00
0005433112418	20074	Economy	8700.00
0005433112412	20074	Economy	8700.00
0005433112416	20074	Economy	8700.00
0005433112411	20074	Economy	8700.00
0005433112410	20074	Economy	8700.00
0005433112409	20074	Economy	8700.00
0005433112413	20074	Economy	8700.00
0005433112408	20074	Economy	8700.00
0005433112417	20074	Economy	8700.00
0005433112415	20074	Economy	8700.00
0005434140591	11935	Business	9700.00
0005434140362	11935	Business	9700.00
0005434140618	11935	Economy	3200.00
0005434140619	11935	Economy	3200.00
0005434140557	11935	Economy	3200.00
0005434140141	11935	Economy	3200.00
0005434140389	11935	Economy	3200.00
0005434140592	11935	Economy	3200.00
0005434140361	11935	Economy	3200.00
0005435283579	28727	Business	9700.00
0005433539098	25047	Economy	9900.00
0005433539099	25047	Economy	9900.00
0005433539100	25047	Economy	9900.00
0005433539124	25047	Economy	9900.00
0005432922638	799	Economy	14600.00
0005433512190	16160	Economy	14600.00
0005433512189	16160	Economy	14600.00
0005435698168	16310	Economy	7200.00
0005435698082	16310	Economy	7200.00
0005435698092	16310	Economy	7200.00
0005435698081	16310	Economy	7200.00
0005435698157	16310	Economy	7200.00
0005435698167	16310	Economy	7200.00
0005435698108	16310	Economy	7200.00
0005434606938	22048	Economy	19300.00
0005434603026	22048	Economy	19300.00
0005434603027	22048	Economy	19300.00
0005435133198	33086	Economy	5400.00
0005435133199	33086	Economy	5400.00
0005435133200	33086	Economy	5400.00
0005432398300	18480	Economy	4900.00
0005432866209	2253	Economy	29100.00
0005434191328	9759	Economy	4400.00
0005435380444	6529	Business	48400.00
0005435312888	6529	Economy	16100.00
0005435312889	6529	Economy	16100.00
0005434505189	22643	Business	48400.00
0005434505311	22643	Business	48400.00
0005434505312	22643	Business	48400.00
0005435104357	22643	Economy	16100.00
0005435104365	22643	Economy	16100.00
0005435104341	22643	Economy	16100.00
0005435104344	22643	Economy	16100.00
0005435104337	22643	Economy	16100.00
0005435104293	22643	Economy	17800.00
0005435104256	22643	Economy	17800.00
0005434505190	22643	Economy	16100.00
0005435104207	22643	Economy	16100.00
0005434505266	22643	Economy	16100.00
0005435104374	22643	Economy	16100.00
0005434505267	22643	Economy	16100.00
0005435104377	22643	Economy	16100.00
0005434505288	22643	Economy	16100.00
0005434505178	22643	Economy	16100.00
0005434505177	22643	Economy	16100.00
0005435104366	22643	Economy	16100.00
0005434505313	22643	Economy	16100.00
0005434505290	22643	Economy	16100.00
0005435104356	22643	Economy	16100.00
0005434505314	22643	Economy	16100.00
0005434505315	22643	Economy	16100.00
0005435104254	22643	Economy	16100.00
0005435104340	22643	Economy	16100.00
0005435104336	22643	Economy	16100.00
0005435104255	22643	Economy	16100.00
0005433368954	1673	Economy	16700.00
0005433368915	1673	Economy	16700.00
0005433368960	1673	Economy	16700.00
0005433368937	1673	Economy	16700.00
0005433368955	1673	Economy	16700.00
0005433368969	1673	Economy	16700.00
0005433368956	1673	Economy	16700.00
0005435654409	21700	Business	50000.00
0005435654400	21700	Economy	16700.00
0005435654284	21700	Economy	16700.00
0005435654322	21700	Economy	16700.00
0005435654461	21700	Economy	16700.00
0005435654421	21700	Economy	16700.00
0005435654478	21700	Economy	16700.00
0005435654429	21700	Economy	16700.00
0005435654479	21700	Economy	16700.00
0005435654495	21700	Economy	16700.00
0005435654388	21700	Economy	16700.00
0005435654440	21700	Economy	16700.00
0005435654406	21700	Economy	16700.00
0005435654387	21700	Economy	16700.00
0005435654441	21700	Economy	16700.00
0005435654448	21700	Economy	16700.00
0005435654412	21700	Economy	16700.00
0005435654447	21700	Economy	16700.00
0005435654389	21700	Economy	16700.00
0005435654462	21700	Economy	16700.00
0005435654446	21700	Economy	16700.00
0005435654463	21700	Economy	16700.00
0005434466606	23220	Economy	20900.00
0005434466608	23220	Economy	20900.00
0005434466603	23220	Economy	20900.00
0005434466609	23220	Economy	20900.00
0005434466604	23220	Economy	20900.00
0005434466607	23220	Economy	20900.00
0005434466611	23220	Economy	20900.00
0005434466584	23220	Economy	20900.00
0005434466605	23220	Economy	20900.00
0005433987302	25680	Economy	7200.00
0005433987330	25680	Economy	7900.00
0005433987253	25680	Economy	7200.00
0005433987373	25680	Economy	7200.00
0005433987252	25680	Economy	7200.00
0005433987300	25680	Economy	7200.00
0005434509377	21338	Economy	15500.00
0005434509376	21338	Economy	15500.00
0005432658654	17854	Business	18000.00
0005432664202	17854	Business	18000.00
0005432661977	17854	Economy	6000.00
0005432661990	17854	Economy	6000.00
0005432664201	17854	Economy	6000.00
0005432661976	17854	Economy	6000.00
0005432661989	17854	Economy	6000.00
0005432658655	17854	Economy	6000.00
0005432869718	26279	Economy	6000.00
0005432869703	26279	Economy	6000.00
0005432869717	26279	Economy	6000.00
0005434151796	26279	Economy	6000.00
0005432905288	3084	Economy	5400.00
0005432848912	3084	Economy	5400.00
0005432848917	3084	Economy	5400.00
0005432848911	3084	Economy	5400.00
0005432848925	3084	Economy	5400.00
0005432848921	3084	Economy	5400.00
0005432848923	3084	Economy	5400.00
0005432848924	3084	Economy	5400.00
0005432848922	3084	Economy	5400.00
0005433439103	31157	Business	16100.00
0005432330009	31157	Business	16100.00
0005433439079	31157	Business	16100.00
0005432329967	31157	Economy	5400.00
0005432329998	31157	Economy	5900.00
0005433439114	31157	Economy	5400.00
0005432330063	31157	Economy	5400.00
0005432329966	31157	Economy	5400.00
0005433439098	31157	Economy	5400.00
0005432330034	31157	Economy	5400.00
0005432330054	31157	Economy	5400.00
0005432329997	31157	Economy	5400.00
0005432330055	31157	Economy	5400.00
0005432329996	31157	Economy	5400.00
0005432330037	31157	Economy	5400.00
0005433439115	31157	Economy	5400.00
0005433439110	31157	Economy	5400.00
0005432329951	31157	Economy	5400.00
0005435297251	6208	Business	124600.00
0005435297257	6208	Economy	41500.00
0005435488430	6208	Economy	45700.00
0005435488473	6208	Economy	41500.00
0005435297250	6208	Economy	41500.00
0005435999848	19568	Economy	41500.00
0005435999862	19568	Economy	41500.00
0005435999799	19568	Economy	41500.00
0005434310149	19568	Economy	45700.00
0005435999782	19568	Economy	41500.00
0005435999781	19568	Economy	41500.00
0005434310148	19568	Economy	41500.00
0005435529896	20854	Business	86000.00
0005434566311	20854	Business	86000.00
0005435529880	20854	Business	86000.00
0005435529890	20854	Business	86000.00
0005435545969	20854	Business	86000.00
0005435529862	20854	Economy	28700.00
0005435545961	20854	Economy	31500.00
0005435529888	20854	Economy	31500.00
0005435545967	20854	Economy	31500.00
0005435529897	20854	Economy	28700.00
0005435502962	20854	Economy	28700.00
0005435529851	20854	Economy	28700.00
0005435529889	20854	Economy	28700.00
0005435529891	20854	Economy	28700.00
0005435545970	20854	Economy	28700.00
0005435502929	20854	Economy	28700.00
0005435502961	20854	Economy	28700.00
0005435545953	20854	Economy	28700.00
0005434566310	20854	Economy	28700.00
0005435545971	20854	Economy	28700.00
0005435545962	20854	Economy	28700.00
0005435529861	20854	Economy	28700.00
0005435502943	20854	Economy	28700.00
0005435529893	20854	Economy	28700.00
0005435502912	20854	Economy	28700.00
0005435545958	20854	Economy	28700.00
0005435529892	20854	Economy	28700.00
0005435529859	20854	Economy	28700.00
0005435529860	20854	Economy	28700.00
0005435545952	20854	Economy	28700.00
0005432629291	28118	Economy	13000.00
0005432629290	28118	Economy	13000.00
0005432629289	28118	Economy	13000.00
0005434268062	8742	Economy	10500.00
0005434268060	8742	Economy	10500.00
0005434268059	8742	Economy	10500.00
0005435960167	15257	Economy	11500.00
0005435960166	15257	Economy	10500.00
0005432873500	1164	Business	115000.00
0005432873501	1164	Economy	38300.00
0005432693907	17465	Economy	38300.00
0005432675585	17465	Economy	42200.00
0005432675586	17465	Economy	38300.00
0005432675575	17465	Economy	38300.00
0005432693908	17465	Economy	38300.00
0005432677690	17465	Economy	38300.00
0005432693946	17465	Economy	38300.00
0005432693956	17465	Economy	38300.00
0005432693955	17465	Economy	38300.00
0005432693945	17465	Economy	38300.00
0005434435631	17332	Economy	13900.00
0005434435632	17332	Economy	13900.00
0005435928284	4091	Economy	7500.00
0005435087059	24404	Economy	7500.00
0005433373798	2441	Business	86800.00
0005433373792	2441	Economy	31800.00
0005433373802	2441	Economy	28900.00
0005433373803	2441	Economy	28900.00
0005433373788	2441	Economy	28900.00
0005433373797	2441	Economy	28900.00
0005433373793	2441	Economy	28900.00
0005433373789	2441	Economy	28900.00
0005433373794	2441	Economy	28900.00
0005433373804	2441	Economy	28900.00
0005433373750	2441	Economy	28900.00
0005433373749	2441	Economy	28900.00
0005435706846	27034	Business	86800.00
0005435706862	27034	Economy	28900.00
0005435706803	27034	Economy	28900.00
0005435706865	27034	Economy	28900.00
0005435706866	27034	Economy	28900.00
0005435706844	27034	Economy	28900.00
0005435706861	27034	Economy	28900.00
0005435706845	27034	Economy	28900.00
0005435706868	27034	Economy	28900.00
0005435706802	27034	Economy	28900.00
0005435706829	27034	Economy	28900.00
0005433194983	4869	Economy	14700.00
0005433194995	4869	Economy	14700.00
0005433194952	4869	Economy	14700.00
0005433195004	4869	Economy	14700.00
0005433194994	4869	Economy	14700.00
0005433194985	4869	Economy	14700.00
0005433194953	4869	Economy	14700.00
0005433194975	4869	Economy	14700.00
0005433194984	4869	Economy	14700.00
0005434626231	32926	Economy	14700.00
0005434626230	32926	Economy	14700.00
0005435786340	13782	Economy	3100.00
0005435786360	13782	Economy	3100.00
0005435786291	13782	Economy	3100.00
0005435786332	13782	Economy	3100.00
0005435786359	13782	Economy	3100.00
0005435786299	13782	Economy	3100.00
0005435787413	13782	Economy	3100.00
0005435786358	13782	Economy	3100.00
0005435786331	13782	Economy	3100.00
0005435786361	13782	Economy	3100.00
0005435786333	13782	Economy	3100.00
0005435786184	13782	Economy	3100.00
0005435937559	27395	Economy	3400.00
0005435937573	27395	Economy	3100.00
0005435937558	27395	Economy	3100.00
0005435937571	27395	Economy	3100.00
0005434409594	20284	Economy	4000.00
0005434409602	20284	Economy	4000.00
0005434409605	20284	Economy	4000.00
0005434409595	20284	Economy	4000.00
0005435311549	27005	Economy	4000.00
0005435311469	27005	Economy	4000.00
0005433124549	5682	Economy	14400.00
0005433124517	5682	Economy	15900.00
0005433124540	5682	Economy	14400.00
0005433124528	5682	Economy	14400.00
0005433124516	5682	Economy	14400.00
0005433124551	5682	Economy	14400.00
0005433124537	5682	Economy	14400.00
0005434311279	15699	Business	43300.00
0005434310163	15699	Economy	14400.00
0005434319854	15699	Economy	15900.00
0005434311280	15699	Economy	14400.00
0005434310183	15699	Economy	14400.00
0005434319868	15699	Economy	14400.00
0005434310181	15699	Economy	14400.00
0005434319789	15699	Economy	14400.00
0005434189346	8962	Economy	24900.00
0005434189343	8962	Economy	24900.00
0005434189345	8962	Economy	24900.00
0005434189342	8962	Economy	24900.00
0005435477024	7542	Business	11100.00
0005433722418	7542	Economy	3700.00
0005434310183	7542	Economy	3700.00
0005433722456	7542	Economy	3700.00
0005433722452	7542	Economy	4100.00
0005433722453	7542	Economy	3700.00
0005433722444	7542	Economy	3700.00
0005433722416	7542	Economy	3700.00
0005433722417	7542	Economy	3700.00
0005433722437	7542	Economy	3700.00
0005433722448	7542	Economy	3700.00
0005433722488	7542	Economy	3700.00
0005433722508	7542	Economy	3700.00
0005433722512	7542	Economy	3700.00
0005435477025	7542	Economy	3700.00
0005433722455	7542	Economy	3700.00
0005434310181	7542	Economy	3700.00
0005433722438	7542	Economy	3700.00
0005434310163	7542	Economy	3700.00
0005433722507	7542	Economy	3700.00
0005433450600	30407	Business	11100.00
0005432693955	30407	Business	11100.00
0005432693956	30407	Business	11100.00
0005432693945	30407	Economy	3700.00
0005432693946	30407	Economy	3700.00
0005432693908	30407	Economy	3700.00
0005433450563	30407	Economy	3700.00
0005433450604	30407	Economy	3700.00
0005433450506	30407	Economy	3700.00
0005432693907	30407	Economy	3700.00
0005433450611	30407	Economy	3700.00
0005433450505	30407	Economy	3700.00
0005433124540	30408	Economy	4100.00
0005432721663	30408	Economy	4100.00
0005432721652	30408	Economy	3700.00
0005433124517	30408	Economy	3700.00
0005432721678	30408	Economy	3700.00
0005432721651	30408	Economy	3700.00
0005433124549	30408	Economy	3700.00
0005433124537	30408	Economy	3700.00
0005433124551	30408	Economy	3700.00
0005433124528	30408	Economy	3700.00
0005433124516	30408	Economy	3700.00
0005432721684	30408	Economy	3700.00
0005432928149	1363	Economy	25800.00
0005434345269	29780	Economy	4000.00
0005434345277	29780	Economy	4000.00
0005434345142	29780	Economy	4000.00
0005434345278	29780	Economy	4000.00
0005434345141	29780	Economy	4000.00
0005434345276	29780	Economy	4000.00
0005434345214	29780	Economy	4000.00
0005434345286	29780	Economy	4000.00
0005434345270	29780	Economy	4000.00
0005435825397	18019	Economy	66600.00
0005435825421	18019	Economy	66600.00
0005435825395	18019	Economy	66600.00
0005435825424	18019	Economy	66600.00
0005435825392	18019	Economy	66600.00
0005435243628	5611	Business	27800.00
0005435243658	5611	Economy	9300.00
0005435243646	5611	Economy	9300.00
0005435243648	5611	Economy	9300.00
0005435243647	5611	Economy	9300.00
0005435950042	15386	Economy	9300.00
0005432785361	15386	Economy	9300.00
0005432785326	15386	Economy	10200.00
0005435950044	15386	Economy	9300.00
0005432785290	15386	Economy	9300.00
0005432785325	15386	Economy	9300.00
0005432785360	15386	Economy	9300.00
0005432785165	15386	Economy	9300.00
0005435950034	15386	Economy	9300.00
0005432785327	15386	Economy	9300.00
0005435950035	15386	Economy	9300.00
0005432785318	15386	Economy	9300.00
0005435950052	15386	Economy	9300.00
0005432785335	15386	Economy	9300.00
0005432785317	15386	Economy	9300.00
0005435851175	4339	Economy	6300.00
0005435851174	4339	Economy	6300.00
0005434461705	28860	Economy	6300.00
0005434463996	28860	Economy	6300.00
0005435257525	6236	Economy	4400.00
0005435257541	6236	Economy	4000.00
0005435257547	6236	Economy	4000.00
0005435257546	6236	Economy	4000.00
0005434926809	20355	Business	11900.00
0005434926733	20355	Business	11900.00
0005434926821	20355	Business	11900.00
0005434926851	20355	Economy	4000.00
0005433497886	20355	Economy	4000.00
0005434926856	20355	Economy	4400.00
0005434444179	20355	Economy	4400.00
0005434444165	20355	Economy	4000.00
0005434926735	20355	Economy	4000.00
0005434444164	20355	Economy	4000.00
0005434926808	20355	Economy	4000.00
0005434444152	20355	Economy	4000.00
0005434444153	20355	Economy	4000.00
0005434926863	20355	Economy	4000.00
0005434926732	20355	Economy	4000.00
0005432785359	12182	Economy	13700.00
0005432785297	12182	Economy	13700.00
0005432785300	12182	Economy	15100.00
0005432785366	12182	Economy	13700.00
0005432785356	12182	Economy	13700.00
0005435243620	15405	Business	41200.00
0005435243626	15405	Economy	13700.00
0005435243663	15405	Economy	13700.00
0005435243603	15405	Economy	15100.00
0005435243661	15405	Economy	13700.00
0005435243536	15405	Economy	13700.00
0005435243602	15405	Economy	13700.00
0005435243601	15405	Economy	13700.00
0005435243666	15405	Economy	13700.00
0005435243636	15405	Economy	13700.00
0005435243665	15405	Economy	13700.00
0005435243639	15405	Economy	13700.00
0005435243662	15405	Economy	13700.00
0005435243652	15405	Economy	13700.00
0005435243635	15405	Economy	13700.00
0005435243664	15405	Economy	13700.00
0005435243651	15405	Economy	13700.00
0005435243572	15405	Economy	13700.00
0005435243630	15405	Economy	13700.00
0005434880969	10104	Business	49700.00
0005434880948	10104	Economy	16600.00
0005434880947	10104	Economy	16600.00
0005434880968	10104	Economy	16600.00
0005434880980	10104	Economy	16600.00
0005434880967	10104	Economy	16600.00
0005434880828	10104	Economy	16600.00
0005434880986	10104	Economy	16600.00
0005434880982	10104	Economy	16600.00
0005434880849	10104	Economy	16600.00
0005435914210	14648	Economy	16600.00
0005435914113	14648	Economy	18200.00
0005434252235	9244	Economy	20300.00
0005435933559	9244	Economy	20300.00
0005435660459	24654	Economy	20300.00
0005435660467	24654	Economy	20300.00
0005435660466	24654	Economy	20300.00
0005435660468	24654	Economy	20300.00
0005432967685	2813	Business	33000.00
0005432967678	2813	Economy	11000.00
0005432967654	2813	Economy	11000.00
0005432967666	2813	Economy	11000.00
0005432967684	2813	Economy	11000.00
0005432967664	2813	Economy	11000.00
0005432967665	2813	Economy	11000.00
0005433681947	29137	Economy	11000.00
0005433681961	29137	Economy	11000.00
0005433681926	29137	Economy	11000.00
0005433681959	29137	Economy	11000.00
0005433681960	29137	Economy	11000.00
0005433681948	29137	Economy	11000.00
0005434153581	9275	Business	132900.00
0005434272232	9275	Economy	44300.00
0005434272233	9275	Economy	44300.00
0005434152849	9275	Economy	44300.00
0005434152850	9275	Economy	44300.00
0005434269166	9275	Economy	44300.00
0005434153582	9275	Economy	44300.00
0005433616812	25258	Business	132900.00
0005433616791	25258	Business	132900.00
0005435983704	25258	Business	132900.00
0005435983706	25258	Business	132900.00
0005433634798	25258	Business	132900.00
0005433616804	25258	Business	132900.00
0005435983718	25258	Economy	44300.00
0005435983708	25258	Economy	44300.00
0005433578203	25258	Economy	44300.00
0005433578202	25258	Economy	44300.00
0005435983705	25258	Economy	44300.00
0005433616593	25258	Economy	44300.00
0005433616594	25258	Economy	44300.00
0005433616819	25258	Economy	44300.00
0005433616725	25258	Economy	44300.00
0005433634803	25258	Economy	44300.00
0005435983707	25258	Economy	44300.00
0005433616828	25258	Economy	44300.00
0005433578201	25258	Economy	44300.00
0005433616813	25258	Economy	44300.00
0005433578195	25258	Economy	44300.00
0005433616742	25258	Economy	44300.00
0005433634816	25258	Economy	44300.00
0005433634815	25258	Economy	44300.00
0005433578188	25258	Economy	44300.00
0005433578206	25258	Economy	44300.00
0005435477031	4220	Economy	64400.00
0005435477015	4220	Economy	64400.00
0005435947663	4220	Economy	64400.00
0005432571429	4220	Economy	64400.00
0005435477022	4220	Economy	64400.00
0005435477030	4220	Economy	64400.00
0005435787412	4220	Economy	70800.00
0005435477029	4220	Economy	64400.00
0005435947679	4220	Economy	64400.00
0005434273135	4220	Economy	64400.00
0005435477028	4220	Economy	64400.00
0005435987058	26587	Economy	70800.00
0005435960176	26587	Economy	64400.00
0005435987059	26587	Economy	64400.00
0005433075532	336	Business	21500.00
0005433075545	336	Business	21500.00
0005432949697	336	Business	21500.00
0005433129412	336	Economy	7200.00
0005432949685	336	Economy	7900.00
0005432949699	336	Economy	7200.00
0005432949635	336	Economy	7200.00
0005432949554	336	Economy	7200.00
0005434088056	11579	Business	21500.00
0005433570888	11579	Business	21500.00
0005433570874	11579	Business	21500.00
0005433570839	11579	Business	21500.00
0005433570829	11579	Business	21500.00
0005433570920	11579	Business	21500.00
0005433570868	11579	Business	21500.00
0005433570958	11579	Economy	7900.00
0005433570931	11579	Economy	7900.00
0005434087988	11579	Economy	7900.00
0005433570959	11579	Economy	7200.00
0005433570972	11579	Economy	7200.00
0005433570934	11579	Economy	7200.00
0005433570940	11579	Economy	7200.00
0005433570840	11579	Economy	7200.00
0005433570838	11579	Economy	7200.00
0005433570973	11579	Economy	7200.00
0005433570937	11579	Economy	7200.00
0005433570924	11579	Economy	7200.00
0005433570956	11579	Economy	7200.00
0005433570763	11579	Economy	7200.00
0005433570930	11579	Economy	7200.00
0005433570830	11579	Economy	7200.00
0005433570844	11579	Economy	7200.00
0005433570907	11579	Economy	7900.00
0005434088057	11579	Economy	7900.00
0005434088058	11579	Economy	7200.00
0005433570906	11579	Economy	7200.00
0005433570921	11579	Economy	7200.00
0005434326027	11579	Economy	7200.00
0005434326032	11579	Economy	7200.00
0005433570980	11579	Economy	7200.00
0005433570933	11579	Economy	7200.00
0005434326047	11579	Economy	7200.00
0005433570911	11579	Economy	7200.00
0005433570831	11579	Economy	7200.00
0005433570866	11579	Economy	7200.00
0005434087987	11579	Economy	7200.00
0005433570919	11579	Economy	7200.00
0005434087986	11579	Economy	7200.00
0005433570884	11579	Economy	7200.00
0005433570928	11579	Economy	7200.00
0005433435490	2374	Business	184500.00
0005433435466	2374	Economy	61500.00
0005433435503	2374	Economy	61500.00
0005433435480	2374	Economy	61500.00
0005433435489	2374	Economy	61500.00
0005433435479	2374	Economy	61500.00
0005432986013	2374	Economy	61500.00
0005432986012	2374	Economy	61500.00
0005432985943	2374	Economy	61500.00
0005433435478	2374	Economy	61500.00
0005433435508	2374	Economy	61500.00
0005434731291	2374	Economy	61500.00
0005433435502	2374	Economy	61500.00
0005433435465	2374	Economy	61500.00
0005432985993	2374	Economy	61500.00
0005433435470	2374	Economy	61500.00
0005432869720	2374	Economy	61500.00
0005435983672	26196	Business	184500.00
0005432655872	26196	Business	184500.00
0005432655871	26196	Business	184500.00
0005433766768	26196	Business	184500.00
0005435983597	26196	Business	184500.00
0005435983659	26196	Economy	67700.00
0005432655878	26196	Economy	61500.00
0005433755867	26196	Economy	61500.00
0005433755861	26196	Economy	61500.00
0005433755836	26196	Economy	61500.00
0005433755822	26196	Economy	61500.00
0005433755832	26196	Economy	61500.00
0005435983671	26196	Economy	61500.00
0005432655877	26196	Economy	61500.00
0005435983635	26196	Economy	67700.00
0005433755863	26196	Economy	61500.00
0005435983599	26196	Economy	61500.00
0005435983593	26196	Economy	61500.00
0005435983636	26196	Economy	61500.00
0005434029730	1485	Economy	13000.00
0005434029729	1485	Economy	14300.00
0005433152382	1485	Economy	13000.00
0005433152383	1485	Economy	13000.00
0005433152410	1485	Economy	13000.00
0005433152409	1485	Economy	13000.00
0005433152408	1485	Economy	13000.00
0005434376062	20157	Business	38900.00
0005434375997	20157	Economy	13000.00
0005434375963	20157	Economy	13000.00
0005434376006	20157	Economy	13000.00
0005434376022	20157	Economy	13000.00
0005434375962	20157	Economy	13000.00
0005434376072	20157	Economy	13000.00
0005434376021	20157	Economy	13000.00
0005434376066	20157	Economy	13000.00
0005433262061	527	Economy	9200.00
0005433262050	527	Economy	9200.00
0005433262036	527	Economy	9200.00
0005434995380	12904	Economy	9200.00
0005434995375	12904	Economy	9200.00
0005434995379	12904	Economy	9200.00
0005434995374	12904	Economy	10100.00
0005432425918	12843	Business	27500.00
0005432425936	12843	Business	27500.00
0005432426039	12843	Business	27500.00
0005432426019	12843	Business	27500.00
0005432425996	12843	Business	27500.00
0005432425948	12843	Business	27500.00
0005432425585	12843	Economy	9200.00
0005432425983	12843	Economy	9200.00
0005432425758	12843	Economy	9200.00
0005432425944	12843	Economy	9200.00
0005432425997	12843	Economy	9200.00
0005432425982	12843	Economy	9200.00
0005432425943	12843	Economy	9200.00
0005432425839	12843	Economy	9200.00
0005432425951	12843	Economy	9200.00
0005432426063	12843	Economy	9200.00
0005432426060	12843	Economy	9200.00
0005432425757	12843	Economy	9200.00
0005432425935	12843	Economy	9200.00
0005432426062	12843	Economy	9200.00
0005432425919	12843	Economy	9200.00
0005432426022	12843	Economy	9200.00
0005432425875	12843	Economy	9200.00
0005432425584	12843	Economy	9200.00
0005434735841	484	Economy	8200.00
0005433929730	484	Economy	8200.00
0005434735842	484	Economy	8200.00
0005434735843	484	Economy	9000.00
0005434735844	484	Economy	8200.00
0005434376236	484	Economy	8200.00
0005433059060	484	Economy	8200.00
0005434025676	12701	Business	24500.00
0005434025540	12701	Economy	8200.00
0005434025577	12701	Economy	8200.00
0005434025541	12701	Economy	8200.00
0005434025682	12701	Economy	8200.00
0005434029729	12701	Economy	8200.00
0005434028399	12701	Economy	8200.00
0005434025657	12701	Economy	8200.00
0005434025656	12701	Economy	9000.00
0005434025576	12701	Economy	8200.00
0005434025677	12701	Economy	8200.00
0005434025678	12701	Economy	8200.00
0005434025683	12701	Economy	8200.00
0005434029730	12701	Economy	8200.00
0005434175876	2170	Business	34700.00
0005433037846	2170	Economy	11600.00
0005433037809	2170	Economy	11600.00
0005433037834	2170	Economy	11600.00
0005433037685	2170	Economy	11600.00
0005434175877	2170	Economy	11600.00
0005433037799	2170	Economy	11600.00
0005433037810	2170	Economy	11600.00
0005433037837	2170	Economy	11600.00
0005433926062	24083	Business	34700.00
0005433875431	24083	Business	34700.00
0005433926112	24083	Economy	11600.00
0005433929889	24083	Economy	11600.00
0005433926049	24083	Economy	11600.00
0005433925913	24083	Economy	11600.00
0005433925984	24083	Economy	11600.00
0005433926007	24083	Economy	11600.00
0005433929896	24083	Economy	11600.00
0005433929883	24083	Economy	11600.00
0005433926008	24083	Economy	11600.00
0005433926048	24083	Economy	11600.00
0005433929733	24083	Economy	11600.00
0005433926063	24083	Economy	11600.00
0005433925955	24083	Economy	11600.00
0005433875430	24083	Economy	11600.00
0005433925985	24083	Economy	11600.00
0005433926113	24083	Economy	11600.00
0005433929894	24083	Economy	11600.00
0005433926038	24083	Economy	11600.00
0005433929734	24083	Economy	11600.00
0005433181817	254	Business	83700.00
0005433235788	254	Comfort	47400.00
0005433236068	254	Comfort	47400.00
0005433235946	254	Economy	27900.00
0005433236051	254	Economy	27900.00
0005433235789	254	Economy	27900.00
0005433236022	254	Economy	30700.00
0005433181838	254	Economy	27900.00
0005433235941	254	Economy	27900.00
0005433236037	254	Economy	27900.00
0005433236058	254	Economy	27900.00
0005433126976	254	Economy	27900.00
0005433236038	254	Economy	27900.00
0005433235942	254	Economy	27900.00
0005433235907	254	Economy	27900.00
0005433236000	254	Economy	27900.00
0005434032158	254	Economy	27900.00
0005433236057	254	Economy	27900.00
0005433131841	254	Economy	27900.00
0005433181831	254	Economy	27900.00
0005433766751	254	Economy	27900.00
0005433235975	254	Economy	27900.00
0005433181816	254	Economy	27900.00
0005434552737	9866	Business	83700.00
0005434552849	9866	Business	83700.00
0005434729044	9866	Business	83700.00
0005434729029	9866	Business	83700.00
0005434552863	9866	Comfort	47400.00
0005434552851	9866	Comfort	47400.00
0005434731291	9866	Economy	27900.00
0005435142958	9866	Economy	27900.00
0005434552757	9866	Economy	27900.00
0005435142969	9866	Economy	27900.00
0005434729004	9866	Economy	27900.00
0005434552848	9866	Economy	27900.00
0005434729012	9866	Economy	27900.00
0005434552864	9866	Economy	30700.00
0005434552736	9866	Economy	27900.00
0005435142954	9866	Economy	27900.00
0005434552833	9866	Economy	27900.00
0005434735840	9866	Economy	27900.00
0005435142952	9866	Economy	27900.00
0005434552865	9866	Economy	27900.00
0005434552721	9866	Economy	27900.00
0005434552758	9866	Economy	27900.00
0005434552841	9866	Economy	27900.00
0005435142955	9866	Economy	27900.00
0005434552803	9866	Economy	27900.00
0005434552769	9866	Economy	27900.00
0005434552850	9866	Economy	27900.00
0005434735839	9866	Economy	27900.00
0005434552738	9866	Economy	27900.00
0005435142953	9866	Economy	27900.00
0005435142941	9866	Economy	27900.00
0005434552667	9866	Economy	27900.00
0005435142942	9866	Economy	27900.00
0005434728984	9866	Economy	27900.00
0005434729043	9866	Economy	27900.00
0005435631054	7740	Business	42100.00
0005435283509	7740	Business	42100.00
0005435283519	7740	Comfort	23900.00
0005435215501	7740	Comfort	23900.00
0005435215500	7740	Economy	14000.00
0005435283525	7740	Economy	14000.00
0005435283520	7740	Economy	14000.00
0005435215491	7740	Economy	14000.00
0005435283524	7740	Economy	14000.00
0005435631053	7740	Economy	14000.00
0005435283532	7740	Economy	14000.00
0005435215527	7740	Economy	14000.00
0005435283541	7740	Economy	14000.00
0005435215521	7740	Economy	14000.00
0005435215522	7740	Economy	14000.00
0005435215526	7740	Economy	15400.00
0005435215507	7740	Economy	14000.00
0005435215528	7740	Economy	14000.00
0005435215525	7740	Economy	14000.00
0005435283542	7740	Economy	14000.00
0005435215414	7740	Economy	14000.00
0005435215508	7740	Economy	14000.00
0005433656768	7740	Economy	14000.00
0005435215428	7740	Economy	14000.00
0005435215457	7740	Economy	14000.00
0005435426834	5363	Business	43100.00
0005435042935	5363	Business	43100.00
0005435654523	5363	Comfort	24400.00
0005435042934	5363	Comfort	24400.00
0005434245829	5363	Comfort	24400.00
0005435426847	5363	Economy	14400.00
0005435426737	5363	Economy	14400.00
0005435319825	5363	Economy	14400.00
0005435950054	5363	Economy	14400.00
0005435426835	5363	Economy	14400.00
0005435319823	5363	Economy	14400.00
0005435768122	5363	Economy	14400.00
0005435426848	5363	Economy	14400.00
0005434245830	5363	Economy	14400.00
0005435768123	5363	Economy	14400.00
0005435319824	5363	Economy	14400.00
0005434345234	10891	Business	43100.00
0005435617035	10891	Business	43100.00
0005434345228	10891	Business	43100.00
0005435616740	10891	Business	43100.00
0005435617007	10891	Business	43100.00
0005435617042	10891	Comfort	24400.00
0005435616741	10891	Comfort	24400.00
0005434573765	10891	Comfort	24400.00
0005435617055	10891	Comfort	24400.00
0005435617014	10891	Comfort	24400.00
0005434345248	10891	Comfort	24400.00
0005435551779	10891	Comfort	24400.00
0005434345262	10891	Comfort	24400.00
0005435617207	10891	Comfort	24400.00
0005435551778	10891	Comfort	24400.00
0005435617194	10891	Comfort	24400.00
0005434345291	10891	Comfort	24400.00
0005434345288	10891	Economy	14400.00
0005435617201	10891	Economy	14400.00
0005435616737	10891	Economy	14400.00
0005434345245	10891	Economy	14400.00
0005435617244	10891	Economy	14400.00
0005434345233	10891	Economy	15800.00
0005435617008	10891	Economy	14400.00
0005434573762	10891	Economy	15800.00
0005435617208	10891	Economy	14400.00
0005435546241	10891	Economy	14400.00
0005434345246	10891	Economy	14400.00
0005435616850	10891	Economy	14400.00
0005435551784	10891	Economy	14400.00
0005435556767	10891	Economy	14400.00
0005435546242	10891	Economy	14400.00
0005435616736	10891	Economy	14400.00
0005434345290	10891	Economy	14400.00
0005434345238	10891	Economy	14400.00
0005434345237	10891	Economy	14400.00
0005435617034	10891	Economy	14400.00
0005434345282	10891	Economy	14400.00
0005435097491	10891	Economy	14400.00
0005435616693	10891	Economy	15800.00
0005434573763	10891	Economy	14400.00
0005434573764	10891	Economy	14400.00
0005435097499	10891	Economy	14400.00
0005434573757	10891	Economy	14400.00
0005435551780	10891	Economy	14400.00
0005435617041	10891	Economy	14400.00
0005435617200	10891	Economy	14400.00
0005435617033	10891	Economy	14400.00
0005434345247	10891	Economy	14400.00
0005435551785	10891	Economy	14400.00
0005435556770	10891	Economy	14400.00
0005435097492	10891	Economy	14400.00
0005434345118	10891	Economy	14400.00
0005432461387	3307	Business	18800.00
0005432461381	3307	Business	18800.00
0005435860729	3307	Business	18800.00
0005435858745	3307	Business	18800.00
0005432461312	3307	Business	18800.00
0005432461412	3307	Economy	6900.00
0005434326107	3307	Economy	6300.00
0005432461216	3307	Economy	6300.00
0005432461434	3307	Economy	6300.00
0005435860709	3307	Economy	6300.00
0005432461313	3307	Economy	6300.00
0005432461421	3307	Economy	6300.00
0005432461365	3307	Economy	6300.00
0005435860728	3307	Economy	6300.00
0005435858727	3307	Economy	6300.00
0005432461430	3307	Economy	6900.00
0005435858728	3307	Economy	6300.00
0005434326063	3307	Economy	6300.00
0005432461422	3307	Economy	6300.00
0005435858744	3307	Economy	6300.00
0005435860718	3307	Economy	6300.00
0005432461330	3307	Economy	6300.00
0005434326064	3307	Economy	6300.00
0005435860731	3307	Economy	6300.00
0005432461435	3307	Economy	6300.00
0005432461391	3307	Economy	6300.00
0005432461271	3307	Economy	6300.00
0005434326095	3307	Economy	6300.00
0005435886869	3306	Business	18800.00
0005435886814	3306	Economy	6300.00
0005435886855	3306	Economy	6300.00
0005435886760	3306	Economy	6300.00
0005435933560	3306	Economy	6300.00
0005435886813	3306	Economy	6300.00
0005435886870	3306	Economy	6300.00
0005435886842	3306	Economy	6300.00
0005435886761	3306	Economy	6300.00
0005433507725	8300	Business	18800.00
0005433507724	8300	Economy	6300.00
0005433507698	8300	Economy	6300.00
0005433634798	8299	Business	18800.00
0005433634815	8299	Economy	6900.00
0005434143854	8299	Economy	6300.00
0005433634803	8299	Economy	6300.00
0005434143795	8299	Economy	6300.00
0005433806384	8299	Economy	6300.00
0005433806397	8299	Economy	6300.00
0005434143845	8299	Economy	6300.00
0005433634816	8299	Economy	6300.00
0005434266034	8294	Business	18800.00
0005434150194	8294	Business	18800.00
0005434150192	8294	Business	18800.00
0005434265983	8294	Economy	6300.00
0005434265943	8294	Economy	6300.00
0005434265951	8294	Economy	6300.00
0005434266053	8294	Economy	6300.00
0005434266049	8294	Economy	6300.00
0005434265950	8294	Economy	6300.00
0005434266050	8294	Economy	6300.00
0005434265984	8294	Economy	6300.00
0005434266031	8294	Economy	6300.00
0005434265982	8294	Economy	6300.00
0005434266052	8294	Economy	6300.00
0005434266037	8294	Economy	6900.00
0005434273135	8294	Economy	6300.00
0005434150193	8294	Economy	6300.00
0005434266030	8294	Economy	6300.00
0005434150191	8294	Economy	6300.00
0005434266048	8294	Economy	6300.00
0005434265942	8294	Economy	6300.00
0005434150203	8294	Economy	6300.00
0005433194975	30110	Business	9900.00
0005433194994	30110	Business	9900.00
0005432384299	30110	Business	9900.00
0005434300267	30110	Business	9900.00
0005433194995	30110	Economy	3300.00
0005433722500	30110	Economy	3300.00
0005435477030	30110	Economy	3300.00
0005432384254	30110	Economy	3600.00
0005432384251	30110	Economy	3600.00
0005433722413	30110	Economy	3600.00
0005433722474	30110	Economy	3300.00
0005433194983	30110	Economy	3300.00
0005433722509	30110	Economy	3300.00
0005432384284	30110	Economy	3300.00
0005435477031	30110	Economy	3300.00
0005432384317	30110	Economy	3300.00
0005434300266	30110	Economy	3300.00
0005432384316	30110	Economy	3300.00
0005432384318	30110	Economy	3300.00
0005432384183	30110	Economy	3300.00
0005432384319	30110	Economy	3300.00
0005433194984	30110	Economy	3300.00
0005433722499	30110	Economy	3300.00
0005435477015	30110	Economy	3300.00
0005432728306	30110	Economy	3300.00
0005433194985	30110	Economy	3300.00
0005433195004	30110	Economy	3300.00
0005433722421	30110	Economy	3300.00
0005433194952	30110	Economy	3300.00
0005435477028	30110	Economy	3300.00
0005432384242	30110	Economy	3300.00
0005435477029	30110	Economy	3300.00
0005433722475	30110	Economy	3300.00
0005435477022	30110	Economy	3300.00
0005432384324	30110	Economy	3300.00
0005433722436	30110	Economy	3300.00
0005433194953	30110	Economy	3300.00
0005432384182	30110	Economy	3300.00
0005432384295	30110	Economy	3300.00
0005432925175	1763	Economy	19100.00
0005435541650	22015	Business	57200.00
0005435518459	22015	Business	57200.00
0005435541645	22015	Business	57200.00
0005435518460	22015	Economy	19100.00
0005433517166	22015	Economy	19100.00
0005435541622	22015	Economy	21000.00
0005435518458	22015	Economy	19100.00
0005435518453	22015	Economy	19100.00
0005435518443	22015	Economy	19100.00
0005435546230	22015	Economy	19100.00
0005435541593	22015	Economy	19100.00
0005435518444	22015	Economy	19100.00
0005435541619	22015	Economy	19100.00
0005435546224	22015	Economy	19100.00
0005435546225	22015	Economy	19100.00
0005435541646	22015	Economy	19100.00
0005435541644	22015	Economy	19100.00
0005434665026	7391	Economy	6200.00
0005435491506	7391	Economy	6200.00
0005435253220	7391	Economy	6200.00
0005435491495	7391	Economy	6200.00
0005435491507	7391	Economy	6200.00
0005434459410	28920	Economy	6200.00
0005434459415	28920	Economy	6200.00
0005434459409	28920	Economy	6200.00
0005434459405	28920	Economy	6200.00
0005432909443	2094	Economy	13300.00
0005432909437	2094	Economy	12100.00
0005432909440	2094	Economy	12100.00
0005432909429	2094	Economy	12100.00
0005432909442	2094	Economy	12100.00
0005432909433	2094	Economy	12100.00
0005432909441	2094	Economy	12100.00
0005432909434	2094	Economy	12100.00
0005433468587	23840	Economy	13300.00
0005433468588	23840	Economy	12100.00
0005433468602	23840	Economy	12100.00
0005433468584	23840	Economy	12100.00
0005433468583	23840	Economy	12100.00
0005433468597	23840	Economy	12100.00
0005433468595	23840	Economy	12100.00
0005433468607	23840	Economy	12100.00
0005433468601	23840	Economy	12100.00
0005435177850	6361	Economy	12200.00
0005434150072	6361	Economy	13400.00
0005435723103	6361	Economy	12200.00
0005434150076	6361	Economy	12200.00
0005435177874	6361	Economy	12200.00
0005435177873	6361	Economy	12200.00
0005435723106	6361	Economy	12200.00
0005432361680	21020	Economy	12200.00
0005434459416	17729	Economy	3100.00
0005432605440	31660	Economy	7300.00
0005432605493	31660	Economy	6600.00
0005432605490	31660	Economy	6600.00
0005432605439	31660	Economy	6600.00
0005432605494	31660	Economy	6600.00
0005432605492	31660	Economy	6600.00
0005432605516	31660	Economy	6600.00
0005432605507	31660	Economy	6600.00
0005435154706	29599	Economy	19500.00
0005435154704	29599	Economy	17800.00
0005435154692	29599	Economy	17800.00
0005435154705	29599	Economy	17800.00
0005435154693	29599	Economy	17800.00
0005435154691	29599	Economy	17800.00
0005435257380	6682	Economy	12700.00
0005435257386	6682	Economy	12700.00
0005435257390	6682	Economy	12700.00
0005433473493	23886	Economy	12700.00
0005434606937	18927	Economy	6600.00
0005434606936	18927	Economy	6600.00
0005434606934	18927	Economy	6600.00
0005435904724	3841	Economy	24900.00
0005435904490	3841	Economy	22600.00
0005435904476	3841	Economy	22600.00
0005435904729	3841	Economy	22600.00
0005435904475	3841	Economy	22600.00
0005435904469	3841	Economy	22600.00
0005435904477	3841	Economy	22600.00
0005435904725	3841	Economy	22600.00
0005434602974	19053	Economy	24900.00
0005434602968	19053	Economy	22600.00
0005434522543	19053	Economy	22600.00
0005434605007	19053	Economy	22600.00
0005434522554	19053	Economy	22600.00
0005434602978	19053	Economy	22600.00
0005434602975	19053	Economy	22600.00
0005434522555	19053	Economy	22600.00
0005434605001	19053	Economy	22600.00
0005434602977	19053	Economy	22600.00
0005434602979	19053	Economy	22600.00
0005434605002	19053	Economy	22600.00
0005434602981	19053	Economy	22600.00
0005434605003	19053	Economy	22600.00
0005434604992	19053	Economy	22600.00
0005434602980	19053	Economy	22600.00
0005434522541	19053	Economy	22600.00
0005434602976	19053	Economy	22600.00
0005432891579	398	Economy	14800.00
0005432891589	398	Economy	14800.00
0005433293444	398	Economy	14800.00
0005432891595	398	Economy	14800.00
0005432891577	398	Economy	14800.00
0005432891590	398	Economy	14800.00
0005432891583	398	Economy	14800.00
0005432891582	398	Economy	14800.00
0005432891596	398	Economy	14800.00
0005433293433	398	Economy	14800.00
0005432749852	12078	Business	44500.00
0005432748682	12078	Economy	14800.00
0005432748662	12078	Economy	14800.00
0005432748602	12078	Economy	14800.00
0005432753401	12078	Economy	14800.00
0005432928148	18944	Economy	28200.00
0005432928146	18944	Economy	25700.00
0005432928147	18944	Economy	25700.00
0005432928130	18944	Economy	25700.00
0005432928145	18944	Economy	25700.00
0005433527372	32513	Economy	25700.00
0005433525357	32513	Economy	25700.00
0005433527373	32513	Economy	25700.00
0005435375173	5292	Business	84000.00
0005435375154	5292	Business	84000.00
0005435299917	5292	Economy	28000.00
0005435375156	5292	Economy	28000.00
0005435386762	5292	Economy	28000.00
0005435386760	5292	Economy	28000.00
0005435735268	5292	Economy	28000.00
0005435375091	5292	Economy	28000.00
0005435375155	5292	Economy	28000.00
0005435315120	5292	Economy	28000.00
0005435375153	5292	Economy	28000.00
0005435386763	5292	Economy	28000.00
0005435386764	5292	Economy	28000.00
0005435315119	5292	Economy	28000.00
0005435662013	5292	Economy	28000.00
0005435662014	5292	Economy	28000.00
0005435299916	5292	Economy	28000.00
0005435386761	5292	Economy	28000.00
0005435386759	5292	Economy	28000.00
0005435150401	9921	Business	84000.00
0005434558602	9921	Business	84000.00
0005434558568	9921	Business	84000.00
0005434827283	9921	Comfort	47600.00
0005434827049	9921	Comfort	47600.00
0005432396356	9921	Comfort	47600.00
0005434827263	9921	Economy	28000.00
0005434827183	9921	Economy	28000.00
0005434558594	9921	Economy	28000.00
0005434558579	9921	Economy	28000.00
0005434827039	9921	Economy	28000.00
0005434827218	9921	Economy	28000.00
0005434827291	9921	Economy	28000.00
0005434828775	9921	Economy	28000.00
0005434827288	9921	Economy	28000.00
0005434826854	9921	Economy	28000.00
0005432396357	9921	Economy	28000.00
0005435150426	9921	Economy	28000.00
0005434827254	9921	Economy	28000.00
0005434827250	9921	Economy	28000.00
0005434827154	9921	Economy	30800.00
0005434827155	9921	Economy	28000.00
0005434827219	9921	Economy	28000.00
0005434558587	9921	Economy	28000.00
0005434827282	9921	Economy	28000.00
0005432400222	9921	Economy	28000.00
0005434828774	9921	Economy	28000.00
0005434827295	9921	Economy	28000.00
0005434558569	9921	Economy	28000.00
0005434827272	9921	Economy	28000.00
0005435083040	26005	Economy	7400.00
0005435083039	26005	Economy	7400.00
0005434215891	9516	Economy	10900.00
0005434215882	9516	Economy	10900.00
0005434215888	9516	Economy	10900.00
0005434215851	9516	Economy	10900.00
0005434215876	9516	Economy	10900.00
0005434215884	9516	Economy	10900.00
0005434215883	9516	Economy	10900.00
0005434215852	9516	Economy	10900.00
0005434215901	9516	Economy	10900.00
0005434215900	9516	Economy	10900.00
0005434215877	9516	Economy	10900.00
0005434757613	28614	Business	32800.00
0005434757516	28614	Business	32800.00
0005434757622	28614	Economy	10900.00
0005434757574	28614	Economy	10900.00
0005434757688	28614	Economy	12000.00
0005434757575	28614	Economy	10900.00
0005434757621	28614	Economy	10900.00
0005434757666	28614	Economy	10900.00
0005434757687	28614	Economy	10900.00
0005434757631	28614	Economy	10900.00
0005434757623	28614	Economy	10900.00
0005434757675	28614	Economy	10900.00
0005434757515	28614	Economy	10900.00
0005434757632	28614	Economy	10900.00
0005434757580	28614	Economy	10900.00
0005434757612	28614	Economy	10900.00
0005434640019	23244	Economy	19000.00
0005434640105	23244	Economy	19000.00
0005434640078	23244	Economy	19000.00
0005434640097	23244	Economy	19000.00
0005434640090	23244	Economy	19000.00
0005434640065	23244	Economy	19000.00
0005434640096	23244	Economy	19000.00
0005434640022	23244	Economy	19000.00
0005433531404	18590	Economy	23200.00
0005433527351	18590	Economy	23200.00
0005433527352	18590	Economy	23200.00
0005433527366	18590	Economy	23200.00
0005435315137	10575	Business	9100.00
0005435315130	10575	Business	9100.00
0005435315101	10575	Business	9100.00
0005435315102	10575	Economy	3000.00
0005435315133	10575	Economy	3000.00
0005433181833	10575	Economy	3000.00
0005435315136	10575	Economy	3000.00
0005435315132	10575	Economy	3000.00
0005433181768	10575	Economy	3000.00
0005435315100	10575	Economy	3000.00
0005435315138	10575	Economy	3000.00
0005433181832	10575	Economy	3000.00
0005433181834	10575	Economy	3000.00
0005435315131	10575	Economy	3000.00
0005434558573	27714	Business	9100.00
0005434558590	27714	Business	9100.00
0005434552795	27714	Business	9100.00
0005434558530	27714	Economy	3000.00
0005434558589	27714	Economy	3300.00
0005434552859	27714	Economy	3300.00
0005434558518	27714	Economy	3300.00
0005434552858	27714	Economy	3000.00
0005434558595	27714	Economy	3000.00
0005434552843	27714	Economy	3000.00
0005434558574	27714	Economy	3000.00
0005434558517	27714	Economy	3000.00
0005434558572	27714	Economy	3000.00
0005434552794	27714	Economy	3000.00
0005434552766	27714	Economy	3000.00
0005434558596	27714	Economy	3000.00
0005434552862	27714	Economy	3000.00
0005434552818	27714	Economy	3000.00
0005435254541	6170	Economy	11700.00
0005435254543	6170	Economy	11700.00
0005435254542	6170	Economy	11700.00
0005433459346	19329	Economy	11700.00
0005433459337	19329	Economy	11700.00
0005435438538	6706	Economy	17000.00
0005432533369	6706	Economy	17000.00
0005435438589	6706	Economy	17000.00
0005435683324	24611	Business	51100.00
0005435683315	24611	Business	51100.00
0005435790418	24611	Economy	17000.00
0005435719600	24611	Economy	17000.00
0005435683316	24611	Economy	17000.00
0005435719601	24611	Economy	17000.00
0005435654517	24611	Economy	17000.00
0005435683331	24611	Economy	17000.00
0005435662009	24611	Economy	17000.00
0005435654518	24611	Economy	17000.00
0005435683208	24611	Economy	17000.00
0005435683332	24611	Economy	17000.00
0005435631053	24611	Economy	17000.00
0005435683322	24611	Economy	17000.00
0005435683323	24611	Economy	17000.00
0005435683336	24611	Economy	17000.00
0005435683335	24611	Economy	17000.00
0005435683330	24611	Economy	17000.00
0005435631054	24611	Economy	17000.00
0005435683325	24611	Economy	17000.00
0005435790416	24611	Economy	17000.00
0005435127579	31877	Economy	8800.00
0005435127578	31877	Economy	8800.00
0005435127559	31877	Economy	8800.00
0005435098616	31877	Economy	8800.00
0005435127546	31877	Economy	8800.00
0005435127567	31877	Economy	8800.00
0005435732718	13550	Business	36600.00
0005435732716	13550	Economy	12200.00
0005435732717	13550	Economy	12200.00
0005435732704	13550	Economy	12200.00
0005435732725	13550	Economy	12200.00
0005433399440	19381	Business	36600.00
0005433399460	19381	Economy	12200.00
0005433399387	19381	Economy	12200.00
0005433399388	19381	Economy	12200.00
0005433399404	19381	Economy	12200.00
0005433399457	19381	Economy	12200.00
0005435070521	13176	Business	11300.00
0005435070520	13176	Economy	3800.00
0005435070540	13176	Economy	3800.00
0005435070555	13176	Economy	3800.00
0005435925679	15460	Business	11300.00
0005435925701	15460	Economy	3800.00
0005435925715	15460	Economy	3800.00
0005435925720	15460	Economy	3800.00
0005435925708	15460	Economy	3800.00
0005435925714	15460	Economy	3800.00
0005435808474	29480	Economy	27100.00
0005435808531	29480	Economy	24700.00
0005435808525	29480	Economy	24700.00
0005435808530	29480	Economy	24700.00
0005435808484	29480	Economy	24700.00
0005435808510	29480	Economy	24700.00
0005435808512	29480	Economy	24700.00
0005435808507	29480	Economy	24700.00
0005435808483	29480	Economy	24700.00
0005435808514	29480	Economy	24700.00
0005435808476	29480	Economy	24700.00
0005435808520	29480	Economy	24700.00
0005435808516	29480	Economy	24700.00
0005435808519	29480	Economy	24700.00
0005435808513	29480	Economy	24700.00
0005435808475	29480	Economy	24700.00
0005435808509	29480	Economy	24700.00
0005435808508	29480	Economy	24700.00
0005435808473	29480	Economy	24700.00
0005435808526	29480	Economy	24700.00
0005435808527	29480	Economy	24700.00
0005434757662	10706	Business	61300.00
0005434757661	10706	Economy	20400.00
0005434757690	10706	Economy	20400.00
0005434757531	10706	Economy	20400.00
0005434757686	10706	Economy	20400.00
0005434757670	10706	Economy	20400.00
0005434757671	10706	Economy	20400.00
0005434757614	10706	Economy	20400.00
0005434757533	10706	Economy	20400.00
0005434757532	10706	Economy	20400.00
0005434757605	10706	Economy	20400.00
0005434757659	10706	Economy	20400.00
0005434757641	10706	Economy	20400.00
0005434757691	10706	Economy	20400.00
0005434757534	10706	Economy	20400.00
0005434215791	28701	Business	61300.00
0005434215815	28701	Business	61300.00
0005434215899	28701	Economy	20400.00
0005434215814	28701	Economy	20400.00
0005434215794	28701	Economy	22500.00
0005434215872	28701	Economy	20400.00
0005434215775	28701	Economy	20400.00
0005434215738	28701	Economy	20400.00
0005434215792	28701	Economy	20400.00
0005434215819	28701	Economy	20400.00
0005434215881	28701	Economy	20400.00
0005434215856	28701	Economy	20400.00
0005434215809	28701	Economy	20400.00
0005434215846	28701	Economy	20400.00
0005434215898	28701	Economy	20400.00
0005434215702	28701	Economy	20400.00
0005434215784	28701	Economy	20400.00
0005434215893	28701	Economy	20400.00
0005434215873	28701	Economy	20400.00
0005434215801	28701	Economy	20400.00
0005435377962	5473	Economy	9800.00
0005434230010	5473	Economy	9800.00
0005434230011	5473	Economy	9800.00
0005434230038	5473	Economy	9800.00
0005435556767	5473	Economy	9800.00
0005435377961	5473	Economy	9800.00
0005435377989	5473	Economy	9800.00
0005434230037	5473	Economy	9800.00
0005435377980	5473	Economy	9800.00
0005435377979	5473	Economy	9800.00
0005434230039	5473	Economy	9800.00
0005435556770	5473	Economy	9800.00
0005435377978	5473	Economy	9800.00
0005434230036	5473	Economy	9800.00
0005435007673	12952	Business	29500.00
0005435041700	12952	Business	29500.00
0005435007708	12952	Economy	9800.00
0005435007716	12952	Economy	9800.00
0005435041696	12952	Economy	10800.00
0005435007698	12952	Economy	10800.00
0005435041658	12952	Economy	9800.00
0005435007707	12952	Economy	9800.00
0005435903219	14852	Economy	17600.00
0005435903211	14852	Economy	19400.00
0005435554322	14852	Economy	17600.00
0005435554323	14852	Economy	17600.00
0005435554321	14852	Economy	17600.00
0005434559190	28007	Business	106800.00
0005434559152	28007	Business	106800.00
0005434559143	28007	Business	106800.00
0005434559184	28007	Business	106800.00
0005434559142	28007	Business	106800.00
0005434559191	28007	Economy	35600.00
0005434559187	28007	Economy	35600.00
0005434559192	28007	Economy	35600.00
0005434559165	28007	Economy	35600.00
0005434559171	28007	Economy	35600.00
0005434523846	28007	Economy	35600.00
0005434523842	28007	Economy	39200.00
0005434559172	28007	Economy	35600.00
0005434559138	28007	Economy	35600.00
0005434559183	28007	Economy	35600.00
0005434559173	28007	Economy	35600.00
0005434559141	28007	Economy	35600.00
0005434559169	28007	Economy	35600.00
0005434559179	28007	Economy	35600.00
0005434559180	28007	Economy	35600.00
0005434559189	28007	Economy	35600.00
0005434559153	28007	Economy	35600.00
0005434559159	28007	Economy	35600.00
0005434559186	28007	Economy	35600.00
0005434559174	28007	Economy	35600.00
0005434559182	28007	Economy	35600.00
0005434523836	28007	Economy	35600.00
0005434559175	28007	Economy	35600.00
0005434559188	28007	Economy	35600.00
0005434559139	28007	Economy	35600.00
0005433435491	26514	Business	18500.00
0005433435504	26514	Economy	6200.00
0005433435473	26514	Economy	6200.00
0005433435464	26514	Economy	6200.00
0005435983672	26691	Economy	6800.00
0005435983635	26691	Economy	6200.00
0005435983593	26691	Economy	6200.00
0005435983599	26691	Economy	6200.00
0005435983659	26691	Economy	6200.00
0005435983636	26691	Economy	6200.00
0005435983671	26691	Economy	6200.00
0005435983597	26691	Economy	6200.00
0005432584749	31483	Economy	10100.00
0005432584755	31483	Economy	10100.00
0005432584787	31483	Economy	10100.00
0005432584754	31483	Economy	10100.00
0005432584770	31483	Economy	10100.00
0005433255268	873	Economy	8300.00
0005433255269	873	Economy	7500.00
0005433811689	14364	Economy	4400.00
0005433368959	21744	Business	9800.00
0005433368921	21744	Economy	3300.00
0005433368962	21744	Economy	3300.00
0005433368980	21744	Economy	3300.00
0005433368961	21744	Economy	3300.00
0005433368982	21744	Economy	3300.00
0005433368979	21744	Economy	3300.00
0005433368944	21744	Economy	3300.00
0005433368922	21744	Economy	3300.00
0005433368981	21744	Economy	3300.00
0005435270224	9384	Business	186200.00
0005435270192	9384	Business	186200.00
0005435270121	9384	Economy	62100.00
0005434270267	9384	Economy	62100.00
0005435270191	9384	Economy	62100.00
0005435858744	9384	Economy	62100.00
0005435858745	9384	Economy	62100.00
0005435270120	9384	Economy	62100.00
0005434273127	9384	Economy	62100.00
0005435270223	9384	Economy	62100.00
0005434273126	9384	Economy	62100.00
0005435270225	9384	Economy	62100.00
0005435858728	9384	Economy	62100.00
0005435858727	9384	Economy	62100.00
0005434268064	9384	Economy	62100.00
0005435270226	9384	Economy	62100.00
0005433806384	26230	Business	186200.00
0005432666446	26230	Economy	62100.00
0005433786197	26230	Economy	62100.00
0005433786194	26230	Economy	62100.00
0005433786190	26230	Economy	62100.00
0005433806397	26230	Economy	62100.00
0005433786081	26230	Economy	62100.00
0005433786165	26230	Economy	62100.00
0005432663100	26230	Economy	62100.00
0005433786135	26230	Economy	62100.00
0005433786166	26230	Economy	62100.00
0005432666445	26230	Economy	62100.00
0005432666444	26230	Economy	62100.00
0005433786184	26230	Economy	62100.00
0005434983431	27377	Economy	17900.00
0005434983432	27377	Economy	17900.00
0005433962729	24240	Business	36400.00
0005433962709	24240	Business	36400.00
0005433962752	24240	Business	36400.00
0005433962727	24240	Business	36400.00
0005433962599	24240	Business	36400.00
0005433962760	24240	Business	36400.00
0005433962666	24240	Business	36400.00
0005433987302	24240	Business	36400.00
0005433962659	24240	Economy	13400.00
0005433962528	24240	Economy	12100.00
0005433962604	24240	Economy	12100.00
0005433962676	24240	Economy	12100.00
0005433962529	24240	Economy	12100.00
0005433962626	24240	Economy	12100.00
0005433962570	24240	Economy	12100.00
0005433962600	24240	Economy	12100.00
0005433987300	24240	Economy	12100.00
0005433962683	24240	Economy	12100.00
0005433987253	24240	Economy	12100.00
0005433962601	24240	Economy	12100.00
0005433962650	24240	Economy	12100.00
0005433962677	24240	Economy	12100.00
0005433962761	24240	Economy	12100.00
0005433962678	24240	Economy	12100.00
0005433962605	24240	Economy	12100.00
0005433962684	24240	Economy	12100.00
0005433962491	24240	Economy	12100.00
0005433987373	24240	Economy	12100.00
0005433962685	24240	Economy	12100.00
0005433987330	24240	Economy	12100.00
0005433962748	24240	Economy	12100.00
0005433962755	24240	Economy	12100.00
0005433962730	24240	Economy	12100.00
0005433962710	24240	Economy	12100.00
0005433962749	24240	Economy	12100.00
0005433962715	24240	Economy	12100.00
0005433962756	24240	Economy	12100.00
0005433962728	24240	Economy	12100.00
0005433987252	24240	Economy	12100.00
0005433962509	24240	Economy	12100.00
0005433962657	24240	Economy	12100.00
0005433962530	24240	Economy	12100.00
0005433962645	24240	Economy	12100.00
0005433962665	24240	Economy	12100.00
0005433962658	24240	Economy	12100.00
0005433962711	24240	Economy	12100.00
0005433962669	24240	Economy	12100.00
0005433962747	24240	Economy	12100.00
0005433962668	24240	Economy	12100.00
0005433166279	962	Economy	23100.00
0005434481055	16594	Economy	23100.00
0005434481052	16594	Economy	23100.00
0005434481056	16594	Economy	23100.00
0005434481054	16594	Economy	23100.00
0005434481053	16594	Economy	23100.00
0005433872588	32544	Economy	17200.00
0005435142966	21923	Economy	15400.00
0005435150401	21923	Economy	15400.00
0005435150426	21923	Economy	15400.00
0005435142965	21923	Economy	15400.00
0005435529887	11226	Business	57200.00
0005435502942	11226	Business	57200.00
0005435502964	11226	Economy	19100.00
0005435319829	11226	Economy	19100.00
0005435529839	11226	Economy	19100.00
0005435529894	11226	Economy	19100.00
0005435529895	11226	Economy	19100.00
0005435545972	11226	Economy	19100.00
0005434573771	20949	Economy	19100.00
0005434573772	20949	Economy	19100.00
0005434573773	20949	Economy	19100.00
0005432693907	2906	Economy	3400.00
0005432693955	2906	Economy	3400.00
0005432693956	2906	Economy	3400.00
0005432693945	2906	Economy	3400.00
0005432693946	2906	Economy	3400.00
0005432693908	2906	Economy	3400.00
0005434300253	2908	Business	10300.00
0005434300258	2908	Business	10300.00
0005434300235	2908	Economy	3400.00
0005433194982	2908	Economy	3400.00
0005432881240	2908	Economy	3800.00
0005433124516	2908	Economy	3400.00
0005434300243	2908	Economy	3400.00
0005434300246	2908	Economy	3400.00
0005434300236	2908	Economy	3400.00
0005433124537	2908	Economy	3400.00
0005434300259	2908	Economy	3400.00
0005433124549	2908	Economy	3400.00
0005434300242	2908	Economy	3400.00
0005432881235	2908	Economy	3400.00
0005433124551	2908	Economy	3400.00
0005433194981	2908	Economy	3400.00
0005433124540	2908	Economy	3400.00
0005432881236	2908	Economy	3400.00
0005432881199	2908	Economy	3400.00
0005433124517	2908	Economy	3400.00
0005433195016	2908	Economy	3400.00
0005433124528	2908	Economy	3400.00
0005434310177	30024	Business	10300.00
0005432707503	30024	Economy	3400.00
0005434310171	30024	Economy	3400.00
0005434310165	30024	Economy	3800.00
0005434310150	30024	Economy	3800.00
0005434310156	30024	Economy	3400.00
0005434310170	30024	Economy	3400.00
0005432707505	30024	Economy	3400.00
0005434310169	30024	Economy	3400.00
0005434310157	30024	Economy	3400.00
0005434310176	30024	Economy	3400.00
0005434310158	30024	Economy	3400.00
0005434310185	30024	Economy	3400.00
0005432707504	30024	Economy	3400.00
0005434310184	30024	Economy	3400.00
0005434989046	27546	Economy	4000.00
0005434980669	27546	Economy	3600.00
0005434989135	27546	Economy	3600.00
0005434980668	27546	Economy	3600.00
0005434980660	27546	Economy	3600.00
0005434989119	27546	Economy	3600.00
0005434980594	27546	Economy	3600.00
0005434989118	27546	Economy	3600.00
0005434989047	27546	Economy	3600.00
0005434989132	27546	Economy	3600.00
0005434980667	27546	Economy	3600.00
0005434980655	27546	Economy	3600.00
0005434980678	27546	Economy	3600.00
0005434989069	27546	Economy	3600.00
0005433113597	10285	Economy	19700.00
0005435939972	3551	Economy	9000.00
0005435925711	3551	Economy	9000.00
0005435070540	15317	Business	26900.00
0005435950338	15317	Business	26900.00
0005435070520	15317	Economy	9000.00
0005435070555	15317	Economy	9000.00
0005435070521	15317	Economy	9000.00
0005432664210	26417	Economy	5900.00
0005432667515	26417	Economy	5900.00
0005432664209	26417	Economy	5900.00
0005432664211	26417	Economy	5900.00
0005432667516	26417	Economy	5900.00
0005432920476	227	Business	20000.00
0005433103954	227	Business	20000.00
0005432920480	227	Business	20000.00
0005433439115	227	Business	20000.00
0005432677690	227	Economy	6700.00
0005433103874	227	Economy	6700.00
0005433103922	227	Economy	6700.00
0005433103574	227	Economy	6700.00
0005434028399	227	Economy	6700.00
0005433103881	227	Economy	6700.00
0005433103988	227	Economy	6700.00
0005433103955	227	Economy	6700.00
0005433103682	227	Economy	6700.00
0005433439114	227	Economy	6700.00
0005433103926	227	Economy	6700.00
0005433103967	227	Economy	6700.00
0005433103925	227	Economy	6700.00
0005433103957	227	Economy	6700.00
0005433103890	227	Economy	6700.00
0005433103927	227	Economy	6700.00
0005433103921	227	Economy	6700.00
0005433103575	227	Economy	6700.00
0005433929898	228	Business	20000.00
0005433929893	228	Economy	7300.00
0005433687764	228	Economy	6700.00
0005433929892	228	Economy	6700.00
0005433477255	8017	Business	20000.00
0005434157959	8017	Business	20000.00
0005434157911	8017	Business	20000.00
0005434157769	8017	Business	20000.00
0005434157910	8017	Business	20000.00
0005434157742	8017	Business	20000.00
0005434157913	8017	Business	20000.00
0005433477254	8017	Business	20000.00
0005434157770	8017	Economy	7300.00
0005434191331	8017	Economy	6700.00
0005434191330	8017	Economy	6700.00
0005434157980	8017	Economy	6700.00
0005434157829	8017	Economy	6700.00
0005433477290	8017	Economy	6700.00
0005434175876	8017	Economy	6700.00
0005434157977	8017	Economy	6700.00
0005434157978	8017	Economy	6700.00
0005434157950	8017	Economy	6700.00
0005434157949	8017	Economy	6700.00
0005434215905	8017	Economy	6700.00
0005434157743	8017	Economy	6700.00
0005434157828	8017	Economy	6700.00
0005433477288	8017	Economy	6700.00
0005434157948	8017	Economy	6700.00
0005434157827	8017	Economy	6700.00
0005434152873	8017	Economy	6700.00
0005434152869	8017	Economy	6700.00
0005434157984	8017	Economy	7300.00
0005434157979	8017	Economy	7300.00
0005434215907	8017	Economy	6700.00
0005434157838	8017	Economy	7300.00
0005434215906	8017	Economy	6700.00
0005433477291	8017	Economy	6700.00
0005433477204	8017	Economy	6700.00
0005434157771	8017	Economy	6700.00
0005434175877	8017	Economy	6700.00
0005433477293	8017	Economy	6700.00
0005434157882	8017	Economy	6700.00
0005433477292	8017	Economy	6700.00
0005434157780	8017	Economy	6700.00
0005434157944	8017	Economy	6700.00
0005433477289	8017	Economy	6700.00
0005434157874	8017	Economy	6700.00
0005434157989	8017	Economy	6700.00
0005434157889	8017	Economy	6700.00
0005434157958	8017	Economy	6700.00
0005434191332	8017	Economy	6700.00
0005434157888	8017	Economy	6700.00
0005435914113	3489	Economy	11700.00
0005435903217	3489	Economy	11700.00
0005435903215	3489	Economy	11700.00
0005435914210	3489	Economy	11700.00
0005434880968	14572	Business	35000.00
0005435127587	14572	Business	35000.00
0005435626863	14572	Comfort	19900.00
0005435626865	14572	Comfort	19900.00
0005432800287	14572	Comfort	19900.00
0005435127564	14572	Comfort	19900.00
0005435127581	14572	Economy	11700.00
0005435626823	14572	Economy	11700.00
0005434880828	14572	Economy	11700.00
0005435626756	14572	Economy	11700.00
0005432800284	14572	Economy	11700.00
0005434880947	14572	Economy	11700.00
0005434880967	14572	Economy	11700.00
0005435127513	14572	Economy	11700.00
0005435127575	14572	Economy	11700.00
0005435127542	14572	Economy	11700.00
0005435626845	14572	Economy	11700.00
0005432800253	14572	Economy	11700.00
0005435626761	14572	Economy	11700.00
0005435626859	14572	Economy	11700.00
0005434880982	14572	Economy	11700.00
0005434880986	14572	Economy	11700.00
0005434880948	14572	Economy	11700.00
0005432800286	14572	Economy	11700.00
0005432800276	14572	Economy	11700.00
0005435127487	14572	Economy	11700.00
0005435127580	14572	Economy	11700.00
0005435127543	14572	Economy	11700.00
0005435626832	14572	Economy	12800.00
0005435626831	14572	Economy	11700.00
0005432800275	14572	Economy	11700.00
0005432800252	14572	Economy	11700.00
0005435127544	14572	Economy	11700.00
0005434880980	14572	Economy	11700.00
0005434880849	14572	Economy	11700.00
0005435127568	14572	Economy	11700.00
0005435626760	14572	Economy	11700.00
0005435626864	14572	Economy	11700.00
0005435127552	14572	Economy	11700.00
0005435127576	14572	Economy	11700.00
0005434880969	14572	Economy	11700.00
0005435127514	14572	Economy	11700.00
0005435890071	3634	Economy	14800.00
0005434325949	15619	Economy	14800.00
0005435958093	15160	Economy	4100.00
0005435426859	8923	Economy	10400.00
0005434247223	8923	Economy	10400.00
0005434247222	8923	Economy	10400.00
0005435629452	16055	Economy	10400.00
0005435933553	4429	Economy	12200.00
0005433405032	2863	Economy	4200.00
0005433405033	2863	Economy	4200.00
0005435797897	29328	Economy	4200.00
0005433962453	25806	Business	21400.00
0005433962275	25806	Business	21400.00
0005433962494	25806	Business	21400.00
0005433962369	25806	Business	21400.00
0005433962371	25806	Business	21400.00
0005433962724	25806	Business	21400.00
0005433962762	25806	Economy	7100.00
0005433962329	25806	Economy	7100.00
0005433962680	25806	Economy	7100.00
0005433962538	25806	Economy	7100.00
0005433962654	25806	Economy	7100.00
0005433962194	25806	Economy	7800.00
0005433962512	25806	Economy	7100.00
0005433962495	25806	Economy	7100.00
0005433962611	25806	Economy	7100.00
0005433962674	25806	Economy	7100.00
0005433962667	25806	Economy	7100.00
0005433962621	25806	Economy	7100.00
0005433962726	25806	Economy	7100.00
0005433962388	25806	Economy	7100.00
0005433962593	25806	Economy	7100.00
0005433962706	25806	Economy	7100.00
0005433962370	25806	Economy	7100.00
0005433962545	25806	Economy	7100.00
0005433962757	25806	Economy	7100.00
0005433962716	25806	Economy	7100.00
0005433962662	25806	Economy	7100.00
0005433962725	25806	Economy	7100.00
0005435787477	25806	Economy	7100.00
0005433962660	25806	Economy	7100.00
0005433962444	25806	Economy	7100.00
0005433962742	25806	Economy	7100.00
0005433962698	25806	Economy	7100.00
0005433962330	25806	Economy	7100.00
0005433962580	25806	Economy	7100.00
0005433962452	25806	Economy	7100.00
0005433962540	25806	Economy	7100.00
0005433962518	25806	Economy	7100.00
0005433962501	25806	Economy	7100.00
0005433962539	25806	Economy	7100.00
0005433962689	25806	Economy	7100.00
0005433962445	25806	Economy	7100.00
0005433962723	25806	Economy	7100.00
0005433962603	25806	Economy	7100.00
0005433962630	25806	Economy	7100.00
0005433962515	25806	Economy	7100.00
0005433962741	25806	Economy	7100.00
0005433962514	25806	Economy	7100.00
0005433962520	25806	Economy	7100.00
0005435083039	24441	Economy	3900.00
0005435083040	24441	Economy	3900.00
0005435287045	5105	Business	18000.00
0005435286806	5105	Business	18000.00
0005435287048	5105	Business	18000.00
0005435551779	5105	Business	18000.00
0005435287011	5105	Business	18000.00
0005435551778	5105	Business	18000.00
0005435287038	5105	Economy	6000.00
0005435286855	5105	Economy	6000.00
0005435287046	5105	Economy	6000.00
0005435286983	5105	Economy	6000.00
0005435287039	5105	Economy	6000.00
0005435551784	5105	Economy	6000.00
0005435286990	5105	Economy	6000.00
0005435287049	5105	Economy	6000.00
0005435286966	5105	Economy	6000.00
0005435286993	5105	Economy	6000.00
0005435286937	5105	Economy	6000.00
0005435287007	5105	Economy	6000.00
0005435287012	5105	Economy	6000.00
0005435286886	5105	Economy	6000.00
0005435286854	5105	Economy	6000.00
0005435287047	5105	Economy	6000.00
0005435286807	5105	Economy	6000.00
0005435286856	5105	Economy	6000.00
0005435286992	5105	Economy	6000.00
0005435287017	5105	Economy	6000.00
0005435286888	5105	Economy	6000.00
0005435551785	5105	Economy	6000.00
0005435286887	5105	Economy	6000.00
0005435551780	5105	Economy	6000.00
0005435286899	5105	Economy	6000.00
0005435287041	5105	Economy	6000.00
0005435007707	5102	Business	18000.00
0005435732742	5102	Business	18000.00
0005434311280	5102	Business	18000.00
0005435007673	5102	Economy	6600.00
0005433688861	5102	Economy	6000.00
0005435007716	5102	Economy	6000.00
0005433688862	5102	Economy	6000.00
0005435270205	5102	Economy	6000.00
0005433685578	5102	Economy	6000.00
0005435007698	5102	Economy	6000.00
0005433690989	5102	Economy	6000.00
0005434311279	5102	Economy	6000.00
0005433815582	5102	Economy	6000.00
0005435270206	5102	Economy	6000.00
0005435007708	5102	Economy	6000.00
0005433786081	8500	Business	18000.00
0005433786184	8500	Business	18000.00
0005432666445	8500	Business	18000.00
0005434245847	8500	Economy	6000.00
0005432666446	8500	Economy	6000.00
0005434245816	8500	Economy	6000.00
0005434245828	8500	Economy	6000.00
0005433786190	8500	Economy	6000.00
0005433786135	8500	Economy	6000.00
0005432666444	8500	Economy	6600.00
0005434245846	8500	Economy	6000.00
0005433786197	8500	Economy	6000.00
0005433786166	8500	Economy	6000.00
0005434245823	8500	Economy	6000.00
0005433786194	8500	Economy	6000.00
0005432663100	8500	Economy	6000.00
0005434245824	8500	Economy	6000.00
0005434245827	8500	Economy	6000.00
0005433786165	8500	Economy	6000.00
0005433616813	8501	Business	18000.00
0005433616725	8501	Business	18000.00
0005434230216	8501	Business	18000.00
0005434230244	8501	Business	18000.00
0005434230228	8501	Business	18000.00
0005434230217	8501	Business	18000.00
0005434230188	8501	Business	18000.00
0005434230135	8501	Business	18000.00
0005434230227	8501	Business	18000.00
0005433616593	8501	Business	18000.00
0005434230215	8501	Business	18000.00
0005433616594	8501	Business	18000.00
0005434230079	8501	Economy	6600.00
0005433616819	8501	Economy	6000.00
0005434230093	8501	Economy	6000.00
0005434230146	8501	Economy	6000.00
0005434230230	8501	Economy	6000.00
0005434230245	8501	Economy	6000.00
0005434230235	8501	Economy	6000.00
0005434230175	8501	Economy	6000.00
0005434230199	8501	Economy	6000.00
0005433616804	8501	Economy	6000.00
0005433616791	8501	Economy	6000.00
0005434230189	8501	Economy	6000.00
0005433616828	8501	Economy	6000.00
0005434230120	8501	Economy	6000.00
0005434230277	8501	Economy	6600.00
0005434230136	8501	Economy	6600.00
0005434230278	8501	Economy	6000.00
0005434230229	8501	Economy	6000.00
0005434230190	8501	Economy	6000.00
0005434230092	8501	Economy	6000.00
0005433616742	8501	Economy	6000.00
0005434230238	8501	Economy	6000.00
0005434230080	8501	Economy	6000.00
0005434230243	8501	Economy	6000.00
0005434230128	8501	Economy	6000.00
0005434230122	8501	Economy	6000.00
0005434230090	8501	Economy	6000.00
0005434230121	8501	Economy	6000.00
0005433616812	8501	Economy	6000.00
0005434230214	8501	Economy	6000.00
0005434230252	8501	Economy	6000.00
0005434230267	8501	Economy	6000.00
0005434230010	8502	Business	18000.00
0005434230011	8502	Economy	6600.00
0005434230039	8502	Economy	6000.00
0005434265904	8502	Economy	6000.00
0005434150072	8502	Economy	6000.00
0005434265880	8502	Economy	6000.00
0005434230037	8502	Economy	6000.00
0005434150076	8502	Economy	6000.00
0005434230036	8502	Economy	6000.00
0005434265903	8502	Economy	6000.00
0005434230038	8502	Economy	6000.00
0005434640032	12617	Economy	16200.00
0005434640093	12617	Economy	16200.00
0005434640031	12617	Economy	14800.00
0005434640091	12617	Economy	14800.00
0005434640083	12617	Economy	14800.00
0005434640092	12617	Economy	14800.00
0005434640068	12617	Economy	14800.00
0005434640084	12617	Economy	14800.00
0005434640106	12617	Economy	14800.00
0005434640049	12617	Economy	14800.00
0005433202773	23385	Economy	14800.00
0005433202791	23385	Economy	14800.00
0005433202792	23385	Economy	14800.00
0005433202762	23385	Economy	14800.00
0005432330034	21064	Business	18900.00
0005432330054	21064	Business	18900.00
0005432330009	21064	Business	18900.00
0005432329966	21064	Economy	6300.00
0005432384308	21064	Economy	6300.00
0005432384335	21064	Economy	6900.00
0005432329998	21064	Economy	6300.00
0005432384304	21064	Economy	6300.00
0005432330063	21064	Economy	6300.00
0005432384334	21064	Economy	6300.00
0005432330037	21064	Economy	6300.00
0005432329951	21064	Economy	6300.00
0005432384320	21064	Economy	6300.00
0005432329996	21064	Economy	6300.00
0005432384333	21064	Economy	6300.00
0005432384325	21064	Economy	6300.00
0005432330055	21064	Economy	6300.00
0005432384330	21064	Economy	6300.00
0005432329967	21064	Economy	6300.00
0005432384278	21064	Economy	6300.00
0005432384313	21064	Economy	6300.00
0005432384321	21064	Economy	6300.00
0005432329997	21064	Economy	6300.00
0005432848919	31244	Business	18900.00
0005432848910	31244	Economy	6300.00
0005432848913	31244	Economy	6300.00
0005432848914	31244	Economy	6300.00
0005432848918	31244	Economy	6300.00
0005432954149	2488	Business	89600.00
0005432954194	2488	Business	89600.00
0005432954172	2488	Economy	29900.00
0005432954176	2488	Economy	32800.00
0005432954192	2488	Economy	29900.00
0005432954178	2488	Economy	29900.00
0005432954197	2488	Economy	29900.00
0005432954196	2488	Economy	29900.00
0005432954193	2488	Economy	29900.00
0005432954179	2488	Economy	29900.00
0005432954177	2488	Economy	29900.00
0005432954173	2488	Economy	29900.00
0005433642692	27580	Business	89600.00
0005433642750	27580	Economy	29900.00
0005433642767	27580	Economy	29900.00
0005433642777	27580	Economy	29900.00
0005433642663	27580	Economy	29900.00
0005433642775	27580	Economy	29900.00
0005433642664	27580	Economy	29900.00
0005433642741	27580	Economy	29900.00
0005433642751	27580	Economy	29900.00
0005432426039	30770	Business	12700.00
0005432425948	30770	Business	12700.00
0005432425839	30770	Business	12700.00
0005432425757	30770	Economy	4200.00
0005432425585	30770	Economy	4700.00
0005432425919	30770	Economy	4700.00
0005432425918	30770	Economy	4200.00
0005432425758	30770	Economy	4200.00
0005432425875	30770	Economy	4200.00
0005432425997	30770	Economy	4200.00
0005432425584	30770	Economy	4200.00
0005432425944	30770	Economy	4200.00
0005432426062	30770	Economy	4200.00
0005432426063	30770	Economy	4200.00
0005432425935	30770	Economy	4200.00
0005432425982	30770	Economy	4200.00
0005432425936	30770	Economy	4200.00
0005432426019	30770	Economy	4200.00
0005432425943	30770	Economy	4200.00
0005432425951	30770	Economy	4200.00
0005432425983	30770	Economy	4200.00
0005432425996	30770	Economy	4200.00
0005432426022	30770	Economy	4200.00
0005432426060	30770	Economy	4200.00
0005432902103	9599	Business	32600.00
0005434157714	9599	Business	32600.00
0005432902086	9599	Business	32600.00
0005432902104	9599	Economy	10900.00
0005434157713	9599	Economy	10900.00
0005432949642	11847	Business	105900.00
0005432949668	11847	Business	105900.00
0005432949664	11847	Economy	35300.00
0005432949669	11847	Economy	35300.00
0005432949583	11847	Economy	38800.00
0005432949688	11847	Economy	35300.00
0005432949590	11847	Economy	35300.00
0005432949677	11847	Economy	35300.00
0005432949667	11847	Economy	35300.00
0005432949670	11847	Economy	35300.00
0005432949647	11847	Economy	35300.00
0005432949691	11847	Economy	35300.00
0005432949676	11847	Economy	35300.00
0005432949678	11847	Economy	35300.00
0005433570978	25314	Business	105900.00
0005433570969	25314	Business	105900.00
0005433570979	25314	Business	105900.00
0005433570726	25314	Business	105900.00
0005433570961	25314	Business	105900.00
0005433570951	25314	Business	105900.00
0005433570950	25314	Economy	35300.00
0005433570953	25314	Economy	35300.00
0005433570900	25314	Economy	35300.00
0005433570725	25314	Economy	35300.00
0005433570749	25314	Economy	35300.00
0005433570954	25314	Economy	35300.00
0005433570977	25314	Economy	35300.00
0005433570949	25314	Economy	35300.00
0005433570952	25314	Economy	35300.00
0005433570748	25314	Economy	35300.00
0005433570730	25314	Economy	35300.00
0005433570828	25314	Economy	35300.00
0005433570912	25314	Economy	35300.00
0005433570923	25314	Economy	35300.00
0005433570897	25314	Economy	35300.00
0005433570862	25314	Economy	35300.00
0005433570957	25314	Economy	35300.00
0005433570968	25314	Economy	35300.00
0005433570892	25314	Economy	35300.00
0005434655521	12521	Economy	22400.00
0005434655522	12521	Economy	22400.00
0005434655523	12521	Economy	22400.00
0005434655491	12521	Economy	22400.00
0005434655500	12521	Economy	22400.00
0005434655501	12521	Economy	22400.00
0005434655464	12521	Economy	22400.00
0005434655499	12521	Economy	22400.00
0005434655492	12521	Economy	22400.00
0005434655463	12521	Economy	22400.00
0005432429021	7459	Business	32000.00
0005435266330	7459	Business	32000.00
0005432429030	7459	Economy	10700.00
0005435266346	7459	Economy	10700.00
0005435266321	7459	Economy	10700.00
0005432429034	7459	Economy	10700.00
0005435546239	7459	Economy	10700.00
0005435546240	7459	Economy	10700.00
0005433717378	29199	Business	32000.00
0005433722507	29199	Business	32000.00
0005433722456	29199	Economy	10700.00
0005433722455	29199	Economy	10700.00
0005433717377	29199	Economy	10700.00
0005433722488	29199	Economy	10700.00
0005433685578	29199	Economy	10700.00
0005433722418	29199	Economy	10700.00
0005433722448	29199	Economy	10700.00
0005433722438	29199	Economy	10700.00
0005433717408	29199	Economy	10700.00
0005433722416	29199	Economy	10700.00
0005433717326	29199	Economy	10700.00
0005433722512	29199	Economy	10700.00
0005433722444	29199	Economy	10700.00
0005433719241	29199	Economy	11700.00
0005433717327	29199	Economy	10700.00
0005433722437	29199	Economy	10700.00
0005433719238	29199	Economy	10700.00
0005433688861	29199	Economy	10700.00
0005433722453	29199	Economy	10700.00
0005433722508	29199	Economy	10700.00
0005433722417	29199	Economy	10700.00
0005433722452	29199	Economy	10700.00
0005433717395	29199	Economy	10700.00
0005433690989	29199	Economy	10700.00
0005433719237	29199	Economy	10700.00
0005433717425	29199	Economy	10700.00
0005433656768	29199	Economy	10700.00
0005433688862	29199	Economy	10700.00
0005435860731	8671	Business	36500.00
0005434182554	8671	Business	36500.00
0005435860729	8671	Economy	13400.00
0005435860718	8671	Economy	12200.00
0005435860709	8671	Economy	12200.00
0005435860728	8671	Economy	12200.00
0005434182555	8671	Economy	12200.00
0005434143854	11647	Business	36500.00
0005434143795	11647	Economy	12200.00
0005434326300	11647	Economy	12200.00
0005434326299	11647	Economy	12200.00
0005434143845	11647	Economy	12200.00
0005434095674	11647	Economy	12200.00
0005434095673	11647	Economy	12200.00
0005433399460	1428	Business	33000.00
0005433399404	1428	Business	33000.00
0005433399387	1428	Business	33000.00
0005433399440	1428	Economy	11000.00
0005433399388	1428	Economy	11000.00
0005433399457	1428	Economy	11000.00
0005435732704	19256	Economy	11000.00
0005435732716	19256	Economy	11000.00
0005435732717	19256	Economy	11000.00
0005435732718	19256	Economy	11000.00
0005435732725	19256	Economy	11000.00
0005434444152	17382	Economy	14100.00
0005434444164	17382	Economy	14100.00
0005434444179	17382	Economy	14100.00
0005434444153	17382	Economy	14100.00
0005434444165	17382	Economy	14100.00
0005434954721	28349	Economy	5800.00
0005434352065	29637	Economy	14000.00
0005434352052	29637	Economy	14000.00
0005434326104	29637	Economy	14000.00
0005434352051	29637	Economy	14000.00
0005433346022	1087	Business	30600.00
0005433346067	1087	Business	30600.00
0005433346051	1087	Business	30600.00
0005433346069	1087	Business	30600.00
0005433346050	1087	Business	30600.00
0005433345839	1087	Business	30600.00
0005433345994	1087	Economy	11200.00
0005433346066	1087	Economy	10200.00
0005433269869	1087	Economy	10200.00
0005433345984	1087	Economy	10200.00
0005433345934	1087	Economy	10200.00
0005433346021	1087	Economy	10200.00
0005433346052	1087	Economy	10200.00
0005433346059	1087	Economy	10200.00
0005433269868	1087	Economy	11200.00
0005433346013	1087	Economy	10200.00
0005433346014	1087	Economy	10200.00
0005433346015	1087	Economy	10200.00
0005433345906	1087	Economy	10200.00
0005433345756	1087	Economy	10200.00
0005433346065	1087	Economy	10200.00
0005433346016	1087	Economy	10200.00
0005433345995	1087	Economy	10200.00
0005433346060	1087	Economy	10200.00
0005433345926	1087	Economy	10200.00
0005435530196	17045	Economy	10200.00
0005435530197	17045	Economy	10200.00
0005435508812	17045	Economy	10200.00
0005434444188	17045	Economy	10200.00
0005432852090	1347	Economy	33700.00
0005432852102	1347	Economy	33700.00
0005432852079	1347	Economy	33700.00
0005432852088	1347	Economy	33700.00
0005432852103	1347	Economy	33700.00
0005432852089	1347	Economy	33700.00
0005432852093	1347	Economy	33700.00
0005434069348	12781	Business	40300.00
0005434069563	12781	Economy	13400.00
0005434082634	12781	Economy	13400.00
0005434069444	12781	Economy	13400.00
0005433989900	12781	Economy	13400.00
0005434069504	12781	Economy	13400.00
0005434069649	12781	Economy	13400.00
0005434069553	12781	Economy	14800.00
0005434082564	12781	Economy	14800.00
0005434069433	12781	Economy	13400.00
0005433989901	12781	Economy	13400.00
0005434069630	12781	Economy	13400.00
0005434069587	12781	Economy	13400.00
0005434069528	12781	Economy	13400.00
0005434082612	12781	Economy	13400.00
0005434069432	12781	Economy	13400.00
0005434069525	12781	Economy	13400.00
0005434069633	12781	Economy	13400.00
0005434069590	12781	Economy	13400.00
0005434069582	12781	Economy	13400.00
0005434069431	12781	Economy	13400.00
0005434069576	12781	Economy	13400.00
0005434069636	12781	Economy	13400.00
0005434069583	12781	Economy	13400.00
0005434069609	12781	Economy	13400.00
0005433989899	12781	Economy	13400.00
0005434069589	12781	Economy	13400.00
0005434069349	12781	Economy	13400.00
0005434082635	12781	Economy	13400.00
0005435283552	30641	Business	40300.00
0005435283531	30641	Economy	13400.00
0005435860638	30641	Economy	13400.00
0005435283530	30641	Economy	13400.00
0005434265892	5502	Business	35300.00
0005435617202	5502	Economy	11800.00
0005434265876	5502	Economy	11800.00
0005434265875	5502	Economy	11800.00
0005434265874	5502	Economy	12900.00
0005432535976	5502	Economy	11800.00
0005435463524	5502	Economy	11800.00
0005432535974	5502	Economy	11800.00
0005434265861	5502	Economy	11800.00
0005435767962	13495	Business	35300.00
0005435768057	13495	Economy	11800.00
0005435768034	13495	Economy	11800.00
0005435768033	13495	Economy	11800.00
0005435767963	13495	Economy	11800.00
0005435732742	13495	Economy	12900.00
0005435768047	13495	Economy	11800.00
0005435723103	13495	Economy	11800.00
0005435768049	13495	Economy	11800.00
0005435768096	13495	Economy	11800.00
0005435723106	13495	Economy	11800.00
0005434605007	18644	Economy	3300.00
0005432649573	25088	Economy	29400.00
0005433286163	1890	Business	48700.00
0005433286166	1890	Economy	16200.00
0005433009927	1890	Economy	16200.00
0005433009964	1890	Economy	16200.00
0005433009944	1890	Economy	16200.00
0005433286197	1890	Economy	16200.00
0005433009940	1890	Economy	16200.00
0005433286229	1890	Economy	16200.00
0005433286223	1890	Economy	16200.00
0005433009943	1890	Economy	16200.00
0005433009928	1890	Economy	16200.00
0005433810795	22606	Business	48700.00
0005435725782	22606	Business	48700.00
0005435725770	22606	Business	48700.00
0005435725781	22606	Business	48700.00
0005435097517	22606	Economy	16200.00
0005433810779	22606	Economy	16200.00
0005435725786	22606	Economy	16200.00
0005435725778	22606	Economy	16200.00
0005435097506	22606	Economy	16200.00
0005433810793	22606	Economy	16200.00
0005433810722	22606	Economy	17900.00
0005433810808	22606	Economy	16200.00
0005435097512	22606	Economy	16200.00
0005433810786	22606	Economy	16200.00
0005433810752	22606	Economy	16200.00
0005435725777	22606	Economy	16200.00
0005433810723	22606	Economy	16200.00
0005433810767	22606	Economy	16200.00
0005435097516	22606	Economy	16200.00
0005433810760	22606	Economy	16200.00
0005435725783	22606	Economy	16200.00
0005435725787	22606	Economy	16200.00
0005435097505	22606	Economy	16200.00
0005433810785	22606	Economy	16200.00
0005433810780	22606	Economy	16200.00
0005433810753	22606	Economy	16200.00
0005433810794	22606	Economy	16200.00
0005433810804	22606	Economy	16200.00
0005433810798	22606	Economy	16200.00
0005433810807	22606	Economy	16200.00
0005433810796	22606	Economy	16200.00
0005435725771	22606	Economy	16200.00
0005433810791	22606	Economy	16200.00
0005433810773	22606	Economy	16200.00
0005435725758	22606	Economy	16200.00
0005435283254	5557	Business	99800.00
0005435283247	5557	Economy	33300.00
0005435283213	5557	Economy	33300.00
0005435283172	5557	Economy	33300.00
0005433815582	13873	Business	99800.00
0005433848254	13873	Economy	33300.00
0005433848345	13873	Economy	33300.00
0005433848373	13873	Economy	33300.00
0005433848344	13873	Economy	33300.00
0005434621181	32986	Economy	16600.00
0005434621182	32986	Economy	15100.00
0005434621183	32986	Economy	15100.00
0005434621174	32986	Economy	15100.00
0005435937552	4269	Economy	12700.00
0005435786356	27283	Economy	12700.00
0005435786367	27283	Economy	12700.00
0005435786336	27283	Economy	12700.00
0005435786351	27283	Economy	12700.00
0005435786357	27283	Economy	12700.00
0005435786345	27283	Economy	12700.00
0005434994296	27283	Economy	12700.00
0005435786275	27283	Economy	12700.00
0005435787412	27283	Economy	12700.00
0005435786348	27283	Economy	12700.00
0005435786352	27283	Economy	12700.00
0005435786268	27283	Economy	12700.00
0005435786269	27283	Economy	12700.00
0005435840532	4738	Business	40900.00
0005434150157	4738	Business	40900.00
0005434150198	4738	Business	40900.00
0005434150226	4738	Economy	13600.00
0005434150236	4738	Economy	13600.00
0005435840529	4738	Economy	13600.00
0005434150188	4738	Economy	13600.00
0005434150227	4738	Economy	13600.00
0005434150189	4738	Economy	13600.00
0005434150187	4738	Economy	13600.00
0005435840528	4738	Economy	13600.00
0005435840527	4738	Economy	13600.00
0005434559175	30534	Business	40900.00
0005434559169	30534	Business	40900.00
0005434559172	30534	Business	40900.00
0005432461385	30534	Business	40900.00
0005432461375	30534	Business	40900.00
0005434559183	30534	Business	40900.00
0005432569427	30534	Business	40900.00
0005434082612	30534	Business	40900.00
0005433726165	30534	Business	40900.00
0005434559171	30534	Economy	15000.00
0005432461440	30534	Economy	13600.00
0005434082635	30534	Economy	13600.00
0005433726168	30534	Economy	13600.00
0005434559174	30534	Economy	13600.00
0005434559159	30534	Economy	13600.00
0005434559187	30534	Economy	13600.00
0005432569424	30534	Economy	13600.00
0005434559139	30534	Economy	13600.00
0005434559173	30534	Economy	13600.00
0005432461405	30534	Economy	13600.00
0005434559152	30534	Economy	13600.00
0005434559192	30534	Economy	13600.00
0005434559180	30534	Economy	13600.00
0005434559188	30534	Economy	13600.00
0005434559190	30534	Economy	13600.00
0005433726143	30534	Economy	13600.00
0005434559165	30534	Economy	13600.00
0005432461417	30534	Economy	13600.00
0005434559191	30534	Economy	13600.00
0005433726151	30534	Economy	13600.00
0005433726144	30534	Economy	13600.00
0005433726170	30534	Economy	13600.00
0005432461418	30534	Economy	13600.00
0005433726164	30534	Economy	13600.00
0005434559186	30534	Economy	13600.00
0005434559179	30534	Economy	13600.00
0005432569426	30534	Economy	13600.00
0005434559143	30534	Economy	13600.00
0005434082634	30534	Economy	13600.00
0005434559184	30534	Economy	13600.00
0005434082564	30534	Economy	13600.00
0005434559189	30534	Economy	13600.00
0005433726169	30534	Economy	13600.00
0005434559142	30534	Economy	13600.00
0005434559138	30534	Economy	13600.00
0005434559153	30534	Economy	13600.00
0005434559141	30534	Economy	13600.00
0005433726150	30534	Economy	13600.00
0005432569406	30534	Economy	13600.00
0005434559182	30534	Economy	13600.00
0005432461386	30534	Economy	13600.00
0005435720168	21205	Economy	9900.00
0005435725785	13706	Economy	8800.00
0005435725761	13706	Economy	8800.00
0005435725780	13706	Economy	8800.00
0005435725773	13706	Economy	8800.00
0005435725784	13706	Economy	8800.00
0005435508831	11116	Business	23600.00
0005435546003	11116	Economy	7900.00
0005435380436	11116	Economy	7900.00
0005435530187	11116	Economy	7900.00
0005435530184	11116	Economy	8600.00
0005435508827	11116	Economy	7900.00
0005435530185	11116	Economy	7900.00
0005435530194	11116	Economy	7900.00
0005435380443	11116	Economy	7900.00
0005435545997	11116	Economy	7900.00
0005435508830	11116	Economy	7900.00
0005435530192	11116	Economy	7900.00
0005435530193	11116	Economy	7900.00
0005435508807	11116	Economy	7900.00
0005433345994	17092	Business	23600.00
0005433346069	17092	Business	23600.00
0005433346016	17092	Business	23600.00
0005433346051	17092	Business	23600.00
0005433346059	17092	Economy	7900.00
0005435097502	17092	Economy	7900.00
0005433346013	17092	Economy	7900.00
0005433345906	17092	Economy	7900.00
0005433346060	17092	Economy	7900.00
0005435097497	17092	Economy	7900.00
0005433345995	17092	Economy	7900.00
0005433346022	17092	Economy	7900.00
0005433346014	17092	Economy	7900.00
0005433346021	17092	Economy	8600.00
0005433346052	17092	Economy	7900.00
0005435097496	17092	Economy	7900.00
0005433346066	17092	Economy	7900.00
0005433345934	17092	Economy	7900.00
0005435097486	17092	Economy	7900.00
0005435097501	17092	Economy	7900.00
0005433345926	17092	Economy	7900.00
0005433346015	17092	Economy	7900.00
0005433346050	17092	Economy	7900.00
0005433345984	17092	Economy	7900.00
0005433346065	17092	Economy	7900.00
0005433346067	17092	Economy	7900.00
0005433345756	17092	Economy	7900.00
0005433345839	17092	Economy	7900.00
0005434159058	9064	Economy	8900.00
0005434159057	9064	Economy	8900.00
0005432920481	9064	Economy	8900.00
0005434159050	9064	Economy	8900.00
0005432920318	9064	Economy	8900.00
0005432920473	9064	Economy	8900.00
0005433507719	20464	Economy	8900.00
0005432400222	18328	Economy	5800.00
0005432396356	18328	Economy	5800.00
0005432396357	18328	Economy	5800.00
0005435626864	11031	Business	9500.00
0005435127513	11031	Business	9500.00
0005435127487	11031	Business	9500.00
0005435127564	11031	Business	9500.00
0005435626832	11031	Economy	3200.00
0005435554319	11031	Economy	3500.00
0005435626863	11031	Economy	3200.00
0005435127544	11031	Economy	3200.00
0005435626845	11031	Economy	3200.00
0005435626823	11031	Economy	3200.00
0005435626865	11031	Economy	3200.00
0005435626756	11031	Economy	3200.00
0005435127587	11031	Economy	3200.00
0005435127543	11031	Economy	3200.00
0005435127542	11031	Economy	3200.00
0005435127552	11031	Economy	3200.00
0005435626760	11031	Economy	3200.00
0005435626761	11031	Economy	3200.00
0005435127568	11031	Economy	3200.00
0005435626831	11031	Economy	3200.00
0005435127580	11031	Economy	3200.00
0005435626859	11031	Economy	3200.00
0005435554318	11031	Economy	3200.00
0005435127576	11031	Economy	3200.00
0005435127514	11031	Economy	3200.00
0005435127581	11031	Economy	3200.00
0005435127575	11031	Economy	3200.00
0005435178540	7114	Business	86900.00
0005435219257	7114	Economy	29000.00
0005435443583	7114	Economy	29000.00
0005435715956	27099	Economy	31900.00
0005432394224	27099	Economy	29000.00
0005432394223	27099	Economy	29000.00
0005432398297	27099	Economy	29000.00
0005435518450	11383	Business	20200.00
0005435518451	11383	Economy	6700.00
0005435546229	11383	Economy	7400.00
0005435541652	11383	Economy	6700.00
0005435541609	11383	Economy	6700.00
0005435541596	11383	Economy	6700.00
0005435541651	11383	Economy	6700.00
0005435541653	11383	Economy	6700.00
0005435541641	11383	Economy	6700.00
0005435518374	11383	Economy	6700.00
0005435541595	11383	Economy	6700.00
0005435541594	11383	Economy	6700.00
0005433252370	2273	Economy	6700.00
0005434908779	25592	Business	20200.00
0005434908830	25592	Economy	6700.00
0005434908711	25592	Economy	7400.00
0005434908715	25592	Economy	6700.00
0005434908806	25592	Economy	6700.00
0005434908878	25592	Economy	6700.00
0005434908834	25592	Economy	6700.00
0005434908829	25592	Economy	6700.00
0005434908777	25592	Economy	6700.00
0005434908778	25592	Economy	6700.00
0005434908835	25592	Economy	6700.00
0005434908842	25592	Economy	6700.00
0005434908805	25592	Economy	6700.00
0005435787476	25592	Economy	6700.00
0005434908714	25592	Economy	6700.00
0005434908782	25592	Economy	6700.00
0005434908673	25592	Economy	6700.00
0005432433842	13050	Economy	11300.00
0005432433841	13050	Economy	11300.00
0005434182553	11998	Economy	7200.00
0005433129412	11998	Economy	6600.00
0005434182552	11998	Economy	6600.00
0005434182551	11998	Economy	6600.00
0005434326047	29830	Economy	6600.00
0005434326027	29830	Economy	6600.00
0005434326032	29830	Economy	6600.00
0005435935131	16452	Economy	18100.00
0005435698178	24699	Economy	18100.00
0005435698150	24699	Economy	18100.00
0005432968905	18757	Economy	4400.00
0005435283591	7328	Business	23100.00
0005435283581	7328	Economy	7700.00
0005435283580	7328	Economy	7700.00
0005434140444	28555	Business	23100.00
0005434140548	28555	Business	23100.00
0005434140519	28555	Business	23100.00
0005434140593	28555	Business	23100.00
0005434140232	28555	Economy	7700.00
0005434140397	28555	Economy	7700.00
0005434140396	28555	Economy	7700.00
0005434140404	28555	Economy	7700.00
0005434140537	28555	Economy	7700.00
0005434140616	28555	Economy	7700.00
0005434140462	28555	Economy	7700.00
0005434140538	28555	Economy	7700.00
0005434140628	28555	Economy	7700.00
0005434140446	28555	Economy	7700.00
0005434140547	28555	Economy	7700.00
0005434140617	28555	Economy	7700.00
0005434140614	28555	Economy	7700.00
0005434140558	28555	Economy	7700.00
0005434140586	28555	Economy	7700.00
0005434140234	28555	Economy	7700.00
0005434140233	28555	Economy	7700.00
0005434140520	28555	Economy	7700.00
0005434140610	28555	Economy	7700.00
0005434140539	28555	Economy	7700.00
0005434140472	28555	Economy	7700.00
0005434140447	28555	Economy	7700.00
0005434140620	28555	Economy	7700.00
0005433407705	1900	Economy	21700.00
0005434505276	16726	Economy	6900.00
0005434505308	16726	Economy	6900.00
0005434505303	16726	Economy	6900.00
0005434505299	16726	Economy	6900.00
0005434505300	16726	Economy	6900.00
0005434505305	16726	Economy	6900.00
0005434505304	16726	Economy	6900.00
0005435312886	22882	Economy	6900.00
0005435312887	22882	Economy	6900.00
0005435312885	22882	Economy	6900.00
0005435312884	22882	Economy	6900.00
0005433266990	2191	Economy	7000.00
0005435078774	24331	Economy	7000.00
0005435078792	24331	Economy	7000.00
0005435078793	24331	Economy	7000.00
0005435078794	24331	Economy	7000.00
0005435464564	6658	Economy	9800.00
0005434989114	23595	Economy	10800.00
0005434989105	23595	Economy	9800.00
0005435803353	23595	Economy	9800.00
0005434989082	23595	Economy	9800.00
0005434989072	23595	Economy	9800.00
0005434989084	23595	Economy	9800.00
0005434989079	23595	Economy	9800.00
0005434989083	23595	Economy	9800.00
0005435803354	23595	Economy	9800.00
0005432384314	31333	Business	9900.00
0005433450611	31333	Economy	3300.00
0005433450506	31333	Economy	3300.00
0005432384329	31333	Economy	3300.00
0005432384315	31333	Economy	3300.00
0005432384338	31333	Economy	3300.00
0005432384214	31333	Economy	3300.00
0005432384286	31333	Economy	3300.00
0005433450563	31333	Economy	3300.00
0005432384328	31333	Economy	3300.00
0005432384323	31333	Economy	3300.00
0005432384301	31333	Economy	3300.00
0005433450604	31333	Economy	3300.00
0005432384300	31333	Economy	3300.00
0005432384326	31333	Economy	3300.00
0005432384225	31333	Economy	3300.00
0005432384309	31333	Economy	3300.00
0005433450505	31333	Economy	3300.00
0005432384098	31333	Economy	3300.00
0005432384213	31333	Economy	3300.00
0005432384212	31333	Economy	3300.00
0005432384322	31333	Economy	3300.00
0005432384226	31333	Economy	3300.00
0005433450600	31333	Economy	3300.00
0005432384327	31333	Economy	3300.00
0005432384285	31333	Economy	3300.00
0005435548621	20809	Economy	26200.00
0005435548620	20809	Economy	26200.00
0005435548606	20809	Economy	23800.00
0005435548607	20809	Economy	23800.00
0005435548625	20809	Economy	23800.00
0005435548619	20809	Economy	23800.00
0005435548612	20809	Economy	23800.00
0005435548618	20809	Economy	23800.00
0005435548605	20809	Economy	23800.00
0005433788325	26484	Economy	23800.00
0005433788314	26484	Economy	23800.00
0005433788315	26484	Economy	23800.00
0005433788324	26484	Economy	23800.00
0005433788309	26484	Economy	23800.00
0005433788321	26484	Economy	23800.00
0005435299913	10742	Economy	15600.00
0005433131838	10742	Economy	15600.00
0005434300249	26849	Economy	17200.00
0005434287913	26849	Economy	17200.00
0005434287937	26849	Economy	15700.00
0005434300238	26849	Economy	15700.00
0005434287839	26849	Economy	15700.00
0005434287935	26849	Economy	15700.00
0005434300240	26849	Economy	15700.00
0005434287934	26849	Economy	15700.00
0005434300239	26849	Economy	15700.00
0005434287941	26849	Economy	15700.00
0005434287936	26849	Economy	15700.00
0005434300241	26849	Economy	15700.00
0005434269162	25476	Economy	22800.00
0005434269165	25476	Economy	22800.00
0005435314952	6111	Economy	22300.00
0005435314951	6111	Economy	22300.00
0005435314949	6111	Economy	22300.00
0005435314945	6111	Economy	22300.00
0005433651095	27634	Business	89800.00
0005433651106	27634	Economy	29900.00
0005433651105	27634	Economy	29900.00
0005433651084	27634	Economy	29900.00
0005433651088	27634	Economy	29900.00
0005433651028	27634	Economy	29900.00
0005433651083	27634	Economy	29900.00
0005433651027	27634	Economy	29900.00
0005433651085	27634	Economy	29900.00
0005433651041	27634	Economy	29900.00
0005435860618	4789	Economy	17600.00
0005435860623	4789	Economy	17600.00
0005435860619	4789	Economy	17600.00
0005433869600	32578	Economy	17600.00
0005433869588	32578	Economy	17600.00
0005433869522	32578	Economy	17600.00
0005433869612	32578	Economy	17600.00
0005433869613	32578	Economy	17600.00
0005433869529	32578	Economy	17600.00
0005433869506	32578	Economy	17600.00
0005433869597	32578	Economy	17600.00
0005435911661	3407	Economy	22600.00
0005434663797	12497	Economy	22600.00
0005434663781	12497	Economy	22600.00
0005434663805	12497	Economy	22600.00
0005433869600	14503	Economy	18500.00
0005433869588	14503	Economy	16800.00
0005433869522	14503	Economy	16800.00
0005433869613	14503	Economy	16800.00
0005433869529	14503	Economy	16800.00
0005433869612	14503	Economy	16800.00
0005433869597	14503	Economy	16800.00
0005433869506	14503	Economy	16800.00
0005435860633	32691	Economy	16800.00
0005435860620	32691	Economy	16800.00
0005435860621	32691	Economy	16800.00
0005435860632	32691	Economy	16800.00
0005435860634	32691	Economy	16800.00
0005432800286	12153	Economy	4900.00
0005432800284	12153	Economy	4400.00
0005432800287	12153	Economy	4400.00
0005432800253	12153	Economy	4400.00
0005432800252	12153	Economy	4400.00
0005432800276	12153	Economy	4400.00
0005432800275	12153	Economy	4400.00
0005435293622	7086	Economy	16400.00
0005435311549	7086	Economy	16400.00
0005435311469	7086	Economy	16400.00
0005434409571	26914	Business	49100.00
0005434300231	26914	Economy	16400.00
0005434409543	26914	Economy	16400.00
0005434409615	26914	Economy	16400.00
0005434409582	26914	Economy	16400.00
0005434409522	26914	Economy	16400.00
0005434409597	26914	Economy	16400.00
0005434409523	26914	Economy	16400.00
0005434409517	26914	Economy	16400.00
0005434409567	26914	Economy	16400.00
0005434300224	26914	Economy	18000.00
0005434409539	26914	Economy	16400.00
0005434409596	26914	Economy	16400.00
0005434409593	26914	Economy	16400.00
0005434300233	26914	Economy	16400.00
0005434409526	26914	Economy	16400.00
0005434409577	26914	Economy	16400.00
0005434409518	26914	Economy	16400.00
0005434409581	26914	Economy	16400.00
0005434409524	26914	Economy	16400.00
0005434409538	26914	Economy	16400.00
0005434409616	26914	Economy	16400.00
0005434409572	26914	Economy	16400.00
0005434300230	26914	Economy	16400.00
0005432605493	21366	Economy	16500.00
0005432605440	21366	Economy	15000.00
0005434512244	21366	Economy	15000.00
0005434512245	21366	Economy	15000.00
0005432605516	21366	Economy	15000.00
0005432605439	21366	Economy	15000.00
0005432605507	21366	Economy	15000.00
0005432605492	21366	Economy	15000.00
0005432605490	21366	Economy	15000.00
0005432605494	21366	Economy	15000.00
0005434908777	14978	Business	18900.00
0005434908842	14978	Business	18900.00
0005434908805	14978	Economy	6300.00
0005434908714	14978	Economy	6900.00
0005434908673	14978	Economy	6300.00
0005434908778	14978	Economy	6300.00
0005434908878	14978	Economy	6300.00
0005434908711	14978	Economy	6300.00
0005434908830	14978	Economy	6300.00
0005434908715	14978	Economy	6300.00
0005434908829	14978	Economy	6300.00
0005434908834	14978	Economy	6300.00
0005434908806	14978	Economy	6300.00
0005434908782	14978	Economy	6300.00
0005434908835	14978	Economy	6300.00
0005434908779	14978	Economy	6300.00
0005433252375	25826	Economy	6300.00
0005433252384	25826	Economy	6300.00
0005433252383	25826	Economy	6300.00
0005433810766	14161	Economy	17400.00
0005433810801	14161	Economy	19200.00
0005433810783	14161	Economy	17400.00
0005433810806	14161	Economy	17400.00
0005433810802	14161	Economy	17400.00
0005433810759	14161	Economy	17400.00
0005433810707	14161	Economy	17400.00
0005433810774	14161	Economy	17400.00
0005433810745	14161	Economy	17400.00
0005433810800	14161	Economy	17400.00
0005433810805	14161	Economy	17400.00
0005433810799	14161	Economy	17400.00
0005433810708	14161	Economy	17400.00
0005433810744	14161	Economy	17400.00
0005433009945	22833	Business	52300.00
0005433009958	22833	Business	52300.00
0005433009916	22833	Economy	17400.00
0005433009946	22833	Economy	17400.00
0005433009854	22833	Economy	17400.00
0005433009960	22833	Economy	17400.00
0005433009976	22833	Economy	17400.00
0005433009949	22833	Economy	17400.00
0005433009882	22833	Economy	17400.00
0005433009915	22833	Economy	17400.00
0005433009926	22833	Economy	17400.00
0005433009902	22833	Economy	17400.00
0005433009914	22833	Economy	17400.00
0005433009959	22833	Economy	17400.00
0005433009901	22833	Economy	17400.00
0005435719120	27121	Business	85200.00
0005435719118	27121	Business	85200.00
0005435719114	27121	Business	85200.00
0005435719044	27121	Business	85200.00
0005435719070	27121	Business	85200.00
0005435719068	27121	Economy	28400.00
0005435719054	27121	Economy	28400.00
0005435719096	27121	Economy	28400.00
0005435719104	27121	Economy	28400.00
0005435719078	27121	Economy	28400.00
0005435719103	27121	Economy	28400.00
0005435719043	27121	Economy	28400.00
0005435719113	27121	Economy	31200.00
0005435719116	27121	Economy	28400.00
0005435719109	27121	Economy	28400.00
0005435719093	27121	Economy	28400.00
0005435719108	27121	Economy	28400.00
0005435719097	27121	Economy	28400.00
0005435719119	27121	Economy	28400.00
0005435719049	27121	Economy	28400.00
0005435719075	27121	Economy	28400.00
0005435719061	27121	Economy	28400.00
0005435719106	27121	Economy	28400.00
0005435719079	27121	Economy	28400.00
0005435719121	27121	Economy	28400.00
0005435719048	27121	Economy	28400.00
0005435719042	27121	Economy	28400.00
0005435719071	27121	Economy	28400.00
0005435719099	27121	Economy	28400.00
0005435719123	27121	Economy	28400.00
0005435719073	27121	Economy	28400.00
0005435719067	27121	Economy	28400.00
0005435719098	27121	Economy	28400.00
0005435719074	27121	Economy	28400.00
0005435719122	27121	Economy	28400.00
0005435719124	27121	Economy	28400.00
0005435719058	27121	Economy	28400.00
0005435719112	27121	Economy	28400.00
0005435719115	27121	Economy	28400.00
0005435719083	27121	Economy	28400.00
0005435719117	27121	Economy	28400.00
0005434926809	14958	Economy	7600.00
0005434926733	14958	Economy	7600.00
0005434926863	14958	Economy	7600.00
0005434926808	14958	Economy	7600.00
0005434926856	14958	Economy	7600.00
0005434926732	14958	Economy	7600.00
0005434926821	14958	Economy	7600.00
0005434926735	14958	Economy	7600.00
0005434926851	14958	Economy	7600.00
0005435375180	20536	Economy	7600.00
0005435999852	15800	Economy	8100.00
0005435999818	15800	Economy	8100.00
0005435999855	15800	Economy	8100.00
0005435999864	15800	Economy	8100.00
0005435999817	15800	Economy	8100.00
0005435999835	15800	Economy	8100.00
0005435488371	19685	Economy	8900.00
0005435488402	19685	Economy	8100.00
0005435488478	19685	Economy	8100.00
0005435488372	19685	Economy	8100.00
0005435488408	19685	Economy	8100.00
0005435488448	19685	Economy	8100.00
0005435488444	19685	Economy	8100.00
0005435473248	6032	Business	199300.00
0005435617244	6032	Economy	66400.00
0005435473296	6032	Economy	66400.00
0005432660882	18072	Business	199300.00
0005432660881	18072	Economy	66400.00
0005435840271	18072	Economy	66400.00
0005435840261	18072	Economy	66400.00
0005433462791	19911	Business	146400.00
0005433462800	19911	Business	146400.00
0005433462799	19911	Business	146400.00
0005433462808	19911	Business	146400.00
0005433462806	19911	Economy	48800.00
0005433462792	19911	Economy	48800.00
0005433460497	19911	Economy	48800.00
0005433460483	19911	Economy	48800.00
0005433462797	19911	Economy	48800.00
0005433460486	19911	Economy	48800.00
0005433460496	19911	Economy	48800.00
0005433462805	19911	Economy	48800.00
0005433460492	19911	Economy	48800.00
0005433462793	19911	Economy	48800.00
0005433462807	19911	Economy	48800.00
0005433462804	19911	Economy	48800.00
0005433460498	19911	Economy	48800.00
0005433460481	19911	Economy	53700.00
0005433460495	19911	Economy	48800.00
0005433460493	19911	Economy	48800.00
0005433462794	19911	Economy	48800.00
0005433462803	19911	Economy	48800.00
0005433286163	23005	Economy	5200.00
0005433286166	23005	Economy	5200.00
0005433286197	23005	Economy	5200.00
0005433286223	23005	Economy	5200.00
0005433286229	23005	Economy	5200.00
0005435097523	32079	Business	15700.00
0005435104380	32079	Economy	5200.00
0005435104349	32079	Economy	5200.00
0005435104382	32079	Economy	5200.00
0005435104369	32079	Economy	5200.00
0005435104363	32079	Economy	5200.00
0005435104324	32079	Economy	5200.00
0005435104304	32079	Economy	5200.00
0005435104229	32079	Economy	5200.00
0005435104370	32079	Economy	5200.00
0005435104362	32079	Economy	5700.00
0005435104373	32079	Economy	5700.00
0005435104272	32079	Economy	5200.00
0005435097518	32079	Economy	5200.00
0005435104376	32079	Economy	5200.00
0005435104371	32079	Economy	5200.00
0005435104335	32079	Economy	5200.00
0005435097524	32079	Economy	5200.00
0005435104372	32079	Economy	5200.00
0005435097515	32079	Economy	5200.00
0005435104338	32079	Economy	5200.00
0005435097526	32079	Economy	5200.00
0005435104383	32079	Economy	5200.00
0005435104364	32079	Economy	5200.00
0005435104310	32079	Economy	5200.00
0005435104309	32079	Economy	5200.00
0005434302894	19949	Business	150400.00
0005432802641	19949	Business	150400.00
0005432802621	19949	Business	150400.00
0005434302892	19949	Business	150400.00
0005432802622	19949	Business	150400.00
0005434302901	19949	Business	150400.00
0005432802603	19949	Business	150400.00
0005434302895	19949	Business	150400.00
0005434302899	19949	Business	150400.00
0005432802611	19949	Economy	50100.00
0005432802602	19949	Economy	50100.00
0005432802640	19949	Economy	50100.00
0005432802606	19949	Economy	50100.00
0005432802601	19949	Economy	50100.00
0005432802620	19949	Economy	50100.00
0005432802632	19949	Economy	50100.00
0005434302903	19949	Economy	50100.00
0005434302906	19949	Economy	50100.00
0005432802636	19949	Economy	50100.00
0005432802607	19949	Economy	50100.00
0005432802617	19949	Economy	50100.00
0005433112425	19949	Economy	50100.00
0005434302898	19949	Economy	50100.00
0005432802600	19949	Economy	50100.00
0005432802639	19949	Economy	50100.00
0005432802604	19949	Economy	50100.00
0005432802615	19949	Economy	50100.00
0005432802638	19949	Economy	50100.00
0005432802634	19949	Economy	50100.00
0005432802637	19949	Economy	50100.00
0005434302900	19949	Economy	50100.00
0005434302905	19949	Economy	50100.00
0005432802623	19949	Economy	50100.00
0005432802633	19949	Economy	50100.00
0005434302902	19949	Economy	50100.00
0005434302907	19949	Economy	50100.00
0005433112424	19949	Economy	50100.00
0005434302897	19949	Economy	50100.00
0005432531750	30627	Business	42100.00
0005434069628	30627	Business	42100.00
0005434069592	30627	Business	42100.00
0005434069638	30627	Business	42100.00
0005432531781	30627	Comfort	23900.00
0005432531845	30627	Economy	14000.00
0005432531630	30627	Economy	14000.00
0005434069601	30627	Economy	14000.00
0005432531629	30627	Economy	14000.00
0005432429032	30627	Economy	14000.00
0005432537121	30627	Economy	14000.00
0005434069495	30627	Economy	14000.00
0005432531547	30627	Economy	14000.00
0005432533379	30627	Economy	14000.00
0005434069640	30627	Economy	14000.00
0005432531617	30627	Economy	14000.00
0005434069593	30627	Economy	14000.00
0005434069622	30627	Economy	14000.00
0005432531846	30627	Economy	14000.00
0005434069637	30627	Economy	14000.00
0005432531728	30627	Economy	14000.00
0005434069626	30627	Economy	14000.00
0005432531772	30627	Economy	14000.00
0005434069641	30627	Economy	14000.00
0005432531786	30627	Economy	14000.00
0005432531736	30627	Economy	14000.00
0005434069519	30627	Economy	14000.00
0005434069627	30627	Economy	14000.00
0005434069496	30627	Economy	14000.00
0005434069462	30627	Economy	14000.00
0005432531457	30627	Economy	14000.00
0005432531691	30627	Economy	14000.00
0005434069591	30627	Economy	14000.00
0005432531796	30627	Economy	14000.00
0005434069598	30627	Economy	14000.00
0005432531844	30627	Economy	14000.00
0005432429031	30627	Economy	14000.00
0005432531780	30627	Economy	14000.00
0005432429033	30627	Economy	14000.00
0005432531729	30627	Economy	14000.00
0005432537122	30627	Economy	14000.00
0005432531773	30627	Economy	14000.00
0005434069520	30627	Economy	14000.00
0005435654363	24826	Business	9800.00
0005435654402	24826	Economy	3300.00
0005435654356	24826	Economy	3300.00
0005435654442	24826	Economy	3300.00
0005435654482	24826	Economy	3300.00
0005435654414	24826	Economy	3300.00
0005435654458	24826	Economy	3300.00
0005435654481	24826	Economy	3300.00
0005435654467	24826	Economy	3300.00
0005435654444	24826	Economy	3300.00
0005435654413	24826	Economy	3300.00
0005435654443	24826	Economy	3300.00
0005435654474	24826	Economy	3300.00
0005435654497	24826	Economy	3300.00
0005435654445	24826	Economy	3300.00
0005435654411	24826	Economy	3300.00
0005434980667	23575	Economy	10500.00
0005434980669	23575	Economy	9500.00
0005434980678	23575	Economy	9500.00
0005434980660	23575	Economy	9500.00
0005434980668	23575	Economy	9500.00
0005434980655	23575	Economy	9500.00
0005434980594	23575	Economy	9500.00
0005434302904	19825	Economy	8700.00
0005434302910	19825	Economy	8700.00
0005434140611	11958	Business	9700.00
0005434140455	11958	Business	9700.00
0005434140604	11958	Economy	3200.00
0005434140621	11958	Economy	3200.00
0005434140578	11958	Economy	3200.00
0005434140597	11958	Economy	3200.00
0005434140622	11958	Economy	3200.00
0005434140588	11958	Economy	3200.00
0005434140560	11958	Economy	3200.00
0005434140605	11958	Economy	3200.00
0005434140561	11958	Economy	3200.00
0005434140459	11958	Economy	3200.00
0005434140598	11958	Economy	3200.00
0005435283581	28714	Economy	3200.00
0005435283580	28714	Economy	3500.00
0005435283591	28714	Economy	3200.00
0005435916247	3700	Economy	7200.00
0005435698178	16266	Economy	7900.00
0005435698150	16266	Economy	7200.00
0005434606934	22064	Economy	19300.00
0005434606936	22064	Economy	19300.00
0005433519590	22064	Economy	19300.00
0005434606937	22064	Economy	19300.00
0005435628831	15982	Economy	3700.00
0005434445321	17633	Economy	7100.00
0005435390439	7532	Economy	12500.00
0005435390441	7532	Economy	12500.00
0005435178540	27179	Economy	4900.00
0005434191325	9789	Economy	4400.00
0005434191329	9789	Economy	4400.00
0005434191324	9789	Economy	4400.00
0005435312882	6545	Economy	16100.00
0005435104372	22646	Business	48400.00
0005434505305	22646	Business	48400.00
0005434505300	22646	Business	48400.00
0005434505276	22646	Economy	16100.00
0005435104324	22646	Economy	16100.00
0005434505299	22646	Economy	16100.00
0005434505304	22646	Economy	17800.00
0005435104309	22646	Economy	16100.00
0005435104380	22646	Economy	16100.00
0005435104272	22646	Economy	16100.00
0005435104370	22646	Economy	16100.00
0005435104382	22646	Economy	16100.00
0005435104363	22646	Economy	16100.00
0005434505308	22646	Economy	16100.00
0005435104383	22646	Economy	16100.00
0005435104349	22646	Economy	16100.00
0005435104310	22646	Economy	16100.00
0005435104369	22646	Economy	16100.00
0005435104338	22646	Economy	16100.00
0005435104362	22646	Economy	16100.00
0005435104371	22646	Economy	16100.00
0005435104304	22646	Economy	16100.00
0005435104376	22646	Economy	16100.00
0005435104364	22646	Economy	16100.00
0005435104335	22646	Economy	16100.00
0005434505303	22646	Economy	16100.00
0005435104373	22646	Economy	16100.00
0005435104229	22646	Economy	16100.00
0005433368978	1680	Business	50000.00
0005433368977	1680	Economy	16700.00
0005435654411	21706	Business	50000.00
0005435790410	21706	Business	50000.00
0005435654443	21706	Economy	16700.00
0005435654481	21706	Economy	16700.00
0005435654442	21706	Economy	16700.00
0005435654402	21706	Economy	16700.00
0005435654413	21706	Economy	16700.00
0005435654445	21706	Economy	16700.00
0005435654482	21706	Economy	16700.00
0005435654458	21706	Economy	16700.00
0005435654356	21706	Economy	16700.00
0005435654497	21706	Economy	16700.00
0005435654414	21706	Economy	16700.00
0005435654474	21706	Economy	16700.00
0005435654444	21706	Economy	16700.00
0005435654363	21706	Economy	16700.00
0005435654467	21706	Economy	16700.00
0005433987357	25645	Business	21500.00
0005433987289	25645	Business	21500.00
0005433987318	25645	Business	21500.00
0005433987261	25645	Economy	7200.00
0005433987295	25645	Economy	7200.00
0005433987372	25645	Economy	7200.00
0005433987296	25645	Economy	7200.00
0005433987262	25645	Economy	7200.00
0005433987336	25645	Economy	7200.00
0005433987066	25645	Economy	7200.00
0005433987356	25645	Economy	7200.00
0005433987319	25645	Economy	7200.00
0005435788842	25645	Economy	7200.00
0005435788843	25645	Economy	7200.00
0005432659765	17858	Economy	6000.00
0005432661981	17858	Economy	6000.00
0005432657540	17858	Economy	6000.00
0005432664204	17858	Economy	6000.00
0005432658652	17858	Economy	6000.00
0005432663108	17858	Economy	6000.00
0005432663107	17858	Economy	6000.00
0005432657541	17858	Economy	6000.00
0005432655892	17858	Economy	6000.00
0005432661982	17858	Economy	6000.00
0005432664206	17858	Economy	6000.00
0005432664205	17858	Economy	6000.00
0005432869719	26325	Business	18000.00
0005432869711	26325	Economy	6000.00
0005432330047	31113	Business	16100.00
0005433439097	31113	Economy	5400.00
0005432330020	31113	Economy	5900.00
0005432330004	31113	Economy	5400.00
0005432330041	31113	Economy	5400.00
0005432330016	31113	Economy	5400.00
0005432330039	31113	Economy	5400.00
0005432330019	31113	Economy	5400.00
0005432330006	31113	Economy	5400.00
0005432329924	31113	Economy	5400.00
0005432330058	31113	Economy	5400.00
0005432330042	31113	Economy	5400.00
0005432330038	31113	Economy	5400.00
0005432329925	31113	Economy	5400.00
0005432329923	31113	Economy	5400.00
0005432330031	31113	Economy	5400.00
0005432330015	31113	Economy	5400.00
0005432330005	31113	Economy	5400.00
0005433439107	31113	Economy	5400.00
0005432330032	31113	Economy	5400.00
0005435488469	6198	Economy	41500.00
0005435488468	6198	Economy	41500.00
0005435488436	6198	Economy	41500.00
0005435488441	6198	Economy	41500.00
0005435488476	6198	Economy	41500.00
0005435488463	6198	Economy	41500.00
0005435297267	6198	Economy	41500.00
0005435488440	6198	Economy	41500.00
0005435488461	6198	Economy	41500.00
0005435488464	6198	Economy	41500.00
0005435488467	6198	Economy	41500.00
0005435999852	19540	Economy	41500.00
0005434310141	19540	Economy	41500.00
0005434310145	19540	Economy	45700.00
0005434310139	19540	Economy	41500.00
0005435999817	19540	Economy	41500.00
0005435999855	19540	Economy	41500.00
0005435999864	19540	Economy	41500.00
0005435999835	19540	Economy	41500.00
0005435999818	19540	Economy	41500.00
0005434191331	1587	Business	86000.00
0005434191330	1587	Economy	28700.00
0005434191332	1587	Economy	28700.00
0005435529895	20882	Business	86000.00
0005435545972	20882	Economy	28700.00
0005435502964	20882	Economy	28700.00
0005435529894	20882	Economy	28700.00
0005435529839	20882	Economy	28700.00
0005435502942	20882	Economy	28700.00
0005435529887	20882	Economy	28700.00
0005432629279	28126	Economy	13000.00
0005432629280	28126	Economy	13000.00
0005432675569	17495	Business	115000.00
0005432693951	17495	Economy	38300.00
0005432693888	17495	Economy	42200.00
0005432693904	17495	Economy	38300.00
0005432693887	17495	Economy	38300.00
0005432693938	17495	Economy	38300.00
0005432693802	17495	Economy	38300.00
0005432693919	17495	Economy	38300.00
0005434435616	17284	Economy	13900.00
0005435087061	24416	Economy	8200.00
0005435087056	24416	Economy	8200.00
0005435087062	24416	Economy	7500.00
0005433195016	4836	Business	44200.00
0005433194982	4836	Business	44200.00
0005433194981	4836	Economy	14700.00
0005435937552	27442	Economy	3100.00
0005434409514	20267	Business	12000.00
0005434409611	20267	Business	12000.00
0005434409548	20267	Economy	4000.00
0005434409515	20267	Economy	4000.00
0005434409600	20267	Economy	4000.00
0005434409547	20267	Economy	4000.00
0005435311539	27001	Economy	4000.00
0005435311552	27001	Economy	4000.00
0005435311557	27001	Economy	4000.00
0005435311559	27001	Economy	4000.00
0005435311551	27001	Economy	4000.00
0005435311538	27001	Economy	4000.00
0005435311558	27001	Economy	4000.00
0005435297400	5678	Economy	14400.00
0005435297399	5678	Economy	14400.00
0005433124539	5678	Economy	14400.00
0005434310167	15686	Economy	14400.00
0005434319867	15686	Economy	14400.00
0005434310168	15686	Economy	14400.00
0005434310166	15686	Economy	14400.00
0005434319847	15686	Economy	14400.00
0005434310182	15686	Economy	14400.00
0005434319848	15686	Economy	14400.00
0005434505323	16617	Economy	24900.00
0005434484541	16617	Economy	24900.00
0005434505321	16617	Economy	24900.00
0005434505324	16617	Economy	24900.00
0005434505322	16617	Economy	24900.00
0005434310167	7555	Business	11100.00
0005433722514	7555	Business	11100.00
0005433722420	7555	Business	11100.00
0005435477021	7555	Economy	3700.00
0005433722481	7555	Economy	3700.00
0005433722495	7555	Economy	3700.00
0005434310166	7555	Economy	3700.00
0005433722482	7555	Economy	3700.00
0005433722491	7555	Economy	3700.00
0005433722513	7555	Economy	3700.00
0005434310168	7555	Economy	3700.00
0005433722487	7555	Economy	3700.00
0005433722503	7555	Economy	3700.00
0005434310182	7555	Economy	3700.00
0005433722486	7555	Economy	3700.00
0005432693887	30423	Business	11100.00
0005432693919	30423	Economy	3700.00
0005432693888	30423	Economy	3700.00
0005432693951	30423	Economy	3700.00
0005432693938	30423	Economy	3700.00
0005432693904	30423	Economy	3700.00
0005432693802	30423	Economy	3700.00
0005433124539	30424	Economy	3700.00
0005433193436	1410	Economy	23500.00
0005433525357	18512	Business	70400.00
0005434587341	18512	Economy	23500.00
0005434345259	29803	Economy	4000.00
0005434345084	29803	Economy	4000.00
0005434345297	29803	Economy	4000.00
0005434345251	29803	Economy	4000.00
0005433416090	1247	Economy	66600.00
0005435825419	18030	Economy	66600.00
0005435626888	5623	Business	27800.00
0005435477005	5623	Business	27800.00
0005435243649	5623	Economy	9300.00
0005435477004	5623	Economy	9300.00
0005435243650	5623	Economy	9300.00
0005435626887	5623	Economy	9300.00
0005435243641	5623	Economy	9300.00
0005435243642	5623	Economy	9300.00
0005432785359	15335	Business	27800.00
0005435950043	15335	Business	27800.00
0005435950032	15335	Business	27800.00
0005432785300	15335	Economy	9300.00
0005432785366	15335	Economy	9300.00
0005432785297	15335	Economy	9300.00
0005432785356	15335	Economy	9300.00
0005435851177	4338	Economy	6300.00
0005435257531	6280	Economy	4000.00
0005435257532	6280	Economy	4000.00
0005434926822	20346	Business	11900.00
0005434926849	20346	Business	11900.00
0005434444184	20346	Economy	4000.00
0005434926848	20346	Economy	4000.00
0005433497893	20346	Economy	4000.00
0005434926751	20346	Economy	4000.00
0005434926750	20346	Economy	4000.00
0005434926815	20346	Economy	4000.00
0005434926813	20346	Economy	4000.00
0005433497894	20346	Economy	4000.00
0005434444186	20346	Economy	4000.00
0005434926814	20346	Economy	4000.00
0005434444185	20346	Economy	4000.00
0005432785363	12180	Economy	13700.00
0005432785357	12180	Economy	13700.00
0005432785362	12180	Economy	13700.00
0005435243658	15402	Economy	13700.00
0005435243647	15402	Economy	13700.00
0005435243628	15402	Economy	13700.00
0005435243646	15402	Economy	13700.00
0005435243648	15402	Economy	13700.00
0005434880983	10086	Business	49700.00
0005434880879	10086	Economy	16600.00
0005434880974	10086	Economy	16600.00
0005434880880	10086	Economy	16600.00
0005434880925	10086	Economy	16600.00
0005435914208	14610	Economy	16600.00
0005435914184	14610	Economy	16600.00
0005435914175	14610	Economy	16600.00
0005435914176	14610	Economy	16600.00
0005435914207	14610	Economy	16600.00
0005435933560	9249	Economy	20300.00
0005433681970	29180	Economy	11000.00
0005433681971	29180	Economy	11000.00
0005433681973	29180	Economy	11000.00
0005434152851	9315	Economy	44300.00
0005433616829	25240	Economy	44300.00
0005433616803	25240	Economy	44300.00
0005433634826	25240	Economy	44300.00
0005433616764	25240	Economy	44300.00
0005433616775	25240	Economy	44300.00
0005433634827	25240	Economy	44300.00
0005433616762	25240	Economy	44300.00
0005433616779	25240	Economy	44300.00
0005433634813	25240	Economy	44300.00
0005433634825	25240	Economy	44300.00
0005433616765	25240	Economy	44300.00
0005433616830	25240	Economy	44300.00
0005433616774	25240	Economy	44300.00
0005433616796	25240	Economy	44300.00
0005435856320	4239	Business	193100.00
0005435477025	4239	Business	193100.00
0005435477024	4239	Economy	70800.00
0005435856331	4239	Economy	64400.00
0005435856321	4239	Economy	64400.00
0005435787413	4239	Economy	64400.00
0005435960174	26602	Economy	64400.00
0005435960175	26602	Economy	64400.00
0005435987060	26602	Economy	64400.00
0005432949656	350	Business	21500.00
0005432949597	350	Business	21500.00
0005432949598	350	Economy	7200.00
0005432949695	350	Economy	7200.00
0005433929883	350	Economy	7200.00
0005433075547	350	Economy	7200.00
0005433134264	350	Economy	7200.00
0005433570726	11619	Business	21500.00
0005434326044	11619	Business	21500.00
0005433570969	11619	Business	21500.00
0005434088045	11619	Business	21500.00
0005433570730	11619	Business	21500.00
0005433570968	11619	Business	21500.00
0005433570828	11619	Business	21500.00
0005433570949	11619	Business	21500.00
0005434326031	11619	Business	21500.00
0005434326043	11619	Business	21500.00
0005434088041	11619	Business	21500.00
0005433570748	11619	Business	21500.00
0005433570923	11619	Economy	7900.00
0005433570912	11619	Economy	7200.00
0005433570749	11619	Economy	7200.00
0005433570954	11619	Economy	7200.00
0005433570978	11619	Economy	7200.00
0005433570725	11619	Economy	7200.00
0005433570961	11619	Economy	7200.00
0005433570892	11619	Economy	7200.00
0005434088043	11619	Economy	7200.00
0005433570862	11619	Economy	7200.00
0005434088040	11619	Economy	7200.00
0005433570950	11619	Economy	7200.00
0005433570953	11619	Economy	7200.00
0005433570900	11619	Economy	7200.00
0005433570952	11619	Economy	7900.00
0005434326029	11619	Economy	7200.00
0005434326017	11619	Economy	7900.00
0005433570977	11619	Economy	7200.00
0005433570951	11619	Economy	7200.00
0005433570957	11619	Economy	7200.00
0005434326016	11619	Economy	7200.00
0005433570979	11619	Economy	7200.00
0005434088055	11619	Economy	7200.00
0005433570897	11619	Economy	7200.00
0005434326030	11619	Economy	7200.00
0005434326048	11619	Economy	7200.00
0005433817572	13953	Economy	6300.00
0005432986001	2333	Business	184500.00
0005432986002	2333	Economy	61500.00
0005432869725	2333	Economy	61500.00
0005432986014	2333	Economy	61500.00
0005433435505	2333	Economy	61500.00
0005432869721	2333	Economy	61500.00
0005432986017	2333	Economy	61500.00
0005432986015	2333	Economy	61500.00
0005432986003	2333	Economy	61500.00
0005432986018	2333	Economy	61500.00
0005432986007	2333	Economy	61500.00
0005432869722	2333	Economy	61500.00
0005435983588	26166	Business	184500.00
0005433755789	26166	Economy	61500.00
0005433755874	26166	Economy	61500.00
0005433755742	26166	Economy	61500.00
0005435983642	26166	Economy	61500.00
0005433152411	1496	Economy	13000.00
0005433152416	1496	Economy	13000.00
0005434375924	20137	Business	38900.00
0005434376030	20137	Economy	13000.00
0005434375923	20137	Economy	13000.00
0005434376031	20137	Economy	13000.00
0005434376042	20137	Economy	14300.00
0005434376067	20137	Economy	13000.00
0005434376068	20137	Economy	13000.00
0005433262055	603	Business	27500.00
0005433158206	603	Economy	9200.00
0005433766768	603	Economy	9200.00
0005434995378	12830	Business	27500.00
0005434995377	12830	Business	27500.00
0005434995372	12830	Business	27500.00
0005434995376	12830	Economy	9200.00
0005432426008	12860	Business	27500.00
0005432426070	12860	Business	27500.00
0005432425999	12860	Business	27500.00
0005432426001	12860	Business	27500.00
0005432426018	12860	Economy	10100.00
0005432426003	12860	Economy	10100.00
0005432426026	12860	Economy	9200.00
0005432425991	12860	Economy	9200.00
0005432425990	12860	Economy	9200.00
0005432426077	12860	Economy	9200.00
0005432426074	12860	Economy	9200.00
0005432425998	12860	Economy	9200.00
0005432426049	12860	Economy	9200.00
0005432426000	12860	Economy	9200.00
0005432426027	12860	Economy	9200.00
0005432426017	12860	Economy	9200.00
0005432426028	12860	Economy	9200.00
0005432426046	12860	Economy	9200.00
0005432425883	12860	Economy	10100.00
0005432426052	12860	Economy	9200.00
0005432426056	12860	Economy	9200.00
0005432425900	12860	Economy	9200.00
0005432426002	12860	Economy	9200.00
0005432425884	12860	Economy	9200.00
0005432426047	12860	Economy	9200.00
0005432426075	12860	Economy	9200.00
0005432425897	12860	Economy	9200.00
0005432425807	12860	Economy	9200.00
0005432426034	12860	Economy	9200.00
0005432425901	12860	Economy	9200.00
0005432426055	12860	Economy	9200.00
0005432426069	12860	Economy	9200.00
0005434735839	467	Business	24500.00
0005433059057	467	Economy	8200.00
0005433929733	467	Economy	8200.00
0005434735840	467	Economy	8200.00
0005433059064	467	Economy	8200.00
0005433059013	467	Economy	8200.00
0005433059052	467	Economy	8200.00
0005433059059	467	Economy	8200.00
0005433059014	467	Economy	8200.00
0005433929734	467	Economy	8200.00
0005433059053	467	Economy	8200.00
0005434025693	12667	Business	24500.00
0005434025655	12667	Economy	8200.00
0005434025635	12667	Economy	8200.00
0005434025670	12667	Economy	8200.00
0005434025692	12667	Economy	8200.00
0005434025654	12667	Economy	8200.00
0005434032157	12667	Economy	8200.00
0005433529384	32441	Business	111600.00
0005433529376	32441	Business	111600.00
0005433529388	32441	Business	111600.00
0005433529389	32441	Economy	37200.00
0005433529377	32441	Economy	37200.00
0005433533419	32441	Economy	37200.00
0005433533420	32441	Economy	37200.00
0005433529375	32441	Economy	37200.00
0005433037824	2162	Business	34700.00
0005434175881	2162	Business	34700.00
0005434088056	2162	Business	34700.00
0005434175882	2162	Economy	11600.00
0005434088057	2162	Economy	11600.00
0005433037845	2162	Economy	11600.00
0005433037823	2162	Economy	11600.00
0005434088058	2162	Economy	11600.00
0005432749852	2162	Economy	11600.00
0005433926069	24106	Business	34700.00
0005433929731	24106	Economy	12700.00
0005433929732	24106	Economy	11600.00
0005433926107	24106	Economy	11600.00
0005433926060	24106	Economy	11600.00
0005433929726	24106	Economy	11600.00
0005433236054	253	Comfort	47400.00
0005433126984	253	Comfort	47400.00
0005433236066	253	Comfort	47400.00
0005433236065	253	Economy	27900.00
0005433126983	253	Economy	27900.00
0005433236025	253	Economy	27900.00
0005433236017	253	Economy	27900.00
0005433236056	253	Economy	27900.00
0005433236024	253	Economy	27900.00
0005433236016	253	Economy	27900.00
0005433236059	253	Economy	27900.00
0005433111567	253	Economy	27900.00
0005433236029	253	Economy	27900.00
0005433235937	253	Economy	27900.00
0005433236030	253	Economy	27900.00
0005433236060	253	Economy	27900.00
0005433236055	253	Economy	27900.00
0005435142966	9848	Business	83700.00
0005434729020	9848	Business	83700.00
0005434552818	9848	Comfort	47400.00
0005434729021	9848	Comfort	47400.00
0005434552862	9848	Comfort	47400.00
0005434552766	9848	Comfort	47400.00
0005434728873	9848	Comfort	47400.00
0005434728872	9848	Economy	27900.00
0005434728958	9848	Economy	27900.00
0005434728957	9848	Economy	27900.00
0005435142965	9848	Economy	27900.00
0005434552858	9848	Economy	27900.00
0005434552843	9848	Economy	27900.00
0005434552794	9848	Economy	27900.00
0005434728960	9848	Economy	27900.00
0005434552795	9848	Economy	27900.00
0005434552859	9848	Economy	27900.00
0005435725741	7729	Comfort	23900.00
0005435215481	7729	Economy	14000.00
0005435215531	7729	Economy	14000.00
0005435215482	7729	Economy	14000.00
0005435215516	7729	Economy	14000.00
0005435215484	7729	Economy	14000.00
0005435654517	5334	Business	43100.00
0005434245816	5334	Business	43100.00
0005435426811	5334	Business	43100.00
0005434245824	5334	Business	43100.00
0005435654518	5334	Comfort	24400.00
0005433719241	5334	Comfort	24400.00
0005435319827	5334	Economy	14400.00
0005435426839	5334	Economy	14400.00
0005433719238	5334	Economy	14400.00
0005435426817	5334	Economy	14400.00
0005435426831	5334	Economy	14400.00
0005435950052	5334	Economy	14400.00
0005434245827	5334	Economy	14400.00
0005433719237	5334	Economy	14400.00
0005434245828	5334	Economy	14400.00
0005435426818	5334	Economy	14400.00
0005435426850	5334	Economy	14400.00
0005434245846	5334	Economy	14400.00
0005435380442	5334	Economy	14400.00
0005434245847	5334	Economy	14400.00
0005435426851	5334	Economy	14400.00
0005434245823	5334	Economy	14400.00
0005435616969	10909	Business	43100.00
0005434345277	10909	Business	43100.00
0005435097502	10909	Business	43100.00
0005435617059	10909	Comfort	24400.00
0005435556768	10909	Business	43100.00
0005435616961	10909	Comfort	24400.00
0005435097486	10909	Comfort	24400.00
0005435626887	10909	Comfort	24400.00
0005434345214	10909	Comfort	24400.00
0005435097497	10909	Economy	14400.00
0005434573773	10909	Economy	14400.00
0005434345270	10909	Economy	14400.00
0005435626888	10909	Economy	14400.00
0005434345276	10909	Economy	14400.00
0005434345278	10909	Economy	14400.00
0005435617058	10909	Economy	14400.00
0005434573771	10909	Economy	14400.00
0005434345142	10909	Economy	14400.00
0005434345286	10909	Economy	14400.00
0005434573772	10909	Economy	14400.00
0005435097496	10909	Economy	14400.00
0005435616855	10909	Economy	14400.00
0005435551776	10909	Economy	15800.00
0005435616854	10909	Economy	14400.00
0005435617245	10909	Economy	14400.00
0005434345141	10909	Economy	14400.00
0005435617044	10909	Economy	14400.00
0005435097501	10909	Economy	14400.00
0005435551777	10909	Economy	14400.00
0005434345269	10909	Economy	14400.00
0005435556769	10909	Economy	14400.00
0005435858748	3272	Business	18800.00
0005432461440	3272	Business	18800.00
0005432461375	3272	Business	18800.00
0005435858736	3272	Economy	6300.00
0005432461405	3272	Economy	6300.00
0005435858746	3272	Economy	6300.00
0005432461417	3272	Economy	6300.00
0005434326104	3272	Economy	6300.00
0005435858747	3272	Economy	6300.00
0005432461386	3272	Economy	6300.00
0005432461418	3272	Economy	6300.00
0005432461385	3272	Economy	6300.00
0005435886875	3271	Business	18800.00
0005435886871	3271	Economy	6900.00
0005435886806	3271	Economy	6900.00
0005435886854	3271	Economy	6300.00
0005435886860	3271	Economy	6300.00
0005435886861	3271	Economy	6300.00
0005435886841	3271	Economy	6900.00
0005435886874	3271	Economy	6300.00
0005435886862	3271	Economy	6300.00
0005433507719	8270	Business	18800.00
0005435629452	8270	Business	18800.00
0005433806379	8268	Business	18800.00
0005434143848	8268	Business	18800.00
0005433634827	8268	Business	18800.00
0005434143853	8268	Economy	6900.00
0005434143856	8268	Economy	6300.00
0005434143855	8268	Economy	6300.00
0005434143838	8268	Economy	6300.00
0005433806386	8268	Economy	6300.00
0005434143818	8268	Economy	6300.00
0005434143858	8268	Economy	6300.00
0005434143832	8268	Economy	6900.00
0005433634826	8268	Economy	6300.00
0005433806394	8268	Economy	6300.00
0005434143794	8268	Economy	6300.00
0005433634813	8268	Economy	6300.00
0005434143847	8268	Economy	6300.00
0005433806395	8268	Economy	6300.00
0005434143837	8268	Economy	6300.00
0005433634825	8268	Economy	6300.00
0005434266036	8257	Business	18800.00
0005434265981	8257	Business	18800.00
0005434266035	8257	Business	18800.00
0005434230047	8257	Economy	6900.00
0005434265914	8257	Economy	6300.00
0005434150223	8257	Economy	6300.00
0005434150170	8257	Economy	6300.00
0005434266042	8257	Economy	6300.00
0005434230049	8257	Economy	6300.00
0005434266041	8257	Economy	6300.00
0005434230048	8257	Economy	6300.00
0005432384328	30091	Business	9900.00
0005432384327	30091	Business	9900.00
0005432384286	30091	Business	9900.00
0005433722416	30091	Business	9900.00
0005433722512	30091	Business	9900.00
0005432384098	30091	Business	9900.00
0005434300236	30091	Business	9900.00
0005432728305	30091	Economy	3300.00
0005432384314	30091	Economy	3300.00
0005433722453	30091	Economy	3300.00
0005433722448	30091	Economy	3300.00
0005432384214	30091	Economy	3300.00
0005432384338	30091	Economy	3300.00
0005432384226	30091	Economy	3600.00
0005433722507	30091	Economy	3600.00
0005433722437	30091	Economy	3600.00
0005433195016	30091	Economy	3600.00
0005434300235	30091	Economy	3300.00
0005433722418	30091	Economy	3300.00
0005432384301	30091	Economy	3300.00
0005433722488	30091	Economy	3300.00
0005435477024	30091	Economy	3300.00
0005432384323	30091	Economy	3300.00
0005433722456	30091	Economy	3300.00
0005432384212	30091	Economy	3300.00
0005432384326	30091	Economy	3300.00
0005435477025	30091	Economy	3300.00
0005433722452	30091	Economy	3300.00
0005432728304	30091	Economy	3300.00
0005434300246	30091	Economy	3300.00
0005432384329	30091	Economy	3300.00
0005432384315	30091	Economy	3300.00
0005432384300	30091	Economy	3300.00
0005433722508	30091	Economy	3300.00
0005433722417	30091	Economy	3300.00
0005433194982	30091	Economy	3300.00
0005433722438	30091	Economy	3300.00
0005434300242	30091	Economy	3300.00
0005433194981	30091	Economy	3300.00
0005432384225	30091	Economy	3300.00
0005432384309	30091	Economy	3300.00
0005433722455	30091	Economy	3300.00
0005434300243	30091	Economy	3300.00
0005432384285	30091	Economy	3300.00
0005432728311	30091	Economy	3300.00
0005433722444	30091	Economy	3300.00
0005432384213	30091	Economy	3300.00
0005434300259	30091	Economy	3300.00
0005434300253	30091	Economy	3300.00
0005432384322	30091	Economy	3300.00
0005434300258	30091	Economy	3300.00
0005432925172	1743	Economy	19100.00
0005435546229	22027	Business	57200.00
0005435541653	22027	Business	57200.00
0005435541609	22027	Business	57200.00
0005435518374	22027	Economy	19100.00
0005433517157	22027	Economy	19100.00
0005433517167	22027	Economy	19100.00
0005435541596	22027	Economy	21000.00
0005435518450	22027	Economy	19100.00
0005435541651	22027	Economy	19100.00
0005435541652	22027	Economy	19100.00
0005435541595	22027	Economy	19100.00
0005433517156	22027	Economy	19100.00
0005435518451	22027	Economy	19100.00
0005433517168	22027	Economy	19100.00
0005435541641	22027	Economy	19100.00
0005435541594	22027	Economy	19100.00
0005432823508	28936	Economy	6800.00
0005432839916	28936	Economy	6200.00
0005434459416	28936	Economy	6200.00
0005432823509	28936	Economy	6200.00
0005432839917	28936	Economy	6200.00
0005435990831	15715	Business	145300.00
0005435990832	15715	Economy	48400.00
0005435990834	15715	Economy	48400.00
0005434150071	6387	Economy	12200.00
0005435723105	6387	Economy	12200.00
0005435723104	6387	Economy	12200.00
0005434150070	6387	Economy	12200.00
0005432361774	20992	Economy	12200.00
0005432361773	20992	Economy	12200.00
0005434459423	17690	Economy	3100.00
0005432605517	31667	Economy	6600.00
0005432605473	31667	Economy	6600.00
0005432605518	31667	Economy	6600.00
0005432605500	31667	Economy	6600.00
0005432605459	31667	Economy	6600.00
0005432605515	31667	Economy	6600.00
0005432605479	31667	Economy	6600.00
0005432605458	31667	Economy	6600.00
0005432605508	31667	Economy	6600.00
0005432605480	31667	Economy	6600.00
0005432891593	389	Business	44500.00
0005432891581	389	Business	44500.00
0005432891586	389	Economy	14800.00
0005433293432	389	Economy	14800.00
0005432891584	389	Economy	14800.00
0005434152869	389	Economy	14800.00
0005432891585	389	Economy	14800.00
0005433875430	389	Economy	14800.00
0005432891580	389	Economy	14800.00
0005432891560	389	Economy	14800.00
0005434152873	389	Economy	14800.00
0005433875431	389	Economy	14800.00
0005432891561	389	Economy	14800.00
0005432891594	389	Economy	14800.00
0005432891587	389	Economy	14800.00
0005432753400	12073	Business	44500.00
0005435154705	12073	Business	44500.00
0005432748683	12073	Economy	14800.00
0005435154693	12073	Economy	14800.00
0005435154692	12073	Economy	14800.00
0005435154704	12073	Economy	14800.00
0005435154706	12073	Economy	14800.00
0005435154691	12073	Economy	14800.00
0005432928149	18947	Economy	25700.00
0005433525360	32469	Economy	25700.00
0005433525359	32469	Economy	25700.00
0005433531405	32469	Economy	25700.00
0005435299920	5245	Business	84000.00
0005435179720	5245	Economy	28000.00
0005435315106	5245	Economy	28000.00
0005435375159	5245	Economy	28000.00
0005435662009	5245	Economy	28000.00
0005435375158	5245	Economy	30800.00
0005435375157	5245	Economy	28000.00
0005435179719	5245	Economy	28000.00
0005435150427	9900	Business	84000.00
0005435150434	9900	Business	84000.00
0005434558573	9900	Business	84000.00
0005435150419	9900	Business	84000.00
0005434827264	9900	Comfort	47600.00
0005434558590	9900	Comfort	47600.00
0005434827185	9900	Economy	28000.00
0005435150433	9900	Economy	28000.00
0005434558518	9900	Economy	28000.00
0005434558574	9900	Economy	28000.00
0005434827252	9900	Economy	28000.00
0005434558595	9900	Economy	28000.00
0005434827104	9900	Economy	28000.00
0005435150435	9900	Economy	28000.00
0005434558589	9900	Economy	30800.00
0005434558572	9900	Economy	28000.00
0005435150432	9900	Economy	28000.00
0005434558530	9900	Economy	28000.00
0005434827268	9900	Economy	28000.00
0005434827251	9900	Economy	28000.00
0005435150420	9900	Economy	28000.00
0005434827267	9900	Economy	28000.00
0005434827105	9900	Economy	28000.00
0005434558596	9900	Economy	28000.00
0005434827265	9900	Economy	28000.00
0005434558517	9900	Economy	28000.00
0005435150431	9900	Economy	28000.00
0005434215822	9572	Economy	10900.00
0005434215829	9572	Economy	10900.00
0005434215902	9572	Economy	10900.00
0005434215828	9572	Economy	10900.00
0005434215821	9572	Economy	10900.00
0005434757686	28633	Business	32800.00
0005434757671	28633	Business	32800.00
0005434757690	28633	Business	32800.00
0005434757662	28633	Economy	10900.00
0005434757661	28633	Economy	10900.00
0005434757531	28633	Economy	12000.00
0005434757659	28633	Economy	10900.00
0005434757670	28633	Economy	10900.00
0005434757532	28633	Economy	10900.00
0005434757605	28633	Economy	10900.00
0005434757534	28633	Economy	10900.00
0005434757533	28633	Economy	10900.00
0005434757691	28633	Economy	10900.00
0005434757641	28633	Economy	10900.00
0005434757614	28633	Economy	10900.00
0005433202793	1971	Economy	20900.00
0005433202794	1971	Economy	19000.00
0005434640093	23257	Economy	20900.00
0005434640032	23257	Economy	19000.00
0005434640084	23257	Economy	19000.00
0005434640049	23257	Economy	19000.00
0005434640083	23257	Economy	19000.00
0005434640091	23257	Economy	19000.00
0005434640092	23257	Economy	19000.00
0005434640106	23257	Economy	19000.00
0005434640031	23257	Economy	19000.00
0005434640068	23257	Economy	19000.00
0005435327139	6052	Business	69700.00
0005435327140	6052	Economy	23200.00
0005433527372	18580	Economy	23200.00
0005434601598	18580	Economy	23200.00
0005434601595	18580	Economy	23200.00
0005434601535	18580	Economy	23200.00
0005434601596	18580	Economy	23200.00
0005433527373	18580	Economy	23200.00
0005434601599	18580	Economy	23200.00
0005434601534	18580	Economy	23200.00
0005433181816	10618	Business	9100.00
0005433181831	10618	Economy	3300.00
0005435315119	10618	Economy	3000.00
0005433181817	10618	Economy	3000.00
0005433181838	10618	Economy	3000.00
0005435315120	10618	Economy	3000.00
0005434552857	27719	Economy	3000.00
0005434552845	27719	Economy	3000.00
0005434558588	27719	Economy	3000.00
0005434552846	27719	Economy	3000.00
0005434552856	27719	Economy	3000.00
0005434558612	27719	Economy	3000.00
0005434552767	27719	Economy	3000.00
0005433459343	19298	Economy	11700.00
0005433459342	19298	Economy	11700.00
0005434828775	6748	Business	51100.00
0005435438591	6748	Business	51100.00
0005434828774	6748	Business	51100.00
0005435220386	6748	Economy	17000.00
0005435438592	6748	Economy	17000.00
0005432533376	6748	Economy	17000.00
0005435683321	24592	Business	51100.00
0005435683320	24592	Economy	17000.00
0005435654519	24592	Economy	17000.00
0005435654514	24592	Economy	17000.00
0005435683334	24592	Economy	17000.00
0005435654520	24592	Economy	17000.00
0005435127574	31873	Economy	8800.00
0005435127588	31873	Economy	8800.00
0005435732728	13508	Economy	12200.00
0005435732729	13508	Economy	12200.00
0005433399464	19394	Economy	12200.00
0005433399436	19394	Economy	12200.00
0005433399421	19394	Economy	12200.00
0005433399447	19394	Economy	12200.00
0005435070511	13141	Economy	3800.00
0005435070526	13141	Economy	3800.00
0005435070506	13141	Economy	4100.00
0005435070525	13141	Economy	3800.00
0005435070510	13141	Economy	3800.00
0005435070507	13141	Economy	3800.00
0005435070544	13141	Economy	3800.00
0005435070505	13141	Economy	3800.00
0005435925711	15514	Business	11300.00
0005434757684	10729	Economy	20400.00
0005434757680	10729	Economy	20400.00
0005434757665	10729	Economy	20400.00
0005434757677	10729	Economy	20400.00
0005434757597	10729	Economy	20400.00
0005434757678	10729	Economy	20400.00
0005434757685	10729	Economy	20400.00
0005434757664	10729	Economy	20400.00
0005434757676	10729	Economy	20400.00
0005434757692	10729	Economy	20400.00
0005434757596	10729	Economy	20400.00
0005434757667	10729	Economy	20400.00
0005434757693	10729	Economy	20400.00
0005434215852	28689	Business	61300.00
0005434215877	28689	Economy	20400.00
0005434215876	28689	Economy	20400.00
0005434215891	28689	Economy	20400.00
0005434215888	28689	Economy	20400.00
0005434215900	28689	Economy	20400.00
0005434215883	28689	Economy	20400.00
0005434215884	28689	Economy	20400.00
0005434215901	28689	Economy	20400.00
0005434215882	28689	Economy	20400.00
0005434215851	28689	Economy	20400.00
0005434230043	5454	Economy	9800.00
0005435377987	5454	Economy	9800.00
0005435377985	5454	Economy	9800.00
0005434230027	5454	Economy	9800.00
0005435556769	5454	Economy	9800.00
0005435556768	5454	Economy	9800.00
0005435377986	5454	Economy	10800.00
0005434230026	5454	Economy	9800.00
0005435377990	5454	Economy	9800.00
0005434230035	5454	Economy	9800.00
0005435041621	12971	Economy	9800.00
0005435041672	12971	Economy	9800.00
0005435041620	12971	Economy	9800.00
0005435041694	12971	Economy	9800.00
0005435041690	12971	Economy	9800.00
0005435041662	12971	Economy	9800.00
0005435041680	12971	Economy	9800.00
0005435041679	12971	Economy	9800.00
0005435041693	12971	Economy	9800.00
0005435042939	12971	Economy	9800.00
0005435903215	14848	Business	52900.00
0005435554318	14848	Economy	17600.00
0005435903217	14848	Economy	17600.00
0005435554319	14848	Economy	17600.00
0005434411900	20183	Business	52900.00
0005434427459	20183	Economy	17600.00
0005434427471	20183	Economy	17600.00
0005434427475	20183	Economy	17600.00
0005434427458	20183	Economy	17600.00
0005434427432	20183	Economy	17600.00
0005433435502	26552	Business	18500.00
0005434270267	26552	Economy	6200.00
0005433435490	26552	Economy	6200.00
0005433435479	26552	Economy	6200.00
0005434273127	26552	Economy	6200.00
0005433435466	26552	Economy	6200.00
0005434273126	26552	Economy	6200.00
0005433435465	26552	Economy	6200.00
0005433435503	26552	Economy	6200.00
0005433435478	26552	Economy	6200.00
0005433435508	26552	Economy	6200.00
0005433435480	26552	Economy	6200.00
0005433435489	26552	Economy	6200.00
0005434268064	26552	Economy	6200.00
0005433435470	26552	Economy	6200.00
0005435983642	26700	Economy	6200.00
0005435983588	26700	Economy	6200.00
0005434943593	16198	Economy	7500.00
0005433654984	27606	Economy	30200.00
0005433654969	27606	Economy	30200.00
0005433654983	27606	Economy	30200.00
0005433654976	27606	Economy	30200.00
0005433654970	27606	Economy	30200.00
0005433654981	27606	Economy	30200.00
0005433811690	14363	Economy	4400.00
0005433368960	21756	Business	9800.00
0005433368969	21756	Business	9800.00
0005433368937	21756	Economy	3300.00
0005433368955	21756	Economy	3300.00
0005433368954	21756	Economy	3300.00
0005433368956	21756	Economy	3300.00
0005433368915	21756	Economy	3300.00
0005435858747	9376	Business	186200.00
0005435858748	9376	Economy	62100.00
0005434171465	9376	Economy	62100.00
0005435858736	9376	Economy	62100.00
0005435270206	9376	Economy	62100.00
0005435270205	9376	Economy	62100.00
0005435858746	9376	Economy	62100.00
0005433786198	26221	Business	186200.00
0005433806386	26221	Business	186200.00
0005433786196	26221	Economy	68300.00
0005433806395	26221	Economy	68300.00
0005433785984	26221	Economy	62100.00
0005433806379	26221	Economy	62100.00
0005433786000	26221	Economy	62100.00
0005433786001	26221	Economy	62100.00
0005433806394	26221	Economy	62100.00
0005433786195	26221	Economy	62100.00
0005433785985	26221	Economy	62100.00
0005435135804	33034	Economy	5300.00
0005435135805	33034	Economy	5300.00
0005433962750	24262	Business	36400.00
0005433987066	24262	Business	36400.00
0005433962466	24262	Business	36400.00
0005433962686	24262	Business	36400.00
0005433987336	24262	Business	36400.00
0005433962702	24262	Business	36400.00
0005433962773	24262	Business	36400.00
0005433962731	24262	Economy	13400.00
0005433962758	24262	Economy	13400.00
0005433962751	24262	Economy	13400.00
0005433962717	24262	Economy	12100.00
0005433962586	24262	Economy	12100.00
0005433962640	24262	Economy	12100.00
0005433987262	24262	Economy	12100.00
0005433962687	24262	Economy	12100.00
0005433962707	24262	Economy	12100.00
0005433987296	24262	Economy	12100.00
0005433962700	24262	Economy	12100.00
0005433987319	24262	Economy	12100.00
0005433962541	24262	Economy	12100.00
0005433962585	24262	Economy	12100.00
0005433962701	24262	Economy	12100.00
0005433962740	24262	Economy	12100.00
0005433962598	24262	Economy	12100.00
0005433987318	24262	Economy	12100.00
0005433962473	24262	Economy	12100.00
0005433962703	24262	Economy	13400.00
0005433962625	24262	Economy	12100.00
0005433962720	24262	Economy	12100.00
0005433962704	24262	Economy	12100.00
0005433962696	24262	Economy	12100.00
0005433987356	24262	Economy	12100.00
0005433987357	24262	Economy	12100.00
0005433962759	24262	Economy	12100.00
0005433962718	24262	Economy	12100.00
0005433962739	24262	Economy	12100.00
0005433987295	24262	Economy	12100.00
0005433962719	24262	Economy	12100.00
0005433987261	24262	Economy	12100.00
0005433962681	24262	Economy	12100.00
0005433987289	24262	Economy	12100.00
0005433962624	24262	Economy	12100.00
0005433987372	24262	Economy	12100.00
0005433166268	954	Economy	25400.00
0005433166267	954	Economy	23100.00
0005433166289	954	Economy	23100.00
0005433166287	954	Economy	23100.00
0005435386764	10357	Economy	17000.00
0005435386763	10357	Economy	15400.00
0005435386761	10357	Economy	15400.00
0005435386759	10357	Economy	15400.00
0005435386760	10357	Economy	15400.00
0005435386762	10357	Economy	15400.00
0005435150433	21912	Economy	15400.00
0005435150419	21912	Economy	15400.00
0005435150432	21912	Economy	15400.00
0005435150427	21912	Economy	15400.00
0005435150434	21912	Economy	15400.00
0005435150431	21912	Economy	15400.00
0005435150420	21912	Economy	15400.00
0005435150435	21912	Economy	15400.00
0005435529884	11216	Economy	19100.00
0005435319824	11216	Economy	19100.00
0005435529876	11216	Economy	21000.00
0005435319825	11216	Economy	19100.00
0005435319823	11216	Economy	19100.00
0005435529900	11216	Economy	19100.00
0005434573755	20915	Business	57200.00
0005434573756	20915	Economy	19100.00
0005433683409	29281	Economy	17100.00
0005433683415	29281	Economy	17100.00
0005433683416	29281	Economy	17100.00
0005432693802	2904	Business	10300.00
0005432693887	2904	Economy	3800.00
0005432693938	2904	Economy	3400.00
0005432693919	2904	Economy	3400.00
0005432693951	2904	Economy	3400.00
0005432693904	2904	Economy	3400.00
0005432693888	2904	Economy	3400.00
0005434300239	2945	Business	10300.00
0005432881245	2945	Economy	3400.00
0005433124539	2945	Economy	3400.00
0005433195000	2945	Economy	3400.00
0005433195014	2945	Economy	3400.00
0005434300238	2945	Economy	3400.00
0005434300249	2945	Economy	3400.00
0005433195013	2945	Economy	3400.00
0005433195015	2945	Economy	3400.00
0005433195001	2945	Economy	3400.00
0005433194999	2945	Economy	3400.00
0005433195012	2945	Economy	3400.00
0005434300241	2945	Economy	3400.00
0005434300240	2945	Economy	3400.00
0005434310183	29952	Economy	3400.00
0005434310163	29952	Economy	3400.00
0005434310181	29952	Economy	3400.00
0005434989125	27577	Economy	4000.00
0005434989120	27577	Economy	4000.00
0005434989109	27577	Economy	3600.00
0005434989121	27577	Economy	3600.00
0005434989126	27577	Economy	3600.00
0005434980602	27577	Economy	3600.00
0005434989099	27577	Economy	3600.00
0005434989123	27577	Economy	3600.00
0005434989128	27577	Economy	3600.00
0005434989100	27577	Economy	3600.00
0005434989122	27577	Economy	3600.00
0005434980674	27577	Economy	3600.00
0005434989130	27577	Economy	3600.00
0005434989127	27577	Economy	3600.00
0005434989108	27577	Economy	3600.00
0005434989133	27577	Economy	3600.00
0005434989129	27577	Economy	3600.00
0005434989087	27577	Economy	3600.00
0005434989088	27577	Economy	3600.00
0005434980676	27577	Economy	3600.00
0005434989134	27577	Economy	3600.00
0005434989117	27577	Economy	3600.00
0005434989054	27577	Economy	3600.00
0005435925716	3558	Business	26900.00
0005435925674	3558	Business	26900.00
0005435925725	3558	Economy	9000.00
0005435939973	3558	Economy	9000.00
0005435925724	3558	Economy	9900.00
0005435925717	3558	Economy	9000.00
0005435939971	3558	Economy	9000.00
0005435939974	3558	Economy	9000.00
0005435925703	3558	Economy	9000.00
0005435070525	15318	Business	26900.00
0005435719042	15318	Business	26900.00
0005435719058	15318	Business	26900.00
0005435719122	15318	Economy	9000.00
0005435719083	15318	Economy	9000.00
0005435070505	15318	Economy	9000.00
0005435719068	15318	Economy	9900.00
0005435719070	15318	Economy	9900.00
0005435719075	15318	Economy	9000.00
0005435719104	15318	Economy	9000.00
0005435070507	15318	Economy	9000.00
0005435719109	15318	Economy	9000.00
0005435719061	15318	Economy	9000.00
0005435719048	15318	Economy	9000.00
0005435719108	15318	Economy	9000.00
0005435719123	15318	Economy	9000.00
0005435719114	15318	Economy	9000.00
0005435719049	15318	Economy	9000.00
0005435070544	15318	Economy	9000.00
0005435719120	15318	Economy	9000.00
0005435719093	15318	Economy	9000.00
0005435719079	15318	Economy	9000.00
0005435719106	15318	Economy	9000.00
0005435719097	15318	Economy	9000.00
0005435719099	15318	Economy	9000.00
0005435070511	15318	Economy	9000.00
0005435719043	15318	Economy	9000.00
0005435719117	15318	Economy	9000.00
0005435719118	15318	Economy	9000.00
0005435719044	15318	Economy	9000.00
0005435719078	15318	Economy	9000.00
0005435719054	15318	Economy	9000.00
0005435719119	15318	Economy	9000.00
0005435719116	15318	Economy	9000.00
0005435070510	15318	Economy	9000.00
0005435719113	15318	Economy	9000.00
0005435719121	15318	Economy	9000.00
0005435719073	15318	Economy	9000.00
0005435719112	15318	Economy	9000.00
0005435719098	15318	Economy	9000.00
0005435719124	15318	Economy	9000.00
0005435719096	15318	Economy	9000.00
0005435070526	15318	Economy	9000.00
0005435719071	15318	Economy	9000.00
0005435719067	15318	Economy	9000.00
0005435719074	15318	Economy	9000.00
0005435070506	15318	Economy	9000.00
0005435719103	15318	Economy	9000.00
0005435719115	15318	Economy	9000.00
0005432664202	26444	Economy	5900.00
0005432664201	26444	Economy	5900.00
0005433103727	42	Business	20000.00
0005433435530	42	Business	20000.00
0005432920482	42	Economy	6700.00
0005433103840	42	Economy	6700.00
0005432920478	42	Economy	6700.00
0005433103813	42	Economy	6700.00
0005433103993	42	Economy	7300.00
0005433103909	42	Economy	6700.00
0005433103910	42	Economy	6700.00
0005433103839	42	Economy	6700.00
0005433103992	42	Economy	6700.00
0005433103877	42	Economy	6700.00
0005433103963	42	Economy	6700.00
0005432392082	42	Economy	6700.00
0005432753401	43	Economy	7300.00
0005433929894	43	Economy	6700.00
0005433929889	43	Economy	6700.00
0005433929896	43	Economy	6700.00
0005434157902	8047	Business	20000.00
0005434157908	8047	Business	20000.00
0005434157816	8047	Business	20000.00
0005434157876	8047	Business	20000.00
0005434215909	8047	Business	20000.00
0005434175882	8047	Business	20000.00
0005434157952	8047	Economy	7300.00
0005434157970	8047	Economy	6700.00
0005434157974	8047	Economy	6700.00
0005434157932	8047	Economy	6700.00
0005434157962	8047	Economy	6700.00
0005434157953	8047	Economy	6700.00
0005434157863	8047	Economy	6700.00
0005434152872	8047	Economy	6700.00
0005434157896	8047	Economy	6700.00
0005434157907	8047	Economy	6700.00
0005434157898	8047	Economy	7300.00
0005434157963	8047	Economy	6700.00
0005434151811	8047	Economy	6700.00
0005434157862	8047	Economy	6700.00
0005434157756	8047	Economy	6700.00
0005434215908	8047	Economy	6700.00
0005434157945	8047	Economy	6700.00
0005434157931	8047	Economy	6700.00
0005434157955	8047	Economy	6700.00
0005434175881	8047	Economy	6700.00
0005434157956	8047	Economy	6700.00
0005434157875	8047	Economy	6700.00
0005432818336	8045	Economy	6700.00
0005433870796	32366	Economy	6900.00
0005433870795	32366	Economy	6900.00
0005433870794	32366	Economy	6900.00
0005435914207	3507	Comfort	19900.00
0005435914184	3507	Economy	11700.00
0005435914176	3507	Economy	11700.00
0005435914774	3507	Economy	11700.00
0005435914208	3507	Economy	12800.00
0005435914175	3507	Economy	12800.00
0005435626847	14582	Comfort	19900.00
0005435626846	14582	Comfort	19900.00
0005435626848	14582	Comfort	19900.00
0005434880880	14582	Comfort	19900.00
0005434427475	14582	Comfort	19900.00
0005435127579	14582	Comfort	19900.00
0005434427459	14582	Economy	11700.00
0005434880974	14582	Economy	11700.00
0005434880879	14582	Economy	11700.00
0005435626766	14582	Economy	11700.00
0005435127546	14582	Economy	11700.00
0005435626853	14582	Economy	11700.00
0005435127567	14582	Economy	11700.00
0005435626732	14582	Economy	11700.00
0005434427458	14582	Economy	12800.00
0005434938721	14582	Economy	11700.00
0005435626734	14582	Economy	11700.00
0005434427471	14582	Economy	11700.00
0005434938710	14582	Economy	11700.00
0005435626839	14582	Economy	11700.00
0005435626770	14582	Economy	11700.00
0005435626850	14582	Economy	11700.00
0005435127559	14582	Economy	11700.00
0005434427432	14582	Economy	11700.00
0005434880925	14582	Economy	11700.00
0005434880983	14582	Economy	11700.00
0005435626733	14582	Economy	11700.00
0005434938711	14582	Economy	11700.00
0005435127578	14582	Economy	11700.00
0005434325971	15609	Economy	14800.00
0005434325970	15609	Economy	14800.00
0005434325986	15609	Economy	14800.00
0005434325985	15609	Economy	14800.00
0005433420650	624	Economy	4100.00
0005435958091	15180	Economy	4100.00
0005435629449	16077	Economy	10400.00
0005432646374	25112	Economy	29200.00
0005432646358	25112	Economy	32200.00
0005432646370	25112	Economy	29200.00
0005432646338	25112	Economy	29200.00
0005432646357	25112	Economy	29200.00
0005432646346	25112	Economy	29200.00
0005432646372	25112	Economy	29200.00
0005433405036	2885	Economy	4600.00
0005433405037	2885	Economy	4200.00
0005433962676	25716	Business	21400.00
0005433962711	25716	Business	21400.00
0005433962760	25716	Business	21400.00
0005433962729	25716	Business	21400.00
0005433962747	25716	Business	21400.00
0005433962752	25716	Economy	7100.00
0005433962604	25716	Economy	7100.00
0005433962685	25716	Economy	7100.00
0005433962756	25716	Economy	7100.00
0005433962748	25716	Economy	7800.00
0005433962601	25716	Economy	7100.00
0005433962657	25716	Economy	7100.00
0005433962710	25716	Economy	7100.00
0005433962728	25716	Economy	7100.00
0005433962669	25716	Economy	7100.00
0005433962599	25716	Economy	7100.00
0005433962684	25716	Economy	7100.00
0005433962650	25716	Economy	7100.00
0005433962727	25716	Economy	7100.00
0005433962658	25716	Economy	7100.00
0005433962570	25716	Economy	7100.00
0005433962677	25716	Economy	7100.00
0005433962509	25716	Economy	7100.00
0005433962668	25716	Economy	7100.00
0005433962665	25716	Economy	7100.00
0005433962715	25716	Economy	7100.00
0005433962709	25716	Economy	7100.00
0005433962666	25716	Economy	7100.00
0005433962730	25716	Economy	7100.00
0005433962678	25716	Economy	7100.00
0005433962755	25716	Economy	7100.00
0005433962749	25716	Economy	7100.00
0005433962626	25716	Economy	7100.00
0005433962683	25716	Economy	7100.00
0005433962491	25716	Economy	7100.00
0005433962528	25716	Economy	7100.00
0005433962605	25716	Economy	7100.00
0005433962659	25716	Economy	7100.00
0005433962600	25716	Economy	7100.00
0005433962761	25716	Economy	7100.00
0005433962645	25716	Economy	7100.00
0005433962529	25716	Economy	7100.00
0005433962530	25716	Economy	7100.00
0005435287005	4992	Business	18000.00
0005435551776	4992	Business	18000.00
0005435286961	4992	Business	18000.00
0005435287032	4992	Economy	6000.00
0005435287030	4992	Economy	6000.00
0005435287029	4992	Economy	6000.00
0005435287006	4992	Economy	6000.00
0005435286960	4992	Economy	6000.00
0005435286952	4992	Economy	6000.00
0005435551777	4992	Economy	6000.00
0005435286997	4992	Economy	6000.00
0005435286987	4992	Economy	6000.00
0005433685587	5007	Business	18000.00
0005433815581	5007	Business	18000.00
0005435270207	5007	Economy	6000.00
0005435270168	5007	Economy	6000.00
0005435732735	5007	Economy	6000.00
0005435732740	5007	Economy	6000.00
0005433690988	5007	Economy	6000.00
0005435270167	5007	Economy	6000.00
0005435732741	5007	Economy	6000.00
0005435270222	5007	Economy	6000.00
0005435732736	5007	Economy	6000.00
0005433690987	5007	Economy	6000.00
0005435732734	5007	Economy	6000.00
0005433785985	8560	Business	18000.00
0005433786198	8560	Economy	6000.00
0005433785984	8560	Economy	6000.00
0005433786000	8560	Economy	6000.00
0005433786195	8560	Economy	6000.00
0005434245835	8560	Economy	6600.00
0005433786196	8560	Economy	6000.00
0005433786001	8560	Economy	6000.00
0005433616774	8561	Business	18000.00
0005434230152	8561	Business	18000.00
0005434230241	8561	Business	18000.00
0005434230187	8561	Business	18000.00
0005434230132	8561	Economy	6600.00
0005434230145	8561	Economy	6600.00
0005434230264	8561	Economy	6000.00
0005434230153	8561	Economy	6000.00
0005433616803	8561	Economy	6000.00
0005434230212	8561	Economy	6000.00
0005434230276	8561	Economy	6000.00
0005433616779	8561	Economy	6000.00
0005433616829	8561	Economy	6000.00
0005433616830	8561	Economy	6000.00
0005434230151	8561	Economy	6000.00
0005434230179	8561	Economy	6000.00
0005433616796	8561	Economy	6000.00
0005434230155	8561	Economy	6000.00
0005433616764	8561	Economy	6000.00
0005434230198	8561	Economy	6000.00
0005433616765	8561	Economy	6000.00
0005434230197	8561	Economy	6000.00
0005434230186	8561	Economy	6000.00
0005433616775	8561	Economy	6000.00
0005433616762	8561	Economy	6000.00
0005434230219	8561	Economy	6000.00
0005434230218	8561	Economy	6000.00
0005434230169	8561	Economy	6000.00
0005434230154	8561	Economy	6000.00
0005434230242	8561	Economy	6000.00
0005434265886	8562	Business	18000.00
0005434230026	8562	Business	18000.00
0005435960167	8562	Economy	6000.00
0005435960166	8562	Economy	6000.00
0005434265894	8562	Economy	6000.00
0005434150071	8562	Economy	6000.00
0005434230043	8562	Economy	6000.00
0005434265887	8562	Economy	6000.00
0005434265888	8562	Economy	6000.00
0005434230027	8562	Economy	6000.00
0005434230035	8562	Economy	6000.00
0005434265895	8562	Economy	6000.00
0005434265898	8562	Economy	6000.00
0005434265889	8562	Economy	6000.00
0005434265885	8562	Economy	6000.00
0005434150070	8562	Economy	6000.00
0005432330016	21080	Business	18900.00
0005432384302	21080	Economy	6300.00
0005432330006	21080	Economy	6300.00
0005432330039	21080	Economy	6300.00
0005432384311	21080	Economy	6300.00
0005432384303	21080	Economy	6300.00
0005432330005	21080	Economy	6300.00
0005432330004	21080	Economy	6300.00
0005432329923	21080	Economy	6300.00
0005432329924	21080	Economy	6300.00
0005432330031	21080	Economy	6300.00
0005432330041	21080	Economy	6300.00
0005432329925	21080	Economy	6300.00
0005432330047	21080	Economy	6300.00
0005432330020	21080	Economy	6300.00
0005432330015	21080	Economy	6300.00
0005432330032	21080	Economy	6300.00
0005432330019	21080	Economy	6300.00
0005432330038	21080	Economy	6300.00
0005432330058	21080	Economy	6300.00
0005432330042	21080	Economy	6300.00
0005432848917	31273	Business	18900.00
0005432848922	31273	Economy	6300.00
0005432848924	31273	Economy	6300.00
0005432848921	31273	Economy	6300.00
0005432848911	31273	Economy	6300.00
0005432848923	31273	Economy	6300.00
0005432848912	31273	Economy	6300.00
0005432848925	31273	Economy	6300.00
0005432425807	30765	Business	12700.00
0005432426069	30765	Business	12700.00
0005432425999	30765	Business	12700.00
0005432462581	30765	Business	12700.00
0005432426000	30765	Economy	4200.00
0005432425991	30765	Economy	4200.00
0005432425900	30765	Economy	4200.00
0005432426001	30765	Economy	4200.00
0005432426074	30765	Economy	4700.00
0005432426018	30765	Economy	4700.00
0005432425883	30765	Economy	4700.00
0005432426055	30765	Economy	4200.00
0005432426049	30765	Economy	4200.00
0005432426028	30765	Economy	4200.00
0005432425897	30765	Economy	4200.00
0005432426008	30765	Economy	4200.00
0005432426052	30765	Economy	4200.00
0005432426017	30765	Economy	4200.00
0005432426027	30765	Economy	4200.00
0005432426056	30765	Economy	4200.00
0005432425998	30765	Economy	4200.00
0005432426075	30765	Economy	4200.00
0005432426026	30765	Economy	4200.00
0005432426002	30765	Economy	4200.00
0005432426077	30765	Economy	4200.00
0005432426034	30765	Economy	4200.00
0005432433839	30765	Economy	4200.00
0005432425901	30765	Economy	4200.00
0005432433840	30765	Economy	4200.00
0005432426046	30765	Economy	4200.00
0005432426047	30765	Economy	4200.00
0005432425884	30765	Economy	4200.00
0005432426070	30765	Economy	4200.00
0005432426003	30765	Economy	4200.00
0005432425990	30765	Economy	4200.00
0005432822413	28994	Business	32600.00
0005432818336	28994	Economy	10900.00
0005432822415	28994	Economy	10900.00
0005432822414	28994	Economy	10900.00
0005432949697	11856	Economy	35300.00
0005432949685	11856	Economy	35300.00
0005432949635	11856	Economy	35300.00
0005432949699	11856	Economy	35300.00
0005432949554	11856	Economy	35300.00
0005433570865	25302	Business	105900.00
0005433570983	25302	Economy	35300.00
0005433570908	25302	Economy	35300.00
0005433570984	25302	Economy	35300.00
0005433570946	25302	Economy	35300.00
0005433570965	25302	Economy	35300.00
0005435340709	5397	Economy	24600.00
0005434655537	12511	Business	67200.00
0005434655538	12511	Economy	22400.00
0005434655539	12511	Economy	22400.00
0005435546241	7413	Economy	10700.00
0005435546242	7413	Economy	10700.00
0005435266339	7413	Economy	10700.00
0005433722514	29209	Business	32000.00
0005433722420	29209	Business	32000.00
0005433717421	29209	Economy	10700.00
0005433722486	29209	Economy	10700.00
0005433717427	29209	Economy	10700.00
0005433722487	29209	Economy	10700.00
0005433717432	29209	Economy	10700.00
0005433717419	29209	Economy	10700.00
0005433690987	29209	Economy	10700.00
0005433722481	29209	Economy	10700.00
0005433690988	29209	Economy	10700.00
0005433685587	29209	Economy	10700.00
0005433722513	29209	Economy	10700.00
0005433722503	29209	Economy	10700.00
0005433722491	29209	Economy	10700.00
0005433722482	29209	Economy	10700.00
0005433717431	29209	Economy	10700.00
0005433717420	29209	Economy	10700.00
0005433717323	29209	Economy	10700.00
0005433722495	29209	Economy	10700.00
0005434184728	8656	Economy	12200.00
0005434143818	11668	Business	36500.00
0005434095695	11668	Business	36500.00
0005434143856	11668	Economy	12200.00
0005434095688	11668	Economy	12200.00
0005434143838	11668	Economy	12200.00
0005434143858	11668	Economy	12200.00
0005434095696	11668	Economy	12200.00
0005434143855	11668	Economy	12200.00
0005434143853	11668	Economy	12200.00
0005434143832	11668	Economy	12200.00
0005434143848	11668	Economy	12200.00
0005434143794	11668	Economy	12200.00
0005434143847	11668	Economy	12200.00
0005434143837	11668	Economy	12200.00
0005433399447	1456	Economy	11000.00
0005433399436	1456	Economy	11000.00
0005433399464	1456	Economy	11000.00
0005433399421	1456	Economy	11000.00
0005435732728	19286	Economy	11000.00
0005435732729	19286	Economy	11000.00
0005434444185	17390	Economy	15600.00
0005434444186	17390	Economy	14100.00
0005434444184	17390	Economy	14100.00
0005434326106	29680	Economy	14000.00
0005434352046	29680	Economy	14000.00
0005434352047	29680	Economy	14000.00
0005434326105	29680	Economy	14000.00
0005433346070	1095	Business	30600.00
0005433346076	1095	Business	30600.00
0005433345978	1095	Business	30600.00
0005433346061	1095	Economy	10200.00
0005433346045	1095	Economy	10200.00
0005433346072	1095	Economy	10200.00
0005433346020	1095	Economy	10200.00
0005433346087	1095	Economy	10200.00
0005433345989	1095	Economy	10200.00
0005433346073	1095	Economy	10200.00
0005433346029	1095	Economy	10200.00
0005433346023	1095	Economy	10200.00
0005433346028	1095	Economy	10200.00
0005433346046	1095	Economy	10200.00
0005433346077	1095	Economy	10200.00
0005433345838	1095	Economy	10200.00
0005433346074	1095	Economy	10200.00
0005433346068	1095	Economy	10200.00
0005433346086	1095	Economy	10200.00
0005433346071	1095	Economy	10200.00
0005435530187	17076	Business	30600.00
0005433462792	17076	Business	30600.00
0005433462804	17076	Business	30600.00
0005433462791	17076	Business	30600.00
0005433462808	17076	Business	30600.00
0005435530184	17076	Economy	10200.00
0005433460498	17076	Economy	10200.00
0005433462797	17076	Economy	10200.00
0005435545997	17076	Economy	10200.00
0005433462793	17076	Economy	10200.00
0005433462807	17076	Economy	10200.00
0005433460493	17076	Economy	10200.00
0005435508831	17076	Economy	10200.00
0005435530185	17076	Economy	10200.00
0005435530192	17076	Economy	10200.00
0005433462800	17076	Economy	10200.00
0005433460486	17076	Economy	10200.00
0005435508827	17076	Economy	10200.00
0005433460483	17076	Economy	10200.00
0005433462805	17076	Economy	10200.00
0005433460481	17076	Economy	11200.00
0005433460495	17076	Economy	10200.00
0005433462806	17076	Economy	10200.00
0005433460496	17076	Economy	10200.00
0005435508830	17076	Economy	10200.00
0005435530193	17076	Economy	10200.00
0005435508807	17076	Economy	10200.00
0005433462799	17076	Economy	10200.00
0005435546003	17076	Economy	10200.00
0005433462794	17076	Economy	10200.00
0005433462803	17076	Economy	10200.00
0005435530194	17076	Economy	10200.00
0005433460492	17076	Economy	10200.00
0005433460497	17076	Economy	10200.00
0005432390475	18275	Economy	33700.00
0005432392082	18275	Economy	33700.00
0005432390479	18275	Economy	33700.00
0005432390465	18275	Economy	33700.00
0005432390484	18275	Economy	33700.00
0005432390474	18275	Economy	33700.00
0005432390464	18275	Economy	33700.00
0005432390480	18275	Economy	33700.00
0005433989906	12767	Business	40300.00
0005434082585	12767	Business	40300.00
0005434069628	12767	Business	40300.00
0005434026761	12767	Economy	13400.00
0005433989905	12767	Economy	13400.00
0005434069640	12767	Economy	13400.00
0005434069520	12767	Economy	13400.00
0005434069622	12767	Economy	13400.00
0005434069462	12767	Economy	13400.00
0005434069637	12767	Economy	13400.00
0005434082642	12767	Economy	13400.00
0005434069601	12767	Economy	13400.00
0005434069641	12767	Economy	13400.00
0005434069591	12767	Economy	13400.00
0005434069495	12767	Economy	13400.00
0005434069593	12767	Economy	13400.00
0005434069626	12767	Economy	13400.00
0005434082641	12767	Economy	13400.00
0005434069627	12767	Economy	13400.00
0005434082614	12767	Economy	13400.00
0005434069592	12767	Economy	13400.00
0005434069519	12767	Economy	13400.00
0005434069598	12767	Economy	13400.00
0005434069638	12767	Economy	13400.00
0005434069496	12767	Economy	13400.00
0005435283519	30656	Economy	13400.00
0005435283525	30656	Economy	13400.00
0005435283509	30656	Economy	13400.00
0005435283520	30656	Economy	13400.00
0005435283532	30656	Economy	13400.00
0005435283542	30656	Economy	13400.00
0005435283541	30656	Economy	13400.00
0005435283524	30656	Economy	13400.00
0005434265904	5513	Economy	11800.00
0005435617201	5513	Economy	11800.00
0005435617208	5513	Economy	11800.00
0005435617194	5513	Economy	12900.00
0005435463531	5513	Economy	11800.00
0005434265880	5513	Economy	11800.00
0005435463528	5513	Economy	11800.00
0005434265903	5513	Economy	11800.00
0005435463530	5513	Economy	11800.00
0005435617200	5513	Economy	11800.00
0005435617207	5513	Economy	11800.00
0005435768090	13447	Economy	11800.00
0005435768121	13447	Economy	11800.00
0005435725741	13447	Economy	11800.00
0005435723105	13447	Economy	11800.00
0005435732736	13447	Economy	11800.00
0005435732740	13447	Economy	11800.00
0005435732734	13447	Economy	11800.00
0005435732735	13447	Economy	11800.00
0005435768056	13447	Economy	11800.00
0005435732741	13447	Economy	11800.00
0005435768093	13447	Economy	11800.00
0005435723104	13447	Economy	11800.00
0005435768092	13447	Economy	11800.00
0005435720168	13447	Economy	11800.00
0005434602982	18729	Economy	3300.00
0005435904490	19168	Economy	3300.00
0005435904725	19168	Economy	3300.00
0005435904729	19168	Economy	3300.00
0005435904724	19168	Economy	3300.00
0005433286200	1770	Economy	17900.00
0005433009972	1770	Economy	16200.00
0005433286226	1770	Economy	16200.00
0005433286222	1770	Economy	16200.00
0005433286204	1770	Economy	16200.00
0005433286225	1770	Economy	16200.00
0005433009981	1770	Economy	16200.00
0005433009971	1770	Economy	16200.00
0005433009954	1770	Economy	16200.00
0005433286209	1770	Economy	16200.00
0005433286227	1770	Economy	16200.00
0005433810708	22570	Business	48700.00
0005433810783	22570	Economy	16200.00
0005435097524	22570	Economy	16200.00
0005435097515	22570	Economy	16200.00
0005433810707	22570	Economy	17900.00
0005433810806	22570	Economy	16200.00
0005433810799	22570	Economy	16200.00
0005433810801	22570	Economy	16200.00
0005433810766	22570	Economy	16200.00
0005433810774	22570	Economy	16200.00
0005435725784	22570	Economy	16200.00
0005435097518	22570	Economy	16200.00
0005435725761	22570	Economy	16200.00
0005433810802	22570	Economy	16200.00
0005433810745	22570	Economy	16200.00
0005433810744	22570	Economy	16200.00
0005433810759	22570	Economy	16200.00
0005433810800	22570	Economy	16200.00
0005435097526	22570	Economy	16200.00
0005435725785	22570	Economy	16200.00
0005435097523	22570	Economy	16200.00
0005433810805	22570	Economy	16200.00
0005435725773	22570	Economy	16200.00
0005435725780	22570	Economy	16200.00
0005435283223	5598	Economy	33300.00
0005435283222	5598	Economy	33300.00
0005433848404	13838	Business	99800.00
0005433848399	13838	Economy	33300.00
0005433848412	13838	Economy	36600.00
0005433848371	13838	Economy	33300.00
0005433848391	13838	Economy	33300.00
0005433848353	13838	Economy	33300.00
0005433848403	13838	Economy	33300.00
0005433848411	13838	Economy	33300.00
0005433815581	13838	Economy	33300.00
0005433848340	13838	Economy	33300.00
0005435332635	7814	Economy	15100.00
0005435937545	4286	Economy	12700.00
0005435937546	4286	Economy	12700.00
0005435786331	27294	Business	38000.00
0005435786299	27294	Business	38000.00
0005435786184	27294	Economy	12700.00
0005435786333	27294	Economy	12700.00
0005435786358	27294	Economy	12700.00
0005435786361	27294	Economy	12700.00
0005435786332	27294	Economy	13900.00
0005435786359	27294	Economy	13900.00
0005435787413	27294	Economy	12700.00
0005435786340	27294	Economy	12700.00
0005435786291	27294	Economy	12700.00
0005435786360	27294	Economy	12700.00
0005434150203	4704	Economy	13600.00
0005434150192	4704	Economy	13600.00
0005434150191	4704	Economy	13600.00
0005435840515	4704	Economy	13600.00
0005434150193	4704	Economy	13600.00
0005435960176	4704	Economy	13600.00
0005434150194	4704	Economy	13600.00
0005432569429	30545	Business	40900.00
0005432569430	30545	Business	40900.00
0005432569400	30545	Business	40900.00
0005434082642	30545	Business	40900.00
0005432461406	30545	Economy	15000.00
0005432569417	30545	Economy	13600.00
0005434082614	30545	Economy	13600.00
0005434082585	30545	Economy	13600.00
0005432461431	30545	Economy	13600.00
0005432569416	30545	Economy	13600.00
0005432569420	30545	Economy	13600.00
0005432569399	30545	Economy	13600.00
0005432569419	30545	Economy	13600.00
0005434082641	30545	Economy	13600.00
0005435725788	13724	Economy	8800.00
0005435725776	13724	Economy	8800.00
0005435732726	13724	Economy	8800.00
0005435725762	13724	Economy	8800.00
0005435508823	11097	Business	23600.00
0005435508816	11097	Economy	7900.00
0005435545996	11097	Economy	7900.00
0005435508833	11097	Economy	7900.00
0005435508822	11097	Economy	7900.00
0005435530149	11097	Economy	7900.00
0005435508817	11097	Economy	7900.00
0005435508824	11097	Economy	7900.00
0005435508821	11097	Economy	7900.00
0005433346070	17114	Business	23600.00
0005433346029	17114	Business	23600.00
0005433346073	17114	Business	23600.00
0005433346061	17114	Economy	7900.00
0005433346077	17114	Economy	7900.00
0005433346087	17114	Economy	7900.00
0005433346028	17114	Economy	8600.00
0005433346076	17114	Economy	7900.00
0005433346072	17114	Economy	7900.00
0005433345989	17114	Economy	7900.00
0005433346068	17114	Economy	7900.00
0005433345838	17114	Economy	7900.00
0005433345978	17114	Economy	7900.00
0005433346023	17114	Economy	7900.00
0005433346071	17114	Economy	7900.00
0005433346045	17114	Economy	7900.00
0005433346020	17114	Economy	7900.00
0005433346086	17114	Economy	7900.00
0005433346074	17114	Economy	7900.00
0005433346046	17114	Economy	7900.00
0005432920476	9092	Business	26600.00
0005432920480	9092	Economy	8900.00
0005433507732	20476	Economy	8900.00
0005433477294	20476	Economy	9800.00
0005433477285	20476	Economy	8900.00
0005433477295	20476	Economy	8900.00
0005433477284	20476	Economy	8900.00
0005433477297	20476	Economy	8900.00
0005433507726	20476	Economy	8900.00
0005435626847	10940	Business	9500.00
0005435127567	10940	Business	9500.00
0005435626733	10940	Business	9500.00
0005435554317	10940	Economy	3200.00
0005435554316	10940	Economy	3200.00
0005435626850	10940	Economy	3200.00
0005435626732	10940	Economy	3200.00
0005435626853	10940	Economy	3200.00
0005435626734	10940	Economy	3200.00
0005435127559	10940	Economy	3200.00
0005435626839	10940	Economy	3200.00
0005435127578	10940	Economy	3200.00
0005435626766	10940	Economy	3200.00
0005435626848	10940	Economy	3200.00
0005435626846	10940	Economy	3200.00
0005435626770	10940	Economy	3200.00
0005435127546	10940	Economy	3200.00
0005435127579	10940	Economy	3200.00
0005435179425	7090	Economy	29000.00
0005435219265	7090	Economy	29000.00
0005432398300	27091	Economy	29000.00
0005433060492	2712	Economy	7700.00
0005435518457	11397	Economy	6700.00
0005435518456	11397	Economy	6700.00
0005435518454	11397	Economy	6700.00
0005434908839	25599	Business	20200.00
0005434908877	25599	Business	20200.00
0005434908838	25599	Business	20200.00
0005434908886	25599	Economy	6700.00
0005434908844	25599	Economy	6700.00
0005434908850	25599	Economy	6700.00
0005434908735	25599	Economy	6700.00
0005434908887	25599	Economy	6700.00
0005434908897	25599	Economy	6700.00
0005434908880	25599	Economy	6700.00
0005434908849	25599	Economy	6700.00
0005432862525	2513	Economy	13600.00
0005432621455	28043	Economy	12400.00
0005432621456	28043	Economy	12400.00
0005434182555	12031	Economy	7200.00
0005434182554	12031	Economy	6600.00
0005433134264	12031	Economy	6600.00
0005434326031	29842	Economy	7200.00
0005434326090	29842	Economy	6600.00
0005434326029	29842	Economy	6600.00
0005434326044	29842	Economy	6600.00
0005434326016	29842	Economy	6600.00
0005434326030	29842	Economy	6600.00
0005434326091	29842	Economy	6600.00
0005434326048	29842	Economy	6600.00
0005434326017	29842	Economy	6600.00
0005434326043	29842	Economy	6600.00
0005435698153	24709	Economy	18100.00
0005435698154	24709	Economy	18100.00
0005433724940	21599	Economy	4400.00
0005435283586	7322	Business	23100.00
0005435283585	7322	Economy	7700.00
0005434140361	28543	Business	23100.00
0005434140141	28543	Economy	7700.00
0005434140591	28543	Economy	7700.00
0005434140362	28543	Economy	7700.00
0005434140619	28543	Economy	7700.00
0005434140618	28543	Economy	7700.00
0005434140592	28543	Economy	7700.00
0005434140389	28543	Economy	7700.00
0005434140557	28543	Economy	7700.00
0005435808508	23097	Economy	23900.00
0005435808530	23097	Economy	23900.00
0005434610333	23097	Economy	21700.00
0005435808507	23097	Economy	21700.00
0005435808519	23097	Economy	21700.00
0005435808476	23097	Economy	21700.00
0005435808514	23097	Economy	21700.00
0005435808516	23097	Economy	21700.00
0005435808520	23097	Economy	21700.00
0005435808509	23097	Economy	21700.00
0005435808513	23097	Economy	21700.00
0005434610338	23097	Economy	21700.00
0005435808526	23097	Economy	21700.00
0005435808531	23097	Economy	21700.00
0005435808525	23097	Economy	21700.00
0005435808484	23097	Economy	21700.00
0005435808483	23097	Economy	21700.00
0005435808527	23097	Economy	21700.00
0005435808475	23097	Economy	21700.00
0005435808473	23097	Economy	21700.00
0005434610332	23097	Economy	21700.00
0005435808474	23097	Economy	21700.00
0005435808510	23097	Economy	21700.00
0005435808512	23097	Economy	21700.00
0005434505296	16720	Economy	6900.00
0005434505298	16720	Economy	6900.00
0005434505209	16720	Economy	6900.00
0005434505289	16720	Economy	6900.00
0005434505320	16720	Economy	6900.00
0005434505316	16720	Economy	6900.00
0005434505254	16720	Economy	6900.00
0005434505297	16720	Economy	6900.00
0005434505293	16720	Economy	6900.00
0005434505210	16720	Economy	6900.00
0005435312888	22912	Economy	7600.00
0005435312889	22912	Economy	6900.00
0005435078770	24329	Economy	7000.00
0005434989135	23611	Economy	9800.00
0005434989132	23611	Economy	9800.00
0005434989047	23611	Economy	9800.00
0005434989118	23611	Economy	9800.00
0005434989069	23611	Economy	9800.00
0005434989046	23611	Economy	9800.00
0005435803351	23611	Economy	9800.00
0005434989119	23611	Economy	9800.00
0005432384330	31307	Business	9900.00
0005432384308	31307	Business	9900.00
0005432384333	31307	Economy	3300.00
0005432384320	31307	Economy	3300.00
0005432384325	31307	Economy	3300.00
0005432384313	31307	Economy	3300.00
0005432384334	31307	Economy	3300.00
0005432384278	31307	Economy	3300.00
0005432384335	31307	Economy	3300.00
0005432384304	31307	Economy	3300.00
0005432384321	31307	Economy	3300.00
0005433131841	10783	Economy	15600.00
0005435299917	10783	Economy	15600.00
0005433126976	10783	Economy	15600.00
0005435299916	10783	Economy	15600.00
0005433110394	2400	Economy	15700.00
0005433110393	2400	Economy	15700.00
0005434300270	26819	Economy	15700.00
0005434300271	26819	Economy	15700.00
0005434269166	25465	Economy	22800.00
0005434272233	25465	Economy	22800.00
0005434272232	25465	Economy	22800.00
0005435860623	32667	Economy	16800.00
0005435860618	32667	Economy	16800.00
0005435860619	32667	Economy	16800.00
0005435311551	7046	Economy	16400.00
0005435293626	7046	Economy	16400.00
0005435293624	7046	Economy	18000.00
0005435311558	7046	Economy	16400.00
0005435311539	7046	Economy	16400.00
0005435293625	7046	Economy	16400.00
0005435311538	7046	Economy	16400.00
0005435311557	7046	Economy	16400.00
0005435311559	7046	Economy	16400.00
0005435311552	7046	Economy	16400.00
0005434300199	26928	Business	49100.00
0005434300198	26928	Economy	16400.00
0005434409602	26928	Economy	16400.00
0005434300225	26928	Economy	16400.00
0005434409595	26928	Economy	16400.00
0005434409605	26928	Economy	18000.00
0005434409594	26928	Economy	16400.00
0005435220522	6474	Economy	15000.00
0005432605473	21356	Economy	15000.00
0005432605458	21356	Economy	15000.00
0005432605508	21356	Economy	15000.00
0005432605517	21356	Economy	15000.00
0005432605459	21356	Economy	15000.00
0005432605479	21356	Economy	15000.00
0005432605500	21356	Economy	15000.00
0005432605518	21356	Economy	15000.00
0005432605515	21356	Economy	15000.00
0005432605480	21356	Economy	15000.00
0005434908880	15015	Business	18900.00
0005434908886	15015	Economy	6300.00
0005434908735	15015	Economy	6300.00
0005434908877	15015	Economy	6300.00
0005434908850	15015	Economy	6300.00
0005434908839	15015	Economy	6300.00
0005434908887	15015	Economy	6300.00
0005434908897	15015	Economy	6300.00
0005434908838	15015	Economy	6300.00
0005434908844	15015	Economy	6300.00
0005434908849	15015	Economy	6300.00
0005433252370	25874	Economy	6300.00
0005434171513	9181	Economy	18100.00
0005434171514	9181	Economy	18100.00
0005433810792	14165	Business	52300.00
0005433810797	14165	Business	52300.00
0005433810777	14165	Economy	19200.00
0005433810721	14165	Economy	17400.00
0005433810790	14165	Economy	17400.00
0005433810788	14165	Economy	17400.00
0005433810720	14165	Economy	17400.00
0005433810789	14165	Economy	17400.00
0005433009940	22837	Economy	17400.00
0005433009927	22837	Economy	17400.00
0005433009943	22837	Economy	17400.00
0005433009964	22837	Economy	17400.00
0005433009944	22837	Economy	17400.00
0005433009928	22837	Economy	17400.00
0005434926815	14936	Business	22900.00
0005434926822	14936	Business	22900.00
0005434926848	14936	Economy	8400.00
0005434926750	14936	Economy	7600.00
0005434926814	14936	Economy	7600.00
0005434926751	14936	Economy	7600.00
0005434926813	14936	Economy	7600.00
0005434926849	14936	Economy	7600.00
0005435999860	15794	Economy	8100.00
0005435999857	15794	Economy	8100.00
0005435999858	15794	Economy	8100.00
0005435999861	15794	Economy	8100.00
0005435999859	15794	Economy	8100.00
0005435999841	15794	Economy	8100.00
0005435999842	15794	Economy	8100.00
0005435488430	19699	Economy	8100.00
0005435488473	19699	Economy	8100.00
0005435473285	5998	Business	199300.00
0005432537123	5998	Economy	66400.00
0005435617245	5998	Economy	66400.00
0005435840276	18062	Business	199300.00
0005435840254	18062	Business	199300.00
0005432667516	18062	Economy	66400.00
0005432664210	18062	Economy	66400.00
0005432664209	18062	Economy	66400.00
0005432664211	18062	Economy	66400.00
0005435840255	18062	Economy	66400.00
0005432667515	18062	Economy	66400.00
0005433286204	23048	Economy	5200.00
0005433286225	23048	Economy	5200.00
0005435380444	23048	Economy	5200.00
0005433286209	23048	Economy	5200.00
0005433286226	23048	Economy	5200.00
0005433286227	23048	Economy	5200.00
0005433286222	23048	Economy	5200.00
0005433286200	23048	Economy	5200.00
0005435104347	32062	Economy	5200.00
0005435104305	32062	Economy	5200.00
0005435104331	32062	Economy	5200.00
0005435104367	32062	Economy	5200.00
0005435097504	32062	Economy	5200.00
0005435104368	32062	Economy	5200.00
0005435104332	32062	Economy	5200.00
0005435104348	32062	Economy	5200.00
0005435104287	32062	Economy	5200.00
0005432531756	30616	Economy	14000.00
0005432531835	30616	Economy	14000.00
0005432531836	30616	Economy	14000.00
0005432531714	30616	Economy	14000.00
0005432531782	30616	Economy	14000.00
0005434069557	30616	Economy	14000.00
0005435654475	24846	Economy	3300.00
0005435654498	24846	Economy	3300.00
0005435698153	16259	Economy	7900.00
0005435698154	16259	Economy	7200.00
0005433368974	1660	Economy	16700.00
0005433463963	19916	Business	201300.00
0005433463957	19916	Business	201300.00
0005433463965	19916	Business	201300.00
0005433463967	19916	Economy	67100.00
0005433463962	19916	Economy	67100.00
0005433461631	19916	Economy	67100.00
0005433463958	19916	Economy	67100.00
0005433461645	19916	Economy	67100.00
0005433463964	19916	Economy	67100.00
0005433463968	19916	Economy	67100.00
0005433461647	19916	Economy	67100.00
0005433461644	19916	Economy	67100.00
0005433461650	19916	Economy	67100.00
0005433463961	19916	Economy	67100.00
0005433461655	19916	Economy	67100.00
0005433461652	19916	Economy	67100.00
0005433461649	19916	Economy	67100.00
0005433461632	19916	Economy	67100.00
0005432655891	17839	Business	18000.00
0005432655870	17839	Business	18000.00
0005432666450	17839	Economy	6000.00
0005432658653	17839	Economy	6000.00
0005432657539	17839	Economy	6000.00
0005432657538	17839	Economy	6000.00
0005432661995	17839	Economy	6000.00
0005432639468	25056	Economy	29100.00
0005432639486	25056	Economy	32000.00
0005432639497	25056	Economy	29100.00
0005432330012	31141	Economy	5400.00
0005433439111	31141	Economy	5400.00
0005432330033	31141	Economy	5400.00
0005435488477	6176	Economy	41500.00
0005433158206	13203	Economy	12300.00
0005434446586	17547	Economy	13600.00
0005434446580	17547	Economy	12300.00
0005434446590	17547	Economy	12300.00
0005434446588	17547	Economy	12300.00
0005434444191	17547	Economy	12300.00
0005434444192	17547	Economy	12300.00
0005434446591	17547	Economy	12300.00
0005434446592	17547	Economy	12300.00
0005434446581	17547	Economy	12300.00
0005432675587	17480	Business	115000.00
0005432693944	17480	Economy	38300.00
0005432677689	17480	Economy	38300.00
0005432675584	17480	Economy	38300.00
0005435787415	13791	Economy	3400.00
0005435786365	13791	Economy	3100.00
0005435786364	13791	Economy	3100.00
0005435786363	13791	Economy	3100.00
0005435786347	13791	Economy	3100.00
0005435786366	13791	Economy	3100.00
0005435786349	13791	Economy	3100.00
0005435787414	13791	Economy	3100.00
0005435786350	13791	Economy	3100.00
0005435477034	7698	Economy	3700.00
0005433124522	30432	Economy	4100.00
0005433124543	30432	Economy	3700.00
0005433124544	30432	Economy	3700.00
0005432693944	30432	Economy	3700.00
0005435477000	5658	Business	27800.00
0005435243660	5658	Economy	9300.00
0005435477003	5658	Economy	9300.00
0005435477001	5658	Economy	9300.00
0005435477002	5658	Economy	9300.00
0005435243659	5658	Economy	9300.00
0005432785363	15362	Economy	9300.00
0005432785357	15362	Economy	9300.00
0005432785362	15362	Economy	9300.00
0005435257545	6350	Business	11900.00
0005435243641	15399	Business	41200.00
0005435243650	15399	Business	41200.00
0005435243649	15399	Economy	13700.00
0005435243642	15399	Economy	15100.00
0005435914216	14599	Business	49700.00
0005433616825	25211	Economy	48700.00
0005433578196	25211	Economy	44300.00
0005433578198	25211	Economy	44300.00
0005433578197	25211	Economy	44300.00
0005433616824	25211	Economy	44300.00
0005433578194	25211	Economy	48700.00
0005433634823	25211	Economy	44300.00
0005433616822	25211	Economy	44300.00
0005433616823	25211	Economy	44300.00
0005433634795	25211	Economy	44300.00
0005433616818	25211	Economy	44300.00
0005434273136	4223	Economy	64400.00
0005435477021	4223	Economy	64400.00
0005435987063	26604	Economy	64400.00
0005432949672	360	Economy	7200.00
0005432869724	2353	Business	184500.00
0005432869723	2353	Economy	61500.00
0005432986010	2353	Economy	61500.00
0005432869726	2353	Economy	61500.00
0005434376169	2353	Economy	61500.00
0005433755888	26169	Economy	61500.00
0005435983669	26169	Economy	61500.00
0005432655892	26169	Economy	61500.00
0005435983670	26169	Economy	61500.00
0005435983660	26169	Economy	61500.00
0005434376070	20121	Business	38900.00
0005434376024	20121	Economy	13000.00
0005434376169	20121	Economy	13000.00
0005434376071	20121	Economy	13000.00
0005434376069	20121	Economy	13000.00
0005434376023	20121	Economy	13000.00
0005434376060	20121	Economy	13000.00
0005434376059	20121	Economy	13000.00
0005434376061	20121	Economy	13000.00
0005433262064	529	Economy	9200.00
0005433262063	529	Economy	9200.00
0005433262037	529	Economy	9200.00
0005434446580	12862	Business	27500.00
0005434444191	12862	Business	27500.00
0005434446590	12862	Business	27500.00
0005434446592	12862	Business	27500.00
0005434444192	12862	Economy	10100.00
0005434446588	12862	Economy	9200.00
0005434446586	12862	Economy	9200.00
0005434446591	12862	Economy	9200.00
0005434446581	12862	Economy	9200.00
0005432426013	12868	Business	27500.00
0005432425940	12868	Business	27500.00
0005432426066	12868	Economy	10100.00
0005432425939	12868	Economy	9200.00
0005432425929	12868	Economy	9200.00
0005432426064	12868	Economy	9200.00
0005432425866	12868	Economy	9200.00
0005432426065	12868	Economy	9200.00
0005432425865	12868	Economy	9200.00
0005432426042	12868	Economy	9200.00
0005432426012	12868	Economy	9200.00
0005433929731	460	Economy	8200.00
0005433929726	460	Economy	8200.00
0005433929732	460	Economy	8200.00
0005434025679	12647	Business	24500.00
0005434025643	12647	Business	24500.00
0005434025685	12647	Economy	9000.00
0005434025662	12647	Economy	8200.00
0005434025681	12647	Economy	8200.00
0005434025684	12647	Economy	8200.00
0005434025680	12647	Economy	8200.00
0005434032156	12647	Economy	8200.00
0005434025701	12647	Economy	8200.00
0005434025700	12647	Economy	8200.00
0005434032155	12647	Economy	8200.00
0005433037853	2158	Economy	11600.00
0005433037854	2158	Economy	11600.00
0005434088055	2158	Economy	11600.00
0005433037815	2158	Economy	12700.00
0005433037844	2158	Economy	11600.00
0005433926105	24124	Economy	11600.00
0005433925875	24124	Economy	11600.00
0005433926106	24124	Economy	11600.00
0005433931555	24124	Economy	11600.00
0005433925983	24124	Economy	11600.00
0005433929897	24124	Economy	11600.00
0005433929899	24124	Economy	11600.00
0005433236035	262	Comfort	47400.00
0005434032157	262	Economy	27900.00
0005433290067	262	Economy	27900.00
0005433181841	262	Economy	27900.00
0005433181830	262	Economy	27900.00
0005433181842	262	Economy	27900.00
0005433111568	262	Economy	27900.00
0005433236052	262	Economy	27900.00
0005434729054	9852	Comfort	47400.00
0005434552857	9852	Comfort	47400.00
0005434552845	9852	Economy	27900.00
0005434728995	9852	Economy	27900.00
0005434729032	9852	Economy	27900.00
0005434552846	9852	Economy	27900.00
0005434552856	9852	Economy	27900.00
0005434729033	9852	Economy	27900.00
0005434729036	9852	Economy	27900.00
0005434552767	9852	Economy	27900.00
0005434728928	9852	Economy	27900.00
0005434729045	9852	Economy	27900.00
0005434729037	9852	Economy	27900.00
0005435283543	7758	Economy	14000.00
0005435283545	7758	Economy	14000.00
0005435215492	7758	Economy	14000.00
0005435215479	7758	Economy	14000.00
0005435631055	7758	Economy	14000.00
0005435215533	7758	Economy	14000.00
0005435283546	7758	Economy	14000.00
0005435283544	7758	Economy	14000.00
0005435042939	5338	Comfort	24400.00
0005435426836	5338	Comfort	24400.00
0005435426800	5338	Comfort	24400.00
0005435654514	5338	Economy	14400.00
0005435426852	5338	Economy	14400.00
0005434245835	5338	Economy	14400.00
0005435654519	5338	Economy	14400.00
0005435426799	5338	Economy	14400.00
0005435768121	5338	Economy	14400.00
0005435426837	5338	Economy	14400.00
0005435426854	5338	Economy	14400.00
0005435380441	5338	Economy	14400.00
0005435426853	5338	Economy	14400.00
0005435654520	5338	Economy	14400.00
0005434345297	10921	Comfort	24400.00
0005435551774	10921	Economy	14400.00
0005435617030	10921	Economy	14400.00
0005434345259	10921	Economy	14400.00
0005434345251	10921	Economy	14400.00
0005435551772	10921	Economy	14400.00
0005434345084	10921	Economy	14400.00
0005435617032	10921	Economy	14400.00
0005435617204	10921	Economy	14400.00
0005434573756	10921	Economy	14400.00
0005435617031	10921	Economy	14400.00
0005434573755	10921	Economy	14400.00
0005434326105	3242	Business	18800.00
0005435858722	3242	Business	18800.00
0005435858734	3242	Business	18800.00
0005432461406	3242	Economy	6900.00
0005435858742	3242	Economy	6300.00
0005435856358	3242	Economy	6300.00
0005435856357	3242	Economy	6300.00
0005435858741	3242	Economy	6300.00
0005432461431	3242	Economy	6300.00
0005434326106	3242	Economy	6300.00
0005435858723	3242	Economy	6300.00
0005435886835	3241	Business	18800.00
0005435886834	3241	Economy	6300.00
0005435903223	3241	Economy	6300.00
0005435886780	3241	Economy	6300.00
0005435903224	3241	Economy	6300.00
0005433507732	8165	Business	18800.00
0005434505322	8165	Business	18800.00
0005434505323	8165	Business	18800.00
0005434505321	8165	Economy	6300.00
0005434505324	8165	Economy	6300.00
0005433507726	8165	Economy	6300.00
0005433806411	8279	Business	18800.00
0005433634823	8279	Economy	6900.00
0005433806398	8279	Economy	6300.00
0005433634795	8279	Economy	6300.00
0005434266025	8292	Business	18800.00
0005434150210	8292	Economy	6900.00
0005434150234	8292	Economy	6300.00
0005434273136	8292	Economy	6300.00
0005434266043	8292	Economy	6300.00
0005434266026	8292	Economy	6300.00
0005434150209	8292	Economy	6300.00
0005433195000	30125	Business	9900.00
0005432384308	30125	Business	9900.00
0005433195012	30125	Business	9900.00
0005434300249	30125	Economy	3300.00
0005433194999	30125	Economy	3300.00
0005433722481	30125	Economy	3300.00
0005433722513	30125	Economy	3300.00
0005432384320	30125	Economy	3300.00
0005434300240	30125	Economy	3600.00
0005434300239	30125	Economy	3600.00
0005432384334	30125	Economy	3600.00
0005432384335	30125	Economy	3300.00
0005433722491	30125	Economy	3300.00
0005432384321	30125	Economy	3300.00
0005433195014	30125	Economy	3300.00
0005433195001	30125	Economy	3300.00
0005432384333	30125	Economy	3300.00
0005432384325	30125	Economy	3300.00
0005432384304	30125	Economy	3300.00
0005433722495	30125	Economy	3300.00
0005433722514	30125	Economy	3300.00
0005433195015	30125	Economy	3300.00
0005433722487	30125	Economy	3300.00
0005435477021	30125	Economy	3300.00
0005433722420	30125	Economy	3300.00
0005434300241	30125	Economy	3300.00
0005433722482	30125	Economy	3300.00
0005433722486	30125	Economy	3300.00
0005432384330	30125	Economy	3300.00
0005432384278	30125	Economy	3300.00
0005432728312	30125	Economy	3300.00
0005432384313	30125	Economy	3300.00
0005433722503	30125	Economy	3300.00
0005433195013	30125	Economy	3300.00
0005434300238	30125	Economy	3300.00
0005432823507	28906	Business	18500.00
0005434459423	28906	Economy	6200.00
0005435990833	15745	Economy	48400.00
0005435154702	29595	Economy	17800.00
0005435154695	29595	Economy	17800.00
0005435154701	29595	Economy	17800.00
0005435154679	29595	Economy	17800.00
0005435154678	29595	Economy	17800.00
0005435154694	29595	Economy	17800.00
0005435154677	29595	Economy	17800.00
0005435154697	29595	Economy	17800.00
0005433473532	23904	Economy	12700.00
0005433473533	23904	Economy	12700.00
0005433473529	23904	Economy	12700.00
0005434606939	18910	Economy	6600.00
0005433293439	379	Business	44500.00
0005434152872	379	Business	44500.00
0005434151811	379	Economy	14800.00
0005432891588	379	Economy	14800.00
0005434827031	9886	Business	84000.00
0005434827253	9886	Comfort	47600.00
0005434827271	9886	Comfort	47600.00
0005434665025	9886	Economy	28000.00
0005434827285	9886	Economy	28000.00
0005434665024	9886	Economy	28000.00
0005435150436	9886	Economy	28000.00
0005434827032	9886	Economy	28000.00
0005434827033	9886	Economy	28000.00
0005434831288	9886	Economy	28000.00
0005434831290	9886	Economy	28000.00
0005435150437	9886	Economy	28000.00
0005434558612	9886	Economy	28000.00
0005434827281	9886	Economy	28000.00
0005434831289	9886	Economy	28000.00
0005434827284	9886	Economy	28000.00
0005434558588	9886	Economy	28000.00
0005435315106	10602	Economy	3000.00
0005434558616	27679	Business	9100.00
0005434558617	27679	Economy	3000.00
0005434552838	27679	Economy	3300.00
0005434558570	27679	Economy	3000.00
0005434552839	27679	Economy	3000.00
0005434558599	27679	Economy	3000.00
0005434558606	27679	Economy	3000.00
0005434558615	27679	Economy	3000.00
0005432533379	6740	Business	51100.00
0005435631055	24607	Economy	17000.00
0005435683314	24607	Economy	17000.00
0005435683313	24607	Economy	17000.00
0005435070527	13189	Business	11300.00
0005435070567	13189	Business	11300.00
0005435070553	13189	Economy	3800.00
0005435070568	13189	Economy	3800.00
0005435070554	13189	Economy	3800.00
0005435925725	15484	Business	11300.00
0005435925674	15484	Economy	4100.00
0005435925724	15484	Economy	3800.00
0005435925716	15484	Economy	3800.00
0005435925717	15484	Economy	3800.00
0005435925703	15484	Economy	3800.00
0005434757689	10737	Economy	20400.00
0005434757546	10737	Economy	20400.00
0005434215822	28659	Economy	20400.00
0005434215828	28659	Economy	20400.00
0005434215829	28659	Economy	20400.00
0005434215821	28659	Economy	20400.00
0005434215902	28659	Economy	20400.00
0005434230028	5440	Business	29500.00
0005434229986	5440	Economy	9800.00
0005435735284	5440	Economy	9800.00
0005434230029	5440	Economy	9800.00
0005435554316	14861	Economy	17600.00
0005435554317	14861	Economy	17600.00
0005433435505	26543	Economy	6200.00
0005435983670	26715	Economy	6200.00
0005435983669	26715	Economy	6200.00
0005435983660	26715	Economy	6200.00
0005432858412	3168	Economy	10100.00
0005432858411	3168	Economy	10100.00
0005435270167	9345	Economy	62100.00
0005435858741	9345	Economy	62100.00
0005435270168	9345	Economy	62100.00
0005435858734	9345	Economy	62100.00
0005435858722	9345	Economy	62100.00
0005435270222	9345	Economy	62100.00
0005435858742	9345	Economy	62100.00
0005435858723	9345	Economy	62100.00
0005435270207	9345	Economy	62100.00
0005433786068	26273	Business	186200.00
0005432657540	26273	Business	186200.00
0005433786067	26273	Business	186200.00
0005432663107	26273	Business	186200.00
0005433763602	26273	Business	186200.00
0005433786108	26273	Economy	68300.00
0005433786164	26273	Economy	68300.00
0005432657541	26273	Economy	62100.00
0005433786175	26273	Economy	62100.00
0005433786174	26273	Economy	62100.00
0005432659765	26273	Economy	62100.00
0005433806398	26273	Economy	62100.00
0005433786162	26273	Economy	62100.00
0005433786177	26273	Economy	62100.00
0005433786176	26273	Economy	62100.00
0005433763604	26273	Economy	62100.00
0005433763630	26273	Economy	62100.00
0005432663108	26273	Economy	62100.00
0005433806411	26273	Economy	62100.00
0005433786163	26273	Economy	62100.00
0005433763603	26273	Economy	62100.00
0005433962623	24250	Business	36400.00
0005433962766	24250	Business	36400.00
0005433962763	24250	Business	36400.00
0005433962555	24250	Business	36400.00
0005433962744	24250	Economy	12100.00
0005433962397	24250	Economy	12100.00
0005433962607	24250	Economy	12100.00
0005433962712	24250	Economy	12100.00
0005433962606	24250	Economy	12100.00
0005433962768	24250	Economy	12100.00
0005433962765	24250	Economy	12100.00
0005433962525	24250	Economy	12100.00
0005433962705	24250	Economy	12100.00
0005433962708	24250	Economy	12100.00
0005433962734	24250	Economy	12100.00
0005433962764	24250	Economy	12100.00
0005433962713	24250	Economy	12100.00
0005433962735	24250	Economy	12100.00
0005434481046	16555	Economy	23100.00
0005435142968	21938	Economy	17000.00
0005435150437	21938	Economy	15400.00
0005435142970	21938	Economy	15400.00
0005435150436	21938	Economy	15400.00
0005435502937	11185	Economy	19100.00
0005435529874	11185	Economy	19100.00
0005435319827	11185	Economy	19100.00
0005435529899	11185	Economy	19100.00
0005435502959	11185	Economy	19100.00
0005435502965	11185	Economy	19100.00
0005435502960	11185	Economy	19100.00
0005435502966	11185	Economy	19100.00
0005434300270	2986	Business	10300.00
0005434300271	2986	Business	10300.00
0005433194986	2986	Economy	3400.00
0005433194991	2986	Economy	3400.00
0005432693944	2986	Economy	3400.00
0005433124522	2986	Economy	3400.00
0005433124544	2986	Economy	3400.00
0005433124543	2986	Economy	3400.00
0005434310168	29991	Business	10300.00
0005434310182	29991	Economy	3400.00
0005434310167	29991	Economy	3400.00
0005434310166	29991	Economy	3400.00
0005435070567	15288	Business	26900.00
0005435070568	15288	Economy	9000.00
0005435070527	15288	Economy	9000.00
0005435070554	15288	Economy	9000.00
0005435070553	15288	Economy	9000.00
0005432664204	26364	Economy	5900.00
0005432664205	26364	Economy	5900.00
0005432664206	26364	Economy	5900.00
0005432677689	80	Business	20000.00
0005433104007	80	Business	20000.00
0005433435519	80	Economy	6700.00
0005433103961	80	Economy	6700.00
0005433103990	80	Economy	6700.00
0005433103966	80	Economy	6700.00
0005433103962	80	Economy	6700.00
0005433103964	80	Economy	6700.00
0005433103996	80	Economy	6700.00
0005433103946	80	Economy	6700.00
0005433103965	80	Economy	6700.00
0005433435520	80	Economy	6700.00
0005433103960	80	Economy	6700.00
0005433103989	80	Economy	6700.00
0005433435518	80	Economy	6700.00
0005433103799	80	Economy	6700.00
0005433103800	80	Economy	6700.00
0005432753400	81	Economy	6700.00
0005434152870	8151	Business	20000.00
0005434157799	8151	Business	20000.00
0005434152871	8151	Economy	6700.00
0005434157820	8151	Economy	6700.00
0005433477297	8151	Economy	6700.00
0005434157939	8151	Economy	6700.00
0005434157904	8151	Economy	6700.00
0005434157986	8151	Economy	6700.00
0005434157917	8151	Economy	6700.00
0005433477294	8151	Economy	6700.00
0005434157870	8151	Economy	6700.00
0005434157905	8151	Economy	6700.00
0005433477295	8151	Economy	6700.00
0005434157916	8151	Economy	6700.00
0005433477284	8151	Economy	6700.00
0005434157871	8151	Economy	6700.00
0005434157920	8151	Economy	6700.00
0005433477285	8151	Economy	6700.00
0005435903208	3494	Business	35000.00
0005435914216	3494	Comfort	19900.00
0005435626739	14565	Business	35000.00
0005432800289	14565	Economy	11700.00
0005432800290	14565	Economy	11700.00
0005435127574	14565	Economy	11700.00
0005435127588	14565	Economy	11700.00
0005435626868	14565	Economy	11700.00
0005435626869	14565	Economy	12800.00
0005435626855	14565	Economy	11700.00
0005435626854	14565	Economy	11700.00
0005434938695	14565	Economy	11700.00
0005435626764	14565	Economy	11700.00
0005435629451	16099	Economy	10400.00
0005435797896	29312	Economy	4600.00
0005433962773	25746	Business	21400.00
0005433962739	25746	Business	21400.00
0005433962466	25746	Business	21400.00
0005433962687	25746	Economy	7100.00
0005433962758	25746	Economy	7100.00
0005433962740	25746	Economy	7100.00
0005433962731	25746	Economy	7800.00
0005433962750	25746	Economy	7800.00
0005433962473	25746	Economy	7100.00
0005433962718	25746	Economy	7100.00
0005433962707	25746	Economy	7100.00
0005433962703	25746	Economy	7100.00
0005433962759	25746	Economy	7100.00
0005433962719	25746	Economy	7100.00
0005433962696	25746	Economy	7100.00
0005433962640	25746	Economy	7100.00
0005433962625	25746	Economy	7100.00
0005433962751	25746	Economy	7100.00
0005433962717	25746	Economy	7100.00
0005433962681	25746	Economy	7100.00
0005433962686	25746	Economy	7100.00
0005433962585	25746	Economy	7100.00
0005433962704	25746	Economy	7100.00
0005433962701	25746	Economy	7100.00
0005433962700	25746	Economy	7100.00
0005433962702	25746	Economy	7100.00
0005433962624	25746	Economy	7100.00
0005433962720	25746	Economy	7100.00
0005433962598	25746	Economy	7100.00
0005433962541	25746	Economy	7100.00
0005433962586	25746	Economy	7100.00
0005435287051	5109	Economy	6000.00
0005435286974	5109	Economy	6000.00
0005435287052	5109	Economy	6000.00
0005435551772	5109	Economy	6000.00
0005435551774	5109	Economy	6600.00
0005435287034	5109	Economy	6000.00
0005435286881	5109	Economy	6000.00
0005435287000	5109	Economy	6000.00
0005435286973	5109	Economy	6000.00
0005435287002	5109	Economy	6000.00
0005435287033	5109	Economy	6000.00
0005435286880	5109	Economy	6000.00
0005435287054	5109	Economy	6000.00
0005435477012	5109	Economy	6000.00
0005435287001	5109	Economy	6000.00
0005435732743	5116	Economy	6000.00
0005432663107	8590	Business	18000.00
0005433786175	8590	Business	18000.00
0005433786176	8590	Economy	6000.00
0005433786174	8590	Economy	6000.00
0005433786163	8590	Economy	6000.00
0005433786162	8590	Economy	6000.00
0005433786164	8590	Economy	6000.00
0005433786108	8590	Economy	6000.00
0005432659765	8590	Economy	6000.00
0005433786068	8590	Economy	6000.00
0005433786177	8590	Economy	6000.00
0005433786067	8590	Economy	6000.00
0005432663108	8590	Economy	6000.00
0005434230239	8591	Business	18000.00
0005434230274	8591	Business	18000.00
0005433616824	8591	Business	18000.00
0005433616822	8591	Economy	6000.00
0005434230263	8591	Economy	6000.00
0005434230240	8591	Economy	6000.00
0005434230287	8591	Economy	6600.00
0005433616825	8591	Economy	6000.00
0005433616818	8591	Economy	6000.00
0005434230249	8591	Economy	6000.00
0005433616823	8591	Economy	6000.00
0005434230275	8591	Economy	6000.00
0005434230081	8591	Economy	6000.00
0005434230262	8591	Economy	6000.00
0005434230028	8592	Business	18000.00
0005434173635	8592	Economy	6000.00
0005434229986	8592	Economy	6000.00
0005435629449	8592	Economy	6000.00
0005434230029	8592	Economy	6000.00
0005432384288	21095	Economy	6300.00
0005432330033	21095	Economy	6900.00
0005432330012	21095	Economy	6300.00
0005432384289	21095	Economy	6300.00
0005432954200	2471	Business	89600.00
0005432954188	2471	Economy	29900.00
0005432954201	2471	Economy	29900.00
0005432954187	2471	Economy	29900.00
0005433642776	27592	Economy	29900.00
0005432426013	30761	Business	12700.00
0005432425939	30761	Economy	4200.00
0005432425866	30761	Economy	4700.00
0005432426042	30761	Economy	4200.00
0005432425865	30761	Economy	4200.00
0005432426065	30761	Economy	4200.00
0005432425940	30761	Economy	4200.00
0005432425929	30761	Economy	4200.00
0005432426012	30761	Economy	4200.00
0005432426066	30761	Economy	4200.00
0005432426064	30761	Economy	4200.00
0005433570986	25290	Business	105900.00
0005433570882	25290	Business	105900.00
0005433570967	25290	Economy	35300.00
0005433570987	25290	Economy	35300.00
0005433570963	25290	Economy	35300.00
0005433570988	25290	Economy	35300.00
0005433570960	25290	Economy	35300.00
0005433570893	25290	Economy	35300.00
0005432429033	7466	Economy	10700.00
0005432429031	7466	Economy	10700.00
0005432429032	7466	Economy	10700.00
0005435266337	7466	Economy	10700.00
0005434352060	29650	Economy	14000.00
0005434352059	29650	Economy	14000.00
0005433346063	1073	Business	30600.00
0005433346019	1073	Business	30600.00
0005433346064	1073	Economy	10200.00
0005433346054	1073	Economy	10200.00
0005433346053	1073	Economy	10200.00
0005433345921	1073	Economy	10200.00
0005433346085	1073	Economy	10200.00
0005433346018	1073	Economy	10200.00
0005433345849	1073	Economy	11200.00
0005433346055	1073	Economy	10200.00
0005433345945	1073	Economy	10200.00
0005433346062	1073	Economy	10200.00
0005435508817	17068	Economy	10200.00
0005435508823	17068	Economy	10200.00
0005435508816	17068	Economy	10200.00
0005435545996	17068	Economy	10200.00
0005435508822	17068	Economy	10200.00
0005435092367	17068	Economy	10200.00
0005434445321	17068	Economy	10200.00
0005435092366	17068	Economy	10200.00
0005435508824	17068	Economy	10200.00
0005435530149	17068	Economy	10200.00
0005435508821	17068	Economy	10200.00
0005435508833	17068	Economy	10200.00
0005434082651	12817	Business	40300.00
0005434069557	12817	Economy	13400.00
0005434082650	12817	Economy	13400.00
0005434082648	12817	Economy	13400.00
0005434082636	12817	Economy	13400.00
0005434082649	12817	Economy	13400.00
0005435463529	5532	Economy	11800.00
0005434265888	5532	Economy	11800.00
0005434265894	5532	Economy	11800.00
0005434265887	5532	Economy	11800.00
0005434265895	5532	Economy	11800.00
0005435463534	5532	Economy	11800.00
0005434265885	5532	Economy	11800.00
0005434265898	5532	Economy	11800.00
0005434265889	5532	Economy	11800.00
0005435463525	5532	Economy	11800.00
0005434265886	5532	Economy	11800.00
0005433529384	13480	Business	35300.00
0005435768045	13480	Business	35300.00
0005433529377	13480	Business	35300.00
0005433529389	13480	Economy	11800.00
0005435768051	13480	Economy	11800.00
0005435735284	13480	Economy	11800.00
0005433529375	13480	Economy	11800.00
0005435767848	13480	Economy	11800.00
0005435767849	13480	Economy	11800.00
0005433529388	13480	Economy	11800.00
0005435732743	13480	Economy	11800.00
0005433529376	13480	Economy	12900.00
0005435768046	13480	Economy	11800.00
0005433533420	13480	Economy	11800.00
0005433533419	13480	Economy	11800.00
0005435767850	13480	Economy	11800.00
0005434515046	19197	Economy	3300.00
0005435846359	4123	Business	88300.00
0005435844441	4123	Economy	29400.00
0005435844438	4123	Economy	29400.00
0005435846360	4123	Economy	29400.00
0005433009935	1820	Business	48700.00
0005433286224	1820	Business	48700.00
0005433009936	1820	Business	48700.00
0005433009830	1820	Economy	16200.00
0005433286217	1820	Economy	16200.00
0005433009967	1820	Economy	16200.00
0005433009965	1820	Economy	16200.00
0005433810789	22546	Economy	16200.00
0005433810720	22546	Economy	16200.00
0005435732726	22546	Economy	16200.00
0005433810792	22546	Economy	16200.00
0005433810777	22546	Economy	16200.00
0005433810721	22546	Economy	16200.00
0005433810790	22546	Economy	16200.00
0005435725788	22546	Economy	16200.00
0005433810797	22546	Economy	16200.00
0005433810788	22546	Economy	16200.00
0005435725762	22546	Economy	16200.00
0005435097504	22546	Economy	16200.00
0005435725776	22546	Economy	16200.00
0005435283252	5586	Economy	33300.00
0005435283253	5586	Economy	33300.00
0005435937572	4280	Economy	12700.00
0005434994305	27302	Economy	12700.00
0005435960175	4694	Business	40900.00
0005434150223	4694	Economy	13600.00
0005434150170	4694	Economy	13600.00
0005435960174	4694	Economy	13600.00
0005435840534	4694	Economy	13600.00
0005434082650	30553	Business	40900.00
0005434082636	30553	Business	40900.00
0005432461413	30553	Business	40900.00
0005432461328	30553	Business	40900.00
0005434082648	30553	Economy	13600.00
0005432569411	30553	Economy	13600.00
0005434082649	30553	Economy	13600.00
0005432569428	30553	Economy	13600.00
0005432569409	30553	Economy	13600.00
0005432461432	30553	Economy	13600.00
0005432569410	30553	Economy	13600.00
0005434082651	30553	Economy	13600.00
0005432569405	30553	Economy	13600.00
0005435380442	11092	Business	23600.00
0005435508832	11092	Economy	7900.00
0005435508781	11092	Economy	7900.00
0005433346018	17135	Business	23600.00
0005433346053	17135	Economy	7900.00
0005435097498	17135	Economy	7900.00
0005433345921	17135	Economy	7900.00
0005433346064	17135	Economy	8600.00
0005433345945	17135	Economy	7900.00
0005433346019	17135	Economy	7900.00
0005433346085	17135	Economy	7900.00
0005433346054	17135	Economy	7900.00
0005433346063	17135	Economy	7900.00
0005433345849	17135	Economy	7900.00
0005433346055	17135	Economy	7900.00
0005433346062	17135	Economy	7900.00
0005432920482	9074	Economy	8900.00
0005432920478	9074	Economy	8900.00
0005433507728	20485	Economy	8900.00
0005435179720	10165	Economy	5800.00
0005435179719	10165	Economy	5800.00
0005435626855	11007	Business	9500.00
0005435127574	11007	Economy	3200.00
0005435626868	11007	Economy	3200.00
0005435127588	11007	Economy	3200.00
0005435626739	11007	Economy	3200.00
0005435626854	11007	Economy	3200.00
0005435626869	11007	Economy	3200.00
0005435626764	11007	Economy	3200.00
0005434411900	14672	Economy	3200.00
0005433788314	20673	Economy	24600.00
0005433788324	20673	Economy	24600.00
0005433788325	20673	Economy	24600.00
0005433788315	20673	Economy	24600.00
0005433788321	20673	Economy	24600.00
0005433788309	20673	Economy	24600.00
0005435541647	11409	Economy	7400.00
0005435541620	11409	Economy	7400.00
0005435518461	11409	Economy	6700.00
0005435541648	11409	Economy	6700.00
0005432433839	13025	Economy	11300.00
0005432433840	13025	Economy	11300.00
0005435283597	7321	Business	23100.00
0005435283588	7321	Economy	7700.00
0005435283571	7321	Economy	7700.00
0005435283590	7321	Economy	7700.00
0005435283589	7321	Economy	7700.00
0005435283572	7321	Economy	7700.00
0005434505302	16675	Economy	7600.00
0005434505310	16675	Economy	6900.00
0005434505282	16675	Economy	6900.00
0005434505301	16675	Economy	6900.00
0005434505319	16675	Economy	6900.00
0005434505317	16675	Economy	6900.00
0005434505239	16675	Economy	6900.00
0005434505309	16675	Economy	6900.00
0005434989117	23594	Economy	10800.00
0005434989109	23594	Economy	10800.00
0005434989100	23594	Economy	9800.00
0005434989129	23594	Economy	9800.00
0005434989054	23594	Economy	9800.00
0005434989133	23594	Economy	9800.00
0005434989088	23594	Economy	9800.00
0005434989108	23594	Economy	9800.00
0005434989130	23594	Economy	9800.00
0005434989121	23594	Economy	9800.00
0005434989099	23594	Economy	9800.00
0005434989120	23594	Economy	9800.00
0005434989134	23594	Economy	9800.00
0005434989126	23594	Economy	9800.00
0005434989128	23594	Economy	9800.00
0005434989127	23594	Economy	9800.00
0005434989122	23594	Economy	9800.00
0005434989125	23594	Economy	9800.00
0005434989123	23594	Economy	9800.00
0005434989087	23594	Economy	9800.00
0005433869599	32595	Economy	19400.00
0005433869606	32595	Economy	17600.00
0005433869610	32595	Economy	17600.00
0005433869604	32595	Economy	17600.00
0005433869584	32595	Economy	17600.00
0005433869611	32595	Economy	17600.00
0005433869609	32595	Economy	17600.00
0005433869607	32595	Economy	17600.00
0005433869605	32595	Economy	17600.00
0005433869601	32595	Economy	17600.00
0005433869610	14477	Economy	18500.00
0005433869611	14477	Economy	16800.00
0005433869609	14477	Economy	16800.00
0005433869599	14477	Economy	16800.00
0005433869584	14477	Economy	16800.00
0005433869604	14477	Economy	16800.00
0005433869605	14477	Economy	16800.00
0005433869601	14477	Economy	16800.00
0005433869607	14477	Economy	16800.00
0005433869606	14477	Economy	16800.00
0005432800290	12108	Economy	4900.00
0005432800289	12108	Economy	4400.00
0005434409611	26913	Business	49100.00
0005434409548	26913	Business	49100.00
0005434409514	26913	Economy	16400.00
0005434409515	26913	Economy	18000.00
0005434409600	26913	Economy	16400.00
0005434300221	26913	Economy	16400.00
0005434409547	26913	Economy	16400.00
0005433009972	22836	Business	52300.00
0005434171514	22836	Economy	19200.00
0005434171513	22836	Economy	17400.00
0005433009971	22836	Economy	17400.00
0005433009954	22836	Economy	17400.00
0005433009981	22836	Economy	17400.00
0005435999793	15792	Economy	8900.00
0005435999851	15792	Economy	8100.00
0005432664202	18032	Economy	66400.00
0005432664201	18032	Economy	66400.00
0005435104375	32094	Business	15700.00
0005435104269	32094	Business	15700.00
0005435104358	32094	Economy	5200.00
0005435097509	32094	Economy	5200.00
0005435104385	32094	Economy	5200.00
0005435104387	32094	Economy	5200.00
0005435104388	32094	Economy	5200.00
0005435097525	32094	Economy	5200.00
0005435104386	32094	Economy	5200.00
0005435097508	32094	Economy	5200.00
0005435097513	32094	Economy	5200.00
0005435104320	32094	Economy	5200.00
0005435097514	32094	Economy	5200.00
0005435104381	32094	Economy	5200.00
0005435097522	32094	Economy	5200.00
0005435097521	32094	Economy	5200.00
0005435104384	32094	Economy	5200.00
0005435104352	32094	Economy	5200.00
0005435104389	32094	Economy	5200.00
\.


--
-- Data for Name: tickets; Type: TABLE DATA; Schema: bookings; Owner: -
--

COPY tickets (ticket_no, book_ref, passenger_id, passenger_name, contact_data) FROM stdin;
0005432000987	06B046	8149 604011	VALERIY TIKHONOV	{"phone": "+70127117011"}
0005432000988	06B046	8499 420203	EVGENIYA ALEKSEEVA	{"phone": "+70378089255"}
0005432000989	E170C3	1011 752484	ARTUR GERASIMOV	{"phone": "+70760429203"}
0005432000990	E170C3	4849 400049	ALINA VOLKOVA	{"email": "volkova.alina_03101973@postgrespro.ru", "phone": "+70582584031"}
0005432000991	F313DD	6615 976589	MAKSIM ZHUKOV	{"email": "m-zhukov061972@postgrespro.ru", "phone": "+70149562185"}
0005432000992	F313DD	2021 652719	NIKOLAY EGOROV	{"phone": "+70791452932"}
0005432000993	F313DD	0817 363231	TATYANA KUZNECOVA	{"email": "kuznecova-t-011961@postgrespro.ru", "phone": "+70400736223"}
0005432000994	CCC5CB	2883 989356	IRINA ANTONOVA	{"email": "antonova.irina04121972@postgrespro.ru", "phone": "+70844502960"}
0005432000995	CCC5CB	3097 995546	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina10101976@postgrespro.ru", "phone": "+70268080457"}
0005432000996	1FB1E4	6866 920231	POLINA ZHURAVLEVA	{"phone": "+70639918455"}
0005432000997	DE3EA6	6030 369450	ALEKSANDR TIKHONOV	{"phone": "+70568350272"}
0005432000998	4B75D1	8675 588663	ILYA POPOV	{"email": "popov_ilya.1971@postgrespro.ru", "phone": "+70003638926"}
0005432000999	9E60AA	0764 728785	ALEKSANDR KUZNECOV	{"phone": "+70892601069"}
0005432001000	69DAD1	8954 972101	VSEVOLOD BORISOV	{"email": "borisov_v_1975@postgrespro.ru", "phone": "+70126208679"}
0005432001001	69DAD1	6772 748756	NATALYA ROMANOVA	{"email": "n-romanova.1981@postgrespro.ru", "phone": "+70898580864"}
0005432001002	69DAD1	7364 216524	ANTON BONDARENKO	{"phone": "+70322899756"}
0005432001003	08A2A5	3635 182357	VALENTINA NIKITINA	{"email": "nikitinavalentina.1975@postgrespro.ru", "phone": "+70794132478"}
0005432001004	08A2A5	8252 507584	ALLA TARASOVA	{"phone": "+70212106431"}
0005432001005	C2CAB7	1026 982766	OKSANA MOROZOVA	{"phone": "+70806484401"}
0005432001006	C6DA66	7107 950192	GENNADIY GERASIMOV	{"email": "gerasimov.g111981@postgrespro.ru", "phone": "+70733090498"}
0005432001007	C6DA66	4765 014996	RAISA KONOVALOVA	{"phone": "+70038510644"}
0005432001008	3EFFCA	3342 145536	VIKTOR IVANOV	{"email": "ivanovviktor1976@postgrespro.ru", "phone": "+70467287014"}
0005432001009	7E0F14	0001 745349	OKSANA KOROLEVA	{"email": "okoroleva1963@postgrespro.ru", "phone": "+70512056517"}
0005432001010	63126E	7273 175330	NIKOLAY IVANOV	{"email": "ivanovn1963@postgrespro.ru", "phone": "+70841199867"}
0005432001011	285BC5	1370 120631	DENIS KUZNECOV	{"email": "kuznecov-d.1978@postgrespro.ru", "phone": "+70127715737"}
0005432001012	232788	5559 553314	ALEKSANDR DENISOV	{"email": "adenisov1964@postgrespro.ru", "phone": "+70827988994"}
0005432001013	EE82FC	6544 483657	NATALYA BELOVA	{"email": "natalyabelova.1970@postgrespro.ru", "phone": "+70969066252"}
0005432001014	C3B60B	7011 596158	YURIY MEDVEDEV	{"phone": "+70620336121"}
0005432001015	C3B60B	6772 891759	VLADIMIR POPOV	{"email": "vladimir_popov.121976@postgrespro.ru", "phone": "+70359525605"}
0005432001016	7DC7C4	8116 659266	ANZHELIKA ABRAMOVA	{"phone": "+70518693810"}
0005432001017	7DC7C4	3542 318601	SVETLANA VLASOVA	{"email": "vlasova_s.1965@postgrespro.ru", "phone": "+70375206559"}
0005432001018	36AA7A	8511 999561	LYUDMILA MELNIKOVA	{"email": "melnikova.l.061975@postgrespro.ru", "phone": "+70807339750"}
0005432001019	F11350	0630 169679	VITALIY ALEKSEEV	{"email": "alekseev-v.101975@postgrespro.ru", "phone": "+70816024815"}
0005432001020	82DB02	0085 303617	PAVEL GUSEV	{"phone": "+70450902749"}
0005432001021	82DB02	8080 870126	NATALYA ZAYCEVA	{"email": "zayceva-natalya_1965@postgrespro.ru", "phone": "+70323018596"}
0005432001022	572A29	3755 842338	LEONID ORLOV	{"email": "l_orlov.13061955@postgrespro.ru", "phone": "+70569828738"}
0005432001023	572A29	2295 465854	SVETLANA POPOVA	{"email": "s.popova.18041976@postgrespro.ru", "phone": "+70650410562"}
0005432001024	572A29	4245 607929	TATYANA MAKSIMOVA	{"phone": "+70235326894"}
0005432001025	31F31A	7859 943808	MARIYA FEDOROVA	{"email": "m.fedorova-011974@postgrespro.ru", "phone": "+70868265157"}
0005432001026	F5F784	2765 289085	OLEG KUZNECOV	{"email": "oleg.kuznecov-10101967@postgrespro.ru", "phone": "+70154552799"}
0005432001027	F5F784	4278 618557	LYUDMILA SOKOLOVA	{"phone": "+70834193348"}
0005432001028	598886	5657 976071	EVGENIY GUSEV	{"phone": "+70030408217"}
0005432001029	598886	9384 205645	VLADIMIR ANTONOV	{"email": "vladimir.antonov.121972@postgrespro.ru", "phone": "+70254846003"}
0005432001030	18C1D5	0544 834528	NIKOLAY VOLKOV	{"email": "nvolkov_1965@postgrespro.ru", "phone": "+70866269566"}
0005432001031	EA4481	6365 326222	IVAN MEDVEDEV	{"phone": "+70386792287"}
0005432001032	EA4481	7686 012334	ELENA STEPANOVA	{"email": "stepanova_e_101981@postgrespro.ru", "phone": "+70501251610"}
0005432001033	94A438	1564 396952	VLADIMIR SEMENOV	{"email": "v.semenov-111977@postgrespro.ru", "phone": "+70423972699"}
0005432001034	0C3F23	2279 938743	SERGEY RODIONOV	{"phone": "+70173119239"}
0005432001035	0C3F23	8140 620813	ALEKSANDR NAUMOV	{"phone": "+70845063940"}
0005432001036	F1AF5B	9257 239781	OLESYA BELOVA	{"phone": "+70032251911"}
0005432001037	2EAC25	5829 268568	GLEB SERGEEV	{"phone": "+70833682034"}
0005432001038	7C4EB0	7140 936574	ANTONIDA AKIMOVA	{"phone": "+70008312768"}
0005432001039	47F326	6055 541445	MARIYA KONOVALOVA	{"phone": "+70616079128"}
0005432001040	47F326	6856 343851	OKSANA GAVRILOVA	{"phone": "+70760750840"}
0005432001041	750FC5	1989 394243	VLADIMIR MIRONOV	{"email": "mironov-vladimir-02021977@postgrespro.ru", "phone": "+70687617377"}
0005432001042	750FC5	7497 108600	TATYANA OSIPOVA	{"email": "t.osipova011972@postgrespro.ru", "phone": "+70912861848"}
0005432001043	4109DE	5324 130395	EVGENIY SEMENOV	{"phone": "+70932081461"}
0005432001044	D067BC	6259 021260	RAISA ROMANOVA	{"email": "romanova.r-18081971@postgrespro.ru", "phone": "+70955400547"}
0005432001045	D067BC	6849 694832	ALEKSANDR SMIRNOV	{"email": "asmirnov.071957@postgrespro.ru", "phone": "+70138371984"}
0005432001046	FE0198	9542 445779	IRINA KAZAKOVA	{"email": "kazakova-irina_061985@postgrespro.ru", "phone": "+70816143153"}
0005432001047	FE0198	2536 676370	ANNA KAZAKOVA	{"phone": "+70996719782"}
0005432001048	EA9B0F	3392 878429	ILYA BONDARENKO	{"email": "bondarenko.ilya_1980@postgrespro.ru", "phone": "+70743678093"}
0005432001049	6D004A	0207 310663	SOFYA DAVYDOVA	{"email": "sofya.davydova.1966@postgrespro.ru", "phone": "+70894115583"}
0005432001050	6D004A	6808 774590	MARINA SEMENOVA	{"phone": "+70746710027"}
0005432001051	8E6BB3	5582 658715	ANNA BORISOVA	{"phone": "+70282151122"}
0005432001052	8E6BB3	8109 611094	EGOR NIKOLAEV	{"email": "e_nikolaev-07021970@postgrespro.ru", "phone": "+70422011135"}
0005432001053	D8094E	2489 626224	SERGEY VOLKOV	{"phone": "+70929720436"}
0005432001054	7E76A9	2811 332014	VLADIMIR AFANASEV	{"email": "afanasev-v.25051972@postgrespro.ru", "phone": "+70464902131"}
0005432001055	4A1A3A	7198 591092	TATYANA KISELEVA	{"phone": "+70083851158"}
0005432001056	90FF45	3262 369338	SVETLANA LUKYANOVA	{"email": "lukyanova.s.101976@postgrespro.ru", "phone": "+70451586731"}
0005432001057	FDE044	4128 658175	SERGEY MOROZOV	{"email": "morozovs031982@postgrespro.ru", "phone": "+70300710344"}
0005432001058	FDE044	6709 734767	ALEKSANDR MAKSIMOV	{"phone": "+70803198912"}
0005432001059	88411C	0326 266595	NIKOLAY FOMIN	{"phone": "+70566082566"}
0005432001060	D0B9CE	2215 922557	LIDIYA CHERNOVA	{"email": "lidiya-chernova101971@postgrespro.ru", "phone": "+70976485519"}
0005432001061	D0B9CE	2290 450397	SVETLANA SIDOROVA	{"email": "s-sidorova_031971@postgrespro.ru", "phone": "+70263808510"}
0005432001062	D0B9CE	2467 774707	VYACHESLAV ILIN	{"phone": "+70275234145"}
0005432001063	ACCA92	7650 555895	ROMAN BARANOV	{"email": "roman_baranov-1973@postgrespro.ru", "phone": "+70002968931"}
0005432001064	4FAEB6	5364 307705	DIANA NESTEROVA	{"phone": "+70688114495"}
0005432001065	EC1E8B	1115 708092	LARISA POPOVA	{"phone": "+70621931072"}
0005432001066	EC1E8B	7066 161500	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr-091971@postgrespro.ru", "phone": "+70539788707"}
0005432001067	717CED	6903 458379	YURIY ROMANOV	{"phone": "+70101140704"}
0005432001068	717CED	2651 489583	ALEKSEY EGOROV	{"email": "egorov.a041974@postgrespro.ru", "phone": "+70731329841"}
0005432001069	5C9140	5534 060462	EKATERINA ILINA	{"phone": "+70940844444"}
0005432001070	AA2140	1527 165464	RUSLAN PETROV	{"phone": "+70672454440"}
0005432001071	4DC130	1051 084909	GALINA VOROBEVA	{"email": "g.vorobeva_081991@postgrespro.ru", "phone": "+70972213683"}
0005432001072	378E67	8616 037931	TATYANA SMIRNOVA	{"phone": "+70159055796"}
0005432001073	7B4620	8557 326046	MIKHAIL GRIGOREV	{"phone": "+70948810700"}
0005432001074	7327C3	1662 000481	EKATERINA ZAYCEVA	{"phone": "+70950001418"}
0005432001075	7327C3	2432 012911	PAVEL GERASIMOV	{"email": "gerasimov_p_12061961@postgrespro.ru", "phone": "+70431383084"}
0005432001076	B0EEAB	6723 926887	NADEZHDA SOROKINA	{"email": "sorokinanadezhda-18011975@postgrespro.ru", "phone": "+70453869609"}
0005432001077	9C6646	3608 388798	ALEKSANDR AFANASEV	{"email": "afanasev-aleksandr1962@postgrespro.ru", "phone": "+70144051720"}
0005432001078	9C6646	7140 268929	ELENA AFANASEVA	{"phone": "+70593645549"}
0005432001079	9C6646	8851 001440	EKATERINA KUZNECOVA	{"phone": "+70069354504"}
0005432001080	12C67A	3802 843058	ALEKSEY ALEKSANDROV	{"email": "a-aleksandrov.01061977@postgrespro.ru", "phone": "+70359103481"}
0005432002040	763A73	7953 226769	SVETLANA SMIRNOVA	{"email": "smirnova-s.11101976@postgrespro.ru", "phone": "+70265420366"}
0005432002041	460AAE	4046 519379	NIKOLAY DMITRIEV	{"phone": "+70381804597"}
0005432002042	29182D	7906 253170	TAMARA NAUMOVA	{"email": "naumova_tamara.1983@postgrespro.ru", "phone": "+70200351125"}
0005432002043	E5546D	3499 600919	SANIYA GORBUNOVA	{"email": "saniya_gorbunova_08091976@postgrespro.ru", "phone": "+70691706678"}
0005432002044	BE9453	7634 557379	STEPAN ANDREEV	{"phone": "+70762580807"}
0005432002045	BE9453	3040 999771	NATALYA KRASNOVA	{"phone": "+70779843025"}
0005432002046	1C9C91	9798 777629	TATYANA EGOROVA	{"email": "egorova.tatyana021984@postgrespro.ru", "phone": "+70279980404"}
0005432002047	07FA66	1965 249712	ANATOLIY YAKOVLEV	{"email": "anatoliy-yakovlev1968@postgrespro.ru", "phone": "+70814295471"}
0005432002048	72B58D	3721 175259	RAISA KONOVALOVA	{"email": "konovalova-r_26081979@postgrespro.ru", "phone": "+70194716988"}
0005432002049	0DB5AD	6010 499587	VALENTIN KAZAKOV	{"email": "kazakov_valentin.29061971@postgrespro.ru", "phone": "+70293067922"}
0005432002050	997E15	1779 518628	IVAN KUDRYASHOV	{"phone": "+70268002514"}
0005432002051	870D94	5097 655285	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila.031969@postgrespro.ru", "phone": "+70782391603"}
0005432002052	968984	8644 554295	OLGA MASLOVA	{"email": "maslova-olga1969@postgrespro.ru", "phone": "+70758777374"}
0005432002053	8C7425	6186 994345	VLADISLAV DAVYDOV	{"email": "davydov-v.051972@postgrespro.ru", "phone": "+70489667506"}
0005432002054	8C7425	4695 856216	VLADISLAV MIKHAYLOV	{"email": "mikhaylovv_1971@postgrespro.ru", "phone": "+70999329143"}
0005432002055	51F5DD	8783 595848	ANTON POPOV	{"email": "anton.popov101986@postgrespro.ru", "phone": "+70976453918"}
0005432002056	73EA62	2043 017956	VLADIMIR ABRAMOV	{"email": "abramov_vladimir.1977@postgrespro.ru", "phone": "+70547391621"}
0005432002057	A5D460	4616 199659	SVETLANA NIKOLAEVA	{"email": "snikolaeva.17121969@postgrespro.ru", "phone": "+70326617507"}
0005432002058	0251F7	8958 344017	ALEKSANDR KOROLEV	{"phone": "+70135147843"}
0005432002059	FF22FD	6934 410835	NATALYA NIKIFOROVA	{"email": "nnikiforova_1989@postgrespro.ru", "phone": "+70008969413"}
0005432002060	FF22FD	0785 272945	IGOR SMIRNOV	{"phone": "+70403323675"}
0005432002061	87CD54	7922 672476	VADIM NIKOLAEV	{"email": "v.nikolaev1970@postgrespro.ru", "phone": "+70346224801"}
0005432002062	EB268F	0773 380234	PETR KUDRYASHOV	{"email": "p.kudryashov-1978@postgrespro.ru", "phone": "+70746551013"}
0005432002063	EB268F	4410 246549	LARISA ANDREEVA	{"phone": "+70810193492"}
0005432002064	EB268F	7642 296155	ANASTASIYA TITOVA	{"phone": "+70644111723"}
0005432002065	0B59DC	1923 120553	ELENA ZAYCEVA	{"phone": "+70069874535"}
0005432002066	CD57C7	3728 554045	VALERIY ZHURAVLEV	{"phone": "+70708243398"}
0005432002067	B6F102	0629 646553	VALENTINA POPOVA	{"phone": "+70372334526"}
0005432002068	E79588	0372 961331	ALEKSANDR YAKOVLEV	{"phone": "+70644378927"}
0005432002069	577432	4092 308813	ARTEM BELOV	{"email": "a-belov-091968@postgrespro.ru", "phone": "+70381839476"}
0005432002070	577432	1711 618099	MIKHAIL KUZNECOV	{"phone": "+70084503465"}
0005432002071	4A2634	3162 818670	DMITRIY GRIGOREV	{"phone": "+70990515252"}
0005432002072	0190EA	1516 279111	EVGENIYA TARASOVA	{"email": "evgeniya.tarasova.1975@postgrespro.ru", "phone": "+70800308378"}
0005432002073	66583B	1351 880695	MAKSIM MAKAROV	{"email": "m_makarov031979@postgrespro.ru", "phone": "+70019526280"}
0005432002074	66583B	6734 551438	IVAN STEPANOV	{"phone": "+70392144991"}
0005432002075	7FDD9E	5007 881943	OLGA SCHERBAKOVA	{"email": "scherbakovao031964@postgrespro.ru", "phone": "+70290603147"}
0005432002076	7FDD9E	0040 228336	ANDREY NOVIKOV	{"email": "novikov.andrey_1975@postgrespro.ru", "phone": "+70335221559"}
0005432002077	7FDD9E	8787 021967	NATALYA NIKOLAEVA	{"email": "n_nikolaeva28011970@postgrespro.ru", "phone": "+70521094520"}
0005432002078	7FDD9E	8740 671993	LIDIYA MIKHAYLOVA	{"email": "mikhaylova-l.1975@postgrespro.ru", "phone": "+70733133460"}
0005432002079	591681	4951 373336	NAILYA OSIPOVA	{"phone": "+70389228708"}
0005432002080	305FED	2284 731506	VLADIMIR POPOV	{"email": "vladimir-popov1971@postgrespro.ru", "phone": "+70515420873"}
0005432002081	305FED	6745 357385	IVAN FROLOV	{"email": "frolov_i_101966@postgrespro.ru", "phone": "+70886971455"}
0005432002082	91B552	9559 912020	DMITRIY AFANASEV	{"phone": "+70068604338"}
0005432002083	91B552	6061 665501	LYUDMILA BARANOVA	{"email": "l_baranova02041976@postgrespro.ru", "phone": "+70735288539"}
0005432002084	91B552	5257 259922	EKATERINA MAKAROVA	{"phone": "+70030164971"}
0005432002085	779171	2081 267369	EGOR STEPANOV	{"email": "e.stepanov_1966@postgrespro.ru", "phone": "+70066037200"}
0005432002086	E8328C	2530 856376	NINA MALYSHEVA	{"email": "n.malysheva21101974@postgrespro.ru", "phone": "+70522189133"}
0005432002087	1E49CB	7834 217071	NATALYA NESTEROVA	{"phone": "+70008655333"}
0005432002088	71004B	6671 353458	ALEKSANDR VLASOV	{"phone": "+70130566548"}
0005432002089	912031	6142 188205	ANASTASIYA SEMENOVA	{"phone": "+70125671307"}
0005432002090	4926F5	2719 114850	PAVEL MEDVEDEV	{"email": "pavel_medvedev_051962@postgrespro.ru", "phone": "+70164122723"}
0005432002091	04E1A6	6285 568179	OLEG NOVIKOV	{"email": "olegnovikov09081960@postgrespro.ru", "phone": "+70118631206"}
0005432002092	81E245	1519 677002	VALENTINA MOROZOVA	{"phone": "+70408848681"}
0005432002093	D82597	5337 985896	VALERIYA PETROVA	{"phone": "+70419809549"}
0005432002094	D2E575	2125 227779	SERGEY MELNIKOV	{"email": "smelnikov-021971@postgrespro.ru", "phone": "+70826094885"}
0005432002095	D2E575	9368 371119	VALENTINA NIKOLAEVA	{"email": "valentinanikolaeva.071971@postgrespro.ru", "phone": "+70460637068"}
0005432002096	E91FFA	7771 568929	ALEKSEY ISAEV	{"email": "aisaev_06101977@postgrespro.ru", "phone": "+70355424701"}
0005432002097	E91FFA	8400 665396	VLADIMIR KOZLOV	{"email": "kozlovv-031978@postgrespro.ru", "phone": "+70722366555"}
0005432002098	E91FFA	2017 987584	ALEKSANDRA SERGEEVA	{"email": "sergeeva-a.1969@postgrespro.ru", "phone": "+70216234428"}
0005432002099	E91FFA	2978 913979	OLGA FEDOROVA	{"email": "o_fedorova.15021969@postgrespro.ru", "phone": "+70306599570"}
0005432002100	EBE02B	5428 141449	ALEKSEY SERGEEV	{"email": "sergeev_aleksey051971@postgrespro.ru", "phone": "+70888931421"}
0005432002101	EE9AB7	4412 370512	VLADIMIR SMIRNOV	{"email": "smirnov_v_1971@postgrespro.ru", "phone": "+70722050322"}
0005432002102	D27AB8	3492 636407	SERGEY SHEVCHENKO	{"phone": "+70713122267"}
0005432002103	D27AB8	7630 718270	YAROSLAV TIMOFEEV	{"email": "yaroslavtimofeev1970@postgrespro.ru", "phone": "+70517392168"}
0005432002104	D27AB8	9434 011529	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_25071970@postgrespro.ru", "phone": "+70305761859"}
0005432002105	822D3F	6184 350459	IGOR PETROV	{"email": "petrov_igor.1973@postgrespro.ru", "phone": "+70588304996"}
0005432002106	C4F765	5005 723955	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.1976@postgrespro.ru", "phone": "+70780340065"}
0005432002107	C4F765	6340 891229	ALEKSANDR GORBUNOV	{"phone": "+70345477185"}
0005432002108	01D17B	0099 383201	NATALYA MEDVEDEVA	{"email": "medvedevanatalya1970@postgrespro.ru", "phone": "+70456010818"}
0005432002109	A63705	7046 102995	ALENA EFREMOVA	{"email": "efremova_alena_121967@postgrespro.ru", "phone": "+70592017025"}
0005432002110	53EE1F	3442 513616	VLADIMIR IVANOV	{"email": "vladimir_ivanov09071975@postgrespro.ru", "phone": "+70138022132"}
0005432002111	274AC4	1024 016017	SERGEY IVANOV	{"email": "s_ivanov1972@postgrespro.ru", "phone": "+70885144627"}
0005432002112	958939	9892 527641	ANASTASIYA MARTYNOVA	{"email": "martynova_anastasiya.13101979@postgrespro.ru", "phone": "+70185282807"}
0005432002113	958939	7771 399433	ELIZAVETA ANDREEVA	{"email": "elizaveta-andreeva.04061980@postgrespro.ru", "phone": "+70892781012"}
0005432002114	6AB291	1251 356266	PAVEL MIKHAYLOV	{"email": "mikhaylovpavel.06101975@postgrespro.ru", "phone": "+70312817589"}
0005432002115	6AB291	0964 663736	PAVEL FEDOROV	{"phone": "+70131045700"}
0005432002116	6F5347	1539 494854	ALEKSEY VASILEV	{"phone": "+70213000443"}
0005432002117	CEBCE8	9614 779520	ANNA ANTONOVA	{"email": "antonova.a-09021975@postgrespro.ru", "phone": "+70957377604"}
0005432002118	DE4DA1	4009 898890	YULIYA SAVELEVA	{"phone": "+70976806526"}
0005432002119	7B03C1	2189 414514	ANATOLIY NIKITIN	{"phone": "+70109048870"}
0005432002120	B70F27	9287 665666	IRINA NAUMOVA	{"phone": "+70994853856"}
0005432002121	31FAA5	7025 139528	GALIYA DMITRIEVA	{"phone": "+70024177302"}
0005432002122	31FAA5	6048 365559	DMITRIY DENISOV	{"email": "dmitriydenisov.1964@postgrespro.ru", "phone": "+70689930966"}
0005432002123	9E9472	6148 117177	NIKITA ROMANOV	{"email": "nikitaromanov-031971@postgrespro.ru", "phone": "+70653368441"}
0005432002124	0DBEBD	9598 958485	GENNADIY IVANOV	{"email": "gennadiyivanov1969@postgrespro.ru", "phone": "+70359003021"}
0005432002125	263191	7751 244017	MARIYA MAKSIMOVA	{"phone": "+70622470372"}
0005432002126	263191	7530 019951	GALINA TIKHONOVA	{"phone": "+70108937277"}
0005432002127	F29C09	8896 392275	IRINA ABRAMOVA	{"email": "i-abramova.02011969@postgrespro.ru", "phone": "+70277814627"}
0005432002128	F29C09	1802 320892	ANDREY ALEKSEEV	{"phone": "+70917768633"}
0005432002129	8BA30C	4930 860654	NINA SOKOLOVA	{"phone": "+70462550614"}
0005432002130	577969	4608 412107	TATYANA ZHURAVLEVA	{"phone": "+70013561455"}
0005432002131	6CFEB8	0896 877389	NIKITA MAKSIMOV	{"email": "nmaksimov1984@postgrespro.ru", "phone": "+70603865098"}
0005432002132	49DA66	4345 501219	NATALIYA KAZAKOVA	{"email": "kazakova-n_29101972@postgrespro.ru", "phone": "+70143910640"}
0005432002133	E2634D	5145 999640	MIKHAIL ZHURAVLEV	{"phone": "+70900505612"}
0005432002134	41E97D	2091 828112	YULIYA YUDINA	{"phone": "+70405615125"}
0005432002135	72E9A2	9050 091605	NINA ZOTOVA	{"email": "zotova-n_011984@postgrespro.ru", "phone": "+70693576717"}
0005432002136	72E9A2	3080 758447	VLADISLAV KUZNECOV	{"phone": "+70705595171"}
0005432002137	568FA3	0730 574794	EMIL ISAEV	{"phone": "+70483776157"}
0005432003645	D34ADF	5763 808478	SERGEY FILIPPOV	{"email": "sfilippov1973@postgrespro.ru", "phone": "+70407414118"}
0005432003646	1FE8F6	7352 229580	YURIY SIDOROV	{"email": "sidorov-yuriy-17021978@postgrespro.ru", "phone": "+70132834771"}
0005432003647	1FE8F6	0990 692076	ANATOLIY KAZAKOV	{"phone": "+70118113427"}
0005432003648	CE01AE	9420 542320	VALERIYA PETROVA	{"email": "petrovavaleriya-011958@postgrespro.ru", "phone": "+70988744639"}
0005432003649	CE01AE	5356 110572	NIKITA MARTYNOV	{"email": "martynov.nikita31081968@postgrespro.ru", "phone": "+70326216766"}
0005432003650	2539B6	1356 407932	ELENA SOROKINA	{"phone": "+70058293084"}
0005432003651	F69AAC	7432 315875	SVETLANA BELOVA	{"email": "svetlana_belova.16061977@postgrespro.ru", "phone": "+70295567656"}
0005432003652	BC92C6	2961 981128	KONSTANTIN KUZMIN	{"phone": "+70791174792"}
0005432003653	BC92C6	8883 114742	YURIY MIKHAYLOV	{"email": "mikhaylovyuriy_1976@postgrespro.ru", "phone": "+70550275407"}
0005432003654	B68857	3371 474323	VALENTINA BELOVA	{"email": "belova-valentina_041979@postgrespro.ru", "phone": "+70354477048"}
0005432003655	B68857	3166 908684	EKATERINA VLASOVA	{"phone": "+70020543179"}
0005432003656	B2BF63	7373 957677	ALEKSANDR TARASOV	{"email": "a-tarasov_1975@postgrespro.ru", "phone": "+70505071072"}
0005432003657	86B9CF	4544 543692	IGOR DENISOV	{"email": "denisovigor.1976@postgrespro.ru", "phone": "+70486080498"}
0005432003658	54EC3C	1213 163131	TATYANA ALEKSEEVA	{"phone": "+70424968735"}
0005432003659	54EC3C	0693 483818	KLAVDIYA ARKHIPOVA	{"email": "k_arkhipova-051975@postgrespro.ru", "phone": "+70496463908"}
0005432003660	30B129	4418 156267	ANNA SEMENOVA	{"phone": "+70117459301"}
0005432003661	91693C	2712 185563	ALEKSEY SHEVCHENKO	{"phone": "+70118403026"}
0005432003662	E8A492	7162 304983	SERGEY SEMENOV	{"email": "semenov-sergey121985@postgrespro.ru", "phone": "+70784562877"}
0005432003663	E8A492	8574 652566	YULIYA BOGDANOVA	{"email": "bogdanovayuliya_101964@postgrespro.ru", "phone": "+70501291092"}
0005432003664	78C8AB	9368 135059	MIKHAIL FROLOV	{"email": "frolovmikhail-1962@postgrespro.ru", "phone": "+70181641443"}
0005432003665	235263	4321 784474	NIKOLAY KRASNOV	{"email": "krasnov_nikolay_23061978@postgrespro.ru", "phone": "+70921532941"}
0005432003666	FE8DC3	4175 923375	VERA SCHERBAKOVA	{"email": "scherbakova_v.1981@postgrespro.ru", "phone": "+70984762364"}
0005432003667	FE8DC3	7630 166228	NATALYA ALEKSEEVA	{"email": "alekseevanatalya-15041968@postgrespro.ru", "phone": "+70737023857"}
0005432003668	D39010	6415 439789	SERGEY ISAEV	{"phone": "+70028214106"}
0005432003669	4FCEE6	6791 082522	NINA KUZMINA	{"email": "kuzminanina-31011965@postgrespro.ru", "phone": "+70654853812"}
0005432003670	E33E2B	7893 562577	IVAN POPOV	{"email": "ivanpopov.1985@postgrespro.ru", "phone": "+70798991248"}
0005432003671	610C0E	1737 059096	NATALYA BELYAEVA	{"email": "belyaeva-n_09111974@postgrespro.ru", "phone": "+70794754910"}
0005432003672	C7D1C1	0796 697225	NATALIYA NAZAROVA	{"email": "nazarovan_16081980@postgrespro.ru", "phone": "+70107446104"}
0005432003673	C7D1C1	0750 738975	VADIM BARANOV	{"phone": "+70718887901"}
0005432003674	FBC58C	8926 645860	OLGA ANISIMOVA	{"email": "anisimova-olga.111983@postgrespro.ru", "phone": "+70494488809"}
0005432003675	FBC58C	6069 507361	ALEKSANDR KUZMIN	{"phone": "+70846239137"}
0005432003676	7CEF60	1742 484872	VLADIMIR IVANOV	{"email": "ivanov_vladimir_1977@postgrespro.ru", "phone": "+70348147359"}
0005432003677	DA7C29	9593 811595	VERONIKA FADEEVA	{"email": "fadeeva.veronika_27111964@postgrespro.ru", "phone": "+70821997229"}
0005432003678	1AE4B1	5351 530143	EVGENIYA KUZMINA	{"email": "evgeniya_kuzmina1972@postgrespro.ru", "phone": "+70355263317"}
0005432003679	C04A44	2911 522380	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy.13121970@postgrespro.ru", "phone": "+70262971068"}
0005432003680	87B5F4	5553 250318	VLADIMIR SERGEEV	{"phone": "+70935513095"}
0005432003681	975516	7270 339448	EVGENIYA TIKHONOVA	{"email": "e.tikhonova-03121975@postgrespro.ru", "phone": "+70730084791"}
0005432003682	E776F1	9195 526669	VASILIY DAVYDOV	{"phone": "+70794801062"}
0005432003683	269611	0015 392971	ARKADIY MOROZOV	{"phone": "+70302158840"}
0005432003684	269611	0667 994328	KRISTINA DMITRIEVA	{"phone": "+70053573502"}
0005432003685	EACE29	1472 507617	NATALYA STEPANOVA	{"email": "natalya.stepanova-031966@postgrespro.ru", "phone": "+70585815674"}
0005432003686	D6425C	9720 046214	TAMARA ZAKHAROVA	{"phone": "+70636911493"}
0005432003687	FA077C	4949 271354	EKATERINA AKIMOVA	{"email": "akimova-ekaterina.1971@postgrespro.ru", "phone": "+70056947074"}
0005432003688	D50E16	2805 612979	VALENTINA EGOROVA	{"phone": "+70370183648"}
0005432003689	D50E16	3959 005130	STANISLAV MAKSIMOV	{"phone": "+70815361402"}
0005432003690	8E481B	1902 281414	ALEKSANDR FILIPPOV	{"phone": "+70211464650"}
0005432003691	353E9D	2106 247086	ELENA MARTYNOVA	{"phone": "+70962867099"}
0005432003692	EB3D45	0048 842989	EKATERINA DMITRIEVA	{"phone": "+70443180323"}
0005432003693	8524D1	4631 903827	NATALYA GAVRILOVA	{"phone": "+70710023537"}
0005432003694	8524D1	6589 139365	STEPAN DAVYDOV	{"email": "s.davydov.081960@postgrespro.ru", "phone": "+70920228483"}
0005432003695	8524D1	3313 171813	VALERIYA IVANOVA	{"email": "valeriyaivanova.02121974@postgrespro.ru", "phone": "+70781622877"}
0005432003696	7E8647	1094 281585	TATYANA FADEEVA	{"email": "tatyana_fadeeva30011969@postgrespro.ru", "phone": "+70628975412"}
0005432003697	F90E1E	4092 035651	VYACHESLAV GAVRILOV	{"email": "gavrilovvyacheslav1963@postgrespro.ru", "phone": "+70700886487"}
0005432003698	F59A5C	4027 021486	ROMAN SOROKIN	{"phone": "+70918079318"}
0005432003699	49CD3E	5537 184275	VADIM YAKOVLEV	{"email": "yakovlevvadim_071967@postgrespro.ru", "phone": "+70479588848"}
0005432003700	E0FF37	4058 228327	VLADIMIR MAKAROV	{"phone": "+70406884048"}
0005432003701	031161	8789 984837	NATALYA SMIRNOVA	{"email": "natalya-smirnova-041969@postgrespro.ru", "phone": "+70567009903"}
0005432003702	031161	8041 983962	VLADISLAV MOISEEV	{"phone": "+70117849610"}
0005432003703	EBD8C7	6147 718396	LYUBOV GERASIMOVA	{"phone": "+70550479774"}
0005432003704	8CDA1D	8045 064468	ARTEM ABRAMOV	{"phone": "+70700851096"}
0005432003705	81A197	2792 479509	ALEKSEY SOKOLOV	{"email": "a-sokolov-1981@postgrespro.ru", "phone": "+70678076269"}
0005432003706	EB381C	4395 725672	YANA GRISHINA	{"email": "grishina-y22091978@postgrespro.ru", "phone": "+70204654837"}
0005432003707	FA71D7	1546 581209	DMITRIY TIKHONOV	{"phone": "+70302791725"}
0005432003708	7EB4FD	9699 386596	SVETLANA BELOVA	{"email": "belova-svetlana_23091976@postgrespro.ru", "phone": "+70661725303"}
0005432003709	1C19A3	3411 993529	ALEKSANDRA MARTYNOVA	{"phone": "+70415454155"}
0005432003710	0596DB	3457 559343	ANASTASIYA IVANOVA	{"phone": "+70100250421"}
0005432003711	0596DB	4193 473158	SERGEY NIKITIN	{"phone": "+70785214865"}
0005432003712	E14006	9472 074226	SERGEY OSIPOV	{"phone": "+70732447908"}
0005432003713	E14006	8018 599833	TAMARA VOLKOVA	{"email": "tamara-volkova1976@postgrespro.ru", "phone": "+70253901143"}
0005432003714	A18EDF	8372 097000	ILYA MOROZOV	{"email": "ilyamorozov.12011977@postgrespro.ru", "phone": "+70559179895"}
0005432003715	185997	1139 844497	ANNA FROLOVA	{"phone": "+70047679223"}
0005432003716	185997	0453 009167	VITALIY PAVLOV	{"email": "pavlov_v1966@postgrespro.ru", "phone": "+70160097374"}
0005432003717	A40F55	4471 656892	OLGA EFREMOVA	{"email": "olga_efremova061974@postgrespro.ru", "phone": "+70391029163"}
0005432003718	3E57DC	5912 784724	ANDREY ROMANOV	{"email": "romanov.a1975@postgrespro.ru", "phone": "+70737618246"}
0005432003719	3E57DC	7669 395771	YURIY BORISOV	{"email": "borisovy1974@postgrespro.ru", "phone": "+70948649713"}
0005432003720	B13EDC	8787 373041	SVETLANA POLYAKOVA	{"phone": "+70784273776"}
0005432003721	B13EDC	8852 798714	ALEKSANDR ORLOV	{"email": "orlov.aleksandr1957@postgrespro.ru", "phone": "+70859676939"}
0005432003722	123B65	9889 761857	DANIL MELNIKOV	{"email": "melnikovd.03111971@postgrespro.ru", "phone": "+70568155220"}
0005432003723	592624	5823 062375	ELENA ALEKSEEVA	{"email": "elenaalekseeva-1972@postgrespro.ru", "phone": "+70177464380"}
0005432003724	F86FE3	0248 084619	KONSTANTIN KISELEV	{"phone": "+70097070764"}
0005432003725	F86FE3	8093 015815	NINA NESTEROVA	{"phone": "+70926022560"}
0005432003726	9C5DAE	8669 073100	LYUCIYA SCHERBAKOVA	{"email": "scherbakova_lyuciya_011968@postgrespro.ru", "phone": "+70780305269"}
0005432003727	92DE26	7929 842603	VALENTINA SOKOLOVA	{"email": "v.sokolova12091979@postgrespro.ru", "phone": "+70832830605"}
0005432003728	AB7433	9228 599686	OKSANA PAVLOVA	{"phone": "+70231029064"}
0005432003729	C8331B	6048 440157	INNA PAVLOVA	{"phone": "+70834466668"}
0005432003730	C69989	9785 678737	GALINA BARANOVA	{"email": "baranovagalina_15121974@postgrespro.ru", "phone": "+70899748356"}
0005432003731	6A9641	3461 215546	NIKOLAY AFANASEV	{"phone": "+70890816419"}
0005432003732	5C52C6	7264 009909	VLADIMIR SOKOLOV	{"email": "v_sokolov.1970@postgrespro.ru", "phone": "+70896892224"}
0005432003733	079231	1001 132595	TATYANA OSIPOVA	{"phone": "+70137076461"}
0005432003734	9D26E1	2971 220471	IRINA RODIONOVA	{"phone": "+70608685587"}
0005432003735	4A4E63	0219 972863	ANNA POLYAKOVA	{"phone": "+70674445871"}
0005432003736	46A0F8	7636 010867	OLGA MASLOVA	{"email": "maslova.olga1969@postgrespro.ru", "phone": "+70919752742"}
0005432003737	46A0F8	9847 619975	LYUDMILA DMITRIEVA	{"email": "l.dmitrieva_051984@postgrespro.ru", "phone": "+70499065009"}
0005432003738	46A0F8	1384 167758	SVETLANA KOVALEVA	{"email": "svetlana_kovaleva-1988@postgrespro.ru", "phone": "+70054531583"}
0005432003739	0E84A1	8160 813874	SVETLANA PETROVA	{"phone": "+70821899504"}
0005432003740	2520B2	2400 780246	TATYANA KONDRATEVA	{"email": "kondrateva.t-09061962@postgrespro.ru", "phone": "+70695925093"}
0005432003741	991AB1	8280 357463	NADEZHDA DMITRIEVA	{"phone": "+70997482131"}
0005432003742	A1F275	2436 890917	EVGENIY KUDRYASHOV	{"email": "kudryashov-e061974@postgrespro.ru", "phone": "+70439546181"}
0005432003743	A1F275	3622 526714	ANNA KONOVALOVA	{"email": "akonovalova-1968@postgrespro.ru", "phone": "+70218331120"}
0005432003744	A1F275	9018 311034	ALLA KUZNECOVA	{"email": "alla.kuznecova-1969@postgrespro.ru", "phone": "+70065338401"}
0005432003745	B3D774	4661 702408	ANDREY FROLOV	{"email": "a.frolov_08041966@postgrespro.ru", "phone": "+70347998603"}
0005432003746	9DD60E	8654 429592	VLADIMIR FILIPPOV	{"phone": "+70528637629"}
0005432003747	0F783F	6762 796968	VYACHESLAV SERGEEV	{"phone": "+70836796043"}
0005432003748	B1ECA9	3701 240406	NATALYA ZAKHAROVA	{"email": "zakharovanatalya011960@postgrespro.ru", "phone": "+70395198857"}
0005432003749	0D588D	3397 557623	ALEKSEY ORLOV	{"phone": "+70800149424"}
0005432003750	5D1537	3292 325187	ANDREY SAVELEV	{"email": "asavelev-1975@postgrespro.ru", "phone": "+70268918721"}
0005432003751	F73FF6	8982 323108	TIGRAN GRIGOREV	{"phone": "+70698651379"}
0005432003752	BAC192	8214 272944	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr.021966@postgrespro.ru", "phone": "+70089173195"}
0005432003753	BAC192	0517 638974	KSENIYA YUDINA	{"email": "yudina.kseniya061972@postgrespro.ru", "phone": "+70401027516"}
0005432003754	BAC192	2862 128172	ZOYA KOMAROVA	{"email": "komarovaz_1973@postgrespro.ru", "phone": "+70959230450"}
0005432003755	CA102A	0142 925438	GALINA KONOVALOVA	{"phone": "+70126824204"}
0005432003756	CA102A	2236 250438	DIANA VLASOVA	{"email": "vlasova_d.081973@postgrespro.ru", "phone": "+70219442538"}
0005432003757	DBEF99	9676 520212	ELMIRA ZAKHAROVA	{"phone": "+70834161413"}
0005432003758	D99BD8	4431 007737	ALEKSANDR AFANASEV	{"phone": "+70062284954"}
0005432003759	D99BD8	6276 624317	ALEKSANDR FEDOTOV	{"email": "aleksandr_fedotov11121966@postgrespro.ru", "phone": "+70212229180"}
0005432003760	D99BD8	9345 564956	NATALYA NIKOLAEVA	{"email": "n_nikolaeva-19061974@postgrespro.ru", "phone": "+70586926111"}
0005432003761	8DA993	4137 339856	ALEKSANDR SAVELEV	{"email": "a.savelev-061979@postgrespro.ru", "phone": "+70712123376"}
0005432003762	8DA993	9149 091355	ANASTASIYA DANILOVA	{"phone": "+70150044699"}
0005432003763	62FD56	1512 523785	ANASTASIYA PAVLOVA	{"phone": "+70837139718"}
0005432003764	62FD56	1656 295096	VLADIMIR ROMANOV	{"email": "romanov_v13021978@postgrespro.ru", "phone": "+70763527003"}
0005432003765	95292F	4518 908407	ANDREY MOISEEV	{"phone": "+70057570736"}
0005432003766	C6C382	1576 926666	ELENA KULIKOVA	{"phone": "+70358057895"}
0005432003767	C6C382	8590 412874	MIKHAIL KRASNOV	{"phone": "+70428202651"}
0005432003768	B5C4B1	7189 412990	VALERIY IVANOV	{"email": "ivanov-valeriy071964@postgrespro.ru", "phone": "+70964263807"}
0005432003769	B5C4B1	7947 696545	TATYANA BORISOVA	{"email": "tatyana_borisova121967@postgrespro.ru", "phone": "+70834643504"}
0005432003770	8DA987	4341 662542	ALEKSANDR MARTYNOV	{"phone": "+70326204319"}
0005432003771	8DA987	5686 271611	VADIM ANDREEV	{"phone": "+70808337456"}
0005432003772	520E20	0759 215646	ANATOLIY KUZNECOV	{"phone": "+70689263035"}
0005432003773	520E20	6043 164334	YULIYA SOROKINA	{"phone": "+70103183588"}
0005432003774	D5D0E1	0965 267341	SERGEY ZAKHAROV	{"email": "sergey_zakharov1977@postgrespro.ru", "phone": "+70633802845"}
0005432003775	E5C6E5	5839 459746	SERGEY YAKOVLEV	{"email": "yakovlevs_27091975@postgrespro.ru", "phone": "+70015944973"}
0005432003776	E5C6E5	6857 692801	ANDREY ANTONOV	{"email": "andrey_antonov-1973@postgrespro.ru", "phone": "+70046704205"}
0005432003777	D1FDA3	7362 092647	ALEKSANDR GUSEV	{"email": "gusev-aleksandr-071978@postgrespro.ru", "phone": "+70114731036"}
0005432003778	D1FDA3	0280 251663	TATYANA KOROLEVA	{"phone": "+70569976583"}
0005432003779	81916B	5081 834363	MARGARITA NOVIKOVA	{"email": "novikova.margarita31071973@postgrespro.ru", "phone": "+70556225748"}
0005432003780	B060FB	3002 288800	SVETLANA MOROZOVA	{"email": "morozova-svetlana.1966@postgrespro.ru", "phone": "+70290497931"}
0005432003781	AFE311	1734 859554	SERGEY FILIPPOV	{"email": "filippovs.06041966@postgrespro.ru", "phone": "+70123461900"}
0005432003782	95CF7C	2683 525225	LYUBOV DANILOVA	{"phone": "+70226463575"}
0005432003783	95CF7C	3430 815878	IVAN SERGEEV	{"email": "sergeevi.08051969@postgrespro.ru", "phone": "+70316279857"}
0005432003784	3308B9	7438 881840	YANA DANILOVA	{"phone": "+70391110289"}
0005432003785	A5DC62	7091 962178	LARISA FEDOROVA	{"email": "fedorova-larisa.1961@postgrespro.ru", "phone": "+70045768419"}
0005432003786	76533A	1282 968975	OLGA KALININA	{"email": "kalinina_o_011977@postgrespro.ru", "phone": "+70753217157"}
0005432003787	2CF94D	8280 468376	OLEG MAKAROV	{"phone": "+70480427913"}
0005432003788	2CF94D	0537 376021	ILYA KOROLEV	{"phone": "+70222241949"}
0005432003789	59089E	1584 484477	ALLA ILINA	{"phone": "+70806879505"}
0005432003790	59089E	3414 079720	SERGEY MAKAROV	{"phone": "+70766705038"}
0005432003791	E869C6	6078 247219	ANDREY GRIGOREV	{"email": "grigorev_a-24101977@postgrespro.ru", "phone": "+70186389342"}
0005432003792	E869C6	5159 521459	LYUDMILA FILATOVA	{"phone": "+70795258018"}
0005432003793	D8F43D	3747 775547	VALENTINA KISELEVA	{"email": "kiseleva.valentina.071981@postgrespro.ru", "phone": "+70811539419"}
0005432003794	CC3AA1	4226 968733	ALBERT KOZLOV	{"email": "albert-kozlov041974@postgrespro.ru", "phone": "+70554311352"}
0005432003795	1708F5	3376 317680	ALEKSANDR FOMIN	{"email": "fomin.aleksandr_101971@postgrespro.ru", "phone": "+70947244152"}
0005432003796	9EF84C	0287 292518	ANNA SOKOLOVA	{"email": "sokolova-anna-10081974@postgrespro.ru", "phone": "+70860740498"}
0005432003797	F71607	9349 527296	LYUDMILA ALEKSEEVA	{"email": "alekseeva.l.041972@postgrespro.ru", "phone": "+70028797045"}
0005432005163	B531A2	1965 907208	TATYANA NESTEROVA	{"phone": "+70056803378"}
0005432005164	BF45E3	0872 976365	VALENTINA ZAKHAROVA	{"phone": "+70564054822"}
0005432005165	B1DA60	7792 729627	SERGEY BONDARENKO	{"email": "sergey_bondarenko04061972@postgrespro.ru", "phone": "+70471753663"}
0005432005166	6E8E95	3207 450077	ALLA LAZAREVA	{"phone": "+70006353349"}
0005432005167	6E8E95	0875 197017	DENIS IVANOV	{"email": "d-ivanov-18091972@postgrespro.ru", "phone": "+70256918492"}
0005432005168	69CBA0	5357 305697	VERONIKA RODIONOVA	{"phone": "+70889756533"}
0005432005169	5CFA29	7765 855758	DANIL SEMENOV	{"phone": "+70072145795"}
0005432005170	D669D8	9789 390128	OLGA MATVEEVA	{"email": "omatveeva-1968@postgrespro.ru", "phone": "+70680581863"}
0005432005171	D669D8	0227 573894	SERGEY MOROZOV	{"email": "s_morozov-26061975@postgrespro.ru", "phone": "+70865755955"}
0005432005172	D669D8	2407 910957	YURIY FOMIN	{"phone": "+70931496622"}
0005432005173	CE6149	2116 904434	LYUBOV SEMENOVA	{"email": "semenova-l_1971@postgrespro.ru", "phone": "+70106530464"}
0005432005174	77D011	6209 127371	EVGENIY MAKSIMOV	{"phone": "+70508486036"}
0005432005175	77D011	2581 286256	NAILYA IVANOVA	{"phone": "+70003268424"}
0005432005176	FC8D2B	0699 895569	TAMARA ORLOVA	{"email": "orlova.tamara.24071964@postgrespro.ru", "phone": "+70821987276"}
0005432005177	FC8D2B	1076 761092	VLADIMIR MOISEEV	{"email": "vladimir.moiseev_09031973@postgrespro.ru", "phone": "+70295894354"}
0005432005178	78FF32	8779 809267	TATYANA NIKITINA	{"email": "tatyana.nikitina_121965@postgrespro.ru", "phone": "+70737763215"}
0005432005179	C16D29	4531 067565	DMITRIY KUZMIN	{"phone": "+70437173802"}
0005432005180	F41110	6137 212542	ALEKSANDRA SERGEEVA	{"phone": "+70537072207"}
0005432005181	2268C8	0047 122097	SOFIYA POTAPOVA	{"email": "s-potapova1972@postgrespro.ru", "phone": "+70483300808"}
0005432005182	4421F0	4371 937540	TAMARA TIKHONOVA	{"email": "t_tikhonova041973@postgrespro.ru", "phone": "+70804906798"}
0005432005183	4421F0	4923 889844	ANTON KOROLEV	{"email": "antonkorolev_081976@postgrespro.ru", "phone": "+70886470145"}
0005432005184	431213	9446 048067	VALENTINA FILIPPOVA	{"phone": "+70615626510"}
0005432005185	431213	9547 428388	ANTON VASILEV	{"phone": "+70650733196"}
0005432005186	74FF98	1563 107593	DMITRIY GERASIMOV	{"phone": "+70658379972"}
0005432005187	58F8FF	8780 672992	SERGEY ZAKHAROV	{"email": "zakharov-s_081971@postgrespro.ru", "phone": "+70177740103"}
0005432005188	58F8FF	5580 243815	ALEKSANDR KUZNECOV	{"phone": "+70048361600"}
0005432005189	96B71C	6362 062371	ANDREY ANTONOV	{"phone": "+70459673861"}
0005432005190	E8A60B	5522 683529	OLEG POPOV	{"phone": "+70043666122"}
0005432005191	3347A4	1815 582083	MARIYA SAVELEVA	{"email": "saveleva_mariya_1977@postgrespro.ru", "phone": "+70026181882"}
0005432005192	3347A4	0211 905046	IGOR KOZLOV	{"email": "kozlov-i.021976@postgrespro.ru", "phone": "+70337818082"}
0005432005193	D90F72	4175 390217	VALERIY ZAKHAROV	{"email": "zakharov-v.081962@postgrespro.ru", "phone": "+70525559610"}
0005432005194	A1D2F2	7428 555303	FANIS VASILEV	{"phone": "+70420305995"}
0005432005195	12B9EA	5955 683706	MARINA KOZLOVA	{"phone": "+70773560143"}
0005432005196	8FE2C6	2545 014961	OLGA SOKOLOVA	{"phone": "+70512441812"}
0005432005197	1F43A4	2785 294170	VITALIY GAVRILOV	{"email": "v-gavrilov.1966@postgrespro.ru", "phone": "+70556632243"}
0005432005198	E08552	3491 687173	NIKOLAY VLASOV	{"phone": "+70400770234"}
0005432005199	E08552	0262 703619	YULIYA KOZLOVA	{"email": "y.kozlova28091978@postgrespro.ru", "phone": "+70450933157"}
0005432005200	9066ED	8709 491335	ARTEM AFANASEV	{"email": "aafanasev.29111970@postgrespro.ru", "phone": "+70359110196"}
0005432005201	E2A3CC	5163 816189	IVAN YAKOVLEV	{"email": "ivan-yakovlev071973@postgrespro.ru", "phone": "+70788739132"}
0005432005202	36299E	1775 683947	NIKOLAY ABRAMOV	{"email": "abramov_nikolay.091992@postgrespro.ru", "phone": "+70810350635"}
0005432005203	EFA649	9818 488066	PETR ZHUKOV	{"email": "zhukov_petr_1982@postgrespro.ru", "phone": "+70979463612"}
0005432005204	EFA649	6155 218947	VASILIY ROMANOV	{"email": "romanov.v061974@postgrespro.ru", "phone": "+70040827395"}
0005432005205	50C39B	7703 976111	MIKHAIL ZAKHAROV	{"email": "m_zakharov-071977@postgrespro.ru", "phone": "+70994246428"}
0005432005206	50C39B	8353 750104	DANILA NIKOLAEV	{"email": "nikolaev-danila-1960@postgrespro.ru", "phone": "+70131267514"}
0005432005207	357A9B	7823 662750	KRISTINA KOROLEVA	{"phone": "+70891315859"}
0005432005208	357A9B	4794 851739	DENIS IVANOV	{"email": "ivanov_denis.15051976@postgrespro.ru", "phone": "+70295674289"}
0005432005209	50B650	5750 097850	ROMAN SMIRNOV	{"email": "r_smirnov12071972@postgrespro.ru", "phone": "+70024302034"}
0005432005210	8FC7FE	2345 324800	MIKHAIL BORISOV	{"email": "borisov_m-051973@postgrespro.ru", "phone": "+70847476027"}
0005432005211	B47571	4017 539054	TATYANA IVANOVA	{"email": "ivanova-t_1971@postgrespro.ru", "phone": "+70969798357"}
0005432005212	9A2F6A	7397 271912	VASILIY ANTONOV	{"email": "v.antonov1966@postgrespro.ru", "phone": "+70674989304"}
0005432005213	9A2F6A	7179 187549	NATALYA NESTEROVA	{"phone": "+70102186513"}
0005432005214	D99543	5461 256161	VALERIY IVANOV	{"email": "valeriyivanov.1973@postgrespro.ru", "phone": "+70339740510"}
0005432005215	BAAB9B	8392 312401	ARTEM FEDOTOV	{"phone": "+70133677718"}
0005432005216	BAAB9B	5969 897237	ARTEM AFANASEV	{"phone": "+70921018588"}
0005432005217	6A1F5A	1055 818590	SERGEY OSIPOV	{"email": "sergey.osipov17101973@postgrespro.ru", "phone": "+70615467591"}
0005432005218	4103AD	4980 625111	SVETLANA DMITRIEVA	{"phone": "+70957666193"}
0005432005219	4103AD	6954 291085	LYUDMILA MAKAROVA	{"phone": "+70882364605"}
0005432005220	8EFEC9	5216 664290	ALEKSANDR SOROKIN	{"phone": "+70547599078"}
0005432005221	66950D	7316 117191	POLINA ZOTOVA	{"phone": "+70106427329"}
0005432005222	3E2010	0150 257525	ALEKSEY KOZLOV	{"email": "a.kozlov.101971@postgrespro.ru", "phone": "+70566069784"}
0005432005223	FAC68D	1376 009646	VLADIMIR IVANOV	{"email": "ivanov.vladimir_011967@postgrespro.ru", "phone": "+70901399666"}
0005432005224	983F5C	6369 244235	VALERIY DAVYDOV	{"email": "davydov-v24011969@postgrespro.ru", "phone": "+70343871235"}
0005432005225	FC59C5	6630 780229	NIKOLAY ZAYCEV	{"email": "zaycev_nikolay-1972@postgrespro.ru", "phone": "+70645510815"}
0005432005226	26EE4F	6224 535822	SEMEN GRIGOREV	{"email": "grigorev.s_1973@postgrespro.ru", "phone": "+70894060597"}
0005432005227	D2981D	7685 128989	VLADISLAV AFANASEV	{"phone": "+70468146934"}
0005432005228	0483B7	1699 376953	GALINA MATVEEVA	{"phone": "+70859519735"}
0005432005229	0483B7	4841 257440	EVA NIKOLAEVA	{"email": "enikolaeva-1976@postgrespro.ru", "phone": "+70069066726"}
0005432005230	A09840	2804 517423	KONSTANTIN VOROBEV	{"phone": "+70364696843"}
0005432005231	3615CB	0277 482719	VALENTINA SMIRNOVA	{"email": "valentinasmirnova_1969@postgrespro.ru", "phone": "+70061623215"}
0005432005232	99DED2	7925 307618	SERGEY SMIRNOV	{"email": "smirnov.sergey19021971@postgrespro.ru", "phone": "+70542076532"}
0005432005233	99DED2	8232 341586	ALEKSANDR BORISOV	{"phone": "+70310364351"}
0005432005234	0EC9C5	5337 466923	OLESYA TARASOVA	{"phone": "+70877913000"}
0005432005235	BDE23C	9847 000553	SHAVKAT KULIKOV	{"email": "skulikov1968@postgrespro.ru", "phone": "+70180404471"}
0005432005236	BDE23C	5698 516569	VLADIMIR TARASOV	{"email": "vladimirtarasov05081964@postgrespro.ru", "phone": "+70447583470"}
0005432005237	F98FDE	3047 221486	ROMAN KRASNOV	{"phone": "+70861695099"}
0005432005238	F98FDE	1494 510836	VALERIYA TIKHONOVA	{"phone": "+70120422153"}
0005432005239	2451BC	7630 262257	NATALYA TIMOFEEVA	{"phone": "+70404355042"}
0005432005240	D13BC9	4861 452430	ANATOLIY KULIKOV	{"email": "akulikov-01081971@postgrespro.ru", "phone": "+70142709860"}
0005432005241	768617	6152 327495	EVGENIY ALEKSEEV	{"email": "ealekseev-011967@postgrespro.ru", "phone": "+70324365619"}
0005432005242	768617	7936 924670	VIKTORIYA NAZAROVA	{"email": "nazarova_viktoriya-071977@postgrespro.ru", "phone": "+70433613578"}
0005432005243	71F5D0	6056 827434	RUSLAN ISAEV	{"email": "isaev.ruslan-061975@postgrespro.ru", "phone": "+70214373127"}
0005432005244	3F399B	4115 563544	MARIYA YUDINA	{"email": "mariyayudina1976@postgrespro.ru", "phone": "+70760430606"}
0005432005245	3C0270	0905 314273	ELENA ALEKSANDROVA	{"email": "e-aleksandrova_04081964@postgrespro.ru", "phone": "+70545258360"}
0005432005246	FAF5AA	3999 904861	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov.1966@postgrespro.ru", "phone": "+70931085187"}
0005432005247	DDE239	5575 402519	NATALIYA KALININA	{"phone": "+70317080446"}
0005432005248	4739E5	9499 164316	TATYANA KOMAROVA	{"email": "tatyana_komarova041969@postgrespro.ru", "phone": "+70058130752"}
0005432005249	4739E5	8381 460554	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev.101972@postgrespro.ru", "phone": "+70759663254"}
0005432005250	0CAC77	0313 393515	EKATERINA DANILOVA	{"phone": "+70445520754"}
0005432005251	C4981E	2048 355967	SVETLANA FROLOVA	{"phone": "+70765300755"}
0005432005252	C4981E	0519 380399	LYUDMILA CHERNOVA	{"phone": "+70958097784"}
0005432005253	CB31F4	5662 632471	NATALYA KOMAROVA	{"email": "natalya_komarova_19061977@postgrespro.ru", "phone": "+70602383501"}
0005432005254	CB31F4	7236 009599	NATALYA ALEKSEEVA	{"email": "alekseeva-natalya.22071967@postgrespro.ru", "phone": "+70575436281"}
0005432005255	49A899	7416 443149	MIKHAIL SOROKIN	{"email": "sorokin.mikhail.081981@postgrespro.ru", "phone": "+70870476869"}
0005432005256	7EEC81	2177 820928	DARYA NIKITINA	{"phone": "+70098333990"}
0005432005257	36572A	1667 015136	DENIS BELOV	{"email": "belov-denis-07061979@postgrespro.ru", "phone": "+70153167779"}
0005432005258	36572A	9003 766031	ALFIYA NIKIFOROVA	{"email": "a_nikiforova.1961@postgrespro.ru", "phone": "+70281890629"}
0005432005259	BD2808	6925 422744	ALEKSANDR DAVYDOV	{"phone": "+70250801130"}
0005432005260	BD2808	2896 383485	VASILIY SOROKIN	{"email": "sorokin-vasiliy-12091978@postgrespro.ru", "phone": "+70327581033"}
0005432005261	BAE4F1	7183 778839	SVETLANA SOROKINA	{"phone": "+70988367383"}
0005432005262	BAE4F1	5503 927145	VLADIMIR BELOV	{"phone": "+70932424426"}
0005432005263	AF32F5	3005 069122	LYUBOV FEDOROVA	{"email": "lyubov.fedorova-17111974@postgrespro.ru", "phone": "+70076730905"}
0005432005264	F43B38	8253 670642	DANIYA KOZLOVA	{"email": "kozlova_d_1975@postgrespro.ru", "phone": "+70821135566"}
0005432005265	6B5E60	9058 720955	ALEKSANDR GRIGOREV	{"phone": "+70429931295"}
0005432005266	CF58F6	8339 287821	NATALYA NIKOLAEVA	{"phone": "+70498570052"}
0005432005267	BA9363	2295 501809	OLGA GUSEVA	{"phone": "+70969902263"}
0005432005268	BA9363	4304 616911	MAKSIM MOROZOV	{"phone": "+70552563636"}
0005432005269	BA9363	1561 523007	ANATOLIY MAKAROV	{"email": "makarova.1966@postgrespro.ru", "phone": "+70832259934"}
0005432005270	4B7B0D	3634 341307	IRINA KOMAROVA	{"email": "i_komarova_081980@postgrespro.ru", "phone": "+70632150511"}
0005432005271	4B7B0D	8796 052535	LYUDMILA SERGEEVA	{"phone": "+70893970334"}
0005432005272	119C53	7391 895388	DMITRIY BARANOV	{"phone": "+70889803274"}
0005432005273	357950	5626 382366	ALEKSEY PETROV	{"phone": "+70721105719"}
0005432005274	5DE9F1	3594 558861	EKATERINA MATVEEVA	{"phone": "+70633576430"}
0005432005275	C31F0C	9735 309958	IRINA IVANOVA	{"phone": "+70575511831"}
0005432005276	9CE7C2	0987 146760	EVGENIY IVANOV	{"email": "ivanov-evgeniy-1975@postgrespro.ru", "phone": "+70582643116"}
0005432005277	CFFF11	5785 702605	ALEKSEY AFANASEV	{"phone": "+70214049619"}
0005432005278	12728D	8475 776833	EVGENIY ROMANOV	{"phone": "+70071309935"}
0005432005279	28F5D0	4787 638284	ALEKSANDR SOROKIN	{"phone": "+70587178358"}
0005432005280	1856F3	1310 208486	VALENTINA FROLOVA	{"email": "frolova-v_20091975@postgrespro.ru", "phone": "+70629520063"}
0005432005281	166F96	0386 061047	LYUBOV NIKITINA	{"email": "nikitina-lyubov_27081964@postgrespro.ru", "phone": "+70121945347"}
0005432005282	B0F767	6393 139922	TATYANA ROMANOVA	{"phone": "+70006268975"}
0005432005283	BE6989	0751 397686	GENNADIY MATVEEV	{"email": "g_matveev-1969@postgrespro.ru", "phone": "+70947332985"}
0005432005284	BE6989	3158 790778	ALEKSANDRA KOROLEVA	{"email": "korolevaaleksandra-03041981@postgrespro.ru", "phone": "+70508522321"}
0005432005285	36266C	2658 984061	NINA VASILEVA	{"phone": "+70895334595"}
0005432005286	36266C	9487 778862	YULIYA ROMANOVA	{"phone": "+70416030763"}
0005432005287	FA28F7	7406 641073	NIKOLAY ORLOV	{"email": "orlov-n.051967@postgrespro.ru", "phone": "+70701261985"}
0005432005288	278654	9825 281391	VIKTOR VOLKOV	{"email": "v-volkov-1979@postgrespro.ru", "phone": "+70202889500"}
0005432005289	38407C	1951 409485	PAVEL KARPOV	{"phone": "+70669818509"}
0005432005290	B4988C	6504 848964	ALEKSANDR KUZNECOV	{"phone": "+70932302659"}
0005432005291	B4988C	0310 950081	LYUBOV ABRAMOVA	{"email": "abramova_lyubov.1987@postgrespro.ru", "phone": "+70680138489"}
0005432005292	E40AC7	2431 762055	IGOR KOROLEV	{"email": "korolev.i_051975@postgrespro.ru", "phone": "+70219470863"}
0005432005293	E40AC7	5542 168780	ALEKSANDR NIKITIN	{"phone": "+70539601803"}
0005432006708	31F638	9994 445534	NADEZHDA KOLESNIKOVA	{"phone": "+70166709746"}
0005432006709	31F638	7487 578814	ELENA KISELEVA	{"email": "elena-kiseleva_091962@postgrespro.ru", "phone": "+70691325836"}
0005432006710	67219B	2828 136076	TATYANA GRISHINA	{"phone": "+70105850649"}
0005432006711	EB6D18	0406 758772	MIKHAIL NIKOLAEV	{"phone": "+70562351386"}
0005432006712	EB6D18	9664 022625	NATALIYA ERMAKOVA	{"email": "ermakova-nataliya111977@postgrespro.ru", "phone": "+70505527758"}
0005432006713	F648E2	9943 787981	YANA ROMANOVA	{"email": "romanova.yana_1967@postgrespro.ru", "phone": "+70095472218"}
0005432006714	9459F5	1772 529870	MARIYA TIMOFEEVA	{"phone": "+70915524710"}
0005432006715	B0EB2F	1004 548882	RAISA TROFIMOVA	{"phone": "+70862697528"}
0005432006716	868C0C	0749 609175	GALINA VLASOVA	{"phone": "+70508721353"}
0005432006717	868C0C	3054 227067	DMITRIY NIKOLAEV	{"phone": "+70045475639"}
0005432006718	868C0C	0115 423741	ANASTASIYA KOROLEVA	{"email": "korolevaa.091975@postgrespro.ru", "phone": "+70887751547"}
0005432006719	E48FA1	7166 243310	RAISA STEPANOVA	{"email": "r.stepanova101959@postgrespro.ru", "phone": "+70699561372"}
0005432006720	776703	5327 141665	VIKTORIYA ZOTOVA	{"email": "viktoriya_zotova.031975@postgrespro.ru", "phone": "+70212217199"}
0005432006721	91E333	0331 025844	SERGEY EGOROV	{"phone": "+70765564767"}
0005432006722	7982E0	5766 854570	TATYANA SAVELEVA	{"phone": "+70417832526"}
0005432006723	7982E0	6653 590571	NATALYA MIRONOVA	{"phone": "+70493852981"}
0005432006724	7982E0	7675 434874	MATVEY ANTONOV	{"email": "matvey-antonov.041973@postgrespro.ru", "phone": "+70985618632"}
0005432006725	10A98E	7870 727602	TAMARA ROMANOVA	{"phone": "+70264984724"}
0005432006726	7189A1	1950 815317	ALEKSANDR PAVLOV	{"email": "aleksandr.pavlov.1973@postgrespro.ru", "phone": "+70854499272"}
0005432006727	FD38D2	0493 421928	YULIYA CHERNOVA	{"email": "chernova-y_011975@postgrespro.ru", "phone": "+70376007509"}
0005432006728	FD38D2	2067 647159	OLEG NIKOLAEV	{"email": "olegnikolaev_071967@postgrespro.ru", "phone": "+70451865648"}
0005432006729	0BE40A	8498 685539	TAMARA GORBUNOVA	{"phone": "+70793303105"}
0005432006730	EA8EE0	0655 177677	ALEKSANDR ANDREEV	{"phone": "+70425865308"}
0005432006731	24D29A	0893 707949	TATYANA RYABOVA	{"email": "t_ryabova111968@postgrespro.ru", "phone": "+70895736477"}
0005432006732	786D90	9032 196736	TATYANA KUZNECOVA	{"phone": "+70465823126"}
0005432006733	C24387	7683 668029	ANNA YAKOVLEVA	{"email": "a-yakovleva.14061969@postgrespro.ru", "phone": "+70562142278"}
0005432006734	20D722	0404 267361	MARIYA NOVIKOVA	{"email": "mnovikova.1971@postgrespro.ru", "phone": "+70874804858"}
0005432006735	20D722	1304 469220	ANTONINA POPOVA	{"phone": "+70707856655"}
0005432006736	20D722	2578 462635	GULFIYA MOISEEVA	{"phone": "+70280315335"}
0005432006737	E98D1F	3363 585338	ELENA ALEKSEEVA	{"email": "elenaalekseeva.1976@postgrespro.ru", "phone": "+70549148178"}
0005432006738	E98D1F	9096 100946	ARTEM FEDOROV	{"phone": "+70085333523"}
0005432006739	C68CBD	1919 290147	VALERIY VASILEV	{"email": "valeriy-vasilev1968@postgrespro.ru", "phone": "+70192520096"}
0005432006740	9858B1	9930 525529	YANA ZAKHAROVA	{"email": "zakharova_y_17101966@postgrespro.ru", "phone": "+70892169164"}
0005432006741	09F63E	2587 141367	KLAVDIYA EFREMOVA	{"email": "k.efremova111984@postgrespro.ru", "phone": "+70943222568"}
0005432006742	09F63E	7348 314717	ELENA YAKOVLEVA	{"email": "yakovleva-elena_26121967@postgrespro.ru", "phone": "+70328200300"}
0005432006743	534BB3	1920 345170	VALENTINA VASILEVA	{"email": "valentina-vasileva09051974@postgrespro.ru", "phone": "+70087152088"}
0005432006744	C4738C	8775 964419	MAKSIM SCHERBAKOV	{"phone": "+70226760621"}
0005432006745	C4738C	5273 326514	DANIIL DENISOV	{"email": "daniildenisov1978@postgrespro.ru", "phone": "+70619718831"}
0005432006746	D87A79	6931 371006	SERGEY SIDOROV	{"phone": "+70017965636"}
0005432006747	DFC691	6089 998491	PETR NAZAROV	{"email": "p_nazarov_121983@postgrespro.ru", "phone": "+70124765734"}
0005432006748	DFC691	8632 976162	SVETLANA CHERNOVA	{"email": "chernova-svetlana-1969@postgrespro.ru", "phone": "+70126043863"}
0005432006749	189430	2362 885759	NAIL SEMENOV	{"email": "semenov.nail-1970@postgrespro.ru", "phone": "+70271639561"}
0005432006750	88F1F7	7472 841938	ALEKSANDR SEMENOV	{"phone": "+70358576089"}
0005432006751	36E324	6008 675303	ALLA MELNIKOVA	{"email": "melnikovaa_1967@postgrespro.ru", "phone": "+70919255183"}
0005432006752	BF5981	7791 135189	NATALYA KUDRYASHOVA	{"phone": "+70382383025"}
0005432006753	F1C1B3	4575 631635	VERA ABRAMOVA	{"email": "vera-abramova.1972@postgrespro.ru", "phone": "+70320324509"}
0005432006754	2458C1	7090 185970	TATYANA MAKAROVA	{"email": "tatyana_makarova-11101972@postgrespro.ru", "phone": "+70042861772"}
0005432006755	C53CEB	2275 971506	DMITRIY MIKHAYLOV	{"phone": "+70840877540"}
0005432006756	037F6A	6192 428642	ALEKSANDR GUSEV	{"phone": "+70111315410"}
0005432006757	AEED84	6297 832093	ANTONINA STEPANOVA	{"phone": "+70021688773"}
0005432006758	AEED84	8461 442645	ALEKSANDR SEMENOV	{"email": "semenovaleksandr-1967@postgrespro.ru", "phone": "+70218035065"}
0005432006759	502DA3	4287 371021	ANASTASIYA MOISEEVA	{"phone": "+70707787351"}
0005432006760	502DA3	1041 525540	ALEKSANDR SHEVCHENKO	{"phone": "+70765657498"}
0005432006761	FE7180	0097 655868	SVETLANA AFANASEVA	{"phone": "+70444807907"}
0005432006762	FE7180	2005 886674	ALSU GORBUNOVA	{"email": "alsu-gorbunova071971@postgrespro.ru", "phone": "+70457431455"}
0005432006763	FE7180	9552 636655	VLADIMIR ABRAMOV	{"email": "v-abramov.1959@postgrespro.ru", "phone": "+70310009612"}
0005432006764	B3FE1D	5875 349402	ANNA BORISOVA	{"email": "a_borisova111972@postgrespro.ru", "phone": "+70237224278"}
0005432006765	811B51	2776 318271	VALENTINA ISAEVA	{"email": "isaeva_v1978@postgrespro.ru", "phone": "+70360388868"}
0005432006766	811B51	1618 277808	VASILIY DENISOV	{"phone": "+70695046676"}
0005432006767	1568D5	7852 628202	GLEB SCHERBAKOV	{"email": "scherbakov_gleb_14091971@postgrespro.ru", "phone": "+70351340517"}
0005432006768	1568D5	8684 799740	LIDIYA SOKOLOVA	{"email": "lidiya-sokolova_011969@postgrespro.ru", "phone": "+70363056440"}
0005432006769	BEAA3D	7870 361228	ALEKSEY IVANOV	{"phone": "+70452203922"}
0005432006770	246445	5757 589570	ELENA BORISOVA	{"phone": "+70782271963"}
0005432006771	25F2CE	3109 702801	LILIYA FROLOVA	{"email": "liliya-frolova.06041971@postgrespro.ru", "phone": "+70525959173"}
0005432006772	79F44E	8172 555365	VITALIY PETROV	{"phone": "+70846558620"}
0005432006773	9BF058	2560 990715	ALEKSANDRA EFIMOVA	{"phone": "+70587644890"}
0005432006774	9BF058	5775 337205	ELENA AFANASEVA	{"email": "e_afanaseva-13051970@postgrespro.ru", "phone": "+70887822345"}
0005432006775	D7B0A9	9715 657448	DMITRIY TARASOV	{"email": "tarasov_dmitriy1972@postgrespro.ru", "phone": "+70896913536"}
0005432006776	D7B0A9	9819 994993	ALEKSEY ZHUKOV	{"phone": "+70917307918"}
0005432006777	D7B0A9	5897 502196	RUSTEM FEDOROV	{"phone": "+70847026181"}
0005432006778	D7B0A9	9938 325404	YAKOV KARPOV	{"phone": "+70787266758"}
0005432006779	C6606D	1669 140627	NADEZHDA GORBUNOVA	{"phone": "+70224126137"}
0005432006780	052C83	2544 737025	MIKHAIL NOVIKOV	{"phone": "+70142899670"}
0005432006781	00BBF4	0457 897678	YURIY KULIKOV	{"email": "kulikov.y-1979@postgrespro.ru", "phone": "+70902684864"}
0005432006782	00BBF4	4813 271415	GALINA KUZNECOVA	{"phone": "+70741152329"}
0005432006783	79FB19	4447 479138	PAVEL KOROLEV	{"phone": "+70641921085"}
0005432006784	C29EA5	8810 567499	SERGEY GUSEV	{"phone": "+70531630202"}
0005432006785	C29EA5	7593 964464	MAKSIM STEPANOV	{"email": "stepanov-maksim23111964@postgrespro.ru", "phone": "+70481038880"}
0005432006786	256ABE	6748 089325	YULIYA ORLOVA	{"email": "yorlova.1973@postgrespro.ru", "phone": "+70141582228"}
0005432006787	074AF6	8631 592144	OLGA PETROVA	{"phone": "+70216167167"}
0005432006788	074AF6	7724 888397	ELENA NOVIKOVA	{"email": "e_novikova11111972@postgrespro.ru", "phone": "+70732114616"}
0005432006789	4681C8	7596 363513	VASILIY ALEKSEEV	{"phone": "+70741744069"}
0005432006790	4681C8	3262 667669	VLADIMIR OSIPOV	{"email": "vladimir-osipov_15011981@postgrespro.ru", "phone": "+70040736881"}
0005432006791	3F6C58	3741 352646	EVGENIY KUZNECOV	{"phone": "+70463957050"}
0005432006792	816A8C	7629 781719	NIKOLAY BELOV	{"email": "nikolay-belov_04031975@postgrespro.ru", "phone": "+70880284283"}
0005432006793	4E285F	7237 022733	OLEG BELOV	{"phone": "+70238846219"}
0005432006794	7BDDD0	9380 333107	DAMIR VASILEV	{"phone": "+70489592380"}
0005432006795	9D80F4	8242 270665	ANTON IVANOV	{"email": "anton-ivanov-28121977@postgrespro.ru", "phone": "+70433337168"}
0005432006796	9D80F4	9961 371321	NAILYA TARASOVA	{"email": "n.tarasova-18021975@postgrespro.ru", "phone": "+70557131818"}
0005432006797	9D80F4	6715 230686	MADINA FOMINA	{"email": "fominamadina121983@postgrespro.ru", "phone": "+70404454842"}
0005432006798	62C74A	4443 794340	KLARA FROLOVA	{"email": "k-frolova_031975@postgrespro.ru", "phone": "+70795722044"}
0005432006799	2C1250	0391 441473	ELENA SEMENOVA	{"phone": "+70725850468"}
0005432006800	5A8BAE	9703 868222	YULIYA KUZNECOVA	{"phone": "+70136762525"}
0005432006801	2191C6	4267 299799	EKATERINA TARASOVA	{"email": "tarasovae-28051964@postgrespro.ru", "phone": "+70892881730"}
0005432006802	2191C6	2105 911428	ANNA KUDRYASHOVA	{"phone": "+70461194217"}
0005432006803	2191C6	2292 927157	ALINA POPOVA	{"email": "popova.alina_021967@postgrespro.ru", "phone": "+70656770097"}
0005432006804	AF7F4D	5286 163559	ANASTASIYA EGOROVA	{"email": "a_egorova.041967@postgrespro.ru", "phone": "+70789097394"}
0005432006805	AF7F4D	8533 729904	DENIS MATVEEV	{"phone": "+70509108437"}
0005432006806	053319	6181 331768	VLADIMIR GERASIMOV	{"email": "gerasimov_v-13081988@postgrespro.ru", "phone": "+70507882359"}
0005432006807	053319	8509 623315	ELENA SOKOLOVA	{"email": "sokolova-elena061970@postgrespro.ru", "phone": "+70444845027"}
0005432006808	9F5755	6582 416569	NATALIYA AFANASEVA	{"phone": "+70837795865"}
0005432006809	7B3631	4236 405066	PELAGEYA NAZAROVA	{"email": "p_nazarova_1960@postgrespro.ru", "phone": "+70804513558"}
0005432006810	2EA5C0	6134 947692	SERGEY NAZAROV	{"email": "nazarov.s-1980@postgrespro.ru", "phone": "+70629309383"}
0005432006811	4E70B9	1887 520460	OLGA KOZLOVA	{"phone": "+70622908333"}
0005432006812	4E70B9	5317 495293	NINA LOGINOVA	{"email": "loginovan_04101972@postgrespro.ru", "phone": "+70700799738"}
0005432006813	60D168	5875 349683	IRINA IVANOVA	{"email": "irina_ivanova_1973@postgrespro.ru", "phone": "+70054514544"}
0005432006814	60D168	7061 953135	GALINA FROLOVA	{"phone": "+70835876826"}
0005432006815	60D168	4822 178958	VERA ROMANOVA	{"phone": "+70989841360"}
0005432006816	0625F3	1361 828537	FAINA SOROKINA	{"phone": "+70741432203"}
0005432006817	88D454	5910 912429	VALERIYA TROFIMOVA	{"email": "valeriya.trofimova-1961@postgrespro.ru", "phone": "+70209548608"}
0005432006818	495D86	9921 721161	DMITRIY GAVRILOV	{"phone": "+70572014663"}
0005432006819	7A442E	7048 187676	RAISA ANTONOVA	{"phone": "+70232000642"}
0005432006820	7A442E	6338 268223	SERGEY MARTYNOV	{"email": "martynov-sergey.19101976@postgrespro.ru", "phone": "+70073421340"}
0005432006821	017F60	5853 911973	ANTONINA CHERNOVA	{"phone": "+70790419957"}
0005432006822	017F60	4281 091011	NATALYA ABRAMOVA	{"phone": "+70224058694"}
0005432006823	F27224	0746 397072	GRIGORIY YAKOVLEV	{"email": "yakovlevg_15091967@postgrespro.ru", "phone": "+70418120399"}
0005432006824	F27224	6470 566976	LEONID SOROKIN	{"email": "lsorokin.10101979@postgrespro.ru", "phone": "+70121733355"}
0005432006825	23D344	0010 835638	YURIY NIKITIN	{"email": "yuriy-nikitin-26061977@postgrespro.ru", "phone": "+70755547836"}
0005432006826	606B98	0598 498028	NATALYA MIRONOVA	{"email": "mironova-n_21101969@postgrespro.ru", "phone": "+70534200964"}
0005432006827	4ED7A7	8294 265214	DMITRIY GUSEV	{"email": "gusev-dmitriy.01011966@postgrespro.ru", "phone": "+70263557298"}
0005432006828	4ED7A7	8618 285013	ANDREY DENISOV	{"phone": "+70221323956"}
0005432006829	45A0A2	6807 628917	ALEVTINA MAKAROVA	{"email": "makarova.a20121970@postgrespro.ru", "phone": "+70967325816"}
0005432006830	5AA085	5684 150685	OLGA PETROVA	{"email": "petrova.olga071968@postgrespro.ru", "phone": "+70410775048"}
0005432006831	1A7334	5306 271068	SVETLANA PETROVA	{"email": "petrovas_1959@postgrespro.ru", "phone": "+70933696966"}
0005432006832	1A7334	2019 441970	VIKTOR MOISEEV	{"phone": "+70760801971"}
0005432006833	734731	6177 297995	ARTEM KUZMIN	{"phone": "+70090411894"}
0005432006834	063600	4669 534826	ALISA ANTONOVA	{"phone": "+70424739099"}
0005432006835	063600	7386 941949	SHAVKAT BORISOV	{"email": "borisovs.071968@postgrespro.ru", "phone": "+70737724220"}
0005432006836	B2A7A5	4181 629409	VLADIMIR FOMIN	{"phone": "+70522847919"}
0005432006837	7291B5	7358 553490	ANATOLIY MIKHAYLOV	{"phone": "+70867024295"}
0005432006838	07EFF1	7551 156125	ALINA ZHURAVLEVA	{"phone": "+70699621712"}
0005432006839	FADF9C	3536 244794	IGOR KARPOV	{"phone": "+70828426723"}
0005432006840	E3DCF7	2578 851410	VIKTOR NOVIKOV	{"phone": "+70113623009"}
0005432006841	6763C5	2933 094764	NADEZHDA KUDRYASHOVA	{"email": "n_kudryashova1982@postgrespro.ru", "phone": "+70341998507"}
0005432006842	6763C5	2055 529475	OLEG MOROZOV	{"email": "morozovoleg.09111973@postgrespro.ru", "phone": "+70978675459"}
0005432006843	05FB63	3374 626132	NINA KUDRYASHOVA	{"phone": "+70338001798"}
0005432006844	05FB63	2874 616166	ILYA KUZNECOV	{"phone": "+70900009818"}
0005432006845	8A7B69	0527 565921	VERA IVANOVA	{"email": "vera.ivanova.011961@postgrespro.ru", "phone": "+70870437042"}
0005432006846	9EA7DD	0314 115054	ANASTASIYA ZAKHAROVA	{"phone": "+70163100481"}
0005432006847	7148D6	8038 667911	NIKOLAY SIDOROV	{"phone": "+70690455301"}
0005432006848	7148D6	8570 751669	EVGENIYA SERGEEVA	{"email": "sergeeva_e_071965@postgrespro.ru", "phone": "+70542288655"}
0005432006849	719579	2970 173101	ERIK STEPANOV	{"email": "stepanoverik_27061963@postgrespro.ru", "phone": "+70665642366"}
0005432006850	B6E1F1	1625 427369	SERGEY KUZNECOV	{"email": "kuznecov-s-30121962@postgrespro.ru", "phone": "+70574254553"}
0005432019779	C61348	2548 049524	TATYANA KOZLOVA	{"phone": "+70928292903"}
0005432019780	C61348	1067 402780	MARGARITA BOGDANOVA	{"email": "bogdanovamargarita1970@postgrespro.ru", "phone": "+70775489206"}
0005432019781	6BF8A7	4814 810320	ALEKSANDR KUZNECOV	{"email": "kuznecova_1966@postgrespro.ru", "phone": "+70702048347"}
0005432019782	19EC55	2393 392295	ALINA ROMANOVA	{"email": "romanovaa.1964@postgrespro.ru", "phone": "+70289075420"}
0005432019783	F87AC6	8247 014793	VLADIMIR FEDOROV	{"email": "fedorov.v.11061978@postgrespro.ru", "phone": "+70534678168"}
0005432019784	547AA8	3154 932591	MARIYA NIKIFOROVA	{"email": "nikiforova.mariya.021976@postgrespro.ru", "phone": "+70011692691"}
0005432019785	8C1C59	0117 118606	ZOYA IVANOVA	{"email": "ivanova_z_051968@postgrespro.ru", "phone": "+70073887084"}
0005432019786	0B05D2	6930 698813	RAILYA NAZAROVA	{"phone": "+70380163032"}
0005432019787	74C6C2	1547 863184	ILYA DENISOV	{"email": "denisov.ilya15071969@postgrespro.ru", "phone": "+70802857510"}
0005432019788	C747E5	6387 832099	ANDREY MOROZOV	{"phone": "+70482514866"}
0005432019789	9DB4C6	1017 786062	OLGA POPOVA	{"email": "popova-o-25041984@postgrespro.ru", "phone": "+70224980105"}
0005432019790	9DB4C6	9835 317519	POLINA EFREMOVA	{"email": "polina_efremova.07031979@postgrespro.ru", "phone": "+70451251374"}
0005432019791	9DB4C6	8461 865950	YURIY TIKHONOV	{"phone": "+70766963532"}
0005432019792	D5D36E	9424 914821	ANNA AKIMOVA	{"email": "akimova_a-24121968@postgrespro.ru", "phone": "+70528928697"}
0005432019793	D5D36E	4911 794403	EGOR MARTYNOV	{"email": "martynov.e.101975@postgrespro.ru", "phone": "+70449732381"}
0005432019794	5F6FA7	1767 638408	DANIIL KONOVALOV	{"email": "konovalov_daniil_28011972@postgrespro.ru", "phone": "+70590491297"}
0005432019795	A6CC83	8168 984685	EKATERINA ZAKHAROVA	{"phone": "+70499532177"}
0005432019796	0F9D3E	5823 275469	NATALIYA ZAKHAROVA	{"email": "zakharova_nataliya-1968@postgrespro.ru", "phone": "+70571659879"}
0005432019797	C49879	5183 460820	DARYA SEMENOVA	{"email": "semenovadarya.1962@postgrespro.ru", "phone": "+70988027204"}
0005432019798	D5E612	0567 535647	ANASTASIYA MAKAROVA	{"phone": "+70959692059"}
0005432019799	D5E612	9673 945662	IRINA KULIKOVA	{"email": "kulikova-irina-1966@postgrespro.ru", "phone": "+70629707777"}
0005432019800	2F462D	5574 393806	MARIYA EGOROVA	{"phone": "+70286060475"}
0005432019801	86E411	2626 336747	VIKTOR PETROV	{"email": "vpetrov_071970@postgrespro.ru", "phone": "+70218344555"}
0005432019802	18A5B9	3256 573186	ALEKSEY SMIRNOV	{"email": "a.smirnov.1974@postgrespro.ru", "phone": "+70220320377"}
0005432019803	28C3C5	4953 742051	GENNADIY BORISOV	{"phone": "+70474311181"}
0005432019804	28C3C5	8136 112634	IRINA POTAPOVA	{"email": "potapova_irina.1974@postgrespro.ru", "phone": "+70434872315"}
0005432019805	9B571D	1576 112718	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova_1966@postgrespro.ru", "phone": "+70459920936"}
0005432019806	A76E06	2249 954454	IRINA MOROZOVA	{"phone": "+70140882719"}
0005432019807	A76E06	7732 925350	LARISA KONOVALOVA	{"email": "larisa-konovalova.031964@postgrespro.ru", "phone": "+70985235867"}
0005432019808	8092CE	0820 407177	VALENTINA PAVLOVA	{"phone": "+70458134014"}
0005432019809	8092CE	4069 386182	ELENA FEDOROVA	{"phone": "+70464046849"}
0005432019810	9C8172	1691 449761	ANASTASIYA LUKYANOVA	{"email": "anastasiya.lukyanova-041974@postgrespro.ru", "phone": "+70168594667"}
0005432019811	9C8172	5072 309573	YURIY GAVRILOV	{"email": "y_gavrilov_1981@postgrespro.ru", "phone": "+70821353416"}
0005432019812	AF04AD	8837 917590	NATALYA KRASNOVA	{"email": "n.krasnova_091963@postgrespro.ru", "phone": "+70989357118"}
0005432019813	60951F	6198 672862	SERGEY KRASNOV	{"phone": "+70653558988"}
0005432019814	BB950B	1647 893770	LYUDMILA MAKAROVA	{"email": "lyudmilamakarova.30121975@postgrespro.ru", "phone": "+70761726261"}
0005432019815	0CB6B1	4692 931997	NINA IVANOVA	{"phone": "+70410660378"}
0005432019816	0CB6B1	3366 250504	NATALYA KOZLOVA	{"email": "natalya.kozlova-111989@postgrespro.ru", "phone": "+70358119861"}
0005432019817	FFBAB2	8912 612349	ALENA GORBUNOVA	{"phone": "+70625243923"}
0005432019818	FFBAB2	3870 322782	ALEKSANDR MOISEEV	{"email": "moiseevaleksandr.17091969@postgrespro.ru", "phone": "+70077219842"}
0005432019819	12A214	9820 485512	TAMARA BELYAEVA	{"email": "belyaeva-t.031972@postgrespro.ru", "phone": "+70877988939"}
0005432019820	48795B	5859 126336	VLADIMIR MAKAROV	{"email": "vladimirmakarov.13051981@postgrespro.ru", "phone": "+70738465243"}
0005432019821	48795B	0477 833849	SERGEY ZHUKOV	{"phone": "+70265829678"}
0005432019822	3B6707	6903 862483	NATALYA KUZNECOVA	{"phone": "+70016770893"}
0005432019823	3B6707	5985 576578	OLGA KUZNECOVA	{"email": "kuznecova-olga-121960@postgrespro.ru", "phone": "+70802067909"}
0005432019824	C86204	6505 484373	ANNA VOROBEVA	{"phone": "+70243842613"}
0005432019825	8A262D	3946 285134	PAVEL MIRONOV	{"phone": "+70131085341"}
0005432019826	363574	2893 766043	ELENA STEPANOVA	{"phone": "+70394389722"}
0005432019827	39052C	1527 320499	OLGA ANDREEVA	{"email": "olga.andreeva-1976@postgrespro.ru", "phone": "+70660654274"}
0005432019828	FB52CF	7336 424995	NATALYA MIKHAYLOVA	{"email": "n_mikhaylova.021967@postgrespro.ru", "phone": "+70271413068"}
0005432019829	66BC1A	3386 752845	VIKTOR GUSEV	{"phone": "+70601908283"}
0005432019830	78D839	6897 969937	TATYANA AFANASEVA	{"phone": "+70643515646"}
0005432019831	78D839	4874 886671	ALBINA STEPANOVA	{"email": "a_stepanova041965@postgrespro.ru", "phone": "+70374671502"}
0005432019832	738CA7	0425 690666	LYUBOV ANISIMOVA	{"phone": "+70367826121"}
0005432019833	3D9629	7880 305562	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina.1966@postgrespro.ru", "phone": "+70648536906"}
0005432019834	3D9629	1040 542971	SERGEY PETROV	{"phone": "+70287254444"}
0005432019835	A4EB97	3275 051706	ALEKSANDR KUZMIN	{"phone": "+70196945232"}
0005432019836	76184F	6344 157785	IVAN DMITRIEV	{"phone": "+70142946091"}
0005432019837	F7B98F	3584 802224	DARYA TIMOFEEVA	{"phone": "+70893220953"}
0005432019838	F7B98F	0705 481348	DARYA KONOVALOVA	{"phone": "+70154518271"}
0005432019839	F86D18	8350 811311	PAVEL ALEKSEEV	{"phone": "+70174368608"}
0005432019840	214415	9028 149896	DENIS ROMANOV	{"email": "romanov_d-1980@postgrespro.ru", "phone": "+70791548101"}
0005432019841	A64EB8	6464 838902	TATYANA KOROLEVA	{"email": "koroleva-tatyana061977@postgrespro.ru", "phone": "+70297511220"}
0005432019842	FE03BC	6385 019285	TATYANA SIDOROVA	{"phone": "+70269497989"}
0005432019843	FE03BC	4647 195826	ELENA ANTONOVA	{"email": "antonovaelena1968@postgrespro.ru", "phone": "+70840741039"}
0005432019844	FE03BC	6092 033020	YURIY KUZNECOV	{"phone": "+70923027192"}
0005432019845	04AAB1	3446 588744	NATALYA MATVEEVA	{"phone": "+70559915111"}
0005432019846	04AAB1	6659 392707	OLEG ZAYCEV	{"email": "ozaycev.04031957@postgrespro.ru", "phone": "+70465396875"}
0005432019847	CC4EA3	0839 557900	YURIY GUSEV	{"email": "gusev_y-13061970@postgrespro.ru", "phone": "+70247333579"}
0005432019848	B6C937	7806 237982	ELENA SOLOVEVA	{"email": "elena-soloveva_27111975@postgrespro.ru", "phone": "+70573939678"}
0005432019849	B6C937	5096 770201	IRINA VOLKOVA	{"email": "volkovai.051970@postgrespro.ru", "phone": "+70688990606"}
0005432019850	F7E82E	2901 737209	PETR PETROV	{"phone": "+70957255856"}
0005432019851	F7E82E	6129 905555	ANTONINA ANISIMOVA	{"email": "antonina_anisimova.24071981@postgrespro.ru", "phone": "+70131145482"}
0005432019852	D5FE56	2298 963304	EVGENIYA KUZNECOVA	{"email": "kuznecovaevgeniya_081976@postgrespro.ru", "phone": "+70229136442"}
0005432019853	74D7F2	0582 988045	VALERIYA KUZNECOVA	{"phone": "+70372551693"}
0005432019854	4A2D06	5127 735577	ANDREY MELNIKOV	{"email": "melnikova_24071981@postgrespro.ru", "phone": "+70465953465"}
0005432019855	65971A	8837 048114	NIKITA KOROLEV	{"email": "nikita_korolev091968@postgrespro.ru", "phone": "+70778728341"}
0005432019856	E12694	5221 455028	TAMARA KOZLOVA	{"phone": "+70677883807"}
0005432019857	D335CA	9284 067873	IVAN VOLKOV	{"email": "ivolkov-1976@postgrespro.ru", "phone": "+70912400382"}
0005432019858	E747DE	9282 769202	VLADIMIR KONOVALOV	{"phone": "+70985574014"}
0005432019859	E747DE	8456 212092	EVGENIY KUZNECOV	{"email": "kuznecove-081976@postgrespro.ru", "phone": "+70972616572"}
0005432019860	6647AA	3653 605886	EKATERINA VOROBEVA	{"email": "ekaterina.vorobeva_1974@postgrespro.ru", "phone": "+70047460086"}
0005432019861	6647AA	8370 661212	OLGA POPOVA	{"email": "popovaolga.031966@postgrespro.ru", "phone": "+70430445872"}
0005432019862	38FD81	2980 266205	ALEKSANDR KOROLEV	{"email": "a_korolev.1985@postgrespro.ru", "phone": "+70585652099"}
0005432019863	38FD81	9833 783677	OLESYA MEDVEDEVA	{"email": "medvedeva.o_12021974@postgrespro.ru", "phone": "+70821505359"}
0005432019864	38FD81	3692 209188	ELENA ANISIMOVA	{"phone": "+70581913599"}
0005432019865	B54EBC	6089 879835	GALINA MIRONOVA	{"email": "g.mironova121975@postgrespro.ru", "phone": "+70597883090"}
0005432019866	78ED48	4220 329910	OLGA PETROVA	{"email": "petrova.o-051956@postgrespro.ru", "phone": "+70305812566"}
0005432019867	78ED48	1867 653717	MIKHAIL DMITRIEV	{"phone": "+70040532035"}
0005432019868	D41B28	9775 397104	TATYANA FILATOVA	{"email": "filatova-tatyana_23071964@postgrespro.ru", "phone": "+70491674264"}
0005432019869	E8642B	4538 415749	OLGA IVANOVA	{"phone": "+70013982412"}
0005432019870	CA6555	6136 654729	NADEZHDA TIKHONOVA	{"phone": "+70502362742"}
0005432019871	1BA5EC	3683 674810	SVETLANA SIDOROVA	{"phone": "+70862761387"}
0005432019872	1BA5EC	6434 462037	TATYANA RODIONOVA	{"email": "rodionova-tatyana-21051970@postgrespro.ru", "phone": "+70009687256"}
0005432019873	1BA5EC	4997 263679	IBRAGIM TIKHONOV	{"phone": "+70877475214"}
0005432019874	1EA898	2045 059431	IVAN PAVLOV	{"phone": "+70051298495"}
0005432019875	8D9FBB	4987 421380	ALLA NAZAROVA	{"email": "anazarova-1970@postgrespro.ru", "phone": "+70431795310"}
0005432019876	63661F	8203 776628	ALEKSANDR KUZMIN	{"email": "akuzmin_031962@postgrespro.ru", "phone": "+70039521856"}
0005432019877	16CF2B	5546 982658	DMITRIY DAVYDOV	{"email": "d-davydov.1971@postgrespro.ru", "phone": "+70480648811"}
0005432019878	BE0A57	2319 376134	ALEKSEY GUSEV	{"phone": "+70557315124"}
0005432019879	46CB09	1181 176118	ZOYA ZAKHAROVA	{"email": "zakharova_zoya081958@postgrespro.ru", "phone": "+70226810658"}
0005432019880	46CB09	3146 845036	ANTON KUZNECOV	{"phone": "+70972895006"}
0005432019881	76BAF2	7808 560318	SERGEY KOZLOV	{"email": "skozlov_1975@postgrespro.ru", "phone": "+70224276162"}
0005432019882	866CE5	2412 794274	ALEKSANDR GUSEV	{"email": "gusev.aleksandr.031976@postgrespro.ru", "phone": "+70267598195"}
0005432019883	34E0DB	7013 870450	VLADIMIR SHEVCHENKO	{"phone": "+70345749414"}
0005432019884	34E0DB	4976 431294	MIKHAIL NIKITIN	{"email": "mikhailnikitin1966@postgrespro.ru", "phone": "+70150602255"}
0005432019885	54C960	5106 348938	EKATERINA SOROKINA	{"email": "sorokina_ekaterina.07121962@postgrespro.ru", "phone": "+70435204612"}
0005432019886	58EA56	3386 739499	ILNAR GUSEV	{"email": "gusev.i.1978@postgrespro.ru", "phone": "+70241635105"}
0005432019887	9EDED1	6860 679415	YURIY ISAEV	{"email": "yisaev_13081970@postgrespro.ru", "phone": "+70168995593"}
0005432019888	43EE53	1240 738253	VLADIMIR TARASOV	{"phone": "+70141375863"}
0005432019889	43EE53	5901 400831	VYACHESLAV ZHURAVLEV	{"phone": "+70238738975"}
0005432019890	149773	9777 737201	VLADIMIR BARANOV	{"email": "baranov.v.1964@postgrespro.ru", "phone": "+70056779256"}
0005432019891	149773	2512 941510	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr-1973@postgrespro.ru", "phone": "+70815647055"}
0005432019892	C24F49	6802 616848	VALERIY KUZNECOV	{"email": "v_kuznecov-1970@postgrespro.ru", "phone": "+70433529271"}
0005432019893	C24F49	7455 678477	VALERIYA NESTEROVA	{"email": "vnesterova-111978@postgrespro.ru", "phone": "+70429318175"}
0005432019894	5077EB	7620 484696	ROMAN OSIPOV	{"phone": "+70806237067"}
0005432019895	2BCAC8	7153 787499	OLGA SOKOLOVA	{"email": "sokolova.o.071980@postgrespro.ru", "phone": "+70603003705"}
0005432019896	2BCAC8	5380 268049	ROMAN KAZAKOV	{"phone": "+70850424064"}
0005432019897	D1BEB8	3903 171791	ANASTASIYA AKIMOVA	{"email": "a_akimova-11091971@postgrespro.ru", "phone": "+70755817048"}
0005432019898	ABA3A0	7991 002529	OLGA VASILEVA	{"email": "vasileva.o.1968@postgrespro.ru", "phone": "+70170501350"}
0005432019899	ABA3A0	8350 644479	NINA SCHERBAKOVA	{"email": "n-scherbakova_1967@postgrespro.ru", "phone": "+70252062129"}
0005432019900	2D0BA2	2729 366742	SERGEY AFANASEV	{"email": "afanasev.s24011971@postgrespro.ru", "phone": "+70569989337"}
0005432019901	2D0BA2	5564 146609	ALENA SAVELEVA	{"phone": "+70314060451"}
0005432019902	C72E8E	6345 941360	SNEZHANA NIKOLAEVA	{"phone": "+70717204232"}
0005432019903	04E42D	4963 379730	DMITRIY VOLKOV	{"phone": "+70174977962"}
0005432019904	936FEC	8959 098655	VLADIMIR NIKOLAEV	{"email": "vnikolaev.1965@postgrespro.ru", "phone": "+70043013633"}
0005432019905	936FEC	4943 473827	VLADIMIR GUSEV	{"email": "gusev.vladimir-1985@postgrespro.ru", "phone": "+70814078614"}
0005432019906	60AD0F	8195 386024	GENNADIY VOLKOV	{"email": "volkovgennadiy-1961@postgrespro.ru", "phone": "+70151094001"}
0005432019907	B6E5FE	2383 077648	DMITRIY SEMENOV	{"email": "d_semenov.1969@postgrespro.ru", "phone": "+70031264234"}
0005432019908	7F61CE	6978 862257	NAZIYA SOROKINA	{"email": "naziyasorokina.1972@postgrespro.ru", "phone": "+70041515295"}
0005432019909	7F61CE	2153 828659	ALEKSEY BARANOV	{"email": "baranov_a.091979@postgrespro.ru", "phone": "+70597647450"}
0005432019910	D33D60	9085 285715	IVAN SEMENOV	{"phone": "+70584739637"}
0005432019911	CC0204	9385 508520	ALEKSEY CHERNOV	{"phone": "+70687992538"}
0005432019912	273783	6409 596885	OKSANA POPOVA	{"email": "popova.oksana1967@postgrespro.ru", "phone": "+70137975871"}
0005432019913	273783	5153 750170	SERGEY VLASOV	{"email": "vlasovsergey.21031969@postgrespro.ru", "phone": "+70942682389"}
0005432019914	D97F7D	3200 404434	TATYANA FROLOVA	{"phone": "+70006087048"}
0005432019915	D97F7D	7238 564880	TATYANA VOLKOVA	{"email": "volkova-t_041986@postgrespro.ru", "phone": "+70291299695"}
0005432019916	E34C9D	8561 896425	EVGENIY PETROV	{"phone": "+70177471272"}
0005432019917	E34C9D	4071 190659	MARINA SOLOVEVA	{"email": "m.soloveva.121970@postgrespro.ru", "phone": "+70714778425"}
0005432019918	1F295E	1359 461460	SERGEY GORBUNOV	{"email": "gorbunov-s_061976@postgrespro.ru", "phone": "+70874650488"}
0005432019919	1F295E	5659 631615	ALEKSANDR DAVYDOV	{"phone": "+70163977079"}
0005432019920	1F295E	3627 156256	MARGARITA OSIPOVA	{"phone": "+70866871665"}
0005432019921	CAA70F	1970 189591	OLGA GAVRILOVA	{"email": "olgagavrilova.29111965@postgrespro.ru", "phone": "+70655872455"}
0005432019922	24233C	2516 393893	SVETLANA KONDRATEVA	{"phone": "+70907450915"}
0005432019923	6F3EEB	7108 123671	LEONID ANTONOV	{"phone": "+70099179541"}
0005432019924	65E29D	9937 836677	IVAN SEMENOV	{"phone": "+70901808962"}
0005432019925	66D3C8	4622 594150	ANATOLIY KARPOV	{"phone": "+70746551003"}
0005432019926	3D5715	3555 142456	POLINA ZHURAVLEVA	{"phone": "+70398542694"}
0005432019927	4AA338	8549 399655	SERGEY MARTYNOV	{"phone": "+70098668668"}
0005432019928	21E2E8	2724 867759	LIDIYA DENISOVA	{"phone": "+70736906780"}
0005432019929	D1EFCD	5927 177870	VASILIY BELOV	{"phone": "+70691518307"}
0005432019930	62D98B	5825 247612	SVETLANA NESTEROVA	{"email": "nesterova.svetlana.24021972@postgrespro.ru", "phone": "+70995752689"}
0005432019931	60DFA1	8256 616686	VIKTOR VOLKOV	{"phone": "+70069139383"}
0005432019932	60DFA1	5807 724975	ELENA MIRONOVA	{"email": "elenamironova-04081966@postgrespro.ru", "phone": "+70595757346"}
0005432019933	60DFA1	3075 979886	KONSTANTIN NAZAROV	{"email": "k-nazarov.1977@postgrespro.ru", "phone": "+70083670741"}
0005432019934	04FBEA	8075 340875	ANDREY MOISEEV	{"phone": "+70618855576"}
0005432019995	09549C	1455 201273	KONSTANTIN FEDOROV	{"phone": "+70971949462"}
0005432019935	70E4A8	2629 729193	EKATERINA NESTEROVA	{"email": "nesterova-ekaterina.1966@postgrespro.ru", "phone": "+70369299112"}
0005432019936	600164	3806 528613	ALEKSANDRA POPOVA	{"phone": "+70632842611"}
0005432019937	600164	7988 736818	VITALIY SOKOLOV	{"phone": "+70513858958"}
0005432019938	B571CE	7728 795837	ARKADIY SOKOLOV	{"phone": "+70423050334"}
0005432019939	0FEAE5	2966 863962	DMITRIY SEMENOV	{"email": "semenov.d.03111958@postgrespro.ru", "phone": "+70990159818"}
0005432019940	0FEAE5	9554 803337	ALEKSANDR MOROZOV	{"phone": "+70977215622"}
0005432019941	8AD345	1540 201931	ANTONINA KONDRATEVA	{"phone": "+70499333565"}
0005432019942	DDD751	6793 697958	GENNADIY SCHERBAKOV	{"email": "scherbakov_g.1974@postgrespro.ru", "phone": "+70026618373"}
0005432019943	DDD751	6994 219268	TATYANA OSIPOVA	{"email": "osipovat.081977@postgrespro.ru", "phone": "+70154311608"}
0005432019944	625B38	6775 844828	VALENTINA TITOVA	{"email": "titova-v1969@postgrespro.ru", "phone": "+70167585857"}
0005432019945	625B38	0446 202131	VERA ALEKSEEVA	{"email": "veraalekseeva-011979@postgrespro.ru", "phone": "+70504568720"}
0005432019946	1873D7	9119 288620	IVAN MEDVEDEV	{"email": "i.medvedev-1964@postgrespro.ru", "phone": "+70615832995"}
0005432019947	1873D7	2314 433984	YURIY KOZLOV	{"email": "kozlov_y.031961@postgrespro.ru", "phone": "+70389822970"}
0005432019948	E490F7	2506 959562	MARIYA MAKAROVA	{"phone": "+70400367846"}
0005432019949	7552AB	2753 041002	VYACHESLAV PETROV	{"phone": "+70050833736"}
0005432019950	212FF1	2389 128960	OLGA ABRAMOVA	{"email": "abramova.o.1975@postgrespro.ru", "phone": "+70522313166"}
0005432019951	FFC84F	5661 375331	IGOR SOROKIN	{"email": "isorokin.1969@postgrespro.ru", "phone": "+70292091613"}
0005432019952	550D5C	1446 717377	ALEKSANDRA TIKHONOVA	{"phone": "+70563077755"}
0005432019953	550D5C	7864 715875	YULIYA DMITRIEVA	{"email": "dmitrieva_y_11061971@postgrespro.ru", "phone": "+70203603143"}
0005432019954	F342F3	4366 344969	TATYANA ORLOVA	{"email": "t.orlova.02011985@postgrespro.ru", "phone": "+70622697496"}
0005432019955	DFF336	9293 311765	LYUDMILA KUZNECOVA	{"phone": "+70022116274"}
0005432019956	9DD46A	8100 651977	GRIGORIY KUZNECOV	{"phone": "+70587854772"}
0005432019957	9DD46A	4498 434810	ANNA NOVIKOVA	{"email": "novikova.a_23121984@postgrespro.ru", "phone": "+70619722435"}
0005432019958	B8FDA6	4116 601079	IRINA MOISEEVA	{"phone": "+70640762643"}
0005432019959	B8FDA6	1200 709627	KONSTANTIN VASILEV	{"phone": "+70692462496"}
0005432019960	4FA884	3911 217107	ILYA SEMENOV	{"email": "semenov_i_111983@postgrespro.ru", "phone": "+70417497613"}
0005432019961	D9EC73	4228 802212	KONSTANTIN GRIGOREV	{"email": "konstantin.grigorev_19071976@postgrespro.ru", "phone": "+70854743896"}
0005432019962	D9EC73	0723 675308	ANATOLIY ILIN	{"email": "a-ilin.10081966@postgrespro.ru", "phone": "+70288201623"}
0005432019963	E92596	8028 465190	LYUDMILA DENISOVA	{"phone": "+70971707840"}
0005432019964	6DD9F5	7093 155678	SOFYA FEDOROVA	{"phone": "+70489124058"}
0005432019965	6DD9F5	5465 866020	DMITRIY BORISOV	{"phone": "+70555471968"}
0005432019966	DF90D1	4700 383499	RAISA EFREMOVA	{"phone": "+70340055168"}
0005432019967	4D815F	0736 852628	OLEG KOROLEV	{"email": "korolev_oleg-23041962@postgrespro.ru", "phone": "+70148161723"}
0005432019968	4DD37E	4638 425057	FAINA ALEKSANDROVA	{"email": "f.aleksandrova.30071988@postgrespro.ru", "phone": "+70422118653"}
0005432019969	3D7323	1635 158539	ELIZAVETA MATVEEVA	{"phone": "+70182469250"}
0005432019970	3D7323	1953 140626	TAMARA SOKOLOVA	{"email": "tsokolova-12051983@postgrespro.ru", "phone": "+70756894392"}
0005432019971	45377A	2185 286218	MIKHAIL MOISEEV	{"email": "m_moiseev.04121986@postgrespro.ru", "phone": "+70914510563"}
0005432019972	45377A	0785 969921	YULIYA GUSEVA	{"phone": "+70771314095"}
0005432019973	F1C222	7367 699636	VLADIMIR TIKHONOV	{"email": "tikhonovvladimir_1976@postgrespro.ru", "phone": "+70812348298"}
0005432019974	FB4D13	3382 183128	GALINA KARPOVA	{"email": "karpovag_1967@postgrespro.ru", "phone": "+70007620064"}
0005432019975	780042	5825 437759	YULIYA SAVELEVA	{"phone": "+70701934832"}
0005432019976	2E77DE	7674 784482	VALERIY GRIGOREV	{"phone": "+70411303452"}
0005432019977	2E77DE	8675 858762	NIKOLAY SCHERBAKOV	{"phone": "+70939214197"}
0005432019978	8865FF	3516 924885	SERGEY POPOV	{"email": "popovs.1983@postgrespro.ru", "phone": "+70034064032"}
0005432019979	9CE988	9068 391762	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov.1974@postgrespro.ru", "phone": "+70414378778"}
0005432019980	9CE988	2372 702453	LYUDMILA SERGEEVA	{"email": "sergeeva.lyudmila_1980@postgrespro.ru", "phone": "+70262052670"}
0005432019981	FA14C3	8862 906386	TATYANA VASILEVA	{"phone": "+70073066078"}
0005432019982	4EC9C6	8973 851482	NIKOLAY KAZAKOV	{"phone": "+70190170813"}
0005432019983	F381CC	7574 708120	MAKSIM VLASOV	{"phone": "+70537750473"}
0005432019984	387900	0309 078607	NATALYA FILATOVA	{"email": "natalya.filatova_121973@postgrespro.ru", "phone": "+70596712783"}
0005432019985	387900	9854 239033	ALEKSANDR GRIGOREV	{"email": "a.grigorev-29041973@postgrespro.ru", "phone": "+70537312588"}
0005432019986	05AD1F	9567 001492	EKATERINA SCHERBAKOVA	{"email": "scherbakova.e_031978@postgrespro.ru", "phone": "+70394531295"}
0005432019987	113F09	4525 649826	ELENA LEBEDEVA	{"email": "e.lebedeva.03121969@postgrespro.ru", "phone": "+70799167867"}
0005432019988	D00F1C	5093 778114	MIKHAIL SOROKIN	{"phone": "+70173926137"}
0005432019989	129309	9795 939919	NADEZHDA NESTEROVA	{"email": "nadezhda_nesterova1966@postgrespro.ru", "phone": "+70026532060"}
0005432019990	978886	6261 223105	KONSTANTIN SAVELEV	{"phone": "+70718580846"}
0005432019991	978886	2865 049793	ILYA VASILEV	{"phone": "+70862885229"}
0005432019992	978886	7020 687336	PELAGEYA SERGEEVA	{"phone": "+70041428488"}
0005432019993	4A1CAC	2301 081926	ELENA EFREMOVA	{"email": "efremova.e-021972@postgrespro.ru", "phone": "+70055250748"}
0005432019994	09549C	6523 938774	NATALYA NOVIKOVA	{"email": "novikova_natalya10011979@postgrespro.ru", "phone": "+70687067484"}
0005432019996	ACD439	4448 629709	MARINA VASILEVA	{"phone": "+70258035449"}
0005432019997	89774D	2405 924635	SVETLANA SCHERBAKOVA	{"email": "scherbakovasvetlana.1974@postgrespro.ru", "phone": "+70020310865"}
0005432019998	89774D	5443 084747	EKATERINA DANILOVA	{"email": "e_danilova051976@postgrespro.ru", "phone": "+70216564846"}
0005432019999	613ADD	1499 392642	OLESYA KARPOVA	{"phone": "+70343535282"}
0005432020000	613ADD	7435 297684	ALEKSANDR KONOVALOV	{"email": "konovalov.aleksandr121961@postgrespro.ru", "phone": "+70070403722"}
0005432020001	46D5C7	8212 529406	NINA BORISOVA	{"email": "borisova_nina_061970@postgrespro.ru", "phone": "+70307826099"}
0005432020002	46D5C7	6157 742934	VITALIY ROMANOV	{"phone": "+70993031652"}
0005432020003	46D5C7	3046 741195	VIKTORIYA FILIPPOVA	{"phone": "+70630753513"}
0005432020004	F45510	2540 978059	OLGA CHERNOVA	{"email": "chernovao_1971@postgrespro.ru", "phone": "+70450088892"}
0005432020005	A86E39	5880 233869	LARISA ILINA	{"email": "larisa_ilina071971@postgrespro.ru", "phone": "+70790947893"}
0005432020006	572DD7	2022 481973	ARTEM SAVELEV	{"email": "a.savelev.081980@postgrespro.ru", "phone": "+70226955812"}
0005432020007	572DD7	6164 877795	IVAN SIDOROV	{"email": "ivan-sidorov1970@postgrespro.ru", "phone": "+70282019463"}
0005432020008	94E549	1515 020483	ANDREY BELOV	{"email": "andrey-belov10021968@postgrespro.ru", "phone": "+70817915126"}
0005432020009	94E549	9927 793367	ALEKSEY EGOROV	{"email": "egorov.a.27101978@postgrespro.ru", "phone": "+70179896378"}
0005432020010	EA6F7E	9965 830757	IRINA MOISEEVA	{"email": "moiseevai_1972@postgrespro.ru", "phone": "+70674959296"}
0005432020011	7F8DB0	5280 978471	VIKTORIYA BELOVA	{"phone": "+70983804411"}
0005432020012	7F8DB0	7796 117785	ROMAN VLASOV	{"email": "r-vlasov-071980@postgrespro.ru", "phone": "+70892350809"}
0005432020013	7D55E9	8658 611386	YANA STEPANOVA	{"phone": "+70072935481"}
0005432020014	7D55E9	7173 802947	ANASTASIYA BELOVA	{"email": "belova-anastasiya_011977@postgrespro.ru", "phone": "+70663060863"}
0005432020015	B83393	1255 975399	NATALYA ERMAKOVA	{"email": "ermakova.n23081965@postgrespro.ru", "phone": "+70310345484"}
0005432020016	BFE14D	4237 014474	ANATOLIY FEDOROV	{"email": "anatoliy.fedorov.051970@postgrespro.ru", "phone": "+70811105664"}
0005432020017	679513	6891 064493	GENNADIY VOLKOV	{"email": "g_volkov-051982@postgrespro.ru", "phone": "+70953438757"}
0005432020018	1947B4	9541 208532	ANZHELA KUZNECOVA	{"phone": "+70144619856"}
0005432020019	1947B4	7391 086875	VALENTINA FOMINA	{"phone": "+70169267638"}
0005432020020	21BE7E	8917 713255	KRISTINA ZOTOVA	{"phone": "+70256724405"}
0005432020021	4D12F6	6308 310042	LYUDMILA BOGDANOVA	{"phone": "+70357140840"}
0005432020022	56097B	3926 404204	ANASTASIYA GERASIMOVA	{"email": "a.gerasimova-01031985@postgrespro.ru", "phone": "+70251368528"}
0005432020023	F0D490	5385 157818	ALEKSEY IVANOV	{"email": "alekseyivanov-23041970@postgrespro.ru", "phone": "+70981109696"}
0005432020024	DA541A	7689 727422	SVETLANA FEDOROVA	{"phone": "+70339654518"}
0005432020025	DA541A	1451 266294	SOFYA BORISOVA	{"phone": "+70404947184"}
0005432020026	B83E06	2017 544207	IRINA KAZAKOVA	{"phone": "+70769063041"}
0005432020027	B83E06	1808 959634	ALEKSANDR BELOV	{"phone": "+70587170677"}
0005432020028	22895F	8966 850428	ROZA FEDOROVA	{"phone": "+70661985693"}
0005432020029	BBB5D0	4622 955280	ANDREY POPOV	{"phone": "+70877668035"}
0005432020030	447617	9364 609356	TARAS AFANASEV	{"email": "afanasev.taras-26121971@postgrespro.ru", "phone": "+70425949855"}
0005432020031	B9B80A	8407 487284	VERA ROMANOVA	{"phone": "+70514561163"}
0005432020032	C689F8	6066 806903	GALINA SOKOLOVA	{"email": "sokolova_g20011980@postgrespro.ru", "phone": "+70586193507"}
0005432020033	14009B	3447 701033	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir-1968@postgrespro.ru", "phone": "+70244634666"}
0005432020034	CE06E6	9038 821722	ELENA AKIMOVA	{"email": "elena.akimova101980@postgrespro.ru", "phone": "+70774924185"}
0005432020035	CE06E6	5736 878581	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov-14071982@postgrespro.ru", "phone": "+70531692313"}
0005432020036	BCA2AE	8528 297353	ANNA KALININA	{"email": "anna_kalinina091968@postgrespro.ru", "phone": "+70604137378"}
0005432020037	BCA2AE	5433 694955	ALEKSANDR BORISOV	{"phone": "+70824839878"}
0005432020038	278C82	6473 638797	NATALIYA GUSEVA	{"phone": "+70525705678"}
0005432020039	9315EA	2870 018610	ANNA DENISOVA	{"email": "denisova-anna.06021980@postgrespro.ru", "phone": "+70558631447"}
0005432020040	9315EA	0357 870895	MARIYA VASILEVA	{"phone": "+70488777417"}
0005432020041	07897E	7281 826032	SVETLANA LAZAREVA	{"phone": "+70281810423"}
0005432020042	3E821F	8050 302657	SERGEY VLASOV	{"phone": "+70572924333"}
0005432020043	53E469	9684 911491	VIKTOR ORLOV	{"email": "orlov.viktor_081978@postgrespro.ru", "phone": "+70879774890"}
0005432020044	0BDFDE	6442 876590	VERA BELOVA	{"email": "belovav-1976@postgrespro.ru", "phone": "+70128828796"}
0005432020045	0BDFDE	3581 327782	NADEZHDA KONOVALOVA	{"email": "n.konovalova05091967@postgrespro.ru", "phone": "+70352981975"}
0005432020046	123BFC	3111 000873	IGOR YAKOVLEV	{"email": "yakovlev-igor_02061970@postgrespro.ru", "phone": "+70354397777"}
0005432020047	123BFC	2677 979909	NATALYA IVANOVA	{"phone": "+70621471032"}
0005432020048	8F1268	8963 122734	VIKTORIYA ANDREEVA	{"phone": "+70291372071"}
0005432020049	313A1D	2566 977767	DMITRIY CHERNOV	{"email": "d-chernov-051979@postgrespro.ru", "phone": "+70217060827"}
0005432020050	F338CC	6428 083603	GALINA FILIPPOVA	{"phone": "+70900900666"}
0005432020051	D48B30	9829 782319	VERA ANTONOVA	{"email": "vantonova12081960@postgrespro.ru", "phone": "+70886235086"}
0005432020052	D48B30	6647 185164	ELIZAVETA MARTYNOVA	{"email": "martynova.e_1970@postgrespro.ru", "phone": "+70755135612"}
0005432020053	F09DBC	6132 348183	ELVIRA EGOROVA	{"phone": "+70080428886"}
0005432020054	F09DBC	2756 747851	MARIYA ZOTOVA	{"phone": "+70550466567"}
0005432020055	D5247C	2977 252625	ALEKSANDR ZAYCEV	{"email": "azaycev-011986@postgrespro.ru", "phone": "+70071316280"}
0005432020056	D5247C	6804 643882	GERMAN MIRONOV	{"phone": "+70416376503"}
0005432020057	A0EA03	3638 047502	RIMMA KUZNECOVA	{"phone": "+70068522420"}
0005432020058	913374	1861 128680	ILYA DAVYDOV	{"email": "i_davydov081972@postgrespro.ru", "phone": "+70546597317"}
0005432020059	913374	2323 693034	IRINA ERMAKOVA	{"email": "iermakova.121971@postgrespro.ru", "phone": "+70434429620"}
0005432020060	D77E68	3002 490890	ILYAS STEPANOV	{"email": "ilyas_stepanov1973@postgrespro.ru", "phone": "+70305673087"}
0005432020061	6127E6	5718 159402	ARKADIY ZHURAVLEV	{"phone": "+70924640509"}
0005432020062	88A821	5870 976109	ALEKSEY SERGEEV	{"email": "a.sergeev_1960@postgrespro.ru", "phone": "+70336430933"}
0005432020063	88A821	3231 409106	KIRILL DMITRIEV	{"email": "dmitriev-k-02021980@postgrespro.ru", "phone": "+70942663532"}
0005432020064	88A821	0276 785208	ELENA RYABOVA	{"phone": "+70835009043"}
0005432020065	9288CE	7065 509418	YURIY KISELEV	{"phone": "+70591344647"}
0005432020066	682D2E	4297 292479	IVAN MAKAROV	{"email": "makarov_ivan_051973@postgrespro.ru", "phone": "+70379084289"}
0005432020067	4EF27E	9493 220036	ANNA FROLOVA	{"email": "frolova-a_071968@postgrespro.ru", "phone": "+70718332951"}
0005432020068	1AF27C	3015 075229	ARTEM DMITRIEV	{"email": "artemdmitriev.1973@postgrespro.ru", "phone": "+70646247338"}
0005432020069	1AF27C	1139 653116	VLADIMIR PETROV	{"phone": "+70347018002"}
0005432020070	A6CB6B	6867 674039	ALEKSEY SOLOVEV	{"email": "solovev.a101967@postgrespro.ru", "phone": "+70040847301"}
0005432020071	A6CB6B	6116 346438	ELENA PAVLOVA	{"email": "pavlova-elena_011979@postgrespro.ru", "phone": "+70454105852"}
0005432020072	E77CB0	6740 379688	VYACHESLAV MIKHAYLOV	{"phone": "+70693547639"}
0005432020073	3C89DB	2836 578899	VLADIMIR TARASOV	{"phone": "+70710460994"}
0005432020074	6984AA	6773 697828	MIKHAIL SOROKIN	{"phone": "+70308676433"}
0005432020075	6984AA	4222 061068	ANTON SOLOVEV	{"email": "anton-solovev111977@postgrespro.ru", "phone": "+70038384737"}
0005432020076	173A57	9403 843878	TIMUR NIKOLAEV	{"phone": "+70997479576"}
0005432020077	173A57	1967 119502	LILIYA ZAKHAROVA	{"phone": "+70446967118"}
0005432020078	718802	8939 979236	NIKOLAY KISELEV	{"email": "kiselevn_11081980@postgrespro.ru", "phone": "+70592254030"}
0005432020079	85681D	8404 823407	EVGENIY KUZMIN	{"phone": "+70759817948"}
0005432020080	2FD522	5366 360859	SERGEY TARASOV	{"email": "tarasovs_1977@postgrespro.ru", "phone": "+70661235805"}
0005432020081	02966A	6871 042188	EVGENIY VASILEV	{"email": "vasilev_evgeniy111981@postgrespro.ru", "phone": "+70491316821"}
0005432020082	6E808D	9140 806041	EVGENIY EGOROV	{"email": "e.egorov-031976@postgrespro.ru", "phone": "+70262158645"}
0005432020083	65B8A0	0629 717682	ZINAIDA POPOVA	{"phone": "+70036533581"}
0005432020084	6E2506	2206 994681	YULIYA GAVRILOVA	{"email": "yuliya_gavrilova_1970@postgrespro.ru", "phone": "+70111374682"}
0005432020085	6E2506	6573 662127	OLGA MIRONOVA	{"email": "olga-mironova23031970@postgrespro.ru", "phone": "+70730152883"}
0005432020086	96F70A	6023 669847	VLADISLAV NIKITIN	{"email": "nikitin.v1970@postgrespro.ru", "phone": "+70973945782"}
0005432020087	F73FDF	4020 235348	VERA VOROBEVA	{"email": "vera_vorobeva051984@postgrespro.ru", "phone": "+70570200670"}
0005432020088	AF7F8A	6393 259660	SVETLANA RODIONOVA	{"phone": "+70656827120"}
0005432020089	AF7F8A	6245 075718	VALERIY SCHERBAKOV	{"email": "scherbakovvaleriy-26121980@postgrespro.ru", "phone": "+70993311607"}
0005432020090	EA5216	2994 388334	TATYANA SOROKINA	{"phone": "+70140370757"}
0005432020091	EA5216	7671 333531	NADEZHDA LUKYANOVA	{"email": "nadezhdalukyanova-1968@postgrespro.ru", "phone": "+70257797736"}
0005432020092	141325	2696 335945	ALLA FILATOVA	{"phone": "+70296879377"}
0005432020093	141325	9743 160846	NIKITA GERASIMOV	{"phone": "+70829867450"}
0005432020094	F30619	3359 884321	TATYANA KONDRATEVA	{"email": "t_kondrateva.101965@postgrespro.ru", "phone": "+70799981832"}
0005432020095	03FA64	0500 403251	VLADIMIR IVANOV	{"phone": "+70834960010"}
0005432020096	03FA64	5395 504265	VITALIY DMITRIEV	{"phone": "+70079843484"}
0005432020097	439CA1	7518 445612	ALEKSANDR MATVEEV	{"email": "matveev.a-031972@postgrespro.ru", "phone": "+70055347830"}
0005432020098	B8C2D9	3084 123917	EVGENIY ALEKSANDROV	{"email": "evgeniyaleksandrov_24011965@postgrespro.ru", "phone": "+70437994674"}
0005432020099	B8C2D9	2429 866746	ARTEM KUZNECOV	{"phone": "+70367436546"}
0005432020100	078B9A	2673 084304	VLADIMIR ZAKHAROV	{"phone": "+70288362220"}
0005432020101	6A2722	0750 887170	ANDREY VLASOV	{"email": "avlasov-011971@postgrespro.ru", "phone": "+70082967249"}
0005432020102	6A2722	2083 565127	NIKOLAY ZHUKOV	{"email": "zhukovnikolay-1971@postgrespro.ru", "phone": "+70827345819"}
0005432020103	84D02A	5889 255151	LIDIYA ORLOVA	{"phone": "+70184020830"}
0005432020104	1FB74C	3122 280580	MAKSIM KARPOV	{"phone": "+70707699810"}
0005432020105	1E0818	5182 977501	GALINA STEPANOVA	{"email": "stepanovag17061974@postgrespro.ru", "phone": "+70646686673"}
0005432020106	1E0818	1393 340669	LYUDMILA KUZNECOVA	{"phone": "+70464447754"}
0005432020107	1E0818	4327 153019	EVGENIY ILIN	{"email": "eilin.1972@postgrespro.ru", "phone": "+70999429793"}
0005432020108	B98105	2559 171417	ELENA CHERNOVA	{"email": "chernovaelena_07081969@postgrespro.ru", "phone": "+70998644862"}
0005432020109	B98105	0119 784340	DARYA MALYSHEVA	{"email": "d_malysheva1959@postgrespro.ru", "phone": "+70352497752"}
0005432020110	AEE5C0	7959 406254	GENNADIY KUZNECOV	{"email": "kuznecovgennadiy1968@postgrespro.ru", "phone": "+70152128788"}
0005432020111	AEE5C0	2649 557684	ADELINA TITOVA	{"phone": "+70543632675"}
0005432020112	07ED62	9974 114054	OLGA KUZNECOVA	{"email": "kuznecovao-22041965@postgrespro.ru", "phone": "+70538548156"}
0005432020113	EB3A46	6830 810219	RAISA STEPANOVA	{"email": "rstepanova1966@postgrespro.ru", "phone": "+70796790920"}
0005432020114	6668DA	8182 533743	SERGEY ALEKSEEV	{"email": "alekseev_sergey-1980@postgrespro.ru", "phone": "+70801429389"}
0005432020115	6668DA	5660 190512	TATYANA YAKOVLEVA	{"email": "yakovleva_tatyana_26091973@postgrespro.ru", "phone": "+70111898460"}
0005432020116	6668DA	8566 477919	NATALYA KONOVALOVA	{"email": "konovalova.natalya101976@postgrespro.ru", "phone": "+70995865185"}
0005432020117	48699C	0804 755038	SVETLANA BELOVA	{"phone": "+70976908603"}
0005432020118	005696	8783 431871	IRINA VASILEVA	{"phone": "+70840261333"}
0005432020119	005696	9790 140874	OLEG SCHERBAKOV	{"phone": "+70766374027"}
0005432020120	9A8776	9061 922009	VLADISLAV MEDVEDEV	{"email": "vladislavmedvedev.1964@postgrespro.ru", "phone": "+70472578255"}
0005432020121	92DC06	7756 431675	ELENA KRASNOVA	{"email": "elena_krasnova09111982@postgrespro.ru", "phone": "+70378220929"}
0005432020122	92DC06	5392 731252	DMITRIY GUSEV	{"email": "gusev.dmitriy01041974@postgrespro.ru", "phone": "+70820792653"}
0005432020123	92DC06	9417 323021	IRINA NAZAROVA	{"email": "nazarova-i-23051972@postgrespro.ru", "phone": "+70912630972"}
0005432020124	1766FA	2203 103787	EKATERINA AFANASEVA	{"phone": "+70054797655"}
0005432020125	83A07B	4249 898314	SOFIYA STEPANOVA	{"email": "s.stepanova17071972@postgrespro.ru", "phone": "+70419184936"}
0005432020126	83A07B	5870 778002	NIKOLAY EGOROV	{"email": "nikolayegorov-1972@postgrespro.ru", "phone": "+70450475476"}
0005432020127	67C35F	2376 383107	NATALYA GAVRILOVA	{"email": "natalya_gavrilova_1970@postgrespro.ru", "phone": "+70952097340"}
0005432020128	67C35F	2426 764550	MARINA DMITRIEVA	{"phone": "+70239163621"}
0005432020129	4C714C	3613 609181	DENIS GAVRILOV	{"phone": "+70776381590"}
0005432020130	24222B	8063 275282	ALEKSEY TIKHONOV	{"email": "alekseytikhonov-1970@postgrespro.ru", "phone": "+70030649039"}
0005432020131	4E4BA2	7199 910960	ALEKSEY KAZAKOV	{"phone": "+70303247684"}
0005432020132	4E4BA2	4801 371981	OKSANA NIKITINA	{"phone": "+70093073802"}
0005432020133	E1197B	2837 859685	IRINA DANILOVA	{"phone": "+70877877939"}
0005432020134	E1197B	5992 530447	VLADIMIR KUZMIN	{"phone": "+70234676425"}
0005432020135	E1197B	5871 953589	SERGEY GUSEV	{"email": "gusev.s13061969@postgrespro.ru", "phone": "+70479700364"}
0005432020136	DEA034	0908 049123	DENIS MOROZOV	{"phone": "+70146486620"}
0005432020137	3ACAEE	8476 131174	VALERIY PAVLOV	{"email": "valeriy_pavlov.061972@postgrespro.ru", "phone": "+70331918539"}
0005432020138	C5FA2E	3664 113893	VLADISLAV ZHUKOV	{"phone": "+70401008565"}
0005432020139	2102CA	6070 554186	ANDREY GUSEV	{"email": "gusev_andrey.011966@postgrespro.ru", "phone": "+70363832974"}
0005432020140	60FCD8	1190 269840	IRINA KUZNECOVA	{"email": "kuznecova_irina29101975@postgrespro.ru", "phone": "+70162285712"}
0005432020141	04C7EA	7133 945557	TATYANA ABRAMOVA	{"phone": "+70333030186"}
0005432020142	CC5C15	0393 869567	ALINA KONOVALOVA	{"email": "konovalova.a.111965@postgrespro.ru", "phone": "+70921630411"}
0005432020143	CC5C15	5556 759589	SERGEY FEDOROV	{"phone": "+70429466648"}
0005432020144	241E50	7199 941095	SVETLANA KAZAKOVA	{"email": "svetlana_kazakova111969@postgrespro.ru", "phone": "+70911924482"}
0005432020145	F46569	9672 607820	ANATOLIY KRASNOV	{"phone": "+70936406124"}
0005432020146	70F9D5	2698 986840	KRISTINA SEMENOVA	{"email": "semenovakristina.28041979@postgrespro.ru", "phone": "+70759964770"}
0005432020147	190124	0408 176169	ALEKSEY FROLOV	{"phone": "+70445277562"}
0005432020148	190124	7567 572026	IGOR VOLKOV	{"phone": "+70108993554"}
0005432020149	22F77D	2163 650782	OLGA GAVRILOVA	{"email": "olga.gavrilova.051978@postgrespro.ru", "phone": "+70745106638"}
0005432020150	2759B2	7665 226270	VARVARA ILINA	{"email": "ilina_v_1979@postgrespro.ru", "phone": "+70506351200"}
0005432020151	2759B2	1335 788560	TATYANA DAVYDOVA	{"phone": "+70871676744"}
0005432020152	52467A	1178 422533	VALERIY NIKITIN	{"phone": "+70788165389"}
0005432020153	52467A	1033 688884	MARINA DMITRIEVA	{"email": "dmitrieva.marina-121964@postgrespro.ru", "phone": "+70958636666"}
0005432020154	0815A4	4414 543717	IRINA SERGEEVA	{"phone": "+70722716056"}
0005432020155	4CF4EE	3280 924250	RAIL DAVYDOV	{"phone": "+70064897373"}
0005432020156	4CF4EE	1257 319043	ROMAN VOROBEV	{"email": "r-vorobev-26111975@postgrespro.ru", "phone": "+70874936558"}
0005432020157	FB1763	9758 819458	SERGEY VASILEV	{"email": "vasilevs1980@postgrespro.ru", "phone": "+70086959768"}
0005432020158	76FB8F	3787 320696	MIKHAIL PETROV	{"email": "m.petrov031975@postgrespro.ru", "phone": "+70193195878"}
0005432020159	7CBB0F	8452 246945	ANNA NAUMOVA	{"email": "naumova-a.1959@postgrespro.ru", "phone": "+70276101898"}
0005432020160	DE1897	3429 238710	YAROSLAV FEDOTOV	{"phone": "+70852612629"}
0005432020161	DE1897	6729 659708	YULIYA KOROLEVA	{"email": "y.koroleva071975@postgrespro.ru", "phone": "+70232121367"}
0005432020219	F67BDA	2913 285982	NIKOLAY GAVRILOV	{"phone": "+70152555613"}
0005432020162	157B6E	5776 029621	DANILA KUDRYASHOV	{"email": "kudryashov.d.091961@postgrespro.ru", "phone": "+70051999010"}
0005432020163	BC39F4	5220 585975	VITALIY KRASNOV	{"phone": "+70914677358"}
0005432020164	BC39F4	3069 012466	MARIYA OVCHINNIKOVA	{"phone": "+70233812224"}
0005432020165	0D9077	9864 460738	ALEKSANDR ORLOV	{"email": "orlova_081970@postgrespro.ru", "phone": "+70934893433"}
0005432020166	D27797	5791 453794	EVGENIYA BOGDANOVA	{"email": "e_bogdanova101968@postgrespro.ru", "phone": "+70394491164"}
0005432020167	D27797	6499 852742	ANDREY KOROLEV	{"email": "korolev.andrey.031975@postgrespro.ru", "phone": "+70865027736"}
0005432020168	410E15	4514 804638	ANASTASIYA IVANOVA	{"phone": "+70759746149"}
0005432020169	410E15	7119 023942	SERGEY SHEVCHENKO	{"email": "shevchenkosergey-1971@postgrespro.ru", "phone": "+70866130899"}
0005432020170	B69EC7	6480 611327	TATYANA YUDINA	{"phone": "+70301635554"}
0005432020171	B69EC7	4064 753994	BORIS ISAEV	{"email": "boris_isaev.17041966@postgrespro.ru", "phone": "+70162383490"}
0005432020172	0CFB3F	3657 271543	EKATERINA SERGEEVA	{"email": "sergeeva.ekaterina-25111981@postgrespro.ru", "phone": "+70078062226"}
0005432020173	0CFB3F	0409 127598	MIROSLAV EGOROV	{"email": "miroslavegorov-23121984@postgrespro.ru", "phone": "+70721644806"}
0005432020174	9F2928	8360 050447	ALEVTINA MELNIKOVA	{"email": "a-melnikova_24051979@postgrespro.ru", "phone": "+70304326456"}
0005432020175	9F2928	0137 511638	ANASTASIYA MAKAROVA	{"phone": "+70594532582"}
0005432020176	751BF9	7166 885240	GALINA KARPOVA	{"phone": "+70380405897"}
0005432020177	751BF9	2001 288717	RUSLAN VOROBEV	{"email": "vorobev-ruslan.1965@postgrespro.ru", "phone": "+70385348224"}
0005432020178	84B73E	2082 734151	NIKITA KOROLEV	{"phone": "+70349001475"}
0005432020179	AA0524	1960 215860	PETR KUDRYASHOV	{"email": "pkudryashov.1982@postgrespro.ru", "phone": "+70674305475"}
0005432020180	251DC8	9695 862301	EVGENIY KULIKOV	{"phone": "+70097341581"}
0005432020181	251DC8	9206 062787	VALERIY SEMENOV	{"phone": "+70059403179"}
0005432020182	251DC8	3328 321371	ALEKSANDR KUZMIN	{"phone": "+70439816595"}
0005432020183	456302	0694 425640	ALEKSANDR GERASIMOV	{"phone": "+70488872109"}
0005432020184	456302	3283 198274	VADIM ABRAMOV	{"phone": "+70580480944"}
0005432020185	456302	7839 489407	TAMARA DMITRIEVA	{"phone": "+70276159397"}
0005432020186	161570	1439 035638	YANA KUZMINA	{"phone": "+70011694192"}
0005432020187	BFB47F	5673 243813	STEPAN SIDOROV	{"phone": "+70916379137"}
0005432020188	2F1CEC	0342 943279	MARINA DENISOVA	{"phone": "+70731128465"}
0005432020189	1E6F77	0389 281627	EVGENIY SIDOROV	{"phone": "+70366030104"}
0005432020190	B37038	4706 272472	LYUDMILA KOROLEVA	{"phone": "+70948378563"}
0005432020191	B37038	4965 677517	POLINA GUSEVA	{"email": "guseva-polina111966@postgrespro.ru", "phone": "+70682181434"}
0005432020192	AAA950	6611 279255	ALEKSANDR VLASOV	{"phone": "+70206029907"}
0005432020193	AAA950	5016 051210	SERGEY PAVLOV	{"phone": "+70832715286"}
0005432020194	979047	7574 881572	ALEKSANDR EGOROV	{"phone": "+70023482639"}
0005432020195	6E341E	6960 013664	MAKSIM SMIRNOV	{"email": "smirnov-m03021973@postgrespro.ru", "phone": "+70795331098"}
0005432020196	65B87B	1192 968705	DENIS SEMENOV	{"email": "dsemenov.14111970@postgrespro.ru", "phone": "+70424376406"}
0005432020197	11F194	3209 269548	DMITRIY KOZLOV	{"phone": "+70573879497"}
0005432020198	E1786D	0338 961054	SERGEY ILIN	{"phone": "+70305681347"}
0005432020199	3490B1	3550 467946	ELENA KOROLEVA	{"email": "koroleva.elena_12011972@postgrespro.ru", "phone": "+70698298410"}
0005432020200	3490B1	4248 850555	ILDAR IVANOV	{"phone": "+70949135983"}
0005432020201	CA9318	5017 383901	NATALYA POTAPOVA	{"phone": "+70115777435"}
0005432020202	201222	0972 761710	ANTONINA DENISOVA	{"email": "denisova_a.1974@postgrespro.ru", "phone": "+70824485288"}
0005432020203	56FCD5	7272 463654	IRINA CHERNOVA	{"email": "irinachernova-30101968@postgrespro.ru", "phone": "+70174257492"}
0005432020204	9588B4	8655 684112	MARIYA KAZAKOVA	{"email": "kazakova_m.03021963@postgrespro.ru", "phone": "+70584214679"}
0005432020205	9588B4	0676 747911	IRINA MIKHAYLOVA	{"email": "irinamikhaylova22041965@postgrespro.ru", "phone": "+70028185086"}
0005432020206	D6459D	3655 411358	ELENA KUZNECOVA	{"email": "elena_kuznecova1964@postgrespro.ru", "phone": "+70544625428"}
0005432020207	D6459D	8867 251030	ARTEM KARPOV	{"phone": "+70182609834"}
0005432020208	DB21DC	7425 891257	VIKTOR MAKAROV	{"phone": "+70946519819"}
0005432020209	DB21DC	0240 035511	MAKSIM PAVLOV	{"email": "mpavlov_101961@postgrespro.ru", "phone": "+70464302175"}
0005432020210	06C50F	6025 141656	VALENTINA CHERNOVA	{"phone": "+70543324499"}
0005432020211	D04DD5	2368 314565	GENNADIY IVANOV	{"phone": "+70704171980"}
0005432020212	DDD384	0236 149814	IVAN SIDOROV	{"phone": "+70388926062"}
0005432020213	3DDBD2	8447 545295	TATYANA BORISOVA	{"email": "borisova-tatyana.1973@postgrespro.ru", "phone": "+70685939260"}
0005432020214	0459F9	0519 979213	DENIS BORISOV	{"email": "denisborisov.1975@postgrespro.ru", "phone": "+70087705246"}
0005432020215	0459F9	8442 244759	VLADIMIR POPOV	{"phone": "+70198659254"}
0005432020216	BC03C6	9258 956741	ALEKSANDR ALEKSANDROV	{"phone": "+70291013549"}
0005432020217	BC03C6	6222 142824	GALINA KONDRATEVA	{"phone": "+70928420884"}
0005432020218	2B6AD6	0197 026082	LARISA TIMOFEEVA	{"email": "l_timofeeva_111974@postgrespro.ru", "phone": "+70184175384"}
0005432020220	869300	7057 214030	ALEKSANDR KAZAKOV	{"phone": "+70945153087"}
0005432020221	869300	2058 486208	ELENA GORBUNOVA	{"email": "gorbunovae.30041964@postgrespro.ru", "phone": "+70820406881"}
0005432020222	391F7B	1169 698417	PELAGEYA NESTEROVA	{"email": "nesterova-pelageya-06011981@postgrespro.ru", "phone": "+70347841541"}
0005432020223	B5808D	8387 220093	VALENTINA KOROLEVA	{"email": "koroleva.valentina1983@postgrespro.ru", "phone": "+70189647768"}
0005432020224	E317DF	5761 668920	ELIZAVETA VASILEVA	{"phone": "+70942873621"}
0005432020225	F173A6	5715 670770	SERGEY TARASOV	{"phone": "+70701771466"}
0005432020226	F5718A	4517 023684	ALIYA DMITRIEVA	{"email": "dmitrieva-a1961@postgrespro.ru", "phone": "+70481548200"}
0005432020227	8B0D91	9464 089822	ANNA FILATOVA	{"email": "anna-filatova-26071970@postgrespro.ru", "phone": "+70704803242"}
0005432020228	3B2DA9	4200 705817	YURIY ABRAMOV	{"email": "abramovyuriy.1969@postgrespro.ru", "phone": "+70259693738"}
0005432020229	EE065D	6223 109767	EVGENIYA BELOVA	{"email": "belova-e_041965@postgrespro.ru", "phone": "+70921350661"}
0005432020230	EE3310	4885 799571	SERGEY KOZLOV	{"phone": "+70803054621"}
0005432020231	375BA3	7031 334879	VERA MAKSIMOVA	{"phone": "+70054109535"}
0005432020232	375BA3	3829 379157	ALEKSEY NIKITIN	{"email": "nikitina01051974@postgrespro.ru", "phone": "+70576069217"}
0005432020233	F93E69	3156 999571	ELIZAVETA ZHUKOVA	{"phone": "+70586167989"}
0005432020234	F93E69	6855 749754	SVETLANA POTAPOVA	{"email": "svetlana_potapova-111972@postgrespro.ru", "phone": "+70143222280"}
0005432020235	6C9AFC	8908 784714	TALGAT SCHERBAKOV	{"phone": "+70498702420"}
0005432020236	9F321F	8434 863172	TATYANA FILATOVA	{"email": "t_filatova1972@postgrespro.ru", "phone": "+70754006420"}
0005432020237	BAB584	7198 028336	ANDREY VOLKOV	{"email": "a.volkov061983@postgrespro.ru", "phone": "+70971554548"}
0005432020238	282AAD	6720 510235	ROMAN ABRAMOV	{"email": "r_abramov011976@postgrespro.ru", "phone": "+70669339764"}
0005432020239	3B51A0	1874 426960	SERGEY TIMOFEEV	{"phone": "+70707890872"}
0005432020240	E6F84B	9417 356242	PAVEL STEPANOV	{"phone": "+70810884545"}
0005432020241	B5484F	2091 349120	ELENA BELOVA	{"phone": "+70001008752"}
0005432020242	58BC55	9134 293325	VALENTINA FILATOVA	{"phone": "+70104577620"}
0005432020243	5E5168	4996 493193	YURIY ANTONOV	{"email": "antonov_y.121975@postgrespro.ru", "phone": "+70552784364"}
0005432020244	5E5168	6386 376097	ANATOLIY ILIN	{"email": "ailin.101973@postgrespro.ru", "phone": "+70301561123"}
0005432020245	E72879	1534 819690	PETR MAKAROV	{"email": "makarov_petr-20091967@postgrespro.ru", "phone": "+70327023391"}
0005432020246	A19EE3	1928 519640	ROMAN SOLOVEV	{"phone": "+70884885797"}
0005432020247	A19EE3	8641 241822	EGOR VOLKOV	{"phone": "+70360307031"}
0005432020248	914F03	6291 331352	VALENTINA NESTEROVA	{"email": "valentinanesterova011967@postgrespro.ru", "phone": "+70766639862"}
0005432020249	FB863D	0589 524640	SVETLANA SOROKINA	{"email": "s.sorokina_1967@postgrespro.ru", "phone": "+70560438593"}
0005432020250	4A23E1	6288 341039	ALEKSEY IVANOV	{"email": "ivanovaleksey-18101975@postgrespro.ru", "phone": "+70714795175"}
0005432020251	4A23E1	7041 058520	VALENTINA SERGEEVA	{"email": "sergeeva-valentina14091972@postgrespro.ru", "phone": "+70993037059"}
0005432020252	3402C6	8106 263488	VALERIY FILIPPOV	{"phone": "+70630935581"}
0005432020253	3402C6	1435 355473	LIDIYA NESTEROVA	{"phone": "+70957701776"}
0005432020254	CEF832	2442 360433	VIKTOR ANTONOV	{"phone": "+70643778780"}
0005432020255	9AC807	6887 199544	YULIYA SOROKINA	{"email": "yuliya.sorokina_1969@postgrespro.ru", "phone": "+70380157235"}
0005432020256	46C86C	8261 226452	NIKOLAY MELNIKOV	{"email": "melnikov.n-1977@postgrespro.ru", "phone": "+70414570744"}
0005432020257	F1FCB5	4333 871217	LEV GRIGOREV	{"phone": "+70597249899"}
0005432020258	EA77D1	3633 599712	YULIYA KUZMINA	{"email": "y_kuzmina20071975@postgrespro.ru", "phone": "+70122954844"}
0005432020259	80839B	7605 920950	NELLI POPOVA	{"email": "popova-nelli.1971@postgrespro.ru", "phone": "+70344717351"}
0005432020260	12A7DB	3674 658106	STANISLAV KARPOV	{"phone": "+70292231035"}
0005432020261	12A7DB	8471 308089	ELENA NIKOLAEVA	{"phone": "+70390635889"}
0005432020262	D880E0	4906 226338	OLGA ARKHIPOVA	{"email": "arkhipova.olga-1970@postgrespro.ru", "phone": "+70840598241"}
0005432020263	D0351C	7027 506392	PAVEL KUZMIN	{"email": "kuzmin.pavel051953@postgrespro.ru", "phone": "+70245301006"}
0005432020264	5F2C58	5719 829207	OKSANA TARASOVA	{"phone": "+70330874560"}
0005432020265	3B955C	8591 994184	TATYANA RODIONOVA	{"phone": "+70234072415"}
0005432020266	3B955C	6417 170867	DARYA MOROZOVA	{"phone": "+70667704581"}
0005432020267	E78CA4	6190 294119	ANASTASIYA PETROVA	{"email": "petrova-a.1979@postgrespro.ru", "phone": "+70297334895"}
0005432020268	A94E0B	5454 970323	IGOR PETROV	{"phone": "+70190622451"}
0005432020269	A94E0B	2632 140082	VLADIMIR KUZNECOV	{"phone": "+70671355051"}
0005432020270	E1B7B6	2672 235543	NATALYA FROLOVA	{"phone": "+70143559394"}
0005432020271	EAB7CA	6999 422261	DMITRIY FROLOV	{"phone": "+70878157368"}
0005432020272	59508B	0773 085554	ALEKSANDR KUZNECOV	{"phone": "+70826339730"}
0005432020273	CA7383	3990 199805	ELENA LOGINOVA	{"email": "loginova-e-081965@postgrespro.ru", "phone": "+70930681547"}
0005432020274	3ED8A3	1619 977934	TATYANA KONDRATEVA	{"email": "kondratevatatyana_24091969@postgrespro.ru", "phone": "+70083636606"}
0005432020275	3ED8A3	8030 582769	TATYANA MOROZOVA	{"email": "morozovatatyana_1970@postgrespro.ru", "phone": "+70188672952"}
0005432020276	8EA42B	7785 632369	NIKOLAY EGOROV	{"email": "egorov-nikolay1976@postgrespro.ru", "phone": "+70318232789"}
0005432020277	D8CEAC	3716 184412	IRINA KOZLOVA	{"phone": "+70114598428"}
0005432020278	F9F90A	2515 232261	SVETLANA BELOVA	{"email": "belova-s1972@postgrespro.ru", "phone": "+70283592302"}
0005432020279	B31E0B	4577 268187	FEDOR EGOROV	{"email": "egorov-fedor_011971@postgrespro.ru", "phone": "+70473286422"}
0005432020280	3FF7BE	2958 425228	TAMARA ARKHIPOVA	{"phone": "+70405363049"}
0005432020281	44C156	9190 702791	KLARA LOGINOVA	{"phone": "+70827799398"}
0005432020282	7817E5	0901 263528	KSENIYA ILINA	{"phone": "+70630953104"}
0005432020283	1E29EA	8335 718585	NINA ORLOVA	{"phone": "+70428643795"}
0005432020284	1E29EA	3551 517786	SERGEY ROMANOV	{"phone": "+70596699295"}
0005432020285	296896	5108 095166	ANATOLIY ANTONOV	{"email": "antonovanatoliy_1970@postgrespro.ru", "phone": "+70000341106"}
0005432020286	CAD06E	1493 681893	MIKHAIL MIKHAYLOV	{"phone": "+70128628732"}
0005432020287	32CE61	0361 301531	DIANA SEMENOVA	{"phone": "+70742935386"}
0005432020288	32CE61	9112 336373	ALEKSANDR OSIPOV	{"email": "osipov-a101971@postgrespro.ru", "phone": "+70020530238"}
0005432020289	32CE61	7997 325574	OLESYA YAKOVLEVA	{"phone": "+70958394038"}
0005432020290	D92ACD	6804 635825	GALINA KONOVALOVA	{"email": "konovalovag25091973@postgrespro.ru", "phone": "+70900860509"}
0005432020291	D92ACD	0590 944163	IGOR KUZNECOV	{"email": "i-kuznecov10031972@postgrespro.ru", "phone": "+70425742008"}
0005432020292	6B0DA3	5734 110981	VYACHESLAV KUZNECOV	{"email": "kuznecov_v_1968@postgrespro.ru", "phone": "+70069779167"}
0005432020293	D27783	6975 628194	FEDOR EGOROV	{"email": "fegorov_061952@postgrespro.ru", "phone": "+70886027831"}
0005432020294	D27783	2920 332329	IRINA MASLOVA	{"phone": "+70117132447"}
0005432020295	0C1367	6850 149266	ALEKSEY KUZNECOV	{"phone": "+70202048969"}
0005432020296	30DB27	6319 716574	ROMAN BORISOV	{"phone": "+70336967868"}
0005432020297	BB3585	7582 074032	ANDREY MOISEEV	{"email": "andrey-moiseev.1968@postgrespro.ru", "phone": "+70787065357"}
0005432020298	D6FC59	6108 673614	SERGEY ROMANOV	{"phone": "+70783023809"}
0005432020299	D9BBE1	1208 148548	ELENA FROLOVA	{"email": "efrolova.1980@postgrespro.ru", "phone": "+70424828924"}
0005432020300	968C4C	2841 876147	TATYANA NIKITINA	{"email": "nikitina_tatyana-26081982@postgrespro.ru", "phone": "+70202571155"}
0005432020301	F3943B	7904 828282	VIKTOR NAUMOV	{"phone": "+70904241558"}
0005432020302	0F22F3	0411 353579	MARIYA KUZNECOVA	{"email": "kuznecova-m_04061978@postgrespro.ru", "phone": "+70937455095"}
0005432020303	0F22F3	9609 676856	GALINA TITOVA	{"email": "g-titova-14071971@postgrespro.ru", "phone": "+70939655355"}
0005432020304	F5C81C	7257 672943	OLEG IVANOV	{"email": "oleg-ivanov_1984@postgrespro.ru", "phone": "+70632852802"}
0005432020305	60E8CE	6678 918767	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov_1972@postgrespro.ru", "phone": "+70958865099"}
0005432020306	1919B0	9530 736761	OKSANA STEPANOVA	{"phone": "+70018723026"}
0005432020307	1919B0	6280 259402	VLADIMIR ALEKSEEV	{"phone": "+70314140655"}
0005432020308	1CB956	0298 956477	TATYANA KUDRYASHOVA	{"email": "kudryashovat.071966@postgrespro.ru", "phone": "+70811253111"}
0005432020309	ED33C3	6305 100889	FEDOR MELNIKOV	{"phone": "+70166706392"}
0005432020310	ED33C3	8957 482329	VLADIMIR SMIRNOV	{"phone": "+70231351346"}
0005432020311	ED33C3	4708 511932	YULIYA SMIRNOVA	{"email": "smirnova.yuliya-1978@postgrespro.ru", "phone": "+70768524400"}
0005432020312	80D313	3978 772653	TAMARA ANTONOVA	{"phone": "+70294166489"}
0005432020313	9598F5	0789 055597	YURIY KULIKOV	{"phone": "+70202420212"}
0005432020314	9598F5	8184 884301	ALEKSEY ORLOV	{"phone": "+70580292987"}
0005432020315	6279F1	1231 609293	VLADIMIR TIKHONOV	{"phone": "+70051570448"}
0005432020316	6279F1	6768 032736	EKATERINA NOVIKOVA	{"email": "novikova_e29011966@postgrespro.ru", "phone": "+70315869675"}
0005432020317	BC8018	6836 419587	LYUBOV NOVIKOVA	{"email": "lyubov.novikova.021971@postgrespro.ru", "phone": "+70776236926"}
0005432020318	BC8018	4424 804232	NIKITA VASILEV	{"email": "n-vasilev.051978@postgrespro.ru", "phone": "+70125243062"}
0005432020319	9A042D	4475 243304	MIKHAIL ZAKHAROV	{"phone": "+70552289914"}
0005432020320	9A042D	7823 721705	YULIYA KRASNOVA	{"email": "krasnova_yuliya1981@postgrespro.ru", "phone": "+70214968633"}
0005432020321	2B817F	6820 420751	TAMARA KARPOVA	{"email": "karpova.t_1982@postgrespro.ru", "phone": "+70483231491"}
0005432020322	2B817F	6511 718328	VLADIMIR MEDVEDEV	{"phone": "+70939956361"}
0005432020323	100B41	1372 388024	ANDREY DENISOV	{"email": "denisov-andrey_19011981@postgrespro.ru", "phone": "+70213606464"}
0005432020324	100B41	2876 998624	VALENTINA ANTONOVA	{"email": "valentina_antonova1963@postgrespro.ru", "phone": "+70494028641"}
0005432020325	100B41	3841 582880	NINA KONDRATEVA	{"email": "kondrateva.nina.041966@postgrespro.ru", "phone": "+70446822201"}
0005432020326	47B2B7	2633 865425	RAMZIYA FADEEVA	{"phone": "+70779405304"}
0005432020327	E0FE65	7184 631153	DMITRIY FILIPPOV	{"email": "filippov_d_1967@postgrespro.ru", "phone": "+70043039329"}
0005432020328	E0FE65	9023 477765	RIMMA TROFIMOVA	{"email": "trofimova.rimma.081969@postgrespro.ru", "phone": "+70140702335"}
0005432020329	65B6E2	2295 468296	MARINA DAVYDOVA	{"phone": "+70897095360"}
0005432020330	E78605	3871 762926	GALINA DAVYDOVA	{"phone": "+70287128082"}
0005432020331	3F23A2	5551 628545	DMITRIY ZHURAVLEV	{"email": "dzhuravlev.101968@postgrespro.ru", "phone": "+70410343919"}
0005432020332	3F23A2	4914 421459	KRISTINA EFREMOVA	{"email": "efremova-kristina1971@postgrespro.ru", "phone": "+70287168579"}
0005432020333	3F23A2	3968 166441	IRINA KOROLEVA	{"email": "koroleva-i-111983@postgrespro.ru", "phone": "+70610825906"}
0005432020334	48242F	8286 800938	GALINA POTAPOVA	{"email": "galina.potapova_1968@postgrespro.ru", "phone": "+70309161520"}
0005432020335	FA6D16	8708 637735	ALEKSANDR EGOROV	{"phone": "+70246077180"}
0005432020336	FA6D16	9387 836350	KSENIYA KUZNECOVA	{"email": "kseniyakuznecova.031971@postgrespro.ru", "phone": "+70535652543"}
0005432020337	D59010	1081 621860	FAIL VOROBEV	{"email": "f_vorobev.081965@postgrespro.ru", "phone": "+70986137417"}
0005432020338	D59010	7499 554761	ARMEN FROLOV	{"email": "frolova_12071970@postgrespro.ru", "phone": "+70671607100"}
0005432020339	AF008F	3268 743712	NADEZHDA KUZMINA	{"phone": "+70634235575"}
0005432020340	14CFC0	5525 380958	NINA BELOVA	{"phone": "+70740792522"}
0005432020341	4F2B34	0299 880974	OLGA ABRAMOVA	{"phone": "+70936522283"}
0005432020342	DA80C5	6585 256856	MIKHAIL POPOV	{"phone": "+70217768906"}
0005432020343	0A1D52	5578 940969	ANATOLIY CHERNOV	{"email": "chernov-a071973@postgrespro.ru", "phone": "+70381442134"}
0005432020344	0A1D52	7142 263531	SABINA KRASNOVA	{"phone": "+70477556712"}
0005432020345	8FCF47	7563 324988	PAVEL ANDREEV	{"email": "p_andreev-20091976@postgrespro.ru", "phone": "+70473802412"}
0005432020346	8FCF47	2819 910786	ZOYA FROLOVA	{"phone": "+70780936853"}
0005432020347	862FB5	1249 056409	IVAN STEPANOV	{"email": "stepanovi_24021969@postgrespro.ru", "phone": "+70070604540"}
0005432020348	A113BD	7464 532030	IVAN STEPANOV	{"phone": "+70228805653"}
0005432020349	A113BD	6128 059607	VALENTINA KARPOVA	{"phone": "+70194733784"}
0005432020350	85F4CE	7204 041801	ANATOLIY FOMIN	{"email": "anatoliyfomin-27011979@postgrespro.ru", "phone": "+70312445088"}
0005432020351	80FBDF	2161 926850	STANISLAV POPOV	{"phone": "+70845673162"}
0005432020352	80FBDF	3114 666856	STEPAN MATVEEV	{"email": "matveev.stepan30041984@postgrespro.ru", "phone": "+70703182351"}
0005432020353	BD4400	3113 415219	VIKTOR KUZNECOV	{"phone": "+70558602715"}
0005432020354	B44F15	9261 486167	OLGA VASILEVA	{"email": "vasileva-o1966@postgrespro.ru", "phone": "+70306413060"}
0005432020355	D00AA1	2227 261029	BULAT MOROZOV	{"phone": "+70315838532"}
0005432020356	D00AA1	4009 083329	SERGEY NOVIKOV	{"phone": "+70210047489"}
0005432020357	51C37D	2043 895432	ANATOLIY GAVRILOV	{"phone": "+70593952094"}
0005432020358	95334B	9950 118315	NATALYA MOROZOVA	{"email": "morozova-natalya_1965@postgrespro.ru", "phone": "+70980369849"}
0005432020359	95334B	6573 602319	OLESYA MIKHAYLOVA	{"phone": "+70801561527"}
0005432020360	119302	5102 719373	RUSLAN ORLOV	{"phone": "+70322208703"}
0005432020361	29649D	1588 975224	ILYA PAVLOV	{"phone": "+70483483262"}
0005432020362	86F4B3	8712 872792	YULIYA ZHUKOVA	{"phone": "+70330285572"}
0005432020363	5D11F9	3835 158619	SERGEY KULIKOV	{"email": "kulikov.s27021959@postgrespro.ru", "phone": "+70915514316"}
0005432020364	49CB67	4917 247615	VYACHESLAV KOROLEV	{"phone": "+70215697507"}
0005432020365	0D9382	5192 350680	VLADISLAV VOROBEV	{"phone": "+70673054406"}
0005432020366	8C4980	3940 937965	GENNADIY YAKOVLEV	{"email": "yakovlev.gennadiy28121983@postgrespro.ru", "phone": "+70077899012"}
0005432020367	8C4980	0205 595912	MAKSIM ZAKHAROV	{"phone": "+70087158408"}
0005432020368	0A578B	8922 059212	NATALYA NOVIKOVA	{"phone": "+70356134673"}
0005432020369	F2B0F0	8483 030596	ALEKSEY ALEKSANDROV	{"email": "aleksandrov.a.1972@postgrespro.ru", "phone": "+70332333642"}
0005432020370	F2B0F0	5182 042392	RAVIL GAVRILOV	{"phone": "+70843021686"}
0005432020371	6BABEC	0685 665634	ANNA KOROLEVA	{"email": "a-koroleva-031970@postgrespro.ru", "phone": "+70591437436"}
0005432020372	E823FE	1437 899143	GALINA ZOTOVA	{"phone": "+70655946133"}
0005432020373	160EAB	5909 331177	ANNA SIDOROVA	{"phone": "+70872291814"}
0005432020374	302A65	2760 303493	ZOYA MAKAROVA	{"phone": "+70215373903"}
0005432020375	5DF5B7	9981 508655	EKATERINA SIDOROVA	{"phone": "+70099497591"}
0005432020376	5DF5B7	6021 564660	VALENTINA SERGEEVA	{"phone": "+70645134537"}
0005432020377	5DF5B7	7904 942931	ALEKSANDR GAVRILOV	{"email": "gavrilov-a-30121967@postgrespro.ru", "phone": "+70661470896"}
0005432020378	4F90A8	1886 059934	ANASTASIYA FILATOVA	{"email": "anastasiya-filatova_1974@postgrespro.ru", "phone": "+70749385145"}
0005432020379	A1FD53	1413 463065	ANASTASIYA IVANOVA	{"email": "ivanova-anastasiya.17111969@postgrespro.ru", "phone": "+70670762387"}
0005432020380	A1FD53	2103 239213	EVGENIY ABRAMOV	{"phone": "+70053021450"}
0005432020381	9B64EB	5977 752312	VALERIYA BELOVA	{"phone": "+70337398258"}
0005432020382	F2B53E	6809 120142	VALENTINA MAKAROVA	{"email": "vmakarova.23081962@postgrespro.ru", "phone": "+70243251886"}
0005432020383	F2B53E	1450 833738	MARIYA ERMAKOVA	{"phone": "+70296435115"}
0005432020384	18EA0F	5041 081982	ALENA ALEKSANDROVA	{"email": "aleksandrova-a_01051981@postgrespro.ru", "phone": "+70750415015"}
0005432020385	BF3ED0	6933 555726	GALINA POTAPOVA	{"email": "galina_potapova-06021966@postgrespro.ru", "phone": "+70528325436"}
0005432020386	867976	2367 383441	IVAN SAVELEV	{"email": "savelev.i_1978@postgrespro.ru", "phone": "+70871778663"}
0005432020387	F7DC09	8701 348836	DANIIL POPOV	{"phone": "+70038061619"}
0005432020388	F7DC09	8224 274359	SVETLANA ZAYCEVA	{"phone": "+70898666475"}
0005432020389	1AF68D	1648 880974	NINA ISAEVA	{"email": "isaeva_n-051975@postgrespro.ru", "phone": "+70857804128"}
0005432020390	1AF68D	6443 745609	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakovaaleksandra.1966@postgrespro.ru", "phone": "+70735332522"}
0005432020391	1AF68D	0741 631973	NINA ORLOVA	{"email": "orlova_nina.101967@postgrespro.ru", "phone": "+70463188826"}
0005432020392	1BE604	4792 474847	VIKTOR KUZNECOV	{"email": "kuznecov.v_14071981@postgrespro.ru", "phone": "+70832426080"}
0005432020393	3E3068	8277 983588	ELENA LAZAREVA	{"email": "lazarevaelena_1980@postgrespro.ru", "phone": "+70789596112"}
0005432020394	36E83A	1836 519966	IRINA KUZMINA	{"email": "i.kuzmina-08041965@postgrespro.ru", "phone": "+70531441781"}
0005432020395	8EA0EB	8728 836417	MARIYA MAKAROVA	{"email": "makarova_mariya.121966@postgrespro.ru", "phone": "+70084324143"}
0005432020396	8EA0EB	6082 248273	TATYANA BELYAEVA	{"email": "tbelyaeva_111976@postgrespro.ru", "phone": "+70401350952"}
0005432020397	FB002C	9508 941862	ANNA POTAPOVA	{"phone": "+70873919050"}
0005432020398	FB002C	5000 791005	ANASTASIYA DENISOVA	{"phone": "+70706780177"}
0005432020399	FB002C	5855 737212	IRINA TIMOFEEVA	{"phone": "+70213288455"}
0005432020400	64E6E1	2780 333481	ELENA MAKAROVA	{"phone": "+70387541116"}
0005432020401	96673A	2566 050787	VERA ZAYCEVA	{"email": "zayceva-v-1979@postgrespro.ru", "phone": "+70550057597"}
0005432020402	0D811B	9836 178607	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov_20051969@postgrespro.ru", "phone": "+70913615847"}
0005432020403	0D811B	6135 889074	SVETLANA ALEKSEEVA	{"phone": "+70632391876"}
0005432020404	10315F	7723 994506	DMITRIY PETROV	{"email": "dmitriy.petrov-1977@postgrespro.ru", "phone": "+70329546018"}
0005432020405	A3C0A3	6949 593355	YURIY TARASOV	{"phone": "+70531631668"}
0005432020406	5FF6B8	3413 356731	ELENA POTAPOVA	{"phone": "+70383265873"}
0005432020407	76A6BB	7679 660591	VLADIMIR DMITRIEV	{"phone": "+70570259070"}
0005432020408	76A6BB	4382 003770	ANATOLIY VASILEV	{"phone": "+70150952809"}
0005432020409	96E06C	8321 573773	NATALYA OSIPOVA	{"phone": "+70641203186"}
0005432020410	86DCAE	2631 524831	KSENIYA SOLOVEVA	{"email": "solovevak_27121968@postgrespro.ru", "phone": "+70757587006"}
0005432020411	0A0A13	0148 742947	RAVILYA POPOVA	{"phone": "+70426718005"}
0005432020412	E63308	4188 287098	IGOR KUZNECOV	{"phone": "+70928320172"}
0005432020413	E63308	4859 375416	DANIIL POPOV	{"phone": "+70450392840"}
0005432020414	A93010	8007 625427	ZINAIDA MATVEEVA	{"email": "matveeva.z-1970@postgrespro.ru", "phone": "+70246162137"}
0005432020415	E4630F	9328 271860	MIKHAIL ANDREEV	{"phone": "+70570128667"}
0005432020416	DA2EA4	9943 712354	LARISA EGOROVA	{"email": "egorova_l.061974@postgrespro.ru", "phone": "+70407246948"}
0005432020417	66EE50	7550 301182	VLADISLAV KRASNOV	{"phone": "+70558345770"}
0005432020418	261358	4185 520720	SERGEY BARANOV	{"email": "baranov_sergey02041966@postgrespro.ru", "phone": "+70410406065"}
0005432020419	B233C1	5610 375327	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova-lyudmila-1972@postgrespro.ru", "phone": "+70787241543"}
0005432020897	BDFCAA	8022 443019	ZINAIDA SEMENOVA	{"phone": "+70254966741"}
0005432020420	61A6CC	7660 586672	LYUDMILA RODIONOVA	{"email": "lyudmila_rodionova-111964@postgrespro.ru", "phone": "+70329724881"}
0005432020421	61A6CC	6310 709932	TATYANA SCHERBAKOVA	{"phone": "+70805252050"}
0005432020422	0CD30A	4232 698449	NATALYA SOROKINA	{"phone": "+70412734367"}
0005432020423	D0DA58	1831 481459	MIKHAIL NIKITIN	{"email": "nikitinm.20121968@postgrespro.ru", "phone": "+70011232046"}
0005432020424	349E20	7681 706180	NATALYA AFANASEVA	{"phone": "+70683715256"}
0005432020425	0406BA	8421 075054	NATALYA EGOROVA	{"phone": "+70274523709"}
0005432020426	71F03A	3717 375323	GALINA CHERNOVA	{"phone": "+70453492624"}
0005432020427	FBD6A4	8045 900503	TAISIYA AKIMOVA	{"email": "akimova-t.111980@postgrespro.ru", "phone": "+70728570745"}
0005432020428	5C9EC0	7414 183214	IRINA KISELEVA	{"email": "irina.kiseleva.04111970@postgrespro.ru", "phone": "+70800225699"}
0005432020429	637F8B	1219 062185	SERGEY SAVELEV	{"email": "s_savelev.011984@postgrespro.ru", "phone": "+70711052825"}
0005432020430	637F8B	2434 385116	LYUDMILA MASLOVA	{"phone": "+70202888385"}
0005432020431	D35197	5905 350210	OLGA VASILEVA	{"phone": "+70240308580"}
0005432020432	D35197	9190 012513	MARINA TITOVA	{"phone": "+70497227521"}
0005432020433	AF28FB	4512 120801	VALENTINA OSIPOVA	{"phone": "+70798984054"}
0005432020434	AF28FB	0732 371727	YULIYA FROLOVA	{"email": "yfrolova_14071986@postgrespro.ru", "phone": "+70219819117"}
0005432020435	5B72B1	8698 519606	ANDREY FROLOV	{"phone": "+70110441474"}
0005432020436	960846	9125 216687	VLADIMIR DENISOV	{"email": "vdenisov-03031981@postgrespro.ru", "phone": "+70023108674"}
0005432020437	960846	2537 017137	VERA KOZLOVA	{"phone": "+70109878352"}
0005432020438	F6665B	9610 088319	VLADIMIR STEPANOV	{"phone": "+70401068114"}
0005432020439	B1BA6A	7692 600244	LIDIYA ABRAMOVA	{"email": "abramova.l_16021984@postgrespro.ru", "phone": "+70919436835"}
0005432020440	A6F9EE	0345 411294	ELENA PETROVA	{"email": "epetrova_17031977@postgrespro.ru", "phone": "+70788241251"}
0005432020441	A6F9EE	2903 128531	NATALYA SAVELEVA	{"email": "saveleva-n-1970@postgrespro.ru", "phone": "+70357258763"}
0005432020442	E0FA01	2692 319886	IRINA ILINA	{"phone": "+70284379037"}
0005432020443	B3418F	6836 604004	EVGENIY STEPANOV	{"phone": "+70571437822"}
0005432020444	51A508	0981 285798	GYUZEL ALEKSANDROVA	{"email": "gyuzelaleksandrova121981@postgrespro.ru", "phone": "+70792506780"}
0005432020445	954621	7287 916380	IRINA NESTEROVA	{"email": "nesterova_irina091988@postgrespro.ru", "phone": "+70273184394"}
0005432020446	B5BC1D	6386 468468	GENNADIY KAZAKOV	{"email": "kazakov_gennadiy-01121974@postgrespro.ru", "phone": "+70763127962"}
0005432020447	B5BC1D	7097 493879	EKATERINA KOZLOVA	{"email": "kozlova-e-09011968@postgrespro.ru", "phone": "+70592152762"}
0005432020448	B5BC1D	4185 006132	ELENA ZOTOVA	{"phone": "+70366919954"}
0005432020449	53576C	0836 899158	IGOR SERGEEV	{"email": "igorsergeev24061971@postgrespro.ru", "phone": "+70626284092"}
0005432020450	FCBBCE	6815 833605	MIKHAIL NIKOLAEV	{"phone": "+70724581822"}
0005432020451	0ABEF6	9173 702501	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e_1964@postgrespro.ru", "phone": "+70145246868"}
0005432020452	434E02	7408 983259	ANNA TIKHONOVA	{"email": "tikhonova_anna.091975@postgrespro.ru", "phone": "+70145155418"}
0005432020453	E9922E	6058 308918	GEORGIY ALEKSANDROV	{"email": "g_aleksandrov-01081973@postgrespro.ru", "phone": "+70392156214"}
0005432020454	837782	3823 656038	DMITRIY MAKAROV	{"phone": "+70917639856"}
0005432020455	0BDC55	8689 799872	VALENTINA AFANASEVA	{"email": "afanaseva-valentina-101965@postgrespro.ru", "phone": "+70000015770"}
0005432020456	8B5B75	8991 305285	OLGA MEDVEDEVA	{"email": "medvedeva.olga.31051963@postgrespro.ru", "phone": "+70433767107"}
0005432020457	24EE42	6715 865502	IVAN MAKAROV	{"phone": "+70782866929"}
0005432020458	33D4FB	2818 202427	MAKSIM MIRONOV	{"email": "maksimmironov-23021985@postgrespro.ru", "phone": "+70097183997"}
0005432020459	D9B423	4049 450404	NIKITA ALEKSEEV	{"phone": "+70663014880"}
0005432020460	8D113E	2625 035601	TATYANA ZOTOVA	{"phone": "+70248112620"}
0005432020461	88F0B2	9789 447376	ALEKSANDR FILIPPOV	{"email": "a.filippov.16111972@postgrespro.ru", "phone": "+70484754085"}
0005432020462	DA5200	2301 016853	ALEKSANDR GUSEV	{"phone": "+70919369881"}
0005432020463	4988E0	5908 296669	MAKSIM ZHUKOV	{"phone": "+70826888336"}
0005432020464	70E761	8990 373611	VLADIMIR MAKSIMOV	{"email": "maksimov-vladimir.17041982@postgrespro.ru", "phone": "+70156533650"}
0005432020465	895FA2	3736 281122	EKATERINA VOLKOVA	{"email": "volkovaekaterina_071979@postgrespro.ru", "phone": "+70981679750"}
0005432020466	7AE3D0	4696 804171	ALEKSANDR SMIRNOV	{"phone": "+70619998285"}
0005432020467	925548	3331 891012	LYUBOV SAVELEVA	{"email": "saveleva.lyubov.10121972@postgrespro.ru", "phone": "+70721345848"}
0005432020468	925548	2767 689624	SERGEY BORISOV	{"phone": "+70685570385"}
0005432020469	549D7C	3313 113024	OLEG IVANOV	{"phone": "+70765889590"}
0005432020470	549D7C	1907 085042	TATYANA MASLOVA	{"email": "tatyana.maslova.091973@postgrespro.ru", "phone": "+70928942797"}
0005432020471	42A541	0111 432889	OLGA STEPANOVA	{"email": "o.stepanova_1963@postgrespro.ru", "phone": "+70454259586"}
0005432020472	497165	1299 067983	NATALYA LOGINOVA	{"phone": "+70090007487"}
0005432020473	49CC76	6074 934663	VLADIMIR MEDVEDEV	{"phone": "+70504337853"}
0005432020474	968EC6	1776 072362	NATALYA GORBUNOVA	{"email": "natalya.gorbunova.1966@postgrespro.ru", "phone": "+70950346455"}
0005432020475	505B7A	4250 211704	IRINA SERGEEVA	{"email": "irinasergeeva29031973@postgrespro.ru", "phone": "+70053206356"}
0005432020476	59E8C4	3784 937499	IGOR KRASNOV	{"phone": "+70694947894"}
0005432020477	279016	0067 651480	VALENTINA NIKITINA	{"email": "nikitinavalentina_21071978@postgrespro.ru", "phone": "+70599407096"}
0005432020478	5E023E	6008 263358	VIKTOR GAVRILOV	{"email": "gavrilovviktor_1973@postgrespro.ru", "phone": "+70594027456"}
0005432020958	122E59	5947 891093	ARTEM FOMIN	{"phone": "+70865056737"}
0005432020479	A53C18	4647 861591	ZINAIDA NAZAROVA	{"email": "nazarova_z.1970@postgrespro.ru", "phone": "+70857637845"}
0005432020480	A53C18	6514 415832	VLADIMIR GAVRILOV	{"phone": "+70813847144"}
0005432020481	5E40F3	3893 683867	ANDREY NIKITIN	{"email": "andrey-nikitin_1971@postgrespro.ru", "phone": "+70502830520"}
0005432020482	5E40F3	1624 104178	VLADIMIR YAKOVLEV	{"email": "vladimir-yakovlev_13091982@postgrespro.ru", "phone": "+70547998561"}
0005432020483	FC9508	3028 655310	VITALIY MARTYNOV	{"email": "martynovv-24081968@postgrespro.ru", "phone": "+70267374305"}
0005432020484	108DC3	1533 979411	TAMARA KOROLEVA	{"phone": "+70818273003"}
0005432020485	108DC3	8871 843521	ALEKSEY NAZAROV	{"phone": "+70183262985"}
0005432020486	AB199F	3334 672951	VIKTORIYA ANDREEVA	{"phone": "+70719637878"}
0005432020487	AB199F	1467 038330	NIKOLAY KULIKOV	{"email": "n-kulikov-05051971@postgrespro.ru", "phone": "+70884863267"}
0005432020488	0BA7CE	0676 657426	ILYA KUZNECOV	{"phone": "+70361035864"}
0005432020489	314EA8	0765 741324	ZINAIDA LOGINOVA	{"email": "loginova_z.081965@postgrespro.ru", "phone": "+70204460290"}
0005432020490	9DBAF2	6643 738115	ELENA SIDOROVA	{"phone": "+70922333728"}
0005432020491	10221E	1316 124226	ALEKSEY SEMENOV	{"phone": "+70845224769"}
0005432020492	10221E	7016 851609	DARYA OVCHINNIKOVA	{"email": "ovchinnikovad-10021964@postgrespro.ru", "phone": "+70246475394"}
0005432020493	122A2E	5764 039943	RUMIYA OSIPOVA	{"email": "osipova.rumiya_20061963@postgrespro.ru", "phone": "+70506474704"}
0005432020494	122A2E	5435 122249	SVETLANA PETROVA	{"email": "petrova-s_24061977@postgrespro.ru", "phone": "+70429325990"}
0005432020495	14D046	5780 079794	GALINA POPOVA	{"email": "galina-popova_03011971@postgrespro.ru", "phone": "+70501289412"}
0005432020496	8F9EEE	9550 723490	NADEZHDA EGOROVA	{"email": "egorovan.1983@postgrespro.ru", "phone": "+70939709118"}
0005432020497	A35A39	3540 893516	DANILA GUSEV	{"email": "d.gusev_081974@postgrespro.ru", "phone": "+70726637128"}
0005432020498	27C23C	5879 216566	SVETLANA ALEKSEEVA	{"email": "alekseeva-s_13051965@postgrespro.ru", "phone": "+70266247553"}
0005432020499	6C476E	4464 799409	LYUBOV VOLKOVA	{"phone": "+70440684751"}
0005432020500	F833C7	7449 036004	ELENA MASLOVA	{"email": "emaslova-02121980@postgrespro.ru", "phone": "+70413564183"}
0005432020501	F833C7	5849 938522	ELENA SOLOVEVA	{"phone": "+70150660818"}
0005432020502	097A9B	7914 111100	GALINA TIKHONOVA	{"email": "tikhonova_g-10101970@postgrespro.ru", "phone": "+70885267818"}
0005432020503	91978F	1762 565196	ALEKSANDRA NIKITINA	{"email": "nikitina_aleksandra.31101983@postgrespro.ru", "phone": "+70107580375"}
0005432020504	91978F	7979 246667	LYUDMILA ISAEVA	{"phone": "+70454231798"}
0005432020505	BDB7DC	6586 820491	RIMMA ROMANOVA	{"email": "romanova-r.111979@postgrespro.ru", "phone": "+70634923500"}
0005432020506	DAF5B3	5937 917162	ELENA KUZNECOVA	{"phone": "+70871163317"}
0005432020507	81239C	7165 679552	IRINA NOVIKOVA	{"phone": "+70619154459"}
0005432020508	5D1F99	0575 740696	ALEVTINA KOVALEVA	{"email": "kovalevaa10111976@postgrespro.ru", "phone": "+70224104642"}
0005432020509	B31668	9252 648177	ANATOLIY NOVIKOV	{"phone": "+70562609417"}
0005432020510	4DC153	2529 289518	DENIS KUZNECOV	{"email": "kuznecov-denis.1981@postgrespro.ru", "phone": "+70816708134"}
0005432020511	F458B6	3895 867385	TATYANA SMIRNOVA	{"email": "tatyana-smirnova-1962@postgrespro.ru", "phone": "+70957450548"}
0005432020512	A33BF4	2729 083200	PAVEL IVANOV	{"phone": "+70345420387"}
0005432020513	2D817A	1690 999296	LYUBOV LEBEDEVA	{"phone": "+70251111591"}
0005432020514	75B5FB	8682 722997	NINA DENISOVA	{"phone": "+70315539272"}
0005432020515	E021AD	0791 056131	ALEKSEY GORBUNOV	{"phone": "+70826567510"}
0005432020516	182566	5424 761483	YURIY SOROKIN	{"phone": "+70629924223"}
0005432020517	FFC058	2054 865543	ANDREY ISAEV	{"email": "isaev-a.031976@postgrespro.ru", "phone": "+70464675779"}
0005432020518	FFC058	0538 474195	ALEVTINA KUZMINA	{"phone": "+70854486106"}
0005432020519	C0A813	1606 114796	DANIIL MAKAROV	{"email": "makarov-d1980@postgrespro.ru", "phone": "+70361158556"}
0005432020520	C0A813	8635 968732	RAISA ISAEVA	{"email": "r-isaeva_07041960@postgrespro.ru", "phone": "+70482406249"}
0005432020521	7ED5A0	4124 408067	GALINA ORLOVA	{"phone": "+70249986647"}
0005432020522	7ED5A0	2501 311781	POLINA RYABOVA	{"phone": "+70032028583"}
0005432020523	3D56F6	3902 771938	VLADIMIR NIKOLAEV	{"phone": "+70475567573"}
0005432020524	5DE64D	8180 996846	SERGEY OSIPOV	{"email": "osipovs_121957@postgrespro.ru", "phone": "+70882935203"}
0005432020525	3D39F5	3642 387346	TATYANA MARTYNOVA	{"email": "t_martynova.23091969@postgrespro.ru", "phone": "+70734311480"}
0005432020526	312713	2693 026505	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-121978@postgrespro.ru", "phone": "+70208098362"}
0005432020527	312713	3563 853347	YULIYA POPOVA	{"email": "yuliya-popova.041973@postgrespro.ru", "phone": "+70481201760"}
0005432020528	B7F1C1	1523 823772	SERGEY TIKHONOV	{"phone": "+70550143896"}
0005432020529	D70BE6	1920 687080	RAMIL EGOROV	{"phone": "+70763494939"}
0005432020530	D70BE6	0047 149132	SERGEY FROLOV	{"email": "frolov-s.1962@postgrespro.ru", "phone": "+70661912774"}
0005432020531	FCEB8E	3350 365272	ELVIRA VASILEVA	{"phone": "+70586861533"}
0005432020532	51B187	8576 615467	MARINA NIKOLAEVA	{"phone": "+70926430499"}
0005432020533	51B187	1576 857461	VIKTOR YAKOVLEV	{"email": "vyakovlev-041984@postgrespro.ru", "phone": "+70859137406"}
0005432020534	463238	6262 442986	VLADIMIR SOROKIN	{"phone": "+70359413860"}
0005432020535	463238	2628 032149	VYACHESLAV IVANOV	{"email": "v_ivanov1964@postgrespro.ru", "phone": "+70377861874"}
0005432020536	C153DF	9695 177950	YURIY ZAKHAROV	{"email": "zakharovyuriy03041983@postgrespro.ru", "phone": "+70559303410"}
0005432020537	2AA1D1	6195 590319	OLGA EGOROVA	{"phone": "+70322398675"}
0005432020538	2AA1D1	4237 518326	SOFYA KUDRYASHOVA	{"phone": "+70899614043"}
0005432020959	829075	1828 463905	IVAN OSIPOV	{"phone": "+70140186966"}
0005432020539	F3DE12	7876 761852	LARISA SCHERBAKOVA	{"email": "larisa_scherbakova.1976@postgrespro.ru", "phone": "+70086977834"}
0005432020540	285B09	3130 239088	VLADIMIR TIMOFEEV	{"phone": "+70086796275"}
0005432020541	285B09	7305 511169	SERGEY BORISOV	{"email": "s_borisov.091972@postgrespro.ru", "phone": "+70151299567"}
0005432020542	EE0403	1198 117979	DMITRIY FILIPPOV	{"phone": "+70084492390"}
0005432020543	08FC63	7480 565743	ANDREY PETROV	{"phone": "+70903031179"}
0005432020544	63338A	0481 930115	ARTEM GUSEV	{"email": "artem_gusev_1964@postgrespro.ru", "phone": "+70562939557"}
0005432020545	63338A	8700 389208	NATALYA MAKSIMOVA	{"phone": "+70615792871"}
0005432020546	68468E	1601 883757	EKATERINA VASILEVA	{"email": "ekaterina-vasileva.06061985@postgrespro.ru", "phone": "+70913738926"}
0005432020547	68468E	6253 108128	YULIYA GERASIMOVA	{"email": "gerasimova_y-1981@postgrespro.ru", "phone": "+70020293502"}
0005432020548	475E82	7878 162992	TAMARA PETROVA	{"phone": "+70554382476"}
0005432020549	42C50C	4858 738893	GALINA POLYAKOVA	{"phone": "+70430072639"}
0005432020550	E69B7B	3631 979107	MARINA KRASNOVA	{"phone": "+70867127375"}
0005432020551	DC08CF	9384 986483	KONSTANTIN KOZLOV	{"phone": "+70109344054"}
0005432020552	C2949B	1237 887697	SERGEY NIKITIN	{"phone": "+70528356386"}
0005432020553	C2949B	7248 207192	ANTON SMIRNOV	{"email": "smirnova_13101972@postgrespro.ru", "phone": "+70814119069"}
0005432020554	1BA5BD	7913 109373	ALEKSANDR SMIRNOV	{"email": "smirnov_a-111974@postgrespro.ru", "phone": "+70327112822"}
0005432020555	DECD70	5446 241103	ANTON VLASOV	{"phone": "+70519749048"}
0005432020556	797277	5752 024014	TATYANA PETROVA	{"phone": "+70047349563"}
0005432020557	797277	0910 230656	FAINA FILIPPOVA	{"email": "filippova_faina.16111974@postgrespro.ru", "phone": "+70874351442"}
0005432020558	C958F5	3952 935811	DMITRIY GERASIMOV	{"email": "d.gerasimov.031978@postgrespro.ru", "phone": "+70878071052"}
0005432020559	5909F3	5977 906988	LYUDMILA KOLESNIKOVA	{"email": "kolesnikovalyudmila1985@postgrespro.ru", "phone": "+70814208199"}
0005432020560	DFA7A3	9662 532824	DMITRIY KOROLEV	{"email": "korolev_dmitriy-041969@postgrespro.ru", "phone": "+70134945067"}
0005432020561	6CD782	4680 612374	VLADIMIR MOISEEV	{"phone": "+70015979856"}
0005432020562	AE03C4	2073 922305	MARINA SERGEEVA	{"phone": "+70992545309"}
0005432020563	761437	4338 214089	MARINA SOROKINA	{"email": "marina-sorokina26121969@postgrespro.ru", "phone": "+70791057810"}
0005432020564	761437	8067 546864	NADEZHDA FEDOROVA	{"email": "n-fedorova.1978@postgrespro.ru", "phone": "+70525580869"}
0005432020565	E708CF	4754 546239	VALERIY MIRONOV	{"email": "mironov_v-1970@postgrespro.ru", "phone": "+70111819399"}
0005432020566	63D7D1	7863 185229	YURIY GRIGOREV	{"email": "grigorev-y_1975@postgrespro.ru", "phone": "+70379964055"}
0005432020567	3E5407	3927 200956	ELVIRA LEBEDEVA	{"phone": "+70721724074"}
0005432020568	3E5407	7060 879758	OLGA POPOVA	{"email": "olga-popova.021966@postgrespro.ru", "phone": "+70132779152"}
0005432020569	262451	9718 244788	ANASTASIYA PETROVA	{"email": "a-petrova11081971@postgrespro.ru", "phone": "+70037665188"}
0005432020570	220DB0	3050 278489	SVETLANA GORBUNOVA	{"phone": "+70524125014"}
0005432020571	220DB0	6879 666871	AIDA GAVRILOVA	{"email": "gavrilovaa1973@postgrespro.ru", "phone": "+70460986794"}
0005432020572	A8063C	8648 259146	MIKHAIL ROMANOV	{"email": "romanov.m.1980@postgrespro.ru", "phone": "+70002509300"}
0005432020573	5334E3	9117 773335	ANASTASIYA RODIONOVA	{"phone": "+70260955041"}
0005432020574	5334E3	2780 560937	LYUDMILA NIKOLAEVA	{"phone": "+70981413222"}
0005432020575	3DD5E7	3111 261807	EKATERINA KUZMINA	{"email": "kuzminae_061988@postgrespro.ru", "phone": "+70198561520"}
0005432020576	C79E46	7213 817782	VIKTOR SMIRNOV	{"email": "v-smirnov02091984@postgrespro.ru", "phone": "+70551261855"}
0005432020577	164007	6879 813961	ANATOLIY ZAKHAROV	{"phone": "+70505832627"}
0005432020578	E6AB9B	8171 814219	GALINA POPOVA	{"email": "popova.galina_23051983@postgrespro.ru", "phone": "+70952197750"}
0005432020579	5D153B	9111 131279	VALERIY SERGEEV	{"email": "sergeev-valeriy.1977@postgrespro.ru", "phone": "+70343461312"}
0005432020580	5D153B	5294 467094	MAKSIM KRASNOV	{"email": "krasnov.maksim_091967@postgrespro.ru", "phone": "+70643172506"}
0005432020581	9B4C54	3821 392844	NIKOLAY TIMOFEEV	{"phone": "+70480075363"}
0005432020582	9B4C54	9508 568334	GENNADIY MIKHAYLOV	{"phone": "+70259526786"}
0005432020583	22B947	4831 193000	ANASTASIYA KOROLEVA	{"phone": "+70028963229"}
0005432020584	AD794A	9835 385744	EVGENIYA SOROKINA	{"phone": "+70245676501"}
0005432020585	AD794A	3324 655973	SVETLANA KONOVALOVA	{"email": "svetlana-konovalova121971@postgrespro.ru", "phone": "+70709448842"}
0005432020586	597199	3329 035498	NINA KARPOVA	{"email": "nina.karpova09101962@postgrespro.ru", "phone": "+70796043419"}
0005432020587	35BF55	5144 170890	NIKITA MAKAROV	{"email": "makarovn_061964@postgrespro.ru", "phone": "+70655390655"}
0005432020588	1703C3	8135 602585	VALENTINA VOLKOVA	{"phone": "+70810667100"}
0005432020589	1703C3	5263 465409	VLADIMIR NAUMOV	{"email": "naumov_v.1965@postgrespro.ru", "phone": "+70293366976"}
0005432020590	78501B	5905 396333	ZLATA SOKOLOVA	{"phone": "+70306245515"}
0005432020591	78501B	5491 750097	IVAN NIKOLAEV	{"phone": "+70730489352"}
0005432020592	4C6409	9681 057050	ALEKSEY VOROBEV	{"phone": "+70059864685"}
0005432020593	8351F5	9128 510382	ZINAIDA VLASOVA	{"email": "vlasova-zinaida1979@postgrespro.ru", "phone": "+70914641742"}
0005432020594	0422CF	8469 611754	LIDIYA CHERNOVA	{"phone": "+70802073385"}
0005432020595	0422CF	8971 279544	NIKOLAY ANDREEV	{"phone": "+70999962802"}
0005432020596	BE95F4	7720 835430	ANTONINA ROMANOVA	{"phone": "+70422428473"}
0005432020597	BE95F4	7095 448151	ZINAIDA AKIMOVA	{"phone": "+70540100640"}
0005432020598	D65877	0115 785347	ZOYA TITOVA	{"phone": "+70880936948"}
0005432020599	3D5DBD	6114 027529	MAKSIM MIRONOV	{"email": "mironovm.15011981@postgrespro.ru", "phone": "+70257790820"}
0005432020600	0EF2EC	2944 046299	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov_1965@postgrespro.ru", "phone": "+70890940924"}
0005432020601	685C72	3820 846541	VITALIY NIKITIN	{"email": "nikitin-v1971@postgrespro.ru", "phone": "+70234844885"}
0005432020602	A7B856	7238 194889	ALEKSEY FROLOV	{"email": "frolovaleksey-041973@postgrespro.ru", "phone": "+70905999497"}
0005432020603	8F948A	5875 059743	ZINAIDA ANISIMOVA	{"phone": "+70674021280"}
0005432020604	8F948A	8754 103295	VITALIY IVANOV	{"phone": "+70151468670"}
0005432020605	F2DA09	7031 682184	LARISA BARANOVA	{"email": "l.baranova-1957@postgrespro.ru", "phone": "+70101494361"}
0005432020606	EA1B7A	3973 522445	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr-011963@postgrespro.ru", "phone": "+70800242214"}
0005432020607	FB9240	1188 689994	ALEKSEY IVANOV	{"phone": "+70988147345"}
0005432020608	FB9240	1039 181162	SVETLANA EGOROVA	{"email": "s_egorova-08081974@postgrespro.ru", "phone": "+70620499881"}
0005432020609	FB9240	1775 758020	IRINA MAKSIMOVA	{"email": "maksimova-irina031974@postgrespro.ru", "phone": "+70969154947"}
0005432020610	FB9240	5075 580388	IVAN BELOV	{"phone": "+70470493329"}
0005432020611	92847F	0698 901608	EKATERINA VASILEVA	{"email": "vasileva_e1955@postgrespro.ru", "phone": "+70717358263"}
0005432020612	89FD68	8422 462893	YULIYA AKIMOVA	{"email": "y_akimova.15101978@postgrespro.ru", "phone": "+70803214272"}
0005432020613	940937	5066 482721	VITALIY SEMENOV	{"phone": "+70419497252"}
0005432020614	5316EE	5355 848700	EKATERINA FROLOVA	{"email": "frolova-e-061975@postgrespro.ru", "phone": "+70526036998"}
0005432020615	295A7B	1203 898214	GALINA ALEKSEEVA	{"email": "galina_alekseeva_1971@postgrespro.ru", "phone": "+70415853393"}
0005432020616	56BE89	7512 118329	OKSANA PETROVA	{"email": "o-petrova.10081979@postgrespro.ru", "phone": "+70677736558"}
0005432020617	46F536	3453 994477	ELIZAVETA ANDREEVA	{"phone": "+70875855262"}
0005432020618	241189	6189 002958	TATYANA RODIONOVA	{"email": "rodionovatatyana.091984@postgrespro.ru", "phone": "+70934531166"}
0005432020619	27F5F7	4606 335582	ALEKSANDR FILIPPOV	{"phone": "+70071142812"}
0005432020620	3766A9	2189 725347	ANDREY GERASIMOV	{"email": "gerasimov_andrey-08091959@postgrespro.ru", "phone": "+70353481597"}
0005432020621	A83E67	4897 789399	ELENA VASILEVA	{"phone": "+70131358303"}
0005432020622	A83E67	0735 614071	EKATERINA TARASOVA	{"email": "e-tarasova.011983@postgrespro.ru", "phone": "+70403511388"}
0005432020623	A83E67	7868 856086	VALENTINA MAKAROVA	{"email": "vmakarova-1973@postgrespro.ru", "phone": "+70980902044"}
0005432020624	C1CBF8	1696 172361	YANA MOROZOVA	{"email": "yana_morozova_021966@postgrespro.ru", "phone": "+70469329730"}
0005432020625	9D5420	3348 229535	NADEZHDA AFANASEVA	{"phone": "+70227881619"}
0005432020626	9D5420	8725 890085	YULIYA VOLKOVA	{"phone": "+70154237566"}
0005432020627	48EBA5	3306 198079	GALIYA GAVRILOVA	{"phone": "+70686400144"}
0005432020628	FD2EAE	9530 416742	VLADIMIR VOLKOV	{"email": "volkov.v-081961@postgrespro.ru", "phone": "+70450909206"}
0005432020629	FD2EAE	6010 585321	VITALIY ALEKSEEV	{"phone": "+70520387104"}
0005432020630	BE8C82	4393 690017	TATYANA NIKITINA	{"email": "t.nikitina-111966@postgrespro.ru", "phone": "+70966077016"}
0005432020631	C0A801	0139 721398	EVGENIY KOZLOV	{"phone": "+70181793379"}
0005432020632	C0A801	4932 028734	KLAVDIYA SOLOVEVA	{"email": "k_soloveva-041975@postgrespro.ru", "phone": "+70568383198"}
0005432020633	E83AE7	3980 885351	ELENA IVANOVA	{"phone": "+70352472131"}
0005432020634	E83AE7	1092 962845	ILYA KOZLOV	{"phone": "+70672453600"}
0005432020635	BE76E6	5485 371706	OLGA SIDOROVA	{"email": "sidorovao27021976@postgrespro.ru", "phone": "+70980216239"}
0005432020636	BE76E6	8693 745065	ANTON EGOROV	{"phone": "+70783385466"}
0005432020637	E61810	9025 356611	VLADIMIR DAVYDOV	{"phone": "+70141172197"}
0005432020638	614CF0	5361 405186	SHAVKAT VOLKOV	{"phone": "+70622380559"}
0005432020639	BD3CB2	6652 391806	PAVEL ILIN	{"phone": "+70520700929"}
0005432020640	BD3CB2	9306 510737	TATYANA NIKOLAEVA	{"email": "tnikolaeva_28051971@postgrespro.ru", "phone": "+70601205899"}
0005432020641	FA5CE9	0704 727683	ARINA PETROVA	{"phone": "+70003597758"}
0005432020642	E88947	6899 762869	MATVEY STEPANOV	{"phone": "+70532589646"}
0005432020643	0BCF35	8483 650292	NADEZHDA MAKAROVA	{"phone": "+70823268523"}
0005432020644	69C53B	6168 675871	DAVID KONOVALOV	{"phone": "+70600373490"}
0005432020645	234831	3944 347132	TATYANA KUDRYASHOVA	{"email": "kudryashova-t_041962@postgrespro.ru", "phone": "+70655142735"}
0005432020646	66E151	6450 516920	VALERIY BELOV	{"phone": "+70811977442"}
0005432020647	A01509	8712 043615	ANNA SEMENOVA	{"email": "a.semenova1978@postgrespro.ru", "phone": "+70027831692"}
0005432020648	A01509	1129 275431	KSENIYA MOROZOVA	{"email": "morozovak.1977@postgrespro.ru", "phone": "+70817940715"}
0005432020649	04A6A1	8721 889479	ANZHELIKA EGOROVA	{"phone": "+70129178219"}
0005432020650	8C1714	9293 360285	GALINA FROLOVA	{"phone": "+70355192611"}
0005432020651	8C1714	3721 231099	NATALYA ILINA	{"email": "ilina_n-011975@postgrespro.ru", "phone": "+70100874795"}
0005432020652	8C1714	7188 694037	LILIYA SIDOROVA	{"phone": "+70366978484"}
0005432020653	9F649D	5840 036183	VALERIY OSIPOV	{"phone": "+70540368723"}
0005432020654	F6043F	2024 799597	SERGEY KUZNECOV	{"phone": "+70133778174"}
0005432020655	F6043F	5124 931395	RUMIYA MALYSHEVA	{"phone": "+70883439199"}
0005432020656	D75894	9588 899458	ALEKSANDR KUZNECOV	{"phone": "+70757360627"}
0005432020657	D75894	5015 314610	TATYANA FILATOVA	{"email": "t_filatova-1975@postgrespro.ru", "phone": "+70111081834"}
0005432020658	0FBB8D	6675 914925	OLGA ABRAMOVA	{"email": "abramova_o.061983@postgrespro.ru", "phone": "+70197244718"}
0005432020659	0FBB8D	9939 469731	ROMAN PETROV	{"email": "roman-petrov1973@postgrespro.ru", "phone": "+70962948476"}
0005432020660	73F205	0492 699189	ALEKSANDR ILIN	{"phone": "+70031227178"}
0005432020661	23E680	2818 641540	PAVEL RODIONOV	{"email": "pavel_rodionov-011966@postgrespro.ru", "phone": "+70751275807"}
0005432020662	BF66FF	2859 507139	NIKOLAY KAZAKOV	{"phone": "+70183675161"}
0005432020663	3CA787	3315 227649	NADEZHDA SCHERBAKOVA	{"email": "n_scherbakova_061960@postgrespro.ru", "phone": "+70381569894"}
0005432020664	686A20	9130 494185	LARISA OSIPOVA	{"email": "osipova.l.091965@postgrespro.ru", "phone": "+70795873353"}
0005432020665	1852F6	5672 324093	RUSLAN OSIPOV	{"email": "osipov.ruslan031978@postgrespro.ru", "phone": "+70995048747"}
0005432020666	6E0C8F	8932 306657	LARISA KULIKOVA	{"email": "lkulikova05021959@postgrespro.ru", "phone": "+70051452936"}
0005432020667	54C38C	8102 298357	LYUBOV DAVYDOVA	{"phone": "+70569112360"}
0005432020668	A3FE8C	9566 199977	VIOLETTA KOROLEVA	{"phone": "+70737891790"}
0005432020669	A3FE8C	4874 551147	DARYA MELNIKOVA	{"email": "daryamelnikova_1984@postgrespro.ru", "phone": "+70588187644"}
0005432020670	A3FE8C	3712 152575	MAKSIM KAZAKOV	{"email": "kazakov.m-1975@postgrespro.ru", "phone": "+70659272280"}
0005432020671	D0AC89	0693 678945	ELENA YAKOVLEVA	{"email": "elena-yakovleva-1980@postgrespro.ru", "phone": "+70103888641"}
0005432020672	E4AB05	9348 545838	ALEKSEY KOZLOV	{"phone": "+70580999692"}
0005432020673	899883	0018 836553	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov-121963@postgrespro.ru", "phone": "+70542445712"}
0005432020674	899883	6504 322627	IRINA NAZAROVA	{"email": "irina-nazarova_11091981@postgrespro.ru", "phone": "+70660406113"}
0005432020675	899883	3365 816145	NIKITA ORLOV	{"email": "nikitaorlov.101988@postgrespro.ru", "phone": "+70817541227"}
0005432020676	F242DF	0821 246778	ANNA LOGINOVA	{"email": "a.loginova121971@postgrespro.ru", "phone": "+70591867643"}
0005432020677	81B45A	3762 662608	GALINA NOVIKOVA	{"phone": "+70324363845"}
0005432020678	31F001	1800 576779	ANNA SERGEEVA	{"email": "a_sergeeva.051964@postgrespro.ru", "phone": "+70535838395"}
0005432020679	31F001	7892 270063	ALENA KOLESNIKOVA	{"email": "alena_kolesnikova_091976@postgrespro.ru", "phone": "+70643873951"}
0005432020680	AB16DE	1651 951060	SVETLANA ZAYCEVA	{"phone": "+70772188791"}
0005432020681	5BD3A2	4883 196321	NATALYA LAZAREVA	{"email": "lazareva.natalya.041970@postgrespro.ru", "phone": "+70968788281"}
0005432020682	AEC538	2154 487988	VIKTOR MEDVEDEV	{"phone": "+70370302436"}
0005432020683	AEC538	5279 183015	ALEKSANDR KISELEV	{"phone": "+70723074156"}
0005432020684	C376C0	1886 410282	NIKITA TIKHONOV	{"email": "nikita.tikhonov.09081964@postgrespro.ru", "phone": "+70998657518"}
0005432020685	C376C0	1844 729209	LYUBOV POPOVA	{"phone": "+70791415925"}
0005432020686	1F783A	7887 449493	ELENA MIKHAYLOVA	{"phone": "+70496444539"}
0005432020687	B39074	6882 446122	RAFAEL FEDOROV	{"phone": "+70390117877"}
0005432020688	C4B0AE	6301 511968	GALINA ZHURAVLEVA	{"phone": "+70057311122"}
0005432020689	C4B0AE	0743 522715	ILYA KUZNECOV	{"email": "kuznecovilya04121980@postgrespro.ru", "phone": "+70080519018"}
0005432020690	B58D8C	8857 067002	TATYANA EGOROVA	{"email": "egorova-t111969@postgrespro.ru", "phone": "+70744421932"}
0005432020691	B58D8C	1810 325728	ALEKSEY BORISOV	{"phone": "+70558016341"}
0005432020692	0BD67D	9004 762022	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova-041963@postgrespro.ru", "phone": "+70925346003"}
0005432020693	0BD67D	7320 326387	BORIS KOROLEV	{"email": "b.korolev_011982@postgrespro.ru", "phone": "+70828840458"}
0005432020694	7739F2	9818 179192	OLGA ILINA	{"email": "oilina1972@postgrespro.ru", "phone": "+70277565096"}
0005432020695	7739F2	0487 035603	NINA KOLESNIKOVA	{"email": "kolesnikovanina_011979@postgrespro.ru", "phone": "+70302810409"}
0005432020696	50C4D7	2692 552268	SANIYA TARASOVA	{"email": "tarasova-s1971@postgrespro.ru", "phone": "+70573058787"}
0005432020697	50C4D7	6266 692323	TAISIYA SAVELEVA	{"phone": "+70643921174"}
0005432020698	C159EC	1089 974451	ALEKSEY YAKOVLEV	{"email": "yakovlev.a.16021965@postgrespro.ru", "phone": "+70854138147"}
0005432020699	3F9E67	5220 798923	ARTEM FROLOV	{"phone": "+70321799768"}
0005432020700	983411	4871 942096	VIKTOR VLASOV	{"email": "vlasovviktor-01021971@postgrespro.ru", "phone": "+70087282932"}
0005432020701	3486CA	2124 317572	KARINA BELOVA	{"email": "karina-belova17041972@postgrespro.ru", "phone": "+70402830262"}
0005432020702	22A852	4573 501045	DMITRIY ANDREEV	{"phone": "+70017194002"}
0005432020703	22A852	0779 535169	NATALYA KRASNOVA	{"email": "krasnova-n061965@postgrespro.ru", "phone": "+70220743938"}
0005432020704	79D8BC	2711 215772	DMITRIY SOLOVEV	{"email": "solovev.dmitriy.091969@postgrespro.ru", "phone": "+70336026062"}
0005432020705	821D07	2688 772004	VIKTORIYA SERGEEVA	{"phone": "+70823343518"}
0005432020706	70A653	2715 908115	VLADIMIR KUZNECOV	{"phone": "+70307985372"}
0005432020707	70A653	7093 891646	SVETLANA AKIMOVA	{"phone": "+70524476063"}
0005432020708	4B0B22	5692 096849	ALBINA ZHURAVLEVA	{"phone": "+70828974416"}
0005432020709	649854	7505 910325	ALEKSANDR KUZNECOV	{"phone": "+70632909670"}
0005432020710	1C9559	5621 144920	ELENA POTAPOVA	{"email": "elenapotapova_081968@postgrespro.ru", "phone": "+70434173821"}
0005432020711	1C9559	4396 264904	KONSTANTIN GAVRILOV	{"email": "gavrilovkonstantin26111963@postgrespro.ru", "phone": "+70564515543"}
0005432020712	6E0E85	2699 888328	ALEKSANDRA PAVLOVA	{"phone": "+70327035023"}
0005432020713	3E4BA0	5201 657376	ALEKSANDR MIRONOV	{"phone": "+70764841937"}
0005432020714	3E4BA0	3868 240112	VIKTORIYA DAVYDOVA	{"phone": "+70516012753"}
0005432020715	FFF6D4	1385 828610	IVAN DENISOV	{"email": "denisov_ivan1965@postgrespro.ru", "phone": "+70557387573"}
0005432020716	EA32C9	5362 883685	NADEZHDA AFANASEVA	{"email": "afanaseva_nadezhda121965@postgrespro.ru", "phone": "+70405046016"}
0005432020717	2C6E61	9846 382026	GALINA IVANOVA	{"email": "galina_ivanova_19101973@postgrespro.ru", "phone": "+70972498860"}
0005432020718	D4513A	7350 460478	SERGEY VASILEV	{"email": "sergey.vasilev101971@postgrespro.ru", "phone": "+70443755404"}
0005432020719	B4E133	2337 982745	KLAVDIYA IVANOVA	{"email": "ivanovaklavdiya_1971@postgrespro.ru", "phone": "+70991015908"}
0005432020720	B4E133	8362 031967	GALINA FILIPPOVA	{"phone": "+70290799115"}
0005432020721	5A9EE1	8756 399504	VALENTINA YAKOVLEVA	{"phone": "+70397248880"}
0005432020722	B8D2D0	3551 101554	NADEZHDA RODIONOVA	{"phone": "+70106246266"}
0005432020723	F1FF52	6229 913661	NAIL GUSEV	{"email": "gusev-nail_1978@postgrespro.ru", "phone": "+70875781225"}
0005432020724	966B7D	3343 502988	VIOLETTA PETROVA	{"email": "violettapetrova.121971@postgrespro.ru", "phone": "+70254123584"}
0005432020725	074285	8543 168796	LEYLA ISAEVA	{"email": "isaeva_l_1978@postgrespro.ru", "phone": "+70548881065"}
0005432020726	074285	0038 801674	ALEKSEY MIKHAYLOV	{"email": "aleksey.mikhaylov.1953@postgrespro.ru", "phone": "+70469539289"}
0005432020727	07A19D	2114 410320	NADEZHDA AFANASEVA	{"phone": "+70559678929"}
0005432020728	2E0BDE	4742 176529	VERA VOLKOVA	{"phone": "+70588689350"}
0005432020729	5F703C	8468 939905	ELENA BORISOVA	{"phone": "+70892002206"}
0005432020730	5F703C	1860 876787	YURIY KOZLOV	{"email": "kozlovyuriy_20061978@postgrespro.ru", "phone": "+70746928395"}
0005432020731	5F703C	2540 190623	NIKITA KARPOV	{"phone": "+70056287155"}
0005432020732	E0D649	2488 836394	VLADIMIR TIMOFEEV	{"email": "vladimir-timofeev1971@postgrespro.ru", "phone": "+70069622202"}
0005432020733	8FF5DC	7061 566085	NATALYA NIKOLAEVA	{"email": "nikolaevanatalya071976@postgrespro.ru", "phone": "+70845179086"}
0005432020734	7AAD66	7573 176553	ANDREY EGOROV	{"phone": "+70926392298"}
0005432020735	3E26F6	9085 507473	MARINA TIKHONOVA	{"phone": "+70501800258"}
0005432020736	C9FFE0	2373 351390	NIKITA GERASIMOV	{"phone": "+70545551626"}
0005432020737	82A3EB	3543 106029	YAN MATVEEV	{"phone": "+70637809667"}
0005432020738	82A3EB	1710 471257	TATYANA STEPANOVA	{"email": "stepanova.tatyana.1988@postgrespro.ru", "phone": "+70498755291"}
0005432020739	82A3EB	5946 131392	MIKHAIL TIKHONOV	{"email": "tikhonovmikhail-101976@postgrespro.ru", "phone": "+70146863908"}
0005432020740	74242A	5245 860532	NATALYA MIKHAYLOVA	{"phone": "+70682919957"}
0005432020741	4A5FD3	8331 617138	KIRILL VASILEV	{"email": "vasilevk.101974@postgrespro.ru", "phone": "+70893553366"}
0005432020742	4A5FD3	3536 544343	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey-1966@postgrespro.ru", "phone": "+70511735558"}
0005432020743	2FAE0F	2555 948445	IGOR FROLOV	{"email": "i_frolov-121970@postgrespro.ru", "phone": "+70131561060"}
0005432020744	2FAE0F	6792 848815	ANNA NIKITINA	{"email": "nikitina-a_29021976@postgrespro.ru", "phone": "+70614979751"}
0005432020745	456D52	7150 239192	ANTON SEMENOV	{"phone": "+70904166841"}
0005432020746	F4FDC5	3196 954180	OLGA IVANOVA	{"email": "ivanovao-121973@postgrespro.ru", "phone": "+70881793964"}
0005432020747	2CF134	4262 131739	VLADIMIR ABRAMOV	{"email": "abramov.vladimir.10061970@postgrespro.ru", "phone": "+70365365779"}
0005432020748	2CF134	4416 721745	RAFIK SOKOLOV	{"email": "sokolov_r_08091970@postgrespro.ru", "phone": "+70013430098"}
0005432020749	2CF134	1734 973889	RUSLAN ILIN	{"email": "ilinruslan-1961@postgrespro.ru", "phone": "+70125557740"}
0005432020750	EF1C1E	9899 478092	DMITRIY IVANOV	{"phone": "+70549690025"}
0005432020751	00D367	9176 505722	NIKITA NAUMOV	{"email": "naumov_nikita_061974@postgrespro.ru", "phone": "+70517860377"}
0005432020752	A9A245	4550 230733	ALEKSANDR POPOV	{"email": "popov-aleksandr16091978@postgrespro.ru", "phone": "+70402428322"}
0005432020753	A9A245	8377 561390	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey091977@postgrespro.ru", "phone": "+70642157850"}
0005432020754	C3C231	0847 471080	LYUDMILA ZAKHAROVA	{"phone": "+70019570676"}
0005432020755	9AD2B4	4954 545577	VLADISLAV VASILEV	{"email": "vasilev.v_061967@postgrespro.ru", "phone": "+70322241404"}
0005432020756	BFFDE8	8055 682960	ALINA KUZMINA	{"email": "akuzmina-1966@postgrespro.ru", "phone": "+70210910803"}
0005432020757	BFFDE8	0618 376188	LIDIYA YAKOVLEVA	{"phone": "+70318130194"}
0005432020758	6B5913	0474 029379	ALEKSANDR ISAEV	{"phone": "+70835327735"}
0005432020759	BBD70B	5124 281177	ANDREY KUZNECOV	{"email": "kuznecov.a_1977@postgrespro.ru", "phone": "+70033368011"}
0005432020760	BBD70B	3866 483685	NIKOLAY KISELEV	{"phone": "+70749925625"}
0005432020761	0F2E61	5878 900349	MARIYA SAVELEVA	{"email": "mariya.saveleva.1976@postgrespro.ru", "phone": "+70143709732"}
0005432020762	AF993E	8098 907322	VASILIY IVANOV	{"email": "ivanov.vasiliy-121971@postgrespro.ru", "phone": "+70028676580"}
0005432020763	AF993E	9363 390185	TATYANA MELNIKOVA	{"phone": "+70800849260"}
0005432020764	175A9A	1666 043021	MARIYA KOROLEVA	{"email": "koroleva_m-12051984@postgrespro.ru", "phone": "+70134767603"}
0005432020765	35458B	0112 940082	ALLA ERMAKOVA	{"phone": "+70054844138"}
0005432020766	AE7666	0550 051907	ANGELINA ILINA	{"phone": "+70691801706"}
0005432020767	AE7666	0006 892909	ANNA TIKHONOVA	{"phone": "+70050716456"}
0005432020768	AE7666	7634 048456	IRINA MEDVEDEVA	{"email": "irina.medvedeva.07101974@postgrespro.ru", "phone": "+70037396747"}
0005432020769	D595F4	4292 911252	TAMARA MOISEEVA	{"email": "tmoiseeva-101968@postgrespro.ru", "phone": "+70558152324"}
0005432020770	D595F4	8141 088200	EKATERINA OVCHINNIKOVA	{"phone": "+70325454040"}
0005432020771	D595F4	8609 868732	VASILIY MOROZOV	{"phone": "+70635048393"}
0005432020772	EAD9A0	1720 161112	TATYANA FOMINA	{"phone": "+70303852378"}
0005432020773	E54AA7	6197 529598	GALINA BELOVA	{"email": "belova-g_19081969@postgrespro.ru", "phone": "+70934544578"}
0005432020774	E54AA7	0799 330170	SANIYA FILATOVA	{"email": "filatova.saniya.13071985@postgrespro.ru", "phone": "+70993599357"}
0005432020775	F9199D	2030 111180	ANDREY SMIRNOV	{"phone": "+70161793207"}
0005432020776	2BC72A	6804 704899	SABINA SERGEEVA	{"email": "sergeeva-s-30101971@postgrespro.ru", "phone": "+70585115990"}
0005432020777	0A07C2	1096 008625	ANATOLIY NOVIKOV	{"phone": "+70331143300"}
0005432020778	4AFEF1	5665 789855	MARINA YAKOVLEVA	{"email": "yakovlevam1957@postgrespro.ru", "phone": "+70729238967"}
0005432020779	4AFEF1	5393 712616	RUSLAN VLASOV	{"email": "r.vlasov-1969@postgrespro.ru", "phone": "+70167106842"}
0005432020780	0EB875	8332 303969	NATALYA LOGINOVA	{"email": "natalya_loginova-011974@postgrespro.ru", "phone": "+70363529607"}
0005432020781	5D12AD	9718 186081	TIMUR KONOVALOV	{"phone": "+70642157142"}
0005432020782	549CD5	1247 133151	SERGEY FILIPPOV	{"email": "filippov.sergey_16101985@postgrespro.ru", "phone": "+70082991551"}
0005432020783	67A810	9876 867027	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda_17091974@postgrespro.ru", "phone": "+70609539517"}
0005432020784	E16554	0431 391927	ANATOLIY NIKOLAEV	{"email": "anikolaev081977@postgrespro.ru", "phone": "+70264868173"}
0005432020785	28BD99	7853 364262	ANTONINA EGOROVA	{"email": "egorova_antonina-021982@postgrespro.ru", "phone": "+70378232309"}
0005432020786	28BD99	6832 368776	IGOR SAVELEV	{"email": "savelev.igor021975@postgrespro.ru", "phone": "+70325817037"}
0005432020787	AEEC97	1340 513481	ALEKSEY NIKOLAEV	{"phone": "+70943799387"}
0005432020788	AEEC97	1202 191051	MARGARITA KOZLOVA	{"phone": "+70603025862"}
0005432020789	97097E	7709 827717	LYUDMILA EFREMOVA	{"email": "efremova-l.061971@postgrespro.ru", "phone": "+70173019536"}
0005432020790	ACF4C0	2296 967672	PAVEL MARTYNOV	{"phone": "+70675849549"}
0005432020791	6DF5EA	1948 940713	ALEKSANDR FROLOV	{"email": "a_frolov1951@postgrespro.ru", "phone": "+70932685566"}
0005432020792	23270D	7482 765225	LYUBOV OSIPOVA	{"email": "lyubov.osipova-10021979@postgrespro.ru", "phone": "+70741167079"}
0005432020793	BF58FE	2661 991801	ZOYA IVANOVA	{"email": "ivanovazoya_121970@postgrespro.ru", "phone": "+70790350871"}
0005432020794	BF58FE	1338 216496	ANTONINA KISELEVA	{"email": "antonina-kiseleva-1969@postgrespro.ru", "phone": "+70429630904"}
0005432020795	6FD14D	1002 421222	MARINA ZOTOVA	{"phone": "+70446022825"}
0005432020796	6FD14D	1040 571321	YULIANA DAVYDOVA	{"email": "davydova.y.19031975@postgrespro.ru", "phone": "+70267521837"}
0005432020797	6FD14D	1946 906820	LYUDMILA MAKAROVA	{"phone": "+70498856226"}
0005432020798	250D7B	8821 443471	ANATOLIY KOZLOV	{"email": "kozlova-1977@postgrespro.ru", "phone": "+70139920989"}
0005432020799	17603C	4223 167531	YURIY MAKAROV	{"phone": "+70286773740"}
0005432020800	76FB11	0684 206388	ANNA STEPANOVA	{"phone": "+70433538182"}
0005432020801	76FB11	9244 917424	SEMEN BELOV	{"phone": "+70648118764"}
0005432020802	F20344	3578 477208	ANASTASIYA NIKITINA	{"email": "a-nikitina1979@postgrespro.ru", "phone": "+70057005531"}
0005432020803	F20344	3402 099152	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr091973@postgrespro.ru", "phone": "+70160244781"}
0005432020804	B2DDEF	1388 571109	ANNA STEPANOVA	{"email": "stepanova_anna.1970@postgrespro.ru", "phone": "+70708879629"}
0005432020805	1E1518	1689 769751	OLEG KARPOV	{"email": "o.karpov1971@postgrespro.ru", "phone": "+70686692378"}
0005432020806	E9003E	8354 500496	VLADIMIR KUZNECOV	{"phone": "+70364749920"}
0005432020807	BDD3A7	6934 640642	EVGENIY MIRONOV	{"email": "e_mironov-041977@postgrespro.ru", "phone": "+70572048585"}
0005432020808	EC8819	5513 651759	ANASTASIYA VOLKOVA	{"email": "volkova_anastasiya-30081971@postgrespro.ru", "phone": "+70701194734"}
0005432020809	EC8819	6689 087468	ALBINA DMITRIEVA	{"phone": "+70396403044"}
0005432020810	EC8819	2867 096539	ANTONINA ISAEVA	{"email": "isaeva_a_041986@postgrespro.ru", "phone": "+70805446856"}
0005432020811	E5997F	1056 662215	DMITRIY MOROZOV	{"email": "morozov.d_1975@postgrespro.ru", "phone": "+70021003433"}
0005432020812	EC300E	2731 740668	LEONID GERASIMOV	{"email": "leonid-gerasimov1965@postgrespro.ru", "phone": "+70930556909"}
0005432020813	EC300E	8869 756825	EVGENIY AFANASEV	{"phone": "+70986324566"}
0005432020814	D0A5F6	7236 596037	OLGA FEDOROVA	{"email": "fedorovao_121975@postgrespro.ru", "phone": "+70387070765"}
0005432020815	90D8C5	0755 432581	SVETLANA VASILEVA	{"phone": "+70545289808"}
0005432020816	6D2D0F	2620 982701	ROMAN MATVEEV	{"email": "matveev-roman29111959@postgrespro.ru", "phone": "+70510172051"}
0005432020817	6D2D0F	9172 810845	MARIYA BARANOVA	{"email": "m.baranova-05031958@postgrespro.ru", "phone": "+70938913256"}
0005432020818	6D2D0F	6868 271929	NINA BORISOVA	{"email": "borisova.nina_1972@postgrespro.ru", "phone": "+70397283609"}
0005432020819	3905EB	3515 838242	ALEKSANDR BELOV	{"phone": "+70928907117"}
0005432020820	2E36AB	9768 148386	NIKOLAY KOZLOV	{"email": "nikolaykozlov1966@postgrespro.ru", "phone": "+70779470097"}
0005432020821	9B9533	3160 483691	SHAVKAT NAZAROV	{"phone": "+70766412431"}
0005432020822	9B9533	5273 774118	KLAVDIYA SOLOVEVA	{"email": "soloveva_klavdiya061976@postgrespro.ru", "phone": "+70189161912"}
0005432020823	DC1554	7658 719042	ANGELINA FOMINA	{"email": "afomina.041975@postgrespro.ru", "phone": "+70048399888"}
0005432020824	03E643	3550 143852	LYUDMILA MAKSIMOVA	{"email": "lyudmila_maksimova1972@postgrespro.ru", "phone": "+70617500544"}
0005432020825	714D5D	2996 825595	LEONTIY BELOV	{"phone": "+70050542740"}
0005432020826	49A428	8896 600995	GALINA ZAYCEVA	{"phone": "+70227084888"}
0005432020827	49A428	8191 619504	SVETLANA KOROLEVA	{"phone": "+70546123242"}
0005432020828	820920	4502 204977	TAMARA GUSEVA	{"phone": "+70903477943"}
0005432020829	A21439	6864 685866	EKATERINA IVANOVA	{"phone": "+70797095471"}
0005432020830	C0126A	3101 708397	ALEKSANDR MOROZOV	{"phone": "+70885278891"}
0005432020831	C0126A	9118 383147	SERGEY SERGEEV	{"phone": "+70937231630"}
0005432020832	C0126A	7848 108927	DARYA ANISIMOVA	{"email": "anisimova_darya-22011972@postgrespro.ru", "phone": "+70799413339"}
0005432020833	590064	9972 074787	LYUDMILA NESTEROVA	{"email": "lyudmilanesterova-1973@postgrespro.ru", "phone": "+70510936319"}
0005432020834	590064	0125 021803	NINA PETROVA	{"email": "nina-petrova-061968@postgrespro.ru", "phone": "+70122585724"}
0005432020835	B2A2B5	9957 989479	EVGENIY KUZNECOV	{"phone": "+70965387069"}
0005432020836	BE37B7	9028 424379	OLGA KRASNOVA	{"phone": "+70520132922"}
0005432020837	41F563	2620 372575	ANTONINA FADEEVA	{"phone": "+70057740369"}
0005432020838	41F563	1943 475441	ANDREY GERASIMOV	{"email": "gerasimov.andrey.071981@postgrespro.ru", "phone": "+70215890960"}
0005432020839	41F563	3910 520957	TATYANA KUZNECOVA	{"phone": "+70361192534"}
0005432020840	16F9E4	1954 926289	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina.091964@postgrespro.ru", "phone": "+70244118663"}
0005432020841	AE1C19	8046 681121	ANTONINA ZAKHAROVA	{"phone": "+70724464479"}
0005432020842	A83831	6234 701083	ALEKSANDR DAVYDOV	{"email": "a-davydov.021967@postgrespro.ru", "phone": "+70288660868"}
0005432020843	A83831	5287 104929	OKSANA MATVEEVA	{"email": "oksana-matveeva.1974@postgrespro.ru", "phone": "+70254416972"}
0005432020844	4A2697	6437 168245	ALEKSANDR ORLOV	{"phone": "+70469576679"}
0005432020845	4A2697	1933 162124	IRINA KUZNECOVA	{"phone": "+70729582207"}
0005432020846	0981D5	1025 365511	VIKTORIYA NESTEROVA	{"phone": "+70240413175"}
0005432020847	29E7F9	2494 345563	OLEG GORBUNOV	{"email": "gorbunov-oleg-011973@postgrespro.ru", "phone": "+70707970515"}
0005432020848	29E7F9	3580 235651	LYUDMILA ERMAKOVA	{"phone": "+70778608819"}
0005432020849	DC9511	2447 854918	GALINA ZAKHAROVA	{"email": "gzakharova-051987@postgrespro.ru", "phone": "+70242153197"}
0005432020850	DC9511	4647 198861	VLADIMIR NIKITIN	{"email": "v.nikitin_041985@postgrespro.ru", "phone": "+70911161438"}
0005432020851	3BE3D7	2451 785617	ALEKSEY TIMOFEEV	{"phone": "+70549655730"}
0005432020852	753F7A	5628 863472	POLINA ZOTOVA	{"email": "pzotova1968@postgrespro.ru", "phone": "+70274557952"}
0005432020853	724461	3581 846719	EVGENIY IVANOV	{"phone": "+70151455730"}
0005432020854	5876D1	4953 027250	DMITRIY MATVEEV	{"phone": "+70654287953"}
0005432020855	5876D1	9459 549072	ZINAIDA BOGDANOVA	{"email": "zinaida.bogdanova.1972@postgrespro.ru", "phone": "+70233286751"}
0005432020856	5FAD2E	4237 430182	STANISLAV EGOROV	{"email": "stanislav_egorov041973@postgrespro.ru", "phone": "+70259229351"}
0005432020857	F9041C	2314 979660	FEDOR SMIRNOV	{"phone": "+70020231686"}
0005432020858	01E9AF	6805 568760	TATYANA ZOTOVA	{"email": "tatyana-zotova_21051965@postgrespro.ru", "phone": "+70713907481"}
0005432020859	01E9AF	2319 137059	LYUDMILA VLASOVA	{"email": "vlasova.l.07071972@postgrespro.ru", "phone": "+70355437375"}
0005432020860	01E9AF	9324 063105	EKATERINA DENISOVA	{"phone": "+70382080844"}
0005432020861	01E9AF	7966 342870	STANISLAV ZAYCEV	{"phone": "+70216341154"}
0005432020862	C02BFA	2376 928117	OLEG KAZAKOV	{"phone": "+70830381272"}
0005432020863	C02BFA	6486 714474	MAKSIM MIKHAYLOV	{"email": "m_mikhaylov-111971@postgrespro.ru", "phone": "+70932929681"}
0005432020864	C02BFA	7223 583476	NINA TIKHONOVA	{"phone": "+70742097571"}
0005432020865	CAFFD3	5525 555488	IGOR TIKHONOV	{"email": "tikhonov.i-09101971@postgrespro.ru", "phone": "+70821389871"}
0005432020866	B6AE29	6244 434532	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr.24121976@postgrespro.ru", "phone": "+70392392992"}
0005432020867	920EB7	2239 929916	VYACHESLAV BARANOV	{"phone": "+70437937095"}
0005432020868	F8F490	2214 129288	VLADIMIR ZAKHAROV	{"email": "zakharovv_03051980@postgrespro.ru", "phone": "+70880934012"}
0005432020869	F8F490	3149 157032	MARINA VOLKOVA	{"email": "volkova_m.091980@postgrespro.ru", "phone": "+70274907803"}
0005432020870	F8F490	5186 712351	DANILA YAKOVLEV	{"phone": "+70499751902"}
0005432020871	96F3FD	8010 914550	ALEKSANDR GERASIMOV	{"phone": "+70694849598"}
0005432020872	764DE1	9411 674985	ELENA SAVELEVA	{"email": "savelevaelena021977@postgrespro.ru", "phone": "+70092983221"}
0005432020873	764DE1	6977 945625	VIKTOR ILIN	{"email": "v_ilin.1973@postgrespro.ru", "phone": "+70007386768"}
0005432020874	791FAF	4807 033087	OLEG FOMIN	{"phone": "+70094361876"}
0005432020875	F1812F	2411 776353	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov1961@postgrespro.ru", "phone": "+70879457618"}
0005432020876	1CB3A7	1565 665539	VALERIYA VASILEVA	{"email": "vvasileva.02081970@postgrespro.ru", "phone": "+70921464518"}
0005432020877	1CB3A7	1314 153786	TATYANA NESTEROVA	{"email": "nesterovat.021984@postgrespro.ru", "phone": "+70918608472"}
0005432020878	F8F309	9401 190087	ANNA KOZLOVA	{"email": "anna-kozlova_24111965@postgrespro.ru", "phone": "+70034324258"}
0005432020879	D4882A	2283 889323	ALEKSANDR MIRONOV	{"phone": "+70758472459"}
0005432020880	17BAAC	9403 704251	SVETLANA KRASNOVA	{"email": "svetlana.krasnova_1976@postgrespro.ru", "phone": "+70918796383"}
0005432020881	4B2B9C	9067 170064	TATYANA IVANOVA	{"phone": "+70805533391"}
0005432020882	263316	5477 904046	VALENTINA ALEKSANDROVA	{"email": "valentina.aleksandrova1977@postgrespro.ru", "phone": "+70664803704"}
0005432020883	6A368F	4565 260952	DANILA BORISOV	{"email": "danilaborisov-18031974@postgrespro.ru", "phone": "+70700587598"}
0005432020884	24A513	8131 160731	TATYANA ZAKHAROVA	{"email": "zakharovatatyana-1965@postgrespro.ru", "phone": "+70341531812"}
0005432020885	D86B96	9253 187496	VENERA VASILEVA	{"email": "vasileva.venera.26031980@postgrespro.ru", "phone": "+70737502664"}
0005432020886	D86B96	3050 424333	TATYANA NAUMOVA	{"email": "naumovat-101971@postgrespro.ru", "phone": "+70197778499"}
0005432020887	E81B39	8229 766507	ELIZAVETA FEDOROVA	{"phone": "+70750994706"}
0005432020888	E81B39	5689 648715	ALEKSEY NIKITIN	{"email": "anikitin121975@postgrespro.ru", "phone": "+70507261809"}
0005432020889	D50C5E	8639 306029	ALEKSANDR KUZMIN	{"email": "kuzmin_a.14071964@postgrespro.ru", "phone": "+70679575240"}
0005432020890	D50C5E	6884 886319	OLGA NIKIFOROVA	{"phone": "+70964154774"}
0005432020891	BA2606	1728 688956	ANDREY AFANASEV	{"email": "andrey-afanasev-081975@postgrespro.ru", "phone": "+70993467738"}
0005432020892	1788B5	3072 726836	NURIYA FILIPPOVA	{"phone": "+70682652246"}
0005432020893	FF9372	6382 568854	EKATERINA MASLOVA	{"phone": "+70341019296"}
0005432020894	FF9372	7780 037736	OLEG ILIN	{"phone": "+70718592286"}
0005432020895	707D94	4871 018704	DMITRIY SEMENOV	{"phone": "+70608511290"}
0005432020896	BDFCAA	9652 701855	SERGEY MATVEEV	{"phone": "+70696285025"}
0005432020898	C1A04D	9417 290294	ALEFTINA POPOVA	{"email": "a-popova_091971@postgrespro.ru", "phone": "+70325110585"}
0005432020899	C1A04D	1613 839922	SVETLANA KUDRYASHOVA	{"email": "kudryashova.s051967@postgrespro.ru", "phone": "+70620058730"}
0005432020900	F1EB14	6014 046862	NATALYA MATVEEVA	{"email": "matveeva-n041976@postgrespro.ru", "phone": "+70567208645"}
0005432020901	0FF91C	2923 213473	ALSU ILINA	{"email": "ilina-a11051964@postgrespro.ru", "phone": "+70041983420"}
0005432020902	E88BF9	2783 306757	FARIDA SIDOROVA	{"email": "farida.sidorova_1971@postgrespro.ru", "phone": "+70705796226"}
0005432020903	29577D	6269 794131	MARIYA KRASNOVA	{"phone": "+70506417931"}
0005432020904	29577D	8805 536864	ALEKSEY RODIONOV	{"phone": "+70146903795"}
0005432020905	8A78CC	0653 143097	SVETLANA SIDOROVA	{"email": "sidorova-svetlana.061965@postgrespro.ru", "phone": "+70917334840"}
0005432020906	8A78CC	8117 547703	NIKOLAY FROLOV	{"email": "frolov.n-1974@postgrespro.ru", "phone": "+70804613551"}
0005432020907	2F6880	9266 904178	RODION KOZLOV	{"phone": "+70680837671"}
0005432020908	2F6880	2288 175871	ALEKSANDR SERGEEV	{"email": "sergeeva1979@postgrespro.ru", "phone": "+70549026849"}
0005432020909	46623C	2134 877359	VLADISLAV TIKHONOV	{"email": "tikhonov_vladislav041974@postgrespro.ru", "phone": "+70926463815"}
0005432020910	A903CA	5449 123864	EVGENIY MIRONOV	{"phone": "+70417701464"}
0005432020911	616533	5099 438529	NADEZHDA ABRAMOVA	{"email": "abramova_nadezhda_011973@postgrespro.ru", "phone": "+70091303238"}
0005432020912	B3B48B	4825 882579	KIRILL KUZNECOV	{"email": "kuznecov.k-21111969@postgrespro.ru", "phone": "+70516424901"}
0005432020913	FAA039	5611 238526	ANNA TIKHONOVA	{"email": "tikhonova-a1974@postgrespro.ru", "phone": "+70585835118"}
0005432020914	FAA039	0365 290055	ALEKSANDR MEDVEDEV	{"email": "medvedev.aleksandr-101985@postgrespro.ru", "phone": "+70233990742"}
0005432020915	FAA039	9265 891113	ANDREY TIKHONOV	{"phone": "+70321512220"}
0005432020916	9F8EED	8657 329992	NINA KARPOVA	{"phone": "+70734373076"}
0005432020917	9F8EED	9444 354384	ANATOLIY SIDOROV	{"phone": "+70327694132"}
0005432020918	B5528C	5006 291651	DANIIL NIKITIN	{"email": "nikitin-d-25121970@postgrespro.ru", "phone": "+70900323570"}
0005432020919	3720E4	9411 056748	ALEKSEY PETROV	{"phone": "+70204847189"}
0005432020920	7AC38A	0147 595517	ANATOLIY ANDREEV	{"phone": "+70841686507"}
0005432020921	7AC38A	3579 726100	LILIYA KOZLOVA	{"phone": "+70788988653"}
0005432020922	1D8631	3205 589310	VYACHESLAV ZAKHAROV	{"phone": "+70645010221"}
0005432020923	8C62B9	6252 688412	SERGEY BELOV	{"phone": "+70677135563"}
0005432020924	BCECAC	3363 953473	NIKITA DENISOV	{"email": "denisovn_18121976@postgrespro.ru", "phone": "+70599920271"}
0005432020925	BCECAC	2861 914352	TATYANA ZHURAVLEVA	{"phone": "+70971883647"}
0005432020926	9DE56E	4741 026578	VERONIKA ZHUKOVA	{"phone": "+70588862105"}
0005432020927	056A6E	5954 969559	EVGENIYA SOKOLOVA	{"phone": "+70050064584"}
0005432020928	056A6E	2777 888300	YURIY MIRONOV	{"email": "mironov_yuriy.25111971@postgrespro.ru", "phone": "+70837630896"}
0005432020929	ED559F	1208 541899	DMITRIY SEMENOV	{"email": "semenov_dmitriy1965@postgrespro.ru", "phone": "+70100817088"}
0005432020930	ED559F	7953 592760	ANDREY TIMOFEEV	{"phone": "+70314109480"}
0005432020931	1DD0DB	3322 321714	VLADISLAV NIKITIN	{"phone": "+70693162189"}
0005432020932	6DF743	2432 128706	PAVEL KUZNECOV	{"phone": "+70565519553"}
0005432020933	586CF1	9880 778764	OLGA GUSEVA	{"email": "olga-guseva-1976@postgrespro.ru", "phone": "+70476260446"}
0005432020934	586CF1	6809 154137	MAKSIM MELNIKOV	{"email": "melnikovm_1982@postgrespro.ru", "phone": "+70183634355"}
0005432020935	8AB0A1	1088 311230	VLADIMIR CHERNOV	{"phone": "+70322317817"}
0005432020936	B8289C	9062 654969	ROMAN NOVIKOV	{"phone": "+70189368195"}
0005432020937	B8289C	7998 841224	ELENA KUZNECOVA	{"email": "e.kuznecova041981@postgrespro.ru", "phone": "+70991074868"}
0005432020938	6484C7	2176 966700	NATALYA EFIMOVA	{"phone": "+70165332809"}
0005432020939	A2CABD	1426 046936	NIKOLAY PAVLOV	{"email": "nikolay_pavlov.1979@postgrespro.ru", "phone": "+70779499675"}
0005432020940	A2CABD	6165 274665	OLGA KULIKOVA	{"phone": "+70303990121"}
0005432020941	A2CABD	3758 584036	ARTUR GRIGOREV	{"email": "grigorev_artur_27071978@postgrespro.ru", "phone": "+70530207311"}
0005432020942	37CC59	2893 047176	ELENA IVANOVA	{"phone": "+70909993305"}
0005432020943	7793A0	0562 142668	VERA FEDOROVA	{"email": "v-fedorova_16041978@postgrespro.ru", "phone": "+70376952465"}
0005432020944	FA337E	1783 552340	VIKTOR CHERNOV	{"phone": "+70391381261"}
0005432020945	968812	4307 485018	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva-15121972@postgrespro.ru", "phone": "+70851859717"}
0005432020946	968812	8722 109886	IRINA SAVELEVA	{"phone": "+70625383384"}
0005432020947	551C2C	0466 000402	TATYANA FILATOVA	{"phone": "+70874385836"}
0005432020948	AFEC44	4490 150775	VLADIMIR NOVIKOV	{"email": "vladimir-novikov-1985@postgrespro.ru", "phone": "+70325025286"}
0005432020949	0C7C23	4342 551719	IRINA ANTONOVA	{"phone": "+70421075775"}
0005432020950	A05E72	2655 129648	IVAN KUZNECOV	{"phone": "+70629705980"}
0005432020951	A05E72	6335 372723	MATVEY NOVIKOV	{"email": "novikov.matvey-091980@postgrespro.ru", "phone": "+70023358877"}
0005432020952	2E145B	6131 139823	YURIY NAZAROV	{"email": "ynazarov-10091978@postgrespro.ru", "phone": "+70304615348"}
0005432020953	B23BAD	6392 105177	SERGEY KRASNOV	{"email": "skrasnov.19111963@postgrespro.ru", "phone": "+70478366568"}
0005432020954	D81CF0	1852 521528	NATALYA FROLOVA	{"email": "natalyafrolova.061970@postgrespro.ru", "phone": "+70901196446"}
0005432020955	D81CF0	0517 071367	NADEZHDA KOLESNIKOVA	{"email": "kolesnikova.nadezhda-1953@postgrespro.ru", "phone": "+70971924505"}
0005432020956	11D04C	9278 210619	ANASTASIYA KONDRATEVA	{"phone": "+70283122156"}
0005432020957	5312B6	7725 318036	ANNA KOROLEVA	{"email": "koroleva_a.051966@postgrespro.ru", "phone": "+70286072739"}
0005432020960	CF61BC	5319 601038	TATYANA ALEKSEEVA	{"phone": "+70358399511"}
0005432020961	CF61BC	9039 920478	PAVEL POPOV	{"email": "popov_pavel-07021981@postgrespro.ru", "phone": "+70531093335"}
0005432020962	CF61BC	8148 383297	KONSTANTIN PAVLOV	{"email": "k-pavlov-1979@postgrespro.ru", "phone": "+70772550974"}
0005432020963	CE2722	7569 714837	GENNADIY ZAKHAROV	{"phone": "+70711233272"}
0005432020964	CE2722	0592 663982	NINA SIDOROVA	{"email": "n-sidorova_24041969@postgrespro.ru", "phone": "+70998474765"}
0005432020965	CE2722	6070 172385	ULYANA VOROBEVA	{"email": "u-vorobeva.1966@postgrespro.ru", "phone": "+70336569866"}
0005432020966	4BD350	9158 760131	VLADIMIR GAVRILOV	{"phone": "+70778297670"}
0005432020967	F96E8A	9276 773936	KSENIYA PAVLOVA	{"email": "k_pavlova.1966@postgrespro.ru", "phone": "+70749147423"}
0005432020968	F96E8A	0645 970754	IRINA ORLOVA	{"email": "orlova.i.1969@postgrespro.ru", "phone": "+70716000015"}
0005432020969	827F4C	5169 300185	TATYANA MOROZOVA	{"email": "tmorozova1962@postgrespro.ru", "phone": "+70339226571"}
0005432020970	E3E9EB	3968 358664	TAMARA SEMENOVA	{"email": "semenova.tamara23101968@postgrespro.ru", "phone": "+70299946832"}
0005432020971	E3E9EB	1456 190820	MARIYA ZAKHAROVA	{"phone": "+70951124257"}
0005432020972	61EF87	4399 566001	ALEKSANDR ISAEV	{"email": "aleksandr_isaev061960@postgrespro.ru", "phone": "+70769887795"}
0005432020973	D9D933	8576 696171	VLADIMIR TIKHONOV	{"email": "tikhonovv.1965@postgrespro.ru", "phone": "+70666005913"}
0005432020974	D9D933	8957 795169	SVETLANA PETROVA	{"email": "s-petrova-15041979@postgrespro.ru", "phone": "+70354654027"}
0005432020975	6CDFC5	7883 367174	RIMMA FADEEVA	{"phone": "+70712596425"}
0005432020976	145B76	7532 777470	EVGENIY DMITRIEV	{"email": "edmitriev-121957@postgrespro.ru", "phone": "+70314623359"}
0005432020977	145B76	5177 906325	EDUARD GORBUNOV	{"email": "eduardgorbunov-05021982@postgrespro.ru", "phone": "+70885348792"}
0005432020978	CB5C08	0461 349880	VENERA ZAYCEVA	{"email": "v_zayceva_17011965@postgrespro.ru", "phone": "+70593541519"}
0005432020979	CB5C08	9047 892511	ALEKSANDRA KISELEVA	{"phone": "+70371562836"}
0005432020980	D6A71F	9153 877408	MAKSIM PETROV	{"email": "petrovm-1980@postgrespro.ru", "phone": "+70677876048"}
0005432020981	3F8CDA	1883 483245	DENIS PETROV	{"email": "petrovdenis-081960@postgrespro.ru", "phone": "+70399995549"}
0005432020982	3F8CDA	1151 048263	KSENIYA AFANASEVA	{"phone": "+70138562122"}
0005432020983	3F8CDA	7001 932323	ZULFIYA MAKSIMOVA	{"phone": "+70047538912"}
0005432020984	21210B	1418 244285	ALEKSANDR SMIRNOV	{"phone": "+70493989507"}
0005432020985	337A89	4956 218886	ALEKSANDR NOVIKOV	{"phone": "+70676566427"}
0005432020986	337A89	2857 802474	YAROSLAV KAZAKOV	{"phone": "+70647686745"}
0005432020987	3A1266	1763 727818	INNA POPOVA	{"email": "popova_inna-18081963@postgrespro.ru", "phone": "+70832272189"}
0005432020988	3A1266	4918 134664	NATALYA NESTEROVA	{"email": "nesterova_natalya_1972@postgrespro.ru", "phone": "+70234418192"}
0005432020989	3B2439	8499 133762	EVGENIYA NOVIKOVA	{"email": "e.novikova-081975@postgrespro.ru", "phone": "+70950254101"}
0005432020990	2E37D2	5371 724035	GALINA AKIMOVA	{"phone": "+70238784426"}
0005432020991	DA74F7	2609 860251	ANATOLIY KARPOV	{"email": "karpovanatoliy-121965@postgrespro.ru", "phone": "+70234100739"}
0005432020992	DA74F7	4927 224803	ANATOLIY VASILEV	{"email": "anatoliyvasilev071981@postgrespro.ru", "phone": "+70124439369"}
0005432020993	AB9DDB	9767 470970	IRINA MELNIKOVA	{"email": "imelnikova-101979@postgrespro.ru", "phone": "+70219071889"}
0005432020994	AB9DDB	9831 729843	LARISA BELOVA	{"phone": "+70233539878"}
0005432020995	20ED7A	6671 286364	ELVIRA DAVYDOVA	{"email": "davydovaelvira-111976@postgrespro.ru", "phone": "+70150289854"}
0005432020996	20ED7A	5475 905743	SERGEY DMITRIEV	{"phone": "+70522238576"}
0005432020997	389FEE	9737 721936	ARTUR MAKAROV	{"email": "artur.makarov_19061981@postgrespro.ru", "phone": "+70387292660"}
0005432020998	4A57BD	1255 347091	EGOR SERGEEV	{"email": "egorsergeev.081957@postgrespro.ru", "phone": "+70624954761"}
0005432020999	4A57BD	9593 763670	SERGEY GRIGOREV	{"phone": "+70782021409"}
0005432021000	62DABB	7088 609872	ANDREY TIKHONOV	{"phone": "+70950823723"}
0005432021001	62DABB	4479 616607	ANATOLIY ROMANOV	{"phone": "+70049309813"}
0005432021002	62DABB	6931 582384	YULIYA POPOVA	{"phone": "+70653540442"}
0005432021003	F07734	2529 175692	VALENTINA IVANOVA	{"email": "ivanova.v-16031980@postgrespro.ru", "phone": "+70949551446"}
0005432021004	F07734	1527 494419	TATYANA ANDREEVA	{"phone": "+70564095971"}
0005432021005	F07734	3680 362502	DMITRIY RODIONOV	{"phone": "+70022771448"}
0005432021006	B72815	2366 339682	ANDREY CHERNOV	{"email": "a_chernov.091979@postgrespro.ru", "phone": "+70632525742"}
0005432021007	7882EB	1120 739138	LYUBOV POPOVA	{"email": "popova.l15061970@postgrespro.ru", "phone": "+70088525828"}
0005432021008	E0603E	7720 154798	VALENTINA YAKOVLEVA	{"email": "valentina-yakovleva081981@postgrespro.ru", "phone": "+70913872824"}
0005432021009	685D3A	4402 925967	ELDAR MIKHAYLOV	{"email": "e-mikhaylov_01011965@postgrespro.ru", "phone": "+70811060322"}
0005432021010	7E33D1	2533 270386	ELIZAVETA AKIMOVA	{"email": "elizaveta_akimova011973@postgrespro.ru", "phone": "+70549412425"}
0005432021011	7E33D1	9369 619888	MIKHAIL NAUMOV	{"email": "naumov-m.06021962@postgrespro.ru", "phone": "+70778734580"}
0005432021012	7E33D1	7926 118240	DENIS ZAYCEV	{"email": "zaycev_denis021958@postgrespro.ru", "phone": "+70565092743"}
0005432021013	0677FD	1627 649296	OLGA DENISOVA	{"phone": "+70878093208"}
0005432021014	090C7B	8666 765700	VALERIY PETROV	{"phone": "+70145303518"}
0005432021015	090C7B	1691 317193	KSENIYA ILINA	{"phone": "+70656295336"}
0005432021016	71EB58	8604 202652	VALENTINA RYABOVA	{"email": "ryabovavalentina.1966@postgrespro.ru", "phone": "+70036111025"}
0005432021017	9794BB	6770 583696	FEDOR TIKHONOV	{"phone": "+70284689253"}
0005432021018	7E0A7A	7322 506118	VERA SIDOROVA	{"email": "v_sidorova_051976@postgrespro.ru", "phone": "+70000300547"}
0005432021019	DF0B34	4128 820512	TATYANA EGOROVA	{"phone": "+70311774588"}
0005432021020	DF0B34	9287 656957	MIKHAIL KUZMIN	{"email": "kuzmin.mikhail_13071979@postgrespro.ru", "phone": "+70375622761"}
0005432021021	4F9C6A	0333 814087	RAFAEL STEPANOV	{"phone": "+70466698868"}
0005432021022	31C55D	0619 795298	PAVEL KUZNECOV	{"phone": "+70060375186"}
0005432021023	89C690	4951 779362	SVETLANA EGOROVA	{"phone": "+70891652436"}
0005432021024	DECD0D	1334 052599	YULIYA DMITRIEVA	{"email": "dmitrieva.y25071976@postgrespro.ru", "phone": "+70018522480"}
0005432021025	E9ACC0	6154 743797	NATALYA MAKSIMOVA	{"email": "maksimova-n021961@postgrespro.ru", "phone": "+70705686105"}
0005432021026	E9ACC0	8446 446114	VLADISLAV IVANOV	{"phone": "+70311934474"}
0005432021027	8390A3	4405 586288	LIDIYA KOZLOVA	{"phone": "+70350624980"}
0005432021028	43E6DD	8835 090147	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova-1977@postgrespro.ru", "phone": "+70671138552"}
0005432021029	43E6DD	1485 704188	EVGENIY VASILEV	{"phone": "+70916866560"}
0005432021030	43E6DD	2303 471680	ELENA BELOVA	{"phone": "+70529571282"}
0005432021031	F7FD5C	3286 911729	DENIS VASILEV	{"email": "vasilev_denis1979@postgrespro.ru", "phone": "+70653393520"}
0005432021032	8F5589	9421 398737	OLGA PAVLOVA	{"email": "o-pavlova.091954@postgrespro.ru", "phone": "+70374991382"}
0005432021033	8F5589	6442 927968	ALEKSEY KRASNOV	{"email": "aleksey.krasnov-18111965@postgrespro.ru", "phone": "+70593885122"}
0005432021034	8F5589	6012 518568	NIKOLAY RODIONOV	{"email": "nikolay_rodionov061971@postgrespro.ru", "phone": "+70570266098"}
0005432021035	B618E5	5235 699410	VIKTOR VLASOV	{"email": "v.vlasov_091974@postgrespro.ru", "phone": "+70051029724"}
0005432021036	5225E7	5110 273139	ALEKSEY IVANOV	{"email": "ivanov-aleksey.18041958@postgrespro.ru", "phone": "+70842994010"}
0005432021037	5225E7	7100 012853	DENIS NAUMOV	{"email": "naumov-denis_071978@postgrespro.ru", "phone": "+70987842799"}
0005432021038	FB3262	6291 241494	IGOR ILIN	{"email": "ilini-1971@postgrespro.ru", "phone": "+70731753711"}
0005432021039	FB3262	8400 627984	IGOR SCHERBAKOV	{"phone": "+70913096800"}
0005432021040	162993	9663 010468	VLADIMIR FILIPPOV	{"email": "filippovv.22091977@postgrespro.ru", "phone": "+70272961558"}
0005432021041	B4818F	3392 588220	IGOR ALEKSEEV	{"phone": "+70687700194"}
0005432021042	6E6800	4332 680503	OKSANA KUDRYASHOVA	{"email": "okudryashova-23091970@postgrespro.ru", "phone": "+70736831544"}
0005432021043	1A7C12	8305 415869	ILYA KUZNECOV	{"phone": "+70684395270"}
0005432021044	021CC8	1911 035992	ALEKSEY KUZMIN	{"email": "kuzmin-a_1964@postgrespro.ru", "phone": "+70621090463"}
0005432021045	021CC8	2912 067235	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandra.aleksandrova.1975@postgrespro.ru", "phone": "+70366620581"}
0005432021046	021CC8	2751 142849	MARIYA KOLESNIKOVA	{"phone": "+70952134798"}
0005432021047	021CC8	7533 861411	IRINA KARPOVA	{"phone": "+70461466933"}
0005432021048	E16092	0455 225469	LIDIYA VLASOVA	{"phone": "+70935523623"}
0005432021049	668E53	0781 522878	EKATERINA VASILEVA	{"phone": "+70244338314"}
0005432021050	F05313	9353 024975	MARINA KOZLOVA	{"phone": "+70278050171"}
0005432034449	7B7E86	6602 529695	VALERIY SIDOROV	{"email": "valeriy-sidorov051986@postgrespro.ru", "phone": "+70519231090"}
0005432034450	7B7E86	0560 387284	IRINA ZAYCEVA	{"email": "zayceva_irina_1980@postgrespro.ru", "phone": "+70817354850"}
0005432034451	FD3844	8115 949393	DAMIR PETROV	{"phone": "+70285629180"}
0005432034452	91DAD0	0133 218731	NATALYA EGOROVA	{"phone": "+70897936611"}
0005432034453	5638A8	0976 213791	IRINA KAZAKOVA	{"email": "kazakovairina1974@postgrespro.ru", "phone": "+70933081452"}
0005432034454	36C8BB	1851 861757	VALENTINA KUZMINA	{"phone": "+70432027790"}
0005432034455	B4142C	2708 428983	VASILIY FEDOROV	{"phone": "+70004771859"}
0005432034456	117DB3	7118 133370	EGOR GRIGOREV	{"phone": "+70351644009"}
0005432034457	117DB3	7676 058535	ILYA POPOV	{"email": "popov.i.101955@postgrespro.ru", "phone": "+70043791513"}
0005432034458	117DB3	4676 645750	IGOR KUZNECOV	{"phone": "+70028973442"}
0005432034459	DBAAA1	1702 465372	DMITRIY ZHURAVLEV	{"email": "dmitriy-zhuravlev-04101966@postgrespro.ru", "phone": "+70085146726"}
0005432034460	8EB513	8672 549105	OLGA ZAKHAROVA	{"email": "zakharova_o-19041961@postgrespro.ru", "phone": "+70657638264"}
0005432034461	FD402A	7740 318263	OKSANA ALEKSANDROVA	{"email": "o.aleksandrova121975@postgrespro.ru", "phone": "+70143262363"}
0005432034462	DE169A	4728 993451	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey_1976@postgrespro.ru", "phone": "+70765806379"}
0005432034463	D40802	3491 821952	SERGEY MAKSIMOV	{"phone": "+70276327380"}
0005432034464	D40802	0440 419350	YULIYA ABRAMOVA	{"email": "yabramova.1964@postgrespro.ru", "phone": "+70493871116"}
0005432034465	5F72DE	1052 479322	OLEG MIKHAYLOV	{"email": "mikhaylov_o_1982@postgrespro.ru", "phone": "+70528594631"}
0005432034466	AAB8E8	7368 412461	OLGA SAVELEVA	{"phone": "+70363378952"}
0005432034467	B71F8B	0827 293636	DAVID NIKOLAEV	{"email": "d-nikolaev.1967@postgrespro.ru", "phone": "+70570982099"}
0005432034468	B71F8B	8806 663760	MARINA POPOVA	{"phone": "+70629547095"}
0005432034469	507B78	4817 541503	TATYANA MAKSIMOVA	{"phone": "+70898531477"}
0005432034470	606EBE	2310 724898	IGOR ANTONOV	{"email": "i.antonov04051982@postgrespro.ru", "phone": "+70429893125"}
0005432034471	6A2898	8985 950420	VALENTINA VASILEVA	{"email": "v-vasileva_24041975@postgrespro.ru", "phone": "+70819672697"}
0005432034472	D09F7B	3715 150926	NIKOLAY TARASOV	{"email": "tarasov-nikolay_111973@postgrespro.ru", "phone": "+70910718050"}
0005432034473	D09F7B	6324 221545	MARIYA STEPANOVA	{"phone": "+70324225165"}
0005432034474	95760F	4518 104615	LYUBOV GUSEVA	{"phone": "+70590238312"}
0005432034475	60623E	8530 065926	NIKITA MATVEEV	{"email": "matveev-n.061970@postgrespro.ru", "phone": "+70543411504"}
0005432034476	D98185	6730 272123	DMITRIY ZHUKOV	{"email": "dzhukov-061972@postgrespro.ru", "phone": "+70052060694"}
0005432034477	D98185	8953 029152	DANA SIDOROVA	{"phone": "+70175437140"}
0005432034478	93002A	5868 208848	IRINA BORISOVA	{"phone": "+70526565495"}
0005432034479	B2C59C	4092 646824	VALERIY ALEKSEEV	{"email": "alekseevvaleriy1975@postgrespro.ru", "phone": "+70064308383"}
0005432034480	B2C59C	7277 323748	VALENTINA SOROKINA	{"email": "sorokina.valentina_041983@postgrespro.ru", "phone": "+70050519342"}
0005432034481	8C0238	5088 270111	NATALIYA EFIMOVA	{"email": "efimova.n_08021979@postgrespro.ru", "phone": "+70862181770"}
0005432034482	E866CD	3913 923279	VADIM FILIPPOV	{"phone": "+70191857960"}
0005432034483	E866CD	0753 739358	NINA KOROLEVA	{"email": "nkoroleva-081968@postgrespro.ru", "phone": "+70411056715"}
0005432034484	2A48CC	4601 171733	RUSLAN MAKAROV	{"phone": "+70567896764"}
0005432034485	2A48CC	7357 007193	GALINA MEDVEDEVA	{"phone": "+70649693808"}
0005432034486	2A48CC	8980 595434	ZOYA ZHURAVLEVA	{"email": "z_zhuravleva.081976@postgrespro.ru", "phone": "+70725825555"}
0005432034487	64BE2C	1601 428223	OLEG SIDOROV	{"email": "olegsidorov-1968@postgrespro.ru", "phone": "+70456133784"}
0005432034488	8AACDD	3982 380471	SERGEY TARASOV	{"phone": "+70258032029"}
0005432034489	8AACDD	1582 269481	DMITRIY KUZNECOV	{"email": "d.kuznecov.05121967@postgrespro.ru", "phone": "+70427537647"}
0005432034490	03FF3A	7401 572567	ARTEM KONOVALOV	{"email": "konovalov.a.1970@postgrespro.ru", "phone": "+70905294671"}
0005432034491	6152DD	1683 370090	VALENTINA KAZAKOVA	{"phone": "+70211497695"}
0005432034492	583416	8883 274401	TATYANA MAKAROVA	{"phone": "+70309932009"}
0005432034493	D83400	5875 372815	SERGEY NIKOLAEV	{"phone": "+70160069134"}
0005432034494	DB18BA	3037 911189	DIANA TIMOFEEVA	{"phone": "+70742931940"}
0005432034495	6BEC64	1034 482477	SERGEY ZHUKOV	{"email": "sergey_zhukov-101967@postgrespro.ru", "phone": "+70591746943"}
0005432034496	ACD899	0541 372437	ALEKSANDR FROLOV	{"phone": "+70047754603"}
0005432034497	1717AF	1890 523487	ANNA ERMAKOVA	{"phone": "+70812348613"}
0005432034498	1717AF	2252 361597	ANASTASIYA SOKOLOVA	{"email": "anastasiya_sokolova_1976@postgrespro.ru", "phone": "+70727352733"}
0005432034499	8B4DBC	7799 507833	VLADIMIR BORISOV	{"phone": "+70359727157"}
0005432034500	8B4DBC	9622 105001	ALEKSANDR VASILEV	{"email": "vasilev.a-091983@postgrespro.ru", "phone": "+70822946982"}
0005432034501	4AD1AA	0611 172251	OLEG SEMENOV	{"email": "o.semenov-22031977@postgrespro.ru", "phone": "+70670518148"}
0005432034502	4AD1AA	6024 165875	TATYANA MATVEEVA	{"email": "matveeva_t17111974@postgrespro.ru", "phone": "+70208180244"}
0005432034503	899C71	3847 866741	ELENA ABRAMOVA	{"email": "e.abramova-1976@postgrespro.ru", "phone": "+70805699318"}
0005432034504	86D780	0752 320983	IRINA ALEKSANDROVA	{"email": "irina_aleksandrova-101975@postgrespro.ru", "phone": "+70718728742"}
0005432034505	B23AB2	9917 919409	NIKOLAY ZHURAVLEV	{"phone": "+70170626069"}
0005432034506	069859	1711 775411	SVETLANA ANTONOVA	{"email": "svetlana-antonova-1974@postgrespro.ru", "phone": "+70510934435"}
0005432034507	069859	5686 016897	VADIM ROMANOV	{"phone": "+70091921519"}
0005432034508	714829	8815 003754	SERGEY MOROZOV	{"email": "morozov_sergey_04101972@postgrespro.ru", "phone": "+70229291144"}
0005432034509	E5848E	4423 540899	VALENTINA IVANOVA	{"email": "ivanova_v111986@postgrespro.ru", "phone": "+70621863506"}
0005432034510	C72E90	9062 246688	ANDREY POPOV	{"phone": "+70504558866"}
0005432034511	6A6A3A	4829 238191	NINA SMIRNOVA	{"email": "n_smirnova_12121964@postgrespro.ru", "phone": "+70247715845"}
0005432034512	6A6A3A	1314 605120	LARISA FILIPPOVA	{"phone": "+70020906588"}
0005432034513	6A6A3A	4781 892027	TATYANA KOROLEVA	{"phone": "+70507008286"}
0005432034514	866000	0585 261672	ALEKSEY DAVYDOV	{"email": "aleksey.davydov-26031967@postgrespro.ru", "phone": "+70323788103"}
0005432034515	2424F4	7906 936479	NADEZHDA NIKITINA	{"phone": "+70814800155"}
0005432034516	5CF08B	4705 222108	GALINA ABRAMOVA	{"email": "abramovag-26021973@postgrespro.ru", "phone": "+70288526408"}
0005432034517	5CF08B	7862 856123	ANTON MOROZOV	{"email": "anton_morozov021977@postgrespro.ru", "phone": "+70704769141"}
0005432034518	9DA97E	8834 848362	TATYANA KALININA	{"email": "kalinina_tatyana1959@postgrespro.ru", "phone": "+70372300224"}
0005432034519	FC92DD	3307 766901	NINA PAVLOVA	{"email": "nina-pavlova111964@postgrespro.ru", "phone": "+70981661239"}
0005432034520	FC92DD	5753 106304	ELENA FROLOVA	{"phone": "+70658086868"}
0005432034521	269DB1	3848 186139	SERGEY KUZNECOV	{"phone": "+70331452706"}
0005432034522	0E1EF3	4272 615447	ANDREY SEMENOV	{"email": "semenov-andrey_05101972@postgrespro.ru", "phone": "+70122672081"}
0005432034523	0E1EF3	2008 138788	ANTONINA BELYAEVA	{"phone": "+70494932136"}
0005432034524	0D747B	1741 533370	VIKTOR BORISOV	{"email": "viktor-borisov-29101972@postgrespro.ru", "phone": "+70640609252"}
0005432034525	F33D3F	5958 463032	ANATOLIY NIKITIN	{"email": "a.nikitin.04061964@postgrespro.ru", "phone": "+70210349937"}
0005432034526	80EB42	5844 402295	DMITRIY ZAYCEV	{"phone": "+70222735391"}
0005432034527	80EB42	9979 525163	LILIYA KUZMINA	{"email": "kuzmina.liliya-1973@postgrespro.ru", "phone": "+70745907524"}
0005432034528	80EB42	7939 839236	ALESYA VOLKOVA	{"phone": "+70261387851"}
0005432034529	B70783	8166 318367	ELENA DMITRIEVA	{"phone": "+70851205776"}
0005432034530	1D8C85	3288 826564	EVGENIY ROMANOV	{"phone": "+70811418040"}
0005432034531	37D32D	2567 811995	SVETLANA POLYAKOVA	{"phone": "+70019732917"}
0005432034532	71038D	2238 235347	OKSANA GUSEVA	{"email": "oguseva07021968@postgrespro.ru", "phone": "+70703036736"}
0005432034533	71038D	2439 362869	TATYANA KRASNOVA	{"email": "tatyana_krasnova_031971@postgrespro.ru", "phone": "+70337909681"}
0005432034534	0A7301	7555 954204	ELENA KUZMINA	{"email": "kuzmina_e.25121970@postgrespro.ru", "phone": "+70577991785"}
0005432034535	4C8B22	3517 328592	NIKOLAY IVANOV	{"phone": "+70409026091"}
0005432034536	4C8B22	6702 600950	KRISTINA ANDREEVA	{"phone": "+70884815813"}
0005432034537	3BFFE3	5510 328384	EKATERINA IVANOVA	{"email": "ivanova-ekaterina.1971@postgrespro.ru", "phone": "+70692545337"}
0005432034538	3BFFE3	4861 347050	ARTUR FILIPPOV	{"phone": "+70965695726"}
0005432034539	34C6DF	1852 262503	ELENA EGOROVA	{"email": "egorova_elena.21041978@postgrespro.ru", "phone": "+70243849623"}
0005432034540	34C6DF	2254 429295	NIKOLAY KONOVALOV	{"phone": "+70859909991"}
0005432034541	FBF5C5	5794 022801	VLADIMIR ILIN	{"email": "v.ilin_27031974@postgrespro.ru", "phone": "+70636289177"}
0005432034542	8B1BC1	8826 162093	DMITRIY KRASNOV	{"phone": "+70377096584"}
0005432034543	470BFF	5898 556506	YULIYA ILINA	{"phone": "+70839433053"}
0005432034544	658DF3	1103 159952	EKATERINA DANILOVA	{"email": "e.danilova.021975@postgrespro.ru", "phone": "+70183410042"}
0005432034545	8BBCC3	9123 760144	ANNA DENISOVA	{"phone": "+70308756766"}
0005432034546	8BBCC3	7686 677837	MARIYA ZHUKOVA	{"phone": "+70469716662"}
0005432034547	1D2110	9701 794919	ANTON BELOV	{"phone": "+70666047488"}
0005432034548	1D2110	1513 861557	ELENA GUSEVA	{"phone": "+70158202857"}
0005432034549	5A123A	2664 405083	NATALYA SOROKINA	{"email": "sorokinan-03111972@postgrespro.ru", "phone": "+70245396341"}
0005432034550	F77AD7	5180 523245	LIDIYA KRASNOVA	{"email": "krasnova_lidiya.011973@postgrespro.ru", "phone": "+70246877451"}
0005432034551	F77AD7	8724 519448	VALERIY FILIPPOV	{"email": "filippov_valeriy_14031969@postgrespro.ru", "phone": "+70256138842"}
0005432034552	F77AD7	7767 140148	VALERIYA BELYAEVA	{"phone": "+70623643505"}
0005432034553	B0316A	6716 763513	VLADIMIR ZHUKOV	{"email": "zhukov_vladimir101978@postgrespro.ru", "phone": "+70098802657"}
0005432034554	859885	4635 731275	MARIYA ZAKHAROVA	{"email": "zakharova.m_05081964@postgrespro.ru", "phone": "+70366715715"}
0005432034555	2F748F	4391 060567	EKATERINA KRASNOVA	{"email": "krasnova_e.081977@postgrespro.ru", "phone": "+70047366495"}
0005432034556	D67B49	7837 666864	LYUBOV POTAPOVA	{"phone": "+70207171899"}
0005432034557	FA6A3F	6866 529295	ULYANA POPOVA	{"email": "popovaulyana.121972@postgrespro.ru", "phone": "+70246617905"}
0005432034558	2D8135	4144 232685	ALEKSANDR SCHERBAKOV	{"phone": "+70122988417"}
0005432034559	2D8135	3011 363247	MARIYA RODIONOVA	{"phone": "+70436474123"}
0005432034560	07C1A3	4874 607818	TATYANA TROFIMOVA	{"phone": "+70736327093"}
0005432034561	F33746	5519 601143	VIKTOR KULIKOV	{"email": "v.kulikov-031967@postgrespro.ru", "phone": "+70099297234"}
0005432034562	7CF561	1951 793935	ROMAN ALEKSANDROV	{"email": "r.aleksandrov.1974@postgrespro.ru", "phone": "+70626104850"}
0005432034563	76A95C	5806 203218	ELENA SERGEEVA	{"email": "sergeeva_elena_111979@postgrespro.ru", "phone": "+70650043446"}
0005432034564	6696C6	3677 982673	ANTON SEMENOV	{"phone": "+70787811467"}
0005432034565	5F68BB	9997 565701	ANTONINA VASILEVA	{"phone": "+70233241722"}
0005432034566	BACABE	1917 214964	LARISA KAZAKOVA	{"email": "larisakazakova-12031968@postgrespro.ru", "phone": "+70838733899"}
0005432034567	BACABE	4366 415353	SERGEY KONOVALOV	{"email": "konovalov.sergey_041970@postgrespro.ru", "phone": "+70318309517"}
0005432034568	BACABE	0560 043694	OLGA NESTEROVA	{"email": "o-nesterova_11081973@postgrespro.ru", "phone": "+70856768255"}
0005432034569	494770	1130 278503	ANATOLIY GUSEV	{"email": "a.gusev19081974@postgrespro.ru", "phone": "+70847053798"}
0005432034570	047769	3119 546863	ILSHAT ABRAMOV	{"phone": "+70650699205"}
0005432034571	047769	2802 934872	NADEZHDA MAKAROVA	{"email": "makarova_n20021970@postgrespro.ru", "phone": "+70650314496"}
0005432034572	4B7674	5220 525863	TAMARA VASILEVA	{"email": "tamara_vasileva-121969@postgrespro.ru", "phone": "+70455452439"}
0005432034573	C763CB	4459 627783	VIKTOR SERGEEV	{"email": "v-sergeev_1977@postgrespro.ru", "phone": "+70872272529"}
0005432034574	D89B61	9790 282472	DENIS IVANOV	{"phone": "+70970707863"}
0005432034575	D89B61	4213 080200	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov-03031962@postgrespro.ru", "phone": "+70412338345"}
0005432034576	722705	3680 144936	MIKHAIL DMITRIEV	{"phone": "+70074422313"}
0005432034577	37F27F	4506 963221	VADIM SOLOVEV	{"email": "vadim_solovev071978@postgrespro.ru", "phone": "+70720885156"}
0005432034578	44B9D6	6707 333639	IRINA NESTEROVA	{"phone": "+70520089672"}
0005432034579	BB01AB	8017 168518	IVAN NOVIKOV	{"email": "novikovivan1968@postgrespro.ru", "phone": "+70320827744"}
0005432034580	A22333	3919 650595	IGOR KULIKOV	{"phone": "+70202507695"}
0005432034581	71DE63	9136 313941	ARTEM SOROKIN	{"email": "artemsorokin.12121982@postgrespro.ru", "phone": "+70403098491"}
0005432034582	09B0A3	2236 124479	OLEG OSIPOV	{"phone": "+70571519000"}
0005432034583	5F55DB	1520 589267	ALEKSANDR IVANOV	{"email": "a-ivanov1979@postgrespro.ru", "phone": "+70645038643"}
0005432034584	5F55DB	4153 472534	DMITRIY KRASNOV	{"email": "d-krasnov051984@postgrespro.ru", "phone": "+70766645950"}
0005432034585	5F55DB	8186 857627	ANDREY SEMENOV	{"email": "semenov.andrey_07111977@postgrespro.ru", "phone": "+70285696595"}
0005432034586	AE9D1A	0724 473238	YAROSLAV POPOV	{"phone": "+70431105377"}
0005432034587	759E53	5660 878537	GERMAN NOVIKOV	{"phone": "+70250149888"}
0005432034588	759E53	9177 869715	POLINA KONDRATEVA	{"email": "kondrateva.p_051971@postgrespro.ru", "phone": "+70037641810"}
0005432034589	F6B2C7	6340 249174	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin08121974@postgrespro.ru", "phone": "+70696952195"}
0005432034590	608996	3039 059496	FLYURA KRASNOVA	{"email": "f_krasnova06011968@postgrespro.ru", "phone": "+70049287749"}
0005432034591	87FB98	6153 353968	LYUDMILA IVANOVA	{"email": "ivanovalyudmila-1968@postgrespro.ru", "phone": "+70535071443"}
0005432034592	87FB98	7568 868804	DENIS IVANOV	{"phone": "+70883078054"}
0005432034593	E79E72	4320 714640	GALINA VASILEVA	{"phone": "+70749322030"}
0005432034594	D20CEF	4328 098757	VASILIY FOMIN	{"email": "fomin-v_071971@postgrespro.ru", "phone": "+70315902964"}
0005432034595	D20CEF	2265 249832	VASILIY EGOROV	{"email": "vasiliyegorov011975@postgrespro.ru", "phone": "+70532017361"}
0005432034596	4EC39B	1284 417202	ELENA KUZNECOVA	{"phone": "+70318427207"}
0005432034597	8A6D2D	1228 498135	RAISA BARANOVA	{"email": "baranova-r_1966@postgrespro.ru", "phone": "+70718249390"}
0005432034598	8A6D2D	1346 042136	NATALYA NIKOLAEVA	{"email": "n.nikolaeva_081979@postgrespro.ru", "phone": "+70197199111"}
0005432034599	B39E66	0695 282580	YURIY MEDVEDEV	{"email": "y-medvedev-06031974@postgrespro.ru", "phone": "+70245830473"}
0005432034600	7E9318	7614 011500	MARIYA LOGINOVA	{"email": "loginova-mariya_021979@postgrespro.ru", "phone": "+70877976078"}
0005432034601	4513FB	8106 644761	MARINA KARPOVA	{"email": "karpova-m011977@postgrespro.ru", "phone": "+70575792987"}
0005432034602	44092E	2485 453883	ALEKSANDR NAZAROV	{"email": "a.nazarov1967@postgrespro.ru", "phone": "+70697880179"}
0005432034603	44092E	3997 977503	DANIIL NIKOLAEV	{"phone": "+70119165761"}
0005432034604	74ED53	1726 448247	GALINA ALEKSANDROVA	{"email": "aleksandrova.g-18091983@postgrespro.ru", "phone": "+70992907222"}
0005432034605	C9B170	6240 814590	DMITRIY SIDOROV	{"phone": "+70051549814"}
0005432034606	DBAD80	1122 914712	POLINA OSIPOVA	{"phone": "+70652917812"}
0005432034607	7477FC	8082 219157	ANATOLIY MOISEEV	{"email": "moiseev-a-11061970@postgrespro.ru", "phone": "+70438231840"}
0005432034608	BBBBAC	8996 923885	MARGARITA ROMANOVA	{"email": "romanova-margarita-1979@postgrespro.ru", "phone": "+70676467745"}
0005432034609	08706B	0966 435489	RUSLAN GUSEV	{"email": "gusev.ruslan_081981@postgrespro.ru", "phone": "+70625463332"}
0005432034610	93FA10	6194 633633	ULYANA IVANOVA	{"phone": "+70737281545"}
0005432034611	A65966	3773 300189	EKATERINA MIRONOVA	{"email": "mironova.ekaterina_121976@postgrespro.ru", "phone": "+70728739617"}
0005432034612	A65966	3945 391688	ALEKSANDR TIKHONOV	{"phone": "+70419563318"}
0005432034613	9ADFBD	9236 819734	NATALYA GORBUNOVA	{"phone": "+70320039524"}
0005432034614	55C812	5952 315495	NATALYA ZAKHAROVA	{"phone": "+70953163226"}
0005432034615	2644B5	9092 046139	LIDIYA KUZNECOVA	{"phone": "+70657346187"}
0005432034616	2644B5	9476 485745	ELENA KUZNECOVA	{"phone": "+70562531569"}
0005432034617	2644B5	3835 713094	SVETLANA MALYSHEVA	{"phone": "+70116502809"}
0005432034618	43B2EE	0048 652852	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_011971@postgrespro.ru", "phone": "+70528731492"}
0005432034619	7EE9F7	4353 188752	ALEKSEY ANDREEV	{"phone": "+70129922081"}
0005432034620	6BBA9D	0263 836082	VYACHESLAV SCHERBAKOV	{"email": "scherbakov.vyacheslav.1973@postgrespro.ru", "phone": "+70870913707"}
0005432034621	613017	1399 934911	ANASTASIYA KAZAKOVA	{"phone": "+70192515734"}
0005432034622	613017	5073 704326	ARTEM BELOV	{"phone": "+70130653599"}
0005432034623	B77EBC	2587 344858	MARIYA KAZAKOVA	{"phone": "+70074957162"}
0005432034624	AFF245	0709 193972	ANATOLIY PAVLOV	{"phone": "+70056028191"}
0005432034625	76EF3A	6336 871374	TIGRAN SERGEEV	{"phone": "+70361400767"}
0005432034626	086C2C	8736 401059	OLGA NAZAROVA	{"phone": "+70531025708"}
0005432034627	001269	2853 922120	BORIS ORLOV	{"email": "orlov.boris121981@postgrespro.ru", "phone": "+70381699675"}
0005432034628	001269	2667 544137	MARIYA NIKOLAEVA	{"phone": "+70500305342"}
0005432034629	001269	5157 134525	NIKOLAY CHERNOV	{"email": "chernov-n1968@postgrespro.ru", "phone": "+70359486833"}
0005432034630	763EAF	4972 530798	NINA NIKITINA	{"phone": "+70462116884"}
0005432034631	763EAF	6589 698018	ANDREY ROMANOV	{"phone": "+70723715099"}
0005432034632	EF09A7	0862 656444	SVETLANA SCHERBAKOVA	{"phone": "+70151454487"}
0005432034633	BEA686	1468 450242	VLADIMIR ZAKHAROV	{"phone": "+70415657536"}
0005432034634	BEA686	8280 882473	ALLA ROMANOVA	{"phone": "+70831349864"}
0005432034635	170A25	9178 502144	VALENTINA VOLKOVA	{"phone": "+70418936068"}
0005432034636	170A25	3554 874598	GENNADIY EGOROV	{"email": "egorov_g1971@postgrespro.ru", "phone": "+70726291200"}
0005432034637	C187A4	6832 112355	DMITRIY FEDOROV	{"email": "fedorov.dmitriy-08071979@postgrespro.ru", "phone": "+70951112081"}
0005432034638	B47ABB	5534 215577	EVGENIYA POPOVA	{"email": "popovae.121979@postgrespro.ru", "phone": "+70869140018"}
0005432034639	1781F7	2875 916271	ALEKSANDR MATVEEV	{"email": "matveev.a-28031956@postgrespro.ru", "phone": "+70238558022"}
0005432034640	1781F7	6728 070578	YULIYA FILIPPOVA	{"email": "y_filippova1977@postgrespro.ru", "phone": "+70289312941"}
0005432034641	8F4C73	3080 263184	NELLI GUSEVA	{"email": "guseva-nelli_101968@postgrespro.ru", "phone": "+70293183162"}
0005432034642	8F4C73	1879 013641	ALEKSANDR KONOVALOV	{"email": "konovalov.aleksandr.24041966@postgrespro.ru", "phone": "+70341756511"}
0005432034643	8F4C73	2638 069641	IRINA KUZNECOVA	{"email": "kuznecova.irina-31071965@postgrespro.ru", "phone": "+70769716409"}
0005432034644	0E4364	6610 498607	ZINAIDA DAVYDOVA	{"phone": "+70315049041"}
0005432034645	2B4FDD	2259 769471	GALINA MATVEEVA	{"email": "galina_matveeva_051972@postgrespro.ru", "phone": "+70398475159"}
0005432034646	EF7953	8151 579339	VALENTINA DANILOVA	{"email": "danilova-v.22121965@postgrespro.ru", "phone": "+70520056586"}
0005432034647	0BFACA	3264 176317	VALERIY CHERNOV	{"phone": "+70957813647"}
0005432034648	0BFACA	9405 033007	LYUBOV VOLKOVA	{"email": "l.volkova15081974@postgrespro.ru", "phone": "+70680769465"}
0005432034649	E668A5	1100 055588	IRINA SOLOVEVA	{"phone": "+70418453380"}
0005432034650	CAE703	5301 641227	ELENA NESTEROVA	{"phone": "+70557659781"}
0005432034651	949A05	9153 798788	DARYA KOROLEVA	{"email": "darya-koroleva26111970@postgrespro.ru", "phone": "+70994178549"}
0005432034652	949A05	5586 509163	EVA SIDOROVA	{"phone": "+70506168523"}
0005432034653	E11BF2	0335 599832	ALEKSANDRA KUZMINA	{"email": "aleksandra-kuzmina_1979@postgrespro.ru", "phone": "+70415843353"}
0005432034654	8F9ECA	9366 867862	MARINA MAKSIMOVA	{"phone": "+70592475905"}
0005432034655	640C7B	9461 722825	RAMIL PETROV	{"phone": "+70427888871"}
0005432034656	B3B4F6	3242 738505	ALEKSEY ANDREEV	{"phone": "+70480799345"}
0005432034657	B3B4F6	9688 120793	SERGEY VOLKOV	{"email": "volkov_sergey_15101966@postgrespro.ru", "phone": "+70184743318"}
0005432034658	869FAD	4174 151148	ANNA MEDVEDEVA	{"email": "anna.medvedeva071972@postgrespro.ru", "phone": "+70501905591"}
0005432034659	2ABA18	3951 885621	EKATERINA ISAEVA	{"email": "isaeva.ekaterina_1973@postgrespro.ru", "phone": "+70544537667"}
0005432034660	2ABA18	2483 401775	ALEKSANDR ORLOV	{"email": "orlov_a.1978@postgrespro.ru", "phone": "+70767901204"}
0005432034661	78B91F	4104 174362	NINA NAZAROVA	{"phone": "+70478554566"}
0005432034662	78B91F	8213 182997	GALINA PETROVA	{"phone": "+70082510957"}
0005432034663	8C9E42	0669 732498	LYUBOV TIMOFEEVA	{"email": "timofeeva.l1972@postgrespro.ru", "phone": "+70194572835"}
0005432034664	F16C61	1822 819957	OLGA IVANOVA	{"email": "ivanova_olga_1973@postgrespro.ru", "phone": "+70413436298"}
0005432034665	176294	5965 988319	NIKOLAY MAKAROV	{"phone": "+70347412332"}
0005432034666	A2E225	8705 336956	MARIYA RYABOVA	{"email": "mariya_ryabova.1968@postgrespro.ru", "phone": "+70349883792"}
0005432034667	5627D6	3378 941455	GENNADIY SMIRNOV	{"phone": "+70057363711"}
0005432034668	3EAE17	3667 304278	NATALYA ISAEVA	{"email": "isaevanatalya.02051982@postgrespro.ru", "phone": "+70941499348"}
0005432034669	DFBC3A	1149 646859	MAKSIM KUZMIN	{"email": "maksim_kuzmin051976@postgrespro.ru", "phone": "+70114757188"}
0005432034670	62D3AF	2719 570088	ALEKSANDR BONDARENKO	{"email": "a-bondarenko.20021978@postgrespro.ru", "phone": "+70209328356"}
0005432034671	3DF114	3711 849225	NIKOLAY MIKHAYLOV	{"email": "mikhaylov-n_061981@postgrespro.ru", "phone": "+70143653683"}
0005432034672	85B31D	2148 180842	ANDREY KISELEV	{"email": "kiselev.a111972@postgrespro.ru", "phone": "+70197949449"}
0005432034673	12CC2D	0259 665864	MIKHAIL BORISOV	{"phone": "+70295912742"}
0005432034674	05BFA4	9133 974483	MIKHAIL IVANOV	{"phone": "+70350787589"}
0005432034675	05BFA4	8051 672659	MARINA SAVELEVA	{"email": "saveleva.m_1972@postgrespro.ru", "phone": "+70112790142"}
0005432034676	762648	0174 841592	LEONID SERGEEV	{"email": "lsergeev_021970@postgrespro.ru", "phone": "+70860194178"}
0005432034677	37EFD8	9513 565556	OLGA MEDVEDEVA	{"email": "o-medvedeva-061983@postgrespro.ru", "phone": "+70496666126"}
0005432034678	7B765F	3750 665148	VIKTORIYA KOROLEVA	{"email": "koroleva-viktoriya_10021974@postgrespro.ru", "phone": "+70640703251"}
0005432034679	F66262	1321 888691	VLADIMIR MELNIKOV	{"email": "melnikov.vladimir021974@postgrespro.ru", "phone": "+70932587157"}
0005432034680	87A213	0627 072704	OLGA IVANOVA	{"phone": "+70695188169"}
0005432034681	13166B	0355 208444	ANNA AKIMOVA	{"phone": "+70949794801"}
0005432034682	9C4481	0244 491501	ALEKSANDRA KALININA	{"email": "kalinina-aleksandra14061973@postgrespro.ru", "phone": "+70791380374"}
0005432034683	DB67A5	8403 785914	LARISA MAKAROVA	{"email": "makarovalarisa_1970@postgrespro.ru", "phone": "+70803240291"}
0005432034684	C38885	9660 147733	OLESYA EGOROVA	{"phone": "+70129071759"}
0005432034685	92CA76	0003 638203	YURIY MAKSIMOV	{"phone": "+70342499584"}
0005432034686	669176	1281 443212	ALEKSEY GRIGOREV	{"phone": "+70157802640"}
0005432034687	669176	3386 523924	DARYA MARTYNOVA	{"email": "martynovad_1979@postgrespro.ru", "phone": "+70122171509"}
0005432034688	5BEE74	4933 145864	SERAFIMA ANDREEVA	{"phone": "+70918293732"}
0005432034689	F78418	8094 508778	ANNA MELNIKOVA	{"email": "melnikova.a-021979@postgrespro.ru", "phone": "+70317547665"}
0005432034690	1ADF39	1092 583397	ANTON SAVELEV	{"email": "savelev.a01051968@postgrespro.ru", "phone": "+70759242848"}
0005432034691	4011E6	6059 175577	ANATOLIY ORLOV	{"email": "a-orlov-1961@postgrespro.ru", "phone": "+70291945809"}
0005432034692	4011E6	2525 496576	TATYANA ABRAMOVA	{"email": "tatyana-abramova03091963@postgrespro.ru", "phone": "+70387369995"}
0005432034693	382F96	7678 763209	NADEZHDA CHERNOVA	{"phone": "+70157330045"}
0005432034694	67F009	3185 585282	TATYANA ABRAMOVA	{"email": "tatyana_abramova1972@postgrespro.ru", "phone": "+70251518360"}
0005432034695	F6AB36	6025 631020	YAROSLAV ISAEV	{"phone": "+70051282113"}
0005432034696	F6AB36	4649 356318	OKSANA VOROBEVA	{"email": "oksana.vorobeva-12121975@postgrespro.ru", "phone": "+70267322175"}
0005432034697	86C0BE	8188 414126	ANASTASIYA SIDOROVA	{"email": "sidorovaa_1967@postgrespro.ru", "phone": "+70542048299"}
0005432034698	B503FB	3569 588924	ELENA TROFIMOVA	{"phone": "+70893546365"}
0005432034699	1C042D	7497 435185	MIKHAIL GERASIMOV	{"email": "gerasimov.m-03051974@postgrespro.ru", "phone": "+70239989756"}
0005432034700	02A06B	1301 531923	IGOR VOROBEV	{"email": "vorobevi-05041956@postgrespro.ru", "phone": "+70534763801"}
0005432034701	02A06B	3615 982843	VIKTORIYA KOROLEVA	{"phone": "+70234383002"}
0005432034702	D6D0C8	5212 487043	ALEKSANDR KOZLOV	{"phone": "+70693693573"}
0005432034703	D6D0C8	4391 494368	ELENA SIDOROVA	{"phone": "+70533766062"}
0005432034704	CBAD89	8339 688645	EVGENIY BORISOV	{"phone": "+70544090889"}
0005432034705	658AE3	0199 645891	VLADISLAV MAKAROV	{"phone": "+70751871914"}
0005432034706	D8622E	9694 800778	NAILYA NIKIFOROVA	{"email": "nikiforovan_20101958@postgrespro.ru", "phone": "+70479344319"}
0005432034707	51BD22	8177 614435	SEMEN STEPANOV	{"email": "stepanovsemen.1985@postgrespro.ru", "phone": "+70750539540"}
0005432034708	7E8609	7474 554457	ZINAIDA DAVYDOVA	{"email": "davydova.zinaida_31071979@postgrespro.ru", "phone": "+70191963711"}
0005432034709	9C499C	3463 970064	LYUBOV FROLOVA	{"phone": "+70161740078"}
0005432034710	9C499C	5607 900705	SERGEY DMITRIEV	{"email": "s-dmitriev-20121968@postgrespro.ru", "phone": "+70412343145"}
0005432034711	9C499C	3245 441492	YURIY IVANOV	{"email": "ivanovy.04091982@postgrespro.ru", "phone": "+70705941944"}
0005432034712	520529	6736 891488	DANIL DENISOV	{"email": "denisov.danil-1970@postgrespro.ru", "phone": "+70334664946"}
0005432034713	D3D5BC	6059 723294	ZHANNA KOMAROVA	{"phone": "+70397654941"}
0005432034714	D3D5BC	4982 698098	LEONID POPOV	{"phone": "+70762387173"}
0005432034715	FBE174	5689 138398	DMITRIY POPOV	{"email": "popov_dmitriy-1977@postgrespro.ru", "phone": "+70127139240"}
0005432034716	A6B262	5127 489554	TATYANA VLASOVA	{"phone": "+70493053309"}
0005432034717	8CD44F	9799 677774	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov1971@postgrespro.ru", "phone": "+70928479908"}
0005432034718	6E9099	9441 215491	VERA KONOVALOVA	{"email": "v.konovalova-20091974@postgrespro.ru", "phone": "+70926360013"}
0005432034719	65C83D	9182 383961	ELENA MALYSHEVA	{"phone": "+70408326598"}
0005432034720	A82180	9611 656115	LYUDMILA SMIRNOVA	{"email": "smirnovalyudmila.071978@postgrespro.ru", "phone": "+70255239600"}
0005432034721	FFF642	4245 162140	ALEKSANDR ABRAMOV	{"email": "abramovaleksandr-03021965@postgrespro.ru", "phone": "+70702006856"}
0005432034722	CF5FE9	8654 948917	VALENTINA FOMINA	{"phone": "+70980164228"}
0005432034723	CF5FE9	0850 565381	POLINA CHERNOVA	{"phone": "+70051847143"}
0005432034724	94B30B	0029 363379	NATALYA MAKSIMOVA	{"email": "natalya_maksimova071972@postgrespro.ru", "phone": "+70412690845"}
0005432034725	F4503E	4106 529181	NIKOLAY ZHURAVLEV	{"email": "nikolay.zhuravlev13111971@postgrespro.ru", "phone": "+70273680555"}
0005432034726	F4503E	4570 864890	OLESYA MARTYNOVA	{"email": "martynova-olesya.1977@postgrespro.ru", "phone": "+70865337727"}
0005432034727	ACCCBA	7010 989475	VERA BOGDANOVA	{"email": "bogdanova-vera.31051978@postgrespro.ru", "phone": "+70477152412"}
0005432034728	A3F514	5882 041243	MAKSIM VOLKOV	{"email": "volkov.maksim041975@postgrespro.ru", "phone": "+70148168797"}
0005432034729	B12BE8	6118 827201	BORIS PETROV	{"phone": "+70125760511"}
0005432034730	44A558	4110 360732	RIMMA SIDOROVA	{"email": "r_sidorova-071973@postgrespro.ru", "phone": "+70752361139"}
0005432034731	44A558	1325 311925	TATYANA DENISOVA	{"email": "tatyanadenisova-1964@postgrespro.ru", "phone": "+70359322345"}
0005432034732	9DAD19	5410 843426	ELENA NESTEROVA	{"phone": "+70243392203"}
0005432034733	939A7D	5625 865961	MARIYA NOVIKOVA	{"email": "m.novikova.081960@postgrespro.ru", "phone": "+70328943255"}
0005432034734	939A7D	7433 627289	VASILIY KULIKOV	{"email": "kulikov_vasiliy-02091972@postgrespro.ru", "phone": "+70616457682"}
0005432034735	D45174	9968 162204	ANDREY RODIONOV	{"email": "rodionov.a14021977@postgrespro.ru", "phone": "+70599087226"}
0005432034736	D45174	7276 380534	NINA EFIMOVA	{"phone": "+70630856581"}
0005432034737	75BBD5	2795 280344	GENNADIY SEMENOV	{"email": "semenov.gennadiy1963@postgrespro.ru", "phone": "+70306014782"}
0005432034738	75BBD5	2550 208261	NIKOLAY DENISOV	{"email": "nikolay.denisov_02021976@postgrespro.ru", "phone": "+70884422927"}
0005432034739	795779	1821 578724	VYACHESLAV ROMANOV	{"email": "vyacheslav-romanov30061977@postgrespro.ru", "phone": "+70296042284"}
0005432034740	795779	4122 662986	VIKTOR IVANOV	{"email": "viktor.ivanov_011978@postgrespro.ru", "phone": "+70403906411"}
0005432034741	795779	9351 193309	RAISA ABRAMOVA	{"email": "raisa-abramova-1972@postgrespro.ru", "phone": "+70014995637"}
0005432034742	DDEACA	4174 886695	IGOR NIKOLAEV	{"phone": "+70287314641"}
0005432034743	DDEACA	2016 741144	EKATERINA TROFIMOVA	{"email": "trofimova-e_1974@postgrespro.ru", "phone": "+70419120956"}
0005432034744	D415D7	5440 368557	SVETLANA LAZAREVA	{"email": "s_lazareva.1965@postgrespro.ru", "phone": "+70470467105"}
0005432034745	F0B67E	5269 076952	EVGENIY FEDOROV	{"email": "e_fedorov061984@postgrespro.ru", "phone": "+70879410403"}
0005432034746	F20284	9876 117883	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana111979@postgrespro.ru", "phone": "+70574061139"}
0005432034747	F20284	0758 407027	OLGA KUDRYASHOVA	{"email": "kudryashova-olga.081976@postgrespro.ru", "phone": "+70887234052"}
0005432034748	F20284	3117 595772	VIKTOR POPOV	{"email": "v-popov.031975@postgrespro.ru", "phone": "+70600864184"}
0005432034749	17FBF7	3052 863415	KRISTINA PETROVA	{"email": "petrova-kristina.121970@postgrespro.ru", "phone": "+70062149972"}
0005432034750	17FBF7	3644 406751	VLADISLAV GUSEV	{"phone": "+70453814431"}
0005432034751	449974	7761 165369	VLADIMIR VOLKOV	{"phone": "+70956712433"}
0005432034752	449974	2885 978705	DIANA KARPOVA	{"email": "karpova-d-16061977@postgrespro.ru", "phone": "+70726597031"}
0005432034753	449974	1525 322812	IGOR KOZLOV	{"phone": "+70510659529"}
0005432034754	988B41	5769 625658	NIKOLAY DENISOV	{"phone": "+70482814125"}
0005432034755	3070D7	1699 700637	ALLA ABRAMOVA	{"phone": "+70773483438"}
0005432034756	31FE17	3866 709998	VLADISLAV KULIKOV	{"email": "v.kulikov-1975@postgrespro.ru", "phone": "+70556838910"}
0005432034757	F76410	1940 528601	SERGEY RODIONOV	{"email": "sergey.rodionov-051985@postgrespro.ru", "phone": "+70198845030"}
0005432034758	B545B3	4691 029227	SVETLANA ANDREEVA	{"phone": "+70020752686"}
0005432034759	B545B3	3229 107444	ALEKSANDRA ERMAKOVA	{"phone": "+70257612912"}
0005432034760	0439B8	5336 523437	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov_19061976@postgrespro.ru", "phone": "+70161597661"}
0005432034761	14E9A8	3994 992772	FARID BARANOV	{"phone": "+70950582449"}
0005432034762	9F3771	6659 212712	VALENTINA KOROLEVA	{"email": "korolevavalentina_04081981@postgrespro.ru", "phone": "+70701733846"}
0005432034763	D7D45D	8342 027709	IGOR KOZLOV	{"phone": "+70378629619"}
0005432034764	F332DC	2539 254883	EKATERINA SOROKINA	{"email": "sorokina_e041970@postgrespro.ru", "phone": "+70046743194"}
0005432034765	AC9522	1317 727139	ALEKSANDRA ORLOVA	{"phone": "+70691312253"}
0005432034766	65CBF0	6321 504020	ILYA VLASOV	{"email": "i_vlasov-17051976@postgrespro.ru", "phone": "+70915344663"}
0005432034767	65CBF0	4050 124535	TATYANA KUDRYASHOVA	{"phone": "+70823254168"}
0005432034768	AB8518	6927 150318	EVGENIY KULIKOV	{"phone": "+70464859900"}
0005432034769	AB8518	3283 625969	NINA CHERNOVA	{"phone": "+70797626565"}
0005432034770	538B39	4142 263390	KONSTANTIN BARANOV	{"email": "baranov-konstantin_111965@postgrespro.ru", "phone": "+70859711899"}
0005432034771	A0E08E	8706 730646	MAKSIM PAVLOV	{"email": "pavlov.m031985@postgrespro.ru", "phone": "+70511813107"}
0005432034772	EF88CB	7259 744508	IRINA SMIRNOVA	{"phone": "+70335143066"}
0005432034773	545195	0287 750351	VLADISLAV DAVYDOV	{"phone": "+70928381932"}
0005432034774	275E99	5189 414429	SVETLANA IVANOVA	{"phone": "+70011446064"}
0005432034775	05A202	5191 005330	ALEKSANDR KUDRYASHOV	{"email": "kudryashova1974@postgrespro.ru", "phone": "+70272416062"}
0005432034776	05A202	1099 802394	ARKADIY OSIPOV	{"phone": "+70804112052"}
0005432034777	411E0F	9026 193552	VLADISLAV IVANOV	{"email": "v_ivanov_18011978@postgrespro.ru", "phone": "+70186929579"}
0005432034778	6E4FCC	9339 834966	IRINA EGOROVA	{"phone": "+70030899228"}
0005432034779	0DF777	0502 737644	LYUBOV NAUMOVA	{"email": "lyubov_naumova-081958@postgrespro.ru", "phone": "+70540498596"}
0005432034780	0DF777	2786 022826	ELENA RODIONOVA	{"email": "elenarodionova.02111973@postgrespro.ru", "phone": "+70937117293"}
0005432034781	77CBA0	6623 625615	OKSANA DMITRIEVA	{"email": "dmitrievaoksana1984@postgrespro.ru", "phone": "+70172631482"}
0005432034782	77CBA0	0889 425456	NIKOLAY IVANOV	{"phone": "+70883274157"}
0005432034783	AC1555	9320 856889	NATALYA SMIRNOVA	{"phone": "+70592440620"}
0005432034784	AC1555	8645 588644	NIKOLAY FOMIN	{"email": "fomin.n.1972@postgrespro.ru", "phone": "+70500717612"}
0005432034785	AC1555	2921 082117	PAVEL IVANOV	{"email": "ivanov_p_021971@postgrespro.ru", "phone": "+70726425257"}
0005432034786	ABC96B	2532 704427	YURIY FOMIN	{"email": "y.fomin-1973@postgrespro.ru", "phone": "+70839694165"}
0005432034787	1DF35F	1160 973865	ALEKSANDR MELNIKOV	{"phone": "+70686540561"}
0005432034788	E0EFDA	5421 597369	RAISA TROFIMOVA	{"phone": "+70947671036"}
0005432034789	E0EFDA	6421 874350	TATYANA LUKYANOVA	{"phone": "+70757527042"}
0005432034790	A3EA5D	8100 527372	VIKTOR KOROLEV	{"phone": "+70411933720"}
0005432034791	B5E278	0271 735658	TATYANA ALEKSANDROVA	{"email": "tatyana-aleksandrova.21101971@postgrespro.ru", "phone": "+70199030667"}
0005432034792	6F5E2D	3203 874432	SVETLANA BELYAEVA	{"phone": "+70935245232"}
0005432034793	6F5E2D	8753 586751	TAMARA NIKOLAEVA	{"email": "tamara_nikolaeva.21121973@postgrespro.ru", "phone": "+70398327248"}
0005432034794	5BB077	0917 600295	KIRILL PETROV	{"email": "petrovkirill_091984@postgrespro.ru", "phone": "+70412114943"}
0005432034795	8B332F	7067 887717	ANNA POLYAKOVA	{"email": "polyakovaanna.22061991@postgrespro.ru", "phone": "+70093856173"}
0005432034796	8B332F	9899 052931	ALEKSANDR TARASOV	{"phone": "+70110725155"}
0005432034797	E606D9	7272 995891	ALEKSANDR KUDRYASHOV	{"phone": "+70736356117"}
0005432034798	E606D9	5621 736266	EVGENIY IVANOV	{"email": "evgeniyivanov-1969@postgrespro.ru", "phone": "+70050410976"}
0005432034799	8AD1CB	9302 900997	ANATOLIY ANTONOV	{"email": "a_antonov_021987@postgrespro.ru", "phone": "+70149290786"}
0005432034800	303A5E	9692 148094	SVETLANA ZHURAVLEVA	{"phone": "+70102638227"}
0005432034801	D2F988	9846 635864	DMITRIY ROMANOV	{"email": "d_romanov.061973@postgrespro.ru", "phone": "+70215234358"}
0005432034802	5A2DFB	1138 733639	OLGA KUZNECOVA	{"email": "olgakuznecova.051963@postgrespro.ru", "phone": "+70675541367"}
0005432034803	0E8238	2790 723443	TATYANA SMIRNOVA	{"email": "t_smirnova_051982@postgrespro.ru", "phone": "+70731871108"}
0005432034804	0E8238	4557 366780	DMITRIY VOLKOV	{"email": "dmitriy.volkov_011968@postgrespro.ru", "phone": "+70117501591"}
0005432034805	9F16A0	8975 989520	VYACHESLAV MATVEEV	{"email": "matveev-v1983@postgrespro.ru", "phone": "+70165734126"}
0005432034806	30542C	0424 497337	MARINA ORLOVA	{"email": "m.orlova_01121973@postgrespro.ru", "phone": "+70044343898"}
0005432034807	7FF5F0	9593 576710	NIKOLAY TARASOV	{"phone": "+70678419670"}
0005432034808	7FF5F0	7205 797506	ANNA ARKHIPOVA	{"email": "anna_arkhipova_1968@postgrespro.ru", "phone": "+70472910756"}
0005432034809	B1F0AC	3812 751091	OLGA BORISOVA	{"phone": "+70902250558"}
0005432034810	9D5D08	8545 068261	ILYA VLASOV	{"email": "vlasov_ilya1972@postgrespro.ru", "phone": "+70274816593"}
0005432034811	5D4781	6511 426842	ALEKSEY ABRAMOV	{"phone": "+70679294347"}
0005432034812	5D4781	0728 452215	NIKOLAY EGOROV	{"email": "nikolay_egorov-071974@postgrespro.ru", "phone": "+70978124551"}
0005432034813	21288C	2307 988286	ANDREY BORISOV	{"email": "borisov.andrey.1964@postgrespro.ru", "phone": "+70224399677"}
0005432034814	C35AAA	2518 975207	TATYANA MAKSIMOVA	{"phone": "+70909381113"}
0005432034815	D76D51	4568 320995	MIKHAIL ISAEV	{"email": "isaev_mikhail.06071971@postgrespro.ru", "phone": "+70639103939"}
0005432034816	D76D51	7638 386164	POLINA TROFIMOVA	{"phone": "+70283308189"}
0005432034817	09890A	3800 565547	NINA ALEKSANDROVA	{"phone": "+70623739468"}
0005432034818	FBF976	0614 147832	ASKAR SIDOROV	{"phone": "+70221214049"}
0005432034819	FBF976	6913 090044	NATALYA KOROLEVA	{"phone": "+70320732452"}
0005432034820	7F77B6	1223 391748	VITALIY NIKOLAEV	{"email": "nikolaevv.011971@postgrespro.ru", "phone": "+70018530141"}
0005432034821	120223	2749 854676	RAISA MASLOVA	{"phone": "+70537890385"}
0005432034822	1C4F72	5642 857027	IGOR ABRAMOV	{"email": "igor-abramov091974@postgrespro.ru", "phone": "+70103165637"}
0005432034823	41E127	9815 194599	NADEZHDA OVCHINNIKOVA	{"phone": "+70135658881"}
0005432034824	3F7132	2765 032507	VADIM KUZNECOV	{"email": "kuznecovvadim_23121977@postgrespro.ru", "phone": "+70767776518"}
0005432034825	DAB09A	7767 800514	OLGA SAVELEVA	{"email": "savelevaolga.041964@postgrespro.ru", "phone": "+70720699453"}
0005432034826	62BA32	5623 361758	SVETLANA KOZLOVA	{"email": "kozlova.svetlana.1972@postgrespro.ru", "phone": "+70084681005"}
0005432034827	E29DDD	7482 745180	MAKSIM SMIRNOV	{"phone": "+70960797904"}
0005432034828	6D45AB	1850 634312	EKATERINA DAVYDOVA	{"phone": "+70846191127"}
0005432034829	9C73AD	8385 111727	ALENA MIKHAYLOVA	{"email": "alena_mikhaylova_021963@postgrespro.ru", "phone": "+70022511135"}
0005432034830	9C73AD	3764 728530	LYUDMILA KONDRATEVA	{"email": "kondrateva.lyudmila.101974@postgrespro.ru", "phone": "+70532311511"}
0005432034831	535E06	0982 893364	ZOYA ZAKHAROVA	{"phone": "+70051252261"}
0005432035246	EAB251	0681 459683	VALENTINA MOROZOVA	{"phone": "+70569134635"}
0005432034832	535E06	9296 121558	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr041985@postgrespro.ru", "phone": "+70676531901"}
0005432034833	6C5E1F	6442 765268	KSENIYA DENISOVA	{"email": "denisova.kseniya.021976@postgrespro.ru", "phone": "+70915854425"}
0005432034834	6C5E1F	7729 059374	ELENA SERGEEVA	{"email": "sergeeva_e-1980@postgrespro.ru", "phone": "+70838597729"}
0005432034835	6C5E1F	5413 366545	LYUDMILA KUZNECOVA	{"phone": "+70724702368"}
0005432034836	D32376	1201 502706	SVETLANA LUKYANOVA	{"phone": "+70317861206"}
0005432034837	A5CA2D	9119 531598	EVGENIY DMITRIEV	{"email": "e-dmitriev_091980@postgrespro.ru", "phone": "+70389744182"}
0005432034838	9657A0	9995 215720	YAROSLAV MAKAROV	{"phone": "+70112487030"}
0005432034839	DF8C03	5779 776497	NINA KALININA	{"email": "kalinina-nina30091957@postgrespro.ru", "phone": "+70370424142"}
0005432034840	071246	5050 415931	LARISA MAKSIMOVA	{"phone": "+70551140588"}
0005432034841	071246	8196 017657	SVETLANA SIDOROVA	{"phone": "+70984678791"}
0005432034842	821A07	3262 140558	ANASTASIYA IVANOVA	{"phone": "+70853710993"}
0005432034843	821A07	1645 770670	IRINA SMIRNOVA	{"phone": "+70531816545"}
0005432034844	3E3F2A	2155 055354	KIRILL SAVELEV	{"phone": "+70129571185"}
0005432034845	905B8D	8112 551484	NATALYA MAKSIMOVA	{"email": "maksimovan_15051955@postgrespro.ru", "phone": "+70226410765"}
0005432034846	905B8D	3580 565381	TATYANA SOLOVEVA	{"phone": "+70601556465"}
0005432034847	0C28DA	8426 403894	MIKHAIL FEDOROV	{"phone": "+70768854922"}
0005432034848	0C28DA	8896 100862	ROMAN KOROLEV	{"email": "korolevroman.20011967@postgrespro.ru", "phone": "+70136507861"}
0005432034849	0C28DA	8006 307477	YURIY YAKOVLEV	{"phone": "+70328910065"}
0005432034850	B89902	6597 619469	ALEKSANDRA OSIPOVA	{"email": "aosipova041974@postgrespro.ru", "phone": "+70916549483"}
0005432034851	296DC3	6037 446855	NIKOLAY NIKOLAEV	{"email": "nikolaev.nikolay.1974@postgrespro.ru", "phone": "+70497912983"}
0005432034852	296DC3	2562 002255	DMITRIY FROLOV	{"email": "dmitriy_frolov1971@postgrespro.ru", "phone": "+70162846079"}
0005432034853	409032	6899 262400	VALENTINA SERGEEVA	{"phone": "+70480130609"}
0005432034854	8440EA	1183 024376	VLADIMIR SOKOLOV	{"phone": "+70382748104"}
0005432034855	71B821	1452 213513	ANNA VLASOVA	{"phone": "+70933308004"}
0005432034856	0EFDF0	9235 052777	VLADIMIR POPOV	{"email": "v-popov-21081971@postgrespro.ru", "phone": "+70362279970"}
0005432034857	3E36B7	4584 491591	MIKHAIL MATVEEV	{"phone": "+70058480875"}
0005432034858	E42712	8038 035068	ALEKSANDR FROLOV	{"phone": "+70335869450"}
0005432034859	8963A8	0227 877062	DMITRIY NAZAROV	{"phone": "+70047343233"}
0005432034860	58687B	4969 289918	ALEKSANDR STEPANOV	{"phone": "+70830263371"}
0005432034861	4B9355	5137 383154	EVGENIY KUZNECOV	{"phone": "+70578786433"}
0005432034862	4B9355	3135 969736	VLADIMIR DENISOV	{"email": "denisov-vladimir.1963@postgrespro.ru", "phone": "+70467850064"}
0005432034863	4B9355	0638 707207	NIKOLAY SIDOROV	{"email": "n.sidorov-1962@postgrespro.ru", "phone": "+70786074828"}
0005432034864	013A37	8419 861551	ALEKSANDR MAKAROV	{"email": "makarov.a_13081983@postgrespro.ru", "phone": "+70712027600"}
0005432034865	013A37	1524 590474	YAROSLAV NAZAROV	{"phone": "+70401320011"}
0005432034866	AC5A8C	2304 028707	MIKHAIL ZAKHAROV	{"email": "m_zakharov_05031973@postgrespro.ru", "phone": "+70098861891"}
0005432034867	AC5A8C	9947 514998	ANDREY ILIN	{"email": "ilin_a-071962@postgrespro.ru", "phone": "+70711338711"}
0005432034868	AC5A8C	2856 727940	OLEG DMITRIEV	{"email": "dmitrievoleg1971@postgrespro.ru", "phone": "+70494378400"}
0005432034869	AC5A8C	4557 509734	ANASTASIYA AFANASEVA	{"email": "a_afanaseva.121979@postgrespro.ru", "phone": "+70511228972"}
0005432034870	C5A3AA	1773 193336	ALEKSEY ANDREEV	{"phone": "+70902326742"}
0005432034871	35D160	0309 751417	SERGEY MAKSIMOV	{"phone": "+70566700969"}
0005432034872	35D160	7259 391487	NATALYA VOLKOVA	{"phone": "+70834663229"}
0005432034873	0B557D	4250 775296	VLADIMIR SAVELEV	{"email": "savelev-vladimir-1977@postgrespro.ru", "phone": "+70596842518"}
0005432034874	0B557D	7610 214849	MIKHAIL SOKOLOV	{"phone": "+70018091562"}
0005432034875	BFBE44	8984 400498	ALEKSANDRA MAKSIMOVA	{"email": "maksimovaa26121969@postgrespro.ru", "phone": "+70545313342"}
0005432034876	1C88B3	8216 410119	FATIMA EFIMOVA	{"email": "efimova_fatima-15081976@postgrespro.ru", "phone": "+70464270925"}
0005432034877	1C88B3	4090 032276	ANATOLIY PETROV	{"phone": "+70139364898"}
0005432034878	A740A8	5404 302044	SVETLANA FEDOROVA	{"email": "fedorova.svetlana1980@postgrespro.ru", "phone": "+70105787321"}
0005432034879	625235	4488 941889	ANDREY ZAKHAROV	{"phone": "+70248938476"}
0005432034880	C8CD45	2310 897088	VALENTINA ZOTOVA	{"phone": "+70564525027"}
0005432034881	F2236F	2190 226520	ANGELINA AFANASEVA	{"phone": "+70462554088"}
0005432034882	01780A	8361 128920	SVETLANA TARASOVA	{"phone": "+70059846068"}
0005432034883	895AEE	3380 674281	ARTEMIY MELNIKOV	{"email": "a.melnikov_1973@postgrespro.ru", "phone": "+70661858127"}
0005432034884	62C193	5346 287959	NATALYA OSIPOVA	{"email": "natalya-osipova_101965@postgrespro.ru", "phone": "+70175963861"}
0005432034885	AF2F75	6000 588448	ELIZAVETA POPOVA	{"email": "popova-e-1961@postgrespro.ru", "phone": "+70665130581"}
0005432034886	4DE0AC	4211 092974	VALENTINA KUDRYASHOVA	{"phone": "+70802952258"}
0005432034887	85017A	1147 148873	LARISA PAVLOVA	{"email": "pavlova.l.071979@postgrespro.ru", "phone": "+70679393934"}
0005432034888	85017A	9753 954828	NIKOLAY KISELEV	{"phone": "+70828486300"}
0005432034889	85017A	3707 969222	DMITRIY VLASOV	{"phone": "+70118301707"}
0005432034890	0077E1	7650 862304	IVAN ZHURAVLEV	{"phone": "+70460520351"}
0005432034891	CF23C8	3300 005724	ANDREY SCHERBAKOV	{"phone": "+70622394360"}
0005432034892	6B4D29	2710 386818	OLGA NAUMOVA	{"phone": "+70922495255"}
0005432034893	1CA8E2	5525 678880	OLESYA VASILEVA	{"email": "olesyavasileva_121967@postgrespro.ru", "phone": "+70081959319"}
0005432034894	B82491	6718 202151	VYACHESLAV VASILEV	{"email": "vyacheslav_vasilev.10091971@postgrespro.ru", "phone": "+70055689157"}
0005432034895	5A111D	7733 964140	YURIY ROMANOV	{"email": "yuriy.romanov_051970@postgrespro.ru", "phone": "+70415636199"}
0005432034896	94D2DF	3110 497975	ANNA ZOTOVA	{"phone": "+70001853091"}
0005432034897	94D2DF	9823 372633	VERA TARASOVA	{"phone": "+70798275487"}
0005432034898	1D5670	7888 684109	NATALYA NESTEROVA	{"phone": "+70349492861"}
0005432034899	1D5670	8675 156083	VLADISLAV MIRONOV	{"phone": "+70044828565"}
0005432034900	1D5670	6536 627477	VLADIMIR GUSEV	{"email": "gusev.v.1967@postgrespro.ru", "phone": "+70387347845"}
0005432034901	3E29F1	0566 079203	DAVID KUZMIN	{"phone": "+70210911239"}
0005432034902	9D80F2	7704 573760	VYACHESLAV GORBUNOV	{"email": "gorbunov_v-1971@postgrespro.ru", "phone": "+70015391514"}
0005432034903	4AAE16	2420 465247	YULIYA DAVYDOVA	{"email": "ydavydova121970@postgrespro.ru", "phone": "+70603948536"}
0005432034904	4AAE16	2497 943240	VIKTOR MOROZOV	{"email": "morozov_v_1965@postgrespro.ru", "phone": "+70175358501"}
0005432034905	AAD284	6460 925311	DIANA SCHERBAKOVA	{"email": "d-scherbakova-28051973@postgrespro.ru", "phone": "+70686824156"}
0005432034906	AAD284	5918 528646	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov.051981@postgrespro.ru", "phone": "+70412272572"}
0005432034907	BDE685	0990 173490	NINA BOGDANOVA	{"phone": "+70021083191"}
0005432034908	065AB9	4230 280138	EVDOKIYA TROFIMOVA	{"phone": "+70057136292"}
0005432034909	D0C848	5961 668746	EVGENIY TARASOV	{"phone": "+70178138026"}
0005432034910	D0C848	1046 708357	MAKSIM TIKHONOV	{"email": "maksim.tikhonov_081968@postgrespro.ru", "phone": "+70893580737"}
0005432034911	997642	1466 770396	PETR NOVIKOV	{"email": "novikov_petr_1969@postgrespro.ru", "phone": "+70109700605"}
0005432034912	E6AEEE	0459 946391	RUMIYA NIKOLAEVA	{"email": "nikolaeva_r.07021978@postgrespro.ru", "phone": "+70169721814"}
0005432034913	E094AA	5371 785740	DMITRIY SEMENOV	{"email": "semenov.dmitriy26021967@postgrespro.ru", "phone": "+70657623037"}
0005432034914	4AC58A	1969 050800	VALENTINA POPOVA	{"email": "v.popova1970@postgrespro.ru", "phone": "+70267444454"}
0005432034915	51AFE8	7897 361078	DMITRIY KUDRYASHOV	{"email": "dkudryashov.1969@postgrespro.ru", "phone": "+70391655289"}
0005432034916	51AFE8	9409 749303	VIKTOR SAVELEV	{"email": "v_savelev14101979@postgrespro.ru", "phone": "+70557679728"}
0005432034917	2C9320	2476 670555	IVAN ALEKSANDROV	{"email": "aleksandrov.i_30061963@postgrespro.ru", "phone": "+70888102211"}
0005432034918	6DA72F	0301 778978	DENIS KONOVALOV	{"phone": "+70838097978"}
0005432034919	6DA72F	2206 841594	GALINA ANDREEVA	{"email": "g-andreeva111977@postgrespro.ru", "phone": "+70964032844"}
0005432034920	6DA72F	4590 795825	NIKOLAY KUZMIN	{"email": "kuzmin-n091974@postgrespro.ru", "phone": "+70152995218"}
0005432034921	F1ED4D	6217 575103	MAKSIM AFANASEV	{"email": "afanasev-maksim-13081963@postgrespro.ru", "phone": "+70353239980"}
0005432034922	5C90A5	8451 698200	VITALIY ALEKSEEV	{"phone": "+70233846639"}
0005432034923	4976AD	7709 814682	VLADIMIR ISAEV	{"email": "v.isaev_24051964@postgrespro.ru", "phone": "+70226948632"}
0005432034924	1B0D5E	9431 542618	KARINA KUZMINA	{"phone": "+70995927669"}
0005432034925	F5E48A	5588 120242	VIKTOR EGOROV	{"email": "egorovviktor_121973@postgrespro.ru", "phone": "+70943226140"}
0005432034926	F6F5AB	6614 668657	TAMARA KARPOVA	{"email": "karpova.tamara-021975@postgrespro.ru", "phone": "+70548999057"}
0005432034927	36A26F	4760 944756	ALEKSANDR MEDVEDEV	{"phone": "+70388549116"}
0005432034928	95F1F3	2016 421961	VLADIMIR KUZNECOV	{"phone": "+70192386956"}
0005432034929	95F1F3	7750 325767	ULYANA FILIPPOVA	{"email": "u-filippova_15081974@postgrespro.ru", "phone": "+70115952401"}
0005432034930	95F1F3	4657 957228	SVETLANA OVCHINNIKOVA	{"phone": "+70455722259"}
0005432034931	6E6390	6548 792807	ANDREY SERGEEV	{"email": "a.sergeev-111973@postgrespro.ru", "phone": "+70346927155"}
0005432034932	5DB152	9310 718060	EVGENIYA MAKAROVA	{"phone": "+70469169514"}
0005432034933	5DB152	4531 847167	ANNA PAVLOVA	{"email": "a_pavlova.1969@postgrespro.ru", "phone": "+70270720812"}
0005432034934	0A73ED	7270 691216	MAKSIM ALEKSEEV	{"email": "maksim_alekseev09101972@postgrespro.ru", "phone": "+70805100840"}
0005432034935	568969	0482 416106	TATYANA IVANOVA	{"email": "ivanova-t.031965@postgrespro.ru", "phone": "+70962646642"}
0005432034936	568969	6457 950944	ALEKSEY VLASOV	{"email": "alekseyvlasov-14121962@postgrespro.ru", "phone": "+70225404130"}
0005432034937	35C94C	4314 348279	MARIYA KOLESNIKOVA	{"email": "mariya-kolesnikova051975@postgrespro.ru", "phone": "+70305467235"}
0005432034938	2C63E8	6565 041643	IRINA POLYAKOVA	{"email": "polyakova.irina.30031984@postgrespro.ru", "phone": "+70398840604"}
0005432034939	B87ABB	2640 318008	IGOR POPOV	{"email": "popovi051970@postgrespro.ru", "phone": "+70357542223"}
0005432034940	01FD5B	2483 199309	TATYANA MOISEEVA	{"email": "tmoiseeva-1971@postgrespro.ru", "phone": "+70366129364"}
0005432034941	01FD5B	1225 716683	VASILIY MIRONOV	{"email": "mironov-v_26091975@postgrespro.ru", "phone": "+70456315372"}
0005432034942	01FD5B	2842 606667	ALLA STEPANOVA	{"email": "alla-stepanova.1975@postgrespro.ru", "phone": "+70354569024"}
0005432034943	ABEA85	4043 943874	VALENTINA VOLKOVA	{"phone": "+70821962968"}
0005432034944	033394	9534 195773	KONSTANTIN VOROBEV	{"email": "vorobev.k1978@postgrespro.ru", "phone": "+70047585548"}
0005432034945	D8E9D7	2192 539464	DENIS VOLKOV	{"phone": "+70084565055"}
0005432034946	D8E9D7	8964 907142	LIDIYA SMIRNOVA	{"email": "smirnova-l1968@postgrespro.ru", "phone": "+70660127298"}
0005432034947	F0A1E7	0283 811499	TATYANA VOLKOVA	{"phone": "+70086463282"}
0005432034948	B0238C	4192 937712	SVETLANA KONDRATEVA	{"email": "kondrateva_svetlana-041969@postgrespro.ru", "phone": "+70630813884"}
0005432034949	06676C	0415 253721	SVETLANA KARPOVA	{"phone": "+70855198241"}
0005432034950	18EAAD	1846 138554	OLGA TIMOFEEVA	{"email": "timofeevaolga-18021973@postgrespro.ru", "phone": "+70863331526"}
0005432034951	D9D2F2	0673 810751	SERGEY KAZAKOV	{"email": "sergey_kazakov_1967@postgrespro.ru", "phone": "+70582030677"}
0005432034952	5EBFE3	2130 871911	SERGEY KARPOV	{"email": "karpov-sergey1984@postgrespro.ru", "phone": "+70859970770"}
0005432034953	918FBB	3642 736639	GULNARA VOLKOVA	{"phone": "+70881040578"}
0005432034954	9752AB	7834 888297	IRINA POPOVA	{"phone": "+70897214562"}
0005432034955	1B81F4	5520 622640	DMITRIY KUZNECOV	{"phone": "+70610884350"}
0005432034956	2D1F05	6068 295143	VALERIYA ANTONOVA	{"phone": "+70930001400"}
0005432034957	2D1F05	8853 036821	ANGELINA IVANOVA	{"email": "a_ivanova.1971@postgrespro.ru", "phone": "+70108587563"}
0005432034958	2D1F05	6125 155731	IRINA ANTONOVA	{"email": "irinaantonova1981@postgrespro.ru", "phone": "+70658269893"}
0005432034959	A70CBD	4292 777926	ANTON SERGEEV	{"email": "anton_sergeev1970@postgrespro.ru", "phone": "+70892699920"}
0005432034960	D48B14	8136 222596	ALEFTINA IVANOVA	{"email": "a.ivanova-111979@postgrespro.ru", "phone": "+70616767814"}
0005432034961	A5EA96	8491 679640	PAVEL ROMANOV	{"email": "pavel-romanov.10081977@postgrespro.ru", "phone": "+70251726956"}
0005432034962	A5EA96	3115 783904	ILONA BELYAEVA	{"phone": "+70958208652"}
0005432034963	DAD6BD	0437 007458	MARINA ANDREEVA	{"email": "andreeva.marina_01021967@postgrespro.ru", "phone": "+70420113911"}
0005432034964	A1A284	7183 956755	ALEKSANDRA SOLOVEVA	{"email": "aleksandra_soloveva_1967@postgrespro.ru", "phone": "+70682921400"}
0005432034965	B5BA5C	6087 878447	ANNA SOKOLOVA	{"email": "anna-sokolova_121976@postgrespro.ru", "phone": "+70839578011"}
0005432034966	B5BA5C	9012 812803	ALEKSANDR ORLOV	{"email": "orlov_aleksandr-28091971@postgrespro.ru", "phone": "+70902393430"}
0005432034967	357DC2	3624 383910	LYUBOV MIRONOVA	{"email": "lmironova.31101969@postgrespro.ru", "phone": "+70283247322"}
0005432034968	CE9796	3777 152452	RAISA KUDRYASHOVA	{"phone": "+70250993161"}
0005432034969	87FEEF	3419 403377	GALINA FILIPPOVA	{"email": "galina.filippova01011969@postgrespro.ru", "phone": "+70990112082"}
0005432034970	1ECE92	1198 661485	SERGEY KUZNECOV	{"email": "s.kuznecov-121965@postgrespro.ru", "phone": "+70500697629"}
0005432034971	1ECE92	9941 038341	SVETLANA IVANOVA	{"email": "ivanova.svetlana19121966@postgrespro.ru", "phone": "+70696856770"}
0005432034972	54DE25	7950 480608	MARIYA FROLOVA	{"email": "frolova_m_011980@postgrespro.ru", "phone": "+70360840182"}
0005432034973	CB40CD	6959 166599	VALENTINA SERGEEVA	{"email": "vsergeeva.1966@postgrespro.ru", "phone": "+70077254302"}
0005432034974	CB40CD	9176 215110	NATALYA MAKSIMOVA	{"email": "maksimova_natalya1979@postgrespro.ru", "phone": "+70465730262"}
0005432034975	A55A35	2364 911364	KONSTANTIN SIDOROV	{"phone": "+70212240900"}
0005432034976	5A93F2	1926 529980	NINA POLYAKOVA	{"email": "n.polyakova_05021962@postgrespro.ru", "phone": "+70145300064"}
0005432034977	013124	0150 242545	LYUDMILA ZHURAVLEVA	{"phone": "+70683238291"}
0005432034978	4586D0	8489 423854	VLADIMIR MIRONOV	{"email": "mironov.vladimir-1972@postgrespro.ru", "phone": "+70080892880"}
0005432034979	6B27AC	5387 400525	TAMARA ABRAMOVA	{"phone": "+70317991106"}
0005432034980	554A1C	7857 856930	VLADIMIR ILIN	{"phone": "+70163150106"}
0005432034981	DC1C69	8432 687463	DENIS NAZAROV	{"phone": "+70317884517"}
0005432034982	01CA2E	3989 743904	DARYA DENISOVA	{"email": "denisova_d.1964@postgrespro.ru", "phone": "+70660420095"}
0005432034983	01CA2E	8038 228635	VERA NIKITINA	{"email": "vera.nikitina1970@postgrespro.ru", "phone": "+70702124846"}
0005432034984	BE60FD	3165 555823	ANTON GUSEV	{"email": "gusev_a.101989@postgrespro.ru", "phone": "+70158307654"}
0005432034985	5788D0	3952 722373	MARIYA NESTEROVA	{"email": "nesterova.mariya-1972@postgrespro.ru", "phone": "+70913121438"}
0005432034986	B09FE8	9164 668170	TATYANA FADEEVA	{"phone": "+70350956470"}
0005432034987	116671	7817 397153	ALEKSANDR PETROV	{"email": "aleksandr_petrov-1971@postgrespro.ru", "phone": "+70151061040"}
0005432034988	116671	4943 009581	ARTEM SHEVCHENKO	{"email": "artem.shevchenko_22061968@postgrespro.ru", "phone": "+70913326442"}
0005432034989	E3D757	9874 074416	OLGA KONDRATEVA	{"phone": "+70755326286"}
0005432034990	E3D757	1852 743509	LYUDMILA POLYAKOVA	{"email": "polyakova_l_021966@postgrespro.ru", "phone": "+70768904011"}
0005432034991	53BA6B	5704 899002	NINA ABRAMOVA	{"email": "ninaabramova10091985@postgrespro.ru", "phone": "+70531761810"}
0005432034992	275D18	7151 520486	TATYANA IVANOVA	{"email": "tatyana_ivanova-1969@postgrespro.ru", "phone": "+70381494231"}
0005432034993	82AB9B	8041 344214	GALINA PETROVA	{"email": "galinapetrova-101981@postgrespro.ru", "phone": "+70341846948"}
0005432034994	DCEFEC	1521 852306	NATALYA TROFIMOVA	{"phone": "+70131624776"}
0005432034995	DCEFEC	6322 551927	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr1980@postgrespro.ru", "phone": "+70382144820"}
0005432034996	C1B612	0361 244831	ALENA IVANOVA	{"phone": "+70074365576"}
0005432034997	F9CA6E	7503 723757	SOFIYA NIKOLAEVA	{"email": "nikolaevas.10011964@postgrespro.ru", "phone": "+70457347598"}
0005432034998	F9CA6E	0045 184979	RAVIL KUZNECOV	{"phone": "+70740361806"}
0005432034999	F1C17C	8405 123064	GALINA VOLKOVA	{"email": "gvolkova-1959@postgrespro.ru", "phone": "+70308656012"}
0005432035000	B7B551	7374 037323	VYACHESLAV KUZNECOV	{"email": "kuznecovv_041977@postgrespro.ru", "phone": "+70435332393"}
0005432035001	B7B551	4134 991374	NATALYA DENISOVA	{"email": "n-denisova1966@postgrespro.ru", "phone": "+70150939156"}
0005432035002	A64FAE	0227 289468	ANDREY SOKOLOV	{"email": "sokolov_andrey13091968@postgrespro.ru", "phone": "+70559993270"}
0005432035003	6FECE6	7686 497059	ANTON SMIRNOV	{"phone": "+70083155299"}
0005432035004	6FECE6	5650 702973	ALINA TROFIMOVA	{"email": "a-trofimova_101959@postgrespro.ru", "phone": "+70217558879"}
0005432035005	60486B	3812 080886	VLADISLAV KISELEV	{"email": "kiselevvladislav_1978@postgrespro.ru", "phone": "+70407044833"}
0005432035006	1B4FB2	7665 480874	EVGENIY NAUMOV	{"phone": "+70917560432"}
0005432035007	AFBF86	0697 028089	IRINA MIKHAYLOVA	{"phone": "+70502212940"}
0005432035008	49E08E	3646 167744	IRINA YAKOVLEVA	{"email": "irina.yakovleva-1968@postgrespro.ru", "phone": "+70883644702"}
0005432035009	88A6A8	5529 630532	RAIL SOROKIN	{"phone": "+70440972112"}
0005432035010	92533D	5979 474837	VASILIY KOROLEV	{"phone": "+70385554244"}
0005432035011	3B3DA3	2133 201246	YURIY ZAYCEV	{"email": "zaycev-yuriy-26041981@postgrespro.ru", "phone": "+70956775290"}
0005432035012	674B51	6428 336768	SERGEY SOROKIN	{"email": "sorokin.sergey.02021968@postgrespro.ru", "phone": "+70340751160"}
0005432035013	6DEB4D	6727 287919	ALEKSEY IVANOV	{"email": "ivanov.aleksey1979@postgrespro.ru", "phone": "+70076659643"}
0005432035014	3D0F60	5504 189856	YULIYA OSIPOVA	{"email": "osipova_y_01071980@postgrespro.ru", "phone": "+70547286398"}
0005432035015	3D0F60	0474 618364	VYACHESLAV MIKHAYLOV	{"email": "vmikhaylov_1970@postgrespro.ru", "phone": "+70881602491"}
0005432035016	3B7FEF	8436 554299	ANASTASIYA KUZNECOVA	{"email": "akuznecova_1963@postgrespro.ru", "phone": "+70554659656"}
0005432035017	0A5431	6350 420557	OLEG MELNIKOV	{"email": "melnikov.oleg.16101980@postgrespro.ru", "phone": "+70372315186"}
0005432035018	0A5431	9325 196567	GULFIYA KONOVALOVA	{"phone": "+70948593287"}
0005432035019	2AEBD3	5115 708377	VALENTINA KOLESNIKOVA	{"phone": "+70235479873"}
0005432035020	B29C6B	8729 754081	MARIYA DMITRIEVA	{"email": "mariyadmitrieva071972@postgrespro.ru", "phone": "+70082241633"}
0005432035021	2DEE0B	0008 244668	SERGEY ROMANOV	{"email": "s.romanov1970@postgrespro.ru", "phone": "+70196953797"}
0005432035022	2DEE0B	2388 866380	VASILIY MARTYNOV	{"email": "v-martynov.1968@postgrespro.ru", "phone": "+70993533816"}
0005432035023	C652E6	3916 375912	VLADIMIR AFANASEV	{"email": "afanasev.vladimir-1971@postgrespro.ru", "phone": "+70892467676"}
0005432035024	6C573A	6609 773295	NATALYA SMIRNOVA	{"phone": "+70959048448"}
0005432035025	6C573A	2454 121269	RINAT BELOV	{"email": "belov_r_17031988@postgrespro.ru", "phone": "+70897106076"}
0005432035026	6C573A	1616 327640	GALINA KOROLEVA	{"email": "g.koroleva-011973@postgrespro.ru", "phone": "+70587253106"}
0005432035027	ACD51A	2651 122544	ALENA SIDOROVA	{"email": "a-sidorova-09011971@postgrespro.ru", "phone": "+70870518640"}
0005432035028	130915	7689 804440	LYUBOV LOGINOVA	{"email": "lloginova-1960@postgrespro.ru", "phone": "+70649265219"}
0005432035029	29EFCE	5863 087053	VALENTINA BELOVA	{"email": "belovavalentina_021977@postgrespro.ru", "phone": "+70826032799"}
0005432035030	29EFCE	9857 035006	TATYANA MASLOVA	{"phone": "+70266202048"}
0005432035031	9353B8	7587 333315	EKATERINA KONOVALOVA	{"phone": "+70067869951"}
0005432035032	9353B8	2027 182927	ELENA SOLOVEVA	{"phone": "+70846391530"}
0005432035033	2586E2	5442 904067	SERGEY SOROKIN	{"phone": "+70478444800"}
0005432035034	6585C3	4571 754144	LYUBOV KOLESNIKOVA	{"email": "l_kolesnikova031970@postgrespro.ru", "phone": "+70598672846"}
0005432035035	6585C3	3331 214792	VIKTOR VLASOV	{"email": "vlasov-viktor_1975@postgrespro.ru", "phone": "+70645426914"}
0005432035036	D54E7E	1474 255026	ELENA KUZNECOVA	{"phone": "+70248817691"}
0005432035037	FEC3B3	1253 084643	SERGEY PETROV	{"email": "spetrov06021966@postgrespro.ru", "phone": "+70528030587"}
0005432035038	17D649	3404 372096	ALEKSANDR TARASOV	{"email": "tarasovaleksandr.1966@postgrespro.ru", "phone": "+70954911929"}
0005432035039	F81EEC	4371 040223	ALEFTINA FEDOROVA	{"phone": "+70915450767"}
0005432035040	55DDAE	0820 825238	GALINA MAKAROVA	{"email": "g.makarova.22061957@postgrespro.ru", "phone": "+70304299243"}
0005432035041	55DDAE	3395 659736	VIKTOR ALEKSEEV	{"email": "v.alekseev051976@postgrespro.ru", "phone": "+70647402725"}
0005432035042	18BF68	4353 569450	VLADIMIR NIKITIN	{"phone": "+70218870987"}
0005432035043	10106C	1721 804468	LYUBOV SERGEEVA	{"phone": "+70261298599"}
0005432035044	10106C	5284 619788	IRINA POLYAKOVA	{"email": "polyakova-irina1974@postgrespro.ru", "phone": "+70009855198"}
0005432035045	3A555C	6832 752333	ALEKSANDRA ZHUKOVA	{"phone": "+70584833535"}
0005432035046	3A555C	9692 176416	VIKTOR ZAKHAROV	{"phone": "+70744209866"}
0005432035047	9B2677	0677 496533	MARINA ZHURAVLEVA	{"email": "zhuravleva-m.071976@postgrespro.ru", "phone": "+70796737013"}
0005432035048	9B2677	3888 716227	DENIS STEPANOV	{"email": "stepanovd1967@postgrespro.ru", "phone": "+70290817228"}
0005432035049	965CDF	5563 204061	MARAT PETROV	{"phone": "+70138605463"}
0005432035050	B481C3	0314 361146	TATYANA KOROLEVA	{"email": "koroleva-tatyana_121966@postgrespro.ru", "phone": "+70571747518"}
0005432035051	4D90F8	9226 986753	SVETLANA KONOVALOVA	{"phone": "+70084551741"}
0005432035052	696550	8695 861995	LYUBOV AFANASEVA	{"email": "afanasevalyubov-09111976@postgrespro.ru", "phone": "+70738176585"}
0005432035053	696550	6304 012865	ELENA TROFIMOVA	{"email": "elena_trofimova.1966@postgrespro.ru", "phone": "+70824395392"}
0005432035054	508EE0	0974 669491	ANNA ZHURAVLEVA	{"email": "zhuravlevaanna13051986@postgrespro.ru", "phone": "+70914022741"}
0005432035055	D2C704	6249 420427	SERGEY FEDOROV	{"phone": "+70274729723"}
0005432035056	D2C704	6313 234580	NATALYA KUDRYASHOVA	{"phone": "+70130087542"}
0005432035057	ACD75D	4178 480695	ALEKSANDR PAVLOV	{"phone": "+70574981927"}
0005432035058	ACD75D	6364 852154	GENNADIY KOROLEV	{"email": "korolev_gennadiy-071972@postgrespro.ru", "phone": "+70225002349"}
0005432035059	2A444F	5339 859136	ALEKSANDR SERGEEV	{"phone": "+70048699856"}
0005432035060	AE0056	8798 414746	SERGEY BORISOV	{"phone": "+70254769416"}
0005432035061	AE0056	6869 505153	VYACHESLAV ISAEV	{"email": "vyacheslavisaev_1962@postgrespro.ru", "phone": "+70122383398"}
0005432035062	AE0056	4212 066172	RUSLAN SHEVCHENKO	{"email": "shevchenko-ruslan16061958@postgrespro.ru", "phone": "+70131481534"}
0005432035063	40946F	3816 188534	ALEKSANDR PETROV	{"phone": "+70876361706"}
0005432035064	40946F	9096 047438	VIKTOR KOZLOV	{"phone": "+70896560277"}
0005432035065	820473	0970 758190	VALENTINA FILIPPOVA	{"phone": "+70804826597"}
0005432035066	EB4D9A	6045 100136	ANTON DAVYDOV	{"phone": "+70013654682"}
0005432035067	07CA7A	6970 123709	VLADIMIR MEDVEDEV	{"email": "v_medvedev_23071966@postgrespro.ru", "phone": "+70000527948"}
0005432035068	12953C	0274 183159	ALBERT MARTYNOV	{"phone": "+70814179061"}
0005432035069	12953C	5446 628054	ELENA KOZLOVA	{"phone": "+70477606234"}
0005432035070	FF7DBD	6724 148928	NIKOLAY SEMENOV	{"email": "semenovn101976@postgrespro.ru", "phone": "+70475630907"}
0005432035071	FF7DBD	7385 903398	ALINA EGOROVA	{"email": "alina.egorova091973@postgrespro.ru", "phone": "+70115147707"}
0005432035072	BFA1D2	7781 493021	ALEKSEY FROLOV	{"email": "aleksey-frolov-1960@postgrespro.ru", "phone": "+70283730944"}
0005432035073	2AA497	6530 662468	YULIYA KUDRYASHOVA	{"phone": "+70925052878"}
0005432035074	25E4C8	5859 623702	DENIS YAKOVLEV	{"email": "yakovlev-d_1972@postgrespro.ru", "phone": "+70902043569"}
0005432035075	F00DBE	7772 646719	ELENA VOLKOVA	{"email": "e.volkova-1972@postgrespro.ru", "phone": "+70551496457"}
0005432035076	0EF194	6771 408846	LIDIYA OSIPOVA	{"email": "l_osipova.17091979@postgrespro.ru", "phone": "+70822098047"}
0005432035077	FB75C7	4869 741878	TAMARA FOMINA	{"email": "fomina.tamara-1971@postgrespro.ru", "phone": "+70968357349"}
0005432035078	B8BCF1	0336 587564	IRINA EGOROVA	{"email": "irinaegorova-1963@postgrespro.ru", "phone": "+70915039414"}
0005432035079	98EC25	0512 355376	OLGA MATVEEVA	{"phone": "+70873122311"}
0005432035080	FD1F1F	3757 741814	TATYANA ROMANOVA	{"email": "t_romanova.13051969@postgrespro.ru", "phone": "+70913721672"}
0005432035081	5EF580	8278 040438	ALBINA DAVYDOVA	{"email": "davydova-albina.27081969@postgrespro.ru", "phone": "+70005578913"}
0005432035082	5DD066	2039 747716	IVAN ZAKHAROV	{"email": "ivan-zakharov_05101965@postgrespro.ru", "phone": "+70373508270"}
0005432035083	F5465F	0241 060111	VLADIMIR MELNIKOV	{"phone": "+70237655756"}
0005432035084	3FF2FA	2830 665340	DANIIL TARASOV	{"phone": "+70981341539"}
0005432035085	45EFD7	4124 878633	IGOR KOZLOV	{"phone": "+70018051373"}
0005432035086	B68A0C	9173 048642	ANDREY MEDVEDEV	{"email": "andrey_medvedev-1976@postgrespro.ru", "phone": "+70028136330"}
0005432035087	B68A0C	1334 177912	VLADIMIR ORLOV	{"phone": "+70268547819"}
0005432035088	B68A0C	7229 558281	NINA BORISOVA	{"phone": "+70746082348"}
0005432035089	FD0A36	9601 122457	LARISA ANTONOVA	{"phone": "+70697865021"}
0005432035090	72EAC3	2706 105896	EVGENIY KAZAKOV	{"phone": "+70917283681"}
0005432035091	D96AB9	2376 268745	VLADIMIR FROLOV	{"phone": "+70545094760"}
0005432035092	4621FF	8262 534015	IDA BORISOVA	{"phone": "+70059630351"}
0005432035093	4621FF	2969 653410	ANASTASIYA MARTYNOVA	{"phone": "+70946675853"}
0005432035094	4890D0	3152 611220	YANA YUDINA	{"phone": "+70543369928"}
0005432035095	DFE78E	0769 642337	GALINA POTAPOVA	{"email": "potapova.g_041966@postgrespro.ru", "phone": "+70816780622"}
0005432035096	DFE78E	0587 054875	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr22061972@postgrespro.ru", "phone": "+70024435930"}
0005432035097	B98CAA	0776 511438	SOFYA KULIKOVA	{"phone": "+70439086069"}
0005432035098	B98CAA	1144 074002	NATALYA MOISEEVA	{"phone": "+70324521059"}
0005432035099	3629A1	7481 292229	ALEKSEY MEDVEDEV	{"phone": "+70418364965"}
0005432035100	38020C	7998 475715	VASILIY SIDOROV	{"email": "vasiliysidorov-041967@postgrespro.ru", "phone": "+70228244069"}
0005432035101	38020C	7348 040187	LYUDMILA AFANASEVA	{"phone": "+70207034704"}
0005432035102	7AE29E	7626 400186	VERA ABRAMOVA	{"email": "abramova.vera01031973@postgrespro.ru", "phone": "+70686643197"}
0005432035103	5050A4	1285 057885	NIKITA SMIRNOV	{"phone": "+70586683474"}
0005432035104	5050A4	5988 786341	ROMAN KRASNOV	{"email": "krasnovr.1971@postgrespro.ru", "phone": "+70372130414"}
0005432035105	8D50F5	6850 383932	ELENA NIKIFOROVA	{"email": "nikiforova.elena071976@postgrespro.ru", "phone": "+70597015228"}
0005432035106	8D50F5	3389 189515	VALENTINA FILATOVA	{"phone": "+70591040756"}
0005432035107	8F8286	0196 811565	ARTEM SHEVCHENKO	{"phone": "+70777365693"}
0005432035108	6F05A7	3458 715566	DMITRIY MAKAROV	{"email": "makarov_d_02041961@postgrespro.ru", "phone": "+70682116821"}
0005432035109	6F05A7	4876 073639	GALINA KUZMINA	{"email": "kuzmina.g.031978@postgrespro.ru", "phone": "+70337734034"}
0005432035110	4CD322	2845 535772	MAKSIM IVANOV	{"phone": "+70533714142"}
0005432035111	793C8A	8184 789170	MIKHAIL POPOV	{"phone": "+70690493174"}
0005432035112	87215B	6084 760642	DANIYA BARANOVA	{"email": "d-baranova07031968@postgrespro.ru", "phone": "+70243183938"}
0005432035113	87215B	7496 704178	DANIL FEDOROV	{"phone": "+70747466030"}
0005432035114	4D8F2B	3099 376072	EKATERINA NESTEROVA	{"email": "nesterova-ekaterina-031968@postgrespro.ru", "phone": "+70920150706"}
0005432035115	F639C9	4891 192711	LARISA TIKHONOVA	{"email": "larisa.tikhonova.011978@postgrespro.ru", "phone": "+70559995387"}
0005432035116	F639C9	0432 154436	DARINA BELOVA	{"email": "darinabelova.15091969@postgrespro.ru", "phone": "+70530556169"}
0005432035117	F639C9	0189 517415	MARGARITA PETROVA	{"phone": "+70571583222"}
0005432035118	5BFA05	8659 482652	NADEZHDA ABRAMOVA	{"phone": "+70429596045"}
0005432035119	C955DB	5129 345383	ELENA SOKOLOVA	{"email": "sokolova.elena.1964@postgrespro.ru", "phone": "+70769836052"}
0005432035120	FCDFE1	6406 613932	ANTONINA LEBEDEVA	{"email": "lebedevaantonina051970@postgrespro.ru", "phone": "+70655532828"}
0005432035121	94E239	6389 076246	VALERIY BORISOV	{"email": "borisov.v-091971@postgrespro.ru", "phone": "+70561521784"}
0005432035122	94E239	6916 678667	DMITRIY VLASOV	{"email": "dmitriy_vlasov_30031981@postgrespro.ru", "phone": "+70032684259"}
0005432035123	91C749	8812 580689	DENIS PAVLOV	{"email": "d-pavlov-071985@postgrespro.ru", "phone": "+70088907430"}
0005432035124	91C749	0471 091853	DMITRIY MIRONOV	{"email": "dmironov_11111969@postgrespro.ru", "phone": "+70202981495"}
0005432035125	A02628	4041 799305	NADEZHDA YAKOVLEVA	{"phone": "+70915214629"}
0005432035126	A033E5	5207 997730	LILIYA MATVEEVA	{"email": "liliya-matveeva.031977@postgrespro.ru", "phone": "+70694934274"}
0005432035127	3A63B0	1059 833411	IGOR FOMIN	{"email": "fominigor1970@postgrespro.ru", "phone": "+70318298162"}
0005432035128	A550A7	6069 180917	EVA POTAPOVA	{"email": "potapovae-1974@postgrespro.ru", "phone": "+70667273512"}
0005432035129	9A7C9F	7380 365920	YULIYA PETROVA	{"phone": "+70256836192"}
0005432035130	9A7C9F	4536 780299	TAMARA DMITRIEVA	{"phone": "+70432164845"}
0005432035131	89E7BA	4149 828517	VLADISLAV FEDOROV	{"phone": "+70693216191"}
0005432035132	4AB0BE	3818 096866	EKATERINA BORISOVA	{"phone": "+70357439705"}
0005432035133	FF92B8	5631 811440	OLGA VOLKOVA	{"email": "volkova.olga-1987@postgrespro.ru", "phone": "+70562998889"}
0005432035134	4A66E3	7149 127717	ALEKSANDR FILIPPOV	{"phone": "+70036799244"}
0005432035135	6A8EAF	1145 317010	TATYANA DENISOVA	{"phone": "+70017481711"}
0005432035136	6A8EAF	5881 979911	SVETLANA KARPOVA	{"phone": "+70931887322"}
0005432035137	ECB0B5	0477 179816	EKATERINA KISELEVA	{"email": "ekaterinakiseleva-24081974@postgrespro.ru", "phone": "+70465125603"}
0005432035138	E2FA1F	5266 133411	VIKTOR TIKHONOV	{"phone": "+70814246942"}
0005432035139	E2FA1F	4851 951217	MARINA RYABOVA	{"phone": "+70811497454"}
0005432035140	B221E5	3895 621196	ELENA SOROKINA	{"phone": "+70787382120"}
0005432035141	7DDB97	9288 641447	NIKOLAY SOROKIN	{"phone": "+70114741270"}
0005432035142	7DDB97	8832 219381	ANATOLIY ANDREEV	{"phone": "+70732043888"}
0005432035143	4C8FE3	7112 557181	NIKOLAY IVANOV	{"email": "nikolay-ivanov_1966@postgrespro.ru", "phone": "+70164430100"}
0005432035144	4C8FE3	3797 123972	VIKTOR IVANOV	{"email": "ivanov_viktor.1972@postgrespro.ru", "phone": "+70445652215"}
0005432035145	E331FD	6067 677108	LILIYA YUDINA	{"email": "yudina-l041964@postgrespro.ru", "phone": "+70618341335"}
0005432035146	47A1C3	0763 338634	SERGEY KUZNECOV	{"email": "sergeykuznecov071970@postgrespro.ru", "phone": "+70382329901"}
0005432035147	4036B5	1190 341553	YAN GORBUNOV	{"email": "gorbunov-y-1960@postgrespro.ru", "phone": "+70736366572"}
0005432035148	F722E3	8863 865708	NIKITA STEPANOV	{"email": "stepanov-nikita23091980@postgrespro.ru", "phone": "+70785926948"}
0005432035149	F722E3	9897 403309	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylovaa_01091979@postgrespro.ru", "phone": "+70083783693"}
0005432035150	B078F3	4635 573156	KSENIYA SOKOLOVA	{"email": "kseniya.sokolova-19101965@postgrespro.ru", "phone": "+70640624436"}
0005432035151	7FD10A	6881 776849	VALENTINA MATVEEVA	{"phone": "+70788418533"}
0005432035152	8EB9B8	2004 602983	NIKITA DMITRIEV	{"phone": "+70557229265"}
0005432035153	8EB9B8	8156 126763	DENIS PAVLOV	{"phone": "+70255257577"}
0005432035154	DC6BE6	0203 650400	ROMAN MATVEEV	{"phone": "+70969675010"}
0005432035155	C19219	0511 757281	TATYANA AFANASEVA	{"email": "tatyana.afanaseva-05011978@postgrespro.ru", "phone": "+70555283436"}
0005432035156	C19219	2315 899540	TATYANA RYABOVA	{"email": "t.ryabova-1973@postgrespro.ru", "phone": "+70725976468"}
0005432035157	463266	4223 819564	IRINA STEPANOVA	{"email": "i.stepanova-011963@postgrespro.ru", "phone": "+70687176929"}
0005432035158	976163	6630 241576	NINA ANDREEVA	{"email": "andreevan07041978@postgrespro.ru", "phone": "+70686822608"}
0005432035159	F4AD8E	4360 842228	MARIYA ALEKSEEVA	{"phone": "+70170202876"}
0005432035160	598CCE	8718 975217	ELENA GORBUNOVA	{"email": "elena.gorbunova-25111983@postgrespro.ru", "phone": "+70210166627"}
0005432035161	3ED620	7908 534117	ROMAN SAVELEV	{"email": "savelev_r.021975@postgrespro.ru", "phone": "+70916386064"}
0005432035162	46B02F	5524 916343	ARTEM ALEKSEEV	{"phone": "+70044579412"}
0005432035163	80036F	1659 282022	EVGENIYA PETROVA	{"phone": "+70295825332"}
0005432035164	CDC1E1	7039 871245	ALENA MOROZOVA	{"email": "morozova.a091978@postgrespro.ru", "phone": "+70219607997"}
0005432035165	9CD84D	3604 156868	MIKHAIL PETROV	{"email": "petrov_mikhail-111974@postgrespro.ru", "phone": "+70087123647"}
0005432035166	521CE5	9014 368895	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay25081979@postgrespro.ru", "phone": "+70668692271"}
0005432035167	10EA8A	1280 827787	EVGENIY ANTONOV	{"email": "antonove-021970@postgrespro.ru", "phone": "+70466207790"}
0005432035168	10EA8A	9235 029828	DARYA SIDOROVA	{"email": "sidorova_darya21071979@postgrespro.ru", "phone": "+70281594965"}
0005432035169	51536A	0745 535199	OKSANA RODIONOVA	{"email": "o_rodionova_20071969@postgrespro.ru", "phone": "+70753741946"}
0005432035170	3283C7	4297 088560	VALENTIN ABRAMOV	{"email": "abramovvalentin_1968@postgrespro.ru", "phone": "+70163986616"}
0005432035171	EACA2D	5877 989418	SERGEY KISELEV	{"email": "s.kiselev-1982@postgrespro.ru", "phone": "+70916427398"}
0005432035172	CCF693	6880 963225	EVGENIY ALEKSEEV	{"email": "alekseev.evgeniy_22091965@postgrespro.ru", "phone": "+70822117867"}
0005432035173	B9AF5D	0825 640745	NIKOLAY SHEVCHENKO	{"phone": "+70728309620"}
0005432035174	B9AF5D	0718 249764	ARMEN IVANOV	{"phone": "+70684514183"}
0005432035175	F0F4D3	9698 057382	VERA NIKIFOROVA	{"phone": "+70287373277"}
0005432035176	F0F4D3	9915 457691	ARTEM GAVRILOV	{"phone": "+70219286838"}
0005432035177	F0F4D3	1016 488027	NINA MIRONOVA	{"email": "nina-mironova09011983@postgrespro.ru", "phone": "+70414343970"}
0005432035178	547185	3877 028960	ALEKSEY AFANASEV	{"phone": "+70451234625"}
0005432035179	547185	1159 937116	GALINA BORISOVA	{"phone": "+70776338977"}
0005432035180	E655AD	3644 060286	ALEKSEY ZAKHAROV	{"phone": "+70141089667"}
0005432035181	C9BAED	8622 057556	NINA MOROZOVA	{"email": "n-morozova1975@postgrespro.ru", "phone": "+70669298068"}
0005432035182	C9BAED	3261 425749	ANZHELIKA NOVIKOVA	{"email": "a_novikova09011983@postgrespro.ru", "phone": "+70585726966"}
0005432035183	E56995	8590 012553	LYUDMILA SEMENOVA	{"phone": "+70054119016"}
0005432035184	3287EE	1267 710870	ELENA POTAPOVA	{"phone": "+70478278170"}
0005432035185	B13785	5152 950415	ARINA FROLOVA	{"email": "arina-frolova.1968@postgrespro.ru", "phone": "+70165076825"}
0005432035186	B13785	5697 534935	ALEKSANDR KAZAKOV	{"phone": "+70365363318"}
0005432035187	38DA0F	0168 558596	NATALYA KUZMINA	{"email": "natalya_kuzmina-1976@postgrespro.ru", "phone": "+70115545634"}
0005432035188	F7E342	0591 472910	IRINA KUZMINA	{"email": "kuzmina-i_1981@postgrespro.ru", "phone": "+70747746363"}
0005432035189	98B7CA	0300 114104	TATYANA OSIPOVA	{"email": "t.osipova.041979@postgrespro.ru", "phone": "+70090533114"}
0005432035190	F14B6D	5429 310855	MIKHAIL SEMENOV	{"email": "m_semenov111978@postgrespro.ru", "phone": "+70252055211"}
0005432035191	F14B6D	2957 886129	ALEKSANDRA SOLOVEVA	{"email": "aleksandra-soloveva-071971@postgrespro.ru", "phone": "+70853667797"}
0005432035192	A29E4E	9244 765244	TATYANA KUZMINA	{"phone": "+70222386894"}
0005432035193	A29E4E	9638 370331	VALERIYA STEPANOVA	{"phone": "+70980092344"}
0005432035194	73A353	6558 463279	VIKTOR ZHUKOV	{"email": "zhukov_viktor-13121970@postgrespro.ru", "phone": "+70124098009"}
0005432035195	A06EFA	9550 294893	EKATERINA IVANOVA	{"email": "ivanova.e1966@postgrespro.ru", "phone": "+70281626254"}
0005432035196	6F54D9	3113 722107	OKSANA GAVRILOVA	{"email": "gavrilovaoksana.051976@postgrespro.ru", "phone": "+70809013354"}
0005432035197	D23207	5189 370161	EVGENIYA KOROLEVA	{"email": "koroleva.e_121979@postgrespro.ru", "phone": "+70414751896"}
0005432035198	9C8DBF	9594 542945	ALEKSANDR SCHERBAKOV	{"phone": "+70237172327"}
0005432035199	CBBF13	5804 273077	OKSANA FROLOVA	{"email": "oksana.frolova_11041971@postgrespro.ru", "phone": "+70822641520"}
0005432035200	234758	8928 912601	DAMIR ALEKSANDROV	{"phone": "+70006055267"}
0005432035201	BB2641	9866 732252	ELENA ROMANOVA	{"email": "elenaromanova_1974@postgrespro.ru", "phone": "+70676910725"}
0005432035202	BB2641	7843 328972	ANDREY KUZMIN	{"phone": "+70572775194"}
0005432035203	B9B686	3868 670812	VLADIMIR VOROBEV	{"phone": "+70437075377"}
0005432035204	2A5B30	6289 436847	SOFIYA OVCHINNIKOVA	{"phone": "+70247709245"}
0005432035205	7EC742	9426 756633	TATYANA STEPANOVA	{"email": "stepanova-tatyana-1975@postgrespro.ru", "phone": "+70975492174"}
0005432035206	7E6FDB	6403 011495	OLGA GERASIMOVA	{"phone": "+70709118620"}
0005432035207	3C3C53	7744 440825	VLADIMIR EGOROV	{"phone": "+70770942075"}
0005432035208	4E2113	8347 820654	NIKITA STEPANOV	{"email": "n_stepanov_14041979@postgrespro.ru", "phone": "+70444101164"}
0005432035209	072355	4589 560781	ANDREY BONDARENKO	{"phone": "+70873267860"}
0005432035210	29E225	1607 115730	DINA VOLKOVA	{"email": "d-volkova04071973@postgrespro.ru", "phone": "+70293572755"}
0005432035211	29E225	2689 512262	ANNA VASILEVA	{"email": "avasileva.1981@postgrespro.ru", "phone": "+70891401517"}
0005432035212	2FB08F	4941 219251	ANASTASIYA KUDRYASHOVA	{"phone": "+70057008161"}
0005432035213	2FB08F	3820 639576	VLADIMIR VASILEV	{"email": "vladimir-vasilev101976@postgrespro.ru", "phone": "+70770410763"}
0005432035214	2FB08F	8864 377635	NATALYA OSIPOVA	{"email": "osipovanatalya-061965@postgrespro.ru", "phone": "+70240559866"}
0005432035215	5A3707	5765 182318	DAVID ALEKSEEV	{"email": "alekseevd_091952@postgrespro.ru", "phone": "+70808009715"}
0005432035216	969557	6180 610943	NATALYA MELNIKOVA	{"phone": "+70720209705"}
0005432035217	52F48E	3816 142831	EVDOKIYA SOKOLOVA	{"email": "evdokiya.sokolova_1971@postgrespro.ru", "phone": "+70194261837"}
0005432035218	52F48E	7484 026573	ILDAR IVANOV	{"email": "ivanov-i081969@postgrespro.ru", "phone": "+70786875031"}
0005432035219	CC8B51	1533 543797	PETR ANDREEV	{"phone": "+70163530261"}
0005432035220	FE3384	9589 394243	OLGA KUZNECOVA	{"phone": "+70565587227"}
0005432035221	FE3384	9521 247459	IRINA BARANOVA	{"phone": "+70759792584"}
0005432035222	8BC9BF	6454 449381	SERGEY MAKSIMOV	{"phone": "+70290365961"}
0005432035223	471D47	4786 954809	MARIYA POPOVA	{"email": "mariya_popova18041972@postgrespro.ru", "phone": "+70991444884"}
0005432035224	7C86E8	5143 999636	SERGEY DAVYDOV	{"phone": "+70431806170"}
0005432035225	2B7124	1735 722029	NIKOLAY MIKHAYLOV	{"phone": "+70807133215"}
0005432035226	1002AC	6563 082843	SERGEY GORBUNOV	{"email": "gorbunov.sergey_031971@postgrespro.ru", "phone": "+70535700297"}
0005432035227	51E729	9414 077006	MARIYA MIRONOVA	{"email": "m_mironova1957@postgrespro.ru", "phone": "+70336779984"}
0005432035228	51E729	4533 741185	MIKHAIL PETROV	{"phone": "+70089756417"}
0005432035229	C48DD9	4060 869683	ALEKSEY PAVLOV	{"phone": "+70387374229"}
0005432035230	998DA2	2699 080832	VASILISA ANTONOVA	{"email": "antonova-v-101967@postgrespro.ru", "phone": "+70056265877"}
0005432035231	9AF680	1061 463221	NATALYA TIKHONOVA	{"email": "ntikhonova_13021972@postgrespro.ru", "phone": "+70644820199"}
0005432035232	41F8C1	7114 154931	ELENA FADEEVA	{"email": "fadeevaelena_27061985@postgrespro.ru", "phone": "+70889434654"}
0005432035233	1C5C09	6391 737112	ELIZAVETA KOZLOVA	{"email": "kozlova.e.1981@postgrespro.ru", "phone": "+70860360730"}
0005432035234	1E2459	5477 979367	KONSTANTIN OSIPOV	{"email": "osipovkonstantin-091968@postgrespro.ru", "phone": "+70111683065"}
0005432035235	CCE096	0096 931751	VALENTINA IVANOVA	{"phone": "+70295961528"}
0005432035236	CCE096	7918 064701	SOFYA AKIMOVA	{"phone": "+70102897664"}
0005432035237	CCE096	6850 321522	VLADIMIR KOROLEV	{"email": "v-korolev04031967@postgrespro.ru", "phone": "+70759482134"}
0005432035238	53D2DA	6976 326822	SERGEY KISELEV	{"email": "kiselev-s-17031976@postgrespro.ru", "phone": "+70306173949"}
0005432035239	249474	4802 522805	RADIK ZAYCEV	{"phone": "+70837910748"}
0005432035240	2AAE25	2868 101307	ANATOLIY KUDRYASHOV	{"phone": "+70132231332"}
0005432035241	2AAE25	1597 383113	ILYA ANDREEV	{"email": "ilyaandreev121977@postgrespro.ru", "phone": "+70389914677"}
0005432035242	C49778	7048 507071	VALERIY KUZMIN	{"email": "v_kuzmin_121964@postgrespro.ru", "phone": "+70749100591"}
0005432035243	C49778	6869 035216	ALEKSANDRA ROMANOVA	{"email": "a_romanova.1974@postgrespro.ru", "phone": "+70876559161"}
0005432035244	9854E2	5906 104026	SERGEY BARANOV	{"email": "s.baranov1966@postgrespro.ru", "phone": "+70805782552"}
0005432035245	9854E2	0240 183599	NINA IVANOVA	{"phone": "+70141638146"}
0005432035247	EAB251	9948 937350	VALENTINA KOROLEVA	{"email": "valentinakoroleva-1972@postgrespro.ru", "phone": "+70659716388"}
0005432035248	EAB251	5090 800808	NATALYA VOLKOVA	{"email": "volkova.natalya.05081959@postgrespro.ru", "phone": "+70068381580"}
0005432035249	1637E1	1649 675466	YURIY GRIGOREV	{"email": "yuriygrigorev-021974@postgrespro.ru", "phone": "+70734866761"}
0005432035250	431247	0636 128455	PAVEL AFANASEV	{"email": "pavelafanasev.1963@postgrespro.ru", "phone": "+70613499232"}
0005432035251	16CDC3	4433 727432	NATALYA KUZNECOVA	{"email": "kuznecova_n_07041969@postgrespro.ru", "phone": "+70565380180"}
0005432035252	BABED6	4328 418665	LYUDMILA FADEEVA	{"email": "fadeeva.l_20061960@postgrespro.ru", "phone": "+70351752073"}
0005432035253	0F2239	9848 091844	ALEKSANDR NAZAROV	{"phone": "+70645124754"}
0005432035254	0F2239	5846 671023	KONSTANTIN KOZLOV	{"phone": "+70548574425"}
0005432035255	0F2239	3341 746760	BORIS NAZAROV	{"phone": "+70896838922"}
0005432035256	14D1AD	8242 362369	DENIS KULIKOV	{"email": "kulikov-denis_10011974@postgrespro.ru", "phone": "+70379016137"}
0005432035257	19448F	3667 598455	TATYANA ZHUKOVA	{"email": "tatyana-zhukova_1971@postgrespro.ru", "phone": "+70155614211"}
0005432035258	6F6694	0082 641903	SERGEY STEPANOV	{"email": "stepanovsergey.11111981@postgrespro.ru", "phone": "+70646980669"}
0005432035259	A97F19	3653 117945	ALEKSANDRA SEMENOVA	{"phone": "+70754157623"}
0005432035260	5D551A	8358 153204	VLADIMIR FOMIN	{"email": "vladimir_fomin-27031954@postgrespro.ru", "phone": "+70454207039"}
0005432035261	5D551A	4709 404687	BORIS VOLKOV	{"phone": "+70989041373"}
0005432035262	E1A9CD	8062 688907	VALENTINA KISELEVA	{"email": "kiseleva-v.1964@postgrespro.ru", "phone": "+70102639425"}
0005432035263	7C66D5	2557 611383	VLADIMIR KOROLEV	{"phone": "+70895324075"}
0005432035264	009C82	4287 710629	IVAN SMIRNOV	{"email": "i_smirnov-1978@postgrespro.ru", "phone": "+70345178343"}
0005432035265	6D30A4	9657 303686	VALENTINA EFIMOVA	{"phone": "+70649683020"}
0005432035266	0FAED7	8889 753512	YULIYA SEMENOVA	{"phone": "+70825370536"}
0005432035267	8F2B2C	3259 424116	TATYANA NIKOLAEVA	{"email": "nikolaeva_tatyana_101969@postgrespro.ru", "phone": "+70106816759"}
0005432035268	56709E	3226 686371	NIKOLAY ZHURAVLEV	{"phone": "+70387704590"}
0005432035269	6F8DC6	5674 174881	IRINA ZAYCEVA	{"phone": "+70361354385"}
0005432035270	88AD81	5137 189990	NIKOLAY FILIPPOV	{"email": "filippov.nikolay-061974@postgrespro.ru", "phone": "+70552663264"}
0005432035271	88AD81	9349 644273	VIKTOR POPOV	{"phone": "+70372015400"}
0005432035272	084D2E	6858 902618	GRIGORIY FOMIN	{"email": "fomingrigoriy-091969@postgrespro.ru", "phone": "+70233300252"}
0005432035273	084D2E	6934 043273	GALINA NESTEROVA	{"email": "nesterova_g_081974@postgrespro.ru", "phone": "+70124805944"}
0005432035274	878A07	4057 326119	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov.071973@postgrespro.ru", "phone": "+70878948876"}
0005432035275	B963DC	9340 304218	ANNA NIKIFOROVA	{"email": "anna-nikiforova.011977@postgrespro.ru", "phone": "+70323671003"}
0005432035276	34B86A	5843 319454	NINA ALEKSANDROVA	{"email": "aleksandrovan091980@postgrespro.ru", "phone": "+70168659152"}
0005432035277	BEA4C5	8720 169167	RIMMA TARASOVA	{"email": "rimma-tarasova071977@postgrespro.ru", "phone": "+70233903718"}
0005432035278	6DE96C	5252 497398	VADIM BORISOV	{"phone": "+70912959606"}
0005432035279	9928CC	0139 343134	TATYANA TITOVA	{"email": "tatyana_titova1981@postgrespro.ru", "phone": "+70147410475"}
0005432035280	9928CC	4526 521549	VALERIY GAVRILOV	{"phone": "+70862398341"}
0005432035281	62E38D	9843 577950	DMITRIY KUZNECOV	{"phone": "+70289711284"}
0005432035282	A5ABCC	9266 393829	NINA BELOVA	{"email": "belovanina.02061972@postgrespro.ru", "phone": "+70646727885"}
0005432035283	932EC3	5140 746996	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva1973@postgrespro.ru", "phone": "+70812195573"}
0005432035284	932EC3	2369 213471	SERGEY SERGEEV	{"email": "ssergeev-121969@postgrespro.ru", "phone": "+70285184346"}
0005432035285	362FBB	7054 202215	LARISA KUZNECOVA	{"phone": "+70707394590"}
0005432035286	FAE42B	9567 291636	VLADISLAV BARANOV	{"phone": "+70729220192"}
0005432035287	78B56C	0729 278305	YULIYA ABRAMOVA	{"email": "abramova.yuliya_25021975@postgrespro.ru", "phone": "+70692918277"}
0005432035288	0430CD	4700 752320	NATALYA GERASIMOVA	{"email": "n.gerasimova.101963@postgrespro.ru", "phone": "+70664567856"}
0005432035289	F0EE0F	9957 918503	OLEG VOLKOV	{"phone": "+70864062128"}
0005432035290	F0EE0F	1362 461352	YURIY GUSEV	{"phone": "+70070671733"}
0005432035291	8B7EAB	5903 000607	ELENA MAKAROVA	{"phone": "+70522975715"}
0005432035292	4DE02D	7445 634973	OLEG FILIPPOV	{"phone": "+70632097635"}
0005432035293	4DE02D	5782 683918	VIKTOR BONDARENKO	{"phone": "+70806554270"}
0005432035294	4DE02D	5497 192351	ANDREY NOVIKOV	{"phone": "+70291787279"}
0005432035295	587DEC	3881 637567	ELENA SMIRNOVA	{"email": "elena-smirnova12081979@postgrespro.ru", "phone": "+70506376857"}
0005432035296	23FD61	8875 144510	ANNA PAVLOVA	{"email": "pavlova_a1980@postgrespro.ru", "phone": "+70142339597"}
0005432035297	4EAA09	0720 886177	DENIS DENISOV	{"email": "denisovd_1969@postgrespro.ru", "phone": "+70497632247"}
0005432035298	DCC483	4026 841162	VALENTINA BOGDANOVA	{"phone": "+70958911852"}
0005432035299	F4831C	4344 239920	ZOYA NESTEROVA	{"phone": "+70808495674"}
0005432035300	0D7A8E	8669 677068	MARIYA BOGDANOVA	{"email": "m_bogdanova.1990@postgrespro.ru", "phone": "+70768820589"}
0005432035301	B54EE2	5313 104390	ARTEM KRASNOV	{"email": "artem.krasnov.071977@postgrespro.ru", "phone": "+70847115557"}
0005432035302	B54EE2	8244 502402	DARYA KUZNECOVA	{"phone": "+70630130951"}
0005432035303	B54EE2	7689 741012	SVETLANA ROMANOVA	{"email": "s-romanova_21061973@postgrespro.ru", "phone": "+70179044593"}
0005432035304	9D66E3	5964 749847	VALENTINA SAVELEVA	{"email": "savelevavalentina-011979@postgrespro.ru", "phone": "+70802071041"}
0005432035305	9D66E3	6771 715419	ILDAR KUZNECOV	{"email": "kuznecov.i031975@postgrespro.ru", "phone": "+70578139001"}
0005432035306	E82983	4915 520265	VASILIY GORBUNOV	{"phone": "+70920818141"}
0005432035307	A6B9A6	1869 041303	IRINA KRASNOVA	{"email": "i.krasnova1973@postgrespro.ru", "phone": "+70370353199"}
0005432035308	5778E0	3608 825969	KRISTINA FADEEVA	{"phone": "+70547124413"}
0005432035309	7EF3CB	3308 715876	TAMARA SERGEEVA	{"email": "tamara.sergeeva_1968@postgrespro.ru", "phone": "+70286802602"}
0005432035310	218107	3985 886831	RAVIL ZHURAVLEV	{"phone": "+70889379462"}
0005432035311	218107	5718 581035	SERGEY KONOVALOV	{"email": "konovalov_s-1974@postgrespro.ru", "phone": "+70422885491"}
0005432035312	44E6EA	7075 337983	YULIYA KISELEVA	{"phone": "+70510981579"}
0005432035313	5C6507	5376 939048	LARISA ZOTOVA	{"phone": "+70157139885"}
0005432035314	D20EF0	8119 654425	MAKSIM KUZNECOV	{"email": "m-kuznecov-1964@postgrespro.ru", "phone": "+70415873809"}
0005432035315	D20EF0	9537 649706	KRISTINA FROLOVA	{"email": "kristina-frolova121975@postgrespro.ru", "phone": "+70579671780"}
0005432035316	3513F7	2549 334241	OLEG MAKAROV	{"email": "o.makarov.01101972@postgrespro.ru", "phone": "+70384857267"}
0005432035317	CDCF75	2772 136614	GRIGORIY KISELEV	{"email": "grigoriykiselev081970@postgrespro.ru", "phone": "+70332773164"}
0005432035318	70EBB4	8571 141527	SVETLANA KISELEVA	{"phone": "+70880896774"}
0005432035319	70EBB4	0675 895876	YULIYA SEMENOVA	{"phone": "+70204963706"}
0005432035320	70EBB4	2447 699715	ANDREY MIRONOV	{"email": "andrey-mironov.27081976@postgrespro.ru", "phone": "+70044371123"}
0005432035321	4FD56E	5568 992461	TATYANA MEDVEDEVA	{"phone": "+70893689487"}
0005432035322	A20075	3297 680126	NADEZHDA AKIMOVA	{"email": "n-akimova-25081964@postgrespro.ru", "phone": "+70827131512"}
0005432035323	950884	5557 949516	ALENA KAZAKOVA	{"email": "kazakovaalena-081968@postgrespro.ru", "phone": "+70472593225"}
0005432035324	950884	9000 466137	MARIYA MARTYNOVA	{"email": "mariya-martynova-1969@postgrespro.ru", "phone": "+70134163094"}
0005432035325	F10F6E	7669 933845	SVETLANA NIKOLAEVA	{"email": "svetlananikolaeva.101966@postgrespro.ru", "phone": "+70712488270"}
0005432035326	AF5FBD	0888 973171	ANASTASIYA NOVIKOVA	{"email": "novikova.anastasiya_041971@postgrespro.ru", "phone": "+70873176218"}
0005432035327	AF5FBD	5780 956232	LILIYA ABRAMOVA	{"email": "liliya.abramova.1979@postgrespro.ru", "phone": "+70188321817"}
0005432035328	1772BF	1029 213206	DMITRIY KOZLOV	{"phone": "+70124984976"}
0005432035329	50D356	4639 668546	TATYANA EGOROVA	{"email": "tatyanaegorova-031976@postgrespro.ru", "phone": "+70296342965"}
0005432035330	E8E523	5377 898288	IRINA BOGDANOVA	{"phone": "+70398073149"}
0005432035331	83850F	7024 662955	IVAN VOROBEV	{"email": "vorobev_i-031974@postgrespro.ru", "phone": "+70390188650"}
0005432035332	28EAD3	1916 681520	TATYANA GRISHINA	{"phone": "+70303150920"}
0005432035333	7723F2	9991 125037	ALEKSANDR IVANOV	{"email": "a.ivanov_18051976@postgrespro.ru", "phone": "+70192224446"}
0005432035334	B9B2D4	2493 261308	ALEKSANDRA DMITRIEVA	{"email": "dmitrieva.a12011983@postgrespro.ru", "phone": "+70776408471"}
0005432035335	B9B2D4	0831 296693	IRINA PAVLOVA	{"email": "pavlova.i051993@postgrespro.ru", "phone": "+70298439530"}
0005432035336	C16CC3	8640 559958	ANASTASIYA SOKOLOVA	{"phone": "+70956481055"}
0005432035337	CAC92F	0015 478011	NIKOLAY KAZAKOV	{"email": "n-kazakov.081968@postgrespro.ru", "phone": "+70619894462"}
0005432035338	ED1701	8157 058544	ANDREY IVANOV	{"phone": "+70745212191"}
0005432035339	ED1701	0535 280121	PAVEL ROMANOV	{"email": "pavel-romanov_021960@postgrespro.ru", "phone": "+70627079540"}
0005432035340	94FB48	3780 921406	ARTEM KARPOV	{"email": "karpov_artem-081975@postgrespro.ru", "phone": "+70223518608"}
0005432035341	94FB48	5911 367919	ALEKSANDR PETROV	{"phone": "+70315697431"}
0005432035342	B6C918	2224 512686	LILIYA IVANOVA	{"email": "ivanova-l1960@postgrespro.ru", "phone": "+70440592617"}
0005432035343	B42B2C	2910 923053	MARIYA SAVELEVA	{"email": "m-saveleva1974@postgrespro.ru", "phone": "+70033321365"}
0005432035344	B42B2C	6398 023130	ALEKSANDR ROMANOV	{"phone": "+70804201370"}
0005432035345	E5C058	6059 421682	DIANA KOMAROVA	{"email": "komarova_d051972@postgrespro.ru", "phone": "+70075198891"}
0005432035346	E5C058	3677 322881	EKATERINA GUSEVA	{"email": "gusevae_1971@postgrespro.ru", "phone": "+70742933783"}
0005432035347	1B3137	1448 647794	OLGA NOVIKOVA	{"email": "olga.novikova_1964@postgrespro.ru", "phone": "+70048987486"}
0005432035348	832E32	9564 527458	ALEKSANDR BORISOV	{"phone": "+70156333832"}
0005432035349	11B934	7049 205376	NATALYA MAKAROVA	{"phone": "+70588405587"}
0005432035350	D1257A	2422 286583	ALEKSANDR SCHERBAKOV	{"phone": "+70119573754"}
0005432035351	6434A7	7433 044955	SOFYA LEBEDEVA	{"phone": "+70080461864"}
0005432035352	6434A7	4555 230829	DMITRIY VASILEV	{"phone": "+70884973538"}
0005432035353	9C7159	9546 486397	MARINA NAZAROVA	{"email": "marina-nazarova-121970@postgrespro.ru", "phone": "+70439012385"}
0005432035354	9C7159	5984 274308	MIKHAIL NAZAROV	{"phone": "+70592285621"}
0005432035355	CFEDE6	6714 512050	ELENA VOROBEVA	{"email": "elena-vorobeva021975@postgrespro.ru", "phone": "+70362854195"}
0005432035356	235CF0	4762 080756	MARINA VLASOVA	{"email": "vlasovam-091970@postgrespro.ru", "phone": "+70578156841"}
0005432035357	235CF0	1678 166218	SVETLANA MAKAROVA	{"phone": "+70490512105"}
0005432035358	CAF41D	7179 065113	IGOR SIDOROV	{"email": "igor_sidorov_111971@postgrespro.ru", "phone": "+70931942948"}
0005432035359	CAF41D	9143 465395	ZOYA KUZNECOVA	{"email": "kuznecova.z_1969@postgrespro.ru", "phone": "+70354456772"}
0005432035360	7530D1	2633 729498	DARYA MALYSHEVA	{"email": "malysheva.darya_14021967@postgrespro.ru", "phone": "+70011826635"}
0005432035361	38B630	2733 482875	ILSHAT ZAKHAROV	{"phone": "+70563702739"}
0005432035362	993593	9993 414277	ANDREY VOROBEV	{"phone": "+70923244264"}
0005432035363	EA5CF8	8917 892718	OLEG MEDVEDEV	{"email": "o_medvedev12121969@postgrespro.ru", "phone": "+70001147776"}
0005432035364	EA5CF8	0733 520214	RINAT EGOROV	{"phone": "+70724600624"}
0005432035423	5EFB93	3571 620014	ELENA FROLOVA	{"phone": "+70265983100"}
0005432035365	AB843E	2826 694430	LIDIYA PAVLOVA	{"email": "lidiya_pavlova.17031983@postgrespro.ru", "phone": "+70933853451"}
0005432035366	AB843E	4942 502018	MILENA NESTEROVA	{"phone": "+70618073402"}
0005432035367	AE8005	1890 733181	LYUBOV SMIRNOVA	{"phone": "+70366789249"}
0005432035368	1843B6	0960 654737	YANA ANDREEVA	{"email": "y-andreeva1972@postgrespro.ru", "phone": "+70069300744"}
0005432035369	6B5714	8639 837983	ALEKSEY SOROKIN	{"phone": "+70090162394"}
0005432035370	6D5BAA	4013 155165	ANNA OVCHINNIKOVA	{"email": "ovchinnikovaa_18041969@postgrespro.ru", "phone": "+70789200326"}
0005432035371	6D5BAA	9433 493051	VLADIMIR VASILEV	{"email": "vasilevv.121969@postgrespro.ru", "phone": "+70472390851"}
0005432035372	AAC3FA	4504 156392	DANIIL GORBUNOV	{"phone": "+70931229455"}
0005432035373	AAC3FA	6412 762437	ANNA SERGEEVA	{"phone": "+70970370375"}
0005432035374	43027D	6088 761368	NADEZHDA FROLOVA	{"email": "nadezhda.frolova.25061969@postgrespro.ru", "phone": "+70112178039"}
0005432035375	017DF6	5076 259826	GALINA OSIPOVA	{"email": "osipova-g.16071970@postgrespro.ru", "phone": "+70243550285"}
0005432035376	289952	5703 976935	ALEKSANDR PAVLOV	{"email": "pavlov.a111962@postgrespro.ru", "phone": "+70955788214"}
0005432035377	289952	2451 940734	MAKSIM IVANOV	{"email": "ivanov_maksim.18051968@postgrespro.ru", "phone": "+70078699722"}
0005432035378	031273	2662 601956	OLGA ROMANOVA	{"phone": "+70038154722"}
0005432035379	031273	4256 466694	ILGIZ KUZMIN	{"phone": "+70758966799"}
0005432035380	E4629B	3259 996281	IRINA OSIPOVA	{"phone": "+70161373845"}
0005432035381	5A1912	8082 288072	VERONIKA IVANOVA	{"email": "veronika_ivanova_07041982@postgrespro.ru", "phone": "+70021092546"}
0005432035382	5A1912	0325 031169	ALEKSANDR SOKOLOV	{"phone": "+70903514038"}
0005432035383	3E9CE7	3164 096464	OLGA MARTYNOVA	{"phone": "+70766913083"}
0005432035384	3E9CE7	1414 418934	RUSLAN OSIPOV	{"email": "ruslan_osipov-051972@postgrespro.ru", "phone": "+70587180954"}
0005432035385	FB255F	1400 590446	IRINA KONOVALOVA	{"phone": "+70898451078"}
0005432035386	40404D	8270 306365	LYUBOV SOLOVEVA	{"phone": "+70587611771"}
0005432035387	40404D	8463 755076	ROMAN ILIN	{"phone": "+70320536907"}
0005432035388	40404D	7213 030169	YURIY PETROV	{"phone": "+70893610186"}
0005432035389	1C937A	2484 285240	EVGENIY KUZNECOV	{"phone": "+70383756095"}
0005432035390	7D7DE6	1525 134102	SERGEY DMITRIEV	{"email": "dmitriev_sergey101965@postgrespro.ru", "phone": "+70857230899"}
0005432035391	B81F14	2066 454678	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr1974@postgrespro.ru", "phone": "+70832073194"}
0005432035392	CF25C7	5472 748478	LYUDMILA EGOROVA	{"phone": "+70594093481"}
0005432035393	CF25C7	3390 292662	DARYA KISELEVA	{"phone": "+70721982108"}
0005432035394	CF25C7	9442 540426	RINAT NOVIKOV	{"email": "r-novikov.031983@postgrespro.ru", "phone": "+70411892703"}
0005432035395	0E50AA	3653 383722	NIKITA FROLOV	{"email": "nfrolov_1976@postgrespro.ru", "phone": "+70185729813"}
0005432035396	0E50AA	3227 969774	DANIL KOZLOV	{"phone": "+70029937392"}
0005432035397	0E50AA	6831 461313	OLGA DAVYDOVA	{"phone": "+70827964224"}
0005432035398	E3512B	7743 632917	OLGA ISAEVA	{"phone": "+70266243637"}
0005432035399	E3512B	7994 926207	NATALYA MOROZOVA	{"phone": "+70457030037"}
0005432035400	98651D	5821 946673	IRINA POLYAKOVA	{"phone": "+70963581049"}
0005432035401	98651D	7807 828718	ALEKSANDR KOROLEV	{"email": "a-korolev1976@postgrespro.ru", "phone": "+70051619124"}
0005432035402	B5DEDB	4178 645694	VALENTINA POLYAKOVA	{"email": "polyakova_valentina_20091986@postgrespro.ru", "phone": "+70479431539"}
0005432035403	B5DEDB	5850 806513	VALERIY YAKOVLEV	{"phone": "+70024271498"}
0005432035404	E04F11	9757 551881	ANDREY KOZLOV	{"phone": "+70375379736"}
0005432035405	E6CF02	2853 822980	ANNA NIKITINA	{"phone": "+70840514869"}
0005432035406	B9A9CD	2133 710354	ALEKSEY KOZLOV	{"phone": "+70127377256"}
0005432035407	B9A9CD	2181 352704	VALERIY SMIRNOV	{"phone": "+70377563777"}
0005432035408	E1CC19	0118 297864	VALENTINA KUZNECOVA	{"phone": "+70015790291"}
0005432035409	826831	5900 815045	SERGEY VASILEV	{"phone": "+70600116489"}
0005432035410	0E86D0	4183 710646	ALEKSEY BORISOV	{"phone": "+70491051490"}
0005432035411	2E5BCF	5256 877628	MARAT KUZNECOV	{"phone": "+70860766311"}
0005432035412	2E5BCF	9598 957166	VLADIMIR KUZNECOV	{"phone": "+70363447250"}
0005432035413	9BA76C	9248 524437	EKATERINA NIKOLAEVA	{"phone": "+70109866007"}
0005432035414	66A56B	3918 383734	PAVEL KULIKOV	{"phone": "+70851539122"}
0005432035415	5F828F	6055 558904	GULNARA MIKHAYLOVA	{"phone": "+70390015068"}
0005432035416	AC5B7B	6334 861370	ANNA ZOTOVA	{"phone": "+70164414349"}
0005432035417	AC5B7B	3579 326129	VASILIY MIKHAYLOV	{"phone": "+70012976765"}
0005432035418	1483D2	3385 117604	TAMARA VOLKOVA	{"phone": "+70438930820"}
0005432035419	4A4F41	3206 372191	NINA FILIPPOVA	{"email": "n_filippova.20051971@postgrespro.ru", "phone": "+70540840333"}
0005432035420	4A4F41	0447 225699	NADEZHDA SMIRNOVA	{"email": "smirnovan_081970@postgrespro.ru", "phone": "+70448720190"}
0005432035421	9A23BC	5547 408993	KSENIYA NESTEROVA	{"email": "nesterova-k.1972@postgrespro.ru", "phone": "+70444988380"}
0005432035422	9A23BC	1492 257096	LILIYA ISAEVA	{"phone": "+70215678308"}
0005432035424	825D56	0467 184698	ALLA DMITRIEVA	{"phone": "+70861336165"}
0005432035425	825D56	9306 187765	SERGEY MIRONOV	{"email": "sergey_mironov.061965@postgrespro.ru", "phone": "+70030517020"}
0005432035426	181AD1	0260 172811	MARIYA IVANOVA	{"phone": "+70891232553"}
0005432035427	181AD1	4662 035916	LYUDMILA KARPOVA	{"phone": "+70279263150"}
0005432035428	181AD1	9054 629802	VLADIMIR KONOVALOV	{"email": "v-konovalov15041983@postgrespro.ru", "phone": "+70124839127"}
0005432035429	E611C3	6597 132018	ALEKSANDR FEDOROV	{"phone": "+70783986957"}
0005432035430	E611C3	9401 779194	GALINA NESTEROVA	{"email": "nesterova.g.1983@postgrespro.ru", "phone": "+70514502138"}
0005432035431	D35D3C	6817 727324	VIKTOR KOZLOV	{"phone": "+70100650097"}
0005432035432	D35D3C	5215 803828	YULIYA MAKAROVA	{"email": "makarova.y1971@postgrespro.ru", "phone": "+70628269795"}
0005432035433	11E053	3186 837926	ELENA NIKOLAEVA	{"email": "elena_nikolaeva121981@postgrespro.ru", "phone": "+70055822069"}
0005432035434	1D2BCA	4184 031885	FEDOR MIKHAYLOV	{"phone": "+70517003181"}
0005432035435	A4305C	3060 573979	ELENA SIDOROVA	{"email": "sidorova-elena1973@postgrespro.ru", "phone": "+70416934214"}
0005432035436	A4305C	2613 212751	VYACHESLAV SCHERBAKOV	{"email": "vyacheslavscherbakov-03091969@postgrespro.ru", "phone": "+70591088190"}
0005432035437	30A93A	6126 616526	DMITRIY POPOV	{"email": "dmitriy.popov_1975@postgrespro.ru", "phone": "+70310543237"}
0005432035438	30A93A	7220 321073	VALENTINA ALEKSEEVA	{"phone": "+70053149900"}
0005432035439	8FE008	4786 764355	NATALYA ILINA	{"phone": "+70001839565"}
0005432035440	B78E94	4305 766467	RAFAIL KUZMIN	{"email": "kuzmin.r_31051982@postgrespro.ru", "phone": "+70502370068"}
0005432035441	B7493E	1711 316727	VYACHESLAV IVANOV	{"phone": "+70062120682"}
0005432035442	9B1AFA	5031 852930	LEYLA MIRONOVA	{"phone": "+70168885636"}
0005432035443	D1A03D	5110 882420	ANASTASIYA MAKAROVA	{"phone": "+70653687648"}
0005432035444	99F027	9719 125733	NINA KOROLEVA	{"phone": "+70804731730"}
0005432035445	99F027	2270 956989	ANDREY DAVYDOV	{"phone": "+70560625582"}
0005432035446	EE9DA2	6584 522239	ANASTASIYA VOLKOVA	{"email": "volkova-a_1978@postgrespro.ru", "phone": "+70579160586"}
0005432035447	EE9DA2	2418 081367	YULIYA NIKITINA	{"phone": "+70700559801"}
0005432035448	BACBCD	2240 469492	DANIIL PAVLOV	{"phone": "+70693095643"}
0005432035449	BACBCD	1749 141670	KSENIYA BELOVA	{"email": "belova-kseniya_101968@postgrespro.ru", "phone": "+70774253492"}
0005432035450	BACBCD	1261 552371	RAISA TITOVA	{"email": "titovaraisa.13111963@postgrespro.ru", "phone": "+70737763718"}
0005432035451	B4CE4E	3255 866273	TAMARA PETROVA	{"email": "petrova.t.13091962@postgrespro.ru", "phone": "+70690471165"}
0005432035452	9E14A5	5495 989659	ANDREY KOZLOV	{"email": "kozlov.a-04111965@postgrespro.ru", "phone": "+70863269035"}
0005432035453	9E14A5	2898 536154	LYUBOV GORBUNOVA	{"phone": "+70346872979"}
0005432035454	1EF59E	7843 450358	ALEKSEY KUZNECOV	{"phone": "+70124957993"}
0005432035455	A85D2B	4028 289865	RAFIK KUZNECOV	{"email": "kuznecov.rafik.20021967@postgrespro.ru", "phone": "+70550491641"}
0005432035456	872E61	4799 947115	ANDREY SEMENOV	{"phone": "+70021241146"}
0005432035457	CB898D	1089 646022	RENAT BARANOV	{"phone": "+70700129028"}
0005432035458	FB39A1	2652 577099	VIKTOR PAVLOV	{"email": "v_pavlov.1970@postgrespro.ru", "phone": "+70572043602"}
0005432035459	22D04D	1071 737333	ANATOLIY BARANOV	{"phone": "+70231011122"}
0005432035460	6F0698	1369 572462	VERA BELYAEVA	{"phone": "+70714600505"}
0005432035461	1CFB41	7193 803776	DMITRIY BARANOV	{"phone": "+70256407862"}
0005432035462	06A475	2734 429371	ELENA BELOVA	{"email": "belova-e081965@postgrespro.ru", "phone": "+70300230146"}
0005432035463	06A475	1065 725147	ALEKSANDR PETROV	{"email": "petrova.121975@postgrespro.ru", "phone": "+70001174585"}
0005432035464	D01A9E	6832 893249	LYUBOV SERGEEVA	{"email": "sergeeva-l-111978@postgrespro.ru", "phone": "+70616642160"}
0005432035465	D42AA9	5299 184429	OKSANA SEMENOVA	{"email": "oksana_semenova.031992@postgrespro.ru", "phone": "+70453507769"}
0005432035466	2F0BD2	8814 837212	OLGA IVANOVA	{"phone": "+70745485557"}
0005432035467	2F0BD2	2523 599578	ALEKSANDR NAZAROV	{"phone": "+70252561269"}
0005432035468	9BA4E4	7936 858012	ANDREY VOROBEV	{"phone": "+70390927410"}
0005432035469	25B44B	4770 615849	ANDREY KUZNECOV	{"email": "andrey.kuznecov-1967@postgrespro.ru", "phone": "+70733325784"}
0005432035470	25B44B	0176 947191	VLADIMIR YAKOVLEV	{"email": "yakovlev.v1974@postgrespro.ru", "phone": "+70706166890"}
0005432035471	FAAE27	2653 690515	VLADISLAV FILIPPOV	{"phone": "+70583417091"}
0005432035472	26682B	4570 347055	VIKTOR NIKOLAEV	{"phone": "+70739377601"}
0005432035473	9E50D5	1680 787883	POLINA ZHURAVLEVA	{"email": "zhuravleva_p.071981@postgrespro.ru", "phone": "+70553954246"}
0005432035474	A30EBD	4030 546871	ALEKSEY PETROV	{"phone": "+70796956144"}
0005432035475	593A7A	5531 366971	VYACHESLAV OSIPOV	{"phone": "+70133619661"}
0005432035476	1F555D	3383 576281	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-mikhail_1960@postgrespro.ru", "phone": "+70938006716"}
0005432035477	1F555D	5913 397794	DMITRIY BELOV	{"phone": "+70030225644"}
0005432035478	A015C5	4771 297474	VIKTOR MARTYNOV	{"phone": "+70700599284"}
0005432035479	DCBA29	9306 130396	SERGEY SMIRNOV	{"email": "smirnovsergey.1974@postgrespro.ru", "phone": "+70739071319"}
0005432035480	DCBA29	1152 634297	VALENTINA NOVIKOVA	{"phone": "+70612546863"}
0005432035481	7F7BDE	5923 171207	ELENA SMIRNOVA	{"phone": "+70496313521"}
0005432035482	7F7BDE	7890 269206	ANTONIDA KUZMINA	{"phone": "+70361494365"}
0005432035483	7F7BDE	8243 251605	ANGELINA MARTYNOVA	{"email": "martynova-angelina-081970@postgrespro.ru", "phone": "+70281899268"}
0005432035484	E984E8	0968 894404	ELENA IVANOVA	{"phone": "+70403797023"}
0005432035485	E984E8	0998 885312	DMITRIY ZAYCEV	{"phone": "+70850554353"}
0005432035486	D3F24C	9376 224194	OLESYA GORBUNOVA	{"phone": "+70680498549"}
0005432035487	D3F24C	7721 290306	YULIYA GUSEVA	{"phone": "+70197835441"}
0005432035488	AB7719	7621 562505	ALEKSEY MOROZOV	{"email": "morozovaleksey.121970@postgrespro.ru", "phone": "+70465659267"}
0005432035489	33122B	6337 589603	TATYANA FILATOVA	{"email": "tatyanafilatova.1981@postgrespro.ru", "phone": "+70393342866"}
0005432035490	E33D9E	1391 699830	SERGEY ROMANOV	{"phone": "+70246461349"}
0005432035491	E33D9E	3680 769475	ALEKSANDR DAVYDOV	{"phone": "+70649743120"}
0005432035492	CAE95B	2276 811472	IVAN YAKOVLEV	{"email": "i.yakovlev25091973@postgrespro.ru", "phone": "+70739194104"}
0005432035493	1547E7	8980 225253	SERGEY ZAYCEV	{"email": "zaycev.sergey1962@postgrespro.ru", "phone": "+70458512789"}
0005432035494	7646E6	2481 358008	SVETLANA NIKIFOROVA	{"email": "nikiforova-s.1972@postgrespro.ru", "phone": "+70487100536"}
0005432035495	948BE9	6111 890083	TATYANA ANDREEVA	{"email": "andreeva_t-1974@postgrespro.ru", "phone": "+70994227899"}
0005432035496	697DB0	3406 733394	GALINA FEDOROVA	{"email": "galina_fedorova-04041971@postgrespro.ru", "phone": "+70481001186"}
0005432035497	697DB0	5743 987886	ALEKSEY MEDVEDEV	{"email": "medvedevaleksey_1974@postgrespro.ru", "phone": "+70377067811"}
0005432035498	69A3A5	5529 695841	ILDAR NAZAROV	{"email": "i.nazarov061972@postgrespro.ru", "phone": "+70355310785"}
0005432035499	9D2CDB	7495 224413	ALEKSANDR SEMENOV	{"phone": "+70625550460"}
0005432035500	DD239D	9547 562249	YULIYA PETROVA	{"phone": "+70101052638"}
0005432035501	E45FEE	0798 420377	VALENTINA FILATOVA	{"phone": "+70777845986"}
0005432035502	3448ED	7853 448944	NIKITA GRIGOREV	{"phone": "+70698341776"}
0005432035503	32573D	5001 233840	OLGA GUSEVA	{"email": "guseva-olga111971@postgrespro.ru", "phone": "+70279484043"}
0005432035504	32573D	5625 744994	OLGA MATVEEVA	{"phone": "+70801178917"}
0005432035505	B2CB4E	9075 587581	MARIYA MAKAROVA	{"email": "makarova-m1969@postgrespro.ru", "phone": "+70211410475"}
0005432035506	3D70F1	6482 096770	NIKOLAY BARANOV	{"email": "nikolay-baranov-1965@postgrespro.ru", "phone": "+70357671659"}
0005432035507	4CBF40	0690 447125	ZHANNA LUKYANOVA	{"phone": "+70649219775"}
0005432035508	4CBF40	8631 677303	ANDREY ORLOV	{"email": "a.orlov.1973@postgrespro.ru", "phone": "+70133904156"}
0005432035509	565C6A	0881 593832	GENNADIY NAZAROV	{"phone": "+70673588138"}
0005432035510	565C6A	5918 899596	VLADIMIR BELOV	{"email": "vladimir_belov.111977@postgrespro.ru", "phone": "+70508360389"}
0005432035511	4D5C6D	1926 410210	PAVEL ORLOV	{"phone": "+70793412784"}
0005432035512	4D5C6D	2922 282201	ALEKSEY SMIRNOV	{"phone": "+70342596951"}
0005432035513	F062EB	9106 376408	EVGENIY FEDOROV	{"phone": "+70631886042"}
0005432035514	546814	2249 618141	IVAN PAVLOV	{"email": "ipavlov.05081964@postgrespro.ru", "phone": "+70056185627"}
0005432035515	546814	3697 647240	OKSANA ERMAKOVA	{"phone": "+70950855564"}
0005432035516	1A51CB	6750 965840	ALEKSANDR STEPANOV	{"phone": "+70242276636"}
0005432035517	BB7636	1790 506197	SVETLANA MIKHAYLOVA	{"phone": "+70520216079"}
0005432035518	9B35F3	8301 700998	VYACHESLAV FOMIN	{"email": "vfomin101973@postgrespro.ru", "phone": "+70076759224"}
0005432035519	82E391	6409 397089	IVAN KUZNECOV	{"email": "kuznecov_i-03011964@postgrespro.ru", "phone": "+70757043704"}
0005432035520	6E7F8C	9287 877594	YURIY GAVRILOV	{"email": "gavrilov_yuriy_17101961@postgrespro.ru", "phone": "+70045469154"}
0005432035521	6E7F8C	0530 750554	DARYA SAVELEVA	{"phone": "+70100123537"}
0005432035522	0BA940	0267 488093	SVYATOSLAV ALEKSANDROV	{"phone": "+70625045828"}
0005432035523	AA774B	9328 145182	NATALYA KOZLOVA	{"phone": "+70395350306"}
0005432035524	AA774B	5354 601819	MARINA SCHERBAKOVA	{"email": "marina_scherbakova011983@postgrespro.ru", "phone": "+70187424976"}
0005432035525	3A5564	3335 991412	VALERIY SERGEEV	{"email": "vsergeev_1970@postgrespro.ru", "phone": "+70197884305"}
0005432035526	3A5564	3276 758211	BORIS MIKHAYLOV	{"phone": "+70222874901"}
0005432035527	3A5564	6224 978242	TAMARA RODIONOVA	{"phone": "+70412679195"}
0005432035528	72BCE8	1116 153601	MARIYA NESTEROVA	{"phone": "+70379296415"}
0005432035529	474F5F	1062 865727	ALEKSANDR TIKHONOV	{"phone": "+70972764874"}
0005432035530	491AA1	9846 609117	VLADIMIR VOLKOV	{"phone": "+70982155701"}
0005432035531	491AA1	5472 797483	ALEKSANDR FEDOROV	{"phone": "+70682845705"}
0005432035532	82AA57	3865 017630	SERGEY ZHUKOV	{"email": "sergey.zhukov1978@postgrespro.ru", "phone": "+70918027666"}
0005432035533	C1C072	0741 153794	NATALYA RYABOVA	{"email": "natalya_ryabova121965@postgrespro.ru", "phone": "+70642557233"}
0005432035534	C4553C	0055 294948	MIKHAIL GERASIMOV	{"phone": "+70903579183"}
0005432035535	191083	9172 508277	VLADIMIR MELNIKOV	{"phone": "+70056015979"}
0005432035536	916567	1499 269341	ILDAR KRASNOV	{"email": "krasnov-i041965@postgrespro.ru", "phone": "+70827373582"}
0005432035537	0FD66A	0145 274551	OLEG GRIGOREV	{"phone": "+70801473655"}
0005432035538	A3B524	2087 176319	ARTEMIY KOROLEV	{"phone": "+70866886530"}
0005432035539	A3B524	6986 533749	ALEKSANDR ZHUKOV	{"email": "zhukova_111974@postgrespro.ru", "phone": "+70932752740"}
0005432035540	4D55B0	2498 881014	NIKOLAY SCHERBAKOV	{"email": "scherbakovn-06011961@postgrespro.ru", "phone": "+70172575953"}
0005432035541	B91BFB	7658 061574	ALEKSANDRA MIRONOVA	{"phone": "+70362011684"}
0005432035542	A5224E	0187 018726	TATYANA ZHURAVLEVA	{"phone": "+70046154411"}
0005432035543	097591	8182 767405	IGOR KARPOV	{"phone": "+70797398452"}
0005432035544	72FFE2	7187 186183	ALEKSANDR SIDOROV	{"email": "sidorova15101956@postgrespro.ru", "phone": "+70423541311"}
0005432035545	13A328	9365 158177	ELENA SMIRNOVA	{"email": "e-smirnova_021977@postgrespro.ru", "phone": "+70640004382"}
0005432035546	AD1BC9	6635 747916	ALEKSANDR KISELEV	{"phone": "+70963288134"}
0005432035547	A2B609	7532 707840	SERGEY PAVLOV	{"email": "s-pavlov_1967@postgrespro.ru", "phone": "+70548274063"}
0005432035548	2D0597	6270 059316	MARIANNA KUZMINA	{"email": "kuzminamarianna.1983@postgrespro.ru", "phone": "+70847878776"}
0005432035549	2D0597	1836 666701	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr.1971@postgrespro.ru", "phone": "+70517058069"}
0005432035550	2D0597	4982 088547	ALEKSANDR DENISOV	{"email": "aleksandr_denisov-121971@postgrespro.ru", "phone": "+70335498763"}
0005432035551	E97B82	0810 195083	EDGAR DAVYDOV	{"phone": "+70015145868"}
0005432035552	E97B82	8619 156045	MARIYA ISAEVA	{"email": "m_isaeva1978@postgrespro.ru", "phone": "+70608109105"}
0005432035553	1A4121	7296 314849	DARYA MATVEEVA	{"phone": "+70775671795"}
0005432035554	1021B5	5627 335153	EVGENIYA YAKOVLEVA	{"email": "yakovleva.e1968@postgrespro.ru", "phone": "+70267338076"}
0005432035555	1021B5	8174 340939	ANTON EGOROV	{"phone": "+70179534479"}
0005432035556	CD7341	7612 423933	SERGEY DENISOV	{"email": "denisov.s.02121966@postgrespro.ru", "phone": "+70339589716"}
0005432035557	2B2F38	3759 658840	MAKSIM DAVYDOV	{"email": "m.davydov_061969@postgrespro.ru", "phone": "+70062415395"}
0005432035558	C6BE3F	9281 487446	MARINA IVANOVA	{"email": "ivanova.m-041976@postgrespro.ru", "phone": "+70726716451"}
0005432035559	B060BB	5043 174437	NIKOLAY VASILEV	{"email": "vasilev.n-1964@postgrespro.ru", "phone": "+70760498780"}
0005432035560	B060BB	0104 194631	VERA NAZAROVA	{"email": "nazarovavera-1967@postgrespro.ru", "phone": "+70092260858"}
0005432035561	B060BB	4160 916908	ALEKSANDR MIRONOV	{"phone": "+70417130898"}
0005432035562	E23572	5538 943904	OLGA SMIRNOVA	{"phone": "+70511814245"}
0005432035563	E23572	2172 255417	DANILA VOROBEV	{"email": "vorobevdanila-071972@postgrespro.ru", "phone": "+70008677898"}
0005432035564	F89FDE	2301 911636	GENNADIY DAVYDOV	{"phone": "+70156383918"}
0005432035565	F89FDE	6294 379339	ELENA DENISOVA	{"email": "denisova_e_19081988@postgrespro.ru", "phone": "+70145963167"}
0005432035566	F89FDE	7778 066588	POLINA NIKIFOROVA	{"phone": "+70164752799"}
0005432035567	CA14BC	5983 584698	YULIYA KUDRYASHOVA	{"email": "y.kudryashova1974@postgrespro.ru", "phone": "+70487968990"}
0005432035568	CA14BC	7456 482587	VLADIMIR FEDOTOV	{"email": "fedotov_v_19011969@postgrespro.ru", "phone": "+70302700051"}
0005432035569	CA14BC	9003 664933	ALEKSANDR RODIONOV	{"email": "rodionov_a06051973@postgrespro.ru", "phone": "+70064002944"}
0005432035570	14630E	7685 616797	VIKTOR SOROKIN	{"phone": "+70878252430"}
0005432035571	248196	6828 599986	GEORGIY IVANOV	{"email": "g-ivanov26021974@postgrespro.ru", "phone": "+70666580894"}
0005432035572	CD9E0E	9042 555313	IRINA NAUMOVA	{"phone": "+70714864379"}
0005432035573	CD9E0E	4299 409919	KRISTINA KOROLEVA	{"phone": "+70440928826"}
0005432035574	CD9E0E	5657 357257	IRINA VASILEVA	{"email": "vasileva.i_1973@postgrespro.ru", "phone": "+70026332995"}
0005432035575	4BA243	4658 231928	VLADIMIR MAKSIMOV	{"email": "vladimir.maksimov_21071975@postgrespro.ru", "phone": "+70185840829"}
0005432035576	FBA068	6329 624580	TATYANA IVANOVA	{"phone": "+70059600663"}
0005432035577	EB35B7	3444 780519	YURIY NAZAROV	{"phone": "+70012309830"}
0005432035578	92F253	1770 965194	VERA POPOVA	{"phone": "+70871071670"}
0005432035579	727A30	8284 894136	VIKTOR GERASIMOV	{"email": "v_gerasimov.02111965@postgrespro.ru", "phone": "+70571487655"}
0005432035580	42DD24	8346 674874	EDUARD ANDREEV	{"email": "e-andreev_031972@postgrespro.ru", "phone": "+70476396203"}
0005432035581	E4ECEF	8079 491316	SERGEY POPOV	{"phone": "+70116954901"}
0005432035582	D0A342	5081 555545	ARTEM DENISOV	{"phone": "+70827424866"}
0005432035583	D0A342	0886 962454	FEDOR MEDVEDEV	{"email": "medvedev-f.1980@postgrespro.ru", "phone": "+70441163081"}
0005432035584	631177	4705 912428	ELENA FILATOVA	{"email": "filatova-elena_071973@postgrespro.ru", "phone": "+70174089846"}
0005432035585	631177	7576 923468	VIKTOR STEPANOV	{"email": "stepanovv.051977@postgrespro.ru", "phone": "+70839409652"}
0005432035586	7B5DE8	1594 202117	NIKITA NIKOLAEV	{"phone": "+70733873304"}
0005432035587	48C167	0870 015815	RAISA NAZAROVA	{"email": "raisanazarova.1965@postgrespro.ru", "phone": "+70338011003"}
0005432035588	4F3378	7031 827885	IRINA ZAKHAROVA	{"email": "izakharova_1977@postgrespro.ru", "phone": "+70216931835"}
0005432035589	D3783D	4158 481865	DMITRIY FEDOROV	{"email": "fedorov.d12071968@postgrespro.ru", "phone": "+70399601971"}
0005432035590	C55631	8874 362515	DMITRIY SCHERBAKOV	{"email": "dmitriy.scherbakov071981@postgrespro.ru", "phone": "+70453277988"}
0005432035591	A20EEA	9556 808053	IVAN MELNIKOV	{"email": "melnikov.i_031973@postgrespro.ru", "phone": "+70838441046"}
0005432035592	F19781	5913 023565	YULIYA ALEKSANDROVA	{"phone": "+70138303039"}
0005432035593	F19781	7578 961245	VLADIMIR SMIRNOV	{"phone": "+70085806710"}
0005432035594	71A9FF	2156 471624	IVAN KAZAKOV	{"email": "kazakov_ivan_09051972@postgrespro.ru", "phone": "+70239211029"}
0005432035595	786C9D	8493 857142	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov_14031979@postgrespro.ru", "phone": "+70177662064"}
0005432035596	D6CD26	6239 603163	VIKTORIYA BORISOVA	{"phone": "+70384475562"}
0005432035597	D6CD26	6949 367679	PETR KOZLOV	{"phone": "+70288594705"}
0005432035598	D6CD26	0860 356660	IGOR STEPANOV	{"email": "stepanovigor-24011981@postgrespro.ru", "phone": "+70501336350"}
0005432035599	497FFF	9023 415108	LIDIYA PAVLOVA	{"email": "pavlova.lidiya29071974@postgrespro.ru", "phone": "+70837893417"}
0005432035600	F45EBE	2835 018378	VALENTINA NAUMOVA	{"phone": "+70932430211"}
0005432035601	8AC3C6	1824 150204	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov.091973@postgrespro.ru", "phone": "+70763854028"}
0005432035602	2E91E6	8094 971869	VLADISLAV ALEKSANDROV	{"phone": "+70824585104"}
0005432035603	403ABD	2653 283175	IRINA MEDVEDEVA	{"phone": "+70806426096"}
0005432035604	AA1ED3	4430 955491	MAKSIM SOROKIN	{"phone": "+70558548868"}
0005432035605	BD9770	6923 416513	RAMIL GRIGOREV	{"email": "grigorev-ramil1971@postgrespro.ru", "phone": "+70608706152"}
0005432035606	BD9770	6549 550037	VLADISLAV MAKSIMOV	{"email": "v.maksimov-1959@postgrespro.ru", "phone": "+70047366536"}
0005432035607	BD9770	3567 814680	ANNA KUZNECOVA	{"email": "kuznecova-a.26031968@postgrespro.ru", "phone": "+70972297662"}
0005432035608	1DEB26	6222 890973	ALEKSEY PETROV	{"phone": "+70237313856"}
0005432035609	93D776	5363 428970	ALENA BARANOVA	{"phone": "+70324566735"}
0005432035610	6AF1E0	1284 342059	OLGA LEBEDEVA	{"email": "lebedeva.olga.1984@postgrespro.ru", "phone": "+70536589607"}
0005432035611	AB6A34	8887 417171	SERGEY SOKOLOV	{"email": "sokolov.sergey_1980@postgrespro.ru", "phone": "+70147340521"}
0005432035612	2278D2	4406 202806	VLADIMIR RODIONOV	{"email": "rodionov_vladimir-16081969@postgrespro.ru", "phone": "+70599189814"}
0005432035613	7128C0	4370 166276	VLADIMIR MARTYNOV	{"email": "martynovvladimir_061975@postgrespro.ru", "phone": "+70276755071"}
0005432035614	1E4899	6393 948857	NADEZHDA KUZMINA	{"email": "nadezhdakuzmina_13021976@postgrespro.ru", "phone": "+70500356935"}
0005432035615	1E4899	4692 210085	VLADIMIR KRASNOV	{"email": "v.krasnov_14071971@postgrespro.ru", "phone": "+70441847360"}
0005432035616	1E4899	6938 819271	VALERIY NIKOLAEV	{"email": "valeriy.nikolaev_01071973@postgrespro.ru", "phone": "+70580109017"}
0005432035617	1E4899	0397 851430	ANASTASIYA PAVLOVA	{"email": "pavlova_anastasiya09011967@postgrespro.ru", "phone": "+70388626921"}
0005432035618	BBE605	1612 333531	OLEG MEDVEDEV	{"email": "o.medvedev-1974@postgrespro.ru", "phone": "+70639108948"}
0005432035619	9170DC	7604 243927	NADEZHDA PETROVA	{"email": "npetrova.021975@postgrespro.ru", "phone": "+70208239122"}
0005432035620	9170DC	5379 867874	RINAT FROLOV	{"phone": "+70706981431"}
0005432035621	F20E90	6888 203296	IGOR CHERNOV	{"email": "chernov-igor_021973@postgrespro.ru", "phone": "+70372202666"}
0005432035622	F20E90	7878 491235	DMITRIY GAVRILOV	{"email": "gavrilov-d-1970@postgrespro.ru", "phone": "+70623051695"}
0005432035623	6A8798	1514 879495	SERGEY KUZNECOV	{"email": "kuznecov.sergey-1971@postgrespro.ru", "phone": "+70895400353"}
0005432035624	F9CD85	8755 680082	OLEG SERGEEV	{"email": "sergeev-oleg-09011970@postgrespro.ru", "phone": "+70899561170"}
0005432035625	F9CD85	2008 035731	ALEKSANDR BORISOV	{"phone": "+70888918169"}
0005432035626	FBC16C	4440 126566	VALENTINA DAVYDOVA	{"phone": "+70481453299"}
0005432035627	24AA9B	4349 840159	ELENA BORISOVA	{"phone": "+70881022805"}
0005432035628	24AA9B	0396 216653	VALENTINA NAUMOVA	{"email": "naumova_valentina.29051975@postgrespro.ru", "phone": "+70016224456"}
0005432035629	3F0969	9054 677201	NIKOLAY PETROV	{"email": "petrov-nikolay.011979@postgrespro.ru", "phone": "+70246630791"}
0005432035630	3F0969	2020 741193	ANDREY ROMANOV	{"email": "romanova-22021974@postgrespro.ru", "phone": "+70705715867"}
0005432035631	2E859A	1007 380130	MATVEY DENISOV	{"phone": "+70473060320"}
0005432035632	7DE65B	0654 444602	TATYANA TARASOVA	{"email": "tatyana_tarasova-18011964@postgrespro.ru", "phone": "+70864945915"}
0005432035633	7DE65B	4649 317730	LIDIYA KULIKOVA	{"phone": "+70889055200"}
0005432035634	08244D	3812 768399	VLADIMIR KARPOV	{"email": "karpov.v19121969@postgrespro.ru", "phone": "+70742962186"}
0005432035635	C1EAA3	1224 322603	SERGEY MARTYNOV	{"phone": "+70233546369"}
0005432035636	C1EAA3	9388 718201	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov.04111971@postgrespro.ru", "phone": "+70957603513"}
0005432035637	BD51C6	8329 667449	VLADIMIR VOROBEV	{"email": "v.vorobev_02051973@postgrespro.ru", "phone": "+70947074809"}
0005432035638	7C4B13	2481 883488	KSENIYA MIRONOVA	{"email": "mironova-k_1975@postgrespro.ru", "phone": "+70941348319"}
0005432035639	E6FC14	1085 642477	IVAN OSIPOV	{"email": "osipov.ivan091971@postgrespro.ru", "phone": "+70803549580"}
0005432035640	E6FC14	3952 372690	NINA TARASOVA	{"email": "n.tarasova_1969@postgrespro.ru", "phone": "+70517024321"}
0005432035641	8AC7D0	5987 025599	SEMEN KUZNECOV	{"email": "s_kuznecov_1976@postgrespro.ru", "phone": "+70001697443"}
0005432035642	C1977C	9444 149255	VLADISLAV SERGEEV	{"phone": "+70685639927"}
0005432035643	C1977C	9092 533451	OLGA ZAKHAROVA	{"phone": "+70575174210"}
0005432035644	C1977C	7858 583042	ALEKSANDR AFANASEV	{"phone": "+70493892988"}
0005432035645	2282A6	9727 624761	VERA TIKHONOVA	{"phone": "+70689790325"}
0005432035646	95B523	6444 073435	DARYA KOVALEVA	{"phone": "+70168342465"}
0005432035647	FEA0EA	4715 510773	SVETLANA FADEEVA	{"email": "s.fadeeva-1981@postgrespro.ru", "phone": "+70722044783"}
0005432035648	28866E	1997 542480	ANASTASIYA KUZNECOVA	{"email": "akuznecova_1971@postgrespro.ru", "phone": "+70222357692"}
0005432035649	28866E	0521 486383	ILYA VASILEV	{"phone": "+70019195862"}
0005432035650	28866E	9683 471324	OLGA SERGEEVA	{"email": "olga.sergeeva-04071973@postgrespro.ru", "phone": "+70373036096"}
0005432035651	3879DC	5442 659469	VLADIMIR OSIPOV	{"email": "vladimir.osipov.071982@postgrespro.ru", "phone": "+70724632563"}
0005432035652	01805B	4546 794722	ALEKSANDRA TIMOFEEVA	{"phone": "+70826356129"}
0005432035653	8354C2	3257 659316	GLEB NOVIKOV	{"phone": "+70259914039"}
0005432035654	09A26F	0396 212750	NADEZHDA SOROKINA	{"phone": "+70050245159"}
0005432035655	09A26F	0090 037227	NINA LEBEDEVA	{"email": "lebedevan1968@postgrespro.ru", "phone": "+70939289704"}
0005432035656	E43A4C	6429 973931	STANISLAV DENISOV	{"phone": "+70598844359"}
0005432035657	422ADF	6266 683020	TAMARA SOLOVEVA	{"phone": "+70386015131"}
0005432035658	422ADF	0830 872722	YURIY KULIKOV	{"phone": "+70093786785"}
0005432035659	CD63B8	1936 852531	MATVEY KUZNECOV	{"phone": "+70823943338"}
0005432035660	CD63B8	5589 434949	ARINA KUZMINA	{"phone": "+70821491471"}
0005432035661	4D2E5E	9564 651773	TATYANA ZAYCEVA	{"phone": "+70560656584"}
0005432035662	4D2E5E	7445 037764	NIKITA PETROV	{"email": "n-petrov.011969@postgrespro.ru", "phone": "+70283992112"}
0005432035663	4D2E5E	5532 749425	RUSTAM VOLKOV	{"email": "volkov-r1958@postgrespro.ru", "phone": "+70492656454"}
0005432035664	571327	9461 262800	NATALYA KUZNECOVA	{"email": "kuznecova.n-12011968@postgrespro.ru", "phone": "+70163574258"}
0005432035665	571327	3121 360351	ALFIYA YUDINA	{"email": "yudina_a_1962@postgrespro.ru", "phone": "+70805465060"}
0005432035666	EDA038	9952 206615	OLGA FEDOROVA	{"email": "fedorova-olga25061960@postgrespro.ru", "phone": "+70269998070"}
0005432035667	BDB581	5387 835636	OLGA IVANOVA	{"phone": "+70526766248"}
0005432035668	BDB581	5211 817392	YULIYA ROMANOVA	{"email": "romanova-y_1975@postgrespro.ru", "phone": "+70176969335"}
0005432035669	BDB581	2114 672538	VITALIY TIKHONOV	{"phone": "+70687099648"}
0005432035670	A0F631	1315 893434	ELENA YUDINA	{"phone": "+70547688459"}
0005432035671	7B8DE8	7030 971790	OLEG PETROV	{"email": "petrov-o_06031976@postgrespro.ru", "phone": "+70808644634"}
0005432035672	7B8DE8	5709 326829	ELENA MIKHAYLOVA	{"email": "elena-mikhaylova-021973@postgrespro.ru", "phone": "+70289670264"}
0005432035673	EE5921	1229 136653	VALERIY MEDVEDEV	{"email": "valeriy-medvedev_28031967@postgrespro.ru", "phone": "+70480750011"}
0005432035674	A6A8D2	8474 843509	VERA YAKOVLEVA	{"phone": "+70328621202"}
0005432035675	A6A8D2	1054 189777	ANDREY ANDREEV	{"phone": "+70032105796"}
0005432035676	68AE12	9563 064328	ARTEM KOROLEV	{"email": "a.korolev061963@postgrespro.ru", "phone": "+70170095201"}
0005432035677	68AE12	2051 759890	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov_12121972@postgrespro.ru", "phone": "+70060930844"}
0005432035678	170E1E	4708 414591	NADEZHDA FILIPPOVA	{"email": "nadezhda_filippova-081980@postgrespro.ru", "phone": "+70456020336"}
0005432035679	170E1E	8898 883679	ARTEM EGOROV	{"email": "artemegorov20021967@postgrespro.ru", "phone": "+70673041825"}
0005432035680	92B9E9	0759 023469	ALENA OSIPOVA	{"phone": "+70556101128"}
0005432035681	F1D0A1	7342 549776	YURIY SOKOLOV	{"phone": "+70752000116"}
0005432035682	380805	8158 517352	MARIYA KUZNECOVA	{"email": "kuznecova.m.1972@postgrespro.ru", "phone": "+70464511892"}
0005432035683	460CB7	9363 422592	VLADIMIR BELOV	{"phone": "+70925359635"}
0005432035684	8C870A	2978 287428	ARMEN SAVELEV	{"email": "armen-savelev-01081966@postgrespro.ru", "phone": "+70277770146"}
0005432035685	4EC033	2267 141350	NINA NOVIKOVA	{"phone": "+70335690418"}
0005432035686	95B056	6485 025150	DMITRIY SOKOLOV	{"phone": "+70187610219"}
0005432035687	3779D4	3469 727246	KONSTANTIN MIKHAYLOV	{"phone": "+70914045085"}
0005432035688	8D47A5	1020 380688	SERGEY ZAYCEV	{"phone": "+70152167115"}
0005432035689	259C0F	4547 567412	LYUBOV ROMANOVA	{"phone": "+70915474203"}
0005432035690	A0DB95	9574 813996	VLADIMIR NOVIKOV	{"phone": "+70466979575"}
0005432035691	A0DB95	5358 142716	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov-111971@postgrespro.ru", "phone": "+70041242652"}
0005432035692	ED9974	2186 963323	ALEKSEY PAVLOV	{"email": "a.pavlov101976@postgrespro.ru", "phone": "+70089531418"}
0005432035693	0BB7FE	2641 533697	VALERIY SHEVCHENKO	{"phone": "+70994082453"}
0005432035694	211B18	9887 639085	MARINA SMIRNOVA	{"email": "smirnova_marina.1967@postgrespro.ru", "phone": "+70126108938"}
0005432035695	0B1A4A	6847 043039	NINA YAKOVLEVA	{"phone": "+70363175806"}
0005432035696	0B1A4A	0021 801525	TAISIYA CHERNOVA	{"email": "chernova_t.14091966@postgrespro.ru", "phone": "+70648579923"}
0005432035697	BD0DE6	3367 100999	NADEZHDA SIDOROVA	{"email": "n-sidorova_061970@postgrespro.ru", "phone": "+70984551859"}
0005432035698	BD0DE6	4548 509406	LILIYA SERGEEVA	{"phone": "+70301260336"}
0005432035699	68EBF8	8988 702891	ALEKSANDR MELNIKOV	{"phone": "+70152372388"}
0005432035700	877202	4283 293036	ALEKSANDRA MAKAROVA	{"email": "makarovaaleksandra.011969@postgrespro.ru", "phone": "+70784975747"}
0005432035701	877202	3791 585796	ANNA MASLOVA	{"email": "a-maslova-1972@postgrespro.ru", "phone": "+70969113567"}
0005432035702	4EE7C0	8635 800724	GALINA KISELEVA	{"email": "kiselevag_031978@postgrespro.ru", "phone": "+70374165450"}
0005432035703	C776A8	2165 815827	GALINA GERASIMOVA	{"phone": "+70435794221"}
0005432035704	577ADE	1129 871774	LYUBOV DAVYDOVA	{"email": "davydova.lyubov_04061962@postgrespro.ru", "phone": "+70508252267"}
0005432035705	8B26F1	9193 791226	IVAN KRASNOV	{"phone": "+70487982965"}
0005432035706	5E5FA7	2499 119452	IRINA EFIMOVA	{"email": "i-efimova24071974@postgrespro.ru", "phone": "+70715673545"}
0005432035707	5E5FA7	4035 955778	ELENA ALEKSEEVA	{"email": "e.alekseeva05071973@postgrespro.ru", "phone": "+70245217970"}
0005432035708	23B054	3619 572459	RUMIYA KOZLOVA	{"phone": "+70327378579"}
0005432035709	87F53E	5209 211890	ILMIRA NAUMOVA	{"email": "ilmira.naumova031965@postgrespro.ru", "phone": "+70979455075"}
0005432035710	87F53E	0805 806758	DANILA SCHERBAKOV	{"phone": "+70013277535"}
0005432035711	593441	4533 673597	IRINA MAKSIMOVA	{"phone": "+70521582937"}
0005432035712	593441	8650 218321	TAMARA AFANASEVA	{"email": "afanasevatamara-1971@postgrespro.ru", "phone": "+70806775983"}
0005432035713	8C24E6	0263 278450	ELENA MAKAROVA	{"email": "elena.makarova1980@postgrespro.ru", "phone": "+70875596412"}
0005432035714	D7663B	6319 507851	SOFIYA OSIPOVA	{"phone": "+70350579633"}
0005432035715	D7663B	5020 416947	SERGEY FEDOROV	{"email": "sergeyfedorov.09021958@postgrespro.ru", "phone": "+70522915121"}
0005432035716	D7663B	8435 964902	ANATOLIY SOKOLOV	{"phone": "+70908747452"}
0005432035717	01A684	7778 497838	STANISLAV POPOV	{"email": "popov.stanislav-01121970@postgrespro.ru", "phone": "+70888935658"}
0005432035718	FCB629	9341 620636	BORIS KUZMIN	{"email": "kuzmin-boris011973@postgrespro.ru", "phone": "+70771030302"}
0005432035719	4C139D	6091 214185	VIKTOR VOLKOV	{"email": "volkov.v.081969@postgrespro.ru", "phone": "+70433939609"}
0005432035720	7896EC	2269 862032	ELENA SOKOLOVA	{"phone": "+70358436936"}
0005432035721	6131EB	6404 873832	ARTEM ZHURAVLEV	{"email": "azhuravlev-121967@postgrespro.ru", "phone": "+70157706827"}
0005432035722	6131EB	3524 208325	EVGENIY NAZAROV	{"phone": "+70607908944"}
0005432035723	8E0C61	4367 379999	NINA MARTYNOVA	{"phone": "+70250030363"}
0005432035724	8174BB	9809 032350	ANASTASIYA RYABOVA	{"phone": "+70518356516"}
0005432035725	E6CFA2	7445 564651	ANDREY KUZNECOV	{"email": "a.kuznecov.21011970@postgrespro.ru", "phone": "+70211720724"}
0005432035726	332192	5546 425360	NADEZHDA BELOVA	{"email": "nbelova-25071967@postgrespro.ru", "phone": "+70396496482"}
0005432035727	332192	1313 090920	VIKTORIYA KUZNECOVA	{"email": "viktoriyakuznecova01011974@postgrespro.ru", "phone": "+70344215276"}
0005432035728	660CA8	4246 128937	RAISA VOLKOVA	{"email": "volkova-raisa05041969@postgrespro.ru", "phone": "+70575923717"}
0005432035729	78753A	4595 808438	OLEG SOLOVEV	{"phone": "+70676759349"}
0005432035730	78753A	9803 676319	ILYA STEPANOV	{"phone": "+70631658113"}
0005432035731	46800E	1179 939188	ROMAN DAVYDOV	{"email": "davydov.roman23041967@postgrespro.ru", "phone": "+70976687406"}
0005432035732	46800E	9702 398887	VALERIY STEPANOV	{"phone": "+70648293160"}
0005432035733	46800E	9620 516065	MARIYA KUZMINA	{"email": "kuzmina-mariya-1974@postgrespro.ru", "phone": "+70553533796"}
0005432035734	AB145D	9122 396982	POLINA MALYSHEVA	{"phone": "+70510692731"}
0005432035735	B65C15	4795 492146	ANNA MAKSIMOVA	{"phone": "+70301502663"}
0005432035736	101A89	0580 837161	ALENA MELNIKOVA	{"phone": "+70634946482"}
0005432035737	83BB38	3110 843273	VLADIMIR VOROBEV	{"email": "vladimirvorobev.30121976@postgrespro.ru", "phone": "+70933160119"}
0005432035738	2E42E3	8904 938424	SVETLANA ZAKHAROVA	{"email": "s-zakharova-101968@postgrespro.ru", "phone": "+70838735529"}
0005432035739	D4DD88	1205 060057	OLEG PAVLOV	{"email": "pavlovoleg.15071980@postgrespro.ru", "phone": "+70742667659"}
0005432035740	D4DD88	3173 377901	RIMMA KONOVALOVA	{"email": "konovalova-rimma07051970@postgrespro.ru", "phone": "+70359532018"}
0005432035741	A67B92	6176 087103	ALEKSEY NOVIKOV	{"email": "novikov.aleksey.1984@postgrespro.ru", "phone": "+70978490928"}
0005432035742	D2C7F4	5480 295014	EVGENIY MIKHAYLOV	{"email": "emikhaylov-101968@postgrespro.ru", "phone": "+70978991393"}
0005432035743	FE6582	3251 059942	SERGEY VOROBEV	{"email": "s_vorobev031967@postgrespro.ru", "phone": "+70374712628"}
0005432035744	9955B2	8551 041712	SERGEY POPOV	{"email": "spopov.06091965@postgrespro.ru", "phone": "+70851288008"}
0005432035745	9955B2	4959 062774	MAKSIM DENISOV	{"phone": "+70146798730"}
0005432035746	5EB229	3954 736263	VITALIY MOISEEV	{"phone": "+70171881696"}
0005432035747	2A5200	4116 987891	YURIY PETROV	{"email": "ypetrov-15111954@postgrespro.ru", "phone": "+70163293508"}
0005432035748	02A3DF	4686 210514	LEONID GRIGOREV	{"email": "grigorevl.111977@postgrespro.ru", "phone": "+70166806019"}
0005432035749	02A3DF	6685 343859	NATALYA FOMINA	{"email": "natalya-fomina.26041979@postgrespro.ru", "phone": "+70939811228"}
0005432035750	1754BE	7080 020827	LYUBOV ANTONOVA	{"email": "lyubovantonova.1970@postgrespro.ru", "phone": "+70168248320"}
0005432035751	F48F9B	5421 565894	VALERIY SAVELEV	{"phone": "+70590516299"}
0005432035752	F48F9B	9842 961462	VERONIKA SERGEEVA	{"phone": "+70472002016"}
0005432035753	372F7A	7602 041290	EVGENIYA NAUMOVA	{"phone": "+70865037564"}
0005432035754	CB7CBE	5199 725397	VLADISLAV MELNIKOV	{"phone": "+70187703600"}
0005432035755	CB7CBE	3591 175165	VLADIMIR KOROLEV	{"phone": "+70192447674"}
0005432035756	E63A06	2009 069165	YURIY KOROLEV	{"phone": "+70352398067"}
0005432035757	24DA51	9626 077621	VLADIMIR VOROBEV	{"phone": "+70742743649"}
0005432035758	566FDA	4782 638268	ALEKSANDR SERGEEV	{"email": "asergeev.18031972@postgrespro.ru", "phone": "+70981789707"}
0005432035759	D17462	1761 195798	DAVID YAKOVLEV	{"phone": "+70959994130"}
0005432035760	F5C8F5	4064 239870	IVAN GERASIMOV	{"phone": "+70431389912"}
0005432035761	2C72A6	1571 179782	VLADIMIR AFANASEV	{"phone": "+70347932470"}
0005432035762	2C72A6	8912 006453	GALINA SMIRNOVA	{"phone": "+70600448047"}
0005432035763	0EFCBC	8890 802485	LYUBOV AKIMOVA	{"email": "l-akimova1977@postgrespro.ru", "phone": "+70647098310"}
0005432042468	D3DE06	1829 922881	VIKTOR MAKAROV	{"phone": "+70789271133"}
0005432042469	D3DE06	8419 033151	ANATOLIY ZAYCEV	{"email": "zaycev_anatoliy-101990@postgrespro.ru", "phone": "+70820874928"}
0005432042470	44B6D9	9240 646668	YURIY OSIPOV	{"email": "yuriy_osipov_1970@postgrespro.ru", "phone": "+70773845027"}
0005432042471	49D6F0	0686 164896	ANZHELA NIKIFOROVA	{"email": "nikiforova_anzhela111980@postgrespro.ru", "phone": "+70158801690"}
0005432042472	7F111E	4995 625356	ANASTASIYA POTAPOVA	{"email": "apotapova-27011978@postgrespro.ru", "phone": "+70701949620"}
0005432042473	500E65	1860 253109	ANASTASIYA GERASIMOVA	{"email": "anastasiya.gerasimova.111975@postgrespro.ru", "phone": "+70185719607"}
0005432042474	A81E89	6439 337048	ANATOLIY NAZAROV	{"phone": "+70831091906"}
0005432042475	A81E89	0251 301994	NATALIYA SMIRNOVA	{"email": "n_smirnova.071975@postgrespro.ru", "phone": "+70155068167"}
0005432042476	0EEC13	4957 424646	DMITRIY BELOV	{"email": "d.belov_111965@postgrespro.ru", "phone": "+70707448586"}
0005432042477	5FB246	6624 661984	LYUBOV KOROLEVA	{"phone": "+70733844378"}
0005432042478	5FB246	0206 018119	ELENA GUSEVA	{"email": "e-guseva111966@postgrespro.ru", "phone": "+70555138164"}
0005432042479	239DE2	3841 352655	EKATERINA NESTEROVA	{"phone": "+70121039058"}
0005432042480	C5BEE2	9105 795617	ANATOLIY NIKOLAEV	{"phone": "+70565561048"}
0005432042481	3BBA25	8830 815224	IGOR MIRONOV	{"phone": "+70170875148"}
0005432042482	0979E5	8630 787168	LYUBOV TARASOVA	{"email": "tarasova.l-14091971@postgrespro.ru", "phone": "+70327467292"}
0005432042483	6B3DDF	2402 713942	ALEKSANDR POPOV	{"email": "popovaleksandr_23011971@postgrespro.ru", "phone": "+70348578228"}
0005432042484	6B3DDF	6286 700999	NATALYA MAKAROVA	{"phone": "+70831096017"}
0005432042485	F9FBD5	3725 895967	VALENTINA OSIPOVA	{"phone": "+70977231107"}
0005432042486	CB0D3F	6759 316875	YULIYA POTAPOVA	{"phone": "+70793174441"}
0005432042487	7AD798	9475 838604	LYUDMILA EGOROVA	{"phone": "+70184679723"}
0005432042488	065830	0422 209451	NINA NIKOLAEVA	{"email": "nina-nikolaeva04071964@postgrespro.ru", "phone": "+70075200390"}
0005432042489	065830	1240 814109	NIKOLAY NOVIKOV	{"email": "n_novikov-1960@postgrespro.ru", "phone": "+70981259385"}
0005432042490	92427D	2930 021529	ANNA VOLKOVA	{"phone": "+70975985286"}
0005432042491	2D9782	8331 740031	TAMARA MOROZOVA	{"email": "t_morozova-1976@postgrespro.ru", "phone": "+70952733593"}
0005432042492	C45D82	0144 197628	EKATERINA ROMANOVA	{"phone": "+70038486686"}
0005432042493	71AFAE	5249 261857	GRIGORIY SAVELEV	{"phone": "+70786752360"}
0005432042494	71AFAE	9959 221518	KONSTANTIN CHERNOV	{"email": "chernov_k1972@postgrespro.ru", "phone": "+70681826031"}
0005432042495	E18B9A	6740 127169	DENIS MIKHAYLOV	{"phone": "+70922305420"}
0005432042496	74CC35	6641 504753	YURIY ZAYCEV	{"phone": "+70014411602"}
0005432042497	74CC35	3010 196782	SERGEY ANTONOV	{"email": "antonov-s.1963@postgrespro.ru", "phone": "+70394217021"}
0005432042498	F419BE	5605 637579	SERGEY KARPOV	{"phone": "+70118005710"}
0005432042499	88CD4E	3345 947051	OLGA DMITRIEVA	{"phone": "+70534236770"}
0005432042500	C96CDE	5969 265946	ELENA SEMENOVA	{"phone": "+70800322490"}
0005432042501	328041	8310 763449	NINA LAZAREVA	{"email": "ninalazareva23021970@postgrespro.ru", "phone": "+70940317884"}
0005432042502	2DB044	9628 677186	RUDOLF KOROLEV	{"email": "korolev.rudolf-31081968@postgrespro.ru", "phone": "+70648138760"}
0005432042503	2DB044	4659 877569	LIDIYA ABRAMOVA	{"email": "l.abramova.1971@postgrespro.ru", "phone": "+70783450606"}
0005432042504	53745B	1375 400962	NATALYA AFANASEVA	{"email": "afanasevanatalya.1964@postgrespro.ru", "phone": "+70434453581"}
0005432042505	4F1484	2933 239504	ELIZAVETA KUZNECOVA	{"email": "e_kuznecova011975@postgrespro.ru", "phone": "+70779604787"}
0005432042506	4F1484	2531 323746	RAFAEL PAVLOV	{"email": "pavlov.rafael-011978@postgrespro.ru", "phone": "+70184690729"}
0005432042507	20681A	7122 107444	SERGEY NIKOLAEV	{"email": "nikolaevsergey-14031978@postgrespro.ru", "phone": "+70816522185"}
0005432042508	20681A	4328 893518	PAVEL IVANOV	{"phone": "+70644726010"}
0005432042509	69DB0F	2878 763444	VLADIMIR MOROZOV	{"email": "morozov-v_18071974@postgrespro.ru", "phone": "+70892409149"}
0005432042510	69EBF3	2523 377237	ANASTASIYA IVANOVA	{"email": "a.ivanova.26081975@postgrespro.ru", "phone": "+70412455707"}
0005432042511	69EBF3	8508 276163	VLADIMIR BARANOV	{"phone": "+70150430242"}
0005432042512	813525	2534 617456	RUSLAN MOROZOV	{"phone": "+70137013679"}
0005432042513	813525	2182 025330	NINA TIKHONOVA	{"phone": "+70241965431"}
0005432042514	112F3D	8722 845752	ARTEM ZAKHAROV	{"phone": "+70994035050"}
0005432042515	E5D112	0888 692501	VLADIMIR TARASOV	{"email": "tarasov-v031973@postgrespro.ru", "phone": "+70439262101"}
0005432042516	E2BE56	9085 205366	NIKITA ZAKHAROV	{"phone": "+70295321995"}
0005432042517	EE33D4	3201 589889	GALINA YUDINA	{"phone": "+70865648879"}
0005432042518	EE33D4	6332 398776	NATALYA FROLOVA	{"phone": "+70829998322"}
0005432042519	EE33D4	1146 115532	MARIYA ZAYCEVA	{"phone": "+70208945846"}
0005432042520	269C33	5285 382524	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov.1958@postgrespro.ru", "phone": "+70026664788"}
0005432042521	955CAD	5257 850033	ALEKSEY KUZNECOV	{"email": "kuznecova-021960@postgrespro.ru", "phone": "+70261060546"}
0005432042522	955CAD	8333 402205	VLADIMIR ISAEV	{"email": "isaev.vladimir-17071968@postgrespro.ru", "phone": "+70877733907"}
0005432042523	0AD7E5	3884 605807	EVGENIYA MEDVEDEVA	{"phone": "+70084597618"}
0005432042524	0AD7E5	3671 068001	KLAVDIYA DENISOVA	{"email": "denisova-klavdiya.11091963@postgrespro.ru", "phone": "+70134118346"}
0005432042525	7E3B78	5017 693263	ELENA KUZNECOVA	{"email": "kuznecova-elena.22091968@postgrespro.ru", "phone": "+70542114944"}
0005432042526	D0AEA9	4157 318912	NADEZHDA TROFIMOVA	{"email": "trofimova.n051984@postgrespro.ru", "phone": "+70955808640"}
0005432042527	FFA6C9	7062 250009	ARTEM SOKOLOV	{"phone": "+70747801811"}
0005432042528	FFA6C9	0805 031063	TATYANA MOISEEVA	{"email": "t-moiseeva1972@postgrespro.ru", "phone": "+70621467665"}
0005432042529	D2B282	1657 170149	ANASTASIYA CHERNOVA	{"email": "anastasiya.chernova021978@postgrespro.ru", "phone": "+70373491261"}
0005432042530	D2B282	5970 489782	TAISIYA ILINA	{"email": "taisiya.ilina.01111975@postgrespro.ru", "phone": "+70407131604"}
0005432042531	60542A	9552 889601	KSENIYA SOKOLOVA	{"email": "sokolovak031983@postgrespro.ru", "phone": "+70725585264"}
0005432042532	41ACC5	5507 441122	EMMA ZAKHAROVA	{"email": "emmazakharova_011975@postgrespro.ru", "phone": "+70844271916"}
0005432042533	9E7882	7929 752690	SVETLANA ZHURAVLEVA	{"phone": "+70794373607"}
0005432042534	E8A7EE	9547 187775	VLADISLAV GERASIMOV	{"phone": "+70799841794"}
0005432042535	7AE833	6599 105555	LYUBOV FEDOROVA	{"phone": "+70108376313"}
0005432042536	42415F	8468 881308	TATYANA AKIMOVA	{"email": "tatyana_akimova-121968@postgrespro.ru", "phone": "+70557381956"}
0005432042537	42415F	4363 244976	IVAN ORLOV	{"email": "orlov-ivan051971@postgrespro.ru", "phone": "+70778442767"}
0005432042538	E5B131	9843 388324	OLGA ANISIMOVA	{"email": "olga.anisimova-1976@postgrespro.ru", "phone": "+70126940383"}
0005432042539	1E94E8	0524 679366	ANDREY PAVLOV	{"email": "pavlov.a-03071966@postgrespro.ru", "phone": "+70480132755"}
0005432042540	1E94E8	1535 775598	NIKOLAY BELOV	{"phone": "+70797856971"}
0005432042541	E73540	2321 656449	GENNADIY BORISOV	{"email": "gennadiy.borisov_1966@postgrespro.ru", "phone": "+70848648956"}
0005432042542	E73540	0789 043249	SERGEY YAKOVLEV	{"phone": "+70585681261"}
0005432042543	E73540	3581 466921	IRAIDA MARTYNOVA	{"phone": "+70650295561"}
0005432042544	F288A4	8240 793213	YURIY SOKOLOV	{"phone": "+70685015172"}
0005432042545	3F8523	3443 588319	SVETLANA DAVYDOVA	{"email": "davydova.svetlana-02121963@postgrespro.ru", "phone": "+70390496061"}
0005432042546	3F8523	2459 882979	GALINA VOLKOVA	{"email": "g_volkova1966@postgrespro.ru", "phone": "+70395930955"}
0005432042547	9CF872	8516 910765	KSENIYA SEMENOVA	{"email": "kseniya.semenova-31081970@postgrespro.ru", "phone": "+70565717902"}
0005432042548	3477E2	4888 666986	KONSTANTIN NIKITIN	{"email": "nikitin_k.1969@postgrespro.ru", "phone": "+70393923809"}
0005432042549	E631B9	4458 478846	GLEB ALEKSEEV	{"phone": "+70318950441"}
0005432042550	E631B9	6951 783697	MIKHAIL CHERNOV	{"email": "chernovmikhail_06091964@postgrespro.ru", "phone": "+70988149279"}
0005432042551	854CF0	9077 371282	KONSTANTIN MAKAROV	{"email": "makarov_k.30111967@postgrespro.ru", "phone": "+70838914481"}
0005432042552	854CF0	3072 778980	MARIYA NAZAROVA	{"phone": "+70812790457"}
0005432042553	78C5AC	2493 223057	MARINA NOVIKOVA	{"phone": "+70359047841"}
0005432042554	78C5AC	9426 097903	ARTEM VASILEV	{"email": "avasilev-011981@postgrespro.ru", "phone": "+70558044051"}
0005432042555	CCD23F	1108 643974	ANNA SMIRNOVA	{"email": "smirnova_anna_081965@postgrespro.ru", "phone": "+70731627283"}
0005432042556	1AA3E2	8758 567468	VALERIY KARPOV	{"phone": "+70629304345"}
0005432042557	87497F	2479 040476	ANDREY MOROZOV	{"phone": "+70289907537"}
0005432042558	A634EE	8785 701172	OLGA DAVYDOVA	{"email": "davydova.o.1975@postgrespro.ru", "phone": "+70063487158"}
0005432042559	6DB045	6402 671900	VITALIY FILIPPOV	{"email": "vfilippov.081967@postgrespro.ru", "phone": "+70778767052"}
0005432042560	84FA75	1819 512609	LYUDMILA EGOROVA	{"phone": "+70636169766"}
0005432042561	60EB1C	6381 593604	OLEG IVANOV	{"email": "ivanovoleg1963@postgrespro.ru", "phone": "+70915448760"}
0005432042562	DE62EC	2752 405965	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov_1973@postgrespro.ru", "phone": "+70571411588"}
0005432042563	083B77	5234 329007	EKATERINA POPOVA	{"email": "e-popova1973@postgrespro.ru", "phone": "+70551294297"}
0005432042564	083B77	1188 734305	GENNADIY ZAKHAROV	{"email": "gennadiy_zakharov.111967@postgrespro.ru", "phone": "+70528024778"}
0005432042565	DD8904	0532 019033	LYUBOV FOMINA	{"email": "fominal-1968@postgrespro.ru", "phone": "+70093445829"}
0005432042566	DD8904	7883 861332	GLEB IVANOV	{"phone": "+70745683833"}
0005432042567	06C789	8382 932726	VALENTINA SOROKINA	{"phone": "+70737758096"}
0005432042568	B8CB46	9847 969825	LARISA LOGINOVA	{"email": "l-loginova091965@postgrespro.ru", "phone": "+70919607544"}
0005432042569	B8CB46	4636 434619	VERA FROLOVA	{"phone": "+70833499487"}
0005432042570	3F156A	6874 081031	YULIYA FILIPPOVA	{"phone": "+70038697928"}
0005432042571	3F156A	6582 562801	ANDREY POPOV	{"email": "popov-andrey.13051981@postgrespro.ru", "phone": "+70132663594"}
0005432042572	5A8535	2272 508210	PAVEL VASILEV	{"phone": "+70053002049"}
0005432042573	963B1F	4154 390774	ELENA ZAKHAROVA	{"phone": "+70486329690"}
0005432042574	DCF142	7102 746455	GALINA BARANOVA	{"email": "baranovag-22121975@postgrespro.ru", "phone": "+70880447653"}
0005432042575	28328C	7814 474556	DMITRIY MAKSIMOV	{"phone": "+70844417062"}
0005432042576	52A5C5	4642 212428	GENNADIY ROMANOV	{"phone": "+70164229749"}
0005432042577	52A5C5	8283 924055	ZINAIDA MARTYNOVA	{"phone": "+70024039365"}
0005432042578	BCA44A	3659 900904	NIKOLAY KUZNECOV	{"email": "kuznecov-n.19061978@postgrespro.ru", "phone": "+70114958404"}
0005432042579	643747	0712 030544	LYUDMILA LOGINOVA	{"email": "lyudmilaloginova1971@postgrespro.ru", "phone": "+70627323750"}
0005432042580	7D859C	8348 890793	ANATOLIY NIKITIN	{"phone": "+70813740086"}
0005432042581	269F2B	7532 090479	ANNA PETROVA	{"email": "petrova_a_16091967@postgrespro.ru", "phone": "+70626685109"}
0005432042582	B20D8B	4285 436506	VLADIMIR FOMIN	{"email": "vladimir-fomin-1961@postgrespro.ru", "phone": "+70516640486"}
0005432042583	079602	1227 876733	VITALIY TIMOFEEV	{"email": "v-timofeev_101974@postgrespro.ru", "phone": "+70669860870"}
0005432042584	079602	2662 809494	SVETLANA EGOROVA	{"phone": "+70741187603"}
0005432042585	DED061	6849 505147	IRINA MEDVEDEVA	{"phone": "+70509954760"}
0005432042586	DED061	8677 641380	OLGA YUDINA	{"phone": "+70996799197"}
0005432042587	459649	9577 673432	VASILIY VASILEV	{"phone": "+70400088516"}
0005432042588	163449	8546 034847	ALENA PAVLOVA	{"phone": "+70346579500"}
0005432042589	C91ACF	9336 539525	VALERIY MAKSIMOV	{"phone": "+70272520380"}
0005432042590	B4EFAE	1975 535484	ALEKSANDR ZAYCEV	{"phone": "+70718793201"}
0005432042591	B4EFAE	1880 741827	VLADIMIR RODIONOV	{"phone": "+70989686936"}
0005432042592	435FBE	1456 381655	VLADIMIR NIKITIN	{"phone": "+70947113176"}
0005432042593	14B376	3425 590962	VLADIMIR PAVLOV	{"email": "pavlov_v_101970@postgrespro.ru", "phone": "+70599841545"}
0005432042594	EA0065	9679 505278	ALEKSANDR FROLOV	{"phone": "+70814044707"}
0005432042595	B4664A	9172 402648	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov.20111977@postgrespro.ru", "phone": "+70689823238"}
0005432042596	B4664A	8089 384022	VALENTINA POPOVA	{"phone": "+70874856942"}
0005432042597	58B896	1518 884831	IVAN MOROZOV	{"email": "ivan_morozov13051976@postgrespro.ru", "phone": "+70999849351"}
0005432042598	58B896	0923 619071	ANDREY FILIPPOV	{"email": "filippova-1981@postgrespro.ru", "phone": "+70708873313"}
0005432042599	FF1AEB	6683 971413	ALISA KOZLOVA	{"email": "alisa.kozlova_1967@postgrespro.ru", "phone": "+70262015570"}
0005432042600	9FB5DC	6350 753559	YULIYA SMIRNOVA	{"phone": "+70660879898"}
0005432042601	E41648	1065 287848	ANNA GAVRILOVA	{"email": "annagavrilova.111972@postgrespro.ru", "phone": "+70008794294"}
0005432042602	4119BF	4725 949247	VERA FADEEVA	{"email": "verafadeeva-1960@postgrespro.ru", "phone": "+70206223176"}
0005432042603	4119BF	6965 322349	NIKOLAY OSIPOV	{"email": "osipovn.1977@postgrespro.ru", "phone": "+70397896823"}
0005432042604	A2A4BA	8826 712341	KARINA ALEKSANDROVA	{"phone": "+70232529642"}
0005432042605	281270	9431 278181	NIKITA ALEKSEEV	{"email": "nikitaalekseev_1963@postgrespro.ru", "phone": "+70765720482"}
0005432042606	281270	0383 364291	TATYANA EFIMOVA	{"email": "tatyana-efimova_1970@postgrespro.ru", "phone": "+70210001862"}
0005432042607	941E5B	1230 072856	VYACHESLAV NOVIKOV	{"phone": "+70120576860"}
0005432042608	5D9389	7727 447885	NADEZHDA OSIPOVA	{"email": "nadezhda.osipova_1973@postgrespro.ru", "phone": "+70001477133"}
0005432042609	D220AE	2672 266594	TATYANA IVANOVA	{"email": "ivanovat.30071979@postgrespro.ru", "phone": "+70715332480"}
0005432042610	3A00E7	1170 449310	GALINA STEPANOVA	{"email": "g_stepanova-1966@postgrespro.ru", "phone": "+70334064282"}
0005432042611	DA0B80	9042 430755	SVETLANA KISELEVA	{"email": "svetlana-kiseleva1983@postgrespro.ru", "phone": "+70164137607"}
0005432042612	6C3D39	5037 870704	KIRA AKIMOVA	{"email": "k-akimova.051976@postgrespro.ru", "phone": "+70753675168"}
0005432042613	6C3D39	3455 148568	PAVEL KUZNECOV	{"phone": "+70244527873"}
0005432042614	ABCABE	9626 579683	ZHANNA KUZNECOVA	{"phone": "+70481400898"}
0005432042615	E12523	7463 857674	KONSTANTIN VASILEV	{"email": "kvasilev-03021972@postgrespro.ru", "phone": "+70415239846"}
0005432042616	166088	3792 858573	DARYA MEDVEDEVA	{"phone": "+70838883207"}
0005432042617	166088	0040 742203	TAMARA POPOVA	{"phone": "+70976059042"}
0005432042618	A8A564	7422 813261	MARIYA KOMAROVA	{"phone": "+70905734866"}
0005432042619	B39F7F	3162 405177	SERGEY YAKOVLEV	{"email": "sergeyyakovlev24081973@postgrespro.ru", "phone": "+70026814473"}
0005432042620	B39F7F	2177 629664	SERGEY SCHERBAKOV	{"email": "scherbakov-s-25101966@postgrespro.ru", "phone": "+70356527877"}
0005432042621	B39F7F	2119 266506	RAMIL ZAYCEV	{"email": "rzaycev.1970@postgrespro.ru", "phone": "+70950736790"}
0005432042622	2E0F69	8930 474865	NATALYA SOLOVEVA	{"email": "n_soloveva_1974@postgrespro.ru", "phone": "+70251436033"}
0005432042623	2E0F69	3855 106081	ELIZAVETA MATVEEVA	{"email": "elizaveta-matveeva17091969@postgrespro.ru", "phone": "+70891192315"}
0005432042624	2E0F69	1869 058980	ALEKSANDR SOLOVEV	{"phone": "+70162335631"}
0005432042625	2E0F69	0794 733462	TAISIYA PETROVA	{"phone": "+70424506992"}
0005432042626	9C285F	0448 799946	MARIYA IVANOVA	{"email": "ivanovamariya-1964@postgrespro.ru", "phone": "+70304968427"}
0005432042627	69E14A	7514 306170	ILYA SOKOLOV	{"email": "sokolov-i-1980@postgrespro.ru", "phone": "+70146108360"}
0005432042628	FBF9FF	0211 608552	ALEKSANDR ZAYCEV	{"email": "a.zaycev_16121969@postgrespro.ru", "phone": "+70562533139"}
0005432042629	853CE5	8578 013649	DMITRIY GAVRILOV	{"email": "d-gavrilov-30071966@postgrespro.ru", "phone": "+70267693258"}
0005432042630	EC0BD1	3953 902048	OLGA LUKYANOVA	{"phone": "+70884083714"}
0005432042631	A45937	8098 943846	VITALIY SEMENOV	{"phone": "+70168975751"}
0005432042632	88226D	8951 166250	ELENA DANILOVA	{"phone": "+70364702744"}
0005432042633	88226D	6838 909520	IRINA ISAEVA	{"phone": "+70515495316"}
0005432042634	88226D	4830 226349	DMITRIY MIKHAYLOV	{"phone": "+70417931369"}
0005432042635	88226D	8179 842529	ZINAIDA SERGEEVA	{"phone": "+70660578776"}
0005432042636	4B5337	6384 039531	ANNA FROLOVA	{"email": "anna.frolova-1984@postgrespro.ru", "phone": "+70582079728"}
0005432042637	A7FE52	1681 006737	GALINA EFREMOVA	{"email": "efremova.g_1971@postgrespro.ru", "phone": "+70358183103"}
0005432042638	A7FE52	2617 714246	VASILIY AFANASEV	{"phone": "+70809108976"}
0005432042639	3F8C43	0254 639958	EVGENIY OSIPOV	{"email": "eosipov.051971@postgrespro.ru", "phone": "+70636208185"}
0005432042640	3F8C43	7482 998011	NINA DAVYDOVA	{"phone": "+70283858229"}
0005432042641	AC614D	4511 958043	VLADIMIR PAVLOV	{"email": "pavlov_v.1970@postgrespro.ru", "phone": "+70331768386"}
0005432042642	AC614D	0624 364442	SVETLANA GAVRILOVA	{"email": "gavrilova-s_1968@postgrespro.ru", "phone": "+70360981202"}
0005432042643	E85F99	9641 867065	YURIY POPOV	{"email": "popov-yuriy_1963@postgrespro.ru", "phone": "+70964032311"}
0005432042644	E85F99	4228 568133	VALENTINA AFANASEVA	{"phone": "+70500969560"}
0005432042645	8E4F02	5901 372872	TATYANA VASILEVA	{"phone": "+70494996290"}
0005432042646	D86721	0082 735333	NINA MOISEEVA	{"phone": "+70698126507"}
0005432042647	D86721	2106 547795	ANDREY ZHUKOV	{"phone": "+70120691537"}
0005432042648	D86721	8499 436952	VLADIMIR TIKHONOV	{"email": "tikhonov-vladimir.14071974@postgrespro.ru", "phone": "+70842385914"}
0005432042649	0F61BF	0016 218348	ZINAIDA NOVIKOVA	{"phone": "+70415402595"}
0005432042650	0F61BF	7405 603474	SERGEY IVANOV	{"phone": "+70257826864"}
0005432042651	5F5FE6	4636 429496	MARIYA ISAEVA	{"email": "isaeva.m-10071980@postgrespro.ru", "phone": "+70015428288"}
0005432042652	4B740C	4080 530802	ANNA EFIMOVA	{"email": "anna-efimova1971@postgrespro.ru", "phone": "+70636879884"}
0005432042653	4B740C	2592 576904	ALEKSANDR VOLKOV	{"email": "avolkov.1971@postgrespro.ru", "phone": "+70119884380"}
0005432042654	F57DD7	4475 345459	MIKHAIL SEMENOV	{"email": "mikhailsemenov101972@postgrespro.ru", "phone": "+70930921636"}
0005432042655	F57DD7	1021 999783	GALINA POTAPOVA	{"email": "potapovag.1958@postgrespro.ru", "phone": "+70747484115"}
0005432042656	EA4C65	2985 246766	TATYANA MOISEEVA	{"phone": "+70799304541"}
0005432042657	EA4C65	5561 949732	MARINA KAZAKOVA	{"email": "m_kazakova071979@postgrespro.ru", "phone": "+70921226176"}
0005432042658	A53525	6438 486596	GRIGORIY PETROV	{"phone": "+70442179920"}
0005432042659	7B1854	7250 444847	POLINA BELOVA	{"phone": "+70410701488"}
0005432042660	5ADC19	0104 785006	ALEKSEY KULIKOV	{"email": "kulikov_aleksey-081966@postgrespro.ru", "phone": "+70273701636"}
0005432042661	5ADC19	5718 267320	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr_1972@postgrespro.ru", "phone": "+70128180030"}
0005432042662	BC8859	0203 186300	SERGEY GRIGOREV	{"email": "sergeygrigorev_20021975@postgrespro.ru", "phone": "+70048308468"}
0005432042663	EC59F7	6416 696899	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-051979@postgrespro.ru", "phone": "+70735410785"}
0005432042664	BF0C00	6071 381113	LILIYA VOLKOVA	{"phone": "+70361668263"}
0005432042665	A2448A	6000 830110	VSEVOLOD KAZAKOV	{"email": "vkazakov1973@postgrespro.ru", "phone": "+70917055630"}
0005432042666	72383B	9074 130539	NATALIYA KOZLOVA	{"email": "nataliyakozlova.1973@postgrespro.ru", "phone": "+70352855170"}
0005432042667	493D0A	1488 278967	ANATOLIY KULIKOV	{"email": "kulikova_101970@postgrespro.ru", "phone": "+70609968604"}
0005432042668	44C3E0	4125 049265	NINA MEDVEDEVA	{"phone": "+70403846982"}
0005432042669	D7A2AF	5188 606016	MARK BONDARENKO	{"email": "mark-bondarenko-05021991@postgrespro.ru", "phone": "+70289250459"}
0005432042670	81C30F	5314 505435	IRINA SOKOLOVA	{"email": "irinasokolova_1974@postgrespro.ru", "phone": "+70383517077"}
0005432042671	81C30F	3276 675267	LYUDMILA KULIKOVA	{"phone": "+70158461950"}
0005432042672	CF9E08	7520 101863	IRINA NIKITINA	{"email": "nikitinai24051980@postgrespro.ru", "phone": "+70679679845"}
0005432042673	920E52	3024 895677	KAMIL KUZNECOV	{"phone": "+70866942228"}
0005432042674	920E52	9183 758720	MILANA FROLOVA	{"email": "frolova_milana.111979@postgrespro.ru", "phone": "+70558894670"}
0005432042675	992830	2917 920717	KLAVDIYA SOROKINA	{"email": "k.sorokina_07081979@postgrespro.ru", "phone": "+70019365025"}
0005432042676	DC4889	3152 702249	NINA SIDOROVA	{"phone": "+70143754462"}
0005432042677	0CE082	3157 439386	GUZEL ORLOVA	{"phone": "+70506155198"}
0005432042678	F886ED	9553 871772	SABINA YUDINA	{"phone": "+70646962921"}
0005432042679	4CCFBC	9802 230374	VIKTOR GUSEV	{"email": "v_gusev.24021974@postgrespro.ru", "phone": "+70258318947"}
0005432042680	15A9CC	9189 223017	NINA YAKOVLEVA	{"email": "yakovlevan06091978@postgrespro.ru", "phone": "+70097052174"}
0005432042681	334D7D	2183 809905	ALENA IVANOVA	{"email": "ivanovaalena15011967@postgrespro.ru", "phone": "+70231291704"}
0005432042682	5BD3D6	8545 714642	ANNA FEDOROVA	{"phone": "+70994356123"}
0005432042683	5BD3D6	7101 613522	NINA IVANOVA	{"email": "ivanova_n101970@postgrespro.ru", "phone": "+70213354755"}
0005432042684	00CE1C	5628 422867	OLGA ERMAKOVA	{"phone": "+70138561040"}
0005432042685	8FFBEC	2630 541110	RAMIL ZHURAVLEV	{"email": "zhuravlev-r.061966@postgrespro.ru", "phone": "+70217724586"}
0005432042686	B75818	2541 190101	IRINA CHERNOVA	{"phone": "+70866180963"}
0005432042687	B75818	1639 516254	OLGA SMIRNOVA	{"email": "smirnova-o.13051968@postgrespro.ru", "phone": "+70700403146"}
0005432042688	9FFF98	4058 604628	IRINA SMIRNOVA	{"email": "smirnova_irina-1971@postgrespro.ru", "phone": "+70397278118"}
0005432042689	8B8D6A	3981 905994	SERGEY KAZAKOV	{"phone": "+70745382003"}
0005432042690	8B8D6A	5530 077381	MAKSIM NIKOLAEV	{"phone": "+70054475017"}
0005432042691	C86979	5475 260904	ALEKSEY KARPOV	{"phone": "+70246869372"}
0005432042692	153D5C	8520 179219	VLADIMIR KUZNECOV	{"email": "v_kuznecov_1972@postgrespro.ru", "phone": "+70121835305"}
0005432042693	153D5C	9374 978435	GALINA NIKITINA	{"phone": "+70061826285"}
0005432042694	153D5C	3749 396632	PAVEL SAVELEV	{"phone": "+70544050238"}
0005432042695	44F192	6078 656762	MARAT GAVRILOV	{"phone": "+70565328289"}
0005432042696	385C7D	0365 164685	NIKOLAY VASILEV	{"email": "vasilev.nikolay-1983@postgrespro.ru", "phone": "+70227098661"}
0005432042697	013BC0	4180 674822	NIKOLAY IVANOV	{"phone": "+70127063678"}
0005432042698	013BC0	1135 973943	TAMARA MAKAROVA	{"phone": "+70425481264"}
0005432042699	013BC0	9065 634020	YURIY MIRONOV	{"email": "yuriymironov-1959@postgrespro.ru", "phone": "+70970396652"}
0005432042700	DD1152	1179 922974	SERGEY KUZNECOV	{"email": "kuznecov-s031976@postgrespro.ru", "phone": "+70958143098"}
0005432042701	DD1152	9092 252076	OLGA VASILEVA	{"phone": "+70918779285"}
0005432042702	08C770	6217 701907	LYUDMILA VOLKOVA	{"email": "volkovalyudmila.1958@postgrespro.ru", "phone": "+70774076878"}
0005432042703	F70F79	4066 041434	MARIYA MAKSIMOVA	{"email": "maksimova.mariya-1965@postgrespro.ru", "phone": "+70764029325"}
0005432042704	F70F79	7827 972778	SERGEY DAVYDOV	{"phone": "+70356385532"}
0005432042705	6F5A99	6932 462849	NADEZHDA PAVLOVA	{"phone": "+70006452808"}
0005432042706	A9E13D	2211 041731	EVGENIY ABRAMOV	{"email": "e-abramov.13061970@postgrespro.ru", "phone": "+70898197883"}
0005432042707	29FBC5	7285 495235	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov-1980@postgrespro.ru", "phone": "+70331237453"}
0005432042708	29FBC5	7718 677264	PELAGEYA KUZNECOVA	{"email": "kuznecovap-1965@postgrespro.ru", "phone": "+70459393173"}
0005432042709	9281D0	6579 454863	VLADIMIR KOROLEV	{"phone": "+70894948465"}
0005432042710	E97768	7621 062778	NATALYA GERASIMOVA	{"phone": "+70127320961"}
0005432042711	45B714	3548 686406	LYUDMILA YAKOVLEVA	{"phone": "+70886425941"}
0005432042712	45B714	1599 471539	LYUBOV TROFIMOVA	{"email": "l_trofimova-071977@postgrespro.ru", "phone": "+70814340852"}
0005432042713	AE4B25	3284 300877	SERGEY KOZLOV	{"phone": "+70771027894"}
0005432042714	4B89B4	2657 187211	KONSTANTIN POPOV	{"phone": "+70185004787"}
0005432042715	46815F	2090 009872	VIKTOR FEDOROV	{"email": "fedorov_viktor-1957@postgrespro.ru", "phone": "+70330802683"}
0005432042716	46815F	7002 319973	VYACHESLAV STEPANOV	{"phone": "+70489815172"}
0005432042717	C4571D	0381 725374	SERGEY KUZMIN	{"phone": "+70935813488"}
0005432042718	3B7488	8177 763118	OLGA OVCHINNIKOVA	{"phone": "+70554275291"}
0005432042719	3B7488	3596 777413	ELIZAVETA KONOVALOVA	{"phone": "+70076503149"}
0005432042720	D7BCA8	8560 203206	ZOYA ISAEVA	{"phone": "+70160406110"}
0005432042721	FCD659	4164 934518	ALEKSANDR STEPANOV	{"phone": "+70167183461"}
0005432042722	FCD659	2262 850463	OLGA ILINA	{"phone": "+70882290914"}
0005432042723	D1371A	6927 619478	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov-20011984@postgrespro.ru", "phone": "+70857501261"}
0005432042724	431BDB	7707 357754	OLGA KULIKOVA	{"phone": "+70123477599"}
0005432042725	25BACA	4129 969235	NADEZHDA BELYAEVA	{"email": "nadezhda.belyaeva071977@postgrespro.ru", "phone": "+70150652767"}
0005432042726	25BACA	4802 316295	OKSANA NOVIKOVA	{"phone": "+70913051758"}
0005432042727	9556C2	7524 117149	ILDAR KRASNOV	{"email": "i-krasnov-021975@postgrespro.ru", "phone": "+70024914660"}
0005432042728	DE4B0D	0674 635006	ELENA MAKAROVA	{"phone": "+70187720244"}
0005432042729	DE4B0D	0446 262149	VLADIMIR IVANOV	{"phone": "+70955395253"}
0005432042730	164D70	6094 648048	ROMAN ZAKHAROV	{"email": "rzakharov1970@postgrespro.ru", "phone": "+70218010049"}
0005432042731	164D70	9097 913952	ELENA MOROZOVA	{"email": "morozova-elena.1979@postgrespro.ru", "phone": "+70042208930"}
0005432042732	164D70	6263 715729	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_111978@postgrespro.ru", "phone": "+70475879890"}
0005432042733	B99161	6129 829068	MIKHAIL MOROZOV	{"phone": "+70853588734"}
0005432042734	B99161	1784 385839	GALINA KAZAKOVA	{"email": "g_kazakova.1974@postgrespro.ru", "phone": "+70717603929"}
0005432042735	B99161	8993 786921	IRINA RODIONOVA	{"email": "rodionova-irina-1979@postgrespro.ru", "phone": "+70143855604"}
0005432042736	B99161	0684 407653	NIKOLAY KRASNOV	{"email": "nikolay-krasnov.081975@postgrespro.ru", "phone": "+70223954691"}
0005432042737	02EE73	2055 578018	GALINA NIKOLAEVA	{"phone": "+70677819592"}
0005432042738	02EE73	0817 504391	LARISA VOROBEVA	{"email": "larisa.vorobeva_16051961@postgrespro.ru", "phone": "+70696955243"}
0005432042739	D8AC64	5453 486061	ILYA DMITRIEV	{"phone": "+70054165531"}
0005432042740	D8AC64	9191 616288	ANDREY NIKOLAEV	{"phone": "+70406112981"}
0005432042741	B0D9FD	5450 694348	ANATOLIY PAVLOV	{"phone": "+70917786113"}
0005432042742	38F377	8647 447982	ANATOLIY NAZAROV	{"email": "nazarova1981@postgrespro.ru", "phone": "+70904452079"}
0005432042743	38F377	3013 232248	ALBINA VOROBEVA	{"phone": "+70458827772"}
0005432042744	38F377	5588 322303	VIKTOR KUZMIN	{"phone": "+70879513794"}
0005432042745	8D5191	5157 575130	GENNADIY SIDOROV	{"email": "g.sidorov.1965@postgrespro.ru", "phone": "+70813687749"}
0005432042746	8D5191	2811 766710	ANNA NIKIFOROVA	{"email": "nikiforova.a.14051973@postgrespro.ru", "phone": "+70796292228"}
0005432042747	8D5191	3404 730376	GALINA ANDREEVA	{"email": "galina.andreeva-1971@postgrespro.ru", "phone": "+70591348533"}
0005432042748	0C9A42	9616 301753	VYACHESLAV SAVELEV	{"email": "savelev-v.1979@postgrespro.ru", "phone": "+70165855675"}
0005432042749	0C9A42	4189 411778	MARINA MEDVEDEVA	{"phone": "+70079283982"}
0005432042750	786D37	8662 152818	KONSTANTIN MELNIKOV	{"phone": "+70614092851"}
0005432042751	786D37	0094 954940	ASIYA NOVIKOVA	{"phone": "+70866254819"}
0005432042752	786D37	3170 559659	NIKOLAY TARASOV	{"email": "tarasov.nikolay.071961@postgrespro.ru", "phone": "+70147447093"}
0005432042753	11E54D	9651 278083	VALENTINA KUZNECOVA	{"phone": "+70650324755"}
0005432042754	58E2E3	3283 293749	VLADIMIR BORISOV	{"phone": "+70906386900"}
0005432042755	375029	7932 341332	SERGEY KOZLOV	{"email": "kozlov-s.1967@postgrespro.ru", "phone": "+70154193607"}
0005432042756	375029	9548 557032	BORIS MATVEEV	{"email": "matveevboris1979@postgrespro.ru", "phone": "+70909445973"}
0005432042757	FF6BCB	9404 759456	MARINA YAKOVLEVA	{"email": "yakovleva.m121978@postgrespro.ru", "phone": "+70964971229"}
0005432042758	FF6BCB	7976 760303	YURIY VASILEV	{"phone": "+70803708505"}
0005432042759	F60666	4386 959638	VLADIMIR ANDREEV	{"email": "andreev-vladimir.23041976@postgrespro.ru", "phone": "+70775449130"}
0005432042760	FF8767	0621 439615	VLADISLAV MIKHAYLOV	{"phone": "+70588027780"}
0005432042761	84879B	6751 449095	LYUBOV MAKAROVA	{"email": "l.makarova_041980@postgrespro.ru", "phone": "+70721741790"}
0005432042762	190260	1051 883729	SERGEY SOLOVEV	{"phone": "+70446086472"}
0005432042763	0B959D	6805 756911	ALEKSANDR KUDRYASHOV	{"phone": "+70300733085"}
0005432042764	0B959D	2058 266291	VALENTINA ANTONOVA	{"phone": "+70232726533"}
0005432042765	931B48	4516 539937	ALEKSEY SERGEEV	{"phone": "+70328035429"}
0005432042766	931B48	1901 333352	MARIYA KRASNOVA	{"phone": "+70312586289"}
0005432042767	94370E	2866 867240	MARINA KOMAROVA	{"email": "m.komarova_07121974@postgrespro.ru", "phone": "+70665662383"}
0005432042768	94370E	8979 607191	TATYANA VOLKOVA	{"email": "t-volkova_051966@postgrespro.ru", "phone": "+70365484808"}
0005432042769	AB1B63	2489 813436	ALEKSEY KUZMIN	{"phone": "+70523717084"}
0005432042770	1609DD	1508 007177	NAIL POPOV	{"phone": "+70985620915"}
0005432042771	DAFD58	9020 598117	OLGA IVANOVA	{"phone": "+70211525843"}
0005432042772	A19372	2245 961579	IRINA PAVLOVA	{"phone": "+70711963002"}
0005432042773	126691	6430 087498	LARISA EFIMOVA	{"phone": "+70932077363"}
0005432042774	1BFF56	9849 471145	VASILIY ZAKHAROV	{"email": "v-zakharov.1967@postgrespro.ru", "phone": "+70564804477"}
0005432042775	1BFF56	4059 521883	VERA KOROLEVA	{"email": "vera_koroleva-1973@postgrespro.ru", "phone": "+70507621089"}
0005432042776	0B8CB0	0588 374346	ALEKSANDR ROMANOV	{"phone": "+70385673712"}
0005432042777	B4B68F	7311 485921	ALEKSANDR DENISOV	{"email": "denisov-aleksandr071975@postgrespro.ru", "phone": "+70124577004"}
0005432042778	725F11	0835 397990	YURIY BARANOV	{"phone": "+70810445496"}
0005432042779	725F11	9528 563266	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey_31051961@postgrespro.ru", "phone": "+70843559312"}
0005432042780	725F11	7655 951512	ANTONINA BELYAEVA	{"email": "belyaeva.a.08071974@postgrespro.ru", "phone": "+70441634539"}
0005432042781	4B5A53	6308 173008	ALEKSANDR GUSEV	{"email": "a_gusev.1970@postgrespro.ru", "phone": "+70227791904"}
0005432042782	35EA98	8523 140147	ALEKSANDRA ROMANOVA	{"email": "aleksandraromanova_011986@postgrespro.ru", "phone": "+70377080836"}
0005432042783	509660	0453 416524	VITALIY ABRAMOV	{"email": "abramov.vitaliy1982@postgrespro.ru", "phone": "+70784459097"}
0005432042784	6BE067	5910 103581	KIRILL PETROV	{"email": "kpetrov_111976@postgrespro.ru", "phone": "+70255111473"}
0005432042785	56392C	9527 445915	VERONIKA TARASOVA	{"email": "tarasova-v_081960@postgrespro.ru", "phone": "+70408642842"}
0005432042786	1614CA	2486 342214	VYACHESLAV ANDREEV	{"email": "v-andreev.1973@postgrespro.ru", "phone": "+70755570985"}
0005432042787	0A4A1A	0528 014903	NIKITA FOMIN	{"email": "fomin-n.31121968@postgrespro.ru", "phone": "+70066083263"}
0005432042788	480B7B	5880 922715	RUDOLF TIMOFEEV	{"email": "timofeev-r03021969@postgrespro.ru", "phone": "+70677577747"}
0005432042789	480B7B	4059 716428	ANNA SEMENOVA	{"phone": "+70665845655"}
0005432042790	483495	7568 458000	LYUBOV KALININA	{"phone": "+70524866117"}
0005432042791	6AC191	8774 043850	YULIYA RYABOVA	{"phone": "+70356244842"}
0005432042792	F9FD9D	1178 934115	ALEKSEY ZAYCEV	{"phone": "+70523809759"}
0005432042793	2E35AC	2290 936131	ELENA MOROZOVA	{"email": "e.morozova.1975@postgrespro.ru", "phone": "+70174249041"}
0005432042794	43B453	3790 595559	ALEKSANDR MIRONOV	{"phone": "+70861895370"}
0005432042795	43B453	6510 194606	YULIYA SMIRNOVA	{"phone": "+70455328310"}
0005432042796	91474A	1192 471837	ALEKSANDR SHEVCHENKO	{"phone": "+70379737622"}
0005432042797	DB5F9D	6565 087034	SERGEY SCHERBAKOV	{"phone": "+70181908049"}
0005432042798	167AAF	2931 532132	OLGA ANDREEVA	{"email": "o_andreeva.28091971@postgrespro.ru", "phone": "+70882903054"}
0005432042799	51CD07	6934 574638	VLADISLAV SOKOLOV	{"email": "vladislavsokolov_121968@postgrespro.ru", "phone": "+70586174372"}
0005432042800	B6736C	3197 270119	OLGA ERMAKOVA	{"phone": "+70977377604"}
0005432042801	289966	9543 985493	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey051976@postgrespro.ru", "phone": "+70447678215"}
0005432042802	6026A6	5020 957428	DMITRIY KRASNOV	{"email": "krasnov.d.22091962@postgrespro.ru", "phone": "+70743314345"}
0005432042803	5105F2	1369 363085	ARINA KISELEVA	{"email": "kiselevaa.1971@postgrespro.ru", "phone": "+70405185312"}
0005432042804	16973F	5657 672690	RUSLAN GRIGOREV	{"phone": "+70178574820"}
0005432042805	0C26F9	7112 433784	NIKOLAY SCHERBAKOV	{"phone": "+70958753861"}
0005432042806	0C26F9	9337 980689	TATYANA ORLOVA	{"email": "t.orlova.111960@postgrespro.ru", "phone": "+70020452378"}
0005432042807	AE6605	7931 943522	RUSTAM ZHUKOV	{"email": "r_zhukov.1979@postgrespro.ru", "phone": "+70888015718"}
0005432042808	ECD181	1021 182171	ARTEM SCHERBAKOV	{"email": "scherbakov_a.1963@postgrespro.ru", "phone": "+70242577600"}
0005432042809	ECD181	8361 802397	VLADIMIR TIMOFEEV	{"email": "timofeev.v1983@postgrespro.ru", "phone": "+70006625452"}
0005432042810	F95843	3076 332911	TATYANA YUDINA	{"email": "yudina-t_1957@postgrespro.ru", "phone": "+70231969496"}
0005432042811	F95843	1524 296215	LYUDMILA MIRONOVA	{"email": "lyudmila_mironova29031967@postgrespro.ru", "phone": "+70465618201"}
0005432042812	6E28F5	1608 838795	YANA KUZNECOVA	{"email": "y.kuznecova051985@postgrespro.ru", "phone": "+70533284914"}
0005432042813	01819C	4323 368054	VITALIY MAKAROV	{"email": "vitaliy.makarov_031974@postgrespro.ru", "phone": "+70216881946"}
0005432042814	993FD2	8260 777068	ALEKSANDR GORBUNOV	{"email": "gorbunov_a.31101970@postgrespro.ru", "phone": "+70396432033"}
0005432042815	F0DC45	9045 222946	ALEKSEY ZHUKOV	{"email": "zhukov_aleksey.1987@postgrespro.ru", "phone": "+70097060903"}
0005432042816	EDFFE5	3701 767935	ALEKSEY ANDREEV	{"phone": "+70940870923"}
0005432042817	4904C0	7355 892263	VLADISLAV SCHERBAKOV	{"phone": "+70162117510"}
0005432042818	662FEC	4786 121385	MARIYA FOMINA	{"email": "mariya.fomina-07041975@postgrespro.ru", "phone": "+70371108966"}
0005432042819	0F0AB8	9400 981505	ALEKSEY KOZLOV	{"email": "a_kozlov.061972@postgrespro.ru", "phone": "+70767914069"}
0005432042820	783D67	7238 588076	ANATOLIY FEDOROV	{"email": "fedorov.anatoliy21011978@postgrespro.ru", "phone": "+70107790175"}
0005432042821	BDF89A	1980 863149	LYUDMILA TIKHONOVA	{"email": "lyudmila_tikhonova1965@postgrespro.ru", "phone": "+70923286078"}
0005432042822	02FA85	3958 885616	EVGENIY FEDOROV	{"phone": "+70166612645"}
0005432042823	02FA85	2501 180230	NAILYA CHERNOVA	{"phone": "+70030124340"}
0005432042824	1FAC4D	6619 435059	SERGEY IVANOV	{"phone": "+70215798272"}
0005432042825	5E862B	4276 902133	ALEKSEY SEMENOV	{"phone": "+70508889048"}
0005432042826	E8DD03	2559 975673	SVETLANA RODIONOVA	{"email": "rodionova_svetlana-04081983@postgrespro.ru", "phone": "+70727211512"}
0005432042827	A8A792	1380 427486	ANDREY FROLOV	{"phone": "+70533531362"}
0005432042828	A8A792	7380 053765	POLINA DAVYDOVA	{"email": "polina.davydova_04101981@postgrespro.ru", "phone": "+70078668955"}
0005432042829	78B980	1883 614854	YULIYA SOKOLOVA	{"email": "sokolovayuliya-1983@postgrespro.ru", "phone": "+70981887442"}
0005432042830	78B980	7927 251942	SVETLANA POPOVA	{"email": "svetlana.popova_091979@postgrespro.ru", "phone": "+70517874962"}
0005432042831	4F4E43	6442 129102	TATYANA FILIPPOVA	{"email": "filippovat.1976@postgrespro.ru", "phone": "+70949245911"}
0005432042832	5CE523	3800 491709	RUSLAN MIKHAYLOV	{"phone": "+70696311893"}
0005432042833	521D30	4649 148947	VLADIMIR TARASOV	{"phone": "+70804498148"}
0005432042834	31F059	8893 147791	LYUDMILA DANILOVA	{"phone": "+70859362513"}
0005432042835	036043	9817 318504	IRINA KOROLEVA	{"email": "koroleva-irina_1972@postgrespro.ru", "phone": "+70933543922"}
0005432042836	036043	2357 832508	VADIM SMIRNOV	{"email": "smirnov_v_031968@postgrespro.ru", "phone": "+70614458588"}
0005432042837	036043	2373 460190	MILANA POPOVA	{"phone": "+70610147764"}
0005432042838	28C408	3952 344229	EVDOKIYA MIKHAYLOVA	{"phone": "+70828043990"}
0005432042839	C1BE2B	1085 116647	NIKOLAY MELNIKOV	{"phone": "+70511304865"}
0005432042840	2E6DBD	0223 809660	SERGEY GAVRILOV	{"email": "sergeygavrilov07091971@postgrespro.ru", "phone": "+70457403249"}
0005432042841	B5B1AB	6105 018949	ANTONINA AKIMOVA	{"email": "antonina_akimova10061977@postgrespro.ru", "phone": "+70886917591"}
0005432042842	B5B1AB	3542 463893	KONSTANTIN ALEKSEEV	{"phone": "+70271645343"}
0005432042843	ABA426	1265 179282	IRINA NIKOLAEVA	{"phone": "+70975738957"}
0005432042844	B43DE5	9185 173058	OLGA FADEEVA	{"phone": "+70285623709"}
0005432042845	B43DE5	3768 658593	KIRILL KISELEV	{"email": "kiselev.k.101977@postgrespro.ru", "phone": "+70304130525"}
0005432042846	32A196	9942 974257	PAVEL KUZNECOV	{"phone": "+70495164603"}
0005432042847	32A196	5012 339730	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr.1978@postgrespro.ru", "phone": "+70575956184"}
0005432042848	3F4986	2423 594145	VALERIY SOKOLOV	{"phone": "+70895315081"}
0005432042849	215C7D	3172 605444	ZINAIDA MASLOVA	{"phone": "+70692440153"}
0005432042850	9D9F96	1691 712269	DENIS ZAYCEV	{"email": "denis.zaycev-06051967@postgrespro.ru", "phone": "+70569631424"}
0005432042851	9D9F96	8158 793164	VIKTOR ANDREEV	{"phone": "+70456799932"}
0005432042852	17B7B7	1901 800465	MARINA KUZNECOVA	{"email": "kuznecova-marina.121974@postgrespro.ru", "phone": "+70271696329"}
0005432042853	17B7B7	7606 550934	PAVEL GAVRILOV	{"phone": "+70829121883"}
0005432042854	CFB499	4341 733363	TAMARA SOLOVEVA	{"phone": "+70643708349"}
0005432042855	E7852B	7788 060852	ANDREY PAVLOV	{"email": "pavlov_andrey-051970@postgrespro.ru", "phone": "+70607182038"}
0005432042856	A4FBEB	6404 883286	NATALYA KOROLEVA	{"email": "natalya_koroleva-13041963@postgrespro.ru", "phone": "+70649628609"}
0005432042857	DF10A3	1567 498602	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova_1981@postgrespro.ru", "phone": "+70259003978"}
0005432042858	DF10A3	1760 598792	ANDREY ZAKHAROV	{"phone": "+70889010158"}
0005432042859	FE08AC	6303 725895	NIKOLAY DAVYDOV	{"email": "davydov-nikolay_07011974@postgrespro.ru", "phone": "+70826182638"}
0005432042860	2D891A	1148 480331	IRINA MAKAROVA	{"phone": "+70603789290"}
0005432042861	9ED5B8	3336 523738	MIKHAIL STEPANOV	{"email": "stepanov_mikhail-1971@postgrespro.ru", "phone": "+70143069513"}
0005432042862	9ED5B8	8608 239855	ROZA SCHERBAKOVA	{"phone": "+70869387467"}
0005432042863	D57FB6	5226 784236	SVETLANA ARKHIPOVA	{"phone": "+70136728724"}
0005432042864	C378A4	7969 781545	TATYANA MALYSHEVA	{"phone": "+70498203870"}
0005432042865	C378A4	2113 211180	LYUDMILA ISAEVA	{"email": "lyudmila-isaeva16021977@postgrespro.ru", "phone": "+70354026924"}
0005432042866	E6AACC	3046 097859	MIKHAIL FOMIN	{"email": "fomin-mikhail-1963@postgrespro.ru", "phone": "+70752630903"}
0005432042867	187804	4753 080371	MAKSIM KARPOV	{"email": "karpovm.111957@postgrespro.ru", "phone": "+70867015903"}
0005432042868	187804	5095 795362	VIKTORIYA TIKHONOVA	{"email": "viktoriya_tikhonova1971@postgrespro.ru", "phone": "+70575091205"}
0005432042869	0779F7	5280 214427	SERAFIMA ARKHIPOVA	{"phone": "+70253748018"}
0005432042870	0779F7	6052 938526	TATYANA FROLOVA	{"email": "frolova_tatyana.22101978@postgrespro.ru", "phone": "+70837608013"}
0005432042871	2CF7D8	2900 855556	VERA NIKIFOROVA	{"email": "nikiforovav.1978@postgrespro.ru", "phone": "+70483604983"}
0005432042872	E33AF9	7139 393278	YULIYA KUZNECOVA	{"phone": "+70782091565"}
0005432042873	E33AF9	2043 523542	FILIPP MAKSIMOV	{"phone": "+70071620584"}
0005432042874	806ED4	7056 850606	EVGENIY MAKAROV	{"email": "e-makarov_051985@postgrespro.ru", "phone": "+70700372357"}
0005432042875	A60F40	8605 207181	TAMARA SEMENOVA	{"phone": "+70636003623"}
0005432042876	A60F40	8072 056821	MAKSIM EGOROV	{"email": "egorov_maksim1965@postgrespro.ru", "phone": "+70236073293"}
0005432042877	232515	9715 290109	IVAN NOVIKOV	{"email": "novikov.i-12121966@postgrespro.ru", "phone": "+70809953309"}
0005432042878	E43CE0	7712 024099	ALEKSANDRA KOLESNIKOVA	{"email": "kolesnikova.aleksandra1972@postgrespro.ru", "phone": "+70215090250"}
0005432042879	91DF5C	3157 525251	YURIY KULIKOV	{"phone": "+70552681834"}
0005432042880	6A6A24	7422 034168	NINA KUZNECOVA	{"phone": "+70629715313"}
0005432042881	6A6A24	9663 650155	NIKOLAY GUSEV	{"phone": "+70315888423"}
0005432042882	6A6A24	1051 891840	ELENA ZAYCEVA	{"email": "elenazayceva-1980@postgrespro.ru", "phone": "+70332096199"}
0005432042883	9FE934	6775 558086	EKATERINA TROFIMOVA	{"email": "trofimova_e1974@postgrespro.ru", "phone": "+70282499457"}
0005432042884	EED258	6208 265671	SERGEY ANTONOV	{"email": "antonov.s-071965@postgrespro.ru", "phone": "+70162154803"}
0005432042885	4C5894	7079 797861	ANNA FILIPPOVA	{"phone": "+70127974102"}
0005432042886	4C5894	5255 015205	VIKTOR NAUMOV	{"email": "vnaumov.091963@postgrespro.ru", "phone": "+70433121056"}
0005432042887	79E159	9986 110654	KONSTANTIN CHERNOV	{"email": "konstantin.chernov.1968@postgrespro.ru", "phone": "+70652624609"}
0005432042888	79E159	4812 096981	DENIS MELNIKOV	{"email": "denis.melnikov-1980@postgrespro.ru", "phone": "+70907786829"}
0005432042889	B571C9	6191 507942	TATYANA KOROLEVA	{"phone": "+70506010635"}
0005432042890	B571C9	6805 953172	GALINA GORBUNOVA	{"phone": "+70482164807"}
0005432042891	2629E7	1897 746245	ELIZAVETA BELYAEVA	{"email": "e-belyaeva-071982@postgrespro.ru", "phone": "+70724476490"}
0005432042892	0BB46E	5644 548148	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr-11031970@postgrespro.ru", "phone": "+70094960029"}
0005432042893	0BB46E	1431 458303	ANNA KULIKOVA	{"phone": "+70757040268"}
0005432042894	6C6133	1954 623939	OLEG FROLOV	{"email": "ofrolov.021978@postgrespro.ru", "phone": "+70078267860"}
0005432042895	6C6133	9580 509537	MARIYA NIKOLAEVA	{"email": "mariyanikolaeva_1969@postgrespro.ru", "phone": "+70052888816"}
0005432042896	BECEAA	7502 091844	POLINA FILATOVA	{"phone": "+70143417186"}
0005432042897	B02FDB	5405 677108	VARVARA FILATOVA	{"email": "varvara.filatova-1980@postgrespro.ru", "phone": "+70371279011"}
0005432042898	B02FDB	3037 161067	NIKOLAY GAVRILOV	{"phone": "+70841802636"}
0005432042899	671DA0	7747 585818	ROMAN DMITRIEV	{"email": "dmitriev_roman-01091973@postgrespro.ru", "phone": "+70195899064"}
0005432042900	49A7AC	2928 467483	EKATERINA ZOTOVA	{"phone": "+70608882319"}
0005432042901	2C2FEC	7774 728304	SERGEY MELNIKOV	{"email": "melnikov_s_1970@postgrespro.ru", "phone": "+70062798369"}
0005432042902	0E6962	0769 490590	NINA MEDVEDEVA	{"phone": "+70119602400"}
0005432042903	D4E0D1	8788 624595	NINA MELNIKOVA	{"email": "nina-melnikova_1977@postgrespro.ru", "phone": "+70890226390"}
0005432042904	CE4F8B	0974 326774	IRINA SCHERBAKOVA	{"email": "scherbakovairina.10031979@postgrespro.ru", "phone": "+70843598450"}
0005432042905	D0421F	1410 482266	MARIYA POLYAKOVA	{"phone": "+70604713035"}
0005432042906	C72119	4406 518310	ILYA KOZLOV	{"email": "ikozlov.22071968@postgrespro.ru", "phone": "+70265319069"}
0005432042907	ED49BB	2475 214946	SOFYA STEPANOVA	{"phone": "+70091282694"}
0005432042908	9813CA	5351 011557	NATALYA KISELEVA	{"phone": "+70045952833"}
0005432042909	AA0EBF	4122 410909	VALENTINA SEMENOVA	{"email": "semenova_v-051963@postgrespro.ru", "phone": "+70705543389"}
0005432042910	AA0EBF	5312 731487	EVGENIY MATVEEV	{"email": "matveev_evgeniy.19071979@postgrespro.ru", "phone": "+70512461150"}
0005432042911	11B7A2	8787 244283	SERGEY MELNIKOV	{"email": "melnikov.sergey_031984@postgrespro.ru", "phone": "+70052780732"}
0005432042912	224479	1372 970476	ALEKSEY OSIPOV	{"email": "osipovaleksey1985@postgrespro.ru", "phone": "+70902178117"}
0005432042913	1966C5	1077 608181	VYACHESLAV MAKAROV	{"phone": "+70921837145"}
0005432042914	5459D5	3568 024430	BORIS SMIRNOV	{"phone": "+70617640204"}
0005432042915	03A29C	7862 342261	ALEKSEY ALEKSANDROV	{"phone": "+70272475750"}
0005432042916	66B26B	6679 328443	VIKTORIYA DAVYDOVA	{"phone": "+70221275020"}
0005432042975	15B674	6968 554506	GALINA SAVELEVA	{"phone": "+70586204166"}
0005432042917	66B26B	1573 922020	SHAMIL DMITRIEV	{"email": "dmitriev.shamil03021975@postgrespro.ru", "phone": "+70566455001"}
0005432042918	97B8F1	2673 345682	SVETLANA BELYAEVA	{"email": "belyaevasvetlana-041970@postgrespro.ru", "phone": "+70982596981"}
0005432042919	265962	3879 738185	ANTONINA MOROZOVA	{"email": "morozova.a-1972@postgrespro.ru", "phone": "+70587892407"}
0005432042920	807545	7554 145216	SERGEY SOKOLOV	{"email": "s-sokolov_21111967@postgrespro.ru", "phone": "+70878239105"}
0005432042921	0C84E9	1578 162385	NATALYA KISELEVA	{"phone": "+70773992035"}
0005432042922	5952A6	3104 404999	VALENTINA OSIPOVA	{"phone": "+70905405335"}
0005432042923	388989	1971 776601	VYACHESLAV TARASOV	{"email": "tarasov_v041980@postgrespro.ru", "phone": "+70460399292"}
0005432042924	6F9666	8144 075396	AYRAT ANDREEV	{"email": "andreev-a-1970@postgrespro.ru", "phone": "+70967321365"}
0005432042925	74C0FF	0781 129239	ILMIR SOLOVEV	{"phone": "+70934658067"}
0005432042926	74C0FF	0494 379088	OKSANA NESTEROVA	{"phone": "+70631261585"}
0005432042927	500FBE	4047 390018	DMITRIY ANTONOV	{"email": "dmitriyantonov-1971@postgrespro.ru", "phone": "+70368905743"}
0005432042928	81B477	8767 596303	MARINA TIKHONOVA	{"phone": "+70540900570"}
0005432043095	04D5FA	4364 195913	NATALYA POPOVA	{"phone": "+70668701817"}
0005432042929	3DCBB9	9538 489847	MARGARITA ALEKSEEVA	{"email": "alekseeva.m031971@postgrespro.ru", "phone": "+70608941502"}
0005432042930	0881AC	1942 218503	ZOYA POPOVA	{"email": "popova-zoya.21051982@postgrespro.ru", "phone": "+70913640971"}
0005432042931	0881AC	5363 153386	ANDREY STEPANOV	{"email": "andrey-stepanov121971@postgrespro.ru", "phone": "+70191833604"}
0005432042932	74315C	7590 991073	SERGEY DMITRIEV	{"email": "sergey.dmitriev.02091973@postgrespro.ru", "phone": "+70797701923"}
0005432042933	7E2A36	1437 781432	ALEKSEY IVANOV	{"phone": "+70249026078"}
0005432042934	6B704A	9777 919531	ELENA FILATOVA	{"email": "e.filatova.071974@postgrespro.ru", "phone": "+70527685665"}
0005432042935	AFEBCE	3051 746082	ANTONINA SOKOLOVA	{"email": "antoninasokolova_11121964@postgrespro.ru", "phone": "+70788183668"}
0005432042936	6790A1	9024 011309	EKATERINA TIMOFEEVA	{"phone": "+70330704294"}
0005432042937	6790A1	3425 808464	VADIM NOVIKOV	{"email": "v_novikov-10041975@postgrespro.ru", "phone": "+70997304151"}
0005432042938	9C5BD5	5956 070308	VASILIY ORLOV	{"phone": "+70916764368"}
0005432042939	9C5BD5	0742 866028	VALENTINA FROLOVA	{"email": "frolova-valentina-09121971@postgrespro.ru", "phone": "+70054706929"}
0005432042940	BBC1E3	4816 768952	DMITRIY SERGEEV	{"email": "dsergeev-01101959@postgrespro.ru", "phone": "+70097013102"}
0005432042941	5B36FF	3476 779126	IGOR PETROV	{"email": "petrov.i-21111968@postgrespro.ru", "phone": "+70703809501"}
0005432042942	4D8399	1720 957849	VASILIY MELNIKOV	{"phone": "+70473612294"}
0005432042943	669C19	1713 680062	IVAN TIMOFEEV	{"phone": "+70706879051"}
0005432042944	EF0A4B	8532 189526	GALINA RODIONOVA	{"phone": "+70106240922"}
0005432042945	0C8527	5337 823684	EVGENIYA CHERNOVA	{"phone": "+70693562216"}
0005432042946	E31EC7	2978 503791	TATYANA RODIONOVA	{"email": "rodionovat_15111964@postgrespro.ru", "phone": "+70119564198"}
0005432042947	BCF6A5	6944 639237	NIKOLAY SIDOROV	{"phone": "+70060078054"}
0005432042948	D9CFD4	2949 695710	SERGEY KISELEV	{"email": "kiselev-s-1966@postgrespro.ru", "phone": "+70251331109"}
0005432042949	17BDE1	2768 723711	VALERIY CHERNOV	{"email": "chernov-valeriy-121975@postgrespro.ru", "phone": "+70769831744"}
0005432042950	77EFFB	5411 110890	ALEKSANDR OSIPOV	{"email": "a-osipov101978@postgrespro.ru", "phone": "+70811497602"}
0005432042951	77EFFB	3917 790773	TATYANA TIKHONOVA	{"email": "t.tikhonova_1971@postgrespro.ru", "phone": "+70517247428"}
0005432042952	0B2FDC	1274 540914	DENIS IVANOV	{"email": "denis_ivanov12011970@postgrespro.ru", "phone": "+70990769291"}
0005432042953	0B2FDC	6799 748951	DENIS PETROV	{"email": "petrov_denis_071977@postgrespro.ru", "phone": "+70306522646"}
0005432042954	6780DC	4495 171859	YURIY POPOV	{"phone": "+70986096455"}
0005432042955	B33C33	7313 402360	NADEZHDA KOROLEVA	{"email": "koroleva-nadezhda1976@postgrespro.ru", "phone": "+70822761549"}
0005432042956	B33C33	7843 989459	LIDIYA VASILEVA	{"email": "vasileva.lidiya-06061964@postgrespro.ru", "phone": "+70088160284"}
0005432042957	51C401	4527 248066	SVETLANA NESTEROVA	{"phone": "+70515324375"}
0005432042958	184586	3813 602658	SOFYA MALYSHEVA	{"phone": "+70725256908"}
0005432042959	6BF4A5	2222 716356	VIKTOR ALEKSANDROV	{"phone": "+70574035377"}
0005432042960	6FD672	5931 510153	ALINA SOKOLOVA	{"email": "a-sokolova-06101976@postgrespro.ru", "phone": "+70640670402"}
0005432042961	C150F0	9155 475875	ELENA KAZAKOVA	{"email": "kazakova_elena_11071967@postgrespro.ru", "phone": "+70395253946"}
0005432042962	635A82	0121 020818	GRIGORIY KUZNECOV	{"email": "kuznecov_g-10061965@postgrespro.ru", "phone": "+70427246514"}
0005432042963	635A82	2841 191700	OLEG SEMENOV	{"phone": "+70277253442"}
0005432042964	DCD0FB	5368 395922	ILYA VOLKOV	{"email": "ilyavolkov19041975@postgrespro.ru", "phone": "+70578829088"}
0005432042965	DCD0FB	5529 126280	SERGEY VOLKOV	{"phone": "+70271597276"}
0005432042966	538384	1049 315022	MARIYA SOROKINA	{"email": "sorokina-mariya.1969@postgrespro.ru", "phone": "+70419765673"}
0005432042967	538384	5528 587621	SVETLANA FOMINA	{"email": "sfomina.061970@postgrespro.ru", "phone": "+70956348841"}
0005432042968	7414CE	7122 085441	MARINA MOROZOVA	{"phone": "+70987531486"}
0005432042969	06BBFF	2959 298131	VADIM TIKHONOV	{"email": "vadim_tikhonov_061978@postgrespro.ru", "phone": "+70664694380"}
0005432042970	06BBFF	7129 177772	OLGA TROFIMOVA	{"phone": "+70096201831"}
0005432042971	0EE092	4996 226934	EVGENIY DAVYDOV	{"email": "davydov-evgeniy.041979@postgrespro.ru", "phone": "+70884840103"}
0005432042972	138E98	0208 679529	ELENA TIMOFEEVA	{"phone": "+70679849963"}
0005432042973	55EFD0	5179 719183	MARINA IVANOVA	{"email": "marina.ivanova041969@postgrespro.ru", "phone": "+70349729866"}
0005432042974	4A9A4B	5606 017266	NADEZHDA MAKAROVA	{"phone": "+70035903930"}
0005432042976	15B674	0961 884027	GALINA MIRONOVA	{"phone": "+70288227729"}
0005432042977	B176AD	3160 334624	LYUBOV ORLOVA	{"email": "l.orlova-05051964@postgrespro.ru", "phone": "+70729124742"}
0005432042978	18ECFF	5081 623687	EVGENIY MAKAROV	{"phone": "+70136843679"}
0005432042979	18ECFF	1547 392645	EVGENIY EGOROV	{"email": "evgeniy.egorov-01111970@postgrespro.ru", "phone": "+70096872950"}
0005432042980	6553AB	9551 210164	VIKTOR ANTONOV	{"email": "v.antonov_18081962@postgrespro.ru", "phone": "+70332233099"}
0005432042981	8D9B6F	7127 339821	ANNA ERMAKOVA	{"email": "ermakova.a_051967@postgrespro.ru", "phone": "+70186203310"}
0005432042982	8D9B6F	2678 280352	DAMIR SCHERBAKOV	{"phone": "+70929984065"}
0005432042983	193AC5	6023 105645	ALEKSEY ANTONOV	{"phone": "+70487478109"}
0005432042984	193AC5	6813 653712	MAKSIM VASILEV	{"email": "vasilev-maksim_101982@postgrespro.ru", "phone": "+70459762849"}
0005432042985	6C0E2C	7491 778713	PAVEL VOLKOV	{"phone": "+70815393444"}
0005432042986	399375	4882 054045	NATALYA KISELEVA	{"email": "natalya.kiseleva_1968@postgrespro.ru", "phone": "+70477111070"}
0005432042987	9D1DBC	5997 355762	VYACHESLAV MAKAROV	{"phone": "+70799472522"}
0005432042988	9D1DBC	2183 045993	MATVEY KUZNECOV	{"phone": "+70032292443"}
0005432042989	9D1DBC	4149 237447	VLADIMIR OSIPOV	{"email": "v_osipov_12071970@postgrespro.ru", "phone": "+70078063329"}
0005432042990	FFC495	6751 034414	ALEKSANDR FEDOROV	{"phone": "+70087059346"}
0005432042991	FFC495	9172 874555	ALEKSANDR VASILEV	{"email": "vasilev.a_1964@postgrespro.ru", "phone": "+70306117494"}
0005432042992	C9FBCC	5620 395088	ANATOLIY KONOVALOV	{"email": "anatoliykonovalov061970@postgrespro.ru", "phone": "+70490837118"}
0005432042993	B0DB7A	4306 649563	DMITRIY NOVIKOV	{"email": "novikov-d.121978@postgrespro.ru", "phone": "+70265204507"}
0005432042994	E9BB1B	3988 963086	ANATOLIY KUDRYASHOV	{"email": "kudryashov-anatoliy_1969@postgrespro.ru", "phone": "+70949692747"}
0005432042995	475D4C	7676 158602	VASILIY TARASOV	{"email": "tarasov-v.03041980@postgrespro.ru", "phone": "+70321122158"}
0005432042996	9A7D53	1282 094820	VIKTORIYA SCHERBAKOVA	{"phone": "+70413561607"}
0005432042997	5C5106	5957 171890	IRINA MIKHAYLOVA	{"email": "irina.mikhaylova-071971@postgrespro.ru", "phone": "+70504068324"}
0005432042998	5C5106	7722 048987	VLADIMIR SERGEEV	{"phone": "+70792343946"}
0005432042999	2394A4	3467 622939	YURIY KUZMIN	{"phone": "+70985743491"}
0005432043000	2394A4	9487 391387	NADEZHDA BARANOVA	{"email": "n-baranova05091974@postgrespro.ru", "phone": "+70732186404"}
0005432043001	2394A4	0668 528296	TATYANA FADEEVA	{"email": "tatyana.fadeeva_18121974@postgrespro.ru", "phone": "+70956855392"}
0005432043002	DCC546	1496 068957	TATYANA KUDRYASHOVA	{"email": "kudryashova_tatyana.25081967@postgrespro.ru", "phone": "+70096585148"}
0005432043003	C387F6	0314 372717	DENIS SOROKIN	{"phone": "+70343190643"}
0005432043004	F161A5	1761 710794	NATALYA FADEEVA	{"email": "fadeeva_natalya13071969@postgrespro.ru", "phone": "+70059429857"}
0005432043005	F161A5	7379 395961	MIKHAIL DMITRIEV	{"phone": "+70079431451"}
0005432043006	9BA648	4530 430427	SOFYA MIKHAYLOVA	{"email": "sofyamikhaylova24111962@postgrespro.ru", "phone": "+70341642760"}
0005432043007	9BA648	6374 076316	IVAN SAVELEV	{"email": "isavelev.17011960@postgrespro.ru", "phone": "+70672434573"}
0005432043008	9BA648	4203 291285	NADEZHDA SCHERBAKOVA	{"email": "n.scherbakova_12071963@postgrespro.ru", "phone": "+70837908572"}
0005432043009	234836	9881 317365	GALINA MOROZOVA	{"email": "galina-morozova.1965@postgrespro.ru", "phone": "+70672944052"}
0005432043010	ECCF3F	3799 293272	VYACHESLAV MIKHAYLOV	{"email": "vyacheslav-mikhaylov-1963@postgrespro.ru", "phone": "+70871425216"}
0005432043011	ECCF3F	0187 552938	VLADIMIR VOLKOV	{"email": "volkovv.04091980@postgrespro.ru", "phone": "+70564596630"}
0005432043012	044065	1313 001032	VALENTINA IVANOVA	{"email": "ivanova.v-31051977@postgrespro.ru", "phone": "+70626179184"}
0005432043013	14E0CB	2228 883161	NATALIYA ANDREEVA	{"email": "nataliyaandreeva_17011969@postgrespro.ru", "phone": "+70867206973"}
0005432043014	7A85DF	6754 076863	VIKTOR SMIRNOV	{"email": "viktor-smirnov11101965@postgrespro.ru", "phone": "+70166517533"}
0005432043015	7A85DF	1965 404047	IRINA MATVEEVA	{"email": "matveeva_irina-121978@postgrespro.ru", "phone": "+70138725204"}
0005432043016	EA2335	0201 963302	ALEKSANDR MIRONOV	{"phone": "+70280633786"}
0005432043017	AE51E8	9988 721994	KRISTINA SIDOROVA	{"email": "sidorova-k-031979@postgrespro.ru", "phone": "+70310267683"}
0005432043018	71973A	1423 969343	ALEKSANDR MAKSIMOV	{"phone": "+70353184600"}
0005432043019	90C2B9	4614 478214	ANNA DANILOVA	{"email": "danilova.anna1969@postgrespro.ru", "phone": "+70417680294"}
0005432043020	2241F1	7726 868805	SERGEY ANTONOV	{"phone": "+70551037432"}
0005432043021	2241F1	7843 055882	ALEKSANDR MIRONOV	{"email": "mironovaleksandr_01081977@postgrespro.ru", "phone": "+70282198292"}
0005432043022	2241F1	5517 252909	ILYAS KUZNECOV	{"email": "i_kuznecov.11021972@postgrespro.ru", "phone": "+70678569000"}
0005432043023	87170B	7024 905855	VLADIMIR CHERNOV	{"phone": "+70120608599"}
0005432043024	87170B	7868 490555	ANGELINA DANILOVA	{"phone": "+70977794726"}
0005432043025	B4238F	2177 098210	VASILIY ANTONOV	{"email": "antonovv01021965@postgrespro.ru", "phone": "+70322376881"}
0005432043026	CB2A0E	1077 064057	MARAT TIMOFEEV	{"email": "m-timofeev091978@postgrespro.ru", "phone": "+70841457985"}
0005432043027	63AF8C	3001 894875	GEORGIY OSIPOV	{"email": "g_osipov.121971@postgrespro.ru", "phone": "+70780540125"}
0005432043028	B66A40	2964 066922	KONSTANTIN GRIGOREV	{"email": "grigorev_konstantin_041975@postgrespro.ru", "phone": "+70942479198"}
0005432043029	C6F108	5392 198385	MARAT STEPANOV	{"email": "stepanovmarat-1963@postgrespro.ru", "phone": "+70683640713"}
0005432043030	42C715	8553 291902	NIKOLAY EGOROV	{"phone": "+70159451367"}
0005432043031	42C715	1647 989205	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr-1975@postgrespro.ru", "phone": "+70366534673"}
0005432043032	9CF629	5691 206873	IVAN VOLKOV	{"phone": "+70298353622"}
0005432043033	9CF629	7748 329959	VIKTORIYA SERGEEVA	{"email": "viktoriya_sergeeva.071972@postgrespro.ru", "phone": "+70527515354"}
0005432043034	20AE3D	0678 750555	VIKTORIYA KULIKOVA	{"phone": "+70225962622"}
0005432043035	19DD8F	2856 680855	DMITRIY SEMENOV	{"phone": "+70922746207"}
0005432043036	7A36CB	9591 414981	LIDIYA ZAKHAROVA	{"email": "zakharoval-091968@postgrespro.ru", "phone": "+70369871786"}
0005432043037	7A36CB	9599 745645	MAKSIM FEDOROV	{"email": "fedorov-maksim_081965@postgrespro.ru", "phone": "+70026145807"}
0005432043038	2FDC26	9191 584184	NIKOLAY KUZNECOV	{"email": "n_kuznecov.1970@postgrespro.ru", "phone": "+70620483280"}
0005432043039	9A9C16	1020 865947	OLGA MIRONOVA	{"email": "o_mironova_1978@postgrespro.ru", "phone": "+70908566476"}
0005432043040	9A9C16	1329 075727	ANASTASIYA FADEEVA	{"phone": "+70150460799"}
0005432043041	5A0B3A	2798 164300	OLGA TIMOFEEVA	{"phone": "+70880294278"}
0005432043042	EFE964	5260 593020	SERGEY KUZNECOV	{"phone": "+70312051610"}
0005432043043	B75683	5823 323535	EVGENIY SOROKIN	{"email": "evgeniy_sorokin.1970@postgrespro.ru", "phone": "+70696685451"}
0005432043044	B75683	9842 755218	RAFIK BONDARENKO	{"phone": "+70817369926"}
0005432043045	5C0DEE	2251 263548	OLGA ROMANOVA	{"email": "olgaromanova.071970@postgrespro.ru", "phone": "+70755190657"}
0005432043046	75C38F	4860 291833	SERGEY BELOV	{"phone": "+70175699278"}
0005432043047	75C38F	7040 832223	TAMARA DMITRIEVA	{"email": "dmitrievat_1980@postgrespro.ru", "phone": "+70429215480"}
0005432043048	5DFCD7	9668 290148	SEMEN SMIRNOV	{"phone": "+70462974439"}
0005432043049	5DFCD7	0350 221644	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr.021954@postgrespro.ru", "phone": "+70071384078"}
0005432043050	C539AB	7296 619653	NADEZHDA DANILOVA	{"phone": "+70929664673"}
0005432043051	C539AB	8375 131798	LYUBOV KISELEVA	{"phone": "+70447969428"}
0005432043052	EF221A	0780 600650	DMITRIY YAKOVLEV	{"email": "yakovlev.d.30101958@postgrespro.ru", "phone": "+70261321811"}
0005432043053	EF221A	2466 489687	ELENA KOLESNIKOVA	{"email": "elena.kolesnikova.021982@postgrespro.ru", "phone": "+70162826822"}
0005432043054	594850	8149 782972	LIYA NIKITINA	{"phone": "+70702751961"}
0005432043055	85AD01	1211 679295	VLADIMIR VOROBEV	{"email": "vorobev_vladimir_101966@postgrespro.ru", "phone": "+70519150108"}
0005432043056	85AD01	6711 731707	ANDREY BORISOV	{"email": "a_borisov_1972@postgrespro.ru", "phone": "+70048414420"}
0005432043057	85AD01	1199 145881	DMITRIY GERASIMOV	{"email": "d_gerasimov-27021975@postgrespro.ru", "phone": "+70021485563"}
0005432043058	A012C5	6813 437259	VERA ZAKHAROVA	{"email": "vera.zakharova_1962@postgrespro.ru", "phone": "+70763435341"}
0005432043059	A68D4E	2765 838943	SERGEY VLASOV	{"email": "vlasovsergey.24061969@postgrespro.ru", "phone": "+70019585758"}
0005432043060	A68D4E	7387 603113	ELMIRA GERASIMOVA	{"phone": "+70527223305"}
0005432043061	A68D4E	8004 782043	ALEKSEY IVANOV	{"phone": "+70655966333"}
0005432043062	FBBDD4	3149 929159	ELENA MAKAROVA	{"email": "elenamakarova.10031965@postgrespro.ru", "phone": "+70038460657"}
0005432043063	E7E8E9	6664 598433	MARINA TITOVA	{"phone": "+70003026556"}
0005432043064	496975	6922 625742	VIKTOR STEPANOV	{"email": "vstepanov_081981@postgrespro.ru", "phone": "+70773918420"}
0005432043065	D61D0E	0903 599202	DMITRIY FEDOROV	{"email": "dmitriy.fedorov-1975@postgrespro.ru", "phone": "+70336118598"}
0005432043066	82B64E	6259 825964	RINAT KUDRYASHOV	{"phone": "+70117507090"}
0005432043067	47482D	6908 104188	ELVIRA BELYAEVA	{"phone": "+70486305476"}
0005432043068	905359	8692 291993	ZINAIDA TARASOVA	{"phone": "+70073616914"}
0005432043069	905359	9645 948574	LEONID SHEVCHENKO	{"email": "shevchenko_l-1956@postgrespro.ru", "phone": "+70577158516"}
0005432043070	45B8DC	2093 751830	SVETLANA KUDRYASHOVA	{"email": "kudryashova-s.1966@postgrespro.ru", "phone": "+70391990054"}
0005432043071	45B8DC	9712 925495	ALEKSANDR FEDOROV	{"phone": "+70869783330"}
0005432043072	9A51E0	9455 651478	EVGENIY ZHUKOV	{"phone": "+70429733299"}
0005432043073	9A51E0	3125 086780	PAVEL EGOROV	{"phone": "+70927938138"}
0005432043074	0756D1	2768 568672	ANDREY MAKSIMOV	{"email": "maksimov_andrey17061964@postgrespro.ru", "phone": "+70594484829"}
0005432043075	0756D1	2028 015104	ELENA GRISHINA	{"phone": "+70159751386"}
0005432043076	F9AB00	9406 515715	LYUDMILA STEPANOVA	{"phone": "+70949933719"}
0005432043077	254862	5075 044176	LYUBOV KOMAROVA	{"phone": "+70158656750"}
0005432043078	9A02B7	5010 017188	MAKSIM ALEKSEEV	{"email": "m.alekseev_121968@postgrespro.ru", "phone": "+70657243691"}
0005432043079	DBCC42	1399 215886	VALENTINA POTAPOVA	{"email": "v_potapova-1979@postgrespro.ru", "phone": "+70558089630"}
0005432043080	B04DE9	6774 864306	EVGENIYA FEDOROVA	{"phone": "+70182620373"}
0005432043081	FC1A3A	6249 897589	EGOR DAVYDOV	{"phone": "+70857359362"}
0005432043082	FC1A3A	5603 253209	ELENA STEPANOVA	{"email": "elena-stepanova-051970@postgrespro.ru", "phone": "+70132477102"}
0005432043083	082467	1212 858861	VLADIMIR ABRAMOV	{"phone": "+70121517483"}
0005432043084	11E23B	6977 060444	ANATOLIY VLASOV	{"email": "anatoliy_vlasov.031971@postgrespro.ru", "phone": "+70806404081"}
0005432043085	BDA325	4996 569148	OLEG VOLKOV	{"email": "volkov_oleg_1968@postgrespro.ru", "phone": "+70293452940"}
0005432043086	96B2BC	9758 014720	LYUBOV ABRAMOVA	{"email": "abramoval_1961@postgrespro.ru", "phone": "+70311631687"}
0005432043087	319821	6713 462473	ANNA AFANASEVA	{"phone": "+70968317511"}
0005432043088	319821	4847 980152	NINA DENISOVA	{"phone": "+70801532826"}
0005432043089	1E6B85	0989 896944	VLADIMIR KULIKOV	{"phone": "+70892558237"}
0005432043090	1E6B85	5618 345274	EKATERINA ANISIMOVA	{"phone": "+70941507183"}
0005432043091	1F13A6	2173 419374	GENNADIY VOROBEV	{"phone": "+70917025323"}
0005432043092	1F13A6	8847 747896	OLGA IVANOVA	{"email": "ivanova-o.08061980@postgrespro.ru", "phone": "+70579252437"}
0005432043093	9BCA70	3037 578520	DMITRIY MAKAROV	{"email": "dmakarov_1979@postgrespro.ru", "phone": "+70822978654"}
0005432043094	EBEA93	0244 872274	SEMEN RODIONOV	{"phone": "+70986346840"}
0005432043096	04D5FA	0847 523928	DMITRIY MIKHAYLOV	{"email": "dmitriymikhaylov1968@postgrespro.ru", "phone": "+70301483571"}
0005432043097	1B84A0	9619 104230	OLEG MEDVEDEV	{"email": "olegmedvedev_041968@postgrespro.ru", "phone": "+70186258860"}
0005432043098	1B84A0	9443 506813	YANA GORBUNOVA	{"email": "ygorbunova.1968@postgrespro.ru", "phone": "+70601847170"}
0005432043099	6B83DA	4613 382518	ZUKHRA EGOROVA	{"phone": "+70421924017"}
0005432043100	6B83DA	6537 133406	ARTEM ALEKSEEV	{"email": "aalekseev_031967@postgrespro.ru", "phone": "+70687419811"}
0005432043101	6B83DA	5520 963539	ANNA BELYAEVA	{"email": "belyaeva-a-22111969@postgrespro.ru", "phone": "+70587198608"}
0005432043102	2BF216	6427 356674	NADEZHDA KULIKOVA	{"email": "kulikova-nadezhda_081983@postgrespro.ru", "phone": "+70154636989"}
0005432043103	2446AB	1664 519476	VLADIMIR GERASIMOV	{"email": "vladimirgerasimov-1980@postgrespro.ru", "phone": "+70503510700"}
0005432043104	9A4FC3	3417 622934	DMITRIY PETROV	{"email": "petrov.dmitriy-051969@postgrespro.ru", "phone": "+70987590020"}
0005432043105	08613E	9079 999760	YURIY TARASOV	{"phone": "+70346449174"}
0005432043106	B1D38E	7041 371071	PAVEL MIRONOV	{"email": "pavel.mironov.1967@postgrespro.ru", "phone": "+70740427414"}
0005432043107	F526F1	7572 616266	TATYANA KAZAKOVA	{"email": "kazakova_t051966@postgrespro.ru", "phone": "+70973813500"}
0005432043108	59929A	9572 208011	ANNA POPOVA	{"email": "anna.popova-1973@postgrespro.ru", "phone": "+70502766695"}
0005432043109	5D00D5	6024 757333	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev1971@postgrespro.ru", "phone": "+70008925929"}
0005432043110	5D00D5	0280 970475	ELENA SMIRNOVA	{"phone": "+70014171641"}
0005432043111	4FB253	4351 327450	SERGEY GERASIMOV	{"phone": "+70733154115"}
0005432043112	BEE29C	5992 752750	DARYA FADEEVA	{"email": "darya-fadeeva_25111972@postgrespro.ru", "phone": "+70631505062"}
0005432043113	291BF3	2356 050784	DMITRIY MEDVEDEV	{"email": "medvedev.d_031963@postgrespro.ru", "phone": "+70482909922"}
0005432043114	7D563E	9432 129585	OLGA KOZLOVA	{"phone": "+70534974287"}
0005432043115	83B0C5	5414 067682	ANATOLIY MIRONOV	{"email": "a_mironov.21031977@postgrespro.ru", "phone": "+70219787983"}
0005432043116	75EF9D	7809 952670	LYUDMILA RODIONOVA	{"phone": "+70502864464"}
0005432043117	918E7E	8093 668129	VIKTOR FEDOROV	{"email": "vfedorov.111970@postgrespro.ru", "phone": "+70890731288"}
0005432043118	918E7E	7001 484247	ELENA ABRAMOVA	{"email": "eabramova10031972@postgrespro.ru", "phone": "+70099855235"}
0005432043119	12D311	8919 849086	GALINA NIKOLAEVA	{"phone": "+70035106829"}
0005432043120	B2F3A1	1385 504383	NATALYA MOROZOVA	{"email": "natalya.morozova-29051982@postgrespro.ru", "phone": "+70008380885"}
0005432043121	77AB7A	1463 446305	VALERIYA ZAKHAROVA	{"email": "valeriya.zakharova-041971@postgrespro.ru", "phone": "+70010905317"}
0005432043122	77AB7A	9693 613219	SOFYA DMITRIEVA	{"email": "dmitrieva_s07071983@postgrespro.ru", "phone": "+70852287796"}
0005432043123	86538C	1930 562263	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.22071974@postgrespro.ru", "phone": "+70859751850"}
0005432043124	86538C	6893 069308	AYRAT BELOV	{"email": "ayrat-belov-09081970@postgrespro.ru", "phone": "+70098786024"}
0005432043125	E2C8F8	0434 957713	ALEKSANDRA MALYSHEVA	{"email": "amalysheva.021986@postgrespro.ru", "phone": "+70761170058"}
0005432043126	78AA6F	4424 189455	YURIY DAVYDOV	{"phone": "+70691711563"}
0005432043127	661CF4	8019 121669	VALERIY ALEKSEEV	{"email": "alekseev-v_1973@postgrespro.ru", "phone": "+70053890729"}
0005432043128	0D7F7D	2401 073538	TATYANA DENISOVA	{"email": "tatyana-denisova.18031981@postgrespro.ru", "phone": "+70903428543"}
0005432043129	0D7F7D	7305 786301	GALINA NIKOLAEVA	{"email": "galinanikolaeva.081976@postgrespro.ru", "phone": "+70627798332"}
0005432043130	39FB78	3959 371873	MIKHAIL SCHERBAKOV	{"email": "mikhail-scherbakov_1970@postgrespro.ru", "phone": "+70133618238"}
0005432043131	D548D9	6901 823410	MATRENA PETROVA	{"phone": "+70096343015"}
0005432043132	D548D9	6226 810991	ANTONINA BELOVA	{"email": "antonina-belova_1979@postgrespro.ru", "phone": "+70222599398"}
0005432043133	563191	5845 669104	MARIYA GERASIMOVA	{"email": "gerasimova_mariya.09021965@postgrespro.ru", "phone": "+70380978255"}
0005432043134	4AB9C4	2474 899353	VIKTOR IVANOV	{"email": "ivanov_viktor031972@postgrespro.ru", "phone": "+70277435585"}
0005432043135	4AB9C4	2465 784841	ALEKSANDR MEDVEDEV	{"phone": "+70203157476"}
0005432044541	5B4942	1584 190802	EVGENIYA BELOVA	{"phone": "+70502221700"}
0005432044475	7E9055	7252 612275	VYACHESLAV SAVELEV	{"email": "savelev_vyacheslav1967@postgrespro.ru", "phone": "+70251141791"}
0005432044476	DBCC79	2431 512351	DIANA POLYAKOVA	{"phone": "+70646998333"}
0005432044477	DBCC79	6193 247851	VYACHESLAV KRASNOV	{"email": "vyacheslav.krasnov.28081967@postgrespro.ru", "phone": "+70058741317"}
0005432044478	E0DDC4	1434 262450	NATALYA ARKHIPOVA	{"email": "n_arkhipova.1975@postgrespro.ru", "phone": "+70140593644"}
0005432044479	CF0430	5184 491755	MATVEY STEPANOV	{"phone": "+70871208463"}
0005432044480	E1666E	5644 736629	YULIYA ZHUKOVA	{"email": "zhukova.y.121964@postgrespro.ru", "phone": "+70516410857"}
0005432044481	0764C9	6904 739431	ANATOLIY TIKHONOV	{"email": "tikhonov.a.21121978@postgrespro.ru", "phone": "+70175493651"}
0005432044482	0764C9	5350 160380	NADEZHDA MAKAROVA	{"email": "n_makarova.021981@postgrespro.ru", "phone": "+70599543921"}
0005432044483	0D6822	2824 228159	ANNA DENISOVA	{"email": "a.denisova071972@postgrespro.ru", "phone": "+70612119245"}
0005432044484	63C4E1	0830 153427	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir-28021969@postgrespro.ru", "phone": "+70463312719"}
0005432044485	63C4E1	3343 633663	YURIY ZHURAVLEV	{"email": "yuriy_zhuravlev-1969@postgrespro.ru", "phone": "+70351040970"}
0005432044486	D1B737	3109 858072	SERGEY IVANOV	{"email": "ivanov.sergey_1969@postgrespro.ru", "phone": "+70773283636"}
0005432044487	EDD456	3914 215260	MIKHAIL GORBUNOV	{"phone": "+70888093616"}
0005432044488	8D49D4	5609 349050	RAIS DAVYDOV	{"phone": "+70493756397"}
0005432044489	F8E9CB	7108 259443	SERGEY IVANOV	{"email": "s_ivanov.081976@postgrespro.ru", "phone": "+70054633934"}
0005432044490	58E403	0585 196805	DMITRIY SOLOVEV	{"email": "d-solovev_031966@postgrespro.ru", "phone": "+70815908870"}
0005432044491	58E403	5569 452908	LYUDMILA ORLOVA	{"phone": "+70612536939"}
0005432044492	EE6FD0	3339 979433	SERGEY MARTYNOV	{"email": "martynovsergey-1981@postgrespro.ru", "phone": "+70250108165"}
0005432044493	EE6FD0	7889 201635	VLADIMIR ALEKSEEV	{"phone": "+70053064744"}
0005432044494	EFAF83	2303 954398	LYUBOV IVANOVA	{"email": "lyubovivanova_1976@postgrespro.ru", "phone": "+70943759094"}
0005432044495	E21536	8090 168270	YULIYA SMIRNOVA	{"phone": "+70869285993"}
0005432044496	4C6253	5006 828549	LYUBOV SIDOROVA	{"email": "sidorova_lyubov19101985@postgrespro.ru", "phone": "+70453195263"}
0005432044497	7C60C9	8247 454879	NATALYA KUZNECOVA	{"phone": "+70525295890"}
0005432044498	CD438F	4769 980808	VLADISLAV VLASOV	{"email": "vladislavvlasov.021976@postgrespro.ru", "phone": "+70422684826"}
0005432044499	A48CD3	6464 786614	ALEKSEY MAKAROV	{"email": "makarov_a.09121968@postgrespro.ru", "phone": "+70828519780"}
0005432044500	3F0E20	3073 223400	ALEKSANDR SOLOVEV	{"phone": "+70744057693"}
0005432044501	379176	4722 781063	ANDREY MIRONOV	{"email": "a-mironov_1963@postgrespro.ru", "phone": "+70806661756"}
0005432044502	FF231D	5474 222333	NADEZHDA NIKITINA	{"email": "nikitina.n.13051961@postgrespro.ru", "phone": "+70604461881"}
0005432044503	FF231D	1663 050572	TAISIYA ANTONOVA	{"email": "t-antonova_1984@postgrespro.ru", "phone": "+70578929792"}
0005432044504	E680A1	2670 789827	NIKOLAY ZAKHAROV	{"phone": "+70242798920"}
0005432044505	CA1061	1917 875234	ANNA ZHUKOVA	{"email": "a_zhukova-04081977@postgrespro.ru", "phone": "+70667497494"}
0005432044506	222814	5548 849905	NIKOLAY MATVEEV	{"phone": "+70293540299"}
0005432044507	FD808D	2582 279856	GALINA MAKAROVA	{"email": "gmakarova-021979@postgrespro.ru", "phone": "+70803381098"}
0005432044508	FD808D	6716 677067	EVGENIYA ZHUKOVA	{"email": "zhukovaevgeniya_081968@postgrespro.ru", "phone": "+70775919312"}
0005432044509	BE4EC5	7578 050658	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr30041968@postgrespro.ru", "phone": "+70797722100"}
0005432044510	AE2DE2	4761 651371	DANILA PETROV	{"email": "danilapetrov-061973@postgrespro.ru", "phone": "+70978610873"}
0005432044511	AE2DE2	7743 853231	VITALIY KUDRYASHOV	{"email": "kudryashov_v-28101969@postgrespro.ru", "phone": "+70090271022"}
0005432044512	C9BA16	2956 119331	VYACHESLAV STEPANOV	{"email": "vstepanov17101972@postgrespro.ru", "phone": "+70587786926"}
0005432044513	C9BA16	3162 289494	TATYANA DMITRIEVA	{"email": "dmitrievat.071973@postgrespro.ru", "phone": "+70217283517"}
0005432044514	52232C	0148 504915	ALEKSEY VOROBEV	{"phone": "+70203125642"}
0005432044515	1440C0	3578 192118	NINA IVANOVA	{"phone": "+70004103329"}
0005432044516	1440C0	6391 023831	KRISTINA ROMANOVA	{"phone": "+70649317395"}
0005432044517	3AC727	0790 631609	ZOYA ANDREEVA	{"phone": "+70613140023"}
0005432044518	B28BA4	0461 465053	LYUDMILA FEDOROVA	{"phone": "+70105759882"}
0005432044519	86F143	3546 504499	EKATERINA GORBUNOVA	{"phone": "+70861505262"}
0005432044520	CD33CE	4629 055089	KSENIYA NAUMOVA	{"email": "naumova.kseniya.031968@postgrespro.ru", "phone": "+70977992220"}
0005432044521	66FB2B	2570 650621	PAVEL IVANOV	{"phone": "+70477004730"}
0005432044522	66FB2B	0646 737917	GALIYA KONDRATEVA	{"email": "kondratevagaliya-13081975@postgrespro.ru", "phone": "+70528365047"}
0005432044523	E6E26B	3909 834537	NINA ANISIMOVA	{"phone": "+70861802061"}
0005432044524	CF566F	8064 845839	VERA VOLKOVA	{"email": "v.volkova_02081964@postgrespro.ru", "phone": "+70826490877"}
0005432044525	9F4419	5860 115826	ANATOLIY ANDREEV	{"email": "anatoliyandreev.011965@postgrespro.ru", "phone": "+70757334504"}
0005432044526	FA8C42	1136 483412	MAKSIM MELNIKOV	{"phone": "+70671770813"}
0005432044527	6A44F8	6164 967730	VASILIY MAKAROV	{"phone": "+70239972118"}
0005432044528	6A44F8	5963 517833	SVETLANA SIDOROVA	{"email": "svetlana.sidorova_1971@postgrespro.ru", "phone": "+70345250755"}
0005432044529	688E45	1386 429532	SVETLANA EFIMOVA	{"email": "efimova-svetlana061976@postgrespro.ru", "phone": "+70595053304"}
0005432044530	71F3BD	4905 011943	LYUBOV IVANOVA	{"phone": "+70589528202"}
0005432044531	71F3BD	4272 255187	LYUDMILA KUZMINA	{"phone": "+70179558785"}
0005432044532	3DC8B9	0031 274389	ALEKSEY TARASOV	{"phone": "+70644768852"}
0005432044533	3DC8B9	3860 918446	ANASTASIYA KRASNOVA	{"phone": "+70429862998"}
0005432044534	39FC80	7417 465493	SERGEY SOKOLOV	{"phone": "+70912549632"}
0005432044535	0E2205	3617 201493	EVGENIY BARANOV	{"email": "e.baranov-1978@postgrespro.ru", "phone": "+70375291729"}
0005432044536	55258C	8575 354553	ALEKSANDRA DENISOVA	{"phone": "+70393843129"}
0005432044537	55258C	1805 548223	TAISIYA MOROZOVA	{"email": "t.morozova.1977@postgrespro.ru", "phone": "+70652215248"}
0005432044538	55258C	1979 864870	MIKHAIL KUZNECOV	{"email": "mkuznecov021963@postgrespro.ru", "phone": "+70867048275"}
0005432044539	27E198	2376 999210	GALINA ROMANOVA	{"phone": "+70258010156"}
0005432044540	AF240F	9155 571184	NATALYA RYABOVA	{"email": "ryabovanatalya.021973@postgrespro.ru", "phone": "+70867069016"}
0005432044542	E6A1F0	8615 179001	ELINA ZAYCEVA	{"phone": "+70747270333"}
0005432044543	0FA53E	1592 753114	OLGA ALEKSEEVA	{"phone": "+70106112155"}
0005432044544	35E3CE	4149 000808	ANNA LAZAREVA	{"email": "annalazareva.031970@postgrespro.ru", "phone": "+70840258582"}
0005432044545	D13527	3352 410373	LEONID GORBUNOV	{"phone": "+70200068688"}
0005432044546	D13527	6934 462721	YANA BOGDANOVA	{"email": "bogdanovay.1965@postgrespro.ru", "phone": "+70264042709"}
0005432044547	01515B	9025 529251	RAISA NIKOLAEVA	{"email": "raisa.nikolaeva14031979@postgrespro.ru", "phone": "+70239119637"}
0005432044548	325386	0496 946852	ALLA SOROKINA	{"phone": "+70707899189"}
0005432044549	325386	5983 837414	SVETLANA KULIKOVA	{"email": "s_kulikova-121966@postgrespro.ru", "phone": "+70028223331"}
0005432044550	055684	5286 888572	ALEKSANDRA LEBEDEVA	{"email": "aleksandra_lebedeva_1969@postgrespro.ru", "phone": "+70591991588"}
0005432044551	AF08D0	6087 730353	ALBERT KOZLOV	{"phone": "+70130664120"}
0005432044552	D5524C	0362 689821	DENIS MAKAROV	{"email": "makarovdenis1967@postgrespro.ru", "phone": "+70297168259"}
0005432044553	407285	2036 936298	VERA KOLESNIKOVA	{"email": "kolesnikova.vera.07121966@postgrespro.ru", "phone": "+70140253507"}
0005432044554	407285	8007 182278	RAVZA POTAPOVA	{"phone": "+70190371974"}
0005432044555	836B0E	4221 011139	DARYA PAVLOVA	{"phone": "+70950141228"}
0005432044556	B7CD95	6423 379910	NATALYA AKIMOVA	{"email": "akimova_natalya.1969@postgrespro.ru", "phone": "+70490595306"}
0005432044557	FC9823	0807 893196	ALEKSANDR MOROZOV	{"email": "morozovaleksandr_1970@postgrespro.ru", "phone": "+70830461131"}
0005432044558	C8C68B	7910 758843	TATYANA FROLOVA	{"phone": "+70114511938"}
0005432044559	27958E	2005 190574	SERGEY VOROBEV	{"phone": "+70473949825"}
0005432044560	7F9F71	5616 824840	LYUDMILA MOISEEVA	{"email": "lyudmilamoiseeva071947@postgrespro.ru", "phone": "+70968616515"}
0005432044561	46D394	1263 287458	ALEKSEY MOISEEV	{"email": "moiseeva_1976@postgrespro.ru", "phone": "+70330663969"}
0005432044562	112C62	2200 996212	IRINA KOROLEVA	{"email": "irina_koroleva-1968@postgrespro.ru", "phone": "+70436228552"}
0005432044563	112C62	8398 938570	ALEKSANDR KOZLOV	{"phone": "+70813075179"}
0005432044564	AB9FE3	6786 549399	EVDOKIYA VASILEVA	{"email": "evdokiya.vasileva041971@postgrespro.ru", "phone": "+70326012466"}
0005432044565	E032B6	7731 727421	SERGEY KUZNECOV	{"phone": "+70781508405"}
0005432044566	E032B6	5760 977715	MARIYA PETROVA	{"email": "petrovam_1965@postgrespro.ru", "phone": "+70421940201"}
0005432044567	13FA1F	1065 613883	TAMARA KUZNECOVA	{"email": "kuznecova-t.1969@postgrespro.ru", "phone": "+70631511203"}
0005432044568	87F412	4052 579292	RINAT YAKOVLEV	{"email": "yakovlev_rinat1962@postgrespro.ru", "phone": "+70126336484"}
0005432044569	87F412	9818 995472	ALEKSANDR MIRONOV	{"phone": "+70000033614"}
0005432044570	D87A6E	0310 131277	VIKTOR TIMOFEEV	{"phone": "+70196750245"}
0005432044571	D87A6E	7494 729987	OLGA ZAKHAROVA	{"email": "olga_zakharova_1974@postgrespro.ru", "phone": "+70612308006"}
0005432044572	9D5A8D	3071 479905	DMITRIY ISAEV	{"email": "isaevdmitriy1973@postgrespro.ru", "phone": "+70620049567"}
0005432044573	9D5A8D	9233 655610	VERA ROMANOVA	{"email": "v.romanova1986@postgrespro.ru", "phone": "+70909067488"}
0005432044574	9D5A8D	9971 790188	NINA IVANOVA	{"phone": "+70480976072"}
0005432044575	1B631D	3281 131216	SVETLANA ANTONOVA	{"email": "antonovas.121973@postgrespro.ru", "phone": "+70066390691"}
0005432044576	1B631D	6137 258573	VIKTOR VLASOV	{"email": "v.vlasov_1972@postgrespro.ru", "phone": "+70165045626"}
0005432044577	4B664F	3813 323019	YULIYA KOROLEVA	{"phone": "+70283020834"}
0005432044578	4B664F	4989 097932	ALEKSEY KUZMIN	{"phone": "+70418731099"}
0005432044579	E20E71	3535 410332	ARTEM SIDOROV	{"phone": "+70396475227"}
0005432044580	E20E71	8119 955399	MARIYA TARASOVA	{"email": "mtarasova1966@postgrespro.ru", "phone": "+70578844893"}
0005432044581	0132F3	2805 856777	ALEKSANDRA NIKIFOROVA	{"phone": "+70331621146"}
0005432044582	2A53D8	2537 614617	VALENTIN BORISOV	{"phone": "+70103221065"}
0005432044583	2A53D8	4775 934040	ALINA CHERNOVA	{"email": "alina.chernova.1976@postgrespro.ru", "phone": "+70951458500"}
0005432044584	FE801B	3293 704035	ARTEM ALEKSANDROV	{"phone": "+70085611365"}
0005432044585	B6252C	4622 587028	NATALYA TARASOVA	{"email": "tarasovanatalya_29081978@postgrespro.ru", "phone": "+70443825601"}
0005432044586	B6252C	3959 395609	OLGA IVANOVA	{"phone": "+70419989828"}
0005432044587	D63E2A	3196 565190	VLADIMIR FOMIN	{"phone": "+70252685931"}
0005432044588	D63E2A	0997 136750	IGOR KUZMIN	{"email": "ikuzmin_071974@postgrespro.ru", "phone": "+70210693457"}
0005432044589	0D5087	5077 007903	OLGA BORISOVA	{"phone": "+70816407365"}
0005432044590	D79C07	4505 062099	OLGA GRISHINA	{"phone": "+70463227330"}
0005432044591	B4E504	9389 057064	ARTEM ANTONOV	{"phone": "+70451034926"}
0005432044592	0F8F2A	0376 040107	SERGEY TIMOFEEV	{"phone": "+70143925509"}
0005432044593	50F2AF	0332 997211	ANNA IVANOVA	{"email": "ivanova.a-031967@postgrespro.ru", "phone": "+70349737528"}
0005432044594	38622B	7469 386226	ANASTASIYA BELOVA	{"email": "a_belova.20051970@postgrespro.ru", "phone": "+70885767741"}
0005432044595	38622B	6765 076132	ALISA BORISOVA	{"phone": "+70044001761"}
0005432044596	7A13C8	7629 500868	KRISTINA ANISIMOVA	{"phone": "+70275984266"}
0005432044597	688B35	6369 869581	BOGDAN ZAKHAROV	{"phone": "+70308896277"}
0005432044598	C3BBD9	8716 128243	ELVIRA ANDREEVA	{"email": "e_andreeva_1972@postgrespro.ru", "phone": "+70984446583"}
0005432044599	72D89A	1062 223075	IRINA SEMENOVA	{"phone": "+70334791804"}
0005432044600	72D89A	0937 762152	ALEKSANDR AFANASEV	{"email": "afanaseva_1971@postgrespro.ru", "phone": "+70634063927"}
0005432044601	9656E8	1298 815985	SERGEY NAUMOV	{"email": "naumov.s_111978@postgrespro.ru", "phone": "+70840671524"}
0005432044602	6F0D74	3219 047520	FANIL ALEKSANDROV	{"phone": "+70559579288"}
0005432044603	6F0D74	6149 651108	POLINA VOLKOVA	{"email": "pvolkova-061979@postgrespro.ru", "phone": "+70638765535"}
0005432044604	4120F7	9348 317161	ELENA KUZNECOVA	{"email": "kuznecovaelena_101971@postgrespro.ru", "phone": "+70524966890"}
0005432044605	C5346F	5698 569445	NATALYA ROMANOVA	{"phone": "+70954226236"}
0005432044606	480AFA	3229 056033	SERGEY VLASOV	{"phone": "+70690850415"}
0005432044607	A94EA5	5569 693050	ALEKSANDR AFANASEV	{"phone": "+70764388081"}
0005432044608	F04A3B	2573 476546	ANASTASIYA KULIKOVA	{"phone": "+70656521616"}
0005432044609	F04A3B	4818 010647	VALERIY MIKHAYLOV	{"email": "mikhaylov_v-091976@postgrespro.ru", "phone": "+70025916564"}
0005432045579	CB0014	6771 809141	DMITRIY GERASIMOV	{"email": "gerasimov-d28111964@postgrespro.ru", "phone": "+70623705147"}
0005432045580	EE71BD	7180 541477	VYACHESLAV ALEKSEEV	{"phone": "+70667979872"}
0005432045581	EE71BD	0336 110039	KSENIYA KAZAKOVA	{"email": "k.kazakova-051982@postgrespro.ru", "phone": "+70900936264"}
0005432045582	04952D	3518 255418	ELENA RYABOVA	{"email": "eryabova31121968@postgrespro.ru", "phone": "+70716806735"}
0005432045583	04952D	6977 604418	ZOYA SOKOLOVA	{"phone": "+70570101613"}
0005432045584	9185F5	7812 274232	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev-16061968@postgrespro.ru", "phone": "+70113366373"}
0005432045585	BF8F98	6621 331716	POLINA SOLOVEVA	{"email": "p_soloveva-1966@postgrespro.ru", "phone": "+70171093502"}
0005432045586	AF5A4F	6501 838745	DENIS KULIKOV	{"email": "dkulikov111973@postgrespro.ru", "phone": "+70053658844"}
0005432045587	8E684A	3060 091311	ZOYA LAZAREVA	{"email": "z-lazareva.121987@postgrespro.ru", "phone": "+70422777370"}
0005432045588	BC71B9	6952 662108	EVGENIY ILIN	{"email": "ilin-e1966@postgrespro.ru", "phone": "+70015918862"}
0005432045589	7F09B7	2301 893328	POLINA KUZNECOVA	{"phone": "+70585753910"}
0005432045590	F1191D	2296 044381	LYUBOV NAUMOVA	{"phone": "+70343703658"}
0005432045591	F1191D	2624 028920	DARYA KUZMINA	{"email": "kuzmina.d-101979@postgrespro.ru", "phone": "+70925895642"}
0005432045592	477FBD	8827 398405	ANDREY MELNIKOV	{"phone": "+70374293178"}
0005432045593	E0716D	0749 563509	STEPAN ZAKHAROV	{"email": "zakharov-stepan-011970@postgrespro.ru", "phone": "+70845525016"}
0005432045594	E0716D	5791 469501	GALINA IVANOVA	{"email": "ivanovag_101969@postgrespro.ru", "phone": "+70993339328"}
0005432045595	E0716D	0481 028569	YURIY CHERNOV	{"email": "chernov.yuriy.121969@postgrespro.ru", "phone": "+70545419506"}
0005432045596	192E78	1863 700219	RAMIL VOLKOV	{"email": "volkov_r-031986@postgrespro.ru", "phone": "+70996270384"}
0005432045597	192E78	5781 829751	LYUBOV NIKIFOROVA	{"phone": "+70789103051"}
0005432045598	C885AC	3201 441381	EKATERINA ISAEVA	{"email": "e.isaeva.1974@postgrespro.ru", "phone": "+70721660510"}
0005432045599	1E5F1B	4012 644235	IRINA NOVIKOVA	{"email": "novikova.i-1966@postgrespro.ru", "phone": "+70736950482"}
0005432045600	1E5F1B	1056 891292	EVGENIY BORISOV	{"email": "borisov-e-021977@postgrespro.ru", "phone": "+70738638447"}
0005432045601	EC8F15	3433 758311	VLADIMIR STEPANOV	{"email": "stepanovv07101964@postgrespro.ru", "phone": "+70355073621"}
0005432045602	EC8F15	3535 633980	MAKSIM SOKOLOV	{"email": "sokolovmaksim-1966@postgrespro.ru", "phone": "+70520940057"}
0005432045603	EC8F15	0026 391561	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr-13091964@postgrespro.ru", "phone": "+70232483773"}
0005432045604	BBB3B7	4931 309899	YULIYA ABRAMOVA	{"phone": "+70943604191"}
0005432045605	AE5C47	9831 987471	KIRILL NIKOLAEV	{"email": "k-nikolaev-041962@postgrespro.ru", "phone": "+70733770146"}
0005432045606	C19232	0773 180845	YAROSLAV MOROZOV	{"email": "morozov_y.061959@postgrespro.ru", "phone": "+70853765616"}
0005432045607	C19232	2882 462182	ALBERT POPOV	{"email": "albert-popov.061979@postgrespro.ru", "phone": "+70477792955"}
0005432045608	378231	7721 538498	ALEKSANDR DMITRIEV	{"email": "aleksandrdmitriev-011974@postgrespro.ru", "phone": "+70467403358"}
0005432045609	378231	9977 512518	ILYA ALEKSEEV	{"phone": "+70744874324"}
0005432045610	CC5F55	0307 918010	ELIZAVETA LUKYANOVA	{"email": "elukyanova05031968@postgrespro.ru", "phone": "+70529313234"}
0005432045611	9283A4	6645 394105	IVAN NIKITIN	{"phone": "+70427047778"}
0005432045612	9283A4	2049 926686	EVGENIY TIMOFEEV	{"email": "e_timofeev1969@postgrespro.ru", "phone": "+70787417168"}
0005432045613	0C1A9B	7836 316227	IRINA KISELEVA	{"email": "kiseleva.irina.09061989@postgrespro.ru", "phone": "+70701550123"}
0005432045614	0C1A9B	0724 616367	NATALYA ABRAMOVA	{"email": "n-abramova.011970@postgrespro.ru", "phone": "+70415530587"}
0005432045615	A2AB5F	1996 891772	ANDREY MOISEEV	{"phone": "+70102945880"}
0005432045616	A2AB5F	5566 151384	VLADIMIR KOZLOV	{"email": "v.kozlov_1973@postgrespro.ru", "phone": "+70778757230"}
0005432045617	12276B	2060 954349	RUSLAN PAVLOV	{"phone": "+70212803491"}
0005432045618	9D9FDA	3344 363749	NINA KUZNECOVA	{"email": "n_kuznecova_031978@postgrespro.ru", "phone": "+70772327178"}
0005432045619	68E7F5	1746 782616	NATALYA KUZNECOVA	{"email": "natalyakuznecova_1972@postgrespro.ru", "phone": "+70506221870"}
0005432045620	68E7F5	5872 082876	VLADIMIR CHERNOV	{"phone": "+70947538965"}
0005432045621	219ECF	2505 231318	NATALYA DANILOVA	{"email": "danilova_natalya_17061969@postgrespro.ru", "phone": "+70843130067"}
0005432045622	219ECF	8526 559112	IRINA BORISOVA	{"email": "i_borisova-16101974@postgrespro.ru", "phone": "+70971789433"}
0005432045623	0D87B9	2861 430714	MIKHAIL IVANOV	{"email": "ivanov.mikhail1976@postgrespro.ru", "phone": "+70182937986"}
0005432045624	5681EF	5478 104763	ALEKSANDR MIRONOV	{"phone": "+70259167378"}
0005432045625	F50379	5285 529271	ROMAN KAZAKOV	{"email": "r.kazakov1976@postgrespro.ru", "phone": "+70575001233"}
0005432045626	8DF2FB	0622 357227	RENAT TIKHONOV	{"email": "r_tikhonov.051982@postgrespro.ru", "phone": "+70818027042"}
0005432045627	8DF2FB	1516 037634	VALERIYA SERGEEVA	{"email": "valeriya-sergeeva.12081970@postgrespro.ru", "phone": "+70506874698"}
0005432045628	BE2DBC	9453 926554	SERGEY SHEVCHENKO	{"phone": "+70866612709"}
0005432045629	BE2DBC	6015 455839	MARINA DAVYDOVA	{"email": "davydova-m.04071972@postgrespro.ru", "phone": "+70804934609"}
0005432045630	FF1C52	2925 008486	ELIZAVETA GORBUNOVA	{"phone": "+70343127089"}
0005432045631	E56367	9966 779431	ANDREY BORISOV	{"email": "borisov_andrey1983@postgrespro.ru", "phone": "+70299132755"}
0005432045632	B54C26	0191 105933	EKATERINA POTAPOVA	{"email": "potapova-e-1983@postgrespro.ru", "phone": "+70605453536"}
0005432045633	451411	4489 140068	LARISA BELOVA	{"email": "larisa.belova-18051968@postgrespro.ru", "phone": "+70145280415"}
0005432045634	5EF3E3	1564 787327	EVGENIY NIKITIN	{"phone": "+70761421909"}
0005432045635	EB160A	9334 651528	ALEKSANDR IVANOV	{"email": "aivanov-21041955@postgrespro.ru", "phone": "+70161860891"}
0005432045636	E1DDC9	5453 343824	ALEKSANDR YAKOVLEV	{"phone": "+70683015100"}
0005432045637	E1DDC9	1339 927510	IGOR POPOV	{"phone": "+70221847735"}
0005432045638	F2C75A	4291 471889	ALEKSEY SIDOROV	{"phone": "+70536367216"}
0005432045639	F2C75A	0689 971581	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov.01011975@postgrespro.ru", "phone": "+70134835979"}
0005432045640	7F6869	3647 935805	ANTONINA AFANASEVA	{"email": "afanasevaantonina_02091970@postgrespro.ru", "phone": "+70194932533"}
0005432045641	7F6869	2404 775799	EVGENIY SEMENOV	{"email": "semenov.e121973@postgrespro.ru", "phone": "+70706807026"}
0005432045642	2A624E	6871 938875	ELENA LAZAREVA	{"email": "elena-lazareva1980@postgrespro.ru", "phone": "+70570752030"}
0005432045643	A8D9FD	8925 278733	ALEKSEY BONDARENKO	{"email": "a_bondarenko_121973@postgrespro.ru", "phone": "+70629356689"}
0005432045644	E8584E	6507 626172	SERGEY VOLKOV	{"phone": "+70615022375"}
0005432045645	8F9C75	9480 408619	MARIYA BELOVA	{"email": "belova_mariya_25021973@postgrespro.ru", "phone": "+70465234478"}
0005432045646	8F9EB8	0082 558908	OLGA GUSEVA	{"email": "oguseva.011964@postgrespro.ru", "phone": "+70055427451"}
0005432045647	72F691	2953 899988	NATALYA ZHURAVLEVA	{"phone": "+70869861383"}
0005432045648	3E0C36	2614 972927	ELVIRA TIKHONOVA	{"phone": "+70737527168"}
0005432045649	3E0C36	5197 978752	IRINA SOROKINA	{"phone": "+70312972105"}
0005432045650	BC54C9	9764 849898	TATYANA IVANOVA	{"phone": "+70558344141"}
0005432045651	BEA6EA	9149 617937	VITALIY KOROLEV	{"phone": "+70359592326"}
0005432045652	7ED128	2324 070031	DMITRIY KUZNECOV	{"email": "d_kuznecov.1974@postgrespro.ru", "phone": "+70559447765"}
0005432045653	9B2FB5	1050 069733	OLESYA TROFIMOVA	{"phone": "+70122299074"}
0005432045654	E1836A	3166 310935	KSENIYA LOGINOVA	{"email": "loginovakseniya.1966@postgrespro.ru", "phone": "+70346809251"}
0005432045655	AA19AF	5086 454311	IGOR KAZAKOV	{"email": "kazakov_i-05031990@postgrespro.ru", "phone": "+70064571093"}
0005432045656	5EEFD3	7466 432624	IRINA ARKHIPOVA	{"email": "irina.arkhipova.1970@postgrespro.ru", "phone": "+70110240238"}
0005432045657	BD918C	2549 792057	NIKOLAY EGOROV	{"phone": "+70287090203"}
0005432045658	03DAB0	8024 456578	DMITRIY POPOV	{"email": "popov.d111972@postgrespro.ru", "phone": "+70388829367"}
0005432045659	07008E	4476 785703	RUSLAN IVANOV	{"phone": "+70852403123"}
0005432045660	07008E	1642 493688	VIKTOR MAKAROV	{"phone": "+70753254439"}
0005432045661	07008E	8898 035777	ALEKSANDR IVANOV	{"phone": "+70369127862"}
0005432045662	0215AD	7164 199607	OKSANA FILATOVA	{"phone": "+70693158312"}
0005432045663	BE8478	3090 310197	TATYANA OSIPOVA	{"phone": "+70428430619"}
0005432045664	C96BBA	4683 600957	IRINA KRASNOVA	{"phone": "+70995632834"}
0005432045665	978995	6245 650785	ALEKSANDR KRASNOV	{"phone": "+70936274950"}
0005432045666	978995	9293 136846	POLINA FADEEVA	{"phone": "+70825672013"}
0005432045667	6D0907	3169 854577	ARINA ZAKHAROVA	{"phone": "+70796399816"}
0005432045668	6D0907	5893 155979	OLGA KOZLOVA	{"phone": "+70036998222"}
0005432045669	5BF6A4	1181 472309	KLARA NESTEROVA	{"email": "nesterova-klara.081956@postgrespro.ru", "phone": "+70278537869"}
0005432045670	7D9E87	7695 262261	ANNA PETROVA	{"email": "a_petrova-1976@postgrespro.ru", "phone": "+70479109452"}
0005432047484	A3F4BE	9883 426439	LEYLA EGOROVA	{"email": "egorova.leyla-1968@postgrespro.ru", "phone": "+70986161507"}
0005432047485	A3F4BE	7161 136328	MARAT MELNIKOV	{"email": "mmelnikov-03041964@postgrespro.ru", "phone": "+70643465959"}
0005432047486	520075	0156 889595	YULIYA KULIKOVA	{"phone": "+70903776229"}
0005432047487	C69406	5066 494220	ANNA MAKSIMOVA	{"email": "maksimova_anna.06101968@postgrespro.ru", "phone": "+70022217976"}
0005432047488	C69406	1474 576670	MIKHAIL VLASOV	{"email": "vlasov.mikhail_1975@postgrespro.ru", "phone": "+70688151624"}
0005432047489	A247AF	0864 931948	OLGA ZHURAVLEVA	{"email": "zhuravlevao-031974@postgrespro.ru", "phone": "+70727043027"}
0005432047490	88C6D9	1699 870274	EGOR KAZAKOV	{"phone": "+70728105537"}
0005432047491	88C6D9	0902 649631	ELENA KOROLEVA	{"phone": "+70424999574"}
0005432047492	D25744	8170 374895	ANASTASIYA GERASIMOVA	{"email": "gerasimovaanastasiya_1965@postgrespro.ru", "phone": "+70745293777"}
0005432047493	54D74C	9389 256093	SERGEY MAKAROV	{"email": "makarov-sergey-1972@postgrespro.ru", "phone": "+70036342372"}
0005432047494	54D74C	6558 819381	ANATOLIY ZHURAVLEV	{"email": "anatoliyzhuravlev.1972@postgrespro.ru", "phone": "+70001492537"}
0005432047495	B71BA7	5338 550879	ALEKSEY POPOV	{"phone": "+70617532958"}
0005432047496	AD9A1F	8219 089462	GULFIYA GORBUNOVA	{"email": "gorbunova_gulfiya.25101982@postgrespro.ru", "phone": "+70967149835"}
0005432047497	48F34F	1578 277672	ARTEM ALEKSEEV	{"phone": "+70521378419"}
0005432047498	39B50A	9906 209539	ANDREY IVANOV	{"phone": "+70788087586"}
0005432047499	39B50A	4981 410854	IVAN KUDRYASHOV	{"phone": "+70609596448"}
0005432047500	015BD3	8371 642326	OLEG SERGEEV	{"phone": "+70974893517"}
0005432047501	015BD3	3611 340784	BORIS MEDVEDEV	{"phone": "+70560896919"}
0005432047502	2AFE48	2193 169429	ANASTASIYA SEMENOVA	{"email": "semenova-a_1970@postgrespro.ru", "phone": "+70178934638"}
0005432047503	2AFE48	6236 734276	ANDREY KONOVALOV	{"phone": "+70976798013"}
0005432047504	0E25CD	8460 882068	KIRILL STEPANOV	{"phone": "+70665289965"}
0005432047505	0E25CD	1844 100328	SERGEY GRIGOREV	{"email": "sergey-grigorev.27011958@postgrespro.ru", "phone": "+70946878970"}
0005432047506	2F9BC9	2585 701490	OLGA KUZNECOVA	{"phone": "+70836105821"}
0005432047507	2F9BC9	3073 018125	VALENTINA RODIONOVA	{"email": "v.rodionova-22011960@postgrespro.ru", "phone": "+70204033387"}
0005432047508	E053CF	6599 306877	DENIS DENISOV	{"phone": "+70254635177"}
0005432047509	01A2AE	2066 932331	SERGEY VASILEV	{"phone": "+70657763917"}
0005432047510	91EF2B	1103 170977	VLADIMIR MEDVEDEV	{"phone": "+70202980796"}
0005432047511	91EF2B	6087 485012	NIKOLAY KRASNOV	{"phone": "+70183103144"}
0005432047512	F7DD81	9831 100789	ANDREY MOISEEV	{"phone": "+70577964009"}
0005432047513	520C96	4060 329093	ALEKSANDRA ZHURAVLEVA	{"email": "zhuravleva.a081972@postgrespro.ru", "phone": "+70303769550"}
0005432047514	520C96	6650 225797	VIKTOR ABRAMOV	{"email": "abramovv111976@postgrespro.ru", "phone": "+70422552994"}
0005432047515	573975	4584 572541	ALEKSANDR ALEKSANDROV	{"phone": "+70162136785"}
0005432047516	573975	8343 774832	MARIYA YUDINA	{"email": "yudina-mariya.051966@postgrespro.ru", "phone": "+70275000906"}
0005432047517	70A037	5444 081435	ALINA MIKHAYLOVA	{"email": "alina_mikhaylova-04081966@postgrespro.ru", "phone": "+70990623710"}
0005432047518	66213F	4326 654557	VERA SERGEEVA	{"email": "vera.sergeeva-1963@postgrespro.ru", "phone": "+70641340007"}
0005432047519	F3E44F	4830 957842	NIKOLAY ANTONOV	{"email": "antonov.n1978@postgrespro.ru", "phone": "+70416800885"}
0005432047520	37FF7B	1978 491332	TATYANA ARKHIPOVA	{"phone": "+70056421970"}
0005432047521	F7D5FB	4763 010289	NADEZHDA MARTYNOVA	{"phone": "+70239409343"}
0005432047522	F7D5FB	0974 364052	YULIYA VOROBEVA	{"phone": "+70060920046"}
0005432047523	C78B91	8477 631194	ANNA MOISEEVA	{"phone": "+70435737938"}
0005432047524	F6FEC3	7504 029540	MIKHAIL VASILEV	{"phone": "+70600758714"}
0005432047525	994C31	6228 014753	ANTONINA TARASOVA	{"phone": "+70808278698"}
0005432047526	994C31	2125 330052	ALEKSEY KARPOV	{"email": "karpov-aleksey.111974@postgrespro.ru", "phone": "+70267769466"}
0005432047527	08F831	2125 191321	TATYANA SEMENOVA	{"email": "tatyana.semenova-1965@postgrespro.ru", "phone": "+70750787367"}
0005432047528	04347A	9708 510731	TATYANA LAZAREVA	{"phone": "+70292194520"}
0005432047529	E608A8	0193 066810	TAMARA RODIONOVA	{"email": "rodionova.tamara111969@postgrespro.ru", "phone": "+70694806218"}
0005432047530	F30EE4	5807 244757	TATYANA ANISIMOVA	{"email": "anisimova.t011967@postgrespro.ru", "phone": "+70012644577"}
0005432047531	F4FE3F	4471 401740	YULIYA IVANOVA	{"email": "yuliyaivanova.1967@postgrespro.ru", "phone": "+70380764433"}
0005432047532	3F7320	4646 778627	ANATOLIY KUZMIN	{"phone": "+70236167539"}
0005432047533	FC5A65	9739 614532	VYACHESLAV NIKOLAEV	{"email": "vyacheslav_nikolaev02041974@postgrespro.ru", "phone": "+70651836844"}
0005432047534	59FA64	5044 567569	PAVEL SOLOVEV	{"email": "psolovev061980@postgrespro.ru", "phone": "+70789019828"}
0005432047535	8DBC37	6720 804998	ALEKSANDR DENISOV	{"phone": "+70215276258"}
0005432047536	3F8597	7094 365064	ALEKSANDRA POPOVA	{"phone": "+70463022662"}
0005432047537	F0FF6C	7760 598717	NIKOLAY FILIPPOV	{"phone": "+70120440267"}
0005432047538	F0FF6C	8631 343015	MARINA ABRAMOVA	{"phone": "+70675511801"}
0005432047539	F4B87C	8203 353517	OLEG SIDOROV	{"email": "oleg-sidorov101964@postgrespro.ru", "phone": "+70647916224"}
0005432047540	692691	2521 341175	MARIYA VASILEVA	{"phone": "+70113196483"}
0005432047541	692691	6107 282674	NINA KOROLEVA	{"email": "n_koroleva1974@postgrespro.ru", "phone": "+70556015328"}
0005432047542	692691	7679 879645	GENNADIY MATVEEV	{"phone": "+70005698082"}
0005432047543	FE858D	1702 390568	VALENTINA KUZMINA	{"phone": "+70039424341"}
0005432047544	FE858D	0794 991226	ALEKSEY ZHURAVLEV	{"email": "aleksey.zhuravlev021963@postgrespro.ru", "phone": "+70714236019"}
0005432047545	0838F5	3947 395491	DMITRIY KONOVALOV	{"phone": "+70376937000"}
0005432047546	199C77	8228 661483	TAMARA NIKOLAEVA	{"phone": "+70870562903"}
0005432047547	4EF3B3	0688 386053	EKATERINA ROMANOVA	{"phone": "+70261459478"}
0005432047548	04EE68	8438 717060	ALEKSEY NAZAROV	{"phone": "+70281097866"}
0005432047549	04EE68	6312 322890	STANISLAV IVANOV	{"phone": "+70569191021"}
0005432047550	F44D98	0192 118545	ANDREY FROLOV	{"email": "a-frolov_05051975@postgrespro.ru", "phone": "+70136620432"}
0005432047551	F44D98	2361 677890	VLADIMIR SMIRNOV	{"phone": "+70757721949"}
0005432047552	61C82C	0480 407948	RIMMA FILIPPOVA	{"phone": "+70770521648"}
0005432047553	AAD6E5	0665 006640	OLGA NAZAROVA	{"email": "nazarova_olga-14101986@postgrespro.ru", "phone": "+70016535472"}
0005432047554	318A6F	1035 101735	IRINA SIDOROVA	{"email": "i-sidorova_031960@postgrespro.ru", "phone": "+70692221646"}
0005432047555	EEC5DA	7943 300835	SERGEY SHEVCHENKO	{"email": "shevchenkosergey.101978@postgrespro.ru", "phone": "+70238436514"}
0005432047556	5C59EA	4549 404449	VALERIY GRIGOREV	{"email": "grigorev_valeriy-1966@postgrespro.ru", "phone": "+70300710595"}
0005432047557	7EA8CE	2767 820814	ILDAR DENISOV	{"phone": "+70022796065"}
0005432047558	6AD08D	9198 954854	SVETLANA SAVELEVA	{"phone": "+70207793483"}
0005432047559	6AD08D	6230 449022	MARIYA SERGEEVA	{"email": "mariyasergeeva-1969@postgrespro.ru", "phone": "+70393483205"}
0005432047560	2BED59	1331 023564	VALENTINA POPOVA	{"phone": "+70688675475"}
0005432047561	2BED59	4415 723586	ANASTASIYA NESTEROVA	{"email": "nesterovaa-091964@postgrespro.ru", "phone": "+70495559179"}
0005432047562	9F849A	1735 025277	ROMAN DENISOV	{"phone": "+70092906313"}
0005432047563	CE8B7F	8606 163356	ILDAR ANTONOV	{"email": "ildar_antonov.28051965@postgrespro.ru", "phone": "+70436010525"}
0005432047564	B7B9E2	7912 724869	ANATOLIY FEDOROV	{"email": "anatoliy_fedorov12011975@postgrespro.ru", "phone": "+70696878263"}
0005432047565	D826B0	9811 935834	IGOR PAVLOV	{"phone": "+70171815582"}
0005432047566	3C4D90	6119 035434	VADIM YAKOVLEV	{"email": "yakovlev-vadim.101976@postgrespro.ru", "phone": "+70433410727"}
0005432047567	6FEAE4	6661 438586	VALENTINA VLASOVA	{"email": "vlasova_valentina-1974@postgrespro.ru", "phone": "+70866632065"}
0005432047568	8851EB	2008 797158	KONSTANTIN MAKAROV	{"phone": "+70185766387"}
0005432047569	E140F4	9011 150183	LYUBOV YUDINA	{"phone": "+70804578332"}
0005432047570	16EC3F	0669 032186	SERGEY BELOV	{"phone": "+70863394345"}
0005432047571	D802F4	0594 598100	VALERIY CHERNOV	{"email": "chernovvaleriy-011964@postgrespro.ru", "phone": "+70395558059"}
0005432047572	36E1A2	9942 461805	MARINA IVANOVA	{"phone": "+70575180515"}
0005432047573	5B15D0	7023 054870	VIKTOR MIRONOV	{"phone": "+70511311102"}
0005432047574	C0256B	5874 790287	OKSANA YUDINA	{"phone": "+70419160844"}
0005432047575	C0256B	0646 730386	SERGEY NOVIKOV	{"phone": "+70734297672"}
0005432047576	3B27DE	8312 282671	ALENA BORISOVA	{"email": "borisova_alena.1979@postgrespro.ru", "phone": "+70586686719"}
0005432047577	3B27DE	8091 323464	SERGEY MIKHAYLOV	{"phone": "+70563031981"}
0005432047578	963A15	9717 694692	IVAN EGOROV	{"phone": "+70478586553"}
0005432047579	C40963	2265 737887	ANATOLIY ZAKHAROV	{"email": "a-zakharov-27071961@postgrespro.ru", "phone": "+70025776879"}
0005432047580	CB20D7	1315 062828	IGOR BORISOV	{"phone": "+70201024842"}
0005432047581	6D9F13	6844 730954	DENIS BORISOV	{"phone": "+70150852536"}
0005432047582	9EFBD7	0711 386162	NATALYA TIMOFEEVA	{"email": "natalyatimofeeva-051966@postgrespro.ru", "phone": "+70957182027"}
0005432047583	9EFBD7	4556 519178	VIKTOR GERASIMOV	{"phone": "+70862607799"}
0005432047584	851309	4146 830635	OLGA NOVIKOVA	{"phone": "+70671920958"}
0005432047585	110FCB	7739 780343	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana-1972@postgrespro.ru", "phone": "+70840804233"}
0005432047586	59D873	2900 748330	ALEKSEY DENISOV	{"phone": "+70128467272"}
0005432047587	BA3A75	3998 304888	GALINA ORLOVA	{"phone": "+70251689046"}
0005432047588	D30FB1	4721 499903	ANDREY KUZNECOV	{"email": "kuznecov-a_1969@postgrespro.ru", "phone": "+70477959050"}
0005432047589	43CB39	8241 219024	OLGA SERGEEVA	{"email": "sergeeva-olga18041971@postgrespro.ru", "phone": "+70863427500"}
0005432047590	43CB39	9479 901546	SERGEY NAZAROV	{"phone": "+70663398751"}
0005432047591	43CB39	4658 576108	LARISA SOKOLOVA	{"phone": "+70915608822"}
0005432047592	68ACC5	0400 902198	VLADIMIR SIDOROV	{"email": "sidorov_vladimir-11101974@postgrespro.ru", "phone": "+70119279219"}
0005432047593	0F54D0	8173 258410	LIDIYA VOLKOVA	{"phone": "+70250538512"}
0005432047594	0F54D0	1497 904793	ALEKSANDR NIKOLAEV	{"phone": "+70266971540"}
0005432047595	A457EE	7638 278501	SVETLANA POPOVA	{"email": "popovas1960@postgrespro.ru", "phone": "+70350573113"}
0005432047596	6E13F6	2015 139313	VALENTINA ERMAKOVA	{"phone": "+70291773974"}
0005432047597	6E13F6	4805 257995	OKSANA VOLKOVA	{"phone": "+70336529529"}
0005432047598	AA0605	0040 903693	NATALYA MIRONOVA	{"email": "n.mironova071973@postgrespro.ru", "phone": "+70939661649"}
0005432047599	AA0605	0552 072549	ELENA KUZNECOVA	{"phone": "+70766646609"}
0005432047600	525335	6558 174230	ANDREY VASILEV	{"phone": "+70688584349"}
0005432047601	F378E8	7541 847835	EVGENIY KUZNECOV	{"phone": "+70621837267"}
0005432047602	CEEBBA	1156 626802	MARIYA FILIPPOVA	{"email": "m-filippova.011976@postgrespro.ru", "phone": "+70059000042"}
0005432047603	812E5C	8579 450008	EVGENIY RODIONOV	{"email": "evgeniy_rodionov-07021981@postgrespro.ru", "phone": "+70607313114"}
0005432047604	E67908	5892 258338	VLADIMIR KUZMIN	{"phone": "+70148075702"}
0005432047605	2C1F5A	1829 178594	ALEKSEY TIMOFEEV	{"email": "timofeev.aleksey1965@postgrespro.ru", "phone": "+70197557880"}
0005432047606	5E67EF	1841 220371	MIKHAIL BARANOV	{"phone": "+70537142422"}
0005432047607	B24475	6790 627365	NINA NOVIKOVA	{"email": "n.novikova_1973@postgrespro.ru", "phone": "+70707960980"}
0005432047608	CE496C	0850 909696	DMITRIY ILIN	{"phone": "+70014089929"}
0005432047609	DC4879	0245 319430	MAKSIM BORISOV	{"phone": "+70042310475"}
0005432047610	5E54C2	4817 305050	MARINA SERGEEVA	{"email": "marina_sergeeva-1977@postgrespro.ru", "phone": "+70010352817"}
0005432047611	5E54C2	6420 372838	VIKTOR GERASIMOV	{"phone": "+70796913955"}
0005432047612	5E54C2	7655 463441	MARINA MOROZOVA	{"phone": "+70979741702"}
0005432047613	0917C2	6819 371149	ELENA KOZLOVA	{"email": "kozlova-elena.14091975@postgrespro.ru", "phone": "+70263892073"}
0005432047614	0917C2	7105 342449	NATALYA VLASOVA	{"phone": "+70061010110"}
0005432047615	A7BBD6	2625 037120	ANTONINA VOLKOVA	{"phone": "+70706343893"}
0005432047616	BD2F5B	4751 542956	ALEKSEY SMIRNOV	{"phone": "+70589320758"}
0005432047617	BD2F5B	4280 531167	DMITRIY IVANOV	{"phone": "+70210259614"}
0005432047618	BD2F5B	6238 469027	TAMARA CHERNOVA	{"phone": "+70168129120"}
0005432047619	BD2F5B	4123 568090	VERA ALEKSEEVA	{"phone": "+70863467196"}
0005432047620	A8A32E	6866 999716	STANISLAV BORISOV	{"phone": "+70573100802"}
0005432047621	16CA8E	8858 470036	ALEKSEY ANTONOV	{"phone": "+70733492825"}
0005432047622	16CA8E	2570 371454	LARISA STEPANOVA	{"email": "l-stepanova_111980@postgrespro.ru", "phone": "+70272985536"}
0005432047623	00B5BC	3122 591233	ANASTASIYA GORBUNOVA	{"phone": "+70127495097"}
0005432047624	B4B45A	2893 454728	TATYANA RYABOVA	{"email": "t_ryabova-01071960@postgrespro.ru", "phone": "+70790335038"}
0005432047625	E8E1CF	9644 229034	ELENA KUZNECOVA	{"phone": "+70835604532"}
0005432047626	FBD779	3295 614643	ALEKSEY KUZNECOV	{"phone": "+70160415139"}
0005432047627	E7B54A	5712 045909	IRINA PAVLOVA	{"phone": "+70362613406"}
0005432047628	553F18	8548 920780	EKATERINA ORLOVA	{"phone": "+70953205132"}
0005432047629	97E7C6	0564 170771	EVGENIY MARTYNOV	{"email": "evgeniy.martynov_12041970@postgrespro.ru", "phone": "+70846910631"}
0005432047630	DA51AB	9516 299658	KRISTINA DENISOVA	{"phone": "+70292531122"}
0005432047631	A03DC9	4884 503857	ZOYA NESTEROVA	{"phone": "+70609164036"}
0005432047632	234C6D	0708 149341	LYUDMILA YAKOVLEVA	{"email": "lyakovleva1978@postgrespro.ru", "phone": "+70436374548"}
0005432047633	673C04	6428 902202	VALENTINA VOROBEVA	{"phone": "+70840075443"}
0005432047634	673C04	3711 871112	NINA NIKOLAEVA	{"email": "ninanikolaeva1976@postgrespro.ru", "phone": "+70356001154"}
0005432047635	7BD6CB	1469 631701	DMITRIY SOROKIN	{"phone": "+70726241729"}
0005432047636	255E3B	4569 374472	LARISA FADEEVA	{"phone": "+70508245071"}
0005432047637	218792	5876 727631	OKSANA SIDOROVA	{"email": "oksana-sidorova-27081966@postgrespro.ru", "phone": "+70952893397"}
0005432047638	2158D0	5972 256761	RUSLAN ILIN	{"email": "ilin.ruslan16061967@postgrespro.ru", "phone": "+70108753371"}
0005432047639	2158D0	1389 596237	OLGA PAVLOVA	{"phone": "+70007990271"}
0005432047640	702290	8666 445732	NAILYA TARASOVA	{"email": "ntarasova_021973@postgrespro.ru", "phone": "+70474298357"}
0005432047641	702290	2154 156842	MIKHAIL NIKITIN	{"phone": "+70702347632"}
0005432047642	8B17F1	0112 961818	RIMMA BELOVA	{"phone": "+70535733686"}
0005432047643	2A48C9	4554 885834	RUSTEM KUZNECOV	{"email": "rustem_kuznecov-1970@postgrespro.ru", "phone": "+70418224476"}
0005432047644	E1C20D	4848 467472	IVAN BARANOV	{"phone": "+70981834065"}
0005432047645	B9F4E7	8588 191113	VIKTOR OSIPOV	{"email": "v-osipov.28011977@postgrespro.ru", "phone": "+70303229341"}
0005432047646	B9F4E7	6797 621338	EKATERINA LAZAREVA	{"email": "e_lazareva.26101974@postgrespro.ru", "phone": "+70156777773"}
0005432047647	B9F4E7	0456 315141	ELENA FROLOVA	{"phone": "+70451979062"}
0005432047648	7C67FA	0848 647348	MARIYA IVANOVA	{"email": "ivanova-m_22121966@postgrespro.ru", "phone": "+70476510302"}
0005432047649	7C67FA	6154 678301	EKATERINA GUSEVA	{"phone": "+70624944447"}
0005432047650	ED75FD	5261 049756	VALERIY NAZAROV	{"email": "nazarov.v_091983@postgrespro.ru", "phone": "+70971459611"}
0005432047651	ED75FD	4851 437746	OLEG ZAKHAROV	{"phone": "+70390912648"}
0005432047652	D98366	8760 048751	EKATERINA MOROZOVA	{"phone": "+70468319146"}
0005432047653	024483	5957 461423	OLGA OVCHINNIKOVA	{"email": "ovchinnikova.olga_1979@postgrespro.ru", "phone": "+70083529992"}
0005432047654	69B1F2	5402 318572	DMITRIY ALEKSANDROV	{"phone": "+70483750352"}
0005432047655	A96BD1	9817 781942	DMITRIY PETROV	{"email": "petrov_dmitriy1960@postgrespro.ru", "phone": "+70426842723"}
0005432047656	03FE9D	1690 261702	ELENA BOGDANOVA	{"email": "e.bogdanova_061968@postgrespro.ru", "phone": "+70264878099"}
0005432047657	03FE9D	6708 478694	IGOR IVANOV	{"email": "ivanov-i1972@postgrespro.ru", "phone": "+70497534246"}
0005432047658	1F3411	1873 437396	TATYANA BORISOVA	{"email": "borisova-t-1969@postgrespro.ru", "phone": "+70262045271"}
0005432047659	D1725B	6305 501037	SERGEY PETROV	{"email": "sergey-petrov.06031973@postgrespro.ru", "phone": "+70833795739"}
0005432047660	A2A76D	3435 118407	LARISA LUKYANOVA	{"phone": "+70934949351"}
0005432047661	B435A4	1885 662140	INNA GERASIMOVA	{"phone": "+70789276057"}
0005432047662	B435A4	8807 160144	NADEZHDA FILIPPOVA	{"phone": "+70712065545"}
0005432047663	B435A4	4411 987927	GENNADIY ILIN	{"email": "ilin_gennadiy_081969@postgrespro.ru", "phone": "+70055667110"}
0005432047664	9A75A6	8403 631427	ALEKSANDR NOVIKOV	{"phone": "+70374634305"}
0005432047665	4994CD	8940 991106	KSENIYA ANTONOVA	{"phone": "+70432640037"}
0005432047666	281397	6378 831228	IRINA KALININA	{"email": "i-kalinina.121978@postgrespro.ru", "phone": "+70435260827"}
0005432049400	A4A2BA	4256 236249	OLGA KUDRYASHOVA	{"email": "kudryashova.olga-091985@postgrespro.ru", "phone": "+70517531821"}
0005432049401	80F627	5028 727269	MIKHAIL VOLKOV	{"email": "mikhailvolkov-14081976@postgrespro.ru", "phone": "+70841343220"}
0005432049402	8B8C40	1572 060933	YURIY KUZNECOV	{"email": "kuznecov.y.061967@postgrespro.ru", "phone": "+70398955775"}
0005432049403	3C61FF	3705 883067	ALEKSANDR STEPANOV	{"phone": "+70654056246"}
0005432049404	F012EC	8789 780031	KSENIYA OSIPOVA	{"email": "k.osipova24031964@postgrespro.ru", "phone": "+70145159787"}
0005432049405	CF1CE7	3692 083602	SERGEY IVANOV	{"email": "sivanov.1979@postgrespro.ru", "phone": "+70202590880"}
0005432049406	070A75	2408 622684	ALEKSANDR KAZAKOV	{"phone": "+70661348243"}
0005432049407	3BD876	2210 884709	VERA VASILEVA	{"phone": "+70342485971"}
0005432049408	D16B12	6833 075475	MARIYA BOGDANOVA	{"phone": "+70032637750"}
0005432049409	B7B36B	3538 094968	ANNA DANILOVA	{"email": "annadanilova1977@postgrespro.ru", "phone": "+70852007879"}
0005432049410	9B158A	3573 629611	ANTONINA ISAEVA	{"email": "isaeva_antonina-1968@postgrespro.ru", "phone": "+70264391147"}
0005432049411	63BEBA	6155 569190	ALEKSANDR ANTONOV	{"phone": "+70217621186"}
0005432049412	B8D4A8	7245 561217	LYUDMILA FOMINA	{"phone": "+70395699527"}
0005432049413	B8D4A8	0895 861845	DARYA MAKAROVA	{"email": "makarova-d-22071970@postgrespro.ru", "phone": "+70125484638"}
0005432049414	FD01C4	9962 921878	RAFAIL ABRAMOV	{"phone": "+70365799713"}
0005432049415	8F8A66	3164 195526	OLGA KARPOVA	{"phone": "+70334027352"}
0005432049416	8F8A66	7696 354602	IRINA KOVALEVA	{"phone": "+70866686111"}
0005432049417	A2C824	6029 066249	TATYANA NIKITINA	{"email": "nikitina_t_1973@postgrespro.ru", "phone": "+70699720507"}
0005432049418	806DE9	1482 519381	SERGEY ORLOV	{"phone": "+70281406050"}
0005432049419	CD9A9C	0602 702460	NAILYA MOROZOVA	{"email": "morozova-nailya_22081977@postgrespro.ru", "phone": "+70587490942"}
0005432049420	A77AAC	1633 568841	TATYANA ZHUKOVA	{"email": "zhukova-tatyana-111966@postgrespro.ru", "phone": "+70645122284"}
0005432049421	A77AAC	4755 558688	VLADIMIR VOLKOV	{"email": "v_volkov-021959@postgrespro.ru", "phone": "+70493817816"}
0005432049422	B25956	2956 412407	DMITRIY ANDREEV	{"email": "andreev-dmitriy.1977@postgrespro.ru", "phone": "+70047706928"}
0005432049423	0AB87C	5185 639390	IVAN KULIKOV	{"phone": "+70335005093"}
0005432049424	F3FD99	2342 739356	ALEKSANDR FROLOV	{"phone": "+70015079865"}
0005432049425	F3FD99	7084 123983	VENIAMIN FOMIN	{"phone": "+70884682705"}
0005432049426	03D1E1	0752 263809	NATALYA CHERNOVA	{"email": "chernova.n.121971@postgrespro.ru", "phone": "+70741107476"}
0005432049427	77F5A5	9332 964806	ALEKSEY POPOV	{"email": "a_popov09101980@postgrespro.ru", "phone": "+70776813717"}
0005432049428	E11268	4221 296129	NADEZHDA GRISHINA	{"phone": "+70544996171"}
0005432049429	E11268	8854 302234	VLADIMIR IVANOV	{"phone": "+70559196248"}
0005432049430	A3A3D4	7201 575256	SVETLANA YUDINA	{"phone": "+70881199682"}
0005432049431	27A5F8	3488 099672	SERGEY VASILEV	{"phone": "+70673652574"}
0005432049432	3469E0	8779 867395	MIKHAIL KUZNECOV	{"email": "kuznecov-m-051958@postgrespro.ru", "phone": "+70980173359"}
0005432049433	FF72DB	7146 116081	ELIZAVETA VLASOVA	{"email": "vlasovae-13061958@postgrespro.ru", "phone": "+70595527164"}
0005432049434	0FE44E	2979 931162	YULIYA MEDVEDEVA	{"phone": "+70053719099"}
0005432049435	1EA3FA	9896 753946	FARIT GUSEV	{"phone": "+70264677560"}
0005432049436	AA6876	2605 298389	TATYANA DMITRIEVA	{"email": "tatyana.dmitrieva_1971@postgrespro.ru", "phone": "+70565579489"}
0005432049437	AA6876	6776 590096	OLGA ZHURAVLEVA	{"email": "o_zhuravleva_05111971@postgrespro.ru", "phone": "+70694876135"}
0005432049438	8962CE	7736 685497	VLADIMIR KISELEV	{"email": "v.kiselev-101976@postgrespro.ru", "phone": "+70423613304"}
0005432049439	778BAF	4657 300372	ELENA IVANOVA	{"email": "ivanova_elena.121984@postgrespro.ru", "phone": "+70626008122"}
0005432049440	2696A6	7360 187033	SVETLANA KONOVALOVA	{"phone": "+70655585651"}
0005432049441	2696A6	7389 959349	DIANA ISAEVA	{"phone": "+70656832396"}
0005432049442	B4D69D	8251 177852	NIKOLAY OSIPOV	{"phone": "+70562166988"}
0005432049443	40ED75	4894 410100	OLGA POPOVA	{"email": "popova_olga-20071974@postgrespro.ru", "phone": "+70675158455"}
0005432049444	40ED75	0029 147821	RUZALIYA KOZLOVA	{"email": "kozlovaruzaliya.011960@postgrespro.ru", "phone": "+70227215248"}
0005432049445	1609DB	0747 526599	NINA MELNIKOVA	{"email": "nmelnikova1973@postgrespro.ru", "phone": "+70031404559"}
0005432049446	1609DB	7783 459407	VLADISLAV SCHERBAKOV	{"email": "scherbakov.v.1972@postgrespro.ru", "phone": "+70453981227"}
0005432049447	5CB69E	5339 434270	VASILIY DMITRIEV	{"phone": "+70353009420"}
0005432049448	5CB69E	2061 091035	IGOR SOLOVEV	{"email": "igor.solovev08071964@postgrespro.ru", "phone": "+70039907063"}
0005432049449	5CB69E	8342 103482	SERGEY SERGEEV	{"email": "sergeev-s27081986@postgrespro.ru", "phone": "+70716838869"}
0005432049450	D1706E	8023 215454	ALEKSANDR MOROZOV	{"phone": "+70761907599"}
0005432049451	E251EB	7821 928748	ALEKSEY POPOV	{"email": "popova1962@postgrespro.ru", "phone": "+70354824839"}
0005432049452	EC924F	3537 091375	NIKOLAY SMIRNOV	{"email": "smirnov.n_07091972@postgrespro.ru", "phone": "+70316021155"}
0005432049453	04B878	7211 878158	ANNA SOLOVEVA	{"phone": "+70098760494"}
0005432049454	252E5B	7982 517411	YURIY SHEVCHENKO	{"email": "shevchenkoy_01011983@postgrespro.ru", "phone": "+70843269308"}
0005432049455	252E5B	8548 581435	NIKOLAY FILIPPOV	{"email": "nikolay.filippov-1968@postgrespro.ru", "phone": "+70348640747"}
0005432049456	A0EE91	3942 537117	ANDREY PETROV	{"phone": "+70893669701"}
0005432049457	DEE6D0	5278 856065	NIKITA MAKAROV	{"email": "nikita-makarov.30121960@postgrespro.ru", "phone": "+70510052913"}
0005432049458	DEE6D0	4087 650564	MIKHAIL DAVYDOV	{"email": "davydov.m_06091968@postgrespro.ru", "phone": "+70088739860"}
0005432049459	C7EC74	1520 742103	MARINA NAUMOVA	{"phone": "+70218504157"}
0005432049460	95D3FC	6763 836802	NADEZHDA DAVYDOVA	{"phone": "+70856617972"}
0005432049461	EBD75C	8134 368330	RUSLAN VOROBEV	{"email": "vorobev_r_28111972@postgrespro.ru", "phone": "+70421995449"}
0005432049462	5DBC61	9784 258896	GALINA POLYAKOVA	{"phone": "+70591292951"}
0005432049463	CF4582	7796 055841	ALEKSEY KAZAKOV	{"email": "kazakova.061971@postgrespro.ru", "phone": "+70313014998"}
0005432049464	0BC6A2	6713 197043	TATYANA IVANOVA	{"email": "ivanova_tatyana-1976@postgrespro.ru", "phone": "+70024455633"}
0005432049465	0BC6A2	2466 035655	NATALYA MARTYNOVA	{"email": "martynovan-031975@postgrespro.ru", "phone": "+70615546193"}
0005432049466	992237	1621 292173	OLEG IVANOV	{"phone": "+70200155916"}
0005432049467	992237	2062 603183	ANTON YAKOVLEV	{"email": "yakovlev_anton1969@postgrespro.ru", "phone": "+70414764530"}
0005432049468	DFA1AC	4506 049176	MARIYA ZOTOVA	{"phone": "+70083622233"}
0005432049469	00EB47	1770 902009	VASILIY ISAEV	{"email": "isaev_v08081958@postgrespro.ru", "phone": "+70368474133"}
0005432049470	00EB47	0964 745352	OLEG SOKOLOV	{"phone": "+70634915225"}
0005432049471	4895F0	9345 003768	ARTEMIY BORISOV	{"phone": "+70838820891"}
0005432049472	A9051C	6038 384027	NATALYA KOZLOVA	{"phone": "+70462716836"}
0005432049473	A9051C	9859 147611	DANILA SOKOLOV	{"email": "danila_sokolov-11091963@postgrespro.ru", "phone": "+70057253773"}
0005432049474	4C4BF8	2068 914970	VASILIY FEDOTOV	{"email": "fedotovv03021970@postgrespro.ru", "phone": "+70760454030"}
0005432049475	130B41	7134 061712	IVAN SERGEEV	{"email": "i.sergeev.1973@postgrespro.ru", "phone": "+70593972034"}
0005432049476	0E9DEE	1408 200173	RAISA KARPOVA	{"phone": "+70364001555"}
0005432049477	1C267F	7761 640828	PAVEL KONOVALOV	{"phone": "+70772047437"}
0005432049478	89E48B	0219 116807	ZHANNA ORLOVA	{"phone": "+70973752353"}
0005432049479	69D133	8774 155464	ANATOLIY CHERNOV	{"phone": "+70017662236"}
0005432049480	207672	6857 786414	EVGENIY MOISEEV	{"email": "evgeniymoiseev.07051973@postgrespro.ru", "phone": "+70173099293"}
0005432049481	207672	7123 649674	ANATOLIY KULIKOV	{"phone": "+70171969582"}
0005432049482	207672	0704 010440	NADEZHDA SEMENOVA	{"phone": "+70047172144"}
0005432049483	8CF896	7668 920276	VLADIMIR IVANOV	{"phone": "+70217186612"}
0005432049484	D35C40	6081 187407	NADEZHDA TIKHONOVA	{"email": "nadezhda.tikhonova_15011968@postgrespro.ru", "phone": "+70475992531"}
0005432049485	1DE9B6	4228 639990	NIKOLAY VOROBEV	{"email": "vorobevnikolay.1979@postgrespro.ru", "phone": "+70077625917"}
0005432049486	360896	7214 795462	VALERIY BONDARENKO	{"email": "bondarenko-v.06071977@postgrespro.ru", "phone": "+70188499315"}
0005432049487	8B0F8B	3615 296773	VASILIY VOLKOV	{"email": "vvolkov.30111974@postgrespro.ru", "phone": "+70736982710"}
0005432049488	0C4587	7547 361429	SAVELIY KOZLOV	{"phone": "+70740533689"}
0005432049489	2E6D7E	4723 934850	SERGEY SAVELEV	{"phone": "+70217949834"}
0005432049490	8B22F6	4981 195196	DENIS SIDOROV	{"phone": "+70405040965"}
0005432049491	8B22F6	4306 046685	GENNADIY DAVYDOV	{"email": "davydov-g_121967@postgrespro.ru", "phone": "+70299586327"}
0005432049492	6ED481	2028 520306	ALENA PETROVA	{"email": "alena.petrova_1976@postgrespro.ru", "phone": "+70693231448"}
0005432049493	B79A24	6443 288782	IRAIDA ROMANOVA	{"email": "iraida.romanova-06021971@postgrespro.ru", "phone": "+70853302827"}
0005432049494	CDDE67	6037 315468	NINA MEDVEDEVA	{"phone": "+70111602121"}
0005432049495	CDDE67	7139 205024	VASILIY VOROBEV	{"phone": "+70728027258"}
0005432049496	CDDE67	8280 473252	ALIYA KOROLEVA	{"email": "aliya.koroleva041971@postgrespro.ru", "phone": "+70540082890"}
0005432049497	4A7ABF	7257 680841	NINA ROMANOVA	{"email": "romanova.n_071967@postgrespro.ru", "phone": "+70076542880"}
0005432049498	4A7ABF	7630 588238	RUMIYA VLASOVA	{"phone": "+70138531884"}
0005432049499	6A4CA9	5056 262341	NATALYA NIKIFOROVA	{"email": "nikiforovanatalya-03081968@postgrespro.ru", "phone": "+70561644427"}
0005432049500	6A4CA9	1264 838624	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr-111983@postgrespro.ru", "phone": "+70716098026"}
0005432049501	0695A4	6461 274114	ANDREY CHERNOV	{"phone": "+70761538035"}
0005432049502	CD09C6	3351 993489	NATALYA YAKOVLEVA	{"email": "n_yakovleva-11071969@postgrespro.ru", "phone": "+70351344168"}
0005432049503	CD09C6	1547 808067	VLADIMIR DENISOV	{"email": "vladimirdenisov-13091979@postgrespro.ru", "phone": "+70072076829"}
0005432049504	CD09C6	1116 139930	NATALYA IVANOVA	{"email": "n_ivanova-09081970@postgrespro.ru", "phone": "+70801287262"}
0005432049505	02E951	1907 566242	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_011964@postgrespro.ru", "phone": "+70419716589"}
0005432049506	02E951	4364 323056	GALINA ORLOVA	{"phone": "+70207436443"}
0005432049507	4CE8A5	4258 951958	GAGIK ZAYCEV	{"phone": "+70969726317"}
0005432049508	4CE8A5	0654 638457	VLADISLAV ZHURAVLEV	{"phone": "+70155335051"}
0005432049509	B5C0BB	6687 965044	NADEZHDA POPOVA	{"phone": "+70526405182"}
0005432049510	E62C97	2373 073763	YULIYA ZHUKOVA	{"phone": "+70643537606"}
0005432049511	E62C97	1819 643103	LYUDMILA MIKHAYLOVA	{"phone": "+70577248232"}
0005432049512	E62C97	0908 250254	PETR NAZAROV	{"email": "nazarov.petr.01111972@postgrespro.ru", "phone": "+70586832312"}
0005432049513	532D2F	3644 337988	IVAN PETROV	{"email": "ivan_petrov_1971@postgrespro.ru", "phone": "+70880332956"}
0005432049514	532D2F	9551 110579	MAKSIM ABRAMOV	{"phone": "+70019310909"}
0005432049515	0D47A2	1560 840671	ANNA FOMINA	{"phone": "+70256877942"}
0005432049516	7BDC11	6215 542580	VALENTINA GORBUNOVA	{"phone": "+70980678827"}
0005432049517	9C50A3	2422 223049	ILMIRA KOVALEVA	{"phone": "+70049660237"}
0005432049518	1C47E7	3471 870201	VALENTINA TARASOVA	{"email": "tarasova-v_1967@postgrespro.ru", "phone": "+70778998220"}
0005432049519	181061	7224 126753	NATALYA NIKITINA	{"phone": "+70169157848"}
0005432049520	1D2FB1	0488 419713	VYACHESLAV MOROZOV	{"phone": "+70542089375"}
0005432049521	AA986E	0736 543181	LIDIYA KULIKOVA	{"email": "kulikova.l.27091971@postgrespro.ru", "phone": "+70977211815"}
0005432049522	AA986E	2355 189893	VLADISLAV IVANOV	{"email": "ivanov_v15091966@postgrespro.ru", "phone": "+70026937397"}
0005432049523	CF277B	6413 770624	ELENA KOZLOVA	{"email": "elena_kozlova-061976@postgrespro.ru", "phone": "+70277680846"}
0005432049524	CF277B	2770 462270	MIKHAIL BARANOV	{"phone": "+70456799994"}
0005432049525	5D284D	4115 938393	POLINA KOZLOVA	{"email": "p.kozlova_16101965@postgrespro.ru", "phone": "+70590762540"}
0005432049526	3FF348	1445 721233	PETR MOROZOV	{"email": "petr-morozov.17111968@postgrespro.ru", "phone": "+70639155965"}
0005432049527	7A3910	7040 613368	SERGEY SEMENOV	{"phone": "+70662187273"}
0005432049528	28CBA1	1289 943437	ELENA PETROVA	{"email": "petrova-e041974@postgrespro.ru", "phone": "+70374582829"}
0005432049529	F9A5E3	1091 319871	VALENTINA KUZNECOVA	{"email": "v_kuznecova.26121972@postgrespro.ru", "phone": "+70737586008"}
0005432049530	D05BA2	8522 966692	MIKHAIL DMITRIEV	{"email": "dmitrievm_011982@postgrespro.ru", "phone": "+70838281812"}
0005432049531	D05BA2	3788 616190	ALEKSANDR FEDOROV	{"email": "fedorova_1971@postgrespro.ru", "phone": "+70506802721"}
0005432049532	F9350B	3073 987712	TATYANA FOMINA	{"phone": "+70218110125"}
0005432049533	DE18CE	9296 764323	OLGA IVANOVA	{"phone": "+70144396500"}
0005432049534	DE18CE	8168 123733	DMITRIY BARANOV	{"email": "dmitriy_baranov.08031967@postgrespro.ru", "phone": "+70055908622"}
0005432049535	4EBFC1	6757 989829	LIDIYA FOMINA	{"phone": "+70734195349"}
0005432049536	A05D0E	0414 241134	ANDREY POPOV	{"phone": "+70672000811"}
0005432049537	12BA53	1073 235213	TATYANA KAZAKOVA	{"phone": "+70566931160"}
0005432049538	A29604	9804 194086	VIKTORIYA MELNIKOVA	{"email": "melnikova-viktoriya1973@postgrespro.ru", "phone": "+70519440848"}
0005432049539	A29604	2180 855984	ALIK KUZNECOV	{"phone": "+70451366417"}
0005432049540	02B1DC	9022 783320	VLADIMIR BORISOV	{"phone": "+70604989846"}
0005432049541	02B1DC	3503 658001	MIKHAIL SOKOLOV	{"email": "sokolov_mikhail-031976@postgrespro.ru", "phone": "+70597158342"}
0005432049542	6AE119	1734 626527	EVGENIY NIKOLAEV	{"email": "nikolaev.evgeniy-1962@postgrespro.ru", "phone": "+70851794616"}
0005432049543	DA13FF	0392 075763	SERGEY TARASOV	{"email": "sergeytarasov-121973@postgrespro.ru", "phone": "+70351614515"}
0005432049544	DB72F5	5406 447491	VENERA POPOVA	{"email": "popova.v1974@postgrespro.ru", "phone": "+70522155033"}
0005432049545	DB72F5	0496 029285	VLADISLAV IVANOV	{"email": "ivanov_vladislav.1978@postgrespro.ru", "phone": "+70072164378"}
0005432049546	DB72F5	6442 021243	PETR SAVELEV	{"email": "psavelev-1952@postgrespro.ru", "phone": "+70976926759"}
0005432049547	B9AB29	7091 420275	ALEKSANDRA MIRONOVA	{"email": "a-mironova_17121959@postgrespro.ru", "phone": "+70373328367"}
0005432049548	989AF1	8463 789790	VASILIY MEDVEDEV	{"phone": "+70142378745"}
0005432049549	49C668	1390 236626	LYUDMILA EGOROVA	{"email": "egorova.lyudmila081964@postgrespro.ru", "phone": "+70839072731"}
0005432049550	72FCF3	6949 199221	NIKOLAY KUZMIN	{"phone": "+70251546885"}
0005432049551	72FCF3	4387 976045	ALEKSEY VLASOV	{"email": "aleksey.vlasov_091974@postgrespro.ru", "phone": "+70910049065"}
0005432049552	F9BF41	3038 662017	KIRILL DAVYDOV	{"phone": "+70680005063"}
0005432049553	74B46B	7946 240576	MIKHAIL PETROV	{"email": "petrov_m1977@postgrespro.ru", "phone": "+70235909909"}
0005432049554	74B46B	4048 648436	KARINA ANISIMOVA	{"email": "anisimova_karina_071982@postgrespro.ru", "phone": "+70980515519"}
0005432049555	755535	1113 749816	GALINA VASILEVA	{"phone": "+70724050107"}
0005432049556	13BC1B	6871 205597	NINA BORISOVA	{"email": "borisova-n-111972@postgrespro.ru", "phone": "+70155633412"}
0005432049557	13BC1B	4183 161242	YANA BORISOVA	{"phone": "+70759705667"}
0005432049558	95D26F	4445 971360	VIKTOR GORBUNOV	{"email": "gorbunov-v.1977@postgrespro.ru", "phone": "+70402018661"}
0005432049559	95D26F	8751 844836	ALEKSEY BONDARENKO	{"phone": "+70873886266"}
0005432049560	20F0C5	5388 175721	OLESYA KOVALEVA	{"phone": "+70974021759"}
0005432049561	6A5722	4106 027775	NINA VLASOVA	{"phone": "+70057595689"}
0005432049562	6A5722	0581 179951	EKATERINA KONDRATEVA	{"phone": "+70252966101"}
0005432049563	0F1020	6179 126416	ELENA LEBEDEVA	{"email": "e.lebedeva-1967@postgrespro.ru", "phone": "+70588780884"}
0005432049564	0F1020	1908 788266	SERGEY MOISEEV	{"phone": "+70379197331"}
0005432049565	DF6FA2	3254 434524	VASILIY AFANASEV	{"phone": "+70977021869"}
0005432049566	83F6AB	7851 656900	NATALIYA NAUMOVA	{"phone": "+70536237567"}
0005432049567	BF102B	8033 836632	ALEKSEY PETROV	{"phone": "+70640972122"}
0005432049568	BF102B	0221 473785	ALEKSANDR KULIKOV	{"phone": "+70148964620"}
0005432051074	17848B	8518 512055	LILIYA KUZNECOVA	{"phone": "+70801904359"}
0005432051075	81833B	6612 456818	LYUBOV MAKAROVA	{"phone": "+70331255826"}
0005432051076	81833B	9776 369580	ANDREY MOISEEV	{"phone": "+70961119915"}
0005432051077	9ED044	3732 646570	ANASTASIYA MIRONOVA	{"email": "anastasiya-mironova.1981@postgrespro.ru", "phone": "+70317716234"}
0005432051078	6B847C	1482 016532	NIKITA SAVELEV	{"phone": "+70872576999"}
0005432051079	546080	9742 263023	ELIZAVETA SERGEEVA	{"phone": "+70496598333"}
0005432051080	A4319F	6839 762124	VALENTINA KOLESNIKOVA	{"phone": "+70631383979"}
0005432051081	D17F2F	4665 377472	INGA MOISEEVA	{"phone": "+70228908667"}
0005432051082	D17F2F	1123 891088	NATALYA ILINA	{"email": "ilina.natalya05121972@postgrespro.ru", "phone": "+70912904903"}
0005432051083	3F05E2	6113 004581	LYUDMILA ALEKSEEVA	{"phone": "+70977285569"}
0005432051084	6B8F0D	8924 804522	PAVEL NIKITIN	{"email": "nikitin_pavel_1979@postgrespro.ru", "phone": "+70549995164"}
0005432051085	6B8F0D	6607 734865	LYUBOV NIKOLAEVA	{"email": "nikolaeva_l-051977@postgrespro.ru", "phone": "+70362344109"}
0005432051086	6F6623	9857 448432	ALEKSANDR IVANOV	{"email": "ivanov-a_09021967@postgrespro.ru", "phone": "+70554562447"}
0005432051087	329E6E	1068 330063	ALEKSEY MAKAROV	{"email": "aleksey_makarov.041988@postgrespro.ru", "phone": "+70660794158"}
0005432051088	329E6E	1804 328092	ANTON ANDREEV	{"phone": "+70061484142"}
0005432051089	0AECD3	7475 703316	IGOR ALEKSANDROV	{"email": "i.aleksandrov_1970@postgrespro.ru", "phone": "+70621947379"}
0005432051090	E421E9	4914 177600	MARINA ABRAMOVA	{"email": "abramova-m_1963@postgrespro.ru", "phone": "+70449445286"}
0005432051091	66872E	8823 197534	DMITRIY MATVEEV	{"phone": "+70893821993"}
0005432051092	1D4451	3687 616406	NADEZHDA NIKIFOROVA	{"phone": "+70287076049"}
0005432051093	3E7A8F	3204 020728	MARINA SMIRNOVA	{"email": "marina.smirnova.17091964@postgrespro.ru", "phone": "+70686650640"}
0005432051094	AC7A28	8963 189088	ALEKSANDR SOKOLOV	{"phone": "+70053315823"}
0005432051095	994E90	9388 948740	GALINA ALEKSEEVA	{"phone": "+70209612644"}
0005432051096	994E90	3691 460013	ALEKSANDR IVANOV	{"phone": "+70247894954"}
0005432051097	074C43	2971 871746	ANTON ZHUKOV	{"email": "zhukov.a12071965@postgrespro.ru", "phone": "+70100561202"}
0005432051098	C56C56	3637 254333	MARIYA MAKSIMOVA	{"email": "maksimova-m.04011972@postgrespro.ru", "phone": "+70282616465"}
0005432051099	02D316	7364 492753	ALINA VASILEVA	{"phone": "+70504290858"}
0005432051100	02D316	4400 858076	ANNA TIMOFEEVA	{"phone": "+70599682431"}
0005432051101	6B65CB	3614 239918	LIDIYA FOMINA	{"phone": "+70476069530"}
0005432051102	C65832	9265 834462	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr.1973@postgrespro.ru", "phone": "+70051253563"}
0005432051103	C65832	9394 156918	MARINA NOVIKOVA	{"phone": "+70818264545"}
0005432051104	C65832	9341 489412	DMITRIY NAUMOV	{"phone": "+70641628641"}
0005432051105	B75E85	0746 997999	LYUDMILA SOROKINA	{"email": "l_sorokina-1971@postgrespro.ru", "phone": "+70406091845"}
0005432051106	2E13A0	2818 874101	TATYANA FEDOROVA	{"phone": "+70719559263"}
0005432051107	2E13A0	7094 791784	ROMAN SHEVCHENKO	{"email": "shevchenko.r.12121970@postgrespro.ru", "phone": "+70205946872"}
0005432051108	28E387	6881 748655	TAISIYA TIKHONOVA	{"email": "ttikhonova.13101976@postgrespro.ru", "phone": "+70870417374"}
0005432051109	0160E0	2377 945420	SERGEY VOROBEV	{"email": "vorobev_sergey.1978@postgrespro.ru", "phone": "+70007438818"}
0005432051110	6CFC7D	6694 392203	LIDIYA NOVIKOVA	{"email": "novikova-lidiya28091975@postgrespro.ru", "phone": "+70701956091"}
0005432051111	6CFC7D	1897 218262	MIKHAIL NAZAROV	{"email": "m-nazarov1969@postgrespro.ru", "phone": "+70984618552"}
0005432051112	E212EB	5797 142068	EDUARD TARASOV	{"email": "eduard.tarasov_1963@postgrespro.ru", "phone": "+70477761336"}
0005432051113	C72554	9863 429988	DENIS ZAYCEV	{"phone": "+70242387593"}
0005432051114	C72554	2001 507907	GALINA KUDRYASHOVA	{"email": "kudryashova.galina-1969@postgrespro.ru", "phone": "+70664174767"}
0005432051115	0A9B59	0663 886282	MIKHAIL IVANOV	{"phone": "+70099725225"}
0005432051116	FC1196	7882 286439	MARIYA SIDOROVA	{"email": "sidorova-mariya_1973@postgrespro.ru", "phone": "+70929709397"}
0005432051117	FC1196	5617 426406	NATALYA VASILEVA	{"email": "n-vasileva061984@postgrespro.ru", "phone": "+70562208739"}
0005432051118	0B63DE	7624 875918	MAKSIM EGOROV	{"email": "egorovmaksim061978@postgrespro.ru", "phone": "+70082744674"}
0005432052708	79515F	4412 493100	NIKOLAY ZAKHAROV	{"phone": "+70973265589"}
0005432051119	0B63DE	9367 072057	ANATOLIY VOLKOV	{"email": "anatoliy-volkov-11101961@postgrespro.ru", "phone": "+70519658881"}
0005432051120	C7A599	7597 020595	OLGA DAVYDOVA	{"email": "davydovao_061978@postgrespro.ru", "phone": "+70259339889"}
0005432051121	18CB80	1698 386676	VLADISLAV GERASIMOV	{"email": "gerasimov-vladislav_021982@postgrespro.ru", "phone": "+70446849949"}
0005432051122	EC0A36	5683 640126	MARGARITA FEDOROVA	{"email": "fedorovam_08031962@postgrespro.ru", "phone": "+70883632960"}
0005432051123	EC0A36	3871 964251	IGOR MOROZOV	{"email": "imorozov-1970@postgrespro.ru", "phone": "+70797699971"}
0005432051124	9E86B1	6372 989979	SERGEY GUSEV	{"email": "gusev-sergey111965@postgrespro.ru", "phone": "+70426879010"}
0005432051125	1C2935	4297 634820	ANDREY MELNIKOV	{"email": "a_melnikov.1979@postgrespro.ru", "phone": "+70479745583"}
0005432051126	D466D4	7502 522417	SVETLANA FROLOVA	{"email": "frolovas.041959@postgrespro.ru", "phone": "+70150259389"}
0005432051127	452EFB	7616 446136	ANNA FILATOVA	{"phone": "+70329617275"}
0005432051128	452EFB	0049 779944	VLADIMIR POPOV	{"email": "vladimir-popov121969@postgrespro.ru", "phone": "+70617639089"}
0005432051129	AC7980	6258 454907	RAISA IVANOVA	{"email": "r.ivanova_05111976@postgrespro.ru", "phone": "+70102646082"}
0005432051130	A07355	5835 241677	LYUDMILA NIKOLAEVA	{"email": "lyudmila_nikolaeva_081984@postgrespro.ru", "phone": "+70231651654"}
0005432051131	A07355	8526 011701	VLADIMIR RODIONOV	{"phone": "+70225949428"}
0005432051132	114615	8004 744077	NADEZHDA MELNIKOVA	{"phone": "+70572522255"}
0005432051133	EE75BF	9748 576564	IVAN CHERNOV	{"phone": "+70907498597"}
0005432051134	08299D	5921 030122	LYUDMILA ZAYCEVA	{"phone": "+70674016341"}
0005432051135	402A6A	3826 289113	ANASTASIYA FEDOROVA	{"email": "fedorova_a-011967@postgrespro.ru", "phone": "+70451965356"}
0005432051136	402A6A	7075 052486	GALINA GRISHINA	{"email": "g-grishina-121969@postgrespro.ru", "phone": "+70476997114"}
0005432051137	8559D6	8213 308276	DANIIL ZAYCEV	{"email": "zaycev-d_1971@postgrespro.ru", "phone": "+70064874532"}
0005432051138	791D0A	2277 875066	OLGA NAZAROVA	{"email": "olganazarova_1961@postgrespro.ru", "phone": "+70163367530"}
0005432051139	1836A2	0694 294230	VALERIY ROMANOV	{"phone": "+70474535567"}
0005432051140	DA5CE4	7718 635206	OLGA PAVLOVA	{"email": "o_pavlova.17011968@postgrespro.ru", "phone": "+70625720596"}
0005432051141	E373C8	6199 464694	ILYA SHEVCHENKO	{"phone": "+70527076382"}
0005432051142	E373C8	7284 379247	LIDIYA PETROVA	{"phone": "+70516336989"}
0005432051143	63F994	9784 375662	VLADIMIR NAZAROV	{"phone": "+70695108819"}
0005432051144	76AA99	0263 669661	DENIS SERGEEV	{"phone": "+70578729946"}
0005432051145	76AA99	0926 415410	ARTEM VOLKOV	{"phone": "+70159750769"}
0005432051146	EA8224	3840 197458	SVETLANA EFREMOVA	{"phone": "+70526731666"}
0005432051147	3199B8	3155 984501	TATYANA MIKHAYLOVA	{"phone": "+70900097337"}
0005432051148	30FFA1	5526 975620	ULYANA ZAYCEVA	{"phone": "+70882077505"}
0005432051149	30FFA1	5872 326053	SERGEY POPOV	{"email": "sergey_popov-031978@postgrespro.ru", "phone": "+70943648745"}
0005432051150	549831	6321 884136	ANDREY MAKSIMOV	{"email": "maksimov_a.021968@postgrespro.ru", "phone": "+70711221609"}
0005432051151	991246	7966 463330	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev_28111963@postgrespro.ru", "phone": "+70878810114"}
0005432051152	991246	9792 491478	IVAN MAKAROV	{"email": "i_makarov.031976@postgrespro.ru", "phone": "+70851415014"}
0005432051153	ACE43D	8369 568119	EKATERINA KONOVALOVA	{"email": "e.konovalova061979@postgrespro.ru", "phone": "+70362826619"}
0005432051154	B80D1B	8210 803007	VLADIMIR ILIN	{"email": "v.ilin071978@postgrespro.ru", "phone": "+70777323533"}
0005432051155	B80D1B	8089 839318	MIKHAIL ZAYCEV	{"phone": "+70008038788"}
0005432051156	4133BE	8928 739797	GRIGORIY YAKOVLEV	{"email": "yakovlev-grigoriy-081976@postgrespro.ru", "phone": "+70109774196"}
0005432051157	FDCCE0	5918 675788	VLADIMIR NOVIKOV	{"phone": "+70047333758"}
0005432051158	7BFE0A	3509 436385	EVA RODIONOVA	{"phone": "+70454503359"}
0005432051159	C5D35B	9787 174671	DMITRIY FROLOV	{"email": "frolov-dmitriy_19021976@postgrespro.ru", "phone": "+70609281054"}
0005432051160	A1B68E	9910 741017	OKSANA FEDOROVA	{"phone": "+70367624743"}
0005432051161	A1B68E	8033 149312	MARIYA FEDOROVA	{"email": "mariyafedorova.1960@postgrespro.ru", "phone": "+70586798367"}
0005432051162	EEF716	3028 413726	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr_121981@postgrespro.ru", "phone": "+70975178851"}
0005432051163	0D2D1B	2892 727666	MAKSIM SHEVCHENKO	{"email": "shevchenko.m.1972@postgrespro.ru", "phone": "+70431577937"}
0005432051164	B73BE1	0309 235218	SERGEY FEDOROV	{"phone": "+70471108929"}
0005432051165	88543E	3565 556551	GALINA POPOVA	{"email": "galina-popova.1965@postgrespro.ru", "phone": "+70397723822"}
0005432051166	EF4226	5118 529971	PAVEL FOMIN	{"phone": "+70452717741"}
0005432051167	66BA33	9964 785810	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.15101973@postgrespro.ru", "phone": "+70705114516"}
0005432051168	66BA33	6492 981455	ARTEM ABRAMOV	{"email": "abramovartem-1975@postgrespro.ru", "phone": "+70284798607"}
0005432051169	6B3E9C	3693 058787	NATALYA PAVLOVA	{"email": "pavlovanatalya.01091978@postgrespro.ru", "phone": "+70065127932"}
0005432051170	DF10F0	0404 492293	SVETLANA MOISEEVA	{"phone": "+70054538072"}
0005432051171	B445D4	6473 281778	PAVEL ROMANOV	{"email": "p_romanov-111972@postgrespro.ru", "phone": "+70761480949"}
0005432051172	8DC211	0713 512462	OLEG SIDOROV	{"email": "sidorov.oleg.24071965@postgrespro.ru", "phone": "+70435527458"}
0005432051173	5E2C17	1429 751750	KONSTANTIN IVANOV	{"phone": "+70109127068"}
0005432051174	D195BA	5589 116924	NIKITA ILIN	{"phone": "+70465893602"}
0005432051175	0EC473	7395 697614	VALENTINA GORBUNOVA	{"phone": "+70634217934"}
0005432051176	0EC473	0730 858649	MIKHAIL ILIN	{"email": "m.ilin.011961@postgrespro.ru", "phone": "+70665820174"}
0005432051177	0EC473	6378 837827	TATYANA MIRONOVA	{"email": "mironova.tatyana-1967@postgrespro.ru", "phone": "+70774588938"}
0005432051178	49811D	4901 507300	ALEKSEY FROLOV	{"email": "alekseyfrolov_1969@postgrespro.ru", "phone": "+70267824526"}
0005432051179	49811D	0519 610705	DANILA KISELEV	{"phone": "+70427216958"}
0005432051180	E81B8A	4020 508169	ALEKSEY DENISOV	{"email": "a_denisov.1981@postgrespro.ru", "phone": "+70820848553"}
0005432051181	E81B8A	7383 528560	VITALIY BORISOV	{"email": "borisov.vitaliy-1986@postgrespro.ru", "phone": "+70311950669"}
0005432051182	642836	1566 681836	SERGEY STEPANOV	{"phone": "+70882857783"}
0005432051183	83E43E	2117 362466	NIKITA MEDVEDEV	{"email": "n.medvedev-30051974@postgrespro.ru", "phone": "+70494462303"}
0005432051184	83E43E	1295 694670	ALEKSEY KRASNOV	{"email": "krasnova_1977@postgrespro.ru", "phone": "+70891694254"}
0005432051185	8E3506	3542 196555	IRINA IVANOVA	{"phone": "+70528831273"}
0005432051186	EC5117	9146 447661	IVAN FEDOTOV	{"email": "ivanfedotov_091978@postgrespro.ru", "phone": "+70277248601"}
0005432051187	EC5117	6495 991112	NADEZHDA IVANOVA	{"phone": "+70995059253"}
0005432051188	EC5117	6133 848445	TAMARA KONOVALOVA	{"phone": "+70296360249"}
0005432051189	64894D	0751 266229	EVGENIY ROMANOV	{"email": "evgeniy-romanov09031970@postgrespro.ru", "phone": "+70631599595"}
0005432051190	6D5CB2	7486 020504	MIKHAIL OSIPOV	{"phone": "+70799676908"}
0005432051191	6D5CB2	2862 719729	VLADIMIR KOROLEV	{"email": "vladimirkorolev-031970@postgrespro.ru", "phone": "+70943745046"}
0005432051192	6D5CB2	4640 078780	SVETLANA ERMAKOVA	{"email": "ermakovas_1960@postgrespro.ru", "phone": "+70674884659"}
0005432051193	99B904	2274 990774	VLADIMIR SOROKIN	{"phone": "+70060633365"}
0005432051194	44C50B	7562 973775	NIKITA SIDOROV	{"email": "sidorov_nikita.15011968@postgrespro.ru", "phone": "+70716538059"}
0005432051195	44C50B	9301 199238	MIKHAIL MIRONOV	{"phone": "+70500695620"}
0005432051196	1CEC45	3315 693651	NIKOLAY KONOVALOV	{"phone": "+70832463387"}
0005432051197	6B3363	0270 332569	MARIYA KONOVALOVA	{"email": "konovalovamariya_1976@postgrespro.ru", "phone": "+70473856135"}
0005432051198	9F60EF	2829 756655	GALINA TITOVA	{"email": "titova-g-16101983@postgrespro.ru", "phone": "+70840472516"}
0005432051199	9F60EF	6999 093096	VIKTOR KULIKOV	{"email": "v.kulikov_13061963@postgrespro.ru", "phone": "+70069794143"}
0005432051200	252892	9870 278797	ALEKSEY KUZNECOV	{"email": "a_kuznecov.16101964@postgrespro.ru", "phone": "+70995677454"}
0005432051201	252892	5510 415859	ELENA CHERNOVA	{"email": "elena-chernova_081973@postgrespro.ru", "phone": "+70719534098"}
0005432051202	CDA269	3062 987517	IRINA ERMAKOVA	{"email": "i.ermakova.1969@postgrespro.ru", "phone": "+70666596875"}
0005432051203	0BFB83	3444 989007	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov15101975@postgrespro.ru", "phone": "+70942053429"}
0005432051204	0BFB83	8420 921997	ALEKSANDR VASILEV	{"email": "vasilev.a-1968@postgrespro.ru", "phone": "+70563030473"}
0005432051205	58AF10	7668 950776	VALERIY KOZLOV	{"email": "kozlovv_1978@postgrespro.ru", "phone": "+70887234524"}
0005432051206	8A29A5	8573 656688	MIKHAIL NOVIKOV	{"phone": "+70810121843"}
0005432051207	C0A710	0828 574075	VIKTOR GAVRILOV	{"phone": "+70899723340"}
0005432051208	7C17A9	0798 209919	GALINA TIKHONOVA	{"email": "tikhonova_g.1981@postgrespro.ru", "phone": "+70892781981"}
0005432051209	4507EA	6414 928497	ALENA POLYAKOVA	{"phone": "+70680267396"}
0005432051210	ECDCB1	4995 361593	TATYANA VASILEVA	{"email": "t.vasileva.1970@postgrespro.ru", "phone": "+70950400154"}
0005432051211	BCAC86	4771 001766	SVETLANA AFANASEVA	{"email": "afanaseva-svetlana_031985@postgrespro.ru", "phone": "+70880010083"}
0005432051212	37F5F3	2412 195886	EKATERINA MAKAROVA	{"phone": "+70269934407"}
0005432051213	4730B7	3457 530235	TATYANA SOLOVEVA	{"email": "soloveva-tatyana-25121978@postgrespro.ru", "phone": "+70480706893"}
0005432051214	4730B7	0042 536732	INNA EFIMOVA	{"email": "efimovainna1970@postgrespro.ru", "phone": "+70317073077"}
0005432051215	045286	8509 919575	YULIYA VOLKOVA	{"email": "volkova_yuliya.05101963@postgrespro.ru", "phone": "+70578649864"}
0005432051216	09E0F1	7036 471762	TAMARA IVANOVA	{"phone": "+70465935767"}
0005432051217	01935F	4465 069012	ELENA ARKHIPOVA	{"email": "arkhipova_e-17101977@postgrespro.ru", "phone": "+70282585365"}
0005432051218	E56CD9	0152 906187	FEDOR ANDREEV	{"email": "andreev_f011976@postgrespro.ru", "phone": "+70904678848"}
0005432051219	D4C8F9	8511 126116	ARTEM MIKHAYLOV	{"email": "mikhaylov.artem.101977@postgrespro.ru", "phone": "+70675324128"}
0005432052694	1173B9	0846 828509	PAVEL GUSEV	{"phone": "+70969270763"}
0005432052691	259981	7730 798862	SERGEY KUZNECOV	{"phone": "+70809138156"}
0005432052692	0D052B	7853 899146	VLADIMIR MAKAROV	{"phone": "+70188626287"}
0005432052693	5CAB13	1945 691288	TATYANA DENISOVA	{"email": "tdenisova_111972@postgrespro.ru", "phone": "+70842297825"}
0005432052695	49C8D7	5209 400304	NADEZHDA NIKITINA	{"email": "n-nikitina1968@postgrespro.ru", "phone": "+70179648668"}
0005432052696	49C8D7	2894 028623	OLGA KOMAROVA	{"phone": "+70747484860"}
0005432052697	B383D3	2990 341325	OLEG SCHERBAKOV	{"email": "o_scherbakov-09051972@postgrespro.ru", "phone": "+70163492287"}
0005432052698	B383D3	8710 975121	ALEKSANDR FEDOTOV	{"phone": "+70962652506"}
0005432052699	142CC4	5139 385695	SERGEY KISELEV	{"email": "kiselevs_16091976@postgrespro.ru", "phone": "+70041635314"}
0005432052700	F07889	1988 516627	GALINA ZHURAVLEVA	{"email": "zhuravleva_galina-1972@postgrespro.ru", "phone": "+70256541877"}
0005432052701	DA0B9F	8973 452783	VALERIY ANDREEV	{"email": "vandreev_10101974@postgrespro.ru", "phone": "+70934107272"}
0005432052702	00C07E	3610 080312	VLADIMIR MOROZOV	{"phone": "+70880380357"}
0005432052703	00C07E	6121 377425	NELLI ROMANOVA	{"phone": "+70655134590"}
0005432052704	A0FCF6	7150 780931	OKSANA ANDREEVA	{"phone": "+70080766586"}
0005432052705	14F004	1092 728365	VYACHESLAV KARPOV	{"email": "v_karpov.081963@postgrespro.ru", "phone": "+70361815888"}
0005432052706	79515F	0946 329590	OLGA VOLKOVA	{"phone": "+70031670326"}
0005432052707	79515F	4820 730918	MARIYA LAZAREVA	{"phone": "+70072333750"}
0005432052709	AA5722	6149 100374	DENIS GORBUNOV	{"phone": "+70693479792"}
0005432052710	A14171	2643 486964	YAN MOROZOV	{"phone": "+70385573657"}
0005432052711	A14171	8419 444428	DARYA SMIRNOVA	{"phone": "+70743276126"}
0005432052712	63B7CF	4061 248844	VLADIMIR FEDOROV	{"email": "v-fedorov.1974@postgrespro.ru", "phone": "+70013452217"}
0005432052713	CDC8F3	7890 696117	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov061972@postgrespro.ru", "phone": "+70257323581"}
0005432052714	786811	5078 427140	GALINA ALEKSANDROVA	{"email": "aleksandrova_g_051955@postgrespro.ru", "phone": "+70420166260"}
0005432052715	7D94BF	9803 626016	NIKITA GAVRILOV	{"phone": "+70834548837"}
0005432052716	1E2966	9931 214503	DANIIL NIKOLAEV	{"email": "d.nikolaev.10061977@postgrespro.ru", "phone": "+70131010119"}
0005432052717	82CE3D	7629 472047	DMITRIY POPOV	{"phone": "+70583028969"}
0005432052718	549417	4382 926535	ALEKSANDR KUZNECOV	{"phone": "+70115064971"}
0005432052719	549417	9152 153268	ROMAN GUSEV	{"email": "roman-gusev.06091959@postgrespro.ru", "phone": "+70424374669"}
0005432052720	100E28	1100 163989	VLADIMIR BONDARENKO	{"email": "bondarenkovladimir27071979@postgrespro.ru", "phone": "+70227069482"}
0005432052721	100E28	5213 614778	DANILA MIRONOV	{"phone": "+70419995039"}
0005432052722	3A1287	4429 479207	EKATERINA LEBEDEVA	{"phone": "+70776117250"}
0005432052723	3A1287	8511 510481	VIKTORIYA LOGINOVA	{"email": "viktoriyaloginova.031978@postgrespro.ru", "phone": "+70560037159"}
0005432052724	49B78D	9335 269766	BOGDAN DENISOV	{"email": "denisov-bogdan_1980@postgrespro.ru", "phone": "+70050620509"}
0005432052725	49B78D	6833 516150	NIKOLAY MATVEEV	{"email": "nmatveev-081959@postgrespro.ru", "phone": "+70535064337"}
0005432052726	720DD0	3090 362441	TIMUR GAVRILOV	{"email": "timur.gavrilov-1969@postgrespro.ru", "phone": "+70421097027"}
0005432052727	1848D9	2302 636301	ALEKSANDR VOLKOV	{"phone": "+70954733194"}
0005432052728	44B65C	9274 618847	ANATOLIY FEDOROV	{"email": "anatoliy_fedorov-11121971@postgrespro.ru", "phone": "+70255047790"}
0005432052729	44B65C	7918 222321	NADEZHDA SEMENOVA	{"phone": "+70550704638"}
0005432052730	9B1244	0074 418640	ANNA ALEKSEEVA	{"email": "anna-alekseeva1987@postgrespro.ru", "phone": "+70803649288"}
0005432052731	9B1244	0901 860919	YURIY SEMENOV	{"phone": "+70549491551"}
0005432052732	C93252	9046 151357	SVETLANA FEDOROVA	{"email": "s-fedorova1977@postgrespro.ru", "phone": "+70723826329"}
0005432052733	0DD2FC	8058 077899	KONSTANTIN DENISOV	{"email": "denisov-k_1958@postgrespro.ru", "phone": "+70139132374"}
0005432052734	0DD2FC	6167 429036	ANTON GRIGOREV	{"email": "grigorev-a-16121967@postgrespro.ru", "phone": "+70528899062"}
0005432052735	0DD2FC	7879 745950	FEDOR MAKAROV	{"phone": "+70942127146"}
0005432052736	D707C6	5199 279980	VIKTOR IVANOV	{"email": "ivanov.viktor-1967@postgrespro.ru", "phone": "+70382130429"}
0005432052737	5CC872	4576 156904	VERA FROLOVA	{"phone": "+70646675992"}
0005432052738	5CC872	1559 159781	EGOR VASILEV	{"email": "evasilev-1973@postgrespro.ru", "phone": "+70252894200"}
0005432052739	5CC872	6786 045999	NIKOLAY SEMENOV	{"email": "nsemenov_09061961@postgrespro.ru", "phone": "+70869643071"}
0005432052740	3EF249	6078 948567	NIKOLAY KULIKOV	{"phone": "+70798935905"}
0005432052741	3EF249	1211 064342	ANATOLIY VOLKOV	{"email": "volkova_091970@postgrespro.ru", "phone": "+70437809097"}
0005432052742	5B49B9	0428 475296	DMITRIY VASILEV	{"phone": "+70522865385"}
0005432052743	E56DED	2912 478974	ALEKSANDR KISELEV	{"phone": "+70873658704"}
0005432052744	26C35B	5961 882303	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov021968@postgrespro.ru", "phone": "+70903768597"}
0005432052745	38BF2C	7932 040414	SERGEY ZAKHAROV	{"phone": "+70826862791"}
0005432052746	38BF2C	4769 926525	ELENA SAVELEVA	{"email": "saveleva_elena10101951@postgrespro.ru", "phone": "+70954689144"}
0005432052747	CABA39	5563 905912	ANNA AKIMOVA	{"email": "annaakimova_06091961@postgrespro.ru", "phone": "+70344481310"}
0005432052748	CABA39	7252 922605	MARIYA SCHERBAKOVA	{"phone": "+70445543806"}
0005432052749	E720B0	1971 296317	TATYANA NAZAROVA	{"email": "t_nazarova.25021966@postgrespro.ru", "phone": "+70028661040"}
0005432052750	31ECA9	7339 154108	KRISTINA KULIKOVA	{"email": "kulikovakristina101973@postgrespro.ru", "phone": "+70056979369"}
0005432052751	EB6932	9716 133464	YURIY SMIRNOV	{"email": "yuriy.smirnov.14101974@postgrespro.ru", "phone": "+70756679533"}
0005432052752	EB6932	6584 238663	NADEZHDA TARASOVA	{"phone": "+70931684082"}
0005432052753	EB6932	0771 648844	VLADIMIR YAKOVLEV	{"phone": "+70767278637"}
0005432052754	4939E1	4973 631141	ALEKSEY ALEKSEEV	{"email": "alekseev.a-30101973@postgrespro.ru", "phone": "+70823421302"}
0005432052755	172932	1111 300039	KLAVDIYA TITOVA	{"phone": "+70423854854"}
0005432052756	172932	1126 959151	DMITRIY MOROZOV	{"email": "morozov-dmitriy121966@postgrespro.ru", "phone": "+70093695972"}
0005432052757	172932	3649 446488	ELENA ZAYCEVA	{"email": "elena.zayceva.16121972@postgrespro.ru", "phone": "+70173813696"}
0005432052758	5D73CB	0204 059197	TATYANA SERGEEVA	{"email": "tatyana-sergeeva_12041976@postgrespro.ru", "phone": "+70940466535"}
0005432052759	FF9540	9115 300939	KSENIYA DMITRIEVA	{"email": "kseniya.dmitrieva.1962@postgrespro.ru", "phone": "+70795471146"}
0005432052760	5933B5	2431 904014	DARYA KOVALEVA	{"phone": "+70192617839"}
0005432052761	EB7065	4949 081097	LYUDMILA BORISOVA	{"email": "lborisova-1973@postgrespro.ru", "phone": "+70530089398"}
0005432052762	EB7065	3727 092437	ALEKSEY ZHURAVLEV	{"email": "zhuravlev.a_1976@postgrespro.ru", "phone": "+70189732600"}
0005432052763	80F73F	4610 442212	SERGEY NIKOLAEV	{"email": "nikolaev.s.1969@postgrespro.ru", "phone": "+70458256806"}
0005432052764	80F73F	2468 853927	PAVEL MEDVEDEV	{"phone": "+70826556809"}
0005432052765	495E47	8426 556893	MIKHAIL FEDOTOV	{"phone": "+70800954390"}
0005432052766	A81FA6	1150 821186	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko.021971@postgrespro.ru", "phone": "+70670813412"}
0005432052767	A13436	8712 460536	TATYANA CHERNOVA	{"phone": "+70492746586"}
0005432052768	3E8D0D	8357 345781	VLADIMIR PAVLOV	{"phone": "+70354101391"}
0005432052769	3E8D0D	4075 025978	NIKOLAY ISAEV	{"phone": "+70521724220"}
0005432052770	3A5715	3418 330104	NINA MAKAROVA	{"phone": "+70613381329"}
0005432052771	F3BBBA	8428 728149	IVAN SOKOLOV	{"phone": "+70382562580"}
0005432052772	5B0933	9755 902658	SVETLANA SEMENOVA	{"email": "s-semenova_021964@postgrespro.ru", "phone": "+70492310748"}
0005432052773	27A937	7477 813991	SERGEY NIKITIN	{"phone": "+70834680272"}
0005432052774	27A937	0797 700021	TAISIYA POPOVA	{"phone": "+70379537469"}
0005432052775	429218	8903 794249	SERGEY ORLOV	{"phone": "+70151798180"}
0005432052776	429218	6509 474509	VALENTINA NESTEROVA	{"email": "vnesterova_071956@postgrespro.ru", "phone": "+70725819572"}
0005432052777	C3DA58	9564 319977	DMITRIY SEMENOV	{"email": "d-semenov-091970@postgrespro.ru", "phone": "+70424934406"}
0005432052778	CF8CE5	4233 418011	VIKTOR VASILEV	{"email": "vasilev_viktor.071975@postgrespro.ru", "phone": "+70762196144"}
0005432052779	CF8CE5	0531 420946	ALEKSANDR SERGEEV	{"email": "a-sergeev-1982@postgrespro.ru", "phone": "+70464064501"}
0005432052780	CF8CE5	0230 778791	RAMIL EGOROV	{"email": "ramil.egorov1965@postgrespro.ru", "phone": "+70358159480"}
0005432052781	B4835C	7393 578824	EVGENIY FILIPPOV	{"email": "efilippov-19071955@postgrespro.ru", "phone": "+70520011022"}
0005432052782	4383CA	9941 058130	OLGA NESTEROVA	{"email": "nesterova-o-04081981@postgrespro.ru", "phone": "+70031865707"}
0005432052783	4383CA	6504 212777	ANDREY KARPOV	{"phone": "+70793297283"}
0005432052784	66242D	2582 767261	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila_07051980@postgrespro.ru", "phone": "+70587869748"}
0005432052785	29F3E3	0996 451677	LYUDMILA SIDOROVA	{"phone": "+70668189781"}
0005432052786	89ED6E	5652 994456	SERGEY BELOV	{"phone": "+70534561795"}
0005432052787	E51D36	1055 101634	GALINA ROMANOVA	{"email": "romanova_g_1972@postgrespro.ru", "phone": "+70115007250"}
0005432052788	C0E589	2197 181811	SERGEY KUZMIN	{"phone": "+70723219882"}
0005432052789	835523	6125 825533	VLADIMIR IVANOV	{"email": "ivanov.vladimir081969@postgrespro.ru", "phone": "+70131485481"}
0005432052790	97FBC6	4700 279662	ILDAR ZAYCEV	{"phone": "+70376701630"}
0005432052791	F76466	3805 625729	VALERIY FOMIN	{"email": "v_fomin081962@postgrespro.ru", "phone": "+70745890821"}
0005432052792	F315EE	3549 165981	ANTON MIRONOV	{"phone": "+70520315140"}
0005432052793	C801D3	8790 013818	PAVEL SOROKIN	{"email": "psorokin-051978@postgrespro.ru", "phone": "+70821433652"}
0005432052794	44BD74	3448 217686	SERGEY FOMIN	{"email": "sergey-fomin_1977@postgrespro.ru", "phone": "+70843650390"}
0005432052795	9F5AE1	6288 183607	IVAN CHERNOV	{"email": "ivan_chernov-071960@postgrespro.ru", "phone": "+70302436995"}
0005432052796	9F5AE1	5223 428161	VLADISLAV KOROLEV	{"email": "vladislav-korolev-03021962@postgrespro.ru", "phone": "+70080203462"}
0005432052797	5EA503	7202 573639	RIMMA OSIPOVA	{"phone": "+70943672189"}
0005432052798	C34724	4305 606090	GALINA FILATOVA	{"email": "filatova.galina-1962@postgrespro.ru", "phone": "+70700482442"}
0005432052799	C34724	0440 639544	PAVEL IVANOV	{"email": "pavel.ivanov_14091987@postgrespro.ru", "phone": "+70185498052"}
0005432052800	87623F	8965 806222	VALENTINA ZAKHAROVA	{"phone": "+70374421954"}
0005432052801	BACFE5	1187 009212	SERGEY ZAKHAROV	{"phone": "+70027773241"}
0005432052802	0333E3	8148 339416	PAVEL ROMANOV	{"email": "promanov25061988@postgrespro.ru", "phone": "+70182606763"}
0005432052803	0333E3	6075 078999	ANTON NIKOLAEV	{"phone": "+70246697294"}
0005432052804	FBC520	1473 330874	OLEG MAKAROV	{"phone": "+70759396405"}
0005432052805	EE6D6C	0611 015058	RAISA NESTEROVA	{"email": "nesterovar-14011975@postgrespro.ru", "phone": "+70047233925"}
0005432052806	289195	2580 019726	MARAT SCHERBAKOV	{"email": "scherbakov.marat10081973@postgrespro.ru", "phone": "+70314492696"}
0005432052807	289195	6023 493690	LIDIYA VASILEVA	{"phone": "+70433629581"}
0005432052808	94F210	0479 737815	TATYANA MALYSHEVA	{"phone": "+70114533735"}
0005432052809	2DBC35	8502 490188	VALERIY KARPOV	{"phone": "+70754905697"}
0005432052810	2DBC35	1373 396699	IGOR STEPANOV	{"email": "stepanov_i_1961@postgrespro.ru", "phone": "+70019234488"}
0005432052811	2B5844	0597 542624	KSENIYA ROMANOVA	{"phone": "+70461503108"}
0005432052812	9F1B66	5618 397700	LIDIYA KOROLEVA	{"phone": "+70747547322"}
0005432052813	AA3795	0926 936220	VALERIY YAKOVLEV	{"email": "valeriy_yakovlev-16011970@postgrespro.ru", "phone": "+70350515830"}
0005432052814	AA3795	4765 307303	OLGA MOROZOVA	{"phone": "+70552220596"}
0005432052815	A6BAEE	5972 145547	PAVEL TARASOV	{"email": "pavel-tarasov081971@postgrespro.ru", "phone": "+70331037284"}
0005432052816	C8442F	1543 991900	ELENA NIKOLAEVA	{"email": "elenanikolaeva-071969@postgrespro.ru", "phone": "+70754105587"}
0005432052817	5549A9	6340 214440	TAMARA NAZAROVA	{"phone": "+70616092746"}
0005432052818	93268D	7483 746245	GALINA KOROLEVA	{"email": "koroleva-g-28011984@postgrespro.ru", "phone": "+70686378334"}
0005432052819	A177EF	2156 121253	VALENTINA IVANOVA	{"email": "valentinaivanova_15051966@postgrespro.ru", "phone": "+70880541952"}
0005432052820	A177EF	7715 295474	TATYANA KUDRYASHOVA	{"email": "kudryashova_tatyana-22121963@postgrespro.ru", "phone": "+70546305180"}
0005432052821	A00FA1	4049 386473	ANASTASIYA KOROLEVA	{"phone": "+70172860861"}
0005432052822	A274DB	0047 290371	IRINA TARASOVA	{"email": "i.tarasova-13011969@postgrespro.ru", "phone": "+70093723893"}
0005432052823	622A8D	1577 775037	NIKITA ROMANOV	{"email": "romanov-n_1975@postgrespro.ru", "phone": "+70585664566"}
0005432052824	0B714A	6989 982169	NATALYA AFANASEVA	{"phone": "+70979041773"}
0005432052825	826B9C	0129 516078	EKATERINA PAVLOVA	{"phone": "+70740617620"}
0005432052826	94DAF1	2590 745204	NADEZHDA KOZLOVA	{"email": "nadezhdakozlova.1968@postgrespro.ru", "phone": "+70930843772"}
0005432052827	94DAF1	6516 201978	STANISLAV MIRONOV	{"email": "s-mironov07081978@postgrespro.ru", "phone": "+70043894834"}
0005432052828	4725D9	5603 974363	DENIS CHERNOV	{"phone": "+70711944517"}
0005432052829	AC2883	3046 138583	NADEZHDA MOISEEVA	{"email": "moiseeva-n-111964@postgrespro.ru", "phone": "+70763089814"}
0005432052830	AC2883	7546 334349	ALEKSANDR SOROKIN	{"email": "asorokin071972@postgrespro.ru", "phone": "+70858752059"}
0005432052831	1D7BBD	2197 461064	NIKITA POPOV	{"phone": "+70159740749"}
0005432054252	4BE5B5	2910 558249	EGOR FOMIN	{"email": "egorfomin-101962@postgrespro.ru", "phone": "+70109983317"}
0005432054253	AEA669	0042 530540	MIKHAIL RODIONOV	{"phone": "+70660409094"}
0005432054254	AEA669	5926 155352	VLADIMIR MELNIKOV	{"phone": "+70962927001"}
0005432054255	4EF007	1833 783650	VIKTOR BELOV	{"phone": "+70231400877"}
0005432054256	4EF007	6877 840084	ALEKSANDR STEPANOV	{"email": "astepanov_1969@postgrespro.ru", "phone": "+70836121205"}
0005432054257	1062E5	5643 974750	TATYANA MALYSHEVA	{"phone": "+70518919210"}
0005432054258	A55769	2484 753871	ARTEM KRASNOV	{"email": "artem-krasnov.101973@postgrespro.ru", "phone": "+70109717132"}
0005432054259	717014	7776 353576	YULIYA GERASIMOVA	{"phone": "+70289369292"}
0005432054260	717014	3549 303386	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr.11091975@postgrespro.ru", "phone": "+70998103751"}
0005432054261	717014	3060 132546	LYUDMILA POPOVA	{"email": "popovalyudmila-101966@postgrespro.ru", "phone": "+70839196621"}
0005432054262	F91C0A	5983 634977	ALEKSANDRA KOZLOVA	{"email": "aleksandra.kozlova_1989@postgrespro.ru", "phone": "+70282682242"}
0005432054263	F91C0A	7639 100125	ALEKSANDR VASILEV	{"email": "vasileva-071968@postgrespro.ru", "phone": "+70797834207"}
0005432054264	B831EB	6626 065345	KRISTINA ERMAKOVA	{"phone": "+70497397382"}
0005432054265	73FA07	6761 586429	SVETLANA FROLOVA	{"phone": "+70745975131"}
0005432054266	327D4F	8509 298457	YULIYA GAVRILOVA	{"email": "gavrilovayuliya_081975@postgrespro.ru", "phone": "+70832016912"}
0005432054267	6CC7FA	7814 230861	GENNADIY MIKHAYLOV	{"email": "mikhaylov_gennadiy_1990@postgrespro.ru", "phone": "+70788459941"}
0005432054268	6CC7FA	2190 081524	TIMOFEY MARTYNOV	{"email": "timofey.martynov-1972@postgrespro.ru", "phone": "+70238815809"}
0005432054269	EFB162	3306 150946	ANTON ZAKHAROV	{"email": "anton_zakharov-051978@postgrespro.ru", "phone": "+70177267006"}
0005432054270	31AF8F	3938 821805	VALERIY DMITRIEV	{"email": "valeriy.dmitriev.1970@postgrespro.ru", "phone": "+70935537323"}
0005432054271	B84489	2227 393571	VALERIYA ANTONOVA	{"email": "v.antonova1970@postgrespro.ru", "phone": "+70062947826"}
0005432054272	B84489	9779 018125	GALINA GORBUNOVA	{"email": "gorbunovagalina-1962@postgrespro.ru", "phone": "+70625591837"}
0005432054273	929A18	9561 021030	LYUDMILA SERGEEVA	{"phone": "+70796227233"}
0005432054274	929A18	7430 217010	ANDREY KUZMIN	{"phone": "+70983342004"}
0005432054275	988A06	8836 772059	ALEKSANDR SOROKIN	{"phone": "+70800272575"}
0005432054276	664B00	8934 547339	LEONID MAKAROV	{"email": "l-makarov-1971@postgrespro.ru", "phone": "+70530457088"}
0005432054277	4C5D53	7753 371662	VYACHESLAV FROLOV	{"phone": "+70518212227"}
0005432054278	4C5D53	0232 006692	ANTON KUZNECOV	{"email": "kuznecov.a.09111973@postgrespro.ru", "phone": "+70095961061"}
0005432054279	45FB50	9997 679943	ROMAN ALEKSEEV	{"phone": "+70005242221"}
0005432054280	66E80B	7408 118686	ANATOLIY SERGEEV	{"phone": "+70366895950"}
0005432054281	8CEDC8	7614 870654	SVETLANA KARPOVA	{"phone": "+70136089172"}
0005432054282	3EF003	7583 751223	ANASTASIYA ZHURAVLEVA	{"phone": "+70754107368"}
0005432054283	3EF003	4761 587528	LARISA KOZLOVA	{"phone": "+70845986459"}
0005432054284	4A131D	5995 919626	VLADIMIR IVANOV	{"phone": "+70159265224"}
0005432054285	4A131D	7151 669307	DIANA KUZNECOVA	{"email": "dkuznecova-091970@postgrespro.ru", "phone": "+70578392313"}
0005432054286	417BEE	4799 654506	TATYANA ROMANOVA	{"phone": "+70669028031"}
0005432054287	51FEB5	4642 914648	NIKITA GAVRILOV	{"phone": "+70740504827"}
0005432054288	B0F680	1147 045718	KONSTANTIN KOROLEV	{"phone": "+70392396277"}
0005432054289	B0F680	6182 228958	ELIZAVETA KUZNECOVA	{"phone": "+70166543546"}
0005432054290	E0A145	0164 364209	IGOR MIKHAYLOV	{"email": "mikhaylov_igor24111969@postgrespro.ru", "phone": "+70874464232"}
0005432054291	E0A145	1779 818768	PETR KUDRYASHOV	{"email": "p-kudryashov.31101973@postgrespro.ru", "phone": "+70854180530"}
0005432054292	B9FBED	9191 038373	TATYANA OSIPOVA	{"phone": "+70028517725"}
0005432054293	7227AF	1195 939403	KONSTANTIN MIKHAYLOV	{"phone": "+70380025830"}
0005432054294	F1D963	0264 359597	ANTON VLASOV	{"email": "a.vlasov041975@postgrespro.ru", "phone": "+70059745724"}
0005432054295	72432D	7685 114205	RINAT STEPANOV	{"email": "rinat_stepanov05051970@postgrespro.ru", "phone": "+70170614809"}
0005432054296	9BC866	5366 724754	ALEKSANDR KAZAKOV	{"email": "kazakov_a-091973@postgrespro.ru", "phone": "+70939236251"}
0005432054297	51EC46	8625 019406	STANISLAV NIKOLAEV	{"email": "nikolaevstanislav-29091976@postgrespro.ru", "phone": "+70808623023"}
0005432054298	51EC46	5214 511427	DMITRIY EGOROV	{"phone": "+70601617997"}
0005432054299	8CDD60	6033 548342	NINA KALININA	{"phone": "+70808989520"}
0005432054300	5184F9	2784 939750	MARIYA IVANOVA	{"email": "m.ivanova_051973@postgrespro.ru", "phone": "+70185555860"}
0005432054301	5184F9	9770 019789	ALEKSANDR ZAYCEV	{"email": "a_zaycev.27011986@postgrespro.ru", "phone": "+70980957846"}
0005432054302	49842D	2923 716431	ELIZAVETA KOROLEVA	{"phone": "+70884529376"}
0005432054303	E15BA1	7555 520905	KONSTANTIN KOZLOV	{"email": "k.kozlov.101971@postgrespro.ru", "phone": "+70998913185"}
0005432054304	E15BA1	8626 533282	TATYANA ROMANOVA	{"email": "t_romanova.16041965@postgrespro.ru", "phone": "+70182989902"}
0005432054305	E1CE34	9676 662617	SERGEY NAZAROV	{"phone": "+70786138822"}
0005432054306	2DE975	5870 433645	OLGA BELYAEVA	{"phone": "+70420822892"}
0005432054307	2DE975	3653 715149	ANNA FILIPPOVA	{"email": "anna-filippova021972@postgrespro.ru", "phone": "+70974384676"}
0005432054308	23C893	5334 700728	NINA ROMANOVA	{"phone": "+70616689252"}
0005432054309	AAB29B	7006 290035	NIKOLAY SERGEEV	{"phone": "+70140120338"}
0005432054310	D94177	5835 867453	VIKTOR IVANOV	{"email": "ivanov-viktor_26041972@postgrespro.ru", "phone": "+70493334201"}
0005432054311	AEBAA7	6203 592264	DANIL FILIPPOV	{"email": "d.filippov021968@postgrespro.ru", "phone": "+70066652919"}
0005432054312	AEBAA7	8908 849988	ELENA SIDOROVA	{"email": "sidorovaelena-1961@postgrespro.ru", "phone": "+70263711551"}
0005432054313	AEBAA7	5383 424066	LYUBOV VASILEVA	{"phone": "+70804250522"}
0005432054314	7AA7C9	9722 086741	NATALYA AKIMOVA	{"email": "akimova-n.1963@postgrespro.ru", "phone": "+70520646747"}
0005432054315	062E39	4240 466382	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey.22091970@postgrespro.ru", "phone": "+70593113100"}
0005432054316	624BD6	2536 790844	KSENIYA KOLESNIKOVA	{"email": "kkolesnikova1971@postgrespro.ru", "phone": "+70451528807"}
0005432054317	624BD6	5235 239593	SERGEY SCHERBAKOV	{"email": "sergeyscherbakov_07011966@postgrespro.ru", "phone": "+70122375926"}
0005432054318	478155	8168 983249	ALEKSANDR BORISOV	{"phone": "+70724263148"}
0005432054319	F9E976	3722 975382	YULIYA PETROVA	{"phone": "+70161417121"}
0005432054320	552D8C	1182 232628	TATYANA FOMINA	{"email": "fomina-tatyana.25071979@postgrespro.ru", "phone": "+70274811684"}
0005432054321	552D8C	5508 441810	ANASTASIYA GRISHINA	{"email": "grishina.a16101978@postgrespro.ru", "phone": "+70536032164"}
0005432054322	552D8C	3528 559642	KSENIYA POLYAKOVA	{"email": "kpolyakova-29101968@postgrespro.ru", "phone": "+70672984648"}
0005432054323	CE2AF5	1419 511099	DMITRIY ALEKSEEV	{"phone": "+70961355278"}
0005432054324	CE2AF5	6920 831194	IRINA PAVLOVA	{"email": "irina.pavlova-29061975@postgrespro.ru", "phone": "+70634886098"}
0005432054325	CE2AF5	3740 748822	DENIS GAVRILOV	{"phone": "+70945401111"}
0005432054326	F1309C	6098 275226	OLGA KUZNECOVA	{"phone": "+70422465191"}
0005432054327	F1309C	2830 300495	ALEKSANDR GORBUNOV	{"email": "gorbunova28051972@postgrespro.ru", "phone": "+70042664776"}
0005432054328	C55BCD	3330 362315	OLGA PETROVA	{"phone": "+70118195470"}
0005432054329	C55BCD	1774 029882	ANDREY KUZNECOV	{"phone": "+70293550478"}
0005432054330	5394DB	2146 972172	VLADIMIR DAVYDOV	{"email": "davydov_v-101979@postgrespro.ru", "phone": "+70089812903"}
0005432054331	C7CA3E	0763 136199	SERGEY SOROKIN	{"phone": "+70174095630"}
0005432054332	C8F4BD	5310 182352	ALEKSEY KOZLOV	{"phone": "+70802970409"}
0005432054333	C8F4BD	0528 759035	NINA SOROKINA	{"phone": "+70121236890"}
0005432054334	86E53F	5024 152833	ANDREY ORLOV	{"email": "orlov-a1973@postgrespro.ru", "phone": "+70077431696"}
0005432054335	86E53F	3296 342668	VIKTOR KUZNECOV	{"email": "kuznecov.v-081971@postgrespro.ru", "phone": "+70990171398"}
0005432054336	0B94B4	9102 034728	OLGA KOLESNIKOVA	{"phone": "+70539495506"}
0005432054337	E19C25	9342 614176	ALEKSANDR FOMIN	{"email": "aleksandrfomin011971@postgrespro.ru", "phone": "+70009564812"}
0005432054338	B0E703	7016 084638	MARIYA AKIMOVA	{"email": "akimova_m18041974@postgrespro.ru", "phone": "+70648808467"}
0005432054339	B0E703	5076 011852	VIKTOR NOVIKOV	{"email": "v-novikov.1976@postgrespro.ru", "phone": "+70074943991"}
0005432054340	B0E703	8095 634749	VYACHESLAV VOLKOV	{"phone": "+70889952679"}
0005432054341	A91054	6366 762713	FEDOR SHEVCHENKO	{"phone": "+70219717171"}
0005432054342	225450	6161 103456	TATYANA KUZNECOVA	{"phone": "+70680150288"}
0005432054343	225450	6189 363758	IVAN IVANOV	{"phone": "+70492303118"}
0005432054344	D9DFB8	9809 755930	BORIS AFANASEV	{"email": "borisafanasev.1975@postgrespro.ru", "phone": "+70707379567"}
0005432054345	761ED1	3845 487412	NIKOLAY GUSEV	{"email": "gusev-n_1979@postgrespro.ru", "phone": "+70983742063"}
0005432054346	EE1EB7	7842 556769	ANASTASIYA YUDINA	{"email": "yudina-a-24041977@postgrespro.ru", "phone": "+70571234995"}
0005432054347	86A464	8767 142079	LARISA ANTONOVA	{"email": "l-antonova.16111979@postgrespro.ru", "phone": "+70752084697"}
0005432054348	86A464	9193 274027	YULIYA KOZLOVA	{"email": "kozlova_yuliya_1972@postgrespro.ru", "phone": "+70489675023"}
0005432054349	27A854	3829 892487	VALENTIN MATVEEV	{"email": "valentinmatveev_1989@postgrespro.ru", "phone": "+70018652393"}
0005432054350	BA30AD	2240 679289	NADEZHDA KUZNECOVA	{"phone": "+70153552720"}
0005432054351	BA30AD	7505 772706	SERGEY STEPANOV	{"phone": "+70593534690"}
0005432054352	C745A7	9962 086962	GALINA ZHURAVLEVA	{"email": "g.zhuravleva_061968@postgrespro.ru", "phone": "+70821412347"}
0005432054353	3D990E	8255 321661	VLADIMIR PAVLOV	{"email": "pavlov_vladimir_1981@postgrespro.ru", "phone": "+70679434110"}
0005432054354	4B0050	5990 078909	VLADIMIR BELOV	{"email": "belovvladimir_011977@postgrespro.ru", "phone": "+70085939131"}
0005432054355	DE28DA	6788 624856	LEONID ANDREEV	{"phone": "+70797613127"}
0005432054356	3C0BEC	1470 543792	MARIYA MATVEEVA	{"email": "matveeva_mariya.031978@postgrespro.ru", "phone": "+70691061287"}
0005432054357	9AE839	2794 412363	ANDREY FILIPPOV	{"phone": "+70421277072"}
0005432054358	8938E0	7594 862175	ELENA ARKHIPOVA	{"email": "arkhipova.e.13121965@postgrespro.ru", "phone": "+70752420945"}
0005432054359	ED24B3	6385 038012	NATALIYA LEBEDEVA	{"phone": "+70914952683"}
0005432054360	ED24B3	0287 357813	EKATERINA ANISIMOVA	{"phone": "+70296396546"}
0005432054361	F1CC87	3503 198697	IRINA GORBUNOVA	{"phone": "+70996540919"}
0005432054362	C6FA6A	8862 755213	EKATERINA EGOROVA	{"phone": "+70502812536"}
0005432054363	B42B86	5473 757024	RAISA ISAEVA	{"phone": "+70635895905"}
0005432054364	B42B86	5132 592533	SERGEY ZAYCEV	{"phone": "+70047136079"}
0005432054365	DF52F9	3106 583517	LYUDMILA SIDOROVA	{"phone": "+70514317145"}
0005432054366	59E786	9212 651939	ANDREY FILIPPOV	{"email": "a_filippov-14051972@postgrespro.ru", "phone": "+70102203140"}
0005432054367	16AA2B	4517 853731	NATALIYA PETROVA	{"phone": "+70293905948"}
0005432054368	16AA2B	3966 263943	GALINA ORLOVA	{"email": "orlova_galina.051963@postgrespro.ru", "phone": "+70049561447"}
0005432054369	AA17DA	4489 612772	TAMARA TIMOFEEVA	{"email": "timofeeva.tamara031978@postgrespro.ru", "phone": "+70221814802"}
0005432054370	9F1E63	2376 460785	VASILIY IVANOV	{"phone": "+70586693225"}
0005432054371	D3830D	2706 317404	SERGEY MIRONOV	{"phone": "+70259542305"}
0005432054372	CBEFE2	6683 560864	OLGA TIMOFEEVA	{"email": "timofeevaolga_051979@postgrespro.ru", "phone": "+70041728720"}
0005432054373	5695D2	4494 827197	NATALYA FOMINA	{"phone": "+70202602761"}
0005432054374	5695D2	9386 730026	INNA KULIKOVA	{"email": "i-kulikova.031970@postgrespro.ru", "phone": "+70315046717"}
0005432054375	D4762C	6106 174148	VLADIMIR ANDREEV	{"phone": "+70693013323"}
0005432054376	4C686A	2988 683403	EKATERINA LEBEDEVA	{"email": "lebedeva_ekaterina-021973@postgrespro.ru", "phone": "+70285680493"}
0005432054377	565309	6714 631646	VALENTINA POPOVA	{"phone": "+70906029440"}
0005432054378	DEE5B7	8768 813686	OLGA KULIKOVA	{"phone": "+70590460435"}
0005432054379	DEE5B7	0945 348833	MARINA POPOVA	{"email": "m_popova_1968@postgrespro.ru", "phone": "+70639491901"}
0005432054380	B74760	4342 793439	TATYANA KONOVALOVA	{"phone": "+70594313047"}
0005432054381	B74760	3179 664882	SVETLANA MOISEEVA	{"phone": "+70651543446"}
0005432054382	964BDC	4707 843066	MARINA MIKHAYLOVA	{"email": "m-mikhaylova_1973@postgrespro.ru", "phone": "+70771493097"}
0005432054383	964BDC	3332 503087	DANIIL KUZNECOV	{"phone": "+70189355917"}
0005432054384	964BDC	1197 721324	SERGEY PAVLOV	{"email": "sergey-pavlov-111968@postgrespro.ru", "phone": "+70280905861"}
0005432054385	964BDC	1331 237800	VLADIMIR IVANOV	{"phone": "+70324108363"}
0005432054386	45670A	0774 893843	ANASTASIYA POPOVA	{"phone": "+70099467624"}
0005432054387	68F12F	3983 881557	SAVELIY POPOV	{"phone": "+70317855752"}
0005432054388	2BA71B	1601 000665	NADEZHDA POPOVA	{"email": "popova_n.1983@postgrespro.ru", "phone": "+70485785161"}
0005432054389	2BA71B	4939 518834	NATALYA OSIPOVA	{"phone": "+70617054470"}
0005432054390	2BA71B	7969 789240	ARTEM KRASNOV	{"phone": "+70211707110"}
0005432054391	31E4E1	5123 995964	ARTEM SOROKIN	{"phone": "+70417920622"}
0005432054392	3119FA	2470 284253	ZAKHAR IVANOV	{"email": "ivanov.zakhar-1976@postgrespro.ru", "phone": "+70360478236"}
0005432054393	CE29FE	7600 601422	VERA GAVRILOVA	{"phone": "+70690865391"}
0005432056231	EFF22F	4119 137694	MARINA ROMANOVA	{"phone": "+70969631878"}
0005432056232	90296F	4760 322900	OLGA RODIONOVA	{"email": "rodionova-o.24091956@postgrespro.ru", "phone": "+70772111000"}
0005432056233	180B8D	0258 702741	IVAN MOISEEV	{"email": "moiseevivan.021973@postgrespro.ru", "phone": "+70381921988"}
0005432056234	F2443D	9331 687698	ANATOLIY VOLKOV	{"phone": "+70211651390"}
0005432056235	953681	7773 763552	ARINA VASILEVA	{"phone": "+70771405699"}
0005432056236	22664C	5209 767292	SERGEY VASILEV	{"email": "vasilev.sergey-111979@postgrespro.ru", "phone": "+70275658755"}
0005432056237	E8DA86	3872 127886	LARISA LAZAREVA	{"email": "lazareva_larisa-04081975@postgrespro.ru", "phone": "+70815194505"}
0005432056238	C5055A	2725 183811	DANIL MOROZOV	{"email": "danilmorozov-16011972@postgrespro.ru", "phone": "+70663310056"}
0005432056239	F82EC3	2996 166803	ANNA BOGDANOVA	{"email": "bogdanova.a.1968@postgrespro.ru", "phone": "+70578996063"}
0005432056240	77140F	5248 674828	VALENTINA FOMINA	{"email": "valentina.fomina061987@postgrespro.ru", "phone": "+70570285093"}
0005432056241	77140F	1618 732685	DANIIL IVANOV	{"email": "ivanovdaniil.101972@postgrespro.ru", "phone": "+70574030811"}
0005432056242	15D59E	7519 753723	YURIY ALEKSANDROV	{"phone": "+70750138358"}
0005432056243	DB2206	0709 738858	SERGEY STEPANOV	{"phone": "+70068023140"}
0005432056244	DB2206	5435 944919	ELENA VLASOVA	{"email": "vlasova-elena.1972@postgrespro.ru", "phone": "+70973825412"}
0005432056245	542357	0397 124408	INNA BOGDANOVA	{"email": "inna.bogdanova-1967@postgrespro.ru", "phone": "+70479837519"}
0005432056246	9B6CBD	0637 882521	VLADIMIR BONDARENKO	{"email": "vladimirbondarenko-091966@postgrespro.ru", "phone": "+70353209584"}
0005432056247	9B6CBD	9534 050326	ANNA EGOROVA	{"email": "egorovaanna.1969@postgrespro.ru", "phone": "+70005683883"}
0005432056248	C24E86	9975 265357	EVGENIYA NIKITINA	{"phone": "+70205365724"}
0005432056249	C24E86	5293 276372	OLGA BOGDANOVA	{"phone": "+70252083861"}
0005432056250	C24E86	1662 874134	LIDIYA ABRAMOVA	{"phone": "+70714606934"}
0005432056251	280C80	6515 229262	NADEZHDA VOROBEVA	{"email": "nvorobeva011979@postgrespro.ru", "phone": "+70814440340"}
0005432056252	37FD9C	0278 693778	MARIYA KUZMINA	{"email": "mariyakuzmina_071987@postgrespro.ru", "phone": "+70369063819"}
0005432056253	37FD9C	0198 184024	OLGA CHERNOVA	{"email": "olga-chernova.17111979@postgrespro.ru", "phone": "+70536692456"}
0005432056254	684878	3950 475463	VLADIMIR MOROZOV	{"email": "vladimir_morozov_011966@postgrespro.ru", "phone": "+70857686703"}
0005432056255	B34316	0796 984155	LIDIYA PETROVA	{"email": "petrova_l.14011966@postgrespro.ru", "phone": "+70083414168"}
0005432056256	C1516A	2712 377256	VALENTINA KOZLOVA	{"email": "v_kozlova061967@postgrespro.ru", "phone": "+70121228199"}
0005432056257	CC9408	2865 570559	OLGA GERASIMOVA	{"phone": "+70409330477"}
0005432056258	D8111C	1586 399220	ANASTASIYA LEBEDEVA	{"phone": "+70044341863"}
0005432056259	625474	2689 630015	NIKOLAY MELNIKOV	{"email": "n.melnikov.1961@postgrespro.ru", "phone": "+70892573646"}
0005432056260	65EF87	2021 101022	SERGEY EGOROV	{"phone": "+70882905646"}
0005432056261	65EF87	4395 153405	VLADIMIR KISELEV	{"phone": "+70250829296"}
0005432056262	A0302F	3650 286771	KSENIYA NIKITINA	{"phone": "+70216629057"}
0005432056263	972B52	4322 522318	EGOR SHEVCHENKO	{"phone": "+70320086025"}
0005432056264	A2B054	0397 022758	EKATERINA KUZNECOVA	{"email": "e.kuznecova-1973@postgrespro.ru", "phone": "+70587652423"}
0005432056265	D1FCD5	0681 592551	MARIYA SMIRNOVA	{"email": "smirnova.m-10041964@postgrespro.ru", "phone": "+70587233117"}
0005432056266	9EBD8C	5309 608316	ILYA NIKOLAEV	{"email": "nikolaev-ilya_02021968@postgrespro.ru", "phone": "+70671185240"}
0005432056267	9EBD8C	9236 525438	VLADISLAV GERASIMOV	{"phone": "+70457625310"}
0005432056268	D0782D	5708 783343	GYUZEL VASILEVA	{"email": "g.vasileva21111978@postgrespro.ru", "phone": "+70124401199"}
0005432056269	572DB0	1108 982066	ANDREY SOKOLOV	{"phone": "+70272747891"}
0005432056270	572DB0	0806 628244	LARISA KUZNECOVA	{"email": "kuznecova_l-17101970@postgrespro.ru", "phone": "+70573139919"}
0005432056271	27595F	8472 855532	NATALIYA NIKITINA	{"phone": "+70079975511"}
0005432056272	E4EDEA	5496 498117	MIKHAIL ZHUKOV	{"phone": "+70287614675"}
0005432056273	B88C2F	4542 389329	MARIYA BORISOVA	{"email": "m.borisova16021973@postgrespro.ru", "phone": "+70625408531"}
0005432056274	F831BE	2079 159803	VIKTOR SEMENOV	{"email": "v.semenov.1972@postgrespro.ru", "phone": "+70043274891"}
0005432056275	F831BE	2950 417380	SERGEY POPOV	{"phone": "+70353285501"}
0005432056276	575E36	2973 305622	NELLI VASILEVA	{"phone": "+70389755692"}
0005432056277	575E36	2243 519229	VASILIY SIDOROV	{"email": "sidorov_vasiliy-081962@postgrespro.ru", "phone": "+70412324064"}
0005432056278	645D4C	3526 540776	NIKOLAY MOISEEV	{"email": "moiseev.n.13071976@postgrespro.ru", "phone": "+70227587097"}
0005432056279	645D4C	0793 325187	ARSENIY VASILEV	{"email": "arseniy.vasilev_1979@postgrespro.ru", "phone": "+70104525832"}
0005432056280	C1DAC5	9002 354430	ALEKSEY KAZAKOV	{"phone": "+70560656608"}
0005432056281	C1DAC5	4003 257193	STEPAN KAZAKOV	{"phone": "+70416420768"}
0005432056282	3149E2	3654 882487	OLGA ALEKSEEVA	{"email": "alekseeva-olga.27061983@postgrespro.ru", "phone": "+70844926983"}
0005432056283	C8E45C	3416 453044	KLAVDIYA DANILOVA	{"phone": "+70629534924"}
0005432056284	C8E45C	7788 071015	YULIYA KUZNECOVA	{"phone": "+70454627009"}
0005432056285	56BB48	2360 001287	GULSHAT POPOVA	{"phone": "+70738710346"}
0005432056286	56BB48	3680 273815	ROMAN BORISOV	{"email": "romanborisov_1979@postgrespro.ru", "phone": "+70411901920"}
0005432056287	56BB48	4761 292137	RADMIR MELNIKOV	{"email": "melnikov_radmir-01091975@postgrespro.ru", "phone": "+70351903096"}
0005432056288	B30BC0	0438 992526	GENNADIY VASILEV	{"phone": "+70626278115"}
0005432056289	F2ADB5	8251 560464	KONSTANTIN ZAKHAROV	{"phone": "+70080696446"}
0005432056290	F2ADB5	8298 880623	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov051964@postgrespro.ru", "phone": "+70248724053"}
0005432056291	5C5020	4084 801583	ELENA VLASOVA	{"email": "elena-vlasova121966@postgrespro.ru", "phone": "+70911749169"}
0005432056292	64F130	8863 699105	ANNA KOMAROVA	{"phone": "+70867898574"}
0005432056293	F18CEF	2244 244989	ALEKSANDR TIKHONOV	{"email": "atikhonov.1960@postgrespro.ru", "phone": "+70954258941"}
0005432056294	F18CEF	4747 023165	YURIY KUZNECOV	{"email": "ykuznecov_081976@postgrespro.ru", "phone": "+70009672217"}
0005432056295	C39E1A	8403 866037	VERA KAZAKOVA	{"phone": "+70642550768"}
0005432056296	4CECDF	1003 975538	MARINA IVANOVA	{"email": "ivanova.m_24101971@postgrespro.ru", "phone": "+70033597295"}
0005432056297	4A9A90	7832 469658	PETR SHEVCHENKO	{"email": "shevchenko.p071964@postgrespro.ru", "phone": "+70215665566"}
0005432056298	488A71	0360 120451	TAMARA TROFIMOVA	{"phone": "+70131179594"}
0005432056299	057076	8913 670845	IGOR MOISEEV	{"email": "moiseev-igor-021975@postgrespro.ru", "phone": "+70750269369"}
0005432056300	057076	9357 283752	NADEZHDA SERGEEVA	{"email": "n_sergeeva.03021969@postgrespro.ru", "phone": "+70286081451"}
0005432056301	20C7C9	9628 860650	VIKTORIYA POPOVA	{"phone": "+70973889996"}
0005432056302	EDE34E	9885 688535	OKSANA DENISOVA	{"email": "oksana_denisova_1977@postgrespro.ru", "phone": "+70026247779"}
0005432056303	5A1C45	2359 514440	VALERIY SAVELEV	{"email": "savelev-valeriy-1975@postgrespro.ru", "phone": "+70215577759"}
0005432056304	5A1C45	7770 095158	ANDREY MEDVEDEV	{"email": "a.medvedev_11021964@postgrespro.ru", "phone": "+70106078500"}
0005432056305	B54A03	3166 670571	DARYA ANDREEVA	{"phone": "+70434667254"}
0005432056306	09BE76	1108 024879	SERGEY ZAYCEV	{"email": "zaycev-sergey-061971@postgrespro.ru", "phone": "+70873871952"}
0005432056307	49B8E9	7908 502367	LIDIYA BELOVA	{"phone": "+70745503676"}
0005432056308	215E6D	5307 676756	YURIY MOROZOV	{"email": "yuriy_morozov.031970@postgrespro.ru", "phone": "+70144568985"}
0005432056309	215E6D	5946 991240	NIKOLAY GUSEV	{"email": "gusev.nikolay.1974@postgrespro.ru", "phone": "+70450012734"}
0005432056310	AF079E	7344 518850	TATYANA ISAEVA	{"phone": "+70981138429"}
0005432056311	AF079E	2165 130711	DANILA ROMANOV	{"email": "romanov.d.08121971@postgrespro.ru", "phone": "+70846057855"}
0005432056312	771023	1425 359219	NATALYA TIMOFEEVA	{"phone": "+70240636637"}
0005432056313	B20D43	8124 855137	BORIS ANDREEV	{"phone": "+70289466737"}
0005432056314	71CF87	2520 522486	YURIY GORBUNOV	{"phone": "+70655351001"}
0005432056315	5A19D2	3728 544068	VALENTINA MATVEEVA	{"phone": "+70409830695"}
0005432056316	5A19D2	2502 032568	MILANA GERASIMOVA	{"email": "gerasimova_m-21101969@postgrespro.ru", "phone": "+70223134000"}
0005432056317	68573E	9811 979383	OLGA SOLOVEVA	{"phone": "+70670854021"}
0005432056318	0A4D2F	5560 540026	LIDIYA NAZAROVA	{"email": "nazarova-l111971@postgrespro.ru", "phone": "+70237986141"}
0005432056319	A7AA59	8140 230684	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir_011967@postgrespro.ru", "phone": "+70258245656"}
0005432056320	A7AA59	9534 569508	EGOR POPOV	{"email": "popov_e091982@postgrespro.ru", "phone": "+70539093256"}
0005432056321	D35BB1	3541 892071	LYUDMILA NAZAROVA	{"email": "nazarovalyudmila_021969@postgrespro.ru", "phone": "+70078210527"}
0005432056322	B1AB43	6157 494271	ANATOLIY MOROZOV	{"email": "morozova.031972@postgrespro.ru", "phone": "+70549341570"}
0005432056323	938412	2957 513643	DENIS MELNIKOV	{"phone": "+70153298890"}
0005432056324	AC1296	7750 286211	ALEKSANDR FOMIN	{"email": "aleksandr-fomin_1964@postgrespro.ru", "phone": "+70647227181"}
0005432056325	8E79B2	2797 740324	ELENA KONOVALOVA	{"email": "elena-konovalova_031967@postgrespro.ru", "phone": "+70119214495"}
0005432056326	8E79B2	1025 555462	DMITRIY DAVYDOV	{"phone": "+70782651258"}
0005432056327	B78973	5925 970790	TAMARA KUDRYASHOVA	{"phone": "+70698506544"}
0005432056328	1BC6FF	0518 134811	SERGEY KUDRYASHOV	{"email": "kudryashov_s21011966@postgrespro.ru", "phone": "+70723632804"}
0005432056329	DF34F7	4474 234351	ANNA GRISHINA	{"email": "grishinaanna_011977@postgrespro.ru", "phone": "+70109008863"}
0005432056330	3645E7	9732 094761	NINA ALEKSEEVA	{"email": "alekseeva-n_1970@postgrespro.ru", "phone": "+70041956288"}
0005432056331	3645E7	1624 913165	GALINA ALEKSANDROVA	{"phone": "+70467300130"}
0005432056332	CF364C	4611 634434	MARIYA IVANOVA	{"email": "m_ivanova-19051980@postgrespro.ru", "phone": "+70026267678"}
0005432056333	94AA59	2409 437741	SVETLANA ALEKSEEVA	{"email": "alekseeva-s_061971@postgrespro.ru", "phone": "+70179883689"}
0005432056334	DA6EB1	9388 145431	SERGEY KULIKOV	{"email": "kulikovsergey1973@postgrespro.ru", "phone": "+70688775088"}
0005432056335	D97020	3526 687046	VITALIY MIRONOV	{"email": "mironov_vitaliy091974@postgrespro.ru", "phone": "+70444025152"}
0005432056336	D97020	4831 570917	EKATERINA SOKOLOVA	{"phone": "+70631851514"}
0005432056337	D97558	1300 598476	ALEKSANDR POPOV	{"email": "popovaleksandr_13041962@postgrespro.ru", "phone": "+70237568978"}
0005432056338	1E23E0	1176 290372	KONSTANTIN FEDOROV	{"email": "fedorovk121967@postgrespro.ru", "phone": "+70684615193"}
0005432056339	1E23E0	4452 917282	ANATOLIY KUZMIN	{"phone": "+70786304940"}
0005432056340	5529EC	6359 870228	ANNA EGOROVA	{"email": "egorovaanna26041966@postgrespro.ru", "phone": "+70930862427"}
0005432056341	B5700B	0726 270914	MIKHAIL KRASNOV	{"phone": "+70382913456"}
0005432056342	B5700B	4252 727304	VIKTORIYA IVANOVA	{"email": "v_ivanova_091967@postgrespro.ru", "phone": "+70548544350"}
0005432056343	754F67	1802 554774	ANASTASIYA TARASOVA	{"email": "a.tarasova_22041987@postgrespro.ru", "phone": "+70931786903"}
0005432056344	B2870C	3810 671984	ELENA NAZAROVA	{"email": "nazarovaelena-28041967@postgrespro.ru", "phone": "+70244704643"}
0005432056345	B2870C	5336 628168	YURIY KAZAKOV	{"phone": "+70444254102"}
0005432056346	41A1B5	6536 076028	ALEKSANDR OSIPOV	{"phone": "+70605212286"}
0005432056347	92B7A6	5358 887544	ARTEM VLASOV	{"phone": "+70920497003"}
0005432056348	8DD4C8	3534 012999	YAROSLAV YAKOVLEV	{"email": "yakovlev-y-19071979@postgrespro.ru", "phone": "+70931814707"}
0005432056349	675670	1211 787658	TAMARA VASILEVA	{"phone": "+70659497823"}
0005432056350	79785C	6663 230705	KAPITALINA SOKOLOVA	{"email": "sokolova.k-04121974@postgrespro.ru", "phone": "+70797843886"}
0005432056351	79785C	1994 394716	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey091974@postgrespro.ru", "phone": "+70511061791"}
0005432056352	518538	5858 114205	GENNADIY EGOROV	{"email": "gennadiy_egorov06091964@postgrespro.ru", "phone": "+70440167007"}
0005432056353	518538	3033 344451	ELENA LAZAREVA	{"email": "lazareva-e-051971@postgrespro.ru", "phone": "+70143934634"}
0005432056354	AB9A0A	4011 953762	RUSLAN GORBUNOV	{"email": "gorbunovruslan.05061972@postgrespro.ru", "phone": "+70707015478"}
0005432056355	13776F	7523 041007	GEORGIY GRIGOREV	{"email": "grigorev_g19021969@postgrespro.ru", "phone": "+70056800324"}
0005432056356	13776F	2078 542403	TATYANA KUZNECOVA	{"phone": "+70974531796"}
0005432056357	13776F	2964 935737	MARINA RODIONOVA	{"phone": "+70255696662"}
0005432056358	145AAE	4795 454772	ANTONINA POPOVA	{"phone": "+70573844554"}
0005432056359	66A16B	7902 902950	OLGA RODIONOVA	{"phone": "+70730512923"}
0005432056360	1F050B	2747 882323	EVGENIY FILIPPOV	{"phone": "+70568333552"}
0005432056361	1F050B	2965 725337	VERA ZAKHAROVA	{"email": "zakharova-v-1980@postgrespro.ru", "phone": "+70777735291"}
0005432056362	AE2E65	6516 146645	MATVEY SERGEEV	{"phone": "+70153539948"}
0005432056363	B878EB	9224 702017	ALEKSANDR FROLOV	{"email": "aleksandr_frolov-29081969@postgrespro.ru", "phone": "+70862834396"}
0005432056364	ACADF2	8136 802677	SERGEY NIKOLAEV	{"phone": "+70233468085"}
0005432056365	15B928	7101 945729	RINAT NAZAROV	{"email": "nazarov_rinat.25031980@postgrespro.ru", "phone": "+70357827220"}
0005432056366	ED7F77	8854 716930	VLADIMIR OSIPOV	{"email": "osipovvladimir081969@postgrespro.ru", "phone": "+70141897120"}
0005432056367	D2971F	4581 363243	ANNA NIKITINA	{"email": "annanikitina.101972@postgrespro.ru", "phone": "+70658881903"}
0005432056368	D2971F	1034 213826	NIKOLAY POPOV	{"email": "n-popov.031972@postgrespro.ru", "phone": "+70328023666"}
0005432056369	90271F	8181 049204	IVAN KUZNECOV	{"phone": "+70590858382"}
0005432056370	90271F	3969 033661	VERA MEDVEDEVA	{"phone": "+70114397770"}
0005432056371	E2873D	4253 886392	IVAN ROMANOV	{"phone": "+70415504541"}
0005432056372	B8BF6D	6294 212611	GALINA DENISOVA	{"email": "galina.denisova_051970@postgrespro.ru", "phone": "+70392307327"}
0005432056373	642025	7389 587107	KONSTANTIN DAVYDOV	{"phone": "+70694550785"}
0005432056374	642025	0002 950506	VALENTINA MAKAROVA	{"phone": "+70484642091"}
0005432056375	BAF370	4222 079629	ELIZAVETA SIDOROVA	{"email": "sidorovaelizaveta.01091967@postgrespro.ru", "phone": "+70612519437"}
0005432056376	348F48	4559 715458	TATYANA ILINA	{"phone": "+70292555398"}
0005432056377	348F48	0627 054519	LYUDMILA MAKAROVA	{"email": "makarova.l-091972@postgrespro.ru", "phone": "+70498984193"}
0005432056378	50C8B2	7632 549898	YULIYA EGOROVA	{"email": "egorova_yuliya_1968@postgrespro.ru", "phone": "+70098174148"}
0005432056379	DFB942	0422 759551	ALEKSEY NAZAROV	{"phone": "+70962103203"}
0005432056380	B84B23	9662 143798	OLGA BARANOVA	{"email": "baranova-o.101964@postgrespro.ru", "phone": "+70596702101"}
0005432056381	2F0F78	2366 898330	VLADIMIR SOROKIN	{"email": "v-sorokin_1957@postgrespro.ru", "phone": "+70444320176"}
0005432056382	ECFADC	9476 708710	VALENTINA SEMENOVA	{"phone": "+70927045801"}
0005432056383	AD684F	7867 674989	DMITRIY IVANOV	{"phone": "+70167953689"}
0005432056384	AD684F	9625 561102	ANNA KONDRATEVA	{"phone": "+70409735124"}
0005432056385	AF814F	5394 648028	DMITRIY ZAKHAROV	{"email": "d-zakharov_101966@postgrespro.ru", "phone": "+70705454564"}
0005432056386	1FE206	8796 728101	MARINA SMIRNOVA	{"email": "smirnova_m1976@postgrespro.ru", "phone": "+70716141575"}
0005432056387	1FE206	3951 790886	YULIYA KOLESNIKOVA	{"phone": "+70046489285"}
0005432056388	9C2EC0	9904 699678	ANATOLIY GUSEV	{"email": "gusev-anatoliy1981@postgrespro.ru", "phone": "+70081501129"}
0005432056389	DBC632	5279 686399	VASILIY VLASOV	{"email": "vasiliy.vlasov18101970@postgrespro.ru", "phone": "+70899179277"}
0005432056390	FAA034	3467 655462	SVETLANA KAZAKOVA	{"phone": "+70805285001"}
0005432056391	FAA034	5100 540783	ZINAIDA DENISOVA	{"phone": "+70690416226"}
0005432056392	C66FD9	9433 273154	ELIZAVETA FILATOVA	{"phone": "+70370121086"}
0005432056393	C66FD9	5793 961311	RAMIL KUZNECOV	{"phone": "+70473950545"}
0005432056394	1BCCCA	4312 057136	IGOR PETROV	{"phone": "+70748364808"}
0005432056395	C0CB89	9290 909875	ALEKSANDR BORISOV	{"phone": "+70669336407"}
0005432056396	F636F5	5799 523801	MAKAR FEDOROV	{"phone": "+70985952182"}
0005432056397	391493	0323 020384	NIKOLAY IVANOV	{"email": "ivanovn.1972@postgrespro.ru", "phone": "+70541013860"}
0005432056398	395B91	9713 852697	NATALYA KUZNECOVA	{"phone": "+70233770224"}
0005432056399	A55C44	8823 091020	ALEKSANDR KISELEV	{"email": "akiselev-051969@postgrespro.ru", "phone": "+70116492524"}
0005432056400	F5E180	2429 623903	IGOR BELOV	{"email": "belov.i121981@postgrespro.ru", "phone": "+70664120227"}
0005432056401	F5E180	0772 946067	POLINA IVANOVA	{"email": "ivanova_polina-1972@postgrespro.ru", "phone": "+70750260224"}
0005432056402	BC2633	5722 566749	NATALYA KUZNECOVA	{"email": "natalyakuznecova.01091976@postgrespro.ru", "phone": "+70974337725"}
0005432056403	1BE090	6899 693715	ARKADIY SOKOLOV	{"phone": "+70530434460"}
0005432056404	1BE090	5525 645778	ANDREY SEMENOV	{"email": "andreysemenov.16011962@postgrespro.ru", "phone": "+70699070864"}
0005432056405	41BBAF	1369 867662	DMITRIY NIKITIN	{"email": "nikitind_1974@postgrespro.ru", "phone": "+70821010361"}
0005432056406	A093BB	8856 099029	TAMARA SOLOVEVA	{"email": "t.soloveva_28111973@postgrespro.ru", "phone": "+70228294654"}
0005432056407	528EF6	9999 580550	IGOR VLASOV	{"email": "vlasov.i-20031969@postgrespro.ru", "phone": "+70784642162"}
0005432058312	99F12B	9529 955790	ANNA CHERNOVA	{"email": "chernova.anna.14111977@postgrespro.ru", "phone": "+70030920156"}
0005432058313	C21205	1126 595197	VIKTOR YAKOVLEV	{"email": "yakovlevv101972@postgrespro.ru", "phone": "+70042766039"}
0005432058314	6E1E84	9363 499643	LYUBOV IVANOVA	{"phone": "+70513171547"}
0005432058315	6E1E84	8461 963749	VALENTINA BOGDANOVA	{"phone": "+70378439721"}
0005432058316	BDB455	4274 968356	ANATOLIY NIKITIN	{"email": "a.nikitin-1963@postgrespro.ru", "phone": "+70324523790"}
0005432058317	DE991D	9330 240369	ANTONINA ANDREEVA	{"email": "a_andreeva081973@postgrespro.ru", "phone": "+70040013691"}
0005432058318	8B9C82	0683 629014	EVGENIY FEDOROV	{"email": "fedorov_e_111979@postgrespro.ru", "phone": "+70208610289"}
0005432058319	8B9C82	2159 681662	ANTON KISELEV	{"email": "a_kiselev_1971@postgrespro.ru", "phone": "+70742078153"}
0005432058320	8C2536	8603 640019	ARTEM IVANOV	{"phone": "+70574443218"}
0005432058321	8C2536	7830 727341	TAMARA KOZLOVA	{"phone": "+70740008684"}
0005432058322	090E18	7093 670834	OLGA BOGDANOVA	{"email": "olga.bogdanova.09091972@postgrespro.ru", "phone": "+70948864117"}
0005432058323	C06FB2	0029 684640	VYACHESLAV VOLKOV	{"phone": "+70903285220"}
0005432058324	C06FB2	3594 848391	TAMARA DENISOVA	{"email": "denisova_t_1967@postgrespro.ru", "phone": "+70674357290"}
0005432058325	A10734	0759 652788	SERGEY KOZLOV	{"email": "sergey_kozlov1982@postgrespro.ru", "phone": "+70937100587"}
0005432058326	A10734	9952 726301	VITALIY SERGEEV	{"email": "vitaliysergeev.1980@postgrespro.ru", "phone": "+70369077574"}
0005432058327	D057F9	6740 167966	TATYANA KUZNECOVA	{"email": "t.kuznecova1973@postgrespro.ru", "phone": "+70098753441"}
0005432058328	014FA3	4809 887933	IRINA CHERNOVA	{"phone": "+70890377868"}
0005432058329	014FA3	7702 800586	EVGENIY SMIRNOV	{"email": "smirnov.evgeniy081973@postgrespro.ru", "phone": "+70485943623"}
0005432058330	014FA3	6187 017874	VADIM GUSEV	{"email": "gusevv-24031975@postgrespro.ru", "phone": "+70689689252"}
0005432058331	6502C6	0554 506168	KSENIYA FILIPPOVA	{"phone": "+70736670647"}
0005432058332	6D010F	3422 053825	AIDA MIKHAYLOVA	{"email": "aidamikhaylova_1967@postgrespro.ru", "phone": "+70429483174"}
0005432058333	636B97	0103 523384	MAKSIM RODIONOV	{"phone": "+70468017958"}
0005432058334	636B97	0059 474685	EVGENIY SEMENOV	{"email": "semenove.1966@postgrespro.ru", "phone": "+70111202765"}
0005432058335	D79B79	2766 111294	ILYA VASILEV	{"email": "vasilev.ilya.1962@postgrespro.ru", "phone": "+70448742563"}
0005432058336	D79B79	5058 130885	IRINA VOROBEVA	{"email": "vorobevai.1962@postgrespro.ru", "phone": "+70127770795"}
0005432058337	72885E	9235 522027	NATALYA YUDINA	{"email": "natalya-yudina.17101968@postgrespro.ru", "phone": "+70242287964"}
0005432058338	72885E	6495 036487	YULIYA VASILEVA	{"email": "yuliya-vasileva.061973@postgrespro.ru", "phone": "+70535014257"}
0005432058339	CBF69E	1585 208048	MARIYA POPOVA	{"phone": "+70288421339"}
0005432058340	2AC953	7698 694509	ANASTASIYA MELNIKOVA	{"phone": "+70544324397"}
0005432058341	A97557	9310 360527	VERA ALEKSANDROVA	{"email": "aleksandrova.v-081964@postgrespro.ru", "phone": "+70941932861"}
0005432058342	A97557	4026 627135	YURIY SOLOVEV	{"phone": "+70369739680"}
0005432058343	44DF9B	0962 941083	ALEKSEY MAKAROV	{"email": "makarov.aleksey.28121980@postgrespro.ru", "phone": "+70633746571"}
0005432058344	8E1338	9705 962751	YURIY SHEVCHENKO	{"phone": "+70968057931"}
0005432058345	8E1338	1046 001570	NIKOLAY DAVYDOV	{"phone": "+70134664026"}
0005432058346	594CF0	7446 166211	POLINA FILIPPOVA	{"email": "polinafilippova-091966@postgrespro.ru", "phone": "+70920057995"}
0005432058347	04A99F	8718 177733	NIKOLAY BELOV	{"phone": "+70229386007"}
0005432058348	51386C	4075 184951	LYUBOV MATVEEVA	{"phone": "+70148283047"}
0005432058349	8B0FF4	0864 889424	ARTEM KUZMIN	{"email": "kuzmin-artem-1965@postgrespro.ru", "phone": "+70431789347"}
0005432058350	B932D8	5032 672876	NATALYA AKIMOVA	{"email": "akimova.n_101980@postgrespro.ru", "phone": "+70486448688"}
0005432058351	B932D8	2486 552472	YULIYA KOROLEVA	{"email": "y-koroleva.26071962@postgrespro.ru", "phone": "+70474573542"}
0005432058352	B00F66	7525 714696	LYUDMILA ZOTOVA	{"phone": "+70210565957"}
0005432058353	B00F66	9802 859666	ALEKSANDR SCHERBAKOV	{"phone": "+70566576185"}
0005432058354	35B634	7409 648942	MARIYA MAKAROVA	{"phone": "+70711883901"}
0005432058355	FE2625	1130 231137	ANASTASIYA KULIKOVA	{"email": "anastasiya-kulikova.111972@postgrespro.ru", "phone": "+70501634141"}
0005432058356	FE2625	1577 386894	EVGENIYA CHERNOVA	{"phone": "+70496779898"}
0005432058357	5748DF	3856 361552	LYUBOV BARANOVA	{"email": "l.baranova1975@postgrespro.ru", "phone": "+70916611411"}
0005432058358	3D2097	6321 140475	KRISTINA MAKSIMOVA	{"phone": "+70572995839"}
0005432058359	30984C	0023 511453	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_s1980@postgrespro.ru", "phone": "+70317413667"}
0005432058360	06F7BE	0177 010251	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.1976@postgrespro.ru", "phone": "+70668117298"}
0005432058361	06F7BE	8427 666544	LARISA ANISIMOVA	{"phone": "+70665440300"}
0005432058362	06F7BE	0363 211731	VIKTOR SCHERBAKOV	{"email": "vscherbakov.1968@postgrespro.ru", "phone": "+70634026302"}
0005432058363	35202B	7433 214065	YULIYA SAVELEVA	{"email": "y_saveleva-1974@postgrespro.ru", "phone": "+70194356198"}
0005432058364	63D04E	1107 976650	GENNADIY MOROZOV	{"email": "morozov_g02111966@postgrespro.ru", "phone": "+70948527520"}
0005432058365	94FCEB	6467 889480	VYACHESLAV KISELEV	{"email": "kiselev-v.051979@postgrespro.ru", "phone": "+70145034249"}
0005432058366	94FCEB	8631 428556	RAMIS NAUMOV	{"email": "ramis_naumov-051975@postgrespro.ru", "phone": "+70319557262"}
0005432058367	C390FC	0749 240037	GALINA NESTEROVA	{"email": "nesterovagalina1974@postgrespro.ru", "phone": "+70522804484"}
0005432058368	6EA2AA	5869 879840	ALEKSANDR KOROLEV	{"email": "korolevaleksandr-021984@postgrespro.ru", "phone": "+70947837264"}
0005432058369	6F45DC	4431 102683	IGOR KOROLEV	{"email": "ikorolev1970@postgrespro.ru", "phone": "+70028359894"}
0005432058370	E6DDB2	2344 273709	VLADIMIR ANDREEV	{"phone": "+70704821758"}
0005432058371	411575	9465 510375	OLGA POPOVA	{"email": "o-popova_071971@postgrespro.ru", "phone": "+70670325801"}
0005432058372	56630D	2286 093629	VALENTINA FADEEVA	{"email": "fadeeva.valentina.24091971@postgrespro.ru", "phone": "+70267229976"}
0005432058373	48175F	4350 016486	ANASTASIYA KULIKOVA	{"phone": "+70060779639"}
0005432058374	7DC438	1305 059333	NADEZHDA ERMAKOVA	{"phone": "+70670932795"}
0005432058375	7DC438	2200 022011	MIKHAIL ANTONOV	{"phone": "+70044034370"}
0005432058376	4C952D	5461 965415	NADEZHDA DMITRIEVA	{"email": "dmitrieva-nadezhda_061972@postgrespro.ru", "phone": "+70535156991"}
0005432058377	4C952D	3671 774751	VALENTINA LOGINOVA	{"email": "valentinaloginova-01031969@postgrespro.ru", "phone": "+70229726473"}
0005432058378	F6C9DF	2625 921819	EVGENIY NIKOLAEV	{"phone": "+70370756042"}
0005432058379	DCD2D3	8334 745022	LYUBOV ALEKSEEVA	{"phone": "+70773894034"}
0005432058380	A025EF	4034 850490	IVAN IVANOV	{"phone": "+70542716777"}
0005432058381	337857	9826 047073	YURIY SCHERBAKOV	{"phone": "+70655328821"}
0005432058382	337857	5816 392310	NATALYA ZAKHAROVA	{"email": "n-zakharova06021966@postgrespro.ru", "phone": "+70636442846"}
0005432058383	87D372	1082 792294	ALINA FADEEVA	{"phone": "+70936868454"}
0005432058384	87D372	5581 841100	PETR SOKOLOV	{"phone": "+70593562941"}
0005432058385	87D372	8044 745265	ALEKSANDR MAKAROV	{"email": "makarova_021969@postgrespro.ru", "phone": "+70067220506"}
0005432058386	16A63D	7958 376927	VLADIMIR TIKHONOV	{"email": "vtikhonov_091967@postgrespro.ru", "phone": "+70689543555"}
0005432058387	16A63D	9413 963216	NADEZHDA DANILOVA	{"phone": "+70155094125"}
0005432058388	B2B026	4334 300707	ALEKSANDR PETROV	{"email": "petrov-a_081969@postgrespro.ru", "phone": "+70786562202"}
0005432058389	A6DD66	9589 432408	TATYANA KUZMINA	{"phone": "+70146028920"}
0005432058390	C90B98	4982 683430	SERGEY SIDOROV	{"phone": "+70807654820"}
0005432058391	80F2B7	4780 189284	ANDREY POPOV	{"email": "andrey_popov.051970@postgrespro.ru", "phone": "+70839827602"}
0005432058392	D59340	3192 240061	ZOYA BARANOVA	{"phone": "+70686626367"}
0005432058393	93F71C	8471 639134	MARINA FROLOVA	{"phone": "+70784864721"}
0005432058394	93F71C	1786 998878	LARISA SERGEEVA	{"phone": "+70545709518"}
0005432058395	F30904	8227 173669	ALEKSANDR KOROLEV	{"phone": "+70856208343"}
0005432058396	B32448	8259 485132	EVGENIY FILIPPOV	{"email": "evgeniy_filippov.101961@postgrespro.ru", "phone": "+70633280167"}
0005432058397	B32448	0512 724147	NIKOLAY BONDARENKO	{"email": "nbondarenko-051965@postgrespro.ru", "phone": "+70563156554"}
0005432058398	32B7C4	5638 678444	SVETLANA EFIMOVA	{"phone": "+70715166357"}
0005432058399	22331C	4877 403588	DARYA LEBEDEVA	{"email": "d_lebedeva-1975@postgrespro.ru", "phone": "+70892795607"}
0005432058400	AF5DE7	3008 466723	NATALYA PAVLOVA	{"phone": "+70081211596"}
0005432058401	AF5DE7	9721 133955	TATYANA PAVLOVA	{"phone": "+70747389949"}
0005432058402	B0E684	8933 258421	ANASTASIYA DMITRIEVA	{"phone": "+70930917855"}
0005432058403	B0E684	7990 058640	NATALYA KAZAKOVA	{"email": "natalyakazakova02071973@postgrespro.ru", "phone": "+70885962658"}
0005432058404	75E222	9542 020301	OLGA MOROZOVA	{"email": "morozova.olga.15101983@postgrespro.ru", "phone": "+70742688744"}
0005432058405	01E8C4	3586 547126	EKATERINA ANDREEVA	{"phone": "+70743856542"}
0005432058406	0FF22B	2435 318517	TATYANA VOLKOVA	{"phone": "+70247648517"}
0005432058407	A10825	0345 299773	ALEKSANDR BARANOV	{"phone": "+70533625196"}
0005432058408	A10825	2815 776427	ANDREY PETROV	{"phone": "+70413210881"}
0005432058409	42EFCF	7819 172353	INNA TITOVA	{"phone": "+70923319492"}
0005432058410	42EFCF	4627 830632	DENIS RODIONOV	{"email": "rodionov.denis061966@postgrespro.ru", "phone": "+70797925428"}
0005432058411	42EFCF	4718 066391	SERGEY TARASOV	{"phone": "+70049952179"}
0005432058412	05B419	8184 794206	EKATERINA KOROLEVA	{"email": "koroleva_e.26121970@postgrespro.ru", "phone": "+70962775188"}
0005432058413	25A1BE	0055 319302	ELENA KUZNECOVA	{"phone": "+70322795561"}
0005432058414	25A1BE	5951 177054	ALEKSANDR FILIPPOV	{"phone": "+70001517799"}
0005432058415	25A1BE	8041 137163	VLADIMIR KUZNECOV	{"phone": "+70287277177"}
0005432058416	B664E2	5418 409991	NATALYA ALEKSANDROVA	{"phone": "+70401323117"}
0005432058417	B664E2	5539 629795	SERGEY OSIPOV	{"phone": "+70038582060"}
0005432058418	A25523	5262 559130	OLESYA GUSEVA	{"phone": "+70079148613"}
0005432058419	2CC757	8217 628589	NATALIYA TIKHONOVA	{"email": "tikhonova-n081968@postgrespro.ru", "phone": "+70176998141"}
0005432058420	0B5F41	0218 944727	LYUDMILA PETROVA	{"phone": "+70559185725"}
0005432058421	0E5D5F	3947 224419	LYUDMILA DANILOVA	{"phone": "+70529744909"}
0005432058422	296BC8	6929 494408	NATALYA BORISOVA	{"phone": "+70750657233"}
0005432058423	10762C	3639 487675	KSENIYA GORBUNOVA	{"email": "k-gorbunova-1983@postgrespro.ru", "phone": "+70011763537"}
0005432058424	34DE52	5197 880174	MARAT MATVEEV	{"email": "matveev.m_1972@postgrespro.ru", "phone": "+70821651596"}
0005432058425	34DE52	1293 267388	TATYANA MIKHAYLOVA	{"phone": "+70533305524"}
0005432058426	8FF901	7868 061189	VLADIMIR IVANOV	{"phone": "+70899449540"}
0005432058427	791711	6219 786348	VYACHESLAV KARPOV	{"phone": "+70604402170"}
0005432058428	68FBE0	7667 364289	TATYANA LUKYANOVA	{"phone": "+70005105308"}
0005432058429	68FBE0	7841 330768	EKATERINA POLYAKOVA	{"phone": "+70299484412"}
0005432058430	059A76	2686 177059	ANNA KONDRATEVA	{"email": "annakondrateva04101970@postgrespro.ru", "phone": "+70035102895"}
0005432058431	A73ABF	8715 896277	GALINA DENISOVA	{"email": "galinadenisova081963@postgrespro.ru", "phone": "+70651827831"}
0005432058432	08CD8D	7064 360853	TATYANA NAZAROVA	{"phone": "+70902156878"}
0005432058433	6D395C	6151 266744	VALERIY IVANOV	{"phone": "+70726893157"}
0005432058434	14B40C	8998 964953	NINA KOVALEVA	{"email": "ninakovaleva-13111966@postgrespro.ru", "phone": "+70430794189"}
0005432058435	14B40C	5166 974380	EVDOKIYA GORBUNOVA	{"email": "gorbunovaevdokiya.12111970@postgrespro.ru", "phone": "+70426307410"}
0005432058436	42FB42	4448 131702	TAMARA KOROLEVA	{"email": "koroleva.t-071976@postgrespro.ru", "phone": "+70237238667"}
0005432058437	10B7A4	6636 053593	NINA KALININA	{"email": "nina_kalinina_051977@postgrespro.ru", "phone": "+70538953160"}
0005432058438	10B7A4	4064 355590	NIKOLAY SMIRNOV	{"email": "smirnov.n_1977@postgrespro.ru", "phone": "+70918727752"}
0005432058439	3899E3	0696 197948	MIKHAIL OSIPOV	{"email": "osipov-m.121977@postgrespro.ru", "phone": "+70653250200"}
0005432058440	FEF741	0098 786679	TATYANA POPOVA	{"email": "t.popova14071977@postgrespro.ru", "phone": "+70659487207"}
0005432058441	FEF741	1152 446794	YURIY EGOROV	{"email": "yuriyegorov-031968@postgrespro.ru", "phone": "+70371254249"}
0005432058442	0DAB10	8170 819069	ANATOLIY VLASOV	{"phone": "+70292528798"}
0005432058443	0DAB10	4035 512948	ALEKSANDR FEDOTOV	{"email": "a.fedotov-30061973@postgrespro.ru", "phone": "+70387170558"}
0005432058444	C65953	7562 912651	VLADIMIR FROLOV	{"phone": "+70402501721"}
0005432058445	BCB0EF	0768 879235	ALEKSEY FEDOTOV	{"phone": "+70962980766"}
0005432058446	6D403B	6160 616311	VIKTOR KOZLOV	{"email": "kozlov_viktor.121966@postgrespro.ru", "phone": "+70773570523"}
0005432058447	6D403B	6979 505710	ALEKSANDR SOKOLOV	{"email": "sokolov-a.25041971@postgrespro.ru", "phone": "+70597851930"}
0005432058448	812B2C	7659 008012	ALEKSANDR OSIPOV	{"email": "aleksandrosipov1968@postgrespro.ru", "phone": "+70397305521"}
0005432058449	B08B0A	1756 570770	ELENA GUSEVA	{"phone": "+70874792599"}
0005432058450	B08B0A	4269 402642	NATALYA OSIPOVA	{"phone": "+70994090471"}
0005432058451	7B2280	3706 234496	VIKTOR MARTYNOV	{"email": "viktor-martynov.061974@postgrespro.ru", "phone": "+70437499111"}
0005432058452	5CF245	5543 442304	DINA AKIMOVA	{"phone": "+70354850999"}
0005432058453	DE57FE	1138 023544	YURIY NIKITIN	{"phone": "+70003009918"}
0005432058454	D4AD55	5145 071884	EVGENIY KONOVALOV	{"phone": "+70581216554"}
0005432058455	EBC84A	6229 358717	SVETLANA SOKOLOVA	{"phone": "+70929713504"}
0005432058456	376BBC	2282 191292	SVETLANA MOISEEVA	{"phone": "+70457983079"}
0005432058457	376BBC	8185 506304	ELENA SMIRNOVA	{"email": "elena-smirnova101970@postgrespro.ru", "phone": "+70333962563"}
0005432058458	376BBC	9074 187999	MARIYA KUZMINA	{"email": "kuzminamariya1969@postgrespro.ru", "phone": "+70036814307"}
0005432058459	4CC730	2408 561686	ALBERT VASILEV	{"email": "vasileva031978@postgrespro.ru", "phone": "+70743761531"}
0005432058460	4CC730	2396 907186	LYUBOV MELNIKOVA	{"phone": "+70993986029"}
0005432058461	1CBE63	3227 060681	NATALYA KOROLEVA	{"email": "koroleva-natalya1974@postgrespro.ru", "phone": "+70065959543"}
0005432058462	476E09	9108 103857	YURIY IVANOV	{"phone": "+70814813937"}
0005432058463	091B30	0301 061229	SVETLANA KOMAROVA	{"phone": "+70833141657"}
0005432058464	091B30	9899 328633	ALEKSEY FOMIN	{"phone": "+70318799337"}
0005432058465	F2040A	1930 148953	LARISA KUZMINA	{"phone": "+70230449093"}
0005432058466	CCEBB9	1767 724682	ALEKSANDRA POTAPOVA	{"email": "aleksandra_potapova-111978@postgrespro.ru", "phone": "+70642933878"}
0005432058467	F00A97	0648 984519	LYUDMILA EGOROVA	{"phone": "+70278429445"}
0005432058468	8EB04F	7741 616464	OLGA TARASOVA	{"email": "tarasova.o_1981@postgrespro.ru", "phone": "+70501746566"}
0005432058469	7CF1D7	9874 829602	SOFIYA KUZMINA	{"email": "s.kuzmina_11031962@postgrespro.ru", "phone": "+70988964086"}
0005432058470	AC617A	3724 463604	NIKOLAY GUSEV	{"phone": "+70514327756"}
0005432058471	CE3FE1	8308 818507	INGA ZAKHAROVA	{"email": "izakharova-13091973@postgrespro.ru", "phone": "+70989153521"}
0005432058472	03A9EF	6698 000509	RUSLAN FOMIN	{"email": "ruslanfomin-03011971@postgrespro.ru", "phone": "+70027317039"}
0005432058473	03A9EF	2100 786298	NADEZHDA ORLOVA	{"email": "nadezhda_orlova18101970@postgrespro.ru", "phone": "+70954171422"}
0005432058474	03A9EF	1600 715972	ALEKSEY YAKOVLEV	{"email": "yakovlevaleksey.1982@postgrespro.ru", "phone": "+70047147682"}
0005432058475	1B1D21	6914 762576	MARINA ISAEVA	{"email": "marina_isaeva.28121977@postgrespro.ru", "phone": "+70552851724"}
0005432058476	44FA95	8242 849635	GALINA ZOTOVA	{"phone": "+70137828133"}
0005432058477	44FA95	6319 897106	YURIY KRASNOV	{"email": "krasnov_y1970@postgrespro.ru", "phone": "+70627269551"}
0005432058478	2F66B3	9132 553837	NATALYA PAVLOVA	{"email": "n_pavlova_031972@postgrespro.ru", "phone": "+70139690130"}
0005432058479	9C6148	5290 556273	VIKTOR EGOROV	{"email": "egorov_viktor.031968@postgrespro.ru", "phone": "+70921304946"}
0005432058480	9C6148	2277 077207	ALEKSANDR SMIRNOV	{"phone": "+70488754967"}
0005432058481	23324C	0003 821136	ANGELINA OVCHINNIKOVA	{"email": "angelina-ovchinnikova.1957@postgrespro.ru", "phone": "+70698780094"}
0005432058482	1ED1C8	5651 810426	SERGEY NIKITIN	{"phone": "+70133243579"}
0005432058483	12C3BE	4078 521693	OLEG KUZNECOV	{"phone": "+70330806998"}
0005432058484	12C3BE	8822 657234	EKATERINA KALININA	{"email": "e_kalinina.121967@postgrespro.ru", "phone": "+70440407013"}
0005432058485	872DA3	9291 552434	ALEKSEY PETROV	{"email": "petrov-aleksey_121971@postgrespro.ru", "phone": "+70661711547"}
0005432058486	872DA3	2996 540935	VLADIMIR KONOVALOV	{"email": "vkonovalov.091977@postgrespro.ru", "phone": "+70652225262"}
0005432058487	872DA3	9999 732842	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr_1962@postgrespro.ru", "phone": "+70806554995"}
0005432058488	E3AE65	8479 240669	KIRILL FEDOROV	{"email": "kirill_fedorov.1965@postgrespro.ru", "phone": "+70947960635"}
0005432058489	E3AE65	1108 470914	ALEKSANDR BELOV	{"email": "belov.aleksandr.1972@postgrespro.ru", "phone": "+70477735870"}
0005432058490	374162	8633 396205	ALEKSEY KARPOV	{"phone": "+70546526621"}
0005432058491	7FB567	9200 690293	IVAN BELOV	{"phone": "+70044826853"}
0005432058492	7FB567	6119 855106	EKATERINA FEDOROVA	{"email": "e_fedorova.1964@postgrespro.ru", "phone": "+70738049556"}
0005432058493	7FB567	6812 646755	INNA SIDOROVA	{"email": "inna-sidorova_1974@postgrespro.ru", "phone": "+70142839998"}
0005432058494	36D22A	7226 790505	SERGEY POPOV	{"email": "sergey.popov051971@postgrespro.ru", "phone": "+70176035179"}
0005432058495	36D22A	6861 492988	EVGENIYA KULIKOVA	{"email": "e_kulikova.10091973@postgrespro.ru", "phone": "+70813313382"}
0005432058496	4DD0B7	7069 756826	MARIYA ANISIMOVA	{"email": "manisimova.1973@postgrespro.ru", "phone": "+70037833031"}
0005432058497	4DD0B7	9690 207566	ANASTASIYA FEDOROVA	{"email": "fedorova.a.061972@postgrespro.ru", "phone": "+70522140589"}
0005432058498	FE7103	0664 234057	KRISTINA MEDVEDEVA	{"phone": "+70521719034"}
0005432058499	FE7103	3575 550956	ALEKSEY POPOV	{"email": "popovaleksey1966@postgrespro.ru", "phone": "+70438424373"}
0005432058500	CF5BFB	6607 493256	GEORGIY ZAYCEV	{"email": "zaycev-g1974@postgrespro.ru", "phone": "+70214977427"}
0005432059469	80F9F1	8332 987400	YURIY DAVYDOV	{"phone": "+70850256148"}
0005432059470	3CD02F	0966 092871	LYUDMILA ALEKSEEVA	{"email": "l.alekseeva-05091960@postgrespro.ru", "phone": "+70980776227"}
0005432059471	3CD02F	1066 321470	GALINA SMIRNOVA	{"phone": "+70381300151"}
0005432059472	090960	5105 998687	IGOR KOROLEV	{"email": "korolevigor081977@postgrespro.ru", "phone": "+70545937111"}
0005432059473	835531	6252 796687	LYUDMILA YAKOVLEVA	{"email": "lyudmila.yakovleva-23091969@postgrespro.ru", "phone": "+70476754869"}
0005432059474	8D1C56	3799 992412	MIKHAIL KOROLEV	{"email": "m.korolev.1972@postgrespro.ru", "phone": "+70764356847"}
0005432059475	8D1C56	6659 961982	DENIS IVANOV	{"phone": "+70337323219"}
0005432059476	41AE4D	5008 275618	OLGA MIRONOVA	{"phone": "+70632890310"}
0005432059477	1E42C6	7704 000973	IRAIDA NIKIFOROVA	{"phone": "+70681313607"}
0005432059478	1E42C6	1588 765633	GALINA GORBUNOVA	{"email": "gorbunova_galina-1974@postgrespro.ru", "phone": "+70099778960"}
0005432059479	550F37	1410 744585	ALEKSANDR ORLOV	{"email": "orlov-a-18061975@postgrespro.ru", "phone": "+70576548171"}
0005432059480	7731D8	3911 189402	DMITRIY ANTONOV	{"email": "antonov.dmitriy_1968@postgrespro.ru", "phone": "+70036976468"}
0005432059481	7731D8	4848 122477	EVGENIY ZAKHAROV	{"phone": "+70981225454"}
0005432059482	BBD04F	0219 339157	NADIYA RODIONOVA	{"phone": "+70734919816"}
0005432059483	BBD04F	4363 420400	SERGEY SERGEEV	{"phone": "+70251574159"}
0005432059484	2458FB	8090 644949	YULIYA ROMANOVA	{"email": "romanovay.30011971@postgrespro.ru", "phone": "+70163684400"}
0005432059485	E7E9A1	4208 195945	RIMMA RYABOVA	{"phone": "+70404989751"}
0005432059486	6C5ED3	3047 689649	ALEKSANDR POPOV	{"email": "popov.aleksandr1969@postgrespro.ru", "phone": "+70003090050"}
0005432059487	D4C17C	0615 914830	VALENTINA IVANOVA	{"phone": "+70860819406"}
0005432059488	D4C17C	7319 000325	SERGEY KULIKOV	{"phone": "+70133686276"}
0005432059489	243B75	1918 239730	ALEKSANDR KUZMIN	{"phone": "+70126277671"}
0005432059490	065B63	0225 807213	VIKTOR KUZNECOV	{"phone": "+70743819408"}
0005432059491	B39B74	6221 680014	ILYA GAVRILOV	{"phone": "+70943320945"}
0005432059492	7D40EB	9120 220892	GALINA MEDVEDEVA	{"email": "galina.medvedeva-1973@postgrespro.ru", "phone": "+70027519595"}
0005432059493	7D40EB	8438 626075	NATALYA MIKHAYLOVA	{"phone": "+70374169819"}
0005432059494	4AD05B	8442 659134	EKATERINA DANILOVA	{"email": "danilova-e_1978@postgrespro.ru", "phone": "+70378442920"}
0005432059495	BDDA71	9980 929504	VLADIMIR MAKAROV	{"phone": "+70922753558"}
0005432059496	BDDA71	1763 886999	EKATERINA POPOVA	{"phone": "+70846626243"}
0005432059497	86670F	4921 982908	OKSANA POPOVA	{"email": "oksana-popova.1968@postgrespro.ru", "phone": "+70888348753"}
0005432059498	D9F451	6506 264399	GLEB TIKHONOV	{"phone": "+70786863059"}
0005432059499	CB9A2D	2551 021885	VLADIMIR IVANOV	{"email": "vivanov_1969@postgrespro.ru", "phone": "+70001494593"}
0005432059500	CB9A2D	3492 738095	SERGEY KUZNECOV	{"email": "kuznecovsergey041975@postgrespro.ru", "phone": "+70018707176"}
0005432059501	5952FB	8318 144840	DMITRIY SMIRNOV	{"phone": "+70886156952"}
0005432059502	5952FB	4249 999707	MIKHAIL IVANOV	{"phone": "+70440886384"}
0005432059503	5952FB	2738 299302	ALEKSEY NIKOLAEV	{"email": "alekseynikolaev-10051968@postgrespro.ru", "phone": "+70694020524"}
0005432059504	19D935	8546 305032	ALEKSANDR ANTONOV	{"email": "antonov_a1972@postgrespro.ru", "phone": "+70314832829"}
0005432059505	19D935	0207 712663	EVGENIYA KUZNECOVA	{"phone": "+70639417780"}
0005432059506	5B4F1F	6272 583394	SERGEY KUZMIN	{"phone": "+70178257279"}
0005432059507	5B4F1F	8946 880349	KSENIYA KUZNECOVA	{"phone": "+70232614464"}
0005432059508	5B4F1F	5734 803204	ANNA PAVLOVA	{"email": "apavlova.011972@postgrespro.ru", "phone": "+70185551917"}
0005432059509	484BB6	4334 357302	OLEG DMITRIEV	{"email": "dmitriev-oleg-1975@postgrespro.ru", "phone": "+70977808633"}
0005432059510	EADA79	9554 131382	VIKTOR DMITRIEV	{"phone": "+70556949562"}
0005432059511	EADA79	0469 773323	OLGA ANDREEVA	{"email": "o.andreeva.1957@postgrespro.ru", "phone": "+70230515881"}
0005432059512	A2450D	4257 875786	OLEG SERGEEV	{"phone": "+70176123449"}
0005432059513	BEE6EA	6644 597792	VLADIMIR SERGEEV	{"email": "sergeev_vladimir_1964@postgrespro.ru", "phone": "+70312729716"}
0005432059514	BEE6EA	0662 164796	VALENTINA KOZLOVA	{"phone": "+70468601556"}
0005432059515	9DF614	6529 757669	RUSTAM AFANASEV	{"phone": "+70938779660"}
0005432059516	7EB0E2	5054 247300	SERGEY SMIRNOV	{"email": "smirnov_sergey-19061973@postgrespro.ru", "phone": "+70063065381"}
0005432059517	6ABC60	4385 431199	LYUDMILA AKIMOVA	{"phone": "+70611803630"}
0005432059518	834C11	2023 701981	LIDIYA KOVALEVA	{"email": "lidiya.kovaleva-19031970@postgrespro.ru", "phone": "+70765287521"}
0005432059519	834C11	8904 795057	ROMAN IVANOV	{"phone": "+70386766477"}
0005432059520	890489	3925 340238	NIKOLAY ALEKSANDROV	{"email": "nikolay-aleksandrov1972@postgrespro.ru", "phone": "+70217538155"}
0005432059521	52F850	7344 249577	RAMAZAN ALEKSEEV	{"phone": "+70288345728"}
0005432059522	2860C8	5495 264858	GALINA FILATOVA	{"email": "filatovagalina051981@postgrespro.ru", "phone": "+70420530279"}
0005432059523	6818CB	3280 574501	RAISA ISAEVA	{"email": "r.isaeva.1970@postgrespro.ru", "phone": "+70771907415"}
0005432059524	CC55D4	7143 928572	ALEKSANDRA SERGEEVA	{"email": "sergeeva_a.101975@postgrespro.ru", "phone": "+70376818175"}
0005432059525	A819BE	2250 134746	DMITRIY TIMOFEEV	{"phone": "+70803784504"}
0005432059526	C88EEA	6362 184011	MIKHAIL FEDOROV	{"email": "mikhail-fedorov_031972@postgrespro.ru", "phone": "+70936976070"}
0005432059527	C8EDB1	1190 164308	MARIANNA MEDVEDEVA	{"email": "medvedeva.marianna.1972@postgrespro.ru", "phone": "+70632501622"}
0005432059528	90B33B	9470 367298	TATYANA RODIONOVA	{"email": "tatyana.rodionova.06071979@postgrespro.ru", "phone": "+70739302054"}
0005432059529	90B33B	0200 237698	YULIYA PAVLOVA	{"phone": "+70385025791"}
0005432059530	066B82	9420 580292	SERGEY KISELEV	{"email": "kiselev_sergey_011973@postgrespro.ru", "phone": "+70650826017"}
0005432059531	93C166	1251 636756	VLADIMIR ANDREEV	{"phone": "+70136168325"}
0005432059532	51960E	1599 935758	SERGEY ILIN	{"email": "sergey.ilin-27031968@postgrespro.ru", "phone": "+70724807411"}
0005432059533	51960E	2838 563118	NATALYA NIKITINA	{"phone": "+70813180452"}
0005432059534	3EDAB5	3410 953570	MARINA TARASOVA	{"phone": "+70629608129"}
0005432059535	0BDDC0	6284 686383	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov.011973@postgrespro.ru", "phone": "+70496637632"}
0005432059536	18FAA6	2727 480445	ALEKSANDR KUZNECOV	{"email": "kuznecov_a16091974@postgrespro.ru", "phone": "+70962548411"}
0005432059537	A8DE2A	7259 329130	VYACHESLAV SOLOVEV	{"phone": "+70259332578"}
0005432059538	A8DE2A	5847 903749	LARISA FOMINA	{"email": "l-fomina_051956@postgrespro.ru", "phone": "+70084576733"}
0005432059539	A8DE2A	4904 414773	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov-081987@postgrespro.ru", "phone": "+70812986115"}
0005432059540	634977	5215 105048	MARIYA ARKHIPOVA	{"email": "m-arkhipova111972@postgrespro.ru", "phone": "+70526685807"}
0005432059541	54185C	6967 898322	TATYANA KULIKOVA	{"phone": "+70407940608"}
0005432059542	425490	5139 066551	SERGEY KUZMIN	{"email": "kuzmin_sergey071982@postgrespro.ru", "phone": "+70881409171"}
0005432059543	425490	5809 206494	ANASTASIYA BELOVA	{"email": "anastasiyabelova011972@postgrespro.ru", "phone": "+70742141878"}
0005432059544	3B506C	0292 681419	DMITRIY IVANOV	{"phone": "+70951391639"}
0005432059545	3B506C	4606 348639	VYACHESLAV MOISEEV	{"email": "moiseevv.091964@postgrespro.ru", "phone": "+70816296288"}
0005432059546	E84598	1157 373382	ALEKSEY SOLOVEV	{"phone": "+70566528667"}
0005432059547	78BC54	0862 950666	MARGARITA EFREMOVA	{"email": "efremova-margarita.1979@postgrespro.ru", "phone": "+70137237901"}
0005432059548	FC40FB	5353 019923	TATYANA EGOROVA	{"phone": "+70975379955"}
0005432059549	927837	0178 045633	NATALYA MAKAROVA	{"email": "nmakarova10091977@postgrespro.ru", "phone": "+70328076299"}
0005432059550	F5E127	7618 018979	OLGA KARPOVA	{"phone": "+70993864098"}
0005432059551	F5E127	6906 563529	IVAN MIRONOV	{"phone": "+70752999862"}
0005432059552	A00CD7	1029 871553	NATALYA DAVYDOVA	{"phone": "+70025527186"}
0005432059553	5C8A6C	0273 486261	ALEKSANDR NAUMOV	{"email": "a.naumov-1975@postgrespro.ru", "phone": "+70007226907"}
0005432059554	89DAE8	7917 703573	ALEKSEY IVANOV	{"email": "a-ivanov03101972@postgrespro.ru", "phone": "+70219933323"}
0005432059555	89DAE8	7552 766398	NATALYA ZHUKOVA	{"email": "zhukova.n1979@postgrespro.ru", "phone": "+70098418521"}
0005432059556	C7394A	9306 889942	TATYANA ZAYCEVA	{"email": "tatyana-zayceva011979@postgrespro.ru", "phone": "+70089597630"}
0005432059557	1B704B	2474 172911	FAINA DAVYDOVA	{"phone": "+70147907129"}
0005432062367	039A4A	7642 144843	ILYA NOVIKOV	{"phone": "+70401323638"}
0005432059558	2A0B89	2445 944858	EVGENIY MAKSIMOV	{"email": "maksimov.evgeniy-061967@postgrespro.ru", "phone": "+70359261679"}
0005432059559	2A0B89	6144 707815	LYUBOV KISELEVA	{"phone": "+70531417432"}
0005432059560	CBD81E	3785 989792	MARAT MARTYNOV	{"email": "martynovmarat10051978@postgrespro.ru", "phone": "+70063647747"}
0005432059561	2815E9	0650 949698	ANASTASIYA NESTEROVA	{"phone": "+70567287747"}
0005432059562	2815E9	6480 869643	ANZHELIKA LAZAREVA	{"email": "anzhelikalazareva1978@postgrespro.ru", "phone": "+70357639072"}
0005432059563	2815E9	2494 306239	DMITRIY SERGEEV	{"email": "sergeevdmitriy_121977@postgrespro.ru", "phone": "+70824810539"}
0005432062134	8E86DB	1407 728996	PAVEL SOROKIN	{"email": "pavelsorokin091977@postgrespro.ru", "phone": "+70381167566"}
0005432062135	8E86DB	1165 175598	ELENA GAVRILOVA	{"email": "e.gavrilova_1973@postgrespro.ru", "phone": "+70059290262"}
0005432062136	9BF661	6546 410308	VIKTOR ALEKSEEV	{"email": "alekseev-viktor_021985@postgrespro.ru", "phone": "+70268921644"}
0005432062137	4FAF0B	8095 954551	NIKOLAY PETROV	{"email": "n_petrov24071977@postgrespro.ru", "phone": "+70837368679"}
0005432062138	2FE391	5422 986517	DMITRIY STEPANOV	{"email": "d_stepanov_1968@postgrespro.ru", "phone": "+70338997813"}
0005432062139	2FE391	6561 214840	LEONID POPOV	{"email": "leonid.popov-28051978@postgrespro.ru", "phone": "+70409268004"}
0005432062140	FE979B	7424 574449	ELVIRA ZAKHAROVA	{"email": "zakharova-elvira-27101970@postgrespro.ru", "phone": "+70033918054"}
0005432062141	87750D	8411 264916	RAIL POPOV	{"email": "popov.rail_1977@postgrespro.ru", "phone": "+70604280102"}
0005432062142	F02C20	1655 978208	TATYANA VOLKOVA	{"phone": "+70239741868"}
0005432062143	F02C20	1147 424855	NINA VLASOVA	{"email": "nina_vlasova.1968@postgrespro.ru", "phone": "+70739712058"}
0005432062144	F8EC04	8911 528475	LIDIYA KUZNECOVA	{"phone": "+70757056599"}
0005432062145	F8EC04	4358 682439	TATYANA BORISOVA	{"email": "t.borisova-041969@postgrespro.ru", "phone": "+70712395448"}
0005432062146	DDBC41	6375 501604	OLGA AFANASEVA	{"email": "olga-afanaseva1980@postgrespro.ru", "phone": "+70558872438"}
0005432062147	DDBC41	3941 808468	DANIIL MEDVEDEV	{"email": "daniil_medvedev-1971@postgrespro.ru", "phone": "+70378136588"}
0005432062148	DDBC41	1191 718914	MIKHAIL GRIGOREV	{"phone": "+70089862019"}
0005432062149	AF23CD	5509 810823	ALEKSANDR TIKHONOV	{"phone": "+70137959965"}
0005432062150	AF23CD	6610 380632	BORIS IVANOV	{"email": "ivanov.b.1981@postgrespro.ru", "phone": "+70208481360"}
0005432062151	9CF84A	4091 190196	ANDREY CHERNOV	{"email": "chernov-andrey_031974@postgrespro.ru", "phone": "+70844397424"}
0005432062152	9CF84A	4044 374561	ANDREY FEDOTOV	{"email": "andrey-fedotov-041971@postgrespro.ru", "phone": "+70392256583"}
0005432062153	9CF84A	2112 940596	TAMARA VOLKOVA	{"phone": "+70531183544"}
0005432062154	54A9CC	0648 042946	KSENIYA RODIONOVA	{"phone": "+70497516255"}
0005432062155	DB9831	5521 423437	VIKTOR PAVLOV	{"email": "v.pavlov_28121973@postgrespro.ru", "phone": "+70995489126"}
0005432062156	DB9831	5611 668662	ELENA KAZAKOVA	{"phone": "+70616745375"}
0005432062157	947F02	6456 463158	SERGEY GERASIMOV	{"phone": "+70929639592"}
0005432062158	947F02	7958 598030	ROZALIYA VASILEVA	{"phone": "+70698993425"}
0005432062159	40C325	5858 684568	VALENTINA POPOVA	{"phone": "+70832940922"}
0005432062160	CD01E6	6741 400801	ALEKSANDR KISELEV	{"phone": "+70946047047"}
0005432062161	628664	7918 972355	TATYANA SEMENOVA	{"email": "tatyanasemenova.1964@postgrespro.ru", "phone": "+70708143457"}
0005432062162	7F09F8	9702 948762	EVGENIYA PETROVA	{"email": "petrova_e19111974@postgrespro.ru", "phone": "+70815877056"}
0005432062163	7F09F8	2475 587142	SERGEY IVANOV	{"email": "sivanov-101952@postgrespro.ru", "phone": "+70245036545"}
0005432062164	1091E5	3569 825077	MAKSIM KONOVALOV	{"email": "konovalovmaksim-111981@postgrespro.ru", "phone": "+70813081303"}
0005432062165	1091E5	7448 624652	IVAN KOROLEV	{"phone": "+70186710439"}
0005432062166	D074A8	9614 364650	IVAN NIKITIN	{"phone": "+70102014803"}
0005432062167	F21FC6	2249 625391	YURIY IVANOV	{"phone": "+70801051153"}
0005432062168	B5EE56	1198 800729	VYACHESLAV SOKOLOV	{"email": "sokolov_v-1979@postgrespro.ru", "phone": "+70630421630"}
0005432062169	9ED39D	5074 707680	MARINA BOGDANOVA	{"email": "bogdanova.m-06111985@postgrespro.ru", "phone": "+70831617088"}
0005432062170	769BE9	1717 058078	ALEKSANDRA KOVALEVA	{"phone": "+70939091371"}
0005432062171	D726A3	2229 204636	TATYANA AFANASEVA	{"phone": "+70092714260"}
0005432062172	84199C	2526 168065	ALEKSANDR NIKOLAEV	{"phone": "+70413670383"}
0005432062173	A953D1	6497 193448	SERGEY ANDREEV	{"phone": "+70027681826"}
0005432062174	8E1BEB	2734 758540	SVETLANA TROFIMOVA	{"email": "svetlana.trofimova.1972@postgrespro.ru", "phone": "+70538046261"}
0005432062175	8E1BEB	3901 026616	IRINA KISELEVA	{"email": "kiseleva.i.031967@postgrespro.ru", "phone": "+70254157237"}
0005432062176	8E1BEB	7706 509361	ALEKSANDR POPOV	{"phone": "+70359485056"}
0005432062177	C879A9	3137 820343	SERGEY FROLOV	{"phone": "+70452521895"}
0005432062178	9613D4	4201 454995	VLADIMIR EGOROV	{"phone": "+70392199505"}
0005432062179	9613D4	9238 235978	TATYANA KAZAKOVA	{"phone": "+70247203511"}
0005432062180	B1907E	0943 503775	MIKHAIL VASILEV	{"phone": "+70189101911"}
0005432062181	16C46D	2481 155317	KONSTANTIN FEDOTOV	{"phone": "+70735323044"}
0005432062182	A5798C	8736 381223	ELENA TIMOFEEVA	{"email": "elena_timofeeva.1978@postgrespro.ru", "phone": "+70451388815"}
0005432062183	A5798C	0768 497802	TATYANA KUZNECOVA	{"email": "kuznecova-t21061982@postgrespro.ru", "phone": "+70469041010"}
0005432062184	FE98A3	4777 759058	ALENA AKIMOVA	{"email": "akimovaalena_011964@postgrespro.ru", "phone": "+70380251431"}
0005432062185	32755C	4949 403101	NIKOLAY IVANOV	{"phone": "+70767288537"}
0005432062186	90A04C	3472 670235	ANDREY SAVELEV	{"phone": "+70578350130"}
0005432062187	0EC9A7	1540 518235	ANATOLIY SOKOLOV	{"email": "a_sokolov_04101966@postgrespro.ru", "phone": "+70139475220"}
0005432062188	1A6BAB	0891 470880	TATYANA ANTONOVA	{"email": "tatyana.antonova-1971@postgrespro.ru", "phone": "+70278889055"}
0005432062189	A1F5C1	7704 765562	VLADIMIR GAVRILOV	{"email": "gavrilov_v_1972@postgrespro.ru", "phone": "+70529246894"}
0005432062190	5558E7	3836 816132	ROZA PETROVA	{"phone": "+70351427933"}
0005432062191	5558E7	3547 263768	KUZMA ROMANOV	{"email": "romanov.kuzma-22111976@postgrespro.ru", "phone": "+70499251510"}
0005432062192	E77421	5829 841869	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr061961@postgrespro.ru", "phone": "+70698971253"}
0005432062193	EF3ACA	5034 390449	OLGA ZAYCEVA	{"email": "zayceva.olga-111982@postgrespro.ru", "phone": "+70033445518"}
0005432062194	EF3ACA	4185 583049	KONSTANTIN SIDOROV	{"email": "konstantin-sidorov_111978@postgrespro.ru", "phone": "+70008399736"}
0005432062195	3F0EB8	2476 989739	ANTON POPOV	{"phone": "+70481969508"}
0005432062196	0DFF29	1212 115309	ALEKSANDRA ZAYCEVA	{"phone": "+70347554984"}
0005432062197	BC0729	6805 008916	SEMEN MOROZOV	{"phone": "+70417604986"}
0005432062198	BC0729	0032 265996	YULIYA STEPANOVA	{"phone": "+70007885694"}
0005432062199	B36C3B	6542 197724	NINA POPOVA	{"email": "popovanina10081970@postgrespro.ru", "phone": "+70135785951"}
0005432062200	B36C3B	7575 952019	SERGEY SMIRNOV	{"email": "smirnov.sergey061983@postgrespro.ru", "phone": "+70802923149"}
0005432062201	385E79	8150 817589	MARINA ZHURAVLEVA	{"email": "marinazhuravleva_081973@postgrespro.ru", "phone": "+70164789206"}
0005432062202	34C0AF	1976 209736	MIKHAIL POPOV	{"email": "mikhail.popov-1970@postgrespro.ru", "phone": "+70452373642"}
0005432062203	ED68B8	0302 881939	DMITRIY NOVIKOV	{"email": "novikov.dmitriy-101976@postgrespro.ru", "phone": "+70067800426"}
0005432062204	F3A16F	5499 144850	LARISA MATVEEVA	{"phone": "+70946830306"}
0005432062205	F3A16F	5991 412236	SERGEY TARASOV	{"phone": "+70582579111"}
0005432062206	F3A16F	2294 358830	DARYA MAKAROVA	{"phone": "+70337399936"}
0005432062207	11518F	4927 005803	ANASTASIYA SAVELEVA	{"email": "saveleva.a021984@postgrespro.ru", "phone": "+70119692004"}
0005432062208	A46A5E	8430 364639	ALEKSEY BORISOV	{"email": "a.borisov_021977@postgrespro.ru", "phone": "+70003823457"}
0005432062209	A46A5E	4553 299885	SAMIRA DAVYDOVA	{"email": "s_davydova.10101978@postgrespro.ru", "phone": "+70801168202"}
0005432062210	67C339	6578 356747	ELENA ORLOVA	{"email": "orlova-elena_121969@postgrespro.ru", "phone": "+70727519739"}
0005432062211	C9BFF1	9824 548392	TATYANA NIKITINA	{"phone": "+70424513189"}
0005432062212	BB9A88	2563 326057	ANNA IVANOVA	{"phone": "+70987862791"}
0005432062213	BB9A88	1362 372752	VIKTORIYA TIKHONOVA	{"email": "vtikhonova_08021974@postgrespro.ru", "phone": "+70925650781"}
0005432062214	17D4D8	9259 319209	ANNA FROLOVA	{"phone": "+70943264845"}
0005432062215	B740C6	9060 084635	MAKSIM MOROZOV	{"phone": "+70677947778"}
0005432062216	B740C6	4127 858400	NINA STEPANOVA	{"phone": "+70973090472"}
0005432062217	B740C6	4523 562652	LIDIYA KUDRYASHOVA	{"phone": "+70692395171"}
0005432062218	7E0890	3574 885723	YULIYA MELNIKOVA	{"phone": "+70970691919"}
0005432062219	7E0890	0178 966542	NAIL KOROLEV	{"phone": "+70114499301"}
0005432062220	809DF8	5494 810830	MARIYA KOZLOVA	{"email": "mariya_kozlova.14021976@postgrespro.ru", "phone": "+70597241028"}
0005432062221	B374DD	4580 415082	ELIZAVETA FILATOVA	{"phone": "+70063757160"}
0005432062222	B1AC5D	7363 994844	DANILA ANDREEV	{"phone": "+70058977824"}
0005432062223	F51B1F	7016 807610	MARIYA KOLESNIKOVA	{"email": "mariya.kolesnikova.1976@postgrespro.ru", "phone": "+70818194934"}
0005432062224	2FCFE0	7839 726283	ANDREY KOZLOV	{"email": "kozlovandrey-1963@postgrespro.ru", "phone": "+70210817113"}
0005432062225	57D0B6	3842 646512	OLEG SERGEEV	{"phone": "+70941550078"}
0005432062226	57D0B6	7760 056277	MARIYA SIDOROVA	{"phone": "+70973599772"}
0005432062227	68A528	6290 883303	PAVEL GORBUNOV	{"phone": "+70910616129"}
0005432062228	C81898	0087 324334	IVAN BARANOV	{"email": "i_baranov_1972@postgrespro.ru", "phone": "+70073549984"}
0005432062229	2A3B89	1792 255524	NIKOLAY PETROV	{"email": "petrovnikolay_1966@postgrespro.ru", "phone": "+70963221546"}
0005432062230	BF5B60	6570 072819	ANATOLIY KRASNOV	{"phone": "+70064692532"}
0005432062231	46E3B8	1414 924066	ANATOLIY NIKOLAEV	{"email": "anatoliy.nikolaev.23041972@postgrespro.ru", "phone": "+70189115924"}
0005432062232	46E3B8	4079 859452	OKSANA BELOVA	{"email": "belovaoksana-08081965@postgrespro.ru", "phone": "+70888095571"}
0005432062233	B204C2	9043 019856	TATYANA IVANOVA	{"phone": "+70871556426"}
0005432062234	B204C2	7279 139991	VALERIY ABRAMOV	{"phone": "+70115054726"}
0005432062235	425786	8049 441759	NIKOLAY PETROV	{"email": "petrovn-121975@postgrespro.ru", "phone": "+70763847293"}
0005432062236	425786	8848 084633	DARYA EGOROVA	{"email": "egorova.darya-071963@postgrespro.ru", "phone": "+70117284895"}
0005432062237	425786	1296 962343	ARTEM KUZMIN	{"email": "akuzmin011967@postgrespro.ru", "phone": "+70210444745"}
0005432062238	D9FC63	4553 356277	GALINA GERASIMOVA	{"email": "galina.gerasimova_21071963@postgrespro.ru", "phone": "+70157418863"}
0005432062239	967087	4892 180542	LIDIYA NAZAROVA	{"email": "lidiya_nazarova-071971@postgrespro.ru", "phone": "+70334516768"}
0005432062240	82F93A	7516 710527	MIKHAIL NAUMOV	{"email": "naumov-m011969@postgrespro.ru", "phone": "+70256075915"}
0005432062241	5CC6B7	5127 715851	VALERIY FILIPPOV	{"phone": "+70228734029"}
0005432062242	5CC6B7	9492 522748	GULNAZ ANTONOVA	{"phone": "+70519680898"}
0005432062243	302095	1940 524732	VIKTOR DAVYDOV	{"phone": "+70981771347"}
0005432062244	ABD5F3	6394 726563	IVAN SEMENOV	{"phone": "+70216404194"}
0005432062245	2B4CEE	1760 936625	NINA MOISEEVA	{"email": "nina.moiseeva.13081970@postgrespro.ru", "phone": "+70989702707"}
0005432062246	2B4CEE	2238 957304	MARINA ZAKHAROVA	{"phone": "+70079836913"}
0005432062247	2B4CEE	0938 882602	GALINA PETROVA	{"email": "petrovagalina071966@postgrespro.ru", "phone": "+70399460796"}
0005432062248	836A88	5276 505588	GALINA MOISEEVA	{"email": "moiseeva_g_1965@postgrespro.ru", "phone": "+70317794831"}
0005432062249	836A88	1587 701289	EVGENIY KISELEV	{"phone": "+70609403067"}
0005432062250	1B253E	3584 799548	ALEKSANDR CHERNOV	{"phone": "+70498025090"}
0005432062251	53692D	2005 437593	YANA NOVIKOVA	{"email": "y.novikova-041975@postgrespro.ru", "phone": "+70334662154"}
0005432062252	7D218B	5123 241717	ARTEM ROMANOV	{"email": "romanov.a-1967@postgrespro.ru", "phone": "+70769398858"}
0005432062253	0D7565	7402 791585	TATYANA GERASIMOVA	{"email": "gerasimova-tatyana-101975@postgrespro.ru", "phone": "+70731727132"}
0005432062254	0D7565	7754 393420	ELIZAVETA EGOROVA	{"email": "egorova-elizaveta10121967@postgrespro.ru", "phone": "+70889347492"}
0005432062255	1FB070	9512 470353	VIKTORIYA VOLKOVA	{"phone": "+70739434382"}
0005432062256	94CF40	9039 764181	ANTONINA GAVRILOVA	{"email": "gavrilova.a03121976@postgrespro.ru", "phone": "+70456403126"}
0005432062257	94CF40	9896 634215	ALEKSEY FOMIN	{"phone": "+70206480163"}
0005432062258	49C8EE	9856 707490	ALEKSEY ZAKHAROV	{"phone": "+70535824831"}
0005432062259	49C8EE	5765 010064	VIKTORIYA POPOVA	{"email": "popova_viktoriya-1966@postgrespro.ru", "phone": "+70269443978"}
0005432062260	D7FE05	5674 948465	LYUBOV BARANOVA	{"email": "baranova.lyubov.011979@postgrespro.ru", "phone": "+70141300271"}
0005432062261	0B1F95	8382 868989	SVETLANA MAKAROVA	{"email": "makarovasvetlana_23061972@postgrespro.ru", "phone": "+70299452954"}
0005432062262	D7138B	3502 186009	NATALYA DANILOVA	{"email": "danilovan_28071981@postgrespro.ru", "phone": "+70619607133"}
0005432062263	D7138B	1119 454844	ANDREY VOROBEV	{"email": "vorobevandrey.1982@postgrespro.ru", "phone": "+70493969236"}
0005432062264	D7138B	6624 560141	DENIS CHERNOV	{"email": "chernov_denis-101976@postgrespro.ru", "phone": "+70656096954"}
0005432062265	2A6F28	8471 850773	OLGA ILINA	{"email": "ilinao.1980@postgrespro.ru", "phone": "+70733645868"}
0005432062266	550635	6304 886531	ALEKSEY MARTYNOV	{"phone": "+70223816607"}
0005432062267	550635	2553 938599	SERGEY MIRONOV	{"email": "s_mironov.121969@postgrespro.ru", "phone": "+70441920058"}
0005432062268	550635	5778 612265	ANATOLIY PAVLOV	{"email": "pavlov_anatoliy_101963@postgrespro.ru", "phone": "+70864469495"}
0005432062269	385BB3	7420 479255	ANATOLIY NOVIKOV	{"phone": "+70228414350"}
0005432062270	79F7E0	8317 960754	ANTONINA MOROZOVA	{"email": "morozova-antonina-1977@postgrespro.ru", "phone": "+70984620203"}
0005432062271	928912	7226 856898	ULYANA RYABOVA	{"email": "u.ryabova.19101969@postgrespro.ru", "phone": "+70995535376"}
0005432062272	330B5F	9623 802934	EKATERINA GAVRILOVA	{"phone": "+70973654495"}
0005432062273	330B5F	5115 780004	EMILIYA YAKOVLEVA	{"email": "emiliya_yakovleva.1979@postgrespro.ru", "phone": "+70220665568"}
0005432062274	ECDF6D	2365 147274	ELENA SMIRNOVA	{"phone": "+70139256638"}
0005432062275	0D219E	1683 643001	VIKTOR KUZNECOV	{"email": "kuznecov_viktor_15061979@postgrespro.ru", "phone": "+70467013549"}
0005432062276	0D219E	0217 006958	GALINA KOMAROVA	{"phone": "+70907086870"}
0005432062277	C3590A	4095 735739	ALI GORBUNOV	{"phone": "+70945631795"}
0005432062278	C3590A	7171 272648	VIKTOR VASILEV	{"email": "vasilev-v05111962@postgrespro.ru", "phone": "+70491886047"}
0005432062279	C3590A	8002 307848	TATYANA STEPANOVA	{"phone": "+70787563736"}
0005432062280	53530D	1959 185805	EKATERINA IVANOVA	{"email": "eivanova121970@postgrespro.ru", "phone": "+70408318218"}
0005432062281	8706F5	5316 450859	SERGEY PETROV	{"phone": "+70268143724"}
0005432062282	8706F5	7969 652088	ALEKSANDR ALEKSEEV	{"phone": "+70320797231"}
0005432062283	E39830	9237 269503	TATYANA RODIONOVA	{"phone": "+70740279653"}
0005432062284	E39830	8486 323762	NIKOLAY TIMOFEEV	{"phone": "+70799345651"}
0005432062285	F0F834	5924 957470	ILYA SIDOROV	{"email": "i_sidorov-1969@postgrespro.ru", "phone": "+70165148508"}
0005432062286	F0F834	7647 463159	ANATOLIY MIKHAYLOV	{"email": "mikhaylov-anatoliy.041969@postgrespro.ru", "phone": "+70542712081"}
0005432062287	FCF7DA	9951 167892	GALINA NIKIFOROVA	{"phone": "+70002024442"}
0005432062288	99CB39	2657 844813	YURIY MAKAROV	{"email": "yuriy-makarov-1981@postgrespro.ru", "phone": "+70252289470"}
0005432062289	15AA80	4833 833835	ARINA SOKOLOVA	{"email": "a.sokolova-10111981@postgrespro.ru", "phone": "+70341705159"}
0005432062290	DCF434	9570 532086	VERA FROLOVA	{"phone": "+70265532406"}
0005432062291	E1794F	8920 472670	TATYANA DENISOVA	{"email": "denisova_t-01011993@postgrespro.ru", "phone": "+70414659676"}
0005432062292	1C3B33	2758 889545	NINA TITOVA	{"email": "nina_titova13091965@postgrespro.ru", "phone": "+70498253880"}
0005432062293	6A5735	9676 670687	VYACHESLAV SOKOLOV	{"phone": "+70131931498"}
0005432062294	A55263	3439 193859	MIKHAIL MAKAROV	{"phone": "+70179313552"}
0005432062295	7D2A2B	4344 156552	VERA OSIPOVA	{"email": "vera_osipova_21011976@postgrespro.ru", "phone": "+70469622753"}
0005432062296	1A569C	9470 736649	TATYANA VOLKOVA	{"phone": "+70808469371"}
0005432062297	CA9DDD	9408 611716	GALINA OSIPOVA	{"email": "galinaosipova-011972@postgrespro.ru", "phone": "+70640840772"}
0005432062298	CA9DDD	7326 302327	LYUBOV FEDOROVA	{"phone": "+70939609660"}
0005432062299	27CD19	0039 335223	MIKHAIL VASILEV	{"email": "vasilev_mikhail1962@postgrespro.ru", "phone": "+70975923494"}
0005432062300	0834BB	7512 363296	NINA NAZAROVA	{"phone": "+70998924687"}
0005432062301	07CF72	7126 939930	VALERIYA SOKOLOVA	{"email": "v-sokolova091966@postgrespro.ru", "phone": "+70156218458"}
0005432062302	07CF72	9689 072685	NATALIYA FILIPPOVA	{"phone": "+70839610075"}
0005432062303	91A529	7374 782127	OKSANA KRASNOVA	{"email": "krasnovaoksana-121979@postgrespro.ru", "phone": "+70566304600"}
0005432062304	91A529	2099 277738	VALENTIN MATVEEV	{"phone": "+70049772369"}
0005432062305	571202	2530 812609	GALINA NESTEROVA	{"phone": "+70501276828"}
0005432062306	571202	0961 121387	NADEZHDA GRISHINA	{"email": "grishinan_21121983@postgrespro.ru", "phone": "+70757677692"}
0005432062307	95F4FC	1149 378055	NATALYA DAVYDOVA	{"email": "davydova-n_1967@postgrespro.ru", "phone": "+70198768318"}
0005432062308	4CF5C5	4929 334949	ALEKSEY DAVYDOV	{"email": "aleksey-davydov.091981@postgrespro.ru", "phone": "+70518266894"}
0005432062309	4CF5C5	0394 424446	IRINA SERGEEVA	{"email": "sergeeva.i-091970@postgrespro.ru", "phone": "+70047913441"}
0005432062310	4CF5C5	5810 551232	NIKOLAY GAVRILOV	{"phone": "+70751344236"}
0005432062311	7628F7	9611 466821	ALEKSEY SOKOLOV	{"email": "asokolov-101980@postgrespro.ru", "phone": "+70309226063"}
0005432062312	7628F7	0562 669833	GEORGIY ILIN	{"email": "georgiy.ilin.29051970@postgrespro.ru", "phone": "+70743442145"}
0005432062313	3D43F2	0039 483870	ANDREY ALEKSEEV	{"email": "alekseev-andrey.12031963@postgrespro.ru", "phone": "+70885477852"}
0005432062314	41B1C3	4119 702753	EKATERINA MOROZOVA	{"email": "morozova.e26091973@postgrespro.ru", "phone": "+70715435628"}
0005432062315	41B1C3	0286 909874	ELENA DAVYDOVA	{"phone": "+70908109677"}
0005432062316	41B1C3	8607 840449	ZULFIYA VASILEVA	{"email": "vasileva-zulfiya.1982@postgrespro.ru", "phone": "+70461964097"}
0005432062317	30B44F	5452 586720	NATALYA SERGEEVA	{"phone": "+70217665986"}
0005432062318	2D3B5B	2852 688456	NATALYA SCHERBAKOVA	{"phone": "+70829675510"}
0005432062319	DABB13	1669 093393	ZINAIDA TIMOFEEVA	{"phone": "+70833926040"}
0005432062320	DABB13	9811 727914	IRINA GUSEVA	{"phone": "+70032103793"}
0005432062321	EC72DD	9976 830473	ELENA KALININA	{"phone": "+70547001674"}
0005432062322	EC72DD	8700 256811	ALEKSEY CHERNOV	{"phone": "+70085414622"}
0005432062323	21E43D	1463 186897	DMITRIY KUZNECOV	{"email": "d_kuznecov_081961@postgrespro.ru", "phone": "+70206397812"}
0005432062324	21E43D	3621 563635	GALINA YUDINA	{"email": "gyudina1974@postgrespro.ru", "phone": "+70620597351"}
0005432062325	DCF9D7	2899 263554	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-valentina-29071965@postgrespro.ru", "phone": "+70119615641"}
0005432062326	DCF9D7	5729 952308	ANDREY SIDOROV	{"email": "sidorov_a-081979@postgrespro.ru", "phone": "+70592091795"}
0005432062327	A79428	3123 487301	VIKTOR KAZAKOV	{"phone": "+70196351024"}
0005432062328	B7A1E2	2881 406073	VASILIY OSIPOV	{"email": "osipovvasiliy.011968@postgrespro.ru", "phone": "+70866161369"}
0005432062329	43BB82	9610 789228	DMITRIY MIRONOV	{"email": "d-mironov1969@postgrespro.ru", "phone": "+70249445194"}
0005432062330	43BB82	9710 308828	EVGENIY KAZAKOV	{"phone": "+70024071372"}
0005432062331	43BB82	1999 498553	ANDREY CHERNOV	{"email": "chernov_a1958@postgrespro.ru", "phone": "+70757607427"}
0005432062332	F4FC74	5478 609119	SERGEY BELOV	{"email": "sbelov_08071970@postgrespro.ru", "phone": "+70998692314"}
0005432062333	0CFFD7	3844 733315	NADEZHDA NOVIKOVA	{"phone": "+70531984336"}
0005432062334	E0C2D5	6649 483834	EVDOKIYA EGOROVA	{"email": "egorova.e051974@postgrespro.ru", "phone": "+70968416045"}
0005432062335	CABF37	4966 700546	SERGEY NAZAROV	{"email": "s-nazarov-13021971@postgrespro.ru", "phone": "+70654429481"}
0005432062336	CABF37	6675 880077	ALLA NESTEROVA	{"phone": "+70167576163"}
0005432062337	5B3C96	5897 713395	KRISTINA KUZNECOVA	{"email": "k_kuznecova_1968@postgrespro.ru", "phone": "+70275918256"}
0005432062338	F2CB22	8506 857244	TATYANA ANDREEVA	{"email": "tatyana_andreeva041966@postgrespro.ru", "phone": "+70672951931"}
0005432062339	5B27C2	7861 419200	VASILIY SAVELEV	{"email": "savelev.vasiliy_01061969@postgrespro.ru", "phone": "+70825334768"}
0005432062340	60E81E	0637 333605	ALEKSANDR SEMENOV	{"email": "semenov-a_1980@postgrespro.ru", "phone": "+70486527016"}
0005432062341	60E81E	4661 470647	MARIYA POPOVA	{"phone": "+70684222647"}
0005432062342	62BEA0	2259 509647	ANDREY YAKOVLEV	{"phone": "+70780786702"}
0005432062343	53EBA5	9565 117274	VASILIY KONOVALOV	{"phone": "+70447035683"}
0005432062344	53EBA5	2292 694273	ALEKSANDR SIDOROV	{"phone": "+70348130980"}
0005432062345	C0E6A9	3435 650887	OLGA SAVELEVA	{"email": "o.saveleva.21011983@postgrespro.ru", "phone": "+70659224453"}
0005432062346	B1D31D	5991 020933	MARAT NOVIKOV	{"phone": "+70146147891"}
0005432062347	3FEBA8	1872 912140	LYUBOV ARKHIPOVA	{"email": "l.arkhipova_29111972@postgrespro.ru", "phone": "+70761304944"}
0005432062348	81099D	6977 392414	ANASTASIYA ZHUKOVA	{"email": "zhukova_a1974@postgrespro.ru", "phone": "+70445129035"}
0005432062349	10F07D	4364 177326	ROMAN KRASNOV	{"email": "krasnov_roman_031979@postgrespro.ru", "phone": "+70999425991"}
0005432062350	6154A6	8165 838715	SERGEY KRASNOV	{"phone": "+70142884343"}
0005432062351	8C5EC1	8930 697662	MARIYA POPOVA	{"email": "mpopova-031973@postgrespro.ru", "phone": "+70773675455"}
0005432062352	8C5EC1	3157 047238	VLADIMIR ANTONOV	{"phone": "+70174154603"}
0005432062353	27334A	1125 445408	MIKHAIL FEDOTOV	{"phone": "+70228309012"}
0005432062354	CCB40F	6025 822257	ALEKSANDR POPOV	{"phone": "+70331363933"}
0005432062355	D32179	3507 571001	TIMOFEY KUZNECOV	{"phone": "+70252184850"}
0005432062356	359432	4573 593358	NATALIYA NOVIKOVA	{"email": "novikovan_101972@postgrespro.ru", "phone": "+70483892394"}
0005432062357	359432	0832 919485	YURIY SOLOVEV	{"phone": "+70983223128"}
0005432062358	9A9B1D	0408 965428	LYUDMILA MAKAROVA	{"phone": "+70330213931"}
0005432062359	9A9B1D	9617 308065	ALEKSANDRA GERASIMOVA	{"email": "agerasimova_25011982@postgrespro.ru", "phone": "+70733166281"}
0005432062360	950EBF	8900 863522	TATYANA SIDOROVA	{"phone": "+70848306425"}
0005432062361	950EBF	5389 502538	LYUDMILA ZAYCEVA	{"phone": "+70198830509"}
0005432062362	950EBF	8494 881605	ALEKSANDRA KONDRATEVA	{"phone": "+70900317636"}
0005432062363	F08331	8619 362621	VLADIMIR IVANOV	{"email": "ivanov.v-29071973@postgrespro.ru", "phone": "+70496929480"}
0005432062364	697D26	9078 299236	TATYANA VOROBEVA	{"phone": "+70284392757"}
0005432062365	4F23A7	2458 114503	VLADIMIR BARANOV	{"email": "vladimirbaranov.021976@postgrespro.ru", "phone": "+70450337414"}
0005432062366	039A4A	9061 976934	ALEKSANDR FEDOTOV	{"phone": "+70863084364"}
0005432062368	041B6C	4499 287216	VLADIMIR TIKHONOV	{"email": "tikhonovv_1968@postgrespro.ru", "phone": "+70313142396"}
0005432062369	73D094	2046 573245	SERGEY KUDRYASHOV	{"phone": "+70015470453"}
0005432062370	86EF72	2909 405977	DARYA MARTYNOVA	{"phone": "+70691990974"}
0005432062371	86EF72	6747 714795	SVETLANA VASILEVA	{"email": "vasileva-svetlana021981@postgrespro.ru", "phone": "+70939870631"}
0005432062372	86EF72	1846 593644	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana1981@postgrespro.ru", "phone": "+70400384645"}
0005432062373	CD8C53	3427 147288	SERGEY KAZAKOV	{"email": "sergeykazakov-08011972@postgrespro.ru", "phone": "+70478060829"}
0005432062374	56CD83	3631 641293	EVGENIY ILIN	{"phone": "+70459541514"}
0005432062375	258401	0580 555925	LARISA GUSEVA	{"phone": "+70950932091"}
0005432062376	6E17C3	7103 289859	VLADIMIR MATVEEV	{"email": "matveev-vladimir071967@postgrespro.ru", "phone": "+70296914535"}
0005432062377	194F34	2829 263110	POLINA ALEKSANDROVA	{"phone": "+70832373563"}
0005432062378	194F34	7992 302650	ALEKSEY SEMENOV	{"email": "a-semenov_26081982@postgrespro.ru", "phone": "+70521471755"}
0005432062379	E407E5	0489 356440	TATYANA PETROVA	{"email": "t-petrova_111967@postgrespro.ru", "phone": "+70092754391"}
0005432062380	E407E5	1484 099059	LYUBOV ZAKHAROVA	{"email": "l-zakharova.23121967@postgrespro.ru", "phone": "+70191542970"}
0005432062381	37EDB4	5640 444952	GALINA VLASOVA	{"email": "vlasova-galina.26021968@postgrespro.ru", "phone": "+70397175046"}
0005432062382	37EDB4	1329 797002	GEORGIY IVANOV	{"email": "georgiy.ivanov-1966@postgrespro.ru", "phone": "+70642719377"}
0005432062383	AADDB3	5500 323628	ELENA EGOROVA	{"email": "elena.egorova091980@postgrespro.ru", "phone": "+70753158489"}
0005432062384	5A0AFF	7137 768600	VLADIMIR DENISOV	{"phone": "+70634294043"}
0005432062385	29DC38	3214 414584	PETR ZHUKOV	{"phone": "+70945794186"}
0005432062386	0A283C	4916 067932	ALEKSEY SOKOLOV	{"phone": "+70573280790"}
0005432062387	704E0B	2563 186422	KSENIYA EGOROVA	{"phone": "+70478175510"}
0005432069394	B34A3B	2298 385952	SVETLANA ROMANOVA	{"phone": "+70860084411"}
0005432069395	21E873	2137 487224	TATYANA KUZNECOVA	{"phone": "+70241115796"}
0005432069396	21E873	3077 365023	ILYA NAZAROV	{"phone": "+70956697582"}
0005432069397	21E873	4807 934336	IRINA AKIMOVA	{"email": "akimova.irina05121982@postgrespro.ru", "phone": "+70288755649"}
0005432069398	12698D	7935 284139	PETR NIKITIN	{"email": "nikitin_p121972@postgrespro.ru", "phone": "+70830436790"}
0005432069399	8F964D	1613 342775	GENNADIY GORBUNOV	{"email": "g-gorbunov_111970@postgrespro.ru", "phone": "+70865023758"}
0005432069400	61266B	6862 444689	YULIYA MIKHAYLOVA	{"email": "mikhaylova_yuliya_1972@postgrespro.ru", "phone": "+70652266198"}
0005432069401	4E3590	6977 675783	ANASTASIYA LAZAREVA	{"email": "a.lazareva101973@postgrespro.ru", "phone": "+70512682103"}
0005432069402	CD7B0A	8496 044141	SERGEY FEDOROV	{"email": "sergeyfedorov-08121972@postgrespro.ru", "phone": "+70355311940"}
0005432069403	CD7B0A	7765 637629	ALEKSEY SOROKIN	{"email": "sorokin-a_071977@postgrespro.ru", "phone": "+70932157259"}
0005432069404	CD7B0A	1108 042107	IVAN ROMANOV	{"email": "ivan-romanov13061956@postgrespro.ru", "phone": "+70197715207"}
0005432069405	13223D	6283 251713	NINA IVANOVA	{"email": "n-ivanova.011983@postgrespro.ru", "phone": "+70362524428"}
0005432069406	46DA02	5416 424487	VLADIMIR SOROKIN	{"phone": "+70608976092"}
0005432069407	3A9227	9028 505732	IGOR ALEKSEEV	{"email": "igor-alekseev081965@postgrespro.ru", "phone": "+70253128791"}
0005432069408	3A9227	4275 174190	IRINA MAKAROVA	{"phone": "+70745447306"}
0005432069409	82C99B	7328 424923	KSENIYA TIKHONOVA	{"email": "tikhonova-k-061965@postgrespro.ru", "phone": "+70889587864"}
0005432069410	82C99B	0241 680025	IRINA KONOVALOVA	{"phone": "+70798067630"}
0005432069411	428BF5	6607 280730	BORIS CHERNOV	{"phone": "+70875820359"}
0005432069412	84A1C4	0463 699409	SERGEY SCHERBAKOV	{"phone": "+70215493989"}
0005432069413	84A1C4	5343 330846	VLADIMIR ANDREEV	{"email": "andreevv041970@postgrespro.ru", "phone": "+70305769458"}
0005432069414	D4B74F	9858 933279	VIKTOR IVANOV	{"phone": "+70041240828"}
0005432069415	82BE0D	2493 639022	ALEKSANDR MELNIKOV	{"phone": "+70918475381"}
0005432069416	84A96D	0857 382560	INNA ZHUKOVA	{"email": "zhukova.i09121966@postgrespro.ru", "phone": "+70384477756"}
0005432069417	8A613B	8720 939690	SERGEY KOZLOV	{"email": "s-kozlov-1963@postgrespro.ru", "phone": "+70083810152"}
0005432069418	DCF398	9451 013454	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir_111973@postgrespro.ru", "phone": "+70921705488"}
0005432069419	DCF398	2101 927941	NINA EGOROVA	{"phone": "+70055515678"}
0005432069420	9D1BCB	2684 496022	IRINA PAVLOVA	{"email": "pavlova-i-07121976@postgrespro.ru", "phone": "+70839563258"}
0005432069421	26C8F3	9338 043407	TATYANA IVANOVA	{"email": "tatyana-ivanova-1965@postgrespro.ru", "phone": "+70765030602"}
0005432069422	26C8F3	6783 836306	POLINA NESTEROVA	{"email": "nesterovap.1973@postgrespro.ru", "phone": "+70094165991"}
0005432069423	820263	5185 677941	ALEKSEY NIKOLAEV	{"email": "anikolaev_1962@postgrespro.ru", "phone": "+70576635258"}
0005432069424	9F4AEF	0425 746079	SVETLANA MOISEEVA	{"email": "svetlana-moiseeva1971@postgrespro.ru", "phone": "+70563977174"}
0005432069425	144F3A	5643 576555	MARINA PETROVA	{"phone": "+70059202695"}
0005432069426	5F4513	1543 449370	ELENA LOGINOVA	{"phone": "+70304682735"}
0005432069427	36C747	3985 124367	ANATOLIY SEMENOV	{"email": "anatoliy-semenov-041970@postgrespro.ru", "phone": "+70081944633"}
0005432069428	36C747	8843 094281	OLGA NIKOLAEVA	{"phone": "+70796116031"}
0005432069429	7FF9F1	8589 784110	DIANA ZAKHAROVA	{"email": "zakharovadiana.1978@postgrespro.ru", "phone": "+70194415509"}
0005432069430	7FF9F1	3168 389515	NIKOLAY ALEKSANDROV	{"phone": "+70199452661"}
0005432069431	430F24	6712 978393	ANTONIDA ISAEVA	{"phone": "+70969439113"}
0005432069432	B49C3E	8305 350120	YULIYA KUZNECOVA	{"email": "ykuznecova.1973@postgrespro.ru", "phone": "+70319943510"}
0005432069433	D3317B	4510 790106	TATYANA KRASNOVA	{"phone": "+70514142464"}
0005432069434	D3317B	3549 498322	ANASTASIYA IVANOVA	{"phone": "+70538864175"}
0005432069435	768408	9017 369055	MAKSIM MEDVEDEV	{"email": "medvedev_maksim091968@postgrespro.ru", "phone": "+70132671355"}
0005432069436	41408B	9492 691557	MIKHAIL SOKOLOV	{"phone": "+70338322752"}
0005432069437	8887D3	0558 883722	TAMARA FROLOVA	{"phone": "+70336321480"}
0005432069438	8887D3	0494 838079	ALEKSANDR SCHERBAKOV	{"phone": "+70144720389"}
0005432069439	238A02	2031 673992	IGOR GUSEV	{"email": "igor-gusev1984@postgrespro.ru", "phone": "+70445712139"}
0005432069440	238A02	8810 734430	ALEKSANDR MIRONOV	{"email": "a_mironov.30041971@postgrespro.ru", "phone": "+70773408068"}
0005432069441	0D8C3A	3706 517063	ELENA SEMENOVA	{"phone": "+70313703575"}
0005432069442	AC357F	0068 601838	ELENA MASLOVA	{"phone": "+70235677382"}
0005432069443	E08F93	4209 666192	GALINA GORBUNOVA	{"email": "g.gorbunova061972@postgrespro.ru", "phone": "+70953736259"}
0005432069444	4CB261	2785 660160	SERGEY MEDVEDEV	{"email": "medvedev-sergey.28011964@postgrespro.ru", "phone": "+70533297710"}
0005432069445	E7C34E	6874 824651	GENNADIY KULIKOV	{"email": "kulikov-g_091975@postgrespro.ru", "phone": "+70401756411"}
0005432069446	E7C34E	7564 929060	ZOYA GORBUNOVA	{"email": "gorbunovaz-091967@postgrespro.ru", "phone": "+70656407422"}
0005432069447	BAE25A	8914 171274	MARIYA MALYSHEVA	{"email": "malysheva-mariya1975@postgrespro.ru", "phone": "+70322958251"}
0005432069448	585AFB	1223 327174	RAISA LAZAREVA	{"email": "r.lazareva_09081975@postgrespro.ru", "phone": "+70029554065"}
0005432069449	A9482A	1901 827667	SERGEY PETROV	{"phone": "+70931462041"}
0005432069450	A9482A	0322 704893	TATYANA MIRONOVA	{"phone": "+70317206303"}
0005432069451	A9482A	7253 784672	NATALYA MOROZOVA	{"email": "natalya.morozova-031972@postgrespro.ru", "phone": "+70575501205"}
0005432069452	F07DEC	8484 482866	SERGEY ZAYCEV	{"phone": "+70763526116"}
0005432069453	F07DEC	0961 692188	PAVEL GUSEV	{"email": "gusev-p-17011976@postgrespro.ru", "phone": "+70953428487"}
0005432069454	6B537D	5587 244038	TATYANA ARKHIPOVA	{"phone": "+70433682484"}
0005432069455	E66537	8916 579231	ALEKSANDR SOKOLOV	{"email": "sokolov.aleksandr.1975@postgrespro.ru", "phone": "+70964896566"}
0005432069456	13B32A	6599 410469	VLADIMIR SEMENOV	{"email": "vladimir.semenov_061971@postgrespro.ru", "phone": "+70071038463"}
0005432069457	13B32A	7978 471661	OKSANA MATVEEVA	{"email": "matveevao_1981@postgrespro.ru", "phone": "+70582065736"}
0005432069458	952071	5749 248229	ILYA MELNIKOV	{"email": "melnikov-ilya_071981@postgrespro.ru", "phone": "+70582761752"}
0005432069459	51084C	1494 735421	ALEKSEY KUZNECOV	{"phone": "+70932828538"}
0005432069460	51084C	0115 194749	VYACHESLAV PAVLOV	{"email": "pavlov-v04071978@postgrespro.ru", "phone": "+70721186315"}
0005432069461	50BE4B	8162 098075	EVGENIYA POTAPOVA	{"phone": "+70158154276"}
0005432069462	50BE4B	4411 792328	OLGA NESTEROVA	{"email": "nesterova_olga-20121973@postgrespro.ru", "phone": "+70792489137"}
0005432069463	7EF5EE	0277 329311	MARINA NAZAROVA	{"email": "m_nazarova.1970@postgrespro.ru", "phone": "+70872592710"}
0005432069464	7EF5EE	1592 453964	VIKTOR POPOV	{"email": "popovviktor-051968@postgrespro.ru", "phone": "+70012980260"}
0005432069465	07D1A4	3437 076455	VLADIMIR BARANOV	{"phone": "+70046766428"}
0005432069466	C288CC	5657 142376	ARINA ARKHIPOVA	{"email": "arina_arkhipova-1962@postgrespro.ru", "phone": "+70239032540"}
0005432069467	6F5F76	6183 351608	KONSTANTIN SERGEEV	{"phone": "+70672274772"}
0005432069468	143E27	9212 473727	ELENA ZAKHAROVA	{"phone": "+70410878407"}
0005432069469	749DC4	8573 774942	VALENTINA PETROVA	{"phone": "+70761105387"}
0005432069470	749DC4	5346 422332	VERA MATVEEVA	{"phone": "+70809703044"}
0005432069471	D8B51F	1175 448767	YURIY TIMOFEEV	{"phone": "+70528763196"}
0005432069472	424D86	1243 150165	ELENA KOMAROVA	{"email": "ekomarova101967@postgrespro.ru", "phone": "+70296634785"}
0005432069473	424D86	8891 835038	MIKHAIL SEMENOV	{"phone": "+70155502295"}
0005432069474	CD95C8	3733 098357	ARTEM MELNIKOV	{"email": "artem_melnikov1959@postgrespro.ru", "phone": "+70086322957"}
0005432069475	54818E	0905 330841	NADEZHDA BARANOVA	{"phone": "+70499821149"}
0005432069476	78F777	8927 687737	KIRILL SIDOROV	{"email": "kirill-sidorov-15021973@postgrespro.ru", "phone": "+70587663103"}
0005432069477	A74A3A	9019 155047	ALEKSANDR MELNIKOV	{"phone": "+70952567063"}
0005432069478	2E62E9	3007 281566	ELENA SCHERBAKOVA	{"email": "elena_scherbakova-021977@postgrespro.ru", "phone": "+70777737969"}
0005432069479	2E62E9	4584 999762	ELENA DENISOVA	{"email": "denisovaelena081966@postgrespro.ru", "phone": "+70524377250"}
0005432069480	7CA36B	6093 349877	TIMOFEY ILIN	{"phone": "+70443477984"}
0005432069481	260C2D	5216 570657	RAVIL TARASOV	{"phone": "+70525080994"}
0005432069482	260C2D	0018 797086	VIKTOR RODIONOV	{"email": "rodionov_viktor_1976@postgrespro.ru", "phone": "+70252372989"}
0005432069483	ADD9E6	2717 032900	ILYA GAVRILOV	{"email": "ilya.gavrilov_1980@postgrespro.ru", "phone": "+70156735708"}
0005432069484	ADD9E6	0059 329367	EKATERINA ANDREEVA	{"phone": "+70327523698"}
0005432069485	01FBA5	4706 758629	TATYANA CHERNOVA	{"email": "chernovat.031978@postgrespro.ru", "phone": "+70775508353"}
0005432069486	01FBA5	0808 854202	LYUBOV EGOROVA	{"phone": "+70629932398"}
0005432069487	9D2178	6280 935295	OLGA TARASOVA	{"email": "o-tarasova1972@postgrespro.ru", "phone": "+70795664447"}
0005432069488	9D2178	0312 822474	OKSANA KONOVALOVA	{"email": "konovalova-o.04071974@postgrespro.ru", "phone": "+70323762135"}
0005432069489	CB7981	2178 624356	NINA SERGEEVA	{"email": "sergeeva-n-19101966@postgrespro.ru", "phone": "+70992593096"}
0005432069490	241F36	2860 297260	VLADIMIR POPOV	{"email": "vpopov1965@postgrespro.ru", "phone": "+70260750622"}
0005432069491	365A84	7562 865323	LYUDMILA KOVALEVA	{"email": "kovaleva.lyudmila.011977@postgrespro.ru", "phone": "+70677741994"}
0005432069492	499D9E	5272 868130	ALEKSANDR GRIGOREV	{"phone": "+70972206606"}
0005432069493	499D9E	0008 327632	VLADIMIR MAKAROV	{"email": "vmakarov_1969@postgrespro.ru", "phone": "+70917042332"}
0005432069494	10A8E9	5120 672252	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr-1975@postgrespro.ru", "phone": "+70779460032"}
0005432069495	949151	4628 592036	VYACHESLAV SEMENOV	{"email": "v_semenov-031974@postgrespro.ru", "phone": "+70592187302"}
0005432069496	949151	1858 144206	VENERA SOLOVEVA	{"email": "soloveva.venera_1971@postgrespro.ru", "phone": "+70638186976"}
0005432069497	5CC101	0240 336733	YULIYA SEMENOVA	{"phone": "+70879619196"}
0005432069498	F607C6	1372 976409	VALERIYA NIKOLAEVA	{"email": "nikolaevav111978@postgrespro.ru", "phone": "+70895235456"}
0005432069499	992EA0	2998 909937	IREK EGOROV	{"phone": "+70796537403"}
0005432069500	67D2BA	1365 687845	SERGEY IVANOV	{"phone": "+70713384411"}
0005432069501	67D2BA	6881 172321	ANGELINA YUDINA	{"email": "angelinayudina09081975@postgrespro.ru", "phone": "+70167057000"}
0005432069502	9EFD11	4778 196233	NAIL MAKSIMOV	{"email": "n_maksimov16101989@postgrespro.ru", "phone": "+70377367956"}
0005432069503	53CF14	9095 629107	GRIGORIY GERASIMOV	{"phone": "+70942456359"}
0005432069504	53CF14	6814 931410	ANTONINA TARASOVA	{"phone": "+70091225453"}
0005432069505	1FE6F5	5475 008031	MIKHAIL KUZNECOV	{"email": "kuznecovm-1966@postgrespro.ru", "phone": "+70413382234"}
0005432069506	1FE6F5	4152 086849	ELENA BARANOVA	{"email": "baranova_e-1961@postgrespro.ru", "phone": "+70581222143"}
0005432069507	99D024	3800 684628	TATYANA LOGINOVA	{"phone": "+70133741350"}
0005432069508	99D024	0264 592946	VALENTINA SOLOVEVA	{"email": "soloveva.valentina.1968@postgrespro.ru", "phone": "+70121872441"}
0005432069509	67CE79	9709 512943	VLADIMIR NAUMOV	{"email": "v-naumov.16051966@postgrespro.ru", "phone": "+70479803968"}
0005432069510	3EEDA1	7252 385127	ANASTASIYA KOVALEVA	{"email": "anastasiyakovaleva-1973@postgrespro.ru", "phone": "+70314264362"}
0005432069511	3EEDA1	9494 509998	MAKSIM IVANOV	{"email": "m_ivanov_1970@postgrespro.ru", "phone": "+70538238663"}
0005432069512	3EB02F	8571 449148	VLADIMIR YAKOVLEV	{"phone": "+70720874115"}
0005432069513	6729FD	7033 552232	NATALYA TARASOVA	{"phone": "+70022815650"}
0005432069514	6729FD	4563 024867	GALINA SOKOLOVA	{"email": "g-sokolova.031972@postgrespro.ru", "phone": "+70796889225"}
0005432069515	3FB0AF	1527 033138	SERGEY EGOROV	{"phone": "+70983872355"}
0005432069516	3FB0AF	6991 567455	LYUBOV ALEKSEEVA	{"phone": "+70100398078"}
0005432069517	D1A21D	0474 497520	VALENTINA VOROBEVA	{"phone": "+70907954940"}
0005432069518	964345	7809 736175	ALEKSANDR DMITRIEV	{"phone": "+70589784598"}
0005432069519	964345	1258 469085	NIKOLAY NOVIKOV	{"email": "novikov_n.051985@postgrespro.ru", "phone": "+70803742650"}
0005432069520	2A2CA2	3892 136794	IRINA KULIKOVA	{"phone": "+70744329012"}
0005432069521	2A2CA2	1216 899736	PETR NAZAROV	{"phone": "+70349202435"}
0005432069522	2A2CA2	3897 744876	ELIZAVETA YAKOVLEVA	{"email": "e_yakovleva111977@postgrespro.ru", "phone": "+70016021266"}
0005432069523	8F1E1B	8477 660573	ALEKSANDR MELNIKOV	{"phone": "+70766837794"}
0005432069524	01075F	9272 680986	IVAN POPOV	{"email": "i-popov_04051966@postgrespro.ru", "phone": "+70489117712"}
0005432069525	01075F	9562 977708	TATYANA PAVLOVA	{"email": "pavlova-tatyana-071979@postgrespro.ru", "phone": "+70129105051"}
0005432069526	01075F	8943 237475	VALERIYA IVANOVA	{"email": "ivanovav.1985@postgrespro.ru", "phone": "+70316030696"}
0005432069527	637B18	8899 687800	GRIGORIY MELNIKOV	{"phone": "+70949227038"}
0005432069528	637B18	8134 532069	ALEKSEY SOROKIN	{"email": "asorokin.081972@postgrespro.ru", "phone": "+70927115438"}
0005432069529	4AF796	4019 022139	ANASTASIYA MAKAROVA	{"email": "makarova_a.051974@postgrespro.ru", "phone": "+70055889873"}
0005432069530	4AF796	3601 062707	SERGEY STEPANOV	{"email": "stepanov.sergey.28111972@postgrespro.ru", "phone": "+70247801267"}
0005432069531	4AF796	2446 191383	NATALYA KONOVALOVA	{"email": "konovalova_n101976@postgrespro.ru", "phone": "+70224696831"}
0005432069532	031570	8578 100895	ELENA TITOVA	{"email": "titova-elena_021961@postgrespro.ru", "phone": "+70174446395"}
0005432069533	AC2ADC	8825 461122	SERGEY KOZLOV	{"phone": "+70537155836"}
0005432069534	66DEAB	8574 058703	LYUDMILA KUZNECOVA	{"email": "kuznecoval.13041978@postgrespro.ru", "phone": "+70046180253"}
0005432069535	8E6B9D	9509 603687	ANDREY GRIGOREV	{"phone": "+70062769422"}
0005432069536	8E6B9D	6356 312797	DMITRIY NIKITIN	{"phone": "+70164497557"}
0005432069537	DF0133	3321 326056	MIKHAIL ANTONOV	{"phone": "+70437564638"}
0005432069538	A1492A	3407 466750	TATYANA ARKHIPOVA	{"phone": "+70510276344"}
0005432069539	1457D0	2596 014819	MAKSIM PAVLOV	{"email": "m.pavlov_1976@postgrespro.ru", "phone": "+70375252913"}
0005432069540	F1996D	1462 399952	ALEKSANDR SMIRNOV	{"email": "a-smirnov1971@postgrespro.ru", "phone": "+70111316482"}
0005432069541	7F1AC9	9218 649085	EVGENIY DMITRIEV	{"email": "dmitrieve_121972@postgrespro.ru", "phone": "+70389062328"}
0005432069542	7F1AC9	6396 026167	ANASTASIYA TARASOVA	{"phone": "+70875395930"}
0005432069543	271E3F	8280 817426	SERGEY KOZLOV	{"phone": "+70236064276"}
0005432069544	271E3F	7858 493583	POLINA PAVLOVA	{"phone": "+70969064166"}
0005432069545	EA1E4F	0537 574239	OLGA YAKOVLEVA	{"email": "yakovleva_o1973@postgrespro.ru", "phone": "+70937173144"}
0005432069546	AC0350	9017 872164	VALENTIN KUZNECOV	{"email": "valentin.kuznecov.051981@postgrespro.ru", "phone": "+70969667191"}
0005432069547	145378	0489 976254	TATYANA MASLOVA	{"phone": "+70666862563"}
0005432069548	C4A550	8065 846512	TATYANA PETROVA	{"email": "petrova.tatyana_1979@postgrespro.ru", "phone": "+70028879174"}
0005432069549	36B676	3417 960495	ANNA STEPANOVA	{"email": "anna.stepanova_121978@postgrespro.ru", "phone": "+70275900402"}
0005432069550	36B676	9149 744993	ANASTASIYA KOLESNIKOVA	{"phone": "+70934072080"}
0005432069733	684F57	4243 917953	GULNARA NESTEROVA	{"phone": "+70646455724"}
0005432069551	658874	4253 527994	MARIYA ZAKHAROVA	{"email": "zakharovamariya1973@postgrespro.ru", "phone": "+70191410867"}
0005432069552	145559	5743 534365	NADEZHDA LEBEDEVA	{"phone": "+70449616725"}
0005432069553	145559	6415 240541	NIKOLAY KISELEV	{"email": "nkiselev_14051980@postgrespro.ru", "phone": "+70152210684"}
0005432069554	08B6AE	2099 919184	ALEKSANDR NAZAROV	{"phone": "+70538162491"}
0005432069555	08B6AE	3687 366595	TATYANA PETROVA	{"phone": "+70587396553"}
0005432069556	06CE58	1942 418256	GENNADIY SEMENOV	{"phone": "+70447112135"}
0005432069557	06CE58	7925 299590	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_09111970@postgrespro.ru", "phone": "+70084566195"}
0005432069558	06CE58	7412 474532	RITA KARPOVA	{"email": "karpova-r.101980@postgrespro.ru", "phone": "+70855945071"}
0005432069559	E49890	2351 173645	NATALYA VOLKOVA	{"phone": "+70388806903"}
0005432069560	E49890	3504 084494	MAKSIM SOKOLOV	{"email": "sokolov-maksim-031970@postgrespro.ru", "phone": "+70629989074"}
0005432069561	CACB77	3593 082780	TATYANA TARASOVA	{"phone": "+70671055250"}
0005432069562	1E5B64	3380 353438	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_061970@postgrespro.ru", "phone": "+70868608134"}
0005432069563	106C5F	3325 917672	ALEKSANDR TARASOV	{"phone": "+70412646750"}
0005432069564	81A54D	7879 126838	MARINA KAZAKOVA	{"phone": "+70481118871"}
0005432069565	81A54D	4952 753079	PELAGEYA IVANOVA	{"phone": "+70793242463"}
0005432069566	81A54D	9041 524617	SVETLANA DMITRIEVA	{"email": "svetlana_dmitrieva-1976@postgrespro.ru", "phone": "+70246294751"}
0005432069567	7C96AE	7654 056640	ALEKSANDRA SAVELEVA	{"email": "saveleva_aleksandra28091976@postgrespro.ru", "phone": "+70606003414"}
0005432069568	C43A9E	9835 110082	GENNADIY KAZAKOV	{"email": "g.kazakov.16061970@postgrespro.ru", "phone": "+70204669276"}
0005432069569	C43A9E	8244 558929	NINA ANDREEVA	{"phone": "+70912354613"}
0005432069570	8E395A	2296 104488	ELENA KONDRATEVA	{"phone": "+70632519220"}
0005432069571	F69216	6858 710742	ALEKSEY FEDOTOV	{"phone": "+70653881729"}
0005432069572	372DF6	4960 198694	DMITRIY KUZNECOV	{"phone": "+70214363849"}
0005432069573	4BBA20	1850 814538	ANASTASIYA EFIMOVA	{"phone": "+70576513591"}
0005432069574	436566	8381 079725	ALEVTINA IVANOVA	{"phone": "+70055757238"}
0005432069575	436566	5377 394863	SERGEY SIDOROV	{"email": "sergey-sidorov-03061971@postgrespro.ru", "phone": "+70960004648"}
0005432069576	4B6D3A	8357 149363	NINA NAZAROVA	{"phone": "+70801423036"}
0005432069577	575120	3019 106354	NIKOLAY GORBUNOV	{"phone": "+70331179588"}
0005432069578	23A6B2	6948 641127	EVGENIYA DANILOVA	{"phone": "+70394899904"}
0005432069579	E1B237	8341 764516	VERA TROFIMOVA	{"phone": "+70555099762"}
0005432069580	E1B237	1663 813650	DMITRIY KAZAKOV	{"phone": "+70746243902"}
0005432069581	42DC06	9592 950801	OLGA DMITRIEVA	{"phone": "+70252470871"}
0005432069582	43F1A3	9180 895291	TATYANA TIKHONOVA	{"phone": "+70065339900"}
0005432069583	43F1A3	6417 865862	OLGA TITOVA	{"phone": "+70695910382"}
0005432069584	4C2DB4	4842 113655	VYACHESLAV VOROBEV	{"email": "vyacheslav_vorobev.011973@postgrespro.ru", "phone": "+70155593947"}
0005432069585	7D5615	7831 833946	TATYANA VOROBEVA	{"email": "vorobeva_tatyana021977@postgrespro.ru", "phone": "+70481585222"}
0005432069586	7C68FF	9567 086263	DARINA ZAKHAROVA	{"email": "darina_zakharova1977@postgrespro.ru", "phone": "+70575056019"}
0005432069587	7C68FF	7959 842226	ROMAN IVANOV	{"email": "ivanov-r1979@postgrespro.ru", "phone": "+70839667169"}
0005432069588	E62F01	0398 933150	TATYANA BELOVA	{"email": "tatyanabelova.1973@postgrespro.ru", "phone": "+70975153107"}
0005432069589	32863A	1734 091224	SVETLANA MOISEEVA	{"phone": "+70295478691"}
0005432069590	E07BC9	6622 409185	PETR MEDVEDEV	{"phone": "+70270726287"}
0005432069591	E07BC9	3796 744445	KLAVDIYA TIMOFEEVA	{"phone": "+70884350714"}
0005432069592	E07BC9	4642 124110	GALINA KISELEVA	{"email": "kiseleva.galina23011974@postgrespro.ru", "phone": "+70737830764"}
0005432069593	337956	1294 344689	ALEKSANDR PETROV	{"phone": "+70024854921"}
0005432069594	337956	0541 708137	IRINA IVANOVA	{"email": "ivanova_i.111983@postgrespro.ru", "phone": "+70520662467"}
0005432069595	63E84B	5072 393050	STEPAN PAVLOV	{"phone": "+70750028994"}
0005432069596	63E84B	9956 110270	ANNA ANDREEVA	{"email": "anna-andreeva.081971@postgrespro.ru", "phone": "+70068136241"}
0005432069597	1283AB	1210 870381	NIKOLAY TIKHONOV	{"phone": "+70348607003"}
0005432069598	6FA801	3690 198812	ELENA ZAKHAROVA	{"phone": "+70433279718"}
0005432069599	6FA801	1924 471853	IRINA KOLESNIKOVA	{"phone": "+70132030222"}
0005432069600	6FA801	4736 878076	TATYANA SOKOLOVA	{"phone": "+70961115444"}
0005432069601	10F64F	7467 396302	IGOR NOVIKOV	{"phone": "+70006903288"}
0005432069602	6EC2CC	9458 753208	VALENTINA GERASIMOVA	{"phone": "+70491578541"}
0005432069603	C68CC1	9267 895197	ALFIYA EGOROVA	{"email": "a_egorova_02051972@postgrespro.ru", "phone": "+70090911258"}
0005432069604	C68CC1	3831 900733	MIKHAIL GUSEV	{"email": "gusev.m.25051979@postgrespro.ru", "phone": "+70879905231"}
0005432069605	BE01F0	7044 265938	MAKSIM FEDOROV	{"phone": "+70334581736"}
0005432069606	D5B611	2274 488254	VLADISLAV PETROV	{"phone": "+70507572078"}
0005432069607	D7F183	6623 815864	ELENA ALEKSANDROVA	{"email": "aleksandrova-elena-16051968@postgrespro.ru", "phone": "+70935694280"}
0005432069608	D7F183	2348 058633	GRIGORIY KUZNECOV	{"email": "kuznecov.grigoriy_1972@postgrespro.ru", "phone": "+70133596463"}
0005432069609	F84F36	3139 343972	SVETLANA MOROZOVA	{"phone": "+70686416194"}
0005432069610	F84F36	1466 511878	TAMARA DAVYDOVA	{"email": "tamara_davydova_1972@postgrespro.ru", "phone": "+70736539817"}
0005432069611	900AD5	6526 745510	ELENA KOZLOVA	{"phone": "+70324208850"}
0005432069612	F216FA	9301 645289	ALEKSEY SEMENOV	{"phone": "+70222237772"}
0005432069613	70B1C3	5342 985749	LYUDMILA MAKAROVA	{"email": "makarovalyudmila101981@postgrespro.ru", "phone": "+70896361652"}
0005432069614	70B1C3	9415 775682	GRIGORIY GRIGOREV	{"email": "grigoriygrigorev_1977@postgrespro.ru", "phone": "+70008538064"}
0005432069615	0C5BA7	7703 309179	IGOR ALEKSEEV	{"email": "alekseevigor_28071977@postgrespro.ru", "phone": "+70692626629"}
0005432069616	612E59	4649 808751	ALEKSANDR KUZMIN	{"phone": "+70728337989"}
0005432069617	612E59	2850 181830	YURIY IVANOV	{"email": "yuriy.ivanov.1978@postgrespro.ru", "phone": "+70641948853"}
0005432069618	6F7B70	5796 709089	OLGA ROMANOVA	{"phone": "+70017002573"}
0005432069619	E52244	6349 418243	ANASTASIYA SAVELEVA	{"phone": "+70770773024"}
0005432069620	58FCD0	1991 847714	ALEKSANDR GAVRILOV	{"email": "gavrilov_a-071984@postgrespro.ru", "phone": "+70644371996"}
0005432069621	8CE295	6648 075517	ELENA MIRONOVA	{"email": "elena.mironova-1973@postgrespro.ru", "phone": "+70843395743"}
0005432069622	64D841	6437 209461	MARIYA KOZLOVA	{"email": "kozlova.mariya_28031962@postgrespro.ru", "phone": "+70577770553"}
0005432069623	D762F4	5791 232615	OKSANA ANTONOVA	{"phone": "+70489033302"}
0005432069624	D762F4	6018 945672	ALEKSEY BELOV	{"email": "belov_aleksey_031982@postgrespro.ru", "phone": "+70800228127"}
0005432069625	D762F4	4807 955136	EVGENIY PAVLOV	{"phone": "+70812951309"}
0005432069626	49FF9F	7302 907806	LYUDMILA STEPANOVA	{"email": "l_stepanova-07071975@postgrespro.ru", "phone": "+70349899521"}
0005432069627	FEB036	7974 512477	SVETLANA KARPOVA	{"phone": "+70912648300"}
0005432069628	8DA117	7174 077961	YANA MEDVEDEVA	{"email": "yana-medvedeva-031982@postgrespro.ru", "phone": "+70640810467"}
0005432069629	59AEB1	2690 893058	DARINA FADEEVA	{"email": "fadeeva-darina.1969@postgrespro.ru", "phone": "+70713267018"}
0005432069630	13F74D	0854 644625	ILYA KUDRYASHOV	{"phone": "+70928355961"}
0005432069631	3429F6	4460 727834	LYUBOV NAUMOVA	{"email": "l-naumova.1984@postgrespro.ru", "phone": "+70676809268"}
0005432069632	759BF0	4941 101894	LIDIYA ZAYCEVA	{"phone": "+70454005229"}
0005432069633	E60005	7039 685729	MARIYA NIKITINA	{"phone": "+70343139626"}
0005432069634	F7C617	5297 090405	VERA BELYAEVA	{"phone": "+70068277272"}
0005432069635	F7C617	8431 003677	ALEKSANDR NAZAROV	{"email": "a.nazarov-121983@postgrespro.ru", "phone": "+70504562522"}
0005432069636	F7C617	2618 437980	TATYANA PETROVA	{"phone": "+70078151110"}
0005432069637	52A9CC	7190 490303	SERGEY MIKHAYLOV	{"email": "sergey.mikhaylov1975@postgrespro.ru", "phone": "+70567439969"}
0005432069638	D35F8D	5250 992164	OLEG KULIKOV	{"phone": "+70596061497"}
0005432069639	23DB85	0082 436604	SVETLANA TARASOVA	{"phone": "+70490383077"}
0005432069640	D4F3B6	4940 608228	IGOR SOKOLOV	{"phone": "+70404789701"}
0005432069641	8B33F9	3176 763830	KHASAN MOROZOV	{"phone": "+70235951582"}
0005432069642	1761FB	9116 175172	VASILIY MAKAROV	{"email": "makarov.vasiliy_1968@postgrespro.ru", "phone": "+70167723548"}
0005432069643	BF305C	8797 980308	NIKITA SIDOROV	{"phone": "+70056986096"}
0005432069644	BF305C	1706 542406	ELENA IVANOVA	{"email": "elenaivanova_25121974@postgrespro.ru", "phone": "+70887977396"}
0005432069645	929647	1750 703605	VALENTINA IVANOVA	{"email": "ivanova.v_091969@postgrespro.ru", "phone": "+70193180843"}
0005432069646	228BE4	2991 954085	LYUDMILA SMIRNOVA	{"email": "smirnova_l.16071977@postgrespro.ru", "phone": "+70887245043"}
0005432069647	228BE4	6903 988780	ALLA IVANOVA	{"phone": "+70612686334"}
0005432069648	65A170	4654 346806	MIKHAIL POPOV	{"email": "popov_m.051969@postgrespro.ru", "phone": "+70595322447"}
0005432069649	65A170	9908 397073	EMIL SAVELEV	{"email": "esavelev-1969@postgrespro.ru", "phone": "+70091395070"}
0005432069650	65A170	2986 336204	DARYA KUZNECOVA	{"email": "kuznecova.d11061974@postgrespro.ru", "phone": "+70927206957"}
0005432069651	7A4F0C	7140 655342	MAYYA MOROZOVA	{"email": "morozova.mayya101980@postgrespro.ru", "phone": "+70642633050"}
0005432069652	C1C7C7	9726 888781	VALENTINA FEDOROVA	{"email": "v-fedorova_071972@postgrespro.ru", "phone": "+70970212628"}
0005432069653	216385	7317 505231	TATYANA DMITRIEVA	{"email": "dmitrieva.t29081960@postgrespro.ru", "phone": "+70795956329"}
0005432069654	75684A	4205 534131	VLADISLAV DMITRIEV	{"phone": "+70561472366"}
0005432069655	9F07B2	1966 157678	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr-1979@postgrespro.ru", "phone": "+70106617469"}
0005432069656	2AE4AC	4761 477414	YULIYA SEMENOVA	{"phone": "+70552840605"}
0005432069657	2AE4AC	7838 430202	VYACHESLAV ROMANOV	{"email": "v_romanov1986@postgrespro.ru", "phone": "+70636824300"}
0005432069658	9FF693	6944 435113	EGOR EGOROV	{"email": "egorov-e_1975@postgrespro.ru", "phone": "+70095865984"}
0005432069659	008B2D	8241 860668	VYACHESLAV SHEVCHENKO	{"phone": "+70079330192"}
0005432069660	0B7925	5457 226893	VLADIMIR SHEVCHENKO	{"phone": "+70586644185"}
0005432069661	0B7925	7432 576743	GULNARA SMIRNOVA	{"phone": "+70335349766"}
0005432069662	0B7925	5026 316604	SVETLANA CHERNOVA	{"email": "s_chernova.1974@postgrespro.ru", "phone": "+70497888241"}
0005432069663	055857	8969 354102	VALENTINA CHERNOVA	{"email": "chernova-valentina.011966@postgrespro.ru", "phone": "+70970865182"}
0005432069664	4FD29A	1050 609692	VIKTOR KULIKOV	{"phone": "+70100108869"}
0005432069665	055DC2	5871 820172	NATALYA SOLOVEVA	{"email": "soloveva.natalya26021975@postgrespro.ru", "phone": "+70620011006"}
0005432069666	87C9D8	7134 643488	DMITRIY ZHUKOV	{"phone": "+70107852501"}
0005432069667	87C9D8	6961 073533	GALINA MAKAROVA	{"email": "galinamakarova1965@postgrespro.ru", "phone": "+70837437405"}
0005432069668	81DBCB	8385 707107	KONSTANTIN AFANASEV	{"phone": "+70599875450"}
0005432069669	23A929	5848 847865	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr.081978@postgrespro.ru", "phone": "+70482419951"}
0005432069670	23A929	5714 126748	EVGENIYA GERASIMOVA	{"email": "e-gerasimova-1967@postgrespro.ru", "phone": "+70241851708"}
0005432069671	37C2AD	4241 887326	PETR FOMIN	{"phone": "+70306369583"}
0005432069672	37C2AD	3988 343555	TATYANA BELOVA	{"email": "tatyana_belova_1967@postgrespro.ru", "phone": "+70929361737"}
0005432069673	565278	9538 721024	TATYANA BORISOVA	{"phone": "+70863764965"}
0005432069674	DD77F6	2721 816106	LYUDMILA PETROVA	{"email": "petrova.lyudmila13061975@postgrespro.ru", "phone": "+70648682665"}
0005432069675	C7A71F	2513 820373	ROMAN FOMIN	{"email": "fomin.r-031975@postgrespro.ru", "phone": "+70388290921"}
0005432069676	254E5C	3221 273058	OLEG SOROKIN	{"phone": "+70466166480"}
0005432069677	C8C11F	0665 713212	PETR PETROV	{"email": "petrovp_1970@postgrespro.ru", "phone": "+70538202284"}
0005432069678	8184AA	4127 460769	EGOR NOVIKOV	{"phone": "+70865568609"}
0005432069679	8184AA	4541 098972	TATYANA GERASIMOVA	{"phone": "+70215613315"}
0005432069680	66B380	7499 684493	YURIY SCHERBAKOV	{"phone": "+70765019133"}
0005432069681	21DD9D	8251 796394	ZINAIDA KOROLEVA	{"phone": "+70895756389"}
0005432069682	4F7E5E	8140 494371	ALEKSANDR GAVRILOV	{"email": "a.gavrilov-011970@postgrespro.ru", "phone": "+70041735684"}
0005432069683	4F7E5E	6681 301816	DENIS KOROLEV	{"email": "korolev_denis-29031963@postgrespro.ru", "phone": "+70968577171"}
0005432069684	86B207	3606 015929	ANDREY MAKAROV	{"phone": "+70743743678"}
0005432069685	E2DB67	2021 633380	VALERIY KUZNECOV	{"phone": "+70461246907"}
0005432069686	8D96EA	7674 803954	MARIYA NIKITINA	{"phone": "+70195802917"}
0005432069687	8D96EA	1330 102502	NINA POLYAKOVA	{"phone": "+70828204641"}
0005432069688	4BA813	1953 538923	ANNA MELNIKOVA	{"email": "a_melnikova_28031981@postgrespro.ru", "phone": "+70457422618"}
0005432069689	4BA813	2001 432543	MARINA EGOROVA	{"phone": "+70989204181"}
0005432069690	C4FF40	4502 476492	NINA KOROLEVA	{"email": "koroleva-nina.1972@postgrespro.ru", "phone": "+70150374326"}
0005432069691	C4FF40	5575 007434	RENATA BELOVA	{"email": "belova-r.20071977@postgrespro.ru", "phone": "+70915639853"}
0005432069692	C4FF40	3891 487333	ANATOLIY KAZAKOV	{"phone": "+70035427637"}
0005432069693	590AD2	4130 946536	IVAN OSIPOV	{"email": "i_osipov-31121971@postgrespro.ru", "phone": "+70418075142"}
0005432069694	590AD2	8585 805695	VALERIY ZAKHAROV	{"email": "zakharovv-1966@postgrespro.ru", "phone": "+70267252177"}
0005432069695	A014BA	9103 709910	NATALYA KUZNECOVA	{"phone": "+70991891549"}
0005432069696	A014BA	2957 583986	VERA TIMOFEEVA	{"email": "vera.timofeeva.1972@postgrespro.ru", "phone": "+70717745731"}
0005432069697	68191D	4239 401708	SVETLANA KRASNOVA	{"email": "krasnova_s-1973@postgrespro.ru", "phone": "+70216831652"}
0005432069698	68191D	1364 746131	INNA TITOVA	{"phone": "+70892329687"}
0005432069699	D35732	3201 557889	ANTON NIKITIN	{"email": "a-nikitin051973@postgrespro.ru", "phone": "+70125991038"}
0005432069700	4F8C9B	5648 343776	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr_021964@postgrespro.ru", "phone": "+70592329065"}
0005432069701	D05AB5	0349 283786	ILYA TIMOFEEV	{"phone": "+70300064580"}
0005432069702	399EBB	4941 082710	OKSANA FADEEVA	{"email": "o.fadeeva1982@postgrespro.ru", "phone": "+70381513777"}
0005432069703	399EBB	9468 018303	YULIYA SMIRNOVA	{"phone": "+70981295408"}
0005432069704	24E6F7	9213 199823	VLADISLAV KUZMIN	{"email": "kuzmin_vladislav-061972@postgrespro.ru", "phone": "+70111742374"}
0005432069705	24E6F7	4879 543621	LYUBOV ABRAMOVA	{"email": "lyubov_abramova.091971@postgrespro.ru", "phone": "+70261123698"}
0005432069706	DE8430	4876 208072	VLADIMIR KULIKOV	{"email": "kulikov.vladimir.011967@postgrespro.ru", "phone": "+70288889180"}
0005432069707	902D94	3153 964943	NADEZHDA VOLKOVA	{"email": "volkova_nadezhda-101969@postgrespro.ru", "phone": "+70469324993"}
0005432069708	D37903	4909 403035	NATALYA MEDVEDEVA	{"phone": "+70313008597"}
0005432069709	D37903	0884 398181	TAMARA ZAYCEVA	{"email": "tamarazayceva28121972@postgrespro.ru", "phone": "+70043894179"}
0005432069710	EF3B7D	4116 499155	VERA KAZAKOVA	{"email": "kazakova.vera-17091977@postgrespro.ru", "phone": "+70077982200"}
0005432069711	EF3B7D	6230 075759	VERA ZHURAVLEVA	{"email": "vera.zhuravleva-011983@postgrespro.ru", "phone": "+70983372492"}
0005432069712	8B3132	2591 959891	OLGA FILIPPOVA	{"email": "ofilippova-1970@postgrespro.ru", "phone": "+70549272385"}
0005432069713	04E7C6	6731 653811	SERGEY FILIPPOV	{"phone": "+70038459309"}
0005432069714	AD23F0	4967 101849	ASKHAT FILIPPOV	{"phone": "+70964402167"}
0005432069715	CBE993	8703 104309	NIKOLAY BARANOV	{"email": "baranovnikolay.1970@postgrespro.ru", "phone": "+70268871505"}
0005432069716	26CC03	3395 031106	ALEKSANDR ILIN	{"email": "aleksandr-ilin_29021976@postgrespro.ru", "phone": "+70698273067"}
0005432069717	0D701D	8288 660377	ANTON KUZNECOV	{"email": "antonkuznecov-061972@postgrespro.ru", "phone": "+70794227811"}
0005432069718	4EAA56	2193 412661	ALEKSANDR DMITRIEV	{"email": "a-dmitriev_1968@postgrespro.ru", "phone": "+70076433914"}
0005432069719	4EAA56	8410 570638	VIKTOR MATVEEV	{"email": "matveev-viktor-19051972@postgrespro.ru", "phone": "+70043306459"}
0005432069720	06872B	4638 624261	SVETLANA RYABOVA	{"email": "s_ryabova-26081975@postgrespro.ru", "phone": "+70949109408"}
0005432069721	06872B	3147 926933	ALEKSANDR IVANOV	{"phone": "+70089674179"}
0005432069722	1FAA6C	5540 203335	ALEKSEY ROMANOV	{"phone": "+70899945804"}
0005432069723	244E27	6040 364534	ARTUR KOZLOV	{"email": "artur_kozlov.1973@postgrespro.ru", "phone": "+70527253146"}
0005432069724	B32C8C	3776 634171	IVAN SOLOVEV	{"email": "i.solovev17021972@postgrespro.ru", "phone": "+70092463565"}
0005432069725	7D556C	1076 554664	IRINA MOROZOVA	{"email": "morozovairina_021968@postgrespro.ru", "phone": "+70902689437"}
0005432069726	7D556C	6568 414576	LYUDMILA KONDRATEVA	{"phone": "+70479360486"}
0005432069727	7D556C	1918 692136	ELENA IVANOVA	{"email": "ivanova.elena.01071971@postgrespro.ru", "phone": "+70518100106"}
0005432069728	A221EA	1102 863549	EVGENIY FOMIN	{"phone": "+70630647269"}
0005432069729	DC83C8	1018 846181	VLADIMIR NIKOLAEV	{"phone": "+70449777286"}
0005432069730	DC83C8	2438 801951	EVGENIYA BARANOVA	{"phone": "+70649290026"}
0005432069731	DF16DC	4893 477383	IRINA KOROLEVA	{"phone": "+70142915605"}
0005432069732	DF16DC	4050 502148	DARYA ABRAMOVA	{"email": "d.abramova1977@postgrespro.ru", "phone": "+70141570194"}
0005432069734	765C6E	7646 755880	VASILIY ALEKSEEV	{"email": "valekseev.1971@postgrespro.ru", "phone": "+70455492590"}
0005432069735	765C6E	7944 551407	ANTON MEDVEDEV	{"email": "a-medvedev041978@postgrespro.ru", "phone": "+70903390859"}
0005432069736	FC29C6	1668 584811	MAKSIM KARPOV	{"email": "karpovm02031966@postgrespro.ru", "phone": "+70681696953"}
0005432069737	FC29C6	3835 044166	SVETLANA LOGINOVA	{"email": "loginova_s_1970@postgrespro.ru", "phone": "+70246156097"}
0005432069738	442806	0387 072994	IVAN MAKAROV	{"email": "makarov_ivan_30041975@postgrespro.ru", "phone": "+70901138923"}
0005432069739	D1B83A	3059 890742	VALENTINA ROMANOVA	{"phone": "+70509761491"}
0005432069740	2EA4A2	2342 139024	VIKTOR ANDREEV	{"phone": "+70300087803"}
0005432069741	2EA4A2	8583 939399	KONSTANTIN BONDARENKO	{"phone": "+70253136342"}
0005432069742	1FECC1	2723 425059	ELENA ORLOVA	{"email": "elena-orlova.111964@postgrespro.ru", "phone": "+70114076508"}
0005432069743	1FECC1	5582 405003	VERA YAKOVLEVA	{"email": "yakovleva_v-23011975@postgrespro.ru", "phone": "+70854024922"}
0005432069744	AD3427	2805 734878	VALENTINA VASILEVA	{"phone": "+70468545711"}
0005432069745	CA9413	4713 993051	ELENA AKIMOVA	{"email": "elena.akimova1977@postgrespro.ru", "phone": "+70589799015"}
0005432069746	90CBEB	1262 599325	VIKTOR DMITRIEV	{"email": "viktordmitriev.081960@postgrespro.ru", "phone": "+70726695289"}
0005432069747	90CBEB	3143 990278	LEYLA FEDOROVA	{"phone": "+70448567389"}
0005432069748	8324B9	6898 185966	GALINA KUZNECOVA	{"phone": "+70510156405"}
0005432069749	53C0A1	0793 821322	ELIZAVETA NESTEROVA	{"email": "enesterova_08071978@postgrespro.ru", "phone": "+70386278811"}
0005432069750	86EC21	4677 144762	SERGEY VASILEV	{"email": "vasilev.s061957@postgrespro.ru", "phone": "+70188287394"}
0005432069751	7D30FD	9526 922529	DINA KOVALEVA	{"phone": "+70921134052"}
0005432069752	E403CD	5686 671898	NIKOLAY ABRAMOV	{"email": "nabramov-02111963@postgrespro.ru", "phone": "+70703545612"}
0005432069753	6C05DA	7361 249460	SERGEY IVANOV	{"phone": "+70957243250"}
0005432069754	6C05DA	3707 774727	SERGEY ORLOV	{"phone": "+70056130150"}
0005432069755	288D78	9998 781972	NIKITA SHEVCHENKO	{"phone": "+70786170426"}
0005432069756	C7D930	7255 583231	SERGEY KUDRYASHOV	{"phone": "+70847869849"}
0005432069757	DE4C11	8836 670335	LYUBOV ZHUKOVA	{"phone": "+70294118649"}
0005432069758	2BD30B	1296 807970	VLADIMIR SIDOROV	{"email": "vladimir_sidorov-111961@postgrespro.ru", "phone": "+70805381879"}
0005432069759	213BD4	3661 666495	ELIZAVETA POPOVA	{"email": "e_popova121974@postgrespro.ru", "phone": "+70456568049"}
0005432069760	1A697C	8883 276081	NINA EFIMOVA	{"email": "efimova.nina.11021965@postgrespro.ru", "phone": "+70955859422"}
0005432069761	FAC2FA	8800 011820	TATYANA LEBEDEVA	{"phone": "+70993111764"}
0005432069762	21D9B0	8823 399719	ALINA GORBUNOVA	{"phone": "+70315489485"}
0005432069763	F55205	3127 672854	NIKOLAY IVANOV	{"phone": "+70503775041"}
0005432069764	F55205	0266 611187	TAMARA TITOVA	{"phone": "+70661601057"}
0005432069765	894939	7599 797244	ANNA LEBEDEVA	{"phone": "+70918291421"}
0005432069766	E45DCD	3233 811893	ILDAR KUZNECOV	{"email": "kuznecov.ildar-1965@postgrespro.ru", "phone": "+70495489478"}
0005432069767	4DC24E	4364 813555	TAMARA KOROLEVA	{"email": "koroleva_tamara-1963@postgrespro.ru", "phone": "+70327413512"}
0005432069768	4DC24E	2668 060514	SERGEY VOLKOV	{"email": "volkovs.1964@postgrespro.ru", "phone": "+70733252367"}
0005432069769	C82B1A	9978 411934	VIKTOR KONOVALOV	{"phone": "+70978174369"}
0005432069770	CFD0D5	1388 676321	MARINA DMITRIEVA	{"phone": "+70886383891"}
0005432069771	466E66	2648 942378	EGOR MELNIKOV	{"phone": "+70926121671"}
0005432069772	466E66	4264 570113	VALENTINA ALEKSEEVA	{"phone": "+70577323274"}
0005432069773	6E83CF	9782 251156	IRINA GERASIMOVA	{"phone": "+70788091895"}
0005432069774	B4FF95	9100 739632	SERGEY IVANOV	{"email": "sergeyivanov.1981@postgrespro.ru", "phone": "+70401305387"}
0005432069775	3F692B	9519 585227	ANNA KOLESNIKOVA	{"phone": "+70778383202"}
0005432069776	DF359B	4422 204590	OKSANA LOGINOVA	{"email": "loginova-oksana1970@postgrespro.ru", "phone": "+70072116726"}
0005432069777	DF359B	0800 264275	OLGA ARKHIPOVA	{"phone": "+70159651772"}
0005432069778	8478C6	8766 364815	RAISA NOVIKOVA	{"phone": "+70154004102"}
0005432069779	8478C6	1166 126020	MAKSIM STEPANOV	{"email": "mstepanov_071980@postgrespro.ru", "phone": "+70975413434"}
0005432069780	82E2A1	3350 562009	VLADIMIR MAKSIMOV	{"email": "vladimirmaksimov_1981@postgrespro.ru", "phone": "+70220322012"}
0005432069781	CD6FDF	2341 434067	ZINAIDA ZOTOVA	{"email": "zotova.z041973@postgrespro.ru", "phone": "+70652822832"}
0005432069782	CD6FDF	4632 227642	ANASTASIYA EGOROVA	{"email": "egorova.a20041966@postgrespro.ru", "phone": "+70391226946"}
0005432069783	640B35	3541 263572	VLADISLAV KISELEV	{"phone": "+70180736786"}
0005432069784	2B1691	2238 167724	SERGEY FEDOROV	{"email": "sergey-fedorov17021974@postgrespro.ru", "phone": "+70737158185"}
0005432069785	2B1691	2466 312019	OLGA MALYSHEVA	{"email": "malyshevaolga.1978@postgrespro.ru", "phone": "+70106157811"}
0005432069786	0838B0	7123 629192	ALEKSEY ALEKSEEV	{"phone": "+70509571725"}
0005432069787	0838B0	6883 568084	NATALYA EGOROVA	{"phone": "+70499183787"}
0005432069788	5B9C4D	2839 105201	TATYANA BOGDANOVA	{"email": "bogdanovat_011976@postgrespro.ru", "phone": "+70299180977"}
0005432069789	B4B010	5398 234523	ALEKSEY SOLOVEV	{"phone": "+70315130923"}
0005432069790	289AD7	5852 781650	ALEKSANDR MIKHAYLOV	{"phone": "+70610576041"}
0005432069791	289AD7	0574 473398	ANTONINA FADEEVA	{"phone": "+70114353736"}
0005432069792	37C019	6969 375133	VYACHESLAV MIKHAYLOV	{"email": "v_mikhaylov-051971@postgrespro.ru", "phone": "+70125095643"}
0005432069793	37C019	6057 700851	NINA MIRONOVA	{"email": "mironovanina.011973@postgrespro.ru", "phone": "+70265563049"}
0005432069794	37C019	7980 328022	VALERIYA VLASOVA	{"email": "vlasova_valeriya.081974@postgrespro.ru", "phone": "+70632360478"}
0005432069795	51BDE7	8766 758376	VLADISLAV KULIKOV	{"email": "vladislav.kulikov.1964@postgrespro.ru", "phone": "+70154366841"}
0005432069796	769D21	7316 089574	NATALIYA ANTONOVA	{"email": "antonova.nataliya_1966@postgrespro.ru", "phone": "+70297894425"}
0005432069797	C4026A	0964 905569	ANATOLIY KONOVALOV	{"phone": "+70788762078"}
0005432069798	C4026A	5033 087224	ELENA KAZAKOVA	{"phone": "+70966338770"}
0005432069799	4F0B1D	1901 137273	VLADIMIR VASILEV	{"email": "v_vasilev_16041968@postgrespro.ru", "phone": "+70929368017"}
0005432069800	964CAD	2877 671639	VALENTINA KOLESNIKOVA	{"email": "kolesnikova_valentina_19041971@postgrespro.ru", "phone": "+70491411121"}
0005432069801	C6A34A	2958 913245	EVGENIY KAZAKOV	{"email": "e_kazakov041976@postgrespro.ru", "phone": "+70724762134"}
0005432069802	751D83	1573 053237	IVAN MARTYNOV	{"email": "martynovi1974@postgrespro.ru", "phone": "+70769197971"}
0005432069803	80E99C	5547 225663	SERGEY ALEKSANDROV	{"email": "aleksandrov_s_1971@postgrespro.ru", "phone": "+70925654885"}
0005432069804	47B1B2	8708 996382	ARTEM KUZNECOV	{"phone": "+70830019699"}
0005432069805	1314A9	6066 340686	ALEKSEY ALEKSANDROV	{"phone": "+70766565771"}
0005432069806	1314A9	4636 625922	OKSANA ANTONOVA	{"email": "oksana_antonova_041960@postgrespro.ru", "phone": "+70544081132"}
0005432069807	9ED4C4	4734 934874	ANDREY KOZLOV	{"email": "a_kozlov-1989@postgrespro.ru", "phone": "+70853661195"}
0005432069808	9ED4C4	7118 124975	ELENA BORISOVA	{"email": "borisova.elena.19021958@postgrespro.ru", "phone": "+70868462707"}
0005432069809	6AAC4B	6637 182932	SERGEY ANDREEV	{"email": "andreev-sergey1971@postgrespro.ru", "phone": "+70043535296"}
0005432069810	AC5370	6194 069039	DAMIR KOZLOV	{"email": "dkozlov_11051979@postgrespro.ru", "phone": "+70359052101"}
0005432069811	AC5370	6896 564464	IVAN SOROKIN	{"email": "i-sorokin_22011963@postgrespro.ru", "phone": "+70080760257"}
0005432069812	7F6951	8323 461098	ANATOLIY SEMENOV	{"phone": "+70430044972"}
0005432069813	7F6951	3537 284649	DENIS PETROV	{"phone": "+70559384544"}
0005432069814	EE8DE2	6070 421342	LYUDMILA POPOVA	{"phone": "+70708992261"}
0005432069815	D530F8	4226 656883	GALINA KAZAKOVA	{"phone": "+70820467104"}
0005432069816	185A08	2912 870724	BORIS KAZAKOV	{"email": "kazakov-boris.1975@postgrespro.ru", "phone": "+70516543712"}
0005432069817	6C866C	2311 896827	OLGA LAZAREVA	{"email": "olga-lazareva.021976@postgrespro.ru", "phone": "+70839317186"}
0005432069818	6C866C	2106 119930	VALENTINA SIDOROVA	{"email": "valentina_sidorova_11111974@postgrespro.ru", "phone": "+70822420164"}
0005432069819	6C866C	0378 009679	VLADIMIR SHEVCHENKO	{"email": "shevchenko_vladimir.26121976@postgrespro.ru", "phone": "+70460363774"}
0005432069820	6D6EA3	5620 785715	NATALYA MAKSIMOVA	{"email": "maksimovanatalya-041966@postgrespro.ru", "phone": "+70679839758"}
0005432069821	6D6EA3	6030 238948	NATALYA MELNIKOVA	{"email": "natalya.melnikova_09011965@postgrespro.ru", "phone": "+70202693182"}
0005432069822	0FAAC7	0210 753120	EMIL SOLOVEV	{"phone": "+70196927776"}
0005432069823	0FAAC7	9928 922818	VALENTINA ZHURAVLEVA	{"phone": "+70860192965"}
0005432069824	0FAAC7	3610 257670	ZINAIDA KOROLEVA	{"email": "zinaidakoroleva27091957@postgrespro.ru", "phone": "+70374515028"}
0005432069825	CDB7BC	2669 145675	SERGEY FOMIN	{"phone": "+70039747756"}
0005432069826	EFC01D	0551 658879	YURIY KUZNECOV	{"phone": "+70560507025"}
0005432069827	EFC01D	1378 925019	VLADIMIR GORBUNOV	{"email": "gorbunov_v.31101971@postgrespro.ru", "phone": "+70162757552"}
0005432069828	45ACA9	7549 972924	IVAN NIKOLAEV	{"email": "i.nikolaev_021966@postgrespro.ru", "phone": "+70239135328"}
0005432069829	9E9530	2141 657710	MARINA KUZNECOVA	{"email": "kuznecova.m_1968@postgrespro.ru", "phone": "+70514966455"}
0005432069830	9E9530	1710 327367	NIKITA KONOVALOV	{"phone": "+70574450120"}
0005432069831	62A244	9140 377446	RAFAEL NIKOLAEV	{"phone": "+70146997996"}
0005432069832	D7EACC	4961 442003	ALEKSANDR EGOROV	{"phone": "+70210974078"}
0005432069833	3AF3BC	1677 858945	ANDREY VASILEV	{"email": "vasilev_andrey.051968@postgrespro.ru", "phone": "+70447668974"}
0005432069834	3AF3BC	6859 067505	VLADIMIR MIKHAYLOV	{"phone": "+70570085065"}
0005432069835	F8C5FE	7686 726622	YURIY KUDRYASHOV	{"email": "kudryashovyuriy_071973@postgrespro.ru", "phone": "+70559102359"}
0005432069836	F8C5FE	3021 165905	SERGEY BORISOV	{"email": "sergey.borisov.10011973@postgrespro.ru", "phone": "+70391197265"}
0005432069837	135B73	3742 198537	GENNADIY STEPANOV	{"email": "stepanov-gennadiy.061968@postgrespro.ru", "phone": "+70429810650"}
0005432069838	73171A	3828 238754	NATALYA LEBEDEVA	{"email": "n.lebedeva_121963@postgrespro.ru", "phone": "+70321029520"}
0005432069839	E5F145	7672 421389	ALEKSANDRA CHERNOVA	{"email": "a.chernova1977@postgrespro.ru", "phone": "+70326397145"}
0005432069840	844A31	6462 031645	DANILA OSIPOV	{"email": "osipov.danila_041974@postgrespro.ru", "phone": "+70034680856"}
0005432069841	0A8420	8566 697324	TATYANA LEBEDEVA	{"phone": "+70933258529"}
0005432069842	0A8420	1976 815130	SERGEY BONDARENKO	{"email": "sergeybondarenko1980@postgrespro.ru", "phone": "+70886948878"}
0005432069843	1066B7	3415 070317	LYUBOV GUSEVA	{"phone": "+70709983423"}
0005432069844	ACED62	9429 814065	ANASTASIYA BORISOVA	{"phone": "+70061938155"}
0005432069845	9C2FB8	1145 247195	VIKTOR MAKAROV	{"email": "makarov-v30091973@postgrespro.ru", "phone": "+70367436328"}
0005432069846	9C2FB8	8760 211309	ALEKSANDR BELOV	{"phone": "+70512440695"}
0005432069847	0ACDFE	4728 329752	SOFYA LEBEDEVA	{"email": "lebedevasofya_1963@postgrespro.ru", "phone": "+70828056483"}
0005432069848	885B41	0844 629191	EVGENIY FOMIN	{"phone": "+70114824077"}
0005432069849	3521A0	5082 088204	IVAN KAZAKOV	{"email": "kazakov.ivan_091975@postgrespro.ru", "phone": "+70964913028"}
0005432069850	3521A0	6038 543245	ALEKSEY IVANOV	{"email": "a-ivanov-1982@postgrespro.ru", "phone": "+70863578521"}
0005432069851	2A74D7	4998 910223	VLADIMIR ANTONOV	{"phone": "+70322935944"}
0005432069852	C976E2	7189 726795	IRINA IVANOVA	{"phone": "+70745775649"}
0005432069853	20B556	9872 938612	ALEKSANDR BONDARENKO	{"phone": "+70653837421"}
0005432069854	20B556	4487 545162	ARTEM MEDVEDEV	{"email": "a_medvedev03121960@postgrespro.ru", "phone": "+70045690445"}
0005432069855	FFCEF2	4795 616507	EKATERINA NAUMOVA	{"phone": "+70625583546"}
0005432069856	421AF2	5750 748792	ANDREY GERASIMOV	{"email": "gerasimov-andrey-15111965@postgrespro.ru", "phone": "+70119867520"}
0005432069857	657122	7443 071822	ULYANA AFANASEVA	{"email": "afanaseva-ulyana-24081969@postgrespro.ru", "phone": "+70898149115"}
0005432069858	B1140E	5394 360970	OLEG NOVIKOV	{"phone": "+70784484977"}
0005432069859	BEF3AC	9146 623664	ANDREY ABRAMOV	{"email": "abramov_a.25061974@postgrespro.ru", "phone": "+70338384291"}
0005432069860	FFDB11	2162 181392	OLGA RODIONOVA	{"email": "olga-rodionova.1975@postgrespro.ru", "phone": "+70602591808"}
0005432069861	FFDB11	4764 604382	LARISA FEDOROVA	{"email": "larisafedorova-25031964@postgrespro.ru", "phone": "+70685604848"}
0005432069862	DA7478	1910 160250	ANDREY KUZNECOV	{"email": "kuznecov-andrey1967@postgrespro.ru", "phone": "+70941779054"}
0005432069863	DFA764	2096 738945	IVAN MIRONOV	{"email": "i.mironov07101981@postgrespro.ru", "phone": "+70037946853"}
0005432069864	DFA764	1252 736822	VLADIMIR MELNIKOV	{"phone": "+70670000423"}
0005432069865	FF6FE1	9205 486083	TATYANA MAKAROVA	{"phone": "+70693320232"}
0005432069866	FD0DD9	1703 975325	ALEKSEY MAKSIMOV	{"email": "maksimov_aleksey_1970@postgrespro.ru", "phone": "+70302956657"}
0005432069867	4E5F3E	5250 147555	SERGEY SOKOLOV	{"email": "sokolov-sergey1973@postgrespro.ru", "phone": "+70880193446"}
0005432069868	1F164D	9728 145075	IVAN SMIRNOV	{"phone": "+70977329271"}
0005432069869	E7633A	2240 657928	PAVEL MELNIKOV	{"email": "melnikov_pavel05101977@postgrespro.ru", "phone": "+70089717210"}
0005432069870	4F83CE	9693 531747	VALENTIN IVANOV	{"phone": "+70859654117"}
0005432069871	4F83CE	0323 353570	GALINA SERGEEVA	{"email": "g.sergeeva_12021976@postgrespro.ru", "phone": "+70836725805"}
0005432069872	4F1066	3381 857490	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy111966@postgrespro.ru", "phone": "+70323176413"}
0005432069873	0FFFE9	2271 432654	ALEKSANDR NOVIKOV	{"phone": "+70407532874"}
0005432069874	349BFD	3353 779518	NIKOLAY PAVLOV	{"phone": "+70092867222"}
0005432069875	0881A6	7254 426578	VERONIKA MAKSIMOVA	{"phone": "+70184711637"}
0005432069876	A225A4	0083 035233	ANTONINA CHERNOVA	{"email": "chernova.a_09111972@postgrespro.ru", "phone": "+70924422521"}
0005432069877	398BD8	5824 605824	SERGEY MELNIKOV	{"email": "s.melnikov-1972@postgrespro.ru", "phone": "+70135173378"}
0005432069878	398BD8	0625 976026	EKATERINA NOVIKOVA	{"email": "novikova_ekaterina-1969@postgrespro.ru", "phone": "+70964300801"}
0005432069879	B22FB3	3102 238914	NATALYA KOZLOVA	{"phone": "+70659257833"}
0005432069880	B22FB3	4080 930306	TATYANA TROFIMOVA	{"phone": "+70533013603"}
0005432069881	B22FB3	1720 295332	ALEKSEY KOZLOV	{"email": "a.kozlov-1971@postgrespro.ru", "phone": "+70787466800"}
0005432069882	EE8528	1351 386599	GALINA SOKOLOVA	{"phone": "+70086434711"}
0005432069883	EE8528	1155 921789	EGOR KUZNECOV	{"phone": "+70628679490"}
0005432069884	86B421	9346 728806	VALENTIN NOVIKOV	{"phone": "+70453130713"}
0005432069885	16EF8C	5263 085068	GENNADIY BELOV	{"phone": "+70892702777"}
0005432069886	16EF8C	4970 580117	IGOR FROLOV	{"email": "frolovigor1978@postgrespro.ru", "phone": "+70469537720"}
0005432069887	E623CA	6073 151109	NATALYA MEDVEDEVA	{"phone": "+70643465403"}
0005432069888	ACEBBA	6394 706799	ANDREY VLASOV	{"phone": "+70180843561"}
0005432069889	ACEBBA	5476 525355	VALENTINA SMIRNOVA	{"phone": "+70241549777"}
0005432069890	3EAAAB	4798 696122	NIKOLAY VLASOV	{"email": "n-vlasov_061971@postgrespro.ru", "phone": "+70083143815"}
0005432069891	A0309F	9445 220338	TAMARA VOLKOVA	{"phone": "+70855516586"}
0005432069892	3434AA	3486 533691	OKSANA IVANOVA	{"email": "o-ivanova.22071956@postgrespro.ru", "phone": "+70726970161"}
0005432069893	3434AA	9537 885005	IRINA MAKAROVA	{"email": "imakarova-1975@postgrespro.ru", "phone": "+70443045591"}
0005432069894	462204	3081 756958	ELENA ALEKSEEVA	{"phone": "+70406555600"}
0005432069895	1AEF98	2074 213215	MAKSIM GERASIMOV	{"phone": "+70135096935"}
0005432069896	CF424A	4470 240141	MATVEY KOZLOV	{"email": "kozlov.matvey.051975@postgrespro.ru", "phone": "+70272020999"}
0005432069897	E8F4E0	7717 266494	IVAN ANTONOV	{"phone": "+70062442330"}
0005432069898	E8F4E0	6174 782749	MIKHAIL SERGEEV	{"email": "m-sergeev.061977@postgrespro.ru", "phone": "+70249273800"}
0005432069899	63C98B	9273 358767	SERGEY MAKAROV	{"email": "makarov.s_1978@postgrespro.ru", "phone": "+70112251466"}
0005432069900	1CF50D	8404 087126	MAKSIM STEPANOV	{"email": "stepanovmaksim_07031979@postgrespro.ru", "phone": "+70244092041"}
0005432069901	1CF50D	2856 858149	ANDREY KUZNECOV	{"phone": "+70864998887"}
0005432069902	39C84C	2503 173331	DMITRIY POPOV	{"phone": "+70524521168"}
0005432069903	39C84C	8356 349997	VALERIY MOROZOV	{"email": "morozovv1980@postgrespro.ru", "phone": "+70520480400"}
0005432069904	268C20	2192 709173	EVGENIY PETROV	{"phone": "+70848867631"}
0005432069905	F1E44E	4214 422431	VALERIY OSIPOV	{"email": "osipov-v.021970@postgrespro.ru", "phone": "+70630329093"}
0005432069906	F1E44E	0457 839175	LYUDMILA NESTEROVA	{"phone": "+70133746861"}
0005432069907	1B052A	6407 032319	ALEKSANDRA ZHUKOVA	{"email": "zhukova_aleksandra.1977@postgrespro.ru", "phone": "+70622085316"}
0005432069908	1B052A	2853 338921	VIKTOR NIKOLAEV	{"phone": "+70158044977"}
0005432069909	5EEC38	4540 848957	ANDREY KRASNOV	{"email": "andrey_krasnov_28121976@postgrespro.ru", "phone": "+70453466485"}
0005432069910	2F58ED	6446 083548	ALEKSANDR ZHUKOV	{"phone": "+70541560634"}
0005432069911	2F58ED	9607 194256	IRINA CHERNOVA	{"email": "i_chernova1975@postgrespro.ru", "phone": "+70413321650"}
0005432069912	B65438	8439 441135	NIKOLAY PAVLOV	{"email": "pavlovnikolay-1974@postgrespro.ru", "phone": "+70483551132"}
0005432069913	5089D4	2133 885862	SERGEY MARTYNOV	{"phone": "+70998390941"}
0005432069914	5089D4	9317 266048	IRINA BELYAEVA	{"phone": "+70820204208"}
0005432069915	38379E	6149 489788	VIKTOR KULIKOV	{"phone": "+70884817749"}
0005432069916	062E89	5885 147591	MARINA FROLOVA	{"phone": "+70024418628"}
0005432069917	062E89	3910 128967	NIKOLAY ZHURAVLEV	{"email": "zhuravlevn-09021968@postgrespro.ru", "phone": "+70815750110"}
0005432069918	DABCB9	3918 501180	MARIYA MASLOVA	{"phone": "+70777192827"}
0005432069919	DABCB9	3464 813527	VALENTIN MOISEEV	{"email": "moiseevv-14121958@postgrespro.ru", "phone": "+70016650215"}
0005432069920	597098	0188 700275	VYACHESLAV NAZAROV	{"email": "vyacheslavnazarov1970@postgrespro.ru", "phone": "+70437439290"}
0005432069921	3EDC62	0784 462877	IRINA KAZAKOVA	{"email": "kazakovairina1973@postgrespro.ru", "phone": "+70116965016"}
0005432069922	6CE1F0	6671 769774	LYUDMILA POPOVA	{"phone": "+70759763141"}
0005432069923	6CE1F0	5038 035792	ALINA EGOROVA	{"phone": "+70622061611"}
0005432069924	6CE1F0	7712 516858	ALEKSEY SOROKIN	{"email": "sorokin_aleksey-1981@postgrespro.ru", "phone": "+70718488284"}
0005432069925	B70F9F	0118 502354	TATYANA IVANOVA	{"phone": "+70180993896"}
0005432069926	685410	2747 549654	MARINA GRISHINA	{"phone": "+70765423361"}
0005432069927	2550B2	6015 136971	LYUDMILA KOZLOVA	{"phone": "+70849364391"}
0005432069928	2550B2	4470 213918	EKATERINA SAVELEVA	{"phone": "+70206874688"}
0005432069929	F29AB8	9364 749723	LILIYA GUSEVA	{"email": "liliya.guseva-09011970@postgrespro.ru", "phone": "+70478883884"}
0005432069930	F29AB8	6778 487070	ALLA ISAEVA	{"email": "isaeva.a10051984@postgrespro.ru", "phone": "+70252630258"}
0005432069931	0E5A44	1829 605739	LYUBOV KRASNOVA	{"phone": "+70162857655"}
0005432069932	0E5A44	9025 176364	VLADIMIR PAVLOV	{"email": "vladimir-pavlov-05071979@postgrespro.ru", "phone": "+70907902382"}
0005432069933	FF6742	4321 421426	EKATERINA FADEEVA	{"phone": "+70987868513"}
0005432069934	969E7F	8608 884373	ELENA KUZNECOVA	{"email": "kuznecova-e_14051972@postgrespro.ru", "phone": "+70096807406"}
0005432069935	969E7F	6312 903288	YAROSLAV ZHURAVLEV	{"phone": "+70820970168"}
0005432069936	223470	2461 423981	VALERIY SCHERBAKOV	{"email": "valeriy-scherbakov.081975@postgrespro.ru", "phone": "+70119329581"}
0005432069937	C2BD4C	7654 496278	OLGA IVANOVA	{"phone": "+70805005978"}
0005432069938	A9EA16	5554 256550	VIKTOR AFANASEV	{"phone": "+70749385668"}
0005432069939	A9EA16	3096 537986	OLGA KOZLOVA	{"email": "kozlova-olga.1967@postgrespro.ru", "phone": "+70050593605"}
0005432069940	ACE257	6639 161215	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov_021970@postgrespro.ru", "phone": "+70498761225"}
0005432069941	ACE257	9623 636500	ALEKSANDR POPOV	{"phone": "+70329412868"}
0005432069942	E3A537	2469 444695	LIDIYA GUSEVA	{"email": "lidiya.guseva101975@postgrespro.ru", "phone": "+70515359588"}
0005432069943	F5F11D	6294 716507	KLAVDIYA ZAYCEVA	{"phone": "+70187771026"}
0005432069944	E29C37	0284 176084	VIKTOR SMIRNOV	{"email": "v.smirnov111977@postgrespro.ru", "phone": "+70085818642"}
0005432069945	B7414E	6655 193805	LYUBOV NAZAROVA	{"phone": "+70181498144"}
0005432069946	B7414E	1348 334273	ELENA BELYAEVA	{"email": "belyaeva-elena-121953@postgrespro.ru", "phone": "+70724087968"}
0005432069947	1BA8FE	1234 728600	IVAN SEMENOV	{"email": "semenov_i-14121977@postgrespro.ru", "phone": "+70205053161"}
0005432069948	5CA18F	6710 829844	OLEG FILIPPOV	{"phone": "+70924808647"}
0005432069949	C0ADF1	5110 345909	SVETLANA BORISOVA	{"email": "borisova-svetlana_07061967@postgrespro.ru", "phone": "+70409827832"}
0005432069950	ABE77F	8422 832237	YURIY GRIGOREV	{"email": "grigorevy011982@postgrespro.ru", "phone": "+70317349437"}
0005432069951	41FEDF	7486 028751	DMITRIY OSIPOV	{"email": "d_osipov-07031966@postgrespro.ru", "phone": "+70611117590"}
0005432069952	8339C2	3996 841731	SVETLANA MELNIKOVA	{"phone": "+70765459497"}
0005432069953	8339C2	2570 154521	VLADIMIR KONOVALOV	{"email": "konovalovvladimir081963@postgrespro.ru", "phone": "+70516501534"}
0005432069954	824A4E	5397 317308	EVGENIY GORBUNOV	{"phone": "+70290233339"}
0005432069955	F5ACF1	3233 573052	EKATERINA POPOVA	{"phone": "+70996649837"}
0005432069956	774542	0194 675074	OLGA RODIONOVA	{"email": "orodionova.08011964@postgrespro.ru", "phone": "+70315011950"}
0005432069957	C93621	0585 174040	VALENTINA SIDOROVA	{"phone": "+70250035143"}
0005432069958	C93621	5092 424219	IRINA LAZAREVA	{"email": "irina_lazareva11081966@postgrespro.ru", "phone": "+70929126325"}
0005432069959	D6DF4C	6096 331866	VYACHESLAV KAZAKOV	{"phone": "+70328529770"}
0005432069960	F21022	5741 966901	PAVEL POPOV	{"phone": "+70773627716"}
0005432069961	F21022	2744 995699	IVAN BORISOV	{"email": "borisov.ivan.21081971@postgrespro.ru", "phone": "+70041721080"}
0005432069962	11619A	4599 553173	GALINA FILATOVA	{"phone": "+70914208448"}
0005432069963	112C59	7663 060522	TATYANA VLASOVA	{"phone": "+70354288324"}
0005432069964	076E3C	9524 184551	SVETLANA ANISIMOVA	{"phone": "+70515698079"}
0005432069965	076E3C	5837 972012	ALEKSANDR TIMOFEEV	{"phone": "+70274176796"}
0005432069966	C7B548	4477 004059	ILYA TARASOV	{"phone": "+70159637295"}
0005432069967	C7B548	7208 697702	IRINA BELOVA	{"email": "i-belova29111972@postgrespro.ru", "phone": "+70666049061"}
0005432069968	3158D4	0609 417187	MIKHAIL FEDOTOV	{"email": "m_fedotov091983@postgrespro.ru", "phone": "+70683448860"}
0005432069969	D95A17	7055 858669	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov-11101959@postgrespro.ru", "phone": "+70136495739"}
0005432069970	973C46	8765 711266	VASILIY ZAYCEV	{"phone": "+70659561731"}
0005432069971	973C46	5036 126040	ALEKSANDR SCHERBAKOV	{"phone": "+70528212678"}
0005432069972	C6AE49	9141 682246	LIDIYA FILATOVA	{"phone": "+70807261832"}
0005432069973	C6AE49	2673 468232	OLESYA MATVEEVA	{"email": "omatveeva_031969@postgrespro.ru", "phone": "+70597642134"}
0005432069974	DFB139	5021 901465	ILYA VOROBEV	{"email": "i-vorobev04031966@postgrespro.ru", "phone": "+70447982508"}
0005432069975	82E41C	9047 013248	OLGA LUKYANOVA	{"email": "lukyanova.olga_28061976@postgrespro.ru", "phone": "+70744518798"}
0005432069976	82E41C	6978 094386	DARYA PETROVA	{"email": "d-petrova_1974@postgrespro.ru", "phone": "+70596946551"}
0005432069977	82E41C	7524 329824	KLAVDIYA GERASIMOVA	{"email": "klavdiya_gerasimova091976@postgrespro.ru", "phone": "+70428742498"}
0005432069978	A54FFF	0455 028488	KRISTINA KOROLEVA	{"email": "koroleva-k121978@postgrespro.ru", "phone": "+70337294031"}
0005432069979	1E1310	6418 967708	DANILA SEMENOV	{"email": "semenov.danila-121979@postgrespro.ru", "phone": "+70215100701"}
0005432069980	B44054	7206 615021	SVETLANA IVANOVA	{"phone": "+70560368883"}
0005432069981	D243E3	8413 288956	DANILA GERASIMOV	{"email": "gerasimov-danila-011974@postgrespro.ru", "phone": "+70378878373"}
0005432069982	02707D	7051 450762	OLGA PAVLOVA	{"phone": "+70231481760"}
0005432069983	741373	8919 856484	IVAN FROLOV	{"email": "ivan-frolov091976@postgrespro.ru", "phone": "+70959614431"}
0005432069984	741373	8401 736213	ANDREY NIKITIN	{"email": "nikitin-andrey.22011967@postgrespro.ru", "phone": "+70584265503"}
0005432069985	39243D	9324 525934	VIKTORIYA ZAKHAROVA	{"phone": "+70292552627"}
0005432069986	80FAF8	5653 208718	ANASTASIYA MALYSHEVA	{"email": "anastasiya_malysheva-1975@postgrespro.ru", "phone": "+70492075343"}
0005432069987	0DED02	5621 044451	ELIZAVETA ALEKSEEVA	{"phone": "+70604145168"}
0005432069988	870A14	9112 169318	OLEG MAKAROV	{"email": "makarovo_15021972@postgrespro.ru", "phone": "+70062009515"}
0005432069989	AEB86D	0373 324935	SERGEY ANDREEV	{"email": "andreevsergey-31121962@postgrespro.ru", "phone": "+70201545734"}
0005432069990	394B5C	1495 091624	OKSANA KUZNECOVA	{"phone": "+70183040734"}
0005432069991	394B5C	3376 676110	MARIYA NOVIKOVA	{"email": "mariya.novikova20061970@postgrespro.ru", "phone": "+70001873929"}
0005432069992	8BE275	6032 117267	ANDREY YAKOVLEV	{"email": "a_yakovlev.011979@postgrespro.ru", "phone": "+70815399912"}
0005432069993	CB1914	7935 288195	GENNADIY VOLKOV	{"email": "volkov_g.04031970@postgrespro.ru", "phone": "+70412241230"}
0005432069994	4B2CB9	7691 757516	NIKOLAY GRIGOREV	{"email": "grigorev.n1987@postgrespro.ru", "phone": "+70154667870"}
0005432069995	89F673	3947 121504	DMITRIY ISAEV	{"phone": "+70320470953"}
0005432069996	39E8C8	3227 180801	DMITRIY KUZMIN	{"phone": "+70447090807"}
0005432069997	C5486E	5449 588230	IGOR ORLOV	{"email": "orlov.igor111976@postgrespro.ru", "phone": "+70417798101"}
0005432069998	D50710	8416 334339	VIKTORIYA NIKOLAEVA	{"email": "vnikolaeva_1987@postgrespro.ru", "phone": "+70509775645"}
0005432069999	C83782	5020 937139	ANNA FROLOVA	{"email": "frolova.a.1972@postgrespro.ru", "phone": "+70399250461"}
0005432070000	79773A	8208 428856	VYACHESLAV VASILEV	{"email": "vvasilev29041964@postgrespro.ru", "phone": "+70588110002"}
0005432070001	79773A	8692 430084	EVGENIYA KUZNECOVA	{"email": "kuznecova-evgeniya-1974@postgrespro.ru", "phone": "+70925851201"}
0005432070002	802B20	6283 758235	RIMMA NIKOLAEVA	{"email": "rimma.nikolaeva101972@postgrespro.ru", "phone": "+70936503539"}
0005432070003	589021	5685 026370	VALERIY FOMIN	{"phone": "+70408964132"}
0005432070004	589021	9147 270235	YURIY GORBUNOV	{"phone": "+70511286572"}
0005432070005	5A1E8F	7723 126968	YULIYA KULIKOVA	{"phone": "+70089871891"}
0005432070006	BE5DD0	5298 167067	TAMARA ANTONOVA	{"email": "t.antonova.1975@postgrespro.ru", "phone": "+70048437947"}
0005432070007	0DDFED	5477 226607	ANASTASIYA GRISHINA	{"email": "anastasiya.grishina29071983@postgrespro.ru", "phone": "+70826395201"}
0005432070008	1F6BC2	6754 005079	NINA TARASOVA	{"phone": "+70209818088"}
0005432070009	7BE9C2	9042 450485	NIKOLAY SOROKIN	{"email": "nikolay_sorokin.1979@postgrespro.ru", "phone": "+70290416348"}
0005432070010	A48837	5138 814363	ROMAN SCHERBAKOV	{"email": "roman_scherbakov.16101982@postgrespro.ru", "phone": "+70305454851"}
0005432070011	132983	7811 477100	OLGA MOROZOVA	{"phone": "+70571491952"}
0005432070012	132983	3995 975618	VLADIMIR GORBUNOV	{"phone": "+70138390846"}
0005432070013	8F33C6	5857 076991	ALEKSANDR ORLOV	{"phone": "+70314710479"}
0005432070014	E4C10F	1113 544962	ANASTASIYA KUZNECOVA	{"phone": "+70769715276"}
0005432070015	E4C10F	7787 155127	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya22041969@postgrespro.ru", "phone": "+70754401679"}
0005432070016	68AA24	8699 046153	YULIYA ANDREEVA	{"email": "y.andreeva021975@postgrespro.ru", "phone": "+70027123577"}
0005432070017	9809AA	0682 528096	ANATOLIY ABRAMOV	{"phone": "+70918194164"}
0005432070018	9809AA	2049 401741	LILIYA NESTEROVA	{"email": "liliya_nesterova_051977@postgrespro.ru", "phone": "+70688843642"}
0005432070019	53F5D7	4548 883837	EVGENIYA IVANOVA	{"email": "e-ivanova061974@postgrespro.ru", "phone": "+70121477817"}
0005432070020	53F5D7	2318 831400	RAISA SAVELEVA	{"phone": "+70628872516"}
0005432070021	1CAEB4	6513 434447	LYUDMILA NAZAROVA	{"email": "nazarova-lyudmila-24051974@postgrespro.ru", "phone": "+70285249153"}
0005432070022	C4E598	7239 329459	SVETLANA AKIMOVA	{"email": "akimova-s1959@postgrespro.ru", "phone": "+70440676600"}
0005432070023	C4E598	8656 992774	ALEKSANDR TIKHONOV	{"email": "atikhonov.14111974@postgrespro.ru", "phone": "+70342471114"}
0005432070024	2F1C4F	8300 333923	VASILIY SEMENOV	{"email": "semenov-vasiliy-121976@postgrespro.ru", "phone": "+70607106551"}
0005432070025	2F1C4F	2305 162297	IRINA SOLOVEVA	{"email": "isoloveva01031967@postgrespro.ru", "phone": "+70485148116"}
0005432070026	F2320F	0734 873039	SVETLANA MOROZOVA	{"email": "morozova_svetlana-1972@postgrespro.ru", "phone": "+70835429313"}
0005432070027	2DEC3D	9621 975099	ANDREY NAZAROV	{"email": "andrey-nazarov1964@postgrespro.ru", "phone": "+70740750502"}
0005432070028	148DC7	4372 293167	ALIYA MAKAROVA	{"phone": "+70218760806"}
0005432070029	297842	5439 397961	RAISA SMIRNOVA	{"email": "smirnova-raisa1968@postgrespro.ru", "phone": "+70895578672"}
0005432070030	297842	4956 582501	NIKITA NAZAROV	{"phone": "+70686820374"}
0005432070031	297842	3266 196482	LILIYA KOVALEVA	{"email": "liliya_kovaleva16061969@postgrespro.ru", "phone": "+70454016115"}
0005432070032	9D39BB	2601 467880	ALEKSANDR ANDREEV	{"phone": "+70968021095"}
0005432070033	10D8A0	7009 887751	ANDREY ROMANOV	{"phone": "+70757826708"}
0005432070034	25FD66	1355 902036	ANASTASIYA ANISIMOVA	{"email": "anastasiya_anisimova_06101976@postgrespro.ru", "phone": "+70170861039"}
0005432070035	25FD66	3089 910832	IRINA ANISIMOVA	{"email": "i_anisimova081977@postgrespro.ru", "phone": "+70173623383"}
0005432070036	118C07	4685 093391	OLGA MELNIKOVA	{"email": "melnikova_o121970@postgrespro.ru", "phone": "+70170056329"}
0005432070037	A47E99	7034 624764	ZLATA KOZLOVA	{"phone": "+70673304550"}
0005432070038	149709	7199 589937	ALEKSANDR ILIN	{"email": "ilina071975@postgrespro.ru", "phone": "+70507007570"}
0005432070039	404160	0352 769329	VIKTOR ANTONOV	{"phone": "+70454353577"}
0005432070040	404160	4262 816262	EVGENIY KARPOV	{"phone": "+70009039212"}
0005432070041	CA6D6A	6721 681552	YURIY POPOV	{"email": "popov.yuriy_1979@postgrespro.ru", "phone": "+70107564857"}
0005432070042	CA6D6A	0208 857123	VLADIMIR ROMANOV	{"email": "romanov-v_1972@postgrespro.ru", "phone": "+70066005138"}
0005432070043	3B8135	1084 853042	VIKTOR ROMANOV	{"phone": "+70180039934"}
0005432070044	CD52CE	7133 436819	ALEKSANDRA MIKHAYLOVA	{"email": "aleksandra_mikhaylova-06121978@postgrespro.ru", "phone": "+70838432997"}
0005432070045	CD52CE	0197 385350	VALENTINA POTAPOVA	{"email": "v-potapova-08101974@postgrespro.ru", "phone": "+70874716222"}
0005432070046	CD52CE	2756 815781	LYUBOV KRASNOVA	{"phone": "+70101944336"}
0005432070047	99F87D	9351 277974	ALLA NIKOLAEVA	{"phone": "+70805632618"}
0005432070048	47AB29	1155 702690	YAROSLAV ALEKSEEV	{"email": "yaroslav-alekseev051957@postgrespro.ru", "phone": "+70736664949"}
0005432070049	D3028B	3073 380866	ARTEM KUZNECOV	{"phone": "+70183872452"}
0005432070050	D3028B	6181 113530	RIMMA DMITRIEVA	{"email": "dmitrieva_rimma.17061969@postgrespro.ru", "phone": "+70341112533"}
0005432070051	6AA133	9260 452914	VLADIMIR ZAKHAROV	{"phone": "+70907303052"}
0005432070052	126522	3454 663150	OLGA MEDVEDEVA	{"phone": "+70198898989"}
0005432070053	126522	7137 745410	GALINA MAKSIMOVA	{"phone": "+70194815577"}
0005432070054	8D5340	6495 167276	LYUBOV LAZAREVA	{"email": "lyubov-lazareva_1967@postgrespro.ru", "phone": "+70182784901"}
0005432070055	307269	4424 847292	ELENA GRISHINA	{"email": "grishina.elena.11111967@postgrespro.ru", "phone": "+70503648443"}
0005432070056	04002B	9990 884115	TAMARA EGOROVA	{"phone": "+70759267704"}
0005432070057	9DF85D	6350 167499	ALEKSANDR ANDREEV	{"phone": "+70001773427"}
0005432070058	1F6581	6659 215651	LYUDMILA DAVYDOVA	{"email": "lyudmila-davydova_25091967@postgrespro.ru", "phone": "+70083546419"}
0005432070059	8D2A05	5796 229360	OLGA STEPANOVA	{"email": "stepanovaolga.031967@postgrespro.ru", "phone": "+70503577128"}
0005432070060	8D2A05	8827 013628	DMITRIY ZAYCEV	{"phone": "+70347217933"}
0005432070061	6A8E90	6006 425236	GERMAN BELOV	{"email": "belov.g.09101972@postgrespro.ru", "phone": "+70086698951"}
0005432070062	6A8E90	0036 750449	NATALYA LOGINOVA	{"phone": "+70889140927"}
0005432070063	C625A3	4335 840063	ANASTASIYA POTAPOVA	{"email": "potapova-anastasiya061973@postgrespro.ru", "phone": "+70207324323"}
0005432070064	D4851F	2252 458540	OLGA NOVIKOVA	{"phone": "+70430704236"}
0005432070065	5C29DF	1927 574466	VASILIY ORLOV	{"email": "orlov_v_23011965@postgrespro.ru", "phone": "+70308034168"}
0005432070066	BFD41D	8963 181152	KONSTANTIN ZHURAVLEV	{"email": "k.zhuravlev12011977@postgrespro.ru", "phone": "+70900984292"}
0005432070067	F34E08	0824 708407	MARIYA MEDVEDEVA	{"phone": "+70519032123"}
0005432070068	49D89F	3846 429408	DARYA SMIRNOVA	{"phone": "+70889637712"}
0005432070069	49D89F	1299 134325	ANASTASIYA TARASOVA	{"email": "a_tarasova16111975@postgrespro.ru", "phone": "+70139242233"}
0005432070070	49D89F	8647 213910	VIOLETTA PAVLOVA	{"phone": "+70953323007"}
0005432070071	144C89	8545 864881	KUZMA ZAYCEV	{"phone": "+70655145201"}
0005432070072	02D432	1108 183069	VIKTOR VLASOV	{"phone": "+70517028124"}
0005432070073	52ACAD	4970 190365	ZINAIDA KOLESNIKOVA	{"email": "zkolesnikova031970@postgrespro.ru", "phone": "+70321165479"}
0005432070074	52ACAD	1488 095228	NATALYA NAUMOVA	{"email": "natalyanaumova_021978@postgrespro.ru", "phone": "+70241697983"}
0005432070075	52ACAD	3581 585261	VLADISLAV VOROBEV	{"email": "vladislav-vorobev-041979@postgrespro.ru", "phone": "+70084987175"}
0005432070076	D8ADC5	0362 871245	DMITRIY MAKAROV	{"phone": "+70728696430"}
0005432070077	FC5E73	9431 871956	MAKSIM SEMENOV	{"phone": "+70632866980"}
0005432070078	FC5E73	0324 916868	VADIM POPOV	{"email": "vadimpopov.1968@postgrespro.ru", "phone": "+70626263079"}
0005432070079	E684E2	3222 540974	ARTEM IVANOV	{"phone": "+70777910166"}
0005432070080	C8F225	0569 442174	TATYANA POPOVA	{"email": "t_popova051976@postgrespro.ru", "phone": "+70529440110"}
0005432070081	C8F225	9717 229681	ILYA MIKHAYLOV	{"phone": "+70522764140"}
0005432070082	8FB9E0	0257 022592	DARYA DENISOVA	{"phone": "+70728619230"}
0005432071520	4AE628	9543 246302	NIKOLAY KUZMIN	{"email": "kuzmin.nikolay-111977@postgrespro.ru", "phone": "+70831176073"}
0005432071521	EECC28	9391 940431	YURIY SOKOLOV	{"phone": "+70944392183"}
0005432071522	BD182B	6556 465487	ANASTASIYA BORISOVA	{"email": "anastasiya_borisova-1987@postgrespro.ru", "phone": "+70215321195"}
0005432071523	C063F8	8891 013146	NATALIYA KUZNECOVA	{"phone": "+70576460860"}
0005432071524	57FA09	9848 785672	ALEKSANDR IVANOV	{"phone": "+70396898069"}
0005432071525	84C52E	8245 490524	OLEG MELNIKOV	{"email": "o.melnikov.1975@postgrespro.ru", "phone": "+70268593592"}
0005432071526	CF741E	2841 807752	VALENTIN ABRAMOV	{"phone": "+70289370452"}
0005432071527	D9AB16	9957 300160	ARTEM IVANOV	{"phone": "+70669343939"}
0005432071528	D9AB16	9472 368418	VERA MASLOVA	{"email": "maslova_v.01111971@postgrespro.ru", "phone": "+70098632354"}
0005432071529	A6869B	9872 060350	MAKSIM KOZLOV	{"email": "maksim-kozlov_1976@postgrespro.ru", "phone": "+70506113812"}
0005432071530	A6869B	6729 136911	NIKOLAY KRASNOV	{"email": "krasnovn-1975@postgrespro.ru", "phone": "+70595919739"}
0005432071531	E8A4B9	1467 816788	IRAIDA FADEEVA	{"email": "iraida-fadeeva16031972@postgrespro.ru", "phone": "+70950255744"}
0005432071532	0537C4	8787 310044	EVGENIYA MOROZOVA	{"email": "emorozova_1970@postgrespro.ru", "phone": "+70728643733"}
0005432071533	086FE6	9302 916214	VLADIMIR ZHUKOV	{"email": "vladimir-zhukov.021982@postgrespro.ru", "phone": "+70918967884"}
0005432071534	7EBDF0	1645 079759	TAMARA GERASIMOVA	{"email": "tamara_gerasimova_25011965@postgrespro.ru", "phone": "+70209968241"}
0005432071535	2CCD81	6774 902559	DMITRIY KOZLOV	{"phone": "+70975471785"}
0005432071536	2CCD81	7742 127586	MARGARITA STEPANOVA	{"phone": "+70662545848"}
0005432071537	CA577F	3007 733223	ARTEM OSIPOV	{"email": "aosipov_1971@postgrespro.ru", "phone": "+70835277309"}
0005432071538	1EC77E	9361 846190	VADIM ZAKHAROV	{"email": "v_zakharov_1969@postgrespro.ru", "phone": "+70184832381"}
0005432071539	3BCE96	8158 356319	SAVELIY BARANOV	{"phone": "+70463169194"}
0005432071540	3BE386	3710 754487	ANASTASIYA IVANOVA	{"email": "anastasiyaivanova18121967@postgrespro.ru", "phone": "+70010750197"}
0005432071541	A046B8	2962 030651	VALERIYA YUDINA	{"email": "valeriyayudina-1981@postgrespro.ru", "phone": "+70097229278"}
0005432071542	F9BD55	9788 488861	LYUDMILA PETROVA	{"email": "petroval.1968@postgrespro.ru", "phone": "+70115763055"}
0005432071543	F9BD55	5383 494561	NINA NIKOLAEVA	{"email": "nikolaeva.nina1975@postgrespro.ru", "phone": "+70195460089"}
0005432071544	837FD7	8452 442509	RAMIL ABRAMOV	{"email": "ramil-abramov.011975@postgrespro.ru", "phone": "+70461656161"}
0005432071545	837FD7	4847 540991	LIDIYA KUZNECOVA	{"phone": "+70005159140"}
0005432071546	23BE35	0956 130831	TATYANA YUDINA	{"email": "yudina-tatyana_1974@postgrespro.ru", "phone": "+70865119261"}
0005432071547	23BE35	7172 259119	INNA KUZMINA	{"phone": "+70740222632"}
0005432071548	2CC049	1056 746572	FEDOR MEDVEDEV	{"email": "f.medvedev.1966@postgrespro.ru", "phone": "+70692287446"}
0005432071549	BD585B	5792 703567	LYUBOV RYABOVA	{"phone": "+70279437365"}
0005432071550	20C773	3461 129009	ANDREY ABRAMOV	{"phone": "+70971248934"}
0005432071551	6238CA	4454 515939	NIKOLAY VASILEV	{"email": "nvasilev-021966@postgrespro.ru", "phone": "+70418870592"}
0005432071552	A1D2D3	3928 669429	ANATOLIY TARASOV	{"phone": "+70964548112"}
0005432071553	6C78AE	2489 860893	ALEKSANDR ROMANOV	{"phone": "+70005299707"}
0005432071554	6C78AE	0327 359215	ALEKSANDR BORISOV	{"email": "borisov.a1959@postgrespro.ru", "phone": "+70278067536"}
0005432071555	22FE6F	0002 387713	DMITRIY SOLOVEV	{"email": "solovevdmitriy_1956@postgrespro.ru", "phone": "+70803753275"}
0005432071556	1B3E55	7312 680823	IGOR KUZNECOV	{"phone": "+70645856521"}
0005432071557	1B3E55	8996 956355	OLGA ORLOVA	{"email": "orlova-o-07121967@postgrespro.ru", "phone": "+70916153252"}
0005432071558	E32C98	7691 814817	GENNADIY BELOV	{"email": "belov_gennadiy_011978@postgrespro.ru", "phone": "+70892098873"}
0005432071559	E32C98	4200 140518	NIKOLAY PAVLOV	{"phone": "+70245852484"}
0005432071560	078F60	9782 944504	IRINA OVCHINNIKOVA	{"email": "ovchinnikova_irina-111959@postgrespro.ru", "phone": "+70980912034"}
0005432071561	4447CB	8420 739049	ELENA PAVLOVA	{"email": "pavlova.elena-06061963@postgrespro.ru", "phone": "+70795720480"}
0005432071562	4447CB	6450 588639	SERGEY NOVIKOV	{"email": "sergeynovikov1970@postgrespro.ru", "phone": "+70618515128"}
0005432071563	64213B	0117 574199	DMITRIY ABRAMOV	{"phone": "+70334799337"}
0005432071564	64213B	2584 487023	BORIS STEPANOV	{"phone": "+70636541065"}
0005432071565	ACF5D1	1944 569012	OLGA POPOVA	{"phone": "+70720930042"}
0005432071566	093A4A	2368 118741	ALEKSANDR BORISOV	{"phone": "+70999552408"}
0005432071567	093A4A	0667 965459	ANASTASIYA KAZAKOVA	{"email": "a_kazakova_03011975@postgrespro.ru", "phone": "+70700421996"}
0005432071568	D0F448	2393 160664	ALEKSANDR POPOV	{"phone": "+70645913509"}
0005432071569	E67C27	5837 495975	KRISTINA ISAEVA	{"phone": "+70437764241"}
0005432071570	A9B849	0470 662405	VALENTINA KRASNOVA	{"phone": "+70985668001"}
0005432071571	A9B849	2460 339769	VERA FADEEVA	{"email": "v-fadeeva-061963@postgrespro.ru", "phone": "+70805366181"}
0005432071572	C4C873	3135 134236	EVGENIY GAVRILOV	{"phone": "+70967622557"}
0005432071573	C4C873	2144 590184	NATALYA VOLKOVA	{"phone": "+70371773373"}
0005432071574	419AC9	5647 027200	LYUDMILA MOROZOVA	{"phone": "+70449447118"}
0005432071575	642E85	6802 432745	ANDREY POPOV	{"phone": "+70115600334"}
0005432071576	9A38E2	1424 801599	PAVEL IVANOV	{"phone": "+70586571826"}
0005432071577	36BDD0	5921 942172	DMITRIY STEPANOV	{"email": "dmitriy-stepanov-051970@postgrespro.ru", "phone": "+70370780313"}
0005432071578	FD7F6E	8031 431759	DANILA FROLOV	{"phone": "+70622814876"}
0005432071579	A59B6B	9219 109168	ELENA NIKOLAEVA	{"phone": "+70465278455"}
0005432071580	AB426B	2024 825608	NATALIYA KRASNOVA	{"phone": "+70333685908"}
0005432071581	A4123C	5957 070253	VIKTOR KULIKOV	{"email": "kulikov_viktor-011973@postgrespro.ru", "phone": "+70261206592"}
0005432071582	C37BBA	4396 667392	LIDIYA KUZNECOVA	{"phone": "+70438832143"}
0005432071583	C37BBA	9723 834510	KRISTINA KONOVALOVA	{"email": "k-konovalova041973@postgrespro.ru", "phone": "+70762603307"}
0005432071584	B22159	7438 800290	LEONID KRASNOV	{"email": "l_krasnov-071970@postgrespro.ru", "phone": "+70139728949"}
0005432071585	54EBAF	7243 050371	VLADIMIR BELOV	{"phone": "+70075502552"}
0005432071586	D38882	0391 179873	ELENA ROMANOVA	{"phone": "+70486970446"}
0005432071587	3DBB19	9200 208363	DANILA ZHUKOV	{"phone": "+70776994482"}
0005432071588	30ABA2	8334 895211	DENIS GORBUNOV	{"phone": "+70173391006"}
0005432071589	6D5FD4	0505 297183	VASILIY KAZAKOV	{"email": "vasiliy-kazakov-15081976@postgrespro.ru", "phone": "+70257563145"}
0005432071590	AB8A2D	1026 362927	SERGEY VASILEV	{"phone": "+70075166386"}
0005432071591	33A2B3	6906 368483	SERGEY ANTONOV	{"email": "antonov-sergey_28121984@postgrespro.ru", "phone": "+70014012259"}
0005432071592	33A2B3	2762 809744	IGOR IVANOV	{"email": "ivanov-igor1972@postgrespro.ru", "phone": "+70227520733"}
0005432071593	33A2B3	8945 554065	LYUBOV MIRONOVA	{"phone": "+70863637418"}
0005432071594	C87268	0163 260507	ANNA VOROBEVA	{"email": "anna-vorobeva_1971@postgrespro.ru", "phone": "+70401072042"}
0005432071595	E9DEDD	2872 888123	OLGA NOVIKOVA	{"email": "olga.novikova-1978@postgrespro.ru", "phone": "+70435904356"}
0005432071596	6E18B8	8542 278318	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.a-1980@postgrespro.ru", "phone": "+70847072184"}
0005432071597	6E18B8	1539 562377	GALIYA ZHUKOVA	{"phone": "+70623214006"}
0005432071598	767C55	2084 680507	TIGRAN SIDOROV	{"email": "sidorovt-05121972@postgrespro.ru", "phone": "+70087450418"}
0005432071599	45AFE7	0812 608508	EVGENIY MOISEEV	{"email": "e_moiseev_09041963@postgrespro.ru", "phone": "+70345732099"}
0005432071600	45AFE7	0326 604959	EVGENIY GORBUNOV	{"phone": "+70396112187"}
0005432071601	B2620A	7920 219609	VIKTOR MEDVEDEV	{"email": "v.medvedev.12011969@postgrespro.ru", "phone": "+70708257258"}
0005432071602	B2620A	1093 479912	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov061968@postgrespro.ru", "phone": "+70605186873"}
0005432071603	B2620A	3729 948201	NATALYA DENISOVA	{"email": "denisova_n-1977@postgrespro.ru", "phone": "+70154759468"}
0005432071604	BD869E	2275 967879	LYUBOV KUZMINA	{"phone": "+70859630835"}
0005432071605	55EA29	8480 802718	ELENA KOZLOVA	{"email": "kozlovae1982@postgrespro.ru", "phone": "+70808712382"}
0005432071606	B53E60	0001 433006	EDUARD FOMIN	{"phone": "+70405020112"}
0005432071607	774EC0	6242 589462	ALEKSANDR KONOVALOV	{"phone": "+70272072909"}
0005432071608	88E6F8	1517 767336	ALEKSANDRA LAZAREVA	{"email": "a_lazareva.31011971@postgrespro.ru", "phone": "+70646619883"}
0005432071609	E21210	8798 849093	LILIYA SOROKINA	{"phone": "+70028325781"}
0005432071610	E21210	0988 112491	VLADIMIR MOROZOV	{"email": "morozov_vladimir_1968@postgrespro.ru", "phone": "+70101822467"}
0005432071611	3E071B	4107 924020	EKATERINA SCHERBAKOVA	{"email": "ekaterina.scherbakova29011976@postgrespro.ru", "phone": "+70766022488"}
0005432071612	3E071B	5253 413113	DMITRIY ANTONOV	{"email": "dantonov_1981@postgrespro.ru", "phone": "+70967217584"}
0005432071613	5E667A	6244 558795	KONSTANTIN FEDOROV	{"phone": "+70618721161"}
0005432071614	5E667A	8911 474854	VIKTOR ABRAMOV	{"phone": "+70063037540"}
0005432071615	5E667A	0981 270328	DMITRIY GORBUNOV	{"email": "gorbunov-d01111976@postgrespro.ru", "phone": "+70200832778"}
0005432071616	B5A0D3	5321 503305	VASILIY NAUMOV	{"phone": "+70230213609"}
0005432071617	80EA03	9898 717004	LYUDMILA KOZLOVA	{"email": "l-kozlova18031972@postgrespro.ru", "phone": "+70638438915"}
0005432071618	09B18F	2360 783811	OLESYA TIMOFEEVA	{"email": "timofeeva-o.1964@postgrespro.ru", "phone": "+70946145150"}
0005432071619	09B18F	0323 041591	ZOYA IVANOVA	{"email": "zoyaivanova031973@postgrespro.ru", "phone": "+70147740826"}
0005432071620	3F7C70	2147 482218	VALERIY ANTONOV	{"phone": "+70593797986"}
0005432071621	65D33D	7395 539703	VALENTINA NIKOLAEVA	{"email": "v_nikolaeva.10061976@postgrespro.ru", "phone": "+70419028072"}
0005432071622	C17466	3197 305981	ARKADIY KUZNECOV	{"email": "arkadiy.kuznecov.02031968@postgrespro.ru", "phone": "+70888449418"}
0005432071623	C17466	0947 759582	ALEKSANDR NOVIKOV	{"email": "novikov.a1967@postgrespro.ru", "phone": "+70756328991"}
0005432071624	D85352	5518 546630	ANNA BORISOVA	{"email": "annaborisova-011967@postgrespro.ru", "phone": "+70223947583"}
0005432071625	7ED60F	6769 885411	RAVIL POPOV	{"phone": "+70511333233"}
0005432071626	7ED60F	3413 791750	VERA EGOROVA	{"phone": "+70085785250"}
0005432071627	7ED60F	2481 939979	NADEZHDA ABRAMOVA	{"phone": "+70596582936"}
0005432071628	C730B2	5219 506094	ALFIYA FEDOROVA	{"email": "fedorova.alfiya1976@postgrespro.ru", "phone": "+70597245309"}
0005432071629	2B9E26	8921 473367	DMITRIY BELOV	{"email": "belovd031986@postgrespro.ru", "phone": "+70139760493"}
0005432071630	9784B2	4208 238208	ANASTASIYA ROMANOVA	{"email": "a.romanova-121971@postgrespro.ru", "phone": "+70719953865"}
0005432071631	C1E645	0188 228982	GENNADIY SOLOVEV	{"email": "gennadiy-solovev_091979@postgrespro.ru", "phone": "+70333559958"}
0005432071632	F66908	4404 063800	ANDREY NAZAROV	{"phone": "+70643061379"}
0005432071633	612229	4433 372061	LYUBOV KONDRATEVA	{"email": "lkondrateva.121970@postgrespro.ru", "phone": "+70497844377"}
0005432071634	3CAA1B	2508 961938	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov_1977@postgrespro.ru", "phone": "+70012482554"}
0005432071635	AB5AEB	2245 560719	LUIZA MAKSIMOVA	{"phone": "+70115076691"}
0005432071636	DC8DA1	6502 243768	ANDREY NOVIKOV	{"phone": "+70527719605"}
0005432071637	F08F01	8258 740766	DANIIL AFANASEV	{"email": "afanasev-d-1976@postgrespro.ru", "phone": "+70598026583"}
0005432071638	CBFD7C	3124 422397	NIKOLAY ABRAMOV	{"email": "n.abramov1971@postgrespro.ru", "phone": "+70839086450"}
0005432071639	CBFD7C	2800 498510	ANNA OSIPOVA	{"email": "osipova_anna_1974@postgrespro.ru", "phone": "+70671303655"}
0005432071640	0EBB9D	2849 863348	SVETLANA KONOVALOVA	{"phone": "+70555347141"}
0005432071641	63D73F	3525 090501	YANA NIKOLAEVA	{"phone": "+70615502670"}
0005432071642	6FE374	8261 295069	MAKSIM MIKHAYLOV	{"phone": "+70716544773"}
0005432071643	8EFEA4	9946 594088	ELENA KOVALEVA	{"email": "e_kovaleva.101971@postgrespro.ru", "phone": "+70631815429"}
0005432071644	458368	0110 628789	VALERIY BORISOV	{"email": "valeriyborisov_1978@postgrespro.ru", "phone": "+70030932409"}
0005432071645	F6B511	4002 013184	SERGEY PAVLOV	{"phone": "+70058092784"}
0005432071646	24DE49	0120 743686	EKATERINA ZAKHAROVA	{"email": "e-zakharova051973@postgrespro.ru", "phone": "+70076478684"}
0005432071647	38074E	5213 387794	OLGA BORISOVA	{"email": "o_borisova24051979@postgrespro.ru", "phone": "+70587139519"}
0005432071648	38074E	1779 854765	GALINA KRASNOVA	{"email": "galinakrasnova-10051971@postgrespro.ru", "phone": "+70836466659"}
0005432071649	99355E	7950 140070	VLADIMIR ALEKSANDROV	{"email": "vladimir-aleksandrov.011983@postgrespro.ru", "phone": "+70613357498"}
0005432071650	E7AF01	4212 304527	ANATOLIY KOZLOV	{"phone": "+70122220664"}
0005432071651	E7AF01	8769 844863	VALENTINA FEDOROVA	{"email": "v-fedorova.111970@postgrespro.ru", "phone": "+70930744128"}
0005432071652	5BE7A2	9861 573319	ANATOLIY NIKITIN	{"email": "anatoliy_nikitin061967@postgrespro.ru", "phone": "+70790998842"}
0005432071653	5BE7A2	1073 367411	NADEZHDA ALEKSANDROVA	{"phone": "+70533110410"}
0005432071654	99D759	8187 996388	ELIZAVETA KAZAKOVA	{"email": "kazakova-elizaveta25101983@postgrespro.ru", "phone": "+70332489193"}
0005432071655	99D759	2267 559161	ANNA PETROVA	{"phone": "+70093101737"}
0005432071656	2DF75D	9971 346493	MARIYA DMITRIEVA	{"email": "dmitrieva_mariya.101959@postgrespro.ru", "phone": "+70321675906"}
0005432071657	519292	6693 207049	SAMIRA MASLOVA	{"phone": "+70849866047"}
0005432071658	519292	9589 610268	VLADIMIR MAKAROV	{"email": "makarov-vladimir-1978@postgrespro.ru", "phone": "+70552826240"}
0005432071659	EEE6AD	7266 121495	ALEKSANDR KARPOV	{"email": "aleksandr.karpov_1967@postgrespro.ru", "phone": "+70642276001"}
0005432071660	EEE6AD	0956 294077	ANNA NIKOLAEVA	{"phone": "+70330839585"}
0005432071661	EEE6AD	3909 051752	ELENA TIKHONOVA	{"email": "e_tikhonova_081974@postgrespro.ru", "phone": "+70978753658"}
0005432071662	F78C52	3154 848142	NATALYA KOZLOVA	{"email": "kozlovanatalya_17121981@postgrespro.ru", "phone": "+70032551140"}
0005432071663	F78C52	5079 742461	VLADIMIR FROLOV	{"email": "vladimir-frolov-1957@postgrespro.ru", "phone": "+70357212507"}
0005432071664	DB46C8	0121 906359	EVDOKIYA KOLESNIKOVA	{"email": "ekolesnikova.091973@postgrespro.ru", "phone": "+70313808588"}
0005432073329	AE3540	1295 799782	NIKITA ZAKHAROV	{"email": "zakharovnikita-1974@postgrespro.ru", "phone": "+70402653605"}
0005432073330	0AB051	8241 004376	EKATERINA KOROLEVA	{"email": "e-koroleva-041973@postgrespro.ru", "phone": "+70110115170"}
0005432073331	122136	7856 813439	DENIS SIDOROV	{"email": "sidorov_denis1969@postgrespro.ru", "phone": "+70686584839"}
0005432073332	270284	0087 803398	ALEKSANDR IVANOV	{"email": "aleksandrivanov-1970@postgrespro.ru", "phone": "+70970899429"}
0005432073333	CB0598	5289 198152	TATYANA KUZMINA	{"phone": "+70737522686"}
0005432073334	CB0598	1221 031954	NIKOLAY SHEVCHENKO	{"phone": "+70032783174"}
0005432073335	A0CF7D	5881 649598	LIDIYA TITOVA	{"phone": "+70510812780"}
0005432073336	097015	8146 533608	EKATERINA ARKHIPOVA	{"email": "arkhipova.e03051968@postgrespro.ru", "phone": "+70002359204"}
0005432073337	290214	9079 825704	ALEKSANDR MAKAROV	{"phone": "+70761960460"}
0005432073338	AC7EB5	0837 130655	VIKTOR IVANOV	{"phone": "+70849303299"}
0005432073339	BE0366	2379 815163	ALEKSANDR SMIRNOV	{"email": "smirnov_a_13101967@postgrespro.ru", "phone": "+70092438859"}
0005432073340	BE0366	9027 943181	NIKOLAY SERGEEV	{"phone": "+70355825445"}
0005432073341	6EE276	9575 028742	DIANA KUZMINA	{"email": "diana-kuzmina1959@postgrespro.ru", "phone": "+70213254179"}
0005432073342	3F71E2	6044 526417	IRINA BORISOVA	{"phone": "+70582343433"}
0005432073343	3017E9	2768 933315	NINA KARPOVA	{"email": "karpova.n_111961@postgrespro.ru", "phone": "+70815903157"}
0005432073344	F28513	2201 581549	ALEKSANDRA ALEKSEEVA	{"email": "alekseeva.aleksandra.1977@postgrespro.ru", "phone": "+70054997982"}
0005432073345	F28513	4444 346148	TATYANA ILINA	{"email": "tatyana_ilina-1967@postgrespro.ru", "phone": "+70390898469"}
0005432073346	37C7CF	8074 251224	OLGA MATVEEVA	{"email": "matveeva.o_031972@postgrespro.ru", "phone": "+70039220310"}
0005432073347	216DA7	8758 818609	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr051974@postgrespro.ru", "phone": "+70373028091"}
0005432073348	D49EE4	4721 216085	VERA SIDOROVA	{"email": "sidorova_vera_031972@postgrespro.ru", "phone": "+70403212487"}
0005432073349	788C15	1002 194072	DMITRIY EGOROV	{"phone": "+70319917967"}
0005432073350	3AD96E	3067 600434	LILIYA NOVIKOVA	{"phone": "+70499975525"}
0005432073351	91043A	0810 720537	OLEG AFANASEV	{"email": "afanasev.oleg-081976@postgrespro.ru", "phone": "+70183045574"}
0005432073352	91043A	1503 271724	NINA NIKOLAEVA	{"email": "nikolaeva-nina_1967@postgrespro.ru", "phone": "+70832100945"}
0005432073353	91043A	5708 686908	LARISA ZHUKOVA	{"phone": "+70604085823"}
0005432073354	8FDD3F	3808 589862	SERGEY SEMENOV	{"phone": "+70561709893"}
0005432073355	8FDD3F	4638 505125	OLEG KUZMIN	{"phone": "+70171201549"}
0005432073356	A27CFF	7589 975234	ANTONINA SAVELEVA	{"phone": "+70408219449"}
0005432073357	27DC0A	2037 106944	IVAN TIMOFEEV	{"phone": "+70729975862"}
0005432073358	7755BC	7692 164855	IRINA MIKHAYLOVA	{"phone": "+70708523916"}
0005432073359	7755BC	0383 590020	MARGARITA LEBEDEVA	{"phone": "+70835125604"}
0005432073360	5114ED	9040 946828	VIKTOR POPOV	{"email": "viktor-popov-051957@postgrespro.ru", "phone": "+70742393954"}
0005432073361	846CBB	3660 150774	ALEVTINA KISELEVA	{"email": "a_kiseleva.061964@postgrespro.ru", "phone": "+70670374584"}
0005432073362	8B70C9	9206 860440	OLGA NIKITINA	{"phone": "+70955992237"}
0005432073363	33C721	0526 101165	ELENA PAVLOVA	{"email": "epavlova-1960@postgrespro.ru", "phone": "+70782144331"}
0005432073364	91D954	1556 525677	EGOR IVANOV	{"email": "ivanov.egor_111970@postgrespro.ru", "phone": "+70472690853"}
0005432073365	7B7598	4889 437190	EVGENIY TARASOV	{"phone": "+70155989094"}
0005432073366	690E87	5616 613718	ELIZAVETA FADEEVA	{"email": "fadeeva-e1970@postgrespro.ru", "phone": "+70341563510"}
0005432073367	A89CD1	1525 720888	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin_021962@postgrespro.ru", "phone": "+70338720807"}
0005432073368	A89CD1	4009 207646	VLADIMIR KOZLOV	{"phone": "+70892995103"}
0005432073369	A89CD1	1943 474457	DMITRIY KONOVALOV	{"email": "konovalov-dmitriy_011973@postgrespro.ru", "phone": "+70863374962"}
0005432073370	A89CD1	2221 457292	ALBINA VOLKOVA	{"phone": "+70717232220"}
0005432073371	E294C2	9171 103628	IVAN SERGEEV	{"email": "ivan-sergeev.051969@postgrespro.ru", "phone": "+70145502856"}
0005432073372	5F48D7	0932 599140	LYUDMILA BELOVA	{"phone": "+70451547167"}
0005432073373	2CEAFB	1273 170903	STANISLAV KOZLOV	{"phone": "+70411042053"}
0005432073374	D11A1F	3936 709789	MARIYA GORBUNOVA	{"email": "m-gorbunova.111969@postgrespro.ru", "phone": "+70217854304"}
0005432073375	AD2F8A	2811 754899	VITALIY IVANOV	{"phone": "+70801020924"}
0005432073376	0CFEBD	4760 076384	NATALYA VASILEVA	{"phone": "+70658804921"}
0005432073377	CB530B	2230 105542	IVAN KRASNOV	{"email": "krasnov-i-021964@postgrespro.ru", "phone": "+70680227294"}
0005432073378	7E0B24	0717 747201	SVETLANA MAKAROVA	{"phone": "+70419883298"}
0005432073379	775793	1016 258050	NATALYA NIKITINA	{"phone": "+70945923817"}
0005432073380	79DFBA	6211 554752	TAMARA MALYSHEVA	{"email": "tamara.malysheva18081963@postgrespro.ru", "phone": "+70066713486"}
0005432073381	79DFBA	7760 838624	NIKOLAY KAZAKOV	{"email": "kazakov.n18041965@postgrespro.ru", "phone": "+70363256004"}
0005432073382	7B0886	6367 216135	MAKSIM IVANOV	{"email": "ivanov-m-1976@postgrespro.ru", "phone": "+70594165464"}
0005432073383	7B0886	1420 560060	NATALYA GERASIMOVA	{"email": "natalya-gerasimova_1961@postgrespro.ru", "phone": "+70455616189"}
0005432073384	7B0886	6583 980954	GYUZEL PAVLOVA	{"email": "pavlova-g_25111978@postgrespro.ru", "phone": "+70319766603"}
0005432073385	F945A1	9259 787654	TATYANA KISELEVA	{"phone": "+70761205630"}
0005432073386	F945A1	0177 704246	VIKTOR NAUMOV	{"email": "v-naumov-19021970@postgrespro.ru", "phone": "+70846165163"}
0005432073387	1779F6	3032 249748	YULIYA BELOVA	{"phone": "+70127387205"}
0005432073388	1779F6	8439 288227	MIKHAIL ILIN	{"phone": "+70270751828"}
0005432073389	9AC870	0434 654371	ANATOLIY MAKSIMOV	{"phone": "+70982954613"}
0005432073390	140246	2236 359661	NIKOLAY CHERNOV	{"email": "chernov.n28051967@postgrespro.ru", "phone": "+70057986836"}
0005432073391	99CF1A	3610 911075	ELENA IVANOVA	{"email": "e-ivanova-1972@postgrespro.ru", "phone": "+70615230416"}
0005432073392	99CF1A	7934 989975	VALENTINA KRASNOVA	{"phone": "+70949844817"}
0005432073393	56AD3F	5198 934756	PETR KUDRYASHOV	{"email": "kudryashov-p.071968@postgrespro.ru", "phone": "+70631287477"}
0005432073394	292754	7428 027248	LARISA KOROLEVA	{"email": "lkoroleva.1968@postgrespro.ru", "phone": "+70885000258"}
0005432073395	205D04	4916 822725	VALENTINA KOROLEVA	{"phone": "+70303617223"}
0005432073396	6E7434	6816 709496	ARTUR ISAEV	{"email": "isaev_a.15111970@postgrespro.ru", "phone": "+70291314510"}
0005432073397	6E7434	1508 844896	MAKSIM KUZNECOV	{"phone": "+70544799737"}
0005432073398	6E7434	2866 711809	ILMIR IVANOV	{"phone": "+70865252819"}
0005432073399	A5D7EB	3136 938980	KONSTANTIN VOLKOV	{"email": "k.volkov1976@postgrespro.ru", "phone": "+70081860884"}
0005432073400	E0FADC	5521 074626	MARAT SMIRNOV	{"email": "smirnov-marat23121965@postgrespro.ru", "phone": "+70540365945"}
0005432073401	E0FADC	2424 476356	MARGARITA MATVEEVA	{"email": "matveeva-m22021975@postgrespro.ru", "phone": "+70420816856"}
0005432073402	F493E5	3982 772427	OLGA KUDRYASHOVA	{"phone": "+70101848727"}
0005432073403	9205C8	0738 072351	NIKOLAY STEPANOV	{"phone": "+70999742035"}
0005432073404	9205C8	9339 583461	MIKHAIL KUDRYASHOV	{"phone": "+70822346443"}
0005432073405	303B38	4549 248893	MIKHAIL ABRAMOV	{"email": "mikhail_abramov.021960@postgrespro.ru", "phone": "+70855399885"}
0005432073406	B634FD	4650 762675	NIKITA MIRONOV	{"email": "mironov.nikita_041962@postgrespro.ru", "phone": "+70777603455"}
0005432073407	F38064	7892 304210	PAVEL GAVRILOV	{"email": "gavrilov.p1970@postgrespro.ru", "phone": "+70841403285"}
0005432073408	2BAF68	6919 159695	NINA POPOVA	{"phone": "+70692392898"}
0005432073409	9E061D	1976 084375	VALENTINA PETROVA	{"email": "vpetrova.101964@postgrespro.ru", "phone": "+70833389890"}
0005432073410	D3534C	3968 213372	ARTEM KUZNECOV	{"email": "akuznecov.091962@postgrespro.ru", "phone": "+70285732783"}
0005432073411	66777D	3260 242017	VERONIKA IVANOVA	{"email": "veronika-ivanova15111972@postgrespro.ru", "phone": "+70049120629"}
0005432073412	76A54E	0442 678200	ANASTASIYA OSIPOVA	{"phone": "+70286874231"}
0005432073413	B86EC0	1795 743792	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov29061972@postgrespro.ru", "phone": "+70607922684"}
0005432073414	C17335	2375 262572	NIKOLAY NAUMOV	{"email": "n.naumov-081975@postgrespro.ru", "phone": "+70914930652"}
0005432073415	C17335	5967 668404	VYACHESLAV PAVLOV	{"email": "vyacheslav-pavlov-011986@postgrespro.ru", "phone": "+70489005726"}
0005432073416	89C1F5	1656 586081	ARINA STEPANOVA	{"email": "stepanova.arina.1967@postgrespro.ru", "phone": "+70349902451"}
0005432073417	89C1F5	7126 975482	ELENA LOGINOVA	{"phone": "+70335131918"}
0005432073418	07DAF2	9433 923792	ELENA VASILEVA	{"phone": "+70252102648"}
0005432073419	C86986	8044 486701	EVGENIYA TIMOFEEVA	{"email": "e_timofeeva.101985@postgrespro.ru", "phone": "+70439832135"}
0005432073420	095520	7376 957642	ALIK MAKAROV	{"email": "makarova-081971@postgrespro.ru", "phone": "+70082337997"}
0005432073421	0059AA	5777 006428	IRINA BELYAEVA	{"email": "belyaeva.i-19041969@postgrespro.ru", "phone": "+70004566121"}
0005432073422	2DECF2	9614 080114	ALENA FROLOVA	{"phone": "+70342408507"}
0005432073423	2DECF2	1863 955166	OLGA BELOVA	{"email": "belova.o_27071975@postgrespro.ru", "phone": "+70933533838"}
0005432073424	1B953F	2602 170969	ALEKSEY ZHUKOV	{"phone": "+70441760120"}
0005432073425	1B953F	4339 161351	ALEKSEY ROMANOV	{"phone": "+70627990990"}
0005432073426	6D0379	4800 613668	VLADIMIR FEDOROV	{"phone": "+70642549956"}
0005432073427	821155	0152 114211	VITALIY VASILEV	{"email": "vasilev-vitaliy_06091979@postgrespro.ru", "phone": "+70856781545"}
0005432073428	F24A14	2679 535618	TATYANA POPOVA	{"phone": "+70847815693"}
0005432073429	F24A14	9406 692614	VALERIY EGOROV	{"email": "v_egorov_23031969@postgrespro.ru", "phone": "+70948846322"}
0005432073430	4F583A	2201 705028	GALINA FILIPPOVA	{"email": "galina.filippova_22121969@postgrespro.ru", "phone": "+70591885705"}
0005432073431	EC212F	5591 009049	LYUBOV NIKITINA	{"email": "lyubov.nikitina051981@postgrespro.ru", "phone": "+70063133515"}
0005432073432	B93354	7854 122548	VALERIY ALEKSANDROV	{"phone": "+70935943883"}
0005432073433	AD96A4	9939 119294	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda_14101978@postgrespro.ru", "phone": "+70446969133"}
0005432073434	610FCF	5685 707218	KONSTANTIN ALEKSANDROV	{"email": "aleksandrovkonstantin1966@postgrespro.ru", "phone": "+70950603697"}
0005432073435	610FCF	8947 476165	ALEKSANDR SAVELEV	{"email": "savelev.aleksandr_1969@postgrespro.ru", "phone": "+70483520104"}
0005432073436	7A381A	2054 610351	OLEG SHEVCHENKO	{"email": "oleg-shevchenko-09041963@postgrespro.ru", "phone": "+70042959247"}
0005432073437	A48CFC	2343 163379	IRINA ANDREEVA	{"phone": "+70695585295"}
0005432073438	63B14E	1190 455589	NIKOLAY ALEKSANDROV	{"email": "aleksandrov_nikolay_1967@postgrespro.ru", "phone": "+70157958017"}
0005432073439	63B14E	7753 370970	NATALYA FADEEVA	{"phone": "+70815626261"}
0005432073440	35CD64	2312 688994	ELENA OVCHINNIKOVA	{"email": "elena-ovchinnikova29091966@postgrespro.ru", "phone": "+70890067982"}
0005432073441	E4550A	5872 468465	EVGENIY KOZLOV	{"phone": "+70386752571"}
0005432073442	A53C65	4343 690707	ALEKSANDR FOMIN	{"email": "a-fomin31101984@postgrespro.ru", "phone": "+70447617455"}
0005432073443	A53C65	8242 936766	NIKOLAY SERGEEV	{"phone": "+70295232233"}
0005432073444	A53C65	0342 071483	ILYA EGOROV	{"email": "i.egorov_1967@postgrespro.ru", "phone": "+70213442363"}
0005432073445	AEACEF	3186 030361	MIKHAIL PETROV	{"email": "m-petrov_1958@postgrespro.ru", "phone": "+70062661085"}
0005432073446	87A6EC	5277 149491	VALERIY BELOV	{"phone": "+70854085308"}
0005432073447	87A6EC	3886 328116	DARYA KUZNECOVA	{"email": "d_kuznecova-1966@postgrespro.ru", "phone": "+70430521636"}
0005432073448	20C491	8304 081864	VALENTINA SOROKINA	{"email": "sorokina.v_1978@postgrespro.ru", "phone": "+70563206663"}
0005432073449	2E57A1	1720 627253	LYAYSAN POLYAKOVA	{"phone": "+70234389268"}
0005432073450	2E57A1	9507 197001	NADEZHDA MAKAROVA	{"email": "makarovanadezhda_09091985@postgrespro.ru", "phone": "+70949160146"}
0005432073451	59E3D3	3315 168644	VLADIMIR MELNIKOV	{"phone": "+70875007313"}
0005432073452	70ED55	3165 125803	DMITRIY TIMOFEEV	{"phone": "+70719149980"}
0005432073453	D60856	0365 898435	ALENA ISAEVA	{"email": "isaeva_alena061975@postgrespro.ru", "phone": "+70926870651"}
0005432073454	D55180	5863 156921	OLEG IVANOV	{"email": "o_ivanov.1970@postgrespro.ru", "phone": "+70122904781"}
0005432073455	D55180	9530 563740	YURIY SCHERBAKOV	{"phone": "+70505115869"}
0005432073456	79DF0D	9649 326618	OLGA FILIPPOVA	{"email": "olga.filippova.101967@postgrespro.ru", "phone": "+70616982143"}
0005432073457	79DF0D	1430 057039	VLADIMIR BORISOV	{"phone": "+70005729373"}
0005432073458	80DFE9	3886 372753	DANIL ZAYCEV	{"phone": "+70911142490"}
0005432073459	19C2C2	7793 107314	KLAVDIYA ZHUKOVA	{"phone": "+70504648536"}
0005432073460	935AC8	5111 077665	IRINA KUZNECOVA	{"email": "irinakuznecova-13031982@postgrespro.ru", "phone": "+70936699762"}
0005432073461	71CC4F	8673 673917	NIKOLAY ZAYCEV	{"email": "nikolay_zaycev-1965@postgrespro.ru", "phone": "+70627425791"}
0005432073462	71CC4F	4183 771310	ANASTASIYA FOMINA	{"email": "fominaa16011972@postgrespro.ru", "phone": "+70049187124"}
0005432073463	EC0AC9	1240 046935	NADEZHDA ILINA	{"phone": "+70173030369"}
0005432073464	B6841D	9307 428912	MARIYA NAZAROVA	{"phone": "+70050511576"}
0005432073465	05B73F	7529 637861	SVETLANA RODIONOVA	{"email": "srodionova.011982@postgrespro.ru", "phone": "+70888404456"}
0005432073466	3D70CE	5651 066173	ELIZAVETA NESTEROVA	{"email": "elizavetanesterova1969@postgrespro.ru", "phone": "+70714748945"}
0005432073467	3D70CE	5486 014507	SERGEY MARTYNOV	{"email": "martynov-s-1962@postgrespro.ru", "phone": "+70475949729"}
0005432073468	B5AABC	4765 182046	ALEKSANDR TARASOV	{"email": "tarasova_111966@postgrespro.ru", "phone": "+70069551341"}
0005432073469	32A0CA	1875 591009	ANASTASIYA SOROKINA	{"phone": "+70048770229"}
0005432073470	32A0CA	5622 157480	DMITRIY ANDREEV	{"phone": "+70160552958"}
0005432073471	32A0CA	7115 887142	TATYANA POPOVA	{"email": "tatyanapopova-011963@postgrespro.ru", "phone": "+70136015094"}
0005432073472	FCA2A3	2779 382339	MAKSIM STEPANOV	{"email": "maksimstepanov011965@postgrespro.ru", "phone": "+70642357773"}
0005432073473	CABD43	7690 953485	ELIZAVETA KOLESNIKOVA	{"email": "kolesnikovaelizaveta101970@postgrespro.ru", "phone": "+70243077333"}
0005432073474	A6D5AD	6220 968531	ANASTASIYA SOLOVEVA	{"email": "soloveva-anastasiya_1968@postgrespro.ru", "phone": "+70576964814"}
0005432073475	6777B9	9750 976367	IRINA KONDRATEVA	{"phone": "+70784490007"}
0005432073476	B3DAD2	7339 238170	ALEKSANDR VLASOV	{"email": "a.vlasov-08041975@postgrespro.ru", "phone": "+70906931942"}
0005432073477	8D2D98	3468 423836	DMITRIY BORISOV	{"phone": "+70400735608"}
0005432073478	C13791	7302 047740	ROMAN PAVLOV	{"email": "rpavlov.1970@postgrespro.ru", "phone": "+70911081890"}
0005432073479	D57FE1	3358 136154	OLGA NESTEROVA	{"phone": "+70511368077"}
0005432073480	7540F8	3344 170575	NIKOLAY SHEVCHENKO	{"email": "shevchenko-nikolay.101957@postgrespro.ru", "phone": "+70364966426"}
0005432073481	7540F8	5983 383964	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov_02031976@postgrespro.ru", "phone": "+70203442963"}
0005432073482	7540F8	4438 552013	EKATERINA KUZNECOVA	{"phone": "+70218558025"}
0005432073483	48774E	3133 883922	PETR ZHUKOV	{"email": "petr_zhukov_1972@postgrespro.ru", "phone": "+70539162837"}
0005432073484	B2081A	4293 618388	DZHAMILYA LEBEDEVA	{"email": "d_lebedeva_1971@postgrespro.ru", "phone": "+70769508736"}
0005432073485	592E15	4948 247268	BORIS ROMANOV	{"email": "romanov-boris.1971@postgrespro.ru", "phone": "+70936415658"}
0005432073486	592E15	9356 142556	VASILIY IVANOV	{"phone": "+70710332471"}
0005432073487	5044AB	5251 691598	MARIYA ANISIMOVA	{"email": "anisimovam-02031970@postgrespro.ru", "phone": "+70861329708"}
0005432073488	DABC89	8487 680423	NIKOLAY MAKAROV	{"email": "makarov.n_041971@postgrespro.ru", "phone": "+70176718519"}
0005432073489	DABC89	4837 044975	VLADIMIR EGOROV	{"email": "egorov-v_14021970@postgrespro.ru", "phone": "+70812852368"}
0005432073490	DABC89	6588 606904	YURIY IVANOV	{"email": "ivanov.yuriy.1972@postgrespro.ru", "phone": "+70663123143"}
0005432073491	DABC89	5469 683118	ELENA ANTONOVA	{"email": "antonova-e-111982@postgrespro.ru", "phone": "+70294097097"}
0005432073492	44DB50	0556 188355	PAVEL NAZAROV	{"email": "nazarovp1965@postgrespro.ru", "phone": "+70049378068"}
0005432073493	44DB50	8139 836929	IGOR VLASOV	{"phone": "+70318593112"}
0005432073494	780664	9172 352765	VALENTINA FEDOROVA	{"phone": "+70904814464"}
0005432073495	203DD5	8952 934166	SERGEY MOISEEV	{"email": "s.moiseev.1969@postgrespro.ru", "phone": "+70814244330"}
0005432073496	72B6F8	2785 363472	ARKADIY KUZNECOV	{"phone": "+70245184273"}
0005432073497	72B6F8	0286 987328	SERGEY FEDOROV	{"email": "fedorov_s.20031972@postgrespro.ru", "phone": "+70276893471"}
0005432075169	E6CFAC	0996 708785	ARKADIY ZAKHAROV	{"email": "arkadiy-zakharov-26021981@postgrespro.ru", "phone": "+70953295254"}
0005432075170	DC316A	8640 699226	GENNADIY MOROZOV	{"email": "morozovgennadiy_21021973@postgrespro.ru", "phone": "+70205951490"}
0005432075171	DC316A	1998 984603	OKSANA VASILEVA	{"email": "vasileva.o.05091978@postgrespro.ru", "phone": "+70881911275"}
0005432075172	201821	5513 394091	VALENTINA PAVLOVA	{"phone": "+70856006572"}
0005432075173	30EF3C	1364 476690	ROMAN POPOV	{"email": "popov_roman_1966@postgrespro.ru", "phone": "+70602392436"}
0005432075174	30EF3C	9420 566713	GALINA ORLOVA	{"phone": "+70306677666"}
0005432075175	E1BF04	1610 167435	LYUBOV NIKOLAEVA	{"phone": "+70395918305"}
0005432075176	2693E7	9657 304754	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr_1980@postgrespro.ru", "phone": "+70745282382"}
0005432075177	1B5611	0693 271600	SOFYA STEPANOVA	{"phone": "+70679038367"}
0005432075178	4FD202	3978 893549	ROMAN DENISOV	{"email": "denisov.roman-101971@postgrespro.ru", "phone": "+70587162547"}
0005432075179	85A140	6657 316871	YULIYA SOROKINA	{"phone": "+70042793036"}
0005432075180	BE42FE	6020 623512	ELENA KAZAKOVA	{"phone": "+70781739772"}
0005432075181	BE42FE	5972 204190	NADEZHDA ZOTOVA	{"email": "nzotova.071981@postgrespro.ru", "phone": "+70584251690"}
0005432075182	9B5DE3	7161 955423	OLGA KOROLEVA	{"email": "koroleva-o.12051974@postgrespro.ru", "phone": "+70487699905"}
0005432075183	6CAC33	6229 278593	VYACHESLAV SAVELEV	{"email": "vsavelev-011968@postgrespro.ru", "phone": "+70688865342"}
0005432075184	6CAC33	7492 013029	ANDREY IVANOV	{"phone": "+70290780360"}
0005432075185	10947A	6402 711758	PAVEL MAKAROV	{"phone": "+70135081644"}
0005432075186	10947A	5788 362890	MIKHAIL SMIRNOV	{"email": "smirnov-mikhail18041985@postgrespro.ru", "phone": "+70787653493"}
0005432075187	3400A3	8734 282354	ANNA FROLOVA	{"phone": "+70509478099"}
0005432075188	3400A3	5234 242453	ANATOLIY VLASOV	{"phone": "+70552260973"}
0005432075189	3400A3	1961 914618	NATALYA VOROBEVA	{"email": "vorobeva.natalya.011983@postgrespro.ru", "phone": "+70122542114"}
0005432075190	A1F776	2798 126489	TATYANA PAVLOVA	{"email": "tpavlova.121964@postgrespro.ru", "phone": "+70387448972"}
0005432075191	46F9EC	1571 528678	VIKTOR POPOV	{"phone": "+70336260188"}
0005432075192	68EE5C	7711 562314	LARISA MARTYNOVA	{"email": "l.martynova.1962@postgrespro.ru", "phone": "+70413485308"}
0005432075193	68EE5C	3852 611222	ANDREY KONOVALOV	{"email": "andrey-konovalov-30031967@postgrespro.ru", "phone": "+70666286733"}
0005432075194	3732E6	8511 558308	VIKTOR SOROKIN	{"phone": "+70789333325"}
0005432075195	B87401	4253 256530	TAMARA ANISIMOVA	{"email": "tamara_anisimova27081967@postgrespro.ru", "phone": "+70505105598"}
0005432075196	3158E6	0780 545616	MARIYA SEMENOVA	{"phone": "+70958957694"}
0005432075197	2A46FF	0817 279320	NADEZHDA MAKAROVA	{"email": "n-makarova1981@postgrespro.ru", "phone": "+70846285100"}
0005432075198	B7CD13	6920 514173	EKATERINA BELYAEVA	{"email": "e.belyaeva061976@postgrespro.ru", "phone": "+70719809777"}
0005432075199	1CF8BE	4626 148896	ALEKSEY FOMIN	{"phone": "+70237829560"}
0005432075200	404E45	7678 425529	OLGA ZHUKOVA	{"email": "olga.zhukova_05011965@postgrespro.ru", "phone": "+70332280874"}
0005432075201	9F53DE	0592 451752	TIMOFEY ZAKHAROV	{"email": "zakharovt.05031976@postgrespro.ru", "phone": "+70662309080"}
0005432075202	FB5320	6385 036428	VIKTOR KISELEV	{"email": "kiselev.v041971@postgrespro.ru", "phone": "+70092743453"}
0005432075203	892E4E	9492 137870	MARIYA ANTONOVA	{"phone": "+70446469276"}
0005432075204	C41657	8308 728844	VALERIY ILIN	{"phone": "+70512322989"}
0005432075205	C41657	5851 396385	KLAVDIYA FILATOVA	{"phone": "+70858318721"}
0005432075206	ACD5BF	3928 968536	ALEKSANDR NIKOLAEV	{"phone": "+70014086781"}
0005432075207	ACD5BF	9352 784581	SERGEY MOROZOV	{"email": "s.morozov_101967@postgrespro.ru", "phone": "+70954018418"}
0005432075208	ACD5BF	0358 064731	NIKITA PETROV	{"phone": "+70549578983"}
0005432075209	2ACF49	3084 092688	ELENA GORBUNOVA	{"phone": "+70385068658"}
0005432075210	82F284	9156 153118	OLGA VLASOVA	{"phone": "+70133391378"}
0005432075211	6B3F82	6109 047961	TAMARA DENISOVA	{"phone": "+70123105476"}
0005432075212	F4533A	7632 997762	VALENTINA SCHERBAKOVA	{"email": "scherbakova_valentina_1967@postgrespro.ru", "phone": "+70681371263"}
0005432075213	3E209A	7602 016894	YURIY SEMENOV	{"phone": "+70848605933"}
0005432075214	D5F79C	5694 804988	ELENA MARTYNOVA	{"email": "martynova-e_091968@postgrespro.ru", "phone": "+70536121923"}
0005432075215	9D8DD6	8860 637446	TATYANA MEDVEDEVA	{"phone": "+70745322127"}
0005432075216	58AEC0	6270 836564	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr1968@postgrespro.ru", "phone": "+70644375098"}
0005432075217	D31676	7162 338609	DMITRIY IVANOV	{"phone": "+70809161542"}
0005432075218	58576B	1825 558336	OLGA MARTYNOVA	{"email": "olga-martynova.111968@postgrespro.ru", "phone": "+70843437099"}
0005432075219	7DCBB8	9194 385133	EGOR GORBUNOV	{"phone": "+70419411203"}
0005432075220	7DCBB8	2953 611373	GALINA FILIPPOVA	{"email": "g-filippova_101975@postgrespro.ru", "phone": "+70420829889"}
0005432075221	368F0F	1516 036999	YANA ROMANOVA	{"phone": "+70381234064"}
0005432075222	C7D176	9416 017197	LYUBOV ZAKHAROVA	{"email": "l.zakharova07071979@postgrespro.ru", "phone": "+70931919169"}
0005432075223	E5C88C	4149 266457	OLEG IVANOV	{"phone": "+70250094442"}
0005432075224	D77412	0473 984604	YURIY KUZMIN	{"email": "kuzmin-yuriy.021975@postgrespro.ru", "phone": "+70146587752"}
0005432075225	C4E5CE	1599 305970	ALLA EGOROVA	{"email": "egorovaalla.111968@postgrespro.ru", "phone": "+70349369056"}
0005432075226	8D155B	6455 815781	NATALYA IVANOVA	{"email": "ivanovan.30031971@postgrespro.ru", "phone": "+70769462213"}
0005432075227	8D155B	3913 684629	ALEKSANDRA CHERNOVA	{"phone": "+70575392559"}
0005432075228	5D5C19	3635 918390	OKSANA KRASNOVA	{"email": "krasnova_oksana-1969@postgrespro.ru", "phone": "+70680529594"}
0005432075229	63C5F1	9834 658896	VASILIY VLASOV	{"phone": "+70543599330"}
0005432075230	4951BB	4020 248003	TATYANA POPOVA	{"email": "tatyanapopova19101974@postgrespro.ru", "phone": "+70214113986"}
0005432075231	2843C5	4148 887288	ARSENIY PAVLOV	{"email": "a.pavlov_1985@postgrespro.ru", "phone": "+70253789925"}
0005432075232	EFB8B0	4400 641916	NATALYA ERMAKOVA	{"email": "ermakova_n.1970@postgrespro.ru", "phone": "+70239983441"}
0005432075233	F3BC35	0202 327974	GALINA MIKHAYLOVA	{"email": "g-mikhaylova-1979@postgrespro.ru", "phone": "+70918952273"}
0005432075234	148B96	0899 968574	GALINA BELYAEVA	{"phone": "+70528742484"}
0005432075235	09B0E2	4470 761615	VIKTOR VASILEV	{"phone": "+70665405092"}
0005432075236	09B0E2	4520 295857	OLGA VOLKOVA	{"email": "volkova-o1967@postgrespro.ru", "phone": "+70880721646"}
0005432075237	445A0F	7875 197391	ANASTASIYA ISAEVA	{"email": "isaeva_a_15061968@postgrespro.ru", "phone": "+70353999895"}
0005432075238	47ECCA	5057 069772	VIKTOR DENISOV	{"email": "denisov_v011974@postgrespro.ru", "phone": "+70613889354"}
0005432075239	323994	6029 671913	BORIS GERASIMOV	{"email": "b_gerasimov.1979@postgrespro.ru", "phone": "+70884476507"}
0005432075240	165C05	9002 023097	OLGA TARASOVA	{"email": "tarasovaolga.061980@postgrespro.ru", "phone": "+70514811537"}
0005432075241	50DCAF	4155 417567	NIKOLAY IVANOV	{"phone": "+70815447271"}
0005432075242	1AB4AF	2358 103999	ALEKSEY DAVYDOV	{"phone": "+70598058130"}
0005432075243	0772E2	6547 073393	ALEKSANDRA SOROKINA	{"email": "sorokina-aleksandra071984@postgrespro.ru", "phone": "+70256444842"}
0005432075244	7180D3	3193 594036	RUSLAN IVANOV	{"phone": "+70003324402"}
0005432075245	5C029A	2949 529721	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr_06051981@postgrespro.ru", "phone": "+70186445596"}
0005432075246	5C029A	6207 434864	ILDAR SOROKIN	{"phone": "+70469628340"}
0005432075247	A16C30	0514 018085	VALENTINA VASILEVA	{"email": "valentina-vasileva1959@postgrespro.ru", "phone": "+70370400215"}
0005432075248	5DF293	8200 849217	SERGEY KOZLOV	{"email": "s-kozlov.1975@postgrespro.ru", "phone": "+70343791753"}
0005432075249	C091A6	1030 350253	EKATERINA ARKHIPOVA	{"email": "e-arkhipova-12101978@postgrespro.ru", "phone": "+70298533816"}
0005432075250	C461E5	6167 123082	DAVID VOROBEV	{"email": "vorobev_d.04101961@postgrespro.ru", "phone": "+70303725622"}
0005432075251	C461E5	1083 137210	EVGENIY KONOVALOV	{"email": "konovalov.evgeniy_1973@postgrespro.ru", "phone": "+70038446162"}
0005432075252	623E89	3806 693961	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena.021966@postgrespro.ru", "phone": "+70475022397"}
0005432075253	623E89	8231 661497	ALEKSANDR VASILEV	{"email": "vasilev_a_011963@postgrespro.ru", "phone": "+70080859299"}
0005432075254	EC361C	9421 893572	OLGA RODIONOVA	{"email": "rodionova.o-031973@postgrespro.ru", "phone": "+70922310328"}
0005432075255	A6F130	8519 480107	IGOR SEMENOV	{"email": "semenovi.1977@postgrespro.ru", "phone": "+70654115404"}
0005432075256	A6F130	0555 358636	VALERIY ANDREEV	{"phone": "+70768940560"}
0005432075257	2965F4	9078 468785	VLADIMIR GAVRILOV	{"phone": "+70055250249"}
0005432075258	B6CBAD	0180 438455	NINA TARASOVA	{"email": "nina_tarasova26081985@postgrespro.ru", "phone": "+70142344567"}
0005432075259	B6CBAD	9839 628159	NIKITA AFANASEV	{"email": "nafanasev.051972@postgrespro.ru", "phone": "+70379417373"}
0005432075260	535353	9088 403239	ANNA OSIPOVA	{"email": "anna.osipova1952@postgrespro.ru", "phone": "+70635366142"}
0005432075261	535353	4588 795617	SERGEY SIDOROV	{"phone": "+70812115913"}
0005432075262	0E30BD	5174 696487	ELENA MARTYNOVA	{"phone": "+70299351468"}
0005432075263	33C074	6918 794476	ALEKSANDR ANDREEV	{"email": "a-andreev_101974@postgrespro.ru", "phone": "+70483894402"}
0005432075264	33C074	5088 626935	LYUDMILA ZAYCEVA	{"phone": "+70439500221"}
0005432075265	CDFDB1	0290 005013	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov1959@postgrespro.ru", "phone": "+70278879344"}
0005432075266	CFF0A7	2026 627402	YULIYA EFIMOVA	{"phone": "+70491103171"}
0005432075267	518FE9	8352 830379	VYACHESLAV KUZMIN	{"phone": "+70887386935"}
0005432075268	518FE9	8061 058046	ALEKSANDR ZHUKOV	{"email": "a-zhukov.1984@postgrespro.ru", "phone": "+70894149490"}
0005432075269	09A253	7867 716195	LYUBOV FROLOVA	{"phone": "+70081518407"}
0005432075270	09A253	5351 345869	LIDIYA KRASNOVA	{"phone": "+70822802517"}
0005432075271	09A253	2086 453701	MIKHAIL MAKSIMOV	{"phone": "+70368914381"}
0005432075272	6454C9	1348 096561	ALEKSANDR IVANOV	{"email": "ivanova_1983@postgrespro.ru", "phone": "+70309737892"}
0005432075273	FB698A	1739 135593	DARYA KUZNECOVA	{"phone": "+70449009504"}
0005432075274	FB698A	5738 321386	IRINA KUZNECOVA	{"email": "i_kuznecova_1966@postgrespro.ru", "phone": "+70731757409"}
0005432075275	FB698A	6279 355932	ZLATA NIKIFOROVA	{"phone": "+70187434868"}
0005432075276	34E1F6	2300 063925	NADEZHDA ANTONOVA	{"phone": "+70883952666"}
0005432075277	34E1F6	9054 490669	ROMAN MATVEEV	{"email": "matveev_r_1976@postgrespro.ru", "phone": "+70219103425"}
0005432075278	34E1F6	9306 319979	MIKHAIL SOKOLOV	{"email": "sokolov.mikhail_081975@postgrespro.ru", "phone": "+70826642165"}
0005432075279	F8356E	5292 406564	ELENA NIKIFOROVA	{"phone": "+70198273186"}
0005432075280	F8356E	3949 613441	BORIS KUZNECOV	{"email": "bkuznecov-18091971@postgrespro.ru", "phone": "+70126690224"}
0005432075281	DBB380	8979 024602	NINA IVANOVA	{"email": "ivanova_nina.091972@postgrespro.ru", "phone": "+70987488450"}
0005432075282	DBB380	6724 164802	ALEKSEY KUDRYASHOV	{"phone": "+70768430635"}
0005432075283	F919A0	0633 035807	TATYANA EGOROVA	{"email": "egorova_tatyana_1969@postgrespro.ru", "phone": "+70873427333"}
0005432075284	439591	7284 052709	VIKTORIYA EFREMOVA	{"email": "viktoriyaefremova.15051980@postgrespro.ru", "phone": "+70040451292"}
0005432075285	E99FFE	9351 020587	RAVIL POPOV	{"phone": "+70211026045"}
0005432075286	2A7A82	8175 932665	VALENTINA SOKOLOVA	{"email": "valentina_sokolova091976@postgrespro.ru", "phone": "+70928853220"}
0005432075287	2A7A82	1240 707330	ELENA MARTYNOVA	{"phone": "+70680030679"}
0005432075288	0C2A43	5059 219609	TATYANA ROMANOVA	{"email": "romanova.tatyana-01011980@postgrespro.ru", "phone": "+70288522729"}
0005432075289	35779C	4654 852522	SOFYA MELNIKOVA	{"email": "melnikova.s.26101960@postgrespro.ru", "phone": "+70665639277"}
0005432075290	35779C	6575 336652	MARIYA SEMENOVA	{"email": "semenovamariya.07051965@postgrespro.ru", "phone": "+70838902428"}
0005432075291	35779C	3595 485688	EKATERINA KOZLOVA	{"phone": "+70021420064"}
0005432075292	A8B4A7	0016 304122	ANATOLIY ISAEV	{"email": "isaev-anatoliy_1977@postgrespro.ru", "phone": "+70412113370"}
0005432075293	E56019	2706 129002	ARTEM GAVRILOV	{"phone": "+70980330659"}
0005432075294	4EF0AE	1233 381701	SVETLANA AKIMOVA	{"email": "akimova.svetlana20081978@postgrespro.ru", "phone": "+70572783851"}
0005432075295	05EA9E	4730 426942	FEDOR SMIRNOV	{"email": "smirnov_f-05091976@postgrespro.ru", "phone": "+70916099190"}
0005432075296	05EA9E	7395 884414	VASILIY BELOV	{"phone": "+70768470447"}
0005432075297	E3FBD1	1090 637708	LIDIYA OSIPOVA	{"email": "osipovalidiya_01041968@postgrespro.ru", "phone": "+70120844914"}
0005432075298	E3FBD1	7281 606270	EKATERINA IVANOVA	{"email": "ekaterina-ivanova-1969@postgrespro.ru", "phone": "+70937731471"}
0005432075299	B7CB6D	9109 919552	ALEKSANDR GUSEV	{"email": "gusev-aleksandr.1981@postgrespro.ru", "phone": "+70750142095"}
0005432075300	B7BD97	3927 633922	SVYATOSLAV KOZLOV	{"phone": "+70587502737"}
0005432075301	F03ACE	3475 077310	GENNADIY DENISOV	{"email": "gennadiy-denisov-011981@postgrespro.ru", "phone": "+70808937995"}
0005432075302	F03ACE	2905 538118	ANDREY ABRAMOV	{"email": "abramovandrey_09041976@postgrespro.ru", "phone": "+70753856811"}
0005432075303	41B30A	6707 614675	POLINA SOROKINA	{"phone": "+70964927511"}
0005432075304	45C151	0214 509836	OLESYA ILINA	{"email": "ilinaolesya.1981@postgrespro.ru", "phone": "+70240191367"}
0005432075305	45C151	9060 740423	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr.1981@postgrespro.ru", "phone": "+70676335576"}
0005432075306	F0CDDA	9626 973019	KONSTANTIN KUZNECOV	{"phone": "+70953847983"}
0005432075307	54F90C	7400 357988	DAMIR SEMENOV	{"phone": "+70532821062"}
0005432075308	CC1FCA	4730 896640	VLADIMIR SEMENOV	{"phone": "+70622623182"}
0005432075309	CC1FCA	5508 168209	VERA KOLESNIKOVA	{"email": "kolesnikovavera-121961@postgrespro.ru", "phone": "+70202474384"}
0005432075310	8A49A9	0633 285330	YANA NIKIFOROVA	{"email": "yananikiforova-15041975@postgrespro.ru", "phone": "+70439553699"}
0005432075311	E3996C	6405 546750	NIKOLAY DMITRIEV	{"email": "dmitriev.n08011971@postgrespro.ru", "phone": "+70998806647"}
0005432075312	D8D35A	7401 755389	SERGEY POPOV	{"email": "popov-sergey_21051972@postgrespro.ru", "phone": "+70845923620"}
0005432075313	129392	0371 927160	LYUDMILA NESTEROVA	{"phone": "+70935906161"}
0005432075314	129392	7143 115921	LIDIYA VASILEVA	{"email": "lidiya_vasileva-04011966@postgrespro.ru", "phone": "+70552377965"}
0005432075315	8D0854	0858 059140	ALEKSANDRA SIDOROVA	{"email": "sidorovaaleksandra_1970@postgrespro.ru", "phone": "+70679242297"}
0005432075316	B60B8F	3546 565242	VENIAMIN BONDARENKO	{"phone": "+70855897557"}
0005432075317	7F32B7	9575 661478	VLADISLAV NOVIKOV	{"email": "novikov-v.021984@postgrespro.ru", "phone": "+70384482020"}
0005432075318	7F32B7	9526 288033	NATALIYA TIMOFEEVA	{"phone": "+70307558802"}
0005432075319	7F32B7	0617 441498	DANILA PETROV	{"phone": "+70897512531"}
0005432075320	1C967C	5004 519584	GENNADIY POPOV	{"email": "g.popov1974@postgrespro.ru", "phone": "+70128568526"}
0005432075321	62A840	9569 343262	NIKOLAY ZAYCEV	{"email": "zaycev-nikolay.03081969@postgrespro.ru", "phone": "+70630407943"}
0005432075322	C00414	4538 455801	ALEKSANDR KUZNECOV	{"email": "a-kuznecov081978@postgrespro.ru", "phone": "+70494826992"}
0005432075323	C00414	0535 272845	LYUBOV KUZMINA	{"phone": "+70143027681"}
0005432075324	880013	9666 119588	TATYANA GRISHINA	{"email": "grishina_tatyana_1987@postgrespro.ru", "phone": "+70470404017"}
0005432075325	7A27AD	8524 066397	SOFYA TARASOVA	{"phone": "+70351964424"}
0005432075326	F6DF5E	3733 926645	VYACHESLAV OSIPOV	{"email": "osipovvyacheslav_06051979@postgrespro.ru", "phone": "+70763654352"}
0005432075327	F6DF5E	9796 147549	IRINA VLASOVA	{"phone": "+70862989697"}
0005432075328	F6DF5E	6900 545695	OLEG SERGEEV	{"phone": "+70924939936"}
0005432075329	F6DF5E	3220 926112	LADA MAKAROVA	{"phone": "+70139736429"}
0005432075330	BBB8C8	0852 896390	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila021970@postgrespro.ru", "phone": "+70505295081"}
0005432075331	BBB8C8	4192 507011	NIKOLAY KUZNECOV	{"email": "kuznecov_n-01111977@postgrespro.ru", "phone": "+70268132703"}
0005432075332	38521B	9703 663039	ANDREY DENISOV	{"phone": "+70570672085"}
0005432078021	27F269	4991 244509	ALEKSANDR KUZMIN	{"phone": "+70789214526"}
0005432078008	6A4B00	3702 566490	ANDREY POPOV	{"email": "a-popov_021978@postgrespro.ru", "phone": "+70293190853"}
0005432078009	230405	7400 375776	DENIS MOROZOV	{"phone": "+70847331147"}
0005432078010	230405	5609 133392	OLGA IVANOVA	{"phone": "+70227109325"}
0005432078011	9EE58A	8531 874444	NIKITA TIKHONOV	{"email": "tikhonov_nikita-21121965@postgrespro.ru", "phone": "+70426943993"}
0005432078012	9EE58A	9686 063110	LYUDMILA POTAPOVA	{"email": "l-potapova_091973@postgrespro.ru", "phone": "+70097581852"}
0005432078013	865E4F	4499 589391	ELENA CHERNOVA	{"phone": "+70157541731"}
0005432078014	865E4F	2501 048351	TATYANA NIKITINA	{"phone": "+70930319518"}
0005432078015	865E4F	0988 770505	VALENTINA FEDOROVA	{"email": "v_fedorova.08101969@postgrespro.ru", "phone": "+70868800764"}
0005432078016	727888	0490 763993	ANTON EGOROV	{"email": "anton-egorov-091970@postgrespro.ru", "phone": "+70711950946"}
0005432078017	075C30	7710 591972	DMITRIY PETROV	{"email": "dmitriy_petrov-22101966@postgrespro.ru", "phone": "+70495046049"}
0005432078018	B8B3C6	6822 659174	NIKITA SOKOLOV	{"email": "sokolovn01101983@postgrespro.ru", "phone": "+70619218819"}
0005432078019	BC1394	8877 243552	NATALYA ORLOVA	{"phone": "+70965881997"}
0005432078020	BC1394	6774 758167	IVAN MELNIKOV	{"email": "melnikov-ivan.121978@postgrespro.ru", "phone": "+70272431432"}
0005432078022	27F269	4998 088606	SVETLANA FILIPPOVA	{"email": "s.filippova_1970@postgrespro.ru", "phone": "+70144193185"}
0005432078023	D5BA43	6843 981727	NAIL KUZMIN	{"email": "kuzmin-nail.15091981@postgrespro.ru", "phone": "+70289525402"}
0005432078024	D5BA43	9014 229079	NIKOLAY PAVLOV	{"phone": "+70371470219"}
0005432078025	D881D8	7312 547457	VALERIY ABRAMOV	{"email": "abramovvaleriy_06041976@postgrespro.ru", "phone": "+70019370496"}
0005432078026	F1FEA1	7262 529614	MARIYA RYABOVA	{"email": "ryabova.mariya_031956@postgrespro.ru", "phone": "+70577918278"}
0005432078027	F1FEA1	0175 462354	NINA EFIMOVA	{"email": "efimovanina_22121984@postgrespro.ru", "phone": "+70734850994"}
0005432078028	F9DC1C	8868 458945	ANGELINA GERASIMOVA	{"phone": "+70019828599"}
0005432078029	F2386D	2585 772863	MATVEY VOROBEV	{"email": "vorobev_matvey.051974@postgrespro.ru", "phone": "+70315467514"}
0005432078030	064A62	4598 573282	YANA SOKOLOVA	{"email": "y.sokolova04021977@postgrespro.ru", "phone": "+70096444088"}
0005432078031	064A62	8469 710811	ANASTASIYA GERASIMOVA	{"email": "gerasimovaa1968@postgrespro.ru", "phone": "+70457119689"}
0005432078032	5E9D60	7376 569763	VADIM ORLOV	{"phone": "+70102183311"}
0005432078033	C5F2A1	2166 645079	NATALIYA IVANOVA	{"phone": "+70439822245"}
0005432078034	C5F2A1	7327 720868	LYUBOV SEMENOVA	{"email": "lyubov_semenova_011978@postgrespro.ru", "phone": "+70587900486"}
0005432078035	861686	2384 021775	YURIY POPOV	{"phone": "+70639438385"}
0005432078036	861686	1980 565558	NADEZHDA ANISIMOVA	{"email": "anisimova-nadezhda_061974@postgrespro.ru", "phone": "+70469499701"}
0005432078037	48F9A7	4850 598859	ZLATA ZAKHAROVA	{"email": "zzakharova041963@postgrespro.ru", "phone": "+70659299118"}
0005432078038	53D5F4	2675 970581	NATALYA ALEKSANDROVA	{"phone": "+70820817557"}
0005432078039	53D5F4	1938 097408	VIKTORIYA BELOVA	{"phone": "+70160548826"}
0005432078040	2119ED	4686 072547	EKATERINA SERGEEVA	{"phone": "+70002845936"}
0005432078041	2119ED	6077 176184	LIDIYA SOKOLOVA	{"phone": "+70335040112"}
0005432078042	3FD715	6480 556851	GENNADIY MIKHAYLOV	{"phone": "+70363826735"}
0005432078043	43A835	1296 865215	VITALIY VASILEV	{"phone": "+70392440340"}
0005432078044	168532	9243 859625	ARSENIY ANTONOV	{"email": "antonov.arseniy_16031978@postgrespro.ru", "phone": "+70253800020"}
0005432078045	168532	4721 753035	ROMAN ZHURAVLEV	{"phone": "+70003701003"}
0005432078046	05FE63	1166 815906	MIKHAIL MARTYNOV	{"phone": "+70161200619"}
0005432078047	F381E5	8566 038563	MIKHAIL KUZNECOV	{"email": "m_kuznecov.15051980@postgrespro.ru", "phone": "+70098399497"}
0005432078048	039858	9675 452669	VALENTINA YAKOVLEVA	{"email": "yakovleva.valentina_031973@postgrespro.ru", "phone": "+70435786559"}
0005432078049	413835	9264 450514	EVGENIY PETROV	{"phone": "+70404117221"}
0005432078050	86EC89	9937 764526	DENIS EGOROV	{"phone": "+70473789161"}
0005432078051	3149B0	2244 991486	YURIY BORISOV	{"email": "y.borisov-071978@postgrespro.ru", "phone": "+70435694603"}
0005432078052	192BDA	8160 939710	IVAN SEMENOV	{"phone": "+70999222063"}
0005432078053	271C84	3828 351149	DMITRIY MATVEEV	{"email": "matveevdmitriy1972@postgrespro.ru", "phone": "+70661144525"}
0005432078054	95B06D	7983 153779	MARIYA MIRONOVA	{"phone": "+70560895528"}
0005432078055	95B06D	5082 166110	YULIYA BELYAEVA	{"email": "yuliya.belyaeva-05081976@postgrespro.ru", "phone": "+70619777997"}
0005432078056	3927B4	9650 131114	MIKHAIL DAVYDOV	{"email": "davydovmikhail_1968@postgrespro.ru", "phone": "+70734386757"}
0005432078057	3927B4	1600 605741	ALEVTINA NESTEROVA	{"phone": "+70096796144"}
0005432078058	C50A85	4752 820360	IVAN MIRONOV	{"email": "i_mironov_101969@postgrespro.ru", "phone": "+70857188834"}
0005432078059	731221	3352 245859	VALENTINA NAZAROVA	{"phone": "+70243985898"}
0005432078060	D07410	2435 668167	IRINA KUZNECOVA	{"email": "kuznecova-irina_121978@postgrespro.ru", "phone": "+70994153542"}
0005432078061	3C711D	0130 980657	MAKSIM NIKOLAEV	{"phone": "+70599934727"}
0005432078062	3C711D	8105 770875	OLGA DMITRIEVA	{"phone": "+70623902287"}
0005432078063	3C711D	6972 301650	MARINA ALEKSEEVA	{"phone": "+70958930734"}
0005432078064	4262E4	7782 732461	VALERIY EGOROV	{"email": "valeriy-egorov-051973@postgrespro.ru", "phone": "+70973858718"}
0005432078065	D9405F	0657 652727	ALFIYA MOROZOVA	{"phone": "+70044792590"}
0005432078066	D9EEB2	3517 739937	ANDREY IVANOV	{"email": "a_ivanov.1973@postgrespro.ru", "phone": "+70945704072"}
0005432078067	D0D667	8976 298774	NIKOLAY STEPANOV	{"email": "stepanov_n-19081957@postgrespro.ru", "phone": "+70269640496"}
0005432078068	879D76	3463 363994	LIDIYA SOKOLOVA	{"email": "lidiyasokolova_1970@postgrespro.ru", "phone": "+70816722802"}
0005432078069	879D76	9273 462985	ELIZAVETA FEDOROVA	{"email": "fedorovaelizaveta.111977@postgrespro.ru", "phone": "+70450692267"}
0005432078070	E5C240	5923 497359	IGOR POPOV	{"phone": "+70151321410"}
0005432078071	290AA2	1108 431812	ARINA MOROZOVA	{"email": "morozova-a_13061977@postgrespro.ru", "phone": "+70946012810"}
0005432078133	E07AAB	8169 021873	ALEKSANDRA KARPOVA	{"phone": "+70152799600"}
0005432078072	2BDF23	7904 725373	TATYANA MARTYNOVA	{"email": "tatyana-martynova031965@postgrespro.ru", "phone": "+70180142619"}
0005432078073	0DEDFD	9796 590613	STANISLAV DAVYDOV	{"phone": "+70470370622"}
0005432078074	5774EA	9297 998022	MARIYA IVANOVA	{"email": "m.ivanova23061964@postgrespro.ru", "phone": "+70691407584"}
0005432078075	5774EA	5877 960306	ALEKSANDR NIKITIN	{"phone": "+70369764720"}
0005432078076	5774EA	2168 493304	ALEKSANDR GORBUNOV	{"email": "gorbunov_aleksandr_1965@postgrespro.ru", "phone": "+70490757501"}
0005432078077	9776F5	0247 400850	MARIYA KOZLOVA	{"email": "kozlova_mariya101962@postgrespro.ru", "phone": "+70514437568"}
0005432078078	F895D3	5717 525074	MARIYA ANTONOVA	{"email": "antonova.mariya1975@postgrespro.ru", "phone": "+70300975550"}
0005432078079	F895D3	7570 801326	ILYA KULIKOV	{"email": "kulikov-i.081970@postgrespro.ru", "phone": "+70777064974"}
0005432078080	3893F4	4632 595503	ALEKSEY KUZNECOV	{"email": "kuznecov.a.121967@postgrespro.ru", "phone": "+70002836067"}
0005432078081	A7B908	5846 460504	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov_17081978@postgrespro.ru", "phone": "+70964307495"}
0005432078082	1752E6	3531 987587	ALEKSANDRA GAVRILOVA	{"phone": "+70551309365"}
0005432078083	AEC23E	9479 028697	IGOR IVANOV	{"phone": "+70590274570"}
0005432078084	AEC23E	4292 390367	VLADISLAV ANTONOV	{"email": "vladislav.antonov27121972@postgrespro.ru", "phone": "+70628461377"}
0005432078085	6A9D72	6688 160876	VALENTINA ANTONOVA	{"email": "vantonova-27031979@postgrespro.ru", "phone": "+70554762083"}
0005432078086	F1871B	0322 747009	ARTEM FOMIN	{"phone": "+70318708892"}
0005432078087	A1C282	9177 195247	MAKSIM SIDOROV	{"email": "sidorovmaksim-091968@postgrespro.ru", "phone": "+70042778515"}
0005432078088	A1C282	3609 363789	VADIM TIKHONOV	{"email": "v-tikhonov26101980@postgrespro.ru", "phone": "+70465667209"}
0005432078089	D4901C	7637 338531	SERGEY CHERNOV	{"phone": "+70428592509"}
0005432078090	5A49FC	7417 940253	ALEKSEY NIKITIN	{"phone": "+70593991900"}
0005432078091	2B87AA	4275 334963	VALERIYA ZAKHAROVA	{"phone": "+70907968400"}
0005432078092	8D8DCA	9961 468713	RAMIL BORISOV	{"phone": "+70418118969"}
0005432078093	770336	4018 267299	DMITRIY KUDRYASHOV	{"email": "dmitriy_kudryashov-081967@postgrespro.ru", "phone": "+70521930491"}
0005432078094	2C53D8	9660 782517	SVETLANA FROLOVA	{"phone": "+70222727258"}
0005432078095	2C53D8	9433 655283	GALINA STEPANOVA	{"phone": "+70743742539"}
0005432078096	2C53D8	0988 716894	VERA ALEKSEEVA	{"phone": "+70027365579"}
0005432078097	76F055	2167 323444	GENNADIY DENISOV	{"email": "gennadiy.denisov031980@postgrespro.ru", "phone": "+70001886282"}
0005432078098	76F055	3163 481720	VLADIMIR IVANOV	{"email": "ivanov.vladimir.11011971@postgrespro.ru", "phone": "+70039507546"}
0005432078099	19F78C	9305 080320	VALENTINA MOROZOVA	{"email": "morozova_valentina_031971@postgrespro.ru", "phone": "+70867410954"}
0005432078100	19F78C	7141 879918	ANDREY SEMENOV	{"email": "asemenov-15041980@postgrespro.ru", "phone": "+70566046233"}
0005432078101	C62FCF	1875 509182	STANISLAV ZHUKOV	{"phone": "+70440254042"}
0005432078102	0F98E5	3192 688072	DENIS NIKOLAEV	{"phone": "+70928494086"}
0005432078103	607005	3254 933572	RUZALIYA KISELEVA	{"phone": "+70106021872"}
0005432078104	C9ADB1	4066 955232	ALEKSANDR TARASOV	{"phone": "+70764386206"}
0005432078105	C9ADB1	7310 153283	ALEKSEY SOLOVEV	{"email": "soloveva-071971@postgrespro.ru", "phone": "+70740452407"}
0005432078106	8FE664	4262 550862	VALENTINA SERGEEVA	{"email": "sergeeva-valentina19031978@postgrespro.ru", "phone": "+70111475732"}
0005432078107	3A6644	8026 216775	ELENA MIKHAYLOVA	{"phone": "+70246214065"}
0005432078108	3A6644	7758 203138	NATALYA VOLKOVA	{"phone": "+70082749969"}
0005432078109	3A6644	3649 472322	OLGA VASILEVA	{"phone": "+70742421837"}
0005432078110	5950CF	8315 621397	ALIYA MOISEEVA	{"email": "moiseeva_a-13061973@postgrespro.ru", "phone": "+70812914128"}
0005432078111	5950CF	4466 170531	DENIS VLASOV	{"email": "vlasov-d.22041975@postgrespro.ru", "phone": "+70986922075"}
0005432078112	5950CF	8543 747544	VITALIY SERGEEV	{"phone": "+70910435462"}
0005432078113	F474F2	1052 140842	YAROSLAV MATVEEV	{"phone": "+70205487567"}
0005432078114	F474F2	2066 846722	SVETLANA ORLOVA	{"email": "svetlana.orlova1983@postgrespro.ru", "phone": "+70059960965"}
0005432078115	D7CAF3	2956 370587	GALINA KUZNECOVA	{"email": "kuznecova_g-121967@postgrespro.ru", "phone": "+70839728548"}
0005432078116	DEE230	4937 334120	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov10111974@postgrespro.ru", "phone": "+70129453337"}
0005432078117	B55600	6999 697135	TATYANA FROLOVA	{"phone": "+70408270375"}
0005432078118	B55600	5623 315073	OLEG NIKOLAEV	{"phone": "+70487230110"}
0005432078119	8EB8F8	7034 048291	EVGENIY KOZLOV	{"phone": "+70357213667"}
0005432078120	8EB8F8	4667 885695	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr-18081962@postgrespro.ru", "phone": "+70686259100"}
0005432078121	0F790D	5604 669293	MILANA EFREMOVA	{"phone": "+70895953408"}
0005432078122	0F790D	6694 728183	MAKSIM MAKSIMOV	{"phone": "+70865627666"}
0005432078123	67A4C0	9563 173752	ELENA GERASIMOVA	{"email": "e-gerasimova.051973@postgrespro.ru", "phone": "+70485423216"}
0005432078124	67A4C0	0862 777499	ZINAIDA FROLOVA	{"phone": "+70471661522"}
0005432078125	1D338E	7916 479689	KIRILL PETROV	{"email": "kirill_petrov-23111979@postgrespro.ru", "phone": "+70172524356"}
0005432078126	1D338E	4551 606745	LILIYA KOMAROVA	{"phone": "+70503393322"}
0005432078127	B7DD84	3073 468695	VASILIY MAKAROV	{"email": "makarov-vasiliy_1978@postgrespro.ru", "phone": "+70709128652"}
0005432078128	7AB3FB	5591 728411	LEONID DENISOV	{"phone": "+70711586782"}
0005432078129	461005	6248 212071	ANASTASIYA KOROLEVA	{"email": "koroleva_a1981@postgrespro.ru", "phone": "+70350801069"}
0005432078130	CBA123	8692 596360	DAVID KUZNECOV	{"phone": "+70015907470"}
0005432078131	CBA123	2222 769658	SERGEY SOLOVEV	{"phone": "+70507655237"}
0005432078132	43BC44	8527 295159	VIKTORIYA ABRAMOVA	{"phone": "+70037457440"}
0005432078134	E07AAB	9624 447552	MARINA LAZAREVA	{"phone": "+70228373879"}
0005432078135	B9554D	9845 914468	ANATOLIY VOROBEV	{"email": "vorobev_a.28061979@postgrespro.ru", "phone": "+70064251451"}
0005432078136	B9554D	0485 086211	TATYANA KUZMINA	{"phone": "+70894583419"}
0005432078137	1C543F	7898 967494	NIKITA SEMENOV	{"email": "semenov.n17031977@postgrespro.ru", "phone": "+70233421317"}
0005432078138	2A882E	3404 176048	ELENA ORLOVA	{"phone": "+70083549473"}
0005432078139	5F8432	0365 988475	VLADIMIR GAVRILOV	{"phone": "+70021360914"}
0005432078140	5F8432	7421 514759	PAVEL NOVIKOV	{"email": "pavel.novikov.111969@postgrespro.ru", "phone": "+70618600283"}
0005432078141	D6E620	7788 810657	SERGEY NIKOLAEV	{"phone": "+70820084295"}
0005432078142	1CA6BE	4685 596706	GALINA FROLOVA	{"email": "frolova-galina.1978@postgrespro.ru", "phone": "+70084804522"}
0005432078143	574C78	3254 919845	ANGELINA DENISOVA	{"phone": "+70100838867"}
0005432078144	CACED2	0464 438655	DMITRIY YAKOVLEV	{"email": "dmitriy.yakovlev.22021963@postgrespro.ru", "phone": "+70710917004"}
0005432078145	CACED2	5625 867205	ALEKSEY SOKOLOV	{"phone": "+70320095780"}
0005432078146	389813	4547 324477	MARIYA KOROLEVA	{"phone": "+70784496579"}
0005432078147	389813	3500 897256	YULIYA POTAPOVA	{"phone": "+70615904002"}
0005432078148	F727F2	2395 196305	VYACHESLAV GERASIMOV	{"phone": "+70594873136"}
0005432078149	1E0A36	8628 235710	ROMAN TARASOV	{"phone": "+70891122968"}
0005432078150	1E0A36	7716 461239	OLGA BORISOVA	{"phone": "+70079426845"}
0005432078151	E30AAA	1977 001723	TIMUR KUDRYASHOV	{"phone": "+70152943142"}
0005432078152	0FB2DC	6034 921811	ANDREY SOKOLOV	{"phone": "+70054600657"}
0005432078153	4AEACC	9458 515382	LYUBOV TROFIMOVA	{"phone": "+70744263702"}
0005432078154	4AEACC	7182 494990	TATYANA GORBUNOVA	{"email": "gorbunovat-09111958@postgrespro.ru", "phone": "+70291329328"}
0005432078155	C98571	0547 861504	MATVEY MOROZOV	{"email": "morozov.matvey_091979@postgrespro.ru", "phone": "+70851065937"}
0005432078156	C98571	4566 371730	NATALIYA KUZNECOVA	{"email": "nataliya.kuznecova-17071979@postgrespro.ru", "phone": "+70238771133"}
0005432078157	1428EB	8064 086272	TATYANA KUZNECOVA	{"email": "kuznecova.t_15091974@postgrespro.ru", "phone": "+70230398662"}
0005432078158	97A8C3	4501 138912	ANNA EFIMOVA	{"email": "anna.efimova_071977@postgrespro.ru", "phone": "+70229725907"}
0005432078159	15C8F9	3117 998852	IRINA ISAEVA	{"email": "isaeva-i.071985@postgrespro.ru", "phone": "+70199021368"}
0005432078160	6F7C3B	3349 533212	VASILIY SAVELEV	{"phone": "+70767195993"}
0005432078161	1EFE08	8596 699639	NIKITA NOVIKOV	{"phone": "+70701078974"}
0005432078162	1EFE08	8532 137257	IVAN BORISOV	{"phone": "+70166916451"}
0005432078163	2EE1D9	7685 785313	OLGA STEPANOVA	{"email": "o.stepanova_011970@postgrespro.ru", "phone": "+70788245365"}
0005432078164	2EE1D9	6045 912839	ALEKSEY FOMIN	{"email": "afomin011968@postgrespro.ru", "phone": "+70252715468"}
0005432078165	9E730E	5978 369461	ANDREY PAVLOV	{"phone": "+70553431102"}
0005432078166	9E730E	5937 087739	MIKHAIL ORLOV	{"phone": "+70140918493"}
0005432078167	E3126C	0173 106750	YULIYA SCHERBAKOVA	{"phone": "+70536839864"}
0005432078168	94F150	9306 904729	GALINA SOROKINA	{"email": "galina-sorokina.1975@postgrespro.ru", "phone": "+70301932972"}
0005432078169	44A0B9	7894 297524	SVETLANA ILINA	{"phone": "+70194954776"}
0005432078170	4F666E	6018 538662	RADIK IVANOV	{"email": "radikivanov_10031975@postgrespro.ru", "phone": "+70955259870"}
0005432078171	732EBB	2104 800880	SERGEY SOKOLOV	{"email": "s_sokolov_29041967@postgrespro.ru", "phone": "+70342184683"}
0005432078172	25D7D7	7141 255487	YURIY FOMIN	{"phone": "+70654359226"}
0005432078173	0E8D7B	7884 203119	TAMARA TIKHONOVA	{"email": "tamara-tikhonova-10061978@postgrespro.ru", "phone": "+70218495930"}
0005432078174	0E8D7B	9486 264476	TIMOFEY EGOROV	{"email": "egorov-timofey.1977@postgrespro.ru", "phone": "+70575936508"}
0005432078175	C60783	3525 227520	DMITRIY MEDVEDEV	{"phone": "+70534213193"}
0005432078176	6C6C51	5200 200184	ALEKSANDRA OSIPOVA	{"phone": "+70402035758"}
0005432078177	6C6C51	1365 134942	EVGENIYA VLASOVA	{"phone": "+70967065314"}
0005432078178	57B03C	4133 630351	ANTONINA IVANOVA	{"phone": "+70277490966"}
0005432078179	171D3E	9346 777679	ANDREY ANDREEV	{"email": "andreevandrey.061971@postgrespro.ru", "phone": "+70991111262"}
0005432078180	171D3E	2570 268571	IGOR SOLOVEV	{"email": "solovev.i.01121980@postgrespro.ru", "phone": "+70274473721"}
0005432078181	6D4588	4631 027841	SERGEY KUZMIN	{"email": "kuzmin_sergey1975@postgrespro.ru", "phone": "+70807989376"}
0005432078182	58F3A6	5290 059841	VLADIMIR KONOVALOV	{"phone": "+70330542535"}
0005432078183	83142F	0082 678907	POLINA LUKYANOVA	{"phone": "+70998359328"}
0005432078184	AA957F	4928 679904	ALEKSEY YAKOVLEV	{"email": "ayakovlev_061984@postgrespro.ru", "phone": "+70119411238"}
0005432078185	22F47C	4913 683844	DMITRIY CHERNOV	{"email": "d-chernov-091979@postgrespro.ru", "phone": "+70376532909"}
0005432078186	4C4A11	0816 417283	TATYANA LUKYANOVA	{"email": "lukyanova_tatyana.1976@postgrespro.ru", "phone": "+70920506238"}
0005432078187	51C8DD	0882 865708	ANTON DENISOV	{"email": "denisov.a-10011970@postgrespro.ru", "phone": "+70375383569"}
0005432078188	51C8DD	7806 817747	VLADIMIR ANDREEV	{"email": "vandreev_25081965@postgrespro.ru", "phone": "+70736783746"}
0005432078189	989B59	7081 220923	VIKTOR ISAEV	{"email": "isaev.viktor-071968@postgrespro.ru", "phone": "+70138924356"}
0005432078190	8691AB	5534 613407	KONSTANTIN ANDREEV	{"email": "andreev.konstantin-1970@postgrespro.ru", "phone": "+70519270934"}
0005432078191	E197DB	0751 392502	IVAN VASILEV	{"email": "vasilev.i.1973@postgrespro.ru", "phone": "+70631337133"}
0005432078192	BC00E4	9499 735134	NATALYA FOMINA	{"email": "fomina.n.011970@postgrespro.ru", "phone": "+70293442853"}
0005432078193	1506F5	5456 861462	STANISLAV MEDVEDEV	{"email": "stanislav_medvedev-1968@postgrespro.ru", "phone": "+70791700967"}
0005432078194	55977F	4433 839947	VLADIMIR RODIONOV	{"phone": "+70890486189"}
0005432078195	55977F	7934 841631	MARTA BORISOVA	{"phone": "+70686679201"}
0005432078196	23F606	8375 816894	LIDIYA ZAYCEVA	{"phone": "+70084740119"}
0005432078197	23F606	6270 493313	IRINA ROMANOVA	{"email": "i_romanova.121975@postgrespro.ru", "phone": "+70104402197"}
0005432078198	75F08F	7527 329604	ANDREY SMIRNOV	{"email": "andrey.smirnov-19081969@postgrespro.ru", "phone": "+70851650614"}
0005432078199	61917E	7935 457246	ELENA BORISOVA	{"email": "borisova.elena_1960@postgrespro.ru", "phone": "+70790965411"}
0005432078200	6ED946	8791 750257	ILYA NOVIKOV	{"email": "i-novikov_011972@postgrespro.ru", "phone": "+70749527693"}
0005432078201	6ED946	2950 876204	TATYANA BARANOVA	{"phone": "+70087579281"}
0005432078202	25906A	3006 608612	NATALYA SOKOLOVA	{"phone": "+70023172592"}
0005432078203	A3A718	0052 454888	VALENTINA ZOTOVA	{"phone": "+70997941919"}
0005432078204	DF72A8	8394 454367	NIKOLAY ALEKSANDROV	{"phone": "+70157539146"}
0005432078205	6E64DC	1616 990629	VERONIKA ZAKHAROVA	{"email": "veronika_zakharova.1979@postgrespro.ru", "phone": "+70681047367"}
0005432078206	6E64DC	7141 977770	KSENIYA SOROKINA	{"phone": "+70014786053"}
0005432078207	A11D9A	6480 617116	DMITRIY MIKHAYLOV	{"phone": "+70536897757"}
0005432078208	5BF7DB	1385 656080	NIKOLAY MAKSIMOV	{"email": "nikolay.maksimov.091970@postgrespro.ru", "phone": "+70583328572"}
0005432078209	38EFA6	2050 545613	ELENA MALYSHEVA	{"phone": "+70647293622"}
0005432078210	2F1F24	0036 695876	NADEZHDA ROMANOVA	{"phone": "+70829368413"}
0005432078211	34F95D	7705 028750	MIKHAIL KUZNECOV	{"phone": "+70401487260"}
0005432078212	1A2EEC	9114 585091	TAMARA NESTEROVA	{"phone": "+70389176976"}
0005432078213	4A01F8	7629 243171	OLEG ZAKHAROV	{"email": "zakharovoleg.1978@postgrespro.ru", "phone": "+70231528730"}
0005432078214	321CBA	9599 667286	OLGA KUZMINA	{"phone": "+70356241389"}
0005432078215	D2E72D	0633 812350	VLADA EGOROVA	{"email": "egorovav.20061977@postgrespro.ru", "phone": "+70658401045"}
0005432078216	127331	3239 326223	ALEKSANDR IVANOV	{"phone": "+70706285606"}
0005432078217	0E62C7	3249 113210	RAVIL MOISEEV	{"email": "moiseev_ravil.101974@postgrespro.ru", "phone": "+70786710116"}
0005432078218	86E092	2052 900259	INNA KISELEVA	{"email": "innakiseleva-07041968@postgrespro.ru", "phone": "+70033190226"}
0005432078219	129696	1988 523724	KSENIYA NAZAROVA	{"phone": "+70199674489"}
0005432078220	306FD5	6220 773090	MIKHAIL ALEKSEEV	{"email": "mikhail.alekseev.061972@postgrespro.ru", "phone": "+70406845276"}
0005432078221	306FD5	6782 667458	PETR SOKOLOV	{"email": "sokolovp_1972@postgrespro.ru", "phone": "+70133088925"}
0005432078222	306FD5	7025 318350	MARIYA TITOVA	{"phone": "+70699920017"}
0005432078223	4246E9	4781 546302	RAMIL DENISOV	{"email": "r-denisov.12051971@postgrespro.ru", "phone": "+70892741954"}
0005432078224	6F6DEE	6026 128942	TAMARA KONDRATEVA	{"email": "kondrateva.tamara-031979@postgrespro.ru", "phone": "+70969801136"}
0005432078225	6F6DEE	0717 317677	ALBINA SEMENOVA	{"email": "albinasemenova_1997@postgrespro.ru", "phone": "+70839651812"}
0005432078226	ED678A	7382 863892	NATALYA ANDREEVA	{"email": "nandreeva28101976@postgrespro.ru", "phone": "+70267403608"}
0005432078227	ED678A	2281 426017	ARTEM KONOVALOV	{"email": "a.konovalov_30071967@postgrespro.ru", "phone": "+70350806564"}
0005432078228	0609E0	9987 141620	SERGEY KONOVALOV	{"phone": "+70401297364"}
0005432078229	BDAE56	6418 772983	TAMARA KULIKOVA	{"phone": "+70518430347"}
0005432078230	C6D539	6776 712539	EGOR ANDREEV	{"phone": "+70548096364"}
0005432078231	2BF7EA	9026 431859	NADEZHDA ANDREEVA	{"email": "n.andreeva-30111962@postgrespro.ru", "phone": "+70434227645"}
0005432078232	2BF7EA	9518 860103	ELENA KUZNECOVA	{"email": "kuznecova.elena011979@postgrespro.ru", "phone": "+70236184661"}
0005432078233	C882E2	3825 143376	VERA KUZNECOVA	{"phone": "+70247356090"}
0005432078234	C882E2	3402 313343	ANNA KOLESNIKOVA	{"email": "kolesnikova-anna.1978@postgrespro.ru", "phone": "+70277810242"}
0005432078235	EE1061	8414 421379	ANDREY KRASNOV	{"email": "krasnovandrey011974@postgrespro.ru", "phone": "+70945725609"}
0005432078236	EE1061	1651 802806	OLGA VOROBEVA	{"phone": "+70461245610"}
0005432078237	EE1061	2721 217833	KIRILL FILIPPOV	{"phone": "+70391724258"}
0005432078238	EAC18B	2429 804151	ANASTASIYA ZAYCEVA	{"email": "zayceva-anastasiya_1971@postgrespro.ru", "phone": "+70192206067"}
0005432078239	750E71	7078 978232	SERGEY FEDOROV	{"phone": "+70996533295"}
0005432078240	750E71	3137 334631	ALEKSEY PETROV	{"email": "a_petrov_1960@postgrespro.ru", "phone": "+70750481887"}
0005432078241	17EA13	6577 400027	STEPAN VASILEV	{"phone": "+70786082292"}
0005432078242	17EA13	4691 547352	DANIIL MEDVEDEV	{"phone": "+70950654893"}
0005432078243	17EA13	2133 130937	NIKOLAY FROLOV	{"email": "frolovn.031970@postgrespro.ru", "phone": "+70072117548"}
0005432078244	155B62	1081 598346	OLGA TROFIMOVA	{"email": "o.trofimova.111965@postgrespro.ru", "phone": "+70021666883"}
0005432078245	6F551E	9823 248996	TATYANA VOLKOVA	{"phone": "+70030324576"}
0005432078246	A56C24	5029 160549	YURIY POPOV	{"phone": "+70736821658"}
0005432078247	18CF63	3319 307472	DMITRIY KOZLOV	{"email": "kozlov-d-28101984@postgrespro.ru", "phone": "+70978718139"}
0005432078248	7EEACE	2038 497489	NADEZHDA POTAPOVA	{"email": "potapova.nadezhda_041966@postgrespro.ru", "phone": "+70575806882"}
0005432078249	CC1AC8	2701 197093	MAKSIM IVANOV	{"email": "maksim-ivanov02021967@postgrespro.ru", "phone": "+70596901429"}
0005432078250	B3F628	5602 450486	ALEKSANDR SCHERBAKOV	{"phone": "+70381371898"}
0005432078251	713CCE	4719 689451	ILYA CHERNOV	{"phone": "+70967681088"}
0005432078252	713CCE	3739 889015	ALEKSEY CHERNOV	{"email": "chernov_a.27081970@postgrespro.ru", "phone": "+70934015011"}
0005432078253	7DF6B9	5695 874391	ANDREY DAVYDOV	{"email": "davydov_a-061972@postgrespro.ru", "phone": "+70023832032"}
0005432078254	389BE0	0647 670703	PAVEL BORISOV	{"phone": "+70292218142"}
0005432078255	FBF7F2	8592 235878	VIKTOR KUZNECOV	{"phone": "+70455354287"}
0005432078256	332F17	9715 422269	VLADIMIR VLASOV	{"email": "vlasov.vladimir011956@postgrespro.ru", "phone": "+70088528515"}
0005432078257	332F17	6848 325311	RIMMA MEDVEDEVA	{"email": "medvedeva.rimma121965@postgrespro.ru", "phone": "+70506059118"}
0005432078258	F48438	3666 379801	TAMARA YAKOVLEVA	{"email": "tamara.yakovleva02041977@postgrespro.ru", "phone": "+70403596208"}
0005432078259	F48438	7473 776851	ARTEM SHEVCHENKO	{"email": "a-shevchenko_06111969@postgrespro.ru", "phone": "+70097510888"}
0005432078260	4D24E6	9441 702736	VALENTIN SERGEEV	{"phone": "+70924748536"}
0005432078261	4D24E6	4656 516796	ZLATA DANILOVA	{"phone": "+70378304031"}
0005432078262	0C0376	0325 916698	YANA TIMOFEEVA	{"email": "timofeeva-y.08111973@postgrespro.ru", "phone": "+70639800930"}
0005432078263	62D123	5435 698458	YULIYA NAZAROVA	{"phone": "+70476734355"}
0005432078264	8376C0	6739 954715	VYACHESLAV TARASOV	{"email": "v.tarasov101972@postgrespro.ru", "phone": "+70829955497"}
0005432078265	349266	8651 020367	VALERIY SOKOLOV	{"email": "vsokolov071975@postgrespro.ru", "phone": "+70494842499"}
0005432078266	349266	9373 324045	VIKTORIYA IVANOVA	{"email": "viktoriya.ivanova_031984@postgrespro.ru", "phone": "+70228780219"}
0005432078267	79F198	8837 733237	ANASTASIYA KULIKOVA	{"phone": "+70869125393"}
0005432078268	62C7FA	5309 994782	MIKHAIL ILIN	{"email": "ilin-mikhail_1977@postgrespro.ru", "phone": "+70016689601"}
0005432078269	62C7FA	7059 907901	IRINA ORLOVA	{"email": "i_orlova091976@postgrespro.ru", "phone": "+70500473605"}
0005432078270	62C7FA	1519 997646	NATALYA DAVYDOVA	{"phone": "+70467918340"}
0005432078271	62C7FA	5631 491274	VLADISLAV PETROV	{"phone": "+70196693102"}
0005432081541	87B377	6689 605973	SERGEY SCHERBAKOV	{"phone": "+70762359940"}
0005432081393	F9C673	1234 335174	ANNA FROLOVA	{"email": "anna-frolova_1972@postgrespro.ru", "phone": "+70982422583"}
0005432081394	54FA3B	6688 751180	FEDOR NIKITIN	{"email": "fnikitin_1972@postgrespro.ru", "phone": "+70964173558"}
0005432081395	792AEE	4523 171744	SERGEY SOKOLOV	{"email": "sokolovs-1972@postgrespro.ru", "phone": "+70158001817"}
0005432081396	792AEE	1699 470234	ELENA SMIRNOVA	{"email": "e.smirnova1976@postgrespro.ru", "phone": "+70808926647"}
0005432081397	7A5C79	1677 354474	VALENTINA KISELEVA	{"phone": "+70909070505"}
0005432081398	96EF55	3831 711035	ANNA ILINA	{"email": "a_ilina-29071972@postgrespro.ru", "phone": "+70957136061"}
0005432081399	E143BD	6974 365677	MIKHAIL KUZNECOV	{"email": "m-kuznecov-1981@postgrespro.ru", "phone": "+70998642984"}
0005432081400	E143BD	4682 247481	SVETLANA SMIRNOVA	{"email": "s-smirnova1971@postgrespro.ru", "phone": "+70866773868"}
0005432081401	225C7E	6810 099169	ANASTASIYA NIKOLAEVA	{"email": "a-nikolaeva_1981@postgrespro.ru", "phone": "+70404099928"}
0005432081402	77302F	3985 852352	RUSLAN VOLKOV	{"email": "volkovruslan.07051967@postgrespro.ru", "phone": "+70389798725"}
0005432081403	77302F	7866 668946	IRINA KONOVALOVA	{"phone": "+70980516443"}
0005432081404	77302F	6870 870973	SERGEY KUZMIN	{"phone": "+70245733469"}
0005432081405	77302F	9430 646806	SERGEY ZHUKOV	{"email": "zhukov-s111976@postgrespro.ru", "phone": "+70895937086"}
0005432081406	77302F	6914 547365	VLADIMIR ROMANOV	{"email": "vladimir_romanov-03061963@postgrespro.ru", "phone": "+70693404466"}
0005432081407	0BA3D8	8719 965369	KONSTANTIN GUSEV	{"email": "konstantin_gusev.111984@postgrespro.ru", "phone": "+70020389751"}
0005432081408	0BA3D8	2469 803236	ANDREY POPOV	{"phone": "+70112515976"}
0005432081409	61AD4A	7143 162548	ARTEM VOROBEV	{"email": "vorobev-a.1980@postgrespro.ru", "phone": "+70247179808"}
0005432081410	CA18A3	8052 944929	SVETLANA MELNIKOVA	{"phone": "+70149388302"}
0005432081411	347BD7	0815 735788	EKATERINA KISELEVA	{"email": "kiseleva-e18101976@postgrespro.ru", "phone": "+70572259685"}
0005432081412	EE4B17	8640 543419	EKATERINA MASLOVA	{"email": "maslova.e.091970@postgrespro.ru", "phone": "+70594385660"}
0005432081413	EE4B17	9354 129579	NATALYA KUZNECOVA	{"email": "natalya-kuznecova.20031981@postgrespro.ru", "phone": "+70197316867"}
0005432081414	1D7BC7	9424 726850	DMITRIY SOROKIN	{"email": "sorokin-d-111973@postgrespro.ru", "phone": "+70862184297"}
0005432081415	C4A04D	2386 237645	MARIYA TARASOVA	{"email": "mtarasova08061980@postgrespro.ru", "phone": "+70307724224"}
0005432081416	17A03D	0538 540957	MIKHAIL ILIN	{"email": "ilin-mikhail1971@postgrespro.ru", "phone": "+70773874239"}
0005432081417	17A03D	2931 691464	MARINA MASLOVA	{"phone": "+70785686225"}
0005432081418	76853C	1729 888951	TATYANA BORISOVA	{"email": "t.borisova-09091956@postgrespro.ru", "phone": "+70329164405"}
0005432081419	E56B1C	6161 632222	YULIYA PAVLOVA	{"phone": "+70612050713"}
0005432081420	E56B1C	1614 101127	TATYANA POTAPOVA	{"phone": "+70710031288"}
0005432081421	E56B1C	0967 195431	DARYA DENISOVA	{"phone": "+70980051730"}
0005432081422	E56B1C	6225 382431	IVAN IVANOV	{"phone": "+70840384537"}
0005432081423	461A13	1888 730211	IRINA GAVRILOVA	{"phone": "+70306563762"}
0005432081424	461A13	2304 073051	VLADIMIR TIMOFEEV	{"email": "v_timofeev24031963@postgrespro.ru", "phone": "+70818715028"}
0005432081425	D8C70B	4199 630979	DMITRIY KONOVALOV	{"email": "konovalov.dmitriy_021976@postgrespro.ru", "phone": "+70432766250"}
0005432081426	07D388	8556 236662	VLADIMIR KOZLOV	{"phone": "+70809759524"}
0005432081427	07D388	5836 658202	ALINA IVANOVA	{"phone": "+70390790472"}
0005432081428	999420	7444 735115	NATALYA NIKOLAEVA	{"email": "nikolaeva.n-011973@postgrespro.ru", "phone": "+70074257261"}
0005432081429	999420	9702 925958	RAISA MAKAROVA	{"email": "makarova_raisa.121971@postgrespro.ru", "phone": "+70747671309"}
0005432081430	942BEF	5229 885595	DMITRIY FEDOROV	{"phone": "+70432245528"}
0005432081431	F5E8F4	9926 085881	MARTA RODIONOVA	{"phone": "+70318847087"}
0005432081432	BEA5F0	7937 586428	PAVEL BARANOV	{"email": "pavel_baranov_1976@postgrespro.ru", "phone": "+70941527093"}
0005432081433	8760C4	4326 120597	NIKOLAY DENISOV	{"phone": "+70035448955"}
0005432081434	91A4F2	5315 288610	MARIYA OVCHINNIKOVA	{"phone": "+70548115673"}
0005432081435	37D45C	6358 308920	ANASTASIYA EGOROVA	{"email": "egorova_a-03091976@postgrespro.ru", "phone": "+70016478030"}
0005432081436	5960A5	2078 776487	OLGA ANISIMOVA	{"phone": "+70561871252"}
0005432081437	51E495	8532 921985	SERGEY FEDOROV	{"email": "fedorov.sergey-081977@postgrespro.ru", "phone": "+70674341607"}
0005432081438	51E495	4678 004185	LARISA MIRONOVA	{"email": "l-mironova-061963@postgrespro.ru", "phone": "+70836293463"}
0005432081439	0744CC	3060 144505	AZAT MAKAROV	{"email": "makarov.a041974@postgrespro.ru", "phone": "+70297009240"}
0005432081440	0744CC	7692 635302	FARID SHEVCHENKO	{"phone": "+70168481039"}
0005432081441	0744CC	0377 452768	ELENA IVANOVA	{"email": "elenaivanova_1970@postgrespro.ru", "phone": "+70773176508"}
0005432081442	7046B9	9342 526997	GENNADIY MARTYNOV	{"email": "g.martynov_1974@postgrespro.ru", "phone": "+70840256454"}
0005432081443	7046B9	3948 621028	VIKTOR KUZNECOV	{"email": "kuznecov-viktor.16121970@postgrespro.ru", "phone": "+70285505611"}
0005432081444	4809E6	1130 610009	YAROSLAV MIKHAYLOV	{"phone": "+70570006523"}
0005432081445	3E333D	1834 344845	TATYANA STEPANOVA	{"email": "stepanovatatyana_04111965@postgrespro.ru", "phone": "+70409606365"}
0005432081446	645739	9822 230542	SERGEY POPOV	{"phone": "+70643931572"}
0005432081447	645739	9720 959169	ALBINA IVANOVA	{"phone": "+70283083636"}
0005432081448	F2FF01	0708 674173	ELIZAVETA VASILEVA	{"email": "vasileva.e061972@postgrespro.ru", "phone": "+70790394185"}
0005432081449	F2FF01	8797 949918	NATALYA NIKOLAEVA	{"phone": "+70793430736"}
0005432081450	F2FF01	3402 489910	SERGEY SAVELEV	{"email": "savelevsergey08041973@postgrespro.ru", "phone": "+70437604735"}
0005432081451	AE3C49	6259 968079	ANNA SMIRNOVA	{"phone": "+70018691989"}
0005432081452	785927	7444 930096	LIDIYA KULIKOVA	{"email": "l-kulikova_021968@postgrespro.ru", "phone": "+70440699069"}
0005432081453	389E62	7172 624787	EKATERINA BORISOVA	{"email": "eborisova_031977@postgrespro.ru", "phone": "+70752334907"}
0005432081454	389E62	0018 500594	SVETLANA LOGINOVA	{"email": "s-loginova_1977@postgrespro.ru", "phone": "+70287263958"}
0005432081455	389E62	0121 287250	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr.1969@postgrespro.ru", "phone": "+70576862112"}
0005432081456	362484	3101 202788	EKATERINA ZAYCEVA	{"phone": "+70207737334"}
0005432081457	362484	8783 252278	MARINA KUZNECOVA	{"phone": "+70472125550"}
0005432081458	C0BEE8	3487 906830	ELENA KUDRYASHOVA	{"phone": "+70040949110"}
0005432081459	C0BEE8	4710 765773	VLADIMIR ABRAMOV	{"phone": "+70491060361"}
0005432081460	05027A	8328 052871	LIDIYA ZAYCEVA	{"phone": "+70271966193"}
0005432081461	D9878A	0719 960554	VITALIY ISAEV	{"email": "isaev.vitaliy_011974@postgrespro.ru", "phone": "+70735820947"}
0005432081462	B069D7	9102 709362	SERGEY EGOROV	{"email": "sergey.egorov-25061989@postgrespro.ru", "phone": "+70651906058"}
0005432081463	ED1492	2362 392199	ZOYA SERGEEVA	{"email": "sergeeva-z01011988@postgrespro.ru", "phone": "+70328350743"}
0005432081464	ED1492	9400 836146	GALINA ZHURAVLEVA	{"email": "g.zhuravleva.1975@postgrespro.ru", "phone": "+70325311124"}
0005432081465	5A3084	6871 351428	TATYANA SERGEEVA	{"phone": "+70827424373"}
0005432081466	64059D	7287 669732	DMITRIY ZHUKOV	{"email": "zhukov_dmitriy-08041969@postgrespro.ru", "phone": "+70437609480"}
0005432081467	674BEB	8141 017129	NINA GUSEVA	{"email": "nina.guseva-1987@postgrespro.ru", "phone": "+70585860574"}
0005432081468	397A3D	8509 315545	LYUBOV BELYAEVA	{"email": "lbelyaeva_1971@postgrespro.ru", "phone": "+70587906072"}
0005432081469	B3476B	3899 692125	DIANA SEMENOVA	{"phone": "+70876707990"}
0005432081470	A790BF	7867 192555	ILYA KULIKOV	{"email": "ilya_kulikov_1975@postgrespro.ru", "phone": "+70716897274"}
0005432081471	2FF7D7	0435 663773	EVGENIY IVANOV	{"phone": "+70850118599"}
0005432081472	5CBB6E	1745 065995	ANATOLIY IVANOV	{"email": "ivanov_a_04031974@postgrespro.ru", "phone": "+70749273193"}
0005432081473	FFC156	3921 654318	SVETLANA KALININA	{"email": "svetlana.kalinina13081976@postgrespro.ru", "phone": "+70123780824"}
0005432081474	383CDC	4416 382757	YULIYA YAKOVLEVA	{"email": "yakovlevayuliya-1981@postgrespro.ru", "phone": "+70201342547"}
0005432081475	3462A3	4377 064022	EMMA YAKOVLEVA	{"phone": "+70665320409"}
0005432081476	001191	1320 532677	DMITRIY KUZMIN	{"email": "kuzmin_d-1979@postgrespro.ru", "phone": "+70147685422"}
0005432081477	001191	4692 784959	NADEZHDA KALININA	{"email": "nadezhda_kalinina031978@postgrespro.ru", "phone": "+70729570886"}
0005432081478	9D6208	1076 128660	PAVEL BARANOV	{"email": "baranov-p.25011975@postgrespro.ru", "phone": "+70990712046"}
0005432081479	9D6208	1292 412073	VITALIY TIKHONOV	{"phone": "+70746964831"}
0005432081480	680CD9	0711 962221	VLADIMIR KOZLOV	{"phone": "+70875251408"}
0005432081481	680CD9	9372 124680	KONSTANTIN IVANOV	{"phone": "+70449722136"}
0005432081482	FB3A3B	2441 637921	TAISIYA DENISOVA	{"email": "taisiya-denisova.1963@postgrespro.ru", "phone": "+70508328761"}
0005432081483	633B4D	3226 170033	RUSLAN GAVRILOV	{"email": "gavrilov_ruslan061966@postgrespro.ru", "phone": "+70512592240"}
0005432081484	633B4D	4624 847070	INNA FEDOROVA	{"phone": "+70605913854"}
0005432081485	8DE68F	2066 422580	ALEKSANDR POPOV	{"email": "a.popov051964@postgrespro.ru", "phone": "+70420189223"}
0005432081486	8DE68F	8695 510957	VLADISLAV ILIN	{"phone": "+70450960603"}
0005432081487	B56A62	4629 957027	ALEKSANDR IVANOV	{"email": "aivanov111981@postgrespro.ru", "phone": "+70996689498"}
0005432081488	9F89F7	9133 579705	ILYA ZAKHAROV	{"phone": "+70859920877"}
0005432081489	E0BFED	6602 214784	OLESYA DENISOVA	{"phone": "+70446098447"}
0005432081490	9F6C15	5558 543757	INNA BOGDANOVA	{"phone": "+70884631301"}
0005432081491	43C073	5246 834382	OLESYA BELOVA	{"phone": "+70929695781"}
0005432081492	43C073	7962 791385	ALEKSANDR FOMIN	{"email": "a-fomin.06111980@postgrespro.ru", "phone": "+70134047908"}
0005432081672	48B16D	8315 129062	VASILIY NIKITIN	{"phone": "+70071213297"}
0005432081493	008978	3749 102538	ANDREY TIMOFEEV	{"email": "a.timofeev.1970@postgrespro.ru", "phone": "+70009238886"}
0005432081494	008978	2837 473389	EKATERINA POPOVA	{"email": "e-popova081970@postgrespro.ru", "phone": "+70061111092"}
0005432081495	290041	9224 027554	SVETLANA ARKHIPOVA	{"phone": "+70471312435"}
0005432081496	0FD6C2	4960 947182	TATYANA KRASNOVA	{"phone": "+70838921214"}
0005432081497	0FD6C2	2580 357109	SERGEY EGOROV	{"email": "egorov_s_18061974@postgrespro.ru", "phone": "+70658488957"}
0005432081498	FFC682	8567 873945	IRINA KOROLEVA	{"email": "koroleva_i-01061975@postgrespro.ru", "phone": "+70925600465"}
0005432081499	35E7D8	2919 008031	EGOR NAZAROV	{"email": "nazarov-egor-021969@postgrespro.ru", "phone": "+70757780040"}
0005432081500	35E7D8	9612 642432	NINA KULIKOVA	{"phone": "+70783870698"}
0005432081501	D2ADA4	8696 597144	EKATERINA ZHURAVLEVA	{"phone": "+70637542930"}
0005432081502	1FB18F	0952 410847	DMITRIY KAZAKOV	{"email": "kazakov.dmitriy011979@postgrespro.ru", "phone": "+70788101213"}
0005432081503	BF469E	9165 915960	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov12021971@postgrespro.ru", "phone": "+70886445459"}
0005432081504	5DFA4B	7482 946134	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova_111982@postgrespro.ru", "phone": "+70852135576"}
0005432081505	6C1DF3	7624 730533	ALEKSANDRA POLYAKOVA	{"email": "a_polyakova.22081977@postgrespro.ru", "phone": "+70811623374"}
0005432081506	924299	0710 845470	ELIZAVETA FILATOVA	{"phone": "+70229221327"}
0005432081507	924299	1694 994838	VLADISLAV PETROV	{"email": "vladislav_petrov1963@postgrespro.ru", "phone": "+70875387840"}
0005432081508	76A9AC	0920 061290	OLGA NIKOLAEVA	{"phone": "+70051028478"}
0005432081509	4BC489	3781 427125	TAMARA KOVALEVA	{"phone": "+70728999481"}
0005432081510	4BC489	0561 047462	MIKHAIL MAKSIMOV	{"phone": "+70967754048"}
0005432081511	84AC63	9823 135433	RAISA MAKAROVA	{"phone": "+70042474526"}
0005432081512	84AC63	5403 097089	MIKHAIL STEPANOV	{"email": "mikhailstepanov.24081981@postgrespro.ru", "phone": "+70711785839"}
0005432081513	84AC63	2482 001054	VASILIY VOROBEV	{"phone": "+70779861374"}
0005432081514	B1D149	5322 327101	OLESYA NESTEROVA	{"phone": "+70733690720"}
0005432081515	D00A3D	5143 521031	SVETLANA LUKYANOVA	{"email": "lukyanovas08081975@postgrespro.ru", "phone": "+70613258834"}
0005432081516	1938EB	7406 587887	GENNADIY KUZMIN	{"phone": "+70163506428"}
0005432081517	54AB32	6970 662223	MIKHAIL STEPANOV	{"phone": "+70656254279"}
0005432081518	63A5DE	5242 953155	MAKSIM EGOROV	{"email": "egorov.maksim1988@postgrespro.ru", "phone": "+70216836780"}
0005432081519	AE5B17	5721 791792	ALEKSEY GAVRILOV	{"phone": "+70966557695"}
0005432081520	17EF8D	3841 736641	ALEKSANDR ZHUKOV	{"phone": "+70077602946"}
0005432081521	17EF8D	6944 381957	OLGA BORISOVA	{"email": "olga.borisova.091967@postgrespro.ru", "phone": "+70729827450"}
0005432081522	17EF8D	0003 105970	SVETLANA POPOVA	{"phone": "+70347971105"}
0005432081523	759C2B	4207 284677	SVETLANA TITOVA	{"phone": "+70065923860"}
0005432081524	5D533B	0184 337371	NATALYA VOROBEVA	{"email": "vorobeva-n-041967@postgrespro.ru", "phone": "+70892447566"}
0005432081525	2114B8	3187 599994	NINA AKIMOVA	{"email": "akimovan031977@postgrespro.ru", "phone": "+70241895490"}
0005432081526	2114B8	9392 360425	VYACHESLAV KUZMIN	{"email": "v.kuzmin-1973@postgrespro.ru", "phone": "+70341929427"}
0005432081527	01758E	8878 636237	NADEZHDA BORISOVA	{"email": "nadezhda_borisova09081966@postgrespro.ru", "phone": "+70316660783"}
0005432081528	01758E	6246 245945	SERGEY YAKOVLEV	{"email": "yakovlev-sergey-1972@postgrespro.ru", "phone": "+70301721865"}
0005432081529	6E7A10	7199 140881	ANDREY SCHERBAKOV	{"email": "scherbakov.a.111971@postgrespro.ru", "phone": "+70258784675"}
0005432081530	6FA267	7937 328503	OLGA NOVIKOVA	{"phone": "+70701407007"}
0005432081531	BC0B77	3719 765676	MIKHAIL NIKOLAEV	{"phone": "+70217815838"}
0005432081532	8C4AD3	0659 224572	POLINA GRISHINA	{"email": "polina.grishina-1970@postgrespro.ru", "phone": "+70731317654"}
0005432081533	CB7792	0198 739960	SERGEY ROMANOV	{"phone": "+70997096460"}
0005432081534	CB7792	1006 815231	ALEKSEY MIRONOV	{"email": "a_mironov_1975@postgrespro.ru", "phone": "+70688645654"}
0005432081535	5F1F7F	2804 992496	NATALYA OSIPOVA	{"email": "natalya-osipova-03031964@postgrespro.ru", "phone": "+70413147437"}
0005432081536	5F1F7F	2356 520095	RAISA AKIMOVA	{"email": "akimova.r-11081974@postgrespro.ru", "phone": "+70740608008"}
0005432081537	F20D1E	3324 226087	MARINA MEDVEDEVA	{"email": "medvedeva.marina-1963@postgrespro.ru", "phone": "+70313379707"}
0005432081538	352AD3	8384 624368	OLGA VOLKOVA	{"phone": "+70386039766"}
0005432081539	E13E89	1064 066013	VIKTOR VLASOV	{"phone": "+70748526644"}
0005432081540	1BA2F3	4305 777435	ALEKSEY NIKITIN	{"phone": "+70662158901"}
0005432081542	3BC45D	5773 580572	EKATERINA FROLOVA	{"email": "frolova_ekaterina-15051966@postgrespro.ru", "phone": "+70472297850"}
0005432081543	EB73ED	9269 306681	ALEKSEY VOLKOV	{"email": "volkov-aleksey12091967@postgrespro.ru", "phone": "+70312708261"}
0005432081544	00B161	6080 468433	DMITRIY FEDOTOV	{"phone": "+70171874823"}
0005432081545	865ED6	1454 872505	ALEKSANDRA KRASNOVA	{"email": "krasnovaa06081969@postgrespro.ru", "phone": "+70151727694"}
0005432081546	DA04B6	6562 848851	LYUDMILA ANISIMOVA	{"phone": "+70904360016"}
0005432081547	BD79D9	6355 391891	VERA MIRONOVA	{"phone": "+70178687268"}
0005432081548	BD79D9	1618 010278	NATALYA NOVIKOVA	{"email": "novikova-natalya-1971@postgrespro.ru", "phone": "+70215943759"}
0005432081549	522B08	7847 728700	EKATERINA MIRONOVA	{"phone": "+70237311700"}
0005432081550	522B08	6412 266312	NATALYA KRASNOVA	{"email": "natalya-krasnova031975@postgrespro.ru", "phone": "+70840976422"}
0005432081551	CA2E81	4433 543714	ALEKSANDR FROLOV	{"email": "frolov-a081979@postgrespro.ru", "phone": "+70324219651"}
0005432081552	CA2E81	9715 157335	LIDIYA BORISOVA	{"email": "borisova_l.121961@postgrespro.ru", "phone": "+70269466623"}
0005432081673	7652BF	2305 469399	NIKOLAY DENISOV	{"phone": "+70418580703"}
0005432081553	87F2BE	7804 914360	VLADIMIR VOROBEV	{"email": "vorobev.vladimir.31051964@postgrespro.ru", "phone": "+70992041453"}
0005432081554	87F2BE	2017 659066	ANATOLIY KONOVALOV	{"phone": "+70686622695"}
0005432081555	87F2BE	9786 642236	RIMMA MALYSHEVA	{"email": "rimma_malysheva.061974@postgrespro.ru", "phone": "+70061897913"}
0005432081556	A73B61	7945 837742	ARTEM DMITRIEV	{"phone": "+70582224435"}
0005432081557	62AF28	5195 753186	VASILIY BELOV	{"email": "belovv.091977@postgrespro.ru", "phone": "+70687434115"}
0005432081558	62AF28	2671 135152	NIKOLAY ZHUKOV	{"email": "zhukovnikolay_081976@postgrespro.ru", "phone": "+70507599685"}
0005432081559	62AF28	1396 744864	KARINA VOROBEVA	{"phone": "+70935711333"}
0005432081560	4681B0	9354 864882	SERGEY GORBUNOV	{"phone": "+70757618967"}
0005432081561	3636D5	2484 672555	SVETLANA KOZLOVA	{"phone": "+70119182980"}
0005432081562	B0C56D	0262 170787	KRISTINA MEDVEDEVA	{"phone": "+70892785429"}
0005432081563	AFC3A0	7310 994614	VIKTOR MAKAROV	{"email": "makarovv.071969@postgrespro.ru", "phone": "+70734536287"}
0005432081564	AFAC52	7052 695762	NINA MELNIKOVA	{"phone": "+70417700177"}
0005432081565	45655B	8331 919923	ALEKSANDR RODIONOV	{"phone": "+70468084201"}
0005432081566	45655B	6767 962809	ANTONINA POPOVA	{"phone": "+70057322298"}
0005432081567	C226F3	1380 796665	VARVARA MAKSIMOVA	{"email": "v_maksimova25071974@postgrespro.ru", "phone": "+70137622004"}
0005432081568	668D83	2634 320374	NATALYA LAZAREVA	{"phone": "+70916432905"}
0005432081569	A1B085	3694 878859	SERGEY TIKHONOV	{"phone": "+70513445385"}
0005432081570	2EBFE8	4396 789434	TATYANA NIKOLAEVA	{"phone": "+70908098348"}
0005432081571	2EBFE8	6264 095328	DANILA KRASNOV	{"email": "krasnov.danila_111971@postgrespro.ru", "phone": "+70233502966"}
0005432081572	08C366	4779 910848	KLAVDIYA NAZAROVA	{"phone": "+70092910893"}
0005432081573	64391C	7483 349145	ALEKSANDR KAZAKOV	{"email": "a_kazakov-28091974@postgrespro.ru", "phone": "+70767982534"}
0005432081574	AEB6B7	9974 277500	LYUDMILA VASILEVA	{"email": "lyudmila.vasileva.051978@postgrespro.ru", "phone": "+70746560609"}
0005432081575	EB8FE3	5905 632313	VALERIY VOROBEV	{"email": "v_vorobev_05021969@postgrespro.ru", "phone": "+70741249322"}
0005432081576	637612	4408 642272	ANDREY KOZLOV	{"email": "kozlov-a-091974@postgrespro.ru", "phone": "+70643289222"}
0005432081577	637612	3797 731505	MAKSIM KONOVALOV	{"email": "konovalov_maksim.101982@postgrespro.ru", "phone": "+70141010608"}
0005432081578	637612	8743 185167	RUDOLF ALEKSEEV	{"phone": "+70746514418"}
0005432081579	2BD6E9	1211 544067	OLGA SOLOVEVA	{"email": "o-soloveva-11101980@postgrespro.ru", "phone": "+70642475761"}
0005432081580	8A6F65	6999 024579	ALSU MOROZOVA	{"email": "morozovaalsu.19041966@postgrespro.ru", "phone": "+70062688024"}
0005432081581	58A508	6906 699166	NADEZHDA MAKSIMOVA	{"phone": "+70570895673"}
0005432081582	58A508	1453 053394	TATYANA EGOROVA	{"phone": "+70734305713"}
0005432081583	0BD0D8	9119 938623	ANDREY SHEVCHENKO	{"phone": "+70018248272"}
0005432081584	0BD0D8	4783 327395	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr-05111974@postgrespro.ru", "phone": "+70696787935"}
0005432081585	075E6D	9883 696231	OLGA TIKHONOVA	{"email": "o-tikhonova_081974@postgrespro.ru", "phone": "+70556001850"}
0005432081586	AE4F3B	9696 932747	IGOR GORBUNOV	{"email": "igorbunov-18081970@postgrespro.ru", "phone": "+70450077249"}
0005432081587	389403	7662 796751	NATALYA KOLESNIKOVA	{"email": "kolesnikova-n.071968@postgrespro.ru", "phone": "+70803500955"}
0005432081588	389403	9603 930831	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir_12091965@postgrespro.ru", "phone": "+70962584103"}
0005432081589	689532	7860 012342	TATYANA KRASNOVA	{"phone": "+70247554970"}
0005432081590	2D24F8	9581 199992	EKATERINA GAVRILOVA	{"phone": "+70526156028"}
0005432081591	2D24F8	9634 546434	SERGEY ORLOV	{"phone": "+70861665851"}
0005432081592	93FDB3	7964 304233	OLGA LOGINOVA	{"phone": "+70510669922"}
0005432081593	93FDB3	2391 747621	ANNA NOVIKOVA	{"email": "anna_novikova-101963@postgrespro.ru", "phone": "+70780405060"}
0005432081594	0F8628	8461 221525	MIKHAIL NIKOLAEV	{"email": "nikolaev.mikhail.1973@postgrespro.ru", "phone": "+70131980741"}
0005432081595	77C6BD	1723 824065	VLADIMIR YAKOVLEV	{"phone": "+70580432127"}
0005432081596	77C6BD	1764 996772	LYUBOV KUZMINA	{"email": "lyubov_kuzmina.101963@postgrespro.ru", "phone": "+70240564106"}
0005432081597	440E8E	2801 988950	RAISA MIKHAYLOVA	{"email": "mikhaylova-r1965@postgrespro.ru", "phone": "+70443814391"}
0005432081598	E49219	1248 518130	ALEKSANDR KARPOV	{"email": "karpov-a1964@postgrespro.ru", "phone": "+70342137724"}
0005432081599	383816	4771 690827	ILYA ORLOV	{"email": "orlov-i_1979@postgrespro.ru", "phone": "+70416431136"}
0005432081600	383816	0050 174553	GENNADIY EGOROV	{"phone": "+70045651627"}
0005432081601	87E00D	2499 223413	ALEKSANDRA RYABOVA	{"email": "ryabova-a_1970@postgrespro.ru", "phone": "+70120278598"}
0005432081602	87E00D	5543 867845	NATALYA ABRAMOVA	{"phone": "+70077795108"}
0005432081603	D7A705	6603 083017	MIKHAIL OSIPOV	{"email": "osipov.mikhail_1977@postgrespro.ru", "phone": "+70854687212"}
0005432081604	D7A705	6933 345585	LYUBOV LUKYANOVA	{"email": "l.lukyanova.1970@postgrespro.ru", "phone": "+70471393836"}
0005432081605	1DB2E8	0477 367372	KONSTANTIN NAUMOV	{"phone": "+70289292939"}
0005432081606	1DB2E8	0080 300513	TATYANA GAVRILOVA	{"email": "gavrilova.t-18121971@postgrespro.ru", "phone": "+70951086285"}
0005432081607	748D96	9324 781529	ANDREY KOZLOV	{"email": "a-kozlov.13071973@postgrespro.ru", "phone": "+70773015005"}
0005432081608	C1E699	6704 593745	NADEZHDA KISELEVA	{"email": "kiseleva.nadezhda.1967@postgrespro.ru", "phone": "+70514559560"}
0005432081609	C1E699	3738 607450	SERGEY KARPOV	{"email": "s-karpov_1971@postgrespro.ru", "phone": "+70675811127"}
0005432081610	8938D7	9592 862258	RAVIL SOROKIN	{"phone": "+70195549585"}
0005432081611	77E915	5735 844482	MAKSIM KARPOV	{"phone": "+70954940514"}
0005432105102	24352C	8506 561594	INNA AFANASEVA	{"phone": "+70422206682"}
0005432081612	8AFCD5	5961 440517	EMIL ZHURAVLEV	{"email": "zhuravleve_081971@postgrespro.ru", "phone": "+70249841455"}
0005432081613	962189	5717 405972	FANIS IVANOV	{"email": "fanis.ivanov09121975@postgrespro.ru", "phone": "+70565036809"}
0005432081614	D00694	0893 476675	VALERIY ZHURAVLEV	{"email": "zhuravlev-v.1985@postgrespro.ru", "phone": "+70654546905"}
0005432081615	D00694	1514 873616	IRINA MIKHAYLOVA	{"phone": "+70302085719"}
0005432081616	F198BE	5506 240689	NIKOLAY ILIN	{"email": "nikolay-ilin011978@postgrespro.ru", "phone": "+70595976188"}
0005432081617	689C91	9177 586135	OKSANA ZHUKOVA	{"email": "o-zhukova-19051978@postgrespro.ru", "phone": "+70935392101"}
0005432081618	C672F2	3641 006030	ALEKSANDR KUZMIN	{"phone": "+70119310236"}
0005432081619	C672F2	4729 866563	NINA SOLOVEVA	{"email": "soloveva_nina_19101977@postgrespro.ru", "phone": "+70597541833"}
0005432081620	C672F2	0158 194598	ELENA MALYSHEVA	{"phone": "+70508054070"}
0005432081621	3838DB	2768 898936	VYACHESLAV SMIRNOV	{"email": "vsmirnov17031972@postgrespro.ru", "phone": "+70145377084"}
0005432081622	287707	3272 227574	MARIYA NIKOLAEVA	{"phone": "+70426663621"}
0005432081623	287707	3721 623913	GRIGORIY KARPOV	{"email": "gkarpov.1970@postgrespro.ru", "phone": "+70947712604"}
0005432081624	FE1190	4091 949767	VALENTINA EFIMOVA	{"phone": "+70724294749"}
0005432081625	C29EEB	6988 450465	SVETLANA VOLKOVA	{"phone": "+70543077375"}
0005432081626	D4F854	1339 034635	ELENA GAVRILOVA	{"phone": "+70221966700"}
0005432081627	BF88AF	0066 663805	EKATERINA MASLOVA	{"phone": "+70558887513"}
0005432081628	C6AB01	2627 604689	GALINA NIKOLAEVA	{"email": "g.nikolaeva21011979@postgrespro.ru", "phone": "+70393130272"}
0005432081629	C6AB01	9591 507908	VERA DAVYDOVA	{"email": "vera-davydova041973@postgrespro.ru", "phone": "+70454258094"}
0005432081630	407DB6	1357 253105	SVETLANA BELOVA	{"phone": "+70429642638"}
0005432081631	05CC87	6507 914830	GALINA STEPANOVA	{"email": "galina.stepanova.1978@postgrespro.ru", "phone": "+70061501486"}
0005432081632	92A43D	1403 874272	ELENA TROFIMOVA	{"email": "elenatrofimova_12071970@postgrespro.ru", "phone": "+70628374641"}
0005432081633	699D24	1917 388678	SVETLANA LOGINOVA	{"email": "svetlana.loginova-1974@postgrespro.ru", "phone": "+70737840998"}
0005432081634	23E423	0211 638483	LYUDMILA NESTEROVA	{"email": "lyudmilanesterova_02061967@postgrespro.ru", "phone": "+70491791677"}
0005432081635	BD3932	5488 612896	NATALYA ANDREEVA	{"email": "nandreeva111967@postgrespro.ru", "phone": "+70425491728"}
0005432081636	C6B531	2688 683033	ZOYA FEDOROVA	{"email": "zoya-fedorova.1972@postgrespro.ru", "phone": "+70621233983"}
0005432081637	C6B531	4343 655104	OLGA NIKOLAEVA	{"phone": "+70713792572"}
0005432081638	929346	0451 499242	ANNA PETROVA	{"phone": "+70044304841"}
0005432081639	929346	4227 254104	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr_1960@postgrespro.ru", "phone": "+70239851004"}
0005432081640	77B27F	0776 506948	NATALIYA MELNIKOVA	{"phone": "+70593127653"}
0005432081641	77B27F	1718 801529	ARSENIY GRIGOREV	{"phone": "+70986970766"}
0005432081642	B54A76	7969 616527	EKATERINA CHERNOVA	{"email": "ekaterina_chernova_111962@postgrespro.ru", "phone": "+70956569993"}
0005432081643	B54A76	6516 817248	LUIZA ALEKSEEVA	{"email": "luiza.alekseeva08091977@postgrespro.ru", "phone": "+70588778374"}
0005432081644	CE3E06	6331 675333	ELENA IVANOVA	{"phone": "+70878487468"}
0005432081645	CE3E06	2618 970174	ZINAIDA GRISHINA	{"email": "zgrishina-011975@postgrespro.ru", "phone": "+70938175578"}
0005432081646	B550BB	0393 600299	ANNA LUKYANOVA	{"phone": "+70628215142"}
0005432081647	B550BB	2150 668940	LYUBOV RYABOVA	{"email": "ryabova_lyubov-13061975@postgrespro.ru", "phone": "+70507552727"}
0005432081648	8F6DDF	4736 550659	RAISA KUZNECOVA	{"email": "kuznecova-r081983@postgrespro.ru", "phone": "+70403556734"}
0005432081649	61A734	1141 479616	ANDREY ALEKSANDROV	{"email": "aleksandrov_a091968@postgrespro.ru", "phone": "+70542746945"}
0005432081650	61A734	4756 269618	ZINAIDA NESTEROVA	{"email": "nesterova_z-061983@postgrespro.ru", "phone": "+70671470606"}
0005432081651	A12EE7	7490 373675	EKATERINA ZHUKOVA	{"email": "e-zhukova1972@postgrespro.ru", "phone": "+70446029808"}
0005432081652	A12EE7	7689 632551	ALEKSANDR FEDOROV	{"phone": "+70156742640"}
0005432081653	902AF0	6647 437408	LEV KUZNECOV	{"email": "lev_kuznecov1978@postgrespro.ru", "phone": "+70274440435"}
0005432081654	A04524	1259 434954	PELAGEYA KOVALEVA	{"phone": "+70810225545"}
0005432081655	A04524	7367 859290	VLADIMIR MOROZOV	{"email": "morozov-vladimir.1975@postgrespro.ru", "phone": "+70914358241"}
0005432081656	D02EE8	0351 215566	TAMARA ANDREEVA	{"phone": "+70850511157"}
0005432081657	A1758B	0265 272612	IRINA POTAPOVA	{"phone": "+70833674407"}
0005432081658	C88D28	8177 866727	KONSTANTIN MOISEEV	{"phone": "+70004214525"}
0005432081659	090E5F	5745 988645	FARIT ZHUKOV	{"phone": "+70683117231"}
0005432081660	3E9E0C	0122 493327	GALINA FILATOVA	{"phone": "+70517137095"}
0005432081661	3E9E0C	1665 657872	MIKHAIL MAKSIMOV	{"phone": "+70182632220"}
0005432081662	BEA4FF	9056 851531	LYUBOV POPOVA	{"phone": "+70449343383"}
0005432081663	71AE91	5662 717025	VIKTOR SHEVCHENKO	{"phone": "+70094983386"}
0005432081664	E1733C	5714 551649	DMITRIY ILIN	{"email": "dmitriy.ilin-101969@postgrespro.ru", "phone": "+70327204979"}
0005432081665	E1733C	9535 825819	VIKTOR VASILEV	{"email": "vasilev.viktor.1964@postgrespro.ru", "phone": "+70326561297"}
0005432081666	1E6778	6933 243485	ANDREY SHEVCHENKO	{"email": "shevchenkoa09051972@postgrespro.ru", "phone": "+70381288695"}
0005432081667	AAB032	9486 306784	NATALYA FILATOVA	{"phone": "+70087558607"}
0005432081668	2A3690	1777 537393	ALEKSEY FEDOROV	{"phone": "+70393999267"}
0005432081669	5472F7	9292 278704	LYUBOV GUSEVA	{"phone": "+70572922454"}
0005432081670	3C01B9	7853 126667	TAMARA ERMAKOVA	{"email": "t_ermakova_1976@postgrespro.ru", "phone": "+70173583634"}
0005432081671	401309	9535 748105	SERGEY VOLKOV	{"phone": "+70711552521"}
0005432081674	7CA3DA	1442 509696	ALEKSEY IVANOV	{"email": "ivanov.aleksey.071965@postgrespro.ru", "phone": "+70554070780"}
0005432081675	DFA2AB	9903 402051	ELENA NIKITINA	{"email": "e-nikitina1960@postgrespro.ru", "phone": "+70647776640"}
0005432081676	DFA2AB	5119 563726	VALENTINA ZOTOVA	{"phone": "+70413192253"}
0005432081677	23750D	2643 070060	KONSTANTIN MOROZOV	{"email": "morozov-konstantin1973@postgrespro.ru", "phone": "+70812331237"}
0005432081678	5B1B18	3264 536453	LARISA MELNIKOVA	{"phone": "+70436621269"}
0005432081679	5B1B18	8634 585368	YURIY VOLKOV	{"email": "yvolkov_1967@postgrespro.ru", "phone": "+70871596272"}
0005432081680	9F8162	5455 720684	ANTON ZHUKOV	{"phone": "+70057220725"}
0005432081681	7AFD0E	7094 908268	ELIZAVETA ZAKHAROVA	{"email": "elizaveta_zakharova.091967@postgrespro.ru", "phone": "+70323283408"}
0005432081682	C4B203	9105 502044	GULSINA SMIRNOVA	{"phone": "+70388290899"}
0005432081683	2F503E	2600 858330	NIKOLAY ZHURAVLEV	{"phone": "+70413752794"}
0005432081684	C35B20	8474 528638	SERGEY BARANOV	{"email": "s_baranov_09121982@postgrespro.ru", "phone": "+70176216498"}
0005432081685	8DD026	6312 972338	LYUDMILA ZAYCEVA	{"phone": "+70361956322"}
0005432081686	0E0FC8	4225 668374	TAISA SOLOVEVA	{"email": "soloveva-taisa.061976@postgrespro.ru", "phone": "+70791270958"}
0005432081687	3A88A6	5375 142989	KRISTINA FILIPPOVA	{"email": "filippova-k-081969@postgrespro.ru", "phone": "+70667915400"}
0005432081688	3A88A6	6615 526195	NIKOLAY ALEKSEEV	{"phone": "+70104750203"}
0005432081689	958B4F	1602 382533	VLADISLAV DMITRIEV	{"phone": "+70364069295"}
0005432081690	958B4F	6991 242281	ALENA MARTYNOVA	{"phone": "+70692749261"}
0005432081691	87E0EC	6706 966608	ANGELINA NAUMOVA	{"email": "angelina-naumova041965@postgrespro.ru", "phone": "+70827366807"}
0005432081692	DAD35D	0367 942597	YURIY PETROV	{"email": "petrovyuriy-22031971@postgrespro.ru", "phone": "+70757998385"}
0005432081693	6A16DD	6917 676143	VLADIMIR KUZNECOV	{"phone": "+70005748597"}
0005432081694	6A16DD	7586 517072	LYUDMILA MIRONOVA	{"phone": "+70814580623"}
0005432081695	B0F379	8518 946347	NIKOLAY KISELEV	{"phone": "+70219902272"}
0005432081696	2CFA7F	6763 856042	ANNA ANISIMOVA	{"email": "anisimova-a.051967@postgrespro.ru", "phone": "+70165386309"}
0005432081697	F01909	3151 529006	SERGEY MOISEEV	{"email": "sergey_moiseev-1963@postgrespro.ru", "phone": "+70804918886"}
0005432081698	F01909	1210 815013	SVETLANA ZAYCEVA	{"phone": "+70138634811"}
0005432104711	4507EF	8271 327107	VIKTOR FEDOROV	{"phone": "+70965976317"}
0005432104712	6BDF14	9771 070420	OLGA VASILEVA	{"phone": "+70181839545"}
0005432104713	335082	3362 855551	VASILIY NOVIKOV	{"phone": "+70610086045"}
0005432104714	335082	3824 851182	TATYANA KOZLOVA	{"email": "tatyana_kozlova.1966@postgrespro.ru", "phone": "+70029545287"}
0005432104715	C11686	7734 875811	ANTON KULIKOV	{"phone": "+70189766411"}
0005432104716	C11686	6328 188275	IRINA SAVELEVA	{"phone": "+70781001565"}
0005432104717	193693	8931 641306	NATALYA ARKHIPOVA	{"email": "arkhipovanatalya.28111985@postgrespro.ru", "phone": "+70325536997"}
0005432104718	9D13FE	9472 466236	ALEKSANDR BELOV	{"phone": "+70212759781"}
0005432104719	9D13FE	6504 157733	ELENA MAKSIMOVA	{"phone": "+70113438687"}
0005432104720	92E1F9	9515 181407	DMITRIY BONDARENKO	{"phone": "+70311599699"}
0005432104721	089036	5946 541274	ELENA GAVRILOVA	{"email": "gavrilovae-15081987@postgrespro.ru", "phone": "+70591412691"}
0005432104722	C47F2B	3153 946338	TATYANA ZAKHAROVA	{"phone": "+70246597503"}
0005432104723	88DEC8	8074 120812	YULIYA MAKSIMOVA	{"email": "y-maksimova.041969@postgrespro.ru", "phone": "+70983371827"}
0005432104724	9CDF88	4873 956403	OLGA SEMENOVA	{"phone": "+70851636075"}
0005432104725	BF4C1C	4140 462771	DMITRIY MEDVEDEV	{"phone": "+70030746930"}
0005432104726	369A87	2818 464648	NIKOLAY SERGEEV	{"email": "n-sergeev_08051978@postgrespro.ru", "phone": "+70067916410"}
0005432104727	D5CA44	6419 385965	STEPAN DENISOV	{"phone": "+70613804441"}
0005432104728	B71FD2	7311 897858	ANDREY SCHERBAKOV	{"phone": "+70333552190"}
0005432104729	B8BEBB	3464 700444	BOGDAN VOLKOV	{"phone": "+70357957971"}
0005432104730	848EBE	2105 821855	ALEKSANDRA EGOROVA	{"email": "egorova-a22041981@postgrespro.ru", "phone": "+70809055654"}
0005432104731	848EBE	9256 124939	ALEKSEY NIKOLAEV	{"phone": "+70242258465"}
0005432104732	E2D529	3898 843913	TATYANA NESTEROVA	{"email": "nesterova_tatyana_1955@postgrespro.ru", "phone": "+70428166147"}
0005432104733	F1F749	9275 491929	IVAN KUZMIN	{"email": "kuzmin_i.21081977@postgrespro.ru", "phone": "+70261690442"}
0005432104734	26EC50	6105 745586	ANGELINA NOVIKOVA	{"email": "a-novikova-091965@postgrespro.ru", "phone": "+70327219347"}
0005432104735	CCC397	2074 064947	RUSLAN VOLKOV	{"email": "ruslan.volkov.091979@postgrespro.ru", "phone": "+70970417508"}
0005432104736	C068C5	5164 989547	SVETLANA VOLKOVA	{"email": "svolkova021978@postgrespro.ru", "phone": "+70793107963"}
0005432104737	A9D902	5340 244547	IRINA DMITRIEVA	{"email": "dmitrieva.i_071978@postgrespro.ru", "phone": "+70158650062"}
0005432104738	660CE3	9544 954758	NIKOLAY STEPANOV	{"phone": "+70434744592"}
0005432104739	A98EC6	4710 130756	ULYANA IVANOVA	{"phone": "+70029952169"}
0005432104740	85DEB0	3984 938731	YURIY ZAYCEV	{"email": "zaycev.yuriy-021982@postgrespro.ru", "phone": "+70348114362"}
0005432104741	7C874B	9506 177425	GENNADIY SMIRNOV	{"phone": "+70147818104"}
0005432104742	68D56B	8084 137099	EKATERINA ABRAMOVA	{"phone": "+70610007614"}
0005432104743	FCBF9E	4342 030002	VERA TIMOFEEVA	{"email": "timofeevav.051969@postgrespro.ru", "phone": "+70819223426"}
0005432104744	FCBF9E	0992 572589	SANIYA BORISOVA	{"phone": "+70248572616"}
0005432104745	0EEA74	8566 967621	OKSANA AFANASEVA	{"phone": "+70688615827"}
0005432104746	8E1604	8745 212390	EVGENIY SMIRNOV	{"email": "e.smirnov-19111970@postgrespro.ru", "phone": "+70423973318"}
0005432104747	8E1604	1250 553612	NADEZHDA MAKSIMOVA	{"email": "maksimovan.041973@postgrespro.ru", "phone": "+70697600094"}
0005432104748	8E1604	6250 627180	IRINA KARPOVA	{"email": "i-karpova.1970@postgrespro.ru", "phone": "+70750943897"}
0005432104749	7E6FF2	2010 951857	SVETLANA MAKSIMOVA	{"phone": "+70823838060"}
0005432104750	182155	1735 846996	MIKHAIL SOROKIN	{"phone": "+70615198904"}
0005432104751	42530E	2843 716064	ANDREY ALEKSEEV	{"email": "andreyalekseev21061968@postgrespro.ru", "phone": "+70427992049"}
0005432104752	79F3EB	1554 697421	ALEKSANDR MOROZOV	{"email": "morozov.a1969@postgrespro.ru", "phone": "+70188496332"}
0005432104753	79F3EB	9920 553421	IGOR GUSEV	{"phone": "+70516093653"}
0005432104754	79F3EB	8317 161493	LYUDMILA PETROVA	{"phone": "+70452980297"}
0005432104755	D56FB7	9400 193701	ALENA IVANOVA	{"email": "alena-ivanova.031967@postgrespro.ru", "phone": "+70054662374"}
0005432104756	BD41A7	1749 661427	DANILA MEDVEDEV	{"phone": "+70257077419"}
0005432104757	7F6E79	5956 228014	ALEKSANDR GUSEV	{"phone": "+70045938518"}
0005432104758	47B2A0	3838 043801	ANNA OSIPOVA	{"phone": "+70463155961"}
0005432104759	47B2A0	0245 760382	NATALYA GAVRILOVA	{"email": "gavrilovan.14051978@postgrespro.ru", "phone": "+70580364263"}
0005432104760	2FC565	3966 301988	SVETLANA POTAPOVA	{"email": "svetlanapotapova_1973@postgrespro.ru", "phone": "+70092774863"}
0005432104761	5767F8	8743 384082	TATYANA ZAKHAROVA	{"email": "tatyana_zakharova1960@postgrespro.ru", "phone": "+70355206733"}
0005432104762	84C4BF	4483 906125	ANTONINA BOGDANOVA	{"email": "bogdanova.antonina.031976@postgrespro.ru", "phone": "+70503147429"}
0005432104763	3B8869	3310 809605	OKSANA NIKOLAEVA	{"phone": "+70935960014"}
0005432104764	3B8869	2505 553790	ALEKSEY SEMENOV	{"phone": "+70156099788"}
0005432104765	F2F03D	7487 147921	OLGA IVANOVA	{"phone": "+70761234779"}
0005432104766	40CCAE	1740 514880	ELENA ZAYCEVA	{"phone": "+70188176037"}
0005432104767	DFE9C9	4711 028806	NATALYA PAVLOVA	{"email": "natalya-pavlova_091972@postgrespro.ru", "phone": "+70779605535"}
0005432104768	94EF7C	7063 315140	VERA KOROLEVA	{"email": "vera_koroleva.1971@postgrespro.ru", "phone": "+70940808585"}
0005432104769	94EF7C	2242 889965	YANINA LAZAREVA	{"email": "y.lazareva-1979@postgrespro.ru", "phone": "+70374732536"}
0005432104770	94EF7C	6943 354325	NATALYA KONOVALOVA	{"phone": "+70395177024"}
0005432104771	320A92	9603 288340	VIKTORIYA DENISOVA	{"email": "viktoriya_denisova_07121968@postgrespro.ru", "phone": "+70873480366"}
0005432104772	022146	4862 346208	OLGA YUDINA	{"email": "yudinaolga.1981@postgrespro.ru", "phone": "+70032773335"}
0005432104773	2407F9	8307 658447	VLADIMIR ALEKSEEV	{"email": "vladimir.alekseev-1978@postgrespro.ru", "phone": "+70307304235"}
0005432104774	D15823	4523 279465	VALERIY RODIONOV	{"email": "rodionov-valeriy.1975@postgrespro.ru", "phone": "+70198557144"}
0005432104775	9177A2	0084 336638	ALEKSANDR GUSEV	{"phone": "+70503027445"}
0005432104776	F9C11E	8512 056206	EVGENIY CHERNOV	{"email": "chernov_evgeniy11101977@postgrespro.ru", "phone": "+70954391634"}
0005432104777	322255	7375 765347	LEONID NIKOLAEV	{"email": "leonid_nikolaev_01041972@postgrespro.ru", "phone": "+70480531105"}
0005432104778	F59EF7	4093 162524	DMITRIY IVANOV	{"email": "ivanov-d1972@postgrespro.ru", "phone": "+70315570589"}
0005432104779	F7D4FD	8866 487364	NATALYA EGOROVA	{"email": "natalya_egorova-21071967@postgrespro.ru", "phone": "+70742865641"}
0005432104780	07C5FC	2323 353093	IGOR SMIRNOV	{"phone": "+70946349909"}
0005432104781	7C9784	0850 971285	ALEKSANDR TIKHONOV	{"email": "a.tikhonov06111972@postgrespro.ru", "phone": "+70967873215"}
0005432104782	9D648D	6606 238826	VLADIMIR MIKHAYLOV	{"phone": "+70262449632"}
0005432104783	9D648D	9280 668180	LYUDMILA BELOVA	{"email": "lyudmila_belova1966@postgrespro.ru", "phone": "+70004139040"}
0005432104784	42A266	3290 269787	GALINA EFIMOVA	{"email": "efimovag.041970@postgrespro.ru", "phone": "+70535533708"}
0005432104785	B1B874	9001 420170	IGOR CHERNOV	{"email": "chernov.igor-1981@postgrespro.ru", "phone": "+70493226103"}
0005432104786	DAAE2D	3562 691151	ANATOLIY BARANOV	{"phone": "+70387233753"}
0005432104787	DAAE2D	6794 631109	IRINA KOROLEVA	{"email": "irina_koroleva-25091985@postgrespro.ru", "phone": "+70146216150"}
0005432104788	0F7C01	9772 483384	YURIY ROMANOV	{"email": "romanov_yuriy_111978@postgrespro.ru", "phone": "+70393019130"}
0005432104789	CF5EAD	3481 131502	TATYANA KUZMINA	{"email": "kuzminat-011974@postgrespro.ru", "phone": "+70016577663"}
0005432104790	CF5EAD	7253 715365	OLESYA GORBUNOVA	{"email": "gorbunova-o-14101969@postgrespro.ru", "phone": "+70735100001"}
0005432104791	EF5583	1094 710581	KARINA IVANOVA	{"phone": "+70053985850"}
0005432104792	68130A	7453 348747	NIKOLAY FROLOV	{"phone": "+70928187381"}
0005432104793	64495D	2826 449505	DARYA MIRONOVA	{"email": "daryamironova_061978@postgrespro.ru", "phone": "+70680818248"}
0005432104794	0AF46D	2149 480241	SVETLANA PAVLOVA	{"email": "pavlovas30121970@postgrespro.ru", "phone": "+70514683391"}
0005432104795	660367	9174 824418	LIDIYA DMITRIEVA	{"phone": "+70175993599"}
0005432104796	660367	7079 379806	ANNA KOMAROVA	{"email": "anna-komarova.28011968@postgrespro.ru", "phone": "+70527659023"}
0005432104797	660367	5458 979177	ELENA ANDREEVA	{"email": "e_andreeva-28051965@postgrespro.ru", "phone": "+70887445019"}
0005432104798	5B0B0A	2521 207272	NADEZHDA VASILEVA	{"email": "nadezhda.vasileva091968@postgrespro.ru", "phone": "+70931350487"}
0005432104799	69AD86	1849 847038	GALINA MOISEEVA	{"phone": "+70781899926"}
0005432104800	40AFBC	8091 931892	MARINA DMITRIEVA	{"email": "dmitrieva.m_1965@postgrespro.ru", "phone": "+70767374376"}
0005432104801	40AFBC	3927 200500	LARISA MALYSHEVA	{"email": "lmalysheva.29061981@postgrespro.ru", "phone": "+70151084417"}
0005432104802	345C2E	1883 614968	TAMARA ILINA	{"email": "ilina-t.1968@postgrespro.ru", "phone": "+70800476922"}
0005432104803	345C2E	3069 354802	DIANA ZOTOVA	{"phone": "+70604730718"}
0005432104804	116759	7249 431971	VADIM NAZAROV	{"email": "nazarovv.16101966@postgrespro.ru", "phone": "+70984676114"}
0005432104805	B144A3	4556 382748	IVAN SOROKIN	{"email": "i-sorokin.19091973@postgrespro.ru", "phone": "+70884259756"}
0005432104806	DD726B	7565 805901	ALEKSANDR GORBUNOV	{"email": "gorbunov.a1972@postgrespro.ru", "phone": "+70088870084"}
0005432104807	DD726B	8098 450712	MIKHAIL YAKOVLEV	{"phone": "+70948899945"}
0005432104808	DD726B	3869 772382	ALINA DAVYDOVA	{"email": "davydova_a.071976@postgrespro.ru", "phone": "+70487716537"}
0005432104809	521A3C	9827 099133	LYUDMILA MAKSIMOVA	{"phone": "+70584938484"}
0005432104810	D12BDD	9243 591402	GENNADIY SOKOLOV	{"phone": "+70270144773"}
0005432104811	3EEACB	3761 431663	VLADIMIR VASILEV	{"email": "vasilev.vladimir_1973@postgrespro.ru", "phone": "+70770662286"}
0005432104812	3EEACB	1358 476833	DMITRIY ORLOV	{"email": "orlov-d-1962@postgrespro.ru", "phone": "+70650286437"}
0005432104813	ADF518	8183 636729	MARINA SMIRNOVA	{"email": "msmirnova-1989@postgrespro.ru", "phone": "+70261056417"}
0005432104814	ADF518	9522 205541	VLADISLAV KUZNECOV	{"email": "kuznecov-vladislav-1967@postgrespro.ru", "phone": "+70068317745"}
0005432104815	ADF518	3133 920257	NATALYA MOISEEVA	{"phone": "+70100681346"}
0005432104816	2591FF	3713 238414	ZHANNA MALYSHEVA	{"phone": "+70264993173"}
0005432104817	FDF1A6	3493 868530	ARTEM SIDOROV	{"phone": "+70814479450"}
0005432104818	FDF1A6	1384 307708	LEONID KARPOV	{"phone": "+70991912326"}
0005432104819	682654	6194 386784	MARIYA VOROBEVA	{"email": "vorobeva_mariya071971@postgrespro.ru", "phone": "+70719471287"}
0005432104820	682654	6191 905407	SERGEY ZAYCEV	{"phone": "+70836354772"}
0005432104821	E7657A	0071 310939	ALEKSANDR PETROV	{"phone": "+70094311060"}
0005432104822	E7657A	6966 414315	GALINA KOLESNIKOVA	{"phone": "+70574718404"}
0005432104823	99BB5E	2507 770616	VADIM MIRONOV	{"phone": "+70670481828"}
0005432104824	A5976B	5189 636244	IRINA ZOTOVA	{"phone": "+70446536599"}
0005432104825	A5976B	4167 828528	SERGEY KUZNECOV	{"phone": "+70134080825"}
0005432104826	694838	3188 756448	ALEKSANDRA ZHUKOVA	{"phone": "+70509358979"}
0005432104827	694838	3141 413826	PAVEL BORISOV	{"phone": "+70897243980"}
0005432104828	E22344	4727 044079	SERGEY SCHERBAKOV	{"email": "scherbakovsergey.03071977@postgrespro.ru", "phone": "+70629997637"}
0005432104829	E734F2	7137 259782	ANDREY MOROZOV	{"phone": "+70473603865"}
0005432104830	60F760	8043 412206	SVETLANA CHERNOVA	{"phone": "+70725912560"}
0005432104831	0984FA	6517 259929	MARINA FADEEVA	{"phone": "+70286368905"}
0005432104832	0984FA	4259 430336	OKSANA ARKHIPOVA	{"email": "arkhipova.o.081973@postgrespro.ru", "phone": "+70717179747"}
0005432104833	FF2A42	7160 704811	EVGENIY DAVYDOV	{"phone": "+70620023501"}
0005432104834	6D1E1F	0838 118355	IVAN VASILEV	{"email": "vasilev_i-091968@postgrespro.ru", "phone": "+70054442176"}
0005432104835	B3B846	1183 805513	ELENA ALEKSEEVA	{"email": "alekseeva.elena121993@postgrespro.ru", "phone": "+70229728768"}
0005432104836	B95C8D	4329 409594	LYUBOV IVANOVA	{"phone": "+70324105577"}
0005432104837	F5446D	9031 742607	EVGENIYA IVANOVA	{"email": "eivanova071952@postgrespro.ru", "phone": "+70685804844"}
0005432104838	F5446D	8975 818266	NINA FOMINA	{"phone": "+70332851481"}
0005432104839	A8631C	7650 655547	LIDIYA SIDOROVA	{"phone": "+70589129102"}
0005432104840	8F6336	0527 589345	NIKOLAY BARANOV	{"email": "nikolay.baranov-19101974@postgrespro.ru", "phone": "+70141755423"}
0005432104841	CDFABD	3159 006050	ELIZAVETA BOGDANOVA	{"email": "e.bogdanova-1969@postgrespro.ru", "phone": "+70950571859"}
0005432104842	CDFABD	2255 726538	MARAT MOISEEV	{"email": "moiseev.marat051976@postgrespro.ru", "phone": "+70672125356"}
0005432104843	FA157E	6424 850859	ZOYA FEDOROVA	{"phone": "+70474165278"}
0005432104844	FA157E	5923 361213	YURIY ZAYCEV	{"email": "zaycev_y.121975@postgrespro.ru", "phone": "+70310624031"}
0005432104845	FA157E	0142 259055	ANDREY ILIN	{"email": "ilin_andrey-1979@postgrespro.ru", "phone": "+70845175003"}
0005432104846	FA157E	0612 844127	ARTEM IVANOV	{"phone": "+70255524681"}
0005432104847	E154D6	8631 542636	LILIYA ISAEVA	{"email": "l.isaeva_28081978@postgrespro.ru", "phone": "+70217181926"}
0005432104848	E154D6	5952 023588	KIRILL KAZAKOV	{"phone": "+70028614640"}
0005432104849	CA34B4	2799 617089	ALEKSEY ANTONOV	{"phone": "+70074027380"}
0005432104850	2FB842	8822 471205	NIKOLAY TARASOV	{"email": "tarasov.n-071962@postgrespro.ru", "phone": "+70336926605"}
0005432104851	5D7436	0971 456937	FANIS ANTONOV	{"email": "fanis-antonov_041976@postgrespro.ru", "phone": "+70048718220"}
0005432104852	B3C85E	0498 796045	VALERIYA ZAYCEVA	{"email": "v.zayceva16121976@postgrespro.ru", "phone": "+70740011097"}
0005432104853	BEE382	1130 588151	VALENTINA SOLOVEVA	{"email": "v-soloveva-121985@postgrespro.ru", "phone": "+70497919391"}
0005432104854	7B8B2B	8062 423226	EKATERINA GORBUNOVA	{"email": "e_gorbunova1963@postgrespro.ru", "phone": "+70983880434"}
0005432104855	7B8B2B	2797 896151	GALINA DANILOVA	{"phone": "+70808732534"}
0005432104856	9FF157	2211 039463	IRINA MOROZOVA	{"email": "morozova-i1978@postgrespro.ru", "phone": "+70618712868"}
0005432104857	961457	3734 674466	IRINA SMIRNOVA	{"email": "irinasmirnova.031977@postgrespro.ru", "phone": "+70458793690"}
0005432104858	961457	9010 081316	ALEKSANDRA KALININA	{"email": "kalinina_aleksandra-13031972@postgrespro.ru", "phone": "+70868882555"}
0005432104859	FC45A4	5068 565482	MARIYA NOVIKOVA	{"email": "novikovam_05121975@postgrespro.ru", "phone": "+70190543497"}
0005432104860	FC45A4	9690 196349	IRINA EFIMOVA	{"email": "efimovai1973@postgrespro.ru", "phone": "+70295186104"}
0005432104861	786118	5785 093790	DENIS ZAYCEV	{"email": "d_zaycev1968@postgrespro.ru", "phone": "+70584520314"}
0005432104862	EB8981	5046 306983	TATYANA MATVEEVA	{"email": "tatyana-matveeva-071980@postgrespro.ru", "phone": "+70709240282"}
0005432104863	EB8981	0904 143878	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-29041979@postgrespro.ru", "phone": "+70125176557"}
0005432104864	692B53	1976 546897	EVGENIY GUSEV	{"phone": "+70042409203"}
0005432104865	692B53	8654 234068	ANNA FILIPPOVA	{"email": "anna-filippova-081961@postgrespro.ru", "phone": "+70559241994"}
0005432104866	1A2F64	9007 367584	ILYA MIRONOV	{"email": "mironovi.071989@postgrespro.ru", "phone": "+70099328041"}
0005432104867	1A2F64	7106 989137	ANTONIDA ZAKHAROVA	{"phone": "+70628804318"}
0005432104868	1A2F64	1701 855633	TATYANA IVANOVA	{"phone": "+70487696074"}
0005432104869	3F87AB	1274 422423	VLADIMIR NIKITIN	{"email": "nikitin-v-041971@postgrespro.ru", "phone": "+70583799940"}
0005432104870	7DD1EC	3274 899650	GALINA ABRAMOVA	{"phone": "+70920992482"}
0005432104871	7DD1EC	2507 097995	TATYANA BOGDANOVA	{"email": "t.bogdanova1981@postgrespro.ru", "phone": "+70201918396"}
0005432104872	577D67	3337 051436	YULIYA BORISOVA	{"email": "yuliya-borisova_081982@postgrespro.ru", "phone": "+70718056700"}
0005432104873	577D67	7626 616654	ELENA STEPANOVA	{"email": "estepanova.07061974@postgrespro.ru", "phone": "+70621268948"}
0005432104874	2977A5	6575 192846	ALLA PAVLOVA	{"email": "pavlova_alla_1978@postgrespro.ru", "phone": "+70858109555"}
0005432104875	2977A5	7317 538774	ALENA SOKOLOVA	{"email": "sokolova_a.091966@postgrespro.ru", "phone": "+70777822181"}
0005432104876	CFE724	6133 533648	LYUBOV SEMENOVA	{"email": "lsemenova_1954@postgrespro.ru", "phone": "+70872262566"}
0005432104877	CFE724	3702 015855	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov_1968@postgrespro.ru", "phone": "+70285792685"}
0005432104878	CFE724	9560 515716	IRINA FROLOVA	{"email": "irina_frolova1967@postgrespro.ru", "phone": "+70905483569"}
0005432104879	43AF80	4941 100995	GALINA POPOVA	{"email": "g.popova.121975@postgrespro.ru", "phone": "+70739209927"}
0005432104880	586486	5859 071462	ALENA NIKIFOROVA	{"email": "nikiforovaa-121976@postgrespro.ru", "phone": "+70110546494"}
0005432104881	2F20DC	1907 387509	IVAN ABRAMOV	{"email": "abramov_i.1969@postgrespro.ru", "phone": "+70891438152"}
0005432104882	AB2529	0489 705724	ANNA IVANOVA	{"email": "anna.ivanova.1981@postgrespro.ru", "phone": "+70116389520"}
0005432104883	450691	0084 142276	KARIM MAKAROV	{"phone": "+70958954256"}
0005432104884	232F7D	9016 081869	LYUBOV MASLOVA	{"email": "maslova_lyubov-25081964@postgrespro.ru", "phone": "+70995060291"}
0005432104885	A041F2	5617 061664	OLEG SERGEEV	{"phone": "+70190115479"}
0005432104886	06F0CE	6914 434836	VALENTINA AFANASEVA	{"phone": "+70370227529"}
0005432104887	B31E6F	2744 741845	LIDIYA MAKAROVA	{"email": "makarova_lidiya13081971@postgrespro.ru", "phone": "+70172133237"}
0005432104888	8AC736	1289 139483	VLADIMIR TARASOV	{"email": "vladimir.tarasov.25081968@postgrespro.ru", "phone": "+70819041249"}
0005432104889	CEBE41	7975 425325	TAMARA ZAYCEVA	{"phone": "+70154606724"}
0005432104890	ED7118	5374 120508	RUSLAN NIKITIN	{"email": "ruslan.nikitin061972@postgrespro.ru", "phone": "+70379519818"}
0005432104891	CC8589	6595 190802	NIKOLAY TARASOV	{"phone": "+70936991404"}
0005432104892	E69E13	4495 608466	NIKOLAY FILIPPOV	{"phone": "+70003354210"}
0005432104893	3D54B8	1276 843207	PETR KARPOV	{"email": "p_karpov.101979@postgrespro.ru", "phone": "+70768072809"}
0005432104894	A97CFA	6607 985237	EDUARD FEDOROV	{"email": "eduardfedorov_111973@postgrespro.ru", "phone": "+70215144638"}
0005432104895	045214	6457 546429	SERGEY EGOROV	{"email": "egorov.sergey-11081961@postgrespro.ru", "phone": "+70809423867"}
0005432104896	B0D4AA	1617 771498	TATYANA NESTEROVA	{"phone": "+70616485988"}
0005432104897	3B36FC	5075 929194	VALENTINA OSIPOVA	{"email": "v-osipova_1964@postgrespro.ru", "phone": "+70934885629"}
0005432104898	B0404F	3919 339590	ANNA KRASNOVA	{"email": "krasnova_a.091978@postgrespro.ru", "phone": "+70248844910"}
0005432104899	154DBD	1147 969183	DENIS FROLOV	{"phone": "+70461816276"}
0005432104900	C97A22	5869 342335	NIKOLAY GRIGOREV	{"email": "grigorevnikolay09111982@postgrespro.ru", "phone": "+70121865047"}
0005432104901	79D979	3939 217526	DMITRIY SHEVCHENKO	{"phone": "+70595876893"}
0005432104902	79D979	4140 532871	SVETLANA SMIRNOVA	{"phone": "+70295312982"}
0005432104903	79D979	5529 508349	VYACHESLAV SHEVCHENKO	{"phone": "+70588898516"}
0005432104904	030FEC	5697 867267	OKSANA IVANOVA	{"phone": "+70478365808"}
0005432104905	030FEC	6605 550783	GALINA KOVALEVA	{"phone": "+70139353002"}
0005432104906	BBA83A	3441 281391	IGOR BELOV	{"email": "igor.belov12071966@postgrespro.ru", "phone": "+70729001689"}
0005432104907	AEAAD4	8060 337717	OLEG MIRONOV	{"email": "mironov.o.101972@postgrespro.ru", "phone": "+70959634075"}
0005432104908	9CCD30	1295 974983	MARIYA KARPOVA	{"email": "mariya_karpova-031987@postgrespro.ru", "phone": "+70633208716"}
0005432104909	9CCD30	4128 356166	YULIYA ILINA	{"email": "yuliya_ilina10121968@postgrespro.ru", "phone": "+70553267658"}
0005432104910	052C7E	9466 070006	SERAFIMA IVANOVA	{"email": "serafimaivanova.1981@postgrespro.ru", "phone": "+70461594901"}
0005432104911	8176A7	3988 332582	MARIYA LOGINOVA	{"email": "mariya-loginova071963@postgrespro.ru", "phone": "+70669953953"}
0005432104912	8176A7	7982 265243	TATYANA FROLOVA	{"phone": "+70568947160"}
0005432104913	F6841D	0091 350603	DENIS YAKOVLEV	{"phone": "+70305930713"}
0005432104914	DA73D5	6864 395812	EVDOKIYA CHERNOVA	{"email": "e-chernova_101972@postgrespro.ru", "phone": "+70017010040"}
0005432104915	20C15D	0109 356782	YAKOV SEMENOV	{"phone": "+70938451988"}
0005432104916	ECBF89	3841 692993	SERGEY DAVYDOV	{"email": "davydov.s1971@postgrespro.ru", "phone": "+70254589756"}
0005432104917	ECBF89	7388 918881	EVGENIY ABRAMOV	{"email": "e.abramov.10041966@postgrespro.ru", "phone": "+70280486839"}
0005432104918	0AEAC7	4373 326343	ANDREY IVANOV	{"phone": "+70948337740"}
0005432104919	88DABD	5170 254029	EVGENIYA POPOVA	{"email": "e-popova_19051975@postgrespro.ru", "phone": "+70340896277"}
0005432104920	F84E18	6417 081753	IRINA NAZAROVA	{"phone": "+70507458993"}
0005432104921	27A98A	6336 924357	VARVARA SAVELEVA	{"phone": "+70680191170"}
0005432104922	2CBCCC	0580 580280	VERONIKA NAZAROVA	{"phone": "+70918598767"}
0005432104923	450392	7404 571173	NATALYA IVANOVA	{"phone": "+70923269609"}
0005432104924	8E01B6	2679 416682	LARISA RODIONOVA	{"email": "rodionova.l_1980@postgrespro.ru", "phone": "+70789142491"}
0005432104925	8E01B6	5889 696300	ALEKSEY ABRAMOV	{"email": "aleksey.abramov121969@postgrespro.ru", "phone": "+70291997983"}
0005432104926	AFEA99	5323 904975	EVGENIYA NOVIKOVA	{"phone": "+70639682574"}
0005432104927	B441B2	8316 330555	NINA NAUMOVA	{"email": "n-naumova.24111971@postgrespro.ru", "phone": "+70411063131"}
0005432104928	B441B2	9823 533146	MAKSIM MIKHAYLOV	{"phone": "+70141060165"}
0005432104929	7F91EE	4540 006369	ALINA OVCHINNIKOVA	{"phone": "+70645037672"}
0005432104930	54E93C	3793 873713	NADEZHDA SMIRNOVA	{"email": "smirnova.n.041965@postgrespro.ru", "phone": "+70885292117"}
0005432104931	54E93C	4980 893692	ROZA AFANASEVA	{"email": "afanaseva_roza-1981@postgrespro.ru", "phone": "+70636550959"}
0005432104932	94AFC3	5931 099709	MAKSIM SCHERBAKOV	{"email": "maksim-scherbakov.12061970@postgrespro.ru", "phone": "+70722415196"}
0005432104933	5B82E5	0691 071689	MARIYA KAZAKOVA	{"phone": "+70572128521"}
0005432104934	1E39F5	7824 365746	ROMAN YAKOVLEV	{"email": "roman.yakovlev-1968@postgrespro.ru", "phone": "+70301563044"}
0005432104935	D254A5	8948 120126	TATYANA EGOROVA	{"email": "t-egorova.23031966@postgrespro.ru", "phone": "+70041650501"}
0005432104936	8B1A0D	1287 063523	DENIS RODIONOV	{"email": "rodionovdenis.24011968@postgrespro.ru", "phone": "+70101384033"}
0005432104937	280D19	8967 013445	MARIYA FROLOVA	{"email": "mariya_frolova021975@postgrespro.ru", "phone": "+70116447619"}
0005432104938	280D19	5900 221836	ALEKSEY NAZAROV	{"email": "nazarova_11061976@postgrespro.ru", "phone": "+70098105195"}
0005432104939	D6FC26	9601 303575	SERGEY KULIKOV	{"phone": "+70409952806"}
0005432104940	BF61B1	9277 198030	MIKHAIL AFANASEV	{"email": "m-afanasev.19101972@postgrespro.ru", "phone": "+70744282355"}
0005432104941	06FE8C	7756 124859	KLAVDIYA PETROVA	{"phone": "+70808039132"}
0005432104942	371019	0649 542671	VLADIMIR PAVLOV	{"phone": "+70985536887"}
0005432104943	7ECBF9	5649 768115	TATYANA KUZNECOVA	{"email": "kuznecova.t-041979@postgrespro.ru", "phone": "+70276863177"}
0005432104944	149345	7528 105941	DANIIL KUZMIN	{"phone": "+70566587528"}
0005432104945	149345	1572 703840	DARYA MAKAROVA	{"email": "makarova-darya_04121979@postgrespro.ru", "phone": "+70012067171"}
0005432104946	A0DE9C	4155 810667	MARIYA MATVEEVA	{"email": "matveeva_m.24121972@postgrespro.ru", "phone": "+70121627258"}
0005432104947	9E51E3	5224 835492	VALENTIN PAVLOV	{"email": "vpavlov-07081969@postgrespro.ru", "phone": "+70062662795"}
0005432104948	46646B	0881 628870	NIKOLAY KUZNECOV	{"email": "kuznecov-n1974@postgrespro.ru", "phone": "+70217951545"}
0005432104949	A5A614	2482 572110	GALINA IVANOVA	{"email": "ivanova_galina1979@postgrespro.ru", "phone": "+70046933487"}
0005432104950	1B6F8B	3105 887540	SERGEY SIDOROV	{"email": "sidorov-sergey061973@postgrespro.ru", "phone": "+70790497237"}
0005432104951	1B6F8B	1809 450946	VENERA MIRONOVA	{"email": "mironova-v041978@postgrespro.ru", "phone": "+70200924750"}
0005432104952	D83492	5456 975459	NATALYA ANTONOVA	{"email": "nantonova_1970@postgrespro.ru", "phone": "+70665901133"}
0005432104953	D83492	5530 504369	VLADIMIR BELOV	{"phone": "+70329503099"}
0005432104954	42A915	5994 747942	MARIYA KUZNECOVA	{"phone": "+70595165582"}
0005432104955	23723E	2801 554303	NIKOLAY TARASOV	{"phone": "+70378652403"}
0005432104956	53F053	7792 902737	STANISLAV ZAKHAROV	{"phone": "+70344168680"}
0005432104957	53F053	7703 231898	OKSANA NIKITINA	{"email": "nikitinaoksana-25081962@postgrespro.ru", "phone": "+70815441286"}
0005432104958	30F4BE	9865 668415	NINA FEDOROVA	{"phone": "+70252810079"}
0005432104959	85AE97	9669 475457	ALEKSEY ANDREEV	{"phone": "+70807845304"}
0005432104960	6FD980	9336 355993	ALEKSANDR BORISOV	{"email": "aleksandrborisov041966@postgrespro.ru", "phone": "+70457690002"}
0005432104961	E3D9F1	2038 748757	ELENA LAZAREVA	{"email": "elena-lazareva-1975@postgrespro.ru", "phone": "+70021738713"}
0005432104962	E8624A	9226 273138	ELENA MELNIKOVA	{"email": "melnikova_elena.31121981@postgrespro.ru", "phone": "+70138612642"}
0005432104963	8D98A8	4086 732125	MAKSIM BORISOV	{"phone": "+70845641112"}
0005432104964	0C7630	7902 174987	TATYANA NIKITINA	{"phone": "+70812532583"}
0005432104965	0C7630	4464 446003	TAMARA ZAYCEVA	{"email": "zayceva_tamara_23111985@postgrespro.ru", "phone": "+70587161185"}
0005432104966	B188B4	5640 515580	GALIYA ZAYCEVA	{"phone": "+70834331942"}
0005432104967	03EA59	9421 308633	TATYANA STEPANOVA	{"email": "tstepanova_1979@postgrespro.ru", "phone": "+70720402816"}
0005432104968	03EA59	9691 927429	NIKOLAY TIKHONOV	{"email": "tikhonov-nikolay101961@postgrespro.ru", "phone": "+70491918632"}
0005432104969	CC47B3	9701 189899	IGOR KUZNECOV	{"email": "i-kuznecov.1960@postgrespro.ru", "phone": "+70240492597"}
0005432104970	594812	1970 871089	SERGEY KUDRYASHOV	{"phone": "+70903423847"}
0005432104971	ACDF08	4677 897885	INNA BELOVA	{"phone": "+70319860502"}
0005432104972	1858D3	1837 828312	LYUBOV ABRAMOVA	{"email": "lyubov_abramova05061982@postgrespro.ru", "phone": "+70719632304"}
0005432104973	67148F	3590 373819	KSENIYA KUZNECOVA	{"email": "kuznecova_kseniya15111973@postgrespro.ru", "phone": "+70346050817"}
0005432104974	1BFCF9	0916 249403	OLEG ZHURAVLEV	{"email": "zhuravlev.o-25101975@postgrespro.ru", "phone": "+70060547707"}
0005432104975	05EEDF	4724 385502	LYUDMILA VASILEVA	{"phone": "+70029027890"}
0005432104976	05EEDF	4040 277859	SERGEY STEPANOV	{"phone": "+70548162286"}
0005432104977	3594BF	4508 857426	GALINA SOROKINA	{"phone": "+70093455329"}
0005432104978	3594BF	8146 071766	ANDREY POPOV	{"phone": "+70595885447"}
0005432104979	F45184	8800 038136	ELENA SOKOLOVA	{"phone": "+70883021501"}
0005432104980	F45184	1995 850688	NATALYA FOMINA	{"email": "natalya.fomina1982@postgrespro.ru", "phone": "+70802674493"}
0005432104981	C9118C	4213 552060	OLGA KISELEVA	{"email": "kiseleva.olga_041967@postgrespro.ru", "phone": "+70481200749"}
0005432104982	87E5CD	2686 952071	MATVEY ANTONOV	{"phone": "+70212629680"}
0005432104983	87E5CD	0117 915266	DINA NAUMOVA	{"phone": "+70542871795"}
0005432104984	D8B713	2638 232230	ALENA KOROLEVA	{"email": "koroleva.alena_1982@postgrespro.ru", "phone": "+70754703299"}
0005432104985	4CCBB2	7534 364629	ELENA ANTONOVA	{"phone": "+70097768862"}
0005432104986	595807	2888 180253	ALEKSANDR BORISOV	{"phone": "+70781873711"}
0005432104987	617287	5604 529325	EVGENIYA ARKHIPOVA	{"email": "evgeniyaarkhipova17061976@postgrespro.ru", "phone": "+70431102861"}
0005432104988	7CD09F	3615 325392	NIKOLAY ISAEV	{"phone": "+70808608833"}
0005432104989	EE4858	7394 136752	SERGEY KRASNOV	{"phone": "+70028719200"}
0005432104990	40601E	5162 084857	ANTON VOLKOV	{"phone": "+70959697541"}
0005432104991	40601E	6397 845118	VENERA ALEKSEEVA	{"email": "alekseeva-v-1968@postgrespro.ru", "phone": "+70738584638"}
0005432104992	A33F6C	2201 044969	EKATERINA BORISOVA	{"phone": "+70964488452"}
0005432104993	475FA3	5525 034971	NADEZHDA PETROVA	{"phone": "+70183026118"}
0005432104994	3AA45B	9464 526133	VERA FILATOVA	{"email": "filatovav.1964@postgrespro.ru", "phone": "+70471236106"}
0005432104995	3AA45B	4733 137381	EKATERINA MEDVEDEVA	{"phone": "+70834169502"}
0005432104996	3AA45B	9510 901150	SVETLANA OSIPOVA	{"email": "osipova.svetlana.31081982@postgrespro.ru", "phone": "+70778077531"}
0005432104997	CF5AC4	2358 196537	IGOR ANTONOV	{"phone": "+70805227855"}
0005432104998	CF5AC4	4705 889233	TATYANA BOGDANOVA	{"email": "bogdanova_t_121977@postgrespro.ru", "phone": "+70415009691"}
0005432104999	73F249	2224 696184	OLEG ANTONOV	{"email": "antonov.oleg-121973@postgrespro.ru", "phone": "+70177435579"}
0005432105000	610BA6	0325 136383	ALEKSANDR BARANOV	{"phone": "+70461764789"}
0005432105001	70A02B	3204 271792	GALINA IVANOVA	{"email": "ivanovagalina.011973@postgrespro.ru", "phone": "+70854717952"}
0005432105002	BA849F	0261 072245	LARISA KALININA	{"phone": "+70988118280"}
0005432105003	BA849F	3289 377769	YULIYA KALININA	{"phone": "+70122851941"}
0005432105004	BA849F	9990 358743	GALINA TARASOVA	{"phone": "+70017019224"}
0005432105005	BC710E	4665 347401	TAMARA SERGEEVA	{"email": "tamarasergeeva-061966@postgrespro.ru", "phone": "+70322587142"}
0005432105006	00FF90	8986 478611	NATALYA STEPANOVA	{"email": "natalyastepanova.071981@postgrespro.ru", "phone": "+70101134761"}
0005432105007	6C346F	8496 399122	EKATERINA SOROKINA	{"phone": "+70938075621"}
0005432105008	672C30	6007 831900	DMITRIY KULIKOV	{"email": "kulikov-dmitriy_21081975@postgrespro.ru", "phone": "+70620833461"}
0005432105009	8B3AAD	2858 045592	ILYA IVANOV	{"email": "ivanov_i_29041981@postgrespro.ru", "phone": "+70763962165"}
0005432105010	7DE379	7043 946053	MARIYA MAKSIMOVA	{"phone": "+70004859504"}
0005432105011	6B2CA6	0435 816769	NADEZHDA ISAEVA	{"email": "nadezhda-isaeva-071973@postgrespro.ru", "phone": "+70424087760"}
0005432105012	7E025C	8063 960123	VIKTORIYA IVANOVA	{"email": "ivanovav-07091966@postgrespro.ru", "phone": "+70787278431"}
0005432105013	F1B8CF	6646 596420	ANNA SCHERBAKOVA	{"email": "ascherbakova041980@postgrespro.ru", "phone": "+70559427380"}
0005432105014	AE1BB0	1606 973186	DIANA KRASNOVA	{"phone": "+70168667359"}
0005432105015	7E7FCA	9841 985478	IGOR ISAEV	{"email": "i.isaev1968@postgrespro.ru", "phone": "+70706146264"}
0005432105016	7E7FCA	4224 771034	VYACHESLAV SAVELEV	{"email": "savelevvyacheslav1969@postgrespro.ru", "phone": "+70571459134"}
0005432105017	210A4D	4410 278788	SVETLANA EGOROVA	{"phone": "+70294252086"}
0005432105018	5DA8F8	6870 904065	NIKOLAY YAKOVLEV	{"email": "nikolay.yakovlev.09051973@postgrespro.ru", "phone": "+70084964960"}
0005432105019	D255C2	6860 225892	ALEKSANDRA NESTEROVA	{"email": "nesterovaa_1977@postgrespro.ru", "phone": "+70091855762"}
0005432105020	D255C2	6853 428430	SVETLANA MARTYNOVA	{"phone": "+70747708328"}
0005432105021	D4126C	7726 586998	ANASTASIYA ALEKSEEVA	{"email": "a.alekseeva-13021972@postgrespro.ru", "phone": "+70405884907"}
0005432105022	D4126C	6925 819972	LARISA EFREMOVA	{"phone": "+70635482302"}
0005432105023	35E90D	4049 641382	KIRILL IVANOV	{"email": "ivanovk081967@postgrespro.ru", "phone": "+70022905391"}
0005432105024	9A3905	5337 095931	KONSTANTIN KRASNOV	{"phone": "+70092412614"}
0005432105025	FBD346	1174 680601	RAISA BELYAEVA	{"phone": "+70391826901"}
0005432105026	AD32CA	6126 309874	VLADISLAV STEPANOV	{"phone": "+70425346300"}
0005432105027	AD32CA	3194 785265	VLADIMIR AFANASEV	{"email": "afanasev_vladimir30041970@postgrespro.ru", "phone": "+70913229121"}
0005432105028	4DF152	8022 026644	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr051977@postgrespro.ru", "phone": "+70447424846"}
0005432105029	811353	6626 439244	NIKOLAY FILIPPOV	{"email": "filippovn_26061970@postgrespro.ru", "phone": "+70115645934"}
0005432105030	C288A7	4363 889468	MAKSIM KUZMIN	{"phone": "+70088063267"}
0005432105031	95A089	9574 945523	NATALYA TIKHONOVA	{"phone": "+70047818127"}
0005432105032	4E5348	0517 175432	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr1983@postgrespro.ru", "phone": "+70340272416"}
0005432105033	4E5348	8652 340807	NIKOLAY SCHERBAKOV	{"phone": "+70939644309"}
0005432105034	D1461A	5807 602062	LYUDMILA NAZAROVA	{"phone": "+70425823117"}
0005432105035	E0AC4A	1644 022268	ALENA GAVRILOVA	{"phone": "+70318575335"}
0005432105036	E0AC4A	5980 022616	NATALYA KUZNECOVA	{"email": "n.kuznecova-19121978@postgrespro.ru", "phone": "+70728208181"}
0005432105037	78DD0A	0662 244070	ALEKSANDR KOZLOV	{"email": "a_kozlov081981@postgrespro.ru", "phone": "+70204540075"}
0005432105038	AC1CC9	0202 211650	VYACHESLAV GERASIMOV	{"email": "gerasimovv101976@postgrespro.ru", "phone": "+70610240390"}
0005432105039	055F7F	0460 916270	DMITRIY EGOROV	{"phone": "+70306835954"}
0005432105040	055F7F	5984 210559	VLADISLAV MAKSIMOV	{"phone": "+70018400785"}
0005432105041	055F7F	6362 203115	NIKOLAY TIMOFEEV	{"phone": "+70553337529"}
0005432105042	00BDAD	3355 612384	IVAN STEPANOV	{"phone": "+70567357595"}
0005432105043	658A3A	2305 931958	INESSA GUSEVA	{"email": "guseva.inessa_061964@postgrespro.ru", "phone": "+70330343555"}
0005432105044	2FF6A0	1428 493140	KONSTANTIN ZHUKOV	{"phone": "+70727181521"}
0005432105045	F976B2	8848 569070	VADIM SMIRNOV	{"email": "vsmirnov091974@postgrespro.ru", "phone": "+70535347428"}
0005432105046	7F8648	4448 169871	LIDIYA DENISOVA	{"email": "l-denisova18041975@postgrespro.ru", "phone": "+70618198684"}
0005432105047	A4FE2A	1556 008011	SVETLANA NOVIKOVA	{"phone": "+70122443215"}
0005432105048	A4FE2A	9793 939516	VYACHESLAV EGOROV	{"phone": "+70551431563"}
0005432105049	CC8EE4	6205 920125	TATYANA FROLOVA	{"email": "tatyana_frolova_081978@postgrespro.ru", "phone": "+70235168697"}
0005432105050	2398C4	4993 667244	VIKTOR SAVELEV	{"email": "viktor.savelev-03111979@postgrespro.ru", "phone": "+70872314963"}
0005432105051	7DF5EE	5337 858966	TATYANA ALEKSEEVA	{"email": "talekseeva_1977@postgrespro.ru", "phone": "+70646160936"}
0005432105052	EE0662	1884 059282	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaa.09031984@postgrespro.ru", "phone": "+70551512488"}
0005432105053	EE0662	2651 205702	VLADIMIR OSIPOV	{"phone": "+70573224757"}
0005432105054	DBBA2E	2493 741884	SVETLANA IVANOVA	{"email": "ivanovasvetlana-07011983@postgrespro.ru", "phone": "+70780805201"}
0005432105055	F68B9D	0747 519884	NIKITA KULIKOV	{"phone": "+70553770826"}
0005432105056	F68B9D	6005 435723	VALENTINA GERASIMOVA	{"phone": "+70095735245"}
0005432105057	F68B9D	8928 708255	OLGA KUZNECOVA	{"phone": "+70002267240"}
0005432105058	49286D	6888 519629	YULIYA MATVEEVA	{"phone": "+70449453993"}
0005432105059	4BC209	3201 465928	OLEG NIKOLAEV	{"phone": "+70864352581"}
0005432105060	644C28	0954 946960	TATYANA VASILEVA	{"email": "t.vasileva.10051984@postgrespro.ru", "phone": "+70059843650"}
0005432105061	66DD6D	6363 100663	NATALYA FEDOROVA	{"email": "natalya-fedorova-011975@postgrespro.ru", "phone": "+70536576607"}
0005432105062	B7AB44	3994 963658	MARINA ILINA	{"phone": "+70274387241"}
0005432105063	044310	8787 340890	VLADIMIR FILIPPOV	{"email": "vladimir-filippov.22071959@postgrespro.ru", "phone": "+70684033853"}
0005432105064	8E0190	9944 634135	YURIY VOLKOV	{"email": "volkov-y_011971@postgrespro.ru", "phone": "+70199351220"}
0005432105065	5CCA19	6285 476188	INNA VLASOVA	{"phone": "+70439618439"}
0005432105066	5CCA19	1795 945889	LIDIYA NESTEROVA	{"email": "lnesterova1973@postgrespro.ru", "phone": "+70312492643"}
0005432105067	5CCA19	3823 771134	SERGEY NIKOLAEV	{"email": "nikolaev_sergey13081979@postgrespro.ru", "phone": "+70298461130"}
0005432105068	BD57E5	4946 521127	ROZA RODIONOVA	{"email": "rodionova_roza_31031970@postgrespro.ru", "phone": "+70343664625"}
0005432105069	42D013	6687 122978	ANDREY ZAKHAROV	{"email": "andrey_zakharov1986@postgrespro.ru", "phone": "+70748513664"}
0005432105070	F25464	4897 246437	KONSTANTIN ZHURAVLEV	{"email": "konstantin-zhuravlev-071963@postgrespro.ru", "phone": "+70754857652"}
0005432105071	F25464	0365 402702	GENNADIY POPOV	{"email": "popov_gennadiy_041957@postgrespro.ru", "phone": "+70788919742"}
0005432105072	A56C90	5915 319662	NIKOLAY TIKHONOV	{"phone": "+70311601269"}
0005432105073	72F4B4	7182 894458	OLEG KUZNECOV	{"phone": "+70002580813"}
0005432105074	1CC016	2679 486950	SERGEY VOLKOV	{"email": "sergey-volkov081970@postgrespro.ru", "phone": "+70894991202"}
0005432105075	1D3FE8	7066 498178	TATYANA BORISOVA	{"email": "tatyana-borisova.18111967@postgrespro.ru", "phone": "+70711153826"}
0005432105076	1D3FE8	7993 626578	SERGEY MAKSIMOV	{"email": "maksimov_s-1970@postgrespro.ru", "phone": "+70357127601"}
0005432105077	D454AF	7821 128107	VLADIMIR BORISOV	{"email": "borisovv_1982@postgrespro.ru", "phone": "+70425145348"}
0005432105078	D454AF	5314 704248	ALEKSANDR POPOV	{"email": "popov-aleksandr1981@postgrespro.ru", "phone": "+70507193772"}
0005432105079	C15006	0231 805821	VIKTOR KOZLOV	{"email": "viktor-kozlov-09081975@postgrespro.ru", "phone": "+70035143601"}
0005432105080	C15006	6549 774420	ALEKSANDR MOISEEV	{"email": "moiseevaleksandr.1969@postgrespro.ru", "phone": "+70016923049"}
0005432105081	123972	8508 728926	MIROSLAV POPOV	{"email": "popov_m.05031972@postgrespro.ru", "phone": "+70779431915"}
0005432105082	96E663	4285 260774	VITALIY BORISOV	{"phone": "+70378878715"}
0005432105083	2EC338	3911 418071	SERGEY SOROKIN	{"phone": "+70620447994"}
0005432105084	056C13	3966 480430	PETR POPOV	{"email": "ppopov_21111969@postgrespro.ru", "phone": "+70494899358"}
0005432105085	336401	5791 524225	ALEKSANDR NAZAROV	{"phone": "+70666186895"}
0005432105086	062C49	7615 548410	YURIY SERGEEV	{"phone": "+70557802706"}
0005432105087	062C49	1906 487000	VERONIKA NAZAROVA	{"email": "veronika.nazarova-1985@postgrespro.ru", "phone": "+70632034378"}
0005432105088	65E21A	5509 629490	VLADIMIR EGOROV	{"email": "egorov.vladimir_06111971@postgrespro.ru", "phone": "+70085647157"}
0005432105089	E254C1	7276 356360	ULYANA NAZAROVA	{"email": "nazarovau_031974@postgrespro.ru", "phone": "+70470435726"}
0005432105090	FBB120	2606 525792	ELMIRA ROMANOVA	{"email": "e.romanova_121976@postgrespro.ru", "phone": "+70971212394"}
0005432105091	C1CD04	3529 839547	SULTAN KRASNOV	{"phone": "+70114805780"}
0005432105092	C1CD04	7275 887685	SERGEY PAVLOV	{"email": "s-pavlov-031959@postgrespro.ru", "phone": "+70703459674"}
0005432105093	A1C8B7	3937 800670	IRINA KUDRYASHOVA	{"email": "irinakudryashova_12101964@postgrespro.ru", "phone": "+70212988770"}
0005432105094	0A54C1	5494 510397	MAKSIM GERASIMOV	{"phone": "+70780585001"}
0005432105095	0A54C1	5602 680882	MARAT TIKHONOV	{"email": "marattikhonov-1979@postgrespro.ru", "phone": "+70382017793"}
0005432105096	9B1FDC	7752 801434	VALENTINA IVANOVA	{"email": "ivanova_valentina101970@postgrespro.ru", "phone": "+70749336750"}
0005432105097	9B1FDC	1040 657414	ANDREY POPOV	{"phone": "+70099448693"}
0005432105098	DB7187	3176 762577	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov-1968@postgrespro.ru", "phone": "+70373527340"}
0005432105099	BD7829	4280 364188	ELENA SOROKINA	{"phone": "+70617802982"}
0005432105100	BD7829	1371 523001	NADEZHDA POLYAKOVA	{"email": "n_polyakova_101964@postgrespro.ru", "phone": "+70911338012"}
0005432105101	1A66F1	5128 528450	MARIYA LUKYANOVA	{"email": "mariyalukyanova091968@postgrespro.ru", "phone": "+70470838354"}
0005432105103	24352C	1979 595090	ANASTASIYA ALEKSEEVA	{"phone": "+70455778447"}
0005432105104	3F4CE9	7425 223027	PAVEL KISELEV	{"phone": "+70710667678"}
0005432105105	3F4CE9	4920 784687	ALEKSANDR ABRAMOV	{"email": "abramova_27021972@postgrespro.ru", "phone": "+70933296059"}
0005432105106	F4365F	3150 905514	ANDREY TIMOFEEV	{"email": "a-timofeev-1978@postgrespro.ru", "phone": "+70691548264"}
0005432105107	F4365F	8996 372868	LYUDMILA POTAPOVA	{"phone": "+70480487458"}
0005432105108	461BFD	6108 306378	VALERIY MAKAROV	{"phone": "+70729017705"}
0005432105109	86E05E	5542 602942	ALEKSANDR POPOV	{"phone": "+70503387507"}
0005432105110	775D41	5423 123279	EKATERINA ZOTOVA	{"email": "e_zotova-1970@postgrespro.ru", "phone": "+70816841079"}
0005432105111	BBCA26	4362 533178	NADEZHDA POPOVA	{"email": "n-popova_091968@postgrespro.ru", "phone": "+70193461155"}
0005432105112	B81225	0414 962665	SERGEY POPOV	{"email": "s-popov.16101986@postgrespro.ru", "phone": "+70544003721"}
0005432105113	9AE382	9277 777422	ANDREY AFANASEV	{"phone": "+70850335408"}
0005432105114	9E626D	5651 581746	SVETLANA TITOVA	{"email": "s.titova-15101985@postgrespro.ru", "phone": "+70186161780"}
0005432105115	CFF8C0	4533 677493	ZINAIDA KOVALEVA	{"email": "z-kovaleva-15081978@postgrespro.ru", "phone": "+70862194716"}
0005432105116	A40520	5093 035042	VALENTINA MAKAROVA	{"email": "v.makarova-101971@postgrespro.ru", "phone": "+70469189007"}
0005432105285	EA3D66	4761 285220	ELENA STEPANOVA	{"phone": "+70440007341"}
0005432105117	19A9A7	5416 930240	TATYANA AFANASEVA	{"email": "afanaseva.tatyana-1970@postgrespro.ru", "phone": "+70478104583"}
0005432105118	47DA74	2590 804622	NATALYA FOMINA	{"email": "fominanatalya.11061966@postgrespro.ru", "phone": "+70292449853"}
0005432105119	26D8E7	3699 843009	VALERIY SERGEEV	{"phone": "+70308501172"}
0005432105120	BCB8B1	9825 994106	ELENA KONOVALOVA	{"email": "elena-konovalova.1967@postgrespro.ru", "phone": "+70591939599"}
0005432105121	BCB8B1	7392 680417	ALEKSANDR MIRONOV	{"phone": "+70128670540"}
0005432105122	14E832	7817 582572	YULIYA PETROVA	{"email": "ypetrova_091971@postgrespro.ru", "phone": "+70207548163"}
0005432105123	A26E64	9898 316342	VALENTINA SERGEEVA	{"email": "sergeeva.valentina_121980@postgrespro.ru", "phone": "+70817898678"}
0005432105124	D2707D	8090 858127	VALENTINA RYABOVA	{"email": "valentinaryabova1972@postgrespro.ru", "phone": "+70079273572"}
0005432105125	D2707D	6413 580132	IVAN VASILEV	{"email": "vasilev.i.22111975@postgrespro.ru", "phone": "+70592434507"}
0005432105126	87599E	2292 578903	PAVEL KRASNOV	{"email": "krasnov.p1966@postgrespro.ru", "phone": "+70763591274"}
0005432105127	87599E	4527 851687	NATALYA MOISEEVA	{"phone": "+70213574586"}
0005432105128	D25ABB	4070 914028	ELENA FILATOVA	{"phone": "+70616202290"}
0005432105129	EA78C7	6966 935451	ALEKSANDR PETROV	{"phone": "+70700345808"}
0005432105130	9CCFEF	3563 926506	NIKOLAY SOROKIN	{"email": "n_sorokin-1963@postgrespro.ru", "phone": "+70981357865"}
0005432105131	7E353E	2314 683976	SVETLANA BELYAEVA	{"phone": "+70714556614"}
0005432105132	7E353E	6175 969480	NATALYA AFANASEVA	{"phone": "+70332842415"}
0005432105133	CEF26A	6917 741821	SVETLANA TIKHONOVA	{"email": "s.tikhonova.081981@postgrespro.ru", "phone": "+70563896838"}
0005432105134	1D2853	0877 270282	EKATERINA SMIRNOVA	{"phone": "+70988245767"}
0005432105135	1D2853	5919 048278	RAMIS FILIPPOV	{"email": "r.filippov.041972@postgrespro.ru", "phone": "+70049005079"}
0005432105136	BC8028	7343 936801	DENIS GRIGOREV	{"phone": "+70184247146"}
0005432105137	8A8DDF	0973 259083	NURLAN ALEKSANDROV	{"email": "aleksandrov_nurlan_11011978@postgrespro.ru", "phone": "+70915652726"}
0005432105138	7F0899	0669 600738	GALINA NIKOLAEVA	{"email": "nikolaevag_111983@postgrespro.ru", "phone": "+70365307829"}
0005432105139	BE53F3	7610 068379	VLADIMIR SOROKIN	{"email": "vladimirsorokin081978@postgrespro.ru", "phone": "+70468582988"}
0005432105140	844CE2	1603 511243	ARTEM FROLOV	{"phone": "+70446139785"}
0005432105141	011A1D	4887 339137	EVGENIY POPOV	{"email": "e-popov_13101974@postgrespro.ru", "phone": "+70442120685"}
0005432105142	1DA8C3	3712 467727	ANDREY ZHURAVLEV	{"phone": "+70832159342"}
0005432105143	0BE98D	1937 251138	VLADISLAV NIKOLAEV	{"phone": "+70030796865"}
0005432105144	9DBC74	7429 674968	OLEG SCHERBAKOV	{"email": "o-scherbakov_101973@postgrespro.ru", "phone": "+70312004117"}
0005432105145	9DBC74	5511 943509	DENIS KAZAKOV	{"email": "denis.kazakov-24041977@postgrespro.ru", "phone": "+70434299196"}
0005432105146	381482	5604 256301	NATALYA KOROLEVA	{"phone": "+70511226607"}
0005432105147	075793	4871 451770	VALENTINA POLYAKOVA	{"email": "polyakovavalentina_1973@postgrespro.ru", "phone": "+70643338573"}
0005432105148	075793	2128 506749	IGOR FOMIN	{"phone": "+70045629269"}
0005432105149	C530F4	4026 595802	ALINA ISAEVA	{"phone": "+70294866505"}
0005432105150	42A55F	5791 170675	TAGIR KUZMIN	{"email": "tagir.kuzmin.16011962@postgrespro.ru", "phone": "+70148492544"}
0005432105151	CCF14B	8026 542379	IGOR KOZLOV	{"email": "i.kozlov_021980@postgrespro.ru", "phone": "+70049003261"}
0005432105152	CCF14B	6178 104257	LYUBOV ILINA	{"phone": "+70869405457"}
0005432105153	E9A7D9	4758 637402	VIKTOR MEDVEDEV	{"phone": "+70851933394"}
0005432105154	E9A7D9	0006 051130	IVAN SIDOROV	{"phone": "+70619300003"}
0005432105155	E9A7D9	9558 974024	TATYANA KONOVALOVA	{"phone": "+70450254135"}
0005432105156	D09E44	1867 435585	MIKHAIL OSIPOV	{"phone": "+70028881296"}
0005432105157	D09E44	0093 435792	OLGA NIKIFOROVA	{"phone": "+70415784514"}
0005432105158	28134C	3404 019211	YURIY KULIKOV	{"email": "yuriy-kulikov-1978@postgrespro.ru", "phone": "+70069153677"}
0005432105159	A10094	9908 981100	IRINA NOVIKOVA	{"phone": "+70574542481"}
0005432105160	A10094	9301 468870	EVGENIY MELNIKOV	{"email": "melnikov-e.1968@postgrespro.ru", "phone": "+70152377222"}
0005432105161	C1B16C	9037 302150	NADEZHDA SCHERBAKOVA	{"phone": "+70675944945"}
0005432105399	EA633E	0071 591944	OLEG KUZMIN	{"phone": "+70440088117"}
0005432105162	B83CE3	3602 374343	IRINA AFANASEVA	{"email": "afanaseva_i12051974@postgrespro.ru", "phone": "+70545568961"}
0005432105163	276A71	5456 383039	KLAVDIYA POLYAKOVA	{"phone": "+70126171232"}
0005432105164	4AAC59	3129 211057	VYACHESLAV STEPANOV	{"email": "stepanov-v.021979@postgrespro.ru", "phone": "+70884568628"}
0005432105165	4AAC59	8364 054449	VLADIMIR MOROZOV	{"email": "v_morozov111961@postgrespro.ru", "phone": "+70930931951"}
0005432105166	9E26E4	4440 505599	ANNA ZHURAVLEVA	{"email": "zhuravleva_anna_07061976@postgrespro.ru", "phone": "+70508493297"}
0005432105167	9E26E4	9818 638317	YULIYA POPOVA	{"phone": "+70412270069"}
0005432105168	B9FDD1	6713 005004	LIDIYA KUDRYASHOVA	{"email": "kudryashova-lidiya-111978@postgrespro.ru", "phone": "+70773702598"}
0005432105169	B9FDD1	9471 767513	ILDAR KUZNECOV	{"email": "ildar-kuznecov.29081964@postgrespro.ru", "phone": "+70447290447"}
0005432105170	EFDF84	2324 005983	NIKITA GRIGOREV	{"phone": "+70138718431"}
0005432105171	03EB3B	6933 525999	KONSTANTIN STEPANOV	{"phone": "+70560230836"}
0005432105172	86DCF0	2041 241061	LYUDMILA SAVELEVA	{"phone": "+70418886015"}
0005432105173	DAC8E0	3788 831011	ANASTASIYA TARASOVA	{"email": "tarasova_anastasiya_10041973@postgrespro.ru", "phone": "+70595336712"}
0005432105174	FE2996	9720 383650	VASILIY SOROKIN	{"email": "v.sorokin.1964@postgrespro.ru", "phone": "+70146904743"}
0005432105175	74BB40	1030 236006	ANASTASIYA CHERNOVA	{"phone": "+70850066317"}
0005432105176	0EAEC6	3841 689778	LYUDMILA TIKHONOVA	{"email": "l.tikhonova-1970@postgrespro.ru", "phone": "+70001439576"}
0005432105177	0EAEC6	8654 418282	NINA BORISOVA	{"phone": "+70064929089"}
0005432105178	72E423	5188 095338	EVGENIY SIDOROV	{"phone": "+70741805772"}
0005432105179	72E423	6320 408311	IGOR EGOROV	{"email": "egorovi_1976@postgrespro.ru", "phone": "+70301973800"}
0005432105180	A12D7D	7645 152193	MARIYA KARPOVA	{"email": "mariya_karpova041980@postgrespro.ru", "phone": "+70645007814"}
0005432105181	DA4429	7249 046099	RUSLAN MAKAROV	{"phone": "+70301653769"}
0005432105182	EC3140	5309 338100	LYUDMILA KUZNECOVA	{"phone": "+70119162353"}
0005432105183	6BB136	7427 981399	PAVEL MOISEEV	{"email": "moiseev.pavel.1968@postgrespro.ru", "phone": "+70386190298"}
0005432105184	7C4C13	8203 887422	ELENA CHERNOVA	{"phone": "+70565020818"}
0005432105185	554AF4	6156 217328	NADEZHDA ZHURAVLEVA	{"phone": "+70594874160"}
0005432105186	554AF4	7575 316416	VIKTOR ROMANOV	{"email": "viktor_romanov.1980@postgrespro.ru", "phone": "+70785035316"}
0005432105187	B51FEA	7062 079166	ALINA NESTEROVA	{"email": "a.nesterova.23081982@postgrespro.ru", "phone": "+70754696526"}
0005432105188	2EA174	2925 830348	VLADIMIR IVANOV	{"phone": "+70155179511"}
0005432105189	0B51F8	3435 722644	ELENA LEBEDEVA	{"phone": "+70543651118"}
0005432105190	86F81E	9279 775094	VALENTINA KISELEVA	{"email": "kiseleva_v21121972@postgrespro.ru", "phone": "+70881190939"}
0005432105191	4D2B68	7895 735175	RAISA KUZMINA	{"phone": "+70403870720"}
0005432105192	4D2B68	8795 799891	NATALYA GRISHINA	{"email": "n_grishina_02021981@postgrespro.ru", "phone": "+70429741680"}
0005432105193	E4CA81	9257 179948	IVAN ZAYCEV	{"email": "zaycev.i-17081975@postgrespro.ru", "phone": "+70791356467"}
0005432105194	16ED28	1683 710133	IVAN MIRONOV	{"phone": "+70853061246"}
0005432105195	5D09F9	2132 318080	SVETLANA POPOVA	{"phone": "+70722468104"}
0005432105196	5D09F9	7534 656171	NIKOLAY GORBUNOV	{"email": "gorbunov-n_1969@postgrespro.ru", "phone": "+70733222630"}
0005432105197	17EBA2	6505 012459	VLADIMIR KRASNOV	{"email": "krasnov.v-041959@postgrespro.ru", "phone": "+70966329279"}
0005432105198	47AA48	5034 214218	SOFIYA NESTEROVA	{"phone": "+70467917310"}
0005432105199	E9C2F9	4235 384075	TATYANA EGOROVA	{"phone": "+70725330329"}
0005432105200	69EF16	1005 827821	ANATOLIY KAZAKOV	{"phone": "+70249561815"}
0005432105201	09B343	9363 945127	MARINA NAUMOVA	{"email": "m-naumova.01051973@postgrespro.ru", "phone": "+70447901646"}
0005432105202	09B343	4481 574436	YURIY SCHERBAKOV	{"email": "yuriyscherbakov_021983@postgrespro.ru", "phone": "+70213797612"}
0005432105203	D44896	7920 958288	IRINA ZAKHAROVA	{"phone": "+70956139955"}
0005432105204	BD93FC	2741 107235	VLADISLAV KUZNECOV	{"phone": "+70233828895"}
0005432105205	52C57F	5714 310767	NATALYA PETROVA	{"email": "petrova_n_28051960@postgrespro.ru", "phone": "+70861896256"}
0005432105206	96E0D0	5221 889719	YULIYA DAVYDOVA	{"phone": "+70138804913"}
0005432105207	472D4F	5586 538644	VALENTINA ZHURAVLEVA	{"email": "valentina_zhuravleva-1979@postgrespro.ru", "phone": "+70290790318"}
0005432105208	777F17	5252 211250	VADIM KUDRYASHOV	{"email": "vadimkudryashov-1971@postgrespro.ru", "phone": "+70077149835"}
0005432105209	FEF3CD	3073 682102	DMITRIY SEMENOV	{"email": "semenov.dmitriy.051977@postgrespro.ru", "phone": "+70811591303"}
0005432105210	34E611	2595 061591	ANGELINA YUDINA	{"phone": "+70966000731"}
0005432105211	34E611	5361 871875	OLGA MALYSHEVA	{"email": "o-malysheva_08031978@postgrespro.ru", "phone": "+70132030445"}
0005432105212	E819D3	7099 485153	ANTONINA MOROZOVA	{"phone": "+70232905827"}
0005432105213	11726A	5504 708809	MARSEL SIDOROV	{"email": "marsel_sidorov-101966@postgrespro.ru", "phone": "+70576222613"}
0005432105214	A3E3C6	3895 882994	NADEZHDA MALYSHEVA	{"phone": "+70770075720"}
0005432105215	588C44	0534 846605	SERGEY NIKITIN	{"email": "nikitin.sergey_1984@postgrespro.ru", "phone": "+70885952086"}
0005432105216	C16F4F	3461 087240	MAKSIM PETROV	{"email": "petrov_m-1961@postgrespro.ru", "phone": "+70688289737"}
0005432105217	C16F4F	3650 514720	SAMVEL SEMENOV	{"phone": "+70468892869"}
0005432105218	519316	9366 099911	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov.111959@postgrespro.ru", "phone": "+70278245974"}
0005432105219	F9EBCF	4605 468546	KLAVDIYA AKIMOVA	{"email": "akimovak.04041982@postgrespro.ru", "phone": "+70950165736"}
0005432105220	189CD6	9326 683962	MIKHAIL ZAKHAROV	{"phone": "+70513800717"}
0005432105221	97C492	9894 414653	ELENA STEPANOVA	{"email": "stepanovae-01091968@postgrespro.ru", "phone": "+70920381251"}
0005432105222	BBF377	4758 030502	KONSTANTIN TIMOFEEV	{"email": "timofeev-konstantin-1969@postgrespro.ru", "phone": "+70198291573"}
0005432105223	2B6455	8869 377911	TATYANA OSIPOVA	{"phone": "+70219504590"}
0005432105224	3BAD5F	6212 368731	LYUDMILA DAVYDOVA	{"email": "davydova_l-031957@postgrespro.ru", "phone": "+70332007722"}
0005432105225	3BAD5F	0774 982909	NIKOLAY BONDARENKO	{"phone": "+70518219588"}
0005432105226	3AEDBF	2089 698631	TATYANA MIKHAYLOVA	{"phone": "+70214666144"}
0005432105227	7BA12A	5632 716647	NATALYA ANDREEVA	{"email": "andreeva.natalya.1981@postgrespro.ru", "phone": "+70012372821"}
0005432105228	7BA12A	6675 165743	ALINA SOKOLOVA	{"phone": "+70045458439"}
0005432105229	D836DD	4021 959282	VIKTOR ALEKSANDROV	{"email": "v_aleksandrov_20051975@postgrespro.ru", "phone": "+70789303588"}
0005432105230	690758	1932 727124	ELENA ALEKSEEVA	{"email": "alekseevaelena.011970@postgrespro.ru", "phone": "+70559814520"}
0005432105231	93FF67	2275 801290	ZINAIDA ORLOVA	{"email": "zorlova-071973@postgrespro.ru", "phone": "+70399512431"}
0005432105232	93FF67	4353 998524	IVAN FROLOV	{"email": "ifrolov_1975@postgrespro.ru", "phone": "+70235262353"}
0005432105233	333FE3	2772 109633	NADEZHDA GUSEVA	{"email": "nadezhda-guseva-1972@postgrespro.ru", "phone": "+70164228703"}
0005432105234	333FE3	3785 467873	ARTEMIY CHERNOV	{"email": "artemiy-chernov_1972@postgrespro.ru", "phone": "+70532114611"}
0005432105235	FAA946	5079 368595	ALEKSANDR DMITRIEV	{"phone": "+70232561015"}
0005432105236	FAA946	7745 255091	GENNADIY NIKOLAEV	{"email": "nikolaev_gennadiy_08031976@postgrespro.ru", "phone": "+70777582996"}
0005432105237	F01407	8922 492705	TATYANA SERGEEVA	{"email": "t_sergeeva-1976@postgrespro.ru", "phone": "+70233470569"}
0005432105238	F01407	3555 791781	SVYATOSLAV RODIONOV	{"email": "svyatoslav-rodionov1976@postgrespro.ru", "phone": "+70497964305"}
0005432105239	1439F1	0030 546963	ANNA TARASOVA	{"email": "tarasovaanna_1982@postgrespro.ru", "phone": "+70694243022"}
0005432105240	FFD69E	1538 439431	ALEKSEY MIRONOV	{"email": "aleksey_mironov.10101977@postgrespro.ru", "phone": "+70650546807"}
0005432105241	D0A766	7019 258093	MARIYA TIMOFEEVA	{"email": "timofeeva.mariya.1966@postgrespro.ru", "phone": "+70575883984"}
0005432105242	F0A518	0645 929273	EVGENIY FEDOROV	{"email": "fedorove1969@postgrespro.ru", "phone": "+70887019146"}
0005432105243	AE4E5B	8996 089265	ELENA MATVEEVA	{"phone": "+70384887152"}
0005432105244	5B55AD	4337 242219	ANASTASIYA DMITRIEVA	{"email": "anastasiya-dmitrieva_101982@postgrespro.ru", "phone": "+70416026559"}
0005432105245	13AEFC	3315 656366	STANISLAV ROMANOV	{"phone": "+70561861707"}
0005432105246	85DA2C	8263 502641	ASIYA NIKITINA	{"email": "a_nikitina.051965@postgrespro.ru", "phone": "+70442651225"}
0005432105247	559A11	6308 234801	GALINA BELOVA	{"email": "g-belova.101969@postgrespro.ru", "phone": "+70573447303"}
0005432105248	85AF22	4466 027277	ROMAN FOMIN	{"phone": "+70206258440"}
0005432105249	0A9DCC	0819 537227	MAKSIM NAZAROV	{"phone": "+70005771379"}
0005432105250	074002	9309 633403	OLGA VOROBEVA	{"phone": "+70184961383"}
0005432105251	074002	3867 604661	VASILIY KAZAKOV	{"phone": "+70477178249"}
0005432105252	1B7176	2901 375165	VLADIMIR VOLKOV	{"email": "v_volkov051960@postgrespro.ru", "phone": "+70297433079"}
0005432105253	1B7176	7993 684910	VALENTINA MIKHAYLOVA	{"email": "valentina_mikhaylova.16121969@postgrespro.ru", "phone": "+70838529784"}
0005432105254	2ACFE1	9139 403404	OLGA BELOVA	{"email": "belova_olga-051975@postgrespro.ru", "phone": "+70121280330"}
0005432105255	93EBEC	0717 424918	VENERA VOROBEVA	{"email": "vorobeva.venera071960@postgrespro.ru", "phone": "+70308421331"}
0005432105256	F5873F	0909 658266	MIKHAIL KUZMIN	{"email": "mikhail.kuzmin-051967@postgrespro.ru", "phone": "+70083643206"}
0005432105257	F5873F	7099 067863	MARINA OSIPOVA	{"email": "osipova_m_1975@postgrespro.ru", "phone": "+70803410910"}
0005432105258	2D4543	5414 540424	MARINA MAKAROVA	{"phone": "+70464160689"}
0005432105259	2D4543	4301 437942	DANIL FEDOTOV	{"email": "danil-fedotov.1966@postgrespro.ru", "phone": "+70065477871"}
0005432105260	FD4F58	1519 834868	SVETLANA EGOROVA	{"phone": "+70957823454"}
0005432105261	7034AC	0206 814490	ALEKSANDR IVANOV	{"phone": "+70789137154"}
0005432105262	7326F3	7691 959250	NINA TIMOFEEVA	{"email": "timofeevanina.1964@postgrespro.ru", "phone": "+70656854397"}
0005432105263	53897C	2840 379122	IVAN SOKOLOV	{"phone": "+70463866960"}
0005432105264	53897C	4207 117684	OLEG SEMENOV	{"email": "olegsemenov_041962@postgrespro.ru", "phone": "+70434951072"}
0005432105265	632CBC	2463 238102	SERGEY ALEKSEEV	{"email": "sergey.alekseev.111965@postgrespro.ru", "phone": "+70698560817"}
0005432105266	632CBC	9616 626306	GULNARA DMITRIEVA	{"phone": "+70204740184"}
0005432105267	D61EF3	4525 152219	ANDREY TARASOV	{"phone": "+70421971166"}
0005432105268	FC9B6F	8662 122728	VLADIMIR EGOROV	{"email": "egorov_vladimir.121969@postgrespro.ru", "phone": "+70998762848"}
0005432105269	9B4F5D	9078 558926	PETR CHERNOV	{"email": "petr.chernov_021972@postgrespro.ru", "phone": "+70365380218"}
0005432105270	9B4F5D	3085 985804	ANATOLIY FOMIN	{"email": "fomin.a051974@postgrespro.ru", "phone": "+70672507219"}
0005432105271	E058EE	9674 718888	OLEG POPOV	{"phone": "+70143309264"}
0005432105272	22FAB9	1301 893004	SERGEY NIKOLAEV	{"phone": "+70706776729"}
0005432105273	EE9741	5480 491252	ANNA ANISIMOVA	{"phone": "+70840803056"}
0005432105274	006CC4	9649 469134	MAKSIM FROLOV	{"phone": "+70505069613"}
0005432105275	669A16	9081 263112	NATALYA ZHURAVLEVA	{"email": "n.zhuravleva_071967@postgrespro.ru", "phone": "+70135018689"}
0005432105276	97278F	2191 452908	OKSANA POPOVA	{"email": "o-popova.08061969@postgrespro.ru", "phone": "+70850172581"}
0005432105277	20079C	3885 911018	VIKTOR PETROV	{"phone": "+70006310358"}
0005432105278	20079C	1969 985699	VALERIY SEMENOV	{"email": "valeriy-semenov_051969@postgrespro.ru", "phone": "+70720756134"}
0005432105279	794766	1051 447954	MARIYA KOMAROVA	{"phone": "+70677104732"}
0005432105280	E0B042	5437 293498	VALENTINA KOLESNIKOVA	{"email": "v-kolesnikova091971@postgrespro.ru", "phone": "+70532719204"}
0005432105281	3E254E	0483 300187	PETR DAVYDOV	{"phone": "+70581627868"}
0005432105282	C0FAC4	0821 804147	TATYANA SAVELEVA	{"phone": "+70643089764"}
0005432105283	800B0E	9060 236795	LYUBOV IVANOVA	{"phone": "+70623271477"}
0005432105284	4663DC	5040 692985	ELIZAVETA FOMINA	{"phone": "+70647612775"}
0005432105286	3CF47B	2791 180561	VLADIMIR SOLOVEV	{"email": "v.solovev1978@postgrespro.ru", "phone": "+70026974343"}
0005432105287	5411D9	1195 115730	SERGEY BARANOV	{"email": "sergeybaranov_011968@postgrespro.ru", "phone": "+70974434590"}
0005432105288	AABDC7	5805 586373	ANASTASIYA MAKAROVA	{"phone": "+70304498052"}
0005432105289	8E6157	1848 969854	ANNA VASILEVA	{"email": "anna.vasileva.031966@postgrespro.ru", "phone": "+70173216822"}
0005432105290	92216A	5431 737251	MAKSIM NAZAROV	{"phone": "+70470808096"}
0005432105291	02E019	6879 663875	ERIK FROLOV	{"email": "efrolov-1974@postgrespro.ru", "phone": "+70584661636"}
0005432105292	015CE3	5903 453647	VADIM OSIPOV	{"email": "v_osipov.091971@postgrespro.ru", "phone": "+70821314806"}
0005432105293	8B0982	4840 026506	SHAMIL MARTYNOV	{"email": "s-martynov1960@postgrespro.ru", "phone": "+70336082836"}
0005432105294	1B44BD	5131 336272	SVETLANA VOROBEVA	{"email": "s_vorobeva17021970@postgrespro.ru", "phone": "+70745197541"}
0005432105295	FD6ECE	6355 567422	ALEKSANDR NIKITIN	{"email": "anikitin-011979@postgrespro.ru", "phone": "+70294761805"}
0005432105296	6A9026	8474 343511	SERGEY VASILEV	{"phone": "+70967979677"}
0005432105297	E275DE	2728 139480	SOFYA MEDVEDEVA	{"email": "smedvedeva-071970@postgrespro.ru", "phone": "+70537775867"}
0005432105298	C6A707	6509 050192	ALEKSANDR ILIN	{"phone": "+70422410464"}
0005432105299	0908A4	6656 821007	OLEG KAZAKOV	{"phone": "+70567688352"}
0005432105300	7B42A3	6535 259831	SVETLANA IVANOVA	{"email": "svetlana.ivanova011972@postgrespro.ru", "phone": "+70263501530"}
0005432105301	888AB5	8371 643600	ELENA ANTONOVA	{"phone": "+70287801783"}
0005432105302	824B08	4748 004566	NINA SCHERBAKOVA	{"phone": "+70511024320"}
0005432105303	5C1229	3279 446107	YANA NAZAROVA	{"phone": "+70831297443"}
0005432105304	5C1229	9938 832080	NATALYA LEBEDEVA	{"email": "natalyalebedeva-1979@postgrespro.ru", "phone": "+70990998208"}
0005432105305	0633AD	2858 980654	NATALYA TITOVA	{"email": "titova-natalya021968@postgrespro.ru", "phone": "+70812263061"}
0005432105306	0633AD	6059 767584	MIKHAIL SOROKIN	{"phone": "+70774307952"}
0005432105307	87FC38	6105 610243	ANATOLIY NIKITIN	{"phone": "+70607104027"}
0005432105308	86BDDD	2259 495521	ALEKSANDR OSIPOV	{"email": "osipovaleksandr.011979@postgrespro.ru", "phone": "+70047279023"}
0005432105309	965BE5	6927 265941	IRINA SOROKINA	{"email": "sorokina-i_1967@postgrespro.ru", "phone": "+70560241536"}
0005432105310	AB9B6B	1684 543979	MAKSIM DENISOV	{"email": "maksim_denisov1971@postgrespro.ru", "phone": "+70313930336"}
0005432105311	4A458E	3285 797341	EKATERINA ARKHIPOVA	{"email": "arkhipova_e021971@postgrespro.ru", "phone": "+70371871817"}
0005432105312	49F4B1	4504 195933	MAKSIM POPOV	{"email": "m_popov1990@postgrespro.ru", "phone": "+70305205009"}
0005432105313	49F4B1	1507 604092	KSENIYA KUZNECOVA	{"email": "kuznecova-kseniya1962@postgrespro.ru", "phone": "+70275546204"}
0005432105314	38CA1E	7972 427521	VALENTINA ISAEVA	{"email": "v-isaeva_29111962@postgrespro.ru", "phone": "+70970717926"}
0005432105315	D6E97E	0971 059253	ALEKSEY ALEKSEEV	{"email": "alekseev_a041986@postgrespro.ru", "phone": "+70909916848"}
0005432105316	D6E97E	4212 701522	ALEKSANDR TIKHONOV	{"phone": "+70909287912"}
0005432105317	C21DAB	9413 687598	NINA ZAYCEVA	{"email": "n_zayceva-11081984@postgrespro.ru", "phone": "+70749798406"}
0005432105318	EE1C08	3499 675455	IRINA ANDREEVA	{"email": "andreeva-irina091972@postgrespro.ru", "phone": "+70045631359"}
0005432105319	EE1C08	2662 864644	ALEVTINA VLASOVA	{"phone": "+70928097360"}
0005432105320	4247B1	9593 093749	IRINA POPOVA	{"phone": "+70749332495"}
0005432105321	4247B1	3968 136941	ANGELINA NIKOLAEVA	{"email": "nikolaeva.angelina24051976@postgrespro.ru", "phone": "+70697737648"}
0005432105322	6DA4E3	1555 404325	DENIS PAVLOV	{"phone": "+70312189358"}
0005432105323	6DA4E3	8428 205557	ANASTASIYA ANDREEVA	{"email": "a-andreeva-101961@postgrespro.ru", "phone": "+70385958980"}
0005432105324	A7C7F6	4625 049249	LYUBOV MOISEEVA	{"phone": "+70241804858"}
0005432105325	A7C7F6	3340 295564	EVGENIY GORBUNOV	{"email": "gorbunove_041973@postgrespro.ru", "phone": "+70043522820"}
0005432105326	87674D	2885 072169	DIANA OVCHINNIKOVA	{"phone": "+70774439995"}
0005432105327	334287	5683 378531	ALEKSANDR MIRONOV	{"phone": "+70486384840"}
0005432105328	AC462F	4068 676272	ILYA VOLKOV	{"phone": "+70312947465"}
0005432105329	501E80	8560 164325	VLADIMIR ANTONOV	{"email": "v_antonov-12061979@postgrespro.ru", "phone": "+70875609256"}
0005432105330	501E80	9469 983983	ELENA YAKOVLEVA	{"phone": "+70447374386"}
0005432105331	5DB116	3020 267005	ANGELINA IVANOVA	{"phone": "+70463731376"}
0005432105332	F4FB5A	9657 302983	ANDREY KRASNOV	{"email": "a-krasnov_1977@postgrespro.ru", "phone": "+70352370194"}
0005432105333	F4FB5A	5573 384598	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.e101960@postgrespro.ru", "phone": "+70161727845"}
0005432105334	734951	3514 531785	EKATERINA POTAPOVA	{"phone": "+70568622424"}
0005432105335	240518	2276 503137	PAVEL KUZNECOV	{"email": "kuznecov.pavel071957@postgrespro.ru", "phone": "+70278392658"}
0005432105336	4F4EA6	9505 272290	ANATOLIY OSIPOV	{"email": "osipov-anatoliy_011973@postgrespro.ru", "phone": "+70011712870"}
0005432105337	BAF363	7858 660006	EKATERINA KUZNECOVA	{"phone": "+70437570137"}
0005432105338	DF785C	7737 868772	NIKOLAY SAVELEV	{"email": "nikolay.savelev_24021975@postgrespro.ru", "phone": "+70974076000"}
0005432105339	E5F3BE	2754 846133	ROMAN FEDOROV	{"phone": "+70368895533"}
0005432105340	E5F3BE	0887 314868	RAVILYA KUZNECOVA	{"phone": "+70391359407"}
0005432105341	4B14D9	0373 947353	ELVIRA TIMOFEEVA	{"email": "timofeevaelvira.071968@postgrespro.ru", "phone": "+70982404591"}
0005432105342	16AF20	6719 170275	MIKHAIL DMITRIEV	{"email": "dmitrievm_16041982@postgrespro.ru", "phone": "+70036762705"}
0005432105343	639ABE	2868 355487	NATALYA YUDINA	{"email": "natalya_yudina.1980@postgrespro.ru", "phone": "+70317671122"}
0005432105344	934455	5337 344419	VALENTINA PAVLOVA	{"phone": "+70677853275"}
0005432105345	12710A	4228 686266	ANATOLIY FROLOV	{"email": "a_frolov1973@postgrespro.ru", "phone": "+70635565201"}
0005432105346	12710A	0375 116045	VIKTOR GORBUNOV	{"email": "vgorbunov24091970@postgrespro.ru", "phone": "+70257883049"}
0005432105347	AB038D	2458 965443	IVAN KUZMIN	{"phone": "+70540539973"}
0005432105348	AB038D	2699 199640	MAKSIM SCHERBAKOV	{"email": "m_scherbakov021985@postgrespro.ru", "phone": "+70341280128"}
0005432105349	AB038D	4959 997239	SVETLANA BARANOVA	{"email": "baranova_svetlana_08091973@postgrespro.ru", "phone": "+70094516399"}
0005432105350	868D71	0301 990386	VALERIY POPOV	{"email": "popov.valeriy101975@postgrespro.ru", "phone": "+70727175969"}
0005432105351	9DBA69	1224 268579	VLADISLAV SMIRNOV	{"email": "smirnov_vladislav-17051970@postgrespro.ru", "phone": "+70772654745"}
0005432105352	6B5777	6794 576106	OLEG KUZMIN	{"phone": "+70653688085"}
0005432105353	6B5777	9017 995212	GEORGIY KOZLOV	{"email": "g-kozlov_051973@postgrespro.ru", "phone": "+70723406083"}
0005432105354	D1EFD7	9660 477932	NIKOLAY KRASNOV	{"email": "nikolay_krasnov_1967@postgrespro.ru", "phone": "+70103713788"}
0005432105355	D1EFD7	8107 432742	DMITRIY MELNIKOV	{"phone": "+70533442028"}
0005432105356	D1EFD7	4865 892942	SERGEY BONDARENKO	{"phone": "+70125338057"}
0005432105357	18AAA9	9941 920216	VLADIMIR CHERNOV	{"email": "chernov.vladimir_1979@postgrespro.ru", "phone": "+70633019281"}
0005432105358	18AAA9	6755 673433	YURIY KAZAKOV	{"email": "yuriy_kazakov-1976@postgrespro.ru", "phone": "+70888857963"}
0005432105359	18AAA9	1383 165038	DAMIR ZAKHAROV	{"email": "zakharov.damir-1972@postgrespro.ru", "phone": "+70176816534"}
0005432105360	BD2433	1430 139975	ELENA ALEKSANDROVA	{"email": "aleksandrova.elena1971@postgrespro.ru", "phone": "+70468174969"}
0005432105361	0BCCD5	2692 270359	IRINA SOROKINA	{"phone": "+70138374669"}
0005432105362	2DBC3B	3762 371746	TATYANA MAKSIMOVA	{"email": "maksimova-t_14111973@postgrespro.ru", "phone": "+70111081176"}
0005432105363	B445D8	6137 583854	OLGA KUZNECOVA	{"email": "olga_kuznecova091959@postgrespro.ru", "phone": "+70991634738"}
0005432105364	B445D8	3632 600854	BORIS KONOVALOV	{"email": "b-konovalov-1972@postgrespro.ru", "phone": "+70222136984"}
0005432105365	D287C6	3283 011687	ELENA KOLESNIKOVA	{"email": "kolesnikovaelena.041971@postgrespro.ru", "phone": "+70399121601"}
0005432105366	12B296	2728 793686	OLGA MASLOVA	{"email": "o-maslova081974@postgrespro.ru", "phone": "+70430787228"}
0005432105367	12B296	2503 168164	ANATOLIY FILIPPOV	{"email": "anatoliyfilippov.1976@postgrespro.ru", "phone": "+70838022142"}
0005432105368	561795	1015 273747	VALERIY FEDOTOV	{"phone": "+70007990307"}
0005432105369	561795	5128 374980	DARYA BELYAEVA	{"phone": "+70702087384"}
0005432105370	EAFC0B	1749 505899	ZOYA VOROBEVA	{"phone": "+70228476759"}
0005432105371	DA7CD9	3732 459646	ALINA ANISIMOVA	{"email": "a-anisimova-1969@postgrespro.ru", "phone": "+70862360695"}
0005432105372	262B4A	0609 454646	STANISLAV IVANOV	{"email": "ivanovs1973@postgrespro.ru", "phone": "+70075093736"}
0005432105373	C67855	3341 357750	ILGIZ ORLOV	{"email": "i-orlov_1962@postgrespro.ru", "phone": "+70988784869"}
0005432105374	C67855	7084 587954	MIKHAIL SAVELEV	{"email": "savelev-m-111973@postgrespro.ru", "phone": "+70525305452"}
0005432105375	280A21	5249 743944	TAMARA MIKHAYLOVA	{"phone": "+70402708280"}
0005432105376	CA65C9	8237 517801	TATYANA KUZMINA	{"email": "t.kuzmina.011968@postgrespro.ru", "phone": "+70955850558"}
0005432105377	CA65C9	8620 150853	YURIY ROMANOV	{"email": "y_romanov.08111969@postgrespro.ru", "phone": "+70507894012"}
0005432105378	F80E61	7212 151037	VLADIMIR GERASIMOV	{"email": "gerasimov-vladimir_051975@postgrespro.ru", "phone": "+70105811135"}
0005432105379	F80E61	7952 897438	YULIYA EFREMOVA	{"email": "efremova.y1977@postgrespro.ru", "phone": "+70038870892"}
0005432105380	AB3E09	6627 503206	DENIS VLASOV	{"email": "denis-vlasov.1965@postgrespro.ru", "phone": "+70047668959"}
0005432105381	AB3E09	3719 303067	NATALYA GUSEVA	{"phone": "+70250411815"}
0005432105382	B91F65	5916 391357	ALEKSEY FILIPPOV	{"phone": "+70254894109"}
0005432105383	B252BC	1865 010801	EKATERINA FROLOVA	{"email": "ekaterina_frolova-031980@postgrespro.ru", "phone": "+70575449101"}
0005432105384	59F196	9376 110883	ALEKSANDRA YAKOVLEVA	{"phone": "+70589631433"}
0005432105385	558D36	8131 752723	OLGA ANDREEVA	{"phone": "+70712259505"}
0005432105386	4B3E44	8154 306639	VALENTINA FOMINA	{"email": "v.fomina-19031957@postgrespro.ru", "phone": "+70893673279"}
0005432105387	4B3E44	6575 861745	VASILIY GORBUNOV	{"email": "gorbunov-vasiliy-081960@postgrespro.ru", "phone": "+70675520868"}
0005432105388	604976	8554 812275	NIKOLAY SOKOLOV	{"phone": "+70995572433"}
0005432105389	CE72B9	1312 624925	DANILA KUZNECOV	{"phone": "+70644230285"}
0005432105390	2E83A5	7431 316380	VERONIKA KOLESNIKOVA	{"email": "kolesnikova-v121972@postgrespro.ru", "phone": "+70674953043"}
0005432105391	FD2552	9047 395414	SERGEY ALEKSEEV	{"phone": "+70770977477"}
0005432105392	481788	9642 555947	ALEKSANDR BORISOV	{"phone": "+70304094844"}
0005432105393	EC7910	2392 199232	SERGEY ALEKSEEV	{"phone": "+70709465214"}
0005432105394	D4C044	1099 855102	EKATERINA KOMAROVA	{"email": "e_komarova-30061978@postgrespro.ru", "phone": "+70952813097"}
0005432105395	E1D130	9844 581674	MARINA SMIRNOVA	{"phone": "+70594674520"}
0005432105396	E1D130	6674 374102	NATALYA MIRONOVA	{"phone": "+70963607575"}
0005432105397	FF84E5	8916 537295	NATALYA NESTEROVA	{"email": "n.nesterova1973@postgrespro.ru", "phone": "+70820817424"}
0005432105398	A70C4A	1721 343155	ALEKSANDR PETROV	{"phone": "+70054501779"}
0005432105400	EA633E	8649 039587	FEDOR KUZNECOV	{"email": "kuznecovf_16111969@postgrespro.ru", "phone": "+70856705061"}
0005432105401	EA633E	5400 145252	VALENTINA ZHURAVLEVA	{"email": "valentina.zhuravleva_25081976@postgrespro.ru", "phone": "+70563885313"}
0005432105402	8204E0	1655 416381	ANATOLIY SOKOLOV	{"phone": "+70552643312"}
0005432105403	48EA81	2505 531787	VIKTORIYA KOROLEVA	{"phone": "+70187657831"}
0005432105404	48EA81	8339 325294	SVYATOSLAV VOROBEV	{"email": "s-vorobev-31081971@postgrespro.ru", "phone": "+70592448122"}
0005432105405	E44412	1118 105217	EVGENIY ROMANOV	{"phone": "+70820903661"}
0005432105406	E44412	9177 441098	VALENTINA NIKOLAEVA	{"phone": "+70552065861"}
0005432105407	D1C859	2154 839730	TATYANA KOROLEVA	{"phone": "+70940114070"}
0005432105408	7FC2DE	8688 482136	ALEKSANDR KOZLOV	{"phone": "+70378144408"}
0005432105409	F330B3	1048 278365	SERGEY KUZNECOV	{"email": "kuznecovsergey-021973@postgrespro.ru", "phone": "+70231160982"}
0005432105410	A42178	8963 135242	MARIYA NAZAROVA	{"phone": "+70323822758"}
0005432105411	FCE1DA	2863 456194	MARINA ALEKSANDROVA	{"email": "marinaaleksandrova_1973@postgrespro.ru", "phone": "+70650157323"}
0005432105412	699B1D	2838 805763	KONSTANTIN NOVIKOV	{"phone": "+70475239438"}
0005432105413	699B1D	3167 182577	ALEKSEY KONOVALOV	{"email": "a-konovalov-021960@postgrespro.ru", "phone": "+70760848896"}
0005432105414	A7CE1D	8620 581815	MAKSIM YAKOVLEV	{"phone": "+70969668682"}
0005432105415	D667B6	9898 275006	ALEKSEY MAKAROV	{"phone": "+70765030006"}
0005432105416	5EA57B	0601 149362	LYUDMILA DANILOVA	{"phone": "+70711464035"}
0005432105417	5EA57B	8971 926326	EVGENIY KULIKOV	{"email": "ekulikov_1990@postgrespro.ru", "phone": "+70813936757"}
0005432105418	A7E774	2163 774191	GALINA ANTONOVA	{"email": "antonovag_1976@postgrespro.ru", "phone": "+70628585723"}
0005432105419	A7E774	4391 617273	TATYANA YAKOVLEVA	{"phone": "+70818391594"}
0005432105420	72572E	5750 822486	ANASTASIYA KUZNECOVA	{"phone": "+70324789621"}
0005432105421	03B3E9	2584 555146	MAKSIM OSIPOV	{"phone": "+70666289494"}
0005432105422	C6B178	4423 244380	ANATOLIY ZAKHAROV	{"phone": "+70915207761"}
0005432105423	E4C9B8	1881 814054	OLEG NIKOLAEV	{"phone": "+70774476299"}
0005432105424	E4C9B8	4353 525591	VLADISLAV CHERNOV	{"phone": "+70544251358"}
0005432105425	71B39B	2445 932627	SERGEY VOLKOV	{"email": "s_volkov_1974@postgrespro.ru", "phone": "+70497294013"}
0005432105426	4A218E	8061 114833	ELENA FEDOROVA	{"email": "fedorova-e-04021970@postgrespro.ru", "phone": "+70639061207"}
0005432105427	6FEA9F	9365 976193	DARINA TROFIMOVA	{"phone": "+70002656010"}
0005432105428	E4B65A	1335 996707	SERGEY SOLOVEV	{"email": "solovev_s_1967@postgrespro.ru", "phone": "+70574495940"}
0005432105429	F3985A	1754 028987	SVETLANA STEPANOVA	{"phone": "+70750018309"}
0005432105430	A1D2E1	3081 978212	SVETLANA NESTEROVA	{"email": "s-nesterova_06021972@postgrespro.ru", "phone": "+70981632504"}
0005432105431	3F0316	2998 446396	GENNADIY ZHURAVLEV	{"phone": "+70412212022"}
0005432105432	94AF02	6225 367828	ANDREY CHERNOV	{"phone": "+70964423941"}
0005432105433	DABD06	9402 635583	MARGARITA AFANASEVA	{"phone": "+70841837017"}
0005432105434	DABD06	5910 725240	TATYANA KISELEVA	{"phone": "+70423810392"}
0005432105435	BA5593	2421 413138	LYUBOV SEMENOVA	{"phone": "+70793318187"}
0005432105436	BA5593	4992 316750	SVETLANA GAVRILOVA	{"email": "s_gavrilova_081964@postgrespro.ru", "phone": "+70375613059"}
0005432105437	8A1837	9939 096285	VYACHESLAV EGOROV	{"email": "vyacheslav-egorov_28021972@postgrespro.ru", "phone": "+70791435372"}
0005432105438	FEB791	7130 325051	ANDREY MEDVEDEV	{"email": "medvedev-andrey-23011970@postgrespro.ru", "phone": "+70829683817"}
0005432105439	FEB791	4264 149358	NINA MEDVEDEVA	{"email": "nmedvedeva_1970@postgrespro.ru", "phone": "+70152413322"}
0005432105440	A6782D	8841 278066	FAINA POPOVA	{"phone": "+70568606825"}
0005432105441	F741F5	4198 516079	EDUARD NAZAROV	{"phone": "+70155600620"}
0005432105442	F741F5	8481 743045	ANDREY KARPOV	{"phone": "+70768138142"}
0005432105443	411C76	9994 419661	TAISIYA FROLOVA	{"phone": "+70239721060"}
0005432105444	6DEB9B	9344 785230	GALINA KAZAKOVA	{"phone": "+70770526223"}
0005432105445	6954A4	4400 799886	IVAN FROLOV	{"phone": "+70951906723"}
0005432105446	6954A4	3882 631046	VLADIMIR MATVEEV	{"email": "matveev-v.071971@postgrespro.ru", "phone": "+70990734332"}
0005432105447	269A93	0515 075334	NINA ALEKSEEVA	{"phone": "+70276496447"}
0005432105448	269A93	1392 295733	ALEKSANDR ZHUKOV	{"phone": "+70483670966"}
0005432105449	46612F	6087 163906	SVETLANA POPOVA	{"phone": "+70738641686"}
0005432105450	33C778	7223 888128	IVAN STEPANOV	{"email": "i.stepanov_1966@postgrespro.ru", "phone": "+70304608706"}
0005432105451	4C9BEC	0299 561271	NATALYA ABRAMOVA	{"phone": "+70630574726"}
0005432105452	A1CA30	5894 810238	ALEKSEY AFANASEV	{"phone": "+70155045278"}
0005432105453	47DC60	5646 937831	TATYANA TROFIMOVA	{"email": "trofimova-t101981@postgrespro.ru", "phone": "+70667284463"}
0005432105454	47DC60	3207 200449	TATYANA TIMOFEEVA	{"email": "tatyana.timofeeva1987@postgrespro.ru", "phone": "+70248745046"}
0005432105455	C6533C	0516 848627	YULIYA AFANASEVA	{"phone": "+70280398802"}
0005432105456	E4867A	2095 153076	TATYANA KARPOVA	{"email": "karpova.t.07041973@postgrespro.ru", "phone": "+70003903027"}
0005432105457	1E56BA	1247 828039	LYUBOV SMIRNOVA	{"phone": "+70506344152"}
0005432105458	1E56BA	6412 044410	VITALIY MOROZOV	{"phone": "+70816396671"}
0005432105459	AE8946	0030 281307	NIKOLAY FILIPPOV	{"email": "filippovn_1977@postgrespro.ru", "phone": "+70264955293"}
0005432105460	D8329D	9362 170987	ANDREY EGOROV	{"email": "andrey.egorov1979@postgrespro.ru", "phone": "+70633566925"}
0005432105461	897C73	4651 625646	IRINA IVANOVA	{"phone": "+70629291674"}
0005432105462	897C73	5131 313268	ROMAN PETROV	{"email": "petrov.roman-16051968@postgrespro.ru", "phone": "+70558567422"}
0005432105463	FB2331	4579 420183	GALINA TIMOFEEVA	{"phone": "+70134747245"}
0005432105464	FB2331	0479 906782	ELENA STEPANOVA	{"phone": "+70270411740"}
0005432105465	FB2331	9955 844803	EVGENIY NIKOLAEV	{"email": "evgeniy.nikolaev1974@postgrespro.ru", "phone": "+70723329011"}
0005432105466	0680ED	8024 216487	ALEKSANDR POPOV	{"phone": "+70540028782"}
0005432105467	06E41B	6416 428505	ALBINA LAZAREVA	{"phone": "+70641534618"}
0005432105468	06E41B	9492 064615	YULIYA IVANOVA	{"email": "y.ivanova25011975@postgrespro.ru", "phone": "+70732618402"}
0005432105469	06E41B	3939 765285	TAISIYA AFANASEVA	{"email": "taisiyaafanaseva_021977@postgrespro.ru", "phone": "+70562717705"}
0005432105470	32F9DB	0469 737972	EKATERINA IVANOVA	{"email": "ivanova.e.1971@postgrespro.ru", "phone": "+70454536384"}
0005432105471	15507C	8917 381683	IVAN FEDOROV	{"email": "fedorov.ivan1975@postgrespro.ru", "phone": "+70989888884"}
0005432105472	15507C	6261 435587	ALENA BOGDANOVA	{"phone": "+70386040309"}
0005432105473	BABDE1	6057 695856	KONSTANTIN KARPOV	{"email": "karpov.konstantin-071976@postgrespro.ru", "phone": "+70032576946"}
0005432105474	BABDE1	7619 560433	ANDREY ORLOV	{"email": "orlov-a_1972@postgrespro.ru", "phone": "+70155437505"}
0005432105475	5F8CFE	0745 414653	YURIY PAVLOV	{"email": "pavlovyuriy18071966@postgrespro.ru", "phone": "+70805217150"}
0005432105476	5F8CFE	9653 544306	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a.031980@postgrespro.ru", "phone": "+70781149013"}
0005432105477	FF37E3	6143 605591	VLADIMIR ORLOV	{"email": "vladimir_orlov_18011961@postgrespro.ru", "phone": "+70535536428"}
0005432105478	FF37E3	3814 450668	NAIL ZAKHAROV	{"phone": "+70770034519"}
0005432105479	FF37E3	8290 320873	ALEKSANDR BARANOV	{"email": "baranovaleksandr.17121964@postgrespro.ru", "phone": "+70226139140"}
0005432105480	6AA135	3808 860153	SERGEY ILIN	{"email": "s.ilin.031973@postgrespro.ru", "phone": "+70195016736"}
0005432105481	ED7AAD	9731 074566	OLGA KOROLEVA	{"phone": "+70240616030"}
0005432105482	ED7AAD	7677 584890	OLGA SEMENOVA	{"email": "o_semenova-121979@postgrespro.ru", "phone": "+70089771326"}
0005432105483	2A5FAC	4881 110584	LYUBOV SERGEEVA	{"phone": "+70755276833"}
0005432105484	702B79	0705 113208	ALEKSANDR GERASIMOV	{"email": "agerasimov_24111970@postgrespro.ru", "phone": "+70302498563"}
0005432105485	702B79	6247 433704	LYUBOV NESTEROVA	{"email": "lyubov-nesterova-1962@postgrespro.ru", "phone": "+70146291168"}
0005432105486	D90D52	5624 833977	MARIYA ILINA	{"email": "ilina-mariya101983@postgrespro.ru", "phone": "+70496516942"}
0005432105487	D90D52	4432 431069	SEMEN NAUMOV	{"email": "s-naumov.14031974@postgrespro.ru", "phone": "+70436857523"}
0005432105488	C314C6	5362 406701	VERA MAKAROVA	{"email": "makarova-v021976@postgrespro.ru", "phone": "+70847991191"}
0005432105489	C314C6	4749 588740	IRINA KOZLOVA	{"phone": "+70140860937"}
0005432105490	02A76C	4443 117119	ELIZAVETA LUKYANOVA	{"email": "e-lukyanova1973@postgrespro.ru", "phone": "+70722232601"}
0005432105491	02A76C	6735 622684	MARINA KUZNECOVA	{"email": "m-kuznecova-20011980@postgrespro.ru", "phone": "+70481858982"}
0005432105492	0B50C1	7740 159270	ALEKSANDR NOVIKOV	{"email": "novikov-a.23081978@postgrespro.ru", "phone": "+70716333058"}
0005432105493	0B50C1	1020 072606	VERA POPOVA	{"email": "v-popova_1970@postgrespro.ru", "phone": "+70397846790"}
0005432105494	0B50C1	8452 175586	DANIIL KISELEV	{"email": "daniil.kiselev081973@postgrespro.ru", "phone": "+70408215091"}
0005432105495	A4F04A	4699 684546	VASILIY KUZMIN	{"email": "kuzmin-vasiliy1974@postgrespro.ru", "phone": "+70586746998"}
0005432105496	125960	5135 842092	DMITRIY KUZMIN	{"phone": "+70990076973"}
0005432105497	101D04	1324 414093	ALEKSANDR NIKOLAEV	{"phone": "+70747851300"}
0005432105498	9C6AAC	5208 803400	VERA ANDREEVA	{"email": "vera.andreeva-021973@postgrespro.ru", "phone": "+70217883371"}
0005432105499	EF6824	7218 251521	SERGEY IVANOV	{"phone": "+70465951525"}
0005432105500	77C173	5305 997996	KIRILL MOISEEV	{"phone": "+70838135841"}
0005432105501	77C173	5147 049507	SERGEY MARTYNOV	{"phone": "+70479438474"}
0005432105502	4DFBAE	9068 092528	DINARA MATVEEVA	{"phone": "+70374932899"}
0005432105503	4DFBAE	1745 635344	KSENIYA KOROLEVA	{"phone": "+70100127190"}
0005432105504	4C6B8B	2843 189004	ALEKSEY SEMENOV	{"phone": "+70727704668"}
0005432105505	B2E292	0420 858833	VLADIMIR OSIPOV	{"phone": "+70635493823"}
0005432105506	6875D9	6865 277883	VITALIY DMITRIEV	{"phone": "+70342451777"}
0005432105507	89A40E	4881 762889	ANDREY VOLKOV	{"phone": "+70472899979"}
0005432105508	980D6F	4281 429284	ILYA PETROV	{"email": "ipetrov-11111971@postgrespro.ru", "phone": "+70388235711"}
0005432105509	980D6F	3963 320284	TATYANA KISELEVA	{"email": "t_kiseleva.15081970@postgrespro.ru", "phone": "+70608679894"}
0005432105510	B8CDB3	2743 942718	ROMAN NAZAROV	{"email": "nazarov.r16031972@postgrespro.ru", "phone": "+70515667051"}
0005432105511	B8CDB3	5859 437110	EVGENIYA ZHUKOVA	{"phone": "+70005825821"}
0005432105512	5DEDA6	5369 007230	TATYANA KOROLEVA	{"phone": "+70555822771"}
0005432105513	6C5C42	5559 942363	BORIS ANDREEV	{"phone": "+70272526203"}
0005432105514	52A437	1787 992357	MARINA KOZLOVA	{"phone": "+70830214032"}
0005432105515	52A437	9905 165542	ALEKSEY PETROV	{"email": "a.petrov121969@postgrespro.ru", "phone": "+70888042972"}
0005432105516	A2A662	2238 060431	POLINA PETROVA	{"phone": "+70265421775"}
0005432105517	A2A662	0717 605824	LYUDMILA KOROLEVA	{"email": "koroleva_l051969@postgrespro.ru", "phone": "+70714422402"}
0005432105518	18A63B	3385 697892	ANATOLIY FOMIN	{"email": "fomin.anatoliy.22071966@postgrespro.ru", "phone": "+70631504500"}
0005432105519	019E5D	7143 699964	MARIYA ISAEVA	{"email": "isaeva-mariya1990@postgrespro.ru", "phone": "+70623021262"}
0005432105520	019E5D	0516 270295	RINAT KAZAKOV	{"email": "r.kazakov1970@postgrespro.ru", "phone": "+70973967597"}
0005432105521	458AF8	6193 361607	DMITRIY BONDARENKO	{"email": "bondarenko_d-121971@postgrespro.ru", "phone": "+70822088697"}
0005432105522	3E7DAB	9457 967230	SERGEY KUZNECOV	{"phone": "+70854707230"}
0005432105523	DD78D6	4009 231872	VERA LAZAREVA	{"phone": "+70442241286"}
0005432105524	4C8E2C	2123 952043	ALINA GORBUNOVA	{"phone": "+70579454938"}
0005432105525	1EC437	6988 223711	ANASTASIYA KARPOVA	{"phone": "+70272752870"}
0005432105526	C3A4A1	7255 126451	DMITRIY SOROKIN	{"email": "dsorokin051960@postgrespro.ru", "phone": "+70720770762"}
0005432105527	D2E385	5628 541320	ELISEY ISAEV	{"email": "isaev.elisey041967@postgrespro.ru", "phone": "+70198316946"}
0005432105528	065DFC	4660 480261	VERA GUSEVA	{"phone": "+70750222101"}
0005432105529	B2C363	9304 292178	KONSTANTIN MOROZOV	{"email": "morozov-konstantin1971@postgrespro.ru", "phone": "+70569380199"}
0005432105530	B2C363	6070 089190	ALEKSANDR KRASNOV	{"email": "krasnov-a-031977@postgrespro.ru", "phone": "+70701421120"}
0005432105531	1D210D	4301 356587	ALENA KUDRYASHOVA	{"email": "kudryashova.a1967@postgrespro.ru", "phone": "+70410816997"}
0005432105532	36A330	0930 023546	NAIL VOLKOV	{"email": "volkov_n021977@postgrespro.ru", "phone": "+70245931372"}
0005432105533	36A330	7970 018458	ELIZAVETA KUZNECOVA	{"email": "elizaveta-kuznecova.1971@postgrespro.ru", "phone": "+70073001395"}
0005432105534	FA1741	9285 111945	NATALYA ABRAMOVA	{"phone": "+70010241916"}
0005432105535	DAA531	2312 044104	YULIYA ARKHIPOVA	{"email": "yarkhipova-061987@postgrespro.ru", "phone": "+70095316078"}
0005432105536	1E19C8	0792 923113	ELENA GERASIMOVA	{"email": "gerasimova_elena021970@postgrespro.ru", "phone": "+70582196029"}
0005432105537	399A8F	6939 247994	IGOR KOROLEV	{"email": "ikorolev.1969@postgrespro.ru", "phone": "+70014192889"}
0005432105538	399A8F	4973 282971	EVGENIY GUSEV	{"phone": "+70201238526"}
0005432105539	5A0BC1	4060 491365	DMITRIY ALEKSANDROV	{"phone": "+70325563262"}
0005432105540	8BEF29	4153 365217	PAVEL SOKOLOV	{"phone": "+70605932422"}
0005432105541	C12175	7550 546150	ROZA OSIPOVA	{"phone": "+70495513992"}
0005432105542	DE703D	6032 861253	IRINA YUDINA	{"email": "yudinai.06101971@postgrespro.ru", "phone": "+70450079535"}
0005432105543	DE703D	2314 783061	ANDREY IVANOV	{"phone": "+70403635166"}
0005432105544	DE703D	2731 629796	MIKHAIL ZAKHAROV	{"phone": "+70256001715"}
0005432105545	B7D708	6328 471092	ELENA KUZNECOVA	{"email": "kuznecova.elena_20041966@postgrespro.ru", "phone": "+70780997890"}
0005432105546	77F54E	6497 980213	ALEKSANDR MIRONOV	{"phone": "+70015933458"}
0005432105547	77F54E	9512 218461	VLADIMIR MAKAROV	{"phone": "+70930714307"}
0005432105548	6B3877	5452 899637	VALERIYA MAKAROVA	{"phone": "+70313490353"}
0005432105549	15C0DB	3949 170552	DAVID POPOV	{"phone": "+70930804145"}
0005432105550	15C0DB	8855 887339	GENNADIY IVANOV	{"phone": "+70882125569"}
0005432105551	15C0DB	8312 931370	LYUDMILA DAVYDOVA	{"phone": "+70388696834"}
0005432105552	85B982	4751 348273	VALENTINA GUSEVA	{"email": "guseva_v11041975@postgrespro.ru", "phone": "+70956619221"}
0005432105553	85B982	0049 731082	VLADIMIR STEPANOV	{"phone": "+70231588617"}
0005432105554	CD4BCD	4149 388778	IGOR MOISEEV	{"phone": "+70350923478"}
0005432105555	CD4BCD	1848 183838	TAMARA ROMANOVA	{"phone": "+70314926575"}
0005432105556	B269BD	9429 765254	OLGA KOZLOVA	{"phone": "+70760539800"}
0005432105557	3BEAE4	6631 365714	ARTEM SERGEEV	{"phone": "+70955916248"}
0005432105558	BAE6C8	9529 197717	TATYANA FILIPPOVA	{"phone": "+70012799892"}
0005432105559	8C88D8	9708 232020	MIKHAIL POPOV	{"email": "m_popov_1973@postgrespro.ru", "phone": "+70281964415"}
0005432105560	9F69E9	8968 610273	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov-25021974@postgrespro.ru", "phone": "+70150220875"}
0005432105561	3165E8	9710 555050	ANNA LEBEDEVA	{"email": "anna-lebedeva071981@postgrespro.ru", "phone": "+70664748024"}
0005432105562	E819F9	9729 158452	OLGA KOROLEVA	{"phone": "+70127501573"}
0005432105563	0F4777	9629 148035	IVAN VOLKOV	{"email": "volkov-ivan-08021968@postgrespro.ru", "phone": "+70717333935"}
0005432105564	C3DA94	2290 555774	ELENA TITOVA	{"email": "etitova-051983@postgrespro.ru", "phone": "+70458059206"}
0005432105565	B4DE67	2510 910337	ELENA YAKOVLEVA	{"phone": "+70946173288"}
0005432105566	C0F6FC	0158 002469	GENNADIY VOROBEV	{"email": "vorobev.gennadiy1971@postgrespro.ru", "phone": "+70946290311"}
0005432105567	02110D	5186 758496	ANATOLIY ANTONOV	{"email": "antonov_anatoliy.1972@postgrespro.ru", "phone": "+70527239856"}
0005432105568	48663B	6326 958020	ANDREY KUDRYASHOV	{"email": "andrey-kudryashov.1972@postgrespro.ru", "phone": "+70945408554"}
0005432105569	831F16	5544 040717	SVETLANA EGOROVA	{"phone": "+70522342028"}
0005432105570	49155D	0293 152647	LIDIYA MAKSIMOVA	{"email": "lidiyamaksimova22031975@postgrespro.ru", "phone": "+70140195430"}
0005432105571	49155D	8309 669061	NATALIYA FILATOVA	{"phone": "+70832657735"}
0005432105572	9B6F81	0713 272398	ELENA SMIRNOVA	{"phone": "+70832697869"}
0005432105573	9B6F81	9856 287766	RUSTAM MAKAROV	{"phone": "+70359723673"}
0005432105574	AB9721	1217 414621	VYACHESLAV SCHERBAKOV	{"email": "scherbakov.vyacheslav061974@postgrespro.ru", "phone": "+70190973598"}
0005432105575	AB9721	4483 123141	LARISA BELYAEVA	{"phone": "+70151007555"}
0005432105576	4E1AB3	3586 468008	ANASTASIYA YUDINA	{"email": "anastasiyayudina-071964@postgrespro.ru", "phone": "+70419415680"}
0005432105577	B1D24A	8348 810787	VSEVOLOD KULIKOV	{"phone": "+70719493389"}
0005432105578	2C4E01	9622 472003	SOFYA SIDOROVA	{"email": "sidorova.sofya-02041971@postgrespro.ru", "phone": "+70531393547"}
0005432105579	2C4E01	2072 491619	EVGENIY SOKOLOV	{"email": "evgeniy.sokolov-22091981@postgrespro.ru", "phone": "+70548642856"}
0005432105580	9B0464	1137 791862	OLGA MIKHAYLOVA	{"email": "o.mikhaylova.1965@postgrespro.ru", "phone": "+70298268304"}
0005432105581	9B0464	4240 194884	ANDREY KUZNECOV	{"email": "andreykuznecov14051972@postgrespro.ru", "phone": "+70497684317"}
0005432105582	9B0464	0472 687800	ALEKSANDR AFANASEV	{"phone": "+70572787464"}
0005432105583	51F222	6667 529848	ANDREY GUSEV	{"phone": "+70896480589"}
0005432105584	19C9DE	0409 530235	RAFIK AFANASEV	{"phone": "+70761170750"}
0005432105585	7C21AE	6242 782788	VLADIMIR TIKHONOV	{"phone": "+70733682403"}
0005432105586	7C21AE	3167 405573	ANNA STEPANOVA	{"phone": "+70734098424"}
0005432105587	6A6227	1451 226647	VIKTOR FEDOTOV	{"phone": "+70182677772"}
0005432105588	59D361	2510 128498	OLGA MAKAROVA	{"email": "makarova-o.091964@postgrespro.ru", "phone": "+70505551980"}
0005432105589	2B0D2F	9185 649593	IVAN POPOV	{"email": "ivan.popov_19031971@postgrespro.ru", "phone": "+70689365499"}
0005432105590	C107D6	7711 284278	IRINA LEBEDEVA	{"email": "lebedeva-i-1969@postgrespro.ru", "phone": "+70031688395"}
0005432105591	7AE593	9752 700982	NIKITA SOLOVEV	{"email": "solovev_nikita-041978@postgrespro.ru", "phone": "+70788845570"}
0005432105592	119147	4628 122851	MARIYA ORLOVA	{"phone": "+70356151153"}
0005432105593	76E63A	3943 720140	ELENA ANDREEVA	{"email": "andreeva.elena071980@postgrespro.ru", "phone": "+70853364531"}
0005432105594	978C15	5764 726388	IGOR KUZNECOV	{"phone": "+70597561516"}
0005432105595	381A55	4329 343235	OLEG GERASIMOV	{"email": "o.gerasimov-09041965@postgrespro.ru", "phone": "+70850933765"}
0005432105596	DE3311	5487 205618	GALINA KARPOVA	{"email": "karpova_g31031969@postgrespro.ru", "phone": "+70254721720"}
0005432105597	D6DD49	7917 053285	YAROSLAV NAZAROV	{"email": "nazarov-yaroslav-1965@postgrespro.ru", "phone": "+70075011608"}
0005432105598	2CFB47	2195 474454	ALEKSEY NAUMOV	{"email": "a_naumov.1967@postgrespro.ru", "phone": "+70412527834"}
0005432105599	2CFB47	0234 135971	ALEKSEY SOLOVEV	{"phone": "+70774006977"}
0005432105600	8984A6	5314 784525	OKSANA EGOROVA	{"phone": "+70771825572"}
0005432105601	A9C571	6597 463257	MARINA EFREMOVA	{"email": "efremova-marina_121964@postgrespro.ru", "phone": "+70335425504"}
0005432105602	B92B44	2734 473241	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov041972@postgrespro.ru", "phone": "+70455695777"}
0005432105603	7A22A7	9973 116074	VYACHESLAV MOROZOV	{"email": "vyacheslav_morozov_1971@postgrespro.ru", "phone": "+70456400915"}
0005432105604	82C054	8686 737927	ELIZAVETA VASILEVA	{"phone": "+70104174635"}
0005432105605	5E25BF	2134 214310	VALERIYA PETROVA	{"phone": "+70511064754"}
0005432105606	75EABC	0325 397371	FEDOR GRIGOREV	{"phone": "+70159242821"}
0005432105607	0665CC	6889 218101	NATALYA ISAEVA	{"email": "nisaeva_25101973@postgrespro.ru", "phone": "+70348747509"}
0005432105608	05AB16	5552 134996	ALEKSANDR TIKHONOV	{"phone": "+70457466219"}
0005432105609	05AB16	7852 640581	SERGEY KUZMIN	{"email": "kuzmin.s1970@postgrespro.ru", "phone": "+70165790934"}
0005432105610	41372A	6225 575225	DMITRIY SOKOLOV	{"email": "dmitriy-sokolov.1972@postgrespro.ru", "phone": "+70672821617"}
0005432105611	B6630B	9883 290789	ALEKSEY KUZNECOV	{"phone": "+70300460634"}
0005432105612	322D05	0598 989200	GALINA VOROBEVA	{"phone": "+70701074915"}
0005432105613	322D05	8329 521579	NIKOLAY BARANOV	{"email": "n-baranov-091963@postgrespro.ru", "phone": "+70218380968"}
0005432105614	24D7A1	0791 757857	LYUBOV ZAYCEVA	{"email": "l-zayceva_30101983@postgrespro.ru", "phone": "+70650976126"}
0005432105615	24D7A1	6644 537725	ARTEM ZAKHAROV	{"email": "azakharov.27021978@postgrespro.ru", "phone": "+70704633610"}
0005432105616	954F56	7593 953722	VALENTINA TROFIMOVA	{"email": "v-trofimova16111966@postgrespro.ru", "phone": "+70248037764"}
0005432105617	C31071	5394 016431	VLADIMIR KUDRYASHOV	{"email": "vladimir_kudryashov_16091960@postgrespro.ru", "phone": "+70034365798"}
0005432105618	322E8F	9335 714625	ALEKSEY ZHURAVLEV	{"email": "zhuravlevaleksey031974@postgrespro.ru", "phone": "+70959701343"}
0005432105619	322E8F	6354 540931	ALEKSANDR FEDOROV	{"phone": "+70144553987"}
0005432105620	BC6B02	6566 656852	ELENA POPOVA	{"email": "epopova-011980@postgrespro.ru", "phone": "+70528365008"}
0005432105621	BC6B02	8545 418615	MATVEY ABRAMOV	{"email": "matvey.abramov.041978@postgrespro.ru", "phone": "+70719767804"}
0005432105622	8C93A5	1056 031770	MARINA ZHUKOVA	{"email": "zhukova.marina1972@postgrespro.ru", "phone": "+70378582694"}
0005432105623	428CDD	8883 578506	IRINA PETROVA	{"phone": "+70723865955"}
0005432105624	428CDD	5475 915505	KLAVDIYA GRISHINA	{"phone": "+70463384941"}
0005432105625	C34AB4	9809 148600	ALEKSANDR ILIN	{"phone": "+70048197564"}
0005432105626	68751F	1050 872498	IRINA KUZMINA	{"phone": "+70983710491"}
0005432105627	9059F2	5271 951732	EGOR MOROZOV	{"phone": "+70667909909"}
0005432105628	9059F2	4452 554921	ALEKSANDRA SCHERBAKOVA	{"phone": "+70514927940"}
0005432105629	0C55CD	2886 075541	YURIY DAVYDOV	{"email": "davydovyuriy-091958@postgrespro.ru", "phone": "+70424129958"}
0005432105630	BCE29D	1980 451617	SERGEY KUZNECOV	{"email": "kuznecov_s_1983@postgrespro.ru", "phone": "+70082647097"}
0005432105631	DFE4D7	8671 457536	KONSTANTIN BELOV	{"phone": "+70165635101"}
0005432105632	CBD9B2	3062 247720	OLGA ABRAMOVA	{"phone": "+70471474325"}
0005432105633	CBD9B2	7797 268331	VLADIMIR PETROV	{"phone": "+70757881096"}
0005432105634	D73966	6852 724350	VITALIY GRIGOREV	{"phone": "+70080918054"}
0005432105635	D73966	9465 343120	VENERA BORISOVA	{"email": "borisova-venera1975@postgrespro.ru", "phone": "+70383485762"}
0005432105636	6E5924	1511 021882	IRINA BELYAEVA	{"phone": "+70504385704"}
0005432105637	6AD3E3	0532 361739	MARAT ZAKHAROV	{"email": "zakharov.m_1976@postgrespro.ru", "phone": "+70127724564"}
0005432105638	8AC2D2	8792 107438	VLADIMIR SCHERBAKOV	{"phone": "+70986376329"}
0005432105639	AFAACE	5658 568130	ANATOLIY SOROKIN	{"email": "anatoliy-sorokin-051963@postgrespro.ru", "phone": "+70731625297"}
0005432105640	BE291F	8077 110055	EKATERINA MASLOVA	{"email": "emaslova1964@postgrespro.ru", "phone": "+70051363615"}
0005432105641	C067FF	0655 151223	NINA PETROVA	{"email": "nina_petrova121979@postgrespro.ru", "phone": "+70582049169"}
0005432105642	1E4626	0217 825341	SERGEY PETROV	{"email": "s.petrov_1971@postgrespro.ru", "phone": "+70018949337"}
0005432105643	1E4626	8426 265134	ALEKSANDR CHERNOV	{"email": "chernov_a.1969@postgrespro.ru", "phone": "+70776622479"}
0005432105644	775EA4	0023 514491	IGOR IVANOV	{"email": "i.ivanov-121977@postgrespro.ru", "phone": "+70556870877"}
0005432105645	D564E2	1210 126357	KIRILL ABRAMOV	{"email": "abramovk.27061970@postgrespro.ru", "phone": "+70211955004"}
0005432105646	D564E2	6822 569888	SERGEY IVANOV	{"phone": "+70563690529"}
0005432105647	05B830	4557 568404	ELIZAVETA KALININA	{"email": "ekalinina.04091977@postgrespro.ru", "phone": "+70616491691"}
0005432105648	05B830	4295 371106	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey1982@postgrespro.ru", "phone": "+70789338356"}
0005432105649	D47157	5141 083562	MIKHAIL MAKAROV	{"email": "mikhail_makarov-091977@postgrespro.ru", "phone": "+70620482642"}
0005432105650	F5EC3E	9118 051184	VITALIY IVANOV	{"phone": "+70620075272"}
0005432105651	E2AD2D	2752 424023	NATALYA ZAYCEVA	{"phone": "+70827645826"}
0005432105652	7B52FD	9434 266544	IRINA KUDRYASHOVA	{"email": "irinakudryashova_021962@postgrespro.ru", "phone": "+70869563235"}
0005432105653	06510C	6226 510644	IVAN SHEVCHENKO	{"phone": "+70190764069"}
0005432105654	7B2F53	8124 053387	YURIY SEMENOV	{"email": "yuriy-semenov1972@postgrespro.ru", "phone": "+70806210336"}
0005432105655	B6E1AB	9343 204376	ANDREY SIDOROV	{"email": "a.sidorov-1971@postgrespro.ru", "phone": "+70053882776"}
0005432105656	B6E1AB	3253 409885	ILYA ABRAMOV	{"phone": "+70130017152"}
0005432105657	4F9A6F	7643 632938	MARINA MARTYNOVA	{"email": "martynova_m-121968@postgrespro.ru", "phone": "+70112909643"}
0005432105658	F83AD4	4445 170222	ANASTASIYA SCHERBAKOVA	{"phone": "+70899262679"}
0005432105659	C062C3	1614 227220	ANASTASIYA MOROZOVA	{"phone": "+70112366227"}
0005432105660	C9BDAF	5469 758049	RUSLAN IVANOV	{"email": "ivanov-ruslan-051970@postgrespro.ru", "phone": "+70202691902"}
0005432105661	C9BDAF	3718 859689	EVGENIY IVANOV	{"phone": "+70120086575"}
0005432105662	ECF2D3	4900 674394	ELIZAVETA KONOVALOVA	{"phone": "+70690304631"}
0005432105663	3AD08C	9047 682474	VLADIMIR TIKHONOV	{"phone": "+70135925111"}
0005432105664	3AD08C	7061 555267	TATYANA BORISOVA	{"phone": "+70181111372"}
0005432105665	3A2FA6	6146 765642	VALERIY VASILEV	{"phone": "+70546037269"}
0005432105666	3A2FA6	3782 571006	ALEKSANDR MARTYNOV	{"phone": "+70416474244"}
0005432105667	126799	8016 757251	EKATERINA IVANOVA	{"phone": "+70594487985"}
0005432105668	126799	0668 276303	SERGEY BELOV	{"email": "belov_sergey-1965@postgrespro.ru", "phone": "+70663910830"}
0005432105669	A29B25	6441 163793	IRINA KONOVALOVA	{"email": "irina_konovalova-28111972@postgrespro.ru", "phone": "+70120304252"}
0005432105670	38C672	6349 139589	NIKITA VOROBEV	{"email": "nikita.vorobev-11111968@postgrespro.ru", "phone": "+70078659058"}
0005432105671	C0AE03	0396 021435	SVETLANA EFREMOVA	{"email": "efremova.s-10051974@postgrespro.ru", "phone": "+70378153310"}
0005432105672	16BB07	9734 336538	OLGA ZOTOVA	{"email": "zotova_olga-1968@postgrespro.ru", "phone": "+70709332152"}
0005432105673	16BB07	5511 636535	YURIY PAVLOV	{"email": "pavlov_y-061968@postgrespro.ru", "phone": "+70131141403"}
0005432105674	FEF103	5452 647738	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay25071974@postgrespro.ru", "phone": "+70737986872"}
0005432105675	FEF103	4159 909372	NIKOLAY KOZLOV	{"email": "kozlov.nikolay_11031975@postgrespro.ru", "phone": "+70731997118"}
0005432105676	FEF103	0928 586102	OLEG MELNIKOV	{"email": "melnikov-o_12121974@postgrespro.ru", "phone": "+70603320310"}
0005432105677	FEF103	1981 268552	LYUBOV VLASOVA	{"email": "l.vlasova_1977@postgrespro.ru", "phone": "+70267620856"}
0005432105678	6169C9	8384 688992	EKATERINA TARASOVA	{"email": "e-tarasova_1979@postgrespro.ru", "phone": "+70591129074"}
0005432105679	924FE4	2853 450553	VLADIMIR ZAYCEV	{"phone": "+70250357295"}
0005432105680	281CDB	3739 473983	IVAN MAKAROV	{"phone": "+70965524392"}
0005432105681	224E02	6148 722943	ROMAN KUDRYASHOV	{"email": "kudryashovroman17031968@postgrespro.ru", "phone": "+70314693677"}
0005432105682	201B28	9279 385877	TAMARA SOKOLOVA	{"phone": "+70575175260"}
0005432105683	138365	8436 144209	NIKOLAY BORISOV	{"email": "nikolay_borisov.061978@postgrespro.ru", "phone": "+70134864492"}
0005432105684	6EFDED	6808 070643	PETR DMITRIEV	{"email": "dmitrievpetr011970@postgrespro.ru", "phone": "+70465377251"}
0005432105685	4022C6	7820 467907	ALEKSEY MAKSIMOV	{"email": "aleksey-maksimov-19091974@postgrespro.ru", "phone": "+70628242867"}
0005432105686	71F386	0002 771242	KONSTANTIN BELOV	{"email": "k.belov-14021974@postgrespro.ru", "phone": "+70096115698"}
0005432105687	71F386	9870 840433	MIKHAIL KOROLEV	{"phone": "+70050672443"}
0005432105688	12A373	8415 271042	SVETLANA NAZAROVA	{"phone": "+70589615909"}
0005432105689	DCFF7A	1022 080969	VYACHESLAV VLASOV	{"email": "vlasov.v.1989@postgrespro.ru", "phone": "+70404222115"}
0005432105690	857E48	3104 829517	DMITRIY FROLOV	{"email": "dmitriyfrolov.15101971@postgrespro.ru", "phone": "+70309188428"}
0005432105691	857E48	5773 745298	ALEKSANDRA ANTONOVA	{"phone": "+70703675041"}
0005432105692	857E48	6237 485869	KIRILL KUZNECOV	{"email": "kuznecov_k.26101976@postgrespro.ru", "phone": "+70602027716"}
0005432105693	857E48	3080 543334	TATYANA LEBEDEVA	{"phone": "+70261282057"}
0005432105694	DEFD30	2575 913474	VALERIY IVANOV	{"email": "v.ivanov_16101975@postgrespro.ru", "phone": "+70345164367"}
0005432105695	A6723F	4791 699789	VALERIY STEPANOV	{"email": "stepanov_v.12081977@postgrespro.ru", "phone": "+70416088085"}
0005432105696	A6723F	7014 999928	SERGEY FOMIN	{"phone": "+70742336993"}
0005432105697	68EEE1	1269 465725	NIKITA SOLOVEV	{"email": "solovev_nikita-01111966@postgrespro.ru", "phone": "+70678672849"}
0005432105698	68EEE1	7451 799220	ILYA KUZNECOV	{"email": "ikuznecov121982@postgrespro.ru", "phone": "+70043235989"}
0005432105699	EB75D8	3961 310885	NATALYA POPOVA	{"phone": "+70059205825"}
0005432105700	5C4334	8336 829675	SERGEY FROLOV	{"email": "frolov_sergey1970@postgrespro.ru", "phone": "+70883898796"}
0005432105701	5C4334	6618 313140	LIDIYA KULIKOVA	{"phone": "+70120703325"}
0005432105702	4EB315	8546 422912	ALEKSANDR KUZMIN	{"phone": "+70472613975"}
0005432105703	67869D	7152 174310	IGOR SHEVCHENKO	{"email": "igor-shevchenko.031975@postgrespro.ru", "phone": "+70934816619"}
0005432105704	0413D8	1633 990417	VALENTINA KOZLOVA	{"phone": "+70203193808"}
0005432105705	0413D8	2019 181106	ALEKSEY PETROV	{"phone": "+70681920601"}
0005432105706	B44BBB	2456 509306	RINAT MAKSIMOV	{"email": "r-maksimov1986@postgrespro.ru", "phone": "+70842779073"}
0005432105707	B44BBB	5236 498063	YAROSLAV SCHERBAKOV	{"phone": "+70929134597"}
0005432105708	CCDB53	4784 321425	DMITRIY KAZAKOV	{"phone": "+70329591493"}
0005432105709	CCDB53	3937 554669	ALEKSANDR ALEKSEEV	{"phone": "+70250417752"}
0005432105710	069619	6026 540116	ANNA ZOTOVA	{"phone": "+70920377735"}
0005432105711	94CFC4	9916 045243	KRISTINA STEPANOVA	{"phone": "+70026188236"}
0005432105712	F41B52	3111 336689	OLGA ZHUKOVA	{"email": "olga-zhukova11121976@postgrespro.ru", "phone": "+70940920792"}
0005432105713	EC68E1	0805 869127	ANNA MOROZOVA	{"email": "morozovaa-1969@postgrespro.ru", "phone": "+70793108129"}
0005432105714	EC68E1	8344 863332	OLGA MOROZOVA	{"phone": "+70558118079"}
0005432105715	473E7C	5813 600954	VYACHESLAV TARASOV	{"email": "vyacheslav-tarasov_1979@postgrespro.ru", "phone": "+70252308671"}
0005432105716	EE808B	7922 392992	MARIYA MAKAROVA	{"email": "makarovamariya09031977@postgrespro.ru", "phone": "+70110533603"}
0005432105717	EE808B	3848 897286	SERGEY MEDVEDEV	{"phone": "+70310800917"}
0005432105718	BECFE9	7542 519385	ANTONINA ALEKSEEVA	{"email": "alekseeva.antonina-081962@postgrespro.ru", "phone": "+70357397899"}
0005432105719	3B68ED	1893 704365	DAMIR FILIPPOV	{"phone": "+70779247335"}
0005432105720	BA08FE	1298 594305	ALEKSEY POPOV	{"email": "aleksey-popov.27011969@postgrespro.ru", "phone": "+70518738460"}
0005432105721	FBA555	5406 085565	LYUDMILA CHERNOVA	{"phone": "+70118570957"}
0005432105722	432771	1408 504077	ANDREY ANTONOV	{"phone": "+70584065990"}
0005432105723	432771	0995 998849	NINA KUZNECOVA	{"email": "nina-kuznecova1973@postgrespro.ru", "phone": "+70869250929"}
0005432105724	52964B	2381 210748	ELVIRA SERGEEVA	{"phone": "+70804716267"}
0005432105725	3AAF73	1025 669045	VALERIY STEPANOV	{"email": "valeriy-stepanov.041972@postgrespro.ru", "phone": "+70737478145"}
0005432105726	3AAF73	4951 556624	PAVEL OSIPOV	{"phone": "+70322798775"}
0005432105727	AF4DC4	7012 050107	ANATOLIY SERGEEV	{"email": "anatoliy-sergeev1972@postgrespro.ru", "phone": "+70421271733"}
0005432105728	249B6B	7084 560407	NINA NAZAROVA	{"email": "nnazarova021974@postgrespro.ru", "phone": "+70636527096"}
0005432105729	E4E9F6	8452 775660	YULIYA KOZLOVA	{"phone": "+70270783210"}
0005432105730	E4E9F6	3623 866445	FEDOR PETROV	{"email": "petrov.fedor-18021990@postgrespro.ru", "phone": "+70343003019"}
0005432105731	E3B781	0137 908914	YAROSLAV FROLOV	{"email": "y-frolov-1971@postgrespro.ru", "phone": "+70112118359"}
0005432105732	E3B781	5946 700199	ELIZAVETA FROLOVA	{"phone": "+70765383617"}
0005432105733	E3B781	4161 433040	SERGEY ROMANOV	{"phone": "+70691691964"}
0005432105734	2371E7	6734 592029	ELENA GRISHINA	{"phone": "+70201917072"}
0005432105735	E4E482	5165 746135	VLADIMIR PAVLOV	{"phone": "+70193805805"}
0005432105736	3C77D5	3815 817969	VERA KUZNECOVA	{"phone": "+70587161029"}
0005432105737	9B30F0	1861 867603	TATYANA SOROKINA	{"email": "sorokina_tatyana021977@postgrespro.ru", "phone": "+70386677464"}
0005432105738	9B30F0	5880 666617	NADEZHDA VLASOVA	{"phone": "+70718549905"}
0005432105739	AE6391	3608 718290	ARINA IVANOVA	{"phone": "+70529086421"}
0005432105740	F06494	4376 211872	VYACHESLAV TARASOV	{"phone": "+70498074348"}
0005432105741	0727AD	1907 105628	TATYANA MAKAROVA	{"phone": "+70054335102"}
0005432105742	07171F	3979 035145	ELIZAVETA MAKSIMOVA	{"phone": "+70920754113"}
0005432105743	041697	7193 448982	ALEKSANDR SOROKIN	{"email": "sorokin_a_01021961@postgrespro.ru", "phone": "+70743576985"}
0005432105744	9A034C	0281 918216	VALENTINA KUZNECOVA	{"email": "vkuznecova1962@postgrespro.ru", "phone": "+70700082109"}
0005432105745	9A034C	6859 118024	SERGEY ILIN	{"email": "sergey-ilin.1972@postgrespro.ru", "phone": "+70395940380"}
0005432105746	B50E03	8677 208071	VERONIKA KUZNECOVA	{"email": "v-kuznecova111975@postgrespro.ru", "phone": "+70021073986"}
0005432105747	840175	0025 847812	EVGENIYA MAKAROVA	{"email": "makarova_e031977@postgrespro.ru", "phone": "+70808700541"}
0005432105748	9B9FC1	1254 759445	ALEKSANDR MARTYNOV	{"phone": "+70899668163"}
0005432105749	52B66D	5533 216163	PETR KARPOV	{"phone": "+70000078220"}
0005432105750	014C8E	3500 631750	NADEZHDA VASILEVA	{"email": "vasilevan-121974@postgrespro.ru", "phone": "+70989528924"}
0005432105751	AEC2ED	6966 185366	DMITRIY ALEKSEEV	{"email": "alekseev.d_101964@postgrespro.ru", "phone": "+70112721839"}
0005432105752	83D534	5765 328103	VALERIY KUZNECOV	{"phone": "+70567334990"}
0005432105753	E895B1	5813 308937	DMITRIY ANDREEV	{"phone": "+70660781948"}
0005432105754	111AC9	3508 754860	SERGEY FEDOROV	{"phone": "+70265272829"}
0005432105755	111AC9	3865 903511	POLINA SERGEEVA	{"email": "p-sergeeva081974@postgrespro.ru", "phone": "+70327137216"}
0005432105756	92614C	6861 865412	MAKSIM YAKOVLEV	{"phone": "+70339622890"}
0005432105757	6610B8	9983 698168	ALEKSEY SMIRNOV	{"email": "smirnova06061973@postgrespro.ru", "phone": "+70983636095"}
0005432105758	0A2B85	7575 519530	YURIY KULIKOV	{"email": "y_kulikov.15071975@postgrespro.ru", "phone": "+70004099006"}
0005432105759	5ABB35	3838 681928	ELENA KONDRATEVA	{"email": "kondrateva_elena.1972@postgrespro.ru", "phone": "+70688602805"}
0005432105760	74AC86	8242 177200	SVETLANA KAZAKOVA	{"phone": "+70417248345"}
0005432105761	5AA4D3	5381 837318	LIDIYA KARPOVA	{"phone": "+70823421214"}
0005432105762	74E201	7866 935127	TATYANA BARANOVA	{"phone": "+70630763216"}
0005432105763	74E201	4862 298640	ANASTASIYA ANDREEVA	{"email": "a_andreeva_1977@postgrespro.ru", "phone": "+70478274932"}
0005432105764	A35B26	6319 218752	VALENTINA ROMANOVA	{"phone": "+70018279682"}
0005432105765	6D3575	7175 201914	OLGA MATVEEVA	{"email": "matveeva-o_11051957@postgrespro.ru", "phone": "+70449003118"}
0005432105766	6D3575	6383 404057	VALENTINA TARASOVA	{"email": "tarasova_valentina_021970@postgrespro.ru", "phone": "+70902777158"}
0005432105767	65CD69	3622 783496	ALEKSANDR KOROLEV	{"phone": "+70406713057"}
0005432105768	486DB8	6295 036735	IRINA KUZMINA	{"phone": "+70751874490"}
0005432105769	486DB8	2904 690152	OKSANA VOLKOVA	{"phone": "+70739595213"}
0005432105770	9E5A24	3438 001770	EKATERINA ZAYCEVA	{"phone": "+70539395697"}
0005432105771	9E5A24	1911 838836	VALENTINA NIKIFOROVA	{"email": "valentina_nikiforova30121978@postgrespro.ru", "phone": "+70388125921"}
0005432105772	7F5C07	5593 296889	KARINA OVCHINNIKOVA	{"email": "karina_ovchinnikova1966@postgrespro.ru", "phone": "+70715334866"}
0005432105773	7F5C07	7242 104941	KONSTANTIN POPOV	{"phone": "+70915271579"}
0005432105774	D0A920	8740 322238	NADEZHDA ANTONOVA	{"phone": "+70963596797"}
0005432105775	2E1AE2	9789 078451	VIKTOR FILIPPOV	{"email": "v.filippov_111967@postgrespro.ru", "phone": "+70010088739"}
0005432105776	241C02	9487 200692	DENIS ALEKSEEV	{"phone": "+70907159891"}
0005432105777	241C02	5288 859385	IGOR SOKOLOV	{"email": "isokolov.23011974@postgrespro.ru", "phone": "+70912701364"}
0005432105778	241C02	4439 365005	SERGEY NAUMOV	{"email": "s-naumov_021962@postgrespro.ru", "phone": "+70824084085"}
0005432105779	72E513	8065 746758	EGOR KUZNECOV	{"email": "ekuznecov031973@postgrespro.ru", "phone": "+70966509650"}
0005432105780	925A08	6342 734601	SERGEY ABRAMOV	{"phone": "+70063078963"}
0005432105781	9CCDF6	6790 295737	YULIYA MIKHAYLOVA	{"phone": "+70590067233"}
0005432105782	2C2D43	5448 661959	IVAN NAUMOV	{"email": "i-naumov-1979@postgrespro.ru", "phone": "+70291091315"}
0005432105783	2C2D43	9080 200670	FEDOR EGOROV	{"email": "egorov.fedor-041958@postgrespro.ru", "phone": "+70979822784"}
0005432105784	53088C	4017 912065	ALEKSANDRA ORLOVA	{"phone": "+70365676104"}
0005432105785	B0EBEC	2852 813150	IGOR GRIGOREV	{"email": "grigorev_igor25031975@postgrespro.ru", "phone": "+70127567865"}
0005432105786	B0EBEC	2937 924068	ALEKSANDR FEDOTOV	{"phone": "+70632458089"}
0005432105787	9D86B3	7732 997486	LEONID BELOV	{"phone": "+70768364640"}
0005432105788	9D86B3	3401 558881	VALERIY KAZAKOV	{"phone": "+70561847322"}
0005432105789	91687B	4846 209529	NIKOLAY VOROBEV	{"phone": "+70912806616"}
0005432105790	91687B	9983 765459	DMITRIY KOROLEV	{"phone": "+70993898311"}
0005432105791	5C22BE	8465 367643	ALEKSEY BORISOV	{"phone": "+70023017947"}
0005432105792	8E6308	1753 935205	ALLA MAKAROVA	{"phone": "+70450115716"}
0005432105793	6F400E	0453 452334	ELENA SERGEEVA	{"email": "elena.sergeeva_30031984@postgrespro.ru", "phone": "+70459028136"}
0005432105794	1D713A	7432 521940	NINA ANTONOVA	{"email": "nantonova.20021980@postgrespro.ru", "phone": "+70316762087"}
0005432105795	1D713A	0067 641426	VYACHESLAV RODIONOV	{"phone": "+70597507147"}
0005432105796	9969D9	3069 212882	DMITRIY MATVEEV	{"email": "d.matveev.121975@postgrespro.ru", "phone": "+70762643451"}
0005432105797	7DC23B	1924 865790	TATYANA IVANOVA	{"phone": "+70929730105"}
0005432105798	960618	1773 839131	VERA ANISIMOVA	{"email": "vanisimova_18011980@postgrespro.ru", "phone": "+70229780453"}
0005432105799	A20D53	1998 401033	MAYYA KOMAROVA	{"phone": "+70382148735"}
0005432105800	3A020D	6539 446429	YULIYA MARTYNOVA	{"email": "y-martynova.011972@postgrespro.ru", "phone": "+70426877805"}
0005432105801	14581D	1146 429851	ALEKSANDR BARANOV	{"email": "baranova-1979@postgrespro.ru", "phone": "+70412653813"}
0005432105802	118F26	5412 898807	LYUDMILA AKIMOVA	{"phone": "+70902221877"}
0005432105803	118F26	5686 024189	ALEKSANDR MEDVEDEV	{"email": "medvedev-a.07091984@postgrespro.ru", "phone": "+70750047385"}
0005432105804	118F26	2666 483948	NIKOLAY VOLKOV	{"phone": "+70588896099"}
0005432105805	619B40	7253 138566	ILYA PAVLOV	{"email": "i_pavlov-09071977@postgrespro.ru", "phone": "+70980300272"}
0005432105806	57147B	8905 468073	VIKTORIYA ALEKSANDROVA	{"phone": "+70793082277"}
0005432105807	57147B	8887 517289	SERGEY ALEKSEEV	{"email": "sergey_alekseev-061975@postgrespro.ru", "phone": "+70733604092"}
0005432105808	279F10	2970 388530	EVGENIYA IVANOVA	{"phone": "+70056765306"}
0005432105809	279F10	7007 034732	NADEZHDA MIKHAYLOVA	{"phone": "+70160636355"}
0005432105810	68BA11	2396 431068	OLGA NIKOLAEVA	{"email": "nikolaevaolga_1979@postgrespro.ru", "phone": "+70784537577"}
0005432105811	FC6AEC	6891 050028	MARIYA SOLOVEVA	{"phone": "+70407775635"}
0005432105812	4807F7	9517 872033	NATALIYA MELNIKOVA	{"phone": "+70031773835"}
0005432105813	4FDE8F	5476 183870	ELENA ANTONOVA	{"phone": "+70235668746"}
0005432105814	4FDE8F	9534 895233	TAMARA POPOVA	{"phone": "+70024023961"}
0005432105815	E61192	5529 029776	NAIL DAVYDOV	{"email": "n_davydov_1975@postgrespro.ru", "phone": "+70070749685"}
0005432105816	3A1446	4741 448942	TAISIYA MATVEEVA	{"email": "taisiya-matveeva-1982@postgrespro.ru", "phone": "+70433858062"}
0005432105817	3A1446	2364 516971	ALEKSANDR KOROLEV	{"phone": "+70960053016"}
0005432105818	A32A98	8526 266356	ARTEM SEMENOV	{"email": "semenov.a_1976@postgrespro.ru", "phone": "+70953551538"}
0005432105819	0EE721	3273 760438	ANGELINA KULIKOVA	{"email": "angelina.kulikova.1979@postgrespro.ru", "phone": "+70596646143"}
0005432105820	E6B39F	6685 023716	ELENA MATVEEVA	{"phone": "+70178821870"}
0005432105821	2749D9	1601 495072	ALEKSEY MATVEEV	{"phone": "+70023958620"}
0005432105822	33B4B3	8513 910877	ELENA PAVLOVA	{"phone": "+70762202281"}
0005432105823	9FAD51	8084 638697	MIKHAIL KUZNECOV	{"phone": "+70976084689"}
0005432105824	9C4021	1767 227990	SERGEY KOZLOV	{"email": "kozlov_s-031963@postgrespro.ru", "phone": "+70068660456"}
0005432105825	9C4021	4635 140687	ANTON BELOV	{"phone": "+70481926646"}
0005432105826	D53238	8421 765099	RAISA SMIRNOVA	{"email": "smirnova-raisa1972@postgrespro.ru", "phone": "+70871552522"}
0005432105827	D53238	1543 246340	ANNA IVANOVA	{"email": "a.ivanova.1976@postgrespro.ru", "phone": "+70784209418"}
0005432105828	D53238	8514 454534	ELENA FADEEVA	{"phone": "+70457480707"}
0005432105829	3E531A	2338 853111	VALENTINA SIDOROVA	{"email": "sidorovavalentina-011969@postgrespro.ru", "phone": "+70615945827"}
0005432105830	3E531A	9212 991845	YURIY MOROZOV	{"phone": "+70696473813"}
0005432105831	DC0028	2214 843160	OLGA PETROVA	{"phone": "+70675434527"}
0005432105832	2DE3F2	9532 543439	ILMIR KULIKOV	{"email": "ilmir-kulikov.041974@postgrespro.ru", "phone": "+70002327775"}
0005432105833	1E49CF	5622 981861	TATYANA POLYAKOVA	{"email": "t-polyakova_011980@postgrespro.ru", "phone": "+70689771133"}
0005432105834	1E49CF	6935 228518	EVGENIY BELOV	{"phone": "+70275548600"}
0005432105835	7847EC	6226 694053	IRINA ANTONOVA	{"phone": "+70566989658"}
0005432105836	78A1E2	0106 861342	VYACHESLAV KAZAKOV	{"phone": "+70487640227"}
0005432105837	F0F19B	6365 056971	YURIY ALEKSANDROV	{"email": "y-aleksandrov_1971@postgrespro.ru", "phone": "+70367431990"}
0005432105838	F93276	1996 813813	YULIYA PETROVA	{"email": "yuliya-petrova111971@postgrespro.ru", "phone": "+70450285483"}
0005432105839	C28859	7341 515498	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr_1969@postgrespro.ru", "phone": "+70546196498"}
0005432105840	67DCE8	2402 343180	IRINA LEBEDEVA	{"phone": "+70141055873"}
0005432105841	696B87	0317 877121	EGOR VOLKOV	{"phone": "+70070236328"}
0005432105842	686555	6563 577729	ALEKSANDR ALEKSEEV	{"email": "alekseeva-091983@postgrespro.ru", "phone": "+70481573140"}
0005432105843	E73287	8097 335240	ANASTASIYA ROMANOVA	{"phone": "+70611396378"}
0005432105844	A42C20	5190 450600	OLGA OVCHINNIKOVA	{"email": "o_ovchinnikova-031971@postgrespro.ru", "phone": "+70514665607"}
0005432105845	456243	8363 619023	SVETLANA PETROVA	{"phone": "+70301744315"}
0005432105846	BCB190	9384 019282	OLEG SERGEEV	{"email": "sergeev_o13041988@postgrespro.ru", "phone": "+70921671632"}
0005432105847	1FB771	5515 413642	NADEZHDA PAVLOVA	{"phone": "+70517836292"}
0005432105848	1FB771	1077 519064	VYACHESLAV KOZLOV	{"email": "kozlov-vyacheslav-11091973@postgrespro.ru", "phone": "+70940059326"}
0005432105849	AA8481	2035 911701	NINA NIKITINA	{"email": "n-nikitina.30101963@postgrespro.ru", "phone": "+70593929947"}
0005432105850	AA8481	8890 568403	SERGEY MIRONOV	{"phone": "+70639713856"}
0005432105851	AA8481	4730 962034	SERGEY KUDRYASHOV	{"phone": "+70288240398"}
0005432105852	9CD003	8309 601310	SVETLANA DANILOVA	{"email": "danilova-s_041984@postgrespro.ru", "phone": "+70763198703"}
0005432105853	2C9585	8774 524748	NATALYA MASLOVA	{"email": "natalyamaslova_071976@postgrespro.ru", "phone": "+70523008024"}
0005432105854	2C9585	8240 915779	ALEKSANDR AFANASEV	{"phone": "+70887664830"}
0005432105855	686D00	9045 161169	ARTUR SAVELEV	{"email": "savelev.a-30011971@postgrespro.ru", "phone": "+70165956822"}
0005432105856	F9F57F	1288 633033	NATALYA STEPANOVA	{"email": "stepanova-natalya.1967@postgrespro.ru", "phone": "+70065146222"}
0005432105857	DCD266	3559 899659	SERGEY SEMENOV	{"email": "semenov_sergey.26011966@postgrespro.ru", "phone": "+70990366740"}
0005432105858	5D7D7D	9631 043129	VERA ILINA	{"phone": "+70913580665"}
0005432105859	7797FE	2609 745432	DMITRIY SERGEEV	{"phone": "+70947783946"}
0005432105860	91CD47	4937 207294	ALEKSANDR RODIONOV	{"email": "a_rodionov-101970@postgrespro.ru", "phone": "+70507687454"}
0005432105861	91CD47	9454 373952	SERGEY KUDRYASHOV	{"phone": "+70593761223"}
0005432105862	FA5819	6094 136342	IVAN VOLKOV	{"email": "ivanvolkov.02081979@postgrespro.ru", "phone": "+70030715716"}
0005432105863	FA5819	3738 878004	MARIYA MAKAROVA	{"email": "mariyamakarova1979@postgrespro.ru", "phone": "+70910149190"}
0005432105864	F771AB	5160 205774	YURIY NAZAROV	{"email": "ynazarov.1973@postgrespro.ru", "phone": "+70595274091"}
0005432105865	4F6043	7276 448012	NADEZHDA KUZMINA	{"email": "kuzmina.n_22011962@postgrespro.ru", "phone": "+70073369088"}
0005432105866	11AEC4	5985 120392	ANASTASIYA MALYSHEVA	{"phone": "+70600085806"}
0005432105867	4F7D33	1931 809037	ANDREY BARANOV	{"email": "a.baranov.1977@postgrespro.ru", "phone": "+70616207969"}
0005432105868	4F7D33	2338 577343	VYACHESLAV ZAKHAROV	{"phone": "+70504625795"}
0005432105869	BB7396	8700 615282	ANASTASIYA SCHERBAKOVA	{"email": "scherbakova.a.071979@postgrespro.ru", "phone": "+70994829026"}
0005432105870	4E0976	3520 747429	ANATOLIY MOISEEV	{"email": "a.moiseev_091974@postgrespro.ru", "phone": "+70923244078"}
0005432105871	2A1551	9503 805734	SVYATOSLAV MELNIKOV	{"email": "svyatoslav.melnikov-1981@postgrespro.ru", "phone": "+70930166240"}
0005432105872	DA1058	1456 342012	ALEKSANDR ZAKHAROV	{"phone": "+70989013566"}
0005432105873	2FB368	1070 534416	VALERIY SOLOVEV	{"email": "v-solovev_1972@postgrespro.ru", "phone": "+70859679968"}
0005432105874	F5B0B5	7838 748396	ALEKSANDR KAZAKOV	{"email": "kazakov.a1962@postgrespro.ru", "phone": "+70802666945"}
0005432105875	F5B0B5	0791 382300	NADEZHDA POTAPOVA	{"email": "potapova-n_23051966@postgrespro.ru", "phone": "+70272763590"}
0005432105876	02E80D	3820 611874	ELENA VOLKOVA	{"email": "volkovae_1969@postgrespro.ru", "phone": "+70871548933"}
0005432105877	8D07A9	1193 543645	NATALYA YUDINA	{"phone": "+70586005948"}
0005432105878	8D07A9	6518 880578	ELENA SERGEEVA	{"email": "sergeeva-e061964@postgrespro.ru", "phone": "+70755559724"}
0005432105879	B5145B	7742 191946	EMILIYA SEMENOVA	{"email": "e-semenova22031968@postgrespro.ru", "phone": "+70985264189"}
0005432105880	B5145B	6049 658440	OKSANA YUDINA	{"email": "o_yudina25111966@postgrespro.ru", "phone": "+70009918710"}
0005432105881	B5145B	2301 474655	NIKOLAY SOLOVEV	{"phone": "+70154191928"}
0005432105882	34BD75	6856 418057	MARINA NIKITINA	{"phone": "+70423749793"}
0005432105883	EFF813	1710 960297	VLADIMIR ILIN	{"email": "ilin.vladimir_111966@postgrespro.ru", "phone": "+70903695623"}
0005432105884	EFF813	9334 060141	TATYANA RODIONOVA	{"phone": "+70643666608"}
0005432105885	009228	1772 520179	SVETLANA ZHUKOVA	{"email": "svetlana_zhukova-1969@postgrespro.ru", "phone": "+70150383097"}
0005432105886	9E0867	1710 558371	VALENTINA SOKOLOVA	{"phone": "+70344048267"}
0005432105887	B8ADD6	6112 509866	MAKSIM KONOVALOV	{"email": "maksim.konovalov_061969@postgrespro.ru", "phone": "+70106299265"}
0005432105888	FED635	6945 700473	DMITRIY ILIN	{"phone": "+70388722963"}
0005432105889	FED635	8017 175934	NINA SOKOLOVA	{"email": "sokolova_nina-12021969@postgrespro.ru", "phone": "+70418866808"}
0005432105890	FED635	7832 132409	DMITRIY ISAEV	{"email": "dmitriy.isaev-041980@postgrespro.ru", "phone": "+70803391228"}
0005432105891	C50814	8719 717334	YAROSLAV KUZMIN	{"email": "kuzmin-yaroslav-19051981@postgrespro.ru", "phone": "+70478697591"}
0005432105892	264F99	7020 108348	LYUDMILA CHERNOVA	{"email": "lchernova_1973@postgrespro.ru", "phone": "+70383337081"}
0005432105893	21BF70	4401 868605	OKSANA FROLOVA	{"email": "frolova.o-111970@postgrespro.ru", "phone": "+70931073522"}
0005432105894	21BF70	1668 072931	ALEKSANDR SCHERBAKOV	{"phone": "+70086714604"}
0005432105895	21BF70	1040 820588	ALEKSEY MAKAROV	{"phone": "+70097644007"}
0005432105896	F57E3E	1075 676497	YURIY GORBUNOV	{"phone": "+70046945328"}
0005432105897	2EDF3C	7171 220842	RINAT MOISEEV	{"email": "moiseevrinat-031977@postgrespro.ru", "phone": "+70051407571"}
0005432105898	925BB5	2031 237155	GRIGORIY ANDREEV	{"phone": "+70956522388"}
0005432105899	42A607	7088 494473	ANTONINA SERGEEVA	{"phone": "+70442150550"}
0005432105900	51EC93	9001 027130	RIMMA KOVALEVA	{"phone": "+70406061764"}
0005432105901	51EC93	6454 840081	ALEKSANDRA TIKHONOVA	{"email": "a-tikhonova.071962@postgrespro.ru", "phone": "+70144629005"}
0005432105902	BCB7A7	9637 870117	LYUBOV SIDOROVA	{"email": "l.sidorova.31071959@postgrespro.ru", "phone": "+70264967308"}
0005432105903	BCB7A7	0841 310110	SERGEY SOROKIN	{"email": "ssorokin-19011974@postgrespro.ru", "phone": "+70660884121"}
0005432105904	B1E0D0	4523 883412	NATALYA DMITRIEVA	{"phone": "+70991669773"}
0005432105905	B1E0D0	1280 667074	VLADIMIR IVANOV	{"phone": "+70987796478"}
0005432105906	6608AB	3063 399537	ALEKSEY STEPANOV	{"email": "aleksey-stepanov-1972@postgrespro.ru", "phone": "+70495954659"}
0005432105907	6608AB	4767 899583	ALEKSANDR MATVEEV	{"email": "a_matveev1986@postgrespro.ru", "phone": "+70948030438"}
0005432105908	6608AB	5329 842578	ALEKSEY KUZNECOV	{"phone": "+70532195944"}
0005432105909	165927	5933 345004	MARGARITA GERASIMOVA	{"phone": "+70736072092"}
0005432105910	9B7D9E	0761 234672	OKSANA MARTYNOVA	{"phone": "+70907041692"}
0005432105911	CFE99C	1622 985292	VIKTOR KUZNECOV	{"phone": "+70450593023"}
0005432105912	CFE99C	7733 809809	EDUARD ISAEV	{"email": "isaeve_091965@postgrespro.ru", "phone": "+70218084203"}
0005432105913	CFE99C	0517 331244	ALEKSEY ZAKHAROV	{"email": "zakharov_a.27111967@postgrespro.ru", "phone": "+70813366576"}
0005432105914	CFE99C	0970 335373	SERGEY SEMENOV	{"phone": "+70759731991"}
0005432105915	366FAD	4929 084190	YULIYA NIKITINA	{"email": "ynikitina-1968@postgrespro.ru", "phone": "+70742247631"}
0005432105916	264072	1953 366789	VALERIY GERASIMOV	{"phone": "+70413768256"}
0005432105917	550B3D	2373 292350	MARIYA ZAKHAROVA	{"email": "m_zakharova-011957@postgrespro.ru", "phone": "+70616270612"}
0005432105918	7857B4	8025 797165	ALEKSANDRA MAKSIMOVA	{"email": "maksimovaaleksandra08091968@postgrespro.ru", "phone": "+70599492679"}
0005432105919	1E51FD	7569 096899	LIDIYA KOVALEVA	{"email": "kovaleva-l_1969@postgrespro.ru", "phone": "+70859368649"}
0005432105920	1E51FD	2078 546867	OLGA ALEKSANDROVA	{"email": "olga.aleksandrova.1961@postgrespro.ru", "phone": "+70744356885"}
0005432105921	3A3042	4247 534896	ILYA SOKOLOV	{"email": "i-sokolov.13071965@postgrespro.ru", "phone": "+70770504730"}
0005432105922	3A3042	5697 716328	LIDIYA KUDRYASHOVA	{"phone": "+70500557134"}
0005432105923	72E3D8	7643 078964	EVA SOKOLOVA	{"email": "e-sokolova_101967@postgrespro.ru", "phone": "+70432070840"}
0005432105924	895969	2918 565030	VERA IVANOVA	{"phone": "+70313064207"}
0005432105925	895969	0803 604910	ALEKSANDR EGOROV	{"phone": "+70277982889"}
0005432105926	781969	9717 879941	NADEZHDA POTAPOVA	{"phone": "+70436944429"}
0005432105927	522852	0845 993124	IVAN KOZLOV	{"phone": "+70707368616"}
0005432105928	89CFBA	2129 245562	YULIYA KAZAKOVA	{"phone": "+70166519676"}
0005432105929	C62D62	3840 431565	ANASTASIYA TARASOVA	{"phone": "+70063794143"}
0005432105930	C62D62	8280 203409	GALINA EGOROVA	{"email": "egorova_g-30091968@postgrespro.ru", "phone": "+70907225393"}
0005432105931	77F02D	9866 278997	ALEKSEY POPOV	{"phone": "+70910023988"}
0005432105932	77F02D	9044 697054	SERGEY SEMENOV	{"email": "semenovs_1966@postgrespro.ru", "phone": "+70537346995"}
0005432105933	F7F4EA	3511 114520	LIDIYA OSIPOVA	{"phone": "+70127736091"}
0005432105934	F7F4EA	6459 685172	DARYA MATVEEVA	{"phone": "+70897426344"}
0005432105935	974F9B	5131 820090	LIDIYA POPOVA	{"phone": "+70720606748"}
0005432105936	974F9B	4347 270274	SVETLANA SERGEEVA	{"phone": "+70918208601"}
0005432105937	4D24DC	9843 147366	VASILIY MAKSIMOV	{"email": "maksimov.vasiliy_101967@postgrespro.ru", "phone": "+70529157241"}
0005432105938	B15611	6409 045790	MARINA KUZNECOVA	{"email": "marina-kuznecova_18011984@postgrespro.ru", "phone": "+70387853871"}
0005432105939	FE5EB3	5457 085546	VYACHESLAV FROLOV	{"phone": "+70108273979"}
0005432105940	A52EDA	5890 978833	SVETLANA RODIONOVA	{"email": "svetlana.rodionova_1965@postgrespro.ru", "phone": "+70037431738"}
0005432105941	79A2DE	8615 469039	ULYANA MELNIKOVA	{"phone": "+70838545057"}
0005432105942	07A9EB	4250 732809	IRINA MAKAROVA	{"email": "makarova_irina_011978@postgrespro.ru", "phone": "+70321379972"}
0005432105943	281B93	7678 925623	ELENA KUZMINA	{"email": "kuzmina.elena-111977@postgrespro.ru", "phone": "+70445355440"}
0005432105944	C10032	6840 566576	NADEZHDA DENISOVA	{"phone": "+70147682060"}
0005432105945	E61694	1337 378506	ZOYA ANTONOVA	{"email": "antonovaz1974@postgrespro.ru", "phone": "+70018083111"}
0005432105946	929F06	0231 997775	DENIS SHEVCHENKO	{"phone": "+70746542457"}
0005432105947	929F06	9439 630654	DENIS MOROZOV	{"email": "d.morozov-20091978@postgrespro.ru", "phone": "+70367739251"}
0005432105948	53EC6B	9870 114378	DMITRIY SOLOVEV	{"email": "solovevdmitriy-1974@postgrespro.ru", "phone": "+70594111183"}
0005432105949	53EC6B	7472 650575	TAMARA IVANOVA	{"phone": "+70706399624"}
0005432105950	1A8A36	0936 784610	VYACHESLAV SMIRNOV	{"phone": "+70936771308"}
0005432105951	1A8A36	3614 674431	EGOR SOKOLOV	{"phone": "+70352480972"}
0005432105952	63813C	0064 839898	ANTONINA KISELEVA	{"email": "antoninakiseleva-15091975@postgrespro.ru", "phone": "+70099302549"}
0005432105953	5FA84C	2963 404346	NADEZHDA PETROVA	{"email": "nadezhda-petrova-07021976@postgrespro.ru", "phone": "+70715704291"}
0005432105954	E2F466	5323 894349	MIKHAIL NIKITIN	{"phone": "+70885497107"}
0005432105955	C9B161	4914 061049	VLADIMIR MIRONOV	{"email": "v.mironov1981@postgrespro.ru", "phone": "+70611307891"}
0005432105956	0E4025	0290 894430	VLADIMIR STEPANOV	{"email": "vladimir_stepanov_1978@postgrespro.ru", "phone": "+70371057548"}
0005432105957	68DA00	1945 702533	MAKSIM SCHERBAKOV	{"email": "maksim_scherbakov23081970@postgrespro.ru", "phone": "+70219710932"}
0005432105958	98E4CE	6628 781336	GALINA IVANOVA	{"phone": "+70277769579"}
0005432105959	98E4CE	1380 074452	VALENTINA ZOTOVA	{"email": "zotova_v_011972@postgrespro.ru", "phone": "+70314246148"}
0005432105960	EA3F94	3946 973803	MARIYA MARTYNOVA	{"phone": "+70805783250"}
0005432105961	E297A2	1691 139683	GLEB TIMOFEEV	{"phone": "+70025547625"}
0005432105962	30A185	5014 572597	IVAN ZAYCEV	{"phone": "+70233626611"}
0005432105963	937293	3891 774170	ANASTASIYA NIKOLAEVA	{"phone": "+70372176777"}
0005432105964	91E814	7536 647855	LYUDMILA BARANOVA	{"email": "l.baranova_18121979@postgrespro.ru", "phone": "+70475722504"}
0005432105965	05BB0B	5743 026111	VALENTINA LAZAREVA	{"phone": "+70805634625"}
0005432105966	88B4BE	1407 655857	VIKTOR BORISOV	{"phone": "+70087024574"}
0005432105967	F67D99	2208 183401	SVETLANA BELOVA	{"email": "belova-s19111981@postgrespro.ru", "phone": "+70210474762"}
0005432105968	048610	8619 523421	ANNA MIKHAYLOVA	{"phone": "+70988700444"}
0005432105969	13A6DF	6306 018685	IRINA ALEKSANDROVA	{"phone": "+70534533845"}
0005432105970	EF65C2	1414 710696	YULIYA GORBUNOVA	{"email": "gorbunova.y1981@postgrespro.ru", "phone": "+70957946536"}
0005432105971	EF65C2	7722 499110	VALENTINA KOLESNIKOVA	{"email": "kolesnikovav-1969@postgrespro.ru", "phone": "+70422529849"}
0005432105972	0EE13C	4175 609740	SVETLANA BORISOVA	{"email": "svetlana_borisova1971@postgrespro.ru", "phone": "+70008490590"}
0005432105973	E4C915	2260 599232	ELENA FROLOVA	{"email": "frolova_elena.081977@postgrespro.ru", "phone": "+70686955691"}
0005432105974	32B308	1510 379204	NADEZHDA GERASIMOVA	{"phone": "+70964402620"}
0005432105975	810CD1	0131 010457	ALEKSEY MOROZOV	{"email": "a-morozov1968@postgrespro.ru", "phone": "+70584894830"}
0005432105976	810CD1	1253 022687	OKSANA BELOVA	{"email": "o-belova-121977@postgrespro.ru", "phone": "+70764599881"}
0005432105977	810CD1	4144 540500	VASILIY KUZNECOV	{"phone": "+70528496342"}
0005432105978	7AC06B	4704 104760	ALEKSANDR GAVRILOV	{"phone": "+70847746921"}
0005432105979	AC0FE2	1325 243220	VALERIY NOVIKOV	{"phone": "+70877005151"}
0005432105980	AC0FE2	1291 063161	DARYA SOROKINA	{"email": "d-sorokina.051970@postgrespro.ru", "phone": "+70206656104"}
0005432105981	B0D1C0	2554 331223	GENNADIY ZHURAVLEV	{"email": "g-zhuravlev_071966@postgrespro.ru", "phone": "+70436838101"}
0005432105982	B0D1C0	4550 677926	DANIIL DMITRIEV	{"phone": "+70182332091"}
0005432105983	31F48B	5230 555484	ANNA MATVEEVA	{"email": "anna_matveeva.10091972@postgrespro.ru", "phone": "+70420918381"}
0005432105984	31F48B	0297 350458	EVGENIY VASILEV	{"email": "vasilev.e.061964@postgrespro.ru", "phone": "+70830394213"}
0005432105985	2C95C8	5673 152547	LIDIYA OSIPOVA	{"phone": "+70627462391"}
0005432105986	020A93	6210 295888	TATYANA ALEKSEEVA	{"phone": "+70730238229"}
0005432105987	020A93	0128 107426	YURIY CHERNOV	{"phone": "+70739133996"}
0005432105988	A763FE	1927 779816	EVGENIY NAZAROV	{"email": "enazarov-08011958@postgrespro.ru", "phone": "+70211756160"}
0005432105989	D0FF56	7631 987698	ALEKSANDR FROLOV	{"email": "aleksandrfrolov_07011975@postgrespro.ru", "phone": "+70403861530"}
0005432105990	92ADCB	2014 592245	IGOR FEDOTOV	{"phone": "+70395307492"}
0005432105991	19474D	0341 867009	ANTONINA ROMANOVA	{"phone": "+70015202888"}
0005432105992	A05B45	9736 499836	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail091966@postgrespro.ru", "phone": "+70706739301"}
0005432105993	DF9BF9	3809 524734	ARTEM KOROLEV	{"email": "artem.korolev_1970@postgrespro.ru", "phone": "+70834262759"}
0005432105994	DF9BF9	3846 263926	SERGEY PETROV	{"email": "petrov.s_051987@postgrespro.ru", "phone": "+70338038935"}
0005432105995	24672A	4627 282525	DENIS SOLOVEV	{"phone": "+70900827114"}
0005432105996	C7064D	7057 058332	VIKTORIYA NAZAROVA	{"email": "v_nazarova.051983@postgrespro.ru", "phone": "+70397859976"}
0005432105997	5268A2	1019 171114	YULIYA MATVEEVA	{"email": "ymatveeva_071979@postgrespro.ru", "phone": "+70438869524"}
0005432105998	8F0DEE	3648 844212	EKATERINA VOLKOVA	{"email": "evolkova011975@postgrespro.ru", "phone": "+70441175576"}
0005432105999	01A5B0	3275 510007	OLGA MARTYNOVA	{"phone": "+70439662700"}
0005432106000	01A5B0	8521 767130	NINA KULIKOVA	{"phone": "+70642468965"}
0005432106001	E69F2B	8066 819902	ILYA MAKAROV	{"phone": "+70730323333"}
0005432106002	E69F2B	2653 111124	DMITRIY FILIPPOV	{"email": "dfilippov.30011978@postgrespro.ru", "phone": "+70247881802"}
0005432106003	73B0FA	5682 798190	ARINA ALEKSANDROVA	{"email": "aleksandrova-arina-09121974@postgrespro.ru", "phone": "+70847681646"}
0005432106004	F63BB9	2637 961884	GALIYA OSIPOVA	{"email": "g_osipova02091970@postgrespro.ru", "phone": "+70692803905"}
0005432106005	6F9FE7	9452 834829	KLAVDIYA NESTEROVA	{"phone": "+70269760854"}
0005432106006	6F9FE7	3854 015628	ELENA TARASOVA	{"email": "elena_tarasova011969@postgrespro.ru", "phone": "+70652113573"}
0005432106007	1F4B48	1842 844444	OLGA EFIMOVA	{"phone": "+70847192473"}
0005432106008	A46C9E	2150 904253	VYACHESLAV KUZNECOV	{"email": "kuznecov_vyacheslav_051967@postgrespro.ru", "phone": "+70592195807"}
0005432106009	A46C9E	2899 296187	VALERIYA AKIMOVA	{"phone": "+70960334958"}
0005432106010	AB7835	0929 250956	EVGENIY IVANOV	{"phone": "+70429145612"}
0005432106011	DFDE13	0898 890109	ANDREY IVANOV	{"phone": "+70319170227"}
0005432106012	7053A7	4360 513898	ANTON SHEVCHENKO	{"phone": "+70654479651"}
0005432106013	7053A7	7681 505864	LYUDMILA YAKOVLEVA	{"email": "yakovleva_lyudmila13121981@postgrespro.ru", "phone": "+70286482396"}
0005432106014	3282DA	7551 565953	ROZALIYA ZAYCEVA	{"phone": "+70940712366"}
0005432106015	3282DA	8268 864170	OLEG ANDREEV	{"phone": "+70499044729"}
0005432106016	48B53C	6013 735852	OLESYA SERGEEVA	{"email": "olesya_sergeeva_111975@postgrespro.ru", "phone": "+70797305999"}
0005432106017	07C6BB	3488 025321	TATYANA TITOVA	{"email": "titova.t.1967@postgrespro.ru", "phone": "+70286431946"}
0005432106018	26CCE3	3520 142514	NATALYA ALEKSEEVA	{"email": "n-alekseeva_1971@postgrespro.ru", "phone": "+70034062714"}
0005432106019	26CCE3	0191 789912	IRINA KONOVALOVA	{"phone": "+70449448797"}
0005432106020	9C573A	3666 519402	MARIYA AFANASEVA	{"phone": "+70111936006"}
0005432106021	5DC846	7202 636701	MIKHAIL VLASOV	{"phone": "+70227425722"}
0005432106022	5DC846	1882 440098	IGOR TIMOFEEV	{"phone": "+70392906577"}
0005432106023	DF7012	9674 825838	IRINA VOLKOVA	{"phone": "+70457675656"}
0005432106024	ABAD3A	5195 186915	EVDOKIYA VOLKOVA	{"email": "volkovaevdokiya02121974@postgrespro.ru", "phone": "+70462931755"}
0005432106025	37A561	3258 418515	ZINAIDA KOVALEVA	{"phone": "+70285088963"}
0005432106026	37A561	0184 939736	RAVIL NOVIKOV	{"email": "novikovr-1967@postgrespro.ru", "phone": "+70648155653"}
0005432106027	37A561	1110 458095	EDGAR ZAKHAROV	{"phone": "+70941319593"}
0005432106028	C1F747	7701 204624	ANATOLIY NOVIKOV	{"email": "novikovanatoliy-16121965@postgrespro.ru", "phone": "+70621108888"}
0005432106029	4FF4C4	9643 259225	IGOR KULIKOV	{"phone": "+70476338994"}
0005432106030	1773E2	2879 783631	ALEKSANDR BORISOV	{"phone": "+70224293588"}
0005432106031	C55F90	4639 061999	DMITRIY FEDOROV	{"phone": "+70099324260"}
0005432106032	7A4AE6	3168 096407	ALEKSANDR KUZMIN	{"email": "kuzmina_07091972@postgrespro.ru", "phone": "+70133881192"}
0005432106033	7A4AE6	1395 998490	NATALYA FROLOVA	{"phone": "+70056505071"}
0005432106034	4859F1	5196 284739	ANTONINA GRISHINA	{"phone": "+70464711736"}
0005432106035	F322BD	3983 277833	VIKTOR SIDOROV	{"email": "viktor_sidorov1968@postgrespro.ru", "phone": "+70424726774"}
0005432106036	F31E77	5423 715223	EMILIYA ILINA	{"phone": "+70527651878"}
0005432106037	677F8E	9415 396218	OLGA GORBUNOVA	{"email": "gorbunovao.1968@postgrespro.ru", "phone": "+70886139622"}
0005432106038	677F8E	6367 270616	VALENTINA NOVIKOVA	{"email": "novikova_valentina-1972@postgrespro.ru", "phone": "+70829852159"}
0005432106039	F06D2D	2892 096136	SERGEY SMIRNOV	{"phone": "+70157528555"}
0005432106040	7E34AB	8693 296736	DMITRIY BONDARENKO	{"phone": "+70927530946"}
0005432106041	7E34AB	2040 191979	KLAVDIYA GUSEVA	{"email": "guseva-klavdiya-18101974@postgrespro.ru", "phone": "+70965318467"}
0005432106042	293CD9	2104 311116	SVETLANA BORISOVA	{"phone": "+70360409760"}
0005432106043	7BF952	6497 373279	RAISA NAZAROVA	{"phone": "+70916919963"}
0005432106044	7BF952	4112 596191	VASILIY IVANOV	{"email": "ivanov.v.1971@postgrespro.ru", "phone": "+70130202466"}
0005432106045	8AA066	4539 255041	ELENA SCHERBAKOVA	{"email": "escherbakova011969@postgrespro.ru", "phone": "+70723167173"}
0005432106046	8AA066	6109 563577	EKATERINA SOROKINA	{"phone": "+70156092145"}
0005432106047	C9DB4A	3071 475173	RAISA GORBUNOVA	{"email": "r.gorbunova_09111963@postgrespro.ru", "phone": "+70216952577"}
0005432106048	488EE1	8740 955471	ANNA GUSEVA	{"email": "guseva_a.021979@postgrespro.ru", "phone": "+70367168835"}
0005432106049	488EE1	6059 575110	VYACHESLAV POPOV	{"phone": "+70265256816"}
0005432106050	224F00	4129 527145	EKATERINA YUDINA	{"email": "yudinae1980@postgrespro.ru", "phone": "+70818975060"}
0005432106051	224F00	6712 672114	NIKOLAY OSIPOV	{"email": "nikolay_osipov1967@postgrespro.ru", "phone": "+70145627338"}
0005432106052	E0771C	8951 069314	ROMAN IVANOV	{"phone": "+70659927905"}
0005432106053	77F5E3	9316 586124	ALEKSANDR DAVYDOV	{"email": "aleksandr-davydov.1973@postgrespro.ru", "phone": "+70748648095"}
0005432106054	77F5E3	1935 288762	NADEZHDA BORISOVA	{"email": "borisova.nadezhda.071972@postgrespro.ru", "phone": "+70683426214"}
0005432106055	DF81CF	5391 756427	TATYANA NIKITINA	{"phone": "+70826995730"}
0005432106056	DF81CF	3501 500572	ALINA AKIMOVA	{"phone": "+70423838699"}
0005432106057	D564C0	5190 429490	SVETLANA KRASNOVA	{"email": "s_krasnova1965@postgrespro.ru", "phone": "+70412135197"}
0005432106058	A22BBF	6772 651832	EVGENIYA DENISOVA	{"phone": "+70552090844"}
0005432106059	4EA848	2916 783748	ELENA YUDINA	{"phone": "+70310593189"}
0005432106060	4EA848	5099 425371	ARTEM FROLOV	{"phone": "+70215153729"}
0005432106061	4EA848	7304 166158	NIKOLAY SIDOROV	{"phone": "+70482336034"}
0005432106062	5E96B3	1754 229057	VIKTOR BONDARENKO	{"email": "v.bondarenko-12101972@postgrespro.ru", "phone": "+70938088000"}
0005432106063	CCAEE6	8744 121245	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev1979@postgrespro.ru", "phone": "+70171460935"}
0005432106064	CCAEE6	7924 295173	OLGA IVANOVA	{"phone": "+70117693181"}
0005432106065	BBFC1A	0346 671769	ARTEM MAKAROV	{"email": "makarov_a.1974@postgrespro.ru", "phone": "+70527868188"}
0005432106066	11792B	6657 101906	NIKOLAY ALEKSEEV	{"phone": "+70336555155"}
0005432106067	D7E77E	2006 605321	ROMAN SCHERBAKOV	{"phone": "+70003107163"}
0005432106068	D7E77E	2999 058728	ALLA SEMENOVA	{"phone": "+70002518462"}
0005432106069	72EA61	7914 017326	DANIIL KUZMIN	{"email": "dkuzmin.09111973@postgrespro.ru", "phone": "+70567720726"}
0005432106070	72EA61	3017 398651	NATALYA MOISEEVA	{"email": "n_moiseeva-1964@postgrespro.ru", "phone": "+70591241110"}
0005432106071	95FD47	0102 392680	OLEG VOROBEV	{"phone": "+70609097215"}
0005432106072	95FD47	3725 101766	NIKOLAY GRIGOREV	{"email": "n.grigorev01091983@postgrespro.ru", "phone": "+70638927155"}
0005432106073	008791	1367 261511	VALENTIN KUDRYASHOV	{"email": "valentin-kudryashov_30101977@postgrespro.ru", "phone": "+70345373281"}
0005432106074	3B0A10	6835 140500	YURIY EGOROV	{"email": "yuriy_egorov.08061963@postgrespro.ru", "phone": "+70761286452"}
0005432106075	3D2BC1	7350 173961	OLGA LAZAREVA	{"email": "olgalazareva_1963@postgrespro.ru", "phone": "+70031690486"}
0005432106076	FF9A57	7349 536689	TAISIYA SOKOLOVA	{"email": "taisiyasokolova.1975@postgrespro.ru", "phone": "+70858565975"}
0005432106077	99019E	5579 336704	OLEG TARASOV	{"email": "oleg.tarasov.1973@postgrespro.ru", "phone": "+70900768409"}
0005432106078	297100	4927 121149	NATALYA KUZNECOVA	{"email": "kuznecova.natalya-051973@postgrespro.ru", "phone": "+70125454892"}
0005432106079	297100	0095 440358	ELVIRA POPOVA	{"email": "popova_e.23081964@postgrespro.ru", "phone": "+70889653476"}
0005432106080	3AD152	3489 139858	VALERIY EGOROV	{"email": "egorovvaleriy_011974@postgrespro.ru", "phone": "+70645024259"}
0005432106081	3AD152	6107 509128	VALENTIN STEPANOV	{"phone": "+70499929477"}
0005432106082	3AD152	9898 259390	SERGEY IVANOV	{"email": "sergey.ivanov-30081967@postgrespro.ru", "phone": "+70569558239"}
0005432106083	AF0E11	8522 118715	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov.091986@postgrespro.ru", "phone": "+70555329493"}
0005432106084	AF0E11	8220 322354	ALISA VASILEVA	{"email": "a-vasileva-1969@postgrespro.ru", "phone": "+70336186789"}
0005432106085	C56B78	0769 550261	ANNA KUZNECOVA	{"phone": "+70903781534"}
0005432106086	C1722E	3067 871771	SERGEY KONOVALOV	{"email": "konovalovs02091971@postgrespro.ru", "phone": "+70001584263"}
0005432106087	C1722E	8253 669628	ROMAN ANTONOV	{"email": "roman_antonov-1978@postgrespro.ru", "phone": "+70294465064"}
0005432106088	C1722E	0880 028033	LYUDMILA LEBEDEVA	{"email": "llebedeva.011976@postgrespro.ru", "phone": "+70538765465"}
0005432106089	EC15CF	4400 375894	DMITRIY SEMENOV	{"phone": "+70404375170"}
0005432106090	024E9B	0262 379785	DMITRIY BELOV	{"email": "d.belov-071972@postgrespro.ru", "phone": "+70160161360"}
0005432106091	5C9343	1157 126519	ILYA SOROKIN	{"email": "sorokin_i_03101984@postgrespro.ru", "phone": "+70351499029"}
0005432106092	C23958	5096 208820	DMITRIY SOKOLOV	{"email": "sokolov.d.25121965@postgrespro.ru", "phone": "+70187720279"}
0005432106093	882B58	2334 962879	GALINA ZOTOVA	{"email": "galina_zotova1967@postgrespro.ru", "phone": "+70407458930"}
0005432106094	1ED651	5004 080319	NADEZHDA VLASOVA	{"email": "vlasova_n-011981@postgrespro.ru", "phone": "+70929326847"}
0005432106095	F5DDE1	3381 230327	NADEZHDA KONOVALOVA	{"phone": "+70936605647"}
0005432106096	F5DDE1	6564 244445	VLADIMIR GRIGOREV	{"email": "v-grigorev_03101978@postgrespro.ru", "phone": "+70959347625"}
0005432106097	416E74	8963 526035	GENNADIY KUZNECOV	{"email": "kuznecovgennadiy03081966@postgrespro.ru", "phone": "+70345330744"}
0005432106098	49ABE4	1221 416379	VITALIY PETROV	{"phone": "+70558812386"}
0005432106099	6B38A3	2164 209804	LARISA TROFIMOVA	{"phone": "+70270098551"}
0005432106100	6B38A3	9874 021374	ALEKSEY DAVYDOV	{"phone": "+70333304462"}
0005432106101	FE24E7	1187 336686	NADEZHDA SOLOVEVA	{"phone": "+70219989623"}
0005432106102	FE24E7	4378 995289	NIKOLAY YAKOVLEV	{"email": "yakovlev-n_1969@postgrespro.ru", "phone": "+70779234789"}
0005432106103	E3E442	0331 533496	DMITRIY MARTYNOV	{"email": "martynov.dmitriy-13101975@postgrespro.ru", "phone": "+70194320695"}
0005432106104	E3E442	5463 154415	ALEVTINA NOVIKOVA	{"email": "novikova_a.101977@postgrespro.ru", "phone": "+70718463829"}
0005432106105	A1C2DB	5727 660692	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey-1985@postgrespro.ru", "phone": "+70620226640"}
0005432106106	245A74	5337 468719	IRINA ROMANOVA	{"phone": "+70923938711"}
0005432106107	427843	6035 706444	TATYANA MALYSHEVA	{"phone": "+70090028622"}
0005432106108	427843	9260 711772	IGOR IVANOV	{"phone": "+70407677201"}
0005432106109	F45965	1718 936217	EVGENIY KOZLOV	{"phone": "+70404689093"}
0005432106110	A06D67	2763 756807	VIKTORIYA ISAEVA	{"email": "viktoriya-isaeva_19111971@postgrespro.ru", "phone": "+70153106444"}
0005432106111	A06D67	0652 954572	IRINA YAKOVLEVA	{"phone": "+70173962028"}
0005432106112	A06D67	0578 320035	YURIY VASILEV	{"email": "vasilev_yuriy031981@postgrespro.ru", "phone": "+70045577748"}
0005432106113	80337D	3541 098411	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir-1960@postgrespro.ru", "phone": "+70023727177"}
0005432106114	3E8684	3501 213086	NIKITA TIMOFEEV	{"email": "n_timofeev1972@postgrespro.ru", "phone": "+70502603533"}
0005432106115	720A69	4271 863359	OLGA ABRAMOVA	{"phone": "+70801876009"}
0005432106116	232372	5456 415407	ALEKSANDR SERGEEV	{"email": "sergeev.a-14061969@postgrespro.ru", "phone": "+70472877471"}
0005432106117	232372	8268 898220	ANATOLIY SIDOROV	{"email": "anatoliy-sidorov031975@postgrespro.ru", "phone": "+70461449186"}
0005432106118	A1FA5F	1118 994553	NADEZHDA ROMANOVA	{"email": "romanova.nadezhda-031972@postgrespro.ru", "phone": "+70509921437"}
0005432106119	9367DD	3308 641746	SERGEY DENISOV	{"email": "denisov-s-1980@postgrespro.ru", "phone": "+70667135027"}
0005432106120	9367DD	4518 500793	ALEKSANDR BELOV	{"phone": "+70930676981"}
0005432106121	2AE2BD	9913 145294	ARTEM BORISOV	{"phone": "+70509608466"}
0005432106122	0F7C5C	6238 399012	VIKTOR MIRONOV	{"email": "mironov_viktor19111969@postgrespro.ru", "phone": "+70075029808"}
0005432106123	0F7C5C	2013 307174	SERGEY FOMIN	{"email": "fomin-s081966@postgrespro.ru", "phone": "+70178281576"}
0005432106124	8B3ABF	3900 196690	ANATOLIY ALEKSEEV	{"email": "alekseevanatoliy-021970@postgrespro.ru", "phone": "+70952646590"}
0005432106125	46D2F2	4197 571308	EVGENIY ZHUKOV	{"phone": "+70497338626"}
0005432106126	46D2F2	4903 848679	TATYANA BELYAEVA	{"phone": "+70315468629"}
0005432106127	B0C349	5468 467886	VADIM SHEVCHENKO	{"phone": "+70645781209"}
0005432106128	A10737	2041 100016	MARIYA FEDOROVA	{"phone": "+70190186663"}
0005432106129	2A26A3	6076 646794	BORIS SEMENOV	{"phone": "+70145912773"}
0005432106130	BABE45	4562 982339	TATYANA IVANOVA	{"phone": "+70055341666"}
0005432106131	43A389	7359 458318	VITALIY FROLOV	{"phone": "+70634294980"}
0005432106132	149474	1622 297326	ALEKSANDR SERGEEV	{"phone": "+70680810427"}
0005432106133	149474	6651 520327	TATYANA KOVALEVA	{"phone": "+70060403482"}
0005432106134	231EC5	4011 249876	ZOYA KUZNECOVA	{"phone": "+70768366749"}
0005432106135	231EC5	1676 927299	NADEZHDA VASILEVA	{"phone": "+70196042151"}
0005432106136	8538DA	5874 161057	NADEZHDA MALYSHEVA	{"email": "malysheva_nadezhda.1978@postgrespro.ru", "phone": "+70131074328"}
0005432106137	DBAA7D	2366 861567	MIKHAIL SCHERBAKOV	{"phone": "+70743128132"}
0005432106138	DBAA7D	9913 569733	TAMARA IVANOVA	{"email": "t-ivanova-20071974@postgrespro.ru", "phone": "+70475859058"}
0005432106139	C9E15E	5088 246924	ANTONINA MALYSHEVA	{"email": "malysheva_a-071972@postgrespro.ru", "phone": "+70197851565"}
0005432106140	9C8150	9769 479312	MIKHAIL OSIPOV	{"email": "m_osipov-1970@postgrespro.ru", "phone": "+70454305728"}
0005432106141	00DBC4	0562 145908	SERGEY ABRAMOV	{"email": "s_abramov-04071960@postgrespro.ru", "phone": "+70630564903"}
0005432106142	00DBC4	2951 863632	OKSANA VASILEVA	{"email": "o.vasileva-20121967@postgrespro.ru", "phone": "+70886939886"}
0005432106143	0C46C3	3221 479485	ELENA ZHUKOVA	{"phone": "+70425388626"}
0005432106144	0C46C3	4637 675803	IVAN SOLOVEV	{"email": "i-solovev22111970@postgrespro.ru", "phone": "+70197902414"}
0005432106145	D71FA8	7265 229852	ALEKSEY ILIN	{"phone": "+70070203973"}
0005432106146	F0229B	3525 235052	POLINA KUZNECOVA	{"phone": "+70197981213"}
0005432106147	F0229B	8033 058039	LARISA PETROVA	{"email": "l.petrova18011987@postgrespro.ru", "phone": "+70656588680"}
0005432106148	FD90A1	0414 357640	MARIYA PETROVA	{"email": "petrova_m.24011975@postgrespro.ru", "phone": "+70417268965"}
0005432106149	FD90A1	5930 029475	ALEKSANDR ALEKSEEV	{"phone": "+70397351805"}
0005432106150	F2715A	6097 003244	VLADISLAV SAVELEV	{"email": "savelev-v_061973@postgrespro.ru", "phone": "+70270697080"}
0005432106151	0C529C	9551 450998	EKATERINA KOROLEVA	{"phone": "+70422263575"}
0005432106152	0C529C	1502 436901	DARINA VASILEVA	{"email": "darina-vasileva-20111973@postgrespro.ru", "phone": "+70362134479"}
0005432106153	285828	9353 597746	TATYANA ZOTOVA	{"phone": "+70575580228"}
0005432106154	E1C1FE	6620 922163	DARYA OSIPOVA	{"phone": "+70721852994"}
0005432106155	12FBDE	2742 033923	SVETLANA FROLOVA	{"phone": "+70248396414"}
0005432106156	12FBDE	2259 107945	ILYA FROLOV	{"phone": "+70051289660"}
0005432106157	12FBDE	0347 071044	ALEKSEY ZHUKOV	{"email": "aleksey_zhukov-101975@postgrespro.ru", "phone": "+70863775568"}
0005432106158	505C8E	1537 771254	MAKSIM ORLOV	{"email": "maksimorlov.14101975@postgrespro.ru", "phone": "+70274445900"}
0005432106159	505C8E	3460 468786	OLGA IVANOVA	{"email": "oivanova.1976@postgrespro.ru", "phone": "+70437369785"}
0005432106160	6B5A04	1023 419157	NATALYA SERGEEVA	{"phone": "+70260727672"}
0005432106161	F7FFD9	4618 933417	VIKTOR KISELEV	{"email": "vkiselev.1984@postgrespro.ru", "phone": "+70617013312"}
0005432106162	F7FFD9	1936 640293	IVAN PETROV	{"email": "petrov-i.1968@postgrespro.ru", "phone": "+70474519623"}
0005432106163	7CEA94	9034 196633	SERGEY GERASIMOV	{"email": "gerasimov-s_25101955@postgrespro.ru", "phone": "+70734569776"}
0005432106164	BAB419	7775 527883	ANTONINA AFANASEVA	{"phone": "+70336956164"}
0005432106165	42CA3B	0275 092500	LYUBOV ABRAMOVA	{"email": "abramova.lyubov.01101967@postgrespro.ru", "phone": "+70565296658"}
0005432106166	367C34	3063 493227	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev101979@postgrespro.ru", "phone": "+70055739846"}
0005432106167	1B4C6B	3294 095418	ARTUR EGOROV	{"phone": "+70066369449"}
0005432106168	1B4C6B	0689 231518	EVGENIY BELOV	{"phone": "+70587578469"}
0005432106169	66EE9A	6062 601757	NATALYA VOLKOVA	{"email": "natalyavolkova.101968@postgrespro.ru", "phone": "+70104061362"}
0005432106170	87A301	6258 642960	SERGEY BARANOV	{"phone": "+70184240029"}
0005432106171	1770D1	5421 360129	ANNA KRASNOVA	{"email": "a.krasnova-081970@postgrespro.ru", "phone": "+70953006763"}
0005432106172	72556E	3731 504369	ELENA MARTYNOVA	{"email": "martynova_e.02021972@postgrespro.ru", "phone": "+70089648855"}
0005432106173	72556E	2218 474672	ANNA PAVLOVA	{"phone": "+70560713773"}
0005432106174	3AC1A3	2371 078056	SERGEY POPOV	{"phone": "+70863187504"}
0005432106175	D7143E	1718 723731	NATALYA STEPANOVA	{"email": "stepanova-natalya-051972@postgrespro.ru", "phone": "+70748149280"}
0005432106176	D7143E	5696 425315	ANNA KARPOVA	{"phone": "+70639318728"}
0005432106177	E6320F	5267 432499	SVETLANA KISELEVA	{"phone": "+70271405285"}
0005432106178	ED1B71	4624 074151	VYACHESLAV GUSEV	{"phone": "+70727478610"}
0005432106179	968B60	4881 845722	ANNA KOMAROVA	{"phone": "+70552882692"}
0005432106180	968B60	9303 257087	OLEG ANDREEV	{"email": "oleg.andreev24051965@postgrespro.ru", "phone": "+70072828862"}
0005432106181	6CA8C1	2635 697705	NINA MOROZOVA	{"phone": "+70685864891"}
0005432106182	6CA8C1	7324 942517	ALEKSANDR TARASOV	{"email": "tarasovaleksandr09111967@postgrespro.ru", "phone": "+70205635178"}
0005432106183	F417FA	6120 399098	LYUBOV SAVELEVA	{"phone": "+70709509177"}
0005432106184	F417FA	2869 721551	PAVEL STEPANOV	{"phone": "+70702247476"}
0005432106185	BA9C3E	0957 241117	TATYANA MARTYNOVA	{"email": "martynova.tatyana101981@postgrespro.ru", "phone": "+70627641177"}
0005432106186	BA9C3E	8666 098040	NINA ZAYCEVA	{"phone": "+70454373369"}
0005432106187	BA9C3E	4480 996938	DMITRIY NAZAROV	{"phone": "+70807998993"}
0005432106188	873B5A	9638 461970	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr.04091957@postgrespro.ru", "phone": "+70264698398"}
0005432106189	B8348A	1992 328380	YULIYA KOMAROVA	{"phone": "+70762580155"}
0005432106190	81A822	2272 797380	BORIS VLASOV	{"phone": "+70123108014"}
0005432106191	F55F8B	3471 931409	VLADIMIR SIDOROV	{"phone": "+70112116801"}
0005432106192	F55F8B	8316 392304	ANAIT CHERNOVA	{"phone": "+70197607116"}
0005432106193	5D6282	4522 588657	NADEZHDA LUKYANOVA	{"phone": "+70365524843"}
0005432106194	A0912E	3243 274415	ANNA POTAPOVA	{"email": "potapovaa-26031982@postgrespro.ru", "phone": "+70926437228"}
0005432106195	AF3C4A	3990 975861	ANTON KAZAKOV	{"phone": "+70748899434"}
0005432106196	E34D7E	2946 625697	ALEKSANDR KUZNECOV	{"phone": "+70217460075"}
0005432106197	D61C98	7264 245037	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov-1966@postgrespro.ru", "phone": "+70483197610"}
0005432106198	D61C98	3479 809672	SERGEY NAUMOV	{"phone": "+70943504043"}
0005432106199	5A698F	2064 273429	LYUDMILA SERGEEVA	{"email": "sergeeva-l_1965@postgrespro.ru", "phone": "+70359757242"}
0005432106200	E9728D	0651 694588	ANATOLIY VOLKOV	{"email": "volkov-a_1967@postgrespro.ru", "phone": "+70887436093"}
0005432106201	E9728D	6175 376398	SERGEY MIKHAYLOV	{"email": "s-mikhaylov-1975@postgrespro.ru", "phone": "+70615711892"}
0005432106202	122E41	6277 923039	NADEZHDA MAKAROVA	{"email": "makarova-nadezhda.1965@postgrespro.ru", "phone": "+70853072816"}
0005432106203	3B9807	6749 383969	GALINA ORLOVA	{"email": "g.orlova-11121971@postgrespro.ru", "phone": "+70802607057"}
0005432106204	E3DA38	7930 755346	TAMARA VASILEVA	{"email": "tamara_vasileva101972@postgrespro.ru", "phone": "+70759064752"}
0005432106205	CAD1E8	1811 235796	ELIZAVETA POPOVA	{"email": "elizaveta_popova19081968@postgrespro.ru", "phone": "+70569755804"}
0005432106206	CAD1E8	6606 219985	VALERIY NIKOLAEV	{"phone": "+70421280168"}
0005432106207	9485ED	7770 204897	NATALYA ANTONOVA	{"email": "n.antonova.31101975@postgrespro.ru", "phone": "+70947291170"}
0005432106208	A9559F	6121 776224	KONSTANTIN VLASOV	{"phone": "+70210675423"}
0005432106209	F22F9A	6982 816426	SHAMIL YAKOVLEV	{"email": "yakovlev_s_23031975@postgrespro.ru", "phone": "+70453084380"}
0005432106210	F22F9A	9787 743772	ALEKSEY VASILEV	{"phone": "+70604058867"}
0005432106211	FEF578	7490 027713	EKATERINA FROLOVA	{"email": "frolovaekaterina.1971@postgrespro.ru", "phone": "+70600584799"}
0005432106212	FEF578	3234 122549	RUSTAM VOLKOV	{"email": "rustam-volkov_03021972@postgrespro.ru", "phone": "+70577812377"}
0005432106213	CE3711	7348 300551	ALEKSANDR SMIRNOV	{"phone": "+70555496744"}
0005432106214	6B4EB1	5054 126047	MARIYA YAKOVLEVA	{"email": "yakovlevam.091976@postgrespro.ru", "phone": "+70226627044"}
0005432106215	6B4EB1	0402 852250	ALEKSANDR VASILEV	{"phone": "+70024698320"}
0005432106216	6B4EB1	0623 845281	MIKHAIL MOROZOV	{"phone": "+70546983580"}
0005432106217	DD43EF	8959 145956	DANILA SAVELEV	{"phone": "+70653085117"}
0005432106218	06C87A	5499 458755	VASILIY ALEKSANDROV	{"email": "vasiliy-aleksandrov-031963@postgrespro.ru", "phone": "+70412884014"}
0005432106219	74536E	9744 587658	MARIYA MAKAROVA	{"phone": "+70385350911"}
0005432106220	F428F9	4648 565516	KRISTINA BARANOVA	{"phone": "+70487053505"}
0005432106221	F428F9	0097 384929	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov23111984@postgrespro.ru", "phone": "+70754383217"}
0005432106222	831817	2581 361223	SERGEY KOZLOV	{"email": "kozlov-s.05121959@postgrespro.ru", "phone": "+70021454645"}
0005432106223	0D2AB2	0080 617620	ALEKSEY SERGEEV	{"phone": "+70604543757"}
0005432106224	23E32B	0833 702585	ALEKSEY PETROV	{"email": "petrov.aleksey081970@postgrespro.ru", "phone": "+70855809401"}
0005432106225	E5F819	1719 879876	SERGEY SOKOLOV	{"email": "s.sokolov1977@postgrespro.ru", "phone": "+70359767542"}
0005432106226	DD9FAE	7187 183992	ANNA KUDRYASHOVA	{"email": "akudryashova-121974@postgrespro.ru", "phone": "+70103747558"}
0005432106227	722A99	1415 563144	NINA KULIKOVA	{"email": "ninakulikova_1969@postgrespro.ru", "phone": "+70071372008"}
0005432106228	722A99	3548 199204	EGOR SAVELEV	{"email": "savelev.e-1970@postgrespro.ru", "phone": "+70151998097"}
0005432106229	0B24AB	5897 083441	ALEKSEY FEDOTOV	{"phone": "+70818583118"}
0005432106230	5BB7CE	1850 752558	ALINA ARKHIPOVA	{"phone": "+70551042089"}
0005432106231	5BB7CE	9433 906862	YULIYA LEBEDEVA	{"email": "y_lebedeva101969@postgrespro.ru", "phone": "+70813068087"}
0005432106232	2C6BCE	3071 946701	FARIT BONDARENKO	{"phone": "+70191234712"}
0005432106233	6A5739	2106 570396	DANILA ABRAMOV	{"email": "abramov_danila_101966@postgrespro.ru", "phone": "+70663931380"}
0005432106234	6A5739	6790 716011	KONSTANTIN FEDOROV	{"email": "k.fedorov.061973@postgrespro.ru", "phone": "+70080281416"}
0005432106235	9A1E38	2048 974302	GALINA MOROZOVA	{"email": "morozova-g10061966@postgrespro.ru", "phone": "+70764294821"}
0005432106236	05CFE3	1008 057378	EKATERINA POPOVA	{"email": "ekaterina_popova-1963@postgrespro.ru", "phone": "+70944051912"}
0005432106237	503C18	1879 964491	VALENTINA ANDREEVA	{"email": "andreeva_valentina1969@postgrespro.ru", "phone": "+70755007066"}
0005432106238	47AA07	7285 447111	TATYANA AFANASEVA	{"email": "tatyana_afanaseva-091969@postgrespro.ru", "phone": "+70348902387"}
0005432106239	47AA07	5835 977035	VALENTINA ZHURAVLEVA	{"email": "zhuravlevavalentina-061977@postgrespro.ru", "phone": "+70292308908"}
0005432106240	47AA07	5037 824008	KSENIYA YAKOVLEVA	{"email": "kseniya-yakovleva.031975@postgrespro.ru", "phone": "+70721274086"}
0005432106241	8D3800	4242 129824	YULIYA LAZAREVA	{"phone": "+70546874919"}
0005432106242	801843	7972 521757	ZOYA NOVIKOVA	{"email": "z.novikova-021977@postgrespro.ru", "phone": "+70003751048"}
0005432106243	801843	9304 167079	NATALYA TARASOVA	{"phone": "+70034730344"}
0005432106244	C11E2E	6524 684100	ANASTASIYA PAVLOVA	{"email": "pavlova-anastasiya_14031978@postgrespro.ru", "phone": "+70167898611"}
0005432106245	4600D9	9557 096916	ELENA BOGDANOVA	{"phone": "+70593771058"}
0005432106246	301135	1751 665009	ANDREY KUZNECOV	{"email": "kuznecovandrey_1985@postgrespro.ru", "phone": "+70518790620"}
0005432106247	301135	4923 746239	NINA PETROVA	{"phone": "+70366389963"}
0005432106248	D55806	2532 468892	GALINA MOROZOVA	{"email": "gmorozova-04031973@postgrespro.ru", "phone": "+70585540100"}
0005432106249	570EF2	1019 071565	ALEKSEY CHERNOV	{"phone": "+70583971586"}
0005432106250	570EF2	7019 089577	YANA FADEEVA	{"phone": "+70341231892"}
0005432106251	AAF1F4	0067 791011	TATYANA ALEKSANDROVA	{"email": "aleksandrova.t-14071966@postgrespro.ru", "phone": "+70947447277"}
0005432106252	AAF1F4	3435 893965	ALENA ZAKHAROVA	{"phone": "+70706579476"}
0005432106253	BCA646	6739 775757	VADIM FILIPPOV	{"email": "v_filippov-1970@postgrespro.ru", "phone": "+70593867266"}
0005432106254	2E11E5	7919 578718	RAISA KUZNECOVA	{"phone": "+70314807310"}
0005432106255	AB3716	4212 930131	TATYANA NESTEROVA	{"email": "tatyana-nesterova-09081973@postgrespro.ru", "phone": "+70044119974"}
0005432106256	9BB5D1	5090 649131	ANASTASIYA GERASIMOVA	{"email": "gerasimova_anastasiya.051977@postgrespro.ru", "phone": "+70537217658"}
0005432106257	4C9660	2835 426913	IGOR MAKAROV	{"phone": "+70003708934"}
0005432106258	4D3265	9667 144850	VLADIMIR NIKITIN	{"email": "v-nikitin.1970@postgrespro.ru", "phone": "+70120572011"}
0005432106259	FE8103	3732 653232	EKATERINA DAVYDOVA	{"email": "e.davydova_1975@postgrespro.ru", "phone": "+70825384902"}
0005432106260	FE8103	1677 837292	LYUBOV POTAPOVA	{"phone": "+70874817366"}
0005432106261	37DFA6	1223 915433	OLGA MAKAROVA	{"email": "o-makarova17031966@postgrespro.ru", "phone": "+70629521461"}
0005432106262	F9BFAB	1082 405741	SOFYA SMIRNOVA	{"phone": "+70146222538"}
0005432106263	1B5437	8692 107208	TAISIYA ERMAKOVA	{"email": "t.ermakova.1968@postgrespro.ru", "phone": "+70223905185"}
0005432106264	819C5B	9040 674243	LARISA KOZLOVA	{"email": "kozlova_larisa-1972@postgrespro.ru", "phone": "+70268531137"}
0005432106265	819C5B	7247 511734	YULIYA KOZLOVA	{"email": "kozlovayuliya-1965@postgrespro.ru", "phone": "+70226216187"}
0005432106266	35C17E	5453 849999	OLESYA VASILEVA	{"phone": "+70010175022"}
0005432106267	35C17E	2957 597075	ANDREY ZAYCEV	{"email": "a-zaycev-15101970@postgrespro.ru", "phone": "+70188447644"}
0005432106268	35C17E	2901 229659	MARIYA ROMANOVA	{"phone": "+70069097454"}
0005432106269	01AF4C	0198 607197	OKSANA EGOROVA	{"email": "egorova_oksana1967@postgrespro.ru", "phone": "+70767649386"}
0005432106270	24DDBA	9786 521160	ELIZAVETA POPOVA	{"email": "popova_elizaveta.1968@postgrespro.ru", "phone": "+70618580756"}
0005432106271	432D0A	5584 616885	GENNADIY EGOROV	{"phone": "+70599812514"}
0005432106272	432D0A	4594 154298	VALENTINA NIKITINA	{"email": "nikitina-valentina14041977@postgrespro.ru", "phone": "+70137237422"}
0005432106273	432D0A	5683 182292	NIKITA MARTYNOV	{"email": "martynov-n.051966@postgrespro.ru", "phone": "+70412264501"}
0005432106274	BD0762	0293 766830	MIKHAIL KRASNOV	{"phone": "+70305824791"}
0005432106275	70B785	0512 620569	NIKOLAY SOKOLOV	{"email": "nsokolov02101975@postgrespro.ru", "phone": "+70785764847"}
0005432106276	70B785	3320 929814	MIKHAIL FEDOTOV	{"email": "fedotov.mikhail-23061972@postgrespro.ru", "phone": "+70347626420"}
0005432106277	EB663D	8480 615797	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov.1982@postgrespro.ru", "phone": "+70577545611"}
0005432106278	B5C311	6174 584702	ILMIRA PAVLOVA	{"email": "pavlovailmira.01011961@postgrespro.ru", "phone": "+70253581632"}
0005432106279	B5C311	2387 281590	GRIGORIY CHERNOV	{"phone": "+70436611214"}
0005432106280	B5C311	3542 497424	TATYANA SAVELEVA	{"phone": "+70641730152"}
0005432106281	60587F	6491 616252	NINEL NAZAROVA	{"email": "nnazarova13061968@postgrespro.ru", "phone": "+70699549937"}
0005432106282	10DB70	1556 470781	VLADIMIR KISELEV	{"email": "kiselev_v.1979@postgrespro.ru", "phone": "+70129934307"}
0005432106283	10DB70	0748 571573	VLADIMIR BELOV	{"email": "vladimir_belov.1978@postgrespro.ru", "phone": "+70494216645"}
0005432106284	82C901	7712 019223	EMIL KOZLOV	{"email": "kozlov.e041983@postgrespro.ru", "phone": "+70861472473"}
0005432106285	DA6829	9833 400248	VIKTOR SERGEEV	{"email": "sergeevv1984@postgrespro.ru", "phone": "+70320114588"}
0005432106286	DA6829	0994 367600	VIKTOR KUZNECOV	{"email": "viktor-kuznecov11031967@postgrespro.ru", "phone": "+70593861143"}
0005432106287	B6F89B	6711 650042	VALENTINA SERGEEVA	{"phone": "+70660476585"}
0005432106288	B22A2C	9599 799356	LYUDMILA ERMAKOVA	{"phone": "+70984390921"}
0005432106289	6E459D	8895 853986	VLADIMIR ANDREEV	{"email": "v_andreev.1971@postgrespro.ru", "phone": "+70535063201"}
0005432106290	6E459D	1852 523799	MARIYA ALEKSEEVA	{"email": "alekseeva-m111980@postgrespro.ru", "phone": "+70497711245"}
0005432106291	A275F6	1931 026049	SVETLANA ROMANOVA	{"phone": "+70132485631"}
0005432106292	A275F6	1087 962600	GALINA SMIRNOVA	{"phone": "+70687705527"}
0005432106293	F1C676	4662 424441	ELENA IVANOVA	{"phone": "+70875341391"}
0005432106294	F1C676	4321 432878	VALENTINA TIKHONOVA	{"phone": "+70339339194"}
0005432106295	CF0875	1439 248396	OKSANA NESTEROVA	{"phone": "+70893448480"}
0005432106296	1A8B48	6672 633397	ANDREY VOROBEV	{"phone": "+70510514202"}
0005432106297	38D922	8836 850803	MARIYA ILINA	{"email": "ilinam.08021973@postgrespro.ru", "phone": "+70360213616"}
0005432106298	D92265	8910 737639	NATALIYA GERASIMOVA	{"phone": "+70491396590"}
0005432106299	5EBBC8	5639 401664	OLGA MAKSIMOVA	{"email": "maksimova-olga_121979@postgrespro.ru", "phone": "+70970392190"}
0005432106300	8CE9D2	1581 844853	YURIY IVANOV	{"email": "y_ivanov.17031968@postgrespro.ru", "phone": "+70535950191"}
0005432106301	D5073C	6123 202130	NIKOLAY KISELEV	{"email": "kiselev.n-1962@postgrespro.ru", "phone": "+70572399053"}
0005432106302	E6CF8E	6482 074294	VASILIY SCHERBAKOV	{"phone": "+70918040717"}
0005432106303	E0EFB1	5599 597696	LYUDMILA AFANASEVA	{"phone": "+70067979670"}
0005432106304	E0EFB1	2254 121505	VALERIY DAVYDOV	{"email": "valeriydavydov-1976@postgrespro.ru", "phone": "+70967589543"}
0005432106305	E48DE2	5184 653897	ARKADIY SHEVCHENKO	{"email": "arkadiy-shevchenko_1968@postgrespro.ru", "phone": "+70267722494"}
0005432106306	CE06F4	3139 085156	MARINA SIDOROVA	{"phone": "+70852919403"}
0005432106307	CE06F4	5506 400567	ANATOLIY CHERNOV	{"email": "anatoliy-chernov121977@postgrespro.ru", "phone": "+70787820107"}
0005432106308	EC5294	6302 841704	SOFIYA FILIPPOVA	{"email": "filippova_s.24061978@postgrespro.ru", "phone": "+70356717671"}
0005432106309	F1DE43	8460 556663	ANDREY NAZAROV	{"phone": "+70741384642"}
0005432106310	F1DE43	1334 566166	OLGA OVCHINNIKOVA	{"phone": "+70108798315"}
0005432106311	E561C5	8807 565009	NATALYA VOROBEVA	{"email": "natalya-vorobeva041981@postgrespro.ru", "phone": "+70770876526"}
0005432106312	E5F4CA	8438 286968	VALENTINA BORISOVA	{"phone": "+70232604564"}
0005432106313	E5F4CA	6543 539078	GENNADIY VASILEV	{"phone": "+70152918223"}
0005432106314	0E6B45	2646 571514	EVGENIY MAKAROV	{"email": "makarov.evgeniy021978@postgrespro.ru", "phone": "+70309835991"}
0005432106315	0E6B45	9133 850857	TATYANA VASILEVA	{"phone": "+70889667246"}
0005432106316	5766F4	9672 178877	ANASTASIYA DENISOVA	{"email": "denisova.anastasiya_08041975@postgrespro.ru", "phone": "+70541635858"}
0005432106317	50ABD3	5566 734793	EVGENIYA ALEKSEEVA	{"email": "evgeniya-alekseeva.1967@postgrespro.ru", "phone": "+70230746651"}
0005432106318	5FB3C8	6872 998390	SVETLANA NAZAROVA	{"email": "nazarovasvetlana03101962@postgrespro.ru", "phone": "+70032271056"}
0005432106319	5FB3C8	8800 589046	TATYANA SEMENOVA	{"email": "semenova.tatyana-101970@postgrespro.ru", "phone": "+70032259795"}
0005432106320	AD29D0	5741 497441	ALEKSANDR ROMANOV	{"phone": "+70096581078"}
0005432106321	1B7A8E	3321 521585	MARINA SAVELEVA	{"email": "m-saveleva-061981@postgrespro.ru", "phone": "+70717514246"}
0005432106322	465D3F	7097 359585	VALENTINA KOLESNIKOVA	{"phone": "+70491757305"}
0005432106323	465D3F	3402 941678	SERGEY KUZNECOV	{"email": "kuznecov.sergey.031977@postgrespro.ru", "phone": "+70842625372"}
0005432106324	51388C	1998 239187	VIKTOR ORLOV	{"email": "viktor.orlov18051980@postgrespro.ru", "phone": "+70928801413"}
0005432106325	AE3F8B	4825 833817	ALEKSEY AFANASEV	{"email": "afanasev_aleksey-1972@postgrespro.ru", "phone": "+70495796158"}
0005432106326	137FF3	9126 410550	TATYANA KALININA	{"email": "tatyanakalinina22051965@postgrespro.ru", "phone": "+70218644565"}
0005432106327	FDD9FA	5519 913034	NINA IVANOVA	{"email": "ivanovan_021962@postgrespro.ru", "phone": "+70439706543"}
0005432106328	D13D32	3981 375216	ANASTASIYA VASILEVA	{"phone": "+70595186475"}
0005432106329	08AFE0	8664 736552	TATYANA KRASNOVA	{"email": "tkrasnova071970@postgrespro.ru", "phone": "+70769126848"}
0005432106330	40E1C7	0557 896426	ANATOLIY ORLOV	{"email": "anatoliyorlov.18071970@postgrespro.ru", "phone": "+70709515994"}
0005432106331	7D3190	8875 399105	ANNA IVANOVA	{"phone": "+70532966391"}
0005432106332	3924A8	1022 168679	ALEKSANDR KUZNECOV	{"phone": "+70436801152"}
0005432106333	3924A8	5265 547210	ALEKSANDRA MEDVEDEVA	{"phone": "+70511398692"}
0005432106334	125169	9613 651703	ZINAIDA VOROBEVA	{"phone": "+70763470081"}
0005432106335	B08E77	4457 834877	LYUDMILA KAZAKOVA	{"phone": "+70584458350"}
0005432106336	B08E77	0768 863243	KLAVDIYA NAZAROVA	{"email": "nazarovaklavdiya-1982@postgrespro.ru", "phone": "+70626563268"}
0005432106337	EBB9C6	7538 829100	ANASTASIYA GORBUNOVA	{"phone": "+70438173488"}
0005432106338	92D339	2662 537996	DMITRIY GAVRILOV	{"phone": "+70054576710"}
0005432106339	92D339	6604 025006	OLGA ERMAKOVA	{"phone": "+70954717592"}
0005432106340	92D339	7132 426379	GALINA PETROVA	{"email": "petrovag_1976@postgrespro.ru", "phone": "+70670470389"}
0005432106341	4B653A	4750 715260	DENIS NIKITIN	{"phone": "+70684945492"}
0005432106342	07DBCF	4467 852631	NADEZHDA ZAKHAROVA	{"phone": "+70956777321"}
0005432106343	07DBCF	5999 575576	VALERIY BORISOV	{"phone": "+70366605728"}
0005432106344	C5D8B1	9843 084260	MARGARITA MIRONOVA	{"phone": "+70607951110"}
0005432106345	C5D8B1	1359 170000	ALEKSANDR BELOV	{"email": "belov.aleksandr1983@postgrespro.ru", "phone": "+70728699358"}
0005432106346	876FF5	4473 901791	EVGENIY KISELEV	{"email": "e-kiselev_111971@postgrespro.ru", "phone": "+70891396359"}
0005432106347	A631F7	3320 863461	INNA GRISHINA	{"email": "grishinai-15061976@postgrespro.ru", "phone": "+70142205855"}
0005432106348	B40597	6267 643745	RAISA KALININA	{"phone": "+70091171199"}
0005432106349	B40597	5767 750178	OLEG VOROBEV	{"email": "o.vorobev1961@postgrespro.ru", "phone": "+70885582988"}
0005432106350	12B11C	4656 520191	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov_1965@postgrespro.ru", "phone": "+70479073358"}
0005432106351	12B11C	2731 158987	NADEZHDA KUZMINA	{"email": "kuzmina-n25051966@postgrespro.ru", "phone": "+70583275016"}
0005432106352	12B11C	1673 070975	NIKOLAY KONOVALOV	{"email": "nikolay_konovalov_1977@postgrespro.ru", "phone": "+70601307530"}
0005432106353	1406E5	9536 057410	OLGA NOVIKOVA	{"email": "novikova-olga_1972@postgrespro.ru", "phone": "+70784366497"}
0005432106354	1406E5	7895 407536	IGOR BORISOV	{"email": "igor.borisov-1984@postgrespro.ru", "phone": "+70249268672"}
0005432106355	F456BB	1693 106330	TATYANA POTAPOVA	{"phone": "+70519333069"}
0005432106356	F456BB	3547 343395	TATYANA POTAPOVA	{"phone": "+70416342666"}
0005432106357	5A6F53	1655 786555	MIKHAIL POPOV	{"email": "popov-m15071975@postgrespro.ru", "phone": "+70566082840"}
0005432106358	330E04	6739 006239	OLGA DENISOVA	{"email": "denisovaolga011976@postgrespro.ru", "phone": "+70918151409"}
0005432106359	B07DFC	9537 180289	SVETLANA SAVELEVA	{"email": "saveleva_svetlana.1973@postgrespro.ru", "phone": "+70012800336"}
0005432106360	147956	6936 177058	ANDREY KUZMIN	{"email": "andreykuzmin.081974@postgrespro.ru", "phone": "+70382669342"}
0005432106361	00044D	3186 858511	NADEZHDA KULIKOVA	{"phone": "+70185102851"}
0005432106362	9FC564	7836 199449	ALEKSANDR SAVELEV	{"email": "savelevaleksandr-1978@postgrespro.ru", "phone": "+70514789456"}
0005432106363	9FC564	5792 930069	ALEKSEY KONOVALOV	{"phone": "+70072126326"}
0005432106364	9FC564	0417 097582	IRINA ALEKSANDROVA	{"email": "aleksandrovai.02101984@postgrespro.ru", "phone": "+70891414845"}
0005432106365	D73493	6083 662343	VLADIMIR TIMOFEEV	{"email": "vladimirtimofeev29051980@postgrespro.ru", "phone": "+70739623958"}
0005432106366	CC79DA	2235 320137	TATYANA NESTEROVA	{"email": "tnesterova_05071972@postgrespro.ru", "phone": "+70129849403"}
0005432106367	2904E3	7066 078196	EVGENIY MOISEEV	{"phone": "+70461398217"}
0005432106368	2904E3	9677 870378	IVAN IVANOV	{"phone": "+70694535602"}
0005432106369	9CBE8A	7174 452223	ALEKSANDR NAUMOV	{"email": "a-naumov26011956@postgrespro.ru", "phone": "+70718149373"}
0005432106370	D35B1A	5949 657873	EVGENIY SIDOROV	{"phone": "+70129654547"}
0005432106371	C96433	3183 314011	EVGENIY AFANASEV	{"phone": "+70414888360"}
0005432106372	083D5B	4392 485969	ANZHELIKA DAVYDOVA	{"phone": "+70705181046"}
0005432106373	C7A59E	8030 045394	EVGENIY VASILEV	{"email": "evgeniy.vasilev14011968@postgrespro.ru", "phone": "+70456801503"}
0005432106374	C7A59E	8005 306870	VITALIY SEMENOV	{"phone": "+70065646137"}
0005432106375	FC3BDC	8090 554548	VALENTINA ANTONOVA	{"phone": "+70626496881"}
0005432106376	FC3BDC	6642 911111	MIKHAIL MOISEEV	{"email": "moiseev.mikhail1975@postgrespro.ru", "phone": "+70216422693"}
0005432106377	FC3BDC	8397 368755	ALEKSEY ZAKHAROV	{"email": "zakharov_aleksey_041980@postgrespro.ru", "phone": "+70239860844"}
0005432106378	262AB5	8879 265174	MIKHAIL GAVRILOV	{"phone": "+70606610821"}
0005432106379	5A6A16	0504 089496	SVETLANA BELOVA	{"phone": "+70465983362"}
0005432106380	7D019E	6881 355980	SVETLANA BORISOVA	{"email": "s-borisova.1967@postgrespro.ru", "phone": "+70990555299"}
0005432106381	53E2DD	7296 992165	ALINA SERGEEVA	{"phone": "+70597004447"}
0005432106382	B6C393	8724 581337	IGOR ALEKSEEV	{"email": "igoralekseev.01091977@postgrespro.ru", "phone": "+70291877659"}
0005432106383	D80348	6607 229360	ANTON GUSEV	{"email": "antongusev_1974@postgrespro.ru", "phone": "+70204108782"}
0005432106384	F1F741	8026 684810	GALINA ALEKSEEVA	{"phone": "+70819371811"}
0005432106385	D3E865	0034 878905	IRINA TARASOVA	{"email": "i-tarasova.1966@postgrespro.ru", "phone": "+70028275595"}
0005432106386	00053F	4794 209061	TATYANA ZAKHAROVA	{"phone": "+70592214423"}
0005432106387	DB051E	3814 485079	ALEKSANDR VOLKOV	{"phone": "+70970308455"}
0005432106388	E9ADAE	5517 957969	MARK NIKITIN	{"phone": "+70703441056"}
0005432106389	5F081F	0528 691626	MARIYA ZAKHAROVA	{"phone": "+70650636236"}
0005432106390	B2F1D1	8683 505949	NATALYA VOROBEVA	{"phone": "+70441632921"}
0005432106391	F40C9C	8152 728608	VADIM MELNIKOV	{"email": "v.melnikov1978@postgrespro.ru", "phone": "+70178314643"}
0005432106392	4C6C83	4945 017937	TATYANA FADEEVA	{"email": "tfadeeva-19091973@postgrespro.ru", "phone": "+70600000557"}
0005432106393	5B3FC7	0588 701000	ELENA KARPOVA	{"email": "karpova_e-1974@postgrespro.ru", "phone": "+70880675296"}
0005432106394	43105E	7056 705700	NINA BORISOVA	{"email": "borisova-nina_071966@postgrespro.ru", "phone": "+70210536581"}
0005432106395	2236F7	7083 719049	ELENA MIKHAYLOVA	{"email": "e-mikhaylova.101994@postgrespro.ru", "phone": "+70668065741"}
0005432106396	AA4DAA	6089 635799	LYUBOV SIDOROVA	{"phone": "+70935795152"}
0005432106397	CE936C	3061 631287	GENNADIY NOVIKOV	{"phone": "+70197225439"}
0005432106398	396A2B	5778 464543	IRINA KOMAROVA	{"email": "komarova.i1970@postgrespro.ru", "phone": "+70951599088"}
0005432106399	396A2B	0062 823002	ALEKSANDR PAVLOV	{"email": "pavlova-28051979@postgrespro.ru", "phone": "+70105023485"}
0005432106400	4EF060	5498 044183	ANDREY SIDOROV	{"phone": "+70335057302"}
0005432106401	216D17	7112 226671	TATYANA VOLKOVA	{"phone": "+70348173500"}
0005432106402	216D17	6164 830027	ANNA NAUMOVA	{"phone": "+70071627370"}
0005432106403	6B1CD3	3173 098558	ANASTASIYA NIKOLAEVA	{"email": "anastasiyanikolaeva_29011974@postgrespro.ru", "phone": "+70547446294"}
0005432106404	20ACD3	8979 746970	ANATOLIY SERGEEV	{"email": "a_sergeev_031971@postgrespro.ru", "phone": "+70489097781"}
0005432106405	F2DAC9	3482 021440	ALEKSEY NIKITIN	{"email": "nikitinaleksey.1969@postgrespro.ru", "phone": "+70702694174"}
0005432106406	C8B452	0243 697873	ELENA POTAPOVA	{"email": "potapova-elena_19121964@postgrespro.ru", "phone": "+70793713834"}
0005432106407	C8B452	7367 559375	YURIY MELNIKOV	{"email": "melnikov_yuriy1970@postgrespro.ru", "phone": "+70211879456"}
0005432106408	C8B452	8134 603425	VIKTORIYA MAKSIMOVA	{"phone": "+70570072408"}
0005432106409	4EAAC7	8664 469048	OLGA POLYAKOVA	{"email": "olga.polyakova-1974@postgrespro.ru", "phone": "+70864631176"}
0005432106410	4EAAC7	1050 141145	MIKHAIL NOVIKOV	{"email": "mikhail-novikov-021986@postgrespro.ru", "phone": "+70674154355"}
0005432106411	51EEB0	6271 372795	NATALYA KOLESNIKOVA	{"email": "nkolesnikova.12041965@postgrespro.ru", "phone": "+70506475439"}
0005432106412	51EEB0	9061 610970	ALEKSANDR SOKOLOV	{"phone": "+70506490656"}
0005432106413	93BB18	8110 220480	ANTON SIDOROV	{"email": "sidorov.anton1972@postgrespro.ru", "phone": "+70834939269"}
0005432106414	0BC378	8497 429674	ANDREY PETROV	{"phone": "+70935357365"}
0005432106415	CB2510	0236 329376	PAVEL MAKAROV	{"phone": "+70817994907"}
0005432106416	0719C5	7177 680424	VLADIMIR BONDARENKO	{"email": "bondarenko.v-051973@postgrespro.ru", "phone": "+70587251527"}
0005432106417	C60304	4841 299935	OLEG MEDVEDEV	{"phone": "+70648363330"}
0005432106418	353E98	5804 412467	VALERIY DENISOV	{"email": "valeriy_denisov.121978@postgrespro.ru", "phone": "+70558900900"}
0005432106419	928C0B	8060 835977	NATALYA FADEEVA	{"email": "fadeevanatalya_081972@postgrespro.ru", "phone": "+70232801133"}
0005432106420	98A019	0500 914336	VIKTOR KOROLEV	{"email": "viktor.korolev.081970@postgrespro.ru", "phone": "+70330626573"}
0005432106421	98A019	4051 225432	VERA FILATOVA	{"phone": "+70415327671"}
0005432106422	981548	4056 529172	YURIY FEDOROV	{"email": "yfedorov.081983@postgrespro.ru", "phone": "+70630560199"}
0005432106423	5BAB5D	8363 743458	LYUDMILA ANTONOVA	{"phone": "+70417085805"}
0005432106424	3354C1	8661 186282	ELENA GUSEVA	{"email": "elena.guseva16081970@postgrespro.ru", "phone": "+70567646189"}
0005432106425	3354C1	7697 630032	ANDREY GERASIMOV	{"phone": "+70129572469"}
0005432106426	67B46A	7945 663362	EKATERINA GORBUNOVA	{"phone": "+70270331912"}
0005432106427	ED5567	4545 167084	OLESYA IVANOVA	{"email": "ivanova.o-011980@postgrespro.ru", "phone": "+70000393681"}
0005432106428	6F475C	5005 590749	ALEKSEY NAUMOV	{"phone": "+70168395738"}
0005432106429	BB62BD	6192 427107	YURIY SERGEEV	{"phone": "+70001898401"}
0005432106430	BB62BD	5439 572105	PELAGEYA SOKOLOVA	{"email": "pelageya_sokolova27031961@postgrespro.ru", "phone": "+70176058011"}
0005432106431	43B521	4457 390027	ANASTASIYA MASLOVA	{"phone": "+70619470920"}
0005432106432	43B521	2632 256016	DMITRIY ZAKHAROV	{"phone": "+70912255758"}
0005432106433	9D122F	9295 148010	IVAN IVANOV	{"phone": "+70240213427"}
0005432106434	86F3CB	4213 304038	DANILA MELNIKOV	{"phone": "+70856964337"}
0005432106435	E54252	6368 450230	IGOR TARASOV	{"phone": "+70175758072"}
0005432106436	E54252	7218 203365	MATVEY ROMANOV	{"phone": "+70879926199"}
0005432106437	7AB534	1635 447241	DENIS MAKAROV	{"email": "makarov.denis-30031990@postgrespro.ru", "phone": "+70366784298"}
0005432106438	72A556	3921 118241	ILNAR SCHERBAKOV	{"email": "ilnar-scherbakov_111975@postgrespro.ru", "phone": "+70260722969"}
0005432106439	B8F3E9	7037 113371	ANATOLIY AFANASEV	{"email": "anatoliyafanasev-1965@postgrespro.ru", "phone": "+70189324508"}
0005432106440	4B71F3	6386 864222	LYUDMILA TARASOVA	{"phone": "+70175566580"}
0005432106441	3BD27B	4685 230300	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey.03011983@postgrespro.ru", "phone": "+70004515993"}
0005432106442	FA7284	2972 855753	PAVEL KUZNECOV	{"phone": "+70647298042"}
0005432106443	DB64FD	2311 554650	MIKHAIL PETROV	{"email": "mpetrov_30061972@postgrespro.ru", "phone": "+70607931443"}
0005432106444	45F241	1062 628634	OLEG SOKOLOV	{"phone": "+70804445815"}
0005432106445	E32C63	5801 058230	VALENTINA KUDRYASHOVA	{"phone": "+70166019152"}
0005432106446	FE1FA2	3453 117520	SERGEY ROMANOV	{"email": "s_romanov.15051952@postgrespro.ru", "phone": "+70328484839"}
0005432106447	E74B02	4560 679523	TATYANA KOVALEVA	{"email": "kovalevatatyana14111963@postgrespro.ru", "phone": "+70544172187"}
0005432106448	E74B02	2765 117453	VALENTINA GORBUNOVA	{"email": "gorbunova_v_1966@postgrespro.ru", "phone": "+70770596029"}
0005432106449	61B3E6	1080 310991	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin1966@postgrespro.ru", "phone": "+70854953967"}
0005432106450	26D574	8210 317691	DANIIL SEMENOV	{"phone": "+70048771320"}
0005432106451	26D574	6363 965702	ARTEM KUZMIN	{"phone": "+70279671716"}
0005432106452	26D574	4000 103801	LIDIYA KOROLEVA	{"email": "lidiyakoroleva.101961@postgrespro.ru", "phone": "+70033230186"}
0005432106453	A1EE97	0267 655762	ANTONINA EFREMOVA	{"email": "antoninaefremova1969@postgrespro.ru", "phone": "+70118363433"}
0005432106454	A1EE97	1154 721353	MIROSLAV EGOROV	{"phone": "+70320351540"}
0005432106455	B974D4	3412 689748	ALEKSEY FILIPPOV	{"email": "aleksey-filippov.31101965@postgrespro.ru", "phone": "+70619194849"}
0005432106456	B974D4	9310 256287	YANA ILINA	{"phone": "+70289652637"}
0005432106457	B974D4	6107 811098	NADEZHDA IVANOVA	{"email": "ivanovanadezhda031967@postgrespro.ru", "phone": "+70897790651"}
0005432106458	BACBC6	2391 030566	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov1958@postgrespro.ru", "phone": "+70063781714"}
0005432106459	84C400	5966 747696	EVDOKIYA NIKOLAEVA	{"phone": "+70139564260"}
0005432106460	D5B570	7151 600058	ROMAN MEDVEDEV	{"email": "r_medvedev_091973@postgrespro.ru", "phone": "+70630256203"}
0005432106461	E9E442	8475 832750	NIKOLAY CHERNOV	{"email": "chernov_nikolay-011979@postgrespro.ru", "phone": "+70695500979"}
0005432106462	E9E442	1884 632846	RUSTAM KOROLEV	{"phone": "+70916842974"}
0005432106463	E9E442	6107 338922	YURIY GERASIMOV	{"email": "gerasimov_y06121969@postgrespro.ru", "phone": "+70641293048"}
0005432106464	36FB2E	9357 002050	EVGENIY PETROV	{"phone": "+70833169388"}
0005432106465	36FB2E	8209 376534	ALEKSANDR FILIPPOV	{"email": "a.filippov12101971@postgrespro.ru", "phone": "+70168540825"}
0005432106466	8AEB4D	6330 467022	VALENTINA BELYAEVA	{"phone": "+70605683300"}
0005432106467	937ACE	4987 538696	NINA MATVEEVA	{"email": "nina_matveeva.1975@postgrespro.ru", "phone": "+70670717773"}
0005432106468	02848E	7731 570237	POLINA NIKIFOROVA	{"phone": "+70481520169"}
0005432106469	BB8C3A	1710 839914	NINA KUZMINA	{"phone": "+70538977557"}
0005432106470	45F7C7	8320 898406	ANTONINA NESTEROVA	{"email": "a.nesterova_021958@postgrespro.ru", "phone": "+70810492183"}
0005432106471	295283	0597 249747	LYUBOV PAVLOVA	{"email": "l_pavlova_1968@postgrespro.ru", "phone": "+70027010948"}
0005432106472	2CF9AB	4611 967051	VLADIMIR ANTONOV	{"phone": "+70135514436"}
0005432106473	D23A42	4976 798878	YULIYA LEBEDEVA	{"email": "yuliya.lebedeva.1962@postgrespro.ru", "phone": "+70539746533"}
0005432106474	D23A42	3360 435678	DENIS SHEVCHENKO	{"email": "denis_shevchenko_1976@postgrespro.ru", "phone": "+70478865823"}
0005432106475	D23A42	4123 653185	GLEB DENISOV	{"phone": "+70155767202"}
0005432106476	5884CF	6141 126022	NATALYA GORBUNOVA	{"email": "gorbunova.natalya_1966@postgrespro.ru", "phone": "+70279796874"}
0005432106477	CAA02C	1001 089893	ALEKSANDR MOISEEV	{"phone": "+70145463523"}
0005432106478	CAA02C	9059 741151	TATYANA PETROVA	{"phone": "+70546969682"}
0005432106479	CAA02C	7405 819891	TATYANA LUKYANOVA	{"email": "lukyanova-tatyana_041976@postgrespro.ru", "phone": "+70696985598"}
0005432106480	681639	8669 792015	NATALYA NOVIKOVA	{"phone": "+70623218492"}
0005432106481	F3B253	0883 906866	NIKOLAY ALEKSANDROV	{"email": "nikolay_aleksandrov121979@postgrespro.ru", "phone": "+70449986830"}
0005432106482	F3B253	5313 284633	EKATERINA SMIRNOVA	{"email": "e_smirnova-011970@postgrespro.ru", "phone": "+70665137923"}
0005432106483	3F1507	4751 596322	NIKOLAY SCHERBAKOV	{"email": "n-scherbakov.011957@postgrespro.ru", "phone": "+70166244304"}
0005432106484	ADEF61	5273 917270	MIKHAIL MIKHAYLOV	{"phone": "+70796010416"}
0005432106485	ADEF61	0037 221475	ALINA SIDOROVA	{"email": "sidorovaalina_06061969@postgrespro.ru", "phone": "+70695631813"}
0005432106486	9A8E00	3303 993314	DANIL PETROV	{"email": "d_petrov-1973@postgrespro.ru", "phone": "+70399897327"}
0005432106487	9A8E00	3248 859391	ILMIRA ZHUKOVA	{"email": "zhukovailmira_011977@postgrespro.ru", "phone": "+70472303293"}
0005432106488	5649FF	1476 702860	ANNA LEBEDEVA	{"email": "lebedeva-anna101963@postgrespro.ru", "phone": "+70183091385"}
0005432106489	081EDF	0680 285546	ALEKSEY KOZLOV	{"email": "aleksey.kozlov-1966@postgrespro.ru", "phone": "+70435787157"}
0005432106490	081EDF	1666 073843	ALENA ILINA	{"email": "ilina-alena1974@postgrespro.ru", "phone": "+70921676667"}
0005432106491	FB20F1	6988 734096	MARIYA KAZAKOVA	{"phone": "+70666574010"}
0005432106492	BAAFF9	9077 187517	DAMIR MELNIKOV	{"phone": "+70864909337"}
0005432106493	BAAFF9	6595 546891	VIKTOR FOMIN	{"phone": "+70446725471"}
0005432106494	82A5FD	5065 334269	YURIY SEMENOV	{"phone": "+70601673139"}
0005432106495	1EE9F6	9291 097541	ANGELINA POLYAKOVA	{"email": "apolyakova.1962@postgrespro.ru", "phone": "+70571835057"}
0005432106496	98E36F	8245 536319	KONSTANTIN AFANASEV	{"email": "konstantin-afanasev_1969@postgrespro.ru", "phone": "+70369148208"}
0005432106497	9D3345	3301 991310	VLADIMIR SHEVCHENKO	{"phone": "+70063719677"}
0005432106498	2AB548	5532 985454	SVETLANA MEDVEDEVA	{"phone": "+70087583232"}
0005432106499	822368	3706 502132	DMITRIY PETROV	{"phone": "+70237574385"}
0005432106500	822368	1826 194803	ARTEM SOKOLOV	{"email": "artem_sokolov1971@postgrespro.ru", "phone": "+70837173817"}
0005432106501	DA41D2	6432 115987	ANASTASIYA ISAEVA	{"phone": "+70611571531"}
0005432106502	D815BB	3189 752750	ALEKSANDRA MALYSHEVA	{"email": "aleksandra.malysheva-061972@postgrespro.ru", "phone": "+70261013092"}
0005432106503	513700	3603 167016	OLGA KUZMINA	{"phone": "+70059880117"}
0005432106504	513700	1354 788654	NINA BARANOVA	{"email": "nbaranova-21041967@postgrespro.ru", "phone": "+70752109527"}
0005432106505	283C76	7597 041328	EVGENIY KUZNECOV	{"email": "kuznecov.e-1968@postgrespro.ru", "phone": "+70329804075"}
0005432106506	97FBFE	5349 841332	LYUDMILA SMIRNOVA	{"email": "lyudmila-smirnova-01051974@postgrespro.ru", "phone": "+70696780146"}
0005432106507	307AEE	3796 863744	ARTEM FILIPPOV	{"phone": "+70839965889"}
0005432106508	BF11A5	6168 086907	RAFIK FEDOROV	{"email": "r_fedorov_091976@postgrespro.ru", "phone": "+70603646773"}
0005432106509	50A286	3632 609388	MARINA SAVELEVA	{"email": "saveleva-marina_03041976@postgrespro.ru", "phone": "+70756463439"}
0005432106510	A46751	2502 607359	RAISA MAKAROVA	{"phone": "+70998041640"}
0005432106511	87E43C	5024 255354	INNA MOROZOVA	{"phone": "+70604327810"}
0005432106512	87E43C	6425 441136	LYUDMILA TITOVA	{"phone": "+70578589436"}
0005432106513	46F9FA	7344 794945	IRINA CHERNOVA	{"email": "i_chernova-121961@postgrespro.ru", "phone": "+70825390138"}
0005432106514	7CB530	7508 473414	VALENTINA ALEKSEEVA	{"phone": "+70978671981"}
0005432106515	4A7A7E	8199 723311	ANASTASIYA MIRONOVA	{"email": "mironova-anastasiya_041977@postgrespro.ru", "phone": "+70502555991"}
0005432106516	4A7A7E	7134 933255	ZINAIDA KOROLEVA	{"email": "koroleva-zinaida-1965@postgrespro.ru", "phone": "+70754155109"}
0005432106517	C3C048	5133 747853	VALENTINA ALEKSANDROVA	{"phone": "+70922446727"}
0005432106518	C2DC0A	8847 864674	SERGEY GUSEV	{"email": "s_gusev-1976@postgrespro.ru", "phone": "+70855139481"}
0005432106519	C2DC0A	2030 277665	VERA KOROLEVA	{"phone": "+70847598013"}
0005432106520	2D6179	0981 226646	ALEKSANDR KUZNECOV	{"phone": "+70713910795"}
0005432106521	A54D94	5677 532965	DENIS KUZNECOV	{"email": "d.kuznecov.23121970@postgrespro.ru", "phone": "+70445002849"}
0005432106522	A54D94	9057 097833	VYACHESLAV MOROZOV	{"email": "v.morozov-1974@postgrespro.ru", "phone": "+70357564738"}
0005432106523	CE0D12	0909 638033	KRISTINA SOROKINA	{"email": "kristina-sorokina.03041965@postgrespro.ru", "phone": "+70075777198"}
0005432106524	DD67CB	4261 365020	SERGEY SMIRNOV	{"phone": "+70452149901"}
0005432106525	F4C7FC	5132 277424	TAMARA NESTEROVA	{"phone": "+70156508327"}
0005432106526	6A9F5D	7428 382537	RAISA IVANOVA	{"email": "raisa-ivanova-1961@postgrespro.ru", "phone": "+70477408923"}
0005432106527	33F563	9276 068551	VLADIMIR STEPANOV	{"email": "stepanov_vladimir_1967@postgrespro.ru", "phone": "+70888954034"}
0005432106528	33F563	5899 643808	NIKOLAY GERASIMOV	{"phone": "+70624059491"}
0005432106529	5B5579	5986 284552	ANTONINA ZOTOVA	{"phone": "+70626829275"}
0005432106530	83B5C5	8218 734298	ELIZAVETA SOLOVEVA	{"phone": "+70407539323"}
0005432106531	83B5C5	4808 648765	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy08051972@postgrespro.ru", "phone": "+70050095571"}
0005432106532	83B5C5	3679 338426	ANATOLIY SAVELEV	{"email": "savelev-anatoliy_081979@postgrespro.ru", "phone": "+70986462371"}
0005432106533	B2A3C5	3351 444704	EVGENIY ILIN	{"email": "e-ilin_05041970@postgrespro.ru", "phone": "+70966058916"}
0005432106534	31E681	5800 348372	SERGEY VOROBEV	{"email": "vorobev_s.1978@postgrespro.ru", "phone": "+70521771361"}
0005432106535	D42F90	0977 027181	EKATERINA SERGEEVA	{"email": "sergeeva_ekaterina031981@postgrespro.ru", "phone": "+70778133301"}
0005432106536	049EB3	8088 709330	SERGEY FROLOV	{"phone": "+70123730888"}
0005432106537	F1E5B7	5217 431626	SERGEY ZAKHAROV	{"phone": "+70269618195"}
0005432106538	351E52	1378 539082	ALEKSANDRA ZHURAVLEVA	{"email": "aleksandrazhuravleva_121971@postgrespro.ru", "phone": "+70057813377"}
0005432106539	DB05AC	6574 361349	NADEZHDA ZAKHAROVA	{"email": "nadezhda.zakharova09081961@postgrespro.ru", "phone": "+70520913032"}
0005432106540	DB05AC	9068 102968	ANTONINA KISELEVA	{"email": "a-kiseleva_17121964@postgrespro.ru", "phone": "+70113612263"}
0005432106541	7B07CB	0247 121596	EDUARD KUZNECOV	{"email": "eduardkuznecov06071974@postgrespro.ru", "phone": "+70466017506"}
0005432106542	BE8C62	7456 387273	LARISA VOROBEVA	{"email": "l_vorobeva_111970@postgrespro.ru", "phone": "+70483466696"}
0005432106543	5556BA	9174 008026	LYUBOV GAVRILOVA	{"email": "gavrilova_lyubov_111964@postgrespro.ru", "phone": "+70988081715"}
0005432106544	BE0AB8	4510 661986	DANIIL SCHERBAKOV	{"phone": "+70218492652"}
0005432106545	5F15F9	1001 951209	NATALYA SMIRNOVA	{"phone": "+70638621573"}
0005432106546	0071C1	5197 562674	YURIY EGOROV	{"email": "yuriy.egorov1973@postgrespro.ru", "phone": "+70971069787"}
0005432106547	D6CE6F	2270 002060	ELENA SOROKINA	{"email": "sorokina_elena-071975@postgrespro.ru", "phone": "+70136313258"}
0005432106548	D6CE6F	3792 263780	ALEKSANDR ABRAMOV	{"email": "a-abramov.1974@postgrespro.ru", "phone": "+70749659352"}
0005432106549	7DEF16	8904 377235	ANDREY KONOVALOV	{"email": "konovalov_andrey-091981@postgrespro.ru", "phone": "+70156999365"}
0005432106550	DB5D4F	6921 050328	RAISA FROLOVA	{"phone": "+70679379506"}
0005432106551	071EE9	3231 006976	YULIYA KUZNECOVA	{"phone": "+70446082306"}
0005432106552	6A4C28	0898 119679	YURIY ALEKSEEV	{"phone": "+70570944988"}
0005432106553	6A4C28	5019 514070	SOFYA MELNIKOVA	{"email": "s.melnikova.1977@postgrespro.ru", "phone": "+70827622412"}
0005432106554	6A4C28	4050 755239	YURIY GAVRILOV	{"phone": "+70880593281"}
0005432106555	FCAE51	8152 078412	ZAKHAR NAZAROV	{"email": "nazarov-z-081979@postgrespro.ru", "phone": "+70987216638"}
0005432106556	3C5107	6181 978554	MARIYA KONOVALOVA	{"email": "mariya_konovalova1969@postgrespro.ru", "phone": "+70257564934"}
0005432106557	3C5107	9613 206599	MIKHAIL VOROBEV	{"email": "vorobev-mikhail031972@postgrespro.ru", "phone": "+70394339534"}
0005432106558	80D1DD	0958 047127	TATYANA FOMINA	{"email": "t.fomina_1964@postgrespro.ru", "phone": "+70422361958"}
0005432106559	A7AFCD	3326 595581	IRINA PETROVA	{"phone": "+70630388331"}
0005432106560	9056C3	4558 349856	DENIS VOLKOV	{"email": "volkov.d_12051978@postgrespro.ru", "phone": "+70290849048"}
0005432106561	A4BDA8	9412 189121	ALEKSANDR MAKSIMOV	{"phone": "+70293179427"}
0005432106562	3BA0D7	3548 709351	ELENA MASLOVA	{"email": "elena.maslova04031968@postgrespro.ru", "phone": "+70626365239"}
0005432106563	FF4825	9719 466856	ALEKSANDR MOISEEV	{"phone": "+70178426530"}
0005432106564	E15103	6136 210694	OKSANA VOROBEVA	{"email": "vorobeva_oksana-111979@postgrespro.ru", "phone": "+70847898875"}
0005432106565	EBD6D1	5230 963812	MARINA LEBEDEVA	{"phone": "+70381029400"}
0005432106566	EBD6D1	0118 400470	EVGENIY NIKITIN	{"phone": "+70078334971"}
0005432106567	7CA841	2902 916845	FARID BELOV	{"phone": "+70576840294"}
0005432106568	7CA841	7802 175858	ALENA NIKITINA	{"email": "nikitina-a.091971@postgrespro.ru", "phone": "+70655332896"}
0005432106569	0BDBDA	5509 065700	DARYA MATVEEVA	{"phone": "+70206495353"}
0005432106570	D4EDBE	2810 585941	STEPAN VLASOV	{"phone": "+70904957743"}
0005432106571	40F98A	0766 363091	LIDIYA RODIONOVA	{"phone": "+70079454729"}
0005432106572	44D38F	8463 392232	GRIGORIY VASILEV	{"email": "vasilevgrigoriy-111968@postgrespro.ru", "phone": "+70757454576"}
0005432106573	CAB72D	1339 553038	IRINA MASLOVA	{"phone": "+70186263816"}
0005432106631	CF9433	3943 117993	VALENTINA MAKSIMOVA	{"phone": "+70272209089"}
0005432106574	CAB72D	4823 070053	ANASTASIYA FROLOVA	{"email": "a_frolova1967@postgrespro.ru", "phone": "+70322462791"}
0005432106575	395B64	1147 986595	VALENTINA KRASNOVA	{"email": "vkrasnova_1965@postgrespro.ru", "phone": "+70928683334"}
0005432106576	395B64	7376 350355	ELENA PAVLOVA	{"email": "elena_pavlova13021962@postgrespro.ru", "phone": "+70189822707"}
0005432106577	C84AD0	2751 296031	LARISA VLASOVA	{"email": "l_vlasova-101966@postgrespro.ru", "phone": "+70233399490"}
0005432106578	C84AD0	1482 540833	EVGENIY ISAEV	{"phone": "+70807299180"}
0005432106579	323367	6982 730995	STANISLAV FILIPPOV	{"phone": "+70368844276"}
0005432106580	CC3FF5	2906 731546	ANNA SERGEEVA	{"email": "sergeeva-a1984@postgrespro.ru", "phone": "+70171623690"}
0005432106581	CD130A	3402 455494	TATYANA RODIONOVA	{"phone": "+70116820573"}
0005432106582	D0A060	3145 060233	VALENTINA KOZLOVA	{"phone": "+70400081546"}
0005432106583	CA574A	6510 058490	MARAT POPOV	{"phone": "+70581933862"}
0005432106584	BEE55B	6462 717890	VLADIMIR SAVELEV	{"phone": "+70671197978"}
0005432106585	FB641B	2440 777328	ALEKSANDR VOROBEV	{"phone": "+70463431807"}
0005432106586	9012A8	5117 323350	OLEG KULIKOV	{"email": "o_kulikov.1974@postgrespro.ru", "phone": "+70679197087"}
0005432106587	28031E	4412 778281	ALEKSANDR KUZNECOV	{"phone": "+70096893825"}
0005432106588	28031E	2726 130928	ALEKSANDR MARTYNOV	{"email": "martynov.aleksandr_021983@postgrespro.ru", "phone": "+70373455276"}
0005432106589	3CB696	4544 372536	DMITRIY AFANASEV	{"email": "afanasev-d.041981@postgrespro.ru", "phone": "+70618752506"}
0005432106590	3CB696	7882 782299	VARVARA MAKSIMOVA	{"email": "maksimova-varvara-081988@postgrespro.ru", "phone": "+70504337775"}
0005432106591	57D2C6	1582 821086	NINA MEDVEDEVA	{"phone": "+70360943425"}
0005432106592	EB1CA2	5902 680538	VALERIY KARPOV	{"phone": "+70184609496"}
0005432106593	BFCCC1	3457 884581	SERGEY IVANOV	{"phone": "+70512911669"}
0005432106594	BFCCC1	9503 454785	TATYANA PAVLOVA	{"phone": "+70293313581"}
0005432106595	BFCCC1	2155 035571	LYUBOV SMIRNOVA	{"phone": "+70445453250"}
0005432106596	56A2D6	1808 734329	SVETLANA MAKAROVA	{"email": "makarova_s-011966@postgrespro.ru", "phone": "+70382022626"}
0005432106597	56A2D6	6858 381273	VASILIY KRASNOV	{"email": "vkrasnov111967@postgrespro.ru", "phone": "+70006894937"}
0005432106598	8EA495	2777 001348	VITALIY ALEKSANDROV	{"phone": "+70826214176"}
0005432106599	277416	9550 284690	SERGEY RODIONOV	{"phone": "+70431525457"}
0005432106600	7ECBDA	4971 750861	TATYANA STEPANOVA	{"email": "tatyanastepanova_121968@postgrespro.ru", "phone": "+70153896959"}
0005432106601	BA33FC	6566 689463	NATALYA POTAPOVA	{"email": "n_potapova15061982@postgrespro.ru", "phone": "+70771534692"}
0005432106602	18BFC2	2230 154208	IGOR MAKAROV	{"email": "makarov-i.1981@postgrespro.ru", "phone": "+70583613678"}
0005432106603	0D58DF	1506 965799	DARYA GUSEVA	{"phone": "+70842345542"}
0005432106604	03D7AB	4350 444031	SERGEY KARPOV	{"phone": "+70607666587"}
0005432106605	A29DCA	1395 548762	ANNA NESTEROVA	{"email": "nesterovaa121985@postgrespro.ru", "phone": "+70240349584"}
0005432106606	B1CA57	8525 434585	TATYANA DAVYDOVA	{"phone": "+70508014780"}
0005432106607	B1CA57	5175 934731	LYUBOV MIRONOVA	{"phone": "+70496547639"}
0005432106608	4753B6	3698 264558	OLGA FROLOVA	{"phone": "+70873579980"}
0005432106609	F55FE3	3336 432378	RAIL POPOV	{"email": "r-popov1979@postgrespro.ru", "phone": "+70798752698"}
0005432106610	F55FE3	9252 166629	TATYANA FADEEVA	{"email": "fadeevatatyana-1969@postgrespro.ru", "phone": "+70441951792"}
0005432106611	7BFEF8	7524 432553	YULIYA VASILEVA	{"email": "vasileva_y071986@postgrespro.ru", "phone": "+70091599118"}
0005432106612	857920	6870 062451	MILANA MIRONOVA	{"phone": "+70134757967"}
0005432106613	E1ABD4	5118 181496	DIANA SERGEEVA	{"phone": "+70984636008"}
0005432106614	0573D3	5220 019218	KONSTANTIN VOLKOV	{"email": "konstantinvolkov-01111968@postgrespro.ru", "phone": "+70586901124"}
0005432106615	0573D3	7938 115728	VERONIKA ILINA	{"phone": "+70938309140"}
0005432106616	D47023	5592 203663	TATYANA MEDVEDEVA	{"email": "medvedevat_1971@postgrespro.ru", "phone": "+70213521616"}
0005432106617	D47023	6233 706682	YURIY VOROBEV	{"email": "y-vorobev15011976@postgrespro.ru", "phone": "+70418656629"}
0005432106618	CD7234	4792 125555	ALINA ISAEVA	{"phone": "+70636948196"}
0005432106619	5A6EC6	0831 224071	VLADIMIR SMIRNOV	{"phone": "+70359880474"}
0005432106620	85421A	6315 864840	MIKHAIL KUZNECOV	{"phone": "+70541924890"}
0005432106621	1D6617	9022 846490	TATYANA VOLKOVA	{"email": "tatyana-volkova-10051976@postgrespro.ru", "phone": "+70874516949"}
0005432106622	1D6617	8462 640538	LYUDMILA NIKITINA	{"phone": "+70953411265"}
0005432106623	8D9AEB	1982 200626	IVAN SCHERBAKOV	{"email": "ivan.scherbakov_28041966@postgrespro.ru", "phone": "+70011177597"}
0005432106624	8D9AEB	0788 316168	ELENA NAZAROVA	{"phone": "+70632390774"}
0005432106625	D70673	3727 079593	ILYA KUZNECOV	{"phone": "+70021612872"}
0005432106626	D70673	1298 384538	MARIYA SCHERBAKOVA	{"email": "mariyascherbakova031968@postgrespro.ru", "phone": "+70451225563"}
0005432106627	BBD716	5193 084868	KARINA KOROLEVA	{"phone": "+70244703765"}
0005432106628	F61AE9	4683 381258	SERGEY SAVELEV	{"email": "s.savelev-1974@postgrespro.ru", "phone": "+70003343783"}
0005432106629	90615F	5129 005156	OLGA OSIPOVA	{"phone": "+70958380066"}
0005432106630	90615F	7042 638977	ALEFTINA PAVLOVA	{"email": "aleftinapavlova_30031969@postgrespro.ru", "phone": "+70448495984"}
0005432106632	CF9433	3888 853336	NIKOLAY MIRONOV	{"email": "nikolay_mironov.1969@postgrespro.ru", "phone": "+70999897754"}
0005432106633	CF9433	6961 954840	ARSEN DMITRIEV	{"phone": "+70546922363"}
0005432106634	6655CF	3592 999480	EVGENIY KAZAKOV	{"email": "evgeniykazakov.091975@postgrespro.ru", "phone": "+70399300197"}
0005432106635	6655CF	7686 549528	TAISIYA MAKSIMOVA	{"phone": "+70992720157"}
0005432106636	6376D7	2804 080112	SERGEY MOISEEV	{"email": "moiseev-s.031975@postgrespro.ru", "phone": "+70419999617"}
0005432106637	87418A	1821 716938	GALINA EGOROVA	{"email": "egorova-galina-07061981@postgrespro.ru", "phone": "+70316249785"}
0005432106638	87418A	4252 682872	OKSANA GORBUNOVA	{"phone": "+70406647385"}
0005432106639	057116	0736 856018	SVETLANA FILIPPOVA	{"phone": "+70021638739"}
0005432106640	792545	0572 176991	ANASTASIYA STEPANOVA	{"email": "anastasiyastepanova_16011982@postgrespro.ru", "phone": "+70913955781"}
0005432106641	792545	8412 243899	IGOR YAKOVLEV	{"phone": "+70935418494"}
0005432106642	B2A0C4	1637 073628	YULIYA FILATOVA	{"email": "filatova.y_08051971@postgrespro.ru", "phone": "+70870724869"}
0005432106643	7138D7	0163 250771	MIKHAIL NOVIKOV	{"phone": "+70630319513"}
0005432106644	3F423F	6994 534658	PAVEL YAKOVLEV	{"email": "pyakovlev-041971@postgrespro.ru", "phone": "+70135827754"}
0005432106645	3F423F	3916 750170	DMITRIY KUZNECOV	{"email": "kuznecov.d-1975@postgrespro.ru", "phone": "+70203289939"}
0005432106646	5A8C04	3391 029817	OLGA SEMENOVA	{"phone": "+70075268599"}
0005432106647	86FA99	9634 856699	OKSANA CHERNOVA	{"phone": "+70157126735"}
0005432106648	6F4BDC	5765 847319	PAVEL PAVLOV	{"phone": "+70637148167"}
0005432106649	EE9D64	5989 306808	TAMARA OVCHINNIKOVA	{"phone": "+70963479440"}
0005432106650	C3B895	0131 971799	VERA GERASIMOVA	{"email": "gerasimova.vera.071962@postgrespro.ru", "phone": "+70004481836"}
0005432106651	C3B895	7627 531986	VLADIMIR SIDOROV	{"email": "vladimirsidorov_1974@postgrespro.ru", "phone": "+70365355707"}
0005432106652	76919C	1245 179899	ALEKSANDR SMIRNOV	{"email": "smirnov_a01091975@postgrespro.ru", "phone": "+70169810251"}
0005432106653	CCBED8	2556 525365	OLGA KUZMINA	{"phone": "+70762327069"}
0005432106654	007264	7330 855076	ARTUR SEMENOV	{"email": "a-semenov1967@postgrespro.ru", "phone": "+70179371107"}
0005432106655	889F67	3414 892152	ANASTASIYA OSIPOVA	{"phone": "+70176418478"}
0005432106656	889F67	4381 084075	OLEG KISELEV	{"phone": "+70296032028"}
0005432106657	245BFB	0974 998771	ALEKSANDR BONDARENKO	{"email": "bondarenko.a-09081958@postgrespro.ru", "phone": "+70716454761"}
0005432106658	C64094	9216 195251	DMITRIY KOZLOV	{"email": "kozlov_d1972@postgrespro.ru", "phone": "+70261965322"}
0005432106659	9C9F2C	3490 047573	IVAN MOROZOV	{"email": "morozov-ivan.06121965@postgrespro.ru", "phone": "+70951386891"}
0005432106660	9C9F2C	5644 840969	REGINA KISELEVA	{"email": "regina_kiseleva_13101971@postgrespro.ru", "phone": "+70913046503"}
0005432106661	0668D9	6134 374813	YULIYA OSIPOVA	{"phone": "+70023368914"}
0005432106662	E4B447	2463 347721	ALEKSEY SOROKIN	{"phone": "+70208886202"}
0005432106663	E4B447	0844 717654	KSENIYA ZOTOVA	{"phone": "+70732786409"}
0005432106664	E4B447	9959 656338	ALEKSANDR BORISOV	{"phone": "+70049827399"}
0005432106665	63373B	0061 140936	LIDIYA POLYAKOVA	{"phone": "+70895212586"}
0005432106666	7C8B0F	6166 729782	ARTEM POPOV	{"email": "a_popov041970@postgrespro.ru", "phone": "+70213284374"}
0005432106667	C1D364	5485 764564	ANATOLIY BORISOV	{"email": "anatoliyborisov_091973@postgrespro.ru", "phone": "+70245218879"}
0005432106668	C1D364	3212 305017	ANNA SOROKINA	{"phone": "+70341440661"}
0005432106669	685D84	3881 049126	ALEKSANDR ZHURAVLEV	{"phone": "+70129572192"}
0005432106670	CFE94F	6905 873478	ANDREY SCHERBAKOV	{"email": "scherbakov.andrey_1983@postgrespro.ru", "phone": "+70412803001"}
0005432106671	CFE94F	3455 787321	KLARA POLYAKOVA	{"email": "polyakovak021988@postgrespro.ru", "phone": "+70206359308"}
0005432106672	418319	7747 001212	NATALYA MIRONOVA	{"phone": "+70312098455"}
0005432106673	418319	7502 788220	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy_17031969@postgrespro.ru", "phone": "+70612991982"}
0005432106674	120170	4549 909006	BORIS NOVIKOV	{"phone": "+70650158491"}
0005432106675	120170	3073 127067	IRINA ROMANOVA	{"phone": "+70826169994"}
0005432106676	120170	9426 144071	SOFYA GUSEVA	{"email": "guseva.sofya.1972@postgrespro.ru", "phone": "+70458722409"}
0005432106677	96BA89	0050 047896	LYUBOV PETROVA	{"email": "lyubov.petrova.28091964@postgrespro.ru", "phone": "+70825712397"}
0005432106678	3F0B13	0632 783248	NINA MARTYNOVA	{"email": "martynovan07061967@postgrespro.ru", "phone": "+70849301703"}
0005432106679	FEFAEC	9035 662913	FARIT FILIPPOV	{"phone": "+70658431125"}
0005432106680	FEFAEC	7408 657542	NATALYA ZHUKOVA	{"email": "zhukova-n_04011969@postgrespro.ru", "phone": "+70462154151"}
0005432106681	D3BD31	4537 515796	LYUDMILA KRASNOVA	{"phone": "+70183126775"}
0005432106682	D3BD31	7242 868580	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1987@postgrespro.ru", "phone": "+70603598743"}
0005432106683	8E8057	9402 366418	EVGENIY NIKOLAEV	{"phone": "+70059747707"}
0005432106684	00B2A0	9644 867864	SERGEY IVANOV	{"email": "ivanov_sergey_04031969@postgrespro.ru", "phone": "+70914515689"}
0005432106685	00B2A0	3945 863598	SERGEY VASILEV	{"email": "vasilev-sergey051969@postgrespro.ru", "phone": "+70368390574"}
0005432106686	F3D4C2	8744 555422	VIKTOR YAKOVLEV	{"email": "v.yakovlev-21071970@postgrespro.ru", "phone": "+70594212638"}
0005432106687	167D02	0388 898961	ALEKSANDR GERASIMOV	{"phone": "+70503029159"}
0005432106688	BCB5EA	6891 988291	NATALYA LUKYANOVA	{"email": "lukyanovan.1989@postgrespro.ru", "phone": "+70365550791"}
0005432106689	6B9A09	0082 355407	ILDAR KARPOV	{"phone": "+70157098992"}
0005432106690	B61DE8	5849 305160	NINA NIKOLAEVA	{"email": "nina_nikolaeva-31101970@postgrespro.ru", "phone": "+70165615167"}
0005432106691	DCD335	9337 400623	RUSLAN KOZLOV	{"email": "r_kozlov111965@postgrespro.ru", "phone": "+70691835036"}
0005432106692	3FA966	2208 191291	EVGENIY ALEKSANDROV	{"phone": "+70194711928"}
0005432106693	3FA966	3993 162670	VALENTIN DMITRIEV	{"email": "valentin-dmitriev.31051975@postgrespro.ru", "phone": "+70515724449"}
0005432106694	899725	5797 489085	ANDREY BARANOV	{"email": "abaranov051967@postgrespro.ru", "phone": "+70595468615"}
0005432106695	DC271E	9893 964894	OLGA KAZAKOVA	{"phone": "+70563508555"}
0005432106696	E58274	6541 489934	LYUDMILA SCHERBAKOVA	{"phone": "+70626126276"}
0005432106697	5CE5BC	2623 374846	IGOR ROMANOV	{"phone": "+70819783672"}
0005432106698	5CE5BC	8450 022028	MARIYA MAKAROVA	{"phone": "+70505714270"}
0005432106699	1A49F3	6332 587045	ANASTASIYA MAKAROVA	{"phone": "+70495896954"}
0005432106700	1A49F3	5653 828653	ELENA GORBUNOVA	{"email": "elena_gorbunova_111973@postgrespro.ru", "phone": "+70507892269"}
0005432106701	BB4334	5658 729385	ALEKSANDR MEDVEDEV	{"phone": "+70839156673"}
0005432106702	BB4334	2430 591596	NINA GAVRILOVA	{"email": "gavrilova-n041977@postgrespro.ru", "phone": "+70166012537"}
0005432106703	7DCA10	7092 559017	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey-1970@postgrespro.ru", "phone": "+70827543616"}
0005432106704	B17E90	9783 497584	ELENA LOGINOVA	{"phone": "+70510868587"}
0005432106705	968C56	1491 841728	GALINA GAVRILOVA	{"phone": "+70087842050"}
0005432106706	968C56	5222 631183	GALINA NESTEROVA	{"email": "nesterova_g-24041958@postgrespro.ru", "phone": "+70698652270"}
0005432106707	1319BB	9080 117085	VALERIY ROMANOV	{"phone": "+70860254404"}
0005432106708	1319BB	0577 302165	YULIYA YUDINA	{"email": "y_yudina021977@postgrespro.ru", "phone": "+70940848971"}
0005432106709	7C7E9F	4179 507683	NATALYA SMIRNOVA	{"phone": "+70951302268"}
0005432106710	7C7E9F	6976 645321	ALEKSANDR SOKOLOV	{"email": "asokolov-061972@postgrespro.ru", "phone": "+70191377694"}
0005432106711	B8C36E	0233 817141	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov.10121974@postgrespro.ru", "phone": "+70518177849"}
0005432106712	D258E2	2463 846764	VLADIMIR ZHUKOV	{"email": "zhukov-vladimir.1975@postgrespro.ru", "phone": "+70149530733"}
0005432106713	D258E2	3863 266052	TATYANA CHERNOVA	{"phone": "+70244817138"}
0005432106714	804442	1559 649095	MIKHAIL KUDRYASHOV	{"email": "kudryashovm_031961@postgrespro.ru", "phone": "+70695477645"}
0005432106715	8F1B01	5445 929669	EKATERINA GRISHINA	{"email": "ekaterina.grishina_1960@postgrespro.ru", "phone": "+70669623987"}
0005432106716	8F1B01	5181 995943	ALEKSEY MAKAROV	{"email": "makarov-aleksey-081975@postgrespro.ru", "phone": "+70208459444"}
0005432106717	A8A6A7	1578 758514	OLGA LAZAREVA	{"phone": "+70215119428"}
0005432106718	D57E1E	6934 284665	VALENTINA YAKOVLEVA	{"phone": "+70634345891"}
0005432106719	8BD225	0333 261156	GRIGORIY CHERNOV	{"email": "chernov_g04081967@postgrespro.ru", "phone": "+70818463810"}
0005432106720	ACF820	8131 906182	VALERIYA NAZAROVA	{"phone": "+70495344827"}
0005432106721	0AEEBB	3079 815597	SHAMIL ZAKHAROV	{"email": "szakharov_011976@postgrespro.ru", "phone": "+70845896635"}
0005432106722	07135E	6479 170272	IGOR PETROV	{"email": "i_petrov.23041969@postgrespro.ru", "phone": "+70122832739"}
0005432106723	07135E	9393 233096	TATYANA SAVELEVA	{"phone": "+70927845824"}
0005432106724	07135E	1704 715424	KLAVDIYA ZAKHAROVA	{"email": "zakharovak_1977@postgrespro.ru", "phone": "+70136903998"}
0005432106725	503575	7897 534084	VITALIY VASILEV	{"phone": "+70183384707"}
0005432106726	7C9C40	2096 367403	ELIZAVETA FADEEVA	{"email": "e_fadeeva.1972@postgrespro.ru", "phone": "+70524094403"}
0005432106727	AFA156	5451 018668	YANA POPOVA	{"phone": "+70157675943"}
0005432106728	4ED9A1	9338 293734	DMITRIY SEMENOV	{"email": "d-semenov_18081979@postgrespro.ru", "phone": "+70211011780"}
0005432106729	62D4C3	3317 449430	OLESYA ZHURAVLEVA	{"email": "olesya-zhuravleva081972@postgrespro.ru", "phone": "+70533975516"}
0005432106730	083D27	1481 268080	VIKTOR MOISEEV	{"email": "v-moiseev_091987@postgrespro.ru", "phone": "+70337238861"}
0005432106731	083D27	2290 350468	OLGA VOLKOVA	{"email": "o_volkova121966@postgrespro.ru", "phone": "+70791980285"}
0005432106732	56F120	7908 954457	ELENA NAZAROVA	{"email": "nazarova-e031980@postgrespro.ru", "phone": "+70930367046"}
0005432106733	56F120	5957 652814	ARTEM DMITRIEV	{"email": "artem-dmitriev.1970@postgrespro.ru", "phone": "+70420441137"}
0005432106734	97385D	0589 991978	VITALIY FEDOTOV	{"phone": "+70201675402"}
0005432106735	97385D	5272 220253	TATYANA MEDVEDEVA	{"email": "t_medvedeva_10021967@postgrespro.ru", "phone": "+70826414057"}
0005432106736	C7197A	5324 157013	INNA GERASIMOVA	{"phone": "+70137628487"}
0005432106737	C7197A	3171 684140	IVAN EGOROV	{"email": "egorov.ivan.1971@postgrespro.ru", "phone": "+70460582317"}
0005432106738	1E7A4B	2469 672713	LYUBOV MEDVEDEVA	{"email": "lmedvedeva-20021976@postgrespro.ru", "phone": "+70975020661"}
0005432106739	73B98A	3424 512605	YANA SERGEEVA	{"phone": "+70384170527"}
0005432106740	68D43A	3096 738723	KARINA KOZLOVA	{"email": "k-kozlova1983@postgrespro.ru", "phone": "+70292619089"}
0005432106741	491158	7900 124075	DMITRIY MIKHAYLOV	{"email": "mikhaylov.d041968@postgrespro.ru", "phone": "+70799359915"}
0005432106742	491158	9468 479086	ELENA ROMANOVA	{"phone": "+70162170061"}
0005432106743	BBEE30	9537 930157	NIKOLAY POPOV	{"email": "popovnikolay.1965@postgrespro.ru", "phone": "+70054898266"}
0005432106744	BBEE30	2116 766375	ANNA ZAYCEVA	{"email": "a-zayceva-071970@postgrespro.ru", "phone": "+70382991617"}
0005432106745	F8A795	5497 351623	VARVARA MASLOVA	{"email": "maslova.v_27121969@postgrespro.ru", "phone": "+70391088600"}
0005432106746	F8A795	6452 818267	TATYANA SAVELEVA	{"phone": "+70603566845"}
0005432106747	FFE55F	7456 015347	YURIY KUZMIN	{"email": "kuzmin.y_18031969@postgrespro.ru", "phone": "+70959602977"}
0005432106748	F2AD67	2353 100079	SERGEY ABRAMOV	{"email": "abramov_s.1969@postgrespro.ru", "phone": "+70758793865"}
0005432106749	F2AD67	2079 339619	ANDREY GAVRILOV	{"phone": "+70595327105"}
0005432106750	F2AD67	7433 292568	TAMARA FADEEVA	{"phone": "+70348866650"}
0005432106751	DD2C07	5511 500287	ZOYA ZAKHAROVA	{"phone": "+70894074989"}
0005432106752	DD2C07	3398 084675	LYUDMILA TROFIMOVA	{"phone": "+70537807984"}
0005432106753	3D2531	8344 247369	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy-101969@postgrespro.ru", "phone": "+70503648576"}
0005432106754	0D4020	8261 805898	MARTA KAZAKOVA	{"phone": "+70803295586"}
0005432106755	FFC05B	3217 166972	MAYYA BORISOVA	{"phone": "+70626528941"}
0005432106756	FFC05B	9100 242293	ELVIRA MAKAROVA	{"email": "elvira-makarova-1970@postgrespro.ru", "phone": "+70276773581"}
0005432106757	0A1E70	0682 995293	LYUBOV PETROVA	{"email": "petrovalyubov10021971@postgrespro.ru", "phone": "+70560502322"}
0005432106758	31C3A2	5142 581332	VYACHESLAV ZAKHAROV	{"email": "v_zakharov121978@postgrespro.ru", "phone": "+70675797062"}
0005432106759	31C3A2	6620 706550	DANILA NIKITIN	{"email": "danila_nikitin.1977@postgrespro.ru", "phone": "+70636530735"}
0005432106760	31C3A2	2562 693118	OLGA NIKITINA	{"phone": "+70175160680"}
0005432106761	A90818	4622 974708	ELIZAVETA KONOVALOVA	{"email": "e-konovalova_1972@postgrespro.ru", "phone": "+70369052009"}
0005432106762	6A1D57	9332 902512	PAVEL BARANOV	{"phone": "+70226323758"}
0005432106763	6A1D57	7548 960505	EVGENIY VOROBEV	{"phone": "+70840551699"}
0005432106764	1A47C0	9348 922838	MARIYA ORLOVA	{"email": "mariyaorlova_121969@postgrespro.ru", "phone": "+70677097684"}
0005432106765	1A47C0	4561 886271	EVGENIY MAKSIMOV	{"email": "maksimov_evgeniy051973@postgrespro.ru", "phone": "+70389770306"}
0005432106766	EDCDFA	8842 245492	ELENA NESTEROVA	{"email": "e_nesterova.1974@postgrespro.ru", "phone": "+70316052538"}
0005432106767	D619F2	9627 876784	SVETLANA IVANOVA	{"email": "ivanova.svetlana-18121975@postgrespro.ru", "phone": "+70420665941"}
0005432106768	D619F2	4062 656600	VALERIY EGOROV	{"phone": "+70776939673"}
0005432106769	297E31	9092 321728	VITALIY AFANASEV	{"email": "vitaliy_afanasev11121962@postgrespro.ru", "phone": "+70333507203"}
0005432106770	CCE565	6059 058359	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov09051974@postgrespro.ru", "phone": "+70365060783"}
0005432106771	93DAF5	8126 846374	ROMAN SOKOLOV	{"email": "sokolov_r08101971@postgrespro.ru", "phone": "+70070908646"}
0005432106772	93DAF5	0095 828046	NATALYA KUZNECOVA	{"email": "kuznecova.natalya031973@postgrespro.ru", "phone": "+70913879111"}
0005432106773	29E54B	4829 644346	ELENA VOROBEVA	{"phone": "+70149710463"}
0005432106774	29E54B	0872 110145	STEPAN KRASNOV	{"phone": "+70154651686"}
0005432106775	106F22	6311 515536	KLAVDIYA KOVALEVA	{"phone": "+70880529529"}
0005432106776	106F22	9571 170858	ALLA MATVEEVA	{"email": "matveevaa-28121974@postgrespro.ru", "phone": "+70205770670"}
0005432106777	E553AE	3073 258877	OLGA NESTEROVA	{"email": "olga_nesterova021976@postgrespro.ru", "phone": "+70130385563"}
0005432106778	E553AE	8750 182817	NAZAR MAKSIMOV	{"email": "n.maksimov.1968@postgrespro.ru", "phone": "+70222044781"}
0005432106779	1C74ED	1037 312098	VENIAMIN SCHERBAKOV	{"email": "veniamin.scherbakov.1971@postgrespro.ru", "phone": "+70001644771"}
0005432106780	1C74ED	4351 544940	TATYANA ZHURAVLEVA	{"phone": "+70662015252"}
0005432106781	D1E0DE	3704 820550	ALEKSANDR VLASOV	{"email": "vlasov.a_1973@postgrespro.ru", "phone": "+70999493234"}
0005432106782	D1E0DE	2599 349571	SERGEY TIMOFEEV	{"phone": "+70979463431"}
0005432106783	876F76	9124 389395	ELENA MELNIKOVA	{"phone": "+70507362485"}
0005432106784	8A0EF4	0328 742823	IVAN GERASIMOV	{"phone": "+70598535503"}
0005432106785	A5E655	1421 247886	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr1970@postgrespro.ru", "phone": "+70989577403"}
0005432106786	D61E4A	4726 680091	NATALYA FADEEVA	{"phone": "+70068509037"}
0005432106787	507F39	3319 473964	SVETLANA TITOVA	{"email": "titova_s.05041979@postgrespro.ru", "phone": "+70518832393"}
0005432106788	507F39	6187 513041	NINA POPOVA	{"email": "popova-nina-1966@postgrespro.ru", "phone": "+70113461026"}
0005432106789	8F511D	4535 886492	ANATOLIY SERGEEV	{"phone": "+70559069298"}
0005432106790	8F511D	8183 000935	KIRILL BARANOV	{"phone": "+70552660750"}
0005432106791	A4F605	2051 217401	LYUBOV NOVIKOVA	{"phone": "+70210638692"}
0005432106792	08A9D0	7852 122198	TATYANA VASILEVA	{"phone": "+70665537971"}
0005432106793	0F1F28	8428 756903	IREK ROMANOV	{"email": "romanovi-30121983@postgrespro.ru", "phone": "+70935615504"}
0005432106794	0F1F28	5521 260201	VIKTOR SCHERBAKOV	{"email": "viktor.scherbakov091974@postgrespro.ru", "phone": "+70169716547"}
0005432106795	E1E6CB	9521 909730	OLGA GUSEVA	{"email": "olga.guseva1988@postgrespro.ru", "phone": "+70067580347"}
0005432106796	7FC1A8	9724 570408	VLADIMIR KUDRYASHOV	{"phone": "+70019526846"}
0005432106797	AE2241	7495 010449	MARIYA NIKITINA	{"email": "mariya_nikitina_121974@postgrespro.ru", "phone": "+70259886427"}
0005432106798	686714	2090 151140	KRISTINA MARTYNOVA	{"phone": "+70191399034"}
0005432106799	BC6481	6984 956607	NATALYA TARASOVA	{"phone": "+70529966309"}
0005432106800	29A702	7448 979529	VADIM AFANASEV	{"email": "afanasevv-1974@postgrespro.ru", "phone": "+70527899989"}
0005432106801	15B540	4041 072578	ANDREY SOLOVEV	{"email": "asolovev051973@postgrespro.ru", "phone": "+70013401822"}
0005432106802	A4E8EB	7987 833165	TATYANA NIKOLAEVA	{"email": "tatyana-nikolaeva_21091970@postgrespro.ru", "phone": "+70917261947"}
0005432106803	A4E8EB	1829 367022	DMITRIY ZHUKOV	{"phone": "+70240329803"}
0005432106804	AF3A59	0752 310110	ANNA AKIMOVA	{"phone": "+70496608364"}
0005432106805	7F6D05	7220 743899	NATALYA BELOVA	{"email": "belova.n-02071977@postgrespro.ru", "phone": "+70395101063"}
0005432106806	7F6D05	7952 314127	VLADIMIR KONOVALOV	{"phone": "+70229438449"}
0005432106807	AD80A5	0013 386792	SHAMIL SAVELEV	{"phone": "+70854312796"}
0005432106808	4B8BDB	8502 120562	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy.1968@postgrespro.ru", "phone": "+70223377166"}
0005432106809	CD1734	3347 961861	ANNA MATVEEVA	{"email": "a-matveeva_021969@postgrespro.ru", "phone": "+70772559504"}
0005432106810	63BB4E	5131 520788	ANNA GUSEVA	{"phone": "+70423798257"}
0005432106811	63BB4E	2301 635402	MAYYA KONOVALOVA	{"email": "konovalova-m16101986@postgrespro.ru", "phone": "+70251063483"}
0005432106812	6B65E7	4028 890990	EKATERINA ZHURAVLEVA	{"phone": "+70800847299"}
0005432106813	6B65E7	1567 519402	VYACHESLAV ZAKHAROV	{"email": "v-zakharov041961@postgrespro.ru", "phone": "+70332061549"}
0005432106814	EF5EA6	8142 514763	SERGEY MATVEEV	{"phone": "+70188163630"}
0005432106815	4184BB	5254 989010	NINA LEBEDEVA	{"phone": "+70992464573"}
0005432106816	10E99D	6147 339929	VIKTOR VASILEV	{"email": "viktor.vasilev1969@postgrespro.ru", "phone": "+70990519328"}
0005432106817	723B8A	6098 069144	ARTEM KOROLEV	{"email": "artemkorolev011974@postgrespro.ru", "phone": "+70856260028"}
0005432106818	723B8A	5098 340322	NATALYA BOGDANOVA	{"phone": "+70523882682"}
0005432106819	CDCFC5	8681 807783	TATYANA SMIRNOVA	{"email": "smirnova-tatyana-23081976@postgrespro.ru", "phone": "+70278925768"}
0005432106820	CDCFC5	7003 247047	PAVEL KUZNECOV	{"email": "kuznecov_p.021970@postgrespro.ru", "phone": "+70077540956"}
0005432106821	D03381	8292 540185	SERGEY FEDOTOV	{"phone": "+70407040167"}
0005432106822	9F3FAF	6838 765819	LARISA ROMANOVA	{"email": "larisa.romanova021979@postgrespro.ru", "phone": "+70865572630"}
0005432106823	9F3FAF	6499 923104	YURIY POPOV	{"phone": "+70415670999"}
0005432106824	158797	1696 205959	EKATERINA VASILEVA	{"phone": "+70839950128"}
0005432106825	158797	6759 215710	EVGENIY ZAKHAROV	{"phone": "+70621533295"}
0005432106826	BAE59E	1430 413807	DMITRIY ROMANOV	{"phone": "+70760263557"}
0005432106827	BAE59E	5809 309863	IRINA ZAYCEVA	{"phone": "+70144909554"}
0005432106828	F876DA	8646 273021	ANDREY MOROZOV	{"phone": "+70592063947"}
0005432106829	729522	6781 228322	ILYA STEPANOV	{"email": "i-stepanov.031962@postgrespro.ru", "phone": "+70089569021"}
0005432106830	59514F	5210 379230	DMITRIY KAZAKOV	{"email": "kazakov.dmitriy_031969@postgrespro.ru", "phone": "+70614272199"}
0005432106831	59514F	2459 238127	MARIYA NOVIKOVA	{"email": "novikova_mariya.101969@postgrespro.ru", "phone": "+70469465299"}
0005432106832	77FE68	2967 554317	EKATERINA ARKHIPOVA	{"email": "e.arkhipova_111981@postgrespro.ru", "phone": "+70575067398"}
0005432106833	EA8BEF	9608 896312	VALENTINA KOMAROVA	{"phone": "+70652159934"}
0005432106834	EA8BEF	7788 901944	NATALYA ZHURAVLEVA	{"phone": "+70708747142"}
0005432106835	4BAA2D	8379 967810	KONSTANTIN TIMOFEEV	{"email": "timofeev.k13061970@postgrespro.ru", "phone": "+70605336343"}
0005432106836	4BAA2D	5532 026343	NATALYA TARASOVA	{"email": "natalya-tarasova.101975@postgrespro.ru", "phone": "+70901301663"}
0005432106837	08A378	6264 437662	KONSTANTIN BORISOV	{"phone": "+70089836029"}
0005432106838	08A378	7071 932410	EKATERINA SEMENOVA	{"email": "ekaterina_semenova021974@postgrespro.ru", "phone": "+70809963123"}
0005432106839	AE0DA6	3515 580149	IGOR GERASIMOV	{"phone": "+70928675951"}
0005432106840	1D31BC	6652 654457	DARYA GAVRILOVA	{"email": "gavrilova-darya.021987@postgrespro.ru", "phone": "+70611240299"}
0005432106841	1D31BC	4637 806221	EKATERINA KISELEVA	{"email": "ekaterina-kiseleva_111979@postgrespro.ru", "phone": "+70944018420"}
0005432106842	3D2005	7290 497224	ALEKSANDR NIKITIN	{"email": "a.nikitin.061964@postgrespro.ru", "phone": "+70835470461"}
0005432106843	55C23B	0041 874763	LIDIYA SOKOLOVA	{"email": "sokolova_lidiya.27121970@postgrespro.ru", "phone": "+70412486231"}
0005432106844	2E8367	3222 255935	DMITRIY KOZLOV	{"email": "dmitriy_kozlov.02101976@postgrespro.ru", "phone": "+70524369868"}
0005432106845	940AF5	7845 258290	GEORGIY ALEKSEEV	{"email": "alekseev-g-16121968@postgrespro.ru", "phone": "+70254852816"}
0005432106846	920389	7543 234719	YULIYA GAVRILOVA	{"email": "gavrilovay-17081965@postgrespro.ru", "phone": "+70919188440"}
0005432106847	74ECF7	1776 490148	TATYANA ROMANOVA	{"phone": "+70702229360"}
0005432106848	29DB95	6639 889558	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova1976@postgrespro.ru", "phone": "+70759121138"}
0005432106849	ED188D	4548 320367	VALENTINA DAVYDOVA	{"email": "davydova.valentina-1978@postgrespro.ru", "phone": "+70629053772"}
0005432106850	ED188D	2631 693955	YULIYA KONOVALOVA	{"phone": "+70380460668"}
0005432106851	17A7C9	6327 969692	EVGENIYA PETROVA	{"email": "evgeniya.petrova_1980@postgrespro.ru", "phone": "+70481973414"}
0005432106852	A7F45B	0631 256187	IRINA NIKITINA	{"email": "nikitina_irina.1972@postgrespro.ru", "phone": "+70881572112"}
0005432106853	A7F45B	2844 216312	YURIY BARANOV	{"phone": "+70589560599"}
0005432106854	FC0296	5786 834924	MIKHAIL POPOV	{"email": "popov.mikhail-04121975@postgrespro.ru", "phone": "+70157139275"}
0005432106855	FC0296	1544 130621	TATYANA NIKITINA	{"phone": "+70046429367"}
0005432106856	39B76C	7804 100889	PRASKOVYA NAZAROVA	{"phone": "+70193865304"}
0005432106857	39B76C	9878 002315	DENIS BARANOV	{"phone": "+70149942245"}
0005432106858	E70B26	3129 200300	EKATERINA NESTEROVA	{"email": "ekaterinanesterova.10121977@postgrespro.ru", "phone": "+70976377450"}
0005432106859	190A94	9713 285816	RAFAIL VOLKOV	{"phone": "+70195632054"}
0005432106860	190A94	5274 589890	SOFYA LOGINOVA	{"email": "loginova_s.051969@postgrespro.ru", "phone": "+70404203808"}
0005432106861	1C4216	8790 630326	FEDOR MAKAROV	{"email": "makarov_fedor021962@postgrespro.ru", "phone": "+70910191403"}
0005432106862	35A186	3800 381844	DAMIR IVANOV	{"phone": "+70854508311"}
0005432106863	00E603	6843 027406	MARIYA SOKOLOVA	{"email": "m-sokolova_1965@postgrespro.ru", "phone": "+70154584328"}
0005432106864	34D7B4	2376 333779	VLADISLAV SAVELEV	{"email": "savelev-v1977@postgrespro.ru", "phone": "+70379853094"}
0005432106865	34D7B4	7057 147682	VITALIY GAVRILOV	{"email": "gavrilovvitaliy_1970@postgrespro.ru", "phone": "+70463875757"}
0005432106866	69AC21	8556 621420	ELIZAVETA VASILEVA	{"phone": "+70385482301"}
0005432106867	710A31	7118 940949	ALEKSANDR SOLOVEV	{"email": "a_solovev-071966@postgrespro.ru", "phone": "+70086854289"}
0005432106868	4298A5	8829 399333	VLADISLAV MOROZOV	{"phone": "+70523624419"}
0005432106869	AAB228	8671 716575	LIDIYA KUZNECOVA	{"phone": "+70679090774"}
0005432106870	AAB228	0523 890316	YURIY TARASOV	{"phone": "+70337692330"}
0005432106871	9B5C67	8288 116723	DMITRIY MELNIKOV	{"email": "melnikovd12071982@postgrespro.ru", "phone": "+70231614023"}
0005432106872	0E5318	7652 697329	DMITRIY FILIPPOV	{"phone": "+70761857337"}
0005432106873	0E1C7D	2194 433323	VIKTORIYA POPOVA	{"email": "vpopova-18091978@postgrespro.ru", "phone": "+70900037351"}
0005432106874	F702A8	6528 963098	ELIZAVETA KALININA	{"email": "kalinina-e-23121971@postgrespro.ru", "phone": "+70199400128"}
0005432106875	F702A8	1165 604797	OLGA POTAPOVA	{"phone": "+70387422529"}
0005432106876	D8349F	8950 958162	EVGENIY PAVLOV	{"email": "e-pavlov-021973@postgrespro.ru", "phone": "+70629084909"}
0005432106877	D8349F	1090 342428	VITALIY VOLKOV	{"email": "volkov-vitaliy1969@postgrespro.ru", "phone": "+70603455660"}
0005432106878	5C30AC	6324 096286	NIKOLAY MOROZOV	{"phone": "+70947559507"}
0005432106879	12C038	3152 495040	NATALYA RYABOVA	{"phone": "+70721081016"}
0005432106880	58925D	9556 363297	KONSTANTIN DENISOV	{"phone": "+70148617266"}
0005432106881	EE3510	5576 013251	VYACHESLAV EGOROV	{"phone": "+70382486411"}
0005432106882	EE3510	1172 921521	ALEKSEY NAUMOV	{"email": "aleksey.naumov-1976@postgrespro.ru", "phone": "+70604389616"}
0005432106883	A25F18	7846 512155	IVAN BORISOV	{"email": "ivanborisov_1968@postgrespro.ru", "phone": "+70837388107"}
0005432106884	3D98E4	6294 258791	EVGENIYA MARTYNOVA	{"email": "emartynova15021983@postgrespro.ru", "phone": "+70147974172"}
0005432106885	3D98E4	2208 595769	VALENTINA DAVYDOVA	{"phone": "+70815938794"}
0005432106886	23200C	8065 037527	EVGENIY ILIN	{"email": "ilin.e.111968@postgrespro.ru", "phone": "+70901896848"}
0005432106887	23200C	1218 324325	SAVELIY MIRONOV	{"email": "smironov-18071980@postgrespro.ru", "phone": "+70841709636"}
0005432106888	06A196	8899 942456	EVGENIY PETROV	{"phone": "+70769326764"}
0005432106889	06A196	5513 948680	SVETLANA BELOVA	{"phone": "+70584892262"}
0005432106890	52A855	6078 009287	ALEKSEY KOZLOV	{"phone": "+70202821950"}
0005432106891	75F116	8560 911364	ALENA POPOVA	{"email": "a_popova_1968@postgrespro.ru", "phone": "+70029178783"}
0005432106892	75F116	7538 364853	ALEKSANDR MOISEEV	{"phone": "+70576109096"}
0005432106893	1C21E2	9720 139504	LYUDMILA POLYAKOVA	{"email": "l_polyakova-081970@postgrespro.ru", "phone": "+70224736736"}
0005432106894	1C21E2	5603 891370	IRINA IVANOVA	{"email": "i_ivanova_071971@postgrespro.ru", "phone": "+70287268461"}
0005432106895	5F7BFE	3287 805301	VLADIMIR VASILEV	{"email": "vasilev_vladimir-08031965@postgrespro.ru", "phone": "+70830297475"}
0005432106896	DCB782	9920 673836	VALENTINA ZHUKOVA	{"email": "zhukova-v.091976@postgrespro.ru", "phone": "+70110442010"}
0005432106897	DCB782	4155 980214	SERGEY TARASOV	{"email": "tarasovsergey1975@postgrespro.ru", "phone": "+70657137857"}
0005432106898	741165	5677 725350	ROZA NAZAROVA	{"phone": "+70731668694"}
0005432106899	73DDD2	7715 733169	KRISTINA MARTYNOVA	{"phone": "+70933055645"}
0005432106900	2D3815	0078 682376	ANDREY MIRONOV	{"email": "andrey_mironov1971@postgrespro.ru", "phone": "+70411577949"}
0005432106901	8F3450	0130 104794	OLEG PAVLOV	{"phone": "+70668337190"}
0005432106902	B1CC36	5320 468877	SVETLANA NAZAROVA	{"phone": "+70788602181"}
0005432109656	FE1BF4	4938 417370	ANDREY SOROKIN	{"phone": "+70408752717"}
0005432106903	B1CC36	5546 671525	VLADIMIR ANDREEV	{"email": "vladimir-andreev19051976@postgrespro.ru", "phone": "+70348663815"}
0005432106904	DF50C1	3002 597753	SERGEY SHEVCHENKO	{"phone": "+70239965100"}
0005432106905	7EA6DE	9260 477127	MAKSIM VASILEV	{"email": "maksim-vasilev.041976@postgrespro.ru", "phone": "+70897768246"}
0005432106906	7EA6DE	1212 238844	VLADIMIR NIKOLAEV	{"email": "v.nikolaev-061974@postgrespro.ru", "phone": "+70476908826"}
0005432106907	873CFF	5203 230269	NATALYA MOROZOVA	{"email": "n-morozova-091971@postgrespro.ru", "phone": "+70307111468"}
0005432106908	777C34	6670 675512	GRIGORIY OSIPOV	{"email": "g.osipov-041967@postgrespro.ru", "phone": "+70206396865"}
0005432106909	777C34	9540 614614	TATYANA MAKAROVA	{"email": "tatyana.makarova.071963@postgrespro.ru", "phone": "+70721594840"}
0005432106910	1531DD	1550 596358	EGOR SIDOROV	{"email": "e.sidorov071976@postgrespro.ru", "phone": "+70923277381"}
0005432106911	1531DD	7793 353476	SVETLANA KOLESNIKOVA	{"phone": "+70186366235"}
0005432106912	47FA74	2908 076046	VALENTINA BOGDANOVA	{"phone": "+70562567589"}
0005432106913	0CD58B	3769 050604	DMITRIY ROMANOV	{"email": "romanov_dmitriy12111959@postgrespro.ru", "phone": "+70603674945"}
0005432106914	AE0390	0184 383535	SVETLANA TROFIMOVA	{"phone": "+70251789981"}
0005432106915	E0AD17	7448 086918	DARYA KUDRYASHOVA	{"phone": "+70718316055"}
0005432106916	61E928	0448 753002	NIKOLAY VLASOV	{"email": "vlasovn041966@postgrespro.ru", "phone": "+70101837895"}
0005432106917	0DD2F8	3448 538461	ALEKSANDR IVANOV	{"phone": "+70449603410"}
0005432106918	FF0961	7382 894086	LARISA SAVELEVA	{"email": "saveleval.17031974@postgrespro.ru", "phone": "+70250218067"}
0005432106919	BF96EC	3858 242606	SERGEY SERGEEV	{"email": "s.sergeev06101980@postgrespro.ru", "phone": "+70288178944"}
0005432106920	BF96EC	4510 562964	TATYANA KRASNOVA	{"email": "t.krasnova.091970@postgrespro.ru", "phone": "+70822251528"}
0005432106921	14B1B1	8979 582866	LYUDMILA SERGEEVA	{"phone": "+70829590720"}
0005432106922	14B1B1	2044 689117	NATALYA ZHURAVLEVA	{"phone": "+70252833675"}
0005432106923	14B1B1	2364 466997	EVGENIY KONOVALOV	{"email": "evgeniy.konovalov_10111978@postgrespro.ru", "phone": "+70106660657"}
0005432106924	8A2E9B	1374 401931	NINA ZAKHAROVA	{"email": "n-zakharova.1978@postgrespro.ru", "phone": "+70340438799"}
0005432106925	87A951	2175 988943	ELENA SIDOROVA	{"phone": "+70750188573"}
0005432106926	6CBCBA	0922 022490	NIKOLAY VASILEV	{"phone": "+70012252559"}
0005432106927	E130EE	4311 709625	MARAT SEMENOV	{"email": "msemenov.1968@postgrespro.ru", "phone": "+70574344482"}
0005432106928	E130EE	3389 416959	IVAN ILIN	{"phone": "+70192638279"}
0005432106929	232AE7	4149 784883	VALENTINA ZAKHAROVA	{"phone": "+70354982098"}
0005432106930	232AE7	8083 143013	ALEKSANDR KUZNECOV	{"email": "akuznecov-09091984@postgrespro.ru", "phone": "+70360103459"}
0005432106931	232AE7	7047 424464	YULIYA KOROLEVA	{"email": "yuliya.koroleva31101986@postgrespro.ru", "phone": "+70922232427"}
0005432106932	4DB4ED	5913 085326	NATALYA ILINA	{"email": "natalya.ilina.1977@postgrespro.ru", "phone": "+70065754789"}
0005432106933	3CEE8A	0237 377918	TAMARA SEMENOVA	{"email": "tamara.semenova.20071979@postgrespro.ru", "phone": "+70672034002"}
0005432106934	5F65B8	6033 273795	YANA ERMAKOVA	{"phone": "+70681574926"}
0005432106935	3C7B31	0832 345827	ANDREY SMIRNOV	{"email": "andreysmirnov021977@postgrespro.ru", "phone": "+70026736339"}
0005432106936	2CD89E	3304 065414	DENIS STEPANOV	{"phone": "+70902830438"}
0005432106937	AAD769	1133 504088	POLINA FADEEVA	{"email": "fadeeva_polina_03021978@postgrespro.ru", "phone": "+70838132474"}
0005432106938	0B31D0	5535 965670	DARYA LUKYANOVA	{"email": "dlukyanova_01011972@postgrespro.ru", "phone": "+70152516878"}
0005432106939	B202C4	0930 446868	ELENA MEDVEDEVA	{"email": "medvedeva-elena-071975@postgrespro.ru", "phone": "+70337433171"}
0005432106940	81A3FA	8229 473459	ANATOLIY MAKAROV	{"phone": "+70969521778"}
0005432106941	3664A5	8524 102101	DMITRIY KUZNECOV	{"phone": "+70828827764"}
0005432106942	BE5015	9544 953368	SERGEY FOMIN	{"phone": "+70565454750"}
0005432106943	59E7E3	5633 239417	VADIM NIKITIN	{"email": "vadim_nikitin12041975@postgrespro.ru", "phone": "+70410936939"}
0005432106944	59E7E3	5226 333748	GALINA AFANASEVA	{"email": "gafanaseva-091969@postgrespro.ru", "phone": "+70672183585"}
0005432106945	4D7523	2945 243380	ASIYA BARANOVA	{"email": "a-baranova.071974@postgrespro.ru", "phone": "+70684395247"}
0005432106946	ED830A	3031 439209	NIKOLAY BARANOV	{"phone": "+70913112041"}
0005432106947	ED830A	8820 473102	ALEKSANDR PAVLOV	{"phone": "+70404356178"}
0005432106948	9CE0B3	3570 192019	VALERIY DMITRIEV	{"phone": "+70572391648"}
0005432106949	9CE0B3	3302 781645	LIDIYA TITOVA	{"email": "titoval_1969@postgrespro.ru", "phone": "+70472262941"}
0005432106950	2BD3A1	9625 950089	AMINA ZAYCEVA	{"phone": "+70559106505"}
0005432106951	A2CA3C	3375 077219	KIRILL FEDOTOV	{"phone": "+70055266934"}
0005432106952	C5CD84	9057 051371	VITALIY TARASOV	{"email": "tarasov_vitaliy_1974@postgrespro.ru", "phone": "+70930413152"}
0005432106953	020ECB	0443 695865	ALEKSEY ANDREEV	{"email": "aandreev.03011982@postgrespro.ru", "phone": "+70019131215"}
0005432106954	185C55	3493 905642	GALINA ORLOVA	{"phone": "+70245270987"}
0005432106955	626C46	5295 117948	ANDREY PAVLOV	{"phone": "+70381004811"}
0005432106956	626C46	6440 397750	YURIY GRIGOREV	{"email": "y-grigorev-1982@postgrespro.ru", "phone": "+70560618059"}
0005432108204	175F6D	5359 546380	VERA ILINA	{"email": "ilina.v.11111983@postgrespro.ru", "phone": "+70320531197"}
0005432108205	54A5A9	1493 034118	VLADIMIR MAKAROV	{"email": "makarov-vladimir_081966@postgrespro.ru", "phone": "+70661924553"}
0005432108206	A2B455	2567 557929	NIKOLAY GERASIMOV	{"email": "gerasimovn.01021972@postgrespro.ru", "phone": "+70029718251"}
0005432108207	EB8FE0	6963 431889	TATYANA ANTONOVA	{"phone": "+70286193135"}
0005432108208	EB8FE0	4932 509714	MARIYA SOROKINA	{"email": "sorokina.m-28061976@postgrespro.ru", "phone": "+70942308266"}
0005432108209	895CFF	2175 361257	LYUBOV MIRONOVA	{"email": "lyubov.mironova_23051965@postgrespro.ru", "phone": "+70943558423"}
0005432108210	C53115	3005 340299	GULNARA MALYSHEVA	{"phone": "+70849816063"}
0005432108211	426C42	8371 175853	KIRA IVANOVA	{"phone": "+70113978841"}
0005432108212	426C42	1233 334310	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova.1975@postgrespro.ru", "phone": "+70402672003"}
0005432108213	235E6F	6777 450083	VIKTOR STEPANOV	{"email": "stepanov_v1979@postgrespro.ru", "phone": "+70426954190"}
0005432108214	1E867E	6468 459802	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_121979@postgrespro.ru", "phone": "+70333823370"}
0005432108215	1DC9A2	9053 730667	ANNA MOISEEVA	{"phone": "+70059464443"}
0005432108216	1DC9A2	7388 554901	VLADIMIR POPOV	{"email": "v-popov_17051973@postgrespro.ru", "phone": "+70696228808"}
0005432108217	1DC9A2	2686 534486	MARINA CHERNOVA	{"phone": "+70129084064"}
0005432108218	FDAFF0	7172 730119	YULIYA GAVRILOVA	{"email": "yuliyagavrilova081980@postgrespro.ru", "phone": "+70770141464"}
0005432108219	1ED179	3420 235529	ALEKSANDR VOROBEV	{"phone": "+70226595495"}
0005432108220	BFCCF5	0482 797627	IGOR BORISOV	{"email": "i.borisov_1971@postgrespro.ru", "phone": "+70476947433"}
0005432108221	4F606C	1697 222370	MARIYA MOISEEVA	{"email": "moiseeva-m-03051975@postgrespro.ru", "phone": "+70974811051"}
0005432108222	4F606C	7214 379729	ILYA FEDOTOV	{"phone": "+70336714850"}
0005432108223	359586	4908 619249	VALERIY ABRAMOV	{"email": "abramovv1977@postgrespro.ru", "phone": "+70120063668"}
0005432108224	359586	2149 532105	VALENTINA TARASOVA	{"email": "v.tarasova-21071966@postgrespro.ru", "phone": "+70860427657"}
0005432108225	33E595	5389 447937	MAKSIM ZAYCEV	{"phone": "+70954804746"}
0005432108226	717D1B	7901 214017	ANNA YUDINA	{"email": "yudina_anna.1975@postgrespro.ru", "phone": "+70708992874"}
0005432108227	717D1B	7084 316262	ANATOLIY TIKHONOV	{"phone": "+70780886290"}
0005432108228	518CF4	5008 300849	GALINA IVANOVA	{"phone": "+70256477833"}
0005432108229	A05789	9914 666629	ANTON KUZNECOV	{"phone": "+70994608146"}
0005432108230	D44809	4001 158215	LIDIYA FADEEVA	{"email": "fadeeva-lidiya-051966@postgrespro.ru", "phone": "+70110227977"}
0005432108231	4D3B24	9082 857449	ALEKSANDR PAVLOV	{"email": "pavlov_a_1973@postgrespro.ru", "phone": "+70293865276"}
0005432108232	BDF2F1	1261 304486	NIKOLAY RODIONOV	{"email": "nrodionov071975@postgrespro.ru", "phone": "+70907689797"}
0005432108233	86FC6B	6965 064755	NATALYA MATVEEVA	{"phone": "+70150962823"}
0005432108234	86FC6B	0520 317185	VIKTOR MEDVEDEV	{"phone": "+70546129821"}
0005432108235	1505BB	6919 238775	ELENA EGOROVA	{"email": "egorova.e-1966@postgrespro.ru", "phone": "+70917391112"}
0005432108236	1505BB	6824 643767	RAISA KOROLEVA	{"phone": "+70759170613"}
0005432108237	C7DC24	7535 855797	ELENA TARASOVA	{"email": "tarasova.elena14021964@postgrespro.ru", "phone": "+70772386592"}
0005432108238	C7DC24	9087 296469	NIKITA MIRONOV	{"phone": "+70805066480"}
0005432108239	BAA7BA	8842 086478	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr.17081982@postgrespro.ru", "phone": "+70047764109"}
0005432108240	BAA7BA	7594 060226	TATYANA IVANOVA	{"phone": "+70509189452"}
0005432108241	0FB557	2392 901123	MARINA ORLOVA	{"email": "marina_orlova_051975@postgrespro.ru", "phone": "+70209559685"}
0005432108242	0FB557	8016 729632	LYUDMILA LOGINOVA	{"email": "lloginova_1973@postgrespro.ru", "phone": "+70664892301"}
0005432108243	0F4DAB	4991 649365	EVGENIY CHERNOV	{"email": "e.chernov-091974@postgrespro.ru", "phone": "+70865427012"}
0005432108244	7CC69C	4282 046883	NADEZHDA KUZNECOVA	{"phone": "+70240991958"}
0005432108245	50C83B	4155 647791	VLADISLAV PETROV	{"email": "petrov.vladislav.1965@postgrespro.ru", "phone": "+70161393599"}
0005432108246	FE425C	0827 967880	NADEZHDA ZAKHAROVA	{"email": "nadezhda.zakharova.02081973@postgrespro.ru", "phone": "+70863731694"}
0005432108247	FE425C	8307 538332	ZARINA NESTEROVA	{"phone": "+70534280085"}
0005432108248	FE425C	3063 592202	VYACHESLAV SMIRNOV	{"email": "vyacheslav-smirnov1974@postgrespro.ru", "phone": "+70153635978"}
0005432108249	4549E4	4736 840178	NATALYA FILIPPOVA	{"phone": "+70449541218"}
0005432108250	4549E4	1045 757397	EKATERINA PETROVA	{"email": "ekaterina_petrova1976@postgrespro.ru", "phone": "+70784650972"}
0005432108251	1203B5	8098 618038	STANISLAV BELOV	{"phone": "+70390678789"}
0005432108252	C62041	2779 200465	VLADIMIR POPOV	{"email": "vladimir_popov.021973@postgrespro.ru", "phone": "+70803949407"}
0005432108253	C62041	3819 116119	ARTEM MEDVEDEV	{"email": "medvedev.a.1968@postgrespro.ru", "phone": "+70151622078"}
0005432108254	961D3F	0433 370117	ALISA MIKHAYLOVA	{"phone": "+70098561619"}
0005432108255	06A551	6212 085003	VLADIMIR TARASOV	{"email": "vladimir-tarasov.15051974@postgrespro.ru", "phone": "+70924260693"}
0005432108256	947F67	6279 506054	OLEG ROMANOV	{"email": "romanov-o_21111987@postgrespro.ru", "phone": "+70855192771"}
0005432108257	2E23D4	7814 752842	ANATOLIY KAZAKOV	{"email": "anatoliy_kazakov.02071964@postgrespro.ru", "phone": "+70133302767"}
0005432108258	C4A368	1066 149956	KIRILL MIKHAYLOV	{"email": "k.mikhaylov_1971@postgrespro.ru", "phone": "+70529900345"}
0005432108259	C4A368	9735 890224	VASILIY STEPANOV	{"phone": "+70103999692"}
0005432108260	B9A5EE	5618 210883	VASILIY KRASNOV	{"email": "krasnovvasiliy.081973@postgrespro.ru", "phone": "+70264557919"}
0005432108261	B9A5EE	9166 445212	EGOR SMIRNOV	{"email": "smirnov-e-1977@postgrespro.ru", "phone": "+70696401380"}
0005432108262	1421BE	6492 560447	PETR SAVELEV	{"email": "savelevp.011976@postgrespro.ru", "phone": "+70994169595"}
0005432108263	3AB076	6497 530267	VLADIMIR NAUMOV	{"phone": "+70614522209"}
0005432108264	5D052B	5461 590008	OLGA NOVIKOVA	{"email": "novikova.olga_04101970@postgrespro.ru", "phone": "+70893279933"}
0005432108265	1D252D	3318 764185	SERGEY DENISOV	{"phone": "+70821274917"}
0005432108266	1D252D	9982 689111	TATYANA PETROVA	{"email": "petrova.tatyana.18061963@postgrespro.ru", "phone": "+70235494806"}
0005432108267	913B4B	9232 771303	RUSLAN MAKSIMOV	{"email": "r-maksimov_071974@postgrespro.ru", "phone": "+70916410691"}
0005432108268	209C1A	5793 644057	SERGEY TIMOFEEV	{"email": "stimofeev-121961@postgrespro.ru", "phone": "+70641183129"}
0005432108269	918975	0144 246206	GALINA SOLOVEVA	{"email": "soloveva-g_051976@postgrespro.ru", "phone": "+70725621672"}
0005432108270	73AAF5	9975 245545	SVETLANA KOROLEVA	{"email": "s.koroleva1965@postgrespro.ru", "phone": "+70432722754"}
0005432108271	94FE8E	2412 793033	DANIL SMIRNOV	{"email": "smirnov-danil.081970@postgrespro.ru", "phone": "+70777711486"}
0005432108272	46A602	3586 689277	NADEZHDA POTAPOVA	{"phone": "+70424321210"}
0005432108273	46A602	5154 487614	MIKHAIL ANDREEV	{"phone": "+70711130786"}
0005432108274	0C32ED	7761 772444	ALEKSEY ANTONOV	{"email": "antonov-a.071963@postgrespro.ru", "phone": "+70310849371"}
0005432108275	0C32ED	1207 395734	VALENTINA POPOVA	{"phone": "+70721222146"}
0005432108276	6AC55D	1047 546645	VALERIY NIKITIN	{"email": "nikitin_valeriy_111955@postgrespro.ru", "phone": "+70026816043"}
0005432108277	6AC55D	2402 932473	ARTEM KULIKOV	{"phone": "+70902772343"}
0005432108278	14D62B	5109 769413	SVETLANA KUDRYASHOVA	{"email": "s-kudryashova08081968@postgrespro.ru", "phone": "+70163532862"}
0005432108279	EBE409	9529 772401	IVAN MOROZOV	{"phone": "+70459785830"}
0005432108280	B8BFDD	4525 530180	ARTEM ISAEV	{"email": "artem-isaev011968@postgrespro.ru", "phone": "+70473636763"}
0005432108281	1B1C13	9439 445314	SVETLANA MAKAROVA	{"email": "makarova_s15051976@postgrespro.ru", "phone": "+70744878264"}
0005432108282	83696D	4349 310169	ANDREY KARPOV	{"email": "karpov.a_1989@postgrespro.ru", "phone": "+70850506108"}
0005432108283	83696D	8507 119789	ALLA KOROLEVA	{"email": "a-koroleva1966@postgrespro.ru", "phone": "+70178365254"}
0005432108284	BAD8BF	0434 718910	ANNA IVANOVA	{"phone": "+70283980146"}
0005432108285	4331AF	7466 906716	ALEKSANDR BARANOV	{"phone": "+70616546134"}
0005432108286	BD0BEF	9743 048334	ALEKSANDR GERASIMOV	{"email": "gerasimov-a17041963@postgrespro.ru", "phone": "+70867207209"}
0005432108287	BD0BEF	7688 158651	SERGEY SERGEEV	{"email": "sergeev_s1969@postgrespro.ru", "phone": "+70544447618"}
0005432108288	95D4B1	3915 935358	OLEG SMIRNOV	{"phone": "+70962024139"}
0005432108289	95D4B1	6999 439420	LYUDMILA PAVLOVA	{"email": "pavlova.lyudmila051967@postgrespro.ru", "phone": "+70593217101"}
0005432108290	65EEC6	2012 352143	ALEKSANDR SOKOLOV	{"phone": "+70596927841"}
0005432108291	65EEC6	5689 387032	EKATERINA KONDRATEVA	{"phone": "+70536362790"}
0005432108292	5BD5C0	3903 810671	VENIAMIN KAZAKOV	{"email": "kazakov-v.091974@postgrespro.ru", "phone": "+70666198312"}
0005432108293	E38CDD	1084 235249	GENNADIY VASILEV	{"email": "g_vasilev.1981@postgrespro.ru", "phone": "+70984505210"}
0005432108294	E38CDD	9498 801501	DMITRIY SHEVCHENKO	{"phone": "+70249893424"}
0005432108295	595406	7077 858836	TATYANA MIRONOVA	{"email": "mironova.tatyana_11101974@postgrespro.ru", "phone": "+70016730758"}
0005432108296	FD71C3	9395 019412	SERGEY BELOV	{"phone": "+70390684716"}
0005432108297	687C37	3647 967978	DAVID SCHERBAKOV	{"email": "scherbakovd.101974@postgrespro.ru", "phone": "+70927064389"}
0005432108298	D6959D	4702 709923	ALEKSANDR PAVLOV	{"phone": "+70905997658"}
0005432108299	D6959D	3879 816202	OLGA FILATOVA	{"email": "filatova_o-21041974@postgrespro.ru", "phone": "+70159515183"}
0005432108300	8216B0	9524 341826	VLADIMIR GRIGOREV	{"phone": "+70538100616"}
0005432108301	8216B0	0639 259110	LARISA KUZNECOVA	{"email": "kuznecova.l1971@postgrespro.ru", "phone": "+70761663570"}
0005432108302	3F711B	8209 753446	ALEKSEY MOISEEV	{"email": "moiseev-aleksey_1976@postgrespro.ru", "phone": "+70523812968"}
0005432108303	2A89C8	7449 907242	YURIY CHERNOV	{"email": "yuriychernov-1975@postgrespro.ru", "phone": "+70865307354"}
0005432108304	5FD625	4454 396539	VLADISLAV SCHERBAKOV	{"phone": "+70576915952"}
0005432108305	E75442	1210 321326	GALINA KULIKOVA	{"phone": "+70611240672"}
0005432108306	2ADDAF	9945 133410	LYUBOV AKIMOVA	{"phone": "+70835152029"}
0005432108307	2ADDAF	3614 764495	MAKSIM IVANOV	{"email": "ivanov_m22061964@postgrespro.ru", "phone": "+70317986822"}
0005432108308	42096B	8711 142415	YURIY SIDOROV	{"phone": "+70046128034"}
0005432108309	42096B	3895 670362	VYACHESLAV KUDRYASHOV	{"email": "vkudryashov06031975@postgrespro.ru", "phone": "+70045887037"}
0005432108310	42096B	8087 061251	NIKOLAY PETROV	{"phone": "+70205765582"}
0005432108311	35DA82	3864 719134	ILYA GAVRILOV	{"email": "i-gavrilov-101977@postgrespro.ru", "phone": "+70135854645"}
0005432108312	DAAFC5	9514 845891	NATALIYA ZAKHAROVA	{"phone": "+70170560799"}
0005432108313	CEF4E8	2190 057184	IRINA POTAPOVA	{"phone": "+70379844785"}
0005432108314	CEF4E8	6711 128023	SERGEY POPOV	{"email": "popov_s01101972@postgrespro.ru", "phone": "+70652416434"}
0005432108315	67560C	4508 709686	YURIY EGOROV	{"email": "y-egorov-1963@postgrespro.ru", "phone": "+70597971335"}
0005432108316	868137	1703 511683	MARINA LOGINOVA	{"email": "marina_loginova-121967@postgrespro.ru", "phone": "+70490018558"}
0005432108317	D7A9FA	4558 847581	SERGEY BORISOV	{"phone": "+70394756577"}
0005432108318	CB2A8D	2899 763395	OLGA PETROVA	{"phone": "+70512817160"}
0005432108319	0F043C	4291 349211	VIKTOR SEMENOV	{"email": "v_semenov-09041973@postgrespro.ru", "phone": "+70712166679"}
0005432108320	E4C66C	2142 333231	ELENA POPOVA	{"email": "popova_elena-31031970@postgrespro.ru", "phone": "+70215454849"}
0005432108321	E4C66C	4576 063082	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev12091965@postgrespro.ru", "phone": "+70636337064"}
0005432108322	E4C66C	8075 217090	OLGA OSIPOVA	{"email": "olga.osipova-091964@postgrespro.ru", "phone": "+70810639695"}
0005432108323	DB5806	8219 735938	LYUDMILA ANDREEVA	{"phone": "+70750233072"}
0005432108324	DB5806	4281 636775	SERGEY FEDOROV	{"email": "fedorov-s.12021965@postgrespro.ru", "phone": "+70573497765"}
0005432109655	FE1BF4	4728 206381	VIKTOR KISELEV	{"phone": "+70511259599"}
0005432109657	6B9898	4590 643054	LEONID VLASOV	{"email": "leonid-vlasov-1972@postgrespro.ru", "phone": "+70250157435"}
0005432109658	6B9898	8110 615257	ZINAIDA VOROBEVA	{"phone": "+70907834488"}
0005432109659	6B9898	5501 865284	NATALYA MAKSIMOVA	{"phone": "+70123034416"}
0005432109660	A1FBA8	6187 217847	KRISTINA ANDREEVA	{"email": "andreeva-k_17011989@postgrespro.ru", "phone": "+70051038894"}
0005432109661	B3DA16	7938 334786	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.1970@postgrespro.ru", "phone": "+70891197799"}
0005432109662	EB7966	1778 005210	ASKAR IVANOV	{"email": "a-ivanov.27031974@postgrespro.ru", "phone": "+70816203828"}
0005432109663	02436C	0602 819065	ELMIRA KUZNECOVA	{"email": "kuznecova-elmira_1964@postgrespro.ru", "phone": "+70029348955"}
0005432109664	E987FE	2730 450023	NADEZHDA SERGEEVA	{"phone": "+70272446781"}
0005432109665	E987FE	7790 129870	VLADIMIR ANDREEV	{"email": "vladimir.andreev_1976@postgrespro.ru", "phone": "+70099159435"}
0005432109666	E987FE	9635 915243	SERGEY VOLKOV	{"email": "volkov_s.1974@postgrespro.ru", "phone": "+70073337677"}
0005432109667	E987FE	0549 586809	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir-1972@postgrespro.ru", "phone": "+70425541244"}
0005432109668	8F4195	0738 085813	YANA MOROZOVA	{"email": "morozova_y-08081966@postgrespro.ru", "phone": "+70121782098"}
0005432109669	83B02D	2798 644554	SERGEY VOLKOV	{"phone": "+70582970536"}
0005432109670	4CF2FB	4547 431147	ALEKSEY KAZAKOV	{"phone": "+70691341262"}
0005432109671	6EC756	0225 712698	VALENTINA FILATOVA	{"email": "filatovav-11111964@postgrespro.ru", "phone": "+70124830666"}
0005432109672	B68D23	3821 315019	ILDAR BORISOV	{"email": "i-borisov_1989@postgrespro.ru", "phone": "+70958804775"}
0005432109673	B68D23	9570 431114	GALINA RODIONOVA	{"phone": "+70616561768"}
0005432109674	B68D23	9781 208623	TATYANA ZOTOVA	{"phone": "+70304454308"}
0005432109675	1BDD65	2533 945891	LUIZA DAVYDOVA	{"phone": "+70945330257"}
0005432109676	1BDD65	7433 621818	NATALYA FADEEVA	{"email": "nfadeeva.20021979@postgrespro.ru", "phone": "+70663977924"}
0005432109677	8F984E	3901 098302	FAINA DANILOVA	{"phone": "+70726700695"}
0005432109678	D63CDE	4409 945962	KLAVDIYA IVANOVA	{"email": "ivanova.klavdiya22101988@postgrespro.ru", "phone": "+70527833287"}
0005432109679	629A43	3614 058622	VALENTINA SAVELEVA	{"email": "savelevav.071979@postgrespro.ru", "phone": "+70828024341"}
0005432109680	D513D5	7574 353422	IVAN IVANOV	{"email": "ivan.ivanov_091976@postgrespro.ru", "phone": "+70919401639"}
0005432109681	050463	6359 508099	VLADIMIR ZAKHAROV	{"phone": "+70145854481"}
0005432109682	B4AFD6	9113 238089	TATYANA ARKHIPOVA	{"phone": "+70311763487"}
0005432109683	B97006	3855 914142	NIKOLAY SOROKIN	{"email": "nikolay-sorokin.071960@postgrespro.ru", "phone": "+70419690683"}
0005432109684	4F5C80	0826 064843	SERGEY IVANOV	{"phone": "+70632932680"}
0005432109685	58CD79	7664 573356	VARVARA ALEKSEEVA	{"email": "valekseeva101975@postgrespro.ru", "phone": "+70049438508"}
0005432109686	DC9E33	0148 945675	ANTON ZAYCEV	{"phone": "+70953514183"}
0005432109687	D8DD07	2945 639749	VLADIMIR VOROBEV	{"phone": "+70021903216"}
0005432109688	7A2484	3327 701293	SERGEY SMIRNOV	{"phone": "+70793808709"}
0005432109689	41F909	1495 888680	ELVIRA BARANOVA	{"phone": "+70710736937"}
0005432109690	41F909	2823 699786	YULIYA BELYAEVA	{"email": "yuliyabelyaeva.121967@postgrespro.ru", "phone": "+70404005336"}
0005432109691	86BBBD	0681 708949	NINA NIKOLAEVA	{"phone": "+70349833357"}
0005432109692	86BBBD	5291 760271	RAISA TIMOFEEVA	{"email": "raisa-timofeeva111967@postgrespro.ru", "phone": "+70663650621"}
0005432109693	86BBBD	6583 979001	ALEKSANDR KULIKOV	{"phone": "+70998140400"}
0005432109694	0AE257	3329 728501	NATALYA KUDRYASHOVA	{"phone": "+70571092918"}
0005432109695	0AE257	1573 137897	YURIY FOMIN	{"phone": "+70589384394"}
0005432109696	1B42DF	8256 492258	RUSLAN NAUMOV	{"email": "r_naumov.1968@postgrespro.ru", "phone": "+70831091933"}
0005432109697	4A2CFE	4244 078143	ANDREY ISAEV	{"email": "aisaev.21041981@postgrespro.ru", "phone": "+70542773816"}
0005432109698	0DBE13	5656 649812	EVGENIY BELOV	{"phone": "+70823830566"}
0005432109699	0DBE13	6581 151096	VLADIMIR AFANASEV	{"email": "afanasevvladimir_28121973@postgrespro.ru", "phone": "+70380095860"}
0005432109700	540F42	9731 037188	VERA FEDOROVA	{"email": "fedorova_v.1978@postgrespro.ru", "phone": "+70223270775"}
0005432109701	015E0D	4218 746935	SERGEY ANTONOV	{"email": "santonov1971@postgrespro.ru", "phone": "+70082577503"}
0005432109702	514121	1124 285909	VYACHESLAV KOZLOV	{"email": "vyacheslav_kozlov121971@postgrespro.ru", "phone": "+70315225634"}
0005432109703	97AC0B	5096 194027	NATALYA SCHERBAKOVA	{"phone": "+70778899169"}
0005432109704	3FB452	5711 712473	SABINA EFIMOVA	{"phone": "+70038886077"}
0005432109705	3C40E6	0266 689999	YURIY KRASNOV	{"email": "krasnov-yuriy-1977@postgrespro.ru", "phone": "+70264576534"}
0005432109706	63EC94	2683 158966	OLGA ARKHIPOVA	{"phone": "+70957681872"}
0005432109707	8DE7A0	9266 571274	ALEKSANDR POPOV	{"email": "aleksandr_popov1977@postgrespro.ru", "phone": "+70862779862"}
0005432109708	01C3FC	9686 889278	TATYANA ANISIMOVA	{"phone": "+70573382780"}
0005432109709	DC03E3	0155 852100	LYUDMILA BELYAEVA	{"email": "belyaeva.l_04091975@postgrespro.ru", "phone": "+70288502398"}
0005432109710	DC03E3	5873 840054	SVETLANA NOVIKOVA	{"email": "novikova_s1962@postgrespro.ru", "phone": "+70950486115"}
0005432109711	1410DA	9933 969984	MAKSIM SHEVCHENKO	{"phone": "+70956353035"}
0005432109712	1410DA	2606 776942	YULIYA MOROZOVA	{"email": "yuliya_morozova.16101972@postgrespro.ru", "phone": "+70401044329"}
0005432109713	350741	5772 790840	VERA EFREMOVA	{"email": "v_efremova_1975@postgrespro.ru", "phone": "+70922284241"}
0005432109714	350741	8009 940324	SERGEY KUZMIN	{"email": "kuzmin-sergey-22081967@postgrespro.ru", "phone": "+70672873466"}
0005432109715	350741	1001 956621	MARIYA VASILEVA	{"email": "vasileva-m1964@postgrespro.ru", "phone": "+70375324656"}
0005432109716	EA84FA	7794 192271	ALEKSEY SOKOLOV	{"email": "sokolov-a-1968@postgrespro.ru", "phone": "+70394019849"}
0005432109717	EA84FA	1351 838018	SERGEY NIKITIN	{"phone": "+70732010401"}
0005432109718	1DBC19	0290 919906	EVGENIY YAKOVLEV	{"phone": "+70223107420"}
0005432109719	7960BF	3114 939451	VERA ANTONOVA	{"email": "vera.antonova-07111980@postgrespro.ru", "phone": "+70771443845"}
0005432109720	2E857F	5618 403077	ANNA LOGINOVA	{"email": "loginova_anna11101971@postgrespro.ru", "phone": "+70569718116"}
0005432109721	66E937	9793 674299	PAVEL ZAKHAROV	{"phone": "+70360550435"}
0005432109722	FF09FA	4268 981300	ANDREY POPOV	{"email": "popov_a_13111980@postgrespro.ru", "phone": "+70940032152"}
0005432109723	47CDA2	8272 909670	PETR NOVIKOV	{"email": "p_novikov-1969@postgrespro.ru", "phone": "+70070105162"}
0005432109724	47CDA2	8550 524075	VARVARA PAVLOVA	{"email": "varvarapavlova.011974@postgrespro.ru", "phone": "+70099988760"}
0005432109725	7F8A2C	1661 903990	ANDREY KOROLEV	{"email": "korolev_a.061987@postgrespro.ru", "phone": "+70076654531"}
0005432109726	7A7A0F	9649 629229	VYACHESLAV IVANOV	{"email": "ivanov.vyacheslav.111959@postgrespro.ru", "phone": "+70773936707"}
0005432109727	7A7A0F	3232 954924	NATALYA KOZLOVA	{"email": "kozlovanatalya-011973@postgrespro.ru", "phone": "+70163501843"}
0005432109728	5E11D4	3754 162513	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev_16061971@postgrespro.ru", "phone": "+70699997846"}
0005432109729	C8D6D8	6123 730553	IGOR BORISOV	{"email": "iborisov.101973@postgrespro.ru", "phone": "+70916436264"}
0005432109730	C8D6D8	0289 408891	ELENA ERMAKOVA	{"email": "ermakova_elena.061982@postgrespro.ru", "phone": "+70035993814"}
0005432109731	1D18B6	9059 427785	NATALYA ALEKSANDROVA	{"email": "aleksandrova-n1956@postgrespro.ru", "phone": "+70817163984"}
0005432109732	ED3AB7	4928 572378	YURIY PETROV	{"phone": "+70545176440"}
0005432109733	ED3AB7	4057 198833	SVETLANA DMITRIEVA	{"phone": "+70049321626"}
0005432109734	DF213C	1001 000312	LYUDMILA MAKSIMOVA	{"email": "maksimova-lyudmila_03031979@postgrespro.ru", "phone": "+70890338529"}
0005432109735	DF213C	2175 286160	ARTEM KOROLEV	{"phone": "+70914951070"}
0005432109736	B13224	5400 306370	TAISIYA NAZAROVA	{"phone": "+70857550668"}
0005432109737	A398F1	6544 658861	LARISA ALEKSEEVA	{"email": "alekseeva_larisa_1976@postgrespro.ru", "phone": "+70180827831"}
0005432109738	A398F1	3858 700382	VLADIMIR MAKSIMOV	{"phone": "+70178841170"}
0005432109739	13B1A6	3049 452578	NINA DANILOVA	{"email": "ndanilova1974@postgrespro.ru", "phone": "+70258327895"}
0005432109740	13B1A6	3699 128031	EKATERINA ALEKSEEVA	{"email": "e_alekseeva-1973@postgrespro.ru", "phone": "+70823557309"}
0005432109741	837FC5	7466 019074	SVETLANA ORLOVA	{"phone": "+70959986693"}
0005432109742	837FC5	1832 508981	SVETLANA KUDRYASHOVA	{"phone": "+70296344953"}
0005432109743	4924C6	9801 259350	ZINAIDA DMITRIEVA	{"email": "dmitrieva-z021964@postgrespro.ru", "phone": "+70024183427"}
0005432109744	4924C6	8997 823338	EKATERINA MOROZOVA	{"phone": "+70338864817"}
0005432109745	DF5ACF	9677 849764	ANTONINA FEDOROVA	{"email": "antonina.fedorova.041963@postgrespro.ru", "phone": "+70350152832"}
0005432109746	760B0F	5261 715447	YURIY PAVLOV	{"phone": "+70292221582"}
0005432109747	760B0F	9971 390222	ANTON PETROV	{"email": "a_petrov_011964@postgrespro.ru", "phone": "+70182000839"}
0005432109748	0C65ED	4917 475894	ANTONINA MAKSIMOVA	{"email": "a-maksimova_26111978@postgrespro.ru", "phone": "+70602258214"}
0005432109749	0C65ED	4518 410867	ARTEM GAVRILOV	{"phone": "+70414278827"}
0005432109750	8CBDCC	6607 620808	VYACHESLAV FROLOV	{"email": "frolovvyacheslav-09051963@postgrespro.ru", "phone": "+70159251221"}
0005432109751	B94016	8639 063812	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr-1975@postgrespro.ru", "phone": "+70814937276"}
0005432109752	B94016	4414 761840	ALEKSANDR ZAKHAROV	{"phone": "+70626488428"}
0005432109753	5F6526	1658 965876	YULIYA MARTYNOVA	{"email": "martynovay.1975@postgrespro.ru", "phone": "+70248468625"}
0005432109754	5F6526	7186 443784	ANNA YUDINA	{"phone": "+70748788176"}
0005432109755	5F6526	9551 615458	ALEKSANDR ZAKHAROV	{"email": "azakharov_1968@postgrespro.ru", "phone": "+70266505243"}
0005432109756	696ABE	5476 578529	IRINA SEMENOVA	{"phone": "+70697272046"}
0005432109757	53A00A	2292 616392	RINAT IVANOV	{"email": "ivanov_r-25051973@postgrespro.ru", "phone": "+70968866599"}
0005432109758	53A00A	5747 336558	YULIYA KOVALEVA	{"phone": "+70151227720"}
0005432109759	A57BAF	0602 959145	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr1960@postgrespro.ru", "phone": "+70979153336"}
0005432109760	42F4AB	0423 484820	IGOR PETROV	{"phone": "+70364573076"}
0005432109761	9CAFB4	7877 247656	ANASTASIYA NIKOLAEVA	{"phone": "+70330299369"}
0005432109762	E3D44E	7830 457801	IRINA EFIMOVA	{"phone": "+70362133490"}
0005432109763	8A754D	0407 015675	NADEZHDA ZAYCEVA	{"phone": "+70978093213"}
0005432109764	1822AD	8396 181440	YURIY PAVLOV	{"phone": "+70398134745"}
0005432109765	1822AD	8616 209461	MAKSIM OSIPOV	{"phone": "+70811464853"}
0005432109766	F7C487	2893 166272	SVETLANA ISAEVA	{"email": "svetlana.isaeva.1978@postgrespro.ru", "phone": "+70877424730"}
0005432109767	FA9FF3	3044 849903	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrovae_22081977@postgrespro.ru", "phone": "+70244532312"}
0005432109768	FA9FF3	1324 736253	GALINA GUSEVA	{"phone": "+70445136078"}
0005432109769	1A2D63	2467 887009	OKSANA POPOVA	{"phone": "+70563539401"}
0005432109770	1A2D63	6500 757952	SERGEY IVANOV	{"phone": "+70795224316"}
0005432109771	BC5BD1	4917 302935	ALEKSEY IVANOV	{"email": "aleksey.ivanov111964@postgrespro.ru", "phone": "+70171433318"}
0005432109772	E4CB62	7840 173491	YULIYA IVANOVA	{"email": "yuliya-ivanova.10051966@postgrespro.ru", "phone": "+70183517286"}
0005432109773	F1974D	6528 065969	ANTONINA SAVELEVA	{"phone": "+70187109223"}
0005432109774	BDEDAD	6202 008978	NIKOLAY GAVRILOV	{"phone": "+70036938576"}
0005432109775	A5FF4C	1943 680390	VASILIY CHERNOV	{"email": "vchernov-15011972@postgrespro.ru", "phone": "+70024539892"}
0005432109776	9D481A	7750 820910	EKATERINA MAKAROVA	{"email": "makarovae041968@postgrespro.ru", "phone": "+70845127250"}
0005432109777	A51462	6534 904367	MARIYA BARANOVA	{"email": "baranova_mariya27021968@postgrespro.ru", "phone": "+70716085599"}
0005432109778	A51462	5401 407812	GRIGORIY FEDOTOV	{"phone": "+70639323082"}
0005432109779	42B73B	8764 881837	DENIS KUZNECOV	{"email": "kuznecov-d_111972@postgrespro.ru", "phone": "+70651543919"}
0005432109780	4689CD	4855 754024	EKATERINA KUZNECOVA	{"phone": "+70013604373"}
0005432109781	1F3D23	0317 822023	ULYANA KOZLOVA	{"email": "ulyanakozlova041970@postgrespro.ru", "phone": "+70128989318"}
0005432109782	1F3D23	5223 522673	MIKHAIL MARTYNOV	{"phone": "+70569246282"}
0005432109783	51FF2D	9073 654106	ANDREY PETROV	{"phone": "+70834731223"}
0005432111225	4B11F2	8359 461188	NATALYA LUKYANOVA	{"email": "lukyanova_natalya1973@postgrespro.ru", "phone": "+70388196257"}
0005432111226	00EB0D	6215 313275	EVGENIY ROMANOV	{"email": "romanov_evgeniy08091967@postgrespro.ru", "phone": "+70077587266"}
0005432111227	80F535	5567 732898	ELENA AKIMOVA	{"email": "elena_akimova-1973@postgrespro.ru", "phone": "+70097320525"}
0005432111228	AA4E31	8045 052749	MARIYA IVANOVA	{"email": "mariyaivanova04021986@postgrespro.ru", "phone": "+70228845468"}
0005432111229	AA4E31	8544 963460	IRINA POPOVA	{"phone": "+70407181481"}
0005432111230	7F5B4C	0236 124948	PAVEL DENISOV	{"email": "pdenisov.06051973@postgrespro.ru", "phone": "+70123990564"}
0005432111231	796670	4918 967830	GEORGIY ANTONOV	{"email": "georgiy-antonov091983@postgrespro.ru", "phone": "+70560091824"}
0005432111232	0893FC	7301 966694	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov.1964@postgrespro.ru", "phone": "+70940547816"}
0005432111233	0893FC	3586 448734	VLADIMIR TIKHONOV	{"email": "vladimir.tikhonov.08051971@postgrespro.ru", "phone": "+70953612779"}
0005432111234	4402FB	3744 262384	LYUDMILA GAVRILOVA	{"email": "gavrilova_l071960@postgrespro.ru", "phone": "+70534931263"}
0005432111235	4402FB	8984 637532	MAKSIM ALEKSEEV	{"email": "alekseev.m081976@postgrespro.ru", "phone": "+70273216870"}
0005432111236	3BB67A	0211 186282	TATYANA NAZAROVA	{"email": "nazarova-t.101981@postgrespro.ru", "phone": "+70815219234"}
0005432111237	A8E89F	3209 580433	TATYANA IVANOVA	{"email": "t_ivanova_30061980@postgrespro.ru", "phone": "+70682669176"}
0005432111238	F36DF0	1685 817139	ARTEM IVANOV	{"phone": "+70032679383"}
0005432111239	44F865	2670 198206	IGOR GUSEV	{"phone": "+70194576123"}
0005432111240	44F865	3430 268957	MIKHAIL NIKITIN	{"email": "mikhail.nikitin11071974@postgrespro.ru", "phone": "+70520152395"}
0005432111241	14B7C2	4456 815969	ARMEN AFANASEV	{"phone": "+70259238157"}
0005432111242	EE0CEE	7322 553855	ALEKSANDR KISELEV	{"phone": "+70835258544"}
0005432111243	63C597	3386 536937	ALEKSEY KAZAKOV	{"phone": "+70675499984"}
0005432111244	63C597	3217 003896	ANGELINA KULIKOVA	{"email": "angelina_kulikova-1964@postgrespro.ru", "phone": "+70553272020"}
0005432111245	25788D	7223 190215	ZOYA MIKHAYLOVA	{"email": "mikhaylovaz031977@postgrespro.ru", "phone": "+70214462828"}
0005432111246	A8BE1F	5024 531177	KSENIYA ANTONOVA	{"email": "kseniya.antonova.1979@postgrespro.ru", "phone": "+70385030318"}
0005432111247	A8BE1F	8367 462033	GALINA ANDREEVA	{"email": "galina_andreeva1968@postgrespro.ru", "phone": "+70597424663"}
0005432111248	1C8FE0	2135 391317	YURIY SMIRNOV	{"email": "y.smirnov-1971@postgrespro.ru", "phone": "+70329729596"}
0005432111249	6BD49C	4804 748047	VALENTINA MOROZOVA	{"email": "valentina.morozova-1969@postgrespro.ru", "phone": "+70913608944"}
0005432111250	437030	7118 287032	ELENA SIDOROVA	{"phone": "+70325841773"}
0005432111251	437030	6331 497488	SERGEY MEDVEDEV	{"email": "sergey_medvedev.30111969@postgrespro.ru", "phone": "+70741883572"}
0005432111252	D7D4EE	1150 876734	EVGENIYA ANDREEVA	{"phone": "+70456719015"}
0005432111253	D7D4EE	9019 663438	YULIYA MIRONOVA	{"phone": "+70824484721"}
0005432111254	C9FB2A	4044 172000	SVETLANA PETROVA	{"phone": "+70472260090"}
0005432111255	7E6C2D	0555 962379	YULIYA VOROBEVA	{"email": "vorobeva.y-05021982@postgrespro.ru", "phone": "+70848339204"}
0005432111256	7E6C2D	6424 205458	VERA KARPOVA	{"email": "vkarpova1967@postgrespro.ru", "phone": "+70743548823"}
0005432111257	92B696	2978 491388	ROZA DMITRIEVA	{"email": "dmitrieva-r-30071965@postgrespro.ru", "phone": "+70439014632"}
0005432111258	92B696	9261 015569	DMITRIY VOLKOV	{"phone": "+70972763838"}
0005432111259	238956	3080 336497	MIKHAIL GAVRILOV	{"phone": "+70875123122"}
0005432111260	A55F83	0850 880131	EVGENIY SERGEEV	{"email": "sergeev_e-051971@postgrespro.ru", "phone": "+70563753629"}
0005432111261	03A029	1782 290942	NATALYA GERASIMOVA	{"phone": "+70770247337"}
0005432111262	03A029	2155 186384	PETR SMIRNOV	{"phone": "+70617920716"}
0005432111263	02960E	1212 203681	YULIYA FOMINA	{"email": "fomina-yuliya-20021971@postgrespro.ru", "phone": "+70737845326"}
0005432111264	02960E	4596 360792	EKATERINA DANILOVA	{"phone": "+70819928467"}
0005432111265	B1752A	2558 100021	MIKHAIL ZAYCEV	{"email": "zaycev_mikhail08041978@postgrespro.ru", "phone": "+70317702040"}
0005432111266	E269A7	9151 339392	VLADIMIR ORLOV	{"email": "vladimir-orlov121970@postgrespro.ru", "phone": "+70340250272"}
0005432111267	6C06DE	6194 482983	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev-23091957@postgrespro.ru", "phone": "+70222368036"}
0005432111268	500E02	9392 714812	MAKSIM POPOV	{"email": "maksim.popov081968@postgrespro.ru", "phone": "+70796952954"}
0005432111269	F29E14	1813 126845	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy-1957@postgrespro.ru", "phone": "+70508627576"}
0005432111270	C8AF37	9540 835569	DANILA KONOVALOV	{"phone": "+70898831746"}
0005432111271	BDB244	3292 489964	VIKTOR KRASNOV	{"email": "krasnov.viktor-31081969@postgrespro.ru", "phone": "+70834363723"}
0005432111272	751CD3	3130 616613	ANDREY OSIPOV	{"email": "osipov-a_31081968@postgrespro.ru", "phone": "+70639491865"}
0005432111273	08AAEE	4556 243273	DANIIL MARTYNOV	{"phone": "+70919344544"}
0005432111274	08AAEE	9455 307878	NINA IVANOVA	{"email": "n_ivanova-1962@postgrespro.ru", "phone": "+70547428031"}
0005432111275	615F5C	2735 028398	VIKTORIYA ANDREEVA	{"email": "v.andreeva.01071977@postgrespro.ru", "phone": "+70427231624"}
0005432111276	615F5C	4811 620603	DMITRIY ANDREEV	{"email": "dmitriy_andreev061970@postgrespro.ru", "phone": "+70671523977"}
0005432111277	615F5C	2792 896965	VENIAMIN NOVIKOV	{"phone": "+70624538249"}
0005432111278	97AA18	2142 313054	OLGA KUZNECOVA	{"email": "olga_kuznecova-07091972@postgrespro.ru", "phone": "+70610499316"}
0005432111279	2F1016	6266 073052	NIKOLAY GUSEV	{"email": "gusev_nikolay_1975@postgrespro.ru", "phone": "+70206330976"}
0005432111280	A19D09	4822 935687	SHAMIL DENISOV	{"email": "denisov.s1974@postgrespro.ru", "phone": "+70726374402"}
0005432111281	A19D09	6378 103433	ANNA FILIPPOVA	{"email": "a-filippova17101969@postgrespro.ru", "phone": "+70401875551"}
0005432111282	9D9ABE	7198 025458	MARIYA ZAYCEVA	{"phone": "+70135254666"}
0005432111283	9D9ABE	7245 470359	ELENA PETROVA	{"email": "petrovae011968@postgrespro.ru", "phone": "+70137715411"}
0005432111284	C39662	6831 359115	ALEKSEY ROMANOV	{"phone": "+70156359473"}
0005432111285	6DE8AB	8692 211687	ALEKSANDR SIDOROV	{"phone": "+70206514862"}
0005432111286	6DE8AB	6958 079380	EKATERINA NIKOLAEVA	{"email": "nikolaeva_ekaterina101970@postgrespro.ru", "phone": "+70596696895"}
0005432111287	31B8C7	3672 149080	IRINA VASILEVA	{"email": "irina_vasileva031959@postgrespro.ru", "phone": "+70419360937"}
0005432111288	3AF2CE	0920 170587	VALENTINA KOMAROVA	{"email": "komarova_v.101986@postgrespro.ru", "phone": "+70684235762"}
0005432111289	69F101	0935 638386	ELIZAVETA BARANOVA	{"phone": "+70280916900"}
0005432111290	69F101	8366 196711	VALERIY ZHUKOV	{"phone": "+70183892636"}
0005432111291	D505DA	7736 381846	LYUBOV RODIONOVA	{"email": "rodionoval111981@postgrespro.ru", "phone": "+70818147918"}
0005432111292	DCA853	7674 314096	ALEKSANDR SERGEEV	{"email": "sergeeva10071970@postgrespro.ru", "phone": "+70547683829"}
0005432111293	DCA853	0492 929371	LARISA STEPANOVA	{"email": "larisa-stepanova.1972@postgrespro.ru", "phone": "+70140055921"}
0005432111294	24AE4C	1924 199619	GALINA VASILEVA	{"email": "galina-vasileva1964@postgrespro.ru", "phone": "+70054116996"}
0005432111295	678843	6064 904499	LIDIYA SOKOLOVA	{"email": "lidiya.sokolova-11011970@postgrespro.ru", "phone": "+70854557624"}
0005432111296	678843	3921 431050	MARIYA IVANOVA	{"phone": "+70236466933"}
0005432111297	3B9F51	8758 105585	NIKOLAY SOROKIN	{"email": "nikolaysorokin061975@postgrespro.ru", "phone": "+70916550704"}
0005432111298	6C10FA	7920 821911	VALENTINA FILIPPOVA	{"phone": "+70460400489"}
0005432111299	6C10FA	6131 703169	ZINAIDA MIRONOVA	{"email": "z_mironova.1972@postgrespro.ru", "phone": "+70128449107"}
0005432111300	5C5D81	7520 988799	ANDREY NOVIKOV	{"phone": "+70553653803"}
0005432111301	79A8FF	3328 050579	ANAIT ISAEVA	{"phone": "+70777726156"}
0005432111302	79A8FF	5536 225297	VYACHESLAV NOVIKOV	{"email": "v-novikov_1972@postgrespro.ru", "phone": "+70494892945"}
0005432111303	AA9ED2	5424 176934	IRINA DENISOVA	{"email": "irina-denisova081976@postgrespro.ru", "phone": "+70908037529"}
0005432111304	3D36C5	8322 883212	NIKOLAY TIKHONOV	{"email": "n-tikhonov1956@postgrespro.ru", "phone": "+70321783600"}
0005432111305	3D36C5	6858 911316	ARTEM PETROV	{"phone": "+70361402969"}
0005432111306	C69B92	5135 933183	ALEKSANDR CHERNOV	{"phone": "+70166914659"}
0005432111307	95CD14	0555 269395	ALEKSEY SHEVCHENKO	{"phone": "+70951539113"}
0005432111308	95CD14	4270 602102	YULIYA VLASOVA	{"email": "vlasovay-18011977@postgrespro.ru", "phone": "+70917428245"}
0005432111309	026156	9285 366217	OLGA STEPANOVA	{"phone": "+70817294335"}
0005432111310	C58BAD	6397 420065	VADIM MIKHAYLOV	{"phone": "+70386776082"}
0005432111311	C58BAD	6690 557220	MIKHAIL ORLOV	{"phone": "+70803290865"}
0005432111312	D53E8B	1859 709017	YAROSLAV PAVLOV	{"phone": "+70299961047"}
0005432111313	7457D8	0871 929877	ALLA STEPANOVA	{"email": "alla.stepanova.1984@postgrespro.ru", "phone": "+70877336620"}
0005432111314	3346B8	7249 751773	VLADIMIR VOLKOV	{"phone": "+70191822167"}
0005432111315	3346B8	0327 517173	VALENTINA SMIRNOVA	{"phone": "+70312358768"}
0005432111316	9B02E6	0496 737229	NATALYA AFANASEVA	{"email": "afanaseva_n-15041974@postgrespro.ru", "phone": "+70722104876"}
0005432111317	9B02E6	7091 306960	ROMAN BORISOV	{"email": "roman.borisov.22081957@postgrespro.ru", "phone": "+70067288146"}
0005432111318	7A27E0	1908 911066	LEONID IVANOV	{"phone": "+70868122389"}
0005432111319	F17D40	7726 838537	EKATERINA PAVLOVA	{"email": "pavlova.ekaterina-21041964@postgrespro.ru", "phone": "+70029594693"}
0005432111320	F17D40	2959 506740	SHAMIL RODIONOV	{"phone": "+70970523223"}
0005432111321	82AB66	4127 900754	YURIY GUSEV	{"email": "yuriygusev23121977@postgrespro.ru", "phone": "+70502302976"}
0005432111322	82AB66	2399 702756	ALEKSEY FROLOV	{"email": "frolov.a-1968@postgrespro.ru", "phone": "+70870379344"}
0005432111323	23628E	6121 240339	GENNADIY TARASOV	{"email": "tarasov_gennadiy-061979@postgrespro.ru", "phone": "+70827142415"}
0005432111324	23628E	6105 907818	TATYANA CHERNOVA	{"phone": "+70668483091"}
0005432111325	DA64C1	8035 952955	NATALYA MAKAROVA	{"email": "n.makarova_13111967@postgrespro.ru", "phone": "+70400514541"}
0005432111326	F2C566	0397 123182	KIRILL MATVEEV	{"email": "matveev_kirill1963@postgrespro.ru", "phone": "+70084446879"}
0005432111327	34406C	7429 641638	GLEB KUZMIN	{"email": "kuzmin_gleb091974@postgrespro.ru", "phone": "+70834487557"}
0005432111328	2056DD	9444 575742	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov_23091975@postgrespro.ru", "phone": "+70159779174"}
0005432111329	0D6521	8631 558573	ANATOLIY AFANASEV	{"email": "anatoliyafanasev_1966@postgrespro.ru", "phone": "+70151459402"}
0005432111330	245B83	9960 444538	IVAN MARTYNOV	{"phone": "+70505770106"}
0005432111331	B6A3F6	9977 369165	ANATOLIY FEDOROV	{"email": "fedorov.anatoliy041972@postgrespro.ru", "phone": "+70661107609"}
0005432111332	1D6AC2	1675 448203	ALEKSANDR BARANOV	{"phone": "+70766575984"}
0005432111333	1D6AC2	1673 187063	NATALYA ANDREEVA	{"phone": "+70578059869"}
0005432111334	EDFA9B	4863 446841	VLADIMIR OSIPOV	{"phone": "+70364514846"}
0005432111335	C875DC	4897 946674	LYUBOV LOGINOVA	{"email": "l-loginova_31081983@postgrespro.ru", "phone": "+70865141046"}
0005432111336	C875DC	7756 520979	NATALYA SOROKINA	{"email": "sorokinan_1977@postgrespro.ru", "phone": "+70680948981"}
0005432111337	CCC7EF	6254 485531	GALINA NIKITINA	{"phone": "+70781336480"}
0005432111338	C00A9D	8333 397350	GALINA TITOVA	{"phone": "+70808577170"}
0005432111339	74605A	0186 276745	NATALYA KOROLEVA	{"phone": "+70941531610"}
0005432111340	74605A	4866 228327	ARTEM KUDRYASHOV	{"email": "a_kudryashov101976@postgrespro.ru", "phone": "+70658698724"}
0005432111341	74605A	1484 599957	IBRAGIM GERASIMOV	{"phone": "+70443604399"}
0005432111342	636D24	1645 539152	VERA POPOVA	{"phone": "+70538272196"}
0005432111343	636D24	7496 780686	KIRILL PETROV	{"email": "petrov_kirill051960@postgrespro.ru", "phone": "+70348706664"}
0005432111344	79523D	4862 685617	ALEKSANDR VLASOV	{"phone": "+70363803483"}
0005432111345	79523D	7886 707785	ANDREY SEMENOV	{"phone": "+70996052305"}
0005432111346	4E05BD	4471 679792	IVAN ZAKHAROV	{"phone": "+70078709214"}
0005432111347	8380FE	1029 506535	GALINA KAZAKOVA	{"phone": "+70821058053"}
0005432111348	DEB18B	7218 425928	SOFYA KOMAROVA	{"phone": "+70688780741"}
0005432111349	90D5A6	7891 790721	DMITRIY ZHUKOV	{"phone": "+70830516049"}
0005432111350	90D5A6	0039 697010	SVETLANA PETROVA	{"phone": "+70595389928"}
0005432111351	90D5A6	9911 799787	MARIYA POTAPOVA	{"email": "m.potapova18101983@postgrespro.ru", "phone": "+70072871242"}
0005432111352	DC3FE7	4051 527462	IRINA FILATOVA	{"phone": "+70359213616"}
0005432111353	51E7AA	8421 286888	LIDIYA NIKOLAEVA	{"phone": "+70228232487"}
0005432111354	1ECA24	7371 169804	ALEKSANDR ISAEV	{"phone": "+70424838110"}
0005432111355	1ECA24	1559 142495	MARIYA PAVLOVA	{"email": "pavlovamariya011956@postgrespro.ru", "phone": "+70022321694"}
0005432111356	C6F059	8403 188744	PAVEL ANTONOV	{"phone": "+70704489566"}
0005432111357	3B2440	7576 534975	ALEKSANDR ANDREEV	{"email": "a_andreev-111975@postgrespro.ru", "phone": "+70307948593"}
0005432111358	3B2440	6676 316395	NATALYA EGOROVA	{"phone": "+70122299273"}
0005432111359	94D66E	9268 496089	ALEKSEY IVANOV	{"phone": "+70754236281"}
0005432111360	94D66E	0149 783173	IRINA TIMOFEEVA	{"phone": "+70200866646"}
0005432111361	B87008	2907 691213	ZOYA ARKHIPOVA	{"phone": "+70022295473"}
0005432111362	B87008	5071 947671	ANTONINA FADEEVA	{"email": "fadeeva-antonina11121970@postgrespro.ru", "phone": "+70029826911"}
0005432111363	A3CE59	7640 412265	ELENA DAVYDOVA	{"email": "davydova.elena-28041975@postgrespro.ru", "phone": "+70215803681"}
0005432111364	8396C3	0282 086860	EKATERINA YUDINA	{"phone": "+70575146005"}
0005432111365	8396C3	5165 902373	OKSANA NIKOLAEVA	{"email": "oksana_nikolaeva081965@postgrespro.ru", "phone": "+70471257932"}
0005432111366	72556F	1529 573064	STANISLAV BORISOV	{"email": "stanislav.borisov_1965@postgrespro.ru", "phone": "+70525895719"}
0005432111367	E888F2	6376 500632	YULIYA MOROZOVA	{"phone": "+70479086598"}
0005432111368	E888F2	5990 968984	PAVEL DMITRIEV	{"phone": "+70262527572"}
0005432111369	E888F2	6708 361137	IVAN KARPOV	{"email": "karpov-ivan.041967@postgrespro.ru", "phone": "+70100788001"}
0005432112475	F62F13	4374 308883	OLGA MELNIKOVA	{"phone": "+70831518775"}
0005432112476	F62F13	8322 793872	VIKTORIYA FROLOVA	{"email": "frolova_viktoriya.21071972@postgrespro.ru", "phone": "+70541397928"}
0005432112477	B5E135	2071 925578	YULIYA BORISOVA	{"email": "yuliya.borisova_101966@postgrespro.ru", "phone": "+70644369728"}
0005432112478	CEF158	4325 686617	TATYANA ORLOVA	{"email": "torlova1976@postgrespro.ru", "phone": "+70854904299"}
0005432112479	CEF158	6985 047823	MARIYA VOLKOVA	{"email": "volkova.m04011987@postgrespro.ru", "phone": "+70748107911"}
0005432112480	1F5F92	1857 899906	NATALIYA ANTONOVA	{"phone": "+70615941061"}
0005432112481	1F5F92	1416 549527	KLAVDIYA TITOVA	{"phone": "+70240264250"}
0005432112482	2E8E88	8448 808081	GALINA FOMINA	{"email": "fominagalina_1972@postgrespro.ru", "phone": "+70020691331"}
0005432112483	004A54	7659 357347	ELENA STEPANOVA	{"email": "stepanovaelena.1974@postgrespro.ru", "phone": "+70048460967"}
0005432112484	A0B995	3472 806362	ALEKSANDR ZHUKOV	{"email": "zhukov.aleksandr28091970@postgrespro.ru", "phone": "+70655788303"}
0005432112485	A0B995	8271 709090	DARYA EGOROVA	{"email": "egorovad.061971@postgrespro.ru", "phone": "+70788528519"}
0005432112486	EEE85B	1063 974175	SERGEY ZAYCEV	{"phone": "+70625140864"}
0005432112487	8CEA85	9109 138679	VALERIY SCHERBAKOV	{"email": "v_scherbakov-111972@postgrespro.ru", "phone": "+70132694542"}
0005432112488	8CEA85	1796 692996	OLGA SIDOROVA	{"phone": "+70170517695"}
0005432112489	D35E24	3509 638574	NATALYA ORLOVA	{"email": "natalyaorlova_30081982@postgrespro.ru", "phone": "+70743371956"}
0005432112490	946F70	6447 650363	SERGEY FEDOROV	{"phone": "+70462560313"}
0005432112491	946F70	8993 134367	ARSENIY BARANOV	{"phone": "+70844653915"}
0005432112492	3EF0C6	2199 531063	ALEKSANDR POPOV	{"phone": "+70629274122"}
0005432112493	5D1650	4867 643263	ELENA ZAKHAROVA	{"email": "zakharovae.1979@postgrespro.ru", "phone": "+70565461645"}
0005432112494	E9C80C	2946 339135	MARGARITA NIKOLAEVA	{"email": "nikolaeva-margarita_1967@postgrespro.ru", "phone": "+70493452582"}
0005432112495	E9C80C	1383 180733	ALEKSANDR MIKHAYLOV	{"phone": "+70695238877"}
0005432112496	B30515	3251 813874	VALENTINA LEBEDEVA	{"phone": "+70000343934"}
0005432112497	25F70F	7122 314385	ALEKSANDR MAKSIMOV	{"phone": "+70821828140"}
0005432112498	57E2D3	0465 483127	ALEKSANDR MAKAROV	{"phone": "+70311335373"}
0005432112499	156304	2129 565489	OLGA NESTEROVA	{"phone": "+70248756897"}
0005432112500	F24CD7	3816 810751	DMITRIY SAVELEV	{"phone": "+70094244661"}
0005432112501	AD7440	3425 823204	ERIK KISELEV	{"phone": "+70773227165"}
0005432112502	79FD5A	1115 621036	YULIYA ZHURAVLEVA	{"phone": "+70406237126"}
0005432112503	D712C3	3839 005489	MARIYA KUZNECOVA	{"phone": "+70626977695"}
0005432112504	07F832	5495 273763	VENIAMIN GRIGOREV	{"email": "grigorev.v.05071980@postgrespro.ru", "phone": "+70938101308"}
0005432112505	07F832	9725 254566	OLEG FEDOROV	{"email": "olegfedorov041972@postgrespro.ru", "phone": "+70821466766"}
0005432112506	1F50F0	2823 880556	IRINA OSIPOVA	{"email": "i.osipova26021961@postgrespro.ru", "phone": "+70336057651"}
0005432112507	407F49	2535 385858	NADEZHDA IVANOVA	{"email": "nadezhdaivanova.031969@postgrespro.ru", "phone": "+70634009024"}
0005432112508	9269F9	3315 941566	LYUDMILA ILINA	{"email": "lyudmilailina03011982@postgrespro.ru", "phone": "+70068421062"}
0005432112509	9269F9	0319 405741	LIDIYA FEDOROVA	{"phone": "+70159524457"}
0005432112510	8FBA44	6738 405895	RITA SIDOROVA	{"email": "rita-sidorova-021974@postgrespro.ru", "phone": "+70941013137"}
0005432112511	AFF5E9	6153 000477	ALEKSANDR ANTONOV	{"phone": "+70847517527"}
0005432112512	AFF5E9	4724 758257	STANISLAV ZAYCEV	{"phone": "+70656499169"}
0005432112513	0ADFCD	1834 929035	LYUBOV POPOVA	{"phone": "+70907558233"}
0005432112514	B1B102	2033 620070	OLGA KUZNECOVA	{"phone": "+70469320145"}
0005432112515	B1B102	9245 299100	LILIYA ISAEVA	{"phone": "+70827817982"}
0005432112516	296B3E	2796 065424	ALEKSEY ZAYCEV	{"phone": "+70886018748"}
0005432112517	296B3E	9811 032864	VALERIY MOISEEV	{"email": "valeriy_moiseev031971@postgrespro.ru", "phone": "+70828336594"}
0005432112518	E57D09	5368 920630	OLGA KOROLEVA	{"phone": "+70960795073"}
0005432112519	E57D09	6057 098577	ALEKSANDR VOROBEV	{"phone": "+70047816877"}
0005432112520	9E839A	2433 797977	ALEKSANDR NAUMOV	{"phone": "+70155253159"}
0005432112521	DC1026	1010 119188	IRINA NESTEROVA	{"email": "nesterova-i011970@postgrespro.ru", "phone": "+70341997874"}
0005432112522	68D885	9993 443523	NADEZHDA POPOVA	{"phone": "+70798854731"}
0005432112523	9CA592	2188 799644	VALENTINA SIDOROVA	{"email": "vsidorova091959@postgrespro.ru", "phone": "+70619993348"}
0005432112524	9CA592	5661 316298	VALERIY BONDARENKO	{"phone": "+70395535785"}
0005432112525	DEC821	5768 798774	VITALIY ILIN	{"phone": "+70395341920"}
0005432112526	7C0238	1183 073061	LYUBOV DANILOVA	{"phone": "+70617702261"}
0005432112527	7B9E02	9507 415364	VIKTOR DMITRIEV	{"email": "viktor.dmitriev031965@postgrespro.ru", "phone": "+70848951381"}
0005432112528	7B9E02	7158 171175	IVAN MAKSIMOV	{"phone": "+70905612899"}
0005432112529	09A665	4727 284946	KIRILL IVANOV	{"phone": "+70888615207"}
0005432112530	C8C1E3	6398 090337	MARIYA DENISOVA	{"email": "denisova.m091981@postgrespro.ru", "phone": "+70991063898"}
0005432112531	CB544C	6762 112115	MARIYA DENISOVA	{"phone": "+70134334143"}
0005432112532	CB544C	5321 381305	ARTEM KUZNECOV	{"phone": "+70843745956"}
0005432112533	5B68B2	5965 803217	MARIYA GRISHINA	{"email": "grishina.m-29071972@postgrespro.ru", "phone": "+70179830810"}
0005432112534	5B68B2	6695 536028	ILGIZ BARANOV	{"email": "baranovilgiz_1979@postgrespro.ru", "phone": "+70925494648"}
0005432112535	3F0F5E	3727 536738	ALEKSANDR TARASOV	{"phone": "+70941780676"}
0005432112536	79B93B	4423 177742	VALENTINA KRASNOVA	{"email": "krasnovavalentina_101973@postgrespro.ru", "phone": "+70093630797"}
0005432112537	79B93B	6865 678921	IVAN NIKOLAEV	{"email": "nikolaev.i_091967@postgrespro.ru", "phone": "+70508069191"}
0005432112538	4EA8F1	9002 649733	ILDUS VOLKOV	{"phone": "+70354514586"}
0005432112539	403D55	6516 697966	ANTONINA ROMANOVA	{"phone": "+70198414487"}
0005432112540	CD264C	5379 728535	INNA VASILEVA	{"phone": "+70243076916"}
0005432112541	A8654C	7675 068862	NATALYA GAVRILOVA	{"email": "gavrilova.natalya1976@postgrespro.ru", "phone": "+70161276960"}
0005432112542	DBD3A3	5360 199506	ANDREY FILIPPOV	{"phone": "+70139912943"}
0005432112543	74F785	4803 646124	TATYANA BOGDANOVA	{"email": "bogdanovat-101971@postgrespro.ru", "phone": "+70207289880"}
0005432112544	89ED11	8579 608821	NIKOLAY AFANASEV	{"email": "nafanasev-1968@postgrespro.ru", "phone": "+70736029601"}
0005432112545	89ED11	8257 040633	IRINA AKIMOVA	{"email": "i-akimova.1971@postgrespro.ru", "phone": "+70568468313"}
0005432112546	2F19C3	6225 252658	ELENA KONDRATEVA	{"phone": "+70396249788"}
0005432112547	2F19C3	3242 305642	LEONTIY MATVEEV	{"email": "matveevleontiy-04021977@postgrespro.ru", "phone": "+70912698553"}
0005432112548	86C3DC	8842 320673	ANDREY ZAYCEV	{"email": "azaycev_1973@postgrespro.ru", "phone": "+70147553684"}
0005432112549	86C3DC	6215 919250	EKATERINA KOROLEVA	{"email": "koroleva_ekaterina-121983@postgrespro.ru", "phone": "+70594005743"}
0005432112550	3E6ACF	8775 569664	ANTONINA FILATOVA	{"email": "afilatova-101984@postgrespro.ru", "phone": "+70683671456"}
0005432112551	6156A0	1837 318311	NATALYA VOLKOVA	{"email": "volkova.natalya.071969@postgrespro.ru", "phone": "+70693820638"}
0005432112552	3CF7C9	5304 716074	ANATOLIY KOROLEV	{"phone": "+70830737015"}
0005432112553	233FFD	3374 461671	GALINA NIKIFOROVA	{"phone": "+70119925827"}
0005432112554	D98EE7	3332 104575	VERA OSIPOVA	{"email": "vera_osipova021986@postgrespro.ru", "phone": "+70461943958"}
0005432112555	D98EE7	0026 555394	PAVEL SEMENOV	{"phone": "+70435094832"}
0005432112556	ED368F	8012 768848	ELENA ANTONOVA	{"phone": "+70290647872"}
0005432112557	BA6756	8012 687084	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_n-24081970@postgrespro.ru", "phone": "+70962496444"}
0005432112558	7BAFD9	9686 524223	PETR SCHERBAKOV	{"phone": "+70022819840"}
0005432112559	D84329	9733 038577	LYUDMILA AFANASEVA	{"email": "afanaseva_lyudmila-23011968@postgrespro.ru", "phone": "+70441935346"}
0005432112560	9DFBBF	2880 560749	DARYA SAVELEVA	{"email": "darya.saveleva_1977@postgrespro.ru", "phone": "+70907255693"}
0005432112561	9DFBBF	1103 732253	ARINA POPOVA	{"email": "arina.popova.071974@postgrespro.ru", "phone": "+70755179369"}
0005432112562	9DFF3D	4190 357678	VALERIY KUZMIN	{"email": "valeriy.kuzmin_121976@postgrespro.ru", "phone": "+70062904209"}
0005432112563	32D52B	7694 416139	TATYANA SCHERBAKOVA	{"email": "scherbakovat_041970@postgrespro.ru", "phone": "+70307484304"}
0005432112564	5A5318	4773 357869	LYUBOV MARTYNOVA	{"email": "l.martynova_031979@postgrespro.ru", "phone": "+70934175905"}
0005432112565	5A5318	0573 299120	ELENA MATVEEVA	{"email": "matveeva-e.1986@postgrespro.ru", "phone": "+70522148625"}
0005432112566	D18AB9	3639 817706	LYUBOV KUZNECOVA	{"phone": "+70343019919"}
0005432112567	BDE5F6	2334 688190	GALINA POPOVA	{"phone": "+70411457552"}
0005432112568	2A5CC4	1420 217232	MARIYA YAKOVLEVA	{"phone": "+70901377837"}
0005432112569	2A5CC4	0001 020479	NIKOLAY MOROZOV	{"phone": "+70659834057"}
0005432112570	9C1B6E	9312 094719	ALEKSANDR KOZLOV	{"phone": "+70863807440"}
0005432112571	9C1B6E	3735 486328	NATALYA GRISHINA	{"phone": "+70379457970"}
0005432112572	EADF49	8734 862848	ANASTASIYA PAVLOVA	{"email": "a-pavlova_15061978@postgrespro.ru", "phone": "+70064069972"}
0005432112573	C4E0E6	0146 523689	ALEKSANDR STEPANOV	{"email": "stepanov.a_1995@postgrespro.ru", "phone": "+70571479858"}
0005432112574	C4E0E6	4569 772075	NAILYA GORBUNOVA	{"phone": "+70961110343"}
0005432112575	68A0E6	6129 828751	ILYAS KISELEV	{"email": "kiselevilyas-24051977@postgrespro.ru", "phone": "+70057614977"}
0005432112576	C96E48	0165 025749	NIKOLAY MELNIKOV	{"email": "nmelnikov_121958@postgrespro.ru", "phone": "+70922898592"}
0005432112577	E2AF4E	9600 025869	NATALIYA BARANOVA	{"email": "nataliya.baranova-031960@postgrespro.ru", "phone": "+70412154167"}
0005432112578	5D753B	2229 313582	VLADIMIR SAVELEV	{"email": "v-savelev-1967@postgrespro.ru", "phone": "+70977978567"}
0005432112579	175D37	6124 772503	VIKTOR MIKHAYLOV	{"phone": "+70724672218"}
0005432112580	AAF655	5343 072113	SERGEY NIKOLAEV	{"phone": "+70875216220"}
0005432112581	2DC010	4759 925494	ANDREY SOROKIN	{"phone": "+70577060085"}
0005432112582	2DC010	7397 162566	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana_011976@postgrespro.ru", "phone": "+70931694066"}
0005432114145	1BC9B3	9415 412291	TATYANA YAKOVLEVA	{"email": "yakovleva.t121970@postgrespro.ru", "phone": "+70306766922"}
0005432114146	A97BAC	9652 169783	YURIY STEPANOV	{"phone": "+70354511195"}
0005432114147	3C9DBD	8895 542613	ALINA KUZNECOVA	{"email": "kuznecova-a-25041977@postgrespro.ru", "phone": "+70022189730"}
0005432114148	3C9DBD	7294 945974	OLGA ANISIMOVA	{"phone": "+70208072707"}
0005432114149	0639CC	6443 019671	OLEG MELNIKOV	{"phone": "+70870100241"}
0005432114150	E6AD8F	0737 816880	EKATERINA SOROKINA	{"phone": "+70880520826"}
0005432114151	FF3374	7838 001565	GALINA IVANOVA	{"email": "g_ivanova_23031970@postgrespro.ru", "phone": "+70278455866"}
0005432114152	FAFFA4	2856 349329	SERGEY EGOROV	{"phone": "+70752251264"}
0005432114153	FAFFA4	5186 044113	ALEKSANDR PETROV	{"email": "aleksandrpetrov_081962@postgrespro.ru", "phone": "+70060950043"}
0005432114154	2FFEF8	0092 133351	MIKHAIL PAVLOV	{"phone": "+70421640336"}
0005432114155	2C569E	3576 542329	LYUBOV KRASNOVA	{"phone": "+70662860081"}
0005432114156	C78A26	5810 131070	OLGA GORBUNOVA	{"email": "gorbunova_o-1978@postgrespro.ru", "phone": "+70221883732"}
0005432114157	896A31	1759 978796	LIDIYA NIKOLAEVA	{"phone": "+70545481309"}
0005432114158	79DC08	6088 242197	SERGEY EGOROV	{"email": "s_egorov-111969@postgrespro.ru", "phone": "+70812131055"}
0005432114159	79DC08	2067 377489	SVETLANA MIKHAYLOVA	{"email": "mikhaylovasvetlana.27051971@postgrespro.ru", "phone": "+70921204743"}
0005432114160	780350	6893 636870	TATYANA OSIPOVA	{"email": "osipova.tatyana-1970@postgrespro.ru", "phone": "+70027607930"}
0005432114161	780350	0643 380784	ALEKSANDR KUZMIN	{"email": "a.kuzmin-121963@postgrespro.ru", "phone": "+70951096447"}
0005432114162	515B6B	2854 228493	DARYA GRISHINA	{"phone": "+70792507131"}
0005432114163	4AF526	8982 662413	IGOR KUZNECOV	{"email": "i.kuznecov1969@postgrespro.ru", "phone": "+70550016118"}
0005432114164	4AF526	9118 743541	ARINA STEPANOVA	{"phone": "+70582316160"}
0005432114165	0B4402	9637 507987	MARGARITA ARKHIPOVA	{"phone": "+70841099560"}
0005432114166	ADD381	5469 248502	ELENA KRASNOVA	{"email": "krasnova_e061974@postgrespro.ru", "phone": "+70170541821"}
0005432114167	89CA30	0396 696427	RADIK POPOV	{"phone": "+70408259661"}
0005432114168	660455	1887 781753	ANTONINA MATVEEVA	{"phone": "+70354500613"}
0005432114169	C64839	3382 859286	ALEKSANDR BELOV	{"email": "aleksandr.belov.081967@postgrespro.ru", "phone": "+70355914591"}
0005432114170	8CE167	3755 312024	VLADISLAV KRASNOV	{"email": "v-krasnov_07121967@postgrespro.ru", "phone": "+70262211985"}
0005432114171	CA22D3	6716 575226	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy.1972@postgrespro.ru", "phone": "+70237420640"}
0005432114172	CA22D3	1132 864090	TATYANA MAKAROVA	{"email": "makarova-tatyana_1982@postgrespro.ru", "phone": "+70482270085"}
0005432114173	FC7E8F	0930 298039	IVAN KAZAKOV	{"phone": "+70626627578"}
0005432114174	FC7E8F	5416 219774	ELENA EGOROVA	{"email": "e_egorova111964@postgrespro.ru", "phone": "+70031606373"}
0005432114175	B34082	5097 097462	ALLA DENISOVA	{"email": "denisova.a.12051970@postgrespro.ru", "phone": "+70557460560"}
0005432114176	B34082	7243 743898	KLAVDIYA MELNIKOVA	{"phone": "+70201673537"}
0005432114177	6AD407	8261 791743	RAISA FROLOVA	{"phone": "+70660942551"}
0005432114178	E72B5F	1642 942305	SERGEY DENISOV	{"phone": "+70107442617"}
0005432114179	E72B5F	3118 634085	LYUDMILA NAUMOVA	{"email": "l_naumova-24041972@postgrespro.ru", "phone": "+70907643594"}
0005432114180	CBFA3C	5970 906586	ARTEM KONOVALOV	{"phone": "+70976104767"}
0005432114181	CEB0EF	9714 282250	RAISA KUZNECOVA	{"phone": "+70933879656"}
0005432114182	15BE77	9213 996791	GENNADIY ZHURAVLEV	{"email": "g_zhuravlev.061961@postgrespro.ru", "phone": "+70319084917"}
0005432114183	9C7B0E	4741 625919	NIKOLAY ABRAMOV	{"email": "abramov_n-1972@postgrespro.ru", "phone": "+70668983787"}
0005432114184	9411DD	6577 189462	ALINA SMIRNOVA	{"email": "smirnova.a1971@postgrespro.ru", "phone": "+70264450337"}
0005432114185	AA0C20	2564 192677	GALINA KOROLEVA	{"phone": "+70712923550"}
0005432114186	697810	6518 142786	VITALIY SIDOROV	{"email": "sidorovv-06071973@postgrespro.ru", "phone": "+70393703572"}
0005432114187	D3E02D	3492 365332	GALINA FROLOVA	{"email": "g_frolova.17121979@postgrespro.ru", "phone": "+70000583032"}
0005432114188	61B9B7	6749 089678	ALEKSANDR KRASNOV	{"phone": "+70432848801"}
0005432114189	118EBC	4834 314437	KRISTINA FROLOVA	{"phone": "+70005425820"}
0005432114190	AD6FAB	3088 959398	LYUDMILA ROMANOVA	{"phone": "+70982004667"}
0005432114191	71CACD	8157 270440	YURIY MIKHAYLOV	{"email": "yuriymikhaylov.12121968@postgrespro.ru", "phone": "+70126567812"}
0005432114192	C06CBE	4529 130302	GALINA LUKYANOVA	{"phone": "+70178343674"}
0005432114193	C06CBE	1488 386652	ANASTASIYA IVANOVA	{"phone": "+70577979355"}
0005432114194	7666E1	5991 172352	EVGENIY KOZLOV	{"phone": "+70303731273"}
0005432114195	8EC98A	7156 562597	VLADIMIR PETROV	{"phone": "+70109188550"}
0005432114196	B8BF8D	2525 301065	VALENTINA FILIPPOVA	{"phone": "+70153120765"}
0005432114197	B8BF8D	9628 599618	NADEZHDA SOROKINA	{"phone": "+70007526550"}
0005432114198	1215E2	8333 769325	NADEZHDA POPOVA	{"phone": "+70055466401"}
0005432114199	9B3A39	0458 820066	VIKTOR ZAKHAROV	{"email": "zakharovv_101972@postgrespro.ru", "phone": "+70375364650"}
0005432114200	4E73A7	6531 443029	ALEKSEY ALEKSEEV	{"email": "aleksey_alekseev_121973@postgrespro.ru", "phone": "+70564931197"}
0005432114201	739CA6	4487 848188	LYUBOV FEDOROVA	{"email": "l-fedorova1971@postgrespro.ru", "phone": "+70724034100"}
0005432114202	739CA6	4062 691596	GALINA PETROVA	{"email": "petrovagalina1971@postgrespro.ru", "phone": "+70031957589"}
0005432114203	0A8016	6595 223575	TATYANA SCHERBAKOVA	{"phone": "+70777217959"}
0005432114204	A39FB6	9535 499163	NIKITA SEMENOV	{"email": "nikita.semenov_21051974@postgrespro.ru", "phone": "+70001132093"}
0005432114205	A39FB6	5229 758460	ALEKSEY FEDOROV	{"email": "fedorovaleksey1972@postgrespro.ru", "phone": "+70615247433"}
0005432114206	751ACA	8662 719672	MARINA SMIRNOVA	{"email": "msmirnova_051979@postgrespro.ru", "phone": "+70763279197"}
0005432114207	857678	3773 258379	LIDIYA PAVLOVA	{"phone": "+70739267341"}
0005432114208	857678	0242 977273	POLINA OSIPOVA	{"email": "p-osipova-121966@postgrespro.ru", "phone": "+70979644241"}
0005432114209	F2DB33	9594 019652	NATALYA NIKOLAEVA	{"email": "natalya.nikolaeva-101975@postgrespro.ru", "phone": "+70904015617"}
0005432114210	BF6B04	2038 551505	LYUDMILA SOLOVEVA	{"phone": "+70525217844"}
0005432114211	BF6B04	2308 754943	MARGARITA IVANOVA	{"email": "ivanova_margarita-07111970@postgrespro.ru", "phone": "+70705502289"}
0005432114212	C0ED92	1003 502680	VALERIYA EFREMOVA	{"email": "valeriya.efremova061968@postgrespro.ru", "phone": "+70454460163"}
0005432114213	7B6911	7162 050787	ELENA KUZNECOVA	{"email": "kuznecova-elena1964@postgrespro.ru", "phone": "+70691135282"}
0005432114214	7B6911	4555 842032	TATYANA KUZNECOVA	{"phone": "+70840984762"}
0005432114215	131EE0	6252 160099	YAROSLAV MIRONOV	{"email": "mironovyaroslav.21111978@postgrespro.ru", "phone": "+70019771150"}
0005432114216	632815	2466 403095	VYACHESLAV NIKOLAEV	{"phone": "+70992934161"}
0005432114217	632815	4509 810257	IRINA AKIMOVA	{"email": "irinaakimova.1968@postgrespro.ru", "phone": "+70821406095"}
0005432114218	B6BC8F	0177 458691	MARSEL FILIPPOV	{"phone": "+70741528356"}
0005432114219	1B15BE	1139 432165	RAFAIL MAKAROV	{"phone": "+70042094755"}
0005432114220	1B15BE	8982 397293	IRINA MALYSHEVA	{"email": "irina-malysheva_041971@postgrespro.ru", "phone": "+70214802036"}
0005432114221	4AAC8A	0843 249634	ARTUR KARPOV	{"phone": "+70388202124"}
0005432114222	4AAC8A	2320 625709	NATALIYA CHERNOVA	{"email": "chernova-n.16021966@postgrespro.ru", "phone": "+70551636973"}
0005432114223	3CD3F0	2013 538305	IRINA MAKAROVA	{"email": "makarova.irina.1966@postgrespro.ru", "phone": "+70602871738"}
0005432114224	3CD3F0	9761 344282	OLEG PAVLOV	{"phone": "+70118888820"}
0005432114225	C05E11	2913 585329	KLAVDIYA ROMANOVA	{"phone": "+70443416936"}
0005432114226	41FB64	0187 834724	NIKOLAY BORISOV	{"phone": "+70658373980"}
0005432114227	5B3FE9	8311 614075	EKATERINA MIRONOVA	{"email": "mironova.e-02031972@postgrespro.ru", "phone": "+70094615027"}
0005432114228	1D89FB	4379 611906	VYACHESLAV SCHERBAKOV	{"phone": "+70886023898"}
0005432114229	EDABAA	4797 187574	VALERIYA ZOTOVA	{"email": "v_zotova_29091965@postgrespro.ru", "phone": "+70977881336"}
0005432114230	EDABAA	0701 196803	IRINA VOLKOVA	{"email": "i_volkova.31051964@postgrespro.ru", "phone": "+70143416349"}
0005432114231	11DBCD	2002 908253	NIKITA NAUMOV	{"email": "naumov.nikita.021986@postgrespro.ru", "phone": "+70636887815"}
0005432114232	11DBCD	9389 523388	ANATOLIY MIKHAYLOV	{"phone": "+70455478912"}
0005432114233	11DBCD	1670 957513	TATYANA KOVALEVA	{"email": "kovaleva_tatyana_29011968@postgrespro.ru", "phone": "+70110982550"}
0005432114234	4D127A	1978 017688	ZOYA SCHERBAKOVA	{"email": "scherbakovaz1975@postgrespro.ru", "phone": "+70332430113"}
0005432114235	4D127A	9871 488688	LIDIYA MAKAROVA	{"email": "makarova.lidiya-13041966@postgrespro.ru", "phone": "+70324322011"}
0005432114236	90C110	2896 368966	DMITRIY MOISEEV	{"phone": "+70179624217"}
0005432114237	90C110	3993 681630	MIKHAIL ALEKSANDROV	{"phone": "+70796355285"}
0005432114238	1251C2	6859 195956	RUSLAN GERASIMOV	{"phone": "+70251625578"}
0005432114239	1251C2	4711 782249	TAMARA BELOVA	{"email": "t-belova1982@postgrespro.ru", "phone": "+70612549208"}
0005432114240	EA6A54	1375 786758	VALENTINA POPOVA	{"phone": "+70821897426"}
0005432114241	EA6A54	4791 793831	DINARA ZHURAVLEVA	{"email": "zhuravleva.d1970@postgrespro.ru", "phone": "+70543392645"}
0005432114242	61F4EF	2567 775867	MAKSIM SIDOROV	{"email": "m-sidorov.1958@postgrespro.ru", "phone": "+70855023278"}
0005432114243	61F4EF	5554 234522	YULIYA ANDREEVA	{"phone": "+70628689787"}
0005432114244	B49939	3839 917437	MIKHAIL SOLOVEV	{"phone": "+70402275073"}
0005432114245	9AC1BA	4778 588226	VLADIMIR ILIN	{"phone": "+70370307224"}
0005432114246	9AC1BA	8728 270393	VLADIMIR POPOV	{"phone": "+70166170140"}
0005432114247	A8ACAD	3412 445039	IRINA FILIPPOVA	{"phone": "+70277469967"}
0005432114248	67D8F6	0251 729043	ELENA MAKSIMOVA	{"email": "elenamaksimova_14031963@postgrespro.ru", "phone": "+70413559357"}
0005432114249	B05285	2587 400897	LYUDMILA MARTYNOVA	{"email": "martynova.lyudmila.121977@postgrespro.ru", "phone": "+70049895053"}
0005432114250	B9D26A	8423 644637	YULIYA DAVYDOVA	{"phone": "+70618099169"}
0005432114251	807018	4533 127287	SNEZHANA GERASIMOVA	{"phone": "+70026035937"}
0005432114252	807018	2474 195980	ELENA CHERNOVA	{"phone": "+70796137048"}
0005432114253	4AF2DB	4050 605719	LYUDMILA SOROKINA	{"phone": "+70761661809"}
0005432114254	4AF2DB	3002 462280	VADIM MATVEEV	{"email": "vadim-matveev_1961@postgrespro.ru", "phone": "+70305839257"}
0005432114255	AB00A8	2090 405595	ANATOLIY BORISOV	{"email": "anatoliyborisov_1965@postgrespro.ru", "phone": "+70816844883"}
0005432114256	AB00A8	7310 372237	IVAN MEDVEDEV	{"phone": "+70077247584"}
0005432114257	9A166D	2275 858504	GENNADIY PAVLOV	{"phone": "+70198198471"}
0005432114258	C5F1C8	6288 601186	LYUBOV MAKSIMOVA	{"phone": "+70844135271"}
0005432114259	9E4621	9443 473828	VLADIMIR ROMANOV	{"phone": "+70285236119"}
0005432114260	9E4621	3049 608683	ALEKSEY CHERNOV	{"email": "chernova-17011972@postgrespro.ru", "phone": "+70388858592"}
0005432114261	B7E89D	9191 995003	ELENA KAZAKOVA	{"phone": "+70435289506"}
0005432114262	FFCCA2	0290 885966	MIKHAIL NIKOLAEV	{"phone": "+70322273184"}
0005432114263	FFCCA2	3965 359155	SERGEY PETROV	{"email": "s-petrov031978@postgrespro.ru", "phone": "+70547543877"}
0005432114264	09DF35	2810 192967	ELENA IVANOVA	{"phone": "+70343726499"}
0005432114265	09DF35	3989 546727	TATYANA ZAYCEVA	{"email": "t.zayceva-081968@postgrespro.ru", "phone": "+70677554954"}
0005432114266	AC3B2C	2659 795228	VLADIMIR TARASOV	{"phone": "+70797995438"}
0005432114267	43BB76	1787 262073	NADEZHDA POTAPOVA	{"email": "nadezhda-potapova-1969@postgrespro.ru", "phone": "+70854824938"}
0005432114268	64A1E9	6120 435018	NATALIYA MARTYNOVA	{"phone": "+70644309824"}
0005432114269	B3D54B	2656 152759	LYUBOV EGOROVA	{"phone": "+70396117960"}
0005432114270	B3D54B	8109 090862	TATYANA NOVIKOVA	{"email": "novikovatatyana_05041979@postgrespro.ru", "phone": "+70441048086"}
0005432114271	3A7DAB	9312 101039	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov011977@postgrespro.ru", "phone": "+70883862332"}
0005432114272	E5FBB7	5380 390339	ALEKSANDR DENISOV	{"email": "denisov.a_29031971@postgrespro.ru", "phone": "+70573646272"}
0005432114273	E5FBB7	8383 429606	VIKTOR NAZAROV	{"phone": "+70494068191"}
0005432114274	B8DDE9	7024 609370	ELENA DANILOVA	{"phone": "+70658146537"}
0005432114275	B8DDE9	3924 533249	IRINA ZAYCEVA	{"phone": "+70557474468"}
0005432114276	B1B5FA	1995 409144	ANNA KOZLOVA	{"email": "akozlova111969@postgrespro.ru", "phone": "+70570387731"}
0005432114277	E433E8	1597 548385	ANDREY IVANOV	{"phone": "+70457165692"}
0005432114278	606ABA	9049 817460	ALINA FEDOROVA	{"phone": "+70697567141"}
0005432114279	D38AE3	7808 464069	ELENA SEMENOVA	{"phone": "+70806047136"}
0005432114280	B2F71D	6401 807599	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy.031971@postgrespro.ru", "phone": "+70648586606"}
0005432114281	AD8168	0725 067623	PELAGEYA NIKITINA	{"email": "p-nikitina_1974@postgrespro.ru", "phone": "+70737435383"}
0005432114282	AD8168	6024 242301	ARTEM NIKOLAEV	{"email": "a_nikolaev-061966@postgrespro.ru", "phone": "+70608854560"}
0005432114283	AD8168	1512 087848	ALEKSANDR BARANOV	{"phone": "+70440643063"}
0005432114284	5443B7	6399 017249	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr1969@postgrespro.ru", "phone": "+70136659298"}
0005432114285	8E194E	8947 302728	MIKHAIL POPOV	{"email": "m-popov.02071972@postgrespro.ru", "phone": "+70211559573"}
0005432114286	80600E	0662 513988	ALEKSANDR DMITRIEV	{"phone": "+70870501792"}
0005432114287	80600E	1466 594797	DMITRIY NOVIKOV	{"email": "d.novikov-1973@postgrespro.ru", "phone": "+70724074161"}
0005432114288	165C76	7414 272027	DENIS SMIRNOV	{"email": "d.smirnov1970@postgrespro.ru", "phone": "+70753024318"}
0005432114289	165C76	9718 359994	NINA KUZNECOVA	{"phone": "+70412838943"}
0005432114290	9C8F2B	3350 902865	ALEKSANDR SCHERBAKOV	{"email": "scherbakova.24091971@postgrespro.ru", "phone": "+70012342044"}
0005432114291	9C8F2B	6126 186569	VYACHESLAV SIDOROV	{"email": "vsidorov-07071984@postgrespro.ru", "phone": "+70821815179"}
0005432114292	14737E	2657 620881	LIDIYA KALININA	{"email": "kalinina-l09061966@postgrespro.ru", "phone": "+70283259521"}
0005432114293	45998B	1877 339943	NADEZHDA EFREMOVA	{"email": "n-efremova1970@postgrespro.ru", "phone": "+70722444131"}
0005432114294	F4B8FB	7435 877619	GENNADIY ANTONOV	{"email": "gennadiy_antonov1976@postgrespro.ru", "phone": "+70615067676"}
0005432114295	CE0456	4197 783978	ELENA EFIMOVA	{"email": "eefimova18031976@postgrespro.ru", "phone": "+70350646572"}
0005432114296	04A31F	8472 667882	VIKTORIYA IVANOVA	{"email": "ivanova_v-22031977@postgrespro.ru", "phone": "+70549500747"}
0005432114297	19CD08	4604 420566	ANDREY DMITRIEV	{"email": "dmitriev_andrey-011981@postgrespro.ru", "phone": "+70009308315"}
0005432114298	65A3AD	9882 701193	VALERIY SOLOVEV	{"phone": "+70859181487"}
0005432121083	04D130	3429 129548	MIKHAIL TIKHONOV	{"email": "mikhailtikhonov_25121981@postgrespro.ru", "phone": "+70654614035"}
0005432121084	04D130	7657 236757	ANATOLIY KISELEV	{"email": "a_kiselev.02041974@postgrespro.ru", "phone": "+70483501538"}
0005432121085	BFE4F1	8514 355824	VIKTOR VOLKOV	{"email": "volkovviktor27121976@postgrespro.ru", "phone": "+70398666494"}
0005432121086	A30AA2	5919 885214	MAKSIM VOROBEV	{"phone": "+70118361025"}
0005432121087	2B3489	7896 062108	ALEKSANDRA ZHUKOVA	{"email": "a-zhukova_28081978@postgrespro.ru", "phone": "+70341960571"}
0005432121088	A24012	6151 843336	DMITRIY ABRAMOV	{"email": "d_abramov.021986@postgrespro.ru", "phone": "+70605019112"}
0005432121089	40F8C3	7388 792914	VIKTOR ALEKSEEV	{"email": "alekseev.viktor-24101975@postgrespro.ru", "phone": "+70008551350"}
0005432121090	F74BCB	0894 331622	ANGELINA SOROKINA	{"email": "angelina-sorokina_31121972@postgrespro.ru", "phone": "+70716775580"}
0005432121091	FC06AB	8279 871522	OLEG IVANOV	{"phone": "+70133491934"}
0005432121092	FC06AB	4749 063553	ANDREY CHERNOV	{"phone": "+70619024725"}
0005432121093	B205FD	0803 201497	KSENIYA PAVLOVA	{"email": "kpavlova-1982@postgrespro.ru", "phone": "+70891331231"}
0005432121094	B205FD	6600 485099	ANDREY BARANOV	{"email": "a.baranov_22041981@postgrespro.ru", "phone": "+70991704140"}
0005432121095	9F7A92	5071 117905	VALENTINA KONOVALOVA	{"email": "konovalova.valentina_031976@postgrespro.ru", "phone": "+70036357551"}
0005432121096	7ABB9D	5231 250164	MAKSIM KAZAKOV	{"email": "kazakov-maksim26091977@postgrespro.ru", "phone": "+70593473798"}
0005432121097	148625	1652 431915	ALEKSANDR ZAYCEV	{"email": "a.zaycev1975@postgrespro.ru", "phone": "+70920273553"}
0005432121098	148625	3147 711411	KONSTANTIN SCHERBAKOV	{"email": "k.scherbakov-1971@postgrespro.ru", "phone": "+70876671376"}
0005432121099	0BA98C	6205 069527	OLEG FEDOROV	{"phone": "+70384815491"}
0005432121100	0BA98C	0223 790536	NADEZHDA VASILEVA	{"phone": "+70729666961"}
0005432121101	692331	7139 380123	NIKOLAY GRIGOREV	{"email": "n.grigorev1977@postgrespro.ru", "phone": "+70068007197"}
0005432121102	630532	2479 041225	IVAN KOROLEV	{"email": "korolev-i_14021964@postgrespro.ru", "phone": "+70786667624"}
0005432121103	EFFB15	3557 601450	VYACHESLAV NIKITIN	{"email": "nikitinv.1966@postgrespro.ru", "phone": "+70910285571"}
0005432121104	EFFB15	6718 952560	DENIS ZAKHAROV	{"email": "zakharov-denis.1974@postgrespro.ru", "phone": "+70281666447"}
0005432121105	72AE32	7140 022116	NIKOLAY VOLKOV	{"phone": "+70873108251"}
0005432121106	572656	5765 064634	VIKTORIYA MAKAROVA	{"email": "viktoriya-makarova-09071983@postgrespro.ru", "phone": "+70333949232"}
0005432121107	72DAED	2469 427131	GALINA MOROZOVA	{"phone": "+70617046618"}
0005432121165	6EE10B	5914 916385	ELMIRA CHERNOVA	{"phone": "+70411998568"}
0005432121108	10F881	6543 512053	NIKOLAY ILIN	{"email": "ilinnikolay.081969@postgrespro.ru", "phone": "+70148043409"}
0005432121109	54CD0C	8725 725505	OLGA ALEKSEEVA	{"phone": "+70573235925"}
0005432121110	FB63EF	0653 738545	SERGEY SEMENOV	{"email": "semenov-sergey-1970@postgrespro.ru", "phone": "+70038186270"}
0005432121111	1E6BEB	2422 412522	VALENTINA KUZMINA	{"email": "v_kuzmina04061974@postgrespro.ru", "phone": "+70147816442"}
0005432121112	1E6BEB	0163 878411	LYUDMILA LAZAREVA	{"phone": "+70816119729"}
0005432121113	E6CBC9	8937 867166	NATALYA MATVEEVA	{"phone": "+70621217612"}
0005432121114	E6CBC9	4114 257608	SERGEY YAKOVLEV	{"phone": "+70287026291"}
0005432121115	E6CBC9	3651 986401	ANTON NIKOLAEV	{"email": "nikolaev-a-1976@postgrespro.ru", "phone": "+70979801693"}
0005432121116	90A26C	4596 899503	MARINA MAKSIMOVA	{"phone": "+70279275593"}
0005432121117	99A205	6180 680308	VERA MAKSIMOVA	{"email": "v_maksimova-101979@postgrespro.ru", "phone": "+70904196679"}
0005432121118	496EBE	9771 864463	LYUDMILA KULIKOVA	{"phone": "+70439798759"}
0005432121119	7F4B91	2163 480623	ELENA NIKIFOROVA	{"phone": "+70007687612"}
0005432121120	1DBCF9	7192 641878	ALEKSANDRA MALYSHEVA	{"phone": "+70076432689"}
0005432121121	1DBCF9	5966 209369	YURIY FEDOROV	{"email": "yuriy_fedorov05071972@postgrespro.ru", "phone": "+70239272940"}
0005432121122	1FC4C5	0064 836133	KSENIYA NOVIKOVA	{"email": "novikova.kseniya_011974@postgrespro.ru", "phone": "+70348349421"}
0005432121123	1FC4C5	4029 359037	ARTEM SAVELEV	{"email": "savelevartem-1969@postgrespro.ru", "phone": "+70568338155"}
0005432121124	82E5DE	7039 918401	ALEKSANDRA FEDOROVA	{"phone": "+70003747803"}
0005432121125	36562A	3288 409970	IRINA BELYAEVA	{"email": "belyaevai_1973@postgrespro.ru", "phone": "+70212892586"}
0005432121126	36562A	3906 384316	VALENTINA ANDREEVA	{"phone": "+70211877430"}
0005432121127	1E3F0D	7814 210332	ALEKSEY KRASNOV	{"phone": "+70952217274"}
0005432121128	EE0901	2618 495690	RAFAIL MIRONOV	{"email": "r.mironov-1978@postgrespro.ru", "phone": "+70642323733"}
0005432121129	403B62	9191 149299	ELENA KUZNECOVA	{"phone": "+70921847007"}
0005432121130	F15A39	6677 538168	RAISA TIKHONOVA	{"phone": "+70044297294"}
0005432121131	F15A39	0054 467052	YURIY ZAYCEV	{"phone": "+70336737796"}
0005432121132	81739D	8701 035689	TATYANA KALININA	{"phone": "+70479753889"}
0005432121133	388E45	6787 432949	NATALYA IVANOVA	{"email": "ivanovan-28021974@postgrespro.ru", "phone": "+70009481379"}
0005432121134	7DDD31	4801 936803	SERGEY ZAYCEV	{"email": "zaycev_s.16021985@postgrespro.ru", "phone": "+70901849939"}
0005432121135	7DDD31	6959 699140	MARIYA SMIRNOVA	{"email": "smirnovamariya-031965@postgrespro.ru", "phone": "+70026089735"}
0005432121136	7DDD31	8876 448855	NIKOLAY DENISOV	{"phone": "+70643252330"}
0005432121137	75874F	2229 362896	NINA BARANOVA	{"email": "nina-baranova-111968@postgrespro.ru", "phone": "+70752118169"}
0005432121138	FFE0F1	2212 306883	ANTON SERGEEV	{"phone": "+70878646762"}
0005432121139	FFE0F1	1576 325209	ANDREY KUZMIN	{"email": "andrey-kuzmin.14061969@postgrespro.ru", "phone": "+70127260476"}
0005432121140	BA4B9E	0133 677910	IRINA POPOVA	{"email": "ipopova_1963@postgrespro.ru", "phone": "+70750101853"}
0005432121141	8F4990	6395 905446	EKATERINA POPOVA	{"email": "e.popova.111959@postgrespro.ru", "phone": "+70746190266"}
0005432121142	8F4990	6546 039873	ALEKSANDR IVANOV	{"phone": "+70879788078"}
0005432121143	D0ECF2	1117 602977	ALEVTINA ALEKSEEVA	{"phone": "+70681210450"}
0005432121144	D0ECF2	3244 601377	NIKOLAY MIRONOV	{"email": "nikolay_mironov-071964@postgrespro.ru", "phone": "+70041674819"}
0005432121145	91039A	3787 482948	ALEKSANDR KRASNOV	{"phone": "+70131905613"}
0005432121146	A44527	5117 380006	ARTEM ZAKHAROV	{"email": "a.zakharov-21061968@postgrespro.ru", "phone": "+70010216669"}
0005432121147	A44527	4733 202591	ALEKSANDR SOKOLOV	{"email": "a_sokolov-1979@postgrespro.ru", "phone": "+70894964423"}
0005432121148	7AA614	5689 029844	MATVEY NOVIKOV	{"email": "novikov_matvey-1967@postgrespro.ru", "phone": "+70510802214"}
0005432121149	7AA614	0329 643393	NAIL ALEKSEEV	{"phone": "+70179354359"}
0005432121150	1F0D7E	5285 976279	VLADIMIR GRIGOREV	{"email": "grigorev-v.081971@postgrespro.ru", "phone": "+70290659055"}
0005432121151	B3A43F	2744 755517	VLADIMIR VOROBEV	{"email": "vladimir-vorobev_1974@postgrespro.ru", "phone": "+70214318613"}
0005432121152	B3A43F	3384 426058	NATALYA KOROLEVA	{"email": "koroleva-natalya-1969@postgrespro.ru", "phone": "+70293097553"}
0005432121153	BB3E14	7740 648055	ELENA FOMINA	{"email": "e.fomina.06081977@postgrespro.ru", "phone": "+70371303071"}
0005432121154	BB3E14	2649 973786	LYUBOV KUZNECOVA	{"email": "kuznecova.l.07061967@postgrespro.ru", "phone": "+70636570554"}
0005432121155	949D4C	0370 870341	PETR POPOV	{"phone": "+70095308281"}
0005432121156	949D4C	1510 740665	ARSENIY SIDOROV	{"email": "a_sidorov_30041969@postgrespro.ru", "phone": "+70089968453"}
0005432121157	0544BB	9455 250129	ANDREY VASILEV	{"phone": "+70714952011"}
0005432121158	0544BB	7084 776728	SOFIYA DMITRIEVA	{"phone": "+70059299122"}
0005432121159	F1091F	7354 526906	IVAN SHEVCHENKO	{"phone": "+70439661538"}
0005432121160	F1091F	1375 926689	OLGA AFANASEVA	{"phone": "+70493513687"}
0005432121161	36364A	3252 495896	VADIM RODIONOV	{"phone": "+70631012018"}
0005432121162	14FC43	4878 177749	RAISA NAZAROVA	{"phone": "+70446324634"}
0005432121163	390AA4	6879 478647	OLGA ANDREEVA	{"phone": "+70679946974"}
0005432121164	390AA4	2072 565830	IVAN SOROKIN	{"phone": "+70464948691"}
0005432121166	6EE10B	3879 781679	DMITRIY POPOV	{"phone": "+70583043553"}
0005432121167	9FE56B	0258 280345	ALEKSEY ZAYCEV	{"email": "aleksey_zaycev-24071975@postgrespro.ru", "phone": "+70071673722"}
0005432121168	EC0A27	6257 256655	ALEKSANDR TARASOV	{"email": "tarasov_a.30081956@postgrespro.ru", "phone": "+70668425489"}
0005432121169	C7B78C	5142 288162	ALEKSEY TIKHONOV	{"phone": "+70267875675"}
0005432121170	AEFD7B	4516 027113	EKATERINA DMITRIEVA	{"email": "dmitrieva.e.101968@postgrespro.ru", "phone": "+70634138512"}
0005432121171	F35E1A	3790 106230	NATALYA STEPANOVA	{"email": "stepanovanatalya.1974@postgrespro.ru", "phone": "+70755354376"}
0005432121172	F35E1A	8897 851910	MAKSIM CHERNOV	{"phone": "+70409993154"}
0005432121173	C9C54C	2849 080273	SERGEY CHERNOV	{"email": "chernov_s-22071975@postgrespro.ru", "phone": "+70419782752"}
0005432121174	884FE4	2595 327187	OLEG POPOV	{"phone": "+70852682314"}
0005432121175	884FE4	4870 565817	PAVEL FOMIN	{"email": "p.fomin051972@postgrespro.ru", "phone": "+70669645837"}
0005432121176	E806AF	5536 185924	EVGENIYA ORLOVA	{"phone": "+70854564915"}
0005432121177	7D6ABA	0746 877629	BORIS MIKHAYLOV	{"phone": "+70310623079"}
0005432121178	FB190C	0601 589165	DENIS MIRONOV	{"email": "d-mironov.30091971@postgrespro.ru", "phone": "+70446438776"}
0005432121179	F3D089	2135 631846	VASILIY BONDARENKO	{"email": "bondarenko_vasiliy1965@postgrespro.ru", "phone": "+70049149134"}
0005432121180	54AADB	7704 473361	ELENA FILATOVA	{"email": "e_filatova061974@postgrespro.ru", "phone": "+70413266270"}
0005432121181	54AADB	2877 311437	DMITRIY DAVYDOV	{"email": "davydovd_31071959@postgrespro.ru", "phone": "+70096533865"}
0005432121182	0C4725	7935 528857	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov-051978@postgrespro.ru", "phone": "+70751986350"}
0005432121183	4EC8F0	4521 521707	DENIS EGOROV	{"phone": "+70233595189"}
0005432121184	E9AED1	2374 647432	VALENTINA SERGEEVA	{"phone": "+70014699909"}
0005432121185	E9AED1	7339 726954	EKATERINA KUZNECOVA	{"phone": "+70122071669"}
0005432121186	E9AED1	6277 869451	MAKSIM ABRAMOV	{"email": "abramov-m1967@postgrespro.ru", "phone": "+70415867544"}
0005432121187	1391A3	6258 515365	NAIL AFANASEV	{"email": "afanasev-nail071961@postgrespro.ru", "phone": "+70067415129"}
0005432121188	1F86FA	7257 270830	EKATERINA LUKYANOVA	{"email": "lukyanova.e_121974@postgrespro.ru", "phone": "+70649112932"}
0005432121189	10C240	5573 544909	EVGENIY PAVLOV	{"phone": "+70915908762"}
0005432121190	A1E4BF	1860 490848	ARTEM DMITRIEV	{"phone": "+70111186919"}
0005432121191	B543CE	9742 692306	DANIL OSIPOV	{"email": "danil_osipov_31081964@postgrespro.ru", "phone": "+70308850759"}
0005432121192	B543CE	0556 769080	GALINA NIKOLAEVA	{"email": "g-nikolaeva.12121971@postgrespro.ru", "phone": "+70363901310"}
0005432121193	B543CE	3080 080116	ANNA ALEKSEEVA	{"email": "a.alekseeva.091976@postgrespro.ru", "phone": "+70215099623"}
0005432121194	647BCA	2382 065024	YULIYA ZAKHAROVA	{"phone": "+70007623971"}
0005432121195	647BCA	3374 097899	VALENTINA ERMAKOVA	{"phone": "+70768721342"}
0005432121196	E874EA	1168 939008	DENIS DMITRIEV	{"phone": "+70529852241"}
0005432121197	80D01C	2239 946472	VIKTOR BELOV	{"email": "viktor-belov26071974@postgrespro.ru", "phone": "+70705042966"}
0005432121198	D3FF7D	4208 629737	ELIZAVETA ZOTOVA	{"phone": "+70711258579"}
0005432121199	D3FF7D	1656 887060	ELENA AKIMOVA	{"email": "akimova_e1981@postgrespro.ru", "phone": "+70022299442"}
0005432121200	E90AEC	8577 968774	MARIYA ZAKHAROVA	{"email": "mariya-zakharova.14061972@postgrespro.ru", "phone": "+70664423708"}
0005432121201	E4F5F4	3622 731573	EKATERINA KOVALEVA	{"phone": "+70565273083"}
0005432121202	85EBCC	8167 784003	LIDIYA MOISEEVA	{"email": "l-moiseeva1979@postgrespro.ru", "phone": "+70551148512"}
0005432121203	5AC818	0735 877320	ANNA VASILEVA	{"phone": "+70406483021"}
0005432121204	1D5F75	5336 100033	ANDREY MATVEEV	{"email": "matveev.a061973@postgrespro.ru", "phone": "+70096553115"}
0005432121205	6DE2D7	2727 110017	VYACHESLAV NIKOLAEV	{"phone": "+70233995876"}
0005432121206	7BED17	8360 612938	KLAVDIYA SMIRNOVA	{"email": "klavdiya.smirnova-21051983@postgrespro.ru", "phone": "+70953036075"}
0005432121207	7BED17	3531 608215	MIKHAIL BONDARENKO	{"phone": "+70202051467"}
0005432121208	7085DE	2307 214416	IRINA ANISIMOVA	{"phone": "+70460362694"}
0005432121209	7085DE	5742 862528	VALERIY IVANOV	{"phone": "+70199524793"}
0005432121210	DB0F78	0000 930517	EKATERINA KOZLOVA	{"phone": "+70577131310"}
0005432121211	DB0F78	0767 070415	SERGEY SOLOVEV	{"email": "solovevs_061972@postgrespro.ru", "phone": "+70833455669"}
0005432121212	37AA0F	0736 483564	VLADISLAV ANDREEV	{"phone": "+70027687299"}
0005432121213	37AA0F	3851 045473	SERGEY IVANOV	{"email": "ivanovs.031962@postgrespro.ru", "phone": "+70303465722"}
0005432121214	A4C26D	1196 465416	VLADIMIR GAVRILOV	{"email": "gavrilovv_1971@postgrespro.ru", "phone": "+70533366455"}
0005432121215	C35EF7	0086 408973	ANNA STEPANOVA	{"email": "stepanova-a_19051974@postgrespro.ru", "phone": "+70028440771"}
0005432121216	2D9035	0062 280578	PAVEL SMIRNOV	{"phone": "+70168272743"}
0005432121217	D4DF9C	8499 784663	VLADIMIR SCHERBAKOV	{"email": "scherbakov.v_02111978@postgrespro.ru", "phone": "+70753410628"}
0005432121218	5CF0CC	4838 299459	YULIYA SIDOROVA	{"phone": "+70381160966"}
0005432121219	5CF0CC	8726 307380	NATALIYA MOROZOVA	{"phone": "+70526740239"}
0005432121220	E25CC3	6527 405082	VLADIMIR VASILEV	{"phone": "+70682911386"}
0005432121221	5AE19F	5180 602062	ALEKSANDR OSIPOV	{"email": "osipovaleksandr1972@postgrespro.ru", "phone": "+70113115691"}
0005432121222	3C618F	0524 860531	ALEKSEY IVANOV	{"email": "aivanov-02041970@postgrespro.ru", "phone": "+70056142906"}
0005432121223	4DC31C	6536 885273	SEMEN TIKHONOV	{"email": "sementikhonov-061977@postgrespro.ru", "phone": "+70361789273"}
0005432121224	A411D4	4479 699594	ARSENIY ZAKHAROV	{"email": "arseniy.zakharov_1988@postgrespro.ru", "phone": "+70640954948"}
0005432121225	F2FDF9	6671 042914	ELENA VOLKOVA	{"email": "elena.volkova-1980@postgrespro.ru", "phone": "+70265614166"}
0005432121226	F55A0E	4470 123890	POLINA SMIRNOVA	{"email": "smirnova.polina29031971@postgrespro.ru", "phone": "+70165923464"}
0005432121227	BE71F1	2239 937108	EVDOKIYA STEPANOVA	{"phone": "+70263268150"}
0005432121228	91DEC2	9606 052805	GENNADIY MAKAROV	{"phone": "+70985231716"}
0005432121229	5073BE	9685 653288	ALENA SAVELEVA	{"email": "saveleva_a1971@postgrespro.ru", "phone": "+70691984316"}
0005432121230	D55634	1513 345794	KIRA MOROZOVA	{"email": "morozova_kira_011968@postgrespro.ru", "phone": "+70390789492"}
0005432121231	0D29F8	0889 421483	ALEKSANDR DENISOV	{"email": "aleksandr-denisov-031990@postgrespro.ru", "phone": "+70039128481"}
0005432121232	0D29F8	1845 519764	YURIY MATVEEV	{"email": "matveev-y1973@postgrespro.ru", "phone": "+70197679686"}
0005432121233	690570	1279 310403	OKSANA BORISOVA	{"email": "oksana.borisova081969@postgrespro.ru", "phone": "+70353312380"}
0005432121234	A96FFE	7030 458732	NATALYA KUZNECOVA	{"email": "natalya-kuznecova041971@postgrespro.ru", "phone": "+70279720288"}
0005432121235	78CF9E	7300 959685	MARINA KULIKOVA	{"phone": "+70836874903"}
0005432121236	78CF9E	9743 105650	SERGEY SAVELEV	{"email": "savelevsergey-1977@postgrespro.ru", "phone": "+70179740810"}
0005432121237	D6C62B	7323 737225	DMITRIY POPOV	{"email": "dmitriy_popov021979@postgrespro.ru", "phone": "+70049995236"}
0005432121238	4D5250	3319 623274	TATYANA KARPOVA	{"phone": "+70379503193"}
0005432121239	4D5250	2796 328710	ANTON SMIRNOV	{"phone": "+70428814863"}
0005432121240	820E88	0965 931712	ALISHER NIKOLAEV	{"phone": "+70405237973"}
0005432121241	13A0C3	3308 126908	YULIYA BORISOVA	{"email": "borisova_yuliya1977@postgrespro.ru", "phone": "+70237106305"}
0005432121242	93ACFD	1319 106546	GLEB KARPOV	{"email": "g-karpov.24071969@postgrespro.ru", "phone": "+70433238990"}
0005432121243	940B2B	2231 812957	MIKHAIL SIDOROV	{"phone": "+70486704935"}
0005432121244	5D1980	9703 601218	SERGEY KUZNECOV	{"email": "s_kuznecov-17061977@postgrespro.ru", "phone": "+70533914430"}
0005432121245	AA60D6	0840 246172	ALEKSANDR STEPANOV	{"phone": "+70736624740"}
0005432121246	FF3089	7044 219808	EVGENIY ALEKSEEV	{"email": "alekseev-e1981@postgrespro.ru", "phone": "+70438110873"}
0005432121247	011A5E	0048 302323	OLGA YAKOVLEVA	{"phone": "+70702989290"}
0005432121248	1903E2	7514 951464	ALEKSEY GUSEV	{"email": "gusev_a-061969@postgrespro.ru", "phone": "+70994871480"}
0005432121249	1903E2	4022 646299	SVETLANA SIDOROVA	{"email": "sidorova-s02041971@postgrespro.ru", "phone": "+70127889315"}
0005432121250	BE8772	6830 558633	OLESYA FROLOVA	{"email": "o.frolova_04101969@postgrespro.ru", "phone": "+70518633819"}
0005432121251	D36DD9	7894 006987	KIRILL SHEVCHENKO	{"email": "shevchenko_k1961@postgrespro.ru", "phone": "+70515392826"}
0005432121252	1D7BF8	8510 764672	DMITRIY MAKSIMOV	{"email": "maksimov_dmitriy.1966@postgrespro.ru", "phone": "+70602807484"}
0005432121253	1D7BF8	4782 662418	VLADIMIR KUZNECOV	{"phone": "+70872798728"}
0005432121254	90B9CC	6163 460994	OLGA ZAKHAROVA	{"phone": "+70717135213"}
0005432121255	90B9CC	7547 954737	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov1961@postgrespro.ru", "phone": "+70930197531"}
0005432121256	942F9F	8342 411584	NINA FROLOVA	{"phone": "+70321719991"}
0005432121257	942F9F	9629 489586	GLEB GERASIMOV	{"phone": "+70656361168"}
0005432121258	2C250F	9062 279527	GENNADIY MOROZOV	{"email": "morozov_g.011964@postgrespro.ru", "phone": "+70522529850"}
0005432121259	FAD1A2	6496 715523	KSENIYA SOKOLOVA	{"email": "k_sokolova.17021968@postgrespro.ru", "phone": "+70517729386"}
0005432121260	FAD1A2	1923 359010	SERGEY POPOV	{"phone": "+70137815274"}
0005432121261	EE5C60	7663 221666	ALENA MAKAROVA	{"email": "alena-makarova_1962@postgrespro.ru", "phone": "+70002012455"}
0005432121262	352460	5584 667216	EKATERINA KOLESNIKOVA	{"email": "e.kolesnikova.1988@postgrespro.ru", "phone": "+70786723139"}
0005432121263	D47B52	5230 857623	LYUDMILA AFANASEVA	{"phone": "+70095518495"}
0005432121264	B1FA75	5582 085516	MATVEY GAVRILOV	{"email": "gavrilov_matvey-09111966@postgrespro.ru", "phone": "+70956494232"}
0005432121265	F01EB4	5921 694877	SVETLANA KAZAKOVA	{"email": "svetlana_kazakova_14021970@postgrespro.ru", "phone": "+70497915628"}
0005432121266	F01EB4	0550 682573	VLADISLAV OSIPOV	{"phone": "+70121304977"}
0005432121267	B2055E	4494 972900	GULNARA ROMANOVA	{"email": "gulnara-romanova1971@postgrespro.ru", "phone": "+70634180059"}
0005432121268	B2055E	9859 560835	ANDREY PAVLOV	{"email": "andreypavlov_1973@postgrespro.ru", "phone": "+70154682477"}
0005432121269	06B0DE	0289 410952	VALERIY SCHERBAKOV	{"email": "scherbakov_v_1984@postgrespro.ru", "phone": "+70288268915"}
0005432121270	6590EA	6787 528216	OLEG KISELEV	{"email": "okiselev_12091970@postgrespro.ru", "phone": "+70544992596"}
0005432121271	A33985	4346 485384	YULIYA ALEKSEEVA	{"phone": "+70456599203"}
0005432121272	C482DD	1636 474783	ALEKSANDR PAVLOV	{"phone": "+70267085917"}
0005432121273	C482DD	9711 400924	ALEKSEY YAKOVLEV	{"email": "a.yakovlev_1977@postgrespro.ru", "phone": "+70423990152"}
0005432121274	7B843B	3829 481759	VALENTINA KULIKOVA	{"email": "valentina-kulikova-1973@postgrespro.ru", "phone": "+70663765643"}
0005432121275	6D8261	9461 333283	SVETLANA DENISOVA	{"email": "denisova_svetlana25081975@postgrespro.ru", "phone": "+70436651200"}
0005432121276	C92EFB	8529 337858	VYACHESLAV CHERNOV	{"phone": "+70959564744"}
0005432121277	3A8A35	8933 423510	GALINA VOLKOVA	{"email": "galina.volkova.1984@postgrespro.ru", "phone": "+70398785752"}
0005432121278	588B8D	8860 891914	VLADIMIR VLASOV	{"phone": "+70347000002"}
0005432121279	63E627	8648 197061	DMITRIY MELNIKOV	{"email": "dmitriy.melnikov.14011965@postgrespro.ru", "phone": "+70313859418"}
0005432121280	64DAA1	4665 591651	LARISA FILATOVA	{"email": "larisa_filatova011963@postgrespro.ru", "phone": "+70893720312"}
0005432121281	0BCD8D	3899 263485	EVGENIY KUDRYASHOV	{"email": "evgeniy_kudryashov29091968@postgrespro.ru", "phone": "+70398633478"}
0005432121282	0BCD8D	0959 616008	TATYANA FROLOVA	{"email": "frolova.t_1965@postgrespro.ru", "phone": "+70148403654"}
0005432121283	B0DFBD	2185 963666	YURIY KAZAKOV	{"email": "kazakov.yuriy-19011967@postgrespro.ru", "phone": "+70578794521"}
0005432121284	AF737B	7352 329162	IVAN PETROV	{"email": "petrov_ivan-1969@postgrespro.ru", "phone": "+70235619384"}
0005432121285	7E1CA4	1004 041861	ELENA DANILOVA	{"phone": "+70824757010"}
0005432121286	804033	3759 601338	TATYANA KRASNOVA	{"email": "tatyana.krasnova-1977@postgrespro.ru", "phone": "+70093269770"}
0005432121287	0D0AC6	0988 972801	DMITRIY KAZAKOV	{"email": "kazakovdmitriy031977@postgrespro.ru", "phone": "+70509641050"}
0005432121288	9270CC	9286 964513	OLGA SOKOLOVA	{"phone": "+70589454855"}
0005432121289	9270CC	4147 391954	TATYANA SOLOVEVA	{"email": "soloveva-tatyana_021977@postgrespro.ru", "phone": "+70544489671"}
0005432121290	044F3E	3796 474331	DENIS ZAKHAROV	{"phone": "+70802154145"}
0005432121291	044F3E	9736 880446	VYACHESLAV PETROV	{"email": "vpetrov.021972@postgrespro.ru", "phone": "+70106979868"}
0005432121292	152336	1036 710500	DMITRIY KISELEV	{"email": "dmitriykiselev.16041972@postgrespro.ru", "phone": "+70832955053"}
0005432121293	40A02B	0811 301505	ELENA VOROBEVA	{"phone": "+70320117733"}
0005432121294	D1A179	4321 146874	KONSTANTIN GAVRILOV	{"email": "gavrilov_k_1976@postgrespro.ru", "phone": "+70582694825"}
0005432121295	D1A179	0818 632970	EKATERINA TROFIMOVA	{"email": "e-trofimova_091986@postgrespro.ru", "phone": "+70197189704"}
0005432121296	2F6F9F	6312 264264	VLADISLAV MIRONOV	{"email": "v_mironov_02091977@postgrespro.ru", "phone": "+70837624616"}
0005432121297	2F6F9F	7020 440139	NATALYA IVANOVA	{"email": "n-ivanova091978@postgrespro.ru", "phone": "+70359845893"}
0005432121298	7B646B	4241 666382	IVAN BORISOV	{"phone": "+70032551706"}
0005432121299	7B646B	4090 450539	ANTONINA POPOVA	{"email": "antonina.popova.051981@postgrespro.ru", "phone": "+70098022337"}
0005432121300	C2CE1A	8702 278771	NATALYA VOROBEVA	{"phone": "+70606099026"}
0005432121301	C2CE1A	1805 239711	TATYANA IVANOVA	{"phone": "+70802897056"}
0005432121302	C2CE1A	5960 476804	ANNA KOZLOVA	{"email": "kozlova_a.011984@postgrespro.ru", "phone": "+70909141801"}
0005432121303	F2FB3E	1678 177506	FEDOR KISELEV	{"phone": "+70193679577"}
0005432121304	F2FB3E	9931 539255	TATYANA OSIPOVA	{"email": "osipova-tatyana20011966@postgrespro.ru", "phone": "+70752846046"}
0005432121305	F2FB3E	8963 044629	MARIYA NIKOLAEVA	{"phone": "+70834674853"}
0005432121306	9310B2	6399 671387	MIKHAIL SMIRNOV	{"email": "smirnov_mikhail-1972@postgrespro.ru", "phone": "+70208550223"}
0005432121307	80E800	8796 984590	ALEKSANDRA POTAPOVA	{"email": "potapovaa1977@postgrespro.ru", "phone": "+70832414589"}
0005432121308	80E800	1515 384601	NATALYA ORLOVA	{"phone": "+70740003525"}
0005432121309	86092D	1991 395509	ELENA GORBUNOVA	{"phone": "+70901864094"}
0005432121310	997027	0289 808444	ROMAN KISELEV	{"email": "kiselev_r_051971@postgrespro.ru", "phone": "+70518849117"}
0005432121311	A1E436	4042 574608	VLADIMIR ORLOV	{"email": "vladimirorlov.051970@postgrespro.ru", "phone": "+70235408703"}
0005432121312	A1E436	4080 345349	NATALYA NAZAROVA	{"phone": "+70312856798"}
0005432121313	FC4129	6325 007819	NADEZHDA PAVLOVA	{"phone": "+70919932382"}
0005432121314	FC4129	2631 167065	DMITRIY VOROBEV	{"phone": "+70282512237"}
0005432121315	FC4129	9337 481783	LILIYA SOROKINA	{"phone": "+70385287507"}
0005432121316	91011E	7620 116584	VALERIY SEMENOV	{"email": "v.semenov.30101964@postgrespro.ru", "phone": "+70482853696"}
0005432121317	91011E	9245 116252	EKATERINA SEMENOVA	{"phone": "+70525940259"}
0005432121318	91011E	5929 574371	OLGA DANILOVA	{"phone": "+70805012681"}
0005432121319	C11BA7	8199 218445	YULIYA VASILEVA	{"email": "vasileva.y_16071971@postgrespro.ru", "phone": "+70123010257"}
0005432121320	6A979F	0756 388647	ANNA MOISEEVA	{"email": "moiseevaa_101980@postgrespro.ru", "phone": "+70169926082"}
0005432121321	6A979F	3569 728157	IRAIDA MASLOVA	{"email": "i_maslova29121968@postgrespro.ru", "phone": "+70901686964"}
0005432121322	204504	8409 623257	TATYANA ZAKHAROVA	{"phone": "+70541498686"}
0005432121323	B437E3	4263 411505	ILGIZ SEMENOV	{"phone": "+70387207630"}
0005432121324	83D036	8023 176863	SERGEY MOISEEV	{"phone": "+70316576846"}
0005432121325	83D036	1716 438104	ALEKSEY FEDOTOV	{"phone": "+70592742629"}
0005432121326	CB0ACE	8098 286372	LARISA BELYAEVA	{"email": "belyaeva_larisa-051969@postgrespro.ru", "phone": "+70856103240"}
0005432121327	5D1BFA	0305 443918	EVGENIYA IVANOVA	{"phone": "+70695788315"}
0005432121328	BA3C21	5564 574899	VITALIY CHERNOV	{"phone": "+70479340845"}
0005432121329	BA3C21	4899 138034	MIKHAIL VOLKOV	{"email": "mikhail_volkov-021972@postgrespro.ru", "phone": "+70790250214"}
0005432121330	BA3C21	5438 183159	LYUBOV ANTONOVA	{"email": "l.antonova_021972@postgrespro.ru", "phone": "+70604096899"}
0005432121331	F4B779	7054 881412	VIKTOR SMIRNOV	{"email": "smirnov-v_16081969@postgrespro.ru", "phone": "+70393032498"}
0005432121332	14CE12	6588 448771	TATYANA RODIONOVA	{"email": "rodionova.t_041978@postgrespro.ru", "phone": "+70905892907"}
0005432121333	14CE12	4022 662181	MARINA ANISIMOVA	{"email": "anisimova-m021974@postgrespro.ru", "phone": "+70957297664"}
0005432121334	14CE12	0752 255395	MARINA DAVYDOVA	{"email": "davydova-marina.1974@postgrespro.ru", "phone": "+70592407097"}
0005432121335	C579EF	0167 501585	EKATERINA VLASOVA	{"phone": "+70094454011"}
0005432121336	0B363F	6574 801206	GENNADIY KOROLEV	{"phone": "+70451522857"}
0005432121337	0B363F	2010 579533	GENNADIY STEPANOV	{"email": "stepanov-g_1961@postgrespro.ru", "phone": "+70410663284"}
0005432121338	0D5504	5554 831923	DMITRIY KISELEV	{"phone": "+70832272507"}
0005432121339	0D5504	4847 814973	VALERIY BARANOV	{"phone": "+70085136869"}
0005432121340	583A4B	6047 441055	OLEG PAVLOV	{"phone": "+70149479587"}
0005432121341	583A4B	8501 031935	GALINA NOVIKOVA	{"email": "novikova.g_101964@postgrespro.ru", "phone": "+70474453031"}
0005432121342	0A1511	0284 159713	KIRILL EGOROV	{"phone": "+70362724924"}
0005432121343	2F5D63	7698 382833	MIKHAIL NIKOLAEV	{"email": "nikolaevmikhail_091975@postgrespro.ru", "phone": "+70113315115"}
0005432121344	E8BF06	4130 379769	VITALIY DENISOV	{"phone": "+70758785695"}
0005432121345	BF7DE5	5239 952058	ALEKSANDR ALEKSANDROV	{"email": "a.aleksandrov20041973@postgrespro.ru", "phone": "+70204563859"}
0005432121346	5D0B6D	0812 329397	SVETLANA PAVLOVA	{"email": "svetlana-pavlova.01011983@postgrespro.ru", "phone": "+70893424680"}
0005432121347	72C789	2724 185279	ALEKSANDRA GAVRILOVA	{"phone": "+70617892292"}
0005432121348	968ED9	3632 005356	DMITRIY MELNIKOV	{"phone": "+70664827808"}
0005432121349	20E57C	7862 755635	MIKHAIL ROMANOV	{"email": "mikhail_romanov_12111972@postgrespro.ru", "phone": "+70493858991"}
0005432121350	20E57C	5973 806535	VASILIY SOKOLOV	{"email": "vasiliy-sokolov-16071970@postgrespro.ru", "phone": "+70857157124"}
0005432121351	DF47ED	9411 932048	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr_1963@postgrespro.ru", "phone": "+70144134381"}
0005432121352	5B0291	9691 633610	IGOR GAVRILOV	{"phone": "+70031631837"}
0005432121353	5B0291	4529 800389	ELENA BELOVA	{"email": "elena-belova-011974@postgrespro.ru", "phone": "+70244875724"}
0005432121354	5B0291	0331 843469	MIKHAIL VOLKOV	{"phone": "+70580006907"}
0005432121355	C2D861	5191 807842	LYUBOV SOKOLOVA	{"email": "sokolova.lyubov.1960@postgrespro.ru", "phone": "+70274934005"}
0005432121356	E636AF	7354 057211	PAVEL SHEVCHENKO	{"phone": "+70059987385"}
0005432121357	0FF23C	1330 999670	YULIYA ANDREEVA	{"email": "andreeva_yuliya011980@postgrespro.ru", "phone": "+70395192956"}
0005432121358	2461F0	7208 975112	TATYANA NESTEROVA	{"phone": "+70371491757"}
0005432121359	B16BA7	1830 686783	MARIYA BELYAEVA	{"phone": "+70451806494"}
0005432121360	B16BA7	5997 480829	DIANA EFIMOVA	{"phone": "+70887072372"}
0005432121361	B16BA7	7477 668965	YURIY PETROV	{"email": "ypetrov-01121962@postgrespro.ru", "phone": "+70639037000"}
0005432121362	612606	0761 676625	ANDREY SAVELEV	{"email": "a_savelev_071961@postgrespro.ru", "phone": "+70966375564"}
0005432121363	184763	6035 515007	IGOR MOROZOV	{"email": "i-morozov-121972@postgrespro.ru", "phone": "+70769531332"}
0005432121364	184763	3921 767200	VIKTORIYA SMIRNOVA	{"phone": "+70691787130"}
0005432121365	461359	4453 215015	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr-30111982@postgrespro.ru", "phone": "+70326455999"}
0005432121366	8A09D1	9446 625314	MARIYA SCHERBAKOVA	{"email": "mariya.scherbakova-051978@postgrespro.ru", "phone": "+70443574965"}
0005432121367	361D3B	8479 611400	KLARA BORISOVA	{"phone": "+70629781175"}
0005432121368	159E77	2269 583101	TAMARA OSIPOVA	{"phone": "+70346841423"}
0005432121369	E17363	1356 773285	IVAN BORISOV	{"phone": "+70391370029"}
0005432121370	E17363	1392 981189	GALINA GRISHINA	{"email": "grishinagalina_30011972@postgrespro.ru", "phone": "+70132638531"}
0005432121371	1B6DBF	5869 074819	OLGA GRISHINA	{"phone": "+70414727499"}
0005432121372	EC8900	0657 945745	ALEKSANDR YAKOVLEV	{"phone": "+70783274333"}
0005432121373	E0B674	5780 876776	VIKTORIYA POLYAKOVA	{"email": "v.polyakova-1982@postgrespro.ru", "phone": "+70011887096"}
0005432121374	B33D99	4802 226094	EDUARD ABRAMOV	{"phone": "+70587968134"}
0005432121375	D5671B	0414 923745	TATYANA KUZNECOVA	{"email": "tkuznecova-21011972@postgrespro.ru", "phone": "+70483065428"}
0005432121376	D5671B	0914 203331	IRINA PETROVA	{"email": "petrova.i_1963@postgrespro.ru", "phone": "+70481533345"}
0005432121377	6F414F	0363 023936	VALENTINA FROLOVA	{"phone": "+70982198981"}
0005432121378	3170BF	0400 145592	DARYA POPOVA	{"email": "daryapopova_071971@postgrespro.ru", "phone": "+70905908162"}
0005432121379	3170BF	9835 663842	NIKOLAY GRIGOREV	{"email": "n_grigorev-081967@postgrespro.ru", "phone": "+70633775968"}
0005432121380	F59E79	1358 811168	ANDREY ALEKSEEV	{"email": "aalekseev.1982@postgrespro.ru", "phone": "+70774736554"}
0005432121381	F59E79	4815 379499	SVETLANA ANISIMOVA	{"email": "svetlana-anisimova.16021967@postgrespro.ru", "phone": "+70393429115"}
0005432121382	E76DFD	7581 071065	ALEKSEY KUZNECOV	{"phone": "+70458206635"}
0005432121383	96C0B6	1079 567369	TAMARA KULIKOVA	{"phone": "+70464468267"}
0005432121384	96C0B6	5788 157572	NINA MIKHAYLOVA	{"phone": "+70311107038"}
0005432121385	96C0B6	8028 315121	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.28091971@postgrespro.ru", "phone": "+70554207604"}
0005432121386	F9FE11	1173 614575	IGOR KARPOV	{"email": "igor.karpov091966@postgrespro.ru", "phone": "+70397738173"}
0005432121387	F9FE11	7229 169620	YULIYA GERASIMOVA	{"phone": "+70369430566"}
0005432121388	65FF25	7258 731582	DINARA KARPOVA	{"phone": "+70182418764"}
0005432121389	F7B5A9	6681 912224	ELENA MOROZOVA	{"phone": "+70576751481"}
0005432121390	F7B5A9	6763 275771	IRINA TARASOVA	{"phone": "+70013758948"}
0005432121391	FA83C4	2685 424227	LEONID ALEKSEEV	{"email": "alekseev-leonid.011982@postgrespro.ru", "phone": "+70858141292"}
0005432121392	F30D76	6944 008135	VIKTORIYA SIDOROVA	{"phone": "+70935635155"}
0005432121393	664FF0	6564 800549	SERGEY MAKSIMOV	{"email": "maksimov.sergey-121974@postgrespro.ru", "phone": "+70187411348"}
0005432121394	A0EA0B	7846 425186	VLADIMIR IVANOV	{"phone": "+70189670175"}
0005432121395	07B60B	3926 552109	ARKADIY MIRONOV	{"email": "mironov_arkadiy_12041967@postgrespro.ru", "phone": "+70952348901"}
0005432121396	07B60B	8607 126862	MARINA EFREMOVA	{"phone": "+70275785805"}
0005432121397	EF738A	0908 240461	GALINA FROLOVA	{"phone": "+70499699890"}
0005432121398	43282F	4874 204690	OLGA SMIRNOVA	{"phone": "+70355445606"}
0005432121399	43282F	6254 143489	NADEZHDA ANTONOVA	{"email": "antonovan.04061970@postgrespro.ru", "phone": "+70793062129"}
0005432121400	EBE879	3464 607920	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya081985@postgrespro.ru", "phone": "+70061511569"}
0005432121401	EBE879	5898 846605	YULIYA ILINA	{"phone": "+70690044496"}
0005432121402	2F0A06	6065 135412	LYUBOV MOISEEVA	{"email": "lyubov.moiseeva_1976@postgrespro.ru", "phone": "+70145692311"}
0005432121403	F9F966	3174 571572	SVETLANA KUZNECOVA	{"phone": "+70120740694"}
0005432121404	F9F966	2212 627855	DENIS KISELEV	{"email": "kiselevdenis-28041962@postgrespro.ru", "phone": "+70248597853"}
0005432121405	EB59A4	2475 889999	IRINA MARTYNOVA	{"email": "martynova_i.01071972@postgrespro.ru", "phone": "+70414020375"}
0005432121406	949FEA	6106 185765	ALEKSANDR FOMIN	{"phone": "+70411600308"}
0005432121407	FB61D4	8922 423655	NADEZHDA OSIPOVA	{"email": "n_osipova_1974@postgrespro.ru", "phone": "+70026289763"}
0005432121408	EA058E	0929 939820	ANATOLIY VLASOV	{"phone": "+70144757802"}
0005432121409	B132D1	6325 888321	SERGEY ALEKSEEV	{"email": "alekseevsergey021977@postgrespro.ru", "phone": "+70525315009"}
0005432121410	6429CD	4967 095586	VIKTOR RODIONOV	{"phone": "+70961238423"}
0005432121411	52B3EF	4971 880002	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila15031981@postgrespro.ru", "phone": "+70341146474"}
0005432121412	6DDF41	9937 571445	DMITRIY MELNIKOV	{"phone": "+70462128906"}
0005432121413	6DDF41	1758 405015	NINA SOKOLOVA	{"email": "sokolova-nina.1964@postgrespro.ru", "phone": "+70439232772"}
0005432121414	61B76F	3785 686415	MIKHAIL NIKOLAEV	{"email": "mnikolaev-031979@postgrespro.ru", "phone": "+70213808317"}
0005432121415	E39B41	4222 969525	ANNA ANTONOVA	{"phone": "+70799604542"}
0005432121416	AD82F0	1891 138284	OLGA ORLOVA	{"phone": "+70558485585"}
0005432121417	AD82F0	7169 948660	IGOR SOLOVEV	{"email": "isolovev.07071985@postgrespro.ru", "phone": "+70539034847"}
0005432121418	561573	7269 556462	DMITRIY MELNIKOV	{"phone": "+70283251280"}
0005432121419	3BD4C2	5346 362949	MARIYA TROFIMOVA	{"phone": "+70456370447"}
0005432121420	872AC2	9523 069874	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev_1980@postgrespro.ru", "phone": "+70578816608"}
0005432121421	D2D610	4206 649638	VALENTINA ANISIMOVA	{"phone": "+70500120404"}
0005432121422	76B819	5058 472041	TATYANA OSIPOVA	{"phone": "+70604432447"}
0005432121423	44F8D6	6511 142541	RAISA POTAPOVA	{"email": "potapova_raisa14061973@postgrespro.ru", "phone": "+70047851861"}
0005432121424	44F8D6	4644 428699	VYACHESLAV KAZAKOV	{"phone": "+70177182447"}
0005432121425	114812	5485 727065	NADEZHDA TARASOVA	{"email": "nadezhdatarasova-17091976@postgrespro.ru", "phone": "+70486917855"}
0005432121426	7CA10A	1382 833002	KONSTANTIN DENISOV	{"phone": "+70260180039"}
0005432121427	9F82BB	4730 828811	TATYANA MAKSIMOVA	{"email": "maksimova_t_1971@postgrespro.ru", "phone": "+70708946184"}
0005432121428	9F82BB	7105 137259	ALEKSEY NAZAROV	{"phone": "+70111644632"}
0005432121429	B7B0BE	1848 649139	ANDREY CHERNOV	{"email": "andrey.chernov081971@postgrespro.ru", "phone": "+70759968422"}
0005432121430	3728B8	9135 511821	ANTON MATVEEV	{"email": "matveevanton091963@postgrespro.ru", "phone": "+70536642307"}
0005432121431	2CB567	1647 878907	IRINA KOLESNIKOVA	{"email": "irina.kolesnikova.1967@postgrespro.ru", "phone": "+70694142706"}
0005432121432	9547DD	8802 677424	ASKAR KISELEV	{"email": "kiselev_askar_1971@postgrespro.ru", "phone": "+70765399072"}
0005432121433	9547DD	2406 837726	ELENA KOROLEVA	{"email": "korolevaelena09061974@postgrespro.ru", "phone": "+70770488096"}
0005432121434	0D3FBE	3766 544936	LEV MOROZOV	{"phone": "+70499161238"}
0005432121435	004E44	3466 089806	ANNA NIKITINA	{"email": "a_nikitina1967@postgrespro.ru", "phone": "+70722322466"}
0005432121436	004E44	3694 494080	DMITRIY DENISOV	{"email": "denisov_dmitriy_061971@postgrespro.ru", "phone": "+70544336500"}
0005432121437	004E44	6059 785463	DMITRIY DAVYDOV	{"email": "davydov-d1968@postgrespro.ru", "phone": "+70433373608"}
0005432121438	F34C15	7833 328666	ANDREY TIKHONOV	{"phone": "+70951230257"}
0005432121439	F34C15	7003 896586	DMITRIY VASILEV	{"email": "vasilev-d_1968@postgrespro.ru", "phone": "+70132166519"}
0005432121440	F34C15	4554 375162	VARVARA VASILEVA	{"phone": "+70025828294"}
0005432121441	1DD3F8	0499 110888	ILYA ANTONOV	{"email": "ilyaantonov.13121972@postgrespro.ru", "phone": "+70267999816"}
0005432121442	1DD3F8	7213 256999	PAVEL VASILEV	{"phone": "+70969042751"}
0005432121443	7DE087	8161 957532	DANIL BORISOV	{"phone": "+70086284606"}
0005432121444	19D0FA	1477 393816	PAVEL FILIPPOV	{"email": "filippovp_27051972@postgrespro.ru", "phone": "+70565441101"}
0005432121445	957EFC	1051 262897	MIKHAIL ZAKHAROV	{"phone": "+70710445021"}
0005432121446	06CFBC	5328 171019	ANDREY KRASNOV	{"phone": "+70548064559"}
0005432121447	06CFBC	6484 539885	ALEKSANDRA YUDINA	{"phone": "+70681504611"}
0005432121448	EE9497	2771 468089	ALSU KOMAROVA	{"phone": "+70371420389"}
0005432121449	D103C0	9090 374105	ELENA MOROZOVA	{"phone": "+70294669919"}
0005432121450	6BFD2B	4156 052113	VALENTINA ZHUKOVA	{"email": "zhukovavalentina-1965@postgrespro.ru", "phone": "+70404540683"}
0005432121451	6BFD2B	1425 394665	LYUBOV MOISEEVA	{"phone": "+70658336574"}
0005432121452	49D75F	7105 765307	TATYANA KUZNECOVA	{"phone": "+70502995001"}
0005432121453	654684	0997 324715	ANTON CHERNOV	{"email": "a.chernov_051973@postgrespro.ru", "phone": "+70024486667"}
0005432121454	FF9F71	9178 575228	ALEKSEY FEDOROV	{"phone": "+70072952567"}
0005432121455	FF9F71	0216 999221	ANDREY VASILEV	{"phone": "+70247374516"}
0005432121456	71555E	1154 432370	MARIYA SAVELEVA	{"email": "mariya_saveleva.081966@postgrespro.ru", "phone": "+70096943704"}
0005432121457	B9EE5A	9166 738341	ALISHER VASILEV	{"email": "avasilev.1969@postgrespro.ru", "phone": "+70198710357"}
0005432121458	4839FD	5678 463187	NADEZHDA VASILEVA	{"phone": "+70345197868"}
0005432121459	4839FD	4014 994798	ANDREY DMITRIEV	{"email": "dmitriev_a-121977@postgrespro.ru", "phone": "+70155451484"}
0005432121460	86607C	3970 597480	NADEZHDA IVANOVA	{"email": "ivanovan-22011967@postgrespro.ru", "phone": "+70724471167"}
0005432121461	924135	9920 673261	SVETLANA IVANOVA	{"phone": "+70930862358"}
0005432121462	D52448	0625 947673	LYUDMILA NOVIKOVA	{"email": "novikova-lyudmila_011983@postgrespro.ru", "phone": "+70970200333"}
0005432121463	F4A350	3630 312437	EKATERINA YAKOVLEVA	{"phone": "+70927893387"}
0005432121464	FE7FB9	0705 994118	MAKSIM POPOV	{"email": "mpopov_18111977@postgrespro.ru", "phone": "+70912559581"}
0005432121465	6DB49E	1278 651199	ELENA MELNIKOVA	{"email": "elenamelnikova.02051975@postgrespro.ru", "phone": "+70524407715"}
0005432121466	6DB49E	9788 120420	VALENTINA FROLOVA	{"email": "v_frolova_091975@postgrespro.ru", "phone": "+70046809157"}
0005432121467	82AB85	6225 513194	SERGEY FOMIN	{"phone": "+70383361907"}
0005432121468	82AB85	5409 590070	PAVEL ISAEV	{"email": "pavelisaev_07111965@postgrespro.ru", "phone": "+70454893141"}
0005432121469	C586D9	9532 948841	DENIS MOROZOV	{"phone": "+70128052429"}
0005432121470	FF7DFC	0076 509994	VLADIMIR VASILEV	{"email": "vasilev_v-1974@postgrespro.ru", "phone": "+70943181431"}
0005432121471	1E7595	2754 525813	TAMARA KARPOVA	{"email": "karpova.t121972@postgrespro.ru", "phone": "+70958856243"}
0005432121472	CB8BF9	9717 750859	VLADIMIR BELOV	{"email": "belov_v-1977@postgrespro.ru", "phone": "+70147925514"}
0005432121473	8B8438	1544 828077	MAKSIM MATVEEV	{"phone": "+70174913456"}
0005432121474	898F27	1537 970901	PETR MIRONOV	{"email": "petr.mironov-23101981@postgrespro.ru", "phone": "+70509844000"}
0005432121475	B96983	5055 715968	VLADIMIR KAZAKOV	{"phone": "+70882382274"}
0005432121476	8389A9	6700 141085	VLADIMIR SIDOROV	{"phone": "+70177361845"}
0005432121477	2A5104	3400 390781	EVGENIY IVANOV	{"email": "evgeniy_ivanov061961@postgrespro.ru", "phone": "+70471401020"}
0005432121478	568C58	8720 096409	MIKHAIL VOLKOV	{"phone": "+70430474172"}
0005432121479	568C58	4914 146389	RINAT OSIPOV	{"email": "r.osipov031962@postgrespro.ru", "phone": "+70406748491"}
0005432121480	EEB0D6	3321 083641	MAKSIM ILIN	{"email": "m-ilin051972@postgrespro.ru", "phone": "+70313122487"}
0005432121481	BA47DB	6947 258864	VERA DENISOVA	{"email": "vera-denisova.1964@postgrespro.ru", "phone": "+70057811114"}
0005432121482	CAF509	5132 817232	ANDREY YAKOVLEV	{"email": "yakovlev_andrey-1973@postgrespro.ru", "phone": "+70058914253"}
0005432121483	CAF509	8798 837578	ALEKSANDR FEDOROV	{"email": "fedorov.a-1976@postgrespro.ru", "phone": "+70606331648"}
0005432121484	AD0DF8	4703 505512	SERGEY STEPANOV	{"phone": "+70553230780"}
0005432121485	AD0DF8	1477 352007	MARINA ZAYCEVA	{"email": "mzayceva-1976@postgrespro.ru", "phone": "+70537329140"}
0005432121486	45386B	5989 433090	VIKTOR IVANOV	{"email": "ivanov-v-1977@postgrespro.ru", "phone": "+70768991158"}
0005432121487	93207C	8988 603783	ANATOLIY ISAEV	{"phone": "+70459230027"}
0005432121488	442A5E	1565 678316	ELENA KONDRATEVA	{"email": "ekondrateva-071974@postgrespro.ru", "phone": "+70011251957"}
0005432121489	52736B	5506 243403	PAVEL ANDREEV	{"email": "p-andreev-23121969@postgrespro.ru", "phone": "+70366715232"}
0005432121490	73EBD9	1851 853312	YURIY SCHERBAKOV	{"phone": "+70695048774"}
0005432121491	0F4D1D	7659 376580	VALERIY SEMENOV	{"email": "semenovvaleriy_101977@postgrespro.ru", "phone": "+70506246122"}
0005432121492	CB7FB2	5613 663105	DMITRIY DAVYDOV	{"phone": "+70988869249"}
0005432121493	70B4C8	2206 691188	SERGEY KISELEV	{"email": "s.kiselev-111963@postgrespro.ru", "phone": "+70066357083"}
0005432121494	F45DFD	3910 421596	VERA ANDREEVA	{"email": "vera.andreeva_101982@postgrespro.ru", "phone": "+70049857188"}
0005432121495	F45DFD	6874 158243	TAMARA RYABOVA	{"phone": "+70414837553"}
0005432121496	7D3033	5060 151101	NIKOLAY BONDARENKO	{"phone": "+70726630473"}
0005432121497	86A17E	1491 477650	NADEZHDA MOROZOVA	{"email": "morozova-nadezhda-10081973@postgrespro.ru", "phone": "+70269677875"}
0005432121498	4D9069	5176 559659	YULIYA KOLESNIKOVA	{"phone": "+70877652609"}
0005432121499	35F272	5743 014213	KRISTINA MAKSIMOVA	{"phone": "+70749225937"}
0005432121500	35F272	6677 734905	NINA ANDREEVA	{"phone": "+70886576216"}
0005432121501	35F272	1626 187678	ANTONINA NAZAROVA	{"email": "nazarova.antonina_081978@postgrespro.ru", "phone": "+70896625539"}
0005432121502	730609	7977 634617	SERGEY POPOV	{"phone": "+70975672090"}
0005432121503	6A8369	4008 023257	MARIYA VOROBEVA	{"email": "mariya.vorobeva_13101970@postgrespro.ru", "phone": "+70680526551"}
0005432121504	C7598B	2014 454746	GENNADIY FEDOROV	{"phone": "+70937375787"}
0005432121505	C7598B	6089 567974	ELENA MALYSHEVA	{"phone": "+70344414468"}
0005432121506	2A59CF	4226 306854	LYUBOV ABRAMOVA	{"email": "abramova-lyubov_071971@postgrespro.ru", "phone": "+70192998467"}
0005432121507	2A59CF	5457 524933	NIKOLAY KUZNECOV	{"email": "n.kuznecov_1964@postgrespro.ru", "phone": "+70950988569"}
0005432121508	90F4E8	5100 601453	ELENA ROMANOVA	{"email": "e-romanova1972@postgrespro.ru", "phone": "+70558980399"}
0005432121509	4DEF67	6595 227158	SERGEY VLASOV	{"email": "vlasov.sergey.07021977@postgrespro.ru", "phone": "+70083770319"}
0005432121510	89FCD0	8988 959934	SERGEY MAKSIMOV	{"phone": "+70843337118"}
0005432121511	AF799A	7737 186662	VIKTOR MIKHAYLOV	{"phone": "+70194028316"}
0005432121512	AF799A	9601 392189	ANDREY SOROKIN	{"email": "sorokin-a_1971@postgrespro.ru", "phone": "+70530048792"}
0005432121513	AF799A	7938 824525	IVAN SEMENOV	{"phone": "+70969153600"}
0005432121514	B3FC09	4833 671813	ANTON GERASIMOV	{"email": "antongerasimov.011964@postgrespro.ru", "phone": "+70060721636"}
0005432121515	FCCB2D	3380 489249	YURIY POPOV	{"phone": "+70721457561"}
0005432121516	A34C8E	8368 159773	NIKOLAY SMIRNOV	{"email": "n_smirnov-1972@postgrespro.ru", "phone": "+70955035960"}
0005432121517	A34C8E	7085 453286	ARKADIY FILIPPOV	{"phone": "+70531525934"}
0005432121518	18576A	9497 800690	ALEKSANDR BORISOV	{"email": "aleksandrborisov091977@postgrespro.ru", "phone": "+70862069616"}
0005432121519	7F7C17	1120 760333	ROMAN POPOV	{"phone": "+70186269814"}
0005432121520	5F0283	9254 195155	PETR NIKOLAEV	{"phone": "+70437700637"}
0005432121521	5F0283	6183 202270	EVGENIY MAKAROV	{"phone": "+70811646193"}
0005432121522	646CCD	9690 022830	DANILA TIKHONOV	{"phone": "+70912711915"}
0005432121523	812043	3934 999797	NADEZHDA NOVIKOVA	{"phone": "+70078756553"}
0005432121524	812043	0645 922539	FATYMA PAVLOVA	{"email": "pavlovaf_1968@postgrespro.ru", "phone": "+70296199078"}
0005432121525	5D2E45	6041 941300	EVGENIY KOROLEV	{"phone": "+70318661078"}
0005432121526	95CFB9	4993 665744	EVGENIY NAZAROV	{"email": "nazarovevgeniy-1981@postgrespro.ru", "phone": "+70536864858"}
0005432121527	373321	7354 477482	ALEKSEY GERASIMOV	{"email": "gerasimov_aleksey_091973@postgrespro.ru", "phone": "+70622040097"}
0005432121528	C99BA4	2167 022599	EKATERINA NAZAROVA	{"phone": "+70520227864"}
0005432121529	C99BA4	4552 341091	GENNADIY PAVLOV	{"email": "gennadiy-pavlov-111963@postgrespro.ru", "phone": "+70536713618"}
0005432121530	1A3899	7712 050515	ELENA KOZLOVA	{"email": "e-kozlova121971@postgrespro.ru", "phone": "+70974752362"}
0005432121531	1A3899	2098 674259	VLADIMIR MAKAROV	{"email": "vmakarov-101964@postgrespro.ru", "phone": "+70302461705"}
0005432121532	959678	4595 471902	ALEKSANDR KOROLEV	{"phone": "+70899262596"}
0005432121533	6D60CE	3439 085914	ELENA NIKIFOROVA	{"email": "e_nikiforova-08111964@postgrespro.ru", "phone": "+70837907233"}
0005432121534	10A404	8957 892518	VASILIY DENISOV	{"email": "denisovv-041978@postgrespro.ru", "phone": "+70421955788"}
0005432121535	0F422D	7609 115628	ANDREY KUZNECOV	{"phone": "+70224021054"}
0005432121536	B12102	6453 599337	EMIL ALEKSEEV	{"email": "e.alekseev_07071977@postgrespro.ru", "phone": "+70729124640"}
0005432121537	9EBC2A	3999 451467	NIKOLAY EGOROV	{"phone": "+70515953570"}
0005432121538	9EBC2A	6217 158953	SERGEY GORBUNOV	{"email": "s-gorbunov-091971@postgrespro.ru", "phone": "+70324782972"}
0005432121539	F13B9A	5108 384069	ZINAIDA FILATOVA	{"email": "filatova-z1976@postgrespro.ru", "phone": "+70548987201"}
0005432121540	BFD673	8742 466455	ALEKSANDR DMITRIEV	{"email": "a-dmitriev1963@postgrespro.ru", "phone": "+70842452933"}
0005432121541	BFD673	1325 208735	VADIM GRIGOREV	{"email": "grigorev.v-13081969@postgrespro.ru", "phone": "+70696741239"}
0005432121542	AEBCB7	0023 025839	SERGEY SEMENOV	{"phone": "+70157135105"}
0005432121543	1596F3	2486 803030	ALEKSEY FOMIN	{"email": "a_fomin-1988@postgrespro.ru", "phone": "+70224683401"}
0005432121544	E145D8	0141 227507	TAMARA BOGDANOVA	{"phone": "+70475944846"}
0005432121545	EEBAFE	8032 159716	NATALYA TIKHONOVA	{"phone": "+70351801697"}
0005432121546	FFEFBB	3310 401219	TATYANA KUZMINA	{"email": "kuzmina.t-06051976@postgrespro.ru", "phone": "+70692163967"}
0005432121547	FFEFBB	3769 117930	ELENA SOKOLOVA	{"email": "sokolovaelena021958@postgrespro.ru", "phone": "+70710703878"}
0005432121548	C3FE69	9362 186697	ZINAIDA KUZMINA	{"email": "kuzmina_zinaida21061960@postgrespro.ru", "phone": "+70858568535"}
0005432121549	DFACC0	7144 461763	MARINA MIKHAYLOVA	{"phone": "+70080459469"}
0005432121550	B633B8	2283 130681	VALENTINA ILINA	{"email": "valentina.ilina.071980@postgrespro.ru", "phone": "+70997028975"}
0005432121551	70ADB7	7005 502514	NATALYA NIKITINA	{"email": "natalya_nikitina.091974@postgrespro.ru", "phone": "+70419391496"}
0005432121552	70ADB7	5820 787903	ALEKSANDR KISELEV	{"email": "kiselev_a14011977@postgrespro.ru", "phone": "+70789466409"}
0005432121553	12C6BD	5298 178746	ANTON MIKHAYLOV	{"phone": "+70475755838"}
0005432121554	12C6BD	7698 253653	ILYA PAVLOV	{"email": "i.pavlov031976@postgrespro.ru", "phone": "+70048066387"}
0005432121555	C556C5	2985 200047	ANATOLIY SHEVCHENKO	{"email": "shevchenkoa.25031974@postgrespro.ru", "phone": "+70601928052"}
0005432121556	362C67	5266 071150	ELENA KUZMINA	{"email": "elena-kuzmina.1970@postgrespro.ru", "phone": "+70309324396"}
0005432121557	E15577	9037 001276	ALEKSANDR MOROZOV	{"email": "morozovaleksandr-121981@postgrespro.ru", "phone": "+70705539601"}
0005432121558	F3CEA9	4297 598231	ELENA ANTONOVA	{"email": "antonova.e-1961@postgrespro.ru", "phone": "+70072072551"}
0005432121559	3DDD59	2644 139438	ALEKSANDR MOROZOV	{"email": "morozovaleksandr_1983@postgrespro.ru", "phone": "+70236576521"}
0005432121560	3DDD59	3834 304997	ARTEM KOZLOV	{"phone": "+70026709707"}
0005432121561	529AFB	7186 400832	VYACHESLAV SEMENOV	{"email": "semenov_vyacheslav1967@postgrespro.ru", "phone": "+70698333534"}
0005432121562	8FC138	6450 918656	SOFIYA POPOVA	{"email": "popova-s.04121967@postgrespro.ru", "phone": "+70098052469"}
0005432121563	76E6F8	0541 103620	ALEKSANDR AFANASEV	{"phone": "+70386191046"}
0005432121564	557844	3157 016100	VALERIY KONOVALOV	{"email": "konovalov.valeriy_011974@postgrespro.ru", "phone": "+70085548509"}
0005432121565	557844	8178 038060	VLADIMIR PETROV	{"phone": "+70813896511"}
0005432121566	4D8988	5470 873232	MIKHAIL KISELEV	{"email": "mikhailkiselev_1972@postgrespro.ru", "phone": "+70351420441"}
0005432121567	4D8988	2902 631674	PAVEL OSIPOV	{"email": "p-osipov_02111973@postgrespro.ru", "phone": "+70728108434"}
0005432121568	21EA47	0329 341586	DMITRIY PETROV	{"phone": "+70799799268"}
0005432121569	62E966	4980 420025	DMITRIY KONOVALOV	{"phone": "+70783295712"}
0005432121570	62E966	2272 981163	RAISA VOLKOVA	{"email": "raisa-volkova_15011966@postgrespro.ru", "phone": "+70013729869"}
0005432121571	47E560	5725 990478	VALENTINA KRASNOVA	{"phone": "+70172718567"}
0005432121572	AF8883	4276 120258	OLGA ZHURAVLEVA	{"phone": "+70342665802"}
0005432121573	2C124A	3551 331142	ELIZAVETA ARKHIPOVA	{"email": "earkhipova_081984@postgrespro.ru", "phone": "+70989749166"}
0005432121574	2C124A	6084 798256	EVGENIY GUSEV	{"phone": "+70607623715"}
0005432121575	29907D	6079 401369	VASILIY KONOVALOV	{"phone": "+70140707446"}
0005432121576	29907D	3747 284360	NURIYA KUZMINA	{"email": "kuzmina_nuriya.16081967@postgrespro.ru", "phone": "+70884680998"}
0005432121577	6DA551	5804 725989	IRINA MAKSIMOVA	{"email": "irina-maksimova.18091974@postgrespro.ru", "phone": "+70865150843"}
0005432121578	BD03B3	6117 746711	IGOR SHEVCHENKO	{"email": "shevchenkoi081971@postgrespro.ru", "phone": "+70372002432"}
0005432121579	E9FEA8	9907 660248	GENNADIY CHERNOV	{"email": "chernovg10031976@postgrespro.ru", "phone": "+70070758016"}
0005432121580	E9FEA8	2434 824323	MARIYA LOGINOVA	{"email": "mariya_loginova_09011978@postgrespro.ru", "phone": "+70219644231"}
0005432121581	BB5BD2	3990 785431	LIDIYA AFANASEVA	{"email": "afanasevalidiya1986@postgrespro.ru", "phone": "+70793863593"}
0005432121582	BB5BD2	6040 075626	TATYANA VOLKOVA	{"email": "t-volkova.1975@postgrespro.ru", "phone": "+70362093142"}
0005432121583	BB5BD2	7958 151814	EVGENIY NAUMOV	{"email": "e.naumov1965@postgrespro.ru", "phone": "+70109376991"}
0005432121584	962E8E	6484 148647	GENNADIY DENISOV	{"email": "denisov-g081983@postgrespro.ru", "phone": "+70545807135"}
0005432121585	500952	3816 448494	EVGENIY NAZAROV	{"email": "e-nazarov_081981@postgrespro.ru", "phone": "+70656378004"}
0005432121586	2F36F4	1418 917143	MIKHAIL SERGEEV	{"email": "mikhail.sergeev.20121968@postgrespro.ru", "phone": "+70269966174"}
0005432121587	2F36F4	1837 923810	VALENTINA DENISOVA	{"phone": "+70543962764"}
0005432121588	36D48E	6018 878720	ERIK MEDVEDEV	{"phone": "+70318364269"}
0005432121589	36D48E	0183 718155	VALENTINA NIKOLAEVA	{"email": "nikolaeva-v_1971@postgrespro.ru", "phone": "+70524185851"}
0005432121590	143B42	1976 699166	EKATERINA MOROZOVA	{"phone": "+70721551491"}
0005432121591	143B42	9160 125829	ALEKSANDR PETROV	{"email": "petrov-a.29091965@postgrespro.ru", "phone": "+70105476919"}
0005432121592	AD06CA	1241 826615	EKATERINA KOROLEVA	{"email": "ekaterina-koroleva05061974@postgrespro.ru", "phone": "+70541533644"}
0005432121593	8C6EF4	9011 080540	TATYANA KOROLEVA	{"email": "t_koroleva.13021968@postgrespro.ru", "phone": "+70160771168"}
0005432121594	DDCC1E	7792 839822	ANASTASIYA NOVIKOVA	{"email": "anastasiyanovikova_1981@postgrespro.ru", "phone": "+70719530224"}
0005432121595	DDCC1E	2762 414446	OLGA BARANOVA	{"email": "baranova_olga-21071965@postgrespro.ru", "phone": "+70510183748"}
0005432121596	11AB62	9182 047139	SERGEY IVANOV	{"phone": "+70265513863"}
0005432121597	11AB62	9604 005531	MAYYA MOROZOVA	{"email": "morozovamayya_011971@postgrespro.ru", "phone": "+70846154242"}
0005432121598	3E50AD	8046 691647	VIKTOR GAVRILOV	{"email": "v.gavrilov021976@postgrespro.ru", "phone": "+70049832899"}
0005432121599	FD30B3	0318 186358	OLGA KAZAKOVA	{"email": "kazakovao.1984@postgrespro.ru", "phone": "+70226973668"}
0005432121600	994353	0594 749591	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov-081970@postgrespro.ru", "phone": "+70947449633"}
0005432121601	148469	5593 041627	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-111965@postgrespro.ru", "phone": "+70001197179"}
0005432121602	14D901	0791 242734	KLAVDIYA ABRAMOVA	{"phone": "+70180755173"}
0005432121603	CD8DBD	3803 145265	ELENA KISELEVA	{"phone": "+70553146039"}
0005432121604	CD8DBD	7394 286199	NATALYA LAZAREVA	{"email": "lazarevanatalya_1974@postgrespro.ru", "phone": "+70630639754"}
0005432121605	50E652	9252 095620	DMITRIY EGOROV	{"email": "egorovd18021980@postgrespro.ru", "phone": "+70751160393"}
0005432121606	50E652	7994 331572	KONSTANTIN SIDOROV	{"phone": "+70788839584"}
0005432121607	FB58B4	6398 898626	VALERIY SOLOVEV	{"email": "solovev.v1973@postgrespro.ru", "phone": "+70092958720"}
0005432121608	FB58B4	6753 069511	ALEKSEY ZAYCEV	{"email": "a-zaycev.021962@postgrespro.ru", "phone": "+70554323432"}
0005432121609	DEE338	2406 101036	DANIIL TIKHONOV	{"phone": "+70057455293"}
0005432121610	F3119A	6167 088903	KSENIYA KALININA	{"email": "k_kalinina-1974@postgrespro.ru", "phone": "+70419785112"}
0005432121611	144B54	3441 730129	SERGEY ORLOV	{"email": "orlovs-27031969@postgrespro.ru", "phone": "+70979530718"}
0005432121612	212627	1536 779463	MARIYA NESTEROVA	{"email": "mariya-nesterova.29071973@postgrespro.ru", "phone": "+70160026341"}
0005432121613	5FF89F	7371 206730	LARISA EFREMOVA	{"phone": "+70145731787"}
0005432121614	5FF89F	9076 352587	ANASTASIYA GAVRILOVA	{"email": "gavrilova-anastasiya-071973@postgrespro.ru", "phone": "+70175354150"}
0005432121615	4DE7A9	2250 822243	ALENA MARTYNOVA	{"email": "a.martynova-1972@postgrespro.ru", "phone": "+70622871331"}
0005432121616	B2CE1A	4325 412303	ANNA PETROVA	{"email": "a.petrova.1959@postgrespro.ru", "phone": "+70507123169"}
0005432121617	E4306E	6910 970886	DARYA VASILEVA	{"phone": "+70454780881"}
0005432121618	E4306E	9437 067193	SERGEY OSIPOV	{"email": "s_osipov-21071974@postgrespro.ru", "phone": "+70170262726"}
0005432121619	E4306E	4556 419023	MARIYA LEBEDEVA	{"email": "lebedevamariya.011976@postgrespro.ru", "phone": "+70256532634"}
0005432121620	9E9D6B	5414 257532	VLADIMIR SIDOROV	{"phone": "+70319440480"}
0005432121621	1D048C	8716 140810	KONSTANTIN GUSEV	{"email": "gusevkonstantin1986@postgrespro.ru", "phone": "+70923800049"}
0005432121622	1D048C	6841 128608	VLADIMIR POPOV	{"email": "popov.vladimir14121976@postgrespro.ru", "phone": "+70616736927"}
0005432121623	C4E777	8606 303252	REGINA KUZMINA	{"phone": "+70679110432"}
0005432121624	B04933	0467 592798	VALERIY GUSEV	{"phone": "+70683146745"}
0005432121625	F5936F	5444 469193	SVETLANA PETROVA	{"phone": "+70729529427"}
0005432121626	5A617A	1776 485136	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov_1974@postgrespro.ru", "phone": "+70626584579"}
0005432121627	EBF4DC	0331 619858	NIKOLAY NIKOLAEV	{"phone": "+70563605783"}
0005432121628	F6D460	6622 822601	ALIYA NIKIFOROVA	{"email": "aliya.nikiforova_1971@postgrespro.ru", "phone": "+70163095985"}
0005432121629	B1BE04	6081 693811	VLADIMIR MOISEEV	{"email": "vmoiseev011973@postgrespro.ru", "phone": "+70335011888"}
0005432121630	A44BAC	7431 616749	KIRILL DENISOV	{"email": "denisovkirill.01121968@postgrespro.ru", "phone": "+70952967772"}
0005432121631	DDE3D4	1588 917010	SVETLANA SERGEEVA	{"phone": "+70300297768"}
0005432121632	72906A	1102 186463	ZINAIDA KUZMINA	{"phone": "+70261208083"}
0005432121633	72906A	5218 573288	PAVEL SEMENOV	{"email": "semenov-p-02091978@postgrespro.ru", "phone": "+70665172146"}
0005432121634	17F828	0102 512542	MARIYA VASILEVA	{"email": "mvasileva091968@postgrespro.ru", "phone": "+70022707254"}
0005432121635	DAB191	1881 389221	LYUBOV STEPANOVA	{"email": "l-stepanova-1972@postgrespro.ru", "phone": "+70860304595"}
0005432121636	34C454	0645 227959	VALENTINA KOZLOVA	{"email": "kozlovavalentina.1959@postgrespro.ru", "phone": "+70217834159"}
0005432121637	34C454	2600 041274	NATALIYA KARPOVA	{"phone": "+70850239060"}
0005432121638	E3F2DE	0915 934659	NAILYA VASILEVA	{"phone": "+70584980491"}
0005432121639	E3F2DE	3382 412394	TATYANA KONOVALOVA	{"email": "tatyana_konovalova_121971@postgrespro.ru", "phone": "+70334508168"}
0005432121640	18BD5F	2909 230810	SERGEY KISELEV	{"email": "sergey_kiselev_1975@postgrespro.ru", "phone": "+70057312755"}
0005432121641	5A7A52	5438 618587	ANDREY ORLOV	{"email": "andrey.orlov-16111970@postgrespro.ru", "phone": "+70289009231"}
0005432121642	CD408D	6365 750082	EVA PETROVA	{"email": "e.petrova1960@postgrespro.ru", "phone": "+70450809487"}
0005432121643	9C18B0	6819 954214	NATALYA VOLKOVA	{"email": "volkova.n-011971@postgrespro.ru", "phone": "+70410527800"}
0005432121644	9C18B0	9554 577023	YULIYA MOISEEVA	{"email": "yuliya_moiseeva-1970@postgrespro.ru", "phone": "+70260172829"}
0005432121645	6641F4	7278 070876	OLESYA VOLKOVA	{"email": "volkovaolesya_051977@postgrespro.ru", "phone": "+70397923955"}
0005432121646	9D562A	0457 904788	ALEKSANDR FEDOTOV	{"email": "fedotova.021983@postgrespro.ru", "phone": "+70941612143"}
0005432121647	9D562A	8228 687222	LYUBOV KALININA	{"email": "kalinina_lyubov-1979@postgrespro.ru", "phone": "+70957605355"}
0005432121648	712678	9347 316515	ALBINA VOLKOVA	{"email": "albina-volkova_01061975@postgrespro.ru", "phone": "+70270198693"}
0005432121649	C263C0	2488 155515	SVETLANA MIRONOVA	{"email": "mironovasvetlana-16041970@postgrespro.ru", "phone": "+70336689292"}
0005432121650	C263C0	8259 517655	DMITRIY PAVLOV	{"phone": "+70588856598"}
0005432121651	16E07F	4308 678302	MIKHAIL KRASNOV	{"phone": "+70379755776"}
0005432121652	16E07F	9324 488415	ZINAIDA KOLESNIKOVA	{"email": "z-kolesnikova.041974@postgrespro.ru", "phone": "+70712482903"}
0005432121653	46BAB4	9650 557763	NURIYA VOLKOVA	{"email": "volkova_n1965@postgrespro.ru", "phone": "+70567754500"}
0005432121654	EE094E	0349 722078	ARTEM KOZLOV	{"email": "artem-kozlov1968@postgrespro.ru", "phone": "+70789521987"}
0005432121655	D32617	0844 256503	KONSTANTIN KRASNOV	{"phone": "+70297032470"}
0005432121656	2B7DD9	8432 430220	ANNA KARPOVA	{"phone": "+70804025072"}
0005432121657	2B7DD9	5283 339033	NIKOLAY KUZNECOV	{"phone": "+70033573032"}
0005432121658	2B7DD9	9594 119987	VYACHESLAV KONOVALOV	{"email": "vyacheslavkonovalov_021975@postgrespro.ru", "phone": "+70035971650"}
0005432121659	2B7DD9	8724 589956	NADEZHDA SERGEEVA	{"email": "nadezhdasergeeva_1975@postgrespro.ru", "phone": "+70990766760"}
0005432121660	9D2A7B	0342 298624	ALEKSANDRA MAKSIMOVA	{"email": "maksimovaaleksandra14071970@postgrespro.ru", "phone": "+70333036142"}
0005432121661	9D2A7B	3934 681761	ALENA GAVRILOVA	{"email": "gavrilovaalena-071974@postgrespro.ru", "phone": "+70801434891"}
0005432121662	F6BAA2	3471 441403	IVAN SOLOVEV	{"email": "solovev-i-051959@postgrespro.ru", "phone": "+70407493395"}
0005432121663	F6BAA2	1491 454740	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov-091962@postgrespro.ru", "phone": "+70721761632"}
0005432121664	A2C6DF	3028 349930	MAKSIM MAKAROV	{"email": "makarov-maksim_1969@postgrespro.ru", "phone": "+70307115178"}
0005432121665	A2C6DF	6529 692869	OLESYA OSIPOVA	{"email": "osipovaolesya-08101969@postgrespro.ru", "phone": "+70548349971"}
0005432121666	C4917E	4522 388453	KRISTINA ANISIMOVA	{"phone": "+70904406922"}
0005432121667	C4917E	1463 471676	NATALYA KALININA	{"phone": "+70998637707"}
0005432121668	70515D	5983 260680	ALEKSANDRA BELYAEVA	{"email": "belyaeva_a_091984@postgrespro.ru", "phone": "+70433763303"}
0005432121669	70515D	4146 489307	TATYANA POPOVA	{"phone": "+70183481079"}
0005432121670	AAEC97	0804 507169	ANDREY KUZNECOV	{"email": "a.kuznecov1973@postgrespro.ru", "phone": "+70405751428"}
0005432121671	AAEC97	3489 534063	VASILIY PAVLOV	{"email": "v.pavlov-1977@postgrespro.ru", "phone": "+70417977345"}
0005432121672	16C514	2977 732404	DENIS VOLKOV	{"email": "denis_volkov-1970@postgrespro.ru", "phone": "+70656664542"}
0005432121673	0CD08F	2820 034055	ARTUR CHERNOV	{"phone": "+70684874683"}
0005432121674	A707DA	7034 833882	ALEKSANDR NAZAROV	{"phone": "+70116519154"}
0005432121675	26003E	6423 607304	LYUDMILA ISAEVA	{"phone": "+70936628341"}
0005432121676	879D4D	6806 492960	LYUDMILA NOVIKOVA	{"phone": "+70195665125"}
0005432121677	57D27B	4204 222189	LIDIYA ZAYCEVA	{"phone": "+70910114894"}
0005432121678	4D09E3	8036 576259	SERGEY SAVELEV	{"email": "savelev.sergey-081965@postgrespro.ru", "phone": "+70584701437"}
0005432121679	4D09E3	5949 322284	ALEKSANDR BONDARENKO	{"phone": "+70058324733"}
0005432121680	4D09E3	7212 458369	MARIYA DMITRIEVA	{"email": "mdmitrieva-101967@postgrespro.ru", "phone": "+70531542205"}
0005432121681	575E16	6994 178748	NADEZHDA FROLOVA	{"email": "frolovan041961@postgrespro.ru", "phone": "+70051802224"}
0005432121682	575E16	8161 693662	DENIS KAZAKOV	{"phone": "+70719830914"}
0005432121683	919600	1759 098554	DMITRIY ANDREEV	{"email": "d-andreev.1966@postgrespro.ru", "phone": "+70360523004"}
0005432121684	919600	2114 184660	DANIYA KUZNECOVA	{"phone": "+70825766093"}
0005432121685	27E6C5	3480 051524	STANISLAV MAKAROV	{"phone": "+70127171996"}
0005432121686	F68261	3154 790938	ALEKSANDRA YAKOVLEVA	{"email": "ayakovleva-111963@postgrespro.ru", "phone": "+70506211547"}
0005432121687	DCCF02	6602 720773	ANNA SERGEEVA	{"email": "sergeevaa101980@postgrespro.ru", "phone": "+70737194454"}
0005432121688	38A0B4	8465 151847	DARYA KARPOVA	{"email": "karpova-darya-041972@postgrespro.ru", "phone": "+70837590219"}
0005432121689	38A0B4	9818 239609	ALEKSEY KONOVALOV	{"email": "aleksey_konovalov1968@postgrespro.ru", "phone": "+70574683904"}
0005432121690	704DA6	2145 666975	DENIS BELOV	{"email": "denis.belov-1966@postgrespro.ru", "phone": "+70820930143"}
0005432121691	99B085	6460 132718	ANATOLIY MATVEEV	{"email": "matveev-a_31071968@postgrespro.ru", "phone": "+70159867076"}
0005432121692	99B085	1602 125043	ANTONINA MALYSHEVA	{"email": "malysheva.antonina_071982@postgrespro.ru", "phone": "+70910392549"}
0005432121693	39D5BE	3287 330799	YURIY TIKHONOV	{"phone": "+70686233051"}
0005432121694	184CF8	8495 397861	EVGENIY SOLOVEV	{"phone": "+70941683501"}
0005432121695	FC2220	3229 565877	VERONIKA KRASNOVA	{"phone": "+70134822549"}
0005432121696	4972C9	2457 535112	ALEKSANDR FEDOROV	{"phone": "+70205736373"}
0005432121697	5A876E	8757 336167	VLADIMIR IVANOV	{"email": "vladimir.ivanov-22081972@postgrespro.ru", "phone": "+70021902145"}
0005432121698	5A876E	4353 936886	NINA KARPOVA	{"email": "karpovanina.081971@postgrespro.ru", "phone": "+70360876447"}
0005432121699	98777E	6885 855932	IRINA ANTONOVA	{"phone": "+70986799767"}
0005432121700	4A9DB7	8350 837724	ELENA KISELEVA	{"phone": "+70603525442"}
0005432121701	4A9DB7	3042 405791	DENIS VOROBEV	{"email": "vorobev.d-061968@postgrespro.ru", "phone": "+70495912343"}
0005432121702	5E508C	6255 916107	ARINA SMIRNOVA	{"email": "arina-smirnova29121976@postgrespro.ru", "phone": "+70543158664"}
0005432121703	F1D62D	5827 673372	VIKTOR ROMANOV	{"phone": "+70241346238"}
0005432121704	F1D62D	4154 054808	ALEKSANDRA SAVELEVA	{"email": "a_saveleva1965@postgrespro.ru", "phone": "+70307587254"}
0005432121705	776B62	7325 539636	IRINA FILIPPOVA	{"email": "filippova-i_1967@postgrespro.ru", "phone": "+70695761120"}
0005432121706	776B62	0048 298901	ALEKSANDR GAVRILOV	{"phone": "+70882852943"}
0005432121707	DB9D9F	1042 031444	ANNA ROMANOVA	{"email": "romanova-anna07021964@postgrespro.ru", "phone": "+70675032119"}
0005432121708	B5B83F	4836 055450	ROZA TARASOVA	{"email": "r.tarasova-23081977@postgrespro.ru", "phone": "+70516868571"}
0005432121709	B5B83F	0786 058395	LIDIYA CHERNOVA	{"email": "lidiyachernova_29011976@postgrespro.ru", "phone": "+70959896254"}
0005432121710	B5B83F	6488 182585	ELDAR MIKHAYLOV	{"phone": "+70515008363"}
0005432121711	9632D7	7333 585241	SERGEY YAKOVLEV	{"email": "yakovlev-s27101973@postgrespro.ru", "phone": "+70000935520"}
0005432121712	2499AA	1588 188424	DMITRIY SHEVCHENKO	{"email": "shevchenko-d-1972@postgrespro.ru", "phone": "+70594527267"}
0005432121713	2499AA	4505 391707	SVETLANA VASILEVA	{"phone": "+70344418548"}
0005432121714	D5C250	4735 990610	ANASTASIYA PAVLOVA	{"phone": "+70849217132"}
0005432121715	EE4277	6993 967394	ALEKSANDR PAVLOV	{"phone": "+70540500799"}
0005432121716	EE4277	9536 651048	ANASTASIYA MELNIKOVA	{"email": "melnikovaa16111973@postgrespro.ru", "phone": "+70488707845"}
0005432121717	F1AAA3	6605 108069	IGOR SIDOROV	{"email": "sidorov_igor_1964@postgrespro.ru", "phone": "+70402434709"}
0005432121718	EB2E51	0149 351331	ANDREY SHEVCHENKO	{"email": "andreyshevchenko041977@postgrespro.ru", "phone": "+70390569047"}
0005432121719	EB2E51	6292 536448	EKATERINA YAKOVLEVA	{"email": "yakovleva-e_18061977@postgrespro.ru", "phone": "+70391663007"}
0005432121720	169390	4825 588766	NIKOLAY VLASOV	{"email": "vlasov.n_10051978@postgrespro.ru", "phone": "+70886880306"}
0005432121721	169390	4261 357687	IRINA ALEKSANDROVA	{"email": "i_aleksandrova_1972@postgrespro.ru", "phone": "+70720642605"}
0005432121722	6951EF	7571 882296	ANASTASIYA MALYSHEVA	{"phone": "+70392855638"}
0005432121723	B89244	6810 027062	VADIM KUZNECOV	{"email": "vadim.kuznecov091970@postgrespro.ru", "phone": "+70816410806"}
0005432121724	3C7505	6924 554402	VYACHESLAV MAKSIMOV	{"email": "maksimovv-071966@postgrespro.ru", "phone": "+70288827004"}
0005432121725	23EC97	7304 612082	KSENIYA BELYAEVA	{"phone": "+70939981580"}
0005432121726	23EC97	6893 645983	ALEKSANDR TARASOV	{"phone": "+70346444966"}
0005432121727	917AB5	6184 275367	OLGA ANISIMOVA	{"phone": "+70434325623"}
0005432121728	917AB5	8224 081596	IRINA MOISEEVA	{"email": "moiseevairina.22051965@postgrespro.ru", "phone": "+70054022746"}
0005432121729	038CD4	6297 815618	ELENA VLASOVA	{"phone": "+70335043649"}
0005432121730	038CD4	8092 734600	MAKSIM ZAYCEV	{"email": "mzaycev-1972@postgrespro.ru", "phone": "+70679304188"}
0005432121731	038CD4	1587 891683	VYACHESLAV SIDOROV	{"phone": "+70495447217"}
0005432121732	1CB51B	2927 141742	FEDOR SOLOVEV	{"email": "solovev_f_1969@postgrespro.ru", "phone": "+70348094367"}
0005432121733	1CB51B	7111 951142	SVETLANA MIRONOVA	{"phone": "+70211410949"}
0005432121734	A31385	5564 446011	VALERIY FILIPPOV	{"email": "filippovv20011977@postgrespro.ru", "phone": "+70468334557"}
0005432121735	EF3AAF	9933 647571	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov021957@postgrespro.ru", "phone": "+70306582216"}
0005432121736	8E7DA3	6395 147486	ELENA SEMENOVA	{"email": "elena_semenova_121979@postgrespro.ru", "phone": "+70593891633"}
0005432121737	65F53D	7820 674923	LIDIYA FILATOVA	{"phone": "+70686144903"}
0005432121738	65F53D	7826 198053	GALINA KOROLEVA	{"email": "korolevagalina_05111969@postgrespro.ru", "phone": "+70945656126"}
0005432121739	161A27	2122 648072	OLEG SCHERBAKOV	{"phone": "+70309003861"}
0005432121740	161A27	1664 213465	EGOR KUDRYASHOV	{"phone": "+70082530293"}
0005432121741	161A27	1414 816816	LIDIYA KOROLEVA	{"email": "l.koroleva29031972@postgrespro.ru", "phone": "+70938976777"}
0005432121742	0E02B9	6298 047447	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr.06051970@postgrespro.ru", "phone": "+70048090750"}
0005432121743	1AAA7F	8363 497682	TATYANA ANDREEVA	{"phone": "+70960727383"}
0005432121744	9FB0F5	1260 630162	NIKOLAY SHEVCHENKO	{"phone": "+70113715920"}
0005432121745	2EC9C2	9074 415980	OLGA LUKYANOVA	{"phone": "+70679418253"}
0005432121746	2EC9C2	4847 417903	VASILIY ANTONOV	{"phone": "+70582355250"}
0005432121747	F58DE4	0410 371531	ANASTASIYA STEPANOVA	{"phone": "+70245257987"}
0005432121748	F58DE4	0801 466226	ELENA KUDRYASHOVA	{"phone": "+70555931895"}
0005432121749	708531	1090 823601	SERGEY KUZMIN	{"email": "kuzmins_1972@postgrespro.ru", "phone": "+70093711862"}
0005432121750	708531	8993 796631	OLGA FOMINA	{"email": "fomina-o-091967@postgrespro.ru", "phone": "+70209886950"}
0005432121751	94EB33	7201 373289	NATALIYA PETROVA	{"email": "n-petrova.1963@postgrespro.ru", "phone": "+70532651286"}
0005432121752	94EB33	2017 549271	VERA LEBEDEVA	{"email": "vlebedeva-1965@postgrespro.ru", "phone": "+70644947877"}
0005432121753	0FBA0B	5121 288965	EVGENIY GAVRILOV	{"email": "evgeniygavrilov-1971@postgrespro.ru", "phone": "+70560816497"}
0005432121754	5A7282	8636 532424	VALENTINA KISELEVA	{"phone": "+70334152507"}
0005432121755	5A7282	1735 767017	VALENTINA FEDOROVA	{"email": "fedorovavalentina.1965@postgrespro.ru", "phone": "+70514176886"}
0005432121756	E0D5D6	4142 417639	MARINA FADEEVA	{"phone": "+70006950436"}
0005432121757	E0D5D6	0069 595583	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir_041983@postgrespro.ru", "phone": "+70961788345"}
0005432125318	B77802	7221 452558	STANISLAV KRASNOV	{"email": "stanislav.krasnov10091977@postgrespro.ru", "phone": "+70389441361"}
0005432125319	F99FA9	3547 067545	PAVEL VOROBEV	{"phone": "+70663178672"}
0005432125320	F99FA9	2278 658482	IRINA MARTYNOVA	{"phone": "+70863439215"}
0005432125321	F99FA9	9821 122867	DARYA MIRONOVA	{"email": "mironova_d_091966@postgrespro.ru", "phone": "+70276603484"}
0005432125322	7B7248	6088 316441	IGOR IVANOV	{"email": "ivanov.igor-1972@postgrespro.ru", "phone": "+70127336987"}
0005432125323	69A9E6	1699 926071	NATALYA YUDINA	{"email": "n-yudina15031971@postgrespro.ru", "phone": "+70007725393"}
0005432125324	8CAF64	7684 957084	ALEKSANDR NAZAROV	{"phone": "+70355304339"}
0005432125325	302540	3057 692633	ANATOLIY SIDOROV	{"email": "anatoliy.sidorov011973@postgrespro.ru", "phone": "+70647334010"}
0005432125326	F8E821	9498 673327	ALEKSANDR FROLOV	{"phone": "+70059161947"}
0005432125327	F8E821	2030 724965	ELIZAVETA IVANOVA	{"phone": "+70854830880"}
0005432125328	34C3A1	9257 003186	ARTEMIY SCHERBAKOV	{"email": "scherbakov_a.09091974@postgrespro.ru", "phone": "+70341024778"}
0005432125329	B208C2	7244 642510	MARINA YAKOVLEVA	{"phone": "+70918090863"}
0005432125330	1275BE	0018 642839	NINA OVCHINNIKOVA	{"email": "n_ovchinnikova-061973@postgrespro.ru", "phone": "+70635695440"}
0005432125331	BD6E2E	9460 219282	ALINA NOVIKOVA	{"email": "novikova-alina15071968@postgrespro.ru", "phone": "+70692010388"}
0005432125332	FA43B3	0194 152185	SERGEY DAVYDOV	{"phone": "+70428520171"}
0005432125333	FA43B3	2335 540700	VITALIY SEMENOV	{"phone": "+70376659749"}
0005432125334	74F31A	4016 881604	NATALYA FILIPPOVA	{"email": "natalya.filippova-061977@postgrespro.ru", "phone": "+70125546935"}
0005432125335	CF04FA	0098 045122	DARYA VOLKOVA	{"phone": "+70279739767"}
0005432125336	76AAFF	9319 588979	YURIY VLASOV	{"email": "yuriyvlasov.071988@postgrespro.ru", "phone": "+70134786563"}
0005432125337	76AAFF	4526 702654	GALINA AFANASEVA	{"email": "afanaseva.galina_1966@postgrespro.ru", "phone": "+70480002215"}
0005432125338	D06505	8746 366601	NINA GUSEVA	{"email": "n-guseva1962@postgrespro.ru", "phone": "+70436028859"}
0005432125339	E2E472	7335 326983	VALERIY ANDREEV	{"email": "andreevvaleriy_011972@postgrespro.ru", "phone": "+70878672799"}
0005432125340	FDA3B0	8691 993746	SERGEY ABRAMOV	{"email": "sergey-abramov121972@postgrespro.ru", "phone": "+70113091400"}
0005432125341	DEEA3B	4536 980060	IVAN MIKHAYLOV	{"email": "i.mikhaylov1972@postgrespro.ru", "phone": "+70242890429"}
0005432125342	B362C8	3277 112034	ALEKSEY MARTYNOV	{"email": "a-martynov_041966@postgrespro.ru", "phone": "+70248227051"}
0005432125343	224938	4457 716694	NIKITA MELNIKOV	{"email": "melnikovn-1983@postgrespro.ru", "phone": "+70106611752"}
0005432125344	B627B3	9271 216415	IVAN PAVLOV	{"email": "i.pavlov_1973@postgrespro.ru", "phone": "+70397474915"}
0005432125345	B627B3	0062 337207	EKATERINA SAVELEVA	{"email": "e-saveleva.1964@postgrespro.ru", "phone": "+70895926930"}
0005432125346	B627B3	5162 660169	NIKOLAY SEMENOV	{"email": "n-semenov07091965@postgrespro.ru", "phone": "+70730535117"}
0005432125347	D3CDF1	3158 765909	ANASTASIYA FROLOVA	{"email": "frolova-a_061981@postgrespro.ru", "phone": "+70752940074"}
0005432125348	D3CDF1	6112 039018	NIKOLAY NOVIKOV	{"email": "nikolay_novikov.24071967@postgrespro.ru", "phone": "+70523782934"}
0005432125349	E63C3E	0156 956121	NATALYA RODIONOVA	{"phone": "+70321272521"}
0005432125350	EC996F	7102 042284	SERGEY SCHERBAKOV	{"phone": "+70486316707"}
0005432125351	85D100	0013 814491	VIKTOR KUZNECOV	{"email": "kuznecov.v-1952@postgrespro.ru", "phone": "+70183567768"}
0005432125352	BCFB8B	1072 529061	ALINA KARPOVA	{"phone": "+70467165090"}
0005432125353	9B157D	4548 431543	ELENA AFANASEVA	{"email": "afanaseva-elena-04061980@postgrespro.ru", "phone": "+70890868519"}
0005432125354	760054	3717 574299	GALINA ALEKSEEVA	{"phone": "+70440282811"}
0005432125355	2F581A	8067 325337	ALEKSEY SERGEEV	{"phone": "+70084475981"}
0005432125356	C0B580	2714 957802	MARIYA SERGEEVA	{"phone": "+70019699745"}
0005432125357	872E06	0191 212043	TATYANA IVANOVA	{"email": "t-ivanova-1966@postgrespro.ru", "phone": "+70844291216"}
0005432125358	5B4963	7529 109923	ALEKSEY ANDREEV	{"email": "aleksey_andreev-1977@postgrespro.ru", "phone": "+70133476864"}
0005432125359	110DA5	2503 553105	ALEKSEY SCHERBAKOV	{"phone": "+70737365819"}
0005432125360	09A1AC	3555 354175	NINA LOGINOVA	{"email": "loginova_n_19051973@postgrespro.ru", "phone": "+70809328338"}
0005432125361	09A1AC	6623 280910	ELENA ALEKSEEVA	{"email": "alekseevae1974@postgrespro.ru", "phone": "+70752204355"}
0005432125362	846A6F	1433 508112	ALEKSEY MOISEEV	{"email": "a.moiseev1973@postgrespro.ru", "phone": "+70013149237"}
0005432125363	B43D2B	8065 132143	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev-041980@postgrespro.ru", "phone": "+70665336931"}
0005432125364	B43D2B	3322 282409	ANDREY TIKHONOV	{"email": "tikhonov-andrey_121973@postgrespro.ru", "phone": "+70178756859"}
0005432125365	B46456	9560 643551	EVGENIY YAKOVLEV	{"phone": "+70832148188"}
0005432125366	B46456	4466 645584	LYUBOV RODIONOVA	{"email": "lyubov.rodionova1967@postgrespro.ru", "phone": "+70986385230"}
0005432125367	77FF73	9122 554736	IVAN MOISEEV	{"phone": "+70959950452"}
0005432125368	77FF73	1342 443363	PAVEL TIMOFEEV	{"phone": "+70100744939"}
0005432125369	9BDCCB	8882 405505	OLGA OVCHINNIKOVA	{"email": "ovchinnikova-o_22111965@postgrespro.ru", "phone": "+70306177191"}
0005432125370	9BDCCB	3212 477567	ANTONINA KALININA	{"email": "kalininaa061966@postgrespro.ru", "phone": "+70449843242"}
0005432125371	C9B60D	6280 179693	BOGDAN AFANASEV	{"email": "b-afanasev-31031977@postgrespro.ru", "phone": "+70449231856"}
0005432125372	DDC615	9210 551457	NADEZHDA MAKSIMOVA	{"phone": "+70457510973"}
0005432125373	F95382	0847 124211	EVGENIY MOISEEV	{"email": "evgeniy_moiseev-031976@postgrespro.ru", "phone": "+70903506718"}
0005432125374	3862B8	4048 174173	IGOR KUZNECOV	{"phone": "+70427678163"}
0005432125375	E35A49	2069 099668	ALIYA GERASIMOVA	{"email": "gerasimovaaliya.1965@postgrespro.ru", "phone": "+70740932732"}
0005432125376	A7089E	4187 341163	YURIY KUZNECOV	{"email": "kuznecovy_13111965@postgrespro.ru", "phone": "+70347990324"}
0005432125377	A7089E	8624 771509	NATALYA ANDREEVA	{"phone": "+70565508317"}
0005432125378	563B02	9142 159024	VITALIY FOMIN	{"email": "fominvitaliy_101973@postgrespro.ru", "phone": "+70403298457"}
0005432125379	563B02	1402 810202	DMITRIY ANTONOV	{"email": "antonovdmitriy.1957@postgrespro.ru", "phone": "+70551993772"}
0005432125380	77AC2A	3086 174265	NADEZHDA NAUMOVA	{"email": "n_naumova.031968@postgrespro.ru", "phone": "+70363491011"}
0005432125381	CD9D01	6371 327145	LYUDMILA EGOROVA	{"email": "lyudmila.egorova.121971@postgrespro.ru", "phone": "+70326918976"}
0005432125382	8116BD	1912 284624	VITALIY VASILEV	{"phone": "+70975926178"}
0005432125383	4E6A87	0402 179737	ALEKSANDR SEMENOV	{"email": "semenova1973@postgrespro.ru", "phone": "+70050310483"}
0005432125384	EAD70E	0817 620037	DENIS SMIRNOV	{"email": "smirnovdenis.1973@postgrespro.ru", "phone": "+70794345603"}
0005432125385	8C77D5	4424 785155	ANDREY ANTONOV	{"phone": "+70746173201"}
0005432125386	15167F	4246 347450	ALINA NESTEROVA	{"phone": "+70678475495"}
0005432125387	15167F	4682 737922	ANNA KOROLEVA	{"email": "korolevaa.081980@postgrespro.ru", "phone": "+70857692352"}
0005432125388	15167F	2042 339888	ALEKSANDR KARPOV	{"email": "karpova.031972@postgrespro.ru", "phone": "+70160578481"}
0005432125389	9C6247	3143 268413	ALEKSANDR ILIN	{"email": "ailin1970@postgrespro.ru", "phone": "+70546984119"}
0005432125390	9C6247	9195 670876	SERGEY ROMANOV	{"email": "sergey-romanov02031967@postgrespro.ru", "phone": "+70940576670"}
0005432125391	9C6247	0590 760074	LYUDMILA KOROLEVA	{"phone": "+70441181417"}
0005432125392	063770	4374 982054	KLAVDIYA KONDRATEVA	{"email": "kondrateva_klavdiya031976@postgrespro.ru", "phone": "+70099126851"}
0005432125393	BC3784	1614 179235	YULIYA KUZMINA	{"phone": "+70067389444"}
0005432125394	9ADA19	8524 766336	BOGDAN ANTONOV	{"email": "b-antonov-061974@postgrespro.ru", "phone": "+70789476365"}
0005432125395	9A9104	7338 937983	NIKITA KAZAKOV	{"phone": "+70226990946"}
0005432125396	9A9104	4137 189723	VASILIY MARTYNOV	{"email": "martynov_v1968@postgrespro.ru", "phone": "+70501778418"}
0005432125397	791807	7839 334145	ANASTASIYA KOROLEVA	{"email": "a-koroleva_081973@postgrespro.ru", "phone": "+70718826178"}
0005432125398	CA9C50	1828 007500	DMITRIY IVANOV	{"phone": "+70790284372"}
0005432125399	333458	4539 446214	ALEKSANDR SOLOVEV	{"phone": "+70083260107"}
0005432125400	3F57A1	2429 421542	NADEZHDA KISELEVA	{"phone": "+70922139504"}
0005432125401	4818F8	6585 426125	VIKTORIYA FEDOROVA	{"email": "viktoriya-fedorova.1970@postgrespro.ru", "phone": "+70240006061"}
0005432125402	4818F8	8196 213133	NIKOLAY MIKHAYLOV	{"phone": "+70840086600"}
0005432125403	4818F8	5771 660947	IVAN SERGEEV	{"email": "i-sergeev.1967@postgrespro.ru", "phone": "+70410212852"}
0005432125404	463F5A	5788 199502	IVAN DENISOV	{"phone": "+70396301098"}
0005432125405	CCE121	3953 393556	TATYANA SCHERBAKOVA	{"email": "scherbakova-t071972@postgrespro.ru", "phone": "+70741773502"}
0005432125406	2F05F0	9888 613202	TAISIYA ALEKSEEVA	{"phone": "+70693217583"}
0005432125407	DC7EEF	2481 976900	NONNA MOISEEVA	{"email": "moiseeva.n071963@postgrespro.ru", "phone": "+70661717484"}
0005432125408	DC7EEF	1316 754636	ANDREY TARASOV	{"email": "a.tarasov_22101972@postgrespro.ru", "phone": "+70384357111"}
0005432125409	F3CD83	3274 528600	TATYANA TIMOFEEVA	{"phone": "+70286068473"}
0005432125632	246794	5716 395241	SERGEY MOROZOV	{"phone": "+70825495205"}
0005432125410	F3CD83	7865 341544	OLGA POPOVA	{"email": "olga-popova-03071968@postgrespro.ru", "phone": "+70427711588"}
0005432125411	F3CD83	9276 077889	PETR KOZLOV	{"phone": "+70007264368"}
0005432125412	3A2DF4	9188 163747	ANASTASIYA MAKAROVA	{"email": "makarovaa111974@postgrespro.ru", "phone": "+70858980552"}
0005432125413	3A2DF4	1684 070775	DMITRIY BONDARENKO	{"email": "dmitriy-bondarenko_27071971@postgrespro.ru", "phone": "+70139330114"}
0005432125414	8B7390	4795 801916	NATALYA IVANOVA	{"email": "ivanova_n.13121963@postgrespro.ru", "phone": "+70163571771"}
0005432125415	8B7390	7732 719078	KONSTANTIN IVANOV	{"email": "ivanov.k-22021967@postgrespro.ru", "phone": "+70842176818"}
0005432125416	B695C8	7367 768222	MARIYA KONOVALOVA	{"phone": "+70287601983"}
0005432125417	FF6138	9211 816457	TATYANA NIKIFOROVA	{"email": "nikiforovat.071982@postgrespro.ru", "phone": "+70910309706"}
0005432125418	B7B1FD	5146 894865	STANISLAV POPOV	{"email": "s_popov_011978@postgrespro.ru", "phone": "+70513988769"}
0005432125419	B7B1FD	7425 816013	ANDREY KUZNECOV	{"phone": "+70645062345"}
0005432125420	227543	6122 866145	NATALYA IVANOVA	{"phone": "+70958470842"}
0005432125421	227543	9079 485415	ANZHELIKA ISAEVA	{"phone": "+70023221274"}
0005432125422	502992	1227 841390	ELIZAVETA ALEKSEEVA	{"phone": "+70098126734"}
0005432125423	E2967D	8852 418901	ANDREY SOLOVEV	{"email": "andreysolovev.18031969@postgrespro.ru", "phone": "+70805233649"}
0005432125424	61B78F	7172 652807	TATYANA ROMANOVA	{"email": "romanova_tatyana.011980@postgrespro.ru", "phone": "+70485155112"}
0005432125425	79FCD3	0591 764684	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev.1962@postgrespro.ru", "phone": "+70877711544"}
0005432125426	5A3E43	7377 367440	MIKHAIL AFANASEV	{"email": "m.afanasev021984@postgrespro.ru", "phone": "+70659413341"}
0005432125427	04DCA9	7869 723482	NATALYA TITOVA	{"phone": "+70666594707"}
0005432125428	04DCA9	6588 745801	VALERIYA GUSEVA	{"phone": "+70782589945"}
0005432125429	2C45D9	4646 601592	DMITRIY SEMENOV	{"email": "d-semenov.1974@postgrespro.ru", "phone": "+70250431640"}
0005432125430	699FE0	3107 421565	SERGEY SHEVCHENKO	{"phone": "+70407977007"}
0005432125431	111BB1	3448 557254	LYUBOV KUZNECOVA	{"email": "lkuznecova1982@postgrespro.ru", "phone": "+70892424826"}
0005432125432	3B6953	6597 541073	MAKSIM KONOVALOV	{"phone": "+70744996465"}
0005432125433	3B6953	5778 085561	SERGEY GRIGOREV	{"email": "grigorev_sergey-051964@postgrespro.ru", "phone": "+70521168103"}
0005432125434	4CDA18	4593 850009	VLADIMIR EGOROV	{"phone": "+70302608545"}
0005432125435	91FF5F	4683 575329	SERGEY KUZNECOV	{"email": "kuznecov-sergey_1985@postgrespro.ru", "phone": "+70450580512"}
0005432125436	91FF5F	5780 398511	FAINA KALININA	{"email": "f_kalinina_091963@postgrespro.ru", "phone": "+70834354978"}
0005432125437	2E3C00	2606 273337	RUSLAN GERASIMOV	{"phone": "+70805715159"}
0005432125438	D73D9C	8350 079734	ALINA SEMENOVA	{"email": "semenova.alina-111966@postgrespro.ru", "phone": "+70043266785"}
0005432125439	716EB2	5666 452455	SERGEY BELOV	{"email": "belov_sergey_19081971@postgrespro.ru", "phone": "+70246878957"}
0005432125440	DA17BC	4486 463102	SERGEY BONDARENKO	{"phone": "+70629189522"}
0005432125441	DA17BC	2550 579522	SVETLANA KRASNOVA	{"phone": "+70125641141"}
0005432125442	684DD7	7954 554770	TATYANA BARANOVA	{"email": "baranova.t_1965@postgrespro.ru", "phone": "+70565891611"}
0005432125443	684DD7	9346 332097	ARTEM VOROBEV	{"email": "vorobev_artem-1990@postgrespro.ru", "phone": "+70904432136"}
0005432125444	40111A	1479 963238	ANDREY SERGEEV	{"email": "a.sergeev_061983@postgrespro.ru", "phone": "+70161485303"}
0005432125445	40111A	8047 983556	ARTEM MIRONOV	{"phone": "+70041392152"}
0005432125446	5D9FE4	3743 554402	ANNA KOZLOVA	{"email": "kozlova_anna.091970@postgrespro.ru", "phone": "+70588171509"}
0005432125447	5D9FE4	3763 343160	GALINA ALEKSANDROVA	{"phone": "+70531336136"}
0005432125448	164CC5	8579 041717	EVGENIY DAVYDOV	{"email": "davydov.evgeniy_1966@postgrespro.ru", "phone": "+70989163773"}
0005432125449	4CE2AB	6878 909769	ILYA SOLOVEV	{"phone": "+70594451424"}
0005432125450	D6EFCF	6019 557700	ANDREY SCHERBAKOV	{"phone": "+70180916100"}
0005432125451	F8DEED	0960 931504	TATYANA MALYSHEVA	{"phone": "+70742129293"}
0005432125452	F8DEED	7875 052433	OLEG ROMANOV	{"phone": "+70737873620"}
0005432125453	97C07A	2319 732834	MIKHAIL VOLKOV	{"email": "mikhailvolkov-041975@postgrespro.ru", "phone": "+70315336648"}
0005432125454	97C07A	8364 838336	ANTON ILIN	{"email": "ilin_anton-17031976@postgrespro.ru", "phone": "+70055977003"}
0005432125455	71BF7B	5641 679084	MATVEY TIMOFEEV	{"email": "timofeev-m10091969@postgrespro.ru", "phone": "+70443796309"}
0005432125456	242DAF	7048 702472	VLADIMIR ZHUKOV	{"phone": "+70868181617"}
0005432125457	E349CF	8957 581176	LYUBOV AFANASEVA	{"phone": "+70846715050"}
0005432125458	1894D6	5754 140038	EKATERINA BORISOVA	{"email": "ekaterina_borisova-1968@postgrespro.ru", "phone": "+70227048978"}
0005432125459	E067B6	0702 418009	YAROSLAV KUZNECOV	{"phone": "+70197115389"}
0005432125460	E067B6	8751 599121	PAVEL VASILEV	{"email": "pavelvasilev_111982@postgrespro.ru", "phone": "+70482163586"}
0005432125461	A98BE4	6340 170005	ALEKSANDR TARASOV	{"phone": "+70633484284"}
0005432125462	A98BE4	0458 960193	IRINA VOLKOVA	{"phone": "+70200494147"}
0005432125463	63750A	8700 674391	VLADIMIR MOISEEV	{"phone": "+70263504384"}
0005432125464	0D3241	7356 531637	VLADIMIR TARASOV	{"phone": "+70893864347"}
0005432125465	0D3241	8209 744592	PAVEL SEMENOV	{"email": "semenov-p04081970@postgrespro.ru", "phone": "+70694897419"}
0005432125466	59C8E8	0559 775947	SERGEY STEPANOV	{"email": "sergey.stepanov-29091957@postgrespro.ru", "phone": "+70266457815"}
0005432125467	59C8E8	1024 914151	ALEKSANDRA ALEKSEEVA	{"phone": "+70099581048"}
0005432125468	59C8E8	7698 500563	NADEZHDA KOZLOVA	{"email": "kozlova_nadezhda.14111962@postgrespro.ru", "phone": "+70743885761"}
0005432125469	C21A16	4327 740962	SANIYA ANISIMOVA	{"email": "anisimova_saniya-081972@postgrespro.ru", "phone": "+70413678192"}
0005432125470	26E5CC	5368 383706	DMITRIY MEDVEDEV	{"email": "medvedev-d.091975@postgrespro.ru", "phone": "+70613729455"}
0005432125471	E3804E	2186 742500	YULIYA PAVLOVA	{"email": "pavlovayuliya.121972@postgrespro.ru", "phone": "+70308120480"}
0005432125472	E3804E	7198 321286	ALEKSANDR TIKHONOV	{"phone": "+70785722084"}
0005432125473	2BBA66	4619 257502	VITALIY FROLOV	{"email": "v-frolov.051978@postgrespro.ru", "phone": "+70044100777"}
0005432125474	6890AC	5270 669661	LYUDMILA SEMENOVA	{"email": "lsemenova.1974@postgrespro.ru", "phone": "+70036905209"}
0005432125475	63D0AB	8286 932800	ALEKSANDR ANTONOV	{"phone": "+70479889256"}
0005432125476	63D0AB	1539 221076	ARTEM KOZLOV	{"phone": "+70124142379"}
0005432125477	A71F4E	9568 153720	VYACHESLAV MIRONOV	{"email": "v-mironov_091974@postgrespro.ru", "phone": "+70375298303"}
0005432125478	DB6E6D	2691 412387	ELENA KONDRATEVA	{"email": "e_kondrateva-1978@postgrespro.ru", "phone": "+70636957852"}
0005432125479	67AFFE	1510 337309	ANTONINA NOVIKOVA	{"email": "a.novikova.02081974@postgrespro.ru", "phone": "+70385975185"}
0005432125480	C21C06	7183 727331	MARIYA KONDRATEVA	{"email": "kondrateva.m_1986@postgrespro.ru", "phone": "+70452204801"}
0005432125481	C21C06	6892 148253	VALENTINA BELYAEVA	{"phone": "+70991252497"}
0005432125482	52B316	6512 423211	VLADISLAV SIDOROV	{"email": "sidorov_vladislav1973@postgrespro.ru", "phone": "+70983729936"}
0005432125483	0FAD52	3798 458886	LIYA TARASOVA	{"phone": "+70087378572"}
0005432125484	0FAD52	6105 014387	ANTON NIKITIN	{"phone": "+70076014376"}
0005432125485	BBC932	3068 288861	NATALYA GORBUNOVA	{"email": "gorbunova.natalya1969@postgrespro.ru", "phone": "+70114464172"}
0005432125486	BBC932	2878 537197	MARINA FILATOVA	{"phone": "+70939389880"}
0005432125487	DBDD95	7584 220739	ARSENIY NAZAROV	{"phone": "+70934881369"}
0005432125488	DBDD95	2797 025372	MARIYA KRASNOVA	{"phone": "+70376268688"}
0005432125489	EAF546	3294 721400	LYUDMILA MAKSIMOVA	{"email": "lyudmila-maksimova07051972@postgrespro.ru", "phone": "+70575593094"}
0005432125490	EAF546	8329 615184	IGOR ANDREEV	{"phone": "+70003371882"}
0005432125491	5EFF30	3075 257308	MIKHAIL VOLKOV	{"email": "mikhail.volkov-021976@postgrespro.ru", "phone": "+70251645155"}
0005432125492	5EFF30	9552 438045	SERGEY ZHURAVLEV	{"email": "sergey-zhuravlev101974@postgrespro.ru", "phone": "+70821452558"}
0005432125493	560A8E	7745 529460	GRIGORIY MIKHAYLOV	{"phone": "+70551576872"}
0005432125494	560A8E	0102 699562	LEV FEDOROV	{"email": "fedorovlev.041969@postgrespro.ru", "phone": "+70885328498"}
0005432125495	0DCEE3	6126 525841	ALEKSEY MATVEEV	{"phone": "+70895086619"}
0005432125496	108284	9336 520329	ALEKSANDR NIKITIN	{"phone": "+70734564773"}
0005432125497	552AF6	6233 853015	LYUDMILA ANISIMOVA	{"email": "lyudmila_anisimova03021981@postgrespro.ru", "phone": "+70366937523"}
0005432125498	1E21AC	6416 504272	EKATERINA MELNIKOVA	{"phone": "+70756869166"}
0005432125499	1E21AC	1592 636811	KSENIYA SMIRNOVA	{"phone": "+70617332378"}
0005432125500	7CF8A1	8305 463851	SERGEY MAKAROV	{"email": "smakarov.111987@postgrespro.ru", "phone": "+70764673404"}
0005432125501	FFCCF6	1566 291330	SERGEY POPOV	{"email": "sergey_popov-1970@postgrespro.ru", "phone": "+70171075288"}
0005432125502	CBE4E8	6848 229949	VYACHESLAV AFANASEV	{"email": "v-afanasev_16031974@postgrespro.ru", "phone": "+70390754084"}
0005432125503	2E8A18	1360 868067	GENNADIY FEDOTOV	{"email": "fedotovgennadiy.101983@postgrespro.ru", "phone": "+70713884912"}
0005432125504	ED6E8D	1476 092766	IRINA OVCHINNIKOVA	{"phone": "+70400631033"}
0005432125505	1905B5	5145 182417	LYUDMILA SAVELEVA	{"email": "lsaveleva_28111963@postgrespro.ru", "phone": "+70392671691"}
0005432125506	B27575	3204 591365	KIRILL NOVIKOV	{"email": "k.novikov-04101976@postgrespro.ru", "phone": "+70402535595"}
0005432125507	B27575	0586 343711	TAMARA KOZLOVA	{"email": "kozlova_tamara_02051979@postgrespro.ru", "phone": "+70826764305"}
0005432125508	B9AE8B	3479 545076	RINAT ORLOV	{"phone": "+70224599544"}
0005432125509	CDF6B6	4562 481846	ALEKSEY FROLOV	{"phone": "+70804966787"}
0005432125510	C544B2	6078 469581	SVETLANA AKIMOVA	{"email": "svetlanaakimova_1975@postgrespro.ru", "phone": "+70502523927"}
0005432125511	7DA57A	3714 942093	GALINA KARPOVA	{"email": "karpova-g_1979@postgrespro.ru", "phone": "+70421085002"}
0005432125512	2DC290	9391 116721	NIKOLAY MELNIKOV	{"phone": "+70192712493"}
0005432125513	2DC290	5875 471835	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya_07011972@postgrespro.ru", "phone": "+70245923460"}
0005432125514	B5B515	6859 438932	NIKOLAY SOKOLOV	{"phone": "+70161172701"}
0005432125515	DE475A	6117 156910	TATYANA KONDRATEVA	{"phone": "+70685670132"}
0005432125516	2D2030	1382 178788	SERGEY VASILEV	{"email": "vasilevsergey.28051964@postgrespro.ru", "phone": "+70246376790"}
0005432125517	2D2030	7371 108733	POLINA STEPANOVA	{"email": "stepanovapolina1976@postgrespro.ru", "phone": "+70667044294"}
0005432125518	7A8122	1361 930980	VALERIY SOROKIN	{"email": "sorokinvaleriy-051981@postgrespro.ru", "phone": "+70796126209"}
0005432125519	7A8122	3685 076353	DMITRIY BORISOV	{"email": "dmitriy.borisov.1970@postgrespro.ru", "phone": "+70332816818"}
0005432125520	24BCA4	1028 526061	DANILA SOKOLOV	{"phone": "+70388785682"}
0005432125521	24BCA4	3088 599732	LARISA ROMANOVA	{"email": "l.romanova.1962@postgrespro.ru", "phone": "+70939006058"}
0005432125522	51A51F	3859 921899	LYUBOV GERASIMOVA	{"phone": "+70432559573"}
0005432125523	51A51F	2876 574045	ARINA POPOVA	{"phone": "+70155038621"}
0005432125524	D7E0AA	8620 093531	ELENA MAKAROVA	{"phone": "+70071919572"}
0005432125525	41AD05	7567 612087	IGOR ZAKHAROV	{"email": "i-zakharov28091972@postgrespro.ru", "phone": "+70967134632"}
0005432125526	263A0A	2124 994972	DENIS VLASOV	{"email": "denis_vlasov.1971@postgrespro.ru", "phone": "+70801412509"}
0005432125527	0BC137	1017 782470	GALINA YUDINA	{"email": "yudina_g25061963@postgrespro.ru", "phone": "+70084133031"}
0005432125528	0BC137	6742 144886	NELLI NIKITINA	{"phone": "+70142433983"}
0005432125529	90A4C1	6052 103195	EVDOKIYA BELOVA	{"phone": "+70800831629"}
0005432125530	90A4C1	7382 351360	VALENTINA IVANOVA	{"phone": "+70484143473"}
0005432125531	DE39E6	5217 593228	EKATERINA MEDVEDEVA	{"phone": "+70916202322"}
0005432125532	C20008	2354 469819	YURIY VLASOV	{"email": "yuriy.vlasov051982@postgrespro.ru", "phone": "+70750796121"}
0005432125533	C164BF	0838 953355	ALEKSANDRA SOKOLOVA	{"phone": "+70675085181"}
0005432125534	7A057B	8759 303185	NINA DENISOVA	{"email": "nina.denisova.011961@postgrespro.ru", "phone": "+70624098714"}
0005432125535	78FA94	3047 872293	KSENIYA FEDOROVA	{"phone": "+70367848753"}
0005432125536	8D3C12	9494 451903	ALEKSEY KULIKOV	{"phone": "+70042794761"}
0005432125537	D3FFED	9982 071784	LIDIYA GERASIMOVA	{"phone": "+70408436006"}
0005432125538	D3FFED	5186 958036	NATALYA MIKHAYLOVA	{"email": "natalya_mikhaylova-1968@postgrespro.ru", "phone": "+70081062864"}
0005432125539	F0D69D	6541 660845	ANNA FOMINA	{"email": "fominaanna-1965@postgrespro.ru", "phone": "+70366962705"}
0005432125540	8B9F0A	5468 294547	MARIYA MAKSIMOVA	{"phone": "+70776938668"}
0005432125541	F17A47	3403 780448	MARIANNA SCHERBAKOVA	{"phone": "+70753860815"}
0005432125542	866C25	4613 893987	OLEG EGOROV	{"phone": "+70718333008"}
0005432125543	85E788	4925 927081	MIKHAIL EGOROV	{"email": "mikhailegorov121971@postgrespro.ru", "phone": "+70382134133"}
0005432125544	85E788	0046 766991	VIKTORIYA PAVLOVA	{"phone": "+70158946204"}
0005432125545	A42A74	5736 303761	ALEKSANDRA KONOVALOVA	{"email": "a.konovalova-081976@postgrespro.ru", "phone": "+70365763109"}
0005432125546	4E2CDF	4424 282785	VERA KARPOVA	{"phone": "+70415301046"}
0005432125547	4E2CDF	3625 314260	LYUDMILA AKIMOVA	{"email": "akimova.l.1976@postgrespro.ru", "phone": "+70936306590"}
0005432125548	FA9668	3397 500665	KIRILL SOLOVEV	{"email": "k_solovev1974@postgrespro.ru", "phone": "+70274711745"}
0005432125549	FA9668	7713 809329	DENIS MELNIKOV	{"email": "denismelnikov_121967@postgrespro.ru", "phone": "+70851380541"}
0005432125550	93637E	6000 619886	KLAVDIYA FROLOVA	{"email": "klavdiya_frolova.051969@postgrespro.ru", "phone": "+70670199601"}
0005432125551	18F50A	4772 469790	KLAVDIYA FOMINA	{"phone": "+70699838760"}
0005432125552	18F50A	9614 863233	ANATOLIY SERGEEV	{"email": "anatoliy.sergeev-1965@postgrespro.ru", "phone": "+70680572747"}
0005432125553	9CB3BC	6858 033164	ROZA SOKOLOVA	{"email": "r.sokolova.041971@postgrespro.ru", "phone": "+70802637128"}
0005432125554	C91FFC	8341 957451	TATYANA VOLKOVA	{"email": "volkovatatyana.1971@postgrespro.ru", "phone": "+70996377519"}
0005432125555	C91FFC	9452 666962	ALEKSANDRA NIKITINA	{"email": "nikitina.a.10011967@postgrespro.ru", "phone": "+70980683493"}
0005432125556	AE668E	4674 183118	MIKHAIL ZAKHAROV	{"phone": "+70344556425"}
0005432125557	AE668E	0585 387058	LADA KRASNOVA	{"phone": "+70002102779"}
0005432125558	AE668E	7271 474119	ALEKSEY TIMOFEEV	{"email": "timofeevaleksey-011973@postgrespro.ru", "phone": "+70640214559"}
0005432125559	835D9D	2292 899171	ELENA ERMAKOVA	{"email": "e-ermakova_1976@postgrespro.ru", "phone": "+70838772553"}
0005432125560	07D5F1	1658 419395	VALENTIN SHEVCHENKO	{"phone": "+70697484909"}
0005432125561	07D5F1	6762 123557	VIKTOR ZAKHAROV	{"email": "zakharovv_15111976@postgrespro.ru", "phone": "+70699512963"}
0005432125562	92759C	7696 707892	ALEKSEY KRASNOV	{"phone": "+70052890667"}
0005432125563	B83FB1	1602 098995	DIANA NIKOLAEVA	{"email": "dnikolaeva-101971@postgrespro.ru", "phone": "+70369782051"}
0005432125564	01CAEA	8944 504251	LEV KRASNOV	{"email": "krasnov-l.13061968@postgrespro.ru", "phone": "+70746609524"}
0005432125565	4B24D9	9466 642923	GENNADIY IVANOV	{"email": "g-ivanov-011984@postgrespro.ru", "phone": "+70485803768"}
0005432125566	F19443	8717 877590	PAVEL KISELEV	{"phone": "+70980254363"}
0005432125567	78704E	9458 010584	ELENA MASLOVA	{"email": "maslova-elena1971@postgrespro.ru", "phone": "+70349923241"}
0005432125568	13F2AB	6257 554802	DIANA FOMINA	{"email": "diana_fomina_031980@postgrespro.ru", "phone": "+70347611983"}
0005432125569	3EF96D	6236 802300	VLADIMIR FEDOROV	{"email": "vladimir.fedorov091973@postgrespro.ru", "phone": "+70597074639"}
0005432125570	3EF96D	8688 963850	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr1978@postgrespro.ru", "phone": "+70332926652"}
0005432125571	5A2F77	4085 298333	LYUDMILA BORISOVA	{"phone": "+70671565184"}
0005432125572	5A2F77	2402 802312	DMITRIY GORBUNOV	{"email": "gorbunov-dmitriy_20101976@postgrespro.ru", "phone": "+70695941434"}
0005432125573	3778F7	1678 159735	VYACHESLAV NIKITIN	{"email": "nikitin_vyacheslav121969@postgrespro.ru", "phone": "+70453686575"}
0005432125574	3778F7	0227 643375	NADEZHDA KRASNOVA	{"email": "n-krasnova.091963@postgrespro.ru", "phone": "+70401198584"}
0005432125575	567BDD	0150 081271	SERGEY VASILEV	{"phone": "+70039874115"}
0005432125576	567BDD	6049 853312	ROMAN MATVEEV	{"email": "rmatveev_011978@postgrespro.ru", "phone": "+70422936075"}
0005432125577	B1BCCA	5144 713683	EDUARD BONDARENKO	{"email": "bondarenkoeduard-1966@postgrespro.ru", "phone": "+70042839253"}
0005432125578	B1BCCA	4439 040566	TATYANA TIMOFEEVA	{"email": "timofeeva-tatyana1968@postgrespro.ru", "phone": "+70434223080"}
0005432125579	62CA51	3541 284896	NIKOLAY KARPOV	{"email": "karpov.n.1956@postgrespro.ru", "phone": "+70777093896"}
0005432125580	686D05	3711 602284	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.a051980@postgrespro.ru", "phone": "+70156990955"}
0005432125581	09D890	1557 645518	LYUDMILA ILINA	{"phone": "+70293403935"}
0005432125582	B653AB	6029 327779	VALENTINA SERGEEVA	{"email": "sergeeva.v-24121968@postgrespro.ru", "phone": "+70317612110"}
0005432125583	5BFABA	1497 276369	ALEKSANDR MIRONOV	{"email": "a.mironov-07111964@postgrespro.ru", "phone": "+70058858573"}
0005432125584	0E6575	8455 571098	SVETLANA FADEEVA	{"phone": "+70960213240"}
0005432125585	489757	6157 755073	ANDREY MOISEEV	{"email": "moiseevandrey_1966@postgrespro.ru", "phone": "+70920574317"}
0005432125586	6ED527	7424 723313	TAMARA PETROVA	{"email": "tamarapetrova-051982@postgrespro.ru", "phone": "+70153083054"}
0005432125587	11EDBF	2017 626036	VLADISLAV GORBUNOV	{"phone": "+70499817198"}
0005432125588	11EDBF	6505 774585	ALEKSEY VASILEV	{"email": "vasilev_aleksey_23061986@postgrespro.ru", "phone": "+70593186612"}
0005432125589	130B26	3734 896571	RIMMA ZOTOVA	{"email": "r.zotova_121979@postgrespro.ru", "phone": "+70384803188"}
0005432125590	3C41F2	4865 859324	NADEZHDA KOLESNIKOVA	{"phone": "+70200152059"}
0005432125591	C5731C	6415 708908	VALERIY ROMANOV	{"phone": "+70598630699"}
0005432125592	816E82	6110 551696	NATALYA SMIRNOVA	{"phone": "+70534069596"}
0005432125593	816E82	7923 397423	LYUDMILA BORISOVA	{"phone": "+70993385000"}
0005432125594	F72A58	1393 485114	PAVEL MARTYNOV	{"phone": "+70405365110"}
0005432125595	8E920A	8877 695858	LIDIYA ZAKHAROVA	{"email": "zakharova_l.14061980@postgrespro.ru", "phone": "+70774286649"}
0005432125596	CB7BE5	6111 785918	LIDIYA AFANASEVA	{"email": "lafanaseva.07111969@postgrespro.ru", "phone": "+70760032194"}
0005432125597	CB7BE5	5232 548869	TATYANA EGOROVA	{"phone": "+70588517771"}
0005432125598	E3FB73	8135 740840	ANTON POPOV	{"email": "popov-a.10081974@postgrespro.ru", "phone": "+70343831097"}
0005432125599	E200C9	7850 216643	TATYANA FROLOVA	{"email": "tatyana-frolova06011967@postgrespro.ru", "phone": "+70051147891"}
0005432125600	D0D29D	0371 134671	GALINA SERGEEVA	{"phone": "+70329868044"}
0005432125601	B80FE8	9241 752449	NADEZHDA ERMAKOVA	{"email": "nadezhda.ermakova_081973@postgrespro.ru", "phone": "+70535270473"}
0005432125602	B80FE8	6743 595216	NIKOLAY FOMIN	{"email": "nikolay.fomin1965@postgrespro.ru", "phone": "+70185277745"}
0005432125603	F00D27	0476 275167	VALERIYA YAKOVLEVA	{"email": "yakovleva-valeriya.1958@postgrespro.ru", "phone": "+70356494554"}
0005432125604	FC7D00	0873 285866	ARINA MELNIKOVA	{"email": "arinamelnikova26011976@postgrespro.ru", "phone": "+70612549636"}
0005432125605	FC7D00	0538 643539	POLINA TIKHONOVA	{"phone": "+70594939566"}
0005432125606	D74CA1	3286 493143	NIKOLAY ANTONOV	{"email": "antonov.nikolay.041969@postgrespro.ru", "phone": "+70069093568"}
0005432125607	F4AB1C	8130 326764	ALEKSANDR SMIRNOV	{"phone": "+70920599250"}
0005432125608	F4AB1C	5050 923492	ANGELINA ZAKHAROVA	{"phone": "+70517756048"}
0005432125609	91582D	1160 833868	ANASTASIYA LUKYANOVA	{"email": "lukyanovaa.051980@postgrespro.ru", "phone": "+70446314660"}
0005432125610	C9565A	6103 838410	TIMUR GRIGOREV	{"phone": "+70533605899"}
0005432125611	C9565A	5244 396659	TATYANA ISAEVA	{"email": "t_isaeva.081979@postgrespro.ru", "phone": "+70053660303"}
0005432125612	C9565A	0094 219308	NIKOLAY ZHUKOV	{"email": "zhukov-n081979@postgrespro.ru", "phone": "+70339214532"}
0005432125613	5B1EFF	4392 375299	ANTONINA LOGINOVA	{"email": "aloginova-1967@postgrespro.ru", "phone": "+70617422551"}
0005432125614	F65426	0210 456277	IVAN EGOROV	{"email": "ivan_egorov041976@postgrespro.ru", "phone": "+70484299642"}
0005432125615	F65426	2819 030840	MATVEY ALEKSEEV	{"phone": "+70596764560"}
0005432125616	100333	7291 258646	SERGEY KONOVALOV	{"email": "s.konovalov_1987@postgrespro.ru", "phone": "+70691909657"}
0005432125617	100333	0295 101220	VITALIY MOROZOV	{"email": "morozov_v24071965@postgrespro.ru", "phone": "+70550440820"}
0005432125618	326945	6083 026261	IRINA KAZAKOVA	{"email": "kazakova.irina_041975@postgrespro.ru", "phone": "+70293537483"}
0005432125619	F89768	2450 177826	ANNA BARANOVA	{"email": "baranova_anna_02061964@postgrespro.ru", "phone": "+70140888577"}
0005432125620	650941	9785 164329	GALINA NOVIKOVA	{"phone": "+70559373587"}
0005432125621	E732C8	6169 070399	ALEKSANDR STEPANOV	{"phone": "+70624917118"}
0005432125622	E732C8	5497 741962	LIDIYA KAZAKOVA	{"email": "lidiya-kazakova-051981@postgrespro.ru", "phone": "+70141900615"}
0005432125623	B25404	6570 630310	OLEG VOLKOV	{"phone": "+70988585105"}
0005432125624	B25404	1282 173891	VLADISLAV SCHERBAKOV	{"email": "scherbakov.vladislav_15111986@postgrespro.ru", "phone": "+70772941183"}
0005432125625	969ED0	8795 977776	RASHID NIKOLAEV	{"email": "rashid_nikolaev.121981@postgrespro.ru", "phone": "+70373987962"}
0005432125626	969ED0	8701 033862	NIKOLAY ROMANOV	{"email": "romanov_nikolay23011988@postgrespro.ru", "phone": "+70904196396"}
0005432125627	7A8E76	2742 918041	ELENA VASILEVA	{"email": "vasileva_e.19031972@postgrespro.ru", "phone": "+70032873093"}
0005432125628	7A8E76	6010 344630	VALENTINA MELNIKOVA	{"email": "valentina.melnikova.1963@postgrespro.ru", "phone": "+70756067974"}
0005432125629	CBABD8	3522 597282	NADEZHDA FOMINA	{"email": "fominanadezhda-071966@postgrespro.ru", "phone": "+70086890228"}
0005432125630	CBABD8	7458 330177	SERGEY SERGEEV	{"phone": "+70079413150"}
0005432125631	CBABD8	1168 883066	VALENTINA ROMANOVA	{"email": "v-romanova1961@postgrespro.ru", "phone": "+70548905731"}
0005432125633	BD0D0F	4570 203393	VLADIMIR ANDREEV	{"phone": "+70512696325"}
0005432125634	BD0D0F	8488 123058	IGOR ZHURAVLEV	{"email": "zhuravlevigor1977@postgrespro.ru", "phone": "+70928979030"}
0005432125635	7EAC2B	5339 911291	LYUDMILA GUSEVA	{"email": "l_guseva1975@postgrespro.ru", "phone": "+70950761502"}
0005432125636	B7FED0	2949 920384	NIKOLAY DMITRIEV	{"phone": "+70075761817"}
0005432125637	49D0C5	3981 779577	ANATOLIY DMITRIEV	{"email": "dmitriev.anatoliy-101962@postgrespro.ru", "phone": "+70444000526"}
0005432125638	49D0C5	7117 227166	YULIYA MIKHAYLOVA	{"email": "y_mikhaylova_1967@postgrespro.ru", "phone": "+70657887278"}
0005432125639	49D0C5	4521 552301	EMMA SERGEEVA	{"email": "sergeevae.25071966@postgrespro.ru", "phone": "+70819810577"}
0005432125640	83675F	9491 792382	SERGEY KULIKOV	{"phone": "+70869535179"}
0005432125641	09C792	2336 779414	GEORGIY ANTONOV	{"email": "g_antonov-11101967@postgrespro.ru", "phone": "+70797354289"}
0005432125642	AB1781	8261 341273	RASHID AFANASEV	{"email": "r_afanasev.13101969@postgrespro.ru", "phone": "+70701061182"}
0005432125643	AB1781	9816 201549	SERGEY GAVRILOV	{"phone": "+70868052888"}
0005432125644	1B7716	3086 251546	ANASTASIYA ABRAMOVA	{"phone": "+70107399979"}
0005432125645	1B7716	8742 938943	MARINA BARANOVA	{"email": "baranova_m17081965@postgrespro.ru", "phone": "+70221279154"}
0005432125646	748372	6518 466782	SERGEY GAVRILOV	{"email": "sergey.gavrilov071962@postgrespro.ru", "phone": "+70131292527"}
0005432125647	748372	7422 421294	DIANA ALEKSEEVA	{"email": "alekseeva-d1970@postgrespro.ru", "phone": "+70543059121"}
0005432125648	14CD35	6451 783184	ALEKSEY SIDOROV	{"phone": "+70138325715"}
0005432125649	6630AE	8000 432173	YULIYA YAKOVLEVA	{"email": "yuliya-yakovleva111960@postgrespro.ru", "phone": "+70082052078"}
0005432125650	92D717	6127 346183	ELENA KUZNECOVA	{"email": "kuznecova-e_1970@postgrespro.ru", "phone": "+70467122087"}
0005432125651	48BC0C	2340 749946	GALINA ERMAKOVA	{"phone": "+70947056529"}
0005432125652	15F9BD	3813 664115	OLESYA AFANASEVA	{"phone": "+70519477332"}
0005432125653	15F9BD	9557 235159	ALEKSANDR CHERNOV	{"email": "chernov-a_051975@postgrespro.ru", "phone": "+70990663787"}
0005432125654	01957B	5164 355612	VALENTINA KOROLEVA	{"email": "koroleva_valentina.051969@postgrespro.ru", "phone": "+70232796234"}
0005432125655	FF039F	5480 103366	VLADIMIR CHERNOV	{"phone": "+70147808829"}
0005432125656	FF039F	5741 289677	SERGEY IVANOV	{"email": "s-ivanov05071981@postgrespro.ru", "phone": "+70184109404"}
0005432125657	015852	1767 524933	VERA VOROBEVA	{"email": "vorobeva_vera11101974@postgrespro.ru", "phone": "+70049635544"}
0005432125658	015852	3786 449451	OKSANA POPOVA	{"email": "popova.oksana_021976@postgrespro.ru", "phone": "+70007742995"}
0005432125659	A303A8	9221 870141	IRINA KUZNECOVA	{"email": "irina_kuznecova-07041958@postgrespro.ru", "phone": "+70797841140"}
0005432125660	E417C1	5762 298121	MAKSIM ZHURAVLEV	{"email": "maksimzhuravlev.121980@postgrespro.ru", "phone": "+70637422441"}
0005432125661	E417C1	9327 805865	SERGEY SOLOVEV	{"phone": "+70478784414"}
0005432125662	E70F3F	2827 697714	ANTONINA POPOVA	{"email": "popova.antonina-041973@postgrespro.ru", "phone": "+70570812812"}
0005432125663	64C045	0008 009364	GALINA NAZAROVA	{"phone": "+70136515865"}
0005432132949	C48104	6231 464265	ELENA SCHERBAKOVA	{"phone": "+70731377531"}
0005432132941	2C4035	6309 368541	ALEKSANDR BARANOV	{"email": "baranov.a.1975@postgrespro.ru", "phone": "+70955438641"}
0005432132942	2C4035	8690 410766	NINA ZAKHAROVA	{"phone": "+70396248411"}
0005432132943	BB4F41	4933 725098	TATYANA YAKOVLEVA	{"email": "tatyanayakovleva_091968@postgrespro.ru", "phone": "+70648486522"}
0005432132944	BB4F41	0774 219427	VIKTORIYA NIKITINA	{"phone": "+70590434275"}
0005432132945	3893F3	4036 528183	VIKTOR DENISOV	{"phone": "+70016439171"}
0005432132946	3893F3	7280 938838	ZHANNA MASLOVA	{"phone": "+70362275809"}
0005432132947	F43DF3	7243 340545	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov.051979@postgrespro.ru", "phone": "+70263679850"}
0005432132948	9A5740	0467 278211	IVAN FEDOTOV	{"email": "i_fedotov-10101973@postgrespro.ru", "phone": "+70266789802"}
0005432132950	C4F254	0831 629756	NATALYA ZAYCEVA	{"email": "natalya.zayceva_31101969@postgrespro.ru", "phone": "+70648243326"}
0005432132951	DF032D	5759 462462	DMITRIY ORLOV	{"phone": "+70409184469"}
0005432132952	71D1E3	7677 716165	MIKHAIL BORISOV	{"phone": "+70406647259"}
0005432132953	051CDF	8903 471364	NADEZHDA IVANOVA	{"phone": "+70545452714"}
0005432132954	3485FD	6813 631304	SERGEY SEMENOV	{"email": "semenovsergey_08091982@postgrespro.ru", "phone": "+70052903950"}
0005432132955	3485FD	8931 337823	ANATOLIY ZAYCEV	{"email": "anatoliyzaycev-101975@postgrespro.ru", "phone": "+70047434696"}
0005432132956	EF8E96	0737 772511	DENIS DENISOV	{"email": "denis-denisov_23011956@postgrespro.ru", "phone": "+70019307653"}
0005432132957	016BBE	4193 663142	PETR ALEKSANDROV	{"phone": "+70480483975"}
0005432132958	AE00C4	2020 281293	NIKOLAY PAVLOV	{"phone": "+70551357429"}
0005432132959	6CB327	8012 531506	SVETLANA OVCHINNIKOVA	{"phone": "+70722544047"}
0005432132960	F7D313	3599 242195	ALEKSANDR KULIKOV	{"phone": "+70823728362"}
0005432132961	73D63C	8368 710870	OKSANA SIDOROVA	{"phone": "+70324416960"}
0005432132962	73D63C	5073 053372	TAMARA ANDREEVA	{"email": "t-andreeva-1979@postgrespro.ru", "phone": "+70164357061"}
0005432132963	B9B1B1	6287 568362	ANATOLIY KRASNOV	{"email": "anatoliy-krasnov.18021979@postgrespro.ru", "phone": "+70129600023"}
0005432132964	B9B1B1	8295 791045	ANTON DMITRIEV	{"phone": "+70283215736"}
0005432132965	AD8D6F	8066 150327	NIKOLAY KUZMIN	{"phone": "+70260848627"}
0005432132966	EC9FE6	4998 180780	VALENTINA ZAKHAROVA	{"phone": "+70240779776"}
0005432132967	EC9FE6	8065 782104	YURIY CHERNOV	{"phone": "+70957603175"}
0005432132968	EC9FE6	1276 172690	ALEKSANDR SOLOVEV	{"phone": "+70362459523"}
0005432132969	F0B64A	0987 018516	YAROSLAV MARTYNOV	{"email": "yaroslav-martynov-20071968@postgrespro.ru", "phone": "+70513124434"}
0005432132970	5B1113	1954 438140	OLESYA ZAKHAROVA	{"email": "zakharovaolesya071966@postgrespro.ru", "phone": "+70762927608"}
0005432132971	7A02AB	3614 378718	MARIYA YUDINA	{"phone": "+70271095055"}
0005432132972	0B2221	1101 977242	LEONID POPOV	{"email": "popovl.1980@postgrespro.ru", "phone": "+70533834403"}
0005432132973	0B2221	1074 676312	SVETLANA SMIRNOVA	{"email": "s_smirnova_051972@postgrespro.ru", "phone": "+70297981200"}
0005432132974	053841	8806 749096	DMITRIY POPOV	{"email": "dmitriy.popov-09011968@postgrespro.ru", "phone": "+70097249548"}
0005432132975	053841	4119 439845	VITALIY ANDREEV	{"email": "v-andreev-1971@postgrespro.ru", "phone": "+70513379270"}
0005432132976	053841	0993 745041	OLEG TIKHONOV	{"phone": "+70672104375"}
0005432132977	59BB96	2848 585324	VALENTINA VOLKOVA	{"email": "valentinavolkova_16111975@postgrespro.ru", "phone": "+70244665722"}
0005432132978	68AF28	0143 985654	OLGA NIKITINA	{"phone": "+70637992761"}
0005432132979	68AF28	1690 765539	YANA POTAPOVA	{"phone": "+70743902494"}
0005432132980	1927B7	1456 306118	YURIY KUZNECOV	{"email": "yuriy-kuznecov_19041978@postgrespro.ru", "phone": "+70483548512"}
0005432132981	7A02C5	4247 501194	TATYANA AFANASEVA	{"email": "t_afanaseva101977@postgrespro.ru", "phone": "+70382141960"}
0005432132982	8FA024	1293 220490	VLADIMIR ZAKHAROV	{"email": "vladimir-zakharov_011968@postgrespro.ru", "phone": "+70349305922"}
0005432132983	8FA024	3195 650618	OLGA NIKOLAEVA	{"email": "nikolaeva-o-1971@postgrespro.ru", "phone": "+70682774948"}
0005432132984	4D4DA0	1085 485458	TAMARA MAKAROVA	{"email": "makarova.t-061976@postgrespro.ru", "phone": "+70154122744"}
0005432132985	5139D6	9096 723502	ANDREY POPOV	{"email": "a-popov1985@postgrespro.ru", "phone": "+70346561251"}
0005432132986	2CB589	8024 221801	NIKOLAY KULIKOV	{"email": "nikolay-kulikov-041977@postgrespro.ru", "phone": "+70997772336"}
0005432132987	B3F4C5	6498 784656	YAROSLAV IVANOV	{"phone": "+70874112788"}
0005432132988	B3F4C5	4056 868125	ANDREY VOROBEV	{"email": "vorobev.a_1974@postgrespro.ru", "phone": "+70283527394"}
0005432132989	E7CF30	4389 803403	KLARA KISELEVA	{"email": "kiselevak111972@postgrespro.ru", "phone": "+70809716971"}
0005432132990	0FD520	1133 734214	ZINAIDA RODIONOVA	{"phone": "+70715713620"}
0005432132991	FAA301	7465 537261	ROZA FROLOVA	{"email": "rfrolova_1965@postgrespro.ru", "phone": "+70164345122"}
0005432132992	6DDDF5	2879 019996	PAVEL BONDARENKO	{"phone": "+70776488369"}
0005432132993	6DDDF5	1820 794334	ALENA POTAPOVA	{"email": "potapova-a-071975@postgrespro.ru", "phone": "+70629725327"}
0005432132994	AA7B8B	5433 260658	VYACHESLAV KONOVALOV	{"email": "konovalov-v.04011973@postgrespro.ru", "phone": "+70131104825"}
0005432132995	DE6DF8	0728 561177	PETR GUSEV	{"phone": "+70533340946"}
0005432132996	82EF02	3622 411346	EKATERINA KARPOVA	{"phone": "+70307376207"}
0005432132997	3D62B9	2403 676776	ELIZAVETA BARANOVA	{"email": "baranova.e.09121964@postgrespro.ru", "phone": "+70025794306"}
0005432132998	E3C529	1596 590799	DARYA VASILEVA	{"email": "d-vasileva-1967@postgrespro.ru", "phone": "+70589879507"}
0005432132999	E027ED	1197 041735	ALEKSANDR ALEKSEEV	{"email": "a.alekseev_051977@postgrespro.ru", "phone": "+70809897351"}
0005432133000	17467B	4170 170768	SVETLANA KRASNOVA	{"phone": "+70012991513"}
0005432133001	1A84A1	5488 209098	INNA ZAYCEVA	{"phone": "+70666841991"}
0005432133002	1B7C44	5240 122172	NIKITA MIKHAYLOV	{"phone": "+70968268756"}
0005432133003	1B7C44	4375 375818	LILIYA ZHUKOVA	{"phone": "+70485406208"}
0005432133004	07F8EA	9262 660302	PAVEL VOROBEV	{"phone": "+70119607218"}
0005432133005	07F8EA	2309 611840	TATYANA KULIKOVA	{"email": "kulikova-t051965@postgrespro.ru", "phone": "+70089005653"}
0005432133006	BEC366	2665 155472	ANATOLIY IVANOV	{"phone": "+70919243499"}
0005432133007	BEC366	9835 333204	ELENA PETROVA	{"phone": "+70432990261"}
0005432133008	B5C4C2	1795 511981	ELENA FEDOROVA	{"phone": "+70133314429"}
0005432133009	6B2F03	3368 661087	KIRILL MATVEEV	{"email": "k-matveev1984@postgrespro.ru", "phone": "+70624033902"}
0005432133010	6B2F03	0339 318639	ALEKSANDR SMIRNOV	{"phone": "+70085022775"}
0005432133011	564AD8	2304 738186	SERGEY IVANOV	{"phone": "+70030100023"}
0005432133012	07CFC4	3817 208582	VLADIMIR FEDOTOV	{"phone": "+70181672190"}
0005432133013	4AFDBF	5411 135964	EVGENIYA NIKIFOROVA	{"email": "nikiforova_e1972@postgrespro.ru", "phone": "+70102662203"}
0005432133014	EDE0FA	8193 359070	VITALIY BELOV	{"email": "belov_vitaliy_061969@postgrespro.ru", "phone": "+70806399392"}
0005432133015	EDE0FA	3108 460535	RINAT MOISEEV	{"phone": "+70911612910"}
0005432133016	C6652D	8036 415301	ELENA FADEEVA	{"phone": "+70759288155"}
0005432133017	9D8BCC	1231 741282	FEDOR ROMANOV	{"phone": "+70189227045"}
0005432133018	7DE0B1	2592 537714	DMITRIY MIRONOV	{"phone": "+70138941953"}
0005432133019	958B76	0729 765647	ZINAIDA ISAEVA	{"email": "isaeva-z31081973@postgrespro.ru", "phone": "+70683884224"}
0005432133020	958B76	5223 302963	ALEKSANDR TARASOV	{"phone": "+70402607271"}
0005432133021	E4D353	2119 105450	NIKOLAY MOISEEV	{"phone": "+70821111364"}
0005432133022	7E0B9F	4366 088696	ANDREY DENISOV	{"email": "adenisov_011975@postgrespro.ru", "phone": "+70256666972"}
0005432133023	F183C0	6350 321526	ALEKSANDRA FOMINA	{"email": "fomina-aleksandra.111974@postgrespro.ru", "phone": "+70613243250"}
0005432133024	E6C0D0	1212 754863	ALEKSEY KRASNOV	{"email": "a_krasnov_071977@postgrespro.ru", "phone": "+70823667280"}
0005432133025	E6C0D0	4335 760445	ALISA SMIRNOVA	{"phone": "+70600571324"}
0005432133026	D720AF	3232 307236	OLGA ILINA	{"phone": "+70578899497"}
0005432133027	E89FBB	4690 169193	VLADIMIR PETROV	{"email": "vladimirpetrov.101968@postgrespro.ru", "phone": "+70704988761"}
0005432133028	E0B77A	8206 270013	MARIYA SEMENOVA	{"email": "m.semenova.011978@postgrespro.ru", "phone": "+70179065659"}
0005432133029	95C55B	4789 633113	LARISA IVANOVA	{"email": "larisa.ivanova1968@postgrespro.ru", "phone": "+70169421536"}
0005432133030	95C55B	7813 880680	TATYANA VASILEVA	{"phone": "+70061247455"}
0005432133031	50F45B	9755 671265	KLAVDIYA SMIRNOVA	{"email": "klavdiya-smirnova_071972@postgrespro.ru", "phone": "+70393736554"}
0005432133032	50F45B	6396 716343	IRINA SAVELEVA	{"email": "saveleva_irina.24051990@postgrespro.ru", "phone": "+70466140216"}
0005432133033	CC46D9	3110 533934	IGOR KUZNECOV	{"email": "igorkuznecov_1970@postgrespro.ru", "phone": "+70557118546"}
0005432133034	CC46D9	4076 099150	TATYANA KOZLOVA	{"email": "t_kozlova_09071973@postgrespro.ru", "phone": "+70453943626"}
0005432133035	3A56E6	4464 154844	IRINA PETROVA	{"email": "irinapetrova1963@postgrespro.ru", "phone": "+70779645993"}
0005432133036	3A56E6	6489 148780	YULIYA NIKITINA	{"phone": "+70534994042"}
0005432133037	3A56E6	4280 197258	ILDAR KOZLOV	{"email": "kozlov_ildar-1978@postgrespro.ru", "phone": "+70281047275"}
0005432133038	41B64A	3743 852565	NINA ANISIMOVA	{"email": "anisimova.n_011964@postgrespro.ru", "phone": "+70414590274"}
0005432133039	7F02A6	1463 034304	YULIYA KUZNECOVA	{"phone": "+70157972092"}
0005432133040	C0E7F1	9348 193294	YULIYA OSIPOVA	{"email": "osipova_yuliya-1962@postgrespro.ru", "phone": "+70098097112"}
0005432133041	C0E7F1	9866 384562	NADIYA AFANASEVA	{"phone": "+70335978139"}
0005432133042	9A2D00	2417 112488	ALEKSANDR MAKAROV	{"phone": "+70644191753"}
0005432133043	9A2D00	6828 891317	PAVEL DENISOV	{"phone": "+70273564759"}
0005432133044	362A63	9304 390918	ANDREY ALEKSEEV	{"phone": "+70425806170"}
0005432133045	ECA615	5283 712061	DANIL ZHUKOV	{"email": "zhukov.danil-1974@postgrespro.ru", "phone": "+70476919399"}
0005432133046	46FC14	8414 662817	GENNADIY GAVRILOV	{"email": "gavrilov.g.03071965@postgrespro.ru", "phone": "+70110467661"}
0005432133047	8FCCDB	7191 612194	KLAVDIYA EFREMOVA	{"email": "efremovak-091984@postgrespro.ru", "phone": "+70806542219"}
0005432133048	380F36	1887 821766	OLEG SHEVCHENKO	{"phone": "+70984631391"}
0005432133049	ED1E08	7189 901293	VIKTOR FOMIN	{"email": "fomin-viktor.1977@postgrespro.ru", "phone": "+70785378333"}
0005432133050	A3599D	3728 275081	MIKHAIL NAZAROV	{"phone": "+70548866132"}
0005432133051	ADEAC5	3209 541216	ALEKSEY ALEKSANDROV	{"phone": "+70823631934"}
0005432133052	DD6E20	9370 403795	ANTONINA KARPOVA	{"phone": "+70089481022"}
0005432133053	7EB5B3	7432 145380	ALIYA PAVLOVA	{"email": "pavlova-aliya_121973@postgrespro.ru", "phone": "+70775857374"}
0005432133054	DF2891	2397 589894	GALINA TITOVA	{"email": "titovag061970@postgrespro.ru", "phone": "+70360336158"}
0005432133055	E7634D	8199 275296	VLADIMIR SMIRNOV	{"email": "smirnov_v_1984@postgrespro.ru", "phone": "+70415368747"}
0005432133056	E7634D	2164 356659	SVETLANA NESTEROVA	{"email": "nesterova.s1980@postgrespro.ru", "phone": "+70110761658"}
0005432133057	E71183	1268 521986	NATALYA SOROKINA	{"phone": "+70702214267"}
0005432133058	8AB989	4177 572540	SERGEY VASILEV	{"email": "s.vasilev1962@postgrespro.ru", "phone": "+70475037987"}
0005432133059	D59E88	8086 743689	PETR NAUMOV	{"email": "pnaumov_1975@postgrespro.ru", "phone": "+70711314746"}
0005432133060	AAAB7C	4937 234094	EVGENIY IVANOV	{"email": "ivanov_evgeniy-1976@postgrespro.ru", "phone": "+70810180170"}
0005432133061	2A22C5	2510 625895	ALEKSANDR BONDARENKO	{"phone": "+70816329572"}
0005432133062	05145A	7151 760107	MAKSIM NOVIKOV	{"email": "novikovmaksim.101974@postgrespro.ru", "phone": "+70790059206"}
0005432133063	F0575B	8831 102108	MIKHAIL POPOV	{"phone": "+70297655670"}
0005432133064	F0575B	7926 119678	ALEKSEY NAZAROV	{"email": "nazarov_aleksey_1967@postgrespro.ru", "phone": "+70565144030"}
0005432133065	2F8453	5167 566455	MIKHAIL ALEKSANDROV	{"phone": "+70640968976"}
0005432133066	681179	7061 960821	TATYANA ILINA	{"email": "ilina_t-101991@postgrespro.ru", "phone": "+70412800817"}
0005432133067	77DF2B	9484 085609	RUMIYA ANTONOVA	{"email": "antonovarumiya-02021971@postgrespro.ru", "phone": "+70007638630"}
0005432133068	5F6D88	3119 101640	SERGEY KAZAKOV	{"email": "kazakov-sergey-08011975@postgrespro.ru", "phone": "+70125881231"}
0005432133069	5F6D88	7666 680174	ANNA TROFIMOVA	{"email": "trofimova.anna.1974@postgrespro.ru", "phone": "+70735188689"}
0005432133070	5F6D88	0597 763458	TATYANA OSIPOVA	{"email": "osipova.tatyana.02051968@postgrespro.ru", "phone": "+70450706801"}
0005432133071	B59F3E	9273 846051	YULIYA TIKHONOVA	{"phone": "+70071061861"}
0005432133072	B59F3E	7760 777304	VLADIMIR FOMIN	{"phone": "+70678302932"}
0005432133073	615DEA	5982 774839	VYACHESLAV IVANOV	{"email": "ivanov-v071976@postgrespro.ru", "phone": "+70011047937"}
0005432133074	2D9E0E	7251 693350	NATALYA BORISOVA	{"email": "borisovan-1970@postgrespro.ru", "phone": "+70183473169"}
0005432133075	2D9E0E	3190 929430	LYUBOV DENISOVA	{"email": "denisova-l-071976@postgrespro.ru", "phone": "+70349669305"}
0005432133076	2D9E0E	7922 546219	TATYANA ANISIMOVA	{"email": "anisimova.tatyana.1974@postgrespro.ru", "phone": "+70467142853"}
0005432133077	F53B12	0218 543137	YURIY SCHERBAKOV	{"email": "yuriy-scherbakov-1978@postgrespro.ru", "phone": "+70228386826"}
0005432133078	135AA0	1168 107551	MARIYA KULIKOVA	{"phone": "+70310478439"}
0005432133079	CF0DCD	2661 886697	ZHANNA ZAYCEVA	{"phone": "+70203045463"}
0005432133080	CF0DCD	4305 579882	OLEG BORISOV	{"phone": "+70400286872"}
0005432133081	24D8DD	6900 084563	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr.011966@postgrespro.ru", "phone": "+70962611699"}
0005432133082	B80F0F	5449 617928	EKATERINA KRASNOVA	{"phone": "+70988058454"}
0005432133083	B80F0F	6549 894514	GALINA SOKOLOVA	{"email": "gsokolova101964@postgrespro.ru", "phone": "+70323589160"}
0005432133084	B80F0F	1593 844803	ANDREY FEDOROV	{"email": "andrey-fedorov.1961@postgrespro.ru", "phone": "+70657919912"}
0005432133085	BEF7B8	3256 722061	ANASTASIYA IVANOVA	{"phone": "+70067381485"}
0005432133086	BEF7B8	2777 215745	RAISA EFREMOVA	{"email": "efremova_raisa121973@postgrespro.ru", "phone": "+70441310512"}
0005432133087	7A8492	1181 458832	SERGEY KOZLOV	{"email": "sergey.kozlov1971@postgrespro.ru", "phone": "+70990871654"}
0005432133088	7A8492	3682 551323	LYUBOV SOLOVEVA	{"email": "l-soloveva.101970@postgrespro.ru", "phone": "+70278035004"}
0005432133089	7A8492	6066 781290	ELENA NAUMOVA	{"phone": "+70280314248"}
0005432133090	3F675B	9214 047532	ANDREY STEPANOV	{"phone": "+70248047699"}
0005432133091	58428B	5686 157223	ELENA KUZNECOVA	{"phone": "+70814037187"}
0005432133092	A34E6E	4218 597147	OLGA MIKHAYLOVA	{"phone": "+70484789779"}
0005432133093	E80D31	4961 561449	IGOR KUZMIN	{"phone": "+70645636632"}
0005432133094	DBCFFA	3516 205556	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-29111967@postgrespro.ru", "phone": "+70637298568"}
0005432133095	52BA87	5250 625561	EVGENIY PETROV	{"phone": "+70062305768"}
0005432133096	52BA87	5515 040753	LILIYA POPOVA	{"email": "l.popova_1968@postgrespro.ru", "phone": "+70310686484"}
0005432133097	4B9E96	6634 100448	NINA VOLKOVA	{"phone": "+70358789828"}
0005432133098	46B3CF	0246 771421	EDUARD KOZLOV	{"phone": "+70371600540"}
0005432133099	B8D761	0509 077853	EKATERINA FILATOVA	{"phone": "+70762481509"}
0005432133100	B8D761	7330 484079	RAISA FEDOROVA	{"phone": "+70068587548"}
0005432133101	065177	2797 921619	SVETLANA TARASOVA	{"phone": "+70647079669"}
0005432133102	BFCD93	1186 321791	EKATERINA LOGINOVA	{"email": "ekaterinaloginova_1974@postgrespro.ru", "phone": "+70385360267"}
0005432133103	BFCD93	7116 688567	ANATOLIY ROMANOV	{"phone": "+70202926295"}
0005432133104	05F8FB	3468 562822	MARINA PAVLOVA	{"email": "pavlova_m_051975@postgrespro.ru", "phone": "+70524696194"}
0005432133105	05F8FB	8744 025703	IRINA STEPANOVA	{"phone": "+70732256651"}
0005432133106	05F8FB	0167 518643	ELENA ROMANOVA	{"email": "romanova_elena1985@postgrespro.ru", "phone": "+70651434541"}
0005432133107	917841	3109 395899	NADEZHDA MAKSIMOVA	{"phone": "+70069852255"}
0005432133108	4F8088	1563 952290	SERGEY MEDVEDEV	{"email": "s.medvedev.071968@postgrespro.ru", "phone": "+70794150552"}
0005432133109	87606B	2080 130122	OLEG KUZMIN	{"phone": "+70742545731"}
0005432133110	87606B	7150 162725	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr_1973@postgrespro.ru", "phone": "+70309415310"}
0005432133111	1FACBC	0715 640465	ALEKSANDR ANDREEV	{"phone": "+70640834898"}
0005432133112	DCAA78	7024 043415	ALEKSANDR SIDOROV	{"phone": "+70376201137"}
0005432133113	FE69A4	4688 527781	RADMIR SIDOROV	{"phone": "+70318733536"}
0005432133114	F74DE7	0944 565387	ALEKSANDR NAUMOV	{"phone": "+70495453527"}
0005432133115	478F31	9118 782764	NIKITA GORBUNOV	{"phone": "+70085761081"}
0005432133116	F50669	9483 947923	KAMIL ALEKSANDROV	{"email": "k.aleksandrov1970@postgrespro.ru", "phone": "+70473405404"}
0005432133117	F50669	7459 290505	ALEKSANDR ALEKSEEV	{"phone": "+70995242703"}
0005432133175	2D3C82	9759 378956	NINA KOVALEVA	{"phone": "+70866078565"}
0005432133118	F50669	7196 533592	TATYANA BORISOVA	{"email": "borisova-t_101970@postgrespro.ru", "phone": "+70459094480"}
0005432133177	2D3C82	9683 524338	IGOR VOLKOV	{"phone": "+70466017152"}
0005432133119	34ADC0	7815 727566	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov_1978@postgrespro.ru", "phone": "+70056588545"}
0005432133120	219786	2407 637144	ALINA ABRAMOVA	{"email": "abramova_a101965@postgrespro.ru", "phone": "+70915899257"}
0005432133121	205446	1761 012130	ELENA YAKOVLEVA	{"phone": "+70239329596"}
0005432133122	205446	7914 622837	ELENA KULIKOVA	{"email": "kulikova.elena_031973@postgrespro.ru", "phone": "+70406746530"}
0005432133123	E3EAFE	5872 967391	VADIM KUZNECOV	{"phone": "+70500597902"}
0005432133124	E3EAFE	0026 945824	ANNA OVCHINNIKOVA	{"email": "ovchinnikovaanna-17121963@postgrespro.ru", "phone": "+70549196867"}
0005432133125	E3EAFE	5232 174639	IRINA KULIKOVA	{"email": "ikulikova.1968@postgrespro.ru", "phone": "+70215387279"}
0005432133126	51DA53	8473 221804	ANASTASIYA POPOVA	{"phone": "+70219590561"}
0005432133127	51DA53	2672 660033	EKATERINA SOKOLOVA	{"email": "sokolovae-21021971@postgrespro.ru", "phone": "+70267258305"}
0005432133128	D1A8A5	1113 431059	SVETLANA MAKAROVA	{"phone": "+70476112764"}
0005432133129	D1A8A5	4803 349359	VITALIY IVANOV	{"email": "vitaliy-ivanov_011974@postgrespro.ru", "phone": "+70746146946"}
0005432133130	27646B	8888 177129	EKATERINA LUKYANOVA	{"email": "e.lukyanova_1970@postgrespro.ru", "phone": "+70127748412"}
0005432133131	409F35	0725 874633	NATALIYA FILIPPOVA	{"phone": "+70399036862"}
0005432133132	409F35	6800 465442	EKATERINA MELNIKOVA	{"email": "melnikovae.1972@postgrespro.ru", "phone": "+70696380379"}
0005432133133	0A282C	3968 583333	IVAN KUDRYASHOV	{"phone": "+70678837810"}
0005432133134	E2018A	2853 713864	ALEKSANDR MIKHAYLOV	{"phone": "+70075580474"}
0005432133135	E2018A	7490 188083	IRINA DENISOVA	{"phone": "+70606683929"}
0005432133136	818256	8591 289786	RINAT MIKHAYLOV	{"email": "mikhaylovr14041973@postgrespro.ru", "phone": "+70450150975"}
0005432133137	C28260	4747 296220	EKATERINA MEDVEDEVA	{"phone": "+70126749329"}
0005432133138	9F0294	2902 523880	NATALYA KISELEVA	{"phone": "+70310880382"}
0005432133139	A7CD95	7685 419564	EKATERINA NESTEROVA	{"phone": "+70626961501"}
0005432133140	A7CD95	4666 012448	TATYANA KOZLOVA	{"phone": "+70530854022"}
0005432133141	E0066A	2435 396987	VLADIMIR KOROLEV	{"email": "vladimir_korolev.30111978@postgrespro.ru", "phone": "+70100979076"}
0005432133142	8401DA	7590 090191	ELENA FILIPPOVA	{"email": "elena_filippova081958@postgrespro.ru", "phone": "+70834850080"}
0005432133143	D22C7E	2330 396740	NIKOLAY VLASOV	{"email": "vlasov.n_1970@postgrespro.ru", "phone": "+70157595147"}
0005432133144	CF3D85	2960 377031	OLGA NIKOLAEVA	{"email": "olganikolaeva.031977@postgrespro.ru", "phone": "+70616937631"}
0005432133145	3DD65D	6083 662761	ALISA ZAKHAROVA	{"email": "zakharova-a-1975@postgrespro.ru", "phone": "+70422029087"}
0005432133146	9FBEC9	1270 336132	GALINA KRASNOVA	{"phone": "+70042348036"}
0005432133147	BD2B86	5571 779269	IGOR MIRONOV	{"phone": "+70483749551"}
0005432133148	FFF4D3	3893 551047	ANVAR MAKAROV	{"phone": "+70227790471"}
0005432133149	43252B	8556 834654	ELENA NOVIKOVA	{"email": "elena.novikova_021959@postgrespro.ru", "phone": "+70709696076"}
0005432133150	A777A2	4799 495738	VERA ISAEVA	{"email": "v-isaeva.071980@postgrespro.ru", "phone": "+70867112231"}
0005432133151	A777A2	3405 754513	NINA KISELEVA	{"phone": "+70891844414"}
0005432133152	787EA0	0869 991584	OLGA VOLKOVA	{"phone": "+70722766161"}
0005432133153	787EA0	5643 637531	VIKTOR ZAKHAROV	{"phone": "+70360281042"}
0005432133154	42FB94	3637 790982	ALEKSANDR VOLKOV	{"phone": "+70569109424"}
0005432133155	F23319	7322 930240	ROMAN ANDREEV	{"phone": "+70782657045"}
0005432133156	D7254C	5971 487335	DMITRIY MIKHAYLOV	{"phone": "+70578461502"}
0005432133157	A020DC	6618 032027	SVETLANA VASILEVA	{"email": "svetlana-vasileva061968@postgrespro.ru", "phone": "+70350550693"}
0005432133158	9D6670	3854 761570	TATYANA KOROLEVA	{"email": "koroleva.tatyana.091973@postgrespro.ru", "phone": "+70825480245"}
0005432133159	9D6670	3369 937983	VERA SERGEEVA	{"phone": "+70397464583"}
0005432133160	B2AA11	3484 782742	ELENA YAKOVLEVA	{"email": "elenayakovleva.111973@postgrespro.ru", "phone": "+70232724987"}
0005432133161	040411	3797 893118	VLADIMIR TARASOV	{"phone": "+70529955882"}
0005432133162	7AE1EC	9226 317781	EKATERINA ROMANOVA	{"email": "romanova_e071965@postgrespro.ru", "phone": "+70040136262"}
0005432133163	7AE1EC	6552 571008	ROMAN ZHURAVLEV	{"email": "rzhuravlev-03031976@postgrespro.ru", "phone": "+70575656846"}
0005432133164	7AE1EC	5728 921356	EKATERINA MELNIKOVA	{"phone": "+70995285622"}
0005432133165	91BE09	5016 013319	NADEZHDA AFANASEVA	{"phone": "+70882514600"}
0005432133166	1356E4	3450 122115	DARYA IVANOVA	{"email": "darya-ivanova-121970@postgrespro.ru", "phone": "+70051558313"}
0005432133167	1356E4	4577 918604	RAMILYA ERMAKOVA	{"phone": "+70592918947"}
0005432133168	2ACEC3	5002 076812	ANNA MIRONOVA	{"phone": "+70859339867"}
0005432133169	F7CF67	9357 280641	OLGA SCHERBAKOVA	{"phone": "+70816666583"}
0005432133170	5C7207	8941 150876	DENIS IVANOV	{"phone": "+70977098464"}
0005432133171	4CCFDF	2790 081856	VLADIMIR GERASIMOV	{"email": "gerasimov.v-081980@postgrespro.ru", "phone": "+70883022119"}
0005432133172	8CDE17	1705 874590	IGOR EGOROV	{"email": "igoregorov021974@postgrespro.ru", "phone": "+70195508135"}
0005432133173	8CDE17	4587 821737	ELENA GRISHINA	{"phone": "+70547761272"}
0005432133174	67F2EC	4998 060242	ELENA PETROVA	{"phone": "+70531884725"}
0005432133176	2D3C82	9738 617863	LIDIYA LAZAREVA	{"email": "lazarevalidiya22021975@postgrespro.ru", "phone": "+70158574572"}
0005432133178	0491F4	3617 278019	IGOR MOISEEV	{"phone": "+70083220528"}
0005432133179	3522BD	2039 731193	ELENA FADEEVA	{"email": "fadeeva.e_15011974@postgrespro.ru", "phone": "+70978105288"}
0005432133180	4F030D	7107 825152	DMITRIY FROLOV	{"email": "dmitriy.frolov-16021975@postgrespro.ru", "phone": "+70052682933"}
0005432133181	4F030D	0475 723075	EKATERINA SOLOVEVA	{"email": "e.soloveva.30101964@postgrespro.ru", "phone": "+70514611484"}
0005432133182	A560F5	9992 043743	NIKOLAY ANDREEV	{"email": "andreevnikolay_021981@postgrespro.ru", "phone": "+70337335850"}
0005432133183	A560F5	8388 544134	INNA KONOVALOVA	{"email": "konovalovainna01041971@postgrespro.ru", "phone": "+70496020389"}
0005432133184	AADEC2	1321 886370	NIKOLAY BARANOV	{"phone": "+70326777806"}
0005432133185	9E5A0B	0810 026918	SERGEY IVANOV	{"email": "ivanovsergey-1978@postgrespro.ru", "phone": "+70641141630"}
0005432133186	9E5A0B	7303 310420	ROMAN IVANOV	{"email": "ivanov_r_011975@postgrespro.ru", "phone": "+70711287195"}
0005432133187	4850F3	8532 954195	VIKTOR ANDREEV	{"email": "andreev_v1962@postgrespro.ru", "phone": "+70871604758"}
0005432133188	7C6929	2966 265620	VLADIMIR ISAEV	{"phone": "+70534667913"}
0005432133189	7C6929	9197 814650	MARIYA NIKIFOROVA	{"email": "nikiforova_m.1978@postgrespro.ru", "phone": "+70933385698"}
0005432133190	210CB4	5814 485065	DARYA SOROKINA	{"phone": "+70922010449"}
0005432133191	7816EA	7386 405550	RAISA NAUMOVA	{"phone": "+70376107333"}
0005432133192	68E56B	4960 694775	ELENA IVANOVA	{"email": "ivanovaelena_051964@postgrespro.ru", "phone": "+70059373891"}
0005432133193	68E56B	4437 690166	ANNA KULIKOVA	{"phone": "+70409567503"}
0005432133194	2A32FF	7912 678449	OLEG MELNIKOV	{"email": "melnikov-oleg-1967@postgrespro.ru", "phone": "+70314094777"}
0005432133195	0059D4	4585 682959	NATALYA NIKOLAEVA	{"phone": "+70293820562"}
0005432133196	24F5D9	1058 635276	SERGEY EGOROV	{"email": "egorov.s.28081970@postgrespro.ru", "phone": "+70223038538"}
0005432133197	80FFFE	6407 831889	SERGEY TIKHONOV	{"email": "sergey_tikhonov-1965@postgrespro.ru", "phone": "+70446955309"}
0005432133198	1A50F5	3299 557576	NIKITA FEDOTOV	{"phone": "+70454296327"}
0005432133199	005380	7990 937310	VERA PAVLOVA	{"phone": "+70284375380"}
0005432133200	506328	9714 182750	NATALYA DANILOVA	{"email": "danilova_natalya_01061974@postgrespro.ru", "phone": "+70171051991"}
0005432133201	506328	6116 228143	ELVIRA ZHUKOVA	{"email": "elvira-zhukova_1981@postgrespro.ru", "phone": "+70194855771"}
0005432133202	4A114D	2956 025608	ANDREY SAVELEV	{"email": "andrey.savelev_31051983@postgrespro.ru", "phone": "+70057324122"}
0005432133203	F44513	6511 573867	OLGA GORBUNOVA	{"email": "gorbunova-o021976@postgrespro.ru", "phone": "+70794809472"}
0005432133204	CC0E13	9251 151383	GALINA POTAPOVA	{"phone": "+70525417464"}
0005432133205	CC0E13	5074 709529	SVETLANA FEDOROVA	{"email": "svetlana.fedorova.081962@postgrespro.ru", "phone": "+70289949568"}
0005432133206	CC0E13	0090 714852	ANDREY TARASOV	{"email": "tarasov.a20041986@postgrespro.ru", "phone": "+70600758830"}
0005432133207	D9C078	5518 551647	IVAN VASILEV	{"phone": "+70769361825"}
0005432133208	D9C078	4051 219799	ANDREY EGOROV	{"email": "egorova-091980@postgrespro.ru", "phone": "+70149379979"}
0005432133209	B1B5A9	9484 925922	VLADIMIR DMITRIEV	{"email": "dmitrievvladimir_051974@postgrespro.ru", "phone": "+70377274637"}
0005432133210	8E51C3	2265 346861	MARINA EFREMOVA	{"email": "marinaefremova-12101978@postgrespro.ru", "phone": "+70397437535"}
0005432133211	205D68	3753 152226	VLADIMIR NAZAROV	{"email": "nazarov.vladimir28121974@postgrespro.ru", "phone": "+70507427426"}
0005432133212	ED728D	3291 148442	VLADIMIR IVANOV	{"phone": "+70289955307"}
0005432133213	ED728D	2091 761725	GALINA KAZAKOVA	{"email": "galinakazakova.101976@postgrespro.ru", "phone": "+70314152092"}
0005432133214	DA3B76	3662 911331	TATYANA NIKIFOROVA	{"email": "nikiforovat-07121968@postgrespro.ru", "phone": "+70769818913"}
0005432133215	9D16FA	1331 131735	VALENTINA NESTEROVA	{"email": "valentinanesterova-031979@postgrespro.ru", "phone": "+70996583852"}
0005432133216	9D16FA	3293 413539	ELENA SAVELEVA	{"email": "elena_saveleva.1976@postgrespro.ru", "phone": "+70046393654"}
0005432133217	EEFC5D	7680 797810	YULIYA ZOTOVA	{"email": "y_zotova13091994@postgrespro.ru", "phone": "+70663824154"}
0005432133218	EEFC5D	8690 668278	ALEKSANDR GRIGOREV	{"phone": "+70330103519"}
0005432133219	536EE2	4273 371971	IRINA MASLOVA	{"phone": "+70888088569"}
0005432133220	536EE2	3209 090594	VYACHESLAV ZAKHAROV	{"phone": "+70097991144"}
0005432133221	2DF50B	8183 279935	TATYANA MAKSIMOVA	{"phone": "+70629717039"}
0005432133222	3F1E38	9500 957661	TATYANA POLYAKOVA	{"phone": "+70863017826"}
0005432133223	3F1E38	0982 299413	GENNADIY ORLOV	{"email": "g.orlov-111970@postgrespro.ru", "phone": "+70961649239"}
0005432133224	3F1E38	1603 785648	ANASTASIYA EFIMOVA	{"email": "anastasiya_efimova-1976@postgrespro.ru", "phone": "+70508601768"}
0005432133225	BB3135	8841 846004	RUSLAN VOLKOV	{"email": "r_volkov.15061964@postgrespro.ru", "phone": "+70740769123"}
0005432133226	4468F1	3558 133099	IVAN SOKOLOV	{"phone": "+70979250507"}
0005432133227	4468F1	1321 624622	YULIYA FEDOROVA	{"phone": "+70966309582"}
0005432133228	D71F70	1795 080653	ALEKSEY AFANASEV	{"phone": "+70190662167"}
0005432133229	D71F70	4439 739994	ANDREY SIDOROV	{"email": "a-sidorov_1974@postgrespro.ru", "phone": "+70385606797"}
0005432133230	9D3D2D	4810 523031	SERGEY ZHUKOV	{"email": "zhukovs-021969@postgrespro.ru", "phone": "+70707215141"}
0005432133231	84C650	7241 859274	NIKITA KOROLEV	{"phone": "+70415892057"}
0005432133232	F7C4C5	0133 561110	ANNA NAZAROVA	{"email": "nazarova-anna_26091968@postgrespro.ru", "phone": "+70602588173"}
0005432133233	12C634	3524 920293	LIDIYA NAUMOVA	{"email": "naumova.lidiya-101972@postgrespro.ru", "phone": "+70752054677"}
0005432133234	12C634	7198 970954	RAFIK KOROLEV	{"email": "rafik-korolev1976@postgrespro.ru", "phone": "+70840366585"}
0005432133235	6126C8	9224 408123	VALENTIN KUDRYASHOV	{"email": "v-kudryashov.30071958@postgrespro.ru", "phone": "+70784594844"}
0005432133236	6126C8	0254 600833	YULIYA RYABOVA	{"email": "ryabovayuliya_031969@postgrespro.ru", "phone": "+70441032710"}
0005432133237	39A724	9012 903193	IRINA MIRONOVA	{"email": "mironovairina.18041968@postgrespro.ru", "phone": "+70505965798"}
0005432133238	000E07	6202 371240	ELVIRA TITOVA	{"phone": "+70280851615"}
0005432133239	000E07	7552 545458	OLGA EFIMOVA	{"phone": "+70058859613"}
0005432133240	000E07	4079 666069	ANNA ZHURAVLEVA	{"phone": "+70863081728"}
0005432133241	539E4F	6076 729226	NINA NOVIKOVA	{"phone": "+70503903613"}
0005432133242	59B1FD	0288 764369	SVETLANA KUZMINA	{"email": "skuzmina.1963@postgrespro.ru", "phone": "+70355731448"}
0005432133243	59B1FD	8623 003701	VALENTINA MELNIKOVA	{"phone": "+70984600084"}
0005432133244	59B1FD	1605 457249	RAFAEL KUZNECOV	{"email": "r-kuznecov-031977@postgrespro.ru", "phone": "+70334468701"}
0005432133245	1C7CC1	0091 705670	GRIGORIY GUSEV	{"phone": "+70144609214"}
0005432133246	CA184A	6031 508457	GULIYA CHERNOVA	{"phone": "+70556685124"}
0005432133247	CA184A	8965 712354	PAVEL KUZNECOV	{"phone": "+70468545302"}
0005432133248	CA184A	7077 095235	ALEKSEY VOROBEV	{"email": "aleksey-vorobev_1977@postgrespro.ru", "phone": "+70521725493"}
0005432133249	1F5A5D	1260 454621	LYUBOV PAVLOVA	{"phone": "+70529047148"}
0005432133250	3A17F6	5315 578791	ZINAIDA GERASIMOVA	{"phone": "+70754266599"}
0005432133251	CCFCC2	8683 125161	EKATERINA BARANOVA	{"email": "baranova.ekaterina19031973@postgrespro.ru", "phone": "+70941904701"}
0005432133252	CCFCC2	7888 512073	ELENA MAKSIMOVA	{"email": "maksimova-e25011960@postgrespro.ru", "phone": "+70439144900"}
0005432133253	E486FF	0526 632667	PETR KUZNECOV	{"email": "petr-kuznecov_121970@postgrespro.ru", "phone": "+70060237236"}
0005432133254	E486FF	0457 324422	VENERA BELOVA	{"email": "venera-belova041975@postgrespro.ru", "phone": "+70248310241"}
0005432133255	0E0FCE	2964 443258	NATALYA ISAEVA	{"phone": "+70398691449"}
0005432133256	56156E	4342 824326	DIANA ABRAMOVA	{"phone": "+70496845757"}
0005432133257	56156E	4920 707935	EKATERINA ABRAMOVA	{"phone": "+70220245375"}
0005432133258	DF157C	0049 141018	SERGEY SERGEEV	{"phone": "+70631784620"}
0005432133259	79B76F	5497 128664	NIKOLAY VOLKOV	{"email": "nikolay.volkov-1968@postgrespro.ru", "phone": "+70400812974"}
0005432133260	79B76F	1205 922819	ELENA KUZNECOVA	{"email": "kuznecova_e.121964@postgrespro.ru", "phone": "+70154932910"}
0005432133261	30C671	7271 211967	ALEKSANDR STEPANOV	{"email": "astepanov-1969@postgrespro.ru", "phone": "+70663103690"}
0005432133262	30C671	6085 161890	EKATERINA POTAPOVA	{"email": "potapova_e1972@postgrespro.ru", "phone": "+70046351843"}
0005432133263	E8A796	9474 903055	VLADIMIR FROLOV	{"email": "frolov_v-031982@postgrespro.ru", "phone": "+70174221565"}
0005432133264	16C20A	9212 473919	IVAN GORBUNOV	{"email": "igorbunov091987@postgrespro.ru", "phone": "+70864511760"}
0005432133265	16C20A	6044 308759	VIKTOR FOMIN	{"email": "v.fomin1975@postgrespro.ru", "phone": "+70366944166"}
0005432133266	37CDD8	8846 218145	LYUDMILA KRASNOVA	{"email": "krasnova-l-081978@postgrespro.ru", "phone": "+70294114094"}
0005432133267	2137E9	1562 505643	MATVEY BELOV	{"email": "belov-matvey_041977@postgrespro.ru", "phone": "+70904239526"}
0005432133268	965A9F	7839 792000	IRINA KISELEVA	{"phone": "+70909430246"}
0005432133269	9A112D	1880 874180	RASIM VOROBEV	{"email": "vorobev-r_05121964@postgrespro.ru", "phone": "+70153508987"}
0005432133270	9A112D	4171 949097	TATYANA SOROKINA	{"email": "t_sorokina-1967@postgrespro.ru", "phone": "+70476334898"}
0005432133271	E742BE	6060 370901	ARTEM KONOVALOV	{"phone": "+70183975446"}
0005432133272	E742BE	8287 059206	YULIYA KOROLEVA	{"phone": "+70429776163"}
0005432133273	B26C9F	9452 000875	GALINA MELNIKOVA	{"phone": "+70752826496"}
0005432133274	B26C9F	8818 795387	MARIYA PAVLOVA	{"email": "pavlova.mariya_1974@postgrespro.ru", "phone": "+70778568434"}
0005432133275	6EC1FE	9902 566203	IVAN STEPANOV	{"phone": "+70381921869"}
0005432133276	E57688	5811 733565	EKATERINA AFANASEVA	{"phone": "+70326845093"}
0005432133277	E57688	9259 262636	MARINA GERASIMOVA	{"email": "marina-gerasimova-1973@postgrespro.ru", "phone": "+70030642940"}
0005432133278	2CE794	5134 519606	PAVEL MARTYNOV	{"phone": "+70193902977"}
0005432133279	666E08	8693 265419	NINA DENISOVA	{"phone": "+70965941045"}
0005432133280	D9AD20	0489 998052	ANTON ZHURAVLEV	{"phone": "+70739876092"}
0005432133281	57FA4D	1243 457093	GENNADIY ANDREEV	{"phone": "+70944177574"}
0005432133282	57FA4D	5256 341395	MARIYA ALEKSANDROVA	{"phone": "+70714516771"}
0005432133283	71C773	9620 999638	SERGEY IVANOV	{"email": "sergeyivanov101961@postgrespro.ru", "phone": "+70538925715"}
0005432133284	84AA66	4162 105194	OLGA POLYAKOVA	{"email": "polyakova.olga-16101967@postgrespro.ru", "phone": "+70988621126"}
0005432133285	84AA66	6552 318150	OLGA ANDREEVA	{"email": "olgaandreeva.1970@postgrespro.ru", "phone": "+70353687368"}
0005432133286	D6D8DB	9423 689583	EKATERINA EFIMOVA	{"phone": "+70274751506"}
0005432133287	F8FDC2	4871 957821	TAMARA CHERNOVA	{"phone": "+70565642625"}
0005432133288	60A4B5	3651 427707	ALEKSANDR FROLOV	{"email": "frolov.aleksandr_021967@postgrespro.ru", "phone": "+70138058166"}
0005432133289	A48FAD	7316 543590	MIKHAIL MIRONOV	{"phone": "+70148409212"}
0005432133530	A0229B	3691 470295	NATALYA ARKHIPOVA	{"phone": "+70734190024"}
0005432133290	BC818B	3810 847836	VLADIMIR KARPOV	{"email": "vladimir-karpov.031960@postgrespro.ru", "phone": "+70080365707"}
0005432133291	037FDC	7890 161557	ALEKSEY STEPANOV	{"phone": "+70320696874"}
0005432133292	AB6190	0568 924340	NADEZHDA IVANOVA	{"phone": "+70885092275"}
0005432133293	AB6190	9352 381575	ANNA PETROVA	{"phone": "+70298907264"}
0005432133294	52BEDF	1510 524666	SVETLANA NIKOLAEVA	{"email": "nikolaeva_svetlana-021983@postgrespro.ru", "phone": "+70235103125"}
0005432133295	18104E	1777 638137	VERA PETROVA	{"email": "petrova-vera.1970@postgrespro.ru", "phone": "+70349026362"}
0005432133296	494CF6	8787 313191	ZINAIDA KISELEVA	{"email": "z.kiseleva011977@postgrespro.ru", "phone": "+70164038730"}
0005432133297	B986E0	6044 074921	NADEZHDA BORISOVA	{"phone": "+70897856481"}
0005432133298	B986E0	8393 014621	YULIYA NESTEROVA	{"phone": "+70674595323"}
0005432133299	9D26AE	3962 382973	TAISIYA MIRONOVA	{"email": "taisiyamironova_10121980@postgrespro.ru", "phone": "+70955766965"}
0005432133300	876F32	5377 371226	PAVEL DAVYDOV	{"phone": "+70013279647"}
0005432133301	876F32	2335 812282	LYUDMILA MASLOVA	{"email": "maslova.lyudmila081976@postgrespro.ru", "phone": "+70787649005"}
0005432133302	D70F19	2333 912178	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr1975@postgrespro.ru", "phone": "+70326525901"}
0005432133303	40EBB9	1886 630447	KLAVDIYA GORBUNOVA	{"phone": "+70399107122"}
0005432133304	40EBB9	4348 928303	GALINA DMITRIEVA	{"phone": "+70991594864"}
0005432133305	602632	9219 617886	NURIYA VOLKOVA	{"email": "nuriya-volkova-031967@postgrespro.ru", "phone": "+70312899438"}
0005432133306	F35A13	9096 813003	MAKAR DENISOV	{"email": "denisov_m1964@postgrespro.ru", "phone": "+70335077482"}
0005432133307	B717D6	2090 595727	ROMAN POPOV	{"phone": "+70675042087"}
0005432133308	B717D6	9977 420666	OLGA SOROKINA	{"email": "sorokina_olga121963@postgrespro.ru", "phone": "+70431403814"}
0005432133309	6AE768	4221 024380	KLAVDIYA NAZAROVA	{"email": "k-nazarova_121966@postgrespro.ru", "phone": "+70129174624"}
0005432133310	EFE3B5	0031 272735	SERGEY MAKAROV	{"email": "makarov.s111974@postgrespro.ru", "phone": "+70272435479"}
0005432133311	39B187	6825 730983	VALERIY SEMENOV	{"phone": "+70305048600"}
0005432133312	C083DA	6380 199651	YULIYA NOVIKOVA	{"email": "novikova_y1977@postgrespro.ru", "phone": "+70521186253"}
0005432133313	7874E0	1263 300560	ALEKSANDRA MIRONOVA	{"email": "a-mironova_1973@postgrespro.ru", "phone": "+70512563433"}
0005432133314	FA1C8D	8673 673365	ELENA SMIRNOVA	{"phone": "+70034207001"}
0005432133315	6E2F87	3417 301448	TATYANA NIKITINA	{"email": "tnikitina_1978@postgrespro.ru", "phone": "+70847995929"}
0005432133316	0A6D5F	6665 527684	ALBINA ANDREEVA	{"phone": "+70774838831"}
0005432133317	F39E74	1542 044986	SVETLANA MARTYNOVA	{"phone": "+70368025803"}
0005432133318	A7FA04	1712 888743	ALI KISELEV	{"email": "kiselev.ali.19041981@postgrespro.ru", "phone": "+70763273759"}
0005432133319	A7FA04	6040 329754	ALEKSEY PETROV	{"phone": "+70148864404"}
0005432133320	9D9631	4502 900829	KARINA MAKSIMOVA	{"phone": "+70689979478"}
0005432133321	AD71FD	5288 964403	RINAT BARANOV	{"phone": "+70274331637"}
0005432133322	DAC2F7	7194 885537	EKATERINA EGOROVA	{"phone": "+70286321637"}
0005432133323	AEB0C1	8566 106906	ELENA KUZNECOVA	{"phone": "+70343339792"}
0005432133324	AEB0C1	2941 137975	MARIYA DENISOVA	{"email": "mariya_denisova_21111973@postgrespro.ru", "phone": "+70991783198"}
0005432133325	D5C124	7096 889738	VSEVOLOD ZAKHAROV	{"phone": "+70933662784"}
0005432133326	DE032F	9270 241594	ANDREY ILIN	{"email": "ilin-a_15051973@postgrespro.ru", "phone": "+70696101992"}
0005432133327	C6DC1B	2664 945514	ANATOLIY VOROBEV	{"phone": "+70110715386"}
0005432133328	6BAF40	7313 178446	NIKOLAY KOROLEV	{"email": "n_korolev1968@postgrespro.ru", "phone": "+70853166913"}
0005432133329	6BAF40	9688 895620	YULIYA ZAKHAROVA	{"email": "y-zakharova-15121977@postgrespro.ru", "phone": "+70826369655"}
0005432133330	6BAF40	1053 406001	VALENTINA ANDREEVA	{"email": "andreeva.v111974@postgrespro.ru", "phone": "+70307652011"}
0005432133331	167D7D	6471 789939	EVGENIY ANDREEV	{"email": "andreev_e1973@postgrespro.ru", "phone": "+70884297344"}
0005432133332	A85D00	8004 930246	EVGENIY NIKOLAEV	{"phone": "+70315612990"}
0005432133333	A16DDB	8421 778490	VALENTINA GAVRILOVA	{"email": "valentina_gavrilova051976@postgrespro.ru", "phone": "+70047163519"}
0005432133334	A16DDB	5952 641500	GYUZEL KUZNECOVA	{"email": "kuznecovagyuzel-24041963@postgrespro.ru", "phone": "+70737841418"}
0005432133335	A16DDB	1336 469719	ANNA KAZAKOVA	{"email": "annakazakova-20081966@postgrespro.ru", "phone": "+70625831380"}
0005432133336	0DA75F	9050 611417	LYUDMILA POLYAKOVA	{"email": "l.polyakova_1980@postgrespro.ru", "phone": "+70012908369"}
0005432133337	0DA75F	6478 209486	KSENIYA PAVLOVA	{"email": "pavlovak-041971@postgrespro.ru", "phone": "+70079231060"}
0005432133338	2C7706	6328 517268	ANDREY ALEKSEEV	{"email": "alekseev-a-1966@postgrespro.ru", "phone": "+70747060957"}
0005432133339	B5D22E	2429 320414	LYUBOV KALININA	{"phone": "+70410076403"}
0005432133340	4CB978	8519 502155	FARID KONOVALOV	{"phone": "+70643643206"}
0005432133341	8D0D8A	3656 738785	MARK SEMENOV	{"phone": "+70734446704"}
0005432133342	8D0D8A	6053 300452	ELIZAVETA SOKOLOVA	{"email": "elizavetasokolova-1975@postgrespro.ru", "phone": "+70055916614"}
0005432133343	DE00E7	8037 848442	LIDIYA SIDOROVA	{"email": "sidorova-l.1982@postgrespro.ru", "phone": "+70197022949"}
0005432133344	E358EE	3780 766774	VASILIY KOZLOV	{"email": "kozlovvasiliy-061977@postgrespro.ru", "phone": "+70163207966"}
0005432133345	ABD204	9533 282543	DMITRIY GAVRILOV	{"email": "dgavrilov_1979@postgrespro.ru", "phone": "+70478117891"}
0005432133346	16D6EA	6783 561259	KRISTINA KOROLEVA	{"email": "k-koroleva-041969@postgrespro.ru", "phone": "+70182982510"}
0005432133347	16D6EA	5898 483151	LIDIYA VOLKOVA	{"phone": "+70527903399"}
0005432133348	2D666C	1143 104383	VIKTOR MARTYNOV	{"phone": "+70700703729"}
0005432133349	890507	7002 092765	PETR VASILEV	{"phone": "+70574498774"}
0005432133350	8821CE	3285 657147	VLADISLAV VASILEV	{"email": "vasilev-v_041969@postgrespro.ru", "phone": "+70587674084"}
0005432133351	8821CE	2501 528937	NATALYA ANISIMOVA	{"phone": "+70682977762"}
0005432133352	056C84	5816 237289	ALEKSANDR ABRAMOV	{"email": "a-abramov-1975@postgrespro.ru", "phone": "+70443385490"}
0005432133353	056C84	3909 739870	NATALYA ANDREEVA	{"phone": "+70344009588"}
0005432133354	BC1FAB	1780 320312	VALENTINA KUZNECOVA	{"email": "valentina.kuznecova.10111957@postgrespro.ru", "phone": "+70354409103"}
0005432133355	64685A	4579 360467	VIKTOR KISELEV	{"email": "v-kiselev.1975@postgrespro.ru", "phone": "+70308191401"}
0005432133356	C4598E	2844 994640	ALEKSEY VASILEV	{"phone": "+70810795902"}
0005432133357	917500	9174 987065	YULIYA DMITRIEVA	{"email": "dmitrieva_yuliya-28071978@postgrespro.ru", "phone": "+70166174361"}
0005432133358	1834EE	4885 654607	VIKTOR SMIRNOV	{"phone": "+70573628244"}
0005432133359	DE830E	3826 311876	ELENA DANILOVA	{"phone": "+70693864611"}
0005432133360	DE830E	9918 818852	IRINA KULIKOVA	{"phone": "+70013067390"}
0005432133361	DE830E	1176 628100	NINA SMIRNOVA	{"phone": "+70130471024"}
0005432133362	6780EB	4196 356943	GEORGIY TIMOFEEV	{"email": "georgiy-timofeev011969@postgrespro.ru", "phone": "+70977709854"}
0005432133363	1CC7F2	2218 822313	ALEKSANDR IVANOV	{"email": "ivanov_a08031966@postgrespro.ru", "phone": "+70355416152"}
0005432133364	A560B4	8776 576626	SVETLANA TIMOFEEVA	{"phone": "+70847897840"}
0005432133365	50B9D5	7321 383647	YULIANA KUZMINA	{"email": "y-kuzmina.111975@postgrespro.ru", "phone": "+70408296303"}
0005432133366	50B9D5	4172 770134	NATALYA MELNIKOVA	{"phone": "+70989712847"}
0005432133367	50B9D5	6705 444667	VIKTOR ABRAMOV	{"email": "viktorabramov_091966@postgrespro.ru", "phone": "+70612380532"}
0005432133368	646CB8	3772 893741	ANNA KUZNECOVA	{"email": "kuznecova-anna-1961@postgrespro.ru", "phone": "+70124889537"}
0005432133369	FFAFA8	9936 054612	ANDREY NOVIKOV	{"email": "novikov.a_26091966@postgrespro.ru", "phone": "+70082309571"}
0005432133370	665DE0	5545 866412	SERGEY SCHERBAKOV	{"phone": "+70489542238"}
0005432133371	50F8E4	9674 046508	ANTON OSIPOV	{"email": "osipov.anton1970@postgrespro.ru", "phone": "+70490050484"}
0005432133372	50F8E4	2855 982922	SERGEY ANDREEV	{"phone": "+70117733103"}
0005432133373	F3511E	2816 616942	VERA KOZLOVA	{"email": "kozlovavera-16091979@postgrespro.ru", "phone": "+70616954590"}
0005432133374	DF3B78	4209 537842	NIKOLAY NIKOLAEV	{"email": "nikolaev_nikolay1970@postgrespro.ru", "phone": "+70916344193"}
0005432133375	3B2B7F	5993 923447	VYACHESLAV POPOV	{"phone": "+70649131943"}
0005432133376	CFA37B	2580 899346	LILIYA NOVIKOVA	{"email": "liliya_novikova.101976@postgrespro.ru", "phone": "+70084683267"}
0005432133377	E142A1	5784 543351	GALINA ISAEVA	{"phone": "+70634970165"}
0005432133378	E142A1	5283 933772	ZLATA TIKHONOVA	{"phone": "+70312582850"}
0005432133379	D90F9B	0618 226684	ROZA PAVLOVA	{"phone": "+70644022065"}
0005432133380	D90F9B	4335 679394	NATALYA MAKAROVA	{"email": "makarova.n.27081979@postgrespro.ru", "phone": "+70543464336"}
0005432133381	E0B156	6172 386693	YURIY SOROKIN	{"phone": "+70187080380"}
0005432133382	FE7A0F	5042 612588	ANNA SCHERBAKOVA	{"phone": "+70560297207"}
0005432133383	731C20	5742 841995	OLGA EGOROVA	{"email": "egorova-o-09091962@postgrespro.ru", "phone": "+70984040671"}
0005432133384	ACBF45	2137 058781	EMMA MARTYNOVA	{"email": "e.martynova1968@postgrespro.ru", "phone": "+70894950129"}
0005432133385	C23011	5977 800363	GYUZEL LAZAREVA	{"email": "gyuzel-lazareva1969@postgrespro.ru", "phone": "+70229876788"}
0005432133386	C23011	2974 825426	PRASKOVYA SOLOVEVA	{"email": "solovevapraskovya.31011973@postgrespro.ru", "phone": "+70792498387"}
0005432133387	A5DA95	5856 573068	ARTEM KOZLOV	{"phone": "+70748458467"}
0005432133388	30518E	9503 159294	ALEKSANDR POPOV	{"email": "popov_a_021971@postgrespro.ru", "phone": "+70922814800"}
0005432133389	25972E	0368 754065	DANIIL MAKSIMOV	{"email": "maksimov-d_071968@postgrespro.ru", "phone": "+70908921526"}
0005432133390	25972E	6286 628699	NINA DMITRIEVA	{"email": "nina-dmitrieva.031973@postgrespro.ru", "phone": "+70554230314"}
0005432133391	97CAA9	0139 182720	SERGEY BONDARENKO	{"email": "bondarenkos-1950@postgrespro.ru", "phone": "+70147145378"}
0005432133392	65592D	4397 411941	GALINA TITOVA	{"email": "g_titova27071971@postgrespro.ru", "phone": "+70781704482"}
0005432133393	65592D	8220 738961	BORIS FROLOV	{"email": "frolov.boris.071981@postgrespro.ru", "phone": "+70271153428"}
0005432133394	65592D	8893 715551	PETR CHERNOV	{"phone": "+70915930132"}
0005432133395	51D2C8	1764 564578	LYUBOV NIKITINA	{"email": "l_nikitina.121969@postgrespro.ru", "phone": "+70003309130"}
0005432133396	51D2C8	3267 241392	VALENTINA FEDOROVA	{"email": "fedorova.valentina30101964@postgrespro.ru", "phone": "+70498839281"}
0005432133397	B3CE3D	1187 194745	MARIYA SIDOROVA	{"email": "sidorovam-1972@postgrespro.ru", "phone": "+70767746848"}
0005432133398	B3CE3D	6287 565690	RUSLAN TARASOV	{"phone": "+70524404342"}
0005432133399	AEDCAA	0274 449911	NIKOLAY CHERNOV	{"phone": "+70015751271"}
0005432133400	AEDCAA	1494 766941	ALEKSEY OSIPOV	{"email": "aleksey.osipov021971@postgrespro.ru", "phone": "+70536540283"}
0005432133401	12B17D	5359 463383	TIMOFEY PETROV	{"phone": "+70989848562"}
0005432133402	12B17D	7710 426824	IRINA ZHURAVLEVA	{"email": "i_zhuravleva1961@postgrespro.ru", "phone": "+70770725918"}
0005432133403	B97A91	9962 108359	KSENIYA KUZNECOVA	{"email": "kuznecova-k.09071983@postgrespro.ru", "phone": "+70239651938"}
0005432133404	CA0B9C	1728 397705	ALEKSANDRA SMIRNOVA	{"email": "smirnova_aleksandra_061974@postgrespro.ru", "phone": "+70170432171"}
0005432133405	22E1B1	9465 717980	YURIY VASILEV	{"phone": "+70774604145"}
0005432133406	27E8D9	0018 966456	LYUBOV ERMAKOVA	{"phone": "+70863859617"}
0005432133407	27E8D9	2062 649606	ALEKSANDR ALEKSEEV	{"phone": "+70287018650"}
0005432133408	C22E32	0887 555722	DMITRIY FROLOV	{"phone": "+70604104650"}
0005432133409	C22E32	8787 286803	TATYANA MIRONOVA	{"phone": "+70288196051"}
0005432133410	045FB8	6571 674183	ARTEM KUZNECOV	{"email": "a.kuznecov011969@postgrespro.ru", "phone": "+70465208736"}
0005432133411	732D3F	9045 941200	RUSTAM SEMENOV	{"phone": "+70685820121"}
0005432133412	860D0D	5475 071998	TAMARA YAKOVLEVA	{"email": "yakovleva.tamara_051967@postgrespro.ru", "phone": "+70148129914"}
0005432133413	860D0D	7774 423412	FEDOR ROMANOV	{"phone": "+70860403115"}
0005432133414	49E27B	2756 570043	MIKHAIL MOISEEV	{"email": "moiseevmikhail08101969@postgrespro.ru", "phone": "+70218372271"}
0005432133415	49E27B	9811 260971	LYUDMILA IVANOVA	{"phone": "+70532924448"}
0005432133416	8D9F9D	6596 176182	MARINA SIDOROVA	{"phone": "+70508690585"}
0005432133417	8D9F9D	6723 185771	TATYANA KUZNECOVA	{"phone": "+70257734114"}
0005432133418	10E77D	0055 928854	VLADIMIR VOLKOV	{"email": "vvolkov-01011980@postgrespro.ru", "phone": "+70943240240"}
0005432133419	3EC7EE	8521 143045	ALEKSANDR BELOV	{"phone": "+70996331223"}
0005432133420	476896	7516 449670	EKATERINA SOROKINA	{"email": "sorokina-ekaterina_1983@postgrespro.ru", "phone": "+70509413025"}
0005432133421	211CA7	9187 318131	MAKSIM FROLOV	{"phone": "+70636117214"}
0005432133422	B6F194	8605 178053	LARISA FILIPPOVA	{"email": "filippova.larisa.041981@postgrespro.ru", "phone": "+70780453619"}
0005432133423	31C3B8	9815 663760	ARTEM VLASOV	{"phone": "+70858789334"}
0005432133424	B8AD2C	9271 542588	EVGENIY FEDOROV	{"phone": "+70379140880"}
0005432133425	B8AD2C	1863 192241	OKSANA TARASOVA	{"phone": "+70726945847"}
0005432133426	86AD26	5107 677815	SERGEY FROLOV	{"phone": "+70696935134"}
0005432133427	86AD26	7362 190524	ANDREY ZAKHAROV	{"email": "zakharovandrey-19081971@postgrespro.ru", "phone": "+70269488822"}
0005432133428	C61BCC	3813 971588	VIKTOR IVANOV	{"email": "v-ivanov_041981@postgrespro.ru", "phone": "+70418296409"}
0005432133429	8262B0	8267 276524	MIKHAIL FROLOV	{"phone": "+70781946331"}
0005432133430	8262B0	9400 954576	ANTONINA GORBUNOVA	{"phone": "+70967398427"}
0005432133431	10E7F7	8729 136051	NADEZHDA SAVELEVA	{"email": "saveleva.n_25041972@postgrespro.ru", "phone": "+70798048316"}
0005432133432	F8EDC4	1291 663858	LYUBOV KALININA	{"email": "lyubov_kalinina30061973@postgrespro.ru", "phone": "+70507648049"}
0005432133433	7FBA06	5097 136975	KLIM MOROZOV	{"email": "k-morozov1964@postgrespro.ru", "phone": "+70267923780"}
0005432133434	F68EA0	5256 586820	DAVID MAKAROV	{"phone": "+70591573950"}
0005432133435	F68EA0	1967 176069	VALENTINA LAZAREVA	{"email": "lazareva_valentina_10061972@postgrespro.ru", "phone": "+70476440519"}
0005432133436	54AF14	5820 768342	VADIM NOVIKOV	{"phone": "+70909618483"}
0005432133437	54AF14	1732 656941	NINA MAKSIMOVA	{"email": "maksimovan1970@postgrespro.ru", "phone": "+70466581410"}
0005432133438	816EC8	6435 928567	ALEKSEY BARANOV	{"email": "baranov_a.101971@postgrespro.ru", "phone": "+70373706942"}
0005432133439	0198F4	6282 514761	ANTON IVANOV	{"phone": "+70346300181"}
0005432133440	F43BEE	8276 744034	RIMMA MASLOVA	{"phone": "+70980540887"}
0005432133441	423FF8	8865 098226	LYUDMILA RYABOVA	{"phone": "+70637548196"}
0005432133442	CD982A	9171 651301	YULIYA VLASOVA	{"phone": "+70027289780"}
0005432133443	CD982A	5258 460738	OLEG MELNIKOV	{"phone": "+70633283597"}
0005432133444	51BC1F	6870 133147	NADEZHDA POPOVA	{"email": "nadezhda.popova_1967@postgrespro.ru", "phone": "+70240683270"}
0005432133445	5325AC	3572 559057	YURIY KUZNECOV	{"phone": "+70986942275"}
0005432133446	01D024	0791 959809	MIKHAIL STEPANOV	{"email": "mikhail_stepanov.021969@postgrespro.ru", "phone": "+70026350047"}
0005432133447	F0D654	7446 930368	IRINA VOROBEVA	{"phone": "+70373571511"}
0005432133448	A61ABA	8030 838340	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov.19071976@postgrespro.ru", "phone": "+70205764453"}
0005432133449	A61ABA	8588 409164	SVETLANA KAZAKOVA	{"email": "kazakova_s-23121973@postgrespro.ru", "phone": "+70028897505"}
0005432133450	A61ABA	0693 411828	ARTUR SOKOLOV	{"phone": "+70602728925"}
0005432133451	F398E6	8620 938614	EVGENIY ROMANOV	{"email": "evgeniy-romanov1965@postgrespro.ru", "phone": "+70566450753"}
0005432133452	AC74A3	9420 693610	SVETLANA KONOVALOVA	{"phone": "+70860202656"}
0005432133453	65E145	8889 305151	EKATERINA KUZMINA	{"email": "kuzminaekaterina071982@postgrespro.ru", "phone": "+70472291997"}
0005432133454	3C7352	1443 287786	SAVELIY SEMENOV	{"phone": "+70138204829"}
0005432133455	3C7352	1440 007552	YURIY VASILEV	{"email": "yvasilev-111969@postgrespro.ru", "phone": "+70648990433"}
0005432133456	FAFF36	1727 236953	VLADIMIR NOVIKOV	{"phone": "+70465562424"}
0005432133457	98B16F	8111 482531	ANGELINA STEPANOVA	{"phone": "+70925967834"}
0005432133458	583E79	6164 995764	VLADIMIR VLASOV	{"phone": "+70366551270"}
0005432133459	040951	7336 351238	SEMEN MATVEEV	{"phone": "+70175283133"}
0005432133460	040951	9531 614899	SVETLANA KOROLEVA	{"email": "koroleva-svetlana_1966@postgrespro.ru", "phone": "+70806262506"}
0005432133461	A457DE	4514 895857	LILIYA GUSEVA	{"email": "guseval_23021977@postgrespro.ru", "phone": "+70717447375"}
0005432133462	EF8F13	8795 571928	DENIS MAKAROV	{"email": "makarov-denis18111973@postgrespro.ru", "phone": "+70303692712"}
0005432133463	EF8F13	1379 146036	LYUBOV SOLOVEVA	{"email": "lsoloveva-081976@postgrespro.ru", "phone": "+70228059646"}
0005432133464	AB76FE	9669 634125	DANIIL MIKHAYLOV	{"email": "mikhaylov_d111973@postgrespro.ru", "phone": "+70754098460"}
0005432133465	AB76FE	6734 582008	NINA VASILEVA	{"phone": "+70446752315"}
0005432133466	E781E0	3896 107288	TATYANA RYABOVA	{"email": "ryabova-t01111971@postgrespro.ru", "phone": "+70214060152"}
0005432133467	E781E0	5884 863970	VIKTOR ALEKSANDROV	{"phone": "+70664958039"}
0005432133468	E781E0	2395 686479	VADIM PETROV	{"email": "petrov.v-02011976@postgrespro.ru", "phone": "+70445884042"}
0005432133469	5F8C6B	1500 353469	IVAN FEDOROV	{"phone": "+70363204997"}
0005432133470	F3A014	1874 909441	NATALYA MAKAROVA	{"phone": "+70282700446"}
0005432133588	1A81FB	8747 180613	ANDREY SMIRNOV	{"phone": "+70204901768"}
0005432133471	242948	9454 550095	IGOR SOLOVEV	{"email": "solovev_i_1980@postgrespro.ru", "phone": "+70566090240"}
0005432133472	242948	2493 042820	ANDREY IVANOV	{"email": "ivanov-a.15071974@postgrespro.ru", "phone": "+70774495945"}
0005432133473	75E09B	4565 591862	NIKOLAY SOROKIN	{"phone": "+70549312836"}
0005432133474	B35749	4642 165565	EKATERINA ZAKHAROVA	{"email": "zakharovae_1984@postgrespro.ru", "phone": "+70200440561"}
0005432133475	F5E1A9	9024 849184	ANASTASIYA SAVELEVA	{"phone": "+70854470446"}
0005432133476	2FFEA3	0420 383794	OLGA IVANOVA	{"email": "ivanovaolga-04111973@postgrespro.ru", "phone": "+70901460717"}
0005432133477	EB26CB	2854 099128	MAKSIM NAZAROV	{"email": "nazarovm.19111968@postgrespro.ru", "phone": "+70670584053"}
0005432133478	DD8ADD	9424 225828	SANIYA SEMENOVA	{"phone": "+70189374022"}
0005432133479	F6F8FD	2240 362798	DENIS NAZAROV	{"phone": "+70665508849"}
0005432133480	F6F8FD	0901 361551	ALEKSANDR VLASOV	{"phone": "+70445935129"}
0005432133481	F356EC	4981 656228	OLGA ISAEVA	{"email": "olga.isaeva.021961@postgrespro.ru", "phone": "+70338073677"}
0005432133482	BF9CDC	9130 775402	BORIS KUZNECOV	{"email": "kuznecovb.28101992@postgrespro.ru", "phone": "+70630684674"}
0005432133483	BF9CDC	3777 616332	DMITRIY SERGEEV	{"phone": "+70119734517"}
0005432133484	452254	5573 033248	ANASTASIYA ISAEVA	{"email": "isaeva-anastasiya-01071984@postgrespro.ru", "phone": "+70435985629"}
0005432133485	D3A0B4	2732 915022	POLINA CHERNOVA	{"email": "pchernova-02111963@postgrespro.ru", "phone": "+70063892817"}
0005432133486	81EEE6	2162 966973	TATYANA BORISOVA	{"phone": "+70296883732"}
0005432133487	53CAB5	7943 272655	ANDREY VOLKOV	{"phone": "+70881391100"}
0005432133488	53CAB5	9323 461561	VALENTINA GERASIMOVA	{"email": "valentinagerasimova.061966@postgrespro.ru", "phone": "+70473921306"}
0005432133489	FBB5BE	7000 719616	OLEG GORBUNOV	{"email": "gorbunovoleg.24081980@postgrespro.ru", "phone": "+70989720061"}
0005432133490	498608	0638 409855	LYUBOV STEPANOVA	{"phone": "+70478279864"}
0005432133491	498608	5144 507658	VALENTINA LAZAREVA	{"phone": "+70978521475"}
0005432133492	498608	8149 381513	EKATERINA LEBEDEVA	{"phone": "+70699266120"}
0005432133493	F4089C	6550 810991	OLGA EGOROVA	{"email": "egorova.olga.21121980@postgrespro.ru", "phone": "+70743441568"}
0005432133494	F4089C	0093 782937	VALENTINA PAVLOVA	{"email": "pavlovav.031973@postgrespro.ru", "phone": "+70091463687"}
0005432133495	FF9DFA	6547 792102	RAMIL KOZLOV	{"phone": "+70671344874"}
0005432133496	DA6066	7975 115199	PAVEL MAKAROV	{"phone": "+70833571961"}
0005432133497	2D0DD5	6400 340785	IRINA IVANOVA	{"email": "irina-ivanova.1979@postgrespro.ru", "phone": "+70897547768"}
0005432133498	4AD80E	2722 601546	NIKOLAY VASILEV	{"phone": "+70820460072"}
0005432133499	0AC4C3	7621 085053	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov_1966@postgrespro.ru", "phone": "+70815916171"}
0005432133500	0AC4C3	4619 886339	SERGEY OSIPOV	{"email": "osipov-s041972@postgrespro.ru", "phone": "+70258427279"}
0005432133501	794D97	2364 073058	ANDREY STEPANOV	{"email": "a.stepanov081946@postgrespro.ru", "phone": "+70314021110"}
0005432133502	794D97	7929 114363	LYUDMILA KUZNECOVA	{"email": "kuznecova.l_111978@postgrespro.ru", "phone": "+70657997889"}
0005432133503	DF7BD5	7324 598006	YURIY ILIN	{"phone": "+70367853960"}
0005432133504	49DCC8	7279 146859	NIKOLAY NIKITIN	{"email": "nikitinnikolay-20061975@postgrespro.ru", "phone": "+70904631601"}
0005432133505	B697B8	0858 700677	OLEG NIKITIN	{"phone": "+70370559391"}
0005432133506	B697B8	3356 722024	VALENTINA SERGEEVA	{"phone": "+70114137620"}
0005432133507	368645	5992 175809	NATALYA KOVALEVA	{"email": "nkovaleva_08061966@postgrespro.ru", "phone": "+70266102162"}
0005432133508	63FE3E	5004 340132	ALEKSEY KARPOV	{"phone": "+70325634777"}
0005432133509	23BAA3	6237 485906	YURIY MATVEEV	{"email": "matveevyuriy14061969@postgrespro.ru", "phone": "+70022875992"}
0005432133510	23BAA3	0849 194075	NATALYA KUZMINA	{"email": "kuzminan-27051973@postgrespro.ru", "phone": "+70284058882"}
0005432133511	23BAA3	1705 674514	EKATERINA NIKITINA	{"email": "nikitina-e1968@postgrespro.ru", "phone": "+70581079494"}
0005432133512	C1CE77	8883 278212	ANATOLIY ANDREEV	{"phone": "+70754848071"}
0005432133513	C1CE77	9317 447569	LYUBOV ILINA	{"email": "lyubov.ilina-051973@postgrespro.ru", "phone": "+70766416861"}
0005432133514	897179	8242 430640	IRINA MAKSIMOVA	{"phone": "+70692233153"}
0005432133515	897179	3195 848744	ANATOLIY NOVIKOV	{"phone": "+70208456124"}
0005432133516	E8A249	2466 827100	ANATOLIY IVANOV	{"email": "ivanov_anatoliy.15101964@postgrespro.ru", "phone": "+70719220786"}
0005432133517	E8A249	7296 174755	ANTON GUSEV	{"phone": "+70314265648"}
0005432133518	E78130	3032 264722	DMITRIY GRIGOREV	{"email": "dgrigorev13121977@postgrespro.ru", "phone": "+70443729149"}
0005432133519	E78130	3308 239646	ALEKSANDR MIRONOV	{"phone": "+70241236887"}
0005432133520	AB6DE6	1108 210664	OLEG ANDREEV	{"email": "andreevo-121963@postgrespro.ru", "phone": "+70546209466"}
0005432133521	AB6DE6	6651 391730	NAIL DENISOV	{"phone": "+70710198157"}
0005432133522	2D8184	3014 158748	VALERIY IVANOV	{"phone": "+70420894874"}
0005432133523	2D8184	2558 421881	PETR NIKITIN	{"email": "petr-nikitin-1968@postgrespro.ru", "phone": "+70497487841"}
0005432133524	DAE239	5836 640104	EVDOKIYA MOISEEVA	{"email": "evdokiyamoiseeva071964@postgrespro.ru", "phone": "+70679418216"}
0005432133525	89B68A	0643 868398	ANASTASIYA MIKHAYLOVA	{"phone": "+70766668243"}
0005432133526	F288B7	3030 050097	NADEZHDA NESTEROVA	{"email": "nesterova-nadezhda.25011977@postgrespro.ru", "phone": "+70738604284"}
0005432133527	F288B7	2165 181950	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova-natalya16011975@postgrespro.ru", "phone": "+70165703395"}
0005432133528	3A762C	7362 530958	FANIL KUZMIN	{"email": "f_kuzmin_26071980@postgrespro.ru", "phone": "+70603059357"}
0005432133529	3A762C	4792 962018	VALENTINA ORLOVA	{"email": "valentina.orlova.05101979@postgrespro.ru", "phone": "+70989749555"}
0005432133531	07C55A	5476 178873	ALEKSANDR EGOROV	{"email": "aleksandr.egorov031956@postgrespro.ru", "phone": "+70883999092"}
0005432133532	07C55A	0001 439760	ULYANA NESTEROVA	{"email": "nesterovaulyana.1979@postgrespro.ru", "phone": "+70371010033"}
0005432133533	EB5640	1082 437538	TATYANA BORISOVA	{"email": "borisova-t06071967@postgrespro.ru", "phone": "+70888701588"}
0005432133534	C90E4C	9383 615906	ZOYA ZAKHAROVA	{"email": "zakharovazoya-1966@postgrespro.ru", "phone": "+70614809913"}
0005432133535	C90E4C	4283 114991	VLADISLAV KUZNECOV	{"phone": "+70152218921"}
0005432133536	BA8E64	4779 302755	GLEB MAKAROV	{"phone": "+70828813858"}
0005432133537	DEBE19	6560 507289	NIKOLAY ZAYCEV	{"phone": "+70679859517"}
0005432133538	DEBE19	4945 612454	NADEZHDA KONOVALOVA	{"email": "konovalova-nadezhda-1968@postgrespro.ru", "phone": "+70688552289"}
0005432133539	D1BB06	1251 022001	IRINA FILIPPOVA	{"email": "filippova.irina.24071969@postgrespro.ru", "phone": "+70486309699"}
0005432133540	C62DE3	1571 562550	IVAN ALEKSEEV	{"email": "ialekseev121979@postgrespro.ru", "phone": "+70449168161"}
0005432133541	E9B91F	4014 200869	DENIS SEMENOV	{"phone": "+70077464623"}
0005432133542	5D1F73	5729 204179	ANNA KUZMINA	{"phone": "+70615731772"}
0005432133543	C6D7E7	3999 698136	VALENTINA ANDREEVA	{"phone": "+70933865431"}
0005432133544	A369BD	5971 056518	VASILIY DMITRIEV	{"email": "v.dmitriev-05041970@postgrespro.ru", "phone": "+70286645693"}
0005432133545	9D5EF2	5860 185027	NINA MATVEEVA	{"phone": "+70973881992"}
0005432133546	9D5EF2	1396 355643	VLADIMIR PAVLOV	{"email": "vladimir_pavlov_1973@postgrespro.ru", "phone": "+70812402869"}
0005432133547	8BCEDC	8568 637338	NINA STEPANOVA	{"email": "nstepanova13081969@postgrespro.ru", "phone": "+70319325269"}
0005432133548	55DED8	0898 872849	YURIY VASILEV	{"email": "y_vasilev1983@postgrespro.ru", "phone": "+70732841456"}
0005432133549	5E39CA	6907 104245	ROMAN SEMENOV	{"email": "rsemenov.1966@postgrespro.ru", "phone": "+70245051651"}
0005432133550	5E39CA	0639 229936	TATYANA MARTYNOVA	{"email": "martynova-tatyana_081985@postgrespro.ru", "phone": "+70590682788"}
0005432133551	5E39CA	9506 331755	YURIY VASILEV	{"phone": "+70181779549"}
0005432133552	5E39CA	0841 314856	DARYA NOVIKOVA	{"email": "novikova.darya.021966@postgrespro.ru", "phone": "+70003787196"}
0005432133553	4004F8	4258 829580	VIKTOR ZAKHAROV	{"phone": "+70142388415"}
0005432133554	9C1387	4329 354089	GENNADIY KAZAKOV	{"phone": "+70184459257"}
0005432133555	C00839	5828 857075	POLINA NIKITINA	{"email": "nikitina-polina-031978@postgrespro.ru", "phone": "+70434186346"}
0005432133556	C00839	3600 322796	SERGEY TIKHONOV	{"phone": "+70410947187"}
0005432133557	00F9DC	2209 533888	KONSTANTIN MAKAROV	{"email": "konstantinmakarov_19111969@postgrespro.ru", "phone": "+70452028056"}
0005432133558	4B91B7	0770 913323	STANISLAV SERGEEV	{"phone": "+70224893264"}
0005432133559	7C1E9F	1588 487559	NATALYA SERGEEVA	{"phone": "+70724888529"}
0005432133560	6CF821	4689 817532	NADEZHDA KUZNECOVA	{"phone": "+70612689831"}
0005432133561	56D827	8782 501703	KARINA FILIPPOVA	{"phone": "+70163626943"}
0005432133562	56D827	3323 927805	POLINA GAVRILOVA	{"email": "pgavrilova_22101984@postgrespro.ru", "phone": "+70987777980"}
0005432133563	85A7C0	5255 415830	VIKTORIYA LUKYANOVA	{"email": "v_lukyanova.1974@postgrespro.ru", "phone": "+70157711071"}
0005432133564	85A7C0	3560 056473	ANDREY YAKOVLEV	{"email": "yakovlev_a-1970@postgrespro.ru", "phone": "+70448915230"}
0005432133565	88FD9C	3187 394287	DMITRIY POPOV	{"email": "d.popov121971@postgrespro.ru", "phone": "+70571615583"}
0005432133566	88FD9C	6966 147464	ANATOLIY STEPANOV	{"phone": "+70687643680"}
0005432133567	1DBD0B	4455 794749	KRISTINA NIKOLAEVA	{"phone": "+70899404802"}
0005432133568	EB92C4	0090 018871	VLADIMIR MARTYNOV	{"email": "martynov-vladimir.051966@postgrespro.ru", "phone": "+70487650344"}
0005432133569	EB92C4	1874 849108	OLGA VASILEVA	{"email": "olga_vasileva101971@postgrespro.ru", "phone": "+70703773807"}
0005432133570	2DC2EF	5687 675892	SERGEY EGOROV	{"email": "sergeyegorov091969@postgrespro.ru", "phone": "+70663630776"}
0005432133571	2DC2EF	6981 741311	ALEKSANDR KULIKOV	{"email": "kulikov.a1972@postgrespro.ru", "phone": "+70556606309"}
0005432133572	033720	8819 602869	NADEZHDA YAKOVLEVA	{"email": "nyakovleva_25061977@postgrespro.ru", "phone": "+70031024175"}
0005432133573	DB53D2	0537 335661	MARINA GUSEVA	{"email": "guseva.m_011985@postgrespro.ru", "phone": "+70638926177"}
0005432133574	DB53D2	1384 264964	VLADIMIR TIMOFEEV	{"email": "v.timofeev_08101970@postgrespro.ru", "phone": "+70388174137"}
0005432133575	71EF9E	5028 053553	GERMAN NIKITIN	{"email": "nikitin.g.111985@postgrespro.ru", "phone": "+70996680263"}
0005432133576	2F9D70	2886 083015	YAROSLAV FEDOTOV	{"email": "fedotov_y.01081970@postgrespro.ru", "phone": "+70662059425"}
0005432133577	A93C6F	6513 387176	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d08091965@postgrespro.ru", "phone": "+70381222304"}
0005432133578	05C2D2	0044 670734	IRINA SEMENOVA	{"email": "semenova-i.051970@postgrespro.ru", "phone": "+70383381034"}
0005432133579	05C2D2	6154 326480	NATALYA MIRONOVA	{"email": "n-mironova.121972@postgrespro.ru", "phone": "+70671761263"}
0005432133580	05C2D2	4860 828318	MARIYA NAUMOVA	{"email": "mariyanaumova_1973@postgrespro.ru", "phone": "+70829629487"}
0005432133581	85BB1F	3453 802718	NIKOLAY ISAEV	{"email": "isaev-nikolay_1973@postgrespro.ru", "phone": "+70183537460"}
0005432133582	85BB1F	1794 426317	ANDREY KISELEV	{"phone": "+70944184452"}
0005432133583	2F6F72	0095 716530	TATYANA FEDOROVA	{"email": "t_fedorova.051968@postgrespro.ru", "phone": "+70025363521"}
0005432133584	2F6F72	4817 495757	ANNA ZAKHAROVA	{"email": "zakharovaa-1978@postgrespro.ru", "phone": "+70700933284"}
0005432133585	D1B9A7	1622 838239	LYUDMILA NOVIKOVA	{"phone": "+70825778273"}
0005432133586	5BD21F	9737 288433	TATYANA DENISOVA	{"email": "denisova-tatyana_01081975@postgrespro.ru", "phone": "+70901949241"}
0005432133587	489202	5683 981822	DMITRIY PETROV	{"email": "petrov_dmitriy-1972@postgrespro.ru", "phone": "+70789597353"}
0005432133589	1FB128	3016 181795	ANATOLIY KRASNOV	{"email": "krasnova021972@postgrespro.ru", "phone": "+70259061181"}
0005432133590	7EF341	0322 074742	GRIGORIY MAKSIMOV	{"phone": "+70404677857"}
0005432133591	46317D	4625 092537	ANDREY BELOV	{"phone": "+70321804663"}
0005432133592	4E2326	5002 477646	EVDOKIYA BELOVA	{"email": "belova_evdokiya.21011973@postgrespro.ru", "phone": "+70002453617"}
0005432133593	290A4E	9753 610158	ALEKSANDRA ROMANOVA	{"email": "romanova.a-15041984@postgrespro.ru", "phone": "+70069772117"}
0005432133594	290A4E	9762 408143	OLGA FROLOVA	{"email": "olga.frolova_1975@postgrespro.ru", "phone": "+70908285797"}
0005432133595	812C34	0074 943048	YULIYA KULIKOVA	{"email": "yuliya-kulikova1979@postgrespro.ru", "phone": "+70373561789"}
0005432133596	C0EFE7	0345 513856	IRINA ARKHIPOVA	{"phone": "+70659765518"}
0005432133597	C0EFE7	8557 006037	ANASTASIYA OSIPOVA	{"email": "osipova-anastasiya_17081975@postgrespro.ru", "phone": "+70647929492"}
0005432133598	BEA664	0168 006721	GLEB TIKHONOV	{"email": "glebtikhonov.18121967@postgrespro.ru", "phone": "+70942919683"}
0005432133599	397EE2	9684 795410	ANNA KUZNECOVA	{"email": "anna.kuznecova.10051967@postgrespro.ru", "phone": "+70993869855"}
0005432133600	41E1AF	0615 523986	ANNA RYABOVA	{"email": "anna.ryabova.1972@postgrespro.ru", "phone": "+70575401881"}
0005432133601	41E1AF	0550 272763	TAMARA STEPANOVA	{"phone": "+70302783346"}
0005432133602	86D107	4163 133368	ALEKSANDR KRASNOV	{"email": "krasnov.a_1987@postgrespro.ru", "phone": "+70840899663"}
0005432133603	3103A4	8549 590242	TATYANA KUZMINA	{"email": "kuzmina.t_041958@postgrespro.ru", "phone": "+70240432267"}
0005432133604	E1634E	8220 927287	TAMARA FROLOVA	{"phone": "+70511370154"}
0005432133605	98EAEC	5669 432649	ANDREY KUZNECOV	{"email": "kuznecov-andrey_1965@postgrespro.ru", "phone": "+70212759898"}
0005432133606	2ABE7E	0602 541364	VIKTORIYA SOLOVEVA	{"phone": "+70338912535"}
0005432133607	2ABE7E	3780 566442	GALINA IVANOVA	{"email": "g.ivanova.31071978@postgrespro.ru", "phone": "+70580496764"}
0005432133608	B8EB87	9647 330760	MIKHAIL MAKSIMOV	{"email": "mikhail.maksimov-1967@postgrespro.ru", "phone": "+70160414098"}
0005432133609	B8EB87	7225 615238	GALINA STEPANOVA	{"email": "galinastepanova091979@postgrespro.ru", "phone": "+70232270282"}
0005432133610	EA0CE5	9032 228878	NIKOLAY MAKAROV	{"phone": "+70268444941"}
0005432133611	7400A1	7596 301902	VYACHESLAV MOROZOV	{"phone": "+70046269870"}
0005432133612	97457B	0789 861383	ALENA TIMOFEEVA	{"email": "a-timofeeva.1973@postgrespro.ru", "phone": "+70285161244"}
0005432133613	97457B	7704 185754	TATYANA ABRAMOVA	{"phone": "+70341424824"}
0005432133614	CA2D9E	0710 834103	LARISA BELOVA	{"phone": "+70336636664"}
0005432133615	45CC3C	6308 346611	VERA IVANOVA	{"phone": "+70121842359"}
0005432133616	45CC3C	6614 001216	NINA OSIPOVA	{"phone": "+70552393473"}
0005432133617	F7BB01	2469 424389	IVAN ANTONOV	{"email": "antonovivan.1981@postgrespro.ru", "phone": "+70604946372"}
0005432133618	F7BB01	0701 074569	OKSANA KUZNECOVA	{"email": "oksana_kuznecova1979@postgrespro.ru", "phone": "+70663686400"}
0005432133619	A362B1	0170 365014	ALEKSEY ZAYCEV	{"email": "zaycev.a-081977@postgrespro.ru", "phone": "+70113355376"}
0005432133620	516355	5736 081164	GALINA MOISEEVA	{"email": "galinamoiseeva_1959@postgrespro.ru", "phone": "+70012982737"}
0005432133621	6CA809	3412 472524	OLEG KUDRYASHOV	{"email": "kudryashov.o29041962@postgrespro.ru", "phone": "+70454587405"}
0005432133622	B3A0D9	8066 333764	KONSTANTIN VOLKOV	{"phone": "+70967191672"}
0005432133623	491278	3134 900188	VASILIY IVANOV	{"phone": "+70892009586"}
0005432133624	AD493E	9630 309325	MARIYA FOMINA	{"email": "mariya_fomina.091960@postgrespro.ru", "phone": "+70331537986"}
0005432133625	E305E9	7463 255790	ARTEM CHERNOV	{"email": "a_chernov041977@postgrespro.ru", "phone": "+70288634730"}
0005432133626	E305E9	1936 630476	SOFYA MOISEEVA	{"phone": "+70388895000"}
0005432133627	78FDAC	3854 163785	MIKHAIL SHEVCHENKO	{"email": "shevchenkomikhail_20031977@postgrespro.ru", "phone": "+70684023013"}
0005432133628	919571	8068 265324	OLGA MELNIKOVA	{"phone": "+70197892733"}
0005432133629	7222BA	5071 442810	ELIZAVETA RYABOVA	{"email": "ryabova.e_101971@postgrespro.ru", "phone": "+70308126397"}
0005432133630	7222BA	8980 313581	NADEZHDA YUDINA	{"phone": "+70748907142"}
0005432133631	6AC0BA	3384 272400	LYUDMILA KOVALEVA	{"email": "kovaleva.l1973@postgrespro.ru", "phone": "+70993378590"}
0005432133632	718C0C	9362 007162	YURIY DMITRIEV	{"email": "dmitriev.y-091971@postgrespro.ru", "phone": "+70920542288"}
0005432133633	EC6E48	4735 661169	NATALYA KUDRYASHOVA	{"phone": "+70328052362"}
0005432133634	EC6E48	6093 152336	NIKOLAY ZHURAVLEV	{"phone": "+70755156458"}
0005432133635	D65C33	9516 271881	POLINA MALYSHEVA	{"email": "pmalysheva_24051974@postgrespro.ru", "phone": "+70205215994"}
0005432133636	3808F3	4189 442442	IRINA POTAPOVA	{"phone": "+70493251536"}
0005432133637	A783B1	4353 395203	PETR TIKHONOV	{"email": "tikhonovpetr-041975@postgrespro.ru", "phone": "+70948190248"}
0005432133638	A783B1	7618 562063	DARYA FEDOROVA	{"phone": "+70118537285"}
0005432133639	391841	6950 357340	VYACHESLAV SOROKIN	{"phone": "+70848394296"}
0005432133640	391841	4416 168336	VLADIMIR IVANOV	{"email": "ivanov_vladimir13041982@postgrespro.ru", "phone": "+70292680137"}
0005432133641	A91B18	9820 736565	YULIYA ROMANOVA	{"email": "y_romanova101959@postgrespro.ru", "phone": "+70232271366"}
0005432133642	A91B18	9072 414916	ELENA MOROZOVA	{"email": "elena-morozova_04081980@postgrespro.ru", "phone": "+70673754773"}
0005432133643	C7E7B6	1726 935370	MAKSIM DENISOV	{"phone": "+70863318689"}
0005432133644	C7E7B6	5441 010064	FEDOR RODIONOV	{"phone": "+70590279388"}
0005432133645	5EBA68	6196 772323	ALINA SOKOLOVA	{"phone": "+70519791175"}
0005432133646	86333B	2036 475379	DENIS ABRAMOV	{"phone": "+70324285607"}
0005432133647	016160	0548 100121	IRINA LOGINOVA	{"phone": "+70132187306"}
0005432136182	E6512B	6668 311544	VIKTOR OSIPOV	{"phone": "+70867619218"}
0005432133648	57D02B	5485 908878	SERGEY SERGEEV	{"email": "sergeevsergey101969@postgrespro.ru", "phone": "+70283598531"}
0005432133649	1DC2FA	4215 556327	ILMIRA IVANOVA	{"email": "iivanova091960@postgrespro.ru", "phone": "+70445809624"}
0005432133650	B40988	4707 350205	IRINA POTAPOVA	{"email": "potapova_irina_061978@postgrespro.ru", "phone": "+70809574423"}
0005432133651	F2FC42	5406 617440	TATYANA KUZNECOVA	{"phone": "+70194386609"}
0005432133652	F2FC42	9147 980129	YURIY GAVRILOV	{"phone": "+70867165733"}
0005432133653	E2A553	1955 125758	VLADIMIR SCHERBAKOV	{"phone": "+70403335250"}
0005432133654	972F4B	4411 242235	OLEG STEPANOV	{"email": "stepanovoleg_26101979@postgrespro.ru", "phone": "+70153394626"}
0005432133655	D99FBD	0242 817230	KONSTANTIN FEDOROV	{"email": "konstantin_fedorov_081969@postgrespro.ru", "phone": "+70482011141"}
0005432133656	F6032F	4368 349178	PAVEL SAVELEV	{"email": "savelev.pavel-091968@postgrespro.ru", "phone": "+70327312878"}
0005432133657	11F11A	0454 481933	FARIT VASILEV	{"email": "vasilev.f_1959@postgrespro.ru", "phone": "+70455029891"}
0005432133658	EEA636	6499 794692	IRINA POPOVA	{"phone": "+70359873928"}
0005432133659	EEA636	7761 133033	EKATERINA EFIMOVA	{"email": "e.efimova_1980@postgrespro.ru", "phone": "+70297680829"}
0005432133660	91E7FC	7197 994792	NIKOLAY ORLOV	{"phone": "+70833478214"}
0005432133661	91E7FC	8303 643198	LARISA BELOVA	{"email": "larisa_belova-12101967@postgrespro.ru", "phone": "+70873051512"}
0005432136079	BE3A1B	6624 772415	ANASTASIYA FROLOVA	{"phone": "+70079270721"}
0005432136080	BE3A1B	4193 390681	ANASTASIYA VOLKOVA	{"email": "anastasiya_volkova.071976@postgrespro.ru", "phone": "+70252529355"}
0005432136081	BF17AC	0053 522141	ALEKSEY NIKITIN	{"email": "anikitin-05121977@postgrespro.ru", "phone": "+70791177200"}
0005432136082	BFBC6F	6478 975747	IRINA VASILEVA	{"phone": "+70433992056"}
0005432136083	BFBC6F	9155 454402	NATALYA PETROVA	{"email": "n_petrova_04031973@postgrespro.ru", "phone": "+70939121973"}
0005432136084	BFBC6F	8062 148061	ALEVTINA KONOVALOVA	{"phone": "+70749344329"}
0005432136085	435EE5	0650 799214	VYACHESLAV ABRAMOV	{"email": "vyacheslav_abramov-30061971@postgrespro.ru", "phone": "+70884289133"}
0005432136086	FE932E	0408 003043	ANASTASIYA BORISOVA	{"email": "anastasiyaborisova_1965@postgrespro.ru", "phone": "+70910317366"}
0005432136087	771A89	7291 399860	RAISA GERASIMOVA	{"email": "raisa-gerasimova_111960@postgrespro.ru", "phone": "+70330891011"}
0005432136088	BC8272	3276 902103	OLEG ILIN	{"phone": "+70803697257"}
0005432136089	BC8272	0408 778518	VALENTINA MATVEEVA	{"phone": "+70378431885"}
0005432136090	C26AB2	2397 907851	ALSU NOVIKOVA	{"phone": "+70503974010"}
0005432136091	7B758C	6397 808161	ALEKSANDR SERGEEV	{"email": "a.sergeev.09051981@postgrespro.ru", "phone": "+70877237928"}
0005432136092	26D34D	9758 025496	STANISLAV PAVLOV	{"phone": "+70692265169"}
0005432136093	7DEDB7	6662 797511	SERGEY DENISOV	{"email": "s-denisov1967@postgrespro.ru", "phone": "+70824016991"}
0005432136094	A221DD	1902 914647	EVGENIY MEDVEDEV	{"email": "medvedev_evgeniy.011973@postgrespro.ru", "phone": "+70955924487"}
0005432136095	D6034E	4646 154598	MARIYA STEPANOVA	{"phone": "+70812570789"}
0005432136096	71B15A	5514 983643	GALINA KOMAROVA	{"phone": "+70834494357"}
0005432136097	71B15A	1708 555915	OLGA NESTEROVA	{"email": "nesterova-olga-13031973@postgrespro.ru", "phone": "+70927460413"}
0005432136098	022164	3510 393986	ALEKSANDR VLASOV	{"phone": "+70040278613"}
0005432136099	022164	3866 811710	ELENA LEBEDEVA	{"email": "e-lebedeva_011978@postgrespro.ru", "phone": "+70490598413"}
0005432136100	022164	6340 869883	MARINA SERGEEVA	{"email": "marina-sergeeva-02051976@postgrespro.ru", "phone": "+70307539799"}
0005432136101	038114	4582 136693	ANATOLIY DMITRIEV	{"email": "dmitriev-a_081980@postgrespro.ru", "phone": "+70758945529"}
0005432136102	EE9017	6269 232294	VLADIMIR MAKAROV	{"email": "v.makarov.20051974@postgrespro.ru", "phone": "+70590498825"}
0005432136103	EE9017	5628 455764	NIKOLAY SMIRNOV	{"email": "nsmirnov_1974@postgrespro.ru", "phone": "+70994294216"}
0005432136104	054E97	2380 841491	IRINA MARTYNOVA	{"phone": "+70212640613"}
0005432136105	054E97	3346 211416	TATYANA MALYSHEVA	{"email": "tmalysheva-101966@postgrespro.ru", "phone": "+70611338593"}
0005432136106	054E97	4721 182593	VASILIY PAVLOV	{"email": "pavlov_vasiliy121976@postgrespro.ru", "phone": "+70996046382"}
0005432136107	FD3F87	5515 517284	SERGEY FILIPPOV	{"email": "filippov_sergey_13031967@postgrespro.ru", "phone": "+70701806766"}
0005432136108	FD3F87	7632 929861	KIRILL KOROLEV	{"email": "kirillkorolev-01051960@postgrespro.ru", "phone": "+70451261130"}
0005432136109	C65C9B	0473 518239	SERGEY MAKAROV	{"phone": "+70965819747"}
0005432136110	61199D	5995 079385	ALEKSANDR MOROZOV	{"email": "a-morozov.02021977@postgrespro.ru", "phone": "+70425651558"}
0005432136111	61199D	3674 658173	OLGA SAVELEVA	{"phone": "+70031687449"}
0005432136112	A8BF16	4929 125932	VALENTINA TARASOVA	{"email": "v_tarasova.071973@postgrespro.ru", "phone": "+70425871328"}
0005432136113	434D39	2632 739254	VALENTIN GRIGOREV	{"phone": "+70574556431"}
0005432136114	8DDB93	3439 237152	KONSTANTIN VASILEV	{"email": "vasilev-konstantin-06091981@postgrespro.ru", "phone": "+70117296492"}
0005432136115	406E76	0149 015824	LYUDMILA MAKSIMOVA	{"email": "lyudmila.maksimova.03061972@postgrespro.ru", "phone": "+70568009490"}
0005432136116	FE7712	8318 532221	OLGA KRASNOVA	{"email": "o-krasnova-06081971@postgrespro.ru", "phone": "+70565716565"}
0005432136117	FE7712	9374 844879	DENIS FOMIN	{"email": "fomindenis.03021959@postgrespro.ru", "phone": "+70003161481"}
0005432136118	15CD5A	9282 323208	YULIYA KOROLEVA	{"phone": "+70499566872"}
0005432136119	1A0EB3	2042 887551	ANTONINA NIKIFOROVA	{"email": "nikiforova_antonina_1976@postgrespro.ru", "phone": "+70896717885"}
0005432136120	1A0EB3	7647 516707	YULIYA ZHURAVLEVA	{"phone": "+70454299271"}
0005432136121	1A0EB3	6433 730134	DANIL FILIPPOV	{"email": "d_filippov.1978@postgrespro.ru", "phone": "+70263886128"}
0005432136122	9FF179	3988 626387	NADEZHDA SOROKINA	{"phone": "+70149864701"}
0005432136123	B13CA2	6062 382401	ANATOLIY MIKHAYLOV	{"email": "a-mikhaylov_04071972@postgrespro.ru", "phone": "+70605198955"}
0005432136124	5F8711	4150 926470	OLGA LUKYANOVA	{"phone": "+70510534935"}
0005432136125	161498	7813 638048	ANASTASIYA BORISOVA	{"phone": "+70840440799"}
0005432136126	161498	2741 490020	ALEKSANDR FROLOV	{"phone": "+70539234650"}
0005432136127	7D12D0	9594 323636	NIKOLAY POPOV	{"phone": "+70901699670"}
0005432136128	BF5D0A	7891 651152	TATYANA MOROZOVA	{"phone": "+70867890702"}
0005432136129	A5C0AD	9401 577081	ILYA MARTYNOV	{"phone": "+70307264713"}
0005432136130	00218C	0485 139376	VIKTORIYA VASILEVA	{"email": "viktoriya_vasileva_16071970@postgrespro.ru", "phone": "+70171177572"}
0005432136131	6F1C74	8665 429803	LIDIYA ZAKHAROVA	{"email": "l-zakharova_011974@postgrespro.ru", "phone": "+70755425000"}
0005432136132	38CDDC	5950 463303	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr.08091973@postgrespro.ru", "phone": "+70411337438"}
0005432136133	54C2D9	9247 924292	ALEKSANDR SOKOLOV	{"email": "sokolov.a051980@postgrespro.ru", "phone": "+70188100461"}
0005432136134	AAFBF1	3816 428381	ALEKSANDRA POPOVA	{"email": "popova.aleksandra-17111964@postgrespro.ru", "phone": "+70158572367"}
0005432136135	AAFBF1	7970 467581	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov061972@postgrespro.ru", "phone": "+70778674656"}
0005432136136	E8F96C	8576 782442	ELENA KRASNOVA	{"phone": "+70882957046"}
0005432136137	53445C	2149 183470	OLGA NAZAROVA	{"email": "o-nazarova_1970@postgrespro.ru", "phone": "+70213128752"}
0005432136138	0CD247	5961 210585	KRISTINA AFANASEVA	{"email": "afanaseva.k-05121966@postgrespro.ru", "phone": "+70171359875"}
0005432136139	BA8021	2326 472907	ALEKSANDR MOISEEV	{"email": "a.moiseev.1968@postgrespro.ru", "phone": "+70211151685"}
0005432136140	6E728B	4150 570237	EKATERINA BARANOVA	{"email": "baranova_ekaterina.20061965@postgrespro.ru", "phone": "+70520755933"}
0005432136141	F01FA4	7822 659184	ELENA STEPANOVA	{"email": "elena-stepanova-1971@postgrespro.ru", "phone": "+70421450592"}
0005432136142	A82415	7853 110103	OLGA KUZMINA	{"email": "kuzminaolga1974@postgrespro.ru", "phone": "+70693622306"}
0005432136143	A82415	8588 584317	MIKHAIL GERASIMOV	{"email": "gerasimov-mikhail_1965@postgrespro.ru", "phone": "+70962368147"}
0005432136144	CADB4D	4694 392882	OKSANA KOROLEVA	{"phone": "+70460202290"}
0005432136145	3B3E64	3567 609990	NIKOLAY POPOV	{"phone": "+70414916465"}
0005432136146	FA6718	3508 096678	NATALYA NESTEROVA	{"phone": "+70841103785"}
0005432136147	221A97	9379 289519	ALEKSANDR VASILEV	{"email": "a-vasilev_1972@postgrespro.ru", "phone": "+70047971445"}
0005432136148	1CC990	7205 593102	ILYA POPOV	{"phone": "+70412362583"}
0005432136149	16B419	0717 024585	MARINA KONDRATEVA	{"email": "kondratevamarina.1966@postgrespro.ru", "phone": "+70221776445"}
0005432136150	16B419	9880 008983	MIKHAIL ROMANOV	{"phone": "+70773394289"}
0005432136151	C093CB	6276 694238	EVGENIY KONOVALOV	{"email": "ekonovalov.28111978@postgrespro.ru", "phone": "+70354842588"}
0005432136152	C8ECFC	9975 966411	PAVEL DAVYDOV	{"email": "p_davydov.1979@postgrespro.ru", "phone": "+70384022112"}
0005432136153	C8ECFC	1482 720856	VADIM BORISOV	{"email": "borisov.vadim.1970@postgrespro.ru", "phone": "+70094843832"}
0005432136154	4D08C1	9454 591019	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova19111966@postgrespro.ru", "phone": "+70755495318"}
0005432136155	94DCC2	0806 793046	EKATERINA KOROLEVA	{"email": "korolevae_081986@postgrespro.ru", "phone": "+70616281786"}
0005432136156	5A1C52	8291 455685	ALEKSANDR GUSEV	{"phone": "+70517356760"}
0005432136157	45C58B	8394 226843	GALINA CHERNOVA	{"phone": "+70094411848"}
0005432136158	80F9CD	2807 467580	KONSTANTIN ANDREEV	{"phone": "+70526997634"}
0005432136159	AEF3EB	4661 690644	TATYANA KISELEVA	{"phone": "+70061050566"}
0005432136160	F8C9F1	6021 996626	VLADIMIR SCHERBAKOV	{"email": "scherbakov.vladimir-24011966@postgrespro.ru", "phone": "+70716310669"}
0005432136161	BF17F1	1301 423169	ALEKSANDRA FADEEVA	{"email": "fadeeva.a_30051983@postgrespro.ru", "phone": "+70307686295"}
0005432136162	BF17F1	9525 966046	DINA AFANASEVA	{"email": "dina.afanaseva-061976@postgrespro.ru", "phone": "+70367505982"}
0005432136163	DBDD52	2996 146301	VIKTOR ZAYCEV	{"email": "v-zaycev.081977@postgrespro.ru", "phone": "+70018111000"}
0005432136164	EDB6FA	5428 919841	NINA CHERNOVA	{"phone": "+70174231660"}
0005432136165	E7071F	3879 454646	IVAN PETROV	{"email": "ivanpetrov.031968@postgrespro.ru", "phone": "+70923438327"}
0005432136166	E7071F	2708 469286	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir-25071969@postgrespro.ru", "phone": "+70049218903"}
0005432136167	ACB5FB	4009 229061	VALENTIN SCHERBAKOV	{"phone": "+70840323689"}
0005432136168	F50EE9	0174 687980	ALEKSANDRA PAVLOVA	{"phone": "+70024224286"}
0005432136169	B9F518	5842 408182	ANNA LAZAREVA	{"phone": "+70843252551"}
0005432136170	1F5206	4365 410193	PAVEL GERASIMOV	{"email": "gerasimov_p.01101970@postgrespro.ru", "phone": "+70926873814"}
0005432136171	1F5206	1649 308145	MARINA NIKOLAEVA	{"phone": "+70104501905"}
0005432136172	0820AD	9290 957831	TATYANA MELNIKOVA	{"email": "t-melnikova_1970@postgrespro.ru", "phone": "+70061723288"}
0005432136173	0820AD	9070 991495	IGOR KOROLEV	{"phone": "+70624481575"}
0005432136174	25E159	5578 476264	ELENA KULIKOVA	{"email": "elena_kulikova061970@postgrespro.ru", "phone": "+70192496432"}
0005432136175	25E159	1971 616079	TATYANA ANDREEVA	{"phone": "+70675643695"}
0005432136176	B1853C	3258 335490	ALEKSANDRA ZHURAVLEVA	{"email": "aleksandra.zhuravleva-1975@postgrespro.ru", "phone": "+70109937557"}
0005432136177	B89878	6434 429554	ALEKSEY BELOV	{"phone": "+70045156793"}
0005432136178	EC967A	9581 247043	MARIYA KUZMINA	{"phone": "+70929607369"}
0005432136179	316438	2132 241225	ANNA ROMANOVA	{"email": "romanova-a-08111972@postgrespro.ru", "phone": "+70102437607"}
0005432136180	3C995A	3424 311250	RAVIL VOROBEV	{"phone": "+70264416380"}
0005432136181	2A9567	5603 966931	OLGA FILIPPOVA	{"email": "filippova-olga_11011976@postgrespro.ru", "phone": "+70725202163"}
0005432136183	6A48C1	5301 039698	EVGENIYA ROMANOVA	{"email": "e_romanova011973@postgrespro.ru", "phone": "+70583938620"}
0005432136184	6A48C1	7183 730201	ANASTASIYA ZAKHAROVA	{"email": "zakharova.anastasiya_081971@postgrespro.ru", "phone": "+70968064978"}
0005432136185	AE9230	3644 696651	LYUBOV AFANASEVA	{"phone": "+70578916584"}
0005432136186	AE9230	5382 227889	NINA KUDRYASHOVA	{"email": "nkudryashova-061977@postgrespro.ru", "phone": "+70379053650"}
0005432136187	D583CE	2960 422198	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda_24031968@postgrespro.ru", "phone": "+70096245494"}
0005432136188	EB6EBD	2203 792764	ALIYA GAVRILOVA	{"phone": "+70254230926"}
0005432136189	0EF859	2251 932285	ALEKSEY KUZNECOV	{"phone": "+70571363111"}
0005432136190	CF3067	2385 304641	NINA ILINA	{"email": "nina.ilina-1975@postgrespro.ru", "phone": "+70406434507"}
0005432136191	CF3067	4724 206482	ALEKSANDR GAVRILOV	{"phone": "+70270924586"}
0005432136192	A37B9D	9267 575679	LEONID KUZMIN	{"email": "leonid_kuzmin.1971@postgrespro.ru", "phone": "+70277313012"}
0005432136193	A37B9D	8305 848943	OKSANA BELOVA	{"phone": "+70144995738"}
0005432136194	A25D90	5658 082958	EVGENIY ILIN	{"phone": "+70211824479"}
0005432136195	139F7C	4914 639372	KSENIYA POPOVA	{"phone": "+70500970691"}
0005432136196	139F7C	1240 913080	GLEB GUSEV	{"phone": "+70458744357"}
0005432136197	0D8F48	3965 113957	ALEKSEY SHEVCHENKO	{"phone": "+70759553747"}
0005432136198	4D4FAB	6179 818910	IRINA BELOVA	{"email": "irina.belova.011966@postgrespro.ru", "phone": "+70107946987"}
0005432136199	AC9A5E	9682 285397	ELIZAVETA GUSEVA	{"phone": "+70606730608"}
0005432136200	4C9302	2029 733553	EKATERINA GRISHINA	{"email": "ekaterina_grishina081977@postgrespro.ru", "phone": "+70270846915"}
0005432136201	4C9302	2653 812787	RAISA POLYAKOVA	{"email": "polyakova_r_1978@postgrespro.ru", "phone": "+70664153044"}
0005432136202	68A74D	3280 114205	ALEKSANDR VOROBEV	{"email": "vorobev-aleksandr-1975@postgrespro.ru", "phone": "+70912009333"}
0005432136203	68A74D	3354 692421	IVAN ZAYCEV	{"email": "ivan_zaycev_23121966@postgrespro.ru", "phone": "+70106957967"}
0005432136204	5B3442	2405 634021	TATYANA FILATOVA	{"phone": "+70692848547"}
0005432136205	02CAC0	6868 198187	VERA EGOROVA	{"email": "vera-egorova06111965@postgrespro.ru", "phone": "+70506102066"}
0005432136206	17A90B	7369 106233	VIKTOR KOZLOV	{"phone": "+70970152674"}
0005432136207	FA3DF7	9130 350829	VALENTINA TIKHONOVA	{"phone": "+70745832133"}
0005432136208	42EBAF	2168 326068	ANASTASIYA KOVALEVA	{"phone": "+70024134487"}
0005432136209	33DD45	1768 608696	MATVEY KARPOV	{"email": "karpov_m_1980@postgrespro.ru", "phone": "+70898005232"}
0005432136210	DA6DFD	4462 043737	ANNA RYABOVA	{"phone": "+70566466774"}
0005432136211	DA6DFD	4851 716870	NATALYA GUSEVA	{"email": "n.guseva09061964@postgrespro.ru", "phone": "+70830743408"}
0005432136212	DA6DFD	9236 181887	TATYANA DANILOVA	{"email": "tdanilova08071976@postgrespro.ru", "phone": "+70885990768"}
0005432136213	5D1047	8753 001839	DENIS KOROLEV	{"email": "korolev_d-1959@postgrespro.ru", "phone": "+70867375001"}
0005432136214	91F881	9523 411367	VIKTOR SEMENOV	{"phone": "+70274256534"}
0005432136215	E8A1F5	3567 617012	YURIY SOLOVEV	{"email": "solovev-yuriy_071988@postgrespro.ru", "phone": "+70823461378"}
0005432136216	3AEAF4	4649 801915	IRINA ZAYCEVA	{"phone": "+70129375431"}
0005432136217	3AEAF4	6826 098015	ROMAN SOKOLOV	{"email": "sokolov_roman-21041966@postgrespro.ru", "phone": "+70268860218"}
0005432136218	3AEAF4	8586 929226	IRINA IVANOVA	{"phone": "+70502840650"}
0005432136219	46EFD0	9340 181592	ALEKSANDR VASILEV	{"phone": "+70311413873"}
0005432136220	FF466B	4743 309484	MARGARITA SIDOROVA	{"phone": "+70588261148"}
0005432136221	B603CA	4755 506394	NINA DENISOVA	{"email": "nina_denisova26121981@postgrespro.ru", "phone": "+70563337884"}
0005432136222	BB9A0D	8493 880989	PETR NIKOLAEV	{"phone": "+70333663786"}
0005432136223	5AAC41	4123 176372	MARIYA KISELEVA	{"email": "kiseleva.mariya_29021972@postgrespro.ru", "phone": "+70890708154"}
0005432136224	4B4FF1	6655 213940	OLEG TIKHONOV	{"phone": "+70331575904"}
0005432136225	1AE2D0	7823 895937	DENIS YAKOVLEV	{"email": "yakovlevd.011972@postgrespro.ru", "phone": "+70639327553"}
0005432136226	604C73	9229 592080	ERIK IVANOV	{"email": "ivanov.e1968@postgrespro.ru", "phone": "+70956613779"}
0005432136227	D25AB5	6251 615422	NIKOLAY MOISEEV	{"phone": "+70044545415"}
0005432136228	BA611D	0235 680373	VALENTINA ANISIMOVA	{"email": "anisimova_valentina.041967@postgrespro.ru", "phone": "+70084203800"}
0005432136229	CFCB18	7079 434673	ELIZAVETA NESTEROVA	{"email": "elizaveta.nesterova-1975@postgrespro.ru", "phone": "+70549425229"}
0005432136230	E6E79D	3086 363747	GALINA MAKAROVA	{"email": "galinamakarova_04091966@postgrespro.ru", "phone": "+70347001235"}
0005432136231	54DE5D	4477 342278	NATALIYA TARASOVA	{"phone": "+70636988200"}
0005432136232	2DF963	2122 488865	SVETLANA SOKOLOVA	{"email": "svetlana_sokolova-011970@postgrespro.ru", "phone": "+70609551520"}
0005432136233	981B74	1664 657847	NIKITA NAUMOV	{"phone": "+70156637823"}
0005432136234	540C53	2789 205961	ALEKSANDR KOROLEV	{"email": "aleksandr-korolev_1969@postgrespro.ru", "phone": "+70736155216"}
0005432136235	4CD26A	5751 436877	OKSANA ORLOVA	{"email": "orlova.o_081981@postgrespro.ru", "phone": "+70615573436"}
0005432136236	E0805B	2291 793005	LYUBOV ALEKSEEVA	{"email": "lalekseeva-1959@postgrespro.ru", "phone": "+70510979316"}
0005432136237	E0805B	2260 639568	VIKTOR SMIRNOV	{"phone": "+70061150627"}
0005432136238	03120B	5874 741753	ANASTASIYA IVANOVA	{"phone": "+70381346211"}
0005432136239	03120B	7211 010176	IVAN MOISEEV	{"email": "ivanmoiseev1980@postgrespro.ru", "phone": "+70899904013"}
0005432136240	03120B	1795 723296	NATALIYA KUZNECOVA	{"phone": "+70581466209"}
0005432136241	DC554D	1096 786736	VLADIMIR VASILEV	{"email": "v_vasilev.021969@postgrespro.ru", "phone": "+70199405290"}
0005432136242	DC554D	9344 057426	NINA ALEKSEEVA	{"email": "nina-alekseeva-11091972@postgrespro.ru", "phone": "+70023962904"}
0005432136243	4F71F7	9027 438198	TATYANA KUZNECOVA	{"email": "kuznecova-t-091973@postgrespro.ru", "phone": "+70321447790"}
0005432136244	E22F46	6915 392674	IVAN MAKSIMOV	{"phone": "+70454548338"}
0005432136245	E22F46	5771 988770	TATYANA KOROLEVA	{"phone": "+70512108467"}
0005432136246	45905E	3521 859005	NADEZHDA SMIRNOVA	{"phone": "+70247154874"}
0005432136247	BAF61D	0557 169374	IRINA SOKOLOVA	{"email": "i-sokolova.02021977@postgrespro.ru", "phone": "+70471275705"}
0005432136248	190F3F	5397 051859	ALEKSEY AFANASEV	{"phone": "+70742750120"}
0005432136249	E15FD1	3255 965164	IRINA TIMOFEEVA	{"email": "timofeeva_i.121968@postgrespro.ru", "phone": "+70784758682"}
0005432136250	0520C2	4912 725944	ANASTASIYA SMIRNOVA	{"phone": "+70509735899"}
0005432136251	0520C2	2083 212569	YURIY SERGEEV	{"email": "y-sergeev.061979@postgrespro.ru", "phone": "+70069158782"}
0005432136252	2E714D	4923 266913	SVETLANA MAKAROVA	{"email": "makarova-s1967@postgrespro.ru", "phone": "+70997481791"}
0005432136253	2E714D	9046 531331	DMITRIY IVANOV	{"phone": "+70326621616"}
0005432136254	554E85	1471 324158	ALEKSANDRA LOGINOVA	{"email": "aloginova-081968@postgrespro.ru", "phone": "+70873733860"}
0005432136255	554E85	5375 015944	SERGEY KUZNECOV	{"phone": "+70026169875"}
0005432136256	1F6ADC	3646 163809	ALEKSEY SOKOLOV	{"phone": "+70797318267"}
0005432136257	CC14EC	0814 238807	RAFAIL ORLOV	{"phone": "+70455981953"}
0005432136258	CC14EC	8573 724304	IVAN BORISOV	{"phone": "+70803686529"}
0005432136259	DF2AE4	4726 458399	DARYA KOZLOVA	{"email": "darya_kozlova011967@postgrespro.ru", "phone": "+70201376477"}
0005432136260	36096C	2780 598101	VIKTOR VASILEV	{"phone": "+70943024488"}
0005432136261	B8ECDE	8063 116864	YURIY TARASOV	{"phone": "+70070134254"}
0005432136262	1FFEF1	3326 984049	RIMMA VOLKOVA	{"email": "volkova-r_051972@postgrespro.ru", "phone": "+70465454962"}
0005432136263	0DCCF0	7837 491894	VLADIMIR ILIN	{"email": "ilin_vladimir.06071972@postgrespro.ru", "phone": "+70664379957"}
0005432136264	146272	0726 802345	VLADIMIR BARANOV	{"phone": "+70171163913"}
0005432136265	F564F9	2801 209008	DMITRIY FEDOROV	{"phone": "+70779339559"}
0005432136266	F564F9	2817 433942	OLEG KARPOV	{"email": "oleg_karpov_21121978@postgrespro.ru", "phone": "+70860296344"}
0005432136267	AA7135	6024 043208	OLGA DMITRIEVA	{"email": "dmitrieva-o.05021974@postgrespro.ru", "phone": "+70156080607"}
0005432136268	8B59ED	9103 690998	OLGA ZAKHAROVA	{"phone": "+70647718238"}
0005432136269	8B59ED	9486 629948	ALEKSEY KUZMIN	{"email": "kuzminaleksey_25061965@postgrespro.ru", "phone": "+70192769073"}
0005432136270	5B70DD	5071 488327	NIKOLAY STEPANOV	{"phone": "+70086675910"}
0005432136271	D82B13	0276 759305	ALEKSANDRA EGOROVA	{"email": "a_egorova.1978@postgrespro.ru", "phone": "+70060490018"}
0005432136272	D82B13	7963 931487	ELENA ANISIMOVA	{"phone": "+70195523082"}
0005432136273	88C476	6368 649928	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin-121987@postgrespro.ru", "phone": "+70373079112"}
0005432136274	6F8876	9564 379992	NADEZHDA VASILEVA	{"email": "n_vasileva.1971@postgrespro.ru", "phone": "+70015988620"}
0005432136275	51E8E8	5624 655046	VALENTIN KONOVALOV	{"phone": "+70014821259"}
0005432136276	51E8E8	7722 187258	OLGA ANDREEVA	{"email": "o_andreeva_27071974@postgrespro.ru", "phone": "+70586940959"}
0005432136277	51E8E8	7686 524371	SERGEY NIKOLAEV	{"email": "s_nikolaev_12081983@postgrespro.ru", "phone": "+70041204701"}
0005432136278	511F11	6691 367043	ALEKSEY IVANOV	{"email": "ivanov.aleksey1971@postgrespro.ru", "phone": "+70593135398"}
0005432136279	511F11	5801 997609	NATALYA FILIPPOVA	{"phone": "+70228439293"}
0005432136280	897C68	1193 367518	DIANA KUZNECOVA	{"email": "d-kuznecova.04041970@postgrespro.ru", "phone": "+70536570965"}
0005432136281	229784	7060 573044	MAKSIM ZHUKOV	{"email": "maksim.zhukov.04051973@postgrespro.ru", "phone": "+70092311402"}
0005432136282	229784	1691 129518	EVGENIYA SEMENOVA	{"email": "evgeniya.semenova.1969@postgrespro.ru", "phone": "+70743047134"}
0005432136283	DC781B	9770 650196	LYUBOV KULIKOVA	{"email": "kulikoval15021967@postgrespro.ru", "phone": "+70610643015"}
0005432136284	DC781B	2897 012518	ANGELINA IVANOVA	{"phone": "+70848220507"}
0005432136285	DC781B	9143 184975	SERGEY NIKITIN	{"email": "sergey-nikitin_081968@postgrespro.ru", "phone": "+70790974146"}
0005432136286	755428	4529 793282	ALEKSEY STEPANOV	{"email": "a_stepanov_051981@postgrespro.ru", "phone": "+70757103201"}
0005432136287	C5A90C	3654 312341	OLEG ABRAMOV	{"email": "olegabramov_1968@postgrespro.ru", "phone": "+70391343226"}
0005432136288	C5A90C	5271 106902	LYUDMILA NIKOLAEVA	{"email": "l-nikolaeva-05081967@postgrespro.ru", "phone": "+70653051779"}
0005432136289	350B5D	9479 322707	VLADISLAV PAVLOV	{"phone": "+70955755207"}
0005432136290	C77B77	5760 445475	ANATOLIY CHERNOV	{"phone": "+70449631110"}
0005432136291	8B0C93	7512 655565	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov1969@postgrespro.ru", "phone": "+70922322372"}
0005432136292	DC0D06	0475 621721	NIKOLAY BORISOV	{"phone": "+70131993599"}
0005432136293	DC0D06	1466 925391	ANNA GUSEVA	{"email": "a_guseva1975@postgrespro.ru", "phone": "+70267429303"}
0005432136294	B0DEE0	0650 304876	NIKOLAY MARTYNOV	{"email": "martynov.n101971@postgrespro.ru", "phone": "+70688557563"}
0005432136295	54A1B0	1476 241507	VLADISLAV AFANASEV	{"email": "vladislav_afanasev081971@postgrespro.ru", "phone": "+70343205991"}
0005432136296	28B058	7834 174638	NINA POPOVA	{"phone": "+70101576126"}
0005432136297	51ABAB	8057 662553	SERGEY VASILEV	{"email": "vasilevs-15011967@postgrespro.ru", "phone": "+70056512265"}
0005432136298	F9057D	8499 376747	ANDREY SERGEEV	{"email": "andrey_sergeev-1971@postgrespro.ru", "phone": "+70120338886"}
0005432136299	93BB63	1127 747469	ALEKSANDR ZAYCEV	{"email": "zaycev-a_081978@postgrespro.ru", "phone": "+70999929671"}
0005432136300	70CD71	0079 264961	NAILYA KUZNECOVA	{"phone": "+70892748057"}
0005432136301	C170CD	7905 142732	NINA NIKOLAEVA	{"phone": "+70614384033"}
0005432140343	170B81	4452 205416	DARYA ZHUKOVA	{"phone": "+70491874583"}
0005432136302	C170CD	9755 314473	SVETLANA KARPOVA	{"email": "karpovasvetlana_071971@postgrespro.ru", "phone": "+70770619102"}
0005432136303	83D5CE	6016 513390	GRIGORIY IVANOV	{"email": "g.ivanov.051977@postgrespro.ru", "phone": "+70078912104"}
0005432136304	97D05B	4932 202424	ARTEM GERASIMOV	{"email": "artem_gerasimov.25121958@postgrespro.ru", "phone": "+70212224352"}
0005432136305	97D05B	4774 078413	ALEKSANDR ANDREEV	{"phone": "+70125823890"}
0005432136306	A2BD7C	3364 694301	SVETLANA POLYAKOVA	{"email": "spolyakova_071956@postgrespro.ru", "phone": "+70479003631"}
0005432136307	2B7C99	5757 962050	ANDREY NAZAROV	{"phone": "+70345944103"}
0005432136308	5E3C67	3805 353933	NATALYA BOGDANOVA	{"email": "n_bogdanova-20051975@postgrespro.ru", "phone": "+70122637102"}
0005432136309	4DAC52	4407 054936	MARIYA LUKYANOVA	{"phone": "+70242657533"}
0005432136310	C27F05	5560 624130	TATYANA ANDREEVA	{"phone": "+70450176093"}
0005432136311	2EE9AC	3352 842551	NATALYA ANTONOVA	{"phone": "+70326496943"}
0005432136312	CD6AE4	5145 632772	SERGEY BELOV	{"phone": "+70782890070"}
0005432136313	CD6AE4	3576 178463	ANASTASIYA MOROZOVA	{"email": "amorozova.121979@postgrespro.ru", "phone": "+70039605665"}
0005432136314	603593	7550 509921	EGOR POPOV	{"phone": "+70056392962"}
0005432136315	18269F	2192 150160	ANTONINA KUZNECOVA	{"phone": "+70138529151"}
0005432136316	18269F	5368 037048	TATYANA STEPANOVA	{"email": "tstepanova_26061977@postgrespro.ru", "phone": "+70035632407"}
0005432140317	AE1EFD	0400 425235	TATYANA VOLKOVA	{"phone": "+70338665892"}
0005432140298	81FF71	6255 276757	NINA LOGINOVA	{"phone": "+70262620177"}
0005432140299	81FF71	9414 558589	VLADIMIR SHEVCHENKO	{"phone": "+70708918154"}
0005432140300	F8025C	6239 599156	MATVEY MOISEEV	{"email": "matvey-moiseev.21081972@postgrespro.ru", "phone": "+70632633310"}
0005432140301	48B0E8	6152 582331	IRINA NIKOLAEVA	{"phone": "+70444559923"}
0005432140302	E2CC20	5866 669652	ANATOLIY SIDOROV	{"phone": "+70818123518"}
0005432140303	E2CC20	5423 533944	ALEKSANDRA PETROVA	{"email": "petrova-aleksandra_06091975@postgrespro.ru", "phone": "+70703423460"}
0005432140304	55B73A	6310 661224	MAKSIM ZHUKOV	{"phone": "+70938534941"}
0005432140305	89405B	4455 070704	VALENTINA NAUMOVA	{"email": "naumova-v_12121979@postgrespro.ru", "phone": "+70933682099"}
0005432140306	89405B	3063 039502	ANDREY KOZLOV	{"email": "andrey_kozlov081983@postgrespro.ru", "phone": "+70263070939"}
0005432140307	89405B	2883 703391	NATALYA POPOVA	{"email": "popova_n_28121967@postgrespro.ru", "phone": "+70257427470"}
0005432140308	47844E	1545 082981	ANASTASIYA POTAPOVA	{"email": "anastasiyapotapova.021974@postgrespro.ru", "phone": "+70427234299"}
0005432140309	47844E	4968 894340	ELENA ZAYCEVA	{"email": "e-zayceva.1961@postgrespro.ru", "phone": "+70847088211"}
0005432140310	14E1FC	5672 744723	ANTON CHERNOV	{"email": "chernov-anton.1970@postgrespro.ru", "phone": "+70603159284"}
0005432140311	70FFA4	2565 664113	ARTEM NOVIKOV	{"phone": "+70160893015"}
0005432140312	8132EB	0374 166726	VLADIMIR IVANOV	{"email": "vladimir_ivanov_1975@postgrespro.ru", "phone": "+70287987152"}
0005432140313	A2E2BE	3983 330748	TATYANA SMIRNOVA	{"email": "smirnova.tatyana-021971@postgrespro.ru", "phone": "+70740446035"}
0005432140314	72A4CB	3085 232385	KSENIYA TARASOVA	{"email": "ktarasova111976@postgrespro.ru", "phone": "+70194594378"}
0005432140315	B595A2	2553 233884	LYUBOV MOISEEVA	{"phone": "+70831079237"}
0005432140316	7FE038	1399 311129	ALEKSANDR TARASOV	{"email": "a_tarasov_16021968@postgrespro.ru", "phone": "+70092837865"}
0005432140318	8AF472	6746 715110	EKATERINA MIRONOVA	{"phone": "+70770503156"}
0005432140319	EE7D18	8053 369558	SVETLANA ZAKHAROVA	{"email": "zakharova.s.30061975@postgrespro.ru", "phone": "+70636371374"}
0005432140320	31DFD4	0531 062039	DMITRIY DAVYDOV	{"email": "dmitriy.davydov_04081973@postgrespro.ru", "phone": "+70346514135"}
0005432140321	31DFD4	9921 863899	VITALIY IVANOV	{"phone": "+70004176451"}
0005432140322	31DFD4	5687 342308	NIKOLAY KUZMIN	{"email": "nikolaykuzmin_10101970@postgrespro.ru", "phone": "+70777349314"}
0005432140323	F906B0	5725 260560	YURIY ANTONOV	{"phone": "+70620883872"}
0005432140324	F906B0	1880 833229	EVGENIY ZHURAVLEV	{"email": "evgeniy-zhuravlev_14071977@postgrespro.ru", "phone": "+70283205012"}
0005432140325	04E3BC	1216 918088	YULIYA FEDOROVA	{"email": "y.fedorova.17091975@postgrespro.ru", "phone": "+70490171100"}
0005432140326	DFBC40	3942 828515	VYACHESLAV SERGEEV	{"email": "sergeev_vyacheslav_071972@postgrespro.ru", "phone": "+70864825851"}
0005432140327	AE7D5D	9934 641520	NIKITA ALEKSANDROV	{"email": "n_aleksandrov-1991@postgrespro.ru", "phone": "+70993263513"}
0005432140328	30475E	7510 848546	ELENA POPOVA	{"email": "epopova1965@postgrespro.ru", "phone": "+70492968372"}
0005432140329	30475E	9361 476129	NATALYA ALEKSEEVA	{"email": "alekseeva-n_1954@postgrespro.ru", "phone": "+70488127284"}
0005432140330	AAABE5	0825 195565	ALEKSEY KOZLOV	{"phone": "+70442212062"}
0005432140331	AAABE5	7062 954535	DMITRIY MAKSIMOV	{"phone": "+70544669263"}
0005432140332	697087	8735 552364	DARYA PETROVA	{"phone": "+70557247770"}
0005432140333	71E81F	2194 017498	OLGA IVANOVA	{"phone": "+70933074360"}
0005432140334	D6C42A	4942 981126	ILFAT FEDOTOV	{"phone": "+70275519149"}
0005432140335	1AB59A	2742 730506	SERGEY NOVIKOV	{"phone": "+70854247213"}
0005432140336	3490D4	2418 464743	SVETLANA KUZNECOVA	{"email": "kuznecovas.1976@postgrespro.ru", "phone": "+70246246837"}
0005432140337	CC7C74	2716 760524	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila_051968@postgrespro.ru", "phone": "+70813396354"}
0005432140338	CC7C74	9502 595647	OLGA AFANASEVA	{"phone": "+70351080622"}
0005432140339	413A7D	0522 395685	GALINA MASLOVA	{"phone": "+70087003071"}
0005432140340	413A7D	2148 938536	SERGEY BONDARENKO	{"phone": "+70594540424"}
0005432140341	413A7D	7189 647913	ALBERT ZHURAVLEV	{"email": "albertzhuravlev-1975@postgrespro.ru", "phone": "+70306132280"}
0005432140342	01E157	7314 203444	DMITRIY POPOV	{"phone": "+70086065516"}
0005432140344	170B81	8676 806225	PAVEL KOROLEV	{"phone": "+70786424560"}
0005432140345	A04922	4670 655907	ANASTASIYA PAVLOVA	{"email": "a.pavlova-1980@postgrespro.ru", "phone": "+70924964114"}
0005432140346	ABEC61	0117 352917	OLGA ANTONOVA	{"phone": "+70514041006"}
0005432140347	AD2BDB	1672 040376	ELMIRA KUZNECOVA	{"email": "elmira.kuznecova-121974@postgrespro.ru", "phone": "+70036668213"}
0005432140348	CAEE2B	6130 751362	ANDREY KOZLOV	{"email": "kozlov.a29051978@postgrespro.ru", "phone": "+70258425407"}
0005432140349	FD1D31	9765 086316	GALINA KUZNECOVA	{"email": "kuznecova.g041959@postgrespro.ru", "phone": "+70127218321"}
0005432140350	942351	5933 924729	VLADIMIR VASILEV	{"email": "vladimir-vasilev.1963@postgrespro.ru", "phone": "+70573603249"}
0005432140351	A55FFE	6323 179868	ANTONINA PETROVA	{"email": "a-petrova-1970@postgrespro.ru", "phone": "+70203413015"}
0005432140352	A55FFE	5769 306552	RADIK KISELEV	{"email": "radikkiselev_1972@postgrespro.ru", "phone": "+70716021483"}
0005432140353	DDA84A	7437 765748	ELENA KULIKOVA	{"email": "kulikova.elena.12031968@postgrespro.ru", "phone": "+70130901114"}
0005432140354	A793F0	2439 461048	GEORGIY STEPANOV	{"phone": "+70887876026"}
0005432140355	AE8A95	6418 935150	ALEKSANDR BELOV	{"phone": "+70715617854"}
0005432140356	38B131	5298 729897	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov_24071965@postgrespro.ru", "phone": "+70809594616"}
0005432140357	96177B	1563 646221	VLADIMIR ANDREEV	{"phone": "+70885320595"}
0005432140358	96177B	3621 010723	DARYA ORLOVA	{"phone": "+70473017685"}
0005432140359	07CBD7	7077 129987	EKATERINA MARTYNOVA	{"email": "ekaterina.martynova1959@postgrespro.ru", "phone": "+70854895427"}
0005432140360	113A97	9583 201941	VLADISLAV CHERNOV	{"email": "chernov.v041979@postgrespro.ru", "phone": "+70904717812"}
0005432140361	71D4C8	0231 062256	LIDIYA SIDOROVA	{"phone": "+70195939487"}
0005432140362	341E4C	9316 834271	VLADIMIR IVANOV	{"email": "ivanov.vladimir1984@postgrespro.ru", "phone": "+70632372567"}
0005432140363	270566	5467 384697	NATALIYA NAZAROVA	{"email": "nataliya.nazarova1976@postgrespro.ru", "phone": "+70327502889"}
0005432140364	270566	8634 798946	VALENTIN IVANOV	{"phone": "+70671789921"}
0005432140365	EA3FDD	3588 339715	MARIYA GUSEVA	{"email": "mariya.guseva1973@postgrespro.ru", "phone": "+70204264737"}
0005432140366	12D665	0890 565859	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr-1969@postgrespro.ru", "phone": "+70728264934"}
0005432140367	F239F5	0812 056835	SVETLANA MOROZOVA	{"phone": "+70470519013"}
0005432140368	F239F5	1967 421576	NATALYA SOLOVEVA	{"email": "soloveva.n-061973@postgrespro.ru", "phone": "+70363112807"}
0005432140369	B47E93	8777 739242	TATYANA NESTEROVA	{"email": "t_nesterova051971@postgrespro.ru", "phone": "+70999931074"}
0005432140370	B47E93	0127 704110	ALENA SOROKINA	{"phone": "+70663515197"}
0005432140371	A82C58	0324 867962	TAISIYA TIMOFEEVA	{"email": "taisiya_timofeeva021972@postgrespro.ru", "phone": "+70405633529"}
0005432140372	40967C	1159 343694	EKATERINA MAKAROVA	{"phone": "+70984070167"}
0005432140373	40967C	0218 620436	ALEKSEY VOLKOV	{"phone": "+70282431906"}
0005432140374	BB499E	7572 903204	NIKITA PETROV	{"email": "petrov-n-091973@postgrespro.ru", "phone": "+70404230555"}
0005432140375	4379BC	1298 247505	EVGENIY BONDARENKO	{"email": "e.bondarenko.1973@postgrespro.ru", "phone": "+70332537200"}
0005432140376	260696	7423 185558	ALBINA ZAKHAROVA	{"email": "zakharova.a23091963@postgrespro.ru", "phone": "+70668285155"}
0005432140377	58F553	3343 932446	SERGEY BARANOV	{"phone": "+70950055215"}
0005432140378	58F553	2769 971930	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov_24101973@postgrespro.ru", "phone": "+70139972399"}
0005432140379	B34AEE	9048 148602	VALENTINA ERMAKOVA	{"email": "v-ermakova-061970@postgrespro.ru", "phone": "+70064420552"}
0005432140380	B34AEE	2229 861415	KSENIYA KARPOVA	{"email": "k-karpova-20071969@postgrespro.ru", "phone": "+70583102533"}
0005432140381	966306	4956 471114	DMITRIY SCHERBAKOV	{"phone": "+70566962172"}
0005432140382	B74626	8900 839431	IRINA KUZMINA	{"phone": "+70610596164"}
0005432140383	B74626	6885 735250	YURIY KUZNECOV	{"phone": "+70474788959"}
0005432140384	3F8802	4511 691156	KIRILL NOVIKOV	{"email": "kirill-novikov.13011964@postgrespro.ru", "phone": "+70309798076"}
0005432140385	CC649D	9664 297568	SVETLANA DAVYDOVA	{"email": "davydovasvetlana_081984@postgrespro.ru", "phone": "+70341976257"}
0005432140386	7DDA89	8031 056001	ANNA EGOROVA	{"email": "anna.egorova011972@postgrespro.ru", "phone": "+70608257595"}
0005432140387	C5A13D	0367 864858	VERONIKA ZAKHAROVA	{"phone": "+70894266173"}
0005432140388	F28F46	2481 752114	VALENTIN SERGEEV	{"phone": "+70707895601"}
0005432140389	F28F46	1501 997060	ELENA KAZAKOVA	{"email": "kazakovae.1968@postgrespro.ru", "phone": "+70649853990"}
0005432140390	5821BF	7688 731757	MARGARITA FILIPPOVA	{"email": "filippova.m.20051975@postgrespro.ru", "phone": "+70028141733"}
0005432140391	45601E	5082 105727	PETR ZAYCEV	{"email": "zaycev.p-071980@postgrespro.ru", "phone": "+70958011516"}
0005432140392	B65FB5	8165 903362	VLADIMIR KUDRYASHOV	{"phone": "+70137788276"}
0005432140393	2F7AE6	4569 672421	MIKHAIL PAVLOV	{"email": "mikhail_pavlov.011972@postgrespro.ru", "phone": "+70124798701"}
0005432140394	2F7AE6	7999 878224	OLGA PETROVA	{"phone": "+70202817841"}
0005432140395	45793D	4025 299935	POLINA ISAEVA	{"email": "p-isaeva101970@postgrespro.ru", "phone": "+70829567812"}
0005432140396	45793D	7595 701912	ALEKSANDR NOVIKOV	{"email": "novikov_a.031981@postgrespro.ru", "phone": "+70428672357"}
0005432140397	29ED01	6714 562973	MIKHAIL VOLKOV	{"email": "mikhail-volkov091972@postgrespro.ru", "phone": "+70162700823"}
0005432140398	29ED01	1895 094361	YURIY ILIN	{"email": "yuriy-ilin1973@postgrespro.ru", "phone": "+70338877554"}
0005432140399	E5E97F	1348 335427	VLADIMIR MAKAROV	{"phone": "+70669380887"}
0005432140400	E5E97F	2593 257509	VIKTORIYA PETROVA	{"email": "petrova_v.011980@postgrespro.ru", "phone": "+70470765831"}
0005432140401	E0C7FF	3689 750748	LYUBOV KUZNECOVA	{"phone": "+70802423048"}
0005432140402	2AACF6	2807 069956	MIKHAIL KARPOV	{"phone": "+70175980524"}
0005432140403	5E7977	6820 614416	ELENA PETROVA	{"phone": "+70923335472"}
0005432140404	2B356D	5854 969825	VASILIY ZAKHAROV	{"phone": "+70946331645"}
0005432140405	2B356D	9467 320273	ALEKSANDR MIKHAYLOV	{"phone": "+70990628947"}
0005432140406	DE1DA3	2232 973706	KSENIYA PETROVA	{"email": "petrova-kseniya.1960@postgrespro.ru", "phone": "+70945370983"}
0005432140407	DE1DA3	5314 065395	SOFYA DANILOVA	{"phone": "+70144791814"}
0005432140408	DE1DA3	6078 251429	YAROSLAV DAVYDOV	{"phone": "+70929160148"}
0005432140409	94EB44	9740 074295	VLADIMIR ISAEV	{"phone": "+70872318843"}
0005432140410	94EB44	8101 094301	VALENTINA ABRAMOVA	{"email": "valentina.abramova03091977@postgrespro.ru", "phone": "+70569063202"}
0005432140411	65E218	8114 509988	VLADISLAV KUZNECOV	{"email": "vladislav.kuznecov-30061969@postgrespro.ru", "phone": "+70273356678"}
0005432140412	65E218	5398 074908	OLEG ABRAMOV	{"phone": "+70853176027"}
0005432140413	750B60	8532 296807	YAROSLAV NOVIKOV	{"email": "y.novikov051967@postgrespro.ru", "phone": "+70760461180"}
0005432140414	750B60	0622 915474	EVGENIY NIKITIN	{"email": "enikitin101963@postgrespro.ru", "phone": "+70159787136"}
0005432140415	147561	3230 617650	VALENTINA ISAEVA	{"email": "isaevavalentina-031981@postgrespro.ru", "phone": "+70765014717"}
0005432140416	CC7962	4704 150729	ANASTASIYA MIRONOVA	{"email": "anastasiya-mironova.1970@postgrespro.ru", "phone": "+70085555514"}
0005432140417	462B7D	6650 155213	VYACHESLAV KOROLEV	{"email": "vkorolev.1984@postgrespro.ru", "phone": "+70830686020"}
0005432140418	3AEC02	2556 700281	ANDREY MOROZOV	{"email": "amorozov_1977@postgrespro.ru", "phone": "+70226582819"}
0005432140419	3AEC02	4421 186370	EVGENIYA KONOVALOVA	{"email": "evgeniya-konovalova_19091970@postgrespro.ru", "phone": "+70520213657"}
0005432140420	3AEC02	5337 736551	ANATOLIY PETROV	{"phone": "+70486243844"}
0005432140421	1B23AB	5055 110390	DMITRIY DENISOV	{"email": "dmitriydenisov_121970@postgrespro.ru", "phone": "+70752642351"}
0005432140422	5E8651	9726 734732	ANNA STEPANOVA	{"phone": "+70951788500"}
0005432140423	F5B7DB	4154 342469	YULIYA KUZNECOVA	{"phone": "+70527244811"}
0005432140424	51C8C8	8371 547240	MAKSIM GERASIMOV	{"phone": "+70072361879"}
0005432140425	2C6F6A	8998 646697	LILIYA FROLOVA	{"email": "lfrolova1980@postgrespro.ru", "phone": "+70670770418"}
0005432140426	71FF94	6310 574823	ANATOLIY ALEKSEEV	{"email": "a.alekseev-08021974@postgrespro.ru", "phone": "+70952465712"}
0005432140483	5FE8D6	0218 881856	EVGENIY ANTONOV	{"phone": "+70261068971"}
0005432140484	4094E8	3921 053235	VALENTIN ORLOV	{"phone": "+70071103282"}
0005432140427	71FF94	5291 013914	ANASTASIYA ILINA	{"email": "anastasiya.ilina.1980@postgrespro.ru", "phone": "+70110784436"}
0005432140428	A200CE	9893 518663	SVETLANA MOROZOVA	{"phone": "+70886531501"}
0005432140429	33680E	3578 462896	IVAN TIMOFEEV	{"email": "timofeev_ivan.1967@postgrespro.ru", "phone": "+70068302547"}
0005432140430	EA858C	3961 587890	DARYA YUDINA	{"phone": "+70233544688"}
0005432140431	71B684	1544 378237	ALEKSANDR VOLKOV	{"phone": "+70348082108"}
0005432140432	71B684	5705 565257	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev-23111973@postgrespro.ru", "phone": "+70885087766"}
0005432140433	78EC74	8729 998654	ELENA KUZNECOVA	{"phone": "+70278806363"}
0005432140434	85D6F9	3571 890475	ANDREY VLASOV	{"email": "vlasov-a031979@postgrespro.ru", "phone": "+70348999843"}
0005432140435	A6DFAB	0339 646801	TATYANA NAUMOVA	{"email": "naumova.tatyana_061970@postgrespro.ru", "phone": "+70701130601"}
0005432140436	5E96CA	9876 477774	NIKOLAY ORLOV	{"phone": "+70650369238"}
0005432140437	71485C	0231 601842	NIKOLAY SCHERBAKOV	{"email": "nikolayscherbakov_121986@postgrespro.ru", "phone": "+70451471558"}
0005432140438	71485C	6412 173994	NADEZHDA IVANOVA	{"phone": "+70135447543"}
0005432140439	BFA9AA	1622 458781	ELENA MIRONOVA	{"phone": "+70396412509"}
0005432140440	BFA9AA	1445 883551	ANTON FEDOROV	{"email": "fedorov.a21111972@postgrespro.ru", "phone": "+70336641900"}
0005432140441	F96BB4	9285 398820	EVGENIY ZAKHAROV	{"email": "zakharov-e-1982@postgrespro.ru", "phone": "+70106475211"}
0005432140442	F96BB4	7146 502081	SAMIR MOISEEV	{"email": "samir.moiseev12091962@postgrespro.ru", "phone": "+70353385011"}
0005432140443	577676	3688 489851	ANATOLIY VOLKOV	{"phone": "+70565004441"}
0005432140444	577676	4649 420735	TATYANA FILIPPOVA	{"phone": "+70376950585"}
0005432140445	8B3707	6524 033083	RUSLAN ZAKHAROV	{"email": "zakharov-r.1982@postgrespro.ru", "phone": "+70841955694"}
0005432140446	8B3707	7385 798191	ANTONINA KISELEVA	{"email": "kiseleva-antonina26111970@postgrespro.ru", "phone": "+70106747034"}
0005432140447	0A076A	7029 646386	VLADIMIR SMIRNOV	{"phone": "+70714471952"}
0005432140448	7975E3	0013 644271	MARIYA POLYAKOVA	{"email": "mariya_polyakova_041978@postgrespro.ru", "phone": "+70496436873"}
0005432140449	55BDB9	3917 324057	GALINA MELNIKOVA	{"phone": "+70805849238"}
0005432140450	55BDB9	8244 371032	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir-121978@postgrespro.ru", "phone": "+70322218441"}
0005432140451	B0E661	1274 249787	NATALYA TARASOVA	{"phone": "+70682014490"}
0005432140452	B0E661	2426 689537	VALERIY POPOV	{"email": "popovvaleriy13111977@postgrespro.ru", "phone": "+70460573259"}
0005432140453	8522DF	0579 592479	ANGELINA SCHERBAKOVA	{"email": "scherbakova-angelina.091966@postgrespro.ru", "phone": "+70084963172"}
0005432140454	5BD047	0167 685964	VLADIMIR IVANOV	{"email": "ivanov-vladimir16031960@postgrespro.ru", "phone": "+70442460940"}
0005432140455	0C22CB	2824 242123	RENAT KUZMIN	{"email": "renatkuzmin_23061982@postgrespro.ru", "phone": "+70050855072"}
0005432140456	87868E	0727 388234	NATALYA NESTEROVA	{"phone": "+70087111135"}
0005432140457	87868E	9714 803350	PAVEL KUZNECOV	{"email": "p_kuznecov.1970@postgrespro.ru", "phone": "+70118414301"}
0005432140458	365FB9	9736 584559	LYUBOV MAKAROVA	{"email": "l-makarova.041980@postgrespro.ru", "phone": "+70875392212"}
0005432140459	365FB9	3858 915279	VITALIY SERGEEV	{"phone": "+70903186857"}
0005432140460	7A4F41	5103 639158	VIKTORIYA POPOVA	{"phone": "+70021830154"}
0005432140461	DF4498	2570 998004	NINA FROLOVA	{"email": "frolova-nina-1974@postgrespro.ru", "phone": "+70558027810"}
0005432140462	DF4498	6443 933465	MARINA SOROKINA	{"email": "marina_sorokina_1978@postgrespro.ru", "phone": "+70446625632"}
0005432140463	544DA5	5786 632112	NIKOLAY KOZLOV	{"phone": "+70372272867"}
0005432140464	544DA5	2048 456913	ALEKSEY SERGEEV	{"email": "alekseysergeev.1973@postgrespro.ru", "phone": "+70132001614"}
0005432140465	467B70	4063 041116	VADIM ORLOV	{"phone": "+70397277137"}
0005432140466	4C7094	3638 583251	VLADIMIR MOISEEV	{"phone": "+70852868581"}
0005432140467	311092	3741 912793	VALENTINA POPOVA	{"email": "vpopova.1974@postgrespro.ru", "phone": "+70079301703"}
0005432140468	01CFBD	7495 113941	LYUDMILA MAKAROVA	{"phone": "+70826112763"}
0005432140469	2CDC14	3495 214579	NURIYA IVANOVA	{"phone": "+70309546410"}
0005432140470	EC8CD8	1040 325744	DANIIL IVANOV	{"phone": "+70358526555"}
0005432140471	EC8CD8	2498 762577	EKATERINA ISAEVA	{"email": "isaevaekaterina_121968@postgrespro.ru", "phone": "+70465283316"}
0005432140472	EC8CD8	8070 846264	YURIY STEPANOV	{"phone": "+70106865042"}
0005432140473	DEE97D	7546 063630	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr_1972@postgrespro.ru", "phone": "+70821097864"}
0005432140474	2919BE	7602 095845	EVDOKIYA LEBEDEVA	{"phone": "+70165950594"}
0005432140475	2919BE	2459 190125	NIKITA MOISEEV	{"phone": "+70540085770"}
0005432140476	908423	6059 775205	ANNA EFIMOVA	{"phone": "+70635524040"}
0005432140477	769B9E	4181 132707	ELENA AFANASEVA	{"email": "afanaseva-e-1966@postgrespro.ru", "phone": "+70066831123"}
0005432140478	468156	2076 728398	GENNADIY KUZMIN	{"phone": "+70642367702"}
0005432140479	40FA6C	3842 511174	ANDREY GRIGOREV	{"email": "grigorev_andrey10041965@postgrespro.ru", "phone": "+70043014256"}
0005432140480	6F8FD4	3315 663819	VYACHESLAV ANTONOV	{"phone": "+70036010588"}
0005432140481	7F8052	5750 600637	ELENA IVANOVA	{"email": "elena_ivanova_1973@postgrespro.ru", "phone": "+70375702190"}
0005432140482	39D2BA	2967 977266	ANATOLIY KUDRYASHOV	{"email": "anatoliykudryashov_1964@postgrespro.ru", "phone": "+70569993583"}
0005432140485	4094E8	2349 898825	FAIL KUZMIN	{"phone": "+70857770094"}
0005432140486	AFA629	3487 629812	SERGEY TIKHONOV	{"email": "tikhonov_sergey_041971@postgrespro.ru", "phone": "+70628570815"}
0005432140487	AFA629	8172 739138	ALEKSEY PAVLOV	{"email": "pavlov_aleksey_1960@postgrespro.ru", "phone": "+70055453131"}
0005432140488	3A8532	0576 412936	ALEKSANDR YAKOVLEV	{"phone": "+70473058942"}
0005432140489	5B2DC6	0970 241630	SERGEY ROMANOV	{"email": "sergey-romanov.1962@postgrespro.ru", "phone": "+70554016141"}
0005432140490	D4FC23	9137 621681	VALENTINA KUZNECOVA	{"email": "v.kuznecova_1975@postgrespro.ru", "phone": "+70193627707"}
0005432140491	D905B0	2793 423531	VASILIY SOLOVEV	{"phone": "+70313668551"}
0005432140492	70115D	4610 707817	MARIYA POLYAKOVA	{"email": "polyakova_mariya_05081959@postgrespro.ru", "phone": "+70326139227"}
0005432140493	0E1F15	6101 194278	NATALYA FILATOVA	{"email": "filatovan-1979@postgrespro.ru", "phone": "+70275006744"}
0005432140494	7027F9	7211 590831	ANASTASIYA ZOTOVA	{"phone": "+70127339842"}
0005432140495	AF7AE5	8909 069431	NATALYA FOMINA	{"email": "fomina-natalya.021964@postgrespro.ru", "phone": "+70863674966"}
0005432140496	6F3A0F	4084 807557	TATYANA IVANOVA	{"email": "tivanova-041973@postgrespro.ru", "phone": "+70700008420"}
0005432140497	5122D5	9752 210188	VLADIMIR IVANOV	{"email": "vivanov_1982@postgrespro.ru", "phone": "+70869618884"}
0005432140498	5122D5	5798 926869	NIKOLAY SEMENOV	{"email": "n-semenov_27061970@postgrespro.ru", "phone": "+70790681218"}
0005432140499	157BF5	8904 384115	ANNA POPOVA	{"email": "apopova.031988@postgrespro.ru", "phone": "+70403805852"}
0005432140500	157BF5	0016 280529	ALEKSANDR KUZNECOV	{"phone": "+70707378899"}
0005432140501	A0CA29	2506 139540	RAZIYA ZOTOVA	{"email": "zotovaraziya.011968@postgrespro.ru", "phone": "+70697292727"}
0005432140502	A0CA29	4798 701197	ANDREY GERASIMOV	{"email": "gerasimov_andrey.091983@postgrespro.ru", "phone": "+70777053087"}
0005432140503	321A04	3634 431916	LYUBOV FEDOROVA	{"email": "lyubov_fedorova_22071963@postgrespro.ru", "phone": "+70180541925"}
0005432140504	CED51D	7177 963424	MARIYA KOMAROVA	{"phone": "+70483639943"}
0005432140505	CED51D	4191 220959	VALENTINA KOZLOVA	{"phone": "+70147993047"}
0005432140506	CED51D	2624 125978	IVAN FEDOTOV	{"email": "ifedotov041977@postgrespro.ru", "phone": "+70441521212"}
0005432140507	2BE8A7	5606 019243	SERGEY PAVLOV	{"phone": "+70223141419"}
0005432140508	2BE8A7	9086 920966	VIKTOR SOKOLOV	{"phone": "+70087382745"}
0005432140509	3D1DD7	6417 782766	KLAVDIYA PETROVA	{"email": "kpetrova-1970@postgrespro.ru", "phone": "+70895450556"}
0005432140510	D9E2B8	3414 810066	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr.031973@postgrespro.ru", "phone": "+70316363091"}
0005432140511	D9E2B8	2006 406077	VIKTOR BORISOV	{"phone": "+70763982194"}
0005432140512	47BB73	8523 554609	ALEKSEY DMITRIEV	{"email": "aleksey_dmitriev_10011966@postgrespro.ru", "phone": "+70671898142"}
0005432140513	BA2A78	8495 906400	POLINA AFANASEVA	{"email": "p.afanaseva.1986@postgrespro.ru", "phone": "+70051553665"}
0005432140514	A40039	1246 816040	RUSTAM KUZNECOV	{"phone": "+70967261109"}
0005432140515	68D4EF	5942 238146	NAILYA ANTONOVA	{"phone": "+70835451656"}
0005432140516	39A8C2	8706 559569	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov_14111975@postgrespro.ru", "phone": "+70502699076"}
0005432140517	39A8C2	5788 287103	OLGA BELOVA	{"phone": "+70780083725"}
0005432140518	04B98A	4470 722890	ANDREY ROMANOV	{"email": "a-romanov.1980@postgrespro.ru", "phone": "+70168314479"}
0005432140519	04B98A	4788 804741	IVAN KUZMIN	{"email": "i_kuzmin-051973@postgrespro.ru", "phone": "+70799626808"}
0005432140520	04B98A	8369 132537	KRISTINA EFREMOVA	{"email": "efremova-k071970@postgrespro.ru", "phone": "+70683029624"}
0005432140521	0F3E14	2101 006558	SERGEY GAVRILOV	{"email": "gavrilov-sergey1969@postgrespro.ru", "phone": "+70526508412"}
0005432140522	BAAA4E	3396 706310	ALEKSANDR SOLOVEV	{"phone": "+70866325032"}
0005432140523	BAAA4E	8297 566833	ELENA KOMAROVA	{"phone": "+70738237845"}
0005432140524	19A216	8736 889883	TAMARA ANISIMOVA	{"email": "tamara_anisimova-031969@postgrespro.ru", "phone": "+70780390570"}
0005432140525	19A216	0831 364369	VALENTINA FROLOVA	{"email": "frolovav-1975@postgrespro.ru", "phone": "+70070951565"}
0005432140526	631745	0259 239478	IGOR ANDREEV	{"email": "andreev.igor-111969@postgrespro.ru", "phone": "+70517830171"}
0005432140527	FA4CB3	1190 754456	LYUBOV ERMAKOVA	{"phone": "+70653572386"}
0005432140528	6A4BB2	6568 766898	ANNA ABRAMOVA	{"email": "aabramova25071984@postgrespro.ru", "phone": "+70031542037"}
0005432140529	6A4BB2	7098 153849	GULNARA KOROLEVA	{"phone": "+70123347320"}
0005432140530	748DF8	4816 687800	ZINAIDA KUZNECOVA	{"phone": "+70353404202"}
0005432140531	748DF8	3608 910490	VERA KOZLOVA	{"phone": "+70932072414"}
0005432140532	4660D7	3781 395436	OLGA KARPOVA	{"phone": "+70405319527"}
0005432140533	07C0E8	6480 284176	ALEKSANDR KRASNOV	{"phone": "+70803238574"}
0005432140534	0F4C37	0095 455956	KRISTINA ANISIMOVA	{"phone": "+70425017136"}
0005432140535	975E48	3591 464640	IGOR MOROZOV	{"email": "morozov-i031979@postgrespro.ru", "phone": "+70329182486"}
0005432140536	EA4EBB	1581 706740	NATALYA TITOVA	{"email": "ntitova-31031966@postgrespro.ru", "phone": "+70600000316"}
0005432140537	8515C5	6496 219210	MARINA FROLOVA	{"email": "frolova.m-23021965@postgrespro.ru", "phone": "+70866574403"}
0005432140538	CAD864	6314 030079	VLADIMIR FROLOV	{"email": "frolov-v_1976@postgrespro.ru", "phone": "+70873654211"}
0005432140539	CAD864	8416 469639	MIKHAIL FEDOROV	{"phone": "+70341082992"}
0005432140540	2DF530	4363 009324	ANDREY SMIRNOV	{"email": "smirnov_a.081967@postgrespro.ru", "phone": "+70374348023"}
0005432140541	C8123F	0352 691889	OLEG GUSEV	{"phone": "+70000688272"}
0005432140542	2F024D	8730 689756	VIKTOR SOROKIN	{"phone": "+70168856098"}
0005432140543	FD8739	7177 544080	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov_1983@postgrespro.ru", "phone": "+70207897867"}
0005432140544	A91C61	7994 144494	DMITRIY SEMENOV	{"phone": "+70502919204"}
0005432140545	8BB108	0670 043068	ROMAN IVANOV	{"phone": "+70147332564"}
0005432140546	8BB108	3652 500896	SERGEY EGOROV	{"phone": "+70172809473"}
0005432140547	DB5E74	0260 974823	ALEKSANDRA MOROZOVA	{"phone": "+70177678341"}
0005432140548	DB5E74	6798 919475	ANTONINA FEDOROVA	{"phone": "+70192884809"}
0005432140549	43CAD1	1062 922437	VALENTINA SOKOLOVA	{"phone": "+70570897613"}
0005432140550	43CAD1	4880 306730	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov1976@postgrespro.ru", "phone": "+70399661591"}
0005432140551	AA91A9	7845 765325	MARIYA KOROLEVA	{"phone": "+70475243300"}
0005432140552	AA91A9	6007 332687	EKATERINA ALEKSANDROVA	{"email": "e.aleksandrova-101973@postgrespro.ru", "phone": "+70707021375"}
0005432140553	C1CCB1	0442 351375	NIKOLAY NIKITIN	{"email": "nikitin_nikolay27101963@postgrespro.ru", "phone": "+70315838854"}
0005432140554	C1CCB1	7708 791964	PAVEL KARPOV	{"email": "pavel_karpov.1960@postgrespro.ru", "phone": "+70199960124"}
0005432140555	98D049	6668 535168	NIKOLAY BARANOV	{"email": "n.baranov_1968@postgrespro.ru", "phone": "+70499648887"}
0005432140556	B475F4	7845 528390	NIKOLAY EGOROV	{"email": "nikolayegorov.101973@postgrespro.ru", "phone": "+70758460923"}
0005432140557	52FC7D	8757 126492	ELENA PETROVA	{"phone": "+70454240475"}
0005432140558	E0D322	4552 558258	ELEONORA BORISOVA	{"phone": "+70718060135"}
0005432140559	E0D322	7921 131499	ALEKSANDR ANDREEV	{"phone": "+70878882405"}
0005432140560	2034C6	1099 822405	PETR POPOV	{"email": "popov.petr1971@postgrespro.ru", "phone": "+70851085129"}
0005432140561	F38AFF	3319 959763	TATYANA FILIPPOVA	{"phone": "+70077050170"}
0005432140562	C3377A	8000 480219	EKATERINA KUZNECOVA	{"email": "e-kuznecova-06121975@postgrespro.ru", "phone": "+70374237762"}
0005432140563	C3377A	2423 508137	SVETLANA MIRONOVA	{"email": "svetlana_mironova_1967@postgrespro.ru", "phone": "+70364510234"}
0005432140564	6D2BB3	4264 513111	SERGEY KUDRYASHOV	{"phone": "+70712120477"}
0005432140565	6D2BB3	4215 863858	TATYANA ANISIMOVA	{"phone": "+70664070893"}
0005432140566	4EA163	8859 852814	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_121981@postgrespro.ru", "phone": "+70310772481"}
0005432140567	4EA163	7067 077773	MIKHAIL SEMENOV	{"email": "semenov-mikhail-1969@postgrespro.ru", "phone": "+70976134601"}
0005432140568	D28D50	7780 297505	BORIS MOROZOV	{"email": "morozov.boris.29031960@postgrespro.ru", "phone": "+70414149679"}
0005432140569	F3D7C3	8095 356790	RINAT SAVELEV	{"phone": "+70640362324"}
0005432140570	7CF1E1	6996 119308	KAMIL MIKHAYLOV	{"phone": "+70415803203"}
0005432140571	7CF1E1	4816 135535	TATYANA ZHUKOVA	{"phone": "+70370356248"}
0005432140572	7CF1E1	2292 390935	ANDREY SHEVCHENKO	{"phone": "+70926895062"}
0005432140573	14B712	6030 896325	VARVARA DAVYDOVA	{"phone": "+70907572158"}
0005432140574	A177CE	1910 002925	OLGA TIMOFEEVA	{"email": "timofeeva.o24021970@postgrespro.ru", "phone": "+70522501237"}
0005432140575	A177CE	0443 434185	LEONID IVANOV	{"email": "ivanov.leonid.091987@postgrespro.ru", "phone": "+70115472777"}
0005432140576	4DA005	7524 767136	EKATERINA ANTONOVA	{"email": "e_antonova.101978@postgrespro.ru", "phone": "+70570094498"}
0005432140577	49EA8F	0236 953956	VALENTIN MIKHAYLOV	{"phone": "+70341514890"}
0005432140578	49EA8F	0380 944562	DMITRIY NOVIKOV	{"email": "novikovdmitriy.071972@postgrespro.ru", "phone": "+70440179850"}
0005432140579	C5B3AA	7661 206548	VLADIMIR GORBUNOV	{"phone": "+70409004402"}
0005432140580	CEC863	3389 375534	SERGEY NIKOLAEV	{"phone": "+70826493437"}
0005432140581	8AFF0E	5209 568349	TATYANA FILIPPOVA	{"phone": "+70733122678"}
0005432140582	16E722	8702 225654	NADEZHDA STEPANOVA	{"email": "stepanova.n_17101980@postgrespro.ru", "phone": "+70211882591"}
0005432140583	664897	5503 000315	TAKHIR VLASOV	{"email": "takhir_vlasov_1981@postgrespro.ru", "phone": "+70963609204"}
0005432140584	664897	9307 822024	LARISA BORISOVA	{"email": "l-borisova.041973@postgrespro.ru", "phone": "+70270948073"}
0005432140585	664897	3760 087064	LYUBOV KONOVALOVA	{"email": "lyubovkonovalova-04081983@postgrespro.ru", "phone": "+70779045671"}
0005432140586	7AABB4	3060 812226	ARINA DAVYDOVA	{"phone": "+70290036808"}
0005432140587	DCB649	8402 645178	MIKHAIL CHERNOV	{"phone": "+70268757279"}
0005432140588	E85684	5419 329879	NIKOLAY VLASOV	{"email": "nvlasov071961@postgrespro.ru", "phone": "+70441091506"}
0005432140589	DB913D	0830 951347	GENNADIY PAVLOV	{"phone": "+70092725415"}
0005432140590	DB913D	8871 998524	IVAN MAKAROV	{"email": "makarov.ivan-19021971@postgrespro.ru", "phone": "+70261542298"}
0005432140591	FD2020	7169 601479	ARTEM SOKOLOV	{"email": "artem-sokolov_1973@postgrespro.ru", "phone": "+70780198773"}
0005432140592	FD2020	0564 040296	SERGEY SOLOVEV	{"email": "s-solovev-19071978@postgrespro.ru", "phone": "+70596322305"}
0005432140593	35EBA3	8634 671902	VLADIMIR KONOVALOV	{"email": "v.konovalov_1967@postgrespro.ru", "phone": "+70554991076"}
0005432140594	9B5CE4	9139 268403	KRISTINA MEDVEDEVA	{"email": "kristina_medvedeva011982@postgrespro.ru", "phone": "+70217322236"}
0005432140595	7C51AF	7439 175518	NADEZHDA RODIONOVA	{"email": "rodionova_nadezhda-051976@postgrespro.ru", "phone": "+70319809705"}
0005432140596	56DE98	8621 185136	ANDREY ZHURAVLEV	{"email": "andreyzhuravlev_24111967@postgrespro.ru", "phone": "+70277964560"}
0005432140597	414288	5118 283109	MARIYA BELOVA	{"email": "mariyabelova29041972@postgrespro.ru", "phone": "+70538866849"}
0005432140598	57B656	7567 411151	GRIGORIY SERGEEV	{"email": "sergeevgrigoriy23051982@postgrespro.ru", "phone": "+70349426298"}
0005432140599	57B656	3605 408901	NADEZHDA EFIMOVA	{"email": "nefimova111964@postgrespro.ru", "phone": "+70349536000"}
0005432140600	AED585	9449 387458	VALERIY ZAYCEV	{"phone": "+70811339917"}
0005432140601	F25A38	5424 405696	ILYA RODIONOV	{"email": "i_rodionov_091972@postgrespro.ru", "phone": "+70326510614"}
0005432140602	0D1B4D	1118 133412	MARGARITA POPOVA	{"email": "popova-m101962@postgrespro.ru", "phone": "+70269123656"}
0005432140603	3C103D	7384 164036	VLADIMIR BARANOV	{"email": "baranov-vladimir1971@postgrespro.ru", "phone": "+70620881697"}
0005432140604	3C103D	7631 597540	VALERIY VASILEV	{"phone": "+70486471193"}
0005432140605	CED434	2061 817484	STEPAN NAZAROV	{"email": "s-nazarov.081965@postgrespro.ru", "phone": "+70735760129"}
0005432140606	B6E66C	3319 029748	VERA KUZNECOVA	{"phone": "+70178574632"}
0005432140607	21367B	7478 114859	LIDIYA TITOVA	{"phone": "+70537682765"}
0005432140608	DB42F6	6957 105040	LILIYA NIKITINA	{"phone": "+70054132843"}
0005432140609	95E09C	6954 317069	LYUBOV PAVLOVA	{"phone": "+70131262053"}
0005432140610	CF6571	6479 576024	NATALYA FADEEVA	{"phone": "+70267601339"}
0005432140611	CF6571	0577 787249	ILYA TIMOFEEV	{"email": "timofeev.i.1973@postgrespro.ru", "phone": "+70932463589"}
0005432140612	CF6571	4631 847461	VALENTINA NIKITINA	{"email": "valentina-nikitina11041968@postgrespro.ru", "phone": "+70768854394"}
0005432140613	95D031	7747 535429	ELENA NAZAROVA	{"email": "nazarova_elena_061983@postgrespro.ru", "phone": "+70478587487"}
0005432140614	1834A6	1582 415162	ELIZAVETA ISAEVA	{"email": "elizavetaisaeva_1978@postgrespro.ru", "phone": "+70959337254"}
0005432140615	1834A6	7871 531339	TATYANA POPOVA	{"phone": "+70754657875"}
0005432140616	810984	9666 158305	ALEKSANDRA SEMENOVA	{"phone": "+70885406391"}
0005432140617	810984	6562 436799	NIKOLAY FEDOROV	{"email": "n-fedorov091971@postgrespro.ru", "phone": "+70549581602"}
0005432140618	AA41B2	8714 242379	ALEKSANDR PAVLOV	{"phone": "+70896058429"}
0005432140619	5E7244	6027 812978	GALINA VLASOVA	{"phone": "+70905363078"}
0005432140620	5E7244	4610 162818	ELENA KOZLOVA	{"email": "elena_kozlova_1964@postgrespro.ru", "phone": "+70675465972"}
0005432140621	C14548	5072 385167	EVGENIY MAKAROV	{"phone": "+70099607862"}
0005432140622	5B4A46	2952 275656	YANA EGOROVA	{"phone": "+70116439889"}
0005432140623	36764C	1386 833494	RITA DMITRIEVA	{"email": "dmitrieva.r.30041979@postgrespro.ru", "phone": "+70637425642"}
0005432140624	9E05D0	2307 954593	EVGENIYA LAZAREVA	{"phone": "+70514003292"}
0005432140625	9E05D0	7348 225281	LYUBOV FOMINA	{"email": "lyubov_fomina.1973@postgrespro.ru", "phone": "+70925383235"}
0005432140626	60F335	1840 862779	OLGA STEPANOVA	{"phone": "+70600190290"}
0005432140627	60F335	4019 244594	DMITRIY FILIPPOV	{"phone": "+70106724420"}
0005432140628	89EED2	0126 941228	LILIYA NIKITINA	{"phone": "+70254178299"}
0005432140629	C7214C	8061 471216	SVETLANA KUZNECOVA	{"phone": "+70268898342"}
0005432140630	22542D	4238 579137	VIKTOR MATVEEV	{"phone": "+70549224340"}
0005432140631	22542D	6911 836820	TATYANA ISAEVA	{"email": "isaeva_tatyana-061971@postgrespro.ru", "phone": "+70822382641"}
0005432140632	FE4813	1787 608249	ALEKSANDRA ANISIMOVA	{"phone": "+70734513304"}
0005432140633	3ABE5C	8839 708968	VLADIMIR ANDREEV	{"email": "andreev-v011969@postgrespro.ru", "phone": "+70563747582"}
0005432140634	BD7AB6	9617 287810	VERA ABRAMOVA	{"phone": "+70827546272"}
0005432140635	46CBFE	3827 518800	MIKHAIL NIKITIN	{"phone": "+70783373854"}
0005432140636	46CBFE	4086 511145	EGOR SERGEEV	{"email": "sergeev_e_19091971@postgrespro.ru", "phone": "+70147197194"}
0005432140637	8B7428	9739 513547	ANDREY ANDREEV	{"phone": "+70880407519"}
0005432140638	E0DCCF	2201 328415	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr.071975@postgrespro.ru", "phone": "+70727149849"}
0005432140639	65510C	9354 168455	SERGEY ABRAMOV	{"phone": "+70303981959"}
0005432140640	65510C	8637 313540	GALINA MELNIKOVA	{"phone": "+70492152762"}
0005432140641	62C67C	8319 276390	ALEKSANDR MIRONOV	{"phone": "+70726814934"}
0005432140642	D24F96	5768 637711	LYUDMILA NESTEROVA	{"phone": "+70708540322"}
0005432140643	E09767	1600 503126	LYUDMILA KUZNECOVA	{"phone": "+70630452891"}
0005432140644	E09767	7669 586920	ANTONINA FADEEVA	{"phone": "+70759427893"}
0005432140645	E09767	8003 304660	ARTUR KUZNECOV	{"email": "kuznecov-a_16071969@postgrespro.ru", "phone": "+70727732975"}
0005432140646	5F7C79	2236 199002	OLGA NIKIFOROVA	{"email": "nikiforova_olga_1965@postgrespro.ru", "phone": "+70801527832"}
0005432140647	1BE2C6	5578 687143	DANILA KOZLOV	{"email": "kozlov-danila111971@postgrespro.ru", "phone": "+70888123614"}
0005432140648	A706F1	8211 690208	TATYANA NOVIKOVA	{"phone": "+70312063970"}
0005432140649	BC5168	6261 089737	IGOR ALEKSEEV	{"email": "alekseev_i-25041964@postgrespro.ru", "phone": "+70302566074"}
0005432140650	BC5168	7060 808664	VALENTINA MAKAROVA	{"phone": "+70646906930"}
0005432140651	144377	8220 987091	PETR PAVLOV	{"phone": "+70399244380"}
0005432140652	144377	0296 471122	TATYANA VOROBEVA	{"email": "tatyana_vorobeva.121980@postgrespro.ru", "phone": "+70644284973"}
0005432140653	900ED2	5794 341018	ELENA KRASNOVA	{"phone": "+70528029762"}
0005432140654	4C02C0	5167 859765	VALENTINA NAZAROVA	{"email": "nazarova-valentina-021977@postgrespro.ru", "phone": "+70472415691"}
0005432140655	45DCCC	8969 363497	EDUARD IVANOV	{"email": "e.ivanov.101974@postgrespro.ru", "phone": "+70934727443"}
0005432140656	23C24F	4910 310566	IVAN ALEKSEEV	{"email": "alekseev-i_04101983@postgrespro.ru", "phone": "+70423150398"}
0005432140657	04669C	9837 871579	ANNA NOVIKOVA	{"phone": "+70874278715"}
0005432140658	2FF224	0924 312909	VLADIMIR SMIRNOV	{"email": "smirnovvladimir.1980@postgrespro.ru", "phone": "+70992875623"}
0005432140659	9AE1A5	8510 330320	VALENTINA IVANOVA	{"phone": "+70903618662"}
0005432140660	0C9809	5939 210832	ELENA DAVYDOVA	{"phone": "+70646460685"}
0005432140661	3FF64B	5028 653117	MAKSIM SIDOROV	{"email": "m_sidorov101982@postgrespro.ru", "phone": "+70457605148"}
0005432140662	14D9B3	0707 863767	PETR VLASOV	{"phone": "+70374292256"}
0005432140663	A5C98E	0804 016251	ZOYA FROLOVA	{"email": "zfrolova_28081968@postgrespro.ru", "phone": "+70497800405"}
0005432140664	A5C98E	4149 037552	GLEB KUDRYASHOV	{"phone": "+70118559245"}
0005432140665	A5C98E	7386 803142	GALINA MEDVEDEVA	{"phone": "+70513399007"}
0005432140666	7E2106	8330 345861	LYUDMILA GAVRILOVA	{"email": "lyudmilagavrilova_29021964@postgrespro.ru", "phone": "+70453828105"}
0005432140667	7E2106	7650 296367	DANILA TIKHONOV	{"email": "danila.tikhonov121979@postgrespro.ru", "phone": "+70856371787"}
0005432140668	655ABA	0738 403891	VITALIY ANDREEV	{"email": "andreev-v-081968@postgrespro.ru", "phone": "+70170616228"}
0005432140669	77E373	4225 370554	ANATOLIY PAVLOV	{"email": "pavlov-a-1966@postgrespro.ru", "phone": "+70321789602"}
0005432140670	03A96B	2833 456580	NATALYA KOROLEVA	{"email": "natalyakoroleva021988@postgrespro.ru", "phone": "+70458610963"}
0005432140671	03A96B	0241 214628	DMITRIY VASILEV	{"phone": "+70799494770"}
0005432140672	0E2E01	7443 769337	NIKOLAY BONDARENKO	{"phone": "+70320457156"}
0005432140673	4AD260	0070 974527	VYACHESLAV POPOV	{"email": "vyacheslavpopov.1986@postgrespro.ru", "phone": "+70987314950"}
0005432140674	4AD260	4382 636406	VIKTOR KOZLOV	{"email": "viktor-kozlov121980@postgrespro.ru", "phone": "+70514825422"}
0005432140675	42DBCB	0419 780815	YURIY KRASNOV	{"phone": "+70774680534"}
0005432140676	42DBCB	8686 123877	ELENA DENISOVA	{"email": "denisova-elena1980@postgrespro.ru", "phone": "+70151272273"}
0005432140677	42DBCB	8959 012671	VIKTOR PETROV	{"email": "petrov_viktor_1975@postgrespro.ru", "phone": "+70143275401"}
0005432140678	A14AA5	9716 216047	VADIM VASILEV	{"email": "vasilevv-1963@postgrespro.ru", "phone": "+70342854792"}
0005432140679	30DEA6	5464 291375	ALEKSANDR AFANASEV	{"phone": "+70391357527"}
0005432140680	E0C478	6659 308098	NIKOLAY NIKOLAEV	{"email": "nikolaynikolaev.05111970@postgrespro.ru", "phone": "+70503704723"}
0005432140681	FB8886	5542 187515	ARTEM MAKAROV	{"email": "makarovartem27041974@postgrespro.ru", "phone": "+70675788228"}
0005432140682	2B0033	6962 784249	NATALYA AFANASEVA	{"phone": "+70112923127"}
0005432140683	BEABD2	8803 859966	TATYANA VOLKOVA	{"email": "tatyana_volkova_1968@postgrespro.ru", "phone": "+70121754419"}
0005432140684	303E93	0657 553261	TAMARA VOROBEVA	{"email": "tamara-vorobeva1976@postgrespro.ru", "phone": "+70181341477"}
0005432140685	303E93	4400 407511	EDUARD ABRAMOV	{"email": "abramov-eduard_081964@postgrespro.ru", "phone": "+70522004248"}
0005432140686	885C39	3620 773123	SERGEY PAVLOV	{"email": "sergeypavlov_031971@postgrespro.ru", "phone": "+70849532422"}
0005432140687	131355	1744 140393	ALEKSANDR SEMENOV	{"email": "a.semenov_1964@postgrespro.ru", "phone": "+70084209670"}
0005432140688	131355	1008 856235	VYACHESLAV MEDVEDEV	{"email": "medvedev-v_09031977@postgrespro.ru", "phone": "+70491463503"}
0005432140689	361AF6	9963 560109	ANDREY ROMANOV	{"email": "andrey_romanov_051977@postgrespro.ru", "phone": "+70386754062"}
0005432140690	361AF6	4532 145927	VYACHESLAV KRASNOV	{"email": "krasnov-vyacheslav071981@postgrespro.ru", "phone": "+70047906367"}
0005432140691	58EBE8	2685 635879	ANNA SOROKINA	{"email": "a-sorokina071971@postgrespro.ru", "phone": "+70639201729"}
0005432140692	58EBE8	3352 111868	ELENA DENISOVA	{"email": "elena-denisova12081970@postgrespro.ru", "phone": "+70659401212"}
0005432142218	348B6D	4994 563284	LYUBOV VASILEVA	{"phone": "+70760349481"}
0005432142197	CC5F8C	8437 401440	ELENA ZAKHAROVA	{"phone": "+70777409122"}
0005432142198	7A27EB	3398 396071	KRISTINA KOROLEVA	{"phone": "+70665932438"}
0005432142199	0A1A09	3738 823110	EKATERINA MAKAROVA	{"email": "ekaterina_makarova.041976@postgrespro.ru", "phone": "+70484885665"}
0005432142200	0A1A09	3347 110834	VLADISLAV AFANASEV	{"email": "afanasev.vladislav.061978@postgrespro.ru", "phone": "+70056432433"}
0005432142201	0A1A09	5864 602649	LYUDMILA AKIMOVA	{"email": "lyudmilaakimova.071979@postgrespro.ru", "phone": "+70220306676"}
0005432142202	B59173	9718 612015	GALINA ABRAMOVA	{"phone": "+70276735288"}
0005432142203	57C7AE	9473 072980	KIRILL TIKHONOV	{"email": "k.tikhonov12111968@postgrespro.ru", "phone": "+70722789997"}
0005432142204	57C7AE	8751 688538	SVETLANA ALEKSANDROVA	{"email": "aleksandrova-svetlana081967@postgrespro.ru", "phone": "+70357730307"}
0005432142205	C8558C	6900 651958	IGOR FEDOROV	{"email": "igor_fedorov-1971@postgrespro.ru", "phone": "+70822621127"}
0005432142206	2CA084	2836 230533	SVETLANA SOROKINA	{"phone": "+70185808487"}
0005432142207	2CA084	7324 440271	MAKSIM POPOV	{"email": "m_popov_031982@postgrespro.ru", "phone": "+70179700410"}
0005432142208	2CA084	2664 549476	ARTEM SERGEEV	{"email": "asergeev1973@postgrespro.ru", "phone": "+70956468587"}
0005432142209	AFAC7D	7623 775773	NATALYA KOZLOVA	{"phone": "+70049920257"}
0005432142210	AFAC7D	1654 585465	ANGELINA RYABOVA	{"email": "ryabova.a-041976@postgrespro.ru", "phone": "+70866223730"}
0005432142211	80F2AE	2559 836514	ANATOLIY PAVLOV	{"email": "pavlova-1978@postgrespro.ru", "phone": "+70693440602"}
0005432142212	80F2AE	7605 753764	ALEKSANDR TIMOFEEV	{"email": "atimofeev.041966@postgrespro.ru", "phone": "+70217916235"}
0005432142213	150941	7135 181530	YULIYA STEPANOVA	{"email": "y_stepanova.1985@postgrespro.ru", "phone": "+70305320851"}
0005432142214	70C1E4	7853 316908	NIKOLAY IVANOV	{"phone": "+70558688667"}
0005432142215	86E71A	0723 696323	VALENTINA STEPANOVA	{"email": "stepanova.valentina-111967@postgrespro.ru", "phone": "+70237525282"}
0005432142216	B1995C	7965 191604	MARIYA FROLOVA	{"email": "frolova.m1967@postgrespro.ru", "phone": "+70666315123"}
0005432142217	BC4070	1365 870056	OKSANA VOROBEVA	{"email": "o.vorobeva-1966@postgrespro.ru", "phone": "+70794747545"}
0005432142219	348B6D	5908 174300	ALEKSANDR KUZNECOV	{"phone": "+70037190580"}
0005432142220	0BC6AA	2966 508905	DMITRIY DAVYDOV	{"email": "davydov-dmitriy_111964@postgrespro.ru", "phone": "+70447775704"}
0005432142221	0BC6AA	6538 156188	VLADIMIR VOLKOV	{"email": "volkov_vladimir02071980@postgrespro.ru", "phone": "+70227275363"}
0005432142222	9E33D5	1590 504746	VLADIMIR TARASOV	{"phone": "+70202052243"}
0005432142223	9E33D5	4185 440863	NATALYA MIRONOVA	{"email": "n.mironova_28021976@postgrespro.ru", "phone": "+70563031785"}
0005432142224	D6C05F	1606 648146	VERA TIKHONOVA	{"email": "vera.tikhonova22031962@postgrespro.ru", "phone": "+70261263196"}
0005432142225	3BDD24	3457 228517	ANATOLIY POPOV	{"email": "anatoliy-popov_101979@postgrespro.ru", "phone": "+70178136666"}
0005432142226	3BDD24	9865 103939	SERGEY FEDOROV	{"phone": "+70291622324"}
0005432142227	7BACCC	0584 668256	OKSANA POTAPOVA	{"email": "opotapova.1971@postgrespro.ru", "phone": "+70654663899"}
0005432142228	48970F	0041 606051	ANDREY MOROZOV	{"phone": "+70441772307"}
0005432142229	1F15C4	6078 925427	DMITRIY MIRONOV	{"email": "mironovd1972@postgrespro.ru", "phone": "+70819431711"}
0005432142230	10C9DF	2472 215513	SVETLANA ROMANOVA	{"phone": "+70503022924"}
0005432142231	13489C	6321 471691	MARIYA AFANASEVA	{"email": "m_afanaseva.1961@postgrespro.ru", "phone": "+70958186488"}
0005432142232	04C3E7	7183 522207	TATYANA KALININA	{"email": "kalinina.tatyana1974@postgrespro.ru", "phone": "+70834147830"}
0005432142233	B4F793	3200 833769	MARIYA GAVRILOVA	{"phone": "+70550539098"}
0005432142234	179F91	2012 736002	GALINA ZHURAVLEVA	{"email": "zhuravleva-g1982@postgrespro.ru", "phone": "+70708512455"}
0005432142235	FAA526	7211 438959	ZINAIDA NIKIFOROVA	{"email": "zinaidanikiforova.031972@postgrespro.ru", "phone": "+70369507066"}
0005432142236	FAA526	7546 302696	VIKTOR POPOV	{"email": "popov-v041976@postgrespro.ru", "phone": "+70102036058"}
0005432142237	69C051	7356 891552	OLESYA KOZLOVA	{"email": "kozlova-o_11021975@postgrespro.ru", "phone": "+70174710017"}
0005432142238	5B3F30	6517 237012	ANDREY NAZAROV	{"email": "nazarovandrey1973@postgrespro.ru", "phone": "+70486890873"}
0005432142239	F5DD40	5649 345527	ALEKSEY SMIRNOV	{"phone": "+70434536160"}
0005432142240	F5DD40	5541 030458	VLADIMIR IVANOV	{"email": "vladimir-ivanov1975@postgrespro.ru", "phone": "+70583644925"}
0005432142241	FC0046	0166 077352	ANGELINA YAKOVLEVA	{"email": "yakovlevaangelina1979@postgrespro.ru", "phone": "+70110077292"}
0005432142242	B8695F	9006 623633	LYUDMILA BELOVA	{"email": "belova.l.02031967@postgrespro.ru", "phone": "+70061364637"}
0005432142243	A787B9	6720 777451	YULIYA STEPANOVA	{"email": "y_stepanova1980@postgrespro.ru", "phone": "+70764940465"}
0005432142244	AF7444	1878 909896	PELAGEYA RYABOVA	{"email": "pelageya-ryabova_061980@postgrespro.ru", "phone": "+70001153185"}
0005432142245	719933	2017 414730	TATYANA BORISOVA	{"email": "borisova-t_10071971@postgrespro.ru", "phone": "+70747156961"}
0005432142246	59DDA0	9613 126084	PETR VASILEV	{"phone": "+70931655492"}
0005432142247	AE2CFC	0111 300057	VYACHESLAV KUZMIN	{"email": "vyacheslav_kuzmin-041970@postgrespro.ru", "phone": "+70220136482"}
0005432142248	5EF79A	9773 197396	NIKOLAY ZAKHAROV	{"phone": "+70355462689"}
0005432142249	5EF79A	1650 776195	GENNADIY MAKAROV	{"email": "makarov_gennadiy_121968@postgrespro.ru", "phone": "+70099512358"}
0005432142250	C17D3F	1467 671734	TATYANA EFREMOVA	{"email": "efremova.t-1969@postgrespro.ru", "phone": "+70122431500"}
0005432142251	CEABBB	4115 430726	OKSANA FEDOROVA	{"email": "o-fedorova_09031974@postgrespro.ru", "phone": "+70254032954"}
0005432142252	CEABBB	9243 538333	LYUDMILA SCHERBAKOVA	{"email": "scherbakovalyudmila_091972@postgrespro.ru", "phone": "+70637161723"}
0005432142253	FD0302	1887 511456	GUZEL KOZLOVA	{"email": "guzel-kozlova.101976@postgrespro.ru", "phone": "+70092819906"}
0005432142254	FD0302	3461 724466	IVAN FROLOV	{"email": "ifrolov_051972@postgrespro.ru", "phone": "+70800640637"}
0005432142255	FD0302	6832 361190	TATYANA KULIKOVA	{"phone": "+70170745681"}
0005432142256	3D9103	6924 259602	ZARINA FEDOROVA	{"phone": "+70710480924"}
0005432142257	DDA579	4561 732499	NIKOLAY KOZLOV	{"phone": "+70146987808"}
0005432142258	2E5101	2919 819857	NIKOLAY AFANASEV	{"phone": "+70138554725"}
0005432142259	810B0D	2762 672865	ELIZAVETA KARPOVA	{"email": "elizaveta_karpova1967@postgrespro.ru", "phone": "+70988863938"}
0005432142260	ED21F3	4112 456352	NADEZHDA BOGDANOVA	{"email": "bogdanova-n-1964@postgrespro.ru", "phone": "+70727420940"}
0005432142261	ED21F3	8592 132987	SERGEY IVANOV	{"email": "sergey.ivanov.101971@postgrespro.ru", "phone": "+70858262518"}
0005432142262	98313B	3892 194576	VIKTOR STEPANOV	{"email": "stepanov_viktor_1975@postgrespro.ru", "phone": "+70782418310"}
0005432142263	98313B	2642 374269	OLEG DENISOV	{"phone": "+70511894248"}
0005432142264	CEFC99	7915 001653	DARYA SOROKINA	{"email": "sorokinad1976@postgrespro.ru", "phone": "+70384159682"}
0005432142265	CEFC99	3292 088578	ANTON ANDREEV	{"email": "andreevanton_011967@postgrespro.ru", "phone": "+70548720473"}
0005432142266	756950	4684 739459	ELENA RYABOVA	{"phone": "+70943114232"}
0005432142267	756950	6482 880422	MARIYA EFREMOVA	{"email": "m_efremova_011982@postgrespro.ru", "phone": "+70074608131"}
0005432142268	A8A452	3079 454265	YANA YAKOVLEVA	{"email": "y.yakovleva-1980@postgrespro.ru", "phone": "+70098162664"}
0005432142269	A8A452	2788 974049	NINA NIKOLAEVA	{"phone": "+70325411202"}
0005432142270	EAF430	5558 482835	IVAN KARPOV	{"phone": "+70361142188"}
0005432142271	762CA0	5663 577810	NATALYA MOROZOVA	{"email": "morozova.n.021968@postgrespro.ru", "phone": "+70438233483"}
0005432142272	762CA0	2137 630888	GALINA SEMENOVA	{"phone": "+70554632033"}
0005432142273	E4BE68	6329 923555	LYUDMILA SCHERBAKOVA	{"phone": "+70885721469"}
0005432142274	E4BE68	8351 007418	TATYANA KUZNECOVA	{"phone": "+70357372678"}
0005432142275	1196A7	2787 272154	DARYA NIKOLAEVA	{"email": "darya.nikolaeva111970@postgrespro.ru", "phone": "+70058127960"}
0005432142276	5F38C9	5884 224007	VIKTOR GRIGOREV	{"email": "viktor_grigorev061980@postgrespro.ru", "phone": "+70058896749"}
0005432142277	85E2CD	4883 881590	VLADISLAV SMIRNOV	{"email": "v-smirnov.1971@postgrespro.ru", "phone": "+70602311608"}
0005432142278	470E98	8576 525186	ALEKSANDR IVANOV	{"phone": "+70930172155"}
0005432142279	006D91	8318 194576	ARTEM ANTONOV	{"email": "antonov_a.071957@postgrespro.ru", "phone": "+70401674121"}
0005432142280	9F2BCA	9388 777313	VLADISLAV SOKOLOV	{"email": "v.sokolov_041970@postgrespro.ru", "phone": "+70064236713"}
0005432142281	426821	8639 534458	NINA ROMANOVA	{"email": "nina-romanova-1972@postgrespro.ru", "phone": "+70708695732"}
0005432142282	186019	2360 065651	ROZA EGOROVA	{"phone": "+70307676812"}
0005432142283	E973F8	2740 278908	TATYANA MOISEEVA	{"phone": "+70075344362"}
0005432142284	744E35	9328 034276	NIKOLAY POPOV	{"phone": "+70578833461"}
0005432142285	0F7F78	7952 987875	ANTONINA FROLOVA	{"phone": "+70984562025"}
0005432142286	E8C77C	8196 158363	VIKTOR GORBUNOV	{"phone": "+70885952136"}
0005432142287	BF32F5	8536 765863	FANIS IVANOV	{"email": "f_ivanov.1963@postgrespro.ru", "phone": "+70835885593"}
0005432142288	B3DF41	7198 001509	YURIY ZAKHAROV	{"email": "yuriyzakharov06041973@postgrespro.ru", "phone": "+70407657974"}
0005432142289	B3DF41	0095 553679	ANDREY IVANOV	{"email": "ivanovandrey_1966@postgrespro.ru", "phone": "+70402023267"}
0005432142290	B3DF41	8854 467999	VIKTOR BONDARENKO	{"phone": "+70749030804"}
0005432142291	1882A1	6610 221554	MIKHAIL SIDOROV	{"email": "sidorovmikhail.1975@postgrespro.ru", "phone": "+70584431016"}
0005432142292	CD289B	6209 105373	OLGA FILATOVA	{"email": "olga-filatova-25081983@postgrespro.ru", "phone": "+70987667358"}
0005432142293	6A175B	0147 379534	SERGEY EGOROV	{"email": "egorov.s_15101964@postgrespro.ru", "phone": "+70355087122"}
0005432142294	4D45B3	5413 341455	GRIGORIY KOZLOV	{"phone": "+70720684768"}
0005432142295	4D45B3	2157 296217	GALINA KISELEVA	{"phone": "+70505401694"}
0005432142296	FC92A0	7680 964150	ELENA KUZNECOVA	{"email": "elena-kuznecova_011969@postgrespro.ru", "phone": "+70887235001"}
0005432142297	649BAE	0996 782044	VLADIMIR SCHERBAKOV	{"phone": "+70489492624"}
0005432142298	649BAE	8922 289518	SVETLANA ZAYCEVA	{"phone": "+70014079427"}
0005432142299	7DC3AD	6952 023774	GALINA KUDRYASHOVA	{"email": "kudryashova.g-021976@postgrespro.ru", "phone": "+70482991385"}
0005432142300	7DC3AD	0780 734825	ALEKSANDR DMITRIEV	{"email": "dmitriev-a_071966@postgrespro.ru", "phone": "+70150597461"}
0005432142301	B8A0DA	3116 141721	IRINA VLASOVA	{"email": "vlasova_irina.29091970@postgrespro.ru", "phone": "+70373627497"}
0005432142302	B8A0DA	7374 134905	ALEKSANDR SMIRNOV	{"email": "smirnov-aleksandr071975@postgrespro.ru", "phone": "+70050460629"}
0005432142303	FDA5D9	7352 811306	TATYANA KISELEVA	{"email": "tatyana.kiseleva.071971@postgrespro.ru", "phone": "+70493375671"}
0005432142304	2F4496	9741 271753	VLADIMIR KUZNECOV	{"phone": "+70538423159"}
0005432142305	EF4F83	9987 331519	MAYA LOGINOVA	{"phone": "+70952151632"}
0005432142306	EF4F83	1525 406458	SERGEY SHEVCHENKO	{"phone": "+70282032399"}
0005432142307	36B21C	0690 931353	VALERIYA SEMENOVA	{"email": "valeriya_semenova.1973@postgrespro.ru", "phone": "+70950905686"}
0005432142308	8E7CD9	7622 988952	RAMIL KUZMIN	{"phone": "+70463845372"}
0005432142309	8E7CD9	3604 739383	ALEKSEY VOROBEV	{"email": "alekseyvorobev-08031981@postgrespro.ru", "phone": "+70948415874"}
0005432142310	B673D5	4029 423829	NATALYA KOROLEVA	{"phone": "+70725374828"}
0005432142311	F4FC02	7495 622313	EGOR TARASOV	{"email": "tarasov-egor_121975@postgrespro.ru", "phone": "+70889624291"}
0005432142312	E6FE8E	5602 906644	EVGENIY KOROLEV	{"phone": "+70480686615"}
0005432142313	E6FE8E	3271 261004	MARINA NESTEROVA	{"phone": "+70327264676"}
0005432142314	DFD55E	1970 053107	YURIY SEMENOV	{"email": "semenov-yuriy.02011964@postgrespro.ru", "phone": "+70566663831"}
0005432142315	DFD55E	8238 521977	SVETLANA FROLOVA	{"email": "svetlanafrolova_1969@postgrespro.ru", "phone": "+70460312658"}
0005432142316	BEA9C6	7974 166033	KSENIYA MOISEEVA	{"email": "moiseevak.121968@postgrespro.ru", "phone": "+70373451589"}
0005432142317	BEA9C6	5245 714554	ALENA YAKOVLEVA	{"email": "a.yakovleva-111973@postgrespro.ru", "phone": "+70875159687"}
0005432142318	7C4F2C	9490 085824	GALINA SOKOLOVA	{"phone": "+70289889596"}
0005432144018	49C504	0387 017187	PAVEL FROLOV	{"phone": "+70944558042"}
0005432142319	566595	8833 884304	ALEKSEY FOMIN	{"email": "fomin-a.111974@postgrespro.ru", "phone": "+70538127555"}
0005432142320	A8A4E6	1134 431700	GALINA ROMANOVA	{"email": "romanovag_091974@postgrespro.ru", "phone": "+70359363906"}
0005432142321	8D758B	4339 102843	LYUBOV NOVIKOVA	{"email": "novikova-l021981@postgrespro.ru", "phone": "+70218790310"}
0005432142322	BCD377	5342 020237	TAMARA SOKOLOVA	{"email": "sokolova-t-061976@postgrespro.ru", "phone": "+70906340505"}
0005432142323	BCD377	9447 317261	ALEKSANDR VASILEV	{"email": "avasilev_081981@postgrespro.ru", "phone": "+70553855200"}
0005432142324	D2BCE5	0237 808900	ANTONINA TROFIMOVA	{"email": "antonina.trofimova121975@postgrespro.ru", "phone": "+70747489478"}
0005432142325	9D15B4	8324 595520	YURIY NAZAROV	{"phone": "+70650274760"}
0005432142326	9D15B4	0229 119919	ALEKSANDRA POPOVA	{"email": "aleksandra.popova17051969@postgrespro.ru", "phone": "+70018864441"}
0005432142327	2BA058	9125 456100	YURIY KONOVALOV	{"email": "ykonovalov_101982@postgrespro.ru", "phone": "+70429186909"}
0005432142328	2BA058	5287 976730	VIKTOR SOROKIN	{"email": "viktorsorokin-1965@postgrespro.ru", "phone": "+70116223235"}
0005432142329	D3FA34	7570 542607	ALEKSANDRA ZAKHAROVA	{"phone": "+70636999870"}
0005432142330	6348D7	0832 933591	SERGEY NIKITIN	{"phone": "+70935080118"}
0005432142331	5A291C	6726 283800	RUSLAN FEDOTOV	{"email": "fedotovr-071966@postgrespro.ru", "phone": "+70126930769"}
0005432142332	5A291C	1796 684451	ILDAR ZHURAVLEV	{"email": "i_zhuravlev03051969@postgrespro.ru", "phone": "+70725532575"}
0005432142333	58BBD0	2596 301812	DMITRIY SERGEEV	{"email": "dmitriy.sergeev-26061977@postgrespro.ru", "phone": "+70627391923"}
0005432142334	DC8C8F	4779 105698	LYUDMILA KOZLOVA	{"phone": "+70677414117"}
0005432142335	DC8C8F	6192 410693	IRINA TROFIMOVA	{"email": "irina.trofimova.1977@postgrespro.ru", "phone": "+70842652888"}
0005432142336	0F0DD1	5650 012736	ALEKSANDR SOROKIN	{"email": "sorokina.29111975@postgrespro.ru", "phone": "+70883649308"}
0005432142337	48D6BE	8641 461050	ANDREY NIKITIN	{"email": "a.nikitin_011976@postgrespro.ru", "phone": "+70844287959"}
0005432142338	E90EFD	3380 269447	MARINA IVANOVA	{"email": "m-ivanova_28121965@postgrespro.ru", "phone": "+70702160307"}
0005432142339	E6A8EE	1393 866174	LYUDMILA KUZMINA	{"email": "l.kuzmina_091978@postgrespro.ru", "phone": "+70003979507"}
0005432142340	E6A8EE	0586 785878	MARIYA KOZLOVA	{"email": "kozlova-mariya-1965@postgrespro.ru", "phone": "+70559316814"}
0005432142341	723AAC	4223 237932	ALEKSANDR NOVIKOV	{"email": "novikov.a01031977@postgrespro.ru", "phone": "+70371048035"}
0005432142342	DD86ED	2682 968819	NIKOLAY CHERNOV	{"phone": "+70777284248"}
0005432142343	5B7E94	3185 676518	ANATOLIY KAZAKOV	{"phone": "+70123805955"}
0005432142344	5B7E94	7727 709655	VIKTOR SHEVCHENKO	{"email": "viktor_shevchenko1982@postgrespro.ru", "phone": "+70910791845"}
0005432142345	E2BEA2	7134 052875	ANATOLIY KULIKOV	{"email": "akulikov-02081967@postgrespro.ru", "phone": "+70699695455"}
0005432142346	E2BEA2	8039 064799	VALERIY KOZLOV	{"phone": "+70470441231"}
0005432143929	EAE044	6345 529703	DMITRIY CHERNOV	{"phone": "+70066546439"}
0005432143930	2E47EE	0903 478957	MARIYA YAKOVLEVA	{"phone": "+70822727758"}
0005432143931	F09231	9597 711685	YULIYA KOROLEVA	{"email": "yuliya-koroleva-16111980@postgrespro.ru", "phone": "+70439422159"}
0005432143932	4847C7	4768 759144	ANATOLIY STEPANOV	{"email": "anatoliy-stepanov011966@postgrespro.ru", "phone": "+70488985074"}
0005432143933	39E999	2575 741486	LYUDMILA TROFIMOVA	{"email": "trofimova-l.03031995@postgrespro.ru", "phone": "+70035652549"}
0005432143934	5A5794	9530 675342	VALENTIN IVANOV	{"email": "valentinivanov_031970@postgrespro.ru", "phone": "+70500999806"}
0005432143935	A7902F	7177 520989	VERA LEBEDEVA	{"email": "vera_lebedeva22071983@postgrespro.ru", "phone": "+70158112181"}
0005432143936	998750	9777 788318	RIMMA MASLOVA	{"email": "r.maslova_061976@postgrespro.ru", "phone": "+70718624057"}
0005432143937	2C2B8B	3869 066932	SVETLANA CHERNOVA	{"email": "chernovas_1971@postgrespro.ru", "phone": "+70348397244"}
0005432143938	2C2B8B	7654 912065	ALEKSEY POPOV	{"phone": "+70934397035"}
0005432143939	83973C	1465 180936	KIRILL MAKAROV	{"email": "kirill_makarov_1965@postgrespro.ru", "phone": "+70046676398"}
0005432143940	A51E0A	8528 894381	SVETLANA KOMAROVA	{"email": "s_komarova031969@postgrespro.ru", "phone": "+70023795362"}
0005432143941	A51E0A	8290 877413	ALEKSEY KOROLEV	{"email": "alekseykorolev10091985@postgrespro.ru", "phone": "+70737304472"}
0005432143942	694289	2071 116126	SERGEY KULIKOV	{"email": "kulikov-s.08071971@postgrespro.ru", "phone": "+70017091711"}
0005432143943	240733	2535 752798	ELIZAVETA KONOVALOVA	{"phone": "+70840019242"}
0005432143944	240733	5253 135535	ANDREY GRIGOREV	{"phone": "+70504056622"}
0005432143945	277611	9236 422622	ILDAR ABRAMOV	{"email": "ildar_abramov121977@postgrespro.ru", "phone": "+70430811385"}
0005432143946	9C7268	2490 360392	KIRILL SCHERBAKOV	{"email": "scherbakovkirill.15081990@postgrespro.ru", "phone": "+70799857202"}
0005432143947	2CAD91	9718 336768	EVGENIYA MAKAROVA	{"email": "makarova.evgeniya-1984@postgrespro.ru", "phone": "+70416226349"}
0005432143948	D2A2F9	8507 877421	EKATERINA MIRONOVA	{"email": "mironova.e.1965@postgrespro.ru", "phone": "+70327524281"}
0005432143949	64FA0B	6037 900269	TATYANA ZHUKOVA	{"phone": "+70859498731"}
0005432143950	C3B8FE	1612 667562	NADEZHDA DMITRIEVA	{"email": "ndmitrieva-1963@postgrespro.ru", "phone": "+70328854719"}
0005432143951	9874EC	7745 983827	DMITRIY KUZNECOV	{"email": "kuznecov_d-051972@postgrespro.ru", "phone": "+70757046923"}
0005432143952	9874EC	2574 745913	ANNA KISELEVA	{"phone": "+70588474330"}
0005432143953	9874EC	1131 092642	VLADIMIR POPOV	{"email": "popovvladimir_29111979@postgrespro.ru", "phone": "+70381632942"}
0005432143954	B29A99	7366 802048	ANASTASIYA LEBEDEVA	{"phone": "+70435246079"}
0005432143955	18CA0A	4933 152323	BORIS MOROZOV	{"phone": "+70256114219"}
0005432143956	DDFFC6	0910 957319	TATYANA POPOVA	{"phone": "+70107632324"}
0005432143957	8643CA	6843 469783	DANIIL PETROV	{"phone": "+70368409759"}
0005432143958	487DC0	7299 134095	MIKHAIL ROMANOV	{"email": "m.romanov-061968@postgrespro.ru", "phone": "+70139429632"}
0005432143959	487DC0	5501 887865	SERGEY FOMIN	{"phone": "+70046941247"}
0005432143960	487DC0	9725 514962	LYUBOV ZAKHAROVA	{"phone": "+70579226464"}
0005432143961	487DC0	1114 344946	OLEG MEDVEDEV	{"email": "oleg_medvedev08111969@postgrespro.ru", "phone": "+70944925554"}
0005432143962	25F526	3525 711285	ANNA NIKIFOROVA	{"phone": "+70585301347"}
0005432143963	CD65EE	9128 098458	ANTON EGOROV	{"phone": "+70452686459"}
0005432143964	2863AE	0906 279808	ELIZAVETA VOROBEVA	{"phone": "+70503380941"}
0005432143965	0E2FE8	2800 986776	SERGEY NIKOLAEV	{"email": "sergey-nikolaev_101963@postgrespro.ru", "phone": "+70634062018"}
0005432143966	E862C9	3519 929127	NIKITA MATVEEV	{"phone": "+70543006668"}
0005432143967	E862C9	4439 079758	ALINA NOVIKOVA	{"phone": "+70327276869"}
0005432143968	24BC40	4680 863331	TATYANA YAKOVLEVA	{"email": "yakovleva_tatyana16011973@postgrespro.ru", "phone": "+70523683887"}
0005432143969	24BC40	8650 878723	NIKITA VASILEV	{"phone": "+70788974758"}
0005432143970	187AD2	6481 468872	ALEKSANDR GORBUNOV	{"email": "gorbunova_1975@postgrespro.ru", "phone": "+70127857381"}
0005432143971	187AD2	7918 983831	LYUBOV VASILEVA	{"email": "vasileva_l-1965@postgrespro.ru", "phone": "+70002238011"}
0005432143972	963828	7152 796213	RUSLAN KUZNECOV	{"email": "r_kuznecov_04021984@postgrespro.ru", "phone": "+70142374804"}
0005432143973	CA3F4F	8716 760691	ELENA MIKHAYLOVA	{"phone": "+70968903212"}
0005432143974	A94B00	8939 157736	DMITRIY POPOV	{"phone": "+70299907207"}
0005432143975	A94B00	5976 651989	ULYANA EFREMOVA	{"email": "u_efremova.1969@postgrespro.ru", "phone": "+70067521425"}
0005432143976	D9BB59	3311 772547	TATYANA BORISOVA	{"email": "borisova-tatyana-1976@postgrespro.ru", "phone": "+70876057536"}
0005432143977	D9BB59	5794 633675	NINA EGOROVA	{"phone": "+70035306987"}
0005432143978	B8406D	1276 132088	GALINA BOGDANOVA	{"email": "bogdanova_galina.19041970@postgrespro.ru", "phone": "+70431162971"}
0005432143979	D17233	9825 065793	TATYANA KUZNECOVA	{"phone": "+70538177507"}
0005432143980	F44919	8179 538646	KLAVDIYA NESTEROVA	{"email": "nesterova-k.05101972@postgrespro.ru", "phone": "+70371628965"}
0005432143981	62129E	0300 801258	TATYANA POTAPOVA	{"phone": "+70731907134"}
0005432143982	7340AE	0524 865327	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay_061983@postgrespro.ru", "phone": "+70708268949"}
0005432143983	7340AE	4295 545442	EVGENIYA ROMANOVA	{"email": "romanova_e-1966@postgrespro.ru", "phone": "+70352986394"}
0005432143984	6634E8	4468 856475	OLGA NOVIKOVA	{"phone": "+70805421103"}
0005432143985	6634E8	3622 435405	NIKOLAY MOROZOV	{"email": "morozov-nikolay091970@postgrespro.ru", "phone": "+70051729152"}
0005432143986	B95E0B	2531 909093	VERA MEDVEDEVA	{"email": "vera_medvedeva-21121969@postgrespro.ru", "phone": "+70785561696"}
0005432143987	B95E0B	2552 084513	VIKTORIYA FADEEVA	{"phone": "+70722700202"}
0005432143988	B95E0B	3434 893273	ALEKSANDRA NOVIKOVA	{"email": "novikova_a_1977@postgrespro.ru", "phone": "+70832592844"}
0005432143989	14A718	4847 889727	NADEZHDA OVCHINNIKOVA	{"email": "n-ovchinnikova23071976@postgrespro.ru", "phone": "+70877865171"}
0005432143990	4E0E59	1955 519922	YURIY KRASNOV	{"email": "krasnov.yuriy.1970@postgrespro.ru", "phone": "+70968075826"}
0005432143991	23AB52	5315 358130	KONSTANTIN STEPANOV	{"email": "stepanov_k-1969@postgrespro.ru", "phone": "+70356267207"}
0005432143992	23AB52	9490 572664	ZINAIDA LUKYANOVA	{"email": "lukyanovaz-1982@postgrespro.ru", "phone": "+70371312309"}
0005432143993	D2C514	5365 858009	ALEKSANDR POPOV	{"phone": "+70323383284"}
0005432143994	D2C514	5189 003408	VALENTINA ZAKHAROVA	{"phone": "+70921993609"}
0005432143995	2904E5	4022 422583	GALINA KUZNECOVA	{"email": "galinakuznecova-061979@postgrespro.ru", "phone": "+70149934765"}
0005432143996	7DA3E2	1881 171160	ELENA MARTYNOVA	{"phone": "+70846372162"}
0005432143997	328BC4	4836 437837	EVGENIY RODIONOV	{"email": "e.rodionov_14051980@postgrespro.ru", "phone": "+70942090646"}
0005432143998	328BC4	4872 797635	ALEKSANDR KOROLEV	{"email": "koroleva-01031964@postgrespro.ru", "phone": "+70643356475"}
0005432143999	50C56B	6493 501615	SERGEY DENISOV	{"email": "denisovsergey27061961@postgrespro.ru", "phone": "+70017911517"}
0005432144000	50C56B	0856 580195	NIKOLAY NIKOLAEV	{"phone": "+70092992678"}
0005432144001	50C56B	0076 471146	NIKITA BONDARENKO	{"phone": "+70554713304"}
0005432144002	683BFD	9292 148851	YANA IVANOVA	{"email": "ivanova_y-021977@postgrespro.ru", "phone": "+70335651046"}
0005432144003	CD8481	5680 753275	YURIY KULIKOV	{"email": "kulikov.y-21111958@postgrespro.ru", "phone": "+70017937040"}
0005432144004	9D7DA8	3861 646967	ALEKSANDRA SOLOVEVA	{"phone": "+70801897500"}
0005432144005	CCCD66	1221 585333	ALEKSANDR BORISOV	{"email": "borisov-a_06041965@postgrespro.ru", "phone": "+70278821865"}
0005432144006	1818C6	2682 318014	IRINA EFREMOVA	{"email": "efremova.irina_111983@postgrespro.ru", "phone": "+70089055523"}
0005432144007	1818C6	7485 798364	TAMARA KOLESNIKOVA	{"phone": "+70904099203"}
0005432144008	3987B9	1412 814849	VALENTINA KULIKOVA	{"email": "kulikovav.14021969@postgrespro.ru", "phone": "+70632686809"}
0005432144009	3987B9	8982 233749	EGOR IVANOV	{"phone": "+70822849209"}
0005432144010	126C77	6873 251266	NIKOLAY ALEKSEEV	{"phone": "+70439436670"}
0005432144011	126C77	3585 250709	TAMARA KOVALEVA	{"phone": "+70271794199"}
0005432144012	C440E2	8399 332519	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko111964@postgrespro.ru", "phone": "+70777986139"}
0005432144013	BB7BF0	2326 434846	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.18061983@postgrespro.ru", "phone": "+70303300248"}
0005432144014	BB7BF0	7722 571392	DARYA MAKSIMOVA	{"email": "maksimova-d_1973@postgrespro.ru", "phone": "+70830870819"}
0005432144015	A07379	6079 209924	ANNA BOGDANOVA	{"phone": "+70607577750"}
0005432144016	6622AC	4197 403782	IRINA BOGDANOVA	{"phone": "+70967134880"}
0005432144017	455730	5627 435909	MARIYA FADEEVA	{"phone": "+70101749968"}
0005432144019	36F9F4	1163 296934	IVAN NIKITIN	{"phone": "+70129778663"}
0005432144020	315E95	8082 641646	OLGA KUZNECOVA	{"phone": "+70638574440"}
0005432144021	25E908	9116 419922	NIKOLAY BELOV	{"phone": "+70386319232"}
0005432144022	D80484	5384 564753	VALERIY SERGEEV	{"phone": "+70445027006"}
0005432144023	676EEA	9829 931710	OLGA FILATOVA	{"email": "filatova_olga_1967@postgrespro.ru", "phone": "+70124797902"}
0005432144024	8D406F	3752 680003	IRINA SOLOVEVA	{"phone": "+70843236566"}
0005432144025	5BE430	9508 188004	NINA ROMANOVA	{"phone": "+70001128628"}
0005432144026	0D92CC	1969 679926	LYUDMILA SMIRNOVA	{"email": "smirnova_lyudmila_1972@postgrespro.ru", "phone": "+70118466090"}
0005432144027	F16E5C	0457 214624	TAMARA CHERNOVA	{"phone": "+70524900590"}
0005432144028	2EFFAB	3011 240606	RUSLAN VOROBEV	{"phone": "+70995465579"}
0005432144029	8FCF96	5336 625366	LYUDMILA ISAEVA	{"phone": "+70917949818"}
0005432144030	921E17	7545 641159	VLADIMIR ALEKSEEV	{"phone": "+70147864256"}
0005432144031	921E17	5204 925504	MARIYA DMITRIEVA	{"email": "dmitrievamariya1976@postgrespro.ru", "phone": "+70567061724"}
0005432144032	90A9F6	4916 061872	MAKSIM NIKOLAEV	{"email": "maksim_nikolaev.12091966@postgrespro.ru", "phone": "+70520164442"}
0005432144033	CC8A11	5914 881484	MIKHAIL PETROV	{"email": "m-petrov-09071973@postgrespro.ru", "phone": "+70360174382"}
0005432144034	4FC794	8744 974230	NAIL PAVLOV	{"email": "nailpavlov-1978@postgrespro.ru", "phone": "+70815291109"}
0005432144035	4F06B7	5677 315792	RAISA ROMANOVA	{"email": "romanova.r-1961@postgrespro.ru", "phone": "+70377879411"}
0005432144036	265E21	4986 589013	OLESYA NAZAROVA	{"email": "nazarovaolesya-1977@postgrespro.ru", "phone": "+70789891224"}
0005432144037	F88665	2207 949115	VALERIYA PETROVA	{"email": "petrova-valeriya.07071977@postgrespro.ru", "phone": "+70916863658"}
0005432144038	F91A73	8630 070663	LIDIYA VASILEVA	{"email": "l_vasileva.1984@postgrespro.ru", "phone": "+70570891607"}
0005432144039	BF91DB	8873 179049	LYUBOV BARANOVA	{"email": "baranova.l091967@postgrespro.ru", "phone": "+70952705231"}
0005432144040	BF91DB	0884 577619	RAFAEL IVANOV	{"phone": "+70716032816"}
0005432144041	3DCF5F	8529 592678	RIMMA VOLKOVA	{"email": "volkova_r.28101972@postgrespro.ru", "phone": "+70532923930"}
0005432144042	4FB02B	0683 276593	NATALYA KONOVALOVA	{"phone": "+70437671770"}
0005432144043	1D0629	6333 279287	ALEKSEY ORLOV	{"email": "orlova-121966@postgrespro.ru", "phone": "+70984599764"}
0005432144044	3C5CAA	2973 534162	TIMOFEY MAKAROV	{"phone": "+70764234854"}
0005432144045	40A91F	8098 638214	ANDREY ANDREEV	{"email": "andreeva28041977@postgrespro.ru", "phone": "+70711338870"}
0005432144046	F04248	3181 908529	NIKOLAY ABRAMOV	{"phone": "+70046602006"}
0005432144047	2567F3	3448 028148	VITALIY KOZLOV	{"email": "kozlov_vitaliy1980@postgrespro.ru", "phone": "+70297928240"}
0005432144048	E85FE3	1443 582350	IRINA NESTEROVA	{"email": "i_nesterova-23051963@postgrespro.ru", "phone": "+70045075199"}
0005432144049	110E13	5012 868450	VITALIY MOROZOV	{"phone": "+70525270252"}
0005432144050	110E13	2343 413975	NATALIYA MIKHAYLOVA	{"email": "mikhaylova.n-1983@postgrespro.ru", "phone": "+70139278087"}
0005432144051	EFA47D	1840 949854	KONSTANTIN MOROZOV	{"email": "konstantin-morozov_1973@postgrespro.ru", "phone": "+70204121066"}
0005432144052	92E57C	4873 572659	EGOR SERGEEV	{"email": "egor_sergeev.1973@postgrespro.ru", "phone": "+70332556060"}
0005432144053	92E57C	0508 417170	SERGEY FROLOV	{"email": "s_frolov.30011959@postgrespro.ru", "phone": "+70230382160"}
0005432144054	5A8256	4034 641513	NIKOLAY ZAKHAROV	{"email": "nzakharov051962@postgrespro.ru", "phone": "+70971539018"}
0005432144055	1D8E6B	1149 789986	ANDREY MOROZOV	{"phone": "+70806357005"}
0005432144056	D3D102	5475 512094	KLAVDIYA RYABOVA	{"email": "k.ryabova-1977@postgrespro.ru", "phone": "+70792350369"}
0005432144057	45EF10	5788 587969	VLADIMIR ZHUKOV	{"phone": "+70826945265"}
0005432144058	45EF10	4313 446899	ANATOLIY MATVEEV	{"phone": "+70248161183"}
0005432144059	AECFAD	2387 136260	DINA SMIRNOVA	{"phone": "+70084122009"}
0005432144060	AECFAD	8797 060747	DARYA NESTEROVA	{"phone": "+70480813838"}
0005432144061	B9B4D3	5449 670504	ANGELINA FROLOVA	{"phone": "+70233211112"}
0005432144062	5114C2	6029 004226	IRINA MARTYNOVA	{"phone": "+70767492747"}
0005432144063	5114C2	7070 387384	ZINAIDA NOVIKOVA	{"email": "novikova_zinaida1981@postgrespro.ru", "phone": "+70506465271"}
0005432144064	55C4F4	5021 720602	IGOR TIKHONOV	{"email": "igor-tikhonov.1970@postgrespro.ru", "phone": "+70708076325"}
0005432144065	B74066	9039 191545	MIKHAIL KONOVALOV	{"email": "m.konovalov-17031961@postgrespro.ru", "phone": "+70489409271"}
0005432144066	B74066	5553 525744	MIKHAIL NIKOLAEV	{"phone": "+70021474972"}
0005432144067	450C57	8010 864610	SERGEY MIRONOV	{"email": "mironov-sergey091966@postgrespro.ru", "phone": "+70607032298"}
0005432144068	450C57	8783 212523	TATYANA MAKSIMOVA	{"email": "tmaksimova-1972@postgrespro.ru", "phone": "+70466291712"}
0005432144069	450C57	7957 224847	ELENA BELYAEVA	{"email": "elena.belyaeva_1971@postgrespro.ru", "phone": "+70425188211"}
0005432144070	80ED0F	8899 301260	ANDREY KONOVALOV	{"phone": "+70420320316"}
0005432144071	E72DB2	4691 867845	SVETLANA DANILOVA	{"phone": "+70811183806"}
0005432144072	E72DB2	4833 084197	MAKSIM SIDOROV	{"email": "sidorov.m-1984@postgrespro.ru", "phone": "+70933407477"}
0005432144073	A70729	5537 472112	ZINAIDA KARPOVA	{"phone": "+70457067302"}
0005432144074	9378A1	4433 125128	ARTEM MEDVEDEV	{"phone": "+70578055309"}
0005432144075	9378A1	4660 940550	VIKTORIYA KUZNECOVA	{"phone": "+70752204181"}
0005432144076	E221E5	0874 793256	DMITRIY FEDOROV	{"phone": "+70361719903"}
0005432144077	65B3B0	0410 159122	ANNA POPOVA	{"phone": "+70999663834"}
0005432144078	65B3B0	9379 584708	OLEG IVANOV	{"email": "ivanovo-101967@postgrespro.ru", "phone": "+70097991087"}
0005432144079	EE536E	1146 657262	VALENTINA POLYAKOVA	{"email": "polyakovav.16011978@postgrespro.ru", "phone": "+70696573462"}
0005432144080	EE536E	4811 275768	GALIYA PETROVA	{"phone": "+70089721814"}
0005432144081	B32247	9930 739269	OLEG SCHERBAKOV	{"phone": "+70577347994"}
0005432145075	B5061B	4343 438295	ALEKSANDR GRIGOREV	{"phone": "+70140378452"}
0005432145076	32B39A	5785 275718	VIKTORIYA VASILEVA	{"email": "vasileva_v_1974@postgrespro.ru", "phone": "+70854753205"}
0005432145077	32B39A	8588 185708	MARIYA EGOROVA	{"phone": "+70447587687"}
0005432145078	150A44	0191 718779	EVGENIY SEMENOV	{"email": "semenov_evgeniy-07021985@postgrespro.ru", "phone": "+70458738708"}
0005432145079	061ABE	8712 331801	TIMUR GORBUNOV	{"phone": "+70502108718"}
0005432145080	061ABE	8048 931285	MAKSIM GUSEV	{"email": "mgusev1977@postgrespro.ru", "phone": "+70161330218"}
0005432145081	061ABE	1303 457416	VALENTINA ZAYCEVA	{"email": "zayceva-valentina.071963@postgrespro.ru", "phone": "+70941239161"}
0005432145082	557F2E	4129 568418	ELENA MEDVEDEVA	{"phone": "+70760541768"}
0005432145083	408AB9	0458 505834	ELENA POPOVA	{"phone": "+70040395299"}
0005432145084	408AB9	2420 540114	VLADIMIR SEMENOV	{"email": "semenovvladimir_071979@postgrespro.ru", "phone": "+70656667063"}
0005432145085	D36041	7635 082522	VYACHESLAV VASILEV	{"phone": "+70163978086"}
0005432145086	8B42DA	3396 177494	KAMIL MIKHAYLOV	{"email": "mikhaylov-kamil091969@postgrespro.ru", "phone": "+70416291632"}
0005432145087	42D2CE	8091 183042	SERGEY SIDOROV	{"email": "sidorov_s.30061975@postgrespro.ru", "phone": "+70336522907"}
0005432145088	B81906	2013 682647	DMITRIY FEDOTOV	{"email": "dmitriyfedotov.03041974@postgrespro.ru", "phone": "+70409602124"}
0005432145089	53ADF6	5176 239693	ALEKSANDR MAKAROV	{"phone": "+70432390763"}
0005432145090	53ADF6	7051 889649	OKSANA ANISIMOVA	{"phone": "+70112690726"}
0005432145091	1CD0E9	4777 736046	ALEKSANDR IVANOV	{"email": "ivanovaleksandr_031982@postgrespro.ru", "phone": "+70815510439"}
0005432145092	1CD0E9	4348 902354	RUMIYA IVANOVA	{"phone": "+70533621695"}
0005432145093	632E7A	2004 609552	ARTEM POPOV	{"email": "popov.artem.1957@postgrespro.ru", "phone": "+70759688073"}
0005432145094	D1C786	2217 105098	ZUKHRA LAZAREVA	{"email": "zukhra.lazareva_101983@postgrespro.ru", "phone": "+70111142797"}
0005432145095	D1C786	4243 182463	EKATERINA NIKOLAEVA	{"email": "ekaterina_nikolaeva_031972@postgrespro.ru", "phone": "+70286821021"}
0005432145096	527E5A	2598 787128	ELENA NAUMOVA	{"phone": "+70560414820"}
0005432145097	3712AF	5106 425880	VLADIMIR TIMOFEEV	{"email": "timofeev_vladimir.041968@postgrespro.ru", "phone": "+70610759142"}
0005432145098	3712AF	0346 001102	SERGEY ZHUKOV	{"phone": "+70852227185"}
0005432145099	309393	6706 655524	TATYANA PETROVA	{"phone": "+70625023012"}
0005432145100	ED37B1	4068 090025	DANIIL KAZAKOV	{"phone": "+70386476591"}
0005432145101	0B17FA	1816 920466	ALEKSANDR RODIONOV	{"phone": "+70656867710"}
0005432145102	0B17FA	3710 823950	LIDIYA KUZMINA	{"email": "lkuzmina-02041983@postgrespro.ru", "phone": "+70719842839"}
0005432145103	0B17FA	3345 304081	VYACHESLAV ABRAMOV	{"email": "vabramov061978@postgrespro.ru", "phone": "+70649823148"}
0005432145104	0B2D1E	3238 059804	NAIL FILIPPOV	{"email": "n-filippov_20061972@postgrespro.ru", "phone": "+70687485650"}
0005432145105	76DEF6	6643 394618	EVGENIY SMIRNOV	{"email": "smirnov-evgeniy-121963@postgrespro.ru", "phone": "+70061768364"}
0005432145106	76DEF6	7294 145506	VERA IVANOVA	{"phone": "+70829905459"}
0005432145107	5A676B	4672 937062	ARTEM ORLOV	{"email": "a-orlov.111970@postgrespro.ru", "phone": "+70149261862"}
0005432145108	5A676B	4150 164546	LYUDMILA OSIPOVA	{"email": "lyudmila.osipova.1963@postgrespro.ru", "phone": "+70688883715"}
0005432145109	5A676B	5912 890679	ELENA STEPANOVA	{"phone": "+70420192215"}
0005432145110	CACF27	2541 246150	GENNADIY SERGEEV	{"phone": "+70356847483"}
0005432145111	750616	8481 048487	ANASTASIYA ALEKSEEVA	{"email": "alekseeva-a.1976@postgrespro.ru", "phone": "+70625365215"}
0005432145112	96850B	0009 834556	ANTONINA SERGEEVA	{"phone": "+70030760888"}
0005432145113	96850B	8748 568934	SERGEY DENISOV	{"phone": "+70072452554"}
0005432145114	E3D58F	9521 346844	MARINA SOLOVEVA	{"email": "solovevam.111976@postgrespro.ru", "phone": "+70050668066"}
0005432145115	E3D58F	6739 090074	VLADISLAV CHERNOV	{"phone": "+70117440008"}
0005432145116	517B40	9222 652559	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev_19031974@postgrespro.ru", "phone": "+70464791888"}
0005432145117	517B40	6275 163536	GENNADIY IVANOV	{"phone": "+70333843504"}
0005432145118	C2589C	5335 686318	NATALYA KISELEVA	{"phone": "+70878955141"}
0005432145119	126039	5123 067367	EVGENIYA SEMENOVA	{"email": "evgeniyasemenova24091962@postgrespro.ru", "phone": "+70183488531"}
0005432145120	CB39F6	9298 219996	NADEZHDA MIKHAYLOVA	{"phone": "+70925488596"}
0005432145121	CB39F6	9290 472203	OLGA VOLKOVA	{"email": "volkova_olga.091965@postgrespro.ru", "phone": "+70110994435"}
0005432145122	327BAA	4498 831300	ELENA KUZNECOVA	{"phone": "+70467420006"}
0005432145123	9A2813	1632 838667	MATVEY ILIN	{"email": "m_ilin_29071967@postgrespro.ru", "phone": "+70062899809"}
0005432145124	7F53CC	2145 524571	ARTEM GORBUNOV	{"phone": "+70567337568"}
0005432145125	4C848D	5963 655518	ALEKSANDR DENISOV	{"phone": "+70812213054"}
0005432145126	F450B0	6726 266556	ANASTASIYA POPOVA	{"phone": "+70015959036"}
0005432145127	D3AC61	2331 189826	VALENTINA BARANOVA	{"phone": "+70057325371"}
0005432145128	9E88F7	3267 207996	ARTEM ZAKHAROV	{"email": "zakharov_a-1978@postgrespro.ru", "phone": "+70796671575"}
0005432145129	9E88F7	0476 021016	DENIS PAVLOV	{"email": "pavlov-denis-1968@postgrespro.ru", "phone": "+70839887677"}
0005432145130	181106	9947 927240	RUSLAN KOZLOV	{"phone": "+70334403674"}
0005432145131	181106	9461 827964	EKATERINA ROMANOVA	{"phone": "+70012626861"}
0005432145132	181106	5449 472178	NATALYA ZHUKOVA	{"phone": "+70481997619"}
0005432145133	181106	0522 322243	YANA SCHERBAKOVA	{"phone": "+70138859325"}
0005432145134	96AC17	8932 002980	NATALYA KUZNECOVA	{"phone": "+70128918637"}
0005432145135	03CFD1	6690 274363	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov.041972@postgrespro.ru", "phone": "+70017859849"}
0005432145136	CF98D7	3056 369827	ELENA KAZAKOVA	{"email": "kazakova_e.111959@postgrespro.ru", "phone": "+70368053142"}
0005432145137	0B8A07	9296 285587	ALEKSANDR TIKHONOV	{"email": "tikhonov.a.19121971@postgrespro.ru", "phone": "+70845803897"}
0005432145138	0B8A07	5893 375238	EKATERINA CHERNOVA	{"email": "e_chernova-031972@postgrespro.ru", "phone": "+70388090725"}
0005432145139	E15831	3775 742788	DMITRIY ORLOV	{"email": "orlov_dmitriy-051973@postgrespro.ru", "phone": "+70225546983"}
0005432145140	E15831	4888 774796	ELENA POTAPOVA	{"email": "e.potapova1979@postgrespro.ru", "phone": "+70934874508"}
0005432145141	878B4B	3051 805425	NINA SMIRNOVA	{"email": "smirnova.nina_08111970@postgrespro.ru", "phone": "+70426929758"}
0005432145142	7F00B2	1711 520779	ALEKSEY KUZMIN	{"email": "kuzmina.17051967@postgrespro.ru", "phone": "+70036281406"}
0005432145143	79EC17	8316 947356	ANATOLIY SHEVCHENKO	{"email": "shevchenko-anatoliy_101976@postgrespro.ru", "phone": "+70648184476"}
0005432145144	FCA792	0948 955923	IRINA DMITRIEVA	{"email": "dmitrieva_irina1961@postgrespro.ru", "phone": "+70786883701"}
0005432145145	D6354C	7280 160578	NATALYA PETROVA	{"phone": "+70324259386"}
0005432145146	D6354C	4071 642370	ELENA FEDOROVA	{"phone": "+70546364095"}
0005432145147	761E24	0656 316016	ALEKSANDR TARASOV	{"phone": "+70194664864"}
0005432145148	6F8E0D	4177 087801	NATALYA IVANOVA	{"phone": "+70351070669"}
0005432145149	9CDECE	9745 736509	SALAVAT FILIPPOV	{"email": "salavat_filippov.041966@postgrespro.ru", "phone": "+70325578408"}
0005432145150	9CDECE	9629 426657	ANGELINA SMIRNOVA	{"email": "angelinasmirnova041971@postgrespro.ru", "phone": "+70976640486"}
0005432145151	4825B6	7378 626555	ANNA NESTEROVA	{"email": "nesterova.a1972@postgrespro.ru", "phone": "+70658419050"}
0005432145152	4825B6	3161 299139	SERGEY STEPANOV	{"phone": "+70337898902"}
0005432145153	BB0559	7896 191062	LIDIYA NOVIKOVA	{"email": "novikova-l.051972@postgrespro.ru", "phone": "+70871244866"}
0005432145154	D6AB22	7868 087307	OKSANA LEBEDEVA	{"email": "lebedeva_o021980@postgrespro.ru", "phone": "+70500139004"}
0005432145155	D6AB22	9456 392328	SERGEY ZAKHAROV	{"phone": "+70607137406"}
0005432145156	50D0F8	7149 581122	SEMEN KARPOV	{"phone": "+70211188605"}
0005432145157	233A9E	5979 823222	SVETLANA NESTEROVA	{"email": "nesterova-svetlana.121975@postgrespro.ru", "phone": "+70201517828"}
0005432145158	A41958	6540 859965	EVGENIYA ORLOVA	{"phone": "+70117698366"}
0005432145159	484806	7457 694035	MIKHAIL BORISOV	{"email": "borisovmikhail-24101973@postgrespro.ru", "phone": "+70313642936"}
0005432145160	484806	9851 327791	ELENA SEMENOVA	{"email": "semenova_e.1966@postgrespro.ru", "phone": "+70030810222"}
0005432145161	6500C4	5457 585142	NATALYA PAVLOVA	{"email": "pavlovanatalya15111959@postgrespro.ru", "phone": "+70505349983"}
0005432145162	6500C4	5043 289140	ALEKSANDR YAKOVLEV	{"phone": "+70309835431"}
0005432145163	360289	1670 142367	VALENTINA FEDOROVA	{"email": "fedorova.v.1975@postgrespro.ru", "phone": "+70998810043"}
0005432145164	5FE53F	3936 152488	TATYANA ILINA	{"email": "ilina-t.1979@postgrespro.ru", "phone": "+70725054818"}
0005432145165	32A923	1227 655836	NATALYA IVANOVA	{"phone": "+70989401872"}
0005432145166	D6ED79	0577 601017	EVGENIY SCHERBAKOV	{"email": "evgeniy-scherbakov-111959@postgrespro.ru", "phone": "+70157136092"}
0005432145167	4B5FDE	3872 022624	MARIYA ALEKSEEVA	{"phone": "+70047108646"}
0005432145168	4B5FDE	9272 734863	TAMARA POPOVA	{"email": "popova.tamara101967@postgrespro.ru", "phone": "+70218098445"}
0005432145169	245827	9604 664723	NINA POPOVA	{"phone": "+70950646195"}
0005432145170	3B0535	9268 875526	VADIM VOLKOV	{"phone": "+70060469913"}
0005432145171	3B0535	5889 386476	NATALYA ALEKSEEVA	{"phone": "+70528723202"}
0005432145172	7FD2C0	3353 376794	OLGA SIDOROVA	{"email": "olga-sidorova_04011977@postgrespro.ru", "phone": "+70241996821"}
0005432145173	7FD2C0	5492 970907	ROZA VOLKOVA	{"email": "volkova_r-1984@postgrespro.ru", "phone": "+70360965136"}
0005432146163	AB47AD	9645 631347	KIRA BOGDANOVA	{"phone": "+70727374017"}
0005432146164	3D49C5	9796 528189	NIKITA NIKITIN	{"email": "nikitinnikita_13111971@postgrespro.ru", "phone": "+70698197155"}
0005432146165	3D49C5	7594 148998	ANNA KALININA	{"email": "a-kalinina.03061982@postgrespro.ru", "phone": "+70417105116"}
0005432146166	E3C589	4983 750650	OLGA ZOTOVA	{"email": "ozotova_26051975@postgrespro.ru", "phone": "+70678308579"}
0005432146167	561FCF	6683 559819	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_1976@postgrespro.ru", "phone": "+70804102842"}
0005432146168	561FCF	8341 201351	NIKOLAY KUDRYASHOV	{"phone": "+70703174822"}
0005432146169	561FCF	7044 487870	VALERIY GORBUNOV	{"phone": "+70719859151"}
0005432146170	561FCF	8234 270671	ALEKSANDR SMIRNOV	{"email": "smirnov_a-1971@postgrespro.ru", "phone": "+70790046087"}
0005432146171	F6DE8F	8554 467721	EVGENIY CHERNOV	{"email": "chernov.e.22021963@postgrespro.ru", "phone": "+70183082001"}
0005432146172	1CC723	7199 684380	OLGA ILINA	{"email": "ilina-olga-071983@postgrespro.ru", "phone": "+70176622621"}
0005432146173	EEA56F	5807 170331	ALEKSANDR ZHUKOV	{"email": "zhukov-a_101976@postgrespro.ru", "phone": "+70148143207"}
0005432146174	EEA56F	2532 306880	ELENA SOROKINA	{"email": "e.sorokina061973@postgrespro.ru", "phone": "+70580573711"}
0005432146175	A9170F	7972 680883	ALEKSEY IVANOV	{"phone": "+70108557612"}
0005432146176	1378F2	7732 335670	ALEKSANDR MARTYNOV	{"email": "martynov.a-061973@postgrespro.ru", "phone": "+70196373094"}
0005432146177	1378F2	0982 166449	ELENA OVCHINNIKOVA	{"phone": "+70177658609"}
0005432146178	A5AB1E	3812 070341	ELENA KUZNECOVA	{"phone": "+70353312706"}
0005432146179	A5AB1E	5265 990641	VLADISLAV NIKITIN	{"phone": "+70415398916"}
0005432146180	D3DE9D	9602 852850	SERGEY SAVELEV	{"email": "ssavelev-111961@postgrespro.ru", "phone": "+70750601642"}
0005432146181	D3DE9D	4697 312770	OLGA BARANOVA	{"email": "o_baranova.03091970@postgrespro.ru", "phone": "+70402241945"}
0005432146182	5A4BA2	2973 181176	NATALYA SOLOVEVA	{"email": "natalya-soloveva.1956@postgrespro.ru", "phone": "+70225322222"}
0005432146183	5A4BA2	5037 193102	VASILIY GUSEV	{"email": "vasiliygusev.24071965@postgrespro.ru", "phone": "+70726844101"}
0005432146184	DF9D93	8784 635300	MIKHAIL MOROZOV	{"email": "m.morozov1959@postgrespro.ru", "phone": "+70257579333"}
0005432146185	DF9D93	3267 042158	PRASKOVYA KUDRYASHOVA	{"email": "kudryashova.praskovya.1963@postgrespro.ru", "phone": "+70045400438"}
0005432146186	11AC18	9025 272233	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko31081974@postgrespro.ru", "phone": "+70391955679"}
0005432146187	332510	8164 528764	LARISA ISAEVA	{"phone": "+70202764218"}
0005432146188	79F059	2668 005832	LYUDMILA ZAYCEVA	{"email": "lyudmila_zayceva_19061982@postgrespro.ru", "phone": "+70307742995"}
0005432146189	3D4882	2219 168408	ANNA IVANOVA	{"email": "ivanovaanna.01021987@postgrespro.ru", "phone": "+70094021595"}
0005432146190	3D4882	8960 871147	LIDIYA FILATOVA	{"phone": "+70606267839"}
0005432146191	FB02FB	0950 145923	ANNA SOROKINA	{"phone": "+70702769587"}
0005432146192	915C1B	1118 683984	OLGA SEMENOVA	{"email": "semenova_o.1978@postgrespro.ru", "phone": "+70787540302"}
0005432146193	5EEFC8	2960 127952	NINA SOROKINA	{"email": "n.sorokina_1963@postgrespro.ru", "phone": "+70850601652"}
0005432146194	5EEFC8	5708 727265	OLEG PETROV	{"phone": "+70744400517"}
0005432146195	02609A	5140 959662	ANDREY KUZNECOV	{"email": "kuznecovandrey-1970@postgrespro.ru", "phone": "+70637670856"}
0005432146196	9A0B27	6339 011996	NIKOLAY ZAYCEV	{"email": "nikolay-zaycev.08011990@postgrespro.ru", "phone": "+70022091563"}
0005432146197	D184F1	7213 979840	RAVIL KUZNECOV	{"phone": "+70466787496"}
0005432146198	CAF695	3316 262480	OKSANA MIRONOVA	{"phone": "+70386887865"}
0005432146199	975ECA	0525 090788	VIKTOR MAKSIMOV	{"phone": "+70110183426"}
0005432146200	A48878	9128 153787	ALFIYA ZHURAVLEVA	{"phone": "+70435135469"}
0005432146201	D62691	0373 398581	MURAD TIKHONOV	{"phone": "+70063879772"}
0005432146202	DF83D9	7779 282713	ALEKSANDR SEMENOV	{"phone": "+70230937832"}
0005432146203	34AE2D	9524 873789	DMITRIY EGOROV	{"phone": "+70385263293"}
0005432146204	34AE2D	8482 180500	YURIY NAZAROV	{"email": "y.nazarov_01051973@postgrespro.ru", "phone": "+70911162948"}
0005432146205	56FCC6	6299 626268	TATYANA RODIONOVA	{"email": "trodionova.29091983@postgrespro.ru", "phone": "+70097708574"}
0005432146206	B385EF	5753 414451	GALINA GUSEVA	{"email": "guseva-galina-1958@postgrespro.ru", "phone": "+70364804827"}
0005432146207	E536F5	5825 520954	SERGEY PAVLOV	{"phone": "+70899248842"}
0005432146208	E536F5	4577 284195	TAISIYA IVANOVA	{"email": "ivanovat1982@postgrespro.ru", "phone": "+70032754953"}
0005432146209	00FC75	0922 828022	KLARA ZHUKOVA	{"phone": "+70016581274"}
0005432146210	DBB202	8036 076090	LYUDMILA KUZMINA	{"email": "kuzmina-l071972@postgrespro.ru", "phone": "+70098233144"}
0005432146211	DBB202	6290 268532	VALENTINA ALEKSEEVA	{"phone": "+70009349113"}
0005432146212	410E81	9463 906185	SERGEY DAVYDOV	{"email": "davydovs17031973@postgrespro.ru", "phone": "+70189064380"}
0005432146213	410E81	5702 033093	PETR PAVLOV	{"email": "petrpavlov071961@postgrespro.ru", "phone": "+70422232152"}
0005432146214	416460	3317 693264	VITALIY YAKOVLEV	{"email": "yakovlev_vitaliy-061981@postgrespro.ru", "phone": "+70691781015"}
0005432146215	6BA16F	3709 204844	ILYA FILIPPOV	{"email": "ifilippov021978@postgrespro.ru", "phone": "+70987619004"}
0005432146216	868A13	7579 923894	TATYANA KUZMINA	{"phone": "+70159091487"}
0005432146217	868A13	8767 092872	ILYA KUZMIN	{"email": "kuzmin-i1975@postgrespro.ru", "phone": "+70759521323"}
0005432146218	DC1FCC	9730 707442	YULIYA SOROKINA	{"email": "yuliyasorokina_1966@postgrespro.ru", "phone": "+70241700213"}
0005432146219	0AE9C7	1830 652162	LYUBOV ZHURAVLEVA	{"phone": "+70771198351"}
0005432146220	D3D241	8256 652923	DENIS SAVELEV	{"email": "denis_savelev111966@postgrespro.ru", "phone": "+70170882259"}
0005432146221	789823	5599 343477	NATALYA NAZAROVA	{"phone": "+70253440616"}
0005432146222	58D992	0618 718031	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov051966@postgrespro.ru", "phone": "+70040894429"}
0005432146223	DC01F8	9616 521079	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila.011964@postgrespro.ru", "phone": "+70053270187"}
0005432146224	A7AEE8	8996 069509	VASILISA NIKOLAEVA	{"phone": "+70000671749"}
0005432146225	9145F1	9101 666093	NIKOLAY ANTONOV	{"email": "nikolay-antonov.1969@postgrespro.ru", "phone": "+70225784250"}
0005432146226	9145F1	3779 834043	LYUBOV MATVEEVA	{"phone": "+70933759678"}
0005432146227	9145F1	3273 095501	SERGEY NIKOLAEV	{"email": "nikolaev_s_041983@postgrespro.ru", "phone": "+70180611973"}
0005432146228	4F8496	8856 302271	ALEKSEY NIKITIN	{"phone": "+70178313940"}
0005432146229	2EBC40	1468 794552	ANDREY KARPOV	{"email": "karpov.andrey-121972@postgrespro.ru", "phone": "+70027374161"}
0005432146230	2EBC40	1043 503870	SERGEY MIKHAYLOV	{"email": "mikhaylovs.1965@postgrespro.ru", "phone": "+70614974494"}
0005432146231	FCAB90	0986 438470	NATALYA KOROLEVA	{"phone": "+70298250882"}
0005432146232	2D7B50	2367 641226	IGOR NOVIKOV	{"phone": "+70676803147"}
0005432146233	6357EE	4407 215170	ALEKSANDR SEMENOV	{"phone": "+70186380614"}
0005432146234	02AB35	0724 475435	IRINA RODIONOVA	{"phone": "+70379373759"}
0005432146235	02AB35	1462 504201	PAVEL MELNIKOV	{"phone": "+70269666787"}
0005432146236	F4A406	9040 062633	DMITRIY ABRAMOV	{"phone": "+70628144782"}
0005432146237	D5CAA2	0005 446558	SVETLANA NAZAROVA	{"phone": "+70077928046"}
0005432146238	317119	9282 351094	DMITRIY YAKOVLEV	{"phone": "+70747640185"}
0005432146239	DADBA9	8985 874265	ANNA ZAKHAROVA	{"phone": "+70844311983"}
0005432146240	989103	8605 237722	VIKTOR KARPOV	{"phone": "+70235901324"}
0005432146241	989103	7714 545647	LILIYA EFREMOVA	{"email": "liliya-efremova-061968@postgrespro.ru", "phone": "+70618650740"}
0005432146242	136EA6	2701 041193	ANTON KUZNECOV	{"phone": "+70325507037"}
0005432146243	C9114E	9057 890282	ILYA SIDOROV	{"email": "sidorov.i_061973@postgrespro.ru", "phone": "+70695436980"}
0005432146244	E04742	1108 959215	VLADISLAV SCHERBAKOV	{"phone": "+70194431280"}
0005432146245	E04742	6078 888831	VERA ABRAMOVA	{"phone": "+70226415243"}
0005432146246	E04742	6275 037055	ALISA KUZNECOVA	{"email": "kuznecova.a021958@postgrespro.ru", "phone": "+70985797859"}
0005432146247	E04742	9964 668159	LYUDMILA ROMANOVA	{"phone": "+70337129714"}
0005432146248	579C6E	4297 892220	YURIY DMITRIEV	{"email": "yuriydmitriev091976@postgrespro.ru", "phone": "+70418613684"}
0005432146249	579C6E	6937 951898	IGOR TIMOFEEV	{"phone": "+70902673095"}
0005432146250	579C6E	2347 306726	VALERIY IVANOV	{"email": "valeriy_ivanov-081971@postgrespro.ru", "phone": "+70470209396"}
0005432146251	588C9A	9239 214261	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova-1973@postgrespro.ru", "phone": "+70405778058"}
0005432146252	588C9A	1865 028243	MIKHAIL NOVIKOV	{"email": "m.novikov-031966@postgrespro.ru", "phone": "+70309415821"}
0005432146253	588C9A	0087 868445	ALEKSANDR MOISEEV	{"email": "a-moiseev_1978@postgrespro.ru", "phone": "+70758094032"}
0005432146254	023AB5	6007 460405	VIKTOR TIKHONOV	{"email": "viktor.tikhonov_09031966@postgrespro.ru", "phone": "+70818081081"}
0005432146255	6EC424	1356 690536	MIKHAIL MELNIKOV	{"email": "melnikov_m-18011969@postgrespro.ru", "phone": "+70754092233"}
0005432146256	5E85DD	8370 709429	VADIM TIMOFEEV	{"email": "timofeev-v.1968@postgrespro.ru", "phone": "+70109459057"}
0005432146257	5E85DD	3993 489828	ILNUR IVANOV	{"phone": "+70357749766"}
0005432146258	B4A2CF	8058 805365	GALINA MEDVEDEVA	{"email": "g-medvedeva26101981@postgrespro.ru", "phone": "+70049677274"}
0005432146259	D66F38	2703 379812	VALERIY POPOV	{"email": "valeriy-popov.121976@postgrespro.ru", "phone": "+70603665011"}
0005432150054	0DCC06	8094 871967	NIKOLAY FEDOROV	{"phone": "+70206669081"}
0005432150055	F1113C	1526 497769	NIKOLAY NAUMOV	{"email": "naumov.nikolay-041960@postgrespro.ru", "phone": "+70769929671"}
0005432150056	2566D4	5318 651621	VIKTOR SOKOLOV	{"email": "sokolov_v_14031967@postgrespro.ru", "phone": "+70563702921"}
0005432150057	2566D4	6397 042370	GALINA SEMENOVA	{"email": "gsemenova-021967@postgrespro.ru", "phone": "+70867397237"}
0005432150058	D22015	4882 073006	TATYANA ZAKHAROVA	{"phone": "+70714957426"}
0005432150059	D22015	2924 836299	ROZA STEPANOVA	{"email": "r.stepanova091969@postgrespro.ru", "phone": "+70024255588"}
0005432150060	89EF7F	8716 805587	SERGEY POPOV	{"phone": "+70961836255"}
0005432150061	1F3773	8005 663441	BORIS NIKOLAEV	{"email": "nikolaevb121971@postgrespro.ru", "phone": "+70004759555"}
0005432150062	1F3773	0908 696123	ARTEM STEPANOV	{"email": "artem.stepanov031977@postgrespro.ru", "phone": "+70992343723"}
0005432150063	26FB68	7934 319433	ANNA KOVALEVA	{"email": "kovaleva-a1973@postgrespro.ru", "phone": "+70813113675"}
0005432150064	26FB68	2366 031075	ANDREY ALEKSEEV	{"phone": "+70966597550"}
0005432150065	2A442C	5707 104036	VALERIY DENISOV	{"email": "valeriy.denisov-16051978@postgrespro.ru", "phone": "+70761367893"}
0005432150066	A1C4E8	5250 103624	EVGENIY IVANOV	{"phone": "+70374707195"}
0005432150067	2DACFB	5760 821679	LYUBOV BARANOVA	{"phone": "+70388863051"}
0005432150068	8A60EF	5871 911671	MAKSIM ORLOV	{"email": "m.orlov071974@postgrespro.ru", "phone": "+70673194826"}
0005432150069	330EA2	7039 450371	ELENA KULIKOVA	{"email": "elena.kulikova.051974@postgrespro.ru", "phone": "+70355804285"}
0005432150070	330EA2	8194 692609	KIRILL POPOV	{"phone": "+70877250899"}
0005432150071	EE1625	7855 104764	NATALYA PETROVA	{"email": "natalya_petrova_02011968@postgrespro.ru", "phone": "+70701098014"}
0005432150072	D887C6	8390 954098	ANASTASIYA SOKOLOVA	{"email": "a_sokolova1975@postgrespro.ru", "phone": "+70394440227"}
0005432150073	D887C6	1239 276743	VITALIY NAUMOV	{"email": "vnaumov_08081968@postgrespro.ru", "phone": "+70499324326"}
0005432150074	B22777	0947 520283	VALENTINA SERGEEVA	{"phone": "+70681593826"}
0005432150075	919F0B	0297 054253	ALEKSANDR ZAKHAROV	{"phone": "+70468465068"}
0005432150076	50786D	2623 411833	ILDAR SEMENOV	{"phone": "+70468914360"}
0005432150077	50786D	6889 489045	ZINAIDA BOGDANOVA	{"email": "bogdanovaz11121970@postgrespro.ru", "phone": "+70372595720"}
0005432150078	1228C7	8965 788710	VIKTOR VASILEV	{"phone": "+70033227989"}
0005432150079	1228C7	7299 855594	OKSANA MELNIKOVA	{"email": "melnikovao-011975@postgrespro.ru", "phone": "+70684578909"}
0005432150080	D9D33D	1125 306381	VALENTIN FEDOROV	{"phone": "+70459731747"}
0005432150081	9709F9	2326 409509	GENNADIY IVANOV	{"phone": "+70844226276"}
0005432150082	D2DA3F	0547 010295	EVGENIY ZHURAVLEV	{"phone": "+70508465123"}
0005432150083	8FB523	3834 983577	ANNA TIKHONOVA	{"phone": "+70879689170"}
0005432150084	8FB523	0646 701869	KSENIYA MIKHAYLOVA	{"phone": "+70460257264"}
0005432150085	FF0C39	7629 758366	KONSTANTIN POPOV	{"email": "k.popov-17041981@postgrespro.ru", "phone": "+70706491324"}
0005432150086	9C6854	8978 895174	VALENTINA DAVYDOVA	{"phone": "+70411418725"}
0005432150087	9C6854	4586 358852	MARIYA MALYSHEVA	{"phone": "+70787787990"}
0005432150088	4C932F	4799 186800	KIRILL ZAKHAROV	{"email": "k-zakharov.011966@postgrespro.ru", "phone": "+70225033278"}
0005432150089	3B60EC	4708 124966	TATYANA ZOTOVA	{"email": "t-zotova11021964@postgrespro.ru", "phone": "+70775396547"}
0005432150090	14CA43	0122 631258	ANASTASIYA TARASOVA	{"phone": "+70156354082"}
0005432150091	14CA43	2895 143054	VALENTINA EFIMOVA	{"email": "v.efimova_071978@postgrespro.ru", "phone": "+70698647816"}
0005432150092	CC085B	7703 551647	YURIY DMITRIEV	{"email": "yuriy-dmitriev.041978@postgrespro.ru", "phone": "+70223126448"}
0005432150093	CC085B	0590 985948	ANDREY SAVELEV	{"phone": "+70692484544"}
0005432150094	63D0A4	6524 307817	MARINA RODIONOVA	{"email": "m.rodionova-101970@postgrespro.ru", "phone": "+70358762171"}
0005432150095	0A1F06	8246 735889	VLADIMIR DMITRIEV	{"phone": "+70119170573"}
0005432150096	710654	8001 425805	FEDOR ANTONOV	{"email": "antonov.f_1970@postgrespro.ru", "phone": "+70110015922"}
0005432150097	76C91C	6774 481493	GENNADIY ROMANOV	{"email": "romanov-g_1970@postgrespro.ru", "phone": "+70695950346"}
0005432150098	76C91C	9937 985855	MIKHAIL IVANOV	{"email": "mikhail-ivanov-1973@postgrespro.ru", "phone": "+70185644662"}
0005432150099	621ECB	8131 254869	ELENA MOROZOVA	{"email": "morozova-e_1970@postgrespro.ru", "phone": "+70652238107"}
0005432150100	621ECB	9317 563684	GENNADIY NIKITIN	{"phone": "+70522036053"}
0005432150101	740908	8540 483597	EVGENIY EGOROV	{"phone": "+70308381593"}
0005432150102	740908	9840 626271	IVAN DMITRIEV	{"phone": "+70421181641"}
0005432150103	7AB086	6920 895976	ELENA MIRONOVA	{"phone": "+70964137003"}
0005432150104	7AB086	2927 466049	MARAT PAVLOV	{"email": "pavlovm.22031976@postgrespro.ru", "phone": "+70739201047"}
0005432150105	59B7A3	0363 235141	NATALYA TIMOFEEVA	{"email": "timofeeva_natalya-1965@postgrespro.ru", "phone": "+70741409772"}
0005432150106	59B7A3	6906 195077	DARYA ANDREEVA	{"email": "darya-andreeva_24061970@postgrespro.ru", "phone": "+70909941437"}
0005432150107	2A961E	1045 451161	RAISA KUZNECOVA	{"email": "kuznecova-raisa_1968@postgrespro.ru", "phone": "+70419422609"}
0005432150108	D940B0	8196 494376	NATALYA EGOROVA	{"email": "egorovanatalya091975@postgrespro.ru", "phone": "+70806938407"}
0005432150109	155303	0205 081793	LARISA EFIMOVA	{"phone": "+70976468958"}
0005432150110	C3E14F	1648 486097	ALBINA KOROLEVA	{"email": "albinakoroleva.29031980@postgrespro.ru", "phone": "+70798965936"}
0005432150111	A86230	1871 738882	NAIL KISELEV	{"email": "nkiselev_061967@postgrespro.ru", "phone": "+70091156004"}
0005432150112	807980	0306 690103	GALINA KUDRYASHOVA	{"phone": "+70524296643"}
0005432150113	E60072	9065 041614	VALENTINA KUZMINA	{"phone": "+70188975876"}
0005432150114	A090D4	1573 196030	ALEKSEY SIDOROV	{"phone": "+70135456436"}
0005432150115	A090D4	1077 274492	LARISA KOROLEVA	{"email": "koroleval_041970@postgrespro.ru", "phone": "+70921401785"}
0005432150116	2E707A	9203 883788	NATALYA MOROZOVA	{"phone": "+70316603780"}
0005432150117	18B4ED	5429 860331	DMITRIY KISELEV	{"email": "kiselev.dmitriy.01051973@postgrespro.ru", "phone": "+70623931623"}
0005432150118	67C0C5	2936 943580	NATALYA ALEKSEEVA	{"email": "natalya-alekseeva.1970@postgrespro.ru", "phone": "+70934556836"}
0005432150119	93699A	6747 997941	VALERIY PAVLOV	{"email": "pavlovv_08091980@postgrespro.ru", "phone": "+70389113088"}
0005432150120	93699A	4445 445065	VYACHESLAV SOROKIN	{"phone": "+70205931118"}
0005432150121	87533C	8119 944206	SERGEY FEDOROV	{"phone": "+70959934223"}
0005432150122	87533C	0782 914867	VERA AFANASEVA	{"email": "afanasevavera-14121973@postgrespro.ru", "phone": "+70087615318"}
0005432150123	E955B2	3296 386783	VALERIYA MIRONOVA	{"phone": "+70766850421"}
0005432150124	E955B2	1264 233334	ALEKSEY ZAKHAROV	{"phone": "+70919578721"}
0005432150125	E05329	3644 072515	LYUDMILA TITOVA	{"email": "ltitova_1971@postgrespro.ru", "phone": "+70104679352"}
0005432150126	F9063F	9052 943980	OLGA IVANOVA	{"email": "ivanovaolga07021974@postgrespro.ru", "phone": "+70986622599"}
0005432150127	F9063F	9594 947861	SERGEY PETROV	{"phone": "+70982276312"}
0005432150128	301F68	2032 312441	SVETLANA KOZLOVA	{"phone": "+70013367144"}
0005432150129	C766DB	2325 301391	DANIIL VOROBEV	{"phone": "+70622416001"}
0005432150130	173F22	2386 322405	SVETLANA KOMAROVA	{"email": "komarova-s-081981@postgrespro.ru", "phone": "+70366827459"}
0005432150131	173F22	2782 814269	NIKOLAY IVANOV	{"email": "ivanov_n1975@postgrespro.ru", "phone": "+70978556915"}
0005432150132	300AF5	3187 137918	VALERIY FROLOV	{"email": "valeriy.frolov.051975@postgrespro.ru", "phone": "+70897310771"}
0005432150133	300AF5	8875 535904	MARAT KARPOV	{"email": "karpov_marat_051977@postgrespro.ru", "phone": "+70573422312"}
0005432150134	0395FB	9923 780893	ROMAN VASILEV	{"email": "romanvasilev.1969@postgrespro.ru", "phone": "+70725078153"}
0005432150135	44AAC4	6610 950212	SERGEY KULIKOV	{"phone": "+70064283384"}
0005432150136	B1710C	2989 325005	KONSTANTIN TIKHONOV	{"phone": "+70326934810"}
0005432150137	B1710C	0697 331308	SERGEY POPOV	{"phone": "+70439135722"}
0005432150138	FACAA0	3335 286879	NIKOLAY TARASOV	{"email": "n-tarasov_07061979@postgrespro.ru", "phone": "+70323044457"}
0005432150139	7F984F	5521 526720	EVGENIY OSIPOV	{"email": "osipov-e_26071981@postgrespro.ru", "phone": "+70699353127"}
0005432150140	387425	7933 332507	DMITRIY SOKOLOV	{"email": "dsokolov_1962@postgrespro.ru", "phone": "+70999565278"}
0005432150141	5564BA	7333 108177	EVGENIYA SEMENOVA	{"phone": "+70558811217"}
0005432150142	5564BA	9260 282332	VIKTORIYA EFIMOVA	{"phone": "+70669521772"}
0005432150143	DBA71D	5566 016729	NIKITA FEDOROV	{"phone": "+70788302187"}
0005432150144	376C82	6322 205363	DMITRIY NIKOLAEV	{"phone": "+70471592249"}
0005432150145	376C82	3606 472358	ALEKSANDR ALEKSANDROV	{"phone": "+70888334436"}
0005432150146	A77B7B	8176 707939	DARYA SEMENOVA	{"phone": "+70288124638"}
0005432150147	B55BA4	0593 295683	KIRILL VASILEV	{"phone": "+70027645688"}
0005432150148	B55BA4	8634 655392	SVETLANA KALININA	{"email": "kalininas-011970@postgrespro.ru", "phone": "+70296013191"}
0005432150149	C43C2E	2207 799521	DMITRIY BARANOV	{"email": "d_baranov01121971@postgrespro.ru", "phone": "+70945006374"}
0005432150150	A01F67	9564 029853	TATYANA GERASIMOVA	{"email": "gerasimova.tatyana_1964@postgrespro.ru", "phone": "+70958405539"}
0005432150151	AE06F6	6850 833910	VLADIMIR PETROV	{"email": "petrov_vladimir13021970@postgrespro.ru", "phone": "+70300244723"}
0005432150152	646866	5247 375770	VALENTIN SOKOLOV	{"email": "v-sokolov-1962@postgrespro.ru", "phone": "+70420636152"}
0005432150153	745FF4	1948 784019	ZOYA BOGDANOVA	{"phone": "+70094066815"}
0005432150154	F149AA	0505 087626	SHAVKAT SIDOROV	{"email": "sidorovshavkat-25041977@postgrespro.ru", "phone": "+70508103812"}
0005432150155	F149AA	7311 270200	IVAN MIRONOV	{"phone": "+70057205157"}
0005432150156	208D4A	3053 993010	NINA GERASIMOVA	{"phone": "+70483685838"}
0005432150157	90B4BC	1423 736214	IRINA KOROLEVA	{"email": "koroleva-irina-011976@postgrespro.ru", "phone": "+70313722760"}
0005432150158	90B4BC	4728 345886	YURIY IVANOV	{"phone": "+70977670849"}
0005432150159	A83998	6522 235917	ANNA NESTEROVA	{"phone": "+70220982729"}
0005432150160	821A34	8219 020833	OLGA KOROLEVA	{"email": "o_koroleva1980@postgrespro.ru", "phone": "+70743343823"}
0005432150161	9C7D8F	1001 251380	FANIS MIKHAYLOV	{"email": "fmikhaylov.061969@postgrespro.ru", "phone": "+70071977602"}
0005432150162	FF7655	2859 242733	EKATERINA KUZNECOVA	{"phone": "+70422311917"}
0005432150163	70A65E	1065 271020	PAVEL ORLOV	{"phone": "+70681384879"}
0005432150164	C11254	5252 279406	VALENTINA CHERNOVA	{"phone": "+70363787614"}
0005432150165	1A3BD6	0110 555400	LYUDMILA ANDREEVA	{"phone": "+70308480522"}
0005432150166	69BB5F	5058 792023	VALENTINA BARANOVA	{"phone": "+70429708108"}
0005432150167	03219C	4973 423433	DMITRIY PETROV	{"email": "dmitriy_petrov.1962@postgrespro.ru", "phone": "+70071910976"}
0005432150168	745A10	8420 039897	ANDREY ALEKSANDROV	{"email": "andreyaleksandrov-02021969@postgrespro.ru", "phone": "+70837366294"}
0005432150169	A9F6E9	5403 837793	RAISA POLYAKOVA	{"email": "r_polyakova-101977@postgrespro.ru", "phone": "+70576953012"}
0005432150170	27C1F4	3756 907587	PETR FROLOV	{"email": "frolovpetr-081968@postgrespro.ru", "phone": "+70069893867"}
0005432150171	73BC27	6870 663609	VALENTINA IVANOVA	{"phone": "+70123081756"}
0005432150172	282EA7	3831 061573	DANIIL FILIPPOV	{"phone": "+70075115851"}
0005432150173	976EBC	4138 720296	IRINA POPOVA	{"email": "popovairina_121974@postgrespro.ru", "phone": "+70752563223"}
0005432150174	976EBC	4322 240075	VLADIMIR ILIN	{"email": "v_ilin_011971@postgrespro.ru", "phone": "+70903447991"}
0005432150175	7F1B8D	1960 388300	IRINA KUZNECOVA	{"email": "kuznecovairina_27121969@postgrespro.ru", "phone": "+70974002001"}
0005432150176	7F1B8D	9304 442379	NIKITA MIKHAYLOV	{"phone": "+70011194160"}
0005432150177	9EF37C	2511 671582	SERGEY IVANOV	{"email": "s.ivanov_1986@postgrespro.ru", "phone": "+70624458468"}
0005432150178	FBE0F6	3657 709226	NADEZHDA TIMOFEEVA	{"email": "timofeevan111964@postgrespro.ru", "phone": "+70121074728"}
0005432150179	FBE0F6	1271 364041	ALEKSANDR BELOV	{"email": "a-belov13121967@postgrespro.ru", "phone": "+70271899665"}
0005432150180	384A1D	9709 446603	PAVEL MAKAROV	{"email": "p_makarov_021976@postgrespro.ru", "phone": "+70084130457"}
0005432150181	384A1D	9596 073385	ALEKSEY FOMIN	{"email": "aleksey-fomin.26121974@postgrespro.ru", "phone": "+70211043927"}
0005432150182	B1843C	1282 924746	EVGENIY SOLOVEV	{"email": "solovev-evgeniy1968@postgrespro.ru", "phone": "+70996539583"}
0005432150183	3D1569	7331 510102	MARIYA FEDOROVA	{"phone": "+70558231640"}
0005432150184	268FC5	5509 448603	NADEZHDA DAVYDOVA	{"phone": "+70905530566"}
0005432150185	0FACB1	0674 324259	ALEKSEY MIRONOV	{"phone": "+70154955806"}
0005432150186	ACD00A	5030 134308	VLADIMIR SMIRNOV	{"email": "smirnov.v_1980@postgrespro.ru", "phone": "+70402868797"}
0005432150187	9CB4E1	6287 550460	VALENTIN FOMIN	{"phone": "+70816982395"}
0005432150188	47A8EE	1712 784202	NATALYA KRASNOVA	{"phone": "+70105520833"}
0005432150189	47A8EE	5231 001016	DARYA ROMANOVA	{"email": "darya_romanova_27041975@postgrespro.ru", "phone": "+70823293600"}
0005432150190	6C46ED	1350 824628	MARGARITA OVCHINNIKOVA	{"email": "m_ovchinnikova-101980@postgrespro.ru", "phone": "+70790215609"}
0005432150191	1887AB	7836 210466	YULIYA FILIPPOVA	{"phone": "+70682211764"}
0005432150192	73A59E	9983 580272	NIKOLAY KUZNECOV	{"phone": "+70493552493"}
0005432150193	1FCD93	1291 640468	VIKTORIYA BARANOVA	{"email": "baranova-v.10031972@postgrespro.ru", "phone": "+70287758801"}
0005432150194	C87D51	2125 734788	ALEKSANDR ANDREEV	{"phone": "+70786238775"}
0005432150195	942CB9	1806 592416	KIRILL PAVLOV	{"email": "k_pavlov_1962@postgrespro.ru", "phone": "+70102027180"}
0005432150196	4EB1FA	7249 370585	ANASTASIYA LAZAREVA	{"phone": "+70805883365"}
0005432150197	D6FBB4	1147 096105	IRINA MAKAROVA	{"phone": "+70458113361"}
0005432150198	EFD543	9913 194623	EVGENIY CHERNOV	{"email": "e-chernov-02111966@postgrespro.ru", "phone": "+70677391365"}
0005432150199	EFD543	4067 885533	ALEKSANDR ANDREEV	{"phone": "+70991557968"}
0005432150200	E69D98	0205 703491	ANTON POPOV	{"phone": "+70903070831"}
0005432150201	E69D98	2344 900016	VIKTOR ROMANOV	{"phone": "+70048369707"}
0005432150202	96E228	4920 774649	EVGENIY FILIPPOV	{"email": "filippov.e-091970@postgrespro.ru", "phone": "+70365403488"}
0005432150203	383E5F	7969 923433	LYUBOV KAZAKOVA	{"email": "lkazakova_1962@postgrespro.ru", "phone": "+70328687791"}
0005432150204	24F224	3935 040135	ANTONINA PAVLOVA	{"phone": "+70545816586"}
0005432150205	7DE3AD	6639 963939	OKSANA KUZNECOVA	{"email": "oksana.kuznecova.1968@postgrespro.ru", "phone": "+70505918930"}
0005432150206	F1CDB8	1770 015474	ALBERT IVANOV	{"email": "albert.ivanov27081976@postgrespro.ru", "phone": "+70162517216"}
0005432150207	57EBDE	9309 024810	ELENA IVANOVA	{"email": "ivanova.elena041976@postgrespro.ru", "phone": "+70065941690"}
0005432150208	BE6DEF	8940 570946	IRINA MIKHAYLOVA	{"phone": "+70398222127"}
0005432150209	BE6DEF	9086 949494	ANNA MAKSIMOVA	{"phone": "+70475153852"}
0005432150210	40DF35	8927 273434	NATALYA LOGINOVA	{"phone": "+70710240351"}
0005432150211	40DF35	5618 590477	LYUBOV MOROZOVA	{"phone": "+70697591292"}
0005432150212	62B4C1	3335 013059	NIKOLAY PAVLOV	{"phone": "+70101216421"}
0005432150213	62B4C1	9544 888757	ALEKSEY MARTYNOV	{"email": "aleksey.martynov_28071964@postgrespro.ru", "phone": "+70801708317"}
0005432150214	D38877	1729 357875	VLADIMIR KARPOV	{"phone": "+70236142808"}
0005432150215	3BEB56	4892 662625	EVGENIY SEMENOV	{"email": "semenove-07111976@postgrespro.ru", "phone": "+70640815885"}
0005432150216	3BEB56	1139 492961	MARIYA GAVRILOVA	{"email": "mgavrilova.12031968@postgrespro.ru", "phone": "+70421880697"}
0005432150217	459AB6	0306 185916	ALEKSEY KUZNECOV	{"email": "kuznecov.a_15041978@postgrespro.ru", "phone": "+70693697359"}
0005432150218	459AB6	5189 319152	SERGEY FEDOTOV	{"phone": "+70899689755"}
0005432150219	0703D5	0394 725589	ALSU MATVEEVA	{"email": "alsu_matveeva_14051983@postgrespro.ru", "phone": "+70779635514"}
0005432150220	0703D5	2787 193777	NADEZHDA NIKITINA	{"phone": "+70489601975"}
0005432150221	A00449	5091 854744	SERGEY OSIPOV	{"email": "osipov_sergey_1978@postgrespro.ru", "phone": "+70480086894"}
0005432150222	358473	6561 590851	NATALYA BOGDANOVA	{"phone": "+70634798261"}
0005432150223	7C359A	6716 895821	TATYANA MARTYNOVA	{"email": "martynovatatyana_07071979@postgrespro.ru", "phone": "+70883462995"}
0005432150224	5CBBA8	4182 342832	SERGEY FROLOV	{"email": "sergey_frolov_07041960@postgrespro.ru", "phone": "+70135201201"}
0005432150225	7E21A6	3782 832265	DMITRIY TIMOFEEV	{"phone": "+70165117440"}
0005432150226	452195	0307 919250	ELENA YAKOVLEVA	{"phone": "+70294487687"}
0005432150227	452195	3708 902758	GEORGIY DMITRIEV	{"email": "dmitriev-g-1983@postgrespro.ru", "phone": "+70106638850"}
0005432150228	D51ED9	2610 462299	NIKOLAY KUDRYASHOV	{"email": "nikolay.kudryashov-1972@postgrespro.ru", "phone": "+70805755669"}
0005432150229	D51ED9	5937 143504	MARINA TARASOVA	{"email": "tarasova.marina-1967@postgrespro.ru", "phone": "+70112389528"}
0005432150230	C217FB	7908 018971	VITALIY KISELEV	{"phone": "+70750380922"}
0005432150231	C217FB	2367 351953	NADEZHDA LAZAREVA	{"phone": "+70248465342"}
0005432150232	94CD05	1606 927596	MARINA SOKOLOVA	{"email": "sokolova_marina_1980@postgrespro.ru", "phone": "+70725297116"}
0005432150233	2BB0CB	9477 199979	VYACHESLAV PETROV	{"phone": "+70167176229"}
0005432150234	5FC082	2566 611274	YULIYA KOZLOVA	{"phone": "+70191218801"}
0005432150235	0FCD95	6511 009633	RAFIK KONOVALOV	{"email": "rkonovalov-081971@postgrespro.ru", "phone": "+70713831104"}
0005432150236	8AC758	7364 708298	NIKITA MAKSIMOV	{"email": "maksimov_n-15051983@postgrespro.ru", "phone": "+70693496640"}
0005432150237	3853DC	0564 761300	VYACHESLAV SMIRNOV	{"phone": "+70110151884"}
0005432150238	730562	0632 882612	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-02061963@postgrespro.ru", "phone": "+70351799484"}
0005432150239	730562	0613 546655	LIDIYA TIKHONOVA	{"email": "l-tikhonova05121973@postgrespro.ru", "phone": "+70696262922"}
0005432150240	5961AA	4455 484694	EKATERINA ZHUKOVA	{"email": "ezhukova_1975@postgrespro.ru", "phone": "+70428556168"}
0005432150241	C7D1B1	9770 034293	VLADIMIR KAZAKOV	{"email": "kazakovvladimir091978@postgrespro.ru", "phone": "+70974902886"}
0005432150242	C7D1B1	4708 896575	ELIZAVETA IVANOVA	{"phone": "+70156155576"}
0005432150243	C8DDD5	6075 399395	DARYA NIKOLAEVA	{"phone": "+70048117273"}
0005432150244	C8DDD5	1131 148082	KIRILL GUSEV	{"phone": "+70588285694"}
0005432150245	C8DDD5	2706 285453	EKATERINA KONOVALOVA	{"phone": "+70839621137"}
0005432150246	AB4A99	7487 122198	VYACHESLAV TIKHONOV	{"email": "tikhonovv-091955@postgrespro.ru", "phone": "+70339081999"}
0005432150247	FD9F35	7902 868373	GALINA KUZNECOVA	{"phone": "+70900170213"}
0005432150248	FD9F35	0071 980362	VALERIY SMIRNOV	{"email": "smirnov.valeriy.041971@postgrespro.ru", "phone": "+70077257638"}
0005432150249	D26F2A	0067 421717	ANNA ISAEVA	{"phone": "+70009422546"}
0005432150250	DF9B10	3402 661450	VLADIMIR SAVELEV	{"phone": "+70888249556"}
0005432150251	DF9B10	2168 827773	ANATOLIY SHEVCHENKO	{"phone": "+70700013083"}
0005432150252	42E91A	0591 681019	MIKHAIL RODIONOV	{"email": "rodionov.m.041975@postgrespro.ru", "phone": "+70350445302"}
0005432150253	5D5FB4	1634 390748	ELENA ANDREEVA	{"email": "andreeva-elena.1968@postgrespro.ru", "phone": "+70246457024"}
0005432150254	4C2236	1877 676919	YAKOV SHEVCHENKO	{"phone": "+70613828699"}
0005432150255	521102	5009 715062	NATALIYA CHERNOVA	{"email": "chernova.nataliya_1974@postgrespro.ru", "phone": "+70953863246"}
0005432150256	8C3EF5	7950 037091	ULYANA ANDREEVA	{"phone": "+70895707835"}
0005432150257	8C3EF5	4304 469354	ARTEM SCHERBAKOV	{"email": "artem_scherbakov.1968@postgrespro.ru", "phone": "+70351830471"}
0005432150258	8C3EF5	0628 572009	ELVIRA EFREMOVA	{"phone": "+70802694937"}
0005432150259	EA71AC	7867 484569	OLGA DENISOVA	{"phone": "+70426876547"}
0005432150260	EA71AC	3989 062575	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr_1969@postgrespro.ru", "phone": "+70410680741"}
0005432150261	D3CAAF	2024 995295	TATYANA VOLKOVA	{"phone": "+70304934737"}
0005432150262	8E5B7A	4718 601536	MARIYA DENISOVA	{"phone": "+70565165812"}
0005432150263	8E5B7A	5689 206605	DMITRIY KOZLOV	{"email": "d_kozlov_28051963@postgrespro.ru", "phone": "+70197679128"}
0005432150264	CD4240	2429 760276	VALENTINA MOISEEVA	{"phone": "+70514241844"}
0005432150265	77D9D9	4204 703775	YURIY EGOROV	{"phone": "+70924689812"}
0005432150266	0AC179	5998 397458	VALERIY KUZMIN	{"email": "valeriy.kuzmin051975@postgrespro.ru", "phone": "+70661272014"}
0005432150267	0AC179	3066 143533	SERGEY MOISEEV	{"email": "moiseev_sergey.24041968@postgrespro.ru", "phone": "+70223922554"}
0005432150268	E9A1EC	9328 870481	VALENTINA BELOVA	{"phone": "+70203372677"}
0005432150269	E9A1EC	9426 490228	SVETLANA BELYAEVA	{"email": "belyaevasvetlana.21081978@postgrespro.ru", "phone": "+70435965177"}
0005432150270	9B8A53	4139 216201	NATALYA BELOVA	{"phone": "+70138426842"}
0005432150271	ACF58E	5648 242401	SERGEY MAKSIMOV	{"email": "maksimov.s_09101965@postgrespro.ru", "phone": "+70064426546"}
0005432150272	ACF58E	6747 292331	VIKTOR VLASOV	{"phone": "+70865418221"}
0005432150273	A64347	0681 680806	GALINA MIKHAYLOVA	{"email": "mikhaylovag.27071967@postgrespro.ru", "phone": "+70765775536"}
0005432150274	A64347	1222 815839	VLADIMIR FOMIN	{"email": "vfomin_031976@postgrespro.ru", "phone": "+70843350464"}
0005432150275	C292A8	3542 116208	ELENA VOLKOVA	{"phone": "+70046783933"}
0005432150276	6556C1	9937 773967	SVETLANA TIKHONOVA	{"email": "tikhonova-svetlana_25111972@postgrespro.ru", "phone": "+70107598536"}
0005432150277	41C453	6450 503213	VALERIYA ANTONOVA	{"email": "antonova_v091981@postgrespro.ru", "phone": "+70098479719"}
0005432150278	BE295E	0662 548388	ELENA MATVEEVA	{"email": "elena.matveeva081980@postgrespro.ru", "phone": "+70550090228"}
0005432150279	BE295E	1722 735624	ALEKSANDR ILIN	{"phone": "+70090595218"}
0005432150280	29CEE1	5233 928505	YULIYA KUZNECOVA	{"email": "y_kuznecova1971@postgrespro.ru", "phone": "+70781771141"}
0005432150281	29CEE1	0820 518287	VLADIMIR BONDARENKO	{"email": "bondarenko_v-1971@postgrespro.ru", "phone": "+70193859923"}
0005432150282	3DD719	5283 265512	VERA SOKOLOVA	{"phone": "+70178262640"}
0005432150283	54113F	5955 641386	ZHANNA SEMENOVA	{"email": "zhanna_semenova_19041977@postgrespro.ru", "phone": "+70520411756"}
0005432150284	F76A24	2514 168877	YULIYA OVCHINNIKOVA	{"email": "y-ovchinnikova_101987@postgrespro.ru", "phone": "+70349875945"}
0005432150285	F76A24	2779 708547	YULIYA FEDOROVA	{"email": "yuliya-fedorova31031965@postgrespro.ru", "phone": "+70479694573"}
0005432150286	F76A24	6303 327146	RAMIL BELOV	{"email": "r-belov11081980@postgrespro.ru", "phone": "+70812993359"}
0005432150287	F76A24	4463 719496	MIKHAIL ANDREEV	{"phone": "+70767248583"}
0005432150288	8E63EB	3264 852205	SERGEY GERASIMOV	{"email": "gerasimovsergey1975@postgrespro.ru", "phone": "+70027901856"}
0005432150289	3BBD84	9701 069374	NIKOLAY MOROZOV	{"email": "nikolay_morozov-061975@postgrespro.ru", "phone": "+70274579735"}
0005432150290	3BBD84	6673 219943	ALEKSANDR PETROV	{"phone": "+70899773865"}
0005432150291	F0E4F4	2996 328667	GALINA GORBUNOVA	{"email": "g_gorbunova_07011977@postgrespro.ru", "phone": "+70485964253"}
0005432150292	05224B	5414 777782	MATVEY MIKHAYLOV	{"email": "mikhaylovmatvey06071986@postgrespro.ru", "phone": "+70907495454"}
0005432150293	91A0BC	6535 433678	VYACHESLAV ILIN	{"phone": "+70185965588"}
0005432150294	3477D8	9793 098995	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr1969@postgrespro.ru", "phone": "+70264270898"}
0005432150295	3477D8	8219 766136	VALENTINA IVANOVA	{"email": "ivanova.valentina_101975@postgrespro.ru", "phone": "+70176171500"}
0005432150296	74BB91	0501 891652	VASILIY KUZNECOV	{"email": "kuznecov-vasiliy-051972@postgrespro.ru", "phone": "+70402471356"}
0005432150297	265F88	3339 916083	ANNA KUZNECOVA	{"email": "anna_kuznecova_051969@postgrespro.ru", "phone": "+70803146801"}
0005432150298	265F88	1257 484484	DMITRIY SAVELEV	{"email": "savelevdmitriy081978@postgrespro.ru", "phone": "+70657659623"}
0005432150299	C082D1	4320 024419	GENNADIY BONDARENKO	{"phone": "+70690179359"}
0005432150300	63BF17	5174 577819	YANA MAKAROVA	{"email": "makarova-yana-10121965@postgrespro.ru", "phone": "+70387049584"}
0005432150301	63BF17	7435 350220	KIRILL ZAYCEV	{"email": "k_zaycev-081974@postgrespro.ru", "phone": "+70238837440"}
0005432150302	C9F6C7	0381 124033	VIKTOR FILIPPOV	{"phone": "+70608772839"}
0005432150303	C9F6C7	0797 182380	DARYA OSIPOVA	{"email": "daryaosipova.121980@postgrespro.ru", "phone": "+70556280332"}
0005432150304	8888F6	0452 852686	SERGEY PAVLOV	{"email": "pavlov_sergey.28121979@postgrespro.ru", "phone": "+70123045940"}
0005432150305	4124CE	6921 542709	PAVEL SCHERBAKOV	{"phone": "+70468409126"}
0005432150306	4124CE	6181 751749	MARGARITA TARASOVA	{"email": "tarasova_margarita-021964@postgrespro.ru", "phone": "+70203316648"}
0005432150307	4124CE	0851 767299	ELENA ZHUKOVA	{"phone": "+70770601665"}
0005432150308	242317	9245 651213	OLGA VOLKOVA	{"email": "olga_volkova21011959@postgrespro.ru", "phone": "+70212995514"}
0005432150309	669877	7987 415749	LYUBOV KUZNECOVA	{"phone": "+70226078047"}
0005432150310	669877	1898 136317	PETR IVANOV	{"email": "ivanov-p1958@postgrespro.ru", "phone": "+70943011363"}
0005432150311	771A0D	8334 784599	NINA DAVYDOVA	{"email": "davydova_n051963@postgrespro.ru", "phone": "+70839508039"}
0005432150312	771A0D	6613 245692	VLADIMIR ZAYCEV	{"phone": "+70109307571"}
0005432150313	3DBAEC	3283 607429	STANISLAV MAKAROV	{"phone": "+70124598678"}
0005432150314	3DBAEC	8617 315164	NINA MAKAROVA	{"phone": "+70660414534"}
0005432150315	76E78F	4659 387993	ALEKSANDR AFANASEV	{"phone": "+70496262497"}
0005432150316	AEF6C3	7258 841450	ALEKSEY ABRAMOV	{"phone": "+70518168646"}
0005432150317	469B54	6145 609166	DANIIL ROMANOV	{"phone": "+70747697744"}
0005432150318	A56744	6401 888348	KAROLINA KOMAROVA	{"phone": "+70424953862"}
0005432150319	436341	5500 044165	ELENA MOROZOVA	{"email": "morozova_e1967@postgrespro.ru", "phone": "+70314369363"}
0005432150320	48EC94	0249 259085	DINARA KONDRATEVA	{"email": "dinara.kondrateva_031986@postgrespro.ru", "phone": "+70242286693"}
0005432150321	800054	8185 815234	LIDIYA VOLKOVA	{"phone": "+70538648028"}
0005432150322	B8366D	0257 796990	ALEKSANDRA IVANOVA	{"email": "a-ivanova30061977@postgrespro.ru", "phone": "+70774617878"}
0005432150323	334A45	3410 976267	ARSENIY FEDOTOV	{"email": "fedotov_arseniy_011976@postgrespro.ru", "phone": "+70201412440"}
0005432150324	334A45	4512 762819	ALEKSANDR IVANOV	{"phone": "+70736669986"}
0005432150325	21C7B5	3674 374027	LILIYA POPOVA	{"email": "popova_l1969@postgrespro.ru", "phone": "+70629895074"}
0005432150326	70B3F8	7096 765354	LYUBOV IVANOVA	{"email": "lyubov-ivanova.091973@postgrespro.ru", "phone": "+70020510889"}
0005432150327	70B3F8	4223 572637	LYUBOV KRASNOVA	{"email": "l_krasnova-19091957@postgrespro.ru", "phone": "+70209900632"}
0005432150328	FBB53E	8700 337881	SERGEY PAVLOV	{"phone": "+70628666835"}
0005432150329	FBB53E	4960 682228	NADEZHDA MARTYNOVA	{"phone": "+70395031765"}
0005432150330	93BB01	6515 905130	IVAN KOROLEV	{"email": "korolev_ivan_031982@postgrespro.ru", "phone": "+70421279408"}
0005432150331	93BB01	5238 339492	NATALYA FILATOVA	{"phone": "+70839608052"}
0005432150332	A84113	2790 541488	ALLA MASLOVA	{"email": "maslovaalla1974@postgrespro.ru", "phone": "+70735534170"}
0005432150333	B1AA44	9279 603661	VASILIY KUZNECOV	{"email": "kuznecovvasiliy11031969@postgrespro.ru", "phone": "+70190127748"}
0005432150334	CD44E4	8681 408612	GLEB ILIN	{"email": "g-ilin-24121974@postgrespro.ru", "phone": "+70423229423"}
0005432150335	43B252	1141 469925	VALERIY SIDOROV	{"phone": "+70682984900"}
0005432150336	C5F21C	0102 583491	OLEG ANTONOV	{"phone": "+70703177051"}
0005432150337	91296A	9372 297162	NIKITA ANTONOV	{"email": "antonov.nikita_1979@postgrespro.ru", "phone": "+70440444340"}
0005432150338	A8080E	3734 675189	SVETLANA GRISHINA	{"phone": "+70742549704"}
0005432150339	F184D1	9790 952402	VLADIMIR IVANOV	{"phone": "+70261412821"}
0005432150340	DE2D97	4247 227019	MARINA ROMANOVA	{"email": "romanova_m_051985@postgrespro.ru", "phone": "+70156689756"}
0005432150341	09BD67	7303 264338	ALEKSANDR TIKHONOV	{"email": "a-tikhonov121970@postgrespro.ru", "phone": "+70356826621"}
0005432150342	09BD67	0823 003025	VALERIY ANTONOV	{"email": "antonov-valeriy.031977@postgrespro.ru", "phone": "+70575163735"}
0005432150343	ABDC40	1990 199516	OLGA YAKOVLEVA	{"email": "olga_yakovleva-31031969@postgrespro.ru", "phone": "+70461990109"}
0005432150344	A033F2	1708 144928	MAKSIM BORISOV	{"email": "m_borisov_1978@postgrespro.ru", "phone": "+70069413630"}
0005432150345	A033F2	7134 046172	NATALIYA YAKOVLEVA	{"phone": "+70583549993"}
0005432150346	B1BB60	8849 298915	KSENIYA NAZAROVA	{"email": "nazarova.k071971@postgrespro.ru", "phone": "+70648324955"}
0005432150347	B0FE4F	7464 723846	ANASTASIYA SOROKINA	{"phone": "+70207820140"}
0005432150348	B0FE4F	2306 974683	KRISTINA YUDINA	{"email": "kyudina-06031979@postgrespro.ru", "phone": "+70454978864"}
0005432150349	7BF811	5486 478787	ALEKSEY MEDVEDEV	{"phone": "+70888647492"}
0005432150350	7BF811	4691 283244	ALEKSEY ILIN	{"email": "ilin_aleksey-031972@postgrespro.ru", "phone": "+70231064803"}
0005432150351	0EBCEC	7566 471078	FEDOR BELOV	{"phone": "+70535364389"}
0005432150352	9EB8A3	0633 973951	NINA ZAKHAROVA	{"phone": "+70177862865"}
0005432150353	E9A1CA	0069 681384	SERGEY SOKOLOV	{"phone": "+70148262097"}
0005432150354	683608	6910 704265	VALERIYA TIMOFEEVA	{"phone": "+70946530219"}
0005432150355	683608	1771 334995	LIDIYA BARANOVA	{"email": "baranova.l-081980@postgrespro.ru", "phone": "+70853850718"}
0005432150356	C4A2B3	5901 981692	ANATOLIY MELNIKOV	{"email": "melnikov_anatoliy.031976@postgrespro.ru", "phone": "+70828821495"}
0005432150357	CBF521	5575 007828	GENNADIY ISAEV	{"phone": "+70830655551"}
0005432150358	CBF521	1613 146572	TATYANA ISAEVA	{"email": "tatyanaisaeva_01031979@postgrespro.ru", "phone": "+70394274794"}
0005432150359	710B02	6836 855425	ARTUR ZAKHAROV	{"email": "zakharov_artur041970@postgrespro.ru", "phone": "+70222149189"}
0005432150360	56EC16	1406 524625	ANTONINA KUZMINA	{"email": "a.kuzmina121966@postgrespro.ru", "phone": "+70366116112"}
0005432150361	56EC16	3985 917104	IRINA DENISOVA	{"email": "irinadenisova_1963@postgrespro.ru", "phone": "+70483611281"}
0005432150362	35B7EB	1951 912002	ALINA ZHURAVLEVA	{"phone": "+70758901571"}
0005432150363	7CF203	8133 167518	ALBINA KUDRYASHOVA	{"email": "albina_kudryashova.09041974@postgrespro.ru", "phone": "+70623453908"}
0005432150364	A47CBC	4897 527318	NINA KULIKOVA	{"phone": "+70299858587"}
0005432150365	A0A41C	4856 939110	ELENA LAZAREVA	{"email": "lazareva_elena.1978@postgrespro.ru", "phone": "+70627808348"}
0005432150366	AAD70F	0235 377278	NATALYA TROFIMOVA	{"email": "trofimova.n_091959@postgrespro.ru", "phone": "+70949465503"}
0005432150367	77AFCF	3300 164053	ANNA SIDOROVA	{"phone": "+70671536979"}
0005432150368	6F2609	1942 830914	YULIYA TIKHONOVA	{"email": "tikhonova-y_1974@postgrespro.ru", "phone": "+70826844159"}
0005432150369	014FCF	9901 372956	ELENA DMITRIEVA	{"phone": "+70823687792"}
0005432150370	014FCF	2803 672295	ALEKSANDR PETROV	{"email": "aleksandr_petrov.1981@postgrespro.ru", "phone": "+70262172503"}
0005432150371	7114B9	5910 111379	YAN ALEKSEEV	{"phone": "+70963969463"}
0005432150372	B5D4AB	7855 941355	ANNA POPOVA	{"phone": "+70064861562"}
0005432150373	152B67	8410 908048	ALEKSANDR MAKAROV	{"phone": "+70881549559"}
0005432150374	279765	3892 891015	ELENA TIKHONOVA	{"email": "etikhonova_1972@postgrespro.ru", "phone": "+70092679866"}
0005432150375	2E1A24	4861 269587	DMITRIY VLASOV	{"phone": "+70582895526"}
0005432150376	ADEF16	3666 413003	EVGENIYA ARKHIPOVA	{"email": "arkhipova-evgeniya_1972@postgrespro.ru", "phone": "+70129994656"}
0005432150377	533851	6923 185879	VALENTINA KOROLEVA	{"email": "koroleva.valentina-1974@postgrespro.ru", "phone": "+70272435427"}
0005432150378	1FEA74	8520 623287	OLGA PAVLOVA	{"phone": "+70259499450"}
0005432150379	017AA5	3527 567305	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov-011966@postgrespro.ru", "phone": "+70266551787"}
0005432150380	4C2F07	1958 034928	DMITRIY ALEKSEEV	{"email": "dmitriy_alekseev-14011967@postgrespro.ru", "phone": "+70840042323"}
0005432150381	4EAC1C	8431 667794	SERGEY GUSEV	{"phone": "+70282184014"}
0005432150382	4EAC1C	3642 076744	SVETLANA ANDREEVA	{"phone": "+70545102311"}
0005432150383	D96543	2213 591525	RAISA AFANASEVA	{"phone": "+70679804241"}
0005432150384	A28250	9394 770603	ALEKSANDR KONOVALOV	{"phone": "+70479083417"}
0005432150385	DF56C3	2658 120178	ANTON POPOV	{"email": "popov_anton.021978@postgrespro.ru", "phone": "+70845114429"}
0005432150386	F3C1EE	1181 888733	MARAT MOROZOV	{"phone": "+70078330432"}
0005432150387	DB1A38	6695 725868	IGOR VLASOV	{"email": "i_vlasov_121964@postgrespro.ru", "phone": "+70959637297"}
0005432150388	C1F70C	3137 352983	MARGARITA MOROZOVA	{"phone": "+70792711927"}
0005432150389	E85755	8241 823491	TATYANA TARASOVA	{"email": "tarasova.t021976@postgrespro.ru", "phone": "+70687154112"}
0005432150390	A67B0A	1884 934184	NIKOLAY ALEKSANDROV	{"phone": "+70197981885"}
0005432150391	97D4DD	4060 701880	VLADIMIR ABRAMOV	{"email": "abramov_vladimir_1964@postgrespro.ru", "phone": "+70389673868"}
0005432150392	E6DE1E	3714 073563	VALENTINA BORISOVA	{"phone": "+70996576917"}
0005432150393	F323F5	5187 298187	VLADIMIR VOLKOV	{"email": "vladimir_volkov.12091965@postgrespro.ru", "phone": "+70037135891"}
0005432150394	F323F5	1939 334808	ANASTASIYA FILIPPOVA	{"phone": "+70891028543"}
0005432150395	6383E6	2081 383541	YULIYA MAKSIMOVA	{"phone": "+70661562402"}
0005432150396	BD6F28	9975 944342	EVGENIYA NIKOLAEVA	{"phone": "+70838104845"}
0005432150397	BD6F28	4959 727202	EKATERINA SOROKINA	{"phone": "+70403659233"}
0005432150398	6A7E1D	1723 608345	VIKTORIYA KOZLOVA	{"phone": "+70424204593"}
0005432150399	6A7E1D	0924 168142	NINA MEDVEDEVA	{"email": "medvedeva.nina.111965@postgrespro.ru", "phone": "+70172935923"}
0005432150400	7D9305	5874 584191	VALENTINA FILIPPOVA	{"phone": "+70314973157"}
0005432150401	663E87	7074 830525	LYUDMILA ALEKSEEVA	{"email": "lalekseeva-1979@postgrespro.ru", "phone": "+70476231902"}
0005432150402	210244	4612 123207	ANTONINA VASILEVA	{"phone": "+70537129335"}
0005432150403	210244	4509 855551	ANATOLIY NIKOLAEV	{"email": "nikolaev.a.111965@postgrespro.ru", "phone": "+70020091913"}
0005432150404	9B54D3	9636 772289	MAKSIM NOVIKOV	{"phone": "+70558362190"}
0005432150405	9B54D3	5220 307296	EVGENIYA KUDRYASHOVA	{"email": "e.kudryashova-041982@postgrespro.ru", "phone": "+70567401220"}
0005432150406	BCD79B	5431 141248	VIKTOR SAVELEV	{"phone": "+70592618136"}
0005432150407	DB0A4E	2409 331811	IVAN KUZNECOV	{"email": "i.kuznecov1962@postgrespro.ru", "phone": "+70891960260"}
0005432150408	DB0A4E	1587 880633	VIKTOR SCHERBAKOV	{"email": "v_scherbakov_17101970@postgrespro.ru", "phone": "+70159867725"}
0005432150409	34C75F	9032 901010	PETR MOROZOV	{"phone": "+70660489638"}
0005432150410	B482DE	6074 440265	ANASTASIYA NESTEROVA	{"email": "a-nesterova-27101978@postgrespro.ru", "phone": "+70472989055"}
0005432150411	1F6440	3491 282901	NAIL KARPOV	{"phone": "+70566028545"}
0005432150412	1F6440	9065 379988	IRINA GERASIMOVA	{"email": "gerasimova-irina101981@postgrespro.ru", "phone": "+70939555751"}
0005432150413	03A9EB	9929 261027	ELENA MIKHAYLOVA	{"phone": "+70974841538"}
0005432150414	97CDD5	3755 006701	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr.1972@postgrespro.ru", "phone": "+70628678143"}
0005432150415	D28DD2	5480 099542	ALEKSANDR NOVIKOV	{"phone": "+70834001488"}
0005432150416	D28DD2	5214 594388	DMITRIY KAZAKOV	{"phone": "+70908621034"}
0005432150417	554106	6532 661940	TAMARA MATVEEVA	{"email": "matveeva-tamara071971@postgrespro.ru", "phone": "+70214644042"}
0005432150418	557FC6	8715 115416	NINA ZHUKOVA	{"email": "n.zhukova121980@postgrespro.ru", "phone": "+70761350478"}
0005432150419	7A83D0	9622 387449	LIDIYA GERASIMOVA	{"email": "l_gerasimova-091990@postgrespro.ru", "phone": "+70889593891"}
0005432150420	BFE381	1851 249348	MARIYA MALYSHEVA	{"email": "mariya_malysheva03111968@postgrespro.ru", "phone": "+70204475504"}
0005432150421	BFE381	7083 092342	VASILIY NIKOLAEV	{"email": "v-nikolaev041973@postgrespro.ru", "phone": "+70131515438"}
0005432150422	483907	2104 982829	RAFAEL SEMENOV	{"email": "semenov-rafael.111969@postgrespro.ru", "phone": "+70792380825"}
0005432150423	483907	3346 154434	ALEKSANDR FOMIN	{"phone": "+70440777328"}
0005432150424	483907	4493 897257	GENNADIY KONOVALOV	{"email": "konovalov_gennadiy081967@postgrespro.ru", "phone": "+70161745525"}
0005432150425	B21E4E	8148 433845	VERA MAKAROVA	{"phone": "+70734225992"}
0005432150426	B21E4E	4216 683555	GALINA MOISEEVA	{"phone": "+70423649655"}
0005432150427	EC244C	7676 804240	NATALYA SAVELEVA	{"phone": "+70122457070"}
0005432150428	E8699E	4575 274614	NINA KONDRATEVA	{"email": "kondrateva-nina051963@postgrespro.ru", "phone": "+70902915444"}
0005432150429	E8699E	6092 671155	DENIS CHERNOV	{"email": "d_chernov.30081972@postgrespro.ru", "phone": "+70238463720"}
0005432150430	E8699E	0720 369856	EVGENIY KOZLOV	{"email": "kozlov.e101980@postgrespro.ru", "phone": "+70914571551"}
0005432150431	675989	9089 957310	VIKTOR SCHERBAKOV	{"email": "scherbakov_viktor1957@postgrespro.ru", "phone": "+70347401005"}
0005432150432	675989	5320 789748	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a1966@postgrespro.ru", "phone": "+70716116992"}
0005432153813	2CBF4F	0879 120853	ANNA GAVRILOVA	{"email": "gavrilova-a_1968@postgrespro.ru", "phone": "+70993774878"}
0005432153814	E0C010	1128 225491	DMITRIY PAVLOV	{"phone": "+70863804853"}
0005432153815	04A144	3480 688139	SVETLANA NESTEROVA	{"email": "nesterovas.09091963@postgrespro.ru", "phone": "+70548173867"}
0005432153816	04A144	4824 296405	ALENA SOROKINA	{"phone": "+70798556215"}
0005432153817	4D632B	5837 371337	ANATOLIY TARASOV	{"phone": "+70262961850"}
0005432153818	1D9346	8959 145294	PAVEL MAKAROV	{"email": "p.makarov_1971@postgrespro.ru", "phone": "+70530957550"}
0005432153819	F5E479	4534 204007	NIKOLAY SAVELEV	{"phone": "+70900472868"}
0005432153820	E9E2B9	1812 302262	VALENTINA KONDRATEVA	{"email": "kondratevav.31101972@postgrespro.ru", "phone": "+70513524737"}
0005432153821	DF382B	2523 445154	MAKSIM PETROV	{"phone": "+70938569844"}
0005432153822	DF382B	7623 597208	ALEKSANDR NOVIKOV	{"phone": "+70197211916"}
0005432153823	70A5A1	2592 201742	ALEKSANDR ANTONOV	{"email": "aantonov_31031971@postgrespro.ru", "phone": "+70460220942"}
0005432153824	70A5A1	4567 263211	INNA MELNIKOVA	{"phone": "+70706491133"}
0005432153825	4C6402	7794 975125	GALINA NIKOLAEVA	{"email": "galina_nikolaeva-071969@postgrespro.ru", "phone": "+70554619452"}
0005432153826	E104C8	8331 285353	MAKSIM NIKOLAEV	{"email": "nikolaevmaksim_24051954@postgrespro.ru", "phone": "+70727115180"}
0005432153827	E104C8	3047 949809	VIKTOR ILIN	{"phone": "+70022977851"}
0005432153828	8BA4FD	7389 223456	ILNUR NOVIKOV	{"email": "novikov.ilnur051980@postgrespro.ru", "phone": "+70614705973"}
0005432153829	8BA4FD	9043 459825	DMITRIY VLASOV	{"email": "d-vlasov-1975@postgrespro.ru", "phone": "+70893455621"}
0005432153830	2C78AD	5689 803431	KIRILL RODIONOV	{"phone": "+70067503367"}
0005432153831	E984D3	4188 131947	ALEKSANDR FEDOROV	{"phone": "+70158963670"}
0005432153832	D3B3DE	9733 906591	MIKHAIL SOKOLOV	{"phone": "+70746899009"}
0005432153833	C3E9BA	0523 974024	ELENA GERASIMOVA	{"email": "e.gerasimova.1970@postgrespro.ru", "phone": "+70409842504"}
0005432153834	2CBB8D	1208 752134	VALENTINA STEPANOVA	{"email": "valentina.stepanova-1968@postgrespro.ru", "phone": "+70266229535"}
0005432153835	2CBB8D	7251 825959	VALENTINA SMIRNOVA	{"phone": "+70037964921"}
0005432153836	44D833	3555 378842	SERGEY FEDOROV	{"email": "fedorov-sergey1971@postgrespro.ru", "phone": "+70711119049"}
0005432153837	965D47	8070 447130	TATYANA ARKHIPOVA	{"phone": "+70690421844"}
0005432153838	59A7FF	6764 412939	IVAN ABRAMOV	{"phone": "+70811972473"}
0005432153839	4EDE7D	0053 689309	IRINA TARASOVA	{"email": "i-tarasova_121978@postgrespro.ru", "phone": "+70566241395"}
0005432153840	BB7A71	4909 250509	NIKOLAY SCHERBAKOV	{"email": "scherbakov.n26021965@postgrespro.ru", "phone": "+70985604251"}
0005432153841	417582	1958 457273	IVAN SOROKIN	{"phone": "+70484236600"}
0005432153842	417582	1641 576110	ALEKSANDRA BORISOVA	{"email": "aborisova-1971@postgrespro.ru", "phone": "+70768439404"}
0005432153843	986CAA	1145 814380	GENNADIY ISAEV	{"phone": "+70951296210"}
0005432153844	986CAA	8070 116428	SERGEY SEMENOV	{"email": "semenov-s.23061980@postgrespro.ru", "phone": "+70715559253"}
0005432153845	A014CA	0307 559648	LARISA NOVIKOVA	{"email": "novikova-larisa_1973@postgrespro.ru", "phone": "+70826577979"}
0005432153846	064B91	3080 192376	EVGENIY NIKOLAEV	{"email": "nikolaev-e_1969@postgrespro.ru", "phone": "+70382349777"}
0005432153847	4B4516	8572 932942	SVETLANA BARANOVA	{"phone": "+70905365936"}
0005432153848	4B4516	3821 560388	VLADIMIR NAZAROV	{"email": "nazarov.vladimir-1973@postgrespro.ru", "phone": "+70932888086"}
0005432153849	4B4516	3542 496156	DMITRIY TARASOV	{"phone": "+70213287660"}
0005432153850	E15098	4638 280983	IVAN FILIPPOV	{"phone": "+70671430343"}
0005432153851	D1E0E8	8694 858655	ALEKSANDR YAKOVLEV	{"email": "ayakovlev-1957@postgrespro.ru", "phone": "+70720286930"}
0005432153852	FEB089	1466 141587	NADEZHDA MOROZOVA	{"email": "nadezhda_morozova.16061978@postgrespro.ru", "phone": "+70810081834"}
0005432153853	6BD7EA	3472 105754	ALEKSANDR KULIKOV	{"email": "a-kulikov.1972@postgrespro.ru", "phone": "+70236723173"}
0005432153854	DFA020	6667 443914	ANDREY BORISOV	{"email": "andreyborisov_1972@postgrespro.ru", "phone": "+70293682308"}
0005432153855	C934E2	1117 906114	NADEZHDA MAKSIMOVA	{"email": "n_maksimova_101979@postgrespro.ru", "phone": "+70556769181"}
0005432153856	068BDF	9448 070778	VASILIY ROMANOV	{"phone": "+70405731801"}
0005432153857	068BDF	2174 893825	ANDREY ANDREEV	{"email": "a-andreev.1980@postgrespro.ru", "phone": "+70652014683"}
0005432153858	1E010D	3028 303379	NADEZHDA MEDVEDEVA	{"email": "nmedvedeva.01071970@postgrespro.ru", "phone": "+70551507140"}
0005432153859	38E70D	0502 144499	NATALYA ZAKHAROVA	{"email": "natalya_zakharova.19061964@postgrespro.ru", "phone": "+70924210979"}
0005432153860	38E70D	7002 568673	ANTON NOVIKOV	{"phone": "+70267243064"}
0005432153861	38E70D	9112 400047	ANNA LUKYANOVA	{"email": "a.lukyanova_04071979@postgrespro.ru", "phone": "+70557104961"}
0005432153862	60E8BD	7076 816834	ALENA DENISOVA	{"phone": "+70261351487"}
0005432153863	60E8BD	7706 690118	MIKHAIL STEPANOV	{"phone": "+70411947542"}
0005432153864	AAA3EB	0917 838049	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga1976@postgrespro.ru", "phone": "+70051577911"}
0005432153865	75D28C	9897 080768	YURIY MELNIKOV	{"phone": "+70119008089"}
0005432153866	75D28C	4299 681777	ANATOLIY FOMIN	{"phone": "+70263187261"}
0005432153867	981BFB	7861 572428	DANIIL DMITRIEV	{"phone": "+70993268926"}
0005432153868	FF3A15	4745 818165	ALEKSANDR DMITRIEV	{"phone": "+70459045005"}
0005432153869	DD38CA	3184 405652	ANTON FROLOV	{"email": "frolova.13111972@postgrespro.ru", "phone": "+70265917024"}
0005432153870	1044C0	4845 786509	ROZALIYA BARANOVA	{"phone": "+70224520004"}
0005432153871	1044C0	4357 752192	LYUBOV ARKHIPOVA	{"phone": "+70803259952"}
0005432153872	8BD3E3	1269 568781	YULIYA KAZAKOVA	{"phone": "+70744470718"}
0005432153873	B97782	0993 621318	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr041963@postgrespro.ru", "phone": "+70253950667"}
0005432153874	DBC0EB	3048 887119	NADEZHDA POPOVA	{"phone": "+70465194243"}
0005432153875	AA708A	0388 425952	SERGEY KUZNECOV	{"email": "kuznecov-sergey.22031967@postgrespro.ru", "phone": "+70625397814"}
0005432153876	D60EBC	0420 350626	VALENTINA BARANOVA	{"phone": "+70896974275"}
0005432153877	786F9E	8441 675319	ALEKSANDR NAUMOV	{"email": "naumov.a-15081961@postgrespro.ru", "phone": "+70717495431"}
0005432153878	E0BCB4	5435 511873	VLADIMIR EGOROV	{"email": "vladimir_egorov.1975@postgrespro.ru", "phone": "+70319756877"}
0005432153879	59E7D6	7036 628359	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov011976@postgrespro.ru", "phone": "+70784664202"}
0005432153880	80B537	2065 487491	DENIS IVANOV	{"email": "d-ivanov1966@postgrespro.ru", "phone": "+70108159813"}
0005432153881	8A22F6	4586 132377	ANNA SOKOLOVA	{"phone": "+70255221434"}
0005432153882	2E149C	7349 087637	SERGEY FEDOROV	{"phone": "+70215692981"}
0005432153883	587712	2069 070682	ALEKSANDR KUZMIN	{"email": "a-kuzmin.091965@postgrespro.ru", "phone": "+70971730982"}
0005432153884	E66C6D	7408 247740	ALEKSEY GAVRILOV	{"email": "gavrilov_aleksey-041977@postgrespro.ru", "phone": "+70350704319"}
0005432153885	F2E8D6	9161 642805	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev-1970@postgrespro.ru", "phone": "+70439108928"}
0005432153886	215B9F	9804 593737	ANDREY ANDREEV	{"phone": "+70703068980"}
0005432153887	47E7F7	2803 330636	MAGOMED TIKHONOV	{"phone": "+70587541958"}
0005432153888	487AFF	0429 350443	VLADISLAV ILIN	{"email": "v.ilin_17101971@postgrespro.ru", "phone": "+70151065242"}
0005432153889	7EB936	9709 976534	ANDREY POPOV	{"email": "popova15021970@postgrespro.ru", "phone": "+70200430547"}
0005432153890	63DD9C	0645 515040	OLGA KUZNECOVA	{"phone": "+70479821536"}
0005432153891	63DD9C	4466 759853	MIKHAIL BONDARENKO	{"email": "bondarenkomikhail_12041981@postgrespro.ru", "phone": "+70220638636"}
0005432153892	E70485	0289 543480	EVGENIY VOROBEV	{"email": "evgeniy_vorobev.061967@postgrespro.ru", "phone": "+70405376077"}
0005432153893	B23BC1	9661 620904	VADIM NIKITIN	{"email": "v.nikitin1971@postgrespro.ru", "phone": "+70657905028"}
0005432153894	8D1C98	2112 032084	MARINA KARPOVA	{"email": "marinakarpova_051975@postgrespro.ru", "phone": "+70016863190"}
0005432153895	8D1C98	5440 363324	LYUBOV POPOVA	{"email": "popova-lyubov071973@postgrespro.ru", "phone": "+70873167872"}
0005432153896	8D1C98	7007 433526	ALEKSANDR SMIRNOV	{"phone": "+70402013178"}
0005432153897	9DEE57	7803 374352	OLGA TARASOVA	{"phone": "+70296079807"}
0005432153898	5FCF92	5347 604649	ALEKSANDR KAZAKOV	{"phone": "+70214646614"}
0005432153899	43889B	1613 885965	OLGA FROLOVA	{"phone": "+70425562529"}
0005432153900	5C4D03	9001 244789	SERGEY ZAYCEV	{"email": "zaycev-s101968@postgrespro.ru", "phone": "+70285905706"}
0005432153901	05E5D2	8932 329965	IVAN SERGEEV	{"email": "i_sergeev1968@postgrespro.ru", "phone": "+70106187950"}
0005432153902	05E5D2	4820 295134	EVGENIY PETROV	{"phone": "+70398145628"}
0005432153903	05E5D2	6469 729206	TATYANA LEBEDEVA	{"email": "lebedevatatyana.1978@postgrespro.ru", "phone": "+70158731232"}
0005432153904	813372	9662 963826	VALENTIN SERGEEV	{"phone": "+70149988142"}
0005432153905	28BED9	5967 789733	SVETLANA SOKOLOVA	{"phone": "+70578950339"}
0005432153906	EB8258	4424 649351	MIKHAIL MOROZOV	{"email": "morozovm.061975@postgrespro.ru", "phone": "+70407651448"}
0005432153907	EB8258	9701 519457	ARTUR KUZNECOV	{"phone": "+70263303009"}
0005432153908	02F894	3206 764199	VLADISLAV PETROV	{"phone": "+70986395698"}
0005432153909	02F894	5124 277562	ALEKSEY SMIRNOV	{"phone": "+70492182480"}
0005432153910	5FD306	8411 752086	NADEZHDA AFANASEVA	{"email": "afanaseva.n-111974@postgrespro.ru", "phone": "+70724127462"}
0005432153911	A60E3E	4309 306849	MARIYA MOROZOVA	{"email": "m-morozova.1976@postgrespro.ru", "phone": "+70624133379"}
0005432153912	A60E3E	8325 155847	ANDREY ALEKSANDROV	{"phone": "+70174076111"}
0005432153913	D4898A	9931 464849	ELIZAVETA ZOTOVA	{"phone": "+70305954703"}
0005432153914	10E6BA	2192 696611	VLADISLAV DMITRIEV	{"email": "vladislav_dmitriev.1981@postgrespro.ru", "phone": "+70518176379"}
0005432153915	017036	9288 420634	SEMEN FEDOROV	{"phone": "+70255724610"}
0005432153916	017036	9338 680676	ANNA ANDREEVA	{"email": "andreeva-a-081976@postgrespro.ru", "phone": "+70281316665"}
0005432153917	85EB13	9768 805129	VLADIMIR POPOV	{"email": "popovvladimir.051975@postgrespro.ru", "phone": "+70187041880"}
0005432153918	DBA610	2929 496209	VYACHESLAV KOROLEV	{"phone": "+70565740592"}
0005432153919	3B9F56	4744 314564	TAMARA KOZLOVA	{"phone": "+70585554712"}
0005432153920	C4C494	0411 394255	LYUBOV MATVEEVA	{"email": "lmatveeva.08021968@postgrespro.ru", "phone": "+70019165072"}
0005432153921	248271	9132 777096	VERA STEPANOVA	{"phone": "+70622319205"}
0005432153922	E10266	1825 454570	ELIZAVETA NIKITINA	{"email": "enikitina.11111976@postgrespro.ru", "phone": "+70405649944"}
0005432153923	E10266	1171 521208	ELENA KUZNECOVA	{"phone": "+70159038918"}
0005432153924	009612	2866 001065	SVETLANA POPOVA	{"phone": "+70933961742"}
0005432153925	009612	3274 916705	ALENA PAVLOVA	{"email": "pavlovaa-101968@postgrespro.ru", "phone": "+70066394592"}
0005432153926	6B1008	3655 411846	ANDREY AFANASEV	{"phone": "+70973590771"}
0005432153927	020D53	7591 157884	LYUDMILA KOROLEVA	{"phone": "+70025399966"}
0005432153928	AAC370	1176 010814	TATYANA LUKYANOVA	{"email": "lukyanovat-1967@postgrespro.ru", "phone": "+70491357276"}
0005432153929	AAC370	8302 866675	NINA ALEKSANDROVA	{"email": "nina.aleksandrova-1975@postgrespro.ru", "phone": "+70519116071"}
0005432153930	8FCD65	8994 014025	NINA MAKAROVA	{"email": "makarova.nina.101978@postgrespro.ru", "phone": "+70335777146"}
0005432153931	67ECE5	1932 062189	DENIS GUSEV	{"phone": "+70237748880"}
0005432153932	237D87	8815 709637	ANTONINA MIRONOVA	{"email": "antonina.mironova-1968@postgrespro.ru", "phone": "+70515358410"}
0005432153933	237D87	8439 557732	NINA ZAYCEVA	{"email": "zaycevanina.15011982@postgrespro.ru", "phone": "+70274302633"}
0005432153934	AE8439	7516 627986	IRINA LOGINOVA	{"phone": "+70635308431"}
0005432153935	14F45F	8341 464739	SERGEY TIKHONOV	{"email": "tikhonov-sergey1981@postgrespro.ru", "phone": "+70002996328"}
0005432153936	14F45F	6689 023652	LYUDMILA LUKYANOVA	{"email": "lyudmila-lukyanova.19021966@postgrespro.ru", "phone": "+70927290228"}
0005432153937	C15306	4018 665613	KSENIYA ANISIMOVA	{"phone": "+70831907655"}
0005432153938	C15306	2265 744463	MARINA SAVELEVA	{"email": "saveleva_marina061980@postgrespro.ru", "phone": "+70691907688"}
0005432153939	C15306	4654 120326	NATALYA MOISEEVA	{"email": "n_moiseeva.071963@postgrespro.ru", "phone": "+70639896177"}
0005432153940	C4802E	6604 273392	IVAN MELNIKOV	{"email": "melnikov_i.031979@postgrespro.ru", "phone": "+70041080775"}
0005432153941	C4802E	5547 101556	LYUDMILA MELNIKOVA	{"email": "lyudmila_melnikova1965@postgrespro.ru", "phone": "+70632061725"}
0005432153942	C4802E	6246 895671	DMITRIY SIDOROV	{"phone": "+70236435434"}
0005432153943	A3E862	0202 661770	MIROSLAV GRIGOREV	{"phone": "+70232214912"}
0005432153944	A3E862	0686 603597	KONSTANTIN DMITRIEV	{"email": "dmitriev.konstantin_1972@postgrespro.ru", "phone": "+70328653742"}
0005432153945	18CF4F	9228 214556	ILYA NIKITIN	{"email": "nikitin.ilya_20111974@postgrespro.ru", "phone": "+70656737472"}
0005432153946	D8092F	7684 878363	SVETLANA PETROVA	{"email": "s.petrova.1976@postgrespro.ru", "phone": "+70800136554"}
0005432153947	D8092F	2180 293375	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr-041969@postgrespro.ru", "phone": "+70376083829"}
0005432153948	C14AC5	4842 798865	VERA SOKOLOVA	{"phone": "+70180628417"}
0005432153949	DB886C	2659 688125	ELENA MAKAROVA	{"email": "makarovaelena-071984@postgrespro.ru", "phone": "+70074509597"}
0005432153950	DB886C	3242 572740	OLGA KALININA	{"phone": "+70960000546"}
0005432153951	E0EF7F	2557 023681	VLADISLAV ZHURAVLEV	{"phone": "+70897293163"}
0005432153952	E0EF7F	3026 318247	ANASTASIYA KOZLOVA	{"phone": "+70759764735"}
0005432153953	E0EF7F	7973 684527	NIKOLAY AFANASEV	{"email": "n_afanasev-041969@postgrespro.ru", "phone": "+70509790805"}
0005432153954	09869F	8056 479599	ALEKSANDR TARASOV	{"email": "atarasov_1976@postgrespro.ru", "phone": "+70689887718"}
0005432153955	09869F	0276 149261	OKSANA YUDINA	{"phone": "+70357393352"}
0005432153956	E104FE	2224 234494	ELENA IVANOVA	{"email": "elena-ivanova1966@postgrespro.ru", "phone": "+70641960448"}
0005432153957	4EB9A9	3611 181079	ELENA IVANOVA	{"email": "ivanova_elena.091978@postgrespro.ru", "phone": "+70056279626"}
0005432153958	4EB9A9	9574 893497	RUSLAN SEMENOV	{"phone": "+70677664264"}
0005432153959	0492A9	8674 087132	IGOR IVANOV	{"email": "ivanovigor-04111990@postgrespro.ru", "phone": "+70115099696"}
0005432154016	EEC467	8622 940538	ANTONINA IVANOVA	{"phone": "+70254803381"}
0005432153960	0492A9	1078 887699	TATYANA IVANOVA	{"email": "ivanovat_1969@postgrespro.ru", "phone": "+70126459685"}
0005432153961	4D4BC8	6342 882926	GALINA FILATOVA	{"phone": "+70017557093"}
0005432153962	4D4BC8	7019 444227	TATYANA MOROZOVA	{"email": "morozova-t.13081965@postgrespro.ru", "phone": "+70142207246"}
0005432153963	0B63A4	3492 245974	LYUBOV SIDOROVA	{"phone": "+70200692752"}
0005432153964	2BBDF2	5227 594889	MARGARITA LUKYANOVA	{"email": "lukyanova.m_121965@postgrespro.ru", "phone": "+70303058417"}
0005432153965	2BBDF2	1326 520307	YURIY BELOV	{"phone": "+70216208017"}
0005432153966	2EFE45	8984 109299	GALINA KONOVALOVA	{"email": "konovalova.galina-091969@postgrespro.ru", "phone": "+70519197048"}
0005432153967	2EFE45	3684 537229	VLADIMIR VOROBEV	{"phone": "+70013859626"}
0005432153968	E61141	4627 365727	INNA ZHURAVLEVA	{"email": "zhuravlevai-1968@postgrespro.ru", "phone": "+70155902647"}
0005432153969	E61141	7974 683918	ALEKSANDR MARTYNOV	{"email": "a-martynov-1981@postgrespro.ru", "phone": "+70882183190"}
0005432153970	FFED9A	6568 332000	ALEKSEY GORBUNOV	{"phone": "+70121933653"}
0005432153971	E4524A	6782 684128	EVGENIY NIKOLAEV	{"email": "e_nikolaev_12121969@postgrespro.ru", "phone": "+70663690480"}
0005432153972	E4524A	1160 907458	SERGEY IVANOV	{"phone": "+70363751530"}
0005432153973	052286	8231 099851	RIMMA KISELEVA	{"email": "rimma-kiseleva_111964@postgrespro.ru", "phone": "+70336009955"}
0005432153974	052286	2757 362007	ALEKSEY FEDOTOV	{"email": "fedotov_aleksey_071966@postgrespro.ru", "phone": "+70443240872"}
0005432153975	D74AE7	4439 865142	ALEKSANDR VASILEV	{"phone": "+70043110160"}
0005432153976	D74AE7	8320 556061	ALEVTINA ROMANOVA	{"phone": "+70628173051"}
0005432153977	E67524	0954 602685	KIRILL MIRONOV	{"phone": "+70023897996"}
0005432153978	E67524	5745 827531	IVAN ABRAMOV	{"phone": "+70384514235"}
0005432153979	9B9600	3427 787739	NADEZHDA KOZLOVA	{"email": "kozlova_n_1966@postgrespro.ru", "phone": "+70282710245"}
0005432153980	9B9600	9477 792855	ANASTASIYA BELOVA	{"phone": "+70529553447"}
0005432153981	183621	5142 032138	SVETLANA KOROLEVA	{"phone": "+70564686705"}
0005432153982	7E9750	7194 571314	GALINA ANISIMOVA	{"phone": "+70309879973"}
0005432153983	7E9750	5945 985399	MARIYA MIKHAYLOVA	{"phone": "+70031376879"}
0005432153984	111A6E	6974 476493	IRINA STEPANOVA	{"email": "stepanovairina.1971@postgrespro.ru", "phone": "+70561649721"}
0005432153985	D5BD38	8079 398106	VLADIMIR GERASIMOV	{"email": "vgerasimov_1970@postgrespro.ru", "phone": "+70752929262"}
0005432153986	D5BD38	9898 388795	NATALYA EGOROVA	{"email": "egorova_n-091979@postgrespro.ru", "phone": "+70693696607"}
0005432153987	A8268F	7491 364681	TATYANA FILIPPOVA	{"phone": "+70557576085"}
0005432153988	A8268F	8971 185581	ANGELINA AKIMOVA	{"phone": "+70361006886"}
0005432153989	3C2DB8	1964 103345	OLESYA FEDOROVA	{"phone": "+70586142347"}
0005432153990	3C2DB8	1444 692175	OLGA ARKHIPOVA	{"email": "arkhipova.o-1964@postgrespro.ru", "phone": "+70389906533"}
0005432153991	841F50	9135 231625	MARGARITA SEMENOVA	{"email": "semenova-m-08011979@postgrespro.ru", "phone": "+70602872671"}
0005432153992	841F50	5092 811814	MIKHAIL SIDOROV	{"phone": "+70668333427"}
0005432153993	457F83	5225 068634	OLGA IVANOVA	{"email": "ivanovaolga-121963@postgrespro.ru", "phone": "+70641763391"}
0005432153994	457F83	0544 218767	ANASTASIYA KISELEVA	{"email": "kiseleva_anastasiya_1960@postgrespro.ru", "phone": "+70618488462"}
0005432153995	5A0635	7691 561263	RIMMA SOROKINA	{"email": "sorokina.rimma1978@postgrespro.ru", "phone": "+70037070988"}
0005432153996	5A0635	5090 626147	DARYA VLASOVA	{"email": "darya-vlasova_04121977@postgrespro.ru", "phone": "+70323107330"}
0005432153997	6197A6	7432 965346	VERA NESTEROVA	{"phone": "+70180589869"}
0005432153998	6197A6	4299 272132	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir.1975@postgrespro.ru", "phone": "+70796340203"}
0005432153999	6197A6	8608 885491	DANIL VOLKOV	{"phone": "+70407482385"}
0005432154000	038B17	6361 007992	ANTON GERASIMOV	{"email": "agerasimov11121980@postgrespro.ru", "phone": "+70737962310"}
0005432154001	038B17	7887 102373	RAFIK KUZNECOV	{"phone": "+70217717260"}
0005432154002	116F59	6685 055536	DMITRIY AFANASEV	{"email": "afanasevd_09041970@postgrespro.ru", "phone": "+70110312396"}
0005432154003	1E7205	6632 049200	LYUDMILA ILINA	{"phone": "+70235359694"}
0005432154004	1E7205	5459 047931	YULIYA KISELEVA	{"phone": "+70142114773"}
0005432154005	B5A103	0097 043463	IVAN AFANASEV	{"email": "ivan-afanasev.02021975@postgrespro.ru", "phone": "+70053071864"}
0005432154006	D24ADD	7649 709878	VLADIMIR SOROKIN	{"email": "vsorokin03031974@postgrespro.ru", "phone": "+70373930639"}
0005432154007	D24ADD	1828 289670	IRINA VASILEVA	{"email": "vasilevai1965@postgrespro.ru", "phone": "+70277276549"}
0005432154008	D24ADD	6818 793082	DENIS IVANOV	{"email": "denis_ivanov-03081963@postgrespro.ru", "phone": "+70020268333"}
0005432154009	31E5C0	0627 763718	NATALIYA VOLKOVA	{"phone": "+70993414122"}
0005432154010	0D0E3A	6217 481127	NINA ERMAKOVA	{"email": "ermakova-nina_091971@postgrespro.ru", "phone": "+70852376855"}
0005432154011	BC4656	7329 927867	ANNA SOLOVEVA	{"email": "soloveva_a_1975@postgrespro.ru", "phone": "+70668092487"}
0005432154012	3B0391	4428 588879	NIKOLAY GERASIMOV	{"phone": "+70965346586"}
0005432154013	2EF23F	6816 506146	NATALYA TIMOFEEVA	{"phone": "+70268831951"}
0005432154014	594D2C	3139 078638	NINA MOROZOVA	{"phone": "+70397679973"}
0005432154015	594D2C	5733 650664	DARYA IVANOVA	{"phone": "+70636924005"}
0005432154017	54B1C7	6582 284744	ELENA MAKAROVA	{"phone": "+70972767842"}
0005432154018	8A797F	2710 930453	KSENIYA ZAYCEVA	{"email": "kseniyazayceva_031971@postgrespro.ru", "phone": "+70358129659"}
0005432154019	AC5AD5	6402 592732	NINA MOISEEVA	{"email": "ninamoiseeva-1982@postgrespro.ru", "phone": "+70368809207"}
0005432154020	1016B9	2575 027144	NATALYA MAKSIMOVA	{"email": "maksimovanatalya_01101970@postgrespro.ru", "phone": "+70751253177"}
0005432154021	CDD138	3163 059513	ASIYA KRASNOVA	{"phone": "+70413902401"}
0005432154022	466E78	2833 489784	ANATOLIY SIDOROV	{"email": "anatoliy-sidorov-051960@postgrespro.ru", "phone": "+70045720391"}
0005432154023	820276	8720 219479	VITALIY VASILEV	{"email": "vasilev_vitaliy_16011976@postgrespro.ru", "phone": "+70784411520"}
0005432154024	F1AFDC	7584 533601	PAVEL FOMIN	{"email": "fomin_pavel_021976@postgrespro.ru", "phone": "+70253337079"}
0005432154025	63369C	8640 262174	YURIY STEPANOV	{"phone": "+70403340737"}
0005432154026	63369C	9806 819640	RAMIS KUZMIN	{"phone": "+70637506124"}
0005432154027	E6205A	7481 836261	YURIY MOROZOV	{"email": "yuriy.morozov-01041971@postgrespro.ru", "phone": "+70108833481"}
0005432154028	E6205A	5328 334934	ELENA YAKOVLEVA	{"phone": "+70647305037"}
0005432154029	C88E1B	7676 426012	TAMARA FEDOROVA	{"phone": "+70768188443"}
0005432154030	C88E1B	1653 633900	LARISA KISELEVA	{"email": "lkiseleva_1967@postgrespro.ru", "phone": "+70678332199"}
0005432154031	E88AD0	1180 093102	DENIS EGOROV	{"email": "egorov-d081976@postgrespro.ru", "phone": "+70905375714"}
0005432154032	8CEB20	0496 346828	RUSLAN KISELEV	{"email": "ruslan_kiselev.041970@postgrespro.ru", "phone": "+70187906419"}
0005432154033	8CEB20	8532 923479	SVETLANA GAVRILOVA	{"email": "svetlana.gavrilova091979@postgrespro.ru", "phone": "+70806220382"}
0005432154034	8CEB20	1580 444905	IRINA KISELEVA	{"email": "ikiseleva-03031963@postgrespro.ru", "phone": "+70398446038"}
0005432154035	8CEB20	4344 151609	MIKHAIL PAVLOV	{"email": "pavlov.m.05011970@postgrespro.ru", "phone": "+70292460915"}
0005432154036	646153	0773 920336	VIKTORIYA ZHURAVLEVA	{"phone": "+70766019930"}
0005432154037	65F568	0493 349176	LYUDMILA ALEKSEEVA	{"email": "lyudmilaalekseeva20061977@postgrespro.ru", "phone": "+70535319942"}
0005432154038	2BD9A5	5405 455037	ALEKSANDR FILIPPOV	{"phone": "+70223461220"}
0005432154039	2BD9A5	3666 580966	EVGENIY PAVLOV	{"email": "pavlove_11111971@postgrespro.ru", "phone": "+70979683059"}
0005432154040	156284	4710 030352	LYUDMILA YAKOVLEVA	{"email": "yakovleva_l-19041970@postgrespro.ru", "phone": "+70692237904"}
0005432154041	53D2C7	4542 086772	VITALIY CHERNOV	{"email": "chernov-vitaliy-05061973@postgrespro.ru", "phone": "+70722070502"}
0005432154042	53D2C7	4615 692354	TATYANA KRASNOVA	{"email": "krasnova_tatyana-1973@postgrespro.ru", "phone": "+70244162316"}
0005432154043	81F9A5	0126 440836	NINA RYABOVA	{"phone": "+70452567693"}
0005432154044	81F9A5	5258 184893	TAMARA ZAYCEVA	{"email": "tamara_zayceva1972@postgrespro.ru", "phone": "+70753000479"}
0005432154045	8D565A	0468 441839	OLGA ILINA	{"email": "ilina-olga_30011973@postgrespro.ru", "phone": "+70071207893"}
0005432154046	2B9CE7	5166 599893	ANNA LEBEDEVA	{"email": "anna_lebedeva1971@postgrespro.ru", "phone": "+70072941058"}
0005432154047	B6EB6A	1137 546509	LARISA IVANOVA	{"email": "livanova091978@postgrespro.ru", "phone": "+70493021570"}
0005432154048	B6EB6A	9055 432160	YURIY NIKITIN	{"phone": "+70915467959"}
0005432154049	8A85E6	9308 458074	VIKTOR EGOROV	{"email": "egorov_viktor_28041972@postgrespro.ru", "phone": "+70403143332"}
0005432154050	8A85E6	3616 609578	LARISA VLASOVA	{"email": "larisa-vlasova-28091972@postgrespro.ru", "phone": "+70912101250"}
0005432154051	8F0C32	9292 630837	DENIS MELNIKOV	{"phone": "+70081802738"}
0005432154052	6F4B42	4529 506644	ELENA DENISOVA	{"phone": "+70291734588"}
0005432154053	46E4F1	7955 650043	ANDREY ANTONOV	{"phone": "+70385447747"}
0005432154054	033A12	1479 617903	IVAN KONOVALOV	{"email": "konovalovivan_011985@postgrespro.ru", "phone": "+70145310173"}
0005432154055	033A12	1842 095553	ALEKSANDRA SOROKINA	{"email": "sorokinaa.15111966@postgrespro.ru", "phone": "+70677724465"}
0005432154056	033A12	9307 492284	VALENTINA KULIKOVA	{"phone": "+70348849262"}
0005432154057	5BA589	6468 653556	NATALIYA POTAPOVA	{"phone": "+70168883205"}
0005432154058	661A95	3165 893648	IVAN YAKOVLEV	{"email": "i-yakovlev1960@postgrespro.ru", "phone": "+70081568520"}
0005432154059	54CBE0	7791 264093	TATYANA KOVALEVA	{"email": "kovaleva_t-1972@postgrespro.ru", "phone": "+70618373675"}
0005432154060	B2FC5C	8886 602012	ANASTASIYA TITOVA	{"email": "a_titova.1968@postgrespro.ru", "phone": "+70345559899"}
0005432154061	B2FC5C	2189 354494	ILYA KUZNECOV	{"email": "kuznecov.ilya.1960@postgrespro.ru", "phone": "+70369715986"}
0005432154062	D82F44	4912 180828	ROMAN PETROV	{"phone": "+70120692764"}
0005432154063	16012A	4736 911995	SERGEY GUSEV	{"phone": "+70953849534"}
0005432154064	16012A	7762 642079	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda.24021981@postgrespro.ru", "phone": "+70378845021"}
0005432154065	DDC611	9975 329605	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko-1961@postgrespro.ru", "phone": "+70043787940"}
0005432154066	59D1D1	2515 509393	IGOR NIKITIN	{"phone": "+70570989918"}
0005432154067	1F03B4	8587 358107	VIKTORIYA BELYAEVA	{"phone": "+70210348691"}
0005432154068	B1387F	8702 464551	LYUDMILA MOROZOVA	{"phone": "+70218215163"}
0005432154069	DBB138	2345 665854	ALEKSEY VOLKOV	{"phone": "+70629674459"}
0005432154070	7F011E	2513 513743	YURIY NAUMOV	{"email": "naumovy.1967@postgrespro.ru", "phone": "+70155529544"}
0005432154071	64177C	7587 657844	TATYANA NAZAROVA	{"phone": "+70999118697"}
0005432154072	39A45D	4164 035776	NATALYA KOLESNIKOVA	{"phone": "+70523425178"}
0005432154073	39A45D	6385 935689	ELENA TIKHONOVA	{"phone": "+70137344625"}
0005432154074	F9E987	2009 639191	EKATERINA DANILOVA	{"email": "danilova_ekaterina_011969@postgrespro.ru", "phone": "+70754293220"}
0005432154075	3F0EFA	9744 889657	NATALIYA ROMANOVA	{"phone": "+70394002442"}
0005432154076	B3DF88	4218 223083	ASIYA KUZNECOVA	{"email": "kuznecova_a081966@postgrespro.ru", "phone": "+70126059261"}
0005432154077	668B3B	3863 415231	EVGENIY ANDREEV	{"email": "evgeniy_andreev.04011971@postgrespro.ru", "phone": "+70322756840"}
0005432154078	B4CEE4	0609 114515	KONSTANTIN BELOV	{"email": "belov_k.081971@postgrespro.ru", "phone": "+70692719417"}
0005432154079	F77C1E	4565 324485	IRINA NESTEROVA	{"phone": "+70939883506"}
0005432154080	E4F44B	8771 653237	VALENTINA ILINA	{"phone": "+70928488200"}
0005432154081	E4F44B	2465 811799	VALENTINA SIDOROVA	{"phone": "+70212332706"}
0005432154082	E4F44B	2772 378192	GEORGIY KUZNECOV	{"email": "kuznecov_georgiy1966@postgrespro.ru", "phone": "+70975316215"}
0005432154083	F756BD	7223 978560	TATYANA ABRAMOVA	{"email": "abramova-t.1966@postgrespro.ru", "phone": "+70512576167"}
0005432154084	43A66B	9129 447303	TATYANA BELOVA	{"email": "tatyana_belova.1977@postgrespro.ru", "phone": "+70022503848"}
0005432154085	D3037B	6974 861652	VALERIY VOLKOV	{"phone": "+70840940259"}
0005432154086	070338	2475 805566	ALEKSANDR KUZMIN	{"email": "a-kuzmin.1973@postgrespro.ru", "phone": "+70319175031"}
0005432154087	9AC7C8	4338 052719	VALENTIN GRIGOREV	{"email": "grigorevv051972@postgrespro.ru", "phone": "+70461537327"}
0005432154088	0BCC5D	5562 805904	SERGEY FROLOV	{"email": "frolov-s.29031971@postgrespro.ru", "phone": "+70551981098"}
0005432154089	0BCC5D	9192 155044	TATYANA ANDREEVA	{"phone": "+70724519064"}
0005432154090	0BCC5D	8995 028778	RIMMA GRISHINA	{"email": "grishina-rimma.1976@postgrespro.ru", "phone": "+70150545733"}
0005432154091	253B00	7833 752823	ALEKSANDR ZHURAVLEV	{"phone": "+70260866538"}
0005432154092	45F85D	9368 428213	YURIY FROLOV	{"email": "y_frolov.041972@postgrespro.ru", "phone": "+70029127384"}
0005432154093	45F85D	2267 297729	ANDREY GAVRILOV	{"phone": "+70165762384"}
0005432154094	6F49EB	0980 696889	ANATOLIY FROLOV	{"email": "frolov.a_12121980@postgrespro.ru", "phone": "+70069078572"}
0005432154095	6F49EB	3616 350810	DENIS SEMENOV	{"email": "denis-semenov-06021978@postgrespro.ru", "phone": "+70098826261"}
0005432154096	C9A3AC	1687 771088	KSENIYA GRISHINA	{"email": "kseniya.grishina051971@postgrespro.ru", "phone": "+70131191402"}
0005432154097	2D2C93	6158 411781	VALENTINA ZHUKOVA	{"phone": "+70361260864"}
0005432154098	2D2C93	5434 408394	ANTONINA KOROLEVA	{"email": "koroleva_antonina.021979@postgrespro.ru", "phone": "+70256559982"}
0005432154099	3E8EB7	3405 339196	PAVEL ROMANOV	{"email": "p.romanov-091964@postgrespro.ru", "phone": "+70077646554"}
0005432154100	901BD6	2451 136044	EKATERINA SOROKINA	{"email": "ekaterina_sorokina_15071977@postgrespro.ru", "phone": "+70597386981"}
0005432154101	901BD6	7799 843579	BORIS DENISOV	{"phone": "+70714394671"}
0005432154102	BA4F5C	1666 399595	ELENA NIKITINA	{"email": "nikitina_elena_20081973@postgrespro.ru", "phone": "+70811160981"}
0005432154103	E8B129	6011 906716	MARIYA ZHURAVLEVA	{"email": "zhuravleva_m021980@postgrespro.ru", "phone": "+70951101847"}
0005432154104	E8B129	2015 265130	ANNA SEMENOVA	{"phone": "+70556943484"}
0005432154105	617DF5	3408 663565	EVGENIY NIKOLAEV	{"phone": "+70428156658"}
0005432154106	65249B	1286 769020	NIKOLAY KRASNOV	{"email": "krasnov.nikolay_19021977@postgrespro.ru", "phone": "+70303085673"}
0005432154107	3AE0D0	0572 092221	SERGEY KUZNECOV	{"email": "kuznecov.sergey1967@postgrespro.ru", "phone": "+70447046468"}
0005432154108	3AE0D0	5709 884803	EKATERINA ALEKSANDROVA	{"email": "aleksandrova_ekaterina-1983@postgrespro.ru", "phone": "+70757946080"}
0005432154109	380E11	5086 382871	ZINAIDA SEMENOVA	{"phone": "+70326080701"}
0005432154110	9EFC71	9470 855774	NATALYA SAVELEVA	{"email": "n-saveleva-03041970@postgrespro.ru", "phone": "+70406113463"}
0005432154111	9EFC71	4492 141515	IRINA ANTONOVA	{"phone": "+70769734099"}
0005432154112	9EFC71	0434 671335	VLADIMIR VASILEV	{"phone": "+70445048558"}
0005432154113	0C0244	5453 914488	OLEG KUZNECOV	{"phone": "+70015446784"}
0005432154114	B0E7A4	9972 492464	VALENTIN FEDOTOV	{"email": "valentin-fedotov.121982@postgrespro.ru", "phone": "+70048724227"}
0005432154115	71692D	0979 020402	LIDIYA ANDREEVA	{"email": "andreeva_l_1963@postgrespro.ru", "phone": "+70082190913"}
0005432154116	A2CB71	0430 603454	EVGENIY NOVIKOV	{"phone": "+70585472240"}
0005432154117	23665E	7901 921691	VYACHESLAV ANTONOV	{"phone": "+70913091208"}
0005432154118	5B1E1E	5948 219855	NIKOLAY TIMOFEEV	{"email": "timofeev-n-10061967@postgrespro.ru", "phone": "+70072933534"}
0005432154119	7F384C	1973 103367	MAKSIM ZHUKOV	{"phone": "+70521506627"}
0005432154120	A7ED87	9460 213982	ANATOLIY KUZNECOV	{"phone": "+70379560275"}
0005432154121	498824	2517 929515	ANDREY SOROKIN	{"phone": "+70167727812"}
0005432154122	498824	7609 512142	YULIYA ALEKSEEVA	{"email": "yuliyaalekseeva_051975@postgrespro.ru", "phone": "+70319202586"}
0005432154123	2F2B52	1524 240600	SERGEY IVANOV	{"email": "ivanov.sergey_1972@postgrespro.ru", "phone": "+70463455961"}
0005432154124	EBC38E	9097 087277	NINA BORISOVA	{"email": "borisova.nina-021972@postgrespro.ru", "phone": "+70964801050"}
0005432154125	E4896F	9537 334795	LIDIYA ALEKSEEVA	{"phone": "+70187841767"}
0005432154126	570439	6877 543194	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev_1982@postgrespro.ru", "phone": "+70092324853"}
0005432154127	512471	1559 499201	EVGENIYA VOROBEVA	{"email": "e.vorobeva_05111972@postgrespro.ru", "phone": "+70306029525"}
0005432154128	7212BC	1977 868027	SVETLANA IVANOVA	{"phone": "+70187794650"}
0005432154129	5514EE	7301 628797	STEPAN NOVIKOV	{"phone": "+70427442192"}
0005432154130	C05960	7557 134030	NINA NIKIFOROVA	{"email": "nikiforova.nina_21091983@postgrespro.ru", "phone": "+70111543500"}
0005432154131	C05960	9195 874530	OLGA ANTONOVA	{"email": "antonova-olga_1963@postgrespro.ru", "phone": "+70134295213"}
0005432154132	C05960	1731 822509	ANDREY SOLOVEV	{"phone": "+70933448601"}
0005432154133	CF31D4	4107 622039	EKATERINA MOROZOVA	{"email": "morozova-e-081981@postgrespro.ru", "phone": "+70541030607"}
0005432154134	CF31D4	9827 823608	VLADIMIR DMITRIEV	{"email": "v_dmitriev_1970@postgrespro.ru", "phone": "+70785502384"}
0005432154135	394EC1	2264 303718	NADEZHDA SOKOLOVA	{"email": "sokolova.n.1982@postgrespro.ru", "phone": "+70328544927"}
0005432154136	9CBDD0	4423 840792	VIKTOR FEDOROV	{"phone": "+70354930433"}
0005432154137	6E62A2	3012 179232	VLADISLAV MAKAROV	{"phone": "+70574009323"}
0005432154138	6E62A2	9902 015818	ELENA VOROBEVA	{"phone": "+70745134684"}
0005432154139	AC3BBA	1358 380014	OLGA MIKHAYLOVA	{"email": "olga.mikhaylova-12071974@postgrespro.ru", "phone": "+70931770796"}
0005432156418	785C7B	3853 611925	VALERIY IVANOV	{"phone": "+70781532230"}
0005432156286	FEFF0B	0429 428771	ALLA POTAPOVA	{"phone": "+70121846550"}
0005432156287	7ED3CD	7705 713284	ILYA YAKOVLEV	{"phone": "+70297915316"}
0005432156288	064242	7822 408272	SERGEY FEDOROV	{"email": "sergey.fedorov-1975@postgrespro.ru", "phone": "+70346570947"}
0005432156289	BB6C2C	0656 527313	NINA KUZMINA	{"email": "nina_kuzmina_071985@postgrespro.ru", "phone": "+70874794343"}
0005432156290	BB6C2C	5190 945355	VYACHESLAV MAKAROV	{"phone": "+70166501992"}
0005432156291	901707	2290 878355	EVGENIY KAZAKOV	{"email": "e.kazakov.11081966@postgrespro.ru", "phone": "+70392606028"}
0005432156292	1C272F	8273 560348	BORIS BORISOV	{"email": "b_borisov.06021971@postgrespro.ru", "phone": "+70919630091"}
0005432156293	1C272F	9487 343600	ILYA KUZMIN	{"phone": "+70115894339"}
0005432156294	B1AFD3	7958 636465	SOFYA NIKITINA	{"phone": "+70021650693"}
0005432156295	D1BC64	7257 426117	TAMARA ZOTOVA	{"email": "tamarazotova1975@postgrespro.ru", "phone": "+70710601941"}
0005432156296	D1BC64	6926 937824	SVETLANA SOROKINA	{"email": "sorokina_svetlana_1967@postgrespro.ru", "phone": "+70929876181"}
0005432156297	68AC61	9760 983177	VALENTINA POPOVA	{"email": "popovavalentina_111957@postgrespro.ru", "phone": "+70254494750"}
0005432156298	624E9A	7227 529656	MARINA KOZLOVA	{"email": "marina-kozlova.031966@postgrespro.ru", "phone": "+70450304807"}
0005432156299	624E9A	6848 345059	VALERIYA BORISOVA	{"email": "borisova.valeriya_1974@postgrespro.ru", "phone": "+70460912161"}
0005432156300	EC6FFE	3671 960360	NIKOLAY SMIRNOV	{"phone": "+70180587032"}
0005432156301	0324E7	7315 035543	DANIIL KONOVALOV	{"phone": "+70948071220"}
0005432156302	0324E7	7713 368485	ALEKSANDR TIMOFEEV	{"email": "timofeev_a.061971@postgrespro.ru", "phone": "+70082751050"}
0005432156303	469DCA	0259 167359	MIKHAIL KOZLOV	{"phone": "+70331043105"}
0005432156304	432EB6	1857 047278	EVELINA NAUMOVA	{"email": "enaumova-021966@postgrespro.ru", "phone": "+70500961336"}
0005432156305	432EB6	7040 207234	KONSTANTIN KONOVALOV	{"phone": "+70428488256"}
0005432156306	432EB6	5407 613336	EMMA YAKOVLEVA	{"email": "e.yakovleva_041976@postgrespro.ru", "phone": "+70460349436"}
0005432156307	499851	0149 564306	ANTONINA EGOROVA	{"email": "egorova.a04091976@postgrespro.ru", "phone": "+70967064390"}
0005432156308	EDEDAF	8413 490076	OKSANA SEMENOVA	{"phone": "+70947031836"}
0005432156309	9D521B	8743 130274	TATYANA EGOROVA	{"phone": "+70126954446"}
0005432156310	9D521B	6467 160149	ALEKSEY BORISOV	{"email": "a-borisov_1965@postgrespro.ru", "phone": "+70469952087"}
0005432156311	9D521B	5450 467853	SERGEY ANTONOV	{"phone": "+70776660895"}
0005432156312	D7A770	4615 959554	NATALYA IVANOVA	{"email": "ivanova_n.02041967@postgrespro.ru", "phone": "+70964291808"}
0005432156313	6FBD61	2270 475028	ANASTASIYA POPOVA	{"phone": "+70671152690"}
0005432156314	B74719	0944 402768	ROMAN VOLKOV	{"phone": "+70158626148"}
0005432156315	B74719	2613 055323	LYUDMILA AFANASEVA	{"phone": "+70131746252"}
0005432156316	BF2830	3809 715324	ALEKSEY POPOV	{"phone": "+70769379040"}
0005432156317	6152DA	8933 262795	OLEG SOKOLOV	{"phone": "+70634381154"}
0005432156318	E62DF2	5178 096244	MARIYA DMITRIEVA	{"email": "mariya_dmitrieva1976@postgrespro.ru", "phone": "+70258484424"}
0005432156319	1522F5	2211 876133	IGOR PETROV	{"phone": "+70109499399"}
0005432156320	88BCE3	0937 343773	DMITRIY SEMENOV	{"email": "semenov_dmitriy.1959@postgrespro.ru", "phone": "+70268655346"}
0005432156321	D53026	4165 695943	KONSTANTIN VOROBEV	{"email": "k_vorobev_061966@postgrespro.ru", "phone": "+70160843547"}
0005432156322	D53026	7083 049676	YULIYA ZAKHAROVA	{"email": "zakharova_yuliya_27061983@postgrespro.ru", "phone": "+70956424073"}
0005432156323	D53026	7245 204993	VLADIMIR FEDOTOV	{"phone": "+70791741203"}
0005432156324	33974A	5915 085705	VIKTORIYA MOISEEVA	{"email": "moiseevaviktoriya.031967@postgrespro.ru", "phone": "+70243968305"}
0005432156325	33974A	9525 703006	SVETLANA BELYAEVA	{"email": "belyaeva.s-28101971@postgrespro.ru", "phone": "+70982024072"}
0005432156326	33974A	9468 194350	EKATERINA PAVLOVA	{"email": "e_pavlova-121965@postgrespro.ru", "phone": "+70840697791"}
0005432156327	224101	8046 455820	NADEZHDA ANISIMOVA	{"email": "nadezhda.anisimova-1964@postgrespro.ru", "phone": "+70493750239"}
0005432156328	05FB95	8297 629348	VLADIMIR SEMENOV	{"phone": "+70685830089"}
0005432156329	50CC2E	1796 272760	IRINA MALYSHEVA	{"email": "irina.malysheva.02061967@postgrespro.ru", "phone": "+70979881921"}
0005432156330	C6A7C0	6881 838889	NIKITA OSIPOV	{"phone": "+70015005103"}
0005432156331	0600A5	5210 976535	PAVEL MEDVEDEV	{"email": "p.medvedev-1967@postgrespro.ru", "phone": "+70604113143"}
0005432156332	0600A5	5269 035944	DENIS VLASOV	{"phone": "+70223948480"}
0005432156333	213425	4137 166076	GALINA MAKAROVA	{"email": "makarova_galina17111958@postgrespro.ru", "phone": "+70340697465"}
0005432156334	5F847F	4881 926759	SERGEY DENISOV	{"phone": "+70923515453"}
0005432156335	C8644B	2377 697116	PETR FOMIN	{"phone": "+70590828685"}
0005432156336	C8644B	9727 880793	EVGENIY GERASIMOV	{"email": "evgeniy_gerasimov-22121965@postgrespro.ru", "phone": "+70121082820"}
0005432156337	B315FB	4231 547940	VLADIMIR GUSEV	{"phone": "+70544170420"}
0005432156338	B315FB	8812 128040	SERGEY VASILEV	{"phone": "+70359752787"}
0005432156339	0B3F0F	8389 687794	RINAT VLASOV	{"email": "vlasovrinat111962@postgrespro.ru", "phone": "+70827759214"}
0005432156340	915590	6178 421714	OKSANA OSIPOVA	{"email": "oksanaosipova.19051984@postgrespro.ru", "phone": "+70778480049"}
0005432156341	915590	2619 123106	NATALYA DAVYDOVA	{"phone": "+70286360697"}
0005432156342	915590	8539 312975	TATYANA POPOVA	{"phone": "+70108161987"}
0005432156343	E75F10	2826 266456	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr_1975@postgrespro.ru", "phone": "+70594045820"}
0005432156344	E7A6F9	3014 547027	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev-1967@postgrespro.ru", "phone": "+70223787160"}
0005432156345	2AC755	7593 842096	NATALIYA KOROLEVA	{"phone": "+70557531649"}
0005432156346	803944	9916 647625	IRINA KISELEVA	{"email": "irina-kiseleva.111965@postgrespro.ru", "phone": "+70743410409"}
0005432156347	B3D606	7676 097054	VIKTORIYA KOROLEVA	{"email": "v-koroleva-091973@postgrespro.ru", "phone": "+70044639761"}
0005432156348	3EFCAF	4095 886479	SERGEY KARPOV	{"email": "sergey_karpov_1963@postgrespro.ru", "phone": "+70896082317"}
0005432156349	3EFCAF	0122 060612	DMITRIY NOVIKOV	{"phone": "+70296781576"}
0005432156350	B86B77	4527 457310	SAMIRA ARKHIPOVA	{"phone": "+70933957381"}
0005432156351	407F1E	8636 257823	ALEKSANDR VOROBEV	{"email": "vorobev-aleksandr1977@postgrespro.ru", "phone": "+70126037226"}
0005432156352	407F1E	0015 332371	NATALYA NIKOLAEVA	{"phone": "+70904453778"}
0005432156353	38E6C0	0721 975841	VIKTOR VOLKOV	{"phone": "+70100404921"}
0005432156354	38E6C0	1680 620094	EKATERINA BORISOVA	{"email": "borisova_e051972@postgrespro.ru", "phone": "+70177473096"}
0005432156355	F9B377	3317 961339	DENIS PAVLOV	{"phone": "+70241024403"}
0005432156356	B54AA4	5187 644942	LYUBOV SAVELEVA	{"email": "lyubov-saveleva_1968@postgrespro.ru", "phone": "+70289185638"}
0005432156357	2FA189	8064 807974	ARINA MASLOVA	{"phone": "+70828802022"}
0005432156358	2FA189	0441 633414	TATYANA KOMAROVA	{"email": "t_komarova051982@postgrespro.ru", "phone": "+70443230952"}
0005432156359	A1403D	8348 003248	NATALIYA YAKOVLEVA	{"email": "n-yakovleva_071974@postgrespro.ru", "phone": "+70818659432"}
0005432156360	A1403D	2781 261280	SVETLANA MIKHAYLOVA	{"email": "smikhaylova.1969@postgrespro.ru", "phone": "+70597446217"}
0005432156361	55FC23	9667 804939	SVETLANA KUZNECOVA	{"email": "svetlana_kuznecova-1969@postgrespro.ru", "phone": "+70865230517"}
0005432156362	AA7239	5752 697427	ALEKSEY ZAKHAROV	{"email": "zakharov_a-071975@postgrespro.ru", "phone": "+70413068013"}
0005432156363	C68BBC	1291 730226	DENIS NIKITIN	{"email": "dnikitin.091976@postgrespro.ru", "phone": "+70761271376"}
0005432156364	CADE93	1269 505811	ELENA NIKOLAEVA	{"email": "nikolaeva-e.011979@postgrespro.ru", "phone": "+70933271556"}
0005432156365	CADE93	2423 830524	SERGEY KUZMIN	{"email": "kuzminsergey-011962@postgrespro.ru", "phone": "+70163994195"}
0005432156366	CADE93	5549 690257	ALEKSANDR FROLOV	{"phone": "+70581196904"}
0005432156367	F89A29	2285 915535	MIKHAIL SCHERBAKOV	{"phone": "+70511293895"}
0005432156368	2FC17A	1537 642160	ALEKSANDR NIKOLAEV	{"phone": "+70037562191"}
0005432156369	2FC17A	9634 971240	KSENIYA EGOROVA	{"email": "egorova.kseniya_11081961@postgrespro.ru", "phone": "+70912613854"}
0005432156370	DF9945	8330 348561	TATYANA DENISOVA	{"phone": "+70600268151"}
0005432156371	2DB7B9	2996 644894	VLADIMIR FEDOTOV	{"phone": "+70428001287"}
0005432156372	4DB5B9	6824 286719	YURIY SERGEEV	{"email": "sergeev.y04101976@postgrespro.ru", "phone": "+70181386902"}
0005432156373	474738	0244 867449	ELENA MEDVEDEVA	{"email": "medvedeva.elena-1967@postgrespro.ru", "phone": "+70846774465"}
0005432156374	DD2B1D	3047 525675	ALEKSANDR MARTYNOV	{"email": "martynov-a.1968@postgrespro.ru", "phone": "+70646432292"}
0005432156375	4DBDC9	6512 283487	NATALYA EGOROVA	{"email": "natalyaegorova01031985@postgrespro.ru", "phone": "+70119179575"}
0005432156376	4DBDC9	1818 540056	SERGEY BORISOV	{"phone": "+70581191518"}
0005432156377	CEF65B	6828 530275	VLADIMIR PETROV	{"email": "petrovvladimir-06091982@postgrespro.ru", "phone": "+70289375644"}
0005432156378	CEF65B	1235 428905	VYACHESLAV BONDARENKO	{"phone": "+70490978020"}
0005432156379	01B95D	9125 849108	TATYANA SIDOROVA	{"phone": "+70975145847"}
0005432156380	91E5E1	3073 678331	NINA SERGEEVA	{"phone": "+70009856927"}
0005432156381	146C7E	4139 001102	VLADIMIR KULIKOV	{"email": "vladimir_kulikov.09091979@postgrespro.ru", "phone": "+70872410340"}
0005432156382	146C7E	3082 817366	POLINA NESTEROVA	{"email": "nesterova_polina_041971@postgrespro.ru", "phone": "+70569368083"}
0005432156383	8E1731	5054 245101	VYACHESLAV ABRAMOV	{"email": "vabramov_27101968@postgrespro.ru", "phone": "+70831852060"}
0005432156384	9CDD44	1671 743558	TATYANA ZHURAVLEVA	{"email": "zhuravlevat_1959@postgrespro.ru", "phone": "+70435343225"}
0005432156385	126341	0167 272676	ILYA ZAKHAROV	{"phone": "+70760204837"}
0005432156386	126341	3906 022872	VLADISLAV KRASNOV	{"email": "v.krasnov_101978@postgrespro.ru", "phone": "+70768793140"}
0005432156387	F8B553	8708 405974	ALEKSANDR TIKHONOV	{"phone": "+70905793418"}
0005432156388	19996F	8939 891494	ALEKSEY NAZAROV	{"email": "a.nazarov.12021972@postgrespro.ru", "phone": "+70059220745"}
0005432156389	2BD633	8329 712947	OLEG KUZNECOV	{"email": "kuznecov-oleg_031964@postgrespro.ru", "phone": "+70362539241"}
0005432156390	2BD633	9162 019460	KSENIYA ERMAKOVA	{"email": "kseniyaermakova.06111960@postgrespro.ru", "phone": "+70920760799"}
0005432156391	43B429	9845 764957	ALBINA FROLOVA	{"email": "albina-frolova-081966@postgrespro.ru", "phone": "+70934354795"}
0005432156392	C09F01	9704 973077	MAKSIM KUZNECOV	{"email": "m.kuznecov_02121972@postgrespro.ru", "phone": "+70692692424"}
0005432156393	7CB098	2929 048102	NINA MELNIKOVA	{"phone": "+70346474720"}
0005432156394	7CB098	2565 784443	SVETLANA VLASOVA	{"email": "vlasova_s-28011976@postgrespro.ru", "phone": "+70819561482"}
0005432156395	65FCE8	9356 476957	DMITRIY MELNIKOV	{"email": "melnikov.d_1964@postgrespro.ru", "phone": "+70917993449"}
0005432156396	65FCE8	5657 958919	NATALYA ALEKSEEVA	{"phone": "+70706034500"}
0005432156397	65FCE8	9239 038899	DARYA KOLESNIKOVA	{"email": "kolesnikova-darya.1962@postgrespro.ru", "phone": "+70536389312"}
0005432156398	A90F6D	4199 699663	YULIYA ANTONOVA	{"phone": "+70280493752"}
0005432156399	F9E3C3	2181 701565	OLGA KUZNECOVA	{"email": "olga.kuznecova-061969@postgrespro.ru", "phone": "+70538405766"}
0005432156400	12C827	6776 745704	NATALYA MATVEEVA	{"phone": "+70240036825"}
0005432156401	12C827	7905 749719	ANDREY SAVELEV	{"phone": "+70380133931"}
0005432156402	9FB92C	6146 476695	ALEKSANDR IVANOV	{"email": "ivanovaleksandr051976@postgrespro.ru", "phone": "+70068254703"}
0005432156403	9FB92C	3433 115401	ELENA ABRAMOVA	{"email": "abramovaelena_13101977@postgrespro.ru", "phone": "+70323139847"}
0005432156404	D6F469	5545 909509	MARIYA ZAYCEVA	{"email": "mzayceva-011972@postgrespro.ru", "phone": "+70266272551"}
0005432156405	A942A3	6430 172737	VALENTINA FILIPPOVA	{"phone": "+70308026512"}
0005432156406	BF0F7A	2448 033724	NINA STEPANOVA	{"email": "nstepanova.061972@postgrespro.ru", "phone": "+70448733825"}
0005432156407	0B455B	2692 218395	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr_051971@postgrespro.ru", "phone": "+70761567467"}
0005432156408	E047DC	2027 847254	VYACHESLAV ISAEV	{"email": "vyacheslav-isaev.1969@postgrespro.ru", "phone": "+70715544060"}
0005432156409	E047DC	3721 402100	SERGEY KISELEV	{"email": "sergey_kiselev.091974@postgrespro.ru", "phone": "+70135771975"}
0005432156410	99FA05	9799 791312	ELENA GORBUNOVA	{"email": "gorbunova_e1962@postgrespro.ru", "phone": "+70585890733"}
0005432156411	2B18CD	2359 572271	IVAN BORISOV	{"email": "borisov_ivan28041958@postgrespro.ru", "phone": "+70205609133"}
0005432156412	67B6C7	9361 628681	IVAN SHEVCHENKO	{"email": "ivanshevchenko-011981@postgrespro.ru", "phone": "+70194022047"}
0005432156413	5CDAA7	0099 734089	IDA MAKSIMOVA	{"phone": "+70772389100"}
0005432156414	5CDAA7	8639 288832	VYACHESLAV KRASNOV	{"email": "v-krasnov.1971@postgrespro.ru", "phone": "+70682958559"}
0005432156415	5CDAA7	7737 391430	SERGEY SEMENOV	{"phone": "+70950589170"}
0005432156416	C3B3E6	9277 414535	ALEKSEY VOROBEV	{"phone": "+70110428751"}
0005432156417	C3B3E6	1819 324025	ALEKSEY GAVRILOV	{"phone": "+70868076475"}
0005432156419	785C7B	9540 619011	MARIYA PETROVA	{"email": "petrova_m-101976@postgrespro.ru", "phone": "+70697250720"}
0005432156420	FBBF35	6954 995411	GENNADIY KULIKOV	{"phone": "+70009383099"}
0005432156421	48C4CF	7739 419333	FANIYA KOLESNIKOVA	{"phone": "+70504635770"}
0005432156422	48C4CF	0108 142829	DMITRIY GRIGOREV	{"phone": "+70609109590"}
0005432156423	DA2806	6374 154969	GALINA BORISOVA	{"phone": "+70456106628"}
0005432156424	63D963	4817 928472	ALEKSEY MARTYNOV	{"email": "aleksey.martynov.23071980@postgrespro.ru", "phone": "+70151980548"}
0005432156425	E7F9E3	6465 557046	ARTEM KOROLEV	{"phone": "+70418838058"}
0005432156426	4D54D9	1751 696648	TATYANA BOGDANOVA	{"email": "bogdanova-t.06061975@postgrespro.ru", "phone": "+70703408516"}
0005432156427	C84493	2977 904446	VASILIY SCHERBAKOV	{"email": "scherbakovv.1975@postgrespro.ru", "phone": "+70742505037"}
0005432156428	F59CB4	1846 251365	IVAN SOKOLOV	{"email": "i.sokolov.1964@postgrespro.ru", "phone": "+70225843507"}
0005432156429	1CA45C	1324 210328	LARISA KARPOVA	{"email": "l_karpova.061979@postgrespro.ru", "phone": "+70545229006"}
0005432156430	9D042D	9318 440115	IRINA NIKITINA	{"email": "nikitina_i_11091978@postgrespro.ru", "phone": "+70668299294"}
0005432156431	9D042D	6496 503871	TATYANA FILATOVA	{"phone": "+70375459091"}
0005432156432	23F6ED	2272 934581	VALENTINA ANDREEVA	{"email": "v.andreeva.041972@postgrespro.ru", "phone": "+70858903536"}
0005432156433	28FF9A	8916 730418	ALEKSANDR IVANOV	{"phone": "+70586160478"}
0005432156434	28FF9A	7929 105286	IRINA SOKOLOVA	{"email": "sokolovai.031982@postgrespro.ru", "phone": "+70910221878"}
0005432156435	CFE6AC	7868 460488	LYUDMILA BELOVA	{"phone": "+70537780853"}
0005432156436	CFE6AC	8797 083591	IRINA VOLKOVA	{"phone": "+70926870272"}
0005432156437	FAF842	0683 778233	TAMARA ZOTOVA	{"email": "zotova_tamara1972@postgrespro.ru", "phone": "+70138388717"}
0005432156438	FAF842	4966 281400	GALINA ILINA	{"phone": "+70974211184"}
0005432156439	4CDAF3	2884 509166	PETR GORBUNOV	{"email": "petr-gorbunov-01101976@postgrespro.ru", "phone": "+70136398919"}
0005432156440	4CDAF3	8748 170193	SVETLANA MAKAROVA	{"phone": "+70885631460"}
0005432156441	767A94	6299 494909	SERGEY YAKOVLEV	{"email": "yakovlev.sergey23081970@postgrespro.ru", "phone": "+70710952971"}
0005432156442	8AE9EC	4919 577175	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey-1981@postgrespro.ru", "phone": "+70199489921"}
0005432156443	8AE9EC	4929 834675	TIMUR DMITRIEV	{"email": "tdmitriev.22121965@postgrespro.ru", "phone": "+70207719099"}
0005432156444	95D37A	9544 113610	SERGEY KUDRYASHOV	{"email": "s_kudryashov_1980@postgrespro.ru", "phone": "+70620049206"}
0005432156445	7F952C	0783 212618	NINA MATVEEVA	{"email": "nina_matveeva.1971@postgrespro.ru", "phone": "+70716611708"}
0005432156446	7F952C	0804 987979	VALENTINA OVCHINNIKOVA	{"email": "v-ovchinnikova_03081971@postgrespro.ru", "phone": "+70033841526"}
0005432156447	07892D	5035 062272	STEPAN VASILEV	{"phone": "+70987760743"}
0005432156448	4346AC	2143 990130	EVGENIY NAZAROV	{"phone": "+70915596773"}
0005432156449	FEA47B	4408 603212	STANISLAV ANDREEV	{"phone": "+70170858213"}
0005432156450	E956D3	3268 641526	NIKOLAY ABRAMOV	{"email": "nikolay.abramov101966@postgrespro.ru", "phone": "+70651725541"}
0005432156451	E956D3	3558 851228	DANILA GORBUNOV	{"phone": "+70276834130"}
0005432156452	E956D3	9135 562538	EVGENIY FROLOV	{"email": "frolov.evgeniy-01111967@postgrespro.ru", "phone": "+70683565445"}
0005432156453	E956D3	7445 200123	ANDREY BORISOV	{"email": "andrey_borisov-071973@postgrespro.ru", "phone": "+70912366295"}
0005432157536	A4815C	1261 390915	VIKTOR VLASOV	{"phone": "+70184056407"}
0005432156454	A68557	3213 556983	ALESYA ANDREEVA	{"email": "andreeva.alesya021965@postgrespro.ru", "phone": "+70539341576"}
0005432156455	D46403	6323 318154	YURIY DMITRIEV	{"email": "dmitrievyuriy1973@postgrespro.ru", "phone": "+70573910930"}
0005432156456	D46403	8394 106788	TATYANA PETROVA	{"email": "petrova-t1975@postgrespro.ru", "phone": "+70784984517"}
0005432156457	B41D21	7416 883923	VASILIY YAKOVLEV	{"phone": "+70299013067"}
0005432156458	AA1314	7903 327475	MIKHAIL ZAKHAROV	{"phone": "+70424679834"}
0005432156459	3B61F8	6876 040824	LYUBOV POLYAKOVA	{"phone": "+70001548081"}
0005432156460	F02E8A	6620 034500	EVGENIYA FILATOVA	{"phone": "+70592223745"}
0005432156461	29302C	6973 119861	VADIM ROMANOV	{"phone": "+70114691214"}
0005432156462	603507	2575 018668	VIKTOR ALEKSANDROV	{"phone": "+70655125937"}
0005432156463	F4AE67	7518 279250	NINA KUZMINA	{"phone": "+70231284994"}
0005432156464	A925FD	7092 900516	RAFAIL VOROBEV	{"phone": "+70201263471"}
0005432156465	A925FD	2960 739140	ALFIYA KOZLOVA	{"phone": "+70487025218"}
0005432156466	A925FD	6758 314431	VADIM NOVIKOV	{"email": "novikov_v03101973@postgrespro.ru", "phone": "+70563607049"}
0005432156467	8D97D4	9022 358375	ALEKSEY FEDOROV	{"email": "a_fedorov_04011968@postgrespro.ru", "phone": "+70950379462"}
0005432156468	D33759	5855 883178	MAKSIM AFANASEV	{"email": "afanasev-m-29121966@postgrespro.ru", "phone": "+70209173014"}
0005432156469	D33759	7188 520276	INNA NIKITINA	{"phone": "+70610361311"}
0005432156470	A3596A	2854 473534	MARIYA MARTYNOVA	{"email": "mariya_martynova_081951@postgrespro.ru", "phone": "+70811019931"}
0005432156471	0697E1	2781 621917	ANASTASIYA GERASIMOVA	{"email": "gerasimova-anastasiya04061970@postgrespro.ru", "phone": "+70627855306"}
0005432156472	C286FA	8223 633726	ALENA SAVELEVA	{"phone": "+70174393055"}
0005432156473	C286FA	0195 668591	ALEVTINA ALEKSEEVA	{"email": "alekseeva_a_08121974@postgrespro.ru", "phone": "+70364030958"}
0005432156474	904CC4	7659 766448	MARAT FEDOROV	{"email": "marat.fedorov18071967@postgrespro.ru", "phone": "+70411412983"}
0005432156475	57E3B7	2352 586161	LYUDMILA MELNIKOVA	{"phone": "+70565927246"}
0005432156476	D1738B	7634 537028	TAISIYA POLYAKOVA	{"email": "taisiya_polyakova.01021981@postgrespro.ru", "phone": "+70656717302"}
0005432156477	B7F443	7014 561128	ALENA ANTONOVA	{"phone": "+70401094819"}
0005432156478	8A6963	9415 746251	EKATERINA KUZMINA	{"email": "ekaterina.kuzmina30071957@postgrespro.ru", "phone": "+70676854849"}
0005432156479	169ACE	4096 187355	GALINA ALEKSANDROVA	{"email": "galina.aleksandrova.26031958@postgrespro.ru", "phone": "+70689236440"}
0005432156480	EAE5D4	8966 119341	ALEKSEY MEDVEDEV	{"email": "aleksey_medvedev_101978@postgrespro.ru", "phone": "+70346612798"}
0005432156481	AD280F	6654 479590	GRIGORIY NIKOLAEV	{"email": "nikolaev_g_14101973@postgrespro.ru", "phone": "+70067661492"}
0005432156482	B40642	0223 689573	ALEKSANDRA FROLOVA	{"phone": "+70129891509"}
0005432156483	B40642	3169 119222	YULIYA RODIONOVA	{"phone": "+70351276024"}
0005432156484	B40642	9144 549357	VLADIMIR POPOV	{"phone": "+70669959087"}
0005432156485	EDCF01	4147 248965	ANDREY YAKOVLEV	{"email": "yakovlevandrey.21111970@postgrespro.ru", "phone": "+70227051132"}
0005432156486	EDCF01	7647 597178	ANASTASIYA ROMANOVA	{"email": "a.romanova_1974@postgrespro.ru", "phone": "+70811924969"}
0005432156487	5084A4	7522 141607	NINA SEMENOVA	{"phone": "+70638483329"}
0005432156488	5084A4	3353 681246	OLGA SAVELEVA	{"phone": "+70004646945"}
0005432156489	AB4F7A	1925 887262	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov-1973@postgrespro.ru", "phone": "+70491357613"}
0005432156490	CB3BA8	0887 198276	MARINA KUZNECOVA	{"phone": "+70963866342"}
0005432156491	CB3BA8	1564 973957	VLADIMIR PETROV	{"phone": "+70440906759"}
0005432156492	F1D995	0505 881133	NATALYA KOROLEVA	{"phone": "+70724392181"}
0005432156493	F1D995	8982 131000	ELENA TARASOVA	{"email": "elena-tarasova-011975@postgrespro.ru", "phone": "+70048738522"}
0005432157457	201210	5896 205509	OLGA GRISHINA	{"phone": "+70273857850"}
0005432157458	201210	1583 542093	LILIYA ZAYCEVA	{"email": "zayceva.liliya-1972@postgrespro.ru", "phone": "+70823833175"}
0005432157459	6462A6	9167 975131	DARYA ANDREEVA	{"email": "andreeva-darya_091960@postgrespro.ru", "phone": "+70792934258"}
0005432157460	6462A6	9261 408699	ARTEM TARASOV	{"email": "a.tarasov1970@postgrespro.ru", "phone": "+70883966631"}
0005432157461	C76996	7806 883223	IRINA SEMENOVA	{"phone": "+70765927812"}
0005432157462	83A47E	0141 219540	EKATERINA FILIPPOVA	{"phone": "+70711420787"}
0005432157463	83A47E	2400 022262	IGOR SIDOROV	{"email": "sidorov_i_04101976@postgrespro.ru", "phone": "+70891258911"}
0005432157464	5F646E	9620 206600	ANNA CHERNOVA	{"email": "chernova.anna_1968@postgrespro.ru", "phone": "+70875538795"}
0005432157465	CAEB99	2816 003789	MARINA TIMOFEEVA	{"phone": "+70762281216"}
0005432157466	CAEB99	0769 000287	ALENA VOROBEVA	{"email": "a.vorobeva.14051965@postgrespro.ru", "phone": "+70798953131"}
0005432157467	936AD8	2983 392390	EVGENIYA DMITRIEVA	{"phone": "+70147512312"}
0005432157468	FF4581	6181 752346	VALENTINA GRISHINA	{"phone": "+70569492275"}
0005432157469	C9D1C3	3465 501173	IVAN ANDREEV	{"phone": "+70423894217"}
0005432157470	A0CE88	0392 431437	SERGEY STEPANOV	{"email": "stepanov-sergey-071974@postgrespro.ru", "phone": "+70341453201"}
0005432157471	D3CF98	0563 165178	YULIYA IVANOVA	{"email": "ivanova.yuliya_1975@postgrespro.ru", "phone": "+70613814025"}
0005432157472	D3CF98	5075 277281	ROMAN MIRONOV	{"phone": "+70235221382"}
0005432157473	03410A	1118 777922	SALAVAT ANDREEV	{"email": "salavat_andreev-12071984@postgrespro.ru", "phone": "+70800838145"}
0005432157474	03410A	2436 635510	EVGENIY SCHERBAKOV	{"phone": "+70271314604"}
0005432157475	B0D8A6	6922 947441	ALEKSEY GAVRILOV	{"email": "a_gavrilov.071961@postgrespro.ru", "phone": "+70114209401"}
0005432157476	80BDF1	7913 741970	TAISIYA GAVRILOVA	{"email": "t.gavrilova_11111966@postgrespro.ru", "phone": "+70985383618"}
0005432157477	80BDF1	1549 042183	YAROSLAVA MOROZOVA	{"email": "morozova.yaroslava05091973@postgrespro.ru", "phone": "+70294431055"}
0005432157478	0E0911	0989 770400	NIKOLAY PETROV	{"email": "n.petrov.1963@postgrespro.ru", "phone": "+70676713183"}
0005432157479	DAB1CF	5861 633573	ELENA DENISOVA	{"email": "denisova.elena-121974@postgrespro.ru", "phone": "+70660508042"}
0005432157480	AB2AB2	3268 888933	PAVEL BORISOV	{"email": "borisov-p_071980@postgrespro.ru", "phone": "+70799549626"}
0005432157481	AB2AB2	8712 853262	SERGEY ZAKHAROV	{"phone": "+70264768197"}
0005432157482	712DAB	0932 921670	TIMUR ORLOV	{"email": "orlov_timur-23101976@postgrespro.ru", "phone": "+70025223573"}
0005432157483	AE328E	4139 363526	OLGA MIRONOVA	{"email": "mironova-olga21091966@postgrespro.ru", "phone": "+70644294418"}
0005432157484	DEEA20	2888 679412	VALENTINA ANDREEVA	{"phone": "+70587743182"}
0005432157485	DEEA20	2285 176334	OLGA ANTONOVA	{"email": "olga.antonova011966@postgrespro.ru", "phone": "+70003435940"}
0005432157486	5C332B	1854 787121	ANDREY MELNIKOV	{"phone": "+70293961789"}
0005432157487	AB9124	1930 984809	GALINA FOMINA	{"phone": "+70480279627"}
0005432157488	9BCC1A	0631 209625	VALENTINA POPOVA	{"phone": "+70023491023"}
0005432157489	7426EE	1024 325175	ALEKSANDR KULIKOV	{"phone": "+70170871642"}
0005432157490	7426EE	8977 809474	ANNA VASILEVA	{"phone": "+70610092893"}
0005432157491	4255F8	3855 630528	KRISTINA NESTEROVA	{"email": "nesterova_k_041983@postgrespro.ru", "phone": "+70422017989"}
0005432157492	9FFBFB	8278 029164	NIKOLAY MAKSIMOV	{"email": "nmaksimov_021973@postgrespro.ru", "phone": "+70159394721"}
0005432157493	C7A417	3791 568823	NATALYA NESTEROVA	{"email": "nesterova_n1974@postgrespro.ru", "phone": "+70182092303"}
0005432157494	120948	4845 859349	VLADIMIR STEPANOV	{"email": "stepanov_vladimir.051979@postgrespro.ru", "phone": "+70933183512"}
0005432157495	0C3CCC	9213 454694	ANATOLIY POPOV	{"phone": "+70472299765"}
0005432157496	0C3CCC	4903 960431	GALINA STEPANOVA	{"email": "stepanovag.061969@postgrespro.ru", "phone": "+70054515254"}
0005432157497	357056	8243 111163	GALINA ORLOVA	{"email": "g.orlova081966@postgrespro.ru", "phone": "+70207922187"}
0005432157498	357056	2015 357893	VIKTORIYA SMIRNOVA	{"phone": "+70862621146"}
0005432157499	357056	0560 340087	TATYANA POLYAKOVA	{"email": "polyakova_tatyana_091979@postgrespro.ru", "phone": "+70861639792"}
0005432157500	72DC9D	6863 484695	ZINAIDA MELNIKOVA	{"phone": "+70280539582"}
0005432157501	72DC9D	2057 858981	DMITRIY MOROZOV	{"phone": "+70740534666"}
0005432157502	573C46	9011 258337	TATYANA FROLOVA	{"email": "tatyanafrolova-101967@postgrespro.ru", "phone": "+70605080126"}
0005432157503	E27522	1347 335818	VALENTINA ANTONOVA	{"phone": "+70622540482"}
0005432157504	E27522	2955 973156	ANDREY KAZAKOV	{"email": "andrey_kazakov.081967@postgrespro.ru", "phone": "+70246499021"}
0005432157505	384154	6887 614980	NATALYA KUZNECOVA	{"email": "kuznecovan_1972@postgrespro.ru", "phone": "+70110782796"}
0005432157506	1A5859	0300 777922	NADEZHDA KONOVALOVA	{"email": "konovalova_n.031978@postgrespro.ru", "phone": "+70486915368"}
0005432157507	1A5859	7010 768864	TAMARA NOVIKOVA	{"email": "tamara_novikova_27071970@postgrespro.ru", "phone": "+70083984740"}
0005432157508	CD8FCA	1644 859274	OLGA OSIPOVA	{"phone": "+70823108689"}
0005432157509	5A38C9	8709 389084	IGOR MIKHAYLOV	{"phone": "+70764375946"}
0005432157510	7AF5D2	9400 650246	TAMARA MIRONOVA	{"phone": "+70990460661"}
0005432157511	592C68	4327 933900	SERGEY NIKITIN	{"email": "sergey_nikitin-19061975@postgrespro.ru", "phone": "+70789752266"}
0005432157512	A94A7A	8148 622917	ELENA BELOVA	{"email": "e_belova30081969@postgrespro.ru", "phone": "+70122005642"}
0005432157513	7910A3	0452 004849	SERGEY KARPOV	{"email": "s.karpov.051977@postgrespro.ru", "phone": "+70576644068"}
0005432157514	07C9DA	1600 806556	ZINAIDA KUZNECOVA	{"email": "zinaida-kuznecova.041976@postgrespro.ru", "phone": "+70992943858"}
0005432157515	35283B	6973 574466	TATYANA KALININA	{"phone": "+70525501858"}
0005432157516	CF728F	9601 017625	NATALYA POPOVA	{"phone": "+70559052089"}
0005432157517	F14225	2180 751466	NIKOLAY SEMENOV	{"phone": "+70778028830"}
0005432157518	F14225	2174 605012	IGOR MAKAROV	{"email": "makarov_i-111971@postgrespro.ru", "phone": "+70825869393"}
0005432157519	63B448	1014 995691	MIKHAIL FEDOROV	{"email": "fedorov_mikhail.091972@postgrespro.ru", "phone": "+70238998841"}
0005432157520	41AE15	7343 896302	ALEKSEY MEDVEDEV	{"email": "a-medvedev.111967@postgrespro.ru", "phone": "+70675472655"}
0005432157521	EFC28F	4400 986387	EVGENIYA DENISOVA	{"email": "denisovaevgeniya_1971@postgrespro.ru", "phone": "+70884247640"}
0005432157522	006306	7868 632616	EVGENIY VOROBEV	{"email": "vorobevevgeniy_101974@postgrespro.ru", "phone": "+70892112037"}
0005432157523	006306	3818 884363	EVGENIYA GUSEVA	{"phone": "+70466251276"}
0005432157524	D3E506	3163 708458	PETR KOZLOV	{"email": "p-kozlov-021981@postgrespro.ru", "phone": "+70469046512"}
0005432157525	D3E506	1683 921581	OLGA SERGEEVA	{"email": "o-sergeeva1983@postgrespro.ru", "phone": "+70885150543"}
0005432157526	EAD818	2327 444082	ELENA AFANASEVA	{"email": "eafanaseva.101974@postgrespro.ru", "phone": "+70123534314"}
0005432157527	D449FE	8319 860528	NIKOLAY POPOV	{"phone": "+70168470480"}
0005432157528	AC22AA	0073 859024	EKATERINA FILATOVA	{"phone": "+70538310789"}
0005432157529	AC22AA	5986 981156	NADEZHDA KOVALEVA	{"phone": "+70379799561"}
0005432157530	CBD64E	5276 742034	FARIT SMIRNOV	{"phone": "+70911795565"}
0005432157531	EDDC8F	7169 776885	PAVEL KAZAKOV	{"email": "pavel_kazakov1974@postgrespro.ru", "phone": "+70682367415"}
0005432157532	5AA69E	0010 075632	ALEKSANDR ORLOV	{"phone": "+70896778860"}
0005432157533	5AA69E	6903 265310	SVETLANA FOMINA	{"email": "fomina_s-031971@postgrespro.ru", "phone": "+70431493925"}
0005432157534	8BCB96	1138 011502	IGOR FEDOTOV	{"email": "fedotovigor.01071967@postgrespro.ru", "phone": "+70133132638"}
0005432157535	53CB0A	8009 130887	MARINA SERGEEVA	{"email": "sergeevam-121975@postgrespro.ru", "phone": "+70447772575"}
0005432157537	A4815C	7924 059223	IRINA IVANOVA	{"phone": "+70924354240"}
0005432157538	A4815C	0208 543215	ELENA NESTEROVA	{"phone": "+70191089766"}
0005432157539	842BE9	9334 713889	OLGA NAZAROVA	{"phone": "+70580522167"}
0005432157540	1AF38A	1276 566991	SERGEY KUZMIN	{"email": "sergey_kuzmin.1980@postgrespro.ru", "phone": "+70777384451"}
0005432157541	1AF38A	8408 682549	VITALIY PAVLOV	{"phone": "+70231193720"}
0005432157542	FA8BA2	8379 606512	NADEZHDA KUZMINA	{"phone": "+70031730567"}
0005432157543	FA8BA2	3045 448626	ANNA ROMANOVA	{"email": "anna_romanova051987@postgrespro.ru", "phone": "+70217880440"}
0005432157544	FA8BA2	4922 340324	VALENTIN MELNIKOV	{"phone": "+70077353503"}
0005432157545	323EF3	1805 318677	ELMIRA IVANOVA	{"phone": "+70314842535"}
0005432157546	768E00	9368 106240	ANATOLIY VOLKOV	{"email": "avolkov-14061984@postgrespro.ru", "phone": "+70558315830"}
0005432157547	768E00	6365 481503	IRINA SOROKINA	{"email": "sorokina_irina.051969@postgrespro.ru", "phone": "+70499994383"}
0005432157548	9CD926	1408 371662	PETR KRASNOV	{"email": "p_krasnov-121975@postgrespro.ru", "phone": "+70437021896"}
0005432157549	557E60	6745 325006	ANASTASIYA NIKITINA	{"email": "anikitina-051971@postgrespro.ru", "phone": "+70688934892"}
0005432159775	BA7FAF	5633 888162	PAVEL ILIN	{"phone": "+70001898408"}
0005432159776	BA7FAF	3952 666242	ARTUR MEDVEDEV	{"email": "a.medvedev_111969@postgrespro.ru", "phone": "+70016882969"}
0005432159777	BA7FAF	6943 929555	OLEG EGOROV	{"email": "oleg_egorov.28111973@postgrespro.ru", "phone": "+70067687011"}
0005432159778	9A8DFE	7852 259435	VLADIMIR KUZMIN	{"phone": "+70331024107"}
0005432159779	7E8E20	2992 464200	LARISA ZHURAVLEVA	{"email": "zhuravleva_larisa-24101976@postgrespro.ru", "phone": "+70690280745"}
0005432159780	7E8E20	4221 836056	IGOR VLASOV	{"email": "i_vlasov_011967@postgrespro.ru", "phone": "+70163954519"}
0005432159781	37EFF1	4257 619422	ALEKSANDR IVANOV	{"phone": "+70892846675"}
0005432159782	37EFF1	0230 806883	NIKOLAY KUZMIN	{"phone": "+70672002436"}
0005432159783	92BFDF	2272 804097	LYUDMILA ABRAMOVA	{"email": "abramova_l04081974@postgrespro.ru", "phone": "+70378238682"}
0005432159784	93C07D	6120 017654	VALERIY GAVRILOV	{"phone": "+70333109339"}
0005432159785	F8BE73	3189 062913	LYUDMILA SMIRNOVA	{"email": "lyudmilasmirnova1970@postgrespro.ru", "phone": "+70727641154"}
0005432159786	65232B	1961 490085	VIKTOR MAKAROV	{"phone": "+70177594458"}
0005432159787	84A11C	2310 758294	ALEKSANDR SMIRNOV	{"phone": "+70004036546"}
0005432159788	7AF130	5201 608643	INNA FEDOROVA	{"email": "fedorova.inna051971@postgrespro.ru", "phone": "+70579386373"}
0005432159789	7AF130	7946 609404	VLADIMIR SERGEEV	{"email": "vsergeev061967@postgrespro.ru", "phone": "+70851865531"}
0005432159790	DF56DC	1824 672568	DMITRIY ROMANOV	{"email": "dmitriy.romanov.01081964@postgrespro.ru", "phone": "+70931523161"}
0005432159791	CDE4DC	1609 255309	ALEKSANDR IVANOV	{"phone": "+70468314427"}
0005432159792	CDE4DC	9693 026073	TATYANA IVANOVA	{"email": "t_ivanova28061986@postgrespro.ru", "phone": "+70039857622"}
0005432159793	9E2AD4	8810 125088	ELENA ROMANOVA	{"phone": "+70220687437"}
0005432159794	1039AF	4850 855013	IGOR SOKOLOV	{"email": "sokolov-igor-101960@postgrespro.ru", "phone": "+70884488616"}
0005432159795	1039AF	7437 158290	ALLA NIKOLAEVA	{"phone": "+70463177992"}
0005432159796	308C47	9111 097726	SERGEY PETROV	{"email": "spetrov051967@postgrespro.ru", "phone": "+70257420611"}
0005432159797	44C445	3096 123927	VIKTOR NAZAROV	{"email": "nazarov_v14111980@postgrespro.ru", "phone": "+70039702105"}
0005432159798	F8212E	9539 346419	ALEKSEY VASILEV	{"phone": "+70285962173"}
0005432159799	97F3D5	0156 594835	LYUBOV BORISOVA	{"phone": "+70473287634"}
0005432159800	433776	7287 304984	TIGRAN KUZNECOV	{"phone": "+70706851889"}
0005432159801	3E6E67	0530 714238	RAFAIL BONDARENKO	{"phone": "+70850123684"}
0005432159802	5A22BD	3356 649461	SERGEY ANDREEV	{"phone": "+70258828271"}
0005432159803	260555	4365 938813	NINA KOVALEVA	{"email": "kovaleva-n_081982@postgrespro.ru", "phone": "+70711904157"}
0005432159804	71E6BA	8657 512848	ANNA SOROKINA	{"email": "a-sorokina-081979@postgrespro.ru", "phone": "+70586936311"}
0005432159805	AA4F1F	1173 412281	VIKTOR KUZNECOV	{"phone": "+70972055124"}
0005432159806	58C42A	4890 913398	OLEG VOLKOV	{"email": "volkov.o_1971@postgrespro.ru", "phone": "+70899626286"}
0005432159807	E97DF2	9645 042748	ILYA SOROKIN	{"email": "ilya.sorokin.11081970@postgrespro.ru", "phone": "+70196584527"}
0005432159808	16DDB1	7377 401857	ZAKHAR STEPANOV	{"email": "stepanov.zakhar_041979@postgrespro.ru", "phone": "+70905240837"}
0005432159809	AA0BFD	6005 454645	LIDIYA KUZMINA	{"email": "lidiya-kuzmina-1979@postgrespro.ru", "phone": "+70434652273"}
0005432159810	AA0BFD	9591 880667	ANASTASIYA KRASNOVA	{"email": "krasnovaanastasiya-1979@postgrespro.ru", "phone": "+70143080086"}
0005432159811	AA0BFD	5690 868633	ALEKSEY RODIONOV	{"email": "arodionov101981@postgrespro.ru", "phone": "+70261484096"}
0005432159812	4302AF	8441 618061	VERA BELOVA	{"phone": "+70654475898"}
0005432159813	D0CB4D	2142 270536	NIKOLAY YAKOVLEV	{"email": "n-yakovlev-03071979@postgrespro.ru", "phone": "+70719968008"}
0005432159814	B1B5C3	1229 926837	ALEKSANDR IVANOV	{"email": "a.ivanov031968@postgrespro.ru", "phone": "+70707635464"}
0005432159815	DAD9C6	7321 132474	VALENTINA MOROZOVA	{"email": "morozova-valentina_1983@postgrespro.ru", "phone": "+70914528733"}
0005432159816	61F349	4715 730872	EVGENIY MOROZOV	{"phone": "+70602574753"}
0005432159817	61F349	9506 467733	STEPAN PETROV	{"email": "petrov_stepan1978@postgrespro.ru", "phone": "+70978996536"}
0005432159818	620316	9171 922224	FEDOR KOROLEV	{"phone": "+70307484997"}
0005432159819	9C4AC7	6510 514841	STANISLAV KONOVALOV	{"email": "stanislavkonovalov.041984@postgrespro.ru", "phone": "+70746365797"}
0005432159820	FBA3D4	4585 829833	MARINA SOKOLOVA	{"phone": "+70861438146"}
0005432159821	1BD7A2	5887 835010	EVGENIY SCHERBAKOV	{"email": "e.scherbakov_29091968@postgrespro.ru", "phone": "+70271589830"}
0005432159877	D1D2F7	2086 868472	SERGEY KOZLOV	{"phone": "+70898304098"}
0005432159822	466FF0	7210 882227	VLADISLAV ALEKSEEV	{"email": "v_alekseev.11061979@postgrespro.ru", "phone": "+70534091237"}
0005432159823	E8B1D4	0881 356677	GEORGIY KUZNECOV	{"phone": "+70763486877"}
0005432159824	9C8EA5	7525 441464	ARTEM MOROZOV	{"phone": "+70858207912"}
0005432159825	4D194C	1126 179531	KONSTANTIN FILIPPOV	{"email": "filippov_konstantin_1964@postgrespro.ru", "phone": "+70600215051"}
0005432159826	02E1DD	1055 927295	VALENTINA VASILEVA	{"email": "vvasileva20051970@postgrespro.ru", "phone": "+70214941036"}
0005432159827	05D9BB	4932 432622	DMITRIY MELNIKOV	{"email": "d-melnikov1963@postgrespro.ru", "phone": "+70312450399"}
0005432159828	05D9BB	5871 877987	ALEKSANDR ORLOV	{"email": "orlov_a.08041975@postgrespro.ru", "phone": "+70772034887"}
0005432159829	11660E	5217 816089	ANNA BELYAEVA	{"phone": "+70390224521"}
0005432159830	11660E	0832 910832	OLGA ANISIMOVA	{"email": "olga-anisimova.091972@postgrespro.ru", "phone": "+70817434625"}
0005432159831	56C388	7803 825002	ELENA KOMAROVA	{"phone": "+70679835181"}
0005432159832	56C388	1621 630263	ANATOLIY TIMOFEEV	{"email": "timofeev-anatoliy081977@postgrespro.ru", "phone": "+70178537164"}
0005432159833	3A5219	2772 464765	MAKSIM MOISEEV	{"phone": "+70295454919"}
0005432159834	F49911	1848 502963	ALEVTINA IVANOVA	{"email": "ivanova-alevtina1967@postgrespro.ru", "phone": "+70969382209"}
0005432159835	F49911	6179 971932	IGOR IVANOV	{"phone": "+70112680358"}
0005432159836	F49911	8742 087304	TATYANA FROLOVA	{"phone": "+70632326801"}
0005432159837	B6DAF2	2359 752349	SANIYA SIDOROVA	{"email": "saniyasidorova-1986@postgrespro.ru", "phone": "+70562447929"}
0005432159838	D17B0E	6535 988374	OLGA VOROBEVA	{"email": "olga_vorobeva.10031969@postgrespro.ru", "phone": "+70825368119"}
0005432159839	16F77A	3735 557021	DENIS ZHURAVLEV	{"phone": "+70328239398"}
0005432159840	16F77A	3850 204311	ALENA YAKOVLEVA	{"phone": "+70813623384"}
0005432159841	7C9B41	1319 602574	NATALYA POLYAKOVA	{"email": "polyakova.natalya.011962@postgrespro.ru", "phone": "+70505069268"}
0005432159842	00CCBC	1429 881421	DARYA IVANOVA	{"phone": "+70366507458"}
0005432159843	19794C	5913 772302	ALEKSEY FOMIN	{"phone": "+70528734418"}
0005432159844	78736E	6073 040317	OLGA VASILEVA	{"phone": "+70442267848"}
0005432159845	84964A	0883 360196	NATALYA MAKSIMOVA	{"email": "maksimova_natalya_1967@postgrespro.ru", "phone": "+70211810084"}
0005432159846	84964A	8037 285759	MARGARITA NAZAROVA	{"email": "nazarovamargarita-25041979@postgrespro.ru", "phone": "+70108166977"}
0005432159847	5AC17B	9953 489653	EVGENIY PAVLOV	{"email": "pavlovevgeniy.10111966@postgrespro.ru", "phone": "+70407627402"}
0005432159848	349177	0454 110260	OLGA KISELEVA	{"email": "olgakiseleva.12031964@postgrespro.ru", "phone": "+70374860136"}
0005432159849	6F82B1	1997 786015	TATYANA LUKYANOVA	{"phone": "+70741216485"}
0005432159850	6F82B1	6533 731479	YURIY ORLOV	{"phone": "+70645029778"}
0005432159851	81D717	2026 113007	ALEKSEY KUZNECOV	{"email": "akuznecov.031967@postgrespro.ru", "phone": "+70118759395"}
0005432159852	81D717	1296 552359	NIKOLAY EGOROV	{"email": "nikolay.egorov16081971@postgrespro.ru", "phone": "+70533771924"}
0005432159853	E6EE23	2413 637168	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_v-011978@postgrespro.ru", "phone": "+70619579609"}
0005432159854	E6EE23	8472 880029	VYACHESLAV MELNIKOV	{"email": "melnikovvyacheslav.1964@postgrespro.ru", "phone": "+70758320740"}
0005432159855	866547	5487 347231	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov_04091969@postgrespro.ru", "phone": "+70103779115"}
0005432159856	866547	6287 785505	EKATERINA SEMENOVA	{"email": "semenova-ekaterina.1981@postgrespro.ru", "phone": "+70932320165"}
0005432159857	6EA69B	1505 269577	KARINA SERGEEVA	{"email": "karina_sergeeva.30061965@postgrespro.ru", "phone": "+70805795734"}
0005432159858	5E3778	1299 421497	DENIS GAVRILOV	{"email": "gavrilovdenis_25051972@postgrespro.ru", "phone": "+70632425992"}
0005432159859	5E3778	6797 460702	ANTON OSIPOV	{"email": "osipov.a-16081969@postgrespro.ru", "phone": "+70393168947"}
0005432159860	A10CDF	4921 882974	VENIAMIN GAVRILOV	{"email": "gavrilov-veniamin-14011968@postgrespro.ru", "phone": "+70756660759"}
0005432159861	A10CDF	2473 150168	ALEKSANDRA POPOVA	{"phone": "+70476636361"}
0005432159862	0CC07E	9097 541649	MAKSIM POPOV	{"phone": "+70037808267"}
0005432159863	CD683F	1776 242542	IRINA NESTEROVA	{"email": "inesterova20071963@postgrespro.ru", "phone": "+70569609061"}
0005432159864	4D3855	3474 616984	PETR KRASNOV	{"phone": "+70736647287"}
0005432159865	4D3855	9866 668362	GALINA ABRAMOVA	{"email": "galina-abramova_17101972@postgrespro.ru", "phone": "+70490905334"}
0005432159866	FA0385	1931 633221	ANNA NIKIFOROVA	{"email": "anna_nikiforova-1974@postgrespro.ru", "phone": "+70321522726"}
0005432159867	2DB569	5173 030470	VALENTINA ZAKHAROVA	{"email": "v_zakharova13031981@postgrespro.ru", "phone": "+70377446814"}
0005432159868	68CF05	9592 099077	NURIYA AFANASEVA	{"phone": "+70202180146"}
0005432159869	8B8823	3677 976755	DMITRIY NIKITIN	{"email": "nikitind.1969@postgrespro.ru", "phone": "+70129034088"}
0005432159870	8B8823	6654 024385	VLADIMIR STEPANOV	{"phone": "+70698110562"}
0005432159871	8B8823	0877 599217	ANNA KUZMINA	{"phone": "+70624340748"}
0005432159872	CCC6CD	6467 009267	ALMIRA KUZNECOVA	{"email": "almirakuznecova01021963@postgrespro.ru", "phone": "+70256603153"}
0005432159873	4E14D2	3870 177584	SERGEY GUSEV	{"email": "sergey-gusev-18111969@postgrespro.ru", "phone": "+70687185129"}
0005432159874	294A05	0601 090159	ANASTASIYA KULIKOVA	{"email": "anastasiyakulikova-021981@postgrespro.ru", "phone": "+70446639728"}
0005432159875	294A05	7048 821523	VERA IVANOVA	{"phone": "+70439734723"}
0005432159876	AD5FC6	2864 104607	ANNA ZAKHAROVA	{"email": "zakharova-a_031973@postgrespro.ru", "phone": "+70449184200"}
0005432159878	D1D2F7	3209 157205	TATYANA IVANOVA	{"email": "ivanova_tatyana-011974@postgrespro.ru", "phone": "+70120824138"}
0005432159879	616A41	2551 356112	OLGA FEDOROVA	{"phone": "+70755044464"}
0005432159880	B29792	1391 203469	OKSANA POLYAKOVA	{"phone": "+70712682970"}
0005432159881	3564F3	0850 430032	NADEZHDA MIRONOVA	{"email": "mironovanadezhda-1966@postgrespro.ru", "phone": "+70915947131"}
0005432159882	3564F3	5116 301770	DMITRIY EGOROV	{"email": "egorovdmitriy-21111975@postgrespro.ru", "phone": "+70037463360"}
0005432159883	3CAA12	4049 107137	ILNUR FEDOROV	{"email": "i.fedorov.101974@postgrespro.ru", "phone": "+70170657436"}
0005432159884	F67CBA	4410 070371	RAFAIL KUZMIN	{"email": "kuzminrafail_08011964@postgrespro.ru", "phone": "+70550433349"}
0005432159885	27D1A1	8340 385494	NINA ANDREEVA	{"phone": "+70986407206"}
0005432159886	0A5512	8185 524521	GENNADIY NIKOLAEV	{"phone": "+70764348359"}
0005432159887	09D8D7	9391 707167	TATYANA TIMOFEEVA	{"phone": "+70832808711"}
0005432159888	CBA4D1	5220 952560	ALINA MAKAROVA	{"email": "makarovaa-091971@postgrespro.ru", "phone": "+70111133108"}
0005432159889	CBA4D1	2614 312292	KLAVDIYA NESTEROVA	{"phone": "+70826396344"}
0005432159890	8EE398	2722 827660	MAKSIM VASILEV	{"email": "vasilevm081968@postgrespro.ru", "phone": "+70471239396"}
0005432159891	016022	4896 947407	IVAN ZAKHAROV	{"email": "i.zakharov.071977@postgrespro.ru", "phone": "+70567336895"}
0005432159892	15F7BE	8225 354278	TATYANA BORISOVA	{"email": "tatyana.borisova.1970@postgrespro.ru", "phone": "+70084459637"}
0005432159893	7F91EC	4778 454464	VALENTINA MOROZOVA	{"phone": "+70963095002"}
0005432159894	F19D88	3960 341927	OLGA RYABOVA	{"email": "ryabovao-13091965@postgrespro.ru", "phone": "+70119311150"}
0005432159895	F19D88	6992 507906	NINA KUZNECOVA	{"email": "nina-kuznecova.1971@postgrespro.ru", "phone": "+70765984605"}
0005432159896	DBA1FA	7486 991754	EVGENIYA TIKHONOVA	{"phone": "+70095877120"}
0005432159897	ECBF56	7956 041314	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov1977@postgrespro.ru", "phone": "+70592368419"}
0005432159898	8C1E19	0209 783265	ELENA FROLOVA	{"email": "elenafrolova-19041962@postgrespro.ru", "phone": "+70620259876"}
0005432159899	343D78	5365 956669	TAISIYA GERASIMOVA	{"email": "t.gerasimova031977@postgrespro.ru", "phone": "+70166827395"}
0005432159900	67C7FB	3277 371015	KONSTANTIN KRASNOV	{"email": "krasnovkonstantin-051985@postgrespro.ru", "phone": "+70357631434"}
0005432159901	52688E	6083 160282	EKATERINA POPOVA	{"email": "popovae-1978@postgrespro.ru", "phone": "+70626544990"}
0005432159902	549945	6077 996427	MARGARITA ZAKHAROVA	{"email": "zakharovam_101973@postgrespro.ru", "phone": "+70664566293"}
0005432159903	F57F7F	0128 265317	ALEKSANDR KAZAKOV	{"email": "a-kazakov.1981@postgrespro.ru", "phone": "+70655491109"}
0005432159904	F57F7F	9914 615382	NADEZHDA BELOVA	{"email": "n.belova.031980@postgrespro.ru", "phone": "+70000990751"}
0005432159905	2FFCDD	1838 230693	ANDREY POPOV	{"phone": "+70525815379"}
0005432159906	2FFCDD	8373 113520	OKSANA TIKHONOVA	{"phone": "+70574038427"}
0005432159907	70573E	3693 141900	ZULFIYA POPOVA	{"phone": "+70796692812"}
0005432159908	A93AE7	5025 563267	YULIYA POPOVA	{"phone": "+70379096622"}
0005432159909	A93AE7	9894 727828	OLGA ZAYCEVA	{"email": "olga_zayceva_031979@postgrespro.ru", "phone": "+70894373417"}
0005432159910	96A1F5	7183 025808	TATYANA KISELEVA	{"email": "kiselevatatyana061980@postgrespro.ru", "phone": "+70563653255"}
0005432159911	96A1F5	1459 888421	TAMARA BORISOVA	{"phone": "+70891778891"}
0005432159912	AFA312	9413 631368	MAKSIM VOLKOV	{"phone": "+70269323912"}
0005432159913	AFA312	6272 663906	VASILISA DANILOVA	{"email": "danilovav-031980@postgrespro.ru", "phone": "+70006652019"}
0005432159914	1AC652	9858 408502	VIKTOR KUZMIN	{"email": "kuzmin-v-051975@postgrespro.ru", "phone": "+70832085804"}
0005432159915	1AC652	6428 351348	DMITRIY IVANOV	{"email": "dmitriyivanov_03011960@postgrespro.ru", "phone": "+70726225574"}
0005432159916	90CAB6	1932 346891	MIKHAIL IVANOV	{"phone": "+70362804960"}
0005432159917	5AE95A	6461 171451	DARYA ROMANOVA	{"email": "romanova.darya.30091962@postgrespro.ru", "phone": "+70666231708"}
0005432159918	114E38	2965 714819	ELENA EGOROVA	{"phone": "+70054173226"}
0005432159919	DDF8E0	4726 192239	NINA GORBUNOVA	{"email": "n.gorbunova-1971@postgrespro.ru", "phone": "+70822288938"}
0005432159920	DDF8E0	4198 369503	GENNADIY MOROZOV	{"phone": "+70173671975"}
0005432159921	534F55	2105 691762	EVGENIY VLASOV	{"phone": "+70558211335"}
0005432159922	E0F6BD	5743 101507	DANIIL VOLKOV	{"phone": "+70002727996"}
0005432159923	108FBD	0269 645770	EVGENIY BORISOV	{"email": "borisov-e_061968@postgrespro.ru", "phone": "+70227114871"}
0005432159924	BDC3B8	7595 070306	OLGA SOLOVEVA	{"phone": "+70544792688"}
0005432159925	BDC3B8	6200 466433	TIMOFEY MATVEEV	{"email": "matveev-timofey05021966@postgrespro.ru", "phone": "+70946540501"}
0005432159926	BDC3B8	1517 906732	EKATERINA SOKOLOVA	{"email": "sokolova_ekaterina.071974@postgrespro.ru", "phone": "+70651189698"}
0005432159927	9727DB	3232 387803	SERGEY SMIRNOV	{"email": "sergeysmirnov-26021959@postgrespro.ru", "phone": "+70768311128"}
0005432159928	E36D65	9998 339792	ANDREY PETROV	{"email": "petrov-andrey_25081982@postgrespro.ru", "phone": "+70182119549"}
0005432159929	E36D65	8443 454545	ELIZAVETA FILIPPOVA	{"phone": "+70154958763"}
0005432159930	1D3ED2	3280 702332	EKATERINA VOLKOVA	{"email": "e_volkova-091960@postgrespro.ru", "phone": "+70820698558"}
0005432159931	BE8CBB	0128 840564	VIKTORIYA AFANASEVA	{"email": "afanaseva-viktoriya-071978@postgrespro.ru", "phone": "+70517125819"}
0005432159932	BE8CBB	3816 997311	SERGEY KULIKOV	{"phone": "+70666358435"}
0005432159933	C837CA	4260 783425	OKSANA LAZAREVA	{"phone": "+70705655636"}
0005432159934	C60356	1362 753593	VALENTINA LUKYANOVA	{"phone": "+70372323586"}
0005432159935	C60356	5940 065088	EKATERINA KUZNECOVA	{"email": "e_kuznecova_11041979@postgrespro.ru", "phone": "+70681541601"}
0005432159936	CA6324	8242 900065	TAMARA ARKHIPOVA	{"phone": "+70767695313"}
0005432159937	FA1932	5918 722661	VALENTIN IVANOV	{"phone": "+70652637371"}
0005432159938	569C16	8768 299972	EKATERINA KISELEVA	{"phone": "+70981764936"}
0005432159939	7D756C	2419 337550	ELENA NESTEROVA	{"phone": "+70300706770"}
0005432159940	7A458F	8547 616024	ILYA NIKOLAEV	{"phone": "+70116263384"}
0005432159941	7A458F	6902 134750	ZULFIYA TARASOVA	{"email": "zulfiya_tarasova_091971@postgrespro.ru", "phone": "+70839602866"}
0005432159942	9C70F7	7213 897276	OLGA SOKOLOVA	{"email": "sokolovaolga-1967@postgrespro.ru", "phone": "+70275924567"}
0005432159943	54372C	5304 788360	ALEKSANDR DMITRIEV	{"email": "admitriev27041979@postgrespro.ru", "phone": "+70756297301"}
0005432159944	26CF6A	1746 824912	ANATOLIY GUSEV	{"phone": "+70371186510"}
0005432159945	EAF7D1	4898 543884	SERGEY NOVIKOV	{"phone": "+70146301271"}
0005432159946	EAF7D1	5143 750214	IRINA EFIMOVA	{"email": "efimovairina.08101975@postgrespro.ru", "phone": "+70960204518"}
0005432159947	ABABB6	5615 103465	ANASTASIYA ILINA	{"phone": "+70514807957"}
0005432159948	F2B5DB	8698 507347	DMITRIY EGOROV	{"email": "egorov.dmitriy-121970@postgrespro.ru", "phone": "+70337215115"}
0005432159949	EEABB3	7831 768899	OLEG KOROLEV	{"email": "korolevo_081959@postgrespro.ru", "phone": "+70705784147"}
0005432159950	B9EAC6	5690 629037	MIKHAIL SCHERBAKOV	{"phone": "+70223069045"}
0005432159951	5CA063	7289 349284	GALINA KONDRATEVA	{"email": "gkondrateva_23101989@postgrespro.ru", "phone": "+70777968428"}
0005432159952	0372E1	2527 391554	VIKTOR PAVLOV	{"email": "pavlovv14091961@postgrespro.ru", "phone": "+70320063997"}
0005432159953	0372E1	9601 005971	LYUBOV KOLESNIKOVA	{"phone": "+70271159246"}
0005432159954	D6318B	4623 219226	MAKSIM GORBUNOV	{"email": "mgorbunov_031969@postgrespro.ru", "phone": "+70619485960"}
0005432159955	FA0491	4327 155109	EVGENIY POPOV	{"email": "e-popov-28021980@postgrespro.ru", "phone": "+70894646252"}
0005432159956	9B1750	3939 692451	ILYA NAZAROV	{"phone": "+70238165231"}
0005432159957	B961B4	5414 495649	EVGENIY IVANOV	{"email": "e_ivanov.121976@postgrespro.ru", "phone": "+70594267597"}
0005432159958	96102D	5237 145714	KSENIYA ORLOVA	{"phone": "+70326220559"}
0005432159959	75C94F	2796 718602	ANTON KUZMIN	{"phone": "+70291529153"}
0005432159960	8DBB98	4402 257751	ALEKSEY ZAYCEV	{"phone": "+70512280710"}
0005432159961	8DBB98	8648 123298	INNA KUZMINA	{"email": "kuzminainna1973@postgrespro.ru", "phone": "+70106093695"}
0005432159962	B9074B	2101 687008	SERGEY KUZMIN	{"email": "kuzmin-s_021980@postgrespro.ru", "phone": "+70453947950"}
0005432159963	BBC75A	4882 695216	IGOR DENISOV	{"email": "igor.denisov04031966@postgrespro.ru", "phone": "+70711476283"}
0005432159964	7587CD	4914 037139	MARIYA AKIMOVA	{"email": "akimova-m.03081979@postgrespro.ru", "phone": "+70820541710"}
0005432159965	CBB4E9	1360 870035	VLADIMIR IVANOV	{"phone": "+70385169512"}
0005432159966	E21355	8048 326501	NATALIYA CHERNOVA	{"phone": "+70199960123"}
0005432159967	E21355	6956 123319	ANATOLIY SAVELEV	{"phone": "+70387196429"}
0005432159968	8B6CBC	6633 464062	TATYANA NAUMOVA	{"email": "tnaumova051969@postgrespro.ru", "phone": "+70323802310"}
0005432159969	4AD125	6021 148661	VLADIMIR NAZAROV	{"email": "nazarov_vladimir-07021971@postgrespro.ru", "phone": "+70507040404"}
0005432159970	4AD125	9256 809154	SERGEY ALEKSEEV	{"email": "alekseev_s-081974@postgrespro.ru", "phone": "+70141576783"}
0005432159971	935157	1011 786327	NIKITA DMITRIEV	{"email": "dmitriev.nikita.041974@postgrespro.ru", "phone": "+70187129456"}
0005432159972	EDBA78	4924 085588	TIMUR FILIPPOV	{"phone": "+70152006454"}
0005432159973	EDBA78	0032 850485	VYACHESLAV EGOROV	{"email": "egorov.v_1965@postgrespro.ru", "phone": "+70450435798"}
0005432159974	EDBA78	0850 004930	IRINA KALININA	{"email": "kalinina_irina041968@postgrespro.ru", "phone": "+70672752612"}
0005432159975	36F6A4	3414 904346	GALINA ORLOVA	{"email": "g.orlova.19011976@postgrespro.ru", "phone": "+70900942589"}
0005432159976	7085FA	1126 288329	VIKTORIYA ZAKHAROVA	{"email": "zakharovaviktoriya051978@postgrespro.ru", "phone": "+70208816447"}
0005432159977	639201	5860 498733	DANIIL SOKOLOV	{"phone": "+70150039929"}
0005432159978	B7FC98	8279 900539	IVAN STEPANOV	{"phone": "+70724736523"}
0005432159979	A18BD1	9661 837294	VLADIMIR DMITRIEV	{"email": "dmitrievv_1969@postgrespro.ru", "phone": "+70453257431"}
0005432159980	1B186A	4189 377002	IGOR KAZAKOV	{"phone": "+70848539081"}
0005432159981	806EC5	1087 006698	ALEKSANDR KUDRYASHOV	{"phone": "+70435636601"}
0005432159982	806EC5	1301 306891	YURIY MAKSIMOV	{"phone": "+70063027502"}
0005432159983	3FCDF3	2568 588468	VITALIY SOROKIN	{"phone": "+70693350584"}
0005432159984	3FCDF3	1610 416885	SVETLANA MIRONOVA	{"email": "mironova_s_051970@postgrespro.ru", "phone": "+70941635366"}
0005432159985	7988D8	1614 387920	NIKOLAY KUZNECOV	{"phone": "+70765161673"}
0005432159986	7988D8	8186 870643	ELENA STEPANOVA	{"email": "stepanova.elena041964@postgrespro.ru", "phone": "+70426172094"}
0005432159987	37C2DC	7994 241501	EVGENIY AFANASEV	{"phone": "+70671930138"}
0005432159988	7575CF	4756 200423	ELENA KULIKOVA	{"email": "e-kulikova-1971@postgrespro.ru", "phone": "+70115650114"}
0005432159989	7575CF	4428 507497	ELENA SMIRNOVA	{"phone": "+70558526885"}
0005432159990	7575CF	4328 809007	YURIY YAKOVLEV	{"phone": "+70432080575"}
0005432159991	7575CF	4089 243205	NATALIYA ILINA	{"email": "ilina.nataliya-061979@postgrespro.ru", "phone": "+70752625959"}
0005432159992	14F2B6	0083 219612	SERGEY ALEKSEEV	{"email": "sergey-alekseev_011975@postgrespro.ru", "phone": "+70794168432"}
0005432161110	0680F1	6339 107392	NIKOLAY ANDREEV	{"phone": "+70882899733"}
0005432161111	F4A3B9	8199 537513	SERGEY BORISOV	{"email": "s.borisov_01051970@postgrespro.ru", "phone": "+70324114737"}
0005432161112	1A84CE	7954 958456	NATALYA PETROVA	{"email": "n-petrova.031978@postgrespro.ru", "phone": "+70665283689"}
0005432161113	1A84CE	2253 794957	DMITRIY IVANOV	{"email": "ivanov_dmitriy_06121970@postgrespro.ru", "phone": "+70317124344"}
0005432161114	F8CD21	3301 872606	VLADIMIR ANDREEV	{"phone": "+70471222785"}
0005432161115	268AA4	4173 034910	EVGENIY MOROZOV	{"email": "morozove_121974@postgrespro.ru", "phone": "+70808686021"}
0005432161116	DA75BF	7925 255297	MAKSIM AFANASEV	{"email": "afanasev_m_23101982@postgrespro.ru", "phone": "+70639880583"}
0005432161117	8C71F1	0618 812403	IGOR SAVELEV	{"email": "igor_savelev.1966@postgrespro.ru", "phone": "+70391266250"}
0005432161118	8C71F1	3900 397491	FAINA KULIKOVA	{"phone": "+70606685476"}
0005432161119	043E17	8293 620543	VASILIY SIDOROV	{"email": "vasiliy-sidorov1970@postgrespro.ru", "phone": "+70429553102"}
0005432161120	EFF06A	4077 245562	ANATOLIY DAVYDOV	{"email": "davydovanatoliy_17061970@postgrespro.ru", "phone": "+70847706612"}
0005432161121	82B5A1	8789 122339	YURIY KUZNECOV	{"phone": "+70299168318"}
0005432161122	82B5A1	4459 418748	YULIYA LAZAREVA	{"phone": "+70622023793"}
0005432161123	82B5A1	1434 507367	LARISA TARASOVA	{"phone": "+70733021886"}
0005432161124	187DB4	6147 763259	ALEKSEY MOROZOV	{"phone": "+70889904092"}
0005432161125	187DB4	6510 680745	ANDREY ZAKHAROV	{"phone": "+70411749840"}
0005432161126	57CDEB	2488 983811	KSENIYA ABRAMOVA	{"email": "k-abramova.1971@postgrespro.ru", "phone": "+70774814984"}
0005432161127	57CDEB	6274 820400	DIANA SOLOVEVA	{"phone": "+70824667955"}
0005432161128	384776	1081 030467	OLESYA POPOVA	{"email": "popovao.071963@postgrespro.ru", "phone": "+70769884285"}
0005432161129	EE67EB	6215 216786	ANASTASIYA CHERNOVA	{"phone": "+70765075687"}
0005432161130	BC4EDF	0967 339002	EKATERINA PAVLOVA	{"email": "pavlova_ekaterina13031962@postgrespro.ru", "phone": "+70119498884"}
0005432161131	BC4EDF	0832 183789	YULIYA DMITRIEVA	{"phone": "+70968831441"}
0005432161132	6B14D0	1759 978988	MIKHAIL ALEKSANDROV	{"phone": "+70633847414"}
0005432161133	6B14D0	1500 579649	LIDIYA LEBEDEVA	{"phone": "+70718815890"}
0005432161134	6ACBA1	2272 269141	YURIY SOLOVEV	{"email": "solovev-y-02061977@postgrespro.ru", "phone": "+70795698674"}
0005432161135	47043F	2127 710444	NATALYA PETROVA	{"phone": "+70492766486"}
0005432161136	E4ED68	7416 857989	DANIIL KONOVALOV	{"phone": "+70810198936"}
0005432161137	078DE0	0616 322747	OLGA BELOVA	{"email": "belova.o.25011969@postgrespro.ru", "phone": "+70887767008"}
0005432161138	078DE0	1982 547639	ANTON IVANOV	{"phone": "+70807282566"}
0005432161139	078DE0	3053 756257	ILYA AFANASEV	{"email": "afanasevi.1968@postgrespro.ru", "phone": "+70675063253"}
0005432161140	31F6F2	2015 891291	RUSLAN ILIN	{"email": "ilin.ruslan.1970@postgrespro.ru", "phone": "+70942824356"}
0005432161141	31F6F2	5224 136225	SERGEY MARTYNOV	{"email": "smartynov24101968@postgrespro.ru", "phone": "+70835307556"}
0005432161142	0E7BAE	5822 071509	ANDREY MAKSIMOV	{"phone": "+70865358686"}
0005432161143	0E7BAE	4307 987313	EVGENIYA ALEKSEEVA	{"email": "alekseevae041967@postgrespro.ru", "phone": "+70371975676"}
0005432161144	2F9CE1	9763 348651	VLADIMIR EGOROV	{"phone": "+70806924641"}
0005432161145	C91937	5315 377265	SERGEY GORBUNOV	{"email": "gorbunov.sergey_02121977@postgrespro.ru", "phone": "+70248819033"}
0005432161146	B20A3B	5949 603042	VIKTOR EGOROV	{"email": "vegorov031965@postgrespro.ru", "phone": "+70814435314"}
0005432161147	FCDA40	0220 670793	VALENTIN STEPANOV	{"email": "v-stepanov-061976@postgrespro.ru", "phone": "+70596386518"}
0005432161148	FCDA40	0336 578079	LYUBOV SOROKINA	{"email": "sorokina-l.011978@postgrespro.ru", "phone": "+70981712582"}
0005432161149	D520DD	4444 501373	ALEKSANDR PAVLOV	{"phone": "+70475193280"}
0005432161150	D520DD	8708 596692	MARIYA KOZLOVA	{"phone": "+70409456605"}
0005432161151	B7AA40	0233 603199	EKATERINA GRISHINA	{"email": "grishina_ekaterina.061985@postgrespro.ru", "phone": "+70247780964"}
0005432161152	35EE8C	5549 578684	MARIYA ISAEVA	{"email": "isaeva_mariya_091964@postgrespro.ru", "phone": "+70448328385"}
0005432161153	5549BC	9541 342760	ALINA NESTEROVA	{"email": "a.nesterova_15051972@postgrespro.ru", "phone": "+70313825972"}
0005432161154	C84C4C	5782 711062	VLADIMIR NIKOLAEV	{"phone": "+70152348283"}
0005432161155	C12BF4	8607 514276	ALEKSANDR ALEKSEEV	{"phone": "+70131379977"}
0005432161156	740316	9891 622104	IRINA POTAPOVA	{"email": "potapova_i.1973@postgrespro.ru", "phone": "+70838150445"}
0005432161157	740316	1594 390140	NINA LAZAREVA	{"phone": "+70844644368"}
0005432161158	68C388	4630 908863	YULIYA FILIPPOVA	{"email": "filippova-y.061981@postgrespro.ru", "phone": "+70610955791"}
0005432161159	68C388	4813 359810	TAMARA MELNIKOVA	{"phone": "+70894133758"}
0005432161160	106040	8495 050197	OLGA SOKOLOVA	{"email": "o_sokolova-061973@postgrespro.ru", "phone": "+70931357313"}
0005432161161	CE5787	6119 895162	TATYANA PETROVA	{"email": "t.petrova_11101969@postgrespro.ru", "phone": "+70671333079"}
0005432161162	CE5787	3106 802861	VARVARA NESTEROVA	{"phone": "+70959975483"}
0005432161163	DCD10D	8354 118227	PAVEL VASILEV	{"phone": "+70215889561"}
0005432161164	DCD10D	9390 900992	ALEKSANDR AFANASEV	{"phone": "+70560908440"}
0005432161165	8DEAC2	2223 308332	TATYANA VOROBEVA	{"phone": "+70200421048"}
0005432161166	8DEAC2	5148 880983	ANNA KULIKOVA	{"phone": "+70613662612"}
0005432161167	3000DC	0754 889352	PETR IVANOV	{"email": "pivanov.04071987@postgrespro.ru", "phone": "+70957160194"}
0005432161168	3000DC	6114 701584	VYACHESLAV YAKOVLEV	{"phone": "+70679808700"}
0005432161169	9A9ED4	2396 938231	VIKTOR GERASIMOV	{"phone": "+70217680470"}
0005432161170	599B19	7401 544555	DENIS ZAKHAROV	{"phone": "+70669455846"}
0005432161171	599B19	9100 160893	LIDIYA PETROVA	{"email": "lidiya_petrova05081983@postgrespro.ru", "phone": "+70848191677"}
0005432161172	D46B63	0091 945263	VLADIMIR NIKOLAEV	{"email": "vladimir-nikolaev011978@postgrespro.ru", "phone": "+70125146538"}
0005432161173	D46B63	3335 130098	VLADIMIR MATVEEV	{"phone": "+70436488492"}
0005432161174	3D2D81	6251 160208	VERA MAKAROVA	{"phone": "+70401198441"}
0005432161175	94CE0E	1038 421607	LIDIYA FILATOVA	{"phone": "+70870417724"}
0005432161176	94CE0E	6462 069155	YAN IVANOV	{"email": "yan.ivanov_101975@postgrespro.ru", "phone": "+70734570209"}
0005432161177	067295	7444 612627	KRISTINA CHERNOVA	{"email": "kchernova081973@postgrespro.ru", "phone": "+70422806937"}
0005432161178	067295	8635 811448	NADEZHDA TIKHONOVA	{"phone": "+70161717462"}
0005432161179	C36C25	9654 241394	VERONIKA SIDOROVA	{"email": "veronika-sidorova_1983@postgrespro.ru", "phone": "+70065935460"}
0005432161180	A2213C	5082 841903	DENIS ZHURAVLEV	{"phone": "+70671285047"}
0005432161181	33CA20	3581 981763	VLADIMIR PAVLOV	{"phone": "+70972289049"}
0005432161182	522EF1	9504 649822	SERGEY GORBUNOV	{"phone": "+70634146989"}
0005432161183	42A065	6479 487087	ALEKSANDR SIDOROV	{"phone": "+70976659962"}
0005432161184	DBAAB9	4090 691787	ALEKSANDR MATVEEV	{"email": "a-matveev.10021975@postgrespro.ru", "phone": "+70339262855"}
0005432161185	A66EB5	1648 442090	ILYA POPOV	{"phone": "+70584167613"}
0005432161186	AE5CA7	3098 097691	MARINA PETROVA	{"phone": "+70585448472"}
0005432161187	BA8BB5	7236 280996	ELENA FILATOVA	{"email": "filatova_elena-091967@postgrespro.ru", "phone": "+70326148179"}
0005432161188	BA8BB5	5399 609664	LYUDMILA POLYAKOVA	{"phone": "+70532317268"}
0005432161189	AE7C4C	7213 022785	VALENTINA VLASOVA	{"phone": "+70602477568"}
0005432161190	DC15E1	1519 474413	ANDREY FROLOV	{"email": "a_frolov_061979@postgrespro.ru", "phone": "+70997665813"}
0005432161191	D2D5AC	3962 614426	RAISA FEDOROVA	{"phone": "+70323089483"}
0005432161192	493BAC	7483 917309	VLADIMIR MATVEEV	{"phone": "+70285522880"}
0005432161193	6A9485	9181 280665	YULIYA POPOVA	{"email": "popova.y-24081983@postgrespro.ru", "phone": "+70879008839"}
0005432161194	6A9485	8473 271893	NATALYA TARASOVA	{"email": "natalya-tarasova_011974@postgrespro.ru", "phone": "+70334204406"}
0005432161195	610585	4844 112589	YURIY GERASIMOV	{"email": "gerasimov.y-061979@postgrespro.ru", "phone": "+70563925715"}
0005432161196	610585	5534 642795	NATALYA MEDVEDEVA	{"phone": "+70436620075"}
0005432161197	76BA0D	0420 416715	MARIYA KUZMINA	{"email": "m.kuzmina04091975@postgrespro.ru", "phone": "+70751290888"}
0005432161198	76BA0D	5937 190868	VITALIY STEPANOV	{"email": "stepanov-vitaliy_1969@postgrespro.ru", "phone": "+70175382433"}
0005432161199	7728BC	2539 428114	VLADISLAV ZHURAVLEV	{"email": "zhuravlev-v-1969@postgrespro.ru", "phone": "+70389264102"}
0005432161200	9A6315	4561 779197	MAKSIM POPOV	{"email": "popov.m_111975@postgrespro.ru", "phone": "+70185361617"}
0005432161201	C99D53	6249 001716	PAVEL MOROZOV	{"phone": "+70746724458"}
0005432161202	23C0B2	0571 313409	ROMAN MOROZOV	{"email": "morozov_roman-17071977@postgrespro.ru", "phone": "+70397144039"}
0005432161203	E98B67	5710 629720	ANASTASIYA MEDVEDEVA	{"phone": "+70930399321"}
0005432161204	E98B67	5117 361264	OLEG AFANASEV	{"email": "afanasev.oleg1967@postgrespro.ru", "phone": "+70641185686"}
0005432161205	99F5F6	8529 821156	ANDREY FOMIN	{"email": "fomin-a.031969@postgrespro.ru", "phone": "+70419240764"}
0005432161206	B56F4D	4148 371171	ALEKSANDR MAKSIMOV	{"email": "maksimov_a_06101975@postgrespro.ru", "phone": "+70856067414"}
0005432161207	5D2A30	8741 490870	ELENA RYABOVA	{"email": "ryabova.elena_061977@postgrespro.ru", "phone": "+70147518550"}
0005432161208	9ABA0E	8759 573460	SERGEY SOROKIN	{"phone": "+70602614155"}
0005432161209	3C69D8	7276 558247	IGOR ORLOV	{"email": "i-orlov.1979@postgrespro.ru", "phone": "+70330284131"}
0005432161210	3C69D8	5637 440213	OLESYA KUZMINA	{"phone": "+70931100672"}
0005432161211	2EC31B	0882 680204	NATALYA VOLKOVA	{"phone": "+70584959100"}
0005432161212	EA5625	2918 124740	ALLA FROLOVA	{"phone": "+70842936655"}
0005432161213	EA5625	7904 301400	ELIZAVETA SAVELEVA	{"email": "saveleva.e101972@postgrespro.ru", "phone": "+70587395298"}
0005432161214	BE8024	1312 454074	ALEKSEY BARANOV	{"phone": "+70260743063"}
0005432161215	BE8024	8369 302970	POLINA GORBUNOVA	{"email": "p.gorbunova.061975@postgrespro.ru", "phone": "+70826049613"}
0005432161216	0E916C	9370 815930	MIKHAIL IVANOV	{"phone": "+70953075108"}
0005432161217	0E916C	5283 761162	OLGA BORISOVA	{"email": "olgaborisova.1974@postgrespro.ru", "phone": "+70152551536"}
0005432161218	816105	2445 465163	ANDREY KRASNOV	{"email": "andrey.krasnov.04021975@postgrespro.ru", "phone": "+70649029855"}
0005432164955	8B1B73	3082 215735	VLADIMIR IVANOV	{"email": "ivanov.v_12061971@postgrespro.ru", "phone": "+70977804663"}
0005432164901	0F83DC	7609 112614	ALEKSEY ANDREEV	{"email": "aandreev051973@postgrespro.ru", "phone": "+70856798448"}
0005432164902	0F83DC	0001 044587	SERGEY EGOROV	{"email": "egorov.sergey_08091965@postgrespro.ru", "phone": "+70552679582"}
0005432164903	C575C0	9679 090469	VALERIY GORBUNOV	{"email": "gorbunov_valeriy.1957@postgrespro.ru", "phone": "+70322412034"}
0005432164904	198946	0406 558436	RINAT KOZLOV	{"email": "rinat.kozlov-1983@postgrespro.ru", "phone": "+70556148911"}
0005432164905	838A28	6941 925211	ALEKSANDR NAZAROV	{"phone": "+70953110245"}
0005432164906	81372C	4236 733986	DARYA MIRONOVA	{"phone": "+70973316896"}
0005432164907	E5ED2A	7011 958115	OKSANA PAVLOVA	{"email": "o-pavlova_1970@postgrespro.ru", "phone": "+70666417681"}
0005432164908	6AE02E	4989 295692	NELLI RODIONOVA	{"email": "nellirodionova-1968@postgrespro.ru", "phone": "+70803470009"}
0005432164909	303981	8445 779825	RAISA MAKAROVA	{"email": "raisa-makarova_1975@postgrespro.ru", "phone": "+70799005707"}
0005432164910	A48B05	5069 294417	ALEKSANDR KOROLEV	{"email": "korolev.a_021969@postgrespro.ru", "phone": "+70797675446"}
0005432164911	DE19F5	4253 038173	NINA MIKHAYLOVA	{"phone": "+70332988991"}
0005432164912	DE19F5	7765 269194	DMITRIY PAVLOV	{"email": "d_pavlov-1976@postgrespro.ru", "phone": "+70101487729"}
0005432164913	AD33A1	9392 161055	SVETLANA BELYAEVA	{"email": "svetlana_belyaeva_1982@postgrespro.ru", "phone": "+70722761501"}
0005432164914	A02665	0228 341777	YURIY MAKAROV	{"phone": "+70565989916"}
0005432164915	A02665	2777 971358	DARYA CHERNOVA	{"email": "darya-chernova.021962@postgrespro.ru", "phone": "+70887419024"}
0005432164916	F5B270	3132 650506	NIKOLAY ZAKHAROV	{"email": "zakharov-nikolay041979@postgrespro.ru", "phone": "+70774072804"}
0005432164917	FD885B	5478 885345	IVAN ROMANOV	{"phone": "+70416934917"}
0005432164918	33AC2D	3004 668977	ALEKSANDR STEPANOV	{"email": "stepanova_06031965@postgrespro.ru", "phone": "+70844597355"}
0005432164919	A50D41	8880 774370	NIKITA SAVELEV	{"phone": "+70090467997"}
0005432164920	58451F	5914 935220	ZARINA OVCHINNIKOVA	{"email": "z-ovchinnikova.10011969@postgrespro.ru", "phone": "+70404708869"}
0005432164921	03FD0B	9149 001108	YULIANA POPOVA	{"phone": "+70325673943"}
0005432164922	D285CF	0661 433269	ALEKSANDR MAKAROV	{"email": "makarova-28031971@postgrespro.ru", "phone": "+70274622260"}
0005432164923	D285CF	7389 434347	DENIS SOROKIN	{"email": "sorokind_11031964@postgrespro.ru", "phone": "+70003757309"}
0005432164924	4133DF	1440 803561	EVGENIY SMIRNOV	{"email": "smirnov_e1962@postgrespro.ru", "phone": "+70738104172"}
0005432164925	4133DF	5652 883985	ANATOLIY FOMIN	{"email": "anatoliy_fomin1978@postgrespro.ru", "phone": "+70144073925"}
0005432164926	6BEEF0	7676 204525	EKATERINA KUZNECOVA	{"phone": "+70966278054"}
0005432164927	D20C9E	5421 934625	ANATOLIY VLASOV	{"email": "vlasov-a-101971@postgrespro.ru", "phone": "+70740402511"}
0005432164928	03394D	0163 948575	ALEKSANDR ZAYCEV	{"email": "zaycev-a_1967@postgrespro.ru", "phone": "+70981147346"}
0005432164929	59E9A5	3809 049387	ALEKSEY NAZAROV	{"phone": "+70862443880"}
0005432164930	772F54	4619 136902	OLEG ANDREEV	{"phone": "+70376760558"}
0005432164931	772F54	5455 216125	OLGA SERGEEVA	{"phone": "+70781107758"}
0005432164932	3B510A	9534 816338	SVETLANA PETROVA	{"email": "petrova-s-1977@postgrespro.ru", "phone": "+70620739201"}
0005432164933	4EFAA1	1859 925644	NADEZHDA KOROLEVA	{"phone": "+70275089306"}
0005432164934	DAD21F	4109 455332	ALEKSANDR VOLKOV	{"phone": "+70553504625"}
0005432164935	7B2F67	2844 771388	MIKHAIL CHERNOV	{"phone": "+70597232606"}
0005432164936	680C96	0367 824308	NATALYA NAZAROVA	{"email": "nazarova-natalya-1964@postgrespro.ru", "phone": "+70630803866"}
0005432164937	BA0B1C	5304 739454	IVAN ORLOV	{"phone": "+70252059537"}
0005432164938	AAA781	3834 184840	ALEKSANDR ROMANOV	{"phone": "+70652199144"}
0005432164939	84F002	3965 897084	YURIY NOVIKOV	{"phone": "+70809470620"}
0005432164940	9FF634	9637 369668	NIKOLAY SEMENOV	{"email": "semenov_nikolay.041976@postgrespro.ru", "phone": "+70838991016"}
0005432164941	65343B	3920 320997	DMITRIY ISAEV	{"phone": "+70630833855"}
0005432164942	65343B	3627 390766	OLEG FEDOTOV	{"phone": "+70641330255"}
0005432164943	A3DD40	2230 973730	DANILA NIKITIN	{"phone": "+70318447330"}
0005432164944	A3DD40	9128 721531	LYUDMILA EGOROVA	{"email": "egorova.l_061983@postgrespro.ru", "phone": "+70322016437"}
0005432164945	A3DD40	2295 588544	ZULFIYA IVANOVA	{"email": "ivanovazulfiya-1968@postgrespro.ru", "phone": "+70911521675"}
0005432164946	4351DD	6003 825784	ANASTASIYA KULIKOVA	{"phone": "+70917429467"}
0005432164947	A66283	8670 282886	NATALYA ALEKSANDROVA	{"phone": "+70144391927"}
0005432164948	A66283	6870 940586	STANISLAV KOZLOV	{"phone": "+70859255095"}
0005432164949	FBE18A	3515 812246	NIKOLAY NIKITIN	{"email": "n_nikitin14111968@postgrespro.ru", "phone": "+70215570163"}
0005432164950	0FED0F	5698 238549	NATALYA KISELEVA	{"phone": "+70616666908"}
0005432164951	6D8DC8	2336 479449	GLEB SOLOVEV	{"email": "gleb_solovev.04081968@postgrespro.ru", "phone": "+70666047746"}
0005432164952	6D8DC8	0454 288973	OLGA KUZNECOVA	{"email": "o.kuznecova.1983@postgrespro.ru", "phone": "+70147962462"}
0005432164953	3FF2F2	9923 513271	SVETLANA VOROBEVA	{"phone": "+70273806494"}
0005432164954	A441B4	5589 493875	TIMOFEY NOVIKOV	{"email": "novikovt-14071965@postgrespro.ru", "phone": "+70052358177"}
0005432164956	628333	2124 472324	TAMARA IVANOVA	{"email": "ivanova_tamara-091977@postgrespro.ru", "phone": "+70913421079"}
0005432164957	CE553D	2336 801538	VITALIY NAZAROV	{"email": "v.nazarov01031968@postgrespro.ru", "phone": "+70492076690"}
0005432164958	CE553D	9688 304073	VERA NOVIKOVA	{"email": "novikovavera.091975@postgrespro.ru", "phone": "+70092048408"}
0005432164959	4E2F5D	1209 208184	VLADIMIR POPOV	{"email": "vladimir_popov_021968@postgrespro.ru", "phone": "+70972379134"}
0005432164960	36B2D7	8867 475988	SERGEY SMIRNOV	{"phone": "+70509290968"}
0005432164961	30F44E	2400 192802	VITALIY SERGEEV	{"phone": "+70674456699"}
0005432164962	93CF5D	3122 004439	TAMARA KONOVALOVA	{"email": "t_konovalova-04101968@postgrespro.ru", "phone": "+70468186257"}
0005432164963	2F3828	9973 575380	OKSANA KUZMINA	{"phone": "+70728048777"}
0005432164964	9F115D	6069 098649	NATALYA MAKSIMOVA	{"phone": "+70679505876"}
0005432164965	9F115D	8811 861826	IGOR MEDVEDEV	{"phone": "+70299973984"}
0005432164966	AB2F93	6571 431883	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey.1970@postgrespro.ru", "phone": "+70398356522"}
0005432164967	AB2F93	2278 818218	VALERIY KUZNECOV	{"phone": "+70244090067"}
0005432164968	D68079	3327 675603	DENIS IVANOV	{"phone": "+70083784385"}
0005432164969	9B7A41	4169 635227	ARINA TARASOVA	{"email": "arinatarasova_1977@postgrespro.ru", "phone": "+70449756855"}
0005432164970	0E897C	0634 839828	PAVEL PAVLOV	{"phone": "+70860162247"}
0005432164971	0EC317	6588 352729	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov_13121964@postgrespro.ru", "phone": "+70847109714"}
0005432164972	A02D9F	8583 124639	SVETLANA GORBUNOVA	{"email": "sgorbunova_041975@postgrespro.ru", "phone": "+70372589939"}
0005432164973	A02D9F	5399 245344	MIKHAIL ZAKHAROV	{"email": "mikhailzakharov.041978@postgrespro.ru", "phone": "+70582820915"}
0005432164974	0B8122	0223 343228	GALINA ANDREEVA	{"phone": "+70480017170"}
0005432164975	E9452E	9070 939269	KLAVDIYA MOROZOVA	{"email": "morozovaklavdiya.021966@postgrespro.ru", "phone": "+70937849206"}
0005432164976	F237B0	5141 542504	EVGENIY BELOV	{"phone": "+70487141256"}
0005432164977	F237B0	3789 578985	VERA KISELEVA	{"phone": "+70468656834"}
0005432164978	E9CA0D	0346 755073	TATYANA ANDREEVA	{"phone": "+70984966160"}
0005432164979	6F5EF1	2577 460760	SERGEY IVANOV	{"email": "sergey.ivanov_1984@postgrespro.ru", "phone": "+70432249164"}
0005432164980	B61754	1864 107346	KLAVDIYA MARTYNOVA	{"phone": "+70345861660"}
0005432164981	4AB369	6148 622091	LIDIYA NAUMOVA	{"phone": "+70734887692"}
0005432164982	21AA7F	3476 195295	SERGEY SIDOROV	{"email": "ssidorov-1979@postgrespro.ru", "phone": "+70164104791"}
0005432164983	21AA7F	4818 413808	DMITRIY FILIPPOV	{"phone": "+70083088130"}
0005432164984	006BAA	8225 090172	OKSANA ANDREEVA	{"phone": "+70488404572"}
0005432164985	006BAA	2550 185968	SVETLANA ILINA	{"email": "ilina-s_011970@postgrespro.ru", "phone": "+70932442955"}
0005432164986	B1A6F1	3533 297647	ROMAN KISELEV	{"email": "kiselev-r.27101972@postgrespro.ru", "phone": "+70188128797"}
0005432164987	2DAE54	8194 340676	ANDREY FROLOV	{"email": "a-frolov_13121968@postgrespro.ru", "phone": "+70218382226"}
0005432164988	F27A7C	7379 455306	ALEKSEY DENISOV	{"phone": "+70390874178"}
0005432164989	744683	6419 401038	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya22101967@postgrespro.ru", "phone": "+70435343425"}
0005432164990	744683	4913 641635	ALEKSEY GRIGOREV	{"phone": "+70052385834"}
0005432164991	805284	8517 130498	OLGA KAZAKOVA	{"phone": "+70597940266"}
0005432164992	980190	1850 345653	SERGEY GERASIMOV	{"email": "sergey.gerasimov.051971@postgrespro.ru", "phone": "+70808206147"}
0005432164993	7B258A	4371 867808	ANTONINA BOGDANOVA	{"email": "bogdanova_a121972@postgrespro.ru", "phone": "+70677080059"}
0005432164994	7B258A	6477 231332	VIKTOR ZAKHAROV	{"phone": "+70043033446"}
0005432164995	A24D9C	3746 306610	IRINA ZHUKOVA	{"email": "zhukovai-22091967@postgrespro.ru", "phone": "+70308328214"}
0005432164996	B52504	5059 748851	IRINA DENISOVA	{"email": "i.denisova1974@postgrespro.ru", "phone": "+70904468307"}
0005432164997	07CDF1	5952 795774	KLAVDIYA ANDREEVA	{"phone": "+70424291392"}
0005432164998	80A21F	1577 875723	ANATOLIY KULIKOV	{"email": "kulikov_anatoliy09081965@postgrespro.ru", "phone": "+70567076367"}
0005432164999	7CDB5B	6275 508058	AIDA NAZAROVA	{"email": "nazarova_a.051969@postgrespro.ru", "phone": "+70359032886"}
0005432165000	7CDB5B	7316 542922	ELENA KONDRATEVA	{"phone": "+70384744375"}
0005432165001	5A476D	9964 989237	ELENA FILIPPOVA	{"email": "filippovaelena_011985@postgrespro.ru", "phone": "+70666748956"}
0005432165002	5A476D	1489 568501	EDUARD SIDOROV	{"email": "e-sidorov.011969@postgrespro.ru", "phone": "+70502686160"}
0005432165003	47F7E5	5951 193383	KIRILL POPOV	{"email": "kpopov1977@postgrespro.ru", "phone": "+70197992799"}
0005432165004	CB51A9	8193 066558	VALENTINA SIDOROVA	{"email": "valentina_sidorova.1967@postgrespro.ru", "phone": "+70912629045"}
0005432165005	CFF196	4143 379961	ARTUR AFANASEV	{"email": "afanasev-artur.021972@postgrespro.ru", "phone": "+70596644410"}
0005432165006	95F72E	6488 605567	ANNA MIKHAYLOVA	{"email": "mikhaylovaa-121966@postgrespro.ru", "phone": "+70363434710"}
0005432165007	FF9DEC	7206 573839	NIKOLAY TIKHONOV	{"phone": "+70630696272"}
0005432165008	B3EB90	4882 863940	SVETLANA SERGEEVA	{"phone": "+70569702448"}
0005432165009	B3EB90	5852 364520	VLADIMIR ZAKHAROV	{"email": "vladimir-zakharov.08091967@postgrespro.ru", "phone": "+70950882945"}
0005432165010	FBEB6B	0355 902766	SERGEY BORISOV	{"email": "sergey-borisov-27021978@postgrespro.ru", "phone": "+70720870461"}
0005432165011	FBEB6B	1950 981959	DANILA ZHUKOV	{"phone": "+70390407882"}
0005432165012	897427	0026 181700	FAINA POPOVA	{"email": "fpopova1971@postgrespro.ru", "phone": "+70651706820"}
0005432165013	FD34EA	8902 164217	SVETLANA CHERNOVA	{"phone": "+70609610737"}
0005432165014	BE4E99	4678 926970	VIKTOR DENISOV	{"email": "denisov_v-081962@postgrespro.ru", "phone": "+70006977052"}
0005432165015	1596A6	4016 247632	OKSANA BORISOVA	{"phone": "+70675158333"}
0005432165016	1596A6	3269 386852	ANASTASIYA KUDRYASHOVA	{"phone": "+70844985663"}
0005432165017	BB4ADA	5311 843082	PELAGEYA VASILEVA	{"phone": "+70255831607"}
0005432165018	AE3203	7759 192937	VLADIMIR ANTONOV	{"phone": "+70059011877"}
0005432165019	D8BCBF	4142 810879	SVETLANA SERGEEVA	{"phone": "+70416769756"}
0005432165020	E20EA9	2289 018223	EKATERINA VOROBEVA	{"phone": "+70990386017"}
0005432165021	D1DF8A	9681 549892	ZINAIDA MALYSHEVA	{"email": "malysheva-zinaida-13121969@postgrespro.ru", "phone": "+70772220331"}
0005432165022	8D6320	5403 877299	NATALYA TIKHONOVA	{"phone": "+70464532567"}
0005432165023	4EA52A	2110 032756	NIKOLAY VOROBEV	{"email": "n.vorobev-1962@postgrespro.ru", "phone": "+70489037028"}
0005432165024	84AB12	0873 629604	ALEKSANDRA DENISOVA	{"phone": "+70757238256"}
0005432165025	3A6C64	3653 812696	VIOLETTA NIKITINA	{"phone": "+70567409980"}
0005432165026	100C4F	9314 215201	MARIYA VOROBEVA	{"email": "vorobeva_mariya1972@postgrespro.ru", "phone": "+70026491320"}
0005432165027	50BD77	5027 572336	ANATOLIY MELNIKOV	{"email": "melnikov.anatoliy.1966@postgrespro.ru", "phone": "+70887812031"}
0005432165028	3D7FA9	9648 551554	ANDREY NIKOLAEV	{"email": "nikolaev.a1988@postgrespro.ru", "phone": "+70445061370"}
0005432165029	EB0DE5	7759 792875	DMITRIY IVANOV	{"phone": "+70295109992"}
0005432165030	EB0DE5	4656 558917	LARISA KONDRATEVA	{"email": "kondratevalarisa.1964@postgrespro.ru", "phone": "+70059781236"}
0005432165031	623652	5115 882355	SERGEY ANDREEV	{"email": "s-andreev_121966@postgrespro.ru", "phone": "+70083691245"}
0005432165032	8FC5C9	0190 572753	ALEKSEY BELOV	{"email": "belov.aleksey.1969@postgrespro.ru", "phone": "+70621889242"}
0005432165033	9E2613	9520 104986	ALEKSANDR ROMANOV	{"email": "romanov_a.10051977@postgrespro.ru", "phone": "+70590221796"}
0005432165034	EADC5C	4913 559400	ELENA GERASIMOVA	{"email": "gerasimova.e.1967@postgrespro.ru", "phone": "+70545280330"}
0005432165035	CD0840	9391 464087	RINAT POPOV	{"email": "popov_r.111974@postgrespro.ru", "phone": "+70516522586"}
0005432165036	CD0840	3402 119603	DARYA NIKOLAEVA	{"email": "nikolaeva_d-1958@postgrespro.ru", "phone": "+70627941093"}
0005432165037	5740CF	4375 508595	NIKITA KOZLOV	{"phone": "+70567140034"}
0005432165038	A03F9B	9334 119139	SVETLANA KONDRATEVA	{"email": "kondratevasvetlana-29021968@postgrespro.ru", "phone": "+70798691470"}
0005432165039	0DF853	7786 004517	OLEG SCHERBAKOV	{"email": "oleg.scherbakov_061980@postgrespro.ru", "phone": "+70356121959"}
0005432165040	38F909	7608 387892	VALENTINA MAKAROVA	{"phone": "+70455463467"}
0005432165041	A44C6C	7465 963923	NATALYA DANILOVA	{"phone": "+70270713284"}
0005432165042	6D7EEB	8944 365165	MARIYA GAVRILOVA	{"phone": "+70831413381"}
0005432165043	6D7EEB	2541 036284	VITALIY MAKAROV	{"email": "v_makarov_04021978@postgrespro.ru", "phone": "+70379913427"}
0005432165044	B7312A	7301 329556	PETR MEDVEDEV	{"phone": "+70001805676"}
0005432165045	B7312A	5835 479145	NINA KOROLEVA	{"email": "nina.koroleva.02041984@postgrespro.ru", "phone": "+70612786058"}
0005432165046	D09766	0308 234834	SERGEY MAKAROV	{"email": "makarovsergey.04121973@postgrespro.ru", "phone": "+70085567470"}
0005432165047	ADE3DD	3444 787182	IGOR SCHERBAKOV	{"email": "scherbakovigor02041969@postgrespro.ru", "phone": "+70209332844"}
0005432165048	DAAA27	3120 800649	SERGEY ALEKSANDROV	{"email": "aleksandrovsergey1971@postgrespro.ru", "phone": "+70238418232"}
0005432165049	051AE8	9548 481364	TATYANA KOLESNIKOVA	{"email": "tatyanakolesnikova04021964@postgrespro.ru", "phone": "+70063040650"}
0005432165050	573DA8	7197 278161	YURIY PETROV	{"email": "petrov_yuriy.1971@postgrespro.ru", "phone": "+70967048407"}
0005432165051	573DA8	2126 755147	PETR POPOV	{"phone": "+70802212710"}
0005432165052	D61172	2679 112409	EKATERINA BARANOVA	{"phone": "+70222797044"}
0005432165053	D1B9CE	9118 161373	OLGA KOROLEVA	{"phone": "+70956385202"}
0005432165054	1B0C9C	5516 763934	GENNADIY ILIN	{"phone": "+70550134103"}
0005432165055	1B0C9C	0421 309656	ANDREY SEMENOV	{"phone": "+70048075493"}
0005432165056	86A3B9	8474 545641	TATYANA ZHUKOVA	{"email": "zhukova-tatyana_15101970@postgrespro.ru", "phone": "+70366532613"}
0005432165223	DA099E	9888 175462	NINA KALININA	{"phone": "+70621298011"}
0005432165057	A859D9	7248 073565	SERGEY KUZMIN	{"email": "kuzmins-06041973@postgrespro.ru", "phone": "+70266480441"}
0005432165058	4E664E	8477 719865	DMITRIY KRASNOV	{"email": "krasnov.dmitriy-121972@postgrespro.ru", "phone": "+70424615867"}
0005432165059	2DF744	1730 401903	LILIYA ANISIMOVA	{"phone": "+70718466621"}
0005432165060	1791C2	1198 848743	ROMAN SOROKIN	{"email": "sorokin-roman_1959@postgrespro.ru", "phone": "+70549530129"}
0005432165061	1791C2	2601 504538	SERGEY VLASOV	{"email": "svlasov1973@postgrespro.ru", "phone": "+70409055624"}
0005432165062	C97332	4944 628142	ANNA DENISOVA	{"email": "denisova_anna.1963@postgrespro.ru", "phone": "+70500619397"}
0005432165063	4DB5C8	5085 996896	ALENA TROFIMOVA	{"phone": "+70374112115"}
0005432165064	523D1B	4343 406575	GERMAN POPOV	{"email": "germanpopov-1992@postgrespro.ru", "phone": "+70860329155"}
0005432165065	EA75C5	6404 847049	ALEKSEY SOLOVEV	{"phone": "+70377047680"}
0005432165066	080CFA	2396 291040	ALENA KARPOVA	{"phone": "+70783392174"}
0005432165067	B938C1	4637 113035	MARIYA MELNIKOVA	{"email": "m.melnikova_081971@postgrespro.ru", "phone": "+70940894582"}
0005432165068	4CE5EA	4237 011647	ILYA SAVELEV	{"email": "i.savelev.1978@postgrespro.ru", "phone": "+70748369878"}
0005432165069	949AB8	1578 224835	SERGEY MOISEEV	{"email": "moiseev-s061972@postgrespro.ru", "phone": "+70722704448"}
0005432165070	949AB8	4787 307053	NELLI DMITRIEVA	{"email": "dmitrieva-nelli.19041968@postgrespro.ru", "phone": "+70314546703"}
0005432165071	E719EE	6842 638839	IRINA KAZAKOVA	{"phone": "+70484021304"}
0005432165072	72C87A	8449 129914	IRINA FILATOVA	{"email": "ifilatova.17061974@postgrespro.ru", "phone": "+70645085634"}
0005432165073	EB5FD9	0366 161596	INNA KRASNOVA	{"email": "inna-krasnova1981@postgrespro.ru", "phone": "+70721200736"}
0005432165074	D680A7	5090 537410	ROMAN KUDRYASHOV	{"phone": "+70698352327"}
0005432165075	D680A7	2239 136045	ANTON SHEVCHENKO	{"phone": "+70705563127"}
0005432165076	F6AABF	7578 367341	KRISTINA NOVIKOVA	{"phone": "+70083338564"}
0005432165077	39FF93	6415 016770	VLADISLAV MIKHAYLOV	{"email": "v-mikhaylov-27061975@postgrespro.ru", "phone": "+70161424895"}
0005432165078	39FF93	5288 295478	LYUDMILA GUSEVA	{"phone": "+70670018449"}
0005432165079	B33936	5388 814022	YULIYA KOROLEVA	{"phone": "+70220224077"}
0005432165080	1BE844	9624 227091	OKSANA LUKYANOVA	{"phone": "+70869565050"}
0005432165081	ACFA3B	7917 747863	NATALYA POPOVA	{"email": "popova.natalya08021968@postgrespro.ru", "phone": "+70698815326"}
0005432165082	501B16	6289 514966	ALEKSANDR DMITRIEV	{"email": "dmitriev-a1970@postgrespro.ru", "phone": "+70371477407"}
0005432165083	234F45	2861 607722	MAKSIM OSIPOV	{"email": "maksim_osipov02101979@postgrespro.ru", "phone": "+70810585732"}
0005432165084	15F518	1923 325104	SVETLANA LOGINOVA	{"email": "svetlana_loginova_1974@postgrespro.ru", "phone": "+70690922203"}
0005432165085	E29467	8296 030806	NINA VOLKOVA	{"email": "nina.volkova1977@postgrespro.ru", "phone": "+70742743883"}
0005432165086	09F59E	9334 345600	RAISA ZAKHAROVA	{"phone": "+70158919137"}
0005432165087	09F59E	3981 197054	GALINA IVANOVA	{"email": "ivanovag14121974@postgrespro.ru", "phone": "+70851966947"}
0005432165088	FCB6AA	0867 740112	RUSLAN IVANOV	{"phone": "+70630051015"}
0005432165089	283E1A	2942 224251	NATALYA MAKSIMOVA	{"email": "natalyamaksimova-121962@postgrespro.ru", "phone": "+70027793242"}
0005432165090	95EE32	6631 737968	ALEKSANDR TIMOFEEV	{"email": "timofeev.aleksandr23021969@postgrespro.ru", "phone": "+70739430394"}
0005432165091	5646AC	1031 072917	ANTONINA AFANASEVA	{"email": "afanasevaa.051970@postgrespro.ru", "phone": "+70772492335"}
0005432165092	5646AC	8966 097763	NATALYA KUZNECOVA	{"email": "kuznecovan.1970@postgrespro.ru", "phone": "+70435147522"}
0005432165093	0B9FAC	1747 760190	LYUDMILA POPOVA	{"phone": "+70653430973"}
0005432165094	0B9FAC	6411 380437	NURLAN BORISOV	{"email": "nurlanborisov_101975@postgrespro.ru", "phone": "+70971625780"}
0005432165095	1529B7	0062 544756	ELENA GERASIMOVA	{"phone": "+70211265599"}
0005432165096	013333	0028 430340	MARGARITA KUZNECOVA	{"email": "kuznecovamargarita03071979@postgrespro.ru", "phone": "+70457546595"}
0005432165097	915A20	8163 930027	IGOR DMITRIEV	{"email": "dmitrievi.1966@postgrespro.ru", "phone": "+70510338691"}
0005432165098	915A20	5238 077279	ELENA PAVLOVA	{"email": "e-pavlova111973@postgrespro.ru", "phone": "+70666734053"}
0005432165099	915A20	0761 056675	SERGEY KUZNECOV	{"email": "sergey_kuznecov-061975@postgrespro.ru", "phone": "+70917475150"}
0005432165100	E48B0C	0119 857937	MARIYA FOMINA	{"email": "fomina-mariya_1960@postgrespro.ru", "phone": "+70332637595"}
0005432165101	E48B0C	3919 611427	NIKOLAY STEPANOV	{"email": "n.stepanov.051975@postgrespro.ru", "phone": "+70535758561"}
0005432165102	305E86	9830 841474	EKATERINA KUZMINA	{"email": "e_kuzmina091979@postgrespro.ru", "phone": "+70828217486"}
0005432165103	305E86	4428 373710	YULIYA VASILEVA	{"email": "yuliya-vasileva-031972@postgrespro.ru", "phone": "+70989232860"}
0005432165104	F276C8	7667 174033	ELENA KUZNECOVA	{"email": "kuznecova.e_1985@postgrespro.ru", "phone": "+70197380545"}
0005432165105	F276C8	9415 544872	OLGA TITOVA	{"email": "o.titova.10091961@postgrespro.ru", "phone": "+70108466416"}
0005432165106	F276C8	8875 240224	DMITRIY MEDVEDEV	{"email": "dmitriy_medvedev_041974@postgrespro.ru", "phone": "+70478068900"}
0005432165107	F156EB	7308 096850	VALENTINA MAKAROVA	{"email": "makarova-v.1970@postgrespro.ru", "phone": "+70158450078"}
0005432165108	721F90	3156 674724	DMITRIY SOROKIN	{"phone": "+70780830168"}
0005432165109	8AEAA5	6527 653634	NATALYA FEDOROVA	{"email": "natalyafedorova-11101968@postgrespro.ru", "phone": "+70512834318"}
0005432165110	56AFC2	8603 513227	ALEKSANDRA IVANOVA	{"phone": "+70873525419"}
0005432165111	71CF1A	1169 378305	SVETLANA IVANOVA	{"email": "ivanova_svetlana.1977@postgrespro.ru", "phone": "+70369811905"}
0005432165112	8D0E05	4268 742155	TATYANA MOISEEVA	{"email": "moiseeva.tatyana21051967@postgrespro.ru", "phone": "+70261992453"}
0005432165113	D86216	2896 523389	OLGA MATVEEVA	{"phone": "+70401987878"}
0005432165114	8B37C0	6171 378142	TAISIYA NIKITINA	{"phone": "+70021531513"}
0005432165115	7C72DE	9008 132219	VALENTINA MIKHAYLOVA	{"phone": "+70005841602"}
0005432165116	E02D4E	4934 975738	OLGA IVANOVA	{"phone": "+70391226935"}
0005432165117	3BE8B7	8465 499927	NADEZHDA DMITRIEVA	{"email": "dmitrieva_n1978@postgrespro.ru", "phone": "+70400612963"}
0005432165118	B3C66E	5685 704748	SVETLANA EFREMOVA	{"phone": "+70502097050"}
0005432165119	9160E0	5269 590198	VIOLETTA EFIMOVA	{"phone": "+70337992252"}
0005432165120	9160E0	1132 074228	VERA ABRAMOVA	{"phone": "+70208405129"}
0005432165121	421E6B	2163 218438	ROMAN MOISEEV	{"phone": "+70182889925"}
0005432165122	68DD89	5658 732331	KONSTANTIN KONOVALOV	{"phone": "+70891400470"}
0005432165123	68DD89	3378 744677	DANILA ABRAMOV	{"phone": "+70761991467"}
0005432165124	E45345	8235 487497	SVETLANA ISAEVA	{"phone": "+70460682443"}
0005432165125	EF359F	6718 157043	MARIYA MOROZOVA	{"phone": "+70076482595"}
0005432165126	3B8832	3592 731921	EVGENIYA KOROLEVA	{"email": "koroleva-e_011980@postgrespro.ru", "phone": "+70664107525"}
0005432165127	BD1ACD	5812 003613	EVGENIY CHERNOV	{"email": "chernov-e_1967@postgrespro.ru", "phone": "+70684072286"}
0005432165128	BD1ACD	2021 855061	ALEKSANDR MELNIKOV	{"phone": "+70033009983"}
0005432165129	18FC74	5208 393582	GALINA IVANOVA	{"email": "ivanova-g-1970@postgrespro.ru", "phone": "+70915792397"}
0005432165130	155ED5	9195 355901	MARIYA POLYAKOVA	{"phone": "+70731667438"}
0005432165131	155ED5	6212 531225	MARIYA RODIONOVA	{"phone": "+70127772964"}
0005432165132	E4B0F1	8166 535679	VALENTIN VASILEV	{"email": "vasilev.v_081978@postgrespro.ru", "phone": "+70260374076"}
0005432165133	0F25FC	5389 135098	VLADIMIR KUZNECOV	{"email": "kuznecov-v-12031964@postgrespro.ru", "phone": "+70891459550"}
0005432165134	0F25FC	5265 450286	ALLA IVANOVA	{"email": "a_ivanova_041969@postgrespro.ru", "phone": "+70499100421"}
0005432165135	0F25FC	3808 653041	TAISIYA ZHURAVLEVA	{"email": "zhuravleva_taisiya.25061966@postgrespro.ru", "phone": "+70119775628"}
0005432165136	0F25FC	7112 946004	IRINA SEMENOVA	{"phone": "+70411594845"}
0005432165137	BBA8C3	7238 358326	VLADISLAV AFANASEV	{"phone": "+70197610760"}
0005432165138	22CA47	4486 796134	TATYANA IVANOVA	{"email": "t_ivanova_101964@postgrespro.ru", "phone": "+70098068739"}
0005432165139	FB83C8	2307 344006	TATYANA NIKIFOROVA	{"phone": "+70581707803"}
0005432165140	2DDFC5	9548 185122	SEMEN MARTYNOV	{"email": "smartynov-1966@postgrespro.ru", "phone": "+70191869812"}
0005432165141	345E95	7768 823574	ALEKSANDR KULIKOV	{"phone": "+70415371357"}
0005432165142	8805ED	9422 401100	TIMOFEY NIKOLAEV	{"email": "nikolaevt.15111971@postgrespro.ru", "phone": "+70546360861"}
0005432165143	8805ED	9290 950907	OKSANA FILIPPOVA	{"phone": "+70205467942"}
0005432165144	1E1762	5979 166544	NURIYA MARTYNOVA	{"email": "nuriya.martynova.011977@postgrespro.ru", "phone": "+70518411243"}
0005432165145	1E1762	8395 900994	DANIIL KOROLEV	{"phone": "+70482726900"}
0005432165146	0F191E	4227 588133	LARISA RYABOVA	{"phone": "+70554746430"}
0005432165147	0F191E	9823 752986	VIKTORIYA ZHUKOVA	{"phone": "+70225606540"}
0005432165148	9FE6CA	9343 628707	RAISA VASILEVA	{"phone": "+70403003851"}
0005432165149	69ABDF	9434 604357	FEDOR NIKITIN	{"phone": "+70391812606"}
0005432165150	69ABDF	1175 336598	ELENA TITOVA	{"email": "titovaelena.011973@postgrespro.ru", "phone": "+70529000096"}
0005432165151	17192B	6211 262087	KRISTINA YAKOVLEVA	{"email": "kristina-yakovleva-31081976@postgrespro.ru", "phone": "+70486319149"}
0005432165152	17192B	1648 557492	NATALYA ZHUKOVA	{"email": "zhukova-natalya.1974@postgrespro.ru", "phone": "+70433032516"}
0005432165153	BD4DEE	4590 454816	LARISA EGOROVA	{"phone": "+70837133685"}
0005432165154	BEC541	1799 450621	ALEKSANDR OSIPOV	{"email": "aleksandrosipov.1982@postgrespro.ru", "phone": "+70183119967"}
0005432165155	9F6831	7245 756764	IRINA ANTONOVA	{"phone": "+70929923233"}
0005432165156	D2820C	4505 805783	ANASTASIYA VOROBEVA	{"email": "vorobeva-anastasiya_041968@postgrespro.ru", "phone": "+70950431104"}
0005432165157	482EEC	9913 223047	NAIL SCHERBAKOV	{"phone": "+70235329479"}
0005432165158	FEE020	2895 151927	ALEKSANDR ILIN	{"phone": "+70103506930"}
0005432165159	AB3730	5867 627230	SVETLANA NAZAROVA	{"phone": "+70322141227"}
0005432165160	A1FF4C	6353 684958	YURIY ANTONOV	{"phone": "+70424591241"}
0005432165161	A27603	6411 323216	ANFISA MIRONOVA	{"email": "anfisa_mironova.031967@postgrespro.ru", "phone": "+70523039476"}
0005432165162	FE173A	1825 640967	DMITRIY KUDRYASHOV	{"phone": "+70740080074"}
0005432165163	FE173A	1337 313437	VITALIY NIKOLAEV	{"email": "nikolaev.vitaliy_1976@postgrespro.ru", "phone": "+70149146537"}
0005432165164	1835DF	4137 704809	VALERIYA LOGINOVA	{"email": "v.loginova.10031982@postgrespro.ru", "phone": "+70811337925"}
0005432165165	1835DF	3368 047806	ALENA GORBUNOVA	{"email": "alenagorbunova_051976@postgrespro.ru", "phone": "+70912966186"}
0005432165166	985DF9	3834 377317	VLADIMIR GAVRILOV	{"email": "v-gavrilov15061969@postgrespro.ru", "phone": "+70965590354"}
0005432165167	4740BE	5339 340236	ALEKSANDR VOROBEV	{"email": "a.vorobev.1982@postgrespro.ru", "phone": "+70008820542"}
0005432165168	F5C353	8000 760281	YURIY YAKOVLEV	{"email": "yakovlev-y01101972@postgrespro.ru", "phone": "+70498693621"}
0005432165169	345D50	9058 062689	ELIZAVETA MELNIKOVA	{"email": "melnikova.e_091979@postgrespro.ru", "phone": "+70137059341"}
0005432165170	685788	2085 880672	ANDREY FILIPPOV	{"email": "filippov-andrey_1975@postgrespro.ru", "phone": "+70080667623"}
0005432165171	685788	8618 487575	OLGA TIMOFEEVA	{"email": "timofeeva_olga-13101964@postgrespro.ru", "phone": "+70589688048"}
0005432165172	830BB6	2151 985692	IVAN MARTYNOV	{"email": "ivan-martynov1974@postgrespro.ru", "phone": "+70512481698"}
0005432165173	830BB6	9777 524381	TATYANA ZHUKOVA	{"phone": "+70529720900"}
0005432165174	9EB392	4203 744710	ALEKSANDR NIKITIN	{"phone": "+70112672364"}
0005432165175	A4EB1B	6829 622960	NIKOLAY VOROBEV	{"email": "vorobev_nikolay081970@postgrespro.ru", "phone": "+70489175368"}
0005432165176	A4EB1B	3658 734995	SERGEY AFANASEV	{"email": "s_afanasev-09071960@postgrespro.ru", "phone": "+70179423437"}
0005432165177	833059	9145 452203	ANASTASIYA VOLKOVA	{"email": "a_volkova-1981@postgrespro.ru", "phone": "+70855719096"}
0005432165178	833059	8437 521865	MAKSIM GAVRILOV	{"phone": "+70717553660"}
0005432165179	37DF77	3611 057511	NATALYA ANTONOVA	{"phone": "+70485629192"}
0005432165180	9A687A	9678 373589	VLADIMIR MATVEEV	{"phone": "+70352958981"}
0005432165181	0AF754	5227 459023	GALINA TROFIMOVA	{"email": "trofimova.galina_20061968@postgrespro.ru", "phone": "+70864649750"}
0005432165182	EEC377	2710 457576	TATYANA OSIPOVA	{"email": "osipova.t.1977@postgrespro.ru", "phone": "+70285533383"}
0005432165183	A2CF30	9880 939897	ALENA NAZAROVA	{"email": "nazarova.alena.1971@postgrespro.ru", "phone": "+70410211046"}
0005432165184	AF2FC2	1389 425392	EGOR MIKHAYLOV	{"phone": "+70154049585"}
0005432165185	AF2FC2	2480 549596	NADEZHDA EGOROVA	{"email": "egorovanadezhda_1970@postgrespro.ru", "phone": "+70529493310"}
0005432165186	AF2FC2	8862 728007	EKATERINA SIDOROVA	{"phone": "+70207704708"}
0005432165187	707AD9	0409 451845	NATALYA ANISIMOVA	{"phone": "+70263400133"}
0005432165188	707AD9	9502 723981	VERA GAVRILOVA	{"phone": "+70500759122"}
0005432165189	240FC7	5970 373956	ALEKSANDR ZAKHAROV	{"email": "a-zakharov.1974@postgrespro.ru", "phone": "+70481505578"}
0005432165190	7485C1	8851 554079	VLADISLAV SIDOROV	{"phone": "+70133023000"}
0005432165191	7485C1	1309 052732	PETR KOZLOV	{"email": "kozlov-p_11121971@postgrespro.ru", "phone": "+70118901200"}
0005432165192	759B5F	2132 709599	TATYANA NIKIFOROVA	{"email": "nikiforovatatyana-101978@postgrespro.ru", "phone": "+70197428632"}
0005432165193	F17AFE	9651 680223	PAVEL POPOV	{"email": "popov_pavel-09041956@postgrespro.ru", "phone": "+70844139719"}
0005432165194	263C8F	6896 682444	ANASTASIYA KUZNECOVA	{"phone": "+70465929648"}
0005432165195	3CB840	1129 648955	MIROSLAV KULIKOV	{"email": "m-kulikov1971@postgrespro.ru", "phone": "+70694975285"}
0005432165196	3CB840	1515 833111	VALERIY NIKOLAEV	{"email": "nikolaev.valeriy.05011966@postgrespro.ru", "phone": "+70888080034"}
0005432165197	6F9B5C	2893 370838	NINA MIKHAYLOVA	{"email": "mikhaylova.n.041975@postgrespro.ru", "phone": "+70595867741"}
0005432165198	A69575	9762 529472	RISHAT ISAEV	{"phone": "+70379014950"}
0005432165199	2D8FE2	2653 441394	VIKTORIYA AFANASEVA	{"phone": "+70343707900"}
0005432165200	2D8FE2	9301 099198	ALIYA IVANOVA	{"email": "ivanova.a_29011978@postgrespro.ru", "phone": "+70966463588"}
0005432165201	87B879	3349 224934	ANATOLIY BONDARENKO	{"email": "bondarenkoanatoliy_061968@postgrespro.ru", "phone": "+70906539283"}
0005432165202	87B879	9452 416983	LYUDMILA ZAKHAROVA	{"phone": "+70674979746"}
0005432165203	2E0188	2360 104086	NATALYA ZAKHAROVA	{"phone": "+70983982942"}
0005432165204	2E0188	6951 413591	ALEKSANDR SHEVCHENKO	{"phone": "+70013364320"}
0005432165205	A41D7E	0707 481625	ALEKSEY ROMANOV	{"phone": "+70533737911"}
0005432165206	122AD0	3160 043751	ANATOLIY POPOV	{"email": "anatoliypopov.26101970@postgrespro.ru", "phone": "+70803887730"}
0005432165207	6DF6DC	5814 665010	NATALYA CHERNOVA	{"phone": "+70974487852"}
0005432165208	AE9C50	8324 283755	VITALIY KUZMIN	{"phone": "+70315174861"}
0005432165209	AE9C50	0689 737538	EVDOKIYA KUDRYASHOVA	{"email": "evdokiya.kudryashova_1967@postgrespro.ru", "phone": "+70806845574"}
0005432165210	C237B3	0261 047407	ELENA KUZMINA	{"email": "kuzmina-elena.1966@postgrespro.ru", "phone": "+70525819331"}
0005432165211	DB75CC	5006 641590	ELENA SOKOLOVA	{"phone": "+70827453988"}
0005432165212	5E1B83	4486 763580	MARIYA ALEKSANDROVA	{"phone": "+70452886914"}
0005432165213	5E1B83	3123 348508	ROMAN TIKHONOV	{"email": "tikhonov-r.081977@postgrespro.ru", "phone": "+70184953140"}
0005432165214	CEF587	3829 286199	ANNA TIMOFEEVA	{"email": "anna_timofeeva.10111980@postgrespro.ru", "phone": "+70970979587"}
0005432165215	E792E7	9342 455071	ALEKSANDR DENISOV	{"phone": "+70141189049"}
0005432165216	204640	2513 781649	ALEKSANDRA MOROZOVA	{"email": "a.morozova_23041979@postgrespro.ru", "phone": "+70543029442"}
0005432165217	BD009E	7828 101293	DMITRIY ZAYCEV	{"phone": "+70297725438"}
0005432165218	8B3699	7506 340589	PETR MOROZOV	{"email": "p_morozov-091960@postgrespro.ru", "phone": "+70299870443"}
0005432165219	862AB5	3707 261245	MARINA KUZNECOVA	{"email": "kuznecova_m.111972@postgrespro.ru", "phone": "+70479662998"}
0005432165220	70C538	0479 355832	SERGEY SCHERBAKOV	{"email": "s_scherbakov.091972@postgrespro.ru", "phone": "+70601737473"}
0005432165221	70C538	5530 036739	YURIY MIKHAYLOV	{"email": "mikhaylov_yuriy-04101969@postgrespro.ru", "phone": "+70669541958"}
0005432165222	61C147	5796 633266	OLEG OSIPOV	{"email": "osipovoleg_1969@postgrespro.ru", "phone": "+70589493019"}
0005432165224	DA099E	3005 247575	TATYANA VOLKOVA	{"email": "tatyana-volkova.07061978@postgrespro.ru", "phone": "+70724185393"}
0005432165225	476E33	4213 219942	ZINAIDA VASILEVA	{"email": "vasileva.zinaida_081957@postgrespro.ru", "phone": "+70188999861"}
0005432165226	EF7B55	0481 394849	VALENTINA FEDOROVA	{"phone": "+70094865420"}
0005432165227	ABAF3E	7677 431864	VIKTOR TARASOV	{"email": "tarasovviktor011981@postgrespro.ru", "phone": "+70035399539"}
0005432165228	ABAF3E	6099 016042	YURIY IVANOV	{"phone": "+70691239439"}
0005432165229	22A1F1	6065 675120	TAMARA TARASOVA	{"email": "t-tarasova1975@postgrespro.ru", "phone": "+70100986501"}
0005432165230	56CD12	9084 936678	MARIYA MAKSIMOVA	{"email": "maksimova-mariya.01011972@postgrespro.ru", "phone": "+70972710552"}
0005432165231	56CD12	1995 785310	ELIZAVETA MOISEEVA	{"phone": "+70077941359"}
0005432165232	D90C83	6509 734431	VASILIY NIKOLAEV	{"phone": "+70795456318"}
0005432165233	373DAE	1412 188901	MARIYA MALYSHEVA	{"phone": "+70598968848"}
0005432165234	0908A0	5552 086497	MARGARITA SOROKINA	{"email": "sorokina_m_1975@postgrespro.ru", "phone": "+70160636121"}
0005432165235	B7B140	8649 619183	ZOYA ALEKSANDROVA	{"email": "zoya.aleksandrova021967@postgrespro.ru", "phone": "+70555979509"}
0005432165236	47CE96	6836 133085	LYUBOV SOKOLOVA	{"phone": "+70249202545"}
0005432165237	6CDA75	8240 383156	VIKTOR GAVRILOV	{"email": "viktor-gavrilov21111975@postgrespro.ru", "phone": "+70110838620"}
0005432165238	BC38E4	8173 404768	VIKTORIYA CHERNOVA	{"phone": "+70488064525"}
0005432165239	BC38E4	9300 521185	VASILIY PAVLOV	{"email": "pavlov-vasiliy-061964@postgrespro.ru", "phone": "+70435141267"}
0005432165240	5D6734	5062 929315	TAISIYA POLYAKOVA	{"email": "taisiyapolyakova.10041970@postgrespro.ru", "phone": "+70808607095"}
0005432165241	4E4250	2672 966277	ELENA SMIRNOVA	{"phone": "+70628082880"}
0005432165242	351A3A	7354 713473	VLADISLAV KUZNECOV	{"email": "kuznecov_vladislav19011979@postgrespro.ru", "phone": "+70852895031"}
0005432165243	54AB2D	8360 081363	GALINA KUZNECOVA	{"phone": "+70337277884"}
0005432165244	54AB2D	7866 477724	VALENTINA AFANASEVA	{"phone": "+70711355042"}
0005432165245	2899CD	8274 266447	MIKHAIL MOISEEV	{"phone": "+70391125426"}
0005432165246	D6703B	3764 882161	ANNA MIKHAYLOVA	{"email": "mikhaylova-anna_1973@postgrespro.ru", "phone": "+70048494204"}
0005432165247	7C189A	5751 332777	YULIYA RODIONOVA	{"email": "rodionovayuliya081977@postgrespro.ru", "phone": "+70731007566"}
0005432165248	32A322	2976 052260	TATYANA ILINA	{"email": "tilina_121974@postgrespro.ru", "phone": "+70679867807"}
0005432165249	64F98A	5990 425972	RUSLAN SOKOLOV	{"phone": "+70858508394"}
0005432165250	64F98A	4259 928813	SERGEY SOKOLOV	{"email": "sergey_sokolov-071973@postgrespro.ru", "phone": "+70906607635"}
0005432165251	2A3932	0179 886627	OLGA PETROVA	{"email": "olga.petrova_011986@postgrespro.ru", "phone": "+70285401233"}
0005432165252	C33528	7320 126203	MARIYA MALYSHEVA	{"phone": "+70705010559"}
0005432165253	CABB11	5725 132811	ELENA BOGDANOVA	{"phone": "+70693787014"}
0005432165254	D85A1B	0374 933098	VIKTOR MAKSIMOV	{"email": "viktor.maksimov-061969@postgrespro.ru", "phone": "+70420148740"}
0005432165255	D3BAB5	2361 187775	ILYA VOROBEV	{"email": "i.vorobev.01121963@postgrespro.ru", "phone": "+70155295227"}
0005432165256	A727C4	9753 762697	OLGA KUZNECOVA	{"phone": "+70722591506"}
0005432165257	F835D6	9143 687882	YURIY SEMENOV	{"email": "semenovyuriy.15061965@postgrespro.ru", "phone": "+70157180928"}
0005432165258	6921A6	7411 906490	OLGA ANDREEVA	{"email": "olga.andreeva.1968@postgrespro.ru", "phone": "+70141213387"}
0005432165259	6921A6	1532 397396	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov21061973@postgrespro.ru", "phone": "+70448419375"}
0005432165260	04974C	2743 416050	OLEG MEDVEDEV	{"phone": "+70674808378"}
0005432165261	2787D6	9142 225082	SVETLANA ALEKSEEVA	{"email": "alekseeva.s_091979@postgrespro.ru", "phone": "+70508833135"}
0005432165262	2787D6	3768 838471	VIKTOR BARANOV	{"email": "vbaranov_1981@postgrespro.ru", "phone": "+70924407985"}
0005432165263	4F16F5	9923 713531	ELENA ZOTOVA	{"phone": "+70794033316"}
0005432165264	4F16F5	4508 187953	NINA NOVIKOVA	{"phone": "+70360529406"}
0005432165265	4F16F5	4691 052514	ELENA KUZNECOVA	{"email": "e_kuznecova_021962@postgrespro.ru", "phone": "+70794435698"}
0005432165266	203CB5	1965 930219	VALENTINA ANISIMOVA	{"phone": "+70635446098"}
0005432166843	8C5DEA	6246 768552	TATYANA EFIMOVA	{"phone": "+70028324971"}
0005432166844	F7057E	0427 894269	OLGA STEPANOVA	{"phone": "+70372280507"}
0005432166845	851A0F	4358 349868	VITALIY DENISOV	{"phone": "+70490086008"}
0005432166846	052C55	3032 077854	IRINA BELOVA	{"email": "irinabelova.091959@postgrespro.ru", "phone": "+70072830654"}
0005432166847	96FB2B	6721 159494	POLINA AFANASEVA	{"email": "afanaseva.polina_1973@postgrespro.ru", "phone": "+70518545457"}
0005432166848	1A92CF	7733 497612	DANIL KUZMIN	{"email": "kuzmin.d-25101973@postgrespro.ru", "phone": "+70063536164"}
0005432166849	B6E5A6	2963 126062	VALENTINA KUDRYASHOVA	{"phone": "+70044042515"}
0005432166850	C9CF5E	2133 960464	TATYANA SOROKINA	{"phone": "+70174659204"}
0005432166851	ADC3DF	4572 769554	NIKOLAY ZAYCEV	{"phone": "+70794211576"}
0005432166852	28B48F	3137 041657	NIKOLAY POPOV	{"email": "npopov_1973@postgrespro.ru", "phone": "+70747215415"}
0005432166853	074DD9	0433 792424	ELENA TITOVA	{"email": "titova-elena08091963@postgrespro.ru", "phone": "+70927850186"}
0005432166854	4B7537	9224 754286	YURIY GERASIMOV	{"email": "gerasimov-y.1966@postgrespro.ru", "phone": "+70442294150"}
0005432166855	4B7537	1621 575557	DMITRIY DAVYDOV	{"phone": "+70535304504"}
0005432166856	1CA240	6862 791749	VIKTOR ISAEV	{"email": "isaev_viktor_09021970@postgrespro.ru", "phone": "+70263932500"}
0005432166857	276775	4483 295859	ALEFTINA ZAKHAROVA	{"phone": "+70915387094"}
0005432166858	276775	4693 998210	NATALYA MOISEEVA	{"email": "natalyamoiseeva-121976@postgrespro.ru", "phone": "+70609555189"}
0005432166859	114B8A	0696 839587	ELENA YUDINA	{"phone": "+70993359737"}
0005432166860	3EC092	5685 095872	NIKOLAY ABRAMOV	{"email": "abramov_nikolay_1969@postgrespro.ru", "phone": "+70003257884"}
0005432166861	6FFA29	4812 917014	ARTEM KUDRYASHOV	{"email": "akudryashov.12091969@postgrespro.ru", "phone": "+70555793513"}
0005432166862	6FFA29	2100 878987	GALINA MAKAROVA	{"email": "galinamakarova.071979@postgrespro.ru", "phone": "+70316473576"}
0005432166863	048BB9	9272 893036	SVETLANA SAVELEVA	{"phone": "+70412745905"}
0005432166864	048BB9	2216 907041	DARYA TITOVA	{"phone": "+70863464688"}
0005432166865	529D3D	0357 655554	YULIYA MIKHAYLOVA	{"email": "y-mikhaylova-091968@postgrespro.ru", "phone": "+70758199091"}
0005432166866	529D3D	1179 447452	VLADIMIR KONOVALOV	{"phone": "+70108077839"}
0005432166867	24BAB0	0917 261078	NINA FOMINA	{"phone": "+70440919711"}
0005432166868	F8F93A	8601 179097	NATALYA PETROVA	{"phone": "+70762914255"}
0005432166869	F8F93A	4046 002963	ALEKSANDRA KONOVALOVA	{"phone": "+70572907272"}
0005432166870	F8F93A	7705 097040	ALEKSANDR SOROKIN	{"email": "sorokina-1962@postgrespro.ru", "phone": "+70960780344"}
0005432166871	09B512	3074 407882	OLEG MOISEEV	{"email": "moiseev-oleg.1969@postgrespro.ru", "phone": "+70024523795"}
0005432166872	09B512	9679 349453	MARIYA VASILEVA	{"email": "vasilevamariya.1964@postgrespro.ru", "phone": "+70523738755"}
0005432166873	B89222	5538 864743	VLADIMIR RODIONOV	{"phone": "+70558223440"}
0005432166874	B89222	3887 948657	MARIYA MIRONOVA	{"phone": "+70506959841"}
0005432166875	7505C4	8104 309653	VITALIY ZAKHAROV	{"phone": "+70045631390"}
0005432166876	1D06B8	6622 183837	ELENA SEMENOVA	{"email": "semenova.elena_03051963@postgrespro.ru", "phone": "+70954545586"}
0005432166877	1D06B8	3433 051435	ALENA GERASIMOVA	{"phone": "+70489728529"}
0005432166878	1E672A	7786 550035	ALEKSANDR PETROV	{"phone": "+70751214592"}
0005432166879	1E672A	2265 950673	EKATERINA PETROVA	{"phone": "+70942147553"}
0005432166880	6C8D0C	3118 143280	VLADIMIR EGOROV	{"phone": "+70158297803"}
0005432166881	48BF23	5987 983750	GALINA FOMINA	{"phone": "+70718266552"}
0005432166882	48BF23	9753 251029	TATYANA ISAEVA	{"phone": "+70231193889"}
0005432166883	9DE0D8	4266 180555	ANDREY MIRONOV	{"email": "andrey.mironov.1983@postgrespro.ru", "phone": "+70912639287"}
0005432166884	9DE0D8	4050 485718	EKATERINA MAKSIMOVA	{"email": "maksimova.ekaterina.1976@postgrespro.ru", "phone": "+70206939928"}
0005432166885	363E7C	0128 757948	ANDREY ZAKHAROV	{"phone": "+70000193468"}
0005432166886	B3B34B	0159 105240	NIKOLAY SMIRNOV	{"phone": "+70958556055"}
0005432166887	8EEFB2	2620 160782	OLGA SEMENOVA	{"email": "olgasemenova-021982@postgrespro.ru", "phone": "+70983878084"}
0005432166888	1405F9	1866 991609	VERA KUZNECOVA	{"email": "v.kuznecova_051971@postgrespro.ru", "phone": "+70068264174"}
0005432166889	269EEC	5932 434698	VALENTINA MOISEEVA	{"email": "valentinamoiseeva-1975@postgrespro.ru", "phone": "+70177250465"}
0005432166890	DB1685	3194 451888	OKSANA AFANASEVA	{"email": "afanaseva-oksana_1965@postgrespro.ru", "phone": "+70974241959"}
0005432166891	DC9FC6	3065 833493	VALENTINA VASILEVA	{"phone": "+70943167334"}
0005432166892	DC9FC6	6356 015179	ALEKSANDRA KISELEVA	{"phone": "+70865469228"}
0005432166893	E93970	1947 580271	VITALIY SMIRNOV	{"phone": "+70887048749"}
0005432166894	E93970	6914 217757	ALEKSEY SMIRNOV	{"email": "smirnov_a22111962@postgrespro.ru", "phone": "+70948191764"}
0005432166895	3F4A94	2301 935203	EDUARD KUDRYASHOV	{"phone": "+70256266236"}
0005432166896	3F4A94	2830 298749	OLGA YUDINA	{"phone": "+70547376755"}
0005432166897	3F4A94	2305 282512	IRINA DMITRIEVA	{"phone": "+70452109760"}
0005432166898	9CB635	7718 583285	ANNA NAUMOVA	{"email": "naumova-anna29031978@postgrespro.ru", "phone": "+70357960168"}
0005432166899	8F9E33	4546 830333	EVGENIYA MOISEEVA	{"email": "moiseeva.e-25021964@postgrespro.ru", "phone": "+70561519149"}
0005432166900	B98101	8381 604189	VASILIY NOVIKOV	{"email": "vasiliy.novikov28081974@postgrespro.ru", "phone": "+70089956553"}
0005432166901	666E65	6954 785177	VALENTIN KOZLOV	{"email": "v.kozlov18021966@postgrespro.ru", "phone": "+70499132398"}
0005432166902	666E65	0693 362900	OLEG MELNIKOV	{"phone": "+70501790012"}
0005432166903	666E65	1974 593549	NATALIYA FADEEVA	{"phone": "+70818262892"}
0005432166904	9BAC9B	9133 459918	ANZHELA KUDRYASHOVA	{"phone": "+70467651879"}
0005432166905	6E416C	7619 555847	IRINA ZAYCEVA	{"email": "izayceva19081972@postgrespro.ru", "phone": "+70481758886"}
0005432166906	B35467	3465 029615	ALEKSANDR SCHERBAKOV	{"phone": "+70910630311"}
0005432166907	ADA4C0	1960 529300	ANATOLIY KUZNECOV	{"phone": "+70505549297"}
0005432166908	ADA4C0	1818 607103	ANNA CHERNOVA	{"phone": "+70936878349"}
0005432166909	6B3998	3774 201355	EVGENIY KULIKOV	{"email": "kulikov.evgeniy24021965@postgrespro.ru", "phone": "+70854640131"}
0005432166910	6B3998	3976 259495	KIRILL TARASOV	{"phone": "+70859164992"}
0005432166911	93F134	1680 275697	ALENA SEMENOVA	{"phone": "+70471011521"}
0005432166912	A0B7FB	0154 590921	OLGA ABRAMOVA	{"email": "abramova_o081973@postgrespro.ru", "phone": "+70603382551"}
0005432170362	EA92BA	8102 369891	TATYANA KONOVALOVA	{"phone": "+70546947944"}
0005432166913	C2855D	0461 189174	IGOR VASILEV	{"email": "vasilevigor.051970@postgrespro.ru", "phone": "+70042840763"}
0005432166914	285278	7007 421115	VERA KOROLEVA	{"email": "koroleva.v_1969@postgrespro.ru", "phone": "+70408950797"}
0005432166915	9205FA	4350 726069	VASILIY MEDVEDEV	{"email": "medvedev_vasiliy.1971@postgrespro.ru", "phone": "+70673184036"}
0005432166916	ABD07F	7753 164354	EVGENIYA MAKAROVA	{"phone": "+70465981163"}
0005432166917	4CE162	2424 453838	NATALYA IVANOVA	{"email": "natalyaivanova_1960@postgrespro.ru", "phone": "+70306124024"}
0005432166918	610D52	5548 634398	RAISA KOROLEVA	{"phone": "+70752961275"}
0005432166919	610D52	9508 938741	VLADISLAV SMIRNOV	{"phone": "+70477072574"}
0005432166920	610D52	5843 410123	NATALIYA ROMANOVA	{"phone": "+70397221544"}
0005432166921	E6C7A1	4978 951565	ANNA BARANOVA	{"phone": "+70392631101"}
0005432166922	1999EE	9839 929193	KSENIYA ISAEVA	{"email": "isaeva.k_28011988@postgrespro.ru", "phone": "+70976536482"}
0005432166923	1999EE	3791 556360	RUSLAN DAVYDOV	{"email": "ruslandavydov.1974@postgrespro.ru", "phone": "+70524572090"}
0005432166924	DD8B12	1717 269827	NADEZHDA YAKOVLEVA	{"email": "n-yakovleva.1967@postgrespro.ru", "phone": "+70284124407"}
0005432166925	DE08D4	6986 025309	ELENA SOLOVEVA	{"email": "soloveva.e.23061972@postgrespro.ru", "phone": "+70644521626"}
0005432166926	DE08D4	4311 209104	ANNA GRISHINA	{"phone": "+70867112759"}
0005432166927	28B70A	5276 442610	EKATERINA SOKOLOVA	{"phone": "+70207571456"}
0005432166928	8BE5B8	7002 719862	TATYANA SEMENOVA	{"email": "tatyana-semenova04051977@postgrespro.ru", "phone": "+70039499593"}
0005432166929	5E595A	6514 541074	PAVEL GAVRILOV	{"email": "gavrilovpavel-1978@postgrespro.ru", "phone": "+70464561295"}
0005432166930	2382DB	2833 510992	KIRILL SERGEEV	{"phone": "+70698324285"}
0005432166931	28613A	3397 026291	VYACHESLAV SCHERBAKOV	{"email": "vscherbakov.1976@postgrespro.ru", "phone": "+70772975565"}
0005432166932	9F439B	0607 204643	VITALIY ZAYCEV	{"email": "zaycev-v.091981@postgrespro.ru", "phone": "+70455593790"}
0005432166933	D641B0	5351 008456	SERGEY VOROBEV	{"email": "vorobev_s.1977@postgrespro.ru", "phone": "+70665809490"}
0005432166934	D55B0A	4473 564811	ALEKSANDR PETROV	{"phone": "+70503749763"}
0005432166935	D55B0A	0286 502487	IRINA AKIMOVA	{"phone": "+70887406037"}
0005432166936	F70DA8	9839 021248	NATALYA NESTEROVA	{"phone": "+70731015332"}
0005432166937	F70DA8	5231 698048	EKATERINA NAUMOVA	{"email": "e_naumova11101972@postgrespro.ru", "phone": "+70259997513"}
0005432166938	C9371E	1448 917655	ELENA IVANOVA	{"email": "ivanova_elena1974@postgrespro.ru", "phone": "+70781449454"}
0005432166939	C9371E	3277 579407	EGOR ILIN	{"email": "ilin-egor_1973@postgrespro.ru", "phone": "+70053689818"}
0005432166940	C9371E	3509 465903	SVETLANA KRASNOVA	{"email": "krasnova_svetlana-1989@postgrespro.ru", "phone": "+70518536590"}
0005432166941	7FE46A	8668 906010	VLADIMIR IVANOV	{"phone": "+70228237524"}
0005432166942	CCF3F3	6138 209876	RUFIYA PETROVA	{"email": "r_petrova111977@postgrespro.ru", "phone": "+70773833579"}
0005432166943	317CB7	0981 478390	ALENA ILINA	{"email": "a_ilina1970@postgrespro.ru", "phone": "+70835397519"}
0005432166944	6DFA4B	8444 297046	ALEKSANDR BELOV	{"phone": "+70687564456"}
0005432166945	850908	1509 993774	ALLA IVANOVA	{"phone": "+70543387004"}
0005432166946	D7393D	1043 961546	ALEKSANDR ISAEV	{"email": "isaev-aleksandr_27081975@postgrespro.ru", "phone": "+70351073757"}
0005432166947	F86766	7260 894719	NIKOLAY NIKITIN	{"phone": "+70481852664"}
0005432166948	1FD4D4	5229 440561	SERGEY YAKOVLEV	{"email": "syakovlev_051975@postgrespro.ru", "phone": "+70785665724"}
0005432166949	1FD4D4	2290 638091	LYUDMILA KISELEVA	{"phone": "+70912435756"}
0005432166950	E2B616	7715 732326	NINA IVANOVA	{"phone": "+70168855778"}
0005432166951	E176A6	5636 237098	MARFA KUZNECOVA	{"email": "marfakuznecova1969@postgrespro.ru", "phone": "+70887613474"}
0005432166952	E176A6	7127 526456	ALEKSANDR TIKHONOV	{"email": "tikhonov-aleksandr_1966@postgrespro.ru", "phone": "+70239526253"}
0005432166953	60A959	4457 221381	VLADIMIR KUZMIN	{"phone": "+70656857314"}
0005432166954	AAC180	9565 031288	SERGEY KUZMIN	{"phone": "+70356894226"}
0005432166955	4E4C58	4865 277305	RAFAIL EGOROV	{"email": "rafailegorov_1975@postgrespro.ru", "phone": "+70987117253"}
0005432166956	4E4C58	2708 255033	SERGEY POPOV	{"email": "s-popov22021971@postgrespro.ru", "phone": "+70565335357"}
0005432166957	4E4C58	7620 697497	ANNA PAVLOVA	{"email": "apavlova.1978@postgrespro.ru", "phone": "+70717010837"}
0005432166958	4193FE	5351 502284	NATALYA TROFIMOVA	{"email": "trofimova-n041972@postgrespro.ru", "phone": "+70233395118"}
0005432166959	4193FE	8550 351976	VALERIY MEDVEDEV	{"email": "medvedev-v.1980@postgrespro.ru", "phone": "+70580918139"}
0005432166960	1EBB8D	7095 099479	VIKTOR MIRONOV	{"phone": "+70567497831"}
0005432166961	023ED0	5752 170009	NATALYA KUZNECOVA	{"email": "kuznecova.n1969@postgrespro.ru", "phone": "+70437096760"}
0005432166962	96092B	1039 809275	VITALIY SOROKIN	{"phone": "+70244249448"}
0005432166963	225F63	5978 001716	ROMAN MELNIKOV	{"phone": "+70944875162"}
0005432166964	128341	3627 232542	RUSLAN NIKITIN	{"phone": "+70058465515"}
0005432166965	CB9A4D	8478 039308	LIDIYA GORBUNOVA	{"email": "lidiya_gorbunova.16041968@postgrespro.ru", "phone": "+70935687107"}
0005432166966	CB9A4D	8639 425605	OLGA KRASNOVA	{"phone": "+70453647651"}
0005432166967	AD92A3	9125 186991	OLGA KUZMINA	{"phone": "+70753040905"}
0005432166968	68F71B	6749 324651	KSENIYA GRISHINA	{"email": "k-grishina-11021967@postgrespro.ru", "phone": "+70579744483"}
0005432166969	198B64	9152 547627	ROMAN YAKOVLEV	{"phone": "+70216501418"}
0005432166970	198B64	6164 605063	EVGENIY SOKOLOV	{"phone": "+70418795223"}
0005432166971	954170	7036 386421	RUSTAM TARASOV	{"email": "r.tarasov-12071979@postgrespro.ru", "phone": "+70384241570"}
0005432166972	32159C	3450 815546	ALEKSANDR ANDREEV	{"email": "andreeva011990@postgrespro.ru", "phone": "+70217883521"}
0005432166973	A9E6CF	5134 896296	ZINAIDA KUDRYASHOVA	{"email": "z_kudryashova1983@postgrespro.ru", "phone": "+70359857370"}
0005432166974	6971F6	8723 733153	VLADIMIR NIKOLAEV	{"phone": "+70736320218"}
0005432166975	6971F6	7506 145568	SERGEY KOZLOV	{"email": "kozlov-sergey_15021973@postgrespro.ru", "phone": "+70676308478"}
0005432166976	81013B	9183 951545	MARIYA YAKOVLEVA	{"email": "yakovleva-m_06011964@postgrespro.ru", "phone": "+70025795280"}
0005432166977	81013B	4689 182455	IVAN VASILEV	{"phone": "+70430910233"}
0005432166978	D56E81	3032 456441	RUSTAM MELNIKOV	{"email": "r-melnikov.06091969@postgrespro.ru", "phone": "+70145552674"}
0005432166979	D56E81	9320 204588	ANGELINA KUZNECOVA	{"phone": "+70555874649"}
0005432166980	BBC32F	5585 350054	OLEG SOROKIN	{"email": "sorokin-oleg.25021970@postgrespro.ru", "phone": "+70880740514"}
0005432166981	E9F5FB	1347 553305	MARIYA MASLOVA	{"phone": "+70607190503"}
0005432166982	E9F5FB	4944 929648	VALENTINA SCHERBAKOVA	{"email": "valentina_scherbakova1976@postgrespro.ru", "phone": "+70118234248"}
0005432166983	4770DC	8687 967487	PAVEL GUSEV	{"phone": "+70904957098"}
0005432166984	31004C	5516 399645	SERGEY ZAKHAROV	{"email": "zakharovs.061965@postgrespro.ru", "phone": "+70143322009"}
0005432166985	E4567D	3275 057600	LYUBOV MOISEEVA	{"email": "lyubovmoiseeva.08011966@postgrespro.ru", "phone": "+70121716703"}
0005432166986	BB70EF	2503 410782	SVETLANA POPOVA	{"email": "svetlana-popova.1964@postgrespro.ru", "phone": "+70858653591"}
0005432166987	AF593D	7788 614261	ANNA ALEKSEEVA	{"phone": "+70286370258"}
0005432166988	AF593D	7512 626777	ILYA KUZMIN	{"email": "ilya_kuzmin_14061971@postgrespro.ru", "phone": "+70592585082"}
0005432166989	FCC37A	8322 540564	ALEKSANDR ILIN	{"phone": "+70930783517"}
0005432166990	FCC37A	7554 888286	ANTON SERGEEV	{"email": "sergeev-a_1971@postgrespro.ru", "phone": "+70198234791"}
0005432166991	6A0559	2176 521557	NADEZHDA KUZNECOVA	{"phone": "+70841074094"}
0005432166992	ED7A13	3149 529867	YULIYA IVANOVA	{"email": "yuliya_ivanova-051975@postgrespro.ru", "phone": "+70558423656"}
0005432166993	F5E3D1	2406 423994	ANDREY PAVLOV	{"email": "pavlov.andrey_1980@postgrespro.ru", "phone": "+70477931136"}
0005432166994	070E7E	7211 404258	DMITRIY SAVELEV	{"phone": "+70399222468"}
0005432166995	7487D6	7668 705991	RIMMA DAVYDOVA	{"phone": "+70063193032"}
0005432166996	7487D6	2470 468756	SERGEY NIKITIN	{"phone": "+70311715189"}
0005432170266	5F8DD9	3253 037481	LARISA YUDINA	{"phone": "+70926215865"}
0005432170267	30403A	2615 297112	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev24021974@postgrespro.ru", "phone": "+70337871324"}
0005432170268	30403A	5126 754790	EKATERINA ISAEVA	{"email": "isaeva_e.10061964@postgrespro.ru", "phone": "+70519141908"}
0005432170269	2048D3	2899 601692	SERGEY SOROKIN	{"email": "ssorokin_1972@postgrespro.ru", "phone": "+70342254933"}
0005432170270	FD1A0D	8794 831056	OLGA IVANOVA	{"email": "oivanova.1968@postgrespro.ru", "phone": "+70313659423"}
0005432170271	319E23	2685 436752	EVGENIY BORISOV	{"email": "borisov.e071977@postgrespro.ru", "phone": "+70918360070"}
0005432170272	6CFDF5	7697 556358	OLGA KUZNECOVA	{"phone": "+70437422542"}
0005432170273	6CFDF5	2149 032540	MIKHAIL PETROV	{"email": "mikhail.petrov-20101964@postgrespro.ru", "phone": "+70344861239"}
0005432170274	778925	8085 561684	DANILA DAVYDOV	{"phone": "+70810229122"}
0005432170275	59057C	2081 884452	ALEKSEY MAKAROV	{"email": "makarovaleksey04031976@postgrespro.ru", "phone": "+70396146047"}
0005432170276	CA4BE4	9546 437212	VALENTINA SERGEEVA	{"phone": "+70482124512"}
0005432170277	4F1DCD	1412 067589	ALINA NIKOLAEVA	{"phone": "+70115010704"}
0005432170278	58BBB1	6415 051678	IRINA FILIPPOVA	{"phone": "+70263828454"}
0005432170279	58BBB1	3907 502112	SERGEY KUZNECOV	{"email": "kuznecovsergey1965@postgrespro.ru", "phone": "+70208184219"}
0005432170280	AEEAE4	8260 817844	ILMIRA ALEKSEEVA	{"phone": "+70468526547"}
0005432170281	AEEAE4	6095 144455	ALEKSANDR VLASOV	{"email": "a_vlasov_15051968@postgrespro.ru", "phone": "+70151340987"}
0005432170282	8ABFC0	0383 286482	MARIYA ERMAKOVA	{"email": "mariya.ermakova-1962@postgrespro.ru", "phone": "+70676092241"}
0005432170283	8ABFC0	2627 242245	DMITRIY NAZAROV	{"email": "dmitriynazarov.121975@postgrespro.ru", "phone": "+70289680890"}
0005432170284	8ABFC0	4266 983563	ALEKSEY ALEKSEEV	{"phone": "+70877873733"}
0005432170285	7E36FF	1394 502399	ANTON KUZMIN	{"email": "a.kuzmin.1961@postgrespro.ru", "phone": "+70776379183"}
0005432170286	D45EEE	0404 371678	EVGENIY ALEKSEEV	{"phone": "+70786395324"}
0005432170287	9443ED	6026 480753	ZUKHRA KARPOVA	{"phone": "+70818446597"}
0005432170288	EFE0CC	8675 584060	ALEKSANDR MARTYNOV	{"email": "martynov_aleksandr_1969@postgrespro.ru", "phone": "+70551270927"}
0005432170289	BE22D8	6562 948606	OLGA ZAKHAROVA	{"email": "olga_zakharova-18071974@postgrespro.ru", "phone": "+70100884329"}
0005432170290	A9600F	2901 805517	MIKHAIL MOROZOV	{"email": "morozovm-14041966@postgrespro.ru", "phone": "+70633039037"}
0005432170291	7FB3FD	5685 056290	MAKSIM CHERNOV	{"phone": "+70394599842"}
0005432170292	354C9B	7433 477214	OKSANA SOROKINA	{"phone": "+70976614819"}
0005432170293	614F1F	4318 376727	VALENTINA POPOVA	{"email": "vpopova_1971@postgrespro.ru", "phone": "+70644904466"}
0005432170294	223ABE	5086 222218	NATALIYA GAVRILOVA	{"phone": "+70854150783"}
0005432170295	E36C14	7809 820114	OLGA STEPANOVA	{"phone": "+70412896496"}
0005432170296	E36C14	2845 462986	ALISHER YAKOVLEV	{"email": "ayakovlev-03011984@postgrespro.ru", "phone": "+70471156450"}
0005432170297	3C3BDF	3046 851029	ALEKSANDR MELNIKOV	{"email": "a-melnikov021983@postgrespro.ru", "phone": "+70182529979"}
0005432170298	63519A	2677 169508	NATALYA TIMOFEEVA	{"email": "natalya.timofeeva071980@postgrespro.ru", "phone": "+70882777001"}
0005432170299	41470D	4395 958593	ANASTASIYA SOROKINA	{"phone": "+70287087899"}
0005432170300	2E38DA	2110 222168	ANATOLIY OSIPOV	{"email": "osipov-anatoliy_29121982@postgrespro.ru", "phone": "+70078607832"}
0005432170301	AA1569	7058 424787	RAISA ORLOVA	{"email": "orlova_r_1974@postgrespro.ru", "phone": "+70391400022"}
0005432170302	AA1569	0675 740393	EKATERINA MOISEEVA	{"phone": "+70525528632"}
0005432170303	F87DAA	3392 013973	VALENTINA FILIPPOVA	{"email": "filippovavalentina.25051977@postgrespro.ru", "phone": "+70723569121"}
0005432170304	F87DAA	1776 332582	VIKTOR DAVYDOV	{"email": "viktor_davydov1976@postgrespro.ru", "phone": "+70210503201"}
0005432170305	7D5A0F	3507 629216	VADIM IVANOV	{"email": "ivanovvadim.081965@postgrespro.ru", "phone": "+70288510708"}
0005432170306	AD5637	1848 924457	GALINA PAVLOVA	{"email": "pavlovag021974@postgrespro.ru", "phone": "+70397991992"}
0005432170307	AD5637	9830 758957	ANASTASIYA KUZMINA	{"email": "kuzminaa.041970@postgrespro.ru", "phone": "+70156669830"}
0005432170308	55D9EB	8060 272999	TATYANA ANDREEVA	{"phone": "+70261318128"}
0005432170309	125E82	9900 808665	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a.05091967@postgrespro.ru", "phone": "+70567062875"}
0005432170310	A2B9D3	0653 611837	MARIYA MIRONOVA	{"email": "m.mironova_11041975@postgrespro.ru", "phone": "+70277275346"}
0005432170311	258558	7279 423525	OKSANA KONDRATEVA	{"phone": "+70438064319"}
0005432170312	D28CB4	5818 625535	DMITRIY PAVLOV	{"email": "pavlov-dmitriy_21031964@postgrespro.ru", "phone": "+70296581665"}
0005432170313	EBAC06	2582 072209	IRINA EGOROVA	{"email": "egorova-i1967@postgrespro.ru", "phone": "+70267010213"}
0005432170314	DE616E	2766 088044	EVGENIY GERASIMOV	{"email": "gerasimovevgeniy051982@postgrespro.ru", "phone": "+70187649427"}
0005432170315	34BED6	3510 600565	SERGEY STEPANOV	{"phone": "+70341049092"}
0005432170316	870BF4	7132 692372	DAMIR ORLOV	{"email": "orlovdamir1971@postgrespro.ru", "phone": "+70129131403"}
0005432170317	010477	9566 070528	VYACHESLAV IVANOV	{"phone": "+70551213300"}
0005432170318	010477	2957 106915	TATYANA KOMAROVA	{"phone": "+70247378561"}
0005432170319	590275	8095 341754	BORIS KUZNECOV	{"phone": "+70130172939"}
0005432170320	590275	7032 762394	MAKSIM ROMANOV	{"phone": "+70809000985"}
0005432170321	182D6A	0647 692633	VALENTINA AFANASEVA	{"email": "valentina_afanaseva.1968@postgrespro.ru", "phone": "+70399715753"}
0005432170322	182D6A	1783 876127	ANASTASIYA EGOROVA	{"phone": "+70292278571"}
0005432170323	714FB8	8294 943756	ZINAIDA KRASNOVA	{"phone": "+70974919837"}
0005432170324	F012F2	5796 617333	MARIYA FOMINA	{"email": "fominamariya_121972@postgrespro.ru", "phone": "+70947810596"}
0005432170325	F012F2	7693 627088	NIKOLAY VOLKOV	{"email": "volkov_nikolay_1974@postgrespro.ru", "phone": "+70384433541"}
0005432170326	291A0C	9361 481681	SEMEN MEDVEDEV	{"phone": "+70900016976"}
0005432170327	291A0C	2189 986406	VERA ZAYCEVA	{"phone": "+70189135845"}
0005432170328	CE960C	5967 713183	SVETLANA IVANOVA	{"email": "ivanova_s-041956@postgrespro.ru", "phone": "+70619104155"}
0005432170329	F5F39A	8002 779729	KARINA ANTONOVA	{"email": "karinaantonova121970@postgrespro.ru", "phone": "+70203039406"}
0005432170330	D16267	6050 498502	SERGEY PETROV	{"email": "petrov_sergey1972@postgrespro.ru", "phone": "+70554367885"}
0005432170331	D16267	1914 531311	TATYANA MAKAROVA	{"phone": "+70731800605"}
0005432170332	712B4C	7990 542502	PETR SIDOROV	{"phone": "+70899918407"}
0005432170333	D59F1F	5915 126866	VERA SOKOLOVA	{"phone": "+70842712136"}
0005432170334	D59F1F	1731 592212	YURIY IVANOV	{"phone": "+70401973104"}
0005432170335	D426C1	4105 292785	LEONID ANTONOV	{"email": "l-antonov.011973@postgrespro.ru", "phone": "+70499875887"}
0005432170336	D426C1	4987 740498	SERGEY CHERNOV	{"phone": "+70220541489"}
0005432170337	DB7884	0028 420142	NIKOLAY ANDREEV	{"email": "n.andreev-20011978@postgrespro.ru", "phone": "+70447978845"}
0005432170338	720902	9417 020546	PRASKOVYA ZAYCEVA	{"phone": "+70462632066"}
0005432170339	720902	1295 373997	ELENA IVANOVA	{"email": "ivanova-e.1972@postgrespro.ru", "phone": "+70654154074"}
0005432170340	720902	0874 779374	LYUBOV RYABOVA	{"phone": "+70195513813"}
0005432170341	E60996	4072 598499	ARTUR GUSEV	{"phone": "+70224849880"}
0005432170342	47B40C	8137 855418	ALINA SERGEEVA	{"email": "sergeevaa_01121972@postgrespro.ru", "phone": "+70214236024"}
0005432170343	953159	0786 345474	OKSANA KOZLOVA	{"email": "o.kozlova_04041967@postgrespro.ru", "phone": "+70773834651"}
0005432170344	953159	5935 060392	ALEKSANDR ISAEV	{"email": "a-isaev_14031971@postgrespro.ru", "phone": "+70241580561"}
0005432170345	FCE220	3818 464052	VIKTOR SOLOVEV	{"phone": "+70015764732"}
0005432170346	FCE220	9543 010495	ALEKSEY MOROZOV	{"phone": "+70859001992"}
0005432170347	B7790D	8584 894226	DENIS KUZNECOV	{"phone": "+70502112514"}
0005432170348	470CD2	4877 398915	ALEKSANDR ALEKSEEV	{"phone": "+70999271127"}
0005432170349	470CD2	1673 747685	LIDIYA GRISHINA	{"phone": "+70252701099"}
0005432170350	55B635	7765 665962	KIRILL PETROV	{"phone": "+70749938597"}
0005432170351	55B635	0052 289210	OLGA EFIMOVA	{"email": "o.efimova_031963@postgrespro.ru", "phone": "+70808279358"}
0005432170352	233E78	3621 302784	OLGA IVANOVA	{"phone": "+70760466635"}
0005432170353	233E78	7985 552925	TAISA KUZMINA	{"phone": "+70283193644"}
0005432170354	4EBDC8	4245 729231	EVGENIY ANDREEV	{"email": "andreev.evgeniy-1965@postgrespro.ru", "phone": "+70497540049"}
0005432170355	A804BB	9720 660201	LYUBOV NIKITINA	{"email": "nikitinal_18011979@postgrespro.ru", "phone": "+70340715630"}
0005432170356	C38A44	8177 155383	KONSTANTIN SCHERBAKOV	{"phone": "+70736320863"}
0005432170357	71774F	2705 469653	ELVIRA ANDREEVA	{"email": "e-andreeva-071975@postgrespro.ru", "phone": "+70143683300"}
0005432170358	A39C60	1812 918063	ALBINA LOGINOVA	{"email": "albinaloginova-24041975@postgrespro.ru", "phone": "+70850647865"}
0005432170359	A39C60	8686 944576	PETR DMITRIEV	{"email": "petr-dmitriev1964@postgrespro.ru", "phone": "+70214187830"}
0005432170360	A39C60	5664 045041	DANILA SOROKIN	{"email": "sorokin.danila-031978@postgrespro.ru", "phone": "+70869390313"}
0005432170361	BAFEF7	2664 549940	LARISA ZAKHAROVA	{"phone": "+70684542364"}
0005432170363	C9A6DA	1371 168568	SERGEY GUSEV	{"email": "sergeygusev.1973@postgrespro.ru", "phone": "+70572404474"}
0005432170364	FFBD68	9126 780291	LYUBOV NIKITINA	{"phone": "+70640073183"}
0005432170365	FFBD68	9320 141693	BORIS MOROZOV	{"email": "morozovboris.041967@postgrespro.ru", "phone": "+70424137853"}
0005432170366	DC5EE6	1040 466712	MARINA IVANOVA	{"phone": "+70224396312"}
0005432170367	570130	2157 406354	ALEKSEY PETROV	{"email": "a.petrov_19051980@postgrespro.ru", "phone": "+70769920350"}
0005432170368	CD055D	7576 893421	MARIYA KAZAKOVA	{"email": "kazakovamariya03091967@postgrespro.ru", "phone": "+70920126586"}
0005432170369	CD055D	9868 571486	SVETLANA ZAYCEVA	{"phone": "+70479144994"}
0005432170370	B55088	2115 136761	VLADIMIR PETROV	{"phone": "+70734760950"}
0005432170371	A46BF9	9506 005919	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya091975@postgrespro.ru", "phone": "+70305850319"}
0005432170372	37017C	3496 934270	TATYANA ZHUKOVA	{"email": "tatyanazhukova.1974@postgrespro.ru", "phone": "+70257904771"}
0005432170373	338108	0430 766445	ANTON BELOV	{"email": "anton_belov1968@postgrespro.ru", "phone": "+70814690682"}
0005432170374	338108	7904 042576	OKSANA IVANOVA	{"phone": "+70694991039"}
0005432170375	EF362B	7816 764973	NADEZHDA KUZMINA	{"email": "kuzmina-nadezhda_1977@postgrespro.ru", "phone": "+70905273007"}
0005432170376	D97A8E	9791 995679	ALEKSANDR KUZNECOV	{"email": "a.kuznecov.26101984@postgrespro.ru", "phone": "+70577405808"}
0005432170377	E4F373	6795 783191	ALEKSEY POPOV	{"email": "a_popov1977@postgrespro.ru", "phone": "+70084955429"}
0005432170378	E4F373	0257 239217	SERGEY TIMOFEEV	{"email": "sergey_timofeev121976@postgrespro.ru", "phone": "+70258650808"}
0005432170379	50D546	6575 237597	IGOR KOROLEV	{"phone": "+70554006771"}
0005432170380	50D546	5623 236343	ANASTASIYA ZOTOVA	{"phone": "+70713432594"}
0005432170381	E0F712	4531 552311	GALINA MOROZOVA	{"email": "galina-morozova.111966@postgrespro.ru", "phone": "+70933325856"}
0005432170382	4C3637	8492 126794	NIKITA DENISOV	{"email": "denisov_n1978@postgrespro.ru", "phone": "+70023327402"}
0005432170383	514357	0543 310909	LARISA IVANOVA	{"email": "ivanovalarisa_021967@postgrespro.ru", "phone": "+70000105324"}
0005432170384	A970B4	7399 530253	MARGARITA ALEKSEEVA	{"email": "alekseeva_m.031964@postgrespro.ru", "phone": "+70479587334"}
0005432170385	B7EBE1	8531 140896	LYUDMILA ZAKHAROVA	{"email": "lyudmila.zakharova-20061981@postgrespro.ru", "phone": "+70085497473"}
0005432170386	B7EBE1	1784 075841	ALEKSANDR NIKITIN	{"email": "a_nikitin_101965@postgrespro.ru", "phone": "+70367077681"}
0005432170387	43A1C5	0091 187274	IRINA DANILOVA	{"email": "danilova.i-1974@postgrespro.ru", "phone": "+70475745052"}
0005432170388	43A1C5	5821 307615	PAVEL MAKAROV	{"email": "makarov-pavel121973@postgrespro.ru", "phone": "+70126464923"}
0005432170389	22B2BA	0497 974935	IGOR CHERNOV	{"email": "i-chernov_051973@postgrespro.ru", "phone": "+70967914805"}
0005432170390	278B2E	0374 781926	POLINA GUSEVA	{"email": "polinaguseva_1974@postgrespro.ru", "phone": "+70192739770"}
0005432170391	4D2E86	2165 333942	PAVEL YAKOVLEV	{"email": "p_yakovlev-19101967@postgrespro.ru", "phone": "+70282523963"}
0005432170392	4D2E86	7875 252175	DMITRIY SIDOROV	{"phone": "+70218120671"}
0005432170393	7488D5	2858 059251	ANNA NESTEROVA	{"phone": "+70250670862"}
0005432170394	C9480D	6269 778669	ALEKSANDR SMIRNOV	{"phone": "+70831227837"}
0005432170395	C9480D	4898 540281	ZINAIDA NIKITINA	{"email": "nikitina-zinaida041973@postgrespro.ru", "phone": "+70753795951"}
0005432170396	C9480D	0023 461929	VALENTIN BORISOV	{"phone": "+70858207904"}
0005432170397	7542F4	1395 980393	VYACHESLAV KARPOV	{"email": "vyacheslav-karpov1974@postgrespro.ru", "phone": "+70746476320"}
0005432170398	7127BF	3398 120049	NINA MOROZOVA	{"email": "morozova_n21011975@postgrespro.ru", "phone": "+70612915157"}
0005432170399	7127BF	5696 463328	VALENTINA ORLOVA	{"email": "valentina.orlova_1970@postgrespro.ru", "phone": "+70630710401"}
0005432170400	7127BF	9041 816340	EVGENIY MELNIKOV	{"email": "evgeniy.melnikov1963@postgrespro.ru", "phone": "+70845417209"}
0005432170401	77C1A1	2261 669812	PAVEL MEDVEDEV	{"phone": "+70109314844"}
0005432170402	77C1A1	2830 171886	ELENA KOZLOVA	{"email": "kozlova-e-06041969@postgrespro.ru", "phone": "+70544321779"}
0005432170403	77C1A1	0833 281698	ALEKSEY EGOROV	{"phone": "+70125364943"}
0005432170404	488ACA	2834 518430	VALENTINA MOROZOVA	{"email": "valentina.morozova.121980@postgrespro.ru", "phone": "+70085214304"}
0005432170405	6D171E	5318 480853	VIKTOR EGOROV	{"email": "v_egorov.071970@postgrespro.ru", "phone": "+70682337137"}
0005432170406	65FAD6	2616 007336	OLEG ANDREEV	{"email": "olegandreev.28081961@postgrespro.ru", "phone": "+70724321165"}
0005432170407	71EA67	3609 919960	VENERA MAKAROVA	{"email": "v_makarova-031973@postgrespro.ru", "phone": "+70555741626"}
0005432170408	71EA67	2238 440303	YANA LEBEDEVA	{"email": "lebedeva-y1967@postgrespro.ru", "phone": "+70483609485"}
0005432170409	878B7E	4818 761389	NIKITA POPOV	{"email": "popov.nikita1974@postgrespro.ru", "phone": "+70407605937"}
0005432170410	282912	2911 123658	BULAT KUZNECOV	{"email": "kuznecov-b.17031973@postgrespro.ru", "phone": "+70895016506"}
0005432170411	282912	6020 687493	IRINA ZAKHAROVA	{"email": "i-zakharova_011977@postgrespro.ru", "phone": "+70200747173"}
0005432170412	282912	9928 336091	ANASTASIYA MIRONOVA	{"phone": "+70042961752"}
0005432170413	114E4C	4605 960525	VALENTINA NIKOLAEVA	{"phone": "+70669127922"}
0005432170414	EEE021	6655 020490	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_1972@postgrespro.ru", "phone": "+70491864996"}
0005432170415	2705EA	4994 076118	IRINA ILINA	{"email": "i_ilina1964@postgrespro.ru", "phone": "+70846096684"}
0005432170416	882D6B	1723 384570	EVGENIY IVANOV	{"phone": "+70710280702"}
0005432170417	93CCA5	4316 951967	ELENA SMIRNOVA	{"phone": "+70503385418"}
0005432170418	78136F	5595 632778	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_1972@postgrespro.ru", "phone": "+70556986705"}
0005432170419	78136F	8609 506318	MIROSLAV KUZNECOV	{"phone": "+70743994871"}
0005432170420	CF2BD1	6315 342948	ANATOLIY ALEKSANDROV	{"email": "aleksandrov.a20011977@postgrespro.ru", "phone": "+70640802709"}
0005432170421	C3AE06	0983 258837	ILSHAT TIKHONOV	{"phone": "+70859625456"}
0005432170422	EC5E7F	3333 051892	LYUDMILA KONDRATEVA	{"email": "lyudmila.kondrateva_27031977@postgrespro.ru", "phone": "+70405218334"}
0005432170423	B1D251	8668 994032	MAKSIM SAVELEV	{"email": "savelev.maksim.1967@postgrespro.ru", "phone": "+70132081950"}
0005432170424	C03163	9830 634401	NELLI FILIPPOVA	{"phone": "+70304381440"}
0005432170425	A686AC	4040 171456	ELENA AKIMOVA	{"phone": "+70225161861"}
0005432170426	A686AC	1551 491829	NINA GERASIMOVA	{"email": "ninagerasimova101971@postgrespro.ru", "phone": "+70306794317"}
0005432170427	92B261	1352 622759	NINA RODIONOVA	{"phone": "+70526454352"}
0005432170428	26F991	0875 651651	ANNA NOVIKOVA	{"email": "novikova.a061972@postgrespro.ru", "phone": "+70346134501"}
0005432170429	26F991	4017 944911	MIKHAIL MOISEEV	{"email": "m.moiseev-071977@postgrespro.ru", "phone": "+70464126589"}
0005432170430	26F991	5805 834521	NADEZHDA IVANOVA	{"phone": "+70747802238"}
0005432170431	5BE6A0	0343 931632	ELENA KOROLEVA	{"phone": "+70318260796"}
0005432170432	636305	8148 071414	YURIY TIKHONOV	{"phone": "+70551336669"}
0005432170433	AB176D	6157 101903	IGOR KOZLOV	{"phone": "+70679073473"}
0005432170434	C82B43	5849 417829	MARIYA SERGEEVA	{"phone": "+70146136152"}
0005432170435	5CFA85	5895 082821	VALENTINA KARPOVA	{"email": "v.karpova_101975@postgrespro.ru", "phone": "+70041850432"}
0005432170436	5D2125	4255 120490	VASILIY VASILEV	{"phone": "+70708900562"}
0005432170437	1390CD	6002 297572	ALEKSEY MAKAROV	{"email": "makarov-a-041974@postgrespro.ru", "phone": "+70068666134"}
0005432170438	1CD018	1162 205519	GALINA KAZAKOVA	{"email": "galina_kazakova.1973@postgrespro.ru", "phone": "+70314796807"}
0005432170439	1CD018	7173 800324	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.16021980@postgrespro.ru", "phone": "+70918230299"}
0005432170440	1CD018	7528 619589	RIMMA ISAEVA	{"email": "r-isaeva021978@postgrespro.ru", "phone": "+70503793051"}
0005432170441	9FEF65	7423 294786	EVGENIY POPOV	{"email": "evgeniy.popov.29031961@postgrespro.ru", "phone": "+70574507989"}
0005432170442	4DB6BA	7142 714741	VLADISLAV FILIPPOV	{"phone": "+70966787034"}
0005432170443	1E8D55	3543 113470	IRINA FOMINA	{"email": "fominairina061967@postgrespro.ru", "phone": "+70465948812"}
0005432170444	BC4483	0967 601190	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov101975@postgrespro.ru", "phone": "+70917746383"}
0005432170445	BC4483	7129 347898	GRIGORIY BONDARENKO	{"email": "grigoriy_bondarenko-091974@postgrespro.ru", "phone": "+70995496167"}
0005432170446	275DBD	7267 139289	RAISA KUZNECOVA	{"email": "raisa_kuznecova_1979@postgrespro.ru", "phone": "+70041101623"}
0005432170447	275DBD	8634 992847	RAISA GAVRILOVA	{"email": "r-gavrilova1989@postgrespro.ru", "phone": "+70271964264"}
0005432170448	7A21F7	5281 208448	AMIR ANTONOV	{"email": "a.antonov-06121966@postgrespro.ru", "phone": "+70480629575"}
0005432170449	7A21F7	4654 599987	IRINA ZHUKOVA	{"phone": "+70739319892"}
0005432170450	9710C4	9994 645298	SERAFIMA IVANOVA	{"phone": "+70225594250"}
0005432170451	9710C4	5280 992895	ALINA NIKIFOROVA	{"phone": "+70923251804"}
0005432170452	9710C4	7370 210967	OLESYA FROLOVA	{"email": "olesyafrolova.071968@postgrespro.ru", "phone": "+70080369208"}
0005432170453	7550B3	8146 256322	VASILIY SMIRNOV	{"email": "vsmirnov101973@postgrespro.ru", "phone": "+70216769630"}
0005432170454	7AE112	6676 913409	MARIYA FILIPPOVA	{"email": "mariya.filippova.1969@postgrespro.ru", "phone": "+70113228259"}
0005432170455	2E7C1B	3627 057057	ALEKSANDR KUZMIN	{"phone": "+70241905521"}
0005432170456	2E7C1B	4567 272260	LYUDMILA FADEEVA	{"email": "fadeeva-l.1964@postgrespro.ru", "phone": "+70194215973"}
0005432170457	6CC895	6835 905129	VLADISLAV MOROZOV	{"phone": "+70217370255"}
0005432170458	8E1F61	7747 020162	VLADIMIR KULIKOV	{"phone": "+70742189681"}
0005432170459	8E1F61	7472 815204	VASILIY MOROZOV	{"email": "morozov.v_20031972@postgrespro.ru", "phone": "+70127359789"}
0005432170460	3905D1	9081 957306	ELENA NIKITINA	{"phone": "+70401603345"}
0005432170461	3905D1	9583 836300	ANATOLIY KUZMIN	{"email": "kuzmin_anatoliy-04051968@postgrespro.ru", "phone": "+70139596358"}
0005432170462	3905D1	5653 477223	GALINA MIKHAYLOVA	{"phone": "+70807179671"}
0005432170463	6D342E	6123 510967	SVETLANA ALEKSEEVA	{"email": "alekseeva-svetlana-1964@postgrespro.ru", "phone": "+70788600847"}
0005432170464	EFF1BF	1633 731677	RAISA NESTEROVA	{"email": "raisa.nesterova.31071967@postgrespro.ru", "phone": "+70566255287"}
0005432170465	5864E2	6372 620636	KSENIYA VOLKOVA	{"email": "kseniya.volkova_1971@postgrespro.ru", "phone": "+70009663615"}
0005432170466	BF2DA4	2551 481776	IRINA FEDOROVA	{"phone": "+70312277132"}
0005432170467	E8D734	7462 901590	EKATERINA SERGEEVA	{"email": "ekaterina_sergeeva.29011982@postgrespro.ru", "phone": "+70505921824"}
0005432170468	E8D734	6120 770765	MARINA NESTEROVA	{"phone": "+70639342974"}
0005432170469	1ADC12	8554 275133	VIKTOR SERGEEV	{"email": "sergeev_viktor1981@postgrespro.ru", "phone": "+70780113514"}
0005432170470	889165	9993 574474	DMITRIY KUZNECOV	{"phone": "+70128242338"}
0005432170471	2D8CD9	0690 511477	NATALYA IVANOVA	{"phone": "+70680371645"}
0005432170472	195791	3482 143853	VIKTOR SERGEEV	{"email": "sergeevviktor-14081981@postgrespro.ru", "phone": "+70040033121"}
0005432170473	64F001	3883 988806	ANNA BORISOVA	{"email": "borisova.anna_1972@postgrespro.ru", "phone": "+70955064573"}
0005432170474	64F001	1392 272681	SVETLANA ZOTOVA	{"email": "zotova.s-02021972@postgrespro.ru", "phone": "+70269716325"}
0005432170475	802CB4	9281 572105	OLGA ERMAKOVA	{"email": "ermakovao.121973@postgrespro.ru", "phone": "+70044297118"}
0005432170476	3DDDAF	8914 182603	GULNARA KOVALEVA	{"email": "kovaleva-gulnara.13051969@postgrespro.ru", "phone": "+70290484784"}
0005432170477	2E7DF8	8478 056197	ALENA KAZAKOVA	{"phone": "+70121998572"}
0005432170478	609AEE	0514 186709	OLGA MASLOVA	{"phone": "+70169191735"}
0005432170479	609AEE	6849 638268	NAIL MELNIKOV	{"email": "melnikovn-1968@postgrespro.ru", "phone": "+70170191874"}
0005432170480	609AEE	8571 159191	VITALIY NAUMOV	{"phone": "+70096438927"}
0005432170481	84428C	4668 136202	VLADIMIR DMITRIEV	{"email": "vdmitriev_26091967@postgrespro.ru", "phone": "+70477466334"}
0005432170482	734D2C	8642 059716	ANDREY FROLOV	{"email": "andrey_frolov12101989@postgrespro.ru", "phone": "+70054791256"}
0005432170483	5F3045	9339 961526	MARINA SEMENOVA	{"email": "semenova_marina.041977@postgrespro.ru", "phone": "+70178082403"}
0005432170484	6B5E98	9285 347990	VLADIMIR NAZAROV	{"email": "vladimir.nazarov-09091978@postgrespro.ru", "phone": "+70488223190"}
0005432170485	35F550	3431 229950	ELENA BELOVA	{"phone": "+70290991988"}
0005432170486	35F550	4562 022058	VIKTOR KUZMIN	{"email": "kuzmin-viktor.1976@postgrespro.ru", "phone": "+70573555732"}
0005432170487	0A50F7	3736 431336	GENNADIY NAZAROV	{"email": "gnazarov_1969@postgrespro.ru", "phone": "+70897190589"}
0005432170488	68B2B7	2195 454891	ANASTASIYA VASILEVA	{"phone": "+70999763506"}
0005432170489	D11BDB	0061 229441	OLGA ZOTOVA	{"phone": "+70513048226"}
0005432170490	9DC694	2131 044435	VIKTORIYA MIRONOVA	{"email": "mironova.v121961@postgrespro.ru", "phone": "+70680735650"}
0005432170491	61BA96	9475 722614	LYUDMILA DENISOVA	{"phone": "+70434676820"}
0005432170492	E472B4	7069 455697	MATVEY BELOV	{"phone": "+70305008993"}
0005432170493	E472B4	0933 558476	IVAN FOMIN	{"phone": "+70170266211"}
0005432170494	E472B4	4400 699755	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya-08041974@postgrespro.ru", "phone": "+70758410100"}
0005432170495	2048F8	2877 820712	TATYANA NAUMOVA	{"email": "naumova_t.101988@postgrespro.ru", "phone": "+70031625755"}
0005432170496	6F2C35	0364 363477	IVAN SAVELEV	{"phone": "+70921825370"}
0005432170497	4FE20C	2033 781152	ANATOLIY SIDOROV	{"email": "a_sidorov-01011980@postgrespro.ru", "phone": "+70456557600"}
0005432170498	4FE20C	4647 133318	ALEKSANDR SMIRNOV	{"phone": "+70181743694"}
0005432170499	09F024	5448 308850	ALEKSEY ANTONOV	{"email": "antonov_aleksey101972@postgrespro.ru", "phone": "+70662966916"}
0005432170500	E8FF75	3601 631281	VALENTINA RODIONOVA	{"email": "rodionova.v.22061976@postgrespro.ru", "phone": "+70001119696"}
0005432170501	4F2FDB	6122 849001	IVAN KRASNOV	{"phone": "+70159687029"}
0005432170502	AA3590	9244 145016	ELENA BOGDANOVA	{"phone": "+70892958441"}
0005432170503	2C2081	1924 207068	VLADIMIR TIKHONOV	{"phone": "+70046888965"}
0005432170504	86ACBA	0705 110426	KLAVDIYA DANILOVA	{"phone": "+70087418545"}
0005432170505	4EF9FF	4368 646355	NADEZHDA ORLOVA	{"email": "orlova-nadezhda111970@postgrespro.ru", "phone": "+70343622527"}
0005432170506	30AD9A	8024 814563	ELMIRA MOROZOVA	{"phone": "+70698671390"}
0005432170507	30AD9A	8012 697726	OLGA KOROLEVA	{"phone": "+70409146934"}
0005432170508	65447A	5612 801850	ANDREY ALEKSANDROV	{"email": "andreyaleksandrov_061980@postgrespro.ru", "phone": "+70480646836"}
0005432170509	098409	6358 332533	VLADIMIR GRIGOREV	{"email": "grigorev_vladimir_1975@postgrespro.ru", "phone": "+70411117602"}
0005432170510	8E75C2	1968 601109	ALEKSEY RODIONOV	{"phone": "+70796164084"}
0005432170511	90198D	6471 765753	IRINA GORBUNOVA	{"email": "irinagorbunova.021969@postgrespro.ru", "phone": "+70203073330"}
0005432170512	90198D	4989 965709	GALINA KOZLOVA	{"phone": "+70856109063"}
0005432170513	E8C87A	8401 539686	SVETLANA MARTYNOVA	{"phone": "+70110770995"}
0005432170514	B9197F	5770 751831	RAISA ARKHIPOVA	{"email": "arkhipova-r-051962@postgrespro.ru", "phone": "+70233706031"}
0005432170515	B9197F	7262 504513	ELENA MELNIKOVA	{"email": "melnikova.e.24061973@postgrespro.ru", "phone": "+70490179659"}
0005432170516	032EAF	4741 984615	VALERIYA ANISIMOVA	{"email": "anisimovavaleriya_1971@postgrespro.ru", "phone": "+70403549358"}
0005432170517	118076	5526 561112	VYACHESLAV MOISEEV	{"phone": "+70850347761"}
0005432170518	D56CCE	0773 883158	MARIYA STEPANOVA	{"email": "stepanova_mariya-071971@postgrespro.ru", "phone": "+70527043101"}
0005432170519	D56CCE	5658 831752	IRINA KOMAROVA	{"phone": "+70277050296"}
0005432170520	D6C270	1108 658120	SOFIYA ZAYCEVA	{"email": "sofiya.zayceva-19091970@postgrespro.ru", "phone": "+70957316122"}
0005432170521	D6C270	9048 666251	ALEKSANDR FILIPPOV	{"email": "a-filippov_01081962@postgrespro.ru", "phone": "+70836952862"}
0005432170522	2097FD	1136 511254	IGOR VOROBEV	{"phone": "+70521493481"}
0005432170523	4F6D44	1428 381002	IVAN PAVLOV	{"phone": "+70817332186"}
0005432170524	A7B019	7216 467491	YULIYA MAKAROVA	{"phone": "+70760268854"}
0005432170525	A7B019	5843 519029	IRINA KRASNOVA	{"email": "irina-krasnova1979@postgrespro.ru", "phone": "+70402047914"}
0005432170526	3ACAC3	7539 262657	ALINA BELOVA	{"email": "abelova.111956@postgrespro.ru", "phone": "+70846139355"}
0005432170527	A0BFAF	3120 817394	YULIYA FEDOROVA	{"phone": "+70840997451"}
0005432170528	02F7DD	1689 007442	NATALYA AFANASEVA	{"phone": "+70393482272"}
0005432170529	5E9EB3	7917 596627	MIKHAIL TIMOFEEV	{"email": "timofeev.mikhail-111975@postgrespro.ru", "phone": "+70099576197"}
0005432170530	4C8464	9005 792375	MARIYA ROMANOVA	{"phone": "+70532331452"}
0005432170531	4C8464	2869 236680	EKATERINA EGOROVA	{"phone": "+70202311852"}
0005432170532	95A436	7744 857762	SERGEY ANDREEV	{"phone": "+70694515947"}
0005432170533	95A436	4401 577189	LYUBOV MIKHAYLOVA	{"email": "l-mikhaylova_11101968@postgrespro.ru", "phone": "+70532495579"}
0005432170534	3CD1BF	2857 942222	ALEKSANDR KONOVALOV	{"email": "konovalov-aleksandr_101986@postgrespro.ru", "phone": "+70012272224"}
0005432170535	C303D0	6327 526116	VASILIY SCHERBAKOV	{"phone": "+70057031467"}
0005432170536	96324A	0741 426451	RIMMA BELYAEVA	{"email": "belyaeva_rimma-06071978@postgrespro.ru", "phone": "+70167556982"}
0005432170537	96324A	5912 790465	SERGEY KARPOV	{"email": "karpov-sergey061980@postgrespro.ru", "phone": "+70984716668"}
0005432170538	E211C9	6993 929031	ALEKSANDR KUZNECOV	{"phone": "+70850846277"}
0005432170539	8E0874	4298 497137	EVGENIYA ZAYCEVA	{"phone": "+70965493565"}
0005432170540	32CD55	1180 049942	LEONID GUSEV	{"email": "leonid_gusev09041969@postgrespro.ru", "phone": "+70617379771"}
0005432170541	80F059	2632 551419	EVGENIY TIMOFEEV	{"email": "timofeev.evgeniy.05011969@postgrespro.ru", "phone": "+70320158768"}
0005432170542	249950	6021 890007	REGINA VASILEVA	{"email": "r_vasileva-091981@postgrespro.ru", "phone": "+70776520102"}
0005432170543	249950	9180 024518	YAROSLAV POPOV	{"email": "popov.yaroslav1979@postgrespro.ru", "phone": "+70763964854"}
0005432170544	C849B8	6260 438365	NATALYA MOROZOVA	{"email": "morozova-n-1975@postgrespro.ru", "phone": "+70733808686"}
0005432170545	C849B8	8252 008471	IRINA BORISOVA	{"phone": "+70146213014"}
0005432170546	86F9F8	8429 250217	VLADIMIR SCHERBAKOV	{"email": "scherbakovvladimir1974@postgrespro.ru", "phone": "+70518361905"}
0005432170547	86F9F8	4051 975006	VLADISLAV FEDOROV	{"email": "v_fedorov-1968@postgrespro.ru", "phone": "+70854536828"}
0005432170548	89D69F	1439 798152	MARINA MAKAROVA	{"email": "mmakarova-051971@postgrespro.ru", "phone": "+70221809390"}
0005432170549	C53E74	2365 534871	ALEKSANDR KONOVALOV	{"phone": "+70404014427"}
0005432170550	702745	4922 463721	NINA POTAPOVA	{"email": "potapova-n_1966@postgrespro.ru", "phone": "+70077497497"}
0005432170551	702745	8507 027992	VERA ILINA	{"email": "ilinavera_1973@postgrespro.ru", "phone": "+70076756157"}
0005432170552	A8410F	9265 858957	KLARA NESTEROVA	{"phone": "+70360909698"}
0005432170553	A8410F	3248 027931	TAMARA VOLKOVA	{"phone": "+70739564633"}
0005432170554	E22A3D	5655 679966	DMITRIY ZHURAVLEV	{"phone": "+70607360755"}
0005432170555	0942BA	3673 889082	VLADIMIR GUSEV	{"phone": "+70961568266"}
0005432170556	0942BA	9253 402066	FAINA PETROVA	{"phone": "+70143603662"}
0005432170557	166FAF	2587 883250	VIKTOR VOLKOV	{"phone": "+70625782196"}
0005432170558	166FAF	4490 118924	VIKTORIYA NAZAROVA	{"phone": "+70212215596"}
0005432170559	9ACB1F	8503 011605	VIKTOR NAZAROV	{"email": "nazarov-viktor-101970@postgrespro.ru", "phone": "+70874377991"}
0005432170560	750B33	7970 530794	DMITRIY FROLOV	{"email": "dfrolov_1977@postgrespro.ru", "phone": "+70206521857"}
0005432170561	E67C8D	3384 469187	VERONIKA PETROVA	{"email": "petrovaveronika_07041977@postgrespro.ru", "phone": "+70619577276"}
0005432170562	BFCC73	5760 883093	KSENIYA YUDINA	{"email": "kseniya_yudina-1963@postgrespro.ru", "phone": "+70029756190"}
0005432170563	19ACE9	4462 531045	MAKSIM IVANOV	{"phone": "+70566999332"}
0005432170564	6EE78A	1105 071219	ALEKSANDR ABRAMOV	{"phone": "+70694308144"}
0005432170565	8CA973	9420 957414	ALEKSEY IVANOV	{"phone": "+70880542036"}
0005432170566	2906F1	4797 023205	ARTUR KOZLOV	{"email": "kozlov_a-1964@postgrespro.ru", "phone": "+70576321633"}
0005432170567	F9AE8A	7004 756906	STEPAN IVANOV	{"email": "ivanov.s111972@postgrespro.ru", "phone": "+70776406449"}
0005432170568	B9A2C3	1965 031256	IRINA BOGDANOVA	{"phone": "+70861606208"}
0005432170569	D3DEF5	9786 346292	MARINA KOLESNIKOVA	{"email": "marina-kolesnikova_14091964@postgrespro.ru", "phone": "+70667839817"}
0005432170570	ED1F8F	0702 168292	VALENTINA GUSEVA	{"phone": "+70999809425"}
0005432170571	ED1F8F	0249 509851	VALERIY KUZMIN	{"email": "v.kuzmin.011968@postgrespro.ru", "phone": "+70344297964"}
0005432170572	E71966	7703 011989	EKATERINA ERMAKOVA	{"phone": "+70628840224"}
0005432170573	FF0E19	6875 099283	MARIYA MATVEEVA	{"phone": "+70414805489"}
0005432170574	859929	2186 710413	SERGEY STEPANOV	{"email": "s-stepanov_05081963@postgrespro.ru", "phone": "+70582584796"}
0005432170575	0A5F04	8115 874613	MARIYA LEBEDEVA	{"email": "mariya_lebedeva-1970@postgrespro.ru", "phone": "+70566373935"}
0005432170576	0A5F04	5323 763937	NIKITA GUSEV	{"phone": "+70547877553"}
0005432170577	640330	5777 289730	SVETLANA POLYAKOVA	{"email": "polyakovas-29041978@postgrespro.ru", "phone": "+70814123244"}
0005432170578	640330	3172 734312	TATYANA POTAPOVA	{"phone": "+70468592974"}
0005432170579	17F029	8418 714618	MARIYA LUKYANOVA	{"phone": "+70599460915"}
0005432170580	17F029	6821 623412	DARYA EFIMOVA	{"email": "defimova_121983@postgrespro.ru", "phone": "+70898964841"}
0005432170581	5B6335	0457 311526	SERGEY KOZLOV	{"email": "sergey_kozlov-061973@postgrespro.ru", "phone": "+70149573146"}
0005432170582	3DAE82	4356 678959	VYACHESLAV ALEKSEEV	{"phone": "+70992066295"}
0005432170583	DA48D9	8328 662156	DMITRIY IVANOV	{"email": "ivanovdmitriy_05111971@postgrespro.ru", "phone": "+70883588714"}
0005432170584	DA48D9	4293 744382	OLEG BONDARENKO	{"phone": "+70202599628"}
0005432170585	DA48D9	6469 027854	YURIY GERASIMOV	{"email": "yuriy_gerasimov_1979@postgrespro.ru", "phone": "+70182075389"}
0005432170586	19D3DE	4582 098073	EKATERINA SOKOLOVA	{"phone": "+70172238134"}
0005432181319	61CA7B	0831 591001	MARIYA KISELEVA	{"phone": "+70272622089"}
0005432181320	61CA7B	9022 817652	IRINA PETROVA	{"email": "irina-petrova_09111971@postgrespro.ru", "phone": "+70126447505"}
0005432181321	DE33FE	7263 472304	TATYANA GUSEVA	{"email": "guseva-tatyana_121969@postgrespro.ru", "phone": "+70017688674"}
0005432181322	DF5D56	8513 388006	ASKAR GERASIMOV	{"email": "gerasimovaskar031975@postgrespro.ru", "phone": "+70481232816"}
0005432181323	1AB1C4	6698 130713	VIKTORIYA PETROVA	{"email": "v-petrova091961@postgrespro.ru", "phone": "+70402303687"}
0005432181324	636114	2331 382300	NATALIYA ZAKHAROVA	{"email": "zakharova_n_111966@postgrespro.ru", "phone": "+70440069049"}
0005432181325	D6F975	2870 743131	YURIY KOROLEV	{"phone": "+70041381926"}
0005432181326	C74834	3321 431735	ALEKSANDR IVANOV	{"phone": "+70118730679"}
0005432181327	9B8B52	6114 650817	ZHANNA LOGINOVA	{"email": "zhanna.loginova.051971@postgrespro.ru", "phone": "+70896558366"}
0005432181328	71398E	2891 406740	MIKHAIL MATVEEV	{"email": "matveev-m-02031978@postgrespro.ru", "phone": "+70534124455"}
0005432181329	71398E	5620 523784	YURIY POPOV	{"email": "popovy.11121973@postgrespro.ru", "phone": "+70913892383"}
0005432181330	977819	4912 380574	YULIYA FADEEVA	{"phone": "+70636646518"}
0005432181331	977819	1251 735204	ANATOLIY FROLOV	{"phone": "+70822658472"}
0005432181332	CC0A34	8595 127153	EVGENIY ILIN	{"phone": "+70304016272"}
0005432181333	CC0A34	3672 469780	SERGEY MOROZOV	{"phone": "+70975029625"}
0005432181334	323EA6	0596 945766	VALENTINA KOZLOVA	{"phone": "+70825613898"}
0005432181335	323EA6	4161 778516	ALEKSANDR MARTYNOV	{"phone": "+70912454977"}
0005432181336	CBFD97	7917 769504	NIKOLAY GORBUNOV	{"email": "gorbunov-n-041967@postgrespro.ru", "phone": "+70406316185"}
0005432181337	CC906E	0877 706465	MAKSIM FROLOV	{"email": "m-frolov.30031972@postgrespro.ru", "phone": "+70115892031"}
0005432181338	12F2AE	5624 906458	SERGEY KUZNECOV	{"phone": "+70112492985"}
0005432181339	12F2AE	8046 752599	NATALYA FILIPPOVA	{"email": "filippovan.111981@postgrespro.ru", "phone": "+70126117902"}
0005432181340	12F2AE	6918 669870	NINA ZAKHAROVA	{"phone": "+70732862178"}
0005432181341	471B22	0579 332162	TATYANA PETROVA	{"phone": "+70885009989"}
0005432181342	D4E9AC	0500 063862	IGOR KISELEV	{"phone": "+70637097018"}
0005432181343	D4E9AC	8629 267698	VLADISLAV SAVELEV	{"email": "savelev.vladislav071974@postgrespro.ru", "phone": "+70868668057"}
0005432181344	B631E6	1070 586355	DENIS MELNIKOV	{"phone": "+70874631388"}
0005432181345	8858D1	7241 153262	PAVEL NOVIKOV	{"phone": "+70968717417"}
0005432181346	994506	1031 045481	ANASTASIYA POTAPOVA	{"email": "potapova.a-1970@postgrespro.ru", "phone": "+70581667231"}
0005432181347	0984D7	3954 577709	ANDREY MATVEEV	{"email": "matveev-a_17041972@postgrespro.ru", "phone": "+70077532177"}
0005432181348	36F2E2	2876 260937	SERGEY VOROBEV	{"phone": "+70829220676"}
0005432181349	36F2E2	8548 072786	VALERIY KOZLOV	{"phone": "+70315546881"}
0005432181350	ABB6E6	6879 823298	ALEKSANDR TIMOFEEV	{"phone": "+70566615581"}
0005432181351	4EEB98	5682 184647	MARIYA MATVEEVA	{"phone": "+70108787239"}
0005432181352	A23C14	3035 077139	ALEKSANDR MAKAROV	{"phone": "+70958558648"}
0005432181353	A23C14	1472 619395	TATYANA SEMENOVA	{"email": "semenova-t061971@postgrespro.ru", "phone": "+70133045040"}
0005432181354	2ECEED	8744 780187	VALENTINA PAVLOVA	{"phone": "+70891107884"}
0005432181355	8D1C79	2586 726084	DMITRIY ILIN	{"email": "ilin_dmitriy_01091966@postgrespro.ru", "phone": "+70929371338"}
0005432181356	43CDD8	2044 711931	VALERIYA MAKSIMOVA	{"email": "valeriya-maksimova1964@postgrespro.ru", "phone": "+70854411121"}
0005432181357	924895	7643 962729	IRINA EGOROVA	{"email": "i_egorova1968@postgrespro.ru", "phone": "+70705994909"}
0005432181358	DFB5AA	7104 888541	IRAIDA ZHUKOVA	{"phone": "+70688926070"}
0005432181359	E23ACB	7398 903702	NATALIYA BELOVA	{"email": "nataliya_belova_1983@postgrespro.ru", "phone": "+70520132939"}
0005432181360	34FDA4	8567 917145	NATALYA BORISOVA	{"email": "borisova-n.021974@postgrespro.ru", "phone": "+70676193847"}
0005432181361	C29358	0531 969034	MAKSIM SOLOVEV	{"email": "solovevmaksim061977@postgrespro.ru", "phone": "+70228690959"}
0005432181362	C40F1E	0612 597629	ANZHELIKA MAKSIMOVA	{"email": "anzhelika_maksimova_1977@postgrespro.ru", "phone": "+70747252741"}
0005432181363	C40F1E	6412 534106	NADEZHDA VOLKOVA	{"phone": "+70486560992"}
0005432181364	11ED10	9279 066417	NATALYA ORLOVA	{"email": "natalya-orlova.111979@postgrespro.ru", "phone": "+70027456457"}
0005432181365	DE1D38	8467 129902	ANASTASIYA GORBUNOVA	{"email": "gorbunova.anastasiya1979@postgrespro.ru", "phone": "+70681377171"}
0005432181366	842201	2145 640221	ILONA DMITRIEVA	{"phone": "+70710357382"}
0005432181367	842201	1317 228833	ANDREY NAZAROV	{"email": "a.nazarov_011976@postgrespro.ru", "phone": "+70090124552"}
0005432181368	F0DE1B	1471 902838	IVAN DENISOV	{"phone": "+70868817149"}
0005432181369	F0DE1B	2288 316684	NATALYA POPOVA	{"email": "n_popova_17031978@postgrespro.ru", "phone": "+70622383576"}
0005432181370	4502B3	9555 304301	KSENIYA KUZNECOVA	{"phone": "+70449182378"}
0005432181371	477642	0792 412978	ANNA OVCHINNIKOVA	{"phone": "+70303249874"}
0005432181372	6BD1D4	6982 404035	EVGENIYA MAKAROVA	{"email": "makarova-e04011977@postgrespro.ru", "phone": "+70760329125"}
0005432181373	1E0975	5852 828338	ANTON MOISEEV	{"email": "antonmoiseev.1973@postgrespro.ru", "phone": "+70753762416"}
0005432181374	1E0975	6168 716614	EKATERINA ZAYCEVA	{"email": "ekaterina.zayceva091980@postgrespro.ru", "phone": "+70012681665"}
0005432181375	A808AF	6378 472158	VALERIY KONOVALOV	{"phone": "+70881215164"}
0005432181376	6B3392	8083 882562	IVAN ANTONOV	{"email": "ivan_antonov.1967@postgrespro.ru", "phone": "+70755625242"}
0005432181377	C2CB1F	7241 118987	ANNA NOVIKOVA	{"email": "a_novikova-16031987@postgrespro.ru", "phone": "+70272947085"}
0005432181378	9096F5	4761 133127	ELENA FADEEVA	{"email": "efadeeva1958@postgrespro.ru", "phone": "+70239938755"}
0005432181379	9096F5	1818 253151	ALINA LAZAREVA	{"email": "a_lazareva1974@postgrespro.ru", "phone": "+70247958117"}
0005432181380	4C888C	0446 427202	DENIS MOISEEV	{"email": "moiseevd.121980@postgrespro.ru", "phone": "+70954856950"}
0005432181381	185BFA	4674 608167	LYUBOV STEPANOVA	{"phone": "+70425935890"}
0005432181382	92387F	5172 336588	ELIZAVETA ALEKSANDROVA	{"email": "elizavetaaleksandrova-09101959@postgrespro.ru", "phone": "+70280366723"}
0005432181383	C90BDB	7424 149143	TATYANA GAVRILOVA	{"email": "gavrilova_t_1965@postgrespro.ru", "phone": "+70556596561"}
0005432181384	753E2C	5523 767702	VLADIMIR KISELEV	{"phone": "+70783147085"}
0005432181385	FBB7FD	5958 139832	ALEKSEY SOROKIN	{"email": "a.sorokin04061976@postgrespro.ru", "phone": "+70931348360"}
0005432181386	C4E79B	4148 915011	IVAN FEDOROV	{"email": "fedorov-ivan23011973@postgrespro.ru", "phone": "+70691575701"}
0005432181387	98480E	0569 343311	ANASTASIYA POPOVA	{"phone": "+70229937505"}
0005432181388	823103	1190 334730	DMITRIY TIMOFEEV	{"phone": "+70564372729"}
0005432181389	823103	4163 651953	ALENA KUZNECOVA	{"email": "kuznecova.a29041972@postgrespro.ru", "phone": "+70948807960"}
0005432181390	5B3052	2377 627882	OLGA MIKHAYLOVA	{"email": "mikhaylova-o-1973@postgrespro.ru", "phone": "+70593974373"}
0005432181391	7AE9A2	1341 443317	PAVEL CHERNOV	{"phone": "+70516968958"}
0005432181392	9CD725	0779 006768	GALINA MARTYNOVA	{"email": "martynova.g_15061966@postgrespro.ru", "phone": "+70545432231"}
0005432181393	9CD725	6936 091847	NAIL KOROLEV	{"email": "korolev.nail011975@postgrespro.ru", "phone": "+70453697340"}
0005432181394	4BA334	1390 675729	TAMARA SOROKINA	{"email": "tamara-sorokina_061980@postgrespro.ru", "phone": "+70598184543"}
0005432181395	4BA334	4460 834646	DMITRIY ALEKSANDROV	{"email": "aleksandrov.dmitriy_1967@postgrespro.ru", "phone": "+70140827572"}
0005432181396	0668A5	5592 908709	ANATOLIY SOLOVEV	{"phone": "+70512266886"}
0005432181397	0668A5	3836 010787	ELENA SOLOVEVA	{"phone": "+70929709396"}
0005432181398	E05198	7995 261454	VITALIY IVANOV	{"email": "v-ivanov-1975@postgrespro.ru", "phone": "+70955495545"}
0005432181399	E05198	1050 803987	LILIYA MOISEEVA	{"phone": "+70564262867"}
0005432181400	B90911	6348 517688	EKATERINA TIKHONOVA	{"phone": "+70550062148"}
0005432181401	373022	5883 628494	ALEVTINA KOZLOVA	{"phone": "+70233147614"}
0005432181402	CCD92C	0568 826699	VERA ROMANOVA	{"email": "veraromanova_091977@postgrespro.ru", "phone": "+70334827581"}
0005432181403	B2BFAC	0353 403778	VALENTINA SEMENOVA	{"phone": "+70085405258"}
0005432181792	0E338C	3476 809234	MIKHAIL MIRONOV	{"phone": "+70091478906"}
0005432181404	823B26	4396 481299	MARIYA ANISIMOVA	{"email": "anisimova_mariya13091969@postgrespro.ru", "phone": "+70220848093"}
0005432181405	823B26	3626 290642	TAMARA POPOVA	{"phone": "+70279831016"}
0005432181406	3F2EFA	9745 470331	RAISA KOZLOVA	{"email": "kozlova.r031971@postgrespro.ru", "phone": "+70398613667"}
0005432181407	D7A47C	6314 106613	VLADIMIR ZAKHAROV	{"email": "v_zakharov_07101980@postgrespro.ru", "phone": "+70635338507"}
0005432181408	7EAA97	1355 805404	NATALYA ISAEVA	{"email": "natalya-isaeva_051983@postgrespro.ru", "phone": "+70831916768"}
0005432181409	CDDE06	3665 514065	ANNA EGOROVA	{"phone": "+70881534460"}
0005432181410	2207BF	0572 352208	ALEKSANDR IVANOV	{"phone": "+70304893928"}
0005432181411	2207BF	8706 491400	NINA IVANOVA	{"phone": "+70130576572"}
0005432181412	710E2F	6975 437837	LIDIYA DENISOVA	{"email": "denisoval.051975@postgrespro.ru", "phone": "+70071986536"}
0005432181413	F7A861	6149 423180	LYUBOV NAUMOVA	{"phone": "+70438253917"}
0005432181414	F7A861	8793 018903	OLGA MELNIKOVA	{"email": "melnikova_olga-07121981@postgrespro.ru", "phone": "+70470992301"}
0005432181415	7129F7	2245 292990	ZINAIDA VASILEVA	{"phone": "+70144199655"}
0005432181416	A6D129	9378 540424	ANDREY BELOV	{"email": "a-belov_1973@postgrespro.ru", "phone": "+70441350701"}
0005432181417	4641AA	9263 204058	OLEG KOZLOV	{"phone": "+70782158835"}
0005432181418	DEDAF3	9084 964294	KLAVDIYA FOMINA	{"phone": "+70507076499"}
0005432181419	2A9F5B	0335 879362	ANATOLIY MEDVEDEV	{"phone": "+70537193586"}
0005432181420	A04ED0	4833 259790	VASILIY GUSEV	{"email": "gusev-v.051956@postgrespro.ru", "phone": "+70811936095"}
0005432181421	C716BC	8887 976920	ANASTASIYA EGOROVA	{"email": "egorovaanastasiya.01091971@postgrespro.ru", "phone": "+70110858742"}
0005432181422	150F18	8983 972703	IRINA NAUMOVA	{"phone": "+70431885759"}
0005432181423	710C0D	4604 188978	ALEKSEY CHERNOV	{"phone": "+70705744021"}
0005432181424	5E5605	9289 071104	MAKSIM MAKAROV	{"phone": "+70242417277"}
0005432181425	DC6BFF	4960 307166	TATYANA NAZAROVA	{"phone": "+70238638276"}
0005432181426	3444FE	2255 035502	SERGEY SOLOVEV	{"email": "sergeysolovev111961@postgrespro.ru", "phone": "+70423233229"}
0005432181427	B5B439	1916 652062	VERA KARPOVA	{"phone": "+70123485648"}
0005432181428	B5B439	1982 904912	ARTUR MAKAROV	{"phone": "+70054483942"}
0005432181429	A8383E	0841 578392	MIKHAIL MIRONOV	{"email": "mikhailmironov.03051972@postgrespro.ru", "phone": "+70920802904"}
0005432181430	A8383E	0176 600787	YULIYA VASILEVA	{"email": "yuliya_vasileva-27121971@postgrespro.ru", "phone": "+70704422051"}
0005432181431	12C88A	8562 336379	ALEKSANDR KOZLOV	{"phone": "+70258329649"}
0005432181432	3AA49F	6935 767911	ANATOLIY CHERNOV	{"email": "a.chernov121974@postgrespro.ru", "phone": "+70655804782"}
0005432181433	DE0305	8594 185210	SERGEY ALEKSEEV	{"phone": "+70291514258"}
0005432181434	DECCE0	1611 183669	YURIY KOZLOV	{"email": "kozlov_yuriy28061962@postgrespro.ru", "phone": "+70309078966"}
0005432181435	E951B9	9380 881922	DARYA OSIPOVA	{"phone": "+70141711546"}
0005432181436	D6D59D	7998 149887	MARINA KOROLEVA	{"phone": "+70259766547"}
0005432181437	00D5AD	4693 543040	VALENTINA FEDOROVA	{"phone": "+70663721459"}
0005432181438	B4E854	8055 009715	KONSTANTIN FROLOV	{"email": "konstantinfrolov_121969@postgrespro.ru", "phone": "+70072972479"}
0005432181439	B4E854	9212 653873	VIKTOR MELNIKOV	{"phone": "+70270924527"}
0005432181440	0DD894	2502 499396	RUMIYA VASILEVA	{"email": "vasileva_r_091969@postgrespro.ru", "phone": "+70900972478"}
0005432181441	42A31B	9277 714947	VERONIKA ALEKSEEVA	{"email": "alekseeva_veronika.121960@postgrespro.ru", "phone": "+70907963593"}
0005432181442	F0B407	9978 086277	MIKHAIL POPOV	{"email": "popov_m021976@postgrespro.ru", "phone": "+70833368444"}
0005432181443	8CDF10	3797 743683	SOFIYA ZAYCEVA	{"phone": "+70819659744"}
0005432181444	7FA0E9	3358 290052	DANIIL BELOV	{"phone": "+70323371737"}
0005432181445	7FA0E9	1832 351981	LARISA LEBEDEVA	{"phone": "+70944769131"}
0005432181446	369B7D	3667 730530	RUSTAM OSIPOV	{"phone": "+70358686049"}
0005432181447	52AC7D	8648 550352	ALEKSEY ZAYCEV	{"email": "zaycev.a_041962@postgrespro.ru", "phone": "+70210415614"}
0005432181448	9BBDB5	3815 526937	OLGA LOGINOVA	{"email": "olga_loginova.061976@postgrespro.ru", "phone": "+70756976698"}
0005432181449	BA1609	9595 426042	TATYANA POPOVA	{"phone": "+70561995975"}
0005432181450	976414	4965 055844	VLADIMIR PAVLOV	{"email": "pavlov-v_23031960@postgrespro.ru", "phone": "+70554189744"}
0005432181451	E00346	0474 861872	MARINA PAVLOVA	{"phone": "+70825705647"}
0005432181452	E00346	9115 041950	ALEKSANDR VASILEV	{"phone": "+70502161860"}
0005432181453	903FBB	6725 813372	NIKOLAY NIKOLAEV	{"phone": "+70476263762"}
0005432181454	CE9E00	7235 812264	VITALIY MAKAROV	{"email": "makarov.v-1968@postgrespro.ru", "phone": "+70252724925"}
0005432181455	CD763D	8413 370092	LYUBOV NOVIKOVA	{"email": "novikova_lyubov-1960@postgrespro.ru", "phone": "+70717282534"}
0005432181456	CD763D	1389 273225	GLEB MAKAROV	{"phone": "+70543003948"}
0005432181457	7E2E3C	3231 867564	EVGENIY ANTONOV	{"email": "evgeniy-antonov01121971@postgrespro.ru", "phone": "+70759189291"}
0005432181458	812C57	7885 159862	MIKHAIL NIKOLAEV	{"phone": "+70291356616"}
0005432181459	AD4037	2154 794170	NIKITA SMIRNOV	{"phone": "+70378817795"}
0005432181460	286ECC	8569 036377	ANATOLIY SCHERBAKOV	{"email": "a-scherbakov1977@postgrespro.ru", "phone": "+70083888932"}
0005432181461	A9E83D	6460 056845	SVETLANA SAVELEVA	{"email": "saveleva_svetlana-1970@postgrespro.ru", "phone": "+70097741918"}
0005432181462	9E41BC	1151 222845	ANASTASIYA EFIMOVA	{"phone": "+70452701280"}
0005432181463	9E8CE5	9567 940760	ANTONINA ISAEVA	{"email": "isaevaa.04121977@postgrespro.ru", "phone": "+70596351267"}
0005432181464	B2C86F	0510 186282	NINA MASLOVA	{"email": "ninamaslova091969@postgrespro.ru", "phone": "+70118017473"}
0005432181465	99644C	0468 470059	ANASTASIYA TIKHONOVA	{"email": "tikhonovaanastasiya-16041962@postgrespro.ru", "phone": "+70519966462"}
0005432181466	D5EBBA	1820 267891	ANNA IVANOVA	{"email": "ivanovaa.31051975@postgrespro.ru", "phone": "+70055795661"}
0005432181523	0350C5	4843 052292	SERGEY KONOVALOV	{"phone": "+70950650108"}
0005432181467	D5EBBA	9185 087280	LYUDMILA ILINA	{"email": "lyudmila.ilina_29111969@postgrespro.ru", "phone": "+70146025570"}
0005432181468	54FB9A	6073 100541	IGNAT FEDOTOV	{"email": "ignat_fedotov1964@postgrespro.ru", "phone": "+70910539057"}
0005432181469	54FB9A	5730 922197	ALEKSANDR IVANOV	{"email": "ivanov_a_12061977@postgrespro.ru", "phone": "+70001278974"}
0005432181470	B004F8	1105 790741	NATALYA NIKIFOROVA	{"phone": "+70517396365"}
0005432181471	B004F8	7490 840775	ALEKSANDR MATVEEV	{"email": "amatveev1964@postgrespro.ru", "phone": "+70910412675"}
0005432181472	B004F8	6477 318573	VLADIMIR KUZNECOV	{"email": "kuznecov_v-1964@postgrespro.ru", "phone": "+70114602627"}
0005432181473	D672D6	6841 759850	PAVEL STEPANOV	{"phone": "+70012059501"}
0005432181474	D672D6	7257 286786	ELENA IVANOVA	{"email": "elena_ivanova_25031972@postgrespro.ru", "phone": "+70354001402"}
0005432181475	D3AD8B	1317 784601	VERA ZAKHAROVA	{"phone": "+70141363655"}
0005432181476	325EAC	4329 451222	ANATOLIY OSIPOV	{"email": "anatoliy.osipov.031963@postgrespro.ru", "phone": "+70373136624"}
0005432181477	2DB28C	2537 056013	TATYANA VOLKOVA	{"phone": "+70646165757"}
0005432181478	2DB28C	2933 931767	TATYANA PAVLOVA	{"email": "tpavlova.1969@postgrespro.ru", "phone": "+70482658070"}
0005432181479	505262	1990 552394	VALENTIN KUZNECOV	{"email": "v_kuznecov21031978@postgrespro.ru", "phone": "+70497250835"}
0005432181480	6F7A8C	3128 337324	KAMILA YUDINA	{"phone": "+70044888796"}
0005432181481	F9818B	0457 836351	OLGA MAKAROVA	{"phone": "+70989918803"}
0005432181482	F967D1	0145 367820	YURIY SOKOLOV	{"phone": "+70631667117"}
0005432181483	07AC61	2423 974238	ANDREY MELNIKOV	{"email": "melnikov-andrey_1975@postgrespro.ru", "phone": "+70939842152"}
0005432181484	07AC61	7333 764032	ANDREY FOMIN	{"phone": "+70686947444"}
0005432181485	E5C2F2	4526 632694	ALEKSANDRA MATVEEVA	{"email": "matveevaa17021966@postgrespro.ru", "phone": "+70562357420"}
0005432181486	E5C2F2	8247 923089	ALEKSANDR NAUMOV	{"email": "naumov.a_071974@postgrespro.ru", "phone": "+70305418969"}
0005432181487	44D86D	1894 658297	FARIDA SIDOROVA	{"email": "farida_sidorova_101983@postgrespro.ru", "phone": "+70564685749"}
0005432181488	44D86D	2580 419561	TIMUR GAVRILOV	{"phone": "+70801808759"}
0005432181489	A8DB03	9632 984551	NIKOLAY DMITRIEV	{"phone": "+70512265560"}
0005432181490	EBC215	0304 623844	TAMARA ALEKSEEVA	{"phone": "+70038149630"}
0005432181491	A974C5	7345 564138	SVETLANA GAVRILOVA	{"phone": "+70569665518"}
0005432181492	C7F0B1	1364 391966	NELLI PETROVA	{"phone": "+70425466701"}
0005432181493	C7F0B1	1027 206522	SERGEY GORBUNOV	{"email": "s-gorbunov-1975@postgrespro.ru", "phone": "+70178921773"}
0005432181494	C7F0B1	1756 334822	ARINA KUZNECOVA	{"email": "kuznecova.arina_1973@postgrespro.ru", "phone": "+70306040855"}
0005432181495	9EDC50	5189 559627	TAMARA NOVIKOVA	{"email": "tamaranovikova_1972@postgrespro.ru", "phone": "+70454503958"}
0005432181496	573C15	0753 281675	NELLI OSIPOVA	{"phone": "+70103344150"}
0005432181497	1847CF	3636 757363	ELENA SOROKINA	{"phone": "+70586042254"}
0005432181498	4B40A6	6030 562209	ALEKSANDR ALEKSEEV	{"phone": "+70763063389"}
0005432181499	C95462	4665 149064	EGOR TIMOFEEV	{"email": "timofeev.egor041982@postgrespro.ru", "phone": "+70254877040"}
0005432181500	81AD18	0875 125466	ALEKSANDR CHERNOV	{"email": "a_chernov_1970@postgrespro.ru", "phone": "+70562529078"}
0005432181501	81AD18	5144 382163	NIKOLAY MIRONOV	{"email": "mironov-n.1966@postgrespro.ru", "phone": "+70301464912"}
0005432181502	81AD18	0597 765966	OLGA SEMENOVA	{"email": "o-semenova.101973@postgrespro.ru", "phone": "+70674034593"}
0005432181503	39CD83	0661 402635	ALEKSANDR POPOV	{"email": "aleksandr_popov_101975@postgrespro.ru", "phone": "+70882070592"}
0005432181504	CD32A0	5646 296921	OLGA GRISHINA	{"email": "grishina.olga_1969@postgrespro.ru", "phone": "+70235378820"}
0005432181505	CD32A0	6738 427524	ALLA DMITRIEVA	{"email": "admitrieva_1967@postgrespro.ru", "phone": "+70369840232"}
0005432181506	913ED9	7379 023074	VARVARA BARANOVA	{"phone": "+70452944317"}
0005432181507	CC9EA8	1624 843396	RAISA SOKOLOVA	{"phone": "+70407731328"}
0005432181508	CC9EA8	3273 296725	VYACHESLAV FROLOV	{"email": "vfrolov101964@postgrespro.ru", "phone": "+70235661694"}
0005432181509	894CA5	1987 066673	ANNA EFIMOVA	{"email": "efimova-a-011976@postgrespro.ru", "phone": "+70865616235"}
0005432181510	894CA5	4571 476124	DENIS PETROV	{"email": "denis-petrov_08041978@postgrespro.ru", "phone": "+70144964686"}
0005432181511	E34FE6	1434 719899	TATYANA ZAYCEVA	{"email": "tzayceva.101973@postgrespro.ru", "phone": "+70528402663"}
0005432181512	EC5A33	8287 390111	TATYANA KOROLEVA	{"phone": "+70594108938"}
0005432181513	811295	7784 033145	TATYANA SEMENOVA	{"phone": "+70454275499"}
0005432181514	4F1B70	5214 659483	EVGENIY ALEKSANDROV	{"email": "evgeniy_aleksandrov.19071979@postgrespro.ru", "phone": "+70189010622"}
0005432181515	4A0998	5596 585409	TATYANA ILINA	{"phone": "+70195816922"}
0005432181516	74FB0A	2464 615002	KONSTANTIN KARPOV	{"email": "k-karpov1963@postgrespro.ru", "phone": "+70947619179"}
0005432181517	A8E16A	7428 944018	LYUDMILA NIKITINA	{"phone": "+70857136874"}
0005432181518	25F914	7622 836583	VALENTINA FROLOVA	{"email": "valentina-frolova-1968@postgrespro.ru", "phone": "+70831198463"}
0005432181519	25F914	4710 838265	EKATERINA SCHERBAKOVA	{"email": "e_scherbakova.121972@postgrespro.ru", "phone": "+70652781441"}
0005432181520	6E1279	9646 267249	VIKTOR VASILEV	{"phone": "+70503556298"}
0005432181521	45109D	5846 570852	DENIS MATVEEV	{"phone": "+70375651637"}
0005432181522	0350C5	3575 401055	EVGENIYA DMITRIEVA	{"phone": "+70767525100"}
0005432181524	ED8C5C	7130 967934	ALEKSANDR MIRONOV	{"phone": "+70652119569"}
0005432181525	5C68ED	2360 621178	IRINA KOZLOVA	{"phone": "+70446576577"}
0005432181526	5C68ED	3120 152829	NATALYA ALEKSANDROVA	{"email": "natalya_aleksandrova_1970@postgrespro.ru", "phone": "+70112691815"}
0005432181527	498954	4124 079816	ANATOLIY IVANOV	{"email": "ivanova-1974@postgrespro.ru", "phone": "+70042946062"}
0005432181528	3623FE	0973 025643	ALEKSEY KUZNECOV	{"phone": "+70010201670"}
0005432181529	60A033	4007 914126	GENNADIY NAUMOV	{"email": "naumov-g111969@postgrespro.ru", "phone": "+70939763273"}
0005432181530	559407	9148 817437	ELENA MOISEEVA	{"email": "elena_moiseeva.08121972@postgrespro.ru", "phone": "+70876809755"}
0005432181531	EB14D7	2644 785345	ARTUR TIKHONOV	{"email": "artur-tikhonov.16121963@postgrespro.ru", "phone": "+70764716856"}
0005432181532	EB14D7	6957 378659	OLESYA TITOVA	{"phone": "+70469847397"}
0005432181533	38A94C	2285 087763	EGOR PAVLOV	{"email": "e_pavlov28061961@postgrespro.ru", "phone": "+70291823029"}
0005432181534	5F5552	6370 279281	ALEKSEY NOVIKOV	{"email": "novikov.aleksey_19011977@postgrespro.ru", "phone": "+70027771007"}
0005432181535	5F5552	0481 475218	YULIYA VASILEVA	{"phone": "+70246882711"}
0005432181536	20CE60	3314 797913	MARK POPOV	{"email": "m.popov-091973@postgrespro.ru", "phone": "+70279183053"}
0005432181537	20CE60	2645 399660	ANTON SIDOROV	{"email": "anton.sidorov_31051969@postgrespro.ru", "phone": "+70968401406"}
0005432181538	24BCE2	4246 404315	MARINA TARASOVA	{"phone": "+70076041108"}
0005432181539	DD5DAE	9836 164174	NINA NIKOLAEVA	{"phone": "+70327413596"}
0005432181540	2487F1	1744 900068	VLADIMIR ZAYCEV	{"email": "zaycevvladimir.091968@postgrespro.ru", "phone": "+70978994377"}
0005432181541	2487F1	2375 155541	YURIY KUZNECOV	{"phone": "+70935382947"}
0005432181542	591751	3050 297850	DMITRIY ALEKSEEV	{"phone": "+70763818371"}
0005432181543	3FF4FA	2397 785282	TAMARA ANDREEVA	{"phone": "+70858406219"}
0005432181544	3FF4FA	4054 921554	VALENTINA RODIONOVA	{"email": "rodionova-v_1972@postgrespro.ru", "phone": "+70939703857"}
0005432181545	B60162	3779 832148	GERMAN ORLOV	{"phone": "+70062912158"}
0005432181546	B60162	5889 501114	EGOR VASILEV	{"email": "vasileve.021960@postgrespro.ru", "phone": "+70255177808"}
0005432181547	3F5D03	1039 198858	LIDIYA LEBEDEVA	{"email": "lidiyalebedeva.1964@postgrespro.ru", "phone": "+70609817848"}
0005432181548	1EE1E8	1396 887437	RAIL FROLOV	{"email": "frolov.rail_1966@postgrespro.ru", "phone": "+70436118423"}
0005432181549	B6476E	8923 217718	ANDREY KUZMIN	{"phone": "+70955890169"}
0005432181550	E4E146	5024 371344	ALEKSANDRA DAVYDOVA	{"email": "aleksandra_davydova081973@postgrespro.ru", "phone": "+70731848419"}
0005432181551	E4E146	9992 297831	KARINA TIKHONOVA	{"phone": "+70546466705"}
0005432181552	9095AC	7831 050306	ANDREY MELNIKOV	{"email": "melnikov.a.121965@postgrespro.ru", "phone": "+70700543237"}
0005432181553	9095AC	1989 615653	DMITRIY ISAEV	{"phone": "+70224048065"}
0005432181554	036EBA	7080 138994	MARIYA FILIPPOVA	{"email": "filippovam21111966@postgrespro.ru", "phone": "+70323006378"}
0005432181555	ACD9B6	2324 335614	ANNA KALININA	{"email": "kalininaanna051969@postgrespro.ru", "phone": "+70719315441"}
0005432181556	57A17E	5754 796385	ALEKSANDR FROLOV	{"phone": "+70838008599"}
0005432181557	3C050C	8786 701330	MARIYA KOMAROVA	{"phone": "+70204894818"}
0005432181558	3C050C	4358 198235	OLEG IVANOV	{"email": "o_ivanov-031975@postgrespro.ru", "phone": "+70248271966"}
0005432181559	9A38DF	8311 516344	YANA ZHURAVLEVA	{"email": "yana-zhuravleva071979@postgrespro.ru", "phone": "+70504704271"}
0005432181560	08CA3E	4477 873728	LYUDMILA NOVIKOVA	{"email": "novikova.lyudmila.1974@postgrespro.ru", "phone": "+70438040400"}
0005432181561	DA65F4	6638 449545	NIKOLAY TIKHONOV	{"phone": "+70053408409"}
0005432181562	151F38	3536 520152	ALEVTINA PETROVA	{"email": "alevtina-petrova-02101978@postgrespro.ru", "phone": "+70648720709"}
0005432181563	D22606	1013 597159	VYACHESLAV DENISOV	{"phone": "+70258472499"}
0005432181564	0E2EB2	5471 316628	NATALIYA ALEKSANDROVA	{"email": "n-aleksandrova-101982@postgrespro.ru", "phone": "+70106728649"}
0005432181565	896B8A	6339 267706	ANTONINA GUSEVA	{"phone": "+70524957486"}
0005432181566	896B8A	7714 641631	LYUDMILA ALEKSEEVA	{"phone": "+70379051421"}
0005432181567	497E14	4486 776093	EVGENIYA MIKHAYLOVA	{"email": "mikhaylova-evgeniya091964@postgrespro.ru", "phone": "+70297981834"}
0005432181568	3AFA9D	9698 273446	VLADIMIR EGOROV	{"email": "egorov-vladimir31081970@postgrespro.ru", "phone": "+70154566459"}
0005432181569	A7EC19	7815 574377	DARYA IVANOVA	{"phone": "+70125515599"}
0005432181570	762849	1035 165303	LYUDMILA KISELEVA	{"phone": "+70535707537"}
0005432181571	D8CE7C	2466 758076	SERGEY MIKHAYLOV	{"email": "sergeymikhaylov_111980@postgrespro.ru", "phone": "+70844553198"}
0005432181572	901D85	0017 991946	YULIYA FROLOVA	{"email": "frolova-y.17111976@postgrespro.ru", "phone": "+70824393665"}
0005432181573	231C5E	3889 518723	MARIYA FEDOROVA	{"phone": "+70708495585"}
0005432181574	C25F2C	0890 292943	ZLATA KUZMINA	{"phone": "+70565185899"}
0005432181575	91210F	1476 549279	ANNA STEPANOVA	{"email": "a.stepanova-28051966@postgrespro.ru", "phone": "+70851200160"}
0005432181576	91210F	1375 818933	ELENA KOMAROVA	{"email": "e-komarova24071955@postgrespro.ru", "phone": "+70409605791"}
0005432181577	91210F	5882 207244	GALINA NIKIFOROVA	{"phone": "+70137911893"}
0005432181578	E126D9	4526 607622	LIDIYA CHERNOVA	{"email": "chernova_lidiya061982@postgrespro.ru", "phone": "+70593200701"}
0005432181579	E126D9	9192 025572	DMITRIY ANDREEV	{"phone": "+70015814156"}
0005432181580	057DDD	0358 322430	MIKHAIL DENISOV	{"phone": "+70000036556"}
0005432181581	399487	5142 160641	ANATOLIY MIKHAYLOV	{"email": "mikhaylova_051972@postgrespro.ru", "phone": "+70269881064"}
0005432181582	C76FB8	2803 017938	ALEKSEY KUZNECOV	{"phone": "+70320913589"}
0005432181583	324169	3876 856574	VLADIMIR TIKHONOV	{"email": "tikhonov_vladimir.1969@postgrespro.ru", "phone": "+70983992292"}
0005432181584	324169	1520 184792	GULSINA GORBUNOVA	{"phone": "+70247801176"}
0005432181585	43E924	9409 485461	NATALYA NESTEROVA	{"email": "nesterovanatalya-1963@postgrespro.ru", "phone": "+70143012721"}
0005432181586	43E924	0637 258064	LYUDMILA LEBEDEVA	{"email": "lebedeva_l_051983@postgrespro.ru", "phone": "+70947307402"}
0005432181587	D1E659	9553 274808	VALENTINA SERGEEVA	{"email": "sergeeva_valentina.1967@postgrespro.ru", "phone": "+70338827306"}
0005432181588	4D132F	9338 921557	IVAN GERASIMOV	{"email": "gerasimov.ivan1979@postgrespro.ru", "phone": "+70853690858"}
0005432181589	9DD60D	4201 542816	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev1973@postgrespro.ru", "phone": "+70582921592"}
0005432181590	9DD60D	9110 966836	ANDREY ALEKSEEV	{"email": "aalekseev05101957@postgrespro.ru", "phone": "+70034296167"}
0005432181591	15169A	7241 568366	VLADIMIR DENISOV	{"phone": "+70143313089"}
0005432181592	3FD4BC	5043 665686	YURIY TARASOV	{"email": "tarasov-y-061982@postgrespro.ru", "phone": "+70833979547"}
0005432181593	4457F4	0657 065210	OLESYA AFANASEVA	{"email": "afanaseva.olesya041978@postgrespro.ru", "phone": "+70637234247"}
0005432181594	CACB5C	4332 921186	ROMAN SEMENOV	{"phone": "+70956874222"}
0005432181595	4882C2	5824 346074	VLADIMIR KARPOV	{"email": "v.karpov19041971@postgrespro.ru", "phone": "+70180966597"}
0005432181596	2A736D	5702 467752	ARTEM FROLOV	{"phone": "+70910410749"}
0005432181597	0CFF54	6609 336296	VLADIMIR FILIPPOV	{"email": "vladimirfilippov.15111977@postgrespro.ru", "phone": "+70649030599"}
0005432181598	C0DA4E	5562 726592	ALEKSANDR FOMIN	{"email": "aleksandr.fomin_1972@postgrespro.ru", "phone": "+70897434805"}
0005432181599	24C0E5	1461 477456	SERGEY PAVLOV	{"phone": "+70775290921"}
0005432181600	24C0E5	2203 983699	EVGENIY GUSEV	{"email": "guseve-16111971@postgrespro.ru", "phone": "+70793859699"}
0005432181601	E05291	1507 207940	MARIYA MEDVEDEVA	{"phone": "+70394761167"}
0005432181602	F7746F	5607 286313	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov1970@postgrespro.ru", "phone": "+70005167343"}
0005432181603	F7746F	6316 636200	LYUDMILA VASILEVA	{"phone": "+70400692470"}
0005432181604	08898A	5963 131112	EVDOKIYA SOLOVEVA	{"phone": "+70407449164"}
0005432181605	64F6AF	9292 809116	KSENIYA GORBUNOVA	{"email": "k.gorbunova-081960@postgrespro.ru", "phone": "+70511267011"}
0005432181606	F1D6D6	8948 102291	SOFYA PAVLOVA	{"email": "pavlova-s111971@postgrespro.ru", "phone": "+70950055696"}
0005432181607	244BFB	0273 011513	ILYA AFANASEV	{"email": "i.afanasev_071973@postgrespro.ru", "phone": "+70651220904"}
0005432181608	A25957	2253 221410	NADEZHDA FILATOVA	{"phone": "+70153231224"}
0005432181609	1D68AF	2425 079119	LYUBOV BELOVA	{"email": "lyubovbelova081958@postgrespro.ru", "phone": "+70541326610"}
0005432181610	20C373	2132 543492	LIDIYA LOGINOVA	{"email": "lloginova.051963@postgrespro.ru", "phone": "+70398805305"}
0005432181611	C7615E	7849 733639	PAVEL STEPANOV	{"email": "stepanov_pavel13051964@postgrespro.ru", "phone": "+70498322610"}
0005432181612	B2B200	6860 029616	SERGEY SHEVCHENKO	{"email": "sergeyshevchenko-25081964@postgrespro.ru", "phone": "+70721002422"}
0005432181613	B2B200	4733 783206	TATYANA MOROZOVA	{"email": "tatyanamorozova021978@postgrespro.ru", "phone": "+70877254194"}
0005432181614	6C40E2	1795 406071	VLADIMIR ALEKSANDROV	{"email": "aleksandrov.v1973@postgrespro.ru", "phone": "+70714826606"}
0005432181615	82B849	5684 544341	TATYANA ZAKHAROVA	{"phone": "+70078389106"}
0005432181616	47DB50	7548 465744	NATALYA MELNIKOVA	{"phone": "+70887199999"}
0005432181617	CE3EA0	3782 650596	ILSHAT MIKHAYLOV	{"email": "mikhaylov_i1961@postgrespro.ru", "phone": "+70476299523"}
0005432181618	CE3EA0	6193 061472	LYUDMILA TIKHONOVA	{"email": "tikhonova-l071975@postgrespro.ru", "phone": "+70009628190"}
0005432181619	21310C	4146 571343	ALEKSANDR KOZLOV	{"phone": "+70194043910"}
0005432181620	EED5E3	6868 562423	SERGEY ZAKHAROV	{"email": "zakharov_s.1970@postgrespro.ru", "phone": "+70177958884"}
0005432181621	A6344B	6028 596777	ANDREY ZAKHAROV	{"email": "a-zakharov30051965@postgrespro.ru", "phone": "+70995227682"}
0005432181622	AFC834	0629 904145	LYUDMILA ZHUKOVA	{"email": "zhukova_l-12111960@postgrespro.ru", "phone": "+70217211714"}
0005432181623	AFC834	8952 041635	MATVEY DAVYDOV	{"email": "matvey.davydov051980@postgrespro.ru", "phone": "+70430578003"}
0005432181624	B96465	3742 022631	ILYA STEPANOV	{"phone": "+70954162642"}
0005432181625	395A45	9872 637083	ANNA NESTEROVA	{"phone": "+70039924501"}
0005432181626	421E65	5466 211596	DARYA POLYAKOVA	{"phone": "+70766007381"}
0005432181627	F92050	6325 938650	YURIY KISELEV	{"email": "yuriy.kiselev.12051971@postgrespro.ru", "phone": "+70564302277"}
0005432181628	F92050	0147 266321	ROZA KUZNECOVA	{"phone": "+70154142399"}
0005432181629	C9688A	2623 982591	IRINA RODIONOVA	{"email": "irina-rodionova011977@postgrespro.ru", "phone": "+70074569654"}
0005432181630	4FD233	6372 287678	SVETLANA ABRAMOVA	{"email": "abramova_s1980@postgrespro.ru", "phone": "+70187706433"}
0005432181631	071B87	8589 248613	ROMAN OSIPOV	{"email": "osipovroman-19041967@postgrespro.ru", "phone": "+70982499248"}
0005432181632	48A991	4290 875125	MAKSIM BORISOV	{"email": "maksim.borisov1976@postgrespro.ru", "phone": "+70235360194"}
0005432181633	48A991	8307 026190	ALEKSEY ROMANOV	{"email": "a.romanov19061978@postgrespro.ru", "phone": "+70167003984"}
0005432181634	A24E20	5297 815053	LYUDMILA SERGEEVA	{"phone": "+70999993785"}
0005432181635	A24E20	9555 467599	ALENA KOZLOVA	{"phone": "+70767299438"}
0005432181636	71666F	6073 574773	VLADIMIR ORLOV	{"email": "vladimirorlov.061967@postgrespro.ru", "phone": "+70467514582"}
0005432181637	6012C9	9563 204592	VALERIY KUDRYASHOV	{"email": "v_kudryashov1972@postgrespro.ru", "phone": "+70731127059"}
0005432181638	288F44	3811 024077	MARINA NAUMOVA	{"phone": "+70343690304"}
0005432181639	288F44	6343 113515	ZOYA GORBUNOVA	{"email": "gorbunova.z_14011981@postgrespro.ru", "phone": "+70143346251"}
0005432181640	F8EBAF	7460 711650	VLADIMIR KONOVALOV	{"phone": "+70395650200"}
0005432181641	1CF328	9899 735489	IRINA MAKAROVA	{"phone": "+70318904814"}
0005432181642	90D7DD	5966 053331	VENERA EFREMOVA	{"email": "venera.efremova_1969@postgrespro.ru", "phone": "+70998720387"}
0005432181643	EAF497	3025 969790	NIKOLAY FEDOTOV	{"phone": "+70889183411"}
0005432181644	FD34E0	3887 654213	KSENIYA TITOVA	{"email": "k_titova051978@postgrespro.ru", "phone": "+70505060427"}
0005432181645	FD34E0	6395 386993	TATYANA TARASOVA	{"phone": "+70557134013"}
0005432181646	775E9F	5288 331209	TATYANA RODIONOVA	{"email": "t-rodionova-28041958@postgrespro.ru", "phone": "+70851616680"}
0005432181647	775E9F	4375 285547	NATALYA GAVRILOVA	{"email": "n.gavrilova_1972@postgrespro.ru", "phone": "+70856127741"}
0005432181648	C3D481	3815 277871	ALEKSANDR AFANASEV	{"email": "afanaseva-14081967@postgrespro.ru", "phone": "+70747929519"}
0005432181649	C3D481	4010 850776	MARIYA KOZLOVA	{"phone": "+70414482791"}
0005432181650	183B9F	8748 845155	NATALYA KUZNECOVA	{"phone": "+70623062463"}
0005432181651	513E1B	5251 920854	NATALYA KUZNECOVA	{"phone": "+70157538441"}
0005432181652	7E5AE3	2773 987876	PAVEL YAKOVLEV	{"email": "pavel-yakovlev02031973@postgrespro.ru", "phone": "+70256854689"}
0005432181653	7E5AE3	1434 059956	VLADIMIR POPOV	{"phone": "+70724386654"}
0005432181654	1CE07B	1528 997886	DMITRIY SHEVCHENKO	{"phone": "+70191161503"}
0005432181655	D0AFAD	8024 712453	OLGA SOLOVEVA	{"email": "soloveva-o-011969@postgrespro.ru", "phone": "+70759274630"}
0005432181656	3A865A	8447 033083	VIKTOR FROLOV	{"phone": "+70046004769"}
0005432181657	3A865A	5733 714836	VALENTINA KUZMINA	{"email": "v_kuzmina1989@postgrespro.ru", "phone": "+70478232420"}
0005432181658	56A3B8	1879 716462	PAVEL SMIRNOV	{"email": "pavel_smirnov-1968@postgrespro.ru", "phone": "+70090986725"}
0005432181659	FBCC41	9058 972655	DMITRIY BARANOV	{"email": "baranov-d.091980@postgrespro.ru", "phone": "+70391036585"}
0005432181660	997DE8	0602 538255	EVGENIY IVANOV	{"phone": "+70356355045"}
0005432181661	997DE8	6809 141478	ANATOLIY FILIPPOV	{"email": "a_filippov-111968@postgrespro.ru", "phone": "+70457933886"}
0005432181662	AD0EF8	6160 002980	NIKOLAY KUZNECOV	{"phone": "+70337007476"}
0005432181663	8BDA9F	2182 146511	DMITRIY PETROV	{"email": "petrov_dmitriy-1961@postgrespro.ru", "phone": "+70238452798"}
0005432181664	C506CD	8235 787907	TATYANA STEPANOVA	{"phone": "+70803183929"}
0005432181665	9B1C3D	5901 370639	TATYANA KUZNECOVA	{"email": "kuznecova.t1967@postgrespro.ru", "phone": "+70478262923"}
0005432181666	8F0461	1177 043398	LYUDMILA LUKYANOVA	{"email": "lyudmila_lukyanova_101984@postgrespro.ru", "phone": "+70378456493"}
0005432181667	14D01D	9048 542863	SVETLANA EFIMOVA	{"email": "efimova_svetlana-1972@postgrespro.ru", "phone": "+70951623257"}
0005432181668	287F3F	3857 603127	GALINA DENISOVA	{"phone": "+70480174916"}
0005432181669	89BB74	5066 869861	MARIYA SIDOROVA	{"phone": "+70706859471"}
0005432181670	5D823F	7891 707747	RENAT ZAYCEV	{"phone": "+70726745522"}
0005432181671	5D823F	6658 144129	MIKHAIL FROLOV	{"email": "frolov.mikhail_25071970@postgrespro.ru", "phone": "+70105093123"}
0005432181672	57D68B	1373 057294	DANIL ANDREEV	{"email": "andreev-danil09031966@postgrespro.ru", "phone": "+70501006922"}
0005432181673	57D68B	8397 038027	IGOR ILIN	{"phone": "+70374259234"}
0005432181674	C3BFDC	1925 324596	ALEKSANDRA AFANASEVA	{"email": "aleksandra.afanaseva_13091968@postgrespro.ru", "phone": "+70418120375"}
0005432181675	AC2391	2296 306723	LEV TARASOV	{"phone": "+70264617754"}
0005432181676	53DA0C	9979 957724	NATALYA SEMENOVA	{"email": "semenova_n_021971@postgrespro.ru", "phone": "+70635860609"}
0005432181677	B61959	9525 389815	ANASTASIYA MAKAROVA	{"email": "amakarova_061965@postgrespro.ru", "phone": "+70491157228"}
0005432181678	3BB882	4386 246186	OLGA PAVLOVA	{"phone": "+70244981181"}
0005432181679	7304E9	8762 243952	VERA GRISHINA	{"email": "v.grishina-1967@postgrespro.ru", "phone": "+70908066691"}
0005432181680	7304E9	7149 193563	LEONID FROLOV	{"email": "frolov_leonid_1984@postgrespro.ru", "phone": "+70757334514"}
0005432181681	7304E9	0018 895967	VLADIMIR SAVELEV	{"email": "savelev.v-041979@postgrespro.ru", "phone": "+70017011936"}
0005432181905	3FCA9B	7468 976341	NIKOLAY IVANOV	{"phone": "+70616205706"}
0005432181682	995F0F	5393 427929	TAISIYA SAVELEVA	{"email": "saveleva.t-071971@postgrespro.ru", "phone": "+70828028890"}
0005432181683	E2CA07	4439 515859	YURIY NOVIKOV	{"phone": "+70574677447"}
0005432181684	AA94A7	6026 313880	EKATERINA EFREMOVA	{"email": "efremova-ekaterina.071970@postgrespro.ru", "phone": "+70219480454"}
0005432181685	AA94A7	3224 214071	ELIZAVETA PAVLOVA	{"email": "pavlovaelizaveta-1975@postgrespro.ru", "phone": "+70660421989"}
0005432181686	916DB0	2092 247720	MARINA MAKAROVA	{"phone": "+70219373003"}
0005432181687	916DB0	8817 980216	ELENA ORLOVA	{"email": "orlovaelena1966@postgrespro.ru", "phone": "+70840196683"}
0005432181688	916DB0	9958 549283	ALEKSANDR KULIKOV	{"email": "aleksandr.kulikov-091973@postgrespro.ru", "phone": "+70283032401"}
0005432181689	712F8C	3965 273017	OLGA KONOVALOVA	{"phone": "+70396766650"}
0005432181690	30DE06	9230 682056	OLGA OVCHINNIKOVA	{"email": "olga_ovchinnikova_12071976@postgrespro.ru", "phone": "+70166708857"}
0005432181691	30DE06	6818 382013	ZINAIDA KARPOVA	{"email": "zinaida.karpova1971@postgrespro.ru", "phone": "+70286243817"}
0005432181692	CFD718	5384 052793	ALLA VASILEVA	{"phone": "+70122591868"}
0005432181693	D13AA5	8876 888730	IVAN VOLKOV	{"email": "i_volkov.081973@postgrespro.ru", "phone": "+70657037963"}
0005432181694	D13AA5	9939 996101	EVGENIYA PETROVA	{"email": "evgeniya_petrova_041967@postgrespro.ru", "phone": "+70122496258"}
0005432181695	14DB61	2329 467725	DENIS ZAYCEV	{"email": "zaycevd.021976@postgrespro.ru", "phone": "+70589177097"}
0005432181696	14DB61	1832 949081	SOFYA KUZNECOVA	{"phone": "+70952192670"}
0005432181697	8325E7	4999 325886	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev.071962@postgrespro.ru", "phone": "+70467211745"}
0005432181698	8325E7	3156 396332	OLGA KOROLEVA	{"email": "koroleva-olga-041972@postgrespro.ru", "phone": "+70177567880"}
0005432181699	8325E7	3927 063403	GENNADIY MIRONOV	{"phone": "+70151977236"}
0005432181700	CC36BF	0944 964066	KONSTANTIN EGOROV	{"phone": "+70872218653"}
0005432181701	C62A28	1491 244598	VLADIMIR ALEKSEEV	{"email": "vladimiralekseev_081977@postgrespro.ru", "phone": "+70740354731"}
0005432181702	1B36B6	0002 050602	LILIYA MELNIKOVA	{"phone": "+70257774467"}
0005432181703	1F6EF8	7201 972931	VALENTIN SERGEEV	{"email": "v_sergeev_1976@postgrespro.ru", "phone": "+70721465188"}
0005432181704	B8004E	6361 138233	SERGEY FROLOV	{"phone": "+70086449257"}
0005432181705	5818DC	9924 873691	IGOR IVANOV	{"email": "ivanov_igor_01121981@postgrespro.ru", "phone": "+70886525458"}
0005432181706	5E1A79	1604 800617	LYUDMILA FADEEVA	{"email": "fadeeva.lyudmila-23011968@postgrespro.ru", "phone": "+70963191468"}
0005432181707	5E1A79	8242 044320	YANA BOGDANOVA	{"email": "yanabogdanova.121978@postgrespro.ru", "phone": "+70059840558"}
0005432181708	10AE9B	9504 653504	MARINA FEDOROVA	{"email": "marina-fedorova_09071971@postgrespro.ru", "phone": "+70492907975"}
0005432181709	F1799B	1954 301614	ELENA TIMOFEEVA	{"email": "etimofeeva23101967@postgrespro.ru", "phone": "+70447379074"}
0005432181710	04D7F8	2464 503099	ANNA SOROKINA	{"email": "a-sorokina031977@postgrespro.ru", "phone": "+70414625838"}
0005432181711	E38839	9721 934550	ANATOLIY GRIGOREV	{"email": "anatoliy-grigorev_13101966@postgrespro.ru", "phone": "+70738349473"}
0005432181712	E38839	9772 371108	SERGEY SIDOROV	{"phone": "+70122266335"}
0005432181713	579D17	9667 289471	POLINA MIKHAYLOVA	{"phone": "+70700764484"}
0005432181714	4663AA	7008 336985	ELIZAVETA KUZNECOVA	{"phone": "+70434711372"}
0005432181715	ACDA01	0726 087167	NIKOLAY VASILEV	{"email": "vasilevnikolay1968@postgrespro.ru", "phone": "+70107891311"}
0005432181716	E44CF7	0343 655679	SERGEY KUDRYASHOV	{"email": "kudryashovsergey-091967@postgrespro.ru", "phone": "+70350415653"}
0005432181717	EF7936	0711 444885	LIDIYA IVANOVA	{"email": "l_ivanova1966@postgrespro.ru", "phone": "+70283813736"}
0005432181718	EF7936	4389 643191	ELENA KOZLOVA	{"phone": "+70429549420"}
0005432181719	2AF031	4818 977373	ALEKSANDR NIKITIN	{"phone": "+70484281621"}
0005432181720	2AF031	3794 500610	ANNA BORISOVA	{"phone": "+70302722226"}
0005432181721	FB360B	3842 243463	MAYYA MOROZOVA	{"phone": "+70294690799"}
0005432181722	3BE383	2515 805870	MAKSIM VLASOV	{"phone": "+70266155190"}
0005432181723	3BE383	1415 940272	TIMUR PETROV	{"email": "petrov.t-1974@postgrespro.ru", "phone": "+70624696454"}
0005432181724	A67B96	0080 903110	VITALIY NIKITIN	{"phone": "+70106105499"}
0005432181725	92F124	0006 950682	ALEKSANDR KUZNECOV	{"phone": "+70056038623"}
0005432181726	27D7AF	9045 918708	TAMARA ALEKSANDROVA	{"email": "tamaraaleksandrova_15081983@postgrespro.ru", "phone": "+70853726658"}
0005432181727	90C293	7019 850669	VIKTOR KRASNOV	{"email": "v.krasnov21021977@postgrespro.ru", "phone": "+70871014155"}
0005432181728	8C5556	7823 480724	VIKTORIYA PAVLOVA	{"email": "pavlovaviktoriya20081985@postgrespro.ru", "phone": "+70761178063"}
0005432181729	8C5556	7021 612441	VYACHESLAV VASILEV	{"phone": "+70600041325"}
0005432181730	491C7C	0690 815989	NINA MASLOVA	{"email": "n.maslova-30121972@postgrespro.ru", "phone": "+70424155086"}
0005432181731	491C7C	4514 985976	OKSANA OSIPOVA	{"email": "osipova.oksana.111973@postgrespro.ru", "phone": "+70472310370"}
0005432181732	73E85F	4953 554674	EKATERINA EFIMOVA	{"email": "e.efimova-1974@postgrespro.ru", "phone": "+70489121246"}
0005432181733	A7F1F8	7520 321786	OLGA YAKOVLEVA	{"email": "o_yakovleva.28051965@postgrespro.ru", "phone": "+70873475687"}
0005432181734	A7F1F8	4160 818794	LYUDMILA TARASOVA	{"email": "tarasovalyudmila-1973@postgrespro.ru", "phone": "+70320488166"}
0005432181735	0506D7	0496 370027	SVETLANA BORISOVA	{"email": "svetlana-borisova.101977@postgrespro.ru", "phone": "+70615610459"}
0005432182129	C96264	8738 433414	ZOYA IVANOVA	{"phone": "+70723867701"}
0005432181736	0506D7	0597 410736	YULIYA KOMAROVA	{"email": "y.komarova-101973@postgrespro.ru", "phone": "+70997044327"}
0005432181737	0B2660	2990 595645	VALERIY ANDREEV	{"email": "andreev-v-1968@postgrespro.ru", "phone": "+70549947467"}
0005432181738	0B2660	9122 808829	ALEKSANDR GERASIMOV	{"phone": "+70749835257"}
0005432181739	52A380	2733 804351	ALEKSANDR AFANASEV	{"phone": "+70961815545"}
0005432181740	52A380	9248 938009	IGOR KUZNECOV	{"phone": "+70914924207"}
0005432181741	52A380	4086 128808	TATYANA GORBUNOVA	{"email": "gorbunova-t.21021972@postgrespro.ru", "phone": "+70217027094"}
0005432181742	F37749	8671 758955	YURIY SIDOROV	{"email": "sidorov_y-1975@postgrespro.ru", "phone": "+70204944398"}
0005432181743	8593CA	6097 884788	EKATERINA PETROVA	{"phone": "+70477045525"}
0005432181744	E48539	7974 669037	OLGA GAVRILOVA	{"email": "olga-gavrilova.081978@postgrespro.ru", "phone": "+70155110909"}
0005432181745	8570BF	3614 947918	NATALYA VASILEVA	{"email": "n_vasileva1970@postgrespro.ru", "phone": "+70048186321"}
0005432181746	EC28BE	6717 895597	VYACHESLAV KOROLEV	{"phone": "+70094592613"}
0005432181747	15F053	6785 101501	SERGEY GORBUNOV	{"phone": "+70010172994"}
0005432181748	134CD6	6479 077879	ALEKSANDR BARANOV	{"email": "aleksandr-baranov-1976@postgrespro.ru", "phone": "+70899795700"}
0005432181749	134CD6	2917 504262	ILNAR RODIONOV	{"phone": "+70833970196"}
0005432181750	D7C2E5	7621 667263	DARYA NOVIKOVA	{"email": "novikova_d_25101974@postgrespro.ru", "phone": "+70068067486"}
0005432181751	E6B60B	1464 552183	VLADIMIR KUZNECOV	{"phone": "+70840914490"}
0005432181752	3B4850	4144 037295	LYUDMILA PETROVA	{"phone": "+70751185393"}
0005432181753	626C91	3338 600121	NATALYA ANDREEVA	{"email": "natalya.andreeva071972@postgrespro.ru", "phone": "+70906488764"}
0005432181754	B29BC8	3802 972654	LYUBOV NOVIKOVA	{"email": "l_novikova-26091983@postgrespro.ru", "phone": "+70852469235"}
0005432181755	B29BC8	5981 205177	KRISTINA NOVIKOVA	{"phone": "+70022901240"}
0005432181756	B29BC8	2891 553991	LYUDMILA KOLESNIKOVA	{"phone": "+70245294750"}
0005432181757	5CE2B4	2273 252492	NATALYA BORISOVA	{"email": "borisova_natalya-1974@postgrespro.ru", "phone": "+70724840222"}
0005432181758	F11F23	4677 213103	NIKOLAY POPOV	{"email": "nikolay.popov_011972@postgrespro.ru", "phone": "+70048549283"}
0005432181759	F11F23	4192 253039	IVAN ISAEV	{"email": "isaev_ivan-21111965@postgrespro.ru", "phone": "+70276405763"}
0005432181760	F11F23	3851 477026	VYACHESLAV TARASOV	{"phone": "+70974022565"}
0005432181761	F11F23	1388 590548	RIMA KUZMINA	{"email": "kuzmina_rima.1976@postgrespro.ru", "phone": "+70336485406"}
0005432181762	A065CC	4885 894098	PRASKOVYA YAKOVLEVA	{"email": "praskovya-yakovleva_061958@postgrespro.ru", "phone": "+70494242928"}
0005432181763	A065CC	0037 748061	MARINA PETROVA	{"phone": "+70702880402"}
0005432181764	C7E230	3900 468136	SVETLANA ZAYCEVA	{"email": "szayceva.091986@postgrespro.ru", "phone": "+70505975448"}
0005432181765	0FA632	2663 250718	LYUDMILA KUZNECOVA	{"phone": "+70340238009"}
0005432181766	299108	5307 994678	MARIYA KONOVALOVA	{"email": "konovalovam_1971@postgrespro.ru", "phone": "+70987907331"}
0005432181767	9217B3	9664 297095	OKSANA ANDREEVA	{"phone": "+70064612931"}
0005432181768	A0249D	3047 516864	VLADIMIR VOLKOV	{"phone": "+70142499360"}
0005432181769	69E59C	6602 687896	MARIYA GRISHINA	{"email": "mariya.grishina.101961@postgrespro.ru", "phone": "+70726813463"}
0005432181770	69E59C	4315 863699	FAINA ALEKSANDROVA	{"phone": "+70970720806"}
0005432181771	0884F5	5706 547386	NINA NAZAROVA	{"phone": "+70325573036"}
0005432181772	02E3C9	9350 707081	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov.03051971@postgrespro.ru", "phone": "+70140136916"}
0005432181773	72FA28	1600 769115	MIKHAIL MEDVEDEV	{"phone": "+70676071879"}
0005432181774	1E0766	9085 601550	DENIS FROLOV	{"email": "frolov-d081969@postgrespro.ru", "phone": "+70779832733"}
0005432181775	2DED82	3824 784314	LYUDMILA BELYAEVA	{"phone": "+70945660601"}
0005432181776	76EB2D	3222 318686	ALEKSEY GRIGOREV	{"phone": "+70693795600"}
0005432181777	76EB2D	4415 376450	SERGEY KUZMIN	{"phone": "+70987356899"}
0005432181778	25F2C2	2795 789385	DIANA KUZMINA	{"phone": "+70400288973"}
0005432181779	25F2C2	4016 828576	ELENA KONDRATEVA	{"email": "kondrateva.elena.021980@postgrespro.ru", "phone": "+70506112964"}
0005432181780	25F2C2	6532 163282	KSENIYA RODIONOVA	{"email": "rodionova-k-041963@postgrespro.ru", "phone": "+70138971897"}
0005432181781	5B1D2A	2272 375996	FANIL SAVELEV	{"email": "savelev_f-071970@postgrespro.ru", "phone": "+70589327001"}
0005432181782	73925C	1784 795475	DMITRIY MARTYNOV	{"phone": "+70612605143"}
0005432181783	1C2816	6620 454278	ANASTASIYA SERGEEVA	{"email": "a_sergeeva.1981@postgrespro.ru", "phone": "+70261645839"}
0005432181784	4365E1	9274 339787	MARIYA YUDINA	{"email": "mariyayudina_18051972@postgrespro.ru", "phone": "+70619521783"}
0005432181785	0B1A2C	8470 343322	TATYANA NIKITINA	{"email": "nikitina-t051982@postgrespro.ru", "phone": "+70682567432"}
0005432181786	BAAFCD	4307 681089	VENIAMIN CHERNOV	{"email": "chernov-v.17091972@postgrespro.ru", "phone": "+70756515476"}
0005432181787	1B1A49	7502 295632	SVETLANA TIKHONOVA	{"email": "tikhonova_svetlana14031966@postgrespro.ru", "phone": "+70585501393"}
0005432181788	D92735	3176 317140	ARTEM FROLOV	{"phone": "+70326703791"}
0005432181789	982F0F	6964 131704	SVETLANA IVANOVA	{"email": "ivanova.s.09061970@postgrespro.ru", "phone": "+70807064688"}
0005432181790	982F0F	6007 015342	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr021963@postgrespro.ru", "phone": "+70347428017"}
0005432181791	EB1B97	7195 298263	ELENA SOROKINA	{"phone": "+70885924357"}
0005432181793	0E338C	2023 503754	EDUARD STEPANOV	{"email": "eduardstepanov1969@postgrespro.ru", "phone": "+70847257201"}
0005432181794	0E338C	0140 691825	GALINA MELNIKOVA	{"phone": "+70321626725"}
0005432181795	B65AED	2029 120599	IRINA KOVALEVA	{"email": "ikovaleva1958@postgrespro.ru", "phone": "+70471552363"}
0005432181796	B65AED	7891 898325	IRINA NESTEROVA	{"phone": "+70337402701"}
0005432181797	90FDEF	7424 880473	NATALYA ZHUKOVA	{"phone": "+70729275089"}
0005432181798	90FDEF	0192 782505	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva-021980@postgrespro.ru", "phone": "+70115775687"}
0005432181799	D3FC37	9615 071936	SVETLANA ZHURAVLEVA	{"phone": "+70149696081"}
0005432181800	C1B641	2882 968870	ALEKSEY KONOVALOV	{"phone": "+70761088242"}
0005432181801	C1B641	3843 301626	LILIYA PAVLOVA	{"phone": "+70754762888"}
0005432181802	6FB21C	5365 178222	LILIYA DMITRIEVA	{"email": "liliya_dmitrieva061973@postgrespro.ru", "phone": "+70460857300"}
0005432181803	413754	5194 424197	EVGENIYA GUSEVA	{"email": "guseva_evgeniya.04111976@postgrespro.ru", "phone": "+70561931710"}
0005432181804	AA8D2C	1907 747166	ANDREY NAUMOV	{"phone": "+70811033470"}
0005432181805	D4D1C1	5049 538717	ALINA KUZNECOVA	{"email": "a_kuznecova15091971@postgrespro.ru", "phone": "+70345257763"}
0005432181806	2CCCFF	9251 291770	OLEG RODIONOV	{"phone": "+70183534391"}
0005432181807	2CCCFF	1081 889484	ALBINA IVANOVA	{"email": "ivanova-a_1978@postgrespro.ru", "phone": "+70942283052"}
0005432181808	2CCCFF	8546 202507	LYUBOV DAVYDOVA	{"phone": "+70581425968"}
0005432181809	EA3539	8167 869476	SERGEY KUZMIN	{"email": "kuzmin_s-06051975@postgrespro.ru", "phone": "+70385579234"}
0005432181810	EA3539	9348 485368	LYUDMILA LEBEDEVA	{"phone": "+70421465254"}
0005432181811	3AB79C	6596 957672	VASILIY ABRAMOV	{"phone": "+70122325116"}
0005432181812	B0BA8C	0249 161054	ANTON KISELEV	{"email": "a.kiselev_051976@postgrespro.ru", "phone": "+70309526944"}
0005432181813	B0BA8C	8072 412984	ANNA MOROZOVA	{"email": "a.morozova011985@postgrespro.ru", "phone": "+70779570178"}
0005432181814	BF832B	7211 044162	IRAIDA MELNIKOVA	{"email": "melnikova.iraida071978@postgrespro.ru", "phone": "+70180633784"}
0005432181815	BF832B	9173 764697	DMITRIY SOROKIN	{"phone": "+70534298988"}
0005432181816	B19189	0617 556448	TATYANA SEMENOVA	{"email": "semenovatatyana_29081979@postgrespro.ru", "phone": "+70317726432"}
0005432181817	B19189	8319 842103	VERA ANISIMOVA	{"phone": "+70261764854"}
0005432181818	B19189	3687 976340	DARYA LUKYANOVA	{"phone": "+70737048126"}
0005432181819	EE49F7	5983 105515	OKSANA PAVLOVA	{"email": "pavlova.o26051963@postgrespro.ru", "phone": "+70238584585"}
0005432181820	1DFC47	0966 273939	NATALYA KUZMINA	{"phone": "+70041289613"}
0005432181821	1DFC47	2808 154688	MARIYA IVANOVA	{"email": "ivanova.mariya-111969@postgrespro.ru", "phone": "+70737824820"}
0005432181822	3028C0	6898 329295	OLEG POPOV	{"phone": "+70615806488"}
0005432181823	3028C0	2726 893492	NIKITA BORISOV	{"phone": "+70902889652"}
0005432181824	781743	0307 159112	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila111976@postgrespro.ru", "phone": "+70030553736"}
0005432181825	175344	6699 863429	DARYA ANDREEVA	{"email": "d.andreeva-1962@postgrespro.ru", "phone": "+70579231482"}
0005432181826	840263	2432 006116	PAVEL BARANOV	{"email": "pbaranov_1969@postgrespro.ru", "phone": "+70683075652"}
0005432181827	F56170	6524 192190	YAROSLAV ANDREEV	{"email": "yaroslav-andreev-111971@postgrespro.ru", "phone": "+70526407836"}
0005432181828	F56170	0089 866079	DANILA MOROZOV	{"phone": "+70627718006"}
0005432181829	AAEC7F	1119 099235	NADEZHDA MIKHAYLOVA	{"email": "nadezhdamikhaylova-19051969@postgrespro.ru", "phone": "+70331161055"}
0005432181830	2869CF	8658 601305	ALEKSEY DENISOV	{"phone": "+70061757670"}
0005432181831	D480E5	0921 252127	MARIYA BELYAEVA	{"email": "belyaeva_m_091965@postgrespro.ru", "phone": "+70818597945"}
0005432181832	5BB646	5221 694431	ANASTASIYA NESTEROVA	{"email": "a-nesterova051971@postgrespro.ru", "phone": "+70127317347"}
0005432181833	5BB646	8326 764862	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.041971@postgrespro.ru", "phone": "+70677352116"}
0005432181834	B4BB0A	3988 681543	VIKTORIYA BORISOVA	{"phone": "+70237313983"}
0005432181835	3D7A16	1196 893879	VIKTOR SAVELEV	{"email": "vsavelev.071974@postgrespro.ru", "phone": "+70920969298"}
0005432181836	551733	2674 949751	YULIYA ROMANOVA	{"phone": "+70454043806"}
0005432181837	25E43C	1701 564369	YULIYA PAVLOVA	{"email": "yuliya-pavlova1969@postgrespro.ru", "phone": "+70035267834"}
0005432181838	25E43C	6036 302977	NADEZHDA NESTEROVA	{"email": "nesterova_n1976@postgrespro.ru", "phone": "+70944746120"}
0005432181839	25E43C	4286 916422	GENNADIY POPOV	{"phone": "+70742528116"}
0005432181840	A4A0E7	1108 787743	MARIYA ANDREEVA	{"email": "andreeva.mariya1982@postgrespro.ru", "phone": "+70685157184"}
0005432181841	A4A0E7	6173 181800	VIKTOR OSIPOV	{"email": "viktorosipov_1972@postgrespro.ru", "phone": "+70273788143"}
0005432181842	E7F2FC	4994 194809	NIKITA GERASIMOV	{"phone": "+70451619248"}
0005432181843	559E92	5194 818014	ANDREY FEDOTOV	{"phone": "+70413359179"}
0005432181844	559E92	9927 488380	RAFIK KRASNOV	{"phone": "+70400648886"}
0005432181845	A079F6	5425 188407	IRINA KONOVALOVA	{"email": "irina.konovalova_011969@postgrespro.ru", "phone": "+70681141228"}
0005432181846	A079F6	6808 922254	DANILA GAVRILOV	{"email": "gavrilovdanila12051970@postgrespro.ru", "phone": "+70129843255"}
0005432181847	6196F8	8234 039218	VALERIY FROLOV	{"email": "v.frolov-1967@postgrespro.ru", "phone": "+70739184400"}
0005432181848	FA7FD5	1375 225763	VALENTINA LEBEDEVA	{"phone": "+70214231535"}
0005432181849	3F1A62	7065 966200	TAMARA ANDREEVA	{"email": "andreeva_tamara_031980@postgrespro.ru", "phone": "+70352820432"}
0005432181850	3F1A62	2470 698281	SVETLANA GRISHINA	{"email": "s.grishina061976@postgrespro.ru", "phone": "+70461980887"}
0005432181851	3F1A62	6366 907565	NATALIYA KOROLEVA	{"phone": "+70205114168"}
0005432181852	94024D	9884 226655	OLGA KAZAKOVA	{"email": "kazakova-olga-051969@postgrespro.ru", "phone": "+70905028695"}
0005432181853	3B612C	5218 888391	SVETLANA FILIPPOVA	{"phone": "+70444791987"}
0005432181854	3B612C	2461 803715	ANNA IVANOVA	{"email": "ivanovaa-1980@postgrespro.ru", "phone": "+70628075866"}
0005432181912	F1951E	0458 662450	LYUBOV LEBEDEVA	{"phone": "+70153108162"}
0005432181855	3B612C	0392 326693	VLADIMIR FOMIN	{"email": "fomin_vladimir1980@postgrespro.ru", "phone": "+70021303929"}
0005432181856	089A99	2120 995468	VALENTIN OSIPOV	{"email": "valentin-osipov.1972@postgrespro.ru", "phone": "+70747379892"}
0005432181857	089A99	3757 322433	OLGA RODIONOVA	{"email": "orodionova_15011968@postgrespro.ru", "phone": "+70288476561"}
0005432181858	EE17AB	3309 338513	MAKSIM MIKHAYLOV	{"phone": "+70121137400"}
0005432181859	EE17AB	1500 004211	ALBINA AFANASEVA	{"phone": "+70751676022"}
0005432181860	EB96C7	7330 605171	ANDREY BONDARENKO	{"phone": "+70124195106"}
0005432181861	85C59B	0853 529596	DMITRIY KULIKOV	{"phone": "+70408357072"}
0005432181862	85C59B	2938 992908	LYUDMILA BOGDANOVA	{"email": "lyudmilabogdanova14021972@postgrespro.ru", "phone": "+70871354835"}
0005432181863	8220E4	7412 256592	LYUDMILA SERGEEVA	{"phone": "+70724069441"}
0005432181864	8220E4	1131 619374	ANTONINA POTAPOVA	{"email": "potapova-a.10121973@postgrespro.ru", "phone": "+70339920600"}
0005432181865	385F5D	0662 204160	ELENA FROLOVA	{"email": "elena.frolova-03101969@postgrespro.ru", "phone": "+70878903734"}
0005432181866	20DDB6	5701 522750	OLGA ZAYCEVA	{"email": "o-zayceva1972@postgrespro.ru", "phone": "+70401913829"}
0005432181867	20DDB6	8282 791862	SERGEY KUZNECOV	{"email": "kuznecovsergey.13041972@postgrespro.ru", "phone": "+70727486069"}
0005432181868	7D99E8	6141 485018	YULIYA GORBUNOVA	{"email": "gorbunova-y-1960@postgrespro.ru", "phone": "+70917785417"}
0005432181869	7D99E8	1327 155306	EKATERINA VOROBEVA	{"email": "vorobeva.e.011954@postgrespro.ru", "phone": "+70322186024"}
0005432181870	52605C	2381 489823	MARIYA SMIRNOVA	{"email": "smirnova.mariya091974@postgrespro.ru", "phone": "+70182114020"}
0005432181871	BBDFD8	0804 819976	DENIS KUZNECOV	{"phone": "+70803949049"}
0005432181872	BBDFD8	6843 900903	KLAVDIYA ZAKHAROVA	{"phone": "+70493037611"}
0005432181873	10CF54	1789 112384	IRINA ZAYCEVA	{"email": "zayceva-i.1978@postgrespro.ru", "phone": "+70745077171"}
0005432181874	26B54E	8416 577744	IGOR SOKOLOV	{"phone": "+70128459430"}
0005432181875	F20878	4852 638256	ROMAN PAVLOV	{"email": "roman.pavlov1974@postgrespro.ru", "phone": "+70052924089"}
0005432181876	673219	1720 430604	GALINA LOGINOVA	{"email": "loginovagalina30041965@postgrespro.ru", "phone": "+70581365748"}
0005432181877	B13DDD	3258 302490	PETR FILIPPOV	{"phone": "+70481983308"}
0005432181878	6C5F2D	9978 936494	ELVIRA KOROLEVA	{"phone": "+70893242396"}
0005432181879	A0D666	8167 464724	VLADIMIR KOZLOV	{"phone": "+70674301222"}
0005432181880	4F8B0D	0994 002287	TATYANA SEMENOVA	{"phone": "+70653230076"}
0005432181881	1680F2	3269 651508	OLGA GUSEVA	{"email": "guseva_olga1973@postgrespro.ru", "phone": "+70748525408"}
0005432181882	3BD788	7469 913481	SVETLANA KRASNOVA	{"phone": "+70463594111"}
0005432181883	7A4B3F	0643 456452	NIKOLAY SERGEEV	{"phone": "+70031394840"}
0005432181884	D54A96	8415 933359	VLADIMIR VASILEV	{"email": "v_vasilev051974@postgrespro.ru", "phone": "+70832172806"}
0005432181885	D54A96	6831 902417	NIKOLAY BONDARENKO	{"email": "bondarenko-nikolay12121975@postgrespro.ru", "phone": "+70222077965"}
0005432181886	9BBA1E	7675 288169	SERGEY NOVIKOV	{"email": "novikov_s051976@postgrespro.ru", "phone": "+70446652197"}
0005432181887	B8162B	5487 618644	VLADIMIR TIKHONOV	{"email": "vladimir.tikhonov.01031977@postgrespro.ru", "phone": "+70930060666"}
0005432181888	34347B	8722 267922	SERGEY GERASIMOV	{"email": "gerasimov-s.071988@postgrespro.ru", "phone": "+70502885416"}
0005432181889	34347B	5874 873585	SERGEY ROMANOV	{"phone": "+70328050100"}
0005432181890	941AA5	0396 423514	LYUBOV STEPANOVA	{"email": "stepanova.lyubov-14011969@postgrespro.ru", "phone": "+70475909083"}
0005432181891	941AA5	2689 028988	VLADIMIR MELNIKOV	{"phone": "+70047942076"}
0005432181892	6D065A	5009 184067	NADEZHDA KARPOVA	{"email": "nadezhda.karpova-04051968@postgrespro.ru", "phone": "+70899338206"}
0005432181893	EDFB87	1598 935055	ALEFTINA CHERNOVA	{"email": "chernova.a_30111967@postgrespro.ru", "phone": "+70193220854"}
0005432181894	5C01B5	1215 091321	TATYANA MARTYNOVA	{"phone": "+70598820937"}
0005432181895	367631	9125 809379	VASILIY BELOV	{"phone": "+70805725775"}
0005432181896	367631	9213 838853	NIKOLAY KUZNECOV	{"phone": "+70982732091"}
0005432181897	B846E7	9751 297753	OLESYA MAKAROVA	{"phone": "+70232318536"}
0005432181898	B846E7	6352 071313	ALEKSEY ZAKHAROV	{"email": "zakharova.07021967@postgrespro.ru", "phone": "+70476052442"}
0005432181899	7F6C83	7276 519737	VLADISLAV DENISOV	{"email": "denisov.v.031963@postgrespro.ru", "phone": "+70170991188"}
0005432181900	7F6C83	1162 531533	TATYANA TARASOVA	{"phone": "+70894504256"}
0005432181901	8FA9B3	2590 293700	ALEKSANDR NIKOLAEV	{"phone": "+70489385176"}
0005432181902	0FFC61	7350 864879	ANASTASIYA IVANOVA	{"email": "ivanovaa051975@postgrespro.ru", "phone": "+70420323880"}
0005432181903	571E86	4551 397852	RIMMA MEDVEDEVA	{"email": "rimma.medvedeva-1967@postgrespro.ru", "phone": "+70882686556"}
0005432181904	7C744E	6159 357442	YURIY ROMANOV	{"phone": "+70628946778"}
0005432181906	D6A1D3	5559 326995	KONSTANTIN MAKSIMOV	{"email": "k_maksimov041977@postgrespro.ru", "phone": "+70163163002"}
0005432181907	B7DF38	8193 967450	NADEZHDA OVCHINNIKOVA	{"email": "nadezhda.ovchinnikova14111974@postgrespro.ru", "phone": "+70990544947"}
0005432181908	124E83	5189 503166	ALENA MARTYNOVA	{"phone": "+70547053197"}
0005432181909	757DEE	0920 714606	ALEKSANDR MARTYNOV	{"email": "martynov_a1970@postgrespro.ru", "phone": "+70337177364"}
0005432181910	757DEE	1929 825261	DMITRIY ISAEV	{"email": "disaev.021982@postgrespro.ru", "phone": "+70594892597"}
0005432181911	F1951E	0073 064863	ALEKSEY GORBUNOV	{"phone": "+70970658335"}
0005432181913	A9A1A8	6929 331070	VERONIKA KOZLOVA	{"phone": "+70454215480"}
0005432181914	A9A1A8	3259 074558	LIDIYA ALEKSANDROVA	{"email": "aleksandrova_l.21101965@postgrespro.ru", "phone": "+70293232454"}
0005432181915	DD348B	4297 719558	MARGARITA ERMAKOVA	{"phone": "+70635468994"}
0005432181916	82A3CA	7934 772205	ELENA TARASOVA	{"phone": "+70549380297"}
0005432181917	82A3CA	7045 421633	ELVIRA KUZNECOVA	{"email": "kuznecova-e_1966@postgrespro.ru", "phone": "+70709067656"}
0005432181918	FAC3CF	1048 841330	LYUBOV LAZAREVA	{"phone": "+70333902954"}
0005432181919	FAC3CF	9334 005473	VLADIMIR MAKAROV	{"email": "v.makarov1974@postgrespro.ru", "phone": "+70069136291"}
0005432181920	46EE79	1419 941289	PAVEL EGOROV	{"phone": "+70744455700"}
0005432181921	D3518A	3857 947089	YURIY BARANOV	{"email": "ybaranov-081971@postgrespro.ru", "phone": "+70251728460"}
0005432181922	D3518A	9561 424434	DMITRIY PAVLOV	{"email": "d_pavlov_041979@postgrespro.ru", "phone": "+70480813563"}
0005432181923	863B1F	9324 398331	ALEKSEY KARPOV	{"email": "a-karpov-021982@postgrespro.ru", "phone": "+70207078537"}
0005432181982	237538	2691 199737	VLADIMIR OSIPOV	{"phone": "+70428378998"}
0005432181924	A236CA	9876 157411	NATALIYA PETROVA	{"email": "nataliya.petrova_121985@postgrespro.ru", "phone": "+70206417719"}
0005432181925	C12469	6449 209922	VLADIMIR GAVRILOV	{"email": "vladimirgavrilov-1972@postgrespro.ru", "phone": "+70477338943"}
0005432181926	3758EB	0741 838599	ELENA DANILOVA	{"phone": "+70199624856"}
0005432181927	5930DA	9688 883619	YURIY ISAEV	{"email": "isaev_y_12091978@postgrespro.ru", "phone": "+70632639146"}
0005432181928	B8CAD1	4678 922032	SVETLANA ZHURAVLEVA	{"phone": "+70889763072"}
0005432181929	88B963	3926 929795	VLADIMIR KUZNECOV	{"email": "v-kuznecov_05071984@postgrespro.ru", "phone": "+70331764590"}
0005432181930	F4F16F	9775 636748	DMITRIY ALEKSANDROV	{"email": "aleksandrov-d_121971@postgrespro.ru", "phone": "+70582556362"}
0005432181931	F4F16F	9255 978909	ANNA IVANOVA	{"email": "ivanova_a.18071950@postgrespro.ru", "phone": "+70319063319"}
0005432181932	810AD3	1427 450074	VERA TARASOVA	{"phone": "+70472793559"}
0005432181933	9AD0F8	8915 669053	OLESYA ZHURAVLEVA	{"email": "ozhuravleva_1971@postgrespro.ru", "phone": "+70536717990"}
0005432181934	06C551	1695 673984	EVGENIY GAVRILOV	{"phone": "+70457800608"}
0005432181935	65B029	0005 016512	NATALYA SOROKINA	{"email": "natalya.sorokina-1975@postgrespro.ru", "phone": "+70854844796"}
0005432181936	65B029	1273 028295	LYUDMILA EGOROVA	{"email": "l.egorova_091981@postgrespro.ru", "phone": "+70151033449"}
0005432181937	EF084E	5231 903100	ELENA NIKIFOROVA	{"phone": "+70907299317"}
0005432181938	B88598	2654 718671	YULIYA SCHERBAKOVA	{"email": "scherbakovayuliya.051970@postgrespro.ru", "phone": "+70518402729"}
0005432181939	41FDE9	3551 855994	MARIYA KUDRYASHOVA	{"email": "m_kudryashova-31051973@postgrespro.ru", "phone": "+70551008151"}
0005432181940	41FDE9	2632 316875	VLADIMIR YAKOVLEV	{"phone": "+70052734783"}
0005432181941	B9E290	8651 344597	VLADIMIR GORBUNOV	{"email": "gorbunov_vladimir.1983@postgrespro.ru", "phone": "+70201658334"}
0005432181942	B9E290	8390 142462	ANZHELIKA KOZLOVA	{"phone": "+70864692749"}
0005432181943	B9E290	7790 801450	LYUDMILA TROFIMOVA	{"email": "l_trofimova-02111970@postgrespro.ru", "phone": "+70511800869"}
0005432181944	5D63C5	5554 350185	EVGENIY SERGEEV	{"phone": "+70235380212"}
0005432181945	F49A94	4962 167237	KSENIYA KOROLEVA	{"email": "kseniya-koroleva-1978@postgrespro.ru", "phone": "+70783380936"}
0005432181946	F49A94	1176 365406	RAISA MAKAROVA	{"email": "makarovaraisa-01091965@postgrespro.ru", "phone": "+70786370925"}
0005432181947	12A5E5	0997 028778	MARINA ANDREEVA	{"phone": "+70531269018"}
0005432181948	12A5E5	7484 917472	YURIY ALEKSEEV	{"phone": "+70036209728"}
0005432181949	4D17AA	9524 325997	EVGENIY VOLKOV	{"email": "evgeniy.volkov.08071987@postgrespro.ru", "phone": "+70372530763"}
0005432181950	4D17AA	4686 395629	VERA GUSEVA	{"email": "guseva.v-091964@postgrespro.ru", "phone": "+70582819654"}
0005432181951	1A76ED	2503 491791	STANISLAV KUZNECOV	{"phone": "+70950493739"}
0005432181952	973614	6827 659903	VLADIMIR TARASOV	{"phone": "+70268349326"}
0005432181953	70883B	9053 591598	ALEKSEY SHEVCHENKO	{"email": "shevchenko_aleksey.1974@postgrespro.ru", "phone": "+70240839204"}
0005432181954	D49D7D	1102 948933	SVETLANA ABRAMOVA	{"email": "abramova.s-031987@postgrespro.ru", "phone": "+70565749159"}
0005432181955	BDEED6	7333 995177	YULIYA NIKITINA	{"phone": "+70022554414"}
0005432181956	BDEED6	9528 457972	EVGENIYA NESTEROVA	{"phone": "+70889225242"}
0005432181957	BDEED6	9617 834073	NADEZHDA BELOVA	{"email": "nadezhda.belova10101966@postgrespro.ru", "phone": "+70432102534"}
0005432181958	3CA795	6353 568294	LYUBOV NIKITINA	{"email": "lyubov_nikitina_1959@postgrespro.ru", "phone": "+70112706811"}
0005432181959	079391	4742 209817	NATALIYA MIKHAYLOVA	{"email": "nataliyamikhaylova.1965@postgrespro.ru", "phone": "+70311191149"}
0005432181960	15AE74	6981 557873	LYUBOV GORBUNOVA	{"email": "lyubov_gorbunova.02051968@postgrespro.ru", "phone": "+70924651991"}
0005432181961	15AE74	0438 048951	EVGENIYA DAVYDOVA	{"email": "davydova.evgeniya101962@postgrespro.ru", "phone": "+70212899881"}
0005432181962	15AE74	5707 806409	LIDIYA CHERNOVA	{"email": "chernova-l_31101968@postgrespro.ru", "phone": "+70713545992"}
0005432181963	92A8DF	3071 867105	ANNA TITOVA	{"phone": "+70827419128"}
0005432181964	C36367	5454 166546	ROMAN SMIRNOV	{"email": "smirnov_r29091969@postgrespro.ru", "phone": "+70010374903"}
0005432181965	C36367	1335 336844	VLADIMIR KRASNOV	{"phone": "+70993251293"}
0005432181966	C36367	2583 165972	MIKHAIL FEDOTOV	{"phone": "+70381383853"}
0005432181967	D4A876	2234 429250	EKATERINA SAVELEVA	{"phone": "+70715927692"}
0005432181968	AC3D3F	5299 253272	ANDREY GERASIMOV	{"email": "agerasimov.1977@postgrespro.ru", "phone": "+70115577912"}
0005432181969	9D56F2	7034 677607	MARINA NAZAROVA	{"phone": "+70322731853"}
0005432181970	0F0D32	7444 427738	DMITRIY MATVEEV	{"email": "dmitriy-matveev.14051975@postgrespro.ru", "phone": "+70224392677"}
0005432181971	61012F	6739 196657	VERONIKA ABRAMOVA	{"email": "vabramova-1970@postgrespro.ru", "phone": "+70670782097"}
0005432181972	61012F	1043 146330	VERA STEPANOVA	{"email": "stepanova_vera.07101974@postgrespro.ru", "phone": "+70405154378"}
0005432181973	EB1BED	8480 904812	EVGENIY SEMENOV	{"email": "semenov_evgeniy-1968@postgrespro.ru", "phone": "+70232254773"}
0005432181974	EB1BED	6000 362785	VIKTOR BARANOV	{"phone": "+70258946625"}
0005432181975	D6BB48	1935 032370	NADEZHDA ANTONOVA	{"email": "n.antonova.1960@postgrespro.ru", "phone": "+70136839637"}
0005432181976	F0BDE1	9713 256966	LYUDMILA DAVYDOVA	{"email": "l-davydova18041970@postgrespro.ru", "phone": "+70171639424"}
0005432181977	F0BDE1	5641 765565	IGOR ZAYCEV	{"phone": "+70525065812"}
0005432181978	0968B8	3205 719831	TATYANA POTAPOVA	{"email": "potapova.t.26041974@postgrespro.ru", "phone": "+70330154417"}
0005432181979	AE6406	9403 250595	TATYANA DENISOVA	{"email": "denisova_tatyana.031966@postgrespro.ru", "phone": "+70407688148"}
0005432181980	BEC81C	8746 206700	OLEG MAKAROV	{"phone": "+70886794303"}
0005432181981	BEC81C	4129 446839	VIKTORIYA VOLKOVA	{"email": "v.volkova.1970@postgrespro.ru", "phone": "+70443828891"}
0005432181983	E76E67	2984 548028	GAGIK MAKSIMOV	{"email": "gagik-maksimov-1973@postgrespro.ru", "phone": "+70254636070"}
0005432181984	06F9CE	7105 275086	EKATERINA FOMINA	{"email": "fominaekaterina-1971@postgrespro.ru", "phone": "+70396977309"}
0005432181985	06F9CE	9800 578615	MAKSIM SIDOROV	{"email": "m.sidorov_1965@postgrespro.ru", "phone": "+70286067866"}
0005432181986	BD6287	3131 637561	SERGEY FEDOROV	{"email": "fedorov.sergey.1972@postgrespro.ru", "phone": "+70922602687"}
0005432181987	BD6287	5554 148530	VADIM KUZNECOV	{"email": "v-kuznecov_071979@postgrespro.ru", "phone": "+70164070611"}
0005432181988	0B0262	9305 096191	OKSANA ORLOVA	{"phone": "+70565512464"}
0005432181989	9AC1AF	5996 994017	OLGA OSIPOVA	{"email": "o_osipova.1973@postgrespro.ru", "phone": "+70044747006"}
0005432181990	DD13D8	9693 070733	LYUDMILA FROLOVA	{"phone": "+70778467637"}
0005432181991	42E0DF	5080 310198	SERGEY KUZMIN	{"email": "s-kuzmin15051976@postgrespro.ru", "phone": "+70833091281"}
0005432181992	316528	8172 851709	ANNA ISAEVA	{"email": "isaeva-anna25121979@postgrespro.ru", "phone": "+70129522426"}
0005432181993	39C73B	7229 867327	EKATERINA KAZAKOVA	{"phone": "+70519953674"}
0005432181994	31370E	2714 033650	EVGENIY ZHUKOV	{"phone": "+70024583729"}
0005432181995	AB3F88	0834 884944	TAMARA STEPANOVA	{"email": "stepanovatamara-09101975@postgrespro.ru", "phone": "+70377711224"}
0005432181996	AB3F88	4458 895920	YULIYA ILINA	{"phone": "+70354037679"}
0005432181997	5A36DC	3746 559192	FEDOR GUSEV	{"phone": "+70395597271"}
0005432181998	7DA7DD	3744 536682	VALERIY KUZNECOV	{"email": "vkuznecov.29121968@postgrespro.ru", "phone": "+70561256673"}
0005432181999	7DA7DD	7308 402978	SERGEY STEPANOV	{"email": "stepanovsergey-1978@postgrespro.ru", "phone": "+70123698707"}
0005432182000	03F965	2554 261229	YAROSLAV ZHURAVLEV	{"email": "zhuravlev-y17081966@postgrespro.ru", "phone": "+70886359444"}
0005432182001	9B8469	9979 073939	DMITRIY FROLOV	{"phone": "+70347550089"}
0005432182002	DCAC99	2471 710164	FEDOR SOROKIN	{"email": "fsorokin.1962@postgrespro.ru", "phone": "+70753294599"}
0005432182003	DCAC99	7578 607136	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova-1961@postgrespro.ru", "phone": "+70917600747"}
0005432182004	DEFDEE	5502 134353	OKSANA DANILOVA	{"email": "o.danilova.1972@postgrespro.ru", "phone": "+70889985424"}
0005432182005	A9C910	9420 199264	NIKOLAY FOMIN	{"email": "fominnikolay.1965@postgrespro.ru", "phone": "+70445632675"}
0005432182006	2BB17F	0230 882462	ANNA KONDRATEVA	{"email": "annakondrateva.1974@postgrespro.ru", "phone": "+70334207414"}
0005432182007	4A0BF3	4109 118801	ALEKSEY VASILEV	{"phone": "+70171568006"}
0005432182008	E3AE5A	7167 021879	ALEKSEY KUZNECOV	{"phone": "+70918469241"}
0005432182009	7DE0ED	0661 422657	VLADIMIR VOROBEV	{"email": "v-vorobev_29051972@postgrespro.ru", "phone": "+70354959097"}
0005432182010	7DE0ED	6180 802152	ALEKSANDR ISAEV	{"email": "aleksandr_isaev_1960@postgrespro.ru", "phone": "+70865747403"}
0005432182011	FC67FC	2684 391264	VERA VOLKOVA	{"email": "volkova.vera.1965@postgrespro.ru", "phone": "+70326617124"}
0005432182012	DEB25D	2327 963623	LYUBOV KRASNOVA	{"phone": "+70689678018"}
0005432182013	556D07	8969 566209	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov121965@postgrespro.ru", "phone": "+70797682618"}
0005432182014	556D07	9947 403623	ELENA GORBUNOVA	{"phone": "+70290724550"}
0005432182015	6C2274	1414 693513	IRINA RYABOVA	{"phone": "+70906034624"}
0005432182016	ABBA72	8880 629509	GALINA RYABOVA	{"email": "ryabova-g_1980@postgrespro.ru", "phone": "+70141885737"}
0005432182017	ABBA72	4828 154057	GALINA GUSEVA	{"phone": "+70760365835"}
0005432182018	4DE574	2429 632822	IRINA SMIRNOVA	{"phone": "+70584113298"}
0005432182019	130F1F	4061 057593	SOFIYA KUZMINA	{"email": "s.kuzmina_051978@postgrespro.ru", "phone": "+70782530071"}
0005432182020	287DB6	4855 135619	VIKTORIYA SEMENOVA	{"email": "semenova.v01081966@postgrespro.ru", "phone": "+70375102681"}
0005432182021	825E96	7550 351892	LYUDMILA BORISOVA	{"email": "borisova-lyudmila-1969@postgrespro.ru", "phone": "+70489742166"}
0005432182022	825E96	1512 164001	VITALIY MARTYNOV	{"email": "vitaliy-martynov_031987@postgrespro.ru", "phone": "+70077194365"}
0005432182023	392782	6062 752417	TATYANA FEDOROVA	{"phone": "+70994340694"}
0005432182024	1A52D8	7925 876488	TATYANA MELNIKOVA	{"phone": "+70865307252"}
0005432182025	DCA565	7622 046153	VADIM NOVIKOV	{"phone": "+70656826751"}
0005432182026	DCA565	0958 576775	NINA SAVELEVA	{"phone": "+70790645137"}
0005432182027	28A66D	9652 297842	VALENTINA BELYAEVA	{"email": "v-belyaeva.1974@postgrespro.ru", "phone": "+70695229239"}
0005432182028	28A66D	5519 975150	DMITRIY BELOV	{"phone": "+70396617273"}
0005432182029	4F907A	0293 126809	VLADIMIR FILIPPOV	{"phone": "+70608714682"}
0005432182030	B52473	1705 693035	ANATOLIY ILIN	{"email": "anatoliy-ilin-18051978@postgrespro.ru", "phone": "+70381125921"}
0005432182031	4BFE41	5730 666058	ANAIT KULIKOVA	{"phone": "+70795548490"}
0005432182032	A25289	5584 875453	TATYANA KULIKOVA	{"phone": "+70042641257"}
0005432182033	A25289	7807 639984	TIMUR KUZNECOV	{"phone": "+70644751539"}
0005432182034	5282D3	6429 906910	VYACHESLAV BARANOV	{"phone": "+70330935113"}
0005432182035	BC6C10	8678 366427	GULFIYA IVANOVA	{"phone": "+70116718184"}
0005432182036	BC6C10	3058 816735	ANASTASIYA AKIMOVA	{"email": "a_akimova.1979@postgrespro.ru", "phone": "+70729009194"}
0005432182037	39EC17	9156 953070	SERGEY SOKOLOV	{"phone": "+70716391103"}
0005432182038	DD2039	7453 855861	NATALYA KRASNOVA	{"phone": "+70766899149"}
0005432182039	DD2039	4543 853892	OLGA SMIRNOVA	{"phone": "+70309862244"}
0005432182040	CBC6ED	2196 116832	MARIYA GAVRILOVA	{"email": "gavrilova-m.011972@postgrespro.ru", "phone": "+70052408225"}
0005432182041	DD0B1D	5721 034936	NATALYA SMIRNOVA	{"phone": "+70281761882"}
0005432182042	D70C25	8070 818337	GALINA KULIKOVA	{"phone": "+70715647626"}
0005432182043	D70C25	0115 827703	ALEKSANDR FILIPPOV	{"email": "a.filippov-1971@postgrespro.ru", "phone": "+70532935395"}
0005432182044	9EFB5F	2764 170012	ELENA SERGEEVA	{"email": "sergeevaelena.031982@postgrespro.ru", "phone": "+70762534850"}
0005432182045	9EFB5F	3790 098627	ROSTISLAV BONDARENKO	{"phone": "+70579741940"}
0005432182046	77DDAC	1340 430499	VALENTINA PAVLOVA	{"email": "valentina-pavlova011968@postgrespro.ru", "phone": "+70269848422"}
0005432182047	2D221A	2560 450742	VLADIMIR VOROBEV	{"email": "vorobev_vladimir-1969@postgrespro.ru", "phone": "+70335374554"}
0005432182048	C927C1	6316 316790	ALEKSANDRA BARANOVA	{"phone": "+70363972214"}
0005432182049	9CAA2F	5303 385133	LYUDMILA OSIPOVA	{"email": "lyudmila.osipova07111966@postgrespro.ru", "phone": "+70695101500"}
0005432182050	DE13C0	6473 015307	DANIIL MOROZOV	{"phone": "+70645105613"}
0005432182051	5EEE71	7558 883316	EKATERINA ROMANOVA	{"email": "romanova_e_03011983@postgrespro.ru", "phone": "+70545194101"}
0005432182052	0F10C0	6270 527989	SERGEY ZAYCEV	{"phone": "+70828375978"}
0005432182053	68B909	5039 560558	ELENA KONDRATEVA	{"phone": "+70860821907"}
0005432182054	8A9EDA	3027 042865	STANISLAV ALEKSEEV	{"email": "stanislav_alekseev_1971@postgrespro.ru", "phone": "+70086725329"}
0005432182055	03B394	9209 367631	TAMARA SMIRNOVA	{"phone": "+70874152763"}
0005432182056	170F06	1129 543291	NADEZHDA SEMENOVA	{"email": "semenova_n_1977@postgrespro.ru", "phone": "+70034720761"}
0005432182057	170F06	4086 343921	OLGA MARTYNOVA	{"phone": "+70945222736"}
0005432182058	801FBD	8222 950539	ANGELINA ZAYCEVA	{"email": "a_zayceva_30091967@postgrespro.ru", "phone": "+70540199021"}
0005432182059	23F5FE	1440 211777	VALENTINA SAVELEVA	{"phone": "+70824859538"}
0005432182060	0BDB78	7211 895039	VLADIMIR SOROKIN	{"phone": "+70678981115"}
0005432182061	0BDB78	4801 900462	NINA SMIRNOVA	{"phone": "+70374024622"}
0005432182062	54031C	6978 250032	KIRILL MIRONOV	{"email": "kirill-mironov1958@postgrespro.ru", "phone": "+70094947010"}
0005432182063	6F84F0	7680 659304	ANATOLIY KRASNOV	{"phone": "+70917735575"}
0005432182064	B8747C	2273 981149	VERONIKA EFREMOVA	{"phone": "+70107298441"}
0005432182065	B8747C	0751 790517	TAMARA AFANASEVA	{"email": "tamara.afanaseva_101966@postgrespro.ru", "phone": "+70737295451"}
0005432182066	2965FC	0399 091718	MIKHAIL POPOV	{"phone": "+70046272897"}
0005432182067	1C2009	2469 664486	TAMARA NESTEROVA	{"phone": "+70308661430"}
0005432182068	76A816	9310 335272	NIKOLAY SAVELEV	{"phone": "+70951936489"}
0005432182069	6DEF00	1079 705351	ALEKSANDR CHERNOV	{"phone": "+70660021253"}
0005432182070	6DEF00	2169 050307	NINA SIDOROVA	{"email": "sidorovan.06011962@postgrespro.ru", "phone": "+70897085159"}
0005432182071	1E92B3	7537 726672	GALINA SEMENOVA	{"email": "g_semenova_25071971@postgrespro.ru", "phone": "+70244052061"}
0005432182072	57849B	3069 667567	ANDREY NIKITIN	{"phone": "+70454564543"}
0005432182073	56D795	8339 549479	EKATERINA AKIMOVA	{"email": "ekaterina_akimova_20081962@postgrespro.ru", "phone": "+70326239016"}
0005432182074	34D192	1272 903530	ANNA IVANOVA	{"phone": "+70000460071"}
0005432182075	34D192	3069 010055	VIOLETTA KONDRATEVA	{"phone": "+70566175768"}
0005432182076	EC1DDD	6824 682469	VITALIY PETROV	{"phone": "+70018660496"}
0005432182077	DA2FCB	9843 509210	LYUDMILA KUZNECOVA	{"phone": "+70385666825"}
0005432182078	1109FA	8851 153068	NIKOLAY ABRAMOV	{"email": "nikolayabramov_25061982@postgrespro.ru", "phone": "+70842226200"}
0005432182079	DB81E6	9054 815797	ELENA SAVELEVA	{"email": "saveleva-e-1985@postgrespro.ru", "phone": "+70872975117"}
0005432182080	DB81E6	7659 499260	SVETLANA ALEKSEEVA	{"phone": "+70265762193"}
0005432182081	2565E7	6660 573405	MARGARITA NAZAROVA	{"email": "nazarova-m.1971@postgrespro.ru", "phone": "+70117642150"}
0005432182082	481272	9505 709893	NINA ALEKSANDROVA	{"email": "ninaaleksandrova-1982@postgrespro.ru", "phone": "+70095015195"}
0005432182083	E39AAE	1509 339379	SERGEY ROMANOV	{"phone": "+70665294254"}
0005432182084	EDCBC9	7900 173455	OLGA KUZNECOVA	{"phone": "+70849351715"}
0005432182085	4A0F3D	4562 929714	ALEKSANDR IVANOV	{"phone": "+70665266963"}
0005432182086	C121B4	6592 827447	NATALIYA KOVALEVA	{"phone": "+70678262524"}
0005432182087	676702	2327 217013	IRINA ORLOVA	{"phone": "+70424974639"}
0005432182088	676702	7931 377933	VIKTOR ABRAMOV	{"email": "vabramov_051965@postgrespro.ru", "phone": "+70921820483"}
0005432182089	992234	4652 251673	ANTON TIMOFEEV	{"email": "anton_timofeev.14031985@postgrespro.ru", "phone": "+70773662415"}
0005432182090	D6EF39	4299 434513	NADEZHDA RYABOVA	{"email": "n-ryabova-1972@postgrespro.ru", "phone": "+70322217069"}
0005432182091	12EFAD	4909 874939	NADEZHDA SOLOVEVA	{"phone": "+70858968841"}
0005432182092	12EFAD	7120 416970	MARAT ROMANOV	{"email": "marat.romanov_09071976@postgrespro.ru", "phone": "+70272273489"}
0005432182093	B45965	5612 796081	ALEKSEY RODIONOV	{"email": "aleksey_rodionov.031973@postgrespro.ru", "phone": "+70301148059"}
0005432182094	B45965	7536 212152	VLADIMIR ZAYCEV	{"email": "zaycev.vladimir-1963@postgrespro.ru", "phone": "+70500345438"}
0005432182095	748A5B	6536 085993	LYUBOV BELOVA	{"email": "belova.l_1970@postgrespro.ru", "phone": "+70526603551"}
0005432182096	7A5628	5392 919077	EVGENIY SOROKIN	{"phone": "+70160509313"}
0005432182097	BBC8F9	8999 974345	IVAN NOVIKOV	{"email": "ivannovikov-061958@postgrespro.ru", "phone": "+70438332377"}
0005432182098	BBC8F9	3069 722651	EKATERINA SMIRNOVA	{"phone": "+70211475944"}
0005432182099	BEDF79	4346 176601	GALINA SCHERBAKOVA	{"email": "scherbakova-galina.051973@postgrespro.ru", "phone": "+70568601841"}
0005432182100	BEDF79	7438 338857	VENERA ZHURAVLEVA	{"email": "venera.zhuravleva_111973@postgrespro.ru", "phone": "+70585141249"}
0005432182101	DC6E24	1738 754273	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_1968@postgrespro.ru", "phone": "+70484038844"}
0005432182102	CE4A6C	1434 201668	ELIZAVETA FEDOROVA	{"phone": "+70457520424"}
0005432182103	CE4A6C	0161 731200	VALENTINA YUDINA	{"email": "v_yudina-041979@postgrespro.ru", "phone": "+70733649275"}
0005432182104	7CA4E3	9535 279289	NATALYA KOZLOVA	{"phone": "+70640013047"}
0005432182105	7CA4E3	6285 051393	VLADIMIR MAKSIMOV	{"email": "v_maksimov-121963@postgrespro.ru", "phone": "+70755332084"}
0005432182106	9F88AD	9916 175729	SOFYA POPOVA	{"email": "s.popova1967@postgrespro.ru", "phone": "+70115531403"}
0005432182107	2B239E	7648 454547	MIKHAIL GRIGOREV	{"email": "grigorevm-1975@postgrespro.ru", "phone": "+70822070854"}
0005432182108	5ADCB0	6183 095948	NATALYA ZAKHAROVA	{"phone": "+70271421992"}
0005432182109	199E64	5546 928024	NATALYA FROLOVA	{"phone": "+70720145583"}
0005432182110	199E64	8940 772784	EKATERINA KUZNECOVA	{"email": "e.kuznecova23111973@postgrespro.ru", "phone": "+70796595860"}
0005432182111	BC5125	3365 163097	LYUBOV SIDOROVA	{"email": "sidorova_lyubov-1962@postgrespro.ru", "phone": "+70436124084"}
0005432182112	BC5125	1024 720918	NIKOLAY NAZAROV	{"email": "nikolay_nazarov-1971@postgrespro.ru", "phone": "+70824689964"}
0005432182113	881BCC	0777 905869	SERGEY POPOV	{"phone": "+70571491356"}
0005432182114	881BCC	2933 021839	VIKTOR FEDOROV	{"phone": "+70573885417"}
0005432182115	B1DD9E	8896 455350	FELIKS SHEVCHENKO	{"email": "feliks_shevchenko07101956@postgrespro.ru", "phone": "+70401132110"}
0005432182116	B1DD9E	1108 807028	SERGEY KUZNECOV	{"phone": "+70176278484"}
0005432182117	E5C03F	5321 690623	FARIT OSIPOV	{"phone": "+70757816281"}
0005432182118	2A9FE1	2624 098873	ANDREY NOVIKOV	{"email": "novikov_andrey_121972@postgrespro.ru", "phone": "+70250702504"}
0005432182119	2A9FE1	8346 002828	GALINA ILINA	{"email": "g-ilina1967@postgrespro.ru", "phone": "+70463535347"}
0005432182120	2A9FE1	0856 351083	SERGEY MARTYNOV	{"phone": "+70080979870"}
0005432182121	374C8B	2472 050095	RAISA SOKOLOVA	{"phone": "+70737109915"}
0005432182122	6E9F22	2740 219390	EVGENIY SIDOROV	{"phone": "+70067730115"}
0005432182123	6E9F22	0967 098853	DENIS IVANOV	{"email": "denisivanov-08091978@postgrespro.ru", "phone": "+70013508790"}
0005432182124	517F23	6445 655839	ALEKSEY VLASOV	{"email": "aleksey.vlasov.22011979@postgrespro.ru", "phone": "+70963911517"}
0005432182125	B2C994	3522 472344	YANA SCHERBAKOVA	{"phone": "+70771952421"}
0005432182126	B2C994	4580 043571	ALEKSANDR SEMENOV	{"email": "asemenov1973@postgrespro.ru", "phone": "+70916114965"}
0005432182127	FDC6D5	9479 861905	ELENA BORISOVA	{"email": "borisova_e-1977@postgrespro.ru", "phone": "+70449917640"}
0005432182128	FDC6D5	5639 798967	ROMAN SIDOROV	{"phone": "+70226401038"}
0005432182130	BE055C	1365 427998	ALEKSANDR ROMANOV	{"phone": "+70322414189"}
0005432182131	0549F6	3973 158789	POLINA SOKOLOVA	{"phone": "+70667072146"}
0005432182132	BE5032	5779 276819	ANASTASIYA NAUMOVA	{"phone": "+70442831545"}
0005432182133	BE5032	9848 815812	ALEKSEY MIRONOV	{"phone": "+70445665892"}
0005432182134	C65497	2390 843181	OLGA NIKOLAEVA	{"email": "o_nikolaeva_1978@postgrespro.ru", "phone": "+70427945990"}
0005432182135	C65497	5310 745881	EVGENIY FOMIN	{"phone": "+70068391034"}
0005432182136	5BA00F	4170 986414	ELENA TROFIMOVA	{"phone": "+70720059526"}
0005432182137	14245E	2415 794506	YURIY GAVRILOV	{"phone": "+70491160615"}
0005432182138	14245E	1452 319757	IGOR DMITRIEV	{"email": "dmitriev.igor_101979@postgrespro.ru", "phone": "+70768438646"}
0005432182139	851542	4485 816608	NINA IVANOVA	{"phone": "+70560978135"}
0005432182140	66B9D6	1975 680439	GALINA VASILEVA	{"phone": "+70757400194"}
0005432182141	59C8BC	2062 248141	VLADIMIR SEMENOV	{"email": "v-semenov.1963@postgrespro.ru", "phone": "+70630745243"}
0005432182142	F1EFB9	9615 401357	MARIYA PETROVA	{"phone": "+70011559351"}
0005432182143	758674	2817 457627	ARTEMIY VASILEV	{"phone": "+70566215162"}
0005432182144	ED8AB2	2080 009727	DARYA FOMINA	{"phone": "+70846216153"}
0005432182145	82E71A	8996 097296	TATYANA MOROZOVA	{"email": "morozovatatyana-091964@postgrespro.ru", "phone": "+70139847535"}
0005432182146	C1D95A	2856 372328	NIKOLAY SAVELEV	{"phone": "+70937107129"}
0005432182147	E33E09	3823 960009	SERGEY GRIGOREV	{"phone": "+70723715416"}
0005432182148	E33E09	1172 255126	VASILISA LAZAREVA	{"email": "v_lazareva.1982@postgrespro.ru", "phone": "+70706934095"}
0005432182149	A93A96	5440 392934	ALEKSANDR MOROZOV	{"email": "morozovaleksandr-1970@postgrespro.ru", "phone": "+70165611274"}
0005432182150	E94AD7	5423 489748	EVGENIY GORBUNOV	{"phone": "+70626548747"}
0005432182151	14BF36	9829 870369	EKATERINA PETROVA	{"phone": "+70925098008"}
0005432182152	14BF36	2015 587572	OKSANA GORBUNOVA	{"email": "gorbunova-oksana-04061970@postgrespro.ru", "phone": "+70331538707"}
0005432182153	14BF36	2360 202759	NATALYA LUKYANOVA	{"phone": "+70849983283"}
0005432182154	0DCC0E	0341 538171	RUSLAN KUDRYASHOV	{"email": "kudryashov-r_1967@postgrespro.ru", "phone": "+70488097571"}
0005432182155	0DCC0E	4452 990882	MARIYA KOZLOVA	{"email": "kozlova.m.05041983@postgrespro.ru", "phone": "+70868688547"}
0005432182156	CE19E6	8794 204444	ELIZAVETA MALYSHEVA	{"phone": "+70176591662"}
0005432182157	16A780	3351 886500	ANNA MOROZOVA	{"phone": "+70099355261"}
0005432182158	229706	7384 668232	ALEKSANDR POPOV	{"email": "popov.a_02011979@postgrespro.ru", "phone": "+70625707325"}
0005432182159	229706	6986 204149	NATALYA CHERNOVA	{"phone": "+70878444946"}
0005432182160	D52CB6	5140 913488	NATALYA NESTEROVA	{"email": "nesterova.natalya.111978@postgrespro.ru", "phone": "+70129772454"}
0005432182161	6C2D74	2663 269255	SOFYA NOVIKOVA	{"phone": "+70056653250"}
0005432182162	928123	6465 982260	ANNA KOROLEVA	{"phone": "+70669723628"}
0005432182163	928123	5590 024481	OLEG MARTYNOV	{"email": "martynovoleg1968@postgrespro.ru", "phone": "+70587740450"}
0005432182164	8DC453	0668 641890	ANASTASIYA BELOVA	{"phone": "+70296766058"}
0005432182165	83C744	4603 441742	NATALYA POLYAKOVA	{"phone": "+70425076077"}
0005432182166	A3CD20	5892 619454	KSENIYA VOLKOVA	{"phone": "+70329838788"}
0005432182167	AF84D5	6537 710517	MARIYA IVANOVA	{"email": "ivanova_mariya21111971@postgrespro.ru", "phone": "+70649001027"}
0005432182168	81F199	1838 258420	ANASTASIYA NESTEROVA	{"email": "anastasiya.nesterova1974@postgrespro.ru", "phone": "+70136425251"}
0005432182169	81F199	6839 059437	VLADIMIR IVANOV	{"email": "vivanov-04081958@postgrespro.ru", "phone": "+70514130741"}
0005432182170	6375A9	4069 708989	IRINA NAUMOVA	{"phone": "+70888308223"}
0005432182171	832407	7319 035441	OLEG IVANOV	{"email": "o.ivanov-031971@postgrespro.ru", "phone": "+70069549250"}
0005432182172	2F583B	3857 280523	ALEKSANDRA MOROZOVA	{"email": "aleksandra_morozova_1968@postgrespro.ru", "phone": "+70135054072"}
0005432182173	16D07C	6237 571781	MAKSIM SMIRNOV	{"email": "m-smirnov-1970@postgrespro.ru", "phone": "+70834103432"}
0005432182174	064728	8144 667924	MIKHAIL KRASNOV	{"email": "krasnovmikhail.111974@postgrespro.ru", "phone": "+70285719069"}
0005432182175	064728	6861 510168	INNA ISAEVA	{"email": "isaeva.inna-1971@postgrespro.ru", "phone": "+70889233376"}
0005432182176	E8B305	6274 407306	GUZEL MASLOVA	{"email": "guzelmaslova_27101974@postgrespro.ru", "phone": "+70593062673"}
0005432182177	96A2C1	2430 816327	ALEKSANDR KULIKOV	{"email": "a.kulikov.28071966@postgrespro.ru", "phone": "+70138493053"}
0005432182178	ABAC3B	7611 544015	YURIY BELOV	{"phone": "+70910764067"}
0005432182179	ABAC3B	2798 880538	MARIYA LOGINOVA	{"phone": "+70023392544"}
0005432182180	8E4A00	7753 476600	OLGA EGOROVA	{"email": "egorova.o-15121971@postgrespro.ru", "phone": "+70515808294"}
0005432182181	8FE9BA	3663 819533	KSENIYA FOMINA	{"email": "k_fomina.17031973@postgrespro.ru", "phone": "+70729133040"}
0005432182182	9E192F	7128 339304	VYACHESLAV VLASOV	{"phone": "+70568110278"}
0005432182183	DA54CF	0403 360576	NIKITA VOROBEV	{"phone": "+70126223347"}
0005432182184	DA54CF	7460 067585	VLADIMIR POPOV	{"phone": "+70221591515"}
0005432182185	276D2E	3275 983144	VIKTORIYA YAKOVLEVA	{"phone": "+70277733168"}
0005432182186	276D2E	0548 755038	MARIYA KRASNOVA	{"phone": "+70717033414"}
0005432182187	ED86B9	2633 073564	TIMOFEY EGOROV	{"email": "timofeyegorov-1968@postgrespro.ru", "phone": "+70858951761"}
0005432182188	D70C52	5459 815232	VIKTOR ZAKHAROV	{"phone": "+70119464591"}
0005432182189	3A7752	0720 267320	ALEVTINA LEBEDEVA	{"email": "a_lebedeva121960@postgrespro.ru", "phone": "+70378597110"}
0005432182190	3A7752	5772 113049	ANASTASIYA KALININA	{"email": "kalinina.anastasiya_1969@postgrespro.ru", "phone": "+70293519160"}
0005432182191	3A7752	2824 067476	OLGA TITOVA	{"email": "olga_titova-13021967@postgrespro.ru", "phone": "+70949219424"}
0005432182192	E43704	8368 313467	NIKOLAY CHERNOV	{"phone": "+70739402992"}
0005432182249	5B09DD	4897 400330	ALEKSANDR GAVRILOV	{"phone": "+70884667540"}
0005432182193	E21BCF	0907 806634	ALENA NAUMOVA	{"email": "a_naumova.1970@postgrespro.ru", "phone": "+70881669572"}
0005432182194	70E9DD	7669 716889	VERA KALININA	{"email": "kalininavera.23021973@postgrespro.ru", "phone": "+70777849511"}
0005432182195	B97FFD	0997 114443	ARTEM KUZNECOV	{"phone": "+70021312695"}
0005432182196	B7B7BB	4200 623801	ANDREY ORLOV	{"phone": "+70488024748"}
0005432182197	B7B7BB	8875 321108	GENNADIY BONDARENKO	{"email": "bondarenkog-101975@postgrespro.ru", "phone": "+70502983767"}
0005432182198	B7B7BB	9914 660733	VALERIY VOLKOV	{"phone": "+70849332317"}
0005432182199	FAD025	1746 307576	EKATERINA VOLKOVA	{"email": "volkova.ekaterina.011966@postgrespro.ru", "phone": "+70429565460"}
0005432182200	1E9219	0677 360865	ANATOLIY BELOV	{"email": "belovanatoliy-01011974@postgrespro.ru", "phone": "+70456792399"}
0005432182201	1E9219	2613 373727	MARINA IVANOVA	{"email": "ivanova.marina-1974@postgrespro.ru", "phone": "+70555001026"}
0005432182202	0E01AE	6411 202923	LEONID VASILEV	{"phone": "+70991537930"}
0005432182203	8C6778	8885 740524	PAVEL ORLOV	{"phone": "+70496516102"}
0005432182204	18458D	8837 365237	MIKHAIL SERGEEV	{"email": "msergeev.13011977@postgrespro.ru", "phone": "+70184666251"}
0005432182205	0FD55A	8679 361071	ALEKSANDRA ZAYCEVA	{"phone": "+70269344556"}
0005432182206	0FD55A	2270 134762	EKATERINA ZOTOVA	{"phone": "+70469741559"}
0005432182207	9CB9AE	6806 737322	NIKOLAY KUZMIN	{"email": "n.kuzmin_1977@postgrespro.ru", "phone": "+70763416616"}
0005432182208	9CB9AE	7442 658251	EKATERINA MIRONOVA	{"phone": "+70490062262"}
0005432182209	D9F687	5741 792709	VERONIKA SCHERBAKOVA	{"email": "scherbakova-v_27061973@postgrespro.ru", "phone": "+70908663078"}
0005432182210	66B8D6	6093 356873	NATALYA OSIPOVA	{"email": "osipovan16101979@postgrespro.ru", "phone": "+70293979797"}
0005432182211	66B8D6	7168 127101	NIKOLAY BELOV	{"phone": "+70561828493"}
0005432182212	1BB4E7	8750 984973	VASILIY ROMANOV	{"email": "romanovvasiliy-031967@postgrespro.ru", "phone": "+70587400200"}
0005432182213	78BC1F	1027 798249	FATIMA DANILOVA	{"phone": "+70027810756"}
0005432182214	799540	9168 479040	PAVEL SOKOLOV	{"phone": "+70679340798"}
0005432182215	799540	9206 741087	VALERIY MOISEEV	{"phone": "+70286083165"}
0005432182216	DB22E2	8256 597038	OLGA LOGINOVA	{"phone": "+70498611067"}
0005432182217	DB22E2	3732 430709	OLGA MAKSIMOVA	{"email": "maksimova-o.1970@postgrespro.ru", "phone": "+70515330194"}
0005432182218	DB22E2	5813 883224	DANIL ALEKSEEV	{"phone": "+70607309005"}
0005432182219	F24996	1342 109992	NINA IVANOVA	{"email": "ivanova.n.1983@postgrespro.ru", "phone": "+70087039259"}
0005432182220	D82E4E	8256 212166	ROMAN FEDOTOV	{"email": "fedotov_r_1962@postgrespro.ru", "phone": "+70293179371"}
0005432182221	158402	7271 187676	ALLA KONDRATEVA	{"email": "kondrateva_alla22111964@postgrespro.ru", "phone": "+70051796074"}
0005432182222	158402	0089 079823	TATYANA ROMANOVA	{"phone": "+70252499084"}
0005432182223	EEC98F	9612 060655	NINA GUSEVA	{"email": "guseva.n.1965@postgrespro.ru", "phone": "+70981403223"}
0005432182224	EEC98F	5382 589183	NATALYA ZAYCEVA	{"email": "zaycevanatalya1967@postgrespro.ru", "phone": "+70899967900"}
0005432182225	D3AB7E	5728 823410	ZINAIDA TARASOVA	{"phone": "+70591258112"}
0005432182226	885590	5538 222228	ALEKSANDR KUZNECOV	{"phone": "+70820516818"}
0005432182227	885590	3077 400962	NIKOLAY MOROZOV	{"phone": "+70074637306"}
0005432182228	9C612A	4662 329514	VALENTINA FOMINA	{"phone": "+70753231050"}
0005432182229	0BCDF3	0569 874507	ANASTASIYA EFREMOVA	{"phone": "+70322247145"}
0005432182230	0BCDF3	1512 584553	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey_091970@postgrespro.ru", "phone": "+70277687043"}
0005432182231	2C2A17	2122 451933	PETR SAVELEV	{"email": "petr_savelev011969@postgrespro.ru", "phone": "+70067285866"}
0005432182232	2C2A17	6211 497744	VALERIY VASILEV	{"phone": "+70346427706"}
0005432182233	AA897A	3387 617144	ALINA OSIPOVA	{"email": "osipova.a04101974@postgrespro.ru", "phone": "+70698221839"}
0005432182234	C9D5B7	3925 217311	ROMAN VOROBEV	{"email": "vorobev.r.29101966@postgrespro.ru", "phone": "+70559801730"}
0005432182235	C9D5B7	6153 235665	LIDIYA KOZLOVA	{"email": "lidiya_kozlova-1983@postgrespro.ru", "phone": "+70890048897"}
0005432182236	7BE1F6	2840 112334	LYUBOV GERASIMOVA	{"phone": "+70719165051"}
0005432182237	767823	8803 183712	DMITRIY AFANASEV	{"phone": "+70758352830"}
0005432182238	767823	0864 081451	VERA GAVRILOVA	{"phone": "+70778786608"}
0005432182239	42846B	8032 881614	INNA MAKAROVA	{"email": "inna-makarova1972@postgrespro.ru", "phone": "+70598039924"}
0005432182240	608454	3401 974705	VALENTIN MOISEEV	{"email": "moiseev_v-24081964@postgrespro.ru", "phone": "+70652629340"}
0005432182241	369CFD	7426 907671	ZINAIDA DMITRIEVA	{"phone": "+70276745322"}
0005432182242	7FCE02	5377 146665	DMITRIY PETROV	{"phone": "+70886684753"}
0005432182354	B06157	4018 193138	SERGEY EGOROV	{"phone": "+70486955051"}
0005432182243	7FCE02	9454 300974	LYUDMILA GERASIMOVA	{"email": "l_gerasimova.121973@postgrespro.ru", "phone": "+70612379613"}
0005432182244	08B0E7	2961 996369	VALENTINA IVANOVA	{"email": "v.ivanova-1974@postgrespro.ru", "phone": "+70229906522"}
0005432182245	5B28F3	0371 454393	ANNA SEMENOVA	{"email": "semenova_a1971@postgrespro.ru", "phone": "+70501298565"}
0005432182246	5B28F3	3126 123658	VLADISLAV ILIN	{"phone": "+70824017631"}
0005432182247	E10EB3	2378 514223	RAISA KOMAROVA	{"email": "raisa_komarova_1966@postgrespro.ru", "phone": "+70304822134"}
0005432182248	87BE3E	8168 904737	LARISA IVANOVA	{"phone": "+70505540087"}
0005432182250	21F1AC	3109 709605	DMITRIY POPOV	{"phone": "+70146986806"}
0005432182251	21F1AC	4432 012133	MIKHAIL ALEKSEEV	{"email": "mikhailalekseev_061966@postgrespro.ru", "phone": "+70142734324"}
0005432182252	4DB85E	0371 298222	RAISA ALEKSEEVA	{"phone": "+70717221172"}
0005432182253	4DB85E	1847 972541	DARYA NAUMOVA	{"phone": "+70387163390"}
0005432182254	1DACFE	9296 113923	ZINAIDA KOVALEVA	{"email": "kovaleva.z.041965@postgrespro.ru", "phone": "+70669127086"}
0005432182255	1DACFE	4145 081600	DANIIL IVANOV	{"phone": "+70050423510"}
0005432182256	777F94	5532 627026	VALENTINA KRASNOVA	{"phone": "+70184717227"}
0005432182257	777F94	2207 244283	DMITRIY OSIPOV	{"phone": "+70793266582"}
0005432182258	7288F1	4578 357503	ALEKSANDR ANTONOV	{"email": "antonov_a.071968@postgrespro.ru", "phone": "+70940324267"}
0005432182259	24915A	8521 330657	LYUDMILA MELNIKOVA	{"phone": "+70772485832"}
0005432182260	7C78C1	6772 447333	NINA KISELEVA	{"phone": "+70477097154"}
0005432182261	8E40EB	6690 405416	EVGENIY NIKOLAEV	{"phone": "+70822998609"}
0005432182262	E94DE9	2312 411895	YURIY IVANOV	{"email": "ivanov.yuriy.04011973@postgrespro.ru", "phone": "+70552597320"}
0005432182263	EAFC89	5980 246055	VLADIMIR GERASIMOV	{"phone": "+70538477907"}
0005432182264	7914C7	8975 750028	ARMEN CHERNOV	{"phone": "+70753534783"}
0005432182265	81B73D	4853 526450	NIKOLAY GERASIMOV	{"phone": "+70383956627"}
0005432182266	4C0C4C	1531 474774	NINA PETROVA	{"phone": "+70070514891"}
0005432182267	F01B70	6781 599112	SVETLANA POPOVA	{"email": "s-popova091971@postgrespro.ru", "phone": "+70766055594"}
0005432182268	A89767	9986 473921	PAVEL FEDOROV	{"phone": "+70245327748"}
0005432182269	A17EC4	9946 126260	NADEZHDA VLASOVA	{"email": "vlasovanadezhda1982@postgrespro.ru", "phone": "+70198471219"}
0005432182270	A17EC4	7720 221372	PAVEL CHERNOV	{"phone": "+70590519528"}
0005432182271	468924	1844 346648	PAVEL ZHURAVLEV	{"email": "pavel_zhuravlev.041982@postgrespro.ru", "phone": "+70323288421"}
0005432182272	468924	8354 769726	NADEZHDA TIMOFEEVA	{"phone": "+70263396851"}
0005432182273	06C704	8095 740244	STANISLAV MIKHAYLOV	{"phone": "+70963974156"}
0005432182274	09F011	9531 392223	VALERIYA TIKHONOVA	{"email": "valeriya.tikhonova-1968@postgrespro.ru", "phone": "+70785908359"}
0005432182275	F2F280	5053 682893	OLESYA KUDRYASHOVA	{"email": "kudryashova-o_18021972@postgrespro.ru", "phone": "+70014307038"}
0005432182276	F2F280	5500 815548	GALINA KUZNECOVA	{"email": "g_kuznecova-031980@postgrespro.ru", "phone": "+70864077917"}
0005432182277	9F0386	5450 549275	SERGEY BONDARENKO	{"email": "bondarenko_s_1972@postgrespro.ru", "phone": "+70048694282"}
0005432182278	9ADF38	6325 897141	KARINA KARPOVA	{"email": "k.karpova_1982@postgrespro.ru", "phone": "+70349129368"}
0005432182279	9ADF38	0436 896736	GALINA NESTEROVA	{"email": "gnesterova-18121962@postgrespro.ru", "phone": "+70356583006"}
0005432182280	3D0D7E	3603 409632	VLADIMIR NAZAROV	{"phone": "+70771351883"}
0005432182281	168F82	5789 180805	VLADIMIR IVANOV	{"phone": "+70000066619"}
0005432182282	E64471	6207 174216	NADEZHDA NIKOLAEVA	{"email": "nikolaevan081983@postgrespro.ru", "phone": "+70222964815"}
0005432182283	52152D	9576 135869	VLADIMIR FOMIN	{"email": "fominvladimir061971@postgrespro.ru", "phone": "+70174461422"}
0005432182284	E3FBB3	9721 389896	IRINA SEMENOVA	{"email": "irina-semenova_11091964@postgrespro.ru", "phone": "+70692992616"}
0005432182285	E3FBB3	3169 292579	ANNA VASILEVA	{"phone": "+70336929454"}
0005432182286	E3FBB3	1573 892439	ANATOLIY ROMANOV	{"email": "a_romanov31121974@postgrespro.ru", "phone": "+70492611382"}
0005432182287	47DCEA	4668 814287	OLEG KUZNECOV	{"phone": "+70944911931"}
0005432182288	968EDE	3040 955164	TATYANA PETROVA	{"phone": "+70375322197"}
0005432182289	10AAB6	9949 481654	VIKTOR KARPOV	{"phone": "+70507436432"}
0005432182290	CEACC8	1676 049256	MIKHAIL SMIRNOV	{"phone": "+70583924827"}
0005432182291	CAE499	4432 757728	OKSANA MIRONOVA	{"email": "mironova.o-051965@postgrespro.ru", "phone": "+70725429147"}
0005432182292	CAE499	6882 673983	NIKOLAY VOROBEV	{"phone": "+70992931497"}
0005432182293	CAE499	0614 407309	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr.091972@postgrespro.ru", "phone": "+70864358653"}
0005432182294	E6ED94	3444 433840	IRINA SAVELEVA	{"phone": "+70149157208"}
0005432182295	304545	3680 597729	SERGEY GRIGOREV	{"email": "grigorevs1978@postgrespro.ru", "phone": "+70976953997"}
0005432182296	304545	7585 997833	YULIYA EFIMOVA	{"email": "y-efimova-101961@postgrespro.ru", "phone": "+70514510283"}
0005432182297	7CB95C	1836 363974	ALEFTINA DAVYDOVA	{"email": "davydova_aleftina.021965@postgrespro.ru", "phone": "+70906668368"}
0005432182298	7CB95C	7187 915868	KLAVDIYA NIKITINA	{"phone": "+70462676696"}
0005432182355	CF1966	3343 096201	OLEG POPOV	{"phone": "+70986475281"}
0005432182299	B3378F	7358 321805	ALEKSEY VOLKOV	{"email": "volkov-aleksey_1977@postgrespro.ru", "phone": "+70830019558"}
0005432182300	0432E7	4977 937805	EGOR KUZNECOV	{"phone": "+70572507354"}
0005432182301	0432E7	7038 209379	ALEKSANDR KULIKOV	{"phone": "+70482579575"}
0005432182302	36C775	8744 129336	PETR MIRONOV	{"email": "mironov_petr_091979@postgrespro.ru", "phone": "+70865546805"}
0005432182303	D4DE21	2182 028117	DZHAMILYA NIKOLAEVA	{"email": "nikolaeva_dzhamilya-1966@postgrespro.ru", "phone": "+70381768517"}
0005432182304	D4DE21	3645 015573	ARTEM PAVLOV	{"email": "pavlov.a_031969@postgrespro.ru", "phone": "+70141019292"}
0005432182305	6C228A	0211 379049	MARINA IVANOVA	{"email": "marinaivanova1966@postgrespro.ru", "phone": "+70315489343"}
0005432182306	6C228A	1908 562082	NATALYA NESTEROVA	{"phone": "+70331611770"}
0005432182307	6C228A	6480 116092	VLADISLAV TIMOFEEV	{"email": "timofeev.v_09031959@postgrespro.ru", "phone": "+70986867662"}
0005432182308	664909	7654 670265	EKATERINA IVANOVA	{"phone": "+70497285989"}
0005432182309	664909	9915 249411	PELAGEYA EFREMOVA	{"phone": "+70560809913"}
0005432182310	003FA5	4864 231194	ANNA EGOROVA	{"email": "anna.egorova.081979@postgrespro.ru", "phone": "+70033391926"}
0005432182311	CE1EAA	2853 110513	KIRILL ZHURAVLEV	{"email": "kirillzhuravlev_23111977@postgrespro.ru", "phone": "+70717596157"}
0005432182312	CE1EAA	2663 508992	TATYANA POPOVA	{"email": "popova-tatyana.18081969@postgrespro.ru", "phone": "+70020173243"}
0005432182313	55109A	4432 032950	ALEKSANDR KUZMIN	{"phone": "+70747033235"}
0005432182314	9B4CBB	0058 598945	ALINA ALEKSEEVA	{"email": "alina.alekseeva.27071972@postgrespro.ru", "phone": "+70407492182"}
0005432182315	9B4CBB	3282 141097	TATYANA VOLKOVA	{"email": "t_volkova.29091974@postgrespro.ru", "phone": "+70520683334"}
0005432182316	D0B7D1	0658 321080	SERGEY MELNIKOV	{"phone": "+70588672401"}
0005432182317	18399C	0136 098311	SERGEY KARPOV	{"phone": "+70319258984"}
0005432182318	18399C	8936 400458	KIRILL DENISOV	{"email": "kirill_denisov091965@postgrespro.ru", "phone": "+70478917287"}
0005432182319	757E5A	4150 177519	ULYANA FOMINA	{"email": "fomina_u111990@postgrespro.ru", "phone": "+70177397331"}
0005432182320	9F5EC4	6104 350067	ANNA KUZMINA	{"email": "kuzmina-a_1970@postgrespro.ru", "phone": "+70450013749"}
0005432182321	B0BC02	3705 160301	TATYANA FEDOROVA	{"email": "tatyana.fedorova-22061970@postgrespro.ru", "phone": "+70741172359"}
0005432182322	18C6AC	8680 062408	ANATOLIY MAKAROV	{"phone": "+70458535501"}
0005432182323	A4F470	3054 935062	LIDIYA FROLOVA	{"phone": "+70538823885"}
0005432182324	5D264C	6467 638670	VITALIY GRIGOREV	{"email": "grigorev_v25041968@postgrespro.ru", "phone": "+70480214292"}
0005432182325	509501	5377 198786	KAMIL KUDRYASHOV	{"phone": "+70317483202"}
0005432182326	AE39EA	1929 532128	PETR IVANOV	{"phone": "+70299936489"}
0005432182327	585A42	0272 317169	GALINA BOGDANOVA	{"email": "g-bogdanova-1976@postgrespro.ru", "phone": "+70494126319"}
0005432182328	585A42	3142 081483	PAVEL MARTYNOV	{"email": "pavel_martynov-051970@postgrespro.ru", "phone": "+70082432816"}
0005432182329	759A93	9750 699051	IRINA DANILOVA	{"email": "idanilova.101977@postgrespro.ru", "phone": "+70497420148"}
0005432182330	54A380	5789 255650	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr-1968@postgrespro.ru", "phone": "+70940695583"}
0005432182331	5F4D28	7729 012183	EVGENIY KARPOV	{"email": "karpov_e.1964@postgrespro.ru", "phone": "+70355192621"}
0005432182332	1B2DE5	7155 846453	IVAN BELOV	{"email": "i-belov_27011976@postgrespro.ru", "phone": "+70699972544"}
0005432182333	8B3697	5825 572969	DMITRIY SERGEEV	{"email": "sergeev-dmitriy.05021978@postgrespro.ru", "phone": "+70333869523"}
0005432182334	8B3697	1896 553044	ZOYA KISELEVA	{"email": "zoya.kiseleva_111973@postgrespro.ru", "phone": "+70991143273"}
0005432182335	08D3E1	1155 139577	ILYA ALEKSEEV	{"phone": "+70057739176"}
0005432182336	24D107	6121 042832	LARISA TARASOVA	{"phone": "+70673723281"}
0005432182337	F4A5F5	7680 486348	VIKTOR MIRONOV	{"phone": "+70439210884"}
0005432182338	59C6AE	3503 461004	VIKTOR KISELEV	{"phone": "+70506382850"}
0005432182339	59C6AE	8380 885672	ROMAN MELNIKOV	{"email": "melnikov.roman-1972@postgrespro.ru", "phone": "+70278529980"}
0005432182340	3D2019	1919 327787	ALEKSANDRA NIKIFOROVA	{"email": "nikiforova-a031981@postgrespro.ru", "phone": "+70592433916"}
0005432182341	047B23	9562 838399	EVGENIY RODIONOV	{"phone": "+70007988186"}
0005432182342	047B23	7097 480076	TATYANA GRISHINA	{"phone": "+70424754708"}
0005432182343	7FD0C1	2373 152637	ALEKSANDR OSIPOV	{"email": "osipovaleksandr1965@postgrespro.ru", "phone": "+70743411555"}
0005432182344	BEF913	3823 816225	GENNADIY POPOV	{"phone": "+70106477368"}
0005432182345	088FAA	0038 936588	DMITRIY VASILEV	{"email": "vasilev.dmitriy_051970@postgrespro.ru", "phone": "+70848417997"}
0005432182346	2D6964	7404 977932	ANASTASIYA YAKOVLEVA	{"phone": "+70073661995"}
0005432182347	2D6964	5842 353029	ANNA DAVYDOVA	{"phone": "+70857182587"}
0005432182348	903767	0837 983287	NADEZHDA KOVALEVA	{"email": "nadezhdakovaleva1974@postgrespro.ru", "phone": "+70533577279"}
0005432182349	4E7569	7075 042037	MARIYA SAVELEVA	{"email": "m.saveleva_1971@postgrespro.ru", "phone": "+70759626980"}
0005432182350	33B446	0054 658118	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.svetlana_17111965@postgrespro.ru", "phone": "+70572239948"}
0005432182351	D924BD	4062 534143	ELENA MAKSIMOVA	{"email": "maksimova-elena021974@postgrespro.ru", "phone": "+70826503389"}
0005432182352	7DD159	5098 357540	VASILIY GORBUNOV	{"phone": "+70358495698"}
0005432182353	B06157	9833 909067	ANASTASIYA POTAPOVA	{"email": "potapova-a-061976@postgrespro.ru", "phone": "+70420364982"}
0005432182356	C39802	3396 991794	VYACHESLAV SOROKIN	{"email": "v_sorokin1979@postgrespro.ru", "phone": "+70728886542"}
0005432182357	CDCFBC	0964 489675	KONSTANTIN BONDARENKO	{"email": "bondarenko_konstantin.08121968@postgrespro.ru", "phone": "+70840598427"}
0005432182358	063E33	1761 251432	TATYANA POLYAKOVA	{"phone": "+70261234377"}
0005432182359	5B898F	3868 717262	LYUDMILA SOLOVEVA	{"email": "soloveva.l011977@postgrespro.ru", "phone": "+70600823257"}
0005432182360	7A4615	6341 175383	ANNA NIKITINA	{"phone": "+70058092216"}
0005432182361	15C495	6798 443366	ELENA VOROBEVA	{"phone": "+70057829104"}
0005432182362	85FB28	5771 772010	LIDIYA ANDREEVA	{"email": "andreeva-l1983@postgrespro.ru", "phone": "+70357552379"}
0005432182363	ECD919	4459 500014	ANNA AKIMOVA	{"email": "aakimova-05031969@postgrespro.ru", "phone": "+70172696597"}
0005432182364	25401A	4968 382324	VALENTINA MOROZOVA	{"phone": "+70801035282"}
0005432182365	5D6B7E	6854 840980	ALEKSANDR MATVEEV	{"phone": "+70740121189"}
0005432182366	5D6B7E	4069 063186	OKSANA AKIMOVA	{"email": "oksana-akimova-1968@postgrespro.ru", "phone": "+70632324962"}
0005432182367	35A40F	6759 863373	NADEZHDA ANDREEVA	{"email": "nadezhda_andreeva_121972@postgrespro.ru", "phone": "+70692551945"}
0005432182368	5EC2DF	9414 300923	ALEKSEY PETROV	{"phone": "+70021388709"}
0005432182369	5EC2DF	2698 439361	RAMIL VASILEV	{"phone": "+70674426635"}
0005432182370	586CBC	6759 048837	EVGENIY EGOROV	{"email": "evgeniy-egorov_03101971@postgrespro.ru", "phone": "+70543695960"}
0005432182371	586CBC	7353 395994	ANDREY KAZAKOV	{"phone": "+70843135091"}
0005432182372	2A1371	6298 932896	SERGEY SIDOROV	{"email": "sergey_sidorov1977@postgrespro.ru", "phone": "+70933724344"}
0005432182373	2A1371	4238 188002	ANNA KISELEVA	{"phone": "+70631413632"}
0005432183428	9D0373	6429 185626	ELVIRA FILIPPOVA	{"email": "filippova.e.1969@postgrespro.ru", "phone": "+70141406562"}
0005432183429	9D0373	7535 783651	TAMARA VOROBEVA	{"email": "vorobeva.t1959@postgrespro.ru", "phone": "+70539418321"}
0005432183430	41CC80	1811 249645	DARYA IVANOVA	{"email": "ivanova.d16071975@postgrespro.ru", "phone": "+70368937212"}
0005432183431	FC5DFA	1343 230832	KLAVDIYA LAZAREVA	{"email": "lazareva_k-1962@postgrespro.ru", "phone": "+70476571591"}
0005432183432	ADC6E9	6462 557737	LYUDMILA SMIRNOVA	{"phone": "+70379350933"}
0005432183433	B6A8B2	9600 929877	OLEG MOISEEV	{"phone": "+70841461253"}
0005432183434	B6A8B2	3381 555730	PAVEL FROLOV	{"email": "frolov-pavel_20021970@postgrespro.ru", "phone": "+70367040397"}
0005432183435	B6A8B2	3435 240958	LIDIYA NESTEROVA	{"phone": "+70599078769"}
0005432183436	379623	4188 595506	LYUBOV KOMAROVA	{"phone": "+70665067566"}
0005432183437	06CDDF	5069 902227	ALEKSANDR KONOVALOV	{"phone": "+70428262702"}
0005432183438	06CDDF	1509 964258	IGOR POPOV	{"phone": "+70716544226"}
0005432183439	E98C23	7200 586086	ELENA STEPANOVA	{"phone": "+70627032402"}
0005432183440	19DEBB	4352 432268	YULIYA BELOVA	{"email": "ybelova07041964@postgrespro.ru", "phone": "+70938825447"}
0005432183441	BBD97C	3389 950083	TAMARA KRASNOVA	{"phone": "+70283043547"}
0005432183442	E24C09	2933 043269	DMITRIY KAZAKOV	{"phone": "+70161513933"}
0005432183443	2E8CC5	3571 804468	TATYANA KONOVALOVA	{"email": "t.konovalova-1978@postgrespro.ru", "phone": "+70999220693"}
0005432183444	BBC215	4373 539280	LYUBOV LAZAREVA	{"email": "lazareva_lyubov.021971@postgrespro.ru", "phone": "+70758621869"}
0005432183445	BBC215	6993 535646	EVGENIY KOZLOV	{"email": "e_kozlov-1957@postgrespro.ru", "phone": "+70175488725"}
0005432183446	3F04EE	3027 515859	IVAN DENISOV	{"phone": "+70071723790"}
0005432183447	937E1F	2054 954079	ANASTASIYA GUSEVA	{"email": "anastasiya.guseva_07091967@postgrespro.ru", "phone": "+70156338488"}
0005432183448	937E1F	0432 417647	IGOR FEDOROV	{"email": "i_fedorov.08021967@postgrespro.ru", "phone": "+70972042530"}
0005432183449	937E1F	4479 740982	VIKTOR SOKOLOV	{"email": "sokolov_viktor_051983@postgrespro.ru", "phone": "+70557063830"}
0005432183450	A4B28E	3603 527143	YURIY KOROLEV	{"email": "korolev_yuriy.071977@postgrespro.ru", "phone": "+70484597026"}
0005432183451	30F847	7560 950737	ALESYA YUDINA	{"phone": "+70505734601"}
0005432183452	4ADCFC	6160 219661	SERGEY KOZLOV	{"email": "kozlov.sergey.011974@postgrespro.ru", "phone": "+70364115676"}
0005432183453	1AE489	7661 652407	SERGEY AFANASEV	{"email": "afanasev.s_1963@postgrespro.ru", "phone": "+70649306392"}
0005432183454	7BE68C	2118 139242	IVAN IVANOV	{"phone": "+70240330946"}
0005432183455	85AA71	7631 484176	ALEKSEY BONDARENKO	{"email": "bondarenkoa.011983@postgrespro.ru", "phone": "+70559306081"}
0005432183456	85AA71	7308 422980	BORIS KULIKOV	{"email": "kulikov_b1967@postgrespro.ru", "phone": "+70439348617"}
0005432183457	85AA71	1507 579358	EVGENIY AFANASEV	{"email": "evgeniy_afanasev1973@postgrespro.ru", "phone": "+70810902909"}
0005432183458	6B2942	4805 287108	NATALYA DENISOVA	{"phone": "+70551999317"}
0005432183459	030273	1271 504665	TATYANA NOVIKOVA	{"phone": "+70807918549"}
0005432183460	030273	8951 003237	EKATERINA PETROVA	{"email": "e_petrova_1984@postgrespro.ru", "phone": "+70993453955"}
0005432183461	B0CABE	5976 823004	VLADISLAV NOVIKOV	{"email": "novikov.vladislav101975@postgrespro.ru", "phone": "+70568363511"}
0005432183462	BC4445	5356 252053	LYUBOV MARTYNOVA	{"email": "lyubov-martynova.1967@postgrespro.ru", "phone": "+70353486432"}
0005432183463	BC4445	0982 819571	RAFAIL KONOVALOV	{"phone": "+70225749875"}
0005432183464	BFF9FC	0748 621587	ANNA VOROBEVA	{"email": "a.vorobeva_1977@postgrespro.ru", "phone": "+70164582769"}
0005432183465	CC255E	5184 034927	SERGEY DENISOV	{"email": "denisovs.1960@postgrespro.ru", "phone": "+70359066141"}
0005432183466	CC255E	7049 586422	EKATERINA FADEEVA	{"email": "fadeeva-e_101977@postgrespro.ru", "phone": "+70775713386"}
0005432183467	48025E	2518 924848	OLESYA LEBEDEVA	{"phone": "+70006302491"}
0005432183468	83F1D5	2240 396441	MARIYA GERASIMOVA	{"phone": "+70086991401"}
0005432183469	83F1D5	5043 240828	ALI NIKOLAEV	{"email": "nikolaev.a_071975@postgrespro.ru", "phone": "+70606959110"}
0005432183470	83F1D5	2184 361851	ALEKSANDR EGOROV	{"phone": "+70074448656"}
0005432183471	476798	0094 691775	VLADIMIR VASILEV	{"phone": "+70920555182"}
0005432183472	476798	9054 487995	VALERIY SOLOVEV	{"phone": "+70458411745"}
0005432183473	024D3B	5846 936526	MARIYA DANILOVA	{"email": "mariyadanilova-041973@postgrespro.ru", "phone": "+70908035209"}
0005432183474	024D3B	3367 949252	ANDREY IVANOV	{"email": "andrey.ivanov.1973@postgrespro.ru", "phone": "+70911136293"}
0005432183475	6E4C9B	9121 264241	LYUBOV LOGINOVA	{"email": "lyubov.loginova_01101973@postgrespro.ru", "phone": "+70674293474"}
0005432183476	30A096	1498 865313	ELVIRA ORLOVA	{"phone": "+70802371076"}
0005432183477	30A096	8585 819465	ANNA NESTEROVA	{"phone": "+70395627756"}
0005432183478	DD0C82	8619 043995	IRINA LUKYANOVA	{"phone": "+70697934601"}
0005432183479	B94CB0	2041 286551	SVETLANA ANISIMOVA	{"phone": "+70277772660"}
0005432183480	26BB35	5325 837912	ANDREY VOLKOV	{"phone": "+70364243500"}
0005432183481	26BB35	8450 041104	ULYANA SEMENOVA	{"email": "semenova_u.26071974@postgrespro.ru", "phone": "+70009138303"}
0005432183482	EED0C3	5589 442569	VERA ZHURAVLEVA	{"email": "zhuravleva_v.05091965@postgrespro.ru", "phone": "+70646771160"}
0005432183483	EED0C3	6826 392408	IVAN SEMENOV	{"phone": "+70544406972"}
0005432183484	FD777D	1990 306879	ANNA RODIONOVA	{"email": "a-rodionova111977@postgrespro.ru", "phone": "+70946027220"}
0005432183485	FD777D	7872 587227	EKATERINA MALYSHEVA	{"phone": "+70847006093"}
0005432183486	4B8D07	1035 415612	ARTEM ZAYCEV	{"phone": "+70057563140"}
0005432183487	76561B	6173 344567	EVGENIY BORISOV	{"phone": "+70769871939"}
0005432183488	225E9E	6345 481697	IGOR MOISEEV	{"phone": "+70351047721"}
0005432183489	AC8BC8	5233 923012	VYACHESLAV ZHUKOV	{"email": "v_zhukov-1973@postgrespro.ru", "phone": "+70653997831"}
0005432183490	AC8BC8	3857 719167	VASILIY MATVEEV	{"phone": "+70065205000"}
0005432183491	96162A	6049 503201	YAROSLAV NOVIKOV	{"phone": "+70608369250"}
0005432183492	D433EC	8749 590917	ARTEM ALEKSANDROV	{"email": "artem.aleksandrov.07041984@postgrespro.ru", "phone": "+70281207179"}
0005432183493	2045F6	2006 457821	IVAN VLASOV	{"phone": "+70518417697"}
0005432183494	1E8E22	7237 412514	MAKSIM SERGEEV	{"email": "m-sergeev.091967@postgrespro.ru", "phone": "+70870694205"}
0005432183495	1E8E22	8717 006149	TATYANA FILIPPOVA	{"phone": "+70329662052"}
0005432183496	24409E	3120 605116	VADIM KUZNECOV	{"phone": "+70048725160"}
0005432183497	DFDB62	8155 152251	SVETLANA KUDRYASHOVA	{"phone": "+70861131824"}
0005432183498	11D91E	2672 181139	EGOR ABRAMOV	{"phone": "+70654972782"}
0005432183499	11D91E	8057 464603	IVAN GERASIMOV	{"phone": "+70717382251"}
0005432183500	2CF812	0176 969138	ELENA FADEEVA	{"email": "fadeeva-e121960@postgrespro.ru", "phone": "+70641327111"}
0005432183501	29EAEF	8388 824808	GALINA KAZAKOVA	{"email": "kazakovag-071963@postgrespro.ru", "phone": "+70624625410"}
0005432183502	A75CB0	5559 137073	VALENTINA GORBUNOVA	{"email": "valentina.gorbunova-01041969@postgrespro.ru", "phone": "+70114054650"}
0005432183503	C317C9	2499 415214	VALENTINA KOZLOVA	{"email": "valentina_kozlova_03011963@postgrespro.ru", "phone": "+70573684479"}
0005432183504	6D5648	5000 171731	GALINA AKIMOVA	{"email": "akimova.g-1969@postgrespro.ru", "phone": "+70617430458"}
0005432183505	6D5648	8043 458523	VITALIY TARASOV	{"phone": "+70264751865"}
0005432183506	D5A77A	4950 393088	YURIY MAKAROV	{"email": "makarovyuriy-071966@postgrespro.ru", "phone": "+70296783627"}
0005432183507	FBDBEE	0076 689347	VLADIMIR SAVELEV	{"email": "savelev-vladimir26031962@postgrespro.ru", "phone": "+70791931317"}
0005432183508	B428B8	1620 061977	VLADIMIR CHERNOV	{"phone": "+70560571545"}
0005432183509	E14465	9638 751238	ELENA KAZAKOVA	{"email": "kazakova.elena121969@postgrespro.ru", "phone": "+70114045300"}
0005432183510	E14465	7620 296370	IRINA ANDREEVA	{"email": "andreevairina_1966@postgrespro.ru", "phone": "+70604586371"}
0005432183511	E14465	1904 607522	ALEVTINA KOZLOVA	{"email": "akozlova_081975@postgrespro.ru", "phone": "+70641793312"}
0005432183512	3D3A0A	5982 021931	ELENA LUKYANOVA	{"phone": "+70254960501"}
0005432183513	C182C4	5392 806347	LEONID SMIRNOV	{"email": "smirnov.l1976@postgrespro.ru", "phone": "+70588147269"}
0005432183514	A77DBD	0440 251886	YURIY SERGEEV	{"email": "yuriy_sergeev021975@postgrespro.ru", "phone": "+70751745217"}
0005432183515	B2503B	4012 385049	YURIY MIKHAYLOV	{"phone": "+70500159374"}
0005432183516	ECFD7A	9070 291943	ALEKSANDR DENISOV	{"phone": "+70727324406"}
0005432183517	7E6A45	3015 786017	PETR SIDOROV	{"email": "p.sidorov.1972@postgrespro.ru", "phone": "+70257169916"}
0005432183518	22616D	8451 360919	ANASTASIYA KUZNECOVA	{"phone": "+70922777686"}
0005432183519	22616D	0591 217691	GALINA SEMENOVA	{"phone": "+70501479596"}
0005432183520	3FB7D3	0658 023720	NADEZHDA VOROBEVA	{"email": "vorobeva-nadezhda-09061973@postgrespro.ru", "phone": "+70934965966"}
0005432183521	ED2B94	5765 396776	VASILIY SIDOROV	{"email": "vasiliy.sidorov081963@postgrespro.ru", "phone": "+70045681692"}
0005432183522	ED2B94	2169 855832	KRISTINA KUZMINA	{"phone": "+70780774623"}
0005432183523	5E5DBD	0270 796518	VLADIMIR ORLOV	{"email": "vladimir.orlov.06011958@postgrespro.ru", "phone": "+70010665892"}
0005432183524	520012	2276 661282	NINA KUZNECOVA	{"phone": "+70252454887"}
0005432183525	DB7018	3139 165263	ZINAIDA MATVEEVA	{"phone": "+70569585339"}
0005432183526	5A2322	8227 069285	MIKHAIL IVANOV	{"phone": "+70159728317"}
0005432183527	5A2322	1159 261331	EVGENIY BELOV	{"email": "e-belov11071983@postgrespro.ru", "phone": "+70877514869"}
0005432183528	5A2322	0321 619912	LYUDMILA SOROKINA	{"phone": "+70643890660"}
0005432184900	5C43BD	3566 005232	VADIM NOVIKOV	{"email": "novikov.vadim.13121969@postgrespro.ru", "phone": "+70968552409"}
0005432184901	F45DAD	2960 645009	VIKTOR KRASNOV	{"email": "krasnov_v13041970@postgrespro.ru", "phone": "+70534821035"}
0005432184902	C8387F	4001 979492	NATALYA ISAEVA	{"email": "isaeva.n.04031969@postgrespro.ru", "phone": "+70787935984"}
0005432184903	12C929	6462 074967	KLAVDIYA VASILEVA	{"email": "klavdiyavasileva-23021981@postgrespro.ru", "phone": "+70061654929"}
0005432184904	CB3B8B	9501 691589	ALEKSEY IVANOV	{"phone": "+70370983924"}
0005432184905	6D6C0C	1235 891406	ANATOLIY GRIGOREV	{"email": "grigorev-a.1972@postgrespro.ru", "phone": "+70715963306"}
0005432184906	29BA4B	7472 546491	OLEG MIRONOV	{"email": "mironov.o.18121960@postgrespro.ru", "phone": "+70443097042"}
0005432184907	5B35C2	1032 748307	NIKOLAY RODIONOV	{"email": "rodionov_n-26031966@postgrespro.ru", "phone": "+70794051984"}
0005432184908	5B35C2	5873 645518	ARSEN GUSEV	{"email": "gusev_a12121966@postgrespro.ru", "phone": "+70894611505"}
0005432184909	CD6A7D	2559 000070	ELENA TARASOVA	{"email": "tarasova-elena.1976@postgrespro.ru", "phone": "+70700188818"}
0005432184910	1B14F9	2017 938457	IRINA KOROLEVA	{"email": "koroleva_irina1965@postgrespro.ru", "phone": "+70856824618"}
0005432184911	1B14F9	3575 291123	OLEG KAZAKOV	{"email": "kazakov-oleg_081977@postgrespro.ru", "phone": "+70525895544"}
0005432184912	5E3CA6	0666 655651	ELENA VOROBEVA	{"email": "elenavorobeva.041981@postgrespro.ru", "phone": "+70457748134"}
0005432184913	6C4718	2345 122286	MARIYA MIKHAYLOVA	{"phone": "+70760980625"}
0005432184914	04AE48	6223 662739	DARYA PETROVA	{"phone": "+70569704910"}
0005432184915	3732EB	9302 918900	VALERIY NAZAROV	{"email": "v.nazarov.1958@postgrespro.ru", "phone": "+70168660949"}
0005432184916	3732EB	7985 206248	DMITRIY GRIGOREV	{"phone": "+70235434437"}
0005432184917	23FCB8	1429 690179	MARIYA ANDREEVA	{"email": "mandreeva111971@postgrespro.ru", "phone": "+70243502420"}
0005432184918	23FCB8	0834 847233	SERGEY ALEKSANDROV	{"phone": "+70860659216"}
0005432184919	8312CD	3867 577832	VALERIYA VLASOVA	{"email": "valeriya_vlasova.061970@postgrespro.ru", "phone": "+70405784276"}
0005432184920	8312CD	7164 744356	NINA SCHERBAKOVA	{"email": "n.scherbakova_121973@postgrespro.ru", "phone": "+70992214139"}
0005432184921	78A10B	0597 050057	OLGA DAVYDOVA	{"email": "davydova_olga101969@postgrespro.ru", "phone": "+70892202988"}
0005432184922	78A10B	2701 335332	ANTONINA NAZAROVA	{"email": "nazarova-antonina011974@postgrespro.ru", "phone": "+70269335505"}
0005432184923	962A9A	9437 929962	LILIYA FROLOVA	{"email": "frolova.l.101968@postgrespro.ru", "phone": "+70870163976"}
0005432184924	962A9A	0948 535081	ARTEM KOROLEV	{"phone": "+70265042117"}
0005432184925	01A13A	6547 015310	NADEZHDA ANDREEVA	{"email": "andreevanadezhda-101961@postgrespro.ru", "phone": "+70622414047"}
0005432184926	01A13A	5586 576676	ARTUR FEDOROV	{"email": "fedorov-a1972@postgrespro.ru", "phone": "+70832735102"}
0005432184927	01A13A	3147 215651	VLADISLAV KARPOV	{"email": "karpovvladislav_22041978@postgrespro.ru", "phone": "+70568023836"}
0005432184928	4710A1	8499 725132	KONSTANTIN ROMANOV	{"email": "konstantin-romanov121977@postgrespro.ru", "phone": "+70169845983"}
0005432184929	7A048F	2255 287389	ANDREY YAKOVLEV	{"email": "a.yakovlev15121970@postgrespro.ru", "phone": "+70971365112"}
0005432184930	9758AE	3968 958527	IVAN ANTONOV	{"phone": "+70105803764"}
0005432184931	9758AE	9603 909758	MAKSIM VOLKOV	{"email": "volkov.m.03091981@postgrespro.ru", "phone": "+70011406471"}
0005432184932	FFB531	6639 693750	ALENA KULIKOVA	{"email": "alenakulikova-1970@postgrespro.ru", "phone": "+70160127509"}
0005432184933	2DE6A4	9330 758852	RIMMA KOZLOVA	{"phone": "+70790735512"}
0005432184934	2DE6A4	3332 870681	ANATOLIY ISAEV	{"phone": "+70858025964"}
0005432184935	2DE6A4	6167 447334	SERGEY KRASNOV	{"phone": "+70015900929"}
0005432184936	9436D1	8219 375763	VALENTINA BOGDANOVA	{"phone": "+70237367464"}
0005432184937	9436D1	3336 142752	RAFAEL ZAYCEV	{"phone": "+70808889058"}
0005432184938	A7711A	5891 977982	MARINA IVANOVA	{"email": "ivanova-m.1977@postgrespro.ru", "phone": "+70363591046"}
0005432184939	B4991E	4760 388453	ELMIRA SAVELEVA	{"phone": "+70753647660"}
0005432184940	B4991E	4839 509513	NAILYA LUKYANOVA	{"phone": "+70511011223"}
0005432184941	E36237	1035 509460	IRINA KOROLEVA	{"phone": "+70096956522"}
0005432184942	378288	9086 994417	LIDIYA PETROVA	{"phone": "+70797157457"}
0005432184943	69872E	7173 453751	KONSTANTIN MAKAROV	{"email": "makarovkonstantin_1968@postgrespro.ru", "phone": "+70356080550"}
0005432184944	C21B4E	2522 324838	IGOR KUZNECOV	{"phone": "+70427214877"}
0005432184945	2BF018	8731 693076	ALEKSANDR CHERNOV	{"phone": "+70840130033"}
0005432184946	2BF018	3195 961650	YURIY SOROKIN	{"email": "sorokinyuriy18061974@postgrespro.ru", "phone": "+70818316493"}
0005432184947	2BF018	2200 682902	STEPAN IVANOV	{"email": "ivanov-stepan-1971@postgrespro.ru", "phone": "+70170236259"}
0005432184948	96AA3B	7073 514076	VLADIMIR NIKOLAEV	{"phone": "+70610930728"}
0005432184949	C1BC31	2442 220237	DENIS FOMIN	{"phone": "+70239086276"}
0005432184950	9C599E	7191 515926	DENIS SHEVCHENKO	{"email": "d_shevchenko.031971@postgrespro.ru", "phone": "+70292649273"}
0005432184951	9C599E	3501 560010	SERGEY IVANOV	{"email": "s.ivanov-1956@postgrespro.ru", "phone": "+70981373141"}
0005432184952	4E8AA4	5758 316532	POLINA MATVEEVA	{"phone": "+70594356653"}
0005432184953	698AAF	2810 605761	VERA DMITRIEVA	{"email": "v-dmitrieva-011976@postgrespro.ru", "phone": "+70649545119"}
0005432184954	A3162D	6381 639628	LIDIYA MIRONOVA	{"phone": "+70327644268"}
0005432184955	A3162D	5837 227581	ILYAS AFANASEV	{"email": "afanasev-ilyas_17011958@postgrespro.ru", "phone": "+70037645554"}
0005432184956	136CEA	5312 835045	NIKOLAY GERASIMOV	{"phone": "+70071724438"}
0005432184957	136CEA	9126 674326	ANATOLIY MAKAROV	{"email": "anatoliymakarov_1969@postgrespro.ru", "phone": "+70906063057"}
0005432184958	A41AAF	8378 945005	OLEG POPOV	{"phone": "+70188919033"}
0005432184959	A41AAF	0475 436825	ANDREY VASILEV	{"email": "avasilev1966@postgrespro.ru", "phone": "+70557423882"}
0005432184960	A41AAF	0719 380181	VIKTOR NIKOLAEV	{"phone": "+70462390040"}
0005432184961	BF7531	8298 234882	ANNA ALEKSANDROVA	{"phone": "+70382751713"}
0005432184962	5C9734	0403 631962	SVETLANA MOISEEVA	{"phone": "+70614359456"}
0005432184963	7F5545	8474 573312	VASILIY MELNIKOV	{"email": "vasiliy-melnikov.25071970@postgrespro.ru", "phone": "+70143444860"}
0005432184964	CC7CE8	4267 048414	ALEKSANDR VOLKOV	{"phone": "+70842089015"}
0005432184965	CC7CE8	1047 754697	ANTONINA ZOTOVA	{"email": "antonina-zotova_021969@postgrespro.ru", "phone": "+70847523712"}
0005432184966	5858F6	9620 306746	ANNA SEMENOVA	{"phone": "+70746362425"}
0005432184967	96AF3F	2872 061446	RUSLAN SAVELEV	{"email": "ruslan_savelev10051963@postgrespro.ru", "phone": "+70609771749"}
0005432184968	96AF3F	9726 461923	MAKSIM SOKOLOV	{"phone": "+70040252136"}
0005432184969	583B45	6645 551161	VALENTINA YAKOVLEVA	{"phone": "+70764309377"}
0005432184970	A59A14	1275 676721	PETR AFANASEV	{"phone": "+70725422808"}
0005432184971	3A7312	8564 572145	MARIYA GUSEVA	{"email": "m_guseva_1970@postgrespro.ru", "phone": "+70025679619"}
0005432184972	E2976C	2565 448581	ALEVTINA ZOTOVA	{"email": "zotova-a_14081967@postgrespro.ru", "phone": "+70225912345"}
0005432184973	E2976C	1084 967024	NIKOLAY ALEKSEEV	{"phone": "+70116761259"}
0005432184974	E2976C	8527 581561	LYUDMILA ALEKSEEVA	{"phone": "+70510728661"}
0005432184975	E2976C	8520 196563	ANZHELIKA KOMAROVA	{"email": "anzhelika.komarova.121975@postgrespro.ru", "phone": "+70830388763"}
0005432184976	606AAB	4532 631059	DENIS POPOV	{"email": "d-popov.121981@postgrespro.ru", "phone": "+70022594247"}
0005432184977	E213F7	4866 524601	IVAN NAZAROV	{"phone": "+70672541117"}
0005432184978	E213F7	1054 376770	EKATERINA SERGEEVA	{"phone": "+70385153955"}
0005432184979	E213F7	6559 955789	NATALYA IVANOVA	{"email": "ivanova-n.16091970@postgrespro.ru", "phone": "+70511650561"}
0005432184980	AD7FF2	6678 792386	MIKHAIL KOROLEV	{"email": "korolevm041968@postgrespro.ru", "phone": "+70138193538"}
0005432184981	559387	9630 013407	ROZALIYA SEMENOVA	{"phone": "+70355230500"}
0005432184982	D080D6	5642 190666	NAILYA CHERNOVA	{"phone": "+70370495734"}
0005432184983	D080D6	0138 113505	YULIYA POLYAKOVA	{"phone": "+70535777481"}
0005432184984	A6D795	6273 285443	PAVEL RODIONOV	{"email": "rodionov_pavel-22101973@postgrespro.ru", "phone": "+70326472471"}
0005432184985	C788CC	0928 502757	SERGEY SEMENOV	{"phone": "+70175948188"}
0005432184986	2E97AD	4332 345754	ZOYA LUKYANOVA	{"email": "lukyanova-zoya121972@postgrespro.ru", "phone": "+70246259588"}
0005432184987	C1212F	7190 787460	GALINA NOVIKOVA	{"phone": "+70282385053"}
0005432184988	C1212F	7275 555368	ALEKSANDR MAKSIMOV	{"email": "a_maksimov_28111970@postgrespro.ru", "phone": "+70205224148"}
0005432184989	990660	4398 369503	ALEKSANDR EGOROV	{"phone": "+70740583439"}
0005432184990	990660	1673 919765	ELENA TITOVA	{"phone": "+70957010443"}
0005432184991	990660	2132 295170	EVGENIYA NIKITINA	{"email": "enikitina-011973@postgrespro.ru", "phone": "+70599971522"}
0005432184992	8123D3	9087 295167	VLADIMIR PAVLOV	{"phone": "+70164816041"}
0005432184993	DBE874	2958 806261	ALLA KOLESNIKOVA	{"phone": "+70685542657"}
0005432184994	DBE874	7223 267202	PAVEL MARTYNOV	{"phone": "+70508540201"}
0005432184995	D5BCE2	5486 889953	TATYANA SCHERBAKOVA	{"email": "t_scherbakova-16041975@postgrespro.ru", "phone": "+70509020046"}
0005432184996	4350BA	4323 560415	ANTONINA SOLOVEVA	{"phone": "+70869581930"}
0005432184997	4350BA	4203 337005	ELIZAVETA ABRAMOVA	{"email": "elizaveta_abramova.1963@postgrespro.ru", "phone": "+70313427496"}
0005432184998	194E2E	2375 844464	ALEKSANDR IVANOV	{"email": "a-ivanov031985@postgrespro.ru", "phone": "+70374596839"}
0005432184999	194E2E	8680 089470	TATYANA NAZAROVA	{"email": "nazarovatatyana.051975@postgrespro.ru", "phone": "+70662962212"}
0005432185000	AAEB31	9524 221008	ELENA MIRONOVA	{"email": "elena_mironova.03091965@postgrespro.ru", "phone": "+70982824637"}
0005432185001	AAEB31	4219 354346	MIKHAIL ZHURAVLEV	{"email": "zhuravlev_m_1972@postgrespro.ru", "phone": "+70481195814"}
0005432185002	D19C4F	1662 047894	NAIL KUZNECOV	{"email": "nail.kuznecov22051973@postgrespro.ru", "phone": "+70929530557"}
0005432185003	F7388C	2701 779645	LILIYA POPOVA	{"email": "l_popova1974@postgrespro.ru", "phone": "+70575419824"}
0005432185004	BE4ABE	2905 783554	VIKTOR FILIPPOV	{"email": "filippov.v-011971@postgrespro.ru", "phone": "+70614133631"}
0005432185005	BE4ABE	3778 731030	VLADIMIR ZAKHAROV	{"phone": "+70463710104"}
0005432185006	C0D1D0	4461 063001	GALINA KUZNECOVA	{"phone": "+70722848336"}
0005432185007	D6F549	0189 664388	MARINA STEPANOVA	{"phone": "+70944479519"}
0005432185008	D6F549	2437 952867	ROMAN TIKHONOV	{"email": "tikhonov-roman_1965@postgrespro.ru", "phone": "+70857444597"}
0005432185009	33279D	2214 115038	MATVEY GERASIMOV	{"email": "gerasimov-matvey.21101971@postgrespro.ru", "phone": "+70455096349"}
0005432185010	6E1BF2	6727 205799	ELENA NIKOLAEVA	{"email": "nikolaevae.26021973@postgrespro.ru", "phone": "+70290188257"}
0005432185011	A8533F	1581 727434	MARIYA MIKHAYLOVA	{"email": "mikhaylovam-19101965@postgrespro.ru", "phone": "+70500270293"}
0005432185012	503EF3	6629 060873	DMITRIY STEPANOV	{"email": "dmitriy_stepanov-071965@postgrespro.ru", "phone": "+70388962093"}
0005432185013	9877B7	0172 126188	VALENTINA IVANOVA	{"email": "v.ivanova.051977@postgrespro.ru", "phone": "+70962405837"}
0005432185014	9877B7	7570 762441	SERGEY KUZMIN	{"phone": "+70664696301"}
0005432185015	9877B7	6522 829244	VLADIMIR KUZMIN	{"email": "kuzmin_v14061976@postgrespro.ru", "phone": "+70587535601"}
0005432185016	3CC3EC	9386 273657	RITA KOVALEVA	{"phone": "+70577781157"}
0005432185017	9CE8A1	0273 477965	ANASTASIYA STEPANOVA	{"phone": "+70627679318"}
0005432185018	0B9489	6931 985688	LYUBOV PETROVA	{"email": "lyubovpetrova22091976@postgrespro.ru", "phone": "+70051421567"}
0005432185019	D5B522	3781 263889	VLADIMIR TIKHONOV	{"email": "tikhonov-vladimir051972@postgrespro.ru", "phone": "+70061559377"}
0005432185020	B0F1BC	2855 021404	NATALIYA LUKYANOVA	{"email": "n_lukyanova.041977@postgrespro.ru", "phone": "+70322140483"}
0005432185021	FDF3C6	5846 717257	VALERIY ALEKSEEV	{"phone": "+70829569056"}
0005432185022	9F051E	8437 545117	NADEZHDA YAKOVLEVA	{"phone": "+70335758952"}
0005432185023	A283AC	6758 157903	EVGENIY MAKAROV	{"email": "makarov_evgeniy_091968@postgrespro.ru", "phone": "+70650036849"}
0005432185024	A283AC	0553 868633	OLGA NOVIKOVA	{"email": "olga_novikova_24061962@postgrespro.ru", "phone": "+70350416736"}
0005432185025	347F7E	8756 224252	MIKHAIL MAKAROV	{"phone": "+70540948871"}
0005432185026	EFDD9A	4213 799331	ALEKSEY NAZAROV	{"phone": "+70522888437"}
0005432185027	EFDD9A	2235 310951	LYUDMILA FROLOVA	{"phone": "+70734901309"}
0005432185028	8319F3	7742 940165	MIKHAIL NOVIKOV	{"email": "novikov-mikhail-1970@postgrespro.ru", "phone": "+70683183557"}
0005432185029	82C86C	8566 418610	MARIYA SMIRNOVA	{"phone": "+70397895250"}
0005432185030	82C86C	4647 597259	SERGEY BELOV	{"email": "belov_s.1968@postgrespro.ru", "phone": "+70003817592"}
0005432185031	A219F5	7326 390326	ANDREY SHEVCHENKO	{"phone": "+70638317151"}
0005432185032	CD1E9D	6453 262952	SERGEY ZAKHAROV	{"email": "zakharovs_23011980@postgrespro.ru", "phone": "+70797358716"}
0005432185033	CD1E9D	5753 414763	ANTON IVANOV	{"phone": "+70270808698"}
0005432186883	83A654	8162 412236	OLGA KOROLEVA	{"phone": "+70587986879"}
0005432186803	59B24F	6243 210246	ANTONINA VASILEVA	{"phone": "+70783613858"}
0005432186804	59B24F	5551 405967	VALENTINA NIKIFOROVA	{"phone": "+70070140390"}
0005432186805	59B24F	6312 513229	NADEZHDA GRISHINA	{"phone": "+70044982863"}
0005432186806	59B24F	0797 766336	GENNADIY MARTYNOV	{"phone": "+70814261284"}
0005432186807	6F90A3	1831 920267	DARYA BOGDANOVA	{"email": "daryabogdanova.04101977@postgrespro.ru", "phone": "+70363334519"}
0005432186808	34ADF6	2577 816238	SVETLANA VASILEVA	{"email": "svetlana-vasileva-1977@postgrespro.ru", "phone": "+70215520908"}
0005432186809	34ADF6	7238 164377	VLADIMIR TARASOV	{"phone": "+70981348389"}
0005432186810	34ADF6	0929 814828	VALERIY ANDREEV	{"phone": "+70414423759"}
0005432186811	5C7B44	0915 974625	NINA SERGEEVA	{"phone": "+70848671605"}
0005432186812	5C7B44	5522 253220	ALEKSANDR BARANOV	{"email": "baranov.aleksandr25081972@postgrespro.ru", "phone": "+70820512102"}
0005432186813	5C7B44	6664 753653	OLGA MOISEEVA	{"email": "olga_moiseeva_1965@postgrespro.ru", "phone": "+70266838215"}
0005432186814	8869B9	3170 577639	MAKSIM ABRAMOV	{"email": "abramovm_111970@postgrespro.ru", "phone": "+70021894869"}
0005432186815	786B81	2088 252667	LYUDMILA NAZAROVA	{"email": "lyudmilanazarova_1979@postgrespro.ru", "phone": "+70588283378"}
0005432186816	786B81	6493 830497	SVETLANA FILIPPOVA	{"email": "s_filippova_30121969@postgrespro.ru", "phone": "+70517117112"}
0005432186817	8B441B	4406 023550	ELMIRA ALEKSEEVA	{"phone": "+70816267484"}
0005432186818	8B441B	6377 336503	IVAN KUZNECOV	{"email": "kuznecov.ivan_071964@postgrespro.ru", "phone": "+70876746003"}
0005432186819	B81CD5	4683 637752	ALEKSANDRA MAKSIMOVA	{"phone": "+70757051539"}
0005432186932	0D624A	5782 084340	VIKTOR FOMIN	{"phone": "+70926850113"}
0005432186820	CCF1A7	1882 518246	NIKOLAY SIDOROV	{"email": "nikolay_sidorov25071978@postgrespro.ru", "phone": "+70885162302"}
0005432186821	2E0DA8	1042 159396	VIKTOR MELNIKOV	{"email": "melnikov_viktor1957@postgrespro.ru", "phone": "+70021737304"}
0005432186822	2E0DA8	0314 344046	VLADIMIR SIDOROV	{"email": "sidorov.v_1970@postgrespro.ru", "phone": "+70156809301"}
0005432186823	E331DA	3348 827279	ANNA GRISHINA	{"phone": "+70725378188"}
0005432186824	2E59D8	2691 812624	ALEKSANDR DMITRIEV	{"email": "dmitriev-a-1974@postgrespro.ru", "phone": "+70177875468"}
0005432186825	2E59D8	0624 397025	ANNA GORBUNOVA	{"phone": "+70141081339"}
0005432186826	2E59D8	3236 468128	LYUDMILA KUZNECOVA	{"email": "kuznecova-l_1965@postgrespro.ru", "phone": "+70853314398"}
0005432186827	5CED85	2868 764965	ELENA ZAYCEVA	{"email": "zayceva-e_1975@postgrespro.ru", "phone": "+70733601857"}
0005432186828	5C2D7B	8858 701173	NATALYA SIDOROVA	{"phone": "+70376304812"}
0005432186829	055742	6843 762196	EVGENIYA KOZLOVA	{"phone": "+70176079934"}
0005432186830	055742	5313 328221	TATYANA ANDREEVA	{"email": "andreeva.tatyana121988@postgrespro.ru", "phone": "+70019428304"}
0005432186831	A102B5	2700 660154	ARTUR RODIONOV	{"email": "arodionov_051979@postgrespro.ru", "phone": "+70258077365"}
0005432186832	F6F161	3956 237843	ANATOLIY KARPOV	{"email": "anatoliy_karpov_121970@postgrespro.ru", "phone": "+70679371643"}
0005432186833	F6F161	0427 425667	DMITRIY TARASOV	{"email": "dmitriy.tarasov_1971@postgrespro.ru", "phone": "+70428845326"}
0005432186834	AED55B	6403 706295	YURIY CHERNOV	{"phone": "+70129305230"}
0005432186835	92C511	3089 489127	RINAT PETROV	{"phone": "+70604400045"}
0005432186836	C2A012	6139 960339	VALENTINA KOVALEVA	{"email": "kovalevav-24031975@postgrespro.ru", "phone": "+70837383558"}
0005432186837	04E023	8093 352532	ALEKSANDR NOVIKOV	{"email": "a_novikov031975@postgrespro.ru", "phone": "+70369092911"}
0005432186838	04E023	0481 996714	ADELINA BELYAEVA	{"email": "adelina.belyaeva.1956@postgrespro.ru", "phone": "+70236254085"}
0005432186839	AA8178	0936 042560	LYUDMILA MOROZOVA	{"email": "l-morozova_031971@postgrespro.ru", "phone": "+70073800259"}
0005432186840	AA8178	5274 470893	IRINA BELOVA	{"email": "belova_i.09061962@postgrespro.ru", "phone": "+70017252112"}
0005432186841	8F5709	8489 682552	ELENA SEMENOVA	{"email": "e.semenova111982@postgrespro.ru", "phone": "+70619688400"}
0005432186842	8F5709	7735 891218	VALERIY KRASNOV	{"email": "valeriykrasnov_21121960@postgrespro.ru", "phone": "+70629018059"}
0005432186843	DF8EF0	6109 644294	VALERIY KUZNECOV	{"phone": "+70622282464"}
0005432186844	A9F860	3434 293240	ELENA MASLOVA	{"email": "maslovaelena-1965@postgrespro.ru", "phone": "+70387515385"}
0005432186845	A9F860	2328 896136	POLINA POPOVA	{"email": "p.popova-1973@postgrespro.ru", "phone": "+70247211233"}
0005432186846	B8F4F3	7017 917446	YULIYA TIKHONOVA	{"email": "tikhonova-yuliya_18011962@postgrespro.ru", "phone": "+70797263473"}
0005432186847	B8F4F3	0328 220860	LYUDMILA KUDRYASHOVA	{"email": "l-kudryashova18041976@postgrespro.ru", "phone": "+70127805632"}
0005432186848	84099A	1540 533683	ELENA GORBUNOVA	{"phone": "+70836775433"}
0005432186849	84099A	4903 190544	IGOR MIKHAYLOV	{"phone": "+70799479650"}
0005432186850	1896C9	0813 931877	IRINA BELOVA	{"email": "belova_i-10111976@postgrespro.ru", "phone": "+70212134383"}
0005432186851	1896C9	4323 476473	LYUDMILA ISAEVA	{"phone": "+70930851116"}
0005432186852	FDD968	7692 123507	ANNA FILIPPOVA	{"phone": "+70841436845"}
0005432186853	2FC59D	0512 926003	YULIYA ISAEVA	{"phone": "+70948685082"}
0005432186854	75AC97	9743 226531	STEPAN PETROV	{"phone": "+70799927436"}
0005432186855	990688	9131 964364	ALEKSEY SEMENOV	{"phone": "+70195768488"}
0005432186856	CF8083	5164 366484	VALENTINA MIKHAYLOVA	{"phone": "+70316827453"}
0005432186857	8134EF	1306 802975	SERGEY VLASOV	{"phone": "+70826078035"}
0005432186858	7F69EE	4873 769846	MARINA PETROVA	{"email": "petrova.marina-03091971@postgrespro.ru", "phone": "+70855319160"}
0005432186859	9E3636	9928 451044	ALEKSANDR POPOV	{"phone": "+70512204345"}
0005432186860	13DA4A	1981 174145	NINA PAVLOVA	{"email": "pavlovanina_1968@postgrespro.ru", "phone": "+70265633216"}
0005432186861	7ED732	3238 535166	ELENA KULIKOVA	{"phone": "+70627995075"}
0005432186862	86B1AF	9203 124524	ANDREY BORISOV	{"phone": "+70042200734"}
0005432186863	86B1AF	2238 869367	TATYANA MELNIKOVA	{"phone": "+70677098674"}
0005432186864	B57E2A	3109 553015	LIDIYA VOLKOVA	{"phone": "+70246458010"}
0005432186865	B6AEC6	4816 684603	VIKTOR KAZAKOV	{"email": "kazakov_viktor1969@postgrespro.ru", "phone": "+70984182434"}
0005432186866	B6AEC6	8809 481108	OLGA FROLOVA	{"email": "frolova-o22121967@postgrespro.ru", "phone": "+70037500742"}
0005432186867	5A73C6	7230 430022	NIKOLAY KRASNOV	{"phone": "+70946645985"}
0005432186868	D76B8B	3877 410085	ZOYA FROLOVA	{"phone": "+70919922971"}
0005432186869	70209B	6529 358108	ALEKSANDR KUZNECOV	{"phone": "+70646545439"}
0005432186870	61BB0D	6068 456987	ANNA KUZNECOVA	{"phone": "+70734684119"}
0005432186871	419ED8	5765 293013	ELENA KOLESNIKOVA	{"email": "kolesnikova_e.051971@postgrespro.ru", "phone": "+70473178782"}
0005432186872	419ED8	0572 067807	ALEKSEY ALEKSEEV	{"email": "alekseev_aleksey_1978@postgrespro.ru", "phone": "+70121384361"}
0005432186873	419ED8	8703 623014	ILYA NOVIKOV	{"email": "novikov_i-29021972@postgrespro.ru", "phone": "+70046668417"}
0005432186874	7677C8	6717 806478	KSENIYA BELOVA	{"phone": "+70743076081"}
0005432186875	3C5BA7	3785 560819	ELENA SMIRNOVA	{"email": "elena.smirnova1985@postgrespro.ru", "phone": "+70685829309"}
0005432186876	3C5BA7	7271 200965	YURIY ALEKSEEV	{"email": "yuriy-alekseev_1971@postgrespro.ru", "phone": "+70666946233"}
0005432186877	3C5BA7	7017 648356	MARINA LUKYANOVA	{"phone": "+70877171684"}
0005432186878	E03561	7142 399139	ANNA MIRONOVA	{"phone": "+70554181922"}
0005432186879	E03561	1404 289579	ALEKSANDR ABRAMOV	{"email": "abramov.a.19051958@postgrespro.ru", "phone": "+70030212487"}
0005432186880	E03561	4598 025432	ALEKSEY MIRONOV	{"email": "mironovaleksey-1972@postgrespro.ru", "phone": "+70570435212"}
0005432186881	609172	6980 255928	MIKHAIL ZAKHAROV	{"email": "m-zakharov.1960@postgrespro.ru", "phone": "+70360125935"}
0005432186882	AB66D3	0290 999420	IRINA KOROLEVA	{"phone": "+70016506085"}
0005432186884	038D2C	8557 730402	SVETLANA TITOVA	{"email": "titova-s121965@postgrespro.ru", "phone": "+70702714893"}
0005432186885	5E70D4	7715 699164	SANIYA FROLOVA	{"email": "sfrolova15111962@postgrespro.ru", "phone": "+70649817680"}
0005432186886	66FC61	6659 962108	OLGA KUZNECOVA	{"email": "o_kuznecova-121975@postgrespro.ru", "phone": "+70736828400"}
0005432186887	1F4693	3547 452669	VALENTIN BORISOV	{"email": "valentin.borisov1970@postgrespro.ru", "phone": "+70608804658"}
0005432186888	FCE59B	2008 505267	NIKOLAY ANDREEV	{"phone": "+70906068114"}
0005432186889	FCE59B	3294 637710	RUSLAN VOLKOV	{"email": "volkov_r.19011969@postgrespro.ru", "phone": "+70757717306"}
0005432186890	FCE59B	9975 505939	DARYA POPOVA	{"phone": "+70562225225"}
0005432186891	FCE59B	0202 397914	TATYANA POPOVA	{"phone": "+70740462891"}
0005432186892	48FB07	4437 827204	GEORGIY EGOROV	{"email": "georgiyegorov-1976@postgrespro.ru", "phone": "+70068560274"}
0005432186893	48FB07	1210 808736	TAMARA NESTEROVA	{"email": "tamara_nesterova.12031972@postgrespro.ru", "phone": "+70887666950"}
0005432186894	21AF46	1518 240534	SERGEY ILIN	{"email": "ilin.sergey_11041970@postgrespro.ru", "phone": "+70503059159"}
0005432186895	C24165	7169 973841	GENNADIY KUZNECOV	{"phone": "+70851070281"}
0005432186896	581208	7349 965682	KONSTANTIN MELNIKOV	{"phone": "+70312166854"}
0005432186897	9D0FDC	5593 695146	VLADIMIR MAKSIMOV	{"phone": "+70475196485"}
0005432186898	B6AD99	1897 501833	KSENIYA LEBEDEVA	{"phone": "+70588950536"}
0005432186899	5280AE	5304 571210	NATALYA MELNIKOVA	{"phone": "+70495369143"}
0005432186900	43BF4B	8897 244115	ANTONINA STEPANOVA	{"email": "antonina.stepanova101959@postgrespro.ru", "phone": "+70884845937"}
0005432186901	43BF4B	3933 430347	NATALYA PAVLOVA	{"phone": "+70853195859"}
0005432186902	D7C040	3127 488688	DANIIL BARANOV	{"phone": "+70822881375"}
0005432186903	D7C040	4090 523048	VALENTINA ILINA	{"phone": "+70873107159"}
0005432186904	C2E949	6060 916558	SERGEY GORBUNOV	{"phone": "+70527261219"}
0005432186905	484FBB	6999 945329	ARTEM ANTONOV	{"email": "artem_antonov-17121972@postgrespro.ru", "phone": "+70630728951"}
0005432186906	484FBB	1824 837034	VLADIMIR SMIRNOV	{"phone": "+70172954799"}
0005432186907	7574FB	5863 587863	GEORGIY GUSEV	{"email": "g-gusev031975@postgrespro.ru", "phone": "+70045970433"}
0005432186908	0B9E61	4032 894705	ELISEY GRIGOREV	{"phone": "+70596837659"}
0005432186909	0B9E61	9908 006997	MARIYA KUZNECOVA	{"email": "kuznecovam.051964@postgrespro.ru", "phone": "+70408773919"}
0005432186910	9036B6	2854 465712	VALENTINA VASILEVA	{"phone": "+70665767955"}
0005432186911	764D1F	0168 466922	ELENA KUZNECOVA	{"email": "kuznecova_elena_20091977@postgrespro.ru", "phone": "+70131556433"}
0005432186912	764D1F	4465 169222	EKATERINA KUZMINA	{"phone": "+70297445111"}
0005432186913	5ECAE2	8819 896580	DMITRIY IVANOV	{"email": "dmitriy-ivanov15071977@postgrespro.ru", "phone": "+70938709448"}
0005432186914	122C1C	4650 803350	MAKSIM IVANOV	{"email": "ivanov-m1968@postgrespro.ru", "phone": "+70086925469"}
0005432186915	EFA31B	4986 234752	VALENTINA FILIPPOVA	{"phone": "+70327522280"}
0005432186916	EFA31B	3014 763674	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.051969@postgrespro.ru", "phone": "+70792448639"}
0005432186917	ED8FBD	2832 792752	EVGENIY ALEKSEEV	{"phone": "+70339667410"}
0005432186918	7D7570	6251 548913	DMITRIY ZAKHAROV	{"email": "d.zakharov09021978@postgrespro.ru", "phone": "+70305736366"}
0005432186919	6ED21D	6518 581528	TATYANA POTAPOVA	{"email": "tpotapova.13031967@postgrespro.ru", "phone": "+70047445499"}
0005432186920	4E854D	6367 608876	VALENTINA ARKHIPOVA	{"email": "valentina_arkhipova-081988@postgrespro.ru", "phone": "+70980485068"}
0005432186921	41A31C	9691 432783	SERGEY AFANASEV	{"phone": "+70789253883"}
0005432186922	F727CB	3877 429685	ELENA KUZNECOVA	{"email": "kuznecova.elena-26061980@postgrespro.ru", "phone": "+70270748310"}
0005432186923	F727CB	2132 306156	TATYANA IVANOVA	{"phone": "+70634258871"}
0005432186924	24A5A6	5712 107597	ANASTASIYA YAKOVLEVA	{"phone": "+70734523371"}
0005432186925	D6E745	2226 128635	ELENA NIKOLAEVA	{"email": "nikolaeva_elena.1969@postgrespro.ru", "phone": "+70263679365"}
0005432186926	89AA34	2933 492796	DENIS GERASIMOV	{"phone": "+70266866581"}
0005432186927	813136	8309 525106	ELENA POPOVA	{"email": "popovae-07121974@postgrespro.ru", "phone": "+70713542195"}
0005432186928	8C4DC4	9940 364332	OLGA MOROZOVA	{"email": "o-morozova071967@postgrespro.ru", "phone": "+70158321069"}
0005432186929	77F358	5871 600258	PETR GRIGOREV	{"email": "p-grigorev.1968@postgrespro.ru", "phone": "+70768695612"}
0005432186930	3540FB	9874 902335	YULIYA TIMOFEEVA	{"email": "timofeeva-yuliya_011984@postgrespro.ru", "phone": "+70905510924"}
0005432186931	0B93EE	2691 907403	ALEKSANDR SMIRNOV	{"phone": "+70514975529"}
0005432186933	7DB0BB	8271 435975	NAILYA TIMOFEEVA	{"phone": "+70076179141"}
0005432186934	8231F8	5214 499559	ALEKSANDR FEDOTOV	{"email": "fedotov.a_011968@postgrespro.ru", "phone": "+70234725309"}
0005432186935	6F3FCA	9519 863693	ILYA PETROV	{"email": "i-petrov_09121969@postgrespro.ru", "phone": "+70363225408"}
0005432186936	6F3FCA	6831 037288	VIKTORIYA MOISEEVA	{"phone": "+70514392601"}
0005432186937	EECC78	3010 801431	MARIYA ZOTOVA	{"email": "zotovam_021981@postgrespro.ru", "phone": "+70923710452"}
0005432186938	EECC78	8321 256116	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr.14081973@postgrespro.ru", "phone": "+70044153354"}
0005432186939	EECC78	6842 904150	LYUBOV MATVEEVA	{"email": "matveeva_lyubov_07101966@postgrespro.ru", "phone": "+70602735049"}
0005432186940	A7F4E4	9100 950287	EKATERINA MIRONOVA	{"phone": "+70115289483"}
0005432186941	3CE0D0	1488 221943	SERGEY DENISOV	{"email": "denisov_sergey_081956@postgrespro.ru", "phone": "+70720365742"}
0005432186942	52E908	1672 270325	LYUDMILA SOROKINA	{"email": "l-sorokina.1979@postgrespro.ru", "phone": "+70772544232"}
0005432186943	93472E	2594 141320	VLADIMIR AFANASEV	{"email": "vladimir_afanasev-071980@postgrespro.ru", "phone": "+70995029174"}
0005432186944	93472E	8680 082790	ANNA ALEKSEEVA	{"email": "alekseeva-a-19021981@postgrespro.ru", "phone": "+70913116073"}
0005432186945	A4AEF9	2038 212515	SERGEY MOROZOV	{"email": "morozovsergey.1978@postgrespro.ru", "phone": "+70958619695"}
0005432186946	A4AEF9	6746 187253	OLGA SOROKINA	{"phone": "+70607013405"}
0005432186947	C50FD1	3362 805646	VALENTINA DMITRIEVA	{"phone": "+70104663159"}
0005432186948	64C1E0	4167 664313	NIKITA KUZNECOV	{"email": "nikita_kuznecov-18041969@postgrespro.ru", "phone": "+70498082496"}
0005432186949	2D78B3	4183 905901	MARGARITA ALEKSANDROVA	{"phone": "+70725270935"}
0005432186950	2D78B3	8257 780814	GENNADIY PAVLOV	{"phone": "+70144194739"}
0005432186951	4BE265	8217 435248	KSENIYA KUZNECOVA	{"email": "kuznecovak.13061980@postgrespro.ru", "phone": "+70593550096"}
0005432186952	3CADD7	5998 495992	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov_1983@postgrespro.ru", "phone": "+70764605525"}
0005432186953	32BDDF	5414 458933	PETR FOMIN	{"email": "petrfomin.1964@postgrespro.ru", "phone": "+70637455926"}
0005432186954	58C4A6	4544 827818	EVGENIY IVANOV	{"phone": "+70222944619"}
0005432186955	60D5B5	4917 560492	OKSANA DAVYDOVA	{"phone": "+70869598066"}
0005432186956	8F0ED1	6544 086844	GENNADIY BORISOV	{"phone": "+70035841917"}
0005432186957	52AB19	9344 711999	DARYA MIKHAYLOVA	{"email": "darya.mikhaylova.061965@postgrespro.ru", "phone": "+70254765430"}
0005432186958	36DF63	7796 013798	ANNA ZAYCEVA	{"phone": "+70152041906"}
0005432186959	946B3E	2502 116978	SOFYA KUDRYASHOVA	{"email": "s_kudryashova1959@postgrespro.ru", "phone": "+70857006119"}
0005432186960	946B3E	8387 313542	ILNUR KULIKOV	{"phone": "+70730661878"}
0005432186961	946B3E	3280 320794	PAVEL MELNIKOV	{"phone": "+70624268028"}
0005432186962	248AFD	4258 941806	SERGEY KUZMIN	{"email": "kuzmin-sergey04041977@postgrespro.ru", "phone": "+70399061227"}
0005432186963	F9363A	3655 319548	PETR POPOV	{"email": "popov-petr1974@postgrespro.ru", "phone": "+70793876662"}
0005432186964	0FBB62	3391 652170	MAKSIM DENISOV	{"phone": "+70227394797"}
0005432186965	B5CB9E	2294 413348	GULNARA KONOVALOVA	{"phone": "+70719692163"}
0005432186966	B5CB9E	5023 723251	ROMAN FILIPPOV	{"phone": "+70462866423"}
0005432186967	AC6E00	0679 488760	ALENA MAKAROVA	{"phone": "+70138347383"}
0005432186968	AC6E00	0476 486811	ALEKSEY VOLKOV	{"phone": "+70028900758"}
0005432186969	B3451C	9439 810762	IRINA DMITRIEVA	{"email": "irina-dmitrieva_11111974@postgrespro.ru", "phone": "+70652144802"}
0005432186970	EF4389	2634 452659	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr.1972@postgrespro.ru", "phone": "+70734963860"}
0005432186971	EF4389	0416 032828	NIKOLAY GRIGOREV	{"phone": "+70936251189"}
0005432186972	EF4389	8413 212561	EKATERINA DAVYDOVA	{"email": "davydova-e.03061963@postgrespro.ru", "phone": "+70691981314"}
0005432188549	215BA2	8281 899964	EVGENIYA KOLESNIKOVA	{"phone": "+70311126788"}
0005432188550	B6D7EA	1336 560336	VASILIY SOROKIN	{"email": "vasiliy_sorokin-04011973@postgrespro.ru", "phone": "+70815296100"}
0005432188551	B6500C	5751 780768	NINA MAKAROVA	{"phone": "+70700022853"}
0005432188552	50DAB9	0737 960543	LYUDMILA IVANOVA	{"email": "ivanova-l_1982@postgrespro.ru", "phone": "+70192954378"}
0005432188553	50DAB9	1278 942359	MIKHAIL PAVLOV	{"email": "pavlov-mikhail_031976@postgrespro.ru", "phone": "+70497530155"}
0005432188554	ECD7EF	8802 769281	VIKTOR POPOV	{"email": "popov_v-04031965@postgrespro.ru", "phone": "+70205878254"}
0005432188555	3F196A	3342 985512	LIDIYA GUSEVA	{"phone": "+70754455025"}
0005432188556	3F196A	3676 309656	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova-anastasiya.1968@postgrespro.ru", "phone": "+70399242351"}
0005432188557	2BE220	7099 706297	RIMMA NIKOLAEVA	{"phone": "+70705628187"}
0005432188558	1779D2	8194 305249	NATALYA KAZAKOVA	{"email": "natalyakazakova.011966@postgrespro.ru", "phone": "+70668526694"}
0005432188559	1779D2	4619 768338	LYUBOV KULIKOVA	{"email": "kulikova.lyubov.061971@postgrespro.ru", "phone": "+70955085875"}
0005432188560	1779D2	7990 127835	NADEZHDA MIRONOVA	{"email": "mironovanadezhda-1973@postgrespro.ru", "phone": "+70872505479"}
0005432188561	BFDFBC	2803 848492	NATALYA TARASOVA	{"email": "natalya.tarasova-1966@postgrespro.ru", "phone": "+70632444221"}
0005432188562	8BFD02	0365 268288	IVAN KOZLOV	{"email": "kozlov.ivan1971@postgrespro.ru", "phone": "+70463039691"}
0005432188563	2359B7	6181 524935	RAFAIL DAVYDOV	{"phone": "+70246537442"}
0005432188564	2359B7	9770 390930	SOFIYA NOVIKOVA	{"email": "novikova.s_1974@postgrespro.ru", "phone": "+70414672375"}
0005432188565	9CC461	6284 773786	VLADIMIR SOLOVEV	{"email": "v.solovev_061986@postgrespro.ru", "phone": "+70046415096"}
0005432188566	CB766C	1893 749450	ALSU GORBUNOVA	{"email": "agorbunova30111974@postgrespro.ru", "phone": "+70889322410"}
0005432188567	CB766C	1282 107458	LYUDMILA NIKOLAEVA	{"phone": "+70485799970"}
0005432188568	F82885	4130 153262	ANASTASIYA NAZAROVA	{"email": "a_nazarova.03081975@postgrespro.ru", "phone": "+70228255560"}
0005432188569	0F18B5	8398 609769	NIKOLAY VOLKOV	{"email": "nikolay.volkov031968@postgrespro.ru", "phone": "+70667589027"}
0005432188570	5A9EDC	0335 774949	ALEKSANDR TIMOFEEV	{"email": "timofeev.a_11111968@postgrespro.ru", "phone": "+70732179076"}
0005432188571	F84AB8	1106 829680	ALLA KOROLEVA	{"email": "korolevaalla.1956@postgrespro.ru", "phone": "+70987600877"}
0005432188572	288AC1	9732 887197	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey15071966@postgrespro.ru", "phone": "+70854706688"}
0005432188573	BF67B8	4778 442194	GENNADIY VOLKOV	{"email": "gennadiy.volkov18081975@postgrespro.ru", "phone": "+70332077947"}
0005432188574	B83898	0310 469294	EVGENIY SHEVCHENKO	{"phone": "+70225212211"}
0005432188575	67FF26	4393 174372	TIMUR AFANASEV	{"email": "t-afanasev_03031963@postgrespro.ru", "phone": "+70450341874"}
0005432188576	165A42	0981 122530	SVETLANA SEMENOVA	{"phone": "+70364973036"}
0005432188577	D08941	1020 313899	IGOR MOISEEV	{"email": "i-moiseev-18111973@postgrespro.ru", "phone": "+70091591306"}
0005432188578	D08941	7494 235001	TATYANA LOGINOVA	{"phone": "+70422948766"}
0005432188579	D08941	8481 948636	PAVEL ROMANOV	{"email": "romanov.p.071969@postgrespro.ru", "phone": "+70138584892"}
0005432188580	C9BBEF	1354 990744	VIKTOR SAVELEV	{"email": "savelevviktor_1969@postgrespro.ru", "phone": "+70945938765"}
0005432188581	C9BBEF	9634 323370	ZINAIDA TITOVA	{"phone": "+70130123169"}
0005432188582	A4C581	9764 573145	ALBERT MELNIKOV	{"email": "melnikov.a-101984@postgrespro.ru", "phone": "+70376762007"}
0005432188583	25BD32	6001 129976	MARINA KRASNOVA	{"phone": "+70116192363"}
0005432188584	EAE735	4572 377548	ANNA AKIMOVA	{"email": "a-akimova1971@postgrespro.ru", "phone": "+70744267271"}
0005432188585	2D6AE8	9098 411658	YULIYA ARKHIPOVA	{"email": "arkhipova_y-11121967@postgrespro.ru", "phone": "+70177314012"}
0005432188586	592576	5059 305365	EVGENIY ALEKSANDROV	{"phone": "+70842762148"}
0005432188587	0354C0	6035 781095	VALERIYA KOVALEVA	{"email": "kovaleva-v.05101963@postgrespro.ru", "phone": "+70748811860"}
0005432188588	0354C0	4268 304770	VLADIMIR MAKAROV	{"phone": "+70552008355"}
0005432188589	980094	6885 069805	LEYLA FILIPPOVA	{"phone": "+70659849244"}
0005432188590	A42628	2946 588666	LYUDMILA ZHURAVLEVA	{"phone": "+70669228024"}
0005432188591	68C94C	9820 401938	NIKOLAY IVANOV	{"phone": "+70388326694"}
0005432188592	F251FA	4697 223615	ALEKSEY SOKOLOV	{"phone": "+70795221311"}
0005432188593	F251FA	5689 410194	ALEKSANDR IVANOV	{"email": "a-ivanov-081981@postgrespro.ru", "phone": "+70582380497"}
0005432188594	B24501	8450 576050	ANDREY VLASOV	{"phone": "+70085680663"}
0005432188595	563151	7003 885625	YURIY SEMENOV	{"email": "semenov-yuriy1972@postgrespro.ru", "phone": "+70901490355"}
0005432188596	563151	7649 391259	ANASTASIYA ISAEVA	{"email": "a.isaeva.24101969@postgrespro.ru", "phone": "+70686969791"}
0005432188597	563151	7431 558709	NATALYA SOROKINA	{"email": "sorokina_n_1988@postgrespro.ru", "phone": "+70857182735"}
0005432188598	262E6E	6611 516259	ELENA KUZNECOVA	{"email": "kuznecova.e-1954@postgrespro.ru", "phone": "+70756190549"}
0005432188599	C98017	0641 157076	SERGEY SOROKIN	{"phone": "+70556097047"}
0005432188600	17A8B1	6839 251406	PAVEL NIKOLAEV	{"email": "nikolaevpavel-1972@postgrespro.ru", "phone": "+70287630079"}
0005432188601	E8D511	9958 516549	DMITRIY TIKHONOV	{"phone": "+70688795235"}
0005432188602	E8D511	4423 169671	LYUDMILA KARPOVA	{"phone": "+70441265225"}
0005432188603	F1C902	6208 717046	ELENA BORISOVA	{"phone": "+70681839669"}
0005432188604	F1C902	6500 645133	KRISTINA ANDREEVA	{"phone": "+70648215352"}
0005432188605	5989D5	8382 077012	VALENTINA KUZMINA	{"phone": "+70631993246"}
0005432188606	320DDE	3390 155095	IVAN MEDVEDEV	{"email": "medvedevivan22031974@postgrespro.ru", "phone": "+70531059539"}
0005432188607	320DDE	5775 342590	ANATOLIY YAKOVLEV	{"email": "anatoliy.yakovlev.09111974@postgrespro.ru", "phone": "+70938031904"}
0005432188608	0DDD95	9002 822325	TATYANA KOZLOVA	{"email": "tkozlova.1977@postgrespro.ru", "phone": "+70484836047"}
0005432188609	527B3B	6769 590214	NIKOLAY MAKAROV	{"phone": "+70015805990"}
0005432188610	527B3B	1817 799407	VALENTINA DENISOVA	{"phone": "+70075885358"}
0005432188611	AC7C60	8496 636606	EKATERINA IVANOVA	{"phone": "+70621506680"}
0005432188612	AC7C60	1131 509464	VLADIMIR RODIONOV	{"email": "rodionov_v-26071979@postgrespro.ru", "phone": "+70557453002"}
0005432188613	F41182	0555 436748	GALINA DENISOVA	{"phone": "+70390953359"}
0005432188614	F41182	9241 136574	SERGEY MOROZOV	{"phone": "+70484076149"}
0005432188615	E73771	3092 551811	NATALYA FEDOROVA	{"email": "n_fedorova_1976@postgrespro.ru", "phone": "+70996818020"}
0005432188616	F34972	7077 978241	ANDREY AFANASEV	{"phone": "+70572879137"}
0005432188617	F34972	8231 024493	ANNA MASLOVA	{"phone": "+70387366616"}
0005432188618	9651B0	9927 073784	GALINA GUSEVA	{"email": "guseva.galina12121962@postgrespro.ru", "phone": "+70984239265"}
0005432188619	A80A38	0339 936702	SVETLANA MAKAROVA	{"email": "makarova-s_041968@postgrespro.ru", "phone": "+70695511144"}
0005432188620	A80A38	8895 785408	ALBINA NIKOLAEVA	{"email": "a_nikolaeva1984@postgrespro.ru", "phone": "+70480637369"}
0005432188621	6EF36A	8007 902522	OLGA VASILEVA	{"email": "olga.vasileva.1973@postgrespro.ru", "phone": "+70818896607"}
0005432188622	6EF36A	6466 001123	ELENA PAVLOVA	{"phone": "+70288200944"}
0005432188623	9C804D	8783 034712	VALENTINA KONDRATEVA	{"email": "kondratevav-08091975@postgrespro.ru", "phone": "+70170276485"}
0005432188624	9C804D	3266 804027	VALENTINA KUZNECOVA	{"phone": "+70588661003"}
0005432188625	9C804D	1479 931001	SERGEY ORLOV	{"phone": "+70930398605"}
0005432188626	E49C83	9718 419727	RAMIL VLASOV	{"email": "vlasov_ramil.1972@postgrespro.ru", "phone": "+70678168537"}
0005432188627	E49C83	8361 922410	YURIY NIKOLAEV	{"email": "yuriynikolaev-111971@postgrespro.ru", "phone": "+70306723797"}
0005432188628	D4AFC9	1119 993437	ROMAN MAKSIMOV	{"email": "r-maksimov1963@postgrespro.ru", "phone": "+70028542708"}
0005432188629	D4AFC9	1968 807917	LIDIYA NAZAROVA	{"email": "nazarovalidiya.071974@postgrespro.ru", "phone": "+70976234284"}
0005432188630	2CD9E7	6348 464648	ALEVTINA VOLKOVA	{"phone": "+70350885759"}
0005432188631	617F95	7847 296492	NIKITA MIKHAYLOV	{"phone": "+70488241677"}
0005432188632	6349F7	9011 017105	VLADIMIR VASILEV	{"phone": "+70953391566"}
0005432188633	76342F	1938 737727	ALEKSEY FOMIN	{"email": "alekseyfomin_23081978@postgrespro.ru", "phone": "+70668597527"}
0005432188634	71FA95	8186 783989	IGOR KOZLOV	{"email": "kozlovi.13081975@postgrespro.ru", "phone": "+70018075884"}
0005432188635	1E6012	3954 238478	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir_29081966@postgrespro.ru", "phone": "+70044232298"}
0005432188636	318CF0	8861 819416	DARYA EFIMOVA	{"phone": "+70002645167"}
0005432188637	1DA66D	8621 390740	IGOR MOISEEV	{"phone": "+70533237979"}
0005432188638	1DA66D	3968 449606	VLADIMIR SMIRNOV	{"phone": "+70660719296"}
0005432188639	5D4740	5661 021104	MARINA GERASIMOVA	{"phone": "+70133364323"}
0005432188640	E2734D	0959 544514	ANATOLIY SEMENOV	{"email": "a_semenov-04031968@postgrespro.ru", "phone": "+70689311378"}
0005432188641	1686E5	8569 161101	SERGEY PAVLOV	{"phone": "+70109491645"}
0005432188642	A4F07B	7709 414521	ALEKSEY KULIKOV	{"phone": "+70773394414"}
0005432188643	A4F07B	5837 746972	DMITRIY STEPANOV	{"phone": "+70988187897"}
0005432188644	6C8E99	9550 520999	VADIM KUDRYASHOV	{"email": "kudryashov-v.08121967@postgrespro.ru", "phone": "+70662317761"}
0005432188645	6C8E99	1495 148410	VLADIMIR SCHERBAKOV	{"phone": "+70483202628"}
0005432188646	2512D4	8214 069037	PAVEL KUZMIN	{"phone": "+70061435110"}
0005432188647	2512D4	1563 918293	LILIYA KAZAKOVA	{"phone": "+70147632110"}
0005432188648	2047F8	9760 131276	VLADIMIR SAVELEV	{"email": "vladimir_savelev28121976@postgrespro.ru", "phone": "+70759234220"}
0005432188649	2047F8	5474 281212	ALEKSANDR ALEKSEEV	{"phone": "+70142287912"}
0005432188650	2047F8	5792 898436	VALERIYA FOMINA	{"email": "vfomina-031973@postgrespro.ru", "phone": "+70937531689"}
0005432188651	0408C1	6268 958849	KONSTANTIN ANTONOV	{"email": "antonov_k031968@postgrespro.ru", "phone": "+70250828530"}
0005432188652	0408C1	5787 081604	PETR SMIRNOV	{"email": "smirnovpetr-1972@postgrespro.ru", "phone": "+70547285521"}
0005432188653	4875F7	8491 086512	ALEKSEY PETROV	{"phone": "+70033148250"}
0005432188654	4875F7	7406 658372	MARINA IVANOVA	{"phone": "+70861491266"}
0005432188655	CCB123	8266 791679	TATYANA MEDVEDEVA	{"phone": "+70532333892"}
0005432188656	944948	0663 624420	ANDREY NIKOLAEV	{"email": "nikolaeva.1983@postgrespro.ru", "phone": "+70776352545"}
0005432188657	6DD297	4703 393706	NATALYA ZHUKOVA	{"email": "n_zhukova_051966@postgrespro.ru", "phone": "+70362397192"}
0005432188658	B59369	4522 599575	DMITRIY PAVLOV	{"phone": "+70533862090"}
0005432188659	81B0F5	1555 768172	VIKTOR FILIPPOV	{"phone": "+70495766872"}
0005432188660	81B0F5	5720 981618	GALINA IVANOVA	{"email": "g-ivanova031975@postgrespro.ru", "phone": "+70261075744"}
0005432188661	2FC1F0	4946 932001	SERGEY VOROBEV	{"email": "vorobev-sergey-1953@postgrespro.ru", "phone": "+70044307625"}
0005432188662	9B9F30	0415 958383	NADEZHDA MASLOVA	{"phone": "+70120021410"}
0005432188663	9B9F30	0753 702169	ZOYA ZHURAVLEVA	{"phone": "+70469973450"}
0005432188664	8AEDA9	0154 603322	MIKHAIL FEDOTOV	{"phone": "+70409611768"}
0005432188665	47F3D4	4735 318223	ANASTASIYA OSIPOVA	{"phone": "+70275396899"}
0005432188666	47F3D4	2216 210339	NIKOLAY AFANASEV	{"email": "afanasev.nikolay.1976@postgrespro.ru", "phone": "+70131390661"}
0005432188667	ED6B11	2828 760207	DIANA SOLOVEVA	{"phone": "+70544796467"}
0005432188668	ED6B11	4781 833481	LARISA KOROLEVA	{"email": "l.koroleva.1966@postgrespro.ru", "phone": "+70934962429"}
0005432188669	ED6B11	0585 179973	ROMAN ANTONOV	{"email": "r-antonov_01121964@postgrespro.ru", "phone": "+70052537873"}
0005432188670	1145D7	0612 353788	KONSTANTIN SERGEEV	{"phone": "+70870765605"}
0005432188671	1145D7	1664 952563	EVGENIY IVANOV	{"phone": "+70056876459"}
0005432188672	5E8D20	9129 279689	IRINA MARTYNOVA	{"email": "martynova.i-19021976@postgrespro.ru", "phone": "+70469454436"}
0005432188673	5E8D20	2026 998847	EKATERINA NAUMOVA	{"phone": "+70127217294"}
0005432188674	D21976	0183 951554	MAKSIM NAUMOV	{"phone": "+70829363294"}
0005432188675	D21976	6852 920828	EGOR KUZMIN	{"phone": "+70055173025"}
0005432188676	648F41	5643 575965	KIRA ZAKHAROVA	{"email": "zakharova.k.1969@postgrespro.ru", "phone": "+70371496312"}
0005432188677	648F41	9623 153735	LARISA DENISOVA	{"phone": "+70624395226"}
0005432188678	89FE3D	4811 738827	MARINA KOVALEVA	{"phone": "+70511622794"}
0005432188679	87DFA5	4470 694304	ELENA ROMANOVA	{"email": "e.romanova_1966@postgrespro.ru", "phone": "+70487125832"}
0005432188680	CD3977	5896 216772	ANDREY TARASOV	{"email": "tarasov-andrey17021976@postgrespro.ru", "phone": "+70132463475"}
0005432188681	18D114	1254 714837	PAVEL ANTONOV	{"phone": "+70267743613"}
0005432188682	18D114	0971 094429	SVETLANA VASILEVA	{"phone": "+70513155632"}
0005432188683	713518	1790 491769	ALEVTINA ILINA	{"phone": "+70737869624"}
0005432188684	EE569E	2088 962971	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov_101985@postgrespro.ru", "phone": "+70490508121"}
0005432188685	EE569E	9916 633247	ANDREY KUZNECOV	{"email": "a-kuznecov-08051970@postgrespro.ru", "phone": "+70187202091"}
0005432188686	34014D	2551 387879	DANIIL GERASIMOV	{"email": "gerasimov.daniil16081972@postgrespro.ru", "phone": "+70176013346"}
0005432188687	34014D	2230 579535	ALEKSEY SOROKIN	{"phone": "+70588907121"}
0005432188688	E0BDC6	4036 480152	GALINA FILATOVA	{"email": "filatova.g-14041965@postgrespro.ru", "phone": "+70790220479"}
0005432188689	E0BDC6	9789 794148	ILYA MOISEEV	{"email": "imoiseev.091985@postgrespro.ru", "phone": "+70139567968"}
0005432188690	64FF7A	0450 848052	ANASTASIYA KONDRATEVA	{"email": "a-kondrateva-051975@postgrespro.ru", "phone": "+70442106151"}
0005432188691	64FF7A	3543 123701	LIDIYA KULIKOVA	{"email": "kulikova_l_1981@postgrespro.ru", "phone": "+70144418681"}
0005432188692	45C6DC	1916 970479	SVETLANA SAVELEVA	{"phone": "+70277664941"}
0005432188693	C96A21	0286 441968	ALEKSANDR VOLKOV	{"email": "avolkov011962@postgrespro.ru", "phone": "+70040658103"}
0005432188694	156A9F	8033 112255	DARYA PETROVA	{"phone": "+70049486504"}
0005432188695	156A9F	6828 222362	MARINA KOROLEVA	{"phone": "+70379864960"}
0005432188696	D9B339	5050 564274	NADEZHDA BORISOVA	{"email": "borisovan12021978@postgrespro.ru", "phone": "+70238995886"}
0005432188697	D9B339	2573 809605	DMITRIY MAKAROV	{"phone": "+70377851531"}
0005432188698	D9B339	6759 083399	VERA TIKHONOVA	{"phone": "+70067030830"}
0005432188699	6B9AFA	3817 568550	ELENA VASILEVA	{"email": "vasileva.e1965@postgrespro.ru", "phone": "+70632101136"}
0005432188700	777752	7183 617533	TATYANA KAZAKOVA	{"phone": "+70200608435"}
0005432188701	3718D2	5679 399288	LYUDMILA NIKITINA	{"email": "lnikitina.25021967@postgrespro.ru", "phone": "+70525852878"}
0005432188702	C291F7	7056 989425	ARTEM POPOV	{"phone": "+70960631574"}
0005432190626	D0A198	7578 029492	POLINA KALININA	{"phone": "+70875962641"}
0005432190561	95BCD0	4768 137788	OLGA NOVIKOVA	{"email": "novikova-olga13101960@postgrespro.ru", "phone": "+70995213648"}
0005432190562	95BCD0	8214 552839	SVETLANA PAVLOVA	{"phone": "+70857974888"}
0005432190563	25E77C	2600 942719	NINA CHERNOVA	{"email": "chernova.nina_1974@postgrespro.ru", "phone": "+70518423756"}
0005432190564	25E77C	8826 629249	MAKSIM RODIONOV	{"email": "rodionov.m.061976@postgrespro.ru", "phone": "+70181473774"}
0005432190565	F195ED	0070 287900	MARINA KOLESNIKOVA	{"phone": "+70028355349"}
0005432190566	5E13EA	2964 490662	ALEKSANDR ALEKSEEV	{"email": "aleksandr-alekseev03041980@postgrespro.ru", "phone": "+70794527981"}
0005432190567	5E13EA	3020 280700	IVAN MIKHAYLOV	{"phone": "+70825104889"}
0005432190568	CAD2B6	7705 164722	YURIY MIKHAYLOV	{"email": "y-mikhaylov-051969@postgrespro.ru", "phone": "+70441643609"}
0005432190569	2432C2	3161 218016	ALEKSANDRA VLASOVA	{"phone": "+70420557014"}
0005432190570	9594D9	6366 493218	NIKITA ILIN	{"email": "nikita.ilin-1968@postgrespro.ru", "phone": "+70826760897"}
0005432190571	4BBC09	9213 631379	ELENA POPOVA	{"phone": "+70502033938"}
0005432190572	6C62D2	3240 991467	EVGENIY GUSEV	{"email": "gusev-evgeniy-1980@postgrespro.ru", "phone": "+70004341842"}
0005432190573	85CD8F	8369 418960	NATALYA NAZAROVA	{"email": "nnazarova_091972@postgrespro.ru", "phone": "+70351578028"}
0005432190574	85CD8F	2422 489556	ELENA SCHERBAKOVA	{"phone": "+70842187801"}
0005432190575	78F507	9690 220212	IRINA ALEKSEEVA	{"phone": "+70062069418"}
0005432190576	61B406	2320 355717	IGOR SIDOROV	{"email": "sidorov_i_031965@postgrespro.ru", "phone": "+70478756519"}
0005432190577	4183ED	3913 190991	EKATERINA ERMAKOVA	{"email": "e-ermakova_091960@postgrespro.ru", "phone": "+70916379124"}
0005432190578	4183ED	1933 046867	DENIS VASILEV	{"email": "vasilev_d_1967@postgrespro.ru", "phone": "+70554829706"}
0005432190579	D3E18B	0863 034361	ANTON ALEKSANDROV	{"phone": "+70784781936"}
0005432190580	2BD868	6514 980206	TATYANA AKIMOVA	{"phone": "+70497793111"}
0005432190581	4687F4	7757 855933	VERA NESTEROVA	{"phone": "+70699866118"}
0005432190582	4687F4	9134 635456	MARIYA FOMINA	{"email": "fomina-m03021969@postgrespro.ru", "phone": "+70210990487"}
0005432190583	26222D	0488 393421	VALENTINA DENISOVA	{"phone": "+70213976761"}
0005432190584	6DA3FD	2806 903917	RAFAIL KUZNECOV	{"phone": "+70745671136"}
0005432190585	3DCD5F	4877 445171	ANNA SMIRNOVA	{"email": "anna.smirnova-1962@postgrespro.ru", "phone": "+70603879269"}
0005432190586	958EF5	4641 604031	EGOR BELOV	{"email": "egor_belov_021972@postgrespro.ru", "phone": "+70658039636"}
0005432190587	56981C	4944 447093	MARINA YUDINA	{"phone": "+70428169874"}
0005432190588	4DAEF5	4659 386746	VLADIMIR GAVRILOV	{"phone": "+70812253420"}
0005432190589	4DAEF5	5329 162728	YULIYA MIKHAYLOVA	{"email": "yuliya.mikhaylova.1972@postgrespro.ru", "phone": "+70704150588"}
0005432190590	A6B3AC	0221 220448	ANDREY KUZNECOV	{"phone": "+70573573117"}
0005432190591	EB24AD	4712 879995	VALENTINA GORBUNOVA	{"email": "valentina_gorbunova-30091986@postgrespro.ru", "phone": "+70726545391"}
0005432190592	854C98	8044 207354	EVGENIY KISELEV	{"phone": "+70264381808"}
0005432190593	92228C	4186 887937	ALEKSANDRA ROMANOVA	{"email": "romanova-a1965@postgrespro.ru", "phone": "+70237000467"}
0005432190594	65B91E	6739 756226	GALINA POLYAKOVA	{"email": "galina_polyakova.24111973@postgrespro.ru", "phone": "+70543961728"}
0005432190595	65B91E	3303 147075	MARIYA FEDOROVA	{"email": "fedorova-m.011984@postgrespro.ru", "phone": "+70728267274"}
0005432190596	F827C8	7650 757720	MIKHAIL MIRONOV	{"email": "mikhailmironov.1981@postgrespro.ru", "phone": "+70080048521"}
0005432190597	F767E4	8031 312263	DIANA IVANOVA	{"email": "diana_ivanova_101975@postgrespro.ru", "phone": "+70988092272"}
0005432190598	F767E4	6423 476292	SVETLANA FEDOROVA	{"email": "fedorova.s-111977@postgrespro.ru", "phone": "+70717798884"}
0005432190599	071A45	6595 350119	VLADIMIR VASILEV	{"email": "vasilev.vladimir-28051968@postgrespro.ru", "phone": "+70547353849"}
0005432190600	802B8A	2263 485903	NATALYA ILINA	{"phone": "+70845217176"}
0005432190601	802B8A	2023 062120	VALERIY BORISOV	{"phone": "+70322343465"}
0005432190602	802B8A	4393 277849	IVAN IVANOV	{"email": "ivanovi111976@postgrespro.ru", "phone": "+70524470338"}
0005432190603	ABD1CC	7516 459251	SERGEY BORISOV	{"email": "sborisov1978@postgrespro.ru", "phone": "+70884864096"}
0005432190604	ABD1CC	0292 368602	VIKTOR ROMANOV	{"email": "viktor-romanov1964@postgrespro.ru", "phone": "+70920359127"}
0005432190605	ABD1CC	5194 577979	SVETLANA KALININA	{"email": "svetlana_kalinina_13041968@postgrespro.ru", "phone": "+70825892119"}
0005432190606	17CD47	0376 367407	NIKOLAY KUDRYASHOV	{"phone": "+70335696566"}
0005432190607	4523F2	3896 106233	ANATOLIY GRIGOREV	{"email": "a_grigorev_11071966@postgrespro.ru", "phone": "+70943781791"}
0005432190608	4523F2	3202 845832	LYUDMILA EGOROVA	{"phone": "+70082360936"}
0005432190609	3026AE	6010 941141	LYUBOV SIDOROVA	{"phone": "+70387111897"}
0005432190610	88600C	5840 437259	ANDREY STEPANOV	{"email": "stepanov.a1976@postgrespro.ru", "phone": "+70922309065"}
0005432190611	88600C	4467 456204	ULYANA ARKHIPOVA	{"email": "ulyana.arkhipova-1963@postgrespro.ru", "phone": "+70746039048"}
0005432190612	C5283F	6337 776960	ALEKSANDR SAVELEV	{"phone": "+70824795391"}
0005432190613	48B34C	6362 587163	MARIYA KONDRATEVA	{"phone": "+70204575327"}
0005432190614	48B34C	3452 353374	POLINA KOZLOVA	{"email": "kozlova_p-1979@postgrespro.ru", "phone": "+70315332956"}
0005432190615	E8AB6A	8615 516383	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov_1983@postgrespro.ru", "phone": "+70374755997"}
0005432190616	E8AB6A	8183 704204	NADEZHDA DMITRIEVA	{"email": "dmitrieva.n1964@postgrespro.ru", "phone": "+70897712750"}
0005432190617	AF4B52	8041 507774	VIKTOR GORBUNOV	{"phone": "+70443761439"}
0005432190618	BCF168	2083 354045	SERGEY SCHERBAKOV	{"phone": "+70994654329"}
0005432190619	536B3B	7364 944494	YURIY KUZNECOV	{"email": "y-kuznecov.06121974@postgrespro.ru", "phone": "+70819172136"}
0005432190620	536B3B	7431 802274	SERGEY VOLKOV	{"email": "volkov.sergey_021968@postgrespro.ru", "phone": "+70023694161"}
0005432190621	536B3B	0962 087582	ANTONINA NESTEROVA	{"phone": "+70350318318"}
0005432190622	C2D8F4	0424 955898	SERGEY MARTYNOV	{"phone": "+70585632869"}
0005432190623	C2D8F4	3699 812959	GALINA NIKOLAEVA	{"email": "nikolaeva.g_051963@postgrespro.ru", "phone": "+70127876362"}
0005432190624	443598	6962 465678	EKATERINA ILINA	{"email": "ilina_e.1967@postgrespro.ru", "phone": "+70721512363"}
0005432190625	D0A198	9216 211282	TATYANA ZOTOVA	{"phone": "+70023469189"}
0005432190627	D0A198	4666 358269	TAMARA SOROKINA	{"email": "t_sorokina031958@postgrespro.ru", "phone": "+70752837227"}
0005432190628	66A8E5	3957 953314	ALEKSEY DMITRIEV	{"email": "alekseydmitriev-24011959@postgrespro.ru", "phone": "+70582546365"}
0005432190629	558088	9680 954090	VYACHESLAV KUZMIN	{"phone": "+70480541651"}
0005432190630	EEF0EB	4422 465321	OLGA KUZNECOVA	{"phone": "+70636037493"}
0005432190631	E4100A	8317 960450	VITALIY KUDRYASHOV	{"phone": "+70966590750"}
0005432190632	49F1F1	6001 905269	MARIYA DENISOVA	{"phone": "+70930721815"}
0005432190633	3A4EEA	1184 063111	YULIYA SERGEEVA	{"email": "sergeeva_yuliya_06011975@postgrespro.ru", "phone": "+70758343844"}
0005432190634	3A4EEA	2747 343819	ANATOLIY KUZMIN	{"email": "kuzminanatoliy111978@postgrespro.ru", "phone": "+70796583397"}
0005432190635	CFA203	0297 749625	ALEKSANDR SAVELEV	{"email": "a.savelev.031978@postgrespro.ru", "phone": "+70637290966"}
0005432190636	CFA203	2272 042296	LYUDMILA CHERNOVA	{"phone": "+70763474685"}
0005432190637	29C720	5656 569865	IGOR SEMENOV	{"phone": "+70591427330"}
0005432192401	803477	4504 845703	ALEKSANDR GAVRILOV	{"phone": "+70841425639"}
0005432190638	2F2D81	8656 052426	VLADIMIR KUZNECOV	{"email": "kuznecov.v28091969@postgrespro.ru", "phone": "+70634908721"}
0005432190639	E02311	8704 342063	GENNADIY GUSEV	{"email": "gusev-g.1983@postgrespro.ru", "phone": "+70199849923"}
0005432190640	E02311	4036 044817	ANDREY BELOV	{"email": "andrey_belov06021976@postgrespro.ru", "phone": "+70986863298"}
0005432190641	E02311	2592 394400	SVETLANA ISAEVA	{"email": "svetlana-isaeva06111967@postgrespro.ru", "phone": "+70528963695"}
0005432190642	BDFECD	5032 929660	ELENA NIKOLAEVA	{"phone": "+70529234921"}
0005432190643	BDFECD	6267 464774	GENNADIY ROMANOV	{"email": "romanov-gennadiy081973@postgrespro.ru", "phone": "+70210361057"}
0005432190644	0A2D55	3152 762284	LYUDMILA BELYAEVA	{"phone": "+70695598704"}
0005432190645	D94AFC	5747 003295	GALINA DANILOVA	{"phone": "+70380815753"}
0005432190646	7E1543	6763 695074	NATALYA ROMANOVA	{"phone": "+70066777207"}
0005432190647	4B2F82	7335 179924	ELENA IVANOVA	{"phone": "+70682148199"}
0005432190648	5F27E8	9644 208673	MARAT PAVLOV	{"email": "marat_pavlov-23071977@postgrespro.ru", "phone": "+70983602204"}
0005432190649	AFC5D4	9645 880646	SAVELIY SCHERBAKOV	{"email": "scherbakov_s_1974@postgrespro.ru", "phone": "+70901427040"}
0005432190650	AFC5D4	9327 654869	ANDREY ROMANOV	{"email": "romanovandrey-21031980@postgrespro.ru", "phone": "+70695742847"}
0005432190651	AFC5D4	9958 101294	ELENA PAVLOVA	{"phone": "+70137933761"}
0005432190652	C9D9D6	3156 800124	OLGA SEMENOVA	{"email": "olga-semenova_1970@postgrespro.ru", "phone": "+70924397447"}
0005432190653	C75ED6	2006 520017	MAKSIM KULIKOV	{"email": "kulikov-m111971@postgrespro.ru", "phone": "+70664281900"}
0005432190654	338CE5	6807 642508	VALENTINA MAKAROVA	{"phone": "+70610694495"}
0005432190655	D1EFF4	2144 011898	VITALIY MAKAROV	{"phone": "+70690548450"}
0005432190656	36B5BE	8747 098367	VIKTORIYA MOISEEVA	{"phone": "+70758738397"}
0005432190657	36B5BE	5296 601636	ALEKSEY PETROV	{"phone": "+70643924067"}
0005432190658	9FA8D3	6599 952832	ANATOLIY NIKITIN	{"email": "anikitin_1965@postgrespro.ru", "phone": "+70731004304"}
0005432190659	65F40F	7521 072215	ANATOLIY CHERNOV	{"email": "chernov-anatoliy121974@postgrespro.ru", "phone": "+70492373342"}
0005432190660	93BEDD	4494 963033	VLADIMIR TIKHONOV	{"phone": "+70305237629"}
0005432190661	93BEDD	3488 552035	ELENA IVANOVA	{"phone": "+70874182083"}
0005432190662	2E5934	8381 352233	MARIYA FILATOVA	{"phone": "+70012196293"}
0005432190663	2E5934	5664 130858	OLGA LOGINOVA	{"phone": "+70681571945"}
0005432190664	D65FF0	5422 821950	IVAN IVANOV	{"email": "ivanovi-1983@postgrespro.ru", "phone": "+70997816079"}
0005432190665	5F4DF0	5620 546827	NATALYA BORISOVA	{"phone": "+70501307554"}
0005432190666	5F4DF0	2714 214909	SERGEY KOROLEV	{"phone": "+70633043273"}
0005432190667	86D3EA	9180 318386	VLADIMIR TIMOFEEV	{"phone": "+70123958919"}
0005432190668	886EB5	1105 469229	VALERIY SERGEEV	{"phone": "+70659317179"}
0005432190669	704024	2628 531869	YULIYA YUDINA	{"phone": "+70796515285"}
0005432190670	6D1CA1	4973 222759	VIKTOR MATVEEV	{"email": "v-matveev1966@postgrespro.ru", "phone": "+70114276401"}
0005432190671	F6A5A9	2901 327231	TATYANA VASILEVA	{"phone": "+70831978591"}
0005432190672	9B5B53	7044 859827	MARIYA SERGEEVA	{"email": "sergeeva.mariya-1973@postgrespro.ru", "phone": "+70140762310"}
0005432190673	B2DAE2	7665 520025	LYUDMILA KOROLEVA	{"phone": "+70334172010"}
0005432190674	B2DAE2	8060 396584	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_10111978@postgrespro.ru", "phone": "+70162727729"}
0005432190675	641ECB	0348 647648	LYUDMILA KRASNOVA	{"email": "krasnova_lyudmila.20121960@postgrespro.ru", "phone": "+70568029560"}
0005432190676	25F811	0111 348788	VLADIMIR ANDREEV	{"email": "vandreev-01071969@postgrespro.ru", "phone": "+70549212996"}
0005432190677	BD052C	7228 484396	GALINA POPOVA	{"email": "galina.popova1972@postgrespro.ru", "phone": "+70441957906"}
0005432190678	B64CC7	0773 011685	ANDREY ANDREEV	{"email": "andreev.a_1971@postgrespro.ru", "phone": "+70695895832"}
0005432190679	4007F1	8138 792535	DMITRIY ILIN	{"email": "ilind-1966@postgrespro.ru", "phone": "+70943227822"}
0005432190680	4007F1	7356 936685	PELAGEYA NAUMOVA	{"email": "p_naumova_041976@postgrespro.ru", "phone": "+70857400400"}
0005432190681	5AC93D	1222 705178	VIKTOR EGOROV	{"phone": "+70894480614"}
0005432190682	0EEFD8	6911 934124	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev_21081974@postgrespro.ru", "phone": "+70800536411"}
0005432190683	93470F	4568 301359	LARISA KUZNECOVA	{"phone": "+70507965185"}
0005432190684	93470F	7279 912821	POLINA KUZNECOVA	{"email": "kuznecova-p_22121975@postgrespro.ru", "phone": "+70780038998"}
0005432190685	EA2D7E	5252 099344	ALEKSANDRA MATVEEVA	{"email": "matveevaa_11051967@postgrespro.ru", "phone": "+70798178574"}
0005432190686	D152E9	9942 002239	ELENA IVANOVA	{"email": "e_ivanova_1975@postgrespro.ru", "phone": "+70277190803"}
0005432190687	D26CB4	1605 225074	SVETLANA FOMINA	{"email": "fomina_svetlana.1974@postgrespro.ru", "phone": "+70694881721"}
0005432190688	D26CB4	2481 477675	ANASTASIYA NAZAROVA	{"phone": "+70486918298"}
0005432190689	B534B1	8998 530008	VALERIYA NIKOLAEVA	{"phone": "+70147930632"}
0005432190690	3BC2C6	1631 748710	ANATOLIY BELOV	{"email": "belov-anatoliy1975@postgrespro.ru", "phone": "+70556162370"}
0005432190691	C1CDF5	5446 121442	TIMUR ABRAMOV	{"phone": "+70649347319"}
0005432190692	99A79C	0245 300416	VASILIY EGOROV	{"email": "v_egorov.081977@postgrespro.ru", "phone": "+70325090483"}
0005432190693	EEEEC4	5458 656228	EKATERINA ANDREEVA	{"phone": "+70702910716"}
0005432190694	EF0557	6858 174896	LYUBOV GORBUNOVA	{"email": "gorbunoval-091973@postgrespro.ru", "phone": "+70337226467"}
0005432190695	B1835C	0808 721890	ALEKSANDR FROLOV	{"phone": "+70271455925"}
0005432190696	29B1B1	3846 547441	ANATOLIY BARANOV	{"email": "baranov.anatoliy-1973@postgrespro.ru", "phone": "+70261962153"}
0005432190697	ABB7AF	4620 023348	VLADIMIR CHERNOV	{"phone": "+70351725481"}
0005432190698	783227	3938 531538	ELENA EFREMOVA	{"email": "elena_efremova_111966@postgrespro.ru", "phone": "+70448080381"}
0005432190699	EE3F21	4431 663562	LYUDMILA NIKITINA	{"phone": "+70181109276"}
0005432190700	E703A0	3845 808038	VALENTINA LEBEDEVA	{"phone": "+70799838666"}
0005432190701	E703A0	7024 376170	VLADIMIR KOZLOV	{"email": "kozlov-v_24041976@postgrespro.ru", "phone": "+70753772873"}
0005432190702	FAF0B1	6134 507222	SEMEN SOKOLOV	{"phone": "+70016762434"}
0005432190703	FB70A8	3600 936714	VIKTORIYA ZOTOVA	{"email": "v.zotova-31081969@postgrespro.ru", "phone": "+70256060457"}
0005432190704	779D70	7355 918212	VITALIY POPOV	{"email": "popov-v051973@postgrespro.ru", "phone": "+70378439253"}
0005432190705	D95BC2	4834 201290	VALERIY PETROV	{"phone": "+70846289246"}
0005432190706	9E2319	4692 266647	IRINA LAZAREVA	{"email": "irina_lazareva1964@postgrespro.ru", "phone": "+70329374527"}
0005432190707	C7FC60	8410 666564	EKATERINA NESTEROVA	{"email": "ekaterina_nesterova.101976@postgrespro.ru", "phone": "+70934770395"}
0005432190708	80EED8	6635 722019	VERA FROLOVA	{"email": "frolova_vera_1965@postgrespro.ru", "phone": "+70256215750"}
0005432190709	D4347A	1799 566018	VALENTINA YAKOVLEVA	{"phone": "+70715750786"}
0005432190710	663139	3844 300325	ANASTASIYA FADEEVA	{"email": "fadeeva-a_03021975@postgrespro.ru", "phone": "+70574535771"}
0005432190711	E347A8	0412 611654	VALERIY KRASNOV	{"email": "v-krasnov01061961@postgrespro.ru", "phone": "+70096155720"}
0005432190712	4B20B7	2799 036224	DAVID IVANOV	{"phone": "+70324126593"}
0005432190713	27FCD4	7448 253133	FAINA IVANOVA	{"phone": "+70736621046"}
0005432190714	BE3A24	6196 234006	ALEKSANDR MOROZOV	{"phone": "+70758853896"}
0005432190715	AEDD5F	0004 563564	NINA ROMANOVA	{"phone": "+70529409620"}
0005432190716	AEDD5F	9147 826862	ALEKSANDR KONOVALOV	{"email": "konovalov.a-1969@postgrespro.ru", "phone": "+70733425721"}
0005432190717	AEDD5F	7389 470399	ANASTASIYA OSIPOVA	{"email": "anastasiya_osipova.1959@postgrespro.ru", "phone": "+70188447055"}
0005432190718	FD9975	4985 965201	SERGEY KOROLEV	{"email": "s_korolev.02011970@postgrespro.ru", "phone": "+70056133130"}
0005432190719	7217D9	4082 475000	LIDIYA MELNIKOVA	{"email": "melnikova_lidiya-1972@postgrespro.ru", "phone": "+70735001860"}
0005432190720	7217D9	0998 816600	MARINA FILATOVA	{"email": "m_filatova1975@postgrespro.ru", "phone": "+70952010268"}
0005432190721	7217D9	9872 667669	OLEG MARTYNOV	{"email": "omartynov_1990@postgrespro.ru", "phone": "+70672313203"}
0005432190722	318C85	7445 832683	SERGEY ALEKSEEV	{"phone": "+70738018746"}
0005432190723	318C85	6600 080157	ALEKSEY FEDOROV	{"email": "a-fedorov_1976@postgrespro.ru", "phone": "+70135711945"}
0005432190724	33CB06	2309 818394	VALENTINA KONDRATEVA	{"email": "v-kondrateva_1966@postgrespro.ru", "phone": "+70204469176"}
0005432190725	D6D365	4040 722268	LIDIYA EGOROVA	{"phone": "+70064440446"}
0005432190726	A1C973	2496 986693	NADEZHDA ARKHIPOVA	{"phone": "+70701295346"}
0005432190727	A1C973	5649 716710	EKATERINA KOMAROVA	{"phone": "+70612775891"}
0005432190728	FE2856	1827 713146	VLADIMIR BELOV	{"email": "belov_v.17081963@postgrespro.ru", "phone": "+70181501352"}
0005432190729	5DC2E8	6736 894631	ALEKSANDR ISAEV	{"email": "isaev_a041960@postgrespro.ru", "phone": "+70882180344"}
0005432190730	5DC2E8	6336 012492	ALEKSANDRA POPOVA	{"email": "aleksandrapopova_18061969@postgrespro.ru", "phone": "+70554500631"}
0005432190731	5DC2E8	7878 878447	VLADIMIR PETROV	{"phone": "+70044242074"}
0005432190732	03046B	1494 191394	IRINA KAZAKOVA	{"email": "ikazakova.1972@postgrespro.ru", "phone": "+70784625250"}
0005432190733	F8BF43	6699 418269	ALEKSANDR BORISOV	{"phone": "+70594748375"}
0005432190734	059435	7703 148326	MAKSIM FILIPPOV	{"email": "maksim.filippov-27101967@postgrespro.ru", "phone": "+70025983371"}
0005432190735	F5D835	4423 300139	DMITRIY ZHUKOV	{"email": "d-zhukov-1973@postgrespro.ru", "phone": "+70638392926"}
0005432190736	F5D835	2823 882355	DANILA KUZMIN	{"phone": "+70111089829"}
0005432190737	F5D835	8159 186613	DARYA TIKHONOVA	{"email": "darya.tikhonova1970@postgrespro.ru", "phone": "+70316996072"}
0005432190738	C2C11B	5725 099974	MARGARITA SOLOVEVA	{"phone": "+70325424653"}
0005432190739	EB882B	1649 182632	EVGENIY ORLOV	{"phone": "+70990755293"}
0005432192263	38CB6B	6395 467328	SAMIR KAZAKOV	{"email": "s-kazakov_061968@postgrespro.ru", "phone": "+70480900932"}
0005432192264	9D2580	8709 289024	VLADIMIR BORISOV	{"email": "vladimir.borisov.26081978@postgrespro.ru", "phone": "+70596642179"}
0005432192265	C04E27	2588 034421	LYUDMILA BOGDANOVA	{"email": "bogdanoval041972@postgrespro.ru", "phone": "+70390411494"}
0005432192266	41E86C	9306 839879	YULIYA ZHUKOVA	{"phone": "+70969748734"}
0005432192267	ED1027	8194 991373	DMITRIY BORISOV	{"phone": "+70956593183"}
0005432192268	913149	4089 853849	VALENTINA DENISOVA	{"phone": "+70872056354"}
0005432192269	913149	9319 383318	NADEZHDA KOVALEVA	{"phone": "+70976956963"}
0005432192270	7F9AF0	8468 878269	NIKITA MAKAROV	{"phone": "+70494130546"}
0005432192271	BFB0CF	0294 708204	GALINA NESTEROVA	{"phone": "+70630462924"}
0005432192272	BFB0CF	6828 836427	VYACHESLAV MAKSIMOV	{"phone": "+70292349599"}
0005432192273	9ADFC2	7073 057587	ANDREY ZAKHAROV	{"email": "andrey.zakharov.1971@postgrespro.ru", "phone": "+70394276790"}
0005432192274	A23C8D	7315 586837	ROMAN OSIPOV	{"email": "r_osipov_11031972@postgrespro.ru", "phone": "+70983573510"}
0005432192275	28F28B	4446 589374	IRINA TITOVA	{"phone": "+70880434286"}
0005432192276	28F28B	5129 393958	ALEKSEY ILIN	{"phone": "+70985266337"}
0005432192277	5E4796	8706 698731	ANNA GRISHINA	{"email": "grishina_anna16091967@postgrespro.ru", "phone": "+70984258726"}
0005432192278	5E4796	8596 596351	ELENA MOROZOVA	{"email": "morozovae.03071968@postgrespro.ru", "phone": "+70814796254"}
0005432192279	5E4796	5296 132201	MARINA ANISIMOVA	{"phone": "+70263108780"}
0005432192280	E0D186	0656 265637	ANATOLIY ISAEV	{"phone": "+70536180977"}
0005432192281	CF0151	0182 597850	VALENTINA GAVRILOVA	{"email": "vgavrilova-06051983@postgrespro.ru", "phone": "+70614348855"}
0005432192282	3D014D	2309 298166	LIDIYA PAVLOVA	{"email": "lidiya.pavlova_1966@postgrespro.ru", "phone": "+70530693596"}
0005432192283	D95E7A	1749 553824	LYUDMILA MOROZOVA	{"phone": "+70531710816"}
0005432192284	E671D3	0654 532267	OLGA ZAKHAROVA	{"phone": "+70431205060"}
0005432192285	E671D3	1951 044765	ALENA KISELEVA	{"email": "kiseleva.a-1972@postgrespro.ru", "phone": "+70965517824"}
0005432192286	4900EE	6045 585454	STEPAN KOZLOV	{"phone": "+70745282613"}
0005432192287	7AFB42	6138 270651	ANDREY STEPANOV	{"phone": "+70719299278"}
0005432192288	0E8786	0965 971066	ANTONINA AFANASEVA	{"email": "a-afanaseva.17081972@postgrespro.ru", "phone": "+70923393114"}
0005432192289	0E8786	3101 121342	VLADISLAV KOROLEV	{"email": "korolev.vladislav-1973@postgrespro.ru", "phone": "+70556723925"}
0005432192290	B6F70F	6028 423184	VALENTINA FEDOROVA	{"phone": "+70798212574"}
0005432192291	B6F70F	4947 280939	YURIY KULIKOV	{"phone": "+70123901043"}
0005432192292	F3ED2E	8614 362590	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr1958@postgrespro.ru", "phone": "+70120144659"}
0005432192293	F3ED2E	4652 464376	OLGA IVANOVA	{"email": "ivanova.o_15051974@postgrespro.ru", "phone": "+70145203368"}
0005432192294	C4400E	7788 961321	ARTUR SEMENOV	{"email": "artur_semenov071973@postgrespro.ru", "phone": "+70091980407"}
0005432192295	672269	6446 972960	ARKADIY ZHURAVLEV	{"email": "zhuravlev_arkadiy_121977@postgrespro.ru", "phone": "+70501801499"}
0005432192296	2FAC9B	9993 029613	ALEKSANDRA SEMENOVA	{"phone": "+70253597131"}
0005432192297	91008A	8560 110904	ALEKSANDR SERGEEV	{"email": "asergeev-021974@postgrespro.ru", "phone": "+70579358110"}
0005432192298	91008A	3884 662356	PELAGEYA KOVALEVA	{"email": "kovaleva.pelageya.14021977@postgrespro.ru", "phone": "+70865319741"}
0005432192299	5C00E7	6096 068012	MARIYA ANTONOVA	{"phone": "+70094518130"}
0005432192300	F776AA	4121 100670	OLGA KOMAROVA	{"email": "komarova_o_15111959@postgrespro.ru", "phone": "+70972398128"}
0005432192301	3A2763	6659 669431	ANASTASIYA SMIRNOVA	{"email": "smirnova.a.01051982@postgrespro.ru", "phone": "+70504490320"}
0005432192302	6C78FD	0579 347796	YAROSLAV KUZNECOV	{"email": "kuznecov-yaroslav-17041976@postgrespro.ru", "phone": "+70064792495"}
0005432192303	66DB49	1682 977958	MARGARITA STEPANOVA	{"email": "margaritastepanova09091973@postgrespro.ru", "phone": "+70208735385"}
0005432192304	5FD93B	1177 378639	VYACHESLAV ORLOV	{"phone": "+70213286393"}
0005432192305	DBB935	9483 316042	ALEKSEY ILIN	{"phone": "+70271277708"}
0005432192306	D2643F	4782 578693	NATALYA ANTONOVA	{"phone": "+70818850765"}
0005432192307	1E4673	9852 883236	PELAGEYA KARPOVA	{"phone": "+70733231750"}
0005432192308	E2C213	7730 340260	VLADIMIR MEDVEDEV	{"email": "vladimir-medvedev_29031964@postgrespro.ru", "phone": "+70820379538"}
0005432192309	E2C213	5283 105529	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev-1977@postgrespro.ru", "phone": "+70746656082"}
0005432192310	0D1AE9	2551 859093	VLADIMIR KISELEV	{"email": "kiselevvladimir.26061976@postgrespro.ru", "phone": "+70085868268"}
0005432192311	609A61	5181 231043	IRINA PAVLOVA	{"email": "pavlova_irina.111972@postgrespro.ru", "phone": "+70704233964"}
0005432192312	1FBC0B	8778 606364	FAINA VLASOVA	{"phone": "+70351209695"}
0005432192313	1933CA	2498 752894	VASILIY NOVIKOV	{"phone": "+70321262442"}
0005432192314	9AD412	7575 661667	YURIY BORISOV	{"email": "borisovy-29061967@postgrespro.ru", "phone": "+70131847932"}
0005432192315	9AD412	5604 856408	PAVEL MAKSIMOV	{"email": "maksimov_pavel-13081970@postgrespro.ru", "phone": "+70206536893"}
0005432192316	5C4D8A	4263 322721	YURIY FROLOV	{"phone": "+70368060914"}
0005432192317	5C4D8A	9944 689965	VITALIY EGOROV	{"phone": "+70035270418"}
0005432192318	5C4D8A	1961 940588	EVGENIY IVANOV	{"email": "e.ivanov1973@postgrespro.ru", "phone": "+70363907457"}
0005432192319	792A43	7056 283902	NINA OSIPOVA	{"phone": "+70492153435"}
0005432192320	8DC4C4	1659 229984	IGOR ZHURAVLEV	{"email": "igor-zhuravlev.011987@postgrespro.ru", "phone": "+70555151467"}
0005432192321	4AF78F	7811 721291	VIKTORIYA GAVRILOVA	{"phone": "+70245490693"}
0005432192322	35B0ED	7486 494837	DMITRIY FOMIN	{"email": "fomin.dmitriy.1972@postgrespro.ru", "phone": "+70977354646"}
0005432192323	FF56E0	1559 062367	EKATERINA PETROVA	{"phone": "+70518226723"}
0005432192324	1D1D50	0406 038131	VYACHESLAV DENISOV	{"email": "vyacheslav_denisov-17041981@postgrespro.ru", "phone": "+70849637135"}
0005432192325	495821	6979 798569	NINA LAZAREVA	{"email": "lazarevanina-101959@postgrespro.ru", "phone": "+70897662839"}
0005432192326	495821	6113 043003	ELENA CHERNOVA	{"email": "chernova-elena.061982@postgrespro.ru", "phone": "+70099233103"}
0005432192327	B4B1F1	7333 394973	ILYA IVANOV	{"email": "iivanov_09011971@postgrespro.ru", "phone": "+70690897580"}
0005432192328	B4B1F1	3472 434312	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy06011985@postgrespro.ru", "phone": "+70953086383"}
0005432192329	812849	7308 427160	ALBINA KUZMINA	{"email": "albina_kuzmina_1954@postgrespro.ru", "phone": "+70519590459"}
0005432192330	4CD3DE	5843 178313	ANNA NAUMOVA	{"email": "anaumova-121955@postgrespro.ru", "phone": "+70498662973"}
0005432192331	98A50C	9755 773696	YANA DENISOVA	{"phone": "+70978278900"}
0005432192332	AA58CF	7340 561676	NIKOLAY ALEKSEEV	{"phone": "+70372443632"}
0005432192333	AA58CF	1938 401376	YURIY GRIGOREV	{"email": "y_grigorev041971@postgrespro.ru", "phone": "+70009691045"}
0005432192334	B8E31F	4155 360876	LYUDMILA NIKITINA	{"email": "nikitina_l.1976@postgrespro.ru", "phone": "+70798115619"}
0005432192335	94AA45	5525 126624	DMITRIY FROLOV	{"email": "frolov.dmitriy041971@postgrespro.ru", "phone": "+70973932566"}
0005432192336	A60FB8	6823 592453	VLADIMIR TARASOV	{"phone": "+70173232621"}
0005432192337	1E2457	0605 745205	ROMAN BARANOV	{"phone": "+70358143138"}
0005432192338	28F78F	5876 240442	NADEZHDA IVANOVA	{"phone": "+70875756160"}
0005432192339	03C2E3	2488 893417	IVAN KUZNECOV	{"phone": "+70215979951"}
0005432192340	A94339	3459 574174	ANNA BELOVA	{"email": "belova.anna_021977@postgrespro.ru", "phone": "+70518678205"}
0005432192341	AD8CCF	3953 460978	NIKITA AFANASEV	{"email": "n_afanasev.29051964@postgrespro.ru", "phone": "+70638136405"}
0005432192342	EBABDF	7300 787077	MIKHAIL MAKAROV	{"email": "makarov_m-1975@postgrespro.ru", "phone": "+70449676520"}
0005432192343	474DB0	6161 197926	VASILIY EGOROV	{"email": "egorov.v_1969@postgrespro.ru", "phone": "+70809025678"}
0005432192344	493251	1278 027245	ANNA GRISHINA	{"phone": "+70299515962"}
0005432192345	BD4022	9359 429912	TATYANA FOMINA	{"phone": "+70844715775"}
0005432192346	647295	9492 043336	MAKSIM YAKOVLEV	{"email": "yakovlevm.1983@postgrespro.ru", "phone": "+70002051788"}
0005432192347	AE4F3E	5248 509960	SERGEY NOVIKOV	{"email": "s-novikov_1966@postgrespro.ru", "phone": "+70160838829"}
0005432192348	0312AC	0092 077708	VALENTINA IVANOVA	{"phone": "+70436324416"}
0005432192349	1210E8	1844 416050	DENIS FILIPPOV	{"email": "filippovdenis.09011966@postgrespro.ru", "phone": "+70860489244"}
0005432192350	51CDD2	1708 447510	MAKSIM MEDVEDEV	{"email": "medvedevmaksim-1974@postgrespro.ru", "phone": "+70058955921"}
0005432192351	6644CC	9340 714830	EKATERINA MAKAROVA	{"email": "e.makarova_24091974@postgrespro.ru", "phone": "+70533445939"}
0005432192352	201E30	3013 057203	IGOR OSIPOV	{"phone": "+70883718564"}
0005432192353	201E30	1928 869398	IRINA KUZMINA	{"email": "kuzminairina.1956@postgrespro.ru", "phone": "+70988497669"}
0005432192354	201E30	9528 285710	DENIS FROLOV	{"email": "frolov_denis.17101976@postgrespro.ru", "phone": "+70879967170"}
0005432192355	2BC30F	3525 646539	YURIY SOROKIN	{"phone": "+70454748660"}
0005432192356	2BC30F	4817 932493	OLGA DAVYDOVA	{"phone": "+70109058318"}
0005432192357	2BC30F	5419 213397	NAILYA KULIKOVA	{"email": "n-kulikova.071965@postgrespro.ru", "phone": "+70689849379"}
0005432192358	4A2BB8	8019 721130	NADEZHDA IVANOVA	{"phone": "+70235821850"}
0005432192359	8E3A6F	3964 526908	SERGEY ILIN	{"phone": "+70420340873"}
0005432192360	8E3A6F	8938 852843	VALERIY EGOROV	{"email": "egorov_v1977@postgrespro.ru", "phone": "+70617887690"}
0005432192361	001A4A	6395 243402	AIDA MOISEEVA	{"phone": "+70203301025"}
0005432192362	001A4A	5741 579581	VALERIY TARASOV	{"phone": "+70858040649"}
0005432192363	001A4A	8708 899679	VASILIY MOISEEV	{"email": "v_moiseev-1998@postgrespro.ru", "phone": "+70815998484"}
0005432192364	41D8C1	6114 287984	TATYANA VLASOVA	{"phone": "+70761212739"}
0005432192365	E8D005	9156 461408	LYUDMILA FROLOVA	{"email": "lyudmila-frolova1967@postgrespro.ru", "phone": "+70489490699"}
0005432192366	F2ABC4	7056 501869	MARIYA SMIRNOVA	{"phone": "+70216324811"}
0005432192367	B7B1C8	6817 557458	IGOR ZHUKOV	{"phone": "+70836306138"}
0005432192368	6DD170	2627 036603	SERGEY DENISOV	{"email": "denisovsergey.031977@postgrespro.ru", "phone": "+70856720219"}
0005432192369	D05B50	0483 697764	LYUDMILA FROLOVA	{"phone": "+70582297322"}
0005432192370	D05B50	8619 525564	VLADIMIR NAUMOV	{"email": "naumov-v.1961@postgrespro.ru", "phone": "+70093781079"}
0005432192371	FCACDB	0587 586912	SVETLANA KOLESNIKOVA	{"phone": "+70118442979"}
0005432192372	FDA347	2515 298561	SERGEY MAKAROV	{"phone": "+70675076606"}
0005432192373	5D68FA	7055 193620	EGOR POPOV	{"phone": "+70926578411"}
0005432192374	D33018	9273 317564	MARINA FOMINA	{"email": "mfomina-1973@postgrespro.ru", "phone": "+70933925173"}
0005432192375	5728CE	9252 612264	GALINA DANILOVA	{"email": "danilova.galina081971@postgrespro.ru", "phone": "+70412687176"}
0005432192376	5728CE	6090 266583	LYUBOV TARASOVA	{"email": "ltarasova1978@postgrespro.ru", "phone": "+70335321660"}
0005432192377	C6DCCC	1742 237645	LYUBOV PETROVA	{"phone": "+70317747525"}
0005432192378	6EBFD6	0692 483785	ALEKSANDRA MIRONOVA	{"email": "mironova.aleksandra_1984@postgrespro.ru", "phone": "+70462373421"}
0005432192379	6EBFD6	8706 844900	ALEKSEY ROMANOV	{"email": "aleksey_romanov_021966@postgrespro.ru", "phone": "+70755633438"}
0005432192380	4B7C45	4179 692464	KIRILL KUZNECOV	{"email": "kirill-kuznecov_15091976@postgrespro.ru", "phone": "+70092031039"}
0005432192381	4B7C45	8770 672169	LIDIYA KALININA	{"phone": "+70751805082"}
0005432192382	4B7C45	2077 847396	EKATERINA OVCHINNIKOVA	{"phone": "+70913534005"}
0005432192383	4B7C45	8176 446759	EVGENIYA ANTONOVA	{"phone": "+70961562295"}
0005432192384	A1751C	0410 427395	YULIYA EFREMOVA	{"email": "efremovay.01011961@postgrespro.ru", "phone": "+70063371923"}
0005432192385	CDF3E7	3533 400867	EVGENIY KOROLEV	{"phone": "+70906834232"}
0005432192386	CDF3E7	4456 118127	ANASTASIYA GAVRILOVA	{"phone": "+70725998290"}
0005432192387	D86660	4815 300819	EKATERINA SOKOLOVA	{"phone": "+70569637874"}
0005432192388	D86660	6184 776094	ELENA KUZNECOVA	{"phone": "+70428063186"}
0005432192389	633981	2853 187291	LYUBOV ROMANOVA	{"email": "l.romanova031966@postgrespro.ru", "phone": "+70740872255"}
0005432192390	52764C	8391 864863	NINA ILINA	{"phone": "+70607423263"}
0005432192391	8AC941	3493 086844	YULIYA ARKHIPOVA	{"email": "yuliyaarkhipova_19061960@postgrespro.ru", "phone": "+70666573762"}
0005432192392	8AC941	5992 355180	PETR SEMENOV	{"email": "p_semenov_1976@postgrespro.ru", "phone": "+70498983577"}
0005432192393	63502F	5412 410825	VALENTINA MAKSIMOVA	{"email": "v-maksimova.091973@postgrespro.ru", "phone": "+70095765493"}
0005432192394	ED5D58	4099 825429	OLGA ANDREEVA	{"phone": "+70822128033"}
0005432192395	79098A	6736 403587	OLGA ALEKSANDROVA	{"email": "o_aleksandrova21031964@postgrespro.ru", "phone": "+70813819663"}
0005432192396	91FACB	3959 788619	VALERIY NOVIKOV	{"phone": "+70026579298"}
0005432192397	795E6F	4871 030111	MARIYA GAVRILOVA	{"email": "mariya.gavrilova-1976@postgrespro.ru", "phone": "+70799895865"}
0005432192398	795E6F	2465 193339	GENNADIY KUZNECOV	{"phone": "+70582135577"}
0005432192399	795E6F	2019 042138	RAISA TROFIMOVA	{"email": "trofimovaraisa.051955@postgrespro.ru", "phone": "+70738077131"}
0005432192400	803477	2716 850289	IVAN MATVEEV	{"phone": "+70958708311"}
0005432192402	3ACAA4	5686 623279	NIKOLAY SERGEEV	{"phone": "+70750381785"}
0005432192403	E0A1A3	1365 638403	VIKTOR GORBUNOV	{"email": "viktorgorbunov_071974@postgrespro.ru", "phone": "+70557719773"}
0005432192404	E0A1A3	9341 767884	EGOR PETROV	{"email": "egor.petrov-1968@postgrespro.ru", "phone": "+70843824253"}
0005432192405	14760A	6622 901942	RIMA MAKAROVA	{"phone": "+70765596408"}
0005432192406	8E63D7	7119 941962	VARVARA STEPANOVA	{"email": "v_stepanova-1978@postgrespro.ru", "phone": "+70967321775"}
0005432192407	0E3BA1	4885 709044	LYUBOV AKIMOVA	{"email": "akimova-lyubov-1981@postgrespro.ru", "phone": "+70226759535"}
0005432192408	62929D	4678 232266	ANDREY ANDREEV	{"email": "andreev-a1970@postgrespro.ru", "phone": "+70525466328"}
0005432192409	62929D	8623 981466	ELENA MARTYNOVA	{"phone": "+70491531099"}
0005432192410	9BC31C	0786 562058	NATALYA KULIKOVA	{"phone": "+70712316932"}
0005432192411	AFEE96	1453 125798	TAMARA GAVRILOVA	{"email": "tgavrilova.1963@postgrespro.ru", "phone": "+70846062979"}
0005432192412	AFEE96	7376 240795	ZHANNA KONOVALOVA	{"email": "zhanna_konovalova-101969@postgrespro.ru", "phone": "+70906021723"}
0005432192413	DADEC3	9202 058122	VLADIMIR KULIKOV	{"email": "vladimir-kulikov_12121972@postgrespro.ru", "phone": "+70916363666"}
0005432192414	B5C3B2	9482 980587	NIKOLAY TIKHONOV	{"phone": "+70245632176"}
0005432192415	91DE33	3691 871684	ALEKSANDR FILIPPOV	{"email": "filippova_22031965@postgrespro.ru", "phone": "+70273983334"}
0005432194435	A0A331	8393 980442	YURIY NOVIKOV	{"email": "y-novikov.18091970@postgrespro.ru", "phone": "+70850017505"}
0005432194436	2542B5	7539 366929	IGOR OSIPOV	{"email": "osipov-i_08051968@postgrespro.ru", "phone": "+70407482792"}
0005432194437	CCBD95	3850 151331	OLEG TARASOV	{"phone": "+70311917783"}
0005432194438	CCBD95	2924 999954	EKATERINA EGOROVA	{"phone": "+70436737166"}
0005432194439	CCBD95	6977 755086	VLADISLAV VOLKOV	{"email": "vvolkov.07071982@postgrespro.ru", "phone": "+70260761628"}
0005432194440	B59CA1	5687 895748	IGOR ALEKSANDROV	{"phone": "+70074416202"}
0005432194441	261530	3357 046121	ARTEM PETROV	{"email": "petrov-a_1966@postgrespro.ru", "phone": "+70279873495"}
0005432194442	015430	2946 802853	ANASTASIYA IVANOVA	{"phone": "+70723838397"}
0005432194443	015430	8548 425008	GALINA ALEKSEEVA	{"email": "galinaalekseeva.17111974@postgrespro.ru", "phone": "+70544879790"}
0005432194444	0D40B1	9224 282896	ROMAN RODIONOV	{"phone": "+70937634585"}
0005432194445	0D40B1	5367 794806	IREK KUZNECOV	{"email": "kuznecov_irek-061979@postgrespro.ru", "phone": "+70183608802"}
0005432194446	5F04C8	4108 670527	VLADIMIR CHERNOV	{"email": "chernov-v101978@postgrespro.ru", "phone": "+70908392803"}
0005432194447	5F04C8	4846 663467	NATALYA ROMANOVA	{"email": "n.romanova_1969@postgrespro.ru", "phone": "+70763054043"}
0005432194448	79D08A	6980 868950	MIKHAIL MAKAROV	{"email": "makarov-mikhail-20011969@postgrespro.ru", "phone": "+70453518271"}
0005432194449	79D08A	0334 946425	NIKOLAY ANDREEV	{"phone": "+70464189125"}
0005432194450	4A092F	8287 128397	EKATERINA BORISOVA	{"email": "borisova-ekaterina.1978@postgrespro.ru", "phone": "+70142063190"}
0005432194451	4A092F	9203 052827	ELENA KUZNECOVA	{"email": "e-kuznecova-1979@postgrespro.ru", "phone": "+70281419297"}
0005432194452	96BC16	7357 077523	VALERIY ZAYCEV	{"email": "valeriy.zaycev_1982@postgrespro.ru", "phone": "+70245191032"}
0005432194453	126571	4441 877721	ALEKSEY KRASNOV	{"email": "krasnovaleksey-1979@postgrespro.ru", "phone": "+70959884305"}
0005432194454	A4E3B7	8849 297141	NATALYA SEMENOVA	{"email": "semenova.n_1976@postgrespro.ru", "phone": "+70645185438"}
0005432194455	7B44CE	6322 957670	RASIM NIKOLAEV	{"email": "nikolaev_rasim1975@postgrespro.ru", "phone": "+70914565558"}
0005432194456	7B44CE	9210 781320	ALFIYA KULIKOVA	{"phone": "+70896980768"}
0005432194457	7A35F6	8439 783919	VALENTINA EGOROVA	{"email": "v_egorova.101976@postgrespro.ru", "phone": "+70026747694"}
0005432194458	7E581E	1245 963079	ANDREY ALEKSANDROV	{"email": "a_aleksandrov101973@postgrespro.ru", "phone": "+70566817978"}
0005432194459	7E581E	7657 507572	RAIL ORLOV	{"email": "orlovr1978@postgrespro.ru", "phone": "+70660524364"}
0005432194460	571304	2426 166509	VLADIMIR SERGEEV	{"email": "sergeevvladimir1968@postgrespro.ru", "phone": "+70043285977"}
0005432194461	D72CC2	0468 007832	SVETLANA IVANOVA	{"phone": "+70243819357"}
0005432194462	02B326	7308 799527	EKATERINA KUZNECOVA	{"phone": "+70234710565"}
0005432194463	EFDF08	0435 475648	MAKSIM MAKAROV	{"email": "maksimmakarov_1971@postgrespro.ru", "phone": "+70665268865"}
0005432194464	EFDF08	0749 511977	ANATOLIY KUZNECOV	{"email": "kuznecov_a_1972@postgrespro.ru", "phone": "+70241005462"}
0005432194465	C090D1	7060 499063	VASILIY MATVEEV	{"email": "matveev_vasiliy1970@postgrespro.ru", "phone": "+70459380168"}
0005432194466	6C1CDE	2676 593545	VLADIMIR ISAEV	{"email": "isaev-v1972@postgrespro.ru", "phone": "+70510276029"}
0005432194467	6C1CDE	7474 113109	NADEZHDA NIKOLAEVA	{"phone": "+70408881669"}
0005432194468	239ADC	2471 003736	NIKITA CHERNOV	{"email": "chernov.n-19091977@postgrespro.ru", "phone": "+70421109536"}
0005432194469	239ADC	0456 375100	VLADIMIR SOROKIN	{"phone": "+70145947652"}
0005432194470	EBE998	6284 076160	VADIM GERASIMOV	{"email": "vadimgerasimov1978@postgrespro.ru", "phone": "+70966106408"}
0005432194471	276DDD	1646 711384	ANNA TITOVA	{"email": "anna_titova_01021967@postgrespro.ru", "phone": "+70110149959"}
0005432194472	A8B287	9555 789752	PAVEL TIKHONOV	{"phone": "+70162471096"}
0005432194473	6A87AD	8467 556595	INNA CHERNOVA	{"email": "chernova-inna_101972@postgrespro.ru", "phone": "+70190395100"}
0005432194474	AFD165	1080 735139	ANNA MAKAROVA	{"email": "anna_makarova051958@postgrespro.ru", "phone": "+70770585808"}
0005432194475	3EF7F0	3468 531355	VIKTORIYA MATVEEVA	{"phone": "+70684017920"}
0005432194476	182E0C	6245 884261	FARIDA FADEEVA	{"email": "fadeeva-farida_061975@postgrespro.ru", "phone": "+70991396286"}
0005432194477	E7A559	7294 382923	VITALIY ZAYCEV	{"phone": "+70073434084"}
0005432194478	E7A559	7374 169355	ALEKSANDR VOLKOV	{"email": "a-volkov.1969@postgrespro.ru", "phone": "+70083797244"}
0005432194479	7AC469	2315 633808	ALEKSEY IVANOV	{"email": "a-ivanov_1984@postgrespro.ru", "phone": "+70115488045"}
0005432194480	7AC469	4969 042634	MAKSIM BONDARENKO	{"email": "maksim_bondarenko101973@postgrespro.ru", "phone": "+70304477160"}
0005432194481	4FF39E	6213 389079	YULIYA OVCHINNIKOVA	{"email": "ovchinnikova_yuliya011968@postgrespro.ru", "phone": "+70155002807"}
0005432194482	0A73CF	8004 343310	ANDREY KAZAKOV	{"phone": "+70848810156"}
0005432194483	59E8A5	7186 718847	SERGEY TIKHONOV	{"email": "tikhonov-sergey_041970@postgrespro.ru", "phone": "+70557163960"}
0005432194484	59E8A5	9013 525478	OKSANA PETROVA	{"phone": "+70792283521"}
0005432194485	681DE8	9286 452117	TIMUR VOLKOV	{"phone": "+70604719973"}
0005432194486	681DE8	6048 726959	TATYANA FROLOVA	{"phone": "+70127795224"}
0005432194487	7324C1	9311 662661	BORIS MOROZOV	{"email": "borismorozov_05041968@postgrespro.ru", "phone": "+70768962608"}
0005432194488	7324C1	4910 760517	NADEZHDA DAVYDOVA	{"email": "davydova_n_061976@postgrespro.ru", "phone": "+70747071110"}
0005432194489	411BD2	6909 709530	ANNA KOZLOVA	{"email": "a-kozlova18081970@postgrespro.ru", "phone": "+70772784108"}
0005432194490	411BD2	7764 254870	VALERIY MARTYNOV	{"email": "valeriy-martynov_13061967@postgrespro.ru", "phone": "+70558670656"}
0005432194491	9B36ED	8312 133474	ANATOLIY BONDARENKO	{"email": "anatoliybondarenko_1965@postgrespro.ru", "phone": "+70190913192"}
0005432194492	1CFBE3	2792 884841	YULIYA TIKHONOVA	{"email": "tikhonovayuliya-02021964@postgrespro.ru", "phone": "+70109367374"}
0005432194493	752BDA	3742 107967	LARISA MEDVEDEVA	{"email": "l_medvedeva-121981@postgrespro.ru", "phone": "+70274247995"}
0005432194494	ED7B5F	5276 253190	YURIY MIKHAYLOV	{"email": "mikhaylovy30051969@postgrespro.ru", "phone": "+70975707752"}
0005432194495	5DE3BA	6163 435322	ALEKSANDR SAVELEV	{"phone": "+70062422372"}
0005432194496	3AA348	9154 821724	ALEKSEY MOROZOV	{"email": "morozov.aleksey_1991@postgrespro.ru", "phone": "+70250940237"}
0005432194497	3AA348	3531 341853	ANDREY DMITRIEV	{"phone": "+70563925758"}
0005432194498	3AA348	8518 684907	ANTON VASILEV	{"email": "vasilevanton_1967@postgrespro.ru", "phone": "+70953357708"}
0005432194499	E406C8	7627 278978	SERGEY NAUMOV	{"email": "s.naumov_1979@postgrespro.ru", "phone": "+70614202839"}
0005432194500	E406C8	9887 611499	NADEZHDA GERASIMOVA	{"email": "nadezhda-gerasimova-081978@postgrespro.ru", "phone": "+70552775220"}
0005432194501	7565E7	2047 995191	ALEKSEY MOISEEV	{"phone": "+70157358593"}
0005432194502	A6D7FF	1927 540755	VLADIMIR SEMENOV	{"email": "semenov-vladimir1987@postgrespro.ru", "phone": "+70239850035"}
0005432194503	0431F6	1630 299558	YULIYA VASILEVA	{"phone": "+70427027345"}
0005432194504	0431F6	6269 186463	ANASTASIYA ILINA	{"email": "ailina-26051977@postgrespro.ru", "phone": "+70301303272"}
0005432194505	4B3A29	9605 120269	LYUDMILA KOROLEVA	{"phone": "+70954826743"}
0005432194506	4B3A29	6280 745271	RUSTEM KISELEV	{"phone": "+70291834018"}
0005432194507	C05AC1	3531 060186	NIKOLAY SEMENOV	{"email": "semenov_n.111974@postgrespro.ru", "phone": "+70095424897"}
0005432194508	EF836F	5689 022895	SERGEY SERGEEV	{"phone": "+70174622502"}
0005432194509	B9B48F	4383 815857	IVAN SCHERBAKOV	{"email": "scherbakovi-041975@postgrespro.ru", "phone": "+70141675952"}
0005432194510	766C7A	4662 667542	SERGEY ANDREEV	{"email": "s-andreev.04081975@postgrespro.ru", "phone": "+70038797747"}
0005432194511	D83EA2	3186 786327	DENIS SOROKIN	{"phone": "+70966928221"}
0005432194512	D83EA2	3502 160052	RAISA DAVYDOVA	{"email": "r_davydova-091976@postgrespro.ru", "phone": "+70427287305"}
0005432194513	B7C73C	2894 440111	POLINA POPOVA	{"phone": "+70643335223"}
0005432194514	B7C73C	3415 633510	OLESYA MARTYNOVA	{"phone": "+70173415698"}
0005432194515	891736	8430 471308	KSENIYA LEBEDEVA	{"email": "klebedeva_081954@postgrespro.ru", "phone": "+70034078856"}
0005432194516	D0DA40	2540 096350	OLGA PAVLOVA	{"phone": "+70816433992"}
0005432194517	D0DA40	9648 913315	NATALYA PETROVA	{"email": "petrova-natalya_1975@postgrespro.ru", "phone": "+70646104051"}
0005432194518	6011A5	7070 293455	LARISA ORLOVA	{"phone": "+70067950209"}
0005432194519	B5C328	4799 139807	NATALYA MOISEEVA	{"email": "moiseeva_natalya-111968@postgrespro.ru", "phone": "+70042554831"}
0005432194520	2D8093	0871 240060	DMITRIY SERGEEV	{"phone": "+70062344058"}
0005432194521	3BF95A	7084 198464	TAISIYA SOKOLOVA	{"phone": "+70906483566"}
0005432194522	1E1A39	1622 405159	ANATOLIY TARASOV	{"email": "anatoliy_tarasov_121977@postgrespro.ru", "phone": "+70757818549"}
0005432194523	1E1A39	7853 714325	VLADISLAV MOROZOV	{"phone": "+70114401052"}
0005432194524	442609	7302 172005	ALEKSANDR FILIPPOV	{"phone": "+70786143127"}
0005432194525	A3FB02	6905 093264	NIKOLAY FOMIN	{"email": "nikolayfomin_10111973@postgrespro.ru", "phone": "+70613164055"}
0005432194526	0E54FE	3202 316870	LYUBOV PETROVA	{"phone": "+70767774467"}
0005432194527	99E687	6129 434610	YULIYA MEDVEDEVA	{"phone": "+70658990784"}
0005432194528	5F1671	9488 268754	VIKTOR SHEVCHENKO	{"email": "shevchenko.v-1968@postgrespro.ru", "phone": "+70407526464"}
0005432194529	9F4338	5687 164542	EVGENIY POPOV	{"phone": "+70268211850"}
0005432194530	9F4338	1506 249347	ALEKSEY GERASIMOV	{"phone": "+70984828249"}
0005432194531	9F4338	1954 431065	NADEZHDA RODIONOVA	{"email": "rodionova-nadezhda_111958@postgrespro.ru", "phone": "+70205481810"}
0005432194532	64F074	7488 557361	NINA TITOVA	{"email": "titovanina.17061977@postgrespro.ru", "phone": "+70350231070"}
0005432194533	7A5BFC	5894 793084	VALENTINA VOLKOVA	{"phone": "+70487492444"}
0005432194534	B2DBD9	5577 423645	DMITRIY ZHUKOV	{"phone": "+70409124951"}
0005432194535	B2DBD9	9394 321218	ANDREY OSIPOV	{"email": "a-osipov_17011968@postgrespro.ru", "phone": "+70538376289"}
0005432194536	1C5A22	4797 951819	MARGARITA POTAPOVA	{"phone": "+70324221865"}
0005432194537	93DEA9	9529 041001	KONSTANTIN KOZLOV	{"email": "konstantinkozlov-1962@postgrespro.ru", "phone": "+70217261037"}
0005432194538	DE4AFB	2327 790435	ELVIRA POPOVA	{"phone": "+70735750293"}
0005432194539	DE4AFB	4276 085403	OLGA MALYSHEVA	{"phone": "+70134116819"}
0005432194540	29EDE7	9164 742007	NATALIYA FOMINA	{"phone": "+70595180677"}
0005432194541	F7866C	6916 040524	ARTEM BONDARENKO	{"email": "bondarenko.artem04051980@postgrespro.ru", "phone": "+70809835700"}
0005432194542	F7866C	9987 460798	ANATOLIY MOROZOV	{"phone": "+70175995178"}
0005432194543	EBF724	8539 986790	DARYA SEMENOVA	{"email": "semenova.darya.06031978@postgrespro.ru", "phone": "+70090692968"}
0005432194544	56A48A	3210 818547	IVAN KUZNECOV	{"email": "kuznecovi-1978@postgrespro.ru", "phone": "+70120501492"}
0005432194545	9ADCBE	3641 834276	EKATERINA GUSEVA	{"phone": "+70037998746"}
0005432194546	9ADCBE	6899 368821	KIRILL SERGEEV	{"phone": "+70310671140"}
0005432194547	8ED5D8	0287 949588	MARINA VLASOVA	{"phone": "+70984838085"}
0005432194548	F57296	8765 282279	TATYANA LOGINOVA	{"phone": "+70183262816"}
0005432194549	838443	6584 672016	NADEZHDA SOROKINA	{"phone": "+70987539523"}
0005432194550	838443	2947 889178	TARAS TIKHONOV	{"phone": "+70990337747"}
0005432194551	838443	7386 243223	OLEG BELOV	{"email": "o_belov1975@postgrespro.ru", "phone": "+70892160448"}
0005432194552	91435A	8444 997106	ARINA MIRONOVA	{"email": "mironovaarina-09051975@postgrespro.ru", "phone": "+70497934559"}
0005432194553	91435A	3373 344238	TATYANA FILATOVA	{"phone": "+70608895119"}
0005432194554	101D9B	3214 252241	NADEZHDA RODIONOVA	{"phone": "+70767375512"}
0005432194555	A7F34B	7707 089056	ELENA VLASOVA	{"phone": "+70217457013"}
0005432194556	7A0F88	1880 201331	IRINA ZAKHAROVA	{"email": "zakharova-irina_011968@postgrespro.ru", "phone": "+70060110514"}
0005432194557	5246A8	1577 608944	TATYANA ARKHIPOVA	{"email": "arkhipovatatyana17031971@postgrespro.ru", "phone": "+70380906611"}
0005432194558	0941CE	4520 180909	MARGARITA MAKSIMOVA	{"email": "maksimovam041958@postgrespro.ru", "phone": "+70991776877"}
0005432194559	EB18EC	6896 978922	ALEKSANDR NIKITIN	{"phone": "+70823254044"}
0005432194560	EB18EC	4050 815607	MIKHAIL FROLOV	{"email": "frolovmikhail.051971@postgrespro.ru", "phone": "+70663735470"}
0005432194561	B892E2	4527 606741	IVAN ZAKHAROV	{"email": "ivan-zakharov101955@postgrespro.ru", "phone": "+70841955071"}
0005432194562	5B5DDB	6354 734826	YURIY PAVLOV	{"email": "yuriy-pavlov1983@postgrespro.ru", "phone": "+70258725861"}
0005432194563	29547A	7816 176109	ALEKSEY MATVEEV	{"email": "a.matveev-04081967@postgrespro.ru", "phone": "+70031592468"}
0005432194564	29547A	7864 644604	ALEKSANDRA POPOVA	{"phone": "+70005182312"}
0005432194565	36F374	8499 925863	VIKTOR SIDOROV	{"email": "sidorov-v_1973@postgrespro.ru", "phone": "+70083988354"}
0005432194566	EA9D3F	0142 599545	FEDOR KUDRYASHOV	{"email": "f_kudryashov1979@postgrespro.ru", "phone": "+70089925513"}
0005432194567	3CC5D0	1437 473912	NIKITA BONDARENKO	{"email": "bondarenko-n-1972@postgrespro.ru", "phone": "+70503099790"}
0005432194568	3CC5D0	6698 229268	VERA NIKITINA	{"email": "nikitina_v-30081974@postgrespro.ru", "phone": "+70213746290"}
0005432194569	23FE33	0532 167152	ALEKSANDR NIKOLAEV	{"phone": "+70024205025"}
0005432194570	23FE33	6821 113016	NIKOLAY BARANOV	{"phone": "+70901560350"}
0005432194571	DC6E32	4454 624931	ZAKHAR NOVIKOV	{"phone": "+70794780757"}
0005432194572	DC6E32	6875 851847	VLADISLAV MATVEEV	{"phone": "+70172932272"}
0005432194573	65EA01	2812 447483	SVETLANA FILIPPOVA	{"email": "filippova.s.1972@postgrespro.ru", "phone": "+70410316708"}
0005432194574	65EA01	8046 924939	BORIS SIDOROV	{"email": "b-sidorov30111965@postgrespro.ru", "phone": "+70371093619"}
0005432194575	8208B7	8797 585600	IVAN DENISOV	{"email": "denisov_i.091975@postgrespro.ru", "phone": "+70996969688"}
0005432194576	9AE731	1317 230509	NIKOLAY GERASIMOV	{"email": "nikolaygerasimov-1969@postgrespro.ru", "phone": "+70944625165"}
0005432194577	9AE731	2524 090341	OLEG NOVIKOV	{"email": "oleg_novikov_05021978@postgrespro.ru", "phone": "+70213392933"}
0005432194578	4EC15D	2918 212983	OLGA ARKHIPOVA	{"phone": "+70760040653"}
0005432194579	08E7EE	0496 111070	OLGA BORISOVA	{"phone": "+70556432684"}
0005432194580	2F4BE7	9017 677382	IGOR DMITRIEV	{"phone": "+70838587539"}
0005432194581	CC5630	2192 608093	OLGA LEBEDEVA	{"email": "o_lebedeva1980@postgrespro.ru", "phone": "+70316207180"}
0005432194582	CC5630	8998 015176	ELENA BELOVA	{"email": "belova_elena_071977@postgrespro.ru", "phone": "+70073087479"}
0005432194583	F505FE	2166 309590	SERGEY MIKHAYLOV	{"phone": "+70091915093"}
0005432194584	69EF28	0032 594672	GRIGORIY BARANOV	{"phone": "+70052995956"}
0005432194585	69EF28	9806 773221	TATYANA KOZLOVA	{"phone": "+70244160368"}
0005432194586	1B309E	5862 811881	DANIIL ALEKSEEV	{"phone": "+70049026685"}
0005432194587	1B309E	0980 163787	ELENA ANTONOVA	{"email": "elenaantonova_1963@postgrespro.ru", "phone": "+70798865109"}
0005432194588	A501DA	4022 950941	ANDREY BARANOV	{"email": "abaranov101972@postgrespro.ru", "phone": "+70214971258"}
0005432194589	A501DA	0937 857593	ANASTASIYA MOISEEVA	{"phone": "+70752008067"}
0005432194590	2D1EEC	1892 268135	IVAN ZAKHAROV	{"email": "zakharov-i_1974@postgrespro.ru", "phone": "+70709747897"}
0005432194591	109BB7	4610 498092	NATALIYA KUDRYASHOVA	{"phone": "+70240745707"}
0005432194592	3F3FF6	5653 961754	VLADIMIR BONDARENKO	{"email": "bondarenkov.091968@postgrespro.ru", "phone": "+70040543918"}
0005432194593	9F1A6E	1434 276341	ARINA BELOVA	{"email": "a.belova-16081975@postgrespro.ru", "phone": "+70847302402"}
0005432194594	11A96C	2262 954626	KLAVDIYA BOGDANOVA	{"phone": "+70381781350"}
0005432194595	114186	7896 155246	ANTON KUZNECOV	{"phone": "+70741759886"}
0005432194596	971537	7955 834918	YURIY GUSEV	{"phone": "+70867444442"}
0005432194597	971537	5911 293875	DANILA ANTONOV	{"phone": "+70064749951"}
0005432194598	1EA241	3369 502041	EVGENIY KOROLEV	{"email": "e-korolev_081961@postgrespro.ru", "phone": "+70712778159"}
0005432194599	8E0EEA	5512 412655	EKATERINA ZHUKOVA	{"email": "ezhukova-01031971@postgrespro.ru", "phone": "+70513188444"}
0005432194600	2E0405	1014 272148	LEONID ZAKHAROV	{"email": "zakharov-l-1959@postgrespro.ru", "phone": "+70938006103"}
0005432194601	B8B8A9	5059 675901	MIKHAIL FOMIN	{"email": "m.fomin_31031970@postgrespro.ru", "phone": "+70129595751"}
0005432194602	3C4959	9882 407030	ANASTASIYA MARTYNOVA	{"email": "martynovaanastasiya021977@postgrespro.ru", "phone": "+70303360459"}
0005432194603	3C4959	2300 283259	VLADIMIR ABRAMOV	{"phone": "+70778683268"}
0005432194604	7A0425	0833 861899	NINA IVANOVA	{"phone": "+70370814150"}
0005432194605	EEC2C1	5160 892375	DENIS ROMANOV	{"email": "romanov_denis.09121974@postgrespro.ru", "phone": "+70425501450"}
0005432194606	82DAF6	2707 120827	VERA EFIMOVA	{"phone": "+70938967723"}
0005432194607	82DAF6	5301 733550	MARINA KOROLEVA	{"email": "marina.koroleva1964@postgrespro.ru", "phone": "+70916091743"}
0005432194608	82DAF6	5378 933998	LYUBOV SOLOVEVA	{"phone": "+70857487510"}
0005432194609	A571DA	7977 669443	VLADIMIR BELOV	{"phone": "+70302190686"}
0005432194610	A571DA	9249 080355	VASILIY KRASNOV	{"phone": "+70026939031"}
0005432194611	B18E33	8262 703485	EKATERINA MAKAROVA	{"email": "ekaterinamakarova-1971@postgrespro.ru", "phone": "+70010386238"}
0005432194612	B18E33	9705 989597	GALINA ROMANOVA	{"email": "gromanova_071972@postgrespro.ru", "phone": "+70684805293"}
0005432194613	8B7226	5401 640242	VLADIMIR SOROKIN	{"email": "sorokin.vladimir1971@postgrespro.ru", "phone": "+70817896362"}
0005432194614	71A531	8442 116039	VERA KOROLEVA	{"email": "koroleva-v_031973@postgrespro.ru", "phone": "+70149899786"}
0005432194615	9E071E	1566 497404	VASILISA YAKOVLEVA	{"email": "v-yakovleva_30091973@postgrespro.ru", "phone": "+70005660544"}
0005432194616	50232C	7015 593153	ALEKSANDR MIKHAYLOV	{"phone": "+70618110865"}
0005432194617	85937E	9704 763232	RAMZIYA ZHUKOVA	{"email": "r-zhukova_1990@postgrespro.ru", "phone": "+70545301534"}
0005432194618	2B81B7	9012 707499	EVGENIY BELOV	{"phone": "+70081566814"}
0005432194619	2B81B7	4015 203668	ROMAN POPOV	{"email": "r_popov1979@postgrespro.ru", "phone": "+70096704282"}
0005432194620	95305C	2416 312871	ELENA ANDREEVA	{"phone": "+70545860444"}
0005432194621	95305C	4253 354414	MARIYA ZOTOVA	{"phone": "+70410909185"}
0005432194622	EF82E5	4087 832237	VLADIMIR BORISOV	{"phone": "+70624106928"}
0005432194623	EF82E5	0680 204839	TATYANA SMIRNOVA	{"email": "smirnovat_041978@postgrespro.ru", "phone": "+70061893471"}
0005432194624	217AD0	0751 384637	OLGA ABRAMOVA	{"email": "abramova_o1952@postgrespro.ru", "phone": "+70728162241"}
0005432194625	240BD0	8509 747907	MAKSIM BORISOV	{"phone": "+70674133925"}
0005432194626	240BD0	7761 315704	OKSANA VOLKOVA	{"phone": "+70048267590"}
0005432194627	08F6F3	2218 225977	ROMAN YAKOVLEV	{"email": "r-yakovlev-011979@postgrespro.ru", "phone": "+70956710005"}
0005432194628	AB0EF0	6344 243422	EKATERINA SOROKINA	{"phone": "+70412864299"}
0005432194629	AB0EF0	2363 583880	ANASTASIYA ERMAKOVA	{"email": "aermakova.1975@postgrespro.ru", "phone": "+70646238122"}
0005432194630	AB0EF0	7684 075371	EKATERINA KOROLEVA	{"email": "e-koroleva_1966@postgrespro.ru", "phone": "+70780874196"}
0005432194631	B2ED65	3170 135271	ALEKSEY ANDREEV	{"phone": "+70419335381"}
0005432194632	B2ED65	8089 358438	VLADIMIR KULIKOV	{"phone": "+70000415970"}
0005432194633	B2ED65	0227 045276	TAISIYA KOROLEVA	{"email": "koroleva.t20041965@postgrespro.ru", "phone": "+70954823094"}
0005432194634	685C4D	5833 659615	EGOR ROMANOV	{"phone": "+70614396524"}
0005432194635	685C4D	2950 794279	VALENTINA MOISEEVA	{"email": "moiseevavalentina_09061967@postgrespro.ru", "phone": "+70430537047"}
0005432194636	E99979	0954 067779	ALEKSEY SIDOROV	{"email": "alekseysidorov-011971@postgrespro.ru", "phone": "+70401340915"}
0005432194637	E99979	3857 005232	LYUBOV ALEKSEEVA	{"phone": "+70183550052"}
0005432195655	69CFF8	0667 457934	SVETLANA GORBUNOVA	{"email": "svetlana-gorbunova_1978@postgrespro.ru", "phone": "+70227807543"}
0005432195656	6EDB5A	0340 322530	DANIL VLASOV	{"email": "vlasov.danil_111979@postgrespro.ru", "phone": "+70875037127"}
0005432195657	6EDB5A	5486 628925	ALEKSANDR ORLOV	{"email": "aleksandr.orlov.14101976@postgrespro.ru", "phone": "+70610236212"}
0005432195658	AE56B9	7370 633657	GALINA ZHURAVLEVA	{"email": "g-zhuravleva_061980@postgrespro.ru", "phone": "+70595043557"}
0005432195659	AE56B9	4288 848733	YULIYA TIKHONOVA	{"phone": "+70309920231"}
0005432195660	651076	7312 166047	ARKADIY NOVIKOV	{"email": "arkadiy.novikov-121976@postgrespro.ru", "phone": "+70691064899"}
0005432195661	DCEB98	3571 955834	SVETLANA IVANOVA	{"phone": "+70559264764"}
0005432195662	D5FE8D	6738 736406	TATYANA MIKHAYLOVA	{"phone": "+70185002247"}
0005432195663	2F5A58	1341 529880	ANNA KRASNOVA	{"email": "krasnova_anna-1978@postgrespro.ru", "phone": "+70137558458"}
0005432195664	059A81	3140 847053	DMITRIY KUZNECOV	{"email": "kuznecov-d.09071968@postgrespro.ru", "phone": "+70779626619"}
0005432195665	3CA8CC	6570 502587	NIKOLAY ZHURAVLEV	{"email": "zhuravlev.nikolay_111964@postgrespro.ru", "phone": "+70678051315"}
0005432195666	3CA8CC	3414 539972	MIKHAIL SOKOLOV	{"email": "mikhail_sokolov051981@postgrespro.ru", "phone": "+70607657977"}
0005432195667	FBEADB	8615 385600	NIKOLAY SCHERBAKOV	{"email": "n.scherbakov1975@postgrespro.ru", "phone": "+70723597982"}
0005432195668	2E3971	4598 995569	OLEG POPOV	{"phone": "+70276801505"}
0005432195669	B44760	7789 644668	ANZHELA ANISIMOVA	{"email": "anisimova-anzhela_08061969@postgrespro.ru", "phone": "+70586390203"}
0005432195670	B44760	6190 597571	OLGA MATVEEVA	{"email": "omatveeva_07051971@postgrespro.ru", "phone": "+70086633638"}
0005432195671	624FF9	1081 090084	TATYANA DMITRIEVA	{"phone": "+70315294843"}
0005432195672	519114	8681 203112	VITALIY GRIGOREV	{"phone": "+70179263282"}
0005432195673	BEFF28	7616 093031	NATALYA MAKAROVA	{"email": "nmakarova.21011962@postgrespro.ru", "phone": "+70413323971"}
0005432195674	BE1B30	4727 156466	MARINA RODIONOVA	{"phone": "+70478154658"}
0005432195675	BE1B30	8240 124873	ANDREY ZAYCEV	{"email": "andrey_zaycev.22121973@postgrespro.ru", "phone": "+70717452385"}
0005432195676	100BF0	1009 534549	TATYANA KUZNECOVA	{"phone": "+70231964671"}
0005432195677	100BF0	4973 366741	NATALYA KOLESNIKOVA	{"phone": "+70395201549"}
0005432195678	B3D60A	4483 145531	VLADIMIR GAVRILOV	{"phone": "+70043721481"}
0005432195679	AAE2CB	5384 610003	GALINA LAZAREVA	{"email": "lazareva-g-12071971@postgrespro.ru", "phone": "+70591458169"}
0005432195680	FB2938	1780 727039	MARINA SEMENOVA	{"email": "msemenova-061960@postgrespro.ru", "phone": "+70155508636"}
0005432195681	FB2938	0409 738359	LYUDMILA MAKAROVA	{"phone": "+70191626988"}
0005432195682	FE4CE2	9375 129622	IVAN IVANOV	{"email": "ivanov-i1960@postgrespro.ru", "phone": "+70826923798"}
0005432195683	FE4CE2	6091 396213	SVETLANA YUDINA	{"phone": "+70507045984"}
0005432195684	222E15	4077 707742	EVGENIY IVANOV	{"phone": "+70730943812"}
0005432195685	222E15	6027 647958	MARINA FROLOVA	{"phone": "+70303546119"}
0005432195686	42659E	5764 197891	LYUDMILA SEMENOVA	{"phone": "+70764467303"}
0005432195687	DD6C8B	1825 817128	EVGENIY VLASOV	{"email": "e.vlasov_05091989@postgrespro.ru", "phone": "+70681798702"}
0005432195688	5B50FB	3943 291985	YULIYA PAVLOVA	{"email": "pavlovay18121971@postgrespro.ru", "phone": "+70487467771"}
0005432195689	281798	4718 521590	NINA ORLOVA	{"email": "orlova-n30101967@postgrespro.ru", "phone": "+70331417401"}
0005432195690	281798	7110 064158	VLADIMIR ANTONOV	{"email": "antonov_v_31081969@postgrespro.ru", "phone": "+70551782573"}
0005432195691	281798	6344 209356	TATYANA POTAPOVA	{"email": "potapova-t061972@postgrespro.ru", "phone": "+70254714053"}
0005432195692	917F8A	4878 409191	IRINA MATVEEVA	{"email": "irina_matveeva_1959@postgrespro.ru", "phone": "+70692122159"}
0005432195693	63A5A5	6355 078821	NATALYA KOLESNIKOVA	{"email": "n-kolesnikova-04111968@postgrespro.ru", "phone": "+70440536088"}
0005432195694	BDC4A2	2762 672495	DMITRIY SCHERBAKOV	{"phone": "+70182950558"}
0005432195695	BDC4A2	8015 582111	DMITRIY FROLOV	{"phone": "+70252928986"}
0005432195696	31DF6B	7007 717611	SERGEY TARASOV	{"email": "s.tarasov1968@postgrespro.ru", "phone": "+70302100451"}
0005432195697	C274AE	2404 501943	EGOR IVANOV	{"email": "ivanov_e.051973@postgrespro.ru", "phone": "+70207587961"}
0005432195698	E2A8C1	0251 243900	ELENA NIKOLAEVA	{"phone": "+70541828965"}
0005432195699	B18702	4440 421039	VALENTINA AFANASEVA	{"email": "v-afanaseva_1973@postgrespro.ru", "phone": "+70433505670"}
0005432195700	3D29AB	2906 102658	ANASTASIYA KAZAKOVA	{"phone": "+70285672939"}
0005432195701	A68036	6179 030111	YULIYA SOLOVEVA	{"phone": "+70890562366"}
0005432195702	A68036	3500 027953	ALEKSEY MIKHAYLOV	{"phone": "+70547680184"}
0005432195703	A68036	7513 512390	STEPAN STEPANOV	{"email": "stepanovstepan-1972@postgrespro.ru", "phone": "+70403469201"}
0005432195704	E6A464	0591 136330	TIMOFEY SMIRNOV	{"email": "smirnov_t.14101976@postgrespro.ru", "phone": "+70251939517"}
0005432195705	43FC7D	0384 469341	ELENA ROMANOVA	{"phone": "+70713325544"}
0005432195706	6F6093	2007 267058	TIMUR MELNIKOV	{"email": "melnikov_t-071969@postgrespro.ru", "phone": "+70473043506"}
0005432195707	6F6093	2122 114956	OLESYA CHERNOVA	{"email": "olesyachernova_1980@postgrespro.ru", "phone": "+70042102209"}
0005432195708	09F6F4	7714 510498	RUSLAN SOROKIN	{"phone": "+70153172192"}
0005432195709	C91401	6159 285948	TATYANA ANTONOVA	{"email": "t-antonova-051968@postgrespro.ru", "phone": "+70702874518"}
0005432195710	53429B	7887 999960	MARIYA ANDREEVA	{"phone": "+70142340832"}
0005432195711	53429B	7254 988940	MARAT SMIRNOV	{"email": "smirnovm111966@postgrespro.ru", "phone": "+70863569944"}
0005432195712	4C60DF	0767 228084	YULIYA FEDOROVA	{"phone": "+70886566029"}
0005432195713	4C60DF	5323 492288	GALINA KONOVALOVA	{"email": "g.konovalova.081963@postgrespro.ru", "phone": "+70829173811"}
0005432195714	576330	5431 303055	YAN ISAEV	{"phone": "+70665060835"}
0005432195715	576330	8395 364808	MIKHAIL KISELEV	{"email": "m.kiselev_1977@postgrespro.ru", "phone": "+70999136375"}
0005432195716	6F5401	9635 177995	ELENA FROLOVA	{"email": "frolovae_1979@postgrespro.ru", "phone": "+70189657353"}
0005432195717	6F5401	8603 965469	VALENTINA ANTONOVA	{"phone": "+70225823811"}
0005432195718	FF2F05	7051 879296	OLGA VOLKOVA	{"email": "ovolkova.1968@postgrespro.ru", "phone": "+70158825991"}
0005432195719	D88655	5463 835970	VITALIY SOLOVEV	{"phone": "+70527612431"}
0005432195720	D88655	2246 503876	ELENA ERMAKOVA	{"email": "e_ermakova-101971@postgrespro.ru", "phone": "+70426597321"}
0005432195721	75F47E	1974 004161	SVETLANA LOGINOVA	{"email": "svetlanaloginova-091972@postgrespro.ru", "phone": "+70357888967"}
0005432195722	DDF4EE	3040 906259	MIKHAIL EGOROV	{"phone": "+70396791188"}
0005432195723	DDF4EE	4699 813948	EKATERINA ANDREEVA	{"phone": "+70778845631"}
0005432195724	DDF4EE	0373 133502	TAMARA SCHERBAKOVA	{"email": "scherbakova.t_10051969@postgrespro.ru", "phone": "+70770651828"}
0005432195725	EA81DD	1972 768770	SERGEY PETROV	{"phone": "+70377953102"}
0005432195726	EA81DD	9742 618272	NADEZHDA ROMANOVA	{"email": "nadezhda_romanova.041971@postgrespro.ru", "phone": "+70366676089"}
0005432195727	E82DDA	4791 995189	POLINA MIKHAYLOVA	{"phone": "+70108378361"}
0005432195728	E82DDA	5906 880154	ANDREY KOROLEV	{"phone": "+70527550417"}
0005432195729	E82DDA	5211 856512	DENIS MAKAROV	{"email": "denis.makarov-08041972@postgrespro.ru", "phone": "+70282971576"}
0005432195730	D628DB	4498 167410	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov_081980@postgrespro.ru", "phone": "+70182107739"}
0005432195731	80050A	0353 205936	ANDREY ANDREEV	{"phone": "+70688463327"}
0005432195732	80050A	6697 794496	EVGENIY OSIPOV	{"email": "e-osipov.04061969@postgrespro.ru", "phone": "+70829918529"}
0005432195733	13060A	9145 585134	IRINA KARPOVA	{"phone": "+70733991636"}
0005432195734	B33FF5	8024 686146	LYUBOV IVANOVA	{"email": "ivanoval101963@postgrespro.ru", "phone": "+70697761871"}
0005432195735	B7E2A7	9717 312719	ALEKSEY SERGEEV	{"phone": "+70139138849"}
0005432195736	85F205	9246 568144	RUSLAN FROLOV	{"phone": "+70402365131"}
0005432195737	85F205	5629 200365	SVETLANA KUZNECOVA	{"email": "s_kuznecova.091976@postgrespro.ru", "phone": "+70823027273"}
0005432195738	3E4B3C	4917 146558	KIRILL DENISOV	{"email": "denisov.kirill-13111970@postgrespro.ru", "phone": "+70173361376"}
0005432195739	3E4B3C	9649 897162	IRINA STEPANOVA	{"phone": "+70335025977"}
0005432195740	054B62	3324 935024	MIKHAIL GERASIMOV	{"phone": "+70336083355"}
0005432195741	A85420	8092 219976	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakova.aleksandra.031971@postgrespro.ru", "phone": "+70533928855"}
0005432195742	5AF91E	7629 048110	YAKOV NOVIKOV	{"phone": "+70398733567"}
0005432195743	D6C416	3374 682162	IRINA OVCHINNIKOVA	{"phone": "+70427492152"}
0005432195744	D6C416	7420 203516	VLADISLAV YAKOVLEV	{"email": "yakovlev-v_09091982@postgrespro.ru", "phone": "+70015786649"}
0005432195745	BF6705	9751 043887	OLGA NIKITINA	{"email": "olga.nikitina-1971@postgrespro.ru", "phone": "+70727921032"}
0005432195746	303503	8709 811457	ALEKSANDR MAKSIMOV	{"phone": "+70060067537"}
0005432195747	1ECA87	8570 733678	EVGENIYA NAUMOVA	{"email": "naumova_e091987@postgrespro.ru", "phone": "+70397331559"}
0005432195748	1ECA87	0569 772461	MATVEY KUZNECOV	{"email": "kuznecov_matvey021976@postgrespro.ru", "phone": "+70125557904"}
0005432195749	1D4D27	6545 866413	SERGEY KUZNECOV	{"email": "kuznecov-s-07091956@postgrespro.ru", "phone": "+70002663291"}
0005432195750	1D4D27	8306 663180	ANATOLIY SCHERBAKOV	{"phone": "+70114586614"}
0005432195751	70DC32	8541 683909	MARINA IVANOVA	{"phone": "+70761850354"}
0005432195752	A5C631	2340 364627	LILIYA SOROKINA	{"email": "liliya.sorokina_081973@postgrespro.ru", "phone": "+70455776304"}
0005432195753	0AA770	2848 521777	MAKSIM SCHERBAKOV	{"phone": "+70490283271"}
0005432195754	BD9329	3066 794278	EGOR IVANOV	{"phone": "+70732427981"}
0005432195755	BD9329	4434 943790	KIRILL FEDOROV	{"phone": "+70478612902"}
0005432195756	BD9329	8531 905120	MAKSIM ZAKHAROV	{"phone": "+70628500772"}
0005432195757	A6488B	5385 930971	VLADIMIR MAKSIMOV	{"email": "vmaksimov.121969@postgrespro.ru", "phone": "+70624799209"}
0005432199230	255554	0275 058545	LIDIYA BOGDANOVA	{"phone": "+70479873119"}
0005432199123	0B1A17	6001 397097	VASILIY MARTYNOV	{"phone": "+70642719747"}
0005432199124	E31113	0467 994407	VASILIY OSIPOV	{"email": "vasiliy_osipov-1978@postgrespro.ru", "phone": "+70489314360"}
0005432199125	B713F2	4527 358094	IRINA ILINA	{"email": "ilina-irina_1967@postgrespro.ru", "phone": "+70437896338"}
0005432199126	B713F2	7705 875663	NADEZHDA ZAKHAROVA	{"phone": "+70829203233"}
0005432199127	48EF69	6200 509385	YURIY KISELEV	{"email": "kiselev-y-021973@postgrespro.ru", "phone": "+70069714008"}
0005432199128	569745	6411 121645	NATALYA ARKHIPOVA	{"email": "arkhipovanatalya_10041980@postgrespro.ru", "phone": "+70704007890"}
0005432199129	4CD633	1377 844504	ELIZAVETA KOLESNIKOVA	{"email": "kolesnikova-elizaveta.27061976@postgrespro.ru", "phone": "+70222418118"}
0005432199130	DB1D30	9203 144291	LIDIYA YAKOVLEVA	{"email": "lyakovleva1967@postgrespro.ru", "phone": "+70500135462"}
0005432199131	DB1D30	5874 854448	ALEKSANDR TIKHONOV	{"phone": "+70711466259"}
0005432199132	DB1D30	3563 074177	MAKSIM MOISEEV	{"email": "moiseev_m.031962@postgrespro.ru", "phone": "+70557901265"}
0005432199133	C6FE7D	4251 768988	TATYANA ANTONOVA	{"phone": "+70424878426"}
0005432199134	7DDDCF	7334 545966	LYUDMILA ROMANOVA	{"phone": "+70694714454"}
0005432199135	140AF1	1692 344149	KIRILL MATVEEV	{"phone": "+70905042112"}
0005432199136	140AF1	3600 036107	ZOYA SOROKINA	{"phone": "+70835282048"}
0005432199137	9506AC	3360 957446	IVAN EGOROV	{"email": "egorov-i_1976@postgrespro.ru", "phone": "+70131450124"}
0005432199138	BF8BE7	8646 571477	ANDREY KUZMIN	{"phone": "+70221709720"}
0005432199139	1B0BFD	5342 565007	SERGEY DENISOV	{"email": "s_denisov.1974@postgrespro.ru", "phone": "+70905323153"}
0005432199140	210CB6	4893 526372	ALBINA BORISOVA	{"email": "borisova-albina_041968@postgrespro.ru", "phone": "+70706306292"}
0005432199141	210CB6	8547 702019	MIKHAIL ILIN	{"email": "mikhaililin18091969@postgrespro.ru", "phone": "+70163509479"}
0005432199142	D34B3F	7305 800646	VIKTOR GERASIMOV	{"phone": "+70599818712"}
0005432199143	C52968	2682 047922	NATALYA NIKOLAEVA	{"email": "n_nikolaeva-091981@postgrespro.ru", "phone": "+70725390130"}
0005432199144	C52968	9216 456855	EGOR YAKOVLEV	{"phone": "+70489060016"}
0005432199145	2C41DD	0297 767468	OLGA PAVLOVA	{"email": "pavlova_olga-11091970@postgrespro.ru", "phone": "+70543411511"}
0005432199146	670BB8	4221 733596	NATALYA ISAEVA	{"phone": "+70142413147"}
0005432199147	E43308	7347 048325	VALENTINA NIKITINA	{"email": "v-nikitina.1981@postgrespro.ru", "phone": "+70668917603"}
0005432199148	35A433	3246 841793	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_aleksandr_121964@postgrespro.ru", "phone": "+70393286883"}
0005432199149	6FD607	5206 355526	ALISHER FROLOV	{"email": "frolov_alisher_1977@postgrespro.ru", "phone": "+70626767204"}
0005432199150	489CC9	8590 951601	LYUDMILA NAZAROVA	{"phone": "+70629417602"}
0005432199151	489CC9	1182 058392	YURIY ZHUKOV	{"email": "zhukovyuriy.03031982@postgrespro.ru", "phone": "+70424323593"}
0005432199152	489CC9	5898 013364	VLADIMIR IVANOV	{"email": "ivanov_vladimir_1962@postgrespro.ru", "phone": "+70073351531"}
0005432199153	437CE5	1440 542841	IRINA FADEEVA	{"email": "fadeeva-i1975@postgrespro.ru", "phone": "+70487855604"}
0005432199154	8D8271	9167 783902	NINA ZAYCEVA	{"phone": "+70195420933"}
0005432199155	182D08	0709 976826	VERA KAZAKOVA	{"email": "vera.kazakova1972@postgrespro.ru", "phone": "+70918567814"}
0005432199156	8964FB	3713 499168	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a_06011971@postgrespro.ru", "phone": "+70269330968"}
0005432199157	8964FB	1362 288274	SERGEY GUSEV	{"email": "gusev_s.1979@postgrespro.ru", "phone": "+70217729519"}
0005432199158	12AB24	7839 735331	ROMAN VASILEV	{"phone": "+70364546626"}
0005432199159	3D5FA2	4878 817950	EGOR FROLOV	{"email": "egor_frolov061967@postgrespro.ru", "phone": "+70539266811"}
0005432199160	3D5FA2	6393 295542	DMITRIY NAZAROV	{"phone": "+70443921323"}
0005432199161	C879FA	4003 737656	ALFIYA ZHUKOVA	{"email": "azhukova.1966@postgrespro.ru", "phone": "+70176949504"}
0005432199162	401378	8220 473738	NIKOLAY GERASIMOV	{"phone": "+70022472698"}
0005432199163	2B45E7	2550 334064	ALEKSANDR GERASIMOV	{"email": "gerasimova_091972@postgrespro.ru", "phone": "+70064617158"}
0005432199164	2B45E7	7269 869058	VALENTINA TIKHONOVA	{"email": "tikhonova-v-19041971@postgrespro.ru", "phone": "+70077976649"}
0005432199165	2B45E7	3944 939168	YULIYA POPOVA	{"email": "popova.yuliya.061978@postgrespro.ru", "phone": "+70684541257"}
0005432199166	D6F661	5273 077653	ANDREY BORISOV	{"email": "a.borisov12021962@postgrespro.ru", "phone": "+70613051263"}
0005432199167	8555C3	8813 814472	SERGEY KUZNECOV	{"phone": "+70022690744"}
0005432199168	91B939	2118 609528	IVAN FROLOV	{"phone": "+70786022779"}
0005432199169	67FF20	0897 696489	ANASTASIYA GERASIMOVA	{"email": "gerasimova_a14031976@postgrespro.ru", "phone": "+70718148839"}
0005432199170	3C8D61	0247 806934	NIKOLAY KUZMIN	{"email": "kuzmin.n_051977@postgrespro.ru", "phone": "+70084483287"}
0005432199171	B2FE33	9478 827334	POLINA KUDRYASHOVA	{"phone": "+70738625226"}
0005432199172	C80E41	8222 492821	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova.1979@postgrespro.ru", "phone": "+70711944448"}
0005432199173	593C25	7887 623423	NIKOLAY SCHERBAKOV	{"phone": "+70193373069"}
0005432199174	593C25	2904 101918	OLGA MARTYNOVA	{"email": "martynova-olga1976@postgrespro.ru", "phone": "+70904134429"}
0005432199175	23776F	2945 255951	ILYA ZHUKOV	{"phone": "+70273964809"}
0005432199176	23776F	4306 239428	KRISTINA MALYSHEVA	{"phone": "+70890584408"}
0005432199177	23776F	0583 158891	ELENA RODIONOVA	{"phone": "+70151489033"}
0005432199178	3FE46A	6322 183462	DENIS VOROBEV	{"email": "denis_vorobev-1978@postgrespro.ru", "phone": "+70885211221"}
0005432199179	234D69	3944 995952	ALEKSEY GAVRILOV	{"phone": "+70653424401"}
0005432199180	063DB2	3448 393880	SVETLANA MATVEEVA	{"phone": "+70610621881"}
0005432199181	BAB93E	9976 832611	GENNADIY MELNIKOV	{"phone": "+70609188222"}
0005432199182	38C56C	1914 692005	YULIYA ZAKHAROVA	{"phone": "+70290467317"}
0005432199183	604950	0929 844200	OLGA KALININA	{"email": "kalinina_olga_1979@postgrespro.ru", "phone": "+70494554314"}
0005432199184	DB1D63	8037 639394	ANDREY SMIRNOV	{"email": "a_smirnov_04061980@postgrespro.ru", "phone": "+70592616981"}
0005432199185	DB1D63	5868 084830	ALEKSANDR VLASOV	{"phone": "+70994342778"}
0005432199186	4AFA9F	5708 897256	ANDREY VOLKOV	{"email": "volkov.andrey_1977@postgrespro.ru", "phone": "+70341666777"}
0005432199187	4AFA9F	8373 656178	YULIYA SIDOROVA	{"email": "ysidorova.12061986@postgrespro.ru", "phone": "+70691222699"}
0005432199188	4AFA9F	7113 489596	ALEKSANDR PAVLOV	{"email": "aleksandr.pavlov_14121975@postgrespro.ru", "phone": "+70725179391"}
0005432199189	1F3884	7470 750644	GEORGIY ORLOV	{"phone": "+70699131331"}
0005432199190	EEC186	4852 989889	KLAVDIYA KOMAROVA	{"email": "klavdiya.komarova_08091964@postgrespro.ru", "phone": "+70423498931"}
0005432199191	898A9E	9372 483825	ANATOLIY ALEKSEEV	{"phone": "+70919279112"}
0005432199192	898A9E	6673 656011	VERA NESTEROVA	{"email": "nesterova.vera-061967@postgrespro.ru", "phone": "+70666482832"}
0005432199193	F9C9B5	6757 695486	GENNADIY SMIRNOV	{"email": "smirnov_gennadiy28051978@postgrespro.ru", "phone": "+70666960713"}
0005432199194	F9C9B5	9499 532872	PETR MAKSIMOV	{"phone": "+70588207314"}
0005432199195	6E713B	3792 683308	ALEKSANDR FROLOV	{"phone": "+70952015980"}
0005432199196	6E713B	5168 784565	VALENTINA YUDINA	{"email": "yudinavalentina_011975@postgrespro.ru", "phone": "+70983196217"}
0005432199197	F1B946	5106 281915	ANDREY AFANASEV	{"phone": "+70519053181"}
0005432199198	F1B946	2691 532660	ANNA POPOVA	{"phone": "+70425762681"}
0005432199199	BFCF9D	0563 672632	SERGEY MAKSIMOV	{"email": "maksimov.s11111966@postgrespro.ru", "phone": "+70339898578"}
0005432199200	A86FEA	1708 648622	MARIYA MIKHAYLOVA	{"phone": "+70736093659"}
0005432199201	7069B4	0073 054917	DIANA NIKITINA	{"phone": "+70063812086"}
0005432199202	FB498E	9032 312147	TATYANA POPOVA	{"email": "tatyana_popova1983@postgrespro.ru", "phone": "+70098730598"}
0005432199203	7A06D7	0177 336691	ELENA IVANOVA	{"phone": "+70104729351"}
0005432199204	5872D0	5986 775759	ALEKSEY BELOV	{"email": "belov.aleksey1956@postgrespro.ru", "phone": "+70373783767"}
0005432199205	BA1C77	0886 717425	VLADISLAV MAKAROV	{"phone": "+70530456116"}
0005432199206	63C013	4632 016235	TATYANA ANDREEVA	{"email": "tatyana.andreeva1968@postgrespro.ru", "phone": "+70559152037"}
0005432199207	73686D	5142 230534	VADIM TIKHONOV	{"phone": "+70361192780"}
0005432199208	24B109	4488 347104	ANNA KONOVALOVA	{"phone": "+70189403930"}
0005432199209	694060	1252 165585	EVGENIY FOMIN	{"email": "evgeniy.fomin081966@postgrespro.ru", "phone": "+70726649683"}
0005432199210	F86BED	5778 038604	EGOR TARASOV	{"email": "e-tarasov-18031975@postgrespro.ru", "phone": "+70094948210"}
0005432199211	9DB43A	4815 752375	TATYANA ZHURAVLEVA	{"email": "t-zhuravleva_101974@postgrespro.ru", "phone": "+70241651350"}
0005432199212	C65815	7631 457688	ALENA ZAKHAROVA	{"phone": "+70490936013"}
0005432199213	C65815	2778 514379	LYUBOV BOGDANOVA	{"email": "bogdanova_l-26081988@postgrespro.ru", "phone": "+70436416328"}
0005432199214	C65815	9738 107059	GALIYA KUZMINA	{"email": "g.kuzmina.29071974@postgrespro.ru", "phone": "+70646896371"}
0005432199215	A313D2	1607 765800	ALEKSANDRA YAKOVLEVA	{"phone": "+70487071786"}
0005432199216	A313D2	1072 772601	EVGENIY ABRAMOV	{"email": "abramov_e.061968@postgrespro.ru", "phone": "+70480228131"}
0005432199217	E5F6AA	9730 870583	RAISA BORISOVA	{"phone": "+70355115452"}
0005432199218	5D78DD	4127 139203	IGOR KRASNOV	{"email": "krasnov.igor_1968@postgrespro.ru", "phone": "+70363376232"}
0005432199219	308349	1677 925516	DARYA NIKOLAEVA	{"phone": "+70419520163"}
0005432199220	C36F84	1755 036001	VIKTOR MAKAROV	{"email": "v_makarov-26091982@postgrespro.ru", "phone": "+70733869639"}
0005432199221	CA0945	0268 161493	EVGENIY KOZLOV	{"email": "kozlov_evgeniy-111969@postgrespro.ru", "phone": "+70347565183"}
0005432199222	BA89A3	4778 156947	VERA MAKSIMOVA	{"email": "maksimova_vera_1988@postgrespro.ru", "phone": "+70404734826"}
0005432199223	102329	0626 633027	SERGEY IVANOV	{"phone": "+70721554105"}
0005432199224	8F7CE0	5620 731519	VLADIMIR KOROLEV	{"email": "v_korolev-041978@postgrespro.ru", "phone": "+70252369424"}
0005432199225	8F7CE0	1061 031684	ANDREY KRASNOV	{"phone": "+70282346540"}
0005432199226	A2CCC0	0142 694816	VALENTINA DANILOVA	{"email": "valentina_danilova_15061964@postgrespro.ru", "phone": "+70536992940"}
0005432199227	A2CCC0	8592 662476	ARMEN ROMANOV	{"email": "aromanov_091970@postgrespro.ru", "phone": "+70423250560"}
0005432199228	A2CCC0	2765 335405	SERGEY ROMANOV	{"phone": "+70378728569"}
0005432199229	1ABC32	4512 555308	ANNA KRASNOVA	{"email": "krasnovaanna-061973@postgrespro.ru", "phone": "+70692540480"}
0005432199231	255554	3778 156330	ARTEMIY MAKAROV	{"email": "a_makarov-061979@postgrespro.ru", "phone": "+70721143909"}
0005432199232	3EEA1D	0499 735994	ALEKSANDR SIDOROV	{"phone": "+70303648109"}
0005432199233	3EEA1D	6064 726832	ARTEM ABRAMOV	{"phone": "+70021466728"}
0005432199234	83EFBF	2158 464409	OLGA ALEKSEEVA	{"email": "alekseevaolga-15071969@postgrespro.ru", "phone": "+70094847639"}
0005432199235	98B2DA	6315 509355	NINA KAZAKOVA	{"email": "kazakovanina_1972@postgrespro.ru", "phone": "+70846702788"}
0005432199236	5E9B89	0814 707731	IGOR FEDOROV	{"email": "fedorovi-19031970@postgrespro.ru", "phone": "+70325381557"}
0005432199237	7E0007	2400 028557	OLGA FROLOVA	{"phone": "+70115018531"}
0005432199238	D5B072	8459 735689	NAIL ILIN	{"phone": "+70897518296"}
0005432199239	645DCB	3540 771924	EVGENIY SEMENOV	{"phone": "+70004405650"}
0005432199240	960356	5956 000124	NATALYA AKIMOVA	{"email": "akimova_n_1968@postgrespro.ru", "phone": "+70768979307"}
0005432199241	D391F0	7258 026668	RAISA KISELEVA	{"email": "kiselevar111967@postgrespro.ru", "phone": "+70256383570"}
0005432199242	F67B81	1640 043275	ALEKSANDR KAZAKOV	{"phone": "+70698544830"}
0005432199243	111DA2	0848 194498	LYUBOV MAKAROVA	{"email": "lmakarova.04011976@postgrespro.ru", "phone": "+70826201074"}
0005432199244	3CACA6	4736 281039	VIKTOR POPOV	{"email": "popov.v1968@postgrespro.ru", "phone": "+70604350743"}
0005432199245	B368AC	7060 228625	OLESYA FADEEVA	{"email": "fadeeva-olesya.1964@postgrespro.ru", "phone": "+70149360992"}
0005432199246	46F295	5647 156435	ALEKSANDR ZHURAVLEV	{"phone": "+70684884304"}
0005432199247	46F295	3534 297197	EKATERINA KULIKOVA	{"phone": "+70240593423"}
0005432199248	359BEB	7148 870202	MARIYA KARPOVA	{"email": "mariyakarpova-041953@postgrespro.ru", "phone": "+70302810926"}
0005432199249	576EEF	2084 340540	ARINA NIKIFOROVA	{"email": "nikiforovaa031961@postgrespro.ru", "phone": "+70228460925"}
0005432199250	576EEF	6569 163921	ZOYA KONOVALOVA	{"email": "konovalovaz.1969@postgrespro.ru", "phone": "+70444069693"}
0005432199251	4CBD93	8198 131884	VALENTIN IVANOV	{"email": "v_ivanov.1974@postgrespro.ru", "phone": "+70923363175"}
0005432199252	4CBD93	9623 516065	YULIYA SIDOROVA	{"phone": "+70858192905"}
0005432199253	C7D782	5041 997067	ANNA GUSEVA	{"email": "gusevaa.081968@postgrespro.ru", "phone": "+70024015424"}
0005432199254	49BDD0	2989 498610	ELENA POPOVA	{"phone": "+70943876130"}
0005432199255	49BDD0	0269 496687	BORIS MOROZOV	{"phone": "+70377329484"}
0005432199256	CB5719	3339 429836	ALEKSANDR SIDOROV	{"email": "sidorov_a1964@postgrespro.ru", "phone": "+70977643244"}
0005432199257	CB5719	6874 930201	PAVEL GRIGOREV	{"phone": "+70164085793"}
0005432199258	D48AEB	3202 137327	ANASTASIYA SEMENOVA	{"phone": "+70488344307"}
0005432199259	AF94AD	1688 866946	VLADISLAV ALEKSEEV	{"email": "alekseev.v.18111964@postgrespro.ru", "phone": "+70804665625"}
0005432199260	B66257	0239 310261	ALEKSANDR VOLKOV	{"email": "volkovaleksandr-051975@postgrespro.ru", "phone": "+70062807667"}
0005432199261	50011E	6197 756178	NATALYA TIMOFEEVA	{"phone": "+70586150834"}
0005432199262	50011E	8710 046260	OLGA EFIMOVA	{"phone": "+70480555169"}
0005432199263	50011E	2234 454728	GALINA GORBUNOVA	{"email": "gorbunova_galina_091973@postgrespro.ru", "phone": "+70924394712"}
0005432199264	EE77F5	0093 991247	MARINA SIDOROVA	{"email": "marina_sidorova_061971@postgrespro.ru", "phone": "+70652095348"}
0005432199265	3ED6F5	6722 191361	RIMMA DANILOVA	{"email": "r-danilova-111962@postgrespro.ru", "phone": "+70602873121"}
0005432199266	371BE2	7799 083593	ASKAR EGOROV	{"phone": "+70020109778"}
0005432199267	ADE312	5548 783126	NATALYA ALEKSANDROVA	{"phone": "+70614268283"}
0005432199268	C913A6	3390 881138	MIKHAIL ROMANOV	{"phone": "+70228597950"}
0005432199269	FB9629	3441 535288	DMITRIY FILIPPOV	{"email": "d_filippov.19101982@postgrespro.ru", "phone": "+70756535971"}
0005432199270	FB9629	2966 277815	VALENTINA PETROVA	{"phone": "+70495251310"}
0005432199271	384E5D	6621 049449	IRINA KALININA	{"phone": "+70716248906"}
0005432199272	004554	3468 293308	RUSTAM VASILEV	{"phone": "+70719887000"}
0005432199273	B6F14F	0800 434249	VALERIY EGOROV	{"phone": "+70466724955"}
0005432199274	E4F412	5469 463476	ALEKSANDR KUZNECOV	{"email": "kuznecova1972@postgrespro.ru", "phone": "+70806845506"}
0005432199275	E4F412	1494 946778	IGOR VASILEV	{"phone": "+70007831700"}
0005432199276	F0A6F0	5835 031389	VALERIY FEDOROV	{"phone": "+70101513878"}
0005432199277	CBC87B	0963 901875	ILYA ZHURAVLEV	{"email": "ilyazhuravlev08031979@postgrespro.ru", "phone": "+70340274889"}
0005432199278	CBC87B	5660 496957	GENNADIY FOMIN	{"phone": "+70880592736"}
0005432199279	5083CF	3508 283852	IRINA SAVELEVA	{"email": "saveleva_i.1959@postgrespro.ru", "phone": "+70770864511"}
0005432199280	F576C2	5317 031034	MATRENA NESTEROVA	{"phone": "+70188157052"}
0005432199281	0D6690	2356 755382	YURIY BELOV	{"phone": "+70668389080"}
0005432199282	E1FBA6	5042 234202	PETR TIKHONOV	{"phone": "+70246854250"}
0005432199283	E1FBA6	6608 093019	MARINA KUZNECOVA	{"email": "kuznecovam.14041971@postgrespro.ru", "phone": "+70183626330"}
0005432199284	F6467B	4024 691930	ANATOLIY MIRONOV	{"email": "mironov.anatoliy_06081970@postgrespro.ru", "phone": "+70029210214"}
0005432199285	A0899C	4665 194113	SERGEY RODIONOV	{"email": "srodionov_1965@postgrespro.ru", "phone": "+70530557997"}
0005432199286	6924AD	1895 187601	ULYANA ANTONOVA	{"email": "antonova_ulyana.111969@postgrespro.ru", "phone": "+70114545637"}
0005432199287	75EF38	6172 751816	OLEG YAKOVLEV	{"email": "yakovlev.o.041977@postgrespro.ru", "phone": "+70607981549"}
0005432199288	15F7F7	0243 211050	OLEG SERGEEV	{"phone": "+70024442653"}
0005432199289	15F7F7	5324 796351	ALEKSEY STEPANOV	{"email": "a-stepanov_1971@postgrespro.ru", "phone": "+70249124192"}
0005432199290	D96D42	5652 244564	MARIYA ZHURAVLEVA	{"email": "m.zhuravleva.111962@postgrespro.ru", "phone": "+70671259034"}
0005432199291	5CB90D	8288 663630	ALLA VASILEVA	{"email": "vasileva-a.1960@postgrespro.ru", "phone": "+70263380561"}
0005432199292	3BD3FD	8046 244639	YURIY SERGEEV	{"email": "ysergeev_1977@postgrespro.ru", "phone": "+70090405455"}
0005432199293	3BD3FD	3060 564337	VIKTOR STEPANOV	{"email": "viktorstepanov-021974@postgrespro.ru", "phone": "+70183442822"}
0005432199294	91A87D	8033 507963	ELENA MELNIKOVA	{"phone": "+70457240192"}
0005432199295	90DD2E	4876 966002	SVETLANA ZOTOVA	{"phone": "+70113500954"}
0005432199296	21E345	0468 359302	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr-19081981@postgrespro.ru", "phone": "+70414299049"}
0005432199297	F6B2F6	9846 051442	VITALIY GUSEV	{"email": "vitaliy_gusev11011980@postgrespro.ru", "phone": "+70945981220"}
0005432199298	CC7456	7959 708693	LYUDMILA KISELEVA	{"phone": "+70669659075"}
0005432199299	563C5E	1544 079100	VERA MEDVEDEVA	{"phone": "+70337264948"}
0005432199300	12B456	6115 956920	IVAN KARPOV	{"email": "karpov.i-091979@postgrespro.ru", "phone": "+70277506816"}
0005432199301	12B456	4020 257157	DMITRIY ZHUKOV	{"phone": "+70977327900"}
0005432199302	2E5A57	9129 009472	VLADISLAV STEPANOV	{"email": "stepanov_vladislav-1979@postgrespro.ru", "phone": "+70252419148"}
0005432199303	61494A	0822 553401	TATYANA NIKITINA	{"email": "nikitinatatyana.01051976@postgrespro.ru", "phone": "+70296701568"}
0005432199304	61494A	7191 036614	VERA ZAKHAROVA	{"phone": "+70071526680"}
0005432199305	61494A	9791 696394	VALERIY OSIPOV	{"email": "osipov_v.1979@postgrespro.ru", "phone": "+70376874621"}
0005432199306	4F22F9	1849 385572	ALEKSANDR GAVRILOV	{"email": "gavrilov.a121962@postgrespro.ru", "phone": "+70319796378"}
0005432199307	D83855	5941 826832	VASILIY POPOV	{"phone": "+70202428810"}
0005432199308	8DC49B	0785 845032	KIRILL KOROLEV	{"phone": "+70596438423"}
0005432199309	FFC6FD	4868 951067	NATALYA ANDREEVA	{"email": "andreeva_n-03121963@postgrespro.ru", "phone": "+70813083507"}
0005432199310	FFC6FD	8140 866547	GALINA DANILOVA	{"email": "danilova.g.21121977@postgrespro.ru", "phone": "+70227725313"}
0005432199311	F0CDE3	5217 460969	RISHAT SERGEEV	{"email": "r_sergeev111971@postgrespro.ru", "phone": "+70295019174"}
0005432199312	F0CDE3	5382 166856	GULFIYA ANDREEVA	{"email": "andreeva_gulfiya.02021966@postgrespro.ru", "phone": "+70352379877"}
0005432199313	EDCDBB	0621 360690	YANA MELNIKOVA	{"phone": "+70833951378"}
0005432199314	EDCDBB	1525 442202	ALEKSANDR KUDRYASHOV	{"email": "aleksandrkudryashov18011975@postgrespro.ru", "phone": "+70309229922"}
0005432199315	EDCDBB	4252 249980	VERA AFANASEVA	{"phone": "+70685709952"}
0005432199316	70B3C5	8851 121755	NIKOLAY PETROV	{"phone": "+70114222694"}
0005432199317	70B3C5	6489 928420	VALENTINA LAZAREVA	{"email": "v.lazareva_021962@postgrespro.ru", "phone": "+70969226795"}
0005432199318	578603	8912 770519	VLADISLAV ROMANOV	{"email": "v.romanov1976@postgrespro.ru", "phone": "+70999898053"}
0005432199319	A9075B	1411 126734	TATYANA DANILOVA	{"email": "danilova-t_021977@postgrespro.ru", "phone": "+70479560265"}
0005432199320	A9075B	6662 060377	NIKITA SMIRNOV	{"email": "n.smirnov.1953@postgrespro.ru", "phone": "+70162096374"}
0005432199321	627741	6794 391570	ROMAN FILIPPOV	{"email": "filippov.r-1984@postgrespro.ru", "phone": "+70770688793"}
0005432199322	627741	6242 311230	SVETLANA ORLOVA	{"email": "orlovasvetlana_041972@postgrespro.ru", "phone": "+70476887541"}
0005432199323	B4FF21	7659 997309	ARTEM KUZMIN	{"phone": "+70310172205"}
0005432199324	608792	0142 715566	VALENTINA GUSEVA	{"phone": "+70302237102"}
0005432199325	4B31E8	3131 617570	ALEKSANDR SOROKIN	{"phone": "+70179755269"}
0005432199326	4B31E8	4859 235429	DANILA MELNIKOV	{"email": "d-melnikov.24041970@postgrespro.ru", "phone": "+70464035970"}
0005432199327	31E752	1631 172763	ARTEM IVANOV	{"phone": "+70555492277"}
0005432199328	8CB71C	1910 487153	TATYANA IVANOVA	{"email": "tatyana.ivanova041965@postgrespro.ru", "phone": "+70710778057"}
0005432199329	BADF5F	2563 878070	SERGEY IVANOV	{"phone": "+70250374801"}
0005432199330	7C96E2	9544 764408	ANATOLIY NIKITIN	{"phone": "+70300568692"}
0005432199331	0EF589	9203 115001	VASILIY KOZLOV	{"email": "kozlov.v.1973@postgrespro.ru", "phone": "+70928404938"}
0005432199332	2BB525	0745 896999	LYUDMILA ANDREEVA	{"phone": "+70841470493"}
0005432199333	E6C6F4	8355 322374	LIDIYA POPOVA	{"email": "lidiyapopova_051960@postgrespro.ru", "phone": "+70201527423"}
0005432199334	E88D96	0075 149234	RAISA POPOVA	{"phone": "+70253433441"}
0005432199335	19EC6E	4293 525951	ZINAIDA POLYAKOVA	{"email": "z.polyakova-25101983@postgrespro.ru", "phone": "+70614490236"}
0005432199336	19EC6E	5221 290056	SERGEY KAZAKOV	{"email": "sergey_kazakov-1985@postgrespro.ru", "phone": "+70874679605"}
0005432199337	871A7C	9226 316344	ALEKSANDR MELNIKOV	{"email": "melnikov-a_061967@postgrespro.ru", "phone": "+70885336014"}
0005432199338	871A7C	1211 439921	YURIY STEPANOV	{"email": "y-stepanov1975@postgrespro.ru", "phone": "+70913677467"}
0005432199339	7C9FA0	7018 062955	NIKOLAY ISAEV	{"email": "isaev.nikolay.07051975@postgrespro.ru", "phone": "+70145483634"}
0005432199340	7C9FA0	6186 811120	NATALYA SCHERBAKOVA	{"email": "natalya-scherbakova-1967@postgrespro.ru", "phone": "+70696864130"}
0005432199341	39C134	5779 504973	ILDAR TIMOFEEV	{"phone": "+70801858218"}
0005432199342	BA1F81	2098 127509	NIKITA NAZAROV	{"email": "nikita_nazarov13011963@postgrespro.ru", "phone": "+70094109283"}
0005432199343	19F88D	2005 249496	RITA EGOROVA	{"phone": "+70613925146"}
0005432199344	9020D6	8239 763454	SERGEY NOVIKOV	{"email": "novikovsergey.02081969@postgrespro.ru", "phone": "+70872507266"}
0005432199345	8E265E	3786 652898	ALEKSANDR FEDOTOV	{"phone": "+70429052608"}
0005432199346	8E265E	4497 127227	VLADIMIR STEPANOV	{"email": "vladimir.stepanov1964@postgrespro.ru", "phone": "+70563733144"}
0005432199347	8E265E	9845 672624	SERGEY KARPOV	{"email": "s_karpov1977@postgrespro.ru", "phone": "+70646443135"}
0005432199348	33B987	4657 157511	OKSANA ANDREEVA	{"phone": "+70204888098"}
0005432199349	73F36D	7378 851261	IRINA BELYAEVA	{"email": "belyaeva_irina-101982@postgrespro.ru", "phone": "+70207189546"}
0005432199350	D5A12E	7131 229359	VIKTOR DMITRIEV	{"email": "dmitriev_v_1986@postgrespro.ru", "phone": "+70153916823"}
0005432199351	55A849	9332 800403	ALEKSANDR KISELEV	{"phone": "+70061902895"}
0005432199352	3238C1	3964 254036	VITALIY SMIRNOV	{"phone": "+70616322308"}
0005432199353	052E7F	0693 303927	VIKTOR FROLOV	{"email": "frolovv_051975@postgrespro.ru", "phone": "+70189857475"}
0005432199354	DF96D9	7109 105574	GALINA ANTONOVA	{"email": "antonovag-1973@postgrespro.ru", "phone": "+70142812715"}
0005432199355	FA6723	0671 080159	OLGA EFIMOVA	{"email": "olga.efimova.061977@postgrespro.ru", "phone": "+70010247131"}
0005432199356	1079C1	5083 642324	ANDREY OSIPOV	{"email": "osipov.andrey.071976@postgrespro.ru", "phone": "+70132906999"}
0005432199357	D1274F	6681 281519	VALENTIN MIKHAYLOV	{"phone": "+70951769048"}
0005432199358	727744	9607 722715	VLADIMIR MOROZOV	{"email": "v-morozov-07091966@postgrespro.ru", "phone": "+70878702158"}
0005432199359	667A26	8761 294130	OLGA GERASIMOVA	{"phone": "+70368973217"}
0005432199360	667A26	0641 025895	ALINA NAZAROVA	{"email": "a_nazarova_1966@postgrespro.ru", "phone": "+70355429554"}
0005432199361	D70629	0578 253159	YULIYA KUZNECOVA	{"email": "kuznecovayuliya_121980@postgrespro.ru", "phone": "+70978092145"}
0005432199362	455300	3720 752974	NATALYA EGOROVA	{"email": "egorova.n_1966@postgrespro.ru", "phone": "+70681245078"}
0005432199363	455300	7667 342977	POLINA KUZNECOVA	{"email": "kuznecovapolina18121957@postgrespro.ru", "phone": "+70281176624"}
0005432199364	83CF75	4942 830746	MATVEY MIRONOV	{"email": "m-mironov-1972@postgrespro.ru", "phone": "+70457522561"}
0005432199365	FDB293	6292 733400	MARIYA TARASOVA	{"email": "tarasova_m_1981@postgrespro.ru", "phone": "+70968717758"}
0005432199366	4B2603	7484 495508	LIDIYA GERASIMOVA	{"phone": "+70230050205"}
0005432199367	B91558	1686 511176	ALEKSEY KUZNECOV	{"email": "a-kuznecov_12041973@postgrespro.ru", "phone": "+70514575348"}
0005432199368	46790F	1088 274303	NATALYA FOMINA	{"email": "fomina.natalya.20111980@postgrespro.ru", "phone": "+70064754522"}
0005432199369	46790F	0990 209705	ALIYA MIKHAYLOVA	{"phone": "+70045545214"}
0005432199370	50781D	6303 312523	ANDREY AFANASEV	{"phone": "+70962072011"}
0005432199371	DAB9B0	6530 161452	PAVEL SOKOLOV	{"phone": "+70150696528"}
0005432199372	DAB9B0	4993 894932	VIKTORIYA VLASOVA	{"phone": "+70823110657"}
0005432199373	DAB9B0	6188 108373	OLGA MIKHAYLOVA	{"email": "mikhaylovaolga_111964@postgrespro.ru", "phone": "+70738396833"}
0005432199374	0BD28A	6293 611438	ELENA KAZAKOVA	{"email": "elena_kazakova_19101960@postgrespro.ru", "phone": "+70321854017"}
0005432199375	0BD28A	2068 077499	GALINA SOKOLOVA	{"email": "sokolova-g_071969@postgrespro.ru", "phone": "+70883940496"}
0005432199376	E0D8F0	9065 897900	IGOR IVANOV	{"phone": "+70914230363"}
0005432199377	E0D8F0	1919 991970	ARINA POPOVA	{"email": "popovaa041967@postgrespro.ru", "phone": "+70806029517"}
0005432199378	46C9AC	6613 190249	IGOR SMIRNOV	{"phone": "+70210213750"}
0005432199379	11E4BA	5000 327234	ANDREY IVANOV	{"phone": "+70088428947"}
0005432199380	11E4BA	0037 395859	DMITRIY ZHURAVLEV	{"phone": "+70764073099"}
0005432199381	A015DA	6793 625686	OLGA SERGEEVA	{"email": "sergeevaolga_27021963@postgrespro.ru", "phone": "+70960536939"}
0005432199382	A015DA	8899 443702	MARIYA ISAEVA	{"email": "isaeva-m_1976@postgrespro.ru", "phone": "+70311258111"}
0005432199383	E4072B	5756 536454	TAMARA KUZNECOVA	{"email": "kuznecova-t.1975@postgrespro.ru", "phone": "+70299564951"}
0005432199384	4DBC63	5303 019682	LYUBOV FADEEVA	{"phone": "+70132339868"}
0005432199385	CA9A84	1978 167175	YULIYA POPOVA	{"phone": "+70216209863"}
0005432199386	47226D	4543 711704	OLEG MAKAROV	{"email": "makarovoleg.02111975@postgrespro.ru", "phone": "+70315592437"}
0005432199387	47226D	2023 095225	VLADIMIR PAVLOV	{"phone": "+70179725715"}
0005432199388	9B46E6	5711 702253	VALENTINA ILINA	{"phone": "+70091868157"}
0005432199389	9B46E6	4447 685509	ELENA FROLOVA	{"email": "elena_frolova.1967@postgrespro.ru", "phone": "+70701137316"}
0005432199390	1A71BD	7340 155588	PAVEL DENISOV	{"phone": "+70791141029"}
0005432199391	B749A3	9710 634683	VALENTINA KUZNECOVA	{"phone": "+70551866676"}
0005432199392	0F1C83	9251 882684	KRISTINA KALININA	{"email": "kalinina-kristina-10061985@postgrespro.ru", "phone": "+70614389941"}
0005432199393	0F1C83	3797 264630	ALINA FILATOVA	{"email": "alina-filatova-1968@postgrespro.ru", "phone": "+70223123970"}
0005432199394	CC4FD9	5843 755521	VIKTOR SHEVCHENKO	{"phone": "+70831300493"}
0005432199395	CC4FD9	8482 990806	MIKHAIL FEDOROV	{"email": "fedorov-m_1969@postgrespro.ru", "phone": "+70675802223"}
0005432199396	458042	3398 776297	ALENA SMIRNOVA	{"phone": "+70022797622"}
0005432199397	458042	0361 143261	SVETLANA ZAYCEVA	{"email": "zayceva.s16111976@postgrespro.ru", "phone": "+70522323933"}
0005432199398	5E6453	0895 619147	ALEKSANDRA DAVYDOVA	{"phone": "+70428990939"}
0005432199399	2553F8	4043 089757	GALINA KUZMINA	{"phone": "+70508973363"}
0005432199400	2553F8	3187 658427	EVGENIY NIKOLAEV	{"email": "nikolaev.e_18031969@postgrespro.ru", "phone": "+70554491781"}
0005432199401	1833EB	7912 801030	DMITRIY NIKITIN	{"email": "nikitin-d041990@postgrespro.ru", "phone": "+70389479573"}
0005432199402	3D54F4	5485 587217	MIKHAIL RODIONOV	{"email": "m-rodionov-081972@postgrespro.ru", "phone": "+70260019116"}
0005432199403	B0C283	7646 610151	LARISA NIKOLAEVA	{"phone": "+70816128194"}
0005432199404	B8E8A1	5877 650718	VLADIMIR TIMOFEEV	{"email": "vladimir_timofeev1966@postgrespro.ru", "phone": "+70126855041"}
0005432199405	B8E8A1	0149 949881	ALENA NIKOLAEVA	{"email": "nikolaeva-a121972@postgrespro.ru", "phone": "+70736362038"}
0005432199406	A82DE1	4152 123476	GALINA FROLOVA	{"email": "g.frolova1957@postgrespro.ru", "phone": "+70537397535"}
0005432199407	CA274C	2690 070027	ZOYA FEDOROVA	{"email": "fedorova-z121973@postgrespro.ru", "phone": "+70058395274"}
0005432199408	50EE0B	8561 572591	NADEZHDA POLYAKOVA	{"phone": "+70159724995"}
0005432199409	50EE0B	2851 190577	ANDREY PAVLOV	{"phone": "+70953724889"}
0005432199410	4D0153	2173 661771	EVGENIYA GAVRILOVA	{"email": "evgeniya.gavrilova_021974@postgrespro.ru", "phone": "+70103203951"}
0005432199411	4D0153	9938 010758	ANASTASIYA VASILEVA	{"email": "anastasiya.vasileva.111967@postgrespro.ru", "phone": "+70106510857"}
0005432199412	A16FEB	5099 933172	LYUBOV MARTYNOVA	{"email": "lmartynova01081964@postgrespro.ru", "phone": "+70714724138"}
0005432199413	38A1CF	4764 957078	NATALYA EGOROVA	{"email": "natalyaegorova.15051976@postgrespro.ru", "phone": "+70968808750"}
0005432199414	22F4BA	1595 542683	IVAN KUZMIN	{"email": "kuzminivan-20101969@postgrespro.ru", "phone": "+70031259907"}
0005432199415	B0F832	4530 578571	MARIYA CHERNOVA	{"phone": "+70105522302"}
0005432199416	B0F832	8445 949474	RAISA NAZAROVA	{"email": "nazarova_r25121986@postgrespro.ru", "phone": "+70102101529"}
0005432199417	B0F832	8070 640967	VIKTOR NAUMOV	{"email": "v-naumov_1980@postgrespro.ru", "phone": "+70360110517"}
0005432199418	56F207	5872 954770	ALEKSANDR DAVYDOV	{"email": "davydovaleksandr.1971@postgrespro.ru", "phone": "+70110334930"}
0005432199419	2870D1	0034 883095	ELIZAVETA KOROLEVA	{"phone": "+70289812279"}
0005432199420	2870D1	6240 746595	ALEVTINA BORISOVA	{"phone": "+70366523059"}
0005432199421	D6A9FD	4950 381346	NIKOLAY ALEKSEEV	{"email": "alekseev_n-1969@postgrespro.ru", "phone": "+70206057195"}
0005432199422	D6A9FD	7277 252349	MIKHAIL KUZMIN	{"email": "kuzmin-mikhail_18111960@postgrespro.ru", "phone": "+70052064080"}
0005432199423	9E905A	9526 738652	ANATOLIY TIKHONOV	{"phone": "+70246105851"}
0005432199424	9E905A	0588 020954	DENIS NIKITIN	{"email": "d-nikitin.1977@postgrespro.ru", "phone": "+70329531150"}
0005432199425	28C097	2014 173692	ELENA KUZNECOVA	{"email": "elena-kuznecova11081966@postgrespro.ru", "phone": "+70562755760"}
0005432199426	28C097	3421 550356	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr-1970@postgrespro.ru", "phone": "+70809211911"}
0005432199427	0211BC	2418 378499	PAVEL KARPOV	{"email": "pavel.karpov121961@postgrespro.ru", "phone": "+70154881450"}
0005432199428	0211BC	8937 511485	MARIYA IVANOVA	{"phone": "+70163955822"}
0005432199429	736BE4	7691 315638	DMITRIY CHERNOV	{"email": "dchernov_1976@postgrespro.ru", "phone": "+70244904817"}
0005432199430	B7FADF	4539 110758	VALENTINA PAVLOVA	{"email": "pavlova-v.1970@postgrespro.ru", "phone": "+70138410840"}
0005432199431	8EBAAE	2208 212263	SVETLANA PETROVA	{"phone": "+70574898079"}
0005432199432	37437D	6546 339392	VALENTINA PETROVA	{"email": "v_petrova.1975@postgrespro.ru", "phone": "+70478173865"}
0005432199433	37437D	6011 984710	NATALIYA KUZNECOVA	{"email": "kuznecovan-121964@postgrespro.ru", "phone": "+70903936702"}
0005432199434	A3FCC2	0662 560532	NATALYA RODIONOVA	{"phone": "+70902633006"}
0005432199435	A3FCC2	5902 477425	TAISIYA MELNIKOVA	{"phone": "+70031590258"}
0005432199436	1B9C42	9220 426582	KIRILL MIRONOV	{"email": "mironov_k.18021965@postgrespro.ru", "phone": "+70826411012"}
0005432199437	C51F61	2132 823796	ROMAN KOROLEV	{"email": "korolev-roman121966@postgrespro.ru", "phone": "+70422107203"}
0005432199438	BB6F3A	6754 009159	YURIY TIMOFEEV	{"email": "timofeev.yuriy071984@postgrespro.ru", "phone": "+70083031272"}
0005432199439	26A3F1	1458 738448	POLINA AFANASEVA	{"phone": "+70433568545"}
0005432199440	DFC1B6	1572 752579	ANATOLIY KARPOV	{"email": "anatoliy-karpov.18051971@postgrespro.ru", "phone": "+70444320496"}
0005432199441	DFC1B6	7768 743517	TATYANA FOMINA	{"email": "fomina-t011954@postgrespro.ru", "phone": "+70382754454"}
0005432199442	EF7EC7	8824 311392	SERGEY ZHURAVLEV	{"phone": "+70200062204"}
0005432199443	EF7EC7	6393 538175	LYUBOV BELOVA	{"email": "l_belova.061971@postgrespro.ru", "phone": "+70294136611"}
0005432199444	7096A7	6607 690294	VIKTOR IVANOV	{"email": "v.ivanov-1969@postgrespro.ru", "phone": "+70912724840"}
0005432199445	49EDC8	8060 838406	OLEG DMITRIEV	{"email": "dmitriev_o1969@postgrespro.ru", "phone": "+70196342613"}
0005432202933	924BFA	8093 679910	SERGEY KOZLOV	{"email": "kozlovsergey.1966@postgrespro.ru", "phone": "+70028419547"}
0005432202934	924BFA	0600 415597	IRINA YAKOVLEVA	{"email": "yakovleva-irina09071971@postgrespro.ru", "phone": "+70660889261"}
0005432202935	44C4A0	2795 912430	ANNA SOKOLOVA	{"email": "sokolovaa-111992@postgrespro.ru", "phone": "+70003465458"}
0005432202936	0C0786	7050 365958	VLADIMIR FEDOROV	{"email": "fedorov_v011956@postgrespro.ru", "phone": "+70304602217"}
0005432202937	0087C1	8977 089463	MARIYA IVANOVA	{"phone": "+70568570887"}
0005432202938	7CBC3A	6291 640609	NINA EGOROVA	{"phone": "+70022594205"}
0005432202939	677DEF	3744 717176	ALEKSANDR BELOV	{"email": "belov-aleksandr-1970@postgrespro.ru", "phone": "+70314825514"}
0005432202940	677DEF	3873 539574	KSENIYA POPOVA	{"email": "popova.k.031967@postgrespro.ru", "phone": "+70477429194"}
0005432202941	72DDE0	3872 380209	ALEKSANDR POPOV	{"email": "a-popov_15091967@postgrespro.ru", "phone": "+70002851233"}
0005432202942	976B99	1159 406459	NADEZHDA CHERNOVA	{"email": "nchernova20101969@postgrespro.ru", "phone": "+70188261695"}
0005432202943	C286DD	8209 186089	VLADIMIR DENISOV	{"email": "vdenisov.21071976@postgrespro.ru", "phone": "+70181285344"}
0005432202944	5D3723	7379 645143	EVGENIY POPOV	{"phone": "+70527194761"}
0005432202945	5D3723	6447 833136	IRINA MOISEEVA	{"phone": "+70935188368"}
0005432202946	342010	0864 028313	ELENA BARANOVA	{"email": "elena-baranova-061965@postgrespro.ru", "phone": "+70211589797"}
0005432202947	342010	6983 601759	EKATERINA TITOVA	{"phone": "+70394974172"}
0005432202948	342010	2384 484966	NINA ABRAMOVA	{"email": "n_abramova.1966@postgrespro.ru", "phone": "+70288660196"}
0005432202949	27EF2C	8119 892197	OLGA ZAYCEVA	{"phone": "+70822254190"}
0005432202950	92CE78	1324 908004	ANNA MAKAROVA	{"phone": "+70647435853"}
0005432202951	92CE78	2463 274175	SVETLANA NIKITINA	{"email": "nikitina-svetlana-02091975@postgrespro.ru", "phone": "+70161002276"}
0005432202952	317DD4	1628 507717	DANILA PETROV	{"phone": "+70299144908"}
0005432202953	3EE178	2486 492336	KSENIYA MASLOVA	{"email": "maslovakseniya.041970@postgrespro.ru", "phone": "+70406456241"}
0005432202954	170D19	0748 367829	VALENTINA BELYAEVA	{"phone": "+70780232029"}
0005432202955	0AA138	6302 547236	MAKSIM TARASOV	{"phone": "+70059919292"}
0005432202956	0AA138	5662 592688	ALEKSEY SHEVCHENKO	{"email": "a_shevchenko06051980@postgrespro.ru", "phone": "+70846510492"}
0005432202957	57A4CF	8784 864158	SERGEY NOVIKOV	{"email": "s-novikov_071967@postgrespro.ru", "phone": "+70210493308"}
0005432202958	A6B852	8187 377384	VIKTOR ISAEV	{"email": "viktor-isaev-091975@postgrespro.ru", "phone": "+70813610307"}
0005432202959	08B7A4	0740 264829	ILDAR FEDOTOV	{"phone": "+70382594305"}
0005432202960	08B7A4	8591 181212	OLGA KAZAKOVA	{"email": "kazakova-olga.041973@postgrespro.ru", "phone": "+70505852480"}
0005432202961	08B7A4	3265 941871	EVGENIY GUSEV	{"phone": "+70913764988"}
0005432202962	A33C92	3429 967631	SVETLANA DAVYDOVA	{"email": "svetlanadavydova-111970@postgrespro.ru", "phone": "+70557522066"}
0005432202963	BC1C11	8974 879748	VLADIMIR POPOV	{"email": "v_popov_24051970@postgrespro.ru", "phone": "+70109027220"}
0005432202964	BC1C11	5535 583376	DMITRIY EGOROV	{"email": "egorov_dmitriy26101969@postgrespro.ru", "phone": "+70241680652"}
0005432202965	BC1C11	3989 844275	ANNA ANTONOVA	{"phone": "+70946184615"}
0005432202966	6164E0	6210 788489	IRINA NAZAROVA	{"phone": "+70032600423"}
0005432202967	6164E0	1238 141751	TATYANA ALEKSEEVA	{"email": "alekseeva-t.18051969@postgrespro.ru", "phone": "+70177905864"}
0005432202968	EB6AB0	5165 884818	GALINA MIRONOVA	{"email": "galina.mironova_15121976@postgrespro.ru", "phone": "+70584819565"}
0005432202969	EB6AB0	6544 903426	LYUBOV YAKOVLEVA	{"email": "lyubovyakovleva-30011965@postgrespro.ru", "phone": "+70854720989"}
0005432202970	69C57F	6514 149207	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov-1981@postgrespro.ru", "phone": "+70994982957"}
0005432202971	693E49	8334 353895	LYUBOV KOROLEVA	{"phone": "+70692213808"}
0005432202972	65C92F	6465 303302	TAMARA IVANOVA	{"email": "ivanova_tamara041967@postgrespro.ru", "phone": "+70157804344"}
0005432202973	65C92F	7018 960026	NIKITA MAKAROV	{"email": "makarovnikita1975@postgrespro.ru", "phone": "+70604229477"}
0005432202974	A2798C	8479 847721	LILIYA MALYSHEVA	{"phone": "+70202746316"}
0005432202975	1EDF79	0650 071446	SVETLANA SIDOROVA	{"email": "s_sidorova_1972@postgrespro.ru", "phone": "+70165441745"}
0005432202976	1EDF79	5790 747653	RADIK EGOROV	{"email": "egorovradik051966@postgrespro.ru", "phone": "+70549932546"}
0005432202977	BB99A5	9195 484063	IVAN DAVYDOV	{"email": "davydov.i1979@postgrespro.ru", "phone": "+70415757851"}
0005432202978	BB99A5	5754 734145	ANNA ZAYCEVA	{"phone": "+70150677325"}
0005432202979	B682CC	5426 421702	FEDOR PETROV	{"email": "petrov-f_1971@postgrespro.ru", "phone": "+70560440610"}
0005432202980	82E0B0	8871 156288	FANIL FILIPPOV	{"phone": "+70799653556"}
0005432202981	82E0B0	4262 138923	ILDAR MOISEEV	{"email": "moiseev.i-18121977@postgrespro.ru", "phone": "+70377341921"}
0005432202982	82E0B0	1025 029149	OLEG NIKITIN	{"email": "nikitinoleg-02031969@postgrespro.ru", "phone": "+70280201081"}
0005432202983	A08731	5750 763459	REGINA ZAKHAROVA	{"phone": "+70334139659"}
0005432202984	B2859C	6717 336194	OKSANA PETROVA	{"email": "petrova_oksana28031975@postgrespro.ru", "phone": "+70375539836"}
0005432202985	B2859C	9358 748419	ELENA LUKYANOVA	{"phone": "+70454074991"}
0005432202986	7B8EF7	9142 666252	MAKSIM VASILEV	{"email": "maksimvasilev011968@postgrespro.ru", "phone": "+70417387674"}
0005432202987	0CA3EB	2143 094279	IRINA VLASOVA	{"phone": "+70951282076"}
0005432202988	2E55FA	1587 268013	ALEVTINA SEMENOVA	{"phone": "+70419293465"}
0005432202989	B30913	5012 426036	ELENA EFREMOVA	{"email": "elena.efremova-1976@postgrespro.ru", "phone": "+70044148526"}
0005432202990	B30913	4878 123979	SVETLANA FILIPPOVA	{"email": "svetlanafilippova_1966@postgrespro.ru", "phone": "+70793171175"}
0005432202991	71BE4D	6450 500337	NIKOLAY GRIGOREV	{"email": "n.grigorev_011964@postgrespro.ru", "phone": "+70997168146"}
0005432202992	71BE4D	1791 486493	SERGEY MAKAROV	{"email": "makarov.s.1981@postgrespro.ru", "phone": "+70996423635"}
0005432202993	235D97	9220 461215	RUSLAN GERASIMOV	{"email": "r_gerasimov_111972@postgrespro.ru", "phone": "+70811124441"}
0005432202994	93EF9D	7734 846286	BORIS VLASOV	{"email": "vlasov-b_051987@postgrespro.ru", "phone": "+70660983810"}
0005432202995	EA9A04	1951 956175	ROMAN BARANOV	{"phone": "+70030029761"}
0005432202996	66B1DC	9338 860691	EVGENIYA SERGEEVA	{"email": "sergeeva-e011972@postgrespro.ru", "phone": "+70057479480"}
0005432202997	03A6DF	6849 279226	ANGELINA ANTONOVA	{"email": "antonova-angelina23051974@postgrespro.ru", "phone": "+70199052020"}
0005432202998	D7A6F8	4852 067021	LYUDMILA NOVIKOVA	{"phone": "+70215048153"}
0005432202999	93B38A	4411 013576	YULIYA DENISOVA	{"email": "denisova-yuliya011969@postgrespro.ru", "phone": "+70781725890"}
0005432203000	38B543	4765 657916	OKSANA PETROVA	{"phone": "+70037173087"}
0005432203001	38B543	0019 759052	EVGENIY SERGEEV	{"phone": "+70747162461"}
0005432203002	CED663	1070 375117	IVAN GERASIMOV	{"phone": "+70346681850"}
0005432203003	39012A	3325 342539	LYUDMILA NESTEROVA	{"email": "l_nesterova_011973@postgrespro.ru", "phone": "+70321159283"}
0005432203004	DF4D28	6312 097810	ELENA VLASOVA	{"phone": "+70420908201"}
0005432203005	EB74AD	5481 473758	OLEG KISELEV	{"email": "kiselev-oleg081979@postgrespro.ru", "phone": "+70134621676"}
0005432203006	8A94CE	1405 830311	EKATERINA SCHERBAKOVA	{"phone": "+70544936609"}
0005432203007	8CC74F	5567 722946	EKATERINA MOISEEVA	{"phone": "+70503098355"}
0005432203008	8CC74F	7124 574316	ANDREY KUZMIN	{"email": "kuzmin.a101976@postgrespro.ru", "phone": "+70299140545"}
0005432203009	91DD09	3390 003873	VALENTINA PETROVA	{"phone": "+70537758618"}
0005432203010	91DD09	5052 945966	DANIIL GRIGOREV	{"phone": "+70031253176"}
0005432203011	C05206	5154 784926	ALEKSANDR PAVLOV	{"email": "a-pavlov-021977@postgrespro.ru", "phone": "+70442001318"}
0005432203012	C05206	8849 017393	IRINA KONOVALOVA	{"phone": "+70422153490"}
0005432203013	BEC70C	2323 724152	GALINA IVANOVA	{"email": "ivanova.g.1972@postgrespro.ru", "phone": "+70128251698"}
0005432203014	B16C24	5180 301319	ANNA BELYAEVA	{"email": "belyaeva.a_20091981@postgrespro.ru", "phone": "+70088970313"}
0005432203015	CBBA5B	8555 094070	LYUBOV NIKOLAEVA	{"phone": "+70920889618"}
0005432203016	85AAAE	5666 218033	ALEKSEY FEDOROV	{"phone": "+70798885329"}
0005432203017	85AAAE	2283 991847	ELIZAVETA SOKOLOVA	{"phone": "+70097109664"}
0005432203018	85AAAE	9567 539996	VIKTOR MAKAROV	{"email": "v_makarov.111971@postgrespro.ru", "phone": "+70684199184"}
0005432203019	03B25B	0083 299868	VLADIMIR MOROZOV	{"email": "v-morozov_1980@postgrespro.ru", "phone": "+70994111142"}
0005432203020	03B25B	0575 724236	YURIY FROLOV	{"email": "yuriy-frolov-081983@postgrespro.ru", "phone": "+70761505651"}
0005432203021	03B25B	4876 596011	ALEKSANDR ALEKSANDROV	{"phone": "+70589069174"}
0005432203022	112DE0	4305 829857	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.121983@postgrespro.ru", "phone": "+70198797735"}
0005432203023	112DE0	1704 994126	YURIY KONOVALOV	{"phone": "+70913602809"}
0005432203024	5F2BFD	8616 892407	VLADIMIR PETROV	{"phone": "+70928053800"}
0005432203025	02094F	8402 093422	ALEKSEY SEMENOV	{"phone": "+70171737804"}
0005432203026	CF13D8	1693 879797	NIKOLAY SIDOROV	{"email": "sidorov_n_021973@postgrespro.ru", "phone": "+70591619526"}
0005432203027	2E68DD	2683 513278	OLGA SIDOROVA	{"phone": "+70757654050"}
0005432203028	F12B98	3481 900759	VIKTORIYA STEPANOVA	{"email": "viktoriya-stepanova-20031972@postgrespro.ru", "phone": "+70388965855"}
0005432203029	BA489D	5202 125034	ZOYA KOZLOVA	{"email": "kozlova-zoya.1971@postgrespro.ru", "phone": "+70766412503"}
0005432203030	F4E5A9	8913 763660	ARTEM IVANOV	{"email": "ivanovartem-1985@postgrespro.ru", "phone": "+70416260232"}
0005432203031	633723	4074 260339	EVGENIY SEMENOV	{"phone": "+70742977174"}
0005432203032	305C34	4601 437116	KSENIYA NIKITINA	{"email": "nikitina_kseniya1986@postgrespro.ru", "phone": "+70693872703"}
0005432203033	305C34	6843 179473	NATALYA KONDRATEVA	{"email": "kondrateva.n-1982@postgrespro.ru", "phone": "+70232063520"}
0005432203034	6F50D4	3335 650170	VLADIMIR KUZNECOV	{"phone": "+70184570109"}
0005432203035	5D9083	8119 286392	LYUBOV EFREMOVA	{"phone": "+70267165867"}
0005432203036	4EE1A1	7431 031535	PAVEL GRIGOREV	{"email": "grigorev_pavel.111970@postgrespro.ru", "phone": "+70260474966"}
0005432203037	161A34	3301 691497	EKATERINA YAKOVLEVA	{"email": "yakovleva.ekaterina-1965@postgrespro.ru", "phone": "+70402091269"}
0005432203038	A52C90	2113 404184	LYUDMILA NESTEROVA	{"email": "lyudmila.nesterova_20111964@postgrespro.ru", "phone": "+70413104219"}
0005432203039	6F307E	9137 385015	NIKOLAY MOROZOV	{"email": "morozovnikolay-061972@postgrespro.ru", "phone": "+70050599495"}
0005432203040	9F38D6	5776 147918	SERGEY ABRAMOV	{"email": "sabramov-051975@postgrespro.ru", "phone": "+70932704784"}
0005432203041	00FCC9	8781 760743	TATYANA NIKOLAEVA	{"email": "nikolaeva.tatyana1963@postgrespro.ru", "phone": "+70840210940"}
0005432203042	ADFADB	6710 740542	VLADIMIR DMITRIEV	{"email": "v.dmitriev_13091978@postgrespro.ru", "phone": "+70166765275"}
0005432203043	F22350	1689 069498	VALENTINA NAUMOVA	{"email": "naumova_v-1959@postgrespro.ru", "phone": "+70195921904"}
0005432203044	AF9875	1143 354376	TAMARA MAKSIMOVA	{"email": "t.maksimova_071977@postgrespro.ru", "phone": "+70684406714"}
0005432203045	1AAA77	5869 904076	VLADIMIR SIDOROV	{"phone": "+70559503552"}
0005432203046	673BE3	7508 375744	ELINA OSIPOVA	{"phone": "+70933111340"}
0005432203047	96334D	0685 253853	ALFIYA POLYAKOVA	{"phone": "+70045009461"}
0005432203048	035A6E	6680 391720	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr.28101976@postgrespro.ru", "phone": "+70864991897"}
0005432203049	6475AB	5467 864447	EGOR MATVEEV	{"email": "e.matveev.1973@postgrespro.ru", "phone": "+70434680572"}
0005432203050	6475AB	5370 803135	ALEVTINA NIKIFOROVA	{"email": "alevtinanikiforova_30121963@postgrespro.ru", "phone": "+70139347808"}
0005432203051	6475AB	8479 496893	YURIY DAVYDOV	{"phone": "+70959087298"}
0005432203052	9FA9D5	0159 207197	VALERIY PETROV	{"phone": "+70835353319"}
0005432203053	1AD5C7	7073 823300	ANDREY SHEVCHENKO	{"phone": "+70869132436"}
0005432203054	57D19C	7331 537668	TAMARA EGOROVA	{"email": "tamara-egorova16091983@postgrespro.ru", "phone": "+70682273315"}
0005432203055	2E75B4	5695 963128	VLADIMIR GRIGOREV	{"email": "grigorev_vladimir-041968@postgrespro.ru", "phone": "+70428436083"}
0005432203056	2E75B4	4277 560181	SVETLANA BARANOVA	{"phone": "+70823965201"}
0005432203057	EDBFCA	0672 330706	DMITRIY SOKOLOV	{"phone": "+70364426504"}
0005432203058	B51A28	8130 328698	VIKTORIYA NIKOLAEVA	{"email": "viktoriya_nikolaeva21061962@postgrespro.ru", "phone": "+70621277784"}
0005432203059	B51A28	7877 561436	TATYANA YAKOVLEVA	{"email": "tatyana-yakovleva_02091965@postgrespro.ru", "phone": "+70617526907"}
0005432203060	6B7D9E	4671 042065	ELENA FOMINA	{"email": "efomina.111974@postgrespro.ru", "phone": "+70225184300"}
0005432203061	661E67	1553 454209	VALENTINA KULIKOVA	{"email": "kulikova.valentina.17101977@postgrespro.ru", "phone": "+70663463666"}
0005432203062	661E67	3879 033713	ANNA VASILEVA	{"email": "a-vasileva-081976@postgrespro.ru", "phone": "+70567441756"}
0005432203063	416B71	1134 397478	VIKTOR SEMENOV	{"email": "semenov.v-021972@postgrespro.ru", "phone": "+70241665795"}
0005432203064	3B127F	2139 436379	IRINA DMITRIEVA	{"email": "irinadmitrieva_111973@postgrespro.ru", "phone": "+70042465066"}
0005432203065	3B127F	9688 106977	TAMARA CHERNOVA	{"phone": "+70483986397"}
0005432203066	3B127F	6001 702479	VERONIKA POPOVA	{"email": "veronikapopova-30081968@postgrespro.ru", "phone": "+70232582207"}
0005432203067	3B127F	0549 524431	ELENA FROLOVA	{"phone": "+70204113934"}
0005432203068	09D332	5850 793146	MARIYA POLYAKOVA	{"phone": "+70514684940"}
0005432203069	09D332	6447 855705	DANIIL ANDREEV	{"phone": "+70119519278"}
0005432203070	1D4C0B	5749 095586	TATYANA KOLESNIKOVA	{"email": "kolesnikova-tatyana24101977@postgrespro.ru", "phone": "+70041515782"}
0005432203071	1D4C0B	7007 139316	ANATOLIY SMIRNOV	{"phone": "+70338944308"}
0005432203072	39A81D	1163 481561	MARIYA DENISOVA	{"phone": "+70387335952"}
0005432203073	8CC606	3059 289710	VALENTINA YAKOVLEVA	{"phone": "+70906363353"}
0005432203074	F19E3E	1355 514919	NATALYA NESTEROVA	{"phone": "+70440306021"}
0005432203075	04E41B	4657 173977	VIKTOR ANDREEV	{"email": "andreev-v.101969@postgrespro.ru", "phone": "+70058972753"}
0005432203076	04E41B	3459 276028	IVAN KOROLEV	{"email": "korolev.i25051980@postgrespro.ru", "phone": "+70260480517"}
0005432203077	559A78	2399 580217	ANNA FOMINA	{"email": "anna-fomina_1981@postgrespro.ru", "phone": "+70115693462"}
0005432203078	CCB227	7605 807110	LYUDMILA KUZMINA	{"phone": "+70468382452"}
0005432203079	CCB227	8336 445676	MIKHAIL KUDRYASHOV	{"email": "kudryashov.mikhail_1989@postgrespro.ru", "phone": "+70064401011"}
0005432203080	DF077E	7654 252315	INESSA MARTYNOVA	{"phone": "+70533225317"}
0005432203081	4FD182	0447 930040	ALEKSEY NIKITIN	{"email": "nikitinaleksey_1987@postgrespro.ru", "phone": "+70925493886"}
0005432203082	62AA85	7920 627063	VALENTINA DANILOVA	{"phone": "+70393548682"}
0005432203083	70C1DA	4320 075074	VLADIMIR ANTONOV	{"email": "antonov_v1961@postgrespro.ru", "phone": "+70483524238"}
0005432203084	0E5E45	9706 010789	NIKOLAY MATVEEV	{"phone": "+70380235691"}
0005432203085	90653E	0288 661551	SVETLANA SOROKINA	{"phone": "+70580550399"}
0005432203086	CF150B	6982 930241	ALEKSANDR MOROZOV	{"email": "morozov-a18101964@postgrespro.ru", "phone": "+70292690390"}
0005432203087	CF150B	4603 091790	ALEKSANDRA SMIRNOVA	{"phone": "+70493748994"}
0005432203088	31979D	3197 884510	NIKOLAY FOMIN	{"phone": "+70283860733"}
0005432203089	96C7F9	0313 659312	ALEKSEY ZHUKOV	{"phone": "+70813722747"}
0005432203090	1FDF85	1779 227279	IRINA SEMENOVA	{"email": "i-semenova_021969@postgrespro.ru", "phone": "+70761504065"}
0005432203091	1BDC81	1123 766508	SERGEY KUZNECOV	{"email": "kuznecov.sergey.26011975@postgrespro.ru", "phone": "+70138837683"}
0005432203092	1BDC81	3960 749084	ROMAN GAVRILOV	{"email": "gavrilov_roman-16051964@postgrespro.ru", "phone": "+70579554065"}
0005432203093	1BDC81	2935 746761	FEDOR OSIPOV	{"email": "osipov.f1975@postgrespro.ru", "phone": "+70632118684"}
0005432203094	729315	8825 374683	ZHANNA KUDRYASHOVA	{"phone": "+70194517374"}
0005432203095	650F44	6871 046366	ANASTASIYA ALEKSEEVA	{"phone": "+70631220172"}
0005432203096	28FDBC	1039 690665	SERGEY GRIGOREV	{"email": "grigorev_sergey20111968@postgrespro.ru", "phone": "+70474341314"}
0005432203097	5BB4D6	2553 189172	NATALYA KUZNECOVA	{"email": "n-kuznecova.29011972@postgrespro.ru", "phone": "+70095777115"}
0005432203098	E21D8E	5425 990480	NADEZHDA PAVLOVA	{"email": "pavlova_n_1971@postgrespro.ru", "phone": "+70765510218"}
0005432203099	69A4EB	8952 089360	DMITRIY MOROZOV	{"phone": "+70088831480"}
0005432203100	0EA6FE	4696 077106	MARIYA BELYAEVA	{"email": "belyaevam_10031964@postgrespro.ru", "phone": "+70748051700"}
0005432203101	0EA6FE	1150 828612	DMITRIY SOROKIN	{"phone": "+70312705616"}
0005432203102	5F2482	7770 653904	GERMAN KRASNOV	{"email": "krasnovgerman1971@postgrespro.ru", "phone": "+70578357336"}
0005432203103	5F2482	1646 313134	DARYA ZHUKOVA	{"phone": "+70490785322"}
0005432203104	052A66	3081 533272	EKATERINA BELOVA	{"phone": "+70873332761"}
0005432203105	E9224D	2825 705886	YULIYA SAVELEVA	{"email": "saveleva.y-1987@postgrespro.ru", "phone": "+70712392642"}
0005432203106	E9224D	8367 860550	NINA ALEKSEEVA	{"email": "n-alekseeva.20011964@postgrespro.ru", "phone": "+70559179369"}
0005432203107	48AAD7	6912 930993	EKATERINA ILINA	{"email": "ilina.ekaterina.22121975@postgrespro.ru", "phone": "+70641926582"}
0005432203108	48AAD7	2061 132320	LEONID GORBUNOV	{"email": "gorbunov.leonid_1972@postgrespro.ru", "phone": "+70296485816"}
0005432203109	CBCE58	2155 402110	OLGA KONDRATEVA	{"email": "kondrateva.o17031970@postgrespro.ru", "phone": "+70714702261"}
0005432203110	CBCE58	7316 456979	DMITRIY BARANOV	{"phone": "+70259170356"}
0005432203111	9DF0A2	8338 012196	VALENTINA KOMAROVA	{"phone": "+70989845628"}
0005432203112	9DF0A2	3266 932614	SVETLANA FOMINA	{"email": "svetlana.fomina.1972@postgrespro.ru", "phone": "+70805699011"}
0005432203113	B77393	8643 130641	STANISLAV DAVYDOV	{"phone": "+70686463900"}
0005432203114	B4B49C	3598 149597	SVETLANA KOVALEVA	{"email": "svetlanakovaleva1978@postgrespro.ru", "phone": "+70050142838"}
0005432203115	722985	8835 533946	ALEKSANDR NIKOLAEV	{"phone": "+70939763318"}
0005432203116	92AA24	4662 448339	EGOR TIKHONOV	{"email": "tikhonov_e-16051982@postgrespro.ru", "phone": "+70099989683"}
0005432203117	92AA24	0359 280814	ALEKSEY KUZMIN	{"phone": "+70495308615"}
0005432203118	BC6EB5	9612 228782	IRINA SMIRNOVA	{"phone": "+70509274179"}
0005432203119	BC6EB5	2692 481632	NATALYA ANDREEVA	{"email": "n_andreeva_14031970@postgrespro.ru", "phone": "+70753721432"}
0005432203179	10E032	3921 362057	DENIS MIKHAYLOV	{"phone": "+70369085886"}
0005432203120	E3D027	5145 083746	SVETLANA GERASIMOVA	{"email": "gerasimovasvetlana.1966@postgrespro.ru", "phone": "+70645005460"}
0005432203121	5B9409	6748 180201	RAISA GERASIMOVA	{"phone": "+70919542265"}
0005432203122	C2EB6C	6475 205690	TATYANA NOVIKOVA	{"email": "novikovatatyana.29111970@postgrespro.ru", "phone": "+70016744921"}
0005432203123	05A110	4756 494049	PETR KUZNECOV	{"phone": "+70353041261"}
0005432203124	18D311	6846 250842	NINA ZAYCEVA	{"phone": "+70894584180"}
0005432203125	18D311	3276 407734	TATYANA OSIPOVA	{"phone": "+70519081982"}
0005432203126	18D311	9284 520966	NATALYA NOVIKOVA	{"phone": "+70041467310"}
0005432203127	62C252	2108 315731	ELENA SMIRNOVA	{"email": "e-smirnova-091977@postgrespro.ru", "phone": "+70637734700"}
0005432203128	62C252	1543 810925	SERGEY KAZAKOV	{"email": "kazakovs.1983@postgrespro.ru", "phone": "+70189636398"}
0005432203129	D202D0	4575 560263	SERGEY EGOROV	{"phone": "+70938490623"}
0005432203130	B7F626	5004 363047	ANDREY FROLOV	{"phone": "+70002816293"}
0005432203131	69EF69	7602 186650	NINA NIKOLAEVA	{"phone": "+70010029969"}
0005432203132	740A07	9117 664073	LYUBOV ARKHIPOVA	{"email": "l.arkhipova-20061975@postgrespro.ru", "phone": "+70203010246"}
0005432203133	E2169E	5251 081059	SERGEY SOROKIN	{"email": "s-sorokin_1967@postgrespro.ru", "phone": "+70076650100"}
0005432203134	8FF5AE	9777 112978	SERGEY KUZNECOV	{"email": "s-kuznecov-091972@postgrespro.ru", "phone": "+70197020074"}
0005432203135	CDAB04	7474 609041	STANISLAV ALEKSANDROV	{"phone": "+70081715045"}
0005432203136	60EB25	2828 026839	LYUBOV ZHUKOVA	{"phone": "+70498854534"}
0005432203137	1D25B6	9282 482744	EVGENIYA FOMINA	{"phone": "+70131250970"}
0005432203138	3A3CDB	6545 615656	LYUDMILA MIRONOVA	{"phone": "+70268692657"}
0005432203139	883CBA	7367 790687	GALINA KULIKOVA	{"phone": "+70658143826"}
0005432203140	CF1CFC	3092 588398	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr.1982@postgrespro.ru", "phone": "+70237986838"}
0005432203141	CF1CFC	0107 299591	VYACHESLAV ZAKHAROV	{"email": "zakharov_vyacheslav.1960@postgrespro.ru", "phone": "+70077182341"}
0005432203142	8631EB	5535 573023	ARINA SMIRNOVA	{"phone": "+70263114112"}
0005432203143	8631EB	8410 112200	ANDREY MEDVEDEV	{"email": "andrey.medvedev-111966@postgrespro.ru", "phone": "+70547340687"}
0005432203144	D7FE54	4325 811105	EVGENIYA KOROLEVA	{"phone": "+70052040706"}
0005432203145	C21FE6	2345 311716	GALINA SERGEEVA	{"email": "g_sergeeva011971@postgrespro.ru", "phone": "+70152292681"}
0005432203146	EC7024	8923 727801	VLADISLAV BELOV	{"phone": "+70913792061"}
0005432203147	7BD3EC	9834 358930	PAVEL NIKOLAEV	{"email": "nikolaev_pavel011972@postgrespro.ru", "phone": "+70045094110"}
0005432203148	7BD3EC	9455 098343	YURIY SEMENOV	{"email": "yuriy_semenov.01021964@postgrespro.ru", "phone": "+70633362853"}
0005432203149	287BC9	4659 696235	SERGEY ZHUKOV	{"phone": "+70418055130"}
0005432203150	718EAF	6550 638169	ANASTASIYA NESTEROVA	{"email": "anastasiyanesterova_01121971@postgrespro.ru", "phone": "+70869432322"}
0005432203151	6CD8F9	1204 247201	VERA ORLOVA	{"email": "v_orlova.1973@postgrespro.ru", "phone": "+70142050002"}
0005432203152	BCFE3C	7394 844525	ALEKSANDRA SEMENOVA	{"email": "semenova.aleksandra-021979@postgrespro.ru", "phone": "+70181314099"}
0005432203153	BCFE3C	1751 724177	MARINA IVANOVA	{"email": "marina-ivanova.021976@postgrespro.ru", "phone": "+70604824570"}
0005432203154	7AFB2F	6857 260940	KONSTANTIN NOVIKOV	{"email": "k_novikov.1963@postgrespro.ru", "phone": "+70523332450"}
0005432203155	91130C	8952 401275	ANASTASIYA KAZAKOVA	{"phone": "+70220028952"}
0005432203156	91130C	6031 436284	ALEVTINA MATVEEVA	{"email": "a.matveeva06111968@postgrespro.ru", "phone": "+70712013379"}
0005432203157	39919D	1779 640562	SERGEY ZHUKOV	{"email": "sergey-zhukov.011960@postgrespro.ru", "phone": "+70389636474"}
0005432203158	61DB97	3800 381621	NINA NESTEROVA	{"email": "nina-nesterova111976@postgrespro.ru", "phone": "+70771810086"}
0005432203159	902736	0931 966526	ANDREY ZHURAVLEV	{"email": "zhuravlev.a051986@postgrespro.ru", "phone": "+70789793680"}
0005432203160	902736	5655 713245	ANTONINA VOROBEVA	{"phone": "+70339989533"}
0005432203161	06F35E	1017 983443	VLADIMIR VASILEV	{"email": "vasilev_vladimir_1968@postgrespro.ru", "phone": "+70305517886"}
0005432203162	06F35E	5167 493608	LARISA SOKOLOVA	{"email": "sokolova_larisa_1971@postgrespro.ru", "phone": "+70339870295"}
0005432203163	C67950	9595 922330	VIKTOR OSIPOV	{"phone": "+70828090631"}
0005432203164	3BE34B	2586 598928	VITALIY CHERNOV	{"email": "vitaliy-chernov-1969@postgrespro.ru", "phone": "+70309778947"}
0005432203165	3BE34B	3957 776982	GALINA SMIRNOVA	{"email": "smirnova_g-121975@postgrespro.ru", "phone": "+70791984920"}
0005432203166	BE3691	0791 410270	SERGEY RODIONOV	{"phone": "+70151744804"}
0005432203167	0A1350	9277 401837	YURIY STEPANOV	{"phone": "+70148917864"}
0005432203168	BFB2AB	5748 921378	ARTUR IVANOV	{"phone": "+70408728694"}
0005432203169	C8C084	2741 685428	VLADIMIR RODIONOV	{"email": "rodionov-v-121970@postgrespro.ru", "phone": "+70609198293"}
0005432203170	C8C084	5046 558453	KSENIYA GERASIMOVA	{"email": "kseniyagerasimova-18041977@postgrespro.ru", "phone": "+70858514080"}
0005432203171	D9C403	8395 488891	TATYANA POPOVA	{"email": "t-popova_1968@postgrespro.ru", "phone": "+70215409979"}
0005432203172	D9C403	0500 006875	KLARA BARANOVA	{"email": "k_baranova-051971@postgrespro.ru", "phone": "+70508733724"}
0005432203173	79ED5F	6697 456358	ANATOLIY ZHURAVLEV	{"phone": "+70616139733"}
0005432203174	501A2D	7771 616316	TATYANA ANDREEVA	{"email": "tatyana_andreeva.031980@postgrespro.ru", "phone": "+70411328379"}
0005432203175	709BEB	1630 724360	IRINA ANDREEVA	{"email": "irina_andreeva-1957@postgrespro.ru", "phone": "+70593735775"}
0005432203176	92A33A	5036 221928	POLINA MAKAROVA	{"email": "pmakarova.081973@postgrespro.ru", "phone": "+70589254048"}
0005432203177	E521BA	5287 035122	ALEKSANDR PAVLOV	{"phone": "+70040647459"}
0005432203178	914044	7489 911535	ARTEM NIKITIN	{"phone": "+70026947015"}
0005432203180	19A12C	1130 854764	ANATOLIY ALEKSANDROV	{"email": "anatoliyaleksandrov_1978@postgrespro.ru", "phone": "+70019339352"}
0005432203181	19A12C	5004 296732	IVAN BARANOV	{"email": "ivan.baranov-1970@postgrespro.ru", "phone": "+70790936632"}
0005432203182	51FBC7	4178 250270	DARYA DAVYDOVA	{"email": "daryadavydova_23111967@postgrespro.ru", "phone": "+70132604253"}
0005432203183	84E822	5276 754378	MARYAM KRASNOVA	{"phone": "+70258135362"}
0005432203184	84E822	6706 880356	NATALYA GORBUNOVA	{"phone": "+70398598590"}
0005432203185	E8241D	2462 931743	STANISLAV ANDREEV	{"phone": "+70910873165"}
0005432203186	E8241D	7650 104109	GRIGORIY PETROV	{"phone": "+70261903585"}
0005432203187	7637E7	9140 996869	DMITRIY IVANOV	{"email": "dmitriyivanov-041972@postgrespro.ru", "phone": "+70696222013"}
0005432203188	7637E7	0792 481352	NATALYA NIKOLAEVA	{"phone": "+70296776468"}
0005432203189	12478C	8364 627418	MARIYA LEBEDEVA	{"email": "mariya_lebedeva_1964@postgrespro.ru", "phone": "+70644235093"}
0005432203190	D9B00A	6451 355158	ELIZAVETA FOMINA	{"email": "fomina.e-1957@postgrespro.ru", "phone": "+70145938346"}
0005432203191	5CC117	7514 621298	SERGEY ILIN	{"email": "sergey_ilin_061967@postgrespro.ru", "phone": "+70784746767"}
0005432203192	5CC117	8447 828647	NAIL SOKOLOV	{"email": "n-sokolov-15011964@postgrespro.ru", "phone": "+70456833210"}
0005432203193	90BCB3	5981 789818	VALENTINA IVANOVA	{"phone": "+70684852086"}
0005432203194	29E3A9	9242 889723	TAISIYA ZAYCEVA	{"phone": "+70037846120"}
0005432203195	EF391C	0533 332626	DENIS ISAEV	{"email": "d-isaev_071958@postgrespro.ru", "phone": "+70647495196"}
0005432203196	C098B7	5600 667725	KIRILL ZHURAVLEV	{"phone": "+70318131202"}
0005432203197	C098B7	7356 099708	VIKTOR CHERNOV	{"phone": "+70930128821"}
0005432203198	C098B7	2381 205616	SERGEY MIKHAYLOV	{"phone": "+70734130086"}
0005432203199	D60263	1467 797297	SVETLANA DAVYDOVA	{"email": "svetlanadavydova091969@postgrespro.ru", "phone": "+70892616745"}
0005432203200	3F25A8	6213 658565	IRINA DMITRIEVA	{"phone": "+70661615071"}
0005432203201	943B4D	7251 239686	VALERIY FEDOTOV	{"phone": "+70764622911"}
0005432203202	09C0B0	7919 040401	GALINA PAVLOVA	{"email": "pavlova.g1986@postgrespro.ru", "phone": "+70676267589"}
0005432203203	09C0B0	4494 812515	MARINA OVCHINNIKOVA	{"email": "marina_ovchinnikova-06071973@postgrespro.ru", "phone": "+70789393811"}
0005432203204	7B834D	6951 555113	ANDREY KARPOV	{"phone": "+70762319098"}
0005432203205	7B834D	2978 251479	DMITRIY STEPANOV	{"phone": "+70915633227"}
0005432203206	BF3FCF	3906 484061	SERGEY VASILEV	{"email": "s_vasilev_071980@postgrespro.ru", "phone": "+70547310841"}
0005432203207	BF3FCF	1328 822123	ELENA YAKOVLEVA	{"phone": "+70166555701"}
0005432203208	623DB7	3091 711543	DMITRIY SOKOLOV	{"phone": "+70854454922"}
0005432203209	623DB7	9772 434467	TAMARA OSIPOVA	{"email": "osipova_t1968@postgrespro.ru", "phone": "+70846544824"}
0005432203210	649A85	1226 180379	MAKSIM SIDOROV	{"email": "m_sidorov13101968@postgrespro.ru", "phone": "+70691715677"}
0005432203211	E0C85A	9705 026417	SERGEY KULIKOV	{"phone": "+70047054774"}
0005432203212	E0C85A	7178 038744	MAKSIM PETROV	{"email": "petrovmaksim_26091971@postgrespro.ru", "phone": "+70461453897"}
0005432203213	155188	5199 502125	NADEZHDA MIRONOVA	{"email": "n_mironova25031970@postgrespro.ru", "phone": "+70922860887"}
0005432203214	222650	5377 387955	ALEKSEY DMITRIEV	{"email": "a-dmitriev29091972@postgrespro.ru", "phone": "+70671804827"}
0005432203215	222650	6885 283200	ANATOLIY FOMIN	{"phone": "+70139274000"}
0005432203216	6F3F81	8409 996321	SERGEY ZHURAVLEV	{"phone": "+70605952966"}
0005432203217	6F3F81	0473 685493	PAVEL FOMIN	{"email": "pavel_fomin_071965@postgrespro.ru", "phone": "+70272699211"}
0005432203218	6F3F81	2372 219029	PAVEL ANTONOV	{"phone": "+70098575707"}
0005432203219	14B1E6	3219 562700	YANA EFIMOVA	{"email": "efimova_y-1968@postgrespro.ru", "phone": "+70997513357"}
0005432203220	14B1E6	5342 687253	TAISIYA KOROLEVA	{"phone": "+70736119358"}
0005432203221	509F7F	1215 138042	GENNADIY FEDOTOV	{"email": "gfedotov.1974@postgrespro.ru", "phone": "+70056763166"}
0005432203222	509F7F	7858 747520	DMITRIY MOROZOV	{"phone": "+70396589616"}
0005432203223	243D7A	4266 853368	VERA ZHURAVLEVA	{"email": "v.zhuravleva_24051960@postgrespro.ru", "phone": "+70850542943"}
0005432203224	243D7A	5564 009047	SERGEY TIKHONOV	{"phone": "+70479198024"}
0005432203225	6E2A75	4313 646954	ELMIRA NAUMOVA	{"email": "naumova-elmira.04111979@postgrespro.ru", "phone": "+70564380751"}
0005432203226	6E2A75	5603 823237	ADELINA POLYAKOVA	{"phone": "+70316289294"}
0005432203227	EF4009	7136 090700	NINA MATVEEVA	{"email": "matveeva-nina1974@postgrespro.ru", "phone": "+70917206889"}
0005432203228	44C3EE	5989 433240	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov101977@postgrespro.ru", "phone": "+70167864477"}
0005432203229	27281D	3716 899448	VYACHESLAV STEPANOV	{"email": "vyacheslav.stepanov-07021969@postgrespro.ru", "phone": "+70182156013"}
0005432203230	48FACD	7765 672885	DIANA IVANOVA	{"email": "ivanova_diana091983@postgrespro.ru", "phone": "+70072461571"}
0005432203231	CBC907	4224 869628	SERGEY GERASIMOV	{"email": "gerasimovs.30011980@postgrespro.ru", "phone": "+70490592458"}
0005432203232	CBC907	9411 931891	PAVEL MIRONOV	{"email": "p-mironov-111970@postgrespro.ru", "phone": "+70549699254"}
0005432203233	E5F69F	2062 810933	OLEG CHERNOV	{"email": "ochernov-14091968@postgrespro.ru", "phone": "+70802884215"}
0005432203234	E5F69F	9341 566986	SVETLANA TROFIMOVA	{"email": "trofimova.s-051988@postgrespro.ru", "phone": "+70166426588"}
0005432203235	7510A2	5280 862455	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr10041968@postgrespro.ru", "phone": "+70851723279"}
0005432203236	7510A2	0969 631537	ILDAR BELOV	{"phone": "+70692144434"}
0005432203237	C65C32	0376 544078	RUSLAN ZHURAVLEV	{"phone": "+70976041778"}
0005432203238	CC7883	9101 751803	PAVEL KONOVALOV	{"email": "konovalov_p_1969@postgrespro.ru", "phone": "+70819556997"}
0005432203239	65F9FE	3312 383958	NIKOLAY ISAEV	{"phone": "+70633598093"}
0005432203240	65F9FE	3046 392418	EKATERINA PETROVA	{"phone": "+70642529718"}
0005432203241	65F9FE	5566 991247	NINA KUZNECOVA	{"email": "kuznecova.nina.1970@postgrespro.ru", "phone": "+70866214238"}
0005432203242	036E20	4428 164377	VIKTOR ALEKSANDROV	{"email": "v.aleksandrov-02071968@postgrespro.ru", "phone": "+70089670873"}
0005432203243	036E20	3145 929857	VALENTINA ROMANOVA	{"phone": "+70376104545"}
0005432203244	036E20	8807 032259	NATALYA NESTEROVA	{"phone": "+70429575874"}
0005432203245	69F07B	0956 614790	ANASTASIYA MEDVEDEVA	{"email": "a_medvedeva-091966@postgrespro.ru", "phone": "+70897532283"}
0005432203246	69F07B	1485 000017	GALINA TITOVA	{"phone": "+70824137329"}
0005432203247	A7E1CD	5722 049009	ANTONINA FILIPPOVA	{"email": "a_filippova_1973@postgrespro.ru", "phone": "+70611746100"}
0005432203248	B6048D	0572 268206	LYUBOV IVANOVA	{"phone": "+70046873766"}
0005432203249	B6048D	5177 086053	VITALIY ORLOV	{"email": "orlov-v_08061972@postgrespro.ru", "phone": "+70935593517"}
0005432203250	104ADA	9618 567482	DARYA SOROKINA	{"email": "sorokina_d.07061980@postgrespro.ru", "phone": "+70596878459"}
0005432203251	104ADA	7267 260112	ROMAN STEPANOV	{"phone": "+70487065576"}
0005432203252	6449B1	5913 971826	KSENIYA MOROZOVA	{"email": "morozova.kseniya_08081969@postgrespro.ru", "phone": "+70628817733"}
0005432203253	6449B1	4777 391560	ANDREY SEMENOV	{"email": "andrey-semenov-1978@postgrespro.ru", "phone": "+70466532831"}
0005432203254	9C0EA3	0485 481370	DIANA EFIMOVA	{"phone": "+70346728404"}
0005432203255	9C0EA3	4284 574950	VALENTINA VASILEVA	{"email": "valentina-vasileva.1968@postgrespro.ru", "phone": "+70805227479"}
0005432203256	9C0EA3	8223 230533	PAVEL ANDREEV	{"phone": "+70157511449"}
0005432203257	9885FC	6581 752410	MAKSIM POPOV	{"phone": "+70883623722"}
0005432203258	9885FC	1863 966612	VLADISLAV KONOVALOV	{"email": "konovalov-vladislav1979@postgrespro.ru", "phone": "+70795481150"}
0005432203259	AA3A63	0231 691530	VALENTINA MOROZOVA	{"email": "morozova-v.14011973@postgrespro.ru", "phone": "+70112574224"}
0005432203260	99DF38	4781 956795	SERGEY KUZNECOV	{"email": "sergeykuznecov101977@postgrespro.ru", "phone": "+70776804174"}
0005432203261	99DF38	4418 256030	ELENA NESTEROVA	{"phone": "+70230490747"}
0005432203262	CD8E2A	0553 449923	NIKOLAY ISAEV	{"email": "nikolay.isaev-31121973@postgrespro.ru", "phone": "+70511501577"}
0005432203263	3231CA	8485 299848	YURIY POPOV	{"email": "ypopov08091982@postgrespro.ru", "phone": "+70119573643"}
0005432203264	3231CA	3530 666450	ALEKSANDR POPOV	{"email": "aleksandr.popov.1977@postgrespro.ru", "phone": "+70740494097"}
0005432203265	3231CA	6006 653016	BORIS MAKSIMOV	{"phone": "+70469466489"}
0005432203266	4578F1	1071 031600	KRISTINA FROLOVA	{"email": "kfrolova.031958@postgrespro.ru", "phone": "+70439616782"}
0005432203267	F1B106	9927 183544	LIDIYA NAZAROVA	{"phone": "+70236228839"}
0005432203268	B916DB	9461 665512	VLADIMIR SIDOROV	{"email": "v_sidorov021972@postgrespro.ru", "phone": "+70704690020"}
0005432203269	DAB2C3	2115 513788	MARIYA MARTYNOVA	{"email": "m-martynova01061979@postgrespro.ru", "phone": "+70377310382"}
0005432203270	3BE348	8347 170273	NINA BOGDANOVA	{"email": "nina_bogdanova-1956@postgrespro.ru", "phone": "+70594183577"}
0005432206212	992AFD	8127 399802	MARIYA MELNIKOVA	{"phone": "+70409074673"}
0005432206091	E8998C	6283 060896	ALEKSANDR SERGEEV	{"email": "a-sergeev1972@postgrespro.ru", "phone": "+70698147902"}
0005432206092	980691	3143 393894	GALINA ISAEVA	{"phone": "+70198624214"}
0005432206093	6C0FCF	5243 072223	EKATERINA MIRONOVA	{"email": "mironovae_1971@postgrespro.ru", "phone": "+70122458462"}
0005432206094	6C0FCF	3941 996325	OLGA AFANASEVA	{"phone": "+70895737894"}
0005432206095	3C6B27	0451 567345	TATYANA SOROKINA	{"email": "tatyanasorokina_021962@postgrespro.ru", "phone": "+70357246895"}
0005432206096	783865	4414 808476	ALEKSEY MAKAROV	{"phone": "+70342488258"}
0005432206097	C6E192	8106 490258	SERGEY ZAKHAROV	{"phone": "+70909435992"}
0005432206098	C6E192	1380 318879	VLADIMIR KARPOV	{"email": "karpov.vladimir061976@postgrespro.ru", "phone": "+70552003573"}
0005432206099	78A690	5383 414982	ELENA KONOVALOVA	{"phone": "+70715426295"}
0005432206100	78A690	3408 510069	KSENIYA SEMENOVA	{"phone": "+70647134820"}
0005432206213	CAD4C7	1122 081877	VIKTORIYA MIKHAYLOVA	{"phone": "+70073580438"}
0005432206101	75E9F3	2293 110450	EVGENIY TARASOV	{"email": "evgeniytarasov021970@postgrespro.ru", "phone": "+70538463044"}
0005432206102	A3F0C8	8685 132987	ANNA SIDOROVA	{"email": "anna-sidorova-03111967@postgrespro.ru", "phone": "+70789056996"}
0005432206103	DACF9F	8298 968198	ELENA IVANOVA	{"phone": "+70734465313"}
0005432206104	1469AE	9582 708770	NINA NIKOLAEVA	{"email": "nina_nikolaeva08061970@postgrespro.ru", "phone": "+70334669446"}
0005432206105	6706BA	4993 047961	NATALYA MALYSHEVA	{"email": "natalyamalysheva071975@postgrespro.ru", "phone": "+70690477307"}
0005432206106	E36D1E	0905 925488	NINA NOVIKOVA	{"phone": "+70967908223"}
0005432206107	1AB2DB	8717 022409	ERIK PAVLOV	{"email": "epavlov_28011975@postgrespro.ru", "phone": "+70610014711"}
0005432206108	96F672	6383 016098	LIDIYA NESTEROVA	{"phone": "+70394529573"}
0005432206109	96F672	2092 600298	ELENA BARANOVA	{"email": "baranova-elena-011973@postgrespro.ru", "phone": "+70789210142"}
0005432206110	C663D7	8610 012227	ARSENIY STEPANOV	{"email": "a.stepanov_071964@postgrespro.ru", "phone": "+70775917505"}
0005432206111	93C2DA	4992 495233	VALENTINA PETROVA	{"email": "petrova_valentina.1964@postgrespro.ru", "phone": "+70959391916"}
0005432206112	4A2A27	2142 225811	AYRAT MAKAROV	{"phone": "+70544307881"}
0005432206113	A8C42C	4991 819283	MARGARITA IVANOVA	{"email": "m.ivanova-051962@postgrespro.ru", "phone": "+70320481911"}
0005432206114	B92B03	1322 414971	SAID RODIONOV	{"email": "rodionov_said_1967@postgrespro.ru", "phone": "+70555094593"}
0005432206115	94C2DF	9507 213819	ALEKSANDR POPOV	{"phone": "+70713078297"}
0005432206116	8D9668	3479 362225	DMITRIY EGOROV	{"phone": "+70857373005"}
0005432206117	89A595	3199 640679	YULIYA BORISOVA	{"email": "borisova-y_011979@postgrespro.ru", "phone": "+70840061176"}
0005432206118	AF5715	9540 996763	OLEG NIKOLAEV	{"email": "nikolaev.oleg.1971@postgrespro.ru", "phone": "+70148727361"}
0005432206119	AF5715	2599 655619	EVGENIY GAVRILOV	{"phone": "+70333903121"}
0005432206120	03B04F	3999 051014	YAROSLAV SCHERBAKOV	{"phone": "+70307113362"}
0005432206121	03B04F	8548 913414	VLADIMIR NIKOLAEV	{"email": "vnikolaev.23041967@postgrespro.ru", "phone": "+70700178617"}
0005432206122	066160	6279 066757	STANISLAV KISELEV	{"phone": "+70496674240"}
0005432206123	F9904C	4322 154621	ALLA GORBUNOVA	{"email": "gorbunovaalla-1969@postgrespro.ru", "phone": "+70303668102"}
0005432206124	0032A3	9603 732614	TATYANA FROLOVA	{"email": "frolova-t_1967@postgrespro.ru", "phone": "+70190238991"}
0005432206125	0032A3	4244 098162	BORIS ABRAMOV	{"phone": "+70955310368"}
0005432206126	596F57	5111 252123	DANIL NOVIKOV	{"phone": "+70523654606"}
0005432206127	596F57	1838 817914	IRINA VOROBEVA	{"email": "irina_vorobeva.15071973@postgrespro.ru", "phone": "+70524365246"}
0005432206128	EAB898	5779 600955	GALINA GAVRILOVA	{"email": "g.gavrilova_101966@postgrespro.ru", "phone": "+70838993109"}
0005432206129	3BB60E	5112 218777	ALEKSANDR KUZMIN	{"phone": "+70261557505"}
0005432206130	75CB30	2156 147619	ALEKSANDR FROLOV	{"phone": "+70548548260"}
0005432206131	88BA1F	2334 167311	TATYANA MIKHAYLOVA	{"phone": "+70991547815"}
0005432206132	88BA1F	2935 961608	NINA LAZAREVA	{"email": "nina.lazareva28091975@postgrespro.ru", "phone": "+70376039655"}
0005432206133	49D704	7905 280483	LYUDMILA NIKOLAEVA	{"email": "l_nikolaeva_24101972@postgrespro.ru", "phone": "+70636757488"}
0005432206134	49D704	2328 568514	ARINA FEDOROVA	{"phone": "+70274449698"}
0005432206135	30B757	8981 656743	ALBINA KRASNOVA	{"phone": "+70298215328"}
0005432206136	402998	0858 565083	EKATERINA CHERNOVA	{"phone": "+70724432514"}
0005432206137	402998	7826 398412	SERGEY FILIPPOV	{"email": "filippov_sergey-20101975@postgrespro.ru", "phone": "+70161606470"}
0005432206138	402998	5063 894581	OKSANA LEBEDEVA	{"email": "lebedeva.oksana-05021971@postgrespro.ru", "phone": "+70849478483"}
0005432206139	402998	0156 570783	NATALYA PAVLOVA	{"email": "pavlova.n_01101966@postgrespro.ru", "phone": "+70789601309"}
0005432206140	468B22	1860 305100	NAIL VOROBEV	{"email": "vorobev_n_041980@postgrespro.ru", "phone": "+70798785594"}
0005432206141	4EEF2E	5333 387659	ZAKHAR ROMANOV	{"phone": "+70378170236"}
0005432206142	4718A3	7855 757006	OLGA KOZLOVA	{"email": "kozlovaolga.1971@postgrespro.ru", "phone": "+70173958379"}
0005432206143	B8D567	1412 308730	EKATERINA KOROLEVA	{"email": "ekaterina.koroleva-10091968@postgrespro.ru", "phone": "+70790562315"}
0005432206144	B8D567	3582 774254	NADEZHDA KUZNECOVA	{"email": "nadezhda.kuznecova08021968@postgrespro.ru", "phone": "+70986109881"}
0005432206145	9953AD	7216 353347	ZAKHAR BORISOV	{"phone": "+70218205137"}
0005432206146	0EAA3B	4553 079193	ALEKSEY KULIKOV	{"phone": "+70879987324"}
0005432206147	0EAA3B	6401 339128	NATALYA ZAKHAROVA	{"phone": "+70415672820"}
0005432206148	F90314	9728 244550	VIKTOR MEDVEDEV	{"email": "vmedvedev04081973@postgrespro.ru", "phone": "+70527098297"}
0005432206149	F90314	6580 663134	TATYANA SOLOVEVA	{"phone": "+70097796519"}
0005432206150	9A9F41	2461 958260	LYUDMILA ISAEVA	{"phone": "+70712754674"}
0005432206151	C0A038	5283 818261	ALEKSANDRA ANDREEVA	{"phone": "+70910507530"}
0005432206152	BB8E12	8970 057351	ALEKSANDR GRIGOREV	{"phone": "+70636243543"}
0005432206153	BB8E12	9663 261789	IVAN KUZMIN	{"email": "kuzmini1967@postgrespro.ru", "phone": "+70011347460"}
0005432206154	C235F6	6472 699354	ANATOLIY SOROKIN	{"email": "anatoliy.sorokin_061965@postgrespro.ru", "phone": "+70841240645"}
0005432206155	C235F6	3561 657286	VIKTORIYA AKIMOVA	{"email": "akimova_v1971@postgrespro.ru", "phone": "+70561768285"}
0005432206156	2DF807	2985 246752	NINA SOKOLOVA	{"email": "sokolova-n1981@postgrespro.ru", "phone": "+70151038800"}
0005432206157	B28340	6748 629633	IVAN ANTONOV	{"email": "ivanantonov.27071979@postgrespro.ru", "phone": "+70791826829"}
0005432206158	57DAA8	9311 950209	DARYA KOLESNIKOVA	{"email": "kolesnikova-d-10051972@postgrespro.ru", "phone": "+70922115448"}
0005432206159	57DAA8	2753 288443	KSENIYA BELYAEVA	{"email": "belyaevak20021973@postgrespro.ru", "phone": "+70619762840"}
0005432206160	61C4B8	4018 271333	ALEKSANDRA MARTYNOVA	{"email": "a.martynova_17041973@postgrespro.ru", "phone": "+70341855307"}
0005432206161	6F6F85	9914 918518	GALINA BORISOVA	{"phone": "+70319162778"}
0005432206162	0181F5	1833 528383	YURIY TARASOV	{"email": "tarasovy19021978@postgrespro.ru", "phone": "+70641129540"}
0005432206163	57C406	4664 648971	SERGEY ROMANOV	{"phone": "+70587073263"}
0005432206164	38126B	3790 796836	GULFIYA FROLOVA	{"email": "frolovag_15121972@postgrespro.ru", "phone": "+70684022839"}
0005432206165	D80C7D	9754 183481	ANDREY FILIPPOV	{"email": "filippov-andrey1959@postgrespro.ru", "phone": "+70494842807"}
0005432206166	D80C7D	9829 578726	VERONIKA ZAYCEVA	{"email": "veronika-zayceva-011983@postgrespro.ru", "phone": "+70197611354"}
0005432206167	DDEBFB	1504 482525	TATYANA STEPANOVA	{"phone": "+70504520685"}
0005432206168	C22C42	6311 291708	NINA MALYSHEVA	{"email": "malysheva.nina_1968@postgrespro.ru", "phone": "+70823289518"}
0005432206169	98D221	3400 198179	DANILA KONOVALOV	{"phone": "+70023491217"}
0005432206170	98D221	0647 294914	ANASTASIYA ALEKSEEVA	{"email": "alekseeva.a-23061982@postgrespro.ru", "phone": "+70228021863"}
0005432206171	98D221	7797 350438	NINA ROMANOVA	{"email": "n.romanova02071977@postgrespro.ru", "phone": "+70090327947"}
0005432206172	7CF23A	6743 026183	MIKHAIL DAVYDOV	{"email": "m-davydov_12101976@postgrespro.ru", "phone": "+70405252541"}
0005432206173	19091A	5174 916118	VALERIY ISAEV	{"phone": "+70851585337"}
0005432206174	DCFC92	2867 530019	ALEKSANDR VLASOV	{"email": "vlasovaleksandr_20041964@postgrespro.ru", "phone": "+70927581082"}
0005432206295	C4DA16	1879 820768	MURAT TIKHONOV	{"phone": "+70738313005"}
0005432206175	DCFC92	7499 071929	VALERIY SMIRNOV	{"email": "smirnovvaleriy011971@postgrespro.ru", "phone": "+70240679872"}
0005432206176	38A59D	3051 441484	GALINA DENISOVA	{"phone": "+70155489425"}
0005432206177	328FD1	3890 871275	ALEKSANDRA ILINA	{"phone": "+70979303270"}
0005432206178	328FD1	1198 432230	NATALYA MARTYNOVA	{"email": "martynova.natalya-01011968@postgrespro.ru", "phone": "+70827349340"}
0005432206179	0E5470	4548 135300	ANDREY FOMIN	{"email": "a_fomin_071978@postgrespro.ru", "phone": "+70685843744"}
0005432206180	FA2429	3364 314690	VALENTINA PETROVA	{"phone": "+70148566685"}
0005432206181	FA2429	1484 522114	DMITRIY CHERNOV	{"phone": "+70940994983"}
0005432206182	FA2429	8688 238375	NATALYA SAVELEVA	{"email": "n_saveleva21111978@postgrespro.ru", "phone": "+70811757990"}
0005432206183	C97EC1	4581 003782	EVGENIYA ABRAMOVA	{"email": "evgeniya-abramova.051971@postgrespro.ru", "phone": "+70198524399"}
0005432206184	36BCD4	3936 891212	YURIY AFANASEV	{"phone": "+70022979878"}
0005432206185	D612F8	2416 219065	ANTONINA KARPOVA	{"phone": "+70840717259"}
0005432206186	D612F8	3683 131539	ZULFIYA GORBUNOVA	{"phone": "+70579747547"}
0005432206187	3DD8D7	4282 682045	ALEKSEY ALEKSEEV	{"phone": "+70141050340"}
0005432206188	89ACD4	0630 923398	ELISEY VASILEV	{"phone": "+70662468494"}
0005432206189	89ACD4	7437 893145	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr.1962@postgrespro.ru", "phone": "+70822714938"}
0005432206190	2D8772	3745 627184	ANDREY MIRONOV	{"email": "andrey.mironov07051979@postgrespro.ru", "phone": "+70781636608"}
0005432206191	5BF3CB	0141 454492	ANASTASIYA POLYAKOVA	{"phone": "+70341423261"}
0005432206192	5174C2	8264 079702	EKATERINA SOLOVEVA	{"email": "e-soloveva-081967@postgrespro.ru", "phone": "+70297016712"}
0005432206193	07FB60	9277 426326	LEYLA FEDOROVA	{"phone": "+70357983584"}
0005432206194	74BE3B	9621 542454	MARIYA DMITRIEVA	{"phone": "+70307872362"}
0005432206195	B0226A	1350 518963	TATYANA MELNIKOVA	{"email": "melnikova.t-051979@postgrespro.ru", "phone": "+70023803924"}
0005432206196	D28C86	9997 476631	IRINA KUZNECOVA	{"email": "irina-kuznecova-101987@postgrespro.ru", "phone": "+70249913186"}
0005432206197	D28C86	4100 392312	DMITRIY TIMOFEEV	{"email": "d.timofeev_16071974@postgrespro.ru", "phone": "+70256465112"}
0005432206198	DFF289	1195 388309	VIKTOR STEPANOV	{"phone": "+70815048518"}
0005432206199	B5AA49	1741 469395	EKATERINA POPOVA	{"email": "popova-ekaterina_25121976@postgrespro.ru", "phone": "+70825125202"}
0005432206200	B5AA49	0386 451539	OLGA BELOVA	{"email": "belova-o_05011965@postgrespro.ru", "phone": "+70806746260"}
0005432206201	89579D	9006 787197	SERGEY TARASOV	{"phone": "+70616549359"}
0005432206202	89579D	6047 674263	VLADIMIR FROLOV	{"email": "frolovvladimir_1969@postgrespro.ru", "phone": "+70254894093"}
0005432206203	9691C5	1373 673553	VALERIY GRIGOREV	{"phone": "+70970045471"}
0005432206204	9691C5	4274 375068	NADEZHDA OVCHINNIKOVA	{"email": "ovchinnikovan1986@postgrespro.ru", "phone": "+70612493083"}
0005432206205	32BFC9	7864 939326	ALEKSEY OSIPOV	{"phone": "+70702309583"}
0005432206206	DA1B4F	0282 242344	DMITRIY NIKITIN	{"email": "nikitin_dmitriy_1978@postgrespro.ru", "phone": "+70161191498"}
0005432206207	AD951D	6550 204441	ULYANA SMIRNOVA	{"email": "smirnovau.06071972@postgrespro.ru", "phone": "+70218431803"}
0005432206208	AD951D	3880 558089	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr_19041969@postgrespro.ru", "phone": "+70520582611"}
0005432206209	AD951D	8724 435649	VALERIYA ERMAKOVA	{"email": "valeriya-ermakova-091981@postgrespro.ru", "phone": "+70783326263"}
0005432206210	E3DFB6	1965 647732	VITALIY VLASOV	{"email": "vitaliy.vlasov-1958@postgrespro.ru", "phone": "+70257571291"}
0005432206211	A392C6	6220 882604	OLEG GORBUNOV	{"phone": "+70011242519"}
0005432206214	CAD4C7	9556 699819	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova.m24121965@postgrespro.ru", "phone": "+70131981672"}
0005432206215	985696	7550 534649	RIFAT NIKITIN	{"email": "nikitin_r.111965@postgrespro.ru", "phone": "+70228992153"}
0005432206216	3183AE	5731 786008	PETR DAVYDOV	{"email": "davydov.p_081972@postgrespro.ru", "phone": "+70832920055"}
0005432206217	3183AE	2451 839340	DENIS KOZLOV	{"email": "kozlov.d.1978@postgrespro.ru", "phone": "+70328615682"}
0005432206218	E3EFDB	5684 412089	ALEKSANDR PAVLOV	{"phone": "+70519951537"}
0005432206219	1B0F00	6296 569205	TATYANA KUZNECOVA	{"email": "t_kuznecova-03031976@postgrespro.ru", "phone": "+70646885967"}
0005432206220	1B0F00	3966 973419	IRINA CHERNOVA	{"email": "ichernova_29051976@postgrespro.ru", "phone": "+70388125305"}
0005432206221	1B0F00	9330 667052	OLESYA RODIONOVA	{"phone": "+70037523039"}
0005432206222	DD403B	7703 327852	IRINA MOROZOVA	{"email": "morozova_i.051980@postgrespro.ru", "phone": "+70950247646"}
0005432206223	DD403B	0046 162865	TATYANA MOROZOVA	{"phone": "+70086274583"}
0005432206224	CC7E3E	9448 029927	KSENIYA VASILEVA	{"email": "vasileva-kseniya-04081979@postgrespro.ru", "phone": "+70810525931"}
0005432206225	CC7E3E	4792 893531	TATYANA NAZAROVA	{"email": "tatyana.nazarova_24111967@postgrespro.ru", "phone": "+70711946896"}
0005432206226	FFF22E	7021 149473	ALSU MIKHAYLOVA	{"email": "mikhaylova-alsu.07061978@postgrespro.ru", "phone": "+70208485036"}
0005432206227	FFF22E	7526 071461	RAISA SIDOROVA	{"email": "r-sidorova011967@postgrespro.ru", "phone": "+70599154985"}
0005432206228	FFF22E	6118 051023	GALINA DMITRIEVA	{"email": "dmitrieva.g_01061982@postgrespro.ru", "phone": "+70173227368"}
0005432206229	414452	4434 012072	TAISIYA KISELEVA	{"email": "taisiya_kiseleva091977@postgrespro.ru", "phone": "+70208404777"}
0005432206230	C7C598	1467 047408	VADIM ZAKHAROV	{"email": "v.zakharov-1969@postgrespro.ru", "phone": "+70432992334"}
0005432206231	AA8913	2703 796543	DMITRIY YAKOVLEV	{"email": "dmitriy-yakovlev24031974@postgrespro.ru", "phone": "+70358411576"}
0005432206232	B3F90E	8204 137760	NATALYA VOLKOVA	{"email": "nvolkova101977@postgrespro.ru", "phone": "+70789316931"}
0005432206233	4A29EB	6390 084326	ANASTASIYA ZAKHAROVA	{"email": "zakharova.a_1975@postgrespro.ru", "phone": "+70236796532"}
0005432206234	9D3238	5994 027995	ALINA STEPANOVA	{"phone": "+70209201594"}
0005432206235	349EE0	3328 600934	SOFIYA ZAKHAROVA	{"email": "zakharovas1970@postgrespro.ru", "phone": "+70210419877"}
0005432206236	C9464E	7833 180734	KIRILL POPOV	{"phone": "+70747818180"}
0005432206237	82152A	7512 351726	DANIL ANTONOV	{"email": "d.antonov.011978@postgrespro.ru", "phone": "+70894754556"}
0005432206238	FB3587	8960 561266	ANTON POPOV	{"phone": "+70910169087"}
0005432206239	934D63	8765 685266	ANDREY SOKOLOV	{"email": "sokolovandrey.081968@postgrespro.ru", "phone": "+70850311646"}
0005432206240	606AAC	6692 651613	IRINA MELNIKOVA	{"email": "irina.melnikova.17081978@postgrespro.ru", "phone": "+70657062280"}
0005432206241	9737A4	8906 797225	TATYANA PAVLOVA	{"phone": "+70928265030"}
0005432206242	C2B947	7728 511407	ANNA KUDRYASHOVA	{"phone": "+70016245654"}
0005432206243	EAA838	3826 759614	KAMILA NIKOLAEVA	{"email": "nikolaevak.041966@postgrespro.ru", "phone": "+70875951098"}
0005432206244	9053F8	7479 203059	VALENTIN BORISOV	{"phone": "+70110795834"}
0005432206245	6A7DA4	9009 538962	IRINA MOROZOVA	{"phone": "+70539941261"}
0005432206246	34222F	5499 747343	IRINA ALEKSEEVA	{"phone": "+70970327648"}
0005432206247	B607DB	6655 045339	ALEVTINA DMITRIEVA	{"phone": "+70438164819"}
0005432206248	3B2519	3511 350133	GALINA NIKOLAEVA	{"email": "nikolaeva_g081966@postgrespro.ru", "phone": "+70345223130"}
0005432206249	D2B9C1	0056 262285	VIKTOR BORISOV	{"email": "viktor_borisov-07021974@postgrespro.ru", "phone": "+70909153679"}
0005432206250	1D0FEA	1652 186140	OLGA MIKHAYLOVA	{"email": "mikhaylovao.091979@postgrespro.ru", "phone": "+70831998201"}
0005432206251	8B0EA1	1268 459193	VLADIMIR KISELEV	{"email": "vladimir-kiselev.1975@postgrespro.ru", "phone": "+70456829949"}
0005432206252	D92C4F	4317 012227	VALENTINA RODIONOVA	{"phone": "+70468907927"}
0005432206253	C0673A	4086 968648	ALEKSANDRA FEDOROVA	{"phone": "+70750667246"}
0005432206254	C0673A	1175 967958	LEV GERASIMOV	{"phone": "+70906807753"}
0005432206255	23F036	6669 156505	NATALYA VOLKOVA	{"phone": "+70722524706"}
0005432206256	F6E597	7413 395539	ANATOLIY KOZLOV	{"phone": "+70878146653"}
0005432206257	CC6EBD	6885 300384	GALINA GRISHINA	{"phone": "+70246925448"}
0005432206258	CC6EBD	7087 591638	ALEKSEY NIKOLAEV	{"email": "aleksey-nikolaev1977@postgrespro.ru", "phone": "+70059958936"}
0005432206259	3E071D	1183 327818	ALEKSANDR ALEKSANDROV	{"email": "aaleksandrov-1969@postgrespro.ru", "phone": "+70048408831"}
0005432206260	3E071D	1734 406924	VITALIY MATVEEV	{"phone": "+70692784190"}
0005432206261	475A4F	0096 941595	EVGENIY ZHUKOV	{"phone": "+70862168103"}
0005432206262	475A4F	3066 046183	IGOR FILIPPOV	{"phone": "+70164728878"}
0005432206263	6FAAA6	1057 176001	ELENA BORISOVA	{"email": "elena_borisova.08061970@postgrespro.ru", "phone": "+70301039083"}
0005432206264	A2D6CB	4562 072199	YURIY SHEVCHENKO	{"email": "shevchenkoyuriy.1966@postgrespro.ru", "phone": "+70730623257"}
0005432206265	A2D6CB	3191 686857	ZINAIDA EFIMOVA	{"email": "efimovaz111968@postgrespro.ru", "phone": "+70242141020"}
0005432206266	A2D6CB	3948 652288	ALLA AFANASEVA	{"email": "afanaseva.a1971@postgrespro.ru", "phone": "+70425507591"}
0005432206267	EEAE8A	3478 584073	GALIYA KUDRYASHOVA	{"email": "kudryashova-g-19021980@postgrespro.ru", "phone": "+70262748205"}
0005432206268	4C6BD9	9617 472935	MARIYA MATVEEVA	{"email": "mariya_matveeva_28071973@postgrespro.ru", "phone": "+70999913999"}
0005432206269	9F0542	1290 924296	VLADIMIR ALEKSEEV	{"email": "valekseev1974@postgrespro.ru", "phone": "+70961195261"}
0005432206270	9453C9	5002 209031	VERA ERMAKOVA	{"email": "ermakova_v_1969@postgrespro.ru", "phone": "+70442521071"}
0005432206271	BC6911	4124 258753	EVDOKIYA MIRONOVA	{"phone": "+70401942896"}
0005432206272	BC6911	3417 156364	ANNA RYABOVA	{"email": "ryabovaa_121961@postgrespro.ru", "phone": "+70129825313"}
0005432206273	E8309B	5622 692148	RADIK SOKOLOV	{"phone": "+70203215036"}
0005432206274	2B0E75	1523 586636	SERGEY ALEKSANDROV	{"email": "s.aleksandrov1972@postgrespro.ru", "phone": "+70495222783"}
0005432206275	948B06	2519 965740	SERGEY MOISEEV	{"phone": "+70643499646"}
0005432206276	3909C2	2829 763200	VIKTOR VLASOV	{"phone": "+70170394784"}
0005432206277	AAC30D	8796 684528	VIOLETTA KOROLEVA	{"phone": "+70581714525"}
0005432206278	F38180	4929 602222	DENIS NOVIKOV	{"phone": "+70901626007"}
0005432206279	ACB156	2267 479772	IRINA DMITRIEVA	{"email": "dmitrieva.irina_061968@postgrespro.ru", "phone": "+70389550101"}
0005432206280	38F133	4823 115367	ALEKSEY FOMIN	{"email": "a.fomin_1974@postgrespro.ru", "phone": "+70175931299"}
0005432206281	AF7C65	3068 660163	ALEKSEY NIKITIN	{"email": "aleksey_nikitin1980@postgrespro.ru", "phone": "+70051344680"}
0005432206282	AF7C65	9986 044268	EVGENIY IVANOV	{"email": "e_ivanov-1955@postgrespro.ru", "phone": "+70023828590"}
0005432206283	AF7C65	1535 861712	ALEKSANDR MARTYNOV	{"phone": "+70550407530"}
0005432206284	694F4D	0101 194561	RISHAT ZAYCEV	{"phone": "+70289615338"}
0005432206285	694F4D	9295 499159	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov-121965@postgrespro.ru", "phone": "+70274990554"}
0005432206286	B1DE1E	1040 195112	ANDREY PETROV	{"phone": "+70643481326"}
0005432206287	F9B04C	8941 709629	GALINA NIKITINA	{"email": "nikitina-galina.1973@postgrespro.ru", "phone": "+70826169591"}
0005432206288	185AE4	0733 230967	MARIYA MASLOVA	{"email": "maslova.mariya-21081972@postgrespro.ru", "phone": "+70290263966"}
0005432206289	873BFE	9416 119941	NIKOLAY ILIN	{"phone": "+70224751210"}
0005432206290	873BFE	9544 041817	GALINA KOROLEVA	{"phone": "+70648070339"}
0005432206291	89E4A2	4356 000625	INNA MELNIKOVA	{"phone": "+70030361313"}
0005432206292	89E4A2	4493 044140	DANIL IVANOV	{"email": "d.ivanov.21041963@postgrespro.ru", "phone": "+70102763913"}
0005432206293	F964DF	8250 840922	TATYANA MIRONOVA	{"email": "tmironova.1966@postgrespro.ru", "phone": "+70419975761"}
0005432206294	FDF46D	6541 629707	TATYANA KONOVALOVA	{"email": "konovalovat_1965@postgrespro.ru", "phone": "+70180903194"}
0005432206296	C4DA16	3611 455572	OLEG GRIGOREV	{"email": "grigorevo_12121965@postgrespro.ru", "phone": "+70409662327"}
0005432206297	3329ED	8679 531021	ANASTASIYA MIKHAYLOVA	{"phone": "+70462342306"}
0005432206298	8EC5D9	4434 939794	MIKHAIL SOLOVEV	{"phone": "+70976841627"}
0005432206299	85C8CB	3163 097152	TAMARA LOGINOVA	{"phone": "+70680899931"}
0005432206300	30CE85	8252 806446	IGOR SOROKIN	{"email": "i-sorokin-011968@postgrespro.ru", "phone": "+70517906821"}
0005432206301	727421	2463 273612	ANNA KOVALEVA	{"email": "a.kovaleva.031965@postgrespro.ru", "phone": "+70269755552"}
0005432206302	727421	4837 715110	IRINA ROMANOVA	{"email": "irina.romanova_1965@postgrespro.ru", "phone": "+70882009343"}
0005432206303	A5E8B2	7298 248128	OLGA GUSEVA	{"email": "guseva-olga.1973@postgrespro.ru", "phone": "+70648227557"}
0005432206304	A5E8B2	5489 032374	SERGEY KUZMIN	{"email": "kuzminsergey23101977@postgrespro.ru", "phone": "+70718658856"}
0005432206305	C59CFE	2971 110914	VASILIY MELNIKOV	{"email": "melnikov-vasiliy.01051969@postgrespro.ru", "phone": "+70389154232"}
0005432206306	2BE58B	3242 341226	ELENA FILIPPOVA	{"phone": "+70796472612"}
0005432206307	0800C1	6565 207754	TATYANA YUDINA	{"phone": "+70218788272"}
0005432206308	9F309B	0397 023377	VITALIY NIKITIN	{"phone": "+70610246015"}
0005432206309	0C811D	2523 398542	TAISIYA PETROVA	{"email": "petrovataisiya-041975@postgrespro.ru", "phone": "+70714126993"}
0005432206310	1BE47A	5461 477421	LYUDMILA POLYAKOVA	{"phone": "+70776254968"}
0005432206311	49469A	2369 095409	ROMAN BONDARENKO	{"email": "r_bondarenko1978@postgrespro.ru", "phone": "+70028183966"}
0005432206312	F8AB09	3851 119226	TATYANA EGOROVA	{"email": "egorova_tatyana.29121982@postgrespro.ru", "phone": "+70001470392"}
0005432206313	A22DD5	0000 679040	SERGEY VASILEV	{"email": "sergeyvasilev-18031968@postgrespro.ru", "phone": "+70867275220"}
0005432206314	A22DD5	2180 899096	VLADISLAV RODIONOV	{"phone": "+70975621517"}
0005432206315	4CBD48	4130 953518	SVETLANA SEMENOVA	{"email": "semenova-svetlana-1972@postgrespro.ru", "phone": "+70186996511"}
0005432206316	4A589B	8469 085671	LARISA SMIRNOVA	{"phone": "+70255802746"}
0005432206317	4A589B	7444 058449	ALEKSANDR MOISEEV	{"email": "a_moiseev-111976@postgrespro.ru", "phone": "+70263308776"}
0005432206318	EBF9DD	7362 416342	NATALYA TARASOVA	{"phone": "+70661733069"}
0005432206319	82C8DF	3726 536539	EDUARD KISELEV	{"email": "kiseleveduard.101960@postgrespro.ru", "phone": "+70573931987"}
0005432206320	82C8DF	7849 065038	MARIYA CHERNOVA	{"email": "mariya.chernova-12061978@postgrespro.ru", "phone": "+70068868245"}
0005432206321	9A2716	8120 993286	NATALYA KAZAKOVA	{"email": "kazakovan.011967@postgrespro.ru", "phone": "+70623705052"}
0005432206322	9A2716	0146 002937	VALENTINA KUZNECOVA	{"email": "v.kuznecova.16051976@postgrespro.ru", "phone": "+70335431301"}
0005432206323	F0BF07	9209 193751	DMITRIY KUZNECOV	{"email": "d-kuznecov.1974@postgrespro.ru", "phone": "+70284398375"}
0005432206324	330BA0	3978 307601	LYUDMILA PAVLOVA	{"phone": "+70298734622"}
0005432206325	B0D3BE	2567 762852	STANISLAV KUZNECOV	{"phone": "+70843059010"}
0005432206326	DDB340	3506 598078	ELENA MAKSIMOVA	{"email": "maksimova.elena_11111960@postgrespro.ru", "phone": "+70141619680"}
0005432206327	6D946B	0298 546030	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy21061966@postgrespro.ru", "phone": "+70592732070"}
0005432206328	0C6982	7157 882892	ELIZAVETA SIDOROVA	{"email": "sidorova-elizaveta-121968@postgrespro.ru", "phone": "+70533166084"}
0005432206329	0C6982	7744 389702	VASILIY GRIGOREV	{"phone": "+70262944909"}
0005432206330	B709D6	3802 096535	ANDREY GERASIMOV	{"email": "agerasimov-1965@postgrespro.ru", "phone": "+70546573964"}
0005432206331	33C629	1900 003843	ARKADIY NOVIKOV	{"phone": "+70003663269"}
0005432206332	33C629	9358 455452	ILYA BORISOV	{"email": "i.borisov.02021969@postgrespro.ru", "phone": "+70557703391"}
0005432206333	4FE967	2967 253584	DENIS ZAKHAROV	{"phone": "+70696572079"}
0005432206334	4D7368	5383 614495	NAILYA ZHUKOVA	{"phone": "+70684632886"}
0005432206335	4D7368	6238 753949	KRISTINA NOVIKOVA	{"email": "k.novikova1977@postgrespro.ru", "phone": "+70762780024"}
0005432206336	87A3E2	8333 597718	KONSTANTIN ROMANOV	{"email": "romanovkonstantin.27061959@postgrespro.ru", "phone": "+70539970267"}
0005432206337	3CDD49	1036 052285	ALEKSEY TIKHONOV	{"phone": "+70253209658"}
0005432206338	3CDD49	6173 053598	ALEKSANDR ALEKSANDROV	{"phone": "+70055565977"}
0005432206339	D3F1FD	7618 962236	EKATERINA SOKOLOVA	{"email": "sokolova.e-1969@postgrespro.ru", "phone": "+70124031893"}
0005432206340	D3F1FD	0727 226472	ANNA ZAKHAROVA	{"phone": "+70311973642"}
0005432206341	E10DB5	4320 615870	VLADIMIR FILIPPOV	{"email": "v_filippov-03091971@postgrespro.ru", "phone": "+70129830849"}
0005432206342	A6176A	6468 074974	EVGENIY VASILEV	{"email": "vasilev_e06111990@postgrespro.ru", "phone": "+70830274547"}
0005432206343	CE99A6	4640 665400	NIKOLAY CHERNOV	{"email": "n-chernov1971@postgrespro.ru", "phone": "+70238044712"}
0005432206344	CE99A6	7621 126951	VIKTOR ANDREEV	{"email": "viktor.andreev-27121965@postgrespro.ru", "phone": "+70483342520"}
0005432206345	3025A8	4985 836956	VYACHESLAV KUZMIN	{"phone": "+70375402595"}
0005432206346	188E93	4449 558017	ANATOLIY KUZNECOV	{"phone": "+70820320483"}
0005432206347	0AB3DE	7211 434529	ROMAN STEPANOV	{"phone": "+70259848830"}
0005432206348	0AB3DE	5362 447823	IVAN MOROZOV	{"phone": "+70249313885"}
0005432206349	9B4559	7790 316672	ALEKSANDR NIKOLAEV	{"phone": "+70877687882"}
0005432206350	830BA4	2691 010338	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr_02041979@postgrespro.ru", "phone": "+70281859155"}
0005432206351	7DC5DB	4074 893210	KSENIYA MASLOVA	{"email": "k.maslova_1970@postgrespro.ru", "phone": "+70965047786"}
0005432206352	70C6DB	3410 730994	EVGENIYA TIMOFEEVA	{"phone": "+70464820426"}
0005432206353	1F3B16	3696 536690	ELENA ANDREEVA	{"email": "andreeva-e_1982@postgrespro.ru", "phone": "+70425545778"}
0005432206354	1F3B16	1461 417497	ELENA POPOVA	{"email": "popova_e_1978@postgrespro.ru", "phone": "+70244570816"}
0005432206355	43703D	0667 136482	OLGA TARASOVA	{"email": "tarasova-olga_1975@postgrespro.ru", "phone": "+70762892448"}
0005432206356	960A66	1060 450613	ELENA MIKHAYLOVA	{"email": "mikhaylova-e.041973@postgrespro.ru", "phone": "+70301181483"}
0005432206357	435409	6675 576881	GERMAN DAVYDOV	{"phone": "+70517975791"}
0005432206358	435409	1641 274879	OLGA GORBUNOVA	{"email": "gorbunova.o.071969@postgrespro.ru", "phone": "+70895394256"}
0005432206359	154DCF	0757 174015	YURIY SERGEEV	{"email": "sergeev-yuriy-101984@postgrespro.ru", "phone": "+70175115126"}
0005432206360	154DCF	9742 232223	VLADIMIR DENISOV	{"phone": "+70066619000"}
0005432206361	6FB3E8	6398 327939	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_21041971@postgrespro.ru", "phone": "+70549989096"}
0005432206362	BC3426	4698 264919	ELENA PAVLOVA	{"email": "e-pavlova_011960@postgrespro.ru", "phone": "+70621526575"}
0005432207664	DE9D81	3584 289490	SERGEY ABRAMOV	{"phone": "+70188925437"}
0005432207616	67CD3A	6289 456887	PAVEL MAKSIMOV	{"phone": "+70216923516"}
0005432207617	52D83C	0313 115309	ANNA ZAYCEVA	{"email": "zayceva.a1972@postgrespro.ru", "phone": "+70555756272"}
0005432207618	52D83C	1233 997147	ARTUR MOROZOV	{"phone": "+70315596998"}
0005432207619	013689	7257 267711	DANIL SMIRNOV	{"phone": "+70044659376"}
0005432207620	FE1579	0902 755408	VALERIY KISELEV	{"phone": "+70675542678"}
0005432207621	FE1579	7872 958461	OLEG EGOROV	{"email": "oleg-egorov101971@postgrespro.ru", "phone": "+70114695605"}
0005432207622	5A04F9	3277 256397	NIKOLAY KUZNECOV	{"phone": "+70045812145"}
0005432207623	394002	3354 274021	LYUBOV IVANOVA	{"email": "l.ivanova.121972@postgrespro.ru", "phone": "+70489131218"}
0005432207624	466911	8946 065789	MIKHAIL VASILEV	{"phone": "+70483889110"}
0005432207625	F969F0	8112 873916	VIKTOR ILIN	{"phone": "+70964868947"}
0005432207626	F969F0	9527 389343	IGOR KISELEV	{"email": "kiselevi01081961@postgrespro.ru", "phone": "+70369621359"}
0005432207627	7F4891	1119 977904	DANIIL MEDVEDEV	{"email": "medvedevdaniil101978@postgrespro.ru", "phone": "+70494297908"}
0005432207628	7F4891	7332 746944	SVETLANA FEDOROVA	{"phone": "+70517219814"}
0005432207629	EC91EA	3509 708521	ANNA RODIONOVA	{"email": "rodionova-a1979@postgrespro.ru", "phone": "+70555163542"}
0005432207630	F3E1E9	8750 838396	NIKOLAY SHEVCHENKO	{"phone": "+70093992283"}
0005432207631	C0E479	9025 838901	FEDOR NOVIKOV	{"email": "f-novikov-111977@postgrespro.ru", "phone": "+70135953062"}
0005432207632	299924	3786 186870	MARIYA VASILEVA	{"phone": "+70605503743"}
0005432207633	D58202	4199 768050	ANATOLIY BONDARENKO	{"email": "bondarenko_anatoliy-03031977@postgrespro.ru", "phone": "+70199512962"}
0005432207634	8DF693	7759 188867	OLGA MARTYNOVA	{"email": "o.martynova.03011979@postgrespro.ru", "phone": "+70310180814"}
0005432207635	8DF693	1438 464912	VIKTORIYA KONOVALOVA	{"phone": "+70436289895"}
0005432207636	8DF693	1348 293932	NATALYA GAVRILOVA	{"email": "natalyagavrilova_1970@postgrespro.ru", "phone": "+70031763177"}
0005432207637	04699E	1613 936766	EKATERINA IVANOVA	{"email": "ivanovae.031981@postgrespro.ru", "phone": "+70455904183"}
0005432207638	04699E	6791 380351	VIKTOR SOROKIN	{"email": "vsorokin.031977@postgrespro.ru", "phone": "+70245352962"}
0005432207639	28AED2	5472 373618	MARIYA KUZNECOVA	{"email": "mariyakuznecova-071976@postgrespro.ru", "phone": "+70210550239"}
0005432207640	28AED2	7522 672272	NATALYA KISELEVA	{"phone": "+70844969259"}
0005432207641	3255CB	9483 405147	DENIS TIKHONOV	{"email": "tikhonov_d.04111966@postgrespro.ru", "phone": "+70444938674"}
0005432207642	D2A4B5	4266 265400	KIRA LEBEDEVA	{"email": "k.lebedeva.1980@postgrespro.ru", "phone": "+70807016033"}
0005432207643	D2A4B5	5212 797860	VALENTIN AFANASEV	{"phone": "+70801057062"}
0005432207644	78587E	9920 762501	NINA ISAEVA	{"email": "nisaeva.011976@postgrespro.ru", "phone": "+70706603568"}
0005432207645	78587E	1811 112754	LYUBOV PETROVA	{"email": "petrova_l.06101981@postgrespro.ru", "phone": "+70384694818"}
0005432207646	97FDCA	6543 367302	ELIZAVETA IVANOVA	{"email": "ivanova.e.1980@postgrespro.ru", "phone": "+70378781588"}
0005432207647	7A8C0E	7705 341078	ANASTASIYA GERASIMOVA	{"email": "anastasiya_gerasimova_31051976@postgrespro.ru", "phone": "+70157968884"}
0005432207648	A73739	2361 837100	IRINA KOROLEVA	{"phone": "+70180209370"}
0005432207649	FAFFE8	8553 409783	LEONID POPOV	{"email": "lpopov-111972@postgrespro.ru", "phone": "+70161362565"}
0005432207650	FAFFE8	5001 512543	DANILA KULIKOV	{"email": "kulikov_danila_1968@postgrespro.ru", "phone": "+70326319109"}
0005432207651	FAFFE8	1957 485403	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov_29041966@postgrespro.ru", "phone": "+70638074649"}
0005432207652	D2B17F	0591 660456	MAKSIM YAKOVLEV	{"phone": "+70166767857"}
0005432207653	D2B17F	5839 130483	DMITRIY FEDOROV	{"email": "fedorov.d10081973@postgrespro.ru", "phone": "+70413221277"}
0005432207654	4705BF	0143 302999	VLADIMIR SMIRNOV	{"email": "smirnov.v_011980@postgrespro.ru", "phone": "+70454778935"}
0005432207655	A78ADE	7949 839165	ANDREY MELNIKOV	{"phone": "+70259984798"}
0005432207656	A78ADE	9046 023253	EVGENIY ILIN	{"phone": "+70135322376"}
0005432207657	FE9E07	2461 128651	ANDREY KOZLOV	{"email": "andrey-kozlov071975@postgrespro.ru", "phone": "+70620320217"}
0005432207658	FE9E07	5893 424081	GALINA ZOTOVA	{"email": "zotova-g.011989@postgrespro.ru", "phone": "+70534012155"}
0005432207659	61523E	3248 547011	SERGEY SAVELEV	{"email": "savelevs_121970@postgrespro.ru", "phone": "+70010916938"}
0005432207660	9A9F95	9217 739712	OLGA ANTONOVA	{"phone": "+70794377606"}
0005432207661	F5CCDB	5723 538759	RIMMA IVANOVA	{"phone": "+70551268030"}
0005432207662	44A4EC	8013 777485	ANNA RODIONOVA	{"phone": "+70019997491"}
0005432207663	1D8134	7146 376462	DENIS IVANOV	{"email": "d.ivanov17031973@postgrespro.ru", "phone": "+70021839491"}
0005432207665	E0E2ED	2598 749184	ANASTASIYA FADEEVA	{"email": "fadeeva.a-021969@postgrespro.ru", "phone": "+70151680262"}
0005432207666	72F042	2973 428425	ALISHER EGOROV	{"email": "egorova.101983@postgrespro.ru", "phone": "+70798651113"}
0005432207667	E642C6	0947 558222	NADEZHDA POPOVA	{"email": "nadezhda_popova-1958@postgrespro.ru", "phone": "+70295817953"}
0005432207668	3D1891	2925 717192	ALEKSANDR YAKOVLEV	{"email": "yakovlev_a_1967@postgrespro.ru", "phone": "+70417473116"}
0005432207669	2C32A1	7716 912000	NIKOLAY KISELEV	{"phone": "+70587453071"}
0005432207670	2C32A1	2359 255330	LIDIYA MEDVEDEVA	{"phone": "+70829264305"}
0005432207671	EE4F8B	6535 683207	OLEG KUZNECOV	{"email": "kuznecov-o_29111960@postgrespro.ru", "phone": "+70105437049"}
0005432207672	C8B7FF	4258 475857	ELENA POLYAKOVA	{"email": "polyakova_e111964@postgrespro.ru", "phone": "+70193429679"}
0005432207673	CBEBBA	6488 460369	VIKTOR RODIONOV	{"phone": "+70806144903"}
0005432207674	1EBF32	3649 419036	SERGEY PAVLOV	{"phone": "+70244976505"}
0005432207675	7B9D78	8019 371315	ALEKSANDR BARANOV	{"phone": "+70942616621"}
0005432207676	F015C7	4679 476357	MAKSIM VASILEV	{"phone": "+70821579373"}
0005432207677	8C77E8	7247 823547	VLADIMIR GRIGOREV	{"phone": "+70459893811"}
0005432207678	A133E9	4781 914625	ELENA LEBEDEVA	{"phone": "+70118752353"}
0005432207679	8970DE	9207 913385	ANTON SEMENOV	{"email": "semenov-anton.05051958@postgrespro.ru", "phone": "+70449881099"}
0005432207680	39739A	7756 845287	NATALYA DMITRIEVA	{"phone": "+70829649080"}
0005432207681	C024B5	0541 057270	PAVEL NIKITIN	{"email": "p.nikitin-021994@postgrespro.ru", "phone": "+70060471028"}
0005432207682	C024B5	5824 153649	ALEKSANDRA SEMENOVA	{"phone": "+70302370384"}
0005432207683	C024B5	2685 527991	GLEB IVANOV	{"phone": "+70919532296"}
0005432207684	F80BFC	4838 267870	DMITRIY EGOROV	{"email": "d.egorov13041970@postgrespro.ru", "phone": "+70199803208"}
0005432207685	F80BFC	8307 311529	INNA KOZLOVA	{"email": "kozlovai.101972@postgrespro.ru", "phone": "+70329871258"}
0005432207686	93DEDD	4677 453551	LYUDMILA MIRONOVA	{"email": "l_mironova.02021967@postgrespro.ru", "phone": "+70967626635"}
0005432207687	AA6C39	7004 557725	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov.1972@postgrespro.ru", "phone": "+70657329980"}
0005432207688	555920	7788 368044	ALEKSEY ILIN	{"email": "ilin.aleksey.03061966@postgrespro.ru", "phone": "+70331645220"}
0005432207689	061139	1554 227741	MIKHAIL MIKHAYLOV	{"email": "mikhaylovmikhail041970@postgrespro.ru", "phone": "+70711492223"}
0005432207690	9CBAA6	4365 697482	TAMARA MALYSHEVA	{"phone": "+70620658056"}
0005432207691	3F6837	6285 132965	MARIYA NIKITINA	{"email": "nikitina.mariya_1970@postgrespro.ru", "phone": "+70156467841"}
0005432207692	3F6837	4164 840183	PAVEL KUZMIN	{"email": "kuzmin.p_041991@postgrespro.ru", "phone": "+70382422012"}
0005432207693	44251B	7437 870269	VLADIMIR ORLOV	{"email": "orlov_vladimir.02021966@postgrespro.ru", "phone": "+70249501834"}
0005432207694	E7047F	5946 305990	TAMARA ZOTOVA	{"phone": "+70848106292"}
0005432207695	EBF0DA	2665 866067	SNEZHANA ERMAKOVA	{"phone": "+70911231883"}
0005432207696	558C94	7196 495383	VLADIMIR VOLKOV	{"email": "v-volkov_29121982@postgrespro.ru", "phone": "+70875492232"}
0005432207697	54BF57	6595 139599	DANILA FROLOV	{"phone": "+70112070992"}
0005432207698	54BF57	7764 814368	NIKOLAY ALEKSEEV	{"email": "alekseev.nikolay-12121963@postgrespro.ru", "phone": "+70933560556"}
0005432207699	A997EA	2608 676206	PETR SHEVCHENKO	{"email": "petr-shevchenko-02101973@postgrespro.ru", "phone": "+70028349534"}
0005432207700	D285D1	9929 488736	SERGEY MATVEEV	{"phone": "+70346560766"}
0005432207701	E84E99	6231 116673	OLGA DMITRIEVA	{"email": "dmitrieva-olga.1987@postgrespro.ru", "phone": "+70975494834"}
0005432207702	C2E04B	9990 147855	ALEKSANDR SEMENOV	{"email": "semenovaleksandr09091968@postgrespro.ru", "phone": "+70163107194"}
0005432207703	1E724D	2677 255287	MARINA KUZMINA	{"email": "marina.kuzmina.06041970@postgrespro.ru", "phone": "+70633162423"}
0005432207704	AFABEC	4249 358057	ALEKSANDR ZHUKOV	{"phone": "+70350691380"}
0005432207705	AFABEC	5585 849056	MIKHAIL MOROZOV	{"email": "m_morozov_1977@postgrespro.ru", "phone": "+70684525867"}
0005432207706	AFABEC	6256 142750	LYUBOV DAVYDOVA	{"phone": "+70544372890"}
0005432207707	E99D85	3954 337824	ZINAIDA PAVLOVA	{"phone": "+70637801300"}
0005432207708	8C3475	3538 602092	NIKOLAY MAKAROV	{"phone": "+70499372236"}
0005432207709	18777A	9394 981979	EVGENIY SOROKIN	{"email": "esorokin_04071965@postgrespro.ru", "phone": "+70350827223"}
0005432207710	3D7AE4	6901 603224	ALEKSANDR BORISOV	{"phone": "+70900842231"}
0005432207711	3D7AE4	8424 034450	ALEKSANDR KUZMIN	{"phone": "+70160069783"}
0005432207712	31CFE1	0945 582560	PAVEL DAVYDOV	{"email": "davydov_pavel.1963@postgrespro.ru", "phone": "+70855681846"}
0005432207713	0C5435	4311 948960	TATYANA YAKOVLEVA	{"email": "yakovleva.t-27021980@postgrespro.ru", "phone": "+70256625861"}
0005432207714	BF29EC	0531 254338	GALINA OSIPOVA	{"email": "osipova.galina081976@postgrespro.ru", "phone": "+70987187617"}
0005432207715	BF29EC	2543 008151	EVDOKIYA SOROKINA	{"phone": "+70573185768"}
0005432207716	4829D5	0468 614897	TATYANA KRASNOVA	{"email": "krasnovat.091980@postgrespro.ru", "phone": "+70191928636"}
0005432207717	4829D5	7789 879862	ANDREY ISAEV	{"email": "isaev-a.03081977@postgrespro.ru", "phone": "+70814890460"}
0005432207718	DA2B6D	8400 389809	ILYA STEPANOV	{"phone": "+70343940647"}
0005432207719	DA2B6D	0127 438949	NINA KRASNOVA	{"phone": "+70271761725"}
0005432207720	D5CF24	2138 795254	STEPAN MIKHAYLOV	{"email": "mikhaylov-s-1977@postgrespro.ru", "phone": "+70339287177"}
0005432207721	D5CF24	7527 685784	LYUBOV MEDVEDEVA	{"email": "lmedvedeva-1984@postgrespro.ru", "phone": "+70258243135"}
0005432207722	A09454	4742 628062	EVGENIYA SIDOROVA	{"email": "sidorova.evgeniya1971@postgrespro.ru", "phone": "+70922541120"}
0005432207723	186B21	4549 383032	KRISTINA ANDREEVA	{"email": "andreeva_kristina_14121973@postgrespro.ru", "phone": "+70288916775"}
0005432207724	BAB973	0495 039108	IRINA KOZLOVA	{"phone": "+70565868495"}
0005432207725	CA8382	0404 472746	VLADIMIR ZAYCEV	{"email": "vladimir.zaycev-101975@postgrespro.ru", "phone": "+70006120569"}
0005432207726	FA86C2	3822 740501	VIKTORIYA VOLKOVA	{"phone": "+70737454395"}
0005432207727	DB3516	4246 105010	VITALIY TIKHONOV	{"phone": "+70217991964"}
0005432207728	DB3516	3475 561288	TATYANA SOROKINA	{"phone": "+70918029024"}
0005432207729	7D9522	9763 639576	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva.lyudmila_1969@postgrespro.ru", "phone": "+70252821002"}
0005432207730	7D9522	8166 567033	BORIS MOROZOV	{"phone": "+70390500849"}
0005432207731	5B25F5	0714 399102	VLADIMIR MOISEEV	{"email": "moiseev-vladimir.1978@postgrespro.ru", "phone": "+70912423779"}
0005432207732	5B25F5	6479 001820	NADEZHDA RYABOVA	{"phone": "+70150993550"}
0005432207733	1890C6	4539 136352	ZINAIDA IVANOVA	{"phone": "+70295706258"}
0005432207734	03A70A	1055 434887	ANDREY NAZAROV	{"email": "nazarova10061964@postgrespro.ru", "phone": "+70358747406"}
0005432207735	285467	0759 503150	ANNA NIKITINA	{"email": "anikitina26051980@postgrespro.ru", "phone": "+70258681569"}
0005432207736	F222A0	2853 599522	IVAN VASILEV	{"email": "vasilevivan1957@postgrespro.ru", "phone": "+70445343587"}
0005432207737	FCB525	9184 392889	IRINA VASILEVA	{"phone": "+70597100258"}
0005432207738	C70761	7307 585671	ANASTASIYA GERASIMOVA	{"email": "gerasimova_anastasiya-1968@postgrespro.ru", "phone": "+70739867320"}
0005432207739	DB3E36	5738 406699	VALENTINA VOLKOVA	{"phone": "+70315469176"}
0005432207740	DB3E36	7217 490905	VALERIY DMITRIEV	{"email": "dmitriev.v_24011968@postgrespro.ru", "phone": "+70247829795"}
0005432207741	DB3E36	8414 648062	YULIYA ANISIMOVA	{"phone": "+70878431411"}
0005432211471	ED09E2	3666 118827	ALEKSANDR ROMANOV	{"phone": "+70793768522"}
0005432211365	68148A	0471 092202	IVAN ZHUKOV	{"email": "izhukov.121961@postgrespro.ru", "phone": "+70275846749"}
0005432211366	00F4EF	6661 597534	TATYANA MIKHAYLOVA	{"email": "t.mikhaylova1971@postgrespro.ru", "phone": "+70534043436"}
0005432211367	00F4EF	0878 522833	IRINA ANTONOVA	{"email": "i-antonova13091969@postgrespro.ru", "phone": "+70479294323"}
0005432211368	6D082C	4262 169374	MATVEY FEDOTOV	{"phone": "+70505998821"}
0005432211369	EA2AEA	7323 497615	ANTON STEPANOV	{"email": "stepanov-anton22021976@postgrespro.ru", "phone": "+70121646197"}
0005432211370	EA2AEA	7198 737665	VALENTINA NIKITINA	{"phone": "+70876982137"}
0005432211371	AC6554	4723 515820	ZINAIDA TIKHONOVA	{"email": "z.tikhonova.111969@postgrespro.ru", "phone": "+70550652008"}
0005432211372	AC6554	1372 002958	TATYANA TIKHONOVA	{"email": "t_tikhonova1971@postgrespro.ru", "phone": "+70617474305"}
0005432211373	D15211	5101 739544	VYACHESLAV NAZAROV	{"email": "vyacheslav_nazarov.1967@postgrespro.ru", "phone": "+70268622489"}
0005432211374	F64136	0737 334014	PAVEL ILIN	{"phone": "+70198955214"}
0005432211375	2B38B0	9614 249720	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin.1972@postgrespro.ru", "phone": "+70396871313"}
0005432211376	2B38B0	7052 472323	SERGEY YAKOVLEV	{"email": "sergey.yakovlev-1980@postgrespro.ru", "phone": "+70146061504"}
0005432211377	2B38B0	9186 526996	ALEKSANDR SMIRNOV	{"phone": "+70539323823"}
0005432211378	4E384D	8683 704438	SVETLANA ALEKSEEVA	{"email": "alekseeva-s.1977@postgrespro.ru", "phone": "+70918042506"}
0005432211379	F2AF0A	3718 822344	ANTON ORLOV	{"phone": "+70974537076"}
0005432211380	58CEE4	2655 951245	TATYANA MAKAROVA	{"email": "makarova_tatyana.1982@postgrespro.ru", "phone": "+70693947695"}
0005432211381	CFE2B1	5842 391269	DMITRIY NIKITIN	{"email": "nikitin.d.1966@postgrespro.ru", "phone": "+70937253203"}
0005432211382	F78BBA	7930 683523	YURIY POPOV	{"phone": "+70815785314"}
0005432211383	F78BBA	4114 491622	ANDREY SMIRNOV	{"email": "andrey.smirnov_15041971@postgrespro.ru", "phone": "+70726101474"}
0005432211384	3644EE	7889 340491	SERGEY MAKSIMOV	{"phone": "+70426778341"}
0005432211385	3644EE	2504 102950	OLGA NIKITINA	{"email": "olga_nikitina-1972@postgrespro.ru", "phone": "+70438186182"}
0005432211386	37E38B	3274 931221	TAMARA KOVALEVA	{"phone": "+70159176436"}
0005432211387	63033A	8311 083654	ANASTASIYA BORISOVA	{"email": "borisova_a101987@postgrespro.ru", "phone": "+70907810038"}
0005432211388	D9DAD0	7809 811696	KAPITALINA KUZMINA	{"email": "kuzminakapitalina-21031973@postgrespro.ru", "phone": "+70664691561"}
0005432211389	2432C6	0549 783096	NATALYA ISAEVA	{"phone": "+70957019792"}
0005432211390	510862	6577 055412	MARGARITA LOGINOVA	{"email": "margarita_loginova-081966@postgrespro.ru", "phone": "+70920860890"}
0005432211391	510862	1593 654705	ALEKSANDR MAKSIMOV	{"email": "aleksandr-maksimov_17051963@postgrespro.ru", "phone": "+70403770689"}
0005432211392	FF2002	3568 377457	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov.03041976@postgrespro.ru", "phone": "+70718879796"}
0005432211393	6DF6A2	6879 426452	ALEKSEY KRASNOV	{"email": "a-krasnov041974@postgrespro.ru", "phone": "+70261088777"}
0005432211394	781F5B	2618 136842	MIKHAIL DAVYDOV	{"email": "m_davydov.1972@postgrespro.ru", "phone": "+70781570612"}
0005432211395	82AADC	8969 930280	ANTON KOZLOV	{"email": "kozlov_anton.28111977@postgrespro.ru", "phone": "+70244261556"}
0005432211396	82AADC	3852 581373	ANDREY GRIGOREV	{"email": "andrey_grigorev_1971@postgrespro.ru", "phone": "+70313498235"}
0005432211397	3F1892	9811 424922	DMITRIY NOVIKOV	{"phone": "+70528512681"}
0005432211398	1BE549	9069 060115	EVGENIY BONDARENKO	{"phone": "+70116066107"}
0005432211399	1BE549	7476 087579	VIKTOR IVANOV	{"email": "ivanov-viktor_1983@postgrespro.ru", "phone": "+70014401984"}
0005432211400	DD8AB1	1865 583179	MARIYA ANISIMOVA	{"email": "mariyaanisimova_071972@postgrespro.ru", "phone": "+70004112826"}
0005432211401	52C81D	3054 846036	ALEKSANDRA VASILEVA	{"phone": "+70092795435"}
0005432211402	52C81D	0785 731296	TATYANA KULIKOVA	{"email": "kulikova-tatyana_021969@postgrespro.ru", "phone": "+70505885773"}
0005432211403	E2AE36	2233 914170	YANA VASILEVA	{"email": "vasilevayana-091969@postgrespro.ru", "phone": "+70778392816"}
0005432211404	2B2637	7734 860186	ELENA SOROKINA	{"phone": "+70120918552"}
0005432211405	2B2637	9771 142165	NATALYA BARANOVA	{"phone": "+70306870243"}
0005432211406	E51694	0753 390486	ANATOLIY ANDREEV	{"email": "andreeva12081969@postgrespro.ru", "phone": "+70872709397"}
0005432211407	E51694	3031 894243	ALEKSANDRA GUSEVA	{"email": "a_guseva_1978@postgrespro.ru", "phone": "+70004112369"}
0005432211408	82FC59	5098 810583	TATYANA TARASOVA	{"email": "tatyana-tarasova1961@postgrespro.ru", "phone": "+70826118319"}
0005432211409	308170	0114 867305	ELENA SOKOLOVA	{"phone": "+70568941839"}
0005432211410	A6D76E	2984 582941	ALEKSANDR MAKAROV	{"phone": "+70146428234"}
0005432211411	01AD5F	7881 640280	LIDIYA DANILOVA	{"phone": "+70609199337"}
0005432211412	8629E2	2910 227643	IVAN DMITRIEV	{"email": "i.dmitriev-06061974@postgrespro.ru", "phone": "+70219890748"}
0005432211413	8629E2	9029 233667	VLADIMIR KRASNOV	{"email": "vladimir.krasnov-1980@postgrespro.ru", "phone": "+70310251457"}
0005432211414	283375	8162 476818	EKATERINA MOROZOVA	{"phone": "+70573373419"}
0005432211415	FD71BD	9417 440058	VERA ZAKHAROVA	{"email": "zakharovavera-081971@postgrespro.ru", "phone": "+70446912346"}
0005432211416	FD71BD	1851 991301	ANATOLIY ANDREEV	{"email": "a.andreev.06061970@postgrespro.ru", "phone": "+70648937302"}
0005432211417	1F38CF	2067 171089	MARINA YAKOVLEVA	{"phone": "+70227729119"}
0005432211418	25E3B5	2531 460222	VITALIY SERGEEV	{"email": "v_sergeev.21051970@postgrespro.ru", "phone": "+70955598945"}
0005432211419	CC3234	7805 494197	LYUBOV CHERNOVA	{"email": "l-chernova-1957@postgrespro.ru", "phone": "+70321198553"}
0005432211420	CC3234	0859 895816	ALEKSEY GRIGOREV	{"email": "alekseygrigorev-111975@postgrespro.ru", "phone": "+70718148014"}
0005432211421	84747F	7426 246032	VALERIY FEDOROV	{"phone": "+70466937896"}
0005432211422	3A2507	3428 937985	LYUDMILA FEDOROVA	{"email": "fedorova_l051968@postgrespro.ru", "phone": "+70702951235"}
0005432211423	F01D0B	2395 341157	PAVEL SOKOLOV	{"phone": "+70099745740"}
0005432211424	400012	2173 124979	SVETLANA TARASOVA	{"phone": "+70823187601"}
0005432211425	C19812	9515 516961	ROMAN MOISEEV	{"phone": "+70885193027"}
0005432211426	D32438	6824 728208	IGOR MOROZOV	{"phone": "+70484143361"}
0005432211427	8D897B	0518 553726	DANIIL ANDREEV	{"email": "dandreev.1970@postgrespro.ru", "phone": "+70339349515"}
0005432211428	155DF4	3605 517066	RAISA KUZNECOVA	{"phone": "+70528862132"}
0005432211429	70B2F6	5382 635831	VLADIMIR GERASIMOV	{"email": "gerasimovv1972@postgrespro.ru", "phone": "+70705101913"}
0005432211430	296881	6221 221777	LARISA AKIMOVA	{"phone": "+70331581387"}
0005432211431	296881	4222 933624	KONSTANTIN MOISEEV	{"email": "konstantin-moiseev_1981@postgrespro.ru", "phone": "+70338789701"}
0005432211432	4C9BBD	7444 998800	SERAFIM SCHERBAKOV	{"phone": "+70858119541"}
0005432211433	4C9BBD	7476 030304	ALEKSEY NIKITIN	{"email": "aleksey.nikitin.071981@postgrespro.ru", "phone": "+70983004763"}
0005432211434	006485	1810 548142	NINA NESTEROVA	{"phone": "+70494428790"}
0005432211435	006485	9378 200094	GALINA KARPOVA	{"email": "g_karpova_1967@postgrespro.ru", "phone": "+70591920868"}
0005432211436	50D197	1318 483494	ALEKSEY BORISOV	{"email": "a_borisov-1964@postgrespro.ru", "phone": "+70309736082"}
0005432211437	50D197	0071 849660	MIKHAIL PAVLOV	{"phone": "+70910386466"}
0005432211438	3DAC25	4133 618097	YULIYA KUZNECOVA	{"phone": "+70760465383"}
0005432211439	3DAC25	6524 729995	ANTONINA VOLKOVA	{"phone": "+70072362748"}
0005432211440	2AC496	1787 262227	NIKOLAY ILIN	{"email": "ilin.nikolay-1976@postgrespro.ru", "phone": "+70026537091"}
0005432211441	5A70C7	9134 159815	RUSTAM VOLKOV	{"phone": "+70758073842"}
0005432211442	7CAE8B	8190 708569	SERGEY ISAEV	{"email": "isaev.sergey_1980@postgrespro.ru", "phone": "+70377936375"}
0005432211443	15690D	8570 743563	VALENTINA SEMENOVA	{"email": "semenova-v_061963@postgrespro.ru", "phone": "+70035655490"}
0005432211444	EDE63A	5609 677700	NIKOLAY SEMENOV	{"phone": "+70850512355"}
0005432211445	0C06E9	9929 186773	MIKHAIL BELOV	{"phone": "+70809855487"}
0005432211446	F8E8E8	6177 083881	IRINA KUZNECOVA	{"email": "i-kuznecova.111985@postgrespro.ru", "phone": "+70603189770"}
0005432211447	3E0137	7245 120306	OLEG KUZNECOV	{"phone": "+70137955755"}
0005432211448	3E0137	7069 822847	OKSANA BELYAEVA	{"email": "belyaeva.oksana-121976@postgrespro.ru", "phone": "+70735595731"}
0005432211449	0A7419	3493 797635	ANDREY NAUMOV	{"email": "naumov-a-091969@postgrespro.ru", "phone": "+70872574702"}
0005432211450	DB4B57	3196 358220	YURIY SEMENOV	{"email": "yuriy-semenov-29031966@postgrespro.ru", "phone": "+70652276248"}
0005432211451	A26D6E	6824 540432	LYUDMILA BELOVA	{"email": "belova_lyudmila-15051966@postgrespro.ru", "phone": "+70019451141"}
0005432211452	13730F	1064 573875	ANNA LEBEDEVA	{"email": "lebedeva.anna-06011961@postgrespro.ru", "phone": "+70545805666"}
0005432211453	13730F	0494 504645	LYUDMILA ZOTOVA	{"phone": "+70825807687"}
0005432211454	6D7E97	1511 818764	LIDIYA SCHERBAKOVA	{"phone": "+70636233398"}
0005432211455	2396AF	8597 977031	YURIY KUZNECOV	{"phone": "+70980133210"}
0005432211456	44F160	5678 583557	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov-01071970@postgrespro.ru", "phone": "+70469744341"}
0005432211457	44F160	9339 431577	MARIYA FILIPPOVA	{"phone": "+70493131392"}
0005432211458	7AB9F0	4885 472137	ANTONINA RODIONOVA	{"email": "rodionova_antonina-05051975@postgrespro.ru", "phone": "+70590372657"}
0005432211459	15132F	8471 635836	ANTONINA SMIRNOVA	{"phone": "+70506462840"}
0005432211460	15132F	8520 104581	ARTEM SERGEEV	{"email": "a.sergeev-061970@postgrespro.ru", "phone": "+70831896075"}
0005432211461	24835E	0672 816646	MARINA ALEKSANDROVA	{"email": "maleksandrova.07121961@postgrespro.ru", "phone": "+70617606413"}
0005432211462	5B8B4E	3291 812971	IRINA KARPOVA	{"phone": "+70405013214"}
0005432211463	089017	0045 588560	EVGENIYA STEPANOVA	{"email": "e-stepanova.21041973@postgrespro.ru", "phone": "+70322932899"}
0005432211464	EE9C6B	6182 333439	EMILIYA KARPOVA	{"email": "emiliya_karpova1974@postgrespro.ru", "phone": "+70111013487"}
0005432211465	E795F4	6810 476213	DAMIR TARASOV	{"phone": "+70473712090"}
0005432211466	E795F4	3616 232038	IGOR IVANOV	{"phone": "+70093772451"}
0005432211467	DF6222	4219 493942	VIKTORIYA NIKITINA	{"email": "v-nikitina091959@postgrespro.ru", "phone": "+70240495614"}
0005432211468	DF6222	4045 961837	ALEKSEY ALEKSANDROV	{"phone": "+70973355478"}
0005432211469	E4D085	1185 688197	VLADISLAV POPOV	{"phone": "+70006632396"}
0005432211470	EB9E60	6129 126699	VALENTINA SEMENOVA	{"phone": "+70871350008"}
0005432211472	5E5052	3174 839942	RAISA NAUMOVA	{"email": "rnaumova-1972@postgrespro.ru", "phone": "+70721069472"}
0005432211473	AFBC8B	4072 615149	PAVEL GRIGOREV	{"phone": "+70788974484"}
0005432211474	5E8D8F	0987 709359	DENIS POPOV	{"email": "denis_popov-06111977@postgrespro.ru", "phone": "+70563016270"}
0005432211475	5858D1	0103 911080	DMITRIY NIKITIN	{"phone": "+70295309826"}
0005432211476	35779E	3568 120364	SERGEY KONOVALOV	{"phone": "+70411657146"}
0005432211477	35779E	1297 457261	TAMARA MAKAROVA	{"email": "tamara-makarova1989@postgrespro.ru", "phone": "+70862384195"}
0005432211478	35779E	4827 351143	ALINA FILATOVA	{"email": "filatovaalina12121975@postgrespro.ru", "phone": "+70507372614"}
0005432211479	CBFE8A	1729 040612	MILANA KUZNECOVA	{"email": "kuznecova_m_1967@postgrespro.ru", "phone": "+70918977852"}
0005432211480	A2EF97	6103 379381	VLADIMIR MAKAROV	{"phone": "+70892729172"}
0005432211481	680D3D	8778 298427	TATYANA DANILOVA	{"email": "danilova_tatyana1969@postgrespro.ru", "phone": "+70269429204"}
0005432211482	427F8B	9218 346545	MIKHAIL MEDVEDEV	{"email": "m.medvedev_121969@postgrespro.ru", "phone": "+70472267601"}
0005432211483	8A2753	7722 065771	OLGA OSIPOVA	{"email": "olga.osipova-121971@postgrespro.ru", "phone": "+70097185783"}
0005432211484	CD8D2C	7064 793648	ALEKSANDR CHERNOV	{"email": "chernovaleksandr08071974@postgrespro.ru", "phone": "+70874714179"}
0005432211485	CD8D2C	5148 258460	SOFYA SEMENOVA	{"email": "sofyasemenova-121967@postgrespro.ru", "phone": "+70481808329"}
0005432211486	CD8D2C	7412 113838	ALEKSANDR KUZNECOV	{"email": "kuznecova24071972@postgrespro.ru", "phone": "+70296854350"}
0005432211487	AF3097	2941 350115	DMITRIY TIMOFEEV	{"phone": "+70101147600"}
0005432211488	C288CF	9650 373848	ILMIR PETROV	{"email": "ipetrov_1971@postgrespro.ru", "phone": "+70545048671"}
0005432211489	3B7102	4702 426945	EVGENIY KUZNECOV	{"email": "ekuznecov.1976@postgrespro.ru", "phone": "+70503361267"}
0005432211490	05B499	8447 270590	TATYANA FOMINA	{"phone": "+70304836607"}
0005432211491	0C1523	2208 983025	VIKTOR ZAKHAROV	{"email": "vzakharov1974@postgrespro.ru", "phone": "+70311824224"}
0005432211492	48F16C	2520 741692	ANZHELA POPOVA	{"phone": "+70322492718"}
0005432211493	35B00C	5010 051943	MIKHAIL KULIKOV	{"phone": "+70527652163"}
0005432211494	9CA6BA	8330 211551	LYUDMILA SAVELEVA	{"phone": "+70167006078"}
0005432211495	B554C3	4858 599882	EVGENIYA ZHURAVLEVA	{"phone": "+70345172544"}
0005432211496	B894F1	3936 125158	MARINA FEDOROVA	{"email": "marina.fedorova_1976@postgrespro.ru", "phone": "+70628612525"}
0005432211497	50345B	6728 465496	MIKHAIL MELNIKOV	{"email": "mikhail-melnikov.01061970@postgrespro.ru", "phone": "+70032020525"}
0005432211498	E3FE60	2623 627110	YURIY OSIPOV	{"phone": "+70231005207"}
0005432211499	E3FE60	6486 434637	MIKHAIL TARASOV	{"email": "tarasovm.20041972@postgrespro.ru", "phone": "+70710731551"}
0005432211500	9FCF64	1648 767135	BOGDAN RODIONOV	{"phone": "+70162055465"}
0005432211501	26259F	9115 697286	SERGEY FROLOV	{"phone": "+70000037682"}
0005432211502	89B2E6	3135 786255	ALEKSANDR VASILEV	{"email": "avasilev_081975@postgrespro.ru", "phone": "+70050691153"}
0005432211503	E39DDE	9279 615634	OLGA POPOVA	{"email": "popova-olga_1961@postgrespro.ru", "phone": "+70834010900"}
0005432211504	8588BF	7800 887011	GENNADIY MOROZOV	{"phone": "+70572730003"}
0005432211505	46DEAC	2943 066195	GENNADIY VLASOV	{"email": "vlasov_gennadiy-1976@postgrespro.ru", "phone": "+70918851960"}
0005432211506	836B9A	9370 189866	MARIYA BOGDANOVA	{"email": "mariya_bogdanova08091970@postgrespro.ru", "phone": "+70452722265"}
0005432211507	836B9A	1729 215085	VLADIMIR GORBUNOV	{"phone": "+70927057939"}
0005432211508	F85A64	2916 325021	FILIPP MIKHAYLOV	{"email": "filippmikhaylov_1976@postgrespro.ru", "phone": "+70183655451"}
0005432211509	C6CBC1	5497 174912	YURIY CHERNOV	{"phone": "+70382937319"}
0005432211510	E25728	9185 333889	LYUDMILA PETROVA	{"email": "lyudmila.petrova_12091967@postgrespro.ru", "phone": "+70742335247"}
0005432211511	298F92	6383 016295	EKATERINA KOLESNIKOVA	{"email": "kolesnikova-ekaterina07011973@postgrespro.ru", "phone": "+70532426040"}
0005432211512	298F92	6024 236276	VIKTORIYA KISELEVA	{"email": "viktoriya-kiseleva.20011972@postgrespro.ru", "phone": "+70319597271"}
0005432211513	D7AACE	0547 674871	VALERIY SOLOVEV	{"email": "valeriy-solovev09061975@postgrespro.ru", "phone": "+70040130522"}
0005432211514	D7AACE	9924 847956	KIRILL NIKOLAEV	{"email": "kirillnikolaev061982@postgrespro.ru", "phone": "+70557396896"}
0005432211515	5DEE5D	8633 367935	GALINA PAVLOVA	{"email": "pavlova.g.24021968@postgrespro.ru", "phone": "+70316707490"}
0005432211516	B0469B	4152 200124	NATALYA NIKITINA	{"email": "nikitinan_26061968@postgrespro.ru", "phone": "+70203577599"}
0005432211517	B0469B	8294 168761	INESSA GRISHINA	{"email": "inessa_grishina_06061975@postgrespro.ru", "phone": "+70303364048"}
0005432211518	F09376	3714 376339	NATALIYA KOMAROVA	{"email": "n-komarova-1982@postgrespro.ru", "phone": "+70963653989"}
0005432211519	BC2526	6580 779478	ALEKSEY ILIN	{"email": "ilinaleksey1964@postgrespro.ru", "phone": "+70950183587"}
0005432211520	BC2526	2848 551531	RAISA POPOVA	{"phone": "+70181582852"}
0005432211521	665635	9771 139061	KLAVDIYA NIKITINA	{"phone": "+70343866867"}
0005432211522	9B90AC	8231 469482	TATYANA VASILEVA	{"phone": "+70303194132"}
0005432211523	A18D5E	7365 340920	TATYANA ZAYCEVA	{"phone": "+70051255222"}
0005432211524	A18D5E	7067 461705	MAKSIM KULIKOV	{"email": "m_kulikov31071974@postgrespro.ru", "phone": "+70487069867"}
0005432211525	5CD95D	0801 548563	GALINA BORISOVA	{"email": "borisovagalina.061963@postgrespro.ru", "phone": "+70414060031"}
0005432211526	5CD95D	7323 163650	TATYANA ERMAKOVA	{"email": "termakova-061977@postgrespro.ru", "phone": "+70454443429"}
0005432211527	ED61B5	3501 903203	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova26111965@postgrespro.ru", "phone": "+70828331128"}
0005432211528	745C5E	7368 380375	ARTUR MAKSIMOV	{"email": "maksimov-artur_121980@postgrespro.ru", "phone": "+70645256492"}
0005432211529	745C5E	9480 084035	NIKOLAY BONDARENKO	{"email": "nikolaybondarenko11061965@postgrespro.ru", "phone": "+70735009390"}
0005432211530	C03E99	8423 326458	LYUDMILA GAVRILOVA	{"email": "gavrilova-lyudmila.051988@postgrespro.ru", "phone": "+70581928751"}
0005432211531	C03E99	9236 035816	VLADIMIR YAKOVLEV	{"phone": "+70085279615"}
0005432211532	C03E99	9296 659064	VERA NIKITINA	{"phone": "+70362157917"}
0005432211533	C03E99	5444 058835	LEONID ROMANOV	{"phone": "+70526204737"}
0005432211534	8BFE6E	3853 902770	VLADIMIR MAKAROV	{"phone": "+70978839093"}
0005432211535	DC4B02	4160 500575	ALEKSANDR SEMENOV	{"phone": "+70738966682"}
0005432211536	DC4B02	0397 663850	OKSANA IVANOVA	{"phone": "+70857843177"}
0005432211537	831D47	1021 207586	TATYANA BARANOVA	{"phone": "+70283456601"}
0005432211538	E41169	3565 911080	SERGEY BELOV	{"email": "belovs_081965@postgrespro.ru", "phone": "+70495967140"}
0005432211539	B65BD7	4679 611671	ANDREY GAVRILOV	{"email": "a.gavrilov-25061979@postgrespro.ru", "phone": "+70206750292"}
0005432211540	93B6E0	5555 416470	MATVEY IVANOV	{"email": "ivanov_matvey1968@postgrespro.ru", "phone": "+70055569730"}
0005432211541	D24498	9836 947070	NINA MATVEEVA	{"email": "matveeva-n-1962@postgrespro.ru", "phone": "+70476671763"}
0005432211542	AED8F0	5429 000083	ELENA IVANOVA	{"phone": "+70449454242"}
0005432211543	B6CD61	3738 902282	ALEKSANDR POPOV	{"email": "aleksandr_popov.071972@postgrespro.ru", "phone": "+70591570698"}
0005432211544	B6CD61	6692 014923	MARIYA KOZLOVA	{"email": "m_kozlova.051973@postgrespro.ru", "phone": "+70020669863"}
0005432211545	03E0B8	3372 912061	KAMIL MATVEEV	{"email": "matveev-k111971@postgrespro.ru", "phone": "+70536153836"}
0005432211546	2127C0	4026 224227	FARID FILIPPOV	{"email": "filippov_farid.29011979@postgrespro.ru", "phone": "+70550422532"}
0005432211547	AE78DA	2581 745050	DENIS TIKHONOV	{"phone": "+70225875642"}
0005432211548	AE78DA	0703 207908	EKATERINA MASLOVA	{"email": "maslova_ekaterina1972@postgrespro.ru", "phone": "+70872553595"}
0005432211549	576EC6	7767 152867	ALEKSEY IVANOV	{"phone": "+70547590596"}
0005432211550	E9EBEB	0761 330959	NATALIYA SOROKINA	{"phone": "+70272758106"}
0005432211551	E9EBEB	6837 491279	KRISTINA YAKOVLEVA	{"phone": "+70961764283"}
0005432211552	E9EBEB	1355 507276	MIKHAIL IVANOV	{"phone": "+70492142829"}
0005432211553	EC4922	5379 386149	NIKOLAY KONOVALOV	{"email": "nikolaykonovalov.061964@postgrespro.ru", "phone": "+70309150272"}
0005432211554	5A9782	9415 824774	OLGA ANTONOVA	{"phone": "+70083137576"}
0005432211555	B4CD12	9341 020549	SEMEN ZAKHAROV	{"phone": "+70305756644"}
0005432211556	F55EFC	4343 025121	VALENTINA KUZMINA	{"phone": "+70374203300"}
0005432211557	E9F597	3452 912160	MARINA KALININA	{"email": "marinakalinina-041970@postgrespro.ru", "phone": "+70974158653"}
0005432211558	E9F597	7158 820554	MARINA VOROBEVA	{"phone": "+70685238204"}
0005432211559	F2F823	4098 611553	SERGEY AFANASEV	{"email": "afanasev-s.06101968@postgrespro.ru", "phone": "+70141608440"}
0005432211560	ACEDE2	3102 699002	SVETLANA KUZNECOVA	{"phone": "+70221039605"}
0005432211561	D1F2C0	4066 891859	IVAN KISELEV	{"phone": "+70218441103"}
0005432211562	906226	2262 269321	ALBERT STEPANOV	{"phone": "+70364814165"}
0005432211563	906226	2312 407077	KARINA KOVALEVA	{"email": "kovalevak-071966@postgrespro.ru", "phone": "+70092783291"}
0005432211564	906226	6501 399999	ARTUR NIKITIN	{"email": "nikitin-artur021969@postgrespro.ru", "phone": "+70759412992"}
0005432211565	63861E	0548 653812	VALERIYA MIKHAYLOVA	{"email": "valeriya.mikhaylova_121970@postgrespro.ru", "phone": "+70673484088"}
0005432211566	63861E	3394 345098	KSENIYA KUZNECOVA	{"phone": "+70048326716"}
0005432211567	5C56F1	3871 373864	ALEKSANDR MOROZOV	{"phone": "+70025627866"}
0005432211568	C95FB4	4743 477690	SEMEN NAUMOV	{"email": "naumov_s.121963@postgrespro.ru", "phone": "+70446521703"}
0005432211569	C95FB4	2149 790431	NIKITA POPOV	{"email": "nikita.popov_1971@postgrespro.ru", "phone": "+70885678782"}
0005432211570	C95FB4	0659 063045	MIKHAIL ANTONOV	{"email": "antonov-m_25091965@postgrespro.ru", "phone": "+70588859297"}
0005432211571	82587D	7088 372468	ANNA LUKYANOVA	{"phone": "+70154057628"}
0005432211572	BE4705	9648 776535	OKSANA ALEKSEEVA	{"phone": "+70209006569"}
0005432211573	7F6722	1492 530002	NADEZHDA GORBUNOVA	{"phone": "+70587348774"}
0005432211574	C217EB	0192 219130	VALENTINA ALEKSEEVA	{"phone": "+70518801210"}
0005432211575	C217EB	5488 126574	VITALIY STEPANOV	{"email": "stepanovvitaliy061970@postgrespro.ru", "phone": "+70164293172"}
0005432211576	E8288E	3220 486078	PETR GRIGOREV	{"email": "p.grigorev-1970@postgrespro.ru", "phone": "+70116161592"}
0005432211577	694C5A	8269 823327	VSEVOLOD DMITRIEV	{"email": "v_dmitriev_01091975@postgrespro.ru", "phone": "+70271839634"}
0005432211578	F14CBA	0526 706706	VLADIMIR SERGEEV	{"phone": "+70360812471"}
0005432211579	F77C64	3660 988667	IVAN ALEKSEEV	{"email": "alekseev_ivan-16121976@postgrespro.ru", "phone": "+70166033124"}
0005432211580	D9BDFD	7254 892393	TATYANA KOROLEVA	{"email": "korolevatatyana081983@postgrespro.ru", "phone": "+70815112748"}
0005432211581	F52611	7775 927201	NATALYA NESTEROVA	{"phone": "+70569336807"}
0005432211582	72B009	9343 199337	IVAN ILIN	{"phone": "+70149157845"}
0005432211583	ABFFA1	8120 548665	ANTONIDA PETROVA	{"email": "a.petrova_031978@postgrespro.ru", "phone": "+70934494227"}
0005432211584	9C97B4	5289 673004	ANNA BARANOVA	{"email": "a.baranova-021974@postgrespro.ru", "phone": "+70052052177"}
0005432211585	9C97B4	5504 745107	NATALYA ANISIMOVA	{"phone": "+70937098226"}
0005432211586	39B962	4281 007343	ALEKSANDR MEDVEDEV	{"phone": "+70876559507"}
0005432211587	2F622D	5512 543073	NATALIYA FROLOVA	{"email": "frolova_n12071980@postgrespro.ru", "phone": "+70000176996"}
0005432211588	7B89B9	7171 372567	LYUDMILA MEDVEDEVA	{"phone": "+70689022975"}
0005432211589	228390	3169 022685	VERA ALEKSANDROVA	{"email": "valeksandrova1984@postgrespro.ru", "phone": "+70649287098"}
0005432211590	F93884	3493 250694	VYACHESLAV BORISOV	{"phone": "+70345852209"}
0005432211591	F93884	1982 398047	TATYANA SIDOROVA	{"email": "sidorova_tatyana.071973@postgrespro.ru", "phone": "+70462326772"}
0005432211592	1A6740	5560 122708	VALERIY ILIN	{"phone": "+70311381092"}
0005432211593	1A6740	7944 503217	LYUDMILA FROLOVA	{"email": "frolova-l.051963@postgrespro.ru", "phone": "+70332886156"}
0005432211594	AA8269	8206 960557	NIKOLAY NAUMOV	{"phone": "+70458385464"}
0005432211595	23C9C7	8733 816317	SVETLANA KULIKOVA	{"phone": "+70789181173"}
0005432211596	23C9C7	6235 530590	ANATOLIY STEPANOV	{"email": "stepanov-anatoliy.1972@postgrespro.ru", "phone": "+70037346545"}
0005432211597	BE8CD2	7171 945003	ALEKSANDRA TITOVA	{"email": "titova-aleksandra-1963@postgrespro.ru", "phone": "+70546042662"}
0005432211598	BE8CD2	4598 815781	LEONTIY KUZNECOV	{"email": "leontiykuznecov061972@postgrespro.ru", "phone": "+70536300687"}
0005432211599	BD77B5	1728 514420	ARSENIY SERGEEV	{"phone": "+70795843326"}
0005432211600	A82139	1634 564485	NATALYA ZHUKOVA	{"email": "zhukova_natalya27051969@postgrespro.ru", "phone": "+70761277701"}
0005432211601	A82139	6844 715960	ALEKSEY STEPANOV	{"email": "a-stepanov28081965@postgrespro.ru", "phone": "+70144658901"}
0005432211602	922490	4716 487513	RAISA PETROVA	{"phone": "+70353604951"}
0005432211603	F7C078	5048 432898	EKATERINA MIKHAYLOVA	{"email": "e.mikhaylova.1983@postgrespro.ru", "phone": "+70592681245"}
0005432211604	F7C078	5841 952111	DMITRIY TARASOV	{"phone": "+70048637099"}
0005432211605	F7C078	9968 757898	ALEKSANDR OSIPOV	{"email": "aleksandr.osipov.1965@postgrespro.ru", "phone": "+70485967922"}
0005432211606	05EE93	1295 659368	ROMAN SOKOLOV	{"phone": "+70270817573"}
0005432211607	05EE93	8709 989668	EKATERINA POPOVA	{"email": "popova-e-25071973@postgrespro.ru", "phone": "+70585002699"}
0005432211608	1390AA	0830 223783	MARIYA PETROVA	{"phone": "+70734017043"}
0005432211609	1390AA	5567 765118	VERA SAVELEVA	{"phone": "+70573704005"}
0005432211610	4751F8	3274 111234	MARINA FOMINA	{"email": "fomina.marina.1967@postgrespro.ru", "phone": "+70368098971"}
0005432211611	B7B17F	4796 568568	ROMAN ZHURAVLEV	{"phone": "+70233463876"}
0005432211612	46A5EE	2617 254569	YULIYA PETROVA	{"email": "petrova_y-1963@postgrespro.ru", "phone": "+70888542481"}
0005432211613	AF90C6	7463 020147	MARIYA ZAKHAROVA	{"phone": "+70456821973"}
0005432211614	1ECA8C	5615 879986	SERGEY MATVEEV	{"phone": "+70968564372"}
0005432211615	A36249	6744 339286	DMITRIY NIKOLAEV	{"phone": "+70616185544"}
0005432211616	AC21D7	8110 373090	ALEKSANDRA KUZNECOVA	{"phone": "+70111338301"}
0005432211617	AC21D7	0464 786272	MARINA KOLESNIKOVA	{"email": "kolesnikova-m_17121967@postgrespro.ru", "phone": "+70049034252"}
0005432211618	D23A12	1472 464319	EVGENIY KUZNECOV	{"email": "ekuznecov081970@postgrespro.ru", "phone": "+70361419798"}
0005432211619	BDAD58	3053 364999	DIANA KULIKOVA	{"email": "d-kulikova.19071976@postgrespro.ru", "phone": "+70311304492"}
0005432211620	D51CB8	8019 195355	NATALYA SERGEEVA	{"phone": "+70041789383"}
0005432211621	B4444B	2376 332592	VALENTINA NESTEROVA	{"email": "nesterova.v23091980@postgrespro.ru", "phone": "+70186497127"}
0005432211622	B4444B	2311 147949	YURIY ZHURAVLEV	{"phone": "+70055582585"}
0005432211623	0BC5EA	6723 417950	ALEKSEY DMITRIEV	{"email": "dmitrievaleksey.1974@postgrespro.ru", "phone": "+70199070186"}
0005432211624	89149C	2413 167690	ALEKSANDR SMIRNOV	{"phone": "+70596891500"}
0005432211625	F75C95	5668 641395	DMITRIY DAVYDOV	{"email": "davydov.d_071976@postgrespro.ru", "phone": "+70094889526"}
0005432211626	73B828	9618 720185	VERA KOROLEVA	{"email": "koroleva_vera.101969@postgrespro.ru", "phone": "+70039671975"}
0005432211627	9782B7	2481 172475	NIKOLAY GORBUNOV	{"phone": "+70338440746"}
0005432211628	9782B7	2225 419724	VALENTINA POPOVA	{"phone": "+70058821440"}
0005432211629	243F56	1467 586596	VIKTOR IVANOV	{"email": "ivanov.v-1975@postgrespro.ru", "phone": "+70861218720"}
0005432211630	142741	0363 289844	VALENTINA ISAEVA	{"email": "v-isaeva.31031995@postgrespro.ru", "phone": "+70360291340"}
0005432211631	8E1ADE	8478 922675	GEORGIY KONOVALOV	{"email": "konovalovgeorgiy.021968@postgrespro.ru", "phone": "+70102206832"}
0005432211632	8E1ADE	4981 017076	RAISA ZAYCEVA	{"email": "zaycevar.15021979@postgrespro.ru", "phone": "+70502785829"}
0005432211633	607E72	8032 143672	OLEG PETROV	{"phone": "+70111770934"}
0005432211634	20F6C4	6503 217180	MARIYA FILIPPOVA	{"email": "m.filippova.051970@postgrespro.ru", "phone": "+70638176363"}
0005432211635	701053	7802 497249	SERGEY NAZAROV	{"email": "nazarovsergey.111973@postgrespro.ru", "phone": "+70617716313"}
0005432211636	701053	5131 519912	YAKOV ROMANOV	{"email": "y-romanov_14081976@postgrespro.ru", "phone": "+70803519564"}
0005432211637	0A7881	7972 819404	ANASTASIYA ZAKHAROVA	{"phone": "+70512855412"}
0005432211638	DB2077	4136 707853	ALEKSANDRA DAVYDOVA	{"email": "davydova.a_18101971@postgrespro.ru", "phone": "+70124771487"}
0005432211639	DB2077	4051 024079	VYACHESLAV TIKHONOV	{"email": "tikhonov-vyacheslav081966@postgrespro.ru", "phone": "+70009281452"}
0005432211640	FDBB80	4405 258884	YANA KUZNECOVA	{"email": "yana-kuznecova_13011961@postgrespro.ru", "phone": "+70842194198"}
0005432211641	8538FA	0959 912196	SERGEY KARPOV	{"email": "sergey-karpov.101971@postgrespro.ru", "phone": "+70582551956"}
0005432211642	8538FA	4711 699736	NIKITA KISELEV	{"phone": "+70776447311"}
0005432211643	1505BF	6811 410403	EKATERINA ALEKSEEVA	{"email": "ealekseeva_1975@postgrespro.ru", "phone": "+70750000700"}
0005432211644	240909	8563 439618	POLINA MIRONOVA	{"phone": "+70883888067"}
0005432211645	F32EA7	0512 227843	ANNA PETROVA	{"email": "anna-petrova_18081979@postgrespro.ru", "phone": "+70822675361"}
0005432211646	36EE15	4340 726662	SVETLANA KUZNECOVA	{"email": "kuznecova.s-06061971@postgrespro.ru", "phone": "+70293240941"}
0005432211647	329ADF	6557 228054	SVETLANA VOROBEVA	{"email": "vorobeva.svetlana.18121981@postgrespro.ru", "phone": "+70175213912"}
0005432211648	125FD8	8378 712079	ANNA YAKOVLEVA	{"email": "yakovleva-anna.1973@postgrespro.ru", "phone": "+70278050841"}
0005432211649	BBA917	8379 307812	NINA GAVRILOVA	{"email": "ninagavrilova24081978@postgrespro.ru", "phone": "+70656395348"}
0005432211650	39FE5A	7582 055389	IGOR KUZNECOV	{"phone": "+70216035807"}
0005432211651	39FE5A	1612 630527	MIKHAIL ALEKSEEV	{"phone": "+70366328083"}
0005432211652	D70E9A	3170 361254	IGOR MIKHAYLOV	{"phone": "+70609028289"}
0005432211653	D70E9A	2838 374865	ALEKSANDR SMIRNOV	{"email": "smirnov.a.021963@postgrespro.ru", "phone": "+70611469420"}
0005432211654	14DF8B	8305 563333	VASILIY NOVIKOV	{"phone": "+70827430753"}
0005432211655	14DF8B	8820 846328	VLADIMIR ZAYCEV	{"email": "vzaycev.1978@postgrespro.ru", "phone": "+70189636290"}
0005432211656	2FF5CF	9139 335115	SERGEY IVANOV	{"phone": "+70609141004"}
0005432211657	AD102E	8927 942824	PAVEL ANDREEV	{"phone": "+70987134072"}
0005432211658	E2EE38	4349 348051	VERA IVANOVA	{"email": "v-ivanova.1978@postgrespro.ru", "phone": "+70308644590"}
0005432211659	21310D	8763 416385	ALEVTINA KUZMINA	{"email": "kuzmina-alevtina091979@postgrespro.ru", "phone": "+70495290110"}
0005432211660	78F5B7	0823 873107	ANASTASIYA DANILOVA	{"email": "anastasiya.danilova-16061965@postgrespro.ru", "phone": "+70437094000"}
0005432211661	B64342	2729 520275	ZARINA PAVLOVA	{"phone": "+70698887453"}
0005432211662	B64342	4427 121163	RUSTEM SOLOVEV	{"phone": "+70904771728"}
0005432211663	3210DE	9055 048777	ALEKSANDR MAKAROV	{"phone": "+70948556668"}
0005432211664	3210DE	4376 547860	LILIYA POPOVA	{"email": "popova-l_1966@postgrespro.ru", "phone": "+70053978064"}
0005432211665	4F264C	3386 759864	YURIY ZHURAVLEV	{"email": "yuriyzhuravlev.1968@postgrespro.ru", "phone": "+70762603462"}
0005432211666	6F384B	8926 328395	VALERIY SOKOLOV	{"phone": "+70894286729"}
0005432211667	6F384B	0689 461536	TATYANA SOKOLOVA	{"email": "sokolovat_1963@postgrespro.ru", "phone": "+70335105892"}
0005432211668	4BA472	1522 962771	EKATERINA VOLKOVA	{"email": "evolkova_15071959@postgrespro.ru", "phone": "+70464677749"}
0005432211669	24E71D	5306 522823	SERGEY MARTYNOV	{"email": "martynov-s-071975@postgrespro.ru", "phone": "+70451959777"}
0005432211670	0319ED	5404 882223	EVGENIY KARPOV	{"email": "karpov.e.1970@postgrespro.ru", "phone": "+70730200706"}
0005432211671	DE6242	4880 810935	VALENTIN IVANOV	{"phone": "+70156405738"}
0005432211672	F1F4DE	2748 934420	SVETLANA FROLOVA	{"phone": "+70866667618"}
0005432211673	F1F4DE	9595 762620	TAMARA KONOVALOVA	{"phone": "+70741159990"}
0005432211674	7A64BF	9752 048180	ARTEM ISAEV	{"phone": "+70607353771"}
0005432211675	4E2BBD	1279 855491	ALEKSANDR SAVELEV	{"phone": "+70452415609"}
0005432211676	C20EF9	6392 700873	ALEKSANDR PETROV	{"email": "aleksandr.petrov.17091973@postgrespro.ru", "phone": "+70939361178"}
0005432211677	3120EB	5921 758617	OLGA KOROLEVA	{"email": "korolevaolga-121965@postgrespro.ru", "phone": "+70632918193"}
0005432211678	2B58E1	7434 787154	VASILIY GORBUNOV	{"email": "vgorbunov081969@postgrespro.ru", "phone": "+70552641179"}
0005432211679	529497	7323 066086	VYACHESLAV IVANOV	{"phone": "+70918955946"}
0005432211680	EF72C2	9695 593242	SERGEY MOROZOV	{"email": "s.morozov.1966@postgrespro.ru", "phone": "+70304145610"}
0005432211681	CF4589	8509 383242	YULIYA POPOVA	{"phone": "+70483602563"}
0005432211682	E691BB	0751 629761	GALINA VOLKOVA	{"email": "galina-volkova.081963@postgrespro.ru", "phone": "+70213241600"}
0005432211683	E691BB	5723 108878	IVAN FOMIN	{"phone": "+70176056850"}
0005432211684	CCC8F0	8299 913147	SERGEY KISELEV	{"email": "kiselev_sergey_1971@postgrespro.ru", "phone": "+70142588349"}
0005432211685	CCC8F0	5867 990249	MARAT ISAEV	{"email": "isaev-marat.1970@postgrespro.ru", "phone": "+70809365395"}
0005432211686	485B1E	9053 562272	RINAT STEPANOV	{"email": "rinat.stepanov1965@postgrespro.ru", "phone": "+70732007833"}
0005432211687	BC27C4	1899 891732	ANASTASIYA SCHERBAKOVA	{"phone": "+70302251334"}
0005432211688	BC27C4	1323 793855	EVGENIY MIRONOV	{"email": "e.mironov.22061976@postgrespro.ru", "phone": "+70277071575"}
0005432211689	3D2DC3	7348 108746	ROMAN NOVIKOV	{"phone": "+70969419382"}
0005432211690	890790	0064 759629	NATALYA DAVYDOVA	{"email": "natalya_davydova.091976@postgrespro.ru", "phone": "+70385812524"}
0005432211691	890790	7102 965121	ALEKSANDRA NAZAROVA	{"email": "nazarova_aleksandra_1969@postgrespro.ru", "phone": "+70410678008"}
0005432211692	890790	9872 354131	SERGEY OSIPOV	{"email": "osipovs091967@postgrespro.ru", "phone": "+70342544275"}
0005432211693	8C34FD	8836 015535	TATYANA ZHURAVLEVA	{"email": "zhuravlevat091977@postgrespro.ru", "phone": "+70310324533"}
0005432211694	C9611A	7768 226611	VASILIY MAKAROV	{"email": "makarovvasiliy-15031977@postgrespro.ru", "phone": "+70733397141"}
0005432211695	C9611A	9671 025195	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov04011966@postgrespro.ru", "phone": "+70845174451"}
0005432211696	1561D9	7706 869353	SVETLANA KRASNOVA	{"phone": "+70094557366"}
0005432211697	CB93B7	1449 207416	EVGENIY SOROKIN	{"phone": "+70399411710"}
0005432211698	9657BC	8423 425797	RIMMA EFIMOVA	{"phone": "+70507347317"}
0005432211699	E9A22B	3909 107938	ANDREY SIDOROV	{"phone": "+70423362885"}
0005432211700	D13148	3643 336356	NINA ZHUKOVA	{"phone": "+70280490296"}
0005432211701	2EC149	4657 326168	ANTON KONOVALOV	{"phone": "+70071387466"}
0005432211702	2EC149	8295 169562	IVAN VOLKOV	{"email": "volkov.i111953@postgrespro.ru", "phone": "+70178074037"}
0005432211703	AAD124	6199 016852	KSENIYA BARANOVA	{"phone": "+70366047163"}
0005432211704	AAD124	7146 019122	OLEG ANTONOV	{"phone": "+70172389726"}
0005432211705	47C74E	0666 428660	ALEKSANDRA KOROLEVA	{"phone": "+70887770550"}
0005432211706	38E376	0220 054065	NINA KAZAKOVA	{"email": "kazakova-n-22111974@postgrespro.ru", "phone": "+70438358056"}
0005432211707	09D2A3	0897 633743	FEDOR PETROV	{"email": "petrovf081981@postgrespro.ru", "phone": "+70175148051"}
0005432211708	09D2A3	0684 627014	ALENA ZHURAVLEVA	{"phone": "+70605848174"}
0005432211709	3C2A07	9887 363266	SERGEY ZHUKOV	{"email": "s.zhukov_15061969@postgrespro.ru", "phone": "+70842300432"}
0005432211710	3C2A07	7118 820213	ANTON KUZNECOV	{"phone": "+70630821479"}
0005432211711	87D6D4	8001 581650	NINA KUZNECOVA	{"phone": "+70460278060"}
0005432211712	E416DE	7661 855211	NATALYA GRISHINA	{"email": "natalya_grishina.1973@postgrespro.ru", "phone": "+70429409563"}
0005432211713	E416DE	5169 406360	EKATERINA MASLOVA	{"phone": "+70475570925"}
0005432211714	CEF15C	5754 632218	IVAN VOROBEV	{"phone": "+70176592395"}
0005432211715	CEF15C	7184 259760	EKATERINA POPOVA	{"phone": "+70004315455"}
0005432211716	63170E	4016 261777	ALEKSEY VASILEV	{"email": "aleksey.vasilev.13081983@postgrespro.ru", "phone": "+70741655214"}
0005432211717	1DFD0A	9053 691690	ANDREY VASILEV	{"email": "andrey-vasilev.1974@postgrespro.ru", "phone": "+70313282020"}
0005432211718	1DFD0A	2024 981456	EVGENIY DMITRIEV	{"phone": "+70209649007"}
0005432211719	1DFD0A	7846 017588	ALEKSANDR IVANOV	{"phone": "+70327473127"}
0005432211720	A40E35	6351 396065	ANATOLIY VOROBEV	{"phone": "+70199334155"}
0005432211721	A40E35	2166 876717	OLESYA ZAYCEVA	{"email": "zayceva_o.15061964@postgrespro.ru", "phone": "+70961703654"}
0005432211722	54DE79	1856 694848	MARINA KOZLOVA	{"phone": "+70459007579"}
0005432211723	3C63C5	0274 017146	OLGA POPOVA	{"phone": "+70432414712"}
0005432211724	074144	3361 338329	MARINA VOLKOVA	{"email": "volkova.m_30081971@postgrespro.ru", "phone": "+70702513250"}
0005432213539	4FA88A	9566 201914	GALINA BELOVA	{"phone": "+70184490362"}
0005432213540	4FA88A	4123 978396	ALEKSANDR MARTYNOV	{"email": "aleksandr-martynov_111986@postgrespro.ru", "phone": "+70168748336"}
0005432213541	6C31C8	6561 201735	ELENA ERMAKOVA	{"phone": "+70661251011"}
0005432213542	6C31C8	2683 147782	IGOR BONDARENKO	{"phone": "+70366694572"}
0005432213543	0F69F9	1297 772333	ALEKSEY MAKSIMOV	{"phone": "+70101579922"}
0005432213544	4CDE84	3190 329608	VLADIMIR SAVELEV	{"email": "vladimirsavelev02081981@postgrespro.ru", "phone": "+70674365220"}
0005432213545	4CDE84	9574 569703	EVGENIYA MIKHAYLOVA	{"email": "mikhaylova-evgeniya_011967@postgrespro.ru", "phone": "+70054746452"}
0005432213546	3088EB	0282 241228	VYACHESLAV MIKHAYLOV	{"email": "vyacheslavmikhaylov-02071963@postgrespro.ru", "phone": "+70929758971"}
0005432213547	A3721D	0410 096497	ELENA MELNIKOVA	{"phone": "+70139780892"}
0005432213548	10653E	5476 407596	LYUDMILA FROLOVA	{"phone": "+70672053438"}
0005432213549	378E15	4374 529531	ZINAIDA CHERNOVA	{"phone": "+70788340676"}
0005432213550	252F3E	9210 285193	ALEKSANDR KUZNECOV	{"phone": "+70240719302"}
0005432213551	252F3E	2582 787921	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov_1976@postgrespro.ru", "phone": "+70243757003"}
0005432213552	A47C15	5928 904021	EGOR SERGEEV	{"phone": "+70225588079"}
0005432213553	A47C15	9355 246636	MIKHAIL DENISOV	{"phone": "+70739258423"}
0005432213554	839E4F	2626 296989	NATALYA KOMAROVA	{"phone": "+70208942153"}
0005432213555	EE572A	3561 750255	SERGEY NAZAROV	{"phone": "+70254629991"}
0005432213556	1BA986	2924 003801	TATYANA YUDINA	{"phone": "+70388732983"}
0005432213557	5F9AB7	6770 383956	ROZA VOLKOVA	{"email": "r_volkova.19021974@postgrespro.ru", "phone": "+70122562417"}
0005432213558	5F9AB7	2777 473390	MARIYA KUZNECOVA	{"email": "kuznecovam-121973@postgrespro.ru", "phone": "+70010918769"}
0005432213559	8AF0C2	5756 064081	ALEKSEY KULIKOV	{"email": "kulikov_a1968@postgrespro.ru", "phone": "+70372591054"}
0005432213560	5A511A	3097 984568	ALEKSANDR IVANOV	{"phone": "+70129786577"}
0005432213561	6A2E8F	4769 667550	VIKTOR SEMENOV	{"phone": "+70345140841"}
0005432213562	6A2E8F	5183 215037	VLADIMIR KOZLOV	{"email": "kozlov.vladimir06091973@postgrespro.ru", "phone": "+70570439266"}
0005432213563	04FF4B	7699 532591	ALEKSEY NAZAROV	{"email": "nazarov_aleksey-101978@postgrespro.ru", "phone": "+70823566485"}
0005432213564	57BA1D	5721 082782	ARTEM ZAYCEV	{"phone": "+70568160073"}
0005432213565	57BA1D	0449 888214	IGOR ZAYCEV	{"email": "zaycev.igor.1979@postgrespro.ru", "phone": "+70901519437"}
0005432213566	8F7E30	5762 467192	EKATERINA EGOROVA	{"email": "egorovaekaterina-1974@postgrespro.ru", "phone": "+70677682317"}
0005432213567	BD2B2D	4847 265081	DMITRIY IVANOV	{"email": "d_ivanov-01061977@postgrespro.ru", "phone": "+70544872768"}
0005432213568	BD2B2D	0558 819361	ROZA KUZNECOVA	{"email": "r-kuznecova-14061975@postgrespro.ru", "phone": "+70780626524"}
0005432213569	9DB77C	4676 779878	NATALIYA IVANOVA	{"email": "nataliya-ivanova-1991@postgrespro.ru", "phone": "+70297064000"}
0005432213570	2B5DA8	0575 265809	ANASTASIYA SOLOVEVA	{"phone": "+70374631169"}
0005432213571	1204AF	8814 727965	NIKOLAY ANTONOV	{"phone": "+70943699052"}
0005432213572	3A1458	7927 407817	GERMAN FILIPPOV	{"email": "filippov_g-01111974@postgrespro.ru", "phone": "+70952924017"}
0005432213573	E88631	3700 696782	DENIS KUZNECOV	{"email": "kuznecov-d.14061969@postgrespro.ru", "phone": "+70047666632"}
0005432213574	DAD013	0437 758530	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a_15011963@postgrespro.ru", "phone": "+70969262703"}
0005432213575	F69B4D	9237 787205	YULIYA GRISHINA	{"email": "yuliya.grishina.04031966@postgrespro.ru", "phone": "+70414222387"}
0005432213576	F69B4D	1906 752230	VLADIMIR ABRAMOV	{"phone": "+70707314035"}
0005432213577	00AFED	9422 550534	EKATERINA YUDINA	{"email": "ekaterinayudina.12101972@postgrespro.ru", "phone": "+70071883897"}
0005432213578	00AFED	8265 519616	OLGA BELOVA	{"phone": "+70560086678"}
0005432213579	B1AE5A	3854 444104	PAVEL IVANOV	{"phone": "+70998063325"}
0005432213580	D9B611	0324 055357	YULIYA ARKHIPOVA	{"phone": "+70064734659"}
0005432213581	D9B611	0440 231254	RUSLAN TIMOFEEV	{"phone": "+70406756317"}
0005432213582	D9B611	4101 789199	MARINA SOKOLOVA	{"phone": "+70403196496"}
0005432213583	04F441	0687 375172	ANTONINA SOROKINA	{"phone": "+70342871197"}
0005432213584	0041E6	9513 585255	MIKHAIL GUSEV	{"email": "mikhailgusev.14071961@postgrespro.ru", "phone": "+70548436272"}
0005432213585	954AB3	3530 579279	SERGEY VLASOV	{"email": "s.vlasov25061965@postgrespro.ru", "phone": "+70980889761"}
0005432213586	954AB3	6150 570747	ARTEM TIMOFEEV	{"phone": "+70491963412"}
0005432213587	5D9B0C	8649 212719	DMITRIY SIDOROV	{"email": "sidorov.dmitriy19081964@postgrespro.ru", "phone": "+70636933659"}
0005432213588	5D9B0C	6209 792890	KONSTANTIN KUDRYASHOV	{"email": "konstantin_kudryashov-021981@postgrespro.ru", "phone": "+70223427210"}
0005432213589	6E60BD	4768 485859	ALINA KOZLOVA	{"email": "a-kozlova06071973@postgrespro.ru", "phone": "+70627678564"}
0005432213590	FA2571	9243 081751	GALINA ZAYCEVA	{"email": "zayceva.galina.061982@postgrespro.ru", "phone": "+70468637651"}
0005432213591	E18F88	5957 546431	DARYA EGOROVA	{"phone": "+70068767458"}
0005432213592	D46CEC	1176 286995	ANASTASIYA NIKITINA	{"email": "nikitina.anastasiya_31011975@postgrespro.ru", "phone": "+70833329675"}
0005432213593	3C52BA	3149 963528	IRINA MASLOVA	{"email": "imaslova_1984@postgrespro.ru", "phone": "+70139439013"}
0005432213594	3C52BA	2075 774774	SERGEY SOROKIN	{"email": "sorokin.sergey.1975@postgrespro.ru", "phone": "+70028607674"}
0005432213595	162D36	6062 770331	ANTON STEPANOV	{"phone": "+70754805892"}
0005432213596	162D36	4291 874395	VERA NIKIFOROVA	{"email": "nikiforova_vera-011972@postgrespro.ru", "phone": "+70138543256"}
0005432213597	94E8E7	5481 248561	EKATERINA LOGINOVA	{"phone": "+70436010354"}
0005432213598	CD3E13	1059 146121	NATALYA VOLKOVA	{"phone": "+70919626273"}
0005432213599	F28D1C	0563 459842	LYUDMILA TIMOFEEVA	{"email": "lyudmila-timofeeva_061977@postgrespro.ru", "phone": "+70855110360"}
0005432213600	86AA7B	7025 869749	GENNADIY KUZMIN	{"email": "kuzming-1962@postgrespro.ru", "phone": "+70624120258"}
0005432213601	461106	8134 427171	LYUDMILA GERASIMOVA	{"phone": "+70374121356"}
0005432213602	461106	6211 742771	BORIS ISAEV	{"phone": "+70887745242"}
0005432213603	1E3C7A	0832 959717	GALINA ANTONOVA	{"phone": "+70027886125"}
0005432213604	1B1A61	9736 061785	RUSLAN NOVIKOV	{"email": "novikov_ruslan-111969@postgrespro.ru", "phone": "+70189278972"}
0005432213605	AA6289	2659 923995	ALEKSANDRA RODIONOVA	{"email": "rodionovaa-1966@postgrespro.ru", "phone": "+70686767140"}
0005432213606	0E042B	7025 603899	INNA VOLKOVA	{"email": "volkova.i_1969@postgrespro.ru", "phone": "+70632737729"}
0005432213607	0E042B	8175 481338	ALEKSANDR SHEVCHENKO	{"phone": "+70216232730"}
0005432213608	275260	7547 487241	RAISA AKIMOVA	{"phone": "+70404996121"}
0005432213609	275260	4585 222466	VITALIY VOLKOV	{"email": "volkovvitaliy10121976@postgrespro.ru", "phone": "+70193317860"}
0005432213610	DC9BA9	4148 433376	VALENTINA BOGDANOVA	{"email": "bogdanova-valentina.101966@postgrespro.ru", "phone": "+70938717735"}
0005432213611	66EF8B	3572 621542	YAROSLAVA ERMAKOVA	{"phone": "+70161985416"}
0005432213612	889798	2823 411826	SOFYA SOROKINA	{"phone": "+70020329148"}
0005432213613	D739FF	6199 295125	SERGEY KOZLOV	{"phone": "+70733751560"}
0005432213614	4FB917	6475 815356	YULIYA ILINA	{"phone": "+70455487498"}
0005432213615	46B5C5	7556 019241	ELENA SAVELEVA	{"email": "saveleva-e071973@postgrespro.ru", "phone": "+70221709916"}
0005432213616	649CA6	8382 602567	VIKTOR NAZAROV	{"phone": "+70159348330"}
0005432213617	35D27A	6413 504051	LYUDMILA GAVRILOVA	{"email": "lgavrilova-22051973@postgrespro.ru", "phone": "+70318508420"}
0005432213618	D4E81F	3850 695407	SERGEY PETROV	{"email": "petrovs_1979@postgrespro.ru", "phone": "+70245586645"}
0005432213619	28DB8C	7365 068303	ELENA ZHURAVLEVA	{"email": "zhuravleva_elena.1978@postgrespro.ru", "phone": "+70325249809"}
0005432213620	10D19E	0559 799181	SERGEY SOKOLOV	{"phone": "+70410748807"}
0005432213621	5FDBF4	7530 702592	INNA EGOROVA	{"phone": "+70226478423"}
0005432213622	372BC0	0784 817751	SVETLANA ANISIMOVA	{"email": "anisimova_svetlana_1960@postgrespro.ru", "phone": "+70561882515"}
0005432213623	372BC0	4533 896163	DMITRIY FILIPPOV	{"phone": "+70593737107"}
0005432213624	E91DBB	8547 692448	ANZHELA EGOROVA	{"phone": "+70630236949"}
0005432213625	012A78	7435 738992	MARINA NOVIKOVA	{"email": "m.novikova041973@postgrespro.ru", "phone": "+70993896705"}
0005432213626	C2FF95	3896 993453	YULIYA KOROLEVA	{"email": "yuliyakoroleva.10061965@postgrespro.ru", "phone": "+70174796086"}
0005432213627	3F0FAF	8200 201941	KONSTANTIN YAKOVLEV	{"email": "konstantin.yakovlev_021975@postgrespro.ru", "phone": "+70451359506"}
0005432213628	3F0FAF	0772 900818	GALINA SOKOLOVA	{"phone": "+70518083484"}
0005432213629	9FD698	5660 288465	IGNAT MELNIKOV	{"email": "melnikov_ignat-28021980@postgrespro.ru", "phone": "+70450680216"}
0005432213630	90A218	8860 700037	VIKTOR GAVRILOV	{"email": "viktorgavrilov-1965@postgrespro.ru", "phone": "+70106827394"}
0005432213631	D975E5	8874 251071	SERGEY NIKITIN	{"email": "snikitin1966@postgrespro.ru", "phone": "+70034480994"}
0005432213632	E8B11F	2180 614521	SVETLANA BELOVA	{"phone": "+70728191161"}
0005432213633	4F1536	9513 237630	EKATERINA SEMENOVA	{"phone": "+70269157057"}
0005432213634	BA276A	1267 951467	NADEZHDA NAZAROVA	{"email": "nadezhda_nazarova.09101972@postgrespro.ru", "phone": "+70690719885"}
0005432213635	8B209C	0813 139805	ANASTASIYA VOLKOVA	{"phone": "+70848329419"}
0005432213636	A68BE6	9207 299007	OLGA MIKHAYLOVA	{"email": "mikhaylovao_09041980@postgrespro.ru", "phone": "+70053880608"}
0005432213637	B756B1	1114 558490	GENNADIY KUZNECOV	{"email": "gennadiykuznecov081965@postgrespro.ru", "phone": "+70234230412"}
0005432213638	A36073	6242 903495	ANDREY ILIN	{"email": "a-ilin.091974@postgrespro.ru", "phone": "+70075128120"}
0005432213639	D707EB	0765 841278	ANVAR SIDOROV	{"email": "sidorov_anvar23121969@postgrespro.ru", "phone": "+70991255846"}
0005432213640	D707EB	0729 756467	VIKTOR SERGEEV	{"phone": "+70135942025"}
0005432213641	1AA02F	2084 227322	LYUDMILA POPOVA	{"phone": "+70656314133"}
0005432213642	1AA02F	5840 755627	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov1969@postgrespro.ru", "phone": "+70782814285"}
0005432213643	1AA02F	1845 489810	ALEKSANDR PAVLOV	{"phone": "+70199369889"}
0005432213644	5B1AE8	5948 555834	LIDIYA KISELEVA	{"phone": "+70780442437"}
0005432213645	5B1AE8	6745 699722	OKSANA BELYAEVA	{"email": "belyaeva-oksana.111966@postgrespro.ru", "phone": "+70433637533"}
0005432213646	52B3EC	2901 016202	LYUBOV NAUMOVA	{"email": "naumova-lyubov_17071979@postgrespro.ru", "phone": "+70874558013"}
0005432213647	29BDBD	5245 459993	VLADIMIR KOROLEV	{"phone": "+70782239678"}
0005432213648	51FBD9	6700 505079	SERGEY ILIN	{"email": "s_ilin_041974@postgrespro.ru", "phone": "+70352544424"}
0005432213649	B403D8	7840 399969	GALINA IVANOVA	{"phone": "+70177873884"}
0005432213650	7B80F6	6620 611014	NINA VOLKOVA	{"phone": "+70281777540"}
0005432213651	F54EAB	3061 291405	ALFIYA TIKHONOVA	{"phone": "+70831955568"}
0005432213652	002EA6	4761 305178	IVAN GRIGOREV	{"email": "grigorev.i_19111967@postgrespro.ru", "phone": "+70987280468"}
0005432213653	065B08	0482 769944	LYUDMILA PETROVA	{"phone": "+70748347053"}
0005432213654	043DC3	7385 609777	TATYANA SMIRNOVA	{"email": "smirnova_tatyana_081972@postgrespro.ru", "phone": "+70881778229"}
0005432213655	1A4471	2389 831832	ANASTASIYA BELOVA	{"email": "belova-anastasiya-061974@postgrespro.ru", "phone": "+70391133624"}
0005432213656	3E0E96	8124 019478	VLADIMIR FROLOV	{"phone": "+70286755204"}
0005432213657	8017A9	0587 712246	GEORGIY FOMIN	{"phone": "+70358129466"}
0005432213658	09B986	5139 480228	OLGA KUZNECOVA	{"email": "kuznecova_olga-26111970@postgrespro.ru", "phone": "+70989710104"}
0005432213659	09B986	7498 312120	VERA ROMANOVA	{"email": "v_romanova-081980@postgrespro.ru", "phone": "+70567645667"}
0005432213660	5C787A	6715 547784	ANASTASIYA MARTYNOVA	{"email": "anastasiyamartynova1981@postgrespro.ru", "phone": "+70389318688"}
0005432213661	6EF06D	2351 785940	ANNA POPOVA	{"phone": "+70942839528"}
0005432213662	6EF06D	5102 221243	TAMARA MATVEEVA	{"email": "matveeva.tamara1965@postgrespro.ru", "phone": "+70807628430"}
0005432213663	1C556A	2954 620993	DANILA KUZNECOV	{"email": "danila-kuznecov05091970@postgrespro.ru", "phone": "+70439347654"}
0005432213664	1C556A	3984 609703	ILYA FROLOV	{"phone": "+70090024219"}
0005432213665	E6A9AB	5376 538521	ALEKSEY KUZMIN	{"email": "kuzmin_a.101984@postgrespro.ru", "phone": "+70985987388"}
0005432213666	F59250	7957 312181	OLGA MAKSIMOVA	{"phone": "+70528180426"}
0005432213667	6A3D8F	3326 070303	OLGA KONDRATEVA	{"email": "olga.kondrateva_111969@postgrespro.ru", "phone": "+70234092025"}
0005432213668	6A3D8F	9386 224001	VLADISLAV ORLOV	{"phone": "+70783342564"}
0005432213669	29C3D1	2811 599886	NATALYA ILINA	{"phone": "+70577866760"}
0005432213670	29C3D1	3288 484736	SERGEY ZAYCEV	{"email": "s-zaycev121963@postgrespro.ru", "phone": "+70318837222"}
0005432213671	29C3D1	9514 355870	TAISIYA TITOVA	{"email": "titova-taisiya1972@postgrespro.ru", "phone": "+70257789017"}
0005432213672	A91325	3791 874338	SERGEY ABRAMOV	{"email": "abramov-sergey051978@postgrespro.ru", "phone": "+70058025378"}
0005432213673	1D6C67	7462 777996	GEORGIY IVANOV	{"email": "georgiy.ivanov-1979@postgrespro.ru", "phone": "+70823339136"}
0005432213674	1D6C67	9424 668755	MILENA LUKYANOVA	{"phone": "+70280778332"}
0005432213675	914DAC	3345 696300	SEMEN BELOV	{"phone": "+70889024258"}
0005432213676	D34CFB	7431 064724	KAROLINA KOROLEVA	{"phone": "+70971988124"}
0005432213677	D34CFB	0458 703183	NIKITA DAVYDOV	{"phone": "+70751426922"}
0005432213678	1E032B	7883 746061	SERGEY ORLOV	{"phone": "+70762202375"}
0005432213679	72469F	2570 678087	DMITRIY SCHERBAKOV	{"email": "dscherbakov.16071973@postgrespro.ru", "phone": "+70935919793"}
0005432213680	72469F	2385 754054	ZINAIDA NIKIFOROVA	{"email": "zinaida-nikiforova.26051970@postgrespro.ru", "phone": "+70885972286"}
0005432213681	E1D824	6341 641495	NATALYA LOGINOVA	{"email": "natalya.loginova.1967@postgrespro.ru", "phone": "+70387304536"}
0005432213682	E1D824	9207 735812	ZINAIDA AFANASEVA	{"phone": "+70490549456"}
0005432213683	107752	6155 926855	MARGARITA NESTEROVA	{"phone": "+70603322241"}
0005432213684	D11E05	5020 413737	PAVEL KUZNECOV	{"email": "kuznecov_pavel.23101980@postgrespro.ru", "phone": "+70265827512"}
0005432213685	0FD32F	3939 862516	RASHIT ILIN	{"email": "ilin-rashit04121977@postgrespro.ru", "phone": "+70534222911"}
0005432213686	0FD32F	7271 156149	SERGEY SHEVCHENKO	{"email": "sergeyshevchenko_1974@postgrespro.ru", "phone": "+70651140560"}
0005432213687	AA5BFB	6577 195974	ANASTASIYA ZHURAVLEVA	{"email": "anastasiyazhuravleva_1975@postgrespro.ru", "phone": "+70809464598"}
0005432213688	806530	9990 694225	MAKSIM PETROV	{"phone": "+70960177342"}
0005432213689	806530	3753 319594	EVGENIY KOROLEV	{"phone": "+70842482017"}
0005432213690	E87285	0928 691596	VASILIY KULIKOV	{"phone": "+70414556352"}
0005432213691	EEAE01	7352 425726	SERGEY VOLKOV	{"email": "volkov_s_061972@postgrespro.ru", "phone": "+70428526529"}
0005432213692	5E4D20	1576 029276	EGOR TIMOFEEV	{"phone": "+70417306922"}
0005432213693	5E4D20	4941 500774	LYUDMILA LUKYANOVA	{"email": "lukyanova-l051972@postgrespro.ru", "phone": "+70956311618"}
0005432213694	FEB808	4437 567321	EKATERINA FROLOVA	{"email": "e.frolova.1956@postgrespro.ru", "phone": "+70812468909"}
0005432213695	BDD268	3121 098543	LYUDMILA NIKITINA	{"phone": "+70605107529"}
0005432213696	1A3A8E	6170 840278	VERA POTAPOVA	{"phone": "+70115979495"}
0005432213697	1A3A8E	4013 979329	VITALIY SEMENOV	{"phone": "+70963281036"}
0005432213698	ED9694	1464 498839	ILYA MOISEEV	{"phone": "+70485074045"}
0005432213699	CD5E06	3279 266379	ALEKSEY ANDREEV	{"phone": "+70648265383"}
0005432213700	CD5E06	6890 116147	ALEKSEY MIRONOV	{"email": "mironovaleksey.1973@postgrespro.ru", "phone": "+70716799598"}
0005432213701	B54057	5144 204036	VERA OVCHINNIKOVA	{"email": "v.ovchinnikova1970@postgrespro.ru", "phone": "+70667535812"}
0005432213702	E961AF	7069 300127	ELENA ERMAKOVA	{"email": "ermakova_elena.101980@postgrespro.ru", "phone": "+70616261426"}
0005432213703	E961AF	6701 673504	ANNA POPOVA	{"email": "anna-popova-1969@postgrespro.ru", "phone": "+70152005935"}
0005432213704	D7FFB8	9290 535354	DMITRIY KRASNOV	{"email": "dmitriy-krasnov-22101974@postgrespro.ru", "phone": "+70822388791"}
0005432213705	C12E7F	9741 576881	EVGENIY KOZLOV	{"email": "e.kozlov1961@postgrespro.ru", "phone": "+70906990165"}
0005432213706	4E5227	8812 768831	ANDREY STEPANOV	{"email": "stepanov-andrey.20111975@postgrespro.ru", "phone": "+70834109729"}
0005432213707	4E5227	0699 474185	NIKITA DAVYDOV	{"email": "davydov-n_121983@postgrespro.ru", "phone": "+70501152912"}
0005432213708	C913B6	5076 027859	LEONID ORLOV	{"email": "orlovleonid_1984@postgrespro.ru", "phone": "+70149281800"}
0005432213709	549027	8442 093325	MAKSIM ANDREEV	{"phone": "+70028480384"}
0005432213710	3DA329	7830 169122	TATYANA ZHUKOVA	{"phone": "+70664944281"}
0005432213711	3DA329	7917 345273	ANATOLIY TIKHONOV	{"email": "anatoliy-tikhonov-121964@postgrespro.ru", "phone": "+70208414190"}
0005432214764	E10ABE	8276 173534	ANASTASIYA MOROZOVA	{"email": "a.morozova.1966@postgrespro.ru", "phone": "+70719854772"}
0005432214765	97CB30	3188 630170	YULIYA NOVIKOVA	{"phone": "+70052072843"}
0005432214766	7DB2EC	2857 353413	VADIM SERGEEV	{"phone": "+70368696135"}
0005432214767	1C70D5	7326 166900	YURIY KUDRYASHOV	{"phone": "+70100792814"}
0005432214768	0ED308	0140 233569	VLADIMIR TARASOV	{"phone": "+70981045780"}
0005432214769	90B8E7	9090 896798	ZULFIYA SIDOROVA	{"phone": "+70193176564"}
0005432214770	E2AF50	6587 193276	OLEG PAVLOV	{"email": "olegpavlov-1971@postgrespro.ru", "phone": "+70803100337"}
0005432214771	1F5352	8760 937294	LYUDMILA ZAKHAROVA	{"email": "zakharoval1972@postgrespro.ru", "phone": "+70389012607"}
0005432214772	0BA8E1	6200 817716	ZINAIDA KOROLEVA	{"email": "koroleva-z1965@postgrespro.ru", "phone": "+70451409949"}
0005432214773	3F73F6	3817 088031	RUSLAN BELOV	{"phone": "+70550830253"}
0005432214774	FC2422	3990 122831	ILYA GRIGOREV	{"email": "grigorev_i.31031965@postgrespro.ru", "phone": "+70766588976"}
0005432214775	FC2422	2280 309115	ELIZAVETA ALEKSEEVA	{"email": "elizavetaalekseeva_1965@postgrespro.ru", "phone": "+70740873517"}
0005432214776	FC2422	3004 842472	EKATERINA MIKHAYLOVA	{"phone": "+70442467882"}
0005432214777	9D2345	9607 131361	MARINA KONDRATEVA	{"email": "m.kondrateva14061984@postgrespro.ru", "phone": "+70844643566"}
0005432214778	0215F0	0125 223929	RAISA MELNIKOVA	{"email": "r_melnikova031963@postgrespro.ru", "phone": "+70017996736"}
0005432214779	BB260A	1677 877039	RAFAIL MOROZOV	{"email": "rafail-morozov_1970@postgrespro.ru", "phone": "+70918527354"}
0005432214780	176FC3	3449 725050	VYACHESLAV BONDARENKO	{"email": "bondarenko-vyacheslav.1971@postgrespro.ru", "phone": "+70443191969"}
0005432214781	C19670	9651 659301	MATRENA KOLESNIKOVA	{"email": "kolesnikova_m.13051979@postgrespro.ru", "phone": "+70209973796"}
0005432214782	D913F2	7409 257612	KONSTANTIN MARTYNOV	{"phone": "+70284894313"}
0005432214783	18B1B5	4754 769013	POLINA DAVYDOVA	{"email": "p_davydova.1962@postgrespro.ru", "phone": "+70433049327"}
0005432214784	18B1B5	5909 172875	LEONID MARTYNOV	{"phone": "+70201145771"}
0005432214785	5EBC91	9003 274029	MAKSIM VOLKOV	{"email": "m-volkov.16121969@postgrespro.ru", "phone": "+70253416297"}
0005432214786	8AB16D	1906 643625	NADEZHDA ANISIMOVA	{"email": "n.anisimova.17031976@postgrespro.ru", "phone": "+70096016698"}
0005432214787	0E08F2	0966 096552	NATALYA SMIRNOVA	{"phone": "+70190651197"}
0005432214788	0E08F2	8250 990858	YULIYA ABRAMOVA	{"phone": "+70534828049"}
0005432214789	0397AB	1251 604506	NIKITA ILIN	{"phone": "+70580093940"}
0005432214790	0397AB	3786 294999	PAVEL GUSEV	{"phone": "+70953842350"}
0005432214791	6D02E8	9344 955122	SERGEY NAUMOV	{"email": "naumov-sergey1984@postgrespro.ru", "phone": "+70877309380"}
0005432214792	0112FF	3739 703678	TATYANA KAZAKOVA	{"email": "kazakova.tatyana_111978@postgrespro.ru", "phone": "+70312365794"}
0005432214793	A3F371	7197 805660	NIKOLAY SEMENOV	{"phone": "+70565991958"}
0005432214794	BFC759	2268 554146	IRINA BORISOVA	{"email": "borisova_irina-26101970@postgrespro.ru", "phone": "+70525360944"}
0005432214795	ECD1BA	5980 093604	NATALYA BORISOVA	{"email": "natalya-borisova-29081965@postgrespro.ru", "phone": "+70254668736"}
0005432214796	858186	6897 638913	ANATOLIY MEDVEDEV	{"phone": "+70419246751"}
0005432214797	DEE675	9908 177555	ELENA GERASIMOVA	{"phone": "+70922498241"}
0005432214798	BEFCDF	1893 391292	PAVEL ZAYCEV	{"email": "zaycev.pavel-1980@postgrespro.ru", "phone": "+70666549524"}
0005432214799	ACAC7A	7015 929147	ALEVTINA KAZAKOVA	{"email": "kazakova_alevtina-1978@postgrespro.ru", "phone": "+70572472408"}
0005432214800	3E8FCA	0470 374200	KHASAN BORISOV	{"email": "kborisov1974@postgrespro.ru", "phone": "+70631925089"}
0005432214801	A08A2C	5949 443701	ANASTASIYA STEPANOVA	{"email": "stepanova-anastasiya1965@postgrespro.ru", "phone": "+70281111716"}
0005432214802	A08A2C	1588 012725	NATALYA IVANOVA	{"phone": "+70964190852"}
0005432214803	35DC75	6202 576462	VALERIY KISELEV	{"phone": "+70914076095"}
0005432214804	D03D6F	1152 303199	OLGA NOVIKOVA	{"email": "olga_novikova071972@postgrespro.ru", "phone": "+70989579210"}
0005432214805	D0578B	4274 243837	VLADIMIR KISELEV	{"phone": "+70421440401"}
0005432214806	D901EA	9023 754441	DENIS ANDREEV	{"email": "andreev.d_06021980@postgrespro.ru", "phone": "+70619896728"}
0005432214807	B12F55	9690 829716	STANISLAV SEMENOV	{"phone": "+70230534639"}
0005432214808	B12F55	6502 377915	DMITRIY SOKOLOV	{"email": "sokolov_dmitriy-011972@postgrespro.ru", "phone": "+70462433476"}
0005432214809	B12F55	1747 194950	LILIYA FILIPPOVA	{"email": "filippova.l_1970@postgrespro.ru", "phone": "+70536755748"}
0005432214810	88D6BB	4181 437505	RAFAIL SOLOVEV	{"email": "solovev-rafail.1968@postgrespro.ru", "phone": "+70936606343"}
0005432214811	88D6BB	3766 824196	MARIYA NESTEROVA	{"email": "nesterova-mariya_101975@postgrespro.ru", "phone": "+70057651304"}
0005432214812	88D6BB	2583 314424	ANATOLIY MIKHAYLOV	{"email": "mikhaylova24071978@postgrespro.ru", "phone": "+70893305238"}
0005432214813	F2A6C5	1178 085832	OLEG KAZAKOV	{"email": "olegkazakov.02061968@postgrespro.ru", "phone": "+70703879070"}
0005432214814	621C5C	8654 411578	ALEKSANDR ALEKSEEV	{"email": "aleksandr-alekseev06111963@postgrespro.ru", "phone": "+70158874459"}
0005432214815	FC1536	0048 570444	MARINA ALEKSEEVA	{"phone": "+70450443302"}
0005432214816	FC1536	9723 549598	ANGELINA EGOROVA	{"email": "angelina.egorova-1962@postgrespro.ru", "phone": "+70992111605"}
0005432214817	D10B58	6205 263624	GENNADIY FILIPPOV	{"email": "gennadiy-filippov_041967@postgrespro.ru", "phone": "+70160259494"}
0005432214818	D10B58	7463 484735	ANDREY ALEKSEEV	{"email": "alekseev_andrey_1969@postgrespro.ru", "phone": "+70515554656"}
0005432214819	22E61A	5656 892157	ANDREY ILIN	{"phone": "+70179354441"}
0005432214820	22E61A	3716 993430	VASILIY MAKAROV	{"phone": "+70438023987"}
0005432214821	45B7B4	8287 866199	OLGA PETROVA	{"email": "petrovaolga_1983@postgrespro.ru", "phone": "+70532131773"}
0005432214822	45B7B4	7365 141761	ROMAN NOVIKOV	{"email": "novikov_r_1961@postgrespro.ru", "phone": "+70269935378"}
0005432214823	587D45	8855 406803	VALENTIN SMIRNOV	{"email": "v-smirnov29081979@postgrespro.ru", "phone": "+70576453859"}
0005432214824	6F47D5	5605 433567	OLGA MELNIKOVA	{"phone": "+70691045357"}
0005432214825	6F47D5	8208 070827	SERGEY IVANOV	{"email": "ivanov.sergey1988@postgrespro.ru", "phone": "+70394963457"}
0005432214826	56A836	9914 652842	SVETLANA ALEKSEEVA	{"phone": "+70516038453"}
0005432214827	56A836	8128 620016	EGOR KOZLOV	{"phone": "+70799403793"}
0005432214828	7CDF59	7389 178012	GALINA BELYAEVA	{"email": "g_belyaeva111971@postgrespro.ru", "phone": "+70921236683"}
0005432214829	68347A	3506 224251	TATYANA TROFIMOVA	{"phone": "+70675106595"}
0005432214830	C070A2	6574 716103	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.061967@postgrespro.ru", "phone": "+70397565720"}
0005432214831	EDE266	4633 624668	MAKSIM BONDARENKO	{"phone": "+70393247172"}
0005432214832	2E54B7	5437 987382	SERGEY ZAYCEV	{"email": "zaycev_sergey_1963@postgrespro.ru", "phone": "+70419488142"}
0005432214833	461FBF	9271 469648	LYUDMILA MELNIKOVA	{"email": "l-melnikova_061977@postgrespro.ru", "phone": "+70353241663"}
0005432214834	461FBF	7209 056300	ZINAIDA MOROZOVA	{"phone": "+70167105254"}
0005432214835	607683	5055 861182	IGOR KUZNECOV	{"email": "kuznecov.i.1975@postgrespro.ru", "phone": "+70293921448"}
0005432214836	66EFAC	6934 618873	EVGENIY ZAYCEV	{"phone": "+70887578613"}
0005432214837	66EFAC	6449 431250	VYACHESLAV NAZAROV	{"email": "nazarov_vyacheslav-30121959@postgrespro.ru", "phone": "+70680284088"}
0005432214838	ED8685	3538 987838	SVETLANA DMITRIEVA	{"email": "dmitrieva-s.1970@postgrespro.ru", "phone": "+70418509139"}
0005432214839	64FA7F	3027 919922	RAMIL GUSEV	{"phone": "+70277314104"}
0005432214840	2B1E8E	5249 861063	ANATOLIY NIKITIN	{"phone": "+70488752607"}
0005432214841	2B1E8E	1409 979904	LYUBOV ZHUKOVA	{"phone": "+70822278740"}
0005432214842	2B1E8E	8327 356846	YURIY RODIONOV	{"email": "rodionov-yuriy.101977@postgrespro.ru", "phone": "+70057397398"}
0005432214843	78BDE7	1018 862956	ANNA ISAEVA	{"phone": "+70637784323"}
0005432214844	78BDE7	0689 855381	LUIZA ZHURAVLEVA	{"email": "l-zhuravleva-111970@postgrespro.ru", "phone": "+70497566754"}
0005432214845	7832A0	0624 655684	NIKOLAY NOVIKOV	{"email": "nnovikov.051973@postgrespro.ru", "phone": "+70379350621"}
0005432214846	7832A0	0860 279455	EVGENIY ILIN	{"phone": "+70210408635"}
0005432214847	E91441	6165 547254	DANILA MAKSIMOV	{"email": "danila.maksimov1962@postgrespro.ru", "phone": "+70014395275"}
0005432214848	E91441	3633 706249	POLINA TIMOFEEVA	{"email": "p-timofeeva.1977@postgrespro.ru", "phone": "+70664736806"}
0005432214849	9C46A1	0668 851494	MARIYA PETROVA	{"email": "mariyapetrova-1978@postgrespro.ru", "phone": "+70926748643"}
0005432214850	9C46A1	8191 467586	MIKHAIL TIKHONOV	{"phone": "+70101025503"}
0005432214851	9C46A1	3790 150391	NADEZHDA AKIMOVA	{"phone": "+70775894548"}
0005432214852	2C85F5	3605 838021	OLEG KUZNECOV	{"phone": "+70546419812"}
0005432214853	0500C6	6563 500642	ANDREY FOMIN	{"email": "a_fomin1976@postgrespro.ru", "phone": "+70693771545"}
0005432214854	C7E3A3	8646 837597	ALEKSANDR SIDOROV	{"phone": "+70918162453"}
0005432214855	250AF1	4159 944796	ANNA ABRAMOVA	{"email": "anna.abramova-061961@postgrespro.ru", "phone": "+70357304012"}
0005432214856	739480	1345 568076	GALINA MAKAROVA	{"phone": "+70734051746"}
0005432214857	AFE28A	5141 754102	ANNA GAVRILOVA	{"phone": "+70550261406"}
0005432214858	A99794	6910 228373	ALEKSANDRA RYABOVA	{"email": "ryabova-a.1970@postgrespro.ru", "phone": "+70568663048"}
0005432214859	A99794	6575 228286	ROMAN MATVEEV	{"email": "roman_matveev051971@postgrespro.ru", "phone": "+70048363485"}
0005432214860	CA0542	4612 388167	NIKITA MIKHAYLOV	{"phone": "+70697633718"}
0005432214861	03014C	7050 584113	VLADIMIR ORLOV	{"email": "orlov_vladimir_02011975@postgrespro.ru", "phone": "+70917908930"}
0005432214862	BC21D8	6731 931110	ZINAIDA OSIPOVA	{"phone": "+70338101681"}
0005432214863	891715	7248 205979	IVAN IVANOV	{"email": "ivanivanov.061974@postgrespro.ru", "phone": "+70110699961"}
0005432214864	549DA8	0080 854704	ANZHELIKA FILIPPOVA	{"phone": "+70856811085"}
0005432214865	2E34AB	5143 061476	PETR BONDARENKO	{"phone": "+70165904168"}
0005432214866	2DA8F8	2904 633454	ANTONINA KONOVALOVA	{"email": "antoninakonovalova041971@postgrespro.ru", "phone": "+70067357935"}
0005432214867	0F1C4C	3196 060080	ALEKSANDR ZHURAVLEV	{"phone": "+70404710171"}
0005432214868	0F1C4C	4610 322714	TATYANA VLASOVA	{"phone": "+70234512529"}
0005432214869	AE2A03	8501 151821	ALINA ERMAKOVA	{"phone": "+70632163032"}
0005432216222	CF2BEC	1317 944525	VLADIMIR ANDREEV	{"phone": "+70260867018"}
0005432216223	CF2BEC	0246 179682	NADEZHDA KONDRATEVA	{"phone": "+70449419490"}
0005432216224	F0F4A2	0578 602061	ZINAIDA MIRONOVA	{"phone": "+70340939331"}
0005432216225	17B845	5403 309863	PELAGEYA SOROKINA	{"phone": "+70271779823"}
0005432216226	CD5B87	8539 693079	MARIYA AKIMOVA	{"phone": "+70598613101"}
0005432216227	61F138	7218 607615	VERA NAZAROVA	{"phone": "+70566349381"}
0005432216228	EF6A5B	1427 814070	ANDREY SOROKIN	{"email": "andreysorokin26071977@postgrespro.ru", "phone": "+70745528138"}
0005432216229	D29179	2468 570839	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr.121973@postgrespro.ru", "phone": "+70934181413"}
0005432216230	D29179	8222 805178	SVETLANA ANISIMOVA	{"email": "anisimova-svetlana021962@postgrespro.ru", "phone": "+70896756344"}
0005432216231	9D1B0C	4818 791359	GALINA PETROVA	{"email": "g-petrova_051978@postgrespro.ru", "phone": "+70658703251"}
0005432216232	4C7189	3936 262776	NATALYA KUZMINA	{"email": "natalya.kuzmina-1970@postgrespro.ru", "phone": "+70446848900"}
0005432216233	4C7189	5609 378348	DMITRIY KUZMIN	{"email": "d_kuzmin-1969@postgrespro.ru", "phone": "+70892853459"}
0005432216234	125DE7	8254 640775	ALEKSEY SHEVCHENKO	{"phone": "+70241756879"}
0005432216235	BFCFBA	4697 103542	YULIYA KULIKOVA	{"phone": "+70117727537"}
0005432216236	BFCFBA	0402 778054	ALEKSEY DAVYDOV	{"phone": "+70760069767"}
0005432216237	D4CEC3	0828 976902	TAISIYA PETROVA	{"phone": "+70153345989"}
0005432216238	2DAA41	4370 121581	GALINA STEPANOVA	{"phone": "+70657471776"}
0005432216239	0666F4	0102 269339	EVGENIY KUDRYASHOV	{"email": "kudryashove.1967@postgrespro.ru", "phone": "+70223047744"}
0005432216240	0666F4	0993 474401	OKSANA SEMENOVA	{"phone": "+70227660603"}
0005432216241	ECFFCE	5297 843775	RAISA RODIONOVA	{"phone": "+70990445863"}
0005432216242	ECFFCE	1700 222942	EVGENIY TIKHONOV	{"phone": "+70962109074"}
0005432216243	90DE68	0349 790851	EVGENIY SERGEEV	{"email": "sergeevevgeniy_051969@postgrespro.ru", "phone": "+70396260170"}
0005432216244	90DE68	0149 185081	GENNADIY MELNIKOV	{"phone": "+70841009006"}
0005432216245	AD6C06	3616 336273	IRINA EGOROVA	{"phone": "+70773065191"}
0005432216246	8BF741	6029 880048	IVAN IVANOV	{"phone": "+70943524569"}
0005432216247	7FD2B9	5926 505490	ALEKSANDR MIRONOV	{"email": "mironov_a-03121964@postgrespro.ru", "phone": "+70159884322"}
0005432216248	7FD2B9	2697 961563	TATYANA MAKAROVA	{"email": "makarovat-1974@postgrespro.ru", "phone": "+70424591167"}
0005432216249	A9A97A	5668 094079	MARINA ZAYCEVA	{"email": "marina_zayceva.1979@postgrespro.ru", "phone": "+70504759422"}
0005432216250	A9A97A	6495 000627	EKATERINA TIKHONOVA	{"email": "tikhonovaekaterina-12101987@postgrespro.ru", "phone": "+70093788379"}
0005432216251	A9A97A	1415 315949	NATALYA ORLOVA	{"email": "natalyaorlova.091972@postgrespro.ru", "phone": "+70517598632"}
0005432216252	55B8A6	9210 114728	KSENIYA DENISOVA	{"email": "denisovak1960@postgrespro.ru", "phone": "+70462771481"}
0005432216253	10AB43	3553 917187	ANASTASIYA SOROKINA	{"email": "asorokina_101969@postgrespro.ru", "phone": "+70779132868"}
0005432216254	700CD7	9272 039143	ELENA GUSEVA	{"email": "guseva-elena_1962@postgrespro.ru", "phone": "+70431565542"}
0005432216255	C19FC4	2524 830491	ANNA MOISEEVA	{"email": "moiseeva_anna-021981@postgrespro.ru", "phone": "+70967395462"}
0005432216256	B31B57	6905 419628	MARIYA BELOVA	{"email": "belova.mariya.1966@postgrespro.ru", "phone": "+70490395438"}
0005432216257	86BC80	0140 122231	TATYANA ZAYCEVA	{"email": "zayceva-t121964@postgrespro.ru", "phone": "+70067020497"}
0005432216258	86BC80	8948 016684	LYUBOV KONDRATEVA	{"email": "lyubovkondrateva-1971@postgrespro.ru", "phone": "+70912128452"}
0005432216259	720B81	0966 483026	ALEKSANDR DMITRIEV	{"email": "dmitriev_a.28011965@postgrespro.ru", "phone": "+70469985500"}
0005432216260	847C4A	3684 549748	GENNADIY KOROLEV	{"email": "korolevgennadiy16091966@postgrespro.ru", "phone": "+70651224779"}
0005432216261	C9FC44	4309 719695	IRINA KRASNOVA	{"phone": "+70621473571"}
0005432216262	7C831B	8294 732403	NINA ERMAKOVA	{"phone": "+70106597887"}
0005432216263	220341	7844 567287	ANNA IVANOVA	{"email": "a-ivanova1987@postgrespro.ru", "phone": "+70063556313"}
0005432216264	220341	7540 092207	FEDOR STEPANOV	{"email": "stepanovf-09101976@postgrespro.ru", "phone": "+70431048513"}
0005432216265	D67F73	6943 868018	MARINA FOMINA	{"email": "marina-fomina.13021971@postgrespro.ru", "phone": "+70083926131"}
0005432216266	F041D6	8973 531204	OLGA SEMENOVA	{"email": "osemenova.27041971@postgrespro.ru", "phone": "+70595890330"}
0005432216267	F041D6	0717 192918	MIKHAIL EGOROV	{"phone": "+70864034846"}
0005432216268	F550FA	1502 931118	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr_30091979@postgrespro.ru", "phone": "+70124618944"}
0005432216269	0EDAE3	2582 416610	IVAN PAVLOV	{"phone": "+70624134263"}
0005432216270	0EDAE3	0155 917554	NURIYA YUDINA	{"phone": "+70607781587"}
0005432216271	149237	6217 353318	EVGENIY PAVLOV	{"email": "pavlov-e_27041964@postgrespro.ru", "phone": "+70661262893"}
0005432216272	9280E6	4384 438883	TIKHON KUZNECOV	{"phone": "+70976650920"}
0005432216273	1358F2	0265 207546	EKATERINA KUZNECOVA	{"email": "kuznecova.ekaterina021972@postgrespro.ru", "phone": "+70379771060"}
0005432216274	A674D3	2847 062969	VALENTINA SMIRNOVA	{"phone": "+70364820563"}
0005432216275	A674D3	5134 308476	IRINA OSIPOVA	{"email": "irinaosipova.101985@postgrespro.ru", "phone": "+70841574941"}
0005432216276	553AD7	6286 070820	VLADIMIR KOZLOV	{"phone": "+70985937366"}
0005432216277	BAEDEE	5352 448661	NIKOLAY SOROKIN	{"phone": "+70298995735"}
0005432216278	4B3856	2782 021867	VIKTOR MIKHAYLOV	{"phone": "+70389931897"}
0005432216279	4B3856	5505 240238	ALEKSANDR KUZNECOV	{"email": "akuznecov.1984@postgrespro.ru", "phone": "+70619102007"}
0005432216280	3B51B4	9857 327362	VALENTINA DMITRIEVA	{"email": "valentina-dmitrieva_19041973@postgrespro.ru", "phone": "+70724877282"}
0005432216281	14ADE5	4552 766911	DMITRIY ROMANOV	{"phone": "+70145894811"}
0005432216282	896F6C	8388 639123	ALEKSANDR VASILEV	{"phone": "+70314812778"}
0005432216283	F35E39	7152 343937	VERA TITOVA	{"email": "titova-v-011971@postgrespro.ru", "phone": "+70325834530"}
0005432216284	77E696	2423 245568	MIKHAIL VASILEV	{"email": "vasilev.m_1973@postgrespro.ru", "phone": "+70666916164"}
0005432216285	2A2B18	6242 173359	NATALYA LOGINOVA	{"email": "n-loginova_101970@postgrespro.ru", "phone": "+70450972255"}
0005432216286	2A2B18	3015 429029	DARYA ALEKSEEVA	{"phone": "+70189183577"}
0005432216287	FEEEC0	4529 251988	ELENA NIKITINA	{"email": "enikitina-17071980@postgrespro.ru", "phone": "+70213589202"}
0005432216288	FEEEC0	3375 505731	ALEKSANDR BARANOV	{"email": "aleksandrbaranov-16041968@postgrespro.ru", "phone": "+70892303773"}
0005432216289	7E857B	4177 076278	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey.1966@postgrespro.ru", "phone": "+70620408900"}
0005432216290	5B6212	8407 388753	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin1966@postgrespro.ru", "phone": "+70057965568"}
0005432216291	5B6212	3450 682319	OLGA GERASIMOVA	{"email": "gerasimova.o1976@postgrespro.ru", "phone": "+70264739987"}
0005432216292	794E86	6637 306265	VLADIMIR MAKAROV	{"phone": "+70468140263"}
0005432216293	FDC35A	8298 446476	ALEKSANDR IVANOV	{"email": "a-ivanov1965@postgrespro.ru", "phone": "+70141177908"}
0005432216294	5191E0	5882 070074	LILIYA EGOROVA	{"email": "l_egorova-14101963@postgrespro.ru", "phone": "+70209794259"}
0005432216295	5191E0	4824 584535	ALEKSANDR MIRONOV	{"email": "mironov_a031973@postgrespro.ru", "phone": "+70751254542"}
0005432216296	D05253	0149 187101	ZAKHAR TIMOFEEV	{"email": "timofeev.zakhar_1959@postgrespro.ru", "phone": "+70592321153"}
0005432216297	571922	6349 494226	VIKTOR SOROKIN	{"phone": "+70012661378"}
0005432216298	97B15A	1997 254944	ANDREY GORBUNOV	{"email": "gorbunov.andrey011968@postgrespro.ru", "phone": "+70483631913"}
0005432216299	8605BA	4478 471914	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-07011959@postgrespro.ru", "phone": "+70826987133"}
0005432216300	3CD2C2	8025 125204	GALINA DENISOVA	{"email": "g_denisova.1968@postgrespro.ru", "phone": "+70738252344"}
0005432216301	1944E7	6241 548171	ALEKSANDR MEDVEDEV	{"phone": "+70333904164"}
0005432216302	566FB1	4174 108878	DANILA KAZAKOV	{"email": "danila-kazakov-1976@postgrespro.ru", "phone": "+70734226840"}
0005432216303	17B90F	2248 918589	VIKTORIYA SOKOLOVA	{"email": "sokolova-viktoriya_26061974@postgrespro.ru", "phone": "+70375990424"}
0005432216304	12EA11	7625 444719	ALEKSEY PETROV	{"email": "apetrov_1974@postgrespro.ru", "phone": "+70675767108"}
0005432216305	9B633B	0150 263816	SVETLANA KAZAKOVA	{"email": "kazakova-svetlana1972@postgrespro.ru", "phone": "+70030561122"}
0005432216306	120624	0460 330312	VALENTINA SOKOLOVA	{"email": "sokolova-valentina1973@postgrespro.ru", "phone": "+70785078865"}
0005432216307	4CD3AE	7462 241966	TATYANA KOZLOVA	{"phone": "+70649602655"}
0005432216308	27E876	8582 615954	ALBINA POTAPOVA	{"email": "potapova_a101967@postgrespro.ru", "phone": "+70012801004"}
0005432216309	075273	8389 205566	LARISA MALYSHEVA	{"email": "malysheva.larisa1965@postgrespro.ru", "phone": "+70821608554"}
0005432216310	075273	3148 321090	ANGELINA KALININA	{"email": "kalinina-a101981@postgrespro.ru", "phone": "+70460896155"}
0005432216311	075273	1587 882697	IVAN IVANOV	{"email": "ivanivanov-1968@postgrespro.ru", "phone": "+70042495341"}
0005432216312	A89DCE	5612 189931	VLADIMIR MELNIKOV	{"email": "melnikov-v-1973@postgrespro.ru", "phone": "+70872118666"}
0005432216313	A89DCE	2539 273754	NINA TROFIMOVA	{"email": "ninatrofimova28011966@postgrespro.ru", "phone": "+70114958702"}
0005432216314	DEFAFC	3751 420326	MARIYA KOLESNIKOVA	{"email": "kolesnikova-mariya_1973@postgrespro.ru", "phone": "+70854756391"}
0005432216315	DEFAFC	5542 158732	ALEKSEY SCHERBAKOV	{"email": "a_scherbakov-13041977@postgrespro.ru", "phone": "+70908197400"}
0005432216316	82E9FA	3301 319381	NINA PETROVA	{"phone": "+70658357608"}
0005432216317	82E9FA	1440 668827	EKATERINA SOLOVEVA	{"email": "ekaterina-soloveva1968@postgrespro.ru", "phone": "+70845368463"}
0005432216318	6A152E	8113 058658	ANASTASIYA KOROLEVA	{"phone": "+70145970562"}
0005432216319	D17AD6	7449 271158	ANATOLIY OSIPOV	{"phone": "+70122632139"}
0005432216320	484DC6	6015 986171	VALERIY YAKOVLEV	{"phone": "+70553935040"}
0005432216321	484DC6	2917 501582	TIGRAN GRIGOREV	{"phone": "+70258171154"}
0005432216322	7463E6	4698 860116	DANILA SAVELEV	{"phone": "+70118316526"}
0005432216323	43305D	9017 976641	VALERIY SOROKIN	{"phone": "+70379305459"}
0005432216324	4F79E2	2063 614347	NINA NAZAROVA	{"email": "nazarova-nina19041978@postgrespro.ru", "phone": "+70549187754"}
0005432216325	4F79E2	2597 182620	ALEKSANDR PETROV	{"phone": "+70253994585"}
0005432216326	1FCFF7	3343 268962	OLGA ANISIMOVA	{"phone": "+70225055020"}
0005432216327	1FCFF7	4840 521694	IRINA KOROLEVA	{"phone": "+70235452227"}
0005432216328	1FCFF7	8293 889617	LIDIYA MIKHAYLOVA	{"phone": "+70585689508"}
0005432216329	5247C1	2234 635893	ROMAN MIRONOV	{"email": "mironov.roman1968@postgrespro.ru", "phone": "+70821389555"}
0005432216330	5247C1	2908 436076	GENNADIY MOROZOV	{"phone": "+70868635757"}
0005432216331	844799	0936 013805	VIKTOR POPOV	{"phone": "+70650633635"}
0005432216332	844799	1763 885958	DENIS ZAYCEV	{"email": "zaycevd-071966@postgrespro.ru", "phone": "+70589210608"}
0005432216333	FBFB26	4122 103113	NIKOLAY ISAEV	{"email": "isaevnikolay-111963@postgrespro.ru", "phone": "+70488243412"}
0005432216334	FBFB26	8248 708064	NATALYA PETROVA	{"email": "petrova_n_12071973@postgrespro.ru", "phone": "+70533924581"}
0005432216335	FBFB26	5300 038708	NADEZHDA BARANOVA	{"email": "baranova_nadezhda-24101980@postgrespro.ru", "phone": "+70287656601"}
0005432216336	E09731	9092 906660	KARINA POPOVA	{"email": "popova_karina081978@postgrespro.ru", "phone": "+70290683090"}
0005432216337	A25A0A	0485 833298	NIKOLAY ORLOV	{"email": "nikolayorlov.021963@postgrespro.ru", "phone": "+70028412824"}
0005432216338	A25A0A	6943 059097	ZOYA KOZLOVA	{"email": "kozlovazoya.111979@postgrespro.ru", "phone": "+70100137374"}
0005432216339	8F042C	4828 711515	RAMIL STEPANOV	{"phone": "+70660751034"}
0005432216340	EFA550	0180 576176	VYACHESLAV ZAYCEV	{"email": "v_zaycev-051974@postgrespro.ru", "phone": "+70534883379"}
0005432216341	EFA550	0750 936127	NATALYA POTAPOVA	{"email": "potapova-natalya19031975@postgrespro.ru", "phone": "+70378568718"}
0005432216342	01D0BB	7629 217615	MIKHAIL GUSEV	{"phone": "+70199798378"}
0005432216343	B59472	5898 351887	TATYANA NAZAROVA	{"email": "t_nazarova1965@postgrespro.ru", "phone": "+70974036769"}
0005432216344	B59472	6627 243431	TATYANA ROMANOVA	{"phone": "+70568309767"}
0005432216345	243015	6839 045249	SVETLANA SERGEEVA	{"email": "sergeeva_s.041969@postgrespro.ru", "phone": "+70800562430"}
0005432216346	243015	5867 469045	VALENTINA MIKHAYLOVA	{"phone": "+70770154191"}
0005432216347	8C5C87	7696 931102	ALEKSEY KARPOV	{"email": "akarpov21051975@postgrespro.ru", "phone": "+70279410899"}
0005432216348	66E530	5715 400134	ILYA PETROV	{"email": "petrov-i1979@postgrespro.ru", "phone": "+70122913846"}
0005432216349	66E530	4402 292401	SERGEY FEDOROV	{"phone": "+70675993741"}
0005432216350	66E530	8557 695301	LYUDMILA MOROZOVA	{"email": "lyudmila.morozova-16101976@postgrespro.ru", "phone": "+70404418729"}
0005432216351	E350E9	0117 308701	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev031961@postgrespro.ru", "phone": "+70696783440"}
0005432216352	13FE41	3145 040709	VIKTOR FEDOROV	{"phone": "+70023537670"}
0005432217724	210222	8701 942134	NINA FROLOVA	{"phone": "+70811032798"}
0005432217725	054897	8736 445815	GENNADIY ZAKHAROV	{"phone": "+70832061360"}
0005432217726	054897	4218 321418	VLADIMIR PAVLOV	{"phone": "+70139805435"}
0005432217727	AEFF4A	6336 545712	ALEKSANDR ZAYCEV	{"phone": "+70677070667"}
0005432217728	941E9A	7656 794047	OLGA MELNIKOVA	{"email": "melnikovaolga-1986@postgrespro.ru", "phone": "+70926543151"}
0005432217729	69B75D	1340 905758	OLESYA SOLOVEVA	{"email": "soloveva_olesya_1975@postgrespro.ru", "phone": "+70370588520"}
0005432217730	69B75D	2978 086688	EVGENIYA ANTONOVA	{"phone": "+70989531446"}
0005432217731	9F729F	5952 013499	ALEKSEY CHERNOV	{"phone": "+70770286921"}
0005432217732	E9E15A	4789 359173	YULIYA IVANOVA	{"email": "ivanova_y-091970@postgrespro.ru", "phone": "+70846686730"}
0005432217733	994880	9050 385479	OLEG VOLKOV	{"phone": "+70390882393"}
0005432217734	994880	3167 558325	ALEKSANDR ISAEV	{"email": "aisaev-10071966@postgrespro.ru", "phone": "+70246370000"}
0005432217735	847F55	2527 001009	ALINA PETROVA	{"email": "alina-petrova01041963@postgrespro.ru", "phone": "+70279007970"}
0005432217736	F3DE41	8077 939169	RAZIYA RODIONOVA	{"email": "r_rodionova-071975@postgrespro.ru", "phone": "+70913237755"}
0005432217737	6EBFDF	4771 263862	IRINA CHERNOVA	{"email": "irina-chernova24101973@postgrespro.ru", "phone": "+70019505626"}
0005432217738	7BEE36	2808 253507	LEYLA FOMINA	{"email": "fomina.l_031972@postgrespro.ru", "phone": "+70628197201"}
0005432217739	7BEE36	3611 740448	ALEKSANDR SOROKIN	{"phone": "+70285172527"}
0005432217740	99B16A	9587 872933	TATYANA ABRAMOVA	{"email": "abramovat.111973@postgrespro.ru", "phone": "+70052822619"}
0005432217741	A057E6	9604 927316	IRINA TIKHONOVA	{"phone": "+70413016749"}
0005432217742	CFE29B	9864 051347	SERGEY KUZNECOV	{"phone": "+70013376607"}
0005432217743	687427	8854 600943	PAVEL IVANOV	{"email": "ivanov-pavel_1968@postgrespro.ru", "phone": "+70124918075"}
0005432217744	687427	7488 516869	EVGENIY ALEKSEEV	{"email": "e_alekseev-1977@postgrespro.ru", "phone": "+70780114446"}
0005432217745	8589BD	7800 545848	ARSEN GORBUNOV	{"phone": "+70661365888"}
0005432217746	D7B76D	1592 195487	MARINA SIDOROVA	{"email": "marina-sidorova-061969@postgrespro.ru", "phone": "+70629167043"}
0005432217747	D4B21A	8426 286018	EKATERINA EGOROVA	{"email": "e.egorova-1977@postgrespro.ru", "phone": "+70609388703"}
0005432217748	467FFA	2537 980687	VYACHESLAV NOVIKOV	{"phone": "+70997727508"}
0005432217749	C1894E	1066 985842	SERGEY SOROKIN	{"email": "sorokin.sergey_011975@postgrespro.ru", "phone": "+70046790638"}
0005432217750	15C5CF	0783 836404	DMITRIY SMIRNOV	{"email": "smirnovd-1962@postgrespro.ru", "phone": "+70030175756"}
0005432217751	7A86DC	1124 905398	ELENA KRASNOVA	{"phone": "+70799548122"}
0005432217752	7A86DC	4682 756541	PAVEL FROLOV	{"email": "frolov_pavel041971@postgrespro.ru", "phone": "+70908504212"}
0005432217753	AD1930	3406 573321	ELENA SMIRNOVA	{"phone": "+70272660185"}
0005432217754	C3A899	5755 947666	ELENA ISAEVA	{"email": "isaeva_e.101975@postgrespro.ru", "phone": "+70065207662"}
0005432217755	C3A899	9180 483881	GALINA MASLOVA	{"email": "maslova-galina041964@postgrespro.ru", "phone": "+70024477548"}
0005432217756	FBCCF6	1923 560343	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr-101975@postgrespro.ru", "phone": "+70980043736"}
0005432217757	D17BFD	3168 234389	MARINA EGOROVA	{"email": "egorova-m.1966@postgrespro.ru", "phone": "+70862563651"}
0005432217758	5FE983	3689 244649	NIKOLAY SERGEEV	{"phone": "+70584392158"}
0005432217759	F637BC	3249 770323	MARIYA FILIPPOVA	{"email": "mariya_filippova.04081982@postgrespro.ru", "phone": "+70514249554"}
0005432217760	5CF8DE	3205 338281	LYUBOV BORISOVA	{"phone": "+70754614116"}
0005432217761	5CF8DE	6279 663439	NINA NIKIFOROVA	{"email": "n-nikiforova031981@postgrespro.ru", "phone": "+70206355484"}
0005432217762	42CD71	1016 698823	NIKITA KOZLOV	{"phone": "+70366662649"}
0005432217763	42CD71	9050 663119	SERGEY GUSEV	{"email": "s.gusev.071972@postgrespro.ru", "phone": "+70994563469"}
0005432217764	99434A	4220 027436	YULIYA DANILOVA	{"phone": "+70240029258"}
0005432217765	99434A	3572 479261	ELENA POLYAKOVA	{"phone": "+70682432594"}
0005432217766	1D244F	7935 651943	EVGENIY SHEVCHENKO	{"phone": "+70124974591"}
0005432217767	1D244F	4392 554901	OLGA TIKHONOVA	{"email": "o-tikhonova-1959@postgrespro.ru", "phone": "+70192573071"}
0005432217768	1D244F	2155 403462	EVGENIY SMIRNOV	{"phone": "+70260557168"}
0005432217769	0971B4	3551 816897	ALEKSANDR FOMIN	{"phone": "+70625811840"}
0005432217770	10319A	1804 247364	NIKITA SERGEEV	{"email": "sergeev-nikita.071952@postgrespro.ru", "phone": "+70017747498"}
0005432217771	D627A0	1279 325542	YULIYA POPOVA	{"email": "ypopova.081968@postgrespro.ru", "phone": "+70491057528"}
0005432217772	FE137A	4208 522820	VLADIMIR STEPANOV	{"email": "stepanov-v091966@postgrespro.ru", "phone": "+70347596205"}
0005432217773	D4F106	1764 060279	STEPAN MAKAROV	{"email": "makarov_stepan_08081974@postgrespro.ru", "phone": "+70101257197"}
0005432217774	D4F106	2360 481926	OLEG KAZAKOV	{"email": "oleg_kazakov-1967@postgrespro.ru", "phone": "+70473492455"}
0005432217775	8FE829	3090 320737	LILIYA NESTEROVA	{"phone": "+70142307223"}
0005432217776	C7906D	3939 685043	ELENA FILIPPOVA	{"phone": "+70735098962"}
0005432217777	8B10F0	3969 330636	TATYANA MIKHAYLOVA	{"phone": "+70276031396"}
0005432217778	96A0F4	7018 320302	LEONID TARASOV	{"phone": "+70023974790"}
0005432217779	A4EFE3	8598 771655	MARINA NESTEROVA	{"email": "m.nesterova.081971@postgrespro.ru", "phone": "+70917245318"}
0005432217780	D72605	2478 052727	SERGEY NAUMOV	{"phone": "+70257472871"}
0005432217781	DD7D82	8447 125179	MARINA KULIKOVA	{"phone": "+70712025194"}
0005432217782	DD7D82	7893 192386	ELENA NIKOLAEVA	{"phone": "+70738997409"}
0005432217783	D57ED0	8452 881261	DMITRIY ORLOV	{"email": "orlovd-1975@postgrespro.ru", "phone": "+70638727964"}
0005432217784	BCA268	7996 834296	DARYA SMIRNOVA	{"email": "daryasmirnova_1964@postgrespro.ru", "phone": "+70572741645"}
0005432217785	BCA268	9355 957839	OKSANA ARKHIPOVA	{"email": "o_arkhipova.1974@postgrespro.ru", "phone": "+70118715133"}
0005432217786	4149CB	8073 737612	POLINA BELOVA	{"phone": "+70937241898"}
0005432217787	4149CB	2031 898161	VLADA ANDREEVA	{"phone": "+70886299644"}
0005432217788	42D986	6074 755382	NIKITA IVANOV	{"phone": "+70490625230"}
0005432217789	677BBD	0190 289611	VALENTINA MEDVEDEVA	{"phone": "+70735500990"}
0005432217790	09299D	1961 023122	KIRILL MAKSIMOV	{"email": "maksimov-kirill11101974@postgrespro.ru", "phone": "+70153348127"}
0005432217791	64D58E	2869 876823	NATALYA KUZNECOVA	{"email": "kuznecovan1982@postgrespro.ru", "phone": "+70860054917"}
0005432217792	64D58E	4264 806190	MARINA BELYAEVA	{"phone": "+70614894193"}
0005432217793	C9CEEB	9714 540879	OLGA MARTYNOVA	{"phone": "+70536939833"}
0005432217794	2478F8	8955 541983	RAISA VLASOVA	{"phone": "+70247701685"}
0005432217795	D9576A	1751 835496	MARGARITA ROMANOVA	{"email": "m_romanova_041973@postgrespro.ru", "phone": "+70407151226"}
0005432217796	822FB9	4449 371047	SVETLANA KALININA	{"email": "s.kalinina021977@postgrespro.ru", "phone": "+70876094314"}
0005432217797	7F3D1A	2414 368768	DENIS ZAYCEV	{"phone": "+70196654435"}
0005432217798	A8D9A5	5126 441451	VERA TITOVA	{"phone": "+70050201441"}
0005432217799	E2DF04	3028 716811	TATYANA ROMANOVA	{"email": "tromanova-18101957@postgrespro.ru", "phone": "+70137244207"}
0005432217800	91B1D6	5862 442103	EVGENIY ZAYCEV	{"email": "zaycevevgeniy-011982@postgrespro.ru", "phone": "+70073041920"}
0005432217801	91B1D6	3815 247396	IRINA SERGEEVA	{"email": "sergeeva_i.1972@postgrespro.ru", "phone": "+70947955346"}
0005432217802	3670F8	6534 951619	NIKOLAY TIKHONOV	{"email": "n_tikhonov_25111966@postgrespro.ru", "phone": "+70367363485"}
0005432217803	3670F8	6681 379570	OLGA VASILEVA	{"phone": "+70998159423"}
0005432217804	216E5F	0866 778466	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail.121974@postgrespro.ru", "phone": "+70422800603"}
0005432217805	564B9C	1641 647960	SERGEY MAKSIMOV	{"phone": "+70771708545"}
0005432217806	3184E7	2582 273906	IRINA NIKOLAEVA	{"email": "nikolaeva.irina101983@postgrespro.ru", "phone": "+70842834949"}
0005432217807	E67EAC	7649 155137	GALINA KUZNECOVA	{"phone": "+70861727720"}
0005432217808	6BB17E	3151 156290	ELENA SERGEEVA	{"phone": "+70344087222"}
0005432217809	2262F2	1364 071789	IGOR KUZNECOV	{"phone": "+70888025625"}
0005432217810	2262F2	2743 456362	OLGA POLYAKOVA	{"phone": "+70506170343"}
0005432217811	3E25C9	3733 625728	ALEKSANDR IVANOV	{"phone": "+70312355293"}
0005432217812	435924	3383 895654	PETR ALEKSEEV	{"email": "alekseevpetr-061979@postgrespro.ru", "phone": "+70750432033"}
0005432217813	6983D6	2517 381161	OLGA KOROLEVA	{"email": "koroleva-o_031981@postgrespro.ru", "phone": "+70414922175"}
0005432217814	D4A7BD	3402 694882	ROMAN NAZAROV	{"phone": "+70575270614"}
0005432217815	18CFC8	3228 262207	SERGEY NOVIKOV	{"email": "s.novikov.101974@postgrespro.ru", "phone": "+70891000065"}
0005432217816	4D6192	9853 732852	NIKOLAY MAKSIMOV	{"phone": "+70193111473"}
0005432217817	944234	0742 608503	NATALYA EFREMOVA	{"email": "efremovan28101980@postgrespro.ru", "phone": "+70619232415"}
0005432217818	944234	9906 321885	RAISA CHERNOVA	{"email": "chernova-raisa051968@postgrespro.ru", "phone": "+70504328175"}
0005432217819	9E784F	3991 645515	ALEKSANDR CHERNOV	{"phone": "+70575469479"}
0005432217820	9E784F	8684 878638	ALEKSANDR GRIGOREV	{"phone": "+70437577495"}
0005432217821	9E784F	2260 886903	NADEZHDA BORISOVA	{"email": "borisova_nadezhda.27121972@postgrespro.ru", "phone": "+70487195284"}
0005432217822	9E784F	5347 082469	MARIYA ALEKSANDROVA	{"email": "m-aleksandrova-111976@postgrespro.ru", "phone": "+70427166062"}
0005432217823	A7DEC8	2219 712292	SERGEY SOROKIN	{"phone": "+70482951704"}
0005432217824	0AD04F	8416 953846	ALEKSANDR GRIGOREV	{"phone": "+70680954804"}
0005432217825	0AD04F	9701 542620	GALINA FILIPPOVA	{"email": "filippovagalina_1969@postgrespro.ru", "phone": "+70084004940"}
0005432217826	B26C5A	5283 218238	OLGA FOMINA	{"email": "fomina.olga-09091973@postgrespro.ru", "phone": "+70240507892"}
0005432217827	E9B5DC	0243 713326	VALENTINA STEPANOVA	{"email": "valentina.stepanova071951@postgrespro.ru", "phone": "+70757688387"}
0005432217828	27182B	4075 017094	ILSHAT TIKHONOV	{"email": "ilshat.tikhonov_1974@postgrespro.ru", "phone": "+70419210575"}
0005432217829	27182B	9470 428723	VALERIY GRIGOREV	{"email": "grigorev.v-021983@postgrespro.ru", "phone": "+70553955686"}
0005432217830	27182B	7092 365067	KONSTANTIN KOZLOV	{"email": "kkozlov-1989@postgrespro.ru", "phone": "+70955591498"}
0005432217831	40D31E	9847 438310	LILIYA SOROKINA	{"email": "lsorokina-1965@postgrespro.ru", "phone": "+70496738582"}
0005432217832	876352	0811 119171	SERGEY ZAYCEV	{"email": "s.zaycev-11061964@postgrespro.ru", "phone": "+70408337258"}
0005432217833	41BDB1	0876 911087	VALENTINA KAZAKOVA	{"email": "valentina-kazakova-081975@postgrespro.ru", "phone": "+70922343485"}
0005432217834	C74F14	1825 336886	RAFAIL TIKHONOV	{"email": "tikhonovrafail-1976@postgrespro.ru", "phone": "+70254203014"}
0005432217835	8EEA43	5521 736221	MARIYA GAVRILOVA	{"email": "m.gavrilova-04101969@postgrespro.ru", "phone": "+70645327753"}
0005432217836	8EEA43	5854 141340	ALEKSANDR ISAEV	{"email": "isaev_aleksandr_031973@postgrespro.ru", "phone": "+70952430334"}
0005432217837	EDF2F0	6834 056558	VALENTINA TIMOFEEVA	{"phone": "+70504016288"}
0005432217838	7A40C6	2683 367399	RAISA MEDVEDEVA	{"email": "medvedeva.raisa-19031982@postgrespro.ru", "phone": "+70208116224"}
0005432217839	7A40C6	9369 047557	ANZHELIKA NESTEROVA	{"email": "nesterovaanzhelika.28121979@postgrespro.ru", "phone": "+70892329302"}
0005432217840	94A491	5539 435088	EGOR NIKOLAEV	{"email": "nikolaev.egor_091979@postgrespro.ru", "phone": "+70163249813"}
0005432217841	5B875E	9498 824238	GEORGIY VOLKOV	{"phone": "+70889726840"}
0005432217842	5B875E	6790 922230	DMITRIY NOVIKOV	{"email": "dmitriy-novikov.03061971@postgrespro.ru", "phone": "+70174950557"}
0005432217843	5B875E	6720 113132	SVETLANA KOZLOVA	{"phone": "+70144242172"}
0005432217844	5B875E	4940 098606	IRINA MAKAROVA	{"email": "makarovai091971@postgrespro.ru", "phone": "+70542982106"}
0005432217845	B30FC8	8722 884515	IRINA KOZLOVA	{"phone": "+70817138757"}
0005432217846	551EEB	2714 280670	OLEG VLASOV	{"email": "vlasovo-30051971@postgrespro.ru", "phone": "+70218251863"}
0005432217847	9E86ED	0375 959106	NIKOLAY GORBUNOV	{"email": "n_gorbunov-12071968@postgrespro.ru", "phone": "+70485373416"}
0005432217848	9E86ED	5118 097975	ILYA KUZMIN	{"email": "ilya.kuzmin_11081960@postgrespro.ru", "phone": "+70824144132"}
0005432217849	AA183B	5788 451632	SERGEY FEDOROV	{"email": "fedorov_sergey121980@postgrespro.ru", "phone": "+70238707227"}
0005432217850	FCE38D	6341 033976	MIKHAIL ALEKSEEV	{"email": "m-alekseev.25041974@postgrespro.ru", "phone": "+70339562929"}
0005432217851	6854FE	1584 738615	VALENTINA BORISOVA	{"phone": "+70033290439"}
0005432217852	45B106	3409 953901	VASILIY PETROV	{"email": "petrov-vasiliy.091973@postgrespro.ru", "phone": "+70411924306"}
0005432217853	C6969E	2199 772480	MARGARITA SMIRNOVA	{"phone": "+70602393044"}
0005432217854	C6969E	8915 585654	SAMIR FEDOROV	{"email": "samir.fedorov-1975@postgrespro.ru", "phone": "+70687134557"}
0005432217855	78337A	4242 794132	ANASTASIYA BARANOVA	{"email": "anastasiya.baranova02051980@postgrespro.ru", "phone": "+70026461602"}
0005432217856	78337A	0355 357769	NIKOLAY KUZNECOV	{"email": "n.kuznecov_011977@postgrespro.ru", "phone": "+70438041757"}
0005432217857	FDBF7D	1824 137852	VADIM ALEKSEEV	{"email": "alekseev_v18071967@postgrespro.ru", "phone": "+70711511614"}
0005432217858	9D5F30	3419 098232	TATYANA IVANOVA	{"email": "t-ivanova_021973@postgrespro.ru", "phone": "+70209720928"}
0005432217859	5123EE	3395 598355	EGOR GERASIMOV	{"email": "egor.gerasimov_03081974@postgrespro.ru", "phone": "+70653027851"}
0005432217860	53BC65	6599 997615	IRINA MOROZOVA	{"email": "irinamorozova-1980@postgrespro.ru", "phone": "+70332703142"}
0005432217861	DB483F	4966 272904	ALEKSEY BORISOV	{"phone": "+70128527504"}
0005432217862	DB483F	9346 639463	TATYANA DENISOVA	{"email": "denisovatatyana-091963@postgrespro.ru", "phone": "+70406641956"}
0005432217863	A79D85	4251 740929	GALINA AKIMOVA	{"email": "akimova.g-101972@postgrespro.ru", "phone": "+70210444698"}
0005432220027	99736A	7702 025782	ANDREY IVANOV	{"phone": "+70215314603"}
0005432219926	A540AF	5423 176589	GALINA DANILOVA	{"email": "g_danilova-21121963@postgrespro.ru", "phone": "+70253223357"}
0005432219927	E9A7AF	5356 054899	DANIIL MARTYNOV	{"email": "d.martynov-21051973@postgrespro.ru", "phone": "+70150693635"}
0005432219928	B94FA8	2684 853062	IVAN YAKOVLEV	{"email": "yakovlevi_111978@postgrespro.ru", "phone": "+70022185834"}
0005432219929	B94FA8	7800 667405	IRINA SEMENOVA	{"email": "semenova_irina.27091975@postgrespro.ru", "phone": "+70529843398"}
0005432219930	1BB869	2940 282140	ALEKSEY ALEKSANDROV	{"email": "a_aleksandrov-071973@postgrespro.ru", "phone": "+70017245723"}
0005432219931	04B0CE	8416 855771	OLGA PAVLOVA	{"email": "pavlova_olga-041967@postgrespro.ru", "phone": "+70073526771"}
0005432219932	87B9FA	1937 674927	LYUBOV PETROVA	{"email": "lpetrova-071964@postgrespro.ru", "phone": "+70096510088"}
0005432219933	DD92BD	0981 032340	ALEKSEY KULIKOV	{"email": "kulikovaleksey_17081972@postgrespro.ru", "phone": "+70787283718"}
0005432219934	13F7A1	5645 769609	GALINA MAKAROVA	{"phone": "+70958320722"}
0005432219935	C8D0FB	2689 234494	OKSANA SEMENOVA	{"phone": "+70305916854"}
0005432219936	5C7F0D	7201 376337	IRINA YUDINA	{"phone": "+70544319935"}
0005432219937	9F6070	5733 098219	ALEKSANDR ANDREEV	{"email": "a.andreev_25091983@postgrespro.ru", "phone": "+70539394134"}
0005432219938	2A3991	4665 963786	ALEKSANDR NAZAROV	{"phone": "+70935394286"}
0005432219939	D6EFB3	9907 147811	ARTEM PETROV	{"email": "petrovartem_25051975@postgrespro.ru", "phone": "+70509085054"}
0005432219940	D6EFB3	8789 266624	IVAN BORISOV	{"phone": "+70631159397"}
0005432219941	86C657	6772 484556	VLADIMIR ISAEV	{"email": "v.isaev-061982@postgrespro.ru", "phone": "+70833108609"}
0005432219942	86C657	3505 184693	VLADISLAV MIKHAYLOV	{"email": "mikhaylov.vladislav-1976@postgrespro.ru", "phone": "+70597096603"}
0005432219943	C314F5	2554 874717	NINA VOLKOVA	{"phone": "+70321276639"}
0005432219944	F17979	8484 129318	YULIYA NIKITINA	{"email": "nikitina-y08021981@postgrespro.ru", "phone": "+70531976819"}
0005432219945	44FFA0	2143 627661	ELENA ISAEVA	{"email": "elenaisaeva-18121971@postgrespro.ru", "phone": "+70611625629"}
0005432219946	44FFA0	0623 684468	IRINA VASILEVA	{"phone": "+70832179775"}
0005432219947	E0A2C5	8877 712070	SERGEY KUZNECOV	{"phone": "+70326325463"}
0005432219948	E0A2C5	9059 026707	VALERIY KUZNECOV	{"email": "kuznecov-valeriy_031976@postgrespro.ru", "phone": "+70283631779"}
0005432219949	E3FCCF	3423 484754	EVGENIY MOROZOV	{"email": "morozov.e31031973@postgrespro.ru", "phone": "+70598567508"}
0005432219950	9F8C2D	2988 081834	VALENTINA ZAKHAROVA	{"phone": "+70994848981"}
0005432219951	9F8C2D	9232 186908	NATALYA RYABOVA	{"email": "ryabova-n-07011969@postgrespro.ru", "phone": "+70525074314"}
0005432219952	9C8431	1663 332592	MAKSIM KAZAKOV	{"phone": "+70942034059"}
0005432219953	9C8431	5450 493183	NATALYA MOROZOVA	{"phone": "+70449305574"}
0005432219954	45DE2D	0247 698280	STANISLAV MOISEEV	{"email": "stanislav_moiseev.26111970@postgrespro.ru", "phone": "+70429926109"}
0005432219955	45DE2D	6828 624699	ALEKSANDR DAVYDOV	{"phone": "+70214139390"}
0005432219956	FE726E	9770 267433	TATYANA MELNIKOVA	{"phone": "+70620250519"}
0005432219957	9B7B78	1115 569035	LYUDMILA PETROVA	{"phone": "+70013912872"}
0005432219958	9B7B78	3017 036587	OLGA NIKITINA	{"phone": "+70805469394"}
0005432219959	EEB027	0886 091345	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr1967@postgrespro.ru", "phone": "+70979068061"}
0005432219960	16F04E	7749 896443	ANTONINA IVANOVA	{"email": "ivanovaantonina-041968@postgrespro.ru", "phone": "+70348977712"}
0005432219961	C6A101	7066 084661	ANATOLIY KUZNECOV	{"email": "kuznecov.anatoliy.1969@postgrespro.ru", "phone": "+70883385078"}
0005432219962	C6A101	9584 351823	ALEKSEY SCHERBAKOV	{"email": "a.scherbakov.1968@postgrespro.ru", "phone": "+70570469963"}
0005432219963	C6A101	3886 291846	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr-091972@postgrespro.ru", "phone": "+70966342536"}
0005432219964	216180	8087 403563	EKATERINA FILIPPOVA	{"phone": "+70464604531"}
0005432219965	83073A	2728 200521	POLINA PAVLOVA	{"phone": "+70571532188"}
0005432219966	C8B706	9648 838276	ALEKSANDR BELOV	{"phone": "+70232137992"}
0005432219967	A3A6B8	2419 633489	ALLA VOLKOVA	{"phone": "+70825536959"}
0005432219968	257DE3	9761 986200	ILYAS KOZLOV	{"email": "kozlov_ilyas21011975@postgrespro.ru", "phone": "+70902983915"}
0005432219969	DA63CC	7349 899269	ZHANNA PETROVA	{"email": "petrova.z.06041967@postgrespro.ru", "phone": "+70348375649"}
0005432219970	14EC4B	6177 230928	ELENA FEDOROVA	{"phone": "+70358971744"}
0005432219971	14EC4B	6688 473024	DENIS ZHURAVLEV	{"email": "zhuravlev_denis.24031966@postgrespro.ru", "phone": "+70220339071"}
0005432219972	14EC4B	3824 663381	ALEKSANDR BORISOV	{"email": "aleksandr_borisov.21061976@postgrespro.ru", "phone": "+70600922399"}
0005432219973	37C34B	6959 115232	ARTEM BONDARENKO	{"email": "artem-bondarenko.091976@postgrespro.ru", "phone": "+70293319514"}
0005432219974	0FD9ED	2293 376611	NIKOLAY KULIKOV	{"email": "kulikov_n111965@postgrespro.ru", "phone": "+70746960328"}
0005432219975	0FD9ED	5387 853649	VALENTIN ZAYCEV	{"phone": "+70023687907"}
0005432219976	0FD9ED	9517 473536	ANDREY GUSEV	{"email": "guseva071968@postgrespro.ru", "phone": "+70153103288"}
0005432219977	219803	4103 184456	VYACHESLAV ROMANOV	{"phone": "+70270718652"}
0005432219978	FF6FF3	2883 594569	EVGENIYA KUZMINA	{"email": "e.kuzmina-061963@postgrespro.ru", "phone": "+70310341452"}
0005432219979	4A09EF	1394 226896	DENIS VASILEV	{"email": "vasilev_denis_091967@postgrespro.ru", "phone": "+70649210012"}
0005432219980	5BED87	1618 051699	IRINA KOVALEVA	{"email": "irina-kovaleva-1977@postgrespro.ru", "phone": "+70769680588"}
0005432219981	5BED87	5495 374361	SOFYA FEDOROVA	{"phone": "+70237405164"}
0005432219982	D1215D	3721 048209	ROMAN VOLKOV	{"email": "volkov.r-1977@postgrespro.ru", "phone": "+70922355383"}
0005432219983	D1215D	1293 004474	ANASTASIYA ZAYCEVA	{"phone": "+70631464515"}
0005432219984	CD2F58	1092 537042	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev1964@postgrespro.ru", "phone": "+70481351453"}
0005432219985	474139	0848 412292	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov_10111972@postgrespro.ru", "phone": "+70832860500"}
0005432219986	8C96AA	0984 280495	VERONIKA KUZNECOVA	{"email": "veronika.kuznecova.24051969@postgrespro.ru", "phone": "+70175679332"}
0005432219987	2A65AE	4796 209960	ELMIRA LAZAREVA	{"phone": "+70128731721"}
0005432219988	B9CA69	8500 681951	IGOR KOZLOV	{"email": "i.kozlov1979@postgrespro.ru", "phone": "+70248272339"}
0005432219989	2F0C23	6317 057683	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova.28021995@postgrespro.ru", "phone": "+70863920251"}
0005432219990	D92134	5474 983122	TATYANA VASILEVA	{"email": "t.vasileva_111982@postgrespro.ru", "phone": "+70078048357"}
0005432219991	65F0DF	7356 690690	OKSANA SAVELEVA	{"phone": "+70050996164"}
0005432219992	21FF4A	6035 877290	ALEKSANDR IVANOV	{"email": "aleksandrivanov_11061965@postgrespro.ru", "phone": "+70621482906"}
0005432219993	898EBA	3490 899150	ZHANNA KUZNECOVA	{"phone": "+70437301743"}
0005432219994	045954	5449 809460	SERGEY POPOV	{"email": "sergeypopov28111960@postgrespro.ru", "phone": "+70668304167"}
0005432219995	045954	1393 132658	MARINA BORISOVA	{"phone": "+70402876925"}
0005432219996	B399F0	3862 439163	TATYANA KOLESNIKOVA	{"phone": "+70756453507"}
0005432219997	F82906	8223 657174	OLGA PETROVA	{"email": "opetrova_24101980@postgrespro.ru", "phone": "+70752707155"}
0005432219998	F82906	6226 167060	NATALYA NAZAROVA	{"email": "natalya-nazarova031975@postgrespro.ru", "phone": "+70838465548"}
0005432219999	2139DE	5952 196587	VERA AFANASEVA	{"email": "afanasevavera.1977@postgrespro.ru", "phone": "+70370525475"}
0005432220000	31D342	5262 367200	ANASTASIYA NIKITINA	{"phone": "+70742377442"}
0005432220001	31D342	8022 158423	OLGA AFANASEVA	{"email": "oafanaseva_21091972@postgrespro.ru", "phone": "+70698360935"}
0005432220002	B059B3	7827 718757	ANASTASIYA VOROBEVA	{"phone": "+70036172654"}
0005432220003	B059B3	4722 208701	IVAN FEDOROV	{"phone": "+70887550632"}
0005432220004	3DFD3A	8600 869414	MIKHAIL VLASOV	{"phone": "+70146298536"}
0005432220005	3DFD3A	4523 874964	ALEKSANDR ZAKHAROV	{"email": "a-zakharov_02091975@postgrespro.ru", "phone": "+70090310508"}
0005432220006	094E7B	6453 132198	DIANA FEDOROVA	{"phone": "+70523897554"}
0005432220007	094E7B	5797 698750	GALINA LUKYANOVA	{"email": "lukyanova_g.061964@postgrespro.ru", "phone": "+70984677774"}
0005432220008	1CE998	6501 957861	VITALIY AFANASEV	{"email": "afanasev_v.1974@postgrespro.ru", "phone": "+70888446089"}
0005432220009	1CE998	8240 608645	DMITRIY KAZAKOV	{"phone": "+70025998283"}
0005432220010	352CBA	5720 316910	NATALYA MAKAROVA	{"phone": "+70750152013"}
0005432220011	352CBA	6394 337054	NADEZHDA GRISHINA	{"email": "nadezhda.grishina_021977@postgrespro.ru", "phone": "+70027310754"}
0005432220012	352CBA	8025 084182	EVGENIY KOZLOV	{"email": "evgeniy.kozlov101977@postgrespro.ru", "phone": "+70998379117"}
0005432220013	7664D3	2394 151983	TATYANA TARASOVA	{"phone": "+70519948255"}
0005432220014	42BF04	7181 609537	VASILIY NOVIKOV	{"email": "novikov_vasiliy.041991@postgrespro.ru", "phone": "+70910043266"}
0005432220015	08D18E	3199 040272	DMITRIY KONOVALOV	{"email": "konovalov_dmitriy061971@postgrespro.ru", "phone": "+70685148917"}
0005432220016	08D18E	2466 377051	GALINA SOLOVEVA	{"email": "galina.soloveva-28111968@postgrespro.ru", "phone": "+70655459544"}
0005432220017	65AEB0	3618 745178	TATYANA ZAKHAROVA	{"email": "tatyana_zakharova1974@postgrespro.ru", "phone": "+70426606693"}
0005432220018	65AEB0	3271 098436	ARTUR KOZLOV	{"email": "kozlov.artur.26041965@postgrespro.ru", "phone": "+70857283538"}
0005432220019	65AEB0	3269 524179	LIDIYA STEPANOVA	{"phone": "+70167458940"}
0005432220020	D7CD58	8567 315377	TAMARA BORISOVA	{"phone": "+70702399921"}
0005432220021	11260B	1691 122928	TATYANA ZHUKOVA	{"phone": "+70144475988"}
0005432220022	49712E	3432 373229	MARIYA SOKOLOVA	{"phone": "+70047519716"}
0005432220023	49712E	9226 215333	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov-1972@postgrespro.ru", "phone": "+70356048206"}
0005432220024	2DAB28	8127 335726	ANNA BELOVA	{"phone": "+70957962979"}
0005432220025	2DAB28	1563 064646	VALENTINA SMIRNOVA	{"phone": "+70415876016"}
0005432220026	FB45F2	4918 098868	VALENTINA FEDOROVA	{"phone": "+70019937332"}
0005432220028	1302D2	7727 263277	RENATA BORISOVA	{"email": "r-borisova-021967@postgrespro.ru", "phone": "+70771608592"}
0005432220029	667911	9087 743645	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr.21011973@postgrespro.ru", "phone": "+70218907037"}
0005432220030	1293B9	5996 025275	SERGEY FILIPPOV	{"phone": "+70025918161"}
0005432220031	1E3C69	7021 256618	ALEKSANDR KOZLOV	{"phone": "+70565850817"}
0005432220032	1E3C69	4704 011805	DENIS RODIONOV	{"email": "rodionov-d25011970@postgrespro.ru", "phone": "+70150708187"}
0005432220033	78BC5E	8166 536717	OKSANA SCHERBAKOVA	{"phone": "+70950262348"}
0005432220034	78BC5E	0266 645850	OKSANA VASILEVA	{"email": "oksanavasileva-07011974@postgrespro.ru", "phone": "+70573386351"}
0005432220035	7231E6	3331 713260	VLADIMIR ORLOV	{"email": "vladimir_orlov_1980@postgrespro.ru", "phone": "+70458050424"}
0005432220036	7231E6	6299 989441	VIKTOR IVANOV	{"email": "ivanov.viktor-011987@postgrespro.ru", "phone": "+70185289147"}
0005432220037	7231E6	3150 631646	VENERA TARASOVA	{"phone": "+70294999619"}
0005432220038	AA62E9	3682 023731	YURIY FOMIN	{"email": "yuriy.fomin081966@postgrespro.ru", "phone": "+70494720864"}
0005432220039	25A76B	7251 914474	LYUDMILA GORBUNOVA	{"phone": "+70410641105"}
0005432220040	25A76B	2169 808662	LYUBOV VASILEVA	{"phone": "+70814267649"}
0005432220041	55C47E	9183 048606	NATALYA AFANASEVA	{"phone": "+70481307789"}
0005432220042	55C47E	6925 892116	TATYANA VOLKOVA	{"email": "volkovat1960@postgrespro.ru", "phone": "+70516894763"}
0005432220043	518573	6113 216742	ALEKSANDRA FILATOVA	{"email": "a.filatova041973@postgrespro.ru", "phone": "+70085985530"}
0005432220044	217603	4085 771536	IRINA YAKOVLEVA	{"phone": "+70723427547"}
0005432220045	9127AD	7222 075037	ALEKSANDR IVANOV	{"phone": "+70768786765"}
0005432220046	2D340F	9115 773843	MIKHAIL DAVYDOV	{"phone": "+70261159537"}
0005432220047	7BD88D	5156 801834	EVGENIYA MOROZOVA	{"email": "e-morozova.1964@postgrespro.ru", "phone": "+70635990929"}
0005432220048	68AB4E	6907 031911	VERA ZHURAVLEVA	{"email": "verazhuravleva_1967@postgrespro.ru", "phone": "+70650387865"}
0005432220049	F6DD03	9411 205029	EMIL TIKHONOV	{"email": "tikhonov_e_1969@postgrespro.ru", "phone": "+70686587391"}
0005432220050	F6DD03	0225 869686	RENAT IVANOV	{"email": "renat.ivanov_101979@postgrespro.ru", "phone": "+70176820048"}
0005432220051	D95DCE	8074 588307	ANNA NAUMOVA	{"email": "naumova-anna1968@postgrespro.ru", "phone": "+70642186006"}
0005432220052	D95DCE	6290 133305	NATALYA KUZNECOVA	{"email": "kuznecovanatalya_111977@postgrespro.ru", "phone": "+70119873230"}
0005432220053	784FBF	3320 949723	ALEKSANDR ZHUKOV	{"phone": "+70146394296"}
0005432220054	E32E5B	5214 668358	EVDOKIYA SOKOLOVA	{"email": "evdokiyasokolova_03021983@postgrespro.ru", "phone": "+70549297585"}
0005432220055	E32E5B	0251 230950	VALERIYA MAKSIMOVA	{"phone": "+70238029145"}
0005432220056	6ECBA6	5406 770192	NINA AFANASEVA	{"phone": "+70662263488"}
0005432220057	6ECBA6	7590 685306	IRINA IVANOVA	{"phone": "+70951330064"}
0005432220058	860BF0	1865 137310	GLEB TARASOV	{"phone": "+70112812885"}
0005432220059	860BF0	9729 749144	IVAN NIKOLAEV	{"email": "ivan_nikolaev.1976@postgrespro.ru", "phone": "+70200785784"}
0005432220060	8B5221	3996 591378	ALEKSANDR VLASOV	{"email": "vlasova-17041975@postgrespro.ru", "phone": "+70925706749"}
0005432220061	F45B2D	4462 836333	VERA KISELEVA	{"phone": "+70865020714"}
0005432220062	BE3120	0344 389492	NINA SOROKINA	{"phone": "+70695955111"}
0005432220063	BE3120	6045 575923	LYUDMILA PETROVA	{"email": "l-petrova_1959@postgrespro.ru", "phone": "+70683491325"}
0005432220064	FA2B78	3631 174305	DANILA KONOVALOV	{"email": "konovalov.d_1978@postgrespro.ru", "phone": "+70033791283"}
0005432220065	FA2B78	2460 385777	YURIY SMIRNOV	{"email": "y-smirnov_1972@postgrespro.ru", "phone": "+70060790239"}
0005432220066	4021FE	4928 591620	NATALYA GAVRILOVA	{"phone": "+70751370049"}
0005432220067	6EAB62	9363 943261	GALINA KUZNECOVA	{"phone": "+70222041429"}
0005432220068	8DF959	0519 368573	SERGEY DMITRIEV	{"email": "s_dmitriev.15081978@postgrespro.ru", "phone": "+70280826016"}
0005432220069	7B8DDD	0943 953194	ALEKSEY KARPOV	{"phone": "+70870563394"}
0005432220070	7B8DDD	1321 327455	ALEKSANDR BONDARENKO	{"phone": "+70565833961"}
0005432220071	1D936C	8586 986830	ANDREY IVANOV	{"phone": "+70109259808"}
0005432220072	1D936C	9289 298236	VERA VASILEVA	{"phone": "+70201843058"}
0005432220073	B2A114	8991 570207	EKATERINA GAVRILOVA	{"phone": "+70430770866"}
0005432220074	964C6E	6043 850766	OLGA NIKITINA	{"phone": "+70999624442"}
0005432220075	65C73D	8875 990490	ELISEY MIKHAYLOV	{"phone": "+70859340923"}
0005432220076	EFC170	3149 538996	LYUDMILA MOROZOVA	{"email": "morozova_lyudmila_031981@postgrespro.ru", "phone": "+70134412898"}
0005432220077	EFC170	3355 428523	LYUDMILA KUZNECOVA	{"phone": "+70756741956"}
0005432220078	D3D262	5786 220930	SERGEY ABRAMOV	{"phone": "+70160387467"}
0005432220079	9FF60C	4474 428416	GALINA MAKAROVA	{"email": "makarova.galina_1958@postgrespro.ru", "phone": "+70790516170"}
0005432220080	9FF60C	6929 900919	OLGA NAZAROVA	{"email": "olga_nazarova_1973@postgrespro.ru", "phone": "+70861302664"}
0005432220081	C1681B	6035 751643	VALENTINA ALEKSEEVA	{"phone": "+70738655398"}
0005432220082	C1681B	5751 995966	DMITRIY VOLKOV	{"email": "dmitriy_volkov081973@postgrespro.ru", "phone": "+70466686612"}
0005432220083	FBE75E	8397 646805	IVAN BONDARENKO	{"phone": "+70037199517"}
0005432220084	2BB65D	3825 067134	ANASTASIYA SOLOVEVA	{"email": "a_soloveva_1972@postgrespro.ru", "phone": "+70519039598"}
0005432220085	806177	2412 693498	ALENA KOZLOVA	{"email": "kozlova-alena_1970@postgrespro.ru", "phone": "+70820676336"}
0005432220086	4B4AB2	2177 251282	SERGEY KULIKOV	{"phone": "+70863748866"}
0005432220087	C824FC	4054 723992	ALEKSANDR FEDOTOV	{"email": "fedotov.aleksandr-26061975@postgrespro.ru", "phone": "+70506544049"}
0005432220088	C824FC	9021 970620	ANDREY IVANOV	{"email": "ivanov.a-1979@postgrespro.ru", "phone": "+70342222381"}
0005432220089	13F348	1026 569122	NINA KONOVALOVA	{"phone": "+70768722602"}
0005432220090	D68BC8	3728 311638	SERGEY PAVLOV	{"phone": "+70318550862"}
0005432220091	92AE6D	8632 099951	IRINA KRASNOVA	{"phone": "+70001311962"}
0005432220092	92AE6D	4733 952625	TAMARA PETROVA	{"email": "petrova.t.01051971@postgrespro.ru", "phone": "+70883832523"}
0005432220093	5D11D2	1517 499896	VYACHESLAV SHEVCHENKO	{"email": "shevchenko-v081975@postgrespro.ru", "phone": "+70367343682"}
0005432220094	5D11D2	6342 125743	NIKOLAY SMIRNOV	{"email": "smirnov_n-29101972@postgrespro.ru", "phone": "+70091560506"}
0005432220095	5D11D2	3359 987869	RAFAIL BARANOV	{"phone": "+70456073682"}
0005432220096	CD6E76	2241 859584	ELENA KOVALEVA	{"email": "elena_kovaleva.061963@postgrespro.ru", "phone": "+70706118403"}
0005432220097	B30E2A	9334 181602	ILYA KUDRYASHOV	{"email": "ilya_kudryashov-1971@postgrespro.ru", "phone": "+70224721290"}
0005432220098	B30E2A	0246 400933	LYUBOV KAZAKOVA	{"email": "kazakova.l_12061974@postgrespro.ru", "phone": "+70170559401"}
0005432220099	3EFFB3	5119 290184	ANTONINA NIKIFOROVA	{"phone": "+70354375156"}
0005432220100	6FC2D9	7671 556700	ALEKSANDR ANTONOV	{"email": "aleksandr_antonov-03061989@postgrespro.ru", "phone": "+70149358774"}
0005432220101	6FC2D9	1215 824821	LIDIYA ANDREEVA	{"email": "l_andreeva29091978@postgrespro.ru", "phone": "+70383520177"}
0005432220102	01575B	0814 641197	MAKSIM ZAYCEV	{"phone": "+70521228455"}
0005432220103	063DE8	8282 444937	VIKTOR ANTONOV	{"email": "v_antonov_121960@postgrespro.ru", "phone": "+70279839417"}
0005432220104	063DE8	2265 397529	YULIYA ZAKHAROVA	{"email": "y_zakharova_06011977@postgrespro.ru", "phone": "+70803108858"}
0005432220105	063DE8	9943 969601	IVAN NAUMOV	{"email": "i-naumov_01121966@postgrespro.ru", "phone": "+70146928118"}
0005432220106	7AD5DB	1316 475786	VALENTINA NIKOLAEVA	{"email": "valentina-nikolaeva_1969@postgrespro.ru", "phone": "+70245329780"}
0005432220107	7AD5DB	2567 573466	ANDREY GORBUNOV	{"email": "gorbunov.andrey.16011974@postgrespro.ru", "phone": "+70435602616"}
0005432220108	C695CA	2249 362063	SEMEN NIKOLAEV	{"phone": "+70431926094"}
0005432220109	6D8361	7881 644347	VIKTOR STEPANOV	{"phone": "+70900675418"}
0005432220110	6D8361	1969 833931	MARINA SERGEEVA	{"phone": "+70041513337"}
0005432220111	2B262B	3277 722078	VASILIY VLASOV	{"phone": "+70496976415"}
0005432220112	31318E	7537 708770	ELENA ROMANOVA	{"email": "romanova.e.091964@postgrespro.ru", "phone": "+70927984847"}
0005432220113	31318E	5335 263117	YULIYA FILIPPOVA	{"email": "y-filippova_071978@postgrespro.ru", "phone": "+70517409254"}
0005432220114	C42E8C	6720 453455	MARINA KUZNECOVA	{"email": "kuznecova.m_1964@postgrespro.ru", "phone": "+70010964877"}
0005432220115	C42E8C	6177 274132	PETR KAZAKOV	{"email": "kazakov_p_091961@postgrespro.ru", "phone": "+70266829836"}
0005432220116	8A2E58	9559 421140	SERGEY MAKAROV	{"email": "s-makarov-1958@postgrespro.ru", "phone": "+70748860603"}
0005432220117	D13C04	0268 261097	TATYANA SAVELEVA	{"email": "t-saveleva-031976@postgrespro.ru", "phone": "+70642619655"}
0005432220118	D13C04	1515 831419	ALIYA ZHUKOVA	{"phone": "+70877929083"}
0005432220119	67482B	9697 829286	NATALYA VOLKOVA	{"phone": "+70542755390"}
0005432220120	81A29C	3727 583330	OLEG ANDREEV	{"email": "andreevo.03101970@postgrespro.ru", "phone": "+70067189216"}
0005432220121	81A29C	8661 983411	DENIS MIKHAYLOV	{"email": "mikhaylov-d.11091976@postgrespro.ru", "phone": "+70897436259"}
0005432220122	7EC1ED	9841 932427	DMITRIY ABRAMOV	{"email": "dmitriy_abramov.1960@postgrespro.ru", "phone": "+70556972346"}
0005432220123	92FC80	3627 917453	SVETLANA NOVIKOVA	{"email": "novikova.s-1972@postgrespro.ru", "phone": "+70055773359"}
0005432220124	2ECD48	1618 344471	ALEKSANDRA DMITRIEVA	{"email": "dmitrieva.a-031982@postgrespro.ru", "phone": "+70368235461"}
0005432220125	2BDA66	8339 388231	SVETLANA SCHERBAKOVA	{"phone": "+70027608008"}
0005432222859	9C877D	9747 637959	EVGENIYA KUZNECOVA	{"phone": "+70717590526"}
0005432220126	F43964	8766 502433	EKATERINA LOGINOVA	{"email": "loginova.e1964@postgrespro.ru", "phone": "+70409174277"}
0005432220127	2E208B	0811 427521	IGOR SOROKIN	{"phone": "+70025745267"}
0005432220128	AC1F86	1427 960240	ELIZAVETA ZAKHAROVA	{"phone": "+70725664357"}
0005432220129	D97D8A	9046 939995	KONSTANTIN OSIPOV	{"phone": "+70731495074"}
0005432220130	D97D8A	7788 823200	SERGEY DENISOV	{"email": "s_denisov30061974@postgrespro.ru", "phone": "+70370902379"}
0005432220131	5828FC	7888 820353	DANIL SCHERBAKOV	{"email": "scherbakovd_1966@postgrespro.ru", "phone": "+70674526416"}
0005432220132	5828FC	7864 993955	ILNAR IVANOV	{"email": "ilnar_ivanov1982@postgrespro.ru", "phone": "+70857873250"}
0005432222777	8DDC98	4754 956344	NIKOLAY ABRAMOV	{"phone": "+70391632076"}
0005432222688	986DCC	9518 043924	ALEKSANDRA GORBUNOVA	{"phone": "+70478564118"}
0005432222689	50467F	7033 129883	NATALYA BELOVA	{"phone": "+70219550744"}
0005432222690	50467F	2052 739809	VLADISLAV IVANOV	{"email": "vladislav_ivanov_19121966@postgrespro.ru", "phone": "+70431644986"}
0005432222691	50467F	7481 819497	VALERIYA BELOVA	{"email": "belova.valeriya_081969@postgrespro.ru", "phone": "+70866529426"}
0005432222692	50467F	1214 320717	LYUDMILA VOROBEVA	{"email": "lyudmila_vorobeva_111977@postgrespro.ru", "phone": "+70347547898"}
0005432222693	B79187	0035 843505	GENNADIY FOMIN	{"phone": "+70489691253"}
0005432222694	2D2E22	5621 583951	OLGA KOMAROVA	{"email": "komarova.olga.05071964@postgrespro.ru", "phone": "+70200039554"}
0005432222695	EDA9C9	4822 580486	ELENA KOLESNIKOVA	{"phone": "+70745739759"}
0005432222696	C4F53B	3348 866164	NIKOLAY POPOV	{"phone": "+70614839820"}
0005432222697	EE8D6A	3578 332907	ELENA SERGEEVA	{"email": "elena-sergeeva_031975@postgrespro.ru", "phone": "+70662265795"}
0005432222698	42B8F6	8096 581641	YANA MOROZOVA	{"phone": "+70817642218"}
0005432222699	42B8F6	1275 531132	STEPAN SCHERBAKOV	{"phone": "+70224031088"}
0005432222700	67BD35	0885 516626	KIRILL ZAYCEV	{"phone": "+70065247803"}
0005432222701	67BD35	9944 653107	LYUDMILA ZHURAVLEVA	{"phone": "+70843774100"}
0005432222702	6203F7	8326 338470	LYUBOV KRASNOVA	{"email": "krasnova_l1967@postgrespro.ru", "phone": "+70215692514"}
0005432222703	03F22F	0019 627392	SVETLANA MAKSIMOVA	{"email": "svetlana.maksimova_1981@postgrespro.ru", "phone": "+70398224102"}
0005432222704	03F22F	0397 066640	LILIYA BORISOVA	{"phone": "+70969550560"}
0005432222705	F55195	9160 521655	ANNA LAZAREVA	{"email": "lazarevaanna-20061966@postgrespro.ru", "phone": "+70077982337"}
0005432222706	C4C42A	5386 432810	EKATERINA KAZAKOVA	{"email": "e_kazakova-22061979@postgrespro.ru", "phone": "+70738920199"}
0005432222707	C4C42A	7108 156094	NINA PETROVA	{"email": "petrova.nina.1977@postgrespro.ru", "phone": "+70245377685"}
0005432222708	C4C42A	8914 419033	MIKHAIL BELOV	{"phone": "+70569771275"}
0005432222709	7010E4	0855 356917	TATYANA NOVIKOVA	{"phone": "+70440395837"}
0005432222710	E63F22	7031 629179	SVETLANA IVANOVA	{"email": "s.ivanova021974@postgrespro.ru", "phone": "+70332657232"}
0005432222711	3074A0	8693 602840	OLGA NAZAROVA	{"phone": "+70531928255"}
0005432222712	9A08BE	4718 942440	MARIYA KULIKOVA	{"phone": "+70502056114"}
0005432222713	9A08BE	5533 384356	ALENA PETROVA	{"phone": "+70900260164"}
0005432222714	EFB567	3433 072882	ALEKSEY MEDVEDEV	{"email": "a.medvedev-21081979@postgrespro.ru", "phone": "+70202481020"}
0005432222715	EFB567	4798 399966	NATALYA MOISEEVA	{"phone": "+70242198172"}
0005432222716	E0D9B7	0116 644667	TATYANA ROMANOVA	{"email": "tromanova-051968@postgrespro.ru", "phone": "+70965782484"}
0005432222717	E0D9B7	0590 000164	TAMARA KOZLOVA	{"phone": "+70645876475"}
0005432222718	E0D9B7	9516 345227	VLADIMIR STEPANOV	{"phone": "+70951276222"}
0005432222719	51FCCB	8046 465984	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay.081965@postgrespro.ru", "phone": "+70928155331"}
0005432222720	93C4AC	1052 669646	NIKITA MAKAROV	{"email": "nmakarov-061966@postgrespro.ru", "phone": "+70084769511"}
0005432222721	847E78	8134 038156	ROZA IVANOVA	{"email": "ivanovaroza-1970@postgrespro.ru", "phone": "+70239834324"}
0005432222722	847E78	3316 803711	VLADISLAV VASILEV	{"email": "v-vasilev_111976@postgrespro.ru", "phone": "+70692570726"}
0005432222723	41DDDD	3556 413711	VLADIMIR DAVYDOV	{"phone": "+70600222913"}
0005432222724	8581D6	7187 538749	NATALYA SIDOROVA	{"email": "sidorovanatalya081977@postgrespro.ru", "phone": "+70686438781"}
0005432222725	8581D6	3758 575392	VLADIMIR MARTYNOV	{"phone": "+70167721246"}
0005432222726	45602C	8478 105359	PAVEL KOROLEV	{"email": "korolev_pavel-111978@postgrespro.ru", "phone": "+70468388159"}
0005432222727	6BC560	6598 815109	ELENA KOMAROVA	{"email": "elena_komarova.091977@postgrespro.ru", "phone": "+70258462817"}
0005432222728	27AF73	3644 687430	SERGEY ZAYCEV	{"phone": "+70833191852"}
0005432222729	629AE5	0129 760829	MIKHAIL FILIPPOV	{"phone": "+70468914959"}
0005432222730	629AE5	7881 657457	NATALYA SOROKINA	{"phone": "+70423586497"}
0005432222731	61B966	4695 635470	ALEKSANDR NOVIKOV	{"email": "novikova-24091970@postgrespro.ru", "phone": "+70563896275"}
0005432222732	61B966	4353 053596	EKATERINA LEBEDEVA	{"email": "e-lebedeva-1948@postgrespro.ru", "phone": "+70683329786"}
0005432222733	C8B684	6034 073446	OLGA IVANOVA	{"email": "ivanova-o_1961@postgrespro.ru", "phone": "+70813317746"}
0005432222734	C8B684	2960 265808	SERGEY VOROBEV	{"email": "s-vorobev_1967@postgrespro.ru", "phone": "+70123180553"}
0005432222735	9BA1A8	4108 274390	GERMAN ALEKSANDROV	{"email": "g-aleksandrov.15111975@postgrespro.ru", "phone": "+70678421367"}
0005432222736	CB2EED	6080 485840	VLADIMIR GORBUNOV	{"phone": "+70189267600"}
0005432222737	ECD7F8	8650 901202	VLADIMIR BELOV	{"email": "belovvladimir-1970@postgrespro.ru", "phone": "+70625819423"}
0005432222738	3750EB	0976 628169	VLADIMIR SHEVCHENKO	{"phone": "+70520183861"}
0005432222739	7287FB	6591 870816	VYACHESLAV ALEKSANDROV	{"phone": "+70009332541"}
0005432222740	1A0BEE	3577 805861	VALERIY SMIRNOV	{"phone": "+70715926101"}
0005432222741	1A0BEE	8628 801985	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev-061964@postgrespro.ru", "phone": "+70704348061"}
0005432222742	A93F42	6645 548144	LARISA ORLOVA	{"email": "l.orlova-1972@postgrespro.ru", "phone": "+70878067097"}
0005432222743	9CB713	9410 639426	DARYA LUKYANOVA	{"email": "lukyanovad.18071990@postgrespro.ru", "phone": "+70571214058"}
0005432222744	9CB713	8692 141722	ALEKSANDR FEDOROV	{"phone": "+70235042749"}
0005432222745	4AD3E4	0942 630150	ELIZAVETA YAKOVLEVA	{"email": "e_yakovleva101965@postgrespro.ru", "phone": "+70503147776"}
0005432222746	4AD3E4	8925 395943	SERGEY KUZNECOV	{"email": "sergeykuznecov-111972@postgrespro.ru", "phone": "+70700185515"}
0005432222747	1C90E3	6053 761604	MARIYA VLASOVA	{"email": "mariya-vlasova.081974@postgrespro.ru", "phone": "+70660961758"}
0005432222748	1C90E3	9782 397108	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-1975@postgrespro.ru", "phone": "+70506603190"}
0005432222749	4C0639	0401 223424	IRINA MEDVEDEVA	{"email": "imedvedeva-121963@postgrespro.ru", "phone": "+70492866193"}
0005432222750	B8DD44	2652 469664	IVAN MAKAROV	{"phone": "+70414092714"}
0005432222751	A41E1C	2303 075062	MIKHAIL FEDOROV	{"email": "mfedorov11101992@postgrespro.ru", "phone": "+70678334566"}
0005432222752	A41E1C	2519 090459	VYACHESLAV PETROV	{"email": "petrovvyacheslav.011970@postgrespro.ru", "phone": "+70337789435"}
0005432222753	8B812E	8287 980711	OLGA IVANOVA	{"email": "olga.ivanova1979@postgrespro.ru", "phone": "+70755383990"}
0005432222754	B8982E	1805 262945	ANNA KULIKOVA	{"phone": "+70018549218"}
0005432222755	B8982E	3209 553981	ROZALIYA ANDREEVA	{"phone": "+70420133017"}
0005432222756	2ABE8D	7746 215042	POLINA VLASOVA	{"phone": "+70024884784"}
0005432222757	429811	5687 309310	ALEKSANDR VOLKOV	{"email": "a_volkov-121961@postgrespro.ru", "phone": "+70129467052"}
0005432222758	B0CD59	2444 016304	NIKOLAY KUZNECOV	{"phone": "+70609984499"}
0005432222759	E6D1F7	4570 992380	VYACHESLAV KONOVALOV	{"phone": "+70261172168"}
0005432222760	E6D1F7	1632 603065	KLAVDIYA SEMENOVA	{"email": "semenovak.1973@postgrespro.ru", "phone": "+70218397355"}
0005432222761	80BAE5	8844 738608	LARISA NOVIKOVA	{"email": "l-novikova.22031973@postgrespro.ru", "phone": "+70624856612"}
0005432222762	E7D6DC	9266 960979	VLADIMIR ILIN	{"phone": "+70399656559"}
0005432222763	E7D6DC	5279 261482	DENIS KRASNOV	{"phone": "+70645746433"}
0005432222764	E7D6DC	0080 320218	ALEKSANDR NAZAROV	{"phone": "+70510293679"}
0005432222765	20E963	7518 006855	LYUBOV AKIMOVA	{"email": "akimoval-1980@postgrespro.ru", "phone": "+70744913009"}
0005432222766	301F1A	8450 955688	PAVEL ZAKHAROV	{"phone": "+70433617594"}
0005432222767	A5C4CF	0795 946431	VERA KOZLOVA	{"email": "kozlova-vera-09081983@postgrespro.ru", "phone": "+70667088847"}
0005432222768	9ABE2F	3119 603583	MATVEY MARTYNOV	{"phone": "+70777739144"}
0005432222769	9ABE2F	0454 435101	TATYANA MOROZOVA	{"email": "t-morozova_15011972@postgrespro.ru", "phone": "+70642721146"}
0005432222770	36A1DE	6298 464442	ALEKSANDR SERGEEV	{"email": "sergeev-a1982@postgrespro.ru", "phone": "+70449196026"}
0005432222771	36A1DE	8605 619484	EKATERINA GORBUNOVA	{"phone": "+70685397269"}
0005432222772	2D3742	3699 283455	EVDOKIYA FADEEVA	{"email": "fadeeva.e.111972@postgrespro.ru", "phone": "+70526857537"}
0005432222773	9F4D61	3717 827429	EVGENIY MIKHAYLOV	{"email": "e.mikhaylov_101975@postgrespro.ru", "phone": "+70412996919"}
0005432222774	9F4D61	7849 088368	VLADIMIR RODIONOV	{"phone": "+70712757068"}
0005432222775	65204B	5661 448291	TATYANA SOROKINA	{"email": "t_sorokina1974@postgrespro.ru", "phone": "+70472056310"}
0005432222776	65204B	0135 962471	KSENIYA IVANOVA	{"email": "kivanova-25101972@postgrespro.ru", "phone": "+70338092024"}
0005432222778	CA4394	9590 376202	TAMARA FEDOROVA	{"email": "t_fedorova_1970@postgrespro.ru", "phone": "+70171312302"}
0005432222779	2D09B7	2740 914604	ANNA KUZNECOVA	{"email": "anna-kuznecova-21101986@postgrespro.ru", "phone": "+70119177327"}
0005432222780	8B6868	6636 966577	OLGA BELOVA	{"email": "belovaolga1971@postgrespro.ru", "phone": "+70000284620"}
0005432222781	8B6868	2206 163639	VADIM KRASNOV	{"email": "krasnov_v_031969@postgrespro.ru", "phone": "+70882484434"}
0005432222782	B52AB9	8463 171890	BORIS PAVLOV	{"phone": "+70501078441"}
0005432222783	B52AB9	0282 766105	MAKSIM GAVRILOV	{"email": "mgavrilov_091963@postgrespro.ru", "phone": "+70841419272"}
0005432222784	3549AC	9237 229577	PETR IVANOV	{"email": "petrivanov.06041973@postgrespro.ru", "phone": "+70258796585"}
0005432222785	3549AC	7494 614532	VERA IVANOVA	{"phone": "+70343325473"}
0005432222786	D08E79	9681 550236	LARISA NIKOLAEVA	{"email": "nikolaeval1970@postgrespro.ru", "phone": "+70587513180"}
0005432222787	707F7C	2444 204230	GALINA KUZNECOVA	{"email": "galina-kuznecova19031963@postgrespro.ru", "phone": "+70228438145"}
0005432222788	707F7C	5959 339683	VLADIMIR MOISEEV	{"email": "vladimir_moiseev-071972@postgrespro.ru", "phone": "+70337214137"}
0005432222789	707F7C	5755 613474	YULIYA FROLOVA	{"phone": "+70366114067"}
0005432222790	A07DF1	8873 711494	ANDREY YAKOVLEV	{"phone": "+70124997234"}
0005432222791	A07DF1	9601 940654	EVGENIY TARASOV	{"phone": "+70545988467"}
0005432222792	3CA6DA	2552 280739	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov_03031979@postgrespro.ru", "phone": "+70703048988"}
0005432222793	3CA6DA	8777 488103	VALENTINA ABRAMOVA	{"phone": "+70881118432"}
0005432222794	4DCFB6	9708 331735	ANNA KUZMINA	{"email": "kuzminaanna.15041969@postgrespro.ru", "phone": "+70058196064"}
0005432222795	A4FB42	0635 368202	MIKHAIL MATVEEV	{"email": "m.matveev_011985@postgrespro.ru", "phone": "+70257826972"}
0005432222796	886946	6526 091323	VASILIY KULIKOV	{"email": "v-kulikov-1964@postgrespro.ru", "phone": "+70352371298"}
0005432222797	6A515E	6253 019628	ALEKSANDR NIKITIN	{"phone": "+70468524540"}
0005432222798	5826E0	5419 962807	STANISLAV NIKITIN	{"email": "stanislav.nikitin_1970@postgrespro.ru", "phone": "+70801234955"}
0005432222799	907ADD	7116 586515	GALINA FADEEVA	{"email": "fadeeva-galina.1973@postgrespro.ru", "phone": "+70564763186"}
0005432222800	FD2E96	3957 134266	ALEKSANDRA NAZAROVA	{"email": "anazarova_121982@postgrespro.ru", "phone": "+70163944417"}
0005432222801	8CC223	5158 241605	GALINA NIKIFOROVA	{"phone": "+70521767980"}
0005432222802	497C08	4827 228498	PETR SOKOLOV	{"phone": "+70032943478"}
0005432222803	429F79	1729 980142	ANATOLIY ZAYCEV	{"email": "a.zaycev17051972@postgrespro.ru", "phone": "+70578087568"}
0005432222804	5A41BE	4642 677876	EKATERINA KOROLEVA	{"phone": "+70046143239"}
0005432222805	7BF7B3	8617 849096	DMITRIY BELOV	{"phone": "+70325710339"}
0005432222806	962D18	7390 721368	RAISA GRISHINA	{"email": "r-grishina.1963@postgrespro.ru", "phone": "+70611438790"}
0005432222807	9882D2	3839 542073	SVETLANA NAZAROVA	{"email": "svetlana_nazarova.011971@postgrespro.ru", "phone": "+70692698595"}
0005432222808	58C1AE	1532 512196	ELENA NAZAROVA	{"phone": "+70318850019"}
0005432222809	6EFD73	8708 443680	ANATOLIY EGOROV	{"phone": "+70074861179"}
0005432222810	C25844	2428 415809	NATALYA NIKITINA	{"email": "natalya_nikitina-051989@postgrespro.ru", "phone": "+70878315313"}
0005432222811	C25844	9653 231170	TAMARA SIDOROVA	{"email": "t.sidorova-081965@postgrespro.ru", "phone": "+70429240052"}
0005432222812	191EDB	4683 957951	DANIIL SOROKIN	{"phone": "+70371891158"}
0005432222813	191EDB	0473 399709	DMITRIY SEMENOV	{"email": "d-semenov-01081957@postgrespro.ru", "phone": "+70848849216"}
0005432222814	697D5F	5175 760819	EVGENIY ANTONOV	{"phone": "+70255069963"}
0005432222815	697D5F	7592 036642	VALERIY ZHURAVLEV	{"phone": "+70260595091"}
0005432222816	683AE6	0277 483288	TATYANA RYABOVA	{"email": "ryabova-tatyana_1964@postgrespro.ru", "phone": "+70665017149"}
0005432222817	2B1727	6907 716643	GENNADIY BELOV	{"email": "g.belov-121967@postgrespro.ru", "phone": "+70879277626"}
0005432222818	ED5151	6782 186125	LYUDMILA NESTEROVA	{"email": "nesterova.lyudmila.061975@postgrespro.ru", "phone": "+70152366858"}
0005432222819	ED5151	9682 926322	EGOR SOLOVEV	{"email": "solovev-e_12021978@postgrespro.ru", "phone": "+70239966562"}
0005432222820	ED5151	7157 391121	SERGEY CHERNOV	{"phone": "+70719758783"}
0005432222821	AE8418	1530 640149	LEONID FILIPPOV	{"email": "leonidfilippov.031968@postgrespro.ru", "phone": "+70862282483"}
0005432222822	6AD576	9868 397470	VLADIMIR ALEKSANDROV	{"phone": "+70864719815"}
0005432222823	4DB09E	7189 220051	KSENIYA ANTONOVA	{"phone": "+70426172382"}
0005432222824	4DB09E	6020 637828	NIKITA VOLKOV	{"email": "volkov-n.22061980@postgrespro.ru", "phone": "+70283990280"}
0005432222825	5FB771	3171 483959	MATVEY GERASIMOV	{"email": "gerasimov.m.1975@postgrespro.ru", "phone": "+70215280080"}
0005432222826	5FB771	1945 545784	TATYANA KOZLOVA	{"email": "kozlovat.051974@postgrespro.ru", "phone": "+70942624373"}
0005432222827	B31F8A	4184 231533	ALEKSANDR PETROV	{"phone": "+70912049459"}
0005432222828	C980E2	1777 949041	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-mikhail_21071971@postgrespro.ru", "phone": "+70734907166"}
0005432222829	C980E2	5044 994003	LARISA NIKITINA	{"email": "nikitina.l.101961@postgrespro.ru", "phone": "+70282837523"}
0005432222830	2BD77D	8869 955453	VALENTINA GUSEVA	{"email": "guseva.valentina101966@postgrespro.ru", "phone": "+70774956910"}
0005432222831	2BD77D	2141 200122	ZINAIDA POPOVA	{"phone": "+70694511151"}
0005432222832	F093F6	3497 683395	TATYANA TIKHONOVA	{"email": "tikhonova-t011975@postgrespro.ru", "phone": "+70491231960"}
0005432222833	4B9A65	7648 461212	ZINAIDA ARKHIPOVA	{"phone": "+70449414228"}
0005432222834	221F77	9520 355715	ALEKSANDR KAZAKOV	{"email": "a_kazakov-081962@postgrespro.ru", "phone": "+70003937222"}
0005432222835	221F77	0730 755439	VLADIMIR BARANOV	{"phone": "+70415742897"}
0005432222836	C2F2AE	8152 344139	ALEKSANDR BORISOV	{"phone": "+70785943243"}
0005432222837	E989B1	5511 726700	EGOR MOROZOV	{"phone": "+70254846885"}
0005432222838	DAC366	2428 150625	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir-31121975@postgrespro.ru", "phone": "+70418134136"}
0005432222839	BAF37D	2099 011268	ALEKSANDR BARANOV	{"email": "baranov_a09121967@postgrespro.ru", "phone": "+70308422088"}
0005432222840	D8D62F	0944 453631	VLADIMIR GUSEV	{"email": "vgusev1971@postgrespro.ru", "phone": "+70211574349"}
0005432222841	3A1E98	1163 201121	ALEKSEY GUSEV	{"phone": "+70990302895"}
0005432222842	7F7F2D	6845 607152	DENIS KUZNECOV	{"email": "denis_kuznecov_051969@postgrespro.ru", "phone": "+70329734174"}
0005432222843	7F7F2D	7691 235822	VIKTOR MOISEEV	{"phone": "+70964287097"}
0005432222844	2C68FC	5897 302148	SERGEY SERGEEV	{"email": "sergey.sergeev05071984@postgrespro.ru", "phone": "+70514450220"}
0005432222845	2C68FC	4941 312870	YURIY GERASIMOV	{"phone": "+70680219325"}
0005432222846	F20954	8625 014749	IGOR SIDOROV	{"email": "sidorovigor.081975@postgrespro.ru", "phone": "+70391108387"}
0005432222847	F20954	8082 634318	VALENTINA SMIRNOVA	{"email": "smirnova.v041969@postgrespro.ru", "phone": "+70696132220"}
0005432222848	D71569	0534 423148	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaanastasiya-30121982@postgrespro.ru", "phone": "+70472753046"}
0005432222849	0B10E1	2121 389499	PLATON ROMANOV	{"email": "platon.romanov-051980@postgrespro.ru", "phone": "+70288163345"}
0005432222850	D3FD7D	7453 923027	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov-051985@postgrespro.ru", "phone": "+70862167460"}
0005432222851	EE2015	2356 596905	GLEB ANTONOV	{"phone": "+70383302479"}
0005432222852	0F3CFB	3362 251957	ANASTASIYA MEDVEDEVA	{"phone": "+70427856755"}
0005432222853	FD221C	5525 847699	EVGENIY MOISEEV	{"phone": "+70389961593"}
0005432222854	FD221C	5943 219621	PAVEL ABRAMOV	{"phone": "+70986709061"}
0005432222855	62E0E8	4706 006928	LYUDMILA ROMANOVA	{"email": "romanova.lyudmila-111978@postgrespro.ru", "phone": "+70679700479"}
0005432222856	62E0E8	7059 468962	VIKTOR ANTONOV	{"phone": "+70200789937"}
0005432222857	9C877D	9265 251938	GALINA KONOVALOVA	{"email": "galina_konovalova_02111973@postgrespro.ru", "phone": "+70560364392"}
0005432222858	9C877D	7910 596830	ELENA PAVLOVA	{"email": "e-pavlova14031976@postgrespro.ru", "phone": "+70612532494"}
0005432222860	203B53	8154 965591	MIKHAIL KUZNECOV	{"email": "kuznecovm1972@postgrespro.ru", "phone": "+70119322501"}
0005432222861	15E12E	7846 116315	GENNADIY MIKHAYLOV	{"phone": "+70175469789"}
0005432222862	ED298F	1688 084006	EVGENIY KOZLOV	{"phone": "+70432882949"}
0005432222863	E67595	9215 363257	ALEKSANDR ISAEV	{"phone": "+70229762366"}
0005432222864	EB28A0	0656 872603	NATALYA YAKOVLEVA	{"phone": "+70089514737"}
0005432222865	EB28A0	2592 100625	ANTONINA IVANOVA	{"phone": "+70936513440"}
0005432222866	5036B3	9100 575690	GEORGIY MARTYNOV	{"phone": "+70278890732"}
0005432222867	4CC6AB	4840 761415	GALINA GRISHINA	{"email": "galinagrishina10101976@postgrespro.ru", "phone": "+70347027671"}
0005432222868	6CD81A	1252 588294	DANILA FEDOTOV	{"email": "fedotov-danila_1968@postgrespro.ru", "phone": "+70681870107"}
0005432222869	C8BAB4	0775 172418	FANIS DAVYDOV	{"email": "fanisdavydov_111976@postgrespro.ru", "phone": "+70683548191"}
0005432222870	C8BAB4	6212 965624	ALEKSANDR MELNIKOV	{"phone": "+70101637585"}
0005432222871	50084D	6164 218035	IVAN KUZNECOV	{"phone": "+70867920757"}
0005432222872	051051	0231 167758	NIKOLAY FOMIN	{"email": "nikolayfomin.041969@postgrespro.ru", "phone": "+70548984625"}
0005432222873	7025BC	8521 114847	NIKOLAY NAZAROV	{"email": "nikolay.nazarov-061976@postgrespro.ru", "phone": "+70263457726"}
0005432222874	5C2160	7495 736353	VITALIY VASILEV	{"email": "vasilev_v-06031974@postgrespro.ru", "phone": "+70717748001"}
0005432222875	284B15	9258 368240	ELENA NIKOLAEVA	{"email": "nikolaeva-elena.01071972@postgrespro.ru", "phone": "+70607680322"}
0005432222876	284B15	0799 299045	ALEKSANDR TIKHONOV	{"phone": "+70357309126"}
0005432222877	9A5EB5	2769 097465	IRINA FROLOVA	{"phone": "+70831168377"}
0005432222878	7E30AB	0177 342417	LYUBOV POPOVA	{"email": "l-popova.051965@postgrespro.ru", "phone": "+70992937588"}
0005432222879	B0D2B0	4020 429511	SERGEY NIKOLAEV	{"email": "snikolaev_1977@postgrespro.ru", "phone": "+70700860171"}
0005432222880	B0D2B0	9951 743712	VLADIMIR MOROZOV	{"phone": "+70727893208"}
0005432222881	D896B5	4552 916071	OLGA VOROBEVA	{"email": "o.vorobeva15091975@postgrespro.ru", "phone": "+70339605349"}
0005432222882	F40666	0289 357001	SERGEY SMIRNOV	{"phone": "+70545554507"}
0005432222883	2842FF	2185 327411	VALENTINA EGOROVA	{"email": "valentina_egorova_05061974@postgrespro.ru", "phone": "+70271444802"}
0005432222884	2842FF	9920 000280	GALINA VASILEVA	{"email": "gvasileva.12111963@postgrespro.ru", "phone": "+70244243021"}
0005432222885	56283F	2977 034220	VYACHESLAV MEDVEDEV	{"email": "medvedev_vyacheslav.121974@postgrespro.ru", "phone": "+70815729277"}
0005432222886	CE5EE6	9637 814112	OLEG ALEKSEEV	{"email": "oleg.alekseev.1974@postgrespro.ru", "phone": "+70825883059"}
0005432222887	CE5EE6	0661 058996	VENIAMIN SOKOLOV	{"phone": "+70768483268"}
0005432222888	0D7AEA	0170 985741	GENNADIY SMIRNOV	{"phone": "+70441672888"}
0005432222889	0D7AEA	0744 407829	RAISA DMITRIEVA	{"email": "raisa.dmitrieva.21011985@postgrespro.ru", "phone": "+70373910322"}
0005432222890	FD4C82	9388 292069	DINARA MOROZOVA	{"phone": "+70128300320"}
0005432222891	6A566D	7665 492843	NIKOLAY PETROV	{"phone": "+70650534681"}
0005432222892	D4D6A6	3496 975856	GALINA ALEKSEEVA	{"phone": "+70100814363"}
0005432222893	3991D3	8697 026984	SVETLANA NIKIFOROVA	{"email": "s.nikiforova04101961@postgrespro.ru", "phone": "+70088346258"}
0005432222894	232687	6175 713980	VYACHESLAV IVANOV	{"phone": "+70107544772"}
0005432222895	A6CCB0	3126 889070	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr_121968@postgrespro.ru", "phone": "+70842460269"}
0005432222896	0BF31D	6587 257420	MARIYA GUSEVA	{"phone": "+70535981491"}
0005432222897	0BF31D	1410 355320	DENIS ALEKSANDROV	{"phone": "+70519588848"}
0005432222898	072A2D	8525 802978	ROZA AKIMOVA	{"phone": "+70442021738"}
0005432222899	CECFBB	6613 418816	ELENA ARKHIPOVA	{"phone": "+70764496474"}
0005432222900	CECFBB	2800 289115	LARISA AFANASEVA	{"phone": "+70147435134"}
0005432222901	D00FC7	8471 955735	PAVEL GAVRILOV	{"phone": "+70497646482"}
0005432222902	F2EE4E	2458 372731	NIKITA SMIRNOV	{"email": "nikitasmirnov-1974@postgrespro.ru", "phone": "+70319145391"}
0005432222903	79225C	0132 056320	NINA ALEKSEEVA	{"email": "alekseeva_nina_091976@postgrespro.ru", "phone": "+70365400460"}
0005432222904	31AEFB	9900 451221	DMITRIY ALEKSANDROV	{"email": "aleksandrov.d-1974@postgrespro.ru", "phone": "+70209299960"}
0005432222905	31AEFB	9460 450448	EKATERINA KOROLEVA	{"phone": "+70340583328"}
0005432222906	97F7B0	3840 746326	VERA GUSEVA	{"email": "gusevavera-031974@postgrespro.ru", "phone": "+70292204452"}
0005432222907	2C3EDF	5064 391832	MARIYA IVANOVA	{"email": "m.ivanova.071972@postgrespro.ru", "phone": "+70310283912"}
0005432222908	2C3EDF	9881 279011	DENIS SEMENOV	{"email": "semenov.denis23051959@postgrespro.ru", "phone": "+70895439581"}
0005432222909	536638	1269 592259	GULNAZ AKIMOVA	{"email": "gulnaz-akimova_021980@postgrespro.ru", "phone": "+70083265257"}
0005432222910	2A5181	2096 490175	KIRILL BORISOV	{"phone": "+70500289386"}
0005432222911	ADF67F	5544 155376	MIKHAIL TIMOFEEV	{"phone": "+70052190905"}
0005432222912	E32AEA	2849 726265	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir1984@postgrespro.ru", "phone": "+70274431719"}
0005432222913	EAC472	2698 776192	ALEKSANDR ABRAMOV	{"email": "abramova-1973@postgrespro.ru", "phone": "+70834931025"}
0005432222914	EAC472	7331 342952	TATYANA VLASOVA	{"email": "t.vlasova1975@postgrespro.ru", "phone": "+70052344776"}
0005432222915	267656	8215 477316	OLEG ILIN	{"email": "ilin-o.081976@postgrespro.ru", "phone": "+70201652993"}
0005432222916	50E938	3782 497973	NADEZHDA NIKIFOROVA	{"email": "nadezhda_nikiforova-1976@postgrespro.ru", "phone": "+70531702062"}
0005432222917	497C05	0480 073094	SERGEY SERGEEV	{"email": "sergeev_sergey_091969@postgrespro.ru", "phone": "+70136416238"}
0005432222918	497C05	2190 986067	FELIKS MOISEEV	{"email": "feliks-moiseev.17121968@postgrespro.ru", "phone": "+70605413861"}
0005432226103	708BC2	1208 132220	RAISA KUZMINA	{"phone": "+70558549880"}
0005432222919	A094FB	6593 347109	MARIYA ZAYCEVA	{"email": "zayceva-mariya_28051947@postgrespro.ru", "phone": "+70936553040"}
0005432222920	A094FB	2637 990703	MARIYA ISAEVA	{"email": "mariya-isaeva.041986@postgrespro.ru", "phone": "+70958280011"}
0005432222921	EC6FF2	4852 036641	ANATOLIY ZAKHAROV	{"email": "a_zakharov121971@postgrespro.ru", "phone": "+70373259909"}
0005432222922	D915BB	9136 847080	RAISA FADEEVA	{"phone": "+70581446060"}
0005432222923	8B0B82	7688 110680	ILYA ALEKSEEV	{"email": "ilya_alekseev_1982@postgrespro.ru", "phone": "+70312980982"}
0005432222924	79C697	4459 004518	ALEVTINA IVANOVA	{"email": "alevtina-ivanova-1967@postgrespro.ru", "phone": "+70698512267"}
0005432222925	F02B7F	5043 109949	VYACHESLAV GERASIMOV	{"email": "gerasimovvyacheslav1975@postgrespro.ru", "phone": "+70346273762"}
0005432222926	DA6145	8225 260682	SERGEY IVANOV	{"email": "sergey.ivanov_1972@postgrespro.ru", "phone": "+70815126870"}
0005432222927	33952D	3156 958349	MARINA ROMANOVA	{"phone": "+70456759285"}
0005432222928	C545E5	8441 241779	TAMARA KALININA	{"phone": "+70271329297"}
0005432222929	C545E5	9875 238101	ELENA POPOVA	{"email": "elenapopova_19121973@postgrespro.ru", "phone": "+70009790456"}
0005432222930	74687A	7054 419249	IGOR YAKOVLEV	{"email": "yakovlevi.1968@postgrespro.ru", "phone": "+70058102894"}
0005432222931	E4FE3B	7897 914767	ANATOLIY PAVLOV	{"phone": "+70923872622"}
0005432222932	357084	7112 949262	ZINAIDA FOMINA	{"email": "zinaida.fomina.061979@postgrespro.ru", "phone": "+70056923554"}
0005432222933	357084	9649 099053	ALLA NIKIFOROVA	{"email": "nikiforovaalla.1974@postgrespro.ru", "phone": "+70719055514"}
0005432222934	F249A5	3500 837445	SERGEY KISELEV	{"phone": "+70838670242"}
0005432222935	F249A5	4105 073286	VLADIMIR MIRONOV	{"email": "vladimirmironov_18011969@postgrespro.ru", "phone": "+70749288083"}
0005432222936	F98839	9572 330872	DMITRIY BELOV	{"phone": "+70447952597"}
0005432222937	6484D7	2624 808000	VIKTOR KUDRYASHOV	{"email": "viktor_kudryashov-111969@postgrespro.ru", "phone": "+70207128923"}
0005432222938	6484D7	1958 907202	LYUBOV PETROVA	{"phone": "+70299897245"}
0005432222939	EC731A	8490 589170	MARIYA NIKITINA	{"email": "nikitina_mariya-1968@postgrespro.ru", "phone": "+70067788662"}
0005432225946	983D73	8884 100210	VYACHESLAV NIKITIN	{"email": "vyacheslavnikitin-1960@postgrespro.ru", "phone": "+70752914724"}
0005432225947	983D73	5459 173379	VYACHESLAV MELNIKOV	{"email": "melnikov_v_24081977@postgrespro.ru", "phone": "+70544201883"}
0005432225948	89CD5A	5462 044249	OLEG NAZAROV	{"email": "oleg.nazarov-031970@postgrespro.ru", "phone": "+70152288865"}
0005432225949	89CD5A	1401 340842	ZOYA KUZMINA	{"email": "z_kuzmina.061975@postgrespro.ru", "phone": "+70796448892"}
0005432225950	FB4900	9329 217295	ELENA BORISOVA	{"phone": "+70670848137"}
0005432225951	608CE0	6289 160855	ALEKSEY GERASIMOV	{"email": "aleksey-gerasimov_18041967@postgrespro.ru", "phone": "+70839825627"}
0005432225952	608CE0	2779 675985	RINAT POPOV	{"email": "rinat.popov_011969@postgrespro.ru", "phone": "+70451318326"}
0005432225953	1D1613	0526 030814	SERGEY PETROV	{"phone": "+70945029943"}
0005432225954	021D1F	6681 502773	GALINA DANILOVA	{"email": "g_danilova_30101978@postgrespro.ru", "phone": "+70375390772"}
0005432225955	92267A	8008 949274	ALEKSANDR KUZNECOV	{"phone": "+70059235187"}
0005432225956	92267A	3150 974045	PETR NAUMOV	{"phone": "+70664967739"}
0005432225957	CD173E	4160 276722	NIKITA VASILEV	{"email": "nikitavasilev-041969@postgrespro.ru", "phone": "+70475444837"}
0005432225958	F09CF4	1415 641970	GENNADIY SHEVCHENKO	{"phone": "+70745227743"}
0005432225959	F09CF4	6218 957315	NINA ISAEVA	{"phone": "+70299991253"}
0005432225960	0A97A7	7025 470825	SERGEY MOROZOV	{"email": "s.morozov-061965@postgrespro.ru", "phone": "+70970204500"}
0005432225961	DEE88E	2213 484390	DMITRIY POPOV	{"email": "popov_dmitriy-1960@postgrespro.ru", "phone": "+70307766254"}
0005432225962	CCF0D1	4958 587538	EVGENIYA OSIPOVA	{"phone": "+70881657593"}
0005432225963	120B30	0525 263613	ALEKSANDR KOZLOV	{"phone": "+70634762264"}
0005432225964	2033B1	8109 576728	LILIYA ROMANOVA	{"email": "l_romanova.14031980@postgrespro.ru", "phone": "+70833637707"}
0005432225965	2033B1	0140 242005	NATALYA KONDRATEVA	{"phone": "+70463197353"}
0005432225966	E2E643	4582 846195	MARIYA ZHUKOVA	{"email": "m-zhukova31081973@postgrespro.ru", "phone": "+70784691153"}
0005432225967	E2E643	6087 869169	VALENTINA SOLOVEVA	{"phone": "+70649096719"}
0005432225968	FB5896	8717 193065	GALINA ZAYCEVA	{"email": "zaycevag1974@postgrespro.ru", "phone": "+70971341795"}
0005432225969	2F6D29	0654 785278	VLADIMIR MOROZOV	{"phone": "+70774990069"}
0005432225970	2F6D29	6361 888340	ELENA GERASIMOVA	{"email": "elena.gerasimova.1967@postgrespro.ru", "phone": "+70865407376"}
0005432225971	4C5853	5631 381431	OKSANA NIKOLAEVA	{"phone": "+70860240406"}
0005432225972	6189BC	3724 673652	MARINA KUZNECOVA	{"email": "kuznecova-marina-1975@postgrespro.ru", "phone": "+70516355150"}
0005432225973	6189BC	8305 389734	MARIYA ALEKSEEVA	{"phone": "+70346349862"}
0005432225974	6F9031	7951 923289	GENNADIY STEPANOV	{"email": "stepanov.gennadiy011977@postgrespro.ru", "phone": "+70664800951"}
0005432225975	8E4A33	6139 366379	GRIGORIY ORLOV	{"phone": "+70073542365"}
0005432225976	AE3570	9136 003752	NINA BORISOVA	{"email": "borisova_nina-11011971@postgrespro.ru", "phone": "+70363519561"}
0005432225977	76AE32	7339 515947	YURIY STEPANOV	{"phone": "+70421309945"}
0005432225978	45E506	0667 105810	TAMARA ALEKSEEVA	{"phone": "+70403937780"}
0005432225979	45E506	6203 095277	IVAN ANTONOV	{"email": "antonov.i-1978@postgrespro.ru", "phone": "+70563682666"}
0005432225980	45E506	7832 160902	ANDREY NIKOLAEV	{"email": "nikolaev_andrey_07061962@postgrespro.ru", "phone": "+70801328352"}
0005432225981	9F2898	6816 724007	OLEG KULIKOV	{"phone": "+70108944727"}
0005432225982	9050CB	5905 570587	NIKOLAY KUZNECOV	{"phone": "+70890012472"}
0005432225983	B5A031	1058 930409	EGOR ALEKSEEV	{"email": "alekseev_egor_04111971@postgrespro.ru", "phone": "+70115201403"}
0005432225984	5568CF	9287 224043	SVETLANA MEDVEDEVA	{"email": "svetlana.medvedeva-03061970@postgrespro.ru", "phone": "+70294493321"}
0005432225985	5568CF	2326 782491	OLGA GERASIMOVA	{"email": "ogerasimova1977@postgrespro.ru", "phone": "+70799373761"}
0005432225986	5568CF	4744 895777	TIMOFEY FEDOTOV	{"email": "t-fedotov_081973@postgrespro.ru", "phone": "+70963430045"}
0005432225987	C5AAE2	7864 039277	SERGEY VASILEV	{"email": "s-vasilev1954@postgrespro.ru", "phone": "+70806157887"}
0005432225988	5F914F	8252 150868	EVGENIY CHERNOV	{"email": "e_chernov_1962@postgrespro.ru", "phone": "+70675220049"}
0005432225989	97C181	7429 345536	MARAT ZHURAVLEV	{"phone": "+70558722666"}
0005432225990	97C181	6119 445344	ARKADIY SCHERBAKOV	{"phone": "+70966851588"}
0005432225991	B6DD50	4367 171034	EVGENIY BORISOV	{"email": "borisov-e-101966@postgrespro.ru", "phone": "+70477953676"}
0005432225992	2B9901	9455 160291	NIKITA SEMENOV	{"email": "n_semenov071965@postgrespro.ru", "phone": "+70638925956"}
0005432225993	2AC0E8	1351 452317	EKATERINA KUZNECOVA	{"email": "kuznecova.ekaterina-1978@postgrespro.ru", "phone": "+70099389298"}
0005432225994	96EEA2	8862 157675	VASILIY PETROV	{"email": "petrov_vasiliy-11021981@postgrespro.ru", "phone": "+70031945086"}
0005432225995	BD8AF4	0973 693422	LARISA MIKHAYLOVA	{"phone": "+70003641982"}
0005432225996	A82944	3719 952870	KONSTANTIN DENISOV	{"email": "denisov.konstantin13031977@postgrespro.ru", "phone": "+70075168882"}
0005432225997	FD4650	4412 504947	ANDREY PETROV	{"phone": "+70438297116"}
0005432225998	64B900	2971 893876	NATALYA TIMOFEEVA	{"phone": "+70466401884"}
0005432225999	C563D6	6633 803899	DMITRIY SIDOROV	{"email": "sidorov.dmitriy05031965@postgrespro.ru", "phone": "+70655785094"}
0005432226000	3C2B05	9089 334155	SERGEY VOLKOV	{"phone": "+70122402910"}
0005432226001	8537C9	7749 475377	ANATOLIY MATVEEV	{"phone": "+70950748966"}
0005432226002	7E3A15	6423 325173	ALEKSEY NAZAROV	{"email": "nazarov.aleksey-1967@postgrespro.ru", "phone": "+70216464021"}
0005432226003	110796	3420 887542	EKATERINA IVANOVA	{"email": "ivanova-ekaterina-25081988@postgrespro.ru", "phone": "+70191901733"}
0005432226004	5F4C17	0101 542584	TATYANA KOROLEVA	{"email": "tkoroleva-051967@postgrespro.ru", "phone": "+70901529110"}
0005432226005	A8F074	7967 068401	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin.26111972@postgrespro.ru", "phone": "+70720963698"}
0005432226006	A8F074	5526 899548	DMITRIY DMITRIEV	{"phone": "+70884978850"}
0005432226007	0187AB	8395 659198	ALEKSEY KUZNECOV	{"email": "kuznecov_a19011970@postgrespro.ru", "phone": "+70054409697"}
0005432226008	03A3EA	1162 982839	MAKSIM GRIGOREV	{"email": "m_grigorev-1969@postgrespro.ru", "phone": "+70487633248"}
0005432226009	97C602	4265 435629	ALEKSANDR SAVELEV	{"phone": "+70514506772"}
0005432226010	34173B	5529 327099	TATYANA MALYSHEVA	{"email": "tmalysheva_1959@postgrespro.ru", "phone": "+70561768087"}
0005432226011	34173B	0530 108113	ALEKSANDR TIMOFEEV	{"email": "timofeev.a22051966@postgrespro.ru", "phone": "+70522578310"}
0005432226012	1FF58E	0457 861347	RAISA VASILEVA	{"phone": "+70307637101"}
0005432226013	1FF58E	4031 511394	NIKOLAY KUZNECOV	{"phone": "+70722870312"}
0005432226014	FF6C62	7716 422951	EKATERINA NAUMOVA	{"phone": "+70717294727"}
0005432226015	2C80A2	3863 233547	ARINA NOVIKOVA	{"email": "novikova.arina_011961@postgrespro.ru", "phone": "+70183799029"}
0005432226016	0DE706	4856 183507	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov.061976@postgrespro.ru", "phone": "+70714304145"}
0005432226017	82712F	6875 757809	MAKSIM KRASNOV	{"email": "m.krasnov-051963@postgrespro.ru", "phone": "+70375520705"}
0005432226018	82712F	9847 506231	OLGA SEMENOVA	{"phone": "+70593126016"}
0005432226019	B9220A	3345 113404	MARIYA KUZNECOVA	{"email": "kuznecova-mariya.111972@postgrespro.ru", "phone": "+70568947098"}
0005432226020	B9220A	9809 721048	ARTEM MEDVEDEV	{"phone": "+70914001432"}
0005432226021	E35225	1773 770985	NIKOLAY MIKHAYLOV	{"phone": "+70808453871"}
0005432226022	F839C3	5250 676122	NIKOLAY SAVELEV	{"phone": "+70411655013"}
0005432226023	53F876	1518 874716	NINA KRASNOVA	{"phone": "+70884332590"}
0005432226024	53F876	8650 733956	MIKHAIL MARTYNOV	{"email": "martynov.mikhail_091973@postgrespro.ru", "phone": "+70552594099"}
0005432226025	E321AA	6094 828953	SERGEY KOROLEV	{"email": "korolev_sergey-09121974@postgrespro.ru", "phone": "+70393540054"}
0005432226026	E321AA	7156 432605	SNEZHANA ZAYCEVA	{"email": "s_zayceva15041971@postgrespro.ru", "phone": "+70648323301"}
0005432226027	E321AA	7175 738646	KONSTANTIN SMIRNOV	{"email": "smirnovkonstantin-04021961@postgrespro.ru", "phone": "+70753808419"}
0005432226028	F05493	3737 711788	OLGA DENISOVA	{"email": "o_denisova.071975@postgrespro.ru", "phone": "+70994920738"}
0005432226029	F05493	8969 126882	RENAT SIDOROV	{"email": "sidorovrenat1975@postgrespro.ru", "phone": "+70407857371"}
0005432226030	B6FDFA	1949 267038	YULIYA BORISOVA	{"email": "y-borisova12111984@postgrespro.ru", "phone": "+70893811448"}
0005432226031	03BDB0	6964 408091	DMITRIY KRASNOV	{"email": "krasnov_d-091967@postgrespro.ru", "phone": "+70791249392"}
0005432226032	03BDB0	9081 622407	VLADIMIR SCHERBAKOV	{"phone": "+70936905764"}
0005432226033	683990	8246 815792	SVETLANA KARPOVA	{"phone": "+70513567122"}
0005432226034	4F98B2	9511 115098	VLADIMIR DAVYDOV	{"email": "davydovvladimir-02091975@postgrespro.ru", "phone": "+70494004948"}
0005432226035	079836	1593 352235	ELENA MIKHAYLOVA	{"email": "elena.mikhaylova1971@postgrespro.ru", "phone": "+70991204188"}
0005432226036	409AF8	3053 605506	VASILIY DMITRIEV	{"email": "vasiliydmitriev_1977@postgrespro.ru", "phone": "+70671568391"}
0005432226037	BA35B3	8001 918832	OLEG NAZAROV	{"email": "olegnazarov.26011970@postgrespro.ru", "phone": "+70974983277"}
0005432226038	F2C03E	6544 024806	MARIYA ANTONOVA	{"phone": "+70712620179"}
0005432226039	1D9E3B	8953 147905	MARIYA MAKSIMOVA	{"phone": "+70292910952"}
0005432226040	41DADF	8540 562735	POLINA LOGINOVA	{"email": "loginova.polina_1976@postgrespro.ru", "phone": "+70604467991"}
0005432226041	E00C2E	1056 642564	RAISA NIKOLAEVA	{"email": "nikolaeva.raisa.111960@postgrespro.ru", "phone": "+70306540929"}
0005432226042	1B9128	3775 101191	VERA POPOVA	{"email": "popovavera.1970@postgrespro.ru", "phone": "+70249067520"}
0005432226043	1B9128	6233 603266	NIKOLAY IVANOV	{"phone": "+70499762621"}
0005432226044	8E401A	3829 847767	IVAN MIKHAYLOV	{"phone": "+70646016143"}
0005432226045	D21271	0357 341121	ALEKSEY SAVELEV	{"email": "a.savelev.1973@postgrespro.ru", "phone": "+70288808279"}
0005432226046	9BB4B1	7843 477239	SERGEY KAZAKOV	{"email": "sergey.kazakov18111968@postgrespro.ru", "phone": "+70883973108"}
0005432226047	2C8AA4	7296 859644	VLADISLAV TARASOV	{"email": "tarasov_v30031966@postgrespro.ru", "phone": "+70742129334"}
0005432226048	2C8AA4	0118 228826	GALINA ALEKSEEVA	{"email": "alekseevagalina.20121973@postgrespro.ru", "phone": "+70445196397"}
0005432226049	4040B8	5011 460711	ANASTASIYA MIKHAYLOVA	{"phone": "+70301311611"}
0005432226050	A97D69	7890 374339	SERGEY MEDVEDEV	{"phone": "+70759384927"}
0005432226051	BEA487	3729 133916	VYACHESLAV DENISOV	{"phone": "+70221626476"}
0005432226052	BEA487	6797 231979	YULIYA DENISOVA	{"phone": "+70736927052"}
0005432226053	2BE842	2360 655394	LYUDMILA PAVLOVA	{"phone": "+70273361186"}
0005432226054	24FFA5	6276 306586	RINAT SOKOLOV	{"phone": "+70114316733"}
0005432226055	24FFA5	3586 953308	MARINA FILATOVA	{"phone": "+70790029060"}
0005432226056	24FFA5	1010 877339	GRIGORIY NAZAROV	{"email": "gnazarov-30061975@postgrespro.ru", "phone": "+70233179088"}
0005432226057	FF1366	5874 769957	ALENA ZHUKOVA	{"phone": "+70642598447"}
0005432226058	35D786	1410 258756	SVETLANA IVANOVA	{"email": "s-ivanova-1970@postgrespro.ru", "phone": "+70369289496"}
0005432226059	35D786	4076 384804	ALEKSANDRA POPOVA	{"phone": "+70136983717"}
0005432226060	6B32D3	9266 183655	ALEKSANDRA SEMENOVA	{"email": "semenovaaleksandra-091972@postgrespro.ru", "phone": "+70178498437"}
0005432226061	A7B01E	3662 861016	OLGA MATVEEVA	{"email": "o-matveeva1965@postgrespro.ru", "phone": "+70660960303"}
0005432226062	BBB849	4732 136016	GUZEL NOVIKOVA	{"phone": "+70201947231"}
0005432226063	743698	6883 025266	VIKTOR SCHERBAKOV	{"phone": "+70720176645"}
0005432226064	743698	3408 932355	VYACHESLAV STEPANOV	{"phone": "+70543668560"}
0005432226065	7F0982	6889 877306	MARINA SIDOROVA	{"email": "m_sidorova-011977@postgrespro.ru", "phone": "+70498014503"}
0005432226066	7F0982	8369 797024	GENNADIY MELNIKOV	{"phone": "+70241558218"}
0005432226067	CBC178	6222 411625	SERGEY GUSEV	{"email": "gusevs-071973@postgrespro.ru", "phone": "+70105314757"}
0005432226068	B75763	8430 676753	SERGEY MIRONOV	{"email": "mironov_sergey.051967@postgrespro.ru", "phone": "+70122171608"}
0005432226069	48C058	9961 966987	ELENA DMITRIEVA	{"phone": "+70349832091"}
0005432226070	786577	5900 682834	ANNA EFREMOVA	{"email": "anna.efremova-1981@postgrespro.ru", "phone": "+70090113580"}
0005432226071	CF8A1E	5337 003073	ELENA MARTYNOVA	{"phone": "+70013725472"}
0005432226072	722BF2	7965 752884	GALINA BORISOVA	{"email": "borisova_galina.1961@postgrespro.ru", "phone": "+70746493616"}
0005432226073	015EC1	2887 433956	VALERIYA KOLESNIKOVA	{"phone": "+70283885592"}
0005432226074	FEEFF6	8548 262227	ILGIZ BELOV	{"phone": "+70035123230"}
0005432226075	FEEFF6	3678 242839	MAKSIM NIKOLAEV	{"phone": "+70048340171"}
0005432226076	393623	9725 047606	PELAGEYA BELOVA	{"email": "belovap-05061980@postgrespro.ru", "phone": "+70753342503"}
0005432226077	393623	6508 776871	EKATERINA ORLOVA	{"phone": "+70022958354"}
0005432226078	71E3F6	4478 189311	DMITRIY SAVELEV	{"email": "dsavelev_25111971@postgrespro.ru", "phone": "+70824812447"}
0005432226079	325E65	0068 475408	VIKTOR ABRAMOV	{"phone": "+70458324906"}
0005432226080	1E6B7F	4172 542216	ALEKSANDR ABRAMOV	{"phone": "+70954386468"}
0005432226081	868FAE	4987 909246	MARAT NOVIKOV	{"email": "novikov.marat_121969@postgrespro.ru", "phone": "+70040507293"}
0005432226082	BD8BE2	6214 854539	NIKOLAY ZHURAVLEV	{"phone": "+70239737428"}
0005432226083	90EAE1	9917 283316	ANASTASIYA POPOVA	{"phone": "+70729279454"}
0005432226084	98A9F6	1114 110755	NINA ILINA	{"phone": "+70465465681"}
0005432226085	3EFAF3	7520 361472	VLADIMIR MAKAROV	{"email": "vladimirmakarov_071983@postgrespro.ru", "phone": "+70546835299"}
0005432226086	3EFAF3	7134 524936	EKATERINA RODIONOVA	{"email": "e-rodionova_011966@postgrespro.ru", "phone": "+70077769616"}
0005432226087	3CA515	3198 907888	NADEZHDA KUZNECOVA	{"phone": "+70851947363"}
0005432226088	57A729	7145 354258	VITALIY GERASIMOV	{"phone": "+70102564381"}
0005432226089	4D6897	0456 913848	ALEKSEY ILIN	{"phone": "+70490768265"}
0005432226090	38EB8B	8545 556863	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova-1976@postgrespro.ru", "phone": "+70297348372"}
0005432226091	E2E536	4972 486021	ELIZAVETA KRASNOVA	{"email": "ekrasnova.031969@postgrespro.ru", "phone": "+70626650760"}
0005432226092	E2E536	4771 784713	ARTEM NIKOLAEV	{"phone": "+70935351863"}
0005432226093	E2E536	0453 228032	VIKTOR IVANOV	{"email": "ivanov-v.11051964@postgrespro.ru", "phone": "+70939612353"}
0005432226094	05847B	9952 201125	IRINA STEPANOVA	{"phone": "+70217965780"}
0005432226095	7E4F72	9662 889425	NIKOLAY BELOV	{"email": "belov-nikolay_09091971@postgrespro.ru", "phone": "+70915577815"}
0005432226096	9E5510	7204 847079	ELENA MASLOVA	{"email": "e_maslova081952@postgrespro.ru", "phone": "+70172395320"}
0005432226097	9E5510	3358 224762	ALEKSEY KOZLOV	{"phone": "+70256249010"}
0005432226098	0675B9	0768 240825	LYUDMILA LEBEDEVA	{"email": "l-lebedeva.1967@postgrespro.ru", "phone": "+70851244094"}
0005432226099	23AE18	8914 816071	ALEKSEY FOMIN	{"phone": "+70034835717"}
0005432226100	D982B0	5288 333671	GERMAN IVANOV	{"phone": "+70114797896"}
0005432226101	708BC2	3964 266545	ALEKSEY ALEKSEEV	{"phone": "+70999756226"}
0005432226102	708BC2	5486 187284	SVETLANA ARKHIPOVA	{"email": "svetlana_arkhipova_21021974@postgrespro.ru", "phone": "+70297248171"}
0005432226104	0A32C8	7741 348970	SEMEN DMITRIEV	{"email": "dmitrievsemen1972@postgrespro.ru", "phone": "+70238272504"}
0005432226105	94B654	3128 484041	YURIY KUZNECOV	{"email": "kuznecov-yuriy23021970@postgrespro.ru", "phone": "+70261454588"}
0005432226106	37B94D	3123 509892	ALEKSEY MELNIKOV	{"phone": "+70862098611"}
0005432226107	E1529E	1477 846457	YULIYA VASILEVA	{"phone": "+70703149320"}
0005432226108	E1529E	1477 602849	NIKOLAY DMITRIEV	{"phone": "+70798375101"}
0005432226109	16C9FB	3771 622532	ALEKSANDR ISAEV	{"phone": "+70318059969"}
0005432226110	7D6153	0164 683346	TIMUR MOROZOV	{"phone": "+70537552847"}
0005432226111	88E1A1	8211 338995	VYACHESLAV IVANOV	{"email": "v_ivanov-1972@postgrespro.ru", "phone": "+70190898904"}
0005432226112	3EE267	0519 484554	ALEKSEY ANDREEV	{"phone": "+70825343251"}
0005432226113	1E158A	0186 741048	NATALYA BORISOVA	{"email": "borisova_natalya_12011977@postgrespro.ru", "phone": "+70944140334"}
0005432226114	36D103	0773 230114	ALEKSEY GAVRILOV	{"email": "a.gavrilov1963@postgrespro.ru", "phone": "+70694151112"}
0005432226115	DBAD46	3065 781636	ANASTASIYA GERASIMOVA	{"email": "anastasiya-gerasimova1967@postgrespro.ru", "phone": "+70841134639"}
0005432226116	6B1B13	9732 059938	VERONIKA MOROZOVA	{"phone": "+70591561078"}
0005432226117	1EA6CC	6751 889991	TATYANA ZHUKOVA	{"email": "zhukova.t.1965@postgrespro.ru", "phone": "+70580628502"}
0005432226118	1EA6CC	7416 955724	VALENTINA STEPANOVA	{"email": "stepanova_v101971@postgrespro.ru", "phone": "+70219087829"}
0005432226119	D90CA5	3916 650533	RUSLAN SOROKIN	{"phone": "+70737879122"}
0005432226120	5375EC	9259 548006	ELENA BELYAEVA	{"email": "elena_belyaeva-02021978@postgrespro.ru", "phone": "+70381537133"}
0005432226121	5375EC	7600 041751	SERGEY VASILEV	{"email": "s-vasilev.121976@postgrespro.ru", "phone": "+70366988168"}
0005432226122	97A8EF	3098 792032	MIKHAIL KOROLEV	{"phone": "+70868363060"}
0005432226123	97A8EF	9398 506539	TATYANA KUZMINA	{"email": "kuzminat_14091968@postgrespro.ru", "phone": "+70862832103"}
0005432226124	97A8EF	7006 900290	DENIS BELOV	{"phone": "+70124259479"}
0005432226125	6F736C	3491 650790	BORIS MIRONOV	{"email": "mironov-b-051966@postgrespro.ru", "phone": "+70932450421"}
0005432226126	13FA9C	5114 183449	ANATOLIY KONOVALOV	{"email": "a-konovalov_111976@postgrespro.ru", "phone": "+70720947551"}
0005432226127	13FA9C	2498 625822	ELENA NOVIKOVA	{"phone": "+70039842112"}
0005432226128	3D743B	6433 577497	GALINA POPOVA	{"email": "gpopova.071969@postgrespro.ru", "phone": "+70488949019"}
0005432226129	A80220	6273 634140	ALEKSEY KAZAKOV	{"email": "kazakov-aleksey1966@postgrespro.ru", "phone": "+70243264126"}
0005432226130	BF7CCE	0452 857937	OLGA TIMOFEEVA	{"email": "timofeeva-o_16111976@postgrespro.ru", "phone": "+70213509587"}
0005432226131	BF7CCE	9761 833647	MIKHAIL STEPANOV	{"phone": "+70206982459"}
0005432226132	BA0F75	0903 592489	YULIYA CHERNOVA	{"phone": "+70291546597"}
0005432226133	BA0F75	5331 745361	VYACHESLAV ANDREEV	{"email": "vyacheslavandreev1985@postgrespro.ru", "phone": "+70340283021"}
0005432226134	BA0F75	6649 284495	PETR MAKSIMOV	{"phone": "+70711531128"}
0005432226135	25FF40	9016 514596	OLGA ALEKSEEVA	{"email": "alekseeva_olga.101973@postgrespro.ru", "phone": "+70842162945"}
0005432226136	87A147	9162 633722	MARINA SEMENOVA	{"phone": "+70001588309"}
0005432226137	BF0B40	0042 955861	ELENA FEDOROVA	{"email": "e-fedorova-16081976@postgrespro.ru", "phone": "+70916965599"}
0005432226138	BF0B40	9948 996434	OLGA ABRAMOVA	{"email": "abramova_o061968@postgrespro.ru", "phone": "+70790398906"}
0005432226139	87AAAF	4975 609722	IGOR EGOROV	{"phone": "+70602254325"}
0005432226140	9D3047	2852 926483	ELENA MIRONOVA	{"phone": "+70882449895"}
0005432226141	9D3047	6935 671685	TAMARA ZAKHAROVA	{"phone": "+70749107172"}
0005432226142	9D3047	3991 798762	DANIIL ANTONOV	{"email": "daniilantonov.29071968@postgrespro.ru", "phone": "+70003317134"}
0005432226143	CCFDDA	0434 828643	YURIY SEMENOV	{"email": "yuriy-semenov011972@postgrespro.ru", "phone": "+70985151639"}
0005432226144	0ED33F	1830 850103	ELIZAVETA VOROBEVA	{"email": "vorobeva-e_1979@postgrespro.ru", "phone": "+70765703925"}
0005432226145	0ED33F	7174 811152	VERONIKA ANDREEVA	{"phone": "+70283417995"}
0005432226146	AFDD90	2691 445280	ALEKSANDR ORLOV	{"phone": "+70063275507"}
0005432226147	EE8300	5449 951274	VLADIMIR MIKHAYLOV	{"phone": "+70478740224"}
0005432226148	A5A37E	5116 134927	DAVID MOROZOV	{"email": "dmorozov_1968@postgrespro.ru", "phone": "+70857454663"}
0005432226149	C22EC4	1732 629038	GALINA MASLOVA	{"phone": "+70955632782"}
0005432226150	B6717C	4667 181669	LIDIYA RYABOVA	{"phone": "+70665722479"}
0005432226151	B6717C	9936 845583	IRINA NESTEROVA	{"phone": "+70645296402"}
0005432226152	B6717C	5505 926577	ILYA IVANOV	{"email": "ivanovilya20101972@postgrespro.ru", "phone": "+70751507178"}
0005432226153	B6717C	0173 514813	ANATOLIY IVANOV	{"phone": "+70165727381"}
0005432226154	687639	3791 955566	ROMAN NAUMOV	{"email": "naumov_r.101962@postgrespro.ru", "phone": "+70250592716"}
0005432226155	687639	7465 889773	ALBINA KUZNECOVA	{"phone": "+70320098108"}
0005432226156	532142	7381 021052	VLADIMIR ROMANOV	{"phone": "+70239335898"}
0005432226157	532142	9451 843748	KLAVDIYA ZHURAVLEVA	{"phone": "+70434937956"}
0005432226158	532142	1120 929097	ELENA ANISIMOVA	{"email": "anisimova-e_1964@postgrespro.ru", "phone": "+70182261797"}
0005432226159	532142	0567 626243	EKATERINA VOLKOVA	{"phone": "+70442348068"}
0005432226160	A7A569	9372 498183	ARTEM POPOV	{"phone": "+70268186424"}
0005432226161	C9CD3C	1942 656268	MARAT SMIRNOV	{"email": "msmirnov.031974@postgrespro.ru", "phone": "+70262406920"}
0005432226162	C9CD3C	1953 131850	VALERIYA POPOVA	{"phone": "+70310253310"}
0005432226163	01E6CF	0267 902943	SERGEY ZAKHAROV	{"email": "sergey-zakharov-1978@postgrespro.ru", "phone": "+70241122191"}
0005432226164	FB7FB2	4840 004036	VIKTOR GORBUNOV	{"email": "gorbunov_v_041971@postgrespro.ru", "phone": "+70875188017"}
0005432226165	EB85D6	6856 750340	YURIY KOZLOV	{"phone": "+70644963288"}
0005432226166	EB85D6	9747 216790	ELENA ALEKSEEVA	{"phone": "+70652635945"}
0005432226167	1F0D93	9526 240695	VALENTINA BELYAEVA	{"email": "belyaeva-valentina1968@postgrespro.ru", "phone": "+70759250267"}
0005432226168	1F0D93	8814 490092	YURIY NOVIKOV	{"phone": "+70310534240"}
0005432226169	837E00	4536 239346	NINA KOROLEVA	{"email": "nina.koroleva061964@postgrespro.ru", "phone": "+70967343175"}
0005432226170	981794	0759 306040	ELENA ISAEVA	{"email": "e.isaeva.1964@postgrespro.ru", "phone": "+70466922643"}
0005432226171	8CFD31	2128 078494	YULIYA DAVYDOVA	{"email": "davydova.yuliya061976@postgrespro.ru", "phone": "+70623396678"}
0005432226172	55A756	5740 589914	ELENA MAKAROVA	{"phone": "+70513903276"}
0005432226173	55A756	7391 690844	TATYANA FROLOVA	{"phone": "+70431442668"}
0005432226174	67129C	0193 014744	IVAN DMITRIEV	{"email": "dmitrievivan.1969@postgrespro.ru", "phone": "+70431252289"}
0005432226175	67129C	7096 160780	IRINA MIRONOVA	{"phone": "+70844150315"}
0005432226176	67129C	5980 914369	ROMAN GUSEV	{"phone": "+70053979606"}
0005432226177	FF1E61	5411 951479	KSENIYA TIMOFEEVA	{"phone": "+70193921710"}
0005432226178	FF1E61	1004 957710	ELENA KUZNECOVA	{"phone": "+70566402994"}
0005432226179	DE452A	4601 488203	TATYANA DENISOVA	{"email": "tatyana_denisova_071973@postgrespro.ru", "phone": "+70655723081"}
0005432226180	DE452A	4266 653393	ALEKSANDRA ABRAMOVA	{"phone": "+70507135067"}
0005432226181	DE452A	6707 627567	NINA NESTEROVA	{"phone": "+70361587355"}
0005432226182	F6ABB0	2174 845808	NIKOLAY KOZLOV	{"email": "nkozlov-1974@postgrespro.ru", "phone": "+70264902811"}
0005432226183	F6ABB0	2296 491848	SERGEY NAUMOV	{"email": "sergey-naumov24061983@postgrespro.ru", "phone": "+70201721340"}
0005432226184	12F639	4631 765341	DMITRIY IVANOV	{"email": "ivanov-dmitriy.1974@postgrespro.ru", "phone": "+70549058469"}
0005432226185	12F639	5423 051802	VLADIMIR MIRONOV	{"phone": "+70829492633"}
0005432226186	23E10C	8366 556637	TATYANA DENISOVA	{"phone": "+70789096134"}
0005432226187	23E10C	4750 531990	ALEKSANDRA VASILEVA	{"email": "vasileva-a_1972@postgrespro.ru", "phone": "+70204080001"}
0005432226188	7F5D9E	0834 141661	ALBINA NOVIKOVA	{"email": "albina-novikova_1963@postgrespro.ru", "phone": "+70842515582"}
0005432226189	7F5D9E	9506 931980	KIRILL ALEKSEEV	{"email": "k_alekseev.111978@postgrespro.ru", "phone": "+70453403699"}
0005432226190	3886EA	5513 892667	NADEZHDA GERASIMOVA	{"email": "gerasimovan031969@postgrespro.ru", "phone": "+70802799451"}
0005432226191	8B91C7	0852 740416	ANASTASIYA MOROZOVA	{"email": "anastasiya_morozova.05101963@postgrespro.ru", "phone": "+70788737291"}
0005432226192	8B91C7	1759 714661	ANNA MEDVEDEVA	{"phone": "+70290665866"}
0005432226193	8B91C7	3086 122932	NIKOLAY PETROV	{"phone": "+70379165725"}
0005432226194	B2871F	7064 717023	TATYANA KOLESNIKOVA	{"email": "kolesnikova-tatyana_071972@postgrespro.ru", "phone": "+70736604408"}
0005432226195	B2871F	3653 133082	SERGEY KRASNOV	{"phone": "+70365738545"}
0005432226196	8B3744	8422 312978	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila_30051968@postgrespro.ru", "phone": "+70867482974"}
0005432226197	8B3744	3540 184296	KRISTINA OSIPOVA	{"phone": "+70886555946"}
0005432226198	95075D	1975 120949	NIKOLAY FILIPPOV	{"email": "n-filippov1964@postgrespro.ru", "phone": "+70372965625"}
0005432226199	95075D	1504 839177	SERGEY NAUMOV	{"email": "naumovs-1967@postgrespro.ru", "phone": "+70361508195"}
0005432226200	BD3930	0661 073668	DMITRIY KUZNECOV	{"phone": "+70938212384"}
0005432226201	3FE87D	9403 211022	VLADISLAV ALEKSANDROV	{"email": "aleksandrovvladislav_1964@postgrespro.ru", "phone": "+70207770406"}
0005432226202	3FE87D	6888 614472	GENNADIY FEDOROV	{"email": "fedorovg-1961@postgrespro.ru", "phone": "+70540346077"}
0005432226203	50DB7D	6934 071562	NIKOLAY MOROZOV	{"phone": "+70940269264"}
0005432226204	50DB7D	1932 759915	ZINAIDA YAKOVLEVA	{"phone": "+70157561520"}
0005432226205	EA3044	0774 474464	VALENTINA NOVIKOVA	{"phone": "+70906672633"}
0005432226206	F0D556	7479 955488	NATALYA VASILEVA	{"email": "natalya_vasileva-111969@postgrespro.ru", "phone": "+70549642881"}
0005432226207	F0D556	0306 637783	ALEKSANDR GUSEV	{"phone": "+70011022406"}
0005432226208	DDCA9B	2404 192313	IRINA ROMANOVA	{"phone": "+70225477568"}
0005432226209	DDCA9B	7119 521034	IRINA MIKHAYLOVA	{"phone": "+70883315526"}
0005432226210	CAE8A6	0861 533113	ELENA VOROBEVA	{"email": "elena.vorobeva_1965@postgrespro.ru", "phone": "+70819087695"}
0005432226211	F4F7B3	1078 402033	ELENA MAKSIMOVA	{"phone": "+70751156210"}
0005432226212	097FB2	9475 936999	SVETLANA YUDINA	{"phone": "+70548629328"}
0005432226213	861334	3361 424512	DARYA ABRAMOVA	{"email": "darya_abramova05121976@postgrespro.ru", "phone": "+70203109646"}
0005432226214	974E0F	8200 297922	ALEKSANDR SERGEEV	{"email": "asergeev17101975@postgrespro.ru", "phone": "+70104556638"}
0005432226215	0DB5E7	0555 362006	LARISA OSIPOVA	{"phone": "+70521527948"}
0005432226216	0DB5E7	1967 454248	MARIYA SAVELEVA	{"phone": "+70454636454"}
0005432226217	1D054C	1570 739829	ZLATA ZHURAVLEVA	{"phone": "+70539745694"}
0005432226218	1D054C	2370 853604	LIDIYA VOLKOVA	{"email": "volkova_lidiya.1971@postgrespro.ru", "phone": "+70575189275"}
0005432226219	015B84	2219 277454	DMITRIY GERASIMOV	{"email": "dmitriy-gerasimov081974@postgrespro.ru", "phone": "+70040692071"}
0005432226220	6A2A03	9296 800069	ALEKSANDR ANTONOV	{"phone": "+70565420442"}
0005432226221	6257B3	1199 662007	SVETLANA ZAYCEVA	{"email": "zaycevas.101974@postgrespro.ru", "phone": "+70879282749"}
0005432226222	6257B3	9435 645343	LYUDMILA PAVLOVA	{"phone": "+70864128245"}
0005432226223	885E68	1820 519330	PAVEL NAUMOV	{"phone": "+70317130862"}
0005432226224	7236CD	7631 509023	ELENA MASLOVA	{"email": "elena-maslova-071977@postgrespro.ru", "phone": "+70892018240"}
0005432226225	7236CD	8771 993814	PAVEL SMIRNOV	{"phone": "+70076350891"}
0005432226226	48E024	7112 290160	SEMEN ZAKHAROV	{"phone": "+70224181243"}
0005432226227	48E024	9550 825126	NIKOLAY EGOROV	{"email": "egorov_n-24081971@postgrespro.ru", "phone": "+70541391027"}
0005432226228	25AC95	4774 724078	IGOR OSIPOV	{"phone": "+70899434634"}
0005432226229	95A9B8	5879 094157	VALENTINA POPOVA	{"phone": "+70295647999"}
0005432226230	635D90	6748 039419	NIKITA FEDOTOV	{"email": "n_fedotov_011968@postgrespro.ru", "phone": "+70459605114"}
0005432226231	AD0CF8	4113 434277	GALINA GUSEVA	{"email": "gusevag-081979@postgrespro.ru", "phone": "+70190345247"}
0005432226232	6B9EE5	8215 577480	ANATOLIY MAKAROV	{"email": "anatoliy-makarov-011982@postgrespro.ru", "phone": "+70908416142"}
0005432226233	B88DBA	8734 865784	OLGA MAKSIMOVA	{"phone": "+70092764806"}
0005432226234	B88DBA	0439 068041	IVAN BORISOV	{"email": "i.borisov_19041970@postgrespro.ru", "phone": "+70203060587"}
0005432226235	65144E	5290 405100	ALEKSANDR GUSEV	{"email": "gusev-aleksandr_111970@postgrespro.ru", "phone": "+70344201669"}
0005432226236	65144E	0053 392753	GENNADIY KUZNECOV	{"email": "kuznecov.gennadiy121969@postgrespro.ru", "phone": "+70182664597"}
0005432226237	20BDE1	4733 138040	TATYANA POTAPOVA	{"phone": "+70958049993"}
0005432226238	592E19	8856 600106	SERGEY MOROZOV	{"email": "sergey-morozov_081981@postgrespro.ru", "phone": "+70687057149"}
0005432226239	812B6E	7804 014858	LYUBOV EGOROVA	{"phone": "+70204565268"}
0005432226240	812B6E	4447 108852	ALEKSEY SEMENOV	{"email": "a-semenov.23041971@postgrespro.ru", "phone": "+70404173136"}
0005432226241	76131E	5389 833694	IRINA ABRAMOVA	{"email": "i_abramova1960@postgrespro.ru", "phone": "+70374986032"}
0005432226242	60D1F9	3452 175379	ANDREY KUZNECOV	{"phone": "+70739796798"}
0005432226243	A8A051	1333 190762	ANDREY MOISEEV	{"email": "moiseev-andrey-1972@postgrespro.ru", "phone": "+70158263527"}
0005432226244	A8A051	5928 866660	NINA KONOVALOVA	{"email": "konovalovan.1968@postgrespro.ru", "phone": "+70894612201"}
0005432231374	CC9F11	0872 602928	YURIY MAKAROV	{"email": "yuriy-makarov-20031988@postgrespro.ru", "phone": "+70798448082"}
0005432231375	CC9F11	3721 011437	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay_1986@postgrespro.ru", "phone": "+70351440698"}
0005432231376	A2B6AE	1997 106660	MIKHAIL MIKHAYLOV	{"phone": "+70495386595"}
0005432231377	F42039	0704 018154	GULIYA KUZMINA	{"email": "kuzminag-11081983@postgrespro.ru", "phone": "+70876794092"}
0005432231378	01BF7C	2991 032448	ELENA ANISIMOVA	{"email": "anisimova.elena25061971@postgrespro.ru", "phone": "+70924138592"}
0005432231379	512441	0022 020806	IRINA POPOVA	{"email": "popova.i.031976@postgrespro.ru", "phone": "+70027107778"}
0005432231380	512441	2712 111307	NIKOLAY MAKAROV	{"phone": "+70815721101"}
0005432231381	BACE49	1379 656211	ALEKSEY GORBUNOV	{"email": "gorbunov_aleksey1970@postgrespro.ru", "phone": "+70656878609"}
0005432231382	AC63B3	3297 128776	YULIYA SAVELEVA	{"email": "yuliya.saveleva-11121967@postgrespro.ru", "phone": "+70415889531"}
0005432231383	C8F925	5876 627693	TATYANA PETROVA	{"email": "petrovat_17041973@postgrespro.ru", "phone": "+70485890628"}
0005432231384	A70A85	3717 107999	ELENA SOLOVEVA	{"email": "soloveva-elena.26121965@postgrespro.ru", "phone": "+70872130442"}
0005432231385	8DD438	6838 097646	TATYANA MASLOVA	{"phone": "+70855377906"}
0005432231386	91A108	4684 663239	VALERIYA MIKHAYLOVA	{"email": "valeriya_mikhaylova.25101973@postgrespro.ru", "phone": "+70376522333"}
0005432231387	91A108	3270 149983	ALIK SEMENOV	{"phone": "+70880578273"}
0005432231388	2AAA18	5535 761909	ELLA MAKSIMOVA	{"phone": "+70124832344"}
0005432231389	2AAA18	0247 705871	VLADIMIR KUZNECOV	{"phone": "+70064898613"}
0005432231390	44C0AC	3018 711906	ROMAN MEDVEDEV	{"phone": "+70705080925"}
0005432231391	671987	7591 949109	ANATOLIY GUSEV	{"phone": "+70395246529"}
0005432231392	960333	3860 483270	KONSTANTIN PETROV	{"phone": "+70452097080"}
0005432231393	960333	9388 344308	MARIYA FEDOROVA	{"email": "m-fedorova30121966@postgrespro.ru", "phone": "+70084841727"}
0005432231394	3438C4	1296 358747	TATYANA STEPANOVA	{"phone": "+70148384309"}
0005432231395	C147C6	7878 294713	ANNA FILIPPOVA	{"phone": "+70916013766"}
0005432231396	C147C6	3458 959277	MAKSIM VOLKOV	{"email": "volkov_m-16041975@postgrespro.ru", "phone": "+70127042308"}
0005432231397	BF096E	5086 000960	EVGENIY GRIGOREV	{"email": "e.grigorev-1972@postgrespro.ru", "phone": "+70751399360"}
0005432231398	5B5631	2393 668548	VADIM ALEKSEEV	{"phone": "+70322515674"}
0005432231399	5B5631	9958 173620	EVGENIY BONDARENKO	{"email": "bondarenkoe-041970@postgrespro.ru", "phone": "+70649347856"}
0005432231400	CB1260	6280 659966	VIKTOR BELOV	{"email": "viktor_belov1964@postgrespro.ru", "phone": "+70069684212"}
0005432231401	A1410C	3913 264172	SVETLANA GRISHINA	{"phone": "+70331479084"}
0005432231402	ABBF3D	1007 492600	OLGA NIKIFOROVA	{"email": "onikiforova-1973@postgrespro.ru", "phone": "+70522867827"}
0005432231403	A65F19	6048 187401	ALEKSEY DENISOV	{"email": "alekseydenisov.1968@postgrespro.ru", "phone": "+70024458340"}
0005432231404	AA17A1	4070 119505	NAIL BONDARENKO	{"email": "bondarenko_nail_041969@postgrespro.ru", "phone": "+70015615909"}
0005432231405	D10BF1	0208 062676	SOFYA CHERNOVA	{"email": "sofyachernova_27081968@postgrespro.ru", "phone": "+70451134631"}
0005432231406	D10BF1	0611 801074	MARIYA ANTONOVA	{"phone": "+70396169833"}
0005432231407	CCDECD	4034 258637	VLADIMIR ZAYCEV	{"email": "vzaycev061971@postgrespro.ru", "phone": "+70243489192"}
0005432231408	DC7CF4	0469 867811	NIKOLAY ROMANOV	{"phone": "+70592988971"}
0005432231409	D5B22D	1858 867395	DMITRIY SCHERBAKOV	{"phone": "+70257231423"}
0005432231410	D5B22D	0828 826918	VALENTIN MIRONOV	{"email": "mironov.v_121976@postgrespro.ru", "phone": "+70270905691"}
0005432231411	D5B22D	0279 256448	ANDREY ANTONOV	{"phone": "+70190731053"}
0005432231412	6B498E	2632 665392	OKSANA TIMOFEEVA	{"email": "timofeeva_oksana1962@postgrespro.ru", "phone": "+70290685738"}
0005432231413	6B498E	3858 075641	VIKTORIYA TARASOVA	{"phone": "+70148748694"}
0005432231414	AE22C9	9679 021815	SERGEY ZAYCEV	{"phone": "+70835852342"}
0005432231415	1849E0	7344 399903	VALERIY IVANOV	{"phone": "+70237360252"}
0005432231416	BFD109	3380 763325	IVAN BELOV	{"email": "ivan-belov-19021976@postgrespro.ru", "phone": "+70375686852"}
0005432231417	5A1B79	4520 698612	ANATOLIY VLASOV	{"email": "vlasov-anatoliy071977@postgrespro.ru", "phone": "+70805260759"}
0005432231418	5A1B79	5107 380940	ALEKSEY KUZNECOV	{"phone": "+70040666105"}
0005432231419	685D29	5410 791727	ALEVTINA KRASNOVA	{"email": "krasnova-alevtina-101975@postgrespro.ru", "phone": "+70805076597"}
0005432231420	DFFD91	2525 138775	TATYANA MOROZOVA	{"phone": "+70558174314"}
0005432231421	D2F2C4	7154 802543	ALEKSEY SERGEEV	{"email": "sergeev-aleksey041985@postgrespro.ru", "phone": "+70408603766"}
0005432231422	D2F2C4	1346 782945	VERA LUKYANOVA	{"phone": "+70045275654"}
0005432231423	D2F2C4	6851 237619	TATYANA IVANOVA	{"email": "ivanova.t_1975@postgrespro.ru", "phone": "+70437958745"}
0005432231424	3DC4C5	4134 064333	VERA KISELEVA	{"phone": "+70534459703"}
0005432231425	5ABD7C	7834 023318	VITALIY DAVYDOV	{"phone": "+70994620909"}
0005432231426	0E9E3F	5391 079620	NADEZHDA ROMANOVA	{"email": "romanovanadezhda.28031976@postgrespro.ru", "phone": "+70912703802"}
0005432231427	DF0175	7701 456347	NINA NOVIKOVA	{"email": "novikova_n061967@postgrespro.ru", "phone": "+70926471143"}
0005432231428	417FF3	9300 182399	GALINA PAVLOVA	{"email": "pavlovagalina_05051976@postgrespro.ru", "phone": "+70391645896"}
0005432231429	8C2301	1424 868041	ALINA ROMANOVA	{"phone": "+70989063087"}
0005432231430	8C2301	8800 787302	SEMEN KUZNECOV	{"phone": "+70669906846"}
0005432231431	C573D4	2153 686868	NIKOLAY MIRONOV	{"phone": "+70721829380"}
0005432231432	63E69D	2462 193224	NADEZHDA FOMINA	{"email": "fominanadezhda-091964@postgrespro.ru", "phone": "+70054373579"}
0005432231433	22EEED	9142 232198	OLEG ANDREEV	{"email": "andreev_oleg_11021978@postgrespro.ru", "phone": "+70450730916"}
0005432231434	22EEED	4831 433931	SERGEY MOISEEV	{"email": "moiseev.sergey17031969@postgrespro.ru", "phone": "+70189345264"}
0005432231435	A63EAD	1813 612402	ANDREY ZHUKOV	{"email": "a-zhukov1970@postgrespro.ru", "phone": "+70690424794"}
0005432231436	C686A5	1687 505609	ALEKSEY GRIGOREV	{"phone": "+70029107772"}
0005432231437	23EAA5	3630 055737	VIKTORIYA SOKOLOVA	{"email": "sokolova-v101988@postgrespro.ru", "phone": "+70099634231"}
0005432231438	23EAA5	7497 610045	ZOYA KULIKOVA	{"phone": "+70639787252"}
0005432231439	23EAA5	6570 029655	TATYANA ILINA	{"phone": "+70430351194"}
0005432231440	6617A3	5164 303837	ELIZAVETA VASILEVA	{"email": "elizaveta.vasileva_02051973@postgrespro.ru", "phone": "+70937718251"}
0005432231441	6617A3	3696 572263	IVAN KISELEV	{"phone": "+70430399103"}
0005432231442	6617A3	2814 043154	NADEZHDA SAVELEVA	{"email": "nadezhda-saveleva-23051980@postgrespro.ru", "phone": "+70272908161"}
0005432231443	6617A3	5711 625872	MARIYA KUDRYASHOVA	{"email": "mariya_kudryashova-1969@postgrespro.ru", "phone": "+70588242492"}
0005432231444	8C0FB8	8998 441253	ANDREY NIKITIN	{"phone": "+70158566377"}
0005432231445	75277E	5053 178348	DMITRIY ISAEV	{"email": "dmitriy-isaev_091978@postgrespro.ru", "phone": "+70019730098"}
0005432231446	D089F7	6871 484620	GALINA TARASOVA	{"email": "tarasova.galina-091978@postgrespro.ru", "phone": "+70661002877"}
0005432231447	2EC53B	4747 787756	ELINA ANTONOVA	{"email": "elina.antonova.081971@postgrespro.ru", "phone": "+70280480667"}
0005432231448	0FC3FD	5476 455677	VIKTOR SCHERBAKOV	{"email": "viktor-scherbakov_15061971@postgrespro.ru", "phone": "+70771928543"}
0005432231449	EE9258	4600 742827	SOFYA STEPANOVA	{"email": "stepanova.s.1973@postgrespro.ru", "phone": "+70515650564"}
0005432231450	D86FFD	2330 119397	SERGEY SOLOVEV	{"phone": "+70575783403"}
0005432231451	CB080A	4566 651118	ALEKSANDR KUZNECOV	{"phone": "+70086512302"}
0005432231452	7F58C9	4899 069733	ELENA KOROLEVA	{"phone": "+70530474678"}
0005432231453	7F58C9	0651 558722	ELENA FOMINA	{"phone": "+70249105416"}
0005432231454	7F58C9	7780 811169	NINA FILATOVA	{"phone": "+70355543887"}
0005432231455	7F58C9	9910 318259	ELENA KUZNECOVA	{"email": "kuznecova-e111969@postgrespro.ru", "phone": "+70824258433"}
0005432231456	415E05	6289 760315	RITA DAVYDOVA	{"email": "r-davydova24121964@postgrespro.ru", "phone": "+70344862587"}
0005432231457	50BDC6	3379 235147	ELENA KONDRATEVA	{"email": "kondratevaelena.1971@postgrespro.ru", "phone": "+70738713633"}
0005432231458	50BDC6	9571 243815	VIKTOR SAVELEV	{"email": "vsavelev_101981@postgrespro.ru", "phone": "+70281262887"}
0005432231459	50BDC6	1274 104957	NIKOLAY PETROV	{"email": "nikolay_petrov_1962@postgrespro.ru", "phone": "+70680162746"}
0005432231460	EA6BEF	4949 846132	SERGEY YAKOVLEV	{"phone": "+70097205501"}
0005432231461	EA6BEF	6503 020359	IVAN IVANOV	{"phone": "+70122426969"}
0005432231462	C44F2C	8731 447581	GALINA POLYAKOVA	{"phone": "+70230553317"}
0005432231463	C44F2C	7188 707847	PAVEL IVANOV	{"phone": "+70213763520"}
0005432231464	CDB148	8712 158276	SERGEY FROLOV	{"email": "sergey.frolov_091972@postgrespro.ru", "phone": "+70509587368"}
0005432231465	CDB148	8324 672630	SERGEY NOVIKOV	{"phone": "+70676317594"}
0005432231466	6DF072	0773 381926	IVAN GAVRILOV	{"phone": "+70759671330"}
0005432231467	6DF072	8877 920445	RISHAT SCHERBAKOV	{"phone": "+70451420285"}
0005432231468	259306	9115 882481	YURIY GUSEV	{"phone": "+70051437740"}
0005432231469	9091EA	4896 531858	LIDIYA NAZAROVA	{"email": "l_nazarova16051971@postgrespro.ru", "phone": "+70450620520"}
0005432231470	F49071	4146 610545	DMITRIY IVANOV	{"email": "d_ivanov.1969@postgrespro.ru", "phone": "+70105932698"}
0005432231471	F49071	7328 646446	VITALIY SMIRNOV	{"email": "smirnov.v-11051968@postgrespro.ru", "phone": "+70156852311"}
0005432231472	ECE423	8564 656730	ALLA ALEKSANDROVA	{"phone": "+70242030765"}
0005432231473	DF357E	3790 990047	ELDAR MEDVEDEV	{"phone": "+70316516832"}
0005432231474	DF357E	4345 398448	MARAT SCHERBAKOV	{"email": "scherbakov_m-16071988@postgrespro.ru", "phone": "+70772752019"}
0005432231475	85096D	0359 710959	NATALYA TITOVA	{"phone": "+70567476245"}
0005432231476	9BEB6C	4357 679581	EKATERINA TIMOFEEVA	{"phone": "+70779511429"}
0005432231477	9BEB6C	5133 615620	TATYANA PAVLOVA	{"email": "pavlovat_1971@postgrespro.ru", "phone": "+70834643637"}
0005432231478	9BEB6C	4967 929206	OLGA KUZMINA	{"email": "o.kuzmina17101969@postgrespro.ru", "phone": "+70979863512"}
0005432231479	011799	0262 742440	MARINA IVANOVA	{"email": "m.ivanova1960@postgrespro.ru", "phone": "+70685204070"}
0005432231480	011799	0859 054620	VYACHESLAV RODIONOV	{"phone": "+70552723214"}
0005432231481	CE0483	3419 458643	NADEZHDA PAVLOVA	{"phone": "+70382932050"}
0005432231482	DDA412	4764 417013	LYUBOV MAKAROVA	{"phone": "+70398576688"}
0005432231483	CFD18D	7959 836556	VIKTOR ZAYCEV	{"phone": "+70750564964"}
0005432231484	A0A173	9909 688609	NIKITA ZAYCEV	{"phone": "+70075445615"}
0005432231485	A0A173	1595 872721	ZOYA ANTONOVA	{"phone": "+70644854096"}
0005432231486	7D012F	1898 068111	ALEKSEY SAVELEV	{"email": "saveleva041965@postgrespro.ru", "phone": "+70728257654"}
0005432231487	7D012F	0210 657602	VLADIMIR IVANOV	{"phone": "+70430407292"}
0005432231488	113972	5700 651505	NIKOLAY MATVEEV	{"email": "nikolay-matveev-111969@postgrespro.ru", "phone": "+70763407836"}
0005432231489	07CACB	1305 009030	RAISA ABRAMOVA	{"phone": "+70018071688"}
0005432231490	E044E2	2357 370641	IGOR NOVIKOV	{"email": "novikov_i_021983@postgrespro.ru", "phone": "+70199423451"}
0005432231491	879119	9814 097880	VLADISLAV SERGEEV	{"phone": "+70944646707"}
0005432231492	B0D90C	1505 609716	NADEZHDA POLYAKOVA	{"email": "polyakova.n_18051974@postgrespro.ru", "phone": "+70716176021"}
0005432231493	5963B5	6610 476314	TATYANA NAUMOVA	{"phone": "+70826728398"}
0005432231494	5963B5	6284 457251	VIKTORIYA YAKOVLEVA	{"email": "v_yakovleva_04101963@postgrespro.ru", "phone": "+70985203876"}
0005432231495	008738	9104 206195	VLADIMIR IVANOV	{"email": "ivanov.vladimir_1982@postgrespro.ru", "phone": "+70058826935"}
0005432231496	008738	1860 782110	VALERIYA FROLOVA	{"phone": "+70817445690"}
0005432231497	84818E	2724 538339	KRISTINA MAKAROVA	{"email": "makarovakristina.051971@postgrespro.ru", "phone": "+70997248760"}
0005432231498	84818E	9167 055491	DENIS ISAEV	{"email": "d_isaev.04041973@postgrespro.ru", "phone": "+70768552225"}
0005432231499	6837F0	0509 174344	MARIYA AFANASEVA	{"phone": "+70905981820"}
0005432231500	51951B	3093 206138	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov.1960@postgrespro.ru", "phone": "+70539887046"}
0005432231501	AD9D27	0617 565441	VLADIMIR MAKAROV	{"email": "makarov_vladimir-1981@postgrespro.ru", "phone": "+70549966929"}
0005432231502	AE0634	8805 940839	ALEVTINA MAKAROVA	{"phone": "+70636029095"}
0005432231503	6D8147	8581 690745	VITALIY PAVLOV	{"phone": "+70792966736"}
0005432231504	6D8147	2694 876763	NATALYA SEMENOVA	{"phone": "+70671809509"}
0005432231505	6D8147	8801 371244	ALEKSANDR GUSEV	{"email": "aleksandr_gusev27081974@postgrespro.ru", "phone": "+70496021647"}
0005432231506	412E53	1901 183200	GALINA KUZNECOVA	{"phone": "+70103691870"}
0005432231507	51FA36	1436 227294	ALEKSANDR MATVEEV	{"phone": "+70955617524"}
0005432231508	51FA36	0316 524245	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov13101979@postgrespro.ru", "phone": "+70266421438"}
0005432231509	AA9BE6	5072 094914	SERGEY ALEKSEEV	{"phone": "+70925488620"}
0005432231510	4DA710	2731 630377	EGOR IVANOV	{"email": "e-ivanov1954@postgrespro.ru", "phone": "+70835451070"}
0005432231511	4DA710	4660 221740	EVGENIY ABRAMOV	{"email": "evgeniy_abramov-1970@postgrespro.ru", "phone": "+70564779188"}
0005432231512	0BE72E	5251 718499	MIKHAIL PETROV	{"email": "petrov_m.02061961@postgrespro.ru", "phone": "+70257346048"}
0005432231513	4E2ACD	5105 890789	LIDIYA VLASOVA	{"email": "l.vlasova1979@postgrespro.ru", "phone": "+70607739774"}
0005432231514	C39219	5661 542771	MARIYA EGOROVA	{"email": "egorovam071973@postgrespro.ru", "phone": "+70018496780"}
0005432231515	7FCA05	7674 319917	RUSLAN IVANOV	{"email": "ivanovr-021986@postgrespro.ru", "phone": "+70807176570"}
0005432231516	7FCA05	1883 634759	ANNA FOMINA	{"phone": "+70065375882"}
0005432231517	DC8C15	7886 353990	ALENA ANISIMOVA	{"phone": "+70831390611"}
0005432231518	B5A2D1	4574 914519	EVGENIY CHERNOV	{"phone": "+70571012185"}
0005432231519	4A39B7	3691 223906	ANDREY ZAKHAROV	{"email": "andrey.zakharov19081960@postgrespro.ru", "phone": "+70036302871"}
0005432231520	92C9A3	8405 494044	GALINA NIKITINA	{"phone": "+70523995753"}
0005432231521	E72FA8	2993 702068	NATALYA IVANOVA	{"email": "ivanovan_1974@postgrespro.ru", "phone": "+70001057599"}
0005432231522	E72FA8	7625 343185	PAVEL DENISOV	{"email": "denisov-pavel.1982@postgrespro.ru", "phone": "+70071172924"}
0005432231523	9AB9F2	4911 720939	ALINA VOROBEVA	{"email": "alina-vorobeva_071973@postgrespro.ru", "phone": "+70421388502"}
0005432231524	0D57B2	4247 503298	EKATERINA MATVEEVA	{"phone": "+70745551455"}
0005432231525	F8D1F7	9806 649897	OLGA MELNIKOVA	{"email": "melnikova.o-07111978@postgrespro.ru", "phone": "+70512130205"}
0005432231526	F8D1F7	9475 646768	OLEG GERASIMOV	{"email": "gerasimov-oleg_1966@postgrespro.ru", "phone": "+70096454575"}
0005432231527	6F3F9F	6580 974800	ELENA ILINA	{"email": "ilina.elena_011968@postgrespro.ru", "phone": "+70994119648"}
0005432231528	64EBD9	5274 289384	LARISA MAKAROVA	{"email": "l.makarova061974@postgrespro.ru", "phone": "+70343232132"}
0005432231529	AA5D7B	6638 854553	DENIS GAVRILOV	{"phone": "+70192543228"}
0005432231530	5619D6	9856 270274	PAVEL DENISOV	{"email": "denisovpavel_14071986@postgrespro.ru", "phone": "+70139004298"}
0005432231531	5619D6	0253 422880	VLADIMIR SEMENOV	{"phone": "+70175273977"}
0005432231532	22DD3D	0907 236953	VIKTOR PAVLOV	{"phone": "+70794142954"}
0005432231533	179B0D	4854 333410	EGOR BARANOV	{"email": "egorbaranov_21091970@postgrespro.ru", "phone": "+70435784351"}
0005432231534	179B0D	9788 580813	VALENTINA MAKAROVA	{"phone": "+70000143018"}
0005432231535	179B0D	8356 306711	SERGEY FEDOROV	{"email": "s.fedorov_1982@postgrespro.ru", "phone": "+70488731555"}
0005432231536	89E1A4	6597 503630	EVGENIY ALEKSANDROV	{"phone": "+70985279070"}
0005432231537	A1A11F	2347 070613	IRINA POPOVA	{"email": "irina.popova_21041971@postgrespro.ru", "phone": "+70074844130"}
0005432231538	A1A11F	9672 944037	ALEKSANDR PETROV	{"email": "a_petrov021976@postgrespro.ru", "phone": "+70975558233"}
0005432231539	81BB5F	2979 285144	NATALYA KARPOVA	{"phone": "+70870319189"}
0005432231540	549ACB	0009 835282	ALEKSEY TIMOFEEV	{"email": "alekseytimofeev1970@postgrespro.ru", "phone": "+70892727002"}
0005432231541	ED501D	5838 151703	SERGEY STEPANOV	{"phone": "+70048915792"}
0005432231542	ED501D	1670 150792	ALEKSANDR BONDARENKO	{"phone": "+70393368838"}
0005432231543	3BC5E3	2504 767673	ANASTASIYA GUSEVA	{"phone": "+70422994586"}
0005432231544	7368A1	0557 407620	DENIS IVANOV	{"phone": "+70742254651"}
0005432231545	7368A1	8651 796163	EKATERINA SIDOROVA	{"phone": "+70388438578"}
0005432231546	7368A1	2588 655343	VARVARA TIMOFEEVA	{"phone": "+70624660650"}
0005432231547	82974C	8562 572300	VALENTINA NIKITINA	{"email": "nikitina-v-25041972@postgrespro.ru", "phone": "+70606521340"}
0005432231548	CDF383	8859 005625	ALENA KOZLOVA	{"email": "kozlova-alena-14101971@postgrespro.ru", "phone": "+70514424749"}
0005432231549	EF82FF	2064 451595	DMITRIY NOVIKOV	{"email": "novikov.dmitriy.09041977@postgrespro.ru", "phone": "+70592349073"}
0005432231550	EF82FF	3435 885378	NADEZHDA PETROVA	{"email": "petrova.n.1976@postgrespro.ru", "phone": "+70999563621"}
0005432231551	202C21	8433 902834	ANDREY DMITRIEV	{"email": "dmitrieva_01041981@postgrespro.ru", "phone": "+70098007218"}
0005432231552	098AD8	7547 161436	GALINA VASILEVA	{"email": "vasileva_g011978@postgrespro.ru", "phone": "+70199857301"}
0005432231553	AA46FA	3415 670204	VALENTINA DENISOVA	{"phone": "+70828310085"}
0005432231554	A97BDB	6467 415654	OLGA VOLKOVA	{"email": "volkovaolga.1960@postgrespro.ru", "phone": "+70176054367"}
0005432231555	6F99C5	8048 606323	ALEKSEY MAKAROV	{"phone": "+70175774475"}
0005432231556	BF9039	2193 248153	SVETLANA ANISIMOVA	{"email": "anisimova.svetlana-22041971@postgrespro.ru", "phone": "+70875593556"}
0005432231557	BF9039	2757 239732	LARISA CHERNOVA	{"phone": "+70387606163"}
0005432231558	59F73A	1875 636691	TATYANA MATVEEVA	{"phone": "+70070747236"}
0005432231559	59F73A	3664 092250	OLGA BELYAEVA	{"email": "olga_belyaeva.02061974@postgrespro.ru", "phone": "+70936928433"}
0005432231560	7C5B94	5743 054571	ROMAN NIKITIN	{"phone": "+70745779739"}
0005432231561	6BDA36	5343 442136	TATYANA NIKITINA	{"email": "nikitina_tatyana1967@postgrespro.ru", "phone": "+70352335368"}
0005432231562	194DA3	9416 438619	SVETLANA VASILEVA	{"phone": "+70868279178"}
0005432231563	194DA3	4800 541015	EGOR VOROBEV	{"email": "vorobev-e.19011975@postgrespro.ru", "phone": "+70247681864"}
0005432231564	84606A	0349 964022	YULIYA VLASOVA	{"email": "y-vlasova-1978@postgrespro.ru", "phone": "+70821518562"}
0005432231565	A4AFDD	0638 996823	NIKOLAY ZAYCEV	{"email": "nikolay.zaycev1971@postgrespro.ru", "phone": "+70281638224"}
0005432231566	FA2F7C	2305 412605	LARISA ZHUKOVA	{"phone": "+70572595561"}
0005432231567	FA2F7C	2255 610850	RAFAEL KUZNECOV	{"email": "rafaelkuznecov061975@postgrespro.ru", "phone": "+70445538746"}
0005432231568	64ABBE	2180 364371	VYACHESLAV STEPANOV	{"email": "v_stepanov.08091979@postgrespro.ru", "phone": "+70105717823"}
0005432231569	8D1B99	0497 149203	ALEKSANDR SOKOLOV	{"phone": "+70923844364"}
0005432231570	8D1B99	4159 395390	SERGEY ZHUKOV	{"email": "s_zhukov1975@postgrespro.ru", "phone": "+70757547237"}
0005432231571	A606D8	2271 142970	IVAN KRASNOV	{"phone": "+70759123672"}
0005432231572	A606D8	9406 982758	VLADIMIR SCHERBAKOV	{"phone": "+70872837919"}
0005432231573	A606D8	5384 823329	PELAGEYA VOLKOVA	{"email": "pelageya-volkova_011969@postgrespro.ru", "phone": "+70172901245"}
0005432231574	DEA9C8	5137 750361	EVGENIY SEMENOV	{"email": "semenove-1979@postgrespro.ru", "phone": "+70681623497"}
0005432231575	EF7A15	1172 446434	DMITRIY KONOVALOV	{"email": "d-konovalov_1971@postgrespro.ru", "phone": "+70808454314"}
0005432231576	EF7A15	7456 520996	NATALYA KUZNECOVA	{"email": "nkuznecova.1980@postgrespro.ru", "phone": "+70828041516"}
0005432231577	148A15	6102 944836	RODION SEMENOV	{"phone": "+70828201401"}
0005432231578	76AFE9	3273 590991	EVGENIYA MAKAROVA	{"phone": "+70517959317"}
0005432231579	76AFE9	8493 428401	TAISA KUZNECOVA	{"phone": "+70196013886"}
0005432231580	566271	3062 985451	VASILIY CHERNOV	{"phone": "+70370946900"}
0005432231581	566271	0840 483986	SVETLANA VLASOVA	{"email": "svetlanavlasova.1979@postgrespro.ru", "phone": "+70152001771"}
0005432231582	131C81	1068 441359	MAYA FEDOROVA	{"email": "mfedorova.1974@postgrespro.ru", "phone": "+70837015882"}
0005432231583	131C81	3609 273627	VALERIY KOROLEV	{"email": "korolevvaleriy_091970@postgrespro.ru", "phone": "+70185232944"}
0005432231584	53472C	4921 017903	GENNADIY POPOV	{"email": "g_popov_021962@postgrespro.ru", "phone": "+70201920430"}
0005432231585	B85E15	5370 107930	ARTEM TARASOV	{"phone": "+70182555087"}
0005432231586	B85E15	1648 895311	EKATERINA KUZNECOVA	{"phone": "+70992583531"}
0005432231587	373B1C	6419 018934	GALINA VOLKOVA	{"email": "volkova.galina.30011980@postgrespro.ru", "phone": "+70299705649"}
0005432231588	373B1C	9091 477092	ANTONINA MIRONOVA	{"phone": "+70277908105"}
0005432231589	8501F9	7559 484833	RISHAT MIRONOV	{"email": "mironovrishat_16011974@postgrespro.ru", "phone": "+70003722373"}
0005432231590	8501F9	4818 068395	ANDREY PETROV	{"email": "petrov_andrey-15011968@postgrespro.ru", "phone": "+70847935277"}
0005432231591	D3DB00	1345 103117	NIKOLAY STEPANOV	{"email": "nikolaystepanov-081978@postgrespro.ru", "phone": "+70114164945"}
0005432231592	D3DB00	9173 197984	LYUBOV POTAPOVA	{"email": "l_potapova-19111971@postgrespro.ru", "phone": "+70317052433"}
0005432231593	093FD3	3559 955276	ALEKSANDR DENISOV	{"email": "adenisov.22111972@postgrespro.ru", "phone": "+70898440362"}
0005432231594	796C41	6687 411646	ELIZAVETA OSIPOVA	{"phone": "+70880925128"}
0005432231595	A0101C	5966 503111	VASILIY MOROZOV	{"email": "vasiliymorozov_09031975@postgrespro.ru", "phone": "+70060670691"}
0005432231596	A0101C	3153 458047	LYUDMILA KOLESNIKOVA	{"phone": "+70276141766"}
0005432231597	F5CE08	9849 746248	MIKHAIL SEMENOV	{"email": "semenov-mikhail-051964@postgrespro.ru", "phone": "+70980526572"}
0005432231598	1F8C22	4938 562393	TAMARA LUKYANOVA	{"email": "lukyanova-t1965@postgrespro.ru", "phone": "+70108598831"}
0005432231599	A48043	2652 384122	ALEKSEY KISELEV	{"phone": "+70396825064"}
0005432231600	BA03CC	0842 724978	TATYANA KOROLEVA	{"email": "t-koroleva061975@postgrespro.ru", "phone": "+70553407785"}
0005432231601	918DC1	1020 168756	ELENA SAVELEVA	{"email": "esaveleva_1966@postgrespro.ru", "phone": "+70527260499"}
0005432231602	918DC1	4953 467435	NATALYA TIMOFEEVA	{"email": "timofeeva-natalya031974@postgrespro.ru", "phone": "+70383247088"}
0005432231603	5136C7	2000 537181	LILIYA KALININA	{"email": "kalinina.l-1973@postgrespro.ru", "phone": "+70112265989"}
0005432231604	5136C7	5956 321322	MIKHAIL ZHURAVLEV	{"phone": "+70279418199"}
0005432231605	68EC98	9793 510459	ALEKSEY MELNIKOV	{"email": "melnikov.aleksey-25111971@postgrespro.ru", "phone": "+70124734608"}
0005432231606	1C8EF7	4440 926148	YURIY MOROZOV	{"phone": "+70977786982"}
0005432231607	C9269C	7207 865409	ZINAIDA YAKOVLEVA	{"email": "zinaida-yakovleva.021969@postgrespro.ru", "phone": "+70224540420"}
0005432231608	51513F	3754 090287	ALIYA KULIKOVA	{"email": "a.kulikova.09061968@postgrespro.ru", "phone": "+70284092620"}
0005432231609	2BE595	1536 860172	SVETLANA VLASOVA	{"email": "vlasova_s11021974@postgrespro.ru", "phone": "+70714333029"}
0005432231610	B4CC39	1362 048622	ANATOLIY MOISEEV	{"email": "anatoliy_moiseev-021975@postgrespro.ru", "phone": "+70157621892"}
0005432231611	FC5456	5407 132268	ALEKSEY ZHUKOV	{"phone": "+70974175785"}
0005432231612	FC5456	6701 201769	ALEKSANDR POPOV	{"phone": "+70459641316"}
0005432231613	FC5456	1263 304831	OLGA KULIKOVA	{"email": "olga-kulikova031966@postgrespro.ru", "phone": "+70940582437"}
0005432231614	0C6F44	8234 909603	VYACHESLAV NOVIKOV	{"phone": "+70154725849"}
0005432231615	F36FFE	9241 874651	ANASTASIYA CHERNOVA	{"phone": "+70761197586"}
0005432231616	439085	7067 061814	ELENA KUZNECOVA	{"email": "kuznecovaelena.031980@postgrespro.ru", "phone": "+70643355015"}
0005432231617	FF3C48	1313 975778	LYUDMILA MOISEEVA	{"email": "lmoiseeva10031985@postgrespro.ru", "phone": "+70106929612"}
0005432231618	FB248C	8199 353353	ALEKSANDR SEMENOV	{"email": "asemenov.1984@postgrespro.ru", "phone": "+70146372626"}
0005432231619	6AFC35	3045 957647	ANATOLIY NIKITIN	{"phone": "+70824982731"}
0005432231620	266046	4427 012656	IRINA AFANASEVA	{"phone": "+70206511514"}
0005432231621	266046	2235 994594	TAISA TARASOVA	{"phone": "+70864533543"}
0005432231622	266046	9476 276809	OLGA ILINA	{"phone": "+70976510774"}
0005432231623	9B37C8	5631 795283	SVETLANA PETROVA	{"email": "svetlanapetrova.22081974@postgrespro.ru", "phone": "+70358992917"}
0005432231624	C4E166	6732 401976	OLGA FROLOVA	{"email": "olga_frolova.121973@postgrespro.ru", "phone": "+70124850294"}
0005432231625	016BAB	2792 251434	VASILIY KONOVALOV	{"phone": "+70676320273"}
0005432231626	43CE12	8982 087162	LYUDMILA ARKHIPOVA	{"email": "arkhipovalyudmila1979@postgrespro.ru", "phone": "+70366947662"}
0005432231627	B77F58	3329 938227	IVAN SCHERBAKOV	{"email": "scherbakovi-101979@postgrespro.ru", "phone": "+70335545437"}
0005432231628	B77F58	8607 878680	ANATOLIY ISAEV	{"phone": "+70987632911"}
0005432231629	796F69	3345 112278	ALEKSANDR ANDREEV	{"phone": "+70467730500"}
0005432231630	931170	9962 036361	ALEKSEY TARASOV	{"phone": "+70583295447"}
0005432231631	931170	5176 855148	VLADIMIR NIKOLAEV	{"email": "v-nikolaev_24021981@postgrespro.ru", "phone": "+70997538658"}
0005432231632	ABCD25	0059 174020	TATYANA SIDOROVA	{"email": "tatyanasidorova_011966@postgrespro.ru", "phone": "+70413692301"}
0005432231633	898A30	7735 416598	NINA KONDRATEVA	{"email": "kondratevanina-21081960@postgrespro.ru", "phone": "+70894599533"}
0005432231634	898A30	2714 772222	EKATERINA PETROVA	{"phone": "+70769163227"}
0005432231635	161464	7999 782132	SERGEY NOVIKOV	{"email": "novikovs1981@postgrespro.ru", "phone": "+70634448097"}
0005432231636	AB320F	3265 136107	IRINA EGOROVA	{"phone": "+70238549954"}
0005432231637	9A71A3	5899 112103	MARINA VOLKOVA	{"email": "marina-volkova-19011977@postgrespro.ru", "phone": "+70551790357"}
0005432231638	F2E41D	9059 362930	MARINA ALEKSANDROVA	{"email": "aleksandrovamarina-13071975@postgrespro.ru", "phone": "+70536239287"}
0005432231639	ED3081	4462 261315	KSENIYA ABRAMOVA	{"email": "kseniya.abramova.27041979@postgrespro.ru", "phone": "+70447736825"}
0005432231640	ED3081	3629 683233	ARTUR ANDREEV	{"phone": "+70776070209"}
0005432231641	ED3081	7999 936449	ANDREY FEDOROV	{"phone": "+70608574593"}
0005432231642	B95D7F	8311 563475	VALERIY ANDREEV	{"phone": "+70421356294"}
0005432231643	A972C1	5413 851376	TATYANA PAVLOVA	{"email": "t.pavlova-16011972@postgrespro.ru", "phone": "+70883479095"}
0005432231644	E513B5	7335 825671	ILYA KAZAKOV	{"phone": "+70267733535"}
0005432231645	8F2065	8935 770074	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva-12051973@postgrespro.ru", "phone": "+70495516668"}
0005432231646	73B34F	5050 076491	OKSANA BELYAEVA	{"phone": "+70116364041"}
0005432231647	A4F81A	4136 055968	ANDREY ISAEV	{"email": "isaev-andrey-24091967@postgrespro.ru", "phone": "+70760639092"}
0005432231648	BD2A67	4433 489792	OLEG ISAEV	{"email": "isaev_oleg_29051968@postgrespro.ru", "phone": "+70477957272"}
0005432231649	871B27	5482 599397	OLESYA DAVYDOVA	{"email": "davydova-o28061980@postgrespro.ru", "phone": "+70188792571"}
0005432231650	A1EB17	7476 467649	ALEKSANDR KONOVALOV	{"phone": "+70434252440"}
0005432231651	57F961	7557 377982	LEV STEPANOV	{"email": "lstepanov_28011963@postgrespro.ru", "phone": "+70890578642"}
0005432231652	DFBC8A	6475 619747	DMITRIY MAKAROV	{"phone": "+70984314584"}
0005432231713	60C001	3609 635854	TATYANA SIDOROVA	{"phone": "+70788445628"}
0005432231653	DFBC8A	6590 796497	NIKOLAY ZAYCEV	{"email": "zaycev.nikolay-1971@postgrespro.ru", "phone": "+70790068965"}
0005432231654	FE2B17	3187 521740	ROMAN KONOVALOV	{"email": "konovalov.r-16121970@postgrespro.ru", "phone": "+70838566793"}
0005432231655	7D50AA	3973 358413	ALENA GUSEVA	{"email": "guseva_a_051982@postgrespro.ru", "phone": "+70699522421"}
0005432231656	7D50AA	9314 987014	EKATERINA OVCHINNIKOVA	{"phone": "+70663397671"}
0005432231657	283235	7408 661973	VERA TROFIMOVA	{"phone": "+70486206627"}
0005432231658	BF48A6	3786 914797	EVGENIY VOLKOV	{"phone": "+70479694251"}
0005432231659	BF48A6	2627 404551	EKATERINA POPOVA	{"email": "ekaterinapopova_1978@postgrespro.ru", "phone": "+70471687365"}
0005432231660	FB096C	7316 716015	VIKTOR GERASIMOV	{"phone": "+70992347806"}
0005432231661	4827BC	6890 970253	GENNADIY FOMIN	{"phone": "+70046107799"}
0005432231662	8A8025	6715 818126	VERA FOMINA	{"phone": "+70844073435"}
0005432231663	8A8025	1654 593013	ALEKSANDR NAZAROV	{"phone": "+70886778769"}
0005432231664	0852E8	2360 286139	MIKHAIL ABRAMOV	{"email": "abramov.m-1972@postgrespro.ru", "phone": "+70201377059"}
0005432231665	0852E8	9427 264728	DARINA MIRONOVA	{"phone": "+70617644983"}
0005432231666	0852E8	9585 359065	LYUDMILA MOROZOVA	{"email": "morozovalyudmila-111966@postgrespro.ru", "phone": "+70768177946"}
0005432231667	D1810E	4273 169290	IVAN NIKOLAEV	{"email": "nikolaev-ivan.1981@postgrespro.ru", "phone": "+70697584228"}
0005432231668	D1810E	7700 893711	ALEKSANDR ANTONOV	{"phone": "+70628968414"}
0005432231669	389549	1061 267014	ROMAN MOROZOV	{"email": "r_morozov-081971@postgrespro.ru", "phone": "+70518009816"}
0005432231670	DA2A6A	0869 532053	EKATERINA MAKSIMOVA	{"phone": "+70726982910"}
0005432231671	DA2A6A	3508 236259	VASILIY SCHERBAKOV	{"phone": "+70655995334"}
0005432231672	19835F	6635 319959	ARINA TITOVA	{"email": "arina_titova-13091969@postgrespro.ru", "phone": "+70707346972"}
0005432231673	088C61	1486 257740	ELLA MAKAROVA	{"email": "e_makarova.071966@postgrespro.ru", "phone": "+70205517812"}
0005432231674	7D210E	9132 494422	NIKITA MATVEEV	{"phone": "+70839132282"}
0005432231675	7D210E	0247 582775	NATALYA MIKHAYLOVA	{"phone": "+70531620494"}
0005432231676	04B1DE	3286 310939	TATYANA SEMENOVA	{"phone": "+70653812654"}
0005432231677	C044F2	4479 922226	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov_031975@postgrespro.ru", "phone": "+70685265903"}
0005432231678	C044F2	4204 899061	VALENTINA KISELEVA	{"email": "kiselevav-15121968@postgrespro.ru", "phone": "+70854782318"}
0005432231679	46EB71	1259 387869	KONSTANTIN NIKITIN	{"phone": "+70938342803"}
0005432231680	2733AC	0801 252534	PETR FEDOROV	{"phone": "+70187183955"}
0005432231681	2733AC	5583 157594	SERGEY KUDRYASHOV	{"email": "sergey_kudryashov.031984@postgrespro.ru", "phone": "+70350896390"}
0005432231682	FD527C	9188 965749	MAKSIM ANDREEV	{"phone": "+70261013051"}
0005432231683	6AF43D	5108 379569	DMITRIY OSIPOV	{"email": "dmitriyosipov_1976@postgrespro.ru", "phone": "+70430646806"}
0005432231684	6F2DA4	2542 602496	VERA PETROVA	{"email": "vera-petrova_1961@postgrespro.ru", "phone": "+70095152395"}
0005432231685	6F2DA4	0833 489537	ILGIZ SCHERBAKOV	{"email": "scherbakovilgiz.1976@postgrespro.ru", "phone": "+70417507486"}
0005432231686	641488	3859 046693	NATALYA KAZAKOVA	{"phone": "+70136350817"}
0005432231687	A7C6B9	6895 736096	NATALYA MELNIKOVA	{"phone": "+70834359667"}
0005432231688	662296	6269 916892	OLGA MIKHAYLOVA	{"phone": "+70845805751"}
0005432231689	A9D862	4885 968649	IRINA PAVLOVA	{"email": "pavlova.i101977@postgrespro.ru", "phone": "+70588021284"}
0005432231690	AD8039	1784 769690	VASILIY TIKHONOV	{"phone": "+70124631695"}
0005432231691	3058ED	5806 163253	YULIYA POPOVA	{"email": "popova_yuliya_1965@postgrespro.ru", "phone": "+70305397833"}
0005432231692	A4A5D8	0690 231450	ALISA OSIPOVA	{"phone": "+70258666979"}
0005432231693	A4A5D8	5269 129479	ANDREY ZHURAVLEV	{"email": "andrey_zhuravlev-1983@postgrespro.ru", "phone": "+70903501811"}
0005432231694	D30F15	2119 872330	EKATERINA FEDOROVA	{"phone": "+70861464415"}
0005432231695	D30F15	7176 788823	VALENTINA KOROLEVA	{"email": "korolevavalentina1974@postgrespro.ru", "phone": "+70191707568"}
0005432231696	27A4DE	2462 118038	ZOYA ZAKHAROVA	{"email": "zakharova-z_031967@postgrespro.ru", "phone": "+70864878847"}
0005432231697	A62F31	5874 274732	LYUBOV OSIPOVA	{"phone": "+70890465271"}
0005432231698	7B5694	1787 111386	ANNA POPOVA	{"email": "anna-popova-12111970@postgrespro.ru", "phone": "+70990130244"}
0005432231699	80C271	2617 479531	SVETLANA NIKITINA	{"email": "svetlana_nikitina_30101977@postgrespro.ru", "phone": "+70207365643"}
0005432231700	FFC541	2941 903198	SERGEY GERASIMOV	{"email": "gerasimov-sergey.28091976@postgrespro.ru", "phone": "+70749298292"}
0005432231701	07B5BB	2269 466172	MAKSIM SOKOLOV	{"email": "sokolov-maksim_071964@postgrespro.ru", "phone": "+70205534656"}
0005432231702	07B5BB	4397 935489	NATALYA BELOVA	{"email": "nbelova.1978@postgrespro.ru", "phone": "+70060840746"}
0005432231703	10F441	8177 704947	ANNA KOROLEVA	{"phone": "+70677600069"}
0005432231704	004382	2096 587162	MARINA KAZAKOVA	{"email": "marina_kazakova_26061977@postgrespro.ru", "phone": "+70459197454"}
0005432231705	18BEDF	2356 200857	NATALYA BELYAEVA	{"email": "natalya_belyaeva_1960@postgrespro.ru", "phone": "+70088564433"}
0005432231706	8CFBE3	6272 515090	ALEKSANDR MOROZOV	{"phone": "+70303532654"}
0005432231707	9225A7	9188 490390	VADIM NAZAROV	{"email": "nazarovvadim111971@postgrespro.ru", "phone": "+70177021999"}
0005432231708	144A66	6101 111475	ALEKSANDR GRIGOREV	{"phone": "+70226528924"}
0005432231709	144A66	1933 438042	ALEKSANDR KUZNECOV	{"email": "kuznecov.a_1964@postgrespro.ru", "phone": "+70842817945"}
0005432231710	62C317	6405 099080	GAGIK PAVLOV	{"phone": "+70457650481"}
0005432231711	8FC8CB	8516 788551	EKATERINA KRASNOVA	{"email": "krasnova.e-1976@postgrespro.ru", "phone": "+70888038465"}
0005432231712	1E928C	7441 474424	ANDREY MATVEEV	{"email": "andrey.matveev_24101962@postgrespro.ru", "phone": "+70791882459"}
0005432231714	60C001	0143 030696	KRISTINA KULIKOVA	{"email": "k-kulikova_1969@postgrespro.ru", "phone": "+70345831583"}
0005432231715	DCB514	7556 603168	NINA NIKITINA	{"phone": "+70251096360"}
0005432231716	002F96	4427 817872	NIKOLAY FEDOTOV	{"email": "fedotov.n.1963@postgrespro.ru", "phone": "+70547832979"}
0005432231717	002F96	9735 155664	IGOR SOKOLOV	{"phone": "+70475443372"}
0005432231718	4DE82C	6210 681018	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.n1961@postgrespro.ru", "phone": "+70898117657"}
0005432231719	91C93D	1214 231724	ALEKSANDR PAVLOV	{"phone": "+70739740304"}
0005432231720	8597DB	4434 735978	YURIY GORBUNOV	{"email": "gorbunov-yuriy_021986@postgrespro.ru", "phone": "+70518651333"}
0005432231721	7F8EB9	9616 788932	SERGEY MATVEEV	{"email": "matveevs.13111976@postgrespro.ru", "phone": "+70037618156"}
0005432231722	09A1C0	8826 692720	VLADIMIR MARTYNOV	{"phone": "+70242863033"}
0005432231723	09A1C0	9184 889920	RUSTYAM TIKHONOV	{"email": "tikhonov_rustyam.1972@postgrespro.ru", "phone": "+70977218494"}
0005432231724	7DCFC7	2610 949611	NATALYA BORISOVA	{"phone": "+70989553652"}
0005432231725	362F9C	0992 694330	NATALIYA MAKAROVA	{"email": "nataliya_makarova101983@postgrespro.ru", "phone": "+70036974756"}
0005432231726	14897B	3256 417599	DARYA TARASOVA	{"phone": "+70183073068"}
0005432231727	1E67BD	7337 446449	NATALYA CHERNOVA	{"email": "chernovanatalya.011980@postgrespro.ru", "phone": "+70557900361"}
0005432231728	E666DD	7633 308563	VALENTINA TARASOVA	{"email": "valentina_tarasova.24091970@postgrespro.ru", "phone": "+70802179362"}
0005432231729	61C911	7677 267536	ANDREY IVANOV	{"email": "andreyivanov.1982@postgrespro.ru", "phone": "+70531371476"}
0005432231730	61C911	2671 652804	NINA YUDINA	{"email": "yudinanina1977@postgrespro.ru", "phone": "+70882700676"}
0005432231731	B43FB9	4354 832036	OLGA ORLOVA	{"phone": "+70063751419"}
0005432231732	B43FB9	7336 902728	VLADISLAV ABRAMOV	{"phone": "+70855513867"}
0005432231733	1DBC90	3290 700069	MARIYA ZAKHAROVA	{"email": "zakharovamariya071972@postgrespro.ru", "phone": "+70817951478"}
0005432231734	1DBC90	9460 658162	EVGENIY EGOROV	{"email": "evgeniyegorov_101973@postgrespro.ru", "phone": "+70118757015"}
0005432231735	532F00	6493 002105	IVAN KUZNECOV	{"email": "kuznecov.i13121980@postgrespro.ru", "phone": "+70327528805"}
0005432231736	E7B33B	8215 665636	SERGEY PETROV	{"phone": "+70254641838"}
0005432231737	1DD45F	4265 233406	VYACHESLAV SMIRNOV	{"email": "vyacheslavsmirnov_1975@postgrespro.ru", "phone": "+70586296958"}
0005432231738	95ABA4	6670 747867	VIKTOR KUDRYASHOV	{"email": "viktor_kudryashov.091962@postgrespro.ru", "phone": "+70003253914"}
0005432231739	95ABA4	0679 014969	VLADIMIR DENISOV	{"phone": "+70583776979"}
0005432231740	95ABA4	8909 163953	OLGA SOKOLOVA	{"email": "olga.sokolova06051967@postgrespro.ru", "phone": "+70234107402"}
0005432231741	95ABA4	0416 042475	MARIYA RODIONOVA	{"phone": "+70604986527"}
0005432231742	166910	6602 946732	MAYYA NIKOLAEVA	{"email": "m_nikolaeva08051972@postgrespro.ru", "phone": "+70343110483"}
0005432231743	413AC9	7506 866611	NATALYA SERGEEVA	{"phone": "+70397236395"}
0005432231744	012258	4902 433858	ALEKSANDR BELOV	{"phone": "+70629953089"}
0005432231745	C1F1E7	1519 853259	LYUBOV KOLESNIKOVA	{"phone": "+70120616509"}
0005432231746	B5EBDB	4111 781692	ARSENIY ALEKSEEV	{"email": "arseniy-alekseev-29051973@postgrespro.ru", "phone": "+70477921377"}
0005432231747	29B430	5470 096898	NATALYA ILINA	{"phone": "+70815825801"}
0005432231748	1F641E	2181 690186	SERGEY KARPOV	{"phone": "+70932442319"}
0005432231749	8BAEFE	5339 699959	ELIZAVETA KUZNECOVA	{"email": "elizavetakuznecova071971@postgrespro.ru", "phone": "+70860558578"}
0005432231750	BD6ADF	6201 280649	NINA KULIKOVA	{"phone": "+70281824621"}
0005432231751	F32F94	0748 654378	ELENA PETROVA	{"email": "petrova_elena.1972@postgrespro.ru", "phone": "+70576722788"}
0005432231752	F32F94	2170 768721	TATYANA SMIRNOVA	{"email": "smirnova.tatyana.21111982@postgrespro.ru", "phone": "+70363411251"}
0005432231753	609125	9678 508331	ALBERT KULIKOV	{"phone": "+70661145111"}
0005432231754	CF9921	5869 321582	ALEKSEY SEMENOV	{"email": "semenov-a1975@postgrespro.ru", "phone": "+70259279847"}
0005432231755	CDBF7E	1334 916138	VLADIMIR DMITRIEV	{"email": "dmitriev.vladimir.1975@postgrespro.ru", "phone": "+70929212184"}
0005432231756	95991A	5475 847473	ELENA NOVIKOVA	{"phone": "+70261607190"}
0005432231757	E9AB2B	6824 473509	SVETLANA FROLOVA	{"phone": "+70626006478"}
0005432231758	02740E	8942 350273	VIKTORIYA GAVRILOVA	{"email": "v_gavrilova_021972@postgrespro.ru", "phone": "+70276593522"}
0005432231759	1B1A1F	3257 499163	DANIIL NIKITIN	{"phone": "+70762753877"}
0005432231760	272099	9080 132512	NATALYA FEDOROVA	{"email": "fedorova.n1974@postgrespro.ru", "phone": "+70470920933"}
0005432231761	272099	8664 035515	ILNAR ALEKSEEV	{"phone": "+70532837150"}
0005432231762	24C470	9510 431625	VALENTIN CHERNOV	{"phone": "+70337451617"}
0005432231763	0BC2BA	8301 011945	PAVEL TARASOV	{"phone": "+70734762978"}
0005432231764	F1C1FB	9575 505697	MAKSIM DMITRIEV	{"phone": "+70395719503"}
0005432231765	F1C1FB	8156 374473	VALENTINA PETROVA	{"email": "v.petrova-111982@postgrespro.ru", "phone": "+70081466493"}
0005432231766	4FA2A7	6053 641682	NATALIYA KULIKOVA	{"email": "nataliya-kulikova101968@postgrespro.ru", "phone": "+70044777433"}
0005432231767	30F1DA	9139 661396	ALEKSEY ALEKSEEV	{"email": "aleksey.alekseev_011970@postgrespro.ru", "phone": "+70125116615"}
0005432231768	30F1DA	0932 901358	FAINA AKIMOVA	{"phone": "+70868676699"}
0005432231769	79A020	4172 442097	KSENIYA VLASOVA	{"email": "vlasova.kseniya-031973@postgrespro.ru", "phone": "+70937210439"}
0005432231770	D1B2DE	0934 789344	NINA MASLOVA	{"email": "maslovanina031972@postgrespro.ru", "phone": "+70696847617"}
0005432231771	5BB5AE	8622 942367	KLAVDIYA LUKYANOVA	{"phone": "+70520593767"}
0005432231772	5BB5AE	6238 326013	ELENA FILATOVA	{"phone": "+70111740439"}
0005432231773	B7531E	6936 322095	NATALYA NIKOLAEVA	{"phone": "+70877367980"}
0005432231774	B7531E	4049 933282	SERGEY TIKHONOV	{"phone": "+70073892024"}
0005432231775	A31DDF	5016 099429	ELENA AFANASEVA	{"email": "elena_afanaseva.041969@postgrespro.ru", "phone": "+70470267573"}
0005432231776	A31DDF	8642 193922	ELENA MIKHAYLOVA	{"phone": "+70265057737"}
0005432231777	344FE1	6287 443186	DMITRIY SAVELEV	{"email": "savelev.dmitriy031971@postgrespro.ru", "phone": "+70095211855"}
0005432231778	E26007	3753 651162	ROMAN MOISEEV	{"email": "moiseev.roman-1973@postgrespro.ru", "phone": "+70353689806"}
0005432231779	144C3C	4166 662310	ANDREY IVANOV	{"phone": "+70232011575"}
0005432231780	144C3C	1106 259895	MAKSIM KUZNECOV	{"email": "m_kuznecov.1982@postgrespro.ru", "phone": "+70211533702"}
0005432231781	6AF98E	4885 354222	ROMAN NIKITIN	{"email": "r.nikitin-061964@postgrespro.ru", "phone": "+70645603344"}
0005432231782	3BEF21	7210 405859	MARGARITA CHERNOVA	{"email": "margarita_chernova1974@postgrespro.ru", "phone": "+70293172223"}
0005432231783	3BEF21	2165 189431	ANASTASIYA SERGEEVA	{"email": "a_sergeeva.03121964@postgrespro.ru", "phone": "+70700584465"}
0005432231784	64A3C1	5989 033172	DMITRIY GUSEV	{"phone": "+70319124637"}
0005432231785	84D29A	1279 912400	YULIYA SERGEEVA	{"email": "yuliyasergeeva.23031976@postgrespro.ru", "phone": "+70812590660"}
0005432231786	B596C1	2078 728749	POLINA KALININA	{"phone": "+70983954060"}
0005432231787	FE36C4	3387 447292	LEONID KARPOV	{"phone": "+70242647150"}
0005432231788	7B0CF1	9095 592881	MARIYA PETROVA	{"phone": "+70793208529"}
0005432231789	7B0CF1	7602 021169	PAVEL TIMOFEEV	{"phone": "+70005006358"}
0005432231790	7B89C9	9090 334867	GALINA IVANOVA	{"phone": "+70219015524"}
0005432231791	EF32E0	4126 508562	SERGEY MEDVEDEV	{"email": "sergey-medvedev25091975@postgrespro.ru", "phone": "+70462842457"}
0005432231792	EF32E0	6187 190109	ELENA ISAEVA	{"email": "e_isaeva_121981@postgrespro.ru", "phone": "+70970630781"}
0005432231793	B78879	1223 544692	EVGENIY VASILEV	{"phone": "+70130102342"}
0005432231794	F108C1	6526 460390	ELENA FILIPPOVA	{"phone": "+70358524895"}
0005432231795	4E65E4	0272 090713	EVGENIY FROLOV	{"email": "frolov-e_24111976@postgrespro.ru", "phone": "+70481621458"}
0005432231796	3D3CD6	6684 907457	IRINA KAZAKOVA	{"phone": "+70846876590"}
0005432231797	3D3CD6	1636 980309	NATALYA FROLOVA	{"phone": "+70197052442"}
0005432231798	5CFF0C	3308 808262	NATALYA MELNIKOVA	{"phone": "+70105804384"}
0005432231799	5434E9	7095 282135	TATYANA KONDRATEVA	{"email": "kondrateva.t_1979@postgrespro.ru", "phone": "+70618289387"}
0005432231800	5434E9	4294 555360	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-1971@postgrespro.ru", "phone": "+70146840732"}
0005432231801	5434E9	7801 549712	DMITRIY KUZNECOV	{"email": "d_kuznecov.22071965@postgrespro.ru", "phone": "+70842135264"}
0005432231802	20FF6F	8269 030142	ALEKSANDR SHEVCHENKO	{"phone": "+70601175316"}
0005432231803	D92A1B	3108 611514	ANASTASIYA FOMINA	{"phone": "+70798154652"}
0005432231804	5EBDAE	8738 026959	DAMIR KUDRYASHOV	{"phone": "+70125586052"}
0005432231805	C5B8DE	2074 297158	ELIZAVETA BELYAEVA	{"email": "elizaveta.belyaeva.28011973@postgrespro.ru", "phone": "+70477759030"}
0005432231806	D69C41	0657 896676	YURIY FEDOROV	{"phone": "+70267384918"}
0005432231807	EB2912	4590 511987	NIKOLAY GAVRILOV	{"phone": "+70214265879"}
0005432231808	43F98B	0277 700438	LYUDMILA NESTEROVA	{"phone": "+70225511577"}
0005432231809	F6D9D8	5587 238871	EVGENIYA DANILOVA	{"email": "edanilova111982@postgrespro.ru", "phone": "+70292134535"}
0005432231810	F6D9D8	0220 760517	GUZEL OSIPOVA	{"email": "osipova.g-1960@postgrespro.ru", "phone": "+70580825635"}
0005432231811	764764	5061 751246	IRINA ZHUKOVA	{"phone": "+70482241428"}
0005432231812	764764	9835 303524	ANDREY VASILEV	{"email": "andrey_vasilev081956@postgrespro.ru", "phone": "+70853772050"}
0005432231813	A4E80D	7599 797877	NATALYA KOZLOVA	{"email": "natalyakozlova.1969@postgrespro.ru", "phone": "+70522433817"}
0005432231814	531055	4134 118216	RIMMA POTAPOVA	{"email": "r-potapova.05011972@postgrespro.ru", "phone": "+70710465256"}
0005432231815	1CC271	7089 342471	OLGA PETROVA	{"phone": "+70435854648"}
0005432231816	9E3743	3116 172119	ALEKSANDR GAVRILOV	{"email": "gavrilova_1974@postgrespro.ru", "phone": "+70062396820"}
0005432231817	9E3743	7046 140105	ARTUR PETROV	{"email": "apetrov_1978@postgrespro.ru", "phone": "+70222599893"}
0005432231818	7E09B3	1888 441384	IGOR KUZNECOV	{"email": "kuznecov_igor.1972@postgrespro.ru", "phone": "+70123822416"}
0005432231819	7E09B3	2265 089501	SERGEY IVANOV	{"phone": "+70380963726"}
0005432231820	7E09B3	3315 812057	TATYANA MEDVEDEVA	{"email": "medvedeva-tatyana_1977@postgrespro.ru", "phone": "+70934678562"}
0005432231821	F3A7FF	7315 349763	OLGA EGOROVA	{"email": "egorovao.12091978@postgrespro.ru", "phone": "+70848921077"}
0005432231822	0902EB	2689 817725	KSENIYA SEMENOVA	{"phone": "+70481089438"}
0005432231823	0902EB	2727 707838	ROMAN YAKOVLEV	{"email": "roman-yakovlev-121980@postgrespro.ru", "phone": "+70810175059"}
0005432231824	CF531B	8711 702168	ANTONINA VOROBEVA	{"email": "a-vorobeva_041964@postgrespro.ru", "phone": "+70590175567"}
0005432231825	513462	5554 433151	VIKTOR ALEKSEEV	{"phone": "+70163372650"}
0005432231826	513462	5938 250885	VLADIMIR ANTONOV	{"email": "antonov_v.061978@postgrespro.ru", "phone": "+70831234394"}
0005432231827	396FDF	0789 219272	IRINA SIDOROVA	{"email": "sidorova.irina.24031980@postgrespro.ru", "phone": "+70683871839"}
0005432231828	2EA273	0600 294380	MIKHAIL PAVLOV	{"email": "pavlov_mikhail-1974@postgrespro.ru", "phone": "+70950430114"}
0005432231829	22849D	6372 210081	OLGA KAZAKOVA	{"phone": "+70669194039"}
0005432231830	DF67AE	6763 579777	YURIY GRIGOREV	{"email": "grigorev_y.041965@postgrespro.ru", "phone": "+70773223259"}
0005432231831	EC0959	7602 889649	VIKTOR FEDOTOV	{"email": "vfedotov121974@postgrespro.ru", "phone": "+70618019264"}
0005432231832	4C2F3F	0411 856672	ALEKSEY VOLKOV	{"email": "a-volkov.21011970@postgrespro.ru", "phone": "+70184649098"}
0005432235513	E92726	0019 592003	VALENTINA KUZNECOVA	{"phone": "+70765144332"}
0005432231833	4C2F3F	4329 714153	GENNADIY FROLOV	{"email": "frolov_g.1972@postgrespro.ru", "phone": "+70958373919"}
0005432231834	4C2F3F	6937 695497	ALEKSANDR GRIGOREV	{"phone": "+70651746890"}
0005432231835	4C2F3F	8745 645672	ALEKSANDR STEPANOV	{"phone": "+70018549467"}
0005432231836	CD4016	7910 123334	MIKHAIL MEDVEDEV	{"phone": "+70417181005"}
0005432231837	A84103	4086 959876	EVGENIY VOLKOV	{"email": "evgeniy-volkov.051973@postgrespro.ru", "phone": "+70922480816"}
0005432231838	3B07A1	0635 678700	TATYANA IVANOVA	{"phone": "+70156473838"}
0005432231839	3B07A1	3980 206093	ELENA IVANOVA	{"email": "elena-ivanova_091970@postgrespro.ru", "phone": "+70241364344"}
0005432231840	67AEEC	5326 446713	EVGENIY MELNIKOV	{"email": "emelnikov_1966@postgrespro.ru", "phone": "+70761762095"}
0005432231841	2BEFB7	1173 421848	TATYANA IVANOVA	{"phone": "+70021947741"}
0005432231842	EC0069	8706 051891	NATALYA VOROBEVA	{"email": "vorobeva-n-1976@postgrespro.ru", "phone": "+70433660396"}
0005432231843	EC0069	4735 600116	ANATOLIY TARASOV	{"email": "tarasov.a_1974@postgrespro.ru", "phone": "+70560314542"}
0005432231844	354E8A	9508 545101	VALENTINA ZAYCEVA	{"email": "vzayceva-1968@postgrespro.ru", "phone": "+70671895200"}
0005432231845	9C21BE	6824 234066	ALINA SERGEEVA	{"email": "a-sergeeva12051963@postgrespro.ru", "phone": "+70767010079"}
0005432231846	0C1ED9	3523 608054	DARYA KOLESNIKOVA	{"phone": "+70659330327"}
0005432231847	0C1ED9	6209 499679	IRINA KISELEVA	{"phone": "+70129829846"}
0005432231848	196561	1827 045556	ALEKSANDR SOKOLOV	{"phone": "+70126167973"}
0005432231849	F3B330	2081 382051	VIKTOR GUSEV	{"email": "viktor_gusev_1978@postgrespro.ru", "phone": "+70021727863"}
0005432231850	F3B330	9292 551510	VITALIY SMIRNOV	{"email": "v_smirnov_1962@postgrespro.ru", "phone": "+70734979241"}
0005432231851	F3B330	7377 217162	ANATOLIY SERGEEV	{"email": "asergeev-19031981@postgrespro.ru", "phone": "+70004197635"}
0005432231852	9AC161	0822 720123	ZLATA ZAYCEVA	{"phone": "+70797544117"}
0005432231853	9AC161	7992 429431	DMITRIY NIKOLAEV	{"email": "nikolaev_dmitriy_21081973@postgrespro.ru", "phone": "+70691266852"}
0005432231854	22BA12	7321 633574	VIKTOR DAVYDOV	{"phone": "+70519243293"}
0005432231855	22BA12	2882 984821	ANATOLIY SHEVCHENKO	{"email": "a.shevchenko.011972@postgrespro.ru", "phone": "+70009332187"}
0005432231856	DFFB6A	9243 762890	RUSLAN KRASNOV	{"phone": "+70208549827"}
0005432231857	DFFB6A	3326 942781	MAYYA PETROVA	{"email": "petrovam.10121982@postgrespro.ru", "phone": "+70243467120"}
0005432231858	A8DC35	8426 272673	SERGEY STEPANOV	{"email": "sergey.stepanov-1969@postgrespro.ru", "phone": "+70720591251"}
0005432231859	45A442	7457 754676	ALEKSEY DMITRIEV	{"phone": "+70429386700"}
0005432231860	5A2D29	8009 380450	VLADISLAV IVANOV	{"phone": "+70763852658"}
0005432231861	A3E2D7	8541 529916	TAMARA KONOVALOVA	{"email": "t_konovalova-21101971@postgrespro.ru", "phone": "+70494308490"}
0005432231862	A3E2D7	0161 279740	RISHAT KOZLOV	{"phone": "+70445064067"}
0005432231863	A3E2D7	1481 971592	ANNA MIKHAYLOVA	{"email": "a-mikhaylova-22031979@postgrespro.ru", "phone": "+70549084031"}
0005432231864	D61900	2538 134469	VIKTOR PAVLOV	{"email": "vpavlov.1959@postgrespro.ru", "phone": "+70622772717"}
0005432231865	9B95FF	4440 995034	YULIYA BELOVA	{"email": "belova-yuliya_061973@postgrespro.ru", "phone": "+70849182003"}
0005432231866	9B95FF	2964 579885	IGOR MARTYNOV	{"phone": "+70329472724"}
0005432231867	E2B22F	6972 962573	ALEKSANDR KUZMIN	{"email": "akuzmin021968@postgrespro.ru", "phone": "+70760179149"}
0005432231868	E2B22F	5391 787864	TAMARA SOROKINA	{"phone": "+70496071615"}
0005432231869	E2B22F	2923 690221	ANNA ISAEVA	{"email": "anna_isaeva1964@postgrespro.ru", "phone": "+70992779625"}
0005432231870	8D51BA	0435 901877	MARINA VOLKOVA	{"phone": "+70420924311"}
0005432231871	B8BE9A	5588 468256	VLADISLAV MATVEEV	{"phone": "+70167952958"}
0005432231872	BDBE21	0745 877108	VADIM MEDVEDEV	{"email": "medvedev.vadim1978@postgrespro.ru", "phone": "+70828132694"}
0005432231873	BDBE21	8829 510450	OLGA MIRONOVA	{"email": "o.mironova_011973@postgrespro.ru", "phone": "+70524689186"}
0005432231874	BDBE21	3951 833632	OLEG ROMANOV	{"phone": "+70751609023"}
0005432231875	136975	5193 321334	SERGEY MARTYNOV	{"email": "martynov-s-06051972@postgrespro.ru", "phone": "+70857439167"}
0005432231876	871A57	2212 645341	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva-051972@postgrespro.ru", "phone": "+70483521085"}
0005432231877	6C68C9	3782 854553	TAMARA MASLOVA	{"email": "maslovat-081978@postgrespro.ru", "phone": "+70227954569"}
0005432231878	6C68C9	0267 729199	SERGEY TARASOV	{"email": "sergeytarasov26031967@postgrespro.ru", "phone": "+70980711995"}
0005432231879	8F6DEC	5210 511294	ANASTASIYA FROLOVA	{"email": "a_frolova1970@postgrespro.ru", "phone": "+70136300904"}
0005432231880	B78318	1886 905549	ANNA POLYAKOVA	{"email": "polyakovaanna16081964@postgrespro.ru", "phone": "+70875016982"}
0005432231881	B78318	9550 474821	OLGA AFANASEVA	{"email": "olga_afanaseva091974@postgrespro.ru", "phone": "+70959978510"}
0005432235746	235661	9533 832156	LIDIYA KOZLOVA	{"phone": "+70536129720"}
0005432235504	60AD6E	0724 398440	ALLA FROLOVA	{"email": "afrolova-15101970@postgrespro.ru", "phone": "+70975619168"}
0005432235505	CC96FD	2573 002562	ELENA VOROBEVA	{"email": "evorobeva-1979@postgrespro.ru", "phone": "+70598205696"}
0005432235506	CB7E3A	4026 007903	KSENIYA TROFIMOVA	{"email": "trofimova.k-1969@postgrespro.ru", "phone": "+70592486803"}
0005432235507	A48071	2436 747069	VALENTINA SOLOVEVA	{"email": "vsoloveva_17031978@postgrespro.ru", "phone": "+70929915818"}
0005432235508	13E3C8	5648 887368	ANNA SAVELEVA	{"email": "savelevaa_03061973@postgrespro.ru", "phone": "+70254536526"}
0005432235509	13E3C8	5647 048219	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda-021960@postgrespro.ru", "phone": "+70905002785"}
0005432235510	13E3C8	8227 356318	NATALYA KISELEVA	{"phone": "+70790577584"}
0005432235511	5F9298	5603 259650	OKSANA POPOVA	{"phone": "+70249208288"}
0005432235512	5F9298	8560 732575	VLADIMIR KISELEV	{"phone": "+70301914889"}
0005432235514	45C910	8067 087791	VITALIY FEDOROV	{"phone": "+70925821485"}
0005432235515	45C910	4309 611570	VLADIMIR MEDVEDEV	{"email": "medvedev_v.111974@postgrespro.ru", "phone": "+70462911702"}
0005432235516	A06561	7423 593606	VADIM SMIRNOV	{"email": "smirnov_vadim_1981@postgrespro.ru", "phone": "+70924376095"}
0005432235517	01AC31	7659 489239	IVAN MELNIKOV	{"email": "melnikov-i_1969@postgrespro.ru", "phone": "+70058832643"}
0005432235518	F1C2A8	5335 273628	RUSLAN ORLOV	{"email": "ruslanorlov1975@postgrespro.ru", "phone": "+70530395113"}
0005432235519	D2F559	4423 777011	NIKOLAY SERGEEV	{"email": "nikolay_sergeev.1969@postgrespro.ru", "phone": "+70017251690"}
0005432235520	5F840E	8242 381670	GENNADIY NOVIKOV	{"email": "novikov-gennadiy_091975@postgrespro.ru", "phone": "+70747523513"}
0005432235521	5F840E	5957 903191	RUSLAN PAVLOV	{"email": "rpavlov.081971@postgrespro.ru", "phone": "+70685569104"}
0005432235522	77F682	0765 323972	VLADIMIR ILIN	{"email": "ilin.v1981@postgrespro.ru", "phone": "+70495354942"}
0005432235523	451B34	3046 168131	SVETLANA KULIKOVA	{"email": "kulikovasvetlana_04071973@postgrespro.ru", "phone": "+70672797692"}
0005432235524	451B34	6315 554013	ALISA SOKOLOVA	{"email": "alisa-sokolova1970@postgrespro.ru", "phone": "+70769674970"}
0005432235525	D3D902	0405 550608	TAMARA VASILEVA	{"email": "vasilevatamara_111978@postgrespro.ru", "phone": "+70445877898"}
0005432235526	83CD0A	9510 592135	PRASKOVYA IVANOVA	{"email": "pivanova-18021962@postgrespro.ru", "phone": "+70968038395"}
0005432235527	CD18E1	2922 863220	DMITRIY MOROZOV	{"email": "dmorozov.1972@postgrespro.ru", "phone": "+70820482331"}
0005432235528	CD18E1	0259 839997	MIKHAIL AFANASEV	{"phone": "+70884049387"}
0005432235529	CD18E1	4072 876572	IVAN EGOROV	{"phone": "+70173702058"}
0005432235530	5B471C	7080 581990	ROZA POTAPOVA	{"email": "roza-potapova.20011970@postgrespro.ru", "phone": "+70602959995"}
0005432235531	FDBFA1	8791 177816	LARISA NAZAROVA	{"phone": "+70428923559"}
0005432235532	FDBFA1	3953 931489	DANILA GRIGOREV	{"email": "danila.grigorev-15101988@postgrespro.ru", "phone": "+70875416419"}
0005432235533	B6B00A	3700 203260	STANISLAV GRIGOREV	{"email": "sgrigorev_061972@postgrespro.ru", "phone": "+70983199799"}
0005432235534	B6B00A	0818 779891	NADEZHDA DENISOVA	{"phone": "+70383068226"}
0005432235535	28DC3E	6191 513713	ANDREY SOROKIN	{"phone": "+70908398160"}
0005432235536	28DC3E	8880 142604	VLADIMIR ZHUKOV	{"email": "zhukovv-07081960@postgrespro.ru", "phone": "+70332336611"}
0005432235537	DACCD1	6420 051478	VLADIMIR ANDREEV	{"email": "vladimir.andreev_071976@postgrespro.ru", "phone": "+70212620542"}
0005432235538	D2B404	6635 170859	SERGEY GAVRILOV	{"phone": "+70281380635"}
0005432235539	050DC5	9885 305323	LYUBOV VOLKOVA	{"phone": "+70040829218"}
0005432235540	76A321	2931 918367	EVGENIY KONOVALOV	{"email": "e.konovalov_071985@postgrespro.ru", "phone": "+70868974350"}
0005432235541	462682	2014 236137	YULIYA PAVLOVA	{"phone": "+70456794563"}
0005432235542	55E3C2	2886 129239	NELYA ZHUKOVA	{"email": "nzhukova1957@postgrespro.ru", "phone": "+70218899138"}
0005432235543	55E3C2	6840 250017	OLEG KISELEV	{"email": "okiselev_19041959@postgrespro.ru", "phone": "+70929136995"}
0005432235544	B14BD2	9264 723574	VALENTINA NIKIFOROVA	{"phone": "+70439493989"}
0005432235545	09A223	5162 747982	IRINA POTAPOVA	{"email": "potapovairina.17111972@postgrespro.ru", "phone": "+70975943950"}
0005432235546	A70D98	7229 748498	KONSTANTIN KUZMIN	{"phone": "+70578497461"}
0005432235547	A70D98	1793 680554	ALEKSEY POPOV	{"email": "popov-a-1978@postgrespro.ru", "phone": "+70610392817"}
0005432235548	55D895	9015 634693	MARGARITA KUZNECOVA	{"phone": "+70002650385"}
0005432235549	55D895	1449 376336	LIDIYA KUZNECOVA	{"phone": "+70840797219"}
0005432235550	FDAFED	0854 872268	IGOR ZAKHAROV	{"email": "zakharov_igor-12041975@postgrespro.ru", "phone": "+70337297143"}
0005432235551	FDAFED	9646 719704	IRINA FILATOVA	{"email": "filatova-irina.24091979@postgrespro.ru", "phone": "+70636186219"}
0005432235552	7BF825	0549 731106	ANDREY ILIN	{"email": "a-ilin-031974@postgrespro.ru", "phone": "+70649067124"}
0005432235553	086052	3912 331175	GALINA VOLKOVA	{"email": "volkova.g.1985@postgrespro.ru", "phone": "+70362821212"}
0005432235554	1F13C3	9663 274628	IGOR GRIGOREV	{"email": "grigorev.igor.29101969@postgrespro.ru", "phone": "+70493819077"}
0005432235555	97C9D8	2102 123042	VLADIMIR PETROV	{"email": "petrov-v-1969@postgrespro.ru", "phone": "+70121957341"}
0005432235556	334FFD	5954 178591	ALEKSANDR KISELEV	{"phone": "+70214227738"}
0005432235557	334FFD	8487 608010	VLADIMIR FILIPPOV	{"email": "filippovv.28121975@postgrespro.ru", "phone": "+70767876820"}
0005432235558	84F2D0	5918 827080	NINA BORISOVA	{"phone": "+70847976897"}
0005432235559	84F2D0	2856 416950	ANASTASIYA DANILOVA	{"phone": "+70842405085"}
0005432235560	0465CF	1365 375373	VALERIY SAVELEV	{"email": "v_savelev_11061971@postgrespro.ru", "phone": "+70521640829"}
0005432235561	9B0349	4602 772228	PAVEL SCHERBAKOV	{"phone": "+70554321537"}
0005432235562	9B0349	1501 673840	ALEKSEY SMIRNOV	{"phone": "+70874812595"}
0005432235563	02416D	4101 086187	EKATERINA CHERNOVA	{"email": "chernova.ekaterina-14111980@postgrespro.ru", "phone": "+70324421917"}
0005432235564	02416D	2764 676827	NIKOLAY ROMANOV	{"email": "romanov.n.21091966@postgrespro.ru", "phone": "+70993338944"}
0005432235565	F64FD1	0470 207422	NIKOLAY IVANOV	{"email": "ivanovn04121965@postgrespro.ru", "phone": "+70100671070"}
0005432235566	F64FD1	9598 718759	SERGEY FROLOV	{"email": "sergey.frolov_041973@postgrespro.ru", "phone": "+70448816839"}
0005432235567	76AA21	8700 736234	GENNADIY EGOROV	{"phone": "+70683245024"}
0005432235568	3A913B	0388 945792	NATALYA RYABOVA	{"email": "ryabova.n.091979@postgrespro.ru", "phone": "+70087582176"}
0005432235569	DE5891	0056 403247	YURIY MAKAROV	{"phone": "+70670294318"}
0005432235570	DE5891	2578 205695	NIKOLAY ZAKHAROV	{"phone": "+70107139213"}
0005432235571	6AC8AD	6223 452319	LYUBOV ZHURAVLEVA	{"email": "zhuravleva.lyubov-031977@postgrespro.ru", "phone": "+70920141864"}
0005432235572	9AA4A1	4831 859743	VERA GUSEVA	{"email": "guseva.v.071978@postgrespro.ru", "phone": "+70281110455"}
0005432235573	EBC4C0	2439 317909	LIDIYA KARPOVA	{"phone": "+70692439688"}
0005432235574	0A878B	3472 268095	LIDIYA KOROLEVA	{"email": "koroleva-lidiya1974@postgrespro.ru", "phone": "+70236164519"}
0005432235575	0A878B	9829 013608	MARINA ANISIMOVA	{"email": "marina.anisimova_05021976@postgrespro.ru", "phone": "+70553541609"}
0005432235576	B9DF89	2755 781148	OLGA SERGEEVA	{"email": "olga_sergeeva-30011968@postgrespro.ru", "phone": "+70430770089"}
0005432235577	277C68	7214 358804	SVETLANA KISELEVA	{"email": "kiseleva.svetlana02031962@postgrespro.ru", "phone": "+70372407804"}
0005432235578	5CE195	8351 302098	EVDOKIYA ANDREEVA	{"email": "evdokiya_andreeva_24121967@postgrespro.ru", "phone": "+70024988493"}
0005432235579	7485F4	3162 853449	SERGEY ALEKSANDROV	{"phone": "+70131882542"}
0005432235580	7485F4	4671 514227	ANNA SIDOROVA	{"email": "annasidorova-1974@postgrespro.ru", "phone": "+70145248935"}
0005432235581	BA8077	7054 824705	ZINAIDA GAVRILOVA	{"email": "gavrilovazinaida-24061972@postgrespro.ru", "phone": "+70067070159"}
0005432235582	BA8077	7269 073373	YULIYA BARANOVA	{"phone": "+70605200822"}
0005432235583	BA0F0C	9418 918771	ANASTASIYA VOLKOVA	{"email": "volkova-anastasiya_121978@postgrespro.ru", "phone": "+70607573570"}
0005432235584	ABACF6	5040 372360	IVAN VLASOV	{"phone": "+70174641540"}
0005432235585	699D93	4020 808934	SERGEY EGOROV	{"email": "sergeyegorov-07071974@postgrespro.ru", "phone": "+70055956423"}
0005432235586	C58249	8894 494613	VALENTINA VASILEVA	{"email": "vasileva_valentina-18011977@postgrespro.ru", "phone": "+70398106916"}
0005432235587	C7D01C	8666 336900	OLGA POPOVA	{"phone": "+70060516739"}
0005432235588	C7D01C	2207 863290	ARTUR CHERNOV	{"email": "a_chernov11091971@postgrespro.ru", "phone": "+70990924025"}
0005432235589	EB66A5	1821 357440	GALINA ZAYCEVA	{"email": "zayceva.galina25051970@postgrespro.ru", "phone": "+70919533081"}
0005432235590	AD9193	7745 836714	NADEZHDA PETROVA	{"email": "petrova_nadezhda.15051984@postgrespro.ru", "phone": "+70346681030"}
0005432235591	AD9193	7831 109392	IRINA GORBUNOVA	{"phone": "+70298315923"}
0005432235592	58D072	7537 382913	SVETLANA RYABOVA	{"email": "s.ryabova-1958@postgrespro.ru", "phone": "+70855350992"}
0005432235593	5D663B	9235 539375	ALEKSEY IVANOV	{"email": "a-ivanov.1975@postgrespro.ru", "phone": "+70338035500"}
0005432235594	13BC23	5046 643909	PAVEL IVANOV	{"phone": "+70891459587"}
0005432235595	C47CF3	7470 808377	ELENA SOROKINA	{"email": "sorokina-e.26021970@postgrespro.ru", "phone": "+70263283185"}
0005432235596	13376E	1488 650590	GALINA PAVLOVA	{"phone": "+70684751523"}
0005432235597	0A1F87	9387 682590	OLGA KOMAROVA	{"phone": "+70099635911"}
0005432235598	0A1F87	8239 850003	VERA KOLESNIKOVA	{"phone": "+70171156048"}
0005432235599	B8C497	1535 381404	SVETLANA NIKITINA	{"email": "nikitina-s.1967@postgrespro.ru", "phone": "+70234030474"}
0005432235600	5DE598	7326 721609	NATALIYA GERASIMOVA	{"email": "n_gerasimova_13101973@postgrespro.ru", "phone": "+70684286919"}
0005432235601	B36AFC	1587 614783	ALEKSANDR NIKOLAEV	{"phone": "+70461653929"}
0005432235602	3E4520	2822 186560	ANASTASIYA STEPANOVA	{"email": "anastasiya_stepanova1980@postgrespro.ru", "phone": "+70726440620"}
0005432235603	BB1024	9708 016419	NATALYA KUZNECOVA	{"phone": "+70233453277"}
0005432235604	E7EE72	2260 213435	ELENA BELYAEVA	{"email": "belyaeva.elena1972@postgrespro.ru", "phone": "+70990977376"}
0005432235605	E7EE72	2887 084611	NIKITA KARPOV	{"phone": "+70591556660"}
0005432235606	E71BE4	8086 904704	LYUDMILA POPOVA	{"phone": "+70810092777"}
0005432235607	B02C0B	5571 944156	ALENA SOROKINA	{"phone": "+70182725502"}
0005432235608	B02C0B	5319 267873	ALEKSANDR KRASNOV	{"email": "a-krasnov_02031967@postgrespro.ru", "phone": "+70948580499"}
0005432235609	F154FB	7925 469022	SVETLANA KISELEVA	{"email": "kiseleva_s_121966@postgrespro.ru", "phone": "+70459332684"}
0005432235610	9F0151	4723 457380	YURIY FEDOROV	{"phone": "+70924405304"}
0005432235611	C6D42B	2988 045285	MARINA ZAKHAROVA	{"email": "zakharovamarina13061979@postgrespro.ru", "phone": "+70720496300"}
0005432235612	7515C3	4762 843822	KONSTANTIN KOZLOV	{"email": "k.kozlov-07041970@postgrespro.ru", "phone": "+70227671160"}
0005432235613	672020	5596 549710	SVETLANA TARASOVA	{"phone": "+70254436425"}
0005432235614	672020	5139 571642	VENIAMIN SMIRNOV	{"email": "smirnovv-071977@postgrespro.ru", "phone": "+70948184007"}
0005432235615	B429D9	8081 112527	GALINA BELYAEVA	{"email": "belyaeva.g.03031966@postgrespro.ru", "phone": "+70600485325"}
0005432235616	717048	2460 812221	VALENTINA NIKITINA	{"email": "v_nikitina.1972@postgrespro.ru", "phone": "+70852530333"}
0005432235617	717048	7756 105475	MARIYA FROLOVA	{"phone": "+70291954714"}
0005432235618	A11787	8232 016023	ALEKSANDR ORLOV	{"email": "orlov_a_03081983@postgrespro.ru", "phone": "+70989889319"}
0005432235619	B1B2BF	5593 950629	OLGA DMITRIEVA	{"phone": "+70740100293"}
0005432235620	B1B2BF	7106 086672	MATVEY KAZAKOV	{"email": "kazakovm1973@postgrespro.ru", "phone": "+70101370844"}
0005432235621	DFE9CA	5973 133792	IRINA PAVLOVA	{"email": "i_pavlova.21051984@postgrespro.ru", "phone": "+70121271852"}
0005432235622	2D5AA6	6687 796952	VLADISLAV MAKAROV	{"email": "vladislavmakarov1964@postgrespro.ru", "phone": "+70722332491"}
0005432235623	E50078	0898 919700	MARGARITA KUZNECOVA	{"phone": "+70322297163"}
0005432235624	A6C639	4129 277353	VALENTINA ALEKSANDROVA	{"email": "aleksandrova_v-081970@postgrespro.ru", "phone": "+70637841994"}
0005432235625	A6C639	0285 229543	MIKHAIL KUZNECOV	{"email": "m-kuznecov-12121974@postgrespro.ru", "phone": "+70306909439"}
0005432235626	E79468	8762 956936	IRINA OVCHINNIKOVA	{"email": "irinaovchinnikova-011980@postgrespro.ru", "phone": "+70485884366"}
0005432235627	7DF3AE	6062 053278	ANASTASIYA KONOVALOVA	{"phone": "+70994466594"}
0005432235628	E3A6A4	0661 438527	VASILIY IVANOV	{"email": "ivanovvasiliy_04121968@postgrespro.ru", "phone": "+70146379085"}
0005432235805	C0ABB7	8870 276713	EVDOKIYA VASILEVA	{"phone": "+70618325630"}
0005432235629	B5F9FE	7224 525439	VIKTORIYA SERGEEVA	{"email": "sergeeva.v031980@postgrespro.ru", "phone": "+70216866331"}
0005432235630	B5F9FE	1910 195456	NATALYA SMIRNOVA	{"email": "n_smirnova1979@postgrespro.ru", "phone": "+70918500900"}
0005432235631	FC326E	2089 125323	RINAT FROLOV	{"email": "frolov.r_121981@postgrespro.ru", "phone": "+70327644327"}
0005432235632	FC326E	1485 972869	GALINA KOZLOVA	{"email": "g-kozlova-011969@postgrespro.ru", "phone": "+70992056386"}
0005432235633	D547FF	6720 591694	VITALIY SMIRNOV	{"phone": "+70859998123"}
0005432235634	D547FF	5469 376136	VERONIKA SMIRNOVA	{"phone": "+70156973773"}
0005432235635	7428B8	9813 373056	YURIY TIKHONOV	{"email": "tikhonov.yuriy.041968@postgrespro.ru", "phone": "+70962102045"}
0005432235636	498F79	6515 110472	OLGA CHERNOVA	{"phone": "+70103163734"}
0005432235637	498F79	0112 940848	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana.11011980@postgrespro.ru", "phone": "+70412857450"}
0005432235638	D467FB	8319 242742	ANNA PAVLOVA	{"email": "anna-pavlova-29091982@postgrespro.ru", "phone": "+70187333892"}
0005432235639	87C3AA	7041 379647	ANATOLIY ANTONOV	{"email": "anatoliy.antonov20061982@postgrespro.ru", "phone": "+70368179833"}
0005432235640	392CA5	7423 476669	EDUARD NAUMOV	{"email": "naumoveduard-16061971@postgrespro.ru", "phone": "+70642536236"}
0005432235641	FFDCEE	7901 525650	GALIYA IVANOVA	{"email": "galiya-ivanova_071981@postgrespro.ru", "phone": "+70824025251"}
0005432235642	D2F866	4983 662170	VALERIY VOROBEV	{"phone": "+70910226435"}
0005432235643	FEC72A	8291 723133	OLGA ALEKSANDROVA	{"email": "o.aleksandrova-031968@postgrespro.ru", "phone": "+70321490274"}
0005432235644	806785	5313 418129	ELENA KOROLEVA	{"phone": "+70504666668"}
0005432235645	806785	0038 747833	VASILIY KUDRYASHOV	{"phone": "+70362690664"}
0005432235646	4656E4	3356 028383	ALLA KOZLOVA	{"phone": "+70448953107"}
0005432235647	0878FF	7461 517881	YURIY GUSEV	{"phone": "+70989790552"}
0005432235648	2B9A8F	8373 739071	MIKHAIL SERGEEV	{"phone": "+70738244692"}
0005432235649	A132A0	9931 767062	NIKITA ORLOV	{"phone": "+70436500757"}
0005432235650	A132A0	6237 100277	MARGARITA MIKHAYLOVA	{"email": "m.mikhaylova-03031972@postgrespro.ru", "phone": "+70350939348"}
0005432235651	A132A0	2342 185955	IGOR GRIGOREV	{"email": "grigorev-igor1969@postgrespro.ru", "phone": "+70542591405"}
0005432235652	4E15E5	0063 825901	SERGEY POPOV	{"email": "popov_s.1961@postgrespro.ru", "phone": "+70202239093"}
0005432235653	4E15E5	5683 558879	KRISTINA MATVEEVA	{"phone": "+70326831423"}
0005432235654	B94C93	8162 933563	OLGA KUZNECOVA	{"email": "olga_kuznecova-071972@postgrespro.ru", "phone": "+70024282004"}
0005432235655	B94C93	6810 389123	ELENA DENISOVA	{"email": "denisovaelena14041962@postgrespro.ru", "phone": "+70070003273"}
0005432235656	B712CD	0187 906486	TATYANA SOROKINA	{"email": "tatyana-sorokina-09121974@postgrespro.ru", "phone": "+70090119185"}
0005432235657	1277B3	3147 915137	EVGENIY KULIKOV	{"email": "kulikov.evgeniy-1991@postgrespro.ru", "phone": "+70236055360"}
0005432235658	30959D	4906 031528	VERA ZAKHAROVA	{"phone": "+70082465373"}
0005432235659	68CF95	2671 706657	SHAVKAT TIMOFEEV	{"email": "timofeev_shavkat1974@postgrespro.ru", "phone": "+70103187105"}
0005432235660	68CF95	0294 864405	STANISLAV GERASIMOV	{"email": "gerasimovstanislav.11051974@postgrespro.ru", "phone": "+70683842231"}
0005432235661	68CF95	2806 623449	GALINA KUZNECOVA	{"email": "kuznecova-galina1971@postgrespro.ru", "phone": "+70357404159"}
0005432235662	9EECAB	4633 477367	ANASTASIYA EFIMOVA	{"phone": "+70440856750"}
0005432235663	9EECAB	7834 629636	SERGEY SHEVCHENKO	{"email": "sshevchenko1989@postgrespro.ru", "phone": "+70662035225"}
0005432235664	758DD0	3208 074726	DARYA POPOVA	{"email": "darya_popova101975@postgrespro.ru", "phone": "+70994977116"}
0005432235665	947EB4	3396 694713	YURIY VLASOV	{"phone": "+70911492151"}
0005432235666	821760	3089 525122	GRIGORIY FOMIN	{"email": "fomin_g01011967@postgrespro.ru", "phone": "+70510718867"}
0005432235667	821760	5700 587208	RAISA GAVRILOVA	{"email": "gavrilova.raisa-091968@postgrespro.ru", "phone": "+70829660213"}
0005432235668	821760	1002 910282	EVDOKIYA ERMAKOVA	{"phone": "+70605782210"}
0005432235669	B8D022	6488 353103	DENIS KUZMIN	{"email": "d.kuzmin-03101968@postgrespro.ru", "phone": "+70210258147"}
0005432235670	9C0551	6710 259065	NINA SOKOLOVA	{"phone": "+70238638320"}
0005432235671	9C0551	0419 207236	LYUBOV KOZLOVA	{"phone": "+70519766833"}
0005432235672	C7FD66	1085 591409	ALEKSEY MELNIKOV	{"email": "melnikov.a.1979@postgrespro.ru", "phone": "+70354831039"}
0005432235673	4A809E	2184 513429	ANNA VASILEVA	{"email": "vasileva_anna-051969@postgrespro.ru", "phone": "+70728985516"}
0005432235674	A8695F	1464 494666	VYACHESLAV BORISOV	{"email": "vyacheslavborisov.1969@postgrespro.ru", "phone": "+70386489547"}
0005432235675	60C31D	5621 480435	MARIYA STEPANOVA	{"email": "stepanova.mariya.1982@postgrespro.ru", "phone": "+70263164170"}
0005432235676	60C31D	8006 262121	IRINA GERASIMOVA	{"email": "gerasimova_irina04031981@postgrespro.ru", "phone": "+70028175403"}
0005432235677	1FF36D	5527 340397	MARIYA OVCHINNIKOVA	{"email": "mariya_ovchinnikova07081968@postgrespro.ru", "phone": "+70511548768"}
0005432235678	5E0915	7915 760766	VLADISLAV IVANOV	{"phone": "+70962001842"}
0005432235679	714B4F	6198 638975	PAVEL PAVLOV	{"phone": "+70442153216"}
0005432235680	7823F4	2155 824019	ARTEM SOKOLOV	{"email": "sokolov_artem.24011973@postgrespro.ru", "phone": "+70094732928"}
0005432235681	62D843	6207 529665	NINA ABRAMOVA	{"phone": "+70723119754"}
0005432235682	ECF92B	0867 035244	GALINA ZAKHAROVA	{"phone": "+70546070296"}
0005432235683	52DC02	8044 963127	OLEG GERASIMOV	{"email": "o-gerasimov_1966@postgrespro.ru", "phone": "+70154000550"}
0005432235684	809257	0923 906525	ARTEM KUZNECOV	{"email": "kuznecov-artem.1972@postgrespro.ru", "phone": "+70510738078"}
0005432235685	3E0A7E	3096 742928	EVGENIY POPOV	{"phone": "+70937068096"}
0005432235686	5F463E	2174 837174	NAIL PAVLOV	{"phone": "+70086546174"}
0005432235687	7264A7	2077 193368	SVETLANA MARTYNOVA	{"email": "martynova.svetlana_14061976@postgrespro.ru", "phone": "+70700090312"}
0005432235688	18C308	6884 455225	ALEKSEY NIKITIN	{"email": "a-nikitin.27111982@postgrespro.ru", "phone": "+70805283565"}
0005432235689	FB3BCD	0276 042265	OLEG ZAKHAROV	{"email": "ozakharov.1971@postgrespro.ru", "phone": "+70005534952"}
0005432235690	FB3BCD	6937 180807	SERGEY ISAEV	{"email": "isaev_sergey_121966@postgrespro.ru", "phone": "+70496120359"}
0005432235691	4332D9	4039 569752	ALEKSEY VASILEV	{"email": "vasilev-a-031977@postgrespro.ru", "phone": "+70547333991"}
0005432235692	517082	2585 658011	GENNADIY STEPANOV	{"phone": "+70967079096"}
0005432235693	517082	9481 883000	VLADIMIR NAZAROV	{"phone": "+70174692966"}
0005432235694	2B1F05	5235 109911	NIKITA IVANOV	{"email": "ivanov_n.021974@postgrespro.ru", "phone": "+70709486620"}
0005432235695	2B1F05	3995 845590	NINA GERASIMOVA	{"phone": "+70258012563"}
0005432235696	2B1F05	3288 136209	NATALYA PETROVA	{"email": "petrovan-31101978@postgrespro.ru", "phone": "+70205898321"}
0005432235697	21DEE8	0517 404811	ANZHELIKA TIKHONOVA	{"email": "tikhonova_a.061980@postgrespro.ru", "phone": "+70042636502"}
0005432235698	21DEE8	9773 754048	STANISLAV TARASOV	{"phone": "+70423005057"}
0005432235699	7E06D2	6532 618030	ANNA POPOVA	{"phone": "+70229870182"}
0005432235700	FA7746	2196 222034	ALSU DMITRIEVA	{"email": "alsu.dmitrieva.23041975@postgrespro.ru", "phone": "+70725768705"}
0005432235701	FA7746	4611 925670	YURIY KUZNECOV	{"email": "kuznecov_yuriy-051972@postgrespro.ru", "phone": "+70007676498"}
0005432235702	B0CCFA	3926 438991	OLEG PAVLOV	{"phone": "+70210626713"}
0005432235703	4D2AF4	6391 119895	NATALYA FILIPPOVA	{"phone": "+70198576128"}
0005432235704	6CFF9C	6250 725997	KARINA YUDINA	{"phone": "+70114987938"}
0005432235705	269655	7187 824749	NIKOLAY KUZMIN	{"email": "nikolay.kuzmin_1970@postgrespro.ru", "phone": "+70029311442"}
0005432235706	B9670D	8274 982505	IRINA BARANOVA	{"phone": "+70251676593"}
0005432235707	B9670D	4728 954990	VALENTINA ILINA	{"phone": "+70024232612"}
0005432235708	8C0B63	9913 249544	TATYANA KISELEVA	{"phone": "+70090097876"}
0005432235709	8C0B63	3718 377831	OLGA MEDVEDEVA	{"email": "medvedeva-o081978@postgrespro.ru", "phone": "+70399762144"}
0005432235710	8C0B63	1532 060728	VYACHESLAV PAVLOV	{"phone": "+70005916062"}
0005432235711	8C0B63	8555 147352	VIKTOR OSIPOV	{"email": "vosipov_27121971@postgrespro.ru", "phone": "+70731779542"}
0005432235712	E47D10	3503 481317	MATVEY SCHERBAKOV	{"phone": "+70679227230"}
0005432235713	C85125	3997 978350	IRINA DENISOVA	{"email": "irina-denisova_02041979@postgrespro.ru", "phone": "+70838566377"}
0005432235714	C85125	5216 046716	TATYANA ZAKHAROVA	{"email": "zakharovatatyana-28071972@postgrespro.ru", "phone": "+70120026599"}
0005432235715	C85125	5780 232340	OLEG SOLOVEV	{"email": "o_solovev_30101968@postgrespro.ru", "phone": "+70711963006"}
0005432235716	FFAB86	0234 876225	ALEKSEY MARTYNOV	{"email": "martynovaleksey.1963@postgrespro.ru", "phone": "+70900538921"}
0005432235717	FFAB86	4668 199780	VLADIMIR ABRAMOV	{"email": "abramov-vladimir.021983@postgrespro.ru", "phone": "+70625084910"}
0005432235718	CE9958	7124 011465	DANIS BORISOV	{"phone": "+70989055044"}
0005432235719	CE9958	0757 339342	LYUDMILA MEDVEDEVA	{"email": "medvedeva-lyudmila04111981@postgrespro.ru", "phone": "+70061297235"}
0005432235720	54F2AF	8830 189808	ARTEM PETROV	{"email": "artem_petrov-1967@postgrespro.ru", "phone": "+70532067409"}
0005432235721	B96849	2250 570938	EVGENIY ANTONOV	{"phone": "+70611227544"}
0005432235722	928F40	7872 948732	OLESYA ZAYCEVA	{"phone": "+70066436566"}
0005432235723	BB1234	0776 233156	SVETLANA MALYSHEVA	{"phone": "+70498821921"}
0005432235724	A476BA	2920 454109	ANDREY VOLKOV	{"email": "andrey_volkov.031962@postgrespro.ru", "phone": "+70008010713"}
0005432235725	02F708	1713 697738	ALEKSANDR IVANOV	{"phone": "+70396653412"}
0005432235726	02F708	5269 475577	LIDIYA GORBUNOVA	{"email": "gorbunova.lidiya_16051971@postgrespro.ru", "phone": "+70594730526"}
0005432235727	7E441D	6683 371792	TAMARA MOROZOVA	{"email": "morozovat.1963@postgrespro.ru", "phone": "+70389317802"}
0005432235728	56D20B	0130 619404	GALINA BELOVA	{"phone": "+70571645328"}
0005432235729	D3959D	3023 513851	IVAN BORISOV	{"email": "borisov.i1973@postgrespro.ru", "phone": "+70120055213"}
0005432235730	AC643D	4075 224608	DMITRIY SEMENOV	{"phone": "+70686961203"}
0005432235731	D54957	1636 015103	ALEKSANDR ANDREEV	{"phone": "+70359375058"}
0005432235732	D54957	2077 111029	EKATERINA STEPANOVA	{"email": "stepanova_e1974@postgrespro.ru", "phone": "+70067545082"}
0005432235733	98EB8C	4999 734715	KIRILL SIDOROV	{"email": "k.sidorov_051958@postgrespro.ru", "phone": "+70000192250"}
0005432235734	98EB8C	3137 398397	MARAT SERGEEV	{"phone": "+70191336018"}
0005432235735	98EB8C	6426 401300	ZHANNA BORISOVA	{"email": "borisova.zhanna.1970@postgrespro.ru", "phone": "+70639233731"}
0005432235736	D08411	6131 235002	DANIIL NOVIKOV	{"email": "d-novikov-1976@postgrespro.ru", "phone": "+70676250935"}
0005432235737	D44B6A	1269 471090	VERONIKA FROLOVA	{"email": "frolovav_101978@postgrespro.ru", "phone": "+70417203762"}
0005432235738	387F89	4338 998584	VITALIY PAVLOV	{"email": "pavlov_vitaliy.06111967@postgrespro.ru", "phone": "+70389039098"}
0005432235739	563FF5	6400 677922	DMITRIY POPOV	{"phone": "+70550275567"}
0005432235740	563FF5	5811 881259	ROZA VASILEVA	{"phone": "+70046859789"}
0005432235741	E635D9	0106 644677	SERGEY ABRAMOV	{"email": "s-abramov-061973@postgrespro.ru", "phone": "+70950733628"}
0005432235742	D39805	0098 951965	TATYANA SEMENOVA	{"email": "semenovatatyana.1971@postgrespro.ru", "phone": "+70904570590"}
0005432235743	F16C9D	7545 419112	ELENA NIKITINA	{"phone": "+70408867211"}
0005432235744	00FD0A	8629 085977	IRINA MOROZOVA	{"email": "morozovai031976@postgrespro.ru", "phone": "+70679694937"}
0005432235745	235661	8855 959266	GEORGIY FEDOTOV	{"phone": "+70811860186"}
0005432235747	D7E0BB	5887 526775	LYUDMILA SOROKINA	{"email": "lyudmila-sorokina-031978@postgrespro.ru", "phone": "+70162200308"}
0005432235748	D7E0BB	6155 782214	VALERIY GAVRILOV	{"phone": "+70779356720"}
0005432235749	C89BEF	6587 406904	MAKSIM MEDVEDEV	{"email": "m.medvedev_01121975@postgrespro.ru", "phone": "+70150482700"}
0005432235750	AB0F77	1378 640698	ELIZAVETA ZAKHAROVA	{"phone": "+70976566348"}
0005432235751	D3542D	5187 088121	NURLAN GERASIMOV	{"phone": "+70214035841"}
0005432235752	B58AFF	2170 235071	IGOR STEPANOV	{"email": "stepanov.i_29011967@postgrespro.ru", "phone": "+70415809895"}
0005432235753	C4C76C	8488 769975	VLADIMIR YAKOVLEV	{"email": "vladimir.yakovlev-1973@postgrespro.ru", "phone": "+70801748345"}
0005432235754	C1BE65	7929 568940	ALEKSANDR NOVIKOV	{"phone": "+70141838565"}
0005432235755	C1BE65	8113 523214	OLGA KONDRATEVA	{"phone": "+70096559671"}
0005432235756	8232D7	9938 299139	ZINAIDA GORBUNOVA	{"email": "gorbunova_z1971@postgrespro.ru", "phone": "+70227417656"}
0005432235757	12A4FD	8777 571021	ANDREY SOROKIN	{"email": "sorokin_andrey_1974@postgrespro.ru", "phone": "+70263241257"}
0005432235758	D16056	0742 682001	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov1965@postgrespro.ru", "phone": "+70609784648"}
0005432235759	D16056	8782 793216	NADEZHDA MATVEEVA	{"email": "nmatveeva_07091961@postgrespro.ru", "phone": "+70593262266"}
0005432235760	7C1179	2573 365309	VIKTOR GUSEV	{"phone": "+70290956034"}
0005432235761	9EEC73	3756 653289	YURIY FILIPPOV	{"phone": "+70384119165"}
0005432235762	87A892	6889 350097	LYUDMILA LOGINOVA	{"email": "lyudmila-loginova-1978@postgrespro.ru", "phone": "+70411052932"}
0005432235763	87A892	8815 039159	NIKOLAY ZAKHAROV	{"phone": "+70351358472"}
0005432235764	F3C943	3231 065124	MARIYA OVCHINNIKOVA	{"email": "ovchinnikovamariya19111978@postgrespro.ru", "phone": "+70872723693"}
0005432235765	47F4BE	3353 866667	ALEKSANDR PETROV	{"phone": "+70293215707"}
0005432235766	A8C200	8450 751927	VALENTINA SCHERBAKOVA	{"phone": "+70677507992"}
0005432235767	E5F2EC	4959 000264	ALEKSANDR DENISOV	{"email": "aleksandr.denisov111975@postgrespro.ru", "phone": "+70178898560"}
0005432235768	3E81E9	6165 448838	ALEKSANDR ROMANOV	{"phone": "+70190156149"}
0005432235769	3E81E9	9542 822834	SVETLANA VASILEVA	{"email": "svasileva-06081980@postgrespro.ru", "phone": "+70128347530"}
0005432235770	332007	5887 885120	ALEKSANDR MATVEEV	{"phone": "+70918185597"}
0005432235771	332007	6518 970701	VLADIMIR ZAYCEV	{"phone": "+70476523438"}
0005432235772	332007	9170 665775	EKATERINA POPOVA	{"phone": "+70998806216"}
0005432235773	4494A0	7469 629466	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey.101979@postgrespro.ru", "phone": "+70046344051"}
0005432235774	4494A0	7195 799550	NATALYA NOVIKOVA	{"email": "n-novikova-29091979@postgrespro.ru", "phone": "+70593028538"}
0005432235775	259F6B	8263 139403	LIDIYA MARTYNOVA	{"email": "martynova.lidiya-19011975@postgrespro.ru", "phone": "+70393481104"}
0005432235776	259F6B	9640 923987	DAMIR ISAEV	{"email": "isaev.damir-02021968@postgrespro.ru", "phone": "+70137622404"}
0005432235777	259F6B	2050 666524	GALINA ARKHIPOVA	{"email": "arkhipovag26081975@postgrespro.ru", "phone": "+70684517513"}
0005432235778	233F68	7985 478841	GALINA NIKIFOROVA	{"phone": "+70517689065"}
0005432235779	233F68	1150 659943	ZINAIDA MAKSIMOVA	{"phone": "+70315980329"}
0005432235780	90768D	4525 211715	ANATOLIY MARTYNOV	{"phone": "+70471850941"}
0005432235781	24BE57	4137 585305	ANDREY STEPANOV	{"email": "stepanovandrey-28121972@postgrespro.ru", "phone": "+70780985702"}
0005432235782	B37464	7202 448875	VALERIY DAVYDOV	{"email": "valeriy.davydov1973@postgrespro.ru", "phone": "+70775476909"}
0005432235783	B37464	1040 203821	GALINA EFREMOVA	{"phone": "+70794123781"}
0005432235784	3060C6	1102 785560	VLADIMIR NIKOLAEV	{"email": "nikolaev.v-061968@postgrespro.ru", "phone": "+70412879820"}
0005432235785	81AF7E	2110 856915	LYUDMILA ZAYCEVA	{"email": "l_zayceva.26111971@postgrespro.ru", "phone": "+70857108770"}
0005432235786	F42938	4320 987572	SVETLANA LUKYANOVA	{"email": "svetlana.lukyanova_061977@postgrespro.ru", "phone": "+70871322254"}
0005432235787	F42938	7132 743662	STANISLAV KUDRYASHOV	{"phone": "+70539461768"}
0005432235788	F42938	3947 540521	ALEKSANDR IVANOV	{"email": "a-ivanov_03091985@postgrespro.ru", "phone": "+70409341602"}
0005432235789	5A500B	9058 235104	KLAVDIYA DMITRIEVA	{"email": "kdmitrieva021975@postgrespro.ru", "phone": "+70287908612"}
0005432235790	BFD789	3460 340910	SERGEY PAVLOV	{"phone": "+70682614955"}
0005432235791	98ED66	9533 705293	VLADISLAV ZAKHAROV	{"email": "v_zakharov_28021972@postgrespro.ru", "phone": "+70232202044"}
0005432235792	A9D9EE	4954 731065	MILENA AKIMOVA	{"email": "makimova1978@postgrespro.ru", "phone": "+70979007526"}
0005432235793	A9D9EE	8003 666839	DMITRIY ROMANOV	{"phone": "+70718367947"}
0005432235794	A9D9EE	5023 813493	KARINA LOGINOVA	{"email": "karina_loginova-111981@postgrespro.ru", "phone": "+70675627553"}
0005432235795	FC114F	4532 587578	PAVEL SOLOVEV	{"email": "pavel.solovev-25071959@postgrespro.ru", "phone": "+70701116356"}
0005432235796	C324F9	7305 342030	ANASTASIYA POPOVA	{"email": "popova.anastasiya.101987@postgrespro.ru", "phone": "+70759221420"}
0005432235797	C324F9	2716 187346	ULYANA NIKITINA	{"email": "nikitinau_051980@postgrespro.ru", "phone": "+70475063251"}
0005432235798	C324F9	2615 719787	SVETLANA FOMINA	{"phone": "+70984673155"}
0005432235799	F8B370	2644 081666	ANATOLIY GUSEV	{"email": "gusev_anatoliy_01061971@postgrespro.ru", "phone": "+70714085894"}
0005432235800	B0C726	2531 380283	ELENA ABRAMOVA	{"phone": "+70303975117"}
0005432235801	B3D0BE	3296 021664	SERGEY BARANOV	{"email": "baranovs011969@postgrespro.ru", "phone": "+70386366969"}
0005432235802	E35E81	8376 602836	OLGA LOGINOVA	{"email": "olga-loginova031968@postgrespro.ru", "phone": "+70123805459"}
0005432235803	559E87	5078 079689	OLEG MAKAROV	{"email": "makarov_o-081982@postgrespro.ru", "phone": "+70757269661"}
0005432235804	AF1770	1437 274466	SVETLANA ANDREEVA	{"phone": "+70438108153"}
0005432235806	500703	7977 139200	VASILIY ZHUKOV	{"email": "v.zhukov-11101979@postgrespro.ru", "phone": "+70658084254"}
0005432235807	500703	9142 686979	ANDREY MELNIKOV	{"email": "melnikov-andrey_091969@postgrespro.ru", "phone": "+70369973261"}
0005432235808	A90F89	7619 297954	ALEKSEY FEDOROV	{"email": "aleksey-fedorov031974@postgrespro.ru", "phone": "+70505106272"}
0005432235809	A90F89	3472 081695	VERA SERGEEVA	{"phone": "+70012100181"}
0005432235810	ABEC91	5748 568585	ANASTASIYA SOROKINA	{"phone": "+70936153236"}
0005432235811	C2104E	1277 895905	ALEKSANDR MOISEEV	{"phone": "+70902699021"}
0005432235812	77DF76	8126 741637	ALEKSANDR ISAEV	{"phone": "+70445349560"}
0005432235813	77DF76	9140 494451	SERGEY POPOV	{"email": "sergey_popov-1969@postgrespro.ru", "phone": "+70097965203"}
0005432235814	944889	3543 390490	LIDIYA DENISOVA	{"email": "lidiya_denisova.17051960@postgrespro.ru", "phone": "+70648423024"}
0005432235815	372499	2401 475604	ANDREY KONOVALOV	{"email": "konovalova-31031980@postgrespro.ru", "phone": "+70487460993"}
0005432235816	DBB1E8	1343 076712	LYUDMILA ORLOVA	{"email": "orlova.l1984@postgrespro.ru", "phone": "+70722129156"}
0005432235817	DBB1E8	9099 748768	ANNA KOLESNIKOVA	{"phone": "+70509975730"}
0005432235818	23C53C	8885 054007	LYUDMILA PETROVA	{"email": "petrovalyudmila-08061971@postgrespro.ru", "phone": "+70879234232"}
0005432235819	5968E1	0282 801625	DMITRIY YAKOVLEV	{"phone": "+70555932068"}
0005432235820	003E25	4068 203311	LYUDMILA ZAKHAROVA	{"phone": "+70296365385"}
0005432235821	003E25	5873 193302	SERGEY ABRAMOV	{"email": "abramov.s.071980@postgrespro.ru", "phone": "+70345182098"}
0005432235822	FB7E8E	2205 416454	ALENA POLYAKOVA	{"email": "polyakovaa.23081983@postgrespro.ru", "phone": "+70352489948"}
0005432235823	FB7E8E	0657 961702	PAVEL MAKAROV	{"phone": "+70138709238"}
0005432235824	AEEE2E	6116 287357	GYUZEL DMITRIEVA	{"email": "g_dmitrieva_10011970@postgrespro.ru", "phone": "+70160525805"}
0005432235825	244D00	6417 472876	NINA ZOTOVA	{"email": "n_zotova081982@postgrespro.ru", "phone": "+70854728064"}
0005432235826	516D89	3977 063879	GENNADIY TIKHONOV	{"email": "g_tikhonov1975@postgrespro.ru", "phone": "+70453832790"}
0005432235827	E81115	1111 499520	VLADIMIR FROLOV	{"phone": "+70856521037"}
0005432235828	EECCDB	7537 064260	ELENA GERASIMOVA	{"email": "egerasimova.061975@postgrespro.ru", "phone": "+70682786522"}
0005432235829	733D38	9554 119253	VYACHESLAV ORLOV	{"phone": "+70469335583"}
0005432235830	699CDD	2935 873681	YURIY IVANOV	{"phone": "+70400623329"}
0005432235831	699CDD	9087 267298	ALEKSANDR ISAEV	{"email": "aleksandr-isaev13031974@postgrespro.ru", "phone": "+70354350982"}
0005432235832	FE6F0B	2348 746158	SERGEY SEMENOV	{"phone": "+70767393501"}
0005432235833	4C8D3E	9837 193701	VERA FEDOROVA	{"email": "verafedorova_13031972@postgrespro.ru", "phone": "+70575673947"}
0005432235834	F8093A	9840 669609	MAKSIM SMIRNOV	{"email": "smirnov-m.1968@postgrespro.ru", "phone": "+70141380291"}
0005432235835	619D9E	6394 660804	SERGEY NAZAROV	{"phone": "+70148385227"}
0005432235836	FDAC5E	8998 614856	LYUBOV SMIRNOVA	{"email": "lyubov-smirnova08051969@postgrespro.ru", "phone": "+70470377436"}
0005432235837	FDAC5E	2582 452045	IRAIDA KULIKOVA	{"phone": "+70006142632"}
0005432235838	588E8B	2803 152893	INNA MEDVEDEVA	{"email": "i.medvedeva_101971@postgrespro.ru", "phone": "+70031334173"}
0005432235839	E8FD65	6870 244214	OLEG SOROKIN	{"phone": "+70100866874"}
0005432235840	3F3724	5311 072564	VIKTOR NAZAROV	{"phone": "+70799144797"}
0005432235841	61C609	3141 973449	ZINAIDA VOROBEVA	{"email": "zinaidavorobeva_111967@postgrespro.ru", "phone": "+70726989419"}
0005432235842	61C609	4438 104153	NATALYA AKIMOVA	{"email": "akimovanatalya.1971@postgrespro.ru", "phone": "+70405390943"}
0005432235843	62D4B2	8355 496152	ALEKSANDR MARTYNOV	{"phone": "+70692035891"}
0005432235844	DAB403	9558 801461	NATALIYA SIDOROVA	{"email": "sidorovan.101972@postgrespro.ru", "phone": "+70262528502"}
0005432235845	DAB403	9598 405148	LEONID GAVRILOV	{"email": "gavrilovleonid.051965@postgrespro.ru", "phone": "+70683394931"}
0005432235846	D10F33	8071 077235	LYUDMILA EFREMOVA	{"email": "lyudmila_efremova-021978@postgrespro.ru", "phone": "+70385125547"}
0005432235847	D10F33	2026 387385	ALEKSEY EGOROV	{"email": "egorov.a-091978@postgrespro.ru", "phone": "+70106721203"}
0005432235848	1C1C22	9772 713564	ANDREY MELNIKOV	{"phone": "+70909483031"}
0005432235849	518E14	9077 120443	GRIGORIY EGOROV	{"phone": "+70355401341"}
0005432235850	518E14	4861 048097	ALEKSANDR NIKITIN	{"phone": "+70572138108"}
0005432235851	2BC33A	0043 469179	LYUDMILA MASLOVA	{"email": "lyudmila.maslova_1969@postgrespro.ru", "phone": "+70494505178"}
0005432235852	2BC33A	8337 028487	ELENA POPOVA	{"email": "elena.popova121970@postgrespro.ru", "phone": "+70418164851"}
0005432235853	2BC33A	1550 316901	ALEKSANDR KUZMIN	{"phone": "+70159910550"}
0005432235854	4B7181	8050 298603	NATALYA PETROVA	{"phone": "+70370153419"}
0005432235855	4B7181	3466 136247	FARIDA NESTEROVA	{"email": "faridanesterova-101956@postgrespro.ru", "phone": "+70974584127"}
0005432235856	3E1256	8291 299516	YULIYA SIDOROVA	{"email": "sidorova.yuliya.26051972@postgrespro.ru", "phone": "+70141275007"}
0005432235857	D6372B	9727 032303	TAMARA ZAKHAROVA	{"phone": "+70646296670"}
0005432235858	F8D8CD	1628 334009	NATALYA VOLKOVA	{"phone": "+70771109791"}
0005432235859	F8D8CD	4526 201035	VITALIY POPOV	{"phone": "+70231953071"}
0005432235860	87C2B0	2169 258150	NATALYA SOROKINA	{"phone": "+70284494374"}
0005432235861	496042	9831 827850	VLADIMIR MAKAROV	{"phone": "+70665623628"}
0005432235862	8E79D9	5487 417531	NATALYA KOROLEVA	{"phone": "+70960296949"}
0005432238827	D87B56	7413 595269	ROZA ZHUKOVA	{"email": "zhukova.roza-11041971@postgrespro.ru", "phone": "+70244879131"}
0005432238828	D87B56	9561 303953	TATYANA BORISOVA	{"email": "tatyanaborisova.1979@postgrespro.ru", "phone": "+70026240963"}
0005432238829	6D246A	7804 316707	ANASTASIYA ORLOVA	{"phone": "+70576621247"}
0005432238830	6D246A	6727 387962	NIKITA MOROZOV	{"phone": "+70915217924"}
0005432238831	731C35	4296 220219	MARINA KUZMINA	{"phone": "+70948809675"}
0005432238832	EBB201	5129 638574	VIKTOR VASILEV	{"email": "vasilev.v-021968@postgrespro.ru", "phone": "+70850750669"}
0005432238833	DFB24B	3989 148516	ALEKSANDR IVANOV	{"phone": "+70063712950"}
0005432238834	ACB6E2	7446 476804	EVGENIY KULIKOV	{"phone": "+70917355518"}
0005432238835	09AEDA	8576 318574	MARGARITA IVANOVA	{"email": "ivanova_m.1972@postgrespro.ru", "phone": "+70708788700"}
0005432238836	CBF560	8553 295597	ANNA ANDREEVA	{"phone": "+70716532895"}
0005432238837	7BF245	0185 481293	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin.101962@postgrespro.ru", "phone": "+70175087692"}
0005432238838	7BF245	8775 716190	NATALYA FOMINA	{"email": "fomina_n.26031971@postgrespro.ru", "phone": "+70957879208"}
0005432238839	7BF245	3190 779467	ALEKSEY VASILEV	{"phone": "+70167039310"}
0005432238840	E112F5	5320 677691	SHAVKAT ILIN	{"email": "shavkat-ilin071977@postgrespro.ru", "phone": "+70331475846"}
0005432238841	5E36C2	6965 517453	IRINA KOMAROVA	{"email": "komarova-irina_1967@postgrespro.ru", "phone": "+70673129630"}
0005432238842	5E36C2	6573 418359	OLGA IVANOVA	{"phone": "+70493898054"}
0005432238843	5261CE	3579 309307	GALINA SAVELEVA	{"email": "galina_saveleva.071963@postgrespro.ru", "phone": "+70295561138"}
0005432238844	00E9AB	2047 025131	DARYA MELNIKOVA	{"email": "dmelnikova-1975@postgrespro.ru", "phone": "+70687886530"}
0005432238845	D890D2	3235 774519	LIDIYA ANDREEVA	{"phone": "+70416103691"}
0005432238846	5F1468	6754 758135	YAROSLAV KISELEV	{"phone": "+70410715199"}
0005432238847	A919E8	9811 801296	NADEZHDA DMITRIEVA	{"phone": "+70766272541"}
0005432238848	A919E8	0252 690511	ALEKSANDR ANTONOV	{"email": "a-antonov-1964@postgrespro.ru", "phone": "+70364001674"}
0005432238849	A919E8	8841 932088	SVETLANA MAKSIMOVA	{"email": "maksimovas-061989@postgrespro.ru", "phone": "+70468174553"}
0005432238850	8D67A1	6374 387108	ALEKSANDR KUZNECOV	{"phone": "+70219248621"}
0005432238851	A64CE5	2323 877552	TATYANA BELOVA	{"email": "t-belova-081971@postgrespro.ru", "phone": "+70430192470"}
0005432238852	587704	4003 780336	NATALIYA ANTONOVA	{"phone": "+70839724135"}
0005432238853	95349B	4494 510503	ILYA GORBUNOV	{"phone": "+70279184642"}
0005432238854	626A90	1659 913267	MARIYA EGOROVA	{"phone": "+70898591406"}
0005432238855	2BF853	1395 144118	VYACHESLAV PAVLOV	{"phone": "+70724834014"}
0005432238856	314F4F	8612 790015	DARYA VASILEVA	{"email": "vasileva.darya.1987@postgrespro.ru", "phone": "+70841637322"}
0005432238857	314F4F	1351 380209	ELIZAVETA ZAKHAROVA	{"email": "ezakharova-15111978@postgrespro.ru", "phone": "+70561181235"}
0005432238858	2742F5	6398 364685	VERA PAVLOVA	{"email": "pavlova.vera031966@postgrespro.ru", "phone": "+70271572883"}
0005432238859	916A9C	8043 701197	ALEKSANDR KUZMIN	{"phone": "+70565315021"}
0005432238860	30F3AD	0002 392899	GALINA IVANOVA	{"email": "ivanova.galina_011969@postgrespro.ru", "phone": "+70280550035"}
0005432238861	8A7679	7129 851684	IGOR SAVELEV	{"phone": "+70121309293"}
0005432238862	5B7AA2	4386 971201	NIKITA BONDARENKO	{"phone": "+70538524083"}
0005432238863	C38C28	3136 404140	IVAN STEPANOV	{"phone": "+70892826815"}
0005432238864	E3D411	5942 428637	ARTEM BELOV	{"email": "belov.artem121964@postgrespro.ru", "phone": "+70713675406"}
0005432238865	FCC00C	0867 918464	ILYA ZAKHAROV	{"phone": "+70376268893"}
0005432238866	3261DA	6376 827991	OLESYA GUSEVA	{"phone": "+70366316860"}
0005432238867	F48E9C	6172 290697	MARIYA PAVLOVA	{"phone": "+70436352567"}
0005432238868	CE80B7	9438 625477	MIKHAIL GERASIMOV	{"email": "mikhailgerasimov.1968@postgrespro.ru", "phone": "+70814982131"}
0005432238869	037292	0039 949348	DENIS ROMANOV	{"email": "romanov-denis091978@postgrespro.ru", "phone": "+70311150043"}
0005432238870	86F220	5603 641700	EKATERINA MELNIKOVA	{"email": "melnikovae01081971@postgrespro.ru", "phone": "+70793214813"}
0005432238871	6FA52F	3685 921562	EKATERINA SCHERBAKOVA	{"phone": "+70918220434"}
0005432238872	6FA52F	2540 773242	IRINA FEDOROVA	{"email": "fedorova-i.1983@postgrespro.ru", "phone": "+70606278727"}
0005432238873	DA6F85	8762 551645	TATYANA KISELEVA	{"email": "kiseleva.tatyana-1965@postgrespro.ru", "phone": "+70292953744"}
0005432238874	DA6F85	0837 402774	ALEKSANDR KRASNOV	{"email": "krasnov_a081968@postgrespro.ru", "phone": "+70292363264"}
0005432238875	DA6F85	1755 355587	RIMMA MAKAROVA	{"phone": "+70473616188"}
0005432238876	17056A	2331 520255	VIKTOR ZAYCEV	{"email": "v.zaycev.1979@postgrespro.ru", "phone": "+70858737703"}
0005432238877	1E13C4	0798 701438	MARIYA NAUMOVA	{"phone": "+70593519944"}
0005432238878	059D44	5902 523761	KIRILL ALEKSEEV	{"phone": "+70695241236"}
0005432238879	059D44	5178 929205	VLADIMIR PETROV	{"email": "v.petrov-071973@postgrespro.ru", "phone": "+70718692956"}
0005432238880	0C1020	8401 649061	MIKHAIL MEDVEDEV	{"email": "medvedev_m.11121978@postgrespro.ru", "phone": "+70129882454"}
0005432238881	636BF0	2819 281775	ELENA KOROLEVA	{"email": "ekoroleva.1965@postgrespro.ru", "phone": "+70264477827"}
0005432238882	636BF0	5422 206818	ANTONINA SIDOROVA	{"email": "sidorovaantonina1976@postgrespro.ru", "phone": "+70363405336"}
0005432238883	636BF0	2420 477797	VYACHESLAV IVANOV	{"email": "v.ivanov.28061979@postgrespro.ru", "phone": "+70235878364"}
0005432238884	01EEC6	9991 334407	MIKHAIL PETROV	{"email": "m_petrov.111969@postgrespro.ru", "phone": "+70764468368"}
0005432238885	1171E7	1549 342966	STANISLAV SMIRNOV	{"phone": "+70493347388"}
0005432238886	D982DD	1413 184130	VALENTINA SEMENOVA	{"email": "semenovavalentina-011975@postgrespro.ru", "phone": "+70628476283"}
0005432238887	9E7C69	3435 604997	ALEKSANDR PETROV	{"phone": "+70772724397"}
0005432238888	BC62ED	4884 261753	ANASTASIYA NESTEROVA	{"phone": "+70245919432"}
0005432238889	6CA7AE	6079 280924	VADIM ZHUKOV	{"email": "zhukov_vadim-011978@postgrespro.ru", "phone": "+70754443097"}
0005432238890	904E39	8873 314504	NIKOLAY NOVIKOV	{"email": "novikovn.13101984@postgrespro.ru", "phone": "+70214454307"}
0005432238891	904E39	8392 264777	NIKITA NOVIKOV	{"email": "nikita.novikov-011958@postgrespro.ru", "phone": "+70368189098"}
0005432238892	83BECC	6486 991261	RAVIL FILIPPOV	{"phone": "+70139262472"}
0005432238893	83BECC	3332 786771	LYUBOV FILATOVA	{"email": "l.filatova_16071974@postgrespro.ru", "phone": "+70222796590"}
0005432238894	3E1AD8	5896 838007	IRINA SIDOROVA	{"phone": "+70503393057"}
0005432238895	9F2D6E	7150 326448	ANNA ROMANOVA	{"email": "anna-romanova-10011970@postgrespro.ru", "phone": "+70900693653"}
0005432238896	9F2D6E	9078 533235	VASILIY VASILEV	{"phone": "+70148842529"}
0005432238897	C33376	3617 816187	RAMIL MAKAROV	{"email": "r_makarov_1974@postgrespro.ru", "phone": "+70345639889"}
0005432238898	191313	8942 943602	ALEKSANDR FROLOV	{"phone": "+70099118363"}
0005432238899	191313	5273 922058	GALINA NESTEROVA	{"email": "galina.nesterova_23071977@postgrespro.ru", "phone": "+70355069127"}
0005432238900	9C4157	6590 622110	VYACHESLAV VOLKOV	{"phone": "+70990727323"}
0005432238901	9C4157	6042 276639	GALINA ORLOVA	{"email": "orlova_galina.111974@postgrespro.ru", "phone": "+70962269457"}
0005432238902	9C4157	8319 417972	PETR VOLKOV	{"phone": "+70708470955"}
0005432238903	9C4157	5495 503194	VIKTORIYA KALININA	{"phone": "+70387768713"}
0005432238904	6B935A	3812 860471	MIKHAIL NIKOLAEV	{"phone": "+70492326146"}
0005432238905	6B935A	0983 750252	EKATERINA SCHERBAKOVA	{"phone": "+70911949293"}
0005432238906	9E687E	2799 606817	NINA ANTONOVA	{"phone": "+70058460403"}
0005432238907	1055BF	1324 946896	IGOR POPOV	{"email": "popov-i.31081979@postgrespro.ru", "phone": "+70568201226"}
0005432238908	E4046A	8407 210551	VADIM ALEKSEEV	{"phone": "+70183667773"}
0005432238909	F4A3B0	3258 839292	DMITRIY MAKAROV	{"phone": "+70023130080"}
0005432238910	F4A3B0	2367 914375	LYUBOV KOROLEVA	{"email": "lyubov.koroleva.07121976@postgrespro.ru", "phone": "+70130344419"}
0005432238911	DCBF9A	8539 928499	TAISIYA ZAYCEVA	{"phone": "+70254312673"}
0005432238912	1A70D4	6381 544756	LEONTIY GUSEV	{"email": "l-gusev-051978@postgrespro.ru", "phone": "+70194648290"}
0005432238913	BD6FB3	6190 547787	EVGENIY ZAYCEV	{"phone": "+70969577620"}
0005432238914	BD6FB3	4799 464765	SOFYA OSIPOVA	{"email": "osipova.sofya-31031966@postgrespro.ru", "phone": "+70188804556"}
0005432238915	370E21	3442 008866	NIKOLAY TARASOV	{"phone": "+70051742366"}
0005432238916	519C49	4605 422500	VYACHESLAV MIRONOV	{"email": "vyacheslavmironov.1979@postgrespro.ru", "phone": "+70944241102"}
0005432238917	519C49	2286 988734	TATYANA KRASNOVA	{"phone": "+70463094799"}
0005432238918	25C7BC	2729 763115	TATYANA YUDINA	{"email": "tatyana.yudina.061965@postgrespro.ru", "phone": "+70918475706"}
0005432238919	81BE0D	8892 280171	DARYA PAVLOVA	{"email": "d_pavlova_10111964@postgrespro.ru", "phone": "+70884243882"}
0005432238920	DF0E44	9644 093064	VLADIMIR BONDARENKO	{"email": "bondarenkov-1970@postgrespro.ru", "phone": "+70826837594"}
0005432238921	DF0E44	5178 023892	MARINA AKIMOVA	{"phone": "+70132148498"}
0005432238922	DF0E44	0565 740988	MARIYA MAKAROVA	{"phone": "+70962178082"}
0005432238923	39CD81	9147 223655	RUSLAN VOROBEV	{"email": "r_vorobev.02051974@postgrespro.ru", "phone": "+70382715801"}
0005432238924	39CD81	8456 900546	DMITRIY ABRAMOV	{"phone": "+70008434402"}
0005432238925	4E5200	8238 511853	VALERIYA KUZMINA	{"email": "kuzmina_v.1963@postgrespro.ru", "phone": "+70267693286"}
0005432238926	4841D7	1842 115642	IVAN MATVEEV	{"email": "ivan-matveev_021972@postgrespro.ru", "phone": "+70276779584"}
0005432238927	4841D7	9525 524550	OLEG DENISOV	{"email": "denisovo-10051962@postgrespro.ru", "phone": "+70361674526"}
0005432238928	2DDF9B	6970 670656	POLINA TITOVA	{"email": "ptitova011973@postgrespro.ru", "phone": "+70484183856"}
0005432238929	B58F72	9512 363094	EVGENIY KOZLOV	{"email": "kozlov-evgeniy.081969@postgrespro.ru", "phone": "+70419099040"}
0005432238930	0ED8D7	1815 631563	MIKHAIL SEMENOV	{"email": "mikhail_semenov.051976@postgrespro.ru", "phone": "+70939224167"}
0005432238931	0ED8D7	5761 835086	VALERIYA STEPANOVA	{"phone": "+70885263694"}
0005432238932	8EE842	9155 566677	TATYANA DAVYDOVA	{"email": "davydova-tatyana-091974@postgrespro.ru", "phone": "+70808555464"}
0005432238933	68A19A	0414 431602	ALEKSANDR KUZNECOV	{"phone": "+70760338384"}
0005432238934	2241E7	3692 988551	MIKHAIL MARTYNOV	{"email": "m_martynov.041973@postgrespro.ru", "phone": "+70800890329"}
0005432238935	30B70B	3039 738635	LYUDMILA KISELEVA	{"phone": "+70812126246"}
0005432238936	817887	8102 894196	ANASTASIYA EFREMOVA	{"email": "efremovaa-071975@postgrespro.ru", "phone": "+70804357771"}
0005432238937	19EA1D	6273 949643	ALESYA MASLOVA	{"email": "maslova.alesya021962@postgrespro.ru", "phone": "+70570539753"}
0005432238938	7D49D9	4329 885614	SERGEY ALEKSEEV	{"email": "alekseevsergey.1968@postgrespro.ru", "phone": "+70086654167"}
0005432238939	FBF305	1767 899251	SEMEN GRIGOREV	{"email": "grigorevsemen_101978@postgrespro.ru", "phone": "+70036887010"}
0005432238940	FBF305	3892 595916	GENNADIY VOLKOV	{"email": "volkov.g_18091969@postgrespro.ru", "phone": "+70162993197"}
0005432238941	4DDD01	6633 168578	NIKOLAY IVANOV	{"email": "n_ivanov1974@postgrespro.ru", "phone": "+70996926463"}
0005432238942	888D6E	6306 602636	GALINA ABRAMOVA	{"phone": "+70217745336"}
0005432238943	FFD41D	2780 204404	ANNA KOROLEVA	{"phone": "+70432221456"}
0005432238944	82E8A8	9637 263866	ALEKSANDR MIRONOV	{"phone": "+70161081744"}
0005432238945	7777EE	6373 721429	GEORGIY MAKAROV	{"phone": "+70092872936"}
0005432238946	0F7FBD	9747 181764	SVETLANA ANDREEVA	{"email": "sandreeva-1968@postgrespro.ru", "phone": "+70299888266"}
0005432238947	FBFAB9	1579 301968	ELENA FADEEVA	{"email": "fadeevaelena.011982@postgrespro.ru", "phone": "+70436720145"}
0005432238948	FBFAB9	3808 022748	YANA GUSEVA	{"phone": "+70043975422"}
0005432238949	2063E5	2288 448187	NATALYA FROLOVA	{"email": "frolova.natalya-121972@postgrespro.ru", "phone": "+70260459188"}
0005432238950	2063E5	9322 353467	ELENA SCHERBAKOVA	{"email": "e-scherbakova_081961@postgrespro.ru", "phone": "+70078987529"}
0005432238951	42B032	0186 112004	LYUBOV CHERNOVA	{"phone": "+70155761437"}
0005432238952	766609	2996 912171	TAMARA KARPOVA	{"email": "tamara-karpova-31011968@postgrespro.ru", "phone": "+70015266582"}
0005432238953	7DBCD3	4440 158408	NATALYA AKIMOVA	{"email": "n-akimova.1968@postgrespro.ru", "phone": "+70589232909"}
0005432238954	7DBCD3	9928 530027	ANATOLIY ALEKSANDROV	{"phone": "+70077019140"}
0005432238955	36EA36	6172 985350	VIKTORIYA SEMENOVA	{"phone": "+70884836795"}
0005432238956	36EA36	3588 490136	GALINA ILINA	{"email": "galina.ilina02011981@postgrespro.ru", "phone": "+70408060601"}
0005432238957	8DAC28	0864 537359	SERGEY KOZLOV	{"phone": "+70127801049"}
0005432238958	AF1009	6632 290395	LYUDMILA YUDINA	{"email": "lyudmila-yudina-06011963@postgrespro.ru", "phone": "+70847713525"}
0005432238959	8C506A	7745 465623	ANASTASIYA PETROVA	{"phone": "+70691803785"}
0005432238960	8C506A	9454 682599	EVGENIY DENISOV	{"email": "edenisov_1971@postgrespro.ru", "phone": "+70270103400"}
0005432238961	637E6C	3416 189058	ELIZAVETA ABRAMOVA	{"email": "abramova-elizaveta-1973@postgrespro.ru", "phone": "+70735070869"}
0005432238962	876ECD	1183 284759	ARTEM ZHUKOV	{"phone": "+70335200179"}
0005432238963	876ECD	0544 002607	ALEKSANDR KUZNECOV	{"email": "kuznecova.1982@postgrespro.ru", "phone": "+70534944444"}
0005432238964	876ECD	5447 059222	ROMAN IVANOV	{"email": "r_ivanov_071978@postgrespro.ru", "phone": "+70165849104"}
0005432238965	3F06DF	9284 944473	PAVEL DENISOV	{"phone": "+70898218005"}
0005432238966	7E880A	0206 311588	VLADIMIR SCHERBAKOV	{"email": "scherbakov.vladimir011968@postgrespro.ru", "phone": "+70498509458"}
0005432238967	7E880A	6431 841788	DMITRIY MIRONOV	{"email": "mironov-dmitriy_011957@postgrespro.ru", "phone": "+70405720750"}
0005432238968	6DF3F8	6664 011288	NATALYA KOROLEVA	{"email": "koroleva.n_081973@postgrespro.ru", "phone": "+70978125682"}
0005432238969	DB18AD	7831 888615	VIKTOR KISELEV	{"phone": "+70249236832"}
0005432238970	DB18AD	4990 026730	NIKOLAY STEPANOV	{"phone": "+70893877309"}
0005432238971	8FB041	6455 156454	VIKTOR MARTYNOV	{"email": "martynov.v.08091965@postgrespro.ru", "phone": "+70806584201"}
0005432238972	8FB041	0975 446497	ELENA MOROZOVA	{"phone": "+70911650643"}
0005432238973	44C6F9	3776 376382	OKSANA KISELEVA	{"phone": "+70380934466"}
0005432238974	F9AB44	0413 525290	REGINA FOMINA	{"email": "regina_fomina1966@postgrespro.ru", "phone": "+70597652438"}
0005432238975	F9AB44	1109 768388	EDUARD SEMENOV	{"phone": "+70568127688"}
0005432238976	A94DE2	7082 031745	OLGA NAZAROVA	{"email": "olga.nazarova-1971@postgrespro.ru", "phone": "+70752551888"}
0005432238977	52C5AA	0756 147486	NIKOLAY NIKOLAEV	{"email": "n-nikolaev_011975@postgrespro.ru", "phone": "+70406409039"}
0005432238978	52C5AA	5513 869463	ALEKSEY MAKSIMOV	{"email": "amaksimov-1972@postgrespro.ru", "phone": "+70164835695"}
0005432238979	52C5AA	6492 179240	LILIYA EFREMOVA	{"phone": "+70105224411"}
0005432238980	A1538B	4078 493164	ELENA IVANOVA	{"email": "elena_ivanova.09091965@postgrespro.ru", "phone": "+70864668438"}
0005432238981	A1538B	3507 783024	MARINA EFREMOVA	{"email": "marina.efremova1980@postgrespro.ru", "phone": "+70436396638"}
0005432238982	A1538B	7263 466703	MARINA ALEKSANDROVA	{"phone": "+70051960550"}
0005432238983	BC0CE0	5280 304753	MARIYA GORBUNOVA	{"email": "m_gorbunova_18121964@postgrespro.ru", "phone": "+70867814233"}
0005432238984	876A44	6258 562576	NATALYA SCHERBAKOVA	{"email": "n_scherbakova-1977@postgrespro.ru", "phone": "+70477570125"}
0005432238985	876A44	4933 019722	SVETLANA MARTYNOVA	{"email": "s-martynova111976@postgrespro.ru", "phone": "+70902130528"}
0005432238986	47F136	2071 948539	KRISTINA MIKHAYLOVA	{"phone": "+70857641156"}
0005432238987	47F136	5352 910297	ELENA LEBEDEVA	{"email": "elenalebedeva1976@postgrespro.ru", "phone": "+70781754609"}
0005432238988	F34313	3772 004769	MIKHAIL KISELEV	{"email": "mikhailkiselev1971@postgrespro.ru", "phone": "+70903435410"}
0005432238989	F34313	1494 795923	NATALIYA IVANOVA	{"phone": "+70269462101"}
0005432238990	D3119C	3667 397061	VIKTOR POPOV	{"email": "viktor_popov-121967@postgrespro.ru", "phone": "+70181097390"}
0005432238991	8DA21D	2056 793750	YURIY SCHERBAKOV	{"phone": "+70994360692"}
0005432238992	82B59A	2384 571622	VYACHESLAV MOISEEV	{"email": "vyacheslav_moiseev-1978@postgrespro.ru", "phone": "+70462057657"}
0005432238993	82B59A	3130 915668	ELENA ZHURAVLEVA	{"email": "zhuravleva_e-1980@postgrespro.ru", "phone": "+70172466175"}
0005432238994	CE0EE1	2955 309573	NADEZHDA BELYAEVA	{"email": "belyaeva-nadezhda_1970@postgrespro.ru", "phone": "+70078882814"}
0005432238995	496BC7	7856 104550	KONSTANTIN ALEKSEEV	{"phone": "+70793196170"}
0005432238996	580D80	8395 876773	SVETLANA YUDINA	{"email": "svetlana-yudina091972@postgrespro.ru", "phone": "+70851598453"}
0005432238997	5A0369	8696 118155	TATYANA RODIONOVA	{"email": "rodionova.tatyana-1981@postgrespro.ru", "phone": "+70556344800"}
0005432238998	B8BACC	5712 376465	EKATERINA TIKHONOVA	{"phone": "+70533353161"}
0005432238999	B8BACC	6233 620018	GALINA BELOVA	{"phone": "+70415664201"}
0005432239000	D8EFAB	2052 052838	VALENTINA ORLOVA	{"phone": "+70951455793"}
0005432239001	2FBA70	1979 039318	SVETLANA PAVLOVA	{"phone": "+70462444654"}
0005432239002	892061	3951 080516	ANDREY ZAKHAROV	{"email": "andrey_zakharov.27091972@postgrespro.ru", "phone": "+70459874980"}
0005432239003	712801	5185 226769	PAVEL VLASOV	{"email": "vlasov_p.041963@postgrespro.ru", "phone": "+70175052723"}
0005432239004	CDE90F	5466 154940	ILDAR SERGEEV	{"phone": "+70754620211"}
0005432239005	7AB14F	3047 004563	TATYANA DANILOVA	{"phone": "+70170197456"}
0005432239006	7AB14F	0962 480885	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov.081972@postgrespro.ru", "phone": "+70023396204"}
0005432239007	BE7897	1071 996144	ANDREY ISAEV	{"phone": "+70770586340"}
0005432239008	BE7897	6992 813772	NADEZHDA MOROZOVA	{"email": "morozovanadezhda_20021974@postgrespro.ru", "phone": "+70412433297"}
0005432239009	23F2B5	4652 514413	ASIYA PETROVA	{"email": "petrova_a071955@postgrespro.ru", "phone": "+70346990909"}
0005432239010	23F2B5	2210 691291	ANNA TIKHONOVA	{"phone": "+70422099367"}
0005432239011	17C060	6168 404584	OLGA SMIRNOVA	{"email": "smirnova-o_1955@postgrespro.ru", "phone": "+70073733640"}
0005432239012	17C060	2547 816515	NAIL KONOVALOV	{"phone": "+70638071550"}
0005432239013	9D75B7	3712 983024	SERGEY KUZNECOV	{"email": "sergeykuznecov.1983@postgrespro.ru", "phone": "+70770141102"}
0005432239014	9D75B7	9984 163549	VALENTINA KOROLEVA	{"phone": "+70359895834"}
0005432239015	9D75B7	7857 803592	STEPAN NAUMOV	{"email": "snaumov.051967@postgrespro.ru", "phone": "+70789879980"}
0005432239016	51D484	9698 673449	MIKHAIL SOKOLOV	{"phone": "+70356855440"}
0005432239017	92E0AA	6747 555578	MARINA LAZAREVA	{"phone": "+70641463596"}
0005432239018	4A7FF4	8378 026092	NINA NAUMOVA	{"phone": "+70542384167"}
0005432239019	400C65	4173 796376	SERGEY NIKOLAEV	{"phone": "+70388092427"}
0005432239020	400C65	4058 822021	GALINA PAVLOVA	{"email": "pavlova_g_101969@postgrespro.ru", "phone": "+70613153789"}
0005432239021	109CFD	9543 657016	SERGEY BONDARENKO	{"phone": "+70915203689"}
0005432239022	8B8F18	1622 749403	ALEKSANDR SIDOROV	{"phone": "+70893791764"}
0005432239023	B6C6C2	8058 394967	YURIY POPOV	{"email": "popovyuriy_061985@postgrespro.ru", "phone": "+70839458428"}
0005432239024	8291B6	7113 927361	EKATERINA FEDOROVA	{"email": "fedorova_ekaterina_101967@postgrespro.ru", "phone": "+70222558131"}
0005432239025	74865F	2954 443282	MAKSIM TIKHONOV	{"email": "tikhonov.maksim-071972@postgrespro.ru", "phone": "+70631939428"}
0005432239026	AE1D59	6572 381790	SVETLANA KULIKOVA	{"email": "kulikova.svetlana-08081973@postgrespro.ru", "phone": "+70679365592"}
0005432239027	AE1D59	4538 527763	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov08071971@postgrespro.ru", "phone": "+70236347738"}
0005432239028	CCF8EE	2038 501270	ANTON ZAKHAROV	{"phone": "+70638157576"}
0005432239029	549F48	4552 153090	SERGEY BELOV	{"phone": "+70897111702"}
0005432239030	549F48	3509 257789	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr_27091991@postgrespro.ru", "phone": "+70267955847"}
0005432239031	260333	1755 746688	NATALIYA SAVELEVA	{"email": "n-saveleva-1967@postgrespro.ru", "phone": "+70281555473"}
0005432239032	4182C0	9803 597378	SVETLANA FROLOVA	{"phone": "+70040435731"}
0005432239033	E09A19	9971 746155	EVGENIY ZAKHAROV	{"phone": "+70396320550"}
0005432239034	05D555	2120 939965	SERGEY OSIPOV	{"phone": "+70631613765"}
0005432239035	15AE04	8310 903660	YULIYA ZHURAVLEVA	{"email": "zhuravleva.y-23121968@postgrespro.ru", "phone": "+70353734181"}
0005432239036	6069A1	3267 649731	ANATOLIY ZHURAVLEV	{"phone": "+70840677261"}
0005432239037	1407F7	4173 033881	TATYANA KARPOVA	{"phone": "+70716127017"}
0005432239038	81647F	5971 242931	SVETLANA NOVIKOVA	{"phone": "+70065387333"}
0005432239039	06497E	6536 423066	SVETLANA TROFIMOVA	{"phone": "+70480217919"}
0005432239040	77D036	2385 666872	LIDIYA SOROKINA	{"email": "sorokina.lidiya031978@postgrespro.ru", "phone": "+70273125506"}
0005432239041	77D036	2042 440816	TATYANA TARASOVA	{"phone": "+70433581294"}
0005432239042	68D78A	2065 030261	TATYANA NIKIFOROVA	{"phone": "+70786720427"}
0005432239043	4E4479	0955 965958	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev.11111966@postgrespro.ru", "phone": "+70933663939"}
0005432239044	0552DA	4862 624790	GENNADIY MOROZOV	{"phone": "+70952488685"}
0005432239045	4E53E1	8780 035320	OLGA MAKAROVA	{"phone": "+70287948123"}
0005432239046	4E53E1	7104 612847	EVGENIY ISAEV	{"email": "evgeniyisaev-14121957@postgrespro.ru", "phone": "+70937612997"}
0005432239047	01870D	6150 897227	TATYANA KOMAROVA	{"phone": "+70644787595"}
0005432239048	01870D	3455 520476	YULIYA LEBEDEVA	{"phone": "+70826326299"}
0005432239049	F351B0	7998 053018	GENNADIY KARPOV	{"email": "karpov-g_051968@postgrespro.ru", "phone": "+70276812391"}
0005432239050	F351B0	6597 366744	VADIM CHERNOV	{"phone": "+70276384672"}
0005432239051	455C2F	9537 237426	SERGEY ANDREEV	{"phone": "+70167515868"}
0005432239052	0A1994	7159 099388	VALENTINA VOLKOVA	{"phone": "+70602519860"}
0005432239053	41099B	7069 558805	VLADIMIR FILIPPOV	{"phone": "+70534392725"}
0005432239054	41099B	7944 219061	DMITRIY SOLOVEV	{"email": "solovev_d_051977@postgrespro.ru", "phone": "+70267797713"}
0005432239055	E44F12	0473 068813	NIKOLAY SIDOROV	{"email": "sidorovn.111981@postgrespro.ru", "phone": "+70620170867"}
0005432239056	4227F8	4820 254646	VLADA STEPANOVA	{"email": "v_stepanova-01111966@postgrespro.ru", "phone": "+70400312424"}
0005432239057	180868	1915 898915	LIDIYA NESTEROVA	{"email": "nesterovalidiya.1972@postgrespro.ru", "phone": "+70859511051"}
0005432239058	180868	1554 903899	SERGEY POPOV	{"email": "sergey.popov_1979@postgrespro.ru", "phone": "+70813398706"}
0005432239059	AA4121	3913 321150	ANDREY CHERNOV	{"email": "chernov-a_24101978@postgrespro.ru", "phone": "+70815886771"}
0005432239060	87210A	8806 036486	NAILYA VASILEVA	{"phone": "+70217663283"}
0005432239061	87210A	5189 247790	IRINA KUZNECOVA	{"email": "irina_kuznecova-18051970@postgrespro.ru", "phone": "+70775925999"}
0005432239062	4FFE40	9293 069897	LARISA DANILOVA	{"email": "danilova-larisa_1965@postgrespro.ru", "phone": "+70769316665"}
0005432239063	16A27E	6286 962917	DMITRIY TARASOV	{"email": "d.tarasov_1965@postgrespro.ru", "phone": "+70551201144"}
0005432239064	FA616D	9406 207874	TATYANA VASILEVA	{"email": "t.vasileva_061976@postgrespro.ru", "phone": "+70238829926"}
0005432239065	FA616D	9129 689330	DMITRIY EGOROV	{"email": "egorov.d.1970@postgrespro.ru", "phone": "+70061571604"}
0005432239066	4B749F	9367 575845	IRAIDA KUZMINA	{"email": "i-kuzmina-12071966@postgrespro.ru", "phone": "+70627176990"}
0005432239067	4B749F	5158 033940	NINA KONOVALOVA	{"email": "nina_konovalova-1971@postgrespro.ru", "phone": "+70075941476"}
0005432239068	B53670	0982 155569	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov1976@postgrespro.ru", "phone": "+70215218222"}
0005432239069	93B711	5697 677058	KONSTANTIN ALEKSEEV	{"email": "alekseev-konstantin.05111982@postgrespro.ru", "phone": "+70276556561"}
0005432239070	C5E12C	0072 964285	LYUDMILA PAVLOVA	{"email": "pavloval09031979@postgrespro.ru", "phone": "+70866446015"}
0005432239071	C5E12C	5031 344783	MARIYA ZAKHAROVA	{"email": "mzakharova041972@postgrespro.ru", "phone": "+70778484902"}
0005432239072	0770FC	3230 362868	PAVEL SMIRNOV	{"email": "pavel_smirnov_21021976@postgrespro.ru", "phone": "+70351552782"}
0005432239073	0770FC	1894 112658	TATYANA ROMANOVA	{"phone": "+70147103762"}
0005432239074	8E2399	2463 803589	NADEZHDA POPOVA	{"email": "popovanadezhda.121981@postgrespro.ru", "phone": "+70445772377"}
0005432239075	8E2399	4543 913141	TATYANA VLASOVA	{"phone": "+70906053356"}
0005432239076	C970C5	4169 950082	MARINA BOGDANOVA	{"phone": "+70864710895"}
0005432239077	A243B3	0013 692360	MARIYA LAZAREVA	{"email": "mariyalazareva-1966@postgrespro.ru", "phone": "+70169714523"}
0005432239078	80D93B	0431 270888	ELENA IVANOVA	{"phone": "+70980498299"}
0005432239079	92B7C5	4767 222046	DMITRIY BARANOV	{"phone": "+70759725084"}
0005432239080	114E24	9079 887438	NIKOLAY ALEKSANDROV	{"phone": "+70724269916"}
0005432239081	94735B	2859 685828	VADIM VOROBEV	{"email": "v_vorobev_011965@postgrespro.ru", "phone": "+70641177608"}
0005432239082	94191D	8951 595450	DANILA SOROKIN	{"phone": "+70067582041"}
0005432239083	51C37E	5435 105564	SERGEY KISELEV	{"email": "kiselev-sergey.03081976@postgrespro.ru", "phone": "+70446011830"}
0005432239084	51C37E	5553 374717	VALENTINA ISAEVA	{"phone": "+70863729826"}
0005432239085	51C37E	3566 506537	TATYANA NIKIFOROVA	{"email": "nikiforova.tatyana.051980@postgrespro.ru", "phone": "+70649332272"}
0005432239086	A7819A	6934 576160	NAZAR KUZNECOV	{"email": "n_kuznecov-21091965@postgrespro.ru", "phone": "+70242383230"}
0005432239087	A7819A	2077 289081	VYACHESLAV MOROZOV	{"email": "vyacheslavmorozov.1968@postgrespro.ru", "phone": "+70476511501"}
0005432239088	768040	8429 098292	VLADISLAV ABRAMOV	{"email": "vladislav-abramov051977@postgrespro.ru", "phone": "+70098625898"}
0005432239089	768040	3124 267357	NINA SERGEEVA	{"phone": "+70059381555"}
0005432239090	46B3D9	6730 653245	SERGEY STEPANOV	{"email": "s.stepanov-12071973@postgrespro.ru", "phone": "+70790699385"}
0005432239091	63CD56	6723 206319	GALINA MOISEEVA	{"email": "moiseeva.g_1968@postgrespro.ru", "phone": "+70549857317"}
0005432239092	6A85AB	2204 212163	ANATOLIY SERGEEV	{"email": "a_sergeev26031967@postgrespro.ru", "phone": "+70970609661"}
0005432239093	6A85AB	8451 350729	VLADIMIR NAUMOV	{"phone": "+70301122303"}
0005432239094	6DDD39	4391 302671	EVGENIYA KARPOVA	{"phone": "+70304059772"}
0005432239095	E29820	9734 106635	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana_051961@postgrespro.ru", "phone": "+70335151553"}
0005432239096	D0BA15	2424 866331	YURIY IVANOV	{"phone": "+70621078661"}
0005432239097	D0BA15	5572 273519	ALEKSANDR MELNIKOV	{"email": "aleksandr_melnikov-1986@postgrespro.ru", "phone": "+70076614929"}
0005432239098	340E7C	9955 011955	RAMIL KAZAKOV	{"phone": "+70236936867"}
0005432239099	99E648	6045 142739	ANDREY KUZMIN	{"email": "a.kuzmin.061966@postgrespro.ru", "phone": "+70672838606"}
0005432239100	C70767	5574 049655	ALEKSANDR SOROKIN	{"phone": "+70695430876"}
0005432239101	C70767	2558 935682	MIKHAIL TIMOFEEV	{"email": "timofeevm011971@postgrespro.ru", "phone": "+70437255777"}
0005432239102	C70767	8415 317631	MARIYA SMIRNOVA	{"phone": "+70648335859"}
0005432239103	5B964B	1044 917616	ELENA MASLOVA	{"phone": "+70121582411"}
0005432239104	0A6E76	8928 222296	YULIYA VLASOVA	{"phone": "+70623415274"}
0005432239105	3F9F8F	5981 307745	STANISLAV SEMENOV	{"email": "semenov_s.1967@postgrespro.ru", "phone": "+70467416606"}
0005432239106	3F9F8F	1265 633724	VITALIY KOZLOV	{"phone": "+70313663782"}
0005432239107	2A0849	6608 715882	VERA DAVYDOVA	{"phone": "+70999477533"}
0005432239108	2A0849	1472 911039	YAN SOKOLOV	{"phone": "+70844193192"}
0005432239109	D35E47	6382 918611	NADEZHDA ISAEVA	{"phone": "+70797502267"}
0005432239110	D35E47	5827 791248	YURIY FROLOV	{"phone": "+70134872720"}
0005432239111	201AA3	6596 022262	ANASTASIYA SOLOVEVA	{"email": "soloveva.a-1969@postgrespro.ru", "phone": "+70872489207"}
0005432239112	A95D41	8713 949050	VALENTIN ALEKSEEV	{"phone": "+70305034120"}
0005432239113	8A6127	0873 070819	SOFYA VASILEVA	{"email": "vasilevas_081966@postgrespro.ru", "phone": "+70687130209"}
0005432239114	19AE9C	2553 790177	ALEKSEY FROLOV	{"phone": "+70871988358"}
0005432239115	19AE9C	1216 289084	NIKOLAY SOLOVEV	{"email": "nikolaysolovev021966@postgrespro.ru", "phone": "+70801739727"}
0005432261087	02E6B6	4535 186967	DENIS ZAKHAROV	{"email": "zakharov_d.051960@postgrespro.ru", "phone": "+70135025535"}
0005432261088	F4C784	6371 700784	LYUBOV SAVELEVA	{"email": "lyubov-saveleva-1971@postgrespro.ru", "phone": "+70627855070"}
0005432261089	F4C784	6932 359385	IGOR SOROKIN	{"email": "igorsorokin23041964@postgrespro.ru", "phone": "+70097749985"}
0005432261090	3F351E	6618 210115	ZOYA KUZNECOVA	{"phone": "+70117376483"}
0005432261091	EB11BB	1118 315493	LYUBOV MOROZOVA	{"phone": "+70728375876"}
0005432261092	52DCEF	6854 078611	IGOR SEMENOV	{"email": "isemenov1980@postgrespro.ru", "phone": "+70246231470"}
0005432261093	1EA809	6633 913429	DMITRIY KRASNOV	{"email": "dkrasnov.24121964@postgrespro.ru", "phone": "+70527912994"}
0005432261094	11B509	0637 814612	EVDOKIYA MAKSIMOVA	{"phone": "+70123143366"}
0005432261095	19FE38	5660 835749	VALENTINA DMITRIEVA	{"phone": "+70167182132"}
0005432261096	19FE38	9141 251461	ANNA ISAEVA	{"phone": "+70279389741"}
0005432261097	506FCB	7650 083565	VITALIY NAZAROV	{"email": "nazarov_vitaliy.071969@postgrespro.ru", "phone": "+70013609277"}
0005432261098	506FCB	7453 780162	SVETLANA VOROBEVA	{"email": "s.vorobeva.08081974@postgrespro.ru", "phone": "+70635611161"}
0005432261099	506FCB	0673 994386	ANASTASIYA PETROVA	{"email": "anastasiyapetrova.101961@postgrespro.ru", "phone": "+70175715198"}
0005432261100	854C4C	1511 328252	MARIYA KOVALEVA	{"email": "kovaleva-m-1973@postgrespro.ru", "phone": "+70276896418"}
0005432261101	854C4C	8910 452385	YULIYA GAVRILOVA	{"email": "yuliyagavrilova1972@postgrespro.ru", "phone": "+70385500974"}
0005432261102	854C4C	7641 575183	NINA OVCHINNIKOVA	{"email": "n_ovchinnikova.08071967@postgrespro.ru", "phone": "+70427204974"}
0005432261103	8E6AB5	9293 682823	EKATERINA KONOVALOVA	{"email": "konovalova-e.1958@postgrespro.ru", "phone": "+70798783791"}
0005432261104	429B95	7132 580850	MIKHAIL IVANOV	{"phone": "+70818601609"}
0005432261105	F9F4EB	7894 116782	NADEZHDA KOZLOVA	{"phone": "+70644662996"}
0005432261106	205824	5482 696891	ANATOLIY OSIPOV	{"email": "a-osipov1971@postgrespro.ru", "phone": "+70156458456"}
0005432261107	E3BD32	0199 079802	OLGA KONOVALOVA	{"phone": "+70616477653"}
0005432261108	2E41FA	0464 276180	ILDAR PETROV	{"phone": "+70706367824"}
0005432261109	2E41FA	8171 264769	ALEKSANDR ZHURAVLEV	{"phone": "+70069840412"}
0005432261110	DE593C	5580 503905	YULIYA PETROVA	{"email": "y-petrova-13111973@postgrespro.ru", "phone": "+70489985658"}
0005432261111	DE593C	4929 139591	MAKSIM SOKOLOV	{"email": "maksim.sokolov-031966@postgrespro.ru", "phone": "+70010213059"}
0005432261112	3F3365	4017 638783	VYACHESLAV POPOV	{"email": "v.popov14061982@postgrespro.ru", "phone": "+70568648461"}
0005432261113	3F3365	5001 503219	TAMARA KOROLEVA	{"email": "t.koroleva101960@postgrespro.ru", "phone": "+70427801539"}
0005432261114	496D37	3947 277648	SERGEY NIKOLAEV	{"email": "nikolaev_s.1968@postgrespro.ru", "phone": "+70412763000"}
0005432261115	496D37	7646 715070	VIKTOR IVANOV	{"phone": "+70219208345"}
0005432261116	D9BB20	0011 072027	MARIYA SEMENOVA	{"email": "mariyasemenova.17031969@postgrespro.ru", "phone": "+70515612437"}
0005432261117	8ADA24	9038 866475	FEDOR GERASIMOV	{"phone": "+70011766476"}
0005432261118	8ADA24	9683 294066	NIKOLAY EGOROV	{"email": "egorovn-04111966@postgrespro.ru", "phone": "+70026749259"}
0005432261119	C3382F	9870 648424	TATYANA NIKITINA	{"phone": "+70149994216"}
0005432261120	C3382F	6390 404877	ALEKSANDR IVANOV	{"phone": "+70605263755"}
0005432261121	AAAF88	9224 539922	ANDREY MEDVEDEV	{"email": "andrey.medvedev_071985@postgrespro.ru", "phone": "+70653941797"}
0005432261122	00CF38	4168 893138	ALEKSEY KULIKOV	{"email": "alekseykulikov021978@postgrespro.ru", "phone": "+70369503486"}
0005432261123	00CF38	3233 349428	NATALYA POPOVA	{"email": "natalya_popova1972@postgrespro.ru", "phone": "+70424490213"}
0005432261124	BA1484	2070 427264	OLGA SEMENOVA	{"phone": "+70927387741"}
0005432261125	8D6873	0404 342448	MARIYA ALEKSEEVA	{"phone": "+70895336800"}
0005432261126	6BECE5	1962 636372	ILYA GRIGOREV	{"email": "grigorev-i-081969@postgrespro.ru", "phone": "+70421365107"}
0005432261127	BE499C	5819 386174	MARIYA RODIONOVA	{"phone": "+70288525260"}
0005432261128	9DEBE2	9534 678775	ARTEM FEDOROV	{"phone": "+70846256243"}
0005432261129	F1B913	2841 753097	ANATOLIY ANDREEV	{"phone": "+70162475774"}
0005432261130	F1B913	6059 793857	SERGEY NIKOLAEV	{"email": "nikolaev.sergey-24101971@postgrespro.ru", "phone": "+70211165672"}
0005432261131	160413	6833 626142	MAKSIM ROMANOV	{"email": "m_romanov-1976@postgrespro.ru", "phone": "+70675465311"}
0005432261132	2DE0B6	3401 049139	PAVEL AFANASEV	{"phone": "+70444975249"}
0005432261133	BE3F54	0673 356108	GALINA KOLESNIKOVA	{"phone": "+70500295829"}
0005432261134	80C7D7	4392 044391	OLEG STEPANOV	{"phone": "+70867539301"}
0005432261135	22605B	1493 418825	NIKOLAY STEPANOV	{"phone": "+70071122991"}
0005432261136	EB831F	9164 506875	SVETLANA MAKAROVA	{"phone": "+70432268002"}
0005432261137	EB831F	2395 700778	ARTEM CHERNOV	{"email": "chernov-a.061966@postgrespro.ru", "phone": "+70261031946"}
0005432261138	6F2ABF	3148 896554	LIDIYA RYABOVA	{"phone": "+70627556059"}
0005432261139	A9461E	9974 895708	EGOR VASILEV	{"phone": "+70284219991"}
0005432261140	A9461E	5380 424395	ALEKSEY MAKAROV	{"phone": "+70914229782"}
0005432261141	A9461E	8683 137379	NIKOLAY IVANOV	{"email": "nikolay.ivanov_1968@postgrespro.ru", "phone": "+70669809249"}
0005432261142	AB8A98	2503 038503	YULIYA NAZAROVA	{"email": "y-nazarova.011969@postgrespro.ru", "phone": "+70181455724"}
0005432261143	AB8A98	9118 652912	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov_111972@postgrespro.ru", "phone": "+70786359465"}
0005432261144	AB8A98	6461 727543	VLADIMIR SOROKIN	{"phone": "+70479459171"}
0005432261145	402F57	2288 248589	NURIYA SCHERBAKOVA	{"phone": "+70318376540"}
0005432261146	402F57	6501 037055	GALINA SCHERBAKOVA	{"email": "scherbakova_galina_25041960@postgrespro.ru", "phone": "+70132525099"}
0005432261147	CD6BA2	9624 113827	NATALYA MIKHAYLOVA	{"email": "mikhaylova.natalya1967@postgrespro.ru", "phone": "+70270534500"}
0005432261148	9D1E80	0448 167080	ANZHELA ISAEVA	{"email": "isaevaanzhela.081978@postgrespro.ru", "phone": "+70180322776"}
0005432261149	FDC2AF	6991 021312	NADEZHDA MIKHAYLOVA	{"phone": "+70057157138"}
0005432261150	4F9E01	9515 507108	ANDREY POPOV	{"email": "popov-a.17051972@postgrespro.ru", "phone": "+70237202999"}
0005432261151	4F9E01	9934 617557	TATYANA KUZNECOVA	{"phone": "+70905853972"}
0005432261152	4F9E01	0815 309694	YULIYA PAVLOVA	{"phone": "+70583083451"}
0005432261153	F80212	9773 293707	KRISTINA MEDVEDEVA	{"email": "kristina_medvedeva_1965@postgrespro.ru", "phone": "+70010061393"}
0005432261154	F80212	6878 735183	ELENA MAKSIMOVA	{"email": "e_maksimova.17071987@postgrespro.ru", "phone": "+70721758203"}
0005432261155	1D87DA	3557 100920	VALERIY TIKHONOV	{"email": "valeriy.tikhonov.031984@postgrespro.ru", "phone": "+70124019609"}
0005432261156	E33E4F	2067 586193	YULIYA KALININA	{"phone": "+70891074561"}
0005432261157	24B92D	9546 646390	IRINA SMIRNOVA	{"email": "ismirnova-101965@postgrespro.ru", "phone": "+70807944506"}
0005432261158	24B92D	7329 958912	VALENTINA ALEKSEEVA	{"email": "alekseeva-v.1966@postgrespro.ru", "phone": "+70508355709"}
0005432261159	00F515	1981 268802	OLEG OSIPOV	{"email": "o.osipov-031980@postgrespro.ru", "phone": "+70311393194"}
0005432261160	3B965E	7894 694051	ELENA KUZNECOVA	{"phone": "+70963976283"}
0005432261161	BC8FF1	8464 580104	IRINA TARASOVA	{"email": "i.tarasova-16121971@postgrespro.ru", "phone": "+70172257688"}
0005432261162	CC5347	6498 288392	GALINA SMIRNOVA	{"phone": "+70339641821"}
0005432261163	68BD91	2750 934481	VERONIKA NOVIKOVA	{"email": "novikovaveronika.1985@postgrespro.ru", "phone": "+70425059143"}
0005432261164	68BD91	8462 618806	ILYA GRIGOREV	{"phone": "+70863003124"}
0005432261165	3FC191	7202 088961	ALEKSEY KULIKOV	{"email": "a-kulikov_09071966@postgrespro.ru", "phone": "+70003549869"}
0005432261166	574F3C	0041 534993	ELENA TIMOFEEVA	{"phone": "+70999236803"}
0005432261167	03F2A5	2877 975677	DIANA TITOVA	{"email": "titova.diana-04091982@postgrespro.ru", "phone": "+70058920763"}
0005432261168	0A27E5	3893 260108	MAKSIM GUSEV	{"phone": "+70029737148"}
0005432261169	0A27E5	1921 315532	EVGENIY EGOROV	{"phone": "+70897835646"}
0005432261170	89C197	3204 367792	VIKTOR TIKHONOV	{"email": "tikhonov.v-1963@postgrespro.ru", "phone": "+70381028146"}
0005432261171	B43433	5136 746805	VALENTINA SCHERBAKOVA	{"email": "scherbakovavalentina-051977@postgrespro.ru", "phone": "+70962981546"}
0005432261172	0F9B71	3107 992351	DARYA MOISEEVA	{"email": "d.moiseeva-031968@postgrespro.ru", "phone": "+70676374282"}
0005432261173	98265F	7469 090370	DMITRIY KUDRYASHOV	{"email": "kudryashov.dmitriy_09081962@postgrespro.ru", "phone": "+70241121480"}
0005432261174	BFA484	3440 110396	OLGA KOROLEVA	{"email": "olgakoroleva05111975@postgrespro.ru", "phone": "+70101434298"}
0005432261175	14B0A0	1202 603115	SERGEY NAUMOV	{"email": "sergey-naumov.02011963@postgrespro.ru", "phone": "+70850899636"}
0005432261176	14B0A0	0545 721991	MARIYA PETROVA	{"email": "m_petrova051968@postgrespro.ru", "phone": "+70376888848"}
0005432261177	9B0FC7	8355 660213	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva.1973@postgrespro.ru", "phone": "+70470502776"}
0005432261178	7BDF8B	3025 748645	ZULFIYA ZAYCEVA	{"phone": "+70940860066"}
0005432261179	7BDF8B	1115 575099	NIKITA FOMIN	{"email": "fominnikita-1967@postgrespro.ru", "phone": "+70345995795"}
0005432261180	EEEF9A	1870 030079	DMITRIY VOROBEV	{"phone": "+70942004528"}
0005432261181	7A6F56	9271 691103	YULIYA KUZMINA	{"email": "ykuzmina_1984@postgrespro.ru", "phone": "+70503485396"}
0005432261182	7A6F56	6235 419442	ALEKSANDR STEPANOV	{"phone": "+70503350775"}
0005432261183	9333D5	3662 162847	IRINA IVANOVA	{"phone": "+70449085019"}
0005432261184	2F2F2A	2228 876418	ANASTASIYA ALEKSEEVA	{"email": "alekseeva.anastasiya_1959@postgrespro.ru", "phone": "+70916722918"}
0005432261185	2F2F2A	7482 274540	ANDREY MOROZOV	{"email": "morozovandrey_1966@postgrespro.ru", "phone": "+70887125681"}
0005432261186	5C17A9	8916 812266	SERGEY AFANASEV	{"phone": "+70587186589"}
0005432261187	180107	4345 801617	EKATERINA SOROKINA	{"email": "sorokinae051974@postgrespro.ru", "phone": "+70281100495"}
0005432261188	888FD1	5271 532553	GERMAN VOLKOV	{"phone": "+70557278055"}
0005432261189	365D52	3151 034522	GALINA KUZNECOVA	{"phone": "+70848791020"}
0005432261190	365D52	8028 543983	LYUBOV POLYAKOVA	{"phone": "+70164800065"}
0005432261191	74443F	0527 218505	MIKHAIL ILIN	{"email": "ilin_m_041977@postgrespro.ru", "phone": "+70699968351"}
0005432261192	5B92A1	0421 366428	ELENA FROLOVA	{"email": "frolova.e.111969@postgrespro.ru", "phone": "+70868119311"}
0005432261193	09CFF6	1591 747024	TATYANA KOLESNIKOVA	{"phone": "+70696693252"}
0005432261194	4AC7A5	8637 938279	OLEG MATVEEV	{"email": "matveev.o111979@postgrespro.ru", "phone": "+70459255674"}
0005432261195	0643BC	4824 148769	MIKHAIL SEMENOV	{"email": "m_semenov1964@postgrespro.ru", "phone": "+70774336563"}
0005432261196	1F3244	7580 963113	SERGEY ZAKHAROV	{"email": "sergey.zakharov.1962@postgrespro.ru", "phone": "+70092775703"}
0005432261197	13F6C4	8857 210876	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov-06071977@postgrespro.ru", "phone": "+70726816115"}
0005432261198	B66F9F	4460 742822	EVGENIYA BOGDANOVA	{"phone": "+70982872989"}
0005432261199	49BAC3	5686 951694	ALEKSEY NOVIKOV	{"email": "novikov.aleksey_29111984@postgrespro.ru", "phone": "+70988828816"}
0005432261200	8185D2	4220 097413	ANATOLIY GRIGOREV	{"email": "grigorev.a_1974@postgrespro.ru", "phone": "+70925585381"}
0005432261201	8185D2	6925 558793	ANTON ANDREEV	{"phone": "+70777320883"}
0005432261202	822310	2931 444983	VASILIY ILIN	{"phone": "+70860103581"}
0005432261203	02260E	0147 804588	ALEKSANDR MELNIKOV	{"phone": "+70516586061"}
0005432261204	C9919E	3134 812148	OLESYA ZAYCEVA	{"phone": "+70118847248"}
0005432261205	B6E5EB	4588 084751	VALENTINA ILINA	{"email": "ilina-v.031983@postgrespro.ru", "phone": "+70795885884"}
0005432261206	B6E5EB	2247 173166	OLGA POTAPOVA	{"email": "o_potapova-1969@postgrespro.ru", "phone": "+70592170368"}
0005432261207	B6E5EB	8984 900652	NATALYA NIKOLAEVA	{"phone": "+70862409284"}
0005432261208	21209E	0804 510234	EDUARD FOMIN	{"phone": "+70332914489"}
0005432261209	1C1137	7618 832198	ANASTASIYA ISAEVA	{"phone": "+70685285003"}
0005432261210	1C1137	1888 815711	MARIYA KUZNECOVA	{"phone": "+70914603212"}
0005432261211	366FD7	6891 936363	VASILIY DMITRIEV	{"phone": "+70856088928"}
0005432261212	8C56A0	0780 258150	ZINAIDA SIDOROVA	{"email": "zinaida.sidorova21121974@postgrespro.ru", "phone": "+70498488646"}
0005432261213	222BBD	3222 656518	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-1974@postgrespro.ru", "phone": "+70982889740"}
0005432261214	1E8128	2423 206925	VIKTOR DMITRIEV	{"phone": "+70120069481"}
0005432261215	1E8128	8101 630601	VLADIMIR FROLOV	{"email": "frolov-vladimir-25031973@postgrespro.ru", "phone": "+70005651157"}
0005432261216	1E8128	4856 815230	ANDREY KONOVALOV	{"email": "andrey.konovalov_091969@postgrespro.ru", "phone": "+70238590382"}
0005432261217	A43E49	3802 957305	YURIY PAVLOV	{"email": "pavlov.yuriy_18091977@postgrespro.ru", "phone": "+70144838425"}
0005432261218	1330B8	8451 964333	ALEKSANDR TIMOFEEV	{"phone": "+70594839475"}
0005432261579	605CF0	9159 607630	OLEG MEDVEDEV	{"phone": "+70213466138"}
0005432261219	1330B8	4623 344633	TATYANA IVANOVA	{"email": "ivanova_tatyana-091972@postgrespro.ru", "phone": "+70524578751"}
0005432261220	4B6476	5942 322589	ANTONINA SEMENOVA	{"email": "antoninasemenova101974@postgrespro.ru", "phone": "+70589586591"}
0005432261221	FC1BEC	6567 667525	VERA BARANOVA	{"email": "v_baranova_09011967@postgrespro.ru", "phone": "+70208179947"}
0005432261222	8BEA00	3268 861817	TATYANA KISELEVA	{"email": "kiselevat_31031976@postgrespro.ru", "phone": "+70265494111"}
0005432261223	8BEA00	6352 069350	ELENA NIKOLAEVA	{"phone": "+70410985836"}
0005432261224	518668	3055 521626	SVETLANA TIMOFEEVA	{"email": "svetlana_timofeeva_31121964@postgrespro.ru", "phone": "+70052269975"}
0005432261225	518668	5377 305935	ANASTASIYA EFREMOVA	{"email": "efremovaa1973@postgrespro.ru", "phone": "+70090710015"}
0005432261226	518668	7005 579965	VIKTORIYA OSIPOVA	{"phone": "+70272630885"}
0005432261227	7C0E3C	5386 361995	DMITRIY KONOVALOV	{"email": "dmitriykonovalov_13091985@postgrespro.ru", "phone": "+70222397110"}
0005432261228	2EE811	2189 385630	VALENTINA KRASNOVA	{"email": "valentina.krasnova1978@postgrespro.ru", "phone": "+70265673400"}
0005432261229	2EE811	1515 286696	ANASTASIYA PETROVA	{"email": "petrova.anastasiya-04121979@postgrespro.ru", "phone": "+70746230186"}
0005432261230	05940C	3301 259299	VLADIMIR KUZNECOV	{"phone": "+70480104651"}
0005432261231	4EBC87	4720 143746	YULIYA FROLOVA	{"phone": "+70522906677"}
0005432261232	B01672	7672 913189	MARIYA CHERNOVA	{"email": "chernova-mariya_101978@postgrespro.ru", "phone": "+70735132845"}
0005432261233	B01672	9406 992586	VALERIY MOROZOV	{"email": "morozov_valeriy_1977@postgrespro.ru", "phone": "+70864747770"}
0005432261234	2886A1	0019 121078	SERGEY SOKOLOV	{"email": "ssokolov_1971@postgrespro.ru", "phone": "+70355557534"}
0005432261235	2886A1	0709 327211	ROMAN MIKHAYLOV	{"phone": "+70380508550"}
0005432261236	2886A1	4753 512614	ANTONINA SERGEEVA	{"email": "sergeeva-a.041971@postgrespro.ru", "phone": "+70029996364"}
0005432261237	2538D4	5886 745167	ALEKSANDR OSIPOV	{"email": "a_osipov-031968@postgrespro.ru", "phone": "+70146733802"}
0005432261238	AA8C41	4531 940245	VIKTOR BELOV	{"phone": "+70465315547"}
0005432261239	87A973	3190 677036	TATYANA AFANASEVA	{"phone": "+70268809108"}
0005432261240	6040DB	8186 827827	ANDREY DENISOV	{"phone": "+70583318195"}
0005432261241	6040DB	5410 517811	SERGEY ANDREEV	{"email": "sergey-andreev-091970@postgrespro.ru", "phone": "+70549019438"}
0005432261242	F18DA1	5079 106549	IGOR BELOV	{"email": "i_belov.1972@postgrespro.ru", "phone": "+70200957771"}
0005432261243	BADFCC	8521 079402	VLADIMIR KUZNECOV	{"email": "v.kuznecov.10111977@postgrespro.ru", "phone": "+70533127184"}
0005432261244	BADFCC	4297 472221	ANVAR FILIPPOV	{"phone": "+70962154920"}
0005432261245	B2250B	2782 343071	ALINA NESTEROVA	{"phone": "+70532955753"}
0005432261246	B2250B	1158 907965	NIKITA DMITRIEV	{"phone": "+70860249165"}
0005432261247	B2250B	0094 272954	MARINA MAKAROVA	{"email": "makarova_marina_1974@postgrespro.ru", "phone": "+70856550253"}
0005432261248	B2250B	0820 439498	MIKHAIL PETROV	{"email": "mikhail_petrov_1969@postgrespro.ru", "phone": "+70043962639"}
0005432261249	D8B293	3158 049928	TATYANA SERGEEVA	{"phone": "+70048174620"}
0005432261250	D8B293	1880 014800	PAVEL NIKOLAEV	{"phone": "+70132520771"}
0005432261251	993299	4142 977673	SERGEY GERASIMOV	{"phone": "+70290095418"}
0005432261252	993299	2156 464960	ANATOLIY ISAEV	{"phone": "+70377188800"}
0005432261253	98BAED	5527 845812	ILDAR MAKSIMOV	{"phone": "+70651837952"}
0005432261254	AFF437	2826 913683	MARIYA ISAEVA	{"phone": "+70498819282"}
0005432261255	3D2276	7768 286321	VLADIMIR MIRONOV	{"email": "vladimir.mironov1969@postgrespro.ru", "phone": "+70274842207"}
0005432261256	3D2276	0001 461551	IGOR SOROKIN	{"email": "sorokin_igor-1966@postgrespro.ru", "phone": "+70575961423"}
0005432261257	3D2276	5523 279748	OLGA ZHUKOVA	{"phone": "+70895999044"}
0005432261258	6B2444	5426 135388	TAMARA DANILOVA	{"phone": "+70632700313"}
0005432261259	7F20B0	9587 247494	GALINA VOLKOVA	{"email": "volkova_galina1970@postgrespro.ru", "phone": "+70619384187"}
0005432261260	7F20B0	1898 370326	ARTEM POPOV	{"email": "popov.artem_041959@postgrespro.ru", "phone": "+70156702241"}
0005432261261	10ECDA	1914 800103	GALINA SCHERBAKOVA	{"email": "scherbakovag_1970@postgrespro.ru", "phone": "+70842441358"}
0005432261262	10ECDA	5338 843316	VIKTOR MAKAROV	{"phone": "+70656640498"}
0005432261263	D0760D	4799 486409	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev-31101974@postgrespro.ru", "phone": "+70230685697"}
0005432261264	511EA5	5638 555704	NADEZHDA RYABOVA	{"phone": "+70691774593"}
0005432261265	511EA5	2072 590091	DENIS KUZNECOV	{"email": "kuznecov-denis1977@postgrespro.ru", "phone": "+70972096713"}
0005432261266	936E93	7947 893307	DARYA KOROLEVA	{"email": "koroleva-d06051962@postgrespro.ru", "phone": "+70843214821"}
0005432261267	DDAFFC	8565 868397	NATALIYA KOZLOVA	{"phone": "+70043659255"}
0005432261268	96778D	4182 088061	NIKOLAY ISAEV	{"phone": "+70721463575"}
0005432261269	11DA73	9721 568441	IRINA ERMAKOVA	{"phone": "+70981355079"}
0005432261270	11DA73	6178 681975	VIKTOR AFANASEV	{"email": "afanasev-v.1977@postgrespro.ru", "phone": "+70501385340"}
0005432261271	D7CDF7	1809 664854	VALENTINA NAZAROVA	{"email": "nazarovav121968@postgrespro.ru", "phone": "+70640816330"}
0005432261272	D7CDF7	7278 369219	VIKTORIYA YUDINA	{"phone": "+70408314927"}
0005432261273	963401	5193 261206	SERGEY VASILEV	{"email": "vasilev_sergey14071972@postgrespro.ru", "phone": "+70968478551"}
0005432261274	963401	9884 231048	YULIYA ILINA	{"email": "y.ilina_051972@postgrespro.ru", "phone": "+70963772286"}
0005432261275	963401	0277 437324	VERONIKA NESTEROVA	{"phone": "+70910398498"}
0005432261276	6D37BF	2420 971697	MARINA BORISOVA	{"email": "borisova.m-12121968@postgrespro.ru", "phone": "+70760749506"}
0005432261277	7BABD8	8111 870327	SERGEY MELNIKOV	{"email": "melnikov.sergey081971@postgrespro.ru", "phone": "+70803846323"}
0005432261278	7BABD8	0519 649715	RAFIS IVANOV	{"phone": "+70407754801"}
0005432261279	8CCDDC	7259 664034	OLEG MARTYNOV	{"email": "oleg-martynov-1975@postgrespro.ru", "phone": "+70867710566"}
0005432261280	E299AE	6740 057234	TATYANA KONDRATEVA	{"email": "t.kondrateva-081979@postgrespro.ru", "phone": "+70357759290"}
0005432261281	E299AE	3290 193489	TATYANA SIDOROVA	{"phone": "+70468546112"}
0005432261282	E84C06	4045 450885	ALEKSANDR OSIPOV	{"email": "osipovaleksandr1959@postgrespro.ru", "phone": "+70324202428"}
0005432261283	12D670	6661 892444	ANNA ILINA	{"phone": "+70438143310"}
0005432261284	3EC05B	9461 167933	EVGENIY NOVIKOV	{"phone": "+70185017092"}
0005432261285	F3A471	7462 433481	VLADIMIR KUZNECOV	{"phone": "+70261787141"}
0005432261286	B8F8D4	7069 147014	ELENA MAKAROVA	{"phone": "+70483713574"}
0005432261287	C28C57	4260 123417	VLADISLAV KUZNECOV	{"email": "v.kuznecov1972@postgrespro.ru", "phone": "+70173596904"}
0005432261288	2A6854	8381 710593	SVETLANA FILIPPOVA	{"phone": "+70683160434"}
0005432261289	2A6854	7096 506593	MIKHAIL FILIPPOV	{"email": "filippovmikhail.081965@postgrespro.ru", "phone": "+70889529577"}
0005432261290	0E49C8	7159 911424	IRAIDA ROMANOVA	{"email": "romanova-iraida-1975@postgrespro.ru", "phone": "+70500017465"}
0005432261291	C769D1	1297 544523	ELENA NESTEROVA	{"phone": "+70837768129"}
0005432261292	073A0C	1791 054439	VLADIMIR VOROBEV	{"email": "vorobev-v_03041973@postgrespro.ru", "phone": "+70777700613"}
0005432261293	073A0C	5079 867591	LYUDMILA ANDREEVA	{"email": "l.andreeva051979@postgrespro.ru", "phone": "+70378239239"}
0005432261294	CACEC6	5970 843434	VALENTINA EGOROVA	{"email": "egorova-valentina_1981@postgrespro.ru", "phone": "+70665199461"}
0005432261295	CACEC6	1102 345624	IRINA VLASOVA	{"phone": "+70830449705"}
0005432261296	772CF4	8464 747220	SERGEY RODIONOV	{"phone": "+70922875218"}
0005432261297	772CF4	9656 821202	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev-091978@postgrespro.ru", "phone": "+70510759110"}
0005432261298	144B35	2505 948487	LIDIYA POPOVA	{"email": "popova_lidiya.1979@postgrespro.ru", "phone": "+70109294721"}
0005432261299	5F5F45	5810 675656	SERGEY SOROKIN	{"phone": "+70713390133"}
0005432261300	5F5F45	4674 850961	GALINA KISELEVA	{"email": "kiselevag.1960@postgrespro.ru", "phone": "+70770231252"}
0005432261301	D7E864	7594 347921	KIRILL SAVELEV	{"email": "savelev.kirill.24101968@postgrespro.ru", "phone": "+70381682402"}
0005432261302	83D0EC	1723 091955	YURIY ILIN	{"phone": "+70759475863"}
0005432261303	E650AC	5550 180344	YAKOV ANTONOV	{"email": "y.antonov_031966@postgrespro.ru", "phone": "+70988016942"}
0005432261304	E650AC	0877 891450	MARINA DENISOVA	{"email": "denisova_m.19101976@postgrespro.ru", "phone": "+70164411505"}
0005432261305	29FF30	5399 069328	RAISA MOROZOVA	{"email": "morozova_raisa_1966@postgrespro.ru", "phone": "+70511849569"}
0005432261306	D9ED02	6319 192657	ANDREY SAVELEV	{"email": "savelev.andrey1985@postgrespro.ru", "phone": "+70107199877"}
0005432261307	D9ED02	0184 169645	LEONID ZAKHAROV	{"email": "l.zakharov021982@postgrespro.ru", "phone": "+70626061353"}
0005432261308	D9ED02	4781 850363	ANNA ANDREEVA	{"phone": "+70216437453"}
0005432261309	0C7272	4337 293114	DMITRIY TIKHONOV	{"email": "dmitriy.tikhonov-14041964@postgrespro.ru", "phone": "+70455128605"}
0005432261310	DFCC6E	6227 344057	MARIYA TIKHONOVA	{"phone": "+70703407264"}
0005432261311	2EC0C3	2399 597358	SERGEY FEDOROV	{"phone": "+70257027024"}
0005432261312	1BB997	7862 462251	ELENA MALYSHEVA	{"email": "malysheva-elena.15041971@postgrespro.ru", "phone": "+70762076707"}
0005432261313	33C7C4	3559 497064	SERGEY MATVEEV	{"phone": "+70582960021"}
0005432261314	33C7C4	8628 451916	ANZHELA IVANOVA	{"phone": "+70384933400"}
0005432261315	050022	3390 997796	YURIY GERASIMOV	{"email": "gerasimov-yuriy_1971@postgrespro.ru", "phone": "+70562851328"}
0005432261316	4E49EB	8911 955332	VLADIMIR SMIRNOV	{"phone": "+70606524128"}
0005432261317	4E49EB	0264 166558	SVETLANA KOZLOVA	{"email": "kozlova_s.081966@postgrespro.ru", "phone": "+70447919927"}
0005432261318	E32E95	7916 709526	MAKSIM BARANOV	{"phone": "+70859639571"}
0005432261319	E32E95	6066 267174	LYUBOV ZHUKOVA	{"email": "zhukovalyubov.01121975@postgrespro.ru", "phone": "+70082177904"}
0005432261320	972DF4	9725 847160	ANDREY GRIGOREV	{"email": "a-grigorev_021972@postgrespro.ru", "phone": "+70346309779"}
0005432261321	972DF4	4396 838289	ALEKSANDR ISAEV	{"phone": "+70896051837"}
0005432261322	18C610	9881 792326	FEDOR STEPANOV	{"email": "stepanov_f.051968@postgrespro.ru", "phone": "+70163055778"}
0005432261323	1EF45A	6791 695045	ANNA NIKITINA	{"phone": "+70521976122"}
0005432261324	1A0C92	3139 086623	PAVEL GORBUNOV	{"email": "gorbunovpavel1970@postgrespro.ru", "phone": "+70507055588"}
0005432261325	1E55EC	4171 951112	LYUDMILA PETROVA	{"email": "petroval-1974@postgrespro.ru", "phone": "+70279950797"}
0005432261326	1E55EC	2374 686760	GALINA TIMOFEEVA	{"email": "g.timofeeva_21121977@postgrespro.ru", "phone": "+70909468739"}
0005432261327	1E55EC	9057 165015	ALEKSANDR POPOV	{"email": "popov-a_25101963@postgrespro.ru", "phone": "+70742143495"}
0005432261328	7F5C50	5632 525749	ELENA ALEKSEEVA	{"phone": "+70288135903"}
0005432261329	7F5C50	8860 262858	LIDIYA BELOVA	{"phone": "+70419377043"}
0005432261330	D98F4E	9555 057022	SVETLANA NESTEROVA	{"email": "nesterova_s-12021982@postgrespro.ru", "phone": "+70261258101"}
0005432261331	03971B	4093 265388	ELENA KULIKOVA	{"email": "kulikovae_071972@postgrespro.ru", "phone": "+70993905769"}
0005432261332	3D5331	4572 086031	DMITRIY FILIPPOV	{"email": "filippov-dmitriy1973@postgrespro.ru", "phone": "+70138790934"}
0005432261333	68B80F	1256 344212	YULIYA PAVLOVA	{"email": "pavlova_y.111975@postgrespro.ru", "phone": "+70647966717"}
0005432261334	0CF6EE	9219 939544	ANNA ZAKHAROVA	{"email": "azakharova09021962@postgrespro.ru", "phone": "+70009930398"}
0005432261335	A086BC	7240 062707	SERGEY ANDREEV	{"phone": "+70486853080"}
0005432261336	A086BC	7957 899301	LYUBOV SEMENOVA	{"phone": "+70973583388"}
0005432261337	D8763A	4410 433847	ALEKSANDR KUZMIN	{"phone": "+70488562989"}
0005432261338	2062D3	7286 609101	MARIYA STEPANOVA	{"email": "stepanova_m.07111971@postgrespro.ru", "phone": "+70172995989"}
0005432261339	2062D3	7865 906419	EVGENIY NIKITIN	{"phone": "+70984821385"}
0005432261340	758F0A	0046 399086	ELENA EGOROVA	{"email": "elena.egorova.091963@postgrespro.ru", "phone": "+70917511744"}
0005432261341	758F0A	7872 286821	ARSENIY SAVELEV	{"phone": "+70652850330"}
0005432261342	76FB47	5666 056309	ELIZAVETA NESTEROVA	{"email": "elizaveta-nesterova_1979@postgrespro.ru", "phone": "+70756497277"}
0005432261343	76FB47	8621 051971	VASILIY MELNIKOV	{"email": "vmelnikov_14061971@postgrespro.ru", "phone": "+70124255191"}
0005432261344	06CD30	0571 007357	ELENA TIKHONOVA	{"email": "tikhonovae.091981@postgrespro.ru", "phone": "+70446412220"}
0005432261345	06CD30	2749 195202	ALEKSANDR VASILEV	{"phone": "+70330908622"}
0005432261346	30F859	3246 119286	VIKTOR ORLOV	{"email": "orlov-viktor121979@postgrespro.ru", "phone": "+70850727180"}
0005432261347	B619BF	9660 778845	VALENTINA IVANOVA	{"phone": "+70926310053"}
0005432261348	BE23E6	8274 026472	VERA ANTONOVA	{"email": "antonova.vera.07041959@postgrespro.ru", "phone": "+70903627544"}
0005432261349	F61BC9	0386 517581	EVGENIYA ZOTOVA	{"email": "zotova_e-1969@postgrespro.ru", "phone": "+70881808055"}
0005432261350	F61BC9	3199 380889	NINA KUZNECOVA	{"email": "kuznecova-n.07081963@postgrespro.ru", "phone": "+70553651094"}
0005432261351	85D6AF	1537 197555	DARYA IVANOVA	{"phone": "+70151397294"}
0005432261352	605E44	5534 830557	EKATERINA MAKAROVA	{"phone": "+70779081806"}
0005432261353	E7C89B	7053 100828	SERGEY SEMENOV	{"phone": "+70124728865"}
0005432261354	E7C89B	4008 282843	NATALYA BARANOVA	{"phone": "+70629528468"}
0005432261355	BAE434	0322 032306	VYACHESLAV GERASIMOV	{"email": "gerasimovvyacheslav_1959@postgrespro.ru", "phone": "+70668558260"}
0005432261356	9A61F1	9257 705597	ALEKSEY PETROV	{"phone": "+70215346367"}
0005432261357	38C5A3	0357 298103	ANNA ALEKSEEVA	{"email": "alekseevaanna-1966@postgrespro.ru", "phone": "+70549459978"}
0005432261358	38C5A3	7535 633592	NIKOLAY MAKAROV	{"email": "makarov_n101968@postgrespro.ru", "phone": "+70643374895"}
0005432261359	F5FDF5	1658 539859	NIKITA AFANASEV	{"email": "afanasev.n.1968@postgrespro.ru", "phone": "+70507410061"}
0005432261360	44C764	9940 353505	VLADIMIR BORISOV	{"email": "vladimir-borisov_021986@postgrespro.ru", "phone": "+70594066079"}
0005432261361	44C764	0386 163935	YURIY FEDOROV	{"phone": "+70385160286"}
0005432261362	0658A8	5437 686240	EVGENIY KUZNECOV	{"email": "e_kuznecov1971@postgrespro.ru", "phone": "+70272025120"}
0005432261363	0658A8	1322 262046	YULIYA NIKITINA	{"email": "ynikitina_1975@postgrespro.ru", "phone": "+70411281469"}
0005432261364	BCC0DD	1008 511155	NATALIYA PETROVA	{"phone": "+70964396434"}
0005432261365	79E57C	7288 544947	EVGENIY MAKSIMOV	{"email": "e.maksimov_16101980@postgrespro.ru", "phone": "+70473912817"}
0005432261366	79E57C	4392 707089	DMITRIY BARANOV	{"email": "baranov.dmitriy.02121966@postgrespro.ru", "phone": "+70682783621"}
0005432261367	9B6C95	6612 617050	SERGEY ABRAMOV	{"phone": "+70883285758"}
0005432261368	4FFA3B	8456 926968	MAKSIM NOVIKOV	{"email": "novikov-maksim.29111971@postgrespro.ru", "phone": "+70058731722"}
0005432261369	4FFA3B	8839 771748	DANIIL MEDVEDEV	{"email": "daniil-medvedev-1978@postgrespro.ru", "phone": "+70171096477"}
0005432261370	F5061A	9847 000611	SERGEY SCHERBAKOV	{"email": "scherbakov.s_1983@postgrespro.ru", "phone": "+70486963684"}
0005432261371	F5061A	8543 198967	OLGA FADEEVA	{"email": "o_fadeeva12031978@postgrespro.ru", "phone": "+70237422960"}
0005432261372	60BBEE	6348 705563	ANDREY KUZNECOV	{"phone": "+70720775268"}
0005432261373	E63958	1185 009253	VASILIY KISELEV	{"phone": "+70889748581"}
0005432261374	F97B55	9347 183198	STEPAN DENISOV	{"phone": "+70475698276"}
0005432261375	3C25A3	8201 022167	ALEKSANDRA MOROZOVA	{"phone": "+70389800778"}
0005432261376	042C2C	5253 318660	VLADIMIR NOVIKOV	{"email": "v_novikov-30121980@postgrespro.ru", "phone": "+70206521550"}
0005432261377	9EAE67	7436 955188	TAMARA SOROKINA	{"phone": "+70508759207"}
0005432261378	9EAE67	6506 787307	LIDIYA KOROLEVA	{"phone": "+70802045245"}
0005432261379	5F37CA	5332 424723	OLGA MARTYNOVA	{"phone": "+70014012684"}
0005432261380	302CA0	2434 350493	SVETLANA SMIRNOVA	{"email": "smirnova-s_04061976@postgrespro.ru", "phone": "+70008241353"}
0005432261381	047FDF	6325 378355	VIKTOR TIKHONOV	{"phone": "+70298209890"}
0005432261382	A081B3	8357 647400	LYUBOV NIKOLAEVA	{"email": "l.nikolaeva_02121978@postgrespro.ru", "phone": "+70591671083"}
0005432261383	2E8474	8655 653785	MAKSIM SHEVCHENKO	{"email": "shevchenko-m1968@postgrespro.ru", "phone": "+70088873527"}
0005432261384	2E8474	1881 380650	ALEKSANDR MARTYNOV	{"email": "aleksandr_martynov_101975@postgrespro.ru", "phone": "+70545129342"}
0005432261385	74F145	4157 230417	ANDREY GERASIMOV	{"email": "gerasimov-a.1966@postgrespro.ru", "phone": "+70289935359"}
0005432261386	74F145	1824 178005	VIKTOR VLASOV	{"email": "vlasov.viktor1971@postgrespro.ru", "phone": "+70206785480"}
0005432261387	9D2CA5	5397 138681	YURIY ALEKSEEV	{"email": "alekseevy-1957@postgrespro.ru", "phone": "+70727711461"}
0005432261388	21057C	0423 539774	ANASTASIYA VASILEVA	{"email": "vasileva_anastasiya_01111971@postgrespro.ru", "phone": "+70046003304"}
0005432261389	21057C	5971 974602	ALEKSANDRA FILIPPOVA	{"phone": "+70977990945"}
0005432261390	21057C	0250 892784	DARYA ALEKSEEVA	{"email": "alekseevadarya.1981@postgrespro.ru", "phone": "+70026148382"}
0005432261391	A320C0	8635 374400	NATALYA SOKOLOVA	{"email": "sokolovanatalya-15091974@postgrespro.ru", "phone": "+70919716180"}
0005432261392	8F92FE	4800 929117	OLGA VASILEVA	{"email": "olga_vasileva_07081974@postgrespro.ru", "phone": "+70908481526"}
0005432261393	B7FDCB	1376 045760	SERGEY ISAEV	{"phone": "+70187379680"}
0005432261394	B7FDCB	2726 409174	TIMUR NAZAROV	{"email": "nazarov.t_1969@postgrespro.ru", "phone": "+70543502837"}
0005432261395	3D220C	0016 932407	NADEZHDA NESTEROVA	{"phone": "+70760031771"}
0005432261396	3D220C	1537 866189	OLGA TIMOFEEVA	{"email": "timofeeva.o_09041965@postgrespro.ru", "phone": "+70939359205"}
0005432261397	D0414E	9404 579213	VLADIMIR SIDOROV	{"phone": "+70391083247"}
0005432261398	D0414E	2997 108336	ELENA KOROLEVA	{"phone": "+70170294436"}
0005432261399	8D53EF	0311 669336	ANDREY DENISOV	{"phone": "+70663954714"}
0005432261400	BA3180	2080 090867	ALEKSANDR ABRAMOV	{"email": "abramov.a13081979@postgrespro.ru", "phone": "+70518252612"}
0005432261401	88D5DA	8507 238746	VITALIY FOMIN	{"phone": "+70132580642"}
0005432261402	3E6022	8567 863081	LIDIYA KALININA	{"phone": "+70658227517"}
0005432261403	FD2A9D	8947 600733	TATYANA PETROVA	{"email": "petrovat021968@postgrespro.ru", "phone": "+70905377330"}
0005432261404	001D91	4990 282982	TATYANA MARTYNOVA	{"phone": "+70253326104"}
0005432261405	001D91	8432 069749	DMITRIY KUZNECOV	{"phone": "+70461652714"}
0005432261406	0BF97A	9529 955477	SVETLANA EFIMOVA	{"phone": "+70156300930"}
0005432261407	0BF97A	9626 474889	LARISA MIKHAYLOVA	{"phone": "+70332152027"}
0005432261408	30B92E	8097 757352	ELENA PETROVA	{"email": "petrovaelena_24091993@postgrespro.ru", "phone": "+70293217992"}
0005432261409	B57C91	3261 125617	VLADIMIR IVANOV	{"phone": "+70914084572"}
0005432261410	969AC7	3736 554965	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr-25071973@postgrespro.ru", "phone": "+70326360017"}
0005432261411	969AC7	6766 915021	ALIYA MOROZOVA	{"email": "morozovaa.21011967@postgrespro.ru", "phone": "+70236697691"}
0005432261412	969AC7	3355 824504	NATALYA BORISOVA	{"phone": "+70451136289"}
0005432261413	A49A55	7985 574586	ALEKSEY SAVELEV	{"email": "savelev_aleksey.30031964@postgrespro.ru", "phone": "+70130960077"}
0005432261414	659A61	6694 640863	STANISLAV MAKAROV	{"phone": "+70493098918"}
0005432261415	DCE00A	0229 398925	SVETLANA POPOVA	{"email": "popova.svetlana_121966@postgrespro.ru", "phone": "+70875726317"}
0005432261416	1D3DDF	6506 179577	OLEG SEMENOV	{"email": "semenov-oleg.10011985@postgrespro.ru", "phone": "+70635878311"}
0005432261417	F92894	8409 349682	VERA ZHUKOVA	{"email": "v_zhukova.1973@postgrespro.ru", "phone": "+70321744515"}
0005432261418	F92894	9865 568634	VALERIYA KULIKOVA	{"phone": "+70917490857"}
0005432261419	716B27	8524 335767	NIKOLAY GORBUNOV	{"email": "gorbunov.n_1976@postgrespro.ru", "phone": "+70927446773"}
0005432261420	716B27	2142 081282	VLADISLAV ORLOV	{"email": "vladislav.orlov-031975@postgrespro.ru", "phone": "+70683230100"}
0005432261421	716B27	3942 126882	VALENTINA NESTEROVA	{"phone": "+70164221106"}
0005432261422	75B031	5314 515668	ANGELINA ZAKHAROVA	{"email": "a_zakharova.091961@postgrespro.ru", "phone": "+70191717684"}
0005432261423	74B8C8	9469 706591	VALENTINA NIKOLAEVA	{"email": "nikolaeva_v.04071977@postgrespro.ru", "phone": "+70661638463"}
0005432261424	74B8C8	5059 335043	EDUARD IVANOV	{"email": "eivanov-04031966@postgrespro.ru", "phone": "+70946036407"}
0005432261425	033774	6670 753179	EGOR IVANOV	{"phone": "+70820688872"}
0005432261426	B6C765	6762 194891	EVGENIY PETROV	{"phone": "+70417609482"}
0005432261427	E9B4A7	1633 550205	ELIZAVETA DAVYDOVA	{"email": "davydovae_031970@postgrespro.ru", "phone": "+70654349895"}
0005432261428	31EC39	4367 963260	EVGENIYA FOMINA	{"phone": "+70247288723"}
0005432261429	F6FF2A	7197 297398	TATYANA CHERNOVA	{"email": "tatyana_chernova_1975@postgrespro.ru", "phone": "+70866581073"}
0005432261430	AFDC09	7912 402766	SOFYA MOISEEVA	{"email": "moiseeva_s071973@postgrespro.ru", "phone": "+70346143926"}
0005432261431	B1BE38	5311 291040	SERGEY MAKAROV	{"email": "makarov.sergey-01091971@postgrespro.ru", "phone": "+70576880331"}
0005432261432	1DA776	5522 666732	ANNA NAUMOVA	{"phone": "+70863005802"}
0005432261433	1DA776	8270 750201	SERGEY IVANOV	{"phone": "+70878136942"}
0005432261434	1FBB5D	2701 017445	VIKTOR STEPANOV	{"phone": "+70164364851"}
0005432261493	B6C30C	0998 390837	NATALYA BORISOVA	{"phone": "+70672141916"}
0005432261435	D2F080	1303 375466	NIKOLAY ZAKHAROV	{"email": "n-zakharov-071962@postgrespro.ru", "phone": "+70825370943"}
0005432261436	D2F080	4646 271992	LARISA NESTEROVA	{"phone": "+70597454900"}
0005432261437	01ED6C	7756 229512	VALERIY BELOV	{"phone": "+70558043513"}
0005432261438	D79230	0072 623629	VALENTINA GORBUNOVA	{"phone": "+70212958879"}
0005432261439	D79230	0029 933112	GALINA ALEKSANDROVA	{"phone": "+70462112593"}
0005432261440	1F7A5E	2228 151784	ALEKSANDR ANTONOV	{"email": "antonov-a.02111978@postgrespro.ru", "phone": "+70374870954"}
0005432261441	0BC5BD	5885 925678	NIKITA SERGEEV	{"phone": "+70646093209"}
0005432261442	7AE8EE	3679 840166	OLGA AFANASEVA	{"phone": "+70910977907"}
0005432261443	8154B2	4291 618169	LARISA KUZMINA	{"phone": "+70120022621"}
0005432261444	F4071D	9732 238721	ELENA YUDINA	{"email": "e_yudina-1962@postgrespro.ru", "phone": "+70015170669"}
0005432261445	89AFFB	8583 018460	MARINA ZAKHAROVA	{"phone": "+70658551446"}
0005432261446	57C8CC	1688 694904	TATYANA ANDREEVA	{"email": "andreevatatyana.12021967@postgrespro.ru", "phone": "+70293658315"}
0005432261447	57C8CC	3141 650118	ANATOLIY GAVRILOV	{"phone": "+70216960402"}
0005432261448	57C8CC	5899 224575	TATYANA SOROKINA	{"phone": "+70460683757"}
0005432261449	57C8CC	7995 710094	DARYA ALEKSEEVA	{"phone": "+70760615774"}
0005432261450	7A0606	1986 353348	DMITRIY NOVIKOV	{"phone": "+70319222987"}
0005432261451	D43113	2898 288022	NATALYA DANILOVA	{"phone": "+70692806872"}
0005432261452	209BB4	5554 308100	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey.021968@postgrespro.ru", "phone": "+70504642511"}
0005432261453	8BF6AF	3291 387568	DARYA FADEEVA	{"phone": "+70287531309"}
0005432261454	73724A	6174 255807	SERGEY DAVYDOV	{"email": "s.davydov021971@postgrespro.ru", "phone": "+70354888450"}
0005432261455	73724A	6046 205120	OLEG MAKAROV	{"email": "makarovoleg091978@postgrespro.ru", "phone": "+70003913780"}
0005432261456	A45802	8993 950125	SERGEY OSIPOV	{"phone": "+70331786384"}
0005432261457	89901E	1866 008418	VALENTINA FROLOVA	{"email": "frolova-v-041976@postgrespro.ru", "phone": "+70275742323"}
0005432261458	8F1135	8741 315402	TATYANA DENISOVA	{"email": "denisovat.021968@postgrespro.ru", "phone": "+70133538207"}
0005432261459	8F1135	8596 246757	IRINA SEMENOVA	{"email": "i.semenova.01121978@postgrespro.ru", "phone": "+70225726168"}
0005432261460	C68C6D	5475 177602	YURIY SAVELEV	{"email": "y-savelev.08011976@postgrespro.ru", "phone": "+70306188857"}
0005432261461	EFF527	1624 562181	MARINA FOMINA	{"email": "marina-fomina_1976@postgrespro.ru", "phone": "+70687981316"}
0005432261462	D0925D	1101 681584	LYUBOV DANILOVA	{"email": "l_danilova.081981@postgrespro.ru", "phone": "+70044982349"}
0005432261463	5CA8A9	3234 719045	IVAN SEMENOV	{"phone": "+70745948863"}
0005432261464	726911	0503 945132	ANTON KUZMIN	{"phone": "+70725307247"}
0005432261465	BAA200	5812 410841	TAMARA STEPANOVA	{"phone": "+70799031732"}
0005432261466	BAA200	8780 273269	ZLATA MOROZOVA	{"email": "morozovazlata-081974@postgrespro.ru", "phone": "+70819459873"}
0005432261467	ED9B38	0145 497132	EKATERINA DANILOVA	{"email": "danilovae031982@postgrespro.ru", "phone": "+70591651763"}
0005432261468	ED9B38	9628 567875	ANDREY KUZMIN	{"phone": "+70884424559"}
0005432261469	522123	7521 260631	OKSANA KOZLOVA	{"email": "oksana-kozlova111977@postgrespro.ru", "phone": "+70946783736"}
0005432261470	384C8F	8786 755277	VALENTINA GAVRILOVA	{"email": "gavrilova-v_1977@postgrespro.ru", "phone": "+70067019251"}
0005432261471	60E78C	1687 546514	VALERIY POPOV	{"email": "popov_valeriy1971@postgrespro.ru", "phone": "+70371179543"}
0005432261472	60E78C	9820 215986	NIKOLAY BORISOV	{"email": "borisov-n-11011969@postgrespro.ru", "phone": "+70492701182"}
0005432261473	60E78C	8286 168490	YURIY PAVLOV	{"phone": "+70285706922"}
0005432261474	354F6A	3949 551406	NADEZHDA ALEKSEEVA	{"phone": "+70804021507"}
0005432261475	667806	5320 301090	NATALYA SEMENOVA	{"phone": "+70937781013"}
0005432261476	581D3E	4837 839490	ALEKSANDR KULIKOV	{"phone": "+70198026266"}
0005432261477	95A375	6918 380937	SERGEY FROLOV	{"email": "s_frolov1965@postgrespro.ru", "phone": "+70339147044"}
0005432261478	95A375	2080 234792	ALEKSANDR GRIGOREV	{"phone": "+70915921460"}
0005432261479	95A375	2759 224197	MARIYA ILINA	{"email": "ilina_mariya_1975@postgrespro.ru", "phone": "+70583771129"}
0005432261480	8A942A	3055 478554	LIDIYA FOMINA	{"email": "lidiya-fomina_08011981@postgrespro.ru", "phone": "+70242039920"}
0005432261481	986B39	2362 991739	ANTON NAUMOV	{"phone": "+70284356021"}
0005432261482	986B39	1367 931315	NATALYA NIKOLAEVA	{"phone": "+70599771120"}
0005432261483	B317C8	8181 084041	YURIY VLASOV	{"phone": "+70388225863"}
0005432261484	477267	3076 019842	OLEG KULIKOV	{"phone": "+70395715160"}
0005432261485	8DB4F2	6318 720529	NIKITA MOROZOV	{"phone": "+70493433222"}
0005432261486	8DB4F2	8914 870425	NONNA SEMENOVA	{"phone": "+70978214545"}
0005432261487	852D24	1005 605212	NIKOLAY ZAYCEV	{"email": "n-zaycev_12121967@postgrespro.ru", "phone": "+70290414352"}
0005432261488	432708	3476 192821	TATYANA KONOVALOVA	{"phone": "+70377937541"}
0005432261489	2D8681	4205 064297	ANASTASIYA FILATOVA	{"phone": "+70029409004"}
0005432261490	49FF40	0274 609057	VALENTINA SERGEEVA	{"phone": "+70629935723"}
0005432261491	572ABD	4630 347945	ANDREY BARANOV	{"phone": "+70937331197"}
0005432261492	572ABD	1961 322705	LYUDMILA ABRAMOVA	{"email": "lyudmila-abramova1974@postgrespro.ru", "phone": "+70306758211"}
0005432261494	1D5B66	9637 671909	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay-081978@postgrespro.ru", "phone": "+70391369044"}
0005432261495	DA42B5	4514 452497	MIKHAIL MIRONOV	{"phone": "+70142475978"}
0005432261496	9ACC2A	0871 518002	GRIGORIY DENISOV	{"email": "denisov-g-09071970@postgrespro.ru", "phone": "+70846219870"}
0005432261497	9ACC2A	9515 312857	ANTON EGOROV	{"phone": "+70065276940"}
0005432261498	EE5B78	7359 812113	ANNA SERGEEVA	{"email": "anna.sergeeva031977@postgrespro.ru", "phone": "+70370455678"}
0005432261499	EE5B78	6882 914136	IRINA FROLOVA	{"email": "frolova-irina_091965@postgrespro.ru", "phone": "+70309300908"}
0005432261500	2B04D7	4203 056848	ALEKSEY DAVYDOV	{"phone": "+70321046976"}
0005432261501	2B04D7	8538 973826	ALEKSEY EGOROV	{"phone": "+70936041541"}
0005432261502	9DB6F5	1759 914685	ALEKSANDRA LAZAREVA	{"phone": "+70297596246"}
0005432261503	BDE2A2	3492 841538	ALINA RODIONOVA	{"phone": "+70424572408"}
0005432261504	BDE2A2	4704 572455	GRIGORIY MAKAROV	{"email": "makarov.grigoriy.101966@postgrespro.ru", "phone": "+70710214977"}
0005432261505	93F2E2	2549 905004	YULIYA POLYAKOVA	{"phone": "+70664307273"}
0005432261506	93F2E2	6025 710345	VITALIY SIDOROV	{"phone": "+70841550897"}
0005432261507	93F2E2	8568 023727	GALINA POPOVA	{"phone": "+70608971315"}
0005432261508	6BCC62	0220 395482	LARISA SOROKINA	{"phone": "+70148917664"}
0005432261509	4A93BC	4890 173944	LYUDMILA ABRAMOVA	{"email": "l-abramova.1965@postgrespro.ru", "phone": "+70574114728"}
0005432261510	429DFA	6396 707868	VERONIKA KRASNOVA	{"email": "veronika.krasnova.1968@postgrespro.ru", "phone": "+70681657856"}
0005432261511	429DFA	1059 174487	KRISTINA ROMANOVA	{"email": "romanova-k.09071974@postgrespro.ru", "phone": "+70687081424"}
0005432261512	87FAC6	9974 827195	IVAN ZAKHAROV	{"phone": "+70180977536"}
0005432261513	1B0974	4381 249499	NIKOLAY KRASNOV	{"phone": "+70897691133"}
0005432261514	CDC302	9966 992670	EKATERINA DMITRIEVA	{"email": "dmitrievae24021966@postgrespro.ru", "phone": "+70641761122"}
0005432261515	738846	6562 131702	ANDREY IVANOV	{"email": "ivanov_andrey-071964@postgrespro.ru", "phone": "+70822426804"}
0005432261516	738846	6173 404024	MIKHAIL DENISOV	{"email": "denisov-m-22061969@postgrespro.ru", "phone": "+70400812129"}
0005432261517	BECE31	4711 331084	PAVEL FILIPPOV	{"email": "filippov.p_29121970@postgrespro.ru", "phone": "+70199415839"}
0005432261518	862C49	4961 635966	INNA BELYAEVA	{"email": "belyaeva.inna_1978@postgrespro.ru", "phone": "+70567021343"}
0005432261519	A9D1B3	9227 543639	YURIY IVANOV	{"email": "y_ivanov.1975@postgrespro.ru", "phone": "+70076665076"}
0005432261520	C14763	4440 011371	DANIIL PAVLOV	{"phone": "+70416012057"}
0005432261521	FF3182	1848 311216	RUSLAN MOROZOV	{"email": "ruslan_morozov_051961@postgrespro.ru", "phone": "+70338485408"}
0005432261522	E07C22	4957 386835	POLINA GUSEVA	{"email": "guseva_polina-1969@postgrespro.ru", "phone": "+70578595918"}
0005432261523	E07C22	6228 617408	VLADISLAV KULIKOV	{"phone": "+70693633907"}
0005432261524	D7D91C	5091 964107	YULIYA KOVALEVA	{"phone": "+70638925368"}
0005432261525	B4F787	8401 492905	VLADISLAV SOKOLOV	{"phone": "+70764627863"}
0005432261526	AF62B5	6131 736619	NINA SMIRNOVA	{"email": "smirnovanina-041978@postgrespro.ru", "phone": "+70656892988"}
0005432261527	AF62B5	5815 453992	NIKOLAY ZAKHAROV	{"phone": "+70991651280"}
0005432261528	915F83	1068 661716	TATYANA ILINA	{"phone": "+70977168162"}
0005432261529	915F83	1471 132515	SVETLANA SEMENOVA	{"email": "ssemenova.1971@postgrespro.ru", "phone": "+70210886856"}
0005432261530	915F83	9303 279904	VIKTORIYA YAKOVLEVA	{"phone": "+70780356714"}
0005432261531	5D407A	0445 127477	DAMIR FILIPPOV	{"phone": "+70323668362"}
0005432261532	A13EA4	1721 601343	VIKTOR KULIKOV	{"email": "viktorkulikov17051981@postgrespro.ru", "phone": "+70655370162"}
0005432261533	D526A4	9305 225168	TATYANA MAKSIMOVA	{"email": "tatyana_maksimova_1977@postgrespro.ru", "phone": "+70316937807"}
0005432261534	22637F	4771 441046	ANATOLIY KUZNECOV	{"phone": "+70260501308"}
0005432261535	184EB3	2405 486000	ANTON FOMIN	{"email": "fomin.a_24061966@postgrespro.ru", "phone": "+70421509454"}
0005432261536	184EB3	6250 213337	NIKOLAY FOMIN	{"email": "nikolayfomin-12081982@postgrespro.ru", "phone": "+70253465673"}
0005432261537	C6D4D8	5770 399867	DANILA YAKOVLEV	{"email": "yakovlev-d1974@postgrespro.ru", "phone": "+70155139255"}
0005432261538	C6D4D8	9434 348430	VALENTIN DAVYDOV	{"phone": "+70868458758"}
0005432261539	1F0EAC	2488 808095	NATALIYA STEPANOVA	{"email": "stepanova_nataliya-061972@postgrespro.ru", "phone": "+70406719418"}
0005432261540	412E47	4600 284046	SVETLANA KOROLEVA	{"phone": "+70903366606"}
0005432261541	412E47	4588 071895	ALEKSANDR KISELEV	{"email": "aleksandr-kiselev_18011971@postgrespro.ru", "phone": "+70820100548"}
0005432261542	35969C	4175 913602	TATYANA EGOROVA	{"phone": "+70762690847"}
0005432261543	35969C	4733 544245	EKATERINA BELOVA	{"phone": "+70330437355"}
0005432261544	C71974	5131 706972	NIKOLAY VLASOV	{"phone": "+70414914810"}
0005432261545	C71974	4955 094141	LYUDMILA MOISEEVA	{"email": "moiseeva.lyudmila-16091971@postgrespro.ru", "phone": "+70863787496"}
0005432261546	26BB01	2558 728400	MAKSIM ZAKHAROV	{"email": "zakharov-m04091974@postgrespro.ru", "phone": "+70234942513"}
0005432261547	B078FA	5936 913645	ELIZAVETA ANTONOVA	{"email": "antonova.elizaveta_15031976@postgrespro.ru", "phone": "+70436708741"}
0005432261548	57E4E8	8751 946328	NADEZHDA NAUMOVA	{"email": "nadezhda-naumova081982@postgrespro.ru", "phone": "+70936820371"}
0005432261549	57E4E8	1381 068163	RAVIL MELNIKOV	{"phone": "+70474699823"}
0005432261550	EC4717	5246 639147	EKATERINA ALEKSEEVA	{"email": "e_alekseeva1972@postgrespro.ru", "phone": "+70190767417"}
0005432261551	48E00E	7683 644636	LIDIYA OSIPOVA	{"phone": "+70663080731"}
0005432261552	48E00E	4778 310590	VALERIY FOMIN	{"email": "v.fomin.22071973@postgrespro.ru", "phone": "+70201708603"}
0005432261553	12E4EE	9888 575055	IVAN ZAKHAROV	{"phone": "+70242529739"}
0005432261554	BAFED6	0084 046481	VITALIY PETROV	{"phone": "+70224691652"}
0005432261555	DE6A01	0623 407619	IRINA SIDOROVA	{"email": "i.sidorova_13061968@postgrespro.ru", "phone": "+70677663244"}
0005432261556	BF6B8D	9952 780497	EKATERINA SMIRNOVA	{"phone": "+70899619325"}
0005432261557	6E0BB0	3035 521438	ALEKSANDR SCHERBAKOV	{"phone": "+70500886735"}
0005432261558	EDE3D2	2472 584838	ALEKSANDR NIKITIN	{"phone": "+70911298651"}
0005432261559	EDE3D2	5514 980188	GALINA SOROKINA	{"email": "sorokinagalina-1966@postgrespro.ru", "phone": "+70985352799"}
0005432261560	A47716	6343 137130	ALEKSEY DENISOV	{"phone": "+70605474846"}
0005432261561	A47716	7270 893716	YURIY FROLOV	{"email": "frolovy-03081967@postgrespro.ru", "phone": "+70657991385"}
0005432261562	D2A445	9453 327251	DMITRIY FEDOTOV	{"email": "dmitriy.fedotov_1982@postgrespro.ru", "phone": "+70489975589"}
0005432261563	FF5CCD	5380 483666	VERA MOROZOVA	{"email": "v.morozova-02041977@postgrespro.ru", "phone": "+70759623333"}
0005432261564	354BE2	1254 532360	VYACHESLAV EGOROV	{"email": "vyacheslav-egorov121972@postgrespro.ru", "phone": "+70842544709"}
0005432261565	78A82B	4967 587796	NIKOLAY NAUMOV	{"phone": "+70731934700"}
0005432261566	FD22DE	2332 203289	TATYANA POPOVA	{"phone": "+70352478245"}
0005432261567	2C1BD5	3478 112325	PETR ROMANOV	{"phone": "+70452180892"}
0005432261568	2C1BD5	8777 118377	ANDREY KUZMIN	{"phone": "+70623154570"}
0005432261569	943687	7190 185011	KRISTINA YAKOVLEVA	{"email": "yakovleva-kristina071968@postgrespro.ru", "phone": "+70623752172"}
0005432261570	943687	1001 273605	KIRILL SIDOROV	{"phone": "+70587424213"}
0005432261571	DEE7C9	3608 277966	LIDIYA LAZAREVA	{"email": "lazareva_lidiya_1974@postgrespro.ru", "phone": "+70895446582"}
0005432261572	DEE7C9	6900 039228	ALLA KUZNECOVA	{"email": "kuznecova-alla-10011971@postgrespro.ru", "phone": "+70936855288"}
0005432261573	52F34F	1414 709291	TARAS ALEKSEEV	{"email": "alekseev-taras-111992@postgrespro.ru", "phone": "+70610667803"}
0005432261574	1CABB6	6290 073268	MARINA SOROKINA	{"email": "sorokina.marina.101963@postgrespro.ru", "phone": "+70110186790"}
0005432261575	280E50	0832 782994	SVETLANA KONOVALOVA	{"phone": "+70248484631"}
0005432261576	9F5643	0601 824763	GENNADIY ANDREEV	{"email": "andreev_gennadiy.19081972@postgrespro.ru", "phone": "+70236410518"}
0005432261577	BD96CC	5600 752179	EKATERINA SEMENOVA	{"email": "semenovaekaterina_1970@postgrespro.ru", "phone": "+70576653880"}
0005432261578	BD96CC	7507 924788	NATALIYA ZOTOVA	{"phone": "+70863961357"}
0005432261580	EE5FE2	9309 109413	PAVEL KUZNECOV	{"email": "kuznecovp.1965@postgrespro.ru", "phone": "+70882143280"}
0005432261581	085565	6401 139261	TATYANA FEDOROVA	{"phone": "+70464953708"}
0005432261582	AC4F52	1381 543437	SVETLANA KUZNECOVA	{"phone": "+70024314577"}
0005432261583	471993	2277 286578	NAZAR ALEKSEEV	{"email": "alekseev_nazar1972@postgrespro.ru", "phone": "+70157139660"}
0005432261584	9C8AE6	2744 016170	LYUDMILA POPOVA	{"phone": "+70833447267"}
0005432261585	592F1F	4411 560283	ILYA DENISOV	{"email": "denisovi.071968@postgrespro.ru", "phone": "+70011252507"}
0005432261586	E8C039	4477 888780	GALINA PETROVA	{"phone": "+70966192781"}
0005432261587	E8C039	7687 105447	OLGA KULIKOVA	{"phone": "+70513357951"}
0005432261588	C266C9	4726 512669	NIKOLAY KUZMIN	{"email": "n.kuzmin-081973@postgrespro.ru", "phone": "+70948060090"}
0005432261589	263C96	5364 770230	SERGEY DAVYDOV	{"phone": "+70296496868"}
0005432261590	A3E26E	5185 029040	ALEKSEY DMITRIEV	{"email": "a-dmitriev091973@postgrespro.ru", "phone": "+70369119163"}
0005432261591	35B7AC	0147 144927	ANASTASIYA NAZAROVA	{"email": "nazarova.a1982@postgrespro.ru", "phone": "+70308114986"}
0005432261592	D80021	4717 411895	IRINA MELNIKOVA	{"phone": "+70890192250"}
0005432261593	D80021	6965 833138	EKATERINA ORLOVA	{"email": "ekaterina.orlova-1977@postgrespro.ru", "phone": "+70305975442"}
0005432261594	BB941F	9619 577704	SVETLANA MATVEEVA	{"phone": "+70012005623"}
0005432261595	BB941F	5551 781882	LILIYA YUDINA	{"email": "liliyayudina-121974@postgrespro.ru", "phone": "+70484117421"}
0005432261596	BB941F	3035 969675	GALINA SOKOLOVA	{"email": "gsokolova-011981@postgrespro.ru", "phone": "+70657915340"}
0005432261597	7B7F2A	6362 547124	VIKTOR AFANASEV	{"email": "vafanasev-1979@postgrespro.ru", "phone": "+70990080775"}
0005432261598	7B7F2A	7169 775098	IVAN KUZNECOV	{"phone": "+70470759835"}
0005432261599	24077D	9808 832087	ALEKSANDR PETROV	{"email": "a-petrov_21031974@postgrespro.ru", "phone": "+70883500445"}
0005432261600	4ABFE0	3850 699626	TATYANA BELYAEVA	{"phone": "+70831917947"}
0005432261601	ECF5E4	2254 708521	RENAT KUZNECOV	{"email": "renat-kuznecov_07041971@postgrespro.ru", "phone": "+70735538603"}
0005432261602	ECF5E4	3229 696823	LYUDMILA KOVALEVA	{"phone": "+70622354620"}
0005432261603	E09330	3976 659552	NATALYA KARPOVA	{"phone": "+70971095455"}
0005432261604	988A14	6978 975615	ANDREY RODIONOV	{"email": "andrey.rodionov.1974@postgrespro.ru", "phone": "+70156720730"}
0005432261605	988A14	2325 002692	EKATERINA BORISOVA	{"email": "e_borisova22101983@postgrespro.ru", "phone": "+70639117403"}
0005432261606	988A14	4421 824198	IRINA ANDREEVA	{"email": "irina-andreeva_091975@postgrespro.ru", "phone": "+70128064744"}
0005432261607	658597	8263 282739	KRISTINA POPOVA	{"email": "kristina_popova-02091981@postgrespro.ru", "phone": "+70057804491"}
0005432261608	C7AD40	7695 011348	IVAN IVANOV	{"phone": "+70565493181"}
0005432261609	C7AD40	8678 006311	TATYANA ILINA	{"phone": "+70666735070"}
0005432261610	B40105	0809 138923	DMITRIY FILIPPOV	{"email": "dmitriyfilippov13011972@postgrespro.ru", "phone": "+70371459218"}
0005432261611	400006	2679 206794	EVGENIY SCHERBAKOV	{"email": "escherbakov_02041968@postgrespro.ru", "phone": "+70881022613"}
0005432261612	86FD89	1241 351677	ROMAN IVANOV	{"phone": "+70275638368"}
0005432261613	89FAD0	5570 702613	NADEZHDA TARASOVA	{"email": "tarasovan18071980@postgrespro.ru", "phone": "+70192268168"}
0005432261614	761990	5594 464967	VLADIMIR FOMIN	{"email": "v.fomin1983@postgrespro.ru", "phone": "+70533411207"}
0005432261615	761990	9618 184987	MAYYA MOROZOVA	{"email": "morozova_m-051973@postgrespro.ru", "phone": "+70622254985"}
0005432261616	B1FA99	6919 037576	TATYANA KOROLEVA	{"phone": "+70474936684"}
0005432261617	159082	1298 261452	NATALYA ANISIMOVA	{"phone": "+70529000127"}
0005432261618	09B69F	5816 198956	PAVEL IVANOV	{"email": "ivanov.p.25081971@postgrespro.ru", "phone": "+70517948485"}
0005432261619	2AB2F6	9846 847847	MARIYA BARANOVA	{"email": "mariya-baranova081969@postgrespro.ru", "phone": "+70748151328"}
0005432261620	372B7D	8383 507659	VLADIMIR FROLOV	{"email": "vladimir.frolov-1975@postgrespro.ru", "phone": "+70413705163"}
0005432261621	A6A3FC	6865 810595	VLADIMIR MAKAROV	{"email": "v.makarov.071971@postgrespro.ru", "phone": "+70824929259"}
0005432261622	45DBE7	6203 488226	DENIS ILIN	{"phone": "+70865531189"}
0005432261623	419CB2	8200 450177	VLADISLAV ZHURAVLEV	{"phone": "+70132064793"}
0005432261624	B92EAB	7447 236060	LYUDMILA KALININA	{"email": "kalininalyudmila.041967@postgrespro.ru", "phone": "+70041583702"}
0005432261625	785691	3986 779644	NADEZHDA DANILOVA	{"email": "danilova_nadezhda05111960@postgrespro.ru", "phone": "+70652167098"}
0005432261626	FE0FD2	4377 467097	VASILIY GUSEV	{"phone": "+70723190237"}
0005432261627	FE0FD2	0847 735400	OLEG KAZAKOV	{"phone": "+70394659177"}
0005432261628	A55677	7695 255418	SVETLANA BOGDANOVA	{"phone": "+70453087142"}
0005432261629	A77FED	7447 206368	TATYANA GORBUNOVA	{"email": "t-gorbunova111965@postgrespro.ru", "phone": "+70767080663"}
0005432261630	A77FED	3624 774046	SERGEY IVANOV	{"phone": "+70661694895"}
0005432261631	6BC0A5	6419 422584	VERA DAVYDOVA	{"phone": "+70935990042"}
0005432261632	6BC0A5	3674 891310	NATALYA KULIKOVA	{"email": "natalya_kulikova.1973@postgrespro.ru", "phone": "+70461121582"}
0005432261633	CFF188	1200 759899	EVGENIY PETROV	{"email": "evgeniy.petrov_06121960@postgrespro.ru", "phone": "+70570578418"}
0005432261634	5601B0	2405 072090	OLGA KOVALEVA	{"email": "kovaleva.olga-29021968@postgrespro.ru", "phone": "+70703041730"}
0005432261635	706470	1320 321436	MARGARITA OVCHINNIKOVA	{"email": "ovchinnikova.margarita-1952@postgrespro.ru", "phone": "+70206849262"}
0005432261636	A98993	1344 860925	LYUDMILA EGOROVA	{"phone": "+70622653801"}
0005432261637	A98993	9900 594402	RAISA MAKSIMOVA	{"email": "maksimova.raisa111972@postgrespro.ru", "phone": "+70285983706"}
0005432261638	A8DAE7	1328 713135	TATYANA LUKYANOVA	{"phone": "+70222267695"}
0005432261639	7525CC	6241 691384	YULIYA GORBUNOVA	{"email": "y_gorbunova.071976@postgrespro.ru", "phone": "+70254754813"}
0005432261640	525621	1258 769049	VASILIY MEDVEDEV	{"email": "vasiliymedvedev_1974@postgrespro.ru", "phone": "+70633100945"}
0005432261641	525621	0589 014615	VLADIMIR ROMANOV	{"phone": "+70390224336"}
0005432261642	525621	4826 082921	ELIZAVETA KOLESNIKOVA	{"email": "e-kolesnikova-27021979@postgrespro.ru", "phone": "+70143165633"}
0005432261643	AC2E92	4473 212137	IRINA SCHERBAKOVA	{"phone": "+70242450846"}
0005432261644	AC2E92	0751 019166	VLADIMIR POPOV	{"phone": "+70851488871"}
0005432261645	54036D	8988 568062	TATYANA KUDRYASHOVA	{"phone": "+70088650905"}
0005432261646	D179B5	2575 834936	IVAN AFANASEV	{"phone": "+70740162853"}
0005432261647	2A4514	8226 181470	VIKTOR NAZAROV	{"phone": "+70200089187"}
0005432261648	2A4514	0393 043899	VERA AFANASEVA	{"phone": "+70634901519"}
0005432261649	8A758A	1816 136883	DMITRIY KUZMIN	{"email": "kuzmin-d_071965@postgrespro.ru", "phone": "+70973608449"}
0005432261650	A6BE58	9470 223207	GALINA MAKAROVA	{"email": "galinamakarova-18091965@postgrespro.ru", "phone": "+70799480463"}
0005432261651	71D49C	0763 832906	ANATOLIY VOLKOV	{"email": "a.volkov_1972@postgrespro.ru", "phone": "+70653781425"}
0005432261652	19C4BF	7675 899267	OLGA NIKOLAEVA	{"email": "nikolaeva.o_121965@postgrespro.ru", "phone": "+70956236297"}
0005432261653	59C96B	0393 463935	VYACHESLAV GERASIMOV	{"email": "gerasimov.v-1985@postgrespro.ru", "phone": "+70943708327"}
0005432261654	69DBDD	6948 376673	PAVEL EGOROV	{"email": "pavel_egorov.14021964@postgrespro.ru", "phone": "+70520567847"}
0005432261655	D56464	0367 514405	MARIYA OSIPOVA	{"email": "m-osipova.04041971@postgrespro.ru", "phone": "+70942177393"}
0005432261656	EAACEB	0169 481129	VERA TIMOFEEVA	{"phone": "+70403593353"}
0005432261657	EAACEB	8219 140523	VERA VOROBEVA	{"phone": "+70655162995"}
0005432261658	F0875E	1950 759765	MARINA SOKOLOVA	{"phone": "+70801514204"}
0005432261659	A41015	6565 435319	SVETLANA ORLOVA	{"email": "orlova.s.19071974@postgrespro.ru", "phone": "+70411242841"}
0005432261660	68A1B5	8170 048284	ALEKSANDR ANDREEV	{"email": "a_andreev_30121983@postgrespro.ru", "phone": "+70722664937"}
0005432261661	87B642	1527 570589	SERGEY FEDOTOV	{"phone": "+70912501291"}
0005432261662	2078EA	9011 193505	ANNA GAVRILOVA	{"email": "gavrilovaanna_03051981@postgrespro.ru", "phone": "+70586661238"}
0005432261663	2078EA	7907 053273	DENIS CHERNOV	{"email": "chernov_d_20021975@postgrespro.ru", "phone": "+70438188428"}
0005432261664	4C8222	9155 134907	EDUARD GAVRILOV	{"email": "gavrilov.eduard_05081979@postgrespro.ru", "phone": "+70236549038"}
0005432261665	08E16D	0277 350168	LYUDMILA MOISEEVA	{"phone": "+70559820077"}
0005432261666	02C21F	8713 460518	MARIYA LUKYANOVA	{"email": "lukyanovamariya_15081969@postgrespro.ru", "phone": "+70541652113"}
0005432261667	02C21F	9926 880222	VIKTOR SOLOVEV	{"email": "solovevviktor25111975@postgrespro.ru", "phone": "+70802301761"}
0005432261668	C059C4	6517 971838	VLADIMIR SOKOLOV	{"phone": "+70103360685"}
0005432261669	89E051	7155 913242	NATALYA KOVALEVA	{"email": "kovalevanatalya.081977@postgrespro.ru", "phone": "+70325244006"}
0005432261670	9A94F2	3810 571359	OLGA ZAYCEVA	{"phone": "+70087853244"}
0005432261671	621793	8959 079060	VIKTOR ZHUKOV	{"email": "zhukov_viktor1959@postgrespro.ru", "phone": "+70950045448"}
0005432261672	621793	5352 420420	LYUDMILA MOROZOVA	{"email": "l.morozova.1970@postgrespro.ru", "phone": "+70245875269"}
0005432261673	5370A8	7370 308755	TATYANA FROLOVA	{"phone": "+70418926572"}
0005432261674	CF0BFA	8050 629399	LIDIYA SCHERBAKOVA	{"phone": "+70886098937"}
0005432261675	65F2A4	7871 855255	NATALYA VLASOVA	{"email": "vlasovan_071982@postgrespro.ru", "phone": "+70770052711"}
0005432261676	E97CFA	6705 587865	SERGEY KOZLOV	{"email": "kozlov_sergey.1975@postgrespro.ru", "phone": "+70970904288"}
0005432261677	223526	5430 503280	YANA BELOVA	{"phone": "+70341896487"}
0005432261678	4212C5	5531 707397	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova.1966@postgrespro.ru", "phone": "+70042938690"}
0005432261679	4212C5	5221 921582	ANATOLIY SEMENOV	{"phone": "+70424986495"}
0005432261680	58953A	8441 157370	DMITRIY KOZLOV	{"phone": "+70018836978"}
0005432261681	947AB8	5943 285636	OLEG POPOV	{"phone": "+70066818723"}
0005432261682	947AB8	3049 291300	ANDREY PAVLOV	{"email": "pavlov_a26121967@postgrespro.ru", "phone": "+70760102715"}
0005432261683	41CCD2	9555 969031	YURIY NIKITIN	{"email": "yuriy-nikitin.20031969@postgrespro.ru", "phone": "+70064114421"}
0005432261684	41CCD2	3843 954872	TATYANA BELYAEVA	{"phone": "+70022750603"}
0005432261685	7D581E	9506 428762	ALEKSEY VLASOV	{"email": "vlasov.a.071969@postgrespro.ru", "phone": "+70575242923"}
0005432261686	AFFB73	7848 898311	NINA NIKOLAEVA	{"phone": "+70804649734"}
0005432261687	4282C6	7054 731040	OKSANA TITOVA	{"email": "titova.oksana_1976@postgrespro.ru", "phone": "+70591073887"}
0005432261688	B7BDE0	1837 395768	TIMUR ZAYCEV	{"phone": "+70910743336"}
0005432261689	0ED066	3820 922389	VLADIMIR RODIONOV	{"email": "vladimir-rodionov1966@postgrespro.ru", "phone": "+70478432488"}
0005432261690	647117	2096 937849	ALEKSANDR SERGEEV	{"email": "sergeev.a.11061976@postgrespro.ru", "phone": "+70175682340"}
0005432261691	13DD97	5513 930381	ANTONINA BORISOVA	{"phone": "+70546932937"}
0005432261692	13DD97	7698 325096	OLGA KRASNOVA	{"email": "o-krasnova1980@postgrespro.ru", "phone": "+70396880209"}
0005432261693	1D64CA	1390 990212	LYUDMILA LEBEDEVA	{"phone": "+70547684607"}
0005432261694	1D64CA	8528 234114	VERA KALININA	{"phone": "+70794287663"}
0005432261695	3842F9	8851 087881	RAISA FOMINA	{"phone": "+70644311043"}
0005432261696	475DD8	9122 578574	ANATOLIY KUZNECOV	{"phone": "+70595264011"}
0005432261697	DCA83D	9740 656414	ALEKSANDR ALEKSEEV	{"phone": "+70807188187"}
0005432261698	DCA83D	3549 053629	SERGEY FOMIN	{"phone": "+70671119773"}
0005432261760	297DCC	2919 174652	VALENTINA NIKITINA	{"phone": "+70303116574"}
0005432261699	D6856E	4144 258568	RUSLAN STEPANOV	{"email": "ruslan.stepanov.031973@postgrespro.ru", "phone": "+70333688786"}
0005432261700	5DE25D	3530 463021	ELENA KAZAKOVA	{"phone": "+70729304080"}
0005432261701	5DE25D	2871 006442	ALINA KISELEVA	{"email": "akiseleva.1968@postgrespro.ru", "phone": "+70783913145"}
0005432261702	6BD914	5570 137990	YULIYA NIKITINA	{"phone": "+70727360211"}
0005432261703	6BD914	3844 025485	ANATOLIY TARASOV	{"email": "anatoliytarasov.31071966@postgrespro.ru", "phone": "+70651874863"}
0005432261704	CA0B6B	5531 077287	VALERIY ALEKSANDROV	{"email": "valeriy-aleksandrov-08101978@postgrespro.ru", "phone": "+70655655543"}
0005432261705	EA6158	7253 179002	SERGEY MOROZOV	{"email": "sergeymorozov.08111975@postgrespro.ru", "phone": "+70851959876"}
0005432261706	9F2A8B	7919 851410	VERA KUZMINA	{"email": "kuzmina_v.11091966@postgrespro.ru", "phone": "+70918480525"}
0005432261707	15BB8F	9726 125224	SERGEY KOZLOV	{"email": "s.kozlov.1977@postgrespro.ru", "phone": "+70396796125"}
0005432261708	15BB8F	8370 366461	NATALYA IVANOVA	{"phone": "+70285915502"}
0005432261709	E0E2FD	2086 461334	BULAT TARASOV	{"email": "tarasov-b-031969@postgrespro.ru", "phone": "+70687121690"}
0005432261710	35CC23	8104 271682	NADEZHDA KOMAROVA	{"phone": "+70288631833"}
0005432261711	EB0334	4810 140727	ANDREY MELNIKOV	{"phone": "+70753071000"}
0005432261712	EB0334	4444 480507	ELENA DENISOVA	{"email": "elenadenisova16051975@postgrespro.ru", "phone": "+70982471270"}
0005432261713	3BF13B	1812 831991	TATYANA SOROKINA	{"phone": "+70364835417"}
0005432261714	AC2132	8117 964181	EKATERINA TARASOVA	{"email": "e-tarasova_1978@postgrespro.ru", "phone": "+70729332630"}
0005432261715	D49F90	7420 362404	LYUDMILA SIDOROVA	{"email": "l_sidorova.20081963@postgrespro.ru", "phone": "+70103767442"}
0005432261716	59C10E	4188 188506	MIKHAIL CHERNOV	{"email": "chernov-mikhail_1968@postgrespro.ru", "phone": "+70371693735"}
0005432261717	4CF52A	8382 803454	DMITRIY BELOV	{"phone": "+70067452469"}
0005432261718	1D44D9	5213 147316	ANATOLIY ALEKSANDROV	{"email": "aleksandrova-21071978@postgrespro.ru", "phone": "+70662608098"}
0005432261719	88D685	0549 478909	SVETLANA KAZAKOVA	{"phone": "+70012216843"}
0005432261720	88D685	5140 882079	ELENA ANTONOVA	{"email": "antonova_elena.011965@postgrespro.ru", "phone": "+70227408841"}
0005432261721	EEE23B	5356 174619	OLGA FEDOROVA	{"phone": "+70062247847"}
0005432261722	EEE23B	7166 489131	MIKHAIL PAVLOV	{"phone": "+70985267472"}
0005432261723	9CBECB	7097 869553	ANDREY MIKHAYLOV	{"phone": "+70179808173"}
0005432261724	9CBECB	3640 026577	KONSTANTIN FOMIN	{"phone": "+70096792811"}
0005432261725	7B20DE	1507 166737	VITALIY FEDOROV	{"email": "fedorov.v-10091973@postgrespro.ru", "phone": "+70452150927"}
0005432261726	290131	7126 070564	EMILIYA ZAYCEVA	{"phone": "+70205274631"}
0005432261727	BA988B	3719 624595	ALEKSANDRA MARTYNOVA	{"phone": "+70988223196"}
0005432261728	4A673B	5879 078688	TATYANA YUDINA	{"email": "yudina.t_051978@postgrespro.ru", "phone": "+70866760140"}
0005432261729	AB0D00	2691 148857	VLADIMIR POPOV	{"phone": "+70525934830"}
0005432261730	E2EC64	3307 551864	IVAN MELNIKOV	{"email": "i_melnikov.121967@postgrespro.ru", "phone": "+70874621031"}
0005432261731	B0701D	4150 774314	OLGA BORISOVA	{"phone": "+70233521702"}
0005432261732	B0701D	6710 266833	ANDREY NAZAROV	{"phone": "+70358465586"}
0005432261733	A269CD	2255 125094	YURIY KUZMIN	{"phone": "+70778761406"}
0005432261734	A269CD	5689 837881	VLADIMIR KISELEV	{"phone": "+70420245833"}
0005432261735	72F5DE	5780 215915	ANASTASIYA FROLOVA	{"email": "a-frolova_06071968@postgrespro.ru", "phone": "+70547687275"}
0005432261736	F5D339	6383 039429	DARYA ZAKHAROVA	{"email": "zakharova-darya-1964@postgrespro.ru", "phone": "+70829696200"}
0005432261737	8C086C	3201 514077	VALENTIN RODIONOV	{"email": "valentin_rodionov-1973@postgrespro.ru", "phone": "+70476899670"}
0005432261738	8C086C	4080 148859	SERGEY DENISOV	{"email": "sergey-denisov_011976@postgrespro.ru", "phone": "+70516875524"}
0005432261739	7035FF	2131 257222	OLEG ZAYCEV	{"email": "o-zaycev_1966@postgrespro.ru", "phone": "+70938243540"}
0005432261740	5871B8	7878 452077	DENIS RODIONOV	{"phone": "+70047698760"}
0005432261741	38B205	6946 837016	SERGEY GORBUNOV	{"email": "sergey.gorbunov071975@postgrespro.ru", "phone": "+70004862225"}
0005432261742	38B205	2296 986244	AYRAT IVANOV	{"phone": "+70386214716"}
0005432261743	3B56C3	7349 299955	RUSLAN CHERNOV	{"phone": "+70566325083"}
0005432261744	3ED98E	9152 457379	ALEKSEY SHEVCHENKO	{"phone": "+70809308470"}
0005432261745	8523DE	0992 756441	ALEKSANDR CHERNOV	{"email": "chernov.a1968@postgrespro.ru", "phone": "+70522878256"}
0005432261746	2B05CE	2529 945389	IGOR ALEKSEEV	{"email": "i.alekseev_30031979@postgrespro.ru", "phone": "+70802881240"}
0005432261747	147E54	5559 447794	RAUF ROMANOV	{"email": "romanov-rauf121973@postgrespro.ru", "phone": "+70362762172"}
0005432261748	147E54	6369 184796	IVAN KUZMIN	{"email": "ivan_kuzmin-031979@postgrespro.ru", "phone": "+70096817331"}
0005432261749	147E54	2973 338227	ALLA KONDRATEVA	{"phone": "+70784558485"}
0005432261750	3867E1	5628 490840	GLEB VLASOV	{"email": "vlasov_g.021966@postgrespro.ru", "phone": "+70798514168"}
0005432261751	B77950	2675 920133	DANIIL IVANOV	{"phone": "+70585608082"}
0005432261752	62AC66	1564 915169	YULIYA KOROLEVA	{"email": "ykoroleva-1967@postgrespro.ru", "phone": "+70065247042"}
0005432261753	62AC66	2794 250163	ALEKSANDR ILIN	{"email": "ilina.021970@postgrespro.ru", "phone": "+70459739852"}
0005432261754	96E137	5780 710928	LILIYA RYABOVA	{"phone": "+70551878770"}
0005432261755	96E137	5336 816960	ALEKSANDR VLASOV	{"phone": "+70954398605"}
0005432261756	96E137	3497 095948	POLINA YAKOVLEVA	{"phone": "+70453931371"}
0005432261757	FB8D18	5646 615201	GALINA PAVLOVA	{"phone": "+70512044065"}
0005432261758	2F2B78	4539 624566	VYACHESLAV MIKHAYLOV	{"phone": "+70357108056"}
0005432261759	44ECA1	5939 840353	ALEKSANDR SOKOLOV	{"phone": "+70649008972"}
0005432261761	297DCC	0606 334510	ANASTASIYA SAVELEVA	{"email": "asaveleva.081969@postgrespro.ru", "phone": "+70887696884"}
0005432261762	297DCC	3381 397569	DMITRIY MATVEEV	{"phone": "+70295155931"}
0005432261763	297DCC	5921 269083	SERGEY MATVEEV	{"phone": "+70910995149"}
0005432261764	424FE1	1714 169083	VALENTINA DAVYDOVA	{"email": "v-davydova-14041958@postgrespro.ru", "phone": "+70242925363"}
0005432261765	17BFEA	3382 266500	ALEKSEY TIMOFEEV	{"phone": "+70382957656"}
0005432261766	7844AE	7845 498769	OLESYA FILIPPOVA	{"email": "filippovaolesya011966@postgrespro.ru", "phone": "+70184716376"}
0005432261767	52B6F8	6337 884136	VLADIMIR FEDOROV	{"phone": "+70192436183"}
0005432261768	52B6F8	7259 569531	MAYA DENISOVA	{"email": "m-denisova-1974@postgrespro.ru", "phone": "+70365211391"}
0005432261769	1A0327	6021 819118	SERGEY BORISOV	{"phone": "+70916917501"}
0005432261770	296B69	1737 946097	SERGEY POPOV	{"phone": "+70685184049"}
0005432261771	43D189	6347 776548	NADEZHDA MAKAROVA	{"phone": "+70676207481"}
0005432261772	A7F678	6491 079442	SERGEY KUZNECOV	{"phone": "+70477972410"}
0005432261773	688E21	6706 705974	SERGEY MEDVEDEV	{"phone": "+70535306622"}
0005432261774	898564	4807 304232	VITALIY MAKAROV	{"phone": "+70669092995"}
0005432261775	898564	8737 399215	SERGEY ALEKSANDROV	{"phone": "+70753585688"}
0005432261776	042356	9008 559847	EGOR MIRONOV	{"email": "mironovegor_23101961@postgrespro.ru", "phone": "+70886545659"}
0005432261777	A71CE9	3311 375516	EGOR SHEVCHENKO	{"phone": "+70581880151"}
0005432261778	BB0133	0495 602786	TAMARA NAZAROVA	{"email": "nazarova.tamara111977@postgrespro.ru", "phone": "+70867715495"}
0005432261779	C2CB7B	6996 688756	ALEKSEY MAKAROV	{"phone": "+70793300377"}
0005432261780	C2CB7B	7726 136333	VLADISLAV STEPANOV	{"phone": "+70705781098"}
0005432261781	1BC67E	0969 073442	MAKSIM NIKITIN	{"email": "maksim-nikitin-30121973@postgrespro.ru", "phone": "+70527667998"}
0005432261782	718CCE	8010 937546	SVETLANA BELYAEVA	{"email": "belyaeva_s101980@postgrespro.ru", "phone": "+70353520992"}
0005432261783	4807D8	4093 743111	MARK FEDOROV	{"email": "fedorovmark.22111972@postgrespro.ru", "phone": "+70790090302"}
0005432261784	A2F0C1	8949 103139	VITALIY KUZNECOV	{"phone": "+70970299483"}
0005432261785	37FA53	0998 454464	NINA OVCHINNIKOVA	{"email": "nina-ovchinnikova-20031978@postgrespro.ru", "phone": "+70830928984"}
0005432261786	015E44	6398 868080	ALEKSANDR BORISOV	{"email": "borisov_aleksandr_041977@postgrespro.ru", "phone": "+70838873116"}
0005432261787	7A4095	8485 169842	IRINA GUSEVA	{"email": "gusevai.031976@postgrespro.ru", "phone": "+70287675889"}
0005432261788	41DA7B	7846 246747	VLADIMIR POPOV	{"email": "popov-vladimir.1961@postgrespro.ru", "phone": "+70605867930"}
0005432261789	41DA7B	0707 064043	VITALIY KRASNOV	{"email": "krasnov-v-091972@postgrespro.ru", "phone": "+70215132518"}
0005432261790	D96A91	0885 061056	MARINA ANTONOVA	{"email": "antonova_m-1962@postgrespro.ru", "phone": "+70279414911"}
0005432261791	236233	6062 678440	DARYA BELYAEVA	{"email": "d.belyaeva_1973@postgrespro.ru", "phone": "+70604730761"}
0005432261792	84C8D8	4338 582901	DANIIL SOKOLOV	{"phone": "+70493807640"}
0005432261793	142993	8265 043227	NATALYA KUZNECOVA	{"email": "kuznecova-n_13091971@postgrespro.ru", "phone": "+70732362783"}
0005432261794	311D6C	7413 187055	SERGEY ROMANOV	{"email": "s-romanov-1976@postgrespro.ru", "phone": "+70195427676"}
0005432261795	311D6C	3260 177298	ANNA BELYAEVA	{"phone": "+70352781630"}
0005432261796	311D6C	4377 256687	VLADIMIR FEDOROV	{"email": "vladimirfedorov-051967@postgrespro.ru", "phone": "+70302908746"}
0005432261797	3E4138	3352 043224	ANDREY EGOROV	{"phone": "+70959745554"}
0005432261798	3E4138	9759 222036	ALEKSANDR FOMIN	{"email": "aleksandr_fomin021966@postgrespro.ru", "phone": "+70599071103"}
0005432261799	130452	6508 103829	LYUDMILA AFANASEVA	{"phone": "+70438744861"}
0005432261800	130452	4697 260849	NATALYA ANISIMOVA	{"email": "anisimova.n-1963@postgrespro.ru", "phone": "+70753953851"}
0005432261801	2FC602	3031 866736	ALEKSANDR GUSEV	{"phone": "+70428280912"}
0005432261802	2FC602	4678 148802	TAMARA TIKHONOVA	{"email": "tikhonova.tamara.13101973@postgrespro.ru", "phone": "+70717253792"}
0005432261803	61DAB4	2334 852557	NINA ABRAMOVA	{"phone": "+70119162977"}
0005432261804	3AFE9A	4490 296247	SERGEY SHEVCHENKO	{"phone": "+70034412198"}
0005432261805	C3F24C	0679 855344	MARINA GRISHINA	{"phone": "+70958958995"}
0005432261806	C3F24C	2271 302587	ALEKSANDR DAVYDOV	{"email": "adavydov041984@postgrespro.ru", "phone": "+70471964718"}
0005432261807	761307	2813 466493	IRINA KUZNECOVA	{"phone": "+70301264689"}
0005432261808	3B4D2B	7055 408884	RAIL NIKOLAEV	{"email": "rail.nikolaev1980@postgrespro.ru", "phone": "+70035812209"}
0005432261809	02F298	9134 897628	ELENA ALEKSEEVA	{"email": "alekseevae-1965@postgrespro.ru", "phone": "+70778318884"}
0005432261810	36BF25	1279 571120	KONSTANTIN VOLKOV	{"email": "volkov.k-121976@postgrespro.ru", "phone": "+70518497098"}
0005432261811	6A4C3C	3964 082496	ANDREY SERGEEV	{"phone": "+70163502304"}
0005432261812	46B8FA	0615 069609	NATALYA KONOVALOVA	{"email": "konovalova.n1967@postgrespro.ru", "phone": "+70132017534"}
0005432261813	912426	2615 893538	LIDIYA CHERNOVA	{"phone": "+70337968191"}
0005432261814	0DFD5C	6075 198560	GENNADIY SHEVCHENKO	{"phone": "+70977322644"}
0005432261815	8B1CE1	9886 275657	ILDAR OSIPOV	{"phone": "+70088265634"}
0005432261816	E34597	3275 244246	LARISA BELOVA	{"phone": "+70985623659"}
0005432261817	A4A0B7	0252 271054	IVAN MAKSIMOV	{"phone": "+70664035523"}
0005432261818	B7C2E1	1279 328934	PAVEL MAKSIMOV	{"email": "pavel_maksimov-04041974@postgrespro.ru", "phone": "+70343716762"}
0005432261819	B82F23	5679 240095	VALENTINA ANTONOVA	{"email": "antonova-v-1974@postgrespro.ru", "phone": "+70724321005"}
0005432261820	B82F23	4730 754515	ALEKSEY SHEVCHENKO	{"email": "shevchenko.a.29011972@postgrespro.ru", "phone": "+70108594800"}
0005432261821	36D331	8771 048372	VLADIMIR FROLOV	{"phone": "+70183118308"}
0005432261822	C6950D	9846 238346	TATYANA NESTEROVA	{"email": "nesterova_t.031973@postgrespro.ru", "phone": "+70503856082"}
0005432261823	C6950D	6921 994455	RUSLAN SOROKIN	{"phone": "+70687504170"}
0005432261824	B89158	7290 749481	ROZA KARPOVA	{"phone": "+70362350627"}
0005432261825	3E6DCC	1378 234667	ALEKSANDR ANTONOV	{"phone": "+70544984526"}
0005432261826	2C355B	8504 187686	ANATOLIY VASILEV	{"phone": "+70560863628"}
0005432261827	BA5C0D	9404 576042	RUSLAN IVANOV	{"email": "ivanovr.051977@postgrespro.ru", "phone": "+70703358308"}
0005432261828	BA5C0D	0872 225674	OLGA ROMANOVA	{"phone": "+70366391184"}
0005432261829	BA5C0D	3377 942927	NINEL AKIMOVA	{"phone": "+70988814806"}
0005432261830	23016E	1708 609294	ELEONORA TARASOVA	{"email": "eleonoratarasova-1979@postgrespro.ru", "phone": "+70646523859"}
0005432261831	23016E	8231 810824	YURIY VASILEV	{"email": "vasilev.yuriy-1973@postgrespro.ru", "phone": "+70925708854"}
0005432261832	77F254	9037 597384	TATYANA ORLOVA	{"phone": "+70811457971"}
0005432261833	77F254	9196 473165	SERGEY MELNIKOV	{"phone": "+70542855837"}
0005432261834	FEAA41	0217 461491	MARIYA LEBEDEVA	{"email": "mariyalebedeva_011975@postgrespro.ru", "phone": "+70243489652"}
0005432261835	FEAA41	9445 962579	GALINA FROLOVA	{"phone": "+70173218606"}
0005432261836	FEAA41	3825 588283	MARINA IVANOVA	{"email": "ivanova-m1983@postgrespro.ru", "phone": "+70250903238"}
0005432261837	1941C2	2389 183510	VIKTORIYA ANISIMOVA	{"phone": "+70139124932"}
0005432261838	2FC9B2	8265 545428	ALEKSANDR KULIKOV	{"email": "kulikov-aleksandr-30061975@postgrespro.ru", "phone": "+70053268364"}
0005432261839	5DAA4D	1836 734710	NADEZHDA KULIKOVA	{"email": "n.kulikova051968@postgrespro.ru", "phone": "+70512327136"}
0005432261840	5DAA4D	7407 552371	SVETLANA KAZAKOVA	{"phone": "+70727741571"}
0005432261841	E65E6D	3330 727103	POLINA DENISOVA	{"email": "p.denisova02071966@postgrespro.ru", "phone": "+70505668357"}
0005432261842	288E6D	6229 645915	SERGEY POPOV	{"phone": "+70232932996"}
0005432261843	01FCB9	9307 478535	ALEKSEY KOZLOV	{"email": "kozlov_a-1957@postgrespro.ru", "phone": "+70938364794"}
0005432261844	19D497	4576 407752	TAMARA KRASNOVA	{"email": "krasnova-tamara_1978@postgrespro.ru", "phone": "+70671205064"}
0005432261845	D5B481	3005 277802	NINA NIKOLAEVA	{"email": "nikolaeva.nina121960@postgrespro.ru", "phone": "+70933879627"}
0005432261846	279C61	3902 847514	MATVEY TIMOFEEV	{"phone": "+70200698556"}
0005432261847	279C61	2626 404537	VLADIMIR PAVLOV	{"email": "pavlovv-1979@postgrespro.ru", "phone": "+70588495528"}
0005432261848	02BB6E	6455 403047	ALBINA OVCHINNIKOVA	{"email": "albina-ovchinnikova_1968@postgrespro.ru", "phone": "+70600110500"}
0005432261849	C2DB8D	0416 659685	NIKITA SAVELEV	{"phone": "+70397873493"}
0005432261850	C2DB8D	7758 191090	SERGEY VASILEV	{"email": "sergey.vasilev-031969@postgrespro.ru", "phone": "+70712948886"}
0005432261851	9336DB	6755 857846	ANDREY VOROBEV	{"phone": "+70261055465"}
0005432261852	766861	2248 186613	ELENA POPOVA	{"email": "popova.e-31121972@postgrespro.ru", "phone": "+70287337294"}
0005432261853	E770B5	3601 891220	NIKOLAY FOMIN	{"phone": "+70081015718"}
0005432261854	03512A	2702 206874	VASILIY MARTYNOV	{"phone": "+70101396695"}
0005432261855	EFF600	3283 675997	ANATOLIY CHERNOV	{"email": "chernov_anatoliy-1972@postgrespro.ru", "phone": "+70583147693"}
0005432261856	B26AD8	4428 709504	ALBERT ISAEV	{"email": "a.isaev_1975@postgrespro.ru", "phone": "+70698390283"}
0005432261857	AB5F2F	1304 383590	OLEG PAVLOV	{"phone": "+70059186604"}
0005432261858	FF1F2B	1966 338600	TATYANA NOVIKOVA	{"phone": "+70803155281"}
0005432261859	D29F17	7219 298041	NATALYA MOROZOVA	{"email": "natalya_morozova.1975@postgrespro.ru", "phone": "+70143929472"}
0005432261860	44E15E	0764 929489	VLADIMIR ZHUKOV	{"phone": "+70309542921"}
0005432261861	BAA33B	3039 869856	VALENTINA MIRONOVA	{"email": "v-mironova-041968@postgrespro.ru", "phone": "+70129426409"}
0005432261862	DB8416	8000 354312	DMITRIY ANTONOV	{"email": "d_antonov-041973@postgrespro.ru", "phone": "+70458203887"}
0005432261863	DB8416	0670 514786	IVAN ZHURAVLEV	{"phone": "+70215511911"}
0005432261864	056DB9	0935 430112	ANNA POPOVA	{"email": "anna.popova1951@postgrespro.ru", "phone": "+70498695917"}
0005432261865	056DB9	5778 209261	VIKTOR GERASIMOV	{"phone": "+70498262307"}
0005432261866	004B38	1465 234868	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir1971@postgrespro.ru", "phone": "+70229218384"}
0005432261867	D84C66	2072 181260	LILIYA IVANOVA	{"email": "ivanoval_031979@postgrespro.ru", "phone": "+70280477382"}
0005432261868	D9053E	3795 384059	NADEZHDA FILIPPOVA	{"phone": "+70236443521"}
0005432261869	D9053E	1026 309497	VLADIMIR IVANOV	{"email": "ivanov.v06081972@postgrespro.ru", "phone": "+70318024808"}
0005432261870	E3A20E	3600 755488	DMITRIY ZHURAVLEV	{"email": "zhuravlev.dmitriy-1969@postgrespro.ru", "phone": "+70110578743"}
0005432261871	7BA5BA	4735 886663	ANASTASIYA KOLESNIKOVA	{"email": "anastasiyakolesnikova1965@postgrespro.ru", "phone": "+70805237143"}
0005432261872	57E4B2	9927 922573	NELLI SOLOVEVA	{"phone": "+70483907844"}
0005432261873	57E4B2	0595 351997	OLGA FEDOROVA	{"email": "fedorovaolga_071983@postgrespro.ru", "phone": "+70188687536"}
0005432261874	57E4B2	1907 985716	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov-1982@postgrespro.ru", "phone": "+70557062715"}
0005432261875	B46950	7842 289165	DMITRIY POPOV	{"email": "popov.dmitriy10021964@postgrespro.ru", "phone": "+70227934997"}
0005432261876	B07311	2305 012297	VIKTOR ZAYCEV	{"phone": "+70820767095"}
0005432261877	AB7BF4	9635 824619	ALEKSANDR KAZAKOV	{"email": "kazakov.a1977@postgrespro.ru", "phone": "+70905178567"}
0005432261878	58ADAE	1787 332342	IRAIDA SERGEEVA	{"email": "sergeeva_iraida.041976@postgrespro.ru", "phone": "+70807958241"}
0005432261879	784394	2956 947245	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr-1972@postgrespro.ru", "phone": "+70988399789"}
0005432261880	ECE5E2	8235 319564	ANASTASIYA ERMAKOVA	{"email": "anastasiyaermakova_1984@postgrespro.ru", "phone": "+70142292885"}
0005432261881	ECE5E2	9115 817330	PAVEL KARPOV	{"email": "pkarpov_09071962@postgrespro.ru", "phone": "+70522644152"}
0005432261882	F38429	8394 780398	GAGIK NIKITIN	{"phone": "+70951440152"}
0005432261883	F38429	4326 675294	ANNA ORLOVA	{"phone": "+70931806036"}
0005432261884	36BF66	8747 853328	IVAN MARTYNOV	{"phone": "+70939917840"}
0005432261885	E68512	5232 479986	VALENTINA KONOVALOVA	{"email": "konovalova-valentina13091971@postgrespro.ru", "phone": "+70647011344"}
0005432261886	980827	8290 774348	IVAN FROLOV	{"email": "frolov_i.111968@postgrespro.ru", "phone": "+70049316798"}
0005432261887	4B5C41	9786 843647	NIKITA GUSEV	{"email": "nikitagusev_1958@postgrespro.ru", "phone": "+70328514191"}
0005432261888	5FF3B5	5171 273767	NIKITA MIKHAYLOV	{"phone": "+70442551332"}
0005432261889	A0D4EA	5950 646097	VYACHESLAV TARASOV	{"email": "tarasov.v.081985@postgrespro.ru", "phone": "+70362474291"}
0005432261890	031526	8160 991402	YANA ALEKSEEVA	{"email": "alekseeva-yana_061970@postgrespro.ru", "phone": "+70409104748"}
0005432261891	CC2607	3956 555925	ANDREY MEDVEDEV	{"phone": "+70969499976"}
0005432261892	BC17FA	7707 553783	YULIYA VOLKOVA	{"email": "yuliyavolkova081981@postgrespro.ru", "phone": "+70306168706"}
0005432261893	FECB74	2102 409370	GALINA KISELEVA	{"phone": "+70833554114"}
0005432261894	CDF34D	9285 703769	VLADIMIR KUZNECOV	{"phone": "+70487175368"}
0005432261895	C4BEF2	5230 049199	YURIY SERGEEV	{"phone": "+70428598952"}
0005432261896	96C568	9942 902467	ELENA FEDOROVA	{"email": "elena-fedorova_1960@postgrespro.ru", "phone": "+70697665659"}
0005432261897	96C568	5893 577525	OLGA ZOTOVA	{"phone": "+70015343234"}
0005432261898	F180D3	5086 675981	EKATERINA CHERNOVA	{"email": "chernova_ekaterina_121972@postgrespro.ru", "phone": "+70038294317"}
0005432261899	F180D3	8704 724819	SVETLANA DMITRIEVA	{"email": "dmitrieva.s-1976@postgrespro.ru", "phone": "+70724325776"}
0005432261900	EC4197	4708 875447	ALEKSANDR EGOROV	{"phone": "+70355005480"}
0005432261901	F084BD	6846 693808	VALENTINA IVANOVA	{"email": "ivanova.valentina.111979@postgrespro.ru", "phone": "+70221618492"}
0005432261902	F084BD	0714 469638	KIRILL ALEKSANDROV	{"email": "aleksandrov.kirill.11051970@postgrespro.ru", "phone": "+70676572720"}
0005432261903	A57377	4926 868089	VLADISLAV EGOROV	{"email": "v_egorov-11061969@postgrespro.ru", "phone": "+70988553276"}
0005432261904	54CD0D	5753 516748	ANDREY RODIONOV	{"phone": "+70506341397"}
0005432261905	54CD0D	7600 927308	DMITRIY MIKHAYLOV	{"phone": "+70124217472"}
0005432261906	54CD0D	0783 571639	MARIYA OSIPOVA	{"phone": "+70759352479"}
0005432261907	54CD0D	2516 561286	NIKOLAY FEDOROV	{"phone": "+70981478926"}
0005432261908	E6B328	0964 417284	ADELINA NIKITINA	{"phone": "+70651401142"}
0005432261909	249D2D	5557 042563	NATALYA NOVIKOVA	{"email": "nnovikova_081973@postgrespro.ru", "phone": "+70965309685"}
0005432261910	2B9053	4961 184402	VERA DAVYDOVA	{"email": "vera.davydova_07071960@postgrespro.ru", "phone": "+70503590184"}
0005432261911	2B9053	6476 034259	ALLA MIKHAYLOVA	{"phone": "+70191987953"}
0005432261912	E00D54	4304 642454	ANASTASIYA LUKYANOVA	{"phone": "+70158367826"}
0005432261913	DE8BBD	4785 596822	SERGEY KOZLOV	{"phone": "+70812392675"}
0005432261914	1D60E2	4570 082394	SERGEY KONOVALOV	{"email": "s.konovalov1984@postgrespro.ru", "phone": "+70430228506"}
0005432261915	1D60E2	7348 658393	NIKITA KUZNECOV	{"phone": "+70887337421"}
0005432261916	E1DD9B	6315 562573	IRINA SEMENOVA	{"phone": "+70304717888"}
0005432261917	E1DD9B	7773 623870	ALEKSEY ZAKHAROV	{"email": "zakharov_aleksey-24051971@postgrespro.ru", "phone": "+70602814520"}
0005432261918	B8235A	4480 110210	TATYANA ANDREEVA	{"email": "andreeva-t06091970@postgrespro.ru", "phone": "+70301045966"}
0005432261919	B8235A	0434 379812	OLGA KAZAKOVA	{"phone": "+70386013595"}
0005432261920	A73C3B	3640 780906	VIKTORIYA CHERNOVA	{"phone": "+70616236096"}
0005432261921	EA4E09	9364 070956	ANDREY SAVELEV	{"phone": "+70095004069"}
0005432261922	EA4E09	4874 605245	NADEZHDA MAKAROVA	{"phone": "+70568293934"}
0005432261923	076B76	4697 545277	VERA ROMANOVA	{"phone": "+70956532254"}
0005432261924	3D9C41	4061 193549	VALENTINA ABRAMOVA	{"phone": "+70866854786"}
0005432261925	915713	5026 497012	LYUBOV PETROVA	{"phone": "+70288417084"}
0005432261926	9E1E64	1587 043395	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin.01071971@postgrespro.ru", "phone": "+70579267654"}
0005432261927	8B05B7	7069 508629	NINA KISELEVA	{"email": "kiseleva-nina1961@postgrespro.ru", "phone": "+70059174642"}
0005432261928	8B05B7	6327 174233	SERGEY MOROZOV	{"phone": "+70013823636"}
0005432261929	8B05B7	6074 402108	NATALYA KRASNOVA	{"email": "krasnova-natalya27011970@postgrespro.ru", "phone": "+70378556613"}
0005432261930	7CC3C5	3400 841419	KARINA BELOVA	{"email": "karina_belova14071975@postgrespro.ru", "phone": "+70135607148"}
0005432261931	ACE966	9436 552136	VERA DENISOVA	{"email": "vera-denisova111977@postgrespro.ru", "phone": "+70249063151"}
0005432261932	A2E805	7259 747566	DENIS ISAEV	{"phone": "+70403926126"}
0005432261933	36A799	7896 678781	RUSTAM FEDOROV	{"email": "fedorov-rustam.1964@postgrespro.ru", "phone": "+70289216443"}
0005432261934	8AA997	1422 397397	MARIYA ERMAKOVA	{"email": "mariya_ermakova-1979@postgrespro.ru", "phone": "+70524426759"}
0005432261935	4C507A	3095 430291	GALIYA VOROBEVA	{"phone": "+70643218990"}
0005432261936	30FCD4	1787 693783	ALEKSEY BORISOV	{"email": "borisov-aleksey.1978@postgrespro.ru", "phone": "+70257353636"}
0005432261937	30FCD4	5966 169233	EVGENIY KUZNECOV	{"email": "evgeniykuznecov_1967@postgrespro.ru", "phone": "+70849417994"}
0005432261938	30FCD4	0520 145447	ANTON KAZAKOV	{"phone": "+70263378684"}
0005432261939	BAB688	1029 184817	ELENA SIDOROVA	{"email": "elenasidorova30061972@postgrespro.ru", "phone": "+70227444496"}
0005432261940	B1B443	6230 954374	RENAT SIDOROV	{"email": "r.sidorov-071969@postgrespro.ru", "phone": "+70425290967"}
0005432261941	4347F7	3948 430310	NATALIYA SAVELEVA	{"phone": "+70647471855"}
0005432261942	5DBCFA	2575 995799	NATALYA ZAKHAROVA	{"email": "zakharova_natalya21041972@postgrespro.ru", "phone": "+70462842197"}
0005432261943	77C09F	7471 349404	ANATOLIY SOROKIN	{"phone": "+70888120944"}
0005432261944	77C09F	1287 235483	IRINA STEPANOVA	{"phone": "+70955029307"}
0005432261945	0A9C03	9533 208348	SERGEY TIMOFEEV	{"email": "sergey-timofeev-1964@postgrespro.ru", "phone": "+70405185209"}
0005432261946	587437	0716 227654	ANATOLIY VASILEV	{"phone": "+70048302292"}
0005432261947	587437	5571 733385	OLGA KAZAKOVA	{"phone": "+70769869541"}
0005432261948	A3794E	0566 536642	LYUDMILA SAVELEVA	{"email": "lyudmila-saveleva.1966@postgrespro.ru", "phone": "+70488964423"}
0005432261949	3DD573	5160 669932	VALERIYA FOMINA	{"phone": "+70668513847"}
0005432261950	54FB65	3042 810197	YURIY ISAEV	{"phone": "+70490761278"}
0005432261951	35230A	7695 774737	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey_071969@postgrespro.ru", "phone": "+70572211995"}
0005432261952	B63845	0535 204375	ARTEM FEDOROV	{"email": "a_fedorov-09031976@postgrespro.ru", "phone": "+70501790235"}
0005432261953	B63845	1049 402598	SERGEY PETROV	{"phone": "+70634528261"}
0005432261954	49CC7B	7498 776483	NATALYA SEMENOVA	{"phone": "+70985187931"}
0005432261955	49CC7B	1850 355775	IVAN CHERNOV	{"email": "ivan_chernov.121965@postgrespro.ru", "phone": "+70616439262"}
0005432261956	1585EC	0490 320527	MARINA BELOVA	{"phone": "+70277200261"}
0005432261957	BC69DE	3637 738844	MARIYA FADEEVA	{"phone": "+70799685830"}
0005432261958	BC69DE	4242 545121	MILANA BORISOVA	{"phone": "+70207291760"}
0005432261959	D4DB74	6534 324861	ELENA ABRAMOVA	{"phone": "+70819453325"}
0005432261960	C56458	2564 233100	LYUBOV TIKHONOVA	{"email": "lyubov-tikhonova_08011978@postgrespro.ru", "phone": "+70887507824"}
0005432261961	586C29	5051 774711	LIDIYA ALEKSEEVA	{"phone": "+70444070351"}
0005432261962	0216DB	4333 042804	ARTEM TARASOV	{"phone": "+70906294302"}
0005432261963	77EF59	4067 462834	ANNA VOROBEVA	{"email": "vorobeva-anna071968@postgrespro.ru", "phone": "+70095196915"}
0005432261964	92C198	4606 877435	TATYANA DANILOVA	{"phone": "+70485504049"}
0005432261965	92C198	2503 574804	ANGELINA TIMOFEEVA	{"email": "timofeeva.angelina01061962@postgrespro.ru", "phone": "+70418119331"}
0005432261966	7AB648	7309 325257	PAVEL IVANOV	{"email": "ivanov_pavel.06111979@postgrespro.ru", "phone": "+70260577371"}
0005432261967	F20F6E	5449 725685	PETR IVANOV	{"phone": "+70384047245"}
0005432261968	AFF58D	5975 840295	NATALYA ABRAMOVA	{"email": "n_abramova071971@postgrespro.ru", "phone": "+70787499793"}
0005432261969	700743	5840 087631	OLEG YAKOVLEV	{"phone": "+70119175593"}
0005432261970	17BE86	9070 536042	DMITRIY BONDARENKO	{"phone": "+70201134495"}
0005432261971	17BE86	7928 140308	KIRILL SCHERBAKOV	{"email": "kscherbakov_14101968@postgrespro.ru", "phone": "+70635685227"}
0005432261972	BFB572	2549 393228	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr_02041981@postgrespro.ru", "phone": "+70540053881"}
0005432261973	61736F	6451 115519	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova-l.27101968@postgrespro.ru", "phone": "+70329997251"}
0005432261974	C6B550	5144 073210	NADEZHDA FILATOVA	{"phone": "+70456990195"}
0005432261975	7D431E	8328 800688	VERA TARASOVA	{"email": "vera-tarasova-1967@postgrespro.ru", "phone": "+70803705729"}
0005432261976	6EE705	6679 324752	ALEKSANDR MEDVEDEV	{"phone": "+70256350160"}
0005432261977	01EA0E	3675 728466	ASIYA MELNIKOVA	{"email": "melnikovaasiya_1968@postgrespro.ru", "phone": "+70355332720"}
0005432261978	01EA0E	3812 838284	SERGEY TIKHONOV	{"phone": "+70043620202"}
0005432261979	042E88	5456 705608	NIKITA ANTONOV	{"phone": "+70649817449"}
0005432261980	042E88	7571 350634	ALEKSANDR STEPANOV	{"phone": "+70532187652"}
0005432261981	684734	9195 348010	NURLAN ALEKSANDROV	{"phone": "+70043822785"}
0005432261982	0E6C94	0819 691833	BORIS IVANOV	{"email": "ivanov.boris121984@postgrespro.ru", "phone": "+70621061273"}
0005432261983	0E6C94	6202 492823	MARIYA NOVIKOVA	{"email": "novikova.m111965@postgrespro.ru", "phone": "+70412729874"}
0005432261984	B0178B	1949 890779	NATALYA ANTONOVA	{"phone": "+70248972132"}
0005432261985	B0178B	7913 255252	ALEKSEY GERASIMOV	{"email": "alekseygerasimov-26071971@postgrespro.ru", "phone": "+70630692486"}
0005432261986	08F6BC	8850 977204	SERGEY NAUMOV	{"phone": "+70836533868"}
0005432261987	95801F	5537 493871	MARIYA POTAPOVA	{"email": "mariya-potapova.031978@postgrespro.ru", "phone": "+70822618304"}
0005432261988	95801F	7731 331330	SEMEN KUZNECOV	{"email": "s.kuznecov1979@postgrespro.ru", "phone": "+70670716499"}
0005432261989	CFA488	1801 953942	YURIY MEDVEDEV	{"phone": "+70406145894"}
0005432261990	0C7E79	7230 705659	ANATOLIY MOISEEV	{"email": "moiseev.a1974@postgrespro.ru", "phone": "+70633356439"}
0005432261991	971921	9669 110334	LILIYA MELNIKOVA	{"phone": "+70492755500"}
0005432261992	783D17	7698 366324	EKATERINA KISELEVA	{"phone": "+70320632578"}
0005432261993	2C0C76	9981 072645	ANTONINA LUKYANOVA	{"phone": "+70060733253"}
0005432261994	785001	0107 771355	GALINA VASILEVA	{"email": "vasileva_g25081966@postgrespro.ru", "phone": "+70287456756"}
0005432261995	20CE54	9295 072779	NIKITA KUZNECOV	{"phone": "+70002790646"}
0005432261996	20CE54	4977 819088	KIRILL SOKOLOV	{"email": "k-sokolov.1973@postgrespro.ru", "phone": "+70048839571"}
0005432261997	F646EB	5481 124495	LILIYA KOROLEVA	{"phone": "+70171933060"}
0005432261998	A04561	7429 597771	TATYANA SOKOLOVA	{"phone": "+70117363188"}
0005432261999	A04561	4532 442426	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov021968@postgrespro.ru", "phone": "+70255133416"}
0005432262000	84B81E	4188 638744	ANATOLIY KULIKOV	{"email": "anatoliy-kulikov-021980@postgrespro.ru", "phone": "+70159476737"}
0005432262001	03F8C0	7398 924872	LYUBOV ORLOVA	{"phone": "+70538212946"}
0005432262002	03F8C0	6220 115284	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev-011970@postgrespro.ru", "phone": "+70798626398"}
0005432262003	D66D4F	6180 737828	VALENTINA ZAYCEVA	{"phone": "+70711915499"}
0005432262004	D66D4F	5959 577047	IRINA LAZAREVA	{"phone": "+70979579439"}
0005432262005	03D979	5109 582480	OLGA KONDRATEVA	{"email": "kondrateva_olga071977@postgrespro.ru", "phone": "+70024720433"}
0005432262006	665017	4174 829844	YULIYA ANDREEVA	{"email": "yuliya-andreeva_1981@postgrespro.ru", "phone": "+70637544127"}
0005432262007	C3D858	4178 248248	VLADISLAV KUZNECOV	{"email": "kuznecov.v-27031978@postgrespro.ru", "phone": "+70731935298"}
0005432262008	C3D858	8556 154176	NIKOLAY RODIONOV	{"email": "rodionovn111964@postgrespro.ru", "phone": "+70733016482"}
0005432262009	54EE7D	9238 338450	EVGENIY ANDREEV	{"email": "andreev_evgeniy_091972@postgrespro.ru", "phone": "+70922659042"}
0005432262010	54EE7D	6587 228494	ANNA KOROLEVA	{"email": "anna_koroleva02121968@postgrespro.ru", "phone": "+70372527640"}
0005432262011	56A775	9577 908977	VALENTINA ROMANOVA	{"email": "vromanova.031969@postgrespro.ru", "phone": "+70986807137"}
0005432262012	1B7B57	1956 695975	YURIY KUZNECOV	{"phone": "+70038371523"}
0005432262013	519D10	9970 823485	EVGENIY ZAKHAROV	{"email": "e_zakharov13021968@postgrespro.ru", "phone": "+70563244601"}
0005432262014	D57657	4310 997626	NADEZHDA TROFIMOVA	{"phone": "+70316263857"}
0005432262015	E5C334	2170 868829	ANDREY ANDREEV	{"phone": "+70991721502"}
0005432262016	C0F9C6	0695 885594	ALFIYA ALEKSANDROVA	{"email": "alfiya.aleksandrova_041968@postgrespro.ru", "phone": "+70127369298"}
0005432262017	C0F9C6	4636 748628	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev1973@postgrespro.ru", "phone": "+70823115062"}
0005432262018	B53874	2472 378880	NATALYA TARASOVA	{"phone": "+70309204463"}
0005432262019	B53874	7109 309716	ALINA MEDVEDEVA	{"phone": "+70576399465"}
0005432262020	499328	6212 823331	DMITRIY PETROV	{"email": "petrov-dmitriy.11011967@postgrespro.ru", "phone": "+70777978603"}
0005432262021	845A3A	1349 590534	NADEZHDA IVANOVA	{"phone": "+70110602373"}
0005432262022	845A3A	6104 300149	VADIM CHERNOV	{"phone": "+70412653401"}
0005432262023	845A3A	4813 547675	VALENTIN PETROV	{"email": "valentin.petrov.1973@postgrespro.ru", "phone": "+70873429984"}
0005432262024	65A6F9	0529 246391	LIDIYA MAKAROVA	{"email": "makarovalidiya1979@postgrespro.ru", "phone": "+70417320735"}
0005432262025	246E68	0865 402882	IRINA MOROZOVA	{"phone": "+70925343395"}
0005432262026	35AF4E	7420 189946	ALEKSANDR NAZAROV	{"email": "anazarov.1964@postgrespro.ru", "phone": "+70971063619"}
0005432262027	02AA7A	9867 492206	KIRILL KAZAKOV	{"email": "kazakovk-1977@postgrespro.ru", "phone": "+70461282380"}
0005432262028	7700A3	5573 280784	ANTONINA ILINA	{"email": "antonina_ilina11071971@postgrespro.ru", "phone": "+70531854035"}
0005432262029	FD784D	4152 134387	OLEG GORBUNOV	{"email": "gorbunov_o_22061967@postgrespro.ru", "phone": "+70147982740"}
0005432262030	729956	3258 216968	GALINA LUKYANOVA	{"phone": "+70651482891"}
0005432262031	D33FCB	4855 711583	IRINA ABRAMOVA	{"email": "irinaabramova081975@postgrespro.ru", "phone": "+70915066366"}
0005432262032	E067B5	8382 748535	DMITRIY POPOV	{"phone": "+70531543227"}
0005432262033	B22C06	6850 158323	OLEG KUDRYASHOV	{"email": "kudryashov-oleg.1974@postgrespro.ru", "phone": "+70826758594"}
0005432262034	FEB542	2340 906427	ANTON NIKITIN	{"email": "anton_nikitin_1978@postgrespro.ru", "phone": "+70990164683"}
0005432262035	FEB542	0815 718480	MARINA TIKHONOVA	{"email": "mtikhonova-11111963@postgrespro.ru", "phone": "+70031614179"}
0005432262036	F162B0	3196 448111	ALEKSANDR KRASNOV	{"phone": "+70219784600"}
0005432262037	9E3884	2320 458932	MAKSIM PETROV	{"phone": "+70053805710"}
0005432262038	221597	1962 985049	SVETLANA LEBEDEVA	{"email": "lebedevas.1968@postgrespro.ru", "phone": "+70046768825"}
0005432262039	1FADC5	0207 086016	ELENA ZAKHAROVA	{"phone": "+70095343924"}
0005432262040	34DB4B	2534 354415	NIKOLAY ALEKSEEV	{"email": "nikolay.alekseev_19121972@postgrespro.ru", "phone": "+70138143092"}
0005432262041	34DB4B	6112 488101	EKATERINA YAKOVLEVA	{"phone": "+70953401158"}
0005432262042	9F4EAB	3248 962364	OLGA MIKHAYLOVA	{"phone": "+70424346897"}
0005432262043	9F4EAB	1333 370293	ALEKSANDR SHEVCHENKO	{"email": "aleksandr-shevchenko.051968@postgrespro.ru", "phone": "+70478381280"}
0005432262044	59250A	0281 383197	NIKOLAY STEPANOV	{"email": "nstepanov.111964@postgrespro.ru", "phone": "+70103545576"}
0005432262045	95E323	9694 262936	VADIM VLASOV	{"email": "vadimvlasov071970@postgrespro.ru", "phone": "+70126053325"}
0005432262046	95E323	5266 029112	NINA LUKYANOVA	{"email": "ninalukyanova-1965@postgrespro.ru", "phone": "+70834820340"}
0005432262047	25BB22	4757 561879	IVAN KISELEV	{"email": "i_kiselev.071973@postgrespro.ru", "phone": "+70583853858"}
0005432262048	BC2D87	2740 438631	ALEKSEY EGOROV	{"email": "egorova.1984@postgrespro.ru", "phone": "+70915615088"}
0005432262049	6CFF2F	6624 642217	GRIGORIY GUSEV	{"email": "gusev.g-25021965@postgrespro.ru", "phone": "+70166666882"}
0005432262050	6CFF2F	2348 484473	ELIZAVETA NIKITINA	{"email": "elizaveta-nikitina.1972@postgrespro.ru", "phone": "+70210861290"}
0005432262051	DF228F	9176 289141	VALERIYA SCHERBAKOVA	{"email": "scherbakova.v.1988@postgrespro.ru", "phone": "+70622858525"}
0005432262052	CB9CBB	6648 009269	ELENA NESTEROVA	{"phone": "+70481531415"}
0005432262053	CB9CBB	5898 471000	EVDOKIYA OSIPOVA	{"email": "e-osipova-111964@postgrespro.ru", "phone": "+70224145675"}
0005432262054	4F5E13	3739 976709	ANDREY BELOV	{"email": "belov.a121954@postgrespro.ru", "phone": "+70799762208"}
0005432262055	E4A429	2463 738922	OKSANA VOLKOVA	{"phone": "+70698348882"}
0005432262056	FCA988	1955 615674	VLADISLAV IVANOV	{"phone": "+70785233008"}
0005432262057	A10541	0302 008092	RUMIYA GUSEVA	{"email": "guseva.rumiya1980@postgrespro.ru", "phone": "+70535521366"}
0005432262058	158940	4393 022327	ANDREY ABRAMOV	{"phone": "+70030875567"}
0005432262059	A27A5A	6792 446283	ALEKSANDR SHEVCHENKO	{"phone": "+70892932436"}
0005432262060	A27A5A	5055 332682	YURIY BONDARENKO	{"phone": "+70104979553"}
0005432262061	A27A5A	3605 898285	IVAN FILIPPOV	{"email": "ivan-filippov.12051980@postgrespro.ru", "phone": "+70028492846"}
0005432262062	46F262	2920 483948	ALEKSEY KOZLOV	{"email": "akozlov_011979@postgrespro.ru", "phone": "+70913836679"}
0005432262063	A8C125	3141 919777	IRINA DMITRIEVA	{"email": "irinadmitrieva-31121972@postgrespro.ru", "phone": "+70556678526"}
0005432262064	A8C125	0988 367511	OLGA KUZMINA	{"phone": "+70077526534"}
0005432262065	A8C125	6632 211237	VLADIMIR MARTYNOV	{"email": "martynov_v091973@postgrespro.ru", "phone": "+70749650219"}
0005432262066	8B08D8	9468 387539	ALEKSANDR RODIONOV	{"phone": "+70671755226"}
0005432262067	A84606	7435 086625	ALEKSANDR DENISOV	{"email": "denisov.aleksandr121971@postgrespro.ru", "phone": "+70397601342"}
0005432262068	A84606	5059 874515	MIKHAIL STEPANOV	{"phone": "+70223796896"}
0005432262069	A84606	4208 312719	LYUDMILA KUZNECOVA	{"email": "lkuznecova-17091969@postgrespro.ru", "phone": "+70692585549"}
0005432262070	A84606	5420 241422	ALEKSANDR KOZLOV	{"phone": "+70679217769"}
0005432262071	3B45A9	8838 449893	ALEKSEY FILIPPOV	{"phone": "+70003119766"}
0005432262072	2C3062	1647 279054	OKSANA FILIPPOVA	{"email": "o-filippova_061972@postgrespro.ru", "phone": "+70320989742"}
0005432262073	12F05D	2892 299655	ALEKSANDR MIKHAYLOV	{"phone": "+70966863345"}
0005432262074	9D1794	2408 743833	NINA TROFIMOVA	{"email": "ninatrofimova1975@postgrespro.ru", "phone": "+70286018253"}
0005432262075	22B79C	3576 213477	GALINA KUZNECOVA	{"phone": "+70711978355"}
0005432262076	22B79C	3098 661108	ANNA ZAKHAROVA	{"email": "a.zakharova-1975@postgrespro.ru", "phone": "+70656674378"}
0005432262077	22B79C	6428 793576	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy091974@postgrespro.ru", "phone": "+70593546256"}
0005432262078	78D176	8285 916854	VALENTINA KOLESNIKOVA	{"email": "kolesnikova-v_1975@postgrespro.ru", "phone": "+70960431022"}
0005432262079	3E3EF7	2108 716099	DMITRIY ANTONOV	{"email": "antonov.d.1969@postgrespro.ru", "phone": "+70002691148"}
0005432262080	3E3EF7	3928 709443	ANZHELIKA STEPANOVA	{"email": "a_stepanova-101979@postgrespro.ru", "phone": "+70090021998"}
0005432262081	BA02EE	9911 648965	OLGA ISAEVA	{"email": "isaeva-o-1963@postgrespro.ru", "phone": "+70520796594"}
0005432262082	BA02EE	6915 361734	LYUDMILA ROMANOVA	{"email": "romanova-lyudmila1957@postgrespro.ru", "phone": "+70966362006"}
0005432262083	BA02EE	5165 886341	ANTON DENISOV	{"phone": "+70896830495"}
0005432262084	CDE1B4	5324 918666	ELENA MAKAROVA	{"email": "e.makarova021976@postgrespro.ru", "phone": "+70612595951"}
0005432262085	FAB44D	0840 945497	SEMEN SIDOROV	{"email": "sidorov_semen.29081964@postgrespro.ru", "phone": "+70329655878"}
0005432262086	452EE2	9380 402893	PAVEL SMIRNOV	{"email": "smirnov_pavel28121976@postgrespro.ru", "phone": "+70878911321"}
0005432262087	452EE2	9865 537823	ALEKSANDR MARTYNOV	{"phone": "+70452483724"}
0005432262088	48DF66	8795 741542	ELENA AKIMOVA	{"email": "elena.akimova.1958@postgrespro.ru", "phone": "+70760600964"}
0005432262089	B786D8	3733 115346	VLADIMIR ANTONOV	{"email": "vladimir.antonov.07031982@postgrespro.ru", "phone": "+70176842366"}
0005432262090	641993	4724 141433	INNA KAZAKOVA	{"email": "inna.kazakova.1974@postgrespro.ru", "phone": "+70268456939"}
0005432262091	75A449	5040 217375	OLGA NIKOLAEVA	{"email": "nikolaeva.o-26121976@postgrespro.ru", "phone": "+70840313264"}
0005432262092	75A449	3917 533482	ELENA SCHERBAKOVA	{"phone": "+70943697402"}
0005432262093	CBD6A2	5618 831823	VYACHESLAV VOLKOV	{"email": "vyacheslav_volkov_09091975@postgrespro.ru", "phone": "+70801255332"}
0005432262094	0CA89C	7656 755664	ALEKSEY MAKAROV	{"phone": "+70508248423"}
0005432262095	0CA89C	5252 984088	LIDIYA SOLOVEVA	{"email": "soloveva_l_27111975@postgrespro.ru", "phone": "+70035402732"}
0005432262096	CEDAD7	3583 806151	OLEG IVANOV	{"phone": "+70280498058"}
0005432262097	4A44FA	2145 674596	ALEKSANDR KARPOV	{"email": "a_karpov19081957@postgrespro.ru", "phone": "+70371276030"}
0005432262098	D05474	6104 691861	NATALYA ERMAKOVA	{"email": "nermakova_18121981@postgrespro.ru", "phone": "+70094033197"}
0005432262099	1DC435	2902 380461	ZINAIDA KOLESNIKOVA	{"email": "kolesnikovaz_22021966@postgrespro.ru", "phone": "+70165381701"}
0005432262100	399C65	7555 670398	ZOYA KOROLEVA	{"phone": "+70051981022"}
0005432262101	C0C5E4	3700 756900	VYACHESLAV GERASIMOV	{"email": "gerasimov-v051968@postgrespro.ru", "phone": "+70658651274"}
0005432262102	2C95CF	8269 982384	SVETLANA ISAEVA	{"phone": "+70943294481"}
0005432262103	5400C7	9685 389664	ALEKSANDR VOLKOV	{"phone": "+70514355142"}
0005432262104	4137A4	7275 201276	EVGENIY PAVLOV	{"phone": "+70620710147"}
0005432262105	A658CE	0989 454375	ALEKSEY BONDARENKO	{"phone": "+70025557245"}
0005432262106	0CC286	9913 836559	SERGEY NIKITIN	{"email": "s_nikitin-1954@postgrespro.ru", "phone": "+70108224330"}
0005432262107	FD69F5	6744 886521	DENIS KUZNECOV	{"email": "d_kuznecov1973@postgrespro.ru", "phone": "+70769440521"}
0005432262108	6DAF83	1376 009459	VLADIMIR RODIONOV	{"email": "rodionov-v1976@postgrespro.ru", "phone": "+70577935726"}
0005432262109	28A9D6	9204 231606	NATALYA ANTONOVA	{"email": "antonova_n_08111976@postgrespro.ru", "phone": "+70267975475"}
0005432262110	B1EA16	7505 264253	EKATERINA ANDREEVA	{"email": "ekaterina.andreeva_1978@postgrespro.ru", "phone": "+70198236709"}
0005432262111	4A0016	9946 136438	ANDREY SAVELEV	{"email": "savelev_a_1972@postgrespro.ru", "phone": "+70218273638"}
0005432262112	39A2A1	1697 602040	EKATERINA PETROVA	{"email": "petrova-e-1973@postgrespro.ru", "phone": "+70852454739"}
0005432262113	AF2CBB	0280 735939	ANDREY PETROV	{"email": "a.petrov1972@postgrespro.ru", "phone": "+70675852769"}
0005432262114	79533E	1517 981299	ALEKSANDR POPOV	{"email": "a_popov-1965@postgrespro.ru", "phone": "+70817469991"}
0005432262115	654890	2790 305157	DARYA ROMANOVA	{"email": "romanova_darya_1976@postgrespro.ru", "phone": "+70279288294"}
0005432262116	63D51C	6073 049817	IVAN MAKAROV	{"email": "i.makarov_091966@postgrespro.ru", "phone": "+70892360384"}
0005432262117	63D51C	3194 542303	IRINA BELOVA	{"phone": "+70643176094"}
0005432262118	2D3323	0128 822442	ANASTASIYA POTAPOVA	{"email": "apotapova.051975@postgrespro.ru", "phone": "+70582599558"}
0005432262119	2D3323	9502 283825	VALENTINA FEDOROVA	{"email": "v_fedorova-24091981@postgrespro.ru", "phone": "+70740602945"}
0005432262120	2D3323	7311 410309	VASILIY POPOV	{"email": "v_popov1961@postgrespro.ru", "phone": "+70593144028"}
0005432262121	C39882	8834 196908	SERGEY ZAKHAROV	{"email": "zakharov-sergey1978@postgrespro.ru", "phone": "+70246006470"}
0005432262122	C39882	4942 035745	LYUBOV NESTEROVA	{"email": "nesterova_l_1968@postgrespro.ru", "phone": "+70309437243"}
0005432262123	144296	0536 438209	VLADISLAV NAZAROV	{"phone": "+70554218458"}
0005432262124	39381F	3838 950800	LARISA DAVYDOVA	{"phone": "+70550419149"}
0005432262125	39381F	9517 724610	VARVARA VLASOVA	{"phone": "+70688756770"}
0005432262126	B57441	8810 805718	MARINA FILIPPOVA	{"email": "mfilippova011958@postgrespro.ru", "phone": "+70758892557"}
0005432262127	B57441	4556 736343	ANTONINA BARANOVA	{"email": "a.baranova-04051976@postgrespro.ru", "phone": "+70407790066"}
0005432262128	BA7283	5251 771813	SVETLANA FEDOROVA	{"phone": "+70894687260"}
0005432262129	9A27A4	2170 006648	VIKTORIYA IVANOVA	{"phone": "+70990371503"}
0005432262130	446F8E	5697 581068	OLGA NAUMOVA	{"email": "olga_naumova-051965@postgrespro.ru", "phone": "+70866197884"}
0005432262131	15873B	0828 476960	NATALYA NIKOLAEVA	{"phone": "+70456336193"}
0005432262132	15873B	5576 032516	KLAVDIYA NIKITINA	{"email": "k.nikitina-1981@postgrespro.ru", "phone": "+70881603665"}
0005432262133	15873B	9669 785994	EKATERINA TARASOVA	{"email": "e_tarasova_091957@postgrespro.ru", "phone": "+70153186372"}
0005432262134	17F845	3057 819685	ANATOLIY GUSEV	{"phone": "+70799618789"}
0005432262135	17F845	2028 870632	VALENTINA ROMANOVA	{"email": "v-romanova_1959@postgrespro.ru", "phone": "+70361222698"}
0005432262136	633AA4	4985 854603	EVGENIYA AKIMOVA	{"phone": "+70588180248"}
0005432262137	99547B	2955 896357	MARIYA MALYSHEVA	{"phone": "+70852349624"}
0005432262138	4FFE9F	6382 248380	YULIYA KUZMINA	{"phone": "+70964433684"}
0005432262139	4FFE9F	0664 038591	ALINA SOKOLOVA	{"phone": "+70877436882"}
0005432262140	4FFE9F	3933 185463	ELENA KULIKOVA	{"phone": "+70928869708"}
0005432262141	5DB913	9537 972317	OLGA KUZNECOVA	{"email": "kuznecovao.041971@postgrespro.ru", "phone": "+70539503990"}
0005432262142	5DB913	3010 422105	IGOR DMITRIEV	{"email": "dmitriev-igor101967@postgrespro.ru", "phone": "+70013483344"}
0005432262143	1C1AC7	3323 599475	STEPAN TARASOV	{"email": "stepan-tarasov-011980@postgrespro.ru", "phone": "+70645870846"}
0005432262144	1C1AC7	8133 762533	MARINA DMITRIEVA	{"email": "dmitrieva-marina_1975@postgrespro.ru", "phone": "+70463622522"}
0005432262145	52A9F7	9526 527940	ANGELINA KOROLEVA	{"phone": "+70964087850"}
0005432262146	AB3B28	4353 227062	OLGA NOVIKOVA	{"phone": "+70462178205"}
0005432262147	AB3B28	0055 311989	EDUARD KRASNOV	{"email": "eduard-krasnov.021977@postgrespro.ru", "phone": "+70603973095"}
0005432262148	4C9908	7271 287835	VLADISLAV MAKAROV	{"email": "makarov.v.01111972@postgrespro.ru", "phone": "+70661757278"}
0005432262149	F96E7C	4656 495957	LYUBOV TIMOFEEVA	{"phone": "+70713616695"}
0005432262150	B17A81	8770 942450	VLADIMIR SIDOROV	{"email": "vladimirsidorov1967@postgrespro.ru", "phone": "+70439800834"}
0005432262151	1296BD	9171 186204	SERGEY MIRONOV	{"email": "mironov_sergey_051977@postgrespro.ru", "phone": "+70868810043"}
0005432262152	974EA4	3528 548934	NATALIYA TIKHONOVA	{"email": "n-tikhonova_08081975@postgrespro.ru", "phone": "+70390382026"}
0005432262153	C7B477	0395 432524	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila-041959@postgrespro.ru", "phone": "+70528004141"}
0005432262154	C7B477	6044 460704	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov-1964@postgrespro.ru", "phone": "+70671816188"}
0005432262155	D12F6B	3742 466976	OLGA CHERNOVA	{"phone": "+70423486848"}
0005432262156	D12F6B	9458 723203	GENNADIY GORBUNOV	{"email": "gorbunov.g_16111963@postgrespro.ru", "phone": "+70086334238"}
0005432262157	D39D98	0828 000327	TATYANA ALEKSANDROVA	{"phone": "+70424468063"}
0005432262158	D39D98	3629 670582	VIKTORIYA NAUMOVA	{"email": "naumova.viktoriya.071980@postgrespro.ru", "phone": "+70388258059"}
0005432262159	7BD382	4607 938949	IGOR MELNIKOV	{"email": "i_melnikov_1981@postgrespro.ru", "phone": "+70677274332"}
0005432262160	BED9D0	0417 494837	KSENIYA TIKHONOVA	{"email": "k-tikhonova101970@postgrespro.ru", "phone": "+70037940366"}
0005432262161	51AB4D	8074 122775	IRINA PETROVA	{"email": "i.petrova.081973@postgrespro.ru", "phone": "+70108282171"}
0005432262162	51AB4D	1908 180815	VITALIY DMITRIEV	{"phone": "+70132641325"}
0005432262163	4DF7E1	6622 004701	OKSANA DANILOVA	{"phone": "+70841848825"}
0005432262164	D79BBC	8045 181168	VALERIY GRIGOREV	{"phone": "+70669589236"}
0005432262165	7BBFB1	8613 477739	VLADIMIR MIKHAYLOV	{"phone": "+70289194404"}
0005432262166	7BBFB1	5032 241698	TATYANA GAVRILOVA	{"email": "gavrilova.tatyana.19011979@postgrespro.ru", "phone": "+70578192410"}
0005432262167	7BBFB1	2701 693696	TATYANA PETROVA	{"email": "t-petrova28111973@postgrespro.ru", "phone": "+70800092380"}
0005432262168	B4BB82	1448 360362	ANTON ILIN	{"email": "a.ilin-19041976@postgrespro.ru", "phone": "+70857452805"}
0005432262169	AB1B3C	5943 818135	YULIYA PETROVA	{"email": "petrova-yuliya_1978@postgrespro.ru", "phone": "+70026632973"}
0005432262170	B21DE2	7895 234659	ALEKSANDR YAKOVLEV	{"phone": "+70240788675"}
0005432262171	B21DE2	0872 021952	PAVEL IVANOV	{"phone": "+70007772317"}
0005432262172	33BFE1	2320 762662	ANASTASIYA NOVIKOVA	{"phone": "+70197323717"}
0005432262173	1B723E	4936 742671	OKSANA IVANOVA	{"email": "ivanovao-1967@postgrespro.ru", "phone": "+70712926320"}
0005432262174	1B723E	9242 547439	IGOR SERGEEV	{"email": "sergeev_i_1986@postgrespro.ru", "phone": "+70391824247"}
0005432262175	7B487A	4836 167478	RENAT SAVELEV	{"email": "r_savelev.1971@postgrespro.ru", "phone": "+70677449267"}
0005432262176	7B487A	7235 712081	OLGA DENISOVA	{"phone": "+70782384528"}
0005432262177	7B487A	9860 717172	DMITRIY SOLOVEV	{"phone": "+70021577693"}
0005432262178	FA3C16	5045 638487	NIKOLAY NOVIKOV	{"phone": "+70413832131"}
0005432262179	34C429	7343 551487	RUSLAN FEDOTOV	{"phone": "+70768391579"}
0005432262180	34C429	1974 208266	ELENA KONDRATEVA	{"phone": "+70810967246"}
0005432262181	B27358	1629 512063	INNA SOROKINA	{"email": "inna-sorokina_1965@postgrespro.ru", "phone": "+70277627012"}
0005432262182	130E8E	9231 317690	IRINA KOMAROVA	{"email": "irina-komarova_29021972@postgrespro.ru", "phone": "+70297824299"}
0005432262183	130E8E	3390 366438	SERGEY ROMANOV	{"email": "sromanov-1981@postgrespro.ru", "phone": "+70201236850"}
0005432262184	0D38E7	7560 956644	SVETLANA IVANOVA	{"email": "ivanova.svetlana.22081962@postgrespro.ru", "phone": "+70039990997"}
0005432262185	0D38E7	7080 431594	SERGEY ROMANOV	{"phone": "+70090236982"}
0005432262186	B9C267	0360 819251	ANNA MOROZOVA	{"email": "morozova.a14011978@postgrespro.ru", "phone": "+70799526527"}
0005432262187	E177E0	8278 607798	NATALYA EFREMOVA	{"phone": "+70023258388"}
0005432262188	45B2DE	1735 655268	ARTEM BORISOV	{"email": "borisov-a-25111973@postgrespro.ru", "phone": "+70912768546"}
0005432262189	0AC020	1515 214401	MARIYA FOMINA	{"phone": "+70208731189"}
0005432262190	0AC020	1355 479869	ALEKSANDR PETROV	{"email": "aleksandrpetrov.1983@postgrespro.ru", "phone": "+70827457656"}
0005432262191	13459D	6837 398948	ALEKSEY ZHURAVLEV	{"phone": "+70991704591"}
0005432262192	262E55	5504 756267	EVGENIY BORISOV	{"email": "e-borisov1977@postgrespro.ru", "phone": "+70860325215"}
0005432262193	B6B225	9705 300326	VLADIMIR ABRAMOV	{"email": "abramov.v-27121968@postgrespro.ru", "phone": "+70173259481"}
0005432262194	B6B225	0918 392107	POLINA MASLOVA	{"phone": "+70840075748"}
0005432262195	84C091	0288 171332	ALEKSANDR KONOVALOV	{"phone": "+70907514470"}
0005432262196	84C091	1823 218254	IRINA MEDVEDEVA	{"email": "medvedeva.i21061978@postgrespro.ru", "phone": "+70203945518"}
0005432262197	3FB8E8	0864 968097	DMITRIY PAVLOV	{"email": "pavlov.dmitriy1963@postgrespro.ru", "phone": "+70322919085"}
0005432262198	B46561	8029 651096	ALENA TIKHONOVA	{"email": "alena.tikhonova.07011989@postgrespro.ru", "phone": "+70463601282"}
0005432262199	0763D0	1878 897804	OLGA PETROVA	{"phone": "+70811972468"}
0005432262200	0763D0	3591 267968	NADEZHDA NOVIKOVA	{"email": "n-novikova-25081972@postgrespro.ru", "phone": "+70083705064"}
0005432262201	16E163	7403 891966	MIKHAIL CHERNOV	{"email": "m_chernov12061976@postgrespro.ru", "phone": "+70886751256"}
0005432262202	800DB0	0776 833524	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr-1961@postgrespro.ru", "phone": "+70470276770"}
0005432262203	F57BA1	0623 485614	ELIZAVETA VOROBEVA	{"phone": "+70740624085"}
0005432262204	F57BA1	2100 107440	MAKSIM KUZNECOV	{"email": "kuznecov_m.091974@postgrespro.ru", "phone": "+70252571318"}
0005432262205	035908	1511 406970	EVGENIYA IVANOVA	{"phone": "+70014528074"}
0005432262206	035908	4262 751730	ANTON ALEKSANDROV	{"email": "aaleksandrov1968@postgrespro.ru", "phone": "+70808256407"}
0005432262207	1CF87C	2010 545407	ILYA STEPANOV	{"email": "stepanovilya.25021969@postgrespro.ru", "phone": "+70462056651"}
0005432262208	B13BB0	5378 944466	VALENTINA KUZMINA	{"email": "kuzmina_v.1962@postgrespro.ru", "phone": "+70515339839"}
0005432262209	B13BB0	9830 474306	RIM KOZLOV	{"phone": "+70274690030"}
0005432262210	D1B330	9962 241144	EVGENIY ABRAMOV	{"email": "e-abramov.061979@postgrespro.ru", "phone": "+70529930397"}
0005432262211	D1B330	1904 581162	MARIYA MARTYNOVA	{"email": "mmartynova_02121971@postgrespro.ru", "phone": "+70802282685"}
0005432262212	7E1617	7980 428358	GALINA SEMENOVA	{"email": "semenovag_1965@postgrespro.ru", "phone": "+70431433543"}
0005432262213	B95350	6744 218569	VLADIMIR NAZAROV	{"email": "nazarov_vladimir_26031969@postgrespro.ru", "phone": "+70025843141"}
0005432262214	B09D6D	5392 408410	SERGEY DMITRIEV	{"email": "dmitriev-sergey-041973@postgrespro.ru", "phone": "+70612668654"}
0005432262215	FBA4B4	0169 451627	ALEKSANDRA KRASNOVA	{"email": "krasnovaa021972@postgrespro.ru", "phone": "+70772945279"}
0005432262216	688CD1	6842 496117	VLADIMIR ANTONOV	{"email": "vladimir_antonov081980@postgrespro.ru", "phone": "+70953588111"}
0005432262217	3C4B24	0226 608879	VERA FROLOVA	{"email": "frolova_v1984@postgrespro.ru", "phone": "+70590758011"}
0005432262218	39261F	9772 387695	EKATERINA NOVIKOVA	{"phone": "+70704520244"}
0005432262219	39261F	4954 990396	SERGEY SAVELEV	{"phone": "+70260345756"}
0005432262220	D82DF8	4757 730053	YANA SIDOROVA	{"phone": "+70022536691"}
0005432262221	D82DF8	1071 083375	ALEKSANDR VOLKOV	{"email": "volkov-a.17041974@postgrespro.ru", "phone": "+70139415697"}
0005432262222	7D0364	9406 223179	MARIYA POPOVA	{"phone": "+70981790326"}
0005432262223	DE8E7C	9959 402589	ALEKSANDR IVANOV	{"email": "ivanov_a1965@postgrespro.ru", "phone": "+70713110766"}
0005432262224	1D92F8	3090 760583	NATALYA KISELEVA	{"email": "kiselevanatalya25041973@postgrespro.ru", "phone": "+70399308118"}
0005432262225	DD3BAA	9429 197321	ANNA FEDOROVA	{"email": "anna_fedorova1975@postgrespro.ru", "phone": "+70202460977"}
0005432262226	AFA214	0875 113360	ELENA GRISHINA	{"phone": "+70802796570"}
0005432262227	AFA214	1937 981565	OLEG ZAYCEV	{"phone": "+70763391486"}
0005432262228	7A3B13	2930 947161	NATALYA KONOVALOVA	{"email": "natalya_konovalova28041971@postgrespro.ru", "phone": "+70769870425"}
0005432262229	10C418	7284 743710	TARAS DAVYDOV	{"phone": "+70956311681"}
0005432262230	10C418	0437 048553	KSENIYA ISAEVA	{"email": "k-isaeva.1966@postgrespro.ru", "phone": "+70662919559"}
0005432262231	8DBA84	2030 003524	ALINA OSIPOVA	{"email": "aosipova.1982@postgrespro.ru", "phone": "+70257672891"}
0005432262232	C6B087	2574 051254	EVGENIY GRIGOREV	{"email": "e-grigorev_011976@postgrespro.ru", "phone": "+70705809492"}
0005432262233	8B938D	9588 025665	SERAFIMA MARTYNOVA	{"phone": "+70822897228"}
0005432262234	2ADF0C	5751 454581	VLADIMIR DMITRIEV	{"phone": "+70799938888"}
0005432262235	666104	6367 019251	ELVIRA LEBEDEVA	{"email": "elviralebedeva04011974@postgrespro.ru", "phone": "+70687699267"}
0005432262236	666104	5695 157961	ELENA FADEEVA	{"email": "e-fadeeva011971@postgrespro.ru", "phone": "+70356011538"}
0005432262237	A57A8B	1681 422560	ALEKSANDR DMITRIEV	{"phone": "+70786618547"}
0005432262238	499146	6079 263997	GALINA DENISOVA	{"email": "galinadenisova-1968@postgrespro.ru", "phone": "+70195531846"}
0005432262239	3020C2	1002 706937	VLADIMIR SEMENOV	{"email": "semenovv1987@postgrespro.ru", "phone": "+70136403614"}
0005432262240	16BAA9	6940 383058	YULIYA LUKYANOVA	{"phone": "+70775867526"}
0005432262241	16BAA9	5636 982059	RAISA FOMINA	{"phone": "+70256146847"}
0005432262242	0FABE8	3184 919122	NADEZHDA EGOROVA	{"email": "nadezhda-egorova-1975@postgrespro.ru", "phone": "+70639237681"}
0005432262243	32C4B6	6948 176820	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov_111970@postgrespro.ru", "phone": "+70701013086"}
0005432262244	649870	8766 862026	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov_121973@postgrespro.ru", "phone": "+70276730588"}
0005432262245	7307EA	7598 599529	ANTONINA ZAYCEVA	{"email": "zayceva.antonina.25081978@postgrespro.ru", "phone": "+70299159599"}
0005432262246	4F0BD4	9517 061686	SOFYA BELYAEVA	{"phone": "+70159677150"}
0005432262247	4F0BD4	2525 210216	VLADISLAV TIMOFEEV	{"email": "timofeev.vladislav1975@postgrespro.ru", "phone": "+70623694516"}
0005432262248	07D41E	9539 365369	DMITRIY VLASOV	{"email": "dvlasov.061972@postgrespro.ru", "phone": "+70887314165"}
0005432262249	1F8C64	1013 138051	VENERA MAKAROVA	{"phone": "+70472947806"}
0005432262250	4019BF	7841 383430	VITALIY FOMIN	{"phone": "+70249856995"}
0005432262251	4019BF	3764 336864	MARINA VOROBEVA	{"phone": "+70751283100"}
0005432262252	66BA9C	6847 899791	ANATOLIY TARASOV	{"email": "atarasov.1974@postgrespro.ru", "phone": "+70798794253"}
0005432262253	66BA9C	2451 078992	ZHANNA PETROVA	{"phone": "+70692900879"}
0005432262254	F5C6C5	1676 119423	LUIZA ANDREEVA	{"phone": "+70729240002"}
0005432262255	0215FC	0930 658961	ANDREY CHERNOV	{"phone": "+70687940484"}
0005432262256	0215FC	7965 370971	YULIYA KUZMINA	{"email": "y_kuzmina.1969@postgrespro.ru", "phone": "+70326369582"}
0005432262257	B2829B	0397 683277	VERA KOROLEVA	{"email": "v_koroleva_091976@postgrespro.ru", "phone": "+70887772383"}
0005432262258	B2829B	4843 149383	YULIYA ZHURAVLEVA	{"phone": "+70393941518"}
0005432262259	068DD9	6392 342101	IRINA ZHURAVLEVA	{"email": "zhuravleva-irina1976@postgrespro.ru", "phone": "+70049035203"}
0005432262260	068DD9	6063 849483	MARINA FILATOVA	{"email": "filatova_m-17041954@postgrespro.ru", "phone": "+70707222001"}
0005432262261	068DD9	0505 693120	MAKSIM VLASOV	{"email": "mvlasov-101965@postgrespro.ru", "phone": "+70853878801"}
0005432262262	BE0945	7597 028946	MARIYA PETROVA	{"email": "m.petrova1966@postgrespro.ru", "phone": "+70881954582"}
0005432262263	220343	0481 198730	GALINA SERGEEVA	{"email": "g_sergeeva1968@postgrespro.ru", "phone": "+70144895513"}
0005432262264	9E6F91	0004 614562	EDUARD PAVLOV	{"phone": "+70859570326"}
0005432262265	9E6F91	7769 780581	DMITRIY VLASOV	{"email": "vlasov.dmitriy18041977@postgrespro.ru", "phone": "+70126510851"}
0005432262266	6393FF	5027 770319	ANDREY YAKOVLEV	{"email": "yakovlev.andrey03081957@postgrespro.ru", "phone": "+70965042681"}
0005432262267	792049	2668 361472	GALINA ALEKSEEVA	{"email": "alekseeva.galina-031972@postgrespro.ru", "phone": "+70587604543"}
0005432262268	792049	9537 533670	EGOR NAZAROV	{"email": "egor-nazarov_041977@postgrespro.ru", "phone": "+70030846995"}
0005432262269	DB6891	5161 298918	KRISTINA SMIRNOVA	{"phone": "+70037267705"}
0005432262270	DB6891	9164 768447	NATALYA SEMENOVA	{"phone": "+70313931272"}
0005432262271	88315D	1927 838808	KSENIYA MAKSIMOVA	{"phone": "+70803198683"}
0005432262272	88315D	9320 644478	VALENTINA ANTONOVA	{"email": "valentinaantonova01041969@postgrespro.ru", "phone": "+70851929376"}
0005432262273	76F20D	5676 743296	YANA ANDREEVA	{"email": "yandreeva.021982@postgrespro.ru", "phone": "+70425351842"}
0005432262274	F5A449	2299 458004	ANATOLIY IVANOV	{"email": "ivanov-a1966@postgrespro.ru", "phone": "+70423856479"}
0005432262275	F07E5E	4009 037933	NIKITA MAKAROV	{"phone": "+70476327388"}
0005432262276	9AF046	0356 866706	LYUDMILA IVANOVA	{"phone": "+70097683122"}
0005432262277	46C663	4849 003602	SERGEY SOKOLOV	{"phone": "+70660414257"}
0005432262278	B3A4D5	6481 665536	OLGA YAKOVLEVA	{"email": "o_yakovleva-061968@postgrespro.ru", "phone": "+70222230096"}
0005432262279	B3A4D5	5373 443059	DMITRIY KUZMIN	{"email": "kuzmin.d1968@postgrespro.ru", "phone": "+70943786899"}
0005432262280	888096	8679 466319	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova.071976@postgrespro.ru", "phone": "+70811642362"}
0005432262281	9B6AC7	0954 041246	SERGEY VOLKOV	{"email": "volkov.sergey-1968@postgrespro.ru", "phone": "+70508273683"}
0005432262282	9B6AC7	0531 514688	IRINA MAKAROVA	{"phone": "+70644958969"}
0005432262283	F85BDF	4189 308277	VYACHESLAV ALEKSEEV	{"phone": "+70591126186"}
0005432262284	30F8DD	7284 481585	VIKTOR ALEKSEEV	{"phone": "+70277151257"}
0005432262285	F5CFAE	6447 229893	ANDREY ZHURAVLEV	{"email": "zhuravlev.a-22081971@postgrespro.ru", "phone": "+70266163846"}
0005432262286	5D3395	2282 563430	OLGA EGOROVA	{"email": "olga-egorova-1974@postgrespro.ru", "phone": "+70900721256"}
0005432262287	733036	3531 581034	VLADISLAV ANDREEV	{"email": "vandreev_081974@postgrespro.ru", "phone": "+70934374705"}
0005432262288	32ED11	0235 491253	GYUZEL KUZNECOVA	{"phone": "+70269111085"}
0005432262289	200773	9350 444714	ELENA ANDREEVA	{"phone": "+70633144387"}
0005432262290	4826C4	9594 128614	RASHID IVANOV	{"email": "ivanovrashid_18051973@postgrespro.ru", "phone": "+70588775473"}
0005432262291	3CDE27	3364 551578	ALEKSEY KARPOV	{"phone": "+70233094420"}
0005432262292	94E2CD	0158 946241	VENIAMIN FROLOV	{"email": "frolovveniamin_111976@postgrespro.ru", "phone": "+70027047155"}
0005432262293	1FA488	2959 796364	LYUBOV SOKOLOVA	{"phone": "+70721201655"}
0005432262294	1FA488	2635 732546	SERGEY GRIGOREV	{"email": "s_grigorev031971@postgrespro.ru", "phone": "+70093715347"}
0005432262295	8BA0DA	4343 621318	EVGENIY SOROKIN	{"phone": "+70480502460"}
0005432262296	A9450B	2725 792852	OLEG SHEVCHENKO	{"email": "shevchenko_o_1982@postgrespro.ru", "phone": "+70889345786"}
0005432262297	A9450B	7382 761080	ELENA KRASNOVA	{"phone": "+70097533521"}
0005432262298	38602F	2081 283558	IRINA VASILEVA	{"phone": "+70757147813"}
0005432262299	7D2EA7	8522 881726	DMITRIY IVANOV	{"email": "ivanov-d.051978@postgrespro.ru", "phone": "+70741235292"}
0005432262300	7D2EA7	9489 684263	NATALYA BORISOVA	{"email": "natalya_borisova-091975@postgrespro.ru", "phone": "+70330434938"}
0005432262301	533801	1134 704870	YURIY IVANOV	{"email": "ivanov_y1962@postgrespro.ru", "phone": "+70852067204"}
0005432262302	09A505	8620 251964	IRINA NESTEROVA	{"email": "nesterova.irina031968@postgrespro.ru", "phone": "+70526259282"}
0005432262303	119A0D	4711 932976	SERGEY SEMENOV	{"email": "semenov.s-031975@postgrespro.ru", "phone": "+70849344671"}
0005432262304	119A0D	9527 109579	VALENTINA AFANASEVA	{"phone": "+70242647381"}
0005432262305	119A0D	3464 021703	OLGA KRASNOVA	{"email": "okrasnova-111971@postgrespro.ru", "phone": "+70386847336"}
0005432262306	015A8B	5633 536506	TATYANA POPOVA	{"email": "popova.t-04111975@postgrespro.ru", "phone": "+70461997700"}
0005432262307	D61164	3329 279370	VALENTINA MATVEEVA	{"email": "v.matveeva.15011968@postgrespro.ru", "phone": "+70770831288"}
0005432262308	D61164	2374 180727	ELENA BORISOVA	{"phone": "+70244917448"}
0005432262309	D61164	0293 548883	ELENA ANISIMOVA	{"phone": "+70452188897"}
0005432262310	36B689	3214 014225	IRINA SOKOLOVA	{"phone": "+70238727785"}
0005432262311	6D81FF	4492 043873	NINA KUZNECOVA	{"phone": "+70807060306"}
0005432262312	297E8E	0647 154924	VALERIY SIDOROV	{"phone": "+70194009948"}
0005432262313	297E8E	4423 159129	TATYANA GORBUNOVA	{"phone": "+70283106506"}
0005432262314	4A9DBF	1147 785637	NADEZHDA MALYSHEVA	{"phone": "+70898782034"}
0005432262315	4A9DBF	8280 345794	ANTON YAKOVLEV	{"email": "a_yakovlev.11091975@postgrespro.ru", "phone": "+70283600544"}
0005432262316	4A9DBF	6963 955786	MARIYA KRASNOVA	{"email": "m_krasnova.121970@postgrespro.ru", "phone": "+70760504407"}
0005432262317	49A7D4	5829 950785	SERGEY AFANASEV	{"email": "afanasev_s1971@postgrespro.ru", "phone": "+70121132362"}
0005432262318	765C5F	5725 906158	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev.101972@postgrespro.ru", "phone": "+70207101979"}
0005432262319	B156D0	4218 423419	SERGEY KRASNOV	{"phone": "+70849793731"}
0005432262320	B156D0	9346 793021	TATYANA IVANOVA	{"phone": "+70277337250"}
0005432262321	C2A52D	8271 078557	IGOR ANTONOV	{"email": "antonov.i111974@postgrespro.ru", "phone": "+70528314641"}
0005432262322	C2A52D	1649 975434	YURIY KISELEV	{"phone": "+70988092148"}
0005432262323	C2A52D	4833 293522	SERGEY BORISOV	{"email": "sergey_borisov-041976@postgrespro.ru", "phone": "+70216971708"}
0005432262324	F085A5	3364 777262	KLAVDIYA SAVELEVA	{"email": "saveleva_klavdiya.101971@postgrespro.ru", "phone": "+70963348349"}
0005432262325	F085A5	3397 108861	ALEKSANDR STEPANOV	{"email": "stepanov-a051971@postgrespro.ru", "phone": "+70621475075"}
0005432262326	B4F38E	3955 413209	MIKHAIL SCHERBAKOV	{"email": "m_scherbakov-021971@postgrespro.ru", "phone": "+70074118639"}
0005432262327	C9E5A5	7354 376378	GALINA BORISOVA	{"email": "galina-borisova111970@postgrespro.ru", "phone": "+70480555639"}
0005432262328	C9E5A5	5900 614847	VERA ROMANOVA	{"email": "romanova-vera.1972@postgrespro.ru", "phone": "+70884883532"}
0005432262329	50DA3F	5554 093836	IVAN SOROKIN	{"email": "sorokin-ivan011971@postgrespro.ru", "phone": "+70359102832"}
0005432262330	7FB8B2	3390 695119	DMITRIY VOLKOV	{"phone": "+70162196316"}
0005432262331	7FB8B2	1972 405015	ANASTASIYA ZAKHAROVA	{"email": "a_zakharova081969@postgrespro.ru", "phone": "+70499070549"}
0005432262332	7FB8B2	8885 566172	LYUBOV ALEKSANDROVA	{"email": "aleksandrovalyubov16021971@postgrespro.ru", "phone": "+70840342299"}
0005432262333	0873DD	0477 028887	ALEKSANDR SHEVCHENKO	{"phone": "+70834563099"}
0005432262334	8590D1	3324 210363	ANVAR NAUMOV	{"phone": "+70200041240"}
0005432262335	7D579C	5237 484787	EKATERINA NOVIKOVA	{"phone": "+70595881467"}
0005432262336	D6EAC3	7992 721653	IGOR TIKHONOV	{"phone": "+70671541844"}
0005432262337	D6EAC3	2504 843797	GENNADIY GAVRILOV	{"email": "gavrilovgennadiy-20111981@postgrespro.ru", "phone": "+70514163343"}
0005432262338	1AFE46	4789 836402	SERGEY ORLOV	{"email": "s.orlov011971@postgrespro.ru", "phone": "+70301511629"}
0005432262339	1AFE46	9116 960735	LIDIYA MIRONOVA	{"email": "mironova_lidiya.1985@postgrespro.ru", "phone": "+70718254076"}
0005432262340	F548B0	4875 784487	ANNA FOMINA	{"email": "a.fomina-1972@postgrespro.ru", "phone": "+70308258869"}
0005432262341	F548B0	5395 916035	SERGEY VOLKOV	{"email": "sergey_volkov_1973@postgrespro.ru", "phone": "+70005787679"}
0005432262342	1CF8E4	6813 010644	ELENA PAVLOVA	{"email": "epavlova121973@postgrespro.ru", "phone": "+70522260192"}
0005432262343	1CF8E4	2739 907710	NIKOLAY KAZAKOV	{"phone": "+70362148499"}
0005432262344	0D29D3	6577 924836	ANATOLIY ANDREEV	{"email": "andreev_anatoliy-14071973@postgrespro.ru", "phone": "+70065867394"}
0005432262345	841592	2898 066813	YULIYA ALEKSEEVA	{"email": "alekseeva.y-051992@postgrespro.ru", "phone": "+70701763994"}
0005432262346	841592	6593 165610	ANTONINA MOROZOVA	{"phone": "+70058722522"}
0005432262347	C23D71	0319 516881	GENNADIY DAVYDOV	{"phone": "+70166813076"}
0005432262348	585499	6333 241592	TATYANA ORLOVA	{"email": "tatyanaorlova1965@postgrespro.ru", "phone": "+70784411217"}
0005432262349	585499	6788 211865	IVAN DMITRIEV	{"phone": "+70566938132"}
0005432262350	325252	6721 408591	NIKOLAY ANDREEV	{"phone": "+70119033171"}
0005432262351	1F0D84	9157 586259	YURIY NIKOLAEV	{"phone": "+70655172973"}
0005432262352	97A2B4	1652 317540	EVGENIY KUZNECOV	{"email": "kuznecov_evgeniy.031960@postgrespro.ru", "phone": "+70402145484"}
0005432262353	E3DADE	9952 096665	NATALYA KUZNECOVA	{"email": "kuznecova-n.23091966@postgrespro.ru", "phone": "+70168824507"}
0005432262354	0A9CE5	5484 846294	SERGEY FILIPPOV	{"phone": "+70682919371"}
0005432262355	0A9CE5	3582 553868	ROMAN PAVLOV	{"email": "romanpavlov-14011970@postgrespro.ru", "phone": "+70082785146"}
0005432262356	0A9CE5	4998 626249	VLADISLAV MOROZOV	{"phone": "+70893466503"}
0005432262357	0D5B99	5384 648939	VALERIY MEDVEDEV	{"email": "v-medvedev_081963@postgrespro.ru", "phone": "+70132024007"}
0005432262358	0ADE57	3747 378807	GALINA ABRAMOVA	{"email": "g-abramova.07021960@postgrespro.ru", "phone": "+70819355671"}
0005432262359	2854BB	9927 378241	MAKSIM TIKHONOV	{"phone": "+70999029609"}
0005432262360	837956	3910 315297	ALI NIKOLAEV	{"email": "nikolaevali-1978@postgrespro.ru", "phone": "+70980155445"}
0005432262361	F6DEF2	8024 544368	YULIYA SOROKINA	{"phone": "+70756023938"}
0005432262362	B93853	8769 708410	VADIM MAKAROV	{"email": "makarovvadim031966@postgrespro.ru", "phone": "+70950899426"}
0005432262363	B93853	9436 416438	VALENTINA MARTYNOVA	{"phone": "+70813563422"}
0005432262364	768EC4	3780 308495	DINARA SCHERBAKOVA	{"phone": "+70449436334"}
0005432262365	0B49DA	8021 135163	EVGENIY ALEKSANDROV	{"phone": "+70709368617"}
0005432262366	55DB14	4904 773283	EGOR KUDRYASHOV	{"phone": "+70382824847"}
0005432262367	55DB14	8725 525397	NINA TIKHONOVA	{"email": "nina-tikhonova04071974@postgrespro.ru", "phone": "+70333620743"}
0005432262368	0872B0	2996 275313	NATALYA SOLOVEVA	{"email": "n-soloveva_21121978@postgrespro.ru", "phone": "+70305845687"}
0005432262369	0872B0	1326 742217	GALINA VOLKOVA	{"phone": "+70869496315"}
0005432262370	22E319	8870 626293	NATALYA YAKOVLEVA	{"email": "yakovleva.natalya_1970@postgrespro.ru", "phone": "+70486012299"}
0005432262371	22E319	8319 772240	ALEKSEY ZAYCEV	{"email": "zaycev-a-04101977@postgrespro.ru", "phone": "+70302802647"}
0005432262372	A67F66	2260 944539	ANATOLIY FEDOROV	{"phone": "+70058769065"}
0005432262373	FEEA2D	2295 503432	IRINA ANTONOVA	{"email": "irina.antonova.111978@postgrespro.ru", "phone": "+70633588434"}
0005432262374	DA9483	7782 385864	DMITRIY TARASOV	{"email": "tarasov-dmitriy.1964@postgrespro.ru", "phone": "+70761525045"}
0005432262375	DA9483	7279 323774	ALEKSEY AFANASEV	{"email": "alekseyafanasev-1983@postgrespro.ru", "phone": "+70269563873"}
0005432262376	DA9483	1074 130227	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy-1975@postgrespro.ru", "phone": "+70351602113"}
0005432262377	C4E445	3822 485908	IGOR YAKOVLEV	{"phone": "+70755815141"}
0005432262378	C4E445	2589 446945	NINA PAVLOVA	{"email": "npavlova_23011981@postgrespro.ru", "phone": "+70494328377"}
0005432262379	C4E445	8564 468655	GALINA BELOVA	{"email": "belovagalina-061976@postgrespro.ru", "phone": "+70041777689"}
0005432262380	31FD83	8124 441879	MARIYA KONOVALOVA	{"email": "mkonovalova1976@postgrespro.ru", "phone": "+70180839389"}
0005432262381	539930	0346 344004	VYACHESLAV MAKAROV	{"email": "makarovv.1979@postgrespro.ru", "phone": "+70483439007"}
0005432262382	19881A	5524 045055	ANASTASIYA POTAPOVA	{"phone": "+70512308013"}
0005432262383	19881A	3886 409930	OKSANA FADEEVA	{"email": "o-fadeeva1977@postgrespro.ru", "phone": "+70551895715"}
0005432262384	BE60CD	7407 075750	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr-071969@postgrespro.ru", "phone": "+70649670298"}
0005432262385	BE60CD	2466 241492	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v_1972@postgrespro.ru", "phone": "+70853375300"}
0005432262386	BE60CD	6433 281330	IVAN SMIRNOV	{"email": "ivan.smirnov-051967@postgrespro.ru", "phone": "+70540599535"}
0005432262387	A32E9C	2203 958584	IVAN IVANOV	{"phone": "+70216571155"}
0005432262388	A5ED37	1722 950003	ALEKSEY SEMENOV	{"phone": "+70274409583"}
0005432262389	A66715	4541 355948	ANATOLIY ORLOV	{"phone": "+70269317409"}
0005432262390	FFA1E8	3992 933633	ANDREY DENISOV	{"email": "andrey_denisov.16091974@postgrespro.ru", "phone": "+70357792497"}
0005432262391	FD0D9E	0802 898435	VALENTIN VOLKOV	{"phone": "+70273724033"}
0005432262392	5B717C	7508 680459	DMITRIY SIDOROV	{"phone": "+70982081757"}
0005432262393	8F61B5	4262 206888	ANDREY IVANOV	{"phone": "+70511406483"}
0005432262394	8F61B5	8167 721142	SERGEY NAZAROV	{"email": "sergey_nazarov_1969@postgrespro.ru", "phone": "+70641187662"}
0005432262395	1583F8	9827 044722	MIKHAIL KUZNECOV	{"phone": "+70496460699"}
0005432262396	423BB7	3774 550646	SERGEY ALEKSEEV	{"phone": "+70107543954"}
0005432262397	423BB7	2361 534468	ANNA KUZNECOVA	{"phone": "+70016959604"}
0005432262398	97BC72	8087 737207	MIKHAIL SEMENOV	{"phone": "+70504374263"}
0005432262399	DAEB8F	6949 675413	KONSTANTIN KUZNECOV	{"phone": "+70292513310"}
0005432262400	692F43	7524 780799	EGOR AFANASEV	{"email": "e_afanasev1978@postgrespro.ru", "phone": "+70383574467"}
0005432262401	F9BC7F	2025 360753	ALEKSANDR POPOV	{"phone": "+70109279407"}
0005432262402	F9BC7F	4533 137558	DANIL FILIPPOV	{"email": "filippovd_29081970@postgrespro.ru", "phone": "+70917347295"}
0005432262403	ABF174	8873 245773	NIKOLAY NIKOLAEV	{"phone": "+70285400441"}
0005432262404	ABF174	8786 791295	TATYANA KUZMINA	{"email": "kuzmina-t_09051980@postgrespro.ru", "phone": "+70078725661"}
0005432262405	5AAD92	8682 884640	IRINA BARANOVA	{"email": "i_baranova.08051983@postgrespro.ru", "phone": "+70133369079"}
0005432262406	5AAD92	2607 353371	ALEKSANDR MELNIKOV	{"phone": "+70438138436"}
0005432262407	6DD9ED	4508 542013	MIKHAIL KULIKOV	{"phone": "+70206533349"}
0005432262408	49FAD4	2434 256978	VALENTIN FEDOTOV	{"email": "vfedotov.031968@postgrespro.ru", "phone": "+70866715106"}
0005432262409	49FAD4	8692 337479	RASHID MOROZOV	{"email": "morozov.r-25121967@postgrespro.ru", "phone": "+70778079740"}
0005432262410	49FAD4	7462 512612	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova_l.1971@postgrespro.ru", "phone": "+70262310151"}
0005432262411	F455A7	4852 275767	ANTON SMIRNOV	{"phone": "+70409394239"}
0005432262412	F455A7	0558 148940	NIKOLAY BARANOV	{"phone": "+70900944298"}
0005432262413	F455A7	6219 393109	SERGEY KUZNECOV	{"email": "sergeykuznecov1971@postgrespro.ru", "phone": "+70178533293"}
0005432262414	B30A68	1455 791039	VYACHESLAV KUZMIN	{"email": "vyacheslavkuzmin-08121976@postgrespro.ru", "phone": "+70970514193"}
0005432262415	480985	1509 814757	TATYANA ORLOVA	{"phone": "+70191340431"}
0005432262416	480985	5400 571765	NATALYA KOVALEVA	{"email": "kovaleva-natalya_07021973@postgrespro.ru", "phone": "+70876058774"}
0005432262417	D7B28E	3193 135682	EKATERINA PETROVA	{"phone": "+70877434669"}
0005432262418	D7B28E	2637 481926	VLADIMIR SHEVCHENKO	{"phone": "+70364097547"}
0005432262419	961C79	4741 675813	ALEKSANDR KUZNECOV	{"phone": "+70711596363"}
0005432262420	00114E	5718 360783	OLGA EGOROVA	{"email": "olga_egorova-1976@postgrespro.ru", "phone": "+70047115091"}
0005432262421	670FEF	3045 151192	MARIYA KUZNECOVA	{"email": "kuznecova_m_1973@postgrespro.ru", "phone": "+70359733393"}
0005432262422	14AB01	0674 289399	VLADIMIR KAZAKOV	{"phone": "+70717820753"}
0005432262423	C98A4D	9919 072648	SERGEY OSIPOV	{"phone": "+70120213753"}
0005432262424	8F50EF	3220 926351	SERGEY FEDOROV	{"email": "sergey_fedorov.1972@postgrespro.ru", "phone": "+70389330363"}
0005432262425	233449	2682 046196	ILYA MATVEEV	{"phone": "+70383169939"}
0005432262426	DF4D0B	6231 099002	IRINA RODIONOVA	{"email": "i-rodionova121971@postgrespro.ru", "phone": "+70576346206"}
0005432262427	DF4D0B	8568 583331	OKSANA SOROKINA	{"email": "sorokina.oksana13091971@postgrespro.ru", "phone": "+70762929348"}
0005432262428	E44DEA	2844 054672	RAISA MIKHAYLOVA	{"phone": "+70437700410"}
0005432262429	AC6E0A	2458 994433	LARISA ZAKHAROVA	{"email": "zakharova-l.17031970@postgrespro.ru", "phone": "+70761932747"}
0005432262430	C51738	0145 502104	DARINA KALININA	{"email": "kalininad01071964@postgrespro.ru", "phone": "+70310107500"}
0005432262431	F69D32	1560 372582	RAISA KUZNECOVA	{"phone": "+70129652920"}
0005432262432	3747CB	6392 357968	IGOR POPOV	{"email": "i.popov071975@postgrespro.ru", "phone": "+70055292170"}
0005432262433	3747CB	0386 377198	VALENTINA GERASIMOVA	{"phone": "+70095843645"}
0005432262434	81776A	0605 996727	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey_15051967@postgrespro.ru", "phone": "+70084228096"}
0005432262435	E693D4	2081 650839	ALEKSEY MELNIKOV	{"email": "a_melnikov1973@postgrespro.ru", "phone": "+70347958204"}
0005432262436	679E63	4541 655356	NIKOLAY TIMOFEEV	{"phone": "+70597406040"}
0005432262437	C44158	0869 679840	VALENTINA VOROBEVA	{"phone": "+70682735508"}
0005432262438	C44158	3697 920837	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir.021984@postgrespro.ru", "phone": "+70645549961"}
0005432262439	F52966	6343 789966	OLGA VASILEVA	{"email": "o_vasileva.081978@postgrespro.ru", "phone": "+70401997131"}
0005432262440	4765FF	7022 888431	VALENTINA MIKHAYLOVA	{"phone": "+70198791902"}
0005432262441	9C158A	1523 627028	RUSLAN ILIN	{"phone": "+70752750944"}
0005432262442	FCBD53	0364 777893	LARISA BOGDANOVA	{"email": "l_bogdanova-041964@postgrespro.ru", "phone": "+70347965939"}
0005432262443	FCBD53	2469 750887	SERAFIM NAUMOV	{"email": "s.naumov_1982@postgrespro.ru", "phone": "+70936153713"}
0005432262444	730CBA	1083 602449	NATALIYA MATVEEVA	{"phone": "+70565019445"}
0005432262445	B55AB0	3120 572098	NATALIYA MARTYNOVA	{"email": "n-martynova1968@postgrespro.ru", "phone": "+70974580109"}
0005432262446	CE8CF9	9445 295942	SERGEY MAKAROV	{"email": "makarov-sergey-1977@postgrespro.ru", "phone": "+70895001025"}
0005432262447	BC61BF	4756 227625	ALEKSEY MARTYNOV	{"phone": "+70916611554"}
0005432262448	B19D79	6371 127902	TATYANA EGOROVA	{"phone": "+70267579683"}
0005432262449	3CB240	6933 279601	VLADIMIR ILIN	{"phone": "+70819502369"}
0005432262450	C43661	1480 970827	LYUDMILA POPOVA	{"email": "lyudmila-popova.1977@postgrespro.ru", "phone": "+70730477504"}
0005432262451	C4DEA8	8864 340200	PAVEL KARPOV	{"email": "pavelkarpov-09051968@postgrespro.ru", "phone": "+70386063020"}
0005432262452	5E9ED7	9372 221527	YURIY VOROBEV	{"email": "y-vorobev_1970@postgrespro.ru", "phone": "+70514592507"}
0005432262453	5E9ED7	9199 461327	OLEG KULIKOV	{"phone": "+70577288176"}
0005432262454	C4E53C	9741 129183	DMITRIY SOROKIN	{"phone": "+70881425935"}
0005432262455	D1AEB6	6511 186503	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr1975@postgrespro.ru", "phone": "+70801742728"}
0005432262456	9B1B3C	2141 151947	RUSTAM SHEVCHENKO	{"phone": "+70358493838"}
0005432262457	CC818D	2372 124653	ALEKSEY ISAEV	{"phone": "+70241217636"}
0005432262458	047408	3429 317453	NATALYA KOROLEVA	{"email": "koroleva_natalya-1980@postgrespro.ru", "phone": "+70390671694"}
0005432262459	047408	5360 196398	MARINA VLASOVA	{"phone": "+70075114371"}
0005432262460	150FBC	5036 910614	ANDREY DMITRIEV	{"phone": "+70516987657"}
0005432262461	150FBC	0825 508564	NIKITA FEDOROV	{"email": "nikita.fedorov121975@postgrespro.ru", "phone": "+70366013473"}
0005432262462	F71464	6225 214389	VALERIY ANTONOV	{"email": "v_antonov1972@postgrespro.ru", "phone": "+70400262638"}
0005432262463	458913	1953 654405	VALERIY MIKHAYLOV	{"email": "mikhaylov-valeriy121970@postgrespro.ru", "phone": "+70577424272"}
0005432262464	1A1DD1	4886 417183	VLADISLAV GUSEV	{"email": "gusev_v_091975@postgrespro.ru", "phone": "+70807996969"}
0005432262465	6D58C4	0308 915520	OLEG DAVYDOV	{"email": "davydov.o_1984@postgrespro.ru", "phone": "+70665241703"}
0005432262466	3CB68B	7319 809378	MARINA POPOVA	{"phone": "+70321440967"}
0005432262467	029719	6894 753351	ELENA MAKAROVA	{"phone": "+70836347754"}
0005432262468	1F76A7	5264 487900	ROZA BELOVA	{"email": "belovaroza.1978@postgrespro.ru", "phone": "+70302024350"}
0005432262469	1573DF	9301 033580	SERGEY SOROKIN	{"email": "sergey-sorokin-1964@postgrespro.ru", "phone": "+70395765065"}
0005432262470	BE3EDC	2300 504882	ALEKSANDR NIKOLAEV	{"email": "anikolaev15101976@postgrespro.ru", "phone": "+70744918427"}
0005432262471	BE3EDC	5525 694169	IVAN IVANOV	{"phone": "+70768302716"}
0005432262472	BE3EDC	9139 884540	PETR CHERNOV	{"email": "chernov.p1975@postgrespro.ru", "phone": "+70345790260"}
0005432262473	C0E00E	5547 260043	VLADIMIR ABRAMOV	{"phone": "+70597291781"}
0005432262474	806730	0959 715809	GRIGORIY VOLKOV	{"phone": "+70859017425"}
0005432262475	806730	5718 211808	YURIY KUZNECOV	{"email": "kuznecov_y-1970@postgrespro.ru", "phone": "+70171449989"}
0005432262476	E3C224	5534 022794	LIDIYA BORISOVA	{"phone": "+70120383641"}
0005432262477	E3C224	8815 343169	OLEG MOROZOV	{"phone": "+70192774735"}
0005432262478	986CBD	4798 515636	TATYANA POPOVA	{"email": "t_popova_011968@postgrespro.ru", "phone": "+70000287690"}
0005432262479	986CBD	0402 478117	SERGEY MOROZOV	{"phone": "+70775269365"}
0005432262480	A5B535	5676 498896	ZINAIDA ILINA	{"email": "z.ilina.23021984@postgrespro.ru", "phone": "+70447186866"}
0005432262481	A0F182	4941 948279	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey-30091967@postgrespro.ru", "phone": "+70253934768"}
0005432262482	7AEC34	4470 578798	EVGENIY ANDREEV	{"phone": "+70019741006"}
0005432262483	7AEC34	2272 580157	ALEKSANDR SCHERBAKOV	{"email": "scherbakova-1978@postgrespro.ru", "phone": "+70009636710"}
0005432262484	ABA81A	7838 256570	KLARA DANILOVA	{"phone": "+70694796405"}
0005432262485	EDA2DE	9256 438690	ALEKSANDR VASILEV	{"phone": "+70451178400"}
0005432262486	D704BA	2695 633083	IRINA MIRONOVA	{"email": "irina_mironova1971@postgrespro.ru", "phone": "+70857211135"}
0005432262487	D704BA	1277 388781	VALENTINA BARANOVA	{"phone": "+70958443948"}
0005432262488	76C055	0886 340260	VIKTOR PAVLOV	{"phone": "+70702160185"}
0005432262489	857806	3924 233687	NATALYA GERASIMOVA	{"email": "n_gerasimova-061976@postgrespro.ru", "phone": "+70720632079"}
0005432262490	857806	5160 749076	ALEKSANDRA MARTYNOVA	{"email": "martynovaaleksandra.14061978@postgrespro.ru", "phone": "+70891032360"}
0005432262491	752042	6324 966786	ALEKSANDRA CHERNOVA	{"email": "aleksandra_chernova_30091961@postgrespro.ru", "phone": "+70579881014"}
0005432262492	90EA31	7866 449961	ALEKSEY KUZMIN	{"email": "aleksey.kuzmin_16051961@postgrespro.ru", "phone": "+70935830069"}
0005432262493	90EA31	4777 171436	SERGEY SOKOLOV	{"email": "s_sokolov1966@postgrespro.ru", "phone": "+70534288741"}
0005432262494	7F1302	5404 545213	ANNA KUZNECOVA	{"email": "kuznecova.a-1974@postgrespro.ru", "phone": "+70754527344"}
0005432262495	C469FC	5767 924818	OLGA TIKHONOVA	{"email": "tikhonovao-22071970@postgrespro.ru", "phone": "+70523248791"}
0005432262496	37C894	3116 174142	VLADIMIR DENISOV	{"phone": "+70246852716"}
0005432262497	98DF47	5075 541279	ANTONINA SERGEEVA	{"phone": "+70133185074"}
0005432262498	67AEC4	1942 618913	SERGEY ILIN	{"email": "s_ilin031971@postgrespro.ru", "phone": "+70805282449"}
0005432262499	67AEC4	5549 059229	VALERIYA SCHERBAKOVA	{"phone": "+70780916091"}
0005432262500	D91454	8545 248490	ALEKSEY ANDREEV	{"phone": "+70475554019"}
0005432262501	D91454	6240 778353	VALERIY SMIRNOV	{"email": "smirnov_v_101962@postgrespro.ru", "phone": "+70415124557"}
0005432262502	70D121	8159 734648	VITALIY FEDOROV	{"phone": "+70104459187"}
0005432262503	EEB2B2	5154 077097	ANATOLIY BELOV	{"email": "a.belov1958@postgrespro.ru", "phone": "+70135905453"}
0005432262504	0A3F1C	1568 124472	ANDREY KUZNECOV	{"email": "a-kuznecov-1965@postgrespro.ru", "phone": "+70503526581"}
0005432262505	B81077	7095 458755	SERGEY FROLOV	{"email": "sergeyfrolov_111973@postgrespro.ru", "phone": "+70493789136"}
0005432262506	3ADC7B	2224 100253	EKATERINA VASILEVA	{"email": "e-vasileva_1966@postgrespro.ru", "phone": "+70940003352"}
0005432262507	7F5D96	5215 312511	MIKHAIL SHEVCHENKO	{"email": "mikhailshevchenko.071970@postgrespro.ru", "phone": "+70609483035"}
0005432262508	7F5D96	5273 377246	KLAVDIYA NAZAROVA	{"phone": "+70150736999"}
0005432262509	6955AB	2128 322118	ALEKSEY KUZNECOV	{"email": "kuznecov.a.22071980@postgrespro.ru", "phone": "+70352755359"}
0005432262510	6955AB	4745 003412	MIKHAIL NAZAROV	{"email": "nazarov.m_061967@postgrespro.ru", "phone": "+70715486742"}
0005432262511	6955AB	4772 907395	EVGENIY MEDVEDEV	{"email": "e_medvedev17031966@postgrespro.ru", "phone": "+70177406435"}
0005432262512	7D5D2B	1085 341179	YULIYA ZOTOVA	{"phone": "+70668605638"}
0005432262513	2D974A	8240 470263	NATALYA KONDRATEVA	{"email": "kondratevan.101979@postgrespro.ru", "phone": "+70573964170"}
0005432262514	6867CB	0623 990813	NATALYA NIKITINA	{"phone": "+70889323293"}
0005432262515	00B8B9	1684 050019	VLADIMIR MIRONOV	{"email": "vladimirmironov1982@postgrespro.ru", "phone": "+70021758984"}
0005432262516	00B8B9	6493 667478	ANASTASIYA POPOVA	{"email": "anastasiya_popova1964@postgrespro.ru", "phone": "+70165545490"}
0005432262517	C6CAA2	2717 177988	SERGEY ORLOV	{"phone": "+70008655087"}
0005432262518	078D66	5136 300705	GALINA ANISIMOVA	{"phone": "+70389525765"}
0005432262519	8C4751	5291 483345	NIKOLAY PETROV	{"phone": "+70649745802"}
0005432262520	8C4751	0539 599477	SVETLANA ZHUKOVA	{"email": "zhukova.s-1978@postgrespro.ru", "phone": "+70364594982"}
0005432262521	E0CBCF	9010 469907	MARINA MELNIKOVA	{"phone": "+70726036784"}
0005432262522	DCA8BC	9495 654674	LIDIYA SOKOLOVA	{"phone": "+70318545931"}
0005432262523	DCA8BC	3153 799391	ALEKSANDRA ALEKSEEVA	{"phone": "+70729646358"}
0005432262524	5A8D98	1090 844875	NATALYA TARASOVA	{"email": "tarasovan23101973@postgrespro.ru", "phone": "+70945322101"}
0005432262525	5A8D98	1513 217904	VALERIY PETROV	{"email": "petrov.valeriy1972@postgrespro.ru", "phone": "+70604042025"}
0005432262526	A3B506	0938 534944	ANASTASIYA KUZMINA	{"email": "a-kuzmina1973@postgrespro.ru", "phone": "+70904053733"}
0005432262527	A3B506	0480 188972	VLADIMIR ZAKHAROV	{"phone": "+70069493220"}
0005432262528	A3B506	8262 968155	NIKOLAY AFANASEV	{"email": "n-afanasev1977@postgrespro.ru", "phone": "+70905138483"}
0005432262529	EFDE8B	2206 832302	STANISLAV IVANOV	{"phone": "+70170066572"}
0005432262530	EFDE8B	3228 416407	OLGA NIKITINA	{"phone": "+70196145352"}
0005432262531	26B2EC	4237 770193	VALENTINA KOZLOVA	{"phone": "+70360762324"}
0005432262532	558097	5809 135857	NIKOLAY ZAKHAROV	{"email": "zakharov.nikolay-30121982@postgrespro.ru", "phone": "+70035602586"}
0005432262533	558097	3954 805297	VIKTOR TIMOFEEV	{"email": "timofeev_v-031975@postgrespro.ru", "phone": "+70722880923"}
0005432262534	558097	8834 174742	ARTEM ILIN	{"phone": "+70592744648"}
0005432262655	ECAF25	3477 983694	ELENA ANISIMOVA	{"phone": "+70418509393"}
0005432262535	378DDE	1287 340149	YULIYA SOROKINA	{"email": "sorokina_yuliya_11011967@postgrespro.ru", "phone": "+70366295192"}
0005432262536	747D41	1048 527225	MAKSIM MAKAROV	{"email": "mmakarov-20081981@postgrespro.ru", "phone": "+70201146480"}
0005432262537	C4B24B	7207 069413	ALFIYA KONOVALOVA	{"phone": "+70931765433"}
0005432262538	C4B24B	2365 160306	NIKOLAY FEDOROV	{"phone": "+70612678138"}
0005432262539	C4B24B	3022 321933	NIKITA PETROV	{"email": "npetrov071967@postgrespro.ru", "phone": "+70435881145"}
0005432262540	996460	0453 233925	EKATERINA SIDOROVA	{"email": "e.sidorova1974@postgrespro.ru", "phone": "+70342848414"}
0005432262541	068330	8030 566512	LYUDMILA LEBEDEVA	{"email": "l-lebedeva1968@postgrespro.ru", "phone": "+70260017870"}
0005432262542	D1E7DC	1280 445097	ALEKSANDR VASILEV	{"phone": "+70392773506"}
0005432262543	D1E7DC	0187 740260	VERA KOMAROVA	{"phone": "+70361272972"}
0005432262544	9B9945	3780 119646	LEV SERGEEV	{"phone": "+70012174429"}
0005432262545	2B23EA	2647 111265	MARIYA IVANOVA	{"phone": "+70989769413"}
0005432262546	F68AF1	6104 563959	KIRILL CHERNOV	{"email": "kchernov1964@postgrespro.ru", "phone": "+70545028643"}
0005432262547	567B10	1797 983440	RAISA KOVALEVA	{"email": "raisa.kovaleva121971@postgrespro.ru", "phone": "+70849307813"}
0005432262548	86D702	8460 360189	NADEZHDA SAVELEVA	{"email": "nadezhda_saveleva.061972@postgrespro.ru", "phone": "+70749848396"}
0005432262549	8F5CBF	2829 970958	VITALIY KAZAKOV	{"phone": "+70790758573"}
0005432262550	BACDD5	1201 607361	NATALYA KISELEVA	{"phone": "+70621209531"}
0005432262551	BACDD5	6832 548358	KRISTINA ANTONOVA	{"email": "k.antonova.1971@postgrespro.ru", "phone": "+70397953210"}
0005432262552	DFD561	1807 433417	MAKSIM ALEKSANDROV	{"phone": "+70259282754"}
0005432262553	2845A4	8194 850088	NIKOLAY BORISOV	{"phone": "+70791517216"}
0005432262554	2845A4	6918 795764	LYAYSAN KOZLOVA	{"phone": "+70549209942"}
0005432262555	114D76	7720 589850	VERA DANILOVA	{"phone": "+70530086868"}
0005432262556	114D76	3946 722777	ANDREY KARPOV	{"email": "andrey.karpov-111973@postgrespro.ru", "phone": "+70478882588"}
0005432262557	275680	2371 031931	MARINA LAZAREVA	{"email": "lazareva.marina1969@postgrespro.ru", "phone": "+70937092534"}
0005432262558	974875	1570 876097	EKATERINA ZHUKOVA	{"phone": "+70489658085"}
0005432262559	7F5D7B	8304 490111	IRINA SOKOLOVA	{"phone": "+70409757838"}
0005432262560	8DBC29	9526 175015	ZULFIYA FROLOVA	{"email": "z.frolova-101976@postgrespro.ru", "phone": "+70010523594"}
0005432262561	8DBC29	8425 814397	RAMIL FOMIN	{"email": "ramil_fomin_1975@postgrespro.ru", "phone": "+70212517012"}
0005432262562	04B67C	2331 611746	ILYAS MATVEEV	{"phone": "+70650448369"}
0005432262563	C0BE74	1849 810445	EVGENIY VLASOV	{"phone": "+70868968638"}
0005432262564	7638C2	4871 008443	VIKTORIYA ZAKHAROVA	{"email": "zakharova_viktoriya-1969@postgrespro.ru", "phone": "+70850315466"}
0005432262565	734B51	6047 674395	ALEKSEY MIRONOV	{"email": "a-mironov.1967@postgrespro.ru", "phone": "+70878654282"}
0005432262566	DA4D12	5380 711163	NADEZHDA TARASOVA	{"email": "nadezhdatarasova-27081964@postgrespro.ru", "phone": "+70223001431"}
0005432262567	3D40C2	0877 692696	KONSTANTIN AFANASEV	{"email": "k-afanasev_1984@postgrespro.ru", "phone": "+70080165736"}
0005432262568	3D40C2	7752 691020	ALEKSANDR MELNIKOV	{"email": "a-melnikov031968@postgrespro.ru", "phone": "+70151940747"}
0005432262569	A06042	2439 321424	EGOR NOVIKOV	{"email": "novikov.egor_101979@postgrespro.ru", "phone": "+70632067765"}
0005432262570	A06042	5176 213427	TATYANA EGOROVA	{"phone": "+70307680966"}
0005432262571	8ACAD3	5372 527875	RAISA PETROVA	{"phone": "+70327455921"}
0005432262572	C74FED	6726 219502	ALEKSEY NOVIKOV	{"email": "novikova1969@postgrespro.ru", "phone": "+70223649623"}
0005432262573	0BAFD0	4013 973101	MARGARITA VASILEVA	{"phone": "+70448543964"}
0005432262574	0206F0	1330 563993	NIKOLAY POPOV	{"email": "nikolay-popov.01081976@postgrespro.ru", "phone": "+70192329739"}
0005432262575	0D4C57	8015 127762	ALEKSANDRA ZAKHAROVA	{"email": "aleksandra_zakharova1963@postgrespro.ru", "phone": "+70001786147"}
0005432262576	BC6A3F	2342 782882	VIKTOR KUDRYASHOV	{"phone": "+70646925870"}
0005432262577	BC6A3F	6553 558685	SNEZHANA OSIPOVA	{"phone": "+70471071850"}
0005432262578	DE94CD	2630 979185	VYACHESLAV KUZMIN	{"email": "kuzmin.vyacheslav.121973@postgrespro.ru", "phone": "+70839665966"}
0005432262579	4A1BEF	7623 596365	ANATOLIY ANDREEV	{"phone": "+70124198544"}
0005432262580	B262A6	6282 018745	MARSEL EGOROV	{"phone": "+70057080461"}
0005432262581	0161ED	7744 535348	ANDREY ANTONOV	{"phone": "+70330308177"}
0005432262582	0161ED	2378 906368	DANIIL STEPANOV	{"email": "daniil-stepanov27031983@postgrespro.ru", "phone": "+70008687361"}
0005432262583	AD4FCE	3638 839415	ANASTASIYA MATVEEVA	{"phone": "+70050055827"}
0005432262584	C8A721	2283 380182	EVGENIY MOROZOV	{"phone": "+70799213429"}
0005432262585	7C854D	8377 037944	GALINA SOKOLOVA	{"phone": "+70656138993"}
0005432262586	1AB369	0245 365579	MIKHAIL FOMIN	{"email": "mfomin.1974@postgrespro.ru", "phone": "+70788059140"}
0005432262587	0D08DC	1102 830671	DIANA TROFIMOVA	{"email": "trofimova_d_1977@postgrespro.ru", "phone": "+70539788414"}
0005432262588	9BA106	9236 862161	ANATOLIY BONDARENKO	{"phone": "+70831811339"}
0005432262589	2AE00D	0963 431056	DMITRIY IVANOV	{"email": "ivanovdmitriy-02011973@postgrespro.ru", "phone": "+70286940580"}
0005432262590	2AE00D	1372 464223	MARIYA DMITRIEVA	{"phone": "+70812077125"}
0005432262591	7BE2E4	2230 850040	ROMAN ISAEV	{"phone": "+70326847016"}
0005432262592	7BE2E4	5328 549880	TAMARA MELNIKOVA	{"email": "t_melnikova111977@postgrespro.ru", "phone": "+70793817653"}
0005432262593	ABC5E7	1920 106279	DANIIL PETROV	{"email": "petrov-d_1975@postgrespro.ru", "phone": "+70323612825"}
0005432262594	ABC5E7	4302 521178	LYUDMILA YUDINA	{"email": "lyudmila-yudina091973@postgrespro.ru", "phone": "+70983614568"}
0005432262595	B05C56	4982 505202	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir_26061970@postgrespro.ru", "phone": "+70969730494"}
0005432262596	211EF0	1497 118190	ALEKSEY FROLOV	{"email": "frolov-aleksey-1973@postgrespro.ru", "phone": "+70201526927"}
0005432262597	A1F019	2747 438821	VALENTINA ANDREEVA	{"phone": "+70102515557"}
0005432262598	19184E	3353 896267	NAILYA KOVALEVA	{"phone": "+70746726753"}
0005432262599	0C5215	9728 643107	ANATOLIY KOZLOV	{"email": "anatoliykozlov-29071975@postgrespro.ru", "phone": "+70286952174"}
0005432262600	50FB48	6946 237390	NIKOLAY STEPANOV	{"email": "nikolay.stepanov-091965@postgrespro.ru", "phone": "+70106964406"}
0005432262601	50FB48	9428 179830	KSENIYA GERASIMOVA	{"email": "gerasimova.k-121973@postgrespro.ru", "phone": "+70121519755"}
0005432262602	23C45A	3118 643056	LILIYA ALEKSEEVA	{"phone": "+70942318130"}
0005432262603	23C45A	2123 496116	TAISIYA BARANOVA	{"email": "taisiyabaranova08061985@postgrespro.ru", "phone": "+70064945819"}
0005432262604	3FBFD0	7296 138154	VITALIY EGOROV	{"phone": "+70845274573"}
0005432262605	DCA5AA	7399 393270	NIKOLAY ANDREEV	{"email": "andreevnikolay_01101971@postgrespro.ru", "phone": "+70354087603"}
0005432262606	DCA5AA	2972 164943	YURIY BONDARENKO	{"phone": "+70372455500"}
0005432262607	057103	2299 535938	NATALYA LUKYANOVA	{"email": "lukyanova_n_1974@postgrespro.ru", "phone": "+70651613950"}
0005432262608	52FC25	8714 576408	ALEKSEY TARASOV	{"email": "tarasova12121973@postgrespro.ru", "phone": "+70452763099"}
0005432262609	52FC25	7861 756438	ALEKSANDR GAVRILOV	{"email": "gavrilov_a-21091965@postgrespro.ru", "phone": "+70931957320"}
0005432262610	52FC25	6717 674966	TAMARA GUSEVA	{"email": "guseva-tamara.1963@postgrespro.ru", "phone": "+70807433911"}
0005432262611	4B1663	1252 017682	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-031977@postgrespro.ru", "phone": "+70238687559"}
0005432262612	EB6F64	6599 408263	VALENTINA POPOVA	{"phone": "+70735425349"}
0005432262613	CC877F	6073 126375	OLGA KONOVALOVA	{"email": "konovalova-olga-1977@postgrespro.ru", "phone": "+70257669115"}
0005432262614	C862DC	0388 957909	ALEKSANDR KRASNOV	{"phone": "+70418546476"}
0005432262615	041AD8	5792 994519	KSENIYA NESTEROVA	{"email": "nesterova.k.071963@postgrespro.ru", "phone": "+70660530032"}
0005432262616	041AD8	9685 766921	YURIY TIMOFEEV	{"email": "timofeev-yuriy_111973@postgrespro.ru", "phone": "+70461666934"}
0005432262617	26DF59	4940 375567	ELENA ANTONOVA	{"phone": "+70484795412"}
0005432262618	5CF71E	3045 687623	VADIM ROMANOV	{"phone": "+70182548349"}
0005432262619	5CF71E	7249 033905	VYACHESLAV POPOV	{"email": "popov_vyacheslav1971@postgrespro.ru", "phone": "+70491266739"}
0005432262620	D86C16	3035 560571	VERA ZHUKOVA	{"phone": "+70560364184"}
0005432262621	5730D6	8288 503827	NATALIYA NAZAROVA	{"phone": "+70580730287"}
0005432262622	8F5B43	6163 999718	IVAN GERASIMOV	{"phone": "+70357164805"}
0005432262623	8DB8EE	2530 000337	VLADIMIR KUZMIN	{"phone": "+70830857005"}
0005432262624	4C514E	5187 217495	ALEKSEY MARTYNOV	{"email": "martynov.a_09071970@postgrespro.ru", "phone": "+70655161647"}
0005432262625	4C514E	8639 989548	LILIYA EFIMOVA	{"email": "efimova.liliya_1966@postgrespro.ru", "phone": "+70299234734"}
0005432262626	4C514E	6248 758287	ALEKSEY OSIPOV	{"email": "osipov-a-28101975@postgrespro.ru", "phone": "+70282043682"}
0005432262627	BD7E78	0665 064957	LYUDMILA EFIMOVA	{"email": "l.efimova-1965@postgrespro.ru", "phone": "+70304217653"}
0005432262628	48D822	1103 796320	KONSTANTIN POPOV	{"email": "konstantin-popov_14081968@postgrespro.ru", "phone": "+70174327180"}
0005432262629	FCF4AF	8452 795016	SVETLANA VOLKOVA	{"phone": "+70427748505"}
0005432262630	CEEB0E	6094 760054	NIKOLAY BELOV	{"email": "nikolaybelov_071972@postgrespro.ru", "phone": "+70854444844"}
0005432262631	AE4758	6511 346456	VIKTOR MATVEEV	{"email": "matveev_viktor_081979@postgrespro.ru", "phone": "+70341343297"}
0005432262632	B4A920	0746 725478	OLEG FROLOV	{"email": "frolov.oleg09091973@postgrespro.ru", "phone": "+70111892424"}
0005432262633	B4A920	3920 899408	IRINA ALEKSANDROVA	{"phone": "+70249975554"}
0005432262634	877594	5572 331847	OLGA ALEKSEEVA	{"phone": "+70675536119"}
0005432262635	596167	9410 847053	ALEKSANDRA BOGDANOVA	{"phone": "+70029525908"}
0005432262636	596167	1644 593906	ALEVTINA ZHUKOVA	{"email": "zhukova-alevtina.091984@postgrespro.ru", "phone": "+70244598622"}
0005432262637	1446BF	1093 340194	ALEKSANDR VASILEV	{"phone": "+70160670877"}
0005432262638	60FBBA	9952 504945	ANNA POPOVA	{"email": "popova.anna-111967@postgrespro.ru", "phone": "+70237932141"}
0005432262639	B3F0BD	7855 774785	VALENTINA SEMENOVA	{"email": "semenovav.30011974@postgrespro.ru", "phone": "+70924511201"}
0005432262640	5BF99B	2226 986103	NINA KRASNOVA	{"phone": "+70997022673"}
0005432262641	DFAEC0	2871 308872	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov1961@postgrespro.ru", "phone": "+70042477732"}
0005432262642	A49216	7089 986984	SERGEY GAVRILOV	{"phone": "+70559047016"}
0005432262643	214CA2	3781 913723	DMITRIY CHERNOV	{"phone": "+70324950406"}
0005432262644	214CA2	1537 092737	DMITRIY GORBUNOV	{"phone": "+70080368894"}
0005432262645	DE4479	4596 298757	VALENTINA YUDINA	{"email": "v.yudina_05121971@postgrespro.ru", "phone": "+70086295228"}
0005432262646	DA4251	0364 421046	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1969@postgrespro.ru", "phone": "+70382331240"}
0005432262647	DA4251	3099 447735	ALEKSANDR SMIRNOV	{"email": "a.smirnov.1968@postgrespro.ru", "phone": "+70989982997"}
0005432262648	5D23A2	5846 199754	FATIMA KOROLEVA	{"phone": "+70163860136"}
0005432262649	C809F6	9502 072939	ELENA LOGINOVA	{"phone": "+70398535463"}
0005432262650	C809F6	5403 262065	NATALYA GAVRILOVA	{"email": "gavrilova.n-1964@postgrespro.ru", "phone": "+70859140846"}
0005432262651	8FA9D6	9632 444916	NATALYA YUDINA	{"phone": "+70402606694"}
0005432262652	A15470	5892 312974	NIKOLAY TIKHONOV	{"phone": "+70109477645"}
0005432262653	E879DF	0477 085414	MIKHAIL DENISOV	{"email": "denisov-mikhail_071973@postgrespro.ru", "phone": "+70799886616"}
0005432262654	ECAF25	6599 025617	NIKOLAY ABRAMOV	{"email": "n_abramov031986@postgrespro.ru", "phone": "+70294815873"}
0005432262656	896DBD	3149 350974	MARIYA TITOVA	{"email": "titova_mariya.071972@postgrespro.ru", "phone": "+70868484268"}
0005432262657	8494A1	5964 284410	MARIYA DENISOVA	{"email": "denisova_mariya091970@postgrespro.ru", "phone": "+70955491434"}
0005432262658	9787B1	2417 380578	GULNARA GUSEVA	{"email": "gulnara.guseva-11031966@postgrespro.ru", "phone": "+70069112686"}
0005432262659	95E2E4	5197 258256	VALENTINA IVANOVA	{"phone": "+70667186132"}
0005432262660	53D778	2162 205193	YULIYA NESTEROVA	{"phone": "+70814309245"}
0005432262661	833A06	4590 794716	ANATOLIY SAVELEV	{"email": "a_savelev1971@postgrespro.ru", "phone": "+70591429678"}
0005432262662	6A9657	6563 792654	ALEKSANDR KULIKOV	{"phone": "+70796581592"}
0005432262663	2D83AF	5641 453684	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev.1968@postgrespro.ru", "phone": "+70258435499"}
0005432262664	237371	3316 170916	ALEKSEY DAVYDOV	{"phone": "+70855604870"}
0005432262665	237371	4652 879460	VLADIMIR SOROKIN	{"email": "sorokin.v.1978@postgrespro.ru", "phone": "+70705578436"}
0005432262666	CEE967	8641 125058	ELENA KUDRYASHOVA	{"phone": "+70754548982"}
0005432262667	95BE5C	4753 962777	NATALYA ILINA	{"email": "natalya_ilina051976@postgrespro.ru", "phone": "+70309191056"}
0005432262668	95BE5C	4083 623687	KRISTINA MIRONOVA	{"email": "mironovakristina041969@postgrespro.ru", "phone": "+70484746427"}
0005432262669	2E84CD	9146 274255	DENIS KUZNECOV	{"email": "denis_kuznecov1982@postgrespro.ru", "phone": "+70607296825"}
0005432262670	68A3AD	7369 743687	ANATOLIY KONOVALOV	{"email": "anatoliykonovalov12101971@postgrespro.ru", "phone": "+70338760512"}
0005432262671	8F5EA8	1061 290413	MARIYA KONOVALOVA	{"email": "konovalova.m_16111970@postgrespro.ru", "phone": "+70371949080"}
0005432262672	6D9A22	1105 122443	LYUBOV ZHURAVLEVA	{"phone": "+70386893703"}
0005432262673	FDFABE	5219 240485	MARIYA KULIKOVA	{"phone": "+70814977714"}
0005432262674	FDFABE	7676 782090	VLADIMIR PAVLOV	{"email": "pavlov-v-111962@postgrespro.ru", "phone": "+70777181997"}
0005432262675	D8D361	1652 898498	SVETLANA MELNIKOVA	{"email": "s-melnikova-05061976@postgrespro.ru", "phone": "+70497420038"}
0005432262676	D8D361	4970 905548	LIDIYA VOLKOVA	{"email": "volkova-lidiya.09101975@postgrespro.ru", "phone": "+70131015044"}
0005432262677	9EAA2D	0152 053846	EKATERINA ISAEVA	{"email": "isaeva-ekaterina_1978@postgrespro.ru", "phone": "+70889915665"}
0005432262678	AFC1DD	2119 770634	TATYANA POTAPOVA	{"email": "tpotapova-03111960@postgrespro.ru", "phone": "+70270905349"}
0005432262679	6E3F2B	1415 338471	GALINA BELYAEVA	{"email": "belyaeva-galina-021969@postgrespro.ru", "phone": "+70446552870"}
0005432262680	6E3F2B	8626 317446	EKATERINA BELYAEVA	{"email": "belyaeva_ekaterina_08041979@postgrespro.ru", "phone": "+70327129400"}
0005432262681	6E3F2B	8136 137340	RUSLAN KOROLEV	{"email": "r.korolev.1972@postgrespro.ru", "phone": "+70995620489"}
0005432262682	4764C7	6972 058131	VITALIY DAVYDOV	{"email": "vitaliy-davydov.091954@postgrespro.ru", "phone": "+70240927882"}
0005432262683	09E956	2785 983949	PAVEL SHEVCHENKO	{"email": "shevchenko-p23051967@postgrespro.ru", "phone": "+70080906389"}
0005432262684	09E956	0548 496674	LYUBOV KUZNECOVA	{"phone": "+70796007204"}
0005432262685	C07080	4079 338905	ZOYA ALEKSANDROVA	{"phone": "+70812225640"}
0005432262686	0DF4EA	9396 502230	SERGEY OSIPOV	{"phone": "+70721020032"}
0005432262687	BA02C4	2682 444847	SVETLANA STEPANOVA	{"phone": "+70385196762"}
0005432262688	56E8CB	2610 915657	TAMARA KUZMINA	{"phone": "+70497745485"}
0005432262689	CF4376	5623 907146	EVGENIYA ALEKSANDROVA	{"email": "aleksandrovae.24041965@postgrespro.ru", "phone": "+70598866134"}
0005432262690	CF4376	1640 261343	BORIS MAKAROV	{"email": "boris_makarov_1970@postgrespro.ru", "phone": "+70101502161"}
0005432262691	A95C7F	3030 816286	NIKOLAY ANTONOV	{"phone": "+70252435539"}
0005432262692	369F9B	7200 338348	IGOR POPOV	{"email": "popov_i.13081982@postgrespro.ru", "phone": "+70564712254"}
0005432262693	76ADD9	9828 123875	LYUBOV SMIRNOVA	{"email": "l.smirnova18021980@postgrespro.ru", "phone": "+70139086999"}
0005432262694	3F3665	1128 914366	IRINA MIKHAYLOVA	{"email": "mikhaylova.irina_1977@postgrespro.ru", "phone": "+70192495597"}
0005432262695	07257F	7984 598972	NIKITA PETROV	{"email": "nikita_petrov.29051967@postgrespro.ru", "phone": "+70613327000"}
0005432262696	07257F	0519 774711	LIDIYA SEMENOVA	{"phone": "+70665157855"}
0005432262697	7E159C	4032 022470	NIKOLAY MAKAROV	{"email": "nikolay.makarov-06051977@postgrespro.ru", "phone": "+70164128093"}
0005432262698	681729	7379 956382	OKSANA ALEKSEEVA	{"email": "o-alekseeva_1987@postgrespro.ru", "phone": "+70932659422"}
0005432262699	681729	3178 110542	MIKHAIL POPOV	{"phone": "+70706214911"}
0005432262700	681729	9466 755947	ELENA MIRONOVA	{"email": "mironova_elena-20031977@postgrespro.ru", "phone": "+70522814848"}
0005432262701	644AC7	6658 509200	NINA KRASNOVA	{"phone": "+70650088281"}
0005432262702	644AC7	7305 014867	ELENA AFANASEVA	{"email": "afanaseva-elena-29081976@postgrespro.ru", "phone": "+70738203472"}
0005432262703	3D7A74	8788 898452	PAVEL SOLOVEV	{"email": "solovev.p_1966@postgrespro.ru", "phone": "+70636564469"}
0005432262704	3D7A74	2583 341368	SVETLANA MAKSIMOVA	{"email": "s_maksimova-24041971@postgrespro.ru", "phone": "+70614282419"}
0005432262705	A433FE	3768 391364	DARYA KUZMINA	{"email": "d_kuzmina-111981@postgrespro.ru", "phone": "+70518839616"}
0005432262706	3E4C08	3814 928476	SVETLANA KUZNECOVA	{"email": "skuznecova1974@postgrespro.ru", "phone": "+70673024327"}
0005432262707	3E4C08	2080 356360	NADEZHDA AFANASEVA	{"email": "afanasevan-25121957@postgrespro.ru", "phone": "+70979379629"}
0005432262708	3CBE23	9312 432232	ALEKSEY ZHUKOV	{"phone": "+70543767467"}
0005432262709	3F893D	4934 901309	SERGEY SIDOROV	{"phone": "+70961298338"}
0005432262710	3F893D	9801 398171	SVETLANA ZHUKOVA	{"email": "zhukova.s121976@postgrespro.ru", "phone": "+70652298215"}
0005432262711	3F893D	3048 294368	EVGENIY SOROKIN	{"email": "e_sorokin.08121968@postgrespro.ru", "phone": "+70780638287"}
0005432262712	3F893D	1583 584296	NADEZHDA ANDREEVA	{"email": "n-andreeva1969@postgrespro.ru", "phone": "+70584033316"}
0005432262713	A86B3F	5716 104033	ANASTASIYA ISAEVA	{"phone": "+70077144562"}
0005432262714	4A4B31	6148 782781	ALEKSANDR SAVELEV	{"phone": "+70023496318"}
0005432262715	4A4B31	1993 963922	SERGEY GRIGOREV	{"email": "grigorev.s.1976@postgrespro.ru", "phone": "+70479731493"}
0005432262716	4CDC9D	9017 382001	NATALIYA PETROVA	{"email": "petrova.nataliya20121968@postgrespro.ru", "phone": "+70190785616"}
0005432262717	53EA6D	5006 792051	VALENTINA NAZAROVA	{"phone": "+70592301368"}
0005432262718	5748C3	0070 382662	IRINA DMITRIEVA	{"email": "dmitrieva.irina08091972@postgrespro.ru", "phone": "+70226852776"}
0005432262719	B16549	4841 475523	TATYANA FROLOVA	{"email": "t-frolova.17061974@postgrespro.ru", "phone": "+70943315928"}
0005432262720	2D5B5F	6868 565508	IRINA GERASIMOVA	{"email": "irina_gerasimova-061975@postgrespro.ru", "phone": "+70726735362"}
0005432262721	608E75	4651 628795	SVETLANA KUDRYASHOVA	{"phone": "+70146598847"}
0005432262722	8E94DF	3307 510236	MARGARITA SCHERBAKOVA	{"phone": "+70473104138"}
0005432262723	9ECF51	2853 634476	IGOR EGOROV	{"phone": "+70235814951"}
0005432262724	C40AD6	4698 561740	NIKITA PAVLOV	{"email": "n.pavlov_1973@postgrespro.ru", "phone": "+70093518581"}
0005432262725	9B5D3F	9328 994678	ELENA BORISOVA	{"phone": "+70345406301"}
0005432262726	BADBFA	9629 203205	ANTONIDA VASILEVA	{"phone": "+70248106935"}
0005432262727	3FCB75	5650 869664	MAKSIM VASILEV	{"phone": "+70816740973"}
0005432262728	911B4C	5759 557878	NINA ZAYCEVA	{"phone": "+70693861882"}
0005432262729	911B4C	4450 964091	IRINA SOLOVEVA	{"phone": "+70946341704"}
0005432262730	FF4C4C	3583 063101	DMITRIY KUZMIN	{"email": "d-kuzmin.071961@postgrespro.ru", "phone": "+70494190939"}
0005432262731	4E8E07	0175 910351	NIKOLAY MARTYNOV	{"email": "nmartynov.14021967@postgrespro.ru", "phone": "+70774893388"}
0005432262732	4E8E07	4746 197021	OLGA MASLOVA	{"email": "olga_maslova_1968@postgrespro.ru", "phone": "+70833498950"}
0005432262733	837F13	5686 058502	NATALIYA EFIMOVA	{"phone": "+70049320636"}
0005432262734	837F13	4715 674123	EVGENIY FEDOTOV	{"email": "fedotov_evgeniy-08091988@postgrespro.ru", "phone": "+70517257080"}
0005432262735	F3C787	4507 106332	ANDREY SCHERBAKOV	{"phone": "+70080711388"}
0005432262736	452738	5236 701829	YANA MOISEEVA	{"phone": "+70008277503"}
0005432262737	3EC67A	4084 582251	ANTONIDA MAKAROVA	{"email": "makarova-a-1972@postgrespro.ru", "phone": "+70655445194"}
0005432262738	3EC67A	9675 953149	SERGEY PAVLOV	{"email": "s_pavlov_1970@postgrespro.ru", "phone": "+70793466522"}
0005432262739	3AD61D	8048 183304	ALEKSEY KONOVALOV	{"phone": "+70773567804"}
0005432262740	748B3C	6481 919242	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay_1979@postgrespro.ru", "phone": "+70350285838"}
0005432262741	748B3C	5491 158231	ALEKSANDR KRASNOV	{"email": "krasnov.a_111967@postgrespro.ru", "phone": "+70275347672"}
0005432262742	748B3C	6565 000359	YULIYA FEDOROVA	{"email": "yfedorova.091985@postgrespro.ru", "phone": "+70357491079"}
0005432262743	250A09	7757 369481	NIKOLAY VOROBEV	{"phone": "+70829454574"}
0005432262744	9C2E66	9234 281827	VALENTINA CHERNOVA	{"phone": "+70533864831"}
0005432262745	56C548	8115 042422	OKSANA ORLOVA	{"email": "oksana.orlova_061979@postgrespro.ru", "phone": "+70375694709"}
0005432262746	16C16F	7319 852834	VIKTORIYA IVANOVA	{"phone": "+70283432904"}
0005432262747	B37433	9449 390051	VALENTIN MOROZOV	{"phone": "+70094384995"}
0005432262748	1143EC	8348 936273	IGOR ZAKHAROV	{"phone": "+70849111740"}
0005432262749	A6B7E1	1990 934049	ALEKSANDR TIKHONOV	{"email": "a_tikhonov.02111975@postgrespro.ru", "phone": "+70057204237"}
0005432262750	A6B7E1	1543 401933	LYUBOV MATVEEVA	{"phone": "+70491931279"}
0005432262751	05FD43	5908 675956	ALEKSEY NIKOLAEV	{"email": "nikolaev.aleksey_29071982@postgrespro.ru", "phone": "+70706187390"}
0005432262752	203F63	6057 830268	FATIMA POTAPOVA	{"email": "potapovaf_091971@postgrespro.ru", "phone": "+70633113486"}
0005432262753	80D06B	8497 275684	GENNADIY GRIGOREV	{"email": "gennadiy.grigorev.18061985@postgrespro.ru", "phone": "+70689136423"}
0005432262754	F09428	3328 834387	MARINA KONDRATEVA	{"email": "marinakondrateva_071975@postgrespro.ru", "phone": "+70229749583"}
0005432262755	F09428	1930 388669	EKATERINA MEDVEDEVA	{"email": "medvedeva-e-1970@postgrespro.ru", "phone": "+70531824824"}
0005432262756	6B7701	0966 793978	MARIYA FILATOVA	{"email": "mfilatova-091973@postgrespro.ru", "phone": "+70468315211"}
0005432262757	5984B8	8102 486021	MARIYA NOVIKOVA	{"phone": "+70291167232"}
0005432262758	5984B8	7760 313862	MARIYA IVANOVA	{"email": "ivanova_m.101973@postgrespro.ru", "phone": "+70870826536"}
0005432262759	46450A	5918 122423	SVETLANA DMITRIEVA	{"phone": "+70109607738"}
0005432262760	453528	1700 615034	YAKOV POPOV	{"email": "ypopov_18091971@postgrespro.ru", "phone": "+70162981882"}
0005432262761	6CEF8F	0508 188885	KONSTANTIN KAZAKOV	{"email": "k.kazakov071971@postgrespro.ru", "phone": "+70723085679"}
0005432262762	6CEF8F	9810 219867	OLGA KISELEVA	{"phone": "+70320267495"}
0005432262763	6CEF8F	0305 794327	ALEKSANDRA PAVLOVA	{"phone": "+70968516099"}
0005432262764	13C2F5	0029 491469	ALEKSEY NAZAROV	{"email": "nazarova.1967@postgrespro.ru", "phone": "+70492643968"}
0005432262765	DD768E	2993 117648	VERA ERMAKOVA	{"phone": "+70264194653"}
0005432262766	3A1634	9797 409184	ALENA BELOVA	{"email": "belova-alena_031963@postgrespro.ru", "phone": "+70694569339"}
0005432262767	3A1634	7739 833339	VLADIMIR AFANASEV	{"phone": "+70768448397"}
0005432262768	4CEB0E	3631 116855	BORIS KISELEV	{"email": "b.kiselev.19051970@postgrespro.ru", "phone": "+70932501144"}
0005432262769	4CEB0E	3936 430333	EKATERINA SMIRNOVA	{"phone": "+70511497783"}
0005432262770	75DBB8	1243 429684	ANATOLIY FEDOTOV	{"phone": "+70871858754"}
0005432262771	5100F5	3016 791633	ALEKSEY CHERNOV	{"email": "a-chernov_06021961@postgrespro.ru", "phone": "+70936040403"}
0005432262772	B8F3A4	7928 091943	TATYANA SOKOLOVA	{"phone": "+70355551135"}
0005432262773	8002D9	8821 589956	VALENTINA KUZNECOVA	{"phone": "+70982500648"}
0005432262774	44097B	4243 898810	EKATERINA VASILEVA	{"phone": "+70738178112"}
0005432262775	4C83AA	1105 694430	ALEKSANDR GORBUNOV	{"phone": "+70728636208"}
0005432262776	AC5F10	9142 655296	MAKSIM ILIN	{"email": "ilin-maksim-021982@postgrespro.ru", "phone": "+70102321590"}
0005432262777	AC5F10	8755 442482	SERGEY SHEVCHENKO	{"phone": "+70571510515"}
0005432262778	D4E608	1859 979123	IRINA ZAKHAROVA	{"email": "zakharovairina.1983@postgrespro.ru", "phone": "+70655128229"}
0005432262779	C1E539	4702 693375	YURIY IVANOV	{"phone": "+70038316321"}
0005432262780	82172C	1478 421142	YURIY VOLKOV	{"email": "volkovy.1979@postgrespro.ru", "phone": "+70100621523"}
0005432262781	0D9199	0769 309739	DMITRIY NIKITIN	{"email": "dmitriy-nikitin.14011967@postgrespro.ru", "phone": "+70614283381"}
0005432262782	0D9199	2038 598127	EKATERINA IVANOVA	{"phone": "+70425652854"}
0005432262783	B50400	7433 979815	VLADISLAV ORLOV	{"email": "vladislavorlov-1976@postgrespro.ru", "phone": "+70403044765"}
0005432262784	97168D	5544 229165	ANASTASIYA MATVEEVA	{"email": "matveeva-a.011975@postgrespro.ru", "phone": "+70784815520"}
0005432262785	97168D	2635 282855	VALENTINA KUZNECOVA	{"email": "vkuznecova.1978@postgrespro.ru", "phone": "+70531257794"}
0005432262786	7A7A23	1093 809943	EKATERINA MAKAROVA	{"phone": "+70830415693"}
0005432262787	7A7A23	2280 034548	MILENA ANTONOVA	{"phone": "+70074642118"}
0005432262788	72A925	7688 901199	ELENA GRISHINA	{"phone": "+70959794128"}
0005432262789	D323FB	9077 254216	VLADIMIR ORLOV	{"email": "orlov_v.051976@postgrespro.ru", "phone": "+70688539687"}
0005432262790	4EAB48	7976 418403	VALENTIN FILIPPOV	{"phone": "+70953978730"}
0005432262791	CCFDFD	5353 103913	VALENTINA ISAEVA	{"email": "isaeva.v1962@postgrespro.ru", "phone": "+70455920928"}
0005432262792	42609E	5356 874764	MIKHAIL NOVIKOV	{"email": "novikov.m-1974@postgrespro.ru", "phone": "+70215626402"}
0005432262793	4ECED0	9501 436251	ALEKSEY KAZAKOV	{"phone": "+70901427010"}
0005432262794	4ECED0	4050 680375	NINA ALEKSEEVA	{"email": "n-alekseeva_26121975@postgrespro.ru", "phone": "+70082890803"}
0005432262795	C8D4DD	1276 025932	OLGA MAKSIMOVA	{"email": "maksimova-o10091966@postgrespro.ru", "phone": "+70664757338"}
0005432262796	C8DA3A	3226 773590	VIKTOR STEPANOV	{"phone": "+70028976864"}
0005432262797	C8DA3A	1135 749368	TATYANA ARKHIPOVA	{"phone": "+70715954216"}
0005432262798	D58A87	4192 112139	NIKOLAY NAZAROV	{"email": "nikolay-nazarov_1969@postgrespro.ru", "phone": "+70299532000"}
0005432262799	8C5125	3060 584637	TATYANA KARPOVA	{"phone": "+70232114841"}
0005432262800	8C5125	4631 169180	YURIY MOISEEV	{"email": "yuriy_moiseev.28071973@postgrespro.ru", "phone": "+70240357467"}
0005432262801	C8D5AA	8824 446777	VLADISLAV YAKOVLEV	{"phone": "+70068368872"}
0005432262802	F9E59A	2617 612473	OKSANA VOLKOVA	{"phone": "+70560433106"}
0005432262803	F97347	3075 508061	FARIDA IVANOVA	{"phone": "+70926879218"}
0005432262804	349814	5919 663173	VLADIMIR SHEVCHENKO	{"email": "vshevchenko1978@postgrespro.ru", "phone": "+70836281075"}
0005432262805	349814	8021 738634	ILYA ANDREEV	{"email": "ilya.andreev.1972@postgrespro.ru", "phone": "+70274910435"}
0005432262806	70AD00	7806 994301	INESSA TIMOFEEVA	{"phone": "+70408582075"}
0005432262807	DF9E96	9332 160464	IRINA NIKOLAEVA	{"email": "irina.nikolaeva1979@postgrespro.ru", "phone": "+70175992532"}
0005432262808	516681	7446 276227	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr27111973@postgrespro.ru", "phone": "+70010110319"}
0005432262809	C7D79D	9690 254178	VLADIMIR PAVLOV	{"phone": "+70466970792"}
0005432262810	7E33A3	3150 402918	ANDREY ILIN	{"phone": "+70064326809"}
0005432262811	1FE20B	7224 079417	MAKSIM MOISEEV	{"phone": "+70402526648"}
0005432262812	74EB6F	4848 081908	NATALYA KOZLOVA	{"email": "kozlova.n-1971@postgrespro.ru", "phone": "+70112406269"}
0005432262813	9CB807	2764 691122	NIKOLAY ZHURAVLEV	{"phone": "+70960030234"}
0005432262814	9CB807	2010 586731	GLEB MATVEEV	{"email": "gleb_matveev1970@postgrespro.ru", "phone": "+70289607267"}
0005432262815	08ADA9	8262 549986	ALEKSEY MAKAROV	{"email": "makarov_a-031965@postgrespro.ru", "phone": "+70548312962"}
0005432262816	08ADA9	9819 098018	MIKHAIL IVANOV	{"email": "ivanov.m.111963@postgrespro.ru", "phone": "+70391732310"}
0005432262817	08ADA9	2814 192754	ALIK NAZAROV	{"email": "a-nazarov_1966@postgrespro.ru", "phone": "+70365544676"}
0005432262818	926738	8971 092146	LYUBOV FROLOVA	{"email": "lfrolova.1974@postgrespro.ru", "phone": "+70117570852"}
0005432262819	926738	9495 484095	VIKTOR NIKOLAEV	{"phone": "+70377985866"}
0005432262820	8E146B	4075 020530	TATYANA YUDINA	{"email": "yudinatatyana1968@postgrespro.ru", "phone": "+70291018461"}
0005432262821	9F0262	0314 291738	VLADISLAV STEPANOV	{"email": "v.stepanov_041976@postgrespro.ru", "phone": "+70462382268"}
0005432262822	902065	4841 113731	VLADIMIR TARASOV	{"phone": "+70700442755"}
0005432262823	9492A5	0524 600072	MURAD MAKSIMOV	{"email": "maksimov_murad.071970@postgrespro.ru", "phone": "+70958523639"}
0005432262824	9492A5	0605 030929	EVGENIYA MATVEEVA	{"email": "evgeniya.matveeva071972@postgrespro.ru", "phone": "+70648425470"}
0005432262825	2E7922	7033 087471	OKSANA ANISIMOVA	{"phone": "+70062914254"}
0005432262826	2E7922	3433 250567	ANTONINA GRISHINA	{"phone": "+70934746181"}
0005432262827	FE8793	5856 880424	VALENTINA KAZAKOVA	{"phone": "+70663971239"}
0005432262828	FE8793	2432 853369	SERGEY KOROLEV	{"phone": "+70865444714"}
0005432262829	87F3BE	2615 944451	TATYANA KOZLOVA	{"phone": "+70608967569"}
0005432262830	046949	2621 460047	ANNA VASILEVA	{"phone": "+70872083351"}
0005432262831	E8C8D9	5833 579650	KSENIYA NIKIFOROVA	{"phone": "+70330453120"}
0005432262832	204DAF	8862 175361	DARYA KUZNECOVA	{"email": "kuznecova.d121984@postgrespro.ru", "phone": "+70025107275"}
0005432262833	204DAF	2488 966333	ANTON POPOV	{"email": "anton-popov.02011975@postgrespro.ru", "phone": "+70922049912"}
0005432262834	9B043D	3353 982668	ALEKSANDR KOROLEV	{"phone": "+70088550887"}
0005432262835	526D5F	6118 704571	ELENA ILINA	{"email": "eilina-061973@postgrespro.ru", "phone": "+70796413832"}
0005432262836	2565B3	2871 074688	ALEKSEY KULIKOV	{"phone": "+70912972997"}
0005432262837	2565B3	8567 844748	VLADA KONOVALOVA	{"email": "konovalova-v1978@postgrespro.ru", "phone": "+70787675145"}
0005432262838	5845A9	6278 859498	ANASTASIYA FOMINA	{"email": "anastasiyafomina.27111971@postgrespro.ru", "phone": "+70077911620"}
0005432262839	760DCF	1572 494971	LYUDMILA GUSEVA	{"email": "guseva_lyudmila.09091968@postgrespro.ru", "phone": "+70633452204"}
0005432262840	053DF9	1856 407261	NINA GUSEVA	{"phone": "+70775400238"}
0005432262841	5C3D54	9625 281448	EKATERINA SOROKINA	{"email": "e-sorokina031963@postgrespro.ru", "phone": "+70027009382"}
0005432262842	63F789	4570 366992	GALINA FILIPPOVA	{"phone": "+70927921092"}
0005432262843	63F789	9071 368521	NAIL NOVIKOV	{"phone": "+70197348364"}
0005432262844	21FE14	5921 811684	MIKHAIL SMIRNOV	{"phone": "+70208088121"}
0005432262845	21FE14	5098 279858	OLESYA LUKYANOVA	{"phone": "+70025669013"}
0005432262846	21FE14	6385 432309	VIKTORIYA ZHUKOVA	{"phone": "+70191171602"}
0005432262847	B30540	3916 194851	SVETLANA ZAYCEVA	{"phone": "+70872942394"}
0005432262848	B30540	5371 939909	NIKOLAY KONOVALOV	{"email": "konovalov_n.1979@postgrespro.ru", "phone": "+70521726668"}
0005432262849	910ACA	2525 973188	NATALYA SIDOROVA	{"email": "n-sidorova05091983@postgrespro.ru", "phone": "+70398350414"}
0005432262850	910ACA	2032 392149	ALEKSEY TIMOFEEV	{"phone": "+70852273422"}
0005432262851	3CF16A	9945 958109	PETR GRIGOREV	{"phone": "+70401663944"}
0005432262852	103201	6052 262696	EVGENIY SEMENOV	{"phone": "+70894476626"}
0005432262853	E59EED	9988 010282	OKSANA POTAPOVA	{"phone": "+70863101974"}
0005432262854	4275E9	2691 902895	MAKSIM ANDREEV	{"phone": "+70365752710"}
0005432262855	B9C8DD	4540 914527	IVAN NOVIKOV	{"phone": "+70912899715"}
0005432262856	118FE9	6305 934249	NIKOLAY AFANASEV	{"email": "nikolayafanasev.08101973@postgrespro.ru", "phone": "+70752080659"}
0005432262857	118FE9	3587 666546	EVGENIY POPOV	{"phone": "+70758260647"}
0005432262858	118FE9	0243 269356	SERGEY DMITRIEV	{"email": "dmitriev.s-041973@postgrespro.ru", "phone": "+70330269490"}
0005432262859	118FE9	1799 437122	TAISIYA SAVELEVA	{"phone": "+70497527396"}
0005432262860	32D1E2	1800 534769	VYACHESLAV VASILEV	{"phone": "+70506881231"}
0005432262861	A830FA	0442 815050	ANATOLIY ISAEV	{"phone": "+70322689973"}
0005432262862	6F57AD	9881 306021	ANATOLIY GRIGOREV	{"phone": "+70128988667"}
0005432262863	B088CE	4130 628257	GENNADIY VOLKOV	{"phone": "+70447255579"}
0005432262864	389AC9	7359 777173	SERGEY MELNIKOV	{"email": "melnikov-sergey.15011982@postgrespro.ru", "phone": "+70731794329"}
0005432262865	9A465C	7433 839379	DMITRIY MAKSIMOV	{"phone": "+70113563895"}
0005432262866	9A465C	3947 931810	MIKHAIL BORISOV	{"email": "borisov.mikhail-121974@postgrespro.ru", "phone": "+70759161558"}
0005432262867	1C2706	7266 712497	LIDIYA NIKIFOROVA	{"email": "lidiya.nikiforova061980@postgrespro.ru", "phone": "+70815079085"}
0005432262868	1C2706	8442 154191	IVAN POPOV	{"email": "popov-i_1976@postgrespro.ru", "phone": "+70508220434"}
0005432262869	1C5FA5	6785 644943	GUZEL SERGEEVA	{"phone": "+70811638388"}
0005432262870	8ED318	5033 997404	ANDREY ALEKSANDROV	{"email": "aleksandrov_andrey_25081979@postgrespro.ru", "phone": "+70081663921"}
0005432262871	A5D69E	3610 848695	OLGA KRASNOVA	{"email": "o-krasnova.081971@postgrespro.ru", "phone": "+70743462224"}
0005432262872	A5D69E	8870 202281	EGOR VOLKOV	{"phone": "+70692038896"}
0005432262873	C072F0	3825 108110	YULIYA ZAKHAROVA	{"email": "yuliya_zakharova_1974@postgrespro.ru", "phone": "+70659984071"}
0005432262874	DEAA95	0291 301859	VERONIKA MAKAROVA	{"phone": "+70672736083"}
0005432262875	E30C70	7307 840737	DMITRIY GERASIMOV	{"email": "gerasimov_d-121982@postgrespro.ru", "phone": "+70791923831"}
0005432262876	DAB606	1406 520848	LYUDMILA KUZNECOVA	{"phone": "+70151164524"}
0005432262877	B2F83C	4453 705565	SERGEY PAVLOV	{"phone": "+70504585681"}
0005432262878	B926D6	9743 197153	VIKTORIYA KOMAROVA	{"email": "komarovav15011967@postgrespro.ru", "phone": "+70597774552"}
0005432262879	57DB64	9253 028403	VARVARA VASILEVA	{"email": "vasileva.varvara.07031967@postgrespro.ru", "phone": "+70525279944"}
0005432262880	A51C6A	8029 661184	NIKITA FEDOTOV	{"email": "fedotov_nikita1964@postgrespro.ru", "phone": "+70687951012"}
0005432262881	09FFBA	3323 562719	SERGEY KRASNOV	{"phone": "+70177346234"}
0005432262882	001892	7184 490516	BORIS SIDOROV	{"phone": "+70467724366"}
0005432262883	E19A73	9947 635355	EKATERINA ISAEVA	{"email": "ekaterina-isaeva_111983@postgrespro.ru", "phone": "+70521499805"}
0005432262884	A5EC8C	3722 238309	RITA KUZNECOVA	{"email": "rita.kuznecova-1977@postgrespro.ru", "phone": "+70598770383"}
0005432262885	6BC744	4939 376616	VLADIMIR MAKAROV	{"email": "makarov-vladimir051970@postgrespro.ru", "phone": "+70777530974"}
0005432262886	2E2ED0	4097 303087	ELENA BOGDANOVA	{"email": "e_bogdanova_13121965@postgrespro.ru", "phone": "+70322906644"}
0005432262887	2E2ED0	0139 440354	LIDIYA KUZNECOVA	{"email": "lidiya-kuznecova.1962@postgrespro.ru", "phone": "+70686396617"}
0005432262888	9DE3E5	7484 006910	VALERIY FROLOV	{"phone": "+70955451203"}
0005432262889	9DE3E5	3051 081288	OLGA PAVLOVA	{"email": "pavlova.olga_041977@postgrespro.ru", "phone": "+70774020795"}
0005432262890	9EA6E8	0138 060576	SVETLANA KOZLOVA	{"phone": "+70407784879"}
0005432262891	264022	2897 259254	ANATOLIY FEDOTOV	{"phone": "+70024528781"}
0005432262892	D938A3	8797 759638	MIKHAIL ZHUKOV	{"phone": "+70416990770"}
0005432262893	D938A3	6409 932333	EKATERINA ZAYCEVA	{"email": "zayceva_e081965@postgrespro.ru", "phone": "+70784964296"}
0005432262894	E3B1CC	5668 045021	VYACHESLAV BONDARENKO	{"email": "bondarenko.vyacheslav-1967@postgrespro.ru", "phone": "+70930029011"}
0005432262895	E3B1CC	8993 405238	EKATERINA KULIKOVA	{"email": "kulikova-e071975@postgrespro.ru", "phone": "+70762784766"}
0005432262896	34DDEB	6556 279827	ELENA GUSEVA	{"phone": "+70353007219"}
0005432262897	CBEFE8	2402 725385	VLADIMIR CHERNOV	{"email": "vchernov_1966@postgrespro.ru", "phone": "+70442049581"}
0005432262898	1D1447	9777 931329	LIDIYA TIMOFEEVA	{"phone": "+70622044512"}
0005432262899	1D1447	8584 822689	ASIYA MELNIKOVA	{"phone": "+70869047012"}
0005432262900	1B31A5	9311 165314	ANDREY IVANOV	{"email": "ivanov.a_091974@postgrespro.ru", "phone": "+70012202897"}
0005432262901	1A5A39	7830 909838	EKATERINA ANTONOVA	{"email": "antonova_ekaterina_23101976@postgrespro.ru", "phone": "+70518741651"}
0005432262902	1A5A39	3372 794544	IVAN BONDARENKO	{"email": "i-bondarenko_021976@postgrespro.ru", "phone": "+70864363097"}
0005432262903	A7CE8F	5486 283559	NATALIYA NIKITINA	{"email": "nikitinanataliya011986@postgrespro.ru", "phone": "+70506770380"}
0005432262904	34BE4E	6129 837018	OLGA NESTEROVA	{"phone": "+70496935021"}
0005432262905	34BE4E	9080 424976	ALEKSEY ANDREEV	{"email": "andreev.aleksey1983@postgrespro.ru", "phone": "+70424480051"}
0005432262906	34BE4E	5810 065201	VITALIY ZAKHAROV	{"phone": "+70681946234"}
0005432262907	90CAB8	3042 243839	VIKTORIYA ZAYCEVA	{"phone": "+70501888692"}
0005432262908	90CAB8	8654 169495	LYUBOV MOROZOVA	{"phone": "+70966412869"}
0005432262909	E43C2B	7590 963438	VASILIY KUZMIN	{"email": "vkuzmin_02041978@postgrespro.ru", "phone": "+70938479968"}
0005432262910	9CD0BF	6251 721814	OLGA OSIPOVA	{"email": "osipovaolga.101972@postgrespro.ru", "phone": "+70686181246"}
0005432262911	9CD0BF	7822 315963	SERGEY KUZNECOV	{"email": "kuznecov-sergey-091980@postgrespro.ru", "phone": "+70558115960"}
0005432262912	9CD0BF	4097 693828	IVAN EGOROV	{"phone": "+70061084822"}
0005432262913	17E998	9454 227450	SERAFIM GUSEV	{"email": "s.gusev_1975@postgrespro.ru", "phone": "+70361326916"}
0005432262914	17E998	8153 131518	MARGARITA GUSEVA	{"email": "guseva-m17091986@postgrespro.ru", "phone": "+70337014895"}
0005432262915	E4881D	6207 642846	MARAT ANDREEV	{"email": "andreev-marat_101975@postgrespro.ru", "phone": "+70850695667"}
0005432262916	E4881D	2180 061283	ALEKSANDR BARANOV	{"email": "baranov.a_091976@postgrespro.ru", "phone": "+70297370514"}
0005432262917	A6291D	7515 199874	IGOR SMIRNOV	{"email": "smirnovigor.041979@postgrespro.ru", "phone": "+70571711290"}
0005432262918	6C87B8	3040 866365	DMITRIY SERGEEV	{"email": "d.sergeev1987@postgrespro.ru", "phone": "+70649214666"}
0005432262919	8C19B6	1676 359433	GALINA IVANOVA	{"email": "ivanova-g_1971@postgrespro.ru", "phone": "+70543640351"}
0005432262920	271E93	9998 981074	EVGENIY SOKOLOV	{"phone": "+70601675573"}
0005432262921	5B502C	9625 387021	TATYANA KAZAKOVA	{"phone": "+70029068604"}
0005432262922	D992C3	2741 217322	ARTEM SOROKIN	{"email": "sorokin-artem1980@postgrespro.ru", "phone": "+70191958550"}
0005432262923	BC9DFD	8672 492764	VLADIMIR ZAKHAROV	{"phone": "+70083346812"}
0005432262924	D696D3	2921 979897	OKSANA PETROVA	{"phone": "+70255687326"}
0005432262925	D696D3	2801 079199	ANGELINA VOROBEVA	{"email": "angelina_vorobeva_18061974@postgrespro.ru", "phone": "+70786815337"}
0005432262926	B380B7	4078 436937	MIKHAIL PETROV	{"email": "mikhail-petrov13121983@postgrespro.ru", "phone": "+70257433124"}
0005432262927	B380B7	2350 084799	LARISA TIMOFEEVA	{"email": "timofeeva-l071970@postgrespro.ru", "phone": "+70165095611"}
0005432262928	567953	4224 636337	SERGEY IVANOV	{"phone": "+70642409118"}
0005432262929	567953	9305 037831	NATALYA MELNIKOVA	{"phone": "+70556284748"}
0005432262930	7F70A9	1668 579554	MARIYA KAZAKOVA	{"email": "kazakova-mariya1971@postgrespro.ru", "phone": "+70131333782"}
0005432262931	D88D00	4125 833358	TATYANA PAVLOVA	{"email": "pavlova.t101958@postgrespro.ru", "phone": "+70205215216"}
0005432262932	D88D00	6479 858124	PAVEL KARPOV	{"email": "pavelkarpov_1969@postgrespro.ru", "phone": "+70784473033"}
0005432262933	091EE7	5059 880191	ALEKSANDR IVANOV	{"phone": "+70461520991"}
0005432262934	3A2048	6371 980977	ALEKSEY KAZAKOV	{"phone": "+70913857583"}
0005432262935	B879C7	1814 042787	VLADIMIR STEPANOV	{"phone": "+70017068218"}
0005432262936	FE7116	4912 998675	PAVEL ZAYCEV	{"phone": "+70662662473"}
0005432262937	D6507A	2612 494080	SERGEY GRIGOREV	{"email": "sergey.grigorev-1966@postgrespro.ru", "phone": "+70065009559"}
0005432262938	D6507A	3733 536170	VLADIMIR PETROV	{"email": "petrov-v_011975@postgrespro.ru", "phone": "+70530039646"}
0005432262939	ADC019	2479 038985	ELENA SMIRNOVA	{"phone": "+70771839219"}
0005432262940	ADC019	9885 950635	ALEKSEY FROLOV	{"phone": "+70081798513"}
0005432262941	E72E36	3110 944604	OLGA SOKOLOVA	{"email": "sokolova.olga.1970@postgrespro.ru", "phone": "+70534935037"}
0005432262942	E72E36	6083 297910	LYUBOV NAZAROVA	{"phone": "+70119974508"}
0005432262943	932CB4	0054 706148	TIMOFEY VLASOV	{"phone": "+70100714231"}
0005432262944	3A2AE8	7684 778129	NIKOLAY MARTYNOV	{"phone": "+70777866779"}
0005432262945	46BCA0	5800 159306	KLAVDIYA MEDVEDEVA	{"phone": "+70177387813"}
0005432262946	46BCA0	8230 026683	ELENA POLYAKOVA	{"email": "polyakova-e1970@postgrespro.ru", "phone": "+70419379295"}
0005432262947	306193	5576 130832	TATYANA GUSEVA	{"phone": "+70955840912"}
0005432262948	7D8909	4794 095966	ANASTASIYA DMITRIEVA	{"phone": "+70752152697"}
0005432262949	7D8909	1206 640913	ANASTASIYA BELOVA	{"email": "belova_a.17121964@postgrespro.ru", "phone": "+70522598406"}
0005432262950	8935A2	0064 278660	SVETLANA BORISOVA	{"phone": "+70825318865"}
0005432262951	8935A2	6379 400410	TATYANA FILATOVA	{"phone": "+70315457711"}
0005432262952	E4ACFE	2164 965168	VALENTIN ALEKSANDROV	{"email": "valentin_aleksandrov041973@postgrespro.ru", "phone": "+70396365862"}
0005432262953	E4ACFE	8738 639032	ELENA MELNIKOVA	{"email": "melnikovaelena.17061977@postgrespro.ru", "phone": "+70090068898"}
0005432262954	EF0437	5074 469195	ELENA VASILEVA	{"phone": "+70252900987"}
0005432262955	EF0437	2104 740765	SERGEY PAVLOV	{"email": "pavlov-s.011974@postgrespro.ru", "phone": "+70596791925"}
0005432262956	EF0437	8759 077447	DINA POTAPOVA	{"phone": "+70901533752"}
0005432262957	904C29	3369 995465	ANDREY SOROKIN	{"email": "a.sorokin_18051969@postgrespro.ru", "phone": "+70175180500"}
0005432262958	03AA4D	1469 543319	ANNA SOLOVEVA	{"email": "asoloveva_1972@postgrespro.ru", "phone": "+70386513748"}
0005432262959	03AA4D	5264 161322	NAIL ZAYCEV	{"phone": "+70043745995"}
0005432262960	EA6516	8694 467099	ALEKSEY MOROZOV	{"phone": "+70113268921"}
0005432262961	5719E5	0353 926680	VENERA DAVYDOVA	{"email": "v_davydova-29121978@postgrespro.ru", "phone": "+70993161838"}
0005432262962	5719E5	8871 386471	NIKOLAY MATVEEV	{"phone": "+70676148752"}
0005432262963	C5B2D4	6220 450510	VERONIKA KOROLEVA	{"email": "koroleva-veronika29071973@postgrespro.ru", "phone": "+70055922844"}
0005432262964	C5B2D4	8945 990023	NIKOLAY NAZAROV	{"email": "n.nazarov1972@postgrespro.ru", "phone": "+70329341525"}
0005432262965	834622	8445 299712	VALERIYA SCHERBAKOVA	{"email": "valeriya_scherbakova-1987@postgrespro.ru", "phone": "+70671658518"}
0005432262966	F3BE14	8361 410761	DARYA PETROVA	{"email": "petrova-d-1982@postgrespro.ru", "phone": "+70515841709"}
0005432262967	662760	8186 716988	DMITRIY STEPANOV	{"phone": "+70872901663"}
0005432262968	662760	8501 601789	VIKTOR FEDOROV	{"phone": "+70539265689"}
0005432262969	D8CC62	0132 585859	ANDREY ZAYCEV	{"email": "zaycev-andrey1986@postgrespro.ru", "phone": "+70340062307"}
0005432262970	F31B5B	8639 371118	DMITRIY BORISOV	{"email": "dmitriy_borisov_111990@postgrespro.ru", "phone": "+70370642315"}
0005432262971	065041	6863 166296	MIKHAIL SMIRNOV	{"email": "mikhail_smirnov_1965@postgrespro.ru", "phone": "+70157792530"}
0005432262972	46B5DB	9689 186520	EVGENIY POPOV	{"email": "popov.evgeniy_1959@postgrespro.ru", "phone": "+70329172290"}
0005432262973	B49746	9011 473863	MARINA FILATOVA	{"email": "m.filatova1977@postgrespro.ru", "phone": "+70784764520"}
0005432262974	1E99C7	7231 394871	DMITRIY PAVLOV	{"phone": "+70429480521"}
0005432262975	1E99C7	3460 912043	ALEKSEY MOROZOV	{"phone": "+70641949144"}
0005432262976	BFC6A5	5028 168869	MARIYA BORISOVA	{"email": "mariya-borisova.1968@postgrespro.ru", "phone": "+70742101351"}
0005432262977	9D17C6	5720 792784	ELENA SAVELEVA	{"email": "e-saveleva14101975@postgrespro.ru", "phone": "+70048630183"}
0005432262978	1C82A9	0297 979845	ALEKSANDR PAVLOV	{"phone": "+70477194035"}
0005432262979	EAA10F	8850 364611	EKATERINA MAKSIMOVA	{"phone": "+70935840104"}
0005432262980	467F39	6441 739557	NATALYA MOISEEVA	{"email": "moiseeva-n.091971@postgrespro.ru", "phone": "+70960777588"}
0005432262981	815890	4521 880850	VERONIKA IVANOVA	{"email": "ivanovav.20071971@postgrespro.ru", "phone": "+70435305676"}
0005432262982	EF4FDD	6262 575561	MIKHAIL PETROV	{"email": "mikhailpetrov.1971@postgrespro.ru", "phone": "+70870968008"}
0005432262983	EF4FDD	6685 860691	RODION KOZLOV	{"email": "rodionkozlov1973@postgrespro.ru", "phone": "+70394705301"}
0005432262984	755AA1	6813 583221	OLGA ZOTOVA	{"email": "zotova_olga1974@postgrespro.ru", "phone": "+70494953863"}
0005432262985	497053	9903 374199	SERGEY SIDOROV	{"email": "sidorov.s_10061965@postgrespro.ru", "phone": "+70702406541"}
0005432262986	729319	9002 255725	ALINA TIKHONOVA	{"phone": "+70576252192"}
0005432262987	017883	4026 144048	ALEKSEY POPOV	{"email": "a.popov24071972@postgrespro.ru", "phone": "+70227132483"}
0005432262988	017883	4990 740569	SVETLANA KUZNECOVA	{"phone": "+70274400171"}
0005432262989	C8C5F3	0174 065266	NATALYA CHERNOVA	{"phone": "+70403205576"}
0005432262990	748B05	1567 509010	LIDIYA RODIONOVA	{"email": "lrodionova.27101968@postgrespro.ru", "phone": "+70281242918"}
0005432262991	A1C950	7373 439755	VLADIMIR KUZNECOV	{"phone": "+70869429748"}
0005432262992	6A3642	6972 142054	ZOYA KONOVALOVA	{"phone": "+70708600212"}
0005432262993	6A3642	1947 291214	OLEG BORISOV	{"email": "borisov_oleg03011967@postgrespro.ru", "phone": "+70470649037"}
0005432262994	6A3642	0545 987177	ALEKSANDRA KUZNECOVA	{"email": "aleksandra_kuznecova061970@postgrespro.ru", "phone": "+70616883882"}
0005432262995	D73EEA	7993 582964	ALEKSANDR ANDREEV	{"email": "andreevaleksandr.031972@postgrespro.ru", "phone": "+70383781517"}
0005432262996	10C11E	8988 865012	VALERIY KISELEV	{"email": "valeriykiselev-20041979@postgrespro.ru", "phone": "+70819943193"}
0005432262997	10C11E	9861 743404	FANIS OSIPOV	{"phone": "+70078090363"}
0005432262998	953E56	8700 006850	VLADIMIR SOKOLOV	{"email": "sokolov.v.1970@postgrespro.ru", "phone": "+70796150869"}
0005432262999	63A985	8182 522249	TATYANA SEMENOVA	{"email": "tatyana-semenova1967@postgrespro.ru", "phone": "+70822201725"}
0005432263000	2C026D	3726 954780	VLADIMIR SEMENOV	{"email": "vladimir_semenov_031973@postgrespro.ru", "phone": "+70085380107"}
0005432263001	D95BD6	3240 798319	IRINA ANISIMOVA	{"phone": "+70985076069"}
0005432263002	D95BD6	2281 563574	ANDREY GRIGOREV	{"phone": "+70964755732"}
0005432263003	FE4FCD	2451 087227	VYACHESLAV KOROLEV	{"phone": "+70427507053"}
0005432263004	32819F	0423 619751	EKATERINA RODIONOVA	{"phone": "+70588319758"}
0005432263005	A91CAB	7753 671358	PAVEL KISELEV	{"phone": "+70455177044"}
0005432263006	421901	4774 263341	MARK ANDREEV	{"email": "andreev.m.12061972@postgrespro.ru", "phone": "+70014489551"}
0005432263007	ADE9E9	4162 371665	TAISIYA BOGDANOVA	{"email": "bogdanova-taisiya-19041965@postgrespro.ru", "phone": "+70391487599"}
0005432263008	B560A1	3026 127873	IGOR VASILEV	{"phone": "+70653392666"}
0005432263009	AD8E44	5177 452558	GALINA IVANOVA	{"email": "ivanova.galina-09111978@postgrespro.ru", "phone": "+70446832251"}
0005432263010	AD8E44	9626 464028	LIDIYA KUDRYASHOVA	{"phone": "+70547724356"}
0005432263011	271612	5968 215768	FAINA KUZNECOVA	{"email": "kuznecova-faina.1978@postgrespro.ru", "phone": "+70243054070"}
0005432263012	0D96BE	6383 394134	VASILIY ILIN	{"phone": "+70253093907"}
0005432263013	0D96BE	2921 670546	EKATERINA BOGDANOVA	{"email": "ekaterina.bogdanova1974@postgrespro.ru", "phone": "+70429371733"}
0005432263014	E3682A	5471 470498	VERA MEDVEDEVA	{"email": "medvedeva.v.031965@postgrespro.ru", "phone": "+70148160618"}
0005432263015	715F06	5408 037854	TATYANA VLASOVA	{"phone": "+70119338229"}
0005432263016	C752D5	3314 753323	ANNA LOGINOVA	{"phone": "+70476911418"}
0005432263017	1452D9	8631 935336	ANTONINA GRISHINA	{"email": "antoninagrishina011972@postgrespro.ru", "phone": "+70416905407"}
0005432263018	A76E34	6604 306784	OLEG SOKOLOV	{"email": "oleg_sokolov25111964@postgrespro.ru", "phone": "+70067338116"}
0005432263019	28A18F	0932 853138	GRIGORIY OSIPOV	{"email": "osipov.grigoriy-091963@postgrespro.ru", "phone": "+70984980763"}
0005432263020	40773D	0091 665010	ANTON GUSEV	{"phone": "+70002341372"}
0005432263021	833A7E	5807 685747	RAISA KULIKOVA	{"phone": "+70859724757"}
0005432263022	39098B	8095 332327	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin.19081977@postgrespro.ru", "phone": "+70263792038"}
0005432263023	9708AB	4773 285736	DMITRIY GUSEV	{"email": "dgusev.101980@postgrespro.ru", "phone": "+70889557214"}
0005432263024	A48843	4232 421863	ALEKSEY MOISEEV	{"phone": "+70619638508"}
0005432263025	79544E	1976 518322	TATYANA NESTEROVA	{"email": "t_nesterova-031984@postgrespro.ru", "phone": "+70990710558"}
0005432263026	79544E	9676 332670	ALEKSANDR POPOV	{"phone": "+70401349183"}
0005432263027	E3A202	2386 598418	EVGENIY VOROBEV	{"phone": "+70527019016"}
0005432263028	1B28D0	4381 738385	NATALIYA IVANOVA	{"email": "n_ivanova.15031961@postgrespro.ru", "phone": "+70338507970"}
0005432263029	46687A	2631 613668	LEONID ISAEV	{"phone": "+70064577119"}
0005432263030	2218E9	0444 964209	VLADIMIR ANDREEV	{"phone": "+70584980205"}
0005432263031	D5B00C	3911 300044	ELENA PAVLOVA	{"email": "epavlova-26121974@postgrespro.ru", "phone": "+70687300874"}
0005432263032	C40409	4388 484625	IVAN MOROZOV	{"email": "i_morozov121972@postgrespro.ru", "phone": "+70740966186"}
0005432263033	D7D7F7	7527 235281	ALEKSANDR FEDOTOV	{"email": "afedotov28031974@postgrespro.ru", "phone": "+70846645029"}
0005432263034	D7D7F7	5262 262620	EKATERINA KRASNOVA	{"phone": "+70822320953"}
0005432263035	93E1C1	9010 777726	OLGA KOZLOVA	{"email": "olga-kozlova24101985@postgrespro.ru", "phone": "+70788014511"}
0005432263036	038124	6729 350157	VLADIMIR FOMIN	{"email": "fomin.v.27061973@postgrespro.ru", "phone": "+70929119403"}
0005432263037	038124	4320 525860	ALEKSANDR BORISOV	{"email": "borisova_121974@postgrespro.ru", "phone": "+70748942476"}
0005432263038	525D09	9706 199941	SERGEY FEDOROV	{"phone": "+70465453569"}
0005432263039	10A6AF	3892 594036	ELENA GUSEVA	{"phone": "+70938753659"}
0005432263040	A19E44	9909 500637	ZOYA EFIMOVA	{"phone": "+70115958462"}
0005432263041	B5AE1F	6048 686447	LIDIYA MASLOVA	{"phone": "+70717737652"}
0005432263042	F0D8D1	6610 961063	LYUDMILA MALYSHEVA	{"phone": "+70349574239"}
0005432263043	E05DA6	7243 333575	NATALYA KARPOVA	{"phone": "+70937581506"}
0005432263044	604C57	8310 572489	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko06121980@postgrespro.ru", "phone": "+70595757435"}
0005432263045	604C57	2399 853470	EKATERINA KUDRYASHOVA	{"email": "ekaterina.kudryashova.07061976@postgrespro.ru", "phone": "+70511736149"}
0005432263046	0CA1F3	6460 529823	RAVIL KARPOV	{"email": "karpov_ravil-13111965@postgrespro.ru", "phone": "+70696381979"}
0005432263047	CCDD7C	5207 271636	EVGENIY TIKHONOV	{"email": "evgeniytikhonov25111977@postgrespro.ru", "phone": "+70030488875"}
0005432263048	CCDD7C	0525 739239	YULIYA KAZAKOVA	{"phone": "+70090724195"}
0005432263049	AB81F9	9123 119894	ANTONINA RYABOVA	{"email": "antonina_ryabova-1981@postgrespro.ru", "phone": "+70224862087"}
0005432263050	AB81F9	1978 934985	NATALYA ZOTOVA	{"email": "n.zotova-1992@postgrespro.ru", "phone": "+70861916323"}
0005432263051	829575	3090 957325	VALERIY VOROBEV	{"phone": "+70175272508"}
0005432263052	AA46E5	3789 295524	TATYANA SOKOLOVA	{"phone": "+70194426995"}
0005432263053	8366DB	3838 811340	NATALYA KRASNOVA	{"phone": "+70773220795"}
0005432263054	8366DB	9700 804832	LIDIYA MAKSIMOVA	{"phone": "+70494832830"}
0005432263055	67C47F	4856 620393	YAKOV SOLOVEV	{"phone": "+70242203312"}
0005432263056	6E7F8B	3277 823456	NELLI EFREMOVA	{"phone": "+70438086360"}
0005432263057	6E7F8B	0018 100029	DMITRIY SIDOROV	{"phone": "+70121312142"}
0005432263058	7B544D	2703 553785	DIANA YUDINA	{"email": "diana.yudina.041969@postgrespro.ru", "phone": "+70063237693"}
0005432263059	02861D	4795 789455	NATALYA ZAKHAROVA	{"email": "zakharova.n_02031982@postgrespro.ru", "phone": "+70274915718"}
0005432263060	CBA2D2	1939 584062	NATALYA MIKHAYLOVA	{"email": "nmikhaylova081979@postgrespro.ru", "phone": "+70630625357"}
0005432263061	CBA2D2	3949 652296	TATYANA PETROVA	{"email": "tatyana-petrova-28031967@postgrespro.ru", "phone": "+70172087430"}
0005432263062	72C72B	5634 183635	ZLATA IVANOVA	{"email": "zlata_ivanova14031978@postgrespro.ru", "phone": "+70332160309"}
0005432263063	72C72B	2962 852002	NIKOLAY STEPANOV	{"email": "stepanov_nikolay-26041966@postgrespro.ru", "phone": "+70850665617"}
0005432263064	DB75D3	9891 547174	LYUDMILA VOLKOVA	{"email": "lyudmilavolkova_15031969@postgrespro.ru", "phone": "+70989085100"}
0005432263065	DB75D3	9192 383796	ALEKSANDRA PAVLOVA	{"email": "aleksandra.pavlova.1975@postgrespro.ru", "phone": "+70081260470"}
0005432263066	A0DA7C	8197 699137	SERGEY ABRAMOV	{"email": "s.abramov.13091977@postgrespro.ru", "phone": "+70608257145"}
0005432263067	232769	5369 622663	SALAVAT MEDVEDEV	{"phone": "+70649358064"}
0005432263068	E33E9B	8155 585015	VLADIMIR ZAYCEV	{"phone": "+70888556763"}
0005432263069	08BAF4	5102 070110	ALEKSANDR PETROV	{"phone": "+70085573542"}
0005432263070	1253A5	1862 934980	TAMARA SCHERBAKOVA	{"phone": "+70399197911"}
0005432263071	6982D9	0630 126945	SERGEY GERASIMOV	{"phone": "+70317726210"}
0005432263072	B4ECC4	6802 951075	VASILIY ZHURAVLEV	{"email": "zhuravlevvasiliy051970@postgrespro.ru", "phone": "+70443606173"}
0005432263073	B4ECC4	8524 229810	BORIS DENISOV	{"phone": "+70442256333"}
0005432263074	23F5D7	1511 006060	ARTEM PETROV	{"email": "petrov_a1961@postgrespro.ru", "phone": "+70887916229"}
0005432263075	186F97	6233 590114	SERGEY ZAYCEV	{"phone": "+70157766899"}
0005432263076	C9C555	6251 661000	TATYANA ANTONOVA	{"email": "t_antonova.15121965@postgrespro.ru", "phone": "+70998450627"}
0005432263077	C9C555	7156 432544	VERA ZOTOVA	{"email": "zotova_vera_1973@postgrespro.ru", "phone": "+70781857389"}
0005432263078	7F7C1E	1637 602929	EGOR SOROKIN	{"phone": "+70517454351"}
0005432263079	AE9D9F	8872 177481	DENIS MIKHAYLOV	{"email": "mikhaylov.denis-05081970@postgrespro.ru", "phone": "+70064947065"}
0005432263080	AE9D9F	5373 372877	YURIY FEDOTOV	{"phone": "+70700880397"}
0005432263081	59EF8C	1742 664548	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov_061967@postgrespro.ru", "phone": "+70165659592"}
0005432263082	CCE429	0696 504138	DMITRIY MIRONOV	{"email": "mironov_dmitriy-1962@postgrespro.ru", "phone": "+70416556159"}
0005432263083	70D740	3622 148030	MAKSIM EGOROV	{"email": "maksim_egorov1968@postgrespro.ru", "phone": "+70975182991"}
0005432263084	70D740	2842 557410	SVETLANA FEDOROVA	{"email": "s-fedorova.061986@postgrespro.ru", "phone": "+70481376634"}
0005432263085	E6403E	0138 312702	ELENA ANTONOVA	{"phone": "+70958628037"}
0005432263086	E6403E	8182 098893	DARYA AKIMOVA	{"email": "akimovadarya_28051959@postgrespro.ru", "phone": "+70473752713"}
0005432263087	39F4D6	8562 724209	ALEKSEY POPOV	{"email": "popov.aleksey_061968@postgrespro.ru", "phone": "+70862132167"}
0005432263088	39F4D6	3359 739013	SERGEY VOROBEV	{"phone": "+70876596959"}
0005432263089	8A3E69	3314 137703	MARIYA ZAYCEVA	{"email": "mariya_zayceva-1975@postgrespro.ru", "phone": "+70161501839"}
0005432263090	7FDF3A	3264 204675	VALENTINA MELNIKOVA	{"phone": "+70704765685"}
0005432263091	B28924	9791 806644	ALEKSANDR PAVLOV	{"email": "a.pavlov.091962@postgrespro.ru", "phone": "+70596185739"}
0005432263092	801437	4836 290430	VERA DANILOVA	{"email": "danilova.vera.31121970@postgrespro.ru", "phone": "+70836054196"}
0005432263093	801437	4512 078521	MARGARITA EGOROVA	{"email": "m_egorova_091972@postgrespro.ru", "phone": "+70097028412"}
0005432263094	164A5E	1164 360391	ALEKSEY SIDOROV	{"email": "alekseysidorov.02061980@postgrespro.ru", "phone": "+70875318801"}
0005432263095	D3E519	2116 990387	VYACHESLAV SOROKIN	{"email": "sorokin_vyacheslav_1970@postgrespro.ru", "phone": "+70533949136"}
0005432263096	68B981	0253 478560	VYACHESLAV SOKOLOV	{"email": "sokolov.v_02071972@postgrespro.ru", "phone": "+70361711003"}
0005432263097	051527	3705 319538	IVAN IVANOV	{"email": "ivan_ivanov.1968@postgrespro.ru", "phone": "+70109542142"}
0005432263098	051527	9132 590726	EVGENIY DENISOV	{"email": "denisov.evgeniy_1969@postgrespro.ru", "phone": "+70055556755"}
0005432263099	25A593	0717 548232	ALEKSEY NIKOLAEV	{"phone": "+70600940387"}
0005432263100	8B17C2	4341 478617	NADEZHDA KONOVALOVA	{"email": "nkonovalova_09101977@postgrespro.ru", "phone": "+70928614463"}
0005432263101	C6380B	1338 586365	ANASTASIYA ARKHIPOVA	{"email": "arkhipova.a101969@postgrespro.ru", "phone": "+70035149086"}
0005432263102	C6380B	3960 135901	VIKTORIYA POPOVA	{"email": "popova-viktoriya.1977@postgrespro.ru", "phone": "+70366416537"}
0005432263103	7D28D0	8607 927427	MIKHAIL TIKHONOV	{"phone": "+70794749188"}
0005432263104	8C8A6A	7701 352914	NIKOLAY KOZLOV	{"email": "nikolaykozlov.041979@postgrespro.ru", "phone": "+70854923654"}
0005432263105	EA6C59	5143 759393	VITALIY MIKHAYLOV	{"email": "v-mikhaylov.1974@postgrespro.ru", "phone": "+70022275309"}
0005432263106	4C5FC7	1868 199840	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin18031971@postgrespro.ru", "phone": "+70428338801"}
0005432263107	4C5FC7	6891 436499	LYUBOV DMITRIEVA	{"phone": "+70923848753"}
0005432263108	B86ED7	0525 831831	VIKTOR MARTYNOV	{"phone": "+70176932252"}
0005432263109	2A0708	3488 595486	ALEKSANDR BELOV	{"phone": "+70698206291"}
0005432263110	657536	0882 436102	IRINA BORISOVA	{"email": "irina.borisova1978@postgrespro.ru", "phone": "+70745749410"}
0005432263111	657536	0593 662307	NIKOLAY ZHURAVLEV	{"email": "n.zhuravlev1970@postgrespro.ru", "phone": "+70201572316"}
0005432263112	AE281A	8179 186921	ANDREY MIKHAYLOV	{"email": "mikhaylov-a_1975@postgrespro.ru", "phone": "+70395702461"}
0005432263113	133BC1	6579 103192	SVETLANA IVANOVA	{"email": "ivanova-svetlana081979@postgrespro.ru", "phone": "+70257677612"}
0005432263114	359BA3	1130 244581	VLADIMIR ALEKSEEV	{"phone": "+70421496520"}
0005432263115	359BA3	5959 254805	NIKOLAY TIKHONOV	{"email": "tikhonov-nikolay20081964@postgrespro.ru", "phone": "+70486379493"}
0005432263116	5E9AC7	8618 172357	TATYANA KRASNOVA	{"email": "krasnova-tatyana051973@postgrespro.ru", "phone": "+70024918697"}
0005432263117	E54C88	2266 505754	ANDREY MIKHAYLOV	{"phone": "+70900579402"}
0005432263118	BBF4F9	0484 965083	EKATERINA FILIPPOVA	{"email": "ekaterina.filippova-05021955@postgrespro.ru", "phone": "+70694525214"}
0005432263119	7A75E7	4969 548961	STANISLAV NOVIKOV	{"phone": "+70988869895"}
0005432263120	7A75E7	1694 043906	IGOR IVANOV	{"email": "i_ivanov.16101961@postgrespro.ru", "phone": "+70828348010"}
0005432263121	7A75E7	9532 520682	ARTUR SOROKIN	{"email": "artur.sorokin.111985@postgrespro.ru", "phone": "+70855681977"}
0005432263122	4354AE	2334 646093	VIKTOR DMITRIEV	{"phone": "+70473522402"}
0005432263123	21572E	0985 529862	MARINA KUZNECOVA	{"email": "mkuznecova1981@postgrespro.ru", "phone": "+70835068500"}
0005432263124	8362DA	1443 972215	LYUBOV MASLOVA	{"email": "l.maslova_1978@postgrespro.ru", "phone": "+70463656340"}
0005432263125	8362DA	1694 406216	NATALYA STEPANOVA	{"phone": "+70306108261"}
0005432263126	9ECB36	6168 830922	ALEKSANDR SERGEEV	{"phone": "+70426988217"}
0005432263127	663255	7120 553093	OLGA ALEKSANDROVA	{"phone": "+70313620315"}
0005432263128	32DF73	5740 302593	ELIZAVETA KUZNECOVA	{"phone": "+70134797586"}
0005432263129	A741CC	6385 068716	ARTEM KUZNECOV	{"email": "artem_kuznecov.05041971@postgrespro.ru", "phone": "+70456611839"}
0005432263130	28036D	1728 533570	VLADIMIR IVANOV	{"email": "vivanov.1974@postgrespro.ru", "phone": "+70065653828"}
0005432263131	28036D	3228 596239	TATYANA STEPANOVA	{"phone": "+70954474050"}
0005432263132	32012F	8376 746735	MARIYA TIKHONOVA	{"email": "m-tikhonova_26041969@postgrespro.ru", "phone": "+70826442512"}
0005432263133	32012F	2633 997377	ELENA ZAKHAROVA	{"phone": "+70970260115"}
0005432263134	9D2C6E	6607 251460	ALEKSANDR SCHERBAKOV	{"phone": "+70842446498"}
0005432263135	9D2C6E	9013 966620	ALEKSEY POPOV	{"email": "popov.aleksey18031971@postgrespro.ru", "phone": "+70626754997"}
0005432263136	354A7F	0498 027951	NINA SEMENOVA	{"phone": "+70363025407"}
0005432263137	40D3CF	7159 453352	ALEKSANDR SOLOVEV	{"email": "solovev-aleksandr-021972@postgrespro.ru", "phone": "+70555535292"}
0005432263138	E35F6C	9018 844710	ANASTASIYA EFIMOVA	{"phone": "+70543147279"}
0005432263139	E35F6C	5728 274246	VALENTINA SOLOVEVA	{"email": "valentina-soloveva121979@postgrespro.ru", "phone": "+70638737355"}
0005432263140	4BCBEC	5572 597957	VALERIY ZAKHAROV	{"phone": "+70118272986"}
0005432263141	CA261D	1948 399920	EVGENIY IVANOV	{"phone": "+70322479882"}
0005432263142	0BE891	1315 040232	ALIK KRASNOV	{"email": "alik-krasnov.081975@postgrespro.ru", "phone": "+70686207977"}
0005432263143	0BE891	0245 901436	VALENTINA MAKAROVA	{"phone": "+70353992843"}
0005432263144	0BE891	6444 960466	ILYA FROLOV	{"phone": "+70650719067"}
0005432263145	D041FF	6769 005102	GENNADIY SOROKIN	{"email": "soroking-111964@postgrespro.ru", "phone": "+70715914569"}
0005432263146	D041FF	2755 722815	DMITRIY ALEKSANDROV	{"phone": "+70082277930"}
0005432263147	D041FF	8476 438502	DANIIL FROLOV	{"phone": "+70938969415"}
0005432263148	830199	9327 217472	VITALIY ALEKSANDROV	{"email": "aleksandrov.v_101975@postgrespro.ru", "phone": "+70737885022"}
0005432263149	271FCF	8687 154693	TATYANA ANTONOVA	{"phone": "+70313422139"}
0005432263150	273550	6441 565719	LYUBOV NAZAROVA	{"email": "l-nazarova.101967@postgrespro.ru", "phone": "+70957880485"}
0005432263151	273550	9037 439826	LIDIYA PETROVA	{"email": "petrova.lidiya.01041967@postgrespro.ru", "phone": "+70937482688"}
0005432263152	273550	2021 853389	ALEKSANDR CHERNOV	{"phone": "+70549684336"}
0005432263153	89E0D5	8157 430182	MARINA ANTONOVA	{"phone": "+70524863011"}
0005432263154	9CE300	2701 982788	DMITRIY ROMANOV	{"phone": "+70178376966"}
0005432263155	6ADF8D	0566 654161	PAVEL BARANOV	{"email": "baranovpavel_1975@postgrespro.ru", "phone": "+70458321715"}
0005432263156	1774FB	4520 616080	YULIYA POLYAKOVA	{"email": "polyakovayuliya_031972@postgrespro.ru", "phone": "+70759371083"}
0005432263157	A85A3A	7200 058133	VIKTOR PETROV	{"email": "viktor.petrov1983@postgrespro.ru", "phone": "+70009673421"}
0005432263158	406F3F	3348 318337	VYACHESLAV DMITRIEV	{"phone": "+70860549536"}
0005432263159	3B8D6D	2562 145351	VERA SERGEEVA	{"phone": "+70238341204"}
0005432263160	1DE560	0984 073802	OLGA MOISEEVA	{"phone": "+70932697558"}
0005432263161	EE1FE7	4083 494358	ALEKSANDR KAZAKOV	{"phone": "+70157729142"}
0005432263162	FF469A	9168 867184	STANISLAV SEMENOV	{"phone": "+70513503643"}
0005432263163	6951A9	1960 365466	ALEKSANDRA FILATOVA	{"phone": "+70623671407"}
0005432263164	6951A9	7809 296516	MARIYA VLASOVA	{"email": "mariya-vlasova.09011981@postgrespro.ru", "phone": "+70200078108"}
0005432263165	83E781	6475 545590	IRINA KONOVALOVA	{"phone": "+70420357260"}
0005432263166	DAC389	2244 474498	ANDREY NAZAROV	{"phone": "+70175949620"}
0005432263167	DAC389	2273 022090	DARYA LOGINOVA	{"email": "loginova_d.1966@postgrespro.ru", "phone": "+70706220035"}
0005432263168	58FDE1	1468 234077	DMITRIY SERGEEV	{"email": "sergeevdmitriy-1977@postgrespro.ru", "phone": "+70795761755"}
0005432263223	C5517D	9337 515860	VALENTINA ZHURAVLEVA	{"phone": "+70976561521"}
0005432263169	819417	4619 586938	EKATERINA MAKSIMOVA	{"email": "maksimova_e.121973@postgrespro.ru", "phone": "+70727133249"}
0005432263170	A5DFC1	1539 980773	NATALYA ZAYCEVA	{"phone": "+70835865064"}
0005432263171	CCC051	0640 319174	ALINA ZAYCEVA	{"email": "alinazayceva_081981@postgrespro.ru", "phone": "+70872363032"}
0005432263172	7D613C	2308 497126	ANNA KULIKOVA	{"phone": "+70911072095"}
0005432263173	2C17FE	7295 884049	ELENA SOROKINA	{"email": "sorokina-elena.28021972@postgrespro.ru", "phone": "+70300807530"}
0005432263174	2C8203	7888 416553	EDUARD KONOVALOV	{"phone": "+70011880459"}
0005432263175	2C8203	6324 873959	ALEKSANDR ILIN	{"email": "aleksandr.ilin.1961@postgrespro.ru", "phone": "+70795102857"}
0005432263176	2C8203	3838 137352	GALINA MATVEEVA	{"email": "gmatveeva_02021978@postgrespro.ru", "phone": "+70875068465"}
0005432263177	6D1CA5	6901 938329	MIKHAIL MATVEEV	{"phone": "+70302426377"}
0005432263178	C06739	8792 420147	MARAT ABRAMOV	{"email": "abramov-m.1965@postgrespro.ru", "phone": "+70102376973"}
0005432263179	CFFD9B	8954 492660	NAZIYA ILINA	{"phone": "+70319807732"}
0005432263180	FCFF2D	2486 599305	DARYA POTAPOVA	{"email": "potapova.darya_021960@postgrespro.ru", "phone": "+70672053230"}
0005432263181	FCFF2D	5513 355366	SERGEY KUZMIN	{"email": "kuzmin.sergey-1972@postgrespro.ru", "phone": "+70300548878"}
0005432263182	41909D	8277 760126	NINA KARPOVA	{"phone": "+70497051019"}
0005432263183	784894	7655 099157	NIKOLAY PETROV	{"email": "npetrov_031977@postgrespro.ru", "phone": "+70405986541"}
0005432263184	784894	8920 014420	LYUDMILA KRASNOVA	{"email": "l-krasnova-1960@postgrespro.ru", "phone": "+70788568683"}
0005432263185	C32D41	9429 550602	ALEKSANDRA ZAKHAROVA	{"email": "zakharova_aleksandra_26011979@postgrespro.ru", "phone": "+70640302839"}
0005432263186	C9BB93	2100 164175	SERGEY KAZAKOV	{"email": "s_kazakov041984@postgrespro.ru", "phone": "+70276644964"}
0005432263187	26BADB	3355 808558	TATYANA GERASIMOVA	{"phone": "+70865872255"}
0005432263188	295970	4249 532585	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov-16061969@postgrespro.ru", "phone": "+70695546725"}
0005432263189	295970	7288 892582	MARINA LUKYANOVA	{"email": "marina_lukyanova_02101966@postgrespro.ru", "phone": "+70551991660"}
0005432263190	727D1E	2441 820297	TATYANA SCHERBAKOVA	{"email": "tatyanascherbakova-1974@postgrespro.ru", "phone": "+70850778563"}
0005432263191	F5696B	7029 402637	EKATERINA NIKOLAEVA	{"phone": "+70392200508"}
0005432263192	ECF14E	3169 379146	MARINA DMITRIEVA	{"phone": "+70305991056"}
0005432263193	A94787	7351 888048	ALEKSEY TARASOV	{"email": "tarasov-aleksey_1976@postgrespro.ru", "phone": "+70635499467"}
0005432263194	E8D08B	8568 278240	LYUBOV MAKSIMOVA	{"email": "maksimoval.1976@postgrespro.ru", "phone": "+70952208092"}
0005432263195	E7BECB	0142 313126	GALINA DMITRIEVA	{"email": "gdmitrieva-24071967@postgrespro.ru", "phone": "+70572743835"}
0005432263196	E7BECB	0202 813990	MIKHAIL EGOROV	{"phone": "+70954023988"}
0005432263197	C83910	5523 411110	VALENTINA VOLKOVA	{"email": "volkova-valentina30061971@postgrespro.ru", "phone": "+70217534218"}
0005432263198	9ECEB9	1353 346720	ALEKSEY KUZMIN	{"phone": "+70829528843"}
0005432263199	9ECEB9	2542 741349	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr_081979@postgrespro.ru", "phone": "+70485390269"}
0005432263200	9ECEB9	3317 573483	IVAN SOROKIN	{"email": "isorokin.1964@postgrespro.ru", "phone": "+70621123902"}
0005432263201	F74836	3843 954890	IRINA KOROLEVA	{"phone": "+70999624989"}
0005432263202	F74836	6166 853230	EVGENIY SAVELEV	{"phone": "+70344646423"}
0005432263203	6B7726	8458 402512	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr03011971@postgrespro.ru", "phone": "+70631591436"}
0005432263204	6B7726	2172 618180	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr-051977@postgrespro.ru", "phone": "+70933720746"}
0005432263205	0A5A64	8946 714837	VALERIYA MOROZOVA	{"email": "valeriyamorozova-19031969@postgrespro.ru", "phone": "+70867457723"}
0005432263206	8C4FD4	4086 514787	SEMEN SOLOVEV	{"email": "ssolovev-011978@postgrespro.ru", "phone": "+70299917586"}
0005432263207	EFEB88	0047 346295	ANATOLIY KONOVALOV	{"email": "a-konovalov05051975@postgrespro.ru", "phone": "+70452721024"}
0005432263208	F8D6B1	0672 073721	OLGA SIDOROVA	{"email": "sidorova.o-1971@postgrespro.ru", "phone": "+70462455774"}
0005432263209	F8D6B1	4668 710682	IRINA POLYAKOVA	{"email": "polyakova_irina.27041967@postgrespro.ru", "phone": "+70726553226"}
0005432263210	1A5192	1870 149364	NATALYA POTAPOVA	{"phone": "+70588422533"}
0005432263211	1A5192	4393 579337	SERGEY EGOROV	{"email": "s-egorov-1966@postgrespro.ru", "phone": "+70453381066"}
0005432263212	1A5192	7960 342056	STANISLAV NIKITIN	{"email": "nikitin_s.031980@postgrespro.ru", "phone": "+70199381308"}
0005432263213	7B0901	6929 965132	DMITRIY POPOV	{"email": "d-popov_061975@postgrespro.ru", "phone": "+70066497751"}
0005432263214	FC0B65	2773 380797	IGOR FILIPPOV	{"email": "igor_filippov-061970@postgrespro.ru", "phone": "+70585144806"}
0005432263215	F17FF2	1186 596096	LIDIYA TIMOFEEVA	{"phone": "+70890073167"}
0005432263216	72D63E	0912 336260	VITALIY SEMENOV	{"email": "vitaliy_semenov.1980@postgrespro.ru", "phone": "+70992080993"}
0005432263217	72D63E	2735 173547	VALENTINA NESTEROVA	{"phone": "+70921176339"}
0005432263218	CDD83A	7175 024284	LYUDMILA STEPANOVA	{"phone": "+70272982011"}
0005432263219	CDD83A	9711 705148	ANDREY KAZAKOV	{"email": "kazakov_a17011981@postgrespro.ru", "phone": "+70531838953"}
0005432263220	C88D6B	0928 606216	ANTON FEDOTOV	{"email": "fedotovanton031968@postgrespro.ru", "phone": "+70165869181"}
0005432263221	7B408B	7251 251198	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey-08091975@postgrespro.ru", "phone": "+70282317439"}
0005432263222	BD635E	7085 777094	ROMAN BONDARENKO	{"phone": "+70683496556"}
0005432263224	951667	3806 649524	GEORGIY KUZNECOV	{"email": "kuznecov-g.1982@postgrespro.ru", "phone": "+70688874393"}
0005432263225	951667	4353 826503	LYUDMILA BORISOVA	{"email": "lyudmilaborisova-1972@postgrespro.ru", "phone": "+70595569044"}
0005432263226	B42B66	1786 341666	ELENA VLASOVA	{"email": "vlasovae-1965@postgrespro.ru", "phone": "+70965883968"}
0005432263227	4E3A74	0717 823881	SERGEY SIDOROV	{"email": "sidorovs04081962@postgrespro.ru", "phone": "+70384026000"}
0005432263228	418A3B	4280 627717	TATYANA ZAKHAROVA	{"phone": "+70449042971"}
0005432263229	AE40F3	2840 656087	IRINA GAVRILOVA	{"email": "gavrilova-i09091968@postgrespro.ru", "phone": "+70961638395"}
0005432263230	AE40F3	4529 903369	VALENTINA TARASOVA	{"phone": "+70068847983"}
0005432263231	BB9563	6725 630865	DMITRIY IVANOV	{"email": "d_ivanov-031975@postgrespro.ru", "phone": "+70317542292"}
0005432263232	BB9563	3857 183040	PAVEL EGOROV	{"phone": "+70050764814"}
0005432263233	93133E	4815 983670	MAKSIM MEDVEDEV	{"phone": "+70027056050"}
0005432263234	6C187F	8458 165788	ALENA POPOVA	{"email": "alenapopova02011981@postgrespro.ru", "phone": "+70789879907"}
0005432263235	6C187F	6322 450402	ANTON TARASOV	{"phone": "+70760561251"}
0005432263236	A79AB1	7561 481956	ALEKSANDRA FILIPPOVA	{"phone": "+70417428570"}
0005432263237	A79AB1	0239 664167	EVGENIY DENISOV	{"phone": "+70680924640"}
0005432263238	2C0F29	6560 456665	OLGA SOKOLOVA	{"phone": "+70826276213"}
0005432264431	7E5403	8819 974644	OKSANA NAZAROVA	{"phone": "+70381085664"}
0005432264432	7E5403	3724 038193	ALLA KULIKOVA	{"email": "alla-kulikova-1982@postgrespro.ru", "phone": "+70526572954"}
0005432264433	359358	7901 107906	NIKOLAY POPOV	{"phone": "+70137545709"}
0005432264434	500FF8	7482 249178	NIKOLAY BORISOV	{"email": "borisov_nikolay.041960@postgrespro.ru", "phone": "+70858335024"}
0005432264435	8E87ED	3857 719547	ALENA EFREMOVA	{"email": "efremovaalena_03081965@postgrespro.ru", "phone": "+70965544289"}
0005432264436	A353C4	4272 731617	ANASTASIYA SOROKINA	{"phone": "+70982569668"}
0005432264437	A353C4	1681 293827	KSENIYA KOROLEVA	{"phone": "+70812866657"}
0005432264438	FE1FE9	8326 147564	ANDREY IVANOV	{"phone": "+70198548851"}
0005432264439	06DB89	8377 007729	NINA ZOTOVA	{"phone": "+70508824709"}
0005432264440	033961	5636 241991	ARTEM SERGEEV	{"phone": "+70685074384"}
0005432264441	BB0E7F	8973 236203	ELENA NIKIFOROVA	{"phone": "+70117418843"}
0005432264442	FC14AF	7492 492492	EKATERINA PETROVA	{"email": "ekaterina_petrova-13031973@postgrespro.ru", "phone": "+70156313438"}
0005432264443	FC14AF	6781 053718	SERGEY KOZLOV	{"email": "kozlov-sergey051961@postgrespro.ru", "phone": "+70011465023"}
0005432264444	BEA6FD	0217 189931	RASHIT TARASOV	{"phone": "+70441736520"}
0005432264445	BEA6FD	5457 264509	MIKHAIL ZAYCEV	{"phone": "+70347772647"}
0005432264446	A79019	2872 506330	ALEKSANDR FILIPPOV	{"phone": "+70014183309"}
0005432264447	819F03	5371 131743	VADIM MIRONOV	{"email": "v.mironov-21011976@postgrespro.ru", "phone": "+70105701565"}
0005432264448	CC18B8	7579 307511	ALEKSANDR CHERNOV	{"phone": "+70552264443"}
0005432264449	CC18B8	1688 187447	VALERIY ZAKHAROV	{"phone": "+70469722014"}
0005432264450	CC18B8	1672 264959	ARTUR YAKOVLEV	{"email": "yakovlev_artur101965@postgrespro.ru", "phone": "+70432726522"}
0005432264451	F53B06	4795 626106	ANDREY KOROLEV	{"phone": "+70986786745"}
0005432264452	F53B06	5788 805718	NINA MEDVEDEVA	{"phone": "+70130047454"}
0005432264453	3162A9	8159 659998	YURIY SIDOROV	{"email": "y-sidorov1979@postgrespro.ru", "phone": "+70128381250"}
0005432264454	3162A9	0877 403004	TATYANA ALEKSEEVA	{"phone": "+70120202180"}
0005432264455	824B9D	5001 488161	RIM KUZMIN	{"email": "rim-kuzmin_13111971@postgrespro.ru", "phone": "+70828385555"}
0005432264456	EA973E	0173 859818	IRINA POPOVA	{"phone": "+70456885767"}
0005432264457	D8A6E0	7902 681063	SAID EGOROV	{"phone": "+70997000493"}
0005432264458	D8A6E0	3541 230684	ALINA KOROLEVA	{"email": "koroleva.a1976@postgrespro.ru", "phone": "+70928845952"}
0005432264459	53B348	0014 555988	VLADIMIR VOLKOV	{"email": "v.volkov1973@postgrespro.ru", "phone": "+70725671841"}
0005432264460	CCEFAA	2271 120849	NATALYA FOMINA	{"phone": "+70767346807"}
0005432264461	CCEFAA	7120 727628	LYUDMILA KUZNECOVA	{"email": "l_kuznecova-22081966@postgrespro.ru", "phone": "+70004367706"}
0005432264462	E37951	7209 655164	EKATERINA PETROVA	{"email": "petrova_ekaterina_30061984@postgrespro.ru", "phone": "+70319191102"}
0005432264463	5CAB5A	9433 359548	ALEKSANDR SOROKIN	{"email": "a-sorokin111973@postgrespro.ru", "phone": "+70649857389"}
0005432264464	964D4F	5146 229146	MARAT MIKHAYLOV	{"phone": "+70503776676"}
0005432264465	46FC35	5862 564811	MARIYA SOKOLOVA	{"email": "sokolova_mariya1976@postgrespro.ru", "phone": "+70052896943"}
0005432264466	DF2996	7558 121083	ANASTASIYA ROMANOVA	{"email": "anastasiyaromanova-05051972@postgrespro.ru", "phone": "+70520197805"}
0005432264467	8E7E5D	9609 032462	EVGENIY SMIRNOV	{"phone": "+70446060341"}
0005432264468	8E7E5D	5511 308366	PAVEL ZHURAVLEV	{"phone": "+70617255974"}
0005432264469	4E278F	3641 844070	YANA LAZAREVA	{"email": "yana.lazareva-11101959@postgrespro.ru", "phone": "+70008558894"}
0005432264470	1D415E	1706 660158	GALINA IVANOVA	{"phone": "+70773014131"}
0005432264471	130602	6503 941998	OLGA ZAYCEVA	{"email": "zaycevaolga_041972@postgrespro.ru", "phone": "+70564229614"}
0005432264472	0ED1E8	8526 780802	ANNA VOLKOVA	{"email": "a.volkova-24011974@postgrespro.ru", "phone": "+70619726081"}
0005432264473	75CF57	5752 725541	NATALYA TIMOFEEVA	{"email": "natalyatimofeeva.1969@postgrespro.ru", "phone": "+70073776628"}
0005432264474	75CF57	6437 071409	LYUDMILA STEPANOVA	{"phone": "+70211597779"}
0005432264475	9BF9AC	4325 351623	ALEKSEY FEDOROV	{"email": "aleksey.fedorov_02101967@postgrespro.ru", "phone": "+70191922545"}
0005432264476	4620EE	0081 319761	LYUBOV DMITRIEVA	{"email": "dmitrievalyubov-061970@postgrespro.ru", "phone": "+70647964627"}
0005432264477	FE14B9	2050 363578	EKATERINA GUSEVA	{"email": "eguseva_1979@postgrespro.ru", "phone": "+70437631452"}
0005432264478	E40A2D	3736 817823	YURIY GERASIMOV	{"phone": "+70854870476"}
0005432264479	28FE9F	3198 531089	GRIGORIY KAZAKOV	{"email": "g-kazakov-011976@postgrespro.ru", "phone": "+70443858949"}
0005432264480	59AB5C	1867 139315	ALEKSEY IVANOV	{"email": "aivanov041978@postgrespro.ru", "phone": "+70603990555"}
0005432264481	CA921E	7167 509083	YURIY ILIN	{"phone": "+70189378177"}
0005432264482	807F5C	3979 486954	OKSANA LUKYANOVA	{"phone": "+70766438903"}
0005432264483	807F5C	2246 995468	ANDREY GRIGOREV	{"phone": "+70639661910"}
0005432264484	67125E	6265 789728	LYUBOV ERMAKOVA	{"email": "ermakova-l_1969@postgrespro.ru", "phone": "+70568256394"}
0005432264485	7F079A	2851 257956	DMITRIY STEPANOV	{"email": "stepanovdmitriy1969@postgrespro.ru", "phone": "+70298401908"}
0005432264486	7F079A	8089 937287	VASILISA IVANOVA	{"email": "ivanova-vasilisa_1970@postgrespro.ru", "phone": "+70315916289"}
0005432264487	930F01	0686 133961	LYUBOV KARPOVA	{"phone": "+70846553144"}
0005432264488	930F01	2287 232127	SERGEY GERASIMOV	{"phone": "+70241571604"}
0005432264489	571561	2142 532284	RAISA POTAPOVA	{"email": "raisa_potapova.081969@postgrespro.ru", "phone": "+70215161862"}
0005432264490	1E95A9	4985 753095	STANISLAV ABRAMOV	{"phone": "+70139974025"}
0005432264491	F9486A	2751 902329	ELENA ZHURAVLEVA	{"phone": "+70497508048"}
0005432264492	EB7F83	3801 155637	MARIYA MIKHAYLOVA	{"phone": "+70634352732"}
0005432264493	366D89	4273 390424	NIKOLAY YAKOVLEV	{"phone": "+70898097076"}
0005432264494	366D89	7733 073861	OLEG FEDOTOV	{"email": "fedotov.oleg-31011978@postgrespro.ru", "phone": "+70798257024"}
0005432264495	E0C7E9	3168 623465	OLGA IVANOVA	{"email": "olgaivanova1972@postgrespro.ru", "phone": "+70998317540"}
0005432264496	E0C7E9	6279 793734	MIKHAIL EGOROV	{"phone": "+70022465560"}
0005432264497	4B130B	5392 343383	ILYA VOLKOV	{"email": "volkovi021990@postgrespro.ru", "phone": "+70846874301"}
0005432264498	4B130B	2313 381509	ANTONINA SMIRNOVA	{"phone": "+70381024086"}
0005432264499	4B130B	7152 899002	NIKOLAY SAVELEV	{"email": "n.savelev-27041962@postgrespro.ru", "phone": "+70110175173"}
0005432264500	B1293D	9087 866736	OLGA AFANASEVA	{"phone": "+70387474002"}
0005432264501	B1293D	0337 416113	ELENA FEDOROVA	{"email": "e-fedorova011975@postgrespro.ru", "phone": "+70619314842"}
0005432264502	8646D3	8313 689997	VALENTINA FOMINA	{"phone": "+70261897376"}
0005432264503	8646D3	8616 856801	DMITRIY ZAKHAROV	{"phone": "+70445612094"}
0005432264504	76F6F0	7527 262310	ANDREY OSIPOV	{"email": "osipov.a-011974@postgrespro.ru", "phone": "+70993209920"}
0005432264505	B9CD12	1677 000651	DANILA ALEKSEEV	{"email": "alekseevd_1966@postgrespro.ru", "phone": "+70179079835"}
0005432264506	0E6A80	5602 151940	IVAN VOROBEV	{"email": "vorobev-i_031973@postgrespro.ru", "phone": "+70394166968"}
0005432264507	0E6A80	9488 988807	GALINA LOGINOVA	{"email": "g_loginova_06111977@postgrespro.ru", "phone": "+70828120940"}
0005432264508	6F4B93	9332 048345	GALINA YAKOVLEVA	{"phone": "+70480167952"}
0005432264509	6F4B93	6932 664818	ARTEM ANDREEV	{"email": "andreev-a.121973@postgrespro.ru", "phone": "+70389060607"}
0005432264510	913202	5818 042311	OLGA DAVYDOVA	{"phone": "+70794737103"}
0005432264511	E90F1E	8874 437157	PAVEL STEPANOV	{"phone": "+70691817396"}
0005432264512	96DBF2	5474 188903	MARINA VASILEVA	{"phone": "+70716963351"}
0005432264513	1C5994	2170 276866	RUSTEM MATVEEV	{"phone": "+70185930092"}
0005432264514	B5316A	8436 254397	IGOR BORISOV	{"phone": "+70360243747"}
0005432264515	B5316A	0831 003918	DMITRIY TARASOV	{"email": "tarasov_d.23021972@postgrespro.ru", "phone": "+70453496652"}
0005432264516	50084B	5088 550356	LIDIYA FILATOVA	{"email": "lidiya.filatova021969@postgrespro.ru", "phone": "+70820592232"}
0005432264517	126ADA	4066 689504	NINA MASLOVA	{"email": "nmaslova.1985@postgrespro.ru", "phone": "+70609198817"}
0005432264518	126ADA	5119 716294	ALEKSANDRA KUZNECOVA	{"phone": "+70337802530"}
0005432264519	126ADA	4610 443975	DMITRIY IVANOV	{"email": "ivanovdmitriy1963@postgrespro.ru", "phone": "+70388205434"}
0005432264520	D88371	8928 892439	STEPAN SEMENOV	{"phone": "+70622037894"}
0005432264521	81A397	0656 171872	LYUBOV KUZNECOVA	{"email": "kuznecova.l_1970@postgrespro.ru", "phone": "+70207955977"}
0005432264522	D71814	9701 310419	VLADIMIR KISELEV	{"email": "vkiselev-23031975@postgrespro.ru", "phone": "+70645160447"}
0005432264523	F9D1CD	6380 052166	EKATERINA ZAKHAROVA	{"phone": "+70987131461"}
0005432264524	7DA520	6560 754939	MIKHAIL PETROV	{"email": "mikhail_petrov.091977@postgrespro.ru", "phone": "+70543001353"}
0005432264525	649F7D	0484 991526	EVGENIY SCHERBAKOV	{"phone": "+70273939541"}
0005432264526	649F7D	8699 155833	VLADIMIR KISELEV	{"email": "vladimir-kiselev-111975@postgrespro.ru", "phone": "+70400672078"}
0005432264527	CC8F27	5931 348559	TATYANA DENISOVA	{"phone": "+70353556190"}
0005432264528	2FAED8	3125 986258	ELENA DENISOVA	{"email": "denisovaelena.1964@postgrespro.ru", "phone": "+70777656572"}
0005432264529	0FDABC	6237 070461	EVGENIY SHEVCHENKO	{"email": "e-shevchenko.18061968@postgrespro.ru", "phone": "+70999481584"}
0005432264530	A123BD	8658 297414	LYUDMILA MAKAROVA	{"email": "lmakarova-071965@postgrespro.ru", "phone": "+70138592435"}
0005432264531	EC811F	3675 219075	NINA ORLOVA	{"phone": "+70300733379"}
0005432264532	34B4EA	2448 824157	LYUDMILA KUDRYASHOVA	{"email": "kudryashova_lyudmila.07071965@postgrespro.ru", "phone": "+70455722707"}
0005432264533	466483	3028 584747	GALINA KUZNECOVA	{"phone": "+70366842646"}
0005432264534	EE0250	1677 338396	NINA LEBEDEVA	{"email": "lebedeva-nina_1982@postgrespro.ru", "phone": "+70365760915"}
0005432264535	BF5C42	4098 864877	DENIS MOISEEV	{"email": "denis_moiseev-101971@postgrespro.ru", "phone": "+70181851966"}
0005432264536	FDE3B9	2984 489821	EKATERINA FROLOVA	{"email": "frolova.ekaterina.15111969@postgrespro.ru", "phone": "+70328564452"}
0005432264537	FDE3B9	1906 644382	VALENTINA EFREMOVA	{"email": "efremova_valentina-011979@postgrespro.ru", "phone": "+70239090794"}
0005432264538	7D9DE7	8722 994499	ANATOLIY MARTYNOV	{"email": "a_martynov03081982@postgrespro.ru", "phone": "+70697169123"}
0005432264539	7D9DE7	7303 238344	GALINA ERMAKOVA	{"email": "galina-ermakova-041967@postgrespro.ru", "phone": "+70958978976"}
0005432264540	FE4A42	2570 992939	VALERIY GAVRILOV	{"email": "gavrilov_valeriy_1971@postgrespro.ru", "phone": "+70671899286"}
0005432264541	DB08AA	0636 683088	IRINA EGOROVA	{"phone": "+70263929493"}
0005432264542	DB08AA	7941 145489	ANZHELIKA GORBUNOVA	{"phone": "+70896038353"}
0005432264543	9F27AF	5059 932531	NATALYA KONDRATEVA	{"phone": "+70190195644"}
0005432264544	9F27AF	2490 807133	VIKTORIYA MELNIKOVA	{"phone": "+70712673227"}
0005432264545	9F27AF	3411 892438	NATALYA LAZAREVA	{"phone": "+70615810900"}
0005432264546	89EEC6	9553 242452	ANTON KUZNECOV	{"email": "kuznecova.071961@postgrespro.ru", "phone": "+70733601457"}
0005432264547	A3765C	7486 067217	ANASTASIYA MAKSIMOVA	{"email": "anastasiya_maksimova_1972@postgrespro.ru", "phone": "+70057732878"}
0005432264548	83223F	5515 628668	IVAN SAVELEV	{"phone": "+70671583685"}
0005432267777	4BD178	1865 719037	VLADIMIR MAKSIMOV	{"email": "maksimov_vladimir-01081968@postgrespro.ru", "phone": "+70135064208"}
0005432267778	4BD178	3429 894730	TAMARA ANDREEVA	{"email": "andreeva.t_1957@postgrespro.ru", "phone": "+70728718966"}
0005432267779	920427	8547 736960	EKATERINA SAVELEVA	{"email": "e_saveleva_1970@postgrespro.ru", "phone": "+70556376091"}
0005432267780	3D09A0	2188 253562	NATALYA SAVELEVA	{"email": "n_saveleva.1966@postgrespro.ru", "phone": "+70915323070"}
0005432267781	3D09A0	4061 527319	LYUBOV ANDREEVA	{"email": "andreeva-l1976@postgrespro.ru", "phone": "+70679138502"}
0005432267782	3D09A0	9370 936424	TATYANA TIKHONOVA	{"email": "tikhonova-tatyana_24011966@postgrespro.ru", "phone": "+70718634702"}
0005432267783	D5A170	8096 702561	ALEKSANDR PETROV	{"phone": "+70296385925"}
0005432267784	D5A170	9450 413165	NIKOLAY TIKHONOV	{"phone": "+70044675193"}
0005432267785	DE8CB3	6647 319385	TAMARA MALYSHEVA	{"email": "tamaramalysheva_22111974@postgrespro.ru", "phone": "+70406507871"}
0005432267786	E0A457	4346 268607	VALENTINA ANDREEVA	{"phone": "+70924700291"}
0005432267787	200D29	8501 123644	IGOR SERGEEV	{"email": "i_sergeev-1970@postgrespro.ru", "phone": "+70056064106"}
0005432267788	BBF0A5	9783 380103	ANTONINA STEPANOVA	{"phone": "+70927803328"}
0005432267789	F1BF83	7827 420179	ROMAN SERGEEV	{"phone": "+70490830463"}
0005432267790	AC8A54	3887 346008	RAISA SOKOLOVA	{"email": "raisasokolova.101969@postgrespro.ru", "phone": "+70016972556"}
0005432267791	DA291C	8835 122518	LEONID ROMANOV	{"email": "romanov.leonid_1969@postgrespro.ru", "phone": "+70148362718"}
0005432267792	DA291C	4751 502804	VIKTOR KOZLOV	{"email": "viktorkozlov-041975@postgrespro.ru", "phone": "+70115371198"}
0005432267793	9A1A4A	2219 555552	TATYANA VOROBEVA	{"phone": "+70671347769"}
0005432267794	9A1A4A	8251 425198	OLEG VOROBEV	{"phone": "+70918451158"}
0005432267795	9A1A4A	6501 300034	FEDOR SOLOVEV	{"email": "f_solovev_1970@postgrespro.ru", "phone": "+70788212244"}
0005432267796	C858CF	8608 925827	ALEKSANDR VASILEV	{"email": "vasilev-a_1971@postgrespro.ru", "phone": "+70051474991"}
0005432267797	0BED63	4318 494009	ANDREY NIKITIN	{"phone": "+70843780635"}
0005432267798	A6E9EC	9523 797236	VALENTINA SERGEEVA	{"email": "sergeevav121967@postgrespro.ru", "phone": "+70004244331"}
0005432267799	A6E9EC	2322 676010	VYACHESLAV MOROZOV	{"email": "morozov.vyacheslav_28091973@postgrespro.ru", "phone": "+70879939190"}
0005432267800	740850	8743 651549	TATYANA ILINA	{"email": "ilina.t-121975@postgrespro.ru", "phone": "+70699913984"}
0005432267801	C16F76	9476 824435	YAN KUZNECOV	{"email": "ykuznecov.1987@postgrespro.ru", "phone": "+70598982219"}
0005432267802	19EA7D	1281 978347	PETR VLASOV	{"phone": "+70108511637"}
0005432267803	19EA7D	5276 973892	EVGENIY MAKAROV	{"email": "makarov-evgeniy-14081973@postgrespro.ru", "phone": "+70089662778"}
0005432267804	4ADA4B	6170 654252	LYUDMILA DMITRIEVA	{"email": "dmitrieva_l.14071976@postgrespro.ru", "phone": "+70006646594"}
0005432267805	48B9AF	3191 322771	VADIM KAZAKOV	{"email": "kazakov.vadim.23061965@postgrespro.ru", "phone": "+70792111251"}
0005432267806	48B9AF	8818 284358	RAISA DANILOVA	{"phone": "+70661995155"}
0005432267807	F07E06	7187 270828	VALERIY POPOV	{"phone": "+70345366567"}
0005432267808	F07E06	1928 813533	ANATOLIY TARASOV	{"email": "a.tarasov101977@postgrespro.ru", "phone": "+70067000763"}
0005432267809	BB92C5	6143 819851	IRINA CHERNOVA	{"phone": "+70203558462"}
0005432267810	0294E3	5053 802467	DARYA MAKSIMOVA	{"email": "maksimova_darya-111973@postgrespro.ru", "phone": "+70923246494"}
0005432267811	0294E3	4292 142093	SERGEY VLASOV	{"email": "vlasov.sergey-1963@postgrespro.ru", "phone": "+70786471866"}
0005432267812	5D7461	3686 447280	NATALYA MELNIKOVA	{"email": "melnikova.n1967@postgrespro.ru", "phone": "+70732829909"}
0005432267813	A79844	4757 999459	ELENA ABRAMOVA	{"email": "e.abramova.22071968@postgrespro.ru", "phone": "+70693435888"}
0005432267814	F7834C	3943 618389	EVGENIY ZHUKOV	{"email": "zhukove_031983@postgrespro.ru", "phone": "+70242622413"}
0005432267815	193309	8701 119106	NATALYA NAZAROVA	{"email": "natalyanazarova.1971@postgrespro.ru", "phone": "+70644908417"}
0005432267816	193309	1037 779524	ELENA ZAKHAROVA	{"phone": "+70381258249"}
0005432267817	809A1B	7985 669892	ANATOLIY FOMIN	{"phone": "+70361337749"}
0005432267818	809A1B	3770 061079	RAISA KRASNOVA	{"phone": "+70914144699"}
0005432267819	C64410	2555 858934	ANDREY ZHURAVLEV	{"email": "andreyzhuravlev.1973@postgrespro.ru", "phone": "+70759763073"}
0005432267820	A972ED	6119 371656	EGOR ANTONOV	{"email": "antonov.e061971@postgrespro.ru", "phone": "+70935417790"}
0005432267821	D15CA7	1568 389273	ALEKSANDR MAKSIMOV	{"email": "amaksimov_03101969@postgrespro.ru", "phone": "+70631526733"}
0005432267822	D22F88	7410 909166	OLEG GERASIMOV	{"email": "o_gerasimov-041975@postgrespro.ru", "phone": "+70292700461"}
0005432267823	579877	5246 561831	OLESYA KISELEVA	{"phone": "+70407470547"}
0005432267824	579877	3555 301992	IVAN GUSEV	{"email": "ivan_gusev-01111960@postgrespro.ru", "phone": "+70421301516"}
0005432267825	AA0202	6721 115601	VALENTINA LAZAREVA	{"email": "v.lazareva.1970@postgrespro.ru", "phone": "+70002195568"}
0005432267826	E5F148	8015 106361	OLGA STEPANOVA	{"email": "ostepanova_1975@postgrespro.ru", "phone": "+70752702888"}
0005432267827	012CB4	3486 316382	LILIYA KOVALEVA	{"phone": "+70641323634"}
0005432267828	6E66B6	1751 324325	VLADIMIR KUZNECOV	{"phone": "+70859785795"}
0005432267829	6E66B6	8427 841581	IRINA NESTEROVA	{"phone": "+70679106664"}
0005432267830	6E66B6	2076 025775	ANATOLIY PETROV	{"email": "petrov_anatoliy.1959@postgrespro.ru", "phone": "+70777477514"}
0005432267831	705ED3	1674 226275	ALEKSANDR SIDOROV	{"phone": "+70040954069"}
0005432267832	4A5AD4	1159 774017	ALEKSANDR MAKAROV	{"phone": "+70122522035"}
0005432267833	C0EE1C	2804 017383	SERGEY KOZLOV	{"phone": "+70370202090"}
0005432267834	C0EE1C	6559 700017	DENIS MOISEEV	{"email": "d_moiseev-1967@postgrespro.ru", "phone": "+70713272199"}
0005432267835	56BB67	0598 851450	ANNA ROMANOVA	{"phone": "+70833172224"}
0005432267836	530FC7	5132 662677	MARAT GRIGOREV	{"phone": "+70020963561"}
0005432267837	9BD707	0327 190161	GENNADIY ALEKSANDROV	{"email": "g.aleksandrov-07101977@postgrespro.ru", "phone": "+70870025127"}
0005432267838	789C72	3634 509305	ANASTASIYA AFANASEVA	{"email": "afanaseva.anastasiya.091980@postgrespro.ru", "phone": "+70954964471"}
0005432267839	862D86	8891 688778	ALEKSEY PETROV	{"phone": "+70655715915"}
0005432267840	AEF250	4341 676080	LILIYA KUZNECOVA	{"email": "kuznecova.liliya051974@postgrespro.ru", "phone": "+70314807974"}
0005432267841	5B2708	4876 446664	DMITRIY PAVLOV	{"phone": "+70876262626"}
0005432267842	500764	1165 924499	VASILIY EGOROV	{"phone": "+70657137070"}
0005432267843	500764	3897 694401	GENNADIY ABRAMOV	{"phone": "+70556124077"}
0005432267844	B22E71	6885 130260	ELENA SOLOVEVA	{"phone": "+70814089528"}
0005432267845	3BD53D	5994 595740	MARIYA NIKITINA	{"email": "m.nikitina_1974@postgrespro.ru", "phone": "+70766992126"}
0005432267846	125461	3700 493993	ALEKSANDR IVANOV	{"phone": "+70300570874"}
0005432267847	125461	4563 217411	VERA KRASNOVA	{"email": "krasnova_v.051974@postgrespro.ru", "phone": "+70170917442"}
0005432267848	0A4BB6	6293 353386	NADEZHDA AFANASEVA	{"email": "afanaseva.n.1974@postgrespro.ru", "phone": "+70610129476"}
0005432267849	0E88C0	0031 352653	YULIYA PETROVA	{"email": "yuliya.petrova-06011979@postgrespro.ru", "phone": "+70895611812"}
0005432267850	0E88C0	6654 737941	SERGEY STEPANOV	{"phone": "+70104287943"}
0005432267851	0CBD5D	9764 064279	IRINA KOROLEVA	{"email": "irina_koroleva1974@postgrespro.ru", "phone": "+70606612427"}
0005432267852	3BD123	2938 476563	ILGIZ CHERNOV	{"phone": "+70827960493"}
0005432267853	73E089	4331 374859	VIKTOR KOZLOV	{"phone": "+70009502316"}
0005432267854	73E089	1299 890949	KONSTANTIN VOROBEV	{"email": "konstantin_vorobev1966@postgrespro.ru", "phone": "+70577591805"}
0005432267855	A27C6A	7605 043156	ALBINA NOVIKOVA	{"phone": "+70407935667"}
0005432267856	13D0DB	7785 418656	TATYANA GORBUNOVA	{"phone": "+70800631682"}
0005432267857	5446B0	9242 171766	RAISA GERASIMOVA	{"phone": "+70772661843"}
0005432267858	CBCDDD	6946 408235	ANTONINA ZHUKOVA	{"email": "zhukovaantonina-091960@postgrespro.ru", "phone": "+70601891792"}
0005432267859	CBCDDD	6479 561336	EVGENIY CHERNOV	{"email": "chernov_evgeniy_061959@postgrespro.ru", "phone": "+70289677035"}
0005432267860	164F46	8619 224548	ALEKSANDR BELOV	{"email": "a.belov-011966@postgrespro.ru", "phone": "+70976812955"}
0005432267861	38CCB4	0701 796712	VLADIMIR SOROKIN	{"phone": "+70634159773"}
0005432267862	760009	5617 593127	ELENA KUZMINA	{"email": "kuzminae-1971@postgrespro.ru", "phone": "+70816262356"}
0005432267863	26BD13	3013 258693	ALLA EFIMOVA	{"email": "a_efimova041969@postgrespro.ru", "phone": "+70593779416"}
0005432267864	70925A	8162 191512	ROMAN FOMIN	{"phone": "+70629891546"}
0005432267865	70925A	6509 413621	VALENTINA FADEEVA	{"phone": "+70931719279"}
0005432267866	F0DE8C	1574 351937	GERMAN ABRAMOV	{"phone": "+70788410053"}
0005432267867	48F371	4517 010589	VALENTINA DMITRIEVA	{"phone": "+70193913440"}
0005432267868	8037C2	3348 525373	ROMAN KOROLEV	{"phone": "+70871190910"}
0005432267869	8037C2	1267 961332	ARTEM GORBUNOV	{"email": "a_gorbunov.24061969@postgrespro.ru", "phone": "+70800348650"}
0005432267870	459335	4969 333581	ANDREY SCHERBAKOV	{"phone": "+70546185648"}
0005432267871	459335	9882 990943	ALEKSANDR ANDREEV	{"email": "aleksandrandreev-07101976@postgrespro.ru", "phone": "+70455956372"}
0005432267872	B6C03B	1478 094439	ALEKSANDR RODIONOV	{"email": "arodionov.1975@postgrespro.ru", "phone": "+70130653655"}
0005432267873	6EF130	9524 901378	TATYANA KOROLEVA	{"phone": "+70914399009"}
0005432267874	342D29	8248 546018	IRINA CHERNOVA	{"phone": "+70989305854"}
0005432267875	342D29	9813 383908	ANDREY GUSEV	{"email": "gusev-a-29011976@postgrespro.ru", "phone": "+70418468947"}
0005432267876	E4B72B	1141 129608	NATALYA ILINA	{"email": "ilinanatalya07111975@postgrespro.ru", "phone": "+70559999528"}
0005432267877	F64780	7776 177134	LARISA GUSEVA	{"phone": "+70262150270"}
0005432267878	7BCA3E	1982 357282	NATALYA GORBUNOVA	{"email": "gorbunova_natalya24121975@postgrespro.ru", "phone": "+70911961651"}
0005432267879	7BCA3E	8970 674970	SVETLANA POPOVA	{"email": "svetlana.popova_1975@postgrespro.ru", "phone": "+70266688726"}
0005432267880	F1827E	4239 816600	TATYANA KARPOVA	{"phone": "+70618463230"}
0005432267881	135EEB	9028 615242	RUSTAM SAVELEV	{"email": "r_savelev.1974@postgrespro.ru", "phone": "+70198866680"}
0005432267882	B5FD34	4843 795030	VERA OVCHINNIKOVA	{"phone": "+70609660706"}
0005432267883	5E22DC	2447 625850	KIRILL GRIGOREV	{"email": "kirill-grigorev1958@postgrespro.ru", "phone": "+70953097256"}
0005432267884	197F68	8824 345419	LILIYA VASILEVA	{"email": "liliya_vasileva-061972@postgrespro.ru", "phone": "+70852926293"}
0005432267885	197F68	5994 629285	RAISA VLASOVA	{"phone": "+70381476006"}
0005432267886	F9BA8D	1818 448767	ASIYA ARKHIPOVA	{"phone": "+70573307129"}
0005432267887	F9BA8D	7298 221821	RINAT GORBUNOV	{"phone": "+70486058406"}
0005432267888	181CB9	7346 459123	ANATOLIY KOZLOV	{"phone": "+70391732847"}
0005432267889	E9C5FA	6639 223145	VALERIYA MARTYNOVA	{"email": "valeriya.martynova_1976@postgrespro.ru", "phone": "+70893064638"}
0005432267890	E9C5FA	0344 070459	ELENA FEDOROVA	{"email": "fedorovaelena20011981@postgrespro.ru", "phone": "+70296806549"}
0005432267891	C53A47	9587 023033	ALEKSANDR ANDREEV	{"phone": "+70186123413"}
0005432267892	A0310E	8078 677409	ALEKSEY PETROV	{"email": "apetrov.1964@postgrespro.ru", "phone": "+70048362578"}
0005432267893	B91C16	3335 524981	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov-1971@postgrespro.ru", "phone": "+70645196943"}
0005432267894	CB6429	0460 770687	ANGELINA MOISEEVA	{"phone": "+70961170289"}
0005432267895	D8E0D0	9078 317059	ANATOLIY PAVLOV	{"email": "pavlov-a.12061964@postgrespro.ru", "phone": "+70423944610"}
0005432267896	60E172	3267 003278	ANTONINA EGOROVA	{"email": "egorova_a_09111983@postgrespro.ru", "phone": "+70926372891"}
0005432267897	361D0F	5419 722356	VADIM MEDVEDEV	{"phone": "+70815552015"}
0005432267898	361D0F	6517 528586	VALERIY VASILEV	{"email": "v-vasilev.031983@postgrespro.ru", "phone": "+70335153884"}
0005432267899	7D4DC2	6887 159275	ELENA POPOVA	{"email": "elena_popova.1974@postgrespro.ru", "phone": "+70165392120"}
0005432267900	7D4DC2	9633 319180	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov_1978@postgrespro.ru", "phone": "+70662647902"}
0005432267901	0EC1B5	6213 564440	KIRILL ALEKSANDROV	{"phone": "+70873007083"}
0005432267902	741DFC	8546 946180	ANNA VOLKOVA	{"email": "volkovaanna_21071974@postgrespro.ru", "phone": "+70126095558"}
0005432267903	741DFC	2122 288089	SERGEY MOISEEV	{"phone": "+70335638318"}
0005432267904	186A35	1289 895758	ELENA FROLOVA	{"phone": "+70462055905"}
0005432267905	186A35	5855 681975	VALENTINA IVANOVA	{"phone": "+70870651261"}
0005432267906	186A35	7011 557458	DARYA KUDRYASHOVA	{"email": "kudryashovadarya1978@postgrespro.ru", "phone": "+70345889827"}
0005432267907	C4364E	7877 021029	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr061974@postgrespro.ru", "phone": "+70698059290"}
0005432267908	C4364E	7031 698713	VASILIY ZHUKOV	{"phone": "+70996088418"}
0005432267909	9037EE	3717 758778	GALINA TARASOVA	{"phone": "+70783901242"}
0005432267910	FC09A7	3660 296172	ELENA OSIPOVA	{"email": "osipovaelena.091969@postgrespro.ru", "phone": "+70666812569"}
0005432267911	B65457	9089 105203	VERA VLASOVA	{"phone": "+70593176395"}
0005432267912	B65457	5322 785256	ANDREY NIKITIN	{"phone": "+70316811875"}
0005432267913	B65457	8957 425060	ARTEM ORLOV	{"email": "orlovartem.12091966@postgrespro.ru", "phone": "+70901301823"}
0005432267914	9C9553	3763 140807	IRAIDA PETROVA	{"phone": "+70273380635"}
0005432267915	B92E0C	9727 483968	TATYANA FROLOVA	{"phone": "+70395900316"}
0005432267916	7CF897	2700 331861	ARTEM ALEKSANDROV	{"email": "aleksandrov-a07021972@postgrespro.ru", "phone": "+70470796546"}
0005432267917	F8E389	0685 579212	YULIYA POLYAKOVA	{"phone": "+70846200209"}
0005432267918	1A42E1	5390 971975	SERGEY SCHERBAKOV	{"phone": "+70899498580"}
0005432267919	1A42E1	0170 588161	YULIYA KRASNOVA	{"email": "krasnovay.111965@postgrespro.ru", "phone": "+70241643099"}
0005432267920	2D6EF2	5237 547858	ZOYA KONOVALOVA	{"phone": "+70895971277"}
0005432267921	877A3E	5938 925390	KLAVDIYA TIKHONOVA	{"phone": "+70649988529"}
0005432267922	877A3E	6769 104560	ARSENIY SEMENOV	{"phone": "+70635702275"}
0005432267923	476797	8962 831813	VLADIMIR MAKSIMOV	{"phone": "+70306729102"}
0005432267924	279674	5473 666917	VLADIMIR NOVIKOV	{"email": "vladimir_novikov-051970@postgrespro.ru", "phone": "+70074301852"}
0005432267925	279674	3996 453696	TATYANA BARANOVA	{"email": "baranova_t.24081965@postgrespro.ru", "phone": "+70524062179"}
0005432267926	7C21B6	1818 110041	VALENTINA SMIRNOVA	{"phone": "+70568138374"}
0005432267927	7C21B6	5989 206568	EVDOKIYA ANTONOVA	{"email": "antonova.evdokiya09101967@postgrespro.ru", "phone": "+70903568794"}
0005432267928	B82952	4579 549890	VLADIMIR SOKOLOV	{"phone": "+70538554242"}
0005432267929	E6245E	2571 062565	YULIYA DANILOVA	{"phone": "+70899289523"}
0005432267930	1877D2	3600 080299	IRINA GRISHINA	{"phone": "+70894070305"}
0005432267931	1E9878	1080 550872	VALENTINA SIDOROVA	{"email": "sidorovavalentina_05031969@postgrespro.ru", "phone": "+70952136285"}
0005432267932	532063	8144 054041	VLADIMIR BELOV	{"email": "belov_vladimir-041971@postgrespro.ru", "phone": "+70880913149"}
0005432267933	532063	9435 064257	ANDREY VOLKOV	{"email": "volkovandrey-011980@postgrespro.ru", "phone": "+70109857946"}
0005432267934	F77CFB	3323 718883	VALERIY KAZAKOV	{"email": "kazakovvaleriy-20061963@postgrespro.ru", "phone": "+70761425892"}
0005432267935	51D342	1556 091098	TATYANA BOGDANOVA	{"email": "bogdanovat.071971@postgrespro.ru", "phone": "+70140696734"}
0005432267936	028A7C	0745 618802	NINA KOROLEVA	{"phone": "+70308018068"}
0005432267937	EC6131	8148 502570	DMITRIY VASILEV	{"email": "dmitriy_vasilev1970@postgrespro.ru", "phone": "+70330622146"}
0005432267938	CA7A36	5388 057726	LYUBOV KUZNECOVA	{"email": "kuznecovalyubov-27021966@postgrespro.ru", "phone": "+70894537698"}
0005432267939	CA7A36	7528 706384	ALEKSANDRA SCHERBAKOVA	{"phone": "+70490760009"}
0005432267940	F310AE	1297 995248	ILYAS KOZLOV	{"email": "i-kozlov-1968@postgrespro.ru", "phone": "+70041403783"}
0005432267941	47C6B7	3414 629016	NADEZHDA GORBUNOVA	{"phone": "+70198466750"}
0005432267942	07B790	8392 123268	LYUBOV EGOROVA	{"phone": "+70147555562"}
0005432267943	7D5F54	6997 057765	VLADIMIR ISAEV	{"email": "isaev_v18121971@postgrespro.ru", "phone": "+70963385646"}
0005432267944	CB7C91	7788 307492	ELENA KRASNOVA	{"phone": "+70470863310"}
0005432267945	778B7F	5270 690032	LIDIYA VOLKOVA	{"phone": "+70522367322"}
0005432267946	22D1D9	0444 717047	SVETLANA YAKOVLEVA	{"email": "yakovleva-svetlana_1966@postgrespro.ru", "phone": "+70767882260"}
0005432267947	22D1D9	0449 085102	OLEG POPOV	{"email": "oleg-popov_061968@postgrespro.ru", "phone": "+70738795505"}
0005432267948	377079	7090 252031	SERGEY KUZNECOV	{"email": "kuznecov_sergey_21071964@postgrespro.ru", "phone": "+70206533902"}
0005432267949	3A890B	5479 827775	DMITRIY BONDARENKO	{"phone": "+70482224319"}
0005432267950	95E4BF	6674 670825	SOFIYA KUZNECOVA	{"email": "skuznecova-19081967@postgrespro.ru", "phone": "+70417147416"}
0005432267951	06B815	4561 832387	SEMEN ALEKSEEV	{"phone": "+70165880922"}
0005432267952	AFC628	1813 156661	LILIYA LUKYANOVA	{"email": "l.lukyanova.1969@postgrespro.ru", "phone": "+70942974954"}
0005432267953	AFC628	7621 299525	VADIM ABRAMOV	{"phone": "+70753895734"}
0005432267954	AFC628	6137 662438	VALENTINA ORLOVA	{"email": "vorlova.03081969@postgrespro.ru", "phone": "+70233255288"}
0005432267955	F8029A	3588 520747	ELIZAVETA MAKAROVA	{"phone": "+70583346560"}
0005432267956	F9C705	0409 337983	ANATOLIY ROMANOV	{"email": "romanov.a.04011967@postgrespro.ru", "phone": "+70306872590"}
0005432267957	F9C705	7274 951730	ALEKSANDR STEPANOV	{"phone": "+70610575735"}
0005432267958	4BA949	3348 879104	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr.041965@postgrespro.ru", "phone": "+70026003195"}
0005432267959	4BA949	0511 600996	MARINA AKIMOVA	{"phone": "+70951807160"}
0005432267960	4BA949	9139 340921	OLEG KUZNECOV	{"email": "o_kuznecov26071976@postgrespro.ru", "phone": "+70289103488"}
0005432267961	BBB64C	1851 069720	VIKTOR MAKSIMOV	{"phone": "+70826087477"}
0005432267962	51631F	9513 659617	MARINA NOVIKOVA	{"email": "m-novikova_28021973@postgrespro.ru", "phone": "+70914410320"}
0005432267963	7E28FC	0090 082045	MIKHAIL ZAKHAROV	{"email": "zakharovm.03061977@postgrespro.ru", "phone": "+70544485294"}
0005432267964	A37292	2121 332889	GALINA SIDOROVA	{"phone": "+70545753902"}
0005432267965	D6C3D8	1103 423267	NADEZHDA SERGEEVA	{"email": "n_sergeeva1976@postgrespro.ru", "phone": "+70593951129"}
0005432267966	D6C3D8	2452 122670	ELENA ALEKSEEVA	{"email": "elena.alekseeva_1972@postgrespro.ru", "phone": "+70019114715"}
0005432267967	E95ED5	9955 801328	OLGA SOKOLOVA	{"email": "olgasokolova11011965@postgrespro.ru", "phone": "+70694520277"}
0005432267968	EB41A9	4246 245527	ANDREY KRASNOV	{"phone": "+70718295424"}
0005432267969	EB41A9	7908 401309	DANIIL KUZNECOV	{"phone": "+70801337871"}
0005432267970	76DBA3	2890 868557	EGOR FILIPPOV	{"email": "filippov-e.17021971@postgrespro.ru", "phone": "+70984258177"}
0005432267971	181540	2878 523019	EKATERINA POPOVA	{"phone": "+70885872719"}
0005432267972	60553D	1220 274013	ANVAR VOLKOV	{"phone": "+70642573695"}
0005432267973	60553D	9736 041104	VLADIMIR ZHURAVLEV	{"phone": "+70279205456"}
0005432267974	5CFE87	1844 801560	NIKOLAY MIKHAYLOV	{"email": "nikolay-mikhaylov-1969@postgrespro.ru", "phone": "+70515473472"}
0005432267975	57BF22	4389 008134	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay03061980@postgrespro.ru", "phone": "+70874739669"}
0005432267976	511169	1534 663701	EKATERINA KOROLEVA	{"phone": "+70596809237"}
0005432267977	E5B1DA	4189 215673	ANTONINA NESTEROVA	{"phone": "+70595154581"}
0005432267978	FB7D99	0848 205669	EVGENIY RODIONOV	{"phone": "+70419131005"}
0005432267979	78DE27	2822 512622	ANNA SOKOLOVA	{"email": "sokolovaanna.13121974@postgrespro.ru", "phone": "+70351087385"}
0005432267980	78DE27	9961 275266	NADEZHDA PETROVA	{"email": "nadezhda_petrova_1964@postgrespro.ru", "phone": "+70615414647"}
0005432267981	794BFA	8804 808569	STEPAN MOISEEV	{"email": "moiseev-stepan_1973@postgrespro.ru", "phone": "+70717474435"}
0005432267982	83630A	9598 674819	TATYANA KUZNECOVA	{"phone": "+70496593876"}
0005432267983	31C9E7	7748 035918	IGOR SOKOLOV	{"email": "igor_sokolov.071979@postgrespro.ru", "phone": "+70158648926"}
0005432267984	31C9E7	0743 717214	MIKHAIL RODIONOV	{"email": "rodionovmikhail-1966@postgrespro.ru", "phone": "+70768451999"}
0005432267985	A46E9B	0292 921382	OLGA IVANOVA	{"email": "olgaivanova_1969@postgrespro.ru", "phone": "+70006111805"}
0005432267986	A46E9B	7063 501202	GALINA PAVLOVA	{"phone": "+70424098558"}
0005432267987	92B40D	2284 355585	DMITRIY DMITRIEV	{"phone": "+70367536866"}
0005432267988	C5B795	5187 180738	VASILIY ISAEV	{"email": "vasiliy-isaev-01121971@postgrespro.ru", "phone": "+70264173299"}
0005432267989	C1BDED	7563 981099	NIKOLAY VLASOV	{"phone": "+70581893609"}
0005432267990	C72C84	3248 461686	VASILIY MOISEEV	{"email": "moiseevv061966@postgrespro.ru", "phone": "+70299394823"}
0005432267991	A16621	2327 723623	SERGEY POPOV	{"phone": "+70182528833"}
0005432267992	C331B0	5032 568291	KLAVDIYA ORLOVA	{"email": "orlova-k.10111977@postgrespro.ru", "phone": "+70666371695"}
0005432267993	AF5C35	2060 903041	NADEZHDA YAKOVLEVA	{"phone": "+70203205944"}
0005432267994	6E1DBA	8356 420661	IGOR MOROZOV	{"email": "igor-morozov_021966@postgrespro.ru", "phone": "+70124235253"}
0005432267995	6E1DBA	6912 486844	OLGA ALEKSANDROVA	{"phone": "+70971376469"}
0005432267996	6E1DBA	8613 844023	OLEG NOVIKOV	{"email": "oleg.novikov_21021965@postgrespro.ru", "phone": "+70131547830"}
0005432267997	694AB6	3706 001711	DANIIL ALEKSEEV	{"email": "d_alekseev_10051953@postgrespro.ru", "phone": "+70744558443"}
0005432267998	694AB6	6000 266302	ANATOLIY NAZAROV	{"email": "anazarov.1969@postgrespro.ru", "phone": "+70405416195"}
0005432267999	4C9A17	7687 849031	VLADIMIR KULIKOV	{"phone": "+70474860970"}
0005432268000	15CBD6	3171 743223	OLESYA LEBEDEVA	{"phone": "+70887209161"}
0005432268001	15CBD6	9656 119666	MAKSIM ANTONOV	{"email": "maksim-antonov_1971@postgrespro.ru", "phone": "+70052442823"}
0005432268002	4C52A3	4304 726272	ZHANNA GAVRILOVA	{"phone": "+70512368875"}
0005432268003	4C52A3	3938 121040	VLADISLAV YAKOVLEV	{"phone": "+70004127255"}
0005432268004	4C52A3	1092 752400	MARGARITA DENISOVA	{"phone": "+70634167731"}
0005432268005	478717	6520 856920	ANASTASIYA ANTONOVA	{"email": "antonovaa081970@postgrespro.ru", "phone": "+70815246536"}
0005432268006	B7576F	4586 765233	LARISA IVANOVA	{"phone": "+70485062299"}
0005432268007	C4DAD8	6765 720399	MARIYA ISAEVA	{"phone": "+70216927577"}
0005432268008	C4DAD8	1805 857279	MARIYA GERASIMOVA	{"email": "gerasimova.mariya_061967@postgrespro.ru", "phone": "+70029953936"}
0005432268009	E475D6	1179 506035	GALINA PETROVA	{"phone": "+70819006608"}
0005432268010	67E109	4013 365279	NIKITA DAVYDOV	{"phone": "+70365137974"}
0005432268011	D61FA4	8064 331189	MAKSIM GAVRILOV	{"email": "gavrilov.maksim_1962@postgrespro.ru", "phone": "+70819464262"}
0005432268012	D61FA4	1014 626223	VIKTOR ANDREEV	{"phone": "+70118964857"}
0005432268013	9D354C	8874 862831	NIKOLAY KARPOV	{"phone": "+70919061069"}
0005432268014	9D354C	1531 886809	YAROSLAV GERASIMOV	{"phone": "+70885425775"}
0005432268015	4DD7BF	8565 111119	DMITRIY GRIGOREV	{"email": "dmitriy_grigorev_25011969@postgrespro.ru", "phone": "+70817044563"}
0005432268016	0AC1AA	4247 815746	NINA KOROLEVA	{"phone": "+70601437935"}
0005432268017	0AC1AA	0403 064808	VYACHESLAV GRIGOREV	{"phone": "+70365335614"}
0005432268018	0AC1AA	8035 957451	SERGEY SCHERBAKOV	{"phone": "+70814030413"}
0005432268019	F07CDF	7070 242331	ANASTASIYA MOROZOVA	{"phone": "+70274244418"}
0005432268020	18C83F	2643 916659	MAKSIM ANDREEV	{"phone": "+70877105069"}
0005432268021	F63830	2901 881459	ANTONINA MAKAROVA	{"email": "makarovaantonina071966@postgrespro.ru", "phone": "+70070404115"}
0005432268022	6CC200	7024 271894	VERA KOROLEVA	{"email": "vera.koroleva07011980@postgrespro.ru", "phone": "+70549437501"}
0005432268023	B5FA35	1589 450783	SVETLANA ISAEVA	{"email": "isaevas_07041967@postgrespro.ru", "phone": "+70459822050"}
0005432268024	61FD23	0179 630000	ALEKSEY KARPOV	{"phone": "+70922458215"}
0005432268025	61FD23	4306 657217	MARIYA ZHURAVLEVA	{"phone": "+70243796378"}
0005432268026	0FFF1C	3244 896148	OLGA MELNIKOVA	{"email": "melnikova_o-1971@postgrespro.ru", "phone": "+70171603742"}
0005432268027	8921EB	2694 547321	TATYANA ROMANOVA	{"email": "romanova_t.22041963@postgrespro.ru", "phone": "+70310095707"}
0005432268028	0DCE7E	8468 698311	ANDREY KUZNECOV	{"phone": "+70719069909"}
0005432268029	C6F58C	1579 679411	EVGENIY MAKSIMOV	{"phone": "+70409641766"}
0005432268030	7CD91F	1167 266526	VIKTOR ORLOV	{"phone": "+70492070696"}
0005432268031	B1365A	3983 635026	MARIYA ARKHIPOVA	{"email": "arkhipova.m_22101970@postgrespro.ru", "phone": "+70176536351"}
0005432268032	B1365A	9215 840336	VIKTOR ANDREEV	{"phone": "+70060406447"}
0005432268033	4BCE94	8160 002939	KIRILL NIKITIN	{"phone": "+70528327747"}
0005432268034	3AC05A	7466 332105	TAMARA NIKOLAEVA	{"email": "nikolaeva_tamara_09021979@postgrespro.ru", "phone": "+70502030428"}
0005432268035	3C170F	2318 542733	YAKOV MOROZOV	{"email": "yakov.morozov_1969@postgrespro.ru", "phone": "+70706286144"}
0005432268036	C72EC9	8079 750281	SERGEY IVANOV	{"phone": "+70918980965"}
0005432268037	3DD5A0	3892 573094	NINA FILIPPOVA	{"phone": "+70991507502"}
0005432268038	3DD5A0	9686 882167	DENIS NOVIKOV	{"phone": "+70805786229"}
0005432268039	C42999	1323 684708	PETR TARASOV	{"phone": "+70889637685"}
0005432268040	C42999	6911 344305	IRINA POLYAKOVA	{"email": "irina_polyakova101963@postgrespro.ru", "phone": "+70160589723"}
0005432268041	1F083B	3471 337833	ZINAIDA MARTYNOVA	{"email": "martynova_z03081970@postgrespro.ru", "phone": "+70951559436"}
0005432268042	1F083B	3917 564565	TATYANA YUDINA	{"phone": "+70416575351"}
0005432268043	1F083B	0757 529054	TATYANA OVCHINNIKOVA	{"phone": "+70039384653"}
0005432268044	0CCD43	2928 031286	GALINA EGOROVA	{"phone": "+70309251333"}
0005432268045	577790	3101 135298	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev_081980@postgrespro.ru", "phone": "+70501186681"}
0005432268046	96072F	3801 442905	IRINA ANDREEVA	{"email": "andreeva_irina.1964@postgrespro.ru", "phone": "+70629233488"}
0005432268047	C7E65E	6262 101205	TATYANA TARASOVA	{"email": "ttarasova1977@postgrespro.ru", "phone": "+70794882763"}
0005432268048	C7E65E	0458 519009	ELENA FILATOVA	{"email": "elena_filatova_16121976@postgrespro.ru", "phone": "+70135524417"}
0005432268049	1EAE3B	3822 767878	GENNADIY GUSEV	{"email": "ggusev-1971@postgrespro.ru", "phone": "+70148398213"}
0005432268050	5F947B	7380 235350	DMITRIY AFANASEV	{"email": "dmitriy-afanasev.041976@postgrespro.ru", "phone": "+70246662725"}
0005432268051	5F947B	2471 564124	VLADIMIR OSIPOV	{"email": "osipov.vladimir-08071981@postgrespro.ru", "phone": "+70189442124"}
0005432268052	4C8788	1980 141807	OLESYA BELOVA	{"email": "belova.o071973@postgrespro.ru", "phone": "+70403534451"}
0005432268053	4C8788	4985 040226	OLGA SIDOROVA	{"phone": "+70790489057"}
0005432268054	4C8788	7423 299652	ELENA EGOROVA	{"email": "egorovaelena-27121967@postgrespro.ru", "phone": "+70113070611"}
0005432268055	D7FBEC	9751 126922	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev-16091982@postgrespro.ru", "phone": "+70748841261"}
0005432268056	D7FBEC	4269 950812	NADEZHDA POLYAKOVA	{"phone": "+70205383312"}
0005432268057	0A16B1	3074 936009	DMITRIY MOROZOV	{"email": "dmorozov_13121977@postgrespro.ru", "phone": "+70389841385"}
0005432268058	401883	2997 061863	OLEG SCHERBAKOV	{"phone": "+70687505035"}
0005432268059	BC3321	4461 091644	SERGEY AFANASEV	{"phone": "+70556940020"}
0005432268060	517F50	0915 987900	NINA KAZAKOVA	{"email": "nkazakova_071971@postgrespro.ru", "phone": "+70209790366"}
0005432268061	517F50	6364 499394	SERGEY MIRONOV	{"phone": "+70782958009"}
0005432268062	3F7C48	6529 876837	GALINA ILINA	{"phone": "+70890338496"}
0005432268063	3F7C48	4511 945276	ZINAIDA VASILEVA	{"phone": "+70640288451"}
0005432268064	143E80	8053 978230	GALINA KUZNECOVA	{"phone": "+70927655439"}
0005432268065	3A20EB	7729 857894	ANDREY ANDREEV	{"email": "andreev_a_20101969@postgrespro.ru", "phone": "+70204537889"}
0005432268066	3A20EB	8171 764982	MAKAR SOROKIN	{"email": "makar_sorokin03111977@postgrespro.ru", "phone": "+70333432570"}
0005432268067	7194E3	1503 019667	ANNA ORLOVA	{"email": "anna-orlova_1964@postgrespro.ru", "phone": "+70683033022"}
0005432268068	55E0DE	1084 599847	EVGENIYA SAVELEVA	{"phone": "+70630046236"}
0005432268069	1A366D	7532 254368	NINA STEPANOVA	{"email": "ninastepanova.081968@postgrespro.ru", "phone": "+70012651891"}
0005432268070	7F9B8B	6190 470352	VERA TARASOVA	{"email": "v-tarasova-031967@postgrespro.ru", "phone": "+70872953260"}
0005432268071	7F9B8B	0545 463129	IRINA KUZNECOVA	{"phone": "+70266216482"}
0005432268072	56AA58	6347 441462	NATALYA DMITRIEVA	{"phone": "+70208799437"}
0005432268073	56AA58	5845 935626	VALENTINA VOLKOVA	{"phone": "+70531853376"}
0005432268074	C221A0	0037 244109	RAISA DENISOVA	{"email": "r_denisova-101977@postgrespro.ru", "phone": "+70652506687"}
0005432268075	F7EB20	3241 241625	NADEZHDA MELNIKOVA	{"email": "melnikovan_041953@postgrespro.ru", "phone": "+70458990005"}
0005432268076	5A0702	2769 696457	VALENTINA ERMAKOVA	{"phone": "+70694221153"}
0005432268077	5A0702	2030 020953	ALEKSANDRA KOZLOVA	{"phone": "+70875274985"}
0005432268078	9F4E19	1863 426575	PAVEL MIKHAYLOV	{"email": "pavel-mikhaylov_1971@postgrespro.ru", "phone": "+70546549017"}
0005432268079	9F4E19	4675 765007	VITALIY GERASIMOV	{"email": "gerasimov-vitaliy.071975@postgrespro.ru", "phone": "+70973987099"}
0005432268080	05D219	2819 660584	YURIY SHEVCHENKO	{"email": "yuriy.shevchenko-1968@postgrespro.ru", "phone": "+70610487631"}
0005432268081	D39E94	0419 600945	YAKOV NIKOLAEV	{"phone": "+70649978528"}
0005432268082	8B4C20	2799 563063	IGOR SIDOROV	{"phone": "+70963543658"}
0005432268083	423969	8217 481618	ALEKSEY VASILEV	{"email": "vasilev-a31071973@postgrespro.ru", "phone": "+70195478776"}
0005432268084	423969	0189 837759	VIKTOR MOROZOV	{"phone": "+70310499740"}
0005432268085	7962C9	2642 786052	VLADIMIR KARPOV	{"phone": "+70235971365"}
0005432268086	00CF04	3640 378460	EKATERINA YAKOVLEVA	{"email": "yakovlevae-021960@postgrespro.ru", "phone": "+70072684177"}
0005432268087	A33E8A	9377 625531	LYUDMILA NESTEROVA	{"email": "l_nesterova_1958@postgrespro.ru", "phone": "+70550892810"}
0005432268088	A33E8A	8339 438795	IRAIDA FILIPPOVA	{"email": "i_filippova_121973@postgrespro.ru", "phone": "+70394026140"}
0005432268089	758782	7865 306377	TATYANA BORISOVA	{"email": "borisovatatyana21071967@postgrespro.ru", "phone": "+70365190748"}
0005432269445	C68456	7489 116249	DMITRIY ABRAMOV	{"email": "d.abramov_31081977@postgrespro.ru", "phone": "+70736739208"}
0005432277663	CE2E4D	5647 708214	ANASTASIYA IVANOVA	{"phone": "+70059979050"}
0005432269446	2C7F87	9293 451259	VYACHESLAV FEDOROV	{"email": "fedorov.vyacheslav_1972@postgrespro.ru", "phone": "+70456299237"}
0005432269447	2C7F87	5293 314610	IGOR VASILEV	{"email": "vasilev.igor-051966@postgrespro.ru", "phone": "+70515862569"}
0005432269448	53B39F	1053 606169	ROMAN MEDVEDEV	{"email": "r_medvedev07021967@postgrespro.ru", "phone": "+70522485310"}
0005432269449	53B39F	0234 834856	IRINA MAKSIMOVA	{"email": "irinamaksimova_021970@postgrespro.ru", "phone": "+70301727176"}
0005432269450	C8C319	6894 776227	IGOR DENISOV	{"phone": "+70678354767"}
0005432269451	7EDEA5	6481 329168	GALINA BELOVA	{"phone": "+70874780980"}
0005432269452	BED304	4952 854705	NATALYA MIRONOVA	{"phone": "+70031458859"}
0005432269453	BED304	8191 254148	ILYA SOLOVEV	{"phone": "+70818854713"}
0005432269454	BED304	6148 029350	LYUBOV VLASOVA	{"phone": "+70890078560"}
0005432269455	322F24	2812 184455	SVETLANA KUDRYASHOVA	{"email": "kudryashova.s.03101972@postgrespro.ru", "phone": "+70687587732"}
0005432269456	322F24	3981 225068	OLGA IVANOVA	{"phone": "+70816702079"}
0005432269457	C0E5CA	0223 026058	YURIY FILIPPOV	{"email": "yuriy_filippov26061972@postgrespro.ru", "phone": "+70266211620"}
0005432269458	C0E5CA	1131 171425	VIKTOR KRASNOV	{"phone": "+70504882542"}
0005432269459	FF1058	3700 416965	MIKHAIL VOROBEV	{"email": "vorobev_m_05041968@postgrespro.ru", "phone": "+70866032244"}
0005432269460	A08336	3603 628465	NINA EFIMOVA	{"phone": "+70972261059"}
0005432269461	1AFC18	5024 671559	NATALYA GERASIMOVA	{"email": "gerasimovanatalya-1974@postgrespro.ru", "phone": "+70101144997"}
0005432269462	1AFC18	4723 701721	ALEKSANDR ALEKSEEV	{"email": "alekseev-a1967@postgrespro.ru", "phone": "+70355856669"}
0005432269463	A8E6C5	4650 238319	VIKTORIYA SAVELEVA	{"phone": "+70733138485"}
0005432269464	977E74	4453 446150	EKATERINA OSIPOVA	{"email": "ekaterina-osipova1971@postgrespro.ru", "phone": "+70901246353"}
0005432269465	91D73E	5560 305555	NATALIYA SAVELEVA	{"email": "nsaveleva_041969@postgrespro.ru", "phone": "+70955947528"}
0005432269466	63B4C4	9887 933235	GALINA VASILEVA	{"email": "g.vasileva-20041973@postgrespro.ru", "phone": "+70485461374"}
0005432269467	E4F0A4	2531 285660	VALENTINA SERGEEVA	{"phone": "+70727159321"}
0005432269468	1817FD	3919 614009	PETR NAUMOV	{"phone": "+70597015062"}
0005432269469	70427A	9993 790871	ARTEM TIMOFEEV	{"phone": "+70887102465"}
0005432269470	70427A	6480 763661	IVAN KUZNECOV	{"phone": "+70511547032"}
0005432269471	440332	2016 998852	MIKHAIL SOROKIN	{"phone": "+70600599603"}
0005432269472	F94129	2101 810427	IVAN SOROKIN	{"email": "sorokin-ivan.1965@postgrespro.ru", "phone": "+70813111077"}
0005432269473	790BE1	0377 465706	OLGA ROMANOVA	{"phone": "+70865226942"}
0005432269474	E3E8DB	3264 494120	VALENTINA OVCHINNIKOVA	{"phone": "+70712829016"}
0005432269475	01FC7A	9651 400157	ALSU POLYAKOVA	{"email": "polyakova_a091972@postgrespro.ru", "phone": "+70126005469"}
0005432269476	D79AAA	9490 148711	TATYANA MOISEEVA	{"email": "moiseeva-t_1976@postgrespro.ru", "phone": "+70070097979"}
0005432269477	CCCFC3	4982 955323	GALINA AKIMOVA	{"email": "galina_akimova.021978@postgrespro.ru", "phone": "+70936080774"}
0005432269478	900B4F	2869 246709	IVAN VLASOV	{"email": "ivanvlasov_031975@postgrespro.ru", "phone": "+70513625794"}
0005432269479	A42BD0	2956 095098	DMITRIY FILIPPOV	{"email": "filippov_d-22121967@postgrespro.ru", "phone": "+70241078098"}
0005432269480	E36C99	7069 154758	SERGEY TIKHONOV	{"email": "stikhonov.1976@postgrespro.ru", "phone": "+70863443880"}
0005432269481	1E3C25	0709 018137	SVETLANA KUZNECOVA	{"phone": "+70729423558"}
0005432269482	1E3C25	1983 214497	IGOR DAVYDOV	{"email": "igor.davydov1977@postgrespro.ru", "phone": "+70870478190"}
0005432269483	1F5933	9450 381551	TATYANA RODIONOVA	{"email": "tatyana_rodionova09021971@postgrespro.ru", "phone": "+70413498921"}
0005432269484	34B377	3270 856383	ANTON ZHUKOV	{"email": "zhukovanton.1974@postgrespro.ru", "phone": "+70943615296"}
0005432269485	89C437	3361 303960	YURIY KUZNECOV	{"phone": "+70234267807"}
0005432269486	A889AA	9398 706747	ANNA BORISOVA	{"email": "borisova_anna_24071971@postgrespro.ru", "phone": "+70813140583"}
0005432269487	A889AA	6353 226301	NATALYA ANISIMOVA	{"phone": "+70340128860"}
0005432269488	67D9EC	1563 474707	ALEKSANDR SEMENOV	{"phone": "+70237147761"}
0005432269489	1CFFD3	6427 868361	VLADIMIR IVANOV	{"email": "ivanov-v21011969@postgrespro.ru", "phone": "+70028460828"}
0005432269490	176422	6061 821300	MARIYA NAUMOVA	{"phone": "+70891777337"}
0005432269491	729D81	8200 609164	EVGENIY ZAYCEV	{"email": "zaycev_evgeniy.1968@postgrespro.ru", "phone": "+70053781226"}
0005432269492	EAEC28	1040 916328	YANA NESTEROVA	{"email": "y_nesterova24081976@postgrespro.ru", "phone": "+70510491595"}
0005432269493	11A91C	1288 046129	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir_1966@postgrespro.ru", "phone": "+70227940210"}
0005432269494	11A91C	7078 210512	NIKOLAY BORISOV	{"phone": "+70101784600"}
0005432269495	242580	5477 243083	ANTON ILIN	{"email": "ilin_anton.101977@postgrespro.ru", "phone": "+70540779953"}
0005432269496	FC5E9B	6086 620564	ROZA YUDINA	{"email": "ryudina_091965@postgrespro.ru", "phone": "+70696032781"}
0005432269497	FC5E9B	5574 269497	NINA DAVYDOVA	{"email": "davydovan.25101962@postgrespro.ru", "phone": "+70720037082"}
0005432269498	FC5E9B	6516 378843	DMITRIY MOISEEV	{"email": "moiseevd051980@postgrespro.ru", "phone": "+70773041412"}
0005432269499	B90DC2	9807 621260	ANASTASIYA KUZMINA	{"phone": "+70379781695"}
0005432269500	15BE3A	1762 374969	LYUDMILA CHERNOVA	{"phone": "+70322677658"}
0005432269501	15BE3A	3207 684332	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a-051976@postgrespro.ru", "phone": "+70060568075"}
0005432269502	169CA9	9400 707797	MARINA SOKOLOVA	{"phone": "+70378764708"}
0005432269503	F95307	4359 143244	ALEKSEY OSIPOV	{"phone": "+70721650857"}
0005432269504	F95307	5162 908613	ALEKSEY PETROV	{"phone": "+70279421337"}
0005432269505	F95307	4596 073842	ANDREY ROMANOV	{"email": "a-romanov.08021974@postgrespro.ru", "phone": "+70139624643"}
0005432269506	059794	6447 629231	LYUDMILA MAKSIMOVA	{"email": "maksimovalyudmila.021986@postgrespro.ru", "phone": "+70009350376"}
0005432269507	F82B03	1637 109124	IRINA BARANOVA	{"email": "baranova_i_031972@postgrespro.ru", "phone": "+70647968815"}
0005432269508	E8884D	1376 936782	PETR GERASIMOV	{"email": "petr_gerasimov-03051976@postgrespro.ru", "phone": "+70291542274"}
0005432269509	C5E7E1	9535 502604	LYUDMILA GRISHINA	{"phone": "+70332124279"}
0005432269510	C5E7E1	5278 722841	TAMARA VASILEVA	{"phone": "+70869972322"}
0005432269511	E05C73	4237 772621	OLGA KUZNECOVA	{"phone": "+70086466377"}
0005432269512	654DB6	9264 366096	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay_09111968@postgrespro.ru", "phone": "+70046118402"}
0005432269513	7FC6A6	2647 235820	OLGA KULIKOVA	{"email": "o_kulikova-1970@postgrespro.ru", "phone": "+70281633190"}
0005432269514	4E431B	6911 042146	EGOR ALEKSANDROV	{"phone": "+70111687058"}
0005432269515	E8054E	1094 027572	OLGA MAKSIMOVA	{"phone": "+70755512881"}
0005432269516	545B28	2071 847558	VLADIMIR NOVIKOV	{"phone": "+70826821900"}
0005432269517	ACDB4A	4324 792976	EKATERINA ALEKSANDROVA	{"email": "aleksandrovaekaterina-21031972@postgrespro.ru", "phone": "+70106215090"}
0005432269518	E922BE	2767 297781	ANNA KUZNECOVA	{"phone": "+70720278124"}
0005432269519	BE74C6	1096 104986	ZULFIYA IVANOVA	{"phone": "+70088454262"}
0005432269520	900507	9200 605246	SERGEY IVANOV	{"phone": "+70637731570"}
0005432269521	19FD49	5670 131734	ALEKSANDR ALEKSEEV	{"phone": "+70857163737"}
0005432269522	C558C2	2405 793352	MARIYA SOLOVEVA	{"phone": "+70153956304"}
0005432269523	C7792D	9553 865921	OLGA KAZAKOVA	{"email": "kazakovao_111989@postgrespro.ru", "phone": "+70018345676"}
0005432269524	A118D8	6973 958367	SERGEY BORISOV	{"phone": "+70770247588"}
0005432269525	A118D8	3072 300055	KSENIYA PETROVA	{"phone": "+70173392068"}
0005432269526	497783	1746 131315	IRINA NESTEROVA	{"phone": "+70562011010"}
0005432269527	BAD6C3	8021 280743	YURIY VASILEV	{"email": "vasilev.y081964@postgrespro.ru", "phone": "+70661845471"}
0005432269528	2A17C9	4026 736528	GRIGORIY ZAKHAROV	{"email": "grigoriy_zakharov_061955@postgrespro.ru", "phone": "+70532578615"}
0005432269529	2A17C9	9554 443824	NINA NIKITINA	{"email": "n-nikitina.1966@postgrespro.ru", "phone": "+70322763151"}
0005432269530	D329E1	8247 445677	ROZALIYA MELNIKOVA	{"email": "r-melnikova1965@postgrespro.ru", "phone": "+70045453871"}
0005432269531	1787F7	1989 985312	ELENA POPOVA	{"phone": "+70022149601"}
0005432269532	1787F7	4338 995935	ANASTASIYA KUZNECOVA	{"email": "kuznecova_anastasiya1980@postgrespro.ru", "phone": "+70785658401"}
0005432269533	C62DE0	1958 376512	LYUBOV KOLESNIKOVA	{"phone": "+70162719644"}
0005432269534	33A270	2284 842128	IVAN DENISOV	{"email": "denisov_ivan_16041976@postgrespro.ru", "phone": "+70273606692"}
0005432269535	C09E8F	0232 720751	ALEKSEY KISELEV	{"phone": "+70456042625"}
0005432269536	4A48C4	9792 733245	SVETLANA MELNIKOVA	{"email": "melnikova.svetlana.22041978@postgrespro.ru", "phone": "+70295601536"}
0005432269537	4A48C4	2537 409727	GALINA SIDOROVA	{"email": "sidorova.g.011969@postgrespro.ru", "phone": "+70195778369"}
0005432269538	2ABA41	9200 130141	ANDREY FOMIN	{"email": "a.fomin101975@postgrespro.ru", "phone": "+70295528821"}
0005432269539	2ABA41	1794 534822	GALINA SIDOROVA	{"phone": "+70904302102"}
0005432269540	F565DC	5342 624669	VALENTINA ALEKSEEVA	{"phone": "+70493133926"}
0005432269541	77A168	8794 696905	EKATERINA FOMINA	{"phone": "+70180009502"}
0005432269542	77A168	5833 973744	ANASTASIYA YUDINA	{"email": "a.yudina-07021963@postgrespro.ru", "phone": "+70505767562"}
0005432269543	563D0C	4668 060006	ALEKSEY GUSEV	{"phone": "+70050657474"}
0005432269544	563D0C	7226 177794	ROSTISLAV SHEVCHENKO	{"phone": "+70205895652"}
0005432269545	2CFCE1	3152 758383	MAKSIM MARTYNOV	{"phone": "+70715179145"}
0005432269546	2CFCE1	6034 087381	IRINA IVANOVA	{"phone": "+70992872302"}
0005432269547	65546B	6828 719032	VIKTORIYA KUZNECOVA	{"email": "kuznecova.v1971@postgrespro.ru", "phone": "+70365589610"}
0005432269548	65546B	0171 259593	TATYANA SEMENOVA	{"email": "semenova.tatyana_121961@postgrespro.ru", "phone": "+70204467616"}
0005432269549	62DC2E	6592 425711	ANNA KUZNECOVA	{"email": "kuznecova-anna-09031962@postgrespro.ru", "phone": "+70982025382"}
0005432269550	54D467	0195 990050	ALEKSANDRA ANDREEVA	{"phone": "+70872780397"}
0005432269551	54D467	3482 546847	DMITRIY KOZLOV	{"email": "dkozlov.14071978@postgrespro.ru", "phone": "+70111895103"}
0005432269552	CC1A7C	3566 455374	ALEKSANDR EGOROV	{"phone": "+70024150677"}
0005432269553	CC1A7C	7127 128651	KIRILL ILIN	{"phone": "+70234118090"}
0005432269554	D99C69	3281 841425	OLGA KOZLOVA	{"email": "kozlovao.031969@postgrespro.ru", "phone": "+70921240374"}
0005432269555	435A7C	6418 001189	MARIYA MATVEEVA	{"email": "mariya.matveeva_061966@postgrespro.ru", "phone": "+70046954744"}
0005432269556	22131E	2661 196173	ANASTASIYA GORBUNOVA	{"phone": "+70127318402"}
0005432269557	BD63B9	6380 112003	ALEKSEY MIKHAYLOV	{"email": "a.mikhaylov-011981@postgrespro.ru", "phone": "+70410137192"}
0005432269558	BD63B9	2599 381209	NINA PAVLOVA	{"email": "pavlovanina-11111971@postgrespro.ru", "phone": "+70954627716"}
0005432269559	23FB80	5831 358979	OKSANA CHERNOVA	{"email": "ochernova09121976@postgrespro.ru", "phone": "+70726529478"}
0005432269560	9E38BB	0816 236131	LYUBOV NOVIKOVA	{"phone": "+70973134332"}
0005432269561	2780EB	1065 382903	NINA SOLOVEVA	{"phone": "+70258510178"}
0005432269562	17369E	4610 213878	DENIS BELOV	{"phone": "+70504979108"}
0005432269563	C32777	7798 213939	MIKHAIL MELNIKOV	{"email": "m-melnikov.07061985@postgrespro.ru", "phone": "+70134328424"}
0005432269564	98BB99	5559 013890	OKSANA ILINA	{"email": "ilinaoksana25031973@postgrespro.ru", "phone": "+70279210569"}
0005432269565	F32BDD	8945 374970	LIDIYA NIKITINA	{"phone": "+70700887106"}
0005432269566	F5C183	6554 900943	OLESYA TIKHONOVA	{"email": "o-tikhonova.031983@postgrespro.ru", "phone": "+70442984733"}
0005432269567	8AEA49	0182 045319	SERGEY MELNIKOV	{"email": "s-melnikov-1972@postgrespro.ru", "phone": "+70776807178"}
0005432269568	CEF2EF	3709 353571	NATALYA OSIPOVA	{"phone": "+70784640041"}
0005432269569	CEF2EF	7203 076749	ELENA BORISOVA	{"email": "elenaborisova-021981@postgrespro.ru", "phone": "+70035634604"}
0005432269570	97C2F3	6479 625006	VERA VASILEVA	{"email": "vasilevavera_051972@postgrespro.ru", "phone": "+70167640280"}
0005432269571	97C2F3	6338 984781	ANATOLIY NOVIKOV	{"email": "novikovanatoliy081985@postgrespro.ru", "phone": "+70431175053"}
0005432269572	A12437	5547 082100	NATALYA POPOVA	{"phone": "+70944467324"}
0005432269573	54B168	8370 242968	SVETLANA MATVEEVA	{"email": "svetlana_matveeva-25101980@postgrespro.ru", "phone": "+70373782616"}
0005432269574	8B91DB	6751 347821	TATYANA PETROVA	{"phone": "+70169112161"}
0005432269575	2CBD48	4219 994203	NATALIYA KONOVALOVA	{"phone": "+70603800718"}
0005432269576	49E5B9	2865 109902	LYUDMILA ALEKSEEVA	{"phone": "+70219646274"}
0005432271039	B5BF63	4143 881909	FARID ANDREEV	{"phone": "+70688430372"}
0005432270954	DA7E74	3030 401789	SERGEY DENISOV	{"phone": "+70695998501"}
0005432270955	E8013E	2928 984372	OLGA KISELEVA	{"phone": "+70618817440"}
0005432270956	E8013E	4227 439132	VALERIY KOZLOV	{"email": "v-kozlov.15051983@postgrespro.ru", "phone": "+70496077478"}
0005432270957	990CE3	0063 380587	ALEKSANDR VOLKOV	{"email": "volkov-a.111978@postgrespro.ru", "phone": "+70398683411"}
0005432270958	683555	8470 829318	YURIY BORISOV	{"phone": "+70935349641"}
0005432270959	683555	7576 078229	ANATOLIY ANTONOV	{"email": "anatoliyantonov101988@postgrespro.ru", "phone": "+70305689226"}
0005432270960	4A4A62	6940 648606	ANNA AKIMOVA	{"email": "akimova-anna.121967@postgrespro.ru", "phone": "+70845829922"}
0005432270961	4A4A62	6503 005254	SHAMIL ALEKSANDROV	{"phone": "+70243271091"}
0005432270962	9415E3	0538 191074	DMITRIY KUZNECOV	{"phone": "+70736185255"}
0005432270963	694F33	2606 410419	SERGEY SMIRNOV	{"phone": "+70801938244"}
0005432270964	ADBE23	8209 800370	EKATERINA MIRONOVA	{"phone": "+70157487170"}
0005432270965	ADBE23	2544 238140	MARGARITA FEDOROVA	{"phone": "+70188409132"}
0005432270966	42E94B	4199 005574	POLINA KARPOVA	{"email": "p.karpova-07071968@postgrespro.ru", "phone": "+70749537287"}
0005432270967	A3E3AB	8388 909680	KONSTANTIN ZAKHAROV	{"phone": "+70673722685"}
0005432270968	51633B	7172 415407	VALENTINA ABRAMOVA	{"phone": "+70351385587"}
0005432270969	51633B	8413 434631	LYUBOV KOLESNIKOVA	{"email": "kolesnikova_l-27011973@postgrespro.ru", "phone": "+70601770269"}
0005432270970	F21B15	9672 958381	VLADIMIR VOROBEV	{"email": "vorobev_vladimir.21081970@postgrespro.ru", "phone": "+70620754731"}
0005432270971	27819A	6689 218729	VLADISLAV GRIGOREV	{"phone": "+70150097002"}
0005432270972	27819A	9976 125917	OLEG GRIGOREV	{"email": "oleg_grigorev061967@postgrespro.ru", "phone": "+70596119589"}
0005432270973	F5B2A1	3308 987620	SVETLANA BORISOVA	{"phone": "+70007149694"}
0005432270974	686650	6761 891685	VITALIY MIRONOV	{"email": "v.mironov-081969@postgrespro.ru", "phone": "+70926627852"}
0005432270975	059A3A	0035 355465	ARINA VLASOVA	{"email": "a-vlasova_111969@postgrespro.ru", "phone": "+70654601591"}
0005432270976	059A3A	3071 145475	TATYANA KAZAKOVA	{"email": "kazakova_tatyana_061973@postgrespro.ru", "phone": "+70146419469"}
0005432270977	0CFC6E	3012 446597	TATYANA ZAKHAROVA	{"phone": "+70446070442"}
0005432270978	8A729D	7854 677203	ALEKSANDR PAVLOV	{"email": "apavlov-23071979@postgrespro.ru", "phone": "+70263861850"}
0005432270979	59309C	9974 788755	ZINAIDA YUDINA	{"phone": "+70943179971"}
0005432270980	59309C	0761 139667	LYUDMILA PAVLOVA	{"email": "pavlova.lyudmila.1954@postgrespro.ru", "phone": "+70372158384"}
0005432270981	F23F61	3179 575482	OLGA TIMOFEEVA	{"email": "timofeeva.olga29101973@postgrespro.ru", "phone": "+70520203789"}
0005432270982	C65500	1170 076475	ALEKSEY IVANOV	{"email": "ivanov_a-041985@postgrespro.ru", "phone": "+70967796033"}
0005432270983	DBA3B2	5201 803369	LYUDMILA ANTONOVA	{"email": "lyudmilaantonova-1985@postgrespro.ru", "phone": "+70480839000"}
0005432270984	DBA3B2	5748 535335	ALENA KOZLOVA	{"phone": "+70411142960"}
0005432270985	16C9A5	3107 719268	DMITRIY STEPANOV	{"phone": "+70380724797"}
0005432270986	C273A0	4473 602274	OLEG NAUMOV	{"phone": "+70368190120"}
0005432270987	810DA5	2803 525990	VALENTINA KOLESNIKOVA	{"email": "kolesnikova-valentina-22011985@postgrespro.ru", "phone": "+70951428020"}
0005432270988	0DA02F	5505 793054	SVETLANA SAVELEVA	{"phone": "+70085040836"}
0005432270989	AB5DA8	7772 873809	FAIL SEMENOV	{"phone": "+70712896626"}
0005432270990	AB5DA8	9355 510500	OLGA ROMANOVA	{"email": "o.romanova.111975@postgrespro.ru", "phone": "+70125670363"}
0005432270991	445315	0232 770120	ALEKSANDR MARTYNOV	{"email": "aleksandr-martynov.1964@postgrespro.ru", "phone": "+70006360557"}
0005432270992	6146FA	8862 344696	ANATOLIY KULIKOV	{"phone": "+70405308811"}
0005432270993	43166A	9029 244783	VASILIY POPOV	{"email": "popovvasiliy101963@postgrespro.ru", "phone": "+70602906166"}
0005432270994	43166A	8347 813833	MIKHAIL YAKOVLEV	{"email": "yakovlevmikhail011975@postgrespro.ru", "phone": "+70287571613"}
0005432270995	54AC04	4650 720419	ANDREY MATVEEV	{"phone": "+70811938953"}
0005432270996	B10AC4	3252 743268	ANASTASIYA ALEKSEEVA	{"phone": "+70863596030"}
0005432270997	74D9B2	6952 677519	ANDREY VASILEV	{"email": "andrey.vasilev12061979@postgrespro.ru", "phone": "+70197649317"}
0005432270998	74D9B2	4087 891322	YULIYA TITOVA	{"email": "yuliya-titova_03031972@postgrespro.ru", "phone": "+70851708015"}
0005432270999	CFFF2E	4493 060120	PAVEL KUZMIN	{"email": "kuzmin.pavel.03021966@postgrespro.ru", "phone": "+70364865341"}
0005432271000	8A3F63	5421 814477	NADEZHDA KISELEVA	{"email": "kiseleva.nadezhda-27011971@postgrespro.ru", "phone": "+70402905947"}
0005432271001	332972	5634 417941	TATYANA EFIMOVA	{"email": "efimovat.1966@postgrespro.ru", "phone": "+70963254566"}
0005432271002	332972	2765 664240	YURIY IVANOV	{"email": "ivanovyuriy_101983@postgrespro.ru", "phone": "+70128956574"}
0005432271003	3D6B70	1175 266685	RAFAIL EGOROV	{"email": "egorov_r1954@postgrespro.ru", "phone": "+70709855649"}
0005432271004	19013C	9920 333614	GALINA AKIMOVA	{"email": "akimova.galina.1967@postgrespro.ru", "phone": "+70057660036"}
0005432271005	92974A	9848 928846	IRINA IVANOVA	{"email": "iivanova.051982@postgrespro.ru", "phone": "+70813804352"}
0005432271006	004B5C	8134 633783	VITALIY MOISEEV	{"phone": "+70642914888"}
0005432271007	CC940B	5679 624120	NINA ZAYCEVA	{"phone": "+70605077884"}
0005432271008	244F07	7962 853891	EVGENIY MIRONOV	{"phone": "+70219404445"}
0005432271009	244F07	5430 715152	PAVEL GAVRILOV	{"email": "p-gavrilov-06031973@postgrespro.ru", "phone": "+70909222499"}
0005432271010	6F1A5A	2497 673919	ILDAR PAVLOV	{"email": "ildar_pavlov_1964@postgrespro.ru", "phone": "+70106126564"}
0005432271011	156DCF	3481 552107	IVAN YAKOVLEV	{"email": "ivan-yakovlev-1978@postgrespro.ru", "phone": "+70003119569"}
0005432271012	09582C	1738 993974	ELENA MELNIKOVA	{"email": "e-melnikova.29111962@postgrespro.ru", "phone": "+70100965913"}
0005432271013	63C4F1	4078 773293	YURIY SOROKIN	{"phone": "+70055070156"}
0005432271014	63C4F1	8847 653242	YURIY ROMANOV	{"email": "yromanov.07011983@postgrespro.ru", "phone": "+70217970311"}
0005432271015	428FFA	0876 481861	NATALYA POPOVA	{"phone": "+70989529111"}
0005432271016	DAE07B	3870 327364	ALEKSANDR KRASNOV	{"email": "a.krasnov.031972@postgrespro.ru", "phone": "+70432031918"}
0005432271017	4102C3	1119 204778	RADIK POPOV	{"phone": "+70710596778"}
0005432271018	4102C3	7220 510671	VITALIY VOLKOV	{"email": "vvolkov-05121972@postgrespro.ru", "phone": "+70201702014"}
0005432271019	177D5F	3236 906077	NIKOLAY GORBUNOV	{"phone": "+70996386794"}
0005432271020	76D865	1937 412448	VITALIY SCHERBAKOV	{"email": "scherbakov.v.071970@postgrespro.ru", "phone": "+70740255478"}
0005432271021	5DEFB6	2545 588461	TATYANA BOGDANOVA	{"email": "t-bogdanova.15021965@postgrespro.ru", "phone": "+70884368501"}
0005432271022	EC4AE3	5064 765134	NIKOLAY CHERNOV	{"email": "nikolay-chernov_031976@postgrespro.ru", "phone": "+70574116603"}
0005432271023	A55F3D	6138 309466	ANDREY MATVEEV	{"email": "matveev_andrey.101970@postgrespro.ru", "phone": "+70054706323"}
0005432271024	9EBD18	6676 964983	NIKOLAY KONOVALOV	{"email": "nkonovalov051974@postgrespro.ru", "phone": "+70452161297"}
0005432271025	9EBD18	5539 924221	OLGA FADEEVA	{"email": "olga.fadeeva1962@postgrespro.ru", "phone": "+70319231971"}
0005432271026	D33DD5	2536 646953	VLADIMIR SOLOVEV	{"phone": "+70972490388"}
0005432271027	D33DD5	5648 990444	ALEKSANDR KARPOV	{"phone": "+70858817686"}
0005432271028	D46ACE	8776 993908	NIKITA AFANASEV	{"email": "afanasev_n121980@postgrespro.ru", "phone": "+70908151217"}
0005432271029	753669	8895 569607	ELVIRA IVANOVA	{"phone": "+70500015686"}
0005432271030	753669	9846 374939	VIKTOR KOZLOV	{"phone": "+70141946366"}
0005432271031	0DAB31	9995 498346	OLGA ZHUKOVA	{"phone": "+70903374067"}
0005432271032	681910	4063 477617	GEORGIY OSIPOV	{"phone": "+70585757614"}
0005432271033	1DE193	9648 047005	OLESYA ANDREEVA	{"email": "olesya_andreeva.04011973@postgrespro.ru", "phone": "+70062640771"}
0005432271034	1DE193	9040 493230	NATALIYA MELNIKOVA	{"phone": "+70898696603"}
0005432271035	1DE193	8078 946183	ALEKSEY SERGEEV	{"phone": "+70669801848"}
0005432271036	1DE193	9023 889015	LYUDMILA MASLOVA	{"phone": "+70996084437"}
0005432271037	6DE0F9	0701 293036	NIKOLAY GERASIMOV	{"email": "gerasimov.n-1973@postgrespro.ru", "phone": "+70385742068"}
0005432271038	BC3D1A	6366 213128	YULIYA AKIMOVA	{"phone": "+70157499433"}
0005432271040	B5BF63	9125 706866	VADIM GERASIMOV	{"email": "v.gerasimov1982@postgrespro.ru", "phone": "+70504439276"}
0005432271041	FE5DD4	4171 078790	GALINA KULIKOVA	{"email": "kulikova.g_081971@postgrespro.ru", "phone": "+70342663529"}
0005432271042	AE377F	9601 329250	VALENTINA SCHERBAKOVA	{"email": "v.scherbakova031966@postgrespro.ru", "phone": "+70586551396"}
0005432271043	763799	8444 970178	OKSANA ZAYCEVA	{"phone": "+70471885152"}
0005432271044	763799	0863 387455	EVGENIY SOKOLOV	{"email": "e.sokolov-071981@postgrespro.ru", "phone": "+70738024921"}
0005432271045	7FC2F0	4371 590999	YURIY SAVELEV	{"phone": "+70008626693"}
0005432271046	7FC2F0	1261 751518	GALINA VOLKOVA	{"email": "g.volkova-04041971@postgrespro.ru", "phone": "+70764437163"}
0005432271047	64CEC0	0095 422004	ANASTASIYA DENISOVA	{"email": "denisova-anastasiya-01041969@postgrespro.ru", "phone": "+70222573160"}
0005432271048	64CEC0	0350 565265	RIMMA MEDVEDEVA	{"phone": "+70571888227"}
0005432271049	CBC480	0555 653787	ANATOLIY POPOV	{"email": "a-popov_071964@postgrespro.ru", "phone": "+70657322097"}
0005432271050	1A5EE7	2160 774060	ANNA ROMANOVA	{"phone": "+70648168265"}
0005432271051	A5AC1C	2723 405321	ANNA PETROVA	{"phone": "+70880534934"}
0005432271052	6666E8	5886 733359	OKSANA KUZMINA	{"phone": "+70328471979"}
0005432271053	6666E8	7479 849976	DANIL KUZNECOV	{"phone": "+70636960492"}
0005432271054	6666E8	9376 000576	ALEKSEY PETROV	{"phone": "+70725771885"}
0005432271055	81344C	2854 335727	LYUDMILA MAKSIMOVA	{"phone": "+70748831419"}
0005432271056	81344C	9724 700235	SVETLANA ISAEVA	{"phone": "+70953164770"}
0005432271057	81344C	6005 337703	DENIS FEDOTOV	{"email": "d-fedotov_1973@postgrespro.ru", "phone": "+70409873330"}
0005432271058	56B9FC	9295 797046	ELENA BORISOVA	{"email": "borisova-elena081967@postgrespro.ru", "phone": "+70776460065"}
0005432271059	46DDA2	8674 401113	IGOR PETROV	{"phone": "+70807275032"}
0005432271060	46DDA2	9954 201943	ALEKSANDR AFANASEV	{"email": "afanasev.a03121974@postgrespro.ru", "phone": "+70556769778"}
0005432271061	0AD626	5693 041793	DMITRIY SEMENOV	{"phone": "+70314921260"}
0005432271062	7F5A00	9515 902592	TATYANA MAKAROVA	{"email": "makarova_tatyana1972@postgrespro.ru", "phone": "+70245597141"}
0005432271063	7F5A00	4927 353241	GALINA ANTONOVA	{"email": "antonova_g.18011966@postgrespro.ru", "phone": "+70366199411"}
0005432271064	7F5A00	3155 659093	VYACHESLAV NIKOLAEV	{"email": "nikolaevvyacheslav_07091970@postgrespro.ru", "phone": "+70705484829"}
0005432271065	AB6B7C	1236 950268	VLADIMIR SOROKIN	{"phone": "+70451273666"}
0005432271066	D749BC	8437 673790	VERONIKA LOGINOVA	{"phone": "+70851633018"}
0005432271067	7F5D92	8707 371069	ELENA LOGINOVA	{"email": "e_loginova.07021973@postgrespro.ru", "phone": "+70467635614"}
0005432271068	7F5D92	4437 458265	IGOR GRIGOREV	{"phone": "+70316795393"}
0005432271069	7632FA	3708 394788	OLEG IVANOV	{"email": "oleg.ivanov-041979@postgrespro.ru", "phone": "+70389295900"}
0005432271070	A2D902	2558 700136	KLAVDIYA IVANOVA	{"phone": "+70873270823"}
0005432271071	163486	7842 012258	ELENA DMITRIEVA	{"phone": "+70084179010"}
0005432271072	44D14E	6476 130487	KONSTANTIN EGOROV	{"phone": "+70525558635"}
0005432271073	6871E1	6142 665523	ALEKSANDR POPOV	{"email": "popov.aleksandr.071981@postgrespro.ru", "phone": "+70012175679"}
0005432271074	D4D725	7956 286230	NATALYA SERGEEVA	{"email": "sergeeva-n.1968@postgrespro.ru", "phone": "+70494803818"}
0005432271075	2AB139	0053 057234	LYUBOV VOROBEVA	{"phone": "+70060618636"}
0005432271076	2AB139	7360 037132	ALEKSANDR VOROBEV	{"phone": "+70556267221"}
0005432271077	C79C72	8665 140507	ALEKSANDR MATVEEV	{"phone": "+70967651275"}
0005432271078	71D355	6976 770239	GALINA FEDOROVA	{"email": "fedorovagalina.06031981@postgrespro.ru", "phone": "+70767044043"}
0005432271079	435753	7840 667345	ELENA MOROZOVA	{"email": "morozova.elena.18061981@postgrespro.ru", "phone": "+70899042449"}
0005432271080	9B2F8D	1624 180420	ALEKSEY DMITRIEV	{"email": "aleksey-dmitriev.111974@postgrespro.ru", "phone": "+70413840940"}
0005432271081	59FD38	5033 947140	ELENA VASILEVA	{"phone": "+70125376511"}
0005432271082	59FD38	1514 430024	YULIYA FROLOVA	{"phone": "+70047658854"}
0005432271083	6F3248	7802 180730	IVAN SHEVCHENKO	{"phone": "+70836481297"}
0005432271084	061948	8648 159804	OLEG ILIN	{"email": "ilin-o.051969@postgrespro.ru", "phone": "+70654534526"}
0005432271085	505036	2199 933468	VERA EFREMOVA	{"email": "veraefremova-26071968@postgrespro.ru", "phone": "+70976346922"}
0005432271086	F0703D	0881 561125	OKSANA FEDOROVA	{"email": "o-fedorova.14031967@postgrespro.ru", "phone": "+70698961757"}
0005432271087	13C69E	9966 076525	PAVEL MIRONOV	{"email": "p.mironov051971@postgrespro.ru", "phone": "+70852623058"}
0005432271088	13C69E	5389 401087	ANNA IVANOVA	{"phone": "+70346082461"}
0005432271089	F304CB	8937 425661	LYUDMILA SOKOLOVA	{"phone": "+70063893340"}
0005432271090	B47008	2187 341125	LYUBOV OSIPOVA	{"phone": "+70763155878"}
0005432271091	E50F80	3547 026359	SERGEY NIKOLAEV	{"phone": "+70482219919"}
0005432277569	5F1987	3002 505184	DMITRIY GERASIMOV	{"phone": "+70200524515"}
0005432277570	5F1987	4384 838906	ROZA TIMOFEEVA	{"phone": "+70503097048"}
0005432277571	B34CC4	6739 848454	ROMAN ZHUKOV	{"phone": "+70922846624"}
0005432277572	6C26C0	0406 001153	ARSENIY IVANOV	{"email": "aivanov24071982@postgrespro.ru", "phone": "+70702460322"}
0005432277573	6C26C0	0605 268338	NADEZHDA MASLOVA	{"email": "maslova-nadezhda-1967@postgrespro.ru", "phone": "+70697570614"}
0005432277574	5A280E	5545 417080	ANASTASIYA SIDOROVA	{"phone": "+70664459721"}
0005432277575	5A280E	6789 976609	VALERIY GAVRILOV	{"phone": "+70916329991"}
0005432277576	DEADB7	0538 834348	VALERIY KISELEV	{"phone": "+70796041279"}
0005432277577	D14206	1027 916996	SERGEY BORISOV	{"email": "sergey_borisov-17041968@postgrespro.ru", "phone": "+70365178979"}
0005432277578	A30B01	9342 935975	ALEKSEY NOVIKOV	{"email": "aleksey-novikov.01011966@postgrespro.ru", "phone": "+70722971497"}
0005432277579	E93D44	5834 726908	OLGA STEPANOVA	{"email": "olga.stepanova1981@postgrespro.ru", "phone": "+70799334932"}
0005432277580	9BC8E9	5107 876382	RUSTAM IVANOV	{"phone": "+70881406551"}
0005432277581	AF89DB	5594 091249	YAROSLAV IVANOV	{"phone": "+70360014815"}
0005432277582	99A7CD	8535 602174	ROMAN DAVYDOV	{"email": "roman-davydov-031972@postgrespro.ru", "phone": "+70372365316"}
0005432277583	72A5FC	5533 666281	GALINA DAVYDOVA	{"phone": "+70691865459"}
0005432277584	2D32E5	9087 024778	ANDREY ANDREEV	{"email": "andreyandreev121973@postgrespro.ru", "phone": "+70654278144"}
0005432277585	05F874	6143 389678	ANATOLIY MIRONOV	{"phone": "+70007169024"}
0005432277586	6C4E11	9719 710606	NIKOLAY NIKOLAEV	{"phone": "+70062079412"}
0005432277587	24707D	2666 433274	MARIYA VOROBEVA	{"email": "mariya_vorobeva_01091970@postgrespro.ru", "phone": "+70027524567"}
0005432277588	2B1806	8043 895744	OLGA TIMOFEEVA	{"email": "o_timofeeva_1971@postgrespro.ru", "phone": "+70143617235"}
0005432277589	F2E3F5	4769 815372	ELENA LOGINOVA	{"email": "e-loginova_07021970@postgrespro.ru", "phone": "+70921591821"}
0005432277590	7CE679	3872 330556	GALINA ERMAKOVA	{"phone": "+70527659566"}
0005432277591	EA1E47	1643 268949	ALEKSANDR SHEVCHENKO	{"phone": "+70094625108"}
0005432277592	EA1E47	8964 576866	ALEKSEY NAUMOV	{"phone": "+70715570817"}
0005432277593	EA1E47	5059 819412	MARIYA MOROZOVA	{"email": "morozova_m26071970@postgrespro.ru", "phone": "+70431208143"}
0005432277594	E66A1A	2563 926901	ZOYA ARKHIPOVA	{"phone": "+70413114696"}
0005432277595	11D242	9773 077474	NATALYA VOROBEVA	{"email": "nvorobeva.051973@postgrespro.ru", "phone": "+70331856090"}
0005432277596	11D242	3863 302222	IRINA MEDVEDEVA	{"email": "imedvedeva_1966@postgrespro.ru", "phone": "+70247266352"}
0005432277597	E16BA5	2124 347945	ALEKSANDR FEDOTOV	{"phone": "+70372545781"}
0005432277598	E16BA5	3393 114628	VASILIY IVANOV	{"phone": "+70663414557"}
0005432277599	7D3622	4006 041146	SERGEY MOROZOV	{"phone": "+70219426171"}
0005432277600	7D3622	7476 149537	NIKOLAY DMITRIEV	{"phone": "+70818877200"}
0005432277601	8E6FE1	8461 337332	ILYA ANDREEV	{"phone": "+70325286751"}
0005432277602	28B5C6	8935 266455	OLGA KUZNECOVA	{"email": "kuznecova_olga_1965@postgrespro.ru", "phone": "+70860751114"}
0005432277603	FE1C8A	1343 181276	VERA MALYSHEVA	{"email": "malyshevav-1974@postgrespro.ru", "phone": "+70194865263"}
0005432277604	FE1C8A	8476 764426	VIKTOR KOZLOV	{"phone": "+70873807098"}
0005432277605	766B4A	3258 630451	VALENTIN OSIPOV	{"email": "v.osipov.071975@postgrespro.ru", "phone": "+70156543717"}
0005432277606	29D4EB	0209 281046	IGOR ZHUKOV	{"phone": "+70366695060"}
0005432277607	29D4EB	2201 774423	NIKOLAY POPOV	{"email": "n_popov-051981@postgrespro.ru", "phone": "+70216050517"}
0005432277608	BA70FA	2721 907100	VALENTINA VASILEVA	{"phone": "+70398590444"}
0005432277609	6530F3	7011 592138	ANATOLIY NOVIKOV	{"email": "a_novikov.021979@postgrespro.ru", "phone": "+70021940082"}
0005432277610	4BE40D	7633 446714	VIKTOR ANTONOV	{"email": "v_antonov_041979@postgrespro.ru", "phone": "+70068390702"}
0005432277611	4BE40D	8864 263894	NINA ROMANOVA	{"email": "nina_romanova-28121968@postgrespro.ru", "phone": "+70564903777"}
0005432277612	E6BDB9	6786 362326	TATYANA ZAKHAROVA	{"phone": "+70590344940"}
0005432277613	E6BDB9	2066 077887	SVETLANA POPOVA	{"email": "popovas-1972@postgrespro.ru", "phone": "+70063355531"}
0005432277614	F4D1D6	9851 687971	DENIS SMIRNOV	{"phone": "+70507245152"}
0005432277615	7CC014	6517 530986	VIKTOR STEPANOV	{"email": "stepanov_v_24091967@postgrespro.ru", "phone": "+70217705082"}
0005432277616	B52BF8	9649 004325	ELENA FILIPPOVA	{"email": "e.filippova1976@postgrespro.ru", "phone": "+70212808729"}
0005432277617	18AA1C	7175 785326	SVETLANA KUZNECOVA	{"phone": "+70139023085"}
0005432277618	0B1ADE	7973 016027	ALEFTINA FILATOVA	{"phone": "+70706435256"}
0005432277619	811D06	7480 637205	GENNADIY VOROBEV	{"email": "vorobev-gennadiy05071971@postgrespro.ru", "phone": "+70378538351"}
0005432277620	76766C	7003 652290	MARIYA SAVELEVA	{"phone": "+70627839828"}
0005432277621	76766C	6048 837315	GALINA KISELEVA	{"phone": "+70008778471"}
0005432277622	543CA5	2046 529904	MIKHAIL TIKHONOV	{"email": "tikhonov-mikhail-091978@postgrespro.ru", "phone": "+70967328648"}
0005432277623	48E7C4	5285 669890	SHAMIL KUZNECOV	{"phone": "+70839047741"}
0005432277624	48E7C4	8287 710426	YURIY POPOV	{"phone": "+70929976452"}
0005432277625	62DC75	4863 885992	LYUDMILA SERGEEVA	{"email": "sergeeval071969@postgrespro.ru", "phone": "+70851277086"}
0005432277626	62DC75	7698 846716	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a26091976@postgrespro.ru", "phone": "+70124172429"}
0005432277627	0DABAD	5818 906027	GENNADIY BELOV	{"phone": "+70410726278"}
0005432277628	1B3ACB	0829 290609	GENNADIY KISELEV	{"phone": "+70541655949"}
0005432277629	7F3153	0354 266664	NINA ZHUKOVA	{"phone": "+70381253766"}
0005432277630	7F3153	3115 545410	PAVEL VOROBEV	{"phone": "+70966988269"}
0005432277631	7F3153	5576 126682	FARIT DMITRIEV	{"email": "dmitriev-farit_1978@postgrespro.ru", "phone": "+70045623720"}
0005432277632	8796F1	8145 521053	LYUDMILA KOZLOVA	{"email": "kozlova.lyudmila_1970@postgrespro.ru", "phone": "+70010869754"}
0005432277633	8796F1	2171 158375	EKATERINA SERGEEVA	{"email": "sergeevaekaterina_021973@postgrespro.ru", "phone": "+70605433862"}
0005432277634	6CE80B	5315 062519	VALERIYA MAKSIMOVA	{"phone": "+70241268738"}
0005432277635	6CE80B	1161 371316	TATYANA DAVYDOVA	{"email": "t.davydova-23071968@postgrespro.ru", "phone": "+70166325076"}
0005432277636	6CE80B	2733 323332	SERGEY DMITRIEV	{"email": "sergey_dmitriev-07021978@postgrespro.ru", "phone": "+70865557458"}
0005432277637	A9FFCD	7422 347014	ANDREY ZHUKOV	{"phone": "+70237409385"}
0005432277638	234952	0075 273848	ANTON SHEVCHENKO	{"email": "shevchenko_a021978@postgrespro.ru", "phone": "+70715628104"}
0005432277639	234952	5166 507821	TATYANA VLASOVA	{"email": "t_vlasova.15101973@postgrespro.ru", "phone": "+70760602633"}
0005432277640	D78967	8147 069764	EGOR GAVRILOV	{"phone": "+70068407488"}
0005432277641	595638	8388 990700	VIKTORIYA GERASIMOVA	{"email": "gerasimova-v-021977@postgrespro.ru", "phone": "+70800084034"}
0005432277642	08CE01	5712 689004	ANDREY SOROKIN	{"email": "andreysorokin-1980@postgrespro.ru", "phone": "+70848263083"}
0005432277643	6B24E1	3081 413505	VIKTOR FOMIN	{"email": "fomin_viktor1971@postgrespro.ru", "phone": "+70654641721"}
0005432277644	6B24E1	3421 234600	ANNA YAKOVLEVA	{"email": "anna-yakovleva-29041970@postgrespro.ru", "phone": "+70663775787"}
0005432277645	6B24E1	7030 146791	VALENTINA SMIRNOVA	{"email": "smirnovavalentina061972@postgrespro.ru", "phone": "+70462246555"}
0005432277646	AAC63F	9403 639022	ARTEM KUZNECOV	{"email": "akuznecov-30111967@postgrespro.ru", "phone": "+70763069264"}
0005432277647	AAC63F	2302 720127	LYUBOV EFREMOVA	{"phone": "+70018310572"}
0005432277648	C3AE09	1965 549273	EVGENIY KUZNECOV	{"email": "kuznecov_e.111979@postgrespro.ru", "phone": "+70590832754"}
0005432277649	BCFA19	2629 962106	SERGEY POPOV	{"phone": "+70951237743"}
0005432277650	54C6D5	3153 002042	VLADIMIR SEMENOV	{"phone": "+70047159362"}
0005432277651	54C6D5	3826 051831	ARTEM MOROZOV	{"email": "morozov.a_28091980@postgrespro.ru", "phone": "+70347309618"}
0005432277652	9FD002	4975 062873	OLGA ANDREEVA	{"phone": "+70308073451"}
0005432277653	46FE05	0220 755890	VIKTOR KOZLOV	{"phone": "+70053789069"}
0005432277654	859976	9854 222092	EVGENIY ZHUKOV	{"phone": "+70521592781"}
0005432277655	859976	7168 400147	ANDREY BORISOV	{"phone": "+70540704495"}
0005432277656	D20D3B	0650 910274	SERGEY KRASNOV	{"email": "sergey.krasnov-1975@postgrespro.ru", "phone": "+70188939469"}
0005432277657	DAFAD9	7749 055927	DARYA GORBUNOVA	{"email": "darya.gorbunova15081984@postgrespro.ru", "phone": "+70310627111"}
0005432277658	97BE39	0066 632669	NATALYA POTAPOVA	{"email": "n.potapova121976@postgrespro.ru", "phone": "+70569800113"}
0005432277659	97BE39	4702 651339	ANTONINA TIKHONOVA	{"phone": "+70875356899"}
0005432277660	BC2FAE	4668 455969	NATALYA KARPOVA	{"phone": "+70198018820"}
0005432277661	3C0308	4925 045932	ANDREY BORISOV	{"email": "borisov.andrey_1967@postgrespro.ru", "phone": "+70462398708"}
0005432277662	98176C	7059 374889	DANIIL FROLOV	{"phone": "+70182092612"}
0005432277664	C511A9	9433 398316	SERGEY VASILEV	{"email": "s.vasilev.08031973@postgrespro.ru", "phone": "+70340966831"}
0005432277665	EF60A5	5803 143203	MATVEY FOMIN	{"phone": "+70118866207"}
0005432277666	1AC17A	1041 282187	LILIYA PETROVA	{"email": "lpetrova.1973@postgrespro.ru", "phone": "+70779282529"}
0005432277667	7C3E7F	5651 784848	KSENIYA ANTONOVA	{"phone": "+70607226146"}
0005432277668	695E89	0477 079189	VLADIMIR KUZNECOV	{"email": "vkuznecov1971@postgrespro.ru", "phone": "+70170637927"}
0005432277669	EF5442	5785 522909	DENIS EGOROV	{"email": "egorov_d.1971@postgrespro.ru", "phone": "+70688230559"}
0005432277670	C4DE4D	6669 074685	ALEKSANDR PETROV	{"phone": "+70940483929"}
0005432277671	C4DE4D	1270 307733	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov_041973@postgrespro.ru", "phone": "+70343922959"}
0005432277672	C97941	2266 457461	NATALYA MATVEEVA	{"phone": "+70698790461"}
0005432277673	C97941	5743 213883	VLADIMIR MELNIKOV	{"email": "melnikovv1982@postgrespro.ru", "phone": "+70651237401"}
0005432277674	FA5218	5015 395513	VASILIY SCHERBAKOV	{"phone": "+70370235291"}
0005432277675	FA5218	9512 354311	RAVIL NOVIKOV	{"phone": "+70491575216"}
0005432277676	FA5218	7785 978007	TATYANA DANILOVA	{"email": "danilova.t30041965@postgrespro.ru", "phone": "+70825107124"}
0005432277677	DFEF11	3705 568562	ALEKSANDRA ISAEVA	{"email": "aleksandra-isaeva-021970@postgrespro.ru", "phone": "+70880802268"}
0005432277678	DFEF11	0904 958159	GALINA POTAPOVA	{"email": "potapova.galina_021984@postgrespro.ru", "phone": "+70804223666"}
0005432277679	423D6D	0219 521810	VLADIMIR RODIONOV	{"phone": "+70458995106"}
0005432277680	7BF9FF	3025 429847	SVETLANA MIRONOVA	{"email": "s.mironova_24041975@postgrespro.ru", "phone": "+70007950083"}
0005432277681	7BF9FF	8386 350352	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey-1958@postgrespro.ru", "phone": "+70255770651"}
0005432277682	513E19	2978 673993	ALEKSANDR MAKAROV	{"phone": "+70782583793"}
0005432277683	031C4B	7996 863150	OLGA POTAPOVA	{"email": "potapova-olga-06091981@postgrespro.ru", "phone": "+70803865952"}
0005432277684	0558C8	3262 659168	GALINA DMITRIEVA	{"email": "g-dmitrieva_1968@postgrespro.ru", "phone": "+70660907838"}
0005432277685	0558C8	9374 175800	IRINA OVCHINNIKOVA	{"phone": "+70534635452"}
0005432277686	BDE0F8	1520 686957	VERONIKA NAZAROVA	{"phone": "+70224339263"}
0005432277687	98C94B	6996 328161	PAVEL GERASIMOV	{"email": "gerasimov_pavel14071971@postgrespro.ru", "phone": "+70205944806"}
0005432277688	01AC56	0162 099776	SVETLANA PAVLOVA	{"phone": "+70843394462"}
0005432277689	97E9A7	0211 710901	ALEKSEY NAUMOV	{"email": "naumov.a.21121966@postgrespro.ru", "phone": "+70959349292"}
0005432277690	D6C4F9	7303 676517	ELENA RYABOVA	{"phone": "+70666884660"}
0005432277691	D6C4F9	9448 999427	DMITRIY FEDOROV	{"phone": "+70141392576"}
0005432277692	C5BBBB	0996 619936	TIMOFEY MOISEEV	{"phone": "+70959727620"}
0005432277693	4377DB	4444 924711	ANASTASIYA NIKOLAEVA	{"email": "anastasiyanikolaeva_07091964@postgrespro.ru", "phone": "+70770120321"}
0005432277694	43FADE	6493 943491	VLADIMIR SIDOROV	{"email": "sidorov_v.021977@postgrespro.ru", "phone": "+70115492402"}
0005432277695	883CE1	0498 075634	PAVEL SOLOVEV	{"phone": "+70630579895"}
0005432277696	38FEFC	6724 641227	VLADIMIR KUZNECOV	{"phone": "+70123208629"}
0005432277697	BA826D	7807 790913	NATALYA IVANOVA	{"email": "natalya.ivanova27021983@postgrespro.ru", "phone": "+70273869037"}
0005432277698	BA826D	8782 580180	TATYANA ROMANOVA	{"email": "romanova-tatyana-18121974@postgrespro.ru", "phone": "+70778447096"}
0005432277699	D058D9	9099 401391	VLADIMIR ZAYCEV	{"email": "vladimir-zaycev_011980@postgrespro.ru", "phone": "+70620463701"}
0005432277700	8DB6A0	1620 316560	ALEKSANDR KULIKOV	{"phone": "+70437532419"}
0005432277701	14223B	3161 015309	VALENTINA ALEKSEEVA	{"email": "v-alekseeva1972@postgrespro.ru", "phone": "+70381246515"}
0005432277702	B90308	8683 397384	STANISLAV PETROV	{"email": "petrov-s_021962@postgrespro.ru", "phone": "+70088388892"}
0005432277703	B90308	3872 105174	MARINA KISELEVA	{"phone": "+70216485421"}
0005432277704	B90308	0405 214020	ELVIRA EGOROVA	{"email": "egorova-elvira-12061968@postgrespro.ru", "phone": "+70519048498"}
0005432277705	E112C3	7634 737103	MARIYA KRASNOVA	{"phone": "+70366858511"}
0005432277706	E112C3	2079 871525	ELENA NAUMOVA	{"email": "naumovaelena.10111973@postgrespro.ru", "phone": "+70041368436"}
0005432277707	CEAE81	7770 430846	SERGEY KARPOV	{"email": "s_karpov-031976@postgrespro.ru", "phone": "+70051007086"}
0005432277708	CEAE81	4202 012955	PAVEL GORBUNOV	{"email": "p.gorbunov.1963@postgrespro.ru", "phone": "+70803325644"}
0005432277709	85D3DA	4124 413035	ARTEM PETROV	{"email": "petrov.a-29101972@postgrespro.ru", "phone": "+70132139488"}
0005432277710	85D3DA	2520 307870	YULIYA KOMAROVA	{"email": "komarova_y-111957@postgrespro.ru", "phone": "+70353063569"}
0005432277711	53777A	1895 930929	VADIM IVANOV	{"phone": "+70512600144"}
0005432277712	055391	7636 635836	IRINA VASILEVA	{"email": "irina-vasileva.051967@postgrespro.ru", "phone": "+70409691381"}
0005432277713	7A13E6	9034 392627	YULIYA BOGDANOVA	{"email": "y_bogdanova_1973@postgrespro.ru", "phone": "+70757748495"}
0005432277714	CB2DEA	4805 288800	OKSANA EGOROVA	{"email": "egorovao-22101986@postgrespro.ru", "phone": "+70252323980"}
0005432277715	FF8646	7603 781109	SERGEY MIKHAYLOV	{"email": "s.mikhaylov.121982@postgrespro.ru", "phone": "+70717817161"}
0005432277716	1A2E42	8951 966842	NIKOLAY BORISOV	{"phone": "+70489269915"}
0005432277717	DFB38D	1008 739621	KONSTANTIN OSIPOV	{"phone": "+70906244569"}
0005432277718	DFB38D	8700 367166	NINA ZHURAVLEVA	{"email": "zhuravleva.n.1974@postgrespro.ru", "phone": "+70900549653"}
0005432277719	6732B9	4052 040102	LYUBOV ALEKSANDROVA	{"phone": "+70633385098"}
0005432277720	6732B9	5397 069218	VYACHESLAV SMIRNOV	{"email": "vyacheslavsmirnov-061962@postgrespro.ru", "phone": "+70703491340"}
0005432277721	621204	1885 689749	VASILIY NOVIKOV	{"email": "vasiliy-novikov_1970@postgrespro.ru", "phone": "+70355267854"}
0005432277722	15DA98	1340 680825	SERGEY SERGEEV	{"email": "s_sergeev-04041978@postgrespro.ru", "phone": "+70050612721"}
0005432277723	15DA98	7849 486172	VLADIMIR NOVIKOV	{"phone": "+70557091462"}
0005432277724	3BD1B1	7837 435049	LYUBOV ANDREEVA	{"email": "andreeva.lyubov-03071980@postgrespro.ru", "phone": "+70448627508"}
0005432277725	87B271	0458 070568	VYACHESLAV SMIRNOV	{"email": "smirnov.vyacheslav_1960@postgrespro.ru", "phone": "+70205580175"}
0005432277726	EDA7F6	7661 056225	SERGEY POPOV	{"email": "popovsergey-1982@postgrespro.ru", "phone": "+70273174021"}
0005432277727	8FD9C3	4444 479006	EGOR PETROV	{"phone": "+70433275914"}
0005432277728	8F1875	0101 642523	OLGA DMITRIEVA	{"email": "odmitrieva-22081970@postgrespro.ru", "phone": "+70125390862"}
0005432277729	77325D	9910 016304	VALENTINA KAZAKOVA	{"phone": "+70261496551"}
0005432277730	77325D	0096 015250	IGOR KUZNECOV	{"phone": "+70991016722"}
0005432277731	559D0A	7021 604916	EKATERINA KOZLOVA	{"phone": "+70874016606"}
0005432277732	F4C588	9637 643462	ALFIYA NIKOLAEVA	{"email": "nikolaevaa_30111966@postgrespro.ru", "phone": "+70653100716"}
0005432277733	F0D9D7	9834 335069	ALEKSEY VASILEV	{"phone": "+70871918369"}
0005432277734	F6753D	9022 403033	NINA NIKOLAEVA	{"phone": "+70161459981"}
0005432277735	FB6C79	2198 606942	NIKOLAY MOROZOV	{"phone": "+70839127100"}
0005432277736	067716	2168 387725	ISLAM FEDOTOV	{"phone": "+70408779621"}
0005432277737	067716	7769 142599	TATYANA FEDOROVA	{"email": "tatyana_fedorova-011972@postgrespro.ru", "phone": "+70241414006"}
0005432277738	74824C	2256 758921	ANNA POPOVA	{"phone": "+70195815036"}
0005432277739	74824C	7091 104336	NINA SIDOROVA	{"phone": "+70683642944"}
0005432277740	1CB442	3462 628434	VALERIYA MIRONOVA	{"email": "mironova-valeriya18111972@postgrespro.ru", "phone": "+70020885945"}
0005432277741	1CB442	4527 083446	AMINA VLASOVA	{"email": "vlasova.amina.15021973@postgrespro.ru", "phone": "+70612632188"}
0005432277742	95BDBD	5789 823493	SVETLANA KUZNECOVA	{"email": "kuznecova-s1976@postgrespro.ru", "phone": "+70250460513"}
0005432277743	3CC51E	6788 489441	TAISIYA SOROKINA	{"email": "sorokina.taisiya-1983@postgrespro.ru", "phone": "+70755413738"}
0005432277744	E1C927	2687 473493	YURIY AFANASEV	{"email": "yuriyafanasev_1973@postgrespro.ru", "phone": "+70897392825"}
0005432277745	EFFE9A	8976 184712	ARTEM KAZAKOV	{"email": "akazakov.1966@postgrespro.ru", "phone": "+70509959874"}
0005432277746	E9F5C8	2314 951810	PRASKOVYA MIRONOVA	{"phone": "+70689306670"}
0005432277747	D2799A	8881 225541	ULYANA NOVIKOVA	{"email": "ulyana-novikova_071974@postgrespro.ru", "phone": "+70317946919"}
0005432277748	59D65E	0203 575908	ALEKSEY EGOROV	{"email": "egorov_a.091982@postgrespro.ru", "phone": "+70626420004"}
0005432277749	8D7349	6180 235430	YURIY MOROZOV	{"email": "morozov-y111968@postgrespro.ru", "phone": "+70726229198"}
0005432277750	12177F	7830 893360	MARIYA MOISEEVA	{"phone": "+70845989207"}
0005432277751	B15F24	0387 637431	OLGA MALYSHEVA	{"phone": "+70940956465"}
0005432277752	FB1C71	4135 900066	LYUBOV SOROKINA	{"phone": "+70405200186"}
0005432277753	FB1C71	8532 280749	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova.1968@postgrespro.ru", "phone": "+70867351523"}
0005432277754	2FF0A3	3829 096930	NATALYA KONDRATEVA	{"email": "kondrateva-natalya1970@postgrespro.ru", "phone": "+70509767918"}
0005432277755	64EABC	4972 343646	ARTEM SEMENOV	{"email": "asemenov-09061967@postgrespro.ru", "phone": "+70491093293"}
0005432277756	64EABC	8034 455438	MARIYA EGOROVA	{"phone": "+70071013490"}
0005432277757	4520CE	2333 657340	YURIY YAKOVLEV	{"email": "yuriy.yakovlev.111968@postgrespro.ru", "phone": "+70124449983"}
0005432277758	4520CE	1945 960359	NATALYA SOROKINA	{"email": "natalyasorokina_101975@postgrespro.ru", "phone": "+70138246226"}
0005432277759	0F6A78	9870 554486	ALINA ABRAMOVA	{"phone": "+70863676536"}
0005432277760	0F6A78	6756 176109	DMITRIY ALEKSEEV	{"phone": "+70096378203"}
0005432277761	B3F04F	0339 488442	NINA ZHUKOVA	{"phone": "+70137613797"}
0005432277762	B3F04F	8294 064458	NATALYA ISAEVA	{"email": "isaeva-natalya.1977@postgrespro.ru", "phone": "+70707753974"}
0005432277763	B52F9E	9631 891052	VIKTOR ZAKHAROV	{"phone": "+70127680238"}
0005432277764	717CAE	3935 469655	NIKOLAY NIKITIN	{"phone": "+70199847510"}
0005432277765	717CAE	1971 682742	FEDOR CHERNOV	{"email": "fedor-chernov.101980@postgrespro.ru", "phone": "+70676157430"}
0005432277766	85DAB4	4220 725793	ELIZAVETA ISAEVA	{"phone": "+70936207529"}
0005432277767	425A74	6689 168705	TATYANA SOROKINA	{"phone": "+70686932438"}
0005432277768	8267E6	2110 286222	ANGELINA KUZNECOVA	{"email": "a-kuznecova-27021983@postgrespro.ru", "phone": "+70914534405"}
0005432277769	8AC8CD	7410 397944	SVETLANA GAVRILOVA	{"phone": "+70009775676"}
0005432277770	CE4B15	6217 024319	ALEKSANDR KONOVALOV	{"email": "a.konovalov-18051959@postgrespro.ru", "phone": "+70972843967"}
0005432277771	3940EC	5482 099909	VYACHESLAV KONOVALOV	{"phone": "+70017497631"}
0005432277772	55C675	5928 982062	GALINA TARASOVA	{"email": "g-tarasova1971@postgrespro.ru", "phone": "+70369401659"}
0005432277773	F8EF1E	8175 918404	GENNADIY PAVLOV	{"phone": "+70164775158"}
0005432277774	7F8320	1236 188218	VIKTOR ZAYCEV	{"phone": "+70204437339"}
0005432277775	7F8320	0575 587451	MIKHAIL VLASOV	{"phone": "+70194915163"}
0005432277776	44238B	5426 054634	SALAVAT FEDOROV	{"email": "fedorov-s-19121971@postgrespro.ru", "phone": "+70028338997"}
0005432277777	73447C	3115 887570	IVAN KOROLEV	{"phone": "+70274033846"}
0005432277778	436918	1219 218406	EKATERINA STEPANOVA	{"phone": "+70667122541"}
0005432277779	436918	2507 090319	PAVEL KRASNOV	{"email": "pavelkrasnov.27021971@postgrespro.ru", "phone": "+70312206141"}
0005432277780	6AFD93	3849 511721	FEDOR PETROV	{"email": "petrov-f_031978@postgrespro.ru", "phone": "+70844160892"}
0005432277781	20DF65	8045 190191	ALEKSANDR RODIONOV	{"phone": "+70798792346"}
0005432277782	F3D018	3288 299155	PAVEL GAVRILOV	{"email": "pgavrilov.111974@postgrespro.ru", "phone": "+70410490570"}
0005432277783	1D7040	5292 697926	IVAN SMIRNOV	{"email": "smirnov_ivan_24011973@postgrespro.ru", "phone": "+70990882439"}
0005432277784	1D7040	1706 278989	NIKOLAY BONDARENKO	{"phone": "+70950905836"}
0005432277785	C6E7B0	9817 462435	NINA PAVLOVA	{"email": "pavlova.nina1975@postgrespro.ru", "phone": "+70855110038"}
0005432277786	4560A1	0943 026703	SERGEY KONOVALOV	{"email": "sergey-konovalov_1967@postgrespro.ru", "phone": "+70325545528"}
0005432277787	4560A1	4338 113559	NATALYA POPOVA	{"email": "natalyapopova_071966@postgrespro.ru", "phone": "+70136395495"}
0005432277788	27966B	7873 132876	MAKSIM GRIGOREV	{"phone": "+70036898556"}
0005432277789	27966B	8329 109826	ALEKSANDR MOISEEV	{"phone": "+70182289099"}
0005432277790	CEEACF	2914 211185	MARIYA PETROVA	{"email": "petrova.m1977@postgrespro.ru", "phone": "+70241345948"}
0005432277791	622EC9	0468 249986	GALINA BORISOVA	{"phone": "+70513130354"}
0005432277792	BA7402	0904 326157	ELENA DENISOVA	{"phone": "+70854011066"}
0005432277793	3B0F2D	8652 812762	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.07071966@postgrespro.ru", "phone": "+70771741580"}
0005432277794	37D102	3361 726996	VASILIY OSIPOV	{"email": "osipovv_07061976@postgrespro.ru", "phone": "+70187632647"}
0005432277795	37D102	9582 932666	VERA KOZLOVA	{"email": "vera_kozlova.28071971@postgrespro.ru", "phone": "+70060806730"}
0005432277796	F423CB	0156 392996	NINA VLASOVA	{"phone": "+70778102331"}
0005432277797	A4C153	1506 867733	IRINA PAVLOVA	{"email": "pavlovairina.22011976@postgrespro.ru", "phone": "+70087553827"}
0005432277798	A4C153	4705 351005	ALEKSANDR MIRONOV	{"phone": "+70330653457"}
0005432277799	707303	8561 157634	NATALYA NAZAROVA	{"phone": "+70896080105"}
0005432277800	AA572E	9349 590934	OLGA ZOTOVA	{"email": "zotovaolga_1967@postgrespro.ru", "phone": "+70830877963"}
0005432277801	F88906	2066 788858	ARSENIY ALEKSANDROV	{"email": "aaleksandrov-1975@postgrespro.ru", "phone": "+70438010176"}
0005432277802	F88906	2349 128961	NINA NAUMOVA	{"email": "n-naumova_28071978@postgrespro.ru", "phone": "+70192891691"}
0005432277803	9C59C2	0708 327084	NINA ZHUKOVA	{"phone": "+70128892988"}
0005432277804	37395C	9309 292751	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga1973@postgrespro.ru", "phone": "+70202717793"}
0005432277805	E24963	6452 899552	DMITRIY ANTONOV	{"phone": "+70851606441"}
0005432277806	E24963	4026 542321	TATYANA SAVELEVA	{"email": "t.saveleva-21061971@postgrespro.ru", "phone": "+70176327072"}
0005432277863	A8DC9A	5371 524767	ALEKSEY FOMIN	{"phone": "+70255582088"}
0005432277807	937BDE	1256 686395	YURIY MIRONOV	{"email": "yuriy-mironov1974@postgrespro.ru", "phone": "+70143701166"}
0005432277808	937BDE	7218 212578	DARYA BELYAEVA	{"email": "d-belyaeva-1965@postgrespro.ru", "phone": "+70804300650"}
0005432277809	F92FB5	1266 206991	NIKOLAY DENISOV	{"phone": "+70227727258"}
0005432277810	F0DF9D	3520 695918	RUSLAN RODIONOV	{"phone": "+70605757607"}
0005432277811	66CDBC	5232 083567	VLADIMIR NIKITIN	{"phone": "+70854770042"}
0005432277812	66CDBC	7852 104416	VLADIMIR NAUMOV	{"email": "naumov.v-19111981@postgrespro.ru", "phone": "+70979869120"}
0005432277813	BAC7E1	5308 927825	SERGEY KOZLOV	{"phone": "+70324469933"}
0005432277814	F6AAE3	7654 102634	VALENTINA KOZLOVA	{"phone": "+70117623535"}
0005432277815	ECF4F7	4808 464110	NIKOLAY VASILEV	{"phone": "+70255316267"}
0005432277816	ECF4F7	6240 591374	DENIS KUZMIN	{"email": "denis_kuzmin_051968@postgrespro.ru", "phone": "+70297823352"}
0005432277817	40B487	9367 639223	TATYANA NIKITINA	{"email": "t-nikitina18091961@postgrespro.ru", "phone": "+70107838744"}
0005432277818	40B487	1675 335185	VLADIMIR ORLOV	{"phone": "+70355639022"}
0005432277819	38A224	5844 489295	POLINA SIDOROVA	{"email": "sidorova.polina111977@postgrespro.ru", "phone": "+70027926671"}
0005432277820	38A224	8467 115587	EVGENIY DAVYDOV	{"email": "davydovevgeniy-30101970@postgrespro.ru", "phone": "+70345178008"}
0005432277821	A33B2E	6414 004345	ALEKSANDR VASILEV	{"phone": "+70419181755"}
0005432277822	D33095	0841 110569	ELENA OSIPOVA	{"phone": "+70246876366"}
0005432277823	D33095	0487 878800	VYACHESLAV ROMANOV	{"phone": "+70022485430"}
0005432277824	0E9263	1489 550476	VALENTINA ZHURAVLEVA	{"email": "zhuravlevav121963@postgrespro.ru", "phone": "+70901497459"}
0005432277825	0E9263	3699 464477	ALEKSANDR POPOV	{"email": "aleksandrpopov_091971@postgrespro.ru", "phone": "+70734514647"}
0005432277826	AA3278	8844 884995	ALEKSANDR FILIPPOV	{"phone": "+70730849435"}
0005432277827	AA3278	2057 915255	IRINA LEBEDEVA	{"phone": "+70001637675"}
0005432277828	AA3278	2214 215378	ANASTASIYA KARPOVA	{"email": "karpova-a-061974@postgrespro.ru", "phone": "+70844271709"}
0005432277829	FA6777	7884 058360	MARIYA KOZLOVA	{"email": "kozlova.mariya.1974@postgrespro.ru", "phone": "+70897983339"}
0005432277830	14AE99	5149 165880	YULIYA ORLOVA	{"email": "yorlova-19071972@postgrespro.ru", "phone": "+70513003259"}
0005432277831	DFED6E	9585 657957	NIKITA KONOVALOV	{"phone": "+70702043772"}
0005432277832	B56CEA	2641 282736	VIKTOR NIKOLAEV	{"email": "viktor.nikolaev.071978@postgrespro.ru", "phone": "+70118179953"}
0005432277833	F62AE0	3260 382082	ELENA FILIPPOVA	{"email": "e.filippova.21091974@postgrespro.ru", "phone": "+70435869640"}
0005432277834	E67A28	0651 385361	GALIYA MOROZOVA	{"phone": "+70550090609"}
0005432277835	E67A28	9686 218601	MAKSIM ALEKSEEV	{"email": "m-alekseev.091965@postgrespro.ru", "phone": "+70638113798"}
0005432277836	2E43A0	8719 737008	DMITRIY KULIKOV	{"email": "dmitriy_kulikov1967@postgrespro.ru", "phone": "+70723364673"}
0005432277837	2E43A0	5536 217520	YURIY NIKOLAEV	{"email": "yuriy-nikolaev_1964@postgrespro.ru", "phone": "+70241085649"}
0005432277838	039A0E	1670 709239	PAVEL ZAKHAROV	{"email": "zakharov-p.051982@postgrespro.ru", "phone": "+70830056998"}
0005432277839	7929C1	2259 950138	ALEKSANDR BONDARENKO	{"email": "a_bondarenko-10061957@postgrespro.ru", "phone": "+70391822357"}
0005432277840	7929C1	5268 967535	ALEKSANDR SIDOROV	{"email": "a-sidorov_091971@postgrespro.ru", "phone": "+70807891902"}
0005432277841	AA5E08	1659 386100	YULIYA IVANOVA	{"email": "ivanova_y.101982@postgrespro.ru", "phone": "+70167788281"}
0005432277842	AA5E08	7094 889950	GRIGORIY POPOV	{"phone": "+70368809827"}
0005432277843	ACE5C0	0414 829880	IRINA IVANOVA	{"phone": "+70784008577"}
0005432277844	901D26	2905 913971	VERA SMIRNOVA	{"email": "smirnova.vera_01061977@postgrespro.ru", "phone": "+70316611038"}
0005432277845	901D26	7692 159679	MARIYA AKIMOVA	{"phone": "+70169664744"}
0005432277846	42D3A7	4174 949633	ALEKSANDR AFANASEV	{"phone": "+70575152902"}
0005432277847	42D3A7	9349 091324	NINA NESTEROVA	{"phone": "+70237237478"}
0005432277848	970B9D	3912 126330	ELENA ZHURAVLEVA	{"email": "e-zhuravleva-28091979@postgrespro.ru", "phone": "+70376571689"}
0005432277849	56EA1A	8754 676827	ZOYA TIKHONOVA	{"email": "z_tikhonova_19021980@postgrespro.ru", "phone": "+70495695013"}
0005432277850	986934	8385 351653	VADIM MATVEEV	{"email": "matveevvadim_061979@postgrespro.ru", "phone": "+70965035307"}
0005432277851	986934	4140 285056	SERGEY VASILEV	{"phone": "+70403536476"}
0005432277852	3A7A28	9777 861120	LIDIYA ZAKHAROVA	{"email": "lidiya-zakharova-091972@postgrespro.ru", "phone": "+70670368032"}
0005432277853	3A7A28	9294 398931	STEPAN KARPOV	{"email": "karpov.stepan_30101969@postgrespro.ru", "phone": "+70550548449"}
0005432277854	3A7A28	3005 982911	MARYAM ALEKSANDROVA	{"email": "aleksandrova_m_1975@postgrespro.ru", "phone": "+70006997839"}
0005432277855	6EB939	0501 029235	NADEZHDA IVANOVA	{"phone": "+70099924371"}
0005432277856	0E4A46	5816 398122	ALEKSANDRA NOVIKOVA	{"phone": "+70238979459"}
0005432277857	A03595	0904 425735	KSENIYA MAKSIMOVA	{"phone": "+70854392234"}
0005432277858	A03595	5901 893219	VIKTOR ALEKSANDROV	{"email": "v_aleksandrov1973@postgrespro.ru", "phone": "+70588871538"}
0005432277859	EDAE09	3694 905873	SOFYA YAKOVLEVA	{"email": "yakovleva-sofya_041975@postgrespro.ru", "phone": "+70465361010"}
0005432277860	119B07	2728 948958	VLADIMIR DAVYDOV	{"phone": "+70853474741"}
0005432277861	119B07	1428 912251	ALEKSANDR NAUMOV	{"phone": "+70628389637"}
0005432277862	A8DC9A	2559 750449	ZULFIYA VLASOVA	{"phone": "+70098265899"}
0005432277864	A8DC9A	0483 940520	ALEKSEY KISELEV	{"email": "a_kiselev-111981@postgrespro.ru", "phone": "+70793172267"}
0005432277865	A8DC9A	5803 913311	ANNA MAKAROVA	{"email": "a.makarova-1974@postgrespro.ru", "phone": "+70724064562"}
0005432277866	5E67C6	1714 429048	ALEKSEY GRIGOREV	{"phone": "+70197576613"}
0005432277867	5E67C6	0796 016458	ANASTASIYA POPOVA	{"email": "popova_a-01021971@postgrespro.ru", "phone": "+70728682584"}
0005432277868	761C42	7570 175594	IRINA AFANASEVA	{"phone": "+70291502647"}
0005432277869	C5DFD1	3410 772226	MAKSIM KUZNECOV	{"email": "mkuznecov.1967@postgrespro.ru", "phone": "+70845387595"}
0005432277870	C5DFD1	5381 352453	IRINA MAKAROVA	{"phone": "+70027777358"}
0005432277871	5C3434	2567 425959	LYUDMILA AKIMOVA	{"phone": "+70621651275"}
0005432277872	20AEDC	8917 602633	ANNA NIKIFOROVA	{"email": "anna-nikiforova_06041965@postgrespro.ru", "phone": "+70327402746"}
0005432277873	2BBAFB	5441 392258	RAISA KRASNOVA	{"phone": "+70148865999"}
0005432277874	2BBAFB	7075 177653	ALEKSANDR DENISOV	{"email": "a.denisov_041976@postgrespro.ru", "phone": "+70110882467"}
0005432277875	5E1834	4777 097302	YURIY DMITRIEV	{"phone": "+70021439707"}
0005432277876	0C392F	6492 262964	NINA FEDOROVA	{"email": "n_fedorova.051970@postgrespro.ru", "phone": "+70660982439"}
0005432277877	0C392F	2588 920827	ZINAIDA VOLKOVA	{"phone": "+70528880432"}
0005432277878	E7550C	7678 886175	VALENTINA MATVEEVA	{"email": "matveeva_v-06021974@postgrespro.ru", "phone": "+70259737805"}
0005432277879	E7550C	7148 148860	OLGA SERGEEVA	{"email": "o_sergeeva03111966@postgrespro.ru", "phone": "+70969020076"}
0005432277880	AD9DD1	8702 072541	SERGEY PETROV	{"email": "petrovsergey.011970@postgrespro.ru", "phone": "+70301219860"}
0005432277881	36D746	4338 114787	ANDREY ZAYCEV	{"email": "andrey-zaycev051984@postgrespro.ru", "phone": "+70395551638"}
0005432277882	36D746	3068 271387	ALEKSANDR FOMIN	{"email": "a.fomin.1964@postgrespro.ru", "phone": "+70402714908"}
0005432277883	3F9320	1715 841448	SERGEY FEDOROV	{"phone": "+70402322415"}
0005432277884	2EE7D3	1041 809713	DENIS EGOROV	{"phone": "+70302268906"}
0005432277885	C38725	2609 091803	MARIYA DAVYDOVA	{"phone": "+70809108409"}
0005432277886	C38725	2401 584072	IGOR NAUMOV	{"email": "naumov_i_10021982@postgrespro.ru", "phone": "+70417303649"}
0005432277887	CE73E1	8644 599045	SERGEY STEPANOV	{"email": "s_stepanov-071980@postgrespro.ru", "phone": "+70130951436"}
0005432277888	243857	1078 923781	ANTON DAVYDOV	{"phone": "+70685799606"}
0005432277889	18D01D	8937 277274	ANDREY MOISEEV	{"phone": "+70332931546"}
0005432277890	023C83	4184 487249	ANASTASIYA KOMAROVA	{"email": "a.komarova041970@postgrespro.ru", "phone": "+70887585146"}
0005432277891	78D0D0	7124 393570	ALEKSANDR GERASIMOV	{"email": "a.gerasimov_051967@postgrespro.ru", "phone": "+70765861321"}
0005432277892	78D0D0	3737 847710	VALENTINA ALEKSEEVA	{"email": "alekseeva-valentina.23081967@postgrespro.ru", "phone": "+70426496094"}
0005432277893	D2F3B1	4520 551897	DMITRIY MAKAROV	{"phone": "+70833970538"}
0005432277894	D2F3B1	1738 948132	BORIS IVANOV	{"phone": "+70526696759"}
0005432277895	653CB0	9912 215698	ZINAIDA KARPOVA	{"phone": "+70229026674"}
0005432277896	653CB0	2611 340929	TATYANA VASILEVA	{"email": "t.vasileva_04111970@postgrespro.ru", "phone": "+70888289512"}
0005432277897	D79777	4276 257222	SERGEY MOISEEV	{"email": "moiseev_s04061979@postgrespro.ru", "phone": "+70176282864"}
0005432277898	D566EB	8140 055514	VLADIMIR IVANOV	{"phone": "+70796692529"}
0005432277899	51869D	9642 023084	VLADIMIR EGOROV	{"email": "v_egorov_16121966@postgrespro.ru", "phone": "+70398326423"}
0005432277900	51869D	1169 714621	LYUDMILA AFANASEVA	{"email": "afanaseva_lyudmila-081968@postgrespro.ru", "phone": "+70045377655"}
0005432277901	970082	5750 510747	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev_1969@postgrespro.ru", "phone": "+70543871000"}
0005432277902	3369E3	3958 263066	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.051977@postgrespro.ru", "phone": "+70140424505"}
0005432277903	3369E3	1106 992778	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr111976@postgrespro.ru", "phone": "+70414895918"}
0005432277904	726384	3967 273732	VALENTINA KUDRYASHOVA	{"email": "kudryashova.v13061975@postgrespro.ru", "phone": "+70511358796"}
0005432277905	06389C	2641 461240	VALERIY NIKOLAEV	{"phone": "+70633758118"}
0005432277906	D51630	7900 751010	NIKOLAY DMITRIEV	{"email": "nikolay-dmitriev02111981@postgrespro.ru", "phone": "+70477956407"}
0005432277907	D51630	6657 086552	ANASTASIYA KALININA	{"phone": "+70711425494"}
0005432277908	3CED9A	7269 863039	ZINAIDA DMITRIEVA	{"phone": "+70900844596"}
0005432277909	0813DC	5979 076260	ALEKSANDR ORLOV	{"email": "aleksandr.orlov.1972@postgrespro.ru", "phone": "+70215327026"}
0005432277910	6B1EB2	3748 207158	NATALYA NESTEROVA	{"email": "natalya-nesterova_12031972@postgrespro.ru", "phone": "+70799200277"}
0005432277911	6B1EB2	0495 591307	KIRILL KUDRYASHOV	{"email": "kudryashov.k1976@postgrespro.ru", "phone": "+70748347886"}
0005432277912	9F380B	9222 325441	NATALYA EFIMOVA	{"phone": "+70218546682"}
0005432277913	F4493F	0152 063004	ROMAN NIKITIN	{"phone": "+70397802144"}
0005432277914	213BE0	0246 453657	IRINA ANTONOVA	{"email": "antonova_i.081975@postgrespro.ru", "phone": "+70237337125"}
0005432277915	5AA964	4042 912721	LARISA KARPOVA	{"email": "karpovalarisa-061973@postgrespro.ru", "phone": "+70301693884"}
0005432277916	5AA964	2551 536327	OLGA YAKOVLEVA	{"phone": "+70510736979"}
0005432277917	F6FF1F	8091 671587	ILYA ALEKSANDROV	{"email": "aleksandrovilya-28051972@postgrespro.ru", "phone": "+70664003705"}
0005432277918	7FB745	5633 771977	ALEKSANDR VOLKOV	{"phone": "+70754195338"}
0005432277919	34699C	0863 847900	MARINA NIKOLAEVA	{"email": "m.nikolaeva-21011969@postgrespro.ru", "phone": "+70851785696"}
0005432277920	34699C	0640 860775	VIKTORIYA MAKSIMOVA	{"email": "viktoriya-maksimova.30071973@postgrespro.ru", "phone": "+70045672260"}
0005432277921	460DDC	9493 582196	ANDREY SEMENOV	{"email": "andrey_semenov11021964@postgrespro.ru", "phone": "+70494177864"}
0005432277922	C454F1	2675 228967	VADIM MOROZOV	{"phone": "+70161764174"}
0005432277923	52850E	2214 997382	NATALYA FROLOVA	{"phone": "+70575598844"}
0005432277924	52850E	0135 415662	EVGENIY MOISEEV	{"phone": "+70922662098"}
0005432277925	B5B272	7525 063942	RAISA GUSEVA	{"email": "guseva.raisa_091969@postgrespro.ru", "phone": "+70019942724"}
0005432277926	ACF24D	3609 629594	SERGEY DENISOV	{"email": "sdenisov-1972@postgrespro.ru", "phone": "+70368989047"}
0005432277927	5A3F42	4733 301571	VALENTINA DAVYDOVA	{"email": "davydovavalentina_121980@postgrespro.ru", "phone": "+70547462495"}
0005432277928	5A3F42	4259 356671	IVAN ZAYCEV	{"phone": "+70997885994"}
0005432277929	269D7A	3019 963049	YULIYA ERMAKOVA	{"email": "ermakovayuliya.1971@postgrespro.ru", "phone": "+70807692059"}
0005432277930	E827AF	4962 156939	NIKOLAY ZAKHAROV	{"phone": "+70602680091"}
0005432277931	29FE9B	1816 668547	ALEKSANDR KOZLOV	{"phone": "+70649365437"}
0005432277932	29FE9B	6906 414547	FAIL TIMOFEEV	{"email": "timofeev-fail.1975@postgrespro.ru", "phone": "+70757480237"}
0005432277933	BC6602	7535 694164	EVGENIY ZHUKOV	{"email": "evgeniy.zhukov011974@postgrespro.ru", "phone": "+70753280933"}
0005432277934	BC6602	8982 091848	GALINA NAUMOVA	{"email": "naumovag091981@postgrespro.ru", "phone": "+70403694508"}
0005432277935	015D4B	4972 299185	SVETLANA BOGDANOVA	{"email": "s-bogdanova-1982@postgrespro.ru", "phone": "+70544575593"}
0005432277936	015D4B	5987 146069	ANATOLIY SOROKIN	{"email": "a-sorokin.011978@postgrespro.ru", "phone": "+70363065569"}
0005432277937	16AA2D	6160 816469	DMITRIY NIKITIN	{"email": "dmitriy.nikitin.1970@postgrespro.ru", "phone": "+70097641801"}
0005432277938	16AA2D	9647 679755	ALEKSEY PAVLOV	{"email": "alekseypavlov-1960@postgrespro.ru", "phone": "+70903045317"}
0005432277939	16AA2D	5638 273121	ALENA SEMENOVA	{"phone": "+70652444299"}
0005432277940	A45367	0609 359882	ALEKSANDR ORLOV	{"phone": "+70682215909"}
0005432277941	88CBE7	3379 114225	NIKOLAY GORBUNOV	{"phone": "+70968579329"}
0005432277942	45820F	4457 590683	KRISTINA NOVIKOVA	{"phone": "+70411528351"}
0005432277943	45820F	4073 011532	OLGA YUDINA	{"email": "olga_yudina.1972@postgrespro.ru", "phone": "+70508802169"}
0005432277944	DF74CC	6519 480638	ALEKSEY TARASOV	{"email": "a-tarasov_1969@postgrespro.ru", "phone": "+70069263259"}
0005432277945	951ECF	1453 304464	SERGEY ABRAMOV	{"phone": "+70893676463"}
0005432277946	BABEB4	5049 293044	OLGA POLYAKOVA	{"phone": "+70599002309"}
0005432277947	2CCF81	7262 817899	EVGENIY ZAKHAROV	{"phone": "+70598176626"}
0005432277948	2CCF81	6342 396630	RINAT ABRAMOV	{"phone": "+70259550592"}
0005432277949	B6CF33	8994 418850	MIKHAIL NIKITIN	{"email": "nikitin_mikhail.051976@postgrespro.ru", "phone": "+70819461227"}
0005432277950	CC596A	0810 034562	VALENTINA KONDRATEVA	{"phone": "+70767197715"}
0005432277951	69BC3A	0617 304486	IVAN FEDOROV	{"email": "i.fedorov_091962@postgrespro.ru", "phone": "+70693417970"}
0005432277952	D74D4A	2073 865077	LYUBOV MAKSIMOVA	{"email": "maksimova.l041970@postgrespro.ru", "phone": "+70143836956"}
0005432277953	D74D4A	5954 129438	IVAN GORBUNOV	{"email": "gorbunov.ivan_1971@postgrespro.ru", "phone": "+70974788530"}
0005432277954	23EE79	5473 948371	TATYANA KOLESNIKOVA	{"email": "kolesnikova-tatyana_1968@postgrespro.ru", "phone": "+70741048453"}
0005432277955	658DAA	7451 692166	ALEKSANDR FEDOROV	{"phone": "+70205803067"}
0005432277956	658DAA	5290 603349	NIKOLAY SERGEEV	{"phone": "+70439792978"}
0005432277957	12BAF6	6756 959955	DMITRIY KOROLEV	{"email": "korolev_d_1971@postgrespro.ru", "phone": "+70854098486"}
0005432277958	D82EE5	6310 235493	NADEZHDA ALEKSEEVA	{"email": "n-alekseeva.041973@postgrespro.ru", "phone": "+70598714663"}
0005432277959	AE9357	3770 267643	ELENA IVANOVA	{"phone": "+70597764054"}
0005432277960	AE9357	8817 247949	OLGA KUZNECOVA	{"email": "olga.kuznecova-21091975@postgrespro.ru", "phone": "+70025356537"}
0005432277961	5CFD25	4156 465238	ALEKSANDR SCHERBAKOV	{"phone": "+70031557721"}
0005432277962	5CFD25	5776 976183	VLADIMIR ILIN	{"phone": "+70585566123"}
0005432277963	F32A22	0997 738243	IVAN GAVRILOV	{"email": "gavrilovivan.1966@postgrespro.ru", "phone": "+70909151745"}
0005432277964	F32A22	9705 822663	DARYA MOISEEVA	{"email": "moiseevad_091984@postgrespro.ru", "phone": "+70491025095"}
0005432277965	F32A22	5396 319077	ELENA SEMENOVA	{"email": "semenova.e.1964@postgrespro.ru", "phone": "+70280225951"}
0005432277966	8EC2BA	2156 100394	ANDREY ZHUKOV	{"email": "zhukov.andrey-041977@postgrespro.ru", "phone": "+70120577271"}
0005432277967	6FC367	1905 388494	ALEKSANDRA VASILEVA	{"email": "vasileva_a.1971@postgrespro.ru", "phone": "+70188034576"}
0005432277968	7FD3F0	1105 149739	OLESYA KOMAROVA	{"phone": "+70263294011"}
0005432277969	0FE8FE	2434 202094	VYACHESLAV STEPANOV	{"phone": "+70047700550"}
0005432277970	8B09CB	1363 958662	VYACHESLAV MATVEEV	{"phone": "+70304378236"}
0005432277971	8B09CB	5893 115206	SHAMIL DENISOV	{"email": "denisovshamil.15061972@postgrespro.ru", "phone": "+70881373939"}
0005432277972	4DFB01	6277 559507	OLEG KULIKOV	{"email": "o_kulikov_091983@postgrespro.ru", "phone": "+70125129065"}
0005432277973	4DFB01	8055 464717	OLGA KOZLOVA	{"email": "olga_kozlova08061978@postgrespro.ru", "phone": "+70547056445"}
0005432277974	0EAAA4	2786 078115	IRINA ANDREEVA	{"email": "i-andreeva1970@postgrespro.ru", "phone": "+70457751946"}
0005432277975	26D10C	8224 209026	IGOR BONDARENKO	{"email": "i.bondarenko-20031965@postgrespro.ru", "phone": "+70408624557"}
0005432277976	BC5492	8111 556595	YURIY TIMOFEEV	{"email": "timofeev-yuriy-1970@postgrespro.ru", "phone": "+70279130220"}
0005432277977	07DE8A	3072 866476	YURIY ORLOV	{"phone": "+70533040740"}
0005432277978	3FFB60	8698 325497	ALEKSANDR MIKHAYLOV	{"phone": "+70419870043"}
0005432277979	3FFB60	0493 784261	ALEKSANDR IVANOV	{"phone": "+70429891946"}
0005432277980	7F6E56	8668 155144	SERGEY KUDRYASHOV	{"email": "kudryashov_sergey1964@postgrespro.ru", "phone": "+70131494935"}
0005432277981	CF95B9	4878 403963	ALEKSEY ISAEV	{"email": "a_isaev-1968@postgrespro.ru", "phone": "+70451123965"}
0005432277982	12CCB9	2454 939216	RAISA AKIMOVA	{"phone": "+70073421729"}
0005432277983	7FF2FF	7015 557695	GALINA PAVLOVA	{"phone": "+70894307474"}
0005432277984	60028C	6314 583866	ARTEM ABRAMOV	{"phone": "+70338589797"}
0005432277985	17CF39	3607 922473	ELENA POPOVA	{"email": "popova.e061957@postgrespro.ru", "phone": "+70227902615"}
0005432277986	740A6D	8554 890472	BOGDAN AFANASEV	{"email": "afanasev-b02121977@postgrespro.ru", "phone": "+70308943897"}
0005432277987	FE0083	2231 101818	KIRILL DENISOV	{"email": "denisov-k.1960@postgrespro.ru", "phone": "+70743569885"}
0005432277988	FE0083	6538 324491	VIKTORIYA ANDREEVA	{"phone": "+70465133384"}
0005432277989	047D7A	4175 280550	VYACHESLAV PETROV	{"phone": "+70460785624"}
0005432277990	610D7F	7027 925703	EDUARD ZHURAVLEV	{"phone": "+70856448291"}
0005432277991	610D7F	8761 718827	LARISA KOROLEVA	{"email": "koroleva-l.25071960@postgrespro.ru", "phone": "+70067028630"}
0005432277992	F900AD	2213 906648	VASILISA KISELEVA	{"email": "kiselevavasilisa.27041972@postgrespro.ru", "phone": "+70261491096"}
0005432277993	F900AD	8219 775619	VLADIMIR ALEKSEEV	{"email": "vladimiralekseev_11081966@postgrespro.ru", "phone": "+70578046230"}
0005432277994	AB2FFF	4601 830394	ARKADIY NOVIKOV	{"email": "novikov_a-14121970@postgrespro.ru", "phone": "+70972555889"}
0005432277995	DE7D36	9543 173008	ALEKSANDR MATVEEV	{"email": "matveev.aleksandr-051976@postgrespro.ru", "phone": "+70327356261"}
0005432277996	DE7D36	0545 347519	OKSANA SEMENOVA	{"phone": "+70882228652"}
0005432277997	0936D5	6391 992287	ANTON SOLOVEV	{"phone": "+70465345910"}
0005432277998	41F818	4314 606648	NATALYA MIRONOVA	{"phone": "+70990078091"}
0005432277999	4A7667	4887 726745	SERGEY ABRAMOV	{"phone": "+70676951355"}
0005432278000	82F028	8814 015712	ALEKSANDRA SAVELEVA	{"email": "saveleva_a_1979@postgrespro.ru", "phone": "+70377358429"}
0005432278001	9A0359	1372 595553	ALEKSANDR BONDARENKO	{"phone": "+70724454462"}
0005432278002	9CB0DB	1784 329474	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.051984@postgrespro.ru", "phone": "+70994337936"}
0005432278003	9CB0DB	7591 774958	GENNADIY GAVRILOV	{"email": "gennadiy.gavrilov-1974@postgrespro.ru", "phone": "+70167519531"}
0005432278004	B4F0B3	7408 533517	YULIYA MATVEEVA	{"phone": "+70353615109"}
0005432278005	60204E	2020 674191	ELENA DMITRIEVA	{"email": "elena_dmitrieva_1960@postgrespro.ru", "phone": "+70110407219"}
0005432278006	60204E	5135 560984	ELENA AKIMOVA	{"email": "e-akimova_1975@postgrespro.ru", "phone": "+70203193514"}
0005432278007	E01118	9198 175969	KONSTANTIN PETROV	{"phone": "+70972582620"}
0005432278008	E01118	8017 023687	VALERIY POPOV	{"email": "popov-v.1974@postgrespro.ru", "phone": "+70924859658"}
0005432278009	33C72A	7442 801007	DMITRIY NIKITIN	{"email": "nikitin_d.04011978@postgrespro.ru", "phone": "+70921214106"}
0005432278010	D20984	6877 253575	TATYANA STEPANOVA	{"email": "stepanova_t_22101973@postgrespro.ru", "phone": "+70567762088"}
0005432278011	D20984	2251 494183	ELIZAVETA GORBUNOVA	{"email": "gorbunovae-061974@postgrespro.ru", "phone": "+70399197992"}
0005432278012	148886	4621 557034	YAROSLAV KISELEV	{"email": "yaroslavkiselev.08111960@postgrespro.ru", "phone": "+70657553892"}
0005432278013	68AA34	6608 563458	ELENA KUZMINA	{"phone": "+70798536976"}
0005432278014	2D505D	6995 121249	ANASTASIYA FEDOROVA	{"email": "fedorova_anastasiya111975@postgrespro.ru", "phone": "+70912926905"}
0005432278015	67BE5A	5538 382785	GALINA ARKHIPOVA	{"phone": "+70076223960"}
0005432278016	4E7559	9725 389693	ELENA MOROZOVA	{"phone": "+70114296692"}
0005432278017	4E7559	0070 593411	VERA GORBUNOVA	{"phone": "+70087589536"}
0005432278018	5D1237	6014 810864	VALENTINA IVANOVA	{"phone": "+70258067009"}
0005432278019	037ADE	4387 086940	LYUDMILA EFREMOVA	{"email": "lyudmilaefremova081969@postgrespro.ru", "phone": "+70116811229"}
0005432278020	A92249	4546 141517	VLADIMIR BARANOV	{"phone": "+70943573413"}
0005432278021	7F1EA1	2889 451415	BOGDAN KISELEV	{"email": "b_kiselev_081978@postgrespro.ru", "phone": "+70081903365"}
0005432278022	7F1EA1	9166 093939	ELENA GORBUNOVA	{"phone": "+70336748208"}
0005432278023	7AC358	5826 812651	MIKHAIL FOMIN	{"email": "fomin-m.081967@postgrespro.ru", "phone": "+70928915806"}
0005432278024	43A10A	2475 361986	VADIM POPOV	{"email": "popov_vadim031969@postgrespro.ru", "phone": "+70685539209"}
0005432278025	43A10A	9428 303928	SERGEY MEDVEDEV	{"email": "medvedev_sergey.031977@postgrespro.ru", "phone": "+70417499151"}
0005432278026	71CA32	8994 673655	RADIK ALEKSEEV	{"phone": "+70202796824"}
0005432278027	71CA32	9021 724316	ANASTASIYA EFIMOVA	{"email": "a_efimova-06081965@postgrespro.ru", "phone": "+70570139120"}
0005432278028	705D60	1475 261947	TATYANA ORLOVA	{"phone": "+70610615153"}
0005432278029	0E88C1	2860 999782	MARIYA LUKYANOVA	{"email": "lukyanova-mariya.27091980@postgrespro.ru", "phone": "+70993244766"}
0005432278030	BB7694	6946 749834	ALEKSANDR DENISOV	{"phone": "+70652838938"}
0005432278031	91EB22	4090 228268	VALERIY ZAKHAROV	{"email": "valeriyzakharov-23101977@postgrespro.ru", "phone": "+70087497489"}
0005432278032	3B4746	3150 504592	GALINA TIKHONOVA	{"phone": "+70065796481"}
0005432278033	838FC9	3306 972543	SERGEY SAVELEV	{"phone": "+70341029963"}
0005432278034	A748B9	8047 717465	LYUDMILA VLASOVA	{"phone": "+70972977986"}
0005432278035	56BED0	2292 724889	OLGA MIKHAYLOVA	{"phone": "+70408970072"}
0005432278036	DDEBBD	2469 122593	MIKHAIL SHEVCHENKO	{"phone": "+70797980623"}
0005432278037	1AF198	1398 927912	ALEKSANDR VASILEV	{"email": "a-vasilev-31051973@postgrespro.ru", "phone": "+70129290246"}
0005432278038	C40E8A	3723 342410	LYUDMILA YUDINA	{"phone": "+70740249377"}
0005432278039	C40E8A	5347 876454	VALENTINA SCHERBAKOVA	{"email": "vscherbakova.081965@postgrespro.ru", "phone": "+70044897747"}
0005432278040	01A936	6664 322630	ALEKSEY TIKHONOV	{"phone": "+70980330153"}
0005432278041	01A936	5409 366256	DANILA OSIPOV	{"phone": "+70096038677"}
0005432278042	199408	2860 676765	OLEG GORBUNOV	{"email": "gorbunov-o051967@postgrespro.ru", "phone": "+70307095511"}
0005432278043	354DB1	1226 644092	IRINA MASLOVA	{"email": "maslova.irina-1956@postgrespro.ru", "phone": "+70023795845"}
0005432278044	401174	9104 085913	VYACHESLAV GERASIMOV	{"phone": "+70795975461"}
0005432278045	ED5D4D	7884 804535	VLADIMIR SCHERBAKOV	{"email": "v-scherbakov-30091970@postgrespro.ru", "phone": "+70377900403"}
0005432278046	293002	4374 828823	YULIYA CHERNOVA	{"email": "chernova_y19061966@postgrespro.ru", "phone": "+70318102983"}
0005432278047	277747	2676 855174	TATYANA OSIPOVA	{"email": "osipova_t-10071967@postgrespro.ru", "phone": "+70063210289"}
0005432278048	8E6509	0399 177018	GALINA KARPOVA	{"email": "karpova-g.041974@postgrespro.ru", "phone": "+70739578864"}
0005432278049	37786A	0960 795121	POLINA VOLKOVA	{"phone": "+70522108561"}
0005432278050	4F2EDC	2509 160870	NADEZHDA ALEKSEEVA	{"phone": "+70936101199"}
0005432278051	B5826A	1947 706290	ALEKSANDR TIKHONOV	{"email": "tikhonov-a02011972@postgrespro.ru", "phone": "+70344109591"}
0005432278052	B5826A	2910 669663	TATYANA POTAPOVA	{"phone": "+70597300903"}
0005432278053	3FC49C	3547 308834	VADIM KAZAKOV	{"phone": "+70966563668"}
0005432278054	FC3869	8878 211228	MIKHAIL IVANOV	{"phone": "+70317443729"}
0005432278055	F62268	5150 689537	MARIYA ALEKSEEVA	{"email": "mariya-alekseeva-031974@postgrespro.ru", "phone": "+70087497000"}
0005432278056	A43219	4519 750260	IGOR SHEVCHENKO	{"phone": "+70220188060"}
0005432278057	7E2056	6056 466045	MARINA MEDVEDEVA	{"email": "m.medvedeva.071976@postgrespro.ru", "phone": "+70041814784"}
0005432278058	18769F	8058 832076	ALEKSEY YAKOVLEV	{"phone": "+70100154596"}
0005432278059	FF11CB	8784 051992	ANASTASIYA SEMENOVA	{"phone": "+70828467515"}
0005432278060	FF11CB	1197 632393	VALENTINA MELNIKOVA	{"email": "valentina-melnikova_1980@postgrespro.ru", "phone": "+70129862768"}
0005432278061	17D144	0593 066253	LYUBOV TROFIMOVA	{"email": "trofimoval_061974@postgrespro.ru", "phone": "+70713073959"}
0005432278062	EBCE4C	6571 730123	ALLA STEPANOVA	{"phone": "+70612166260"}
0005432278063	48590D	3226 283548	VIKTOR MEDVEDEV	{"phone": "+70890544061"}
0005432278064	48590D	9619 985634	VALERIY KARPOV	{"email": "v_karpov.21081973@postgrespro.ru", "phone": "+70422509676"}
0005432278065	A4DFFD	1146 541771	ELENA ALEKSEEVA	{"email": "e.alekseeva_041968@postgrespro.ru", "phone": "+70384042299"}
0005432278066	C6E8D7	7121 819492	NIKOLAY ANDREEV	{"email": "nikolay-andreev.091977@postgrespro.ru", "phone": "+70826140901"}
0005432278067	DE7DEF	5692 253150	OLEG ISAEV	{"phone": "+70137213434"}
0005432278068	DE7DEF	3000 886991	NINA TROFIMOVA	{"email": "n.trofimova-121978@postgrespro.ru", "phone": "+70310358102"}
0005432278069	A8B9E5	6727 869784	LYUDMILA FOMINA	{"phone": "+70700754994"}
0005432278070	AE2436	7589 891425	IRINA MATVEEVA	{"phone": "+70887847418"}
0005432278071	3D6D85	9569 225375	YURIY AFANASEV	{"email": "y.afanasev.09091973@postgrespro.ru", "phone": "+70697847705"}
0005432278072	3D6D85	5646 781084	ELENA FILATOVA	{"email": "filatova-e111976@postgrespro.ru", "phone": "+70313151941"}
0005432278073	F0D148	7671 302559	ALEKSANDR ALEKSEEV	{"phone": "+70699285151"}
0005432278074	95CF22	6821 696358	OLGA KISELEVA	{"email": "kiseleva-olga.071987@postgrespro.ru", "phone": "+70389900669"}
0005432278075	95CF22	4204 670279	EKATERINA ILINA	{"phone": "+70123927396"}
0005432278076	598CEC	9494 060410	ANASTASIYA NIKITINA	{"email": "a.nikitina-03101976@postgrespro.ru", "phone": "+70600152621"}
0005432278077	7EFAFD	2922 515899	SERGEY MIKHAYLOV	{"email": "mikhaylov-sergey22061967@postgrespro.ru", "phone": "+70239093500"}
0005432278078	599F2B	9325 382794	DENIS POPOV	{"email": "d.popov.24021981@postgrespro.ru", "phone": "+70438615265"}
0005432278079	927F0F	0564 260580	VLADIMIR ALEKSEEV	{"phone": "+70860523878"}
0005432278080	982A83	1801 383265	RAMIS POPOV	{"email": "popov-ramis1960@postgrespro.ru", "phone": "+70467676905"}
0005432278081	FB100C	9080 677265	ALEKSANDR MEDVEDEV	{"phone": "+70138745806"}
0005432278082	79AD49	1482 558568	MIKHAIL IVANOV	{"email": "mikhail.ivanov-1969@postgrespro.ru", "phone": "+70172178998"}
0005432278083	8B66A7	4459 603929	VASILIY KRASNOV	{"phone": "+70724195115"}
0005432278084	8B66A7	3971 751278	OLGA SAVELEVA	{"email": "saveleva-o-24091980@postgrespro.ru", "phone": "+70042915939"}
0005432278085	A59882	3376 174644	YULIYA PAVLOVA	{"email": "yuliya_pavlova_031975@postgrespro.ru", "phone": "+70366683771"}
0005432278086	A235B7	3646 598937	ALEKSANDR KARPOV	{"email": "aleksandr-karpov.09061973@postgrespro.ru", "phone": "+70200168994"}
0005432278087	A235B7	4944 375719	ANNA EGOROVA	{"phone": "+70039014483"}
0005432278088	32D698	3315 341660	VLADIMIR BONDARENKO	{"email": "bondarenko.v.101964@postgrespro.ru", "phone": "+70484809479"}
0005432278089	7073CA	3865 765350	TATYANA KUZNECOVA	{"email": "t.kuznecova_111975@postgrespro.ru", "phone": "+70581156379"}
0005432278090	7073CA	4165 648832	GALINA KUZNECOVA	{"phone": "+70311007155"}
0005432278091	3FB531	6983 234720	OLEG ZAKHAROV	{"email": "oleg_zakharov-021974@postgrespro.ru", "phone": "+70125861947"}
0005432278092	3FB531	0882 768653	OLGA KUZNECOVA	{"email": "kuznecova_o_1968@postgrespro.ru", "phone": "+70564817906"}
0005432278093	78EE02	9493 805241	ARTEM KRASNOV	{"phone": "+70987661667"}
0005432278094	1F0099	3441 027329	GENNADIY KOZLOV	{"phone": "+70541620904"}
0005432278095	1F0099	9546 027403	RAISA GAVRILOVA	{"email": "raisagavrilova_1982@postgrespro.ru", "phone": "+70719335007"}
0005432278096	1F0099	5106 795959	ANDREY BONDARENKO	{"phone": "+70095671976"}
0005432278097	D0784C	4906 469312	DMITRIY MIRONOV	{"email": "mironov-d1970@postgrespro.ru", "phone": "+70197449570"}
0005432278098	4C6C0B	1643 106873	SERGEY ROMANOV	{"email": "sromanov101976@postgrespro.ru", "phone": "+70985223052"}
0005432278099	4C6C0B	1234 226265	VADIM BORISOV	{"phone": "+70286188335"}
0005432278100	C901B2	6338 199122	ANNA BORISOVA	{"phone": "+70524153643"}
0005432278101	C901B2	9093 803862	VALERIY GORBUNOV	{"email": "gorbunov_valeriy_1974@postgrespro.ru", "phone": "+70381028849"}
0005432278102	C901B2	9646 925608	OLGA PAVLOVA	{"email": "pavlova_olga-1980@postgrespro.ru", "phone": "+70731609519"}
0005432278103	4C7487	9821 039908	BORIS PETROV	{"email": "b.petrov_22031961@postgrespro.ru", "phone": "+70134868608"}
0005432278104	CCDF07	4201 667892	SERGEY KONOVALOV	{"phone": "+70705923143"}
0005432278105	CCDF07	1437 465491	ILYA FROLOV	{"email": "frolov_ilya-1972@postgrespro.ru", "phone": "+70625313637"}
0005432278106	BD94A6	6852 539766	ALEKSANDRA MEDVEDEVA	{"phone": "+70698090699"}
0005432278107	BD94A6	2458 747596	LYUBOV PETROVA	{"phone": "+70774642189"}
0005432278108	A591B0	4358 941500	RUMIYA ZAKHAROVA	{"email": "zakharova-r-061963@postgrespro.ru", "phone": "+70820483154"}
0005432278109	F5B888	9316 953924	LEONID SERGEEV	{"phone": "+70043456814"}
0005432278110	F5B888	1067 082148	TIMUR ALEKSANDROV	{"phone": "+70242449213"}
0005432278111	D5FAB5	8037 412693	MAKSIM MAKAROV	{"phone": "+70159751850"}
0005432278112	D5FAB5	2097 954261	TATYANA SCHERBAKOVA	{"email": "scherbakova.tatyana_061960@postgrespro.ru", "phone": "+70839252405"}
0005432278113	A0B6CE	9610 254793	SVETLANA SMIRNOVA	{"email": "smirnova.svetlana.21031971@postgrespro.ru", "phone": "+70666969382"}
0005432278114	A0B6CE	7075 297442	VERA SMIRNOVA	{"email": "smirnova-v091977@postgrespro.ru", "phone": "+70974981950"}
0005432278115	29B0EB	6614 736135	VLADIMIR OSIPOV	{"email": "osipov.v.1972@postgrespro.ru", "phone": "+70677097190"}
0005432278116	29B0EB	7078 580446	TAMARA MOISEEVA	{"phone": "+70872529820"}
0005432278117	D483C9	4469 499829	VLADA BORISOVA	{"phone": "+70510101108"}
0005432278118	1F208F	6834 173581	ANNA POPOVA	{"phone": "+70005837576"}
0005432278119	A6F29E	9287 310938	IDA NIKITINA	{"email": "inikitina-051953@postgrespro.ru", "phone": "+70608758295"}
0005432278120	221077	8993 177864	ALEKSEY VOLKOV	{"phone": "+70705724629"}
0005432278121	221077	3841 431906	POLINA VOROBEVA	{"phone": "+70755370871"}
0005432278122	57DA7A	5427 318047	SVETLANA ZAKHAROVA	{"phone": "+70372829147"}
0005432278123	57DA7A	1558 933682	EKATERINA IVANOVA	{"email": "e_ivanova.18071964@postgrespro.ru", "phone": "+70843831724"}
0005432278124	79057E	2449 877031	NINA MAKAROVA	{"phone": "+70427204911"}
0005432278125	F28E5C	8412 548098	DMITRIY ROMANOV	{"phone": "+70273909866"}
0005432278126	E79835	9329 150803	TATYANA AFANASEVA	{"email": "afanaseva-tatyana-01081961@postgrespro.ru", "phone": "+70453143715"}
0005432278127	476B65	3044 097408	OLGA NIKITINA	{"email": "nikitinao071977@postgrespro.ru", "phone": "+70525646134"}
0005432278128	476B65	4345 058048	VALENTIN GORBUNOV	{"email": "gorbunovvalentin.07021980@postgrespro.ru", "phone": "+70040421740"}
0005432278129	2457D2	1674 441330	LYUBOV SOKOLOVA	{"email": "sokolova-l-1966@postgrespro.ru", "phone": "+70138789186"}
0005432278130	2457D2	9153 032549	MARINA SCHERBAKOVA	{"email": "scherbakova-marina.12101977@postgrespro.ru", "phone": "+70510501926"}
0005432278131	9B9A34	7996 075685	VARVARA KOZLOVA	{"phone": "+70930345317"}
0005432278132	B4FA6D	9792 390308	ELINA SERGEEVA	{"email": "e-sergeeva081981@postgrespro.ru", "phone": "+70134821822"}
0005432278133	B4FA6D	8117 799927	SERGEY NAUMOV	{"email": "naumov.sergey.06051985@postgrespro.ru", "phone": "+70728676815"}
0005432278134	BABCC2	9707 805537	NADEZHDA KUZNECOVA	{"phone": "+70037331394"}
0005432278135	B6EA3B	0092 128100	ROMAN MATVEEV	{"email": "rmatveev.041974@postgrespro.ru", "phone": "+70119705979"}
0005432278136	251A05	5529 350482	TATYANA SOKOLOVA	{"phone": "+70340149582"}
0005432278137	251A05	5922 376287	NINA MARTYNOVA	{"email": "martynova_n.091973@postgrespro.ru", "phone": "+70473656874"}
0005432278138	B565CE	4828 823919	ALEKSEY TIKHONOV	{"phone": "+70507885442"}
0005432278139	DE6A92	9048 399339	DMITRIY SIDOROV	{"email": "d-sidorov_10031973@postgrespro.ru", "phone": "+70221354773"}
0005432278140	DE6A92	8886 927815	ARSENIY GRIGOREV	{"email": "agrigorev-1969@postgrespro.ru", "phone": "+70362582353"}
0005432278141	3DB615	9286 182660	TATYANA NAZAROVA	{"phone": "+70578500214"}
0005432278142	B6F174	1768 972086	LEONID PAVLOV	{"email": "pavlov_l.081970@postgrespro.ru", "phone": "+70713243517"}
0005432278143	B6F174	1659 058590	TATYANA DANILOVA	{"email": "t_danilova_1960@postgrespro.ru", "phone": "+70524200795"}
0005432278144	8C1B3C	6739 485280	ALEKSEY AFANASEV	{"phone": "+70946332674"}
0005432278145	526EB6	6668 144490	SERGEY SOROKIN	{"phone": "+70082413250"}
0005432278146	04B222	7826 761998	GALINA POPOVA	{"email": "galina.popova.09121976@postgrespro.ru", "phone": "+70752403943"}
0005432278147	04B222	0042 696012	SERGEY VOLKOV	{"email": "volkovsergey11021973@postgrespro.ru", "phone": "+70136789928"}
0005432278148	DEA909	7398 766851	ANASTASIYA ANTONOVA	{"phone": "+70981607628"}
0005432278149	DEA909	7455 384465	MARIYA TARASOVA	{"email": "tarasova.mariya1987@postgrespro.ru", "phone": "+70577632463"}
0005432278150	7A8850	0056 986319	ANNA TIMOFEEVA	{"email": "timofeeva_anna1977@postgrespro.ru", "phone": "+70925003132"}
0005432278151	104F7E	2774 204991	ANATOLIY SIDOROV	{"email": "sidorov.anatoliy.15071969@postgrespro.ru", "phone": "+70459706238"}
0005432278152	104F7E	9463 283612	ZOYA ILINA	{"email": "zoya-ilina.28071973@postgrespro.ru", "phone": "+70270289753"}
0005432278153	104F7E	5028 762546	OLEG FEDOROV	{"email": "fedorov.o_1964@postgrespro.ru", "phone": "+70610149584"}
0005432278154	780244	7325 851099	OLGA SMIRNOVA	{"email": "olga.smirnova.111984@postgrespro.ru", "phone": "+70936407804"}
0005432278155	405588	6224 450025	NATALYA ALEKSEEVA	{"phone": "+70944257623"}
0005432278156	405588	4857 098163	GEORGIY NIKOLAEV	{"phone": "+70016446976"}
0005432278157	9FFF67	6398 431033	TATYANA MAKAROVA	{"email": "makarova-tatyana-04021975@postgrespro.ru", "phone": "+70814208424"}
0005432278158	9FFF67	4667 816367	DANIL ANTONOV	{"email": "antonovd.081972@postgrespro.ru", "phone": "+70938351529"}
0005432278159	6F16BB	3252 485446	ILYA POPOV	{"phone": "+70840023923"}
0005432278160	CD10C3	1625 015379	ALEKSEY SAVELEV	{"email": "alekseysavelev1963@postgrespro.ru", "phone": "+70261243638"}
0005432278161	CD10C3	9114 492914	YURIY IVANOV	{"phone": "+70535292165"}
0005432278162	BB673F	0038 097991	KONSTANTIN ZAKHAROV	{"phone": "+70150189292"}
0005432278163	66C6A7	3324 023401	MAKSIM DAVYDOV	{"phone": "+70019415262"}
0005432278164	BFCBFB	9504 064994	TATYANA KUDRYASHOVA	{"email": "kudryashovatatyana_051970@postgrespro.ru", "phone": "+70726689520"}
0005432278165	725942	6818 399728	RUFIYA STEPANOVA	{"phone": "+70453879715"}
0005432278166	07AF11	8597 758610	NIKOLAY FROLOV	{"email": "frolov.nikolay-091970@postgrespro.ru", "phone": "+70520690648"}
0005432278167	420FE6	2778 641220	MARINA ZHUKOVA	{"phone": "+70974259872"}
0005432278168	CE31E4	6773 306038	YULIYA ERMAKOVA	{"phone": "+70662084319"}
0005432278169	CE31E4	1050 527283	VALENTINA GRISHINA	{"email": "valentina-grishina-1972@postgrespro.ru", "phone": "+70974521017"}
0005432278170	2CDE14	2265 892211	ALEKSEY POPOV	{"email": "popova_09061977@postgrespro.ru", "phone": "+70603681534"}
0005432278171	3B5D56	8956 298696	EVGENIYA MAKSIMOVA	{"email": "e_maksimova061983@postgrespro.ru", "phone": "+70191654965"}
0005432278172	7A069F	0763 120710	NIKOLAY MOROZOV	{"phone": "+70892896157"}
0005432278173	44B0E8	9866 644663	VLADIMIR KRASNOV	{"email": "krasnov.vladimir_11121983@postgrespro.ru", "phone": "+70614897222"}
0005432278174	441F34	3389 296521	ILYA FILIPPOV	{"phone": "+70301526419"}
0005432278175	A007E0	7475 994961	VERA KUZNECOVA	{"email": "kuznecova-v.1976@postgrespro.ru", "phone": "+70680488841"}
0005432278176	96812F	4906 822801	PAVEL MAKSIMOV	{"phone": "+70488572936"}
0005432278177	70A478	3323 961698	NINA MOISEEVA	{"email": "nina_moiseeva_28031975@postgrespro.ru", "phone": "+70656008181"}
0005432278178	70A478	9456 774852	ALEKSANDR FOMIN	{"phone": "+70030629284"}
0005432278179	B4892C	2490 822946	VALENTINA FADEEVA	{"email": "v-fadeeva-071979@postgrespro.ru", "phone": "+70363747708"}
0005432278180	27B411	3824 352697	LIDIYA POTAPOVA	{"email": "potapova.l-27051979@postgrespro.ru", "phone": "+70729293207"}
0005432278181	27B411	8620 765484	NINA MIRONOVA	{"phone": "+70518188517"}
0005432278182	58BAF1	0908 633614	ZINAIDA KOMAROVA	{"phone": "+70545258889"}
0005432278183	58BAF1	1035 530681	ANDREY VOLKOV	{"email": "a.volkov081977@postgrespro.ru", "phone": "+70611534782"}
0005432278184	399A87	2028 816982	NATALYA IVANOVA	{"phone": "+70704873164"}
0005432278185	F91C93	3615 789466	LIDIYA TROFIMOVA	{"phone": "+70025093564"}
0005432278186	F91C93	1444 965849	ALEKSANDR NAZAROV	{"phone": "+70723395251"}
0005432278187	4C5CAA	5449 165607	MARINA FROLOVA	{"phone": "+70515404545"}
0005432278188	4CD96B	1552 667679	ELENA KISELEVA	{"email": "ekiseleva101958@postgrespro.ru", "phone": "+70572739568"}
0005432278189	B38511	2183 444728	VALERIYA MARTYNOVA	{"email": "valeriya-martynova-1974@postgrespro.ru", "phone": "+70424776534"}
0005432278190	805570	4193 938697	OLGA SMIRNOVA	{"email": "olga-smirnova-1975@postgrespro.ru", "phone": "+70589883896"}
0005432278191	66AFBC	1994 853843	YURIY NIKOLAEV	{"phone": "+70036907492"}
0005432278192	66AFBC	5000 847049	TAMARA AFANASEVA	{"email": "t-afanaseva.011975@postgrespro.ru", "phone": "+70537448436"}
0005432278193	49CA8B	5036 844348	VLADISLAV ISAEV	{"email": "isaev_vladislav-071973@postgrespro.ru", "phone": "+70284516791"}
0005432278194	37BE61	6356 768906	VALERIY PETROV	{"phone": "+70269116993"}
0005432278195	87A731	6969 412504	NATALYA ROMANOVA	{"email": "natalya_romanova-071984@postgrespro.ru", "phone": "+70578981324"}
0005432278196	F317B5	6924 590464	NATALIYA MATVEEVA	{"phone": "+70691062909"}
0005432278197	D590FA	2198 856385	LYUBOV MAKSIMOVA	{"phone": "+70165582348"}
0005432278198	D590FA	1546 418324	OKSANA KUZMINA	{"email": "o.kuzmina-071967@postgrespro.ru", "phone": "+70787775847"}
0005432278199	A611FC	1867 460607	SERGEY ZAKHAROV	{"email": "szakharov_1967@postgrespro.ru", "phone": "+70029861639"}
0005432278200	78CE8C	4300 850161	ALEKSANDR STEPANOV	{"phone": "+70697701181"}
0005432278201	22D963	8121 691955	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a-1962@postgrespro.ru", "phone": "+70894586611"}
0005432278202	C46681	8569 638645	MIKHAIL DENISOV	{"phone": "+70650055239"}
0005432278203	9C0ED1	2494 637364	ALEKSANDR FOMIN	{"email": "a.fomin-1973@postgrespro.ru", "phone": "+70945704430"}
0005432278204	9C0ED1	6809 966592	DMITRIY ZHUKOV	{"email": "d-zhukov-081971@postgrespro.ru", "phone": "+70110463095"}
0005432278205	9C0ED1	9991 025458	ARTEM YAKOVLEV	{"email": "yakovlev_a_051980@postgrespro.ru", "phone": "+70771828773"}
0005432278206	9C0ED1	5583 605816	VIKTOR SIDOROV	{"email": "v_sidorov-1972@postgrespro.ru", "phone": "+70926335054"}
0005432278207	06DC56	4505 625350	ALEVTINA ZHUKOVA	{"phone": "+70628443896"}
0005432278208	A2A15E	6720 070535	DMITRIY SEMENOV	{"email": "semenov_d091975@postgrespro.ru", "phone": "+70252070874"}
0005432278209	A2A15E	3677 235418	KSENIYA FOMINA	{"email": "kseniya-fomina-121980@postgrespro.ru", "phone": "+70036572192"}
0005432279235	CDA8FC	9372 512855	IRINA FROLOVA	{"phone": "+70206277501"}
0005432279236	CDA8FC	7580 290835	VERONIKA GORBUNOVA	{"phone": "+70847930386"}
0005432279237	856BB2	1111 600087	ARTUR ROMANOV	{"phone": "+70794395397"}
0005432279238	856BB2	7857 960919	EKATERINA GRISHINA	{"phone": "+70027031795"}
0005432279239	7A4C54	0380 453140	ELENA RODIONOVA	{"email": "rodionova_elena_1970@postgrespro.ru", "phone": "+70697401267"}
0005432279240	255E50	0607 608521	VALENTINA ZAYCEVA	{"email": "valentina_zayceva_021976@postgrespro.ru", "phone": "+70301609432"}
0005432279241	3BE3DD	0471 044192	SERGEY KRASNOV	{"phone": "+70005430417"}
0005432279242	6C313E	4528 132611	GENNADIY ANDREEV	{"phone": "+70553108187"}
0005432279243	6C313E	4166 453791	TAMARA TIKHONOVA	{"phone": "+70866392694"}
0005432279244	B6CDD2	2651 606832	ALINA DANILOVA	{"phone": "+70611820075"}
0005432279245	0D6CBD	7147 556337	ANTONINA KULIKOVA	{"phone": "+70107758378"}
0005432279246	741718	0843 930591	LYUDMILA ILINA	{"email": "ilinalyudmila-1976@postgrespro.ru", "phone": "+70514240293"}
0005432279247	741718	7702 710440	MARIYA SOROKINA	{"email": "m-sorokina.1970@postgrespro.ru", "phone": "+70332306206"}
0005432279248	3BC90D	2111 069854	ARTEM KOZLOV	{"phone": "+70987543464"}
0005432279249	3BC90D	7276 411565	KSENIYA SMIRNOVA	{"email": "kseniya-smirnova1968@postgrespro.ru", "phone": "+70334951736"}
0005432279250	BF1D28	3739 181879	TATYANA NAUMOVA	{"phone": "+70641275544"}
0005432279251	BF1D28	6110 250514	YULIYA SOLOVEVA	{"email": "yuliyasoloveva.1980@postgrespro.ru", "phone": "+70804610025"}
0005432279252	91503B	7491 473935	VIKTOR SOKOLOV	{"phone": "+70202749898"}
0005432279253	91503B	4646 881772	ALEKSANDRA ORLOVA	{"email": "orlovaaleksandra1977@postgrespro.ru", "phone": "+70754342083"}
0005432279254	78BF2C	1546 270332	TIMOFEY NIKOLAEV	{"email": "timofeynikolaev-1979@postgrespro.ru", "phone": "+70522592818"}
0005432279255	BD9C01	9985 824354	SVETLANA MELNIKOVA	{"email": "melnikovasvetlana1968@postgrespro.ru", "phone": "+70354653676"}
0005432279256	BD9C01	2889 417008	VIKTOR TIMOFEEV	{"phone": "+70260271059"}
0005432279257	ADCBB1	7425 779826	RUSLAN NAZAROV	{"phone": "+70714292190"}
0005432279258	44BF89	4901 983785	VYACHESLAV IVANOV	{"email": "v-ivanov.1965@postgrespro.ru", "phone": "+70941103649"}
0005432279259	1D5CF6	5770 556641	EKATERINA YAKOVLEVA	{"phone": "+70785475082"}
0005432279260	A7AC60	1934 827160	NATALYA RYABOVA	{"email": "ryabovan_051969@postgrespro.ru", "phone": "+70220779579"}
0005432279261	A7AC60	9151 668405	SERGEY PAVLOV	{"email": "sergey.pavlov_1976@postgrespro.ru", "phone": "+70170350697"}
0005432279262	B66C8A	8869 532625	OLGA NIKOLAEVA	{"email": "o-nikolaeva-111975@postgrespro.ru", "phone": "+70330462604"}
0005432279263	D4AE2D	3165 043888	LILIYA MEDVEDEVA	{"email": "medvedeva_liliya_021966@postgrespro.ru", "phone": "+70123045051"}
0005432279264	1B6BAE	5958 367707	MARINA ARKHIPOVA	{"phone": "+70492196869"}
0005432279265	91E474	5475 976288	GALINA GORBUNOVA	{"email": "g-gorbunova.1969@postgrespro.ru", "phone": "+70699371106"}
0005432279266	D19920	9285 478339	NIKOLAY MIKHAYLOV	{"phone": "+70411043682"}
0005432279267	4CEFAF	9829 404978	DMITRIY KAZAKOV	{"email": "dkazakov111972@postgrespro.ru", "phone": "+70988926181"}
0005432279268	4CEFAF	7539 573056	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-24081980@postgrespro.ru", "phone": "+70880119549"}
0005432279269	3937C3	9574 883595	OLEG SCHERBAKOV	{"email": "scherbakovoleg-26041983@postgrespro.ru", "phone": "+70903199624"}
0005432279270	3937C3	9612 321277	VALENTIN KUZNECOV	{"email": "kuznecovvalentin.071978@postgrespro.ru", "phone": "+70569934055"}
0005432279271	60179A	4312 398218	LYUDMILA POTAPOVA	{"email": "l.potapova1968@postgrespro.ru", "phone": "+70444625040"}
0005432279272	64639B	4204 927764	OLGA GORBUNOVA	{"email": "gorbunova_olga_06091978@postgrespro.ru", "phone": "+70963922457"}
0005432279273	D3B9EC	5486 933268	OLGA TIMOFEEVA	{"phone": "+70582755785"}
0005432279274	AF28DB	8473 007975	LYUDMILA KONDRATEVA	{"phone": "+70585608600"}
0005432279275	668E09	9569 972027	TATYANA KAZAKOVA	{"email": "t_kazakova_061985@postgrespro.ru", "phone": "+70013376946"}
0005432279276	BC942A	2479 522154	GRIGORIY ISAEV	{"phone": "+70255719984"}
0005432279277	BC942A	5394 659013	RUSLAN ZHUKOV	{"email": "r_zhukov-031971@postgrespro.ru", "phone": "+70203574654"}
0005432279278	28416B	3076 723304	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova_s.14101958@postgrespro.ru", "phone": "+70892326291"}
0005432279279	A6E3CD	4661 255876	NIKOLAY ZHUKOV	{"phone": "+70718809734"}
0005432279280	79D5AB	5542 203597	NADEZHDA FILATOVA	{"phone": "+70857449358"}
0005432279281	79D5AB	8052 876268	ALEKSANDR ZAKHAROV	{"email": "zakharov_a.1966@postgrespro.ru", "phone": "+70994104263"}
0005432279282	9FE66A	0959 186276	SVETLANA MAKAROVA	{"phone": "+70974732372"}
0005432279283	9FE66A	3466 767843	VLADIMIR VOROBEV	{"email": "v_vorobev09071968@postgrespro.ru", "phone": "+70084030362"}
0005432279284	8F5ECE	8266 501042	TAKHIR SAVELEV	{"email": "t_savelev-031974@postgrespro.ru", "phone": "+70062342655"}
0005432279285	664E63	2019 294789	ALEKSANDR EGOROV	{"email": "aleksandr-egorov.011981@postgrespro.ru", "phone": "+70940348036"}
0005432279286	825B60	4147 751866	ALEKSEY MATVEEV	{"phone": "+70927760227"}
0005432279287	95F012	2975 118442	VLADIMIR ABRAMOV	{"email": "v-abramov.01071962@postgrespro.ru", "phone": "+70410517821"}
0005432279288	5F06DD	9244 080043	IGOR IVANOV	{"phone": "+70304928679"}
0005432279289	DA0E0D	5251 054381	KRISTINA POTAPOVA	{"phone": "+70004113001"}
0005432279290	DA0E0D	9186 945315	ALEKSEY BARANOV	{"phone": "+70100716071"}
0005432279291	7715A6	8863 094500	ELENA GUSEVA	{"email": "elenaguseva051967@postgrespro.ru", "phone": "+70172136307"}
0005432279292	4A0BD6	1558 836274	TAMARA ANISIMOVA	{"email": "tamaraanisimova_09051976@postgrespro.ru", "phone": "+70039295110"}
0005432279293	4A0BD6	5970 246427	VLADIMIR TARASOV	{"email": "vladimir.tarasov_1972@postgrespro.ru", "phone": "+70369517104"}
0005432279294	AD57D6	6368 857212	ANNA KULIKOVA	{"email": "kulikova_anna-041974@postgrespro.ru", "phone": "+70911574743"}
0005432279295	41039E	1401 356126	VIKTORIYA RODIONOVA	{"phone": "+70312591849"}
0005432279296	41039E	8222 934714	ALEKSANDR ROMANOV	{"email": "romanov_a.1970@postgrespro.ru", "phone": "+70855722168"}
0005432279297	E43BB2	5729 230171	MARIYA POPOVA	{"email": "mariya_popova-23041975@postgrespro.ru", "phone": "+70168571148"}
0005432279298	E43BB2	9981 290310	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov.101972@postgrespro.ru", "phone": "+70207487796"}
0005432279299	E43BB2	7915 947544	MARGARITA IVANOVA	{"email": "margarita.ivanova.21011972@postgrespro.ru", "phone": "+70401770769"}
0005432279300	D9FBFA	5169 838705	EVGENIYA KARPOVA	{"email": "karpovae_1983@postgrespro.ru", "phone": "+70871828694"}
0005432279301	D9FBFA	1230 749066	EKATERINA NESTEROVA	{"phone": "+70242960725"}
0005432279302	C341A8	1601 149859	YURIY GORBUNOV	{"email": "gorbunovy-20051966@postgrespro.ru", "phone": "+70967014324"}
0005432279303	C341A8	2489 136652	ALENA EFREMOVA	{"email": "efremova-a.031963@postgrespro.ru", "phone": "+70843260021"}
0005432279304	C341A8	0379 740662	NATALYA NIKIFOROVA	{"phone": "+70550298423"}
0005432279305	C341A8	0422 231791	EKATERINA MAKAROVA	{"email": "e-makarova.13061981@postgrespro.ru", "phone": "+70228367748"}
0005432279306	AA6659	7072 987000	GALINA EGOROVA	{"email": "g-egorova041974@postgrespro.ru", "phone": "+70577460592"}
0005432279307	AA6659	8215 734708	VLADISLAV IVANOV	{"phone": "+70694008548"}
0005432279308	AA6659	1591 729834	LIDIYA POPOVA	{"email": "popova-lidiya1964@postgrespro.ru", "phone": "+70593137869"}
0005432279309	7499A0	9063 694386	KLAVDIYA FROLOVA	{"email": "k.frolova-011978@postgrespro.ru", "phone": "+70709270810"}
0005432279310	4A88A7	3752 591529	YULIYA MIKHAYLOVA	{"phone": "+70645366246"}
0005432279311	F891D7	3815 885375	TATYANA DENISOVA	{"phone": "+70658203054"}
0005432279312	2CA162	2660 820244	EKATERINA AFANASEVA	{"phone": "+70808475262"}
0005432279313	FC9649	3813 742913	ALEKSANDR EGOROV	{"email": "aegorov_061963@postgrespro.ru", "phone": "+70213400145"}
0005432279314	FC9649	1966 985103	ALEKSEY DMITRIEV	{"phone": "+70130490408"}
0005432279315	5F23D6	3361 933778	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov_03111961@postgrespro.ru", "phone": "+70199392759"}
0005432279316	6C66C2	7142 328135	LARISA YAKOVLEVA	{"email": "yakovleva_l1976@postgrespro.ru", "phone": "+70342814491"}
0005432279317	6C66C2	1922 610177	VLADIMIR FOMIN	{"phone": "+70717328362"}
0005432279318	C81EA0	2779 256862	VIKTORIYA TIMOFEEVA	{"email": "v.timofeeva_08051975@postgrespro.ru", "phone": "+70057222308"}
0005432279319	C81EA0	6637 175724	ALINA MAKAROVA	{"email": "makarovaalina-1982@postgrespro.ru", "phone": "+70989168920"}
0005432279320	E1A900	8946 664347	VIKTOR FROLOV	{"email": "frolov_viktor-1988@postgrespro.ru", "phone": "+70707988024"}
0005432279321	3D3DEF	0215 354673	YURIY RODIONOV	{"email": "yrodionov1980@postgrespro.ru", "phone": "+70694713322"}
0005432279322	0FFD2A	5835 966251	NATALYA KOZLOVA	{"phone": "+70074870651"}
0005432279323	6EBB68	8520 581823	TAMARA MAKAROVA	{"email": "tamara_makarova-021961@postgrespro.ru", "phone": "+70786278515"}
0005432279324	C5CF64	8114 574538	VITALIY TIMOFEEV	{"phone": "+70786598394"}
0005432279325	028820	6183 041894	MIKHAIL FILIPPOV	{"email": "filippovmikhail.15041966@postgrespro.ru", "phone": "+70155017279"}
0005432279326	602630	4122 985738	VLADIMIR ISAEV	{"email": "isaev-vladimir1957@postgrespro.ru", "phone": "+70451474323"}
0005432279327	7FC65E	5077 462473	YURIY KUDRYASHOV	{"email": "kudryashov.y-111975@postgrespro.ru", "phone": "+70846209193"}
0005432279328	004B8E	7204 584925	OKSANA CHERNOVA	{"phone": "+70176956457"}
0005432279329	004B8E	8451 315230	KLAVDIYA VLASOVA	{"phone": "+70808920517"}
0005432279330	CA4181	3305 194926	MAKSIM FEDOROV	{"email": "fedorovmaksim.111979@postgrespro.ru", "phone": "+70631534918"}
0005432279331	C19728	1894 671985	ALEKSANDR KOROLEV	{"phone": "+70210082431"}
0005432279332	C19728	9536 357475	MARINA KOZLOVA	{"email": "m.kozlova_29011979@postgrespro.ru", "phone": "+70381747645"}
0005432279333	E02442	2759 164402	VADIM MOROZOV	{"phone": "+70633183286"}
0005432279334	51EB89	5304 403980	GALINA RYABOVA	{"email": "ryabova.galina.081966@postgrespro.ru", "phone": "+70371019922"}
0005432279335	F5F654	0620 122601	OLGA ANDREEVA	{"email": "olgaandreeva.28101969@postgrespro.ru", "phone": "+70323250977"}
0005432279336	F5F654	2005 879079	OKSANA AKIMOVA	{"phone": "+70346177957"}
0005432279337	F5F654	3362 090580	VITALIY CHERNOV	{"phone": "+70953604332"}
0005432279338	C2D2D1	9638 214144	ALEKSANDR KUZNECOV	{"email": "kuznecova_05011983@postgrespro.ru", "phone": "+70297244428"}
0005432282739	8DD719	6273 248444	VLADIMIR GAVRILOV	{"phone": "+70756431900"}
0005432282740	8DD719	9864 886261	LARISA KARPOVA	{"phone": "+70614763290"}
0005432282741	45BADD	0265 101525	EKATERINA ZHUKOVA	{"email": "ekaterina-zhukova.081975@postgrespro.ru", "phone": "+70319722678"}
0005432282742	45BADD	1199 168304	ANATOLIY PETROV	{"phone": "+70935955367"}
0005432282743	F2245C	7594 789590	EKATERINA FOMINA	{"phone": "+70432093614"}
0005432282744	910B15	6977 403748	MARINA SCHERBAKOVA	{"phone": "+70928019920"}
0005432282745	171DE5	2352 113622	IRINA MALYSHEVA	{"phone": "+70907804756"}
0005432282746	171DE5	4365 792979	ALEKSEY STEPANOV	{"email": "stepanova061979@postgrespro.ru", "phone": "+70074908186"}
0005432282747	432F88	2126 833949	VIKTOR BARANOV	{"email": "baranovviktor.11111977@postgrespro.ru", "phone": "+70522917784"}
0005432282748	028011	8527 644774	ALEKSEY SCHERBAKOV	{"phone": "+70121444983"}
0005432282749	028011	5575 207267	ALENA NIKIFOROVA	{"phone": "+70127760110"}
0005432282750	8B629C	2143 722870	NATALYA BORISOVA	{"email": "borisova-n_121973@postgrespro.ru", "phone": "+70875344745"}
0005432282751	E5270E	7431 766341	EVGENIY ZAYCEV	{"phone": "+70328677471"}
0005432282752	6273C1	9896 215508	YANA MARTYNOVA	{"phone": "+70512374992"}
0005432282753	6273C1	3043 109656	VLADISLAV NOVIKOV	{"email": "v.novikov1971@postgrespro.ru", "phone": "+70617921515"}
0005432282754	6273C1	5769 822248	ALEKSANDR VOROBEV	{"phone": "+70726969552"}
0005432282755	375DAB	9836 979071	VALENTINA SIDOROVA	{"phone": "+70142787857"}
0005432282756	375DAB	4525 727528	OLGA BORISOVA	{"email": "olga_borisova-1983@postgrespro.ru", "phone": "+70710237745"}
0005432282757	72CA45	2475 036640	RUZALIYA PETROVA	{"phone": "+70007750982"}
0005432282758	72CA45	7578 494561	VLADIMIR KOROLEV	{"phone": "+70253175230"}
0005432282759	68A364	5448 110936	ELENA KUZNECOVA	{"phone": "+70914403278"}
0005432282760	415435	2974 859094	VLADIMIR KONOVALOV	{"email": "vkonovalov101979@postgrespro.ru", "phone": "+70320451394"}
0005432282761	C9CB08	7792 564357	ZOYA PAVLOVA	{"phone": "+70622816908"}
0005432282762	C2BB61	4210 407042	TAISA KOLESNIKOVA	{"email": "t_kolesnikova_05071979@postgrespro.ru", "phone": "+70859090622"}
0005432282763	12DA06	4973 603829	LARISA ANISIMOVA	{"phone": "+70181785142"}
0005432282764	C8A30B	9046 069987	KONSTANTIN EGOROV	{"email": "konstantin-egorov1970@postgrespro.ru", "phone": "+70763585932"}
0005432282765	B6322C	6081 924819	VALENTINA NAUMOVA	{"phone": "+70663451102"}
0005432282766	B6322C	9459 598774	NIKITA VOLKOV	{"phone": "+70035644442"}
0005432282767	B6322C	3528 729885	IRINA KRASNOVA	{"email": "i-krasnova_121964@postgrespro.ru", "phone": "+70447131760"}
0005432282768	8EBADF	4464 144917	VADIM FILIPPOV	{"phone": "+70398365591"}
0005432282769	79C13E	4944 569053	VYACHESLAV VASILEV	{"email": "vasilev_vyacheslav-081975@postgrespro.ru", "phone": "+70133711946"}
0005432282770	1018EB	4309 099461	VALENTINA GERASIMOVA	{"phone": "+70765562848"}
0005432282771	A30D9A	2235 662789	VASILIY POPOV	{"phone": "+70810518113"}
0005432282772	AD4536	7740 286319	ANATOLIY MIRONOV	{"email": "a-mironov_23011962@postgrespro.ru", "phone": "+70689498829"}
0005432282773	AD4536	8636 756314	MIKHAIL NOVIKOV	{"email": "novikov.mikhail.02101975@postgrespro.ru", "phone": "+70045538369"}
0005432282774	FDD976	9535 529652	OLGA TROFIMOVA	{"phone": "+70755109383"}
0005432282775	FDD976	2281 344168	KLAVDIYA KUZNECOVA	{"phone": "+70846406377"}
0005432282776	62AF9C	7202 360833	NIKOLAY MEDVEDEV	{"phone": "+70484248573"}
0005432282777	62AF9C	7703 979972	LYUBOV ALEKSANDROVA	{"phone": "+70020999795"}
0005432282778	CC0843	9191 882989	ILFAT GUSEV	{"email": "i.gusev_1983@postgrespro.ru", "phone": "+70658455206"}
0005432282779	C27CC4	7510 208892	ANTON OSIPOV	{"email": "anton_osipov-1969@postgrespro.ru", "phone": "+70941869682"}
0005432282780	9F0E80	7323 586708	DMITRIY VASILEV	{"phone": "+70395419850"}
0005432282781	859112	3553 916676	SVETLANA PETROVA	{"email": "s.petrova.29091975@postgrespro.ru", "phone": "+70394491863"}
0005432282782	9B58BF	0392 152643	VIKTORIYA ZAKHAROVA	{"email": "zakharova.viktoriya-1974@postgrespro.ru", "phone": "+70605513861"}
0005432282783	9B58BF	8319 793574	NIKITA POPOV	{"email": "popov_n.01101964@postgrespro.ru", "phone": "+70185639416"}
0005432282784	DC6654	5812 540401	RAMIL YAKOVLEV	{"phone": "+70360869863"}
0005432282785	D9824C	7819 968735	DMITRIY ROMANOV	{"email": "romanov-d1974@postgrespro.ru", "phone": "+70053472739"}
0005432282786	585A68	7617 528194	ANNA KUZMINA	{"phone": "+70093374913"}
0005432282787	1AAEBA	5077 036196	OLGA SOLOVEVA	{"email": "o.soloveva1966@postgrespro.ru", "phone": "+70504210741"}
0005432282788	122B94	6707 105847	MAKSIM MEDVEDEV	{"email": "medvedevmaksim_03101975@postgrespro.ru", "phone": "+70396300217"}
0005432282789	AA8B9B	1965 582532	TATYANA POTAPOVA	{"email": "tatyana-potapova_1970@postgrespro.ru", "phone": "+70499990604"}
0005432282790	A7F28F	6473 217525	NIKOLAY ALEKSEEV	{"phone": "+70483476945"}
0005432282791	F710AD	4502 480609	LARISA ZAKHAROVA	{"email": "zakharova_l.11091982@postgrespro.ru", "phone": "+70027717714"}
0005432282792	F710AD	2401 554834	ANASTASIYA BELYAEVA	{"phone": "+70699408849"}
0005432282793	F710AD	7356 389318	IVAN KONOVALOV	{"phone": "+70329437569"}
0005432282794	6417F5	8673 412678	DAVID PETROV	{"phone": "+70685939716"}
0005432282795	F653E0	8817 508516	GALINA KUZNECOVA	{"phone": "+70263172524"}
0005432282796	12F6EC	6627 910776	YURIY VOLKOV	{"email": "y_volkov-051969@postgrespro.ru", "phone": "+70177866256"}
0005432282797	007AD1	4060 645306	LYUBOV VASILEVA	{"email": "vasileva-lyubov_30031964@postgrespro.ru", "phone": "+70467737164"}
0005432282798	007AD1	9801 094011	VIKTOR SAVELEV	{"email": "v_savelev_1973@postgrespro.ru", "phone": "+70436734343"}
0005432282799	D17B7B	3522 463529	SVETLANA ZAYCEVA	{"email": "svetlana.zayceva.02101976@postgrespro.ru", "phone": "+70051691027"}
0005432282800	5381E3	2127 941229	SERGEY ALEKSEEV	{"phone": "+70962939723"}
0005432282801	361845	0708 215936	OLGA ZAKHAROVA	{"phone": "+70034605199"}
0005432282802	063FA3	5474 873875	FATIMA MOROZOVA	{"phone": "+70147479344"}
0005432282803	454FED	1808 998600	LYUBOV MAKAROVA	{"email": "makarova_l.031961@postgrespro.ru", "phone": "+70783152539"}
0005432282804	F38B28	4134 619704	ALEKSANDRA LUKYANOVA	{"email": "a-lukyanova_071979@postgrespro.ru", "phone": "+70289165379"}
0005432282924	EFA9B5	0704 005536	NIKOLAY KUZMIN	{"phone": "+70523683514"}
0005432282805	74D492	9027 210366	EVGENIY POPOV	{"email": "evgeniypopov.1964@postgrespro.ru", "phone": "+70957313824"}
0005432282806	4C8EF0	3980 862435	DARYA VOLKOVA	{"email": "d-volkova051974@postgrespro.ru", "phone": "+70946662415"}
0005432282807	7988E8	7482 325247	MIKHAIL MARTYNOV	{"phone": "+70423914334"}
0005432282808	7988E8	8773 954276	OKSANA VOROBEVA	{"email": "oksanavorobeva.1979@postgrespro.ru", "phone": "+70923501230"}
0005432282809	D59B0D	4865 208101	MARIYA KONDRATEVA	{"email": "mariyakondrateva1980@postgrespro.ru", "phone": "+70683992049"}
0005432282810	39582D	8877 244108	ALEKSANDR ALEKSEEV	{"email": "alekseeva_12111978@postgrespro.ru", "phone": "+70369224935"}
0005432282811	EC8DD8	8451 677675	OLGA ILINA	{"phone": "+70195155308"}
0005432282812	A6B7B5	7332 289522	ELENA KRASNOVA	{"email": "krasnovaelena_121977@postgrespro.ru", "phone": "+70317400717"}
0005432282813	EF8F0F	2546 924778	IGOR OSIPOV	{"phone": "+70758469513"}
0005432282814	725DF8	9747 266219	LYUDMILA KOZLOVA	{"email": "lyudmilakozlova_27101964@postgrespro.ru", "phone": "+70912276466"}
0005432282815	33C944	2193 222736	VASILIY SERGEEV	{"email": "sergeevv_28111965@postgrespro.ru", "phone": "+70428076601"}
0005432282816	33C944	3570 785494	OLGA KOVALEVA	{"phone": "+70817383104"}
0005432282817	33C944	7455 968926	VALERIY FILIPPOV	{"phone": "+70449864295"}
0005432282818	F88ADE	5907 149978	ANNA ALEKSEEVA	{"email": "a_alekseeva081967@postgrespro.ru", "phone": "+70181633896"}
0005432282819	F88ADE	2987 938095	VALERIYA ZOTOVA	{"phone": "+70356113756"}
0005432282820	55BCD7	2288 359440	LARISA ROMANOVA	{"email": "larisa-romanova-111968@postgrespro.ru", "phone": "+70742956442"}
0005432282821	4916F3	9449 377446	VENIAMIN ZAKHAROV	{"email": "zakharov-v.14081982@postgrespro.ru", "phone": "+70273854086"}
0005432282822	4916F3	0354 609736	IVAN ANDREEV	{"phone": "+70381646253"}
0005432282823	FC5157	5095 868265	POLINA MAKSIMOVA	{"phone": "+70915646078"}
0005432282824	95B4FF	1937 406071	PAVEL SIDOROV	{"phone": "+70728390329"}
0005432282825	95B4FF	0556 665282	ILYA PETROV	{"phone": "+70625704099"}
0005432282826	BB7435	8920 132357	ROZA AFANASEVA	{"email": "rozaafanaseva-31011980@postgrespro.ru", "phone": "+70629705808"}
0005432282827	FF06BD	0751 861206	ALEKSEY NIKITIN	{"email": "nikitin.aleksey.20021971@postgrespro.ru", "phone": "+70971926925"}
0005432282828	4E283D	6261 556833	LIDIYA SERGEEVA	{"phone": "+70669377890"}
0005432282829	14B942	7157 885253	MIKHAIL SIDOROV	{"email": "mikhail_sidorov.17101978@postgrespro.ru", "phone": "+70299403574"}
0005432282830	CDADFA	9840 702436	NATALIYA VOROBEVA	{"phone": "+70362908891"}
0005432282831	CDADFA	9702 154105	VASILIY KUZNECOV	{"phone": "+70617307576"}
0005432282832	D126AD	1891 568741	VIKTORIYA ABRAMOVA	{"phone": "+70745235527"}
0005432282833	082A9E	1830 828998	NIKOLAY CHERNOV	{"phone": "+70226452266"}
0005432282834	082A9E	1404 456057	YURIY IVANOV	{"email": "y-ivanov_1976@postgrespro.ru", "phone": "+70284446857"}
0005432282835	DD5AF5	1321 591823	ANDREY MARTYNOV	{"email": "a_martynov-1974@postgrespro.ru", "phone": "+70658577264"}
0005432282836	DD5AF5	2651 143478	TATYANA NIKOLAEVA	{"email": "nikolaeva_tatyana_1976@postgrespro.ru", "phone": "+70002809869"}
0005432282837	222EDA	4338 910221	VIKTOR ROMANOV	{"phone": "+70771696490"}
0005432282838	222EDA	5653 485293	ANTONINA MELNIKOVA	{"email": "melnikovaa.101968@postgrespro.ru", "phone": "+70662370604"}
0005432282839	32A472	0263 857922	NATALYA YAKOVLEVA	{"phone": "+70285282797"}
0005432282840	32A472	3612 058278	TATYANA RODIONOVA	{"email": "tatyana.rodionova.21041972@postgrespro.ru", "phone": "+70735339597"}
0005432282841	38E608	8136 192518	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy-1971@postgrespro.ru", "phone": "+70907299346"}
0005432282842	B2AAF6	0438 229718	EVGENIY SOROKIN	{"phone": "+70862874424"}
0005432282843	B2AAF6	9878 236039	NATALYA MIKHAYLOVA	{"phone": "+70270212136"}
0005432282844	F755E3	8106 887843	VALENTINA FOMINA	{"phone": "+70860536786"}
0005432282845	F755E3	0545 515995	VLADIMIR SEMENOV	{"phone": "+70476353532"}
0005432282846	650C1D	1251 658860	NINA ANISIMOVA	{"phone": "+70677462327"}
0005432282847	650C1D	8783 756321	NINA IVANOVA	{"email": "ivanova.n1970@postgrespro.ru", "phone": "+70342729114"}
0005432282848	82C60F	7883 124971	NIKOLAY KULIKOV	{"phone": "+70027049259"}
0005432282849	C99CF8	1390 896299	ANNA KOMAROVA	{"phone": "+70606428377"}
0005432282850	C99CF8	9698 908472	VLADIMIR RODIONOV	{"email": "rodionov_vladimir.011973@postgrespro.ru", "phone": "+70719765197"}
0005432282851	3800A1	0478 022928	ANDREY ZAYCEV	{"phone": "+70015932262"}
0005432282852	3800A1	2993 334741	NATALYA VLASOVA	{"phone": "+70331738261"}
0005432282853	E31203	5761 216401	VALERIY IVANOV	{"phone": "+70732633396"}
0005432282854	58366C	5506 046745	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana_051975@postgrespro.ru", "phone": "+70999853914"}
0005432282855	219920	5402 524481	NIKOLAY ISAEV	{"phone": "+70566188431"}
0005432282856	443C4F	2871 930441	VASILIY KULIKOV	{"email": "vasiliy.kulikov_28121977@postgrespro.ru", "phone": "+70977429758"}
0005432282857	20D6DE	6740 757355	ELVIRA PETROVA	{"phone": "+70247662172"}
0005432282858	20D6DE	9461 991285	YULIYA ZAKHAROVA	{"email": "zakharovay1969@postgrespro.ru", "phone": "+70411835461"}
0005432282859	20D6DE	5509 674034	VALENTINA ANISIMOVA	{"email": "anisimova_valentina_1958@postgrespro.ru", "phone": "+70602581787"}
0005432282860	1000DB	5412 790077	ANDREY KAZAKOV	{"email": "kazakov.andrey1963@postgrespro.ru", "phone": "+70840015166"}
0005432282861	78D8A4	5294 426271	KIRILL SCHERBAKOV	{"phone": "+70504525776"}
0005432282862	78D8A4	9461 646419	IRINA ANISIMOVA	{"email": "i_anisimova_111973@postgrespro.ru", "phone": "+70640027994"}
0005432282863	A26C3D	3108 507804	ELENA SEMENOVA	{"phone": "+70677671890"}
0005432282864	C88A1D	5439 951827	ELENA MAKSIMOVA	{"email": "e.maksimova1963@postgrespro.ru", "phone": "+70895732287"}
0005432282865	4D7783	4954 926704	VYACHESLAV ZHUKOV	{"email": "zhukov.v_30051973@postgrespro.ru", "phone": "+70470544085"}
0005432282866	E3A063	4581 108394	TATYANA MAKAROVA	{"email": "makarova-t_061978@postgrespro.ru", "phone": "+70568602384"}
0005432282867	ED1FEF	0262 284640	EVGENIY IVANOV	{"email": "ivanov-e.1987@postgrespro.ru", "phone": "+70780129753"}
0005432282868	ED1FEF	4491 938157	ALIYA FOMINA	{"phone": "+70125009975"}
0005432282869	E1E1AE	5332 709495	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova1969@postgrespro.ru", "phone": "+70732256400"}
0005432282870	E1E1AE	4564 951725	ROZA NIKITINA	{"phone": "+70682127186"}
0005432282871	44CDB6	3629 008992	ARTEM MARTYNOV	{"email": "martynov-artem.091976@postgrespro.ru", "phone": "+70934500518"}
0005432282872	44CDB6	4710 635124	ALEKSANDR ANTONOV	{"email": "antonov_a-101983@postgrespro.ru", "phone": "+70952875279"}
0005432282873	5536C5	5932 007084	SERGEY SCHERBAKOV	{"phone": "+70070336749"}
0005432282874	E7A76F	1210 799581	SVETLANA POLYAKOVA	{"email": "s.polyakova1974@postgrespro.ru", "phone": "+70105775771"}
0005432282875	E7A76F	9842 329510	SVETLANA PETROVA	{"email": "petrova_s_031963@postgrespro.ru", "phone": "+70297482670"}
0005432282876	E7A76F	8992 529729	NATALYA ANISIMOVA	{"email": "anisimova_natalya021969@postgrespro.ru", "phone": "+70819134370"}
0005432282877	C5A59D	4765 496499	VALENTINA NAUMOVA	{"email": "naumova_valentina.24091977@postgrespro.ru", "phone": "+70157292352"}
0005432282878	23B10A	5994 674184	YURIY KUZMIN	{"phone": "+70772810007"}
0005432282879	23B10A	2514 756304	VITALIY DMITRIEV	{"email": "dmitriev-v-121979@postgrespro.ru", "phone": "+70340689134"}
0005432282880	5B0737	7262 609880	TATYANA EGOROVA	{"email": "egorova.tatyana_31081983@postgrespro.ru", "phone": "+70931621771"}
0005432282881	5B0737	9615 713503	LYUBOV MAKAROVA	{"phone": "+70467058784"}
0005432282882	D7B858	6003 036558	LIDIYA IVANOVA	{"email": "ivanova_lidiya-16021977@postgrespro.ru", "phone": "+70785823663"}
0005432282883	FDA62A	2477 086816	GENNADIY ROMANOV	{"email": "romanov-gennadiy-28111968@postgrespro.ru", "phone": "+70029333958"}
0005432282884	FDA62A	7784 961864	OLGA LAZAREVA	{"email": "o_lazareva.051978@postgrespro.ru", "phone": "+70366123733"}
0005432282885	CD5FB4	4378 956829	ZINAIDA TARASOVA	{"phone": "+70701918975"}
0005432282886	511D18	0765 464464	ALEKSEY SAVELEV	{"phone": "+70091807372"}
0005432282887	511D18	3300 736968	VASILIY TIKHONOV	{"email": "tikhonov_vasiliy-1966@postgrespro.ru", "phone": "+70188933144"}
0005432282888	E4AE5A	0116 825029	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey1975@postgrespro.ru", "phone": "+70625597435"}
0005432282889	E4AE5A	9951 904608	VALENTINA ANISIMOVA	{"email": "anisimova_valentina.061973@postgrespro.ru", "phone": "+70579107850"}
0005432282890	E4AE5A	0963 508378	GALINA BELOVA	{"email": "gbelova041969@postgrespro.ru", "phone": "+70492370104"}
0005432282891	E4AE5A	5977 271206	SERGEY BARANOV	{"email": "s.baranov_081961@postgrespro.ru", "phone": "+70923656334"}
0005432282892	06AE1C	1157 565215	EVGENIY KULIKOV	{"phone": "+70836916434"}
0005432282893	06AE1C	1513 199733	DANILA GRIGOREV	{"phone": "+70831710571"}
0005432282894	367F25	1502 268499	EKATERINA KRASNOVA	{"email": "ekaterina-krasnova_1979@postgrespro.ru", "phone": "+70741105115"}
0005432282895	FD82CD	0998 150912	SVETLANA BORISOVA	{"email": "borisova.svetlana-111966@postgrespro.ru", "phone": "+70153491739"}
0005432282896	17446E	5136 980097	OLGA KULIKOVA	{"phone": "+70825620768"}
0005432282897	17446E	7923 206477	DMITRIY BORISOV	{"phone": "+70101956874"}
0005432282898	1F487A	5013 286743	MARIYA YAKOVLEVA	{"email": "yakovleva-mariya_1966@postgrespro.ru", "phone": "+70689223766"}
0005432282899	33EECF	2490 563529	LARISA MAKAROVA	{"email": "makarova.larisa.26021981@postgrespro.ru", "phone": "+70875592784"}
0005432282900	5B4D3C	4811 109785	VLADIMIR SAVELEV	{"email": "savelev_v-1971@postgrespro.ru", "phone": "+70702550833"}
0005432282901	476073	9867 769109	ALEKSANDR ALEKSANDROV	{"email": "aleksandrova.27021968@postgrespro.ru", "phone": "+70100839954"}
0005432282902	476073	4753 828716	IVAN MIRONOV	{"phone": "+70888949211"}
0005432282903	C7294D	3038 699518	IGOR TARASOV	{"email": "tarasov-i-17051974@postgrespro.ru", "phone": "+70628636457"}
0005432282904	F22A2D	1744 276641	DARYA ANDREEVA	{"phone": "+70918886730"}
0005432282905	C5AD93	0866 059618	MIKHAIL SEMENOV	{"email": "semenov_mikhail_09101958@postgrespro.ru", "phone": "+70672479394"}
0005432282906	C7CA26	7884 175943	KLAVDIYA VASILEVA	{"phone": "+70288867299"}
0005432282907	C7CA26	0852 197187	MADINA IVANOVA	{"email": "ivanova_m1975@postgrespro.ru", "phone": "+70132630011"}
0005432282908	C7A8A7	2453 100964	RAIL BELOV	{"phone": "+70929096895"}
0005432282909	C60DD7	4209 925991	DMITRIY FILIPPOV	{"email": "dmitriyfilippov_08041969@postgrespro.ru", "phone": "+70728884081"}
0005432282910	C60DD7	5789 628234	DENIS STEPANOV	{"email": "d_stepanov-1973@postgrespro.ru", "phone": "+70717078751"}
0005432282911	40ABB5	8572 794287	TATYANA IVANOVA	{"phone": "+70377111463"}
0005432282912	40ABB5	6764 618091	MARIYA SERGEEVA	{"phone": "+70922667281"}
0005432282913	40ABB5	5639 442433	ELENA KUZNECOVA	{"email": "kuznecovaelena_121965@postgrespro.ru", "phone": "+70175892111"}
0005432282914	B85128	7206 287972	YURIY MELNIKOV	{"phone": "+70163685500"}
0005432282915	B85128	1652 973886	VARVARA EGOROVA	{"phone": "+70743878339"}
0005432282916	B85128	4286 874316	ALEKSEY MIKHAYLOV	{"phone": "+70209586313"}
0005432282917	48A119	3690 126970	VLADIMIR KUDRYASHOV	{"phone": "+70409357258"}
0005432282918	18F0DE	9532 427953	LYUDMILA MELNIKOVA	{"email": "lyudmila-melnikova.031966@postgrespro.ru", "phone": "+70263119238"}
0005432282919	18F0DE	7285 408030	NINA DANILOVA	{"email": "ninadanilova_091970@postgrespro.ru", "phone": "+70477067755"}
0005432282920	7CBA66	3066 967883	ARINA IVANOVA	{"phone": "+70013346820"}
0005432282921	A226B1	7003 783494	NELLI KOROLEVA	{"phone": "+70570645310"}
0005432282922	25CA78	4774 125947	IRINA STEPANOVA	{"email": "stepanovai15091966@postgrespro.ru", "phone": "+70713776255"}
0005432282923	EFA9B5	0688 253625	VIKTORIYA PAVLOVA	{"email": "viktoriya_pavlova-03111979@postgrespro.ru", "phone": "+70938006719"}
0005432282925	B9F464	1749 263971	NINA ORLOVA	{"phone": "+70093546792"}
0005432282926	B8F27B	2769 091319	ALLA ILINA	{"email": "a.ilina-21101973@postgrespro.ru", "phone": "+70195181245"}
0005432282927	B8F27B	7097 291354	MIKHAIL GORBUNOV	{"phone": "+70039961599"}
0005432282928	7C2B09	2967 296459	VALERIY GERASIMOV	{"email": "gerasimov.v.021972@postgrespro.ru", "phone": "+70847304107"}
0005432282929	656C0C	2742 969359	YURIY VOROBEV	{"phone": "+70977773496"}
0005432282930	266D27	5893 868536	TATYANA DANILOVA	{"phone": "+70665995739"}
0005432282931	266D27	4374 775579	ARTEM IVANOV	{"email": "artem-ivanov_101980@postgrespro.ru", "phone": "+70312623070"}
0005432282932	2E3783	4657 233040	LIYA YUDINA	{"email": "yudinaliya_1973@postgrespro.ru", "phone": "+70745760377"}
0005432282933	0DFC4E	1052 350677	IGOR VASILEV	{"email": "igor.vasilev051970@postgrespro.ru", "phone": "+70916289693"}
0005432282934	1144E4	7166 627227	KLAVDIYA LUKYANOVA	{"phone": "+70168725647"}
0005432282935	57C1DB	1907 705297	YULIYA SOROKINA	{"phone": "+70779411715"}
0005432282936	57C1DB	4314 937714	PAVEL SOLOVEV	{"phone": "+70906804840"}
0005432282937	700923	8407 658971	ALEKSEY KISELEV	{"email": "kiselev-a1974@postgrespro.ru", "phone": "+70554188659"}
0005432282938	700923	1128 728982	LARISA IVANOVA	{"email": "l_ivanova_1969@postgrespro.ru", "phone": "+70751113534"}
0005432282939	144721	2645 674175	IGOR VASILEV	{"email": "vasilev_i_1972@postgrespro.ru", "phone": "+70838665171"}
0005432282940	144721	2700 607008	VLADIMIR KOROLEV	{"email": "v-korolev-26111963@postgrespro.ru", "phone": "+70495262872"}
0005432282941	92DFC1	5618 592897	ARINA ROMANOVA	{"email": "romanova-arina111972@postgrespro.ru", "phone": "+70329065938"}
0005432282942	92DFC1	1944 837763	ANNA STEPANOVA	{"email": "stepanova-anna_031986@postgrespro.ru", "phone": "+70560057040"}
0005432282943	5E4696	7681 896828	ILYA MAKAROV	{"email": "makarov-i.061966@postgrespro.ru", "phone": "+70335201673"}
0005432282944	710D99	2686 025124	ANNA ALEKSANDROVA	{"phone": "+70830873302"}
0005432282945	710D99	1524 460043	ALEKSEY IVANOV	{"phone": "+70593294917"}
0005432282946	6AD685	3373 806207	VLADIMIR ROMANOV	{"email": "romanovvladimir.1972@postgrespro.ru", "phone": "+70544183225"}
0005432282947	B127C5	7529 109334	SEMEN SOROKIN	{"email": "sorokin.s.011966@postgrespro.ru", "phone": "+70294935179"}
0005432282948	5BBF92	7425 310603	VALENTINA AFANASEVA	{"phone": "+70972840886"}
0005432282949	11E5DD	3713 682695	LIDIYA SMIRNOVA	{"email": "l.smirnova.1972@postgrespro.ru", "phone": "+70854558507"}
0005432282950	377A34	7441 363012	ALEKSEY GERASIMOV	{"phone": "+70968840502"}
0005432282951	097F18	0462 056016	SERGEY STEPANOV	{"email": "sergey_stepanov-08121968@postgrespro.ru", "phone": "+70990824361"}
0005432282952	A8FE6B	0071 469433	ANATOLIY BORISOV	{"phone": "+70675791495"}
0005432282953	A8FE6B	1356 699323	TATYANA SEMENOVA	{"email": "semenovat-17061975@postgrespro.ru", "phone": "+70790251955"}
0005432282954	E0BB20	8363 842633	ROMAN EGOROV	{"email": "egorovr071976@postgrespro.ru", "phone": "+70265543940"}
0005432282955	154E6E	7057 353813	TATYANA NIKITINA	{"phone": "+70217672211"}
0005432282956	154E6E	5910 582005	NINA KUZNECOVA	{"email": "kuznecova_nina-091974@postgrespro.ru", "phone": "+70917814780"}
0005432282957	61A417	9607 602382	TATYANA SOLOVEVA	{"email": "soloveva.tatyana051980@postgrespro.ru", "phone": "+70187786878"}
0005432282958	E197F9	1307 866821	ALENA SAVELEVA	{"phone": "+70270653657"}
0005432282959	E94BEE	2006 382571	MARIYA OSIPOVA	{"email": "mariya.osipova_01061968@postgrespro.ru", "phone": "+70180616998"}
0005432282960	E94BEE	2754 474157	LEONID TARASOV	{"email": "tarasov_l1963@postgrespro.ru", "phone": "+70160753332"}
0005432282961	CBE3C8	5154 544653	IVAN BELOV	{"email": "belov-ivan_091972@postgrespro.ru", "phone": "+70346124758"}
0005432282962	60079B	0965 082416	SVETLANA KONDRATEVA	{"email": "kondrateva-s_1964@postgrespro.ru", "phone": "+70808824082"}
0005432282963	60079B	5943 278710	MARIYA IVANOVA	{"email": "ivanova.mariya031968@postgrespro.ru", "phone": "+70769364693"}
0005432282964	0995FA	4818 245807	ALEKSANDRA SOKOLOVA	{"email": "sokolova.a-23011970@postgrespro.ru", "phone": "+70140715773"}
0005432282965	09AFE6	1969 307418	DMITRIY KONOVALOV	{"email": "konovalov.dmitriy_071979@postgrespro.ru", "phone": "+70713965335"}
0005432282966	851EE4	3219 009207	SERGEY GAVRILOV	{"email": "gavrilovsergey10081961@postgrespro.ru", "phone": "+70529774078"}
0005432282967	25A885	6904 917873	SVETLANA ORLOVA	{"email": "orlova_s_011981@postgrespro.ru", "phone": "+70724154674"}
0005432282968	7B303F	3763 295451	ANDREY DMITRIEV	{"email": "andrey.dmitriev01021965@postgrespro.ru", "phone": "+70971226356"}
0005432282969	936072	4796 753419	VITALIY SCHERBAKOV	{"phone": "+70069531969"}
0005432282970	E996A7	5605 927744	OLGA IVANOVA	{"phone": "+70204895322"}
0005432282971	E996A7	3257 076439	MARINA KUZNECOVA	{"email": "mkuznecova-1967@postgrespro.ru", "phone": "+70963186801"}
0005432282972	8DF064	2562 770797	KONSTANTIN DENISOV	{"phone": "+70786141028"}
0005432282973	5D7C9D	6266 844404	SERGEY GORBUNOV	{"email": "gorbunovs10041958@postgrespro.ru", "phone": "+70640379608"}
0005432282974	8C515C	5585 304685	VALENTIN ILIN	{"phone": "+70643852429"}
0005432282975	EBD938	1878 711405	DARYA PAVLOVA	{"phone": "+70969945586"}
0005432282976	8E2025	0159 936176	DANIIL GERASIMOV	{"email": "dgerasimov-1972@postgrespro.ru", "phone": "+70246674515"}
0005432282977	89EDCD	6724 895823	FARIDA ZAYCEVA	{"email": "f_zayceva.1960@postgrespro.ru", "phone": "+70740089253"}
0005432282978	885599	9683 150769	ALEKSANDR MAKSIMOV	{"phone": "+70131807302"}
0005432282979	885599	9771 888419	NIKOLAY KUZMIN	{"email": "kuzmin_nikolay-1964@postgrespro.ru", "phone": "+70671121768"}
0005432282980	9686E7	6777 898118	IRINA DAVYDOVA	{"phone": "+70967248375"}
0005432282981	3367CA	9114 362187	VADIM KUZNECOV	{"phone": "+70472372368"}
0005432282982	A243EE	9281 545965	ALEKSEY ZAYCEV	{"email": "zayceva23091962@postgrespro.ru", "phone": "+70894772389"}
0005432282983	6DB1FB	1585 183381	VALENTINA KALININA	{"phone": "+70245474485"}
0005432282984	711DF3	2821 917060	VALENTINA CHERNOVA	{"email": "v_chernova11071967@postgrespro.ru", "phone": "+70382649089"}
0005432282985	FCFF06	5344 368876	ALEKSANDR IVANOV	{"email": "aivanov.22071960@postgrespro.ru", "phone": "+70356983659"}
0005432282986	B4D086	1488 748507	ANATOLIY PETROV	{"email": "anatoliy.petrov-041979@postgrespro.ru", "phone": "+70467788701"}
0005432282987	1B49E3	6164 088589	SERGEY POPOV	{"email": "sergey-popov1972@postgrespro.ru", "phone": "+70551737233"}
0005432282988	040B5D	2370 538082	SERGEY BELOV	{"email": "sbelov29031979@postgrespro.ru", "phone": "+70383243586"}
0005432282989	FD8582	0325 286256	VLADIMIR KUZNECOV	{"phone": "+70744081889"}
0005432282990	FD8582	2665 039489	EDUARD OSIPOV	{"phone": "+70585774997"}
0005432282991	21FAE9	6835 227083	NIKOLAY KISELEV	{"phone": "+70352444931"}
0005432282992	21FAE9	3007 418252	MARIANNA MAKAROVA	{"phone": "+70387525718"}
0005432282993	932822	9082 723780	ELENA VASILEVA	{"phone": "+70751607397"}
0005432282994	E0810A	8108 711745	YULIYA ZAYCEVA	{"phone": "+70650777695"}
0005432282995	E0810A	9573 317066	VLADIMIR ALEKSEEV	{"phone": "+70271049851"}
0005432282996	91D0B8	7250 609246	YAKOV KUDRYASHOV	{"email": "y-kudryashov-21101968@postgrespro.ru", "phone": "+70859380697"}
0005432282997	91D0B8	9154 169177	LYUDMILA FEDOROVA	{"phone": "+70060888407"}
0005432282998	DFBE81	2947 035081	MARIYA BOGDANOVA	{"email": "bogdanovamariya-04011968@postgrespro.ru", "phone": "+70081988643"}
0005432282999	9BB4D7	0706 414152	OLGA TIMOFEEVA	{"phone": "+70249430255"}
0005432283000	9B2B02	6599 066974	MIKHAIL KARPOV	{"phone": "+70898116298"}
0005432283001	14C016	2948 098076	EKATERINA IVANOVA	{"phone": "+70584214730"}
0005432283002	D648E1	6271 718449	LEONID ILIN	{"phone": "+70260813009"}
0005432283003	4B99F1	5544 703280	NADEZHDA ROMANOVA	{"email": "romanova-n.26091962@postgrespro.ru", "phone": "+70343413360"}
0005432283004	4B99F1	1632 132155	VLADIMIR KARPOV	{"email": "vladimir_karpov.031974@postgrespro.ru", "phone": "+70806410833"}
0005432283005	45C4F9	8522 010495	VASILIY SIDOROV	{"email": "v-sidorov_1969@postgrespro.ru", "phone": "+70456165815"}
0005432283006	45C4F9	5183 431070	VIKTORIYA VASILEVA	{"email": "viktoriya.vasileva_02051964@postgrespro.ru", "phone": "+70260165448"}
0005432283007	D49AA4	9338 527406	YULIYA GAVRILOVA	{"email": "yuliya_gavrilova111975@postgrespro.ru", "phone": "+70678490339"}
0005432283008	5A4FF2	3287 020075	ALEKSANDR KULIKOV	{"email": "aleksandr-kulikov-031985@postgrespro.ru", "phone": "+70502457668"}
0005432283009	5A4FF2	2600 776036	DMITRIY ANTONOV	{"phone": "+70842934913"}
0005432283010	0BEED3	5839 635401	GALINA DAVYDOVA	{"phone": "+70014076946"}
0005432283011	F48254	5980 660735	VITALIY KOROLEV	{"email": "korolevvitaliy.041976@postgrespro.ru", "phone": "+70307022305"}
0005432283012	60C03E	3285 930200	DENIS KULIKOV	{"phone": "+70527337648"}
0005432283013	60C03E	2555 140852	ZOYA KUZNECOVA	{"email": "kuznecovaz16111970@postgrespro.ru", "phone": "+70432582444"}
0005432283014	82DE1C	0458 201948	GALINA NAZAROVA	{"phone": "+70469560287"}
0005432283015	AC875A	4947 312929	MAKSIM VOROBEV	{"email": "maksimvorobev051965@postgrespro.ru", "phone": "+70176078712"}
0005432283016	F6F0C2	6357 876625	ALEKSANDR IVANOV	{"email": "aivanov-02051983@postgrespro.ru", "phone": "+70351492765"}
0005432283017	540BD7	0824 924428	ARINA OSIPOVA	{"email": "osipovaa1986@postgrespro.ru", "phone": "+70422445910"}
0005432283018	13DE31	9760 616982	ALEKSEY ZAKHAROV	{"phone": "+70980536508"}
0005432283019	88F86E	2100 941807	IVAN BARANOV	{"phone": "+70757519998"}
0005432283020	6CB036	6313 725530	NATALYA ORLOVA	{"email": "natalya-orlova1961@postgrespro.ru", "phone": "+70623136681"}
0005432283021	1C1570	1998 236944	TATYANA IVANOVA	{"email": "ivanova_tatyana1971@postgrespro.ru", "phone": "+70385500684"}
0005432283022	1C1570	6377 660647	ALEKSANDRA KARPOVA	{"phone": "+70965219688"}
0005432283023	A9662D	5957 135918	DMITRIY DMITRIEV	{"phone": "+70891627147"}
0005432283024	A9662D	2241 762467	MAKSIM IVANOV	{"phone": "+70509533292"}
0005432283025	537A49	6161 255459	SERGEY IVANOV	{"email": "ivanov.sergey-1968@postgrespro.ru", "phone": "+70859064647"}
0005432283026	537A49	7382 059108	MARIYA KOROLEVA	{"email": "koroleva.mariya_1972@postgrespro.ru", "phone": "+70506346106"}
0005432283027	993697	0520 309493	ANDREY EGOROV	{"email": "a.egorov-23011967@postgrespro.ru", "phone": "+70881843965"}
0005432283028	878F56	6412 291283	NIKOLAY ROMANOV	{"phone": "+70304183148"}
0005432283029	B46F86	3069 214703	ANNA KOROLEVA	{"phone": "+70231342655"}
0005432283030	F58F94	0421 104879	PETR ANTONOV	{"phone": "+70308590817"}
0005432283031	EEFD52	5252 111389	VLADIMIR ZHUKOV	{"phone": "+70470950941"}
0005432283032	B3A748	9742 289444	VLADIMIR VASILEV	{"phone": "+70980004309"}
0005432283033	3F79DC	4077 772652	LYUDMILA DENISOVA	{"phone": "+70738636773"}
0005432283034	3F79DC	6870 176420	VIKTOR ROMANOV	{"email": "romanovviktor.01041981@postgrespro.ru", "phone": "+70790277723"}
0005432283035	3F79DC	7301 919019	NINA IVANOVA	{"email": "nina-ivanova_101953@postgrespro.ru", "phone": "+70050114819"}
0005432283036	5111C6	0649 511839	IGOR PETROV	{"email": "igor.petrov.10041985@postgrespro.ru", "phone": "+70810048096"}
0005432283037	2CC2FF	3585 015281	EVGENIYA PAVLOVA	{"phone": "+70126063953"}
0005432283038	69B3F3	8971 307737	SERGEY BARANOV	{"phone": "+70307489566"}
0005432283039	600329	8215 032594	ANATOLIY KOROLEV	{"email": "anatoliy-korolev-1963@postgrespro.ru", "phone": "+70318312173"}
0005432283040	13E404	5329 668402	GALINA KARPOVA	{"email": "galina.karpova-1974@postgrespro.ru", "phone": "+70917087452"}
0005432283041	13E404	1103 719482	LARISA KUDRYASHOVA	{"phone": "+70511902123"}
0005432283042	D844E8	3615 567254	MARIYA POLYAKOVA	{"email": "polyakova.mariya1980@postgrespro.ru", "phone": "+70509316523"}
0005432283043	EF4781	4332 274889	SERGEY BONDARENKO	{"email": "bondarenko_s23031977@postgrespro.ru", "phone": "+70792880353"}
0005432283044	EF4781	5098 098750	ILYA ROMANOV	{"email": "ilyaromanov29111970@postgrespro.ru", "phone": "+70737038477"}
0005432283045	65DDAE	3770 332567	EVGENIY BARANOV	{"email": "baranov_e061973@postgrespro.ru", "phone": "+70893465371"}
0005432283046	122070	4931 641786	EVGENIY EGOROV	{"email": "e.egorov1967@postgrespro.ru", "phone": "+70132708047"}
0005432283047	08BA9C	3317 708774	IRINA IVANOVA	{"phone": "+70335539677"}
0005432283048	B6E205	8074 599533	LYUBOV ISAEVA	{"phone": "+70819221742"}
0005432283049	E2F3B2	3824 814019	ANATOLIY SOROKIN	{"email": "a.sorokin_1971@postgrespro.ru", "phone": "+70374438882"}
0005432283050	E2F3B2	6340 718877	MARINA ZHUKOVA	{"phone": "+70445504891"}
0005432283051	375BBF	0524 909910	DMITRIY NIKITIN	{"phone": "+70053061447"}
0005432283052	716A27	9022 858963	TATYANA ANISIMOVA	{"email": "anisimovatatyana-1972@postgrespro.ru", "phone": "+70849797094"}
0005432283053	EA1DB3	8077 791493	TATYANA MEDVEDEVA	{"email": "tatyanamedvedeva.061965@postgrespro.ru", "phone": "+70835041425"}
0005432283054	71DD99	9474 048510	TAMARA IVANOVA	{"phone": "+70141255054"}
0005432283055	A888EE	7619 961127	ANDREY GERASIMOV	{"email": "gerasimov-andrey-011979@postgrespro.ru", "phone": "+70498805186"}
0005432283056	A888EE	2831 721378	ROMAN IVANOV	{"email": "ivanov.roman_021960@postgrespro.ru", "phone": "+70752259483"}
0005432283057	A888EE	4153 462626	ALEKSEY BELOV	{"email": "a.belov_011972@postgrespro.ru", "phone": "+70634638044"}
0005432283058	11ABB3	6285 391390	LYUBOV KULIKOVA	{"email": "lkulikova.1981@postgrespro.ru", "phone": "+70101040678"}
0005432283059	11ABB3	5317 596880	DMITRIY KARPOV	{"email": "karpov_d.1964@postgrespro.ru", "phone": "+70080265619"}
0005432283060	B1113F	1786 857031	NIKOLAY KOZLOV	{"phone": "+70032770561"}
0005432283061	B1113F	9401 536690	GALINA ABRAMOVA	{"phone": "+70462492640"}
0005432283062	A10944	9646 468150	NIKITA DMITRIEV	{"phone": "+70892269821"}
0005432283063	B05205	2842 676278	NADEZHDA GORBUNOVA	{"phone": "+70396096758"}
0005432283064	86F32A	2482 029533	NIKOLAY IVANOV	{"email": "n.ivanov.18051983@postgrespro.ru", "phone": "+70081357517"}
0005432283065	86F32A	2779 018525	ZOYA MAKAROVA	{"phone": "+70897447043"}
0005432283066	EB943A	4688 134268	ALEKSANDR ORLOV	{"phone": "+70376250514"}
0005432283067	EB943A	2494 842318	SVETLANA SCHERBAKOVA	{"email": "scherbakova.s.1980@postgrespro.ru", "phone": "+70103032058"}
0005432283068	F24984	2035 785407	ANATOLIY KOZLOV	{"phone": "+70001057647"}
0005432284628	C5AE99	9532 869642	EVGENIY KONOVALOV	{"phone": "+70624399525"}
0005432284505	74427B	8467 414586	OLGA MARTYNOVA	{"email": "o.martynova.04051977@postgrespro.ru", "phone": "+70840022486"}
0005432284506	74427B	6778 447756	VALENTINA NAZAROVA	{"phone": "+70122346404"}
0005432284507	74427B	4812 196163	ALEKSANDR ILIN	{"phone": "+70921860000"}
0005432284508	74427B	2788 605670	ANNA FILIPPOVA	{"email": "filippova-a.10081962@postgrespro.ru", "phone": "+70832552101"}
0005432284509	725645	3193 050417	ALEKSANDR GAVRILOV	{"email": "gavrilov.aleksandr.1979@postgrespro.ru", "phone": "+70069008919"}
0005432284510	21E552	5681 942031	ZOYA MATVEEVA	{"phone": "+70669377872"}
0005432284511	315C90	9039 275266	NADEZHDA ANISIMOVA	{"phone": "+70626535974"}
0005432284512	315C90	3593 262910	NINA VOROBEVA	{"phone": "+70261173898"}
0005432284513	C58316	3513 919750	VALENTINA KAZAKOVA	{"email": "kazakova.valentina13101969@postgrespro.ru", "phone": "+70353986075"}
0005432284514	C58316	3488 761400	VLADIMIR NAUMOV	{"phone": "+70319283801"}
0005432284515	AE9E3D	5984 800601	STANISLAV GORBUNOV	{"phone": "+70766229995"}
0005432284629	736CFC	0097 762003	ELENA KUZMINA	{"phone": "+70481431899"}
0005432284516	1E9178	3669 866934	YANA ALEKSANDROVA	{"email": "yanaaleksandrova-091973@postgrespro.ru", "phone": "+70748665410"}
0005432284517	1E9178	2959 023645	SERGEY GERASIMOV	{"phone": "+70733606988"}
0005432284518	8D4A0F	1319 255350	GEORGIY TIMOFEEV	{"email": "georgiy.timofeev30111975@postgrespro.ru", "phone": "+70991473951"}
0005432284519	8D4A0F	8095 890274	VYACHESLAV KARPOV	{"phone": "+70525040195"}
0005432284520	820984	0113 030550	MIKHAIL KUZNECOV	{"phone": "+70990893631"}
0005432284521	820984	2207 144373	TATYANA NIKOLAEVA	{"email": "t-nikolaeva-30041978@postgrespro.ru", "phone": "+70896898365"}
0005432284522	7B65DA	7462 200830	KRISTINA VLASOVA	{"phone": "+70268569243"}
0005432284523	7B65DA	4263 207250	ALEKSANDR DAVYDOV	{"phone": "+70042643068"}
0005432284524	F31FE8	0805 282666	YURIY GAVRILOV	{"email": "gavrilovy-1984@postgrespro.ru", "phone": "+70440428238"}
0005432284525	72475B	3722 352542	ROMAN KOROLEV	{"phone": "+70460213807"}
0005432284526	665544	8810 958452	MIKHAIL ANTONOV	{"email": "mikhail-antonov.31081987@postgrespro.ru", "phone": "+70713550512"}
0005432284527	EF655D	6673 902942	YULIYA ORLOVA	{"phone": "+70554102867"}
0005432284528	444F78	6177 353534	ANDREY POPOV	{"phone": "+70999951907"}
0005432284529	444F78	9505 178614	DMITRIY VOROBEV	{"phone": "+70410966488"}
0005432284530	444F78	1809 369924	EKATERINA VOLKOVA	{"email": "ekaterina-volkova.1975@postgrespro.ru", "phone": "+70700483910"}
0005432284531	CB4893	6059 032441	NATALYA ILINA	{"email": "ilina.natalya.031971@postgrespro.ru", "phone": "+70233547105"}
0005432284532	CB4893	8189 714223	VLADIMIR NAZAROV	{"email": "v.nazarov_101970@postgrespro.ru", "phone": "+70769594082"}
0005432284533	2038CE	5809 231180	KIRILL NOVIKOV	{"phone": "+70267409833"}
0005432284534	150ABA	3833 321541	IRINA FEDOROVA	{"phone": "+70606624284"}
0005432284535	150ABA	7659 485607	IRINA SEMENOVA	{"phone": "+70892508752"}
0005432284536	AD835A	0478 656760	VLADIMIR KRASNOV	{"email": "krasnov-vladimir.071962@postgrespro.ru", "phone": "+70070616429"}
0005432284537	28FD30	0418 843436	GALINA KUZNECOVA	{"email": "g_kuznecova-1980@postgrespro.ru", "phone": "+70444431721"}
0005432284538	28FD30	8165 655257	SVETLANA GRISHINA	{"phone": "+70367502339"}
0005432284539	4A0E27	0841 010770	OLGA OSIPOVA	{"phone": "+70058436965"}
0005432284540	5AAC83	4996 091903	GALINA MAKAROVA	{"phone": "+70869672286"}
0005432284541	A74783	3184 328563	NATALYA STEPANOVA	{"email": "natalyastepanova02041966@postgrespro.ru", "phone": "+70945840785"}
0005432284542	A74783	2708 755910	RINAT STEPANOV	{"email": "stepanov-r_1968@postgrespro.ru", "phone": "+70861880755"}
0005432284543	C194D2	0939 807071	ANTONINA ANDREEVA	{"email": "andreeva-antonina_081974@postgrespro.ru", "phone": "+70725380028"}
0005432284544	C194D2	4198 323534	VALENTINA NESTEROVA	{"email": "valentina_nesterova-1982@postgrespro.ru", "phone": "+70068076870"}
0005432284545	C194D2	1163 951341	ELENA ISAEVA	{"phone": "+70219952607"}
0005432284546	58AA46	7713 489760	VIKTORIYA KONDRATEVA	{"email": "v.kondrateva-29071983@postgrespro.ru", "phone": "+70305170728"}
0005432284547	B49521	7259 741411	DMITRIY ALEKSEEV	{"phone": "+70339779545"}
0005432284548	8975AA	1814 736961	SVETLANA SOROKINA	{"email": "s.sorokina071967@postgrespro.ru", "phone": "+70151962509"}
0005432284549	18B377	8716 915764	IRINA PETROVA	{"email": "petrova-irina_031976@postgrespro.ru", "phone": "+70046705141"}
0005432284550	97CE01	4291 324335	MARINA ROMANOVA	{"email": "marina-romanova-1977@postgrespro.ru", "phone": "+70215209112"}
0005432284551	6E8528	3804 318740	ANDREY MOROZOV	{"phone": "+70446180171"}
0005432284552	6E8528	7820 788813	OLGA RODIONOVA	{"phone": "+70765762866"}
0005432284553	6E8528	8532 236410	ELENA ABRAMOVA	{"email": "e.abramova-31051976@postgrespro.ru", "phone": "+70046044554"}
0005432284554	2D9D1B	6150 797149	SERGEY SIDOROV	{"email": "s-sidorov-071972@postgrespro.ru", "phone": "+70340059053"}
0005432284555	74C870	6270 544704	NATALYA KONDRATEVA	{"email": "kondrateva_natalya12031969@postgrespro.ru", "phone": "+70698154289"}
0005432284556	A6FAFA	3749 835668	ALEKSEY MIRONOV	{"email": "mironov-a_071975@postgrespro.ru", "phone": "+70220308531"}
0005432284557	8AAC13	5440 112404	ZOYA FROLOVA	{"phone": "+70487956500"}
0005432284558	78137E	0534 315088	TAMARA YAKOVLEVA	{"email": "t-yakovleva_06111979@postgrespro.ru", "phone": "+70601460352"}
0005432284559	746D69	6020 876228	DIANA MIKHAYLOVA	{"phone": "+70418257379"}
0005432284560	2DF79E	9175 166350	SERGEY MELNIKOV	{"email": "melnikov.sergey_19061982@postgrespro.ru", "phone": "+70064707783"}
0005432284561	78F376	7229 067900	ANDREY MOROZOV	{"phone": "+70992723956"}
0005432284562	78F376	7191 835073	TATYANA KOROLEVA	{"email": "koroleva.tatyana-081968@postgrespro.ru", "phone": "+70102970307"}
0005432284563	78F376	9543 561010	PAVEL SOLOVEV	{"email": "solovev_pavel.03091977@postgrespro.ru", "phone": "+70939991162"}
0005432284564	D89E1A	0161 185021	YULIYA KUZMINA	{"phone": "+70464970220"}
0005432284565	D89E1A	0377 143877	OLGA MIRONOVA	{"phone": "+70302178991"}
0005432284566	89945C	1982 931152	VIOLETTA MIKHAYLOVA	{"email": "mikhaylova-v.111970@postgrespro.ru", "phone": "+70076981233"}
0005432284567	89945C	5935 451378	MAKSIM SEMENOV	{"email": "semenov_maksim.1972@postgrespro.ru", "phone": "+70965890856"}
0005432284568	FB1A76	8099 384527	VLADIMIR PETROV	{"phone": "+70299491965"}
0005432284569	FB1A76	8558 120643	DANIIL SOROKIN	{"email": "daniil_sorokin_1985@postgrespro.ru", "phone": "+70356913053"}
0005432284570	2D8A08	2307 513743	ANTON CHERNOV	{"email": "a_chernov_1959@postgrespro.ru", "phone": "+70637611067"}
0005432284571	06AAFE	9287 114162	DENIS PAVLOV	{"phone": "+70461047096"}
0005432284572	06AAFE	9750 732025	VLADISLAV PAVLOV	{"email": "v.pavlov-1976@postgrespro.ru", "phone": "+70250015874"}
0005432284573	9EC2AE	3563 528155	VALENTINA PETROVA	{"email": "petrova.valentina-02031975@postgrespro.ru", "phone": "+70754959153"}
0005432284574	9DDC35	9065 110686	TAMARA PETROVA	{"email": "t_petrova-1960@postgrespro.ru", "phone": "+70135355303"}
0005432284575	4667CC	4101 142613	YURIY POPOV	{"phone": "+70782291619"}
0005432284576	055437	1366 170578	IOSIF DMITRIEV	{"phone": "+70844035740"}
0005432284577	1C13F2	2637 720293	TATYANA KAZAKOVA	{"email": "kazakova_tatyana011967@postgrespro.ru", "phone": "+70484913385"}
0005432284578	1C13F2	8357 422344	EVGENIY ZAKHAROV	{"email": "e_zakharov_1967@postgrespro.ru", "phone": "+70022957757"}
0005432284579	A99EC8	3588 224963	NAIL FROLOV	{"email": "frolovnail_11041962@postgrespro.ru", "phone": "+70043017274"}
0005432284580	505770	6538 186412	PAVEL KAZAKOV	{"email": "kazakov-pavel1976@postgrespro.ru", "phone": "+70353023783"}
0005432284581	4300DD	0739 497714	MIKHAIL SEMENOV	{"email": "semenovmikhail.1978@postgrespro.ru", "phone": "+70134736986"}
0005432284582	F579DF	4230 785694	DMITRIY BONDARENKO	{"email": "dmitriy_bondarenko111969@postgrespro.ru", "phone": "+70139888756"}
0005432284583	9DDC5F	2230 277503	NINA SMIRNOVA	{"phone": "+70205921228"}
0005432284584	9DDC5F	9542 794424	ELISEY KULIKOV	{"phone": "+70677788665"}
0005432284585	AB3BAC	6721 112735	TAMARA KUZMINA	{"email": "kuzmina.t031970@postgrespro.ru", "phone": "+70799773501"}
0005432284586	4AAD83	8522 520305	NADEZHDA ZAKHAROVA	{"email": "n-zakharova22091974@postgrespro.ru", "phone": "+70202820571"}
0005432284587	EBCF92	4957 927537	OLEG SIDOROV	{"phone": "+70251297165"}
0005432284588	70FA44	5778 196674	ANNA ANDREEVA	{"email": "andreevaanna.1979@postgrespro.ru", "phone": "+70184063693"}
0005432284589	8B3A21	6881 349371	OLGA ILINA	{"email": "ilina_o_1968@postgrespro.ru", "phone": "+70818107304"}
0005432284590	25382C	5298 933451	DMITRIY ZHURAVLEV	{"phone": "+70358101672"}
0005432284591	25382C	4575 993739	OLEG FEDOROV	{"email": "fedorovoleg-30081973@postgrespro.ru", "phone": "+70547247647"}
0005432284592	2D4D05	8216 321268	ARTEMIY GERASIMOV	{"email": "a.gerasimov-13021974@postgrespro.ru", "phone": "+70196097007"}
0005432284593	DED624	1001 829790	ALEKSANDR DAVYDOV	{"phone": "+70374362738"}
0005432284594	DED624	1954 591413	ANNA TARASOVA	{"email": "tarasova.anna_061968@postgrespro.ru", "phone": "+70000180863"}
0005432284595	48B49F	5352 955177	VIKTOR SOKOLOV	{"phone": "+70197735585"}
0005432284596	48B49F	2552 644357	ILMIRA GRISHINA	{"email": "i.grishina.1967@postgrespro.ru", "phone": "+70536492053"}
0005432284597	F91D31	4259 097479	ELENA CHERNOVA	{"phone": "+70135056586"}
0005432284598	F91D31	3715 734748	NINA KOROLEVA	{"phone": "+70575641896"}
0005432284599	6DAE81	6474 512685	SVETLANA NOVIKOVA	{"phone": "+70620736748"}
0005432284600	FA11A9	8360 440238	ELENA LOGINOVA	{"email": "loginova.e_1967@postgrespro.ru", "phone": "+70991758400"}
0005432284601	FA11A9	0854 777915	VALENTINA BORISOVA	{"phone": "+70384837158"}
0005432284602	A62BCD	9336 998536	LYUBOV POPOVA	{"email": "lyubov_popova1980@postgrespro.ru", "phone": "+70921383600"}
0005432284603	7CAAC7	9845 574975	ELENA SOROKINA	{"email": "elena.sorokina011977@postgrespro.ru", "phone": "+70096284128"}
0005432284604	7A362E	9879 958833	ALEKSANDR NAUMOV	{"phone": "+70979339118"}
0005432284605	D542AE	0201 737568	ALEKSANDR FEDOROV	{"email": "a-fedorov.121979@postgrespro.ru", "phone": "+70378762129"}
0005432284606	D542AE	6079 198657	LYUDMILA NAZAROVA	{"phone": "+70223449395"}
0005432284607	4A5624	5153 072542	GALINA KOVALEVA	{"phone": "+70324078959"}
0005432284608	7314CE	0135 428608	ALENA NESTEROVA	{"phone": "+70997689498"}
0005432284609	7314CE	4894 867392	ANDREY SHEVCHENKO	{"email": "shevchenko-andrey_1971@postgrespro.ru", "phone": "+70258231963"}
0005432284610	69435D	1199 969584	OLGA IVANOVA	{"phone": "+70780111827"}
0005432284611	A8FA5D	2492 819812	ILMIRA IVANOVA	{"email": "ivanova.i-111973@postgrespro.ru", "phone": "+70991553310"}
0005432284612	B5D711	0328 150567	MARIYA LEBEDEVA	{"phone": "+70189391069"}
0005432284613	FA129C	4962 407336	IRINA DAVYDOVA	{"email": "davydovairina_23101967@postgrespro.ru", "phone": "+70410772405"}
0005432284614	201CB0	6279 296065	NATALYA ERMAKOVA	{"phone": "+70081179392"}
0005432284615	479626	4233 882362	VERA KISELEVA	{"phone": "+70729845327"}
0005432284616	479626	3638 705988	ANATOLIY MOROZOV	{"phone": "+70810567280"}
0005432284617	82C2C5	3268 697703	ANNA MOISEEVA	{"phone": "+70066004899"}
0005432284618	8D5BB0	5403 021797	DIANA SIDOROVA	{"email": "sidorova-d_19121975@postgrespro.ru", "phone": "+70598039797"}
0005432284619	57FB90	8996 788757	VARVARA FILIPPOVA	{"email": "varvara_filippova.1973@postgrespro.ru", "phone": "+70741943262"}
0005432284620	B0A451	9490 917083	IVAN SHEVCHENKO	{"phone": "+70370315845"}
0005432284621	881056	8109 712127	DMITRIY SCHERBAKOV	{"phone": "+70313150180"}
0005432284622	CDDC58	1049 588344	VLADISLAV GAVRILOV	{"email": "gavrilov.vladislav13031980@postgrespro.ru", "phone": "+70272774336"}
0005432284623	CDDC58	8945 298153	OLGA VOLKOVA	{"email": "o.volkova1985@postgrespro.ru", "phone": "+70315064238"}
0005432284624	C95736	2474 192535	DINA SERGEEVA	{"phone": "+70471389426"}
0005432284625	C95736	8114 145753	VLADIMIR POPOV	{"email": "popov.v_21021968@postgrespro.ru", "phone": "+70842687437"}
0005432284626	C95736	2441 054181	NAIL SEMENOV	{"email": "nail.semenov-26021976@postgrespro.ru", "phone": "+70916960568"}
0005432284627	2E6763	3284 005599	NATALYA MASLOVA	{"email": "n-maslova_091977@postgrespro.ru", "phone": "+70196405847"}
0005432284630	736CFC	6882 030915	MAKSIM ZHURAVLEV	{"email": "maksim_zhuravlev_1972@postgrespro.ru", "phone": "+70739130361"}
0005432284631	5E7248	8992 405840	GULFIYA TITOVA	{"email": "titova_g081962@postgrespro.ru", "phone": "+70693637089"}
0005432284632	29E41B	2912 388078	MURAT KONOVALOV	{"email": "mkonovalov28051974@postgrespro.ru", "phone": "+70836943655"}
0005432284633	2FBD26	1871 218024	ELENA VOLKOVA	{"email": "volkova-elena-10021979@postgrespro.ru", "phone": "+70368022444"}
0005432284634	C43B46	6713 475047	VYACHESLAV IVANOV	{"email": "ivanov-vyacheslav30081972@postgrespro.ru", "phone": "+70181287593"}
0005432284635	E18A6E	6351 415244	TATYANA EGOROVA	{"phone": "+70223522449"}
0005432284636	E18A6E	0766 717165	VERA ZOTOVA	{"email": "vera_zotova.21041981@postgrespro.ru", "phone": "+70796819159"}
0005432284637	BCC47D	0682 922528	ALEKSANDR VASILEV	{"phone": "+70578044753"}
0005432284638	93F9F0	6852 904544	VIKTOR PETROV	{"email": "petrovviktor-19101982@postgrespro.ru", "phone": "+70226073165"}
0005432284639	44D177	1069 814906	MIKHAIL VOLKOV	{"phone": "+70225032766"}
0005432284640	44D177	8005 638395	GULFIYA MATVEEVA	{"phone": "+70714989405"}
0005432284641	44D177	0830 640852	PAVEL KOZLOV	{"phone": "+70640292775"}
0005432284642	D9F864	2993 931534	YURIY CHERNOV	{"phone": "+70455830116"}
0005432284643	D9F864	5682 044921	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr_23111967@postgrespro.ru", "phone": "+70047927777"}
0005432284644	8FA55F	7421 418876	ALEKSEY CHERNOV	{"email": "chernov.aleksey.06101978@postgrespro.ru", "phone": "+70464873047"}
0005432284645	4432F6	7114 480294	TATYANA STEPANOVA	{"phone": "+70995159924"}
0005432287099	0A1EF5	4454 593305	ANATOLIY BONDARENKO	{"email": "bondarenko.a.04011979@postgrespro.ru", "phone": "+70994914702"}
0005432287100	60C196	0366 616794	PAVEL KONOVALOV	{"email": "p-konovalov_051962@postgrespro.ru", "phone": "+70783257996"}
0005432287101	60C196	1136 072707	MAKSIM FEDOROV	{"email": "fedorov_m.1973@postgrespro.ru", "phone": "+70623426277"}
0005432287102	60C196	2902 502134	MIKHAIL SMIRNOV	{"email": "m_smirnov.25091968@postgrespro.ru", "phone": "+70234958334"}
0005432287103	8F4267	9070 200406	DMITRIY ZAKHAROV	{"phone": "+70267381184"}
0005432287104	8F4267	9638 769087	ELENA EFIMOVA	{"phone": "+70861242612"}
0005432287105	8F4267	3884 974963	ELENA TARASOVA	{"email": "tarasovaelena-1978@postgrespro.ru", "phone": "+70201619096"}
0005432287106	E2B7B7	0584 521474	NINA LAZAREVA	{"phone": "+70395358853"}
0005432287107	2557D5	3850 226472	OLGA NESTEROVA	{"phone": "+70063341615"}
0005432287108	49B934	0568 709911	OLEG MEDVEDEV	{"phone": "+70569388601"}
0005432287109	7707B8	0512 494193	MARINA YAKOVLEVA	{"phone": "+70437345882"}
0005432287110	C0A77E	4856 930295	SVETLANA TIMOFEEVA	{"email": "svetlana-timofeeva_091970@postgrespro.ru", "phone": "+70547525630"}
0005432287111	28642D	4809 736034	OLGA LUKYANOVA	{"email": "lukyanova-olga-1972@postgrespro.ru", "phone": "+70220839637"}
0005432287112	28642D	3082 757829	EKATERINA KONOVALOVA	{"email": "konovalova.ekaterina_1963@postgrespro.ru", "phone": "+70779728591"}
0005432287113	EE1910	7211 947212	SVETLANA FEDOROVA	{"phone": "+70469110994"}
0005432287114	E996FB	4669 798858	DARYA FEDOROVA	{"phone": "+70775903595"}
0005432287115	E996FB	9774 204390	LARISA SMIRNOVA	{"email": "larisasmirnova-121975@postgrespro.ru", "phone": "+70153031681"}
0005432287116	1AE518	6235 737658	FEDOR MIRONOV	{"phone": "+70105122896"}
0005432287117	29336C	2025 996909	VERA YUDINA	{"phone": "+70663418606"}
0005432287118	EC89CF	8878 225437	ALEKSANDR MIRONOV	{"email": "amironov.12071976@postgrespro.ru", "phone": "+70707012582"}
0005432287119	2AF022	7340 916846	EVGENIY DENISOV	{"phone": "+70866150713"}
0005432287120	3C60AB	0050 790534	IRINA OVCHINNIKOVA	{"email": "i_ovchinnikova.031965@postgrespro.ru", "phone": "+70425257973"}
0005432287121	E18BC4	8842 969167	OLGA SERGEEVA	{"email": "olgasergeeva_1978@postgrespro.ru", "phone": "+70300936756"}
0005432287122	CD15FA	3118 951399	VLADIMIR KOZLOV	{"email": "vladimir-kozlov.23011970@postgrespro.ru", "phone": "+70942197271"}
0005432287123	8ACE1F	0546 062796	DMITRIY IVANOV	{"phone": "+70179359946"}
0005432287124	8EE15D	5873 367843	ALEKSANDR NAZAROV	{"phone": "+70494361868"}
0005432287125	E98317	9233 144767	SVETLANA ZHUKOVA	{"phone": "+70452286550"}
0005432287126	9AF364	9585 358349	ELENA KONDRATEVA	{"phone": "+70300969326"}
0005432287127	74B786	3937 587189	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy.06101967@postgrespro.ru", "phone": "+70991004586"}
0005432287128	70CD0D	0596 446297	ALEKSANDR BORISOV	{"email": "borisov.aleksandr_041970@postgrespro.ru", "phone": "+70103668374"}
0005432287129	70CD0D	6103 497701	SOFYA TARASOVA	{"phone": "+70100911500"}
0005432287130	3BD2FF	7053 159109	SERGEY FOMIN	{"phone": "+70289090965"}
0005432287131	3BD2FF	4589 914655	NADEZHDA KUZMINA	{"email": "kuzmina_n111982@postgrespro.ru", "phone": "+70535138971"}
0005432287132	16D646	4328 956216	ANDREY KULIKOV	{"phone": "+70316580166"}
0005432287133	B6D739	6626 555843	LIDIYA KULIKOVA	{"phone": "+70306936259"}
0005432287134	C83484	4595 653018	SERGEY KUDRYASHOV	{"email": "kudryashovsergey1973@postgrespro.ru", "phone": "+70193978770"}
0005432287135	419349	6151 560778	VALERIY MAKSIMOV	{"phone": "+70168067619"}
0005432287136	6ABA00	4255 762515	MIKHAIL MIKHAYLOV	{"phone": "+70750732631"}
0005432287137	208EEC	8757 743624	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr23121974@postgrespro.ru", "phone": "+70548640483"}
0005432287138	208EEC	4371 299330	ELENA TROFIMOVA	{"email": "trofimova_e-1957@postgrespro.ru", "phone": "+70705749640"}
0005432287139	C76CF3	9834 455756	LYUDMILA SOLOVEVA	{"phone": "+70344242692"}
0005432287140	C76CF3	0147 424028	LYUDMILA GAVRILOVA	{"phone": "+70943565344"}
0005432287141	160DB3	5858 440413	PETR ABRAMOV	{"email": "abramov_p031970@postgrespro.ru", "phone": "+70747009228"}
0005432287142	160DB3	7884 174940	LARISA ZAKHAROVA	{"email": "zakharova-larisa.111973@postgrespro.ru", "phone": "+70815492361"}
0005432287143	5E7E30	6220 292826	YANINA POPOVA	{"phone": "+70707447754"}
0005432287144	DDE850	8080 779418	OLEG IVANOV	{"email": "ivanovoleg_1976@postgrespro.ru", "phone": "+70523252505"}
0005432287145	1D5015	7638 918691	DARYA IVANOVA	{"email": "daryaivanova.1964@postgrespro.ru", "phone": "+70472857755"}
0005432287146	851433	7763 139491	INNA ILINA	{"email": "inna.ilina11121964@postgrespro.ru", "phone": "+70336123529"}
0005432287147	4E1B09	6356 648440	ALEKSANDR TIKHONOV	{"phone": "+70884488143"}
0005432287148	E4ED88	7536 257360	ALEKSANDR STEPANOV	{"email": "a_stepanov-25051967@postgrespro.ru", "phone": "+70911737387"}
0005432287149	91CD0A	8460 645300	DENIS NIKOLAEV	{"email": "nikolaevd_1979@postgrespro.ru", "phone": "+70750130047"}
0005432287150	5F3F80	9619 141666	PETR MOROZOV	{"phone": "+70889057718"}
0005432287151	0AEBA0	5226 148537	TAMARA ISAEVA	{"email": "isaeva.t_1987@postgrespro.ru", "phone": "+70408001603"}
0005432287152	0AEBA0	5437 488042	ELENA SMIRNOVA	{"phone": "+70774214407"}
0005432287153	577D4F	5253 681672	VIKTORIYA YAKOVLEVA	{"phone": "+70587608715"}
0005432287154	92286B	3290 325853	VITALIY MIKHAYLOV	{"phone": "+70374185904"}
0005432287155	92286B	8686 078493	IRINA NOVIKOVA	{"email": "novikova.i1973@postgrespro.ru", "phone": "+70702337542"}
0005432287156	428EBD	1157 091447	ARTUR VOLKOV	{"email": "arturvolkov-23071973@postgrespro.ru", "phone": "+70233032462"}
0005432287157	428EBD	1751 357738	DMITRIY KUZNECOV	{"phone": "+70483139641"}
0005432287158	88B567	1558 019466	ILYA GUSEV	{"phone": "+70101758901"}
0005432287159	6B8DA4	8128 030148	ALEKSANDR TIKHONOV	{"email": "tikhonov.aleksandr1981@postgrespro.ru", "phone": "+70087045105"}
0005432287160	6B8DA4	7568 720807	POLINA GAVRILOVA	{"phone": "+70730329394"}
0005432287161	A4109A	0554 445918	NIKOLAY SCHERBAKOV	{"phone": "+70091944548"}
0005432287162	432C4D	3370 754511	EKATERINA PAVLOVA	{"phone": "+70725350642"}
0005432287163	2A8A21	5536 906428	DMITRIY ZAKHAROV	{"phone": "+70683767247"}
0005432287164	2A8A21	1465 718585	GENNADIY KUZNECOV	{"email": "gkuznecov1981@postgrespro.ru", "phone": "+70663214711"}
0005432287165	8F12AF	3035 674440	VITALIY GERASIMOV	{"email": "gerasimov.v_1957@postgrespro.ru", "phone": "+70025262028"}
0005432287166	43E071	9132 379364	ANNA LAZAREVA	{"phone": "+70616683067"}
0005432287167	43E071	5217 473118	VALERIY MAKSIMOV	{"phone": "+70268976735"}
0005432287168	21569A	6494 671330	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov1975@postgrespro.ru", "phone": "+70602170669"}
0005432287169	21569A	0576 653777	MARAT SMIRNOV	{"email": "marat-smirnov-1964@postgrespro.ru", "phone": "+70358817835"}
0005432287170	21569A	5859 433072	ALINA POPOVA	{"email": "alina_popova_031975@postgrespro.ru", "phone": "+70647838240"}
0005432287171	21569A	0872 815102	VYACHESLAV DENISOV	{"phone": "+70663673033"}
0005432287172	7F5AAC	1472 105530	EKATERINA ZAKHAROVA	{"email": "e.zakharova1975@postgrespro.ru", "phone": "+70679038392"}
0005432287173	7F5AAC	0658 825658	GALINA SMIRNOVA	{"email": "smirnova.g-05121965@postgrespro.ru", "phone": "+70394291633"}
0005432287174	32D3ED	7383 604007	ROMAN FROLOV	{"phone": "+70563305473"}
0005432287175	4A6B69	3399 553584	IRINA LEBEDEVA	{"email": "lebedevairina29031970@postgrespro.ru", "phone": "+70236017470"}
0005432287176	28DF50	3074 521982	NIKOLAY KAZAKOV	{"email": "kazakov.n.15011966@postgrespro.ru", "phone": "+70860291247"}
0005432287177	28DF50	7656 692390	OLEG KISELEV	{"phone": "+70446705701"}
0005432287178	5F0DF3	8205 874611	YURIY SHEVCHENKO	{"phone": "+70521671947"}
0005432287179	5F0DF3	5404 970000	GALINA SOKOLOVA	{"email": "g-sokolova-29111952@postgrespro.ru", "phone": "+70803287801"}
0005432287180	67C1B9	6882 459551	GENNADIY GERASIMOV	{"phone": "+70321431876"}
0005432287181	9A259D	1918 846041	SERGEY ZHURAVLEV	{"phone": "+70724318331"}
0005432287182	9A259D	5819 691447	SERGEY VASILEV	{"phone": "+70436214594"}
0005432287183	9A259D	8249 704167	IVAN IVANOV	{"email": "ivan.ivanov.111977@postgrespro.ru", "phone": "+70420939280"}
0005432287184	EA5A1B	4500 013572	SERGEY NIKITIN	{"phone": "+70154693603"}
0005432287185	F651C3	8516 922239	ARTEM YAKOVLEV	{"email": "yakovlev-a.1972@postgrespro.ru", "phone": "+70952006044"}
0005432287186	809221	9975 408387	ROMAN SHEVCHENKO	{"email": "shevchenkoroman1963@postgrespro.ru", "phone": "+70800112713"}
0005432287187	4B7705	3963 347006	NINA LAZAREVA	{"phone": "+70494044516"}
0005432287188	FB48ED	7012 958939	EVGENIY SIDOROV	{"email": "e-sidorov.061974@postgrespro.ru", "phone": "+70811229969"}
0005432287189	67A90E	3006 946248	EGOR VASILEV	{"phone": "+70751931006"}
0005432287190	2410E0	7134 201614	ZULFIYA KOROLEVA	{"phone": "+70321056928"}
0005432287191	2410E0	9306 016862	ALEKSANDR IVANOV	{"phone": "+70686398371"}
0005432287192	7439C2	5246 741715	KONSTANTIN FILIPPOV	{"email": "filippov-konstantin_1975@postgrespro.ru", "phone": "+70448953597"}
0005432287193	114D60	7935 976133	DENIS KOZLOV	{"email": "d_kozlov_1968@postgrespro.ru", "phone": "+70214873774"}
0005432287194	80A9EA	0927 741386	VLADISLAV SAVELEV	{"email": "savelev.vladislav-11071970@postgrespro.ru", "phone": "+70216113678"}
0005432287195	80A9EA	4150 351763	SERGEY KUZNECOV	{"email": "sergey-kuznecov25071967@postgrespro.ru", "phone": "+70550815260"}
0005432287196	26ED86	2359 597165	YAROSLAV SOKOLOV	{"phone": "+70241607303"}
0005432287197	3DD709	7316 619905	SERGEY MATVEEV	{"phone": "+70538076227"}
0005432287198	3DD709	8917 064833	TATYANA KONDRATEVA	{"phone": "+70783990631"}
0005432287199	22055B	4292 379537	SERGEY KISELEV	{"email": "sergey-kiselev.121973@postgrespro.ru", "phone": "+70982700894"}
0005432287200	5CFF90	3284 592456	NATALYA GUSEVA	{"email": "n.guseva_091971@postgrespro.ru", "phone": "+70571758174"}
0005432287201	5CFF90	7478 123954	VLADIMIR MIRONOV	{"email": "mironov_v121972@postgrespro.ru", "phone": "+70172093820"}
0005432287202	6C29DD	1176 632076	LYUBOV NAZAROVA	{"email": "nazarova.lyubov.1962@postgrespro.ru", "phone": "+70666951559"}
0005432287203	D84639	6000 745277	VADIM DMITRIEV	{"phone": "+70993036971"}
0005432287204	D84639	5857 241048	VALENTINA FEDOROVA	{"phone": "+70747288683"}
0005432287205	7AE80B	6126 486868	NIKITA DMITRIEV	{"email": "nikita-dmitriev1969@postgrespro.ru", "phone": "+70874488664"}
0005432287206	58ADB7	2526 079140	SERGEY SOROKIN	{"phone": "+70354987723"}
0005432287207	58ADB7	1787 254343	ANASTASIYA IVANOVA	{"phone": "+70429463847"}
0005432287208	B9DD51	4951 750896	ROMAN FEDOROV	{"email": "rfedorov071984@postgrespro.ru", "phone": "+70679248465"}
0005432287209	B9DD51	0912 138459	SVYATOSLAV KUZMIN	{"phone": "+70172172669"}
0005432287210	14DC66	0782 643802	ROMAN PETROV	{"phone": "+70027834651"}
0005432287211	56244C	6806 220043	TATYANA POTAPOVA	{"phone": "+70784056232"}
0005432287212	52B975	3965 318622	DMITRIY MATVEEV	{"email": "dmitriymatveev-061967@postgrespro.ru", "phone": "+70227713468"}
0005432287213	1A64DE	1695 853901	VLADIMIR GERASIMOV	{"email": "v.gerasimov.23051981@postgrespro.ru", "phone": "+70749944268"}
0005432287214	85FE9A	0079 413833	OLEG KUZMIN	{"email": "okuzmin_13041980@postgrespro.ru", "phone": "+70507292083"}
0005432287215	85FE9A	0114 325591	VASILIY MARTYNOV	{"email": "martynovv_101974@postgrespro.ru", "phone": "+70150053768"}
0005432287216	8E7F81	9983 981770	ALEKSANDRA ZHUKOVA	{"phone": "+70977649237"}
0005432287217	EB3C0C	4847 535167	YURIY GAVRILOV	{"email": "y.gavrilov-061955@postgrespro.ru", "phone": "+70571253751"}
0005432287218	EB3C0C	0201 024602	NIKOLAY BARANOV	{"email": "nikolaybaranov-1968@postgrespro.ru", "phone": "+70741751799"}
0005432287219	EF0814	6438 063409	RAISA YAKOVLEVA	{"phone": "+70577784213"}
0005432287220	3E33AA	3263 462437	ZLATA NIKITINA	{"email": "znikitina_11041985@postgrespro.ru", "phone": "+70379391363"}
0005432287221	3E33AA	7177 630831	SVETLANA YAKOVLEVA	{"phone": "+70110086114"}
0005432287222	8B36BF	7333 294189	SERGEY KRASNOV	{"email": "s.krasnov-27071979@postgrespro.ru", "phone": "+70218145790"}
0005432287223	530C15	3169 449234	ANTON MATVEEV	{"email": "a.matveev.111972@postgrespro.ru", "phone": "+70388606732"}
0005432287224	A2EDD7	6736 507507	NATALYA PAVLOVA	{"email": "pavlova_natalya.24011959@postgrespro.ru", "phone": "+70770054432"}
0005432287225	A2EDD7	7587 395184	ALEKSEY POPOV	{"phone": "+70071159027"}
0005432287226	50367F	8328 786208	OLGA KOZLOVA	{"email": "kozlova.olga.04081978@postgrespro.ru", "phone": "+70319925742"}
0005432287227	6EDCD8	9001 547480	SEMEN KOROLEV	{"email": "korolev.s_1972@postgrespro.ru", "phone": "+70641679915"}
0005432287228	6EDCD8	7048 867808	SVETLANA KUZMINA	{"email": "svetlanakuzmina-011981@postgrespro.ru", "phone": "+70030209283"}
0005432287229	6EDCD8	5898 861236	IVAN YAKOVLEV	{"email": "ivan.yakovlev-1987@postgrespro.ru", "phone": "+70960710400"}
0005432287230	49BBE6	7917 491979	ANNA VOLKOVA	{"email": "a-volkova12121961@postgrespro.ru", "phone": "+70785516168"}
0005432287231	49BBE6	8964 627333	ALEKSEY ZAKHAROV	{"phone": "+70036662427"}
0005432287232	49BBE6	6741 477915	VALENTINA SOKOLOVA	{"phone": "+70400244731"}
0005432287233	D9670C	7360 491306	OKSANA SMIRNOVA	{"email": "smirnova_oksana1968@postgrespro.ru", "phone": "+70518356886"}
0005432287234	183B69	2000 986605	VERA MAKSIMOVA	{"email": "maksimova.v_051974@postgrespro.ru", "phone": "+70384814197"}
0005432287235	33BD75	8618 980384	YULIYA KISELEVA	{"phone": "+70171205164"}
0005432287236	33BD75	1395 628689	MAKSIM KISELEV	{"phone": "+70351255298"}
0005432287237	C8E08B	6575 148365	VLADIMIR IVANOV	{"email": "vladimir.ivanov111976@postgrespro.ru", "phone": "+70780049316"}
0005432287238	8A23F6	4488 106668	OLGA ZHUKOVA	{"phone": "+70391188946"}
0005432287239	2C0633	1039 924487	VLADIMIR ORLOV	{"email": "orlov_v_12041975@postgrespro.ru", "phone": "+70023825579"}
0005432287240	CD7D81	4281 176175	VLADIMIR SERGEEV	{"email": "sergeev-vladimir.061960@postgrespro.ru", "phone": "+70910756845"}
0005432287241	B5937E	5747 635428	ALINA MIKHAYLOVA	{"email": "mikhaylova_alina_1965@postgrespro.ru", "phone": "+70472363940"}
0005432287242	D90A76	6492 304293	OKSANA CHERNOVA	{"email": "chernovao.16071969@postgrespro.ru", "phone": "+70871560723"}
0005432287243	D90A76	0967 728065	OLEG MAKAROV	{"phone": "+70158073910"}
0005432287244	D90A76	9360 297157	ANNA GRISHINA	{"phone": "+70981462234"}
0005432287245	9989AE	3289 836305	ANTON CHERNOV	{"email": "chernova.041968@postgrespro.ru", "phone": "+70872748591"}
0005432287246	E8089B	6123 759818	NIKOLAY BARANOV	{"email": "baranov.nikolay-1974@postgrespro.ru", "phone": "+70609126224"}
0005432287247	438AE7	4112 603381	OLGA CHERNOVA	{"phone": "+70631774614"}
0005432287248	7AEFC3	4973 540421	ELENA ZAKHAROVA	{"phone": "+70951325449"}
0005432287249	E4815A	5985 809937	ILYA POPOV	{"phone": "+70619514618"}
0005432287250	E4815A	4107 589109	YULIYA SEMENOVA	{"email": "y_semenova-1964@postgrespro.ru", "phone": "+70207830197"}
0005432287251	578459	8251 216414	VALERIYA FEDOROVA	{"email": "fedorova_v-1969@postgrespro.ru", "phone": "+70318277430"}
0005432287252	578459	8287 005355	MIKHAIL MOISEEV	{"email": "moiseev-mikhail_21111969@postgrespro.ru", "phone": "+70596671620"}
0005432287253	578459	5498 775234	VALENTINA FROLOVA	{"phone": "+70950501763"}
0005432287254	DD82A2	1307 148888	SVETLANA STEPANOVA	{"email": "svetlana-stepanova_06081970@postgrespro.ru", "phone": "+70104877131"}
0005432287255	DD82A2	6605 690222	DARYA ZOTOVA	{"phone": "+70602389809"}
0005432287256	B4E20A	9607 078016	EVGENIYA VASILEVA	{"phone": "+70283416196"}
0005432287257	B4E20A	6772 749533	OLGA FILATOVA	{"phone": "+70779132051"}
0005432287258	B4E20A	6101 415614	VLADIMIR POPOV	{"email": "popovv.09101971@postgrespro.ru", "phone": "+70933992181"}
0005432287259	27DD0F	7362 177087	OLEG PETROV	{"email": "petrovo_1973@postgrespro.ru", "phone": "+70057438343"}
0005432287260	C74E4C	7138 664784	ANASTASIYA GAVRILOVA	{"email": "gavrilova_a.1976@postgrespro.ru", "phone": "+70053493995"}
0005432287261	244FF0	9937 009650	YANA RODIONOVA	{"email": "y_rodionova.1957@postgrespro.ru", "phone": "+70271529612"}
0005432287262	23A0EF	2522 209563	POLINA PETROVA	{"phone": "+70491973988"}
0005432287263	0FB87F	6197 453880	ARINA NAZAROVA	{"email": "arinanazarova-09101976@postgrespro.ru", "phone": "+70204577448"}
0005432287264	0FB87F	4378 126658	ILDAR MAKSIMOV	{"email": "ildar-maksimov-17041981@postgrespro.ru", "phone": "+70221858979"}
0005432287265	5C10A3	5557 885176	DMITRIY ORLOV	{"email": "dmitriyorlov_27021965@postgrespro.ru", "phone": "+70268039425"}
0005432287266	6BC3D3	6185 780893	ANASTASIYA KRASNOVA	{"email": "anastasiyakrasnova_1978@postgrespro.ru", "phone": "+70346202134"}
0005432287267	6BC3D3	8985 592719	VASILIY ORLOV	{"email": "orlovv1969@postgrespro.ru", "phone": "+70035308654"}
0005432287268	A5E1FF	5414 386352	ELENA POPOVA	{"email": "elenapopova-02071983@postgrespro.ru", "phone": "+70762255063"}
0005432287269	7D3335	9047 148532	NINA MATVEEVA	{"phone": "+70733653413"}
0005432287270	6111A3	9395 829476	SVETLANA MASLOVA	{"phone": "+70900271542"}
0005432287271	7F130A	0733 745418	ELIZAVETA SERGEEVA	{"phone": "+70865940645"}
0005432287272	7F130A	0921 471524	VIKTOR KUZNECOV	{"email": "viktorkuznecov22121964@postgrespro.ru", "phone": "+70944221741"}
0005432287273	B8E3A1	6479 622855	ALEKSEY CHERNOV	{"email": "aleksey_chernov_121976@postgrespro.ru", "phone": "+70969020507"}
0005432287274	B8E3A1	3172 952810	GENNADIY PETROV	{"phone": "+70861672763"}
0005432287275	91C15F	9506 849664	NADEZHDA MIKHAYLOVA	{"email": "nadezhda-mikhaylova_21121966@postgrespro.ru", "phone": "+70253481622"}
0005432287276	91C15F	8669 755090	DARYA MIRONOVA	{"email": "mironova_darya1969@postgrespro.ru", "phone": "+70838889149"}
0005432287277	91C15F	3737 425872	ANATOLIY FEDOTOV	{"email": "anatoliyfedotov1976@postgrespro.ru", "phone": "+70476631665"}
0005432287278	4ED9FF	2991 601336	ELENA TIKHONOVA	{"phone": "+70737327379"}
0005432287279	4ED9FF	0457 508043	IRINA MAKSIMOVA	{"phone": "+70675915598"}
0005432287280	4ED9FF	2620 455389	DENIS SOROKIN	{"email": "d.sorokin1970@postgrespro.ru", "phone": "+70301901006"}
0005432287281	DE56CC	1528 841048	KIRILL CHERNOV	{"email": "k-chernov.19061979@postgrespro.ru", "phone": "+70245768282"}
0005432287282	CAA0AE	5055 435397	MARK KULIKOV	{"phone": "+70173276206"}
0005432287283	CAA0AE	0152 339543	NATALYA MAKAROVA	{"email": "makarova.natalya-061983@postgrespro.ru", "phone": "+70853838408"}
0005432287284	66732C	0738 166215	SERGEY MOISEEV	{"email": "moiseev_sergey_1983@postgrespro.ru", "phone": "+70854863452"}
0005432287285	2607AE	0305 618872	VLADISLAV STEPANOV	{"phone": "+70600274023"}
0005432287286	2607AE	3340 809980	KIRILL YAKOVLEV	{"email": "yakovlevkirill-08041962@postgrespro.ru", "phone": "+70014513972"}
0005432287287	2607AE	8745 833847	EKATERINA LOGINOVA	{"phone": "+70111924715"}
0005432287288	A313F9	2672 614781	LYUDMILA MASLOVA	{"email": "lyudmila-maslova.03121964@postgrespro.ru", "phone": "+70752155426"}
0005432287289	436AD4	7203 423742	OLGA PAVLOVA	{"email": "o-pavlova-22011977@postgrespro.ru", "phone": "+70922303605"}
0005432287290	457E89	9246 129970	NIKOLAY MOROZOV	{"phone": "+70864332621"}
0005432287291	6E00DC	9730 121423	RUSLAN MEDVEDEV	{"email": "medvedev_r.031969@postgrespro.ru", "phone": "+70252107765"}
0005432287292	6E00DC	8343 106109	NINA GRISHINA	{"phone": "+70392695529"}
0005432287293	6E00DC	3926 934616	LIDIYA MATVEEVA	{"phone": "+70089910703"}
0005432287294	D7D109	1556 009885	ANNA GAVRILOVA	{"phone": "+70457221451"}
0005432287295	D7D109	8371 519517	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev101971@postgrespro.ru", "phone": "+70683958470"}
0005432287296	EA9058	4436 512253	LARISA SCHERBAKOVA	{"email": "scherbakoval_1966@postgrespro.ru", "phone": "+70197800996"}
0005432287297	ACF2B7	0671 481629	VIKTORIYA STEPANOVA	{"phone": "+70648959371"}
0005432287298	DC150E	9992 399353	ZOYA NIKITINA	{"email": "z.nikitina-06011967@postgrespro.ru", "phone": "+70309435608"}
0005432287299	F89304	0375 121243	TAMARA KOROLEVA	{"email": "t.koroleva-1966@postgrespro.ru", "phone": "+70049601212"}
0005432287300	B23852	3903 380206	ALEKSEY NAZAROV	{"email": "nazarov-a.17081958@postgrespro.ru", "phone": "+70389903651"}
0005432287301	7F5014	0213 179028	ANTON SCHERBAKOV	{"email": "scherbakov_anton-1967@postgrespro.ru", "phone": "+70142123641"}
0005432287302	7F5014	4167 845792	NAILYA GORBUNOVA	{"phone": "+70454260016"}
0005432287303	537368	7239 538067	NATALYA KUZNECOVA	{"email": "kuznecovan_15101977@postgrespro.ru", "phone": "+70768892939"}
0005432287304	537368	0942 425875	ANASTASIYA YUDINA	{"email": "yudina_anastasiya.03121978@postgrespro.ru", "phone": "+70994188700"}
0005432287305	432878	0629 388873	ANGELINA NAZAROVA	{"email": "a-nazarova-051975@postgrespro.ru", "phone": "+70337987624"}
0005432287306	48CAC7	1765 107687	NIKOLAY SEMENOV	{"email": "nsemenov_01041973@postgrespro.ru", "phone": "+70016469400"}
0005432287307	B1D36D	7273 362858	ARTEM FILIPPOV	{"email": "filippov.a051968@postgrespro.ru", "phone": "+70773053193"}
0005432287308	2A1786	7330 510012	VLADIMIR FEDOROV	{"phone": "+70439307545"}
0005432287309	5FC90B	2752 335266	NIKOLAY TIMOFEEV	{"phone": "+70996381686"}
0005432287310	6328FE	0959 676133	DMITRIY NAZAROV	{"phone": "+70532772728"}
0005432287311	949E28	4136 940360	MARINA PETROVA	{"email": "petrova-m01021970@postgrespro.ru", "phone": "+70950661493"}
0005432287312	949E28	2236 186276	DANIL KOROLEV	{"email": "d-korolev121963@postgrespro.ru", "phone": "+70406307931"}
0005432287313	C6123E	8751 179313	SERGEY PAVLOV	{"phone": "+70767967862"}
0005432287314	B016D3	6732 770627	NAILYA ZAKHAROVA	{"phone": "+70788195983"}
0005432287315	E25D55	0828 296200	RINAT MIRONOV	{"phone": "+70757301461"}
0005432287316	1C3B97	7412 658392	OLEG KUZNECOV	{"email": "kuznecov.o.1959@postgrespro.ru", "phone": "+70781064193"}
0005432287317	D8E2E9	6375 195306	SERGEY BELOV	{"phone": "+70696590543"}
0005432287318	D8E2E9	9029 302116	TATYANA MELNIKOVA	{"phone": "+70359196138"}
0005432287319	D8E2E9	7507 120326	IGOR NIKITIN	{"email": "nikitin.igor.14031964@postgrespro.ru", "phone": "+70433270228"}
0005432287320	68B80A	3442 865235	TATYANA KULIKOVA	{"email": "tkulikova16031976@postgrespro.ru", "phone": "+70302481523"}
0005432287321	D8B228	9767 422626	NINA MIKHAYLOVA	{"phone": "+70679033999"}
0005432287322	B015CA	9788 775493	ELENA MOISEEVA	{"email": "moiseeva.e.071967@postgrespro.ru", "phone": "+70861910367"}
0005432287323	DF156C	9217 731586	OLESYA POPOVA	{"email": "popova_olesya.1968@postgrespro.ru", "phone": "+70122406619"}
0005432287324	68844B	0394 132032	VIKTOR VASILEV	{"email": "vasilev_v.17121968@postgrespro.ru", "phone": "+70153753131"}
0005432287325	FE1220	1708 064072	KSENIYA POPOVA	{"phone": "+70143075700"}
0005432287326	FE1220	4779 133554	DMITRIY NOVIKOV	{"phone": "+70198649560"}
0005432287327	FE1220	3072 776415	VALERIY ANTONOV	{"phone": "+70895629147"}
0005432287328	059C09	2249 166051	LYUDMILA STEPANOVA	{"phone": "+70971704283"}
0005432287329	8773A5	9578 312362	PETR DMITRIEV	{"phone": "+70000549370"}
0005432287330	8773A5	9665 061643	VASILIY ROMANOV	{"phone": "+70712613727"}
0005432287331	ED059F	5839 183584	DANILA ANTONOV	{"email": "danila-antonov17061972@postgrespro.ru", "phone": "+70143095974"}
0005432287332	4F5561	8652 705249	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d.1973@postgrespro.ru", "phone": "+70123192522"}
0005432287333	4F5561	4286 454154	YURIY ALEKSEEV	{"phone": "+70864949295"}
0005432287334	109B30	6387 965390	VALERIY KUDRYASHOV	{"email": "kudryashov.v28081973@postgrespro.ru", "phone": "+70361608566"}
0005432287335	DBBDE2	5756 036409	ANATOLIY MEDVEDEV	{"phone": "+70589009510"}
0005432287336	DBBDE2	8817 743454	OLGA SOLOVEVA	{"email": "soloveva_o1968@postgrespro.ru", "phone": "+70770085457"}
0005432287337	DBBDE2	1766 802207	SVETLANA CHERNOVA	{"email": "chernova-svetlana_071970@postgrespro.ru", "phone": "+70086212529"}
0005432288927	536A3D	3011 274373	OLGA KOMAROVA	{"phone": "+70995550419"}
0005432288928	536A3D	1694 654851	NADEZHDA BARANOVA	{"email": "baranova.n.20081974@postgrespro.ru", "phone": "+70059629628"}
0005432288929	E82829	9509 924850	VLADIMIR FEDOROV	{"email": "fedorov.vladimir.04041971@postgrespro.ru", "phone": "+70655667136"}
0005432288930	145957	2418 647428	YULIYA MEDVEDEVA	{"email": "medvedevay.1970@postgrespro.ru", "phone": "+70474425296"}
0005432288931	E89950	1375 726300	NIKOLAY KISELEV	{"email": "kiselevnikolay_08081972@postgrespro.ru", "phone": "+70306256451"}
0005432288932	5885CF	6458 750718	TATYANA IVANOVA	{"phone": "+70652106965"}
0005432288933	A97456	0065 885667	OLGA ABRAMOVA	{"phone": "+70676027537"}
0005432288934	986581	3242 163844	GENNADIY ALEKSANDROV	{"phone": "+70330789292"}
0005432288935	986581	7787 038293	SERGEY FEDOTOV	{"email": "fedotovsergey.12071974@postgrespro.ru", "phone": "+70944889286"}
0005432288936	200048	8677 952300	OKSANA ZAKHAROVA	{"phone": "+70328675388"}
0005432288937	028F1B	9576 855482	TATYANA POTAPOVA	{"email": "potapovatatyana_101985@postgrespro.ru", "phone": "+70826758865"}
0005432288938	DD6012	4260 897456	NADEZHDA MARTYNOVA	{"email": "martynova_nadezhda-1966@postgrespro.ru", "phone": "+70058389710"}
0005432288939	11EEC8	1666 053176	SERGEY SOKOLOV	{"email": "sergey-sokolov_011973@postgrespro.ru", "phone": "+70096817917"}
0005432288940	D3F843	7892 596985	POLINA KONDRATEVA	{"email": "kondratevapolina091980@postgrespro.ru", "phone": "+70484366654"}
0005432288941	D3F843	1295 243272	GERMAN FROLOV	{"phone": "+70078215280"}
0005432288942	D3F843	4231 147922	ANTONINA ORLOVA	{"email": "orlova.antonina-051966@postgrespro.ru", "phone": "+70829374852"}
0005432288943	CBCA3F	7944 615151	SVETLANA DANILOVA	{"email": "sdanilova_051984@postgrespro.ru", "phone": "+70085744922"}
0005432288944	A4FA06	4059 872745	REGINA DMITRIEVA	{"phone": "+70448635500"}
0005432288945	A4FA06	2929 101228	SULTAN NOVIKOV	{"phone": "+70873413120"}
0005432288946	3B8CA5	4839 657877	VYACHESLAV EGOROV	{"phone": "+70237294512"}
0005432288947	EDA3DD	2632 405742	ANDREY DMITRIEV	{"email": "dmitrieva1975@postgrespro.ru", "phone": "+70990169274"}
0005432288948	FB0C58	0750 915752	ELVIRA MAKAROVA	{"phone": "+70285695912"}
0005432288949	FB0C58	3375 564447	SERGEY SEMENOV	{"email": "sergey.semenov_20121964@postgrespro.ru", "phone": "+70164188511"}
0005432288950	34D940	2783 706277	GALINA DANILOVA	{"phone": "+70818499176"}
0005432288951	9DE5E4	1719 633390	LADA EFREMOVA	{"phone": "+70217796551"}
0005432288952	F46E3E	5930 169378	LYUDMILA VASILEVA	{"phone": "+70716664675"}
0005432288953	4F659D	5152 988208	STEPAN BORISOV	{"email": "borisov_s-071966@postgrespro.ru", "phone": "+70201947649"}
0005432288954	1E33FD	4649 019479	GALINA KAZAKOVA	{"email": "gkazakova-061975@postgrespro.ru", "phone": "+70543672344"}
0005432288955	1E33FD	3904 476090	NATALYA LAZAREVA	{"phone": "+70969927222"}
0005432288956	2A4EC8	1818 471744	TAMARA SIDOROVA	{"email": "tamara-sidorova.1960@postgrespro.ru", "phone": "+70057043371"}
0005432288957	2A4EC8	1492 548303	ELENA KOROLEVA	{"email": "koroleva_elena-061970@postgrespro.ru", "phone": "+70352049330"}
0005432288958	2A4EC8	7233 403558	DMITRIY MARTYNOV	{"phone": "+70226939173"}
0005432288959	E855E2	9457 370565	ANNA SOROKINA	{"email": "anna.sorokina-1968@postgrespro.ru", "phone": "+70168744050"}
0005432288960	4B2FB0	9041 863153	ARKADIY SMIRNOV	{"phone": "+70160529488"}
0005432288961	ACA76D	5117 253440	DENIS VLASOV	{"phone": "+70996933080"}
0005432288962	B94FA0	3259 267967	KARINA KOZLOVA	{"email": "karina_kozlova_21081974@postgrespro.ru", "phone": "+70105447551"}
0005432288963	B94FA0	0993 171559	ANDREY KARPOV	{"phone": "+70418835777"}
0005432288964	E59CBF	8433 120341	VLADIMIR YAKOVLEV	{"phone": "+70048472372"}
0005432288965	E59CBF	0471 409422	TATYANA MIRONOVA	{"phone": "+70424629618"}
0005432288966	269512	5404 878386	PAVEL BORISOV	{"phone": "+70777003417"}
0005432288967	AF16AD	6985 310290	ANNA PAVLOVA	{"email": "annapavlova-06111982@postgrespro.ru", "phone": "+70465632510"}
0005432288968	C1312B	9498 574721	NADEZHDA VASILEVA	{"phone": "+70860815888"}
0005432288969	C1312B	3411 977273	POLINA ZHURAVLEVA	{"phone": "+70938316384"}
0005432288970	CB3F78	6977 506463	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a27011976@postgrespro.ru", "phone": "+70604873946"}
0005432288971	881F95	7597 854177	NATALYA TIKHONOVA	{"email": "tikhonovanatalya_121971@postgrespro.ru", "phone": "+70794111689"}
0005432288972	E73D98	9037 662564	IRINA KAZAKOVA	{"phone": "+70962600215"}
0005432288973	E73D98	0588 446776	IVAN GRIGOREV	{"phone": "+70012706995"}
0005432288974	8216A8	8812 434717	LARISA BELYAEVA	{"phone": "+70042164887"}
0005432288975	4C333B	0979 394977	OLGA ZAKHAROVA	{"email": "zakharova.o21061971@postgrespro.ru", "phone": "+70498222540"}
0005432288976	D3EA50	2370 073458	ARKADIY IVANOV	{"phone": "+70584985455"}
0005432288977	24EC4B	7309 564001	NIKITA NOVIKOV	{"phone": "+70488579410"}
0005432288978	24EC4B	2754 769807	NIKOLAY NAZAROV	{"email": "nazarovnikolay_101966@postgrespro.ru", "phone": "+70025312050"}
0005432288979	5CA9F4	8075 939702	OLGA ROMANOVA	{"phone": "+70001828424"}
0005432288980	5CA9F4	0480 504584	SOFYA IVANOVA	{"phone": "+70966601662"}
0005432288981	F7BEA7	0415 541300	VLADIMIR MAKSIMOV	{"phone": "+70922904828"}
0005432288982	859CAE	1937 432191	STANISLAV NAUMOV	{"email": "naumovs-081968@postgrespro.ru", "phone": "+70620969735"}
0005432288983	859CAE	8374 729205	VIKTOR KRASNOV	{"email": "krasnov.viktor-1974@postgrespro.ru", "phone": "+70870046337"}
0005432288984	BEABD1	1896 556552	MARINA BELYAEVA	{"phone": "+70369479675"}
0005432288985	BEABD1	7884 600837	SVETLANA IVANOVA	{"email": "s.ivanova-081973@postgrespro.ru", "phone": "+70051501559"}
0005432288986	1E05D8	2421 400142	VIKTOR GAVRILOV	{"email": "gavrilov-v_1964@postgrespro.ru", "phone": "+70048964387"}
0005432288987	25E930	5929 234571	SVETLANA MAKSIMOVA	{"phone": "+70447773953"}
0005432288988	2A197D	3401 905275	ALEKSANDR ABRAMOV	{"email": "a-abramov06121978@postgrespro.ru", "phone": "+70053501059"}
0005432288989	D48D6D	4391 899468	KRISTINA ROMANOVA	{"phone": "+70436902863"}
0005432288990	AA3878	9135 416714	NINA ZAYCEVA	{"email": "n-zayceva20121974@postgrespro.ru", "phone": "+70567242659"}
0005432288991	AA3878	1021 797137	MARIYA KUZNECOVA	{"phone": "+70685729394"}
0005432288992	DF7753	4782 004927	LARISA KOVALEVA	{"email": "lkovaleva1972@postgrespro.ru", "phone": "+70811113154"}
0005432288993	2E91AB	7882 156178	ELENA NIKITINA	{"email": "nikitina_e_28061966@postgrespro.ru", "phone": "+70827736574"}
0005432288994	BB3EDE	9599 478045	MARAT VASILEV	{"email": "vasilev_m-051978@postgrespro.ru", "phone": "+70998824014"}
0005432288995	BB3EDE	5056 130030	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev-02061976@postgrespro.ru", "phone": "+70347326311"}
0005432288996	BB3EDE	7041 318280	PETR AFANASEV	{"email": "p.afanasev-091976@postgrespro.ru", "phone": "+70431135522"}
0005432288997	3B6C05	8843 748877	ALISA SMIRNOVA	{"phone": "+70865556125"}
0005432288998	A985D8	0600 287008	NADEZHDA EGOROVA	{"email": "n.egorova_04121975@postgrespro.ru", "phone": "+70737316840"}
0005432288999	6D47E8	3924 164994	VLADISLAV IVANOV	{"phone": "+70034925633"}
0005432289000	3D6770	2483 787086	NELLI VOLKOVA	{"phone": "+70537721519"}
0005432289001	BA38ED	4186 566752	SERGEY YAKOVLEV	{"phone": "+70538146772"}
0005432289002	BA38ED	5826 682850	DMITRIY ANTONOV	{"email": "antonov-dmitriy1964@postgrespro.ru", "phone": "+70140221978"}
0005432289003	BA38ED	8540 437502	ELIZAVETA KUZMINA	{"email": "e_kuzmina.03091974@postgrespro.ru", "phone": "+70621017088"}
0005432289004	88AF7D	0024 915225	SERGEY IVANOV	{"email": "sergeyivanov031975@postgrespro.ru", "phone": "+70339935237"}
0005432289005	0F2875	6164 100579	SERGEY SIDOROV	{"phone": "+70244940164"}
0005432289006	3CE885	4342 349187	VASILIY BARANOV	{"email": "baranov_vasiliy1960@postgrespro.ru", "phone": "+70434716513"}
0005432289007	0733DD	3033 559162	NINA KUZNECOVA	{"email": "nkuznecova-10061980@postgrespro.ru", "phone": "+70022217334"}
0005432289008	0733DD	1993 031262	YULIYA PAVLOVA	{"phone": "+70708070786"}
0005432289009	43FB82	7964 186608	YURIY TIKHONOV	{"email": "tikhonov-yuriy1972@postgrespro.ru", "phone": "+70225980059"}
0005432289010	43FB82	6259 945934	ALEKSANDR KISELEV	{"email": "kiselev_a_071989@postgrespro.ru", "phone": "+70711829182"}
0005432289011	4B0F55	6327 174008	ANTONINA KALININA	{"phone": "+70374497344"}
0005432289012	A93CAA	9948 177063	NADEZHDA GERASIMOVA	{"email": "ngerasimova.071967@postgrespro.ru", "phone": "+70434244478"}
0005432289013	A93CAA	5392 203388	ANASTASIYA IVANOVA	{"email": "anastasiyaivanova-27011962@postgrespro.ru", "phone": "+70170041387"}
0005432289014	DB9313	3233 243141	MIKHAIL POPOV	{"phone": "+70248738898"}
0005432289015	C041CB	5861 259839	KONSTANTIN GUSEV	{"email": "gusev_konstantin111984@postgrespro.ru", "phone": "+70771996059"}
0005432289016	080E7A	3505 916487	ANNA MAKAROVA	{"phone": "+70968404063"}
0005432289017	FE6B70	8560 143873	LYUDMILA TIKHONOVA	{"email": "l.tikhonova.051969@postgrespro.ru", "phone": "+70202143094"}
0005432289018	9DE392	0801 454743	VLADIMIR DMITRIEV	{"phone": "+70246499646"}
0005432289019	B9BDB5	1414 913209	VERA CHERNOVA	{"email": "vchernova_31101980@postgrespro.ru", "phone": "+70504512712"}
0005432289020	B9BDB5	2448 313938	ALEKSANDR NAZAROV	{"phone": "+70915010995"}
0005432289021	88E2A7	6822 960887	ARINA KOROLEVA	{"phone": "+70620897250"}
0005432289022	6C49E3	1486 294339	ANATOLIY DAVYDOV	{"phone": "+70497482668"}
0005432289023	6C49E3	4065 420752	NIKOLAY POPOV	{"phone": "+70175943759"}
0005432289024	13C48D	9254 864594	IRINA KUZNECOVA	{"email": "kuznecova.i_20091981@postgrespro.ru", "phone": "+70473475687"}
0005432289025	6FA812	6513 408789	RAISA IVANOVA	{"email": "raisaivanova121968@postgrespro.ru", "phone": "+70509308740"}
0005432289026	2B02AA	4693 197795	LARISA FILATOVA	{"email": "filatova-larisa-1972@postgrespro.ru", "phone": "+70277080657"}
0005432289027	2B02AA	9294 904480	TATYANA IVANOVA	{"email": "ivanova-t1966@postgrespro.ru", "phone": "+70254686476"}
0005432289028	EEF056	4339 918311	SERGEY VOROBEV	{"phone": "+70343519224"}
0005432289029	1882EE	6327 275566	YULIYA STEPANOVA	{"email": "y_stepanova1968@postgrespro.ru", "phone": "+70276644802"}
0005432289030	1882EE	9198 527937	VIKTORIYA NIKIFOROVA	{"email": "vnikiforova-1966@postgrespro.ru", "phone": "+70298494700"}
0005432289031	344253	7229 951594	TATYANA ILINA	{"email": "ilina_tatyana-26011973@postgrespro.ru", "phone": "+70036077554"}
0005432289032	344253	0355 979681	SVETLANA NESTEROVA	{"phone": "+70059793009"}
0005432289033	E3A078	1134 824088	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova1985@postgrespro.ru", "phone": "+70456516545"}
0005432289034	E3A078	3552 351861	DMITRIY TARASOV	{"email": "tarasov-d.101984@postgrespro.ru", "phone": "+70329913223"}
0005432289035	23C7D3	8034 699347	DMITRIY MEDVEDEV	{"phone": "+70580891576"}
0005432289036	C6FCA7	7557 164355	NIKOLAY ALEKSEEV	{"email": "nikolayalekseev1969@postgrespro.ru", "phone": "+70586079872"}
0005432289037	0778E4	4177 291449	LYUDMILA ALEKSEEVA	{"email": "alekseeva_lyudmila-101958@postgrespro.ru", "phone": "+70647334049"}
0005432289038	0778E4	0753 136585	KONSTANTIN MELNIKOV	{"phone": "+70387227196"}
0005432289039	58F056	7984 483540	LYUDMILA ANDREEVA	{"phone": "+70224556655"}
0005432289040	71DA9A	3009 582189	SERGEY YAKOVLEV	{"email": "s.yakovlev.111973@postgrespro.ru", "phone": "+70123957610"}
0005432289041	00A2BC	5052 084847	RUSLAN GRIGOREV	{"phone": "+70704291683"}
0005432289042	00A2BC	3036 350458	MIKHAIL CHERNOV	{"email": "mikhail_chernov27111964@postgrespro.ru", "phone": "+70922114024"}
0005432289043	00A2BC	1927 570883	TATYANA EFIMOVA	{"phone": "+70337825301"}
0005432289044	1B7F4B	4154 677305	DMITRIY TIKHONOV	{"email": "tikhonovdmitriy.26061971@postgrespro.ru", "phone": "+70880276877"}
0005432289045	1B7F4B	4036 378634	ALEKSANDR MIRONOV	{"email": "a-mironov.091981@postgrespro.ru", "phone": "+70138197348"}
0005432289046	8A541D	9216 126557	GALINA MAKAROVA	{"phone": "+70715084861"}
0005432289047	C2A79A	1117 350578	BORIS KISELEV	{"phone": "+70741270194"}
0005432289048	8D9DDD	5818 248299	SERGEY MAKAROV	{"phone": "+70683616604"}
0005432289049	D4805D	0725 622846	VITALIY KUZNECOV	{"phone": "+70431493149"}
0005432289050	8C8356	5079 852711	VYACHESLAV KOROLEV	{"email": "vyacheslav-korolev_091976@postgrespro.ru", "phone": "+70774195814"}
0005432289051	62F1A3	7344 490901	TATYANA TARASOVA	{"email": "tatyana_tarasova-12081969@postgrespro.ru", "phone": "+70549080728"}
0005432289052	2F22B7	7168 278167	EVGENIY MAKAROV	{"phone": "+70380460410"}
0005432289053	C2D93B	3625 647198	ALEKSANDR FOMIN	{"phone": "+70335701194"}
0005432289054	CFA6F4	2464 770798	MARIYA NIKITINA	{"email": "nikitina_m_1977@postgrespro.ru", "phone": "+70804876235"}
0005432289055	CFA6F4	0100 520538	MARIYA STEPANOVA	{"phone": "+70957684823"}
0005432289056	CFA6F4	3306 091936	OLGA NAZAROVA	{"phone": "+70605322726"}
0005432289057	7E2635	9031 793616	DENIS FEDOTOV	{"email": "fedotovd.041985@postgrespro.ru", "phone": "+70549427215"}
0005432289058	7E2635	0936 798740	KIRILL FEDOTOV	{"email": "k-fedotov1981@postgrespro.ru", "phone": "+70797937957"}
0005432289059	308D6B	2494 442212	DMITRIY KRASNOV	{"phone": "+70531804153"}
0005432289060	1C7B2E	6448 016758	EVGENIYA TARASOVA	{"phone": "+70998596622"}
0005432289061	073641	6842 354727	DIANA FROLOVA	{"email": "diana-frolova.31031966@postgrespro.ru", "phone": "+70852571069"}
0005432289062	401F1E	6037 275243	MURAD AFANASEV	{"phone": "+70782940637"}
0005432289063	6E5108	3956 460799	VALENTINA VLASOVA	{"phone": "+70001955748"}
0005432289064	6E5108	5413 591526	SERGEY SMIRNOV	{"email": "smirnov_s.13081972@postgrespro.ru", "phone": "+70745498095"}
0005432289065	B3E791	1224 744935	ALEKSEY VASILEV	{"email": "vasilev.a.26041982@postgrespro.ru", "phone": "+70398264752"}
0005432289066	B3E791	2927 746980	ANDREY NIKOLAEV	{"email": "andreynikolaev.031984@postgrespro.ru", "phone": "+70203363449"}
0005432289067	32BE34	2198 010863	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr.1971@postgrespro.ru", "phone": "+70420424033"}
0005432289068	F0DDDB	6617 701031	ELENA POPOVA	{"phone": "+70772202489"}
0005432289069	761901	4867 370925	SERGEY OSIPOV	{"phone": "+70769082815"}
0005432289070	783566	3291 445189	IGOR MEDVEDEV	{"email": "i_medvedev-081976@postgrespro.ru", "phone": "+70595742249"}
0005432289071	783566	6672 720600	DMITRIY POPOV	{"email": "popov-d_101971@postgrespro.ru", "phone": "+70810135729"}
0005432289072	783566	6901 073156	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir_1963@postgrespro.ru", "phone": "+70311230422"}
0005432289073	1A837E	2000 244624	ALEKSEY FOMIN	{"phone": "+70575114147"}
0005432289074	897575	7653 940402	ANTON BONDARENKO	{"phone": "+70208059327"}
0005432289075	897575	0873 998520	ALEKSEY ILIN	{"email": "aleksey-ilin-1971@postgrespro.ru", "phone": "+70882726646"}
0005432289076	BDE7A9	5381 951000	YURIY KONOVALOV	{"phone": "+70171704707"}
0005432289077	BDE7A9	3464 461547	NADEZHDA BELYAEVA	{"phone": "+70734332189"}
0005432289078	DAE955	0719 989923	VALENTINA SAVELEVA	{"phone": "+70905150656"}
0005432289079	DAE955	9004 752384	MIKHAIL ANDREEV	{"phone": "+70216069788"}
0005432289080	61B157	2660 147319	VALERIY ZAKHAROV	{"email": "zakharov_v-01011981@postgrespro.ru", "phone": "+70801108506"}
0005432289081	61B157	9623 005870	MARINA BORISOVA	{"phone": "+70048329347"}
0005432289082	67F6B5	3824 143929	ANDREY IVANOV	{"email": "ivanov.andrey1967@postgrespro.ru", "phone": "+70438262754"}
0005432289083	67F6B5	3997 595733	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir-1970@postgrespro.ru", "phone": "+70490622318"}
0005432289084	932DA2	1762 223625	VALERIY TIKHONOV	{"email": "tikhonovv23111974@postgrespro.ru", "phone": "+70848106110"}
0005432289085	FB731A	4277 888510	ALEKSANDR MIRONOV	{"email": "mironov.a1959@postgrespro.ru", "phone": "+70484025613"}
0005432289086	FB731A	5933 397221	ANTONINA ROMANOVA	{"email": "romanova-antonina111982@postgrespro.ru", "phone": "+70716616713"}
0005432290579	4DB7DE	0561 560737	ELENA DANILOVA	{"email": "elenadanilova-021971@postgrespro.ru", "phone": "+70909718925"}
0005432290580	028250	7431 582445	NIKOLAY OSIPOV	{"email": "osipov-nikolay.091980@postgrespro.ru", "phone": "+70443166724"}
0005432290581	07557B	8020 938839	OLEG ZAKHAROV	{"email": "ozakharov_031977@postgrespro.ru", "phone": "+70882455333"}
0005432290582	07557B	0213 269455	NADEZHDA BORISOVA	{"email": "nadezhdaborisova_1969@postgrespro.ru", "phone": "+70528716129"}
0005432290583	6242B3	7838 506777	ILYA ALEKSEEV	{"email": "alekseev-ilya_04101970@postgrespro.ru", "phone": "+70700724436"}
0005432290584	305A80	9895 195016	OLGA POLYAKOVA	{"email": "o.polyakova.1985@postgrespro.ru", "phone": "+70173728108"}
0005432290585	BD39B4	3944 582370	DIANA AFANASEVA	{"phone": "+70797852052"}
0005432290586	8D18C0	0125 941152	OKSANA GAVRILOVA	{"phone": "+70479697944"}
0005432290587	FDE015	2131 094217	LILIYA MATVEEVA	{"phone": "+70835635826"}
0005432290588	5E1BD8	1658 014537	ANNA KONOVALOVA	{"email": "konovalova_a-1977@postgrespro.ru", "phone": "+70623331429"}
0005432290589	005069	0504 637332	IVAN KUZNECOV	{"email": "kuznecov_i-1981@postgrespro.ru", "phone": "+70445495476"}
0005432290590	005069	7155 409730	ALEKSEY TARASOV	{"email": "a-tarasov-30011962@postgrespro.ru", "phone": "+70243170900"}
0005432290591	3F256B	0943 370332	PELAGEYA DENISOVA	{"email": "p-denisova.051968@postgrespro.ru", "phone": "+70314940918"}
0005432290592	2BEDFD	4100 249779	SNEZHANA BELYAEVA	{"email": "belyaeva_snezhana061977@postgrespro.ru", "phone": "+70532700572"}
0005432290593	6FFB0B	4474 364887	IGOR KUZNECOV	{"phone": "+70276414998"}
0005432290594	C1756D	5217 198036	ROMAN ZHURAVLEV	{"email": "zhuravlevroman-061961@postgrespro.ru", "phone": "+70043421579"}
0005432290595	C1756D	1673 188606	SERGEY KONOVALOV	{"email": "konovalov.s10031970@postgrespro.ru", "phone": "+70468028867"}
0005432290596	75E9F0	7645 036728	VERONIKA MELNIKOVA	{"email": "veronikamelnikova.1961@postgrespro.ru", "phone": "+70666002929"}
0005432290597	75E9F0	9931 786375	VASILIY PAVLOV	{"email": "vasiliy-pavlov-1985@postgrespro.ru", "phone": "+70664328887"}
0005432290598	216FF9	9079 181271	ANDREY KRASNOV	{"email": "andrey.krasnov20041969@postgrespro.ru", "phone": "+70412634426"}
0005432290599	216FF9	0666 295995	OLGA FEDOROVA	{"email": "o.fedorova.16021962@postgrespro.ru", "phone": "+70304896879"}
0005432290600	C22CB3	8695 469232	MARIANNA SOKOLOVA	{"email": "mariannasokolova-1974@postgrespro.ru", "phone": "+70564255840"}
0005432290601	86C459	4312 023214	TATYANA KUZNECOVA	{"email": "kuznecova-t-1974@postgrespro.ru", "phone": "+70952428243"}
0005432290602	11E68F	1286 872177	LYUDMILA BORISOVA	{"phone": "+70001264747"}
0005432290603	11E68F	3007 465064	ALESYA MARTYNOVA	{"phone": "+70144619365"}
0005432290604	11E68F	0883 470601	NIKOLAY NAZAROV	{"email": "nazarov-n-061977@postgrespro.ru", "phone": "+70183808094"}
0005432290605	3013A8	7871 257395	NADEZHDA MOROZOVA	{"phone": "+70061779031"}
0005432290606	32468C	1905 731193	MATVEY SIDOROV	{"email": "matvey-sidorov.011978@postgrespro.ru", "phone": "+70287067828"}
0005432290607	8E957D	8547 782145	EKATERINA KAZAKOVA	{"phone": "+70039643879"}
0005432290608	546C78	9531 335128	ALEKSEY PETROV	{"email": "petrov.a-031978@postgrespro.ru", "phone": "+70815558876"}
0005432290609	DBF72A	5448 095809	ALEKSEY SCHERBAKOV	{"email": "scherbakova.09071978@postgrespro.ru", "phone": "+70688501416"}
0005432290610	45044A	0815 058574	NATALYA NAZAROVA	{"email": "nnazarova.1983@postgrespro.ru", "phone": "+70105999038"}
0005432290611	1AFCDA	9217 313755	VITALIY ZAKHAROV	{"email": "v.zakharov_11031969@postgrespro.ru", "phone": "+70427792257"}
0005432290612	22E502	2338 538122	EVGENIYA NESTEROVA	{"email": "nesterova.e_121961@postgrespro.ru", "phone": "+70602734101"}
0005432290613	22E502	3190 884758	IVAN NAZAROV	{"phone": "+70907034017"}
0005432290614	22E502	7124 666534	OKSANA ZOTOVA	{"email": "zotova_oksana111976@postgrespro.ru", "phone": "+70394199608"}
0005432290615	572099	0298 892456	LARISA TARASOVA	{"email": "tarasova_l_01111959@postgrespro.ru", "phone": "+70308645828"}
0005432290616	572099	6350 606945	ALEKSEY KISELEV	{"email": "kiselev.a.021978@postgrespro.ru", "phone": "+70891123669"}
0005432290617	DA5F23	8160 447355	OLEG KUZNECOV	{"email": "kuznecov_oleg.051972@postgrespro.ru", "phone": "+70416483588"}
0005432290618	E3B7BB	4281 539923	VLADIMIR KULIKOV	{"email": "v_kulikov-1967@postgrespro.ru", "phone": "+70906938579"}
0005432290619	C3FAFB	0429 213925	KSENIYA GUSEVA	{"phone": "+70395953713"}
0005432290620	24093E	9844 376000	ALEKSANDR TARASOV	{"phone": "+70689330017"}
0005432290621	24093E	6495 885291	VALENTINA NIKOLAEVA	{"phone": "+70729353377"}
0005432290622	185FF5	9236 273131	SERGEY ILIN	{"email": "ilins.25041971@postgrespro.ru", "phone": "+70232177393"}
0005432290623	35838E	2760 867278	RUSLAN IVANOV	{"email": "ivanov.r_111972@postgrespro.ru", "phone": "+70444139019"}
0005432290624	525A43	2015 589142	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_041967@postgrespro.ru", "phone": "+70158818872"}
0005432290625	4A3480	7682 445528	ALEKSANDR SMIRNOV	{"email": "smirnov_a1962@postgrespro.ru", "phone": "+70851292828"}
0005432290626	824E11	3209 243482	ALEKSEY ANDREEV	{"phone": "+70398975198"}
0005432290627	824E11	8204 316931	VALENTIN YAKOVLEV	{"phone": "+70336839084"}
0005432290628	824E11	5388 076531	DENIS FEDOROV	{"email": "d_fedorov_16071970@postgrespro.ru", "phone": "+70007748649"}
0005432290629	1826A2	2706 183669	ALSU RODIONOVA	{"email": "arodionova.041978@postgrespro.ru", "phone": "+70396879678"}
0005432290630	73B545	0429 154261	TATYANA ZHUKOVA	{"phone": "+70619609276"}
0005432290631	8CBA23	8579 859462	MIKHAIL VASILEV	{"phone": "+70421519690"}
0005432290632	8CBA23	5863 786919	IRINA MALYSHEVA	{"email": "malysheva-i.1960@postgrespro.ru", "phone": "+70951579887"}
0005432290633	CA0B0E	7939 661957	VASILIY KAZAKOV	{"email": "vasiliy_kazakov_061972@postgrespro.ru", "phone": "+70801454187"}
0005432290634	CA0B0E	8445 654902	RUSLAN KUZMIN	{"phone": "+70060698243"}
0005432290635	D93693	0168 607891	IVAN ZHUKOV	{"email": "ivan.zhukov_1976@postgrespro.ru", "phone": "+70046478805"}
0005432290636	70FF63	2601 218322	DANIL GAVRILOV	{"email": "dgavrilov.25031970@postgrespro.ru", "phone": "+70227306868"}
0005432290637	3E2BDF	0765 928479	VERA DMITRIEVA	{"email": "v_dmitrieva24091984@postgrespro.ru", "phone": "+70013193084"}
0005432290638	499F0C	6019 238678	VITALIY TARASOV	{"phone": "+70394858262"}
0005432290639	5006BA	3484 540104	OLGA POPOVA	{"email": "o-popova-021968@postgrespro.ru", "phone": "+70170215665"}
0005432290640	C811A8	1155 741685	RAISA KUZNECOVA	{"phone": "+70081761227"}
0005432290641	21E38C	5275 543958	BORIS DAVYDOV	{"email": "davydov-b.01071980@postgrespro.ru", "phone": "+70329899382"}
0005432290642	21E38C	9008 768493	SERGEY SIDOROV	{"email": "s_sidorov011969@postgrespro.ru", "phone": "+70291467314"}
0005432290643	99009D	5585 623676	SERGEY SERGEEV	{"phone": "+70091318243"}
0005432290644	4A0215	5085 458337	ANTONINA MAKAROVA	{"email": "amakarova-111979@postgrespro.ru", "phone": "+70643874079"}
0005432290645	E30B24	9479 782860	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov14031960@postgrespro.ru", "phone": "+70216889602"}
0005432290646	950A0D	9086 006866	OLEG PETROV	{"email": "opetrov051972@postgrespro.ru", "phone": "+70255261944"}
0005432290647	950A0D	3561 343703	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov27041974@postgrespro.ru", "phone": "+70558561347"}
0005432290648	5C5A94	2154 409684	DMITRIY KUZMIN	{"email": "dmitriy-kuzmin.03101961@postgrespro.ru", "phone": "+70508815738"}
0005432290649	5E114C	0965 117296	NATALYA SMIRNOVA	{"email": "smirnova_natalya_1973@postgrespro.ru", "phone": "+70181448936"}
0005432290650	943CDC	6188 047245	LIDIYA MOISEEVA	{"email": "moiseeval_1973@postgrespro.ru", "phone": "+70155256234"}
0005432290651	41466F	8679 835199	ALEKSANDR VOLKOV	{"email": "volkova1965@postgrespro.ru", "phone": "+70731798664"}
0005432290652	41466F	4278 311130	SERAFIMA PETROVA	{"phone": "+70691885932"}
0005432290653	84EF48	9666 550070	VIKTOR IVANOV	{"phone": "+70824800372"}
0005432290654	8F826C	0996 513221	NADEZHDA KOVALEVA	{"email": "n_kovaleva_1964@postgrespro.ru", "phone": "+70735495370"}
0005432290655	8F826C	3554 066317	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov_111973@postgrespro.ru", "phone": "+70174590676"}
0005432290656	90984A	4298 089592	ALEKSEY PETROV	{"email": "aleksey_petrov-101967@postgrespro.ru", "phone": "+70984440206"}
0005432290657	ACC821	1366 775454	VLADIMIR PAVLOV	{"phone": "+70887530445"}
0005432290658	87DE88	0701 988396	SERGEY ALEKSANDROV	{"email": "saleksandrov16071969@postgrespro.ru", "phone": "+70547439584"}
0005432290659	E0E8F5	1709 999578	EVGENIY VOLKOV	{"phone": "+70188946275"}
0005432290660	9FC478	4112 956310	DMITRIY NOVIKOV	{"email": "dmitriynovikov.1968@postgrespro.ru", "phone": "+70874722617"}
0005432290661	A5CAC1	3282 574928	VALENTINA GRISHINA	{"phone": "+70576531343"}
0005432290662	FAED84	9897 900907	IVAN ZHUKOV	{"email": "izhukov111970@postgrespro.ru", "phone": "+70429806516"}
0005432290663	D5B2F1	7301 114754	VALENTIN GORBUNOV	{"phone": "+70723155307"}
0005432290664	A22F87	9609 835398	ANGELINA NAZAROVA	{"email": "nazarovaangelina.1970@postgrespro.ru", "phone": "+70728694880"}
0005432290665	D13AD4	8677 188950	RAVIL NIKOLAEV	{"email": "nikolaevravil-25121974@postgrespro.ru", "phone": "+70909124139"}
0005432290666	144515	9286 510815	SVETLANA MASLOVA	{"phone": "+70544271504"}
0005432290667	65FA6C	6664 602761	NADEZHDA KOZLOVA	{"email": "nadezhda_kozlova.081983@postgrespro.ru", "phone": "+70855423771"}
0005432290668	4F9BF4	7159 441851	SERGEY ANDREEV	{"email": "andreevs031973@postgrespro.ru", "phone": "+70413203960"}
0005432290669	4F9BF4	2650 480179	VALENTINA STEPANOVA	{"email": "valentina.stepanova_1975@postgrespro.ru", "phone": "+70894072228"}
0005432290670	D3BA3A	9399 329921	IGOR SOKOLOV	{"email": "sokolov-igor-101981@postgrespro.ru", "phone": "+70300429374"}
0005432290671	672877	1873 367657	TATYANA BORISOVA	{"phone": "+70532291630"}
0005432290672	79BC1A	5527 454299	LYUDMILA RODIONOVA	{"email": "rodionova.lyudmila.20031970@postgrespro.ru", "phone": "+70410408757"}
0005432290673	49B59E	4034 659442	ROZA VASILEVA	{"phone": "+70437619692"}
0005432290674	136F36	7558 707152	YULIYA SAVELEVA	{"email": "yuliya_saveleva_1968@postgrespro.ru", "phone": "+70666246426"}
0005432290675	55CD16	5777 549837	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev.041979@postgrespro.ru", "phone": "+70683562349"}
0005432290676	C13BFB	4002 084851	VITALIY KOZLOV	{"phone": "+70328948243"}
0005432290677	C13BFB	0540 838067	GALINA VOLKOVA	{"phone": "+70893636930"}
0005432290678	C13BFB	0248 842495	PETR KARPOV	{"email": "p.karpov1977@postgrespro.ru", "phone": "+70394945319"}
0005432290679	BE86B4	4426 962848	LYUBOV NAUMOVA	{"email": "naumova_lyubov.28041974@postgrespro.ru", "phone": "+70679368924"}
0005432290680	34A9AC	5005 309595	NATALYA EFREMOVA	{"phone": "+70281987924"}
0005432290681	34A9AC	9086 722454	OLGA ZHURAVLEVA	{"phone": "+70780032773"}
0005432290682	606589	4278 791644	ALEKSEY VOROBEV	{"email": "aleksey-vorobev.30111975@postgrespro.ru", "phone": "+70944163911"}
0005432290683	606589	6238 476218	PAVEL BELOV	{"email": "pavel_belov-04031971@postgrespro.ru", "phone": "+70040755663"}
0005432290684	606589	7785 410594	ANNA IVANOVA	{"phone": "+70789449411"}
0005432290685	606589	8316 533183	SERGEY NOVIKOV	{"phone": "+70074569311"}
0005432290686	ECC100	7849 229014	SERGEY MARTYNOV	{"phone": "+70247728163"}
0005432290687	CF0059	9724 965218	NATALYA ERMAKOVA	{"email": "ermakovan061974@postgrespro.ru", "phone": "+70185702694"}
0005432290688	CF3F7E	4319 532604	YULIYA SOROKINA	{"phone": "+70513627063"}
0005432290689	CF3F7E	5314 374470	MAKSIM NIKOLAEV	{"phone": "+70345577106"}
0005432290690	CF3F7E	2459 667054	GRIGORIY SOKOLOV	{"email": "sokolovgrigoriy_29071971@postgrespro.ru", "phone": "+70253883750"}
0005432290691	A505BB	7965 726381	TATYANA DAVYDOVA	{"phone": "+70881595766"}
0005432290692	6CCE93	7947 529211	ALBINA ILINA	{"email": "ilina-a021965@postgrespro.ru", "phone": "+70811719344"}
0005432290693	80ADA1	9837 189391	SERGEY SOLOVEV	{"phone": "+70903381009"}
0005432290694	80ADA1	8789 045297	ALEKSANDRA SEMENOVA	{"email": "aleksandra-semenova-1977@postgrespro.ru", "phone": "+70977980629"}
0005432290695	BA8DC4	5526 609036	TATYANA KUZNECOVA	{"email": "t_kuznecova-17071983@postgrespro.ru", "phone": "+70628235353"}
0005432290696	BA8DC4	0937 469332	ALEKSEY MAKSIMOV	{"phone": "+70596923165"}
0005432290697	756764	2346 274222	ALEKSANDR MAKSIMOV	{"email": "maksimov_a091979@postgrespro.ru", "phone": "+70321710741"}
0005432290698	C7F166	9983 358174	SHAMIL OSIPOV	{"phone": "+70663227018"}
0005432290699	C7F166	6949 677862	ALEKSANDRA BORISOVA	{"email": "aborisova_25121971@postgrespro.ru", "phone": "+70381814268"}
0005432290700	D559F3	6018 284991	RENAT IVANOV	{"phone": "+70340182803"}
0005432290701	6163D8	7396 103135	NATALYA OSIPOVA	{"email": "natalya_osipova.1972@postgrespro.ru", "phone": "+70401630226"}
0005432290702	6163D8	8535 362363	ZOYA EGOROVA	{"email": "egorova-zoya22091974@postgrespro.ru", "phone": "+70387725212"}
0005432290703	E8844C	1667 776333	NINA ARKHIPOVA	{"email": "nina_arkhipova-26121973@postgrespro.ru", "phone": "+70231978814"}
0005432290704	6B9D44	5225 232853	SVETLANA FILATOVA	{"email": "filatova_s.121973@postgrespro.ru", "phone": "+70316625190"}
0005432290705	6E5583	7263 594136	VASILIY SEMENOV	{"email": "semenovvasiliy-07021975@postgrespro.ru", "phone": "+70593940275"}
0005432290706	985736	0042 619688	VLADIMIR TIKHONOV	{"phone": "+70090589748"}
0005432290707	985736	6179 216671	DENIS FEDOTOV	{"email": "denis-fedotov1981@postgrespro.ru", "phone": "+70393370411"}
0005432290708	EE7E55	4123 070408	IRINA ANDREEVA	{"phone": "+70099577695"}
0005432290709	A420D4	2792 861399	VLADIMIR KOZLOV	{"phone": "+70053993683"}
0005432290710	A420D4	2877 614487	ALEKSANDR MELNIKOV	{"email": "melnikov.a_20061966@postgrespro.ru", "phone": "+70602999383"}
0005432290711	B040B5	1628 641725	ALFIYA IVANOVA	{"email": "ivanova_alfiya_03051972@postgrespro.ru", "phone": "+70888025734"}
0005432290712	4A8365	7521 575957	DMITRIY NAZAROV	{"phone": "+70282242950"}
0005432290713	4A8365	0234 807285	RUMIYA AKIMOVA	{"phone": "+70626610803"}
0005432290714	B2CFE3	3609 579147	ARINA KOVALEVA	{"phone": "+70020334784"}
0005432290715	5AED3F	2565 332112	LYUBOV NIKITINA	{"email": "nikitina-l1960@postgrespro.ru", "phone": "+70490969741"}
0005432290716	00D7EE	8494 189004	IRINA STEPANOVA	{"phone": "+70851626008"}
0005432290717	FEB14B	5796 865343	ALEKSANDR GRIGOREV	{"phone": "+70181913166"}
0005432290718	0A2EE6	2745 113925	ELENA MIKHAYLOVA	{"email": "e-mikhaylova-1967@postgrespro.ru", "phone": "+70752114794"}
0005432290719	0A2EE6	3927 999050	LYUDMILA OSIPOVA	{"email": "lyudmila-osipova_121975@postgrespro.ru", "phone": "+70763359072"}
0005432290720	533023	1515 550832	NATALIYA NIKIFOROVA	{"phone": "+70394313953"}
0005432290721	033265	5208 809629	ANDREY KULIKOV	{"email": "kulikov_andrey-19081971@postgrespro.ru", "phone": "+70389059084"}
0005432290722	975397	5225 593786	SVETLANA SOLOVEVA	{"email": "s_soloveva.03071958@postgrespro.ru", "phone": "+70401999085"}
0005432290723	BBEAB5	6280 737230	LEONID VOLKOV	{"email": "l.volkov-18051970@postgrespro.ru", "phone": "+70214771349"}
0005432290724	BBEAB5	0605 840677	MARIYA PAVLOVA	{"email": "mariya.pavlova.041983@postgrespro.ru", "phone": "+70319921838"}
0005432290725	BBEAB5	9154 609193	EMMA MAKSIMOVA	{"phone": "+70982341783"}
0005432290726	0F8956	0816 578573	SERGEY SOKOLOV	{"email": "sokolov.sergey-1972@postgrespro.ru", "phone": "+70718939016"}
0005432291889	0981DD	5246 696389	DMITRIY MELNIKOV	{"phone": "+70528862386"}
0005432291890	0981DD	8066 800031	OLGA ZAKHAROVA	{"phone": "+70380217051"}
0005432291891	105084	3531 087464	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail1956@postgrespro.ru", "phone": "+70898420549"}
0005432291892	4165AA	4741 081912	GLEB ANTONOV	{"email": "gleb-antonov-04061979@postgrespro.ru", "phone": "+70768885194"}
0005432291893	789FE6	5145 102266	OLGA STEPANOVA	{"email": "stepanovao.031986@postgrespro.ru", "phone": "+70747400475"}
0005432291894	8EC39B	5186 472194	DMITRIY DENISOV	{"phone": "+70750959281"}
0005432291895	0945FB	3406 439916	DENIS SOKOLOV	{"email": "dsokolov.101971@postgrespro.ru", "phone": "+70767492215"}
0005432291896	0945FB	8560 465665	ALEKSANDR FOMIN	{"phone": "+70601158205"}
0005432291897	1FEC3F	9039 782542	SERGEY KUZMIN	{"email": "kuzmins-04121967@postgrespro.ru", "phone": "+70247987404"}
0005432291898	F29379	1578 593874	ALEKSANDR VOLKOV	{"phone": "+70801518257"}
0005432291899	4E7D89	8793 751281	RAISA STEPANOVA	{"email": "stepanovaraisa.1960@postgrespro.ru", "phone": "+70914908630"}
0005432291900	17AB51	4181 264382	TATYANA SOKOLOVA	{"phone": "+70322618681"}
0005432291901	17AB51	8640 560921	VERA STEPANOVA	{"email": "stepanova.vera_1979@postgrespro.ru", "phone": "+70386421044"}
0005432291902	30AF41	3134 337755	VALENTINA ILINA	{"phone": "+70008901528"}
0005432291903	4F16B6	7761 662195	VASILIY CHERNOV	{"email": "chernov.vasiliy.051974@postgrespro.ru", "phone": "+70995930246"}
0005432291904	4F16B6	9572 880040	OKSANA DANILOVA	{"phone": "+70434708460"}
0005432291905	B2757B	4429 396197	ALEKSEY ZHUKOV	{"email": "a.zhukov041965@postgrespro.ru", "phone": "+70478087568"}
0005432291906	D4C384	4053 392980	EVGENIYA NAZAROVA	{"phone": "+70911412192"}
0005432291907	96B781	0794 579653	ALEKSEY KUZMIN	{"phone": "+70491509230"}
0005432291908	1D40E1	0967 250068	EVGENIY POPOV	{"phone": "+70871043693"}
0005432291909	1D40E1	5364 759813	VLADIMIR DMITRIEV	{"phone": "+70356552717"}
0005432291910	E0E6AF	2176 020139	VIKTORIYA MALYSHEVA	{"phone": "+70947052919"}
0005432291911	E0E6AF	1199 549513	RUSTAM MARTYNOV	{"email": "r_martynov121969@postgrespro.ru", "phone": "+70459307982"}
0005432291912	6E39EE	1590 548383	MARINA SEMENOVA	{"phone": "+70298489574"}
0005432291913	6E39EE	7834 015786	DANIL ANDREEV	{"email": "danil-andreev_30111964@postgrespro.ru", "phone": "+70005927943"}
0005432291914	A6438F	5626 247502	SVETLANA ISAEVA	{"phone": "+70395198580"}
0005432291915	EE7DD5	1223 079189	DMITRIY KARPOV	{"email": "d_karpov-1967@postgrespro.ru", "phone": "+70341093221"}
0005432291916	EE7DD5	8263 833996	DARYA SEMENOVA	{"phone": "+70759327462"}
0005432291917	D301E4	7873 755774	IRINA DAVYDOVA	{"phone": "+70857716669"}
0005432291918	5E093C	0458 716008	TATYANA NESTEROVA	{"email": "nesterova.tatyana_28091966@postgrespro.ru", "phone": "+70596970785"}
0005432291919	ED2206	9206 987947	NADEZHDA ROMANOVA	{"email": "nadezhda_romanova-28041963@postgrespro.ru", "phone": "+70815350268"}
0005432291920	ED2206	7267 927736	SERGEY TIMOFEEV	{"email": "timofeev_s-1970@postgrespro.ru", "phone": "+70884108515"}
0005432291921	F2B4F5	5804 108304	EKATERINA YUDINA	{"email": "e_yudina_1966@postgrespro.ru", "phone": "+70183143005"}
0005432291922	DEF6B6	3136 501122	MIKHAIL POPOV	{"email": "popov_m-13051961@postgrespro.ru", "phone": "+70773166051"}
0005432291923	D1C848	6919 917620	TATYANA KONOVALOVA	{"phone": "+70331272372"}
0005432291924	D1C848	3061 422651	NADEZHDA VASILEVA	{"email": "vasileva.n.081974@postgrespro.ru", "phone": "+70511864271"}
0005432291925	E7C59E	0416 978186	SERGEY RODIONOV	{"email": "sergey_rodionov.101970@postgrespro.ru", "phone": "+70601225861"}
0005432291926	E7C59E	7771 977396	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov-1969@postgrespro.ru", "phone": "+70670282283"}
0005432291927	E7C59E	3008 272846	INNA NESTEROVA	{"email": "innanesterova091976@postgrespro.ru", "phone": "+70236857745"}
0005432291928	C8F75C	7457 363109	VLADIMIR VOLKOV	{"phone": "+70584696605"}
0005432291929	E934F3	6484 643474	YULIYA GERASIMOVA	{"email": "gerasimova.yuliya.041974@postgrespro.ru", "phone": "+70517478031"}
0005432291930	3C86CF	2351 430754	VIKTOR FEDOTOV	{"phone": "+70435154732"}
0005432291931	3C86CF	4809 277758	ALEKSEY DAVYDOV	{"email": "aleksey-davydov1967@postgrespro.ru", "phone": "+70238950000"}
0005432291932	5F195A	2725 046977	YULIYA VOROBEVA	{"phone": "+70455613284"}
0005432291933	95C9C9	9299 691121	EVGENIY POPOV	{"email": "popov.e-1965@postgrespro.ru", "phone": "+70904864519"}
0005432291934	95C9C9	2598 737439	ANATOLIY KUDRYASHOV	{"phone": "+70422449046"}
0005432291935	EF8D49	7246 856763	ELENA SOLOVEVA	{"email": "soloveva-e-1980@postgrespro.ru", "phone": "+70262154995"}
0005432291936	823B68	2408 568228	EKATERINA STEPANOVA	{"email": "e_stepanova.061966@postgrespro.ru", "phone": "+70578590672"}
0005432291937	823B68	2804 894776	VYACHESLAV SCHERBAKOV	{"email": "scherbakov.vyacheslav_1971@postgrespro.ru", "phone": "+70175604027"}
0005432291938	7E18CC	0455 887026	ANVAR FOMIN	{"phone": "+70645908418"}
0005432291939	7B2B1D	7825 815387	NATALYA FEDOROVA	{"email": "natalyafedorova.08061969@postgrespro.ru", "phone": "+70888916555"}
0005432291940	7B2B1D	1090 491196	LYUBOV GORBUNOVA	{"phone": "+70519851557"}
0005432291941	30DC81	4098 789695	VALENTINA FEDOROVA	{"email": "valentina-fedorova_041978@postgrespro.ru", "phone": "+70159037642"}
0005432291942	D88A36	7547 128230	YURIY OSIPOV	{"phone": "+70708853382"}
0005432291943	370C50	8738 051567	VLADIMIR ZAYCEV	{"phone": "+70023294651"}
0005432291944	F8F03A	5686 380130	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-1982@postgrespro.ru", "phone": "+70772161004"}
0005432291945	CF76EF	6455 916682	DMITRIY FEDOROV	{"email": "fedorovdmitriy05011973@postgrespro.ru", "phone": "+70581394850"}
0005432291946	C545B5	3020 993398	ALINA KOROLEVA	{"phone": "+70451038689"}
0005432291947	C545B5	2105 225390	VLADIMIR NIKITIN	{"email": "nikitin_vladimir.1964@postgrespro.ru", "phone": "+70606113243"}
0005432291948	0CE9A4	9627 841465	TAISIYA GAVRILOVA	{"email": "gavrilova-t_1970@postgrespro.ru", "phone": "+70378400942"}
0005432291949	0CE9A4	3349 848687	KLAVDIYA ZOTOVA	{"email": "k.zotova1976@postgrespro.ru", "phone": "+70653413517"}
0005432291950	F08779	4598 974964	DARYA NOVIKOVA	{"phone": "+70002129934"}
0005432291951	F08779	1772 465461	KARINA NIKITINA	{"phone": "+70425779500"}
0005432291952	F8A302	9282 796318	GALINA KUZNECOVA	{"phone": "+70748275639"}
0005432291953	9C242F	1440 726917	YURIY ISAEV	{"email": "y-isaev-15101975@postgrespro.ru", "phone": "+70199259056"}
0005432291954	6DAF81	9550 850111	VSEVOLOD FILIPPOV	{"email": "vsevolodfilippov-111975@postgrespro.ru", "phone": "+70880725357"}
0005432291955	6DAF81	6236 260033	IGOR MOROZOV	{"phone": "+70115216144"}
0005432291956	AC0EA1	3705 201597	NAILYA AFANASEVA	{"phone": "+70433579069"}
0005432291957	E480BA	7158 877283	IRINA KUZNECOVA	{"phone": "+70264414636"}
0005432291958	EB82D8	0675 378691	NADEZHDA DENISOVA	{"email": "denisova_nadezhda_1978@postgrespro.ru", "phone": "+70755598566"}
0005432291959	EB82D8	1631 922382	TATYANA OVCHINNIKOVA	{"phone": "+70466729839"}
0005432291960	3F198F	2868 656255	SERGEY SCHERBAKOV	{"phone": "+70593134408"}
0005432291961	E32EFA	4770 411591	ELENA KOZLOVA	{"phone": "+70132164826"}
0005432291962	924E3F	6522 772287	VYACHESLAV IVANOV	{"email": "ivanov.vyacheslav.121978@postgrespro.ru", "phone": "+70607667800"}
0005432291963	08F497	2144 181523	NADEZHDA EFIMOVA	{"email": "efimova-n.13081981@postgrespro.ru", "phone": "+70962139304"}
0005432291964	DCFB3C	2516 628536	ALEKSANDR ABRAMOV	{"phone": "+70756524354"}
0005432291965	E3FEF5	0811 772581	LYUBOV AFANASEVA	{"email": "afanasevalyubov_1974@postgrespro.ru", "phone": "+70703781169"}
0005432291966	65AB56	2505 117338	DMITRIY FROLOV	{"email": "frolov_d041982@postgrespro.ru", "phone": "+70138026181"}
0005432291967	E4ACC2	5225 221637	IVAN SHEVCHENKO	{"phone": "+70141331621"}
0005432291968	F2381D	7522 322420	OLEG NIKOLAEV	{"email": "o_nikolaev.051982@postgrespro.ru", "phone": "+70560475276"}
0005432291969	FFE7E4	7048 767637	GALINA POPOVA	{"phone": "+70945897349"}
0005432291970	F636B3	2597 084553	VIKTOR MOROZOV	{"email": "morozov.viktor.011970@postgrespro.ru", "phone": "+70032631449"}
0005432291971	999B72	0073 646862	RAISA MASLOVA	{"email": "maslovar.26101975@postgrespro.ru", "phone": "+70051226590"}
0005432291972	999B72	5858 820942	VLADIMIR ILIN	{"email": "vladimir-ilin071978@postgrespro.ru", "phone": "+70567820834"}
0005432291973	999B72	3641 120902	ANTONINA SOLOVEVA	{"email": "antoninasoloveva-101977@postgrespro.ru", "phone": "+70112730870"}
0005432291974	999B72	6378 310819	ALEKSEY PAVLOV	{"email": "a.pavlov_101970@postgrespro.ru", "phone": "+70443004488"}
0005432291975	8461F8	7057 616142	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev-031970@postgrespro.ru", "phone": "+70746674256"}
0005432291976	CD50F0	8489 865946	NIKOLAY PAVLOV	{"email": "pavlov_n_081968@postgrespro.ru", "phone": "+70955549864"}
0005432291977	CD50F0	9583 545655	ANTON GORBUNOV	{"email": "agorbunov-1972@postgrespro.ru", "phone": "+70839068911"}
0005432291978	48096E	4041 823721	ELENA ZAKHAROVA	{"phone": "+70978412494"}
0005432291979	9A321A	5437 515889	TAMARA KONDRATEVA	{"email": "kondratevatamara_22091970@postgrespro.ru", "phone": "+70798791426"}
0005432291980	9A321A	6669 885959	EVGENIY KOZLOV	{"phone": "+70037079605"}
0005432291981	2EF0C5	4310 686194	GENNADIY MEDVEDEV	{"phone": "+70665034906"}
0005432291982	3B6541	8575 076554	MAKSIM SCHERBAKOV	{"email": "scherbakov.m.1974@postgrespro.ru", "phone": "+70172937121"}
0005432291983	8679E1	9091 059546	ALEKSEY FEDOROV	{"email": "fedorov-aleksey-06041971@postgrespro.ru", "phone": "+70552374582"}
0005432291984	34DD73	4476 559725	FEDOR MEDVEDEV	{"phone": "+70702543068"}
0005432291985	C7BFA6	8445 984928	VIKTOR ZHUKOV	{"phone": "+70115583481"}
0005432291986	B8DD2F	3190 934234	VALERIY MIKHAYLOV	{"phone": "+70974368861"}
0005432291987	BC9384	5275 339032	MAKSIM GUSEV	{"email": "gusev.m.1974@postgrespro.ru", "phone": "+70890663673"}
0005432291988	BC9384	4479 415665	ALEKSANDR POPOV	{"phone": "+70894607371"}
0005432291989	77B88C	4554 795055	RAISA BELYAEVA	{"phone": "+70529399453"}
0005432291990	068065	9913 763581	POLINA NESTEROVA	{"phone": "+70711891754"}
0005432291991	068065	6727 633215	OLGA SCHERBAKOVA	{"email": "scherbakova.olga03071970@postgrespro.ru", "phone": "+70792742413"}
0005432291992	493012	0336 047692	LARISA KUZMINA	{"email": "larisa_kuzmina-1973@postgrespro.ru", "phone": "+70877529422"}
0005432291993	493012	2228 826628	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.1962@postgrespro.ru", "phone": "+70155706837"}
0005432291994	E289C1	9866 947821	ALEKSANDRA ZHURAVLEVA	{"phone": "+70911367124"}
0005432291995	F1DE42	4907 378146	ALEKSANDR MIRONOV	{"phone": "+70484095056"}
0005432291996	F69284	2516 062473	NIKOLAY KAZAKOV	{"phone": "+70952048714"}
0005432291997	EBEBA5	6720 654866	VALENTINA BELOVA	{"email": "v_belova.25101973@postgrespro.ru", "phone": "+70666560588"}
0005432291998	94B794	1990 861058	DMITRIY BORISOV	{"email": "dborisov-12011983@postgrespro.ru", "phone": "+70100646702"}
0005432291999	0C4C3C	7460 361879	NATALYA BELYAEVA	{"phone": "+70684663585"}
0005432292000	0C4C3C	3148 113151	RUSLAN FEDOTOV	{"email": "fedotovr051977@postgrespro.ru", "phone": "+70182507933"}
0005432292001	0C4C3C	7320 984958	VLADIMIR IVANOV	{"phone": "+70622275797"}
0005432292002	0C4C3C	5439 309224	RAISA KARPOVA	{"phone": "+70194489292"}
0005432293164	B49779	7596 163076	ANDREY GERASIMOV	{"email": "a-gerasimov.29041973@postgrespro.ru", "phone": "+70515735102"}
0005432293165	6BEAAC	9442 205147	VLADISLAV BELOV	{"email": "belovv-02101963@postgrespro.ru", "phone": "+70392404051"}
0005432293166	A7C500	8601 169378	KLAVDIYA VLASOVA	{"email": "vlasova-k_031974@postgrespro.ru", "phone": "+70406467388"}
0005432293167	CF1E0C	2480 723498	LIDIYA EFREMOVA	{"phone": "+70777116575"}
0005432293168	3A6986	5651 778926	VASILIY VASILEV	{"phone": "+70576329147"}
0005432293169	1AACE5	9396 605156	SVETLANA KOROLEVA	{"phone": "+70215574924"}
0005432293170	94610C	3408 252451	ANDREY FROLOV	{"email": "frolovandrey.1969@postgrespro.ru", "phone": "+70003583937"}
0005432293171	FFD136	6197 764779	ANDREY YAKOVLEV	{"email": "yakovleva1976@postgrespro.ru", "phone": "+70354401115"}
0005432293172	F4E7E0	1282 823414	RUSLAN MAKAROV	{"email": "r-makarov031968@postgrespro.ru", "phone": "+70121951554"}
0005432293173	F4E7E0	8887 491612	IVAN POPOV	{"phone": "+70515774583"}
0005432293174	A24854	5079 894053	TATYANA IVANOVA	{"phone": "+70027367349"}
0005432293175	F1DBE2	6296 815974	EKATERINA ZAKHAROVA	{"email": "e.zakharova03021972@postgrespro.ru", "phone": "+70417146035"}
0005432293176	518B3E	8428 247888	NIKOLAY SEMENOV	{"phone": "+70094718540"}
0005432293177	518B3E	1825 085606	MARINA KOLESNIKOVA	{"email": "m_kolesnikova.1971@postgrespro.ru", "phone": "+70047075633"}
0005432293178	1C1EA4	8122 471159	LYUBOV NAUMOVA	{"phone": "+70701521516"}
0005432293179	379386	4642 927452	VALENTINA KUDRYASHOVA	{"email": "vkudryashova1969@postgrespro.ru", "phone": "+70769282868"}
0005432293180	379386	5950 501768	EVGENIYA MAKAROVA	{"email": "evgeniya_makarova1982@postgrespro.ru", "phone": "+70343345547"}
0005432293181	9C649D	1201 537491	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a-17071965@postgrespro.ru", "phone": "+70150356544"}
0005432293182	CCFE66	4114 340212	VYACHESLAV POPOV	{"email": "popov-v.15081979@postgrespro.ru", "phone": "+70198947878"}
0005432293183	CCFE66	5252 520860	ZOYA IVANOVA	{"email": "ivanovazoya.021977@postgrespro.ru", "phone": "+70352228604"}
0005432293184	CCFE66	4408 042047	ELENA ANISIMOVA	{"phone": "+70083420163"}
0005432293185	3B4A59	0762 598008	PETR VOROBEV	{"email": "vorobev-p-091970@postgrespro.ru", "phone": "+70281888554"}
0005432293186	E4DABB	9224 019372	SERGEY MARTYNOV	{"email": "martynov_s06011971@postgrespro.ru", "phone": "+70838979337"}
0005432293187	1FA5AF	9058 389513	RAFAIL VASILEV	{"email": "rafailvasilev.1980@postgrespro.ru", "phone": "+70433083138"}
0005432293188	E0B611	4223 759951	ANVAR DMITRIEV	{"email": "anvar-dmitriev.011976@postgrespro.ru", "phone": "+70658427056"}
0005432293189	DC5442	9123 537961	PRASKOVYA NAZAROVA	{"email": "pnazarova-26061969@postgrespro.ru", "phone": "+70719416046"}
0005432293190	093ABA	6395 763589	VLADIMIR PETROV	{"phone": "+70751968925"}
0005432293191	F481B8	7710 442549	ALEKSANDR KUZMIN	{"phone": "+70031639169"}
0005432293192	97C4AA	4728 476213	VIKTORIYA ROMANOVA	{"email": "viktoriya_romanova_27091977@postgrespro.ru", "phone": "+70579790260"}
0005432293193	D69C7C	2337 551560	VYACHESLAV KOZLOV	{"email": "vyacheslavkozlov.1972@postgrespro.ru", "phone": "+70908398824"}
0005432293194	D69C7C	3689 730413	ELENA MAKAROVA	{"email": "makarova.e.03081976@postgrespro.ru", "phone": "+70173560958"}
0005432293195	D69C7C	1267 115537	NATALYA CHERNOVA	{"email": "chernova.natalya.22041967@postgrespro.ru", "phone": "+70300425725"}
0005432293196	D69C7C	9060 414152	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov12051977@postgrespro.ru", "phone": "+70248894469"}
0005432293197	A8A3F0	7348 653333	VALENTINA IVANOVA	{"phone": "+70393820105"}
0005432293198	C765B8	5442 600714	SERGEY STEPANOV	{"email": "sergey.stepanov.1979@postgrespro.ru", "phone": "+70546036365"}
0005432293199	C765B8	5505 500565	MARINA EGOROVA	{"email": "egorovam-06041964@postgrespro.ru", "phone": "+70506304662"}
0005432293200	A947C8	7485 137246	VENIAMIN MEDVEDEV	{"phone": "+70285778353"}
0005432293201	4CDB8F	0789 505464	IVAN SERGEEV	{"email": "sergeev.i_30101980@postgrespro.ru", "phone": "+70872437320"}
0005432293202	95433C	1323 860503	EKATERINA ANISIMOVA	{"email": "eanisimova.021970@postgrespro.ru", "phone": "+70711847502"}
0005432293203	F78D5C	7399 850171	LYUDMILA ANTONOVA	{"email": "antonova.lyudmila_081976@postgrespro.ru", "phone": "+70774311477"}
0005432293204	F78D5C	6312 192577	VLADIMIR NAZAROV	{"email": "nazarov_v29101969@postgrespro.ru", "phone": "+70064818565"}
0005432293205	A940E9	7103 938254	RAIS GUSEV	{"email": "gusev_rais-1980@postgrespro.ru", "phone": "+70197886024"}
0005432293206	BC1D25	0243 756894	VASILIY ALEKSEEV	{"email": "vasiliy_alekseev.111974@postgrespro.ru", "phone": "+70123347616"}
0005432293207	BF1BF7	9399 285187	VALENTINA TIMOFEEVA	{"email": "timofeeva.v.111977@postgrespro.ru", "phone": "+70579550729"}
0005432293208	BF1BF7	5698 382276	VLADIMIR GRIGOREV	{"email": "grigorev.v.081973@postgrespro.ru", "phone": "+70359043020"}
0005432293209	B28B4B	2939 292526	YULIYA FOMINA	{"email": "fomina_y.1967@postgrespro.ru", "phone": "+70359643032"}
0005432293210	BDD606	3357 284049	IRAIDA KRASNOVA	{"phone": "+70713969948"}
0005432293211	F2A373	1491 965923	ANDREY FEDOROV	{"phone": "+70008295623"}
0005432293212	CE3E59	6207 516727	LIDIYA KULIKOVA	{"email": "kulikova-lidiya-1963@postgrespro.ru", "phone": "+70868315228"}
0005432293213	CE3E59	9598 411313	SVETLANA KOROLEVA	{"phone": "+70795986901"}
0005432293214	23437C	5942 353254	ALEKSANDR DAVYDOV	{"email": "davydov-a_24091961@postgrespro.ru", "phone": "+70043472565"}
0005432293215	407B7D	8261 529437	TATYANA KUDRYASHOVA	{"phone": "+70162469623"}
0005432293216	407B7D	1514 249239	ANNA RODIONOVA	{"email": "rodionovaanna.03091948@postgrespro.ru", "phone": "+70874331057"}
0005432293217	67401B	2800 047837	NATALYA ILINA	{"phone": "+70714620957"}
0005432293218	D5B0DF	2316 178706	ARTEM NIKOLAEV	{"phone": "+70726670288"}
0005432293219	D6C62A	1418 918676	DMITRIY MAKSIMOV	{"phone": "+70081274583"}
0005432293220	739CCC	0860 403314	VIKTORIYA STEPANOVA	{"phone": "+70196349308"}
0005432293221	739CCC	8546 259107	TATYANA KONOVALOVA	{"email": "konovalova_t24071981@postgrespro.ru", "phone": "+70211765027"}
0005432293222	A58A39	2239 242250	VLADIMIR ZAKHAROV	{"phone": "+70095087300"}
0005432293223	A58A39	9816 691799	TATYANA ZAKHAROVA	{"email": "zakharova.tatyana-071962@postgrespro.ru", "phone": "+70663082122"}
0005432293224	D15341	2049 093597	PETR KRASNOV	{"phone": "+70419508589"}
0005432293225	9B1E4B	1368 704219	TATYANA GRISHINA	{"email": "t.grishina_121975@postgrespro.ru", "phone": "+70862895740"}
0005432293226	9B1E4B	6508 262714	SVETLANA ANTONOVA	{"email": "antonova_svetlana.29031979@postgrespro.ru", "phone": "+70954229675"}
0005432293227	9B1E4B	7690 063261	ANDREY CHERNOV	{"email": "chernov-andrey12031967@postgrespro.ru", "phone": "+70924310783"}
0005432293228	27B3BF	0321 635568	LILIYA ALEKSEEVA	{"phone": "+70980789704"}
0005432293229	27B3BF	0942 085550	SERGEY NOVIKOV	{"phone": "+70319344005"}
0005432293230	882947	5835 884818	OLEG ALEKSANDROV	{"email": "olegaleksandrov1970@postgrespro.ru", "phone": "+70060617426"}
0005432293231	9BE0C5	1832 104605	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.031977@postgrespro.ru", "phone": "+70298414383"}
0005432293232	BDE841	8094 176935	ILNAR NIKOLAEV	{"email": "nikolaev_i-091976@postgrespro.ru", "phone": "+70590721477"}
0005432293233	F9CD55	5197 356329	VYACHESLAV KOZLOV	{"email": "kozlov-v_041975@postgrespro.ru", "phone": "+70939544384"}
0005432293234	F9CD55	5456 168156	ALEKSEY KULIKOV	{"email": "a.kulikov-06121969@postgrespro.ru", "phone": "+70156549621"}
0005432293235	F9CD55	3260 066012	IGOR DAVYDOV	{"phone": "+70542476748"}
0005432293236	2C595C	6773 820930	EKATERINA BOGDANOVA	{"email": "bogdanova_e_1974@postgrespro.ru", "phone": "+70841065224"}
0005432293237	2C595C	5595 679770	NATALYA RODIONOVA	{"phone": "+70305792927"}
0005432293238	765E29	3497 782122	ANASTASIYA VASILEVA	{"email": "vasileva-anastasiya_051983@postgrespro.ru", "phone": "+70608776719"}
0005432293239	765E29	3093 870914	NIKOLAY ALEKSEEV	{"phone": "+70623084440"}
0005432293240	F4E5C6	8646 020454	RUSLAN MAKAROV	{"email": "makarov-ruslan1966@postgrespro.ru", "phone": "+70829237507"}
0005432293241	1BB4C4	5210 307888	YURIY EGOROV	{"email": "egorovyuriy.06011973@postgrespro.ru", "phone": "+70320003104"}
0005432293242	1BB4C4	9700 709731	VLADIMIR MOISEEV	{"email": "v_moiseev_1978@postgrespro.ru", "phone": "+70846222399"}
0005432293243	377E22	9381 388849	LYUDMILA KUZNECOVA	{"phone": "+70868751304"}
0005432293244	4050A1	7548 912616	LYUDMILA EGOROVA	{"email": "l-egorova_1970@postgrespro.ru", "phone": "+70926520906"}
0005432293245	02768A	0487 505073	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.04031970@postgrespro.ru", "phone": "+70436655257"}
0005432293246	08C842	2359 180265	IRAIDA AFANASEVA	{"phone": "+70737939375"}
0005432293247	60270E	8100 606210	MIKHAIL DAVYDOV	{"email": "mdavydov1968@postgrespro.ru", "phone": "+70940360758"}
0005432293248	60270E	7027 918432	ANNA STEPANOVA	{"phone": "+70595997469"}
0005432293249	F0AAC6	6091 721163	LEONID MEDVEDEV	{"email": "leonid.medvedev.1973@postgrespro.ru", "phone": "+70764579251"}
0005432293250	625B3C	6059 907582	ANVAR BARANOV	{"email": "a.baranov24081975@postgrespro.ru", "phone": "+70242123959"}
0005432293251	A58543	5390 556981	ELINA NIKOLAEVA	{"email": "nikolaeva_elina_011975@postgrespro.ru", "phone": "+70656374494"}
0005432293252	67A076	7894 301939	IGOR ROMANOV	{"phone": "+70695540965"}
0005432293253	1060AD	1030 377961	LIDIYA YUDINA	{"phone": "+70172031112"}
0005432293254	1060AD	0849 897150	MIKHAIL MIKHAYLOV	{"phone": "+70486607777"}
0005432293255	BB5FC6	2773 058870	NIKITA VOLKOV	{"email": "volkovn12051966@postgrespro.ru", "phone": "+70269023568"}
0005432293256	BCFF3A	4029 282040	OLGA KISELEVA	{"phone": "+70417838083"}
0005432293257	BCFF3A	8854 803060	ARKADIY SMIRNOV	{"email": "arkadiy_smirnov10101978@postgrespro.ru", "phone": "+70077266592"}
0005432293258	E30EB4	3543 386665	PAVEL ZHUKOV	{"phone": "+70395661516"}
0005432293259	E30EB4	0306 885116	VERA NAUMOVA	{"email": "vera-naumova111975@postgrespro.ru", "phone": "+70080197341"}
0005432293260	1537B7	4177 192163	VERA ERMAKOVA	{"email": "vera_ermakova-1975@postgrespro.ru", "phone": "+70624160140"}
0005432293261	7FEA3B	2652 462861	OLEG NAZAROV	{"phone": "+70493579408"}
0005432293262	65A236	7004 023225	MARIYA STEPANOVA	{"email": "stepanovamariya.1975@postgrespro.ru", "phone": "+70685687558"}
0005432293263	65A236	6352 511492	SOFYA DANILOVA	{"phone": "+70894121300"}
0005432293264	F48B1F	7196 751353	LYUBOV OSIPOVA	{"phone": "+70544229073"}
0005432293265	DB72DF	9539 946541	NINA NIKOLAEVA	{"phone": "+70107461502"}
0005432293266	9D8869	8388 735351	LIDIYA SMIRNOVA	{"phone": "+70720627858"}
0005432293267	C04E9E	3099 899917	DMITRIY KUZNECOV	{"phone": "+70466221163"}
0005432293268	77C24C	4075 212900	NIKITA BELOV	{"phone": "+70401576957"}
0005432293269	AD235B	4807 777445	TATYANA KAZAKOVA	{"email": "kazakova_tatyana_081964@postgrespro.ru", "phone": "+70936649158"}
0005432293270	5AFF93	0945 058668	OLGA MOROZOVA	{"phone": "+70392375865"}
0005432293271	5AFF93	7871 840863	ALEKSANDR SMIRNOV	{"email": "a_smirnov_1975@postgrespro.ru", "phone": "+70656862299"}
0005432293272	518A4D	5517 287320	VYACHESLAV VOLKOV	{"email": "volkov_vyacheslav-03061978@postgrespro.ru", "phone": "+70098308747"}
0005432293273	000068	5895 674437	TATYANA PETROVA	{"email": "t_petrova1970@postgrespro.ru", "phone": "+70886117503"}
0005432293274	5D4CF7	3212 171399	VYACHESLAV SOKOLOV	{"email": "vyacheslav-sokolov04041967@postgrespro.ru", "phone": "+70614021630"}
0005432293275	EBEF5E	8911 278884	SVETLANA LEBEDEVA	{"email": "svetlana-lebedeva.24071971@postgrespro.ru", "phone": "+70822800621"}
0005432293276	EBEF5E	0337 700963	NIKOLAY MAKAROV	{"phone": "+70010029652"}
0005432293277	8731E7	5257 383664	OLEG SAVELEV	{"phone": "+70161294030"}
0005432293278	5829C0	9997 592026	GALINA MIRONOVA	{"email": "mironova-g17101978@postgrespro.ru", "phone": "+70594042346"}
0005432293279	A4AB5B	6978 374141	ELENA NOVIKOVA	{"email": "elenanovikova_14111973@postgrespro.ru", "phone": "+70463745007"}
0005432293280	A4AB5B	2000 625486	VALENTINA KOZLOVA	{"email": "kozlovavalentina28091973@postgrespro.ru", "phone": "+70623601676"}
0005432293281	3DBC2D	5094 738574	VALERIY VLASOV	{"email": "v.vlasov.1980@postgrespro.ru", "phone": "+70020741202"}
0005432294455	3C4ED8	0654 834022	VALENTINA NOVIKOVA	{"phone": "+70439367051"}
0005432294445	06D7CC	5463 638632	ILYA SAVELEV	{"email": "savelev_i.021960@postgrespro.ru", "phone": "+70894893341"}
0005432294446	BD1967	0185 630915	NATALYA MAKSIMOVA	{"email": "natalya_maksimova121979@postgrespro.ru", "phone": "+70950371562"}
0005432294447	B4D33B	7187 173818	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr.081986@postgrespro.ru", "phone": "+70285194181"}
0005432294448	B4D33B	3614 249302	VIKTOR ANDREEV	{"email": "viktor-andreev041970@postgrespro.ru", "phone": "+70555295325"}
0005432294449	A3C5DD	7409 591084	OLGA MELNIKOVA	{"phone": "+70985523473"}
0005432294450	445D53	1896 246446	VALENTINA KAZAKOVA	{"email": "valentina.kazakova.28031970@postgrespro.ru", "phone": "+70728293386"}
0005432294451	F2EEF7	9193 720618	DMITRIY STEPANOV	{"email": "stepanov-dmitriy-30071961@postgrespro.ru", "phone": "+70253889558"}
0005432294452	F2EEF7	1630 034844	LYUBOV ABRAMOVA	{"email": "lyubov.abramova.1957@postgrespro.ru", "phone": "+70840933926"}
0005432294453	0C6CC2	4672 956904	TATYANA EFIMOVA	{"email": "efimova_tatyana101974@postgrespro.ru", "phone": "+70032103749"}
0005432294454	0C6CC2	2615 745955	LYUBOV BOGDANOVA	{"phone": "+70582106387"}
0005432294456	12945D	6040 568351	ALEKSANDRA STEPANOVA	{"phone": "+70769427057"}
0005432294457	5A1569	6260 342924	VIKTOR YAKOVLEV	{"phone": "+70597701008"}
0005432294458	F2009B	2744 212901	ELENA BOGDANOVA	{"email": "bogdanova-e21041977@postgrespro.ru", "phone": "+70607685728"}
0005432294459	F2009B	7320 582391	RADMIR NOVIKOV	{"phone": "+70587783642"}
0005432294460	4F3F92	8045 920032	NATALYA NAZAROVA	{"phone": "+70468466068"}
0005432294461	B37ACD	5372 527930	VALENTIN SERGEEV	{"phone": "+70249781766"}
0005432294462	3223EC	5422 870877	NIKOLAY IVANOV	{"email": "nikolay-ivanov.111974@postgrespro.ru", "phone": "+70574037754"}
0005432294463	C9AC49	2807 578768	TATYANA KALININA	{"email": "tatyana-kalinina-021973@postgrespro.ru", "phone": "+70844474073"}
0005432294464	864585	5722 233103	EGOR ISAEV	{"email": "isaev.egor121972@postgrespro.ru", "phone": "+70696897756"}
0005432294465	758D14	0529 570866	LARISA SOKOLOVA	{"email": "larisasokolova061982@postgrespro.ru", "phone": "+70290687913"}
0005432294466	758D14	2768 024810	LYUDMILA SOROKINA	{"phone": "+70452518853"}
0005432294467	1B65AA	3074 908893	MARINA FEDOROVA	{"phone": "+70642410617"}
0005432294468	1B65AA	1803 657141	ALEKSANDR SEMENOV	{"phone": "+70185755612"}
0005432294469	C366D8	7293 785254	NATALYA BORISOVA	{"email": "borisovanatalya09121966@postgrespro.ru", "phone": "+70300530152"}
0005432294470	793B97	6527 286779	ALEKSANDR MELNIKOV	{"phone": "+70717540882"}
0005432294471	A2D0EB	9719 858723	VLADIMIR SAVELEV	{"email": "vladimir.savelev.091972@postgrespro.ru", "phone": "+70158455317"}
0005432294472	A2D0EB	8045 020452	SERGEY PAVLOV	{"email": "sergeypavlov_021960@postgrespro.ru", "phone": "+70545782954"}
0005432294473	50A6BF	4082 771483	VLADIMIR NOVIKOV	{"email": "v-novikov11031979@postgrespro.ru", "phone": "+70627508367"}
0005432294474	FD9EAC	0203 173752	SVETLANA IVANOVA	{"email": "s-ivanova051968@postgrespro.ru", "phone": "+70885211124"}
0005432294475	BC3E9E	8538 638630	ANNA FADEEVA	{"phone": "+70869259481"}
0005432294476	5DD287	6155 173294	ANASTASIYA KOLESNIKOVA	{"phone": "+70863137400"}
0005432294477	06D466	9813 204044	DMITRIY GRIGOREV	{"phone": "+70633291927"}
0005432294478	A36634	9278 538177	EVGENIY GORBUNOV	{"email": "gorbunov.e19111975@postgrespro.ru", "phone": "+70613984670"}
0005432294479	DB584F	8989 619235	GERMAN ABRAMOV	{"email": "abramov.german011970@postgrespro.ru", "phone": "+70292620795"}
0005432294480	333F68	1192 985176	VASILIY ROMANOV	{"phone": "+70032013651"}
0005432294481	2D4467	7599 575924	SERGEY SOLOVEV	{"phone": "+70928251090"}
0005432294482	92B5A2	9035 269966	OLESYA POPOVA	{"email": "popovaolesya26061974@postgrespro.ru", "phone": "+70301973577"}
0005432294483	92B5A2	6417 699178	RAISA KUZMINA	{"phone": "+70872459106"}
0005432294484	C4821F	6790 953701	ALEKSANDR SERGEEV	{"email": "sergeev.a-041969@postgrespro.ru", "phone": "+70039897823"}
0005432294485	C4821F	6123 970379	YULIYA TIKHONOVA	{"email": "tikhonovay_16111968@postgrespro.ru", "phone": "+70254081525"}
0005432294486	3C374A	8476 161471	NIKITA MAKAROV	{"phone": "+70482439997"}
0005432294487	F02038	3086 501750	SVETLANA MOROZOVA	{"email": "svetlana_morozova.29031972@postgrespro.ru", "phone": "+70081223784"}
0005432294488	F02038	9510 077947	KSENIYA RYABOVA	{"email": "kseniyaryabova19041973@postgrespro.ru", "phone": "+70167165678"}
0005432294489	A6AF95	0136 136300	VIKTOR SIDOROV	{"phone": "+70628118409"}
0005432294490	CDCB12	4315 104117	YURIY GAVRILOV	{"email": "y-gavrilov.031976@postgrespro.ru", "phone": "+70058223286"}
0005432294491	CDCB12	5603 589385	DMITRIY NOVIKOV	{"email": "novikovd26121973@postgrespro.ru", "phone": "+70454216664"}
0005432294492	E14DDF	6874 547459	TATYANA NOVIKOVA	{"email": "novikova-t_051976@postgrespro.ru", "phone": "+70470237671"}
0005432294493	F8F5A1	7975 545886	LYUDMILA KONOVALOVA	{"email": "l_konovalova.1975@postgrespro.ru", "phone": "+70980061441"}
0005432294494	E94FB7	4203 631836	NINA KULIKOVA	{"email": "n_kulikova_1970@postgrespro.ru", "phone": "+70949296607"}
0005432294495	683F37	0038 543317	OLESYA IVANOVA	{"phone": "+70740971541"}
0005432294496	07F95F	2845 522004	SERGEY MAKAROV	{"phone": "+70209683643"}
0005432294497	07F95F	0425 100469	ZOYA AKIMOVA	{"email": "akimovazoya_121965@postgrespro.ru", "phone": "+70834098438"}
0005432294498	40CF97	5982 139953	ANDREY KRASNOV	{"phone": "+70621722365"}
0005432294499	41CD61	3287 756910	VLADIMIR MAKAROV	{"email": "vladimir_makarov.15021977@postgrespro.ru", "phone": "+70404207097"}
0005432294500	41CD61	8939 329255	GALINA KOVALEVA	{"email": "g.kovaleva15111975@postgrespro.ru", "phone": "+70341989006"}
0005432294501	0D8C52	4125 625740	ELENA IVANOVA	{"email": "ivanovaelena_051969@postgrespro.ru", "phone": "+70293334425"}
0005432294502	E23007	5064 526333	VLADIMIR MATVEEV	{"email": "matveev-v031979@postgrespro.ru", "phone": "+70756641775"}
0005432294503	E23007	9125 778361	ELENA VLASOVA	{"email": "vlasova.elena_05011971@postgrespro.ru", "phone": "+70683174586"}
0005432294504	1C6EDB	8817 423537	SERGEY KAZAKOV	{"phone": "+70563386004"}
0005432294505	1BF922	9023 631190	NATALYA IVANOVA	{"email": "ivanova_natalya.111975@postgrespro.ru", "phone": "+70341302056"}
0005432294506	1BF922	2373 018445	SERGEY FROLOV	{"email": "frolov.sergey_08031960@postgrespro.ru", "phone": "+70125336912"}
0005432294507	73B8D4	7324 986259	OLGA SOKOLOVA	{"phone": "+70082028279"}
0005432294508	73B8D4	2696 883390	POLINA NIKITINA	{"phone": "+70882009887"}
0005432294509	F3A5A6	6397 775526	ROMAN SOLOVEV	{"email": "rsolovev-1962@postgrespro.ru", "phone": "+70690460128"}
0005432294510	F3A5A6	3507 821893	MAKSIM ABRAMOV	{"email": "abramov-m091973@postgrespro.ru", "phone": "+70912307803"}
0005432294511	9D29AE	9623 697752	OLGA SOROKINA	{"email": "o-sorokina.101970@postgrespro.ru", "phone": "+70931095353"}
0005432294512	9D29AE	5412 014686	LARISA ZAYCEVA	{"email": "zayceva_larisa.071983@postgrespro.ru", "phone": "+70044677586"}
0005432294513	2089EA	8966 132309	GENNADIY KOZLOV	{"email": "g_kozlov.21041969@postgrespro.ru", "phone": "+70161575547"}
0005432294514	D7A30B	1236 169975	VLADIMIR ZHUKOV	{"email": "vladimirzhukov02071974@postgrespro.ru", "phone": "+70443172879"}
0005432294515	75C302	3518 057888	GALINA DANILOVA	{"email": "danilova-galina.101980@postgrespro.ru", "phone": "+70205238515"}
0005432294516	C4A7F0	6344 703821	ALBINA GAVRILOVA	{"email": "albina.gavrilova-011984@postgrespro.ru", "phone": "+70585124306"}
0005432294517	C4A7F0	3411 634736	LIDIYA NIKOLAEVA	{"phone": "+70285157435"}
0005432294518	6C8FC2	8871 034877	LIDIYA SAVELEVA	{"email": "l-saveleva_19011971@postgrespro.ru", "phone": "+70564063909"}
0005432294519	6C8FC2	8151 940135	RUSLAN FEDOROV	{"phone": "+70873850982"}
0005432294520	BE748E	8618 940061	TATYANA PAVLOVA	{"email": "tatyana_pavlova.051967@postgrespro.ru", "phone": "+70789275722"}
0005432294521	D3095C	4131 335463	OLESYA KUDRYASHOVA	{"email": "o-kudryashova-1965@postgrespro.ru", "phone": "+70477825062"}
0005432294522	7785F9	9245 623452	LARISA IVANOVA	{"phone": "+70380949961"}
0005432294523	7785F9	4970 835530	TATYANA VOROBEVA	{"phone": "+70691207107"}
0005432294524	F8C151	1403 293282	ROMAN GORBUNOV	{"email": "romangorbunov_111965@postgrespro.ru", "phone": "+70144635585"}
0005432294525	F8C151	3621 697789	EVGENIY ORLOV	{"phone": "+70299805460"}
0005432294526	71F154	7044 766373	IRINA NAZAROVA	{"email": "i_nazarova_1975@postgrespro.ru", "phone": "+70475902151"}
0005432294527	8FC690	4375 186222	ANDREY PETROV	{"email": "andrey-petrov121977@postgrespro.ru", "phone": "+70095917844"}
0005432294528	6F07A2	6856 773178	GENNADIY ORLOV	{"email": "gennadiy_orlov061964@postgrespro.ru", "phone": "+70066947229"}
0005432294529	4067DE	3210 136040	VIKTOR ANDREEV	{"email": "andreevv_121975@postgrespro.ru", "phone": "+70696091537"}
0005432294530	4067DE	6964 134663	EVGENIYA TROFIMOVA	{"email": "e-trofimova.22021972@postgrespro.ru", "phone": "+70442530387"}
0005432294531	44DC32	1707 349074	SERGEY TIMOFEEV	{"email": "timofeev-s1966@postgrespro.ru", "phone": "+70551771608"}
0005432294532	E614AB	5819 797465	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov081972@postgrespro.ru", "phone": "+70776763100"}
0005432294533	01822F	2862 829645	ALEKSEY ZHUKOV	{"email": "zhukov.a_1979@postgrespro.ru", "phone": "+70652833043"}
0005432294534	01822F	5018 226646	KSENIYA EGOROVA	{"phone": "+70649485576"}
0005432294535	D9FB39	7389 422897	ALEKSEY CHERNOV	{"phone": "+70794799767"}
0005432294536	AE6D96	4659 450474	ALINA PETROVA	{"phone": "+70128101318"}
0005432294537	AE6D96	2354 850771	SERGEY GORBUNOV	{"email": "gorbunov-sergey_1971@postgrespro.ru", "phone": "+70345071998"}
0005432294538	AE6D96	1891 111132	NATALYA ARKHIPOVA	{"email": "n-arkhipova_15081964@postgrespro.ru", "phone": "+70307072053"}
0005432294539	E78DB7	2529 698436	NIKITA ABRAMOV	{"phone": "+70519417904"}
0005432294540	BC7C46	5463 576016	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev-111967@postgrespro.ru", "phone": "+70511011994"}
0005432294541	BC7C46	1735 461404	GALINA IVANOVA	{"email": "ivanova-galina.051973@postgrespro.ru", "phone": "+70182756115"}
0005432294542	A2A927	8021 792972	RAZIYA BORISOVA	{"phone": "+70245192194"}
0005432294543	31B872	6088 909955	VALENTINA KAZAKOVA	{"phone": "+70637037264"}
0005432294544	049445	6113 987091	DARYA PETROVA	{"email": "dpetrova_14031981@postgrespro.ru", "phone": "+70742564060"}
0005432294545	F39A2F	9899 741526	TATYANA KOROLEVA	{"email": "tkoroleva041973@postgrespro.ru", "phone": "+70034152563"}
0005432294546	FFC169	8508 062347	IRINA VASILEVA	{"email": "vasileva_irina_1981@postgrespro.ru", "phone": "+70282770660"}
0005432294547	51BA55	5365 100122	ALEKSANDR EGOROV	{"email": "aleksandr_egorov.1962@postgrespro.ru", "phone": "+70079898938"}
0005432294548	E25EAF	6475 155678	SOFIYA ZAYCEVA	{"email": "zayceva.sofiya13111979@postgrespro.ru", "phone": "+70469115441"}
0005432294549	5FBC8A	0820 988238	LYUDMILA IVANOVA	{"phone": "+70090887588"}
0005432294550	66E832	0422 721369	LYUBOV MOROZOVA	{"phone": "+70535470843"}
0005432294551	6FBE15	8063 061751	VASILIY TIKHONOV	{"email": "tikhonov.vasiliy.1970@postgrespro.ru", "phone": "+70068558733"}
0005432294552	9A6399	2485 245054	MARIYA KUZMINA	{"email": "mariya-kuzmina-20031971@postgrespro.ru", "phone": "+70693293601"}
0005432294553	51C8B0	2197 314593	KLAVDIYA GERASIMOVA	{"email": "klavdiya.gerasimova-1966@postgrespro.ru", "phone": "+70492311103"}
0005432294554	51C8B0	3904 813491	NIKOLAY SCHERBAKOV	{"email": "nscherbakov021975@postgrespro.ru", "phone": "+70563441859"}
0005432294555	2E198C	3963 962863	DARYA KOLESNIKOVA	{"phone": "+70747437246"}
0005432294556	472CEF	0468 739453	SERGEY SERGEEV	{"phone": "+70881602098"}
0005432294557	B37ADB	9012 181907	EKATERINA POLYAKOVA	{"phone": "+70732603654"}
0005432294558	B37ADB	2526 191440	TATYANA NOVIKOVA	{"email": "tatyananovikova-16041973@postgrespro.ru", "phone": "+70980461970"}
0005432294559	2A00B9	9715 676296	ALEKSEY GRIGOREV	{"email": "alekseygrigorev111974@postgrespro.ru", "phone": "+70418416660"}
0005432294560	2A00B9	4277 847031	SERGEY TARASOV	{"email": "tarasov_sergey.1974@postgrespro.ru", "phone": "+70598710784"}
0005432294561	9825FC	6738 342607	SERGEY SIDOROV	{"phone": "+70646258847"}
0005432295832	FBA6D8	0591 958662	ANATOLIY ISAEV	{"email": "anatoliy.isaev071970@postgrespro.ru", "phone": "+70897472312"}
0005432295833	FC6633	9569 930104	ALEKSANDR SCHERBAKOV	{"phone": "+70039675847"}
0005432295834	AFF2CF	6690 939140	IGOR NOVIKOV	{"email": "inovikov_05041979@postgrespro.ru", "phone": "+70984800053"}
0005432295835	7FF525	2118 242839	IRINA ALEKSANDROVA	{"phone": "+70173394481"}
0005432295836	7FF525	7888 141925	DIANA DAVYDOVA	{"email": "davydova_diana-111977@postgrespro.ru", "phone": "+70587105016"}
0005432295837	7FF525	0384 486809	DENIS VOLKOV	{"email": "volkovd.07071971@postgrespro.ru", "phone": "+70388371815"}
0005432295838	053BCB	4807 375163	ANNA ANDREEVA	{"email": "aandreeva_1968@postgrespro.ru", "phone": "+70580965212"}
0005432295839	053BCB	3785 296894	ARTEM ALEKSEEV	{"email": "alekseeva1974@postgrespro.ru", "phone": "+70256270035"}
0005432295840	E3A335	7561 762131	LYUDMILA VOROBEVA	{"email": "vorobeva_lyudmila-1962@postgrespro.ru", "phone": "+70520408314"}
0005432295841	101AB4	2847 497493	SERGEY IVANOV	{"email": "sivanov01031968@postgrespro.ru", "phone": "+70382440247"}
0005432295842	515994	4574 591579	KRISTINA ROMANOVA	{"email": "romanovak.081965@postgrespro.ru", "phone": "+70378953834"}
0005432295843	515994	4173 181988	ILYA POPOV	{"phone": "+70064824786"}
0005432295844	272E58	9256 441183	IRINA SMIRNOVA	{"email": "irina-smirnova_021978@postgrespro.ru", "phone": "+70114153955"}
0005432295845	1B5ED4	6629 807853	LARISA FILATOVA	{"email": "filatova.larisa-1983@postgrespro.ru", "phone": "+70984361451"}
0005432295846	F04877	7664 742744	NATALYA KOROLEVA	{"phone": "+70819291409"}
0005432295847	C0DDD6	7894 620075	NATALYA MAKSIMOVA	{"email": "n-maksimova1973@postgrespro.ru", "phone": "+70585166516"}
0005432295848	8D7C43	8559 404397	ELENA GRISHINA	{"phone": "+70344064150"}
0005432295849	8D7C43	3279 706456	TATYANA KUZNECOVA	{"phone": "+70522945006"}
0005432295850	88AAE8	0549 936981	IGOR CHERNOV	{"phone": "+70525040598"}
0005432295851	B96CF1	9703 877194	YULIYA MELNIKOVA	{"phone": "+70652348832"}
0005432295852	43EE1F	2612 775350	NATALIYA SIDOROVA	{"phone": "+70704840404"}
0005432295853	6A19B6	1866 344116	YURIY SMIRNOV	{"email": "ysmirnov_1977@postgrespro.ru", "phone": "+70289876366"}
0005432295854	6A19B6	3106 032037	SVETLANA MEDVEDEVA	{"phone": "+70618773047"}
0005432295855	6A8EAB	1473 557337	VLADIMIR SMIRNOV	{"phone": "+70875849934"}
0005432295856	3E555F	9240 400093	NATALYA MOISEEVA	{"email": "moiseevanatalya_071977@postgrespro.ru", "phone": "+70997193052"}
0005432295857	ED770C	8091 663349	PAVEL SOLOVEV	{"email": "pavelsolovev1982@postgrespro.ru", "phone": "+70988019772"}
0005432295858	ED770C	9853 138368	LARISA ZHUKOVA	{"email": "zhukova.larisa-1973@postgrespro.ru", "phone": "+70212231883"}
0005432295859	8BD926	0200 601889	PETR AFANASEV	{"email": "afanasev-p_041978@postgrespro.ru", "phone": "+70791322279"}
0005432295860	8BD926	3577 002438	ANDREY VLASOV	{"phone": "+70017717644"}
0005432295861	8BD926	7273 423693	ELENA ZAYCEVA	{"phone": "+70206478389"}
0005432295862	2A3648	0713 302933	IRINA LUKYANOVA	{"phone": "+70032614906"}
0005432295863	040F92	4536 955531	POLINA OSIPOVA	{"phone": "+70070529243"}
0005432295864	040F92	8571 692179	IGOR DENISOV	{"email": "denisovigor091975@postgrespro.ru", "phone": "+70250429722"}
0005432295865	040F92	6079 201270	GALINA MIRONOVA	{"email": "mironova-g-1967@postgrespro.ru", "phone": "+70130038288"}
0005432295866	3EB2A8	4581 533046	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov_27101965@postgrespro.ru", "phone": "+70637487993"}
0005432295867	3EB2A8	1854 648152	LYUDMILA ZOTOVA	{"email": "zotova-l-23071975@postgrespro.ru", "phone": "+70376932918"}
0005432295868	C35770	7424 026966	INNA MOISEEVA	{"email": "i_moiseeva_02041975@postgrespro.ru", "phone": "+70975417353"}
0005432295869	3BA4C9	5261 309354	ELENA EGOROVA	{"phone": "+70122875004"}
0005432295870	563D74	5992 379510	GENNADIY MARTYNOV	{"phone": "+70155399617"}
0005432295871	563D74	9018 600112	LYUDMILA VOROBEVA	{"phone": "+70893843876"}
0005432295872	563D74	5440 772741	NADEZHDA SCHERBAKOVA	{"phone": "+70245667822"}
0005432295873	0D9E45	9539 524612	VYACHESLAV ANTONOV	{"phone": "+70924449760"}
0005432295874	6A8CEF	2688 466875	VALENTINA MAKAROVA	{"email": "v-makarova041962@postgrespro.ru", "phone": "+70566426034"}
0005432295875	E7DAB7	0213 681509	ANATOLIY ZAKHAROV	{"email": "zakharov.anatoliy-111963@postgrespro.ru", "phone": "+70778654351"}
0005432295876	973D8C	3522 617976	GALINA KUZMINA	{"phone": "+70341751629"}
0005432295877	973D8C	8817 766663	ROMAN ZAKHAROV	{"email": "r.zakharov-1967@postgrespro.ru", "phone": "+70860216337"}
0005432295878	D170F9	5242 427743	LEV NOVIKOV	{"email": "l.novikov-021977@postgrespro.ru", "phone": "+70964653635"}
0005432295879	D170F9	0584 790009	LARISA ORLOVA	{"phone": "+70381158676"}
0005432295880	57259A	5314 285681	SERGEY SOKOLOV	{"email": "sokolovsergey_1978@postgrespro.ru", "phone": "+70726577422"}
0005432295881	2D82CE	9912 344630	OLGA POPOVA	{"email": "olgapopova.041980@postgrespro.ru", "phone": "+70559796463"}
0005432295882	094D80	7460 502968	YULIYA BORISOVA	{"email": "y.borisova_29101961@postgrespro.ru", "phone": "+70431908748"}
0005432295883	7A1B18	2647 606834	SERGEY GORBUNOV	{"phone": "+70614020416"}
0005432295884	7AE429	6955 490278	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda-1976@postgrespro.ru", "phone": "+70055339977"}
0005432295885	48098E	9236 974121	VIKTORIYA ANTONOVA	{"email": "antonova.viktoriya1976@postgrespro.ru", "phone": "+70298805071"}
0005432295886	48098E	5179 710551	NELLI IVANOVA	{"phone": "+70010871839"}
0005432295887	7E598A	9534 172131	ANNA SOLOVEVA	{"phone": "+70928791918"}
0005432295888	7E598A	0273 822635	VALERIY DENISOV	{"email": "v_denisov31031982@postgrespro.ru", "phone": "+70695880780"}
0005432295889	182C0D	0802 692119	YULIYA DENISOVA	{"email": "denisova.y21081971@postgrespro.ru", "phone": "+70448930496"}
0005432295890	182C0D	9529 327789	KRISTINA DANILOVA	{"phone": "+70737599901"}
0005432295891	B23FBB	0582 881957	ANTON IVANOV	{"phone": "+70180578888"}
0005432295892	1EFE6A	7708 178109	IGOR KARPOV	{"phone": "+70102004634"}
0005432295893	2FA12E	3732 411468	ANNA YUDINA	{"phone": "+70014704774"}
0005432295894	DB2776	2238 336622	NATALYA FOMINA	{"phone": "+70468459078"}
0005432295895	AABDA5	7095 765434	VALERIY SOROKIN	{"phone": "+70994895674"}
0005432295896	AABDA5	0479 394760	GRIGORIY ROMANOV	{"phone": "+70020990065"}
0005432295897	38DF26	8380 228245	ALEKSEY IVANOV	{"email": "ivanov-a.30051971@postgrespro.ru", "phone": "+70001574541"}
0005432295898	6F3DCD	4465 493066	ALEKSANDR TARASOV	{"phone": "+70517361028"}
0005432295899	AEB232	0544 105924	IVAN MIRONOV	{"email": "i_mironov-1970@postgrespro.ru", "phone": "+70110906506"}
0005432295900	143C21	5079 279802	IRINA SOKOLOVA	{"phone": "+70895119877"}
0005432295901	AA8581	4084 182516	LEV IVANOV	{"phone": "+70829459859"}
0005432295902	AA8581	1549 755239	MARIYA ILINA	{"phone": "+70109174703"}
0005432295903	C19667	2003 424014	PETR KUZNECOV	{"email": "kuznecovp041976@postgrespro.ru", "phone": "+70396581684"}
0005432295904	014C33	5223 019095	NADEZHDA KISELEVA	{"phone": "+70263644328"}
0005432295905	014C33	1673 286883	LARISA IVANOVA	{"phone": "+70868831410"}
0005432295906	03E3CD	1443 049103	VLADIMIR KISELEV	{"phone": "+70692699342"}
0005432295907	383552	8346 616405	ALEKSEY SEMENOV	{"email": "a_semenov26081979@postgrespro.ru", "phone": "+70562980984"}
0005432295908	A67A01	5086 222807	GALINA KOROLEVA	{"phone": "+70178854843"}
0005432295909	D6AC2A	1868 704361	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr.071967@postgrespro.ru", "phone": "+70944794715"}
0005432295910	BB189C	9440 747613	ALEKSANDR EGOROV	{"email": "a.egorov.021969@postgrespro.ru", "phone": "+70268445566"}
0005432295911	92744F	8666 929244	ELENA VOROBEVA	{"phone": "+70748340373"}
0005432295912	518699	5447 217193	MARIYA STEPANOVA	{"email": "stepanova.mariya.08061978@postgrespro.ru", "phone": "+70678312093"}
0005432295913	F67CC5	8682 568416	EKATERINA TIKHONOVA	{"phone": "+70296639312"}
0005432295914	7F234E	6542 003289	LILIYA SOLOVEVA	{"email": "lsoloveva-071978@postgrespro.ru", "phone": "+70920382194"}
0005432295915	9A8BF0	0811 772537	TATYANA MIRONOVA	{"phone": "+70610939762"}
0005432295916	122308	9513 180287	LYUBOV MIKHAYLOVA	{"phone": "+70796146119"}
0005432295917	534D9E	7887 846542	SERGEY ZHUKOV	{"phone": "+70391649848"}
0005432295918	B52529	4576 756584	SVETLANA ROMANOVA	{"email": "svetlanaromanova-061959@postgrespro.ru", "phone": "+70188032155"}
0005432295919	B52529	1587 184621	ILFAT KULIKOV	{"email": "kulikov_ilfat.1965@postgrespro.ru", "phone": "+70077795146"}
0005432295920	B52529	1115 869258	ARTEM KRASNOV	{"phone": "+70414187547"}
0005432295921	7493A1	6910 928746	ELVIRA CHERNOVA	{"phone": "+70953266858"}
0005432295922	5DD147	4568 425589	ZINAIDA MATVEEVA	{"email": "zinaidamatveeva07101974@postgrespro.ru", "phone": "+70838202606"}
0005432295923	5DD147	4195 636482	LARISA FILIPPOVA	{"email": "filippova.larisa_071970@postgrespro.ru", "phone": "+70307960034"}
0005432295924	5DD147	5227 127440	KRISTINA BORISOVA	{"email": "borisovakristina1970@postgrespro.ru", "phone": "+70679797676"}
0005432295925	B14DAE	8780 102688	OKSANA EFIMOVA	{"phone": "+70685453674"}
0005432295926	7CE041	3437 592055	OLGA SEMENOVA	{"phone": "+70225101439"}
0005432295927	7CE041	2118 174941	ANDREY TARASOV	{"phone": "+70036383461"}
0005432295928	E5CDE3	9404 481660	VALERIY DMITRIEV	{"phone": "+70600535213"}
0005432295929	E5CDE3	0920 863686	IVAN SOROKIN	{"email": "sorokin_i.061979@postgrespro.ru", "phone": "+70217539882"}
0005432295930	A799AD	4739 259357	NIKOLAY RODIONOV	{"phone": "+70861951055"}
0005432295931	8D4339	5941 830074	SVETLANA AFANASEVA	{"phone": "+70122908050"}
0005432295932	8D4339	4009 624277	EVGENIYA PETROVA	{"email": "e-petrova-1970@postgrespro.ru", "phone": "+70255409571"}
0005432295933	9A0369	9587 579420	SERGEY SEMENOV	{"email": "sergeysemenov_081979@postgrespro.ru", "phone": "+70293472913"}
0005432295934	9A0369	3573 982148	EKATERINA MOROZOVA	{"phone": "+70698875495"}
0005432295935	0CB91B	0936 737661	ALEKSANDR EGOROV	{"email": "egorov.aleksandr24091979@postgrespro.ru", "phone": "+70397120671"}
0005432295936	0CB91B	9826 324064	NATALYA ANTONOVA	{"email": "n_antonova021974@postgrespro.ru", "phone": "+70599515602"}
0005432295937	E45FE2	8071 852977	IVAN ORLOV	{"email": "ivanorlov-1989@postgrespro.ru", "phone": "+70758155542"}
0005432295938	485F88	0043 300544	EVGENIY SCHERBAKOV	{"phone": "+70311162461"}
0005432295939	485F88	0011 756915	TAMARA PAVLOVA	{"email": "t-pavlova091972@postgrespro.ru", "phone": "+70791371360"}
0005432295940	C083E3	0678 622799	DENIS PAVLOV	{"email": "pavlov.denis_1970@postgrespro.ru", "phone": "+70806650287"}
0005432295941	C083E3	1969 272259	OLGA MASLOVA	{"phone": "+70276607695"}
0005432295942	ADE117	6531 198414	KIRILL ABRAMOV	{"email": "abramov_k.30081958@postgrespro.ru", "phone": "+70300682103"}
0005432295943	DE3FE9	5550 216038	YURIY KOZLOV	{"phone": "+70802298062"}
0005432295944	ECCA1D	1278 110767	SERGEY SEMENOV	{"email": "semenov_sergey.30041982@postgrespro.ru", "phone": "+70175710536"}
0005432295945	DC86DD	7019 796626	DANILA MOISEEV	{"email": "moiseevdanila.13011983@postgrespro.ru", "phone": "+70232600512"}
0005432295946	43BE7B	0326 191238	OLGA DMITRIEVA	{"email": "dmitrieva_o.031968@postgrespro.ru", "phone": "+70060071965"}
0005432295947	43BE7B	9583 912081	VALENTINA BORISOVA	{"email": "borisova-v.041978@postgrespro.ru", "phone": "+70219896775"}
0005432295948	43BE7B	5829 570608	EKATERINA CHERNOVA	{"phone": "+70535709484"}
0005432295949	0C8AD8	4432 157712	LARISA EGOROVA	{"phone": "+70993769675"}
0005432295950	1EFFE4	4753 098427	ELENA SEMENOVA	{"phone": "+70672958078"}
0005432295951	1A886E	2834 340251	NATALYA KUZMINA	{"email": "kuzmina_natalya_1966@postgrespro.ru", "phone": "+70573793274"}
0005432295952	1A886E	1079 495609	SERGEY NAUMOV	{"phone": "+70219452969"}
0005432295953	6DE102	4015 153516	IRINA SOKOLOVA	{"phone": "+70446565549"}
0005432295954	9F62E0	4553 958462	SERGEY TIMOFEEV	{"email": "sergey.timofeev_09041977@postgrespro.ru", "phone": "+70261740428"}
0005432295955	C01798	7315 950835	YURIY TIKHONOV	{"phone": "+70686361011"}
0005432295956	FC723D	9819 751584	VLADIMIR ALEKSEEV	{"phone": "+70175191100"}
0005432295957	FC723D	1212 806819	IVAN EGOROV	{"phone": "+70781049620"}
0005432295958	EB9DA8	9604 144829	ELENA EFREMOVA	{"phone": "+70856379522"}
0005432295959	EB9DA8	0152 612195	ALEKSANDR ABRAMOV	{"phone": "+70238789296"}
0005432295960	517A9B	6048 426605	PETR EGOROV	{"email": "petregorov_021977@postgrespro.ru", "phone": "+70682743486"}
0005432297251	9B2D7E	9356 341035	EKATERINA KUZNECOVA	{"phone": "+70860207392"}
0005432297230	5CBB48	1851 891897	VLADIMIR ILIN	{"phone": "+70595721531"}
0005432297231	D0EA08	0907 617627	NATALYA KUZNECOVA	{"email": "kuznecova.natalya05081972@postgrespro.ru", "phone": "+70637513475"}
0005432297232	D42A30	6384 496646	OLGA KOZLOVA	{"phone": "+70524006523"}
0005432297233	F3F9A0	4122 187215	ILYA FROLOV	{"email": "ilya-frolov_101959@postgrespro.ru", "phone": "+70242542103"}
0005432297234	F3F9A0	0133 466067	VIKTORIYA MIRONOVA	{"email": "mironova-v071986@postgrespro.ru", "phone": "+70060072063"}
0005432297235	4D04C4	0279 754418	VALERIY VASILEV	{"phone": "+70867966845"}
0005432297236	4D04C4	9912 307353	NIKOLAY SIDOROV	{"email": "nikolaysidorov.111990@postgrespro.ru", "phone": "+70103268552"}
0005432297237	62F51E	2071 502988	NATALYA ALEKSEEVA	{"phone": "+70895548296"}
0005432297238	3637B3	0575 901006	SVETLANA VOROBEVA	{"email": "s-vorobeva.03051969@postgrespro.ru", "phone": "+70383773425"}
0005432297239	3637B3	4609 489222	NURLAN BORISOV	{"email": "borisov_n-23071971@postgrespro.ru", "phone": "+70874904201"}
0005432297240	4F61A8	7645 259845	VALERIY TARASOV	{"email": "valeriy_tarasov101976@postgrespro.ru", "phone": "+70207558185"}
0005432297241	8360A5	6901 159340	NATALYA BARANOVA	{"email": "n.baranova1970@postgrespro.ru", "phone": "+70696715471"}
0005432297242	98F0E1	8841 004670	NIKITA FEDOROV	{"phone": "+70349729813"}
0005432297243	F0D48D	2724 654310	ALLA OSIPOVA	{"phone": "+70451329511"}
0005432297244	91F55C	1172 985484	ANATOLIY MAKSIMOV	{"email": "maksimov-anatoliy_101964@postgrespro.ru", "phone": "+70566078359"}
0005432297245	A7FE99	2289 251060	MARGARITA VOLKOVA	{"phone": "+70115838246"}
0005432297246	60EF6C	6520 415975	LEV ALEKSEEV	{"phone": "+70436445760"}
0005432297247	60EF6C	5690 659893	ALEKSANDR EGOROV	{"email": "egorova-051975@postgrespro.ru", "phone": "+70540506622"}
0005432297248	7EE965	5946 839961	RAISA SIDOROVA	{"email": "raisa-sidorova07071971@postgrespro.ru", "phone": "+70300629763"}
0005432297249	7EE965	4710 109851	MIKHAIL ANTONOV	{"email": "antonov_m_101973@postgrespro.ru", "phone": "+70549965353"}
0005432297250	7EE965	1462 650750	GALINA FADEEVA	{"email": "gfadeeva_1980@postgrespro.ru", "phone": "+70059321470"}
0005432297252	DA2755	9301 125669	NATALIYA LOGINOVA	{"phone": "+70627201633"}
0005432297253	390BC8	3487 696235	RUSTAM EGOROV	{"email": "egorovrustam-011964@postgrespro.ru", "phone": "+70723155674"}
0005432297254	462C3C	8575 749194	NIKOLAY PAVLOV	{"phone": "+70944866065"}
0005432297255	0E884C	7032 066988	GENNADIY KUZNECOV	{"phone": "+70057519142"}
0005432297256	0E884C	0735 048659	ALEKSEY GRIGOREV	{"email": "grigorev.a_16011969@postgrespro.ru", "phone": "+70701704418"}
0005432297257	881EE8	4366 776252	EVGENIY FILIPPOV	{"email": "evgeniyfilippov02091975@postgrespro.ru", "phone": "+70877134888"}
0005432297258	881EE8	3634 619070	TATYANA LAZAREVA	{"email": "t.lazareva-1978@postgrespro.ru", "phone": "+70546746476"}
0005432297259	44C1C5	5270 474041	GRIGORIY PAVLOV	{"email": "grigoriypavlov-041983@postgrespro.ru", "phone": "+70039522957"}
0005432297260	44C1C5	7883 951097	NATALYA POTAPOVA	{"email": "n-potapova_101976@postgrespro.ru", "phone": "+70583141599"}
0005432297261	7E3AE5	2092 868486	NIKITA KONOVALOV	{"phone": "+70342471808"}
0005432297262	583619	6234 870241	VIKTOR CHERNOV	{"email": "v-chernov1977@postgrespro.ru", "phone": "+70479441513"}
0005432297263	00A27A	9685 856335	LYUBOV KOZLOVA	{"phone": "+70328737496"}
0005432297264	920C36	3978 614948	NADEZHDA MALYSHEVA	{"email": "malysheva_nadezhda1971@postgrespro.ru", "phone": "+70053725029"}
0005432297265	78A646	2296 746573	VLADIMIR POPOV	{"email": "vladimir.popov.23081972@postgrespro.ru", "phone": "+70875960322"}
0005432297266	78A646	6281 918417	MARIYA SMIRNOVA	{"email": "mariya-smirnova-12021969@postgrespro.ru", "phone": "+70824635052"}
0005432297267	B7A00C	5377 256389	OLGA KUZNECOVA	{"phone": "+70027304689"}
0005432297268	13015D	9761 681038	ELENA NOVIKOVA	{"email": "elena-novikova-1978@postgrespro.ru", "phone": "+70461170859"}
0005432297269	D8DF17	9951 729997	DARYA PAVLOVA	{"email": "pavlova.darya_1971@postgrespro.ru", "phone": "+70605961869"}
0005432297270	D8DF17	5864 957701	TATYANA DMITRIEVA	{"email": "dmitrieva.tatyana.031967@postgrespro.ru", "phone": "+70984366710"}
0005432297271	A3165C	7754 369429	MAKSIM MATVEEV	{"phone": "+70379648940"}
0005432297272	8DA360	3580 820350	ANASTASIYA VOLKOVA	{"email": "a_volkova-16031981@postgrespro.ru", "phone": "+70460749126"}
0005432297273	8DA360	6388 302882	NINA MEDVEDEVA	{"phone": "+70129928577"}
0005432297274	C756B1	7211 823926	VYACHESLAV KRASNOV	{"phone": "+70047502997"}
0005432297275	C756B1	4232 597057	OLGA EFREMOVA	{"phone": "+70833196550"}
0005432297276	E95D24	6628 836060	EKATERINA MASLOVA	{"phone": "+70758734517"}
0005432297277	632934	6608 658791	ALEKSEY MAKAROV	{"email": "makarov.a-04071975@postgrespro.ru", "phone": "+70479269621"}
0005432297278	F90585	2998 015540	NADEZHDA MAKAROVA	{"email": "makarova_nadezhda1967@postgrespro.ru", "phone": "+70569487994"}
0005432297279	58506F	6221 278668	ANDREY KUZMIN	{"email": "kuzmin_andrey-051982@postgrespro.ru", "phone": "+70610682726"}
0005432297280	F875C4	1655 515971	SVETLANA LEBEDEVA	{"email": "lebedevas_1961@postgrespro.ru", "phone": "+70212768965"}
0005432297281	651D35	5476 197495	IVAN CHERNOV	{"email": "i.chernov_1965@postgrespro.ru", "phone": "+70570458477"}
0005432297282	C73156	1498 330358	RAVIL MAKAROV	{"email": "rmakarov_101981@postgrespro.ru", "phone": "+70162555382"}
0005432297283	4E9CB3	6569 815175	IVAN NIKITIN	{"phone": "+70269987597"}
0005432297284	FA5377	2577 082657	ALEKSANDR ORLOV	{"email": "a_orlov021976@postgrespro.ru", "phone": "+70827894235"}
0005432297285	A62468	4953 466028	ARINA KARPOVA	{"email": "arina_karpova-1964@postgrespro.ru", "phone": "+70466835994"}
0005432297286	635488	8660 136400	ILYA ALEKSANDROV	{"email": "ilya-aleksandrov-28061971@postgrespro.ru", "phone": "+70870218882"}
0005432297287	635488	8324 426475	VIKTOR MEDVEDEV	{"email": "medvedev.viktor_1970@postgrespro.ru", "phone": "+70939704561"}
0005432297288	635488	1186 240312	ANNA AKIMOVA	{"phone": "+70374036143"}
0005432297289	621E19	3087 231689	KSENIYA ZHURAVLEVA	{"phone": "+70526412152"}
0005432297290	621E19	3262 650112	VERA SOROKINA	{"phone": "+70554629858"}
0005432297291	0466E6	3181 075271	VLADIMIR POPOV	{"phone": "+70951354272"}
0005432297292	C8D67C	1215 962668	LILIYA DAVYDOVA	{"email": "davydova_liliya_1975@postgrespro.ru", "phone": "+70656510925"}
0005432297293	C8D67C	9717 991131	TATYANA ZAYCEVA	{"email": "tatyana.zayceva_1971@postgrespro.ru", "phone": "+70134248447"}
0005432297294	BE6872	8364 923374	VALERIYA NESTEROVA	{"phone": "+70807724850"}
0005432297295	AD00E4	5022 039046	VALENTINA CHERNOVA	{"phone": "+70863997566"}
0005432297296	9553AA	1091 293318	STEPAN KOROLEV	{"phone": "+70979426745"}
0005432297297	483764	9509 368246	ELENA ZHURAVLEVA	{"email": "elena-zhuravleva_011978@postgrespro.ru", "phone": "+70176167896"}
0005432297298	483764	2341 524242	SERGEY KONOVALOV	{"email": "konovalovs_1964@postgrespro.ru", "phone": "+70580087037"}
0005432297299	320C00	1255 459061	TATYANA TARASOVA	{"phone": "+70501383032"}
0005432297300	96E8AD	7669 410824	ANNA VLASOVA	{"phone": "+70882127902"}
0005432297301	96E8AD	1406 936024	ROMAN DENISOV	{"phone": "+70300692436"}
0005432297302	56E3F0	4681 487708	ARTEM SERGEEV	{"phone": "+70317448610"}
0005432297303	3A78C8	9952 532288	MARIYA DAVYDOVA	{"email": "davydova.mariya16111974@postgrespro.ru", "phone": "+70348378869"}
0005432297304	DB730E	7647 192884	LIDIYA ILINA	{"phone": "+70448888571"}
0005432297305	DB730E	9442 854535	NELLI FILIPPOVA	{"phone": "+70575758172"}
0005432297306	F6E950	7015 554581	IVAN ANDREEV	{"phone": "+70616014215"}
0005432297307	F6E950	6355 668819	TAISA SMIRNOVA	{"email": "smirnova-t08111970@postgrespro.ru", "phone": "+70904689549"}
0005432297308	EAA2D6	2831 889339	ALEKSANDR BORISOV	{"email": "aleksandr.borisov-1969@postgrespro.ru", "phone": "+70287184326"}
0005432297309	EAA2D6	6409 689573	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.s-29091971@postgrespro.ru", "phone": "+70763828922"}
0005432297310	C4D3F2	4160 796612	ARTEM MOROZOV	{"email": "artemmorozov-1969@postgrespro.ru", "phone": "+70515345647"}
0005432297311	591EA6	4232 202166	YURIY SOLOVEV	{"email": "solovev.y1962@postgrespro.ru", "phone": "+70562303447"}
0005432297312	591EA6	8880 362646	ANNA BELYAEVA	{"email": "annabelyaeva.29091981@postgrespro.ru", "phone": "+70939479172"}
0005432297313	200BC3	0990 504748	VIKTORIYA PETROVA	{"phone": "+70586340948"}
0005432297314	200BC3	3748 827122	ANASTASIYA SEMENOVA	{"email": "semenova.anastasiya_31081981@postgrespro.ru", "phone": "+70422524092"}
0005432297315	8996BF	6351 905256	VALERIY MAKSIMOV	{"email": "maksimovv101982@postgrespro.ru", "phone": "+70555377598"}
0005432297316	A084EA	5975 232717	ALINA SAVELEVA	{"email": "saveleva.alina-1961@postgrespro.ru", "phone": "+70855558136"}
0005432297317	475ECC	5350 864800	ALEKSANDR IVANOV	{"phone": "+70224864236"}
0005432297318	475ECC	9549 937612	NIKOLAY FEDOTOV	{"email": "n.fedotov_1978@postgrespro.ru", "phone": "+70875338456"}
0005432297319	B42EC6	0234 710840	VLADIMIR DMITRIEV	{"email": "dmitrievv.24051976@postgrespro.ru", "phone": "+70780315732"}
0005432297320	B42EC6	5413 706526	VITALIY NIKITIN	{"email": "vitaliy_nikitin_071970@postgrespro.ru", "phone": "+70031850801"}
0005432297321	B42EC6	5837 287581	ZHANNA VASILEVA	{"email": "vasileva_zhanna-071965@postgrespro.ru", "phone": "+70320790730"}
0005432297322	A02EAF	9469 458666	KHALIDA ANDREEVA	{"email": "k.andreeva.10041982@postgrespro.ru", "phone": "+70910410863"}
0005432297323	A02EAF	6118 709276	EKATERINA BELOVA	{"phone": "+70128203203"}
0005432297324	DF4F34	0947 749351	VALERIY SERGEEV	{"email": "v.sergeev1973@postgrespro.ru", "phone": "+70438627244"}
0005432297325	DF4F34	0405 060417	DIANA DENISOVA	{"email": "denisova-d-1970@postgrespro.ru", "phone": "+70523339916"}
0005432297326	DF4F34	0029 478074	ALEKSANDR GAVRILOV	{"phone": "+70610600849"}
0005432297327	DA3177	3652 006381	VLADIMIR TIMOFEEV	{"email": "timofeevv-061972@postgrespro.ru", "phone": "+70957158335"}
0005432297328	327A1B	1272 847292	NIKOLAY KOROLEV	{"phone": "+70594019934"}
0005432297329	121833	7800 030663	SERGEY ZAKHAROV	{"email": "zakharovsergey.1967@postgrespro.ru", "phone": "+70319131579"}
0005432297330	55D016	8322 470955	ALEKSANDR FOMIN	{"email": "fominaleksandr.1966@postgrespro.ru", "phone": "+70307134146"}
0005432297331	55D016	5349 493615	EVGENIY FEDOROV	{"phone": "+70718393078"}
0005432297332	FDBCFE	5153 206286	ALEKSANDR NIKITIN	{"email": "nikitina.26021969@postgrespro.ru", "phone": "+70651278920"}
0005432297333	273505	7583 259360	ARTEM NAUMOV	{"email": "naumov-a-081980@postgrespro.ru", "phone": "+70362450879"}
0005432297334	57BF1E	8537 862470	VLADISLAV VOLKOV	{"email": "vvolkov1984@postgrespro.ru", "phone": "+70348332989"}
0005432297335	57BF1E	7551 039116	OLGA ANTONOVA	{"phone": "+70266245305"}
0005432297336	E53A62	2883 136746	IRINA KUZNECOVA	{"phone": "+70303738538"}
0005432297337	6BA013	2726 628741	SVETLANA FROLOVA	{"email": "frolovas.111982@postgrespro.ru", "phone": "+70847990762"}
0005432297338	7DE360	5722 736694	KONSTANTIN DAVYDOV	{"phone": "+70600664485"}
0005432297339	CCAD8D	3532 462610	NATALYA NESTEROVA	{"phone": "+70319526769"}
0005432297340	1F6023	5892 631033	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova_1986@postgrespro.ru", "phone": "+70117557015"}
0005432297341	80DD93	8605 789192	DENIS ZAKHAROV	{"phone": "+70707628778"}
0005432297342	F7F2AA	8750 642453	ANATOLIY SERGEEV	{"email": "sergeev-anatoliy.101974@postgrespro.ru", "phone": "+70184752430"}
0005432297343	A45B23	4700 066348	ANNA VOROBEVA	{"email": "anna_vorobeva1969@postgrespro.ru", "phone": "+70072147285"}
0005432297344	510FAD	0545 104227	VYACHESLAV ROMANOV	{"phone": "+70224895228"}
0005432297345	50E5A6	5148 465675	VITALIY DENISOV	{"email": "denisov.vitaliy_061966@postgrespro.ru", "phone": "+70256144718"}
0005432297346	5E43BE	7954 747052	ALEKSEY SERGEEV	{"email": "asergeev_1969@postgrespro.ru", "phone": "+70252941881"}
0005432297347	5E43BE	9734 991508	NADEZHDA KOROLEVA	{"phone": "+70476751678"}
0005432297348	0F7831	6741 392316	VITALIY IVANOV	{"phone": "+70821757079"}
0005432297349	DD959F	9026 826226	LIDIYA FADEEVA	{"phone": "+70055528779"}
0005432297350	EA530B	4237 908821	LYUBOV KISELEVA	{"email": "l_kiseleva25041973@postgrespro.ru", "phone": "+70335040301"}
0005432297351	EA530B	7756 323684	ANASTASIYA FILIPPOVA	{"phone": "+70235911616"}
0005432297352	322D24	6520 689218	MARIYA ALEKSANDROVA	{"email": "m_aleksandrova.1971@postgrespro.ru", "phone": "+70342803891"}
0005432297353	38BBEB	7046 503824	DMITRIY MELNIKOV	{"phone": "+70910631998"}
0005432300161	40B90A	4443 044141	IRINA VOLKOVA	{"email": "ivolkova1984@postgrespro.ru", "phone": "+70629307137"}
0005432300162	31C6CB	3356 761609	TAMARA FROLOVA	{"phone": "+70369221988"}
0005432300163	37924C	1895 841461	MARIYA VOROBEVA	{"phone": "+70565890716"}
0005432300164	37924C	7322 028431	SERGEY MAKAROV	{"phone": "+70091387783"}
0005432300165	869D4D	1664 890791	EKATERINA TIKHONOVA	{"phone": "+70128200964"}
0005432300166	945515	6285 547018	SERGEY KOZLOV	{"email": "kozlov_sergey_081981@postgrespro.ru", "phone": "+70280258731"}
0005432300167	D4A44A	2395 177053	NIKOLAY NIKOLAEV	{"phone": "+70778733698"}
0005432300168	664ED9	1484 656960	VALENTIN MAKAROV	{"email": "valentin.makarov.071973@postgrespro.ru", "phone": "+70638989100"}
0005432300169	969712	4556 062476	ELENA KOZLOVA	{"phone": "+70306579445"}
0005432300170	1A447E	5271 745507	OLEG MIRONOV	{"phone": "+70952208004"}
0005432300171	F2DE2B	6788 382022	ANNA KALININA	{"email": "anna_kalinina-09011978@postgrespro.ru", "phone": "+70752334952"}
0005432300172	EEB676	6987 236915	TATYANA KULIKOVA	{"phone": "+70622807865"}
0005432300173	EE2285	3097 395330	ANDREY KUZNECOV	{"phone": "+70169772791"}
0005432300174	EE2285	1482 125464	SVYATOSLAV ALEKSEEV	{"email": "alekseev_s-1978@postgrespro.ru", "phone": "+70417412313"}
0005432300175	EADBF7	9437 295586	ILYA NIKOLAEV	{"phone": "+70462582113"}
0005432300176	EADBF7	5519 545338	OLEG ZAYCEV	{"email": "oleg-zaycev-011972@postgrespro.ru", "phone": "+70000873003"}
0005432300177	83C3F6	8603 548186	OLGA STEPANOVA	{"email": "stepanovao_041969@postgrespro.ru", "phone": "+70796785203"}
0005432300178	C0D598	3069 717161	INNA ANDREEVA	{"phone": "+70216371533"}
0005432300179	93AB43	6781 997264	IVAN PAVLOV	{"phone": "+70441001385"}
0005432300180	B061AF	4132 332324	VLADIMIR MAKAROV	{"phone": "+70575487065"}
0005432300181	CCC9DE	4014 951724	KIRILL OSIPOV	{"email": "osipovkirill.06061973@postgrespro.ru", "phone": "+70600659253"}
0005432300182	26493A	2666 235858	IGOR SOROKIN	{"email": "igor.sorokin.27101973@postgrespro.ru", "phone": "+70379957059"}
0005432300183	26493A	9352 406586	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya1988@postgrespro.ru", "phone": "+70348039931"}
0005432300184	26493A	8353 130922	NATALYA ZAKHAROVA	{"email": "natalya-zakharova.1961@postgrespro.ru", "phone": "+70861901737"}
0005432300185	3AEAA4	5267 733396	VIKTOR VOLKOV	{"phone": "+70798547638"}
0005432300186	3AEAA4	1983 889577	KONSTANTIN SMIRNOV	{"email": "smirnov-k25051972@postgrespro.ru", "phone": "+70530715752"}
0005432300187	E26A04	3035 645795	VASILIY EGOROV	{"phone": "+70920819699"}
0005432300188	E26A04	8311 508502	OLGA GERASIMOVA	{"email": "olga-gerasimova_25031978@postgrespro.ru", "phone": "+70435038418"}
0005432300189	9B7C3A	4578 339178	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev.1956@postgrespro.ru", "phone": "+70545008625"}
0005432300190	9B7C3A	3684 352083	ANNA VASILEVA	{"phone": "+70529679583"}
0005432300191	9B7C3A	9067 301316	SERGEY NOVIKOV	{"email": "s.novikov.12111969@postgrespro.ru", "phone": "+70334247508"}
0005432300192	EFE9BB	5481 846148	IGOR SIDOROV	{"phone": "+70625594779"}
0005432300193	99995B	7919 403691	NATALYA KUZMINA	{"email": "natalya.kuzmina-1980@postgrespro.ru", "phone": "+70538518549"}
0005432300194	AC1FDF	9932 889264	VITALIY POPOV	{"email": "vitaliy-popov-051981@postgrespro.ru", "phone": "+70064815937"}
0005432300195	AC1FDF	1020 239239	VIKTOR GAVRILOV	{"email": "vgavrilov.1969@postgrespro.ru", "phone": "+70440422107"}
0005432300196	85B2D7	9784 059768	MARGARITA ANTONOVA	{"phone": "+70061721187"}
0005432300197	85B2D7	0917 343256	ALEKSANDR ROMANOV	{"email": "romanova.1966@postgrespro.ru", "phone": "+70096652515"}
0005432300198	BBAAA0	9896 268687	IGOR KUZNECOV	{"email": "i.kuznecov11101959@postgrespro.ru", "phone": "+70098223319"}
0005432300199	BBAAA0	5237 122906	ANNA GUSEVA	{"email": "gusevaa_111969@postgrespro.ru", "phone": "+70676212189"}
0005432300200	8BB3F9	6205 552438	EVGENIY SERGEEV	{"email": "sergeev-evgeniy081972@postgrespro.ru", "phone": "+70223442979"}
0005432300201	5E71A8	6138 405063	IGOR SOKOLOV	{"phone": "+70438477574"}
0005432300202	5E71A8	6073 119423	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov-08111981@postgrespro.ru", "phone": "+70546300810"}
0005432300203	7E51E7	4087 616114	ALEKSANDRA IVANOVA	{"email": "aleksandra-ivanova_1968@postgrespro.ru", "phone": "+70767610429"}
0005432300204	7E51E7	7566 545635	VALENTINA FEDOROVA	{"email": "fedorovavalentina_1959@postgrespro.ru", "phone": "+70693357261"}
0005432300205	DA531A	9620 365264	RUSLAN GERASIMOV	{"phone": "+70958841901"}
0005432300206	507F4C	3901 517530	IRINA GERASIMOVA	{"email": "gerasimova-i_17031963@postgrespro.ru", "phone": "+70453234549"}
0005432300207	507F4C	6236 886965	VIKTOR SOROKIN	{"email": "viktor.sorokin.15041951@postgrespro.ru", "phone": "+70685008981"}
0005432300208	9F1210	0478 220275	VYACHESLAV ZAYCEV	{"email": "zaycev-vyacheslav081977@postgrespro.ru", "phone": "+70166931604"}
0005432300209	9F1210	7436 250571	ANNA SOLOVEVA	{"email": "annasoloveva.15031970@postgrespro.ru", "phone": "+70622261349"}
0005432300210	C103CE	0217 420550	ALEKSANDR ILIN	{"email": "aleksandr_ilin-12031967@postgrespro.ru", "phone": "+70371616352"}
0005432300211	933132	7985 402194	YULIYA CHERNOVA	{"email": "y_chernova1970@postgrespro.ru", "phone": "+70650185487"}
0005432300212	82D049	1768 002896	DMITRIY MARTYNOV	{"email": "martynovd1958@postgrespro.ru", "phone": "+70980092654"}
0005432300213	82D049	2312 395149	ANTONINA LEBEDEVA	{"phone": "+70598771668"}
0005432300214	E358B8	2025 162413	EVGENIY MATVEEV	{"phone": "+70503220069"}
0005432300215	64E5D9	3094 323038	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr091977@postgrespro.ru", "phone": "+70508837223"}
0005432300216	653DD4	0770 117260	VIKTORIYA MELNIKOVA	{"phone": "+70793870673"}
0005432300217	215173	4412 155580	VALERIY SOLOVEV	{"email": "solovevvaleriy.1971@postgrespro.ru", "phone": "+70205295364"}
0005432300218	2F296F	8750 550661	ALEKSEY SAVELEV	{"phone": "+70286171752"}
0005432300219	F77208	5389 607860	ANNA DMITRIEVA	{"email": "dmitrievaanna.31071964@postgrespro.ru", "phone": "+70807587735"}
0005432300220	F77208	0140 120052	ANATOLIY GRIGOREV	{"phone": "+70606103498"}
0005432300221	034426	2999 979398	FEDOR KUZNECOV	{"phone": "+70765219854"}
0005432300222	61DEB0	9085 163231	TATYANA MAKAROVA	{"email": "tatyana-makarova_1974@postgrespro.ru", "phone": "+70196132562"}
0005432300223	B0E802	4072 867527	ARSENIY ILIN	{"phone": "+70919864021"}
0005432300224	F1D19D	2326 901906	ALEKSANDR KUZNECOV	{"phone": "+70517706466"}
0005432300225	0F643E	0491 134893	VASILISA ALEKSANDROVA	{"email": "aleksandrovav-1969@postgrespro.ru", "phone": "+70039060221"}
0005432300226	7B2474	8978 365855	SERGEY ANDREEV	{"email": "sergeyandreev-031975@postgrespro.ru", "phone": "+70638019658"}
0005432300227	0420F0	1104 193517	ANDREY GERASIMOV	{"email": "gerasimov_andrey-031974@postgrespro.ru", "phone": "+70146131474"}
0005432300228	82D183	4036 073300	LYUBOV SOKOLOVA	{"email": "sokoloval.1968@postgrespro.ru", "phone": "+70179942459"}
0005432300229	BBE0A6	1696 456173	ELENA SIDOROVA	{"email": "esidorova-05111970@postgrespro.ru", "phone": "+70340481546"}
0005432300230	BBE0A6	3578 579036	ALEKSANDR MIRONOV	{"email": "mironov-a.1966@postgrespro.ru", "phone": "+70170770057"}
0005432300231	BBE0A6	9323 175573	NATALIYA MAKAROVA	{"phone": "+70005021068"}
0005432300232	A43F0A	4065 971884	ANATOLIY SOROKIN	{"phone": "+70609584807"}
0005432300233	A7FD68	0058 942520	DMITRIY MOISEEV	{"email": "dmitriymoiseev_091969@postgrespro.ru", "phone": "+70466859428"}
0005432300234	A7FD68	2421 530090	NIKOLAY MAKAROV	{"email": "nikolay-makarov.27071973@postgrespro.ru", "phone": "+70022742167"}
0005432300235	1C5763	4580 440950	LARISA YAKOVLEVA	{"phone": "+70742376289"}
0005432300236	2163E8	9751 873581	DARYA SERGEEVA	{"email": "darya-sergeeva_23061971@postgrespro.ru", "phone": "+70898212809"}
0005432300237	8E8819	6573 839776	EKATERINA ALEKSEEVA	{"email": "ekaterina-alekseeva-1973@postgrespro.ru", "phone": "+70786831861"}
0005432300238	BE6849	2411 038186	ALEKSANDR MIRONOV	{"email": "mironov-a.15031974@postgrespro.ru", "phone": "+70559516370"}
0005432300239	03842B	5594 542298	VLADIMIR VOLKOV	{"email": "vladimir.volkov_1973@postgrespro.ru", "phone": "+70624016639"}
0005432300240	F4385E	4071 150701	IVAN BELOV	{"phone": "+70909659017"}
0005432300241	836CED	9290 512844	DENIS FOMIN	{"phone": "+70791936549"}
0005432300242	20D7F3	3716 129535	ELENA LEBEDEVA	{"email": "lebedeva_elena.1974@postgrespro.ru", "phone": "+70051109736"}
0005432300243	20D7F3	9552 881455	ROMAN POPOV	{"email": "roman.popov-021969@postgrespro.ru", "phone": "+70029878630"}
0005432300244	8DC985	4159 843078	GALINA GERASIMOVA	{"email": "gerasimova.galina.111975@postgrespro.ru", "phone": "+70476734669"}
0005432300245	8DC985	7776 573643	VLADIMIR EGOROV	{"email": "egorov_v.12021981@postgrespro.ru", "phone": "+70618098080"}
0005432300246	826EE5	1275 789812	EKATERINA MEDVEDEVA	{"email": "medvedeva_ekaterina.1960@postgrespro.ru", "phone": "+70989030391"}
0005432300247	826EE5	7324 440683	ELENA KUZMINA	{"email": "kuzmina.elena081961@postgrespro.ru", "phone": "+70726085654"}
0005432300248	3C6D4E	5741 230852	NATALYA SMIRNOVA	{"email": "n_smirnova_061965@postgrespro.ru", "phone": "+70969123106"}
0005432300249	3C6D4E	2518 158669	VASILIY PAVLOV	{"email": "pavlov.v.1963@postgrespro.ru", "phone": "+70189957344"}
0005432300250	C529BE	4811 979575	IVAN SERGEEV	{"phone": "+70403837706"}
0005432300251	C529BE	3900 399537	LYUDMILA GERASIMOVA	{"email": "gerasimova_lyudmila_011968@postgrespro.ru", "phone": "+70820891261"}
0005432300252	A84768	5820 108661	LYUDMILA SEMENOVA	{"email": "semenova-l.111968@postgrespro.ru", "phone": "+70458137036"}
0005432300253	A84768	2015 564796	ANATOLIY ZHUKOV	{"email": "a.zhukov1985@postgrespro.ru", "phone": "+70172187414"}
0005432300254	1D2B8F	8113 538145	YULIYA IVANOVA	{"email": "ivanovay1984@postgrespro.ru", "phone": "+70958294753"}
0005432300255	9A9304	5542 118353	RAUZA IVANOVA	{"phone": "+70502042254"}
0005432300256	10C8D6	6382 082567	EVGENIY ABRAMOV	{"email": "abramovevgeniy1986@postgrespro.ru", "phone": "+70086866413"}
0005432300257	A793B8	6184 761111	ILYA EGOROV	{"phone": "+70470811777"}
0005432300258	10BAA1	6999 706676	ZINAIDA KONOVALOVA	{"email": "konovalova.zinaida15011978@postgrespro.ru", "phone": "+70044823453"}
0005432300259	10BAA1	5928 138615	SVETLANA KULIKOVA	{"email": "s-kulikova021979@postgrespro.ru", "phone": "+70332976411"}
0005432300260	076B01	7989 031153	ROMAN ORLOV	{"email": "roman.orlov_041979@postgrespro.ru", "phone": "+70008792023"}
0005432300261	076B01	2347 617355	ALEKSANDR KUZNECOV	{"phone": "+70023294849"}
0005432300262	076B01	0952 117364	LYUDMILA YUDINA	{"phone": "+70593504088"}
0005432300263	07D18D	8974 700073	TATYANA GRISHINA	{"email": "tatyana_grishina_1965@postgrespro.ru", "phone": "+70255769757"}
0005432300264	07D18D	0091 593115	LIYA FILIPPOVA	{"email": "lfilippova.13121978@postgrespro.ru", "phone": "+70542355840"}
0005432300265	D87A23	2510 481008	VITALIY NOVIKOV	{"email": "vnovikov-31011965@postgrespro.ru", "phone": "+70431254881"}
0005432300266	5FF105	4701 880891	GALINA ZHURAVLEVA	{"phone": "+70871552938"}
0005432300267	5FF105	4277 175071	OKSANA KOVALEVA	{"email": "kovaleva.oksana121971@postgrespro.ru", "phone": "+70313091805"}
0005432300268	5FF105	6051 231185	VIKTOR TARASOV	{"phone": "+70818593553"}
0005432300269	DE747D	2242 811347	IGOR IVANOV	{"phone": "+70376058746"}
0005432300270	9D135C	9135 354108	NATALYA GERASIMOVA	{"email": "gerasimova_natalya-091966@postgrespro.ru", "phone": "+70697604164"}
0005432300271	9D135C	8248 995661	ALEKSANDR SIDOROV	{"phone": "+70015868962"}
0005432300272	9D135C	3555 195980	VASILIY ROMANOV	{"phone": "+70894299742"}
0005432300273	FE89CD	8655 656010	MARIYA KOZLOVA	{"email": "kozlova_mariya-05051983@postgrespro.ru", "phone": "+70972363578"}
0005432300274	CD7F57	5870 366193	VITALIY KRASNOV	{"phone": "+70790081611"}
0005432300275	ADB852	2197 739245	NIKITA FEDOROV	{"email": "fedorov.nikita_08041959@postgrespro.ru", "phone": "+70943289794"}
0005432300276	30C01A	3786 393110	ZOYA LUKYANOVA	{"email": "zoyalukyanova_18081967@postgrespro.ru", "phone": "+70086773450"}
0005432300277	A50FAF	9323 969280	ANASTASIYA SOKOLOVA	{"phone": "+70743391179"}
0005432300278	4EA695	4770 029877	NIKITA NIKITIN	{"phone": "+70827310917"}
0005432300279	608D2A	4849 818931	ALEKSANDR SOROKIN	{"email": "asorokin_1985@postgrespro.ru", "phone": "+70983859158"}
0005432300280	F96496	7620 872396	MARIYA FOMINA	{"email": "m_fomina_30071968@postgrespro.ru", "phone": "+70188458904"}
0005432300281	F96496	8522 832371	VADIM MELNIKOV	{"phone": "+70341123440"}
0005432300282	657E92	2997 190508	MARIYA POPOVA	{"phone": "+70072745445"}
0005432300283	657E92	9532 555380	ANATOLIY GAVRILOV	{"phone": "+70777680828"}
0005432300284	073A97	4129 400661	ANNA GERASIMOVA	{"email": "gerasimova_a1980@postgrespro.ru", "phone": "+70548741331"}
0005432300285	9D46FC	3018 413329	DENIS KUZNECOV	{"phone": "+70688894693"}
0005432300286	33BE90	9155 752948	EKATERINA MOROZOVA	{"phone": "+70671914136"}
0005432300287	A6FE1A	6326 319833	DMITRIY MOROZOV	{"phone": "+70299731958"}
0005432300288	AA0ED2	4158 580783	TATYANA NAZAROVA	{"phone": "+70276563264"}
0005432300289	AA0ED2	8335 918206	VALENTINA MIKHAYLOVA	{"phone": "+70004303786"}
0005432300290	FF9E13	7364 819458	POLINA ANDREEVA	{"email": "andreevap_1980@postgrespro.ru", "phone": "+70184427557"}
0005432300291	691273	7129 937579	ALEKSANDR ROMANOV	{"email": "romanovaleksandr.19051966@postgrespro.ru", "phone": "+70676816453"}
0005432300292	4F6314	3271 492546	EVGENIY PETROV	{"email": "petrov_evgeniy-061972@postgrespro.ru", "phone": "+70757263901"}
0005432300293	7502A0	3473 861205	LEONID BORISOV	{"phone": "+70147708714"}
0005432300294	D18F2F	1453 499998	NIKOLAY OSIPOV	{"email": "n.osipov_101966@postgrespro.ru", "phone": "+70507150415"}
0005432300295	D18F2F	8937 401148	DENIS NIKOLAEV	{"phone": "+70639254511"}
0005432300296	5871C0	2655 436500	TATYANA ANDREEVA	{"email": "andreeva_tatyana081972@postgrespro.ru", "phone": "+70723763570"}
0005432300297	721053	5485 793779	LYUBOV KISELEVA	{"phone": "+70259269653"}
0005432300298	C5C957	9348 446294	EVGENIYA EGOROVA	{"phone": "+70389429543"}
0005432300299	0F3BFA	2954 363903	TATYANA SOKOLOVA	{"phone": "+70817242411"}
0005432300300	0FE771	2158 740848	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev18091980@postgrespro.ru", "phone": "+70554377156"}
0005432300301	0C32CD	0517 456291	VLADIMIR ORLOV	{"email": "v_orlov_1974@postgrespro.ru", "phone": "+70850677315"}
0005432300302	97B517	3647 524078	KONSTANTIN KUZNECOV	{"phone": "+70306975755"}
0005432300303	5FE8D8	0290 213723	KLARA FEDOROVA	{"phone": "+70528792788"}
0005432300304	1474F3	2737 848265	VLADISLAV ZAYCEV	{"phone": "+70609497759"}
0005432300305	100044	2055 801330	SERGEY SOROKIN	{"email": "ssorokin_17101980@postgrespro.ru", "phone": "+70431875143"}
0005432300306	DE7EB6	7443 174195	EVGENIY SMIRNOV	{"email": "smirnov_e-20101976@postgrespro.ru", "phone": "+70456557468"}
0005432300307	9033C0	6001 704851	VLADIMIR ANTONOV	{"phone": "+70491970209"}
0005432300308	987478	2256 427855	NATALYA ROMANOVA	{"email": "romanova-natalya081967@postgrespro.ru", "phone": "+70746045219"}
0005432300309	D96A89	1244 698685	VIKTOR FEDOROV	{"email": "viktor_fedorov.06061972@postgrespro.ru", "phone": "+70509248416"}
0005432300310	CB9A50	6395 063291	SVETLANA LEBEDEVA	{"phone": "+70009416736"}
0005432300311	CB3457	9332 765548	DENIS MAKSIMOV	{"phone": "+70022293761"}
0005432300312	EE0ADD	6629 028125	NIKOLAY IVANOV	{"phone": "+70195122118"}
0005432300313	CDCC46	7098 004158	IRINA ANDREEVA	{"email": "irina.andreeva-1983@postgrespro.ru", "phone": "+70366691147"}
0005432300314	E28D92	1240 703874	DARYA PAVLOVA	{"email": "dpavlova_1971@postgrespro.ru", "phone": "+70038156241"}
0005432300315	E28D92	3387 453526	SERGEY SMIRNOV	{"phone": "+70742185726"}
0005432300316	C4DD82	1256 142329	IRINA TROFIMOVA	{"email": "trofimovai.30061976@postgrespro.ru", "phone": "+70434923293"}
0005432300317	C4DD82	1419 572454	LILIYA NIKIFOROVA	{"phone": "+70151736683"}
0005432300318	3D0DAF	7323 661116	TATYANA MOROZOVA	{"email": "morozova_tatyana.1966@postgrespro.ru", "phone": "+70441237147"}
0005432300319	00CBE2	7667 297853	VALENTINA ANDREEVA	{"email": "andreeva-valentina-1970@postgrespro.ru", "phone": "+70248730919"}
0005432300320	00CBE2	9119 754803	RITA SCHERBAKOVA	{"email": "ritascherbakova06121962@postgrespro.ru", "phone": "+70597462163"}
0005432300321	DB8ECC	9418 541852	NIKOLAY STEPANOV	{"email": "stepanov.nikolay_1962@postgrespro.ru", "phone": "+70544458958"}
0005432300322	DB8ECC	4482 162444	PETR MOROZOV	{"email": "morozovp-101971@postgrespro.ru", "phone": "+70257464548"}
0005432300323	A0FFC5	8807 842120	TATYANA KRASNOVA	{"phone": "+70905384689"}
0005432300324	2C8410	1612 040877	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr.081970@postgrespro.ru", "phone": "+70339830724"}
0005432300325	49195A	0919 453631	TATYANA ANISIMOVA	{"phone": "+70012090650"}
0005432300326	49195A	7895 836774	ALEKSEY MELNIKOV	{"phone": "+70184999303"}
0005432300327	5B49C1	7056 095992	TATYANA LEBEDEVA	{"phone": "+70708668110"}
0005432300328	E6FA53	3578 257083	YULIYA NAUMOVA	{"email": "naumova_yuliya_1979@postgrespro.ru", "phone": "+70164050827"}
0005432300329	E6FA53	6171 048036	NADEZHDA MAKSIMOVA	{"email": "maksimovan-1968@postgrespro.ru", "phone": "+70582450805"}
0005432300330	91D1EB	4539 546733	ANASTASIYA YUDINA	{"phone": "+70185750882"}
0005432300331	91D1EB	0373 416047	VIKTOR DENISOV	{"email": "denisov.viktor.07101987@postgrespro.ru", "phone": "+70311633563"}
0005432300332	01AFE3	1315 677760	VADIM MELNIKOV	{"email": "vadimmelnikov-021979@postgrespro.ru", "phone": "+70634776179"}
0005432300333	F46E92	7484 226537	OLGA ABRAMOVA	{"phone": "+70618972219"}
0005432300334	5A81F1	2728 871127	NATALYA LUKYANOVA	{"phone": "+70405853728"}
0005432300335	5A81F1	8172 180816	DMITRIY FOMIN	{"email": "fomin-dmitriy_021968@postgrespro.ru", "phone": "+70761007340"}
0005432300336	5A81F1	1414 213686	EKATERINA MASLOVA	{"email": "maslova-e-111981@postgrespro.ru", "phone": "+70742368933"}
0005432300337	C84DD9	6862 441301	NIKOLAY SOROKIN	{"email": "n_sorokin-121964@postgrespro.ru", "phone": "+70044898960"}
0005432300338	C84DD9	0824 350102	LYUBOV VASILEVA	{"email": "vasilevalyubov_051978@postgrespro.ru", "phone": "+70325042574"}
0005432300339	9C7694	8372 730627	ANDREY TIKHONOV	{"email": "tikhonov_a.02111973@postgrespro.ru", "phone": "+70046418583"}
0005432300340	9C7694	5639 248602	ALEKSEY MAKAROV	{"phone": "+70285204964"}
0005432300341	5F0009	6331 753753	IVAN MIKHAYLOV	{"email": "ivanmikhaylov-20041980@postgrespro.ru", "phone": "+70117710916"}
0005432300342	F8CA2C	8736 847083	KLAVDIYA BELYAEVA	{"phone": "+70913558763"}
0005432300343	F1F390	4299 989555	VYACHESLAV DAVYDOV	{"phone": "+70470523082"}
0005432300344	F1F390	6921 555090	IRINA PAVLOVA	{"email": "pavlovai_021956@postgrespro.ru", "phone": "+70850155725"}
0005432300345	F16028	6546 997813	LYUDMILA NAZAROVA	{"email": "lyudmila-nazarova.051972@postgrespro.ru", "phone": "+70382835635"}
0005432300346	F16028	1508 109918	MAKSIM VLASOV	{"email": "vlasov-maksim_101981@postgrespro.ru", "phone": "+70412178499"}
0005432300347	AA22E4	6335 190158	OLGA SAVELEVA	{"phone": "+70532228159"}
0005432300348	70BF2F	1732 715959	SERGEY KUZMIN	{"phone": "+70159746912"}
0005432300349	4753AE	8171 917618	MIKHAIL VOROBEV	{"phone": "+70320144207"}
0005432300350	4753AE	5085 938838	ANTON GORBUNOV	{"phone": "+70307019949"}
0005432300351	86DAAC	9933 980177	ANASTASIYA TITOVA	{"phone": "+70805747468"}
0005432300352	4685E6	7624 485286	ELENA SMIRNOVA	{"email": "e.smirnova_18121983@postgrespro.ru", "phone": "+70662131779"}
0005432300353	492BE3	5272 289456	ANASTASIYA ZOTOVA	{"phone": "+70275168778"}
0005432300354	492BE3	4985 340662	YULIYA ALEKSEEVA	{"phone": "+70598171365"}
0005432300355	2964C2	8825 415280	SERGEY MARTYNOV	{"email": "sergey-martynov01011971@postgrespro.ru", "phone": "+70604249333"}
0005432300356	3E8042	0100 467264	VYACHESLAV ANDREEV	{"phone": "+70164047412"}
0005432300357	3E8042	5036 070401	EGOR OSIPOV	{"email": "egor.osipov-1985@postgrespro.ru", "phone": "+70098335280"}
0005432300358	998AB3	0615 180259	RIMMA NOVIKOVA	{"phone": "+70348393439"}
0005432300359	8A0DCC	8707 958821	VLADIMIR PAVLOV	{"phone": "+70344220225"}
0005432300360	8A0DCC	8091 154385	NATALYA KOVALEVA	{"email": "n_kovaleva1973@postgrespro.ru", "phone": "+70052938019"}
0005432300361	05D5B4	7873 140544	OLGA MAKSIMOVA	{"phone": "+70596259015"}
0005432300362	905A62	5022 767869	YURIY NAZAROV	{"email": "yuriynazarov_20071973@postgrespro.ru", "phone": "+70397402226"}
0005432300363	2C48FB	5314 587862	NIKOLAY ABRAMOV	{"phone": "+70134318266"}
0005432300364	F9AC60	5567 569989	NATALYA KOLESNIKOVA	{"phone": "+70822505462"}
0005432300365	F9AC60	3984 169749	POLINA MAKAROVA	{"phone": "+70821215744"}
0005432300366	145E37	9443 551376	YURIY IVANOV	{"email": "ivanov_yuriy.11031978@postgrespro.ru", "phone": "+70367554136"}
0005432300367	145E37	5528 067938	ALEKSEY MELNIKOV	{"email": "melnikov.a1963@postgrespro.ru", "phone": "+70680175534"}
0005432300368	E2BD19	1419 413357	SVETLANA VOROBEVA	{"phone": "+70460825161"}
0005432300369	E2BD19	0859 118642	VLADIMIR FOMIN	{"email": "fominvladimir021986@postgrespro.ru", "phone": "+70188982614"}
0005432300370	7FC08A	2991 325318	RINAT DMITRIEV	{"email": "dmitriev.r-20051979@postgrespro.ru", "phone": "+70829879479"}
0005432300371	DA0D02	2801 602292	ELENA VOROBEVA	{"phone": "+70511121215"}
0005432300372	45D91F	8158 666459	EKATERINA ALEKSANDROVA	{"phone": "+70902522841"}
0005432300373	285F6D	6114 781245	ANNA NIKOLAEVA	{"phone": "+70991996307"}
0005432300374	D3DBA1	2658 465565	KIRA STEPANOVA	{"phone": "+70233091231"}
0005432300375	0EE149	0686 222382	NIKOLAY OSIPOV	{"email": "osipov_nikolay-1983@postgrespro.ru", "phone": "+70914999079"}
0005432300376	673F49	9554 620162	NINA SEMENOVA	{"email": "n-semenova_051965@postgrespro.ru", "phone": "+70491025950"}
0005432300377	B17449	4906 290155	PAVEL IVANOV	{"email": "ivanov.pavel-01041969@postgrespro.ru", "phone": "+70221945730"}
0005432300378	42164F	4207 980943	VALENTINA GAVRILOVA	{"email": "gavrilova-v.07111978@postgrespro.ru", "phone": "+70022514413"}
0005432300379	42164F	0903 272800	SERGEY PETROV	{"phone": "+70780878288"}
0005432300380	B7EECF	7748 674169	NADEZHDA PETROVA	{"email": "n_petrova14071973@postgrespro.ru", "phone": "+70458988601"}
0005432300381	B7EECF	6729 556900	EKATERINA MASLOVA	{"phone": "+70765495302"}
0005432300382	85FC9C	0900 110320	NIKOLAY FEDOROV	{"email": "nikolayfedorov1990@postgrespro.ru", "phone": "+70881663877"}
0005432300383	03BD68	3447 509078	GALINA ZAKHAROVA	{"phone": "+70459022399"}
0005432300384	03BD68	4099 175534	LIDIYA SMIRNOVA	{"phone": "+70568138485"}
0005432300385	92434A	0453 614406	ROMAN ABRAMOV	{"phone": "+70376961510"}
0005432300386	92434A	2589 747003	NATALYA SMIRNOVA	{"email": "smirnova_natalya.1970@postgrespro.ru", "phone": "+70071117573"}
0005432300387	92434A	3649 244386	SERGEY MATVEEV	{"email": "sergeymatveev_1961@postgrespro.ru", "phone": "+70976314063"}
0005432300388	F6A6CB	1777 728956	DENIS YAKOVLEV	{"email": "yakovlevdenis-051975@postgrespro.ru", "phone": "+70725140716"}
0005432300389	F6A6CB	2553 272441	GALINA FEDOROVA	{"phone": "+70359057516"}
0005432300390	CEC582	4507 385463	VLADIMIR ANDREEV	{"phone": "+70872118355"}
0005432300391	C42CB7	2364 618732	VITALIY SOKOLOV	{"email": "sokolov_vitaliy_1969@postgrespro.ru", "phone": "+70223998914"}
0005432300392	9729D6	1974 239617	ALEKSANDR ALEKSANDROV	{"phone": "+70623541290"}
0005432300393	9729D6	7804 324705	VALENTINA SIDOROVA	{"email": "sidorova_v.1971@postgrespro.ru", "phone": "+70832755499"}
0005432300394	C9D2A0	2070 069447	SVETLANA MEDVEDEVA	{"phone": "+70982266829"}
0005432300395	4C836E	5682 697088	SVETLANA MARTYNOVA	{"email": "smartynova_1973@postgrespro.ru", "phone": "+70200434157"}
0005432300396	B94132	2791 324841	IRINA STEPANOVA	{"phone": "+70147804400"}
0005432300397	897EBB	6497 661238	VLADIMIR TARASOV	{"email": "tarasovvladimir-121957@postgrespro.ru", "phone": "+70573299135"}
0005432300398	E088DD	5167 912728	ANNA KISELEVA	{"phone": "+70131889671"}
0005432300399	D6AF6E	7009 128551	ALENA KOVALEVA	{"phone": "+70795378516"}
0005432300400	F7445C	0742 973942	ANTONINA KARPOVA	{"phone": "+70437829992"}
0005432300401	8A817C	4846 592843	ILYA ROMANOV	{"email": "romanov-ilya-23091972@postgrespro.ru", "phone": "+70127168793"}
0005432300402	C7B79A	3088 929267	MIKHAIL BARANOV	{"phone": "+70704686057"}
0005432300403	708298	4792 948118	TATYANA IVANOVA	{"email": "tatyanaivanova.13061962@postgrespro.ru", "phone": "+70357130151"}
0005432300404	FA6313	5094 176112	NIKOLAY GERASIMOV	{"phone": "+70241439571"}
0005432300405	C43D0C	5855 460162	ANDREY KOROLEV	{"email": "andreykorolev-1959@postgrespro.ru", "phone": "+70223652542"}
0005432300406	C43D0C	9399 868695	MARINA EGOROVA	{"phone": "+70325672913"}
0005432300407	D7AD5A	4713 373753	IRINA VLASOVA	{"email": "vlasova.irina_1979@postgrespro.ru", "phone": "+70432512536"}
0005432300408	8F4A51	2905 976901	DMITRIY MAKAROV	{"phone": "+70649674417"}
0005432300409	89C13A	2877 494900	TIMUR ISAEV	{"email": "isaev-timur1979@postgrespro.ru", "phone": "+70101953155"}
0005432300410	D3AAAC	7045 853452	DANIIL POPOV	{"phone": "+70976498872"}
0005432300411	D3AAAC	7763 402882	OLGA OSIPOVA	{"phone": "+70539693312"}
0005432300412	C25C16	8663 247617	EVDOKIYA NIKOLAEVA	{"phone": "+70931612495"}
0005432300413	0721CD	9865 102347	NINA KUDRYASHOVA	{"email": "kudryashovan_081983@postgrespro.ru", "phone": "+70831603172"}
0005432300414	243B27	9165 798577	LYUDMILA NIKITINA	{"email": "lnikitina.1976@postgrespro.ru", "phone": "+70797917528"}
0005432300415	24940A	7657 264456	TAMARA SOKOLOVA	{"email": "sokolova_tamara-121961@postgrespro.ru", "phone": "+70271079573"}
0005432300416	03D970	9814 030925	SVETLANA MARTYNOVA	{"email": "martynova-s.1968@postgrespro.ru", "phone": "+70115037412"}
0005432300417	03D970	3365 882625	VLADISLAV GRIGOREV	{"email": "grigorev-vladislav.081983@postgrespro.ru", "phone": "+70114497092"}
0005432300418	FD7F25	7433 230406	MARIYA SOLOVEVA	{"phone": "+70247119968"}
0005432300419	FD7F25	2853 104161	SERGEY ZHUKOV	{"phone": "+70873790724"}
0005432300420	D55757	0860 193177	NINA IVANOVA	{"phone": "+70759103878"}
0005432300421	998249	7317 126436	SERGEY SOROKIN	{"email": "sorokin_s11061975@postgrespro.ru", "phone": "+70385972519"}
0005432300422	998249	1444 753703	VADIM MOROZOV	{"email": "morozov_vadim-1969@postgrespro.ru", "phone": "+70378633865"}
0005432300423	80C1B0	2836 183684	ALEKSANDR KUZMIN	{"email": "a_kuzmin_1971@postgrespro.ru", "phone": "+70453519487"}
0005432300424	80C1B0	4905 155493	EKATERINA NOVIKOVA	{"phone": "+70018654632"}
0005432300425	13D080	3381 772973	SNEZHANA TARASOVA	{"phone": "+70823231346"}
0005432300426	13D080	8906 100120	LILIYA ZHURAVLEVA	{"email": "zhuravleva-liliya.011979@postgrespro.ru", "phone": "+70392327681"}
0005432300427	D5E2A6	3366 367231	SERGEY KRASNOV	{"email": "krasnov_s091979@postgrespro.ru", "phone": "+70869429252"}
0005432300428	D5E2A6	9495 163386	ELIZAVETA KUZMINA	{"email": "elizaveta_kuzmina-1975@postgrespro.ru", "phone": "+70275641307"}
0005432300429	C69845	0887 724030	RIMMA NAUMOVA	{"phone": "+70389256964"}
0005432300430	98FE5C	9301 766254	ANATOLIY FILIPPOV	{"phone": "+70721555179"}
0005432300431	FBA958	7552 627373	ANDREY GERASIMOV	{"phone": "+70553899754"}
0005432300432	FBA958	1073 079151	ANATOLIY FOMIN	{"email": "anatoliy-fomin.25121973@postgrespro.ru", "phone": "+70997890757"}
0005432300433	404A6D	9320 699783	ZINAIDA MAKAROVA	{"phone": "+70808093833"}
0005432300434	13A635	0003 157993	ALEKSANDR PETROV	{"phone": "+70312146456"}
0005432300435	13A635	1607 815532	VERA KARPOVA	{"phone": "+70916897833"}
0005432300436	5D8798	0195 040341	TATYANA MOISEEVA	{"phone": "+70107756998"}
0005432300437	CEBA81	2792 614169	GENNADIY SCHERBAKOV	{"email": "gennadiy.scherbakov.13111973@postgrespro.ru", "phone": "+70615348462"}
0005432300438	CEBA81	0829 079098	VITALIY TIMOFEEV	{"phone": "+70867158148"}
0005432300439	946341	4025 665291	LIDIYA KARPOVA	{"phone": "+70937380972"}
0005432300440	81D429	6894 028439	VALENTINA MAKAROVA	{"phone": "+70186419432"}
0005432300441	81D429	5738 681057	VENERA MEDVEDEVA	{"email": "medvedeva-v1971@postgrespro.ru", "phone": "+70497257163"}
0005432300442	BBD938	2656 166663	MATVEY ALEKSANDROV	{"phone": "+70529565349"}
0005432300443	BBD938	4701 386526	YULIYA ISAEVA	{"email": "yuliya_isaeva_031977@postgrespro.ru", "phone": "+70977180342"}
0005432300444	BBD938	4198 559717	NATALYA ZAKHAROVA	{"phone": "+70785740147"}
0005432300445	0716B3	3607 661098	VLADIMIR GAVRILOV	{"email": "gavrilov.vladimir1966@postgrespro.ru", "phone": "+70230579515"}
0005432302265	E17E2D	1365 799203	MIKHAIL FEDOTOV	{"email": "mikhail.fedotov_1980@postgrespro.ru", "phone": "+70503756000"}
0005432302266	E17E2D	0503 546166	SERGEY GAVRILOV	{"email": "gavrilov.s.16121967@postgrespro.ru", "phone": "+70188264102"}
0005432302267	C2F9AB	1568 682269	VIKTORIYA KOROLEVA	{"email": "koroleva-viktoriya-1974@postgrespro.ru", "phone": "+70863414925"}
0005432302268	C2F9AB	5439 005252	LYUDMILA IVANOVA	{"phone": "+70076120503"}
0005432302269	C0450D	1359 854563	MARIYA MEDVEDEVA	{"email": "medvedeva-m.1975@postgrespro.ru", "phone": "+70367561519"}
0005432302270	3970E3	8065 811002	OLESYA IVANOVA	{"phone": "+70564237243"}
0005432302271	3970E3	5177 587762	KHASAN KUZNECOV	{"email": "kuznecov.khasan-011978@postgrespro.ru", "phone": "+70303342764"}
0005432302272	B32F5A	7156 660084	NIKOLAY NIKITIN	{"phone": "+70668725202"}
0005432302273	DD7FB4	6190 021795	LILIYA ISAEVA	{"phone": "+70137222942"}
0005432302274	DD7FB4	6420 311691	VERONIKA POPOVA	{"email": "v-popova_1973@postgrespro.ru", "phone": "+70753519276"}
0005432302275	8C6855	5183 817627	NADEZHDA RYABOVA	{"email": "ryabovanadezhda.041976@postgrespro.ru", "phone": "+70575843923"}
0005432302276	4E5938	3986 862227	ANTONINA YUDINA	{"phone": "+70229753458"}
0005432302277	440528	2842 891804	ALINA ZAKHAROVA	{"email": "zakharova.a_1965@postgrespro.ru", "phone": "+70842677042"}
0005432302278	B68F13	0986 358626	MARIYA VASILEVA	{"phone": "+70386230003"}
0005432302279	6C0304	2405 862692	IRINA KUZNECOVA	{"phone": "+70979194045"}
0005432302280	7AC192	0799 594778	SVETLANA OSIPOVA	{"email": "svetlana_osipova_1977@postgrespro.ru", "phone": "+70016964052"}
0005432302281	CF0FD1	4249 346047	DENIS KRASNOV	{"phone": "+70217683467"}
0005432302282	099E2B	4524 509885	GALINA NESTEROVA	{"email": "nesterova.galina1970@postgrespro.ru", "phone": "+70097309622"}
0005432302283	021226	2408 700866	GENNADIY KUZNECOV	{"email": "g-kuznecov-04061966@postgrespro.ru", "phone": "+70168280446"}
0005432302284	ED3B45	7077 211172	DMITRIY IVANOV	{"phone": "+70757031316"}
0005432302285	BA7D12	8012 460139	ARTEM SHEVCHENKO	{"email": "shevchenko-a-1969@postgrespro.ru", "phone": "+70862173883"}
0005432302286	BA7D12	8597 086358	RAISA TARASOVA	{"email": "tarasova_r.1975@postgrespro.ru", "phone": "+70504607891"}
0005432302287	B51EA1	0484 568252	OLEG MIKHAYLOV	{"email": "oleg.mikhaylov-30121976@postgrespro.ru", "phone": "+70121338086"}
0005432302288	D38B94	8445 906013	ELENA ANDREEVA	{"email": "andreeva_e1977@postgrespro.ru", "phone": "+70837526172"}
0005432302289	B9D341	4042 020608	SVETLANA ZHUKOVA	{"email": "zhukova_svetlana-1967@postgrespro.ru", "phone": "+70978410412"}
0005432302290	1D3300	1703 556534	SERGEY ANTONOV	{"phone": "+70716476014"}
0005432302291	723D7D	9298 273015	ELENA IVANOVA	{"phone": "+70886961265"}
0005432302292	723D7D	9630 906261	MARIYA ZHUKOVA	{"email": "m-zhukova1958@postgrespro.ru", "phone": "+70658838621"}
0005432302293	0AE753	7854 126480	MAKSIM PETROV	{"phone": "+70135764526"}
0005432302294	81A361	8610 249593	ALEKSANDR KONOVALOV	{"phone": "+70981418810"}
0005432302295	81A361	4985 190272	VLADIMIR PETROV	{"email": "petrov-v-031968@postgrespro.ru", "phone": "+70043106241"}
0005432302296	DE35C1	0363 110786	DANILA IVANOV	{"phone": "+70375665551"}
0005432302297	DE35C1	5568 109595	PETR TIKHONOV	{"phone": "+70408988070"}
0005432302298	825B75	3280 655198	ALEKSANDR TIKHONOV	{"email": "tikhonov.a-041970@postgrespro.ru", "phone": "+70247645605"}
0005432302299	825B75	1417 663646	MAKSIM MOISEEV	{"phone": "+70066462382"}
0005432302300	51F4D0	3291 337923	DAMIR MATVEEV	{"email": "matveev.damir_1965@postgrespro.ru", "phone": "+70364783667"}
0005432302301	CEEAC2	1605 842102	TATYANA KARPOVA	{"email": "karpova_tatyana.1975@postgrespro.ru", "phone": "+70233146691"}
0005432302302	CEEAC2	3566 138810	SERGEY PETROV	{"email": "petrovs-1972@postgrespro.ru", "phone": "+70801764945"}
0005432302303	1BD9FD	9188 859189	ANNA SOKOLOVA	{"phone": "+70697742843"}
0005432302304	1BD9FD	2517 727116	ALEKSANDR ANTONOV	{"email": "aleksandr_antonov_1972@postgrespro.ru", "phone": "+70090156714"}
0005432302305	1E2A50	8085 777472	GALINA BARANOVA	{"email": "baranova-galina1972@postgrespro.ru", "phone": "+70309628829"}
0005432302306	CD5286	8355 070212	ANASTASIYA NIKOLAEVA	{"phone": "+70815066819"}
0005432302307	00B49E	9428 934360	NIKOLAY KUZMIN	{"phone": "+70441900778"}
0005432302308	7BF8CD	4909 550505	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov-051975@postgrespro.ru", "phone": "+70273662568"}
0005432302309	C0D202	3174 367935	ALEKSANDRA POLYAKOVA	{"email": "a.polyakova26061975@postgrespro.ru", "phone": "+70599365405"}
0005432302310	C0D202	2065 109820	NINEL SERGEEVA	{"email": "sergeeva.n_101962@postgrespro.ru", "phone": "+70414913908"}
0005432302311	522FE9	8348 977975	SVETLANA DMITRIEVA	{"email": "svetlana-dmitrieva.29011970@postgrespro.ru", "phone": "+70370276047"}
0005432302312	522FE9	8748 625929	RUSLAN TARASOV	{"phone": "+70415290303"}
0005432302313	76E068	6504 962825	VALENTINA VOLKOVA	{"email": "valentina_volkova.1970@postgrespro.ru", "phone": "+70523316383"}
0005432302314	76E068	2695 764821	YURIY MEDVEDEV	{"email": "medvedevyuriy_1975@postgrespro.ru", "phone": "+70382323561"}
0005432302315	7294DD	2935 944164	OLEG ILIN	{"phone": "+70909839511"}
0005432302316	2066EF	1958 653210	TATYANA POTAPOVA	{"phone": "+70650265901"}
0005432302317	2A711D	4390 657367	DMITRIY EGOROV	{"phone": "+70374163060"}
0005432302318	1253FE	5274 280506	SERGEY ALEKSEEV	{"email": "salekseev11071981@postgrespro.ru", "phone": "+70987442076"}
0005432302319	904A0D	0249 098101	ARSEN IVANOV	{"phone": "+70373611918"}
0005432302320	369275	3765 888648	DARYA BELOVA	{"email": "belova_darya_1969@postgrespro.ru", "phone": "+70349052858"}
0005432302321	369275	1734 702232	RIMMA SEMENOVA	{"email": "semenova.r.26041969@postgrespro.ru", "phone": "+70340547731"}
0005432302322	7C2257	1183 122990	SVETLANA KARPOVA	{"phone": "+70230788053"}
0005432302323	FF2C7E	3055 847807	MARIYA KONOVALOVA	{"phone": "+70513065924"}
0005432302324	FF2C7E	5722 409682	TAMARA MAKAROVA	{"email": "t-makarova-1962@postgrespro.ru", "phone": "+70505540232"}
0005432302325	32E169	6236 566575	ANNA AFANASEVA	{"phone": "+70550705775"}
0005432302326	20DF60	2588 251360	LILIYA SMIRNOVA	{"email": "smirnova_liliya.1977@postgrespro.ru", "phone": "+70690140131"}
0005432302327	47762B	4417 767183	ANASTASIYA MAKAROVA	{"phone": "+70697418298"}
0005432302328	47762B	1516 454401	IRINA ERMAKOVA	{"email": "ermakova-i_1974@postgrespro.ru", "phone": "+70700866510"}
0005432302329	A3A8A8	6100 036730	OLEG SAVELEV	{"phone": "+70154933989"}
0005432302330	C0E13D	5814 747896	ALEKSEY SOKOLOV	{"email": "sokolova_28021981@postgrespro.ru", "phone": "+70370831704"}
0005432302331	0EFF02	6662 625823	NIKOLAY SMIRNOV	{"email": "smirnovnikolay-1973@postgrespro.ru", "phone": "+70992510363"}
0005432302332	62D273	6248 362219	LARISA DENISOVA	{"email": "denisova_larisa_08081961@postgrespro.ru", "phone": "+70785988154"}
0005432302333	F278D5	7588 007124	IGOR SOROKIN	{"email": "sorokin-igor_20011975@postgrespro.ru", "phone": "+70343140911"}
0005432302334	0530AE	5108 332904	OLGA PETROVA	{"email": "o-petrova10071972@postgrespro.ru", "phone": "+70706088574"}
0005432302335	9EEED0	6870 922213	PAVEL SMIRNOV	{"email": "p.smirnov-08101957@postgrespro.ru", "phone": "+70980478168"}
0005432302336	7A8EF0	1056 582993	ANASTASIYA VOLKOVA	{"email": "volkova.a051975@postgrespro.ru", "phone": "+70619212120"}
0005432302337	918AF4	8702 910011	MIKHAIL ZAKHAROV	{"phone": "+70224350117"}
0005432302338	244F79	4297 176133	EDUARD MIRONOV	{"phone": "+70175700825"}
0005432302339	255AEE	8790 101437	IRINA FILATOVA	{"email": "irinafilatova091977@postgrespro.ru", "phone": "+70891124989"}
0005432302340	255AEE	4380 608994	KONSTANTIN MIRONOV	{"email": "mironovkonstantin_1968@postgrespro.ru", "phone": "+70241400453"}
0005432302341	907B24	6472 580163	NIKOLAY ALEKSEEV	{"phone": "+70685549639"}
0005432302342	48A0EE	1122 789607	SERGEY SMIRNOV	{"email": "smirnov.sergey.14051969@postgrespro.ru", "phone": "+70189966087"}
0005432302343	48A0EE	2530 849878	ALEKSEY SERGEEV	{"email": "aleksey-sergeev-1975@postgrespro.ru", "phone": "+70292704497"}
0005432302344	7D6732	2754 640595	DANA DAVYDOVA	{"phone": "+70331145217"}
0005432302345	038D5E	2404 913046	ELIZAVETA YAKOVLEVA	{"phone": "+70347923539"}
0005432302346	038D5E	7623 774604	IVAN IVANOV	{"email": "iivanov.1967@postgrespro.ru", "phone": "+70756380827"}
0005432302347	44C6CF	3503 501237	MIKHAIL MATVEEV	{"phone": "+70987982237"}
0005432302348	AEC4A4	9821 696288	IRINA DANILOVA	{"email": "danilovai-031967@postgrespro.ru", "phone": "+70923194204"}
0005432302349	6B1215	2329 375548	ANNA RODIONOVA	{"email": "rodionova_anna041972@postgrespro.ru", "phone": "+70576858938"}
0005432302350	933BBB	1939 055496	GULNAZ ANTONOVA	{"email": "antonovagulnaz-1972@postgrespro.ru", "phone": "+70729939018"}
0005432302351	933BBB	1339 852664	ANNA TIKHONOVA	{"email": "annatikhonova.1981@postgrespro.ru", "phone": "+70069481319"}
0005432302352	B20FB0	1515 801803	VIKTORIYA KONDRATEVA	{"email": "viktoriyakondrateva_07051969@postgrespro.ru", "phone": "+70081052316"}
0005432302353	9D521C	9614 427764	ROMAN NAUMOV	{"email": "naumov.r09081965@postgrespro.ru", "phone": "+70292444084"}
0005432302354	49CF37	0371 747679	ALEKSANDR KUZNECOV	{"email": "kuznecov_a_101974@postgrespro.ru", "phone": "+70599813812"}
0005432302355	FF1888	0060 100154	YULIYA ANDREEVA	{"phone": "+70136886313"}
0005432302356	9B1864	7784 748418	MARINA MAKAROVA	{"email": "mmakarova1971@postgrespro.ru", "phone": "+70819068829"}
0005432302357	7E8002	9912 170921	MIKHAIL MIKHAYLOV	{"phone": "+70405646479"}
0005432302358	C1BD37	3445 482471	VLADIMIR GUSEV	{"phone": "+70388843765"}
0005432302359	6561EC	8329 878017	ILONA YUDINA	{"email": "i.yudina021967@postgrespro.ru", "phone": "+70627670100"}
0005432302360	98D0C2	3690 176881	ALEKSANDR SAVELEV	{"email": "a.savelev_051968@postgrespro.ru", "phone": "+70376677497"}
0005432302361	98D0C2	9966 227888	SVETLANA KARPOVA	{"phone": "+70393175511"}
0005432302362	61D6AB	6414 637190	ALEKSEY FEDOROV	{"phone": "+70967033844"}
0005432302363	AB7361	7536 171452	RAISA MARTYNOVA	{"email": "martynova-raisa-1974@postgrespro.ru", "phone": "+70828517224"}
0005432302364	AB7361	7810 802343	VYACHESLAV KOZLOV	{"email": "kozlov-vyacheslav_1960@postgrespro.ru", "phone": "+70946008691"}
0005432302365	AB7361	9307 358320	SOFIYA EFIMOVA	{"email": "efimova.sofiya1968@postgrespro.ru", "phone": "+70608843053"}
0005432302366	5F71A9	7087 344204	GALINA PETROVA	{"phone": "+70034085993"}
0005432302367	5F71A9	1188 808182	SERGEY SCHERBAKOV	{"phone": "+70723020676"}
0005432302368	EB17CE	0726 500526	IVAN VASILEV	{"email": "vasilevi_1972@postgrespro.ru", "phone": "+70357359332"}
0005432302369	B7B7EF	0164 729741	NADEZHDA KOVALEVA	{"phone": "+70672897606"}
0005432302370	B7B7EF	9160 762563	ANDREY SOKOLOV	{"email": "andreysokolov15081966@postgrespro.ru", "phone": "+70910811251"}
0005432302371	2EC1DD	5255 603249	SERGEY BARANOV	{"email": "baranovs-061974@postgrespro.ru", "phone": "+70471665533"}
0005432302372	2EC1DD	3084 569929	ALEKSANDRA KARPOVA	{"email": "a_karpova021967@postgrespro.ru", "phone": "+70651793394"}
0005432302373	2EC1DD	5436 421157	FANIYA KUZNECOVA	{"email": "faniya-kuznecova1968@postgrespro.ru", "phone": "+70585402785"}
0005432302374	53558D	4888 796686	FEDOR POPOV	{"email": "fedor.popov-01011967@postgrespro.ru", "phone": "+70853868625"}
0005432302375	57FE5B	6567 177110	SERGEY BONDARENKO	{"phone": "+70633893402"}
0005432302376	A5EE97	1316 625974	VIKTORIYA RYABOVA	{"phone": "+70708822773"}
0005432302377	F3B60D	0011 331823	NIKOLAY ZAKHAROV	{"phone": "+70104788485"}
0005432302378	1D731F	6768 090635	SERGEY PETROV	{"phone": "+70881759283"}
0005432302379	1D731F	7940 065770	VALENTINA ISAEVA	{"email": "isaevav-1968@postgrespro.ru", "phone": "+70955029881"}
0005432302380	BC6B92	5398 090976	VIKTOR MELNIKOV	{"email": "viktor.melnikov-031970@postgrespro.ru", "phone": "+70211593369"}
0005432302381	2D2944	9142 902985	VALENTINA KONDRATEVA	{"phone": "+70426586743"}
0005432302382	11FE8C	5581 885692	VADIM SERGEEV	{"email": "sergeevv-1966@postgrespro.ru", "phone": "+70462155105"}
0005432302383	11FE8C	8259 227677	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin111980@postgrespro.ru", "phone": "+70942521858"}
0005432302384	012614	3821 206614	EVGENIY SOKOLOV	{"email": "evgeniysokolov1979@postgrespro.ru", "phone": "+70010829323"}
0005432302385	012614	1890 155374	NIKOLAY IVANOV	{"email": "nikolayivanov1968@postgrespro.ru", "phone": "+70174820940"}
0005432302386	EA9162	9705 802138	ANDREY PETROV	{"phone": "+70415710600"}
0005432302387	4C9278	4971 119341	OLESYA DAVYDOVA	{"phone": "+70200721032"}
0005432302388	458D14	2441 631752	IRINA ILINA	{"phone": "+70544913871"}
0005432302389	458D14	2857 303178	KONSTANTIN CHERNOV	{"email": "kchernov.1978@postgrespro.ru", "phone": "+70521136825"}
0005432302390	0F4ABA	5333 608919	SERGEY PETROV	{"email": "spetrov_1972@postgrespro.ru", "phone": "+70160183307"}
0005432302391	53DEF5	4297 826291	ANNA GAVRILOVA	{"phone": "+70540651387"}
0005432302392	53DEF5	6324 545356	OLEG GERASIMOV	{"email": "oleg-gerasimov1961@postgrespro.ru", "phone": "+70674132674"}
0005432302393	4C02FD	1667 220284	TATYANA IVANOVA	{"email": "t_ivanova_1965@postgrespro.ru", "phone": "+70165733777"}
0005432302394	22AB8C	9849 700378	YURIY SERGEEV	{"phone": "+70061407406"}
0005432302395	22AB8C	3464 881276	NADEZHDA ZHUKOVA	{"phone": "+70712438945"}
0005432302396	A5C5B0	0257 096623	VIKTOR ABRAMOV	{"email": "abramov.viktor_1977@postgrespro.ru", "phone": "+70919896977"}
0005432302397	B889A2	4622 331431	SVETLANA RODIONOVA	{"phone": "+70939033006"}
0005432302398	B889A2	9685 630603	FEDOR KUZNECOV	{"phone": "+70824190251"}
0005432302399	B178BB	3474 399192	SERGEY MAKAROV	{"email": "makarov_sergey-111973@postgrespro.ru", "phone": "+70289582384"}
0005432302400	91245F	4079 885556	DMITRIY ILIN	{"email": "ilin_dmitriy-1977@postgrespro.ru", "phone": "+70962129150"}
0005432302401	AEBB69	5514 114992	ANTONINA TIMOFEEVA	{"email": "timofeevaa.061970@postgrespro.ru", "phone": "+70445662132"}
0005432302402	DD43AC	5555 623886	ANNA STEPANOVA	{"phone": "+70589253446"}
0005432302403	662F9A	3737 660215	VIKTOR SIDOROV	{"phone": "+70178438881"}
0005432302404	2C8F54	7022 677393	FEDOR AFANASEV	{"email": "f-afanasev-16101966@postgrespro.ru", "phone": "+70082791299"}
0005432302405	2C8F54	3304 565957	DANA NIKIFOROVA	{"phone": "+70064119620"}
0005432302406	216056	8178 724711	NATALYA MOROZOVA	{"phone": "+70504445212"}
0005432302407	216056	7104 456589	ZINAIDA MAKAROVA	{"email": "zinaidamakarova111969@postgrespro.ru", "phone": "+70079422208"}
0005432302408	5DE06E	5482 531471	SVETLANA ABRAMOVA	{"phone": "+70134654513"}
0005432302409	069E15	1879 463808	DANIIL SEMENOV	{"email": "semenovd_1970@postgrespro.ru", "phone": "+70252034473"}
0005432302410	B4DA06	5606 976479	LEONID KARPOV	{"phone": "+70588947268"}
0005432302411	A4763D	6757 079361	NADEZHDA MIKHAYLOVA	{"phone": "+70357312427"}
0005432302412	53EA10	3364 721133	GALINA SEMENOVA	{"phone": "+70416950227"}
0005432302413	53EA10	4073 009372	SOFYA TARASOVA	{"phone": "+70446739905"}
0005432302414	D5244B	5202 915294	ANASTASIYA MAKSIMOVA	{"email": "maksimova-a1972@postgrespro.ru", "phone": "+70070736831"}
0005432302415	BCD0CC	4109 021540	LIDIYA AFANASEVA	{"email": "lidiya-afanaseva_041970@postgrespro.ru", "phone": "+70506870319"}
0005432302416	BCD0CC	3880 475903	ALEKSANDR MELNIKOV	{"email": "melnikov-a1963@postgrespro.ru", "phone": "+70964917259"}
0005432302417	851097	3291 570245	IGOR KRASNOV	{"email": "krasnovigor.071976@postgrespro.ru", "phone": "+70437260213"}
0005432302418	8F90B9	1953 020183	ELENA BORISOVA	{"phone": "+70638972942"}
0005432302419	2E0167	8744 173255	EVGENIY ALEKSANDROV	{"email": "e.aleksandrov-011974@postgrespro.ru", "phone": "+70425383159"}
0005432302420	C6C736	2027 816998	ALEKSANDR MELNIKOV	{"phone": "+70659767969"}
0005432302421	628492	1892 909750	KSENIYA MIKHAYLOVA	{"email": "kmikhaylova-25111975@postgrespro.ru", "phone": "+70831635133"}
0005432302422	028907	4874 217019	LYUDMILA SIDOROVA	{"phone": "+70744416743"}
0005432302423	028907	4278 834738	VALERIY ILIN	{"email": "ilin_valeriy.061970@postgrespro.ru", "phone": "+70361788848"}
0005432302424	028907	7304 806077	ELENA CHERNOVA	{"email": "echernova-1977@postgrespro.ru", "phone": "+70322437354"}
0005432302425	6BBE1A	7847 943235	DARYA SOKOLOVA	{"phone": "+70516146590"}
0005432302426	04A011	2659 059351	IRINA ISAEVA	{"phone": "+70697751889"}
0005432302427	A3D267	7467 918113	ANDREY SAVELEV	{"phone": "+70688475282"}
0005432302428	C5DDF5	1150 239683	ALEKSEY SOROKIN	{"phone": "+70452208493"}
0005432302429	7D5AC6	8219 722393	SVETLANA YUDINA	{"phone": "+70453792396"}
0005432302430	0E1AC4	9721 767748	MAKSIM ZHURAVLEV	{"phone": "+70020473223"}
0005432302431	BC7E2F	2102 831890	NADEZHDA IVANOVA	{"phone": "+70718924226"}
0005432302432	BC7E2F	4581 383315	EVGENIY ALEKSANDROV	{"email": "aleksandrov.e-1973@postgrespro.ru", "phone": "+70560103420"}
0005432302433	BC7E2F	7961 446119	YULIYA TARASOVA	{"phone": "+70229762154"}
0005432302434	BC7E2F	3911 952773	TATYANA IVANOVA	{"email": "ivanovat_19021977@postgrespro.ru", "phone": "+70433701769"}
0005432302435	500F35	2928 232307	ALEKSANDR NOVIKOV	{"email": "anovikov.02111975@postgrespro.ru", "phone": "+70963738708"}
0005432302436	500F35	7528 457097	NINA VOROBEVA	{"email": "nvorobeva-091977@postgrespro.ru", "phone": "+70068959464"}
0005432302437	D47F0E	6104 521258	ILGIZ VOROBEV	{"phone": "+70229797557"}
0005432302438	D331A2	3143 652984	VALENTIN KUZNECOV	{"email": "valentin.kuznecov-121978@postgrespro.ru", "phone": "+70582617888"}
0005432302439	D331A2	0165 638582	OLGA MOROZOVA	{"email": "o-morozova-1969@postgrespro.ru", "phone": "+70950872938"}
0005432302440	FF2608	6078 956522	ALEKSANDR TIKHONOV	{"email": "a.tikhonov.14101964@postgrespro.ru", "phone": "+70645466365"}
0005432302441	8D57A6	3213 984921	RAISA ZHURAVLEVA	{"phone": "+70961560821"}
0005432302442	355ED1	3376 764599	VIKTOR RODIONOV	{"email": "rodionov-viktor_1979@postgrespro.ru", "phone": "+70047895733"}
0005432302443	FB9F27	9686 350580	ANASTASIYA MELNIKOVA	{"phone": "+70125135185"}
0005432304329	B40499	6817 947274	OLGA LUKYANOVA	{"email": "lukyanovao_1976@postgrespro.ru", "phone": "+70163973844"}
0005432304330	B40499	1630 317754	SERGEY MIKHAYLOV	{"email": "sergey-mikhaylov101963@postgrespro.ru", "phone": "+70654971410"}
0005432304331	26AB98	5318 466912	TATYANA ZAYCEVA	{"email": "zaycevatatyana1972@postgrespro.ru", "phone": "+70676370057"}
0005432304332	23D1B3	8197 013711	NADEZHDA ARKHIPOVA	{"email": "nadezhda-arkhipova-18061976@postgrespro.ru", "phone": "+70794854120"}
0005432304333	B4EE4C	5646 840744	OLGA AKIMOVA	{"email": "olgaakimova.1970@postgrespro.ru", "phone": "+70963750756"}
0005432304334	B4EE4C	0108 643337	DMITRIY ZAYCEV	{"phone": "+70824136011"}
0005432304335	07F2EF	9514 680716	ALEKSEY ZAYCEV	{"email": "zaycev_a.111974@postgrespro.ru", "phone": "+70359520828"}
0005432304336	07F2EF	6077 484529	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_1971@postgrespro.ru", "phone": "+70956570063"}
0005432304337	07F2EF	4657 787659	GALIYA KOZLOVA	{"email": "galiya_kozlova-031974@postgrespro.ru", "phone": "+70999856288"}
0005432304338	563DA4	6516 670692	MAKSIM ISAEV	{"email": "isaev_m-1980@postgrespro.ru", "phone": "+70199571299"}
0005432304339	563DA4	2192 272210	IGOR ZHUKOV	{"email": "igor-zhukov1979@postgrespro.ru", "phone": "+70313553085"}
0005432304340	532DBB	7003 551683	DMITRIY VASILEV	{"phone": "+70019392335"}
0005432304341	60F549	6645 953901	MIKHAIL DMITRIEV	{"phone": "+70946718459"}
0005432304342	820AE2	5863 093093	ANDREY MAKAROV	{"email": "makarov_andrey_23081971@postgrespro.ru", "phone": "+70910462167"}
0005432304343	D143A1	1339 383621	MIKHAIL SCHERBAKOV	{"phone": "+70787833763"}
0005432304344	148978	5910 331030	ILYA GORBUNOV	{"phone": "+70396280643"}
0005432304345	148978	2810 621188	IRAIDA SAVELEVA	{"phone": "+70720017410"}
0005432304346	AC7216	5836 182077	VALERIY EGOROV	{"email": "vegorov.27121972@postgrespro.ru", "phone": "+70041606036"}
0005432304347	AC7216	7038 963724	VLADIMIR NAZAROV	{"phone": "+70722087570"}
0005432304348	A6F0FE	5570 469663	VALENTINA NESTEROVA	{"phone": "+70667299836"}
0005432304349	9DE2A9	6006 567794	DENIS MAKAROV	{"phone": "+70661395906"}
0005432304350	9DE2A9	7812 517395	ELIZAVETA NIKOLAEVA	{"email": "e_nikolaeva-1977@postgrespro.ru", "phone": "+70268793876"}
0005432304351	9DE2A9	9699 972622	TATYANA POPOVA	{"email": "tatyana.popova-1973@postgrespro.ru", "phone": "+70017158749"}
0005432304352	59C0CF	2703 148243	LILIYA SMIRNOVA	{"phone": "+70229027673"}
0005432304353	8B6139	8436 512509	LYUDMILA ZAKHAROVA	{"email": "zakharova-l-14041981@postgrespro.ru", "phone": "+70597757147"}
0005432304354	8B6139	5597 276870	DMITRIY ALEKSANDROV	{"email": "aleksandrov_d-30071971@postgrespro.ru", "phone": "+70939150056"}
0005432304355	1511C2	9372 739337	NINA GRISHINA	{"phone": "+70890559316"}
0005432304356	1511C2	4905 145210	EKATERINA ZAKHAROVA	{"phone": "+70378880866"}
0005432304357	E22A42	8552 389919	KLAVDIYA KOROLEVA	{"email": "k.koroleva111968@postgrespro.ru", "phone": "+70454395974"}
0005432304358	BC0031	4856 835989	VALENTINA MARTYNOVA	{"phone": "+70784668352"}
0005432304359	D07CBF	4377 754106	SERGEY KAZAKOV	{"phone": "+70343794772"}
0005432304360	D07CBF	2954 611362	NIKOLAY MIKHAYLOV	{"email": "n.mikhaylov-1983@postgrespro.ru", "phone": "+70961516558"}
0005432304361	B1DD1D	5062 417938	SERGEY MAKSIMOV	{"phone": "+70571451371"}
0005432304362	C7FEB2	7466 311435	SERGEY ORLOV	{"email": "orlov.s061973@postgrespro.ru", "phone": "+70717892870"}
0005432304363	F2CB8E	9138 487873	ALEKSANDR ORLOV	{"phone": "+70195658811"}
0005432304364	5DF550	1966 255635	IGOR KAZAKOV	{"phone": "+70158308424"}
0005432304365	BAA1C6	5023 528963	VLADIMIR POPOV	{"phone": "+70461130796"}
0005432304366	109410	9466 548571	OLEG BELOV	{"phone": "+70402592259"}
0005432304367	109410	2588 884496	NATALYA GORBUNOVA	{"email": "n_gorbunova.1967@postgrespro.ru", "phone": "+70689576398"}
0005432304368	7BE8B3	9253 465176	DMITRIY BORISOV	{"email": "dmitriy-borisov021963@postgrespro.ru", "phone": "+70628735159"}
0005432304369	0B5F4B	0274 215663	VADIM KARPOV	{"phone": "+70958187756"}
0005432304370	0B33BD	8193 915177	MIKHAIL KUZMIN	{"phone": "+70185724846"}
0005432304371	A4EBB3	8765 761594	ANASTASIYA EFREMOVA	{"email": "efremova_a-041967@postgrespro.ru", "phone": "+70287892492"}
0005432304372	9BF7A4	0196 784543	YURIY IVANOV	{"email": "yivanov10111965@postgrespro.ru", "phone": "+70217294282"}
0005432304373	9BF7A4	2009 310231	RITA TIKHONOVA	{"email": "r-tikhonova-011969@postgrespro.ru", "phone": "+70432971705"}
0005432304374	4FC9B1	3914 230231	NATALYA STEPANOVA	{"email": "natalya-stepanova_23061980@postgrespro.ru", "phone": "+70210239798"}
0005432304375	576793	5955 083355	YANA ORLOVA	{"email": "orlova.yana041978@postgrespro.ru", "phone": "+70885302355"}
0005432304376	97599C	4136 343293	SOFYA GUSEVA	{"email": "guseva-sofya121972@postgrespro.ru", "phone": "+70953019390"}
0005432304377	CD5230	2985 434680	ANATOLIY SEMENOV	{"phone": "+70832873435"}
0005432304378	F98014	9366 181073	ANDREY KAZAKOV	{"phone": "+70894640066"}
0005432304379	47078F	3967 859236	VLADIMIR CHERNOV	{"email": "vladimir.chernov-081973@postgrespro.ru", "phone": "+70389621290"}
0005432304380	47078F	5561 631167	SVETLANA DMITRIEVA	{"email": "s_dmitrieva-09111970@postgrespro.ru", "phone": "+70858426899"}
0005432304381	0E8EFB	8812 709328	VYACHESLAV POPOV	{"phone": "+70316945822"}
0005432304382	0E8EFB	5878 030932	EKATERINA SIDOROVA	{"email": "sidorova_e081972@postgrespro.ru", "phone": "+70548886699"}
0005432304383	0E8EFB	5594 580810	VALENTINA KONOVALOVA	{"email": "valentina_konovalova1980@postgrespro.ru", "phone": "+70742039506"}
0005432304384	959794	5785 107955	DANIIL KUZMIN	{"phone": "+70526500022"}
0005432304385	959794	3013 127327	DMITRIY KOZLOV	{"email": "kozlov-dmitriy081964@postgrespro.ru", "phone": "+70084695585"}
0005432304386	79337D	2857 913481	KRISTINA EFIMOVA	{"email": "efimova_kristina_041966@postgrespro.ru", "phone": "+70948998404"}
0005432304387	CEB3F2	1173 026242	EKATERINA IVANOVA	{"phone": "+70807797911"}
0005432304388	93942F	5368 501258	MIKHAIL DMITRIEV	{"email": "mikhaildmitriev.091982@postgrespro.ru", "phone": "+70427875270"}
0005432304389	4BC48D	3346 372900	GALINA KRASNOVA	{"phone": "+70043293948"}
0005432304390	4BC48D	6555 751311	MIKHAIL GERASIMOV	{"email": "mikhail.gerasimov-15011965@postgrespro.ru", "phone": "+70044311080"}
0005432304391	54B774	7544 991729	ANTONINA KOVALEVA	{"phone": "+70565409574"}
0005432304392	B7F059	0930 328951	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov-1988@postgrespro.ru", "phone": "+70124793273"}
0005432304393	562E38	4997 110356	VADIM BELOV	{"email": "vadim_belov061979@postgrespro.ru", "phone": "+70645887065"}
0005432304394	562E38	8384 733208	ALEKSANDR KAZAKOV	{"phone": "+70640215804"}
0005432304395	DA4F08	7113 991374	IRINA SERGEEVA	{"email": "i_sergeeva_29071968@postgrespro.ru", "phone": "+70360992297"}
0005432304396	597504	1449 069934	TATYANA NIKITINA	{"email": "nikitina-tatyana.19121980@postgrespro.ru", "phone": "+70089184527"}
0005432304397	37E57C	4550 066315	VIKTOR KAZAKOV	{"phone": "+70358877030"}
0005432304398	E694E7	1896 681119	VIKTOR PETROV	{"email": "petrovv02031980@postgrespro.ru", "phone": "+70261246747"}
0005432304399	264696	3789 107160	VALERIY KUZNECOV	{"email": "kuznecov_v-1963@postgrespro.ru", "phone": "+70042567764"}
0005432304400	6F00EC	1896 648996	PAVEL KAZAKOV	{"phone": "+70813032702"}
0005432304401	2CB8B0	5373 170432	ALEKSEY ISAEV	{"email": "isaev_a121969@postgrespro.ru", "phone": "+70244027857"}
0005432304402	62D88B	0921 637051	LILIYA ANTONOVA	{"email": "l.antonova1979@postgrespro.ru", "phone": "+70845473819"}
0005432304403	E5FEE0	4909 121983	GALINA BELYAEVA	{"email": "galina-belyaeva-27101976@postgrespro.ru", "phone": "+70588860756"}
0005432304404	52A926	8685 883914	ELENA ZHURAVLEVA	{"phone": "+70040161936"}
0005432304405	7A1BA1	6265 565306	ANASTASIYA IVANOVA	{"phone": "+70478345768"}
0005432304406	F4F2AA	4762 303316	ANDREY IVANOV	{"email": "andrey_ivanov.02081969@postgrespro.ru", "phone": "+70451750873"}
0005432304407	F4F2AA	3039 243161	SERGEY GUSEV	{"email": "s-gusev031977@postgrespro.ru", "phone": "+70131925795"}
0005432304408	26E38E	1744 809046	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova_29081963@postgrespro.ru", "phone": "+70338630856"}
0005432304409	26E38E	4103 985201	ANTONINA DANILOVA	{"phone": "+70683609229"}
0005432304410	4103D8	6237 951817	NINA LAZAREVA	{"phone": "+70603309048"}
0005432304411	4103D8	7535 663556	VLADIMIR ORLOV	{"phone": "+70763627258"}
0005432304412	8C3B84	8004 673756	ZINAIDA MAKSIMOVA	{"email": "z.maksimova-1979@postgrespro.ru", "phone": "+70268467433"}
0005432304413	E710DE	5752 828534	ELENA VLASOVA	{"email": "elena-vlasova-02111963@postgrespro.ru", "phone": "+70225483875"}
0005432304414	E710DE	1969 714148	NINA SAVELEVA	{"phone": "+70917192642"}
0005432304415	BD5586	1863 741086	KRISTINA ZAKHAROVA	{"email": "zakharovakristina-16111956@postgrespro.ru", "phone": "+70244385248"}
0005432304416	9AE987	3282 125562	TATYANA LUKYANOVA	{"phone": "+70653768480"}
0005432304417	341E6D	8720 032815	SERGEY NIKOLAEV	{"email": "nikolaev-s1959@postgrespro.ru", "phone": "+70949041826"}
0005432304418	341E6D	9804 299881	NATALYA KOMAROVA	{"email": "komarova-natalya.03091978@postgrespro.ru", "phone": "+70151842369"}
0005432304419	68B048	7197 127080	VALENTINA ROMANOVA	{"phone": "+70086259526"}
0005432304420	68B048	8084 219746	GALINA TITOVA	{"email": "galinatitova_041962@postgrespro.ru", "phone": "+70200699635"}
0005432304421	3EA374	7286 169664	YURIY STEPANOV	{"email": "stepanovy-10011972@postgrespro.ru", "phone": "+70541765854"}
0005432304422	3EA374	7408 538485	NINA SMIRNOVA	{"phone": "+70336978598"}
0005432304423	7FFD12	3332 481917	LYUBOV ZAKHAROVA	{"phone": "+70831484019"}
0005432304424	983202	5286 143908	ANATOLIY SCHERBAKOV	{"phone": "+70373042422"}
0005432304425	2F7B51	7148 655629	LYUDMILA TITOVA	{"phone": "+70918980013"}
0005432304426	E659F7	7317 709537	IGOR ROMANOV	{"phone": "+70371566234"}
0005432304427	F1B8C5	9299 444025	PAVEL FROLOV	{"email": "pavel-frolov-051974@postgrespro.ru", "phone": "+70916626454"}
0005432304428	649B0D	1183 312081	INNA MAKAROVA	{"email": "makarova-inna.011965@postgrespro.ru", "phone": "+70770226428"}
0005432304429	1A0170	8054 172874	ALEKSANDR SHEVCHENKO	{"phone": "+70248996003"}
0005432304430	1A0170	8907 016985	TATYANA SERGEEVA	{"email": "sergeeva.t011969@postgrespro.ru", "phone": "+70673329579"}
0005432304431	1A0170	8949 812051	VASILIY SOLOVEV	{"phone": "+70194110975"}
0005432304432	2E864D	5574 867478	OLGA KARPOVA	{"email": "karpova_olga.26031969@postgrespro.ru", "phone": "+70634552386"}
0005432304433	B57EEB	3921 260429	MARIYA KOZLOVA	{"email": "mariya-kozlova-1984@postgrespro.ru", "phone": "+70463875829"}
0005432304434	B69D62	6610 107562	VALENTINA MOISEEVA	{"phone": "+70554034807"}
0005432304435	935DA1	3038 725715	SERGEY ANTONOV	{"phone": "+70370013943"}
0005432304436	935DA1	9048 735379	YURIY NAZAROV	{"phone": "+70669137126"}
0005432304437	1B6EA5	3737 467843	VIKTOR IVANOV	{"email": "ivanov-viktor031965@postgrespro.ru", "phone": "+70800445120"}
0005432304438	1B6EA5	7428 988861	EVGENIYA SIDOROVA	{"email": "evgeniya-sidorova25091975@postgrespro.ru", "phone": "+70992839121"}
0005432304439	EAECD6	8083 934340	VIKTOR SEMENOV	{"email": "v-semenov1977@postgrespro.ru", "phone": "+70563278807"}
0005432304440	D98811	0868 562572	IVAN ORLOV	{"phone": "+70791604017"}
0005432304441	2EC66A	6850 483503	LILIYA KOLESNIKOVA	{"email": "kolesnikova.l_1967@postgrespro.ru", "phone": "+70717118611"}
0005432304442	2EC66A	1035 081352	NURLAN KUZMIN	{"phone": "+70985120650"}
0005432304443	BBCFF9	0262 277498	DMITRIY POPOV	{"email": "dmitriypopov_1977@postgrespro.ru", "phone": "+70110670402"}
0005432304444	7D18AE	8252 813517	SERGEY KUDRYASHOV	{"email": "kudryashovs-1967@postgrespro.ru", "phone": "+70934968044"}
0005432304445	7D18AE	5625 977494	EVGENIYA ANTONOVA	{"email": "e_antonova_021978@postgrespro.ru", "phone": "+70952998728"}
0005432304446	2F392D	4926 772148	VYACHESLAV IVANOV	{"phone": "+70942361242"}
0005432304447	BB0A70	5038 272141	ALEKSEY KULIKOV	{"email": "kulikov.aleksey-23121975@postgrespro.ru", "phone": "+70777710959"}
0005432304448	473956	7359 980637	KONSTANTIN DENISOV	{"phone": "+70980853648"}
0005432304449	05EB9A	5928 781961	TAISIYA VASILEVA	{"phone": "+70469857946"}
0005432304450	087106	4707 053126	TAISIYA BELYAEVA	{"email": "belyaevat-051963@postgrespro.ru", "phone": "+70867860516"}
0005432304451	A7EB48	5579 759001	MIKHAIL ALEKSEEV	{"phone": "+70292652873"}
0005432304452	6DEF2A	2912 135930	INGA EFREMOVA	{"phone": "+70103829946"}
0005432304453	6DEF2A	9147 799978	OLGA MASLOVA	{"phone": "+70452434260"}
0005432304454	2AA279	9546 730130	ANDREY KUZMIN	{"phone": "+70178730392"}
0005432304455	68819E	5583 152164	NIKOLAY MATVEEV	{"phone": "+70867478777"}
0005432304456	68819E	5396 699760	TATYANA MOROZOVA	{"phone": "+70628620656"}
0005432304457	68819E	2378 701032	NINA TARASOVA	{"email": "n-tarasova.121981@postgrespro.ru", "phone": "+70064122468"}
0005432304458	C409AC	4384 487300	ALEKSANDR KOROLEV	{"phone": "+70108872046"}
0005432304459	1121A3	1507 510603	ALEKSEY PAVLOV	{"email": "a-pavlov.111974@postgrespro.ru", "phone": "+70314860364"}
0005432304460	FCD200	9881 824164	MIKHAIL MAKAROV	{"email": "makarov-m-121972@postgrespro.ru", "phone": "+70255567484"}
0005432304461	D2788A	9641 495423	ALEKSANDR CHERNOV	{"phone": "+70342879132"}
0005432304462	D2788A	7818 201215	IRINA FOMINA	{"phone": "+70344958890"}
0005432304463	D2788A	9151 915519	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov071978@postgrespro.ru", "phone": "+70503356709"}
0005432304464	D4776D	2890 489419	IRINA ERMAKOVA	{"email": "ermakova.irina1981@postgrespro.ru", "phone": "+70430501534"}
0005432304465	D4776D	9780 469188	ANNA MIKHAYLOVA	{"phone": "+70550312969"}
0005432304466	0538C7	4158 466562	ELIZAVETA ORLOVA	{"email": "e-orlova-26021983@postgrespro.ru", "phone": "+70180495594"}
0005432304467	0538C7	5181 478098	SVETLANA ANDREEVA	{"phone": "+70256406738"}
0005432304468	760318	6459 540487	KRISTINA ANTONOVA	{"email": "kristina-antonova_29051968@postgrespro.ru", "phone": "+70147290009"}
0005432304469	95992D	9717 254700	ALEKSANDR VOLKOV	{"phone": "+70616596927"}
0005432304470	1E256F	7757 205890	EKATERINA NOVIKOVA	{"phone": "+70479832519"}
0005432304471	2ABF7E	7417 734483	NAIL SCHERBAKOV	{"phone": "+70932267422"}
0005432304472	2ABF7E	8162 496345	EGOR KOROLEV	{"phone": "+70527322899"}
0005432304473	A7F3A5	0151 040529	REGINA NIKOLAEVA	{"phone": "+70418150816"}
0005432304474	A7F3A5	1229 547634	ANATOLIY KUZNECOV	{"email": "kuznecov-anatoliy111972@postgrespro.ru", "phone": "+70287171489"}
0005432304475	046DB2	3742 358468	IRINA ABRAMOVA	{"email": "iabramova_23111971@postgrespro.ru", "phone": "+70226711882"}
0005432304476	A229B4	2597 588973	ELIZAVETA VLASOVA	{"phone": "+70062204193"}
0005432304477	F13437	6063 519030	MARIYA KUZNECOVA	{"email": "mariyakuznecova.081965@postgrespro.ru", "phone": "+70180050837"}
0005432304478	F13437	0307 597655	ALIYA IVANOVA	{"email": "ivanova-a1977@postgrespro.ru", "phone": "+70236843879"}
0005432304479	F13437	3951 915186	ZOYA GUSEVA	{"phone": "+70302901852"}
0005432304480	F13437	3309 000454	GENNADIY ABRAMOV	{"phone": "+70583368046"}
0005432304481	BBD403	4976 990556	LYUBOV EGOROVA	{"email": "lyubovegorova-1966@postgrespro.ru", "phone": "+70916644074"}
0005432304482	EEB49E	5281 739347	OLGA ABRAMOVA	{"phone": "+70034509560"}
0005432304483	64DF83	5574 449801	KLAVDIYA AFANASEVA	{"phone": "+70384432479"}
0005432304484	1062CC	1900 734531	ELENA KOROLEVA	{"phone": "+70696392271"}
0005432304485	B81A76	4374 034499	LYUBOV IVANOVA	{"phone": "+70503919503"}
0005432304486	B81A76	9477 190555	VLADIMIR SOKOLOV	{"email": "sokolov-v-051979@postgrespro.ru", "phone": "+70393356842"}
0005432304487	B81A76	3448 225746	RAVZA IVANOVA	{"email": "rivanova_29071977@postgrespro.ru", "phone": "+70231717204"}
0005432304488	52025D	4366 327711	VIKTOR RODIONOV	{"email": "viktor.rodionov.1977@postgrespro.ru", "phone": "+70378992228"}
0005432304489	D50A46	6186 872927	ZINAIDA GUSEVA	{"email": "guseva.zinaida-1965@postgrespro.ru", "phone": "+70195116387"}
0005432304490	E81C92	6410 616469	EVGENIY KULIKOV	{"phone": "+70529768399"}
0005432304491	D0881D	5827 955524	DMITRIY YAKOVLEV	{"email": "yakovlevd_1963@postgrespro.ru", "phone": "+70937751464"}
0005432304492	104492	7981 174487	VLADIMIR KONOVALOV	{"email": "konovalov.v021974@postgrespro.ru", "phone": "+70863644280"}
0005432304493	089CC7	7109 414278	PAVEL NIKOLAEV	{"email": "pavel-nikolaev-121978@postgrespro.ru", "phone": "+70478713206"}
0005432304494	089CC7	2810 485984	IRINA ZOTOVA	{"email": "zotovairina1970@postgrespro.ru", "phone": "+70594445786"}
0005432304495	417CEA	7795 859931	SVETLANA KOROLEVA	{"phone": "+70014221137"}
0005432304496	417CEA	8644 892068	ANTONINA NOVIKOVA	{"phone": "+70666056231"}
0005432304497	C63E20	5441 819513	ALEKSANDR TIKHONOV	{"email": "tikhonova.20051971@postgrespro.ru", "phone": "+70960487834"}
0005432304498	C63E20	4463 754334	IVAN GRIGOREV	{"phone": "+70135893150"}
0005432304499	FFA00E	9167 190262	DMITRIY KUDRYASHOV	{"email": "kudryashov.d-041972@postgrespro.ru", "phone": "+70846028676"}
0005432304500	FFA00E	2444 784765	IGOR ZAKHAROV	{"phone": "+70551578912"}
0005432304501	FFA00E	5870 256022	INNA MEDVEDEVA	{"phone": "+70662276937"}
0005432304502	00770C	0224 418744	EKATERINA VLASOVA	{"email": "vlasova.ekaterina1970@postgrespro.ru", "phone": "+70024699710"}
0005432304503	00770C	7391 591265	RAISA TARASOVA	{"email": "tarasova.raisa_081963@postgrespro.ru", "phone": "+70540269607"}
0005432304504	04F889	1061 611203	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr30041978@postgrespro.ru", "phone": "+70179217507"}
0005432304505	04F889	2760 610626	ALEKSANDR GAVRILOV	{"phone": "+70350174023"}
0005432304506	C04523	6348 898554	GRIGORIY ANDREEV	{"phone": "+70217833626"}
0005432304507	4831BB	8469 988121	NIKOLAY PETROV	{"email": "n.petrov26021979@postgrespro.ru", "phone": "+70309555976"}
0005432304508	4831BB	9741 650246	KONSTANTIN PETROV	{"phone": "+70917005354"}
0005432304509	0D4D79	5139 694411	ALEKSEY VASILEV	{"email": "vasilev_aleksey-041988@postgrespro.ru", "phone": "+70812779030"}
0005432304510	E8F236	6462 403649	VIKTORIYA MIKHAYLOVA	{"phone": "+70619982738"}
0005432304511	1FB31E	2537 567653	VIKTOR IVANOV	{"email": "v.ivanov_1967@postgrespro.ru", "phone": "+70752699623"}
0005432305705	4DC11A	6485 822898	EVA PETROVA	{"phone": "+70511011706"}
0005432305706	4DC11A	6201 183071	EGOR VASILEV	{"phone": "+70782868630"}
0005432305707	43C26F	1857 148165	ELENA SCHERBAKOVA	{"phone": "+70051735026"}
0005432305708	8BA8E3	4847 284062	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr_1965@postgrespro.ru", "phone": "+70634549554"}
0005432305709	80C931	6481 993287	ALEKSANDR NIKOLAEV	{"phone": "+70740737379"}
0005432305710	80C931	7938 013587	VALERIYA ZAKHAROVA	{"email": "zakharova-v21051971@postgrespro.ru", "phone": "+70638554763"}
0005432305711	80C931	1966 410434	VERONIKA MEDVEDEVA	{"phone": "+70715801955"}
0005432305712	4DFFE3	3238 054157	DMITRIY SHEVCHENKO	{"email": "d_shevchenko101972@postgrespro.ru", "phone": "+70774210418"}
0005432305713	882CB0	7235 868127	IRINA MOROZOVA	{"phone": "+70665270199"}
0005432305714	C67674	7497 288012	VLADIMIR MEDVEDEV	{"email": "medvedevv22091968@postgrespro.ru", "phone": "+70144204463"}
0005432305715	654891	3702 787732	ALEKSEY SOROKIN	{"email": "a_sorokin031971@postgrespro.ru", "phone": "+70184332768"}
0005432305716	9240EA	9859 616304	ANNA KONOVALOVA	{"email": "a.konovalova_101968@postgrespro.ru", "phone": "+70367056379"}
0005432305717	BA0044	6328 896397	ELIZAVETA BARANOVA	{"email": "e.baranova.041976@postgrespro.ru", "phone": "+70523510333"}
0005432305718	D99B8A	0074 548797	VALENTINA ZHURAVLEVA	{"email": "valentinazhuravleva-1985@postgrespro.ru", "phone": "+70991454503"}
0005432305719	727E15	9205 034722	SVETLANA PAVLOVA	{"email": "svetlana_pavlova27101974@postgrespro.ru", "phone": "+70188431742"}
0005432305720	883AEF	0103 196887	NIKITA MAKAROV	{"email": "n_makarov-051979@postgrespro.ru", "phone": "+70181974402"}
0005432305721	AC219F	7630 738510	EVGENIY POPOV	{"phone": "+70817285229"}
0005432305722	8F80F5	6107 243392	EVGENIY MELNIKOV	{"email": "evgeniy_melnikov_07061989@postgrespro.ru", "phone": "+70293560254"}
0005432305723	8F80F5	2419 068915	TATYANA ERMAKOVA	{"email": "ermakova_t-101974@postgrespro.ru", "phone": "+70102408434"}
0005432305724	EBBE83	5301 073411	SERGEY MATVEEV	{"email": "s.matveev-14061970@postgrespro.ru", "phone": "+70461533841"}
0005432305725	AB91B0	5810 467766	NATALYA FOMINA	{"email": "n.fomina.111973@postgrespro.ru", "phone": "+70229189157"}
0005432305726	AB91B0	0238 561416	YULIYA KUZNECOVA	{"phone": "+70169032340"}
0005432305727	F2DCF8	6661 530651	DMITRIY VASILEV	{"phone": "+70198071039"}
0005432305728	90EF94	3495 684855	ANDREY MELNIKOV	{"email": "melnikov-a-031976@postgrespro.ru", "phone": "+70134475685"}
0005432305729	D58173	6263 993184	ANASTASIYA ZHURAVLEVA	{"phone": "+70159826051"}
0005432305730	D58173	8259 931071	POLINA KUZMINA	{"phone": "+70437279327"}
0005432305731	DC12CE	6299 131340	NIKOLAY NIKOLAEV	{"email": "nikolaynikolaev_1973@postgrespro.ru", "phone": "+70691487346"}
0005432305732	B6B69F	3765 897417	ILYA SAVELEV	{"email": "savelev.i-1958@postgrespro.ru", "phone": "+70496703847"}
0005432305733	60482E	4177 675442	YAROSLAV GORBUNOV	{"phone": "+70016964310"}
0005432305734	E0D536	7684 022609	SERGEY ROMANOV	{"phone": "+70827713025"}
0005432305735	D0BBA2	4068 755350	DARYA MIRONOVA	{"phone": "+70497932166"}
0005432305736	D0BBA2	8385 929796	EKATERINA LUKYANOVA	{"email": "lukyanova_ekaterina1963@postgrespro.ru", "phone": "+70515109308"}
0005432305737	D0BBA2	3029 937654	ANNA PETROVA	{"phone": "+70769757263"}
0005432305738	B51CF4	2650 881869	RAISA MARTYNOVA	{"phone": "+70658246748"}
0005432305739	1BCEE4	1884 209279	ARTEM ILIN	{"email": "artem_ilin_051973@postgrespro.ru", "phone": "+70016673758"}
0005432305740	08705D	5535 739194	NATALYA POLYAKOVA	{"phone": "+70715996562"}
0005432305741	1E884F	6712 771482	PLATON GUSEV	{"phone": "+70944152718"}
0005432305742	1E884F	5110 488762	TIMOFEY RODIONOV	{"email": "t_rodionov_27031966@postgrespro.ru", "phone": "+70976472416"}
0005432305743	17E92D	1170 109296	LYUBOV ZOTOVA	{"email": "zotovalyubov-25021977@postgrespro.ru", "phone": "+70839809829"}
0005432305744	17E92D	2161 568187	YURIY SERGEEV	{"phone": "+70054521120"}
0005432305745	49DA7C	4393 054092	IGOR KARPOV	{"email": "ikarpov.1961@postgrespro.ru", "phone": "+70618821284"}
0005432305746	49DA7C	9126 510115	SERGEY DMITRIEV	{"email": "s.dmitriev.1981@postgrespro.ru", "phone": "+70553198982"}
0005432305747	F5FDCB	2717 909303	OLESYA GUSEVA	{"email": "guseva.o_31101981@postgrespro.ru", "phone": "+70467285118"}
0005432305748	BA36E9	0318 624363	NADEZHDA KUZMINA	{"phone": "+70719913559"}
0005432305749	75D6A4	8683 600570	DIANA SEMENOVA	{"phone": "+70202708557"}
0005432305750	EA5F81	4374 561710	ANNA IVANOVA	{"phone": "+70890403976"}
0005432305751	B1F7F5	6572 388728	SERGEY BORISOV	{"phone": "+70355928468"}
0005432305752	A619E6	5693 995107	LARISA ORLOVA	{"phone": "+70124314501"}
0005432305753	05E8CB	5163 594225	GRIGORIY KUZNECOV	{"phone": "+70825197570"}
0005432305754	05E8CB	9846 771393	ANATOLIY MIKHAYLOV	{"phone": "+70550652021"}
0005432305755	05E8CB	2163 914720	EKATERINA DANILOVA	{"phone": "+70880710486"}
0005432305756	D75EC8	6193 554750	DARYA ANISIMOVA	{"phone": "+70030754808"}
0005432305757	E859C0	7700 489473	NIKOLAY MOROZOV	{"email": "morozov-nikolay-1973@postgrespro.ru", "phone": "+70502150377"}
0005432305758	B60A2A	2402 359443	TAMARA IVANOVA	{"email": "ivanova_t-07041966@postgrespro.ru", "phone": "+70253716050"}
0005432305759	191567	8884 540609	TATYANA KULIKOVA	{"email": "tkulikova_1982@postgrespro.ru", "phone": "+70557366402"}
0005432305760	191567	7005 670402	VALENTINA ABRAMOVA	{"email": "valentinaabramova.111969@postgrespro.ru", "phone": "+70430062427"}
0005432305761	21914F	0402 153156	MAKSIM KRASNOV	{"email": "m_krasnov.1970@postgrespro.ru", "phone": "+70269160570"}
0005432305762	21914F	2029 580536	MIKHAIL SAVELEV	{"email": "savelevm_071981@postgrespro.ru", "phone": "+70888743876"}
0005432305763	820698	2138 447323	LYUBOV ORLOVA	{"phone": "+70406327656"}
0005432305764	820698	6152 581398	VLADIMIR ISAEV	{"phone": "+70037506553"}
0005432305765	1B1315	7330 144910	MADINA LOGINOVA	{"phone": "+70615836636"}
0005432305766	8BA7D5	6481 944255	MARIYA TITOVA	{"email": "titova-m11121961@postgrespro.ru", "phone": "+70730100651"}
0005432305767	8BA7D5	0274 378183	NINA MELNIKOVA	{"email": "n.melnikova-24081970@postgrespro.ru", "phone": "+70302675838"}
0005432305768	7D3844	9149 447884	VLADIMIR POPOV	{"email": "popovvladimir-1968@postgrespro.ru", "phone": "+70795261509"}
0005432305769	9998D1	6115 414204	ANDREY TIKHONOV	{"email": "a-tikhonov-1969@postgrespro.ru", "phone": "+70388716224"}
0005432305770	F00BA9	4451 407854	ANTON POPOV	{"email": "antonpopov.1970@postgrespro.ru", "phone": "+70499633080"}
0005432305771	12B322	8836 671899	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr_1974@postgrespro.ru", "phone": "+70063369811"}
0005432305772	3B5F59	8814 813792	MARGARITA POPOVA	{"email": "m_popova.01051976@postgrespro.ru", "phone": "+70366016088"}
0005432305773	3B5F59	0666 753459	ILYA DMITRIEV	{"email": "i_dmitriev-091963@postgrespro.ru", "phone": "+70000750316"}
0005432305774	108F52	5908 228822	DENIS KOZLOV	{"phone": "+70211380206"}
0005432305775	108F52	9706 396789	ALISA FEDOROVA	{"phone": "+70732297452"}
0005432305776	8D7C3E	1407 288534	NADEZHDA TIMOFEEVA	{"email": "nadezhdatimofeeva.051971@postgrespro.ru", "phone": "+70700645919"}
0005432305777	1ACD07	7342 468642	NATALYA KUZMINA	{"phone": "+70451199096"}
0005432305778	9E390F	9959 317331	MARINA SOKOLOVA	{"phone": "+70827066488"}
0005432305779	0EE0DA	8674 693412	ALEKSANDR BORISOV	{"email": "borisov.a1978@postgrespro.ru", "phone": "+70208211013"}
0005432305780	CA4EE7	1783 561787	ALEKSANDR KAZAKOV	{"email": "kazakova17051991@postgrespro.ru", "phone": "+70855606759"}
0005432305781	FA7D62	5868 656333	ELENA ANDREEVA	{"phone": "+70781400144"}
0005432305782	038521	0677 899736	VALENTINA POTAPOVA	{"email": "v-potapova_1962@postgrespro.ru", "phone": "+70384880871"}
0005432305783	CCCFAF	4449 051188	TAMARA ALEKSEEVA	{"email": "t-alekseeva.081967@postgrespro.ru", "phone": "+70922688057"}
0005432305784	CCCFAF	4394 998126	IVAN KUZNECOV	{"phone": "+70938041055"}
0005432305785	CCCFAF	1254 792485	ELENA ERMAKOVA	{"email": "elenaermakova.1977@postgrespro.ru", "phone": "+70774730153"}
0005432305786	76B0A4	4220 920922	ANDREY SAVELEV	{"email": "saveleva_05111964@postgrespro.ru", "phone": "+70107364750"}
0005432305787	76B0A4	0811 424473	LILIYA ALEKSEEVA	{"phone": "+70298967709"}
0005432305788	D7B83D	7515 771618	OLGA KOROLEVA	{"email": "korolevaolga_101972@postgrespro.ru", "phone": "+70160631643"}
0005432305789	FDA9DA	2595 766833	YURIY NOVIKOV	{"phone": "+70491366372"}
0005432305790	FDA9DA	6569 246608	TATYANA MIRONOVA	{"email": "mironova_tatyana.1966@postgrespro.ru", "phone": "+70847773159"}
0005432305791	901B1D	6585 375253	OLGA NESTEROVA	{"phone": "+70824963426"}
0005432305792	6B4581	0521 228515	SERGEY GERASIMOV	{"email": "gerasimov-s04111983@postgrespro.ru", "phone": "+70453135777"}
0005432305793	985EB7	3575 725789	SERGEY MOROZOV	{"phone": "+70353033308"}
0005432305794	995D7E	3141 188317	VIKTORIYA PAVLOVA	{"phone": "+70874140324"}
0005432305795	4BC0FC	8838 374824	ANATOLIY SHEVCHENKO	{"phone": "+70479289324"}
0005432305796	4BC0FC	4406 344533	OLGA KUDRYASHOVA	{"email": "olga_kudryashova.09081971@postgrespro.ru", "phone": "+70982176211"}
0005432305797	1DB22E	4169 148224	ANDREY FEDOTOV	{"phone": "+70003482815"}
0005432305798	D2B14E	2357 667986	VALERIYA KISELEVA	{"phone": "+70534077364"}
0005432305799	161BAA	6293 939806	ANATOLIY VASILEV	{"phone": "+70237007791"}
0005432305800	161BAA	9887 789522	KRISTINA MIKHAYLOVA	{"phone": "+70371473430"}
0005432305801	F7569E	6628 932159	FANIYA SCHERBAKOVA	{"email": "scherbakova.faniya-07021965@postgrespro.ru", "phone": "+70695452658"}
0005432305802	A0652F	2240 670828	MAKSIM BARANOV	{"email": "baranov-m02071967@postgrespro.ru", "phone": "+70036996511"}
0005432305803	75B792	6231 247043	DARYA ROMANOVA	{"email": "romanova-d_24041974@postgrespro.ru", "phone": "+70039150640"}
0005432305804	A8D028	4772 397004	DMITRIY PAVLOV	{"phone": "+70328374576"}
0005432305805	A8D028	5081 561510	DMITRIY KONOVALOV	{"phone": "+70870993440"}
0005432305806	23604C	9845 683242	ANASTASIYA LAZAREVA	{"email": "a.lazareva_27051966@postgrespro.ru", "phone": "+70941653210"}
0005432305807	23604C	7758 120432	SERGEY ISAEV	{"email": "sergey.isaev-1973@postgrespro.ru", "phone": "+70867474578"}
0005432305808	3DB11E	0208 581105	LYUDMILA FOMINA	{"phone": "+70615421746"}
0005432305809	3DB11E	9043 499715	RINAT PETROV	{"phone": "+70897208118"}
0005432305810	3DB11E	1132 137287	OLGA DAVYDOVA	{"email": "o.davydova-1975@postgrespro.ru", "phone": "+70957203722"}
0005432305811	866D93	1319 087312	YURIY PAVLOV	{"email": "yuriypavlov051974@postgrespro.ru", "phone": "+70407083227"}
0005432305812	ADBF88	5146 276319	OLEG DAVYDOV	{"phone": "+70544431396"}
0005432305813	ADBF88	3237 252548	ANGELINA ZAKHAROVA	{"email": "zakharova-angelina-031969@postgrespro.ru", "phone": "+70446763116"}
0005432305814	ADBF88	8030 162142	TAMARA OSIPOVA	{"email": "t_osipova-22111976@postgrespro.ru", "phone": "+70781148339"}
0005432305815	92DAA5	7735 522828	ROMAN SIDOROV	{"email": "sidorovr_081972@postgrespro.ru", "phone": "+70445042495"}
0005432305816	EEE1CD	2587 740008	TATYANA LUKYANOVA	{"email": "tatyana.lukyanova09071972@postgrespro.ru", "phone": "+70937705579"}
0005432305817	450174	0373 413412	NADEZHDA YAKOVLEVA	{"email": "n-yakovleva20051966@postgrespro.ru", "phone": "+70872100880"}
0005432305818	7F198F	7025 057746	ELENA KUZNECOVA	{"email": "ekuznecova.01081967@postgrespro.ru", "phone": "+70121782145"}
0005432305819	5634CC	0914 591772	ANNA MAKAROVA	{"phone": "+70554017669"}
0005432305820	5032A4	9053 286628	VALERIY PETROV	{"email": "valeriy-petrov.031968@postgrespro.ru", "phone": "+70931542095"}
0005432305821	70E361	9874 114836	DANIIL BELOV	{"phone": "+70231460405"}
0005432327890	D858E8	5381 211777	LYUDMILA GERASIMOVA	{"phone": "+70198429570"}
0005432327891	410FB6	1072 292468	GENNADIY IVANOV	{"phone": "+70652469893"}
0005432327892	410FB6	8546 088596	LIDIYA VOROBEVA	{"email": "vorobeva_l.21031975@postgrespro.ru", "phone": "+70101941777"}
0005432327893	410FB6	3372 145823	NATALYA BARANOVA	{"email": "baranova.natalya081964@postgrespro.ru", "phone": "+70331454721"}
0005432327894	C24D9A	0214 698678	ZINAIDA EGOROVA	{"phone": "+70842650604"}
0005432327895	9E6885	8050 182609	EKATERINA NIKOLAEVA	{"email": "nikolaeva_ekaterina.08111971@postgrespro.ru", "phone": "+70827487622"}
0005432327896	AB571E	6071 011279	IRINA BELYAEVA	{"email": "irina_belyaeva-1980@postgrespro.ru", "phone": "+70556372604"}
0005432327897	AF7479	2816 194923	ALEKSEY ZAYCEV	{"phone": "+70385618085"}
0005432327898	C5DA49	2056 390753	EKATERINA DENISOVA	{"email": "edenisova_04011966@postgrespro.ru", "phone": "+70925219693"}
0005432327899	85271D	8196 938236	NIKOLAY EGOROV	{"phone": "+70360983682"}
0005432327900	85271D	7230 402598	GALINA NAZAROVA	{"phone": "+70134440371"}
0005432327901	D1991E	6656 430962	NINA FROLOVA	{"phone": "+70627681557"}
0005432327902	57EC0C	8183 624741	NADEZHDA KUZMINA	{"email": "nadezhda_kuzmina_1980@postgrespro.ru", "phone": "+70807978283"}
0005432327903	5AF99C	9188 432668	LIDIYA SOROKINA	{"phone": "+70985757838"}
0005432327904	493D46	5273 498186	VYACHESLAV CHERNOV	{"phone": "+70489272407"}
0005432327905	9E52E0	9052 957984	EVDOKIYA POPOVA	{"email": "popovae_29051982@postgrespro.ru", "phone": "+70897170451"}
0005432327906	9E52E0	0423 293339	NINA IVANOVA	{"email": "nina-ivanova_1955@postgrespro.ru", "phone": "+70470967638"}
0005432327907	7D1ED1	0847 415468	SERGEY MIRONOV	{"email": "s_mironov.1974@postgrespro.ru", "phone": "+70517412127"}
0005432327908	FADC9D	8890 090079	ANNA KOZLOVA	{"email": "a_kozlova-1964@postgrespro.ru", "phone": "+70040092330"}
0005432327909	FADC9D	8994 427107	ALEKSANDR KOROLEV	{"phone": "+70344546389"}
0005432327910	111A5F	4085 366528	SERGEY KARPOV	{"phone": "+70309428749"}
0005432327911	D79998	1220 869034	SOFYA TARASOVA	{"email": "sofya.tarasova_1964@postgrespro.ru", "phone": "+70783815236"}
0005432327912	C359E1	8132 887131	VIKTOR IVANOV	{"phone": "+70813028055"}
0005432327913	C359E1	5866 894772	VITALIY SOKOLOV	{"phone": "+70397131318"}
0005432327914	45B5DB	5806 774915	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva.1978@postgrespro.ru", "phone": "+70592845771"}
0005432327915	E9967E	2279 794246	ELENA POPOVA	{"phone": "+70816674338"}
0005432327916	E9967E	0962 477280	IGOR ALEKSANDROV	{"phone": "+70102792902"}
0005432327917	22FA7B	2566 419290	YURIY VASILEV	{"email": "yuriy-vasilev-101969@postgrespro.ru", "phone": "+70291804894"}
0005432327918	22FA7B	1680 604188	GALINA IVANOVA	{"email": "galina.ivanova.13101976@postgrespro.ru", "phone": "+70993412441"}
0005432327919	EFA502	9200 375356	SVETLANA MOROZOVA	{"email": "smorozova-30061966@postgrespro.ru", "phone": "+70110079740"}
0005432327920	DAB75B	1347 249623	NINA KOZLOVA	{"email": "nkozlova.05091971@postgrespro.ru", "phone": "+70084632880"}
0005432327921	DCFD86	7333 052659	SERGEY KAZAKOV	{"email": "sergey-kazakov.27021969@postgrespro.ru", "phone": "+70627517988"}
0005432327922	F84E62	6092 371227	SERGEY KAZAKOV	{"phone": "+70309764904"}
0005432327923	F763EE	3634 000687	TATYANA FILATOVA	{"email": "filatova_tatyana_021976@postgrespro.ru", "phone": "+70380393769"}
0005432327924	F763EE	1839 887356	ANDREY POPOV	{"phone": "+70046258565"}
0005432327925	8867B1	7146 690247	ALENA MELNIKOVA	{"phone": "+70202590633"}
0005432327926	9EA81B	7002 739679	RAISA OVCHINNIKOVA	{"phone": "+70119238145"}
0005432327927	9EA81B	6494 194244	ZHANNA KONDRATEVA	{"email": "zkondrateva.30071975@postgrespro.ru", "phone": "+70011020111"}
0005432327928	29CC5A	4986 606784	LYUBOV ORLOVA	{"phone": "+70536014362"}
0005432327929	29CC5A	7412 927357	NATALYA ROMANOVA	{"email": "romanova.n-06011973@postgrespro.ru", "phone": "+70909055090"}
0005432327930	CA1A11	2436 509612	YAN PETROV	{"email": "yan_petrov1983@postgrespro.ru", "phone": "+70214827557"}
0005432327931	AD150B	1632 032320	OLGA RYABOVA	{"email": "ryabova_olga.16081968@postgrespro.ru", "phone": "+70194290879"}
0005432327932	375965	5216 289251	EVGENIY POPOV	{"phone": "+70725324630"}
0005432327933	375965	0876 385506	EVDOKIYA ZHURAVLEVA	{"email": "e_zhuravleva_051987@postgrespro.ru", "phone": "+70334226261"}
0005432327934	FDD725	3029 827253	EKATERINA KAZAKOVA	{"email": "kazakova.e.07021982@postgrespro.ru", "phone": "+70945158958"}
0005432327935	387E39	4486 286075	YULIYA ARKHIPOVA	{"email": "yarkhipova.061975@postgrespro.ru", "phone": "+70664759267"}
0005432327936	87773D	5739 193190	NIKOLAY DAVYDOV	{"phone": "+70636981141"}
0005432327937	87773D	5767 600375	YURIY FOMIN	{"phone": "+70537141816"}
0005432327938	ED8AA7	6036 245543	ILDAR MOISEEV	{"phone": "+70606777429"}
0005432327939	B49B6D	7438 341402	TAMARA YUDINA	{"email": "yudina-tamara1974@postgrespro.ru", "phone": "+70769226388"}
0005432327940	8241E7	0149 053973	NIKITA IVANOV	{"email": "nikita.ivanov.05011970@postgrespro.ru", "phone": "+70008686667"}
0005432327941	8241E7	5249 448672	ALENA NESTEROVA	{"phone": "+70338961655"}
0005432327942	108510	3085 826578	LEONID RODIONOV	{"email": "rodionovl-111985@postgrespro.ru", "phone": "+70850482006"}
0005432327943	108510	6789 086558	GALINA TIMOFEEVA	{"email": "galina_timofeeva-1970@postgrespro.ru", "phone": "+70635246465"}
0005432327944	C26FDE	7099 152074	VERA BELOVA	{"email": "v.belova.1968@postgrespro.ru", "phone": "+70313604997"}
0005432327945	BBF2F8	3593 044149	NADEZHDA EGOROVA	{"email": "n.egorova-21061968@postgrespro.ru", "phone": "+70360752865"}
0005432327946	D0C8E1	8833 474954	TATYANA NAZAROVA	{"email": "nazarova_t-1965@postgrespro.ru", "phone": "+70762699869"}
0005432327947	8E96A2	2360 965816	ANDREY KOROLEV	{"email": "korolev_andrey16051974@postgrespro.ru", "phone": "+70609254999"}
0005432328116	D85704	3505 763938	LYUDMILA NOVIKOVA	{"phone": "+70132035951"}
0005432327948	AAB242	9514 346135	BORIS SMIRNOV	{"email": "smirnov-boris_1961@postgrespro.ru", "phone": "+70468623433"}
0005432327949	0B219E	3167 411014	ANNA GUSEVA	{"email": "anna.guseva_12101968@postgrespro.ru", "phone": "+70171166238"}
0005432327950	BC2147	9684 410357	VIKTOR RODIONOV	{"email": "viktor-rodionov-1964@postgrespro.ru", "phone": "+70459676885"}
0005432327951	7664B8	8436 804728	LIDIYA FROLOVA	{"email": "frolova-l.1968@postgrespro.ru", "phone": "+70484932363"}
0005432327952	7664B8	4153 120219	MAKSIM KUDRYASHOV	{"phone": "+70803179472"}
0005432327953	08568A	7562 046096	NINA MAKSIMOVA	{"email": "maksimova.n_12041969@postgrespro.ru", "phone": "+70315617122"}
0005432327954	ADA76A	5637 091195	KSENIYA SMIRNOVA	{"email": "ksmirnova-18101977@postgrespro.ru", "phone": "+70771867421"}
0005432327955	ADA76A	2612 071956	OLGA KOMAROVA	{"email": "komarova-olga13041982@postgrespro.ru", "phone": "+70188777964"}
0005432327956	CDC4B5	2859 712495	TAMARA ANISIMOVA	{"email": "anisimovat-1969@postgrespro.ru", "phone": "+70140549965"}
0005432327957	CDC4B5	0683 393984	YURIY IVANOV	{"phone": "+70667429520"}
0005432327958	CDC4B5	9688 266509	MAKSIM PAVLOV	{"email": "maksim-pavlov-051979@postgrespro.ru", "phone": "+70214565164"}
0005432327959	CDC4B5	2435 762468	VASILIY SEMENOV	{"phone": "+70760598174"}
0005432327960	C3DB15	3285 398145	GENNADIY BONDARENKO	{"phone": "+70940359467"}
0005432327961	C3DB15	2334 366892	VLADIMIR GUSEV	{"email": "vladimir_gusev-1971@postgrespro.ru", "phone": "+70090560124"}
0005432327962	DEC167	7182 631544	NINA VOLKOVA	{"phone": "+70595682889"}
0005432327963	6FD0AD	1191 142438	EKATERINA ERMAKOVA	{"email": "e.ermakova1969@postgrespro.ru", "phone": "+70087813685"}
0005432327964	BD05FD	7761 038658	YULIYA AFANASEVA	{"email": "afanasevayuliya_31031963@postgrespro.ru", "phone": "+70267487732"}
0005432327965	9A0886	0144 277586	TATYANA ZHURAVLEVA	{"phone": "+70150211386"}
0005432327966	80D6F9	1887 062371	KONSTANTIN PAVLOV	{"email": "konstantin.pavlov-071971@postgrespro.ru", "phone": "+70732153174"}
0005432327967	80D6F9	8047 390704	POLINA VASILEVA	{"phone": "+70152766184"}
0005432327968	E2E72F	4780 152646	ALEKSANDR DENISOV	{"email": "aleksandrdenisov111964@postgrespro.ru", "phone": "+70471133803"}
0005432327969	E2E72F	9636 398190	YURIY MOROZOV	{"email": "y-morozov-16021973@postgrespro.ru", "phone": "+70977405938"}
0005432327970	E2E72F	9401 826274	NATALYA KOZLOVA	{"phone": "+70562641376"}
0005432327971	3A0F47	7199 178240	NATALYA SCHERBAKOVA	{"phone": "+70475735948"}
0005432327972	77478F	6141 447961	MAKSIM IVANOV	{"email": "maksim.ivanov091980@postgrespro.ru", "phone": "+70505109195"}
0005432327973	77478F	7610 478810	IVAN IVANOV	{"phone": "+70224601643"}
0005432327974	CE3A11	0068 228319	ELENA SERGEEVA	{"email": "esergeeva_29011958@postgrespro.ru", "phone": "+70258278167"}
0005432327975	D0B811	4041 478777	ZINAIDA SCHERBAKOVA	{"email": "zinaida.scherbakova22081963@postgrespro.ru", "phone": "+70550125700"}
0005432327976	D0B811	1880 049063	ELENA KOROLEVA	{"phone": "+70041805113"}
0005432327977	C7EA02	2418 625509	VERA LAZAREVA	{"phone": "+70178714890"}
0005432327978	C7EA02	3624 355613	ELENA SERGEEVA	{"phone": "+70472843660"}
0005432327979	C4A582	2810 454253	ALEKSANDR RODIONOV	{"email": "a.rodionov.1974@postgrespro.ru", "phone": "+70269716975"}
0005432327980	A88471	4229 574427	VLADISLAV SIDOROV	{"email": "vladislav-sidorov.1978@postgrespro.ru", "phone": "+70912185511"}
0005432327981	A88471	7616 405357	LIDIYA MATVEEVA	{"email": "lmatveeva-1965@postgrespro.ru", "phone": "+70385994281"}
0005432327982	A88471	5274 741798	GRIGORIY KRASNOV	{"email": "grigoriy_krasnov041974@postgrespro.ru", "phone": "+70319997617"}
0005432327983	0A6B79	3981 694468	ANATOLIY EGOROV	{"phone": "+70937920385"}
0005432327984	0A6B79	5642 762531	ELENA GORBUNOVA	{"phone": "+70962614707"}
0005432327985	028721	2722 429031	ANASTASIYA EGOROVA	{"phone": "+70916177138"}
0005432327986	9129CD	1093 820450	ANTON ANTONOV	{"phone": "+70625571838"}
0005432327987	9129CD	7380 767819	TATYANA IVANOVA	{"phone": "+70425283432"}
0005432327988	9129CD	4585 299862	NIKOLAY TIMOFEEV	{"email": "ntimofeev_1973@postgrespro.ru", "phone": "+70419149099"}
0005432327989	120188	1674 783393	NATALYA GRISHINA	{"phone": "+70623147434"}
0005432327990	B5DEB4	0866 010771	SERGEY IVANOV	{"phone": "+70207003761"}
0005432327991	35C154	3906 282908	MARIYA FROLOVA	{"email": "m_frolova_031968@postgrespro.ru", "phone": "+70024568156"}
0005432327992	AA8ED6	1980 129858	OLGA IVANOVA	{"phone": "+70329731193"}
0005432327993	FA53B7	7798 155340	DENIS TIKHONOV	{"phone": "+70893758158"}
0005432327994	9123DB	4189 083434	ELENA DMITRIEVA	{"email": "dmitrieva_elena18101974@postgrespro.ru", "phone": "+70571108618"}
0005432327995	5E847D	9827 958076	STANISLAV STEPANOV	{"email": "stepanov.stanislav01121973@postgrespro.ru", "phone": "+70402665392"}
0005432327996	546016	6340 082157	ALEKSANDRA NAZAROVA	{"phone": "+70668371385"}
0005432327997	5EE26E	9361 792821	ARTEM YAKOVLEV	{"phone": "+70241313936"}
0005432327998	BE9F0E	0100 919661	LYUDMILA TIMOFEEVA	{"phone": "+70018950882"}
0005432327999	39A9B6	9618 789772	ALENA MAKAROVA	{"phone": "+70867865554"}
0005432328000	39A9B6	4926 710059	GALINA BORISOVA	{"phone": "+70485498595"}
0005432328001	D21CB2	1387 595299	SERGEY AFANASEV	{"email": "afanasevs.111970@postgrespro.ru", "phone": "+70588536905"}
0005432328002	08B372	7383 758409	PAVEL ZHURAVLEV	{"phone": "+70056352873"}
0005432328003	08B372	7838 251097	IVAN KUZNECOV	{"email": "kuznecov-i_1981@postgrespro.ru", "phone": "+70031115502"}
0005432328004	F96CE5	5066 658031	ELENA CHERNOVA	{"email": "chernova-elena.11021962@postgrespro.ru", "phone": "+70050604220"}
0005432328005	F96CE5	1877 450097	ALEKSANDR ALEKSANDROV	{"phone": "+70669602183"}
0005432328006	F96CE5	2029 145805	ROMAN NIKITIN	{"phone": "+70907023809"}
0005432328007	543F72	5764 978700	PAVEL MAKAROV	{"phone": "+70009147344"}
0005432328008	543F72	9648 206108	VLADIMIR KUDRYASHOV	{"email": "kudryashovv27101977@postgrespro.ru", "phone": "+70014438439"}
0005432328009	3A1059	2389 759316	SHAMIL VOROBEV	{"phone": "+70848868073"}
0005432328010	46333B	0041 736206	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav.031967@postgrespro.ru", "phone": "+70292986558"}
0005432328011	871F5B	1369 538276	ELENA MELNIKOVA	{"email": "melnikova.e.111980@postgrespro.ru", "phone": "+70977212425"}
0005432328012	BF2997	4237 175802	GALINA FILATOVA	{"email": "galina_filatova1978@postgrespro.ru", "phone": "+70179054147"}
0005432328013	FF0EFD	9611 966278	ANGELINA SOLOVEVA	{"phone": "+70820536637"}
0005432328014	FF0EFD	7851 302797	OLEG KUZNECOV	{"phone": "+70114425691"}
0005432328015	51551F	1482 726339	DMITRIY MARTYNOV	{"email": "martynovd13081982@postgrespro.ru", "phone": "+70038744253"}
0005432328016	4A055E	7466 087065	YURIY OSIPOV	{"email": "yuriyosipov-16101973@postgrespro.ru", "phone": "+70134547712"}
0005432328017	4A055E	6829 286238	TATYANA SEMENOVA	{"email": "tatyana_semenova_12011982@postgrespro.ru", "phone": "+70130355196"}
0005432328018	42C006	0980 352187	YULIYA MIKHAYLOVA	{"email": "mikhaylovay-031978@postgrespro.ru", "phone": "+70605098184"}
0005432328019	42C006	9280 483714	VALERIY PETROV	{"email": "valeriy.petrov.061978@postgrespro.ru", "phone": "+70805062930"}
0005432328020	2C9D5F	9195 104398	TAMARA TIKHONOVA	{"email": "t-tikhonova_28121960@postgrespro.ru", "phone": "+70008895229"}
0005432328021	1A6213	1118 032259	LYUDMILA SOKOLOVA	{"email": "l_sokolova.1976@postgrespro.ru", "phone": "+70103623389"}
0005432328022	1A6213	4443 971177	DMITRIY FILIPPOV	{"phone": "+70725328020"}
0005432328023	1A6213	9893 885296	SERGEY PETROV	{"phone": "+70852476766"}
0005432328024	E2C8CB	7646 594610	SERGEY KUZNECOV	{"phone": "+70981684757"}
0005432328025	E2C8CB	2115 708422	YURIY MATVEEV	{"email": "yuriy-matveev_011991@postgrespro.ru", "phone": "+70172196540"}
0005432328026	E2C8CB	6131 580909	NATALYA RODIONOVA	{"phone": "+70806345103"}
0005432328027	9CBA6A	2843 099156	VYACHESLAV KOROLEV	{"phone": "+70147967411"}
0005432328028	9CBA6A	4361 453850	IRINA IVANOVA	{"phone": "+70021561584"}
0005432328029	B89651	5348 725407	ALEKSANDR POPOV	{"email": "aleksandrpopov-081969@postgrespro.ru", "phone": "+70117449385"}
0005432328030	B89651	4629 137117	DMITRIY EGOROV	{"email": "dmitriy-egorov_051965@postgrespro.ru", "phone": "+70151064267"}
0005432328031	B89651	8421 332488	GALINA POLYAKOVA	{"email": "g.polyakova_1967@postgrespro.ru", "phone": "+70001509396"}
0005432328032	F2C7B9	7686 896535	ANATOLIY FROLOV	{"phone": "+70768484415"}
0005432328033	5F5DF1	8136 725122	NIKOLAY SAVELEV	{"phone": "+70609233631"}
0005432328034	5F5DF1	5029 377738	YURIY POPOV	{"email": "y.popov_101974@postgrespro.ru", "phone": "+70347488366"}
0005432328035	595054	1909 982975	VALERIY DAVYDOV	{"email": "valeriy.davydov101968@postgrespro.ru", "phone": "+70253033720"}
0005432328036	6D30FC	6716 980717	ALEKSEY KUZMIN	{"email": "a-kuzmin-081977@postgrespro.ru", "phone": "+70940717682"}
0005432328037	2D5F37	0575 227896	GEORGIY NIKOLAEV	{"phone": "+70033317621"}
0005432328038	2D5F37	8512 654431	VLADIMIR BORISOV	{"email": "vladimir_borisov-011969@postgrespro.ru", "phone": "+70087658168"}
0005432328039	CD8326	5277 500945	VALENTINA TIMOFEEVA	{"email": "timofeevavalentina051965@postgrespro.ru", "phone": "+70841701681"}
0005432328040	CD8326	1831 659286	VALENTINA KAZAKOVA	{"phone": "+70808432609"}
0005432328041	E7AC24	9219 037680	OKSANA GORBUNOVA	{"email": "gorbunova-o051970@postgrespro.ru", "phone": "+70676088247"}
0005432328042	E7AC24	8553 832830	OLEG AFANASEV	{"email": "oleg.afanasev_1974@postgrespro.ru", "phone": "+70682351699"}
0005432328043	125189	1419 338108	ELENA ZOTOVA	{"email": "zotova-elena041979@postgrespro.ru", "phone": "+70988522650"}
0005432328044	725362	7692 476198	VIKTORIYA ANTONOVA	{"phone": "+70832019878"}
0005432328045	725362	7159 064958	NATALYA FROLOVA	{"email": "frolovan_061977@postgrespro.ru", "phone": "+70219000420"}
0005432328046	EC3173	8472 097081	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov-1977@postgrespro.ru", "phone": "+70629377928"}
0005432328047	EC3173	1421 848924	MIKHAIL ALEKSANDROV	{"phone": "+70934262137"}
0005432328048	65BA16	6575 549931	ANATOLIY KUZNECOV	{"email": "kuznecov-a12071980@postgrespro.ru", "phone": "+70471747700"}
0005432328049	65BA16	0845 939468	ALEKSANDR MOISEEV	{"email": "moiseev_aleksandr.1975@postgrespro.ru", "phone": "+70062904343"}
0005432328050	EB2A87	4760 697167	TATYANA GERASIMOVA	{"phone": "+70034624252"}
0005432328051	817D46	8525 819512	SERGEY KUZNECOV	{"email": "s.kuznecov_20111972@postgrespro.ru", "phone": "+70777782771"}
0005432328052	952873	1076 586717	YULIYA POLYAKOVA	{"phone": "+70284889957"}
0005432328053	7F6DA4	4988 379955	MARIYA ABRAMOVA	{"phone": "+70519920071"}
0005432328054	7F6DA4	8755 268124	PAVEL IVANOV	{"email": "ivanov-pavel-1970@postgrespro.ru", "phone": "+70484248590"}
0005432328055	7F6DA4	2515 533354	EVGENIY FOMIN	{"phone": "+70301034787"}
0005432328056	497370	5836 198252	DANILA YAKOVLEV	{"email": "danilayakovlev_1981@postgrespro.ru", "phone": "+70545143009"}
0005432328057	497370	2927 943302	SERGEY KUZMIN	{"phone": "+70162470846"}
0005432328058	4E4FD0	8359 247814	ALEKSEY KOZLOV	{"email": "akozlov_28071967@postgrespro.ru", "phone": "+70563192329"}
0005432328059	07505A	2110 511801	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr-121969@postgrespro.ru", "phone": "+70634484835"}
0005432328060	8C580D	7284 490473	ROMAN OSIPOV	{"phone": "+70657512324"}
0005432328061	8C580D	7013 852484	VLADIMIR SEMENOV	{"phone": "+70014730887"}
0005432328062	389092	2340 835597	VYACHESLAV KUZNECOV	{"phone": "+70159179015"}
0005432328063	389092	1058 691197	ZINAIDA IVANOVA	{"email": "zinaida_ivanova.1966@postgrespro.ru", "phone": "+70931656728"}
0005432328064	F802F7	2571 130070	VITALIY IVANOV	{"phone": "+70191969073"}
0005432328065	F802F7	9461 410207	TATYANA VOLKOVA	{"email": "volkova.t.081969@postgrespro.ru", "phone": "+70434059594"}
0005432328066	A99B80	2434 602896	TATYANA YUDINA	{"email": "t_yudina-06111960@postgrespro.ru", "phone": "+70341865847"}
0005432328067	568A6C	1551 516660	ANASTASIYA FEDOROVA	{"email": "fedorova-anastasiya-121973@postgrespro.ru", "phone": "+70485182000"}
0005432328068	D5DF12	8228 598489	OLGA FEDOROVA	{"phone": "+70352010358"}
0005432328069	D6AEAE	2191 470196	SERGEY IVANOV	{"email": "sergey_ivanov_17081974@postgrespro.ru", "phone": "+70322804882"}
0005432328070	6A579E	2748 123971	VALERIY ALEKSANDROV	{"phone": "+70545067700"}
0005432328071	C579BE	8737 499450	YURIY POPOV	{"phone": "+70293426480"}
0005432328072	CC692C	1915 371158	IRINA TARASOVA	{"email": "irina-tarasova.1976@postgrespro.ru", "phone": "+70464817437"}
0005432328073	BC2424	5799 724224	MIKHAIL VLASOV	{"phone": "+70116992352"}
0005432328074	000A39	8140 079977	VALERIY SIDOROV	{"email": "vsidorov-05011965@postgrespro.ru", "phone": "+70887177547"}
0005432328075	3F7AA5	7197 902408	EVGENIY MOROZOV	{"phone": "+70117134058"}
0005432328076	3F7AA5	7619 556574	IVAN NIKOLAEV	{"phone": "+70039297159"}
0005432328077	1C84E7	0617 270388	ALLA YAKOVLEVA	{"email": "alla-yakovleva26061975@postgrespro.ru", "phone": "+70404178534"}
0005432328078	DA5585	5905 123281	ANDREY TIMOFEEV	{"phone": "+70823449645"}
0005432328079	773673	8155 070079	EVGENIY ALEKSEEV	{"phone": "+70136101353"}
0005432328080	9CCD60	7430 129791	OLGA KUDRYASHOVA	{"phone": "+70308632420"}
0005432328081	9ACE23	6781 184034	ALEKSANDR STEPANOV	{"email": "a_stepanov-111966@postgrespro.ru", "phone": "+70045223435"}
0005432328082	D02672	1231 819014	SVETLANA NIKOLAEVA	{"email": "nikolaevasvetlana22111974@postgrespro.ru", "phone": "+70958309059"}
0005432328083	AF6D0A	1944 248017	VLADIMIR SMIRNOV	{"phone": "+70568353834"}
0005432328084	AF6D0A	7336 395361	SERGEY KRASNOV	{"phone": "+70292624691"}
0005432328085	2C2547	0094 140367	NIKOLAY ISAEV	{"email": "isaevn_061975@postgrespro.ru", "phone": "+70369235069"}
0005432328086	A1C7B7	7038 299500	TAISIYA TIKHONOVA	{"phone": "+70033976639"}
0005432328087	FF1965	6298 549916	LYUBOV NOVIKOVA	{"phone": "+70402729578"}
0005432328088	4E464D	0138 719076	VERA KISELEVA	{"email": "kiselevavera121963@postgrespro.ru", "phone": "+70936605816"}
0005432328089	4E464D	3397 582719	ELENA MAKAROVA	{"email": "elenamakarova-1987@postgrespro.ru", "phone": "+70535668918"}
0005432328090	4E464D	1674 540472	DANIL SOKOLOV	{"email": "sokolovdanil-041977@postgrespro.ru", "phone": "+70593224442"}
0005432328091	F64876	2334 909146	ELENA ISAEVA	{"email": "e-isaeva.021965@postgrespro.ru", "phone": "+70918094145"}
0005432328092	F64876	5725 359366	ANNA KALININA	{"phone": "+70676942550"}
0005432328093	50BABB	1724 059252	OLGA SCHERBAKOVA	{"phone": "+70504316838"}
0005432328094	BA4F61	3156 024146	OLGA NOVIKOVA	{"phone": "+70455113241"}
0005432328095	6A5310	2305 808637	DENIS KUDRYASHOV	{"email": "kudryashov-denis.02071962@postgrespro.ru", "phone": "+70791819166"}
0005432328096	6A5310	0773 296781	ARTEM IVANOV	{"email": "artemivanov1975@postgrespro.ru", "phone": "+70877202614"}
0005432328097	A96433	7160 125572	DMITRIY ALEKSEEV	{"email": "alekseevd-31071971@postgrespro.ru", "phone": "+70893957690"}
0005432328098	E91BB0	9433 902928	ILYA AFANASEV	{"phone": "+70820675632"}
0005432328099	E91BB0	8940 773959	LYUDMILA ALEKSEEVA	{"email": "lyudmilaalekseeva_101965@postgrespro.ru", "phone": "+70884977214"}
0005432328100	48B8D0	1330 053777	ANNA TIMOFEEVA	{"email": "timofeevaanna-1970@postgrespro.ru", "phone": "+70218399095"}
0005432328101	48B8D0	8562 893984	MARIYA KOROLEVA	{"phone": "+70994600576"}
0005432328102	9E0B10	6980 860244	SVETLANA GRISHINA	{"email": "grishina-s.1962@postgrespro.ru", "phone": "+70709893613"}
0005432328103	9E5184	7028 804154	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev_1968@postgrespro.ru", "phone": "+70442997185"}
0005432328104	9E5184	9868 928791	TATYANA IVANOVA	{"email": "ivanova.tatyana031973@postgrespro.ru", "phone": "+70236902523"}
0005432328105	07696F	7903 531808	EVGENIY SOKOLOV	{"phone": "+70829879450"}
0005432328106	07696F	7817 389121	ALBINA SEMENOVA	{"phone": "+70391445572"}
0005432328107	07696F	0045 805793	MILENA MELNIKOVA	{"phone": "+70775663525"}
0005432328108	07696F	8674 782101	ALBINA ABRAMOVA	{"phone": "+70998605674"}
0005432328109	CD2922	4501 815457	IRINA GERASIMOVA	{"phone": "+70030454692"}
0005432328110	E40F8B	8763 378385	VADIM KRASNOV	{"email": "vadim.krasnov_1980@postgrespro.ru", "phone": "+70379003045"}
0005432328111	2369F6	3448 073432	IVAN ZHUKOV	{"phone": "+70839780127"}
0005432328112	A30D8C	2100 922491	BORIS KUZNECOV	{"phone": "+70119259423"}
0005432328113	A30D8C	6325 874592	ANATOLIY SMIRNOV	{"phone": "+70667324693"}
0005432328114	033D40	8168 853755	LYUDMILA ZAKHAROVA	{"phone": "+70503883968"}
0005432328115	033D40	5306 701579	VADIM NIKITIN	{"phone": "+70492379679"}
0005432328117	94FFEF	3621 156896	SERGEY IVANOV	{"email": "ivanov_sergey-14111968@postgrespro.ru", "phone": "+70343286843"}
0005432328118	7A7AE8	8076 586828	SERGEY MIKHAYLOV	{"email": "s-mikhaylov.1975@postgrespro.ru", "phone": "+70134080907"}
0005432328119	54552B	3458 242512	ALEKSEY MARTYNOV	{"phone": "+70880728877"}
0005432328120	C077EA	3437 536697	GENNADIY BELOV	{"email": "g-belov_29051970@postgrespro.ru", "phone": "+70565062178"}
0005432328121	5B678E	1366 360703	SERGEY KUZNECOV	{"phone": "+70450713336"}
0005432328122	CA357E	5500 942256	VIKTOR CHERNOV	{"phone": "+70100278132"}
0005432328123	CA357E	0202 966425	VERONIKA MEDVEDEVA	{"email": "veronika-medvedeva-101971@postgrespro.ru", "phone": "+70718134597"}
0005432328124	01679D	9125 477714	GENNADIY ANTONOV	{"phone": "+70990919244"}
0005432328125	A4C62D	6935 375610	ILDUS SMIRNOV	{"phone": "+70408225461"}
0005432328126	1CB05F	4591 287062	ALEKSANDR MOROZOV	{"email": "morozov_a_111984@postgrespro.ru", "phone": "+70072586926"}
0005432328127	993731	3863 065542	ALEKSEY IVANOV	{"email": "ivanova121972@postgrespro.ru", "phone": "+70366395957"}
0005432328128	34B19F	8880 329550	NINA FEDOROVA	{"email": "fedorova_nina1980@postgrespro.ru", "phone": "+70875271871"}
0005432328129	9425C6	0158 054795	YURIY DAVYDOV	{"phone": "+70668589730"}
0005432328130	396E6F	4973 413805	ALINA VASILEVA	{"phone": "+70249291688"}
0005432328131	396E6F	3965 918818	ARMEN FEDOROV	{"email": "a.fedorov121973@postgrespro.ru", "phone": "+70725745722"}
0005432328132	D49810	6204 362363	NATALYA TARASOVA	{"email": "n.tarasova081989@postgrespro.ru", "phone": "+70964436936"}
0005432328133	FEDF4E	7014 320252	NATALYA FILATOVA	{"phone": "+70925296582"}
0005432328134	F05522	6647 356534	NATALYA LEBEDEVA	{"phone": "+70315705107"}
0005432328135	1A4CD8	2939 881415	VLADIMIR SMIRNOV	{"email": "smirnov_v_021964@postgrespro.ru", "phone": "+70372793695"}
0005432328136	1A4CD8	3042 694668	VIKTORIYA VASILEVA	{"phone": "+70556250603"}
0005432328137	1A4CD8	6887 145808	KSENIYA KISELEVA	{"phone": "+70353533579"}
0005432328138	FCBA9D	1742 065568	IRINA KULIKOVA	{"email": "ikulikova.1976@postgrespro.ru", "phone": "+70689844897"}
0005432328139	7F8E2D	1239 834213	LYUBOV POTAPOVA	{"phone": "+70838629894"}
0005432328140	93A2DB	8510 967718	KSENIYA ABRAMOVA	{"email": "kseniya_abramova1966@postgrespro.ru", "phone": "+70545526887"}
0005432328141	5D7CBB	4547 464822	TATYANA NIKIFOROVA	{"phone": "+70060247784"}
0005432328142	5D7CBB	3171 677312	SVETLANA KOVALEVA	{"phone": "+70271831913"}
0005432328143	F73983	8451 337172	VIKTOR FOMIN	{"phone": "+70137517726"}
0005432328144	7CFC31	1616 847673	OLGA KUDRYASHOVA	{"phone": "+70399240921"}
0005432328145	7CFC31	2870 132931	VLADIMIR RODIONOV	{"email": "rodionov-v.10061980@postgrespro.ru", "phone": "+70810434654"}
0005432328146	67DDC0	1956 566881	TATYANA LOGINOVA	{"email": "tatyanaloginova_1965@postgrespro.ru", "phone": "+70215426588"}
0005432328147	67DDC0	8344 612264	ANASTASIYA KOZLOVA	{"phone": "+70322152336"}
0005432328148	FE80AC	5395 448856	EKATERINA EGOROVA	{"email": "e.egorova_1983@postgrespro.ru", "phone": "+70416271099"}
0005432328149	FE80AC	6302 216301	OLGA SOKOLOVA	{"email": "sokolova.olga_1973@postgrespro.ru", "phone": "+70995859254"}
0005432328150	8B8668	9348 792054	IRINA MATVEEVA	{"email": "i.matveeva-1986@postgrespro.ru", "phone": "+70250933742"}
0005432328151	B9FEC2	6864 495773	GALINA ANISIMOVA	{"email": "g.anisimova_031978@postgrespro.ru", "phone": "+70866135353"}
0005432328152	77627A	1941 225954	ALEKSANDR RODIONOV	{"email": "rodionov-a_041980@postgrespro.ru", "phone": "+70291957478"}
0005432328153	49F4A3	1357 432310	VLADIMIR STEPANOV	{"phone": "+70604616445"}
0005432328154	CF2BEB	7222 725836	ALEKSANDRA NAZAROVA	{"phone": "+70494676249"}
0005432328155	6932DF	6094 104609	ANATOLIY KUZNECOV	{"email": "kuznecova121980@postgrespro.ru", "phone": "+70337685276"}
0005432328156	6932DF	4130 367017	ANDREY IVANOV	{"email": "ivanov.andrey.061977@postgrespro.ru", "phone": "+70159245340"}
0005432328157	9DE9D9	3714 046018	RAFAIL ABRAMOV	{"email": "abramovr1969@postgrespro.ru", "phone": "+70286261489"}
0005432328158	336EA9	1768 321423	SVETLANA ZHURAVLEVA	{"email": "szhuravleva_03081973@postgrespro.ru", "phone": "+70459150258"}
0005432328159	336EA9	8167 649610	ELENA VOLKOVA	{"email": "elena-volkova-031968@postgrespro.ru", "phone": "+70632733268"}
0005432328160	336EA9	8486 578570	ANASTASIYA KUZNECOVA	{"phone": "+70408568017"}
0005432328161	21477D	8630 101081	KLAVDIYA VOROBEVA	{"email": "vorobeva-klavdiya-10051981@postgrespro.ru", "phone": "+70087613219"}
0005432328162	E403A7	3090 405676	ALEKSEY ORLOV	{"email": "orlov-aleksey-1968@postgrespro.ru", "phone": "+70230261769"}
0005432328163	151432	4064 048670	ANDREY STEPANOV	{"email": "andrey.stepanov061972@postgrespro.ru", "phone": "+70186442538"}
0005432328164	E6A0B4	0696 209058	VLADIMIR SOLOVEV	{"phone": "+70900106024"}
0005432328165	E6A0B4	0617 414415	NATALYA DENISOVA	{"email": "natalya_denisova.111977@postgrespro.ru", "phone": "+70602468496"}
0005432328166	0CC1B8	5211 270021	IRINA MARTYNOVA	{"phone": "+70465523659"}
0005432328167	7409AA	8307 973912	GALINA KONOVALOVA	{"email": "galinakonovalova1976@postgrespro.ru", "phone": "+70751323902"}
0005432328168	BE89DE	4382 577894	IVAN KONOVALOV	{"phone": "+70246046006"}
0005432328169	F1E14C	4819 491819	PETR KULIKOV	{"phone": "+70157131069"}
0005432328170	623662	7995 558141	SVETLANA LEBEDEVA	{"email": "lebedevasvetlana101971@postgrespro.ru", "phone": "+70390655453"}
0005432328171	D5D916	2621 657063	OLEG AFANASEV	{"email": "afanasev-oleg.29051965@postgrespro.ru", "phone": "+70829641220"}
0005432328172	D5D916	6746 564294	NIKOLAY NIKITIN	{"phone": "+70760484096"}
0005432328173	0FEEDA	3997 606138	NATALYA SMIRNOVA	{"phone": "+70067171812"}
0005432328174	745B20	9006 956404	ELENA FADEEVA	{"phone": "+70134562247"}
0005432328175	F16340	8307 713184	VALENTINA VOLKOVA	{"email": "volkova_v.041966@postgrespro.ru", "phone": "+70035209874"}
0005432328176	6A7C8E	6679 496636	MARIYA SOLOVEVA	{"email": "soloveva_m.111968@postgrespro.ru", "phone": "+70472243165"}
0005432328177	E4C822	1389 326402	VIKTOR FEDOROV	{"email": "fedorov-v1966@postgrespro.ru", "phone": "+70495429985"}
0005432328178	E4C822	7045 871449	PAVEL CHERNOV	{"email": "pavel-chernov-23101967@postgrespro.ru", "phone": "+70207554572"}
0005432328179	A624C9	4961 898245	KSENIYA KUZNECOVA	{"email": "kseniya_kuznecova_09081968@postgrespro.ru", "phone": "+70756720068"}
0005432328180	A624C9	1324 034035	ALENA ALEKSANDROVA	{"email": "alena-aleksandrova-1976@postgrespro.ru", "phone": "+70788545948"}
0005432328181	A624C9	8357 223421	MIKHAIL KUZNECOV	{"email": "m.kuznecov-031972@postgrespro.ru", "phone": "+70229373239"}
0005432328182	9BEEA7	4266 529745	LYUBOV CHERNOVA	{"phone": "+70391449090"}
0005432328183	42B200	0608 440151	NINA NOVIKOVA	{"email": "novikova-nina1960@postgrespro.ru", "phone": "+70500220213"}
0005432328184	FA8703	0684 119079	ANATOLIY SMIRNOV	{"phone": "+70979805657"}
0005432328185	FA8703	8594 250849	ELENA GUSEVA	{"phone": "+70632098675"}
0005432328186	44A08D	9976 662787	KLAVDIYA MATVEEVA	{"email": "matveeva.k-071971@postgrespro.ru", "phone": "+70425989529"}
0005432328187	CF7A67	2748 945067	MARINA IVANOVA	{"email": "mivanova_1978@postgrespro.ru", "phone": "+70449276795"}
0005432328188	ACF598	1336 446301	ELENA BELOVA	{"email": "belova.e-031981@postgrespro.ru", "phone": "+70443167671"}
0005432328189	ACF598	1152 109813	NADEZHDA BOGDANOVA	{"phone": "+70297117276"}
0005432328190	4F7270	7566 842628	VIKTOR MAKAROV	{"phone": "+70306574356"}
0005432328191	023151	3681 982824	ALEKSANDRA NIKITINA	{"phone": "+70948733344"}
0005432328192	1DF2F6	7581 858973	VASILIY STEPANOV	{"email": "vasiliy_stepanov1981@postgrespro.ru", "phone": "+70483783930"}
0005432328193	055284	1755 324260	SERGEY POPOV	{"phone": "+70640524555"}
0005432328194	E05335	7369 493386	ALFIYA IVANOVA	{"phone": "+70634268538"}
0005432328195	E05335	2340 683454	YULIYA AFANASEVA	{"email": "yuliyaafanaseva-1971@postgrespro.ru", "phone": "+70339036578"}
0005432328196	E05335	4789 346976	PETR MEDVEDEV	{"email": "medvedev-petr111973@postgrespro.ru", "phone": "+70199378033"}
0005432328197	B3B78A	1137 285687	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev041961@postgrespro.ru", "phone": "+70053266318"}
0005432328198	59A58C	7152 279272	ELENA KISELEVA	{"email": "kiseleva_elena1977@postgrespro.ru", "phone": "+70293786576"}
0005432328199	59A58C	2376 934274	MATVEY KUZNECOV	{"email": "kuznecovmatvey_091979@postgrespro.ru", "phone": "+70921774944"}
0005432328200	2BC0E7	2558 150980	INNA VASILEVA	{"email": "vasileva.inna071973@postgrespro.ru", "phone": "+70433782149"}
0005432328201	2BC0E7	2179 108860	EVGENIY SOLOVEV	{"email": "soloveve-1971@postgrespro.ru", "phone": "+70874739159"}
0005432328202	3F09ED	1828 335991	VALENTINA BELYAEVA	{"phone": "+70483806106"}
0005432328203	1DE2CB	1455 706305	PAVEL GUSEV	{"phone": "+70233232569"}
0005432328204	43926D	8891 333061	SAMVEL SCHERBAKOV	{"phone": "+70079882355"}
0005432328205	847EBE	9525 512191	OLGA ALEKSEEVA	{"phone": "+70780540363"}
0005432328206	32C510	1335 507352	ANDREY YAKOVLEV	{"email": "andreyyakovlev1969@postgrespro.ru", "phone": "+70967274929"}
0005432328207	ADBFD1	3181 629834	VALENTIN ALEKSEEV	{"email": "valentin_alekseev_09031975@postgrespro.ru", "phone": "+70577277827"}
0005432328208	4AA207	8340 157317	VYACHESLAV MIKHAYLOV	{"phone": "+70102792965"}
0005432328209	8F8477	8745 876542	MARINA MOROZOVA	{"phone": "+70173122361"}
0005432328210	3EEAC4	0720 819532	VALENTINA EFIMOVA	{"phone": "+70835595900"}
0005432328211	773C8A	9660 457420	VERA ROMANOVA	{"email": "romanovavera_06051974@postgrespro.ru", "phone": "+70624101661"}
0005432328212	17FD6B	9840 810640	NINA BELOVA	{"email": "belova-nina_1972@postgrespro.ru", "phone": "+70658738173"}
0005432328213	20FC41	5572 504021	VLADIMIR MEDVEDEV	{"email": "medvedev_vladimir1982@postgrespro.ru", "phone": "+70534080958"}
0005432328214	20FC41	0898 501872	ANASTASIYA MEDVEDEVA	{"email": "anastasiya-medvedeva-101969@postgrespro.ru", "phone": "+70893938341"}
0005432328215	07C07A	0869 470288	MARIYA ZAYCEVA	{"email": "zayceva-mariya1968@postgrespro.ru", "phone": "+70601460971"}
0005432328216	07C07A	7308 302932	SERGEY FILIPPOV	{"phone": "+70217309098"}
0005432328217	B1B030	2737 505866	VLADIMIR GRIGOREV	{"phone": "+70302311060"}
0005432328218	091FB8	5112 481681	ALEKSANDR ROMANOV	{"phone": "+70237700904"}
0005432328219	96EA2C	8516 814575	VLADIMIR BONDARENKO	{"phone": "+70089722958"}
0005432328220	6C5A12	0260 812813	TATYANA KOZLOVA	{"email": "t_kozlova-03061974@postgrespro.ru", "phone": "+70532909131"}
0005432328221	26D45B	8192 949250	TATYANA BELOVA	{"phone": "+70208249237"}
0005432328222	26D45B	8530 141884	VLADIMIR VASILEV	{"email": "vasilev-v1978@postgrespro.ru", "phone": "+70838761640"}
0005432328223	796E95	3809 159603	OLGA ABRAMOVA	{"phone": "+70773413474"}
0005432328224	796E95	3443 306426	VALENTINA MATVEEVA	{"phone": "+70746707669"}
0005432328225	796E95	9608 345325	NAILYA MEDVEDEVA	{"phone": "+70196930028"}
0005432328226	BE351D	4852 600082	DMITRIY SHEVCHENKO	{"email": "shevchenko.d.06031973@postgrespro.ru", "phone": "+70213942312"}
0005432328227	BE351D	1865 714170	ANDREY MOISEEV	{"email": "moiseev-andrey121980@postgrespro.ru", "phone": "+70377637967"}
0005432328228	E309F5	8941 176084	VLADIMIR SOROKIN	{"phone": "+70699751492"}
0005432328229	5E6953	7363 242143	LYUBOV IVANOVA	{"email": "l-ivanova_06031968@postgrespro.ru", "phone": "+70325914613"}
0005432328230	A662B2	7473 045488	OKSANA VASILEVA	{"email": "vasilevaoksana-15081975@postgrespro.ru", "phone": "+70491065655"}
0005432328231	A662B2	5447 645356	VIKTOR KUZNECOV	{"phone": "+70908288022"}
0005432328232	830710	8394 263012	DMITRIY OSIPOV	{"email": "osipovdmitriy_06041977@postgrespro.ru", "phone": "+70023711317"}
0005432328233	830710	4300 370463	IVAN VASILEV	{"phone": "+70458285814"}
0005432328234	8AFE75	3550 916671	ELENA POPOVA	{"email": "e.popova-051966@postgrespro.ru", "phone": "+70226361302"}
0005432328235	8AFE75	4523 312177	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev-1976@postgrespro.ru", "phone": "+70765446653"}
0005432328236	0501DE	4190 941958	MARINA ANTONOVA	{"email": "antonovam-1967@postgrespro.ru", "phone": "+70676977058"}
0005432328237	1C65DC	5990 307441	DANIIL GORBUNOV	{"phone": "+70345565436"}
0005432328238	F2A149	4878 713685	VIKTOR KISELEV	{"phone": "+70679233009"}
0005432328239	76E85C	3216 746438	ANASTASIYA ANDREEVA	{"email": "andreevaanastasiya-11031974@postgrespro.ru", "phone": "+70914683184"}
0005432328240	209F62	5980 513342	MARINA BELYAEVA	{"phone": "+70299026231"}
0005432328241	D147D9	4005 006068	NATALYA IVANOVA	{"email": "natalya_ivanova-061969@postgrespro.ru", "phone": "+70677510201"}
0005432328242	D147D9	1795 311590	YULIYA FILIPPOVA	{"email": "y.filippova_1966@postgrespro.ru", "phone": "+70108607039"}
0005432328243	D93CC0	9298 517876	TATYANA NESTEROVA	{"email": "t.nesterova.081973@postgrespro.ru", "phone": "+70116503281"}
0005432328244	17C4CF	4341 132470	NADEZHDA CHERNOVA	{"email": "n-chernova_021978@postgrespro.ru", "phone": "+70955565782"}
0005432328245	F4376B	0137 774960	ALEKSEY MIRONOV	{"email": "aleksey_mironov.1964@postgrespro.ru", "phone": "+70848475148"}
0005432328246	F4376B	4847 810592	ALEKSEY KUZNECOV	{"email": "a.kuznecov-1979@postgrespro.ru", "phone": "+70376724937"}
0005432328247	86BE58	0144 923397	PETR ISAEV	{"email": "isaevpetr-081980@postgrespro.ru", "phone": "+70909959284"}
0005432328248	6FA77E	0419 729431	VARVARA KISELEVA	{"phone": "+70244339856"}
0005432328249	6FA77E	3515 379341	STEPAN POPOV	{"phone": "+70835409778"}
0005432328250	6404A9	8059 103269	EVGENIY KISELEV	{"phone": "+70459128555"}
0005432328251	0E3F23	8494 403181	ALEKSANDR ANTONOV	{"email": "antonov-a081978@postgrespro.ru", "phone": "+70362041176"}
0005432328252	57778B	6856 246463	VASILIY GRIGOREV	{"email": "grigorev_vasiliy02041967@postgrespro.ru", "phone": "+70334877851"}
0005432328253	57778B	5057 594731	BORIS ANTONOV	{"phone": "+70340336107"}
0005432328254	44828E	3964 636523	PAVEL SCHERBAKOV	{"email": "scherbakovpavel.28011964@postgrespro.ru", "phone": "+70145153260"}
0005432328255	14C188	0977 896398	ALEKSEY NIKOLAEV	{"email": "anikolaev13121977@postgrespro.ru", "phone": "+70861107268"}
0005432328256	5E8969	1463 647592	IRINA FEDOROVA	{"phone": "+70258051877"}
0005432328257	3D3063	3335 001459	MARINA NAZAROVA	{"phone": "+70234738200"}
0005432328258	E1A045	4705 632497	ALEKSANDR PETROV	{"email": "petrov.aleksandr.1973@postgrespro.ru", "phone": "+70707963126"}
0005432328259	D2D7EE	2748 531882	YURIY KUZNECOV	{"email": "ykuznecov1969@postgrespro.ru", "phone": "+70008547447"}
0005432328260	D2D7EE	9013 483524	SVETLANA ZOTOVA	{"phone": "+70014263509"}
0005432328261	CBE6A7	3314 670821	ALEKSEY ANDREEV	{"email": "a.andreev.1965@postgrespro.ru", "phone": "+70957578044"}
0005432328262	CBE6A7	4193 166330	TAMARA LEBEDEVA	{"phone": "+70032429440"}
0005432328263	9EE6FE	9596 327547	NADEZHDA STEPANOVA	{"phone": "+70449066223"}
0005432328264	767B89	6305 717089	ZULFIYA KUZNECOVA	{"email": "kuznecova.z-1973@postgrespro.ru", "phone": "+70623011412"}
0005432328265	F39BDF	2970 784514	NATALYA POLYAKOVA	{"email": "polyakova_natalya021963@postgrespro.ru", "phone": "+70392960624"}
0005432328266	29EFDC	9718 798346	VLADIMIR KONOVALOV	{"email": "konovalov-vladimir.1969@postgrespro.ru", "phone": "+70954193101"}
0005432328267	29EFDC	6799 078254	DARYA MAKAROVA	{"email": "daryamakarova.121971@postgrespro.ru", "phone": "+70355498566"}
0005432328268	29EFDC	5194 818059	ALEKSEY RODIONOV	{"email": "arodionov_021970@postgrespro.ru", "phone": "+70846543666"}
0005432328269	3DDFD5	9036 838466	VALENTINA KOROLEVA	{"email": "koroleva.v27091963@postgrespro.ru", "phone": "+70150944911"}
0005432328270	97EBF2	2475 154356	IVAN MIKHAYLOV	{"email": "mikhaylovivan_08011968@postgrespro.ru", "phone": "+70632758086"}
0005432328271	A6A070	5996 260743	NATALYA TARASOVA	{"email": "n_tarasova021976@postgrespro.ru", "phone": "+70359745497"}
0005432328272	DBCA86	1952 249467	LIDIYA POPOVA	{"email": "popova.lidiya1967@postgrespro.ru", "phone": "+70009567481"}
0005432328273	A62686	4221 910924	ALEKSANDR NAZAROV	{"email": "nazarov-a1974@postgrespro.ru", "phone": "+70313099260"}
0005432328274	9E865A	8648 939865	VLADISLAV POPOV	{"phone": "+70741724081"}
0005432328275	9E865A	9394 216719	INESSA MATVEEVA	{"email": "i-matveeva1976@postgrespro.ru", "phone": "+70419730822"}
0005432328276	2AE694	4295 282559	KARINA ZAKHAROVA	{"phone": "+70458131070"}
0005432328277	E34A99	4432 576786	NIKITA SOROKIN	{"email": "nikita_sorokin_111966@postgrespro.ru", "phone": "+70361749093"}
0005432328278	A7DD41	9914 294368	EGOR NAUMOV	{"email": "naumov_e_051970@postgrespro.ru", "phone": "+70954059295"}
0005432328279	A7DD41	6115 152886	BORIS TIMOFEEV	{"phone": "+70055431904"}
0005432328280	5F5A36	8276 223772	ALEKSANDRA FEDOROVA	{"email": "afedorova011963@postgrespro.ru", "phone": "+70699259541"}
0005432328281	F51EF7	9844 409100	NIKOLAY PETROV	{"phone": "+70375240884"}
0005432328282	F51EF7	9970 851604	ALEKSANDR ANDREEV	{"email": "a_andreev.06011973@postgrespro.ru", "phone": "+70219139997"}
0005432328283	CF4A42	6043 015726	EKATERINA GAVRILOVA	{"phone": "+70314614525"}
0005432328284	CF4A42	8198 937616	YURIY EGOROV	{"phone": "+70200009746"}
0005432328285	1F173E	6871 261147	EVGENIY NAUMOV	{"phone": "+70424768532"}
0005432328286	82435E	2272 796950	EVGENIY SEMENOV	{"phone": "+70198598826"}
0005432328287	DF995F	7600 884618	TATYANA ANDREEVA	{"phone": "+70061768321"}
0005432328288	CE1B61	4721 965716	EKATERINA IVANOVA	{"email": "ekaterinaivanova_19071963@postgrespro.ru", "phone": "+70279049949"}
0005432328289	99E423	7391 832550	MIKHAIL SEMENOV	{"email": "mikhail-semenov.111971@postgrespro.ru", "phone": "+70077126157"}
0005432328290	EAA59E	5453 804204	BORIS ROMANOV	{"phone": "+70635709421"}
0005432328291	EAA59E	8895 068681	NADEZHDA FILIPPOVA	{"phone": "+70289958850"}
0005432328292	EAA59E	5673 594918	ANASTASIYA IVANOVA	{"email": "aivanova.061968@postgrespro.ru", "phone": "+70933155406"}
0005432328293	4DC42E	2438 150726	NATALYA IVANOVA	{"email": "n_ivanova-19061975@postgrespro.ru", "phone": "+70864850951"}
0005432328294	B591AC	9634 184549	VIKTOR STEPANOV	{"email": "stepanovv1975@postgrespro.ru", "phone": "+70614366998"}
0005432328295	B10CA2	6945 338203	MIKHAIL IVANOV	{"email": "m-ivanov.041965@postgrespro.ru", "phone": "+70903498004"}
0005432328296	9D3CE2	4513 289660	LYUDMILA LUKYANOVA	{"email": "lukyanova_l_21091960@postgrespro.ru", "phone": "+70285758130"}
0005432328297	6504CB	3358 050063	EKATERINA IVANOVA	{"phone": "+70353905217"}
0005432328298	0F85DA	0416 147025	ILYA MAKAROV	{"phone": "+70043023448"}
0005432328299	0F85DA	5711 561212	GALINA KUZMINA	{"phone": "+70720428552"}
0005432328300	FDD944	1641 501471	ANNA VOLKOVA	{"phone": "+70168923784"}
0005432328301	FDD944	6558 436380	KRISTINA TARASOVA	{"email": "k_tarasova.28031970@postgrespro.ru", "phone": "+70581797013"}
0005432328302	FDD944	0914 211342	IRINA SIDOROVA	{"email": "sidorova.i_1956@postgrespro.ru", "phone": "+70438545796"}
0005432328303	D72650	9280 882251	OKSANA MIRONOVA	{"phone": "+70518933601"}
0005432328304	A3F80E	9595 451713	ANTON SIDOROV	{"email": "sidorova_20091974@postgrespro.ru", "phone": "+70597161120"}
0005432328305	A3F80E	7809 001333	ALEKSANDR ALEKSEEV	{"email": "a_alekseev_021979@postgrespro.ru", "phone": "+70502578661"}
0005432328306	A3F80E	3160 571101	NINA SOKOLOVA	{"email": "sokolova-n26121971@postgrespro.ru", "phone": "+70610589557"}
0005432328307	B044BD	8090 427379	MARIYA SIDOROVA	{"phone": "+70640937163"}
0005432328308	86A028	1935 830321	OKSANA SMIRNOVA	{"phone": "+70747844750"}
0005432328309	6576EE	7549 798497	MARGARITA KOMAROVA	{"phone": "+70812330151"}
0005432328310	F72E31	2201 547439	MARINA KOZLOVA	{"email": "marina-kozlova22071979@postgrespro.ru", "phone": "+70451407537"}
0005432328311	F72E31	1733 597640	GULSINA ARKHIPOVA	{"phone": "+70583073446"}
0005432328312	F72E31	5421 055082	EVGENIY DMITRIEV	{"email": "dmitriev.e_07011980@postgrespro.ru", "phone": "+70693347384"}
0005432328313	63BFAB	2244 081835	VIKTOR KUZNECOV	{"email": "kuznecov-viktor_021965@postgrespro.ru", "phone": "+70932608212"}
0005432328314	70656A	7571 554773	DMITRIY YAKOVLEV	{"email": "yakovlev-dmitriy24031959@postgrespro.ru", "phone": "+70013116979"}
0005432328315	978A00	5302 500278	LYUDMILA ZHUKOVA	{"email": "lyudmila-zhukova_1974@postgrespro.ru", "phone": "+70274950616"}
0005432328316	35747F	9839 298125	LILIYA STEPANOVA	{"email": "liliyastepanova.091980@postgrespro.ru", "phone": "+70541367289"}
0005432328317	101A4D	2051 516575	MAKSIM MOROZOV	{"phone": "+70986238572"}
0005432328318	59948C	7301 281694	ILYAS SMIRNOV	{"email": "smirnov.ilyas-27011983@postgrespro.ru", "phone": "+70165328358"}
0005432328319	679BCC	1162 511727	YAROSLAV IVANOV	{"email": "ivanov.yaroslav.1970@postgrespro.ru", "phone": "+70790926374"}
0005432328320	679BCC	3717 727757	ZOYA ZAKHAROVA	{"phone": "+70992646250"}
0005432328321	2C1436	2537 332204	OLGA YAKOVLEVA	{"phone": "+70483076852"}
0005432328322	295D4F	1368 971993	MARINA FEDOROVA	{"phone": "+70901585023"}
0005432328323	295D4F	5267 214245	NINA ALEKSANDROVA	{"phone": "+70844733871"}
0005432328324	1B92E4	2639 747312	OLGA POPOVA	{"phone": "+70371016731"}
0005432328325	1B92E4	0935 998181	YAKOV BONDARENKO	{"phone": "+70801667026"}
0005432328326	7B7A9F	0584 468490	VIKTOR VASILEV	{"email": "vasilev_viktor-041967@postgrespro.ru", "phone": "+70260430592"}
0005432328327	A07D70	7014 716653	VLADIMIR SOKOLOV	{"email": "v_sokolov_121968@postgrespro.ru", "phone": "+70061448717"}
0005432328328	637D6B	7302 427397	MIKHAIL KUZMIN	{"email": "kuzmin.mikhail_24051969@postgrespro.ru", "phone": "+70367208844"}
0005432328329	1DA8C8	7930 024704	ANATOLIY STEPANOV	{"phone": "+70324534097"}
0005432328330	759B72	4223 622481	GENNADIY IVANOV	{"phone": "+70937426405"}
0005432328331	74215C	9587 497949	ALEKSANDRA AFANASEVA	{"phone": "+70603635958"}
0005432328332	EE012E	9069 395119	VLADIMIR KUZNECOV	{"phone": "+70549686973"}
0005432328333	BEFE33	7172 735717	ROMAN ORLOV	{"phone": "+70626073564"}
0005432328334	7F110A	9061 363795	ALEKSANDRA DENISOVA	{"email": "a_denisova-121969@postgrespro.ru", "phone": "+70408727353"}
0005432328335	657F86	7301 021432	LYUBOV CHERNOVA	{"email": "chernova-l.041975@postgrespro.ru", "phone": "+70135792040"}
0005432328336	A72EE8	7542 104643	NIKITA PETROV	{"email": "petrov.nikita.11111964@postgrespro.ru", "phone": "+70196103483"}
0005432328337	F07F03	8285 804167	MARIYA SEMENOVA	{"phone": "+70033148064"}
0005432328338	7364CD	5032 175977	SERGEY MAKSIMOV	{"email": "maksimov.sergey.23011974@postgrespro.ru", "phone": "+70295113758"}
0005432328339	563D14	6288 255355	SERGEY IVANOV	{"phone": "+70798770752"}
0005432328340	563D14	2752 598444	VASILIY RODIONOV	{"email": "vasiliy.rodionov1984@postgrespro.ru", "phone": "+70917386639"}
0005432328341	59E25D	0485 751091	DMITRIY GUSEV	{"email": "dgusev111971@postgrespro.ru", "phone": "+70056545911"}
0005432328342	1719E4	0784 471053	GALINA FOMINA	{"phone": "+70195492818"}
0005432328343	1719E4	3104 108672	NATALYA POLYAKOVA	{"phone": "+70105932444"}
0005432328344	1719E4	4596 790214	DMITRIY POPOV	{"email": "popov-dmitriy_111965@postgrespro.ru", "phone": "+70396470678"}
0005432328345	2DC8EF	0681 017329	VLADIMIR FEDOTOV	{"phone": "+70974521764"}
0005432328346	2735D6	3984 924136	VIKTOR GRIGOREV	{"phone": "+70040873378"}
0005432328347	0339FC	7564 018924	NATALYA ZOTOVA	{"email": "zotova-n10021971@postgrespro.ru", "phone": "+70650329156"}
0005432328348	0339FC	9859 005484	BOGDAN MAKAROV	{"phone": "+70182238607"}
0005432328349	BFF4ED	2956 905625	DMITRIY IVANOV	{"email": "dmitriy_ivanov.30071982@postgrespro.ru", "phone": "+70539324678"}
0005432328350	BFF4ED	9048 754080	ALBINA ARKHIPOVA	{"email": "arkhipovaalbina20021974@postgrespro.ru", "phone": "+70800375504"}
0005432328351	023059	2700 228503	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr.19011975@postgrespro.ru", "phone": "+70522653190"}
0005432328352	023059	2733 274452	ALLA YAKOVLEVA	{"email": "alla_yakovleva-031976@postgrespro.ru", "phone": "+70209984064"}
0005432328353	22CCAE	3799 055133	ANGELINA POTAPOVA	{"email": "apotapova.1973@postgrespro.ru", "phone": "+70785988532"}
0005432328354	ADC464	5274 768079	ANNA SCHERBAKOVA	{"email": "anna.scherbakova15021968@postgrespro.ru", "phone": "+70008133845"}
0005432328355	ADC464	8646 838158	MIKHAIL PAVLOV	{"email": "pavlov.m_16111974@postgrespro.ru", "phone": "+70942650194"}
0005432328356	45E027	7129 564597	MIKHAIL ALEKSEEV	{"email": "mikhail_alekseev1971@postgrespro.ru", "phone": "+70877231360"}
0005432328357	25F5B9	8926 498644	DAVID SHEVCHENKO	{"email": "shevchenko-david-1968@postgrespro.ru", "phone": "+70350868826"}
0005432328358	25F5B9	0641 130135	STEPAN TIKHONOV	{"phone": "+70419312794"}
0005432328359	BDBC38	9086 258168	ELENA FEDOROVA	{"email": "fedorova.e17101972@postgrespro.ru", "phone": "+70736403384"}
0005432328360	432718	6219 016449	SERGEY VOLKOV	{"phone": "+70130957483"}
0005432328361	657628	4551 354697	ANDREY ROMANOV	{"phone": "+70727488382"}
0005432328362	0D1107	2629 475420	VLADIMIR KULIKOV	{"phone": "+70365199351"}
0005432328363	6DA055	4044 372275	EKATERINA VOROBEVA	{"phone": "+70221089983"}
0005432328364	54CCCA	4827 270632	IRINA KOVALEVA	{"phone": "+70781323744"}
0005432328365	54CCCA	8537 819991	MATVEY DAVYDOV	{"email": "davydovm_1975@postgrespro.ru", "phone": "+70513259003"}
0005432328366	B7129D	5335 264584	ALEKSANDR VASILEV	{"email": "vasilev-a.1978@postgrespro.ru", "phone": "+70130268451"}
0005432328367	087298	2178 971635	YURIY DMITRIEV	{"email": "dmitriev.yuriy12031970@postgrespro.ru", "phone": "+70883290678"}
0005432328368	A3E27A	8866 380396	ANDREY MAKAROV	{"phone": "+70846925662"}
0005432328369	12097B	8259 754530	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir.05061967@postgrespro.ru", "phone": "+70198730358"}
0005432328370	A418B3	7998 380417	FAINA POPOVA	{"phone": "+70388569545"}
0005432328371	16365D	6539 767252	LYUDMILA ALEKSEEVA	{"email": "alekseeva_lyudmila.22121969@postgrespro.ru", "phone": "+70062424399"}
0005432328372	43B396	6899 121843	ELENA FADEEVA	{"email": "elenafadeeva-16101967@postgrespro.ru", "phone": "+70960277291"}
0005432328373	1383D2	8715 381038	NADEZHDA FEDOROVA	{"email": "n-fedorova1969@postgrespro.ru", "phone": "+70725014898"}
0005432328374	CD7F8F	9666 814058	LIDIYA KUZNECOVA	{"phone": "+70122759034"}
0005432328375	4E517B	9429 920922	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov-1982@postgrespro.ru", "phone": "+70802831456"}
0005432328376	9385A9	1368 437857	VALENTINA POTAPOVA	{"phone": "+70396800118"}
0005432328377	08498B	0222 673415	IRINA OVCHINNIKOVA	{"email": "irina.ovchinnikova1965@postgrespro.ru", "phone": "+70815736926"}
0005432328378	04BC77	4689 080747	ALEKSANDR NIKOLAEV	{"phone": "+70969772498"}
0005432328379	3D04DB	3358 752258	KONSTANTIN MAKSIMOV	{"email": "maksimov.konstantin.021967@postgrespro.ru", "phone": "+70374060888"}
0005432328380	B74EE4	0136 675388	IGOR SEMENOV	{"email": "igor_semenov_1966@postgrespro.ru", "phone": "+70042595625"}
0005432328381	6D8F0B	9200 568549	ANATOLIY SIDOROV	{"email": "sidorov-a-1971@postgrespro.ru", "phone": "+70237767606"}
0005432328382	6D8F0B	2287 919449	EVGENIYA IVANOVA	{"email": "eivanova-091977@postgrespro.ru", "phone": "+70902321739"}
0005432328383	FF8388	4350 709799	VIKTORIYA SERGEEVA	{"phone": "+70784419012"}
0005432328384	D67F72	4426 812765	TATYANA BELOVA	{"email": "belova-tatyana-041964@postgrespro.ru", "phone": "+70589575467"}
0005432328385	0B1EDA	0049 189848	ANDREY KISELEV	{"phone": "+70742351046"}
0005432328386	5E8C71	5815 084731	IVAN FOMIN	{"email": "fomin-i30011974@postgrespro.ru", "phone": "+70697495832"}
0005432328387	0D6784	9008 005870	ANNA KUZNECOVA	{"email": "kuznecovaanna-071970@postgrespro.ru", "phone": "+70468485751"}
0005432328388	0D6784	0001 912971	TATYANA SCHERBAKOVA	{"phone": "+70336576224"}
0005432328389	0D6784	5160 084182	NADEZHDA SOROKINA	{"email": "nadezhda_sorokina.11111979@postgrespro.ru", "phone": "+70883153954"}
0005432328390	EADCB7	4508 398648	NATALYA ALEKSEEVA	{"email": "n_alekseeva-22101968@postgrespro.ru", "phone": "+70251100045"}
0005432328391	032232	1885 783200	SERGEY MAKAROV	{"email": "smakarov.091961@postgrespro.ru", "phone": "+70267682787"}
0005432328392	747599	9253 809936	VLADIMIR ZAYCEV	{"email": "zaycev.vladimir.081976@postgrespro.ru", "phone": "+70731992646"}
0005432328393	4CCB9C	0232 520507	ALEKSANDR VOROBEV	{"email": "avorobev_02021967@postgrespro.ru", "phone": "+70661032746"}
0005432328394	A23C69	0037 609341	MARINA SEMENOVA	{"phone": "+70680694259"}
0005432328395	49FF47	4627 776032	MIKHAIL NOVIKOV	{"email": "novikov.m-111970@postgrespro.ru", "phone": "+70533388053"}
0005432328396	412257	6099 866629	MARINA ISAEVA	{"email": "isaevam.08051965@postgrespro.ru", "phone": "+70064942532"}
0005432328397	513F00	7583 292114	GALINA KAZAKOVA	{"phone": "+70821514178"}
0005432328398	8C3B79	0811 402805	SERGEY NIKOLAEV	{"phone": "+70128159175"}
0005432328399	26895A	2508 389898	VLADIMIR KUZMIN	{"email": "v_kuzmin-1975@postgrespro.ru", "phone": "+70615412634"}
0005432328400	BA7D05	4669 211719	PAVEL MATVEEV	{"phone": "+70650146031"}
0005432328401	8923E8	7544 263085	PAVEL NIKOLAEV	{"email": "nikolaev-p1985@postgrespro.ru", "phone": "+70518677431"}
0005432328402	539DEF	9887 232382	ALEKSANDR ROMANOV	{"email": "romanov.a-041974@postgrespro.ru", "phone": "+70433256909"}
0005432328403	795090	0012 930079	ALLA KUDRYASHOVA	{"phone": "+70176115359"}
0005432328404	795090	0027 960072	VLADIMIR KARPOV	{"phone": "+70025416309"}
0005432328405	029D6D	5153 074324	ANDREY FROLOV	{"phone": "+70447341255"}
0005432328406	D82FD8	2316 340224	NAILYA NOVIKOVA	{"email": "novikovan-09061975@postgrespro.ru", "phone": "+70332197372"}
0005432328407	9250B5	7565 871972	VLADIMIR FOMIN	{"phone": "+70236294094"}
0005432328408	9250B5	0418 296983	OLGA IVANOVA	{"email": "ivanova_olga_29071967@postgrespro.ru", "phone": "+70670602398"}
0005432328409	6CF8A1	1415 213703	NINA BELOVA	{"email": "belova-nina.1974@postgrespro.ru", "phone": "+70377405511"}
0005432328410	2CE739	4893 752268	ANATOLIY YAKOVLEV	{"phone": "+70710691220"}
0005432328411	E700B3	3629 023494	DMITRIY YAKOVLEV	{"phone": "+70523302787"}
0005432328412	7B19F8	0644 225611	DAMIR NIKITIN	{"phone": "+70053700215"}
0005432328413	E095D6	9293 946425	ZOYA PAVLOVA	{"email": "pavlova-zoya.071975@postgrespro.ru", "phone": "+70458131442"}
0005432328414	26F79B	1404 095556	VALERIY NIKOLAEV	{"phone": "+70572687140"}
0005432328415	B06CC0	8479 163244	SERGEY DAVYDOV	{"email": "davydov_s_1964@postgrespro.ru", "phone": "+70132057599"}
0005432328416	B06CC0	8427 657821	ALEKSANDRA FILATOVA	{"phone": "+70862706037"}
0005432328417	252D04	4818 899983	ALEKSEY ILIN	{"phone": "+70214779408"}
0005432328418	BB97A8	8188 929608	SVETLANA BARANOVA	{"email": "baranovas.05011968@postgrespro.ru", "phone": "+70804179602"}
0005432328419	BB97A8	5416 698106	TATYANA MATVEEVA	{"email": "tatyanamatveeva.01031969@postgrespro.ru", "phone": "+70795400888"}
0005432328420	976108	3406 869085	EVGENIY KUZNECOV	{"phone": "+70053459579"}
0005432328421	7051B4	6938 928412	VALERIY SOLOVEV	{"email": "v-solovev-21091971@postgrespro.ru", "phone": "+70774956808"}
0005432328422	7051B4	9781 002494	KAROLINA ANDREEVA	{"phone": "+70150392965"}
0005432328423	E9B057	1764 090921	ARTEM KUZNECOV	{"email": "kuznecova_16031979@postgrespro.ru", "phone": "+70196374800"}
0005432328424	E9B057	2145 640624	ELENA LEBEDEVA	{"email": "lebedeva_e-051968@postgrespro.ru", "phone": "+70872664383"}
0005432328425	24D5AD	0439 420340	ANATOLIY KUZNECOV	{"email": "a.kuznecov07021974@postgrespro.ru", "phone": "+70395707648"}
0005432328426	6FE9A3	5941 834042	ANGELINA KUZNECOVA	{"phone": "+70412904179"}
0005432328427	97EAE9	1204 082582	VALENTINA FROLOVA	{"phone": "+70124935818"}
0005432328428	97EAE9	7405 155421	EKATERINA NIKIFOROVA	{"email": "nikiforovaekaterina_041980@postgrespro.ru", "phone": "+70251818795"}
0005432328429	3A764B	4605 515742	YULIYA FOMINA	{"email": "fomina_y-1974@postgrespro.ru", "phone": "+70438641577"}
0005432328430	3A764B	4905 487133	NINA ALEKSEEVA	{"phone": "+70374921015"}
0005432328431	3A764B	9870 201527	VLADIMIR DAVYDOV	{"email": "davydov.v-061979@postgrespro.ru", "phone": "+70893845881"}
0005432328432	3FD9D4	3858 890397	MIKHAIL SERGEEV	{"phone": "+70477632317"}
0005432328433	763891	5577 141835	IGOR PAVLOV	{"email": "igor-pavlov.051965@postgrespro.ru", "phone": "+70762850991"}
0005432328434	763891	4336 899849	ROMAN IVANOV	{"phone": "+70137547012"}
0005432328435	FB5FFF	1826 440388	MARIYA VASILEVA	{"email": "mvasileva-1964@postgrespro.ru", "phone": "+70623478486"}
0005432328436	E57B0F	2242 647001	SERGEY SCHERBAKOV	{"email": "scherbakov_s.1967@postgrespro.ru", "phone": "+70950867266"}
0005432328437	9DB258	8845 870757	VYACHESLAV ALEKSEEV	{"phone": "+70689337855"}
0005432328438	044AC2	4896 079144	IGOR STEPANOV	{"phone": "+70029505290"}
0005432328439	0E9C0A	1103 019262	SERGEY SOKOLOV	{"email": "sokolov.s_031978@postgrespro.ru", "phone": "+70338705963"}
0005432328440	7749A4	8305 188708	YULIYA SMIRNOVA	{"email": "smirnova.y.1970@postgrespro.ru", "phone": "+70288726935"}
0005432328441	D35616	3805 464493	RAISA KOZLOVA	{"email": "raisa_kozlova-091973@postgrespro.ru", "phone": "+70935415139"}
0005432328442	D35616	3259 909841	NATALYA FILIPPOVA	{"phone": "+70071003462"}
0005432328443	07FD25	4021 202553	ALBINA STEPANOVA	{"phone": "+70102361166"}
0005432328444	1CF88B	4667 257912	ANDREY NIKITIN	{"phone": "+70794284159"}
0005432328445	EE892E	3851 947929	PAVEL CHERNOV	{"email": "pavel.chernov_101958@postgrespro.ru", "phone": "+70656114869"}
0005432328446	67B6AA	2618 028923	KLAVDIYA ROMANOVA	{"email": "klavdiya_romanova1975@postgrespro.ru", "phone": "+70421094495"}
0005432328447	728AAB	1817 820052	YURIY SERGEEV	{"phone": "+70431209265"}
0005432328448	728AAB	8443 418236	RUMIYA SAVELEVA	{"email": "rsaveleva13091979@postgrespro.ru", "phone": "+70137179500"}
0005432328449	4EB3DB	2235 891928	INESSA KUZNECOVA	{"phone": "+70939270318"}
0005432328450	4EB3DB	3958 625588	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko.1974@postgrespro.ru", "phone": "+70575439826"}
0005432328451	94053F	4029 260497	ALLA POPOVA	{"phone": "+70899548709"}
0005432328452	94053F	3833 878940	ANASTASIYA SEMENOVA	{"email": "anastasiyasemenova13071968@postgrespro.ru", "phone": "+70335584731"}
0005432328453	94053F	7214 112162	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr081967@postgrespro.ru", "phone": "+70859183858"}
0005432328454	649B1D	2935 649768	LYUBOV MEDVEDEVA	{"phone": "+70203140417"}
0005432328455	2768B7	8114 137004	SVETLANA KUZNECOVA	{"phone": "+70210118346"}
0005432328456	59C6FB	9326 412947	VITALIY ZAKHAROV	{"email": "vitaliyzakharov.13111969@postgrespro.ru", "phone": "+70426182663"}
0005432328457	8349B8	4711 227194	DANIIL MELNIKOV	{"phone": "+70973945692"}
0005432328458	F2CCC3	6165 629505	OKSANA ZAYCEVA	{"phone": "+70831660787"}
0005432328459	01F24A	2033 211674	YULIYA DMITRIEVA	{"phone": "+70432189507"}
0005432328460	FA4EC3	8026 691409	ALEKSEY OSIPOV	{"email": "osipova_101965@postgrespro.ru", "phone": "+70227002942"}
0005432328461	344C3B	4103 975020	ELENA ERMAKOVA	{"phone": "+70509384990"}
0005432328462	77D8DF	0473 295603	ALEKSANDR KULIKOV	{"email": "a.kulikov14071966@postgrespro.ru", "phone": "+70887157909"}
0005432328463	C2094B	5710 602550	NATALYA MIKHAYLOVA	{"phone": "+70572555160"}
0005432328464	A814A3	6089 235560	SERGEY STEPANOV	{"phone": "+70914631597"}
0005432328465	C2B53E	7058 733324	DENIS TIMOFEEV	{"email": "d_timofeev-25061976@postgrespro.ru", "phone": "+70748882374"}
0005432328466	F098DB	9517 271648	ALEKSANDR KUZNECOV	{"phone": "+70534789252"}
0005432328467	D4419E	7065 819674	NIKITA YAKOVLEV	{"email": "nikita-yakovlev-05051977@postgrespro.ru", "phone": "+70175276803"}
0005432328468	D4419E	2925 295697	ALEVTINA KUZNECOVA	{"email": "kuznecova.alevtina-16051969@postgrespro.ru", "phone": "+70524657179"}
0005432328469	D1739A	5076 419073	ALLA IVANOVA	{"phone": "+70712694108"}
0005432328470	6EC147	7966 960862	ALEKSANDR NIKITIN	{"phone": "+70952875873"}
0005432328471	6EC147	6109 169810	ILDAR KOZLOV	{"phone": "+70252766843"}
0005432328472	765A87	8087 724401	RAVZA BELOVA	{"email": "belova_ravza-111971@postgrespro.ru", "phone": "+70217134360"}
0005432328473	765A87	7126 759663	TATYANA FILIPPOVA	{"phone": "+70487304388"}
0005432328474	8F722D	6728 767669	MARINA FILIPPOVA	{"email": "marina.filippova.091982@postgrespro.ru", "phone": "+70058649950"}
0005432328475	507C78	3280 199266	GALINA ROMANOVA	{"email": "romanova.galina_02101976@postgrespro.ru", "phone": "+70760873951"}
0005432328476	78F69D	6051 072386	ARTEM FOMIN	{"email": "fomin.a.23021964@postgrespro.ru", "phone": "+70888158197"}
0005432328477	86898C	5612 698618	VLADIMIR NAZAROV	{"phone": "+70312344954"}
0005432328478	86898C	2190 990767	TATYANA IVANOVA	{"email": "ivanova_tatyana-061973@postgrespro.ru", "phone": "+70809214483"}
0005432328479	17A8BD	8406 326654	LYUBOV YUDINA	{"email": "yudina_l_1971@postgrespro.ru", "phone": "+70871783010"}
0005432328480	FBB834	7781 275018	ANDREY KOZLOV	{"phone": "+70477936358"}
0005432328481	FBB834	1166 525015	ALEKSANDR MATVEEV	{"phone": "+70333070043"}
0005432328482	B635E5	6129 535016	ILMIR VOLKOV	{"email": "i_volkov_1978@postgrespro.ru", "phone": "+70330805933"}
0005432328483	52D765	4716 268681	NIKOLAY VLASOV	{"phone": "+70968485710"}
0005432328484	D17813	2675 956653	OLESYA LEBEDEVA	{"email": "lebedevaolesya061978@postgrespro.ru", "phone": "+70736494519"}
0005432328485	D17813	6642 006652	MARINA BORISOVA	{"phone": "+70154618139"}
0005432328486	AD37E2	7210 135078	VALENTINA FILIPPOVA	{"phone": "+70174046426"}
0005432328487	AD37E2	5802 481588	NIKOLAY PETROV	{"email": "nikolay-petrov-071970@postgrespro.ru", "phone": "+70320079362"}
0005432328488	E73846	4391 252967	NIKOLAY KUZMIN	{"email": "kuzminnikolay-071968@postgrespro.ru", "phone": "+70791035594"}
0005432328489	FCFF9B	4029 606546	VALERIYA GUSEVA	{"phone": "+70024395209"}
0005432328490	037DE3	2673 755892	OLGA ALEKSEEVA	{"phone": "+70074316013"}
0005432328731	C38B24	6078 857896	SERGEY BELOV	{"phone": "+70830218403"}
0005432328491	037DE3	0716 456295	IRINA NIKIFOROVA	{"email": "nikiforova_irina091967@postgrespro.ru", "phone": "+70450699474"}
0005432328492	90B977	7335 117466	OLGA FILIPPOVA	{"phone": "+70082369105"}
0005432328493	37B573	1403 253194	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov.16111974@postgrespro.ru", "phone": "+70769808713"}
0005432328494	78A31B	8052 641247	VIKTOR AFANASEV	{"email": "vafanasev_111965@postgrespro.ru", "phone": "+70404280023"}
0005432328495	A75FAD	9300 122479	KRISTINA KUZNECOVA	{"phone": "+70989060250"}
0005432328496	A75FAD	5906 810512	VASILIY NOVIKOV	{"phone": "+70033220886"}
0005432328497	FE6D8C	5853 019678	GALINA PAVLOVA	{"email": "galinapavlova.1978@postgrespro.ru", "phone": "+70528789772"}
0005432328498	8D1CE2	8761 691211	STANISLAV ROMANOV	{"email": "romanov_stanislav.1976@postgrespro.ru", "phone": "+70826575871"}
0005432328499	8D1CE2	3251 194588	MAKSIM NAZAROV	{"email": "nazarov_maksim_1986@postgrespro.ru", "phone": "+70608896307"}
0005432328500	E4C4A2	4567 255640	EGOR SEMENOV	{"email": "e_semenov-101969@postgrespro.ru", "phone": "+70339996649"}
0005432328501	1806DD	2835 754933	ALEKSEY BARANOV	{"phone": "+70840492518"}
0005432328502	BA2EE6	5109 917463	SAMVEL SERGEEV	{"phone": "+70245574141"}
0005432328503	C1797D	0064 556758	ALEKSEY SOROKIN	{"email": "a_sorokin.1982@postgrespro.ru", "phone": "+70109193773"}
0005432328504	C1797D	4394 523221	VIKTOR KOROLEV	{"email": "v-korolev_17121972@postgrespro.ru", "phone": "+70854083922"}
0005432328505	E481B2	0434 836107	NADEZHDA MAKSIMOVA	{"phone": "+70000910427"}
0005432328506	E481B2	8607 335643	KHALIDA TROFIMOVA	{"email": "trofimova_khalida.021981@postgrespro.ru", "phone": "+70921576903"}
0005432328507	A14F63	2069 161723	ELENA ANDREEVA	{"phone": "+70714387752"}
0005432328508	758B79	3941 621482	ALEKSEY IVANOV	{"phone": "+70192931377"}
0005432328509	7CB0D4	6366 651671	DARYA MAKAROVA	{"email": "d_makarova-091979@postgrespro.ru", "phone": "+70046418055"}
0005432328510	14343D	7862 982227	MARIYA NOVIKOVA	{"phone": "+70002576312"}
0005432328511	14343D	8344 228446	EVGENIY ROMANOV	{"email": "romanov.evgeniy-27121967@postgrespro.ru", "phone": "+70349906295"}
0005432328512	A4FEFE	9079 057012	KONSTANTIN MAKSIMOV	{"email": "konstantin_maksimov-1968@postgrespro.ru", "phone": "+70432674079"}
0005432328513	A4FEFE	8906 219798	VITALIY POPOV	{"email": "popov.v10031980@postgrespro.ru", "phone": "+70385694787"}
0005432328514	C65D0C	3545 770658	ZINAIDA ORLOVA	{"phone": "+70490745416"}
0005432328515	C65D0C	6823 618303	OLGA FILIPPOVA	{"phone": "+70716353058"}
0005432328516	37078A	6039 144750	TATYANA KUZMINA	{"email": "tkuzmina.25021982@postgrespro.ru", "phone": "+70069024173"}
0005432328517	4B44A0	1441 125166	DENIS KULIKOV	{"email": "d.kulikov-21031967@postgrespro.ru", "phone": "+70666066853"}
0005432328518	C679E7	8793 425894	ELENA IVANOVA	{"email": "ivanova_e-111966@postgrespro.ru", "phone": "+70829524187"}
0005432328519	9A66AB	4490 239642	ALEKSANDR VASILEV	{"phone": "+70096513851"}
0005432328520	8DA6C4	8595 752612	ALEKSEY PAVLOV	{"email": "pavlov-aleksey1972@postgrespro.ru", "phone": "+70641695316"}
0005432328521	A390A3	9068 381777	EVGENIY KUZNECOV	{"email": "kuznecov_evgeniy_041958@postgrespro.ru", "phone": "+70533305531"}
0005432328522	A2599D	3149 552797	EKATERINA MELNIKOVA	{"email": "melnikova_e-23091970@postgrespro.ru", "phone": "+70493634391"}
0005432328523	A2599D	6668 089148	LARISA FOMINA	{"email": "l-fomina-25091985@postgrespro.ru", "phone": "+70187655851"}
0005432328524	0C220A	4264 557613	ALEKSANDR SIDOROV	{"phone": "+70665161990"}
0005432328525	0C220A	3446 723232	ELENA NIKITINA	{"phone": "+70636978055"}
0005432328526	488271	2536 311950	ILYA KAZAKOV	{"email": "ilya_kazakov-08021976@postgrespro.ru", "phone": "+70406396367"}
0005432328527	488271	0618 820078	OLGA KUZMINA	{"phone": "+70365409204"}
0005432328528	6C5E29	5479 839519	INNA NESTEROVA	{"phone": "+70015218357"}
0005432328529	FAF8BF	2671 842365	ALENA SIDOROVA	{"phone": "+70948712764"}
0005432328530	FAF8BF	6266 311453	BORIS BARANOV	{"phone": "+70244697418"}
0005432328531	8451C9	6572 469363	VASILIY VLASOV	{"phone": "+70922868302"}
0005432328532	71744A	3956 197600	VALENTINA NAZAROVA	{"phone": "+70936775691"}
0005432328533	EAAC8B	6949 483060	PAVEL AFANASEV	{"email": "afanasev_pavel.17121972@postgrespro.ru", "phone": "+70855408266"}
0005432328534	EAAC8B	8041 013935	ALEKSANDRA MALYSHEVA	{"email": "malysheva.aleksandra22091989@postgrespro.ru", "phone": "+70486391584"}
0005432328535	EAAC8B	1118 856030	VALERIYA FEDOROVA	{"email": "fedorovav.041978@postgrespro.ru", "phone": "+70008111444"}
0005432328536	43156F	5945 369533	VERA KUZNECOVA	{"email": "kuznecovav-1974@postgrespro.ru", "phone": "+70567837996"}
0005432328537	74DE21	7497 366011	SERGEY KUZNECOV	{"phone": "+70258456984"}
0005432328538	6CE8AD	2976 753460	ALBINA ALEKSEEVA	{"phone": "+70252450494"}
0005432328539	FD164A	5396 328192	OLGA ROMANOVA	{"email": "olga_romanova_21091975@postgrespro.ru", "phone": "+70120116090"}
0005432328540	ACB3C6	6987 557733	NINA FEDOROVA	{"email": "fedorova_n1968@postgrespro.ru", "phone": "+70099992641"}
0005432328541	ACB3C6	7173 117343	VLADISLAV MOROZOV	{"email": "vladislav_morozov1979@postgrespro.ru", "phone": "+70572978574"}
0005432328542	DAA838	5824 136505	PAVEL ROMANOV	{"email": "romanov.p-10071975@postgrespro.ru", "phone": "+70433738852"}
0005432328543	D0844E	2953 330873	NIKITA IVANOV	{"phone": "+70617862300"}
0005432328544	93DC45	4144 129676	TATYANA KUDRYASHOVA	{"email": "t-kudryashova1967@postgrespro.ru", "phone": "+70547410046"}
0005432328545	93DC45	9962 148865	NATALYA KOZLOVA	{"phone": "+70157168041"}
0005432328546	26504F	6203 069261	ALEKSEY MIRONOV	{"phone": "+70650995662"}
0005432328547	6B4C55	6801 821754	ALEKSANDR IVANOV	{"email": "ivanova-1970@postgrespro.ru", "phone": "+70452758744"}
0005432328548	6B4C55	2051 501035	ALEKSANDR NOVIKOV	{"email": "novikov-a091975@postgrespro.ru", "phone": "+70402627135"}
0005432328549	6B4C55	9147 595486	NATALYA BELYAEVA	{"phone": "+70564530549"}
0005432328550	0FDFA1	8925 186654	VALERIY KUDRYASHOV	{"email": "kudryashov.v03041983@postgrespro.ru", "phone": "+70478240440"}
0005432328551	54FB0D	4503 238895	VIKTOR PAVLOV	{"email": "pavlov-viktor.111965@postgrespro.ru", "phone": "+70953201097"}
0005432328552	54FB0D	7209 728017	ALEKSEY POPOV	{"phone": "+70831575704"}
0005432328553	072F28	7485 652508	IVAN ZAKHAROV	{"email": "zakharovivan.1980@postgrespro.ru", "phone": "+70022926449"}
0005432328554	072F28	5411 873940	VLADIMIR MARTYNOV	{"email": "martynov-vladimir.10051985@postgrespro.ru", "phone": "+70039071345"}
0005432328555	7B1166	3192 183040	RENAT FEDOTOV	{"email": "renatfedotov.1974@postgrespro.ru", "phone": "+70430490783"}
0005432328556	7B1166	1193 874333	NATALYA LEBEDEVA	{"phone": "+70338394440"}
0005432328557	65E764	0720 470870	NINA OSIPOVA	{"email": "osipova.nina-011973@postgrespro.ru", "phone": "+70865589913"}
0005432328558	65E764	2300 912977	NIKOLAY KOZLOV	{"phone": "+70598007808"}
0005432328559	1ED09E	4328 576245	LYUDMILA POLYAKOVA	{"phone": "+70152743489"}
0005432328560	3190DA	8126 519311	TATYANA PETROVA	{"email": "t_petrova1971@postgrespro.ru", "phone": "+70880747802"}
0005432328561	3190DA	4903 344051	ALSU RODIONOVA	{"email": "rodionova.alsu.1968@postgrespro.ru", "phone": "+70904794244"}
0005432328562	D4CC7C	9986 230057	MAKSIM KUZNECOV	{"phone": "+70412342494"}
0005432328563	18C941	1981 415908	VIKTOR MAKAROV	{"phone": "+70113286264"}
0005432328564	C61A2B	1614 201595	ALEKSANDR BORISOV	{"phone": "+70885435198"}
0005432328565	142D44	8398 457515	VLADIMIR NIKITIN	{"email": "vladimir-nikitin-071960@postgrespro.ru", "phone": "+70451628550"}
0005432328566	678CFC	0519 010027	ANDREY ANDREEV	{"email": "andreev.andrey-1978@postgrespro.ru", "phone": "+70160313198"}
0005432328567	091A41	5461 413697	ALEKSANDR BARANOV	{"email": "baranov-a041955@postgrespro.ru", "phone": "+70027984654"}
0005432328568	D2816C	9391 912882	NIKOLAY KUZNECOV	{"phone": "+70946956490"}
0005432328569	55189F	1448 259240	ELENA YAKOVLEVA	{"phone": "+70402861872"}
0005432328570	A019D3	6313 030616	NATALYA ROMANOVA	{"email": "romanovanatalya_08051978@postgrespro.ru", "phone": "+70432745116"}
0005432328571	7A8311	3832 927191	ANTON IVANOV	{"phone": "+70646748041"}
0005432328572	DBF5C7	6503 107044	ELENA LEBEDEVA	{"phone": "+70836162005"}
0005432328573	671752	2842 911573	GALINA KOROLEVA	{"email": "korolevag.1971@postgrespro.ru", "phone": "+70082091610"}
0005432328574	D2D0CB	6045 358090	LYUDMILA KRASNOVA	{"phone": "+70301914568"}
0005432328575	CB9FB3	7741 995603	TATYANA TIMOFEEVA	{"phone": "+70641852568"}
0005432328576	9C80B1	8237 806325	OLGA SERGEEVA	{"phone": "+70306435191"}
0005432328577	A16A97	6631 982769	LYUDMILA ZAKHAROVA	{"phone": "+70796781908"}
0005432328578	092F04	9205 841653	TAMARA POPOVA	{"email": "popovatamara-14111968@postgrespro.ru", "phone": "+70570583731"}
0005432328579	AE27EB	9346 826645	DMITRIY DAVYDOV	{"email": "dmitriy_davydov.01091978@postgrespro.ru", "phone": "+70980629960"}
0005432328580	AE27EB	8201 007316	DAMIR IVANOV	{"email": "d_ivanov_02121969@postgrespro.ru", "phone": "+70969639440"}
0005432328581	603045	8921 999688	YURIY ZAKHAROV	{"email": "zakharov_y-13021966@postgrespro.ru", "phone": "+70064668760"}
0005432328582	2B00A7	7107 839733	LIDIYA SMIRNOVA	{"email": "l-smirnova_04041969@postgrespro.ru", "phone": "+70012792195"}
0005432328583	EA8CEB	3666 305104	NIKITA POPOV	{"phone": "+70412662433"}
0005432328584	420994	3410 553233	MIKHAIL FROLOV	{"email": "frolov_m.051985@postgrespro.ru", "phone": "+70518498990"}
0005432328585	420994	2468 666480	EKATERINA YUDINA	{"phone": "+70760636214"}
0005432328586	C0E504	1368 471592	VLADIMIR KUZMIN	{"phone": "+70836574828"}
0005432328587	C0E504	3222 373092	VYACHESLAV MIKHAYLOV	{"email": "v-mikhaylov-1973@postgrespro.ru", "phone": "+70697082315"}
0005432328588	96FB8C	4456 883328	OLGA STEPANOVA	{"phone": "+70196059416"}
0005432328589	AD09DA	1571 624728	VASILIY KUDRYASHOV	{"phone": "+70729958126"}
0005432328590	4D7957	4206 087988	EDUARD KUZMIN	{"phone": "+70809335643"}
0005432328591	4D7957	1413 305761	IRINA ALEKSANDROVA	{"phone": "+70861062334"}
0005432328592	CD41FD	5663 769572	ZINAIDA KUZNECOVA	{"email": "kuznecova.zinaida_081974@postgrespro.ru", "phone": "+70473255243"}
0005432328593	9BCBA4	5764 244971	STANISLAV POPOV	{"phone": "+70983567321"}
0005432328594	408429	7161 687215	ALEKSANDR NOVIKOV	{"phone": "+70743742666"}
0005432328595	1693CC	3469 738976	YULIYA ZHUKOVA	{"email": "zhukova_yuliya.20111976@postgrespro.ru", "phone": "+70739645745"}
0005432328596	0E9314	3359 823994	VYACHESLAV NAZAROV	{"email": "v_nazarov_1975@postgrespro.ru", "phone": "+70278302968"}
0005432328597	0E9314	5401 311301	NIKOLAY ROMANOV	{"email": "romanovn-03031971@postgrespro.ru", "phone": "+70963914992"}
0005432328598	998741	1008 305801	IGOR ABRAMOV	{"phone": "+70965997073"}
0005432328599	998741	7627 244621	ALEKSANDR ROMANOV	{"phone": "+70544565503"}
0005432328600	AE0C6A	1004 427471	SERGEY SIDOROV	{"phone": "+70630444985"}
0005432328601	AE0C6A	9500 683055	NATALYA ISAEVA	{"phone": "+70662078233"}
0005432328602	885383	9720 241036	TATYANA DMITRIEVA	{"phone": "+70361708300"}
0005432328603	885383	1208 048316	RAVIL AFANASEV	{"phone": "+70658994214"}
0005432328604	F078E1	7597 247418	ANDREY ALEKSANDROV	{"email": "andreyaleksandrov.20051971@postgrespro.ru", "phone": "+70075166202"}
0005432328605	D986B6	9346 580011	EVGENIYA MIKHAYLOVA	{"phone": "+70787995206"}
0005432328606	8E9374	6948 689201	VASILIY GORBUNOV	{"email": "gorbunov.v.071968@postgrespro.ru", "phone": "+70825677008"}
0005432328607	8E9374	0061 000762	SERGEY MIKHAYLOV	{"email": "mikhaylov-s1964@postgrespro.ru", "phone": "+70900269877"}
0005432328608	071D09	5856 586255	ANDREY MARTYNOV	{"phone": "+70894116719"}
0005432328609	8274FD	4416 855282	VALERIY PETROV	{"phone": "+70874282041"}
0005432328610	E05888	2908 917894	YURIY MOROZOV	{"email": "morozov-yuriy-08031971@postgrespro.ru", "phone": "+70544962079"}
0005432328611	9AB339	7284 248577	NINA KOROLEVA	{"email": "koroleva_nina1969@postgrespro.ru", "phone": "+70353180582"}
0005432328612	521FFF	6383 767405	ANDREY SHEVCHENKO	{"email": "shevchenko-a-18111980@postgrespro.ru", "phone": "+70471185877"}
0005432328613	8E17CD	5856 245177	SERGEY FILIPPOV	{"phone": "+70045779769"}
0005432328614	8E17CD	6770 933182	YAROSLAVA ZOTOVA	{"email": "y_zotova1967@postgrespro.ru", "phone": "+70797812852"}
0005432328615	6FE36F	3461 495864	IRINA KISELEVA	{"phone": "+70761727451"}
0005432328616	B6A9E5	5504 193816	OLEG ALEKSEEV	{"email": "alekseev_o1963@postgrespro.ru", "phone": "+70084648780"}
0005432328617	17C981	1227 259669	LIDIYA MAKSIMOVA	{"email": "maksimova-lidiya_1975@postgrespro.ru", "phone": "+70898062776"}
0005432328618	17C981	7177 653270	ANATOLIY GAVRILOV	{"phone": "+70104885125"}
0005432328619	17C981	2431 631364	GENNADIY KUZNECOV	{"email": "kuznecov.g-23081972@postgrespro.ru", "phone": "+70187181439"}
0005432328620	029C1C	7017 538347	VALENTINA GERASIMOVA	{"phone": "+70283218163"}
0005432328621	EF4272	3924 637580	OLGA KARPOVA	{"email": "karpova-o121978@postgrespro.ru", "phone": "+70064257490"}
0005432328622	6E86F8	9171 629743	OLGA KARPOVA	{"email": "karpova.o_121976@postgrespro.ru", "phone": "+70263164980"}
0005432328623	228AEA	6050 052787	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_1984@postgrespro.ru", "phone": "+70403318945"}
0005432328624	85D940	0974 364077	DMITRIY MATVEEV	{"phone": "+70910297756"}
0005432328625	85D940	3450 333712	ROMAN NAUMOV	{"phone": "+70725956474"}
0005432328626	4BB489	2318 020408	VALENTINA NIKITINA	{"phone": "+70051254488"}
0005432328627	B7D6A4	4822 235547	VIKTOR MELNIKOV	{"email": "v-melnikov.03031968@postgrespro.ru", "phone": "+70506912159"}
0005432328628	D0EF7D	0930 877067	MIKHAIL TIMOFEEV	{"email": "timofeev.mikhail.1969@postgrespro.ru", "phone": "+70751384130"}
0005432328629	AF3FFC	8031 375912	OLGA POTAPOVA	{"phone": "+70893718743"}
0005432328630	60DA4F	0429 503600	RUMIYA KONDRATEVA	{"phone": "+70510253241"}
0005432328631	6919EA	1301 217697	VLADISLAV VLASOV	{"phone": "+70982835790"}
0005432328632	6919EA	5736 120044	MARIYA BARANOVA	{"phone": "+70314774155"}
0005432328633	36F4EF	2606 122857	LYUBOV ZHURAVLEVA	{"phone": "+70078696080"}
0005432328634	2E1EE0	6536 890840	MAKSIM MIRONOV	{"phone": "+70763452335"}
0005432328635	2E1EE0	1113 675199	MIKHAIL FROLOV	{"phone": "+70107715627"}
0005432328636	01CB1E	0852 694872	VITALIY BELOV	{"phone": "+70334239331"}
0005432328637	5ED92D	5027 151955	VALENTINA SOKOLOVA	{"email": "valentinasokolova-061962@postgrespro.ru", "phone": "+70697869398"}
0005432328638	710921	4334 851476	VIKTOR TIKHONOV	{"email": "tikhonovviktor05061966@postgrespro.ru", "phone": "+70256191245"}
0005432328639	ED7C4F	3579 766220	EVGENIY GERASIMOV	{"phone": "+70340297939"}
0005432328640	4180B3	3131 399355	STANISLAV EGOROV	{"email": "s_egorov-1970@postgrespro.ru", "phone": "+70040133403"}
0005432328641	AC3A10	6121 078896	ILYA RODIONOV	{"email": "ilya.rodionov-20011975@postgrespro.ru", "phone": "+70521153970"}
0005432328642	74CD96	5673 597091	ANTONINA SIDOROVA	{"email": "a-sidorova.011975@postgrespro.ru", "phone": "+70282695043"}
0005432328643	21DA34	5674 062678	ELENA ILINA	{"email": "e.ilina.23071972@postgrespro.ru", "phone": "+70454441836"}
0005432328644	F54EB7	6778 635486	DMITRIY OSIPOV	{"email": "d-osipov-1972@postgrespro.ru", "phone": "+70069107267"}
0005432328645	03258B	4413 703241	ALEKSEY IVANOV	{"email": "aleksey-ivanov.061982@postgrespro.ru", "phone": "+70131394640"}
0005432328646	03258B	3384 934095	KIRILL ABRAMOV	{"phone": "+70254738638"}
0005432328647	C17EF1	6862 587281	NATALYA VOLKOVA	{"email": "volkova-natalya-17021986@postgrespro.ru", "phone": "+70507412755"}
0005432328648	C17EF1	3434 287685	TATYANA POPOVA	{"phone": "+70460610117"}
0005432328649	C17EF1	5420 131933	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov-27021969@postgrespro.ru", "phone": "+70822825904"}
0005432328650	175A73	8046 434075	PETR KUZNECOV	{"email": "kuznecov.petr111971@postgrespro.ru", "phone": "+70335354469"}
0005432328651	4AC1B4	9130 734420	IVAN FROLOV	{"phone": "+70192522416"}
0005432328652	4AC1B4	5337 194612	NATALYA RYABOVA	{"phone": "+70242270835"}
0005432328653	4AF28A	8543 983075	PAVEL IVANOV	{"email": "pavelivanov-1976@postgrespro.ru", "phone": "+70420176398"}
0005432328654	4AF28A	0654 783774	VLADIMIR MAKSIMOV	{"phone": "+70738181470"}
0005432328655	6E9B1C	0850 742751	IRINA SEMENOVA	{"email": "irinasemenova-28121963@postgrespro.ru", "phone": "+70785949715"}
0005432328656	6E9B1C	7548 927792	SVETLANA KONDRATEVA	{"email": "kondrateva.s.041967@postgrespro.ru", "phone": "+70109895151"}
0005432328657	A52E00	8427 369450	GALINA MOROZOVA	{"phone": "+70776338755"}
0005432328658	A52E00	7315 580185	LADA GUSEVA	{"email": "l_guseva.1969@postgrespro.ru", "phone": "+70263872560"}
0005432328659	B34AF5	5580 884130	YURIY POPOV	{"email": "yuriy.popov-09041967@postgrespro.ru", "phone": "+70854999300"}
0005432328660	B34AF5	5756 153109	VALENTINA MARTYNOVA	{"email": "martynova-v1978@postgrespro.ru", "phone": "+70420225281"}
0005432328661	ADC0D6	8400 923002	ANNA FOMINA	{"email": "fomina.a_051971@postgrespro.ru", "phone": "+70363723223"}
0005432328662	D61637	5424 474798	ALEKSEY TARASOV	{"email": "a_tarasov_03031975@postgrespro.ru", "phone": "+70873052393"}
0005432328663	3ADD50	6138 824100	ELENA ROMANOVA	{"email": "romanova_elena_031975@postgrespro.ru", "phone": "+70567440051"}
0005432328664	3ADD50	7730 575482	MAKSIM MELNIKOV	{"phone": "+70032298723"}
0005432328665	00236B	2145 344851	NADEZHDA MAKAROVA	{"email": "makarova-nadezhda-17041976@postgrespro.ru", "phone": "+70140025153"}
0005432328666	CC6D76	6318 757415	PETR GUSEV	{"email": "p-gusev-031973@postgrespro.ru", "phone": "+70287933328"}
0005432328667	CC6D76	5328 616727	IGOR FOMIN	{"phone": "+70715294793"}
0005432328668	4A27F7	3858 859873	ROMAN FEDOROV	{"phone": "+70306555597"}
0005432328669	4A27F7	4373 826746	PAVEL POPOV	{"phone": "+70421535617"}
0005432328853	C33D68	0522 326687	ALFIYA NIKITINA	{"phone": "+70053890242"}
0005432328670	F31A08	0975 479153	IVAN SERGEEV	{"email": "sergeev.ivan_1982@postgrespro.ru", "phone": "+70941244478"}
0005432328671	F31A08	8044 165624	ANVAR BORISOV	{"phone": "+70566741978"}
0005432328672	93A63F	2692 238529	OLGA PAVLOVA	{"phone": "+70675979527"}
0005432328673	E7480C	3552 054270	ALINA VASILEVA	{"email": "vasileva-a-19081974@postgrespro.ru", "phone": "+70941432692"}
0005432328674	3E02FC	4698 556694	IVAN KULIKOV	{"phone": "+70135456813"}
0005432328675	3E02FC	8017 550947	ANDREY MELNIKOV	{"phone": "+70529879986"}
0005432328676	3B5E21	3693 823710	VASILISA SIDOROVA	{"phone": "+70031758470"}
0005432328677	67FD67	9976 640807	ALEKSANDR DENISOV	{"email": "denisov.aleksandr.02091976@postgrespro.ru", "phone": "+70253816091"}
0005432328678	67FD67	5394 344996	VALENTINA KUZMINA	{"email": "kuzminav_1972@postgrespro.ru", "phone": "+70361237433"}
0005432328679	B62811	0535 236507	GALINA KRASNOVA	{"email": "gkrasnova.1972@postgrespro.ru", "phone": "+70938412508"}
0005432328680	3E4B33	9869 870183	VALERIY MAKAROV	{"phone": "+70337383394"}
0005432328681	EC51C8	4983 267925	TAMARA MAKSIMOVA	{"email": "maksimova_t22041978@postgrespro.ru", "phone": "+70031177163"}
0005432328682	EC51C8	5695 546172	LARISA ZAYCEVA	{"phone": "+70679722217"}
0005432328683	88BFA0	4814 036934	NINA DMITRIEVA	{"phone": "+70941339171"}
0005432328684	70F38D	1295 850619	IVAN FILIPPOV	{"email": "filippovivan.081974@postgrespro.ru", "phone": "+70171279372"}
0005432328685	2A8924	6668 046380	DMITRIY YAKOVLEV	{"email": "yakovlev.d.021972@postgrespro.ru", "phone": "+70970432179"}
0005432328686	2A8924	0933 558680	MARIYA IVANOVA	{"phone": "+70427670198"}
0005432328687	388CF8	5046 187917	VERA NOVIKOVA	{"email": "vera.novikova-18091974@postgrespro.ru", "phone": "+70273310973"}
0005432328688	10F541	7402 571006	ELENA MATVEEVA	{"phone": "+70808524967"}
0005432328689	0D419E	7880 399225	ALEKSEY SIDOROV	{"phone": "+70063409687"}
0005432328690	EE08F4	5353 980306	YULIYA FOMINA	{"phone": "+70821080456"}
0005432328691	E29819	5697 139768	EVDOKIYA IVANOVA	{"email": "evdokiyaivanova.26021969@postgrespro.ru", "phone": "+70198048361"}
0005432328692	AE3499	1745 051195	RAVILYA NIKIFOROVA	{"email": "nikiforovaravilya_1963@postgrespro.ru", "phone": "+70727852202"}
0005432328693	8791BA	6747 622021	EVDOKIYA VASILEVA	{"phone": "+70052592289"}
0005432328694	CA25EE	7180 687438	MARIYA SERGEEVA	{"email": "m-sergeeva_011977@postgrespro.ru", "phone": "+70307616780"}
0005432328695	85C518	3047 255327	TATYANA ANTONOVA	{"phone": "+70207094826"}
0005432328696	98BC79	3100 749659	OLGA POPOVA	{"email": "popova-olga-071977@postgrespro.ru", "phone": "+70436279069"}
0005432328697	98BC79	1617 724346	OLGA KUZNECOVA	{"email": "kuznecova_o_18121983@postgrespro.ru", "phone": "+70013187695"}
0005432328698	CEA0E2	9295 767900	VASILIY IVANOV	{"email": "vasiliy_ivanov_1970@postgrespro.ru", "phone": "+70715030564"}
0005432328699	CEA0E2	5624 398949	MARIYA RODIONOVA	{"email": "rodionova_m-16021968@postgrespro.ru", "phone": "+70236080741"}
0005432328700	AEA571	4104 088989	MARINA PETROVA	{"phone": "+70150466540"}
0005432328701	9B4D02	3106 422598	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov_26091971@postgrespro.ru", "phone": "+70172593406"}
0005432328702	36FD6F	7782 694360	DARYA ILINA	{"phone": "+70784472788"}
0005432328703	36FD6F	1609 152030	DMITRIY NAUMOV	{"phone": "+70399614145"}
0005432328704	F0E635	3588 909570	ALEKSEY ZHUKOV	{"phone": "+70735949243"}
0005432328705	F0E635	5460 612654	ALEKSANDR VASILEV	{"phone": "+70006671364"}
0005432328706	9DDBDB	8578 036391	IRINA BORISOVA	{"phone": "+70098192755"}
0005432328707	128F76	5336 353232	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_101973@postgrespro.ru", "phone": "+70996809729"}
0005432328708	454F23	3256 974275	ULYANA TITOVA	{"phone": "+70847038892"}
0005432328709	2CFC5C	3427 765799	ELENA ANISIMOVA	{"email": "anisimova_elena1978@postgrespro.ru", "phone": "+70870780966"}
0005432328710	1AFBEB	5072 475928	MARIYA FILIPPOVA	{"email": "filippovam20011976@postgrespro.ru", "phone": "+70459426958"}
0005432328711	1AFBEB	3998 820957	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.011973@postgrespro.ru", "phone": "+70802732527"}
0005432328712	9838CA	7161 723128	FEDOR KOZLOV	{"email": "fedor_kozlov_01081969@postgrespro.ru", "phone": "+70215375137"}
0005432328713	87DA79	2921 296313	YULIYA TITOVA	{"phone": "+70891710162"}
0005432328714	3D3089	3206 684712	OLEG VOROBEV	{"phone": "+70910904257"}
0005432328715	BF5C71	1640 471336	OLGA PETROVA	{"email": "petrova_olga16061966@postgrespro.ru", "phone": "+70966866786"}
0005432328716	7E1DDB	6270 112642	SERGEY OSIPOV	{"phone": "+70383827259"}
0005432328717	7E1DDB	1094 137658	ILYA MOROZOV	{"phone": "+70100476292"}
0005432328718	92A22F	6997 936870	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev111972@postgrespro.ru", "phone": "+70306461128"}
0005432328719	48DE41	3587 091648	EKATERINA BOGDANOVA	{"phone": "+70382869848"}
0005432328720	48DE41	3891 206925	IGOR KISELEV	{"email": "kiselev-i.041973@postgrespro.ru", "phone": "+70639315901"}
0005432328721	216528	7545 919446	NADEZHDA FILIPPOVA	{"phone": "+70562053394"}
0005432328722	216528	5952 905466	PAVEL DMITRIEV	{"phone": "+70376890956"}
0005432328723	7340C4	5324 710402	SERGEY MARTYNOV	{"phone": "+70263371490"}
0005432328724	D28AEA	5040 705611	VLADIMIR ROMANOV	{"email": "romanov.vladimir-05031970@postgrespro.ru", "phone": "+70015215546"}
0005432328725	26DDFE	8017 247373	IVAN NIKITIN	{"email": "nikitin.ivan061968@postgrespro.ru", "phone": "+70503783482"}
0005432328726	26DDFE	9507 330715	VALENTINA KRASNOVA	{"phone": "+70827373677"}
0005432328727	F8D07E	1337 142624	LILIYA FOMINA	{"email": "l-fomina-05071980@postgrespro.ru", "phone": "+70185416069"}
0005432328728	A5093E	7176 797234	DMITRIY IVANOV	{"email": "d.ivanov.1984@postgrespro.ru", "phone": "+70368581586"}
0005432328729	A5093E	3481 783762	EKATERINA MOISEEVA	{"phone": "+70816243321"}
0005432328730	9465FD	3324 754675	NATALYA KUZNECOVA	{"phone": "+70897633696"}
0005432328732	24DDE4	4030 020022	VALENTINA TIKHONOVA	{"email": "tikhonova-valentina.031977@postgrespro.ru", "phone": "+70880851003"}
0005432328733	4EDA31	5498 111575	SVETLANA STEPANOVA	{"email": "stepanovas-061968@postgrespro.ru", "phone": "+70656529859"}
0005432328734	82FC0E	8669 612928	SERGEY VASILEV	{"email": "sergey.vasilev_1973@postgrespro.ru", "phone": "+70622228382"}
0005432328735	A392F7	6503 833171	VLADIMIR IVANOV	{"phone": "+70284097016"}
0005432328736	A392F7	2295 599351	EKATERINA ZHUKOVA	{"phone": "+70058903188"}
0005432328737	376075	6967 515033	ALEKSANDR VASILEV	{"phone": "+70445149876"}
0005432328738	376075	2141 487235	VALERIY PAVLOV	{"email": "v.pavlov.10061971@postgrespro.ru", "phone": "+70836598589"}
0005432328739	7E1473	8593 639918	ANATOLIY FROLOV	{"phone": "+70704706815"}
0005432328740	5EE980	6473 327895	ANATOLIY MIKHAYLOV	{"phone": "+70481594900"}
0005432328741	D9E78E	2765 586773	IRINA SERGEEVA	{"email": "irina.sergeeva.101961@postgrespro.ru", "phone": "+70684014292"}
0005432328742	DA0989	8078 959512	ALEKSANDR ANDREEV	{"phone": "+70036032911"}
0005432328743	DA0989	1690 592579	ALEKSEY SOROKIN	{"email": "a-sorokin1984@postgrespro.ru", "phone": "+70948887909"}
0005432328744	047E9C	3128 445999	MATVEY OSIPOV	{"phone": "+70716783568"}
0005432328745	344A0E	7090 891882	ALEKSANDR BORISOV	{"email": "borisov-aleksandr.041976@postgrespro.ru", "phone": "+70110704612"}
0005432328746	344A0E	2600 178496	YULIYA PETROVA	{"email": "petrova-y1964@postgrespro.ru", "phone": "+70543103425"}
0005432328747	180CFD	8800 964384	IVAN PAVLOV	{"phone": "+70255439959"}
0005432328748	AA50D3	5091 987363	VERA SIDOROVA	{"email": "v_sidorova_1976@postgrespro.ru", "phone": "+70695254233"}
0005432328749	AA50D3	2117 550939	NIKOLAY KULIKOV	{"email": "n_kulikov21111979@postgrespro.ru", "phone": "+70954122452"}
0005432328750	857D59	7688 285404	VIKTOR KOZLOV	{"email": "kozlov.viktor-1967@postgrespro.ru", "phone": "+70360139454"}
0005432328751	0654D0	1288 022903	VLADIMIR ROMANOV	{"email": "vladimir_romanov-1970@postgrespro.ru", "phone": "+70189550053"}
0005432328752	10AE80	9135 594359	YANA FEDOROVA	{"email": "y.fedorova1963@postgrespro.ru", "phone": "+70178654009"}
0005432328753	10AE80	5231 788036	ANATOLIY SOROKIN	{"email": "anatoliy.sorokin1971@postgrespro.ru", "phone": "+70815138685"}
0005432328754	C0FF25	4340 892006	TATYANA CHERNOVA	{"phone": "+70971369305"}
0005432328755	A82733	1852 387486	NATALYA VASILEVA	{"phone": "+70535916679"}
0005432328756	CD114B	2958 740744	ALEKSANDR SHEVCHENKO	{"phone": "+70650942925"}
0005432328757	CD114B	9615 735500	OLEG KARPOV	{"phone": "+70007706659"}
0005432328758	4DAF56	0709 725565	ALENA NIKITINA	{"phone": "+70743357300"}
0005432328759	5B7709	6511 151895	LYUBOV PETROVA	{"phone": "+70246646691"}
0005432328760	E4980C	7588 912523	SERGEY FEDOTOV	{"email": "fedotov_s031974@postgrespro.ru", "phone": "+70537733289"}
0005432328761	9B7ACA	1658 826869	ILYA POPOV	{"phone": "+70161042710"}
0005432328762	DB4DA9	5685 082704	MARINA ERMAKOVA	{"phone": "+70303603529"}
0005432328763	DB4DA9	8871 292207	LYUDMILA SAVELEVA	{"phone": "+70623694775"}
0005432328764	07ECA9	5267 755844	ARTEM YAKOVLEV	{"phone": "+70584061123"}
0005432328765	A15A61	7709 089734	NATALYA TIKHONOVA	{"email": "tikhonova_n-1976@postgrespro.ru", "phone": "+70520891388"}
0005432328766	72BDBF	2371 490420	ANATOLIY IVANOV	{"phone": "+70060788206"}
0005432328767	5AE4F9	0790 908855	ELENA GERASIMOVA	{"phone": "+70493686562"}
0005432328768	973C28	1632 848714	YURIY SMIRNOV	{"email": "y.smirnov-13071978@postgrespro.ru", "phone": "+70300382277"}
0005432328769	A1E9A5	2384 967066	MIKHAIL ANDREEV	{"email": "mandreev-05061973@postgrespro.ru", "phone": "+70597524307"}
0005432328770	3CDB95	9265 222094	TATYANA MAKAROVA	{"email": "t-makarova.24021969@postgrespro.ru", "phone": "+70052964542"}
0005432328771	CEF825	3910 731412	VLADIMIR FROLOV	{"email": "frolov_vladimir.1967@postgrespro.ru", "phone": "+70493867009"}
0005432328772	CEF825	8489 917898	NADEZHDA SIDOROVA	{"email": "sidorova.n_101983@postgrespro.ru", "phone": "+70994927621"}
0005432328773	A2B071	9190 576063	VYACHESLAV FOMIN	{"email": "v_fomin-04121973@postgrespro.ru", "phone": "+70226866620"}
0005432328774	5074C0	0893 238097	VLADIMIR ORLOV	{"phone": "+70514752946"}
0005432328775	F480DE	1757 348976	GALINA KUZNECOVA	{"phone": "+70668046193"}
0005432328776	D1174A	0833 631971	EVGENIY TARASOV	{"phone": "+70023723447"}
0005432328777	8109E1	9844 856052	NADEZHDA SMIRNOVA	{"email": "smirnova-nadezhda_21091976@postgrespro.ru", "phone": "+70875141355"}
0005432328778	6DC928	3302 445066	OLGA OVCHINNIKOVA	{"phone": "+70925837191"}
0005432328779	06DDFA	3323 535099	NATALYA ANISIMOVA	{"phone": "+70131329123"}
0005432328780	06DDFA	0452 359157	RIMMA ZHUKOVA	{"phone": "+70657571914"}
0005432328781	FBF1DC	4308 943259	NIKOLAY VASILEV	{"email": "nikolay-vasilev_041970@postgrespro.ru", "phone": "+70615643426"}
0005432328782	0B4FD1	1283 228963	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr_09111967@postgrespro.ru", "phone": "+70159928606"}
0005432328783	0B4FD1	0862 537890	ELIZAVETA NAZAROVA	{"phone": "+70107851427"}
0005432328784	A7E6EF	3211 457570	MARIYA LUKYANOVA	{"phone": "+70851570451"}
0005432328785	027A50	0027 973851	EGOR SERGEEV	{"phone": "+70729332301"}
0005432328786	9FB243	8787 250000	ANATOLIY TIKHONOV	{"email": "anatoliy-tikhonov-1972@postgrespro.ru", "phone": "+70524920486"}
0005432328787	EF14E0	6351 415677	ANATOLIY MELNIKOV	{"phone": "+70574552705"}
0005432328788	EF14E0	3524 809351	ILYA BONDARENKO	{"phone": "+70070839791"}
0005432328789	307163	2225 732490	ANDREY ROMANOV	{"phone": "+70565417306"}
0005432328790	307163	8989 183187	IRINA MAKSIMOVA	{"email": "i_maksimova28061985@postgrespro.ru", "phone": "+70542516063"}
0005432328791	FF0C47	1960 136212	PAVEL MAKAROV	{"email": "makarov-p_1973@postgrespro.ru", "phone": "+70159766333"}
0005432328792	ED77FD	6530 833396	OLGA KULIKOVA	{"phone": "+70933684033"}
0005432328793	ED77FD	3462 177324	KIRILL GORBUNOV	{"phone": "+70510633152"}
0005432328794	7D4035	1736 962299	ANASTASIYA DMITRIEVA	{"email": "anastasiya_dmitrieva-04111963@postgrespro.ru", "phone": "+70871843962"}
0005432328795	5EDB4B	1781 375384	ALEKSANDR MAKAROV	{"email": "a.makarov061955@postgrespro.ru", "phone": "+70442805735"}
0005432328796	0AAAEF	6181 038717	POLINA KRASNOVA	{"email": "polina.krasnova31011979@postgrespro.ru", "phone": "+70860182072"}
0005432328797	44E62E	9169 668898	NIKOLAY ALEKSEEV	{"phone": "+70258388887"}
0005432328798	A3A3BA	1145 582509	OLGA IVANOVA	{"phone": "+70142676541"}
0005432328799	8F0005	0032 725521	OLGA SEMENOVA	{"email": "semenovao1970@postgrespro.ru", "phone": "+70715752873"}
0005432328800	AB9A05	2356 739074	VLADISLAV MIRONOV	{"email": "mironovv.1952@postgrespro.ru", "phone": "+70772952803"}
0005432328801	AB9A05	2047 899509	LARISA FEDOROVA	{"phone": "+70899403501"}
0005432328802	AB9A05	2042 948917	MARIYA MIKHAYLOVA	{"email": "m-mikhaylova-21091984@postgrespro.ru", "phone": "+70324619023"}
0005432328803	AB9A05	7517 398379	ANASTASIYA KUZNECOVA	{"phone": "+70296278439"}
0005432328804	0AE1EB	1952 830611	ANDREY SAVELEV	{"phone": "+70461563121"}
0005432328805	0AE1EB	8226 779541	ALIYA ANISIMOVA	{"phone": "+70846130872"}
0005432328806	4DC443	1820 422463	ANDREY NOVIKOV	{"email": "novikov-a_061980@postgrespro.ru", "phone": "+70678926304"}
0005432328807	CCC20F	8580 389220	VERA NIKOLAEVA	{"phone": "+70285138349"}
0005432328808	F05DCE	0871 850769	ELENA MIRONOVA	{"email": "emironova_06091970@postgrespro.ru", "phone": "+70296156935"}
0005432328809	F05DCE	6309 260919	GALINA SAVELEVA	{"phone": "+70744254797"}
0005432328810	F05DCE	8124 914598	NIKOLAY VOLKOV	{"email": "volkov.nikolay1973@postgrespro.ru", "phone": "+70062596735"}
0005432328811	53F215	1665 487361	NIKOLAY NOVIKOV	{"phone": "+70141178750"}
0005432328812	53F215	3705 517496	ELENA KUDRYASHOVA	{"email": "kudryashova-e.121969@postgrespro.ru", "phone": "+70756302893"}
0005432328813	E17286	6825 393940	MARINA ANDREEVA	{"email": "andreeva.marina11111976@postgrespro.ru", "phone": "+70461025593"}
0005432328814	2FBCAA	5024 651360	ELENA VASILEVA	{"email": "elena_vasileva.14041968@postgrespro.ru", "phone": "+70286312152"}
0005432328815	A7BCFE	8283 801517	IRINA FROLOVA	{"phone": "+70111327465"}
0005432328816	AB631A	4407 229796	EKATERINA MAKSIMOVA	{"email": "maksimova.e21091966@postgrespro.ru", "phone": "+70082458873"}
0005432328817	2A602A	2935 920169	DMITRIY POPOV	{"phone": "+70568628189"}
0005432328818	2A602A	8801 254955	SERGEY VASILEV	{"phone": "+70194481669"}
0005432328819	2A602A	0828 069814	VALENTINA CHERNOVA	{"email": "chernova_valentina-081974@postgrespro.ru", "phone": "+70310779001"}
0005432328820	B4EC99	6777 673344	IRINA FEDOROVA	{"email": "fedorova.irina13071990@postgrespro.ru", "phone": "+70007009736"}
0005432328821	A00740	5657 117279	LILIYA MIRONOVA	{"phone": "+70034321644"}
0005432328822	BC6504	2346 568414	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva.1975@postgrespro.ru", "phone": "+70093326093"}
0005432328823	BC6504	3166 678814	OKSANA LAZAREVA	{"phone": "+70196972738"}
0005432328824	068F78	6480 727261	DENIS MOROZOV	{"email": "d_morozov-23091974@postgrespro.ru", "phone": "+70217294015"}
0005432328825	DC616C	5671 430831	MIKHAIL FILIPPOV	{"email": "filippov-m.25021968@postgrespro.ru", "phone": "+70239238661"}
0005432328826	FB276A	7835 297979	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v.011967@postgrespro.ru", "phone": "+70473898803"}
0005432328827	FB276A	3465 770976	DANIL YAKOVLEV	{"phone": "+70202845109"}
0005432328828	FB276A	8766 706173	DARYA KALININA	{"email": "d-kalinina.041963@postgrespro.ru", "phone": "+70952932121"}
0005432328829	66C198	2866 432095	OLGA SOLOVEVA	{"email": "soloveva.olga_20101977@postgrespro.ru", "phone": "+70006949102"}
0005432328830	66C198	4145 823285	VALENTINA BORISOVA	{"phone": "+70786133243"}
0005432328831	2721BA	2046 767085	VERONIKA LOGINOVA	{"email": "v.loginova_31101966@postgrespro.ru", "phone": "+70722463588"}
0005432328832	37429E	3348 722292	OLEG MIKHAYLOV	{"email": "o.mikhaylov_041973@postgrespro.ru", "phone": "+70220380545"}
0005432328833	489172	6886 448773	GALINA POPOVA	{"phone": "+70378303469"}
0005432328834	489172	2094 884438	NIKOLAY PETROV	{"phone": "+70296609905"}
0005432328835	F14838	7203 454897	VSEVOLOD KONOVALOV	{"phone": "+70124102176"}
0005432328836	A86E35	4929 151785	ALEKSANDR BORISOV	{"email": "a-borisov23121976@postgrespro.ru", "phone": "+70462873951"}
0005432328837	93FFC2	1670 450500	BOGDAN KUZNECOV	{"phone": "+70832828265"}
0005432328838	AF2D7F	0634 601248	PETR FEDOTOV	{"phone": "+70059253043"}
0005432328839	3C2F8F	8330 806496	ANTONINA LEBEDEVA	{"email": "lebedeva_antonina23021974@postgrespro.ru", "phone": "+70859837149"}
0005432328840	3C2F8F	9375 970829	ALEKSANDR MIRONOV	{"phone": "+70253558210"}
0005432328841	AF1EFA	6961 385469	SANIYA FEDOROVA	{"email": "fedorova-s-061974@postgrespro.ru", "phone": "+70267534422"}
0005432328842	AF1EFA	1636 526211	RAISA KARPOVA	{"phone": "+70555570217"}
0005432328843	AF1EFA	8809 797071	VALENTINA PETROVA	{"email": "v-petrova.041969@postgrespro.ru", "phone": "+70881438969"}
0005432328844	D5DFB6	5333 442618	NINA ABRAMOVA	{"email": "abramova_nina-30121969@postgrespro.ru", "phone": "+70217658975"}
0005432328845	E80E5E	5493 678364	ANDREY OSIPOV	{"email": "andrey.osipov.09121970@postgrespro.ru", "phone": "+70794776278"}
0005432328846	FDFD95	7201 979625	MARIYA KUZNECOVA	{"email": "m-kuznecova1974@postgrespro.ru", "phone": "+70448017363"}
0005432328847	FDFD95	7608 464682	LYUBOV EGOROVA	{"email": "egorova_l-28111970@postgrespro.ru", "phone": "+70946384087"}
0005432328848	303EF5	3361 131555	ALBINA ORLOVA	{"phone": "+70063157340"}
0005432328849	89AD68	5006 495103	VIKTOR AFANASEV	{"email": "viktorafanasev041979@postgrespro.ru", "phone": "+70224044216"}
0005432328850	B6808F	4134 148145	LYUDMILA ZAKHAROVA	{"phone": "+70068161888"}
0005432328851	B6808F	6959 120467	NAILYA FOMINA	{"phone": "+70362694358"}
0005432328852	21B083	8338 193146	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev29081975@postgrespro.ru", "phone": "+70283668683"}
0005432328854	6B8337	0088 834535	ALEKSANDRA NESTEROVA	{"email": "nesterova-aleksandra1967@postgrespro.ru", "phone": "+70646338589"}
0005432328855	428C54	4442 654370	GALIYA GUSEVA	{"email": "galiya.guseva111972@postgrespro.ru", "phone": "+70324231100"}
0005432328856	3C01CB	9675 839194	VALERIYA KUDRYASHOVA	{"phone": "+70971254799"}
0005432328857	C8A344	4170 667406	LYUDMILA BORISOVA	{"email": "borisova_lyudmila_1974@postgrespro.ru", "phone": "+70395602795"}
0005432328858	C8A344	4961 836280	REGINA TROFIMOVA	{"email": "r_trofimova-1966@postgrespro.ru", "phone": "+70499814287"}
0005432328859	335F4B	1566 254165	LYUDMILA SOROKINA	{"phone": "+70839468232"}
0005432328860	4243A9	1867 677076	VLADIMIR KULIKOV	{"phone": "+70252941291"}
0005432328861	B9C0F0	8197 636933	SVETLANA EFREMOVA	{"phone": "+70413166546"}
0005432328862	1FAE8C	5439 688843	DMITRIY MIKHAYLOV	{"email": "d.mikhaylov.01011975@postgrespro.ru", "phone": "+70534380767"}
0005432328863	1FAE8C	8742 151658	DENIS MOROZOV	{"email": "denis.morozov.1986@postgrespro.ru", "phone": "+70834501371"}
0005432328864	1FAE8C	5243 904079	SERGEY ZAKHAROV	{"email": "zakharov_sergey-1972@postgrespro.ru", "phone": "+70213903679"}
0005432328865	92B93F	6632 578164	ILDAR SIDOROV	{"phone": "+70449200073"}
0005432328866	92B93F	7034 449097	IVAN DMITRIEV	{"email": "ivan_dmitriev-19021983@postgrespro.ru", "phone": "+70676795087"}
0005432328867	B534D8	8755 946545	NATALYA BARANOVA	{"phone": "+70951233158"}
0005432328868	9543FA	9976 393057	KARINA IVANOVA	{"phone": "+70892787247"}
0005432328869	9543FA	1784 830672	ZOYA YAKOVLEVA	{"phone": "+70916401856"}
0005432328870	26087A	1997 806876	ALEKSANDR ALEKSANDROV	{"phone": "+70939241852"}
0005432328871	C641F9	5231 220715	NINA RODIONOVA	{"email": "rodionova_n-18111976@postgrespro.ru", "phone": "+70223484110"}
0005432328872	3A3A32	6612 794510	EKATERINA KISELEVA	{"email": "e_kiseleva.1966@postgrespro.ru", "phone": "+70062492284"}
0005432328873	3A3A32	1125 494350	VASILIY SEMENOV	{"email": "semenov-v.1974@postgrespro.ru", "phone": "+70974929828"}
0005432328874	E9778C	7462 909049	IVAN SOKOLOV	{"email": "sokolov-i-1965@postgrespro.ru", "phone": "+70244752071"}
0005432328875	A72CAA	6212 447155	ELENA ANDREEVA	{"email": "andreeva_elena-11051974@postgrespro.ru", "phone": "+70725937829"}
0005432328876	DD24E2	4833 480000	SERGEY SIDOROV	{"phone": "+70831345944"}
0005432328877	897709	6090 139991	ALEKSEY KUZNECOV	{"email": "a-kuznecov-091973@postgrespro.ru", "phone": "+70910925195"}
0005432328878	F15691	3323 702742	NINA MELNIKOVA	{"email": "melnikova.nina27101974@postgrespro.ru", "phone": "+70778599005"}
0005432328879	1C3741	7216 643708	IRINA FEDOROVA	{"phone": "+70035617876"}
0005432328880	0C0766	2998 972344	DENIS MARTYNOV	{"email": "denis-martynov1969@postgrespro.ru", "phone": "+70877530090"}
0005432328881	AA87EF	3024 085819	NIKOLAY DAVYDOV	{"phone": "+70006568545"}
0005432328882	25319F	7840 130977	NIKOLAY SEMENOV	{"phone": "+70563474937"}
0005432328883	25319F	7244 667534	ZOYA IVANOVA	{"phone": "+70589599302"}
0005432328884	F56F1E	7995 875452	ZINAIDA LUKYANOVA	{"email": "lukyanova-z.111969@postgrespro.ru", "phone": "+70571732855"}
0005432328885	204459	6720 777043	ALEKSANDR SMIRNOV	{"phone": "+70417292345"}
0005432328886	757B26	5044 135723	VALERIY TIMOFEEV	{"email": "timofeev_valeriy.26081980@postgrespro.ru", "phone": "+70945480770"}
0005432328887	757B26	0625 659220	ANNA NAZAROVA	{"phone": "+70856714396"}
0005432328888	1E8EE3	2135 949318	ANASTASIYA PAVLOVA	{"email": "a.pavlova_17091968@postgrespro.ru", "phone": "+70150510671"}
0005432328889	B4CD55	3922 710617	ANDREY VASILEV	{"email": "vasilev.a_25071970@postgrespro.ru", "phone": "+70317220020"}
0005432328890	6DEE68	1672 362171	OLGA POLYAKOVA	{"email": "o-polyakova10041975@postgrespro.ru", "phone": "+70140078904"}
0005432328891	FB77CF	5384 979039	DMITRIY PAVLOV	{"email": "dpavlov-1975@postgrespro.ru", "phone": "+70589289894"}
0005432328892	FB77CF	0864 865484	ALEKSEY ALEKSANDROV	{"email": "aleksandrovaleksey-1970@postgrespro.ru", "phone": "+70698680115"}
0005432328893	FB77CF	4983 944172	ALBINA YAKOVLEVA	{"phone": "+70306087864"}
0005432328894	63FE5E	2883 414260	ALEKSANDRA CHERNOVA	{"email": "aleksandra_chernova101972@postgrespro.ru", "phone": "+70338457143"}
0005432328895	7A1624	3405 577502	ELENA TIKHONOVA	{"email": "tikhonovaelena.16081969@postgrespro.ru", "phone": "+70201287021"}
0005432328896	2852F5	8599 829304	IGOR NAUMOV	{"email": "naumov-i.071967@postgrespro.ru", "phone": "+70546465390"}
0005432328897	8950EF	6800 342226	EVGENIY NOVIKOV	{"phone": "+70007437238"}
0005432328898	E0A2D3	3109 001648	SVETLANA MELNIKOVA	{"email": "melnikova-svetlana14101964@postgrespro.ru", "phone": "+70028917428"}
0005432328899	4E61F7	0788 323269	NINA KULIKOVA	{"phone": "+70725772665"}
0005432328900	FE1E3A	8692 387309	IGOR BORISOV	{"email": "i-borisov18071978@postgrespro.ru", "phone": "+70181894756"}
0005432328901	775ED3	8397 690650	SERGEY GAVRILOV	{"phone": "+70337298185"}
0005432328902	A8A177	0685 760348	IGOR NIKOLAEV	{"email": "i-nikolaev-101965@postgrespro.ru", "phone": "+70899511616"}
0005432328903	E5A468	8410 128149	STANISLAV KOZLOV	{"email": "kozlov.s_1966@postgrespro.ru", "phone": "+70160664647"}
0005432328904	E5A468	2538 707290	LIDIYA MIRONOVA	{"phone": "+70443843957"}
0005432328905	8540FB	5813 534820	EVGENIY CHERNOV	{"phone": "+70752783848"}
0005432328906	C98E39	3994 186657	EVGENIY MELNIKOV	{"email": "melnikov.evgeniy.111974@postgrespro.ru", "phone": "+70031503977"}
0005432328907	A919BE	3791 304190	LIDIYA DANILOVA	{"phone": "+70575092397"}
0005432328908	A919BE	6282 442213	VLADIMIR ORLOV	{"email": "v-orlov-111967@postgrespro.ru", "phone": "+70973364385"}
0005432328909	AA7BAD	6785 217206	YULIYA KISELEVA	{"email": "kiseleva-yuliya31101969@postgrespro.ru", "phone": "+70998506858"}
0005432328910	D313F6	6436 629844	ANATOLIY KRASNOV	{"email": "krasnovanatoliy-1964@postgrespro.ru", "phone": "+70003708949"}
0005432328911	D313F6	7657 561637	OLGA DENISOVA	{"phone": "+70135112239"}
0005432328912	D313F6	4900 777383	SERGEY ORLOV	{"phone": "+70477308986"}
0005432328913	167B22	0086 925855	IRINA KRASNOVA	{"phone": "+70773288016"}
0005432328914	5B4343	7350 265088	ROMAN AFANASEV	{"email": "afanasev-roman-1978@postgrespro.ru", "phone": "+70493110103"}
0005432328915	D07F3A	0284 276331	VALENTINA ALEKSEEVA	{"phone": "+70916128924"}
0005432328916	4EEDCB	3641 964860	YURIY IVANOV	{"email": "ivanov_yuriy_01031980@postgrespro.ru", "phone": "+70013712765"}
0005432328917	257187	9469 988733	ELENA POLYAKOVA	{"email": "e.polyakova041977@postgrespro.ru", "phone": "+70801645259"}
0005432328918	C5BFF9	8914 563405	NADEZHDA YAKOVLEVA	{"phone": "+70194461777"}
0005432328919	58D151	2314 960950	VYACHESLAV MELNIKOV	{"email": "melnikovvyacheslav.1975@postgrespro.ru", "phone": "+70600377535"}
0005432328920	0BDDE6	4794 064954	EVGENIY DENISOV	{"email": "denisov-e25041966@postgrespro.ru", "phone": "+70833670590"}
0005432328921	0BDDE6	0969 614686	MIKHAIL VLASOV	{"email": "vlasov-mikhail-25101979@postgrespro.ru", "phone": "+70676848989"}
0005432328922	0BDDE6	0895 449369	IRINA BELYAEVA	{"phone": "+70184577944"}
0005432328923	C9B107	6246 394328	ELENA KUZNECOVA	{"phone": "+70700268328"}
0005432328924	C9B107	9343 892129	ALEKSANDR NIKOLAEV	{"phone": "+70616997904"}
0005432328925	C9B107	6468 810995	DMITRIY SAVELEV	{"phone": "+70107244860"}
0005432328926	F83697	0880 593821	KSENIYA ARKHIPOVA	{"email": "arkhipovakseniya-16031967@postgrespro.ru", "phone": "+70968892737"}
0005432328927	BB872F	7156 133429	ANASTASIYA BORISOVA	{"phone": "+70489467358"}
0005432328928	A3F555	2227 030100	LYUDMILA RYABOVA	{"email": "ryabova_lyudmila011978@postgrespro.ru", "phone": "+70014838089"}
0005432328929	A3F555	5956 710175	LYUDMILA KOZLOVA	{"phone": "+70210151691"}
0005432328930	840F35	5682 251468	FANIYA AFANASEVA	{"phone": "+70949278212"}
0005432328931	34FEEA	2920 188182	SERGEY MAKSIMOV	{"phone": "+70631273094"}
0005432328932	60011A	5876 463330	LIDIYA CHERNOVA	{"email": "l-chernova_24111981@postgrespro.ru", "phone": "+70865297217"}
0005432328933	4ABBEE	7924 120701	ILYA KUZNECOV	{"phone": "+70821642467"}
0005432328934	75BDC0	3700 139061	ZARINA ANTONOVA	{"phone": "+70605848571"}
0005432328935	14A38C	5725 859113	MARIYA NIKOLAEVA	{"email": "mariya_nikolaeva-1968@postgrespro.ru", "phone": "+70543727363"}
0005432328936	14A38C	2340 484034	VLADIMIR AFANASEV	{"email": "v_afanasev.09071975@postgrespro.ru", "phone": "+70980835593"}
0005432328937	994389	5730 733464	INESSA KUZMINA	{"phone": "+70655958329"}
0005432328938	4B721A	6721 552448	DARYA MAKSIMOVA	{"email": "maksimova.darya.051970@postgrespro.ru", "phone": "+70986223000"}
0005432328939	4B721A	1066 842797	SAVELIY KUZNECOV	{"email": "saveliy.kuznecov-20011968@postgrespro.ru", "phone": "+70552272612"}
0005432328940	4F570F	2627 346150	SVETLANA MIKHAYLOVA	{"phone": "+70676804105"}
0005432328941	9559E0	3146 657343	ANTON MIRONOV	{"phone": "+70783465395"}
0005432328942	333DA1	5584 686986	MAKSIM SCHERBAKOV	{"phone": "+70841801572"}
0005432328943	333DA1	4011 868028	MARK VOLKOV	{"email": "mark_volkov_1968@postgrespro.ru", "phone": "+70607004532"}
0005432328944	C26CE4	0604 000423	TATYANA ZAKHAROVA	{"email": "t_zakharova-09031973@postgrespro.ru", "phone": "+70412218528"}
0005432328945	B834DB	1962 680241	VYACHESLAV SOKOLOV	{"phone": "+70279054815"}
0005432328946	C6B407	9013 060470	ANNA KUZMINA	{"phone": "+70011838159"}
0005432328947	C6B407	3122 717608	NATALYA OSIPOVA	{"phone": "+70959255601"}
0005432328948	51321D	2586 765668	ANASTASIYA KOROLEVA	{"phone": "+70566777134"}
0005432328949	3BD621	7217 288855	OLEG ALEKSEEV	{"phone": "+70383574589"}
0005432328950	BDA37C	7645 672104	DENIS VASILEV	{"email": "denisvasilev-20031976@postgrespro.ru", "phone": "+70352053638"}
0005432328951	BDA37C	7860 618930	ANDREY KOZLOV	{"phone": "+70946199748"}
0005432328952	C8E328	3289 628432	PELAGEYA ORLOVA	{"email": "p_orlova-051969@postgrespro.ru", "phone": "+70739203629"}
0005432328953	39BF07	7557 672606	TAMARA MOROZOVA	{"email": "morozova.tamara26081962@postgrespro.ru", "phone": "+70086030785"}
0005432328954	A8241C	6095 868880	YANA ROMANOVA	{"phone": "+70538367874"}
0005432328955	A8241C	2707 286706	ALENA IVANOVA	{"email": "a.ivanova-051964@postgrespro.ru", "phone": "+70114522405"}
0005432328956	A8241C	5541 505253	TATYANA ROMANOVA	{"email": "romanova.t031960@postgrespro.ru", "phone": "+70045653875"}
0005432328957	A98B85	6161 773089	IRINA ZAKHAROVA	{"phone": "+70720065597"}
0005432328958	02BA11	4816 167151	EVGENIY FILIPPOV	{"phone": "+70968095504"}
0005432328959	FD4DCE	6712 174239	SVETLANA KUZMINA	{"phone": "+70673122090"}
0005432328960	70C2AE	8092 165635	DANIIL EGOROV	{"phone": "+70548331677"}
0005432328961	2555AF	4379 859811	RAISA FEDOROVA	{"phone": "+70371575127"}
0005432328962	2555AF	0601 915492	EVGENIY NIKOLAEV	{"email": "enikolaev-081970@postgrespro.ru", "phone": "+70242094458"}
0005432328963	3B2ACC	4371 243852	EGOR KAZAKOV	{"email": "kazakov-e.17011973@postgrespro.ru", "phone": "+70204568201"}
0005432328964	F590AA	4504 316767	NIKOLAY VOROBEV	{"phone": "+70259087459"}
0005432328965	509944	0721 841970	MARINA MAKAROVA	{"phone": "+70246548731"}
0005432328966	509944	9098 690969	OLGA VLASOVA	{"email": "o-vlasova-1963@postgrespro.ru", "phone": "+70889266764"}
0005432328967	33E60E	7231 704614	OLGA OSIPOVA	{"email": "osipova.olga28051974@postgrespro.ru", "phone": "+70226627882"}
0005432328968	33E60E	2432 323357	VADIM NOVIKOV	{"phone": "+70890344557"}
0005432328969	B99BF9	6673 956617	LYUDMILA ZAKHAROVA	{"email": "zakharova-lyudmila04041965@postgrespro.ru", "phone": "+70489515995"}
0005432328970	B99BF9	1028 042191	DMITRIY DENISOV	{"email": "denisov-d.031978@postgrespro.ru", "phone": "+70074576142"}
0005432328971	4E7815	4715 225330	VALERIY SIDOROV	{"email": "vsidorov041979@postgrespro.ru", "phone": "+70558521161"}
0005432328972	AABCBD	4278 425101	VLADIMIR IVANOV	{"phone": "+70328236643"}
0005432328973	AABCBD	3369 890736	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov.071976@postgrespro.ru", "phone": "+70034634956"}
0005432328974	AABCBD	2203 536953	MIKHAIL POPOV	{"email": "popov.m-23041978@postgrespro.ru", "phone": "+70714201512"}
0005432328975	B9897C	1111 379617	ALENA MIKHAYLOVA	{"email": "mikhaylovaalena.11111972@postgrespro.ru", "phone": "+70041930882"}
0005432328976	B9897C	8328 589688	ANDREY FOMIN	{"email": "fomin.andrey07101959@postgrespro.ru", "phone": "+70184439158"}
0005432328977	A980E8	0677 421557	ALINA KONDRATEVA	{"phone": "+70472182981"}
0005432328978	A980E8	1905 704751	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a.091980@postgrespro.ru", "phone": "+70515593880"}
0005432328979	A980E8	7992 290629	EVGENIYA STEPANOVA	{"phone": "+70262870500"}
0005432328980	583621	9014 064947	IRINA IVANOVA	{"phone": "+70472196743"}
0005432328981	583621	8265 075537	VIKTORIYA MAKAROVA	{"email": "viktoriya_makarova.23091984@postgrespro.ru", "phone": "+70975430717"}
0005432328982	B3CF11	0507 403811	ALEKSANDR TIMOFEEV	{"phone": "+70351017407"}
0005432328983	B3CF11	9110 224510	GALINA FADEEVA	{"email": "fadeeva-g21041980@postgrespro.ru", "phone": "+70141552706"}
0005432328984	E7E765	7721 112619	VALENTINA FROLOVA	{"email": "vfrolova-101974@postgrespro.ru", "phone": "+70708494291"}
0005432328985	1CF32E	9316 115981	ANNA VOLKOVA	{"email": "anna-volkova111974@postgrespro.ru", "phone": "+70206579759"}
0005432328986	1CF32E	8785 436013	DENIS TIMOFEEV	{"phone": "+70669688231"}
0005432328987	472489	1742 114259	OLESYA KOMAROVA	{"email": "olesya_komarova.071961@postgrespro.ru", "phone": "+70994501583"}
0005432328988	472489	2046 399819	ALEKSANDRA KUZNECOVA	{"phone": "+70372073850"}
0005432328989	E6DB42	8883 568258	DARYA VOLKOVA	{"email": "volkova_darya041963@postgrespro.ru", "phone": "+70553230285"}
0005432328990	D2DB9F	4553 306893	ROMAN ANTONOV	{"email": "antonov.r_22121965@postgrespro.ru", "phone": "+70211976588"}
0005432328991	10F5F6	3559 021747	OLGA KALININA	{"phone": "+70134066526"}
0005432328992	249846	0399 987207	IVAN VASILEV	{"phone": "+70579863454"}
0005432328993	579A7F	4471 265869	ALEKSEY VASILEV	{"email": "vasilevaleksey.06121972@postgrespro.ru", "phone": "+70183700946"}
0005432328994	B15CE0	3909 794997	KONSTANTIN GORBUNOV	{"phone": "+70138587495"}
0005432328995	739A45	7975 970719	TAMARA KOROLEVA	{"phone": "+70455229845"}
0005432328996	2AEB31	0467 264261	DANILA YAKOVLEV	{"phone": "+70503125202"}
0005432328997	F9F5B6	4306 862288	MARIYA CHERNOVA	{"phone": "+70477155923"}
0005432328998	262A65	9159 030895	ALEKSANDR DMITRIEV	{"email": "admitriev091969@postgrespro.ru", "phone": "+70234157493"}
0005432328999	262A65	9318 826046	ELEONORA ANTONOVA	{"phone": "+70648192093"}
0005432329000	247D86	2673 502284	TATYANA GRISHINA	{"email": "grishinat-1978@postgrespro.ru", "phone": "+70626346097"}
0005432329001	F03E1B	6848 266870	TATYANA ILINA	{"phone": "+70199091685"}
0005432329002	223076	5560 191555	KONSTANTIN FEDOROV	{"email": "fedorov.k.031973@postgrespro.ru", "phone": "+70032569246"}
0005432329003	223076	1187 859050	SERGEY MATVEEV	{"email": "matveev_s_28111971@postgrespro.ru", "phone": "+70413228125"}
0005432329004	1344EA	1008 025443	IVAN VASILEV	{"phone": "+70464602592"}
0005432329005	1344EA	3688 965245	VITALIY CHERNOV	{"phone": "+70789256902"}
0005432329006	EDEA8A	0664 469652	VIKTORIYA POTAPOVA	{"phone": "+70739960914"}
0005432329007	0BA3CF	8121 230589	GALINA KOZLOVA	{"phone": "+70577116228"}
0005432329008	6EE527	7758 833901	EVGENIY PAVLOV	{"phone": "+70499107181"}
0005432329009	6EE527	2392 499044	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov.101980@postgrespro.ru", "phone": "+70800382230"}
0005432329010	88375A	2095 339624	OLGA NESTEROVA	{"email": "nesterova_o-03061971@postgrespro.ru", "phone": "+70768789762"}
0005432329011	D32157	6723 886789	ALEKSEY SCHERBAKOV	{"phone": "+70472657496"}
0005432329012	E4ED80	7139 157992	VYACHESLAV ZAKHAROV	{"phone": "+70940638703"}
0005432329013	E4ED80	6302 611138	NINA IVANOVA	{"phone": "+70914002217"}
0005432329014	6B0224	0559 429913	ALEKSANDR EGOROV	{"phone": "+70753950319"}
0005432329015	C3335B	6580 844867	NADEZHDA SOROKINA	{"email": "nadezhda-sorokina_04031972@postgrespro.ru", "phone": "+70133781037"}
0005432329016	DD89F4	9047 695896	IGOR ZAKHAROV	{"phone": "+70995768740"}
0005432329017	89995F	1819 473756	VLADIMIR PETROV	{"email": "vladimir-petrov1975@postgrespro.ru", "phone": "+70174160048"}
0005432329018	38DAE0	0101 721173	NINA SEMENOVA	{"email": "n-semenova_1971@postgrespro.ru", "phone": "+70871627343"}
0005432329019	69C8CD	6004 928997	MIKHAIL FOMIN	{"email": "m.fomin.09061965@postgrespro.ru", "phone": "+70746330149"}
0005432329020	ABA70B	0666 443056	ANDREY POPOV	{"phone": "+70434653044"}
0005432329021	ABA70B	4488 174630	DMITRIY MARTYNOV	{"email": "martynovdmitriy-1980@postgrespro.ru", "phone": "+70311660035"}
0005432329022	5D6102	7794 330610	EDUARD TIKHONOV	{"email": "e.tikhonov-1978@postgrespro.ru", "phone": "+70692335943"}
0005432329023	5D6102	0708 947644	YULIYA PETROVA	{"email": "ypetrova_12011977@postgrespro.ru", "phone": "+70496873689"}
0005432329024	F49C73	6135 623474	EVGENIYA KONOVALOVA	{"phone": "+70848854424"}
0005432329025	7E287F	3548 669618	ALEKSEY SCHERBAKOV	{"phone": "+70182021341"}
0005432329026	F4D4E2	6969 911550	MARINA POLYAKOVA	{"email": "polyakova_marina_1975@postgrespro.ru", "phone": "+70120225110"}
0005432329027	F4D4E2	7803 817089	VASILIY MELNIKOV	{"phone": "+70837071826"}
0005432329028	F5207E	8413 480259	ILYA SMIRNOV	{"email": "i.smirnov.091974@postgrespro.ru", "phone": "+70214514960"}
0005432329029	5EC968	9756 495533	NATALYA BORISOVA	{"phone": "+70024230164"}
0005432329030	5EC968	3047 753768	VALERIYA POTAPOVA	{"email": "potapova-valeriya.021986@postgrespro.ru", "phone": "+70087523741"}
0005432329031	FA916E	4419 871373	YULIYA MIKHAYLOVA	{"email": "yuliya_mikhaylova-1973@postgrespro.ru", "phone": "+70165446596"}
0005432329032	FA916E	0377 365509	MIKHAIL GORBUNOV	{"email": "mikhailgorbunov-1973@postgrespro.ru", "phone": "+70397556205"}
0005432329033	20F36B	3094 524936	EKATERINA ANDREEVA	{"phone": "+70086740252"}
0005432329034	B34F22	7186 568682	TATYANA YAKOVLEVA	{"phone": "+70922763660"}
0005432329035	B34F22	8585 013130	TATYANA NIKITINA	{"phone": "+70140447150"}
0005432329036	7F5536	0635 165233	RAMIS ALEKSEEV	{"email": "alekseev-r-1962@postgrespro.ru", "phone": "+70613249776"}
0005432329037	9B0415	7305 349042	POLINA ROMANOVA	{"email": "romanova_polina.011983@postgrespro.ru", "phone": "+70016259689"}
0005432329038	9B0415	8534 565415	RAMIL ZAYCEV	{"phone": "+70506683564"}
0005432329039	51A4BC	7529 365557	SERGEY NIKITIN	{"phone": "+70679198168"}
0005432329040	51A4BC	7622 287094	TATYANA ANTONOVA	{"phone": "+70776650358"}
0005432329041	ABFB5D	3176 318216	VLADIMIR NIKOLAEV	{"email": "nikolaev_vladimir_15021980@postgrespro.ru", "phone": "+70486573172"}
0005432329042	55F7DB	4614 721307	VASILIY MIRONOV	{"email": "mironovv.1972@postgrespro.ru", "phone": "+70436477742"}
0005432329043	55F7DB	4601 108205	ELENA SEMENOVA	{"email": "semenovaelena051975@postgrespro.ru", "phone": "+70793810835"}
0005432329044	146E89	5105 595860	YURIY MAKAROV	{"email": "makarov-yuriy1974@postgrespro.ru", "phone": "+70139262660"}
0005432329045	146E89	8281 543069	TATYANA ILINA	{"email": "ilinat.1978@postgrespro.ru", "phone": "+70087649436"}
0005432329046	017596	3418 760632	OLGA KAZAKOVA	{"email": "olga-kazakova-1971@postgrespro.ru", "phone": "+70259905230"}
0005432329047	DA2CE3	8132 214865	ALEKSEY MOISEEV	{"email": "aleksey_moiseev1964@postgrespro.ru", "phone": "+70387875603"}
0005432329048	818D6C	9381 361507	VITALIY KUZNECOV	{"phone": "+70014763761"}
0005432329049	235D27	5624 484315	IRINA MIRONOVA	{"email": "irina.mironova031980@postgrespro.ru", "phone": "+70540928465"}
0005432329050	388DF3	2063 110917	ALEKSANDR BONDARENKO	{"phone": "+70508005982"}
0005432329051	388DF3	2848 331605	VALENTINA ALEKSEEVA	{"email": "alekseeva_valentina20021965@postgrespro.ru", "phone": "+70848959344"}
0005432329052	57DAF9	6375 154286	SERGEY SMIRNOV	{"phone": "+70037100571"}
0005432329053	3CA20B	6066 950476	NINA YAKOVLEVA	{"email": "yakovleva.n.081976@postgrespro.ru", "phone": "+70459683333"}
0005432329054	FD20CB	8213 453049	TATYANA ARKHIPOVA	{"email": "arkhipova_tatyana_061986@postgrespro.ru", "phone": "+70527660384"}
0005432329055	0BB127	0063 128610	ELENA NIKIFOROVA	{"phone": "+70523608081"}
0005432329056	6E8837	7458 249059	LIDIYA PAVLOVA	{"email": "l.pavlova_1967@postgrespro.ru", "phone": "+70223647053"}
0005432329057	2F988D	8333 372876	DANIIL KONOVALOV	{"email": "konovalov.d-25041973@postgrespro.ru", "phone": "+70366813996"}
0005432329058	D3B088	2768 981302	LYUBOV PETROVA	{"email": "l-petrova021979@postgrespro.ru", "phone": "+70235906059"}
0005432329059	A59616	2492 635842	ANDREY SERGEEV	{"email": "a-sergeev.1968@postgrespro.ru", "phone": "+70809231753"}
0005432329060	A59616	9850 166376	ANDREY DMITRIEV	{"email": "andrey-dmitriev.111974@postgrespro.ru", "phone": "+70888250731"}
0005432329061	F8CF01	7574 768731	EVGENIY ZAKHAROV	{"phone": "+70513556618"}
0005432329062	086D7F	0483 807798	ELENA FILIPPOVA	{"email": "e_filippova_15031974@postgrespro.ru", "phone": "+70418609225"}
0005432329063	7B885F	8386 165916	EVGENIYA VLASOVA	{"email": "vlasovaevgeniya.071975@postgrespro.ru", "phone": "+70331369736"}
0005432329064	FD6983	4289 728092	ANASTASIYA CHERNOVA	{"email": "chernova-anastasiya.101974@postgrespro.ru", "phone": "+70678199739"}
0005432329065	FD6983	1133 679750	STANISLAV IVANOV	{"email": "stanislav.ivanov-121974@postgrespro.ru", "phone": "+70844250632"}
0005432329066	2DC99E	4486 741317	ALEKSEY FROLOV	{"email": "frolov_aleksey1974@postgrespro.ru", "phone": "+70313919959"}
0005432329067	2DC99E	0792 644763	VLADIMIR DMITRIEV	{"phone": "+70058978386"}
0005432329068	2D3148	3623 713532	FARID STEPANOV	{"phone": "+70087576198"}
0005432329069	2D3148	7357 748992	SERGEY VOROBEV	{"email": "vorobev-s_1976@postgrespro.ru", "phone": "+70735960365"}
0005432329070	8A4607	7574 769753	GALINA SOKOLOVA	{"email": "sokolova_g-011983@postgrespro.ru", "phone": "+70905894554"}
0005432329071	E6D5AA	9948 704800	ARTEM DMITRIEV	{"email": "admitriev_1982@postgrespro.ru", "phone": "+70969736873"}
0005432329072	E6D5AA	5334 185271	SERGEY KUZNECOV	{"email": "kuznecov-sergey071972@postgrespro.ru", "phone": "+70427675462"}
0005432329073	95E19F	1420 281036	ALEKSEY ISAEV	{"email": "isaev_aleksey.061969@postgrespro.ru", "phone": "+70286593139"}
0005432329074	CADE74	3937 411038	ILDAR FROLOV	{"email": "ildar.frolov_1973@postgrespro.ru", "phone": "+70874730350"}
0005432329075	CADE74	6325 280738	VIKTOR IVANOV	{"email": "ivanov_viktor_041965@postgrespro.ru", "phone": "+70137875579"}
0005432329076	2D3B96	0065 338650	ALBINA OVCHINNIKOVA	{"email": "ovchinnikova_albina-051960@postgrespro.ru", "phone": "+70797290493"}
0005432329077	9888FA	8953 551341	NATALYA KUZNECOVA	{"phone": "+70219173924"}
0005432329078	75CE3C	7722 020302	TATYANA BORISOVA	{"phone": "+70943478022"}
0005432329079	7E2BDB	9687 212664	EKATERINA KOROLEVA	{"email": "koroleva-e.1963@postgrespro.ru", "phone": "+70860759461"}
0005432329080	1DD56F	6422 863422	ELENA BELOVA	{"email": "belovaelena08031963@postgrespro.ru", "phone": "+70603667918"}
0005432329081	75B1DE	1748 180526	VYACHESLAV RODIONOV	{"email": "vyacheslav_rodionov_1963@postgrespro.ru", "phone": "+70211593635"}
0005432329082	5204B4	6777 675044	TATYANA MATVEEVA	{"phone": "+70035452038"}
0005432329083	5204B4	7522 900659	SVETLANA KUDRYASHOVA	{"phone": "+70045150694"}
0005432329084	5204B4	0278 421518	AYRAT MAKSIMOV	{"email": "ayratmaksimov-1981@postgrespro.ru", "phone": "+70343727112"}
0005432329085	A88E9F	7561 088487	ELIZAVETA MOROZOVA	{"email": "elizaveta-morozova.1965@postgrespro.ru", "phone": "+70871837495"}
0005432329086	511833	9477 667620	MIKHAIL ZAYCEV	{"phone": "+70894676056"}
0005432329087	511833	5877 261916	ANNA EGOROVA	{"email": "egorova-anna.18021989@postgrespro.ru", "phone": "+70177003617"}
0005432329088	DC771A	0300 484384	MAKSIM VLASOV	{"email": "vlasov_m_05081977@postgrespro.ru", "phone": "+70018842637"}
0005432329089	DC771A	1101 032927	ALEKSANDR OSIPOV	{"phone": "+70440666989"}
0005432329090	4F0A5D	2499 731419	NIKOLAY FROLOV	{"email": "nikolay.frolov1963@postgrespro.ru", "phone": "+70158362105"}
0005432329091	9D4FD0	5562 852401	NIKOLAY BORISOV	{"phone": "+70232548716"}
0005432329092	2B4EDE	4230 475747	LYUDMILA ANDREEVA	{"email": "andreeva.lyudmila1968@postgrespro.ru", "phone": "+70842677649"}
0005432329093	4BA6BB	1058 307137	KIRILL DENISOV	{"email": "denisovk.23111966@postgrespro.ru", "phone": "+70648540557"}
0005432329094	76D9F9	5349 092948	ANDREY ABRAMOV	{"phone": "+70664155792"}
0005432329095	76D9F9	1470 780215	ALEKSEY NAUMOV	{"phone": "+70332589747"}
0005432329096	60373D	2821 479516	ARINA NIKIFOROVA	{"email": "arina-nikiforova_121973@postgrespro.ru", "phone": "+70759030003"}
0005432329097	9AEC31	5090 362248	ELENA VOLKOVA	{"email": "volkovae_121971@postgrespro.ru", "phone": "+70347293441"}
0005432329098	9AEC31	2154 666477	NIKOLAY ANDREEV	{"phone": "+70859257534"}
0005432329099	F0DF45	5035 194632	GALINA IVANOVA	{"email": "ivanova.g.1968@postgrespro.ru", "phone": "+70833696086"}
0005432329100	F0DF45	6366 387857	ALEKSANDR KOZLOV	{"phone": "+70467333962"}
0005432329101	4EA1D3	4367 637752	MIKHAIL AFANASEV	{"email": "m_afanasev_1980@postgrespro.ru", "phone": "+70151647556"}
0005432329102	17FD1D	9731 401411	ELENA NAUMOVA	{"email": "naumova-elena_011974@postgrespro.ru", "phone": "+70589123234"}
0005432329103	3ADA32	3046 079017	EKATERINA LUKYANOVA	{"email": "lukyanova-ekaterina-01081969@postgrespro.ru", "phone": "+70646581441"}
0005432329104	3ADA32	7029 773814	VLADIMIR EGOROV	{"email": "egorovvladimir061980@postgrespro.ru", "phone": "+70803823529"}
0005432329105	3ADA32	0091 050517	IGOR KAZAKOV	{"phone": "+70749615146"}
0005432329106	032CB7	3400 647478	ARTUR NAZAROV	{"phone": "+70995018979"}
0005432329107	68E6E6	7477 114760	SERGEY AFANASEV	{"phone": "+70464463678"}
0005432329108	9D6E57	2941 910295	VASILIY FILIPPOV	{"phone": "+70900139147"}
0005432329109	9D6E57	7883 009064	ELENA VLASOVA	{"phone": "+70668814048"}
0005432329110	87F687	4197 946800	VLADIMIR IVANOV	{"email": "ivanovv_081969@postgrespro.ru", "phone": "+70192409140"}
0005432329111	045428	6988 179818	ALEKSANDR CHERNOV	{"email": "chernov_a_24051974@postgrespro.ru", "phone": "+70953305587"}
0005432329112	E9CC02	5127 358105	SERGEY DMITRIEV	{"phone": "+70742333976"}
0005432329113	9A4445	0809 630642	VALENTINA FILATOVA	{"email": "valentinafilatova1984@postgrespro.ru", "phone": "+70302415185"}
0005432329114	618A81	9131 024693	VALENTINA MATVEEVA	{"email": "v.matveeva_031967@postgrespro.ru", "phone": "+70830837318"}
0005432329115	890C5E	9388 589633	VLADIMIR IVANOV	{"phone": "+70898958772"}
0005432329116	10B061	4291 092242	NIKOLAY KAZAKOV	{"email": "kazakovn031967@postgrespro.ru", "phone": "+70766596099"}
0005432329117	05E177	5357 728364	VITALIY TARASOV	{"email": "tarasov.vitaliy-021988@postgrespro.ru", "phone": "+70767575526"}
0005432329118	5198A1	3216 141652	ALINA STEPANOVA	{"email": "stepanova_alina.12021963@postgrespro.ru", "phone": "+70718970361"}
0005432329119	15D55A	8585 728500	TATYANA AFANASEVA	{"email": "afanaseva-tatyana-1974@postgrespro.ru", "phone": "+70104969662"}
0005432329120	15D55A	9972 033033	ALEKSANDRA VLASOVA	{"email": "aleksandravlasova_1969@postgrespro.ru", "phone": "+70152579680"}
0005432329121	E84D20	7824 950846	STEPAN GORBUNOV	{"phone": "+70091666206"}
0005432329122	0E412E	5542 139284	ALEKSANDR MIKHAYLOV	{"phone": "+70123304865"}
0005432329123	941AC0	8912 094070	SERGEY ILIN	{"email": "ilin_s25031982@postgrespro.ru", "phone": "+70030151345"}
0005432329124	941AC0	2300 535017	ALEKSANDR ABRAMOV	{"phone": "+70947197872"}
0005432329125	949BFE	7759 603211	ANTON KUZNECOV	{"email": "kuznecov-a081971@postgrespro.ru", "phone": "+70270168767"}
0005432329126	810E86	6235 020073	SVETLANA MOROZOVA	{"phone": "+70743759149"}
0005432329127	EC24B7	9704 883728	ILYA PAVLOV	{"email": "ilya-pavlov_1971@postgrespro.ru", "phone": "+70941809058"}
0005432329128	EC24B7	8479 017501	ELENA ZOTOVA	{"email": "zotovaelena-04101983@postgrespro.ru", "phone": "+70829010683"}
0005432329129	81DA72	9239 817694	ZINAIDA MOROZOVA	{"email": "morozova.zinaida.16121978@postgrespro.ru", "phone": "+70841177683"}
0005432329130	3C9632	3441 428582	KIRILL ILIN	{"phone": "+70829867299"}
0005432329131	B50BBB	8864 071224	ALEKSANDR VOLKOV	{"email": "avolkov-1965@postgrespro.ru", "phone": "+70329334186"}
0005432329132	B50BBB	9554 004631	IVAN NIKITIN	{"email": "ivannikitin.1968@postgrespro.ru", "phone": "+70574084757"}
0005432329133	4C59AA	5303 678630	ARTEMIY MEDVEDEV	{"email": "medvedev.artemiy121980@postgrespro.ru", "phone": "+70270300742"}
0005432329134	4C59AA	5242 019693	VALERIY SIDOROV	{"email": "valeriysidorov-101970@postgrespro.ru", "phone": "+70043274863"}
0005432329135	BD048D	1481 697719	ELENA POLYAKOVA	{"phone": "+70162045180"}
0005432329136	6072BA	6947 781193	EVGENIYA SERGEEVA	{"phone": "+70457081994"}
0005432329137	79AF36	7831 339349	EKATERINA BELOVA	{"phone": "+70243511545"}
0005432329138	79AF36	4507 287685	ALEKSANDR NIKITIN	{"email": "a_nikitin-061975@postgrespro.ru", "phone": "+70238001108"}
0005432329139	9526E0	2629 834032	TATYANA BELYAEVA	{"phone": "+70666955637"}
0005432329140	9526E0	8764 439680	ANDREY ANTONOV	{"email": "antonova_1962@postgrespro.ru", "phone": "+70902893381"}
0005432329141	2CD8D9	8650 643131	DARYA SIDOROVA	{"phone": "+70215362160"}
0005432329142	2CD8D9	2187 936243	ANTONINA LUKYANOVA	{"email": "lukyanova-a.25041979@postgrespro.ru", "phone": "+70390100250"}
0005432329143	34A153	6335 405581	LEONID KUZNECOV	{"phone": "+70917063511"}
0005432329144	C051F7	2261 706477	ROZALIYA KOMAROVA	{"email": "komarova_r-111975@postgrespro.ru", "phone": "+70562226493"}
0005432329145	C051F7	8709 002482	IRINA VOLKOVA	{"email": "ivolkova_29081980@postgrespro.ru", "phone": "+70076326333"}
0005432329146	ABA584	2582 120025	SERGEY TIMOFEEV	{"phone": "+70894004863"}
0005432329147	899FED	5163 660710	MARIYA ZAKHAROVA	{"email": "zakharova.m-14101974@postgrespro.ru", "phone": "+70876722591"}
0005432329148	BC2CF3	0493 703908	GENNADIY KISELEV	{"email": "kiselevg-1973@postgrespro.ru", "phone": "+70660956105"}
0005432329149	BC2CF3	8563 633073	IRINA NESTEROVA	{"email": "nesterova-irina28081963@postgrespro.ru", "phone": "+70115238474"}
0005432329150	81E6C9	0416 388249	NINA KUZNECOVA	{"phone": "+70331357091"}
0005432329151	81E6C9	2514 168016	GALINA SOKOLOVA	{"email": "sokolovag_30071974@postgrespro.ru", "phone": "+70989239331"}
0005432329152	87D802	6988 782099	TATYANA SERGEEVA	{"email": "t.sergeeva-16121971@postgrespro.ru", "phone": "+70391042355"}
0005432329153	921FC3	5035 191483	IGOR ANDREEV	{"email": "andreevigor-091968@postgrespro.ru", "phone": "+70163542154"}
0005432329154	036770	7132 861524	YURIY NIKITIN	{"email": "nikitin-yuriy-1980@postgrespro.ru", "phone": "+70168650261"}
0005432329155	2CD366	4601 170881	PAVEL RODIONOV	{"email": "prodionov-091986@postgrespro.ru", "phone": "+70664487668"}
0005432329156	2CD366	7242 736357	VALENTINA PAVLOVA	{"email": "pavlovav021980@postgrespro.ru", "phone": "+70029208833"}
0005432329157	226C6E	6516 154787	VLADIMIR GERASIMOV	{"email": "v_gerasimov.1977@postgrespro.ru", "phone": "+70694422743"}
0005432329158	FF1FDF	6817 586222	NADEZHDA ANDREEVA	{"email": "andreeva_n-071962@postgrespro.ru", "phone": "+70864583487"}
0005432329159	006713	8912 372005	ALEKSANDR NAZAROV	{"email": "nazarov-a.081980@postgrespro.ru", "phone": "+70726675511"}
0005432329160	006713	6664 859082	INNA MOISEEVA	{"phone": "+70179447742"}
0005432329161	06480E	8352 602378	NINA GRISHINA	{"phone": "+70088337012"}
0005432329162	06480E	3586 761803	ELIZAVETA ROMANOVA	{"email": "elizavetaromanova-1969@postgrespro.ru", "phone": "+70296798612"}
0005432329163	929233	5487 888940	FEDOR AFANASEV	{"email": "afanasev_f.1966@postgrespro.ru", "phone": "+70409404575"}
0005432329164	929233	6847 952348	VIKTOR KUDRYASHOV	{"email": "kudryashovviktor-111972@postgrespro.ru", "phone": "+70598009349"}
0005432329165	9BCB65	7535 054684	RAISA NIKOLAEVA	{"email": "raisa-nikolaeva.071971@postgrespro.ru", "phone": "+70505988659"}
0005432329166	8FF1BA	7023 828849	TATYANA PETROVA	{"email": "petrova-t.1970@postgrespro.ru", "phone": "+70145304386"}
0005432329167	2B3A04	7961 566680	ANASTASIYA LAZAREVA	{"email": "anastasiyalazareva-1978@postgrespro.ru", "phone": "+70819080172"}
0005432329168	2B3A04	1494 733287	VALERIY KULIKOV	{"email": "valeriy.kulikov.1969@postgrespro.ru", "phone": "+70250775320"}
0005432329169	55C947	7409 335403	VIKTORIYA NESTEROVA	{"phone": "+70370042787"}
0005432329170	264284	2764 537105	ANNA ANISIMOVA	{"email": "anisimova_a071960@postgrespro.ru", "phone": "+70810016290"}
0005432329171	18AA40	5632 989158	NATALYA BARANOVA	{"email": "natalyabaranova07031971@postgrespro.ru", "phone": "+70528200822"}
0005432329172	438B6A	7085 835728	OLGA BOGDANOVA	{"phone": "+70451363861"}
0005432329173	07791D	8962 523064	LUIZA FADEEVA	{"phone": "+70324789518"}
0005432329174	2A4F94	8117 452259	VYACHESLAV SCHERBAKOV	{"email": "scherbakov-v1979@postgrespro.ru", "phone": "+70092317981"}
0005432329175	2A4F94	3422 324590	VASILIY MARTYNOV	{"phone": "+70843608398"}
0005432329176	029FCB	6750 495011	ALEKSANDR KULIKOV	{"email": "a.kulikov1969@postgrespro.ru", "phone": "+70717754259"}
0005432329177	029FCB	5597 829723	KONSTANTIN MARTYNOV	{"email": "martynovk.24101959@postgrespro.ru", "phone": "+70001302235"}
0005432329178	353915	5154 323618	TATYANA MOROZOVA	{"phone": "+70647131860"}
0005432329179	04EC84	7990 514941	ALEKSANDR MIKHAYLOV	{"phone": "+70849014176"}
0005432329180	04EC84	8812 021159	MARIYA KUZNECOVA	{"phone": "+70023470275"}
0005432329181	63A355	3213 285571	ANASTASIYA IVANOVA	{"phone": "+70079251929"}
0005432329182	6F5A15	4476 370621	TATYANA POPOVA	{"email": "tatyana.popova28041972@postgrespro.ru", "phone": "+70327595720"}
0005432329183	C0944B	7011 211150	NATALYA KOROLEVA	{"phone": "+70844627829"}
0005432329184	110AD0	6606 737356	AMIR ROMANOV	{"phone": "+70313918156"}
0005432329185	56F3FB	9794 642672	GULNARA KRASNOVA	{"email": "g-krasnova081969@postgrespro.ru", "phone": "+70680048001"}
0005432329186	56F3FB	9351 480657	ALEKSEY STEPANOV	{"email": "stepanov_aleksey.20011954@postgrespro.ru", "phone": "+70683971026"}
0005432329187	6A6671	8091 004214	VASILIY PAVLOV	{"phone": "+70029621252"}
0005432329188	6A6671	1386 317491	NATALYA BORISOVA	{"phone": "+70507659702"}
0005432329189	4E151E	2778 087639	ALEKSEY CHERNOV	{"phone": "+70272295884"}
0005432329190	4E151E	4844 776305	ANASTASIYA NAZAROVA	{"email": "nazarova_anastasiya-111970@postgrespro.ru", "phone": "+70964309535"}
0005432329191	4E151E	0736 760244	YULIYA OVCHINNIKOVA	{"phone": "+70891768534"}
0005432329192	872E9C	3755 689123	OLGA FILATOVA	{"email": "o-filatova-011986@postgrespro.ru", "phone": "+70526446801"}
0005432329193	2DB7DF	1114 549233	NURLAN VOLKOV	{"email": "nurlan.volkov.1965@postgrespro.ru", "phone": "+70474356870"}
0005432329194	3FF451	5277 705809	ALEKSANDRA ZAKHAROVA	{"phone": "+70656356498"}
0005432329195	68C1BE	5714 107974	DMITRIY RODIONOV	{"email": "rodionov.dmitriy_111972@postgrespro.ru", "phone": "+70389490734"}
0005432329196	68C1BE	1888 944016	SERGEY PETROV	{"email": "sergey_petrov-1973@postgrespro.ru", "phone": "+70939488532"}
0005432329197	92AC33	7897 255122	MARIYA NIKITINA	{"email": "m-nikitina_11021967@postgrespro.ru", "phone": "+70301684394"}
0005432329198	92AC33	1408 334409	NADEZHDA LAZAREVA	{"phone": "+70126187939"}
0005432329199	92AC33	8513 296665	NAILYA SIDOROVA	{"email": "sidorovanailya1964@postgrespro.ru", "phone": "+70945370141"}
0005432329200	2C483B	4666 035664	GALINA BARANOVA	{"phone": "+70851779794"}
0005432329201	63A187	6745 074495	NATALYA ANTONOVA	{"phone": "+70875442111"}
0005432329202	63A187	9135 562323	INNA MATVEEVA	{"phone": "+70256161533"}
0005432329203	FCA817	1627 734948	SERGEY ZHURAVLEV	{"phone": "+70123055671"}
0005432329204	014636	0322 808776	ELENA PETROVA	{"phone": "+70729244205"}
0005432329205	014636	9993 188278	OLGA KOROLEVA	{"phone": "+70921789673"}
0005432329206	CB5A2E	8862 621473	TATYANA POTAPOVA	{"phone": "+70809516516"}
0005432329207	E49C21	6498 856236	VALENTIN VASILEV	{"phone": "+70611426781"}
0005432329208	78CE72	1146 596305	NADEZHDA POPOVA	{"email": "popovan_091960@postgrespro.ru", "phone": "+70464379775"}
0005432329209	A74EA1	4472 274749	IVAN FILIPPOV	{"email": "ifilippov-28061978@postgrespro.ru", "phone": "+70576231632"}
0005432329210	BBB044	8896 798090	DMITRIY NAZAROV	{"phone": "+70680686798"}
0005432329211	BBB044	8468 150633	ANDREY VLASOV	{"email": "vlasov.a1972@postgrespro.ru", "phone": "+70351189088"}
0005432329212	D1919D	8654 407192	VLADIMIR VASILEV	{"phone": "+70650821364"}
0005432329213	48C182	1168 932515	NIKITA PETROV	{"phone": "+70413727073"}
0005432329214	7E1510	9046 175395	GALINA MEDVEDEVA	{"phone": "+70177770415"}
0005432329215	7E1510	1320 207631	IRINA FROLOVA	{"email": "irina-frolova-1975@postgrespro.ru", "phone": "+70525368403"}
0005432329216	F2C51E	5816 038511	YULIYA DAVYDOVA	{"email": "davydova_y-071969@postgrespro.ru", "phone": "+70594697582"}
0005432329217	F2869F	7101 646292	EVGENIYA ANTONOVA	{"email": "evgeniya.antonova111974@postgrespro.ru", "phone": "+70793162579"}
0005432329218	82CC98	9877 088020	MAKSIM KUZNECOV	{"email": "m-kuznecov.061975@postgrespro.ru", "phone": "+70009417959"}
0005432329219	82CC98	5414 675015	ANASTASIYA KARPOVA	{"email": "a_karpova_061958@postgrespro.ru", "phone": "+70961992986"}
0005432329220	26BC91	3166 713350	ALEKSEY GRIGOREV	{"phone": "+70916765059"}
0005432329221	0361AB	8393 721215	VALENTINA KRASNOVA	{"email": "krasnova-valentina.101968@postgrespro.ru", "phone": "+70492145072"}
0005432329222	AAF678	0146 584818	SVETLANA AFANASEVA	{"email": "s.afanaseva_1975@postgrespro.ru", "phone": "+70356520427"}
0005432329223	AAF678	2370 314613	ALEKSANDR SIDOROV	{"phone": "+70138289109"}
0005432329224	5DC15E	9537 318816	SERGEY MIRONOV	{"email": "mironov-sergey1976@postgrespro.ru", "phone": "+70189162017"}
0005432329225	B685D4	5698 250598	SOFYA SIDOROVA	{"phone": "+70326478519"}
0005432329226	B685D4	8694 085629	LIDIYA BORISOVA	{"phone": "+70338223134"}
0005432329227	84852E	2681 431104	ILYA MIKHAYLOV	{"phone": "+70184702726"}
0005432329228	84852E	9836 869841	ALEKSEY FILIPPOV	{"email": "aleksey-filippov-041962@postgrespro.ru", "phone": "+70300191659"}
0005432329229	CAC684	7812 346489	LARISA TARASOVA	{"email": "ltarasova1981@postgrespro.ru", "phone": "+70764623396"}
0005432329230	CAC684	8789 522415	GALINA PAVLOVA	{"phone": "+70539378019"}
0005432329231	A564F1	6523 141674	VLADIMIR GRIGOREV	{"email": "v-grigorev_07051969@postgrespro.ru", "phone": "+70041603042"}
0005432329232	1FA330	1278 940716	DMITRIY KUZNECOV	{"email": "kuznecov.d.1971@postgrespro.ru", "phone": "+70735121187"}
0005432329233	0084AB	8413 365554	VALERIY MOROZOV	{"phone": "+70970287372"}
0005432329234	0084AB	3391 400893	FATIMA KUZMINA	{"email": "fatima_kuzmina031972@postgrespro.ru", "phone": "+70447820274"}
0005432329235	BF3B9D	6425 217466	TATYANA IVANOVA	{"phone": "+70390872737"}
0005432329236	309053	7764 809086	KSENIYA MELNIKOVA	{"phone": "+70689319902"}
0005432329237	EE5A35	1822 696302	SERGEY STEPANOV	{"email": "sergey_stepanov13111978@postgrespro.ru", "phone": "+70236815667"}
0005432329238	236F0F	8940 621523	ANATOLIY KUZMIN	{"phone": "+70127404185"}
0005432329239	236F0F	3636 505851	VITALIY ZHUKOV	{"email": "zhukov-vitaliy1972@postgrespro.ru", "phone": "+70787245654"}
0005432329240	236F0F	4586 317838	SVETLANA IVANOVA	{"email": "ivanova.svetlana_041973@postgrespro.ru", "phone": "+70654462233"}
0005432329241	E5DFE6	4643 845221	LYUBOV MOROZOVA	{"phone": "+70481547563"}
0005432329242	11461F	8654 939112	OLGA NESTEROVA	{"phone": "+70959143492"}
0005432329243	554634	6029 400013	PETR NOVIKOV	{"email": "p-novikov101969@postgrespro.ru", "phone": "+70337409224"}
0005432329244	2FDB95	5883 021473	NADEZHDA ABRAMOVA	{"email": "abramovan.091976@postgrespro.ru", "phone": "+70958321762"}
0005432329245	4742B1	8375 474413	ANZHELA AKIMOVA	{"email": "a-akimova081972@postgrespro.ru", "phone": "+70873695100"}
0005432329246	8B4CFF	7333 667403	ALEKSANDR POPOV	{"email": "a.popov23061978@postgrespro.ru", "phone": "+70078489030"}
0005432329247	37A1E9	5531 934010	LEONID FOMIN	{"phone": "+70099616914"}
0005432329248	DDFE5C	1943 199076	OLGA FROLOVA	{"phone": "+70456547365"}
0005432329249	B0C0A5	3761 114911	OLGA KUZNECOVA	{"email": "kuznecovaolga_121961@postgrespro.ru", "phone": "+70262344968"}
0005432329250	A2AE68	4872 394784	VALENTIN MELNIKOV	{"email": "melnikov.valentin-10041967@postgrespro.ru", "phone": "+70374321062"}
0005432329251	943523	5636 646333	ELENA ABRAMOVA	{"phone": "+70271497224"}
0005432329252	943523	0494 067485	ZINAIDA YAKOVLEVA	{"email": "zinaidayakovleva_1980@postgrespro.ru", "phone": "+70127191210"}
0005432329253	A7A01A	1181 056025	VIKTOR FEDOROV	{"phone": "+70739985562"}
0005432329254	A7A01A	0544 450923	ILMIRA IVANOVA	{"email": "i_ivanova_27011975@postgrespro.ru", "phone": "+70298012775"}
0005432329255	F0FB8F	3525 611385	NATALYA LUKYANOVA	{"phone": "+70923278924"}
0005432329256	94762A	5467 697484	SVETLANA BELOVA	{"email": "belova-svetlana.111968@postgrespro.ru", "phone": "+70727511855"}
0005432329257	94762A	2798 221305	ALEKSEY SOROKIN	{"email": "aleksey_sorokin_061981@postgrespro.ru", "phone": "+70088176415"}
0005432329258	C85E5D	7397 715576	BORIS IVANOV	{"phone": "+70168220988"}
0005432329259	C85E5D	3713 540483	VERA KONOVALOVA	{"phone": "+70593728021"}
0005432329260	7426E0	2069 961877	NIKOLAY SEMENOV	{"email": "nikolaysemenov_12111983@postgrespro.ru", "phone": "+70410186014"}
0005432329261	50D64B	2891 918660	NATALIYA IVANOVA	{"email": "nataliya_ivanova-1960@postgrespro.ru", "phone": "+70544273734"}
0005432329262	12CE53	4086 080074	ALLA ILINA	{"email": "alla.ilina_081974@postgrespro.ru", "phone": "+70363005069"}
0005432329263	12CE53	4028 997899	RUSLAN ANDREEV	{"phone": "+70701364462"}
0005432329264	12CE53	5875 361148	SERGEY SOKOLOV	{"email": "sokolovs_091972@postgrespro.ru", "phone": "+70911917791"}
0005432329265	4D94E2	8203 575930	SEMEN MIRONOV	{"phone": "+70787459996"}
0005432329266	D2AD8B	4483 581032	ALEKSANDR GUSEV	{"email": "a-gusev_31081971@postgrespro.ru", "phone": "+70691297242"}
0005432329267	D2AD8B	9473 368789	ANASTASIYA MAKAROVA	{"phone": "+70009399019"}
0005432329268	C315EC	7142 868065	LYUDMILA SMIRNOVA	{"phone": "+70585492726"}
0005432329269	C315EC	7886 178170	SERGEY KONOVALOV	{"email": "sergey.konovalov1976@postgrespro.ru", "phone": "+70329898137"}
0005432329270	20E333	8502 173151	ELENA SERGEEVA	{"email": "elena_sergeeva19061964@postgrespro.ru", "phone": "+70876005745"}
0005432329271	20E333	9694 991450	VLADIMIR IVANOV	{"phone": "+70200957514"}
0005432329272	D2216D	7827 426541	VALENTINA MIRONOVA	{"phone": "+70287148256"}
0005432329273	D2216D	2298 079222	VERA OSIPOVA	{"phone": "+70378945902"}
0005432329274	8C42A4	8972 317201	NATALYA SEMENOVA	{"email": "natalya-semenova051966@postgrespro.ru", "phone": "+70340041490"}
0005432329275	84CF04	6908 099333	DENIS KULIKOV	{"email": "kulikov_d.03121967@postgrespro.ru", "phone": "+70207261105"}
0005432329276	21E7CF	8081 916736	MARINA ALEKSEEVA	{"phone": "+70663417607"}
0005432329277	7AEFA3	6633 973672	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov-1967@postgrespro.ru", "phone": "+70658697615"}
0005432329278	0252E1	3921 326954	NATALIYA VOLKOVA	{"email": "nvolkova09111971@postgrespro.ru", "phone": "+70831835642"}
0005432329279	0252E1	1358 430541	ANNA ZHUKOVA	{"email": "zhukova.anna-19041968@postgrespro.ru", "phone": "+70761899263"}
0005432329280	71E52B	2094 489457	EKATERINA ERMAKOVA	{"email": "ermakova-e_041977@postgrespro.ru", "phone": "+70093258416"}
0005432329281	16FF42	2862 019804	ALEKSANDR ORLOV	{"phone": "+70886846954"}
0005432329282	EE8800	4811 424508	PAVEL FEDOROV	{"email": "p.fedorov.021968@postgrespro.ru", "phone": "+70105408296"}
0005432329283	5808BC	6180 435902	NIKOLAY SCHERBAKOV	{"phone": "+70812190759"}
0005432329284	033436	5698 871694	KUZMA FILIPPOV	{"email": "k-filippov-1975@postgrespro.ru", "phone": "+70934503488"}
0005432329285	033436	3400 437122	NIKOLAY PETROV	{"phone": "+70926809059"}
0005432329286	812F2E	0109 519088	TAGIR KUZMIN	{"email": "t-kuzmin1980@postgrespro.ru", "phone": "+70697250138"}
0005432329287	812F2E	9423 614780	ELIZAVETA ANDREEVA	{"email": "andreevaelizaveta.14021970@postgrespro.ru", "phone": "+70694782961"}
0005432329288	DD1FC6	2996 939002	VALENTINA CHERNOVA	{"phone": "+70924270595"}
0005432329289	DD1FC6	2786 084592	VALENTINA ZOTOVA	{"phone": "+70310284819"}
0005432329290	B73D74	0295 865808	ELENA PAVLOVA	{"phone": "+70887275032"}
0005432329291	4FE26D	9698 997856	ANTON TIMOFEEV	{"phone": "+70054676761"}
0005432329292	4FE26D	1570 077915	YURIY ZHURAVLEV	{"email": "yuriyzhuravlev1966@postgrespro.ru", "phone": "+70797839658"}
0005432329293	BC1D52	0359 012474	ARINA IVANOVA	{"phone": "+70541046991"}
0005432329294	6B2301	7190 076396	NATALYA MELNIKOVA	{"email": "melnikova_n.031965@postgrespro.ru", "phone": "+70995872101"}
0005432329295	6B2301	9724 456069	ELENA PETROVA	{"phone": "+70472651188"}
0005432329296	6B2301	2887 521271	IGOR CHERNOV	{"phone": "+70955269671"}
0005432329297	622647	6630 161123	OLEG VASILEV	{"phone": "+70516830421"}
0005432329298	DD0540	2011 751527	YURIY NIKOLAEV	{"email": "yuriynikolaev.20041974@postgrespro.ru", "phone": "+70944614524"}
0005432329299	CD4ADE	9399 555894	NINA BORISOVA	{"phone": "+70953404851"}
0005432329300	57D65E	5034 819879	NADEZHDA ZHURAVLEVA	{"email": "nadezhda_zhuravleva_23101972@postgrespro.ru", "phone": "+70140346021"}
0005432329301	DA3B8B	5404 417171	ANTONINA KOROLEVA	{"phone": "+70983896297"}
0005432329302	EA08B5	9961 222123	KSENIYA POPOVA	{"phone": "+70869610887"}
0005432329303	D965CD	9468 948502	VALENTINA NESTEROVA	{"phone": "+70969783158"}
0005432329304	D965CD	0756 473435	EVGENIY KUZMIN	{"phone": "+70935354056"}
0005432329305	A1BBC7	2134 259904	DENIS IVANOV	{"email": "ivanov_d.1966@postgrespro.ru", "phone": "+70852470641"}
0005432329306	A1BBC7	7179 769858	DMITRIY ISAEV	{"email": "isaevdmitriy-061968@postgrespro.ru", "phone": "+70081804520"}
0005432329307	0D81D2	0276 104498	ILYA KOZLOV	{"email": "kozlov-i_1958@postgrespro.ru", "phone": "+70890487248"}
0005432329308	0D81D2	6755 047984	TAMARA MIRONOVA	{"phone": "+70333669642"}
0005432329309	A8CF98	0369 657491	VALERIY SOROKIN	{"email": "v_sorokin.13051973@postgrespro.ru", "phone": "+70756763619"}
0005432329310	85C0DA	9362 943196	OKSANA RYABOVA	{"phone": "+70789075941"}
0005432329311	85C0DA	6225 676887	DANIIL ILIN	{"phone": "+70698959833"}
0005432329312	10630A	6406 737792	ANTON ORLOV	{"email": "a.orlov.1977@postgrespro.ru", "phone": "+70819843553"}
0005432329313	10630A	6309 857685	ZINAIDA KOROLEVA	{"email": "koroleva.z051972@postgrespro.ru", "phone": "+70295941245"}
0005432329314	AE0C88	8556 396433	SERGEY MAKAROV	{"email": "s-makarov_011965@postgrespro.ru", "phone": "+70756359150"}
0005432329315	F1FDED	8447 723450	NIKOLAY GAVRILOV	{"email": "nikolay-gavrilov_111980@postgrespro.ru", "phone": "+70099500918"}
0005432329316	BDAFF7	4649 681687	DENIS ZAKHAROV	{"phone": "+70820085715"}
0005432329317	BDAFF7	3160 150415	KSENIYA KARPOVA	{"phone": "+70417188019"}
0005432329318	BAA7A5	6419 486780	ANASTASIYA IVANOVA	{"email": "ivanova-anastasiya-29101977@postgrespro.ru", "phone": "+70129571744"}
0005432329319	B72945	2529 141215	SVETLANA ZAKHAROVA	{"phone": "+70429500260"}
0005432329320	B72945	9559 201285	NIKOLAY ZAKHAROV	{"phone": "+70246127292"}
0005432329321	B72945	3539 667284	ANNA KAZAKOVA	{"phone": "+70998472612"}
0005432329322	AC6BEB	6939 017135	SHAVKAT NIKOLAEV	{"phone": "+70764267246"}
0005432329323	C3F218	6795 863148	NATALYA MALYSHEVA	{"phone": "+70900368851"}
0005432329324	E36FDB	7427 856213	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.a.1975@postgrespro.ru", "phone": "+70673065755"}
0005432329325	E36FDB	7312 913805	TATYANA RYABOVA	{"phone": "+70059924837"}
0005432329326	98F702	7158 029289	VLADIMIR MOISEEV	{"phone": "+70728222851"}
0005432329327	448529	6638 041463	LYUBOV KOLESNIKOVA	{"phone": "+70839021383"}
0005432329328	DFF9D8	1523 234054	OLGA GRISHINA	{"email": "grishina_olga.1979@postgrespro.ru", "phone": "+70509232653"}
0005432329329	8EBADD	0008 363590	NATALYA PETROVA	{"phone": "+70033887017"}
0005432329330	34265B	4480 563451	SERGEY VOROBEV	{"phone": "+70115601806"}
0005432329331	34265B	1999 249859	VALENTINA GERASIMOVA	{"phone": "+70191433053"}
0005432329332	D4018F	5560 078298	LIDIYA KOLESNIKOVA	{"phone": "+70073487546"}
0005432329333	B9B12B	6367 606386	ALEKSANDR ALEKSANDROV	{"phone": "+70150578742"}
0005432329334	D3A61A	1178 187880	IVAN IVANOV	{"phone": "+70986186676"}
0005432329335	36D7BC	6980 942682	MARIYA SAVELEVA	{"phone": "+70386641221"}
0005432329336	87FFC5	2459 701149	IGOR FOMIN	{"email": "igor_fomin1978@postgrespro.ru", "phone": "+70064833384"}
0005432329337	FEFAFF	3974 114215	NIKOLAY PAVLOV	{"email": "pavlov.n-1970@postgrespro.ru", "phone": "+70769026109"}
0005432329338	FEFAFF	5575 120625	NIKOLAY MAKAROV	{"email": "n_makarov1979@postgrespro.ru", "phone": "+70039084059"}
0005432329339	B3C5E3	9252 308047	MARIYA KONDRATEVA	{"phone": "+70913691515"}
0005432329340	6C4BE4	9656 065740	NADEZHDA BOGDANOVA	{"phone": "+70519206936"}
0005432329341	FB3138	6419 597828	YULIYA DANILOVA	{"phone": "+70267077714"}
0005432329342	E2D298	4446 519178	MIKHAIL ALEKSANDROV	{"email": "aleksandrov.mikhail.1973@postgrespro.ru", "phone": "+70593554742"}
0005432329343	2D4B1C	9041 175319	ELIZAVETA SEMENOVA	{"phone": "+70689945062"}
0005432329344	2D4B1C	5116 885370	VALENTINA LOGINOVA	{"email": "loginovavalentina_22071980@postgrespro.ru", "phone": "+70311084994"}
0005432329345	476B17	9251 012692	DMITRIY FOMIN	{"phone": "+70918124260"}
0005432329346	476B17	7493 630008	IGOR DENISOV	{"phone": "+70523547281"}
0005432329347	07D714	6647 445058	OLESYA BELYAEVA	{"email": "olesya_belyaeva04081976@postgrespro.ru", "phone": "+70481125811"}
0005432329348	07D714	4005 681066	NINA YUDINA	{"phone": "+70923377085"}
0005432329349	7E2446	0159 326708	MARIYA EGOROVA	{"email": "m-egorova-091969@postgrespro.ru", "phone": "+70872199520"}
0005432329350	85D56A	1935 725110	RAMIL ZHURAVLEV	{"email": "r-zhuravlev-061966@postgrespro.ru", "phone": "+70438175267"}
0005432329351	48A9A8	2821 380226	PAVEL SCHERBAKOV	{"email": "pavel-scherbakov_1969@postgrespro.ru", "phone": "+70361531620"}
0005432329352	746782	2196 624348	NADEZHDA KULIKOVA	{"email": "nadezhda_kulikova_1988@postgrespro.ru", "phone": "+70438734006"}
0005432329353	EBFED0	8306 327381	VALENTIN SMIRNOV	{"email": "v.smirnov_051977@postgrespro.ru", "phone": "+70044714504"}
0005432329354	917078	4591 982192	ELENA ZAYCEVA	{"phone": "+70763372738"}
0005432329355	5DED21	9869 684541	OLEG PETROV	{"phone": "+70003156546"}
0005432329356	AC7A15	4280 638132	IGOR ZAKHAROV	{"email": "zakharovigor-1961@postgrespro.ru", "phone": "+70636503013"}
0005432329357	F3B7DE	9861 838133	MIKHAIL SMIRNOV	{"email": "m_smirnov-10111973@postgrespro.ru", "phone": "+70222839906"}
0005432329358	453C11	2716 298666	TATYANA NOVIKOVA	{"email": "t.novikova.1960@postgrespro.ru", "phone": "+70876132345"}
0005432329359	453C11	9194 335574	VLADIMIR FROLOV	{"phone": "+70349827250"}
0005432329360	B3F483	3655 240722	YURIY SCHERBAKOV	{"phone": "+70197614739"}
0005432329361	D71C3D	4645 331260	MARIYA VOLKOVA	{"email": "mariya-volkova_101977@postgrespro.ru", "phone": "+70288573825"}
0005432329362	A16813	2018 939538	IVAN ANDREEV	{"email": "i.andreev_1959@postgrespro.ru", "phone": "+70880921370"}
0005432329363	8DC421	6692 395531	OLEG FILIPPOV	{"phone": "+70527976329"}
0005432329364	03A317	0493 649250	SAVELIY FEDOROV	{"email": "fedorovsaveliy061973@postgrespro.ru", "phone": "+70917000461"}
0005432329365	56FB56	6480 252784	EGOR MIKHAYLOV	{"email": "mikhaylov-egor.1975@postgrespro.ru", "phone": "+70586727451"}
0005432329366	56FB56	5269 624989	NATALYA VASILEVA	{"phone": "+70038661191"}
0005432329367	6D4EBD	2959 774517	ANATOLIY VOLKOV	{"email": "volkov_anatoliy-081985@postgrespro.ru", "phone": "+70109930823"}
0005432329368	DC7310	5146 667021	DMITRIY MOROZOV	{"phone": "+70789455736"}
0005432329369	DC7310	7643 739832	ANATOLIY ROMANOV	{"email": "a_romanov1961@postgrespro.ru", "phone": "+70768253099"}
0005432329370	9C2E0D	1551 807665	EKATERINA SERGEEVA	{"email": "sergeeva-ekaterina-1969@postgrespro.ru", "phone": "+70987642112"}
0005432329371	BF83A6	9620 794234	ELENA KUDRYASHOVA	{"phone": "+70026713295"}
0005432329372	EE7469	3669 265340	ANASTASIYA LOGINOVA	{"phone": "+70862503180"}
0005432329373	EE7469	3935 914317	OLGA ERMAKOVA	{"phone": "+70651820488"}
0005432329374	136D24	1964 476767	TAMARA KULIKOVA	{"email": "kulikova_t.25041955@postgrespro.ru", "phone": "+70062406098"}
0005432329375	E5868A	0707 162559	VLADIMIR POPOV	{"email": "v_popov.14121978@postgrespro.ru", "phone": "+70102973121"}
0005432329376	E5868A	7653 574246	VIKTOR GORBUNOV	{"phone": "+70156980783"}
0005432329377	0AA888	2631 456724	STANISLAV BELOV	{"email": "s_belov.1966@postgrespro.ru", "phone": "+70559571062"}
0005432329378	C20D5C	1215 657003	NATALYA PETROVA	{"email": "petrova-natalya.1960@postgrespro.ru", "phone": "+70748683949"}
0005432329379	7B9C25	7209 500736	ALEKSANDR SEMENOV	{"phone": "+70234722157"}
0005432329380	7B9C25	8271 753731	GRIGORIY SCHERBAKOV	{"email": "grigoriy-scherbakov-011974@postgrespro.ru", "phone": "+70851947303"}
0005432329381	7B9C25	2811 895525	NATALYA KISELEVA	{"email": "n-kiseleva-1976@postgrespro.ru", "phone": "+70135644072"}
0005432329382	A6C56A	4139 305699	ALENA DANILOVA	{"phone": "+70470044030"}
0005432329383	7E266A	2005 380128	ALEKSANDR SCHERBAKOV	{"phone": "+70913594076"}
0005432329384	7E266A	0238 817425	SERGEY OSIPOV	{"phone": "+70516031224"}
0005432329385	1EE6A5	3350 057314	OLGA ABRAMOVA	{"phone": "+70643265435"}
0005432329386	B7AC7C	7247 900983	ALEKSEY MIRONOV	{"phone": "+70706455875"}
0005432329387	6494FC	9178 207821	TATYANA ANISIMOVA	{"email": "anisimova-tatyana_1970@postgrespro.ru", "phone": "+70929686259"}
0005432329388	6494FC	5845 110379	RAISA PAVLOVA	{"email": "pavlova_raisa031973@postgrespro.ru", "phone": "+70748366583"}
0005432329389	27D0D6	7068 312273	LARISA MOROZOVA	{"phone": "+70391491321"}
0005432329390	824714	6061 597086	MAKSIM VASILEV	{"phone": "+70269184177"}
0005432329391	5491D3	2876 933297	RAMIL NAZAROV	{"email": "nazarov.ramil.1971@postgrespro.ru", "phone": "+70492788405"}
0005432329392	5491D3	4079 562670	NATALYA IVANOVA	{"email": "n-ivanova-1966@postgrespro.ru", "phone": "+70578762364"}
0005432329393	5491D3	6470 506351	GENNADIY MIRONOV	{"email": "mironovg_021975@postgrespro.ru", "phone": "+70217172226"}
0005432329394	7D05BB	2254 880618	NATALYA SAVELEVA	{"phone": "+70473494285"}
0005432329395	806827	3049 929499	ANDREY IVANOV	{"phone": "+70168551258"}
0005432329396	519EFF	1567 936183	IGOR BORISOV	{"phone": "+70445020856"}
0005432329397	0EFAED	7781 532413	TATYANA PETROVA	{"phone": "+70621628418"}
0005432329398	700C46	3643 135667	ELENA KRASNOVA	{"email": "elena-krasnova_1979@postgrespro.ru", "phone": "+70051983820"}
0005432329399	700C46	6975 077022	SVETLANA ISAEVA	{"email": "svetlana.isaeva.051962@postgrespro.ru", "phone": "+70802940298"}
0005432329400	6F07F3	3732 300444	NIKITA MATVEEV	{"email": "nikitamatveev_021968@postgrespro.ru", "phone": "+70932683534"}
0005432329401	4E6184	1305 274096	EVELINA ZAKHAROVA	{"email": "zakharova.e101976@postgrespro.ru", "phone": "+70578258963"}
0005432329402	4E6184	2405 071994	OLEG IVANOV	{"phone": "+70692674333"}
0005432329403	4E6184	8840 664907	TATYANA SMIRNOVA	{"phone": "+70366873614"}
0005432329404	E000A5	3847 036191	SERGEY SIDOROV	{"email": "sidorov.sergey_13121973@postgrespro.ru", "phone": "+70432128968"}
0005432329405	E000A5	2387 413677	TATYANA POPOVA	{"email": "popova-t1971@postgrespro.ru", "phone": "+70035888485"}
0005432329406	6D26FF	6605 581344	VIKTOR NAZAROV	{"phone": "+70199308632"}
0005432329407	EDE55F	2097 495696	MAKSIM KAZAKOV	{"phone": "+70030647723"}
0005432329408	FA225F	2386 156352	ANTON MIRONOV	{"email": "mironov.anton14031969@postgrespro.ru", "phone": "+70714200965"}
0005432329409	A51775	9342 183671	VLADIMIR ROMANOV	{"phone": "+70826081021"}
0005432329410	02AF83	7712 257805	NIKOLAY NIKITIN	{"email": "n-nikitin-111967@postgrespro.ru", "phone": "+70896052611"}
0005432329411	02AF83	0328 131458	MAKSIM KONOVALOV	{"phone": "+70559650070"}
0005432329412	E71046	0726 890930	PAVEL SCHERBAKOV	{"email": "scherbakov.pavel.06031968@postgrespro.ru", "phone": "+70364144113"}
0005432329413	E71046	6646 487090	YURIY KISELEV	{"phone": "+70877990471"}
0005432329414	DE9C97	3798 132124	SERGEY KRASNOV	{"email": "skrasnov.1970@postgrespro.ru", "phone": "+70242908608"}
0005432329415	DE3AEA	0284 862348	EVGENIY MIRONOV	{"email": "mironov.e_081971@postgrespro.ru", "phone": "+70373382094"}
0005432329416	2728BB	6706 014254	YULIYA KONOVALOVA	{"phone": "+70636198921"}
0005432329417	ED7214	6851 094105	DMITRIY SHEVCHENKO	{"phone": "+70731357604"}
0005432329418	ED7214	9804 365759	ANNA OVCHINNIKOVA	{"email": "ovchinnikova-a_29091987@postgrespro.ru", "phone": "+70281111050"}
0005432329419	2B4021	6632 995248	LYUBOV CHERNOVA	{"email": "chernovalyubov-22071975@postgrespro.ru", "phone": "+70410355463"}
0005432329420	49F936	1392 996350	ALEKSEY FEDOTOV	{"phone": "+70019696356"}
0005432329421	AA2ECC	8778 697195	VALENTINA SAVELEVA	{"phone": "+70353601532"}
0005432329422	492CA8	8322 233339	RUSLAN ZHUKOV	{"email": "zhukov.r06041965@postgrespro.ru", "phone": "+70429236393"}
0005432329423	82835F	0866 570344	ZOYA SOKOLOVA	{"email": "sokolova_zoya_21101984@postgrespro.ru", "phone": "+70548568945"}
0005432329424	903780	7972 673666	MIKHAIL MAKAROV	{"phone": "+70848794462"}
0005432329425	903780	5299 104874	PETR POPOV	{"email": "popov.petr_1969@postgrespro.ru", "phone": "+70891150809"}
0005432329426	C8F6C4	7208 501035	GALINA KUZNECOVA	{"phone": "+70763324442"}
0005432329427	42F4F5	3417 436169	ANATOLIY MARTYNOV	{"phone": "+70776071191"}
0005432329428	5638C8	0861 166680	VLADIMIR DENISOV	{"email": "vladimir-denisov24041966@postgrespro.ru", "phone": "+70099280432"}
0005432329429	5638C8	0564 266003	YURIY VOLKOV	{"phone": "+70600813309"}
0005432329430	51B687	8114 711863	ANASTASIYA OSIPOVA	{"email": "osipovaanastasiya_051970@postgrespro.ru", "phone": "+70836758352"}
0005432329431	51B687	3000 125793	MAKSIM BARANOV	{"email": "maksimbaranov.02011972@postgrespro.ru", "phone": "+70301170752"}
0005432329432	4C6415	2332 325166	OKSANA SIDOROVA	{"email": "sidorovaoksana_041978@postgrespro.ru", "phone": "+70510770914"}
0005432329433	1D84CC	1107 940460	VALERIY IVANOV	{"email": "ivanov.valeriy_081977@postgrespro.ru", "phone": "+70646829014"}
0005432329434	B4D6A2	8740 958941	LYUDMILA SEMENOVA	{"email": "semenovalyudmila10051965@postgrespro.ru", "phone": "+70720843131"}
0005432329435	B4D6A2	8790 502780	NINA LAZAREVA	{"phone": "+70390921188"}
0005432329436	B4D6A2	9064 415159	VLADISLAV MATVEEV	{"email": "matveev-v_12071980@postgrespro.ru", "phone": "+70339726686"}
0005432329437	FA3D8C	6580 573674	ANTON KOZLOV	{"email": "a-kozlov-1963@postgrespro.ru", "phone": "+70072523087"}
0005432329438	357F51	0782 403692	YURIY BORISOV	{"email": "y_borisov.09051970@postgrespro.ru", "phone": "+70553715419"}
0005432329439	357F51	8338 698186	SVETLANA ZAYCEVA	{"phone": "+70047921948"}
0005432329440	2944AC	9482 149975	YULIYA ALEKSEEVA	{"email": "alekseeva.y_121964@postgrespro.ru", "phone": "+70566752607"}
0005432329441	5ECA97	7266 963403	ANNA GERASIMOVA	{"phone": "+70705530661"}
0005432329442	D9BB42	7457 589456	KRISTINA BORISOVA	{"phone": "+70432608264"}
0005432329443	5DFB28	0120 979235	LIDIYA GERASIMOVA	{"email": "gerasimova.lidiya_1973@postgrespro.ru", "phone": "+70469212531"}
0005432329444	5DFB28	8159 132713	VITALIY PAVLOV	{"email": "pavlov.vitaliy_22121984@postgrespro.ru", "phone": "+70065430420"}
0005432329445	2D4D5E	8564 626778	ELENA KUZNECOVA	{"email": "ekuznecova-1956@postgrespro.ru", "phone": "+70613918064"}
0005432329446	B55CA3	9563 373721	VADIM ANTONOV	{"email": "v.antonov.11071962@postgrespro.ru", "phone": "+70551957611"}
0005432329447	CE8938	5012 571488	MAKSIM ZHUKOV	{"phone": "+70719726219"}
0005432329448	CE8938	8871 990505	TATYANA BORISOVA	{"email": "borisovatatyana021968@postgrespro.ru", "phone": "+70243091993"}
0005432329449	53017B	6704 748085	SERGEY CHERNOV	{"phone": "+70969048800"}
0005432329450	53017B	0732 183717	TAMARA KALININA	{"phone": "+70831533165"}
0005432329451	FF6031	9676 507269	IRINA KAZAKOVA	{"phone": "+70879696170"}
0005432329452	FF6031	2318 280378	SVETLANA AFANASEVA	{"phone": "+70606711834"}
0005432329453	FF6031	4945 990370	ALEKSEY TIKHONOV	{"email": "tikhonov-aleksey_1981@postgrespro.ru", "phone": "+70915648228"}
0005432329454	30124B	9034 762055	LYUDMILA KRASNOVA	{"phone": "+70634542129"}
0005432329455	30124B	7126 130142	YURIY STEPANOV	{"phone": "+70249568887"}
0005432329456	5324E3	8100 177728	LYUDMILA NIKIFOROVA	{"email": "l-nikiforova_1966@postgrespro.ru", "phone": "+70001676742"}
0005432329457	5FC413	4344 779033	YURIY SCHERBAKOV	{"email": "yuriy.scherbakov-17061974@postgrespro.ru", "phone": "+70957136071"}
0005432329458	3513CE	3033 024006	LYUDMILA RYABOVA	{"phone": "+70247902434"}
0005432329459	3513CE	7633 886128	TATYANA ABRAMOVA	{"email": "abramovatatyana021973@postgrespro.ru", "phone": "+70107134952"}
0005432329460	6B749D	8706 258298	YURIY SERGEEV	{"email": "yuriysergeev_01121968@postgrespro.ru", "phone": "+70232644648"}
0005432329461	A88F67	0459 684026	IVAN SAVELEV	{"email": "ivan.savelev.1964@postgrespro.ru", "phone": "+70773207997"}
0005432329462	C59345	8421 981261	GRIGORIY ROMANOV	{"email": "gromanov1972@postgrespro.ru", "phone": "+70113170637"}
0005432329463	00F2F1	2317 595315	OLGA PETROVA	{"phone": "+70546309370"}
0005432329464	AB3E70	5930 639590	VALENTINA MIRONOVA	{"phone": "+70098572751"}
0005432329465	ED66C6	8180 470981	SERGEY SCHERBAKOV	{"phone": "+70540292772"}
0005432329466	ED66C6	0149 260384	EKATERINA MAKSIMOVA	{"email": "maksimova-e_01081974@postgrespro.ru", "phone": "+70968096948"}
0005432329467	D87B69	6612 583261	MAKSIM ZAKHAROV	{"email": "zakharov_m1978@postgrespro.ru", "phone": "+70520959659"}
0005432329468	A49BA6	8627 362713	IGOR SCHERBAKOV	{"phone": "+70342847644"}
0005432329469	A49BA6	3404 152097	SVETLANA ANDREEVA	{"email": "andreeva-s-05041975@postgrespro.ru", "phone": "+70633303851"}
0005432329470	540D26	7739 269771	EVGENIY KISELEV	{"email": "ekiselev_1974@postgrespro.ru", "phone": "+70364940529"}
0005432329471	540D26	4774 226432	TATYANA NAUMOVA	{"phone": "+70885726706"}
0005432329472	299F0D	7471 329289	TATYANA KARPOVA	{"email": "tatyana_karpova_08021984@postgrespro.ru", "phone": "+70663996683"}
0005432329473	E04779	9238 831818	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila.18121990@postgrespro.ru", "phone": "+70686764153"}
0005432329474	D0BCE9	6200 797150	ANASTASIYA VLASOVA	{"phone": "+70841578148"}
0005432329475	D0BCE9	8497 674818	VASILIY SOROKIN	{"phone": "+70428519900"}
0005432329476	9F01E0	5006 438825	VALENTINA MARTYNOVA	{"email": "valentina.martynova-1971@postgrespro.ru", "phone": "+70642594657"}
0005432329477	9F01E0	3127 169726	FARIDA MALYSHEVA	{"email": "malysheva-f061974@postgrespro.ru", "phone": "+70313280939"}
0005432329478	460185	5238 317294	ALEKSANDR ABRAMOV	{"phone": "+70816017641"}
0005432329479	A2CEDA	5230 067887	ALEKSEY SOROKIN	{"phone": "+70998897068"}
0005432329480	A2CEDA	8554 228395	NINA LAZAREVA	{"email": "n_lazareva-18011980@postgrespro.ru", "phone": "+70969054684"}
0005432329481	7049A0	2598 014120	MAKSIM MEDVEDEV	{"phone": "+70280278307"}
0005432329482	7049A0	4615 189364	PAVEL ALEKSANDROV	{"phone": "+70811406363"}
0005432329483	298981	2341 989702	ANNA KONOVALOVA	{"phone": "+70268668952"}
0005432329484	8CDC51	7047 042672	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr-1962@postgrespro.ru", "phone": "+70781791792"}
0005432329485	43501D	2049 330639	VALENTINA RYABOVA	{"email": "ryabova_v-25021977@postgrespro.ru", "phone": "+70834032600"}
0005432329486	A4410F	7950 283178	ALEKSANDR FEDOROV	{"phone": "+70576843116"}
0005432329487	A4410F	2302 675928	DMITRIY CHERNOV	{"email": "d-chernov_1981@postgrespro.ru", "phone": "+70628740816"}
0005432329488	9A17BF	4969 625388	LARISA SOROKINA	{"email": "l-sorokina_29071975@postgrespro.ru", "phone": "+70001257516"}
0005432329489	C2154F	9532 315181	MIKHAIL ALEKSANDROV	{"email": "m-aleksandrov.101979@postgrespro.ru", "phone": "+70080837165"}
0005432329490	C2154F	6822 914879	ANATOLIY NOVIKOV	{"phone": "+70414019067"}
0005432329491	0006C3	4486 459735	YULIYA TROFIMOVA	{"email": "yuliyatrofimova-011988@postgrespro.ru", "phone": "+70850747734"}
0005432329492	0006C3	1691 126633	FARIT ZAKHAROV	{"email": "zakharov-farit27091972@postgrespro.ru", "phone": "+70301259324"}
0005432329493	1D5D17	2427 008498	ANATOLIY ISAEV	{"email": "isaev.anatoliy.1976@postgrespro.ru", "phone": "+70552516380"}
0005432329494	1D5D17	9211 163707	ELENA KOZLOVA	{"email": "elena-kozlova-20071958@postgrespro.ru", "phone": "+70992285086"}
0005432329495	53E154	9540 501950	ELENA BORISOVA	{"phone": "+70254747051"}
0005432329496	2D6819	4533 194268	ELENA NIKITINA	{"phone": "+70030373530"}
0005432329497	2D6819	9689 538953	LYUDMILA ALEKSEEVA	{"email": "alekseeval.17061977@postgrespro.ru", "phone": "+70244452104"}
0005432329498	64D762	5193 348818	IRINA SOKOLOVA	{"email": "sokolova.i.15111982@postgrespro.ru", "phone": "+70676966368"}
0005432329499	64D762	6994 798621	NINA SCHERBAKOVA	{"phone": "+70827107558"}
0005432329500	C0ED0E	9856 160895	GENNADIY SCHERBAKOV	{"email": "scherbakov.gennadiy_12021966@postgrespro.ru", "phone": "+70764171859"}
0005432329501	C0ED0E	8868 254522	MIKHAIL MATVEEV	{"email": "matveev-m20091969@postgrespro.ru", "phone": "+70035681805"}
0005432329502	C0FAE1	8078 079193	TAGIR STEPANOV	{"email": "stepanov-t-19101978@postgrespro.ru", "phone": "+70989964332"}
0005432329503	BCFD5B	0934 451572	VIKTOR VASILEV	{"phone": "+70414072273"}
0005432329504	BCFD5B	0744 300863	ELVIRA LAZAREVA	{"email": "lazareva-elvira1974@postgrespro.ru", "phone": "+70730180694"}
0005432329505	7A1860	8903 558152	VLADIMIR CHERNOV	{"phone": "+70156348642"}
0005432329506	7A1860	2284 984537	EVGENIY SOKOLOV	{"phone": "+70967383154"}
0005432329507	052943	6438 233200	SERGEY SOLOVEV	{"phone": "+70061798870"}
0005432329508	448BCA	6551 410753	LYUDMILA KONDRATEVA	{"email": "lyudmila-kondrateva011962@postgrespro.ru", "phone": "+70527134005"}
0005432329509	448BCA	2537 379410	ZOYA SOLOVEVA	{"phone": "+70846310435"}
0005432329510	371B9D	9005 085448	ALEKSANDR SMIRNOV	{"email": "smirnov.a-1970@postgrespro.ru", "phone": "+70048681904"}
0005432329511	E9A36F	5044 095630	VLADIMIR GAVRILOV	{"email": "v-gavrilov051977@postgrespro.ru", "phone": "+70066668417"}
0005432329512	E9A36F	0953 339909	YURIY GRIGOREV	{"phone": "+70435125101"}
0005432329513	D95676	7958 989697	IRINA ZAKHAROVA	{"email": "zakharova-irina.1967@postgrespro.ru", "phone": "+70220857399"}
0005432329514	7C1137	0315 810627	ANASTASIYA MELNIKOVA	{"email": "anastasiya-melnikova.29071986@postgrespro.ru", "phone": "+70581727697"}
0005432329515	2BD9CD	5559 067280	ALISA MELNIKOVA	{"email": "melnikovaa_091977@postgrespro.ru", "phone": "+70188450898"}
0005432329516	6E7F92	4293 234102	RASHID KONOVALOV	{"email": "rkonovalov1971@postgrespro.ru", "phone": "+70206082390"}
0005432329517	6E7F92	1007 388336	OLGA SCHERBAKOVA	{"email": "scherbakova-o.1968@postgrespro.ru", "phone": "+70830470721"}
0005432329518	3A1E10	3292 513396	VLADIMIR GORBUNOV	{"email": "gorbunov_v.1974@postgrespro.ru", "phone": "+70732130458"}
0005432329519	9E0491	8758 917732	NIKITA PETROV	{"email": "petrov-nikita18101970@postgrespro.ru", "phone": "+70923154475"}
0005432329520	9E0491	6588 750054	EKATERINA ILINA	{"phone": "+70422341990"}
0005432329521	860A21	3870 413049	EKATERINA SOKOLOVA	{"phone": "+70886457154"}
0005432329522	7D2A79	9238 904839	POLINA SCHERBAKOVA	{"phone": "+70204529644"}
0005432329523	7D2A79	5021 383516	FARIDA SMIRNOVA	{"email": "smirnova-farida.081978@postgrespro.ru", "phone": "+70636750625"}
0005432329524	CEC833	9852 443444	SERGEY ZAKHAROV	{"phone": "+70190183509"}
0005432329525	CEC833	8969 433172	LYUBOV MELNIKOVA	{"phone": "+70039271935"}
0005432329526	CCEB1B	0173 853876	PETR NAZAROV	{"email": "nazarov_petr-111977@postgrespro.ru", "phone": "+70497262142"}
0005432329527	A40B0B	3247 090205	PAVEL KUZNECOV	{"email": "p_kuznecov_051981@postgrespro.ru", "phone": "+70967279187"}
0005432329528	A40B0B	5569 781117	LIDIYA AKIMOVA	{"email": "lidiya.akimova-14031974@postgrespro.ru", "phone": "+70912171900"}
0005432329529	C772C7	5654 411317	ILONA NIKITINA	{"email": "i_nikitina_1966@postgrespro.ru", "phone": "+70280918924"}
0005432329530	7EDD08	9076 317434	ALEKSEY KUZMIN	{"phone": "+70766150072"}
0005432329531	173A7C	9392 333921	ANDREY MIKHAYLOV	{"email": "mikhaylov.andrey.08041978@postgrespro.ru", "phone": "+70138611872"}
0005432329532	40118A	6984 257712	LILIYA AFANASEVA	{"phone": "+70597562184"}
0005432329533	40118A	5318 360892	VERA ABRAMOVA	{"email": "abramovavera.1971@postgrespro.ru", "phone": "+70468890560"}
0005432329534	8D045A	3867 488807	NATALIYA PAVLOVA	{"phone": "+70482247963"}
0005432329535	8D045A	3558 625808	ANASTASIYA FOMINA	{"phone": "+70557959061"}
0005432329536	160EF6	9464 784755	GENNADIY NAZAROV	{"email": "nazarov.gennadiy1968@postgrespro.ru", "phone": "+70453441126"}
0005432329537	160EF6	2850 823141	LIDIYA MOISEEVA	{"phone": "+70710280951"}
0005432329538	70AC8B	0966 304924	TATYANA EFREMOVA	{"email": "tatyana_efremova_1978@postgrespro.ru", "phone": "+70326700295"}
0005432329539	85ADDA	2149 044355	ALEKSEY SOROKIN	{"email": "a_sorokin-1974@postgrespro.ru", "phone": "+70676530335"}
0005432329540	A28BC0	9765 070222	NIKOLAY KRASNOV	{"email": "krasnov.nikolay_1969@postgrespro.ru", "phone": "+70979902301"}
0005432329541	3A22B4	1222 095793	LILIYA DMITRIEVA	{"phone": "+70887958410"}
0005432329542	3A22B4	1980 855579	EVGENIYA BELOVA	{"email": "belova_evgeniya1969@postgrespro.ru", "phone": "+70541568469"}
0005432329543	3DEC13	2531 027380	ALEKSANDR VLASOV	{"email": "a-vlasov-1966@postgrespro.ru", "phone": "+70553131268"}
0005432329544	5EAB20	4314 969677	SERGEY ROMANOV	{"phone": "+70830692432"}
0005432329545	4CD69E	9197 407942	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_121966@postgrespro.ru", "phone": "+70277748144"}
0005432329546	23AC4B	5491 774489	VLADIMIR ZAYCEV	{"email": "vladimirzaycev061972@postgrespro.ru", "phone": "+70090942768"}
0005432329547	23AC4B	7182 893443	VLADIMIR KRASNOV	{"phone": "+70566624033"}
0005432329548	23AC4B	5182 561084	SOFYA ANDREEVA	{"phone": "+70036889242"}
0005432329549	34BC62	7916 752704	ANDREY GRIGOREV	{"email": "grigorev.andrey.22021977@postgrespro.ru", "phone": "+70166126274"}
0005432329550	6E9CFD	1050 128945	ALEKSANDR VASILEV	{"phone": "+70803460398"}
0005432329551	99D10B	8390 460916	YULIYA FROLOVA	{"email": "y-frolova.1972@postgrespro.ru", "phone": "+70909996146"}
0005432329552	62F442	8328 049879	VENIAMIN MAKAROV	{"email": "makarovv.051964@postgrespro.ru", "phone": "+70132815586"}
0005432329553	BBDDA6	0448 721165	ALENA YUDINA	{"email": "yudina_a_1974@postgrespro.ru", "phone": "+70880598061"}
0005432329554	A4973B	2223 846907	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova-051987@postgrespro.ru", "phone": "+70015614428"}
0005432329555	D6FA12	3087 068374	DMITRIY GAVRILOV	{"email": "gavrilov_d_1968@postgrespro.ru", "phone": "+70024890879"}
0005432329556	D6FA12	4986 574043	NATALYA KUZNECOVA	{"phone": "+70358200003"}
0005432329557	26000E	2040 496427	MARIYA ZOTOVA	{"email": "zotova_m-1985@postgrespro.ru", "phone": "+70510315287"}
0005432329558	847D3F	0858 193399	LYUBOV CHERNOVA	{"email": "chernova_lyubov.1976@postgrespro.ru", "phone": "+70780104086"}
0005432329559	9F4E07	5157 879468	ALEKSANDRA TITOVA	{"phone": "+70244771529"}
0005432329560	9D650F	9407 878975	ALEKSEY VASILEV	{"phone": "+70686986888"}
0005432329561	9D650F	7070 955865	EKATERINA DENISOVA	{"email": "ekaterina-denisova_061974@postgrespro.ru", "phone": "+70451168392"}
0005432329562	58809B	4869 217517	ALENA SEMENOVA	{"phone": "+70360537738"}
0005432329563	58809B	6072 585680	ALEKSEY BONDARENKO	{"phone": "+70048520624"}
0005432329564	0DF817	7301 728693	ALISA ISAEVA	{"phone": "+70236176882"}
0005432329565	A07613	7770 199067	LIDIYA MELNIKOVA	{"phone": "+70458038306"}
0005432329566	A07613	3885 738180	EVGENIY BORISOV	{"phone": "+70448488904"}
0005432329567	C426EA	8586 333271	ZHANNA MOROZOVA	{"email": "z.morozova04111972@postgrespro.ru", "phone": "+70071210343"}
0005432329568	E1BF26	3847 075205	VALENTINA AFANASEVA	{"phone": "+70214395828"}
0005432329569	DE4028	9331 011008	TATYANA VASILEVA	{"email": "vasilevat-07101970@postgrespro.ru", "phone": "+70262913945"}
0005432329570	DE4028	1592 260284	NIKOLAY OSIPOV	{"email": "n_osipov1961@postgrespro.ru", "phone": "+70930387823"}
0005432329571	D905EF	6447 941701	MARGARITA KOROLEVA	{"email": "m_koroleva.1971@postgrespro.ru", "phone": "+70003788468"}
0005432329572	D905EF	8381 908155	VALENTINA SEMENOVA	{"phone": "+70746580991"}
0005432329573	605B10	3807 852160	DARYA ISAEVA	{"email": "darya_isaeva-011968@postgrespro.ru", "phone": "+70493896690"}
0005432329574	B643DF	3192 185648	RUMIYA SOROKINA	{"email": "rsorokina.041983@postgrespro.ru", "phone": "+70383642798"}
0005432329575	D48108	8446 099345	TATYANA TARASOVA	{"phone": "+70944638113"}
0005432329576	A3EB01	6830 398713	MARIYA CHERNOVA	{"phone": "+70427744466"}
0005432329577	4FB67F	4703 261728	VITALIY NIKOLAEV	{"email": "nikolaev-vitaliy-25011975@postgrespro.ru", "phone": "+70458486566"}
0005432329578	907F60	3123 111821	VALERIY ZHUKOV	{"email": "zhukov-v.28021972@postgrespro.ru", "phone": "+70005714526"}
0005432329579	907F60	3611 314520	ALEKSANDR RODIONOV	{"phone": "+70354502554"}
0005432329580	A258AF	7260 579402	BOGDAN VOLKOV	{"email": "bogdan_volkov091970@postgrespro.ru", "phone": "+70001416433"}
0005432329581	EAFC55	5092 153985	ELIZAVETA NAZAROVA	{"email": "e.nazarova_1973@postgrespro.ru", "phone": "+70056737413"}
0005432329582	B03B2E	8105 725957	ALEKSANDRA ZHURAVLEVA	{"phone": "+70279860316"}
0005432329583	E65572	1350 027549	LARISA KUZNECOVA	{"email": "l-kuznecova-20091975@postgrespro.ru", "phone": "+70496318686"}
0005432329584	E65572	9804 708802	SVETLANA SMIRNOVA	{"email": "smirnova_svetlana-051971@postgrespro.ru", "phone": "+70572273851"}
0005432329585	5CD6B4	4289 867738	VIKTOR EGOROV	{"email": "egorov-viktor_061984@postgrespro.ru", "phone": "+70739905084"}
0005432329586	DD1082	8216 709913	MIKHAIL ZHUKOV	{"phone": "+70224208616"}
0005432329587	F0960E	9729 024207	VIKTOR CHERNOV	{"email": "v_chernov_121970@postgrespro.ru", "phone": "+70222781091"}
0005432329588	7EFA22	1888 234985	SERGEY NIKOLAEV	{"phone": "+70128307027"}
0005432329589	26467A	3682 427051	ARTEM MAKAROV	{"phone": "+70948968919"}
0005432329590	26467A	3449 169832	IRINA KOROLEVA	{"email": "i_koroleva-121974@postgrespro.ru", "phone": "+70605357098"}
0005432329591	3E433A	9450 741982	IVAN MOROZOV	{"email": "i.morozov-18041965@postgrespro.ru", "phone": "+70881767243"}
0005432329592	BE3467	5400 579557	ALEKSANDR BORISOV	{"phone": "+70880402946"}
0005432329593	123EDB	8419 051588	ELENA PETROVA	{"phone": "+70300595876"}
0005432329594	A23268	3322 996994	NIKOLAY POPOV	{"email": "popov.nikolay091970@postgrespro.ru", "phone": "+70687642922"}
0005432329595	C71ACB	8130 232151	ROZA NOVIKOVA	{"email": "r_novikova_121966@postgrespro.ru", "phone": "+70805235003"}
0005432329596	C71ACB	6501 005946	VALERIY PETROV	{"phone": "+70670650590"}
0005432329597	B0A65D	4948 747386	ALEKSANDR DENISOV	{"phone": "+70121184549"}
0005432329598	CEBD5D	5394 058262	SVETLANA MAKAROVA	{"email": "s.makarova_111972@postgrespro.ru", "phone": "+70822911454"}
0005432329599	CEBD5D	7517 797985	GENNADIY FEDOROV	{"email": "gennadiyfedorov_1963@postgrespro.ru", "phone": "+70676607606"}
0005432329600	04A624	2107 913199	YURIY MEDVEDEV	{"email": "medvedev-y-121972@postgrespro.ru", "phone": "+70860288669"}
0005432329601	04A624	2281 510006	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a1979@postgrespro.ru", "phone": "+70357481665"}
0005432329602	1A473A	1552 816980	NATALYA TROFIMOVA	{"phone": "+70187511408"}
0005432329603	740234	5453 853003	VALERIY NOVIKOV	{"phone": "+70420716219"}
0005432329604	B9CF9D	8592 902784	EVGENIY TIMOFEEV	{"email": "timofeev-e-1971@postgrespro.ru", "phone": "+70628478437"}
0005432329605	FB6EAD	7104 586779	NADEZHDA BELOVA	{"phone": "+70913347631"}
0005432329606	91F968	9437 146389	VLADIMIR MAKAROV	{"email": "v_makarov021972@postgrespro.ru", "phone": "+70210982031"}
0005432329607	91F968	3482 047453	OKSANA FEDOROVA	{"email": "ofedorova_06071986@postgrespro.ru", "phone": "+70825214876"}
0005432329608	91F968	3398 906921	VLADIMIR MIRONOV	{"phone": "+70143944822"}
0005432329609	929072	2507 787997	BORIS POPOV	{"email": "popov-b09031973@postgrespro.ru", "phone": "+70746211653"}
0005432329610	929072	9917 643374	NIKOLAY VOROBEV	{"email": "nikolay.vorobev-07081980@postgrespro.ru", "phone": "+70276367298"}
0005432329611	BC4260	8416 582212	KSENIYA DANILOVA	{"email": "kseniya-danilova101982@postgrespro.ru", "phone": "+70339211201"}
0005432329612	AF3330	4123 249135	GALINA VOLKOVA	{"email": "gvolkova_111972@postgrespro.ru", "phone": "+70258943267"}
0005432329613	B32373	2357 085754	MARGARITA GAVRILOVA	{"phone": "+70244388828"}
0005432329614	7BA64C	7781 683028	ROMAN KOROLEV	{"phone": "+70901999437"}
0005432329615	2E4E2E	1586 244739	NIKITA GORBUNOV	{"phone": "+70347310913"}
0005432329616	2E4E2E	5983 976904	DMITRIY SIDOROV	{"email": "sidorovd-1972@postgrespro.ru", "phone": "+70958429462"}
0005432329617	F5EBE1	5589 256199	ALINA DMITRIEVA	{"phone": "+70548047159"}
0005432329618	F5EBE1	9023 623751	PETR MAKSIMOV	{"phone": "+70116723796"}
0005432329619	88675E	1938 211110	EVGENIY KULIKOV	{"phone": "+70317249220"}
0005432329620	11ECEF	8407 707406	SAVELIY IVANOV	{"email": "saveliy_ivanov_30091974@postgrespro.ru", "phone": "+70100309416"}
0005432329621	031FE5	3190 827906	LARISA KOZLOVA	{"phone": "+70508380031"}
0005432329622	FBBDB9	3505 430936	NIKOLAY FILIPPOV	{"phone": "+70435244550"}
0005432329623	62562C	2531 552784	NATALIYA POTAPOVA	{"email": "nataliya-potapova04091978@postgrespro.ru", "phone": "+70890907351"}
0005432329624	F2DE37	5660 190845	ELENA MAKSIMOVA	{"phone": "+70192908801"}
0005432329625	F2DE37	7910 442327	LILIYA FEDOROVA	{"email": "fedoroval_21081969@postgrespro.ru", "phone": "+70324616818"}
0005432329626	F7C7EC	1950 911103	TAISIYA ISAEVA	{"phone": "+70462618855"}
0005432329627	F7C7EC	6288 328214	MIKHAIL DAVYDOV	{"phone": "+70279346631"}
0005432329628	195CA5	5114 782852	OLGA KUZNECOVA	{"email": "olga-kuznecova111971@postgrespro.ru", "phone": "+70797757668"}
0005432329629	195CA5	4179 086187	MARINA IVANOVA	{"email": "ivanovamarina.051963@postgrespro.ru", "phone": "+70709744124"}
0005432329630	EADC0A	5701 474745	MARINA KOZLOVA	{"email": "marina_kozlova-09061971@postgrespro.ru", "phone": "+70961222526"}
0005432329631	EADC0A	1032 116615	VITALIY MARTYNOV	{"email": "vitaliymartynov-25011983@postgrespro.ru", "phone": "+70866526284"}
0005432329632	A1638C	7917 753632	VALERIY MOROZOV	{"email": "morozovvaleriy-1968@postgrespro.ru", "phone": "+70262784108"}
0005432329633	EB5018	9401 691764	NADEZHDA EGOROVA	{"phone": "+70685418472"}
0005432329634	EB5018	5739 765865	LYUDMILA MAKSIMOVA	{"phone": "+70978051768"}
0005432329635	EB5018	3157 605341	ALEVTINA VOLKOVA	{"phone": "+70495575503"}
0005432329636	56C1D4	0072 333386	PETR MELNIKOV	{"email": "melnikov_p.111974@postgrespro.ru", "phone": "+70398354055"}
0005432329637	BE7258	2947 959868	IRINA ZHUKOVA	{"phone": "+70509240339"}
0005432329638	4BA65F	6556 549938	ZINAIDA TARASOVA	{"email": "tarasovazinaida-071964@postgrespro.ru", "phone": "+70087347783"}
0005432329639	4BA65F	3721 215190	TATYANA FROLOVA	{"email": "frolova_tatyana.24051978@postgrespro.ru", "phone": "+70942703616"}
0005432329640	022D8B	7371 140213	ARTEM KUDRYASHOV	{"email": "kudryashovartem-011985@postgrespro.ru", "phone": "+70483276984"}
0005432329641	022D8B	9698 742634	YAN NIKOLAEV	{"email": "yan_nikolaev13091984@postgrespro.ru", "phone": "+70963959740"}
0005432329642	602CE3	6682 109891	SERGEY ZAYCEV	{"email": "szaycev_09051967@postgrespro.ru", "phone": "+70235569909"}
0005432329643	602CE3	6684 435281	NIKITA ABRAMOV	{"email": "nikitaabramov.061976@postgrespro.ru", "phone": "+70461699584"}
0005432329644	3882F5	5350 220685	TATYANA IVANOVA	{"email": "t.ivanova_041972@postgrespro.ru", "phone": "+70551866097"}
0005432329645	3882F5	3569 490769	TATYANA POPOVA	{"phone": "+70576589257"}
0005432329646	B6CB69	8294 069967	VIKTOR GUSEV	{"email": "vgusev1974@postgrespro.ru", "phone": "+70884966536"}
0005432329647	B6CB69	6879 379408	VALENTINA ABRAMOVA	{"phone": "+70884071682"}
0005432329648	52A5BD	0709 802402	GENNADIY FOMIN	{"email": "foming121968@postgrespro.ru", "phone": "+70304897763"}
0005432329649	52A5BD	0777 730331	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov-01021969@postgrespro.ru", "phone": "+70417373843"}
0005432329650	9E22EF	7590 515572	MARGARITA ZHUKOVA	{"email": "m-zhukova1972@postgrespro.ru", "phone": "+70444124190"}
0005432329651	9E22EF	5396 590258	LYUDMILA NIKOLAEVA	{"phone": "+70106250372"}
0005432329652	9E22EF	8586 321680	ROMAN ANTONOV	{"phone": "+70904562574"}
0005432329653	F6806F	4572 128954	NELLI ZAYCEVA	{"email": "nelli.zayceva.041971@postgrespro.ru", "phone": "+70741946119"}
0005432329654	5A4DB3	5972 925417	IRINA TIKHONOVA	{"email": "tikhonova.irina.03111970@postgrespro.ru", "phone": "+70514767351"}
0005432329655	5A4DB3	4326 457172	OLGA GERASIMOVA	{"email": "o-gerasimova-12011974@postgrespro.ru", "phone": "+70382868380"}
0005432329656	7B7FC9	6648 560601	SERGEY NIKITIN	{"email": "sergeynikitin-21041976@postgrespro.ru", "phone": "+70772576371"}
0005432329657	5D9363	2491 690795	VALENTINA FILIPPOVA	{"phone": "+70168265908"}
0005432329658	F51C23	6781 380249	ANDREY PAVLOV	{"email": "andrey-pavlov_061971@postgrespro.ru", "phone": "+70764253685"}
0005432329659	462557	1841 358565	IVAN KUZNECOV	{"email": "i_kuznecov1959@postgrespro.ru", "phone": "+70662554002"}
0005432329660	82E28A	3826 091482	LIDIYA NOVIKOVA	{"phone": "+70193550879"}
0005432329661	9FAF07	8271 589529	DENIS KAZAKOV	{"phone": "+70089334852"}
0005432329662	625574	3859 184713	ALEKSANDR FEDOROV	{"phone": "+70023649192"}
0005432329663	2BC708	7795 778668	GENNADIY YAKOVLEV	{"email": "gyakovlev.08101971@postgrespro.ru", "phone": "+70394076890"}
0005432329664	E0B893	8515 809275	SERGEY MIKHAYLOV	{"email": "mikhaylov.s-06121987@postgrespro.ru", "phone": "+70196422500"}
0005432329665	E0B893	4409 336210	TAISIYA KALININA	{"email": "kalinina_t-011971@postgrespro.ru", "phone": "+70554831412"}
0005432329666	2D100C	6304 805039	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr1959@postgrespro.ru", "phone": "+70218219723"}
0005432329667	0DE9F8	5065 901839	TATYANA BOGDANOVA	{"email": "bogdanova_tatyana_1970@postgrespro.ru", "phone": "+70644330308"}
0005432329668	F62194	4960 687804	TAMARA NIKITINA	{"phone": "+70054993055"}
0005432329669	0B5FA2	2464 289532	ELENA FEDOROVA	{"email": "fedorovae_1978@postgrespro.ru", "phone": "+70138871093"}
0005432329670	4DCBB5	9107 480569	ALEKSEY GERASIMOV	{"email": "gerasimov.aleksey-1983@postgrespro.ru", "phone": "+70244084732"}
0005432329671	494C2F	6817 256335	LYUDMILA KOZLOVA	{"email": "kozlova_l_05031974@postgrespro.ru", "phone": "+70006904966"}
0005432329672	494C2F	6668 594103	YULIYA ALEKSANDROVA	{"phone": "+70686230895"}
0005432329673	E19B82	1262 244449	EVGENIY KONOVALOV	{"phone": "+70860437621"}
0005432329674	534DA7	1838 181731	MARIYA TARASOVA	{"phone": "+70271635488"}
0005432329675	8B0D66	5340 028201	OLGA KUZNECOVA	{"email": "o_kuznecova-021976@postgrespro.ru", "phone": "+70925204835"}
0005432329676	50FE70	6226 546584	EDUARD MARTYNOV	{"email": "e_martynov_31081975@postgrespro.ru", "phone": "+70033649328"}
0005432329677	50FE70	7922 241645	DAMIR ABRAMOV	{"phone": "+70709675245"}
0005432329678	7F87EC	6423 046761	NIKITA SERGEEV	{"email": "sergeev-nikita-031984@postgrespro.ru", "phone": "+70029842540"}
0005432329679	5118AF	2832 215219	SVETLANA CHERNOVA	{"phone": "+70249682843"}
0005432329680	BFE438	0791 099311	EKATERINA VASILEVA	{"email": "vasileva_ekaterina.011971@postgrespro.ru", "phone": "+70524071665"}
0005432329681	10582E	7555 061261	MARIYA KUZNECOVA	{"phone": "+70858839868"}
0005432329682	A3DF8B	7351 740744	DMITRIY ZAYCEV	{"phone": "+70301392890"}
0005432329683	A3DF8B	1115 940618	SVETLANA KISELEVA	{"phone": "+70457541177"}
0005432329684	A3DF8B	5802 191100	DARYA ROMANOVA	{"email": "d.romanova.071969@postgrespro.ru", "phone": "+70431104067"}
0005432329685	B44E55	0301 920909	VALENTINA ANDREEVA	{"phone": "+70893515152"}
0005432329686	46860B	4121 122042	VIKTOR ILIN	{"email": "ilin_v01081973@postgrespro.ru", "phone": "+70633719483"}
0005432329687	3596F3	5778 683846	YULIYA MELNIKOVA	{"email": "melnikova-yuliya_011966@postgrespro.ru", "phone": "+70403933075"}
0005432329688	3596F3	6509 614097	IGOR GUSEV	{"email": "gusev-igor-031969@postgrespro.ru", "phone": "+70209573917"}
0005432329689	56B4D7	7027 397415	IRINA MATVEEVA	{"email": "matveeva.irina1975@postgrespro.ru", "phone": "+70810644088"}
0005432329690	56B4D7	1284 800161	ALEKSEY ISAEV	{"phone": "+70149091366"}
0005432329691	B76AE2	0108 917456	OLGA BELYAEVA	{"email": "belyaeva.olga_03081976@postgrespro.ru", "phone": "+70652304739"}
0005432329692	7CACC3	0272 842003	SHAMIL MATVEEV	{"email": "matveevshamil081973@postgrespro.ru", "phone": "+70978534529"}
0005432329693	4C8A50	6098 969121	ARTEM DAVYDOV	{"phone": "+70958956191"}
0005432329694	5AB475	1712 553841	MIKHAIL KULIKOV	{"phone": "+70681482324"}
0005432329695	5AB475	3588 058859	YULIYA KISELEVA	{"phone": "+70585763402"}
0005432329696	2BFC62	9459 999286	NATALYA IVANOVA	{"email": "ivanova.n_021972@postgrespro.ru", "phone": "+70184267529"}
0005432329697	2BFC62	4477 681157	ALEKSEY KARPOV	{"email": "karpov-aleksey.1969@postgrespro.ru", "phone": "+70317238698"}
0005432329698	129434	8997 532038	EVGENIYA PETROVA	{"email": "e-petrova_03111957@postgrespro.ru", "phone": "+70601314934"}
0005432329699	C5D08D	4653 156825	SVETLANA KOZLOVA	{"phone": "+70841507158"}
0005432329700	08759E	6666 648192	SVETLANA KUZNECOVA	{"phone": "+70469044716"}
0005432329701	DE39E3	6927 502736	NINA KOZLOVA	{"phone": "+70589160045"}
0005432329702	341A2C	9896 319277	OKSANA ZAKHAROVA	{"email": "zakharova_oksana_29061968@postgrespro.ru", "phone": "+70850812088"}
0005432329703	00ABC2	6377 736416	YULIYA VOROBEVA	{"phone": "+70519527111"}
0005432329704	00ABC2	9634 004367	VALERIYA EGOROVA	{"email": "egorova.v121970@postgrespro.ru", "phone": "+70932364540"}
0005432329705	49C272	9561 947388	LYUDMILA DANILOVA	{"email": "l.danilova.021980@postgrespro.ru", "phone": "+70522787440"}
0005432329706	404CF5	7569 314392	VALERIY SIDOROV	{"phone": "+70353068297"}
0005432329707	614FC9	8656 349347	NATALYA PETROVA	{"phone": "+70345788287"}
0005432329708	40DD2C	3572 480241	GRIGORIY TARASOV	{"phone": "+70286987421"}
0005432329709	40DD2C	6689 725645	TAMARA KOROLEVA	{"email": "koroleva.t_1967@postgrespro.ru", "phone": "+70410361402"}
0005432329710	4BECE6	6939 282848	VLADIMIR STEPANOV	{"email": "vladimir.stepanov_03081970@postgrespro.ru", "phone": "+70461873852"}
0005432329711	2898D3	5072 071825	NATALYA OSIPOVA	{"email": "osipova-natalya.061972@postgrespro.ru", "phone": "+70402252509"}
0005432329712	2898D3	4262 684939	VALENTINA LUKYANOVA	{"email": "valentina-lukyanova.23111971@postgrespro.ru", "phone": "+70414559535"}
0005432329713	BB8D70	5583 342868	GALINA DAVYDOVA	{"phone": "+70391357623"}
0005432329714	6708CA	9571 423770	ALEKSANDR GUSEV	{"email": "gusev_a.051977@postgrespro.ru", "phone": "+70190812893"}
0005432329715	3ADC4A	5824 123075	EVGENIY KUZNECOV	{"email": "e.kuznecov_071968@postgrespro.ru", "phone": "+70636999681"}
0005432329716	D9F610	9840 990466	ELENA MELNIKOVA	{"phone": "+70148580554"}
0005432329717	D9F610	0589 871661	ZUKHRA NAZAROVA	{"phone": "+70915557421"}
0005432329718	1E6363	8005 094251	OLGA BOGDANOVA	{"email": "bogdanova_o-1968@postgrespro.ru", "phone": "+70992856371"}
0005432329719	1E6363	1152 407811	ANDREY ZHUKOV	{"email": "a.zhukov021979@postgrespro.ru", "phone": "+70887084908"}
0005432329720	DE8A74	2696 271451	LILIYA NESTEROVA	{"phone": "+70369249351"}
0005432329721	7FC5F9	3770 060375	VLADIMIR NIKOLAEV	{"email": "v-nikolaev1987@postgrespro.ru", "phone": "+70520348657"}
0005432329722	D0752D	3174 119129	MIKHAIL SHEVCHENKO	{"email": "mshevchenko_041993@postgrespro.ru", "phone": "+70044067672"}
0005432329723	0B2EAE	9642 961622	MAKSIM KUZNECOV	{"email": "kuznecov.m.22081975@postgrespro.ru", "phone": "+70588897398"}
0005432329724	0B2EAE	7360 787707	ELVIRA ABRAMOVA	{"phone": "+70471026872"}
0005432329725	0B2EAE	2353 290131	ALEKSEY SOLOVEV	{"email": "solovevaleksey-081974@postgrespro.ru", "phone": "+70452697870"}
0005432329726	126DBE	5073 674389	LYUBOV FEDOROVA	{"phone": "+70346083813"}
0005432329727	126DBE	2128 695928	ANDREY KUZNECOV	{"phone": "+70998397222"}
0005432329728	4B6811	3164 988302	YURIY DENISOV	{"email": "denisovyuriy.071974@postgrespro.ru", "phone": "+70466560165"}
0005432329729	4B6811	6021 874380	GALINA FILIPPOVA	{"email": "g_filippova-14071967@postgrespro.ru", "phone": "+70104773672"}
0005432329730	07EF9C	1506 473039	PAVEL SOKOLOV	{"email": "sokolov.pavel.1972@postgrespro.ru", "phone": "+70157508726"}
0005432329731	07EF9C	6876 908680	MIKHAIL KISELEV	{"phone": "+70305650264"}
0005432329732	B1B247	1938 584720	GALINA MARTYNOVA	{"email": "martynova.g1964@postgrespro.ru", "phone": "+70860798533"}
0005432329733	B1B247	7803 755025	STEPAN KISELEV	{"phone": "+70900822443"}
0005432329734	766CE1	4133 855083	IRINA IVANOVA	{"email": "i-ivanova-1968@postgrespro.ru", "phone": "+70544157394"}
0005432329735	9D84AA	1002 105507	MARIYA AFANASEVA	{"phone": "+70264591090"}
0005432329736	97F35B	8281 249749	LEONID SEMENOV	{"email": "semenov_leonid.1976@postgrespro.ru", "phone": "+70140819706"}
0005432329737	97F35B	0997 738902	MARINA ALEKSEEVA	{"phone": "+70688297215"}
0005432329738	16AF67	1212 004114	EVGENIY ZHUKOV	{"email": "zhukovevgeniy_011982@postgrespro.ru", "phone": "+70408364641"}
0005432329739	F3FCA3	9121 336207	LYUDMILA KARPOVA	{"email": "karpova_l.10051963@postgrespro.ru", "phone": "+70501551379"}
0005432329740	3F624E	7741 218977	GULNARA MAKAROVA	{"email": "makarovagulnara_01071974@postgrespro.ru", "phone": "+70079697087"}
0005432329741	BBD408	4273 788678	SERGEY ABRAMOV	{"email": "abramov.sergey.071979@postgrespro.ru", "phone": "+70873666076"}
0005432329742	F98E44	5791 520543	NIKITA NIKITIN	{"phone": "+70742794642"}
0005432329743	903E0D	7456 570773	LIDIYA TITOVA	{"phone": "+70910035723"}
0005432329744	C71773	4896 770667	ELENA KOVALEVA	{"email": "e-kovaleva.15031972@postgrespro.ru", "phone": "+70674058143"}
0005432329745	200A02	1125 923407	EVGENIY PAVLOV	{"email": "e_pavlov_1972@postgrespro.ru", "phone": "+70906364788"}
0005432329746	200A02	5490 749199	NATALYA LUKYANOVA	{"email": "lukyanova-n-23041970@postgrespro.ru", "phone": "+70254847463"}
0005432329747	43511F	0236 635428	ANTON TARASOV	{"email": "a_tarasov-061972@postgrespro.ru", "phone": "+70520689386"}
0005432329748	43511F	5709 633562	YURIY BARANOV	{"email": "baranov_y1971@postgrespro.ru", "phone": "+70087400961"}
0005432329749	0AFA62	2051 833983	EKATERINA KUDRYASHOVA	{"phone": "+70810101185"}
0005432329750	373285	3938 069703	OLGA POLYAKOVA	{"phone": "+70122072943"}
0005432329751	373285	5115 212860	KARINA KOZLOVA	{"email": "karina-kozlova_101972@postgrespro.ru", "phone": "+70918774242"}
0005432329752	E49279	5520 521381	ELENA LUKYANOVA	{"email": "lukyanova_elena1973@postgrespro.ru", "phone": "+70121044509"}
0005432329753	E49279	4711 173076	PAVEL MIKHAYLOV	{"phone": "+70662035912"}
0005432329754	E49279	0459 345347	GALINA MOROZOVA	{"phone": "+70863282279"}
0005432329755	F31F88	6407 473684	VALENTINA IVANOVA	{"phone": "+70304062621"}
0005432329756	F31F88	8221 076436	LARISA NOVIKOVA	{"email": "larisa_novikova.05061966@postgrespro.ru", "phone": "+70608953945"}
0005432329757	F31F88	0228 309175	IGOR GORBUNOV	{"email": "gorbunov-i101974@postgrespro.ru", "phone": "+70316669476"}
0005432329758	F91563	5912 507907	ANATOLIY SIDOROV	{"email": "sidorovanatoliy_1969@postgrespro.ru", "phone": "+70432165540"}
0005432329759	44C4E1	5792 283383	MIKHAIL POPOV	{"email": "popov_m-1966@postgrespro.ru", "phone": "+70267613868"}
0005432329760	151AD5	3795 625929	SERGEY KOROLEV	{"phone": "+70033141459"}
0005432329761	2FB166	4322 494223	ALEKSANDR VASILEV	{"email": "a.vasilev05081973@postgrespro.ru", "phone": "+70515212159"}
0005432329762	014F78	2342 880986	SERGEY MELNIKOV	{"email": "melnikov_s.101969@postgrespro.ru", "phone": "+70361476102"}
0005432329763	014F78	0590 175806	VLADIMIR ALEKSEEV	{"email": "v_alekseev121976@postgrespro.ru", "phone": "+70743210334"}
0005432329764	8F22A3	6008 532655	YULIYA KUZMINA	{"email": "kuzmina.yuliya-27071969@postgrespro.ru", "phone": "+70516167096"}
0005432329765	8F22A3	8738 965996	ALEKSANDR MOROZOV	{"email": "morozov.a-15111969@postgrespro.ru", "phone": "+70159987606"}
0005432329766	98D4F7	7542 823873	NIKOLAY VLASOV	{"phone": "+70221904423"}
0005432329767	D22139	3531 449563	ANDREY DMITRIEV	{"email": "dmitriev-a.031973@postgrespro.ru", "phone": "+70619606608"}
0005432329768	B171E7	6905 049885	OKSANA KOMAROVA	{"email": "komarova.oksana.081975@postgrespro.ru", "phone": "+70917496601"}
0005432329769	1D37AC	9399 865994	LEONID PETROV	{"phone": "+70269920058"}
0005432329770	A23B43	2538 530868	VIKTOR TIKHONOV	{"phone": "+70785160318"}
0005432329771	532CEF	4370 887816	MARGARITA GERASIMOVA	{"email": "gerasimovam16091973@postgrespro.ru", "phone": "+70696801061"}
0005432329772	920DEC	1040 192048	VASILIY NIKITIN	{"email": "nikitin_v_1980@postgrespro.ru", "phone": "+70858025531"}
0005432329773	808A6A	4934 348688	ALEKSANDR NIKITIN	{"phone": "+70533551807"}
0005432329774	BC4063	9317 657021	ZINAIDA NAUMOVA	{"phone": "+70990026862"}
0005432329775	5203C3	1455 771551	GALINA BORISOVA	{"email": "borisova.g_1978@postgrespro.ru", "phone": "+70652543008"}
0005432329776	5203C3	1707 461355	ELENA NESTEROVA	{"phone": "+70450363537"}
0005432329777	82B393	1805 233600	KIRILL TIMOFEEV	{"email": "ktimofeev.051971@postgrespro.ru", "phone": "+70463868121"}
0005432329778	82B393	6483 765232	PETR SEMENOV	{"email": "psemenov.101975@postgrespro.ru", "phone": "+70584492754"}
0005432329779	E8DA90	6704 314703	ELENA MEDVEDEVA	{"phone": "+70133684390"}
0005432329780	E8DA90	3377 750708	MARIYA DANILOVA	{"email": "danilova-mariya.1965@postgrespro.ru", "phone": "+70156644477"}
0005432329781	190C65	5562 516514	NATALYA MIKHAYLOVA	{"phone": "+70239000868"}
0005432329782	190C65	9085 590589	VALENTINA SMIRNOVA	{"phone": "+70929582996"}
0005432329783	190C65	8634 564846	TATYANA NIKITINA	{"email": "nikitinatatyana26111964@postgrespro.ru", "phone": "+70130961393"}
0005432329784	190C65	0697 908100	OLGA DENISOVA	{"phone": "+70582174149"}
0005432329785	D35244	7389 480981	OLGA SOKOLOVA	{"email": "sokolova_o20101965@postgrespro.ru", "phone": "+70385216222"}
0005432329786	4C171C	8087 468265	NINA KARPOVA	{"phone": "+70250202516"}
0005432329787	D2F933	5513 031976	EVGENIY FILIPPOV	{"phone": "+70649759066"}
0005432329788	13B820	5119 517204	ELENA PETROVA	{"phone": "+70721972606"}
0005432329789	3F2DA2	1617 963774	NIKITA KUZMIN	{"email": "n_kuzmin-1982@postgrespro.ru", "phone": "+70870120717"}
0005432329790	6A2FB0	5262 864423	ARTUR FROLOV	{"phone": "+70964043888"}
0005432329791	C212BC	8792 871492	SERGEY DENISOV	{"email": "s_denisov1967@postgrespro.ru", "phone": "+70018487347"}
0005432329792	C212BC	7268 652277	EDUARD GAVRILOV	{"email": "gavrilov-e25091963@postgrespro.ru", "phone": "+70103289190"}
0005432329793	F662F3	3293 175610	ANDREY CHERNOV	{"email": "andrey-chernov1966@postgrespro.ru", "phone": "+70295867802"}
0005432329794	F662F3	6406 779408	VIKTOR KULIKOV	{"email": "kulikov.viktor_1967@postgrespro.ru", "phone": "+70055997378"}
0005432329795	F662F3	5860 271541	SVETLANA VOROBEVA	{"email": "vorobevas15061977@postgrespro.ru", "phone": "+70824342838"}
0005432329796	00C23F	7186 342819	LYUDMILA ZAKHAROVA	{"phone": "+70506924465"}
0005432329797	3C1F84	3731 911448	TAMARA ILINA	{"email": "ilina.tamara23011971@postgrespro.ru", "phone": "+70467971212"}
0005432329798	3C1F84	4319 803489	ANDREY ZAKHAROV	{"phone": "+70343298223"}
0005432329799	3C1F84	7590 644963	ALEKSANDR STEPANOV	{"phone": "+70290710817"}
0005432329800	FAF3B5	7607 555381	MARIYA KONDRATEVA	{"phone": "+70633366500"}
0005432329801	21C37F	2755 786824	PAVEL KUZNECOV	{"phone": "+70356298286"}
0005432329802	ED1AAD	1357 144861	ALEKSEY SCHERBAKOV	{"email": "ascherbakov08071985@postgrespro.ru", "phone": "+70380274714"}
0005432329803	4AB6AA	2319 467445	LYUDMILA ZAKHAROVA	{"email": "zakharova_lyudmila_1974@postgrespro.ru", "phone": "+70943382187"}
0005432329804	4AB6AA	3738 876063	IVAN TIKHONOV	{"email": "tikhonov_ivan-1965@postgrespro.ru", "phone": "+70748141146"}
0005432329805	BE8CA4	9324 172156	POLINA DMITRIEVA	{"phone": "+70543792139"}
0005432329806	0D031A	5475 968443	LYUBOV POLYAKOVA	{"phone": "+70620395433"}
0005432329807	0D031A	2191 044024	IGOR TARASOV	{"phone": "+70026324276"}
0005432329808	EF000A	7816 432509	OLGA ALEKSEEVA	{"email": "alekseeva.olga30041973@postgrespro.ru", "phone": "+70877917110"}
0005432329809	D190A9	5597 763960	VALENTINA SOLOVEVA	{"email": "valentinasoloveva041969@postgrespro.ru", "phone": "+70373857073"}
0005432329810	50A61D	1155 296259	VYACHESLAV ILIN	{"email": "ilinv.1978@postgrespro.ru", "phone": "+70511765086"}
0005432329811	568E6A	6379 513283	PETR GAVRILOV	{"email": "pgavrilov.1971@postgrespro.ru", "phone": "+70955249993"}
0005432329812	568E6A	7865 679677	ELEONORA ALEKSEEVA	{"phone": "+70565323101"}
0005432329813	CB711A	4365 886819	NADEZHDA POPOVA	{"email": "nadezhda-popova_1979@postgrespro.ru", "phone": "+70175635954"}
0005432329814	B9A066	1896 075195	NATALYA MAKAROVA	{"email": "makarovanatalya_1986@postgrespro.ru", "phone": "+70839118738"}
0005432329815	129247	6852 705763	MARIYA SEMENOVA	{"email": "semenova-m-1984@postgrespro.ru", "phone": "+70990114122"}
0005432329816	B14C99	8484 111698	TAMARA VOLKOVA	{"phone": "+70184730753"}
0005432329817	92033B	4901 269855	SERGEY MAKAROV	{"email": "sergey-makarov.01101982@postgrespro.ru", "phone": "+70844674871"}
0005432329818	D49739	9387 947180	YURIY BARANOV	{"phone": "+70839401000"}
0005432329819	A4DEAD	8750 182628	LARISA VOROBEVA	{"email": "vorobeva-larisa_25021975@postgrespro.ru", "phone": "+70917007523"}
0005432329820	83AB14	3330 362036	MARINA TITOVA	{"phone": "+70705152498"}
0005432329821	520681	6654 207194	MAKSIM SHEVCHENKO	{"email": "maksim.shevchenko_1967@postgrespro.ru", "phone": "+70137886179"}
0005432329822	B80B91	1450 879757	NATALIYA NIKOLAEVA	{"phone": "+70864864706"}
0005432329823	60B254	9982 899366	NIKOLAY FROLOV	{"email": "frolov_n.03051976@postgrespro.ru", "phone": "+70755649017"}
0005432329824	60B254	2597 856581	OLEG IVANOV	{"phone": "+70620776151"}
0005432329825	75E829	5209 449152	ALEKSANDR PETROV	{"phone": "+70814773562"}
0005432329826	AA6053	0431 311527	NATALYA ZHURAVLEVA	{"email": "zhuravleva-n.1982@postgrespro.ru", "phone": "+70696933606"}
0005432329827	AA6053	1228 659316	LYUBOV PETROVA	{"phone": "+70050919466"}
0005432329828	224C76	3939 603259	ALEKSEY NIKITIN	{"email": "nikitin.a_17061972@postgrespro.ru", "phone": "+70368529238"}
0005432329829	224C76	3537 528934	ILYA IVANOV	{"email": "ivanov_ilya_1986@postgrespro.ru", "phone": "+70625337990"}
0005432329830	800A6E	5218 177078	IRINA STEPANOVA	{"phone": "+70780148945"}
0005432329831	8D131B	9311 278334	ELENA OVCHINNIKOVA	{"phone": "+70486446536"}
0005432329832	8D131B	1752 736254	TATYANA KUZMINA	{"email": "t-kuzmina08031977@postgrespro.ru", "phone": "+70082187261"}
0005432329833	615DC9	9724 960569	ALINA MIRONOVA	{"email": "mironova.alina-1967@postgrespro.ru", "phone": "+70312084175"}
0005432329834	615DC9	4044 302337	ANZHELIKA STEPANOVA	{"email": "stepanova-anzhelika-1964@postgrespro.ru", "phone": "+70352218468"}
0005432329835	860BBA	2262 177435	SERGEY MARTYNOV	{"phone": "+70201492694"}
0005432329836	5AF231	1665 224355	IVAN ROMANOV	{"email": "romanovivan-1974@postgrespro.ru", "phone": "+70087524885"}
0005432329837	28E967	4473 991218	VIKTOR SERGEEV	{"phone": "+70279503669"}
0005432329838	6BB526	8018 952984	ALEKSEY DAVYDOV	{"phone": "+70040572004"}
0005432329839	6BB526	8447 053014	LYUDMILA ALEKSANDROVA	{"email": "aleksandroval_1976@postgrespro.ru", "phone": "+70033848874"}
0005432329840	6BB526	9684 586707	ILYA SEMENOV	{"email": "semenov_ilya051963@postgrespro.ru", "phone": "+70656573659"}
0005432329841	B2E152	4623 725653	EGOR ALEKSANDROV	{"phone": "+70881514922"}
0005432329842	D43861	2029 517355	EVGENIY NAUMOV	{"phone": "+70744125221"}
0005432329843	930B58	5015 499196	PAVEL FEDOROV	{"email": "fedorov.p.101969@postgrespro.ru", "phone": "+70978650034"}
0005432329844	436D54	1424 402298	LYUDMILA SOKOLOVA	{"email": "l-sokolova-13121960@postgrespro.ru", "phone": "+70395113227"}
0005432329845	436D54	4216 791290	DANILA NOVIKOV	{"phone": "+70280592210"}
0005432329846	B5DDFA	1617 299798	ALEKSANDRA NESTEROVA	{"email": "a.nesterova_081973@postgrespro.ru", "phone": "+70173625873"}
0005432329847	B5DDFA	3542 839038	MIKHAIL ALEKSANDROV	{"phone": "+70167109542"}
0005432329848	D1C5D3	7253 872745	MARINA SIDOROVA	{"email": "sidorovamarina1981@postgrespro.ru", "phone": "+70515171084"}
0005432329849	FB9473	2380 512420	OLEG PETROV	{"email": "petrov_oleg.03021973@postgrespro.ru", "phone": "+70670436341"}
0005432329850	FB9473	1029 089557	NIKOLAY GRIGOREV	{"email": "grigorevnikolay1970@postgrespro.ru", "phone": "+70413921214"}
0005432329851	EB9CEE	3468 799980	MIKHAIL KRASNOV	{"email": "m-krasnov1975@postgrespro.ru", "phone": "+70561261300"}
0005432329852	C883FC	0631 483432	VALENTINA STEPANOVA	{"phone": "+70381452420"}
0005432329853	C883FC	4287 317758	DMITRIY BELOV	{"email": "d.belov.1968@postgrespro.ru", "phone": "+70635578166"}
0005432329854	3AD249	5896 775754	ANTON KISELEV	{"email": "kiselev_anton-14091969@postgrespro.ru", "phone": "+70638313893"}
0005432329855	3AD249	2921 469254	SEMEN FEDOROV	{"email": "s-fedorov_091970@postgrespro.ru", "phone": "+70691396208"}
0005432329856	49C954	8516 837017	LYUDMILA VOLKOVA	{"email": "volkova.lyudmila-17071977@postgrespro.ru", "phone": "+70824497304"}
0005432329857	58BAAA	7233 664716	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov051981@postgrespro.ru", "phone": "+70376116304"}
0005432329858	BDE664	7395 247411	EVGENIY POPOV	{"phone": "+70423839746"}
0005432329859	BDE664	3388 978163	VALERIY ANTONOV	{"email": "antonovvaleriy1971@postgrespro.ru", "phone": "+70391394993"}
0005432329860	DCCEDD	7378 917053	IGOR BORISOV	{"phone": "+70940811363"}
0005432329861	A11AC5	6482 546720	VALERIY MIKHAYLOV	{"email": "vmikhaylov-091970@postgrespro.ru", "phone": "+70677318127"}
0005432329862	6B84D7	9230 110201	SHAMIL IVANOV	{"email": "ivanov_shamil-1970@postgrespro.ru", "phone": "+70026887047"}
0005432329863	6B84D7	4849 884164	KSENIYA KAZAKOVA	{"email": "kazakova-kseniya.1972@postgrespro.ru", "phone": "+70942897859"}
0005432329864	CA2BE6	3581 779389	ALEKSANDR SMIRNOV	{"email": "smirnov-a_23111974@postgrespro.ru", "phone": "+70859736014"}
0005432329865	AE9937	7520 307283	TATYANA VASILEVA	{"email": "vasilevat-031958@postgrespro.ru", "phone": "+70764670388"}
0005432329866	E9F3DC	4928 855195	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr.1973@postgrespro.ru", "phone": "+70772826792"}
0005432329867	E9F3DC	7685 288019	TATYANA FILIPPOVA	{"email": "tatyana.filippova.1961@postgrespro.ru", "phone": "+70927361717"}
0005432329868	3FDFA3	6567 430372	OLGA SEMENOVA	{"phone": "+70363351256"}
0005432329869	3FDFA3	2612 298477	ANNA MELNIKOVA	{"phone": "+70836269217"}
0005432329870	7C3371	4147 910559	EKATERINA YAKOVLEVA	{"phone": "+70638702001"}
0005432329871	DAE60E	2167 590846	IRINA MAKAROVA	{"email": "makarova-irina-16051967@postgrespro.ru", "phone": "+70930138438"}
0005432329872	5840CF	3860 006099	GALINA GRISHINA	{"phone": "+70653442358"}
0005432329873	0DAC09	5363 476520	SERGEY PETROV	{"email": "petrov-s-101978@postgrespro.ru", "phone": "+70599407286"}
0005432329874	0DAC09	7700 402304	NATALYA NAUMOVA	{"email": "naumova_n.111971@postgrespro.ru", "phone": "+70248447463"}
0005432329875	0DAC09	4040 425296	SVETLANA DMITRIEVA	{"email": "sdmitrieva111977@postgrespro.ru", "phone": "+70883053046"}
0005432329876	8EB754	7622 676296	GENNADIY POPOV	{"email": "popov_g-031976@postgrespro.ru", "phone": "+70904559353"}
0005432329877	8EB754	9460 262862	MARINA MIKHAYLOVA	{"email": "marina-mikhaylova_071977@postgrespro.ru", "phone": "+70852275327"}
0005432329878	8EB754	7049 086748	LYUBOV RODIONOVA	{"phone": "+70322622548"}
0005432329879	9CEB7A	0586 864888	NIKITA ZHURAVLEV	{"email": "nzhuravlev1976@postgrespro.ru", "phone": "+70465448167"}
0005432329880	5BDFCB	6117 221810	ANATOLIY ROMANOV	{"email": "a_romanov_031969@postgrespro.ru", "phone": "+70819902184"}
0005432329881	941FB8	8833 172543	VASILIY FILIPPOV	{"email": "filippov_v-071975@postgrespro.ru", "phone": "+70117455870"}
0005432329882	71F7F4	0236 078731	SERGEY TIMOFEEV	{"email": "sergeytimofeev071977@postgrespro.ru", "phone": "+70466638680"}
0005432329883	71F7F4	2091 491857	SERGEY FILIPPOV	{"email": "s_filippov.1971@postgrespro.ru", "phone": "+70156224924"}
0005432329884	FA82E5	1024 643233	RAISA KOLESNIKOVA	{"email": "raisakolesnikova1978@postgrespro.ru", "phone": "+70215685297"}
0005432329885	902BA8	6920 470201	IVAN KARPOV	{"phone": "+70265788614"}
0005432329886	76D169	7073 061132	EVGENIY SOROKIN	{"phone": "+70898705428"}
0005432329887	49B28D	0124 192405	SERGEY SEMENOV	{"phone": "+70438951622"}
0005432329888	4EB0C0	8474 839893	VERA KONOVALOVA	{"email": "konovalovavera.1983@postgrespro.ru", "phone": "+70769879789"}
0005432329889	58B56A	8287 752035	GENNADIY KUDRYASHOV	{"email": "kudryashovgennadiy_071966@postgrespro.ru", "phone": "+70989455181"}
0005432329890	58B56A	2924 454854	EVDOKIYA ILINA	{"email": "ilina_e-011983@postgrespro.ru", "phone": "+70279120963"}
0005432329891	A979A3	5386 773227	EGOR IVANOV	{"email": "egorivanov-1974@postgrespro.ru", "phone": "+70288856687"}
0005432329892	A979A3	9735 501043	ELENA GRISHINA	{"email": "e_grishina-071979@postgrespro.ru", "phone": "+70218614368"}
0005432329893	A979A3	3083 661485	OLGA GORBUNOVA	{"phone": "+70121384606"}
0005432329894	C1EF93	6783 540452	TAMARA KOZLOVA	{"email": "kozlova.tamara.1984@postgrespro.ru", "phone": "+70384789728"}
0005432329895	F2DF35	1275 714924	ALEKSEY ABRAMOV	{"phone": "+70298429131"}
0005432329896	C0AABB	8233 341845	ANNA DENISOVA	{"phone": "+70556932146"}
0005432329897	03028D	9526 187211	ALEKSANDR SERGEEV	{"phone": "+70121957514"}
0005432329898	7DBE44	1849 812789	EVGENIYA OSIPOVA	{"email": "osipovaevgeniya-10051974@postgrespro.ru", "phone": "+70843167449"}
0005432329899	EEDAF0	3346 337483	VADIM KULIKOV	{"phone": "+70724321588"}
0005432329900	F6ABE2	8315 947210	SERGEY STEPANOV	{"email": "stepanov_sergey1972@postgrespro.ru", "phone": "+70947672218"}
0005432329901	24F757	0839 649849	GALINA POTAPOVA	{"phone": "+70009227833"}
0005432329902	24F757	1762 541878	VALENTINA KUZMINA	{"email": "kuzmina-v.1971@postgrespro.ru", "phone": "+70916275917"}
0005432329903	24F757	1445 880570	NINA ILINA	{"email": "ilina-n-20121957@postgrespro.ru", "phone": "+70833276028"}
0005432329904	1AEC3D	6207 346313	YANA KOZLOVA	{"email": "kozlova.yana-1977@postgrespro.ru", "phone": "+70865736759"}
0005432329905	BF2989	0953 601363	SERGEY VASILEV	{"phone": "+70717575498"}
0005432329906	A741FF	6527 267232	VLADISLAV SOLOVEV	{"phone": "+70946445895"}
0005432329907	E5A37E	2533 147134	RIMMA OSIPOVA	{"email": "osipova-rimma.1975@postgrespro.ru", "phone": "+70133464806"}
0005432329908	E5A37E	5505 372183	ANTONINA KAZAKOVA	{"phone": "+70826566929"}
0005432329909	37E541	7157 535117	OKSANA SOROKINA	{"email": "sorokinaoksana_1975@postgrespro.ru", "phone": "+70216851040"}
0005432329910	B5D77E	6145 099152	TATYANA SEMENOVA	{"email": "t-semenova-1976@postgrespro.ru", "phone": "+70891004826"}
0005432329911	B5D77E	1133 704559	BORIS KUZNECOV	{"email": "boriskuznecov_031976@postgrespro.ru", "phone": "+70038468918"}
0005432329912	C14A97	7047 889612	ALEKSEY SMIRNOV	{"phone": "+70960271532"}
0005432329913	F95CCD	9675 938868	BORIS MAKAROV	{"phone": "+70015995300"}
0005432329914	A3F24C	8695 828198	VALENTINA ALEKSEEVA	{"email": "alekseeva-v_121978@postgrespro.ru", "phone": "+70863875203"}
0005432329915	6EF5B0	6430 920599	ALEKSEY ALEKSEEV	{"email": "a_alekseev_021974@postgrespro.ru", "phone": "+70055412567"}
0005432329916	2B3C8A	9078 839434	NATALIYA EFIMOVA	{"email": "efimova-nataliya031975@postgrespro.ru", "phone": "+70840277707"}
0005432329917	2B3C8A	0674 179585	MIKHAIL ZAYCEV	{"phone": "+70535074062"}
0005432329918	582A7A	5201 478417	LILIYA GERASIMOVA	{"phone": "+70016697763"}
0005432329919	582A7A	7018 369394	VIKTOR ISAEV	{"phone": "+70811065901"}
0005432329920	CD3B25	1974 746153	TATYANA ROMANOVA	{"email": "romanova-t-1981@postgrespro.ru", "phone": "+70674913694"}
0005432329921	FA153A	7643 845897	ELENA MAKSIMOVA	{"email": "maksimova_elena-1974@postgrespro.ru", "phone": "+70995138279"}
0005432329922	FA153A	0638 711579	ALEKSANDR KULIKOV	{"email": "a.kulikov_16081981@postgrespro.ru", "phone": "+70041477888"}
0005432329923	72E3C1	9251 647886	OLESYA EFIMOVA	{"email": "efimova-o.061980@postgrespro.ru", "phone": "+70628780895"}
0005432329924	72E3C1	9685 283057	ANDREY ZAKHAROV	{"email": "andrey_zakharov-1966@postgrespro.ru", "phone": "+70216231894"}
0005432329925	72E3C1	1234 738767	MIKHAIL GAVRILOV	{"phone": "+70810767443"}
0005432329926	A3FC1B	8021 664676	VALERIY KUZNECOV	{"email": "v-kuznecov1977@postgrespro.ru", "phone": "+70764031263"}
0005432329927	A3FC1B	8714 166692	EVGENIY ANTONOV	{"email": "evgeniy.antonov_1967@postgrespro.ru", "phone": "+70922643306"}
0005432329928	65A02E	4950 485192	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov_121972@postgrespro.ru", "phone": "+70609797560"}
0005432329929	7BC94E	2973 409292	PRASKOVYA KOVALEVA	{"phone": "+70339077708"}
0005432329930	E35DFD	4344 638824	SERGEY MIRONOV	{"phone": "+70703995904"}
0005432329931	E35DFD	3774 494334	NATALYA FROLOVA	{"phone": "+70968882501"}
0005432329932	52CB57	0538 945340	ALEKSANDR SHEVCHENKO	{"email": "aleksandr-shevchenko-19061973@postgrespro.ru", "phone": "+70643128906"}
0005432329933	3B6B76	0196 508179	VLADIMIR KOZLOV	{"email": "vladimirkozlov.27121975@postgrespro.ru", "phone": "+70130536649"}
0005432329934	3B6B76	3313 274113	LYUDMILA TITOVA	{"phone": "+70222167909"}
0005432329935	3B6B76	0611 542477	LEV KULIKOV	{"email": "kulikov_l-1982@postgrespro.ru", "phone": "+70767776355"}
0005432329936	BB989B	1499 551146	YURIY KUZNECOV	{"email": "y-kuznecov13041980@postgrespro.ru", "phone": "+70334847796"}
0005432329937	82AD05	5357 134841	EVGENIYA IVANOVA	{"email": "ivanova-evgeniya.1970@postgrespro.ru", "phone": "+70222465918"}
0005432329938	82AD05	7854 381154	NATALYA GERASIMOVA	{"email": "natalya-gerasimova061982@postgrespro.ru", "phone": "+70231455050"}
0005432329939	82AD05	7743 172253	VASILIY ZAYCEV	{"phone": "+70634854487"}
0005432329940	DF9DDA	5092 923554	NINA NIKITINA	{"phone": "+70625131283"}
0005432329941	0C5C36	3411 576363	MARIYA BELOVA	{"phone": "+70161969223"}
0005432329942	2FEB40	1430 312597	ANASTASIYA SERGEEVA	{"phone": "+70530340922"}
0005432329943	DA4C7D	4290 660543	TATYANA POPOVA	{"email": "tatyana.popova.021971@postgrespro.ru", "phone": "+70155609839"}
0005432329944	81D83E	3604 941224	ANNA IVANOVA	{"phone": "+70932706133"}
0005432329945	81D83E	8634 156346	ALEKSANDR KUZNECOV	{"email": "kuznecov-a_1979@postgrespro.ru", "phone": "+70243849960"}
0005432329946	EBCCA2	2399 917203	ALEKSEY VOLKOV	{"phone": "+70959958897"}
0005432329947	96B721	4567 139391	ROMAN MAKSIMOV	{"email": "maksimov_roman_1980@postgrespro.ru", "phone": "+70348809571"}
0005432329948	96B721	1262 022035	ELENA ZAYCEVA	{"email": "zaycevaelena.1968@postgrespro.ru", "phone": "+70465750186"}
0005432329949	3F4700	6600 920726	YANA VOLKOVA	{"phone": "+70464460139"}
0005432329950	A537E3	2156 622980	DMITRIY NOVIKOV	{"phone": "+70503349579"}
0005432329951	4B8B78	0786 429889	ALEKSANDR RODIONOV	{"phone": "+70127697736"}
0005432329952	D084A5	5220 790707	ARTEM NIKITIN	{"email": "nikitin-artem-07071968@postgrespro.ru", "phone": "+70208989453"}
0005432329953	6A0898	2996 068844	EVGENIY DAVYDOV	{"phone": "+70963679129"}
0005432329954	8F363C	2540 343563	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko031974@postgrespro.ru", "phone": "+70583889191"}
0005432329955	8F363C	1579 233229	OLGA CHERNOVA	{"phone": "+70351554673"}
0005432329956	8FC56B	4131 491008	OLGA ZHUKOVA	{"phone": "+70569068951"}
0005432329957	8FC56B	9677 379505	NATALYA KAZAKOVA	{"phone": "+70856390563"}
0005432329958	47074A	9889 963881	NATALYA SMIRNOVA	{"phone": "+70259475525"}
0005432329959	47074A	0958 065534	NINA SOKOLOVA	{"phone": "+70228644867"}
0005432329960	89C1C7	5225 833430	MARIYA LUKYANOVA	{"phone": "+70815577048"}
0005432329961	EA0F38	7882 012393	ELENA ZAKHAROVA	{"phone": "+70021382954"}
0005432329962	EA0F38	5139 840377	MARIYA MIKHAYLOVA	{"phone": "+70748259234"}
0005432329963	EA0F38	6248 787770	ANTON VASILEV	{"email": "vasilev-a-1959@postgrespro.ru", "phone": "+70730242090"}
0005432329964	048D59	6296 112626	EVGENIY PETROV	{"phone": "+70281754788"}
0005432329965	048D59	5108 586990	YURIY FOMIN	{"phone": "+70680830457"}
0005432329966	40746B	7398 873952	TATYANA POTAPOVA	{"email": "t.potapova19021970@postgrespro.ru", "phone": "+70554881396"}
0005432329967	40746B	3431 436410	MARIYA PAVLOVA	{"email": "pavlova-m081978@postgrespro.ru", "phone": "+70251904041"}
0005432329968	5A8876	3673 908237	ELENA MIRONOVA	{"email": "elena_mironova011981@postgrespro.ru", "phone": "+70776360499"}
0005432329969	5A8876	9834 143428	AMIR EGOROV	{"email": "amir.egorov091974@postgrespro.ru", "phone": "+70802705123"}
0005432329970	E31B7A	6358 033759	DARYA IVANOVA	{"email": "ivanovadarya-06071976@postgrespro.ru", "phone": "+70660251871"}
0005432329971	E31B7A	1325 876671	VIKTORIYA PAVLOVA	{"email": "viktoriya.pavlova10051970@postgrespro.ru", "phone": "+70890045528"}
0005432329972	F714B8	7268 792582	KLAVDIYA BORISOVA	{"phone": "+70157950681"}
0005432329973	E470D9	1317 431909	YULIYA VLASOVA	{"phone": "+70336444160"}
0005432329974	A4862E	4595 989328	KHALIDA IVANOVA	{"phone": "+70937188141"}
0005432329975	A4862E	0954 427042	DMITRIY KRASNOV	{"email": "krasnov_dmitriy_1978@postgrespro.ru", "phone": "+70593414109"}
0005432329976	EF1155	7280 824034	ALEKSANDR ANDREEV	{"phone": "+70851493836"}
0005432329977	EF1155	8109 523913	LILIYA LAZAREVA	{"email": "lazarevaliliya21041972@postgrespro.ru", "phone": "+70229245293"}
0005432329978	DDFC91	4331 012207	ALEKSANDR SERGEEV	{"email": "a_sergeev21051973@postgrespro.ru", "phone": "+70286215186"}
0005432329979	DDFC91	3809 985298	SERGEY BELOV	{"phone": "+70170998857"}
0005432329980	B791EF	8262 721575	OLGA VLASOVA	{"phone": "+70176620733"}
0005432329981	B791EF	8845 570244	OLGA KOMAROVA	{"phone": "+70859790589"}
0005432329982	ED98AA	3529 039589	LYUDMILA SCHERBAKOVA	{"phone": "+70657312988"}
0005432329983	ED98AA	3580 122701	NINA IVANOVA	{"phone": "+70121200064"}
0005432329984	EBDF88	6004 198960	NATALIYA KONDRATEVA	{"phone": "+70820233372"}
0005432329985	EBDF88	7817 867075	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr_101971@postgrespro.ru", "phone": "+70926052395"}
0005432329986	53514A	7811 899849	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana_1967@postgrespro.ru", "phone": "+70641128227"}
0005432329987	53514A	0542 962382	ANASTASIYA ILINA	{"email": "ilina-anastasiya01071962@postgrespro.ru", "phone": "+70183258718"}
0005432329988	17759F	7453 312110	GENNADIY FROLOV	{"phone": "+70538674816"}
0005432329989	17759F	2266 527190	IVAN ZAKHAROV	{"email": "zakharov.i23101974@postgrespro.ru", "phone": "+70077910170"}
0005432329990	50C52B	8037 543781	ALEKSANDRA ZAYCEVA	{"phone": "+70911497051"}
0005432329991	50C52B	6102 625256	MIKHAIL KRASNOV	{"email": "m.krasnov.1958@postgrespro.ru", "phone": "+70109304824"}
0005432329992	50C52B	5614 121643	DAMIR IVANOV	{"phone": "+70909406526"}
0005432329993	74FBBD	8658 026812	TATYANA CHERNOVA	{"phone": "+70036181496"}
0005432329994	74FBBD	5786 089495	NINA OSIPOVA	{"phone": "+70876935789"}
0005432329995	74FBBD	7533 567412	LYUDMILA ALEKSEEVA	{"phone": "+70537655698"}
0005432329996	975788	1792 314207	LIDIYA KOMAROVA	{"phone": "+70173751696"}
0005432329997	975788	2302 744197	VLADISLAV ALEKSEEV	{"phone": "+70160487147"}
0005432329998	975788	6927 550618	ALENA POPOVA	{"phone": "+70796834200"}
0005432329999	6FC968	9445 583939	TATYANA CHERNOVA	{"email": "tatyana_chernova.021969@postgrespro.ru", "phone": "+70401448052"}
0005432330000	2445C6	2775 089662	VYACHESLAV POPOV	{"email": "popov-v.24011968@postgrespro.ru", "phone": "+70900357233"}
0005432330001	2445C6	8189 202298	VIKTOR SMIRNOV	{"email": "smirnov_v1971@postgrespro.ru", "phone": "+70259184489"}
0005432330002	E0F629	2157 869345	EVGENIY MATVEEV	{"phone": "+70594280090"}
0005432330003	E0F629	6808 530498	ALEKSANDRA IVANOVA	{"email": "aleksandraivanova-14101976@postgrespro.ru", "phone": "+70843871286"}
0005432330004	1B466F	1427 690992	LYUBOV ALEKSANDROVA	{"phone": "+70011276190"}
0005432330005	1B466F	2262 003188	ANNA TIMOFEEVA	{"email": "timofeeva-anna.1967@postgrespro.ru", "phone": "+70599387353"}
0005432330006	1B466F	1303 264526	NIKOLAY KUDRYASHOV	{"email": "n.kudryashov091967@postgrespro.ru", "phone": "+70126657670"}
0005432330007	482626	3113 865633	EMMA DMITRIEVA	{"phone": "+70272156378"}
0005432330008	54AEDC	3108 594279	OLGA NIKITINA	{"email": "olganikitina_1979@postgrespro.ru", "phone": "+70730057411"}
0005432330009	812DA4	5544 758001	IGOR ORLOV	{"phone": "+70691138713"}
0005432330010	E4720E	8700 930668	MIKHAIL MARTYNOV	{"phone": "+70257692779"}
0005432330011	1F64DC	9992 795246	ANNA SIDOROVA	{"phone": "+70818618278"}
0005432330012	2DD036	8146 112295	IGOR SCHERBAKOV	{"email": "igorscherbakov_21041970@postgrespro.ru", "phone": "+70988725158"}
0005432330013	51BF81	5256 722414	VLADISLAV IVANOV	{"email": "ivanovv.03091966@postgrespro.ru", "phone": "+70162735225"}
0005432330014	51BF81	8914 031748	VERA VOLKOVA	{"phone": "+70131178094"}
0005432330015	4E0907	6143 621777	DENIS SOROKIN	{"email": "sorokin_denis-031966@postgrespro.ru", "phone": "+70699229721"}
0005432330016	4E0907	2477 447358	MARINA ILINA	{"email": "ilina-m121971@postgrespro.ru", "phone": "+70185895561"}
0005432330017	2D289A	9915 542775	VALERIY MIRONOV	{"email": "mironov-valeriy.30101974@postgrespro.ru", "phone": "+70449892250"}
0005432330018	2D289A	1534 199063	ALEKSEY MOROZOV	{"phone": "+70309370026"}
0005432330019	34DF6F	6067 225438	ALENA ZHURAVLEVA	{"phone": "+70856737291"}
0005432330020	34DF6F	2894 949334	ILYA IVANOV	{"email": "ivanovi09041969@postgrespro.ru", "phone": "+70579121605"}
0005432330021	A443EF	7708 563178	VALENTINA KAZAKOVA	{"email": "v.kazakova021957@postgrespro.ru", "phone": "+70386247458"}
0005432330022	D4ADB9	7552 458905	OLGA SEMENOVA	{"phone": "+70301481808"}
0005432330023	4C8416	8214 570352	YULIYA EFIMOVA	{"phone": "+70155653274"}
0005432330024	4C8416	9531 572784	GENNADIY TIKHONOV	{"phone": "+70926730297"}
0005432330025	DF5090	4410 033378	LYUDMILA ORLOVA	{"phone": "+70278594206"}
0005432330026	BC9E64	4138 519262	SERGEY VASILEV	{"email": "vasilev.s-14041980@postgrespro.ru", "phone": "+70690434458"}
0005432330027	A62143	8052 575458	DENIS DAVYDOV	{"email": "davydovdenis-04111973@postgrespro.ru", "phone": "+70104101990"}
0005432330028	A62143	9765 486410	ILYA BELOV	{"phone": "+70876041038"}
0005432330029	E557D1	0947 402147	DMITRIY IVANOV	{"phone": "+70990039591"}
0005432330030	1D483C	3283 389011	EVGENIY FOMIN	{"phone": "+70444108354"}
0005432330031	B6F729	5772 511304	EVGENIY ORLOV	{"phone": "+70545217871"}
0005432330032	B6F729	9823 680535	VLADIMIR IVANOV	{"phone": "+70587506252"}
0005432330033	9F9B39	2854 033849	ALEKSEY MAKAROV	{"phone": "+70701452623"}
0005432330034	1A8386	1887 420443	ALEKSANDR BORISOV	{"phone": "+70845276978"}
0005432330035	F2ECB3	9483 345412	OKSANA LAZAREVA	{"phone": "+70368324805"}
0005432330036	29192A	9811 023894	DMITRIY ZAKHAROV	{"phone": "+70733245284"}
0005432330037	508D3D	5704 335734	ALEKSANDRA LOGINOVA	{"email": "a.loginova.09041976@postgrespro.ru", "phone": "+70141111018"}
0005432330038	F7B707	8395 444325	VALERIYA BORISOVA	{"phone": "+70582176551"}
0005432330039	F7B707	2685 999679	IRINA MOISEEVA	{"phone": "+70511719292"}
0005432330040	67CF23	4707 052995	SERGEY CHERNOV	{"phone": "+70084910896"}
0005432330041	7E5264	5554 384298	VLADIMIR FILIPPOV	{"phone": "+70543538159"}
0005432330042	7E5264	8881 456098	EVGENIY VOLKOV	{"email": "volkov_e_1968@postgrespro.ru", "phone": "+70180729181"}
0005432330043	D9D7DC	2354 467542	ELIZAVETA KOMAROVA	{"phone": "+70628782525"}
0005432330044	2BEED3	4563 784391	KLAVDIYA KULIKOVA	{"phone": "+70805209123"}
0005432330045	2BEED3	1408 228646	RAISA MAKSIMOVA	{"phone": "+70268444419"}
0005432330046	2BEED3	8484 180465	VERONIKA ZAKHAROVA	{"email": "veronikazakharova.26061970@postgrespro.ru", "phone": "+70050897246"}
0005432330047	B91FD9	0316 581640	VLADISLAV ZAKHAROV	{"email": "zakharov-vladislav.1972@postgrespro.ru", "phone": "+70145644041"}
0005432330048	568139	0138 124038	ARTUR ZAKHAROV	{"phone": "+70639188110"}
0005432330049	568139	3576 251623	EKATERINA NESTEROVA	{"phone": "+70414136937"}
0005432330050	8320AB	0201 896099	VALENTINA GRISHINA	{"phone": "+70868143404"}
0005432330051	E8D43A	1125 746707	RAVIL SAVELEV	{"email": "rsavelev.10071978@postgrespro.ru", "phone": "+70736763749"}
0005432330052	41231D	6406 060723	ANASTASIYA KOROLEVA	{"phone": "+70923287646"}
0005432330053	ADE334	6469 026037	TATYANA POPOVA	{"email": "popova_t_10041962@postgrespro.ru", "phone": "+70341343280"}
0005432330054	D38D6C	0978 477964	ALEKSEY MATVEEV	{"email": "matveev-aleksey-011975@postgrespro.ru", "phone": "+70140836776"}
0005432330055	D38D6C	9716 033296	IRINA ZAKHAROVA	{"phone": "+70380053433"}
0005432330056	9A76B6	4957 265950	LYUDMILA ANDREEVA	{"phone": "+70092939205"}
0005432330057	54DE07	6019 939333	VYACHESLAV ZAYCEV	{"phone": "+70488282179"}
0005432330058	468E3E	8313 865325	OLEG EGOROV	{"email": "egorov-o-04011973@postgrespro.ru", "phone": "+70833078269"}
0005432330059	0CB28B	2614 932670	ALEKSANDR POPOV	{"phone": "+70015198674"}
0005432330060	DCC9ED	7653 653382	ANATOLIY KAZAKOV	{"phone": "+70828844350"}
0005432330061	DCC9ED	0758 730061	ANATOLIY KAZAKOV	{"phone": "+70056529399"}
0005432330062	C58734	6350 984387	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr_1979@postgrespro.ru", "phone": "+70729304060"}
0005432330063	661AC1	0760 787182	ANASTASIYA SOROKINA	{"email": "sorokina_a.1959@postgrespro.ru", "phone": "+70259598981"}
0005432335820	1CE10F	0419 066580	SERGEY STEPANOV	{"email": "stepanov-sergey091962@postgrespro.ru", "phone": "+70140959787"}
0005432335821	1CE10F	6596 273683	LARISA ZOTOVA	{"email": "zotoval.1984@postgrespro.ru", "phone": "+70090833766"}
0005432335822	11BA82	4381 592727	LEONID TIKHONOV	{"phone": "+70552295066"}
0005432335823	655C7B	6816 974581	ALEKSANDRA KOVALEVA	{"phone": "+70470755171"}
0005432335824	507930	9734 228410	NADEZHDA SAVELEVA	{"email": "n-saveleva_041962@postgrespro.ru", "phone": "+70970176987"}
0005432335825	6BEEE7	0728 112129	KAMIL EGOROV	{"email": "egorov_kamil_081974@postgrespro.ru", "phone": "+70981870659"}
0005432335826	6BEEE7	0429 933688	SOFIYA NIKOLAEVA	{"phone": "+70040347598"}
0005432335827	6BEEE7	2232 005268	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a1973@postgrespro.ru", "phone": "+70066716950"}
0005432335828	3AD399	3955 484358	ALEKSANDR KAZAKOV	{"email": "kazakov-a.29031979@postgrespro.ru", "phone": "+70559942414"}
0005432335829	7C49B3	8113 582547	MARGARITA KUZMINA	{"email": "kuzmina_margarita_1968@postgrespro.ru", "phone": "+70032033946"}
0005432335830	ECBD94	7235 542533	BOGDAN VOROBEV	{"phone": "+70614310987"}
0005432335831	ECBD94	6235 692168	YULIYA PETROVA	{"email": "petrova-yuliya.09091977@postgrespro.ru", "phone": "+70534758996"}
0005432335832	649745	7236 369451	YULIYA NIKIFOROVA	{"email": "nikiforova.y_091973@postgrespro.ru", "phone": "+70740624396"}
0005432335833	55B690	1035 667961	DMITRIY ANTONOV	{"email": "dmitriy_antonov_15091973@postgrespro.ru", "phone": "+70082475565"}
0005432335834	C68E6F	3390 228994	GALINA IVANOVA	{"email": "ivanova_g.22091963@postgrespro.ru", "phone": "+70133351257"}
0005432335835	C68E6F	4502 956431	NATALYA BARANOVA	{"email": "nbaranova_1972@postgrespro.ru", "phone": "+70858949770"}
0005432335836	C68E6F	2789 468743	NATALYA KUZNECOVA	{"email": "kuznecova_n-20091964@postgrespro.ru", "phone": "+70129061876"}
0005432335837	04D136	4683 886465	ELENA CHERNOVA	{"phone": "+70437522120"}
0005432335838	04D136	5307 949561	MIKHAIL NIKOLAEV	{"phone": "+70005937726"}
0005432335839	6551E5	3669 643223	LYUDMILA SEMENOVA	{"email": "l.semenova.1972@postgrespro.ru", "phone": "+70984654659"}
0005432335840	190D62	2156 007244	VALERIYA VOLKOVA	{"email": "volkovav31051975@postgrespro.ru", "phone": "+70257900585"}
0005432335841	55B20C	3568 936064	VLADIMIR VOLKOV	{"email": "volkov-v.15081966@postgrespro.ru", "phone": "+70011463615"}
0005432335842	161EDA	6526 615307	MAKSIM MAKAROV	{"email": "maksimmakarov.1986@postgrespro.ru", "phone": "+70396057531"}
0005432335843	161EDA	0933 753363	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay_011981@postgrespro.ru", "phone": "+70396858031"}
0005432335844	FE5B35	4603 794377	MARINA PAVLOVA	{"phone": "+70147319203"}
0005432335845	F89966	6039 412487	VITALIY DENISOV	{"email": "v_denisov-18011969@postgrespro.ru", "phone": "+70723503584"}
0005432335846	F89966	8636 361893	ALEKSEY MIRONOV	{"email": "aleksey-mironov021978@postgrespro.ru", "phone": "+70084266415"}
0005432335847	13D5B4	8265 581199	DMITRIY CHERNOV	{"phone": "+70973396800"}
0005432335848	13D5B4	7902 672767	ANDREY KOZLOV	{"email": "kozlov.andrey1973@postgrespro.ru", "phone": "+70128905994"}
0005432335849	96B276	1656 459818	PAVEL POPOV	{"email": "pavel.popov1980@postgrespro.ru", "phone": "+70911170283"}
0005432335850	05EE39	7683 717043	YULIYA VASILEVA	{"email": "yuliyavasileva.06051964@postgrespro.ru", "phone": "+70925035483"}
0005432335851	7C06E9	5841 702314	NIKOLAY MELNIKOV	{"phone": "+70535891257"}
0005432335852	90A462	1306 654580	YULIYA NIKOLAEVA	{"email": "y-nikolaeva-1971@postgrespro.ru", "phone": "+70501969112"}
0005432335853	D55612	7358 679340	EVGENIYA DENISOVA	{"email": "e.denisova-05101961@postgrespro.ru", "phone": "+70052376846"}
0005432335854	CDE3A4	1906 250310	ANGELINA BELOVA	{"phone": "+70672054538"}
0005432335855	19E490	7762 685677	ARTUR MIKHAYLOV	{"email": "artur-mikhaylov-051971@postgrespro.ru", "phone": "+70132392099"}
0005432335856	48B264	4465 532313	VIKTOR DAVYDOV	{"email": "davydov-v.07071980@postgrespro.ru", "phone": "+70999865175"}
0005432335857	48B264	6801 100092	SERGEY IVANOV	{"phone": "+70806049138"}
0005432335858	D020CC	3755 923638	ALEKSEY ABRAMOV	{"email": "abramov-aleksey-111976@postgrespro.ru", "phone": "+70951377623"}
0005432335859	D020CC	5682 235251	VIKTORIYA KUZMINA	{"phone": "+70674453919"}
0005432335860	E6A3AC	2148 038384	ARTEM SHEVCHENKO	{"email": "shevchenkoa1966@postgrespro.ru", "phone": "+70493444534"}
0005432335861	EED99E	6438 468514	YURIY EGOROV	{"email": "egorov-y-071964@postgrespro.ru", "phone": "+70297847650"}
0005432335862	61C8FD	1237 144525	EVGENIY BARANOV	{"phone": "+70077681192"}
0005432335863	0621E6	6995 507375	VENERA MOISEEVA	{"phone": "+70708836611"}
0005432335864	C6BE4E	4308 157886	YURIY SOROKIN	{"email": "sorokin.y-1973@postgrespro.ru", "phone": "+70789080312"}
0005432335865	10F041	2184 247532	IVAN MAKAROV	{"email": "makarov-ivan_111983@postgrespro.ru", "phone": "+70145346980"}
0005432335866	10F041	9928 553424	PAVEL BARANOV	{"phone": "+70120675292"}
0005432335867	EFB1F9	8390 814133	SERGEY BONDARENKO	{"email": "s.bondarenko_1972@postgrespro.ru", "phone": "+70921032365"}
0005432335868	EFB1F9	0887 240729	SOFYA OSIPOVA	{"phone": "+70627273458"}
0005432335869	CD6E16	5894 505724	VYACHESLAV KOZLOV	{"phone": "+70381005192"}
0005432335870	45DC78	8890 322942	NATALYA ALEKSANDROVA	{"email": "natalya_aleksandrova.28011976@postgrespro.ru", "phone": "+70979955829"}
0005432335871	5A1879	6896 199220	VITALIY KRASNOV	{"phone": "+70090047162"}
0005432335872	7D2D25	8492 756552	ANNA MASLOVA	{"email": "maslova_anna_11031973@postgrespro.ru", "phone": "+70495896360"}
0005432335873	ED86A7	1895 841590	MARIYA SEMENOVA	{"email": "mariya.semenova-20031979@postgrespro.ru", "phone": "+70046371935"}
0005432335874	A1AFC9	5064 267081	VALENTINA POPOVA	{"email": "popova_valentina1966@postgrespro.ru", "phone": "+70412477684"}
0005432335875	DF9A41	4922 716993	SVETLANA SERGEEVA	{"phone": "+70858890886"}
0005432335876	BBA300	8046 855394	ANDREY SCHERBAKOV	{"phone": "+70939327312"}
0005432335877	BBA300	3841 842484	STEPAN YAKOVLEV	{"phone": "+70727066384"}
0005432335878	2B7643	8047 706962	OKSANA BELYAEVA	{"phone": "+70327277449"}
0005432335879	060056	0628 015697	MIKHAIL GERASIMOV	{"email": "m-gerasimov.031960@postgrespro.ru", "phone": "+70662500131"}
0005432335880	060056	4993 380313	ANZHELIKA ALEKSANDROVA	{"email": "aleksandrova-anzhelika091978@postgrespro.ru", "phone": "+70946312098"}
0005432335881	6703C9	4797 952671	YURIY GRIGOREV	{"phone": "+70881522578"}
0005432335882	C46762	4718 369608	KONSTANTIN GRIGOREV	{"phone": "+70162069585"}
0005432335883	4F3B21	3996 345697	VITALIY KUZMIN	{"phone": "+70758207689"}
0005432335884	53ABAE	7398 706492	VIKTOR MIKHAYLOV	{"email": "mikhaylov_v02011970@postgrespro.ru", "phone": "+70223855248"}
0005432335885	E0E7F4	5556 974856	IVAN VOROBEV	{"email": "i.vorobev-1967@postgrespro.ru", "phone": "+70091541865"}
0005432335886	60AD4C	3426 499651	ANASTASIYA KUZNECOVA	{"phone": "+70756448369"}
0005432335887	1AA8FE	9898 306772	ANATOLIY BONDARENKO	{"phone": "+70463445006"}
0005432335888	1AA8FE	0980 515069	VLADIMIR DAVYDOV	{"email": "vladimir-davydov.1975@postgrespro.ru", "phone": "+70300369707"}
0005432335889	1AA8FE	0090 190564	MIKHAIL NIKITIN	{"email": "mikhailnikitin_27031972@postgrespro.ru", "phone": "+70351274162"}
0005432335890	519EB4	1733 834176	LYUDMILA KUDRYASHOVA	{"phone": "+70738577221"}
0005432335891	519EB4	4480 662705	LYAYSAN SAVELEVA	{"phone": "+70661092238"}
0005432335892	CB35CA	8643 075371	RINAT GERASIMOV	{"email": "gerasimov-rinat041968@postgrespro.ru", "phone": "+70201842254"}
0005432335893	853761	7701 798958	TATYANA ANDREEVA	{"email": "tatyana_andreeva.1971@postgrespro.ru", "phone": "+70488160861"}
0005432335894	853761	4520 156548	OLEG DAVYDOV	{"email": "davydov_oleg_051976@postgrespro.ru", "phone": "+70852065540"}
0005432335895	219B75	8185 287880	LYUBOV BORISOVA	{"phone": "+70821832614"}
0005432335896	056545	8936 146616	ALEKSANDR NOVIKOV	{"email": "aleksandrnovikov-14031972@postgrespro.ru", "phone": "+70766697449"}
0005432335897	056545	4702 741338	ANGELINA BELOVA	{"email": "belova-angelina-29051973@postgrespro.ru", "phone": "+70716214850"}
0005432335898	E6DEAF	7974 567409	OLGA SERGEEVA	{"phone": "+70047127619"}
0005432335899	E6DEAF	8138 861690	PETR ANDREEV	{"phone": "+70323330559"}
0005432335900	6569AC	4953 210703	IVAN SOROKIN	{"phone": "+70355852527"}
0005432335901	6569AC	8483 823227	ANASTASIYA MEDVEDEVA	{"email": "medvedeva.a.31011973@postgrespro.ru", "phone": "+70011948444"}
0005432335902	8BFD9A	5051 796004	VADIM BARANOV	{"phone": "+70299159165"}
0005432335903	8BFD9A	4009 258523	TATYANA GRISHINA	{"phone": "+70967026996"}
0005432335904	8BFD9A	8665 631595	ANNA BELYAEVA	{"email": "abelyaeva.1971@postgrespro.ru", "phone": "+70886292311"}
0005432335905	250B76	3033 507571	ALEKSEY NAUMOV	{"email": "naumov_a_071982@postgrespro.ru", "phone": "+70027993466"}
0005432335906	250B76	7062 954426	SERGEY ALEKSANDROV	{"email": "sergeyaleksandrov1968@postgrespro.ru", "phone": "+70087390846"}
0005432335907	46B6C2	0022 374728	IRINA BARANOVA	{"email": "baranova_irina-04111966@postgrespro.ru", "phone": "+70076960187"}
0005432335908	AB7186	3664 033648	ANASTASIYA NOVIKOVA	{"phone": "+70324831321"}
0005432335909	6373EA	9902 259296	NATALYA ANTONOVA	{"phone": "+70197363033"}
0005432335910	D24E30	5441 979205	RAISA BORISOVA	{"phone": "+70309531886"}
0005432335911	D24E30	2568 937016	VIKTOR KOZLOV	{"email": "viktor-kozlov_1977@postgrespro.ru", "phone": "+70578256985"}
0005432335912	AE4665	8409 739446	LYUDMILA TARASOVA	{"phone": "+70637453821"}
0005432335913	81FF28	4041 006312	LEONID FEDOTOV	{"email": "leonid_fedotov_051974@postgrespro.ru", "phone": "+70063382673"}
0005432335914	D3661A	4312 908996	MARIYA NESTEROVA	{"email": "m-nesterova-091972@postgrespro.ru", "phone": "+70681491134"}
0005432335915	416A23	7574 760779	TAMARA KAZAKOVA	{"email": "kazakova-tamara-10041960@postgrespro.ru", "phone": "+70353446668"}
0005432335916	416A23	5141 114495	DMITRIY MIRONOV	{"phone": "+70683101750"}
0005432335917	1616A9	1672 379595	NIKOLAY VASILEV	{"email": "vasilev-nikolay.09021960@postgrespro.ru", "phone": "+70040496633"}
0005432335918	1616A9	9721 312158	TATYANA LAZAREVA	{"phone": "+70803965039"}
0005432335919	F26B22	1716 748118	VALENTINA TROFIMOVA	{"phone": "+70367785373"}
0005432335920	CA3995	4169 767276	DANIIL IVANOV	{"phone": "+70810402512"}
0005432335921	B988F9	5265 395162	ANNA MARTYNOVA	{"email": "martynova.anna22041973@postgrespro.ru", "phone": "+70545337599"}
0005432335922	B988F9	0030 864745	ALEKSANDR SIDOROV	{"phone": "+70077438120"}
0005432335923	8E305F	1658 798431	LILIYA NOVIKOVA	{"phone": "+70603275242"}
0005432335924	0970F5	8093 919235	MARINA TIKHONOVA	{"email": "marinatikhonova_05111974@postgrespro.ru", "phone": "+70721527855"}
0005432335925	98B716	4872 954225	EVGENIY BARANOV	{"email": "baranov-evgeniy_18081972@postgrespro.ru", "phone": "+70504284342"}
0005432335926	86562A	4763 902583	FILIPP ILIN	{"email": "filipp_ilin_101984@postgrespro.ru", "phone": "+70097431760"}
0005432335927	CB1BB0	0620 256186	MAKSIM FROLOV	{"phone": "+70768606501"}
0005432335928	CB1BB0	6318 424442	EKATERINA SERGEEVA	{"phone": "+70732363083"}
0005432335929	A838DB	2700 484016	IRINA VASILEVA	{"phone": "+70902075814"}
0005432335930	C8EC50	1920 752692	TATYANA KUZNECOVA	{"phone": "+70930572660"}
0005432335931	C69587	2930 644090	ANTONINA VASILEVA	{"email": "antonina-vasileva.1975@postgrespro.ru", "phone": "+70398463563"}
0005432335932	5AB904	7847 305844	VALERIY FEDOROV	{"phone": "+70227395762"}
0005432335933	5AB904	1264 617388	ALEKSANDR IVANOV	{"phone": "+70464756426"}
0005432335934	8533A2	3297 587750	OLEG RODIONOV	{"phone": "+70295715860"}
0005432335935	A6D679	6247 531995	DIANA GAVRILOVA	{"phone": "+70798660991"}
0005432335936	A6D679	4020 665190	OLGA KOZLOVA	{"phone": "+70979912723"}
0005432335937	A6D679	1115 702946	ALEVTINA DENISOVA	{"phone": "+70373598690"}
0005432335938	A13F85	8499 502082	RUSLAN IVANOV	{"phone": "+70177006599"}
0005432335939	A13F85	1012 041955	SVETLANA ROMANOVA	{"email": "svetlana-romanova-03121977@postgrespro.ru", "phone": "+70846923720"}
0005432335940	9D19C1	5712 851990	OLEG BELOV	{"email": "belov-oleg111966@postgrespro.ru", "phone": "+70879795330"}
0005432335941	9D19C1	5291 781931	GALINA MIRONOVA	{"email": "g-mironova-1965@postgrespro.ru", "phone": "+70817364527"}
0005432335942	25155C	1447 759736	SERGEY MAKSIMOV	{"phone": "+70604026793"}
0005432335943	F1595D	0010 280548	ALEKSANDRA KISELEVA	{"email": "akiseleva.11051966@postgrespro.ru", "phone": "+70793862654"}
0005432335944	F1595D	4061 636960	VASILIY IVANOV	{"phone": "+70016442553"}
0005432335945	CB9B3E	4182 699402	SERGEY IVANOV	{"email": "ivanov_s_21021971@postgrespro.ru", "phone": "+70556904596"}
0005432335946	344A78	9002 223790	EKATERINA FEDOROVA	{"email": "fedorova-ekaterina.08031961@postgrespro.ru", "phone": "+70232289277"}
0005432335947	344A78	1510 817034	VALERIYA ILINA	{"phone": "+70865364254"}
0005432335948	C85E42	2238 793047	ANASTASIYA BORISOVA	{"phone": "+70620001367"}
0005432335949	C85E42	8867 856306	VLADIMIR KONOVALOV	{"email": "vladimir.konovalov_1967@postgrespro.ru", "phone": "+70972988702"}
0005432335950	51C146	2256 056391	SERGEY KARPOV	{"phone": "+70954641773"}
0005432335951	344B0A	7568 767469	YULIYA TROFIMOVA	{"phone": "+70511180706"}
0005432335952	7B79B2	2619 509609	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov_051973@postgrespro.ru", "phone": "+70250199079"}
0005432335953	7B79B2	6945 879133	OLEG KRASNOV	{"email": "krasnov_o1968@postgrespro.ru", "phone": "+70878195906"}
0005432335954	C0024B	8031 920964	GALINA KOZLOVA	{"phone": "+70658800793"}
0005432335955	1E32F0	9776 499715	TIMUR NOVIKOV	{"phone": "+70777115738"}
0005432335956	3AD06E	8914 301085	ALEKSANDR KONOVALOV	{"phone": "+70207940787"}
0005432335957	230E28	5549 144525	NIKOLAY SMIRNOV	{"email": "smirnov_n-031975@postgrespro.ru", "phone": "+70343085519"}
0005432335958	56D93E	0285 815473	ANASTASIYA YUDINA	{"email": "a-yudina11081971@postgrespro.ru", "phone": "+70552903047"}
0005432335959	6E31E8	5673 477638	VIKTOR YAKOVLEV	{"email": "yakovlev.v-111972@postgrespro.ru", "phone": "+70240777010"}
0005432335960	09EBBB	1776 382308	VYACHESLAV MIRONOV	{"phone": "+70883290261"}
0005432335961	093ABE	3623 625248	VALENTINA POTAPOVA	{"email": "v_potapova_18011975@postgrespro.ru", "phone": "+70541796015"}
0005432335962	1B0225	5972 365559	ELENA ORLOVA	{"email": "orlova-elena28081970@postgrespro.ru", "phone": "+70005091666"}
0005432335963	1B0225	6894 079072	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin-27121963@postgrespro.ru", "phone": "+70715295671"}
0005432335964	851D74	4984 407055	ANDREY IVANOV	{"email": "ivanov_a.101957@postgrespro.ru", "phone": "+70805893366"}
0005432335965	1A3052	3243 299961	NIKOLAY GAVRILOV	{"phone": "+70143638434"}
0005432335966	093B9C	0732 216810	SVETLANA MIRONOVA	{"email": "s_mironova031970@postgrespro.ru", "phone": "+70222258339"}
0005432335967	F7344D	5701 537018	EVGENIYA LOGINOVA	{"phone": "+70923518079"}
0005432335968	F7344D	0959 571830	ILYA TARASOV	{"email": "tarasov-ilya-21051976@postgrespro.ru", "phone": "+70083394294"}
0005432335969	C15A33	7634 082551	VALENTIN ROMANOV	{"email": "romanov-valentin_02071969@postgrespro.ru", "phone": "+70043984105"}
0005432335970	C15A33	0612 086877	VIKTOR VOLKOV	{"phone": "+70996056946"}
0005432335971	BBE6A1	5661 055610	IVAN SEMENOV	{"email": "semenov.i1966@postgrespro.ru", "phone": "+70139109832"}
0005432335972	BBE6A1	6568 415638	VERA KUDRYASHOVA	{"email": "vera.kudryashova-28111974@postgrespro.ru", "phone": "+70699077442"}
0005432335973	1C267C	4486 449469	ANTON DMITRIEV	{"email": "dmitriev_a29121978@postgrespro.ru", "phone": "+70427264204"}
0005432335974	1C267C	7636 998322	TATYANA PAVLOVA	{"phone": "+70346517071"}
0005432335975	1C267C	9636 166181	NIKOLAY MOROZOV	{"email": "n.morozov20011964@postgrespro.ru", "phone": "+70640421035"}
0005432335976	657B85	6307 727973	ANDREY ALEKSANDROV	{"phone": "+70523673219"}
0005432335977	EAF793	3286 588407	DENIS KARPOV	{"phone": "+70049126498"}
0005432335978	909E26	9979 733812	ALEKSANDR OSIPOV	{"email": "a-osipov-1993@postgrespro.ru", "phone": "+70803498095"}
0005432335979	485AB7	9481 341920	NATALYA BORISOVA	{"email": "natalya_borisova_071973@postgrespro.ru", "phone": "+70277725620"}
0005432335980	6D1A03	5627 198198	TIMOFEY ZAKHAROV	{"email": "timofey_zakharov-15111965@postgrespro.ru", "phone": "+70040445359"}
0005432335981	2316CA	0021 008620	ARTEM SHEVCHENKO	{"email": "artem-shevchenko.1963@postgrespro.ru", "phone": "+70330528538"}
0005432336159	C4C41E	3888 885590	OLGA DAVYDOVA	{"phone": "+70738442473"}
0005432335982	2316CA	9332 347072	EVGENIYA ZAKHAROVA	{"email": "e.zakharova_11031969@postgrespro.ru", "phone": "+70642780616"}
0005432335983	2316CA	5508 463368	LYUDMILA ANTONOVA	{"phone": "+70468922244"}
0005432335984	3C3ADD	4491 449793	ADELINA ALEKSANDROVA	{"phone": "+70614565587"}
0005432335985	830E68	3120 204878	PELAGEYA YAKOVLEVA	{"phone": "+70078819145"}
0005432335986	D0420E	4494 787158	EDUARD IVANOV	{"email": "e-ivanov22071979@postgrespro.ru", "phone": "+70886228143"}
0005432335987	D0420E	1139 411452	MIKHAIL ANDREEV	{"phone": "+70961749958"}
0005432335988	9BE4C8	2192 536834	TATYANA ROMANOVA	{"phone": "+70545136156"}
0005432335989	5614E6	6070 581532	IRINA MOISEEVA	{"email": "moiseeva-irina_1972@postgrespro.ru", "phone": "+70849909710"}
0005432335990	DA9DF5	6062 453570	NADEZHDA MALYSHEVA	{"phone": "+70866595688"}
0005432335991	B32A12	8619 663748	VIKTOR VASILEV	{"email": "vasilevv_29041968@postgrespro.ru", "phone": "+70081720320"}
0005432335992	B32A12	0289 914391	TATYANA SOROKINA	{"phone": "+70843439978"}
0005432335993	B32A12	7896 829595	EVGENIY NOVIKOV	{"email": "evgeniy_novikov25031979@postgrespro.ru", "phone": "+70320731192"}
0005432335994	35BFA3	6700 481578	IRINA EGOROVA	{"phone": "+70162328743"}
0005432335995	B4FA20	7615 444034	PAVEL VOROBEV	{"email": "vorobev_pavel.101973@postgrespro.ru", "phone": "+70779763237"}
0005432335996	BB0D46	4761 359919	ALEKSANDR VOROBEV	{"email": "a.vorobev23111969@postgrespro.ru", "phone": "+70098126829"}
0005432335997	BB0D46	4962 333857	EKATERINA YAKOVLEVA	{"email": "yakovlevaekaterina-03071986@postgrespro.ru", "phone": "+70572710263"}
0005432335998	709B51	0533 041351	ALEKSEY KUZMIN	{"email": "kuzmin_a_081971@postgrespro.ru", "phone": "+70571959136"}
0005432335999	9D1B91	8185 149557	LARISA DAVYDOVA	{"email": "davydova_larisa.101982@postgrespro.ru", "phone": "+70437208215"}
0005432336000	B1E870	6102 072860	TATYANA KAZAKOVA	{"email": "t.kazakova1972@postgrespro.ru", "phone": "+70015200318"}
0005432336001	B1E870	2320 446168	KRISTINA TARASOVA	{"phone": "+70625751620"}
0005432336002	16B17C	4953 229544	INNA DENISOVA	{"email": "denisovai.071971@postgrespro.ru", "phone": "+70814109193"}
0005432336003	E258B4	0008 329110	VALERIY MAKAROV	{"email": "makarov_valeriy_021964@postgrespro.ru", "phone": "+70815259853"}
0005432336004	E258B4	1574 936069	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev-041983@postgrespro.ru", "phone": "+70444457433"}
0005432336005	7EAB78	1528 272319	TATYANA NOVIKOVA	{"email": "t.novikova.14061966@postgrespro.ru", "phone": "+70278134162"}
0005432336006	B40FF3	4923 714726	KIRILL MOISEEV	{"phone": "+70555792415"}
0005432336007	767944	6374 406157	SVETLANA GUSEVA	{"email": "gusevasvetlana.27051967@postgrespro.ru", "phone": "+70991470490"}
0005432336008	767944	0457 758208	VLADIMIR FROLOV	{"email": "frolovvladimir-1966@postgrespro.ru", "phone": "+70940460106"}
0005432336009	E4B03E	1469 724699	VALENTINA MOROZOVA	{"email": "morozovav1974@postgrespro.ru", "phone": "+70583640029"}
0005432336010	E4B03E	2783 812016	ANATOLIY SIDOROV	{"email": "sidorov_anatoliy-121977@postgrespro.ru", "phone": "+70624443870"}
0005432336011	F9BAC5	2963 721145	EKATERINA ALEKSEEVA	{"email": "ekaterina-alekseeva-26111970@postgrespro.ru", "phone": "+70673128843"}
0005432336012	52FDAA	6763 527230	OLGA RYABOVA	{"phone": "+70679912925"}
0005432336013	E82069	9577 680494	LIDIYA DMITRIEVA	{"phone": "+70063641268"}
0005432336014	4C627B	4729 656540	SVETLANA LUKYANOVA	{"email": "svetlana-lukyanova-11041967@postgrespro.ru", "phone": "+70199941210"}
0005432336015	95244E	4378 699326	ANASTASIYA KISELEVA	{"phone": "+70338875872"}
0005432336016	424277	8572 891073	YURIY MEDVEDEV	{"phone": "+70754917493"}
0005432336017	424277	0407 440436	TATYANA BORISOVA	{"email": "tatyana.borisova-01061964@postgrespro.ru", "phone": "+70057051525"}
0005432336018	424277	7363 412072	LARISA ALEKSANDROVA	{"phone": "+70267328311"}
0005432336019	52EE7D	0626 445887	ELENA POLYAKOVA	{"phone": "+70732642674"}
0005432336020	302DFE	3394 012986	VLADIMIR ANDREEV	{"email": "andreev_v081968@postgrespro.ru", "phone": "+70211770207"}
0005432336021	FA3FD1	5052 331205	GALINA ZHURAVLEVA	{"phone": "+70958518831"}
0005432336022	3DB4D9	0029 113444	SVETLANA YAKOVLEVA	{"phone": "+70354562967"}
0005432336023	3DB4D9	8517 499892	ALEVTINA SAVELEVA	{"phone": "+70874592348"}
0005432336024	3DB4D9	8630 583721	MATVEY NAUMOV	{"phone": "+70070187820"}
0005432336025	41EA5F	3543 939510	IRINA PETROVA	{"email": "petrova_i091964@postgrespro.ru", "phone": "+70930204165"}
0005432336026	41EA5F	7327 058428	IRINA SAVELEVA	{"phone": "+70212539929"}
0005432336027	8FF3B7	9301 105865	MARIYA KUZMINA	{"email": "mariya_kuzmina_011986@postgrespro.ru", "phone": "+70682397589"}
0005432336028	8FF3B7	5724 394506	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov_13041975@postgrespro.ru", "phone": "+70658603397"}
0005432336029	054F16	6628 142424	ALEKSEY VLASOV	{"phone": "+70413747161"}
0005432336030	CCA748	8311 677935	PETR KONOVALOV	{"phone": "+70280118981"}
0005432336031	CCA748	7737 143306	VALERIY TIMOFEEV	{"email": "timofeevv.23021997@postgrespro.ru", "phone": "+70068515700"}
0005432336032	59FF82	1369 205281	VLADIMIR IVANOV	{"phone": "+70944160568"}
0005432336033	59FF82	1081 977360	NATALIYA VOLKOVA	{"phone": "+70058851433"}
0005432336034	621C21	4682 548305	ELENA MARTYNOVA	{"email": "elena-martynova26011961@postgrespro.ru", "phone": "+70624112428"}
0005432336035	DF759E	5419 892826	ARSENIY SOROKIN	{"email": "sorokinarseniy-1964@postgrespro.ru", "phone": "+70511904935"}
0005432336036	BB1276	8907 630022	DMITRIY CHERNOV	{"phone": "+70162283901"}
0005432336037	DCEA96	6940 609098	ALLA GUSEVA	{"email": "guseva-a.101968@postgrespro.ru", "phone": "+70799980266"}
0005432336038	DCEA96	6585 917470	EVGENIY FEDOTOV	{"phone": "+70144207203"}
0005432336039	F2E55B	7130 725982	STANISLAV RODIONOV	{"email": "rodionov-stanislav_29061979@postgrespro.ru", "phone": "+70687867666"}
0005432336040	06AFD6	7067 272521	MARIYA MELNIKOVA	{"email": "m_melnikova.08051962@postgrespro.ru", "phone": "+70856109417"}
0005432336041	2F2B0C	5895 924198	OLGA SMIRNOVA	{"email": "smirnovaolga_011985@postgrespro.ru", "phone": "+70968339880"}
0005432336042	2F2B0C	1754 732387	TATYANA MELNIKOVA	{"phone": "+70027936725"}
0005432336043	F2106D	3305 731493	IVAN GORBUNOV	{"email": "i_gorbunov_1970@postgrespro.ru", "phone": "+70484740654"}
0005432336044	F2106D	3649 348618	EVDOKIYA VOROBEVA	{"phone": "+70886860953"}
0005432336045	10E3D1	4632 421466	ZOYA ZOTOVA	{"phone": "+70485499465"}
0005432336046	B2E6A3	8399 965705	VLADIMIR ISAEV	{"phone": "+70349146296"}
0005432336047	B2E6A3	2859 012279	OLEG KUZNECOV	{"email": "okuznecov-07101979@postgrespro.ru", "phone": "+70387043981"}
0005432336048	DD30B4	0703 896428	DARYA IVANOVA	{"phone": "+70256891631"}
0005432336049	D47983	2525 693056	VERONIKA BARANOVA	{"phone": "+70990346904"}
0005432336050	7E9A92	5235 451352	NINA BELYAEVA	{"email": "nbelyaeva.1977@postgrespro.ru", "phone": "+70711361868"}
0005432336051	7FF8D7	1774 492150	ROMAN KUZNECOV	{"email": "kuznecov.r061972@postgrespro.ru", "phone": "+70124269069"}
0005432336052	7FF8D7	4360 870632	TATYANA GERASIMOVA	{"phone": "+70347047975"}
0005432336053	B54C6A	1471 569963	YURIY RODIONOV	{"email": "rodionov.yuriy_1972@postgrespro.ru", "phone": "+70885908115"}
0005432336054	435AF1	1029 116014	DENIS GUSEV	{"phone": "+70851651172"}
0005432336055	17D444	6496 914813	SERGEY FILIPPOV	{"email": "filippov-s.1976@postgrespro.ru", "phone": "+70011778876"}
0005432336056	04CD7E	8959 942889	LARISA SCHERBAKOVA	{"email": "scherbakovalarisa_101968@postgrespro.ru", "phone": "+70269385778"}
0005432336057	04CD7E	6973 363959	YULIYA YAKOVLEVA	{"phone": "+70713931570"}
0005432336058	5F2A15	0067 557513	MARIYA TITOVA	{"email": "mariyatitova17061976@postgrespro.ru", "phone": "+70486095050"}
0005432336059	0D9783	2873 864315	IGOR NIKITIN	{"email": "nikitini011968@postgrespro.ru", "phone": "+70488323787"}
0005432336060	D1CF60	0500 086853	EVELINA MAKSIMOVA	{"email": "e_maksimova081969@postgrespro.ru", "phone": "+70085043356"}
0005432336061	FDA785	5627 986287	MIKHAIL MOROZOV	{"email": "mikhail-morozov1972@postgrespro.ru", "phone": "+70777211505"}
0005432336062	1350D0	3115 080553	IGOR AFANASEV	{"email": "afanasev_igor_06061963@postgrespro.ru", "phone": "+70013744702"}
0005432336063	578030	1365 088493	VIKTOR ANTONOV	{"phone": "+70522758882"}
0005432336064	B8ED9F	4583 857857	ALEKSEY KULIKOV	{"email": "kulikova_1975@postgrespro.ru", "phone": "+70345802746"}
0005432336065	B8ED9F	7866 361436	YURIY PAVLOV	{"email": "yuriypavlov.06021972@postgrespro.ru", "phone": "+70530131960"}
0005432336066	D3746B	2797 977560	ELENA BORISOVA	{"email": "elenaborisova-1968@postgrespro.ru", "phone": "+70512401681"}
0005432336067	503270	0992 635787	EKATERINA PETROVA	{"email": "ekaterinapetrova_04081981@postgrespro.ru", "phone": "+70749902281"}
0005432336068	D62038	6045 974347	TATYANA KAZAKOVA	{"phone": "+70310588447"}
0005432336069	9091CE	0193 942647	SERGEY ALEKSEEV	{"email": "sergey_alekseev051968@postgrespro.ru", "phone": "+70042053480"}
0005432336070	A7FD6B	6683 349884	SOFIYA KOROLEVA	{"phone": "+70294808311"}
0005432336071	6DE8C9	1666 764315	ALEKSANDRA SAVELEVA	{"email": "savelevaaleksandra.1962@postgrespro.ru", "phone": "+70222068496"}
0005432336072	6DE8C9	1350 518649	ALEKSEY BONDARENKO	{"email": "bondarenko.aleksey-1984@postgrespro.ru", "phone": "+70186369132"}
0005432336073	83B384	2794 058003	IVAN KARPOV	{"phone": "+70896425262"}
0005432336074	83B384	6715 562633	VALENTINA SMIRNOVA	{"email": "v-smirnova.1976@postgrespro.ru", "phone": "+70989634574"}
0005432336075	3C12F1	3715 781866	EVGENIYA CHERNOVA	{"email": "e_chernova091978@postgrespro.ru", "phone": "+70234568287"}
0005432336076	81D66E	9454 588761	OLESYA IVANOVA	{"email": "ivanova-o_091981@postgrespro.ru", "phone": "+70910977242"}
0005432336077	81D66E	6065 656428	VLADIMIR MEDVEDEV	{"phone": "+70289995088"}
0005432336078	3CD018	0795 347024	TATYANA EGOROVA	{"phone": "+70189206138"}
0005432336079	3CD018	5746 530885	VLADIMIR FROLOV	{"phone": "+70232040651"}
0005432336080	B1B464	1859 426615	NIKOLAY ZAYCEV	{"email": "nikolay.zaycev_11031978@postgrespro.ru", "phone": "+70642875238"}
0005432336081	B1B464	2589 531177	SVETLANA SCHERBAKOVA	{"email": "scherbakova-svetlana_02101973@postgrespro.ru", "phone": "+70678527565"}
0005432336082	3EF0A8	9658 252434	VALERIY SMIRNOV	{"email": "valeriy_smirnov-061969@postgrespro.ru", "phone": "+70060256340"}
0005432336083	E0A80C	7583 351199	SERGEY POPOV	{"phone": "+70094926958"}
0005432336084	61D8A4	7059 614369	DENIS MOROZOV	{"email": "denismorozov071961@postgrespro.ru", "phone": "+70079878995"}
0005432336085	4F5018	7683 962346	KSENIYA ZAYCEVA	{"phone": "+70125800771"}
0005432336086	B1C480	6483 696334	IVAN OSIPOV	{"email": "ivan-osipov-1967@postgrespro.ru", "phone": "+70918360974"}
0005432336087	0376AF	8810 474537	OLGA SEMENOVA	{"email": "semenova_olga021979@postgrespro.ru", "phone": "+70006856318"}
0005432336088	A1D6EC	1749 667639	ALEKSEY FILIPPOV	{"phone": "+70016382583"}
0005432336089	0C3CC8	5344 565484	MARINA FADEEVA	{"email": "fadeeva.marina.1979@postgrespro.ru", "phone": "+70497870879"}
0005432336090	0C3CC8	8160 811479	DMITRIY POPOV	{"email": "popov-dmitriy.07051969@postgrespro.ru", "phone": "+70194626578"}
0005432336091	0C3CC8	7229 144874	VASILIY KUZNECOV	{"phone": "+70617675157"}
0005432336092	CAB826	3658 581941	NIKOLAY KUZMIN	{"email": "nikolay_kuzmin.21101969@postgrespro.ru", "phone": "+70948390509"}
0005432336093	F60AD0	1704 443535	TATYANA CHERNOVA	{"phone": "+70921049706"}
0005432336094	F60AD0	6752 377234	OLGA BARANOVA	{"phone": "+70471786003"}
0005432336095	D614CF	6820 065567	ALEKSEY POPOV	{"phone": "+70140054108"}
0005432336096	D614CF	2271 089660	SVETLANA FILATOVA	{"phone": "+70916160795"}
0005432336097	D614CF	2036 987621	VALENTINA ERMAKOVA	{"phone": "+70312231102"}
0005432336098	D614CF	0873 504835	ALEKSEY ALEKSANDROV	{"email": "aleksey-aleksandrov.051973@postgrespro.ru", "phone": "+70828642515"}
0005432336099	A519CA	8086 757019	PETR SCHERBAKOV	{"email": "scherbakov.p041972@postgrespro.ru", "phone": "+70732630413"}
0005432336100	A519CA	8803 521820	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov.06061963@postgrespro.ru", "phone": "+70590842416"}
0005432336101	A3F1E9	6347 193031	NATALYA KISELEVA	{"phone": "+70385098505"}
0005432336102	68D3DA	4097 959901	NATALYA PAVLOVA	{"email": "n.pavlova.14041976@postgrespro.ru", "phone": "+70236881470"}
0005432336103	68D3DA	6787 890771	SERGEY BELOV	{"email": "belovs_091962@postgrespro.ru", "phone": "+70560750208"}
0005432336104	68D3DA	0492 041852	EVGENIY BARANOV	{"email": "ebaranov_081981@postgrespro.ru", "phone": "+70359596645"}
0005432336105	ED066B	8393 609827	ILYA KUZNECOV	{"email": "i-kuznecov-021974@postgrespro.ru", "phone": "+70758699453"}
0005432336106	920977	5685 530115	EVGENIY ZAYCEV	{"email": "zaycev_evgeniy-19081963@postgrespro.ru", "phone": "+70785980924"}
0005432336107	920977	2769 656749	NIKITA BORISOV	{"phone": "+70730422273"}
0005432336108	D1F9D1	9334 840522	SERGEY SEMENOV	{"email": "sergey.semenov_041979@postgrespro.ru", "phone": "+70013113162"}
0005432336109	6532BB	5470 637987	ANNA FEDOROVA	{"email": "fedorova_anna-1971@postgrespro.ru", "phone": "+70777858985"}
0005432336110	6EB090	7825 764081	RINAT KUZNECOV	{"phone": "+70909906026"}
0005432336111	6EB090	4114 524555	LYUDMILA MAKAROVA	{"phone": "+70886605761"}
0005432336112	6029E8	7769 475524	EVGENIYA VLASOVA	{"email": "evgeniyavlasova-1954@postgrespro.ru", "phone": "+70442170911"}
0005432336113	B7ACDC	0006 746983	STEPAN KOZLOV	{"phone": "+70264646291"}
0005432336114	B7ACDC	6753 516653	LILIYA MIRONOVA	{"phone": "+70231917466"}
0005432336115	DA3F0F	9215 706931	VERA NIKOLAEVA	{"email": "vera_nikolaeva_25121971@postgrespro.ru", "phone": "+70886290930"}
0005432336116	20FA0E	2635 376355	VLADISLAV SHEVCHENKO	{"phone": "+70883323409"}
0005432336117	30F6BF	2414 184707	SOFYA KUZNECOVA	{"email": "sofya_kuznecova1970@postgrespro.ru", "phone": "+70372033051"}
0005432336118	4235AC	8170 751387	NINA MIKHAYLOVA	{"email": "mikhaylova-n.30111983@postgrespro.ru", "phone": "+70600659819"}
0005432336119	8B9FCF	6402 210962	MAKSIM VASILEV	{"email": "vasilev.maksim_1971@postgrespro.ru", "phone": "+70434570105"}
0005432336120	733119	6714 476154	VLADIMIR ZAYCEV	{"email": "vladimir_zaycev031967@postgrespro.ru", "phone": "+70467449733"}
0005432336121	733119	1505 762847	LYUBOV ROMANOVA	{"email": "romanova_lyubov-31071972@postgrespro.ru", "phone": "+70127852707"}
0005432336122	CBCAF7	6875 241907	YAROSLAVA LEBEDEVA	{"email": "yaroslava-lebedeva_1968@postgrespro.ru", "phone": "+70166770560"}
0005432336123	2D2E55	3011 607717	VASILIY ALEKSEEV	{"email": "v-alekseev-011972@postgrespro.ru", "phone": "+70614248224"}
0005432336124	D0A4BE	4417 024965	LYUDMILA BARANOVA	{"phone": "+70962373307"}
0005432336125	ED8F71	2686 662983	VALERIYA IVANOVA	{"phone": "+70055426546"}
0005432336126	ED8F71	1371 238204	DANILA EGOROV	{"email": "egorovd_121978@postgrespro.ru", "phone": "+70203662023"}
0005432336127	4A4391	2384 080232	ELENA NIKOLAEVA	{"phone": "+70637481227"}
0005432336128	4010FC	0091 621849	NINA SEMENOVA	{"email": "semenova.n1974@postgrespro.ru", "phone": "+70027621363"}
0005432336129	4010FC	3517 402575	YURIY NOVIKOV	{"email": "yuriy.novikov.021970@postgrespro.ru", "phone": "+70381247182"}
0005432336130	3787D0	8703 527244	OLGA ARKHIPOVA	{"email": "olga.arkhipova-1975@postgrespro.ru", "phone": "+70696892397"}
0005432336131	3787D0	1834 915700	ELENA TIKHONOVA	{"email": "elenatikhonova-011973@postgrespro.ru", "phone": "+70519224918"}
0005432336132	F96923	0979 776288	KIRILL GORBUNOV	{"email": "gorbunov-k-1980@postgrespro.ru", "phone": "+70180347953"}
0005432336133	AE8055	3365 202082	OLGA GORBUNOVA	{"email": "gorbunovaolga_21011972@postgrespro.ru", "phone": "+70160221306"}
0005432336134	1C3658	0682 640989	MARINA KALININA	{"phone": "+70545228814"}
0005432336135	C37D59	6399 764868	ELENA MOROZOVA	{"phone": "+70523605628"}
0005432336136	933428	4819 614625	GALINA SEMENOVA	{"email": "semenova_galina1975@postgrespro.ru", "phone": "+70714742174"}
0005432336137	E9811C	3434 876804	DANIIL PAVLOV	{"phone": "+70518406029"}
0005432336138	E9811C	3677 193668	VENIAMIN MAKSIMOV	{"email": "v_maksimov1974@postgrespro.ru", "phone": "+70931608077"}
0005432336139	17A960	4576 474299	ALEKSANDRA NIKOLAEVA	{"email": "nikolaevaa_1965@postgrespro.ru", "phone": "+70881920628"}
0005432336140	17A960	9202 608623	ANTON SEMENOV	{"email": "semenov-a_1964@postgrespro.ru", "phone": "+70240985237"}
0005432336141	C5C7F3	4288 162825	ALEKSANDR VOROBEV	{"phone": "+70707764388"}
0005432336142	DD14A8	7804 052036	OLGA RYABOVA	{"phone": "+70104821841"}
0005432336143	541E0A	6758 231844	MIKHAIL POPOV	{"email": "mpopov-11091964@postgrespro.ru", "phone": "+70031669989"}
0005432336144	541E0A	1287 272229	LYUBOV SAVELEVA	{"email": "lyubov-saveleva-1969@postgrespro.ru", "phone": "+70228358903"}
0005432336145	698EB2	5287 229189	EKATERINA KRASNOVA	{"email": "ekrasnova03011969@postgrespro.ru", "phone": "+70244354518"}
0005432336146	35532F	3071 551209	ELENA OSIPOVA	{"phone": "+70421001623"}
0005432336147	35532F	6443 546695	TIKHON TIKHONOV	{"email": "t.tikhonov-1972@postgrespro.ru", "phone": "+70402542665"}
0005432336148	35532F	2126 793622	MAKSIM ORLOV	{"email": "maksimorlov31101970@postgrespro.ru", "phone": "+70711176096"}
0005432336149	364830	3585 770737	OLEG PAVLOV	{"phone": "+70039799831"}
0005432336150	917C1E	8205 861177	KLAVDIYA ANISIMOVA	{"email": "anisimovak.1964@postgrespro.ru", "phone": "+70742210156"}
0005432336151	917C1E	9202 646148	ELENA ZAYCEVA	{"phone": "+70836642193"}
0005432336152	D0860C	3117 806243	TATYANA NAUMOVA	{"email": "naumova-tatyana-22011982@postgrespro.ru", "phone": "+70416135449"}
0005432336153	7BD84D	2753 652877	ANNA NIKITINA	{"email": "nikitina.a1971@postgrespro.ru", "phone": "+70226205198"}
0005432336154	43BFB0	2491 599994	MARINA FEDOROVA	{"phone": "+70287479423"}
0005432336155	2005D0	0937 784732	TATYANA RODIONOVA	{"phone": "+70513431665"}
0005432336156	680440	1510 150385	ANZHELIKA STEPANOVA	{"phone": "+70989069101"}
0005432336157	71722C	1018 252269	NADEZHDA KOROLEVA	{"phone": "+70007105664"}
0005432336158	929864	5330 663307	VALENTINA MARTYNOVA	{"phone": "+70562750008"}
0005432336160	C4C41E	1242 939796	VERA DMITRIEVA	{"phone": "+70696134259"}
0005432336161	F746FA	2896 914017	VLADISLAV AFANASEV	{"email": "afanasev.v11071982@postgrespro.ru", "phone": "+70056045484"}
0005432336162	406994	1404 588342	KIRILL DENISOV	{"email": "denisov.kirill031973@postgrespro.ru", "phone": "+70975998991"}
0005432336163	3B260B	8370 892043	TATYANA POPOVA	{"phone": "+70802761517"}
0005432336164	01C013	9132 961997	LYUBOV POPOVA	{"email": "popova_lyubov_30041963@postgrespro.ru", "phone": "+70281136149"}
0005432336165	D9DCD8	6576 282847	KSENIYA KOZLOVA	{"phone": "+70089451882"}
0005432336166	A9602D	3477 718402	ANASTASIYA IVANOVA	{"phone": "+70500131935"}
0005432336167	62FCEB	9072 565619	KSENIYA IVANOVA	{"phone": "+70725342488"}
0005432336168	649722	2577 047568	YURIY KULIKOV	{"email": "kulikov.yuriy01061974@postgrespro.ru", "phone": "+70385646936"}
0005432336169	E6AA21	6322 895855	ALEKSANDRA NOVIKOVA	{"email": "novikova.a-1982@postgrespro.ru", "phone": "+70425305488"}
0005432336170	E6AA21	9899 887203	ELENA GORBUNOVA	{"phone": "+70622683219"}
0005432336171	E6AA21	3794 049703	VLADIMIR MELNIKOV	{"phone": "+70996899451"}
0005432336172	9A9508	7480 164467	RAISA SOLOVEVA	{"email": "raisa.soloveva031979@postgrespro.ru", "phone": "+70984391907"}
0005432336173	F69B6E	7166 548538	VLADISLAV KUZNECOV	{"email": "kuznecovvladislav_1965@postgrespro.ru", "phone": "+70071197513"}
0005432336174	73B23E	4796 553348	ALEKSANDR SOLOVEV	{"phone": "+70809792631"}
0005432336175	73B23E	4652 733616	VLADIMIR KAZAKOV	{"email": "kazakov-vladimir.25121979@postgrespro.ru", "phone": "+70736435066"}
0005432336176	610D11	7382 783135	VIKTORIYA MAKAROVA	{"email": "viktoriya.makarova27071975@postgrespro.ru", "phone": "+70218390359"}
0005432336177	0D25D6	8781 210398	MARIYA ZHURAVLEVA	{"email": "zhuravleva_m.04121969@postgrespro.ru", "phone": "+70743194197"}
0005432336178	D238E5	7326 906693	EKATERINA MAKAROVA	{"email": "ekaterinamakarova.1972@postgrespro.ru", "phone": "+70167188098"}
0005432336179	86F178	2451 507061	GALINA POPOVA	{"phone": "+70623627533"}
0005432336180	CD7105	5250 211924	NATALIYA ZAKHAROVA	{"phone": "+70933773476"}
0005432336181	CD7105	9724 191124	PETR GORBUNOV	{"phone": "+70107197127"}
0005432336182	22DB62	4463 976724	YULIYA KUZNECOVA	{"phone": "+70406158690"}
0005432336183	22DB62	3167 330814	EKATERINA ZOTOVA	{"email": "zotova.e-111967@postgrespro.ru", "phone": "+70450158639"}
0005432336184	558FE4	1829 685591	ANASTASIYA VASILEVA	{"phone": "+70648537054"}
0005432336185	ED74E5	2346 827778	ANDREY SCHERBAKOV	{"phone": "+70752191432"}
0005432336186	3C1FB7	5390 746289	NIKOLAY NIKITIN	{"phone": "+70163533850"}
0005432336187	0A6606	3143 350011	NATALYA FILIPPOVA	{"phone": "+70164358402"}
0005432336188	0A6606	2600 511124	YULIYA LOGINOVA	{"email": "yloginova091975@postgrespro.ru", "phone": "+70271334312"}
0005432336189	5377CC	7487 114886	ILYA KUZNECOV	{"email": "kuznecovilya-1975@postgrespro.ru", "phone": "+70654921835"}
0005432336190	C0BD52	3041 441702	ANNA KOZLOVA	{"email": "kozlova_a-111974@postgrespro.ru", "phone": "+70487823435"}
0005432336191	35A3D6	2118 625137	ALEKSANDR VOLKOV	{"email": "a.volkov.1974@postgrespro.ru", "phone": "+70875605713"}
0005432336192	35A3D6	6664 729540	IVAN PETROV	{"email": "i_petrov_1959@postgrespro.ru", "phone": "+70429002049"}
0005432336193	35A3D6	6374 999270	NINA EFIMOVA	{"phone": "+70783491568"}
0005432336194	BF4A8F	9099 996368	ALEKSANDR SOKOLOV	{"phone": "+70115319570"}
0005432336195	3F1369	7294 118660	LYUDMILA NESTEROVA	{"phone": "+70941171144"}
0005432336196	3F1369	1459 841874	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy_1959@postgrespro.ru", "phone": "+70975256077"}
0005432336197	21DA88	9259 445342	ALEKSEY KOZLOV	{"email": "aleksey.kozlov_081970@postgrespro.ru", "phone": "+70363853841"}
0005432336198	21DA88	0442 419506	EVGENIY GERASIMOV	{"email": "evgeniy-gerasimov-1963@postgrespro.ru", "phone": "+70106865963"}
0005432336199	810896	8517 410506	GULNARA TIKHONOVA	{"email": "tikhonova-g14071971@postgrespro.ru", "phone": "+70459675357"}
0005432336200	E0BF73	0464 942266	ELIZAVETA NOVIKOVA	{"phone": "+70692202114"}
0005432336201	E0BF73	5554 647340	PELAGEYA YAKOVLEVA	{"email": "p_yakovleva-18051989@postgrespro.ru", "phone": "+70241138485"}
0005432336202	6A57C9	9415 971976	NIKITA YAKOVLEV	{"email": "n_yakovlev-121958@postgrespro.ru", "phone": "+70961787559"}
0005432336203	983BB1	4493 921841	DMITRIY FILIPPOV	{"phone": "+70368710960"}
0005432336204	381E07	5283 263419	TATYANA NIKIFOROVA	{"phone": "+70764579267"}
0005432336205	A83033	8659 771498	ALEKSANDR GERASIMOV	{"phone": "+70194628167"}
0005432336206	E5CACC	7046 152824	MARINA EGOROVA	{"phone": "+70706912986"}
0005432336207	3F8DDB	6233 623035	OKSANA KOLESNIKOVA	{"email": "oksana-kolesnikova_021965@postgrespro.ru", "phone": "+70090024636"}
0005432336208	3E5633	2997 378775	ANDREY ORLOV	{"phone": "+70010358504"}
0005432336209	2C1CFA	4050 723109	OLGA ZHURAVLEVA	{"email": "olga-zhuravleva_1960@postgrespro.ru", "phone": "+70660609522"}
0005432336210	93B745	9335 419899	EVDOKIYA ALEKSEEVA	{"phone": "+70487632395"}
0005432336211	93B745	3009 126802	ALEKSEY BELOV	{"email": "belov.a1966@postgrespro.ru", "phone": "+70897753825"}
0005432336212	481E10	6030 384985	NADEZHDA BELOVA	{"phone": "+70774388700"}
0005432336213	5EAA79	6783 585806	SVETLANA SAVELEVA	{"email": "saveleva_svetlana041974@postgrespro.ru", "phone": "+70770556775"}
0005432336214	5EAA79	4351 534586	NATALIYA DMITRIEVA	{"phone": "+70231400434"}
0005432336215	89A8B2	0144 272505	MARIYA ROMANOVA	{"phone": "+70929418896"}
0005432336216	89A8B2	1121 024066	ARSENIY FROLOV	{"phone": "+70461827065"}
0005432336217	081117	3177 332119	OLGA NESTEROVA	{"phone": "+70890911754"}
0005432336218	081117	8221 647140	SERGEY PETROV	{"phone": "+70638079401"}
0005432336219	5D79EB	2342 876113	POLINA RYABOVA	{"email": "polina-ryabova041974@postgrespro.ru", "phone": "+70766174021"}
0005432336220	5D79EB	8222 098967	PETR SIDOROV	{"email": "sidorov-p31011975@postgrespro.ru", "phone": "+70160358131"}
0005432336221	5667C1	7470 674664	TATYANA KOVALEVA	{"email": "kovalevatatyana_1980@postgrespro.ru", "phone": "+70446984976"}
0005432336222	BF8F4B	0788 347652	ALENA LOGINOVA	{"email": "loginovaa-101982@postgrespro.ru", "phone": "+70523112891"}
0005432336223	7A6E20	8218 558594	NATALIYA KRASNOVA	{"email": "krasnovan121955@postgrespro.ru", "phone": "+70027334671"}
0005432336224	73FEEB	5257 595959	DENIS TARASOV	{"email": "tarasov-denis_121964@postgrespro.ru", "phone": "+70873120973"}
0005432336225	0C425F	2562 270236	NINA VOROBEVA	{"email": "vorobeva_n011985@postgrespro.ru", "phone": "+70883751397"}
0005432336226	5DBD7D	4801 287992	KONSTANTIN DENISOV	{"email": "k_denisov.091965@postgrespro.ru", "phone": "+70160343524"}
0005432336227	5DBD7D	2321 349045	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila-111976@postgrespro.ru", "phone": "+70468134023"}
0005432336228	12F5F8	3619 959638	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikova_v-091976@postgrespro.ru", "phone": "+70482460167"}
0005432336229	410091	7383 937911	NINA GUSEVA	{"email": "ninaguseva-1979@postgrespro.ru", "phone": "+70116908919"}
0005432336230	D568F6	4060 261809	VLADIMIR KOROLEV	{"email": "v-korolev_01101970@postgrespro.ru", "phone": "+70892751627"}
0005432336231	0BBB3C	1587 393540	OLGA DMITRIEVA	{"phone": "+70659497979"}
0005432336232	F46772	4879 212131	NATALYA AKIMOVA	{"phone": "+70381340777"}
0005432336233	5187B9	8676 240434	ROZA KONOVALOVA	{"email": "roza_konovalova.091975@postgrespro.ru", "phone": "+70431421285"}
0005432336234	5187B9	5508 928137	PAVEL SIDOROV	{"phone": "+70450309864"}
0005432336235	BF21E6	6385 083270	KIRILL ZAYCEV	{"email": "k.zaycev_29111971@postgrespro.ru", "phone": "+70887805165"}
0005432336236	0A627D	7160 200185	ANTON YAKOVLEV	{"email": "yakovlev-a-1966@postgrespro.ru", "phone": "+70687388450"}
0005432336237	A7C05F	4818 143317	ALEKSANDR DMITRIEV	{"email": "a-dmitriev.20101964@postgrespro.ru", "phone": "+70306064282"}
0005432336238	7DE22F	0198 412828	NINA NIKOLAEVA	{"phone": "+70211875730"}
0005432336239	D7830F	0037 555309	RASHIT KUZMIN	{"email": "rashitkuzmin.1963@postgrespro.ru", "phone": "+70944170663"}
0005432336240	30DFA9	2341 076847	ANNA LEBEDEVA	{"phone": "+70667226285"}
0005432336241	7FAE77	8702 101704	VLADISLAV MAKAROV	{"phone": "+70545930045"}
0005432336242	7FAE77	2045 034417	TAMARA KUZNECOVA	{"phone": "+70053022990"}
0005432336243	B8873D	2251 280779	SERGEY MEDVEDEV	{"phone": "+70620478487"}
0005432336244	711A70	0873 699146	LEONID IVANOV	{"phone": "+70209614275"}
0005432336245	C85778	1870 931218	LIDIYA TIMOFEEVA	{"email": "l-timofeeva27091966@postgrespro.ru", "phone": "+70565160282"}
0005432336246	C7BEB4	3258 788878	YAKOV PETROV	{"email": "petrov_yakov-1964@postgrespro.ru", "phone": "+70172543162"}
0005432336247	C7BEB4	5893 127864	EVGENIY KARPOV	{"email": "karpov_e-25021971@postgrespro.ru", "phone": "+70941140878"}
0005432336248	EDB001	8946 876459	ARTUR STEPANOV	{"email": "artur_stepanov-11111979@postgrespro.ru", "phone": "+70552441829"}
0005432336249	A0895C	7161 380383	EKATERINA KOMAROVA	{"email": "komarova_e05031965@postgrespro.ru", "phone": "+70585406992"}
0005432336250	A0895C	7353 278345	EVDOKIYA ANTONOVA	{"email": "evdokiya.antonova-18051967@postgrespro.ru", "phone": "+70090979408"}
0005432336251	891A2F	5323 363298	SERGEY IVANOV	{"email": "ivanov_sergey-13081976@postgrespro.ru", "phone": "+70643982737"}
0005432336252	7DC92D	0240 812243	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir-22031973@postgrespro.ru", "phone": "+70685049167"}
0005432336253	906E34	7491 021691	ANATOLIY TARASOV	{"email": "anatoliy.tarasov.111978@postgrespro.ru", "phone": "+70249223641"}
0005432336254	906E34	6845 666288	NIKOLAY MATVEEV	{"email": "matveev_nikolay29111962@postgrespro.ru", "phone": "+70643691902"}
0005432336255	B72041	0847 532205	SVETLANA KOLESNIKOVA	{"phone": "+70789605156"}
0005432336256	CEDAE5	5617 682062	EVGENIY POPOV	{"email": "e_popov-04071968@postgrespro.ru", "phone": "+70317200372"}
0005432336257	68A7A4	6221 259332	RAIL VASILEV	{"phone": "+70291850446"}
0005432336258	478EC4	0465 388283	ALENA KONDRATEVA	{"email": "kondratevaa.021984@postgrespro.ru", "phone": "+70752792446"}
0005432336259	82D46E	0935 820739	ALEKSANDR KARPOV	{"email": "karpov_a-1976@postgrespro.ru", "phone": "+70985366669"}
0005432336260	A94F7C	9234 845032	MAKSIM ALEKSEEV	{"phone": "+70024064489"}
0005432336261	73F88D	1496 196309	IBRAGIM ILIN	{"phone": "+70652545733"}
0005432336262	CA755F	4415 676872	IGOR IVANOV	{"email": "i-ivanov_22021980@postgrespro.ru", "phone": "+70585925602"}
0005432336263	F61215	7094 262457	ELMIRA RYABOVA	{"email": "elmira.ryabova.23011972@postgrespro.ru", "phone": "+70003690481"}
0005432336264	F61215	5626 491089	NIKOLAY ZAYCEV	{"email": "zaycev_nikolay_1980@postgrespro.ru", "phone": "+70477866575"}
0005432336265	DAB438	2221 558091	EVGENIY VASILEV	{"email": "vasilev_evgeniy-1977@postgrespro.ru", "phone": "+70845385406"}
0005432336266	4679D1	9655 716484	VYACHESLAV MATVEEV	{"phone": "+70157711380"}
0005432336267	14C23C	0349 565966	OLGA DANILOVA	{"phone": "+70773547687"}
0005432336268	D6BD9D	3309 984093	VITALIY VASILEV	{"phone": "+70434983232"}
0005432336269	D6BD9D	6774 548333	STEPAN NAUMOV	{"email": "naumovs1952@postgrespro.ru", "phone": "+70483172586"}
0005432336270	D845E9	3907 654387	ILYA ISAEV	{"email": "iisaev.051973@postgrespro.ru", "phone": "+70801670263"}
0005432336271	0F12BC	5358 578564	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev.1972@postgrespro.ru", "phone": "+70904537330"}
0005432336272	0F12BC	5255 003424	VALENTINA KUZNECOVA	{"phone": "+70127137316"}
0005432336273	0F12BC	9213 935493	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana22101971@postgrespro.ru", "phone": "+70351504279"}
0005432336274	A762C7	0321 836412	ANDREY SOROKIN	{"phone": "+70832887879"}
0005432336275	9F542A	3102 600285	NINA GUSEVA	{"email": "nina_guseva.05041976@postgrespro.ru", "phone": "+70666065534"}
0005432336276	232D7C	1754 382197	TATYANA SOKOLOVA	{"phone": "+70678054203"}
0005432336277	34C574	0549 829175	ALEKSEY SCHERBAKOV	{"email": "scherbakov.a-101976@postgrespro.ru", "phone": "+70524736480"}
0005432336278	058B5F	6428 476779	ALEKSANDR ABRAMOV	{"phone": "+70271651470"}
0005432336279	35197B	7471 979021	IVAN ZAYCEV	{"email": "i-zaycev.1975@postgrespro.ru", "phone": "+70301070309"}
0005432336280	35197B	0171 627911	VLADIMIR SCHERBAKOV	{"phone": "+70910563717"}
0005432336281	14530A	5635 712193	ANNA SCHERBAKOVA	{"email": "annascherbakova-101980@postgrespro.ru", "phone": "+70600646822"}
0005432336282	4B92CE	1136 870377	VALENTINA LAZAREVA	{"email": "v.lazareva.1976@postgrespro.ru", "phone": "+70818137148"}
0005432336283	052908	6281 248623	LARISA MELNIKOVA	{"email": "melnikovalarisa1982@postgrespro.ru", "phone": "+70688343911"}
0005432336284	35E829	0904 516263	TATYANA ISAEVA	{"phone": "+70407753790"}
0005432336285	7B3256	9363 089501	ALBERT POPOV	{"email": "popov.albert_1958@postgrespro.ru", "phone": "+70650888625"}
0005432336286	08E3A5	1331 855244	VLADIMIR FEDOROV	{"phone": "+70646874591"}
0005432336287	08E3A5	0319 621653	EKATERINA VOLKOVA	{"phone": "+70064216290"}
0005432336288	D88CED	1439 020857	SERGEY MIRONOV	{"email": "mironov-s_1971@postgrespro.ru", "phone": "+70863735893"}
0005432336289	7079E1	7432 259521	OLGA DAVYDOVA	{"phone": "+70832305385"}
0005432336290	0A3BC7	2311 164214	LYUDMILA KUZNECOVA	{"phone": "+70614868140"}
0005432336291	A9AD75	7733 304911	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov.051975@postgrespro.ru", "phone": "+70239117292"}
0005432336292	9DF605	8831 927024	VALENTINA SIDOROVA	{"email": "sidorova_valentina_1974@postgrespro.ru", "phone": "+70772693232"}
0005432336293	CD2C3E	3223 564573	ANATOLIY OSIPOV	{"email": "aosipov-07091978@postgrespro.ru", "phone": "+70796360226"}
0005432336294	CD2C3E	8612 032601	VLADIMIR FEDOTOV	{"email": "fedotov.v-091982@postgrespro.ru", "phone": "+70495877134"}
0005432336295	4E3A91	4698 280203	OLGA BELOVA	{"phone": "+70546682659"}
0005432336296	EBF5E2	0627 884635	ALEKSEY SERGEEV	{"email": "a-sergeev.121972@postgrespro.ru", "phone": "+70297246685"}
0005432336297	236D42	4066 428491	MARGARITA CHERNOVA	{"phone": "+70894340536"}
0005432336298	A2A8D2	2908 692152	TAMARA SOROKINA	{"email": "sorokina.t.1973@postgrespro.ru", "phone": "+70128112500"}
0005432336299	B48E2D	9738 724477	MARINA MELNIKOVA	{"phone": "+70297616579"}
0005432336300	CAB9AA	1952 987194	SERGEY BARANOV	{"email": "s_baranov1967@postgrespro.ru", "phone": "+70975507368"}
0005432336301	6073E7	7660 010966	SERGEY MELNIKOV	{"email": "melnikov_sergey_041956@postgrespro.ru", "phone": "+70243979816"}
0005432336302	6073E7	2601 298320	EVGENIYA KUZMINA	{"phone": "+70101606147"}
0005432336303	7D5693	5110 360688	ALEKSEY NAZAROV	{"email": "a_nazarov.10061971@postgrespro.ru", "phone": "+70435604968"}
0005432336304	4D3234	2019 125096	MARIYA KOROLEVA	{"phone": "+70100897421"}
0005432336305	4D3234	0128 323551	ELIZAVETA NAZAROVA	{"email": "nazarova.e-1958@postgrespro.ru", "phone": "+70587373266"}
0005432336306	8E9112	9349 723019	ILYA MOROZOV	{"email": "ilyamorozov-1973@postgrespro.ru", "phone": "+70353610235"}
0005432336307	BA847D	3083 724738	VALENTINA CHERNOVA	{"phone": "+70713374761"}
0005432336308	76DE5F	1014 280009	NATALYA TIMOFEEVA	{"email": "n-timofeeva_03111968@postgrespro.ru", "phone": "+70541971572"}
0005432336309	188D8C	9072 331839	VALENTINA TARASOVA	{"phone": "+70140440706"}
0005432336310	062AB8	9510 216485	NATALYA ANDREEVA	{"email": "natalya.andreeva101969@postgrespro.ru", "phone": "+70795537396"}
0005432336311	062AB8	7560 223988	ALEKSEY ANDREEV	{"phone": "+70033933458"}
0005432336312	062AB8	7460 096771	ELIZAVETA BORISOVA	{"email": "borisova.elizaveta-08041953@postgrespro.ru", "phone": "+70966492970"}
0005432336313	65BDA4	7744 590214	SERGEY SEMENOV	{"email": "semenovsergey.18111959@postgrespro.ru", "phone": "+70918017634"}
0005432336314	65BDA4	3509 667674	EVGENIYA BORISOVA	{"phone": "+70921494604"}
0005432336315	73471E	2155 111558	NATALYA MIKHAYLOVA	{"phone": "+70241062489"}
0005432336316	73471E	1715 069891	OKSANA GRISHINA	{"email": "grishina.o1962@postgrespro.ru", "phone": "+70530883116"}
0005432336317	250EC6	1298 791874	FEDOR PETROV	{"email": "petrovf.19061960@postgrespro.ru", "phone": "+70687267648"}
0005432336318	BF4239	4953 344872	NIKITA SHEVCHENKO	{"email": "n_shevchenko.061968@postgrespro.ru", "phone": "+70575156044"}
0005432336319	BF4239	3198 277466	SERGEY TARASOV	{"email": "sergey.tarasov_1976@postgrespro.ru", "phone": "+70016194218"}
0005432336320	C42F9E	2411 108784	ANDREY MAKAROV	{"phone": "+70383265038"}
0005432336321	3F463F	9368 278106	VLADIMIR KOZLOV	{"email": "kozlovv19101960@postgrespro.ru", "phone": "+70260266251"}
0005432336322	3B4CC9	0811 395678	KSENIYA ROMANOVA	{"phone": "+70060469950"}
0005432336323	3B4CC9	8492 525513	VLADIMIR RODIONOV	{"phone": "+70746933460"}
0005432336324	E8235F	4686 137580	EKATERINA NAZAROVA	{"email": "ekaterina_nazarova.1970@postgrespro.ru", "phone": "+70212245426"}
0005432336325	98763D	1273 560681	ANNA KONOVALOVA	{"phone": "+70461186234"}
0005432336326	F6C5A0	3459 224793	NATALYA VLASOVA	{"phone": "+70850188076"}
0005432336327	B6D558	2102 936924	OLEG ROMANOV	{"email": "oleg_romanov-101954@postgrespro.ru", "phone": "+70747526322"}
0005432336328	1904FE	0733 162135	ZINAIDA FROLOVA	{"email": "zinaida.frolova.101972@postgrespro.ru", "phone": "+70931814670"}
0005432336329	7821E7	9456 312240	MARGARITA MAKAROVA	{"email": "makarova-margarita-15071975@postgrespro.ru", "phone": "+70302850083"}
0005432336330	16C6D9	6808 359102	TATYANA YAKOVLEVA	{"email": "tatyanayakovleva.14091977@postgrespro.ru", "phone": "+70660572346"}
0005432336331	A16F84	5238 248412	LYUBOV LUKYANOVA	{"phone": "+70463406500"}
0005432336332	0530C9	3035 750078	VLADIMIR KULIKOV	{"email": "kulikov_vladimir.1975@postgrespro.ru", "phone": "+70232731890"}
0005432336333	2265FB	1396 179408	NAILYA KUZNECOVA	{"email": "nkuznecova16101969@postgrespro.ru", "phone": "+70021114927"}
0005432336334	9F502A	3332 579594	DMITRIY SCHERBAKOV	{"email": "scherbakov-d_1975@postgrespro.ru", "phone": "+70278366165"}
0005432336335	DF74EC	8139 015445	ALEKSANDR MOROZOV	{"phone": "+70879330251"}
0005432336336	4CDEA9	3793 606365	GRIGORIY ZHUKOV	{"email": "g-zhukov.011985@postgrespro.ru", "phone": "+70650377339"}
0005432336337	4CDEA9	2771 636651	INNA NOVIKOVA	{"email": "novikova.i121972@postgrespro.ru", "phone": "+70708151660"}
0005432336338	4CDEA9	7806 834663	ELENA NESTEROVA	{"phone": "+70193134516"}
0005432336339	2C4D00	4645 190219	VADIM TARASOV	{"phone": "+70575274360"}
0005432336340	2C4D00	2406 906412	NARIMAN NAZAROV	{"email": "nazarov_nariman.02011967@postgrespro.ru", "phone": "+70376561891"}
0005432336341	4037E0	8066 259399	ALEKSANDR SOKOLOV	{"email": "sokolov.a-1975@postgrespro.ru", "phone": "+70735657018"}
0005432336342	BA96C1	5890 176106	LIDIYA POPOVA	{"email": "lpopova1971@postgrespro.ru", "phone": "+70936921791"}
0005432336343	BA96C1	5503 911012	ALEKSANDR IVANOV	{"email": "ivanov-a.06011970@postgrespro.ru", "phone": "+70107150280"}
0005432336344	3DE9E4	2156 914598	ELENA BARANOVA	{"email": "elena-baranova03021974@postgrespro.ru", "phone": "+70425113251"}
0005432336345	6EE5E7	0338 594451	EVGENIY EGOROV	{"phone": "+70495138988"}
0005432336346	C141BB	6400 710589	ANASTASIYA ERMAKOVA	{"phone": "+70466205830"}
0005432336347	1A4FA4	9204 731545	ELVIRA RYABOVA	{"email": "e.ryabova_04071970@postgrespro.ru", "phone": "+70882347831"}
0005432336348	AA68A6	4215 074047	ANDREY ALEKSANDROV	{"phone": "+70920546769"}
0005432336349	0AB1A9	3819 653247	TAISIYA RODIONOVA	{"email": "rodionova-taisiya_1973@postgrespro.ru", "phone": "+70609308326"}
0005432336350	0AB1A9	2243 533746	MIKHAIL NIKOLAEV	{"email": "m_nikolaev.051974@postgrespro.ru", "phone": "+70929798263"}
0005432336351	ABA28D	1887 697554	KLAVDIYA ALEKSANDROVA	{"phone": "+70317346410"}
0005432336352	0E3804	2401 031156	ANATOLIY CHERNOV	{"email": "chernov-anatoliy.021972@postgrespro.ru", "phone": "+70201204472"}
0005432336353	2D2550	4010 558581	ALEKSEY GRIGOREV	{"email": "a_grigorev071977@postgrespro.ru", "phone": "+70487405645"}
0005432336354	E3A694	5499 427962	ALEKSANDR YAKOVLEV	{"email": "yakovleva.051970@postgrespro.ru", "phone": "+70181206407"}
0005432336355	94CEDA	5946 065717	LYUBOV NIKIFOROVA	{"email": "nikiforova_lyubov-1955@postgrespro.ru", "phone": "+70197552218"}
0005432336356	609BDD	3592 846940	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey1968@postgrespro.ru", "phone": "+70692675828"}
0005432336357	609BDD	6179 729913	VERA PAVLOVA	{"phone": "+70134914997"}
0005432336358	52088C	9829 454766	VERA SOLOVEVA	{"phone": "+70885820212"}
0005432336359	AE4621	9511 022447	VASILIY IVANOV	{"email": "ivanov.v11041953@postgrespro.ru", "phone": "+70950425282"}
0005432336360	8A78FE	6651 421553	IVAN MELNIKOV	{"phone": "+70194488148"}
0005432336361	6B52E1	9064 191618	ELENA SMIRNOVA	{"email": "elena-smirnova071973@postgrespro.ru", "phone": "+70628018371"}
0005432336362	6B52E1	0138 145714	SVETLANA NIKOLAEVA	{"email": "s.nikolaeva_24021980@postgrespro.ru", "phone": "+70691604356"}
0005432336363	F3A29D	3036 178209	IVAN DMITRIEV	{"phone": "+70024949395"}
0005432336364	F3A29D	5536 919773	ANNA KONOVALOVA	{"email": "konovalovaanna.1964@postgrespro.ru", "phone": "+70634724075"}
0005432336365	66ABA5	0506 701687	SERGEY NOVIKOV	{"email": "novikovs.031977@postgrespro.ru", "phone": "+70865004832"}
0005432336366	66ABA5	8999 189768	EVGENIYA GORBUNOVA	{"email": "gorbunovaevgeniya.031972@postgrespro.ru", "phone": "+70638255854"}
0005432336367	9370F5	9291 371052	VLADIMIR YAKOVLEV	{"email": "vladimir_yakovlev1968@postgrespro.ru", "phone": "+70326393324"}
0005432336368	9370F5	3036 817075	OKSANA OSIPOVA	{"email": "o_osipova1977@postgrespro.ru", "phone": "+70918759358"}
0005432336369	34F18E	0247 291125	DARYA SERGEEVA	{"phone": "+70951807879"}
0005432336370	34F18E	8302 459939	MARIYA PETROVA	{"phone": "+70580645421"}
0005432336371	837571	7210 363887	ANNA TIMOFEEVA	{"email": "timofeeva_a.20101972@postgrespro.ru", "phone": "+70828078712"}
0005432336372	837571	0032 623121	STANISLAV ROMANOV	{"email": "stanislavromanov091979@postgrespro.ru", "phone": "+70273875983"}
0005432336373	56CBF5	1194 691032	ALEKSEY SCHERBAKOV	{"phone": "+70013635516"}
0005432336374	D0CEC4	5106 790120	LYUDMILA ZHURAVLEVA	{"email": "lyudmila.zhuravleva.1967@postgrespro.ru", "phone": "+70401401177"}
0005432336375	DAC2E0	7024 221522	LYUDMILA ROMANOVA	{"email": "romanoval.101981@postgrespro.ru", "phone": "+70856097657"}
0005432336376	16AFB9	5854 733561	DARYA ILINA	{"email": "d_ilina-1971@postgrespro.ru", "phone": "+70964006490"}
0005432336377	16AFB9	2894 168061	ANDREY SMIRNOV	{"email": "a_smirnov.1973@postgrespro.ru", "phone": "+70464504253"}
0005432336378	C686A1	7985 810897	NIKOLAY SCHERBAKOV	{"phone": "+70352490495"}
0005432336379	C686A1	1373 924415	DIANA DENISOVA	{"phone": "+70248600586"}
0005432336380	C686A1	8079 326187	ALEKSANDRA ZHURAVLEVA	{"phone": "+70053992377"}
0005432336381	A34EAD	4507 274468	NINA BARANOVA	{"email": "baranova_n.29121980@postgrespro.ru", "phone": "+70478008183"}
0005432336382	8998F1	1189 369247	VALERIY POPOV	{"phone": "+70879595840"}
0005432336383	95EEE2	2888 345081	ANTON NIKOLAEV	{"email": "nikolaev.a_20021965@postgrespro.ru", "phone": "+70936598888"}
0005432336384	EE8A50	2839 944566	GENNADIY KRASNOV	{"email": "krasnov.gennadiy13011975@postgrespro.ru", "phone": "+70394465758"}
0005432359506	3C4CEE	2946 827935	GENNADIY YAKOVLEV	{"phone": "+70361602351"}
0005432359507	96D521	6371 351700	SERGEY GRIGOREV	{"email": "sergey_grigorev1975@postgrespro.ru", "phone": "+70657010267"}
0005432359508	96D521	6675 948379	ANATOLIY NAZAROV	{"phone": "+70522108085"}
0005432359509	EBE0EE	2538 002253	OLGA KUZNECOVA	{"email": "kuznecova.olga1957@postgrespro.ru", "phone": "+70275201975"}
0005432359510	8E3BB9	0610 767035	TATYANA SEMENOVA	{"phone": "+70018865706"}
0005432359511	802F37	4795 471262	KSENIYA ZHURAVLEVA	{"email": "k_zhuravleva_101979@postgrespro.ru", "phone": "+70060049799"}
0005432359512	5228C7	9792 890120	VALENTINA GERASIMOVA	{"email": "v_gerasimova061976@postgrespro.ru", "phone": "+70417198089"}
0005432359513	5228C7	5359 681318	VALERIY ZAYCEV	{"phone": "+70204397004"}
0005432359514	73039A	9795 814743	ALEKSEY EGOROV	{"phone": "+70404242205"}
0005432359515	4629F6	0325 197961	DENIS ZHURAVLEV	{"phone": "+70590418949"}
0005432359516	9D6AAD	8939 306799	IRINA FILIPPOVA	{"email": "filippova-irina-01071973@postgrespro.ru", "phone": "+70778765979"}
0005432359517	9D6AAD	9171 866663	MIKHAIL KUZMIN	{"phone": "+70997367253"}
0005432359518	225903	4565 193892	ALEKSANDR KOZLOV	{"phone": "+70731633772"}
0005432359519	121828	3556 330480	ELENA MAKAROVA	{"email": "elenamakarova.1963@postgrespro.ru", "phone": "+70925647257"}
0005432359520	6357E5	1927 721132	YURIY ABRAMOV	{"phone": "+70931404586"}
0005432359521	6357E5	4019 054637	VERA TARASOVA	{"phone": "+70165313811"}
0005432359522	42777E	5465 101911	IREK FROLOV	{"phone": "+70945085975"}
0005432359523	F143B6	7459 438732	ARTEM NIKITIN	{"email": "nikitin.a_1977@postgrespro.ru", "phone": "+70241809589"}
0005432359524	F143B6	3267 851299	ALEKSANDR POPOV	{"email": "aleksandrpopov.20041981@postgrespro.ru", "phone": "+70069591914"}
0005432359525	9B0F54	8831 208260	GALINA MAKSIMOVA	{"email": "g-maksimova11091964@postgrespro.ru", "phone": "+70303750728"}
0005432359526	9B0F54	7688 098187	OLGA SEMENOVA	{"email": "olga.semenova_051965@postgrespro.ru", "phone": "+70297986260"}
0005432359527	8B1FB6	8015 027438	KONSTANTIN MIKHAYLOV	{"email": "mikhaylov-k071973@postgrespro.ru", "phone": "+70020231372"}
0005432359528	51BFC0	4685 345471	PAVEL SMIRNOV	{"email": "smirnovpavel_18061977@postgrespro.ru", "phone": "+70575925974"}
0005432359529	352C86	0998 467556	LYUBOV OVCHINNIKOVA	{"email": "lyubov_ovchinnikova-1969@postgrespro.ru", "phone": "+70663890358"}
0005432359530	E72348	9948 503281	VIKTORIYA KULIKOVA	{"phone": "+70037834741"}
0005432359531	634CBB	4250 611010	VALERIY SOKOLOV	{"phone": "+70530862766"}
0005432359532	890A89	3017 399400	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev.26021975@postgrespro.ru", "phone": "+70254024731"}
0005432359533	2C9132	9772 707588	VLADISLAV ANDREEV	{"phone": "+70958602311"}
0005432359534	1CF166	1339 608336	ELENA PAVLOVA	{"phone": "+70773923399"}
0005432359535	53D228	1993 140356	RIMMA EFREMOVA	{"email": "rimmaefremova.1969@postgrespro.ru", "phone": "+70098414906"}
0005432359536	B75942	4896 731599	PAVEL NIKITIN	{"email": "p_nikitin07121969@postgrespro.ru", "phone": "+70876124815"}
0005432359537	3118CD	1778 130836	RUSLAN FILIPPOV	{"email": "ruslan_filippov.1968@postgrespro.ru", "phone": "+70932140035"}
0005432359538	3118CD	3541 935246	SERGEY NIKOLAEV	{"email": "nikolaev_s.091970@postgrespro.ru", "phone": "+70447455418"}
0005432359539	682B48	9122 479556	TAGIR MOROZOV	{"email": "morozov.t-111969@postgrespro.ru", "phone": "+70309423164"}
0005432359540	F58920	4456 619632	ILYA MOROZOV	{"phone": "+70266352178"}
0005432359541	F58920	6669 046278	ALEKSANDRA FADEEVA	{"phone": "+70083520796"}
0005432359542	2EC01F	5060 008440	TAMARA EGOROVA	{"phone": "+70375441458"}
0005432359543	5117D7	1764 106616	DANIIL ALEKSEEV	{"phone": "+70663686060"}
0005432359544	E96312	2618 009855	NADEZHDA LEBEDEVA	{"phone": "+70640965680"}
0005432359545	467885	7018 414910	MIKHAIL KUZMIN	{"phone": "+70289435171"}
0005432359546	9083E6	1432 982790	ANDREY SOLOVEV	{"phone": "+70997711990"}
0005432359547	9083E6	8538 130297	YURIY SEMENOV	{"email": "yuriy.semenov.091966@postgrespro.ru", "phone": "+70861145662"}
0005432359548	8101E5	1289 269878	OLGA SMIRNOVA	{"phone": "+70648882007"}
0005432359549	8101E5	5748 425094	LIDIYA RODIONOVA	{"phone": "+70774815975"}
0005432359550	8101E5	1639 627662	EVGENIYA GORBUNOVA	{"email": "evgeniya_gorbunova_17061976@postgrespro.ru", "phone": "+70185016842"}
0005432359551	62478F	6409 220538	NATALYA KONOVALOVA	{"email": "konovalova-natalya_24091969@postgrespro.ru", "phone": "+70969427336"}
0005432359552	844BE9	4829 299216	VLADIMIR IVANOV	{"email": "ivanov.v1972@postgrespro.ru", "phone": "+70139343593"}
0005432359553	555D29	3024 227518	ANASTASIYA KOROLEVA	{"phone": "+70583678027"}
0005432359554	D0AA6E	3738 710450	PAVEL ROMANOV	{"email": "romanov.p.091980@postgrespro.ru", "phone": "+70999697167"}
0005432359555	D0AA6E	3945 099264	EVGENIY PAVLOV	{"email": "pavlovevgeniy1975@postgrespro.ru", "phone": "+70884527297"}
0005432359556	507FC2	8678 981606	YULIYA PETROVA	{"phone": "+70603904323"}
0005432359557	088FFA	0523 877154	VITALIY MATVEEV	{"phone": "+70094462909"}
0005432359558	088FFA	0699 464819	PAVEL NAUMOV	{"phone": "+70555098972"}
0005432359559	CA7A16	0831 202863	ANDREY RODIONOV	{"phone": "+70104468594"}
0005432359560	A16651	1180 692072	MARIYA SOLOVEVA	{"phone": "+70716469777"}
0005432359561	7DA097	9238 853368	VLADIMIR ANTONOV	{"email": "v.antonov-1977@postgrespro.ru", "phone": "+70783014040"}
0005432359562	12945E	4098 855316	MIKHAIL KONOVALOV	{"email": "konovalov-m_1968@postgrespro.ru", "phone": "+70598647754"}
0005432359563	12945E	7044 722015	YULIYA KULIKOVA	{"email": "ykulikova_111968@postgrespro.ru", "phone": "+70791712561"}
0005432359564	D31DD4	4020 649195	VITALIY ALEKSEEV	{"phone": "+70238227566"}
0005432359565	D31DD4	7217 886902	TATYANA MALYSHEVA	{"email": "malysheva-tatyana-091974@postgrespro.ru", "phone": "+70505856572"}
0005432359566	C93478	6323 660529	VERA KULIKOVA	{"phone": "+70122736434"}
0005432359567	8D0730	8921 530751	ALINA POPOVA	{"phone": "+70463774945"}
0005432359568	890D39	2065 859238	MIKHAIL DAVYDOV	{"phone": "+70455960800"}
0005432359569	890D39	8006 526340	ANNA NAZAROVA	{"email": "nazarova.anna-041964@postgrespro.ru", "phone": "+70896605590"}
0005432359570	BB0AEB	7212 139281	RAISA DMITRIEVA	{"phone": "+70376777291"}
0005432359571	255C10	3490 209948	EKATERINA NIKOLAEVA	{"phone": "+70689843248"}
0005432359572	D6C1DA	0222 738066	YULIYA KUZMINA	{"email": "y.kuzmina.10101963@postgrespro.ru", "phone": "+70805007188"}
0005432359573	D6C1DA	2294 229004	OLEG NOVIKOV	{"phone": "+70241434544"}
0005432359574	7C9273	8980 547230	MIKHAIL SIDOROV	{"email": "sidorovmikhail_1981@postgrespro.ru", "phone": "+70837740984"}
0005432359575	454183	3568 474750	MIKHAIL KONOVALOV	{"phone": "+70724737132"}
0005432359576	454183	0219 567746	MIKHAIL ROMANOV	{"email": "romanovmikhail1975@postgrespro.ru", "phone": "+70059435396"}
0005432359577	8F80E8	6485 274059	SVETLANA BARANOVA	{"email": "svetlanabaranova_081984@postgrespro.ru", "phone": "+70013764961"}
0005432359578	8F80E8	8632 037971	OKSANA ORLOVA	{"phone": "+70262607305"}
0005432359579	361450	9394 310811	RAISA SCHERBAKOVA	{"email": "scherbakova.raisa-09031969@postgrespro.ru", "phone": "+70104500425"}
0005432359580	361450	5161 204126	ELENA ISAEVA	{"email": "e_isaeva.1975@postgrespro.ru", "phone": "+70885689276"}
0005432359581	361450	6478 059390	EVGENIY SAVELEV	{"email": "evgeniy.savelev29071970@postgrespro.ru", "phone": "+70116614972"}
0005432359582	61D920	1129 494801	ALISA PETROVA	{"phone": "+70685660384"}
0005432359583	61D920	2406 254623	DIANA ROMANOVA	{"email": "romanova.d.1971@postgrespro.ru", "phone": "+70059476620"}
0005432359584	B4F720	8640 377460	OLESYA SMIRNOVA	{"email": "o_smirnova.1967@postgrespro.ru", "phone": "+70886802419"}
0005432359585	FD4335	6673 646441	IVAN ALEKSEEV	{"phone": "+70773245721"}
0005432359586	FD4335	1143 472518	NINA ISAEVA	{"phone": "+70275247861"}
0005432359587	850795	6733 487858	VALENTINA FROLOVA	{"email": "frolova.valentina_1978@postgrespro.ru", "phone": "+70371721736"}
0005432359588	A94D79	0434 939398	YULIYA SOROKINA	{"phone": "+70735474209"}
0005432359589	CB004C	0247 776653	VLADISLAV MAKSIMOV	{"email": "vmaksimov.011974@postgrespro.ru", "phone": "+70044908982"}
0005432359590	A0C693	1524 460397	LEONID KOZLOV	{"phone": "+70864905343"}
0005432359591	E9949B	2492 075028	SVETLANA NIKOLAEVA	{"phone": "+70382404252"}
0005432359592	038AAF	3457 127041	ANDREY PETROV	{"phone": "+70777662105"}
0005432359593	038AAF	7174 651787	RAFIK GRIGOREV	{"phone": "+70498929082"}
0005432359594	C2CF04	2998 925835	RUSLAN SCHERBAKOV	{"email": "r.scherbakov_05121975@postgrespro.ru", "phone": "+70675039603"}
0005432359595	869F25	6513 190979	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov_061972@postgrespro.ru", "phone": "+70460377875"}
0005432359596	869F25	7669 744275	VLADIMIR VASILEV	{"email": "vladimir.vasilev111976@postgrespro.ru", "phone": "+70160529728"}
0005432359597	C3CA04	7402 074466	PAVEL NOVIKOV	{"phone": "+70019301196"}
0005432359598	2B1393	5005 608874	NATALYA FOMINA	{"email": "natalya_fomina.1964@postgrespro.ru", "phone": "+70944664481"}
0005432359599	2B1393	7059 972279	IVAN FEDOROV	{"email": "i.fedorov.011970@postgrespro.ru", "phone": "+70991830109"}
0005432359600	F3327F	6651 925075	MARIYA BARANOVA	{"phone": "+70425518075"}
0005432359601	58550A	6120 344409	NINA LAZAREVA	{"phone": "+70724140282"}
0005432359602	6B7D1D	3011 428682	DARYA GERASIMOVA	{"email": "gerasimovad.071976@postgrespro.ru", "phone": "+70366488239"}
0005432359603	14C7A2	6333 509000	ANTON CHERNOV	{"phone": "+70131006856"}
0005432359604	C634C8	6251 761905	MIKHAIL ROMANOV	{"phone": "+70372353201"}
0005432359605	C634C8	0765 443483	LARISA MELNIKOVA	{"email": "melnikova.l_121953@postgrespro.ru", "phone": "+70999591985"}
0005432359606	0BF0E6	8539 332993	VASILIY ANTONOV	{"email": "antonovv_031973@postgrespro.ru", "phone": "+70752371338"}
0005432359607	0BF0E6	1561 965351	ALEVTINA KUZMINA	{"phone": "+70081441689"}
0005432359608	AB1F25	9795 594432	ANTONINA GUSEVA	{"phone": "+70069344779"}
0005432359609	8F64D6	6438 434544	DARYA ROMANOVA	{"email": "romanova.d-051977@postgrespro.ru", "phone": "+70053365737"}
0005432359610	8F64D6	1410 365004	ANNA BORISOVA	{"phone": "+70311143530"}
0005432359611	8F64D6	3786 912504	ANNA ERMAKOVA	{"email": "anna.ermakova-021975@postgrespro.ru", "phone": "+70479077570"}
0005432359612	1B35CA	9132 328151	MAKSIM OSIPOV	{"phone": "+70625120919"}
0005432359613	D02174	1011 426378	GALINA FEDOROVA	{"email": "g-fedorova-1972@postgrespro.ru", "phone": "+70516519730"}
0005432359614	D02174	5675 602696	EVGENIY KUZNECOV	{"phone": "+70099367502"}
0005432359615	4EEBC5	8876 904376	ARTEM MIRONOV	{"email": "artemmironov21081978@postgrespro.ru", "phone": "+70258682255"}
0005432359616	4EEBC5	2111 648507	VALERIY KOZLOV	{"email": "kozlovvaleriy1974@postgrespro.ru", "phone": "+70772791815"}
0005432359617	7C87CA	9593 673825	GENNADIY KUZNECOV	{"email": "g-kuznecov-1968@postgrespro.ru", "phone": "+70701103489"}
0005432359618	D84DB5	8544 792018	YAROSLAV GERASIMOV	{"email": "yaroslav_gerasimov.1968@postgrespro.ru", "phone": "+70142785703"}
0005432359619	8DB850	6041 110051	VADIM KUZNECOV	{"email": "v.kuznecov.081977@postgrespro.ru", "phone": "+70030891435"}
0005432359620	BEE131	3768 649671	ALEKSANDR ORLOV	{"email": "orlova-111979@postgrespro.ru", "phone": "+70790528881"}
0005432359621	BEE131	1185 645688	TAMARA ERMAKOVA	{"email": "ermakova_tamara.1971@postgrespro.ru", "phone": "+70043082408"}
0005432359622	2449E6	2464 389968	POLINA SOROKINA	{"email": "sorokina_p_121975@postgrespro.ru", "phone": "+70545245716"}
0005432359623	2449E6	4579 315180	IGOR DMITRIEV	{"email": "igor-dmitriev17121978@postgrespro.ru", "phone": "+70766014840"}
0005432359624	16CBBE	9531 369639	OLEG KULIKOV	{"email": "kulikov-oleg-25051966@postgrespro.ru", "phone": "+70323592965"}
0005432359625	16CBBE	7247 277897	ZOYA FILATOVA	{"email": "filatova-zoya-1964@postgrespro.ru", "phone": "+70818662579"}
0005432359626	86E7CB	5323 757325	ANASTASIYA BOGDANOVA	{"phone": "+70807475955"}
0005432359627	0CE5A3	1533 742204	VYACHESLAV KAZAKOV	{"email": "vyacheslavkazakov021978@postgrespro.ru", "phone": "+70326384791"}
0005432359628	0CE5A3	1916 697519	SERGEY KAZAKOV	{"email": "kazakov-s_041980@postgrespro.ru", "phone": "+70203504348"}
0005432359629	80A8AD	4444 005245	ANNA SEMENOVA	{"phone": "+70858382099"}
0005432359630	2775D0	6292 770922	NATALYA MEDVEDEVA	{"email": "medvedeva_natalya_13081971@postgrespro.ru", "phone": "+70985800345"}
0005432359631	6636AF	9482 934064	TAISIYA MAKSIMOVA	{"email": "taisiyamaksimova_1966@postgrespro.ru", "phone": "+70437202671"}
0005432359632	6636AF	7556 985421	NATALYA NESTEROVA	{"email": "nesterova.natalya.061973@postgrespro.ru", "phone": "+70357803535"}
0005432359633	085673	3884 093050	ANATOLIY BORISOV	{"email": "a.borisov-091980@postgrespro.ru", "phone": "+70148240953"}
0005432359634	085673	9330 361172	ANASTASIYA TIMOFEEVA	{"email": "anastasiya_timofeeva03111982@postgrespro.ru", "phone": "+70607645207"}
0005432359635	085673	4332 217026	MARIYA ALEKSEEVA	{"email": "m_alekseeva_23011975@postgrespro.ru", "phone": "+70827275600"}
0005432359636	105D82	2437 982564	KONSTANTIN CHERNOV	{"email": "konstantin_chernov_051969@postgrespro.ru", "phone": "+70047495472"}
0005432359637	105D82	4646 730414	LIDIYA RODIONOVA	{"phone": "+70907472759"}
0005432359638	8B63A6	2564 224339	SERGEY ZHUKOV	{"phone": "+70747453808"}
0005432359639	8B63A6	0551 779659	OKSANA SEMENOVA	{"email": "osemenova-04071954@postgrespro.ru", "phone": "+70187263267"}
0005432359640	45C7F8	3419 112954	IVAN SOKOLOV	{"email": "i_sokolov-061970@postgrespro.ru", "phone": "+70001053849"}
0005432359641	7A5C3F	9644 061426	PAVEL FOMIN	{"email": "p-fomin_1980@postgrespro.ru", "phone": "+70633436668"}
0005432359642	1BF36A	6489 883108	OLGA MELNIKOVA	{"phone": "+70516858780"}
0005432359643	961FBB	0392 493137	EVGENIYA SMIRNOVA	{"email": "smirnova-evgeniya_08071981@postgrespro.ru", "phone": "+70300948238"}
0005432359644	181A56	6868 983104	ELENA DMITRIEVA	{"email": "e-dmitrieva1969@postgrespro.ru", "phone": "+70586219022"}
0005432359645	181A56	7143 428487	NIKITA FEDOROV	{"email": "fedorov.nikita061970@postgrespro.ru", "phone": "+70385158541"}
0005432359646	4B2339	3329 906871	VENIAMIN MOROZOV	{"phone": "+70226151844"}
0005432359647	4B2339	4815 113420	ELENA RYABOVA	{"email": "e-ryabova_13081972@postgrespro.ru", "phone": "+70478372172"}
0005432359648	A615EF	9197 011104	VALENTINA MAKAROVA	{"email": "valentina.makarova051983@postgrespro.ru", "phone": "+70305078300"}
0005432359649	A615EF	8166 949631	OLGA BORISOVA	{"email": "borisova.olga-1966@postgrespro.ru", "phone": "+70903245448"}
0005432359650	534134	2556 922739	TATYANA SMIRNOVA	{"email": "smirnova-t031967@postgrespro.ru", "phone": "+70002767627"}
0005432359651	43593B	6883 001500	ANNA MOROZOVA	{"phone": "+70573389704"}
0005432359652	A27BC8	7150 649324	PAVEL ANDREEV	{"phone": "+70903946342"}
0005432359653	73C36B	6778 915026	VLADIMIR POPOV	{"phone": "+70503688605"}
0005432359654	661D0E	7437 707475	DENIS NIKOLAEV	{"email": "d-nikolaev.111983@postgrespro.ru", "phone": "+70049388991"}
0005432359655	21AF25	3067 622713	ARINA NAZAROVA	{"phone": "+70719603216"}
0005432359656	B12F18	0628 290689	OLGA NIKOLAEVA	{"phone": "+70545738568"}
0005432359657	7E7C75	3660 184943	TATYANA SIDOROVA	{"email": "tatyana-sidorova_21061984@postgrespro.ru", "phone": "+70744642901"}
0005432359658	140873	9491 063102	VADIM BARANOV	{"phone": "+70255124611"}
0005432359659	140873	2670 406778	POLINA KOVALEVA	{"phone": "+70384766810"}
0005432359660	83E540	9534 222015	ROMAN FILIPPOV	{"email": "roman.filippov-1976@postgrespro.ru", "phone": "+70517628226"}
0005432359661	C15272	6708 940796	IGOR ALEKSEEV	{"phone": "+70588336495"}
0005432359662	C15272	0764 222756	SERGEY PETROV	{"phone": "+70887674128"}
0005432359663	9596D6	6880 409707	ALEKSEY BELOV	{"email": "a_belov-071968@postgrespro.ru", "phone": "+70399811054"}
0005432359664	F3242B	2498 528570	NINA NESTEROVA	{"phone": "+70799230555"}
0005432359665	CB5550	8132 364844	GENNADIY FROLOV	{"email": "g.frolov.29101977@postgrespro.ru", "phone": "+70850535255"}
0005432359666	CB5550	2286 101909	VALENTINA ZAKHAROVA	{"email": "zakharova-v-021983@postgrespro.ru", "phone": "+70632224641"}
0005432359667	44F8E9	0684 289968	ALEKSANDR MARTYNOV	{"email": "martynov_a.02081968@postgrespro.ru", "phone": "+70478417622"}
0005432359668	B2B172	6075 718465	ARTEM TARASOV	{"email": "artem_tarasov_1963@postgrespro.ru", "phone": "+70488737689"}
0005432359669	B2B172	3225 072369	ALEKSANDR KAZAKOV	{"email": "kazakov.a.011974@postgrespro.ru", "phone": "+70504646717"}
0005432359670	E41A1E	4180 919692	SERGEY ALEKSEEV	{"phone": "+70019696498"}
0005432359671	548AFF	7029 646504	OLGA SIDOROVA	{"phone": "+70964682918"}
0005432359672	07A92B	9460 450649	VALERIY AFANASEV	{"email": "afanasev-v_1972@postgrespro.ru", "phone": "+70828388793"}
0005432359673	9B1FE6	9413 500797	ALEVTINA BORISOVA	{"email": "alevtina.borisova-1986@postgrespro.ru", "phone": "+70147845300"}
0005432359674	9B1FE6	4785 437737	LIDIYA MIKHAYLOVA	{"email": "mikhaylova-lidiya_1972@postgrespro.ru", "phone": "+70491374353"}
0005432359675	206C1A	6216 675350	TATYANA ZAKHAROVA	{"phone": "+70730877927"}
0005432359676	E849E6	6224 440856	LYUBOV KOROLEVA	{"email": "koroleva-l1967@postgrespro.ru", "phone": "+70178460009"}
0005432359677	73D075	6411 154932	TIMOFEY MAKAROV	{"email": "timofey_makarov.101989@postgrespro.ru", "phone": "+70116140956"}
0005432359678	3F373B	5725 721277	VYACHESLAV ANDREEV	{"email": "andreev_vyacheslav.08081974@postgrespro.ru", "phone": "+70094671841"}
0005432359679	3F373B	5848 991690	ARINA IVANOVA	{"phone": "+70351906548"}
0005432359680	3F373B	9297 532169	NATALYA CHERNOVA	{"email": "chernova-natalya_17021963@postgrespro.ru", "phone": "+70790281264"}
0005432359681	74ADCE	9236 537746	ANNA IVANOVA	{"phone": "+70057486875"}
0005432359682	50DB2F	3902 443932	MAKSIM MIKHAYLOV	{"email": "mikhaylovm-051982@postgrespro.ru", "phone": "+70419198271"}
0005432359683	50DB2F	6225 838741	NATALYA BORISOVA	{"email": "borisova_n_121956@postgrespro.ru", "phone": "+70305386379"}
0005432359684	83B9CC	4797 726441	IGOR TIMOFEEV	{"phone": "+70877086583"}
0005432359685	DBBF42	6663 331492	NATALYA IVANOVA	{"email": "ivanova-n_081978@postgrespro.ru", "phone": "+70090528118"}
0005432359686	1F337A	1211 762300	OLESYA ANTONOVA	{"email": "antonova-o-01031970@postgrespro.ru", "phone": "+70808380293"}
0005432359687	9A6D73	7358 231640	NIKOLAY KUZMIN	{"email": "kuzmin_n.18101965@postgrespro.ru", "phone": "+70567707544"}
0005432359688	9A6D73	6494 712025	ANASTASIYA NIKOLAEVA	{"email": "nikolaeva.a-041978@postgrespro.ru", "phone": "+70592095504"}
0005432359689	9A6D73	3713 720894	ARTUR SHEVCHENKO	{"phone": "+70618069564"}
0005432359690	17F900	0658 857540	LYUDMILA STEPANOVA	{"phone": "+70046428657"}
0005432359691	6281A2	9841 320514	ARTEM KULIKOV	{"email": "kulikova_061973@postgrespro.ru", "phone": "+70818581974"}
0005432359692	6281A2	7944 317795	ALEKSANDR FILIPPOV	{"phone": "+70978886716"}
0005432359693	EA541A	7284 264167	ANNA DANILOVA	{"email": "danilova.anna.1969@postgrespro.ru", "phone": "+70317972454"}
0005432359694	E075BC	4468 504591	VLADIMIR MELNIKOV	{"phone": "+70611329365"}
0005432359695	E075BC	0783 613671	ELENA SAVELEVA	{"email": "elena.saveleva-011974@postgrespro.ru", "phone": "+70347025249"}
0005432359696	844382	2926 562570	ANNA ANTONOVA	{"phone": "+70082292498"}
0005432359697	40972D	9025 327262	LYUBOV VOLKOVA	{"email": "lyubov-volkova.091976@postgrespro.ru", "phone": "+70297363619"}
0005432359698	593E63	9184 275224	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov_15091983@postgrespro.ru", "phone": "+70071279144"}
0005432359699	4328C3	2244 611864	DANILA SOKOLOV	{"email": "danila.sokolov_071974@postgrespro.ru", "phone": "+70703819463"}
0005432359700	3A9EEA	1701 160530	NIKOLAY SOLOVEV	{"email": "nikolay-solovev-1979@postgrespro.ru", "phone": "+70247345497"}
0005432359701	E3D39C	5551 635545	ALEKSANDR KUZNECOV	{"email": "a.kuznecov_10091977@postgrespro.ru", "phone": "+70921346167"}
0005432359702	63A0D2	9500 007450	TAMARA NAZAROVA	{"email": "nazarova_t1968@postgrespro.ru", "phone": "+70777377152"}
0005432359703	63A0D2	7187 800909	SERGEY GERASIMOV	{"phone": "+70545634465"}
0005432359704	1BE469	2081 589213	TATYANA IVANOVA	{"phone": "+70115545927"}
0005432359705	F8D7CA	3208 061955	ALEKSEY MIRONOV	{"email": "amironov_111972@postgrespro.ru", "phone": "+70855463416"}
0005432359706	F8D7CA	3968 268527	NINA BELYAEVA	{"email": "nbelyaeva.1980@postgrespro.ru", "phone": "+70257352568"}
0005432359707	4F9DA7	5408 025916	SVETLANA IVANOVA	{"email": "s_ivanova-011973@postgrespro.ru", "phone": "+70705465584"}
0005432359708	AFBD7A	5590 386412	DMITRIY ZAKHAROV	{"email": "zakharov-d_091966@postgrespro.ru", "phone": "+70988765471"}
0005432359709	BD42AF	9415 166620	SERGEY DMITRIEV	{"phone": "+70625403679"}
0005432359710	0CF03C	2292 920008	EVDOKIYA VASILEVA	{"email": "evdokiya_vasileva-23051977@postgrespro.ru", "phone": "+70023504420"}
0005432359711	ABF046	6263 396994	EVGENIYA TROFIMOVA	{"email": "trofimova-evgeniya.1972@postgrespro.ru", "phone": "+70855817407"}
0005432359712	4CDA07	1913 235142	EKATERINA KUDRYASHOVA	{"email": "e_kudryashova1967@postgrespro.ru", "phone": "+70324596048"}
0005432359713	4CDA07	9610 573948	SERGEY DAVYDOV	{"phone": "+70946992110"}
0005432359714	9CA0C9	3175 847147	LYUDMILA TIKHONOVA	{"phone": "+70446956920"}
0005432359715	9CA0C9	9389 251325	NIKOLAY OSIPOV	{"phone": "+70954504909"}
0005432359716	9CA0C9	6143 691395	NINA POPOVA	{"email": "n.popova-22091964@postgrespro.ru", "phone": "+70734113536"}
0005432359717	9D4491	1811 639339	GALINA BELOVA	{"email": "g.belova_091963@postgrespro.ru", "phone": "+70232569640"}
0005432359718	CC2F00	5625 955394	MIKHAIL MAKAROV	{"phone": "+70970614505"}
0005432359719	077B78	1465 812590	YURIY KARPOV	{"phone": "+70759012008"}
0005432359720	549ADA	2617 438837	SERGEY KUZMIN	{"email": "kuzmin-s-101962@postgrespro.ru", "phone": "+70974932146"}
0005432359721	633807	1485 793399	OLGA ZAKHAROVA	{"phone": "+70255961379"}
0005432359722	633807	9055 087295	EKATERINA LOGINOVA	{"phone": "+70402552645"}
0005432359723	3351E3	6213 062186	NIKOLAY MOROZOV	{"phone": "+70641059025"}
0005432359724	3351E3	5861 923085	LYUBOV KOZLOVA	{"email": "kozlova-lyubov.1974@postgrespro.ru", "phone": "+70854965530"}
0005432359725	A7A6B0	3333 539768	MARK IVANOV	{"email": "ivanov.m1967@postgrespro.ru", "phone": "+70864250093"}
0005432359726	E14410	6508 725414	ANDREY ANDREEV	{"email": "andreeva_21061959@postgrespro.ru", "phone": "+70011667444"}
0005432359727	6678DE	9567 481166	NIKOLAY ANTONOV	{"email": "n.antonov.1978@postgrespro.ru", "phone": "+70370077183"}
0005432359728	6678DE	1276 222332	ALEKSANDR OSIPOV	{"email": "aleksandrosipov.16121976@postgrespro.ru", "phone": "+70925592612"}
0005432359729	2017FD	1420 474344	NIKOLAY DENISOV	{"phone": "+70083515561"}
0005432359730	2017FD	9370 549347	VALENTINA NIKOLAEVA	{"email": "nikolaeva-v.021970@postgrespro.ru", "phone": "+70323076968"}
0005432359731	F0C25A	3559 473104	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr.121987@postgrespro.ru", "phone": "+70039406295"}
0005432359732	327215	4325 673276	SERGEY PETROV	{"phone": "+70267855163"}
0005432359733	327215	9570 044922	ELENA POPOVA	{"phone": "+70105924924"}
0005432359734	2BD07C	7263 229856	ILDAR ROMANOV	{"phone": "+70026773491"}
0005432359735	5F8D32	1216 002947	ANTON NAZAROV	{"phone": "+70355983728"}
0005432359736	5F8D32	8617 739544	OLEG ABRAMOV	{"phone": "+70784412370"}
0005432359737	97FB58	8923 860145	YURIY KISELEV	{"phone": "+70134890704"}
0005432359738	990FF0	9068 474159	VLADISLAV KRASNOV	{"email": "vladislav.krasnov.12051994@postgrespro.ru", "phone": "+70355244581"}
0005432359739	20A638	0582 524342	DINA MAKAROVA	{"email": "makarova_dina_31071965@postgrespro.ru", "phone": "+70968437863"}
0005432359740	20A638	4729 876367	IVAN KUZNECOV	{"email": "i.kuznecov11111970@postgrespro.ru", "phone": "+70967746742"}
0005432359741	0008FD	9570 262081	NATALYA KRASNOVA	{"phone": "+70958414163"}
0005432359742	67F1C4	0012 003591	ALINA ZAYCEVA	{"email": "zayceva-alina.071976@postgrespro.ru", "phone": "+70057944838"}
0005432359743	0B741A	4299 563012	VALENTINA KUZNECOVA	{"email": "vkuznecova-1970@postgrespro.ru", "phone": "+70456596082"}
0005432359744	0B741A	3628 418622	NIKOLAY SERGEEV	{"phone": "+70417344058"}
0005432359745	B90883	1939 071489	NATALYA DANILOVA	{"email": "n.danilova_1972@postgrespro.ru", "phone": "+70697865870"}
0005432359746	B90883	7036 219852	ALEKSANDR ABRAMOV	{"email": "abramovaleksandr-1976@postgrespro.ru", "phone": "+70383370348"}
0005432359747	B90883	4664 867054	YURIY DMITRIEV	{"phone": "+70316635393"}
0005432359748	4B9F80	0676 007383	SERGEY KUZMIN	{"phone": "+70671244199"}
0005432359749	E1CBC0	2633 496648	ELENA VOLKOVA	{"phone": "+70739806057"}
0005432359750	E1CBC0	5908 902438	NIKITA FOMIN	{"email": "n_fomin_06061969@postgrespro.ru", "phone": "+70822862905"}
0005432359751	2D37DC	2339 848952	ALEKSEY SOROKIN	{"phone": "+70864945621"}
0005432359752	2D37DC	1447 914326	VLADIMIR KOZLOV	{"email": "v_kozlov_081963@postgrespro.ru", "phone": "+70080971455"}
0005432359753	E0011E	3361 825723	VERA KUZNECOVA	{"email": "kuznecova_vera1975@postgrespro.ru", "phone": "+70889950730"}
0005432359754	7F7A90	6531 548316	ALEKSEY NOVIKOV	{"email": "anovikov.031972@postgrespro.ru", "phone": "+70407784213"}
0005432359755	7F7A90	4536 436853	VERA FILIPPOVA	{"phone": "+70101732184"}
0005432359756	E7E43A	0381 697126	OKSANA SAVELEVA	{"phone": "+70148590059"}
0005432359757	4AC3E8	8584 485403	VIKTOR KRASNOV	{"email": "viktorkrasnov.06031978@postgrespro.ru", "phone": "+70689370236"}
0005432359758	4AC3E8	3945 823674	NINA GRISHINA	{"email": "n-grishina.28011978@postgrespro.ru", "phone": "+70477997647"}
0005432359759	CC5452	1735 149475	LILIYA TIMOFEEVA	{"email": "timofeeva.l-19041965@postgrespro.ru", "phone": "+70501268321"}
0005432359760	CC5452	9816 284657	VIKTOR KOROLEV	{"email": "korolevv.07021970@postgrespro.ru", "phone": "+70349050740"}
0005432359761	CC5452	9608 536804	LUIZA EGOROVA	{"phone": "+70365173575"}
0005432359762	4EA4E3	4484 195432	VASILIY SEMENOV	{"email": "semenovv_23031965@postgrespro.ru", "phone": "+70656197633"}
0005432359763	6EF8F4	4043 457609	SERGEY PETROV	{"email": "petrov.s-1973@postgrespro.ru", "phone": "+70492285750"}
0005432359764	3F7FF5	0857 795175	RAFIK PETROV	{"email": "petrov-r.1972@postgrespro.ru", "phone": "+70368470588"}
0005432359765	3F7FF5	1873 204078	OLEG BONDARENKO	{"phone": "+70361103787"}
0005432359766	9499FA	6201 784578	TATYANA SOKOLOVA	{"email": "tatyanasokolova_30101965@postgrespro.ru", "phone": "+70897286145"}
0005432359767	9499FA	7732 477275	TIMOFEY YAKOVLEV	{"email": "yakovlev-t061969@postgrespro.ru", "phone": "+70369548857"}
0005432359768	9499FA	4120 819093	SERGEY KUZMIN	{"email": "sergey-kuzmin.011992@postgrespro.ru", "phone": "+70197639738"}
0005432359769	24C318	0296 860480	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_a051980@postgrespro.ru", "phone": "+70082543485"}
0005432359770	C37A41	3443 516598	EKATERINA ZAYCEVA	{"phone": "+70106862346"}
0005432359771	5140C5	4403 797597	IGOR ANTONOV	{"email": "antonov_i-03091952@postgrespro.ru", "phone": "+70135554937"}
0005432359772	992C3D	4782 601385	OLGA ANDREEVA	{"phone": "+70187161162"}
0005432359773	992C3D	6075 656158	YULIYA ORLOVA	{"phone": "+70241865626"}
0005432359774	DF7DCF	1563 752914	GALINA ALEKSEEVA	{"email": "galina-alekseeva.101961@postgrespro.ru", "phone": "+70003147546"}
0005432359775	60E750	7843 055722	VALENTINA GUSEVA	{"phone": "+70759524560"}
0005432359776	60E750	4266 752876	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr_25071975@postgrespro.ru", "phone": "+70435602840"}
0005432359777	884E8F	5981 268025	ELENA VASILEVA	{"phone": "+70872433751"}
0005432359778	F43853	3193 548714	VALENTINA KONDRATEVA	{"email": "valentina_kondrateva1973@postgrespro.ru", "phone": "+70725986583"}
0005432359779	F43853	6107 703391	MARIYA ANDREEVA	{"email": "andreevamariya-1966@postgrespro.ru", "phone": "+70321799574"}
0005432359780	13D0FF	9730 245058	VALERIY DAVYDOV	{"email": "v.davydov-061986@postgrespro.ru", "phone": "+70920943612"}
0005432359781	3D67FA	2241 869915	GALINA LOGINOVA	{"phone": "+70259361121"}
0005432359782	E0BAAE	0539 974020	MARIYA GORBUNOVA	{"email": "gorbunova.mariya.071960@postgrespro.ru", "phone": "+70079131475"}
0005432359783	E0BAAE	0018 769407	IRINA SIDOROVA	{"phone": "+70270221501"}
0005432359784	403295	2474 430914	VASILIY POPOV	{"phone": "+70205605792"}
0005432359785	403295	3762 738587	VALENTINA OSIPOVA	{"email": "osipova-v.121989@postgrespro.ru", "phone": "+70351558545"}
0005432359786	8DA939	7237 639503	MAYYA ROMANOVA	{"email": "romanova-m.13091961@postgrespro.ru", "phone": "+70060764456"}
0005432359787	7A3FEA	4266 635074	KONSTANTIN ABRAMOV	{"phone": "+70255008027"}
0005432359788	7A3FEA	9198 598390	VALENTINA PAVLOVA	{"email": "pavlovavalentina_07021964@postgrespro.ru", "phone": "+70524259933"}
0005432359789	5BC851	7291 562545	ROMAN MELNIKOV	{"email": "rmelnikov-11071977@postgrespro.ru", "phone": "+70064556021"}
0005432359790	5BC851	4823 986845	OLGA MASLOVA	{"email": "olgamaslova_18061975@postgrespro.ru", "phone": "+70063423582"}
0005432359791	36EC49	6860 841816	NIKOLAY GRIGOREV	{"phone": "+70117195565"}
0005432359792	36EC49	0517 103399	NADEZHDA FROLOVA	{"phone": "+70887632522"}
0005432359793	730BC3	7034 752483	ANDREY KOROLEV	{"email": "andrey.korolev18091979@postgrespro.ru", "phone": "+70862225959"}
0005432359794	FFF9E3	4607 233816	ANDREY KONOVALOV	{"phone": "+70141569266"}
0005432359795	4E98FC	3942 864197	OKSANA KARPOVA	{"email": "karpova-oksana1976@postgrespro.ru", "phone": "+70933469764"}
0005432359796	4E98FC	6257 989559	MIKHAIL KISELEV	{"email": "kiselev.mikhail111961@postgrespro.ru", "phone": "+70123615010"}
0005432359797	7BF428	6629 586203	RUSLAN ZHUKOV	{"phone": "+70850514151"}
0005432359798	096EA5	2941 875855	NIKOLAY MEDVEDEV	{"email": "medvedev_nikolay.091976@postgrespro.ru", "phone": "+70765496701"}
0005432359799	051EE6	6527 059545	VYACHESLAV IVANOV	{"phone": "+70473511491"}
0005432359800	C34BD8	3379 836550	ANATOLIY ISAEV	{"email": "a-isaev_011965@postgrespro.ru", "phone": "+70014447545"}
0005432359801	D8A99B	4934 300553	TATYANA ALEKSEEVA	{"email": "alekseevatatyana-08081952@postgrespro.ru", "phone": "+70681591871"}
0005432359802	0FA11B	5524 473188	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr021979@postgrespro.ru", "phone": "+70139515804"}
0005432359803	0FA11B	0171 315920	ELENA PAVLOVA	{"email": "pavlovaelena_28071977@postgrespro.ru", "phone": "+70826124224"}
0005432359804	0FA11B	5440 301480	YURIY MIKHAYLOV	{"email": "mikhaylov-y1967@postgrespro.ru", "phone": "+70746182266"}
0005432359805	5F0AAC	1426 057843	ELEONORA NAZAROVA	{"email": "nazarova-e-31011972@postgrespro.ru", "phone": "+70048401080"}
0005432359806	B2351C	5818 455427	EDUARD GUSEV	{"email": "e-gusev-21011976@postgrespro.ru", "phone": "+70366155729"}
0005432359807	C31E6A	1291 336886	NATALYA MALYSHEVA	{"phone": "+70189466203"}
0005432359808	E4FCD5	0335 993701	DILYARA KUZNECOVA	{"email": "d.kuznecova.041966@postgrespro.ru", "phone": "+70717533836"}
0005432359809	8A4D2D	3480 075163	IVAN ALEKSEEV	{"phone": "+70007495252"}
0005432359810	0FF838	3504 741208	VERA VASILEVA	{"phone": "+70550417406"}
0005432359811	459A0A	0237 492942	OLEG NAZAROV	{"email": "olegnazarov-14091973@postgrespro.ru", "phone": "+70929953561"}
0005432359812	D62E6A	4057 934529	VLADIMIR GERASIMOV	{"phone": "+70660496625"}
0005432359813	041CF8	6895 240432	GALINA ZHURAVLEVA	{"phone": "+70439362014"}
0005432359814	D40E2E	2320 732795	NATALIYA SERGEEVA	{"phone": "+70873106906"}
0005432359815	D40E2E	9442 166741	ALEKSANDR PETROV	{"email": "a.petrov-1975@postgrespro.ru", "phone": "+70766235607"}
0005432359816	628C24	5179 559813	ALEKSANDR KAZAKOV	{"phone": "+70281140726"}
0005432359817	15BA60	3023 578889	ANATOLIY KOROLEV	{"phone": "+70016229607"}
0005432359818	B720DC	9464 812776	KRISTINA TARASOVA	{"phone": "+70764321256"}
0005432359819	B720DC	8514 465632	MARIYA VLASOVA	{"phone": "+70191037919"}
0005432359820	634592	6502 881019	MIKHAIL KARPOV	{"email": "karpov_m-091971@postgrespro.ru", "phone": "+70307463772"}
0005432359821	30BD62	0231 546075	YURIY ZAKHAROV	{"email": "zakharov_y-05041988@postgrespro.ru", "phone": "+70447543632"}
0005432359822	47537F	2523 766751	FEDOR KONOVALOV	{"email": "konovalov-fedor-101968@postgrespro.ru", "phone": "+70680209776"}
0005432359823	2538A3	8622 882465	MARGARITA ZOTOVA	{"phone": "+70855490032"}
0005432359824	F3D15C	5240 218437	MAKSIM POPOV	{"email": "popov_maksim18041976@postgrespro.ru", "phone": "+70416866182"}
0005432359825	083F2C	6249 574826	ANNA IVANOVA	{"email": "a-ivanova_121975@postgrespro.ru", "phone": "+70547632079"}
0005432359826	2D60C0	1051 123829	IVAN ANTONOV	{"email": "antonovi.101972@postgrespro.ru", "phone": "+70598469692"}
0005432359827	2D60C0	0739 472057	OLGA FOMINA	{"email": "o-fomina.111966@postgrespro.ru", "phone": "+70036915456"}
0005432359828	96F6D8	1253 110268	ELENA SCHERBAKOVA	{"phone": "+70209672853"}
0005432359829	C676C7	2055 852547	YURIY TARASOV	{"phone": "+70519464536"}
0005432359830	64DE78	6869 478526	ARTEM FROLOV	{"email": "afrolov.01081980@postgrespro.ru", "phone": "+70327216044"}
0005432359831	D381FD	5424 349308	ANTON SCHERBAKOV	{"phone": "+70969627050"}
0005432359832	CD8D35	4594 848716	NINA ILINA	{"email": "nina_ilina081979@postgrespro.ru", "phone": "+70259296785"}
0005432359833	A35B52	8545 930850	IVAN PETROV	{"email": "petrov.i18081954@postgrespro.ru", "phone": "+70964726555"}
0005432359834	F1ED33	9779 540147	SERGEY ALEKSANDROV	{"email": "sergeyaleksandrov-1979@postgrespro.ru", "phone": "+70760101155"}
0005432359835	02227B	0644 732233	EVGENIYA KUDRYASHOVA	{"phone": "+70710475621"}
0005432359836	02227B	1201 890891	RAISA LEBEDEVA	{"phone": "+70221861772"}
0005432359837	577EBB	2167 931079	SVETLANA PAVLOVA	{"phone": "+70107496152"}
0005432359838	872076	6249 545457	ANNA MAKAROVA	{"phone": "+70295804418"}
0005432359839	C25183	3964 319796	MIKHAIL SAVELEV	{"email": "savelev_mikhail1968@postgrespro.ru", "phone": "+70664572047"}
0005432359840	E973E8	5433 612096	ALEKSANDR FEDOTOV	{"phone": "+70712317449"}
0005432359841	E973E8	1727 403181	ELIZAVETA AKIMOVA	{"phone": "+70624249053"}
0005432359842	94BC65	9027 988830	VALENTINA GUSEVA	{"email": "gusevavalentina-041982@postgrespro.ru", "phone": "+70803399854"}
0005432359843	94BC65	6276 734675	TATYANA GUSEVA	{"phone": "+70661077288"}
0005432359844	AD2DE0	8351 888112	ALEKSANDR SEMENOV	{"phone": "+70562659794"}
0005432359845	024694	7025 510134	KIRILL STEPANOV	{"email": "k-stepanov.07061973@postgrespro.ru", "phone": "+70605513294"}
0005432359846	024694	1236 172089	LYUBOV KARPOVA	{"phone": "+70400714880"}
0005432359847	7D30DC	3605 906548	IVAN GRIGOREV	{"email": "ivan.grigorev_1982@postgrespro.ru", "phone": "+70227891714"}
0005432359848	D2C772	8953 783298	TATYANA NAZAROVA	{"email": "t-nazarova_041971@postgrespro.ru", "phone": "+70550258354"}
0005432359849	D2C772	2647 432378	SERGEY KAZAKOV	{"email": "s-kazakov.23031967@postgrespro.ru", "phone": "+70502056545"}
0005432359850	D2C772	4708 253534	ANTON NAZAROV	{"phone": "+70357210900"}
0005432359851	3BA388	9625 423986	ANNA EGOROVA	{"email": "egorova-anna.031979@postgrespro.ru", "phone": "+70701219611"}
0005432359852	3BA388	8399 286282	GALINA DAVYDOVA	{"email": "galina.davydova051972@postgrespro.ru", "phone": "+70560674669"}
0005432359853	3BA388	4246 263154	EDUARD RODIONOV	{"email": "e_rodionov_21021983@postgrespro.ru", "phone": "+70330408309"}
0005432359854	11E4D2	1482 756666	MILANA PAVLOVA	{"phone": "+70218727469"}
0005432359855	4A1A77	3849 265552	ANASTASIYA RYABOVA	{"email": "anastasiya.ryabova-25091974@postgrespro.ru", "phone": "+70225252051"}
0005432359856	CB6A4F	7537 128157	SERGEY VOLKOV	{"phone": "+70260102894"}
0005432359857	CB6A4F	3563 335303	ANDREY KISELEV	{"phone": "+70188728561"}
0005432359858	888788	3046 729144	VLADIMIR ZAKHAROV	{"phone": "+70764402761"}
0005432359859	888788	9298 357812	MAKSIM POPOV	{"email": "maksim_popov.1975@postgrespro.ru", "phone": "+70606151313"}
0005432359860	2A7004	2234 563603	MARIYA STEPANOVA	{"phone": "+70749986807"}
0005432359861	2A7004	0822 041632	TATYANA MOROZOVA	{"email": "tatyana.morozova09091967@postgrespro.ru", "phone": "+70128272519"}
0005432359862	2A7004	2868 265265	LYUBOV ROMANOVA	{"email": "lyubov_romanova-1974@postgrespro.ru", "phone": "+70608005317"}
0005432359863	737C04	0790 706998	VIKTOR GAVRILOV	{"email": "viktorgavrilov091985@postgrespro.ru", "phone": "+70626252432"}
0005432359864	6AED1D	2239 287680	VENERA GORBUNOVA	{"email": "v_gorbunova061973@postgrespro.ru", "phone": "+70006437225"}
0005432359865	6AED1D	4464 288014	SERGEY ZAKHAROV	{"email": "zakharov_sergey.1980@postgrespro.ru", "phone": "+70204517721"}
0005432359866	8D5FA9	0020 114550	ANDREY VOLKOV	{"email": "andrey-volkov121983@postgrespro.ru", "phone": "+70208178181"}
0005432359867	8D5FA9	6790 885349	MARIYA GUSEVA	{"phone": "+70720492551"}
0005432359868	5BAF68	5701 996095	ANDREY MAKAROV	{"phone": "+70437456130"}
0005432359869	BD2E07	8284 207185	TAMARA GAVRILOVA	{"email": "t_gavrilova_1968@postgrespro.ru", "phone": "+70748618777"}
0005432359870	BD2E07	6115 717658	OLEG KOROLEV	{"phone": "+70808162901"}
0005432359871	EB54BE	3496 633846	IRAIDA NAUMOVA	{"phone": "+70473228905"}
0005432359872	F1DEDE	5735 826967	EKATERINA ZAYCEVA	{"phone": "+70557706486"}
0005432359873	B11212	6420 373938	SERGEY ZAKHAROV	{"email": "zakharovsergey_061971@postgrespro.ru", "phone": "+70766090144"}
0005432359874	96E154	6583 284193	TATYANA MEDVEDEVA	{"email": "medvedeva_t.26011968@postgrespro.ru", "phone": "+70816421426"}
0005432359875	96E154	3963 623917	OLGA KOZLOVA	{"phone": "+70985907385"}
0005432359876	EDB95A	8045 755373	ALEKSEY ZAKHAROV	{"email": "a_zakharov12101983@postgrespro.ru", "phone": "+70478904868"}
0005432359877	6903C4	5475 242717	EKATERINA KUZMINA	{"email": "kuzmina-ekaterina1974@postgrespro.ru", "phone": "+70456552654"}
0005432359878	E905AB	4873 196516	VLADIMIR MIKHAYLOV	{"phone": "+70392207354"}
0005432359879	E905AB	5071 435814	ANZHELIKA EFREMOVA	{"email": "anzhelika.efremova1973@postgrespro.ru", "phone": "+70715204950"}
0005432359880	9BE7BA	2183 372119	ALEKSEY ANDREEV	{"phone": "+70179458119"}
0005432359881	9FDC15	9582 879103	MARIYA SOLOVEVA	{"email": "mariya.soloveva.1966@postgrespro.ru", "phone": "+70355951405"}
0005432359882	9FDC15	8575 934579	VADIM VOLKOV	{"phone": "+70151036601"}
0005432359883	9614D2	4975 008254	SERGEY CHERNOV	{"phone": "+70692160076"}
0005432359884	9614D2	1009 765168	SVETLANA RODIONOVA	{"email": "svetlanarodionova_14121970@postgrespro.ru", "phone": "+70500913961"}
0005432359885	B8CB62	3013 660928	LYUDMILA MARTYNOVA	{"phone": "+70881371886"}
0005432359886	09EFB2	7178 978481	TATYANA KONDRATEVA	{"phone": "+70733616719"}
0005432359887	4F2F07	3594 410672	PAVEL GAVRILOV	{"email": "p-gavrilov_111975@postgrespro.ru", "phone": "+70452455874"}
0005432359888	F523C4	1736 738674	LYUDMILA MAKAROVA	{"email": "makarova-l1975@postgrespro.ru", "phone": "+70377267414"}
0005432359889	F523C4	2446 142386	EVGENIY IVANOV	{"email": "e_ivanov.07061969@postgrespro.ru", "phone": "+70789980889"}
0005432359890	DB8BBA	5821 740417	ARTEM VASILEV	{"email": "artemvasilev-30031966@postgrespro.ru", "phone": "+70566204177"}
0005432359891	2FB0DD	7775 811089	SERGEY KOZLOV	{"email": "sergey_kozlov.091975@postgrespro.ru", "phone": "+70565919403"}
0005432359892	B314E2	1629 385226	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey15121967@postgrespro.ru", "phone": "+70802998085"}
0005432360115	0731D5	2817 304111	LYUDMILA ZHURAVLEVA	{"phone": "+70093573567"}
0005432359893	3BBCE7	0332 776468	YULIYA MAKSIMOVA	{"email": "yuliya.maksimova-07101976@postgrespro.ru", "phone": "+70999549587"}
0005432359894	B6D835	3517 026668	LYUBOV RYABOVA	{"email": "lyubovryabova.1978@postgrespro.ru", "phone": "+70861678574"}
0005432359895	E34E0E	5311 007786	IVAN ROMANOV	{"email": "ivan.romanov.1965@postgrespro.ru", "phone": "+70974105686"}
0005432359896	E34E0E	0054 758334	EKATERINA ZAKHAROVA	{"phone": "+70403608179"}
0005432359897	195FC4	7047 370460	VLADIMIR SIDOROV	{"phone": "+70839611515"}
0005432359898	C75070	1281 120148	SERGEY KAZAKOV	{"phone": "+70971093712"}
0005432359899	A5CBD9	1539 480728	VIKTOR EGOROV	{"phone": "+70479250662"}
0005432359900	0350D3	7694 055444	YURIY PAVLOV	{"phone": "+70353147829"}
0005432359901	A4204A	2579 511214	ELENA NAUMOVA	{"email": "naumova.elena.1969@postgrespro.ru", "phone": "+70388959223"}
0005432359902	0297E8	0559 635732	ALEKSANDRA TITOVA	{"email": "titova.a-011969@postgrespro.ru", "phone": "+70808005296"}
0005432359903	0297E8	5973 784741	LIDIYA BORISOVA	{"phone": "+70526914766"}
0005432359904	0297E8	8042 189920	ALEKSANDR ABRAMOV	{"email": "abramov_a-1968@postgrespro.ru", "phone": "+70070307222"}
0005432359905	6A9C1A	1505 034294	ALEKSANDR DAVYDOV	{"email": "aleksandr-davydov-1972@postgrespro.ru", "phone": "+70652395485"}
0005432359906	4404DC	0190 625982	IGOR IVANOV	{"email": "ivanov-igor.081976@postgrespro.ru", "phone": "+70823911856"}
0005432359907	EDA0E6	9687 589903	NATALYA FROLOVA	{"email": "nfrolova-1978@postgrespro.ru", "phone": "+70434708344"}
0005432359908	3CDD39	9092 961443	ALEKSANDR SIDOROV	{"phone": "+70947873877"}
0005432359909	3CDD39	4373 248575	MATVEY SMIRNOV	{"phone": "+70182641552"}
0005432359910	3CDD39	4079 610998	ROZA SERGEEVA	{"email": "roza_sergeeva-091976@postgrespro.ru", "phone": "+70711212019"}
0005432359911	4228F2	5874 408838	SVETLANA NAZAROVA	{"email": "s.nazarova_12101974@postgrespro.ru", "phone": "+70735599409"}
0005432359912	4228F2	6565 207759	TATYANA BELOVA	{"email": "belovat-07101967@postgrespro.ru", "phone": "+70796778898"}
0005432359913	6655D6	2347 083281	SERGEY SMIRNOV	{"phone": "+70495695760"}
0005432359914	551DC7	5377 992758	DMITRIY PETROV	{"email": "dmitriy_petrov051975@postgrespro.ru", "phone": "+70782874384"}
0005432359915	1E8579	3011 295963	DMITRIY SCHERBAKOV	{"phone": "+70211916160"}
0005432359916	175542	4421 817151	DENIS ORLOV	{"email": "orlov_d-06091972@postgrespro.ru", "phone": "+70839021952"}
0005432359917	6C404C	3965 863434	NATALYA EFREMOVA	{"phone": "+70145975004"}
0005432359918	6DF3DC	6029 575823	VALENTINA KISELEVA	{"phone": "+70580437899"}
0005432359919	FE2A40	8270 507720	KRISTINA KARPOVA	{"email": "karpova_k08111959@postgrespro.ru", "phone": "+70704645925"}
0005432359920	1DF726	9097 917220	LIDIYA EGOROVA	{"email": "egorova.l011974@postgrespro.ru", "phone": "+70507786032"}
0005432359921	B02928	1898 533970	VERONIKA FROLOVA	{"email": "veronikafrolova1959@postgrespro.ru", "phone": "+70707863512"}
0005432359922	D869C5	4431 493116	PETR BORISOV	{"email": "p_borisov.1972@postgrespro.ru", "phone": "+70586589096"}
0005432359923	D869C5	3173 158665	GALINA BELOVA	{"email": "belova.g_18031978@postgrespro.ru", "phone": "+70963376674"}
0005432359924	EE9AD6	4668 560242	LYUBOV SEMENOVA	{"email": "lyubov.semenova1971@postgrespro.ru", "phone": "+70119402239"}
0005432359925	6AC75F	2346 419840	VALENTIN POPOV	{"phone": "+70100804237"}
0005432359926	01AC2A	4751 469458	ALEKSANDR PAVLOV	{"email": "pavlov.a-14061975@postgrespro.ru", "phone": "+70015410329"}
0005432359927	01AC2A	1766 382465	YURIY POPOV	{"email": "yuriypopov041971@postgrespro.ru", "phone": "+70813477058"}
0005432359928	48AD5E	8896 231224	ALEKSEY TIKHONOV	{"email": "tikhonov-a19121967@postgrespro.ru", "phone": "+70757088901"}
0005432359929	4BDF2A	7245 143908	MARIYA KONOVALOVA	{"phone": "+70964155491"}
0005432359930	3115DA	9405 123769	VALENTINA NAZAROVA	{"email": "nazarova.valentina.20101965@postgrespro.ru", "phone": "+70185022983"}
0005432359931	DFBAEF	4888 946479	SERGEY MIKHAYLOV	{"email": "mikhaylov.s_15061969@postgrespro.ru", "phone": "+70887581208"}
0005432359932	DFBAEF	9997 741612	OLGA ANTONOVA	{"phone": "+70800468517"}
0005432359933	8BAB52	1755 786957	YANA MOISEEVA	{"phone": "+70161786969"}
0005432359934	2E635C	7119 594427	KONSTANTIN BONDARENKO	{"email": "bondarenko_k-041972@postgrespro.ru", "phone": "+70539240617"}
0005432359935	2675B4	2742 652458	MARIYA NESTEROVA	{"email": "mariya_nesterova-051981@postgrespro.ru", "phone": "+70446273719"}
0005432359936	2675B4	3312 685421	SERGEY OSIPOV	{"phone": "+70974120548"}
0005432359937	EE175F	1740 314801	LYUDMILA SOKOLOVA	{"email": "l.sokolova1969@postgrespro.ru", "phone": "+70139592692"}
0005432359938	3EA1B2	2940 188526	YURIY ANTONOV	{"phone": "+70783298140"}
0005432359939	3EA1B2	5421 314679	ALEKSEY KAZAKOV	{"phone": "+70165886868"}
0005432359940	769A56	7051 398248	VIKTOR BONDARENKO	{"email": "bondarenko_viktor.24071970@postgrespro.ru", "phone": "+70355519908"}
0005432359941	769A56	0027 759204	EVGENIY GORBUNOV	{"phone": "+70405347788"}
0005432359942	769A56	7540 229092	VALENTINA MAKSIMOVA	{"email": "vmaksimova-07031969@postgrespro.ru", "phone": "+70468218816"}
0005432359943	0EC3A2	3197 489716	GENNADIY ANDREEV	{"email": "gennadiy.andreev011978@postgrespro.ru", "phone": "+70604617757"}
0005432359944	761AB3	9378 072156	ANATOLIY MOROZOV	{"email": "a.morozov.011969@postgrespro.ru", "phone": "+70751530290"}
0005432359945	8DF175	4999 937688	NATALYA KOMAROVA	{"email": "natalya_komarova_1982@postgrespro.ru", "phone": "+70920968240"}
0005432359946	8DF175	5647 611378	MIKHAIL ANTONOV	{"phone": "+70672079990"}
0005432359947	8DF175	0501 940521	KSENIYA MIKHAYLOVA	{"email": "kseniya.mikhaylova.14071973@postgrespro.ru", "phone": "+70472239600"}
0005432359948	B6817C	6443 310821	ILYAS IVANOV	{"email": "ivanov.i-23121982@postgrespro.ru", "phone": "+70104370332"}
0005432359949	A0C466	0937 702884	LARISA IVANOVA	{"phone": "+70140976974"}
0005432359950	1AFD6C	7732 135963	NIKITA SMIRNOV	{"email": "nikita-smirnov111977@postgrespro.ru", "phone": "+70691711119"}
0005432359951	4E8425	5814 420669	RADMIR SOKOLOV	{"phone": "+70711013224"}
0005432359952	42F3F4	4541 572480	EKATERINA SMIRNOVA	{"phone": "+70401727463"}
0005432359953	42F3F4	9207 194551	VALENTINA FILIPPOVA	{"email": "filippovav081975@postgrespro.ru", "phone": "+70704539196"}
0005432359954	C6E27E	2095 283920	ANNA KOVALEVA	{"email": "anna-kovaleva_26091971@postgrespro.ru", "phone": "+70089916964"}
0005432359955	BB006B	1908 025630	NIKOLAY ANDREEV	{"phone": "+70103479800"}
0005432359956	BB006B	1364 563533	ANDREY YAKOVLEV	{"email": "yakovlev.a061971@postgrespro.ru", "phone": "+70485149942"}
0005432359957	BE5820	6239 782947	SERGEY SIDOROV	{"phone": "+70436036620"}
0005432359958	3A4BA5	3265 035768	LEONID VASILEV	{"phone": "+70525184822"}
0005432359959	AF8E36	5939 831827	EVGENIY ALEKSANDROV	{"email": "e_aleksandrov-02051971@postgrespro.ru", "phone": "+70394667124"}
0005432359960	01E13E	1087 890642	YANA KOZLOVA	{"phone": "+70957480769"}
0005432359961	39EEE0	7008 591151	ILMIRA KOLESNIKOVA	{"phone": "+70509300073"}
0005432359962	78B3C0	5237 400653	DARYA KUZNECOVA	{"email": "darya_kuznecova_28011985@postgrespro.ru", "phone": "+70842053294"}
0005432359963	73F5B7	6380 264145	LYUBOV KOROLEVA	{"email": "koroleva-l011976@postgrespro.ru", "phone": "+70817197412"}
0005432359964	364FF8	1257 032266	KIRILL KUZNECOV	{"email": "kkuznecov-11091968@postgrespro.ru", "phone": "+70509830783"}
0005432359965	364FF8	1943 281785	OLGA OSIPOVA	{"email": "osipova_olga-111968@postgrespro.ru", "phone": "+70646816592"}
0005432359966	5F6701	1760 074413	VLADISLAV SHEVCHENKO	{"phone": "+70693042481"}
0005432359967	E3DAE4	3425 279336	ANDREY CHERNOV	{"email": "chernov-a27111971@postgrespro.ru", "phone": "+70808760723"}
0005432359968	32C148	4099 260329	YURIY KOZLOV	{"email": "y.kozlov-1977@postgrespro.ru", "phone": "+70557310989"}
0005432359969	32C148	9342 864433	EMMA MASLOVA	{"email": "emmamaslova071965@postgrespro.ru", "phone": "+70528226502"}
0005432359970	3F62E6	3456 733142	ALEKSANDR FEDOROV	{"phone": "+70325105448"}
0005432359971	3F62E6	4786 791398	YURIY MARTYNOV	{"phone": "+70747928142"}
0005432359972	1F9361	0663 310947	YURIY MATVEEV	{"phone": "+70739251357"}
0005432359973	1F9361	5296 524248	TATYANA SEMENOVA	{"phone": "+70752825884"}
0005432359974	5EAF03	7848 610376	OLGA IVANOVA	{"phone": "+70793116798"}
0005432359975	5EAF03	2672 574998	ARTEM TIKHONOV	{"email": "a_tikhonov06081977@postgrespro.ru", "phone": "+70284255038"}
0005432359976	D38C88	7163 335026	EKATERINA MAKAROVA	{"phone": "+70345120391"}
0005432359977	D38C88	4348 866175	EKATERINA NAUMOVA	{"email": "ekaterina-naumova-1974@postgrespro.ru", "phone": "+70448361642"}
0005432359978	D38C88	0474 170940	NATALYA ABRAMOVA	{"phone": "+70832833019"}
0005432359979	8FB6E4	0027 827813	ALEKSANDR SOROKIN	{"phone": "+70681479388"}
0005432359980	A84A35	1001 367559	TATYANA ISAEVA	{"email": "isaeva-t041963@postgrespro.ru", "phone": "+70067862089"}
0005432359981	F2E31B	2910 800388	ALEKSANDR KUDRYASHOV	{"email": "a_kudryashov_1971@postgrespro.ru", "phone": "+70280689217"}
0005432359982	D81FCD	6485 537210	SERGEY GUSEV	{"phone": "+70369464920"}
0005432359983	383AC7	0918 268435	SVETLANA AKIMOVA	{"email": "svetlana-akimova101974@postgrespro.ru", "phone": "+70263753375"}
0005432359984	383AC7	3199 387180	DARYA ZOTOVA	{"email": "zotova-darya.101982@postgrespro.ru", "phone": "+70808272975"}
0005432359985	BF06AB	5941 636737	EKATERINA DANILOVA	{"email": "e_danilova-22051980@postgrespro.ru", "phone": "+70547727709"}
0005432359986	480F34	3125 408388	MIKHAIL KUZNECOV	{"phone": "+70737571275"}
0005432359987	480F34	5987 357910	MAKSIM ORLOV	{"email": "maksim.orlov29011962@postgrespro.ru", "phone": "+70138106398"}
0005432359988	5BD2DE	0952 477842	VLADIMIR IVANOV	{"phone": "+70570982578"}
0005432359989	5BD2DE	6494 258116	MARINA NOVIKOVA	{"phone": "+70654028468"}
0005432359990	5F6401	7071 925386	OLEG NIKOLAEV	{"email": "oleg-nikolaev_081974@postgrespro.ru", "phone": "+70937138363"}
0005432359991	5F6401	5623 710090	RUSLAN GRIGOREV	{"email": "r-grigorev-1964@postgrespro.ru", "phone": "+70084102669"}
0005432359992	6A446A	0905 883269	NATALIYA NESTEROVA	{"phone": "+70162859499"}
0005432359993	128012	0672 976854	IGOR KUZNECOV	{"phone": "+70741938853"}
0005432359994	472A5A	2365 455888	EVGENIY SOROKIN	{"email": "sorokin.e.1986@postgrespro.ru", "phone": "+70358573587"}
0005432359995	472A5A	2075 311787	LIDIYA ZAKHAROVA	{"phone": "+70772329949"}
0005432359996	DAD976	5755 020329	VITALIY SOLOVEV	{"phone": "+70027017360"}
0005432359997	DB8102	7303 716143	LIDIYA EGOROVA	{"email": "egorova-lidiya-101975@postgrespro.ru", "phone": "+70678626920"}
0005432359998	68DBAF	2820 781746	IRINA DANILOVA	{"email": "danilovai07101970@postgrespro.ru", "phone": "+70038135023"}
0005432359999	3E1A5B	1530 761545	VERONIKA VLASOVA	{"email": "vlasova_veronika_091970@postgrespro.ru", "phone": "+70037481241"}
0005432360000	332719	3320 106331	KONSTANTIN SIDOROV	{"phone": "+70821826574"}
0005432360001	18B1F1	2923 805081	VALENTIN KULIKOV	{"email": "kulikov_v-16111963@postgrespro.ru", "phone": "+70600889293"}
0005432360002	DD693F	8155 443244	NATALYA KUZNECOVA	{"phone": "+70844406311"}
0005432360003	DD693F	7985 506312	NIKOLAY DAVYDOV	{"phone": "+70730360588"}
0005432360004	039012	7276 348252	ANATOLIY IVANOV	{"email": "anatoliy-ivanov101977@postgrespro.ru", "phone": "+70753143996"}
0005432360005	039012	0373 425073	VIKTOR DAVYDOV	{"phone": "+70052702000"}
0005432360006	378E6E	8534 741988	GALINA ILINA	{"phone": "+70755326314"}
0005432360007	10B2AF	9588 470599	SERGEY ANDREEV	{"phone": "+70133358342"}
0005432360008	315824	4777 954132	ALEFTINA TIKHONOVA	{"phone": "+70730267112"}
0005432360009	084D04	7867 970292	ALENA LOGINOVA	{"email": "loginova_a-1966@postgrespro.ru", "phone": "+70680030898"}
0005432360010	3464EB	3156 762100	GALINA KUZNECOVA	{"phone": "+70453724630"}
0005432360011	51C450	7415 113508	RAISA ILINA	{"phone": "+70958942019"}
0005432360012	51C450	6167 776164	VALERIY GAVRILOV	{"email": "v.gavrilov_31081966@postgrespro.ru", "phone": "+70821044346"}
0005432360013	B44C4A	3860 852194	RODION YAKOVLEV	{"email": "rodionyakovlev_21011962@postgrespro.ru", "phone": "+70954649638"}
0005432360014	339DCD	5483 026985	ANASTASIYA MAKSIMOVA	{"email": "maksimova.a30041965@postgrespro.ru", "phone": "+70412187535"}
0005432360015	71D29F	3306 833923	VERA DAVYDOVA	{"email": "vera-davydova_061967@postgrespro.ru", "phone": "+70626883952"}
0005432360016	74B646	7678 001686	TIKHON ANDREEV	{"email": "andreev-t.1971@postgrespro.ru", "phone": "+70005517376"}
0005432360017	EE4FD4	7676 811032	MARINA EFIMOVA	{"phone": "+70489597331"}
0005432360018	9274AB	0065 278906	MATRENA TROFIMOVA	{"phone": "+70538010517"}
0005432360019	3FDA15	9789 012427	ALEKSANDR ALEKSANDROV	{"phone": "+70539908379"}
0005432360020	3FDA15	3058 246390	OLGA MIRONOVA	{"email": "omironova.1976@postgrespro.ru", "phone": "+70456027677"}
0005432360021	AA0601	4146 298202	ILGIZ MIRONOV	{"email": "ilgizmironov_111992@postgrespro.ru", "phone": "+70485701592"}
0005432360022	DB4797	6647 656542	ROMAN SCHERBAKOV	{"phone": "+70356326606"}
0005432360023	FB448A	6401 306534	VITALIY NOVIKOV	{"email": "novikovvitaliy1975@postgrespro.ru", "phone": "+70622304229"}
0005432360024	981283	7409 674599	VALENTINA MELNIKOVA	{"phone": "+70616200116"}
0005432360025	C9A47E	7875 178445	DENIS SERGEEV	{"email": "denissergeev_02011972@postgrespro.ru", "phone": "+70629984652"}
0005432360026	C9A47E	2945 549902	OLGA GORBUNOVA	{"phone": "+70167418639"}
0005432360027	F947AA	1764 723963	MARIYA ZAKHAROVA	{"phone": "+70099700310"}
0005432360028	B0FD24	3483 775908	ANNA NAZAROVA	{"email": "nazarova-anna-17111974@postgrespro.ru", "phone": "+70845443268"}
0005432360029	299906	3007 694886	MARIYA KUDRYASHOVA	{"phone": "+70564477706"}
0005432360030	5C01BC	3032 123961	OLGA FILIPPOVA	{"email": "filippovao-15111972@postgrespro.ru", "phone": "+70573966435"}
0005432360031	8B1F56	5340 143403	ELENA KUZNECOVA	{"phone": "+70690706946"}
0005432360032	154634	4387 877088	ILNUR GERASIMOV	{"phone": "+70825360218"}
0005432360033	87F6AA	5091 464389	ILYA ROMANOV	{"email": "ilya_romanov_21031977@postgrespro.ru", "phone": "+70542793230"}
0005432360034	87F6AA	4449 692565	DENIS KONOVALOV	{"email": "konovalov-denis-1972@postgrespro.ru", "phone": "+70184904519"}
0005432360035	6CB6D6	4619 940085	DENIS FOMIN	{"phone": "+70437938841"}
0005432360036	6CB6D6	7872 619401	INNA NIKITINA	{"email": "inna.nikitina.101980@postgrespro.ru", "phone": "+70808122078"}
0005432360037	4BDAD5	8213 387162	ANASTASIYA CHERNOVA	{"email": "chernova.a011982@postgrespro.ru", "phone": "+70202551960"}
0005432360038	3F27D2	3674 141999	LYUDMILA SMIRNOVA	{"email": "smirnoval.07031969@postgrespro.ru", "phone": "+70063417075"}
0005432360039	1C5EBB	3367 296704	VITALIY ALEKSANDROV	{"email": "v_aleksandrov_12111975@postgrespro.ru", "phone": "+70474388595"}
0005432360040	4A73E9	3127 812641	NINA BOGDANOVA	{"email": "nina_bogdanova15091979@postgrespro.ru", "phone": "+70428410687"}
0005432360041	C162EF	7937 387743	YULIYA VOLKOVA	{"phone": "+70471999315"}
0005432360042	C162EF	3724 994805	ALEKSANDR POPOV	{"phone": "+70820576110"}
0005432360043	C162EF	1268 685828	LARISA AFANASEVA	{"email": "larisaafanaseva-15041968@postgrespro.ru", "phone": "+70989006193"}
0005432360044	8D1A97	0464 791301	DARYA VASILEVA	{"email": "vasileva_darya.29101972@postgrespro.ru", "phone": "+70066949796"}
0005432360045	86BD8F	6563 371088	VIKTOR NIKOLAEV	{"email": "nikolaev.v_1967@postgrespro.ru", "phone": "+70244912143"}
0005432360046	86BD8F	8485 670586	LYUDMILA MASLOVA	{"email": "maslova_lyudmila-26101987@postgrespro.ru", "phone": "+70006166400"}
0005432360047	2F6F1F	6070 780047	ZINAIDA ZHURAVLEVA	{"email": "zhuravleva-zinaida-1975@postgrespro.ru", "phone": "+70608227656"}
0005432360048	DA7FF6	9039 263826	SVETLANA VLASOVA	{"email": "vlasovasvetlana-25021957@postgrespro.ru", "phone": "+70416952065"}
0005432360049	36E75B	7451 636436	YURIY KUZNECOV	{"email": "y-kuznecov041979@postgrespro.ru", "phone": "+70020823966"}
0005432360050	6DF30E	5796 373516	ELIZAVETA MAKAROVA	{"email": "elizaveta.makarova1979@postgrespro.ru", "phone": "+70465845269"}
0005432360051	D916BE	8369 499224	SERGEY GERASIMOV	{"email": "gerasimovs.03101968@postgrespro.ru", "phone": "+70636080998"}
0005432360052	113F20	7728 352820	ALEKSANDR DMITRIEV	{"email": "dmitriev-a-1970@postgrespro.ru", "phone": "+70505486017"}
0005432360053	AC7A6F	2082 515127	OLGA SOKOLOVA	{"email": "sokolova_olga.1962@postgrespro.ru", "phone": "+70674675939"}
0005432360054	227057	2587 363268	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova_15081971@postgrespro.ru", "phone": "+70432826023"}
0005432360055	F8CB5D	8949 138084	RINAT NIKITIN	{"email": "rinat_nikitin.1983@postgrespro.ru", "phone": "+70340256973"}
0005432360056	F8CB5D	0457 147604	IRINA NIKITINA	{"email": "nikitina_irina_081972@postgrespro.ru", "phone": "+70669360725"}
0005432360057	B28542	7543 850490	MARIYA STEPANOVA	{"email": "stepanova_m.1972@postgrespro.ru", "phone": "+70165160907"}
0005432360058	AD2864	2987 604278	ALEKSANDR EGOROV	{"phone": "+70428268765"}
0005432360059	C6C0E4	8094 563674	MIKHAIL SCHERBAKOV	{"email": "m_scherbakov-021977@postgrespro.ru", "phone": "+70719570594"}
0005432360060	D854D7	2687 130239	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova_1965@postgrespro.ru", "phone": "+70336203821"}
0005432360061	D854D7	8151 004828	NIKOLAY POPOV	{"email": "popovnikolay22061966@postgrespro.ru", "phone": "+70437465792"}
0005432360062	EBDDE3	0269 585005	VYACHESLAV PETROV	{"phone": "+70535657862"}
0005432360063	7F8DAB	3607 299337	VALENTINA ISAEVA	{"email": "isaeva_valentina11041967@postgrespro.ru", "phone": "+70424690320"}
0005432360064	FBEE2C	1977 208793	ELENA FEDOROVA	{"phone": "+70299080849"}
0005432360065	33C188	3192 839401	NADEZHDA ZAYCEVA	{"phone": "+70567050232"}
0005432360066	33C188	5344 904459	TATYANA FILIPPOVA	{"email": "filippovat111965@postgrespro.ru", "phone": "+70168411016"}
0005432360067	64CB81	0542 662420	VIKTOR FEDOROV	{"email": "vfedorov-1968@postgrespro.ru", "phone": "+70088344449"}
0005432360068	64CB81	3986 374223	ALEKSANDR SOKOLOV	{"phone": "+70554361866"}
0005432360069	17D39E	6088 981199	VIKTORIYA SMIRNOVA	{"phone": "+70019612436"}
0005432360070	642F99	7104 943559	TAMARA FROLOVA	{"phone": "+70700442310"}
0005432360071	642F99	7235 158336	EVGENIYA VLASOVA	{"email": "evgeniya.vlasova1969@postgrespro.ru", "phone": "+70757442197"}
0005432360072	642F99	4123 742508	DMITRIY TIKHONOV	{"email": "dmitriy-tikhonov061970@postgrespro.ru", "phone": "+70448277689"}
0005432360073	94164C	2783 386472	SEMEN BONDARENKO	{"phone": "+70267841645"}
0005432360074	0BA2D7	5317 029944	ALEKSEY BARANOV	{"phone": "+70200420350"}
0005432360075	7B0D90	3945 779237	ALEKSEY MAKSIMOV	{"phone": "+70441060670"}
0005432360076	E1C18C	9575 707944	SERGEY SERGEEV	{"phone": "+70721533125"}
0005432360077	E1C18C	7772 974924	KSENIYA MOROZOVA	{"phone": "+70443817480"}
0005432360078	013EF9	0736 248577	SERGEY IVANOV	{"phone": "+70852744318"}
0005432360079	48FACC	6319 639353	IGOR GUSEV	{"phone": "+70453642716"}
0005432360080	1B1432	2101 340394	TATYANA KUZNECOVA	{"phone": "+70268411836"}
0005432360081	04F064	8034 003473	GALINA MARTYNOVA	{"phone": "+70975482910"}
0005432360082	4010D3	9876 553865	VIKTOR POPOV	{"email": "popovviktor_071971@postgrespro.ru", "phone": "+70535923337"}
0005432360083	4010D3	2375 998031	ALEKSEY KUZNECOV	{"email": "alekseykuznecov_1984@postgrespro.ru", "phone": "+70909871374"}
0005432360084	BD833E	4410 153952	EKATERINA ZAKHAROVA	{"phone": "+70160157335"}
0005432360085	23C3CE	1323 345091	YURIY ZAYCEV	{"phone": "+70530009470"}
0005432360086	6B8BBD	2176 475002	IGOR GAVRILOV	{"phone": "+70317378932"}
0005432360087	5C1705	7648 132863	VLADISLAV NIKITIN	{"email": "nikitin.vladislav.1971@postgrespro.ru", "phone": "+70566108689"}
0005432360088	C353F9	0081 062048	ALEKSEY KUZMIN	{"phone": "+70814454185"}
0005432360089	062E3A	9151 851588	SVETLANA OSIPOVA	{"phone": "+70300323815"}
0005432360090	062E3A	2368 342830	PAVEL NOVIKOV	{"email": "novikov.pavel.021983@postgrespro.ru", "phone": "+70332475007"}
0005432360091	747235	1762 535900	RUSTAM PETROV	{"email": "r_petrov_101972@postgrespro.ru", "phone": "+70297986101"}
0005432360092	747235	6264 890952	LYUDMILA KONOVALOVA	{"phone": "+70658916368"}
0005432360093	9A5DE0	2018 205381	ALEKSEY MIRONOV	{"phone": "+70677538264"}
0005432360094	9A5DE0	4832 569189	VALERIYA POPOVA	{"email": "popova-v13121958@postgrespro.ru", "phone": "+70876571445"}
0005432360095	71176B	6452 934984	INNA KUZNECOVA	{"phone": "+70566722358"}
0005432360096	71176B	5097 090558	NIKITA GRIGOREV	{"email": "n_grigorev111976@postgrespro.ru", "phone": "+70058104526"}
0005432360097	B7795A	0126 763338	TATYANA KRASNOVA	{"email": "tkrasnova-1958@postgrespro.ru", "phone": "+70547940332"}
0005432360098	B7795A	5917 933998	GALINA ANTONOVA	{"email": "galina_antonova041985@postgrespro.ru", "phone": "+70001477647"}
0005432360099	84BE4B	6163 117130	ANASTASIYA PAVLOVA	{"email": "pavlova_anastasiya24101970@postgrespro.ru", "phone": "+70234276207"}
0005432360100	3364ED	4018 107158	NATALIYA SCHERBAKOVA	{"email": "scherbakova-nataliya.27121981@postgrespro.ru", "phone": "+70511693777"}
0005432360101	5FA043	9191 671850	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-02021970@postgrespro.ru", "phone": "+70295441490"}
0005432360102	5F0E86	7905 037552	ANDREY KUZMIN	{"email": "andreykuzmin081975@postgrespro.ru", "phone": "+70939768136"}
0005432360103	5F0E86	7688 063285	VALENTINA KARPOVA	{"email": "vkarpova091977@postgrespro.ru", "phone": "+70140488088"}
0005432360104	0CBFF2	8377 446678	ALEKSEY MAKAROV	{"email": "aleksey.makarov.021976@postgrespro.ru", "phone": "+70656653136"}
0005432360105	227BD0	9137 416757	EKATERINA VASILEVA	{"email": "vasileva_e.041981@postgrespro.ru", "phone": "+70646242179"}
0005432360106	E5375A	3594 626961	RUSLAN KUZMIN	{"phone": "+70787724854"}
0005432360107	1FB78C	0407 626147	DENIS SERGEEV	{"phone": "+70766731152"}
0005432360108	1AE6D4	1708 057052	MAKSIM MATVEEV	{"email": "mmatveev_31071972@postgrespro.ru", "phone": "+70416911047"}
0005432360109	FF2072	6721 473057	TATYANA RODIONOVA	{"phone": "+70820660402"}
0005432360110	338393	4003 047867	VASILIY MAKAROV	{"phone": "+70319384487"}
0005432360111	338393	5050 767555	VLADIMIR SIDOROV	{"email": "sidorov-v.31031978@postgrespro.ru", "phone": "+70818791614"}
0005432360112	AAE427	2118 804483	NATALYA IVANOVA	{"phone": "+70810487383"}
0005432360113	AAE427	6251 533611	NINA KOLESNIKOVA	{"phone": "+70550471485"}
0005432360114	5A239B	6087 273063	NIKOLAY BONDARENKO	{"phone": "+70379294149"}
0005432360116	0731D5	8961 063946	OLGA ZAKHAROVA	{"phone": "+70434161855"}
0005432360117	037083	7882 026601	LYUBOV PAVLOVA	{"phone": "+70417391089"}
0005432360118	E0631D	9681 943819	ANNA ALEKSEEVA	{"phone": "+70666054666"}
0005432360119	26BA41	9091 778329	ALINA ZAKHAROVA	{"phone": "+70820312297"}
0005432360120	92099B	5228 831600	TATYANA ANTONOVA	{"phone": "+70817651657"}
0005432360121	9FEA25	8666 191926	NIKITA KUZNECOV	{"phone": "+70281706429"}
0005432360122	85954D	6441 461260	SERGEY FEDOROV	{"email": "sergey_fedorov.051965@postgrespro.ru", "phone": "+70556552954"}
0005432360123	97D4EC	3562 161855	ANNA AKIMOVA	{"phone": "+70481227207"}
0005432360124	97D4EC	1140 503483	POLINA FEDOROVA	{"phone": "+70795601482"}
0005432360125	B40FDE	0961 987825	YULIYA YAKOVLEVA	{"email": "y_yakovleva_091964@postgrespro.ru", "phone": "+70477353517"}
0005432360126	ECC98C	0646 470838	ALEKSANDR FEDOROV	{"phone": "+70971744466"}
0005432360127	018C2F	8264 309444	SERGEY SEMENOV	{"email": "sergeysemenov031976@postgrespro.ru", "phone": "+70265418426"}
0005432360128	A9DC43	5239 945920	VASILIY SCHERBAKOV	{"email": "scherbakov-vasiliy.28091974@postgrespro.ru", "phone": "+70298110624"}
0005432360129	15F2DB	2664 256324	GRIGORIY VOLKOV	{"email": "volkov.g.031975@postgrespro.ru", "phone": "+70423486348"}
0005432360130	42AD9A	7391 720367	TATYANA POPOVA	{"email": "popova.tatyana_1961@postgrespro.ru", "phone": "+70192817517"}
0005432360131	1E6402	9575 974745	ILYA NIKITIN	{"phone": "+70706292452"}
0005432360132	35E27B	6384 655397	ELVIRA IVANOVA	{"email": "ivanova_elvira011961@postgrespro.ru", "phone": "+70522754580"}
0005432360133	35E27B	6051 494397	ELENA EFIMOVA	{"phone": "+70514593435"}
0005432360134	10D83D	3316 658768	ELIZAVETA NESTEROVA	{"phone": "+70177873038"}
0005432360135	10D83D	6903 925604	TATYANA ZAKHAROVA	{"email": "t_zakharova_101976@postgrespro.ru", "phone": "+70385187984"}
0005432360136	672F65	9072 021126	DARYA BORISOVA	{"phone": "+70734724675"}
0005432360137	672F65	0366 399496	ANASTASIYA PAVLOVA	{"email": "pavlova_a.1974@postgrespro.ru", "phone": "+70277303138"}
0005432360138	672F65	7377 093549	MARIYA NAZAROVA	{"email": "mariyanazarova_22011976@postgrespro.ru", "phone": "+70012546112"}
0005432360139	92E04B	5809 932529	SOFIYA PAVLOVA	{"email": "sofiya-pavlova.101977@postgrespro.ru", "phone": "+70893387449"}
0005432360140	92E04B	3469 466626	GALINA BELYAEVA	{"email": "g-belyaeva-071974@postgrespro.ru", "phone": "+70726515288"}
0005432360141	0C6CFC	8747 124557	YURIY ALEKSEEV	{"phone": "+70543580571"}
0005432360142	D20E25	3442 672958	ALINA PAVLOVA	{"phone": "+70473619483"}
0005432360143	CF7D54	7774 962786	VLADIMIR MAKAROV	{"phone": "+70396434055"}
0005432360144	73ED7C	2026 374401	ALEKSEY VASILEV	{"email": "a.vasilev_30011955@postgrespro.ru", "phone": "+70492724565"}
0005432360145	16D4D3	1379 123088	TATYANA MOROZOVA	{"email": "tatyanamorozova021972@postgrespro.ru", "phone": "+70474192430"}
0005432360146	60D1C3	1727 218223	ALEKSEY EGOROV	{"phone": "+70829064724"}
0005432360147	0D4AA2	6246 790373	PAVEL STEPANOV	{"phone": "+70057637243"}
0005432360148	4AC993	4276 538381	SERGEY ORLOV	{"phone": "+70713549351"}
0005432360149	D5FF82	1265 224230	EVGENIY POPOV	{"email": "e-popov.1969@postgrespro.ru", "phone": "+70826973609"}
0005432360150	D5FF82	3850 779804	TATYANA TARASOVA	{"phone": "+70689230832"}
0005432360151	D5FF82	4583 175465	TATYANA KUZNECOVA	{"phone": "+70268723049"}
0005432360152	A72200	2039 406241	FARID DENISOV	{"phone": "+70131515493"}
0005432360153	D15777	3778 088717	GULNARA FILIPPOVA	{"email": "gulnarafilippova_29101971@postgrespro.ru", "phone": "+70707280815"}
0005432360154	918E9C	9440 273191	VALENTIN STEPANOV	{"phone": "+70352631537"}
0005432360155	E61CB3	2822 678184	MARIYA NIKOLAEVA	{"phone": "+70481806013"}
0005432360156	E61CB3	2992 172917	RUSLAN MELNIKOV	{"email": "rmelnikov-06031970@postgrespro.ru", "phone": "+70451342863"}
0005432360157	E61CB3	7724 896771	YULIYA KOROLEVA	{"phone": "+70467623766"}
0005432360158	35CA0E	4383 694338	SERGEY SCHERBAKOV	{"phone": "+70746077251"}
0005432360159	3CC3F4	1468 990824	NIKITA ILIN	{"phone": "+70192903636"}
0005432360160	778550	6344 924188	YURIY ANDREEV	{"phone": "+70582526094"}
0005432360161	DF1315	4164 038117	LIDIYA TARASOVA	{"phone": "+70880420138"}
0005432360162	C01E0A	5860 513362	ELENA TARASOVA	{"email": "tarasova.e28051958@postgrespro.ru", "phone": "+70089428085"}
0005432360163	C01E0A	6651 816727	TAMARA SAVELEVA	{"phone": "+70304777738"}
0005432360164	C01E0A	7727 274824	MARIYA PAVLOVA	{"email": "m_pavlova_1978@postgrespro.ru", "phone": "+70766954638"}
0005432360165	7050DA	7430 775212	ANNA ZOTOVA	{"phone": "+70533750635"}
0005432360166	10F568	1342 904811	VALENTINA PETROVA	{"email": "petrova-v28091976@postgrespro.ru", "phone": "+70504610219"}
0005432360167	10F568	9855 681582	ANNA ILINA	{"phone": "+70578295223"}
0005432360168	6168D3	2673 125508	ZLATA YAKOVLEVA	{"phone": "+70221603543"}
0005432360169	BF54B8	0167 182420	VLADIMIR GAVRILOV	{"email": "v_gavrilov-17081965@postgrespro.ru", "phone": "+70235578895"}
0005432360170	36C5AB	4322 843676	LYUBOV EFREMOVA	{"email": "efremova.lyubov_22121967@postgrespro.ru", "phone": "+70707188452"}
0005432360171	36C5AB	2192 539884	VERA FROLOVA	{"phone": "+70553908375"}
0005432360172	115DC6	7387 935054	PELAGEYA MATVEEVA	{"phone": "+70097640405"}
0005432360285	85D409	2631 504421	YURIY ALEKSANDROV	{"phone": "+70046811018"}
0005432360173	115DC6	6501 100935	ELENA LAZAREVA	{"email": "elena.lazareva-30041978@postgrespro.ru", "phone": "+70968389771"}
0005432360174	BA7915	5684 999127	ANDREY ABRAMOV	{"phone": "+70612626243"}
0005432360175	2093AF	0287 981635	GALINA ERMAKOVA	{"email": "g.ermakova_1967@postgrespro.ru", "phone": "+70572981763"}
0005432360176	2093AF	6053 106823	YURIY KRASNOV	{"email": "yuriy_krasnov041969@postgrespro.ru", "phone": "+70547423531"}
0005432360177	BFC3A5	2302 862081	ALEKSANDR KUZNECOV	{"phone": "+70835366567"}
0005432360178	FDCAD4	1944 043015	NINA KUZNECOVA	{"email": "kuznecova_nina_1991@postgrespro.ru", "phone": "+70520711666"}
0005432360179	CF88B1	7451 937647	RAISA GORBUNOVA	{"email": "r_gorbunova.021970@postgrespro.ru", "phone": "+70120816128"}
0005432360180	D80BE0	8652 878370	ANDREY EGOROV	{"phone": "+70680867977"}
0005432360181	D80BE0	4731 824353	ALEKSEY SOKOLOV	{"email": "asokolov_011972@postgrespro.ru", "phone": "+70413244832"}
0005432360182	D80BE0	5631 016615	GENNADIY GRIGOREV	{"email": "grigorev_gennadiy.26051977@postgrespro.ru", "phone": "+70293166322"}
0005432360183	192649	6763 923286	SERGEY KAZAKOV	{"email": "s_kazakov_051981@postgrespro.ru", "phone": "+70452283908"}
0005432360184	F03DE4	9408 574780	ALEKSANDR ROMANOV	{"phone": "+70878534426"}
0005432360185	4777F1	5641 967038	VLADIMIR ZHUKOV	{"phone": "+70731551721"}
0005432360186	AE2486	9255 253267	LIDIYA ERMAKOVA	{"email": "lidiyaermakova.021990@postgrespro.ru", "phone": "+70817790323"}
0005432360187	AE2486	9474 476653	RUSLAN EGOROV	{"email": "ruslan.egorov.1966@postgrespro.ru", "phone": "+70552778882"}
0005432360188	AE2486	1655 772630	LARISA PETROVA	{"phone": "+70201543851"}
0005432360189	7A859C	6509 999138	ALEKSANDR ALEKSEEV	{"phone": "+70206830893"}
0005432360190	7A859C	3142 747156	ELENA RODIONOVA	{"phone": "+70631119866"}
0005432360191	918CCC	1466 338919	IGOR DAVYDOV	{"email": "davydov_igor.011991@postgrespro.ru", "phone": "+70694854283"}
0005432360192	F67DE8	6354 484608	IVAN FEDOROV	{"phone": "+70471448804"}
0005432360193	54B829	9236 410817	VIKTOR NIKITIN	{"email": "v.nikitin-1981@postgrespro.ru", "phone": "+70030435822"}
0005432360194	54B829	1005 434817	TATYANA STEPANOVA	{"phone": "+70804655431"}
0005432360195	A19674	0071 751862	EVGENIY SOROKIN	{"email": "sorokin.e-18041971@postgrespro.ru", "phone": "+70144108144"}
0005432360196	D09A47	2123 199258	EKATERINA ISAEVA	{"phone": "+70525953963"}
0005432360197	689FD4	8653 861950	DMITRIY ALEKSEEV	{"phone": "+70900464485"}
0005432360198	3C3272	4374 308385	YULIYA ANDREEVA	{"email": "y.andreeva-1961@postgrespro.ru", "phone": "+70444296709"}
0005432360199	3C3272	6022 046698	ANDREY KRASNOV	{"email": "a_krasnov031974@postgrespro.ru", "phone": "+70202597235"}
0005432360200	333635	5074 123933	TAMARA KAZAKOVA	{"phone": "+70540026291"}
0005432360201	333635	1317 265970	NINA NAZAROVA	{"phone": "+70217183882"}
0005432360202	DE8F8D	8695 561652	PAVEL SOLOVEV	{"phone": "+70046769275"}
0005432360203	DE8F8D	8125 556001	YURIY PAVLOV	{"phone": "+70040381421"}
0005432360204	D7171D	5196 207912	ALEKSANDR GAVRILOV	{"email": "gavrilova-031966@postgrespro.ru", "phone": "+70600504420"}
0005432360205	2A28D5	6010 676851	VALENTINA POTAPOVA	{"phone": "+70863734344"}
0005432360206	3D17F3	5460 302387	VLADIMIR SIDOROV	{"email": "vladimir.sidorov-1970@postgrespro.ru", "phone": "+70411903882"}
0005432360207	0D2FC6	4972 961080	VALENTIN VASILEV	{"email": "vasilev_valentin091964@postgrespro.ru", "phone": "+70624102341"}
0005432360208	0D2FC6	8418 052049	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr_091972@postgrespro.ru", "phone": "+70503340277"}
0005432360209	6CF5DB	1212 574426	ANNA KUZMINA	{"phone": "+70071469272"}
0005432360210	00CA80	2459 435068	VLADIMIR DMITRIEV	{"email": "dmitrievv_01101973@postgrespro.ru", "phone": "+70447393797"}
0005432360211	00CA80	4003 248570	ROMAN EGOROV	{"phone": "+70018506586"}
0005432360212	02E25D	0846 562696	VITALIY POPOV	{"phone": "+70625036282"}
0005432360213	02E25D	3796 696336	VALENTINA MAKSIMOVA	{"phone": "+70696236359"}
0005432360214	89DF49	3617 254043	ANTONINA TARASOVA	{"phone": "+70852335454"}
0005432360215	89DF49	1016 792696	DENIS MIKHAYLOV	{"phone": "+70708789125"}
0005432360216	F0E3AA	6229 263283	NADEZHDA IVANOVA	{"phone": "+70881364486"}
0005432360217	45F9D2	1466 569199	NIKOLAY PETROV	{"email": "nikolay.petrov1982@postgrespro.ru", "phone": "+70080348675"}
0005432360218	A8A54E	0478 150068	OLEG NIKITIN	{"email": "olegnikitin_05061975@postgrespro.ru", "phone": "+70157861804"}
0005432360219	A8A54E	8872 836924	IVAN VASILEV	{"phone": "+70695097408"}
0005432360220	A8A54E	6707 418781	IRINA FILIPPOVA	{"email": "filippova_irina-14091974@postgrespro.ru", "phone": "+70545756431"}
0005432360221	E59EFD	7105 049123	LIDIYA BELOVA	{"email": "lidiya_belova30121959@postgrespro.ru", "phone": "+70258750112"}
0005432360222	E8B1CF	3577 055104	OLEG KOZLOV	{"phone": "+70388833723"}
0005432360223	EC4D34	1811 083972	ALEKSANDR BORISOV	{"phone": "+70593500866"}
0005432360224	F16B8F	1239 636067	IVAN TARASOV	{"email": "itarasov-011968@postgrespro.ru", "phone": "+70829860658"}
0005432360225	22722A	4020 921997	NIKOLAY SCHERBAKOV	{"phone": "+70059564800"}
0005432360226	B0BD49	3857 317244	ALEKSANDR IVANOV	{"phone": "+70934708707"}
0005432360227	B0BD49	7670 322768	SERGEY SHEVCHENKO	{"phone": "+70453503746"}
0005432360228	B0BD49	0431 247027	OLGA POLYAKOVA	{"phone": "+70312440790"}
0005432360229	8DBE4D	9416 911693	PETR MELNIKOV	{"phone": "+70520865603"}
0005432360230	6BBD96	4420 753473	VLADISLAV ORLOV	{"email": "vladislavorlov_121971@postgrespro.ru", "phone": "+70986348209"}
0005432360231	B42796	9031 035410	ELENA SMIRNOVA	{"phone": "+70564928942"}
0005432360232	1B1A90	7476 978456	ANASTASIYA GERASIMOVA	{"phone": "+70220299259"}
0005432360233	BA78A2	1581 427388	ANTON ZHURAVLEV	{"email": "zhuravleva.1968@postgrespro.ru", "phone": "+70493584933"}
0005432360234	A1778A	3486 389389	ANATOLIY KUZNECOV	{"phone": "+70086328897"}
0005432360235	963FA3	3392 226511	VALERIY KUDRYASHOV	{"email": "v.kudryashov.27031987@postgrespro.ru", "phone": "+70343820828"}
0005432360236	3B0AD6	8379 880780	RUMIYA ANISIMOVA	{"email": "anisimova-rumiya1969@postgrespro.ru", "phone": "+70010259102"}
0005432360237	7BA2B1	2668 831676	VALENTINA MAKAROVA	{"phone": "+70490925640"}
0005432360238	DD6AA0	2618 267029	SVETLANA POPOVA	{"phone": "+70197349492"}
0005432360239	9E88A5	1234 259384	NIKITA KOROLEV	{"phone": "+70209940934"}
0005432360240	F04CF7	0103 804657	ALEKSANDR POPOV	{"email": "popov-aleksandr_091963@postgrespro.ru", "phone": "+70534606668"}
0005432360241	5DAB00	1129 621152	NATALYA EGOROVA	{"email": "egorova.natalya-1965@postgrespro.ru", "phone": "+70831314664"}
0005432360242	7D9D0E	3015 185247	VALERIYA ZAKHAROVA	{"phone": "+70176531277"}
0005432360243	887864	4552 492330	KSENIYA MAKAROVA	{"phone": "+70416866320"}
0005432360244	887864	7760 247149	ANATOLIY KUZNECOV	{"phone": "+70916749818"}
0005432360245	887864	4801 935805	VLADIMIR MAKSIMOV	{"email": "v.maksimov_051978@postgrespro.ru", "phone": "+70470853146"}
0005432360246	C41D8E	9746 752072	GERMAN SAVELEV	{"email": "g-savelev_27111974@postgrespro.ru", "phone": "+70507056067"}
0005432360247	5C8581	7273 713206	ANDREY ANDREEV	{"phone": "+70702670981"}
0005432360248	5C8581	3156 262228	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov.1988@postgrespro.ru", "phone": "+70675745972"}
0005432360249	5C8581	5362 031857	VLADIMIR GORBUNOV	{"email": "gorbunov-v-1975@postgrespro.ru", "phone": "+70263081323"}
0005432360250	1A15D2	1273 970141	ALEKSANDR NOVIKOV	{"email": "aleksandrnovikov.20101974@postgrespro.ru", "phone": "+70656427336"}
0005432360251	37D72B	2438 119781	ELIZAVETA KUZNECOVA	{"phone": "+70584395068"}
0005432360252	AF61EE	9904 237647	VERA VOROBEVA	{"email": "vvorobeva.1986@postgrespro.ru", "phone": "+70645940734"}
0005432360253	801F84	5768 619739	NATALYA ILINA	{"phone": "+70329716390"}
0005432360254	C9606E	7116 258231	VLADIMIR ILIN	{"phone": "+70058963340"}
0005432360255	A33B43	2458 445635	VYACHESLAV POPOV	{"phone": "+70667039446"}
0005432360256	A33B43	1444 996563	ROMAN SERGEEV	{"email": "roman.sergeev_011976@postgrespro.ru", "phone": "+70243888861"}
0005432360257	A7D787	5462 796751	DMITRIY SOROKIN	{"email": "dsorokin-1982@postgrespro.ru", "phone": "+70232368093"}
0005432360258	1172CC	8315 030482	VALERIYA MAKSIMOVA	{"phone": "+70883597257"}
0005432360259	7F386F	0513 227122	TATYANA ROMANOVA	{"phone": "+70344870875"}
0005432360260	C5321D	7255 109598	MARGARITA ALEKSANDROVA	{"phone": "+70865523170"}
0005432360261	8470E3	9810 774823	ALEKSANDR FEDOROV	{"phone": "+70948443626"}
0005432360262	73CE71	7725 842668	MARIYA VLASOVA	{"phone": "+70799279354"}
0005432360263	73CE71	1748 306135	SERGEY SCHERBAKOV	{"email": "sergeyscherbakov.1964@postgrespro.ru", "phone": "+70066108306"}
0005432360264	C0810C	2026 128661	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.031973@postgrespro.ru", "phone": "+70840260204"}
0005432360265	C0810C	4034 204702	ANDREY EGOROV	{"email": "egorov.a-13021975@postgrespro.ru", "phone": "+70026361975"}
0005432360266	F2A03A	8444 276568	GUZEL NIKOLAEVA	{"phone": "+70078671828"}
0005432360267	F2A03A	9586 392817	NIKOLAY TARASOV	{"email": "n-tarasov_09031983@postgrespro.ru", "phone": "+70606293429"}
0005432360268	F2A03A	8093 009113	ELENA KOZLOVA	{"email": "kozlova_e.15071968@postgrespro.ru", "phone": "+70193819536"}
0005432360269	1C8F64	8634 180648	SERGEY GRIGOREV	{"email": "sergey-grigorev.061980@postgrespro.ru", "phone": "+70224324895"}
0005432360270	446C14	4378 193749	MAKSIM SCHERBAKOV	{"email": "scherbakov_m091972@postgrespro.ru", "phone": "+70385502340"}
0005432360271	446C14	0306 209830	VALENTINA SOKOLOVA	{"email": "sokolova.valentina-22041970@postgrespro.ru", "phone": "+70349870510"}
0005432360272	83805C	4528 744775	OLGA PETROVA	{"email": "olga-petrova1971@postgrespro.ru", "phone": "+70302392086"}
0005432360273	C30AA6	1053 659472	TATYANA POLYAKOVA	{"email": "tatyanapolyakova-1972@postgrespro.ru", "phone": "+70623045636"}
0005432360274	1DEEF8	5661 891757	DMITRIY ILIN	{"phone": "+70439240136"}
0005432360275	1DEEF8	1066 800603	LYUDMILA NAUMOVA	{"email": "l.naumova-26031962@postgrespro.ru", "phone": "+70686027578"}
0005432360276	2C3B6B	1557 194250	ANASTASIYA BELOVA	{"email": "abelova.1970@postgrespro.ru", "phone": "+70869357263"}
0005432360277	FAA5C2	2308 316991	EKATERINA FEDOROVA	{"email": "fedorova_ekaterina.10031974@postgrespro.ru", "phone": "+70211817839"}
0005432360278	FAA5C2	0951 520747	YURIY KOROLEV	{"email": "korolev-y.1985@postgrespro.ru", "phone": "+70363297452"}
0005432360279	6BCF09	5876 263890	MARGARITA TIKHONOVA	{"email": "tikhonova.margarita.091984@postgrespro.ru", "phone": "+70033162559"}
0005432360280	1E5104	3178 094106	SERGEY IVANOV	{"email": "sergey-ivanov_1975@postgrespro.ru", "phone": "+70992064923"}
0005432360281	1E5104	5923 199860	DIANA ISAEVA	{"email": "isaeva.d.1967@postgrespro.ru", "phone": "+70611150112"}
0005432360282	BE7FB6	6502 059823	ARTEMIY NAZAROV	{"email": "a.nazarov05111965@postgrespro.ru", "phone": "+70740233447"}
0005432360283	BE7FB6	5791 066516	EVGENIYA DMITRIEVA	{"phone": "+70477997242"}
0005432360284	28C4AE	2723 925142	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov-051971@postgrespro.ru", "phone": "+70487516624"}
0005432360286	DB5965	6250 799559	OLGA KOROLEVA	{"phone": "+70875813918"}
0005432360287	8E1F5C	5040 026344	INNA GORBUNOVA	{"email": "gorbunova_i_091966@postgrespro.ru", "phone": "+70985666681"}
0005432360288	2BF882	5542 113204	KIRILL VOLKOV	{"email": "volkov_kirill_1970@postgrespro.ru", "phone": "+70765317735"}
0005432360289	9A1A99	4895 925404	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.121973@postgrespro.ru", "phone": "+70428945756"}
0005432360290	C01C6E	4357 694144	SVETLANA PETROVA	{"email": "petrova.svetlana111973@postgrespro.ru", "phone": "+70134823176"}
0005432360291	C01C6E	4315 292237	ALEKSANDR ALEKSEEV	{"phone": "+70804071570"}
0005432360292	C45C99	9351 963201	NATALYA BOGDANOVA	{"phone": "+70548700912"}
0005432360293	4D1607	6270 003516	TAMARA SEMENOVA	{"email": "tsemenova-23051965@postgrespro.ru", "phone": "+70661167249"}
0005432360294	D9FC09	6718 747023	VALENTINA MIKHAYLOVA	{"email": "valentina_mikhaylova-1967@postgrespro.ru", "phone": "+70721136150"}
0005432360295	C6E15B	1271 171952	ANTON ZHURAVLEV	{"email": "anton-zhuravlev-1970@postgrespro.ru", "phone": "+70007854161"}
0005432360296	179CE8	9637 086923	TATYANA LEBEDEVA	{"email": "lebedeva-t1972@postgrespro.ru", "phone": "+70166644735"}
0005432360297	620296	8218 959190	VLADIMIR SOLOVEV	{"phone": "+70837976163"}
0005432360298	620296	4534 282622	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay_1979@postgrespro.ru", "phone": "+70619000113"}
0005432360299	ADD47A	2099 558929	VIKTOR DAVYDOV	{"email": "viktor-davydov011969@postgrespro.ru", "phone": "+70765537531"}
0005432360300	5AB53A	0234 429134	EVGENIY ZHURAVLEV	{"email": "zhuravlev-evgeniy-1970@postgrespro.ru", "phone": "+70971691771"}
0005432360301	5AB53A	7201 642070	TAMARA KOLESNIKOVA	{"email": "kolesnikova.t_1973@postgrespro.ru", "phone": "+70430453077"}
0005432360302	C074B2	3918 650076	PAVEL AFANASEV	{"email": "pavel_afanasev.121974@postgrespro.ru", "phone": "+70622626406"}
0005432360303	C074B2	7263 082723	YANA NIKITINA	{"phone": "+70365321779"}
0005432360304	3BA5A9	5962 551764	YURIY KUZNECOV	{"phone": "+70040588363"}
0005432360305	026E98	3657 961479	NIKITA ZAKHAROV	{"phone": "+70300544034"}
0005432360306	F6A425	5542 813861	ANTONINA OSIPOVA	{"email": "aosipova04091965@postgrespro.ru", "phone": "+70639431750"}
0005432360307	F6A425	2832 406527	KRISTINA OVCHINNIKOVA	{"email": "kristina_ovchinnikova.1969@postgrespro.ru", "phone": "+70577501442"}
0005432360308	5C44EE	1721 819818	VADIM GRIGOREV	{"email": "grigorev.vadim.121985@postgrespro.ru", "phone": "+70267662434"}
0005432360309	5C44EE	8707 818993	GALINA POLYAKOVA	{"phone": "+70532049579"}
0005432360310	403716	6450 863068	ELENA FEDOROVA	{"phone": "+70069521213"}
0005432360311	403716	1741 658749	NIKOLAY MOROZOV	{"email": "morozov-n_031978@postgrespro.ru", "phone": "+70036538020"}
0005432360312	9D2E9B	9635 791032	VIKTOR KULIKOV	{"email": "vkulikov071972@postgrespro.ru", "phone": "+70924513098"}
0005432360313	643B1D	7042 254139	MARIYA RYABOVA	{"email": "ryabova-mariya_1959@postgrespro.ru", "phone": "+70076365213"}
0005432360314	643B1D	6405 460508	EKATERINA MARTYNOVA	{"phone": "+70494211345"}
0005432360315	16E410	5570 369244	LYUDMILA NESTEROVA	{"email": "nesterova_lyudmila051975@postgrespro.ru", "phone": "+70003458236"}
0005432360316	032B1C	6041 338996	ARSENIY POPOV	{"email": "popov-arseniy041968@postgrespro.ru", "phone": "+70166754566"}
0005432360317	40DF4F	4960 333078	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr-11081959@postgrespro.ru", "phone": "+70779338537"}
0005432360318	04F3E4	6326 560695	LILIYA KUZNECOVA	{"phone": "+70952836271"}
0005432360319	CF112A	3924 349621	YULIYA KOZLOVA	{"phone": "+70751929348"}
0005432360320	CF112A	3992 116020	IRAIDA FILIPPOVA	{"email": "filippova_i-071973@postgrespro.ru", "phone": "+70364852285"}
0005432360321	613B75	5652 059773	ARTEMIY KISELEV	{"email": "a.kiselev_111963@postgrespro.ru", "phone": "+70608256835"}
0005432360322	A74627	8123 148182	MARIYA AFANASEVA	{"email": "m-afanaseva-011968@postgrespro.ru", "phone": "+70749606256"}
0005432360323	A74627	0077 920633	LIDIYA NESTEROVA	{"email": "l.nesterova-1967@postgrespro.ru", "phone": "+70359229642"}
0005432360324	85796C	1494 804662	DMITRIY KUDRYASHOV	{"phone": "+70724475940"}
0005432360325	85796C	9421 041100	ALEKSEY MIKHAYLOV	{"email": "amikhaylov-1970@postgrespro.ru", "phone": "+70118843384"}
0005432360326	5A0603	1866 221196	BORIS SOLOVEV	{"email": "b-solovev_15021969@postgrespro.ru", "phone": "+70415472525"}
0005432360327	77D4E1	9703 653640	MIKHAIL ZHUKOV	{"email": "zhukov-mikhail.1971@postgrespro.ru", "phone": "+70623492958"}
0005432360328	2A8883	3747 518687	OLGA EGOROVA	{"email": "o.egorova_1969@postgrespro.ru", "phone": "+70332427432"}
0005432360329	A1E0BF	9506 476051	RAISA SOKOLOVA	{"email": "sokolovar.01111967@postgrespro.ru", "phone": "+70508272458"}
0005432360330	A1E0BF	8397 776367	VIKTOR MIKHAYLOV	{"phone": "+70408415170"}
0005432360331	F287C8	1925 645879	NADEZHDA YUDINA	{"phone": "+70240505725"}
0005432360332	28E606	2107 512155	VALENTINA NOVIKOVA	{"email": "valentina.novikova.1982@postgrespro.ru", "phone": "+70551609967"}
0005432360333	ED983F	7469 334876	MIKHAIL KRASNOV	{"email": "mikhail-krasnov-011976@postgrespro.ru", "phone": "+70284528399"}
0005432360334	3E161A	1891 020835	KLAVDIYA NIKITINA	{"email": "klavdiya_nikitina.1970@postgrespro.ru", "phone": "+70223363895"}
0005432360335	4B9997	1214 801064	SERGEY SMIRNOV	{"email": "smirnov_sergey-1971@postgrespro.ru", "phone": "+70051538547"}
0005432360336	9B297B	1282 631116	ANATOLIY EGOROV	{"email": "egorov_a1986@postgrespro.ru", "phone": "+70446299757"}
0005432360337	8CA646	6259 720243	ALEKSEY MELNIKOV	{"email": "aleksey_melnikov1973@postgrespro.ru", "phone": "+70597869451"}
0005432360338	8CA646	5014 296874	MARIYA VASILEVA	{"email": "mariya-vasileva1974@postgrespro.ru", "phone": "+70160377897"}
0005432360339	2A3EC4	8924 068232	SERGEY RODIONOV	{"phone": "+70444446735"}
0005432360340	E9DAB7	7819 794244	NIKOLAY KULIKOV	{"email": "nikolay-kulikov1967@postgrespro.ru", "phone": "+70414978632"}
0005432360341	CDC0CC	0684 414081	KLARA ROMANOVA	{"email": "romanovaklara-1975@postgrespro.ru", "phone": "+70449322045"}
0005432360342	CDC0CC	7117 203237	ALLA LEBEDEVA	{"email": "lebedeva.a_1967@postgrespro.ru", "phone": "+70425123377"}
0005432360343	7329D7	6859 083027	MARIYA SMIRNOVA	{"phone": "+70010514395"}
0005432360344	8E947D	8702 353999	SVETLANA AFANASEVA	{"email": "s_afanaseva16121978@postgrespro.ru", "phone": "+70240744825"}
0005432360345	8E947D	3942 029124	SERGEY KOZLOV	{"email": "s.kozlov_1963@postgrespro.ru", "phone": "+70271654471"}
0005432360346	8E947D	8336 109577	SERGEY CHERNOV	{"email": "schernov.031980@postgrespro.ru", "phone": "+70947136033"}
0005432360347	70F606	4347 218029	VALENTINA ZHUKOVA	{"email": "v_zhukova09121968@postgrespro.ru", "phone": "+70820084594"}
0005432360348	70F606	9547 121418	VLADIMIR VOROBEV	{"email": "vorobev-vladimir-121975@postgrespro.ru", "phone": "+70287377733"}
0005432360349	88D6E8	2823 444176	MIKHAIL GUSEV	{"phone": "+70002786520"}
0005432360350	88D6E8	3343 543613	ARINA KUZNECOVA	{"email": "akuznecova-091980@postgrespro.ru", "phone": "+70730042242"}
0005432360351	46F984	1696 740952	ILYAS FROLOV	{"email": "i.frolov_1977@postgrespro.ru", "phone": "+70004432778"}
0005432360352	46F984	1227 524511	OLGA POLYAKOVA	{"email": "polyakova_o19091967@postgrespro.ru", "phone": "+70195694257"}
0005432360353	F3F8DC	1551 072507	IGOR MOROZOV	{"phone": "+70322175521"}
0005432360354	6110DA	7106 471318	ELENA YAKOVLEVA	{"email": "yakovleva_elena_1967@postgrespro.ru", "phone": "+70900456304"}
0005432360355	4171F0	4206 587581	ANASTASIYA VASILEVA	{"email": "anastasiyavasileva.24081973@postgrespro.ru", "phone": "+70002835307"}
0005432360356	4171F0	1412 480540	TAMARA AKIMOVA	{"email": "akimova.tamara1978@postgrespro.ru", "phone": "+70761846561"}
0005432360357	0DEE04	6501 315964	RAISA KISELEVA	{"email": "raisa_kiseleva_31011977@postgrespro.ru", "phone": "+70892016285"}
0005432360358	0DEE04	7557 141064	ALEKSANDR SERGEEV	{"phone": "+70997002051"}
0005432360359	0DE675	8124 964099	NIKOLAY VASILEV	{"email": "n.vasilev_03081974@postgrespro.ru", "phone": "+70944212206"}
0005432360360	53F58A	4442 263254	VYACHESLAV KOROLEV	{"email": "korolev.v041962@postgrespro.ru", "phone": "+70359872146"}
0005432360361	344373	6065 872628	ALEKSEY STEPANOV	{"email": "a-stepanov_041984@postgrespro.ru", "phone": "+70255204707"}
0005432360362	0D5BBE	8873 508844	VLADIMIR FEDOROV	{"phone": "+70592113226"}
0005432360363	5B7EA3	6201 015743	EVGENIY KUZNECOV	{"phone": "+70184093484"}
0005432360364	1816E0	8352 866258	SERGEY SHEVCHENKO	{"email": "shevchenko-s-1970@postgrespro.ru", "phone": "+70333352649"}
0005432360365	802A08	4581 889118	NIKOLAY POPOV	{"email": "nikolay_popov_16121971@postgrespro.ru", "phone": "+70966803901"}
0005432360366	E20547	2618 303929	ALEKSANDR ZHURAVLEV	{"phone": "+70829531003"}
0005432360367	9E32D1	1289 367257	NATALYA KOLESNIKOVA	{"phone": "+70687175577"}
0005432360368	A40CB4	6112 916806	DARYA SERGEEVA	{"email": "d.sergeeva30031984@postgrespro.ru", "phone": "+70945475522"}
0005432360369	5466FB	9812 656797	ALEKSANDRA ORLOVA	{"email": "orlovaa.111976@postgrespro.ru", "phone": "+70934298467"}
0005432360370	01E247	4838 166322	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov.1968@postgrespro.ru", "phone": "+70553439303"}
0005432360371	8CFBD4	7301 911489	IGOR MAKSIMOV	{"phone": "+70932599415"}
0005432360372	8CFBD4	5192 529190	SERGEY ZAKHAROV	{"phone": "+70629701746"}
0005432360373	8CFBD4	8546 109013	ALEKSANDR GAVRILOV	{"phone": "+70970995756"}
0005432360374	07CF1D	8850 263801	OLGA NOVIKOVA	{"email": "o-novikova26101975@postgrespro.ru", "phone": "+70537662837"}
0005432360375	775A00	7896 480216	VERA BORISOVA	{"email": "v_borisova02031972@postgrespro.ru", "phone": "+70767495308"}
0005432360376	C104C1	6975 382038	GENNADIY KUZNECOV	{"phone": "+70497532960"}
0005432360377	CBEAC0	9109 377476	IGOR ANDREEV	{"phone": "+70980879007"}
0005432360378	1A66EA	0788 608933	ANASTASIYA NOVIKOVA	{"email": "anovikova-101962@postgrespro.ru", "phone": "+70824461758"}
0005432360379	1A66EA	5812 155260	MARAT DMITRIEV	{"phone": "+70584402794"}
0005432360380	35999E	6613 354601	VITALIY SIDOROV	{"phone": "+70228433980"}
0005432360381	1FCD7C	3792 472754	MAKSIM KOZLOV	{"email": "mkozlov071972@postgrespro.ru", "phone": "+70030069897"}
0005432360382	F96997	6469 940139	ANNA ANTONOVA	{"phone": "+70098357455"}
0005432360383	DA9230	8876 478864	SVETLANA PAVLOVA	{"phone": "+70474768354"}
0005432360384	248F64	4835 160559	RAISA DENISOVA	{"email": "denisova-r-091971@postgrespro.ru", "phone": "+70811057758"}
0005432360385	FD39AC	9635 419919	IRINA SEMENOVA	{"email": "i-semenova.091973@postgrespro.ru", "phone": "+70301714578"}
0005432360386	9C669F	3690 403615	DARYA ALEKSANDROVA	{"phone": "+70920602538"}
0005432360387	9C669F	1474 673963	VALERIY GAVRILOV	{"email": "gavrilov-v_28111971@postgrespro.ru", "phone": "+70198605556"}
0005432360388	E9187C	4984 039850	ELENA KRASNOVA	{"email": "krasnova-elena_111966@postgrespro.ru", "phone": "+70660883918"}
0005432360389	6D6DF5	1818 163483	VIKTOR ILIN	{"phone": "+70016965233"}
0005432360390	F07510	7712 049728	YULIYA NIKIFOROVA	{"email": "ynikiforova.10061975@postgrespro.ru", "phone": "+70759314494"}
0005432360391	F07510	5488 848339	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.nikolay031974@postgrespro.ru", "phone": "+70072600443"}
0005432360392	04402F	0610 955796	KSENIYA KOVALEVA	{"email": "kseniya.kovaleva-28021966@postgrespro.ru", "phone": "+70189370080"}
0005432360393	04402F	0966 706098	ALEKSANDR GAVRILOV	{"phone": "+70944822719"}
0005432360394	C5F31A	1741 282325	TATYANA IVANOVA	{"phone": "+70151356269"}
0005432360395	C5F31A	0216 307110	YANA KARPOVA	{"email": "karpova_y.051984@postgrespro.ru", "phone": "+70437992747"}
0005432360396	4D1105	7202 555164	ANASTASIYA FROLOVA	{"phone": "+70568153591"}
0005432360397	4D1105	8907 737657	ANDREY NAZAROV	{"email": "a-nazarov_15101974@postgrespro.ru", "phone": "+70938208347"}
0005432360398	D4B3A1	8854 593682	LYUBOV OSIPOVA	{"phone": "+70867441236"}
0005432360399	C83EA3	3458 431631	NIKOLAY ISAEV	{"phone": "+70599192621"}
0005432360400	C83EA3	1004 082041	SVETLANA ZOTOVA	{"email": "s.zotova_1983@postgrespro.ru", "phone": "+70178864150"}
0005432360401	7DFBFF	3805 993739	VIKTOR SCHERBAKOV	{"email": "scherbakov.v-24101978@postgrespro.ru", "phone": "+70132042968"}
0005432360402	B5CB52	2690 594677	GALINA VOROBEVA	{"phone": "+70498157470"}
0005432360403	B5CB52	2607 263657	ALEKSEY SEMENOV	{"email": "aleksey.semenov-021985@postgrespro.ru", "phone": "+70195395826"}
0005432360404	508D1B	0755 167643	ALEKSANDRA KRASNOVA	{"email": "krasnova-a_121968@postgrespro.ru", "phone": "+70786531754"}
0005432360405	A0B7D7	0401 347658	MARINA VOLKOVA	{"phone": "+70675898752"}
0005432360406	A0B7D7	5296 959926	ELENA ALEKSANDROVA	{"phone": "+70529699845"}
0005432360407	4EBD0E	7157 791946	OLEG KUZNECOV	{"phone": "+70350722733"}
0005432360408	4EBD0E	2983 337730	PAVEL KUZNECOV	{"email": "kuznecov.p.1973@postgrespro.ru", "phone": "+70283238070"}
0005432360409	9A228C	8941 689245	DARYA BELOVA	{"email": "belova.darya-1976@postgrespro.ru", "phone": "+70611766931"}
0005432360410	129F72	3634 739816	DARYA ERMAKOVA	{"email": "ermakova_d.041985@postgrespro.ru", "phone": "+70735540033"}
0005432360411	463606	1364 882649	DMITRIY NAZAROV	{"email": "d.nazarov.1966@postgrespro.ru", "phone": "+70995255744"}
0005432360412	7F5D68	7568 892847	MAYYA TITOVA	{"phone": "+70023936497"}
0005432360413	7F5D68	7060 213962	SERGEY PETROV	{"phone": "+70409646893"}
0005432360414	44957E	9998 595017	VERA FADEEVA	{"email": "fadeeva_vera.091974@postgrespro.ru", "phone": "+70330431534"}
0005432360415	44957E	2319 820075	VIKTOR MIRONOV	{"email": "mironov_v.11121975@postgrespro.ru", "phone": "+70943482573"}
0005432360416	499F21	8426 933069	DENIS GAVRILOV	{"phone": "+70012535651"}
0005432360417	499F21	3420 493587	ARINA KOROLEVA	{"email": "a-koroleva_01031977@postgrespro.ru", "phone": "+70880954651"}
0005432360418	499F21	8413 432717	NIKOLAY KUZNECOV	{"email": "kuznecov-n_041967@postgrespro.ru", "phone": "+70468332459"}
0005432360419	0E510D	3500 148258	ELENA PAVLOVA	{"phone": "+70542215820"}
0005432360420	227C80	1710 734212	NATALYA FROLOVA	{"email": "frolova_natalya_1981@postgrespro.ru", "phone": "+70398567293"}
0005432360421	227C80	0949 515036	ALENA KOLESNIKOVA	{"email": "kolesnikova-a_1971@postgrespro.ru", "phone": "+70722979675"}
0005432360422	879A36	5104 580752	ALEKSANDR STEPANOV	{"phone": "+70403824581"}
0005432360423	879A36	1424 560737	MIKHAIL SAVELEV	{"phone": "+70180694920"}
0005432360424	088E4D	3637 126932	ANATOLIY EGOROV	{"email": "egorovanatoliy1966@postgrespro.ru", "phone": "+70913651099"}
0005432360425	088E4D	5583 959550	YULIYA GORBUNOVA	{"phone": "+70296737400"}
0005432360426	7032F8	9917 940806	ELENA BORISOVA	{"email": "borisovaelena-01011975@postgrespro.ru", "phone": "+70422072587"}
0005432360427	7032F8	1982 772892	VIKTOR KAZAKOV	{"phone": "+70593770913"}
0005432360428	7032F8	1723 765079	EVGENIYA ERMAKOVA	{"email": "ermakovae011980@postgrespro.ru", "phone": "+70569398044"}
0005432360429	35E5E1	2827 135852	MIKHAIL BARANOV	{"phone": "+70368257552"}
0005432360430	0137BA	4070 329130	ALLA ZHURAVLEVA	{"email": "zhuravleva_alla_02041976@postgrespro.ru", "phone": "+70560342850"}
0005432360431	90DCD3	3688 381410	NIKITA FROLOV	{"email": "frolovn091986@postgrespro.ru", "phone": "+70611420866"}
0005432360432	90DCD3	7744 727557	TATYANA MOROZOVA	{"phone": "+70325616780"}
0005432360433	10B327	9756 692212	LYUDMILA GRISHINA	{"phone": "+70051335586"}
0005432360434	9B4513	4292 489018	TATYANA ROMANOVA	{"phone": "+70074329297"}
0005432360435	9B4513	0425 329350	ANATOLIY CHERNOV	{"email": "anatoliy_chernov_021971@postgrespro.ru", "phone": "+70557156943"}
0005432360436	DFC459	3936 491472	ANDREY BARANOV	{"email": "baranova_1979@postgrespro.ru", "phone": "+70002022186"}
0005432360437	AA8ED8	4828 371362	ANTONIDA TIMOFEEVA	{"email": "timofeeva-a_021973@postgrespro.ru", "phone": "+70920596472"}
0005432360438	AA8ED8	1656 416777	OLGA NIKITINA	{"phone": "+70232169610"}
0005432360439	82FB57	4138 832909	VLADIMIR PAVLOV	{"email": "pavlov.vladimir-031959@postgrespro.ru", "phone": "+70623188921"}
0005432360440	F1AE8C	1671 431807	ALEKSEY SOROKIN	{"email": "sorokin.aleksey061968@postgrespro.ru", "phone": "+70394566756"}
0005432360441	B99EF2	8381 344193	MARIYA YAKOVLEVA	{"email": "yakovlevamariya_20041972@postgrespro.ru", "phone": "+70932161818"}
0005432360442	51EBC3	9810 397889	KRISTINA LUKYANOVA	{"email": "lukyanova.kristina_091970@postgrespro.ru", "phone": "+70734187085"}
0005432360443	51EBC3	3791 826026	OLGA CHERNOVA	{"email": "chernova-olga.1979@postgrespro.ru", "phone": "+70257826587"}
0005432360444	25FB75	6500 939636	IGOR GAVRILOV	{"email": "igavrilov-1969@postgrespro.ru", "phone": "+70023079614"}
0005432360445	25FB75	9087 419399	LYUBOV FILATOVA	{"email": "lfilatova_1965@postgrespro.ru", "phone": "+70046028871"}
0005432360446	EC230F	6896 386195	TAMARA VOROBEVA	{"phone": "+70733092545"}
0005432360447	EC230F	6175 627005	OLGA ISAEVA	{"email": "isaeva.o_08091967@postgrespro.ru", "phone": "+70503192470"}
0005432360448	EC230F	8279 493218	EKATERINA DENISOVA	{"phone": "+70119667713"}
0005432360449	96F888	1748 852726	YULIYA BOGDANOVA	{"phone": "+70602826192"}
0005432360450	96F888	5164 588293	RIMMA IVANOVA	{"phone": "+70802838025"}
0005432360451	A23021	5578 166510	VLADIMIR MIKHAYLOV	{"phone": "+70338736456"}
0005432360452	ECC426	9723 893149	MAKSIM KUZMIN	{"email": "kuzmin-maksim_091968@postgrespro.ru", "phone": "+70719566782"}
0005432360453	65AD73	1275 649672	DMITRIY MIRONOV	{"phone": "+70054151680"}
0005432360454	C99B36	8860 529266	SERGEY POPOV	{"email": "popov-s25121971@postgrespro.ru", "phone": "+70637747032"}
0005432360455	7D8BEC	9128 990960	EVGENIY VASILEV	{"email": "e_vasilev-1967@postgrespro.ru", "phone": "+70579162807"}
0005432360456	7D8BEC	8309 688694	OLEG SCHERBAKOV	{"email": "oleg.scherbakov_011971@postgrespro.ru", "phone": "+70809671360"}
0005432360457	7DF060	5200 890294	MARIYA SOKOLOVA	{"phone": "+70971674004"}
0005432360458	7DF060	4610 457038	DMITRIY AFANASEV	{"phone": "+70560221922"}
0005432360459	DDCCC7	6260 181346	LYUBOV KUZNECOVA	{"email": "kuznecova.l01081974@postgrespro.ru", "phone": "+70817632596"}
0005432360460	5C5D6D	2049 297324	PAVEL FROLOV	{"email": "frolovp04051986@postgrespro.ru", "phone": "+70275120458"}
0005432360461	628D72	5056 310205	TATYANA NAZAROVA	{"phone": "+70347853919"}
0005432360462	624D4D	1312 893968	EKATERINA PAVLOVA	{"email": "ekaterina-pavlova1959@postgrespro.ru", "phone": "+70381394764"}
0005432360463	888951	8066 325086	NATALYA ZAKHAROVA	{"email": "zakharovan.05061983@postgrespro.ru", "phone": "+70792942413"}
0005432360464	591671	1963 095996	VERA MASLOVA	{"email": "v_maslova041987@postgrespro.ru", "phone": "+70966769270"}
0005432360465	8F99C5	5676 298060	ALEKSANDR GUSEV	{"email": "aleksandr_gusev14011970@postgrespro.ru", "phone": "+70497891660"}
0005432360466	DDE5F9	3236 483050	TATYANA MIKHAYLOVA	{"phone": "+70289368371"}
0005432360467	FB1C63	1192 319768	ANTON ZHURAVLEV	{"email": "zhuravlev.anton-121969@postgrespro.ru", "phone": "+70048149373"}
0005432360468	DF6271	8033 238863	ELIZAVETA EGOROVA	{"email": "e-egorova.1977@postgrespro.ru", "phone": "+70593998521"}
0005432360469	DF6271	3065 036773	VLADIMIR SOKOLOV	{"email": "sokolovvladimir.1965@postgrespro.ru", "phone": "+70918108051"}
0005432360470	FBBC62	2817 569982	MAKSIM PETROV	{"phone": "+70769413892"}
0005432360471	911A96	0957 905125	RAISA ABRAMOVA	{"email": "abramova_r-051967@postgrespro.ru", "phone": "+70419895720"}
0005432360472	015684	0233 522265	GALINA MAKAROVA	{"email": "galinamakarova-051978@postgrespro.ru", "phone": "+70433777958"}
0005432360473	1F5459	4492 918972	ANASTASIYA GUSEVA	{"email": "guseva-anastasiya_17051964@postgrespro.ru", "phone": "+70873073413"}
0005432360474	00BF87	5942 134294	GALINA LEBEDEVA	{"email": "glebedeva-041974@postgrespro.ru", "phone": "+70110837928"}
0005432360475	2421B3	9392 139595	NADEZHDA FEDOROVA	{"email": "fedorovanadezhda.26031970@postgrespro.ru", "phone": "+70693124827"}
0005432360476	2421B3	3041 271578	NADEZHDA DANILOVA	{"email": "danilova.nadezhda.1973@postgrespro.ru", "phone": "+70675486302"}
0005432360477	709189	5826 967438	ANASTASIYA ZHUKOVA	{"phone": "+70020978381"}
0005432360478	709189	7066 330873	ALEKSEY VLASOV	{"phone": "+70869304784"}
0005432360479	FAA9D7	7233 771592	VITALIY GUSEV	{"email": "vitaliy-gusev_011973@postgrespro.ru", "phone": "+70591412471"}
0005432360480	FAA9D7	3688 615867	TAMARA ORLOVA	{"email": "tamaraorlova.22111980@postgrespro.ru", "phone": "+70620950342"}
0005432360481	DD5CF1	5057 828048	ZAKHAR MIRONOV	{"email": "z.mironov_1970@postgrespro.ru", "phone": "+70106284292"}
0005432360482	DD5CF1	6013 033852	TATYANA TARASOVA	{"phone": "+70665866939"}
0005432360483	ABF507	8736 329867	ANTON ANDREEV	{"phone": "+70502702015"}
0005432360484	1A4CAB	9967 610157	VLADIMIR KONOVALOV	{"phone": "+70328428879"}
0005432360485	17437B	7310 703053	ANATOLIY SHEVCHENKO	{"email": "anatoliy.shevchenko_1965@postgrespro.ru", "phone": "+70100650822"}
0005432360486	C5F0A4	2283 154043	OLGA DAVYDOVA	{"phone": "+70897723798"}
0005432360487	F3D694	1383 649107	ELENA NIKIFOROVA	{"email": "e-nikiforova-15111974@postgrespro.ru", "phone": "+70580374974"}
0005432360488	993C10	6262 484374	MIKHAIL KOZLOV	{"email": "mikhailkozlov.30041980@postgrespro.ru", "phone": "+70999079504"}
0005432360489	72F16A	1388 400277	TAMARA ANISIMOVA	{"phone": "+70268720926"}
0005432360490	CD1EF1	4357 403382	GALINA BARANOVA	{"phone": "+70649338025"}
0005432360491	CB76E2	6003 045642	OLGA MAKAROVA	{"phone": "+70092417198"}
0005432360492	96FA1A	3099 188381	DMITRIY DENISOV	{"phone": "+70048715128"}
0005432360493	96FA1A	6391 150017	BORIS MOROZOV	{"phone": "+70717503186"}
0005432360494	96FA1A	4549 191834	NADEZHDA TIKHONOVA	{"phone": "+70450449409"}
0005432360495	96FA1A	3780 182200	VENERA MARTYNOVA	{"email": "martynova-venera.1962@postgrespro.ru", "phone": "+70913525441"}
0005432360496	A789C3	1595 136974	ROMAN VASILEV	{"email": "vasilevroman_1963@postgrespro.ru", "phone": "+70927450850"}
0005432360497	A789C3	0235 488352	ALEKSEY SMIRNOV	{"email": "smirnov.aleksey111975@postgrespro.ru", "phone": "+70116132039"}
0005432360498	F36891	4589 961743	MIKHAIL VOLKOV	{"email": "volkov_m1974@postgrespro.ru", "phone": "+70803878828"}
0005432360499	66131F	8631 877123	NATALYA RODIONOVA	{"phone": "+70859252426"}
0005432360500	2E513C	1014 476804	ALENA CHERNOVA	{"phone": "+70510506850"}
0005432360501	EDD662	7712 538036	VASILIY VOROBEV	{"email": "v.vorobev_081978@postgrespro.ru", "phone": "+70429230521"}
0005432360502	58DE33	3232 961769	NINA SOLOVEVA	{"email": "solovevanina1969@postgrespro.ru", "phone": "+70581251508"}
0005432360503	576815	0132 246753	VALENTINA BELYAEVA	{"email": "belyaeva.valentina-1975@postgrespro.ru", "phone": "+70471611235"}
0005432360504	DE12C2	3682 004217	LYUDMILA SOLOVEVA	{"email": "soloveval_101966@postgrespro.ru", "phone": "+70681370589"}
0005432360505	DE12C2	7034 822758	VLADIMIR ALEKSEEV	{"email": "alekseevv.1970@postgrespro.ru", "phone": "+70802434937"}
0005432360506	E09660	6007 203054	ANDREY BELOV	{"email": "belovandrey.1964@postgrespro.ru", "phone": "+70832660662"}
0005432360507	6241D0	8221 866082	VLADIMIR ROMANOV	{"phone": "+70166058062"}
0005432360508	62FFD5	7155 478027	YULIYA SEMENOVA	{"email": "semenova-y-021962@postgrespro.ru", "phone": "+70885178771"}
0005432360509	0F0C41	6859 146329	VLADISLAV PETROV	{"phone": "+70567967715"}
0005432360510	0F0C41	6125 155451	NIKOLAY POPOV	{"phone": "+70671737871"}
0005432360511	0F0C41	3462 097740	ANDREY IVANOV	{"email": "andrey_ivanov_121980@postgrespro.ru", "phone": "+70280514861"}
0005432360512	BEF3EB	1985 476647	YURIY RODIONOV	{"phone": "+70687719007"}
0005432360513	C8ECF9	7778 524064	ALEKSEY KRASNOV	{"phone": "+70874998729"}
0005432360514	4D9A33	9508 567601	ALEKSANDR FROLOV	{"email": "frolov.aleksandr.1975@postgrespro.ru", "phone": "+70893077355"}
0005432360515	4D9A33	3364 158407	VIKTOR FROLOV	{"email": "viktor.frolov31081976@postgrespro.ru", "phone": "+70841224148"}
0005432360516	45FB0D	7025 100689	MIKHAIL VLASOV	{"email": "mikhail_vlasov-20101975@postgrespro.ru", "phone": "+70273888070"}
0005432360517	AE3779	1555 158774	OLESYA IVANOVA	{"email": "ivanova.o.1970@postgrespro.ru", "phone": "+70154501789"}
0005432360518	AE3779	4238 095771	EVGENIYA NIKIFOROVA	{"phone": "+70394589097"}
0005432360519	8447DC	9328 531812	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov-1972@postgrespro.ru", "phone": "+70494805641"}
0005432360520	47FBF6	5645 807900	EVGENIY IVANOV	{"phone": "+70547509973"}
0005432360521	47FBF6	6279 939280	INESSA ORLOVA	{"phone": "+70950657767"}
0005432360522	DF8019	6571 180292	OLEG IVANOV	{"phone": "+70132752466"}
0005432360523	790359	7876 070333	NAIL SOLOVEV	{"email": "nail_solovev021967@postgrespro.ru", "phone": "+70505876343"}
0005432360524	214B64	4579 361428	VIKTOR FEDOTOV	{"phone": "+70819338970"}
0005432360525	C6F575	1887 453357	GRIGORIY SMIRNOV	{"email": "smirnov.grigoriy_1975@postgrespro.ru", "phone": "+70915881534"}
0005432360526	78DBFE	9487 151786	NIKITA MAKAROV	{"email": "makarov-nikita041972@postgrespro.ru", "phone": "+70390993981"}
0005432360527	B5E042	5250 696672	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy_10101974@postgrespro.ru", "phone": "+70503035242"}
0005432360528	F05953	2794 489627	MIKHAIL MATVEEV	{"phone": "+70548374559"}
0005432360529	E9B983	6772 681468	VYACHESLAV GORBUNOV	{"phone": "+70741246176"}
0005432360530	E9B983	7225 186539	VALENTINA KOROLEVA	{"email": "v-koroleva-051965@postgrespro.ru", "phone": "+70254536236"}
0005432360531	55BA11	5115 243405	YURIY SCHERBAKOV	{"email": "yuriy_scherbakov-22011976@postgrespro.ru", "phone": "+70354315195"}
0005432360532	F8267D	6497 956184	SERGEY SAVELEV	{"email": "savelev_sergey_1968@postgrespro.ru", "phone": "+70230633812"}
0005432360533	F8267D	8758 254071	ANATOLIY NAZAROV	{"email": "a_nazarov_18071955@postgrespro.ru", "phone": "+70747604585"}
0005432360534	3B0A46	6854 379978	SERGEY ZAKHAROV	{"email": "zakharov_sergey.08011969@postgrespro.ru", "phone": "+70720602130"}
0005432360535	B5165E	0737 646757	OLGA OSIPOVA	{"phone": "+70598582079"}
0005432360536	C87B9A	3567 819496	MIKHAIL ISAEV	{"email": "isaev.mikhail16051972@postgrespro.ru", "phone": "+70042075009"}
0005432360537	FD2EC5	8850 277165	NADEZHDA KALININA	{"phone": "+70807699733"}
0005432360538	3D85AF	3372 357780	MARIYA VASILEVA	{"email": "vasilevam_17111963@postgrespro.ru", "phone": "+70181046589"}
0005432360539	3D85AF	8274 052213	MIKHAIL PETROV	{"email": "m.petrov091974@postgrespro.ru", "phone": "+70842820999"}
0005432360540	919C86	1844 699306	OLGA EFIMOVA	{"phone": "+70360429924"}
0005432360541	919C86	4472 809749	LIDIYA SEMENOVA	{"email": "lidiya_semenova-061963@postgrespro.ru", "phone": "+70028298144"}
0005432360542	64CA5A	2532 182372	VLADIMIR SEMENOV	{"email": "semenov.v051968@postgrespro.ru", "phone": "+70696017503"}
0005432360543	A7510E	9955 741717	FARIDA KOLESNIKOVA	{"phone": "+70290389045"}
0005432360544	A7510E	2685 769978	SERGEY GAVRILOV	{"phone": "+70201007648"}
0005432360545	47DE30	1392 437492	ALEKSANDR FEDOROV	{"phone": "+70194147105"}
0005432360546	47DE30	4269 041097	YULIYA TIMOFEEVA	{"phone": "+70962186042"}
0005432360547	C2250A	5900 164804	MAKSIM NOVIKOV	{"email": "novikov.m.021974@postgrespro.ru", "phone": "+70692131956"}
0005432360548	325440	7943 590518	LIDIYA FEDOROVA	{"phone": "+70376473204"}
0005432360549	325440	9899 433890	ALEKSANDR FROLOV	{"phone": "+70878841643"}
0005432360550	756BEF	4031 568939	SERGEY POPOV	{"phone": "+70564607875"}
0005432360551	382BA9	9757 442679	NIKOLAY TARASOV	{"email": "tarasov_nikolay-16121954@postgrespro.ru", "phone": "+70424714104"}
0005432360552	BF29C6	4578 847778	IVAN DENISOV	{"phone": "+70106248269"}
0005432360553	BF29C6	9920 199988	VLADIMIR IVANOV	{"email": "vivanov.091969@postgrespro.ru", "phone": "+70428064796"}
0005432360554	43B885	8237 227921	OLESYA TITOVA	{"email": "titovaolesya-011979@postgrespro.ru", "phone": "+70235347998"}
0005432360555	43B885	4207 841781	VLADISLAV PAVLOV	{"phone": "+70845564366"}
0005432360556	BB7DC0	4238 566301	ZOYA BOGDANOVA	{"email": "bogdanova.zoya_18031958@postgrespro.ru", "phone": "+70302557648"}
0005432360557	BB7DC0	4730 432320	ALEKSANDR ZAKHAROV	{"phone": "+70594266975"}
0005432360558	1B5CE6	3915 073798	SVETLANA POTAPOVA	{"phone": "+70611570287"}
0005432360559	B97582	7503 787874	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.1976@postgrespro.ru", "phone": "+70884268211"}
0005432360560	307AF5	7141 610875	ANDREY DENISOV	{"phone": "+70458583403"}
0005432360561	98B640	6816 498686	GENNADIY MAKSIMOV	{"email": "gennadiy.maksimov1980@postgrespro.ru", "phone": "+70987818397"}
0005432360562	F5DC14	5855 872920	PETR ROMANOV	{"email": "romanov_petr.07011964@postgrespro.ru", "phone": "+70022485437"}
0005432360563	B93F3D	4489 339046	YURIY KUZNECOV	{"email": "kuznecov-yuriy-1975@postgrespro.ru", "phone": "+70571440685"}
0005432360564	86D703	4946 638121	ALEKSANDR FEDOROV	{"phone": "+70814770263"}
0005432360565	9DA9BD	5280 604491	VALENTINA MELNIKOVA	{"phone": "+70819196706"}
0005432360566	9DA9BD	0484 454440	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr051982@postgrespro.ru", "phone": "+70307592071"}
0005432360567	9DA9BD	8101 887144	EKATERINA MIRONOVA	{"email": "e-mironova-14031968@postgrespro.ru", "phone": "+70642990245"}
0005432360568	6899C5	0637 046017	ELENA GERASIMOVA	{"email": "elena_gerasimova.111974@postgrespro.ru", "phone": "+70991840218"}
0005432360569	6899C5	9497 710571	VIKTORIYA SERGEEVA	{"email": "v-sergeeva-24051966@postgrespro.ru", "phone": "+70908489868"}
0005432360570	4845C0	2704 045793	IRINA KARPOVA	{"email": "karpova_irina23071973@postgrespro.ru", "phone": "+70407261753"}
0005432360571	BE468C	3535 314784	ANDREY STEPANOV	{"email": "stepanov-andrey011977@postgrespro.ru", "phone": "+70575129040"}
0005432360572	606C79	1620 219110	MATVEY DENISOV	{"phone": "+70944704097"}
0005432360573	606C79	0817 222335	MIKHAIL FILIPPOV	{"email": "filippov.mikhail101973@postgrespro.ru", "phone": "+70493668487"}
0005432360574	3D88BD	7023 090028	YURIY KUZNECOV	{"phone": "+70363017791"}
0005432360575	6C5936	2612 321433	VYACHESLAV KONOVALOV	{"email": "v.konovalov15111966@postgrespro.ru", "phone": "+70350145342"}
0005432360576	42AB7F	9984 821796	NIKITA CHERNOV	{"phone": "+70951703604"}
0005432360577	42AB7F	3163 134274	DMITRIY GUSEV	{"phone": "+70297680236"}
0005432360578	140CE9	6212 387727	OLGA SEMENOVA	{"phone": "+70554358365"}
0005432360579	4C14B9	5326 008508	VIKTOR MIRONOV	{"email": "viktor_mironov_051968@postgrespro.ru", "phone": "+70014483453"}
0005432360580	581428	0181 484926	KARINA BELOVA	{"phone": "+70406259494"}
0005432360581	6F5C36	5780 540103	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail-1972@postgrespro.ru", "phone": "+70011043497"}
0005432360582	04C452	1352 393776	NATALYA MOROZOVA	{"email": "morozova-n_1976@postgrespro.ru", "phone": "+70065112739"}
0005432360583	9F203F	0621 320186	LYUDMILA KUZNECOVA	{"phone": "+70745627331"}
0005432360584	FE839B	3714 706204	ALEKSEY ANDREEV	{"email": "andreev.aleksey1972@postgrespro.ru", "phone": "+70210275041"}
0005432360585	9467F8	1086 554167	YAROSLAV MIKHAYLOV	{"phone": "+70237171141"}
0005432360586	B16902	8769 583227	VADIM FEDOROV	{"email": "v_fedorov-101971@postgrespro.ru", "phone": "+70937903067"}
0005432360587	B6AA76	2460 383489	IRINA ABRAMOVA	{"email": "i.abramova_1973@postgrespro.ru", "phone": "+70425228548"}
0005432360588	B6AA76	9374 963972	ANASTASIYA NAUMOVA	{"email": "a_naumova.25051977@postgrespro.ru", "phone": "+70083289832"}
0005432360589	0CEFE8	4632 227577	YURIY KUZNECOV	{"phone": "+70989032307"}
0005432360590	884EB1	0415 551664	MAKSIM FEDOTOV	{"email": "fedotov_maksim_011968@postgrespro.ru", "phone": "+70089308720"}
0005432360591	884EB1	8230 380678	TAMARA NAZAROVA	{"phone": "+70734861320"}
0005432360592	9A1847	6389 683852	PETR GUSEV	{"email": "gusevp-04071964@postgrespro.ru", "phone": "+70660585761"}
0005432360593	D328E1	4068 131096	ELENA KOVALEVA	{"email": "e.kovaleva25081976@postgrespro.ru", "phone": "+70601097387"}
0005432360594	279FBA	4323 246094	ALEKSANDR MAKAROV	{"phone": "+70520697532"}
0005432360595	279FBA	8033 133502	ELENA BARANOVA	{"email": "baranova.e.1970@postgrespro.ru", "phone": "+70020187267"}
0005432360596	279FBA	7737 800021	ALEKSANDR NOVIKOV	{"phone": "+70967644004"}
0005432360597	E22242	7269 616454	YAROSLAV SERGEEV	{"email": "sergeevy_1970@postgrespro.ru", "phone": "+70524004519"}
0005432360598	19DD20	1593 738472	RUSTAM NOVIKOV	{"email": "rustam_novikov_02061967@postgrespro.ru", "phone": "+70952262025"}
0005432360599	0F8F87	5888 116155	OLEG FOMIN	{"phone": "+70388675124"}
0005432360600	5E905D	4382 648459	EVGENIYA VOLKOVA	{"phone": "+70899226941"}
0005432360601	5E905D	3439 541573	LIDIYA PAVLOVA	{"email": "lpavlova1981@postgrespro.ru", "phone": "+70032045668"}
0005432360602	2EE5FE	3080 685989	YURIY BONDARENKO	{"phone": "+70916003993"}
0005432360603	2D6826	2667 084935	VIKTORIYA POLYAKOVA	{"phone": "+70744083774"}
0005432360604	2D6826	0304 841267	YURIY BORISOV	{"email": "borisov-y09081974@postgrespro.ru", "phone": "+70719349948"}
0005432360605	43380F	3756 555198	DENIS GAVRILOV	{"phone": "+70404865303"}
0005432360606	7426E8	5116 764773	VALENTINA VOROBEVA	{"phone": "+70838856994"}
0005432360607	7426E8	1560 706848	VIKTORIYA AFANASEVA	{"email": "afanasevaviktoriya-1986@postgrespro.ru", "phone": "+70879920797"}
0005432360608	7426E8	6413 191252	OLGA FOMINA	{"phone": "+70083291788"}
0005432360609	F3F985	5013 918377	VASILIY FEDOROV	{"email": "fedorovv_1976@postgrespro.ru", "phone": "+70925906929"}
0005432360610	F3F985	2598 402714	YULIYA BOGDANOVA	{"phone": "+70077124920"}
0005432360611	D43868	7936 639600	NINA DMITRIEVA	{"email": "n-dmitrieva1977@postgrespro.ru", "phone": "+70922599776"}
0005432360612	ED1269	7612 057494	VERONIKA IVANOVA	{"phone": "+70826667064"}
0005432360613	ED1269	1153 487378	DANIIL STEPANOV	{"phone": "+70024880140"}
0005432360614	185FDB	6141 099565	ELENA BORISOVA	{"phone": "+70610222342"}
0005432360615	5C088A	0263 672301	ALEKSEY IVANOV	{"phone": "+70634889355"}
0005432360616	9F5AE5	0184 368799	ALEKSEY ZAYCEV	{"email": "aleksey_zaycev.091962@postgrespro.ru", "phone": "+70257151038"}
0005432360617	92834C	3397 523601	VLADIMIR SAVELEV	{"phone": "+70555342683"}
0005432360618	92834C	2529 782288	OLEG ZAKHAROV	{"phone": "+70174923587"}
0005432360619	7DDF3D	1486 584604	VLADIMIR OSIPOV	{"email": "vladimir_osipov18021976@postgrespro.ru", "phone": "+70102300506"}
0005432360620	7DDF3D	7035 106933	MARINA DENISOVA	{"phone": "+70356413287"}
0005432360621	AF7D4C	0960 550755	NATALYA MASLOVA	{"email": "n.maslova-041956@postgrespro.ru", "phone": "+70655685806"}
0005432360622	E14715	9352 655329	MARGARITA PETROVA	{"phone": "+70561016941"}
0005432360623	F0614C	3962 520696	EVGENIYA POLYAKOVA	{"phone": "+70057183192"}
0005432360624	DE5FB5	3754 042952	LYUDMILA FROLOVA	{"phone": "+70440530910"}
0005432360625	DE5FB5	5614 994495	GALINA FILIPPOVA	{"phone": "+70051747229"}
0005432360626	AD08F9	6443 885002	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a-121974@postgrespro.ru", "phone": "+70383559508"}
0005432360627	AD08F9	1415 253345	LILIYA NAZAROVA	{"email": "nazarovaliliya1964@postgrespro.ru", "phone": "+70792681794"}
0005432360628	0F25EF	3033 650377	YURIY KUZNECOV	{"email": "kuznecov.yuriy.23011974@postgrespro.ru", "phone": "+70008436841"}
0005432360629	86BD30	2877 594471	EVGENIY MARTYNOV	{"email": "martynov.e.011980@postgrespro.ru", "phone": "+70453214277"}
0005432360630	86BD30	0419 295756	DIANA LAZAREVA	{"email": "lazarevadiana.1976@postgrespro.ru", "phone": "+70990885431"}
0005432360631	A7F2E2	3910 099179	KONSTANTIN KARPOV	{"phone": "+70815925508"}
0005432360632	0B89A7	6381 585980	PETR NOVIKOV	{"email": "novikov-petr031966@postgrespro.ru", "phone": "+70381998891"}
0005432360633	0B89A7	0267 466429	VLADIMIR PETROV	{"email": "petrovv.051962@postgrespro.ru", "phone": "+70395841090"}
0005432360634	157843	2590 372361	OLGA MASLOVA	{"phone": "+70732483096"}
0005432360635	157843	2368 715973	TATYANA MELNIKOVA	{"phone": "+70868389469"}
0005432360636	565C5D	4366 105562	ALENA ZAYCEVA	{"phone": "+70617700042"}
0005432360637	1809EA	4235 798644	NADEZHDA NESTEROVA	{"phone": "+70531727622"}
0005432360638	1809EA	0281 445650	ALEKSEY FOMIN	{"email": "a_fomin041963@postgrespro.ru", "phone": "+70205810323"}
0005432360639	D9A7A1	9058 547099	NADEZHDA SOROKINA	{"email": "nsorokina.07051968@postgrespro.ru", "phone": "+70066856776"}
0005432360640	D9A7A1	1407 360765	MARINA ROMANOVA	{"phone": "+70063526042"}
0005432360641	23F5AA	9874 871045	VALERIY KUZNECOV	{"email": "kuznecov-v-10011979@postgrespro.ru", "phone": "+70189636074"}
0005432360642	3BDA6F	9663 315803	ANTONINA MIKHAYLOVA	{"email": "antonina.mikhaylova1979@postgrespro.ru", "phone": "+70627006224"}
0005432360643	CC5C52	5537 505743	NIKOLAY MIKHAYLOV	{"phone": "+70518407237"}
0005432360644	4A72B5	1681 133680	VALERIY BORISOV	{"email": "borisov.v_1977@postgrespro.ru", "phone": "+70998290929"}
0005432360645	CFC7F5	1882 234216	SVETLANA BELOVA	{"email": "svetlana-belova_1978@postgrespro.ru", "phone": "+70642911876"}
0005432360646	D48ED6	9951 335092	ANASTASIYA NESTEROVA	{"phone": "+70584610443"}
0005432360647	962FF0	6256 890656	SERGEY KUZNECOV	{"email": "s.kuznecov-1973@postgrespro.ru", "phone": "+70352932240"}
0005432360648	962FF0	3241 630719	IVAN NIKOLAEV	{"email": "nikolaev_ivan.071978@postgrespro.ru", "phone": "+70165992892"}
0005432360649	25E294	5389 887346	EVGENIY FEDOROV	{"email": "fedorovevgeniy121976@postgrespro.ru", "phone": "+70804633621"}
0005432360650	25E294	7175 207519	ANNA POLYAKOVA	{"email": "polyakovaa_1964@postgrespro.ru", "phone": "+70886903079"}
0005432360651	383809	9002 088679	DMITRIY DENISOV	{"phone": "+70544466944"}
0005432360652	006D45	3650 312975	KLAVDIYA SERGEEVA	{"phone": "+70178944574"}
0005432360653	4E1C7B	2706 586826	RAISA KULIKOVA	{"phone": "+70425128896"}
0005432360654	BBB643	3921 438656	KLAVDIYA KUZNECOVA	{"email": "klavdiya.kuznecova1977@postgrespro.ru", "phone": "+70536791579"}
0005432360655	BBB643	7377 518128	KONSTANTIN ALEKSEEV	{"email": "alekseev_konstantin_021973@postgrespro.ru", "phone": "+70416312080"}
0005432360656	358D92	4226 176280	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev_101974@postgrespro.ru", "phone": "+70781758914"}
0005432360657	358D92	8742 465381	SVETLANA SOLOVEVA	{"email": "soloveva.svetlana.071977@postgrespro.ru", "phone": "+70721018410"}
0005432360658	EEC5DE	4004 799498	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr1977@postgrespro.ru", "phone": "+70377186418"}
0005432360659	64E944	2210 741684	DANILA SIDOROV	{"email": "d-sidorov-071965@postgrespro.ru", "phone": "+70137057078"}
0005432360660	64E944	4995 560627	FARIT CHERNOV	{"email": "farit-chernov-101973@postgrespro.ru", "phone": "+70579142340"}
0005432360661	28FD27	1730 636591	FEDOR MELNIKOV	{"email": "fmelnikov.16091975@postgrespro.ru", "phone": "+70412125980"}
0005432360662	6F91F5	0436 836576	SERGEY ZHURAVLEV	{"phone": "+70334512958"}
0005432360663	6294D4	4517 921399	ALEKSEY SOLOVEV	{"email": "solovev_a_04031970@postgrespro.ru", "phone": "+70701860230"}
0005432360664	6294D4	9551 032409	ALEKSEY FEDOROV	{"phone": "+70588511020"}
0005432360665	C65A26	0545 503076	ALEKSEY POPOV	{"phone": "+70870683407"}
0005432360666	C65A26	0089 134409	EVGENIY VLASOV	{"email": "vlasov-evgeniy.121982@postgrespro.ru", "phone": "+70336309019"}
0005432360667	0E0AA9	9581 863584	TATYANA POPOVA	{"email": "t.popova-081971@postgrespro.ru", "phone": "+70217589529"}
0005432360668	024AB1	1960 592976	LIDIYA MELNIKOVA	{"phone": "+70586507416"}
0005432360669	9A1296	3746 317984	GENNADIY SOKOLOV	{"email": "gennadiy-sokolov-07101965@postgrespro.ru", "phone": "+70992302289"}
0005432360670	E58C92	0786 820580	RUFINA MASLOVA	{"email": "maslovar.1980@postgrespro.ru", "phone": "+70363505952"}
0005432360671	451F27	1125 058241	GALINA MAKAROVA	{"phone": "+70686354115"}
0005432360672	7B8793	7174 011185	ALEKSANDRA SOROKINA	{"phone": "+70887129383"}
0005432360673	7B8793	6062 057760	OLGA BARANOVA	{"phone": "+70734958631"}
0005432360674	EB04C0	4346 994725	VLADIMIR EGOROV	{"phone": "+70884778227"}
0005432360675	EB04C0	2840 193623	SERGEY SERGEEV	{"phone": "+70477532432"}
0005432360676	F84993	6505 351256	SERGEY STEPANOV	{"email": "s-stepanov_1980@postgrespro.ru", "phone": "+70550290372"}
0005432360677	CD903B	1870 759971	ALEKSANDR SOLOVEV	{"email": "aleksandr-solovev_1984@postgrespro.ru", "phone": "+70688847831"}
0005432360678	CD903B	2248 554734	LIDIYA GUSEVA	{"phone": "+70298529596"}
0005432360679	59B8FA	0068 303316	OLGA FROLOVA	{"email": "frolovaolga.081971@postgrespro.ru", "phone": "+70615619900"}
0005432360680	81299A	3016 219151	TAISIYA ALEKSANDROVA	{"email": "aleksandrova.t-11081968@postgrespro.ru", "phone": "+70757568962"}
0005432360681	EDBB71	9119 007847	ANNA SAVELEVA	{"phone": "+70001391370"}
0005432360682	EDBB71	0616 508827	VALENTINA ORLOVA	{"phone": "+70188246200"}
0005432360683	EDBB71	9945 675940	DMITRIY CHERNOV	{"phone": "+70743177388"}
0005432360684	427100	4057 396831	IRINA KOMAROVA	{"email": "komarovai.05061972@postgrespro.ru", "phone": "+70340911973"}
0005432360685	B91CD7	3132 007209	EKATERINA MELNIKOVA	{"phone": "+70689709084"}
0005432360686	32076A	5209 427371	KIRILL BONDARENKO	{"phone": "+70032251337"}
0005432360687	BE9DDA	9355 175913	IRINA VASILEVA	{"phone": "+70685680259"}
0005432360688	D9BDA2	1379 413270	GALINA POTAPOVA	{"email": "galina.potapova.24101978@postgrespro.ru", "phone": "+70438793034"}
0005432360689	D9E32D	7593 474602	GALINA MIKHAYLOVA	{"phone": "+70002987523"}
0005432360690	D9E32D	4858 120178	ANDREY FILIPPOV	{"email": "afilippov_22111979@postgrespro.ru", "phone": "+70671862876"}
0005432360691	F2A060	6328 159532	ANDREY ANTONOV	{"phone": "+70906507002"}
0005432360692	7F7246	8062 069848	BOGDAN STEPANOV	{"email": "bstepanov.021969@postgrespro.ru", "phone": "+70536612893"}
0005432360693	7F7246	1970 260263	ELENA IVANOVA	{"phone": "+70395013673"}
0005432360694	371AE1	4903 539705	ARTEM ILIN	{"phone": "+70975228944"}
0005432360695	C04468	8845 851155	TATYANA LUKYANOVA	{"phone": "+70440851391"}
0005432360696	BE53D1	5050 108524	ANTON KUDRYASHOV	{"email": "antonkudryashov-06061980@postgrespro.ru", "phone": "+70915564474"}
0005432360697	A229FF	8575 270244	NATALYA KOZLOVA	{"email": "kozlova_n_031972@postgrespro.ru", "phone": "+70059245670"}
0005432360698	820A94	6316 170441	NIKOLAY ZAYCEV	{"phone": "+70351508738"}
0005432360699	7A8097	2412 012214	IGOR NAZAROV	{"email": "nazarovigor1972@postgrespro.ru", "phone": "+70228156732"}
0005432360700	7A8097	2572 184472	IVAN STEPANOV	{"email": "stepanov_ivan_05071976@postgrespro.ru", "phone": "+70380548635"}
0005432360701	3D3854	9054 549518	EVGENIY BARANOV	{"email": "baranov_e_061976@postgrespro.ru", "phone": "+70307759015"}
0005432360702	677A2B	2246 627987	PAVEL ISAEV	{"email": "isaev-pavel_18121961@postgrespro.ru", "phone": "+70376712111"}
0005432360703	756A62	8183 453718	NIKOLAY ABRAMOV	{"phone": "+70665818843"}
0005432360704	756A62	9239 188691	TAMARA MIKHAYLOVA	{"phone": "+70010044589"}
0005432360705	C74270	1157 232042	NINA FOMINA	{"email": "nina-fomina.13021976@postgrespro.ru", "phone": "+70418447506"}
0005432360706	7C1318	5781 692371	TATYANA DMITRIEVA	{"email": "dmitrievatatyana.15121975@postgrespro.ru", "phone": "+70435287730"}
0005432360707	A31AF8	0328 767898	EVGENIYA MARTYNOVA	{"email": "evgeniya.martynova_111963@postgrespro.ru", "phone": "+70656024338"}
0005432360708	E6960A	3486 396562	ULYANA SERGEEVA	{"email": "usergeeva1974@postgrespro.ru", "phone": "+70586300143"}
0005432360709	2F5430	6777 816370	ALEKSEY FEDOTOV	{"email": "fedotovaleksey.1971@postgrespro.ru", "phone": "+70929185222"}
0005432360710	C46E33	1167 134970	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov-1972@postgrespro.ru", "phone": "+70926064710"}
0005432360711	8E14B7	8134 454146	ILGIZ KUZNECOV	{"email": "ilgiz-kuznecov_101974@postgrespro.ru", "phone": "+70378378669"}
0005432360712	8E14B7	8762 867912	VLADIMIR TIKHONOV	{"phone": "+70548480240"}
0005432360713	F658E4	6503 343304	NADEZHDA FEDOROVA	{"phone": "+70413272013"}
0005432360714	F658E4	1946 082434	YULIYA PETROVA	{"phone": "+70749758631"}
0005432360715	61ED3F	4416 447806	VALENTINA CHERNOVA	{"email": "v-chernova_08021986@postgrespro.ru", "phone": "+70256249347"}
0005432360716	61ED3F	7548 552131	GENNADIY MIKHAYLOV	{"phone": "+70397026339"}
0005432360717	AC8A9A	4059 089144	OLGA KONOVALOVA	{"phone": "+70682647491"}
0005432360718	AC8A9A	8142 068519	DENIS IVANOV	{"email": "d.ivanov_07041972@postgrespro.ru", "phone": "+70701842063"}
0005432360719	DE5A7C	9484 371779	VLADIMIR BARANOV	{"email": "baranovvladimir061971@postgrespro.ru", "phone": "+70998023748"}
0005432360720	DE2368	3081 963332	SVETLANA FILATOVA	{"phone": "+70144123607"}
0005432360721	35A0AE	1215 089561	INGA BORISOVA	{"phone": "+70386844807"}
0005432360722	F70527	2347 300792	NATALIYA FILIPPOVA	{"phone": "+70723712435"}
0005432360723	F70527	2832 816757	ANDREY KULIKOV	{"phone": "+70338951461"}
0005432360724	2E4E55	5315 085618	RISHAT DENISOV	{"phone": "+70651367704"}
0005432360725	F29B6D	3414 473485	EDUARD SOLOVEV	{"email": "solovev_eduard111959@postgrespro.ru", "phone": "+70873084878"}
0005432360726	754CA4	6905 340969	ANGELINA FEDOROVA	{"email": "a.fedorova011970@postgrespro.ru", "phone": "+70373901701"}
0005432360727	2E63CF	6630 782215	YULIYA KOROLEVA	{"phone": "+70442682650"}
0005432360728	2E63CF	3008 281388	NIKITA AFANASEV	{"email": "afanasev.n051962@postgrespro.ru", "phone": "+70646204177"}
0005432360729	29E81B	9296 030665	DARYA MARTYNOVA	{"phone": "+70060328340"}
0005432360730	633703	9928 127465	NATALYA ROMANOVA	{"phone": "+70844301021"}
0005432360731	03FEB1	9725 489794	VLADIMIR GERASIMOV	{"phone": "+70084187504"}
0005432360732	23F5A6	5235 958132	TIMUR SOKOLOV	{"phone": "+70589828396"}
0005432360733	23F5A6	1325 251297	IRINA EFREMOVA	{"phone": "+70836740714"}
0005432360734	9E572A	5736 502615	NADEZHDA FADEEVA	{"phone": "+70554084587"}
0005432360735	A9012E	4039 872592	IVAN ANTONOV	{"phone": "+70340065343"}
0005432360736	A9012E	4932 480652	ANTONINA ALEKSANDROVA	{"email": "aleksandrova.antonina1973@postgrespro.ru", "phone": "+70475750518"}
0005432360737	02401D	9732 441450	KRISTINA NOVIKOVA	{"email": "novikova-kristina_021971@postgrespro.ru", "phone": "+70435618351"}
0005432360738	02401D	5389 756105	ELENA MASLOVA	{"phone": "+70044130824"}
0005432360739	F8E875	9398 072179	ARTEM EGOROV	{"phone": "+70442530442"}
0005432360740	794797	5989 065310	NINA MAKAROVA	{"email": "nina_makarova-071974@postgrespro.ru", "phone": "+70534279520"}
0005432360741	794797	1427 078987	TATYANA POLYAKOVA	{"email": "t_polyakova.101970@postgrespro.ru", "phone": "+70390654650"}
0005432360742	8818B4	2788 134829	VALERIY VASILEV	{"phone": "+70539130154"}
0005432360743	8818B4	8015 877870	NIKOLAY OSIPOV	{"phone": "+70817786446"}
0005432360744	8818B4	6512 370628	VLADIMIR KUDRYASHOV	{"phone": "+70991283438"}
0005432360745	A98049	6083 309943	LIDIYA MATVEEVA	{"email": "matveeva_lidiya-021976@postgrespro.ru", "phone": "+70967477436"}
0005432360746	A98049	5787 808787	NINA EGOROVA	{"phone": "+70802184011"}
0005432360747	AD42B8	9691 127785	ALEKSEY STEPANOV	{"phone": "+70869444128"}
0005432360748	AD42B8	1143 021282	ELENA KULIKOVA	{"phone": "+70611545104"}
0005432360749	D74A42	0014 586949	ASIYA VOLKOVA	{"phone": "+70008251301"}
0005432360750	AC336D	9247 710215	NATALYA IVANOVA	{"email": "ivanovanatalya-22061975@postgrespro.ru", "phone": "+70746609443"}
0005432360751	B1B510	1440 402301	ANASTASIYA EGOROVA	{"email": "egorova.a-09031970@postgrespro.ru", "phone": "+70220252588"}
0005432360752	14238C	0525 386247	VASILIY TIKHONOV	{"phone": "+70591966749"}
0005432360753	14238C	9462 236178	ALEKSANDR NOVIKOV	{"phone": "+70409321841"}
0005432360754	14238C	4004 377232	TATYANA MAKAROVA	{"phone": "+70239703623"}
0005432360755	65A077	4350 564467	ALEKSEY DMITRIEV	{"phone": "+70291167810"}
0005432360756	80C286	0316 723697	TAMARA MASLOVA	{"email": "maslovatamara_1975@postgrespro.ru", "phone": "+70344353784"}
0005432360757	F35DB5	5228 731189	YURIY BARANOV	{"email": "baranovyuriy_011969@postgrespro.ru", "phone": "+70165838633"}
0005432360758	058870	5450 932950	YURIY ROMANOV	{"phone": "+70984947965"}
0005432360759	52E2E0	3160 232581	SVETLANA NOVIKOVA	{"email": "novikova.s091977@postgrespro.ru", "phone": "+70364257233"}
0005432360760	83E411	5101 817624	ANTON KUZNECOV	{"email": "a_kuznecov_12041970@postgrespro.ru", "phone": "+70889027546"}
0005432360761	5D1DF5	2304 957949	ELINA SEMENOVA	{"phone": "+70643919676"}
0005432360762	C08F5F	0807 129902	MARIYA VLASOVA	{"phone": "+70153659192"}
0005432360763	C08F5F	6342 659228	ANNA EGOROVA	{"phone": "+70796089864"}
0005432360764	B2B517	7026 389294	YULIYA MATVEEVA	{"phone": "+70150320401"}
0005432360765	0E97A8	6353 006920	GALINA TARASOVA	{"email": "galina.tarasova1980@postgrespro.ru", "phone": "+70477206855"}
0005432360766	0E97A8	8717 488217	DANIIL CHERNOV	{"phone": "+70174612035"}
0005432360767	7BC3D9	8691 634321	ELENA YAKOVLEVA	{"phone": "+70522454208"}
0005432360768	7BC3D9	5578 600631	RAFAIL BONDARENKO	{"phone": "+70346558701"}
0005432360769	C5C8F2	0373 591938	SVETLANA CHERNOVA	{"phone": "+70728668419"}
0005432360770	2B85F1	6348 933207	NIKOLAY TARASOV	{"phone": "+70061887270"}
0005432360771	2B85F1	9735 613141	VADIM KULIKOV	{"phone": "+70054673702"}
0005432360772	2B85F1	6544 318331	OLESYA ARKHIPOVA	{"email": "oarkhipova_021974@postgrespro.ru", "phone": "+70961507376"}
0005432360773	CB1D96	8208 486986	YURIY KUZMIN	{"phone": "+70164225289"}
0005432360774	CB1D96	9065 594512	LYUBOV MELNIKOVA	{"email": "lmelnikova_13021973@postgrespro.ru", "phone": "+70498934246"}
0005432360775	443053	5913 182338	IRINA ZOTOVA	{"email": "zotova.i.041971@postgrespro.ru", "phone": "+70485302303"}
0005432360776	10054C	7054 710432	IRINA DENISOVA	{"phone": "+70082330418"}
0005432360777	10054C	2851 048486	VALENTIN EGOROV	{"email": "egorovvalentin-16121980@postgrespro.ru", "phone": "+70512164446"}
0005432360778	10054C	9512 910696	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr28041986@postgrespro.ru", "phone": "+70799767090"}
0005432360779	087AF5	2042 274777	OLGA IVANOVA	{"email": "o.ivanova-28071971@postgrespro.ru", "phone": "+70983619714"}
0005432360780	CA15C9	3758 556587	MARINA KONOVALOVA	{"phone": "+70678357450"}
0005432360781	1F9ADC	5403 166898	ELENA ZHUKOVA	{"phone": "+70751083534"}
0005432360782	4AF225	0930 143850	VIKTOR ANTONOV	{"phone": "+70104709515"}
0005432360783	4AF225	3916 068972	TATYANA EGOROVA	{"email": "tatyanaegorova09111970@postgrespro.ru", "phone": "+70023146486"}
0005432360784	4AF225	5855 072104	YURIY KONOVALOV	{"phone": "+70117630353"}
0005432360785	21D828	5964 315410	MARIYA SERGEEVA	{"phone": "+70487787190"}
0005432360786	21D828	9240 079579	SERGEY IVANOV	{"phone": "+70987508814"}
0005432360787	D6AC6F	9293 111862	ANTON KUZNECOV	{"email": "a-kuznecov.31081968@postgrespro.ru", "phone": "+70934262081"}
0005432360788	FC837C	0655 485369	ELENA BARANOVA	{"phone": "+70505810126"}
0005432360789	FC837C	9814 911997	ANDREY PAVLOV	{"email": "apavlov031960@postgrespro.ru", "phone": "+70984317125"}
0005432360790	A62A64	1535 024061	SERGEY ZAKHAROV	{"email": "sergey.zakharov.091972@postgrespro.ru", "phone": "+70830448223"}
0005432360791	5FEA64	2361 215508	NATALYA SEMENOVA	{"email": "natalya.semenova-071982@postgrespro.ru", "phone": "+70237582402"}
0005432360792	4B3D8D	8653 471212	ELENA NIKOLAEVA	{"email": "nikolaeva-elena-1974@postgrespro.ru", "phone": "+70317634667"}
0005432360793	EC4F73	0537 531962	VALENTINA ORLOVA	{"phone": "+70299779518"}
0005432360794	9C5D78	2280 495074	VITALIY GRIGOREV	{"email": "grigorev-v.1972@postgrespro.ru", "phone": "+70006148541"}
0005432360795	9C5D78	6787 855866	ANASTASIYA TIMOFEEVA	{"phone": "+70367335251"}
0005432360796	85F0F6	8222 465373	EVA NIKITINA	{"phone": "+70647518977"}
0005432360797	8F2B82	2405 060323	PETR ILIN	{"phone": "+70774576895"}
0005432360798	C12FF2	3934 175419	PETR ALEKSEEV	{"email": "petr-alekseev_23121980@postgrespro.ru", "phone": "+70698297323"}
0005432360799	87BBF6	3791 177114	ANDREY RODIONOV	{"email": "rodionov.a-23121964@postgrespro.ru", "phone": "+70211735056"}
0005432360800	87BBF6	9231 117922	VERA AKIMOVA	{"email": "vakimova.29071966@postgrespro.ru", "phone": "+70729966650"}
0005432360801	017C73	8874 422923	SERGEY VOLKOV	{"phone": "+70040407467"}
0005432360802	017C73	0172 372024	TATYANA OVCHINNIKOVA	{"phone": "+70183227838"}
0005432360803	55A728	8774 592985	ARKADIY KISELEV	{"email": "kiselev_a.111966@postgrespro.ru", "phone": "+70797609448"}
0005432360804	1CBE28	3073 932585	MARAT MATVEEV	{"phone": "+70762733166"}
0005432360805	4926D6	5862 824257	ANATOLIY SOKOLOV	{"email": "a.sokolov_1973@postgrespro.ru", "phone": "+70205102325"}
0005432360806	4926D6	9150 928741	LEONID KOROLEV	{"email": "korolev_leonid121969@postgrespro.ru", "phone": "+70382642278"}
0005432360807	4926D6	6930 816348	MIKHAIL FOMIN	{"email": "m-fomin-1970@postgrespro.ru", "phone": "+70236545989"}
0005432360808	DE3025	5189 816661	ROMAN KONOVALOV	{"email": "roman-konovalov1971@postgrespro.ru", "phone": "+70905687845"}
0005432360809	3A8074	4154 970416	LYUDMILA ANDREEVA	{"phone": "+70277804613"}
0005432360810	3A8074	9167 251334	TATYANA SMIRNOVA	{"phone": "+70502882874"}
0005432360811	0C9F86	8800 725511	SVETLANA IVANOVA	{"phone": "+70535375313"}
0005432360812	605E10	5338 463213	ELVIRA MELNIKOVA	{"email": "elvira.melnikova_111966@postgrespro.ru", "phone": "+70864752726"}
0005432360813	B48C4C	2694 559935	VALERIYA ZAYCEVA	{"email": "v_zayceva101975@postgrespro.ru", "phone": "+70591577223"}
0005432360814	85B857	6272 014631	DAMIR MEDVEDEV	{"phone": "+70489091636"}
0005432360815	85B857	2629 274631	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay.1971@postgrespro.ru", "phone": "+70112338150"}
0005432360816	552995	2922 300351	RAISA NIKOLAEVA	{"phone": "+70393477144"}
0005432360817	552995	4425 198425	TATYANA AFANASEVA	{"email": "t.afanaseva08081975@postgrespro.ru", "phone": "+70966301830"}
0005432360818	7490CF	8187 658795	OLGA GORBUNOVA	{"email": "gorbunova_olga071977@postgrespro.ru", "phone": "+70316845324"}
0005432360819	72E2CF	8196 994852	DARYA NOVIKOVA	{"email": "novikova_d.1954@postgrespro.ru", "phone": "+70106998662"}
0005432360820	59F37E	6183 224126	DMITRIY IVANOV	{"email": "ivanovd121973@postgrespro.ru", "phone": "+70244302396"}
0005432360821	21C548	7465 951893	IGOR MOISEEV	{"phone": "+70134285283"}
0005432360822	38566E	6547 386778	ALEKSANDRA EFREMOVA	{"email": "aleksandraefremova.081967@postgrespro.ru", "phone": "+70824520542"}
0005432360823	38566E	1317 731728	YULIYA FOMINA	{"email": "yfomina-13071973@postgrespro.ru", "phone": "+70222396788"}
0005432360824	38566E	8087 950024	LYUDMILA KOROLEVA	{"email": "lyudmilakoroleva-021974@postgrespro.ru", "phone": "+70293766768"}
0005432360825	7F8972	0331 755614	GALINA KOZLOVA	{"email": "gkozlova-031981@postgrespro.ru", "phone": "+70628424419"}
0005432360826	D14900	9424 112759	EVGENIY SERGEEV	{"email": "evgeniy-sergeev.021978@postgrespro.ru", "phone": "+70308384819"}
0005432360827	6D136C	8234 586709	IVAN IVANOV	{"phone": "+70550549672"}
0005432360828	6D136C	7941 550778	SERGEY KOZLOV	{"email": "sergeykozlov-091980@postgrespro.ru", "phone": "+70600898802"}
0005432360829	5D9761	4707 063573	DMITRIY ZHUKOV	{"email": "zhukov.dmitriy.1962@postgrespro.ru", "phone": "+70307623995"}
0005432360830	80A15F	5984 965390	NATALYA TARASOVA	{"email": "tarasovan_011968@postgrespro.ru", "phone": "+70174070560"}
0005432360831	80A15F	0998 531745	VLADIMIR SOLOVEV	{"email": "vsolovev_15021978@postgrespro.ru", "phone": "+70332182343"}
0005432360832	C74312	4476 007740	VADIM CHERNOV	{"email": "v.chernov-091978@postgrespro.ru", "phone": "+70047250313"}
0005432360833	108122	0684 672012	VALERIY ALEKSEEV	{"email": "v.alekseev-1969@postgrespro.ru", "phone": "+70004694006"}
0005432360834	49A2CC	3884 043353	ELENA KONOVALOVA	{"email": "e-konovalova_071969@postgrespro.ru", "phone": "+70083479623"}
0005432360835	7C7B9E	9816 129185	OLEG SIDOROV	{"phone": "+70063434800"}
0005432360836	0381B8	5935 377198	SERGEY KUZMIN	{"email": "kuzminsergey.091970@postgrespro.ru", "phone": "+70992297173"}
0005432360837	0381B8	4829 438609	ANATOLIY SHEVCHENKO	{"email": "shevchenko-anatoliy081970@postgrespro.ru", "phone": "+70929123102"}
0005432360838	891804	1195 888812	LYUDMILA MOROZOVA	{"email": "morozova_l_1968@postgrespro.ru", "phone": "+70571500903"}
0005432360839	891804	1886 428524	DMITRIY MIRONOV	{"email": "mironov-dmitriy-17111971@postgrespro.ru", "phone": "+70005851635"}
0005432360840	A86764	8322 119961	LIDIYA NIKITINA	{"email": "nikitina-lidiya.101978@postgrespro.ru", "phone": "+70265575064"}
0005432360897	4DBAF8	0877 373558	IVAN SMIRNOV	{"phone": "+70926316685"}
0005432360841	835213	0306 786489	VALENTINA TROFIMOVA	{"email": "trofimova.valentina04101961@postgrespro.ru", "phone": "+70764535185"}
0005432360842	985B5C	6697 200318	VALERIY ZHUKOV	{"email": "valeriy.zhukov101982@postgrespro.ru", "phone": "+70366255222"}
0005432360843	2DE182	5082 061821	KSENIYA RYABOVA	{"email": "kseniyaryabova_121977@postgrespro.ru", "phone": "+70039526798"}
0005432360844	9CD0BE	4440 566648	ILYA PAVLOV	{"phone": "+70895666121"}
0005432360845	62F11C	5017 788064	ALEKSEY KISELEV	{"email": "kiselevaleksey-02031983@postgrespro.ru", "phone": "+70755399532"}
0005432360846	62F11C	7109 244356	OLGA ALEKSANDROVA	{"phone": "+70453292253"}
0005432360847	62F11C	8133 398633	TATYANA BORISOVA	{"phone": "+70861630144"}
0005432360848	FF4B16	1494 644002	EGOR BARANOV	{"phone": "+70767996627"}
0005432360849	DA649F	9862 414842	SERGEY PETROV	{"email": "sergey-petrov_101974@postgrespro.ru", "phone": "+70449680438"}
0005432360850	DA649F	1083 764147	GLEB TIKHONOV	{"email": "g.tikhonov-1966@postgrespro.ru", "phone": "+70961283968"}
0005432360851	D954E5	2523 255434	MARINA MEDVEDEVA	{"phone": "+70267754953"}
0005432360852	D954E5	9769 096428	VIKTORIYA POPOVA	{"phone": "+70750477087"}
0005432360853	D954E5	0266 289648	VLADIMIR NIKITIN	{"email": "vladimirnikitin_041965@postgrespro.ru", "phone": "+70837682124"}
0005432360854	59FA17	3021 105293	VLADIMIR ORLOV	{"phone": "+70171224413"}
0005432360855	DA1399	5706 131749	MAKSIM FOMIN	{"phone": "+70171383505"}
0005432360856	DA1399	6985 653885	NATALYA MELNIKOVA	{"phone": "+70822218032"}
0005432360857	B2EEEC	7718 768182	VLADIMIR YAKOVLEV	{"email": "vladimir_yakovlev12011974@postgrespro.ru", "phone": "+70686611301"}
0005432360858	61CE68	6338 465221	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr-1964@postgrespro.ru", "phone": "+70901548226"}
0005432360859	7FEB08	0796 492788	VALENTINA MATVEEVA	{"phone": "+70865027996"}
0005432360860	F5EBC5	1371 901208	ANDREY VOROBEV	{"email": "vorobev-andrey041966@postgrespro.ru", "phone": "+70072628986"}
0005432360861	78612E	5807 752159	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova-1987@postgrespro.ru", "phone": "+70552926692"}
0005432360862	C3B02E	0475 997365	NIKOLAY SHEVCHENKO	{"email": "n-shevchenko-011967@postgrespro.ru", "phone": "+70837780899"}
0005432360863	BF9A4D	4156 723226	VIKTORIYA STEPANOVA	{"phone": "+70697907827"}
0005432360864	BF9A4D	1824 630972	IRINA DENISOVA	{"phone": "+70482304769"}
0005432360865	9696F3	6296 346461	SVETLANA KONOVALOVA	{"phone": "+70231109723"}
0005432360866	706E30	4551 190397	GALINA GORBUNOVA	{"email": "galina.gorbunova081974@postgrespro.ru", "phone": "+70943134211"}
0005432360867	973AA9	3064 658325	ALEKSANDR GUSEV	{"email": "aleksandr.gusev-27051979@postgrespro.ru", "phone": "+70399818913"}
0005432360868	D6832D	0945 129849	ANNA VOLKOVA	{"email": "volkovaa-1972@postgrespro.ru", "phone": "+70674568753"}
0005432360869	D6832D	4573 751724	VARVARA OSIPOVA	{"email": "varvara.osipova17091971@postgrespro.ru", "phone": "+70444541772"}
0005432360870	D6832D	2984 826518	NIKOLAY ISAEV	{"email": "isaev.nikolay-051966@postgrespro.ru", "phone": "+70177701046"}
0005432360871	1457CF	1380 673268	ELENA KOMAROVA	{"phone": "+70240386959"}
0005432360872	2FF543	1536 757378	NATALYA IVANOVA	{"phone": "+70989510898"}
0005432360873	2586C8	9441 747470	POLINA OSIPOVA	{"email": "osipovap_28041974@postgrespro.ru", "phone": "+70191862731"}
0005432360874	2586C8	0242 168765	ILMIR VOROBEV	{"phone": "+70193172118"}
0005432360875	69AE5C	6370 831725	IRINA MIRONOVA	{"email": "irina-mironova_031978@postgrespro.ru", "phone": "+70357674377"}
0005432360876	E89652	5005 324390	EKATERINA GERASIMOVA	{"email": "e_gerasimova18041979@postgrespro.ru", "phone": "+70007500388"}
0005432360877	3695A6	4855 071346	NINA SERGEEVA	{"email": "n.sergeeva051973@postgrespro.ru", "phone": "+70111055777"}
0005432360878	15E593	7212 417668	SERGEY IVANOV	{"phone": "+70918492304"}
0005432360879	15E593	3729 835969	ARTEM ALEKSANDROV	{"email": "a.aleksandrov_06111971@postgrespro.ru", "phone": "+70492195164"}
0005432360880	3F7000	5727 681339	KONSTANTIN BORISOV	{"phone": "+70831155273"}
0005432360881	3F7000	5289 986663	ANDREY KOROLEV	{"email": "korolevandrey.1966@postgrespro.ru", "phone": "+70157968974"}
0005432360882	B34159	6676 448044	PETR ZAYCEV	{"phone": "+70791407116"}
0005432360883	0C3F30	7736 303933	ANNA RODIONOVA	{"phone": "+70313264824"}
0005432360884	3E55EA	9347 241527	ANASTASIYA MARTYNOVA	{"phone": "+70092394160"}
0005432360885	3E55EA	0092 833377	ELIZAVETA KOROLEVA	{"email": "e-koroleva_1962@postgrespro.ru", "phone": "+70211960534"}
0005432360886	3E55EA	5428 542899	IGOR KRASNOV	{"email": "igor-krasnov-11061977@postgrespro.ru", "phone": "+70456436654"}
0005432360887	6D072C	5204 970461	DMITRIY KUZMIN	{"phone": "+70766218179"}
0005432360888	6D072C	1210 133377	DMITRIY PAVLOV	{"email": "d-pavlov1976@postgrespro.ru", "phone": "+70822628922"}
0005432360889	795743	6035 029806	NATALYA KOVALEVA	{"email": "nkovaleva-1977@postgrespro.ru", "phone": "+70460254332"}
0005432360890	11E16D	0014 957771	LARISA MOROZOVA	{"email": "morozova_l-06021966@postgrespro.ru", "phone": "+70830523382"}
0005432360891	0306D0	6620 348631	OLEG FROLOV	{"email": "frolov-o-071977@postgrespro.ru", "phone": "+70748014953"}
0005432360892	0306D0	2373 307781	IVAN FOMIN	{"phone": "+70302542402"}
0005432360893	8D7F5B	8700 078165	PAVEL KUDRYASHOV	{"email": "pavel.kudryashov_10051978@postgrespro.ru", "phone": "+70465531159"}
0005432360894	042D5A	9888 829561	PETR TIMOFEEV	{"phone": "+70265368231"}
0005432360895	F15650	1195 470126	ANASTASIYA EGOROVA	{"phone": "+70463551913"}
0005432360896	7BA59C	0157 891460	ANDREY VASILEV	{"email": "vasileva-24101981@postgrespro.ru", "phone": "+70712580257"}
0005432360898	0F29AE	2789 499605	LARISA KUZMINA	{"email": "larisakuzmina-22111979@postgrespro.ru", "phone": "+70651221676"}
0005432360899	2CD91D	1432 692330	ANATOLIY VOLKOV	{"email": "a_volkov-111968@postgrespro.ru", "phone": "+70011941902"}
0005432360900	5605A3	5826 737154	NIKOLAY BELOV	{"phone": "+70453052098"}
0005432360901	5605A3	8453 833610	NATALIYA SOROKINA	{"email": "n_sorokina-1972@postgrespro.ru", "phone": "+70325935449"}
0005432360902	902BCF	5454 768099	NATALYA MATVEEVA	{"email": "n.matveeva.10031970@postgrespro.ru", "phone": "+70021496323"}
0005432360903	902BCF	3860 757940	OLGA SIDOROVA	{"email": "o-sidorova-30081966@postgrespro.ru", "phone": "+70766766924"}
0005432360904	7309FD	8916 019386	VALENTINA FILATOVA	{"phone": "+70212907132"}
0005432360905	3E40C3	2711 068688	GRIGORIY SOLOVEV	{"email": "grigoriy_solovev.17081969@postgrespro.ru", "phone": "+70893191148"}
0005432360906	3E40C3	3220 862285	AMIR AFANASEV	{"phone": "+70794547203"}
0005432360907	9AB239	2256 672469	MARINA ANISIMOVA	{"email": "m_anisimova.22071973@postgrespro.ru", "phone": "+70784553060"}
0005432360908	0E1DF6	0141 599543	OLGA CHERNOVA	{"phone": "+70069029897"}
0005432360909	F7A118	3360 068603	LYUDMILA SCHERBAKOVA	{"email": "scherbakova_l-09011959@postgrespro.ru", "phone": "+70570043688"}
0005432360910	E8F939	8202 210283	EVGENIYA FILIPPOVA	{"phone": "+70731961770"}
0005432360911	4E0C91	2668 233993	ANATOLIY MAKAROV	{"email": "amakarov_1962@postgrespro.ru", "phone": "+70856400737"}
0005432360912	4E0C91	8801 363760	OLEG KUZNECOV	{"phone": "+70266756026"}
0005432360913	88443F	5853 024107	NATALIYA MATVEEVA	{"email": "n.matveeva101975@postgrespro.ru", "phone": "+70095505463"}
0005432360914	88443F	4021 543008	ALEKSANDR ZHUKOV	{"email": "zhukov.aleksandr-051977@postgrespro.ru", "phone": "+70805408588"}
0005432360915	E223FB	2901 171166	EKATERINA MOROZOVA	{"email": "morozova-e_071975@postgrespro.ru", "phone": "+70585764494"}
0005432360916	07AD2D	1676 112332	VIKTOR FROLOV	{"email": "v.frolov-06071969@postgrespro.ru", "phone": "+70713274567"}
0005432360917	BF9BE4	8803 694361	RASHID MOROZOV	{"phone": "+70093147650"}
0005432360918	4D19D2	2907 654428	OLGA ANDREEVA	{"email": "olgaandreeva1964@postgrespro.ru", "phone": "+70024662045"}
0005432360919	4D19D2	1402 030607	NINA TITOVA	{"phone": "+70517498167"}
0005432360920	59BF3A	9938 044818	VALENTINA NIKOLAEVA	{"phone": "+70642394276"}
0005432360921	59BF3A	5489 034537	TIMUR ANDREEV	{"email": "t-andreev-1963@postgrespro.ru", "phone": "+70746727066"}
0005432360922	D907FD	5706 870970	EKATERINA ILINA	{"email": "ekaterina_ilina-1967@postgrespro.ru", "phone": "+70783349452"}
0005432360923	D907FD	8741 912061	ALEKSANDR GERASIMOV	{"phone": "+70367225278"}
0005432360924	125FE3	1946 097802	NATALYA KUZMINA	{"email": "kuzmina.n111987@postgrespro.ru", "phone": "+70658147398"}
0005432360925	125FE3	2827 789742	LYUDMILA GERASIMOVA	{"email": "l_gerasimova111971@postgrespro.ru", "phone": "+70581864756"}
0005432360926	A46AF5	9341 967343	NELLI POLYAKOVA	{"email": "polyakova.n_101981@postgrespro.ru", "phone": "+70776824679"}
0005432360927	75019C	7214 578654	ALEKSANDR ALEKSEEV	{"email": "alekseev-a_14101965@postgrespro.ru", "phone": "+70295362074"}
0005432360928	A3B0DD	2411 711974	VLADIMIR NOVIKOV	{"phone": "+70775256047"}
0005432360929	18AF02	2256 071191	YURIY VOROBEV	{"phone": "+70089768734"}
0005432360930	47C8F3	5296 776876	EKATERINA KUZNECOVA	{"email": "e.kuznecova_1971@postgrespro.ru", "phone": "+70787530341"}
0005432360931	92D6A3	2666 227675	SERGEY FEDOTOV	{"phone": "+70238345869"}
0005432360932	92D6A3	7472 667487	VALENTINA KONOVALOVA	{"phone": "+70204938722"}
0005432360933	5D0290	6328 916874	ANTONINA AKIMOVA	{"email": "akimova.antonina.21041982@postgrespro.ru", "phone": "+70692280055"}
0005432360934	5AB732	2406 970275	MIKHAIL TIMOFEEV	{"email": "timofeev_mikhail-1972@postgrespro.ru", "phone": "+70478161799"}
0005432360935	AE8863	2084 917791	ANDREY GORBUNOV	{"email": "andreygorbunov_13051972@postgrespro.ru", "phone": "+70112105296"}
0005432360936	993B31	5494 712493	VALENTINA ZAYCEVA	{"email": "valentina-zayceva1977@postgrespro.ru", "phone": "+70140063242"}
0005432360937	A401EB	0960 391618	ZINAIDA NESTEROVA	{"phone": "+70233711751"}
0005432360938	A401EB	9782 240786	MARIYA VASILEVA	{"phone": "+70903374070"}
0005432360939	DB1766	0712 300954	MARGARITA ANISIMOVA	{"phone": "+70026026703"}
0005432361114	3E6746	2871 941051	NIKITA NIKITIN	{"phone": "+70603286150"}
0005432360940	DB1766	7058 108220	EVGENIY FILIPPOV	{"email": "filippove_031979@postgrespro.ru", "phone": "+70017812796"}
0005432360941	056A1C	2069 599196	NATALYA ANISIMOVA	{"email": "anisimova-natalya_1976@postgrespro.ru", "phone": "+70498911138"}
0005432360942	30B965	3757 272765	ANNA GORBUNOVA	{"email": "anna-gorbunova-04051964@postgrespro.ru", "phone": "+70536889725"}
0005432360943	30B965	4032 880448	MARIYA SEMENOVA	{"phone": "+70967912805"}
0005432360944	626A51	2069 030358	ALEKSANDRA DAVYDOVA	{"email": "aleksandradavydova_1973@postgrespro.ru", "phone": "+70609982395"}
0005432360945	626A51	8526 821591	ANNA DENISOVA	{"email": "anna_denisova071978@postgrespro.ru", "phone": "+70740071202"}
0005432360946	71E591	3952 455194	ANTON DMITRIEV	{"phone": "+70247687718"}
0005432360947	14A32F	2165 992603	VIKTORIYA ROMANOVA	{"email": "v_romanova.1968@postgrespro.ru", "phone": "+70446621676"}
0005432360948	239D08	3491 092218	ALEKSEY FOMIN	{"email": "a-fomin.1974@postgrespro.ru", "phone": "+70694494553"}
0005432360949	BDEB5A	1537 420074	OLEG SOKOLOV	{"email": "sokolov-o.041981@postgrespro.ru", "phone": "+70207925678"}
0005432360950	BDEB5A	9471 187199	ALEKSEY SOKOLOV	{"phone": "+70833892791"}
0005432360951	357784	5060 875615	VLADIMIR AFANASEV	{"email": "afanasev_vladimir_14101963@postgrespro.ru", "phone": "+70360412831"}
0005432360952	86CB0A	0965 810464	IGOR KONOVALOV	{"phone": "+70428184327"}
0005432360953	3EE7FF	6267 249509	MARIYA ALEKSANDROVA	{"email": "maleksandrova-1958@postgrespro.ru", "phone": "+70208109330"}
0005432360954	E5901C	8254 101973	ROMAN AFANASEV	{"phone": "+70376888451"}
0005432360955	E5901C	0531 886471	MARIYA DMITRIEVA	{"email": "mariya.dmitrieva.071969@postgrespro.ru", "phone": "+70620040846"}
0005432360956	93F405	1418 901429	ALEKSANDR IVANOV	{"email": "a_ivanov07051975@postgrespro.ru", "phone": "+70676934959"}
0005432360957	430CD4	5391 478227	NINA SERGEEVA	{"email": "sergeeva.nina.101970@postgrespro.ru", "phone": "+70265088306"}
0005432360958	430CD4	2442 713441	RUSTEM TIKHONOV	{"email": "rtikhonov.13031981@postgrespro.ru", "phone": "+70641530627"}
0005432360959	6C341A	8483 438283	VALENTINA KOZLOVA	{"email": "kozlova-v_30051973@postgrespro.ru", "phone": "+70491107775"}
0005432360960	6C341A	1394 670305	ELENA BOGDANOVA	{"phone": "+70788624499"}
0005432360961	2FA7C6	1085 952830	SVETLANA PAVLOVA	{"email": "pavlovas-13081973@postgrespro.ru", "phone": "+70939238119"}
0005432360962	8931E1	1746 866871	ALENA SCHERBAKOVA	{"email": "alena-scherbakova-111979@postgrespro.ru", "phone": "+70798772515"}
0005432360963	458A60	0224 531524	YURIY RODIONOV	{"phone": "+70424164132"}
0005432360964	FA702F	8583 075380	MIKHAIL FOMIN	{"email": "fomin-mikhail.101965@postgrespro.ru", "phone": "+70708937986"}
0005432360965	508475	7073 501855	VIKTOR GORBUNOV	{"email": "gorbunov_v1976@postgrespro.ru", "phone": "+70086114448"}
0005432360966	0F24EA	8312 345558	IRINA FROLOVA	{"phone": "+70477138414"}
0005432360967	FDBD87	1841 213992	VALENTINA OSIPOVA	{"phone": "+70618502402"}
0005432360968	FF6DDA	6723 926415	VLADISLAV EGOROV	{"email": "v-egorov_15121966@postgrespro.ru", "phone": "+70604148318"}
0005432360969	45B45E	6684 034943	EKATERINA SOROKINA	{"email": "sorokinaekaterina_1969@postgrespro.ru", "phone": "+70716223887"}
0005432360970	45B45E	3829 634186	LYUDMILA IVANOVA	{"email": "lyudmilaivanova.11011966@postgrespro.ru", "phone": "+70961598453"}
0005432360971	8D1973	2329 259436	OKSANA ALEKSEEVA	{"email": "alekseeva-o_02111963@postgrespro.ru", "phone": "+70599597936"}
0005432360972	4326A9	2593 185145	YURIY FEDOROV	{"email": "yuriy.fedorov10051966@postgrespro.ru", "phone": "+70098655518"}
0005432360973	6F3221	8748 323674	EKATERINA ALEKSEEVA	{"email": "alekseeva-e_1965@postgrespro.ru", "phone": "+70327116019"}
0005432360974	00742A	8587 016387	NADEZHDA IVANOVA	{"phone": "+70755443948"}
0005432360975	00742A	3183 200266	ALEKSANDR MAKSIMOV	{"email": "amaksimov-1970@postgrespro.ru", "phone": "+70838300778"}
0005432360976	114439	5888 418558	MIKHAIL ALEKSANDROV	{"phone": "+70289539345"}
0005432360977	114439	4657 375352	MIKHAIL SAVELEV	{"phone": "+70676378813"}
0005432360978	114439	9359 759007	VERONIKA TIKHONOVA	{"phone": "+70730118179"}
0005432360979	81D762	4889 569902	DMITRIY ALEKSEEV	{"phone": "+70988939592"}
0005432360980	81D762	2306 145723	OLGA SOROKINA	{"email": "sorokinao.101971@postgrespro.ru", "phone": "+70685056441"}
0005432360981	0ECC8C	8699 269329	SERGEY TARASOV	{"phone": "+70697201386"}
0005432360982	D3E3C7	9773 075416	RAISA AKIMOVA	{"email": "raisaakimova.121966@postgrespro.ru", "phone": "+70243464711"}
0005432360983	D3E3C7	4641 754459	TATYANA ANDREEVA	{"email": "tatyana-andreeva_31051966@postgrespro.ru", "phone": "+70033207755"}
0005432360984	9D9571	4891 106947	DMITRIY ANTONOV	{"phone": "+70856134626"}
0005432360985	E54A62	6192 434545	NATALIYA CHERNOVA	{"phone": "+70222544446"}
0005432360986	EBC5CB	0104 654915	SERGEY AFANASEV	{"phone": "+70705816659"}
0005432360987	EBC5CB	4443 808217	SERGEY ZAKHAROV	{"email": "zakharovsergey_1973@postgrespro.ru", "phone": "+70316819447"}
0005432360988	5F9FCE	4896 757693	MARINA KONDRATEVA	{"email": "m.kondrateva1974@postgrespro.ru", "phone": "+70247073565"}
0005432360989	9DE9B0	5505 588378	NATALYA VASILEVA	{"email": "natalya.vasileva-051976@postgrespro.ru", "phone": "+70140981489"}
0005432360990	0B5F9D	2054 167585	VALERIY SOKOLOV	{"email": "sokolov_v14091967@postgrespro.ru", "phone": "+70676249975"}
0005432360991	D8EDE9	6490 064907	PAVEL NOVIKOV	{"phone": "+70514216202"}
0005432360992	D8EDE9	0497 448942	STANISLAV MAKAROV	{"phone": "+70794289841"}
0005432360993	5E3C69	1750 665104	VALENTINA ORLOVA	{"email": "orlovavalentina_1968@postgrespro.ru", "phone": "+70815142364"}
0005432360994	5E3C69	4084 059814	YULIYA TROFIMOVA	{"phone": "+70339395330"}
0005432360995	5E3C69	6341 721888	TAMARA MAKAROVA	{"email": "makarova_t1972@postgrespro.ru", "phone": "+70427112475"}
0005432360996	272790	8642 043959	VALENTINA DAVYDOVA	{"phone": "+70030609564"}
0005432360997	272790	0688 611837	OLGA MOROZOVA	{"phone": "+70313022108"}
0005432360998	6C3B0D	6580 013966	MARIYA ANDREEVA	{"email": "mariya_andreeva_1963@postgrespro.ru", "phone": "+70817323647"}
0005432360999	6C3B0D	9710 491353	VALERIY SIDOROV	{"email": "v_sidorov-091978@postgrespro.ru", "phone": "+70031864734"}
0005432361000	6C3B0D	0254 334907	ANTONINA KOMAROVA	{"phone": "+70048729820"}
0005432361001	C9D90D	2741 635174	MIKHAIL PETROV	{"email": "petrov-mikhail-081965@postgrespro.ru", "phone": "+70110673059"}
0005432361002	C9D90D	9100 123394	NATALYA KUZMINA	{"phone": "+70812611749"}
0005432361003	A475C1	8731 197899	TATYANA ANTONOVA	{"phone": "+70558112246"}
0005432361004	A7159A	5557 003340	IRAIDA KUZNECOVA	{"email": "ikuznecova-1968@postgrespro.ru", "phone": "+70414994266"}
0005432361005	A7159A	2935 559965	ALEKSANDR TIKHONOV	{"phone": "+70052901074"}
0005432361006	5EF54C	0780 736010	LYUBOV STEPANOVA	{"email": "l_stepanova.111977@postgrespro.ru", "phone": "+70233080964"}
0005432361007	5EF54C	4161 377724	NINA KOROLEVA	{"phone": "+70088057248"}
0005432361118	CB6EE6	8050 534646	TIMOFEY TARASOV	{"phone": "+70651960683"}
0005432361008	5EF54C	8436 934597	LYUDMILA ALEKSEEVA	{"email": "alekseeva_lyudmila061960@postgrespro.ru", "phone": "+70622204121"}
0005432361009	928F91	3127 038905	ANNA PAVLOVA	{"email": "anna-pavlova-1973@postgrespro.ru", "phone": "+70686858245"}
0005432361010	F59F69	1973 291282	NIKOLAY IVANOV	{"email": "ivanov.n_1962@postgrespro.ru", "phone": "+70442695751"}
0005432361011	F59F69	9585 157757	VLADIMIR ABRAMOV	{"phone": "+70844376218"}
0005432361012	EEB8A3	9157 203463	SERGEY SOKOLOV	{"phone": "+70362582351"}
0005432361013	2966E8	4617 984986	VALERIY MIKHAYLOV	{"phone": "+70813777141"}
0005432361014	47E840	5122 041631	TATYANA ZAYCEVA	{"phone": "+70152552952"}
0005432361015	811283	3720 647830	FEDOR GERASIMOV	{"phone": "+70557297388"}
0005432361016	92C1FB	8907 446721	LILIYA ROMANOVA	{"phone": "+70470363451"}
0005432361017	9BAB82	5023 899877	VLADIMIR GAVRILOV	{"email": "gavrilov-vladimir_29011978@postgrespro.ru", "phone": "+70389436469"}
0005432361018	BFBF65	7303 051571	DARYA SOKOLOVA	{"email": "darya-sokolova121966@postgrespro.ru", "phone": "+70357409953"}
0005432361019	656B33	5639 015113	ELIZAVETA STEPANOVA	{"phone": "+70026754596"}
0005432361020	A9B1A4	6449 440375	ILYA KOZLOV	{"email": "kozlov_i05051976@postgrespro.ru", "phone": "+70317761591"}
0005432361021	A9B1A4	7415 157543	SOFYA CHERNOVA	{"email": "sofya.chernova_1962@postgrespro.ru", "phone": "+70491775054"}
0005432361022	ECE205	9463 061100	LIDIYA TARASOVA	{"email": "ltarasova1966@postgrespro.ru", "phone": "+70029542555"}
0005432361023	DDAC27	6498 770167	ALENA OSIPOVA	{"phone": "+70026434543"}
0005432361024	5CF55C	7190 836226	FEDOR ZAYCEV	{"email": "zaycevfedor.21111972@postgrespro.ru", "phone": "+70586023626"}
0005432361025	5CC743	8859 038686	DENIS SOROKIN	{"phone": "+70571891382"}
0005432361026	7EC129	0246 306070	SAMVEL ZAKHAROV	{"email": "zakharov_samvel-021976@postgrespro.ru", "phone": "+70788653425"}
0005432361027	7EC129	5856 278146	IGOR SMIRNOV	{"email": "ismirnov.27061973@postgrespro.ru", "phone": "+70513955515"}
0005432361028	98A5E5	2083 824730	ANTON TIKHONOV	{"phone": "+70809461149"}
0005432361029	83339E	1557 457467	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana_18051971@postgrespro.ru", "phone": "+70861596879"}
0005432361030	83339E	8149 967762	YULIYA DAVYDOVA	{"email": "davydova_yuliya011975@postgrespro.ru", "phone": "+70005526549"}
0005432361031	1F0E7B	3799 784636	TIMUR AFANASEV	{"email": "t.afanasev_081969@postgrespro.ru", "phone": "+70629213092"}
0005432361032	1F0E7B	2019 823519	ALEKSEY STEPANOV	{"email": "a-stepanov.051973@postgrespro.ru", "phone": "+70007221075"}
0005432361033	57771F	4680 467593	RAFIK NOVIKOV	{"phone": "+70086523876"}
0005432361034	1B20A3	3535 602238	RAISA EFIMOVA	{"email": "raisa-efimova1971@postgrespro.ru", "phone": "+70078077467"}
0005432361035	E9D22C	1922 630877	YULIYA BORISOVA	{"email": "yuliya.borisova_1970@postgrespro.ru", "phone": "+70764446744"}
0005432361036	E9D22C	0621 948674	DMITRIY KONOVALOV	{"email": "konovalov.d-02011961@postgrespro.ru", "phone": "+70596803178"}
0005432361037	5AF3D6	6093 170672	VALENTINA KOLESNIKOVA	{"phone": "+70975069852"}
0005432361038	B979D1	1559 042556	VLADISLAV SERGEEV	{"phone": "+70364247224"}
0005432361039	B979D1	5461 677649	ZHANNA DANILOVA	{"email": "danilova-z_031971@postgrespro.ru", "phone": "+70902122490"}
0005432361040	192EE9	8332 483148	EVGENIY EGOROV	{"email": "egorove_1979@postgrespro.ru", "phone": "+70726656348"}
0005432361041	5F8201	9227 977660	OLGA KUZMINA	{"phone": "+70437285696"}
0005432361042	5F8201	9982 229615	ELENA ARKHIPOVA	{"email": "elenaarkhipova_1985@postgrespro.ru", "phone": "+70705212527"}
0005432361043	BCBBA5	8181 129949	GENNADIY TARASOV	{"email": "gennadiytarasov.1974@postgrespro.ru", "phone": "+70409312659"}
0005432361044	E7173E	9141 671719	IRINA FILATOVA	{"phone": "+70717405401"}
0005432361045	11E021	5710 461099	LYUDMILA KULIKOVA	{"email": "kulikoval.1971@postgrespro.ru", "phone": "+70881191425"}
0005432361046	30C7D6	7613 798399	ANATOLIY FROLOV	{"email": "a.frolov-07041970@postgrespro.ru", "phone": "+70315413332"}
0005432361047	30C7D6	0092 265216	NINA MAKAROVA	{"phone": "+70693579148"}
0005432361048	13F058	5699 202518	DMITRIY IVANOV	{"email": "ivanov-d07021969@postgrespro.ru", "phone": "+70677454299"}
0005432361049	490AC8	9901 308829	SERGEY STEPANOV	{"phone": "+70012713910"}
0005432361050	7BF5EB	4910 606769	ELENA ZHUKOVA	{"phone": "+70922384800"}
0005432361051	7BF5EB	9990 421022	SEMEN CHERNOV	{"phone": "+70742640601"}
0005432361052	F94D78	4258 725179	KRISTINA TIMOFEEVA	{"email": "kristina-timofeeva_101970@postgrespro.ru", "phone": "+70731527840"}
0005432361053	A9D7F9	0932 196090	VITALIY PAVLOV	{"email": "vitaliy.pavlov11061981@postgrespro.ru", "phone": "+70597135280"}
0005432361054	9D5408	4148 108552	DARYA NIKOLAEVA	{"email": "d.nikolaeva_19071973@postgrespro.ru", "phone": "+70644253906"}
0005432361055	B0462F	3688 589180	SERGEY YAKOVLEV	{"email": "sergey.yakovlev-1968@postgrespro.ru", "phone": "+70553939371"}
0005432361056	B5ADFC	4235 664027	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr.1971@postgrespro.ru", "phone": "+70826062598"}
0005432361057	8F4547	8284 505749	NINA ANISIMOVA	{"email": "anisimova.nina.1966@postgrespro.ru", "phone": "+70644230575"}
0005432361058	307A92	4324 037573	TATYANA EGOROVA	{"phone": "+70617759546"}
0005432361059	A5A65C	1366 738062	EVGENIYA TIKHONOVA	{"phone": "+70672522355"}
0005432361060	C8A49E	6045 579464	EVDOKIYA MAKAROVA	{"email": "emakarova-06071981@postgrespro.ru", "phone": "+70412928168"}
0005432361061	C8A49E	4609 157491	ALEKSANDR KAZAKOV	{"phone": "+70988785821"}
0005432361062	B3C802	3056 854195	ZAKHAR VOROBEV	{"email": "zakhar.vorobev1980@postgrespro.ru", "phone": "+70961581137"}
0005432361063	B3C802	4355 446162	VLADIMIR SOROKIN	{"email": "sorokinvladimir-031964@postgrespro.ru", "phone": "+70082869060"}
0005432361064	C3AA21	8960 320981	SERGEY ANDREEV	{"email": "andreev-s.1985@postgrespro.ru", "phone": "+70018018420"}
0005432361065	C3AA21	6045 216139	TATYANA GAVRILOVA	{"email": "gavrilovatatyana.061971@postgrespro.ru", "phone": "+70780375251"}
0005432361066	19BBFD	2226 258214	ALEKSANDR ANTONOV	{"email": "a-antonov-1969@postgrespro.ru", "phone": "+70369546125"}
0005432361067	DD9E13	1582 836003	ALEKSEY BONDARENKO	{"email": "aleksey.bondarenko.1980@postgrespro.ru", "phone": "+70235103772"}
0005432361068	DD9E13	0903 250808	VLADIMIR VLASOV	{"phone": "+70021588118"}
0005432361069	5EDBE2	2950 388268	LYUDMILA FILATOVA	{"email": "l-filatova1981@postgrespro.ru", "phone": "+70470175489"}
0005432361070	65BEB6	4451 806381	OKSANA RODIONOVA	{"email": "o.rodionova081962@postgrespro.ru", "phone": "+70194133914"}
0005432361071	4C4818	6156 632781	ELENA SOKOLOVA	{"phone": "+70334000250"}
0005432361072	5B7CBC	8385 034959	GALINA NOVIKOVA	{"email": "novikova.galina1966@postgrespro.ru", "phone": "+70866049603"}
0005432361073	301319	5495 419578	ALEKSANDR FEDOROV	{"phone": "+70821751019"}
0005432361074	CED06D	0189 816730	VALENTINA KULIKOVA	{"email": "valentina_kulikova-16081972@postgrespro.ru", "phone": "+70191459009"}
0005432361075	A9A0C6	1538 661023	YULIYA LAZAREVA	{"email": "lazarevayuliya1962@postgrespro.ru", "phone": "+70031720682"}
0005432361076	BED635	4895 653416	NAILYA VASILEVA	{"email": "vasilevan.23081962@postgrespro.ru", "phone": "+70990536422"}
0005432361077	CCC89C	3717 796014	VITALIY SOLOVEV	{"email": "vitaliysolovev1975@postgrespro.ru", "phone": "+70582237993"}
0005432361078	657880	0337 050305	VLADIMIR TARASOV	{"phone": "+70952869486"}
0005432361079	657880	0111 746924	BORIS BONDARENKO	{"phone": "+70821582420"}
0005432361080	421D33	0845 334478	IVAN ZHURAVLEV	{"email": "zhuravlevi-1966@postgrespro.ru", "phone": "+70246391406"}
0005432361081	421D33	1659 389117	DMITRIY SCHERBAKOV	{"phone": "+70265322259"}
0005432361082	3CB021	8799 562353	SVETLANA FILIPPOVA	{"email": "filippova_svetlana.15061989@postgrespro.ru", "phone": "+70433249639"}
0005432361083	3CB021	8198 052971	OKSANA NESTEROVA	{"phone": "+70215895006"}
0005432361084	3CB021	1092 175319	RUSTAM MOROZOV	{"email": "morozov.rustam021966@postgrespro.ru", "phone": "+70073757443"}
0005432361085	D6CD70	9027 828031	ALEKSANDR ILIN	{"phone": "+70400712039"}
0005432361086	EC9D7E	4138 804923	ALEKSANDR ORLOV	{"phone": "+70087918778"}
0005432361087	C48CD2	2391 834894	LIDIYA KOZLOVA	{"email": "l.kozlova_021976@postgrespro.ru", "phone": "+70667209840"}
0005432361088	59BABB	4186 021297	ALEKSANDR SIDOROV	{"phone": "+70928853967"}
0005432361089	F3596E	5808 585649	NIKOLAY GUSEV	{"email": "gusev.nikolay1965@postgrespro.ru", "phone": "+70797088046"}
0005432361090	C4BC70	2769 488598	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr.25021975@postgrespro.ru", "phone": "+70978047091"}
0005432361091	C4BC70	2740 025999	VALENTINA MELNIKOVA	{"phone": "+70445364501"}
0005432361092	E44EAF	9533 523332	SERGEY FILIPPOV	{"email": "filippovs.041976@postgrespro.ru", "phone": "+70977133558"}
0005432361093	E44EAF	7279 184997	ALEKSANDR PAVLOV	{"email": "a_pavlov_111976@postgrespro.ru", "phone": "+70011102355"}
0005432361094	FF9814	7794 275611	YURIY SCHERBAKOV	{"email": "y.scherbakov-031975@postgrespro.ru", "phone": "+70324354559"}
0005432361095	FF9814	0486 270838	OLEG KUZNECOV	{"email": "kuznecov.oleg1972@postgrespro.ru", "phone": "+70543546943"}
0005432361096	488257	7110 189877	NATALYA ISAEVA	{"email": "isaeva-natalya31071965@postgrespro.ru", "phone": "+70411321360"}
0005432361097	E419A8	2705 452786	SVETLANA POPOVA	{"phone": "+70402374520"}
0005432361098	F900AB	4699 547709	TATYANA SERGEEVA	{"email": "tatyana.sergeeva.24031976@postgrespro.ru", "phone": "+70208059843"}
0005432361099	B82FC4	8287 664291	DANILA KONOVALOV	{"phone": "+70190528432"}
0005432361100	D00254	8792 565386	RISHAT SIDOROV	{"email": "sidorov-rishat.011981@postgrespro.ru", "phone": "+70498254009"}
0005432361101	D00254	3339 171876	TATYANA MOISEEVA	{"phone": "+70421311273"}
0005432361102	23F8E3	1031 999751	ANASTASIYA KALININA	{"phone": "+70011616929"}
0005432361103	3A7E7D	8270 419149	EKATERINA MASLOVA	{"email": "ekaterinamaslova081975@postgrespro.ru", "phone": "+70800393345"}
0005432361104	4E45B7	3429 417686	TATYANA POPOVA	{"phone": "+70382352071"}
0005432361105	1E1679	6488 801011	IRINA NAUMOVA	{"email": "naumovai_10031971@postgrespro.ru", "phone": "+70746837791"}
0005432361106	1E1679	8701 043182	KSENIYA BELOVA	{"phone": "+70039319182"}
0005432361107	1E1679	3647 634798	KRISTINA ZAKHAROVA	{"phone": "+70386437338"}
0005432361108	967515	8066 411165	NATALIYA NESTEROVA	{"email": "nesterova.n_1983@postgrespro.ru", "phone": "+70508469686"}
0005432361109	967515	2678 113524	ANNA ZAKHAROVA	{"email": "zakharova.anna-1970@postgrespro.ru", "phone": "+70973079508"}
0005432361110	87FCDC	9921 495969	IVAN SHEVCHENKO	{"phone": "+70689255755"}
0005432361111	E53F76	6406 531405	IRINA ZAKHAROVA	{"email": "zakharova_i_1980@postgrespro.ru", "phone": "+70453230923"}
0005432361112	F36352	3247 766138	IRINA FOMINA	{"email": "irinafomina051984@postgrespro.ru", "phone": "+70250966656"}
0005432361113	014D1E	0386 508374	SOFYA KUZMINA	{"phone": "+70865412998"}
0005432361115	94BE91	1977 757054	ELENA MOROZOVA	{"email": "morozova_e1968@postgrespro.ru", "phone": "+70803528533"}
0005432361116	94BE91	8762 890253	OLGA PAVLOVA	{"email": "o-pavlova_04021987@postgrespro.ru", "phone": "+70144227744"}
0005432361117	CB6EE6	4122 633209	ALEKSANDR SCHERBAKOV	{"email": "scherbakova1958@postgrespro.ru", "phone": "+70436975537"}
0005432361119	7358AA	9413 713025	ANATOLIY KOZLOV	{"phone": "+70019340528"}
0005432361120	B84302	7372 459443	ALEKSANDR IVANOV	{"phone": "+70642154760"}
0005432361121	7C665C	4511 432218	IRINA POPOVA	{"phone": "+70344668052"}
0005432361122	7C665C	7377 053358	DARYA ERMAKOVA	{"email": "d_ermakova_081970@postgrespro.ru", "phone": "+70221973215"}
0005432361123	77E241	0323 023642	IGOR KOZLOV	{"phone": "+70875900373"}
0005432361124	FD22D8	1245 837942	DMITRIY MAKAROV	{"email": "d-makarov1966@postgrespro.ru", "phone": "+70819130279"}
0005432361125	FD22D8	0147 219032	MARINA BORISOVA	{"phone": "+70440963388"}
0005432361126	1BCAE5	6002 165092	SERGEY GERASIMOV	{"email": "gerasimovs.1962@postgrespro.ru", "phone": "+70365752149"}
0005432361127	4003FD	5661 983792	NADEZHDA KRASNOVA	{"phone": "+70852127413"}
0005432361128	64026E	8989 598788	PAVEL STEPANOV	{"email": "p.stepanov_1973@postgrespro.ru", "phone": "+70608898770"}
0005432361129	EC984C	6769 313749	GALINA ANDREEVA	{"phone": "+70928729521"}
0005432361130	3D146D	5799 701119	NIKOLAY MEDVEDEV	{"phone": "+70069487664"}
0005432361131	3D146D	8670 191899	KLAVDIYA PETROVA	{"phone": "+70872258154"}
0005432361132	06764E	3353 521108	OLGA KONDRATEVA	{"phone": "+70205323666"}
0005432361133	06764E	8162 505530	IRINA POTAPOVA	{"email": "potapova-irina011971@postgrespro.ru", "phone": "+70272343481"}
0005432361134	BA1F4E	9883 733073	VLADIMIR PETROV	{"email": "petrov.v_30121957@postgrespro.ru", "phone": "+70398332873"}
0005432361135	ADEE30	5629 594916	VALENTINA MAKSIMOVA	{"phone": "+70961988318"}
0005432361136	C4F4EC	1858 174385	YURIY KOZLOV	{"email": "y.kozlov_041970@postgrespro.ru", "phone": "+70343731602"}
0005432361137	D14B6D	4517 598238	ANDREY ZAKHAROV	{"email": "andrey.zakharov1972@postgrespro.ru", "phone": "+70130674720"}
0005432361138	285D60	9033 224934	YULIYA NAZAROVA	{"phone": "+70037331079"}
0005432361139	B46347	3202 804412	DMITRIY KUDRYASHOV	{"email": "dmitriykudryashov011987@postgrespro.ru", "phone": "+70853529470"}
0005432361140	55AB2D	5557 708580	ALEKSANDR SIDOROV	{"email": "sidorov-a-14041969@postgrespro.ru", "phone": "+70975229018"}
0005432361141	55AB2D	3942 988328	IRINA RODIONOVA	{"email": "rodionova-irina031975@postgrespro.ru", "phone": "+70045981845"}
0005432361142	A6EB71	4336 374433	ANASTASIYA FROLOVA	{"phone": "+70949696044"}
0005432361143	A6EB71	7234 671521	MARIYA NIKITINA	{"phone": "+70078478475"}
0005432361144	8AC50B	7943 153901	OKSANA FEDOROVA	{"email": "fedorova_oksana.1981@postgrespro.ru", "phone": "+70728747466"}
0005432361145	8AC50B	1888 360306	ALEKSANDR NIKOLAEV	{"phone": "+70965805139"}
0005432361146	327ACD	3601 507576	MARIYA ZOTOVA	{"phone": "+70273018613"}
0005432361147	893890	9619 375358	NATALYA VOROBEVA	{"email": "natalya-vorobeva.1988@postgrespro.ru", "phone": "+70183266702"}
0005432361148	63EAEB	1523 228333	OKSANA KUZMINA	{"email": "kuzmina.o_16071977@postgrespro.ru", "phone": "+70191062681"}
0005432361149	63EAEB	7154 581327	TATYANA GUSEVA	{"phone": "+70611480751"}
0005432361150	2E90DF	8200 507760	GALINA DMITRIEVA	{"email": "dmitrievag_1977@postgrespro.ru", "phone": "+70496604386"}
0005432361151	1CFAE1	1723 679072	SVETLANA MELNIKOVA	{"phone": "+70442418947"}
0005432361152	F88EEA	9503 926179	TAMARA MAKAROVA	{"phone": "+70875876976"}
0005432361153	4CCF24	6311 764260	VITALIY KUZNECOV	{"phone": "+70757709915"}
0005432361154	B54454	4097 149523	KAROLINA KOLESNIKOVA	{"email": "kolesnikovak-071965@postgrespro.ru", "phone": "+70974434761"}
0005432361155	B54454	1737 629877	DENIS SEMENOV	{"email": "semenov-denis_1964@postgrespro.ru", "phone": "+70776631992"}
0005432361156	08099A	6659 862676	NATALYA YAKOVLEVA	{"phone": "+70741966595"}
0005432361157	08099A	8354 353228	MAKSIM ROMANOV	{"email": "maksim_romanov_021984@postgrespro.ru", "phone": "+70599387799"}
0005432361158	08099A	7282 947529	ELENA MARTYNOVA	{"email": "e_martynova-041966@postgrespro.ru", "phone": "+70654995147"}
0005432361159	2BA2E2	5900 253846	STEPAN STEPANOV	{"email": "stepanov-stepan.1982@postgrespro.ru", "phone": "+70416519273"}
0005432361160	2BA2E2	1112 036826	ANASTASIYA KOLESNIKOVA	{"email": "anastasiyakolesnikova_1968@postgrespro.ru", "phone": "+70751243273"}
0005432361161	2BA2E2	8554 522470	GENNADIY NIKITIN	{"phone": "+70518085215"}
0005432361162	53F8AF	7251 372659	VLADIMIR KISELEV	{"phone": "+70129616405"}
0005432361163	78B29E	6797 130919	ANAIT GRISHINA	{"email": "grishinaanait1963@postgrespro.ru", "phone": "+70857991070"}
0005432361164	1FA201	4494 586013	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev-1965@postgrespro.ru", "phone": "+70833966081"}
0005432361165	0E998E	0751 043230	TATYANA ISAEVA	{"email": "t-isaeva06061975@postgrespro.ru", "phone": "+70368035887"}
0005432361166	689C78	6951 824759	ALENA ZOTOVA	{"email": "zotova-alena081961@postgrespro.ru", "phone": "+70676043316"}
0005432361167	689C78	0934 098691	VIKTORIYA YUDINA	{"email": "v-yudina_1972@postgrespro.ru", "phone": "+70162802050"}
0005432361168	6EC3A5	0334 359292	SERGEY YAKOVLEV	{"email": "yakovlev.s_1964@postgrespro.ru", "phone": "+70664977445"}
0005432361169	9A8036	3667 075831	ZAKHAR BARANOV	{"email": "z.baranov-1969@postgrespro.ru", "phone": "+70981929626"}
0005432361170	036B10	7985 953008	OLGA GERASIMOVA	{"phone": "+70915228755"}
0005432361171	F836E8	0781 173332	ELENA YUDINA	{"email": "yudina-e_04051977@postgrespro.ru", "phone": "+70088219368"}
0005432361172	F836E8	7480 117532	NATALYA MAKAROVA	{"email": "makarova.natalya-1966@postgrespro.ru", "phone": "+70812888828"}
0005432361173	300490	5091 545757	GALINA ROMANOVA	{"email": "romanova-galina091976@postgrespro.ru", "phone": "+70467059363"}
0005432361174	300490	8632 602746	VLADISLAV ROMANOV	{"email": "romanov_vladislav061968@postgrespro.ru", "phone": "+70859868621"}
0005432361175	A52379	2708 527604	EKATERINA PAVLOVA	{"phone": "+70333061694"}
0005432361176	037096	7410 108474	VASILIY PETROV	{"email": "petrov.vasiliy-061968@postgrespro.ru", "phone": "+70502579502"}
0005432361177	90A506	9314 365168	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov-081967@postgrespro.ru", "phone": "+70348599675"}
0005432361178	90A506	6838 149138	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr_081972@postgrespro.ru", "phone": "+70404979913"}
0005432361179	CE563F	6458 591243	IVAN KOZLOV	{"email": "kozlovivan_021969@postgrespro.ru", "phone": "+70657754432"}
0005432361180	5E2E61	1539 088512	ARMAN KUDRYASHOV	{"email": "kudryashov-arman.1974@postgrespro.ru", "phone": "+70486924808"}
0005432361181	5E2E61	0751 621614	SERGEY CHERNOV	{"phone": "+70484687514"}
0005432361182	7A8720	1246 090293	ELENA NAZAROVA	{"email": "elena_nazarova1971@postgrespro.ru", "phone": "+70104601507"}
0005432361183	FF06A3	3470 318305	ALEVTINA NAZAROVA	{"email": "nazarova-a041980@postgrespro.ru", "phone": "+70611046639"}
0005432361184	FF06A3	1711 161769	ANASTASIYA EFIMOVA	{"phone": "+70695349167"}
0005432361185	1AB37F	2905 870350	ANATOLIY AFANASEV	{"phone": "+70347423871"}
0005432361186	1AB37F	9544 893668	IGOR MOISEEV	{"email": "i.moiseev_081976@postgrespro.ru", "phone": "+70477191931"}
0005432361187	CE8DA2	7204 333606	SERGEY DMITRIEV	{"phone": "+70385497086"}
0005432361188	77A3F5	9521 817110	RUSTAM FROLOV	{"email": "frolov.rustam1964@postgrespro.ru", "phone": "+70767250547"}
0005432361189	B698B5	2459 257254	TIMUR DENISOV	{"email": "tdenisov.071968@postgrespro.ru", "phone": "+70857747573"}
0005432361190	8E1704	2229 736781	VALENTINA ANTONOVA	{"phone": "+70784951285"}
0005432361191	3B08C3	4637 789423	ANNA SERGEEVA	{"email": "sergeevaanna-1970@postgrespro.ru", "phone": "+70163796567"}
0005432361192	BF6995	1412 960808	SERGEY KUZMIN	{"email": "s-kuzmin_1980@postgrespro.ru", "phone": "+70800373263"}
0005432361193	BF6995	1746 012950	NIKOLAY EGOROV	{"email": "n.egorov.1982@postgrespro.ru", "phone": "+70548201113"}
0005432361194	BA7490	0841 847392	ALISA YUDINA	{"email": "yudina-alisa.011974@postgrespro.ru", "phone": "+70708550317"}
0005432361195	00B2FD	1526 601155	ALEKSANDR FILIPPOV	{"phone": "+70424830746"}
0005432361196	009C73	2096 489646	TAISA ERMAKOVA	{"phone": "+70471862431"}
0005432361197	D8950B	5297 467929	MARINA LOGINOVA	{"email": "loginova-m-28041969@postgrespro.ru", "phone": "+70901883591"}
0005432361198	D8950B	7465 836865	MIKHAIL ALEKSEEV	{"phone": "+70422199845"}
0005432361199	DA8467	0007 753777	TATYANA SEMENOVA	{"email": "t.semenova.30051972@postgrespro.ru", "phone": "+70662377775"}
0005432361200	D768BC	8979 013389	ARKADIY IVANOV	{"email": "ivanov-arkadiy-1980@postgrespro.ru", "phone": "+70083394974"}
0005432361201	D768BC	1726 395736	ALEKSEY KUZNECOV	{"phone": "+70393483830"}
0005432361202	2CA8EE	4653 530736	VIKTOR NAUMOV	{"email": "naumov_viktor13081984@postgrespro.ru", "phone": "+70895793476"}
0005432361203	2CA8EE	8957 931515	NATALYA KUZNECOVA	{"phone": "+70340260062"}
0005432361204	7C3946	1619 924560	NONNA FROLOVA	{"email": "n-frolova-06021968@postgrespro.ru", "phone": "+70167542798"}
0005432361205	7C3946	1532 658142	IVAN DMITRIEV	{"phone": "+70591686165"}
0005432361206	A8685B	1417 820155	SERGEY IVANOV	{"email": "sivanov.26061977@postgrespro.ru", "phone": "+70895794052"}
0005432361207	E1B174	5715 193308	ANDREY ANTONOV	{"phone": "+70537544012"}
0005432361208	E1B174	3818 060627	NIKOLAY ZHURAVLEV	{"email": "zhuravlevn_11061962@postgrespro.ru", "phone": "+70324800696"}
0005432361209	0A0C99	8039 337917	NADEZHDA VOLKOVA	{"email": "n.volkova_03071967@postgrespro.ru", "phone": "+70396062782"}
0005432361210	D0ADA6	5991 765498	VERA POLYAKOVA	{"phone": "+70386174375"}
0005432361211	B758D9	4514 822713	VLADIMIR FROLOV	{"phone": "+70415249503"}
0005432361212	21DCC3	0499 494070	VLADIMIR KONOVALOV	{"email": "v.konovalov-051957@postgrespro.ru", "phone": "+70427083895"}
0005432361213	21DCC3	9224 660689	ALEKSANDR VLASOV	{"phone": "+70025658701"}
0005432361214	14DC96	3758 570521	IVAN TIKHONOV	{"email": "i-tikhonov101980@postgrespro.ru", "phone": "+70019808710"}
0005432361215	14DC96	0516 285377	NADEZHDA EGOROVA	{"phone": "+70386864235"}
0005432361216	650A2E	0880 959662	MARGARITA IVANOVA	{"email": "m_ivanova_28121974@postgrespro.ru", "phone": "+70165550064"}
0005432361217	650A2E	3123 282315	KONSTANTIN BONDARENKO	{"email": "konstantinbondarenko_1969@postgrespro.ru", "phone": "+70039376970"}
0005432361218	C246D8	0341 329728	OLGA DAVYDOVA	{"email": "olga.davydova121975@postgrespro.ru", "phone": "+70240193213"}
0005432361219	C246D8	5708 029011	SVETLANA KRASNOVA	{"email": "krasnova.svetlana_03121967@postgrespro.ru", "phone": "+70360859486"}
0005432361220	0F8B7F	6425 576486	SVETLANA MIKHAYLOVA	{"phone": "+70816752238"}
0005432361221	0F8B7F	2698 257047	LARISA NAUMOVA	{"email": "larisa_naumova16091978@postgrespro.ru", "phone": "+70170040657"}
0005432361222	5A39D1	7710 361558	VLADIMIR KOROLEV	{"phone": "+70874432641"}
0005432361223	38CD1E	8970 575005	STEPAN NIKOLAEV	{"phone": "+70446456108"}
0005432361224	38CD1E	2956 278412	MARIYA TITOVA	{"email": "mariyatitova_1963@postgrespro.ru", "phone": "+70624008639"}
0005432361225	B2505D	7331 076912	SVETLANA NIKITINA	{"email": "svetlana.nikitina-101974@postgrespro.ru", "phone": "+70325130412"}
0005432361226	B2505D	1232 645011	VERA FROLOVA	{"email": "v-frolova1962@postgrespro.ru", "phone": "+70349190416"}
0005432361227	AA3AEF	3581 141199	RADIK VASILEV	{"email": "rvasilev-041967@postgrespro.ru", "phone": "+70403542887"}
0005432361228	4A9B8A	3409 743033	VLADIMIR YAKOVLEV	{"phone": "+70611021652"}
0005432361229	4A9B8A	9501 920072	NIKOLAY EGOROV	{"phone": "+70185315914"}
0005432361230	D64400	9892 754248	PETR MELNIKOV	{"phone": "+70344690062"}
0005432361231	D64400	0316 211352	IRINA POPOVA	{"email": "popova_irina121976@postgrespro.ru", "phone": "+70872772482"}
0005432361232	D64400	9377 407339	YURIY KOZLOV	{"email": "y.kozlov_071981@postgrespro.ru", "phone": "+70934065172"}
0005432361233	550375	2544 111501	DMITRIY SOLOVEV	{"phone": "+70096475588"}
0005432361234	550375	8111 160050	GALINA AFANASEVA	{"phone": "+70372264865"}
0005432361235	3D9442	2287 124966	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr-31121963@postgrespro.ru", "phone": "+70964831843"}
0005432361236	37097E	1004 875211	OLGA BORISOVA	{"phone": "+70487865104"}
0005432361237	CAAC6C	5086 365935	VITALIY ANTONOV	{"phone": "+70794519214"}
0005432361238	32178F	3982 863766	ARTEM BELOV	{"phone": "+70076433732"}
0005432361239	466E94	9430 589861	ANDREY KOROLEV	{"phone": "+70480589513"}
0005432361240	828D03	6990 104491	TATYANA RODIONOVA	{"phone": "+70597700538"}
0005432361241	828D03	9745 091001	ELENA POTAPOVA	{"email": "elena-potapova-1977@postgrespro.ru", "phone": "+70003279093"}
0005432361242	828D03	6932 216760	IGOR VOLKOV	{"email": "i.volkov-1965@postgrespro.ru", "phone": "+70965044598"}
0005432361243	D00C4D	3271 158098	SVETLANA IVANOVA	{"phone": "+70186857273"}
0005432361244	D00C4D	1147 946114	AZAT EGOROV	{"email": "egorov.a.1975@postgrespro.ru", "phone": "+70229779618"}
0005432361245	9B5003	9292 770785	EGOR GAVRILOV	{"phone": "+70771929130"}
0005432361246	5F8461	5913 821886	ANATOLIY FOMIN	{"phone": "+70960459633"}
0005432361247	D34F4C	6361 157120	EKATERINA IVANOVA	{"phone": "+70991205121"}
0005432361248	58B3F8	5503 940228	MIKHAIL KAZAKOV	{"email": "kazakov-mikhail30061972@postgrespro.ru", "phone": "+70012121938"}
0005432361249	72ED73	7416 294917	ELVIRA SOLOVEVA	{"email": "soloveva-elvira.03111972@postgrespro.ru", "phone": "+70291051344"}
0005432361250	72ED73	3269 972725	LIDIYA KULIKOVA	{"email": "lidiyakulikova_051968@postgrespro.ru", "phone": "+70413056865"}
0005432361251	29D32D	0543 175597	VLADIMIR SEMENOV	{"email": "semenovv03031971@postgrespro.ru", "phone": "+70074847993"}
0005432361252	408C2F	3829 780804	ELIZAVETA TIKHONOVA	{"phone": "+70394997309"}
0005432361253	C87D49	6757 722760	GENNADIY KUZNECOV	{"email": "kuznecovg061968@postgrespro.ru", "phone": "+70961877583"}
0005432361254	FEF42C	0647 272096	NATALYA OVCHINNIKOVA	{"email": "n-ovchinnikova_1983@postgrespro.ru", "phone": "+70185671242"}
0005432361255	D8B061	5634 485335	YAKOV DAVYDOV	{"email": "yakov.davydov-051975@postgrespro.ru", "phone": "+70809929715"}
0005432361256	D8B061	5033 846989	NIKOLAY KUZNECOV	{"phone": "+70788568604"}
0005432361257	E34AA3	3404 119219	YURIY MATVEEV	{"email": "yuriy.matveev-1961@postgrespro.ru", "phone": "+70240105011"}
0005432361258	1820B5	7058 027263	ANNA POPOVA	{"phone": "+70174563903"}
0005432361259	9605F8	1937 696252	ELENA KUZNECOVA	{"email": "kuznecovaelena-1965@postgrespro.ru", "phone": "+70680546949"}
0005432361260	371D4D	9293 257297	VIKTOR VOLKOV	{"phone": "+70768777234"}
0005432361261	371D4D	6111 016954	ANDREY BELOV	{"email": "a-belov-1973@postgrespro.ru", "phone": "+70811116192"}
0005432361262	041127	9669 423343	LYUDMILA MATVEEVA	{"phone": "+70909382105"}
0005432361263	C2D2C2	8684 567363	GALINA MAKSIMOVA	{"email": "galina-maksimova.081969@postgrespro.ru", "phone": "+70714651936"}
0005432361264	8CE390	1468 634085	EKATERINA SOKOLOVA	{"email": "sokolova-e.01051972@postgrespro.ru", "phone": "+70326353744"}
0005432361265	8CE390	1180 385267	ANDREY NOVIKOV	{"email": "novikov_a.07121981@postgrespro.ru", "phone": "+70364564089"}
0005432361266	274899	1342 552226	YURIY SOROKIN	{"email": "sorokin.y-1966@postgrespro.ru", "phone": "+70407883985"}
0005432361267	18BD06	8296 666102	NIKITA DAVYDOV	{"phone": "+70545647208"}
0005432361268	18BD06	0621 919857	MARINA ARKHIPOVA	{"email": "marina-arkhipova_24061967@postgrespro.ru", "phone": "+70115357237"}
0005432361269	9C0292	7463 166307	IRINA DENISOVA	{"email": "denisova_irina.12111964@postgrespro.ru", "phone": "+70796717901"}
0005432361270	2D7D6E	7656 466197	RUSLAN VASILEV	{"phone": "+70461769760"}
0005432361271	2D7D6E	7032 810674	TATYANA DMITRIEVA	{"email": "tdmitrieva.04071967@postgrespro.ru", "phone": "+70804831403"}
0005432361272	2301E9	2966 300732	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev-1977@postgrespro.ru", "phone": "+70379866238"}
0005432361273	2301E9	0630 608064	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov.07041976@postgrespro.ru", "phone": "+70456587276"}
0005432361274	938AD5	8750 509865	VALENTINA CHERNOVA	{"email": "vchernova.1963@postgrespro.ru", "phone": "+70400624848"}
0005432361275	938AD5	9747 569607	VERONIKA GAVRILOVA	{"email": "veronikagavrilova06111961@postgrespro.ru", "phone": "+70505296996"}
0005432361276	D3CD27	4019 011433	MIKHAIL PETROV	{"phone": "+70803256630"}
0005432361277	35E980	9829 370412	VLADIMIR VASILEV	{"phone": "+70493252658"}
0005432361278	F43B9F	8697 561969	GALINA FILATOVA	{"email": "filatovag_02111977@postgrespro.ru", "phone": "+70111037446"}
0005432361279	C2E0AE	5877 209174	ELENA EGOROVA	{"phone": "+70364094340"}
0005432361280	C2E0AE	8211 474171	IVAN MOROZOV	{"phone": "+70375438898"}
0005432361281	188F54	4558 589884	ALEKSANDRA VASILEVA	{"email": "aleksandra-vasileva.1977@postgrespro.ru", "phone": "+70771248667"}
0005432361282	188F54	7101 556090	ANASTASIYA ORLOVA	{"phone": "+70841539617"}
0005432361283	D0415B	0310 336406	NIKOLAY SEMENOV	{"email": "semenovn1972@postgrespro.ru", "phone": "+70467577357"}
0005432361284	D0415B	8288 532366	VLADIMIR PAVLOV	{"phone": "+70169773978"}
0005432361285	C54AB7	3119 057911	SERGEY KUZNECOV	{"email": "sergeykuznecov.041972@postgrespro.ru", "phone": "+70050850717"}
0005432361286	DF7927	9195 188428	VLADISLAV GRIGOREV	{"phone": "+70489350701"}
0005432361287	DF7927	2602 594387	ANDREY PETROV	{"email": "petrov_a-011972@postgrespro.ru", "phone": "+70056765952"}
0005432361288	9AC73B	9417 756225	OLGA NIKITINA	{"email": "nikitina-o-20121965@postgrespro.ru", "phone": "+70109020656"}
0005432361289	412F0A	1169 695518	ROZA POPOVA	{"phone": "+70045616629"}
0005432361290	FDA04F	7463 257949	RAISA MIKHAYLOVA	{"phone": "+70358858339"}
0005432361291	30E1CA	0494 919379	VALENTINA FOMINA	{"phone": "+70091761464"}
0005432361292	30E1CA	9125 656805	SERGEY KAZAKOV	{"phone": "+70539266122"}
0005432361293	A5693A	3697 420959	LYUDMILA DAVYDOVA	{"email": "lyudmila_davydova041968@postgrespro.ru", "phone": "+70679226221"}
0005432361294	3CDEF6	5141 419113	ALEKSANDR AFANASEV	{"email": "afanasev_a1969@postgrespro.ru", "phone": "+70803388248"}
0005432361295	69ECBE	3338 750286	VLADIMIR ANTONOV	{"email": "antonov.vladimir-27021978@postgrespro.ru", "phone": "+70384763171"}
0005432361296	69ECBE	1185 177465	MARINA VOLKOVA	{"phone": "+70661354323"}
0005432361297	895EA0	6646 025901	VIKTOR PAVLOV	{"phone": "+70122648485"}
0005432361298	895EA0	9505 252388	NADEZHDA POPOVA	{"email": "popova-n.1975@postgrespro.ru", "phone": "+70102609529"}
0005432361299	933EA7	5616 401748	VLADIMIR KARPOV	{"phone": "+70582882703"}
0005432361300	933EA7	5519 006615	ELENA LUKYANOVA	{"phone": "+70844359576"}
0005432361301	31401A	0617 972233	NADEZHDA KOROLEVA	{"phone": "+70882554825"}
0005432361302	4E36E0	2553 222024	ALEKSANDR IVANOV	{"phone": "+70665441046"}
0005432361303	C74942	3776 706384	VALERIYA KUZNECOVA	{"phone": "+70159664919"}
0005432361304	D056C6	9326 442898	OLGA TARASOVA	{"phone": "+70257286023"}
0005432361305	D056C6	3384 250620	MIKHAIL BORISOV	{"phone": "+70203850585"}
0005432361306	27CCF6	8235 440575	IVAN SERGEEV	{"phone": "+70253946118"}
0005432361307	1C1D28	6428 368098	VIKTOR POPOV	{"email": "popov.viktor.31081961@postgrespro.ru", "phone": "+70437430983"}
0005432361308	13C25F	4764 157397	EKATERINA RYABOVA	{"email": "ekaterina.ryabova01031969@postgrespro.ru", "phone": "+70580364725"}
0005432361309	E40133	0795 617031	ALEKSEY MOROZOV	{"phone": "+70433418986"}
0005432361310	D4F741	0743 786896	PELAGEYA OSIPOVA	{"phone": "+70391326258"}
0005432361311	D4F741	5127 683589	DMITRIY ZAYCEV	{"email": "zaycev.dmitriy1977@postgrespro.ru", "phone": "+70944767419"}
0005432361312	1913A5	6571 060818	ALEKSANDR NAZAROV	{"phone": "+70812362520"}
0005432361313	9E0218	6137 685253	VIKTORIYA SOLOVEVA	{"email": "viktoriya-soloveva1984@postgrespro.ru", "phone": "+70033353830"}
0005432361314	9E0218	0542 033807	ALEKSANDR KOROLEV	{"email": "koroleva121964@postgrespro.ru", "phone": "+70584625353"}
0005432361315	9E0218	7026 305237	KIRA TITOVA	{"email": "ktitova031979@postgrespro.ru", "phone": "+70366427560"}
0005432361316	4DE488	8549 529201	MARIYA GUSEVA	{"email": "mariya-guseva_27111969@postgrespro.ru", "phone": "+70471655116"}
0005432361317	8F0BF5	9298 097501	VALENTINA VLASOVA	{"phone": "+70391058775"}
0005432361318	8F0BF5	5265 415829	ZINAIDA FADEEVA	{"email": "fadeeva-z24061972@postgrespro.ru", "phone": "+70109781511"}
0005432361319	28E16B	6317 008816	NATALYA KONOVALOVA	{"phone": "+70635221134"}
0005432361320	28E16B	9350 915040	OLGA ANTONOVA	{"phone": "+70785667823"}
0005432361321	EAE34C	9021 147140	MARINA IVANOVA	{"phone": "+70247432672"}
0005432361322	865496	8669 920023	GALINA ANTONOVA	{"email": "antonova.g-071974@postgrespro.ru", "phone": "+70070267583"}
0005432361323	865496	3352 175442	ARKADIY NAUMOV	{"phone": "+70195022404"}
0005432361324	FFFC8C	0221 564700	SEMEN EGOROV	{"email": "semen_egorov1959@postgrespro.ru", "phone": "+70416756897"}
0005432361325	541040	1765 189730	LIDIYA SOKOLOVA	{"phone": "+70268017682"}
0005432361326	541040	6348 973724	ANNA SIDOROVA	{"email": "sidorovaanna_121983@postgrespro.ru", "phone": "+70086022123"}
0005432361327	457AC7	3858 185692	ALEKSANDR KAZAKOV	{"phone": "+70148170614"}
0005432361328	AE2ECE	8715 576004	VLADIMIR TIKHONOV	{"phone": "+70011096102"}
0005432361329	AE2ECE	0804 502150	KRISTINA FEDOROVA	{"email": "fedorova.kristina30031968@postgrespro.ru", "phone": "+70554767948"}
0005432361330	343DE3	5198 845249	ALEKSANDR SOROKIN	{"phone": "+70732734421"}
0005432361331	5A6976	0218 256830	VALENTINA KUZNECOVA	{"phone": "+70752329880"}
0005432361332	5A6976	9944 350969	NINA ZAYCEVA	{"phone": "+70322484640"}
0005432361333	0BF0DE	9757 933476	VIKTORIYA MAKAROVA	{"phone": "+70893587175"}
0005432361334	0BF0DE	3133 493678	ALEKSANDR GAVRILOV	{"phone": "+70143145385"}
0005432361335	0BF0DE	9240 729085	DINARA ARKHIPOVA	{"phone": "+70410416235"}
0005432361336	6BDA31	4221 746217	EVGENIY SHEVCHENKO	{"email": "eshevchenko_1963@postgrespro.ru", "phone": "+70605318217"}
0005432361337	B20ACE	0105 415300	TAMARA IVANOVA	{"phone": "+70353504214"}
0005432361338	06EB67	7840 926819	VASILIY GRIGOREV	{"phone": "+70789495130"}
0005432361339	4DC0F1	8867 728348	MARIYA IVANOVA	{"phone": "+70948134840"}
0005432361340	6685E7	7728 762404	GEORGIY KAZAKOV	{"email": "georgiy_kazakov-031968@postgrespro.ru", "phone": "+70990859438"}
0005432361341	BDCCCC	0830 793520	ANZHELA ANTONOVA	{"email": "antonovaanzhela.1969@postgrespro.ru", "phone": "+70793431254"}
0005432361342	BDCCCC	6650 071552	VALERIY POPOV	{"phone": "+70931522683"}
0005432361677	8A2224	7100 950657	ANATOLIY IVANOV	{"phone": "+70199892786"}
0005432361343	8752A3	8313 972350	NINA MIKHAYLOVA	{"email": "nina_mikhaylova_1973@postgrespro.ru", "phone": "+70529283057"}
0005432361344	9FEA48	4736 864280	GALINA CHERNOVA	{"phone": "+70016312933"}
0005432361345	825808	4118 758493	IVAN IVANOV	{"email": "ivanovivan_17061974@postgrespro.ru", "phone": "+70114274593"}
0005432361346	CA83D5	8198 220676	DARYA MOISEEVA	{"email": "moiseeva.darya.021979@postgrespro.ru", "phone": "+70655025394"}
0005432361347	CA83D5	4797 485817	KARINA RYABOVA	{"email": "karina.ryabova-121976@postgrespro.ru", "phone": "+70071636122"}
0005432361348	59CA2D	8064 777738	VLADIMIR KRASNOV	{"phone": "+70954251653"}
0005432361349	59CA2D	3156 522742	SVETLANA ROMANOVA	{"email": "s.romanova.1975@postgrespro.ru", "phone": "+70418906597"}
0005432361350	66AFF0	6762 788019	EVGENIY FROLOV	{"email": "e.frolov051975@postgrespro.ru", "phone": "+70049737465"}
0005432361351	66AFF0	0921 653662	MIKHAIL SERGEEV	{"email": "sergeevm-04101966@postgrespro.ru", "phone": "+70717589655"}
0005432361352	0BE580	5086 045706	ELENA KUZMINA	{"phone": "+70295587289"}
0005432361353	46139E	1954 259645	NATALYA NIKIFOROVA	{"email": "natalyanikiforova-051978@postgrespro.ru", "phone": "+70435306191"}
0005432361354	46139E	7925 527809	TATYANA MIRONOVA	{"phone": "+70967180462"}
0005432361355	45C0BA	8301 789845	ZHANNA GUSEVA	{"email": "guseva-zhanna1970@postgrespro.ru", "phone": "+70250933872"}
0005432361356	45C0BA	2415 277493	NINA OVCHINNIKOVA	{"phone": "+70197742347"}
0005432361357	45C0BA	8411 197526	ANNA VOLKOVA	{"phone": "+70713667236"}
0005432361358	979E64	0103 859230	MATVEY GAVRILOV	{"email": "m.gavrilov16101961@postgrespro.ru", "phone": "+70801533693"}
0005432361359	979E64	5785 262426	ANTONINA ABRAMOVA	{"email": "antonina.abramova-07111969@postgrespro.ru", "phone": "+70779520370"}
0005432361360	979E64	6442 890081	VLADIMIR SOKOLOV	{"phone": "+70875927701"}
0005432361361	979E64	3151 449753	VALENTINA ALEKSANDROVA	{"phone": "+70447368026"}
0005432361362	979E64	4636 232691	VITALIY CHERNOV	{"email": "vitaliy-chernov_1980@postgrespro.ru", "phone": "+70385785611"}
0005432361363	B1DD07	4400 557241	OLEG SOLOVEV	{"phone": "+70331946016"}
0005432361364	813D68	6781 551577	MAKAR BELOV	{"email": "makar-belov_1976@postgrespro.ru", "phone": "+70646631266"}
0005432361365	813D68	4657 735645	ALEKSANDR VLASOV	{"phone": "+70698466825"}
0005432361366	FBE75F	8925 200919	DMITRIY PETROV	{"email": "d.petrov23071975@postgrespro.ru", "phone": "+70743108996"}
0005432361367	FBE75F	0989 187964	YURIY GAVRILOV	{"email": "gavrilov-yuriy1975@postgrespro.ru", "phone": "+70721683548"}
0005432361368	212BAE	8452 243061	SERGEY IVANOV	{"email": "ivanov-s_1976@postgrespro.ru", "phone": "+70734043681"}
0005432361369	60B2DC	4138 040032	SERGEY AFANASEV	{"phone": "+70139451380"}
0005432361370	60B2DC	9247 977430	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikova_valentina.021964@postgrespro.ru", "phone": "+70015042911"}
0005432361371	433239	3543 726202	NINA PAVLOVA	{"email": "npavlova.13021977@postgrespro.ru", "phone": "+70750694759"}
0005432361372	BD730D	4884 022698	MARINA IVANOVA	{"phone": "+70093441842"}
0005432361373	A1D459	4680 120870	VIKTORIYA NAZAROVA	{"email": "v_nazarova14061977@postgrespro.ru", "phone": "+70853786055"}
0005432361374	A1D459	5038 392113	SVETLANA RODIONOVA	{"phone": "+70377869171"}
0005432361375	9B57B8	8645 929902	TATYANA YAKOVLEVA	{"email": "tyakovleva.1976@postgrespro.ru", "phone": "+70787032199"}
0005432361376	9B57B8	1072 858005	YAROSLAV VASILEV	{"phone": "+70399070686"}
0005432361377	28ABFC	1103 977888	OLGA NOVIKOVA	{"email": "novikova_olga1961@postgrespro.ru", "phone": "+70513465524"}
0005432361378	28ABFC	9251 167462	LARISA MOROZOVA	{"email": "l-morozova081969@postgrespro.ru", "phone": "+70383715481"}
0005432361379	B0DEA9	4461 374283	MAKSIM RODIONOV	{"email": "rodionov-m-091975@postgrespro.ru", "phone": "+70268615287"}
0005432361380	094F7B	3320 036315	NATALYA KUZNECOVA	{"email": "natalya_kuznecova-31121966@postgrespro.ru", "phone": "+70111569046"}
0005432361381	93FF7F	2804 488712	ALEKSANDR ANTONOV	{"phone": "+70042053541"}
0005432361382	D91C36	7864 429156	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey-14011977@postgrespro.ru", "phone": "+70060190410"}
0005432361383	D91C36	0391 036726	NATALIYA IVANOVA	{"phone": "+70094539765"}
0005432361384	1CB02E	8258 757400	VLADIMIR SERGEEV	{"email": "v.sergeev-031973@postgrespro.ru", "phone": "+70188582668"}
0005432361385	75E827	3417 757792	OLEG SOKOLOV	{"email": "sokolovoleg_1978@postgrespro.ru", "phone": "+70366173909"}
0005432361386	170B0E	4036 361461	VITALIY ALEKSEEV	{"phone": "+70534041457"}
0005432361387	20D387	3845 938234	IGOR MARTYNOV	{"email": "martynovi041971@postgrespro.ru", "phone": "+70328106245"}
0005432361388	455B92	3855 190658	DMITRIY VASILEV	{"phone": "+70781633109"}
0005432361389	CB254E	5630 114078	ALEKSANDR FILIPPOV	{"phone": "+70138942524"}
0005432361390	B40873	0851 638473	TATYANA KONOVALOVA	{"email": "tkonovalova071971@postgrespro.ru", "phone": "+70171088294"}
0005432361391	BBA3DF	5996 063123	DENIS CHERNOV	{"phone": "+70848132523"}
0005432361392	614929	9019 573309	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova-anastasiya-1973@postgrespro.ru", "phone": "+70474928454"}
0005432361393	11D9A3	7964 537695	GLEB NAZAROV	{"phone": "+70589606821"}
0005432361394	11D9A3	5376 780932	ELENA ILINA	{"phone": "+70419162334"}
0005432361395	6E2BB0	3832 439549	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey_1970@postgrespro.ru", "phone": "+70330544866"}
0005432361396	CA97A7	8986 158128	VALERIY SIDOROV	{"email": "sidorov-v081974@postgrespro.ru", "phone": "+70136484009"}
0005432361397	21F543	4456 817711	ANDREY DMITRIEV	{"email": "dmitrievandrey.1970@postgrespro.ru", "phone": "+70439214959"}
0005432361398	21F543	6264 369333	ANTON IVANOV	{"email": "a_ivanov-1970@postgrespro.ru", "phone": "+70472994161"}
0005432361399	5246E6	8816 130565	IDA KUZNECOVA	{"phone": "+70684375292"}
0005432361400	C496AD	7029 795284	VIKTOR ORLOV	{"phone": "+70837646619"}
0005432361401	286A90	3538 721966	LIDIYA FEDOROVA	{"phone": "+70684640987"}
0005432361402	589DE8	0685 811076	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a_1972@postgrespro.ru", "phone": "+70552818834"}
0005432361403	589DE8	3802 432025	ILYA BORISOV	{"email": "i-borisov_10021994@postgrespro.ru", "phone": "+70365471546"}
0005432361404	CC1157	6416 125806	VLADIMIR IVANOV	{"email": "v_ivanov.26011967@postgrespro.ru", "phone": "+70078844181"}
0005432361405	B42A6C	1843 169775	ALEKSEY KUZMIN	{"email": "alekseykuzmin.17021968@postgrespro.ru", "phone": "+70292354666"}
0005432361406	CDC6B0	4436 158911	NIKITA DENISOV	{"email": "n-denisov.1963@postgrespro.ru", "phone": "+70721383180"}
0005432361407	CDC6B0	4482 319077	VYACHESLAV STEPANOV	{"phone": "+70872885851"}
0005432361408	8F5D7A	5911 221900	LYUBOV GUSEVA	{"email": "l_guseva05111977@postgrespro.ru", "phone": "+70789545659"}
0005432361409	7E7CCC	2575 369437	LIDIYA KOZLOVA	{"phone": "+70663762736"}
0005432361410	7E7CCC	8808 380532	MAKSIM SERGEEV	{"phone": "+70937719855"}
0005432361411	762929	0524 616021	OLGA VOROBEVA	{"email": "vorobevaolga1968@postgrespro.ru", "phone": "+70775917467"}
0005432361412	2FBAF2	2919 927850	RAISA YUDINA	{"email": "r.yudina-1971@postgrespro.ru", "phone": "+70961110095"}
0005432361413	C6B202	4635 852385	NINA VASILEVA	{"email": "vasileva_n-101978@postgrespro.ru", "phone": "+70792405329"}
0005432361414	57117F	0162 641101	SVETLANA PETROVA	{"email": "s.petrova_031989@postgrespro.ru", "phone": "+70346550845"}
0005432361415	57117F	8045 581832	OLESYA MELNIKOVA	{"phone": "+70119117860"}
0005432361416	C1F12B	6422 308873	LILIYA KUZNECOVA	{"email": "l-kuznecova-01091962@postgrespro.ru", "phone": "+70005085491"}
0005432361417	A457D3	8668 281133	SERGEY SEMENOV	{"email": "semenovsergey-081983@postgrespro.ru", "phone": "+70035813055"}
0005432361418	EAEDE5	5281 748058	VALENTINA KONDRATEVA	{"phone": "+70107521383"}
0005432361419	B23CA1	9064 815811	ANDREY MAKAROV	{"email": "makarov.a.091976@postgrespro.ru", "phone": "+70010033435"}
0005432361420	FA8588	1054 677671	VLADIMIR KISELEV	{"email": "v-kiselev011980@postgrespro.ru", "phone": "+70511343522"}
0005432361421	FA8588	2472 835923	ALEKSEY YAKOVLEV	{"phone": "+70945930048"}
0005432361422	896B50	2288 993395	VITALIY BELOV	{"phone": "+70787603883"}
0005432361423	E90147	8769 265258	ARTEM AFANASEV	{"phone": "+70738777317"}
0005432361424	E90147	3719 664216	ILYA KOZLOV	{"email": "kozlov.i16041978@postgrespro.ru", "phone": "+70411489311"}
0005432361425	E90147	5879 552396	GUZEL SAVELEVA	{"email": "guzel_saveleva.26121983@postgrespro.ru", "phone": "+70329747098"}
0005432361426	0D6869	1043 014435	SERGEY DENISOV	{"email": "denisov_s.1964@postgrespro.ru", "phone": "+70022168941"}
0005432361427	0D6869	6564 317008	VALERIY RODIONOV	{"phone": "+70609659780"}
0005432361428	0D6869	2018 932865	NATALYA KOROLEVA	{"phone": "+70496481358"}
0005432361429	A94114	7613 048663	VASILIY POPOV	{"phone": "+70995855087"}
0005432361430	A94114	4271 667051	ILFAT BELOV	{"phone": "+70016131331"}
0005432361431	A94114	7537 846180	ANDREY ZAKHAROV	{"email": "a_zakharov.101967@postgrespro.ru", "phone": "+70167795430"}
0005432361432	8AC8B3	8313 125850	ILYA ZAKHAROV	{"email": "zakharov-ilya_24051965@postgrespro.ru", "phone": "+70660977847"}
0005432361433	2ADAD4	9527 314651	RAMIL MATVEEV	{"email": "matveev_ramil-08121965@postgrespro.ru", "phone": "+70562171057"}
0005432361434	71B4F6	5067 082871	GRIGORIY TARASOV	{"email": "grigoriy-tarasov-24081970@postgrespro.ru", "phone": "+70979144424"}
0005432361435	71B4F6	0869 715692	EKATERINA VOLKOVA	{"phone": "+70654550626"}
0005432361436	547D87	1680 793771	TATYANA ILINA	{"email": "tatyanailina_1958@postgrespro.ru", "phone": "+70912492818"}
0005432361437	CE49E0	7982 531397	OLEG MIKHAYLOV	{"phone": "+70096683697"}
0005432361438	4D9971	2168 463429	NIKOLAY POPOV	{"phone": "+70238500860"}
0005432361439	05F6A4	9425 671501	OLGA NESTEROVA	{"phone": "+70423857335"}
0005432361440	FBC893	2849 942107	VIKTOR FEDOROV	{"phone": "+70145991558"}
0005432361441	8E0F15	0202 430660	DIANA BOGDANOVA	{"phone": "+70213131269"}
0005432361442	FBE99F	3218 273928	TATYANA KUZNECOVA	{"phone": "+70333802790"}
0005432361443	FBE99F	4061 300318	ALEKSANDR BELOV	{"email": "aleksandrbelov.18051973@postgrespro.ru", "phone": "+70162304844"}
0005432361444	3F17E9	9280 294646	OLGA IVANOVA	{"email": "ivanova-olga_091964@postgrespro.ru", "phone": "+70350141429"}
0005432361445	6A069C	8652 570226	DENIS FROLOV	{"email": "denis_frolov.021983@postgrespro.ru", "phone": "+70164273969"}
0005432361446	C8F0A5	2703 587759	IVAN KONOVALOV	{"email": "konovalov-ivan.23111966@postgrespro.ru", "phone": "+70657886496"}
0005432361447	6A70F8	6073 445296	VLADIMIR MATVEEV	{"email": "matveev-v_1972@postgrespro.ru", "phone": "+70589436833"}
0005432361448	6A70F8	0671 240825	VASILIY GUSEV	{"email": "gusev.v_021972@postgrespro.ru", "phone": "+70979278920"}
0005432361449	5B8D71	6531 801752	GALINA KUZMINA	{"phone": "+70191934513"}
0005432361450	95F0C7	6627 664828	VLADISLAV PAVLOV	{"phone": "+70957509713"}
0005432361451	0E35FB	0091 824873	YURIY KOROLEV	{"email": "y.korolev-1972@postgrespro.ru", "phone": "+70738744668"}
0005432361452	20CF2B	6386 786573	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov1980@postgrespro.ru", "phone": "+70976233148"}
0005432361453	CB3F2A	6929 567144	VALENTINA NIKOLAEVA	{"phone": "+70554829858"}
0005432361454	CB3F2A	4561 016115	YULIYA TIMOFEEVA	{"email": "timofeevay121972@postgrespro.ru", "phone": "+70187404996"}
0005432361455	758441	7175 013912	ZINAIDA KOROLEVA	{"email": "zinaida.koroleva_1981@postgrespro.ru", "phone": "+70610382681"}
0005432361456	167577	5962 255946	ALEKSEY VASILEV	{"phone": "+70799071046"}
0005432361457	6633BD	6970 910729	NIKOLAY NIKOLAEV	{"email": "nikolaev-n.071972@postgrespro.ru", "phone": "+70686021745"}
0005432361458	6633BD	1701 861599	DENIS NAZAROV	{"email": "nazarovdenis.09041973@postgrespro.ru", "phone": "+70008955952"}
0005432361459	764EFD	5092 827696	ELENA SOKOLOVA	{"email": "sokolova.e_061972@postgrespro.ru", "phone": "+70065732657"}
0005432361460	A7117E	8317 704018	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaaleksandra-071964@postgrespro.ru", "phone": "+70532681150"}
0005432361461	A7117E	0598 801537	SERGEY SOKOLOV	{"email": "sokolov-sergey_021979@postgrespro.ru", "phone": "+70298903406"}
0005432361462	AE7F8E	3515 864270	IRINA FADEEVA	{"phone": "+70031999921"}
0005432361463	17FAAD	4802 160792	ARTUR MAKAROV	{"phone": "+70464388314"}
0005432361464	17FAAD	8191 501691	ELENA KUZMINA	{"email": "e_kuzmina_061979@postgrespro.ru", "phone": "+70092267800"}
0005432361465	796029	6253 756066	LYUDMILA SIDOROVA	{"phone": "+70882582094"}
0005432361466	8A0093	2299 593723	OLEG GERASIMOV	{"email": "o.gerasimov-101970@postgrespro.ru", "phone": "+70334904288"}
0005432361467	8A0093	2073 910080	SERGEY VLASOV	{"email": "sergey_vlasov.031969@postgrespro.ru", "phone": "+70415341804"}
0005432361468	BB88B9	2761 221892	ALEKSANDR KOZLOV	{"phone": "+70993156706"}
0005432361469	BB88B9	3467 565026	ARTEM KUZNECOV	{"email": "akuznecov.1969@postgrespro.ru", "phone": "+70786327266"}
0005432361470	46E009	2929 027813	VIKTOR VASILEV	{"phone": "+70235951466"}
0005432361471	46E009	4122 390888	MAKSIM VOROBEV	{"phone": "+70799976166"}
0005432361472	46E009	7166 396892	ALEKSEY ANDREEV	{"email": "andreev.aleksey.1978@postgrespro.ru", "phone": "+70361761858"}
0005432361713	69D05B	6371 189023	ELENA SIDOROVA	{"phone": "+70438121833"}
0005432361473	F77B68	5801 095015	MIKHAIL SERGEEV	{"email": "sergeev-mikhail.22081972@postgrespro.ru", "phone": "+70205232626"}
0005432361474	F77B68	4584 907138	TATYANA MEDVEDEVA	{"email": "medvedevat-1979@postgrespro.ru", "phone": "+70193410993"}
0005432361475	28601C	7526 480700	TATYANA KARPOVA	{"phone": "+70901584784"}
0005432361476	28601C	1212 882061	EKATERINA BELOVA	{"phone": "+70426158980"}
0005432361477	AAE193	4937 945525	SERGEY IVANOV	{"phone": "+70671825814"}
0005432361478	7D2972	3697 582297	NIKOLAY KISELEV	{"phone": "+70825419881"}
0005432361479	1BD766	3350 982979	NATALYA KUZMINA	{"email": "kuzmina_natalya-1969@postgrespro.ru", "phone": "+70861965397"}
0005432361480	1FC9E4	5673 949386	OKSANA POPOVA	{"phone": "+70738468663"}
0005432361481	EB2AD7	7110 190958	ALINA KUZNECOVA	{"email": "a-kuznecova_1969@postgrespro.ru", "phone": "+70474572280"}
0005432361482	EB2AD7	8928 323865	TATYANA ZHUKOVA	{"phone": "+70843677249"}
0005432361483	69188D	3305 396521	YULIYA KOMAROVA	{"email": "komarova.y-1977@postgrespro.ru", "phone": "+70134955650"}
0005432361484	69188D	0150 352851	ALEKSEY PETROV	{"phone": "+70033940529"}
0005432361485	69188D	5849 773963	VLADISLAV ZAYCEV	{"email": "v-zaycev_06071960@postgrespro.ru", "phone": "+70319949588"}
0005432361486	D0167C	0751 821005	MARIYA NESTEROVA	{"email": "m.nesterova-1972@postgrespro.ru", "phone": "+70239929581"}
0005432361487	AA8402	4222 519524	LILIYA GORBUNOVA	{"phone": "+70934348572"}
0005432361488	CA7805	2422 605100	IRINA LOGINOVA	{"email": "i_loginova-20061981@postgrespro.ru", "phone": "+70421844601"}
0005432361489	9CC8A7	6729 145748	ANDREY YAKOVLEV	{"email": "yakovlev-a_041966@postgrespro.ru", "phone": "+70739814161"}
0005432361490	9CC8A7	9013 964099	VALENTINA ORLOVA	{"email": "orlova.valentina-30071968@postgrespro.ru", "phone": "+70190003771"}
0005432361491	648186	8053 838732	VLADIMIR BORISOV	{"phone": "+70734760448"}
0005432361492	C6322C	9917 430624	EKATERINA FILATOVA	{"phone": "+70422012470"}
0005432361493	C6322C	3354 511824	ANATOLIY KUZNECOV	{"phone": "+70313133669"}
0005432361494	0977F0	8396 550036	ELENA TROFIMOVA	{"email": "elena.trofimova-1975@postgrespro.ru", "phone": "+70977259013"}
0005432361495	B5E8AA	8100 710308	DENIS FEDOROV	{"phone": "+70122176454"}
0005432361496	5980E9	8037 109389	FEDOR ALEKSEEV	{"phone": "+70613380743"}
0005432361497	5980E9	2819 693336	NIKOLAY FROLOV	{"email": "frolov.n.021964@postgrespro.ru", "phone": "+70598611006"}
0005432361498	41C085	7211 988024	TATYANA ROMANOVA	{"email": "romanova_tatyana-1977@postgrespro.ru", "phone": "+70077071220"}
0005432361499	41C085	3729 707390	VALERIY SIDOROV	{"phone": "+70429616181"}
0005432361500	FAA26E	9068 363635	VALENTIN KUZNECOV	{"phone": "+70892651080"}
0005432361501	1C1D29	0223 844250	IGOR YAKOVLEV	{"phone": "+70725820193"}
0005432361502	1C1D29	5522 397113	VIKTOR MIKHAYLOV	{"email": "mikhaylov.v_20101975@postgrespro.ru", "phone": "+70029490801"}
0005432361503	8C358D	5485 515233	LYUDMILA POTAPOVA	{"phone": "+70571502218"}
0005432361504	C4B25A	3066 212303	TATYANA EFIMOVA	{"phone": "+70697249472"}
0005432361505	77FB54	6056 573437	NINA FEDOROVA	{"phone": "+70856567823"}
0005432361506	6DB0A5	9136 923572	GALIYA ANDREEVA	{"email": "galiyaandreeva-061965@postgrespro.ru", "phone": "+70376117635"}
0005432361507	6DB0A5	5906 059528	VLADIMIR KAZAKOV	{"email": "kazakov-v-21121969@postgrespro.ru", "phone": "+70866495468"}
0005432361508	F608F1	1633 379159	EVGENIY NOVIKOV	{"email": "e.novikov_07061977@postgrespro.ru", "phone": "+70469027000"}
0005432361509	EEF00E	5019 294520	ANTONINA PAVLOVA	{"phone": "+70700843557"}
0005432361510	EEF00E	8659 246822	LYUBOV SAVELEVA	{"email": "saveleva.l1964@postgrespro.ru", "phone": "+70546236082"}
0005432361511	AE8264	6260 414920	DMITRIY ZAYCEV	{"phone": "+70062105948"}
0005432361512	AE8264	9320 718932	ALEKSANDR ANTONOV	{"phone": "+70665815735"}
0005432361513	FEEF8F	2228 767451	KONSTANTIN SIDOROV	{"email": "konstantin.sidorov_1966@postgrespro.ru", "phone": "+70715642841"}
0005432361514	FEEF8F	7706 410193	ZINAIDA SERGEEVA	{"phone": "+70896468430"}
0005432361515	536C69	0541 709612	VALERIYA KOZLOVA	{"email": "v.kozlova-1981@postgrespro.ru", "phone": "+70143967950"}
0005432361516	536C69	5104 546854	VASILIY GUSEV	{"email": "vasiliy.gusev04051965@postgrespro.ru", "phone": "+70088118564"}
0005432361517	C74981	3203 173375	SVETLANA ALEKSEEVA	{"phone": "+70627659252"}
0005432361518	C74981	8036 493082	ELENA BELOVA	{"phone": "+70217721660"}
0005432361519	0850E7	0988 695616	MARIYA KOLESNIKOVA	{"email": "mariya-kolesnikova_26121970@postgrespro.ru", "phone": "+70842228308"}
0005432361520	0850E7	5333 543081	OLGA SCHERBAKOVA	{"email": "o-scherbakova.1972@postgrespro.ru", "phone": "+70426149487"}
0005432361521	9B0B4F	3053 524013	MARIYA FADEEVA	{"email": "m.fadeeva.04011969@postgrespro.ru", "phone": "+70424325734"}
0005432361522	2DA4D0	7607 053213	ZINAIDA NAUMOVA	{"phone": "+70515937018"}
0005432361523	D11F06	4787 414581	DMITRIY IVANOV	{"email": "ivanov-d03021958@postgrespro.ru", "phone": "+70158111293"}
0005432361524	D11F06	6464 560126	SVETLANA KISELEVA	{"email": "kiselevas-1966@postgrespro.ru", "phone": "+70297776095"}
0005432361525	70E2BE	1459 702305	OKSANA FROLOVA	{"phone": "+70307246074"}
0005432361526	7C3B1D	7455 972710	NATALYA ILINA	{"email": "ilina-natalya.111977@postgrespro.ru", "phone": "+70191737538"}
0005432361527	7C3B1D	0186 442810	EVA VOLKOVA	{"email": "eva_volkova.081976@postgrespro.ru", "phone": "+70715214558"}
0005432361528	1CC5C7	1568 122561	EVGENIY IVANOV	{"email": "evgeniyivanov-11031965@postgrespro.ru", "phone": "+70377474004"}
0005432361529	1CC5C7	3871 130523	DANIIL KUZNECOV	{"email": "daniil-kuznecov-30091973@postgrespro.ru", "phone": "+70301242027"}
0005432361530	6B6669	1951 402189	FARIT AFANASEV	{"phone": "+70977394885"}
0005432361531	1CCA60	6543 653417	ANNA SIDOROVA	{"phone": "+70703229007"}
0005432361532	62772D	5670 136453	NIKOLAY MARTYNOV	{"phone": "+70415426514"}
0005432361714	69D05B	9169 709010	MARIYA NESTEROVA	{"phone": "+70415008443"}
0005432361533	183B01	1672 095344	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr.061960@postgrespro.ru", "phone": "+70908667358"}
0005432361534	0954A2	4248 128256	ALEKSEY TARASOV	{"email": "aleksey_tarasov-041965@postgrespro.ru", "phone": "+70374667257"}
0005432361535	0954A2	8093 685022	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana1968@postgrespro.ru", "phone": "+70518584521"}
0005432361536	E0D299	4948 864818	LYUBOV KISELEVA	{"email": "lyubovkiseleva18081972@postgrespro.ru", "phone": "+70757926682"}
0005432361537	E0D299	1228 244760	GALINA LOGINOVA	{"phone": "+70015669853"}
0005432361538	EE426A	8486 017380	PAVEL CHERNOV	{"phone": "+70655686321"}
0005432361539	EE426A	2733 502192	ELENA SIDOROVA	{"phone": "+70701180162"}
0005432361540	676939	4371 812965	IVAN MAKAROV	{"email": "ivanmakarov_1974@postgrespro.ru", "phone": "+70694275735"}
0005432361541	676939	6728 857243	EKATERINA GRISHINA	{"email": "e_grishina-1973@postgrespro.ru", "phone": "+70671404269"}
0005432361542	4F8E38	6930 096319	ILYA PETROV	{"phone": "+70426293214"}
0005432361543	BD6E40	4156 263568	ALEKSANDR POPOV	{"phone": "+70103256543"}
0005432361544	BD6E40	8048 440121	NIKOLAY CHERNOV	{"email": "n.chernov.1963@postgrespro.ru", "phone": "+70252423042"}
0005432361545	154B81	3572 419888	KSENIYA KUZNECOVA	{"phone": "+70155057183"}
0005432361546	A5DB1D	1770 258160	EKATERINA YAKOVLEVA	{"phone": "+70771911789"}
0005432361547	A5DB1D	6866 214960	NIKOLAY SCHERBAKOV	{"email": "nikolayscherbakov.071970@postgrespro.ru", "phone": "+70203207242"}
0005432361548	A9FC44	8024 283700	GALINA GAVRILOVA	{"phone": "+70769670673"}
0005432361549	A9FC44	8104 733035	ANNA FILATOVA	{"phone": "+70518587527"}
0005432361550	0D4FDD	8601 493304	NADEZHDA SMIRNOVA	{"email": "nadezhda_smirnova061980@postgrespro.ru", "phone": "+70084144013"}
0005432361551	90E7AC	2432 357721	OLEG MATVEEV	{"email": "matveev_oleg_081980@postgrespro.ru", "phone": "+70042148718"}
0005432361552	90E7AC	6069 376391	ANDREY SAVELEV	{"email": "savelev-andrey_29051963@postgrespro.ru", "phone": "+70516830872"}
0005432361553	8B5512	4456 884160	VIKTORIYA ZHURAVLEVA	{"phone": "+70642472477"}
0005432361554	B00EC7	1968 851891	NATALYA KRASNOVA	{"phone": "+70083603361"}
0005432361555	941258	5903 800003	ALEKSANDR NIKOLAEV	{"phone": "+70814276349"}
0005432361556	D0DB19	8527 021646	MARINA SOKOLOVA	{"phone": "+70579750979"}
0005432361557	D0DB19	3906 735931	TATYANA KALININA	{"phone": "+70530280477"}
0005432361558	701E7A	5493 582978	TATYANA FILATOVA	{"phone": "+70997945764"}
0005432361559	4A5EBF	9416 624274	DMITRIY POPOV	{"phone": "+70764522980"}
0005432361560	4A5EBF	9273 135094	ELENA ZAYCEVA	{"email": "e.zayceva-1975@postgrespro.ru", "phone": "+70007564154"}
0005432361561	4A5EBF	0103 215029	ALEKSANDR KARPOV	{"email": "karpov.aleksandr1968@postgrespro.ru", "phone": "+70593438068"}
0005432361562	4A5EBF	7831 625248	VALENTINA VASILEVA	{"email": "v.vasileva-1983@postgrespro.ru", "phone": "+70367395920"}
0005432361563	4A5EBF	3113 464060	KSENIYA IVANOVA	{"email": "ivanova.k.20101973@postgrespro.ru", "phone": "+70457690431"}
0005432361564	296628	1207 605264	ANATOLIY TARASOV	{"phone": "+70827592472"}
0005432361565	5ABCBE	9518 437017	VLADISLAV PETROV	{"email": "petrov-vladislav-041973@postgrespro.ru", "phone": "+70055267228"}
0005432361566	5ABCBE	1094 939178	ANATOLIY BELOV	{"email": "a-belov.14071976@postgrespro.ru", "phone": "+70995493872"}
0005432361567	5ABCBE	1696 285761	ELENA MIKHAYLOVA	{"phone": "+70339518426"}
0005432361568	722AAD	2318 625356	LYUBOV KRASNOVA	{"email": "l_krasnova_06051965@postgrespro.ru", "phone": "+70638068872"}
0005432361569	722AAD	3753 142147	YULIYA PETROVA	{"email": "yuliyapetrova_1971@postgrespro.ru", "phone": "+70684717563"}
0005432361570	722AAD	2183 634811	ALEKSANDR ANTONOV	{"phone": "+70406261913"}
0005432361571	067845	4298 741820	ANTON VLASOV	{"phone": "+70428538575"}
0005432361572	56F10E	0440 408378	ALEKSEY SERGEEV	{"phone": "+70087300206"}
0005432361573	56F10E	0278 140635	VALENTINA ALEKSEEVA	{"phone": "+70819901914"}
0005432361574	FA29A8	0414 450654	ANZHELIKA BORISOVA	{"email": "borisova_a-081971@postgrespro.ru", "phone": "+70022888031"}
0005432361575	FA29A8	6277 457537	VLADIMIR PAVLOV	{"phone": "+70463847616"}
0005432361576	B60D36	6240 941731	GLEB NIKITIN	{"phone": "+70657487196"}
0005432361577	B60D36	0243 143106	SNEZHANA TIMOFEEVA	{"email": "snezhana-timofeeva101978@postgrespro.ru", "phone": "+70524276341"}
0005432361578	B60D36	9225 712031	VALERIY PETROV	{"phone": "+70119868897"}
0005432361579	B60D36	5041 556766	MIKHAIL ANTONOV	{"phone": "+70520047503"}
0005432361580	41EB0D	0985 852144	SVETLANA KARPOVA	{"email": "svetlana.karpova16121979@postgrespro.ru", "phone": "+70263500740"}
0005432361581	41EB0D	3953 409976	VALENTINA MASLOVA	{"email": "maslova-valentina05071973@postgrespro.ru", "phone": "+70824162796"}
0005432361582	3061B5	0048 901166	VALERIY BORISOV	{"phone": "+70806409201"}
0005432361583	8298EA	9204 704040	NATALYA CHERNOVA	{"phone": "+70516035744"}
0005432361584	8298EA	4916 370234	NIKOLAY MATVEEV	{"email": "nikolay_matveev-09011956@postgrespro.ru", "phone": "+70875250577"}
0005432361585	8298EA	7406 562028	ALEKSANDR IVANOV	{"email": "a-ivanov.081979@postgrespro.ru", "phone": "+70982589605"}
0005432361586	016BF8	6252 510086	ALEKSANDR RODIONOV	{"phone": "+70018313031"}
0005432361587	6DD221	9107 097189	VASILIY ISAEV	{"email": "v.isaev10021966@postgrespro.ru", "phone": "+70535316227"}
0005432361588	5FEA71	1307 407638	VLADIMIR SOROKIN	{"phone": "+70895800006"}
0005432361589	028FB3	6792 372021	ARTUR MELNIKOV	{"email": "a.melnikov_1974@postgrespro.ru", "phone": "+70823973770"}
0005432361590	D2360E	3682 504959	PAVEL IVANOV	{"phone": "+70620874778"}
0005432361591	E9F3E7	2692 658549	ILYA GERASIMOV	{"phone": "+70181269263"}
0005432361592	6F30F8	9473 236152	MARINA MARTYNOVA	{"email": "marina-martynova081978@postgrespro.ru", "phone": "+70235383075"}
0005432361593	6F30F8	8756 371167	LYUBOV NIKITINA	{"phone": "+70171636995"}
0005432361594	62ED59	4845 747690	GALINA BELOVA	{"email": "belova.galina091961@postgrespro.ru", "phone": "+70511819562"}
0005432361595	055B4D	0051 482251	DENIS ZAKHAROV	{"email": "deniszakharov21091979@postgrespro.ru", "phone": "+70319313499"}
0005432361596	055B4D	1493 219682	NAILYA IVANOVA	{"email": "ivanova.n13111961@postgrespro.ru", "phone": "+70735560427"}
0005432361597	93D7B2	1197 543406	SERGEY FOMIN	{"email": "fomins-031973@postgrespro.ru", "phone": "+70531691330"}
0005432361598	05F445	1016 377020	ANNA DENISOVA	{"email": "anna_denisova.1969@postgrespro.ru", "phone": "+70222682992"}
0005432361599	AD4CB0	1822 940827	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr.121960@postgrespro.ru", "phone": "+70824368358"}
0005432361600	29E307	1576 455773	NINA SMIRNOVA	{"phone": "+70709455303"}
0005432361601	7D483A	6071 629318	MARIYA KOZLOVA	{"email": "mariya_kozlova041981@postgrespro.ru", "phone": "+70196103683"}
0005432361602	99E28B	7752 767274	MARIYA FILATOVA	{"phone": "+70447925636"}
0005432361603	1799B1	0779 589702	SVETLANA POPOVA	{"email": "svetlana-popova.1974@postgrespro.ru", "phone": "+70291197739"}
0005432361604	1799B1	4544 876697	VALENTINA KRASNOVA	{"phone": "+70536935550"}
0005432361605	B89445	5555 535188	LYUBOV FADEEVA	{"email": "l-fadeeva-13091989@postgrespro.ru", "phone": "+70338816606"}
0005432361606	DF1409	9125 635481	VALENTINA MAKAROVA	{"phone": "+70618509243"}
0005432361607	D474A7	3623 677117	NATALYA LOGINOVA	{"phone": "+70583808319"}
0005432361608	5D440C	3828 870030	RAMAZAN NOVIKOV	{"phone": "+70184847411"}
0005432361609	5D440C	2564 452681	LYUBOV NOVIKOVA	{"email": "novikova-lyubov041984@postgrespro.ru", "phone": "+70852706706"}
0005432361610	C1149F	2815 576814	ANNA ISAEVA	{"email": "aisaeva-1966@postgrespro.ru", "phone": "+70021524886"}
0005432361611	C1149F	9025 647133	YURIY FROLOV	{"phone": "+70393394866"}
0005432361612	350A15	3626 875149	ALEKSANDR ALEKSEEV	{"email": "alekseev-a091962@postgrespro.ru", "phone": "+70867414328"}
0005432361613	430FDC	7700 969702	TATYANA ANTONOVA	{"phone": "+70194512430"}
0005432361614	7922DD	0772 602630	VERA EFREMOVA	{"email": "efremova-v111980@postgrespro.ru", "phone": "+70068251156"}
0005432361615	7922DD	2224 158286	ANTONINA BELOVA	{"phone": "+70729798534"}
0005432361616	23F5CC	1951 695881	MARINA MAKAROVA	{"email": "m-makarova-011978@postgrespro.ru", "phone": "+70686128747"}
0005432361617	23F5CC	0629 271595	TATYANA FOMINA	{"phone": "+70295096196"}
0005432361618	29298A	9639 830257	MARIYA NOVIKOVA	{"phone": "+70939073636"}
0005432361619	29298A	8315 449928	DARYA YUDINA	{"email": "daryayudina_041969@postgrespro.ru", "phone": "+70065391556"}
0005432361620	B27EF9	9887 476967	NATALYA ANDREEVA	{"email": "n.andreeva.011981@postgrespro.ru", "phone": "+70020132802"}
0005432361621	F883DE	9512 149317	YULIYA TIKHONOVA	{"phone": "+70314520210"}
0005432361622	001740	9703 790346	DMITRIY CHERNOV	{"email": "d-chernov1967@postgrespro.ru", "phone": "+70493590890"}
0005432361623	001740	0733 229019	DENIS POPOV	{"email": "popov_denis.1983@postgrespro.ru", "phone": "+70953530333"}
0005432361624	4A6F05	6683 416723	SERGEY KRASNOV	{"phone": "+70443026797"}
0005432361625	454DA0	2078 098770	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr-1967@postgrespro.ru", "phone": "+70863511887"}
0005432361626	F0CCA6	7868 174925	EVGENIYA POLYAKOVA	{"phone": "+70754873865"}
0005432361627	F0CCA6	4214 605741	MARIYA MOISEEVA	{"phone": "+70693310064"}
0005432361628	99D2E7	2198 055942	VLADIMIR ROMANOV	{"email": "romanov_v_041985@postgrespro.ru", "phone": "+70774571192"}
0005432361629	A6A732	1339 176722	VERA SEMENOVA	{"email": "v-semenova.16081971@postgrespro.ru", "phone": "+70689081181"}
0005432361630	A6A732	5372 744862	SERGEY ALEKSANDROV	{"phone": "+70526106599"}
0005432361631	E607B9	8111 826349	ANNA NESTEROVA	{"phone": "+70710358812"}
0005432361632	C0E348	5594 573246	VALENTINA ROMANOVA	{"email": "romanova_valentina.041975@postgrespro.ru", "phone": "+70740903382"}
0005432361633	C0E348	4296 741379	OLGA PETROVA	{"email": "o.petrova.041985@postgrespro.ru", "phone": "+70569485217"}
0005432361634	454A36	3663 862481	ALEKSEY EGOROV	{"phone": "+70012573152"}
0005432361635	F7E1F6	0608 043483	IRINA ISAEVA	{"email": "isaevairina091979@postgrespro.ru", "phone": "+70788493247"}
0005432361636	F7E1F6	5145 510242	ARTUR PAVLOV	{"email": "artur-pavlov.1976@postgrespro.ru", "phone": "+70719905575"}
0005432361637	3E8494	1248 148526	RAISA VOLKOVA	{"email": "raisavolkova1971@postgrespro.ru", "phone": "+70836005855"}
0005432361638	6C0AB8	9508 124381	LYUBOV FADEEVA	{"phone": "+70062373997"}
0005432361639	7EF83A	7684 536296	MAKAR MIKHAYLOV	{"phone": "+70342477232"}
0005432361640	004C21	4766 648440	IRINA YAKOVLEVA	{"email": "yakovlevai10011977@postgrespro.ru", "phone": "+70516956305"}
0005432361641	1FA9DD	1898 164072	ELENA FROLOVA	{"email": "e.frolova-1976@postgrespro.ru", "phone": "+70307543793"}
0005432361642	BDB18A	4677 414538	ANNA VOLKOVA	{"email": "anna.volkova.1977@postgrespro.ru", "phone": "+70930318048"}
0005432361643	CF3426	7507 717893	KIRILL IVANOV	{"email": "k.ivanov.1987@postgrespro.ru", "phone": "+70524453891"}
0005432361644	CF3426	5550 397277	MARIYA NAZAROVA	{"email": "nazarova-m05101982@postgrespro.ru", "phone": "+70925244318"}
0005432361645	F66D10	8584 644622	SERGEY SHEVCHENKO	{"email": "shevchenkosergey_30061965@postgrespro.ru", "phone": "+70036169380"}
0005432361646	EA132F	9027 983441	NIKITA SOROKIN	{"phone": "+70047621395"}
0005432361647	526AAF	0749 149217	OLGA MOISEEVA	{"phone": "+70004552907"}
0005432361648	6ED6D8	7878 833821	OLGA KISELEVA	{"phone": "+70905074376"}
0005432361649	EA1F2A	3817 157955	OLGA KULIKOVA	{"email": "olga-kulikova31081971@postgrespro.ru", "phone": "+70167721220"}
0005432361650	EA1F2A	5310 516252	ALEKSANDR ZAYCEV	{"phone": "+70386434567"}
0005432361651	258988	6042 570604	ALEKSEY GAVRILOV	{"email": "gavrilov-aleksey-19011979@postgrespro.ru", "phone": "+70170520427"}
0005432361652	258988	5179 616802	ALEKSANDR SERGEEV	{"phone": "+70097851619"}
0005432361715	69D05B	4798 562944	ALEKSANDR ROMANOV	{"phone": "+70681324043"}
0005432361653	A76F90	7363 349646	DMITRIY MOISEEV	{"email": "dmoiseev.011976@postgrespro.ru", "phone": "+70096158411"}
0005432361654	2E9815	1153 414031	TATYANA GORBUNOVA	{"phone": "+70694378769"}
0005432361655	2E9815	2721 966407	RAISA FILATOVA	{"phone": "+70283611646"}
0005432361656	2E9815	5549 325786	ANASTASIYA ZAKHAROVA	{"phone": "+70367586435"}
0005432361657	472D58	1808 283020	ALEKSANDRA ANTONOVA	{"email": "antonova_a05081981@postgrespro.ru", "phone": "+70775975025"}
0005432361658	472D58	7497 901488	GERMAN TIKHONOV	{"email": "german-tikhonov1980@postgrespro.ru", "phone": "+70054460779"}
0005432361659	A67C47	0468 478388	VLADISLAV NAZAROV	{"email": "nazarov_v-091966@postgrespro.ru", "phone": "+70299449349"}
0005432361660	71CDA0	2026 438138	LIDIYA SMIRNOVA	{"phone": "+70683706738"}
0005432361661	14D34D	2392 081208	YURIY KUZNECOV	{"email": "y.kuznecov-22021966@postgrespro.ru", "phone": "+70139368312"}
0005432361662	D6D6D9	1911 642548	ANDREY IVANOV	{"email": "andreyivanov.18071967@postgrespro.ru", "phone": "+70209440072"}
0005432361663	D6D6D9	5526 300433	SERAFIMA OSIPOVA	{"email": "s.osipova111967@postgrespro.ru", "phone": "+70312690074"}
0005432361664	CDC19C	1036 798711	VLADIMIR BELOV	{"email": "belovv101965@postgrespro.ru", "phone": "+70589635588"}
0005432361665	CDC19C	5823 116927	MAKSIM GUSEV	{"email": "gusev-maksim_071980@postgrespro.ru", "phone": "+70139001030"}
0005432361666	5F3C16	6999 242282	VASILIY ANDREEV	{"email": "vasiliy_andreev.021974@postgrespro.ru", "phone": "+70138543288"}
0005432361667	5F3C16	5373 349430	SOFYA FEDOROVA	{"email": "fedorova.s-1964@postgrespro.ru", "phone": "+70762195995"}
0005432361668	15435C	6266 558339	VALERIYA VOLKOVA	{"phone": "+70852537648"}
0005432361669	21394C	1345 436479	IRINA ZAKHAROVA	{"phone": "+70959042519"}
0005432361670	21394C	4757 688521	EVGENIY NIKITIN	{"email": "nikitin-evgeniy.22111972@postgrespro.ru", "phone": "+70535664108"}
0005432361671	A47AE3	2511 235502	NIKOLAY MAKSIMOV	{"phone": "+70335029372"}
0005432361672	EC0A4B	9919 326903	ELENA MAKSIMOVA	{"email": "maksimovae-071974@postgrespro.ru", "phone": "+70714443289"}
0005432361673	9743BF	9232 557926	KONSTANTIN SCHERBAKOV	{"email": "scherbakov.konstantin-1978@postgrespro.ru", "phone": "+70903698545"}
0005432361674	CDA195	6230 472738	NATALYA ORLOVA	{"phone": "+70497878877"}
0005432361675	CDA195	7529 644289	NIKITA NIKITIN	{"email": "nikitinnikita.1973@postgrespro.ru", "phone": "+70587322716"}
0005432361676	8A2224	4280 480713	VIKTORIYA PAVLOVA	{"email": "pavlova-viktoriya-1966@postgrespro.ru", "phone": "+70425607018"}
0005432361678	8A2224	9061 257081	ANNA KARPOVA	{"email": "karpova.anna_041976@postgrespro.ru", "phone": "+70996205501"}
0005432361679	C2CA2C	0290 182180	ELENA SCHERBAKOVA	{"email": "scherbakova.elena-1967@postgrespro.ru", "phone": "+70593802198"}
0005432361680	8591C9	8524 048282	DMITRIY MIKHAYLOV	{"phone": "+70225345433"}
0005432361681	B1DA96	0708 640172	SVETLANA NESTEROVA	{"email": "nesterova_svetlana.091957@postgrespro.ru", "phone": "+70388454935"}
0005432361682	769A93	0052 054933	MARINA KULIKOVA	{"phone": "+70457368008"}
0005432361683	724367	7604 666209	MIKHAIL ILIN	{"phone": "+70199898711"}
0005432361684	6810B2	3597 599936	ROSTISLAV KUZMIN	{"email": "rostislavkuzmin_07061977@postgrespro.ru", "phone": "+70974637115"}
0005432361685	AA9193	1542 537855	LEV MOROZOV	{"email": "morozov-l-1967@postgrespro.ru", "phone": "+70219366583"}
0005432361686	692815	9300 552926	SVETLANA MAKAROVA	{"phone": "+70954108595"}
0005432361687	A6AD72	1966 001764	OKSANA GRISHINA	{"phone": "+70301799473"}
0005432361688	3739E0	1360 470201	DENIS MAKSIMOV	{"email": "maksimov-d-021978@postgrespro.ru", "phone": "+70230542935"}
0005432361689	1843A4	8517 154933	DENIS MIRONOV	{"phone": "+70956157522"}
0005432361690	751C8F	6021 913412	NADEZHDA FOMINA	{"phone": "+70613629701"}
0005432361691	751C8F	4189 225901	LYUDMILA MELNIKOVA	{"phone": "+70789875234"}
0005432361692	6BF899	1863 045111	ANDREY TIMOFEEV	{"phone": "+70184453370"}
0005432361693	81DA9D	8768 608488	BORIS SIDOROV	{"phone": "+70007123468"}
0005432361694	81DA9D	8071 653118	EVGENIY PAVLOV	{"email": "pavlov-e_081972@postgrespro.ru", "phone": "+70233192793"}
0005432361695	81DA9D	0089 043579	SERGEY KUZNECOV	{"phone": "+70374812521"}
0005432361696	A9A34F	9233 593712	ANASTASIYA SERGEEVA	{"email": "sergeeva-a-18101967@postgrespro.ru", "phone": "+70918695650"}
0005432361697	1A76FA	2468 762454	ELENA KISELEVA	{"phone": "+70845416859"}
0005432361698	1A76FA	2346 735365	ROMAN FOMIN	{"email": "roman_fomin.1972@postgrespro.ru", "phone": "+70447049052"}
0005432361699	432B48	2543 147213	LYUDMILA KISELEVA	{"phone": "+70789202439"}
0005432361700	598A02	7492 849109	VLADISLAV SERGEEV	{"phone": "+70660394830"}
0005432361701	50A8F5	7931 118863	LYUDMILA IVANOVA	{"phone": "+70875329935"}
0005432361702	4A2B1F	6707 628493	NINA SMIRNOVA	{"phone": "+70372436561"}
0005432361703	63C439	6411 101440	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin_031971@postgrespro.ru", "phone": "+70356191473"}
0005432361704	943A70	5252 565639	IGOR FILIPPOV	{"email": "i_filippov041967@postgrespro.ru", "phone": "+70556744762"}
0005432361705	6A9005	9520 235651	ANDREY FILIPPOV	{"phone": "+70599081655"}
0005432361706	4FA6BF	9120 327145	ALEKSANDR MOROZOV	{"email": "a-morozov_051976@postgrespro.ru", "phone": "+70675011483"}
0005432361707	4FA6BF	3690 950846	ANFISA IVANOVA	{"email": "aivanova-1965@postgrespro.ru", "phone": "+70957854458"}
0005432361708	5954C7	5479 751842	OLGA YUDINA	{"email": "yudinao.12011979@postgrespro.ru", "phone": "+70835041803"}
0005432361709	5954C7	3025 167407	ANDREY SIDOROV	{"email": "a_sidorov1968@postgrespro.ru", "phone": "+70795135046"}
0005432361710	5954C7	4815 192525	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-051973@postgrespro.ru", "phone": "+70647704433"}
0005432361711	65BE78	2631 754439	LEONID NIKOLAEV	{"email": "leonid_nikolaev-1970@postgrespro.ru", "phone": "+70458864988"}
0005432361712	65BE78	8816 751267	NADEZHDA ROMANOVA	{"phone": "+70229037468"}
0005432361716	34F057	6976 338381	TATYANA MAKAROVA	{"email": "t-makarova.1972@postgrespro.ru", "phone": "+70703809291"}
0005432361717	34F057	2602 880107	EGOR ZHUKOV	{"email": "egor.zhukov-121970@postgrespro.ru", "phone": "+70885637890"}
0005432361718	15D959	3352 715674	GALINA KUZNECOVA	{"email": "g_kuznecova081973@postgrespro.ru", "phone": "+70013366765"}
0005432361719	15D959	8119 421616	ELENA RODIONOVA	{"phone": "+70168051663"}
0005432361720	5B2BFD	5869 503433	ELENA CHERNOVA	{"email": "chernova.e.041972@postgrespro.ru", "phone": "+70373620825"}
0005432361721	2F1458	8382 627448	EVGENIY MOROZOV	{"email": "e.morozov1970@postgrespro.ru", "phone": "+70575230819"}
0005432361722	347067	4184 629563	KSENIYA MASLOVA	{"phone": "+70045482824"}
0005432361723	F60DAF	8288 724783	VLADIMIR MOISEEV	{"phone": "+70817594880"}
0005432361724	F60DAF	7134 514595	VALERIY KUZNECOV	{"phone": "+70264625553"}
0005432361725	3E5D25	1708 013388	ANATOLIY FEDOROV	{"email": "anatoliy_fedorov1969@postgrespro.ru", "phone": "+70594349845"}
0005432361726	1913B9	0254 552470	OKSANA MIKHAYLOVA	{"phone": "+70620738974"}
0005432361727	B6F1FB	5821 925564	SERGEY FOMIN	{"phone": "+70303874767"}
0005432361728	7490F6	5438 711019	OLESYA SOKOLOVA	{"email": "olesya.sokolova071964@postgrespro.ru", "phone": "+70597207589"}
0005432361729	FB1E9B	2697 292015	VALENTINA ROMANOVA	{"phone": "+70361101053"}
0005432361730	B0A427	8223 118268	LYUBOV BORISOVA	{"email": "l-borisova-01121959@postgrespro.ru", "phone": "+70516855520"}
0005432361731	4BA7C5	0036 583014	VALENTINA TARASOVA	{"email": "v.tarasova_081964@postgrespro.ru", "phone": "+70516158966"}
0005432361732	533C7C	3018 159794	DMITRIY FEDOROV	{"email": "fedorov-d-26061961@postgrespro.ru", "phone": "+70331429221"}
0005432361733	49965B	2977 080880	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey26101979@postgrespro.ru", "phone": "+70072075451"}
0005432361734	7BDFB3	3983 898893	DMITRIY KONOVALOV	{"phone": "+70599489323"}
0005432361735	FD8F78	0086 680495	ANDREY KARPOV	{"email": "karpova_18091978@postgrespro.ru", "phone": "+70109572038"}
0005432361736	EC4A9B	3352 324416	VALERIY MOROZOV	{"email": "morozovv.28011974@postgrespro.ru", "phone": "+70343648650"}
0005432361737	445546	1886 383885	OLGA ZHURAVLEVA	{"phone": "+70379546424"}
0005432361738	3A367B	6868 842271	SVETLANA ARKHIPOVA	{"phone": "+70233300119"}
0005432361739	D92410	4318 979811	VALENTINA TARASOVA	{"phone": "+70053219885"}
0005432361740	4D0B19	8140 379767	ANDREY MAKAROV	{"phone": "+70199336522"}
0005432361741	CA4287	2303 141178	OLGA PETROVA	{"phone": "+70450736233"}
0005432361742	F310C5	0563 901586	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.g05071970@postgrespro.ru", "phone": "+70590440396"}
0005432361743	F310C5	0347 546084	MARGARITA LAZAREVA	{"phone": "+70644976623"}
0005432361744	DF3562	7383 818686	DMITRIY ZHURAVLEV	{"email": "zhuravlevdmitriy-051971@postgrespro.ru", "phone": "+70748990077"}
0005432361745	8F0FA4	8272 810881	VYACHESLAV VOLKOV	{"email": "vyacheslavvolkov_17111964@postgrespro.ru", "phone": "+70617366942"}
0005432361746	0CF720	8995 842718	IVAN KUDRYASHOV	{"email": "i_kudryashov01071972@postgrespro.ru", "phone": "+70101673040"}
0005432361747	954C70	0739 185566	NIKOLAY FILIPPOV	{"phone": "+70352990416"}
0005432361748	954C70	1574 887829	ANATOLIY KOZLOV	{"email": "anatoliykozlov_21021972@postgrespro.ru", "phone": "+70900898309"}
0005432361749	F91B23	2594 800558	ANNA KARPOVA	{"phone": "+70163354639"}
0005432361750	8496EE	8549 380827	IRINA SAVELEVA	{"phone": "+70421270349"}
0005432361751	8496EE	1704 798995	VLADIMIR MATVEEV	{"phone": "+70119577811"}
0005432361752	106526	4296 348327	ALEKSEY FROLOV	{"email": "frolov.a-1979@postgrespro.ru", "phone": "+70339482750"}
0005432361753	B52E52	2299 938379	OLGA KRASNOVA	{"phone": "+70764563537"}
0005432361754	B52E52	5795 835885	RAISA POTAPOVA	{"phone": "+70836649823"}
0005432361755	163CD8	1799 062727	GALINA YAKOVLEVA	{"phone": "+70842268222"}
0005432361756	163CD8	7164 607823	VLADIMIR KONOVALOV	{"email": "konovalovv_041968@postgrespro.ru", "phone": "+70374988036"}
0005432361757	A1F4DC	5046 319451	ARTEM FILIPPOV	{"phone": "+70014483980"}
0005432361758	DD9E09	2082 894720	NINA DMITRIEVA	{"email": "dmitrievanina.121977@postgrespro.ru", "phone": "+70634209641"}
0005432361759	310184	5901 399756	NIKITA TIKHONOV	{"phone": "+70068644784"}
0005432361760	D7D493	8040 126462	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov_061964@postgrespro.ru", "phone": "+70233330836"}
0005432361761	4E2692	2863 663075	TATYANA ROMANOVA	{"email": "romanova-tatyana-28091979@postgrespro.ru", "phone": "+70268060853"}
0005432361762	4E2692	1342 018710	SERGEY EGOROV	{"email": "egorov.s_15021966@postgrespro.ru", "phone": "+70210859445"}
0005432361763	5E895C	2931 513574	VLADIMIR SOKOLOV	{"email": "v.sokolov.1977@postgrespro.ru", "phone": "+70220518127"}
0005432361764	628ED5	6274 280080	ALEKSANDR NIKITIN	{"phone": "+70061132967"}
0005432361765	F51EA5	6067 216660	MARINA NIKOLAEVA	{"email": "nikolaeva-marina-121966@postgrespro.ru", "phone": "+70728736423"}
0005432361766	F51EA5	8250 470557	VALENTINA KRASNOVA	{"email": "valentinakrasnova-1977@postgrespro.ru", "phone": "+70489195817"}
0005432361767	AC033C	4347 473378	MARIYA MELNIKOVA	{"phone": "+70863051329"}
0005432361768	AC033C	1612 883800	ALENA TARASOVA	{"phone": "+70526029813"}
0005432361769	AC033C	3814 174818	ANASTASIYA ZAKHAROVA	{"phone": "+70168510279"}
0005432361770	FBCD4E	5881 968640	SVETLANA POTAPOVA	{"phone": "+70441265967"}
0005432361771	8DA392	4065 759924	VITALIY ZAYCEV	{"email": "vitaliy.zaycev-1969@postgrespro.ru", "phone": "+70413866423"}
0005432361772	8DA392	9819 566352	ELENA VLASOVA	{"phone": "+70450698519"}
0005432361773	3DA8BC	0999 008307	NATALYA VASILEVA	{"phone": "+70485829484"}
0005432361774	3DA8BC	8163 969436	YURIY SAVELEV	{"phone": "+70788615500"}
0005432363359	01A927	1377 489500	DANIL OSIPOV	{"email": "dosipov_111976@postgrespro.ru", "phone": "+70777732252"}
0005432363360	01A927	6986 173029	NADEZHDA DMITRIEVA	{"email": "dmitrieva-n_1971@postgrespro.ru", "phone": "+70347199990"}
0005432363361	F53288	4757 044815	KONSTANTIN MOROZOV	{"email": "kmorozov1968@postgrespro.ru", "phone": "+70909128265"}
0005432363362	31D9FC	5542 189089	VIKTORIYA EGOROVA	{"phone": "+70495593859"}
0005432363363	21FB6F	5216 159230	ANTONINA VASILEVA	{"phone": "+70657561091"}
0005432363364	21FB6F	9221 288626	ALEKSEY ZHUKOV	{"phone": "+70219340982"}
0005432363365	2D4CC8	0122 555227	VALENTINA ILINA	{"email": "ilinavalentina-011969@postgrespro.ru", "phone": "+70002488858"}
0005432363366	2D4CC8	9071 310149	ALEKSANDR VASILEV	{"email": "vasilev_a.31071972@postgrespro.ru", "phone": "+70491536437"}
0005432363367	FBF93F	2918 118647	EKATERINA MOROZOVA	{"email": "e.morozova1970@postgrespro.ru", "phone": "+70685182363"}
0005432363368	670761	1697 000621	SERGEY MAKAROV	{"email": "makarov-s-12011979@postgrespro.ru", "phone": "+70147180516"}
0005432363369	670761	5822 121660	NATALYA ARKHIPOVA	{"phone": "+70824625195"}
0005432363370	B14E9F	1548 294527	ALINA KOZLOVA	{"phone": "+70301040161"}
0005432363371	B14E9F	3823 587890	YULIYA VASILEVA	{"email": "vasileva_yuliya_1970@postgrespro.ru", "phone": "+70230460653"}
0005432363372	2C6B7F	5657 462438	GENNADIY YAKOVLEV	{"email": "g_yakovlev-1979@postgrespro.ru", "phone": "+70664589849"}
0005432363373	3C9EB2	6331 075540	ALEKSANDR MIKHAYLOV	{"phone": "+70691688010"}
0005432363374	9AF16D	0693 038953	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova-06111960@postgrespro.ru", "phone": "+70605808700"}
0005432363375	6E2029	7778 663912	ALEKSANDR VASILEV	{"phone": "+70077761242"}
0005432363376	AA64E3	5334 581194	ALEKSEY ILIN	{"phone": "+70561409942"}
0005432363377	6178D9	8318 630332	MIKHAIL GRIGOREV	{"email": "mgrigorev-101969@postgrespro.ru", "phone": "+70919789201"}
0005432363378	B88FAD	0032 709374	VITALIY MOROZOV	{"phone": "+70161747184"}
0005432363379	AC1D9D	0396 778775	OLGA PAVLOVA	{"email": "olga-pavlova24101977@postgrespro.ru", "phone": "+70102441942"}
0005432363380	6DD0FA	2128 901231	LYUDMILA BOGDANOVA	{"phone": "+70200022248"}
0005432363381	6DD0FA	0452 302093	ELENA VOLKOVA	{"email": "volkova.elena1964@postgrespro.ru", "phone": "+70282518928"}
0005432363382	6DD0FA	2206 677545	ANTONINA STEPANOVA	{"email": "stepanovaantonina_081976@postgrespro.ru", "phone": "+70505024603"}
0005432363383	0DC1BC	4433 098662	MIKHAIL SHEVCHENKO	{"phone": "+70984958951"}
0005432363384	86D47A	2391 834058	ALIYA TARASOVA	{"phone": "+70539304843"}
0005432363385	8A98DD	8044 718529	LYUBOV KOROLEVA	{"email": "l-koroleva_1979@postgrespro.ru", "phone": "+70909666655"}
0005432363386	399864	1445 502185	ALEKSANDR RODIONOV	{"phone": "+70993101571"}
0005432363387	399864	2262 128852	RAIS MAKAROV	{"email": "makarovrais-031975@postgrespro.ru", "phone": "+70770360207"}
0005432363388	399864	0715 807857	NIKOLAY ALEKSANDROV	{"email": "aleksandrov-nikolay.19121977@postgrespro.ru", "phone": "+70497486369"}
0005432363389	5FED10	8705 324928	VARVARA MOROZOVA	{"email": "morozova.varvara.1971@postgrespro.ru", "phone": "+70372848084"}
0005432363390	735911	1958 803125	VLADIMIR NAZAROV	{"phone": "+70732547428"}
0005432363391	858554	3051 397817	RAVIL GAVRILOV	{"phone": "+70653830544"}
0005432363392	858554	4722 178843	ALEVTINA OVCHINNIKOVA	{"email": "ovchinnikova_a_111976@postgrespro.ru", "phone": "+70073804394"}
0005432363393	A61989	0615 432923	SVETLANA TROFIMOVA	{"phone": "+70744081330"}
0005432363394	A61989	7552 681183	DMITRIY SOKOLOV	{"email": "sokolovdmitriy-031968@postgrespro.ru", "phone": "+70592032899"}
0005432363395	78952C	2063 691051	NIKOLAY GORBUNOV	{"phone": "+70322832822"}
0005432363396	E7626A	1936 440812	SERGEY ROMANOV	{"phone": "+70956645207"}
0005432363397	E7626A	3233 632969	NIKOLAY FEDOTOV	{"phone": "+70693193073"}
0005432363398	DCAFDD	4167 504176	EVGENIYA FROLOVA	{"email": "frolova_e-01121973@postgrespro.ru", "phone": "+70523927820"}
0005432363399	DCAFDD	3046 586516	IRINA ZOTOVA	{"phone": "+70640464505"}
0005432363400	2CCA43	3148 867598	IRINA POPOVA	{"phone": "+70625468529"}
0005432363401	FB0136	0200 513398	ALEKSEY KRASNOV	{"email": "a_krasnov28021969@postgrespro.ru", "phone": "+70786049735"}
0005432363402	382993	0810 336217	NINA KRASNOVA	{"email": "nina_krasnova-19071965@postgrespro.ru", "phone": "+70425048183"}
0005432363403	9CF847	8216 475283	TAMARA LEBEDEVA	{"phone": "+70450764273"}
0005432363404	9CF847	0608 180499	MARIYA KUZNECOVA	{"email": "mkuznecova-1980@postgrespro.ru", "phone": "+70043496533"}
0005432363405	DD608E	0476 428730	MIKHAIL SERGEEV	{"email": "sergeev-mikhail1967@postgrespro.ru", "phone": "+70278445416"}
0005432363406	B5E0B1	9109 542837	PAVEL SERGEEV	{"phone": "+70483352737"}
0005432363407	B5E0B1	8035 641281	VARVARA SOKOLOVA	{"email": "sokolova-varvara30111973@postgrespro.ru", "phone": "+70055132472"}
0005432363408	B5E0B1	7303 115343	ALENA ANDREEVA	{"email": "andreeva.alena.021965@postgrespro.ru", "phone": "+70599522342"}
0005432363409	85EF32	5051 581255	VIKTORIYA IVANOVA	{"email": "viktoriya-ivanova.22101977@postgrespro.ru", "phone": "+70772648589"}
0005432363410	4685B5	3330 525157	ANASTASIYA VOROBEVA	{"email": "anastasiya.vorobeva28031965@postgrespro.ru", "phone": "+70790033856"}
0005432363411	4685B5	7280 450990	YAKOV BELOV	{"email": "belov.yakov_011963@postgrespro.ru", "phone": "+70948072866"}
0005432363412	4EBA86	0518 147959	VALENTINA YUDINA	{"email": "yudina_v.19081974@postgrespro.ru", "phone": "+70815182503"}
0005432363413	62F514	2306 968505	ANDREY KOZLOV	{"phone": "+70573245137"}
0005432363414	A07C91	6090 234689	RINAT EGOROV	{"phone": "+70711065566"}
0005432363415	5B4D87	0181 958866	EKATERINA KUDRYASHOVA	{"email": "kudryashova-e-1971@postgrespro.ru", "phone": "+70213637377"}
0005432363416	DF6FFD	3762 575251	YULIYA TITOVA	{"phone": "+70587966800"}
0005432363417	F33B2C	8044 448810	VLADIMIR ZAYCEV	{"email": "zaycevv-021982@postgrespro.ru", "phone": "+70115363970"}
0005432363418	BC42D5	7674 323374	IRINA GUSEVA	{"email": "irinaguseva-1979@postgrespro.ru", "phone": "+70309465478"}
0005432363419	BC42D5	9486 204347	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr-041982@postgrespro.ru", "phone": "+70187266502"}
0005432363420	7C1E86	2048 596673	ELENA ALEKSANDROVA	{"phone": "+70821956965"}
0005432363421	7C1E86	9596 738187	OLGA ZAYCEVA	{"email": "olga.zayceva_09101963@postgrespro.ru", "phone": "+70082336064"}
0005432363422	7C1E86	8499 619350	ROMAN KONOVALOV	{"phone": "+70186261136"}
0005432363423	3DF025	2060 448030	IGOR MOISEEV	{"email": "i-moiseev-1973@postgrespro.ru", "phone": "+70220468335"}
0005432363424	3DF025	6343 042342	NATALIYA ALEKSEEVA	{"email": "alekseevanataliya-29071961@postgrespro.ru", "phone": "+70327083939"}
0005432363425	3DF025	4191 095382	MARINA IVANOVA	{"phone": "+70215424500"}
0005432363426	9F55B1	6441 891173	LARISA MIRONOVA	{"email": "mironova-larisa.20021980@postgrespro.ru", "phone": "+70274298759"}
0005432363427	89F87F	5337 175338	OLGA KOZLOVA	{"phone": "+70011563317"}
0005432363428	302A4B	6950 436640	ELENA DAVYDOVA	{"email": "elena.davydova.091983@postgrespro.ru", "phone": "+70368799914"}
0005432363429	40A293	9855 975157	LYUDMILA POLYAKOVA	{"email": "polyakova.l-08091974@postgrespro.ru", "phone": "+70187103777"}
0005432363430	40A293	4696 928726	VLADIMIR TIMOFEEV	{"email": "timofeevv_021975@postgrespro.ru", "phone": "+70814597777"}
0005432363431	40A293	1822 970972	EDUARD MELNIKOV	{"phone": "+70982548924"}
0005432363432	5F1D89	4172 690616	VLADIMIR NIKOLAEV	{"email": "v-nikolaev1979@postgrespro.ru", "phone": "+70750844259"}
0005432363433	5F1D89	8172 539238	IVAN PETROV	{"email": "ivan-petrov_111966@postgrespro.ru", "phone": "+70670697188"}
0005432363434	B11242	2610 773246	VALERIY MATVEEV	{"phone": "+70351180578"}
0005432363435	693705	2481 661004	ANASTASIYA LUKYANOVA	{"phone": "+70753704405"}
0005432363436	693705	3990 398708	ALEKSANDR MAKAROV	{"phone": "+70002496699"}
0005432363437	C9B38C	5084 534003	EKATERINA GUSEVA	{"email": "e.guseva30091978@postgrespro.ru", "phone": "+70278591351"}
0005432363438	510466	3847 085907	DARYA YUDINA	{"phone": "+70223910689"}
0005432363439	1A1FB5	5120 418713	NIKOLAY SOKOLOV	{"phone": "+70325528471"}
0005432363440	33E623	3621 932975	LYUDMILA FROLOVA	{"phone": "+70864034945"}
0005432363441	33E623	6773 393534	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir_1969@postgrespro.ru", "phone": "+70041849597"}
0005432363442	4EA095	0780 653268	ALEKSEY BORISOV	{"email": "borisov-aleksey071968@postgrespro.ru", "phone": "+70426262534"}
0005432363443	4EA095	9040 091426	DMITRIY VOLKOV	{"email": "dmitriy.volkov-1968@postgrespro.ru", "phone": "+70416730922"}
0005432363444	883A34	4427 619905	RUSLAN PAVLOV	{"phone": "+70545420247"}
0005432363445	0928D1	5128 997112	ILYA MIKHAYLOV	{"email": "ilya_mikhaylov_051976@postgrespro.ru", "phone": "+70171741857"}
0005432363446	C9657B	0396 344146	MARIYA KUZNECOVA	{"phone": "+70469851563"}
0005432363447	CC0506	1093 525778	SERGEY POPOV	{"phone": "+70935553345"}
0005432363448	CC0506	4062 640728	LEONID ABRAMOV	{"email": "abramovl_18061980@postgrespro.ru", "phone": "+70135673714"}
0005432363449	4A1398	1377 837707	DANIYA MOISEEVA	{"email": "moiseeva-d-1969@postgrespro.ru", "phone": "+70289348042"}
0005432363450	4A1398	2690 073730	TATYANA KONOVALOVA	{"email": "konovalova_tatyana.051990@postgrespro.ru", "phone": "+70070964245"}
0005432363451	4A1398	8889 676277	VASILIY MOISEEV	{"phone": "+70634017485"}
0005432363452	C5AFD6	4045 118889	VLADIMIR ANTONOV	{"phone": "+70741834302"}
0005432363453	22CCDC	4392 231994	LIDIYA DAVYDOVA	{"email": "davydova-l071970@postgrespro.ru", "phone": "+70878359868"}
0005432363454	22CCDC	0756 547480	TAISA AFANASEVA	{"email": "afanaseva-t.021973@postgrespro.ru", "phone": "+70127884304"}
0005432363455	04D522	9523 764680	VIKTOR VOLKOV	{"email": "volkov_v-24021971@postgrespro.ru", "phone": "+70609560451"}
0005432363456	04D522	5613 941141	MIKHAIL KOZLOV	{"email": "m-kozlov-06051978@postgrespro.ru", "phone": "+70865844444"}
0005432363457	04D522	4774 369030	ARTEM GRIGOREV	{"phone": "+70673186185"}
0005432363458	FEB0E7	4475 582977	AYRAT ROMANOV	{"email": "aromanov.031961@postgrespro.ru", "phone": "+70997985090"}
0005432363459	5E69B7	1499 553262	TATYANA VASILEVA	{"phone": "+70642484918"}
0005432363460	2B343A	6397 559931	SERGEY NIKITIN	{"email": "s.nikitin-13011968@postgrespro.ru", "phone": "+70011361612"}
0005432363461	2B343A	9519 990831	VLADIMIR STEPANOV	{"email": "v-stepanov-1974@postgrespro.ru", "phone": "+70659564909"}
0005432363462	7629C0	0492 514571	RITA MIRONOVA	{"email": "mironovar_021978@postgrespro.ru", "phone": "+70356535072"}
0005432363463	4BD349	2515 436901	DENIS KONOVALOV	{"phone": "+70522017908"}
0005432363464	6DDA51	9137 152627	VALENTINA MELNIKOVA	{"phone": "+70492189190"}
0005432363465	6DDA51	1755 230718	ALEKSANDR ROMANOV	{"phone": "+70626981321"}
0005432363466	FE3CC7	6271 822042	DMITRIY NIKOLAEV	{"phone": "+70226482002"}
0005432363467	ED4C93	0296 457292	ROMAN PAVLOV	{"email": "pavlovroman-11061977@postgrespro.ru", "phone": "+70546817785"}
0005432363468	A1CF59	5211 533772	GALINA KALININA	{"email": "kalinina_g1977@postgrespro.ru", "phone": "+70740361371"}
0005432363469	A1CF59	4529 498230	ALEKSANDR SEMENOV	{"email": "semenovaleksandr_09011974@postgrespro.ru", "phone": "+70464760754"}
0005432363470	E9C250	2317 319679	STANISLAV SAVELEV	{"email": "stanislav-savelev_1970@postgrespro.ru", "phone": "+70798443055"}
0005432363471	76BB0E	5650 287617	LYUBOV BELYAEVA	{"phone": "+70838360895"}
0005432363472	38C099	3095 869110	LIDIYA FROLOVA	{"email": "froloval.10021969@postgrespro.ru", "phone": "+70109251176"}
0005432363473	4528D9	9951 109650	VALERIY VASILEV	{"email": "v.vasilev_1971@postgrespro.ru", "phone": "+70040844511"}
0005432363474	9FB398	3902 841189	VLADIMIR MELNIKOV	{"phone": "+70538529812"}
0005432363475	9FB398	7152 948215	TAMARA FADEEVA	{"email": "fadeeva.t-16031978@postgrespro.ru", "phone": "+70375159969"}
0005432363476	D89B85	4300 087182	SVETLANA MEDVEDEVA	{"phone": "+70283376192"}
0005432363477	C22DAA	9691 889630	IRINA ROMANOVA	{"phone": "+70800551733"}
0005432363478	D885B9	7078 478834	YULIYA GRISHINA	{"email": "ygrishina061979@postgrespro.ru", "phone": "+70373513738"}
0005432363479	8E6B95	2338 973395	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.021972@postgrespro.ru", "phone": "+70518652028"}
0005432363480	CD3C98	1108 140872	ANASTASIYA ANDREEVA	{"email": "anastasiya.andreeva_05101969@postgrespro.ru", "phone": "+70437733934"}
0005432363481	BD9C65	0019 340791	EKATERINA KUDRYASHOVA	{"phone": "+70109948548"}
0005432363482	12E967	5515 691649	EGOR ISAEV	{"phone": "+70411364594"}
0005432363483	5C01BE	7474 340027	ANASTASIYA ZHUKOVA	{"email": "anastasiya-zhukova.11101974@postgrespro.ru", "phone": "+70563112044"}
0005432363484	5C01BE	7286 119396	ALFIYA FILIPPOVA	{"email": "filippova.alfiya-04111973@postgrespro.ru", "phone": "+70375808252"}
0005432363485	648D34	4921 366142	IRINA NESTEROVA	{"phone": "+70612397397"}
0005432363486	182E94	3476 318064	STANISLAV GRIGOREV	{"email": "sgrigorev-06041968@postgrespro.ru", "phone": "+70911424356"}
0005432363487	C3615A	6393 927184	LIDIYA MAKAROVA	{"email": "lidiyamakarova.071968@postgrespro.ru", "phone": "+70576770748"}
0005432363488	CB3A9A	7377 708130	IRINA SOROKINA	{"email": "sorokina.irina-1974@postgrespro.ru", "phone": "+70365972172"}
0005432363489	0939CB	2604 510239	LYUBOV ABRAMOVA	{"phone": "+70150009763"}
0005432363490	D693A1	9641 228079	SVETLANA MEDVEDEVA	{"email": "svetlanamedvedeva-14051962@postgrespro.ru", "phone": "+70638491823"}
0005432363491	0E6509	2542 241743	YURIY SOKOLOV	{"phone": "+70769636225"}
0005432363492	34BF2B	0122 281134	OLGA PETROVA	{"email": "petrova.olga-1965@postgrespro.ru", "phone": "+70146543702"}
0005432363493	E3F31E	3775 596205	LYUBOV ORLOVA	{"phone": "+70007817271"}
0005432363494	2813F0	9985 878976	KLAVDIYA SOKOLOVA	{"phone": "+70557143268"}
0005432363495	2813F0	2215 811490	ELENA MATVEEVA	{"phone": "+70582107990"}
0005432363496	5B2E62	3742 962300	NINA SOROKINA	{"email": "nsorokina.101967@postgrespro.ru", "phone": "+70584733447"}
0005432363497	5B2E62	3235 455008	RADIK MAKSIMOV	{"phone": "+70239362781"}
0005432363498	5A7F2F	0991 821350	OLGA PAVLOVA	{"email": "pavlova-olga.1979@postgrespro.ru", "phone": "+70532161618"}
0005432363499	541A4F	9873 840946	IRINA CHERNOVA	{"phone": "+70166940706"}
0005432363500	2BF3F3	5787 578940	DMITRIY ALEKSEEV	{"phone": "+70512391432"}
0005432363501	48C981	3391 156231	ANNA POPOVA	{"phone": "+70992254745"}
0005432363502	48C981	7415 551609	ALEKSANDR MOISEEV	{"email": "moiseev-aleksandr_28051977@postgrespro.ru", "phone": "+70560757364"}
0005432363503	48C981	3351 082936	VALENTIN AFANASEV	{"phone": "+70775437946"}
0005432363504	24D4C1	6211 589512	MARIYA ZHURAVLEVA	{"phone": "+70593150250"}
0005432363505	D4D20E	5414 214200	ANASTASIYA BORISOVA	{"email": "a-borisova-18031980@postgrespro.ru", "phone": "+70218774185"}
0005432363506	D4D20E	0856 839400	YURIY CHERNOV	{"phone": "+70607780761"}
0005432363507	1B98C5	5393 821234	DMITRIY ZHURAVLEV	{"phone": "+70119280402"}
0005432363508	245DFF	0166 958373	NADEZHDA SAVELEVA	{"phone": "+70100747941"}
0005432363509	1BD548	6086 723120	TATYANA EGOROVA	{"phone": "+70635913114"}
0005432363510	77E9B9	6782 559813	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev_1971@postgrespro.ru", "phone": "+70020589687"}
0005432363511	77E9B9	6039 583696	MARIYA RODIONOVA	{"phone": "+70420676319"}
0005432363512	DB3B23	0680 967466	DAMIR KUZNECOV	{"email": "kuznecov.d_1970@postgrespro.ru", "phone": "+70070242621"}
0005432363513	1F6B9A	8236 415548	VLADIMIR DMITRIEV	{"email": "dmitriev.v.1983@postgrespro.ru", "phone": "+70340445807"}
0005432363514	1F6B9A	4592 146752	ALENA MIKHAYLOVA	{"phone": "+70151178784"}
0005432363515	83177D	5794 542523	RAISA KOZLOVA	{"phone": "+70149406561"}
0005432363516	83177D	4019 288970	VASILIY KOZLOV	{"email": "v_kozlov091971@postgrespro.ru", "phone": "+70173557062"}
0005432382484	CA230D	5544 944599	ARTEM EGOROV	{"phone": "+70419964170"}
0005432382485	54438F	7164 153571	ZOYA KALININA	{"email": "kalinina-zoya06011971@postgrespro.ru", "phone": "+70659985993"}
0005432382486	54438F	8806 833201	PAVEL SMIRNOV	{"phone": "+70121131068"}
0005432382487	FA1B5F	2159 873041	LARISA LAZAREVA	{"email": "l_lazareva.1966@postgrespro.ru", "phone": "+70670846630"}
0005432382488	DBB8E2	6102 553346	ELENA MIKHAYLOVA	{"email": "mikhaylova_elena_1967@postgrespro.ru", "phone": "+70778422205"}
0005432382489	DBB8E2	1642 171285	ALEKSANDR ALEKSANDROV	{"phone": "+70956184936"}
0005432382490	7D5B2D	7524 085764	LYUDMILA VOROBEVA	{"email": "lyudmila-vorobeva_011983@postgrespro.ru", "phone": "+70707411107"}
0005432382491	2178E1	3080 369924	OLGA DMITRIEVA	{"phone": "+70604524719"}
0005432382492	2178E1	9158 524839	LYUDMILA ANTONOVA	{"phone": "+70509055201"}
0005432382493	018BEF	1759 302302	ULYANA MATVEEVA	{"email": "umatveeva.13091965@postgrespro.ru", "phone": "+70824532149"}
0005432382494	018BEF	9915 630040	ANNA STEPANOVA	{"phone": "+70619191680"}
0005432382495	185BD7	8867 012436	ANASTASIYA SERGEEVA	{"email": "sergeeva.anastasiya_1975@postgrespro.ru", "phone": "+70827037670"}
0005432382496	185BD7	9523 043968	NADEZHDA SERGEEVA	{"email": "n-sergeeva_1963@postgrespro.ru", "phone": "+70826584201"}
0005432382497	226F6C	2062 971943	TATYANA ANTONOVA	{"phone": "+70087804607"}
0005432382498	226F6C	2798 170982	VLADIMIR VASILEV	{"phone": "+70518208244"}
0005432382499	D5A6BB	3523 638285	VADIM NIKOLAEV	{"phone": "+70342375288"}
0005432382500	64AE28	1210 347594	ALEKSANDR MEDVEDEV	{"email": "a_medvedev.1967@postgrespro.ru", "phone": "+70551596326"}
0005432382501	ECB406	6490 896008	IVAN ZAYCEV	{"phone": "+70203564247"}
0005432382502	E99F6E	9456 314171	VLADIMIR PETROV	{"phone": "+70531943593"}
0005432382503	1F5E2F	3481 939664	NADEZHDA TARASOVA	{"email": "tarasova_nadezhda_1976@postgrespro.ru", "phone": "+70197224254"}
0005432382504	788EAA	0121 737006	EGOR ABRAMOV	{"email": "abramovegor_03061968@postgrespro.ru", "phone": "+70858422964"}
0005432382505	AA8118	8132 849884	VLADIMIR ORLOV	{"email": "orlovv.101975@postgrespro.ru", "phone": "+70509754422"}
0005432382506	242CC3	5503 939535	VLADIMIR MOROZOV	{"phone": "+70926045592"}
0005432382507	FADB12	1618 794845	GALINA ANTONOVA	{"phone": "+70801942637"}
0005432382508	4D38B3	6925 480381	OLGA MOROZOVA	{"phone": "+70692880963"}
0005432382509	4D38B3	0060 120893	TATYANA MALYSHEVA	{"phone": "+70775389841"}
0005432382510	C1B56C	7415 270827	IRINA KUZNECOVA	{"phone": "+70298142263"}
0005432382511	2E119B	3640 802410	OLGA MAKAROVA	{"email": "makarovao-18111979@postgrespro.ru", "phone": "+70375649967"}
0005432382512	0477BC	3802 969181	SERGEY ANDREEV	{"email": "sergey_andreev_091967@postgrespro.ru", "phone": "+70029453119"}
0005432382513	21542E	8314 181181	SERGEY ABRAMOV	{"email": "abramov_s_17041972@postgrespro.ru", "phone": "+70811989604"}
0005432382514	21542E	1323 314845	NIKOLAY KUZNECOV	{"phone": "+70609145949"}
0005432382515	F8C502	8141 179815	NATALYA IVANOVA	{"email": "ivanovanatalya1963@postgrespro.ru", "phone": "+70980541116"}
0005432382516	F8C502	3618 259274	VIKTOR KUZMIN	{"phone": "+70321421901"}
0005432382517	BBCF6B	5728 121853	SVETLANA KOZLOVA	{"email": "skozlova.1978@postgrespro.ru", "phone": "+70128608048"}
0005432382518	80EAA9	1072 308425	MAKSIM MEDVEDEV	{"email": "maksimmedvedev_30011976@postgrespro.ru", "phone": "+70542571869"}
0005432382519	80EAA9	9957 638759	SVETLANA KUDRYASHOVA	{"email": "s.kudryashova05111969@postgrespro.ru", "phone": "+70068389279"}
0005432382520	E01ADD	2921 445566	GULSHAT IVANOVA	{"email": "ivanova.gulshat_1970@postgrespro.ru", "phone": "+70681097960"}
0005432382521	3A0196	4620 062065	LYUDMILA NOVIKOVA	{"email": "novikova_lyudmila_1966@postgrespro.ru", "phone": "+70795189394"}
0005432382522	376D2C	9331 710599	NIKOLAY SOKOLOV	{"email": "nikolay-sokolov19011976@postgrespro.ru", "phone": "+70809584631"}
0005432382523	EE0FC2	0867 981106	ALEKSANDR SERGEEV	{"phone": "+70517369784"}
0005432382524	0DBB46	4910 029550	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir-1977@postgrespro.ru", "phone": "+70334288005"}
0005432382525	12FAAA	9968 086057	EKATERINA OSIPOVA	{"phone": "+70340651012"}
0005432382526	BD3EFC	4555 887265	ANATOLIY IVANOV	{"email": "ivanov-anatoliy29111976@postgrespro.ru", "phone": "+70858293418"}
0005432382527	9C7ABE	5277 648258	EVGENIY TIMOFEEV	{"email": "e_timofeev-121960@postgrespro.ru", "phone": "+70179458809"}
0005432382528	A7DC18	6290 323153	VLADIMIR EGOROV	{"email": "v.egorov_1982@postgrespro.ru", "phone": "+70866483316"}
0005432382529	66F5F4	9269 204446	RUSLAN IVANOV	{"email": "ruslanivanov101980@postgrespro.ru", "phone": "+70672853225"}
0005432382530	66F5F4	2955 843612	VLADIMIR IVANOV	{"phone": "+70303699142"}
0005432382531	89E021	4788 030096	ALEKSANDR EGOROV	{"email": "aleksandr_egorov_1978@postgrespro.ru", "phone": "+70748797265"}
0005432382532	89E021	7047 821184	VIKTOR IVANOV	{"phone": "+70841603212"}
0005432382533	89E021	3254 044024	TATYANA BOGDANOVA	{"email": "tbogdanova.1969@postgrespro.ru", "phone": "+70414531040"}
0005432382534	2389B2	7930 069004	YAROSLAV SEMENOV	{"email": "semenov_yaroslav111966@postgrespro.ru", "phone": "+70326983619"}
0005432382535	2389B2	9876 350705	KONSTANTIN ALEKSEEV	{"email": "alekseev.k.081978@postgrespro.ru", "phone": "+70025537081"}
0005432382536	E39CB9	3741 938095	TATYANA NIKITINA	{"email": "nikitina.t.1958@postgrespro.ru", "phone": "+70143129283"}
0005432382537	E6DAF1	4534 215408	ALEKSANDR POPOV	{"email": "a_popov_1974@postgrespro.ru", "phone": "+70229197118"}
0005432382538	4E8AC5	2914 326017	IVAN KAZAKOV	{"phone": "+70947846743"}
0005432382539	C55D22	0642 478791	DANIL ZAKHAROV	{"email": "zakharov-d031967@postgrespro.ru", "phone": "+70559502667"}
0005432382540	5CD870	1052 893219	ANNA ROMANOVA	{"phone": "+70531669848"}
0005432382541	A29B42	5886 150783	RIMMA BELOVA	{"phone": "+70317274515"}
0005432382542	374422	3290 012518	ALEKSANDR SOKOLOV	{"phone": "+70513975880"}
0005432382543	374422	7772 104141	ALEKSANDR PETROV	{"phone": "+70990891743"}
0005432382544	C4009F	5980 618085	VLADIMIR NAZAROV	{"phone": "+70333536954"}
0005432382545	C4009F	9259 254602	VITALIY FROLOV	{"phone": "+70915231055"}
0005432382546	00610D	8778 987633	TATYANA POPOVA	{"email": "tatyana.popova_24041972@postgrespro.ru", "phone": "+70449781155"}
0005432382547	00610D	2844 813800	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov.17111975@postgrespro.ru", "phone": "+70178227270"}
0005432382548	00610D	9330 831682	DAMIR KUZNECOV	{"email": "kuznecov.damir-111976@postgrespro.ru", "phone": "+70629201759"}
0005432382549	75B301	7369 678013	LIDIYA POPOVA	{"phone": "+70394916052"}
0005432382550	8591DF	1414 343212	NINA MIKHAYLOVA	{"email": "mikhaylovanina-041973@postgrespro.ru", "phone": "+70695844128"}
0005432382551	8591DF	9823 070726	SERGEY IVANOV	{"email": "s.ivanov-1973@postgrespro.ru", "phone": "+70723122938"}
0005432382552	3BEF68	1461 411674	YURIY SERGEEV	{"email": "sergeev_yuriy-011972@postgrespro.ru", "phone": "+70271636794"}
0005432382553	825126	9771 038490	ELENA STEPANOVA	{"email": "e_stepanova-1982@postgrespro.ru", "phone": "+70056104595"}
0005432382554	825126	7790 380508	ALEKSANDR FEDOROV	{"phone": "+70231858362"}
0005432382555	9103B8	2712 677812	VALENTINA OSIPOVA	{"email": "valentina_osipova_16031983@postgrespro.ru", "phone": "+70610410520"}
0005432382556	9103B8	5630 001483	TAMARA MIKHAYLOVA	{"email": "tamara.mikhaylova_111966@postgrespro.ru", "phone": "+70389488324"}
0005432382557	6D1A2B	7348 792992	ILYA SCHERBAKOV	{"phone": "+70874617297"}
0005432382558	6D1A2B	9002 067892	OKSANA DENISOVA	{"phone": "+70829487700"}
0005432382559	7A3ACF	2360 920704	OLESYA FILIPPOVA	{"email": "olesyafilippova_041965@postgrespro.ru", "phone": "+70358596833"}
0005432382560	64E358	1212 998849	NADEZHDA KOZLOVA	{"email": "nkozlova-1965@postgrespro.ru", "phone": "+70689092031"}
0005432382561	AD5EDC	0801 040396	EKATERINA DANILOVA	{"phone": "+70808551881"}
0005432382562	AD5EDC	4768 532159	TATYANA OSIPOVA	{"phone": "+70246403684"}
0005432382563	D54945	0459 239605	ANATOLIY AFANASEV	{"email": "anatoliy.afanasev25101972@postgrespro.ru", "phone": "+70140549431"}
0005432382564	8FCA0B	4774 106810	SHAMIL VLASOV	{"phone": "+70693132807"}
0005432382626	E0E89E	3762 116847	NATALYA VASILEVA	{"phone": "+70873282985"}
0005432382565	D26AA8	0943 319952	ALEKSANDR MOROZOV	{"email": "morozov-a_1963@postgrespro.ru", "phone": "+70109592143"}
0005432382566	D26AA8	5753 779990	SVETLANA MAKAROVA	{"phone": "+70468251145"}
0005432382567	928607	8856 385009	NELLI POPOVA	{"email": "n-popova-011970@postgrespro.ru", "phone": "+70689121072"}
0005432382568	A16F13	2927 034234	ELENA SOKOLOVA	{"email": "sokolova-elena_051973@postgrespro.ru", "phone": "+70153270872"}
0005432382569	A16F13	7442 248109	ANNA KOROLEVA	{"email": "a-koroleva-1966@postgrespro.ru", "phone": "+70234040148"}
0005432382570	35427D	4614 180901	IRINA KUDRYASHOVA	{"phone": "+70888160673"}
0005432382571	35427D	3945 074473	OLGA KUZMINA	{"phone": "+70754308830"}
0005432382572	88BA20	5736 419001	DMITRIY VOLKOV	{"email": "d_volkov01011968@postgrespro.ru", "phone": "+70137956104"}
0005432382573	A09838	5006 792026	DMITRIY SMIRNOV	{"email": "smirnov.dmitriy-21081971@postgrespro.ru", "phone": "+70070632285"}
0005432382574	BC58A0	3140 904592	ANTON PETROV	{"email": "a_petrov011972@postgrespro.ru", "phone": "+70637333142"}
0005432382575	58F67E	2508 076038	MARIYA FILIPPOVA	{"email": "filippova.mariya.17101968@postgrespro.ru", "phone": "+70260975150"}
0005432382576	9C1398	7089 129466	ALEKSANDR IVANOV	{"phone": "+70816117051"}
0005432382577	9C1398	1466 150374	NATALYA ANDREEVA	{"phone": "+70956967705"}
0005432382578	81DC07	4529 330054	OLGA MIRONOVA	{"email": "o-mironova-021982@postgrespro.ru", "phone": "+70422937670"}
0005432382579	A16DF3	6308 939721	ELIZAVETA DAVYDOVA	{"email": "e.davydova.27031963@postgrespro.ru", "phone": "+70584347038"}
0005432382580	A16DF3	2935 394602	MARIYA IVANOVA	{"phone": "+70940079701"}
0005432382581	5D08C4	9022 331348	MIKHAIL NOVIKOV	{"email": "mikhailnovikov_091966@postgrespro.ru", "phone": "+70269154630"}
0005432382582	665000	0885 241718	DMITRIY KUZNECOV	{"phone": "+70788280907"}
0005432382583	665000	5896 573775	YULIYA ZAYCEVA	{"email": "yuliya.zayceva06121973@postgrespro.ru", "phone": "+70763469753"}
0005432382584	893612	8484 682157	MARINA MAKSIMOVA	{"email": "maksimova_m011976@postgrespro.ru", "phone": "+70930527376"}
0005432382585	65C90B	6991 062521	MAKSIM KAZAKOV	{"phone": "+70471138122"}
0005432382586	6EAD17	6684 782168	GENNADIY VOROBEV	{"email": "vorobev-g.091969@postgrespro.ru", "phone": "+70690158146"}
0005432382587	561FFC	6040 477587	ANDREY FROLOV	{"phone": "+70585174714"}
0005432382588	561FFC	1255 678189	LYUBOV FILIPPOVA	{"phone": "+70893834867"}
0005432382589	561FFC	6699 783017	RAISA SEMENOVA	{"phone": "+70199455431"}
0005432382590	BC2905	1531 795218	VALENTINA BOGDANOVA	{"email": "bogdanova-valentina-29051975@postgrespro.ru", "phone": "+70136806960"}
0005432382591	BC2905	9935 540763	YURIY MIKHAYLOV	{"email": "mikhaylov_yuriy061974@postgrespro.ru", "phone": "+70427259949"}
0005432382592	5AB490	5629 819629	TATYANA ANDREEVA	{"email": "andreeva.t13051975@postgrespro.ru", "phone": "+70121410123"}
0005432382593	3D3A44	4947 229083	VIKTOR KUZNECOV	{"phone": "+70304946674"}
0005432382594	3D3A44	1669 909684	VLADIMIR ALEKSEEV	{"phone": "+70465646107"}
0005432382595	5C378D	5829 645424	VIKTOR VASILEV	{"email": "vasilev.viktor-121977@postgrespro.ru", "phone": "+70650099409"}
0005432382596	5C378D	8918 582518	SERGEY EGOROV	{"phone": "+70830471367"}
0005432382597	F764DB	9922 604365	MARIYA KUZNECOVA	{"email": "kuznecova.mariya-1970@postgrespro.ru", "phone": "+70915325356"}
0005432382598	F764DB	8893 436681	ALEKSANDR SCHERBAKOV	{"phone": "+70387313425"}
0005432382599	8FC8C6	4997 184457	ANNA SOROKINA	{"phone": "+70654753399"}
0005432382600	1A1284	1341 852005	LYUBOV SCHERBAKOVA	{"phone": "+70742752615"}
0005432382601	1A1284	8825 189400	TATYANA TIMOFEEVA	{"email": "t.timofeeva_1981@postgrespro.ru", "phone": "+70303438099"}
0005432382602	F5FB4C	6108 438086	BORIS DMITRIEV	{"phone": "+70122038351"}
0005432382603	F5FB4C	2531 823901	ALEKSANDR TIMOFEEV	{"phone": "+70573824205"}
0005432382604	F5FB4C	9746 471966	PAVEL KULIKOV	{"phone": "+70467927294"}
0005432382605	2A16C3	3753 571517	SERGEY ISAEV	{"phone": "+70969328082"}
0005432382606	49B7E5	8193 843700	VLADIMIR DENISOV	{"phone": "+70593722621"}
0005432382607	348DA1	3277 608177	OLGA BELOVA	{"email": "olga_belova.25011979@postgrespro.ru", "phone": "+70632975280"}
0005432382608	ED6AD1	2140 431061	ANATOLIY KOZLOV	{"phone": "+70873344438"}
0005432382609	E39355	1133 015320	NINA VASILEVA	{"email": "vasileva-n_09041968@postgrespro.ru", "phone": "+70696264129"}
0005432382610	E39355	1067 097949	YULIYA PETROVA	{"email": "petrova-yuliya.1973@postgrespro.ru", "phone": "+70593842036"}
0005432382611	1E56B8	8455 405578	VALENTINA DANILOVA	{"phone": "+70294277889"}
0005432382612	EC914F	6867 368859	ALEVTINA KALININA	{"email": "kalinina.a.071974@postgrespro.ru", "phone": "+70345989284"}
0005432382613	6F85A0	4249 865918	LARISA NIKITINA	{"phone": "+70434674275"}
0005432382614	6F85A0	6177 162939	YURIY SERGEEV	{"email": "sergeevyuriy-101977@postgrespro.ru", "phone": "+70077980678"}
0005432382615	AFE737	1961 935072	VLADIMIR FEDOROV	{"phone": "+70909175635"}
0005432382616	AFE737	4310 961802	NATALYA KUZNECOVA	{"email": "kuznecova.natalya.16061972@postgrespro.ru", "phone": "+70394466880"}
0005432382617	D4D54A	7889 102577	EDUARD IVANOV	{"phone": "+70489155765"}
0005432382618	D43219	4686 366135	SERGEY ISAEV	{"email": "s_isaev-31101960@postgrespro.ru", "phone": "+70124766988"}
0005432382619	D43219	7286 095056	TATYANA KOLESNIKOVA	{"email": "t_kolesnikova1966@postgrespro.ru", "phone": "+70531330124"}
0005432382620	EE8ACA	5571 621107	ALEKSEY ALEKSANDROV	{"phone": "+70158173168"}
0005432382621	63DEFD	9427 979261	ANDREY MAKAROV	{"email": "makarov_a.09121972@postgrespro.ru", "phone": "+70678547571"}
0005432382622	E35A7E	3033 851084	DARYA EFIMOVA	{"phone": "+70861956520"}
0005432382623	0E97D6	6558 835255	ALEKSANDR FEDOROV	{"phone": "+70887935049"}
0005432382624	42ECA2	0004 966579	NINA MIRONOVA	{"phone": "+70035802815"}
0005432382625	42ECA2	5534 367213	VLADIMIR KAZAKOV	{"email": "vladimir_kazakov.091976@postgrespro.ru", "phone": "+70066647449"}
0005432382627	8C7D56	2229 780844	OLGA FILATOVA	{"email": "filatova.olga-09031961@postgrespro.ru", "phone": "+70794726198"}
0005432382628	8C7D56	7509 140015	ALEKSANDR VOLKOV	{"phone": "+70651116863"}
0005432382629	A8927C	2857 418923	TATYANA KOVALEVA	{"phone": "+70038588577"}
0005432382630	7CC772	8422 396286	GALINA IVANOVA	{"email": "ivanovagalina_24091970@postgrespro.ru", "phone": "+70462113811"}
0005432382631	F4D196	8255 075397	ANATOLIY PAVLOV	{"email": "pavlova-021961@postgrespro.ru", "phone": "+70830084993"}
0005432382632	F4D196	6444 486584	EKATERINA SOROKINA	{"phone": "+70648370786"}
0005432382633	4717D6	0577 795463	MARINA DANILOVA	{"phone": "+70781452188"}
0005432382634	CE283E	0982 279731	ARTEM PAVLOV	{"email": "artem_pavlov-11041961@postgrespro.ru", "phone": "+70530275777"}
0005432382635	4061D0	3677 654480	SVETLANA ZAYCEVA	{"email": "svetlana_zayceva_081973@postgrespro.ru", "phone": "+70509230764"}
0005432382636	658797	9547 168426	EVGENIY SMIRNOV	{"phone": "+70896374838"}
0005432382637	658797	1869 418705	OLEG CHERNOV	{"phone": "+70835149373"}
0005432382638	C0633E	5664 532957	VYACHESLAV GERASIMOV	{"phone": "+70918561110"}
0005432382639	C0633E	4638 980918	YULIYA ORLOVA	{"email": "yuliya-orlova.071963@postgrespro.ru", "phone": "+70753395109"}
0005432382640	0F213E	4215 627480	DAMIR ILIN	{"email": "ilin.damir-04021970@postgrespro.ru", "phone": "+70677210832"}
0005432382641	0F213E	6266 231211	MARIYA VLASOVA	{"email": "mariyavlasova-20051967@postgrespro.ru", "phone": "+70763283281"}
0005432382642	271865	0758 786199	LIDIYA KOROLEVA	{"phone": "+70369859380"}
0005432382643	0B0768	5076 695814	TATYANA SOKOLOVA	{"phone": "+70224402143"}
0005432382644	C14B6A	5064 286383	NIKOLAY KISELEV	{"phone": "+70475963281"}
0005432382645	C14B6A	3502 883461	VYACHESLAV GAVRILOV	{"phone": "+70479204824"}
0005432382646	83F748	7911 455419	NATALYA IVANOVA	{"phone": "+70997872265"}
0005432382647	83F748	9096 391979	IVAN FEDOROV	{"email": "i.fedorov.15101976@postgrespro.ru", "phone": "+70379314483"}
0005432382648	29CF40	7577 309633	VIKTOR ABRAMOV	{"phone": "+70018558103"}
0005432382649	19C1E8	9071 328441	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila1962@postgrespro.ru", "phone": "+70547578780"}
0005432382650	C83087	9701 773297	VLADIMIR ROMANOV	{"email": "romanov.v031971@postgrespro.ru", "phone": "+70839617023"}
0005432382651	D0D9F9	0541 062360	YULIYA ORLOVA	{"email": "yuliya.orlova.21071966@postgrespro.ru", "phone": "+70159306827"}
0005432382652	F8394E	9659 257419	SERGEY KUDRYASHOV	{"phone": "+70287110105"}
0005432382653	BCEF44	2444 765055	NATALYA MIRONOVA	{"email": "mironovan-1964@postgrespro.ru", "phone": "+70367616169"}
0005432382654	BF82D3	3989 311032	VYACHESLAV FOMIN	{"email": "fominvyacheslav-14011962@postgrespro.ru", "phone": "+70603686925"}
0005432382655	BF82D3	3742 090297	SVETLANA ALEKSEEVA	{"email": "alekseeva.s_08111979@postgrespro.ru", "phone": "+70840802795"}
0005432382656	330841	6056 639756	MARINA SOLOVEVA	{"phone": "+70249320273"}
0005432382657	B03362	2324 049477	SERGEY ANTONOV	{"email": "sergeyantonov-011975@postgrespro.ru", "phone": "+70692531897"}
0005432382658	78C49A	1148 780822	ALEKSEY SOROKIN	{"email": "aleksey.sorokin-1976@postgrespro.ru", "phone": "+70146617960"}
0005432382659	D19D57	3737 936816	IGOR TARASOV	{"email": "i_tarasov_1981@postgrespro.ru", "phone": "+70045328626"}
0005432382660	D19D57	4749 478795	ANATOLIY SOROKIN	{"phone": "+70652969390"}
0005432382661	3FE530	3279 029387	TATYANA MEDVEDEVA	{"phone": "+70493676168"}
0005432382662	3FE530	7965 297777	SERGEY POPOV	{"phone": "+70568597544"}
0005432382663	D0AA20	3057 322251	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey05061971@postgrespro.ru", "phone": "+70271712818"}
0005432382664	D0AA20	0317 629025	LIDIYA FROLOVA	{"phone": "+70895855453"}
0005432382665	E65CED	6634 876701	VALENTINA MIRONOVA	{"phone": "+70899307476"}
0005432382666	E65CED	2868 932814	VLADIMIR CHERNOV	{"phone": "+70228166918"}
0005432382667	44EA4D	7573 276858	NINA KOVALEVA	{"email": "nina-kovaleva.1971@postgrespro.ru", "phone": "+70834814695"}
0005432382668	44EA4D	3925 986453	VALENTINA SOROKINA	{"phone": "+70505245450"}
0005432382669	BCEC71	5794 852657	VITALIY TIKHONOV	{"email": "vitaliytikhonov-04091966@postgrespro.ru", "phone": "+70609496615"}
0005432382670	8B5DF9	9644 371630	YURIY MAKAROV	{"email": "ymakarov_05111959@postgrespro.ru", "phone": "+70015749448"}
0005432382671	D6D318	3415 067729	DARYA GUSEVA	{"email": "guseva.d-081977@postgrespro.ru", "phone": "+70488598159"}
0005432382672	D6D318	9798 479757	ALEKSANDR OSIPOV	{"phone": "+70519207427"}
0005432382673	679E2B	1562 178787	MARGARITA IVANOVA	{"email": "ivanova_m_01091976@postgrespro.ru", "phone": "+70036799950"}
0005432382674	F04842	1813 407648	ALEKSANDR GAVRILOV	{"email": "gavrilov-a-1963@postgrespro.ru", "phone": "+70752619804"}
0005432382675	9349E7	6339 593220	LYUDMILA KUZNECOVA	{"phone": "+70435882864"}
0005432382676	6F70B3	6615 679181	LYUBOV KALININA	{"phone": "+70168671070"}
0005432382677	6F70B3	7606 280542	ALLA ZAKHAROVA	{"email": "a.zakharova.1968@postgrespro.ru", "phone": "+70196815011"}
0005432382678	A1049C	7781 996229	NIKOLAY FROLOV	{"phone": "+70562504760"}
0005432382679	B6DAB2	2743 281273	NINA ZAKHAROVA	{"email": "nzakharova-1971@postgrespro.ru", "phone": "+70243845851"}
0005432382680	A7ABBE	6865 417056	EKATERINA MIKHAYLOVA	{"email": "mikhaylovaekaterina.041964@postgrespro.ru", "phone": "+70625528208"}
0005432382681	A7ABBE	7661 259226	MARIYA VOROBEVA	{"phone": "+70988254705"}
0005432382682	9666C5	2804 757177	ANATOLIY VOROBEV	{"phone": "+70348161226"}
0005432382683	9666C5	7754 594673	DMITRIY EGOROV	{"email": "dmitriyegorov.1972@postgrespro.ru", "phone": "+70109332042"}
0005432382684	E97975	7461 750946	RAISA FOMINA	{"phone": "+70507851559"}
0005432382685	C7EA4C	5645 059693	SERGEY KUZNECOV	{"email": "s_kuznecov.041979@postgrespro.ru", "phone": "+70267551691"}
0005432382686	C7EA4C	8981 488818	ANASTASIYA SEMENOVA	{"email": "semenova_a_011977@postgrespro.ru", "phone": "+70355140479"}
0005432382687	B3C054	1830 297216	VIKTOR YAKOVLEV	{"email": "yakovlev_viktor1978@postgrespro.ru", "phone": "+70737750399"}
0005432382688	B3C054	5752 304763	GALINA FADEEVA	{"email": "galina-fadeeva-06041982@postgrespro.ru", "phone": "+70585087416"}
0005432382689	C66FBC	1251 553814	ALEKSEY ZAKHAROV	{"phone": "+70718855191"}
0005432382690	C635CF	6638 298961	ALLA RYABOVA	{"email": "ryabova-a1975@postgrespro.ru", "phone": "+70211687362"}
0005432382691	E80E44	6247 685704	VYACHESLAV KUZNECOV	{"email": "kuznecov_vyacheslav_061975@postgrespro.ru", "phone": "+70852446600"}
0005432382692	613434	1417 695685	GENNADIY IVANOV	{"email": "ivanovg.081973@postgrespro.ru", "phone": "+70034331492"}
0005432382693	613434	3766 981338	NATALYA KOVALEVA	{"phone": "+70356717493"}
0005432382694	B51E84	8140 877945	OLGA KUZNECOVA	{"email": "kuznecova_o1975@postgrespro.ru", "phone": "+70895991785"}
0005432382695	B51E84	6234 694675	MARIYA KOZLOVA	{"phone": "+70266429425"}
0005432382696	B51E84	5242 654418	ALINA KALININA	{"phone": "+70484725368"}
0005432382697	64862E	3414 002504	VASILIY YAKOVLEV	{"email": "yakovlev.vasiliy-29031960@postgrespro.ru", "phone": "+70740594718"}
0005432382698	C73678	2937 592811	IVAN PAVLOV	{"email": "pavlovi_06011977@postgrespro.ru", "phone": "+70124595844"}
0005432382699	D82620	5794 642659	MARIYA ANDREEVA	{"phone": "+70225926082"}
0005432382700	8B6D2B	1266 880198	ANASTASIYA BORISOVA	{"phone": "+70074095187"}
0005432382701	9CC9A8	6238 898895	LYUDMILA FILATOVA	{"email": "l.filatova-011983@postgrespro.ru", "phone": "+70040122174"}
0005432382702	32D16D	0206 264371	SERGEY KUZMIN	{"phone": "+70870315101"}
0005432382703	866099	3910 514802	SERGEY KISELEV	{"email": "kiselev-sergey_1970@postgrespro.ru", "phone": "+70394331474"}
0005432382704	F22588	5808 766408	ARTEM ZAYCEV	{"email": "artemzaycev111965@postgrespro.ru", "phone": "+70065065054"}
0005432382705	F22588	2987 846713	SVETLANA VASILEVA	{"phone": "+70450883141"}
0005432382706	595118	1910 584446	LIDIYA ANTONOVA	{"email": "antonova-lidiya.04041965@postgrespro.ru", "phone": "+70620595055"}
0005432382707	595118	8931 195259	ANNA VASILEVA	{"phone": "+70953730476"}
0005432382708	7A8D3C	6766 354204	VALENTINA KOROLEVA	{"email": "koroleva-valentina1974@postgrespro.ru", "phone": "+70859244257"}
0005432382709	6A5D75	5458 012046	NIKITA KUDRYASHOV	{"email": "kudryashov.nikita_051977@postgrespro.ru", "phone": "+70132577699"}
0005432382710	6A5D75	7699 378452	GRIGORIY ANTONOV	{"email": "g-antonov-041971@postgrespro.ru", "phone": "+70837573855"}
0005432382711	36C157	2891 969702	YULIYA ISAEVA	{"phone": "+70759327810"}
0005432382712	36C157	9986 891516	SERGEY DENISOV	{"email": "sergey.denisov081983@postgrespro.ru", "phone": "+70985797070"}
0005432382713	6E45D9	2172 403599	MIKHAIL ALEKSANDROV	{"phone": "+70908240756"}
0005432382714	3876CF	5079 835259	NATALYA KOVALEVA	{"email": "natalya-kovaleva-17011980@postgrespro.ru", "phone": "+70999778817"}
0005432382715	41D29D	8492 122803	EVGENIY OSIPOV	{"phone": "+70041461101"}
0005432382716	B1E6EA	6180 743101	ELENA EGOROVA	{"phone": "+70610281053"}
0005432382717	E9BE65	1461 391580	IVAN GERASIMOV	{"email": "ivan-gerasimov031977@postgrespro.ru", "phone": "+70678479533"}
0005432382718	4D9FF7	5608 015035	NIKOLAY AFANASEV	{"email": "afanasev-nikolay-1962@postgrespro.ru", "phone": "+70553467466"}
0005432382719	36163C	8892 969340	KONSTANTIN SOLOVEV	{"phone": "+70828210460"}
0005432382720	D2828B	6275 905762	LARISA NAZAROVA	{"email": "nazarova-larisa-1974@postgrespro.ru", "phone": "+70390561570"}
0005432382721	48E61C	4270 106287	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva.22061973@postgrespro.ru", "phone": "+70488493407"}
0005432382722	48E61C	4593 532622	RIMMA KULIKOVA	{"phone": "+70904621019"}
0005432382723	A522BE	5945 422166	VASILIY EGOROV	{"email": "v.egorov21091964@postgrespro.ru", "phone": "+70315725042"}
0005432382724	E7F947	8362 214667	VLADIMIR BORISOV	{"phone": "+70838159546"}
0005432382725	E7F947	0332 541679	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana21071969@postgrespro.ru", "phone": "+70708875570"}
0005432382726	BBAB34	9772 132188	OLGA STEPANOVA	{"email": "stepanova.olga-051980@postgrespro.ru", "phone": "+70198320409"}
0005432382727	9FB042	3043 991444	IRINA KAZAKOVA	{"email": "irina.kazakova.07081977@postgrespro.ru", "phone": "+70953684341"}
0005432382728	ABEFE3	5458 354643	ANTONINA PETROVA	{"email": "a.petrova_18031957@postgrespro.ru", "phone": "+70737097572"}
0005432382729	ABEFE3	9585 050334	ALEKSANDR IVANOV	{"email": "aleksandrivanov03101976@postgrespro.ru", "phone": "+70142702592"}
0005432382730	628F04	5112 036744	OLGA SEMENOVA	{"email": "semenova.o-1974@postgrespro.ru", "phone": "+70495866257"}
0005432382731	1892B0	8099 206815	LARISA ANDREEVA	{"phone": "+70471916664"}
0005432382732	A49A24	9279 841506	YURIY KARPOV	{"phone": "+70045574047"}
0005432382733	CCE91E	9105 896073	NINA LEBEDEVA	{"phone": "+70631910853"}
0005432382734	AEC860	0493 551915	ANASTASIYA ZAKHAROVA	{"email": "anastasiya_zakharova1973@postgrespro.ru", "phone": "+70582275471"}
0005432382735	AEC860	1367 973423	TATYANA NIKITINA	{"email": "tatyana.nikitina_091979@postgrespro.ru", "phone": "+70750230952"}
0005432382736	001E66	6696 292842	VALERIYA MAKSIMOVA	{"phone": "+70247024103"}
0005432382737	F32BF0	8633 744758	SERGEY KUZMIN	{"email": "s-kuzmin-13081984@postgrespro.ru", "phone": "+70347438498"}
0005432382738	4B8DA5	3997 798078	ELENA KONOVALOVA	{"phone": "+70396454609"}
0005432382739	170FA7	7930 494988	ANNA ABRAMOVA	{"email": "abramova_anna-071978@postgrespro.ru", "phone": "+70710333492"}
0005432382740	170FA7	5873 916797	ELLA ZAYCEVA	{"phone": "+70553852436"}
0005432382741	B847D9	1535 180241	MAKSIM ZHUKOV	{"email": "zhukov-maksim_22121983@postgrespro.ru", "phone": "+70712040570"}
0005432382742	A01F74	0221 890218	ALEKSANDRA FILATOVA	{"email": "aleksandra-filatova-17041982@postgrespro.ru", "phone": "+70805809707"}
0005432382743	5BEEF1	7167 944075	DENIS SIDOROV	{"phone": "+70799676233"}
0005432382744	5BEEF1	4841 666922	KSENIYA KUZMINA	{"phone": "+70438176456"}
0005432382745	00C6F2	8129 249938	DMITRIY MIRONOV	{"email": "mironovd.091969@postgrespro.ru", "phone": "+70262313918"}
0005432382746	B3181D	0224 956840	VLADIMIR MIKHAYLOV	{"phone": "+70912316765"}
0005432382747	7AE58F	5376 982323	ANTONINA ARKHIPOVA	{"phone": "+70318283284"}
0005432382748	9981AF	0425 679668	ALEKSEY SOKOLOV	{"email": "sokolov_a011975@postgrespro.ru", "phone": "+70108934207"}
0005432382749	9981AF	8647 436743	ARMAN MELNIKOV	{"email": "melnikov-arman18031976@postgrespro.ru", "phone": "+70207441164"}
0005432382750	9981AF	7311 726536	EKATERINA RYABOVA	{"phone": "+70975232538"}
0005432382751	0DBA69	1168 944192	TIMUR ZHUKOV	{"email": "zhukov_timur.07011981@postgrespro.ru", "phone": "+70478482160"}
0005432382752	EA6319	4424 861215	ANDREY IVANOV	{"email": "andrey.ivanov-061972@postgrespro.ru", "phone": "+70806527424"}
0005432382753	EA6319	7089 043278	MARIYA ANDREEVA	{"email": "mariyaandreeva.121989@postgrespro.ru", "phone": "+70987037775"}
0005432382754	8A11B6	6768 161283	SERGEY FEDOTOV	{"phone": "+70716842310"}
0005432382755	9C0A5B	7437 364168	IRINA FILIPPOVA	{"email": "filippova-irina071983@postgrespro.ru", "phone": "+70221420300"}
0005432382756	2C4DC9	4445 466132	ANATOLIY IVANOV	{"phone": "+70703933112"}
0005432382757	C0BBFA	4732 635253	KONSTANTIN TIKHONOV	{"email": "k.tikhonov_1975@postgrespro.ru", "phone": "+70494522733"}
0005432382758	5096F6	8038 121658	TATYANA KAZAKOVA	{"email": "tkazakova_1974@postgrespro.ru", "phone": "+70139030543"}
0005432382759	55EA3B	6809 631325	VLADIMIR NAUMOV	{"phone": "+70400058488"}
0005432382760	4D61F7	5112 694723	OLGA GUSEVA	{"phone": "+70086325421"}
0005432382761	9DD5C6	9253 728311	SVETLANA ORLOVA	{"email": "orlova-s.041965@postgrespro.ru", "phone": "+70646258977"}
0005432382762	804D9F	9124 926540	NADEZHDA FADEEVA	{"email": "fadeeva_nadezhda.071984@postgrespro.ru", "phone": "+70536021809"}
0005432382763	804D9F	0066 845585	ROMAN TARASOV	{"email": "tarasov.r_1973@postgrespro.ru", "phone": "+70928341916"}
0005432382764	B2DD31	0061 866495	ALEKSANDR OSIPOV	{"phone": "+70955365854"}
0005432382765	B2DD31	4553 043723	ARTUR KOZLOV	{"email": "akozlov1969@postgrespro.ru", "phone": "+70412230358"}
0005432382766	B2DD31	7723 397541	MARGARITA KOZLOVA	{"phone": "+70528290942"}
0005432382767	86092A	6295 729327	KSENIYA DANILOVA	{"phone": "+70828734656"}
0005432382768	A98F41	1531 824511	OLGA MARTYNOVA	{"email": "martynova_olga-031972@postgrespro.ru", "phone": "+70577071181"}
0005432382769	A98F41	5678 765056	KIRILL KISELEV	{"email": "kiselev-kirill-091971@postgrespro.ru", "phone": "+70393144045"}
0005432382770	DBEFF8	4093 810659	EKATERINA BORISOVA	{"email": "borisovaekaterina1982@postgrespro.ru", "phone": "+70650601078"}
0005432382771	E4525A	9952 848882	YANA ZHURAVLEVA	{"phone": "+70356675829"}
0005432382772	E4525A	0150 402315	ALEKSANDR ZAYCEV	{"email": "zaycev-a-06021974@postgrespro.ru", "phone": "+70703798314"}
0005432382773	AE3487	6696 797264	NIKITA SERGEEV	{"email": "sergeev-n_051978@postgrespro.ru", "phone": "+70562417394"}
0005432382774	08C161	7620 709949	RAISA KOROLEVA	{"phone": "+70672104769"}
0005432382775	56C09F	8655 459187	LYUBOV NESTEROVA	{"phone": "+70726491225"}
0005432382776	F3FFFD	6160 131364	MARGARITA EGOROVA	{"phone": "+70684423221"}
0005432382777	362A9C	6727 484754	DENIS IVANOV	{"email": "denis-ivanov_28111974@postgrespro.ru", "phone": "+70190145347"}
0005432382778	362A9C	8160 761633	MIKHAIL MOROZOV	{"phone": "+70935301600"}
0005432382779	E74173	6650 132155	EKATERINA KONOVALOVA	{"phone": "+70143841136"}
0005432382780	768435	5461 172113	VYACHESLAV PAVLOV	{"email": "pavlovv_1976@postgrespro.ru", "phone": "+70235311836"}
0005432382781	768435	4935 363115	ALEKSANDR KUDRYASHOV	{"phone": "+70982884802"}
0005432382782	461412	9566 711481	VIKTOR BORISOV	{"phone": "+70891653093"}
0005432382783	4DA4BD	1672 519917	IVAN KONOVALOV	{"phone": "+70336455351"}
0005432382784	624C1B	4659 812481	GALINA NESTEROVA	{"email": "nesterova_galina.071970@postgrespro.ru", "phone": "+70316146945"}
0005432382785	CC83AF	6818 180901	MARINA KOROLEVA	{"email": "koroleva.marina-25011976@postgrespro.ru", "phone": "+70535830660"}
0005432382786	CC83AF	9822 892456	DILYARA FADEEVA	{"phone": "+70209854195"}
0005432382787	2E5636	2407 378624	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov_28021963@postgrespro.ru", "phone": "+70278705645"}
0005432382788	905029	5349 309691	VYACHESLAV POPOV	{"email": "v-popov_24101981@postgrespro.ru", "phone": "+70916897666"}
0005432382789	905029	7179 208466	IGOR VASILEV	{"email": "vasilev.i_1972@postgrespro.ru", "phone": "+70965998785"}
0005432382790	905029	0658 909751	YURIY NIKOLAEV	{"email": "y-nikolaev-1984@postgrespro.ru", "phone": "+70210009129"}
0005432382791	36D82A	6598 172871	RUSLAN NAZAROV	{"phone": "+70198327695"}
0005432382792	A24723	8890 191485	ANNA RYABOVA	{"phone": "+70660836409"}
0005432382793	A24723	9061 392419	ALEKSEY KULIKOV	{"email": "kulikova.27021968@postgrespro.ru", "phone": "+70172890154"}
0005432382794	A24723	2000 798396	SERGEY VLASOV	{"email": "vlasov_sergey-24101975@postgrespro.ru", "phone": "+70353262969"}
0005432382795	487DB6	7872 282392	NAILYA ANTONOVA	{"email": "n.antonova.1972@postgrespro.ru", "phone": "+70372149798"}
0005432382796	3C5D0B	2124 519223	IRINA MAKAROVA	{"phone": "+70310046015"}
0005432382797	F0CE5E	5549 199264	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr.081967@postgrespro.ru", "phone": "+70709916533"}
0005432382798	B20353	3358 765082	OLEG KUZMIN	{"email": "oleg.kuzmin.061978@postgrespro.ru", "phone": "+70875128840"}
0005432382799	B20353	3343 133204	ALSU FOMINA	{"email": "alsu-fomina06021974@postgrespro.ru", "phone": "+70577381894"}
0005432382800	4534F5	2993 947385	SERGEY KOZLOV	{"phone": "+70617069264"}
0005432382801	C3F297	8448 567615	EKATERINA KRASNOVA	{"phone": "+70506060686"}
0005432382802	65A575	1822 242888	ANNA MEDVEDEVA	{"phone": "+70312242387"}
0005432382803	65A575	7470 120779	YULIYA LOGINOVA	{"email": "loginova.y-22081966@postgrespro.ru", "phone": "+70829993652"}
0005432382804	ADC480	2202 161258	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov.28031984@postgrespro.ru", "phone": "+70883657571"}
0005432382805	98C994	9983 140080	KSENIYA VASILEVA	{"phone": "+70199267746"}
0005432382806	98C994	5510 719547	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr-24041966@postgrespro.ru", "phone": "+70983266535"}
0005432382807	1E9D25	9914 106609	VERA KUZNECOVA	{"phone": "+70914285363"}
0005432382808	1E9D25	8146 495332	SERGEY DENISOV	{"phone": "+70681180433"}
0005432382809	8BED74	1249 562833	VALENTINA SERGEEVA	{"email": "valentinasergeeva_021973@postgrespro.ru", "phone": "+70794179823"}
0005432382810	6AB0BF	3209 820376	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov_1967@postgrespro.ru", "phone": "+70704285206"}
0005432382811	6192AA	8555 292901	NATALIYA ORLOVA	{"phone": "+70512846429"}
0005432382812	74A33A	9630 098668	MARGARITA PAVLOVA	{"email": "pavlova_m-1980@postgrespro.ru", "phone": "+70267954205"}
0005432382813	49E18B	5283 995247	EVGENIY TIMOFEEV	{"email": "etimofeev041968@postgrespro.ru", "phone": "+70890581098"}
0005432382814	49E18B	1038 983961	LILIYA MATVEEVA	{"email": "matveeva_liliya1971@postgrespro.ru", "phone": "+70023878348"}
0005432382815	F94EB0	1678 815694	NINA ZOTOVA	{"email": "zotova-n_27041961@postgrespro.ru", "phone": "+70283539591"}
0005432382816	73759A	2260 927517	SERGEY VASILEV	{"email": "vasilevsergey051977@postgrespro.ru", "phone": "+70828434310"}
0005432382817	73759A	7171 748973	KSENIYA KOROLEVA	{"phone": "+70584652516"}
0005432382818	72346A	7367 746413	ALEKSANDR FEDOTOV	{"phone": "+70235840196"}
0005432382819	60FD77	3128 491971	NATALYA ANTONOVA	{"phone": "+70075134573"}
0005432382820	7B639C	0610 502694	SVETLANA SOROKINA	{"email": "svetlana-sorokina.1970@postgrespro.ru", "phone": "+70782811331"}
0005432382821	6D01A5	8075 733974	ELENA SOLOVEVA	{"email": "soloveva-e-02071964@postgrespro.ru", "phone": "+70484989488"}
0005432382822	6D01A5	8275 378215	VLADIMIR NOVIKOV	{"phone": "+70315347725"}
0005432382823	6D01A5	1336 708591	BORIS KISELEV	{"email": "kiselevb.051981@postgrespro.ru", "phone": "+70471772640"}
0005432382824	E9D6F7	8218 831946	ANNA OVCHINNIKOVA	{"email": "anna_ovchinnikova_08061976@postgrespro.ru", "phone": "+70282312102"}
0005432382825	7E1991	2777 882683	DMITRIY RODIONOV	{"phone": "+70740979620"}
0005432382826	ECA6D7	0506 266199	POLINA DENISOVA	{"phone": "+70195829303"}
0005432382827	B69CFC	8387 877020	SERGEY NAZAROV	{"phone": "+70357567719"}
0005432382828	EF9A9D	0481 934941	TATYANA KOLESNIKOVA	{"phone": "+70122175672"}
0005432382829	EF9A9D	9843 082130	KAMILLA KULIKOVA	{"phone": "+70032047567"}
0005432382830	EF9A9D	9510 842454	EVGENIY SAVELEV	{"email": "savelev_evgeniy-1979@postgrespro.ru", "phone": "+70009131509"}
0005432382831	391C3E	7059 486454	IVAN NAZAROV	{"phone": "+70999837732"}
0005432382832	CE0832	4977 158297	NIKOLAY KUZNECOV	{"phone": "+70962296926"}
0005432382833	24AA79	8489 379306	RAISA DMITRIEVA	{"phone": "+70754077315"}
0005432382834	60C11D	7007 178925	NATALYA LEBEDEVA	{"phone": "+70185166095"}
0005432382835	CE1A25	2790 157988	SERGEY MOISEEV	{"email": "smoiseev_1976@postgrespro.ru", "phone": "+70667827340"}
0005432382836	DF8B52	9437 157797	LYUBOV FROLOVA	{"phone": "+70957254779"}
0005432382837	1DA999	8993 392400	OLGA YAKOVLEVA	{"phone": "+70670773816"}
0005432382838	9DF3E7	3283 549538	GALINA MOROZOVA	{"email": "galina_morozova-021965@postgrespro.ru", "phone": "+70776701671"}
0005432382839	546E92	3599 705133	SERGEY SOROKIN	{"email": "sergey_sorokin17061981@postgrespro.ru", "phone": "+70188619426"}
0005432382840	546E92	3021 849287	ILYA FROLOV	{"email": "ilyafrolov1991@postgrespro.ru", "phone": "+70529737891"}
0005432382841	546E92	9782 127232	NATALYA POLYAKOVA	{"email": "natalyapolyakova1985@postgrespro.ru", "phone": "+70769626894"}
0005432382842	3EC264	5997 844160	DMITRIY FROLOV	{"phone": "+70541271913"}
0005432382843	6302A2	0874 788352	NADEZHDA MATVEEVA	{"email": "matveeva-n.051971@postgrespro.ru", "phone": "+70676891206"}
0005432382844	C353A3	4219 789321	ILDAR PAVLOV	{"phone": "+70169561303"}
0005432382845	D41252	8858 037853	ANNA TARASOVA	{"email": "anna-tarasova_1970@postgrespro.ru", "phone": "+70670256236"}
0005432382846	D41252	0410 280105	KSENIYA RYABOVA	{"phone": "+70543260317"}
0005432382847	809152	6218 168706	TAMARA ZHURAVLEVA	{"email": "tamarazhuravleva051969@postgrespro.ru", "phone": "+70828277931"}
0005432382848	96EED5	8304 352487	ALEKSANDR SOKOLOV	{"email": "sokolov.a-1974@postgrespro.ru", "phone": "+70085595215"}
0005432382849	C93134	8853 479140	VLADIMIR SCHERBAKOV	{"email": "v_scherbakov-121976@postgrespro.ru", "phone": "+70855901572"}
0005432382850	C93134	9703 176278	ARTUR ANTONOV	{"phone": "+70341572364"}
0005432382851	417855	7585 216243	NATALYA IVANOVA	{"email": "ivanovanatalya.091966@postgrespro.ru", "phone": "+70592065642"}
0005432382852	417855	4697 414328	VLADIMIR DMITRIEV	{"phone": "+70006471391"}
0005432382853	1E7883	1390 069947	LARISA DENISOVA	{"phone": "+70862063830"}
0005432382854	1E7883	9200 422899	IVAN NIKITIN	{"email": "nikitinivan_30051970@postgrespro.ru", "phone": "+70489815123"}
0005432382855	FF766D	4734 875820	MARIYA FOMINA	{"phone": "+70787557077"}
0005432382856	C11B9D	9440 450168	PETR SIDOROV	{"phone": "+70849348754"}
0005432382857	1A0B0B	4504 805894	EDUARD KISELEV	{"phone": "+70820192242"}
0005432382858	3E8C1D	8640 937265	EKATERINA IVANOVA	{"email": "ivanova_ekaterina_1967@postgrespro.ru", "phone": "+70959704741"}
0005432382859	76FB7F	2939 628018	GRIGORIY MELNIKOV	{"phone": "+70602925452"}
0005432382860	821D47	3946 370719	VYACHESLAV DENISOV	{"phone": "+70402928527"}
0005432382861	4AE5FA	1794 434400	MIKHAIL SIDOROV	{"phone": "+70177378599"}
0005432382862	4AE5FA	5624 264162	VARVARA KUZNECOVA	{"phone": "+70523513942"}
0005432382863	83D759	9383 205651	ARTEM SERGEEV	{"email": "artemsergeev_1974@postgrespro.ru", "phone": "+70046376633"}
0005432382864	C986E3	7602 042713	ALEKSEY MOROZOV	{"email": "a-morozov03041971@postgrespro.ru", "phone": "+70109478413"}
0005432382865	407326	5732 258605	YURIY MIRONOV	{"email": "ymironov_121983@postgrespro.ru", "phone": "+70284065497"}
0005432382866	8A6CA6	9172 432833	VYACHESLAV IVANOV	{"email": "vyacheslav.ivanov-1965@postgrespro.ru", "phone": "+70674040310"}
0005432382867	25176C	8948 367017	OLESYA MIRONOVA	{"email": "mironova_olesya.111982@postgrespro.ru", "phone": "+70794006350"}
0005432382868	25176C	3349 720316	ANTON KUZNECOV	{"phone": "+70808394148"}
0005432382869	6EB376	2461 350392	SERGEY AFANASEV	{"phone": "+70922938958"}
0005432382870	6EB376	4172 810844	DMITRIY SIDOROV	{"email": "dmitriy-sidorov-041974@postgrespro.ru", "phone": "+70462309380"}
0005432382871	227358	0273 163176	NINA ANISIMOVA	{"email": "n-anisimova-18101975@postgrespro.ru", "phone": "+70866904870"}
0005432382872	B440C6	4511 659053	EVGENIY NAZAROV	{"email": "enazarov.12041976@postgrespro.ru", "phone": "+70658841716"}
0005432382873	2C01E1	4357 265127	DIANA MOROZOVA	{"email": "diana.morozova.18011966@postgrespro.ru", "phone": "+70239501822"}
0005432382874	894D1D	7591 099586	ELENA VASILEVA	{"phone": "+70645482367"}
0005432382875	2C6E4C	5891 023791	NADEZHDA MATVEEVA	{"phone": "+70884679464"}
0005432382876	2C6E4C	1695 294443	NATALYA NAZAROVA	{"phone": "+70611425899"}
0005432382877	2C6E4C	7967 163960	EVGENIY GAVRILOV	{"phone": "+70401808269"}
0005432382878	2C6E4C	9582 234885	TATYANA KUZNECOVA	{"email": "kuznecova-t08081973@postgrespro.ru", "phone": "+70685629282"}
0005432382879	6A2BBA	7828 240591	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov1981@postgrespro.ru", "phone": "+70995259654"}
0005432382880	19D711	8174 111760	VALENTIN ZAKHAROV	{"email": "valentinzakharov.31011980@postgrespro.ru", "phone": "+70867500980"}
0005432382881	0CD987	3672 895341	SOFIYA ALEKSANDROVA	{"phone": "+70011479750"}
0005432382882	405B8B	6966 292279	EVGENIYA ROMANOVA	{"phone": "+70349536620"}
0005432382883	405B8B	1599 538088	OLEG ABRAMOV	{"phone": "+70556788760"}
0005432382884	405B8B	0276 936533	ANDREY VLASOV	{"phone": "+70769483116"}
0005432382885	F14110	7237 317094	ROZA KRASNOVA	{"phone": "+70257514449"}
0005432382886	9C1CFC	2235 236793	KONSTANTIN KUZMIN	{"email": "konstantin.kuzmin_031967@postgrespro.ru", "phone": "+70283027771"}
0005432382887	46E008	1901 498407	MARIYA ZOTOVA	{"email": "mariya.zotova.03121969@postgrespro.ru", "phone": "+70199708123"}
0005432382888	08DFFE	6685 108889	IRINA KISELEVA	{"email": "kiseleva.i-1975@postgrespro.ru", "phone": "+70889350125"}
0005432382889	97C294	6550 602450	ANDREY KOROLEV	{"phone": "+70577569689"}
0005432382890	046C62	0772 312814	YURIY YAKOVLEV	{"email": "yakovlevyuriy_01011972@postgrespro.ru", "phone": "+70946769308"}
0005432382891	9F1FDF	7438 012262	OLGA KOZLOVA	{"email": "kozlovaolga_1979@postgrespro.ru", "phone": "+70403151107"}
0005432382892	15E5F1	0015 679476	TATYANA ROMANOVA	{"email": "romanova-tatyana18021966@postgrespro.ru", "phone": "+70110743350"}
0005432382893	F59A21	6151 362956	GRIGORIY VOLKOV	{"email": "volkov.grigoriy-031974@postgrespro.ru", "phone": "+70779633216"}
0005432382894	8623CF	3709 283573	ALISA ROMANOVA	{"email": "alisa-romanova_23121971@postgrespro.ru", "phone": "+70190517863"}
0005432382895	0566C2	2421 047189	NADEZHDA VASILEVA	{"email": "n.vasileva101967@postgrespro.ru", "phone": "+70440401694"}
0005432382896	0566C2	5253 165026	GALINA SOLOVEVA	{"phone": "+70139815208"}
0005432382897	0AFFAE	6025 218956	OLGA ANTONOVA	{"email": "antonova_o.09111975@postgrespro.ru", "phone": "+70735299349"}
0005432382898	992B1F	4877 484942	LYUDMILA MAKSIMOVA	{"email": "lyudmilamaksimova1969@postgrespro.ru", "phone": "+70404699565"}
0005432382899	992B1F	6839 033476	DANIIL MEDVEDEV	{"email": "medvedev.d-03041968@postgrespro.ru", "phone": "+70438394169"}
0005432382900	F93133	8609 690557	SERGEY DMITRIEV	{"phone": "+70202179373"}
0005432382901	F93133	0095 032165	DZHAMILYA NIKITINA	{"email": "d-nikitina.081969@postgrespro.ru", "phone": "+70097686473"}
0005432382902	72BA69	7359 351680	DARYA POPOVA	{"email": "popovadarya.1971@postgrespro.ru", "phone": "+70960109774"}
0005432382903	78EAD3	1724 568562	ELENA EFREMOVA	{"phone": "+70107971411"}
0005432382904	64AD19	3280 691192	EKATERINA EFIMOVA	{"email": "e-efimova.27021978@postgrespro.ru", "phone": "+70766268584"}
0005432382905	DD8391	7809 085857	LIDIYA VOLKOVA	{"phone": "+70014637393"}
0005432382906	57C47E	8250 970495	TATYANA ANDREEVA	{"email": "andreeva-tatyana_1971@postgrespro.ru", "phone": "+70699822682"}
0005432382907	B82E44	5789 274227	NIKOLAY BONDARENKO	{"phone": "+70237940268"}
0005432382908	463728	5639 141130	KONSTANTIN DAVYDOV	{"email": "konstantindavydov-17061976@postgrespro.ru", "phone": "+70959313053"}
0005432382909	463728	8498 827633	YURIY GUSEV	{"email": "ygusev_091967@postgrespro.ru", "phone": "+70971830002"}
0005432382910	5CD362	3780 877358	TATYANA SOLOVEVA	{"email": "soloveva.tatyana.1973@postgrespro.ru", "phone": "+70985617870"}
0005432382911	5C0444	3631 605974	VALERIY ALEKSEEV	{"phone": "+70782160821"}
0005432382912	5EA3C2	2274 701624	VLADIMIR KUZNECOV	{"email": "v_kuznecov23061956@postgrespro.ru", "phone": "+70643909603"}
0005432382913	5EA3C2	6397 031560	OLGA OVCHINNIKOVA	{"email": "ovchinnikova-o_041968@postgrespro.ru", "phone": "+70439561545"}
0005432382914	966817	1225 815418	YURIY ANDREEV	{"phone": "+70581135975"}
0005432382915	966817	1786 379245	YURIY ZHURAVLEV	{"email": "yzhuravlev-1967@postgrespro.ru", "phone": "+70062981274"}
0005432382916	9760F0	5742 718776	ALEKSANDR NIKITIN	{"phone": "+70077120972"}
0005432382917	9760F0	4019 605878	NADEZHDA FILATOVA	{"email": "filatova.n10061955@postgrespro.ru", "phone": "+70109397533"}
0005432382918	2584E3	9223 362895	ALEKSANDR VASILEV	{"phone": "+70704411549"}
0005432382919	2584E3	4636 605749	MARGARITA GRISHINA	{"email": "grishina-m.01071979@postgrespro.ru", "phone": "+70314109295"}
0005432382920	8DD73E	1727 895895	SERGEY KISELEV	{"email": "kiselev-s-26051974@postgrespro.ru", "phone": "+70037492201"}
0005432382921	6DE30E	6717 833798	ANDREY SCHERBAKOV	{"email": "scherbakova.061981@postgrespro.ru", "phone": "+70990235143"}
0005432382922	6DE30E	6162 166353	IGOR VOLKOV	{"phone": "+70424969309"}
0005432382923	CC6D8E	7119 531767	KSENIYA KUZNECOVA	{"email": "kuznecova-kseniya1968@postgrespro.ru", "phone": "+70945857680"}
0005432382924	212002	2180 440765	VALERIY ZAYCEV	{"email": "vzaycev-1976@postgrespro.ru", "phone": "+70764846634"}
0005432382925	E6A8B0	7776 686970	OLEG GAVRILOV	{"email": "gavrilov_o.1977@postgrespro.ru", "phone": "+70540545377"}
0005432382926	E6A8B0	8441 303543	IRINA KULIKOVA	{"email": "i-kulikova.111977@postgrespro.ru", "phone": "+70498650388"}
0005432382927	38EBBC	5170 758497	DANILA BELOV	{"phone": "+70986277411"}
0005432382928	C6FFF2	3632 815456	GALINA FROLOVA	{"phone": "+70807463928"}
0005432382929	76B972	2230 419933	GALINA ALEKSEEVA	{"email": "galina_alekseeva_1968@postgrespro.ru", "phone": "+70063192235"}
0005432382930	1557DD	1967 750431	NATALIYA KUDRYASHOVA	{"phone": "+70575070453"}
0005432382931	417159	6638 295204	TAMARA RYABOVA	{"email": "tamara.ryabova_1972@postgrespro.ru", "phone": "+70685368583"}
0005432382932	2E2056	0173 083708	NIKITA MAKAROV	{"phone": "+70944714388"}
0005432382933	42B110	4900 728559	NIKOLAY GERASIMOV	{"email": "nikolay_gerasimov041980@postgrespro.ru", "phone": "+70355482326"}
0005432382934	60A5BC	4504 975356	TATYANA ZHURAVLEVA	{"email": "zhuravleva.tatyana-1978@postgrespro.ru", "phone": "+70405502785"}
0005432382935	681D81	0632 982536	DIANA YAKOVLEVA	{"phone": "+70494380743"}
0005432382936	EF4743	1966 153626	PAVEL KISELEV	{"email": "kiselevp18041974@postgrespro.ru", "phone": "+70925053397"}
0005432382937	EF4743	0921 608779	NATALYA KOMAROVA	{"email": "n_komarova.111987@postgrespro.ru", "phone": "+70091045833"}
0005432382938	ADAA51	0607 227912	SERGEY NOVIKOV	{"email": "novikov_sergey.101974@postgrespro.ru", "phone": "+70037600818"}
0005432382939	0CE344	3765 175144	ANTONINA ANDREEVA	{"email": "a-andreeva_24061982@postgrespro.ru", "phone": "+70573141013"}
0005432382940	F2CF1F	3986 660012	NINA KRASNOVA	{"phone": "+70683714615"}
0005432382941	3F1072	5712 763161	ELENA SAVELEVA	{"email": "e_saveleva.1975@postgrespro.ru", "phone": "+70993802947"}
0005432382942	9968BD	3672 275163	NINA NIKITINA	{"phone": "+70908860337"}
0005432382943	CC266C	0864 244353	NADEZHDA YAKOVLEVA	{"email": "yakovlevan-051970@postgrespro.ru", "phone": "+70488208704"}
0005432382944	1D468B	8988 399031	MARIYA IVANOVA	{"email": "ivanova.mariya06121974@postgrespro.ru", "phone": "+70512780315"}
0005432382945	DCF141	5497 258028	MAKSIM KRASNOV	{"phone": "+70474398789"}
0005432382946	DCF141	5208 143049	EKATERINA IVANOVA	{"email": "ivanova.ekaterina-24091952@postgrespro.ru", "phone": "+70088773939"}
0005432382947	2B6688	7515 614100	ARTUR KUZNECOV	{"email": "artur_kuznecov_011968@postgrespro.ru", "phone": "+70959074032"}
0005432382948	2B6688	4540 397615	EKATERINA MATVEEVA	{"phone": "+70920140792"}
0005432382949	2B6688	6147 460977	ANTON ALEKSEEV	{"phone": "+70539038949"}
0005432382950	1C73B2	8762 918031	NATALYA ZHUKOVA	{"email": "natalyazhukova.30071983@postgrespro.ru", "phone": "+70564837583"}
0005432382951	F512B4	9345 421939	ANDREY KOZLOV	{"email": "kozlov-andrey_30041979@postgrespro.ru", "phone": "+70476968143"}
0005432382952	03F740	8839 774809	BORIS DMITRIEV	{"phone": "+70896670861"}
0005432382953	DBF1FE	0432 904780	VERA SERGEEVA	{"email": "v.sergeeva21061966@postgrespro.ru", "phone": "+70954345735"}
0005432382954	DBF1FE	0718 355980	ELIZAVETA IVANOVA	{"phone": "+70958051712"}
0005432382955	3A6357	0218 325578	MARINA KUZMINA	{"phone": "+70673488712"}
0005432382956	E97CEE	9611 397050	NINA LAZAREVA	{"phone": "+70591959039"}
0005432382957	E97CEE	1377 165663	LYUDMILA ABRAMOVA	{"email": "abramova.lyudmila1972@postgrespro.ru", "phone": "+70094992210"}
0005432382958	CDD2C9	6847 095580	SERGEY KULIKOV	{"email": "s.kulikov_26091973@postgrespro.ru", "phone": "+70882934872"}
0005432382959	796CC1	0909 712618	OLGA SOROKINA	{"phone": "+70579589182"}
0005432382960	04F79F	6934 180206	DENIS MAKAROV	{"email": "makarov_d_14091973@postgrespro.ru", "phone": "+70868354328"}
0005432382961	FD1F7A	4072 292556	GALINA EGOROVA	{"phone": "+70332308922"}
0005432382962	D83285	7042 165668	IRINA ILINA	{"email": "irinailina-031956@postgrespro.ru", "phone": "+70305480195"}
0005432382963	D83285	1683 798109	NIKITA ROMANOV	{"phone": "+70327956860"}
0005432382964	D83285	2016 287778	TATYANA NAZAROVA	{"email": "nazarova_tatyana_04071974@postgrespro.ru", "phone": "+70842555726"}
0005432382965	F6E31E	4169 443818	MIKHAIL KISELEV	{"email": "m_kiselev-1968@postgrespro.ru", "phone": "+70860398857"}
0005432382966	5F1CD7	5563 750106	VALENTINA GERASIMOVA	{"email": "valentina-gerasimova-101971@postgrespro.ru", "phone": "+70545650800"}
0005432382967	985915	4765 286341	DMITRIY TIMOFEEV	{"phone": "+70910454639"}
0005432382968	985915	4768 519653	ALEKSEY NIKOLAEV	{"email": "aleksey.nikolaev.11071972@postgrespro.ru", "phone": "+70217224402"}
0005432382969	5C251D	2841 272897	PAVEL MIRONOV	{"email": "mironov-pavel_02011981@postgrespro.ru", "phone": "+70223162861"}
0005432382970	23CA6C	2965 251133	VYACHESLAV KONOVALOV	{"email": "v-konovalov-07061974@postgrespro.ru", "phone": "+70175766212"}
0005432382971	450D2B	9312 321512	DMITRIY DMITRIEV	{"email": "dmitriy.dmitriev-1963@postgrespro.ru", "phone": "+70432096609"}
0005432382972	450D2B	8978 503169	ANDREY NAZAROV	{"email": "nazarov_andrey.02071982@postgrespro.ru", "phone": "+70387542953"}
0005432382973	BBBDF4	5868 162870	ALEKSEY DAVYDOV	{"email": "a_davydov_011971@postgrespro.ru", "phone": "+70231504172"}
0005432382974	BBBDF4	4162 099726	VALERIY BORISOV	{"email": "borisovv1969@postgrespro.ru", "phone": "+70207589364"}
0005432382975	2D6CCA	7585 579913	DMITRIY NIKITIN	{"phone": "+70998333375"}
0005432382976	E0AF6E	5684 994412	DIANA LAZAREVA	{"phone": "+70338332404"}
0005432382977	3C9811	3464 507798	MARIYA TARASOVA	{"phone": "+70626557807"}
0005432382978	3C9811	6967 857344	OLGA POLYAKOVA	{"phone": "+70866106485"}
0005432382979	6A0EDA	6579 333475	GALINA STEPANOVA	{"email": "stepanova.g1972@postgrespro.ru", "phone": "+70292109971"}
0005432382980	94BAA2	0233 846533	NIKITA ISAEV	{"email": "isaev_nikita-13081966@postgrespro.ru", "phone": "+70722376124"}
0005432382981	B2CD0E	7768 293510	VLADIMIR SERGEEV	{"phone": "+70631039193"}
0005432382982	B2CD0E	8701 609633	MIKHAIL KUZNECOV	{"phone": "+70002269680"}
0005432382983	177B20	7291 729235	MARAT FOMIN	{"phone": "+70776988627"}
0005432382984	CF0839	9790 440155	MARINA VASILEVA	{"email": "marina.vasileva_031961@postgrespro.ru", "phone": "+70669776176"}
0005432382985	CF0839	2747 536850	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda-1986@postgrespro.ru", "phone": "+70864877661"}
0005432382986	792D8C	8794 962950	ANNA PETROVA	{"phone": "+70981860980"}
0005432382987	AD5A71	0273 006090	NATALYA BORISOVA	{"phone": "+70583600261"}
0005432382988	3D9F17	8878 754619	OLGA BORISOVA	{"email": "olgaborisova.1979@postgrespro.ru", "phone": "+70710981675"}
0005432382989	B27B70	1635 891149	SERGEY DAVYDOV	{"email": "davydovsergey_08081980@postgrespro.ru", "phone": "+70182405148"}
0005432382990	ECCDF8	5689 704795	ZOYA OSIPOVA	{"phone": "+70818163564"}
0005432382991	8A3BC0	7310 092089	KRISTINA ANTONOVA	{"phone": "+70283715384"}
0005432382992	8A3BC0	0913 118811	TAMARA BOGDANOVA	{"phone": "+70297977762"}
0005432382993	2EFD2C	6131 302678	GENNADIY POPOV	{"email": "popov.gennadiy-1974@postgrespro.ru", "phone": "+70737913878"}
0005432382994	2EFD2C	3836 565656	GALINA ZOTOVA	{"email": "galina_zotova-011969@postgrespro.ru", "phone": "+70390956508"}
0005432382995	42CFF6	0746 242618	ARTEM GORBUNOV	{"phone": "+70629676816"}
0005432382996	42CFF6	7675 095667	ELVINA VOROBEVA	{"email": "elvina-vorobeva-17081971@postgrespro.ru", "phone": "+70530963943"}
0005432382997	2F12C1	6767 975558	LYUDMILA SOKOLOVA	{"email": "sokolova-l16121979@postgrespro.ru", "phone": "+70735143746"}
0005432382998	058BC5	0898 685689	ALEKSANDR IVANOV	{"email": "ivanova_121983@postgrespro.ru", "phone": "+70914857978"}
0005432382999	82B125	9355 490223	OLGA GORBUNOVA	{"phone": "+70815529692"}
0005432383000	8F3498	7350 306207	VIKTOR NIKOLAEV	{"phone": "+70773310062"}
0005432383001	E9FC40	5446 688229	SERGEY POPOV	{"phone": "+70353921060"}
0005432383002	E9FC40	7777 187176	NIKOLAY AFANASEV	{"email": "afanasev-n1973@postgrespro.ru", "phone": "+70254622446"}
0005432383003	72C126	1211 810373	EVGENIY POPOV	{"email": "evgeniy.popov-16051963@postgrespro.ru", "phone": "+70032838606"}
0005432383004	DD18C0	7194 076643	YURIY ZAYCEV	{"phone": "+70122600320"}
0005432383005	DD18C0	5302 872437	ANZHELIKA IVANOVA	{"email": "a.ivanova081974@postgrespro.ru", "phone": "+70977979015"}
0005432383006	D2A7DC	1416 275862	NIKOLAY MAKAROV	{"phone": "+70619205897"}
0005432383007	D2A7DC	6313 614187	ANATOLIY CHERNOV	{"email": "chernov-anatoliy_23051967@postgrespro.ru", "phone": "+70220203155"}
0005432383008	D2A7DC	2777 081440	LYUBOV VASILEVA	{"email": "vasilevalyubov.06061973@postgrespro.ru", "phone": "+70481573593"}
0005432383009	D2A7DC	3680 479264	NATALYA SAVELEVA	{"phone": "+70840360268"}
0005432383010	CCB040	1726 158080	VERA DANILOVA	{"email": "vera_danilova-011971@postgrespro.ru", "phone": "+70700012278"}
0005432383011	9407CA	6908 758101	ALEVTINA MOROZOVA	{"phone": "+70382110030"}
0005432383012	ADEE23	1423 392807	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana-14051974@postgrespro.ru", "phone": "+70179440617"}
0005432383013	03F424	3901 114886	ANTON ILIN	{"email": "ilina-18081974@postgrespro.ru", "phone": "+70375789665"}
0005432383014	03F424	3209 235196	ANASTASIYA KONOVALOVA	{"email": "anastasiya.konovalova21031957@postgrespro.ru", "phone": "+70095860912"}
0005432383015	03F424	5649 922885	EVGENIYA ILINA	{"email": "evgeniyailina-20031964@postgrespro.ru", "phone": "+70955807757"}
0005432383016	F564BB	7939 956998	OLGA MELNIKOVA	{"email": "melnikova_olga.18031970@postgrespro.ru", "phone": "+70971715121"}
0005432383017	4CE8C0	6820 737233	VIKTOR RODIONOV	{"phone": "+70174603001"}
0005432383018	CF4AD8	7887 398712	IRINA AFANASEVA	{"phone": "+70001386175"}
0005432383019	951E6A	3573 485735	VERA GAVRILOVA	{"phone": "+70832097806"}
0005432383020	951E6A	1175 681560	VALERIY DAVYDOV	{"email": "v_davydov_061972@postgrespro.ru", "phone": "+70290514043"}
0005432383021	2FF30D	8260 827568	SVETLANA NIKITINA	{"email": "nikitina.svetlana_061970@postgrespro.ru", "phone": "+70498688460"}
0005432383022	4F6C6D	1863 854248	LYUDMILA KUDRYASHOVA	{"phone": "+70738493883"}
0005432383023	3A9932	9649 077656	IRINA NOVIKOVA	{"email": "novikova-irina.14071966@postgrespro.ru", "phone": "+70964009888"}
0005432383024	3A9932	8789 566511	ANNA POTAPOVA	{"phone": "+70212372755"}
0005432383025	3A9932	9839 865085	ELIZAVETA GERASIMOVA	{"email": "elizaveta-gerasimova.071961@postgrespro.ru", "phone": "+70234111050"}
0005432383026	22C451	1426 684205	IVAN FEDOROV	{"email": "fedorov_ivan_1981@postgrespro.ru", "phone": "+70574815430"}
0005432383027	22C451	3855 062944	ALEKSEY IVANOV	{"email": "alekseyivanov.051976@postgrespro.ru", "phone": "+70079559985"}
0005432383028	103487	1291 174844	TAISIYA MIKHAYLOVA	{"email": "mikhaylova_taisiya-12051968@postgrespro.ru", "phone": "+70036566709"}
0005432383029	3609AC	3152 888872	DENIS KAZAKOV	{"email": "kazakovd28111969@postgrespro.ru", "phone": "+70503371057"}
0005432383030	CD8895	6605 857774	VIKTORIYA TROFIMOVA	{"email": "v-trofimova-11011972@postgrespro.ru", "phone": "+70722360021"}
0005432383031	58E4E5	6094 381705	VLADIMIR VOLKOV	{"phone": "+70980723259"}
0005432383032	3E3540	2232 918077	VALENTIN MARTYNOV	{"email": "martynov_v-21041977@postgrespro.ru", "phone": "+70911898454"}
0005432383033	16E8AF	7414 516621	VIKTORIYA NAZAROVA	{"phone": "+70876103007"}
0005432383034	44027C	1096 644395	ARINA MAKAROVA	{"email": "makarova-arina_071970@postgrespro.ru", "phone": "+70643272594"}
0005432383035	725FE4	5173 121062	LIDIYA NIKITINA	{"email": "nikitina-lidiya-1981@postgrespro.ru", "phone": "+70637754536"}
0005432383036	725FE4	1266 256619	GALINA IVANOVA	{"email": "ivanovagalina_1984@postgrespro.ru", "phone": "+70690800257"}
0005432383037	71AA30	5310 538186	LYUBOV MIRONOVA	{"phone": "+70543344091"}
0005432383038	71AA30	9439 357082	ANDREY SCHERBAKOV	{"phone": "+70308757413"}
0005432383039	24E42E	0450 556139	YAROSLAV KULIKOV	{"phone": "+70305473114"}
0005432383040	24E42E	8082 830674	DENIS MELNIKOV	{"phone": "+70298026077"}
0005432383041	B9B1A0	5796 388701	GALINA BORISOVA	{"phone": "+70449423015"}
0005432383042	D5A4FA	9459 711324	SVETLANA KULIKOVA	{"email": "kulikovas.01111973@postgrespro.ru", "phone": "+70660045101"}
0005432383043	D5A4FA	8689 334583	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov_1959@postgrespro.ru", "phone": "+70947107919"}
0005432383044	D73880	9549 842859	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova_06041958@postgrespro.ru", "phone": "+70896122112"}
0005432383045	D73880	0460 707175	TAMARA ABRAMOVA	{"phone": "+70832217681"}
0005432383046	D73880	6840 001952	SVETLANA KRASNOVA	{"email": "s_krasnova.26051963@postgrespro.ru", "phone": "+70502791259"}
0005432383047	F2F8DC	6739 703027	KIRA MATVEEVA	{"phone": "+70587000712"}
0005432383048	14EDCB	1388 960804	VALENTINA ILINA	{"email": "v-ilina-081983@postgrespro.ru", "phone": "+70520897587"}
0005432383049	4D9736	6702 282436	ARTEM STEPANOV	{"email": "stepanovartem-16121963@postgrespro.ru", "phone": "+70976043815"}
0005432383050	6236F9	3879 610794	SVETLANA ORLOVA	{"phone": "+70472145371"}
0005432383051	AA7E37	9419 911259	ALENA IVANOVA	{"phone": "+70307929917"}
0005432383052	AA7E37	4386 723805	ROMAN KUDRYASHOV	{"phone": "+70171463320"}
0005432383053	784745	3347 967841	DARYA YAKOVLEVA	{"phone": "+70392787234"}
0005432383054	784745	2568 358647	ANASTASIYA SAVELEVA	{"phone": "+70893442891"}
0005432383055	784745	0957 062989	MAKSIM DAVYDOV	{"email": "mdavydov.16101977@postgrespro.ru", "phone": "+70898010735"}
0005432383056	E145C5	9509 270913	ROMAN NOVIKOV	{"email": "novikovr_111965@postgrespro.ru", "phone": "+70922837762"}
0005432383057	7268D5	5721 978607	ZOYA TARASOVA	{"phone": "+70051976182"}
0005432383058	AAF8B0	1377 648072	VITALIY FEDOTOV	{"email": "fedotovv.29091978@postgrespro.ru", "phone": "+70764572791"}
0005432383059	AAF8B0	4098 513081	GALINA SEMENOVA	{"email": "semenova_galina28051971@postgrespro.ru", "phone": "+70263694688"}
0005432383060	C4127C	4491 949331	SERGEY IVANOV	{"email": "sergey-ivanov_21091970@postgrespro.ru", "phone": "+70815886187"}
0005432383061	EE7B5A	1206 412048	SNEZHANA SMIRNOVA	{"phone": "+70002877605"}
0005432383062	EE7B5A	5876 699389	ALEKSANDRA EGOROVA	{"email": "aleksandra-egorova111966@postgrespro.ru", "phone": "+70912452947"}
0005432383063	AD4B1B	2381 574776	SVETLANA FILATOVA	{"phone": "+70363620921"}
0005432383064	83AD3D	9629 142239	YURIY MOROZOV	{"email": "morozov-yuriy031976@postgrespro.ru", "phone": "+70328438296"}
0005432383065	EF3982	5471 580563	NADEZHDA ZAKHAROVA	{"phone": "+70455216129"}
0005432383066	EF3982	4510 619863	DAMIR IVANOV	{"email": "ivanovdamir.051965@postgrespro.ru", "phone": "+70910314541"}
0005432383067	C566F5	8953 852783	ANNA DMITRIEVA	{"phone": "+70018707382"}
0005432383068	8C78BC	6068 532110	VYACHESLAV KRASNOV	{"email": "vyacheslav.krasnov.25031980@postgrespro.ru", "phone": "+70727731759"}
0005432383069	A53CFA	8811 515569	ALEKSEY DAVYDOV	{"email": "davydov-aleksey_1967@postgrespro.ru", "phone": "+70449159359"}
0005432383070	A53CFA	7441 697631	EVGENIY IVANOV	{"phone": "+70092740444"}
0005432383071	A53CFA	6371 978770	ANASTASIYA MATVEEVA	{"email": "matveeva.a-08041969@postgrespro.ru", "phone": "+70326054155"}
0005432383072	4F4F49	1764 126454	OLGA NOVIKOVA	{"email": "novikova-olga_051983@postgrespro.ru", "phone": "+70156305967"}
0005432383073	869330	8176 740335	IBRAGIM VASILEV	{"email": "vasilev_ibragim091976@postgrespro.ru", "phone": "+70446449345"}
0005432383074	4B2222	1250 401542	PAVEL SOKOLOV	{"email": "sokolov.pavel061973@postgrespro.ru", "phone": "+70224475695"}
0005432383075	4B2222	6156 277894	ALEKSEY IVANOV	{"email": "ivanov_a-05051975@postgrespro.ru", "phone": "+70461546850"}
0005432383076	1ECA3B	3678 961411	RIMMA POPOVA	{"email": "rimma.popova_101972@postgrespro.ru", "phone": "+70832893169"}
0005432383077	83D256	1281 622523	ALEKSANDRA IVANOVA	{"email": "ivanova-aleksandra-16021978@postgrespro.ru", "phone": "+70007331970"}
0005432383078	9849D4	3654 382218	TAMARA KULIKOVA	{"email": "tamara_kulikova.07111973@postgrespro.ru", "phone": "+70696415824"}
0005432383079	25482D	9120 593796	NIKITA GORBUNOV	{"phone": "+70583329515"}
0005432383080	9BCECD	9162 968300	ANNA SAVELEVA	{"email": "saveleva.a-16091965@postgrespro.ru", "phone": "+70568879426"}
0005432383081	9BCECD	3881 393056	MAKSIM RODIONOV	{"email": "m_rodionov-1978@postgrespro.ru", "phone": "+70545878529"}
0005432383082	6AE09C	8212 957448	ALEKSEY KUZNECOV	{"email": "kuznecov.a18121969@postgrespro.ru", "phone": "+70042764009"}
0005432383083	9E42D8	8498 910043	ALEKSANDR BELOV	{"phone": "+70113159797"}
0005432383084	17F846	1288 503885	ALEKSANDR BARANOV	{"email": "aleksandr_baranov_24031973@postgrespro.ru", "phone": "+70229157573"}
0005432383085	BCAFEE	0776 969140	NIKOLAY MEDVEDEV	{"email": "medvedev_nikolay-1961@postgrespro.ru", "phone": "+70512088393"}
0005432383086	A02493	8690 256166	NATALYA KUZNECOVA	{"phone": "+70120167501"}
0005432383087	673B79	0339 521359	MARINA BORISOVA	{"phone": "+70928323512"}
0005432383088	60E64C	8218 283029	DENIS KUDRYASHOV	{"email": "kudryashov-d1967@postgrespro.ru", "phone": "+70046550050"}
0005432383089	FEBD16	2319 150827	OLGA MAKAROVA	{"email": "makarova.olga_011967@postgrespro.ru", "phone": "+70884415149"}
0005432383090	B189C4	1617 114852	GALINA VASILEVA	{"phone": "+70074528380"}
0005432383091	AF6CA1	9299 947965	SOFIYA AKIMOVA	{"phone": "+70054218999"}
0005432383092	0F9E91	0907 121689	KRISTINA POLYAKOVA	{"email": "polyakova-k_25111975@postgrespro.ru", "phone": "+70527389443"}
0005432383093	017E71	9797 178016	ALEKSEY VASILEV	{"phone": "+70754397235"}
0005432383094	017E71	3643 680390	FELIKS FOMIN	{"phone": "+70223755815"}
0005432383095	F6FF87	0792 786543	LYUDMILA ABRAMOVA	{"phone": "+70108203298"}
0005432383096	F6FF87	5105 053192	VERA MALYSHEVA	{"email": "v.malysheva_1964@postgrespro.ru", "phone": "+70070464713"}
0005432383097	85566D	0660 377311	SVYATOSLAV SOKOLOV	{"phone": "+70042752979"}
0005432383098	85566D	2101 584457	YULIYA POPOVA	{"phone": "+70515927357"}
0005432383099	86DE6A	0398 978355	YURIY RODIONOV	{"email": "yuriy_rodionov.051974@postgrespro.ru", "phone": "+70849421259"}
0005432383100	86DE6A	9215 327792	PETR MELNIKOV	{"email": "petr-melnikov_1969@postgrespro.ru", "phone": "+70160424784"}
0005432383101	8CC2CF	7281 666923	ANATOLIY KOZLOV	{"email": "akozlov.14101964@postgrespro.ru", "phone": "+70622385543"}
0005432383102	899247	2018 380868	ALEKSANDR KOROLEV	{"phone": "+70451542262"}
0005432383103	EA4A67	5721 270275	GALINA ZHUKOVA	{"email": "galina_zhukova.07011981@postgrespro.ru", "phone": "+70742942005"}
0005432383104	635C4E	3187 331503	OLGA GAVRILOVA	{"email": "o.gavrilova_1967@postgrespro.ru", "phone": "+70330536112"}
0005432383105	C34E19	2113 230099	YAROSLAVA POPOVA	{"email": "popovayaroslava.29101972@postgrespro.ru", "phone": "+70657550258"}
0005432383106	688A2C	5864 906718	ANATOLIY KONOVALOV	{"phone": "+70867111436"}
0005432383107	803184	7946 081659	EVGENIY EGOROV	{"phone": "+70169395627"}
0005432383108	157260	0121 090691	ANDREY SAVELEV	{"phone": "+70414976154"}
0005432383109	712B7B	1209 656992	VASILIY NIKOLAEV	{"phone": "+70554604797"}
0005432383110	F612C2	7903 868830	GALINA SOLOVEVA	{"phone": "+70572068883"}
0005432383111	F612C2	0466 708736	OLGA MALYSHEVA	{"phone": "+70548474739"}
0005432383112	BA34C8	0005 771394	YURIY ALEKSEEV	{"email": "y.alekseev-1979@postgrespro.ru", "phone": "+70650228102"}
0005432383113	9B631E	3282 742385	NATALIYA ZHUKOVA	{"phone": "+70295222894"}
0005432383114	9B631E	2610 889216	NADEZHDA IVANOVA	{"email": "n-ivanova-02011976@postgrespro.ru", "phone": "+70982753801"}
0005432383115	915919	3565 060562	ANDREY KUZNECOV	{"phone": "+70809430193"}
0005432383116	C40433	3784 240266	ALEKSANDR ORLOV	{"phone": "+70003533397"}
0005432383117	C40433	6515 593762	GALINA POTAPOVA	{"email": "potapova_galina_111968@postgrespro.ru", "phone": "+70824327223"}
0005432383118	F9DE09	2587 026081	NIKOLAY KRASNOV	{"phone": "+70932860973"}
0005432383119	F9DE09	4066 868433	IVAN KOZLOV	{"email": "ivan-kozlov08071968@postgrespro.ru", "phone": "+70754863641"}
0005432383120	0CBCA7	4418 294134	LYUDMILA ANDREEVA	{"phone": "+70711323522"}
0005432383121	464D4A	6558 909799	GYUZEL SCHERBAKOVA	{"email": "scherbakova_g111968@postgrespro.ru", "phone": "+70376175739"}
0005432383122	7F6DFE	1909 735056	VALENTINA SMIRNOVA	{"phone": "+70536751994"}
0005432383123	7F6DFE	1477 221370	VLADISLAV SHEVCHENKO	{"email": "v-shevchenko.011976@postgrespro.ru", "phone": "+70972545135"}
0005432383124	7F6DFE	8623 573596	VALENTINA KUDRYASHOVA	{"email": "v_kudryashova_1958@postgrespro.ru", "phone": "+70827961429"}
0005432383125	B097CC	5838 403788	ALEKSANDRA ABRAMOVA	{"phone": "+70252341126"}
0005432383126	B097CC	2734 786498	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina091982@postgrespro.ru", "phone": "+70649611062"}
0005432383127	121682	7464 779359	ALEKSANDR MIKHAYLOV	{"phone": "+70664201032"}
0005432383128	121682	6083 706452	NIKOLAY DENISOV	{"email": "n.denisov-081984@postgrespro.ru", "phone": "+70378738483"}
0005432383129	5DFD71	3321 873215	VLADIMIR ZAYCEV	{"email": "zaycev-v_02021972@postgrespro.ru", "phone": "+70926227402"}
0005432383130	0E6418	2770 401047	LYUDMILA KULIKOVA	{"email": "kulikovalyudmila.20051973@postgrespro.ru", "phone": "+70799199015"}
0005432383131	ED8378	2001 927932	OLGA ZAYCEVA	{"email": "o_zayceva_1977@postgrespro.ru", "phone": "+70597761258"}
0005432383132	B32D2F	7612 941205	OLGA ZAKHAROVA	{"email": "olga-zakharova1968@postgrespro.ru", "phone": "+70666526630"}
0005432383133	BC2481	0949 905940	ELENA GAVRILOVA	{"email": "e-gavrilova1969@postgrespro.ru", "phone": "+70705124526"}
0005432383134	BC2481	9513 194763	YAROSLAV MAKSIMOV	{"phone": "+70437321045"}
0005432383135	7A9821	7932 730825	SERGEY PETROV	{"email": "s_petrov.011979@postgrespro.ru", "phone": "+70419898896"}
0005432383136	206FB8	9108 239939	EVGENIY VASILEV	{"phone": "+70941204752"}
0005432383137	2D53C4	2280 274640	IGOR SAVELEV	{"email": "i-savelev-15111973@postgrespro.ru", "phone": "+70338362452"}
0005432383138	2D53C4	9856 315733	TATYANA KUZNECOVA	{"phone": "+70812162116"}
0005432383139	BC378A	6882 167737	VLADIMIR SOKOLOV	{"email": "vladimirsokolov.021974@postgrespro.ru", "phone": "+70413823853"}
0005432383140	BC378A	3188 120892	ELENA POTAPOVA	{"email": "elena.potapova.081965@postgrespro.ru", "phone": "+70873036133"}
0005432383141	FCBB9B	2045 692008	RUSLAN ZAKHAROV	{"email": "zakharov_ruslan1973@postgrespro.ru", "phone": "+70005331759"}
0005432383142	799CA8	8946 340670	MIKHAIL MIKHAYLOV	{"email": "mikhaylovm_121969@postgrespro.ru", "phone": "+70023110747"}
0005432383143	799CA8	5846 972821	EGOR SCHERBAKOV	{"email": "egor-scherbakov.061977@postgrespro.ru", "phone": "+70761266958"}
0005432383144	126843	2031 470667	ALEKSANDR PETROV	{"email": "petrov-aleksandr22051962@postgrespro.ru", "phone": "+70570129123"}
0005432383145	126843	8668 915329	NATALYA MOROZOVA	{"phone": "+70335408504"}
0005432383146	3267DF	1448 688699	DIANA ROMANOVA	{"phone": "+70701653855"}
0005432383147	B1F038	8762 731191	VIKTOR MAKAROV	{"phone": "+70384858507"}
0005432383148	B1F038	2563 139241	LARISA FOMINA	{"email": "larisa.fomina.14071981@postgrespro.ru", "phone": "+70621004472"}
0005432383149	8473B3	5651 921441	ROMAN ILIN	{"phone": "+70183581141"}
0005432383150	8473B3	0522 763863	LIDIYA LOGINOVA	{"phone": "+70678099704"}
0005432383151	59D4D1	0575 796837	IRINA NAZAROVA	{"email": "irina.nazarova021965@postgrespro.ru", "phone": "+70931070397"}
0005432383152	E2221F	6299 623927	NADEZHDA GAVRILOVA	{"phone": "+70258695983"}
0005432383153	E2221F	4563 183678	ALEKSEY KARPOV	{"email": "karpova_051966@postgrespro.ru", "phone": "+70031175038"}
0005432383154	E2221F	8917 014082	TATYANA ALEKSANDROVA	{"phone": "+70398268895"}
0005432383155	5989BD	8404 232363	TAMARA VOROBEVA	{"phone": "+70044052862"}
0005432383156	DD5594	9961 835466	OLGA SCHERBAKOVA	{"phone": "+70172010923"}
0005432383157	07B062	1475 841842	SERGEY KULIKOV	{"phone": "+70952768339"}
0005432383158	07B062	0985 832620	VLADISLAV KUZMIN	{"email": "vladislav_kuzmin.03051969@postgrespro.ru", "phone": "+70992182867"}
0005432383159	3F8E87	6884 161426	DANIL ILIN	{"phone": "+70478029625"}
0005432383160	C8B59A	1506 690245	YURIY SCHERBAKOV	{"phone": "+70857051947"}
0005432383161	C8B59A	6019 055323	VLADIMIR MAKAROV	{"email": "vladimir_makarov-1972@postgrespro.ru", "phone": "+70002291983"}
0005432383162	18E44D	6602 637258	IVAN MAKSIMOV	{"phone": "+70777259263"}
0005432383163	BDF84B	5334 026427	SERGEY FOMIN	{"phone": "+70072846234"}
0005432383164	2C49EF	9458 050405	RUZALIYA FADEEVA	{"phone": "+70800852292"}
0005432383165	C8CE51	4368 631455	SAMVEL MOROZOV	{"phone": "+70977800177"}
0005432383166	C8CE51	4913 630783	ANDREY GERASIMOV	{"phone": "+70096415681"}
0005432383167	A2A82B	1342 733775	VLADIMIR MOISEEV	{"phone": "+70785766518"}
0005432383168	0AE0DF	0158 077076	VADIM VOROBEV	{"email": "vadim-vorobev-1982@postgrespro.ru", "phone": "+70640970800"}
0005432383169	6B37B2	1122 304276	VLADIMIR KARPOV	{"phone": "+70602858290"}
0005432383170	E2FAAF	8774 289347	DENIS NIKOLAEV	{"email": "nikolaevd.25111969@postgrespro.ru", "phone": "+70051878464"}
0005432383171	E2FAAF	4663 110413	ANNA PAVLOVA	{"phone": "+70825994662"}
0005432383172	4BE0AC	0551 920066	SERGEY EGOROV	{"email": "egorovsergey-1977@postgrespro.ru", "phone": "+70166887205"}
0005432383173	7DBA4C	5345 304569	ANGELINA ALEKSEEVA	{"phone": "+70251586406"}
0005432383174	7DBA4C	4047 868942	OLGA SOLOVEVA	{"phone": "+70996338519"}
0005432383175	8B3100	7549 959206	DARYA KUZNECOVA	{"email": "darya-kuznecova.111988@postgrespro.ru", "phone": "+70924996028"}
0005432383176	E01C11	6859 498698	ALEKSEY NOVIKOV	{"phone": "+70210865533"}
0005432383177	E01C11	7882 358577	DIANA BELOVA	{"phone": "+70402656273"}
0005432383178	219A32	6424 819492	OLGA MIKHAYLOVA	{"phone": "+70444055539"}
0005432383179	A8002A	0623 286715	NINA MELNIKOVA	{"email": "nmelnikova021967@postgrespro.ru", "phone": "+70331372455"}
0005432383180	1D198C	7937 561920	SVETLANA NIKITINA	{"phone": "+70400007994"}
0005432383181	B80C52	1790 076023	ANGELINA EGOROVA	{"phone": "+70829713213"}
0005432383182	155D23	5700 015589	VLADIMIR MOROZOV	{"email": "v_morozov-091959@postgrespro.ru", "phone": "+70623620716"}
0005432383183	C1E398	7186 778270	FEDOR MOROZOV	{"email": "f_morozov071986@postgrespro.ru", "phone": "+70515126594"}
0005432383184	D1BFA7	6373 362589	LYUDMILA ISAEVA	{"email": "l-isaeva02121974@postgrespro.ru", "phone": "+70791659076"}
0005432383185	D4D3C2	7418 324356	ANATOLIY SAVELEV	{"phone": "+70729892807"}
0005432383186	D4D3C2	8897 242549	ALEKSANDR ORLOV	{"email": "orlov_aleksandr-31121975@postgrespro.ru", "phone": "+70072148239"}
0005432383187	CB16F0	9968 691676	MARGARITA NAZAROVA	{"phone": "+70749926412"}
0005432383188	CB16F0	7407 465164	ELENA MOROZOVA	{"email": "morozovae-091968@postgrespro.ru", "phone": "+70934014078"}
0005432383189	1E612B	8712 074841	KSENIYA POLYAKOVA	{"email": "polyakova_kseniya021981@postgrespro.ru", "phone": "+70754766530"}
0005432383190	C3DB0B	9139 405385	MAKSIM SIDOROV	{"phone": "+70662808580"}
0005432383191	1EAA15	9511 280586	NATALYA IVANOVA	{"phone": "+70072186913"}
0005432383192	D9B6F8	9339 032237	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov1983@postgrespro.ru", "phone": "+70453314432"}
0005432383193	13B426	6914 663237	ALEKSEY NAZAROV	{"email": "nazarov.a-1979@postgrespro.ru", "phone": "+70379837987"}
0005432383194	001FA1	9497 094330	TAMARA NOVIKOVA	{"email": "novikovat.11031979@postgrespro.ru", "phone": "+70167450705"}
0005432383195	53D01D	5012 104692	VLADIMIR SIDOROV	{"email": "sidorov-vladimir_021978@postgrespro.ru", "phone": "+70411301017"}
0005432383196	53D01D	7536 629242	MARIYA EFREMOVA	{"phone": "+70677559236"}
0005432383197	AD6016	0631 282089	LIDIYA ISAEVA	{"email": "lidiyaisaeva.1963@postgrespro.ru", "phone": "+70314330948"}
0005432383198	36BD92	4078 009122	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay-021981@postgrespro.ru", "phone": "+70941847588"}
0005432383199	6371E2	4420 956294	VLADIMIR NAUMOV	{"phone": "+70890979887"}
0005432383200	EFAD36	9965 442647	TATYANA NOVIKOVA	{"email": "novikova-tatyana_18061979@postgrespro.ru", "phone": "+70870589532"}
0005432383201	1140A6	3789 024762	RAISA NIKITINA	{"email": "rnikitina041961@postgrespro.ru", "phone": "+70405867083"}
0005432383202	1BD5B2	4664 026498	ELENA TIKHONOVA	{"email": "tikhonovaelena.061968@postgrespro.ru", "phone": "+70027966468"}
0005432383203	1BD5B2	5000 365202	VALERIYA PETROVA	{"email": "valeriya_petrova-091972@postgrespro.ru", "phone": "+70985242587"}
0005432383204	91141A	8971 916640	VALENTINA ANISIMOVA	{"phone": "+70457821628"}
0005432383205	91141A	8441 627903	VLADIMIR VLASOV	{"email": "vladimirvlasov071973@postgrespro.ru", "phone": "+70317961145"}
0005432383206	C5E496	6379 358190	MIKHAIL BELOV	{"email": "belov_m.1973@postgrespro.ru", "phone": "+70317954820"}
0005432383207	A00930	3345 782294	NIKOLAY ALEKSEEV	{"email": "alekseevn.1975@postgrespro.ru", "phone": "+70939763510"}
0005432383208	A00930	9245 019161	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a.091987@postgrespro.ru", "phone": "+70382457361"}
0005432383209	F555F2	5739 038450	TATYANA SOKOLOVA	{"phone": "+70708825670"}
0005432383210	F555F2	6491 924307	ANASTASIYA IVANOVA	{"phone": "+70005944892"}
0005432383211	21159D	0822 786768	ALEKSEY ILIN	{"email": "ailin_11081974@postgrespro.ru", "phone": "+70371751501"}
0005432383212	76DBB7	6705 620620	LEONID TARASOV	{"email": "leonid_tarasov1980@postgrespro.ru", "phone": "+70412677520"}
0005432383213	E1F699	9505 259176	EVGENIY KOZLOV	{"email": "e-kozlov_011973@postgrespro.ru", "phone": "+70179286290"}
0005432383214	BD18E6	7185 774394	DENIS NAZAROV	{"phone": "+70106752607"}
0005432383215	4DCBBF	7860 317375	NIKOLAY VOLKOV	{"email": "nvolkov_11031974@postgrespro.ru", "phone": "+70464255517"}
0005432383216	600D36	6466 584531	ALEKSANDRA VLASOVA	{"email": "vlasova.aleksandra081978@postgrespro.ru", "phone": "+70867714281"}
0005432383217	FAD252	7026 246164	ANDREY TARASOV	{"email": "a-tarasov.03111963@postgrespro.ru", "phone": "+70263818294"}
0005432383218	FAD252	9244 575463	NATALYA EGOROVA	{"phone": "+70888437323"}
0005432383219	3BF0CA	5162 856986	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_02031975@postgrespro.ru", "phone": "+70477803453"}
0005432383220	3BF0CA	0804 198533	POLINA ZHUKOVA	{"phone": "+70374480884"}
0005432383221	3BF0CA	8029 869322	YURIY MAKAROV	{"phone": "+70940253566"}
0005432383222	695C71	1248 670294	GALINA MEDVEDEVA	{"phone": "+70919229738"}
0005432383223	695C71	9709 944044	DMITRIY ZAYCEV	{"email": "dmitriy-zaycev.1965@postgrespro.ru", "phone": "+70869841983"}
0005432383224	D4CB5B	4204 218489	TATYANA NIKIFOROVA	{"phone": "+70865553716"}
0005432383225	96A92A	1797 075044	OLGA SEMENOVA	{"email": "semenovao.14101976@postgrespro.ru", "phone": "+70472502147"}
0005432383226	A94A69	3618 460398	OLEG SAVELEV	{"phone": "+70095046433"}
0005432383227	A94A69	6755 325913	NATALYA DENISOVA	{"email": "ndenisova-051957@postgrespro.ru", "phone": "+70215211239"}
0005432383228	C34DF5	0134 452048	IGOR TIMOFEEV	{"email": "timofeev.i_1976@postgrespro.ru", "phone": "+70703398775"}
0005432383229	C1A053	3063 549168	SVETLANA KOZLOVA	{"phone": "+70879063738"}
0005432383230	5DEBF4	0452 735257	DARYA ROMANOVA	{"phone": "+70917197115"}
0005432383231	0DB0F3	8736 438891	ILDAR KRASNOV	{"email": "krasnovildar.081981@postgrespro.ru", "phone": "+70432250532"}
0005432383232	3D2DB9	6631 566252	GENNADIY NIKOLAEV	{"email": "nikolaevg.1975@postgrespro.ru", "phone": "+70849040947"}
0005432383233	CDEBE6	5956 117666	NADEZHDA GRISHINA	{"email": "nadezhda.grishina_06061965@postgrespro.ru", "phone": "+70232968131"}
0005432383234	CDEBE6	3228 284105	PAVEL ANTONOV	{"email": "pavel_antonov-1978@postgrespro.ru", "phone": "+70621356311"}
0005432383235	76B78F	1416 992873	TAMARA ZAKHAROVA	{"phone": "+70395104182"}
0005432383236	76B78F	5648 356336	PELAGEYA KOROLEVA	{"email": "p.koroleva121965@postgrespro.ru", "phone": "+70487451675"}
0005432383237	10E0F1	0990 218412	VERA BORISOVA	{"email": "borisova.vera_011970@postgrespro.ru", "phone": "+70701457703"}
0005432383238	96082E	3632 978231	MAKSIM DAVYDOV	{"phone": "+70003930830"}
0005432383239	96082E	6447 037922	DARYA NESTEROVA	{"email": "nesterovadarya121965@postgrespro.ru", "phone": "+70601274995"}
0005432383240	2DB3B0	8019 618315	IVAN IVANOV	{"email": "i_ivanov-12041969@postgrespro.ru", "phone": "+70970429633"}
0005432383241	706205	5902 665423	VLADIMIR BELOV	{"phone": "+70023970611"}
0005432383242	706205	9951 956053	MARIYA FILIPPOVA	{"phone": "+70144544715"}
0005432383243	706205	4812 725159	ANTON ZHURAVLEV	{"phone": "+70517648205"}
0005432383244	F2D074	7966 299992	NIKOLAY KOZLOV	{"email": "kozlovn-081961@postgrespro.ru", "phone": "+70281058777"}
0005432383245	561645	9830 485025	IGOR BORISOV	{"phone": "+70518659097"}
0005432383246	372ED5	3106 638315	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov_17051969@postgrespro.ru", "phone": "+70536867918"}
0005432383247	9708D7	3750 928897	MIKHAIL VASILEV	{"email": "mikhail_vasilev-081975@postgrespro.ru", "phone": "+70060993891"}
0005432383248	8DFF95	1040 734022	ELIZAVETA MIRONOVA	{"phone": "+70806556772"}
0005432383249	9BC7A5	8992 790013	MARIYA ZAKHAROVA	{"email": "zakharova.m_12061974@postgrespro.ru", "phone": "+70694489433"}
0005432383250	257041	8935 646812	RUSLAN MOROZOV	{"email": "morozov.ruslan091980@postgrespro.ru", "phone": "+70476019283"}
0005432383251	257041	0051 016436	VIKTORIYA SIDOROVA	{"email": "v_sidorova_031975@postgrespro.ru", "phone": "+70118949022"}
0005432383252	3D532B	7715 789685	NINA BOGDANOVA	{"phone": "+70899329949"}
0005432383253	3D532B	6306 506199	TATYANA STEPANOVA	{"email": "tatyana_stepanova_1969@postgrespro.ru", "phone": "+70229339612"}
0005432383254	EF613A	5874 304748	TAMARA BELOVA	{"phone": "+70118942145"}
0005432383255	04C310	1672 899362	ANNA IVANOVA	{"phone": "+70860742659"}
0005432383256	04C310	8731 865429	DENIS MEDVEDEV	{"phone": "+70848940459"}
0005432383257	04C310	7442 003427	VENERA IVANOVA	{"email": "venera.ivanova-111977@postgrespro.ru", "phone": "+70803937867"}
0005432383258	843CC5	5024 113720	ANDREY TARASOV	{"email": "tarasova_081967@postgrespro.ru", "phone": "+70461965184"}
0005432383259	843CC5	1157 954708	ANTONINA FROLOVA	{"phone": "+70210235524"}
0005432383260	021A41	6396 538298	ALEKSANDR MATVEEV	{"email": "matveev-a.101975@postgrespro.ru", "phone": "+70343521195"}
0005432383261	6226CA	9684 301708	SVETLANA ANDREEVA	{"phone": "+70274439436"}
0005432383262	64519B	5319 464581	ALENA SAVELEVA	{"email": "alena-saveleva1978@postgrespro.ru", "phone": "+70687254998"}
0005432383263	5C8659	3493 724708	ANASTASIYA NIKOLAEVA	{"phone": "+70664586398"}
0005432383264	CEE2FC	2259 875383	DMITRIY ALEKSEEV	{"email": "alekseev_dmitriy_1972@postgrespro.ru", "phone": "+70149829492"}
0005432383265	AF3012	8428 399966	NIKOLAY MATVEEV	{"email": "matveev.n.21081979@postgrespro.ru", "phone": "+70944924784"}
0005432383266	AF3012	4912 152881	GUZEL TARASOVA	{"phone": "+70921741460"}
0005432383267	AF3012	4838 357246	OKSANA SEMENOVA	{"email": "semenovao-23091970@postgrespro.ru", "phone": "+70187690922"}
0005432383268	70BEAA	2123 990989	GENNADIY GORBUNOV	{"phone": "+70817215086"}
0005432383269	70BEAA	9061 255878	VIKTORIYA STEPANOVA	{"email": "viktoriya_stepanova-1979@postgrespro.ru", "phone": "+70445490212"}
0005432383270	1A9275	0830 094226	STEPAN FOMIN	{"email": "fomins_1980@postgrespro.ru", "phone": "+70303942535"}
0005432383271	61A34D	7037 511252	VLADIMIR MEDVEDEV	{"phone": "+70602105616"}
0005432383272	61A34D	0682 456445	ANNA CHERNOVA	{"email": "chernovaanna1975@postgrespro.ru", "phone": "+70928112636"}
0005432383273	9968D5	2337 608024	ILYA GORBUNOV	{"phone": "+70667397623"}
0005432383274	9968D5	9108 383520	STANISLAV VOLKOV	{"phone": "+70175269183"}
0005432383275	9968D5	5202 990021	EVGENIY SEMENOV	{"email": "semenov.evgeniy.15021965@postgrespro.ru", "phone": "+70728065590"}
0005432383276	0AE59C	6225 008135	VALERIY OSIPOV	{"phone": "+70297616527"}
0005432383277	0AE59C	8747 291721	DARYA CHERNOVA	{"phone": "+70437408657"}
0005432383278	80DCC3	8692 095360	NATALIYA KOMAROVA	{"phone": "+70245298137"}
0005432383279	A28B90	3696 499239	VALENTINA ALEKSEEVA	{"email": "alekseeva.v1975@postgrespro.ru", "phone": "+70870204621"}
0005432383280	F7C4AE	4520 356947	KRISTINA ORLOVA	{"phone": "+70342357389"}
0005432383281	F7C4AE	8758 417481	NIKOLAY MEDVEDEV	{"email": "nikolay.medvedev_1981@postgrespro.ru", "phone": "+70801148362"}
0005432383282	57296C	4227 874681	NIKOLAY GORBUNOV	{"phone": "+70579763716"}
0005432383283	57296C	9561 058859	KIRILL KRASNOV	{"email": "krasnovkirill_19011972@postgrespro.ru", "phone": "+70907125769"}
0005432383284	032B98	3310 816801	VLADIMIR PETROV	{"phone": "+70893521376"}
0005432383285	0BCDF1	8358 906568	VERA BORISOVA	{"email": "veraborisova06051978@postgrespro.ru", "phone": "+70599814982"}
0005432383286	6DFC4A	4740 439458	ALEKSEY ANDREEV	{"email": "andreev-a_1968@postgrespro.ru", "phone": "+70544680512"}
0005432383287	6642C2	0892 960755	OLGA ZOTOVA	{"email": "zotova_o.1971@postgrespro.ru", "phone": "+70124457436"}
0005432383288	6642C2	9853 800799	KONSTANTIN SIDOROV	{"email": "k-sidorov-10111965@postgrespro.ru", "phone": "+70326940741"}
0005432383289	3BA295	3974 458568	SVETLANA KUZNECOVA	{"email": "s-kuznecova1976@postgrespro.ru", "phone": "+70368429856"}
0005432383290	E2CC85	9522 667035	EKATERINA ALEKSANDROVA	{"phone": "+70688094032"}
0005432383291	BB349F	6469 953837	TATYANA DENISOVA	{"email": "denisova_t.28081968@postgrespro.ru", "phone": "+70692811276"}
0005432383292	464958	3343 082408	ANDREY VASILEV	{"phone": "+70827411064"}
0005432383293	55DB8E	1102 647952	VALENTINA POLYAKOVA	{"phone": "+70109912135"}
0005432383294	8E6C1D	8898 742203	ANATOLIY PETROV	{"email": "anatoliy_petrov_16081977@postgrespro.ru", "phone": "+70962329024"}
0005432383295	C0BD3F	2879 789983	ALEFTINA SCHERBAKOVA	{"email": "scherbakova_a_11101976@postgrespro.ru", "phone": "+70701677331"}
0005432383296	F702BF	5336 621439	VITALIY MAKSIMOV	{"phone": "+70731943973"}
0005432383297	4AD28B	7748 709720	DENIS NIKITIN	{"phone": "+70439399380"}
0005432383298	83D4FC	2432 637807	ULYANA FROLOVA	{"email": "frolova.ulyana09031973@postgrespro.ru", "phone": "+70099662845"}
0005432383299	9881C5	6507 689989	ALEKSANDR DMITRIEV	{"phone": "+70088238020"}
0005432383300	9881C5	8090 575616	EVGENIY SOKOLOV	{"email": "sokolov-e-11011983@postgrespro.ru", "phone": "+70376861365"}
0005432383301	8CC96F	3719 819964	MARAT TARASOV	{"phone": "+70990562719"}
0005432383302	165E4D	4055 254340	SOFIYA KALININA	{"email": "s_kalinina_25061978@postgrespro.ru", "phone": "+70565537971"}
0005432383303	12BA6F	0735 131955	ALEKSEY BARANOV	{"email": "baranov_a.1971@postgrespro.ru", "phone": "+70355551449"}
0005432383304	12BA6F	3617 385020	IRINA KONOVALOVA	{"email": "irina_konovalova.1966@postgrespro.ru", "phone": "+70390345939"}
0005432383305	2CB9F4	6870 468781	ELIZAVETA SIDOROVA	{"email": "sidorova_e.1968@postgrespro.ru", "phone": "+70002491872"}
0005432383306	C7BE01	7237 281183	NADEZHDA FOMINA	{"email": "fomina.n-18041975@postgrespro.ru", "phone": "+70357930345"}
0005432383307	CEF063	3719 530834	TATYANA FILATOVA	{"email": "filatova_t_14051953@postgrespro.ru", "phone": "+70849573734"}
0005432383308	2D291B	8530 593518	ALEKSANDR SCHERBAKOV	{"phone": "+70862614828"}
0005432383309	145EAC	2100 810265	NADEZHDA ALEKSANDROVA	{"email": "n.aleksandrova-08111976@postgrespro.ru", "phone": "+70529366081"}
0005432383310	63C932	4140 072290	GENNADIY KOZLOV	{"email": "kozlov_gennadiy_06061983@postgrespro.ru", "phone": "+70548177454"}
0005432383311	3788AF	3625 410451	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev.25031966@postgrespro.ru", "phone": "+70204829919"}
0005432383312	3788AF	4020 854617	LEONID ROMANOV	{"phone": "+70446312503"}
0005432383313	2519EC	6421 118616	EGOR BORISOV	{"phone": "+70186550442"}
0005432383314	E54E30	4727 340096	NADEZHDA FROLOVA	{"email": "n.frolova.031971@postgrespro.ru", "phone": "+70396795282"}
0005432383315	E54E30	3738 855616	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr091971@postgrespro.ru", "phone": "+70195427212"}
0005432383316	A43BAE	2845 950154	IRINA KOROLEVA	{"email": "koroleva_i-1973@postgrespro.ru", "phone": "+70474482191"}
0005432383317	8BE6EA	8042 869811	NIKOLAY KUZNECOV	{"email": "kuznecovn-10081968@postgrespro.ru", "phone": "+70140485319"}
0005432383318	1D9F42	9889 413051	DMITRIY ALEKSEEV	{"phone": "+70120834121"}
0005432383319	09E88B	8998 855325	SERGEY MEDVEDEV	{"phone": "+70252958320"}
0005432383320	D12DA2	2872 687510	ANDREY PAVLOV	{"phone": "+70824572080"}
0005432383321	D12DA2	7889 037287	TATYANA DANILOVA	{"phone": "+70760098471"}
0005432383322	8A793F	9366 664601	ALEKSANDR BARANOV	{"email": "a.baranov1975@postgrespro.ru", "phone": "+70669285285"}
0005432383323	A3A2D2	2829 148772	PETR SCHERBAKOV	{"email": "scherbakovpetr_1969@postgrespro.ru", "phone": "+70790435356"}
0005432383324	1B11A7	8378 162858	YULIYA PETROVA	{"email": "petrova-y-1976@postgrespro.ru", "phone": "+70220569544"}
0005432383325	1B11A7	8870 001361	ALEKSANDR VASILEV	{"email": "vasilev_a_29101971@postgrespro.ru", "phone": "+70717507381"}
0005432383326	997D33	2885 694169	NIKOLAY ZHURAVLEV	{"email": "nikolay_zhuravlev_1963@postgrespro.ru", "phone": "+70974891160"}
0005432383327	93F93F	7422 370586	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey-14081969@postgrespro.ru", "phone": "+70432224434"}
0005432383328	529BDC	8583 426471	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr_1967@postgrespro.ru", "phone": "+70471697825"}
0005432383329	74E148	8598 737664	OKSANA FEDOROVA	{"email": "fedorova_oksana1980@postgrespro.ru", "phone": "+70996720812"}
0005432383330	E9F01B	0449 180203	BORIS VASILEV	{"phone": "+70423726339"}
0005432383331	DB1611	2749 063927	NATALIYA MEDVEDEVA	{"phone": "+70397956268"}
0005432383332	DB1611	0720 310074	NATALIYA PETROVA	{"email": "npetrova28021967@postgrespro.ru", "phone": "+70781898623"}
0005432383333	4B8214	5793 152998	KLAVDIYA MARTYNOVA	{"email": "martynova-k17121980@postgrespro.ru", "phone": "+70354099338"}
0005432383334	E40E76	8873 801529	OLGA ZAYCEVA	{"email": "zayceva.o14021976@postgrespro.ru", "phone": "+70689220867"}
0005432383335	E00146	0537 372570	YULIYA TIKHONOVA	{"email": "y.tikhonova_21101975@postgrespro.ru", "phone": "+70560741562"}
0005432383336	996C71	2571 705436	VIKTOR SCHERBAKOV	{"phone": "+70684803224"}
0005432383337	C0F3AC	7900 697293	IRAIDA KUZNECOVA	{"phone": "+70280183303"}
0005432383338	CAF5CC	3432 976506	DARYA FEDOROVA	{"email": "darya.fedorova08061985@postgrespro.ru", "phone": "+70250577982"}
0005432383339	CCAE1D	1365 135272	KONSTANTIN ZAKHAROV	{"phone": "+70903331689"}
0005432383340	CC8BC5	3801 279860	ELENA POLYAKOVA	{"phone": "+70790860466"}
0005432383341	587943	3323 104256	RUSTAM POPOV	{"email": "rustam_popov.07021982@postgrespro.ru", "phone": "+70058770767"}
0005432383342	1BA23F	3867 207733	DMITRIY SOROKIN	{"email": "d_sorokin_1981@postgrespro.ru", "phone": "+70080019068"}
0005432383343	7061CE	1394 194415	EGOR KONOVALOV	{"email": "ekonovalov-16111969@postgrespro.ru", "phone": "+70861823077"}
0005432383344	4626A1	6611 205360	VALERIYA SERGEEVA	{"email": "v-sergeeva_1956@postgrespro.ru", "phone": "+70812049199"}
0005432383345	4626A1	4593 104165	ANDREY GUSEV	{"phone": "+70964241290"}
0005432383346	B809A4	8629 490024	IRINA NIKOLAEVA	{"phone": "+70171102081"}
0005432383347	B809A4	1921 844222	KSENIYA YAKOVLEVA	{"phone": "+70846444560"}
0005432383348	4F0E77	4329 075952	YULIYA EFREMOVA	{"email": "yuliya-efremova-051971@postgrespro.ru", "phone": "+70613505207"}
0005432383349	4F0E77	2838 251102	KONSTANTIN IVANOV	{"phone": "+70826615470"}
0005432383350	A7A853	3858 014362	TATYANA KUZNECOVA	{"email": "kuznecova_t091967@postgrespro.ru", "phone": "+70676733418"}
0005432383351	F0175F	6768 606493	IGOR SAVELEV	{"email": "savelev_i.031980@postgrespro.ru", "phone": "+70016020446"}
0005432383352	688D2D	3968 097277	VLADIMIR VOLKOV	{"phone": "+70714119208"}
0005432383353	E575A8	1986 292978	OLGA GAVRILOVA	{"phone": "+70767299877"}
0005432383354	0B4848	3385 802028	YAROSLAV POPOV	{"email": "popov_yaroslav.26031968@postgrespro.ru", "phone": "+70397191610"}
0005432383355	CB7C3B	8306 408914	DMITRIY IVANOV	{"email": "divanov.25111959@postgrespro.ru", "phone": "+70086824633"}
0005432383356	CB7C3B	4749 439226	TATYANA STEPANOVA	{"email": "stepanovatatyana_1958@postgrespro.ru", "phone": "+70782957251"}
0005432383357	29BFC1	8184 244525	RAISA KUDRYASHOVA	{"email": "raisa-kudryashova-1977@postgrespro.ru", "phone": "+70412876081"}
0005432383358	29BFC1	3027 843234	VALERIY KUDRYASHOV	{"email": "v_kudryashov-121980@postgrespro.ru", "phone": "+70361514012"}
0005432383359	61745A	8020 145043	NATALYA YAKOVLEVA	{"phone": "+70322211123"}
0005432383360	61745A	4646 387474	NATALYA KAZAKOVA	{"email": "n_kazakova.111956@postgrespro.ru", "phone": "+70691047225"}
0005432383361	E756B9	4206 837611	DMITRIY RODIONOV	{"email": "drodionov.1979@postgrespro.ru", "phone": "+70649906663"}
0005432383362	4F0354	0706 590823	POLINA SOKOLOVA	{"phone": "+70836148773"}
0005432383363	532A62	8037 075049	LARISA GRISHINA	{"email": "lgrishina-08041980@postgrespro.ru", "phone": "+70083386966"}
0005432383364	35D6E6	9685 579666	IRINA EGOROVA	{"email": "i.egorova_061979@postgrespro.ru", "phone": "+70137054025"}
0005432383365	01E922	0560 155934	ALENA KUZMINA	{"email": "kuzmina_a.1967@postgrespro.ru", "phone": "+70352378719"}
0005432383366	90892B	3138 520563	MIKHAIL NIKITIN	{"phone": "+70555864590"}
0005432383367	58D9A1	2091 781855	DMITRIY VOLKOV	{"phone": "+70583269331"}
0005432383368	BC27DF	0872 217081	ALEKSANDR GORBUNOV	{"phone": "+70037978284"}
0005432383369	35F931	3357 171101	ANASTASIYA SMIRNOVA	{"phone": "+70859600020"}
0005432383370	C83B37	2857 503741	GRIGORIY IVANOV	{"phone": "+70296692838"}
0005432383371	92D344	2104 962414	YURIY ANTONOV	{"email": "antonov.y1983@postgrespro.ru", "phone": "+70875156762"}
0005432383372	92D344	1287 069652	OLESYA KOZLOVA	{"phone": "+70506146694"}
0005432383373	09B320	2981 403066	YULIYA VASILEVA	{"phone": "+70811394319"}
0005432383374	09B320	8932 899987	ELENA SOLOVEVA	{"email": "soloveva-e-25021975@postgrespro.ru", "phone": "+70874394529"}
0005432383375	4CC1FB	2156 777252	BORIS VASILEV	{"phone": "+70904686235"}
0005432383376	4CC1FB	7076 208418	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr1970@postgrespro.ru", "phone": "+70961185254"}
0005432383377	5E9908	9592 332438	ANDREY MOISEEV	{"email": "moiseev-a30081976@postgrespro.ru", "phone": "+70864076400"}
0005432383378	0922B5	4530 586373	ANGELINA GERASIMOVA	{"email": "gerasimovaa.02061986@postgrespro.ru", "phone": "+70480666692"}
0005432383379	0922B5	8410 397451	LARISA TARASOVA	{"phone": "+70771856388"}
0005432383380	C555EA	4088 638294	VLADIMIR FILIPPOV	{"phone": "+70330448731"}
0005432383381	C555EA	8886 429094	NADEZHDA PETROVA	{"email": "petrovanadezhda071977@postgrespro.ru", "phone": "+70759583904"}
0005432383382	C555EA	6039 673750	OLGA KARPOVA	{"email": "karpovao-04101962@postgrespro.ru", "phone": "+70932957406"}
0005432383383	35B683	2122 547048	GENNADIY ZAYCEV	{"phone": "+70940541503"}
0005432383384	AE10F0	3359 666349	BORIS DMITRIEV	{"phone": "+70373274729"}
0005432383385	AE10F0	3960 233345	GENNADIY BORISOV	{"email": "gborisov.03011983@postgrespro.ru", "phone": "+70470356686"}
0005432383386	2390A0	0029 459547	GALINA FEDOROVA	{"phone": "+70130096836"}
0005432383387	2390A0	4735 031438	ANASTASIYA ALEKSANDROVA	{"email": "a-aleksandrova_24111983@postgrespro.ru", "phone": "+70372397006"}
0005432383388	CC3A36	9570 805590	YULIYA PAVLOVA	{"email": "y-pavlova_1962@postgrespro.ru", "phone": "+70776193973"}
0005432383389	D0880A	9012 520929	ALEKSANDR BORISOV	{"phone": "+70043145653"}
0005432383390	D0880A	1319 239298	ANDREY ZAKHAROV	{"email": "andrey.zakharov-25111974@postgrespro.ru", "phone": "+70232685660"}
0005432383391	D0880A	9547 509120	PAVEL SCHERBAKOV	{"email": "pavel-scherbakov18031976@postgrespro.ru", "phone": "+70985940980"}
0005432383392	0A8EB6	3402 440841	ROMAN KARPOV	{"email": "karpovr.28031973@postgrespro.ru", "phone": "+70491954702"}
0005432383393	0A8EB6	0837 898611	VLADIMIR SOROKIN	{"phone": "+70357437689"}
0005432383394	F82E8F	2600 780086	GALINA ANDREEVA	{"email": "andreeva_g-11041970@postgrespro.ru", "phone": "+70587102754"}
0005432383686	F4035B	2649 168227	DENIS DENISOV	{"phone": "+70394686007"}
0005432383395	DCD657	8453 195600	ANASTASIYA VLASOVA	{"email": "vlasova-anastasiya_1965@postgrespro.ru", "phone": "+70346298328"}
0005432383396	DCD657	0209 748912	LEV KRASNOV	{"phone": "+70486205153"}
0005432383397	D924DE	9188 239163	TATYANA KOVALEVA	{"email": "tatyanakovaleva011974@postgrespro.ru", "phone": "+70754579884"}
0005432383398	D924DE	5160 509582	VALERIYA ZAKHAROVA	{"email": "zakharova_v011975@postgrespro.ru", "phone": "+70787534373"}
0005432383399	4AFE96	3448 245726	MARTA MAKAROVA	{"email": "makarova_marta091963@postgrespro.ru", "phone": "+70327602671"}
0005432383400	4AFE96	9973 334393	VLADIMIR SOKOLOV	{"email": "vsokolov-18081982@postgrespro.ru", "phone": "+70542837794"}
0005432383401	DE10BF	9027 063212	ANNA GAVRILOVA	{"email": "a_gavrilova.091970@postgrespro.ru", "phone": "+70339679498"}
0005432383402	5C0665	4468 151293	NADEZHDA ILINA	{"email": "nadezhda-ilina.041972@postgrespro.ru", "phone": "+70405592214"}
0005432383403	5C0665	8781 805878	VASILIY POPOV	{"phone": "+70905996733"}
0005432383404	16F033	4921 999116	VALENTINA NIKIFOROVA	{"phone": "+70929180553"}
0005432383405	16F033	2634 837986	ANATOLIY NOVIKOV	{"email": "anatoliy-novikov.1984@postgrespro.ru", "phone": "+70445799579"}
0005432383406	9EDF3D	8945 925753	ALEKSANDR ZAKHAROV	{"phone": "+70522516752"}
0005432383407	DCBBEE	6590 338392	DARYA LEBEDEVA	{"phone": "+70758149531"}
0005432383408	6A2CD3	1736 735926	VIKTOR KOROLEV	{"email": "viktor-korolev.1972@postgrespro.ru", "phone": "+70717580139"}
0005432383409	125707	5383 179190	ELENA RODIONOVA	{"email": "elena_rodionova-27081967@postgrespro.ru", "phone": "+70817782092"}
0005432383410	BFC4EF	7237 549634	ZINAIDA SERGEEVA	{"email": "zinaida_sergeeva.051961@postgrespro.ru", "phone": "+70997837285"}
0005432383411	D087B8	5912 527809	ALEKSANDR KULIKOV	{"phone": "+70593250262"}
0005432383412	7145D3	3113 584175	ANATOLIY KULIKOV	{"email": "a_kulikov.21041974@postgrespro.ru", "phone": "+70800507586"}
0005432383413	7145D3	8268 918760	NATALYA ILINA	{"email": "natalya_ilina.1972@postgrespro.ru", "phone": "+70179679057"}
0005432383414	D30FFE	4633 871072	NADEZHDA VASILEVA	{"email": "vasilevan_021972@postgrespro.ru", "phone": "+70097400407"}
0005432383415	D30FFE	0519 538551	ANTON VLASOV	{"email": "vlasov.a_15091964@postgrespro.ru", "phone": "+70659910021"}
0005432383416	7035AD	8926 604680	LYUDMILA TIMOFEEVA	{"email": "timofeeva.l.1993@postgrespro.ru", "phone": "+70146582756"}
0005432383417	744DD7	8277 236818	NATALYA ZAKHAROVA	{"email": "n-zakharova.031977@postgrespro.ru", "phone": "+70184500667"}
0005432383418	744DD7	9237 092857	VYACHESLAV KULIKOV	{"phone": "+70561902598"}
0005432383419	575FDD	2048 151093	DMITRIY ANTONOV	{"email": "dantonov1978@postgrespro.ru", "phone": "+70316493341"}
0005432383420	CE6735	4689 016076	VYACHESLAV GORBUNOV	{"email": "v_gorbunov_09051976@postgrespro.ru", "phone": "+70114434003"}
0005432383421	0C8415	4675 603441	DENIS PAVLOV	{"phone": "+70395712126"}
0005432383422	88F503	2775 408290	VALERIY POPOV	{"email": "popov_valeriy_08011982@postgrespro.ru", "phone": "+70642500008"}
0005432383423	CA95A2	7581 772407	IRINA BELOVA	{"phone": "+70782792736"}
0005432383424	CA95A2	0327 530835	ALIYA VOLKOVA	{"phone": "+70823456219"}
0005432383425	7EFEE4	0992 508522	GENNADIY ROMANOV	{"phone": "+70517809839"}
0005432383426	1199C6	1846 940449	VLADIMIR POPOV	{"phone": "+70185364487"}
0005432383427	1199C6	9063 287096	OLGA MELNIKOVA	{"phone": "+70256578778"}
0005432383428	3629AE	2149 039781	MARIYA KRASNOVA	{"email": "krasnova-m04061972@postgrespro.ru", "phone": "+70941097508"}
0005432383429	9F82EA	3178 748572	ALEKSANDR EGOROV	{"phone": "+70266705439"}
0005432383430	65AFB2	5117 705838	NATALYA VLASOVA	{"phone": "+70344096464"}
0005432383431	65AFB2	3553 733294	ALEKSEY SAVELEV	{"email": "a_savelev_04121978@postgrespro.ru", "phone": "+70365903014"}
0005432383432	DB932E	5113 328534	ALEKSANDR SERGEEV	{"phone": "+70689279319"}
0005432383433	4C9F14	1589 716673	SERGEY DAVYDOV	{"phone": "+70367393254"}
0005432383434	4C9F14	4715 589656	ELENA IVANOVA	{"phone": "+70856759119"}
0005432383435	4C9F14	9584 570367	VERONIKA KALININA	{"email": "kalinina.veronika1970@postgrespro.ru", "phone": "+70057609314"}
0005432383436	B5FABA	4557 866856	IGOR ALEKSEEV	{"phone": "+70863278449"}
0005432383437	B5FABA	5197 912290	ANDREY DENISOV	{"email": "andreydenisov01071967@postgrespro.ru", "phone": "+70880649392"}
0005432383438	8C4001	5919 618554	ILDAR KUZNECOV	{"email": "kuznecov-i_071969@postgrespro.ru", "phone": "+70778941387"}
0005432383439	B91239	3565 654170	VIKTOR GORBUNOV	{"email": "viktor-gorbunov.1959@postgrespro.ru", "phone": "+70133880229"}
0005432383440	B91239	0516 324968	NIKOLAY KOROLEV	{"phone": "+70734507231"}
0005432383441	80DABA	7663 605870	SERGEY MOISEEV	{"email": "moiseevs-071982@postgrespro.ru", "phone": "+70915394477"}
0005432383442	5E0FC6	6258 339174	GALINA KUZNECOVA	{"phone": "+70184137509"}
0005432383443	DC1553	6156 006708	ALEKSANDR MOROZOV	{"phone": "+70469756469"}
0005432383444	3A2227	2201 109503	ALEKSANDR CHERNOV	{"phone": "+70213562456"}
0005432383445	BD1AB8	7002 880483	ALBINA KOROLEVA	{"phone": "+70736968409"}
0005432383446	D19EB5	2573 238057	VLADIMIR GUSEV	{"email": "gusev.v091969@postgrespro.ru", "phone": "+70622159515"}
0005432383447	C8BF34	1777 663869	NINA ZOTOVA	{"phone": "+70307831111"}
0005432383448	E21C76	2039 031269	IRINA FILIPPOVA	{"phone": "+70745671366"}
0005432383449	0EE79C	0874 308571	GALINA VLASOVA	{"phone": "+70889176348"}
0005432383450	8658B1	3325 944760	VITALIY NOVIKOV	{"email": "novikov-vitaliy.061969@postgrespro.ru", "phone": "+70765273127"}
0005432383451	B0269F	3160 651593	ANTONINA ERMAKOVA	{"phone": "+70226344272"}
0005432383452	260002	9335 533761	SVETLANA ZAKHAROVA	{"phone": "+70877926756"}
0005432383453	FF8C8D	0648 291043	SERGEY GAVRILOV	{"phone": "+70736647637"}
0005432383454	FF8C8D	1505 250752	ANDREY SIDOROV	{"email": "a_sidorov31121960@postgrespro.ru", "phone": "+70937906764"}
0005432383455	912E51	3301 900686	VALENTINA ERMAKOVA	{"email": "vermakova_07051967@postgrespro.ru", "phone": "+70352449019"}
0005432383843	29AC35	2995 084440	YULIYA IVANOVA	{"phone": "+70957890733"}
0005432383456	7C2837	5301 895810	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova-17021960@postgrespro.ru", "phone": "+70744785963"}
0005432383457	7C2837	7261 849090	YURIY ZAKHAROV	{"email": "zakharov.yuriy.1962@postgrespro.ru", "phone": "+70788008587"}
0005432383458	036615	1601 962476	ALEKSANDR ABRAMOV	{"phone": "+70234596342"}
0005432383459	036615	1463 711230	NADEZHDA NIKITINA	{"email": "n-nikitina_1971@postgrespro.ru", "phone": "+70168703285"}
0005432383460	42B404	8698 888477	EVGENIY KAZAKOV	{"phone": "+70137255840"}
0005432383461	BDF278	6307 932303	VERA FADEEVA	{"phone": "+70547778304"}
0005432383462	5990CF	3108 560100	NINA NIKOLAEVA	{"phone": "+70414260469"}
0005432383463	5990CF	3397 405355	MARIYA ALEKSEEVA	{"phone": "+70537171452"}
0005432383464	5990CF	5885 818573	SERGEY BORISOV	{"email": "borisov-sergey_1979@postgrespro.ru", "phone": "+70614420228"}
0005432383465	82B40A	0532 566828	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov-21101970@postgrespro.ru", "phone": "+70959389253"}
0005432383466	613E48	3565 255493	DARYA POPOVA	{"email": "popova-darya111973@postgrespro.ru", "phone": "+70668647979"}
0005432383467	21C28D	6332 776218	NATALYA ROMANOVA	{"email": "nromanova.1969@postgrespro.ru", "phone": "+70727201395"}
0005432383468	DB0450	5248 296827	MARGARITA SERGEEVA	{"email": "sergeeva_margarita_07041971@postgrespro.ru", "phone": "+70947725570"}
0005432383469	DB0450	1669 455187	LYUBOV GUSEVA	{"email": "guseva_l-1968@postgrespro.ru", "phone": "+70169812315"}
0005432383470	DB0450	8989 649698	KONSTANTIN NIKITIN	{"email": "nikitin.konstantin-071976@postgrespro.ru", "phone": "+70626681498"}
0005432383471	56B135	9983 261458	VLADIMIR MARTYNOV	{"email": "martynov_vladimir1970@postgrespro.ru", "phone": "+70099606357"}
0005432383472	C5A976	4585 773817	IRINA KOZLOVA	{"phone": "+70872787678"}
0005432383473	238C4E	7604 289967	ALEKSANDR ORLOV	{"phone": "+70583429322"}
0005432383474	4D0E29	6209 576325	NATALYA MIKHAYLOVA	{"phone": "+70518630908"}
0005432383475	4D0E29	1534 248708	NINA KONOVALOVA	{"email": "nina-konovalova_1966@postgrespro.ru", "phone": "+70329229055"}
0005432383476	390935	6345 705220	ALEKSEY MAKAROV	{"phone": "+70058306659"}
0005432383477	7E55FE	0627 344626	EVGENIY NOVIKOV	{"email": "novikove091984@postgrespro.ru", "phone": "+70301983379"}
0005432383478	7E55FE	2269 771723	BORIS SHEVCHENKO	{"email": "b_shevchenko_1970@postgrespro.ru", "phone": "+70096991135"}
0005432383479	290A00	9404 483142	EVGENIY NIKOLAEV	{"email": "evgeniy_nikolaev19121963@postgrespro.ru", "phone": "+70428288846"}
0005432383480	290A00	8309 719076	NINA KOVALEVA	{"email": "n_kovaleva_1966@postgrespro.ru", "phone": "+70495611762"}
0005432383481	1E9FE7	4908 425092	ANDREY BORISOV	{"phone": "+70489827743"}
0005432383482	1E9FE7	2490 259109	EKATERINA LEBEDEVA	{"email": "ekaterina-lebedeva_1981@postgrespro.ru", "phone": "+70912546479"}
0005432383483	F8CACA	1421 542260	NATALYA EFREMOVA	{"phone": "+70794768409"}
0005432383484	0C2AB2	7920 716526	YURIY PETROV	{"email": "y-petrov-14021967@postgrespro.ru", "phone": "+70466971655"}
0005432383485	0C2AB2	1639 889864	DANIIL FEDOTOV	{"email": "daniil-fedotov.051972@postgrespro.ru", "phone": "+70345818958"}
0005432383486	5F99BB	4004 492304	RAFAIL KUZMIN	{"email": "kuzmin-r041973@postgrespro.ru", "phone": "+70548024769"}
0005432383487	2764DC	5664 560104	NINA IVANOVA	{"email": "ivanovan101975@postgrespro.ru", "phone": "+70398243266"}
0005432383488	319C0F	7746 097513	OLGA IVANOVA	{"email": "olga-ivanova.01071977@postgrespro.ru", "phone": "+70693946352"}
0005432383489	84EEE6	5143 915008	NADEZHDA ROMANOVA	{"phone": "+70348355080"}
0005432383490	84EEE6	8950 727815	SERGEY KUZNECOV	{"phone": "+70718591221"}
0005432383491	A31BD4	4557 695659	GALINA NAZAROVA	{"email": "nazarova.galina-07051972@postgrespro.ru", "phone": "+70982701571"}
0005432383492	294582	6704 354823	TATYANA CHERNOVA	{"phone": "+70432008187"}
0005432383493	294582	2222 729412	VIKTOR EGOROV	{"phone": "+70623659792"}
0005432383494	DD53C5	4448 374924	OLGA LUKYANOVA	{"email": "olga-lukyanova.02041971@postgrespro.ru", "phone": "+70176004276"}
0005432383495	DD53C5	8382 804650	VASILIY KISELEV	{"email": "kiselev.vasiliy.1960@postgrespro.ru", "phone": "+70430632564"}
0005432383496	4D0938	2505 581791	VALERIY PETROV	{"email": "petrovv011976@postgrespro.ru", "phone": "+70528158415"}
0005432383497	4D0938	0278 184929	OLGA KUZNECOVA	{"email": "kuznecova.olga.25071967@postgrespro.ru", "phone": "+70342940327"}
0005432383498	296967	7605 865676	ALEKSANDR KUZNECOV	{"phone": "+70614481296"}
0005432383499	927612	0243 692410	EKATERINA BOGDANOVA	{"phone": "+70726216683"}
0005432383500	44DC9A	3298 950910	ELENA AFANASEVA	{"email": "afanaseva_e.1977@postgrespro.ru", "phone": "+70379447783"}
0005432383501	44DC9A	8610 753019	SVETLANA KONOVALOVA	{"email": "konovalova.svetlana1952@postgrespro.ru", "phone": "+70587207996"}
0005432383502	C2C07F	4550 170972	ALEKSANDR SIDOROV	{"phone": "+70842720580"}
0005432383503	EF28EB	8608 105391	NADEZHDA KOVALEVA	{"email": "kovaleva-nadezhda-1966@postgrespro.ru", "phone": "+70776039919"}
0005432383504	941897	6349 828425	MARIYA KALININA	{"email": "kalininam041969@postgrespro.ru", "phone": "+70314674202"}
0005432383505	790269	7823 255060	TATYANA NESTEROVA	{"phone": "+70397509398"}
0005432383506	7D0D28	1659 197766	ALEKSANDR SERGEEV	{"email": "sergeeva.061974@postgrespro.ru", "phone": "+70162079892"}
0005432383507	7D0D28	4636 496012	SERGEY SOKOLOV	{"phone": "+70311280055"}
0005432383508	7D0D28	4511 855736	ARTUR KAZAKOV	{"phone": "+70266166304"}
0005432383509	DFC874	7098 436189	TIMUR KUZMIN	{"email": "t-kuzmin-03091984@postgrespro.ru", "phone": "+70800313157"}
0005432383510	DFC874	2675 289452	ALEKSEY IVANOV	{"email": "aleksey_ivanov_121971@postgrespro.ru", "phone": "+70670579402"}
0005432383511	3056A5	4515 441658	EKATERINA KAZAKOVA	{"email": "ekaterinakazakova-061967@postgrespro.ru", "phone": "+70733132549"}
0005432383512	193C33	1996 471815	GALINA NIKITINA	{"email": "nikitina-galina.1970@postgrespro.ru", "phone": "+70325190632"}
0005432383513	D760F4	1397 759321	MIKHAIL MELNIKOV	{"phone": "+70774565122"}
0005432383514	E03C20	4535 242694	OLGA MEDVEDEVA	{"email": "olga.medvedeva_021973@postgrespro.ru", "phone": "+70041982724"}
0005432383515	80EAFA	3505 847957	SERGEY FROLOV	{"email": "s-frolov03121967@postgrespro.ru", "phone": "+70138391416"}
0005432383516	219F89	2185 285664	ILSHAT MARTYNOV	{"phone": "+70830542146"}
0005432383517	219F89	7898 614783	ALEKSANDR KUZNECOV	{"email": "kuznecova-16041976@postgrespro.ru", "phone": "+70987842497"}
0005432383518	E27057	5722 917170	VLADIMIR NOVIKOV	{"phone": "+70893166555"}
0005432383519	E52670	5611 605065	ELENA NESTEROVA	{"email": "nesterova.elena-091984@postgrespro.ru", "phone": "+70857886379"}
0005432383520	E52670	4928 688617	ELIZAVETA ZAKHAROVA	{"email": "e_zakharova111970@postgrespro.ru", "phone": "+70945591093"}
0005432383521	99B7DA	9618 376910	VITALIY MATVEEV	{"email": "matveev.vitaliy-1980@postgrespro.ru", "phone": "+70810797985"}
0005432383522	1A072C	2636 461094	GALINA BORISOVA	{"phone": "+70965881214"}
0005432383523	1A072C	3856 003312	VITALIY VLASOV	{"email": "v.vlasov.1961@postgrespro.ru", "phone": "+70360259462"}
0005432383524	FE8EC3	8455 404278	VERA MATVEEVA	{"phone": "+70277608612"}
0005432383525	DC5B75	3458 126981	SERGEY ZAKHAROV	{"email": "s-zakharov091986@postgrespro.ru", "phone": "+70264042124"}
0005432383526	4D085A	1235 596354	DARYA KUZNECOVA	{"email": "kuznecova-darya_1983@postgrespro.ru", "phone": "+70512658406"}
0005432383527	5B8B01	0482 831762	ALEKSEY STEPANOV	{"phone": "+70489677275"}
0005432383528	5B8B01	6065 396089	MAKSIM MATVEEV	{"email": "m_matveev-05041977@postgrespro.ru", "phone": "+70082666907"}
0005432383529	F35DFC	2217 310369	IRINA GUSEVA	{"phone": "+70653655690"}
0005432383530	F35DFC	7993 217230	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr1975@postgrespro.ru", "phone": "+70951219054"}
0005432383531	6EBD93	6408 865511	ARTUR IVANOV	{"email": "aivanov-081972@postgrespro.ru", "phone": "+70494616270"}
0005432383532	6EBD93	4388 618326	RIMMA GAVRILOVA	{"email": "rimmagavrilova-22061968@postgrespro.ru", "phone": "+70810140118"}
0005432383533	F9C2C7	9395 143953	IGOR CHERNOV	{"phone": "+70508270462"}
0005432383534	5ACBBF	2182 698311	VLADISLAV VASILEV	{"email": "v.vasilev11041984@postgrespro.ru", "phone": "+70596352894"}
0005432383535	5ACBBF	9983 385281	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov.121983@postgrespro.ru", "phone": "+70863856371"}
0005432383536	5ACBBF	8461 188532	OLGA LEBEDEVA	{"email": "olga_lebedeva06111963@postgrespro.ru", "phone": "+70974559408"}
0005432383537	309398	4952 427854	VLADIMIR ZHUKOV	{"email": "zhukov.vladimir30041979@postgrespro.ru", "phone": "+70426214919"}
0005432383538	B99790	9607 937444	VERA KAZAKOVA	{"email": "kazakova-vera_25031969@postgrespro.ru", "phone": "+70214492902"}
0005432383539	B99790	2330 235800	VYACHESLAV FEDOTOV	{"email": "vyacheslavfedotov-21111972@postgrespro.ru", "phone": "+70333125632"}
0005432383540	A0CB7C	3663 665135	ELENA KRASNOVA	{"email": "elena-krasnova_1989@postgrespro.ru", "phone": "+70548605113"}
0005432383541	52FEEB	2676 502919	ALEKSANDR GORBUNOV	{"phone": "+70941033180"}
0005432383542	52FEEB	8011 072556	ELINA PETROVA	{"email": "e-petrova1980@postgrespro.ru", "phone": "+70641236822"}
0005432383543	DE8BBC	3224 007412	NIKITA ABRAMOV	{"email": "n-abramov.09051982@postgrespro.ru", "phone": "+70297865127"}
0005432383544	6F6EC8	2578 577457	MIKHAIL VLASOV	{"phone": "+70770959644"}
0005432383545	C76A13	3886 488065	RAMIL FOMIN	{"email": "fomin-r.1968@postgrespro.ru", "phone": "+70219642427"}
0005432383546	C76A13	1190 536539	IRINA STEPANOVA	{"email": "stepanova_irina.04061967@postgrespro.ru", "phone": "+70405546835"}
0005432383547	8FAFCD	0030 553326	VADIM SOLOVEV	{"email": "solovev_v.081976@postgrespro.ru", "phone": "+70163468686"}
0005432383548	FD6C01	9878 014354	LYUBOV KRASNOVA	{"phone": "+70897643146"}
0005432383549	4E90B2	6037 795027	LARISA ALEKSEEVA	{"email": "alekseeva_l_01011972@postgrespro.ru", "phone": "+70813747295"}
0005432383550	33DA78	1933 056027	MARINA MAKSIMOVA	{"email": "maksimovam091980@postgrespro.ru", "phone": "+70823945257"}
0005432383551	3BB01F	5349 411633	ELENA GRISHINA	{"phone": "+70807325561"}
0005432383552	3BB01F	6089 241789	ELENA BORISOVA	{"phone": "+70005698885"}
0005432383553	D4050B	4831 042286	ALISA VASILEVA	{"phone": "+70075710441"}
0005432383554	EBD03F	4568 569797	MARIYA YUDINA	{"phone": "+70041114077"}
0005432383555	996223	2991 503529	VIKTORIYA MASLOVA	{"email": "maslovaviktoriya1977@postgrespro.ru", "phone": "+70608199507"}
0005432383556	996223	8496 120904	NINA ALEKSEEVA	{"phone": "+70818797156"}
0005432383557	A8D086	7899 750466	MAKSIM ANDREEV	{"phone": "+70718628164"}
0005432383558	A8D086	0081 503070	VLADIMIR SIDOROV	{"email": "vladimir_sidorov.1979@postgrespro.ru", "phone": "+70658741046"}
0005432383559	001184	2867 749790	NIKOLAY KUZNECOV	{"phone": "+70012213196"}
0005432383560	E505C9	8799 048214	VENERA POLYAKOVA	{"phone": "+70539009303"}
0005432383561	6DAC69	8251 714037	MARIYA FEDOROVA	{"email": "fedorova.m-021974@postgrespro.ru", "phone": "+70989262352"}
0005432383562	643056	6666 577355	ELENA NOVIKOVA	{"email": "elena.novikova28121980@postgrespro.ru", "phone": "+70462613025"}
0005432383563	A37C33	8788 869728	EVGENIY ISAEV	{"email": "evgeniy_isaev.1961@postgrespro.ru", "phone": "+70743591387"}
0005432383564	E97D6D	5013 872891	MAKSIM VOROBEV	{"phone": "+70208088601"}
0005432383565	2199CE	7481 874508	KONSTANTIN SERGEEV	{"email": "k-sergeev.01101972@postgrespro.ru", "phone": "+70050385542"}
0005432383566	7C2B5A	6355 365786	KSENIYA ZHUKOVA	{"email": "zhukova-kseniya121973@postgrespro.ru", "phone": "+70782928913"}
0005432383567	7C2B5A	8506 198012	NIKOLAY PAVLOV	{"phone": "+70447349560"}
0005432383568	7C2B5A	1412 857521	LYUBOV PETROVA	{"email": "petrova.lyubov_28121982@postgrespro.ru", "phone": "+70725111277"}
0005432383569	8238C6	9720 909234	FEDOR MAKSIMOV	{"phone": "+70029136525"}
0005432383570	E35B88	6680 168142	GALINA SIDOROVA	{"email": "g_sidorova_28021959@postgrespro.ru", "phone": "+70930582090"}
0005432383571	53EB7F	0919 972499	MARIYA BOGDANOVA	{"email": "mariyabogdanova1961@postgrespro.ru", "phone": "+70392279080"}
0005432383572	1CC072	8405 489923	KRISTINA VOLKOVA	{"phone": "+70820793501"}
0005432383573	FA59F8	8961 268283	KSENIYA VOLKOVA	{"email": "volkova_kseniya091970@postgrespro.ru", "phone": "+70887944640"}
0005432383574	45EF9A	0595 801012	KONSTANTIN POPOV	{"email": "popovkonstantin.1974@postgrespro.ru", "phone": "+70539595462"}
0005432383575	D70E52	7130 304639	TATYANA MAKSIMOVA	{"email": "maksimovatatyana_1976@postgrespro.ru", "phone": "+70908426014"}
0005432383576	3E5929	9773 064402	ANNA NESTEROVA	{"phone": "+70965871464"}
0005432383577	BE9F2F	2351 162255	SVETLANA STEPANOVA	{"phone": "+70048865448"}
0005432383578	BE9F2F	3040 650549	ANATOLIY DAVYDOV	{"phone": "+70587678410"}
0005432383579	55FD66	3806 570958	ZINAIDA KOZLOVA	{"phone": "+70591290048"}
0005432383580	55FD66	7707 344939	ELENA MAKAROVA	{"phone": "+70109692620"}
0005432383581	7FF490	1856 882386	TAMARA KAZAKOVA	{"phone": "+70578635300"}
0005432383582	7DF76F	3377 954159	VALERIY KISELEV	{"email": "v_kiselev_17011988@postgrespro.ru", "phone": "+70579735522"}
0005432383583	140696	4485 988631	VALERIY YAKOVLEV	{"email": "valeriy-yakovlev_1969@postgrespro.ru", "phone": "+70789743000"}
0005432383584	140696	3682 039280	ANASTASIYA GUSEVA	{"email": "anastasiya.guseva_101975@postgrespro.ru", "phone": "+70709848304"}
0005432383585	140696	8173 826810	ARSENIY ZAKHAROV	{"email": "a_zakharov-061961@postgrespro.ru", "phone": "+70574903826"}
0005432383586	64B3DA	0672 910454	SERGEY FEDOTOV	{"email": "fedotov.sergey01091966@postgrespro.ru", "phone": "+70971861950"}
0005432383587	64B3DA	3274 690236	LYUDMILA ZAKHAROVA	{"phone": "+70871275684"}
0005432383588	2977C8	2345 460359	STANISLAV POPOV	{"phone": "+70475160683"}
0005432383589	2977C8	9556 346510	OLEG TIKHONOV	{"phone": "+70619672971"}
0005432383590	7A5D46	5644 938517	VLADIMIR MAKAROV	{"email": "makarov-v-20101979@postgrespro.ru", "phone": "+70981041208"}
0005432383591	F2FADD	3736 545108	ALEKSEY MOISEEV	{"email": "aleksey-moiseev_1977@postgrespro.ru", "phone": "+70202513811"}
0005432383592	472A15	3057 897750	YULIYA BARANOVA	{"email": "y.baranova-1969@postgrespro.ru", "phone": "+70333598914"}
0005432383593	278CB0	3546 283026	GENNADIY RODIONOV	{"email": "grodionov_1986@postgrespro.ru", "phone": "+70904198130"}
0005432383594	278CB0	6137 995466	VALENTINA KUZMINA	{"phone": "+70690415308"}
0005432383595	DF2BDC	9404 291882	NATALYA ZAYCEVA	{"email": "zayceva.n_041969@postgrespro.ru", "phone": "+70002135710"}
0005432383596	88B4F4	6035 336821	ALEKSANDR POPOV	{"phone": "+70296662916"}
0005432383597	4DB517	0654 764133	VALENTINA ZAYCEVA	{"email": "zayceva.v-1966@postgrespro.ru", "phone": "+70663065633"}
0005432383598	4DB517	9346 565429	KIRILL MIRONOV	{"email": "kirill.mironov_1974@postgrespro.ru", "phone": "+70007041842"}
0005432383599	1F8B7E	0799 318135	RAFAEL KOZLOV	{"email": "kozlov_rafael-1970@postgrespro.ru", "phone": "+70256958902"}
0005432383600	061084	8272 618621	TAMARA FILATOVA	{"email": "tfilatova18091979@postgrespro.ru", "phone": "+70682846107"}
0005432383601	061084	1305 801349	ANDREY DENISOV	{"email": "a-denisov_1964@postgrespro.ru", "phone": "+70728308654"}
0005432383602	B97055	6847 412782	TATYANA KULIKOVA	{"email": "tatyana_kulikova_16041959@postgrespro.ru", "phone": "+70586822917"}
0005432383603	A2C4A1	5628 665643	GALINA FROLOVA	{"phone": "+70533343361"}
0005432383604	38AB22	2011 055550	OLGA EFIMOVA	{"email": "efimova.olga-1973@postgrespro.ru", "phone": "+70595099213"}
0005432383605	38AB22	2200 745999	DENIS SCHERBAKOV	{"phone": "+70649170552"}
0005432383606	D4C91A	2029 117362	VIKTOR KUZNECOV	{"email": "viktorkuznecov.051970@postgrespro.ru", "phone": "+70002266986"}
0005432383607	49F5B0	1919 409336	ALEKSANDRA KISELEVA	{"phone": "+70467570660"}
0005432383608	A57972	3205 171770	DIANA GAVRILOVA	{"phone": "+70940287329"}
0005432383609	8E2046	8707 083485	PETR EGOROV	{"phone": "+70999145313"}
0005432383610	32FBC4	9047 246776	ALEKSANDR STEPANOV	{"phone": "+70199025917"}
0005432383611	34991A	1583 926120	NATALYA KOVALEVA	{"phone": "+70607582286"}
0005432383612	34991A	4270 825137	ELENA TARASOVA	{"email": "tarasova_elena30041975@postgrespro.ru", "phone": "+70959026964"}
0005432383613	2FA5AB	1882 147225	ANDREY DAVYDOV	{"phone": "+70018713425"}
0005432383614	2FA5AB	5999 279599	ELENA ROMANOVA	{"email": "romanova-elena16091973@postgrespro.ru", "phone": "+70760352535"}
0005432383615	ABDFF7	0093 679921	DMITRIY MARTYNOV	{"email": "martynovd-15091973@postgrespro.ru", "phone": "+70703888693"}
0005432383616	BC8357	4310 445861	VALENTINA GUSEVA	{"email": "valentina-guseva051981@postgrespro.ru", "phone": "+70844935109"}
0005432383617	BC8357	0318 393523	ELENA MIKHAYLOVA	{"email": "e.mikhaylova1978@postgrespro.ru", "phone": "+70386317403"}
0005432383618	E75AAB	1173 244609	ANATOLIY KUZMIN	{"email": "anatoliy.kuzmin_081980@postgrespro.ru", "phone": "+70291701867"}
0005432383619	AB7ECB	0464 604739	KRISTINA NIKIFOROVA	{"email": "nikiforovakristina-1971@postgrespro.ru", "phone": "+70824503408"}
0005432383620	DCE66F	5480 905100	ZINAIDA KONOVALOVA	{"phone": "+70784641948"}
0005432383621	CC55FE	6297 873069	NATALYA NOVIKOVA	{"email": "novikova-n-08081966@postgrespro.ru", "phone": "+70432900553"}
0005432383622	B3609C	6736 176469	IRINA ROMANOVA	{"email": "romanovairina.15091974@postgrespro.ru", "phone": "+70089700735"}
0005432383623	652D15	0148 299419	VLADIMIR SHEVCHENKO	{"phone": "+70873792371"}
0005432383624	652D15	3646 139389	VALERIY GUSEV	{"phone": "+70160722443"}
0005432383625	DD334E	1911 194326	VIKTOR PETROV	{"email": "viktor_petrov_1971@postgrespro.ru", "phone": "+70393747340"}
0005432383626	7038B5	7837 640685	NIKOLAY SEMENOV	{"email": "nikolay-semenov-18021971@postgrespro.ru", "phone": "+70124427767"}
0005432383627	7038B5	1911 803696	SERGEY MAKSIMOV	{"email": "sergey-maksimov1975@postgrespro.ru", "phone": "+70023508977"}
0005432383628	70711A	8869 968646	MAKSIM ZAKHAROV	{"email": "zakharov.maksim.03081968@postgrespro.ru", "phone": "+70151768641"}
0005432383629	368901	9575 741102	TATYANA SOKOLOVA	{"email": "sokolova.t_1980@postgrespro.ru", "phone": "+70540123540"}
0005432383630	14FB6F	2362 993919	KSENIYA MASLOVA	{"phone": "+70103363969"}
0005432383631	14FB6F	3496 619996	INGA SOROKINA	{"email": "i-sorokina28061969@postgrespro.ru", "phone": "+70361683361"}
0005432383632	F62B13	0832 030684	LILIYA PETROVA	{"phone": "+70974041748"}
0005432383633	6C5563	5935 405603	ALEKSEY ROMANOV	{"email": "a_romanov.31081966@postgrespro.ru", "phone": "+70819478107"}
0005432383634	6C5563	3042 366052	RAFAIL SCHERBAKOV	{"phone": "+70098950933"}
0005432383635	EC793C	4375 209405	ELENA KUZMINA	{"email": "kuzmina_e-061962@postgrespro.ru", "phone": "+70634366302"}
0005432383636	EC793C	7598 615418	LILIYA MOROZOVA	{"email": "l.morozova_1978@postgrespro.ru", "phone": "+70557483891"}
0005432383637	64DF3D	4596 572859	ELENA KONDRATEVA	{"email": "kondrateva_elena.051978@postgrespro.ru", "phone": "+70135542740"}
0005432383638	369207	6480 799287	GALINA PETROVA	{"email": "g.petrova05111981@postgrespro.ru", "phone": "+70031671782"}
0005432383639	726FE1	7345 699440	DARYA NESTEROVA	{"phone": "+70233896874"}
0005432383640	726FE1	5519 876606	MARAT KOZLOV	{"email": "kozlov_marat12111980@postgrespro.ru", "phone": "+70581964268"}
0005432383641	0612EB	5662 511729	NINA GERASIMOVA	{"email": "gerasimova-nina06101973@postgrespro.ru", "phone": "+70292905200"}
0005432383642	A1D9AD	2406 187314	SERGEY MOISEEV	{"phone": "+70633979337"}
0005432383643	A1D9AD	2364 639481	ALEKSANDR KOZLOV	{"phone": "+70330754716"}
0005432383644	FDC615	4334 084639	EDUARD KUZNECOV	{"email": "kuznecov_eduard.25061977@postgrespro.ru", "phone": "+70630064023"}
0005432383645	FDC615	7662 145187	ANATOLIY NIKOLAEV	{"phone": "+70405843659"}
0005432383646	8E1814	3246 818243	VLADIMIR BONDARENKO	{"phone": "+70933074789"}
0005432383647	50375E	4814 010543	SVETLANA BELOVA	{"phone": "+70281231000"}
0005432383648	910F95	1079 789043	OLGA NAZAROVA	{"phone": "+70022359902"}
0005432383649	EA2EDA	4209 304013	ANTON ZHUKOV	{"phone": "+70971000940"}
0005432383650	81FC14	4858 994465	ELENA OSIPOVA	{"phone": "+70413882585"}
0005432383651	81FC14	0840 896650	KRISTINA ORLOVA	{"email": "orlova_k.1979@postgrespro.ru", "phone": "+70512471421"}
0005432383652	BABB23	9379 912817	EVA SMIRNOVA	{"phone": "+70623979872"}
0005432383653	BABB23	5938 422559	ALEKSANDR ILIN	{"email": "ailin_08111973@postgrespro.ru", "phone": "+70145147516"}
0005432383654	B89784	8721 369105	VLADIMIR KUZNECOV	{"email": "kuznecovv_1977@postgrespro.ru", "phone": "+70328651870"}
0005432383655	30D5E0	3891 146178	VERA VASILEVA	{"email": "vera-vasileva_1978@postgrespro.ru", "phone": "+70554317843"}
0005432383656	B3CEBB	4954 376671	ELENA BARANOVA	{"phone": "+70819071918"}
0005432383657	7A6804	6660 658625	MARIYA NIKOLAEVA	{"email": "mariya-nikolaeva.16111981@postgrespro.ru", "phone": "+70617398089"}
0005432383658	7A6804	7683 256126	VIKTOR VASILEV	{"email": "vasilevviktor.17021972@postgrespro.ru", "phone": "+70056898280"}
0005432383659	4A28BD	8609 700349	NINA POLYAKOVA	{"phone": "+70030749893"}
0005432383660	238E7F	5485 369886	ANASTASIYA RODIONOVA	{"phone": "+70625993498"}
0005432383661	A4792D	4291 174033	VLADISLAV SMIRNOV	{"phone": "+70298443049"}
0005432383662	A4792D	9416 840196	VIKTOR MAKAROV	{"phone": "+70975289914"}
0005432383663	A4792D	4940 180836	GULNAZ MAKAROVA	{"email": "makarova_gulnaz.101970@postgrespro.ru", "phone": "+70636416271"}
0005432383664	5A49D4	2549 782866	EVGENIY VASILEV	{"email": "vasilev_evgeniy.03051969@postgrespro.ru", "phone": "+70928117111"}
0005432383665	107D9C	3917 466961	NINA SMIRNOVA	{"phone": "+70970850370"}
0005432383666	890476	1142 191386	SERGEY DENISOV	{"phone": "+70599467893"}
0005432383667	890476	6611 439949	ANTONINA PETROVA	{"email": "antoninapetrova1967@postgrespro.ru", "phone": "+70603387539"}
0005432383668	DFC0A5	8411 155438	TAMARA VOLKOVA	{"email": "tamaravolkova121972@postgrespro.ru", "phone": "+70306856596"}
0005432383669	DFC0A5	9139 620334	DARYA CHERNOVA	{"email": "darya.chernova16021964@postgrespro.ru", "phone": "+70958580446"}
0005432383670	728BDF	3150 163078	VLADIMIR FROLOV	{"phone": "+70321108503"}
0005432383671	728BDF	1987 022856	LIDIYA ZAKHAROVA	{"email": "l_zakharova_041972@postgrespro.ru", "phone": "+70962608557"}
0005432383672	BFF773	8071 251888	NINA FILIPPOVA	{"email": "filippova_n-1968@postgrespro.ru", "phone": "+70712330461"}
0005432383673	6C69C4	1550 220962	NADEZHDA MAKAROVA	{"email": "makarova_nadezhda.121965@postgrespro.ru", "phone": "+70023942652"}
0005432383674	6CD3BD	4180 953857	YURIY FOMIN	{"phone": "+70141993433"}
0005432383675	DDF364	7304 943457	MARIYA LUKYANOVA	{"email": "m.lukyanova-01081965@postgrespro.ru", "phone": "+70760127219"}
0005432383844	29AC35	1532 922035	ALEKSANDR SERGEEV	{"phone": "+70822594010"}
0005432383676	88B00E	2026 550760	IRINA MIRONOVA	{"email": "i_mironova111964@postgrespro.ru", "phone": "+70866563297"}
0005432383677	E3A937	8720 914171	OLGA PAVLOVA	{"email": "olga-pavlova_071973@postgrespro.ru", "phone": "+70185814661"}
0005432383678	E3A937	7215 460672	SERGEY SCHERBAKOV	{"email": "sergey_scherbakov_21011969@postgrespro.ru", "phone": "+70257230830"}
0005432383679	AB93AC	4045 644494	NIKOLAY ZAKHAROV	{"email": "zakharov-n1970@postgrespro.ru", "phone": "+70778479717"}
0005432383680	E33B83	1781 953848	NIKOLAY KULIKOV	{"email": "nikolay_kulikov.061976@postgrespro.ru", "phone": "+70109531262"}
0005432383681	8104FC	5475 898745	ELVIRA NOVIKOVA	{"phone": "+70938214063"}
0005432383682	420AB8	8790 653598	ALINA VOLKOVA	{"email": "volkova.alina-1974@postgrespro.ru", "phone": "+70704438519"}
0005432383683	420AB8	1932 216972	GALINA SCHERBAKOVA	{"phone": "+70392311513"}
0005432383684	83D5AB	2097 832484	DANIIL ALEKSANDROV	{"email": "aleksandrov_d1972@postgrespro.ru", "phone": "+70816463694"}
0005432383685	62DA57	8650 352830	ELENA SCHERBAKOVA	{"email": "scherbakova_e.14051973@postgrespro.ru", "phone": "+70092258811"}
0005432383687	FBC97B	0856 145194	TATYANA ZHURAVLEVA	{"phone": "+70007490575"}
0005432383688	FBC97B	1416 324384	NIKITA MIKHAYLOV	{"email": "mikhaylovn.06111967@postgrespro.ru", "phone": "+70482988619"}
0005432383689	3AC297	4724 995557	EKATERINA FADEEVA	{"phone": "+70682903631"}
0005432383690	3AC297	3928 527064	NATALYA NAUMOVA	{"email": "naumova_n-24021966@postgrespro.ru", "phone": "+70661288659"}
0005432383691	CC4AEE	5116 609334	MAKSIM ZAKHAROV	{"email": "zakharovm-121977@postgrespro.ru", "phone": "+70314312502"}
0005432383692	627D69	0434 110739	EVGENIY SCHERBAKOV	{"phone": "+70098610409"}
0005432383693	1EE239	8882 721205	INNA VLASOVA	{"phone": "+70895173618"}
0005432383694	1EE239	5336 810191	LARISA MIKHAYLOVA	{"phone": "+70207372023"}
0005432383695	42E5C2	6014 009685	ALI ANDREEV	{"phone": "+70961101570"}
0005432383696	C0A98D	7841 845013	ANATOLIY ABRAMOV	{"email": "a.abramov_24041972@postgrespro.ru", "phone": "+70952830573"}
0005432383697	3B9612	6818 909211	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir31101975@postgrespro.ru", "phone": "+70166912254"}
0005432383698	59F7CC	4837 279155	RUSLAN FROLOV	{"phone": "+70279014159"}
0005432383699	5BDDF4	2451 604216	OLGA TITOVA	{"email": "olga-titova.21101974@postgrespro.ru", "phone": "+70643713654"}
0005432383700	3E3B27	1348 722278	NATALYA TITOVA	{"email": "titova.n.1964@postgrespro.ru", "phone": "+70087881659"}
0005432383701	96D388	8431 109544	YURIY KUZNECOV	{"email": "ykuznecov.24051961@postgrespro.ru", "phone": "+70336165686"}
0005432383702	D2F2C7	0356 632268	KONSTANTIN KULIKOV	{"email": "kulikov_konstantin23071966@postgrespro.ru", "phone": "+70562786779"}
0005432383703	BB66E5	6707 095390	SVETLANA RYABOVA	{"email": "svetlana-ryabova19031971@postgrespro.ru", "phone": "+70250574083"}
0005432383704	A99694	6375 942344	ALEKSEY KAZAKOV	{"email": "alekseykazakov_23061977@postgrespro.ru", "phone": "+70902937408"}
0005432383705	0C8F46	1225 747139	GALINA IVANOVA	{"phone": "+70217890933"}
0005432383706	536944	6105 709627	IVAN MOROZOV	{"email": "i_morozov.071957@postgrespro.ru", "phone": "+70417853557"}
0005432383707	DB7E0E	0058 057967	ANGELINA NIKITINA	{"phone": "+70946390808"}
0005432383708	F15CB9	4421 615053	VALENTINA EGOROVA	{"email": "egorova.v04081963@postgrespro.ru", "phone": "+70905444211"}
0005432383709	3F19DB	5479 836167	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir-1965@postgrespro.ru", "phone": "+70838630361"}
0005432383710	3F19DB	4064 560725	MARGARITA KOZLOVA	{"email": "margarita-kozlova-1975@postgrespro.ru", "phone": "+70595515677"}
0005432383711	144F39	9758 959069	DARYA POTAPOVA	{"phone": "+70410958210"}
0005432383712	48C98F	6462 631157	ROMAN ALEKSEEV	{"phone": "+70832282039"}
0005432383713	48C98F	1387 762560	VALENTINA ROMANOVA	{"email": "romanova-v19021959@postgrespro.ru", "phone": "+70280230135"}
0005432383714	1B2C43	9027 768258	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova1980@postgrespro.ru", "phone": "+70816249064"}
0005432383715	1B2C43	0511 110287	OKSANA ERMAKOVA	{"phone": "+70975220634"}
0005432383716	4785AC	6509 726839	VIKTORIYA POLYAKOVA	{"email": "polyakova-viktoriya.081978@postgrespro.ru", "phone": "+70460120360"}
0005432383717	4F24C4	0067 433547	NIKITA VOLKOV	{"phone": "+70150629443"}
0005432383718	92CE2E	7950 188026	DANIIL MIKHAYLOV	{"email": "mikhaylov.d.111975@postgrespro.ru", "phone": "+70072774864"}
0005432383719	F17B47	3129 691423	MARINA ANISIMOVA	{"email": "m_anisimova.26101962@postgrespro.ru", "phone": "+70962425170"}
0005432383720	B03BC6	8797 200552	VLADIMIR NIKITIN	{"email": "nikitin-vladimir-1965@postgrespro.ru", "phone": "+70408254181"}
0005432383721	B3FBD8	2822 675285	SVETLANA PETROVA	{"phone": "+70970829394"}
0005432383722	B3FBD8	9355 833224	ELENA MASLOVA	{"email": "maslova-e_061982@postgrespro.ru", "phone": "+70637324230"}
0005432383723	C296D6	9043 392561	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev.121974@postgrespro.ru", "phone": "+70481874016"}
0005432383724	FC9971	9411 442039	KONSTANTIN ZHUKOV	{"phone": "+70690770288"}
0005432383725	656B93	5263 303011	EVGENIYA NOVIKOVA	{"phone": "+70080779060"}
0005432383726	656B93	0976 263481	SERGEY SAVELEV	{"phone": "+70637181132"}
0005432383727	682637	2563 207096	LYUDMILA NIKOLAEVA	{"phone": "+70564904844"}
0005432383728	682637	8952 099649	ELENA SOROKINA	{"email": "e_sorokina_041964@postgrespro.ru", "phone": "+70534476698"}
0005432383729	FE2BCC	3586 205252	IRINA KOZLOVA	{"email": "kozlovairina1982@postgrespro.ru", "phone": "+70714818837"}
0005432383730	FE2BCC	6655 626874	ANASTASIYA MELNIKOVA	{"phone": "+70575653868"}
0005432383731	9E1BC7	5662 252251	LYUBOV ZHUKOVA	{"email": "l.zhukova1978@postgrespro.ru", "phone": "+70089070472"}
0005432383732	9E1BC7	0248 056270	SERGEY KAZAKOV	{"email": "sergey-kazakov-14041963@postgrespro.ru", "phone": "+70587860337"}
0005432383733	E2768E	4810 400427	ALEKSEY ROMANOV	{"phone": "+70838101518"}
0005432383734	4C73CE	4370 522528	VLADIMIR VASILEV	{"email": "vladimir-vasilev01041964@postgrespro.ru", "phone": "+70731120211"}
0005432383735	DD5E60	7763 361906	ILYA KUZNECOV	{"phone": "+70557684590"}
0005432383736	80BC7E	6554 323879	TATYANA FILIPPOVA	{"phone": "+70414078713"}
0005432383737	6976B4	2954 136497	TATYANA ZAYCEVA	{"phone": "+70414375013"}
0005432383738	6976B4	0776 650083	ANDREY KRASNOV	{"email": "akrasnov-21031972@postgrespro.ru", "phone": "+70871436095"}
0005432383739	D8A996	4335 606843	IRAIDA KONOVALOVA	{"phone": "+70335461127"}
0005432383740	D8A996	2697 416955	IGOR MEDVEDEV	{"phone": "+70480753467"}
0005432383741	E6A3DA	7676 246153	NIKOLAY KUZNECOV	{"email": "n_kuznecov.031987@postgrespro.ru", "phone": "+70319838761"}
0005432383742	042740	6556 632897	NINA FEDOROVA	{"phone": "+70704886303"}
0005432383743	042740	8259 353916	GRIGORIY ALEKSEEV	{"email": "galekseev1966@postgrespro.ru", "phone": "+70546594966"}
0005432383744	042740	7916 429632	ANDREY SEMENOV	{"phone": "+70216201748"}
0005432383745	D56E02	8859 257426	DANILA SEMENOV	{"email": "danila.semenov041974@postgrespro.ru", "phone": "+70388949896"}
0005432383746	9DB264	6115 287201	DENIS NOVIKOV	{"email": "novikovdenis-101980@postgrespro.ru", "phone": "+70741674387"}
0005432383747	6C8C57	5727 720007	VENERA NIKITINA	{"phone": "+70834240173"}
0005432383748	CF9E8D	4024 461116	KSENIYA VOROBEVA	{"phone": "+70631342866"}
0005432383749	F16C05	9914 671199	ANDREY SOKOLOV	{"email": "sokolovandrey_1966@postgrespro.ru", "phone": "+70309352241"}
0005432383750	AE0EEE	6750 073302	PAVEL SOKOLOV	{"phone": "+70687626615"}
0005432383751	07CF0D	9886 551817	ILYA YAKOVLEV	{"phone": "+70067478219"}
0005432383752	07CF0D	0880 279279	OLGA KUZMINA	{"email": "o_kuzmina_21051972@postgrespro.ru", "phone": "+70450289801"}
0005432383753	671ECE	2028 483021	ARTUR NAUMOV	{"phone": "+70059308578"}
0005432383754	16CF7F	5752 136325	TAISIYA FROLOVA	{"phone": "+70415546492"}
0005432383755	16CF7F	8129 978613	OLESYA LUKYANOVA	{"email": "lukyanova.o_1970@postgrespro.ru", "phone": "+70776200618"}
0005432383756	16CF7F	4411 862076	VIKTORIYA KOROLEVA	{"phone": "+70146077106"}
0005432383757	9044E4	4084 415413	YULIYA ORLOVA	{"phone": "+70276439228"}
0005432383758	3A44EB	9264 578492	LARISA POTAPOVA	{"email": "potapovalarisa.121965@postgrespro.ru", "phone": "+70384869610"}
0005432383759	123C73	5300 200147	GEORGIY ZAYCEV	{"email": "georgiyzaycev_1974@postgrespro.ru", "phone": "+70152377096"}
0005432383760	7F8B22	9793 156313	ALLA MIRONOVA	{"email": "a_mironova_18111973@postgrespro.ru", "phone": "+70224846762"}
0005432383761	1EEC3D	7208 631542	ZAKHAR SIDOROV	{"email": "zakhar_sidorov091968@postgrespro.ru", "phone": "+70005593613"}
0005432383762	CF632F	5888 237522	VALERIY DENISOV	{"phone": "+70173544105"}
0005432383763	1A2901	0223 670234	NINA SERGEEVA	{"email": "nina-sergeeva041973@postgrespro.ru", "phone": "+70909620808"}
0005432383764	C110BC	7461 492518	LYUDMILA DENISOVA	{"email": "ldenisova_1974@postgrespro.ru", "phone": "+70804386451"}
0005432383765	C110BC	6655 606171	ALEKSANDR MOROZOV	{"phone": "+70588390277"}
0005432383766	5625A4	8720 702313	VIKTORIYA KAZAKOVA	{"email": "viktoriyakazakova1983@postgrespro.ru", "phone": "+70491437190"}
0005432383767	4B04A8	3547 492605	EGOR ZHUKOV	{"email": "egor-zhukov16041967@postgrespro.ru", "phone": "+70568495564"}
0005432383768	FD4A48	5165 431567	ARTEM PAVLOV	{"email": "pavlov_artem.20121971@postgrespro.ru", "phone": "+70731169152"}
0005432383769	FEB98E	7454 278331	KONSTANTIN GAVRILOV	{"email": "k.gavrilov_1973@postgrespro.ru", "phone": "+70494974630"}
0005432383770	FEB98E	6981 690593	DARYA ZAYCEVA	{"email": "zayceva_d_27081968@postgrespro.ru", "phone": "+70179801544"}
0005432383771	EAD69E	5997 413783	POLINA ANISIMOVA	{"phone": "+70666369843"}
0005432383772	6845B7	3430 657803	SERGEY ORLOV	{"phone": "+70072184856"}
0005432383773	7DA0A0	5115 527041	VALENTINA ZAYCEVA	{"email": "v_zayceva.091961@postgrespro.ru", "phone": "+70797164888"}
0005432383774	5B7B07	7636 000560	ELENA ABRAMOVA	{"phone": "+70267370593"}
0005432383775	5B7B07	0908 289875	NIKITA ANDREEV	{"phone": "+70205247410"}
0005432383776	76345E	5548 561375	ROMAN FEDOROV	{"email": "roman-fedorov_061968@postgrespro.ru", "phone": "+70196603057"}
0005432383777	0EC082	5285 628205	EKATERINA ILINA	{"email": "ekaterina.ilina-1974@postgrespro.ru", "phone": "+70813581079"}
0005432383778	BE9555	8812 377336	LIDIYA DANILOVA	{"email": "lidiya-danilova.29011976@postgrespro.ru", "phone": "+70825162680"}
0005432383779	B61613	7832 675619	DMITRIY MEDVEDEV	{"email": "medvedev.d28111963@postgrespro.ru", "phone": "+70111643740"}
0005432383780	C9A21F	1528 018180	FAINA VOLKOVA	{"email": "volkova_f.19121984@postgrespro.ru", "phone": "+70949161113"}
0005432383781	E12A31	3611 842071	TAMARA ROMANOVA	{"email": "romanova-tamara-031974@postgrespro.ru", "phone": "+70410613100"}
0005432383782	5AD2B5	6082 420294	ALENA SOROKINA	{"phone": "+70383037828"}
0005432383783	F06ACF	4510 040591	GLEB MATVEEV	{"email": "matveev_gleb.031984@postgrespro.ru", "phone": "+70352932673"}
0005432383784	7FE813	1405 987716	DMITRIY IVANOV	{"email": "ivanovdmitriy11081963@postgrespro.ru", "phone": "+70390848907"}
0005432383785	7FE813	2100 537440	NIKOLAY POPOV	{"phone": "+70080085429"}
0005432383786	790885	2529 845393	TATYANA MIKHAYLOVA	{"email": "mikhaylova-t_1966@postgrespro.ru", "phone": "+70857220104"}
0005432383787	790885	2276 664782	ANDREY ROMANOV	{"email": "romanovandrey.1974@postgrespro.ru", "phone": "+70744804905"}
0005432383788	888F3E	4320 153728	ANASTASIYA KUZMINA	{"phone": "+70902514267"}
0005432383789	81B69C	0094 387690	IRINA GERASIMOVA	{"phone": "+70513624990"}
0005432383790	81B69C	6753 081246	NATALYA SEMENOVA	{"phone": "+70970474650"}
0005432383791	B32E89	8824 211139	VALENTINA FEDOROVA	{"phone": "+70776283483"}
0005432383792	A4FF44	9629 714049	MARIYA CHERNOVA	{"phone": "+70785865014"}
0005432383793	2D9C4E	0485 209739	VENERA KAZAKOVA	{"phone": "+70437697428"}
0005432383794	FAFD4D	6058 030823	ELENA NESTEROVA	{"email": "elenanesterova_021978@postgrespro.ru", "phone": "+70459724746"}
0005432383795	33F27B	5115 159383	VIKTOR ILIN	{"email": "viktorilin.21021973@postgrespro.ru", "phone": "+70790828407"}
0005432383796	D43310	9576 339401	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov_031959@postgrespro.ru", "phone": "+70790102772"}
0005432383797	D43310	0883 175887	MATVEY KUZNECOV	{"phone": "+70055745461"}
0005432383798	94EC7A	8365 209336	EKATERINA KOROLEVA	{"phone": "+70396989164"}
0005432383799	D7CD00	1905 019398	SVETLANA FOMINA	{"email": "fominas_03081980@postgrespro.ru", "phone": "+70512960021"}
0005432383800	893ABE	9155 375540	NATALYA ZAKHAROVA	{"phone": "+70894855890"}
0005432383801	880FE8	5999 316392	VLADIMIR PETROV	{"email": "v.petrov.031970@postgrespro.ru", "phone": "+70978797540"}
0005432383802	5F963B	8699 288938	ALEKSANDR SCHERBAKOV	{"phone": "+70443728274"}
0005432383803	BDD98D	5990 383297	IGOR CHERNOV	{"email": "chernov_igor.111982@postgrespro.ru", "phone": "+70409821605"}
0005432383804	2A6D49	8723 114747	NADEZHDA NAZAROVA	{"email": "nnazarova.29081972@postgrespro.ru", "phone": "+70336019584"}
0005432383805	2A6D49	4623 134719	OLGA DAVYDOVA	{"email": "davydova_o_1975@postgrespro.ru", "phone": "+70532748679"}
0005432383806	9E2085	8982 065076	SERGEY MAKSIMOV	{"phone": "+70192154716"}
0005432383807	9E2085	9662 789027	MIKHAIL PAVLOV	{"phone": "+70736637945"}
0005432383808	9E2085	0721 480943	ALEKSANDR BELOV	{"phone": "+70461194527"}
0005432383809	E96CFC	6849 595669	VALERIYA NOVIKOVA	{"email": "valeriya.novikova_28061971@postgrespro.ru", "phone": "+70260133641"}
0005432383810	60F810	8123 794706	KLAVDIYA PETROVA	{"email": "petrova_k.23091970@postgrespro.ru", "phone": "+70339351023"}
0005432383811	1A3A9C	8372 361514	ZOYA EGOROVA	{"phone": "+70673690772"}
0005432383812	1C1B29	9945 681547	ALEKSANDRA BELOVA	{"phone": "+70678681098"}
0005432383813	72AF8D	2647 240726	NIKOLAY KISELEV	{"phone": "+70533078721"}
0005432383814	249BE0	2349 449399	VALENTINA PETROVA	{"email": "valentinapetrova_10101963@postgrespro.ru", "phone": "+70407021824"}
0005432383815	249BE0	6342 231904	VIKTOR KRASNOV	{"phone": "+70583325295"}
0005432383816	EC2E28	2159 971015	SVETLANA DAVYDOVA	{"phone": "+70067244347"}
0005432383817	2843AD	3965 451059	ANDREY PETROV	{"email": "andrey-petrov.1970@postgrespro.ru", "phone": "+70085448039"}
0005432383818	2843AD	2630 822013	ROZALIYA ZAYCEVA	{"phone": "+70340144767"}
0005432383819	24EA1B	3146 502691	DENIS POPOV	{"phone": "+70057991838"}
0005432383820	24EA1B	8779 493268	EKATERINA MIKHAYLOVA	{"email": "ekaterina_mikhaylova_031967@postgrespro.ru", "phone": "+70487432558"}
0005432383821	6038E4	0631 877052	ALEKSEY SOLOVEV	{"email": "solovev-aleksey_111971@postgrespro.ru", "phone": "+70903789659"}
0005432383822	AB662B	7536 210321	ALEKSANDR NAUMOV	{"email": "naumov.a_061964@postgrespro.ru", "phone": "+70333768617"}
0005432383823	61E7C3	3992 936336	ANDREY ZAYCEV	{"phone": "+70306573943"}
0005432383824	8364C6	9182 473135	VLADIMIR FEDOTOV	{"phone": "+70464471948"}
0005432383825	CDB346	9660 897053	ANTON KRASNOV	{"email": "anton.krasnov_1972@postgrespro.ru", "phone": "+70425431395"}
0005432383826	1E571F	7343 278705	DANIL MIRONOV	{"email": "mironov.d-021968@postgrespro.ru", "phone": "+70343774152"}
0005432383827	1E571F	6810 710910	LYUBOV KUDRYASHOVA	{"email": "kudryashova.lyubov.1975@postgrespro.ru", "phone": "+70747751031"}
0005432383828	8DE950	3983 568252	ELENA KONDRATEVA	{"phone": "+70832236442"}
0005432383829	B4B40C	9775 899690	VALERIYA EFREMOVA	{"email": "valeriyaefremova-051982@postgrespro.ru", "phone": "+70454826050"}
0005432383830	C771D9	4628 303618	LIDIYA ZAYCEVA	{"email": "lidiya.zayceva_1977@postgrespro.ru", "phone": "+70287761003"}
0005432383831	D5ADA0	7906 674769	ANNA MAKAROVA	{"phone": "+70834881213"}
0005432383832	9B7A01	9784 700933	NATALYA CHERNOVA	{"email": "chernova-natalya1958@postgrespro.ru", "phone": "+70380590477"}
0005432383833	9B7A01	3325 582442	ALEKSANDR POPOV	{"phone": "+70224367746"}
0005432383834	748ABF	2397 950992	IRAIDA ILINA	{"email": "ilina-i_081977@postgrespro.ru", "phone": "+70384388981"}
0005432383835	748ABF	4923 126654	VLADIMIR SERGEEV	{"email": "vladimir-sergeev_06061965@postgrespro.ru", "phone": "+70227896376"}
0005432383836	B706BA	4483 618555	POLINA ANTONOVA	{"phone": "+70783856354"}
0005432383837	C6A49D	4617 719727	OLGA SERGEEVA	{"phone": "+70153845966"}
0005432383838	E00CB3	0177 879774	VASILIY SHEVCHENKO	{"email": "v_shevchenko-1976@postgrespro.ru", "phone": "+70198656684"}
0005432383839	E00CB3	2373 142418	TATYANA BELYAEVA	{"phone": "+70793243613"}
0005432383840	E00CB3	8791 373918	EVGENIYA ALEKSEEVA	{"phone": "+70239272154"}
0005432383841	058AE7	4022 302918	GALINA FROLOVA	{"email": "frolova.galina-1970@postgrespro.ru", "phone": "+70586308369"}
0005432383842	CAFCF1	3602 070567	IRINA BOGDANOVA	{"email": "irina_bogdanova_1975@postgrespro.ru", "phone": "+70456671498"}
0005432383845	9D352B	4010 746698	ALEKSEY NAZAROV	{"phone": "+70479721178"}
0005432383846	9D352B	5880 096310	IVAN EGOROV	{"email": "egorov_i.011970@postgrespro.ru", "phone": "+70793755811"}
0005432383847	0E870A	0007 458933	OLEG FEDOROV	{"email": "fedorov_o_1958@postgrespro.ru", "phone": "+70886575679"}
0005432383848	C7136B	7444 477716	EKATERINA KISELEVA	{"email": "e_kiseleva1968@postgrespro.ru", "phone": "+70882951101"}
0005432383849	8763C0	9954 920817	ELENA FOMINA	{"phone": "+70927843488"}
0005432383850	42D689	1748 944425	IRINA KARPOVA	{"email": "irina-karpova_1979@postgrespro.ru", "phone": "+70853502154"}
0005432383851	42D689	3219 941564	VALENTINA GAVRILOVA	{"email": "gavrilovav_121975@postgrespro.ru", "phone": "+70646519488"}
0005432383852	7EC591	9950 556321	VALENTINA MIKHAYLOVA	{"phone": "+70386069901"}
0005432383853	7EC591	8811 736893	TATYANA VOROBEVA	{"phone": "+70695224615"}
0005432383854	96D553	1816 792999	VIKTOR KULIKOV	{"phone": "+70451802569"}
0005432383855	96D553	0571 282764	NINA ANTONOVA	{"email": "n-antonova1968@postgrespro.ru", "phone": "+70734683335"}
0005432383856	E91C02	1455 800983	VERONIKA NOVIKOVA	{"email": "novikovaveronika_1967@postgrespro.ru", "phone": "+70489852406"}
0005432383857	E91C02	9314 623968	VALENTINA DMITRIEVA	{"email": "v-dmitrieva031977@postgrespro.ru", "phone": "+70564632277"}
0005432383858	E9F39E	4272 524259	SERGEY DENISOV	{"phone": "+70373633026"}
0005432383859	E9F39E	4465 464494	ALLA KUZMINA	{"phone": "+70001594985"}
0005432383860	4D8E4A	1821 458292	IRINA MIKHAYLOVA	{"phone": "+70130700220"}
0005432383861	4D8E4A	1147 259820	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr_111961@postgrespro.ru", "phone": "+70094160556"}
0005432383862	2430F8	1206 477568	YULIYA DMITRIEVA	{"email": "dmitrieva.yuliya_1973@postgrespro.ru", "phone": "+70837363157"}
0005432383863	4959B6	1281 898045	KLAVDIYA VASILEVA	{"phone": "+70612431143"}
0005432383864	4959B6	9556 604115	FAINA KULIKOVA	{"phone": "+70166947472"}
0005432383865	CE6F5F	5795 011004	EVGENIY POPOV	{"email": "popov_e-031976@postgrespro.ru", "phone": "+70687317455"}
0005432383866	4EBF65	7825 312625	EVGENIY SOKOLOV	{"phone": "+70120762451"}
0005432383867	97761C	1002 440773	ELENA MELNIKOVA	{"phone": "+70527038978"}
0005432383868	687DAF	7876 625998	MARIYA SEMENOVA	{"email": "semenova_m.1978@postgrespro.ru", "phone": "+70941492952"}
0005432383869	687DAF	9749 540636	PAVEL ZAKHAROV	{"phone": "+70460975889"}
0005432383870	36769B	5227 476897	DMITRIY SOROKIN	{"phone": "+70074663860"}
0005432383871	F41E24	5980 886601	VALERIYA RYABOVA	{"phone": "+70784969094"}
0005432383872	F41E24	4560 832232	ALEKSANDRA KOROLEVA	{"phone": "+70857220737"}
0005432383873	F41E24	4671 349358	KLAVDIYA TROFIMOVA	{"email": "trofimovak.1984@postgrespro.ru", "phone": "+70822058139"}
0005432383874	F41E24	4937 680685	VALENTINA GORBUNOVA	{"email": "gorbunova-valentina-1968@postgrespro.ru", "phone": "+70650306891"}
0005432383875	A33AAE	0832 204428	DMITRIY PETROV	{"email": "d-petrov.091976@postgrespro.ru", "phone": "+70734265417"}
0005432383876	A33AAE	8228 960982	LYUDMILA KOZLOVA	{"phone": "+70462014097"}
0005432383877	6616B8	0020 747667	NATALYA KULIKOVA	{"email": "kulikova_natalya.011961@postgrespro.ru", "phone": "+70875267244"}
0005432383878	30F8D4	4500 297534	SVETLANA PETROVA	{"phone": "+70507509096"}
0005432383879	06B9A7	3605 113818	ANNA ZHURAVLEVA	{"email": "a_zhuravleva_1977@postgrespro.ru", "phone": "+70999535669"}
0005432383880	06B9A7	0566 630686	FANIL DMITRIEV	{"phone": "+70152135985"}
0005432383881	E4B666	6000 788008	ELENA MALYSHEVA	{"phone": "+70550723150"}
0005432383882	74F251	6760 894201	VERA PETROVA	{"phone": "+70165678593"}
0005432383883	74F251	2888 383109	IGOR ILIN	{"email": "i-ilin29121974@postgrespro.ru", "phone": "+70242431195"}
0005432383884	5D4736	2215 218588	TATYANA POPOVA	{"email": "popovat_1967@postgrespro.ru", "phone": "+70301268734"}
0005432383885	FE7B21	5590 644005	DARYA GAVRILOVA	{"phone": "+70355037909"}
0005432383886	B6A326	4889 233006	PAVEL BONDARENKO	{"email": "pbondarenko_1965@postgrespro.ru", "phone": "+70071725895"}
0005432383887	51AC21	3126 448829	ALEKSEY KULIKOV	{"email": "kulikov-aleksey.1981@postgrespro.ru", "phone": "+70413612176"}
0005432383888	51AC21	1262 403278	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey061980@postgrespro.ru", "phone": "+70917865797"}
0005432383889	C18A83	8386 732426	ILYA TARASOV	{"email": "tarasovilya1965@postgrespro.ru", "phone": "+70115032225"}
0005432383890	A0E538	2041 381286	ALEKSANDR EGOROV	{"email": "egorov_aleksandr_061970@postgrespro.ru", "phone": "+70360641696"}
0005432383891	A0E538	1033 293328	ALBERT BELOV	{"phone": "+70431718331"}
0005432383892	EBD5AA	0929 477600	DIANA FROLOVA	{"email": "frolova_diana_1966@postgrespro.ru", "phone": "+70418812750"}
0005432383893	EBD5AA	5296 733627	ELENA PETROVA	{"phone": "+70024603084"}
0005432383894	B7D6E0	6222 638908	STANISLAV MELNIKOV	{"phone": "+70162876823"}
0005432383895	DB2794	3189 440628	NADEZHDA NAZAROVA	{"phone": "+70339208531"}
0005432383896	E820A0	4016 448846	LYUBOV KUZNECOVA	{"email": "l_kuznecova081968@postgrespro.ru", "phone": "+70913761763"}
0005432383897	B8E42C	1710 958775	EVGENIYA FROLOVA	{"phone": "+70424381483"}
0005432383898	339A9F	5416 172781	NADEZHDA LAZAREVA	{"email": "nadezhda-lazareva.10041970@postgrespro.ru", "phone": "+70234399054"}
0005432383899	FEDDF5	4298 164724	NATALYA MASLOVA	{"email": "natalya_maslova.1974@postgrespro.ru", "phone": "+70786007413"}
0005432383900	4E2C3C	2854 564072	GENNADIY VASILEV	{"email": "vasilev_gennadiy_1980@postgrespro.ru", "phone": "+70024455552"}
0005432383901	69C682	0806 308314	ALEKSEY CHERNOV	{"email": "alekseychernov1974@postgrespro.ru", "phone": "+70875081117"}
0005432383902	69C682	7580 336473	IRINA MATVEEVA	{"email": "i-matveeva.07121962@postgrespro.ru", "phone": "+70056712645"}
0005432383903	D2585C	4664 694083	ANZHELIKA KUZNECOVA	{"email": "anzhelika_kuznecova-05031969@postgrespro.ru", "phone": "+70619248690"}
0005432383904	1E3E93	5444 830890	ALEKSEY MAKAROV	{"email": "makarov_aleksey03091971@postgrespro.ru", "phone": "+70077402281"}
0005432383905	1E3E93	5787 496757	SVETLANA MAKSIMOVA	{"phone": "+70939280979"}
0005432383906	CB4A71	9919 537253	VIKTORIYA POPOVA	{"email": "popova_viktoriya091974@postgrespro.ru", "phone": "+70790819451"}
0005432383907	8E2584	7945 026732	GALINA NIKOLAEVA	{"email": "nikolaeva-g_1969@postgrespro.ru", "phone": "+70783969083"}
0005432383908	8E2584	0879 525908	VLADIMIR KUDRYASHOV	{"phone": "+70535486389"}
0005432383909	8FF0C1	1854 534877	EGOR DAVYDOV	{"email": "egor.davydov-121970@postgrespro.ru", "phone": "+70370236713"}
0005432383910	D669D1	5546 651529	VLADIMIR EGOROV	{"phone": "+70643799593"}
0005432383911	E00AF2	2606 597950	NATALYA MAKAROVA	{"phone": "+70571675006"}
0005432383912	E00AF2	4351 196847	VALERIYA ORLOVA	{"phone": "+70164685647"}
0005432383913	E67388	3422 836736	ANATOLIY KUZMIN	{"email": "anatoliy.kuzmin.1966@postgrespro.ru", "phone": "+70929520382"}
0005432383914	CDDA12	3082 252131	ANDREY FOMIN	{"email": "andrey.fomin_18081969@postgrespro.ru", "phone": "+70959455070"}
0005432383915	1D4198	9990 198681	ALEKSEY BELOV	{"email": "belova1956@postgrespro.ru", "phone": "+70139309396"}
0005432383916	BAFB99	2878 993874	ALBINA MOROZOVA	{"email": "albina-morozova.24081981@postgrespro.ru", "phone": "+70713729443"}
0005432383917	496C4B	5949 985963	DMITRIY DMITRIEV	{"phone": "+70926058064"}
0005432383918	A614F5	0747 782441	VERA EFREMOVA	{"phone": "+70043286630"}
0005432383919	A614F5	8613 011816	ELIZAVETA FILIPPOVA	{"phone": "+70709309365"}
0005432383920	C1E4DD	5324 184685	ELENA TROFIMOVA	{"phone": "+70143544122"}
0005432383921	C1E4DD	7126 348995	ZINAIDA ZHUKOVA	{"email": "zhukova_z05091969@postgrespro.ru", "phone": "+70272057851"}
0005432383922	1AB1A2	8550 425569	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev_1974@postgrespro.ru", "phone": "+70318863320"}
0005432383923	A29298	5959 919692	STANISLAV TARASOV	{"email": "tarasov_s.031975@postgrespro.ru", "phone": "+70203726632"}
0005432383924	5B57C1	5933 925777	ALEKSANDR MOROZOV	{"email": "a.morozov111981@postgrespro.ru", "phone": "+70072924968"}
0005432383925	5B57C1	9076 852529	VALERIY RODIONOV	{"phone": "+70322187458"}
0005432383926	5B57C1	3194 048228	ILYAS FEDOTOV	{"phone": "+70450958285"}
0005432383927	3A5F49	3387 347791	ALEKSANDR KAZAKOV	{"email": "kazakov-a081963@postgrespro.ru", "phone": "+70113711724"}
0005432383928	0B4C63	0858 202895	VALENTINA ARKHIPOVA	{"phone": "+70175099241"}
0005432383929	A56E1D	9819 242420	MIKHAIL KUDRYASHOV	{"email": "m.kudryashov30121975@postgrespro.ru", "phone": "+70884287980"}
0005432383930	A56E1D	5712 335015	EGOR PAVLOV	{"phone": "+70272545383"}
0005432383931	C3F236	8057 715670	ILDAR NIKITIN	{"email": "inikitin-27011972@postgrespro.ru", "phone": "+70150591180"}
0005432383932	71FA37	7092 264087	YULIYA SERGEEVA	{"phone": "+70522207464"}
0005432383933	71FA37	2942 662472	LEONID MAKAROV	{"email": "makarov_l1970@postgrespro.ru", "phone": "+70021710546"}
0005432383934	441092	4579 394943	VALENTINA MATVEEVA	{"email": "v.matveeva.10031973@postgrespro.ru", "phone": "+70972083748"}
0005432383935	8A2F5A	6052 892879	VLADIMIR DENISOV	{"email": "denisov-vladimir1970@postgrespro.ru", "phone": "+70597770494"}
0005432383936	452ED6	8180 775338	ELENA ALEKSEEVA	{"email": "elena_alekseeva-1961@postgrespro.ru", "phone": "+70318968151"}
0005432383937	8E80E3	8815 101358	KLAVDIYA ZOTOVA	{"email": "k.zotova071978@postgrespro.ru", "phone": "+70497251991"}
0005432383938	8E80E3	1909 334674	ALEKSANDR MAKSIMOV	{"email": "maksimov.a-30101973@postgrespro.ru", "phone": "+70512245416"}
0005432383939	8CD174	2689 568398	ANASTASIYA KOLESNIKOVA	{"email": "anastasiyakolesnikova_1974@postgrespro.ru", "phone": "+70952869312"}
0005432383940	8CD174	9730 007421	SERGEY FROLOV	{"email": "frolov_s-1973@postgrespro.ru", "phone": "+70000421654"}
0005432383941	2BD853	6477 616526	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila1971@postgrespro.ru", "phone": "+70344960949"}
0005432383942	84B4B8	8929 757273	SVETLANA PAVLOVA	{"email": "pavlova.s.101982@postgrespro.ru", "phone": "+70787069847"}
0005432383943	7D3577	0024 085814	VERA TARASOVA	{"phone": "+70436498400"}
0005432383944	7D3577	7835 245214	MARGARITA KOZLOVA	{"phone": "+70090239197"}
0005432383945	7D3577	2540 758344	ANNA KOZLOVA	{"email": "kozlova.anna.011980@postgrespro.ru", "phone": "+70149449398"}
0005432383946	5B9EC5	3185 174492	TIMUR IVANOV	{"phone": "+70091209498"}
0005432383947	F08865	5485 406056	ELENA YAKOVLEVA	{"email": "yakovleva-e_10051969@postgrespro.ru", "phone": "+70975203296"}
0005432383948	6C8E25	3095 205123	LILIYA KAZAKOVA	{"phone": "+70371742497"}
0005432383949	DFB5C9	7525 830026	MARIYA DAVYDOVA	{"email": "m.davydova.1976@postgrespro.ru", "phone": "+70577076386"}
0005432383950	DFB5C9	7099 261465	PETR NIKOLAEV	{"phone": "+70077312037"}
0005432383951	FA7B20	3293 621813	DENIS VOLKOV	{"email": "volkov.denis18051980@postgrespro.ru", "phone": "+70146056086"}
0005432383952	0D3B14	0766 126672	SEMEN MIRONOV	{"email": "s_mironov03081975@postgrespro.ru", "phone": "+70867914199"}
0005432383953	0D3B14	7331 739107	EVGENIY KUZMIN	{"email": "evgeniykuzmin_101980@postgrespro.ru", "phone": "+70367185188"}
0005432383954	DE0819	8664 916810	YULIYA OVCHINNIKOVA	{"phone": "+70842403836"}
0005432383955	C2D6C2	1310 470323	EVGENIYA ANDREEVA	{"email": "andreeva_e.121974@postgrespro.ru", "phone": "+70721145465"}
0005432383956	6A7B8F	0474 284493	NIKOLAY TIMOFEEV	{"phone": "+70812327457"}
0005432383957	837B34	1631 343050	ALEKSANDR SOLOVEV	{"phone": "+70215006061"}
0005432383958	4BA75A	3758 818149	RINAT ALEKSEEV	{"email": "alekseev_r-041971@postgrespro.ru", "phone": "+70448855943"}
0005432383959	83518D	1295 258269	MIKHAIL KUDRYASHOV	{"email": "mikhailkudryashov_1973@postgrespro.ru", "phone": "+70405727283"}
0005432383960	0C4463	2055 803753	EVGENIY KULIKOV	{"email": "evgeniy_kulikov-12121978@postgrespro.ru", "phone": "+70429977471"}
0005432383961	0C4463	4472 517885	MARGARITA VASILEVA	{"phone": "+70385154744"}
0005432383962	051E74	3668 604653	RIMMA NIKOLAEVA	{"email": "nikolaeva-rimma1962@postgrespro.ru", "phone": "+70289511974"}
0005432383963	051E74	3236 781965	MARIYA DANILOVA	{"phone": "+70909832426"}
0005432383964	FEAE6B	3092 601522	DMITRIY VOROBEV	{"phone": "+70578602712"}
0005432383965	DE907C	3741 954929	VYACHESLAV DENISOV	{"email": "v-denisov-101969@postgrespro.ru", "phone": "+70047627708"}
0005432383966	480AB9	7119 398109	TATYANA KULIKOVA	{"phone": "+70798090881"}
0005432383967	C95EA5	0762 301101	OLEG KOZLOV	{"email": "oleg_kozlov-1968@postgrespro.ru", "phone": "+70861949388"}
0005432383968	CB2633	3385 153157	SERGEY MATVEEV	{"email": "sergey-matveev_26061967@postgrespro.ru", "phone": "+70931958905"}
0005432383969	016107	8234 483615	VYACHESLAV FROLOV	{"phone": "+70401597488"}
0005432383970	6A4F56	6461 391463	DARYA TIKHONOVA	{"phone": "+70786119120"}
0005432383971	94146A	4293 766274	ANTON CHERNOV	{"phone": "+70818998768"}
0005432383972	1D7D37	9093 098234	IVAN NIKOLAEV	{"phone": "+70278167203"}
0005432383973	0EA268	0174 676813	VIKTOR OSIPOV	{"email": "osipov_viktor-1985@postgrespro.ru", "phone": "+70032915419"}
0005432383974	07D81F	1893 554752	ALEKSANDR ANDREEV	{"phone": "+70906955607"}
0005432383975	3A4B44	5076 552427	ALEKSEY SOKOLOV	{"phone": "+70870165303"}
0005432383976	F72B5B	8596 168783	ILYA ZHURAVLEV	{"email": "izhuravlev-041973@postgrespro.ru", "phone": "+70261163772"}
0005432383977	3D9514	7810 796583	LYUDMILA PETROVA	{"email": "lyudmila.petrova_081976@postgrespro.ru", "phone": "+70780556904"}
0005432383978	159C71	5168 331419	OLGA SAVELEVA	{"phone": "+70516978776"}
0005432383979	159C71	1472 626337	VLADIMIR BARANOV	{"email": "vladimir.baranov_1970@postgrespro.ru", "phone": "+70572743347"}
0005432383980	A2FA6D	5720 985935	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr-1976@postgrespro.ru", "phone": "+70633072951"}
0005432383981	A2FA6D	9492 650792	VIKTOR ILIN	{"email": "v.ilin_111980@postgrespro.ru", "phone": "+70816405611"}
0005432383982	0D2EE9	4691 330224	OKSANA GRISHINA	{"email": "grishina_oksana.081976@postgrespro.ru", "phone": "+70758824515"}
0005432383983	0D2EE9	9944 640630	IRINA KOROLEVA	{"email": "koroleva_irina_021967@postgrespro.ru", "phone": "+70694619040"}
0005432383984	B7815B	0363 443610	ALEKSEY MEDVEDEV	{"email": "aleksey.medvedev101972@postgrespro.ru", "phone": "+70974468605"}
0005432383985	C0FD29	5030 402730	LYUBOV LOGINOVA	{"phone": "+70400539824"}
0005432383986	104F94	2147 058269	VASILIY KRASNOV	{"phone": "+70249389896"}
0005432383987	F68729	2158 228792	ANASTASIYA OSIPOVA	{"phone": "+70853096836"}
0005432383988	B93298	6394 520042	YURIY MIKHAYLOV	{"phone": "+70018722135"}
0005432383989	A91D68	3495 885554	RUMIYA TIKHONOVA	{"phone": "+70672706467"}
0005432383990	B9E550	1321 554377	SERGEY POPOV	{"email": "popov_s14031968@postgrespro.ru", "phone": "+70960538075"}
0005432383991	CD6975	9388 613593	ANGELINA POPOVA	{"email": "popovaa-17121969@postgrespro.ru", "phone": "+70204399637"}
0005432383992	CD6975	7917 027552	ALEKSANDR ANDREEV	{"phone": "+70898784292"}
0005432383993	C09AA5	9028 577329	ROMAN ILIN	{"email": "ilinr-121981@postgrespro.ru", "phone": "+70519821237"}
0005432383994	A2CA16	7639 141669	VYACHESLAV VASILEV	{"email": "vyacheslav.vasilev_1964@postgrespro.ru", "phone": "+70402896218"}
0005432383995	2E9C41	1256 409964	ELENA DENISOVA	{"email": "denisova_elena-061973@postgrespro.ru", "phone": "+70358210152"}
0005432383996	6F2403	2440 735959	OLGA KUZNECOVA	{"phone": "+70972660643"}
0005432383997	6F2403	4916 901040	GALINA FILIPPOVA	{"email": "g.filippova-1965@postgrespro.ru", "phone": "+70522369247"}
0005432383998	47898D	1746 494612	ELINA BARANOVA	{"email": "baranova.elina-121970@postgrespro.ru", "phone": "+70229827603"}
0005432383999	3577DE	2739 928781	EVGENIY GRIGOREV	{"email": "grigorev.e-1984@postgrespro.ru", "phone": "+70676897579"}
0005432384000	DE6B4A	8932 626155	IRINA PETROVA	{"email": "petrova_irina101969@postgrespro.ru", "phone": "+70458819201"}
0005432384001	0A28BC	4921 243919	ANGELINA PETROVA	{"email": "a.petrova23021971@postgrespro.ru", "phone": "+70965154412"}
0005432384002	0A28BC	5194 721821	SVETLANA IVANOVA	{"phone": "+70448324019"}
0005432384003	935A54	5102 589281	ALEKSANDR ALEKSEEV	{"email": "alekseeva-1980@postgrespro.ru", "phone": "+70297153108"}
0005432384004	979DB0	8189 579379	OKSANA DMITRIEVA	{"phone": "+70510606491"}
0005432384005	979DB0	9883 896239	IGOR NIKOLAEV	{"phone": "+70216661013"}
0005432384006	0F931B	3299 392715	IRAIDA VOLKOVA	{"email": "volkovairaida-13061969@postgrespro.ru", "phone": "+70084478940"}
0005432384007	0F931B	5704 406359	EVGENIYA DENISOVA	{"email": "denisova_evgeniya_13031964@postgrespro.ru", "phone": "+70809896196"}
0005432384008	35A1F3	3179 810045	SERGEY MAKAROV	{"email": "makarov-s.1963@postgrespro.ru", "phone": "+70489365799"}
0005432384009	BD9204	1206 480407	KARINA KOVALEVA	{"email": "kovaleva.karina-28021961@postgrespro.ru", "phone": "+70908516193"}
0005432384010	BD9204	7511 117296	BORIS PAVLOV	{"email": "boris-pavlov_1970@postgrespro.ru", "phone": "+70795784175"}
0005432384011	E0C51D	0603 552897	DIANA MOISEEVA	{"email": "moiseeva-diana-1969@postgrespro.ru", "phone": "+70439907151"}
0005432384012	E0C51D	2678 921817	VERA ROMANOVA	{"phone": "+70170927676"}
0005432384013	14E2B9	2959 654087	ALEKSANDR VLASOV	{"phone": "+70357010164"}
0005432384014	A4CD1C	6233 509716	ANDREY FROLOV	{"phone": "+70248833039"}
0005432384015	A4CD1C	4639 470017	LYUBOV DENISOVA	{"phone": "+70256282333"}
0005432384016	012EE9	4714 749445	MARIYA NIKOLAEVA	{"phone": "+70969000950"}
0005432384017	75F111	2752 932873	ILYA SEMENOV	{"email": "semenovilya_1973@postgrespro.ru", "phone": "+70858204562"}
0005432384018	75F111	5107 143644	GENNADIY MOISEEV	{"phone": "+70876798266"}
0005432384019	F0CD5C	3826 558586	NATALYA PAVLOVA	{"phone": "+70583573549"}
0005432384020	20FC3B	9483 418243	NADEZHDA SAVELEVA	{"phone": "+70215725024"}
0005432384021	20FC3B	5256 345181	ANNA VOROBEVA	{"phone": "+70060217992"}
0005432384022	8F5EF4	6766 061211	EKATERINA POLYAKOVA	{"phone": "+70508803967"}
0005432384023	8F5EF4	2937 232973	RASHID TARASOV	{"email": "tarasov_rashid14061968@postgrespro.ru", "phone": "+70069133158"}
0005432384024	8F5EF4	8408 668063	ALEKSANDRA SAVELEVA	{"phone": "+70554104008"}
0005432384025	3DB978	8658 061385	VLADIMIR DENISOV	{"phone": "+70412019950"}
0005432384026	3DB978	9738 407387	ANNA KOROLEVA	{"phone": "+70513394142"}
0005432384027	3ADFA8	9898 410381	IRINA ZAYCEVA	{"email": "zayceva-i.19061968@postgrespro.ru", "phone": "+70562202736"}
0005432384028	A9548A	3195 847317	LIDIYA VOLKOVA	{"email": "lidiya-volkova_021973@postgrespro.ru", "phone": "+70484500547"}
0005432384029	5AC5AA	3852 249530	ALEKSANDRA IVANOVA	{"phone": "+70362632711"}
0005432384030	144312	6804 716926	ANASTASIYA NAUMOVA	{"phone": "+70354820147"}
0005432384031	0D41A2	8732 585935	NATALYA RYABOVA	{"phone": "+70214378089"}
0005432384032	280CDB	8166 382317	EKATERINA SIDOROVA	{"phone": "+70998460263"}
0005432384033	98AE0D	1152 571857	VALENTINA KULIKOVA	{"email": "valentina.kulikova.031977@postgrespro.ru", "phone": "+70774071532"}
0005432384034	B5ABE0	0740 443733	ALEKSEY MIKHAYLOV	{"phone": "+70897221363"}
0005432384035	9CF01B	2900 298429	GULFIYA RODIONOVA	{"phone": "+70005937395"}
0005432384036	9CF01B	4640 239310	VLADIMIR STEPANOV	{"phone": "+70591235050"}
0005432384037	D72A54	7444 404064	BORIS FEDOTOV	{"phone": "+70339892436"}
0005432384038	D72A54	9334 230745	ANDREY FILIPPOV	{"email": "filippov_a_28091975@postgrespro.ru", "phone": "+70945659344"}
0005432384039	27696A	1372 082468	STEPAN PAVLOV	{"phone": "+70345450461"}
0005432384040	27696A	1406 759544	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-101976@postgrespro.ru", "phone": "+70063677153"}
0005432384041	5B3D42	2249 418773	VYACHESLAV STEPANOV	{"phone": "+70578981667"}
0005432384042	5B3D42	2408 071945	KONSTANTIN FILIPPOV	{"phone": "+70257768882"}
0005432384043	BB9062	1069 233889	EVGENIY KUZMIN	{"phone": "+70300402778"}
0005432384044	DB9F8A	0754 562036	IVAN BORISOV	{"phone": "+70606492314"}
0005432384045	DB9F8A	9823 443872	NIKOLAY GERASIMOV	{"email": "n.gerasimov17011962@postgrespro.ru", "phone": "+70209340900"}
0005432384046	3B4EEF	3541 867047	RAMIL NIKOLAEV	{"email": "ramil.nikolaev_071978@postgrespro.ru", "phone": "+70217053931"}
0005432384047	138C97	4541 419230	ALBINA ZHURAVLEVA	{"phone": "+70991217748"}
0005432384048	AD2B92	1636 134140	YULIYA POTAPOVA	{"email": "y-potapova1969@postgrespro.ru", "phone": "+70381781728"}
0005432384049	7DCCB3	7912 731537	OKSANA MELNIKOVA	{"email": "omelnikova-1972@postgrespro.ru", "phone": "+70568671314"}
0005432384050	DC1A05	6451 805504	ANASTASIYA TARASOVA	{"phone": "+70405706945"}
0005432384051	16C58B	1293 917974	ANNA MAKAROVA	{"email": "makarova_a1971@postgrespro.ru", "phone": "+70359201652"}
0005432384052	16C58B	8888 294927	DIANA ANDREEVA	{"email": "diana_andreeva101980@postgrespro.ru", "phone": "+70063742765"}
0005432384053	396F87	6363 595602	SERGEY VOLKOV	{"phone": "+70462375198"}
0005432384054	43B18B	3621 281562	DMITRIY GUSEV	{"phone": "+70518175554"}
0005432384055	43B18B	6152 390457	ANNA CHERNOVA	{"email": "a-chernova111975@postgrespro.ru", "phone": "+70888697170"}
0005432384056	514738	6083 147999	TATYANA ZHUKOVA	{"email": "zhukovatatyana.1970@postgrespro.ru", "phone": "+70628006071"}
0005432384057	29972A	3743 301776	TAMARA TARASOVA	{"phone": "+70681565910"}
0005432384058	29972A	7514 981938	ANDREY NIKITIN	{"email": "nikitin_andrey-13031973@postgrespro.ru", "phone": "+70953590244"}
0005432384059	3873F4	0917 258591	MAKSIM PAVLOV	{"email": "m_pavlov_041967@postgrespro.ru", "phone": "+70754795031"}
0005432384060	F88157	2445 901272	ZINAIDA ALEKSANDROVA	{"phone": "+70609199609"}
0005432384061	280463	6060 862056	VIKTORIYA PAVLOVA	{"email": "viktoriya.pavlova.011970@postgrespro.ru", "phone": "+70380250049"}
0005432384062	89F45D	9791 921307	LARISA MOROZOVA	{"email": "morozova-l_121975@postgrespro.ru", "phone": "+70021476424"}
0005432384063	730675	0638 722805	NIKOLAY SAVELEV	{"phone": "+70697627743"}
0005432384064	730675	5056 495244	VALENTINA MEDVEDEVA	{"phone": "+70761414217"}
0005432384065	95131A	7336 412524	VALENTINA GERASIMOVA	{"phone": "+70003969016"}
0005432384066	95131A	4422 994002	SAVELIY SMIRNOV	{"phone": "+70937109958"}
0005432384067	1C117D	4246 436185	SERGEY GORBUNOV	{"phone": "+70936193883"}
0005432384068	1C117D	2273 625562	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov1967@postgrespro.ru", "phone": "+70896697185"}
0005432384069	B5B5A4	5757 622920	ARTEM MARTYNOV	{"email": "martynovartem-1974@postgrespro.ru", "phone": "+70978076615"}
0005432384070	B5B5A4	2083 136826	TATYANA BELOVA	{"email": "tatyana_belova.1972@postgrespro.ru", "phone": "+70908814528"}
0005432384071	512168	2466 220474	NIKOLAY DENISOV	{"phone": "+70646487135"}
0005432384072	5285BA	2328 893857	ILYA MIRONOV	{"email": "imironov111974@postgrespro.ru", "phone": "+70815993619"}
0005432384073	6872B7	8781 664804	VERA NIKITINA	{"phone": "+70044353967"}
0005432384074	EA77B6	6094 859199	ANDREY ZAYCEV	{"phone": "+70034768600"}
0005432384075	EA77B6	9565 311379	SERGEY IVANOV	{"email": "ivanovs.121966@postgrespro.ru", "phone": "+70373342953"}
0005432384076	BA55C2	6625 298295	ALENA ANISIMOVA	{"email": "alena.anisimova1972@postgrespro.ru", "phone": "+70769168339"}
0005432384077	71073A	2458 488015	VERA TITOVA	{"phone": "+70736002476"}
0005432384078	FB1A3D	5090 317252	ELENA MOROZOVA	{"phone": "+70400298778"}
0005432384079	FB1A3D	5624 737500	ALEKSEY ALEKSANDROV	{"email": "aleksandrovaleksey27021982@postgrespro.ru", "phone": "+70645953776"}
0005432384080	3202F8	5417 032215	ILNAR KONOVALOV	{"phone": "+70781577288"}
0005432384081	1D3EC0	0180 643076	NATALYA SMIRNOVA	{"phone": "+70815988413"}
0005432384082	1D3EC0	7195 333813	NIKOLAY FEDOTOV	{"phone": "+70592730949"}
0005432384083	34CDAA	2623 883632	TAMARA ZOTOVA	{"phone": "+70340668859"}
0005432384084	B06715	5564 299699	YURIY KUZNECOV	{"email": "kuznecov-yuriy-1968@postgrespro.ru", "phone": "+70282809594"}
0005432384085	B06715	9423 904746	DMITRIY BORISOV	{"phone": "+70807205864"}
0005432384086	B06715	6262 221355	ALEKSANDR KARPOV	{"email": "karpov_aleksandr_061962@postgrespro.ru", "phone": "+70922690238"}
0005432384087	9A658E	1503 359444	GALINA SAVELEVA	{"phone": "+70632724743"}
0005432384088	9A658E	7285 550123	MARINA MOROZOVA	{"email": "morozova-m.121964@postgrespro.ru", "phone": "+70489723154"}
0005432384089	533120	0964 403911	OLGA KUZNECOVA	{"email": "olga.kuznecova121968@postgrespro.ru", "phone": "+70041306061"}
0005432384090	533120	8401 400727	SERGEY VASILEV	{"email": "sergeyvasilev_1967@postgrespro.ru", "phone": "+70227679419"}
0005432384091	D55E91	8752 210031	ANDREY MELNIKOV	{"email": "melnikov_a-1977@postgrespro.ru", "phone": "+70866616321"}
0005432384092	02821C	1941 206242	KONSTANTIN EGOROV	{"phone": "+70329837439"}
0005432384093	02821C	4756 741731	VIKTOR POPOV	{"email": "popov.viktor.1978@postgrespro.ru", "phone": "+70272530858"}
0005432384094	A140FE	6662 565554	NATALYA SAVELEVA	{"email": "saveleva.n-1974@postgrespro.ru", "phone": "+70585756656"}
0005432384095	D76687	5504 113057	ARTEM PAVLOV	{"email": "pavlov_artem27061973@postgrespro.ru", "phone": "+70997153583"}
0005432384096	D76687	0563 345698	YULIYA DAVYDOVA	{"phone": "+70679604297"}
0005432384097	5E00C0	4512 071468	OLGA PETROVA	{"phone": "+70321933424"}
0005432384098	1E4AD7	6206 804170	NATALYA NESTEROVA	{"email": "n.nesterova_1970@postgrespro.ru", "phone": "+70009779288"}
0005432384099	0F7753	7481 715626	SVETLANA NAZAROVA	{"phone": "+70605252569"}
0005432384100	0F7753	1831 164125	RUSLAN BONDARENKO	{"phone": "+70013724575"}
0005432384101	D85547	7139 786222	TATYANA IVANOVA	{"email": "ivanova.t-05111974@postgrespro.ru", "phone": "+70621523031"}
0005432384102	8A069F	2907 625256	EGOR GAVRILOV	{"email": "gavrilove-1977@postgrespro.ru", "phone": "+70047808506"}
0005432384103	4E0BD7	0891 653562	DMITRIY KUZNECOV	{"email": "dkuznecov031968@postgrespro.ru", "phone": "+70932338638"}
0005432384104	4E0BD7	8977 753132	EVGENIYA ISAEVA	{"phone": "+70854783826"}
0005432384105	1944A0	0771 365732	LYUBOV DMITRIEVA	{"phone": "+70423141907"}
0005432384106	519855	7889 809426	OLEG GERASIMOV	{"email": "gerasimovo101966@postgrespro.ru", "phone": "+70397800406"}
0005432384107	519855	4591 778259	VALENTINA MAKSIMOVA	{"phone": "+70302958333"}
0005432384108	00F172	0277 115156	SERAFIM ROMANOV	{"email": "romanov-serafim031976@postgrespro.ru", "phone": "+70203148360"}
0005432384109	00F172	2805 429519	YULIYA SOROKINA	{"phone": "+70012290062"}
0005432384110	00F172	1104 290370	ALEKSANDR ZHUKOV	{"phone": "+70718755462"}
0005432384111	128E61	5649 034317	ALBINA DENISOVA	{"phone": "+70714972044"}
0005432384112	128E61	5500 864809	ALEKSANDR BONDARENKO	{"phone": "+70872052320"}
0005432384113	128E61	9439 323124	NATALYA MALYSHEVA	{"phone": "+70215099247"}
0005432384114	FCC1A6	9716 596919	NIKOLAY KUZNECOV	{"phone": "+70312304969"}
0005432384115	85B330	9901 617632	RAISA FILATOVA	{"phone": "+70697502270"}
0005432384116	CD333C	1763 007850	OLEG MEDVEDEV	{"email": "oleg.medvedev.04121961@postgrespro.ru", "phone": "+70251349793"}
0005432384117	3439B4	5909 113320	ALEKSEY DMITRIEV	{"phone": "+70981974317"}
0005432384118	407035	4456 166568	VALERIY VOROBEV	{"email": "v-vorobev29041977@postgrespro.ru", "phone": "+70231982844"}
0005432384119	856475	8237 147077	OLGA TARASOVA	{"phone": "+70409896579"}
0005432384120	4134E8	3518 293823	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir-17061975@postgrespro.ru", "phone": "+70781466631"}
0005432384121	85D24D	5772 811843	ELENA KULIKOVA	{"phone": "+70558407417"}
0005432384122	4BD9DE	4997 269582	ALEKSANDR MIRONOV	{"phone": "+70371281491"}
0005432384123	4BD9DE	8746 318934	YANA KOROLEVA	{"email": "y-koroleva101982@postgrespro.ru", "phone": "+70606921649"}
0005432384124	2C0FCA	2619 682161	LYUBOV LOGINOVA	{"phone": "+70014339911"}
0005432384125	6F3853	3799 489687	KLAVDIYA AFANASEVA	{"email": "afanaseva.klavdiya061967@postgrespro.ru", "phone": "+70408744088"}
0005432384126	BDDF7F	8702 129435	YURIY ZAYCEV	{"phone": "+70087997300"}
0005432384127	BDDF7F	1443 870108	IRINA TITOVA	{"phone": "+70541276775"}
0005432384128	7FAD8A	5857 526010	TATYANA IVANOVA	{"email": "tatyana_ivanova09121971@postgrespro.ru", "phone": "+70116595793"}
0005432384129	6F5C65	1680 232796	ANDREY SIDOROV	{"phone": "+70210790538"}
0005432384130	A1B501	3889 726681	OLGA GUSEVA	{"phone": "+70748595813"}
0005432384131	3E17EF	2619 371567	RIMA POPOVA	{"phone": "+70679826799"}
0005432384132	3E17EF	6425 047829	TATYANA TIKHONOVA	{"email": "tikhonova-tatyana.1971@postgrespro.ru", "phone": "+70421580743"}
0005432384133	1C0FFC	9578 397911	LILIYA PAVLOVA	{"phone": "+70326251991"}
0005432384134	1C0FFC	6420 715729	KONSTANTIN NAZAROV	{"phone": "+70376139164"}
0005432384135	9A10BF	7293 502408	ALEKSEY FOMIN	{"phone": "+70217140689"}
0005432384136	7F8852	7633 029647	VLADIMIR MIRONOV	{"email": "mironov.vladimir-22051974@postgrespro.ru", "phone": "+70397452667"}
0005432384137	2F61DA	6741 057129	ALEKSANDR IVANOV	{"email": "aivanov.111974@postgrespro.ru", "phone": "+70877433019"}
0005432384138	2F61DA	9847 970821	SERGEY VOROBEV	{"email": "vorobev.sergey13041961@postgrespro.ru", "phone": "+70202778327"}
0005432384139	E7E6B9	4734 677399	SVETLANA FROLOVA	{"phone": "+70005774484"}
0005432384140	0A4AF0	0355 069011	ELENA ZAYCEVA	{"phone": "+70220042110"}
0005432384141	0A4AF0	0569 423890	ALEKSANDRA RODIONOVA	{"phone": "+70478680879"}
0005432384142	673ABA	6785 192139	VLADISLAV RODIONOV	{"email": "rodionov_v_09041977@postgrespro.ru", "phone": "+70711793129"}
0005432384143	A8C8A0	3065 572024	EVGENIY TIMOFEEV	{"phone": "+70408164950"}
0005432384144	A8C8A0	8621 172691	DMITRIY MELNIKOV	{"email": "dmelnikov_26041973@postgrespro.ru", "phone": "+70187634175"}
0005432384145	A8C8A0	1586 761437	IRINA SMIRNOVA	{"email": "smirnova.irina28121979@postgrespro.ru", "phone": "+70946800490"}
0005432384146	F4BA20	9730 707609	KRISTINA PAVLOVA	{"email": "pavlova.kristina.031975@postgrespro.ru", "phone": "+70060305938"}
0005432384147	9985DF	6888 794137	IRINA KUZNECOVA	{"email": "kuznecova_i-021962@postgrespro.ru", "phone": "+70956680670"}
0005432384148	CAFB3A	5789 826951	VADIM MAKAROV	{"email": "vadim_makarov-07091973@postgrespro.ru", "phone": "+70711020851"}
0005432384149	930474	0920 152356	NINA ORLOVA	{"email": "orlovanina.1978@postgrespro.ru", "phone": "+70941451253"}
0005432384150	22571B	4336 068838	ALEKSANDR NIKITIN	{"email": "a-nikitin-1974@postgrespro.ru", "phone": "+70015664294"}
0005432384151	D1B001	3668 488777	VLADIMIR KISELEV	{"email": "kiselevv_09011972@postgrespro.ru", "phone": "+70888443549"}
0005432384152	F28A86	6694 277066	VITALIY NIKITIN	{"email": "v_nikitin091980@postgrespro.ru", "phone": "+70466588505"}
0005432384153	F28A86	7987 524800	EVGENIY KUZNECOV	{"phone": "+70154204554"}
0005432384154	0829DE	6526 526614	LEV KARPOV	{"email": "karpov-l-041975@postgrespro.ru", "phone": "+70626547671"}
0005432384155	7FE54B	5079 566932	VLADIMIR KRASNOV	{"email": "krasnov.vladimir-011964@postgrespro.ru", "phone": "+70626072843"}
0005432384156	7FE54B	2638 376486	ROMAN NIKITIN	{"email": "nikitin_r_1969@postgrespro.ru", "phone": "+70728086259"}
0005432384157	4441F9	3745 924018	LYUDMILA ANDREEVA	{"email": "andreeva_lyudmila_121982@postgrespro.ru", "phone": "+70411780364"}
0005432384158	7B9211	5578 093255	YULIYA SMIRNOVA	{"phone": "+70820970917"}
0005432384159	7B9211	8829 766021	ANTONINA POPOVA	{"phone": "+70658280202"}
0005432384160	393148	4924 775475	RASHID RODIONOV	{"email": "rashidrodionov1974@postgrespro.ru", "phone": "+70305459908"}
0005432384161	CB18C5	5198 542218	VIKTOR GORBUNOV	{"phone": "+70433986224"}
0005432384162	D9F0CD	1460 393994	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova021984@postgrespro.ru", "phone": "+70839728300"}
0005432384163	D9F0CD	8297 717141	OLGA AFANASEVA	{"phone": "+70438037159"}
0005432384164	8E5DBC	9992 946711	SERGEY SMIRNOV	{"email": "smirnov_sergey.101965@postgrespro.ru", "phone": "+70983018023"}
0005432384165	8E5DBC	5123 391742	ALEKSANDR SMIRNOV	{"phone": "+70062190106"}
0005432384166	B79634	3008 284172	LYUDMILA ILINA	{"phone": "+70603435382"}
0005432384167	695958	2251 710745	VALENTINA SCHERBAKOVA	{"email": "valentinascherbakova1971@postgrespro.ru", "phone": "+70362669524"}
0005432384168	63AF1C	1105 017446	ANATOLIY PETROV	{"email": "apetrov121960@postgrespro.ru", "phone": "+70647018641"}
0005432384169	6DE693	4686 673143	VIKTORIYA BARANOVA	{"phone": "+70445692090"}
0005432384170	6DE693	4231 227931	SERGEY SOLOVEV	{"phone": "+70338485495"}
0005432384171	7F1D0B	7600 047068	ANATOLIY POPOV	{"phone": "+70139896707"}
0005432384172	DB9BB6	8584 772424	ALEKSEY PETROV	{"phone": "+70369726491"}
0005432384173	B60BFC	6079 519139	VLADIMIR CHERNOV	{"email": "chernovv_1970@postgrespro.ru", "phone": "+70182519727"}
0005432384174	E64CE5	6024 624147	SVETLANA ZAYCEVA	{"email": "zaycevasvetlana_121979@postgrespro.ru", "phone": "+70017450512"}
0005432384175	E64CE5	7296 872656	NADEZHDA SMIRNOVA	{"phone": "+70693291850"}
0005432384176	43B47E	8236 583580	IRINA ANISIMOVA	{"email": "anisimova.irina-11021967@postgrespro.ru", "phone": "+70343790412"}
0005432384177	43B47E	5664 829007	SERGEY PAVLOV	{"phone": "+70555399580"}
0005432384178	C32DA0	3350 772928	MARIYA NIKITINA	{"email": "nikitina.m_18071966@postgrespro.ru", "phone": "+70670432197"}
0005432384179	BFFC7C	9490 488706	NATALYA MALYSHEVA	{"phone": "+70675792197"}
0005432384180	A637B1	4106 880518	MIKHAIL MIRONOV	{"email": "mikhail-mironov021970@postgrespro.ru", "phone": "+70487508119"}
0005432384181	A637B1	5220 928142	ALEKSEY KUZNECOV	{"email": "a.kuznecov091966@postgrespro.ru", "phone": "+70922965126"}
0005432384182	3ADF83	2368 926014	VALENTINA DAVYDOVA	{"phone": "+70512364914"}
0005432384183	3ADF83	5687 913665	ALEKSANDR DENISOV	{"email": "denisovaleksandr09011954@postgrespro.ru", "phone": "+70996884373"}
0005432384184	DAEB79	1763 605830	NINA NAUMOVA	{"email": "nina-naumova.1968@postgrespro.ru", "phone": "+70452477463"}
0005432384185	DAEB79	9283 499290	EKATERINA TITOVA	{"phone": "+70080615259"}
0005432384186	64DBA0	4663 311881	EVGENIY NAUMOV	{"phone": "+70168931215"}
0005432384187	148DAC	0497 125893	ALEKSEY MEDVEDEV	{"phone": "+70079506586"}
0005432384188	D49324	7395 269026	ELENA NIKITINA	{"phone": "+70349841591"}
0005432384189	D49324	4520 174538	SERGEY SERGEEV	{"email": "sergeev_s17111967@postgrespro.ru", "phone": "+70700190191"}
0005432384190	BAE109	1512 183753	FARIT IVANOV	{"email": "ivanovf021970@postgrespro.ru", "phone": "+70855304666"}
0005432384191	F0DC44	7308 836936	DMITRIY VOLKOV	{"email": "volkov-d081971@postgrespro.ru", "phone": "+70383074713"}
0005432384192	545CD6	4002 359388	ANNA VASILEVA	{"phone": "+70203846741"}
0005432384193	561121	6164 712307	DARYA SMIRNOVA	{"phone": "+70881537444"}
0005432384194	A941C8	5748 913240	ELVIRA KUZNECOVA	{"email": "e.kuznecova061962@postgrespro.ru", "phone": "+70541209840"}
0005432384195	3C257C	3461 362596	ALEKSANDR BELOV	{"phone": "+70207325960"}
0005432384196	524B7C	7187 857492	PETR MATVEEV	{"email": "matveev_p061981@postgrespro.ru", "phone": "+70730897629"}
0005432384197	D643D1	0978 512924	TAMARA FROLOVA	{"email": "frolova.t.29081967@postgrespro.ru", "phone": "+70550747693"}
0005432384198	EFCCF9	2077 095008	NATALYA POLYAKOVA	{"email": "n.polyakova1970@postgrespro.ru", "phone": "+70375455145"}
0005432384199	A8DA12	7374 007119	ANASTASIYA STEPANOVA	{"email": "stepanova-a-1970@postgrespro.ru", "phone": "+70909642446"}
0005432384200	75A7E6	0564 756595	EKATERINA TARASOVA	{"email": "tarasova.e16101975@postgrespro.ru", "phone": "+70548596069"}
0005432384201	1251EE	0680 917648	DANIIL RODIONOV	{"email": "d-rodionov.021969@postgrespro.ru", "phone": "+70180149635"}
0005432384202	3D1A12	3704 544573	YURIY SIDOROV	{"phone": "+70480351196"}
0005432384203	EC07CB	4216 081023	NELLYA FROLOVA	{"phone": "+70569340576"}
0005432384204	C323E4	8840 663621	MARIYA NESTEROVA	{"phone": "+70071386227"}
0005432384205	C323E4	1694 032110	ANASTASIYA NOVIKOVA	{"email": "anastasiya-novikova.1970@postgrespro.ru", "phone": "+70247914701"}
0005432384206	3AAC78	2284 578245	MAKSIM MEDVEDEV	{"phone": "+70435373913"}
0005432384207	3AAC78	7922 342391	DMITRIY DAVYDOV	{"email": "davydov_d_1967@postgrespro.ru", "phone": "+70718163968"}
0005432384208	09F756	9776 751410	ANDREY PETROV	{"phone": "+70906552849"}
0005432384209	09F756	8610 601523	ALEKSANDR GAVRILOV	{"phone": "+70235534900"}
0005432384210	C6E2CF	6778 810469	ALEKSEY IVANOV	{"phone": "+70128231631"}
0005432384211	A3551D	0515 591903	VALERIY MAKSIMOV	{"phone": "+70573595780"}
0005432384212	F35FB6	6692 957791	ILGIZ BONDARENKO	{"email": "bondarenko_ilgiz.031976@postgrespro.ru", "phone": "+70092421091"}
0005432384213	F35FB6	7759 184380	LYUDMILA GUSEVA	{"email": "guseva-l-081963@postgrespro.ru", "phone": "+70884803256"}
0005432384214	F35FB6	5186 161021	ALEKSEY ROMANOV	{"email": "a.romanov-27121971@postgrespro.ru", "phone": "+70525759947"}
0005432384215	72C27A	2268 545250	VALENTINA BELYAEVA	{"phone": "+70308194931"}
0005432384216	C2E75C	2462 750829	LIDIYA YAKOVLEVA	{"phone": "+70178904999"}
0005432384217	9D19D4	0931 831057	DMITRIY TIKHONOV	{"phone": "+70106641414"}
0005432384218	9D19D4	6923 218684	MIKHAIL MAKAROV	{"phone": "+70997682243"}
0005432384219	B71882	2829 097389	NADEZHDA GUSEVA	{"email": "nadezhda_guseva011965@postgrespro.ru", "phone": "+70855978458"}
0005432384220	A002E7	3272 705541	ULYANA LEBEDEVA	{"email": "ulebedeva101974@postgrespro.ru", "phone": "+70803871442"}
0005432384221	8888B4	0779 661574	VASILIY CHERNOV	{"phone": "+70371159567"}
0005432384222	8888B4	0217 907979	NAILYA FEDOROVA	{"email": "fedorovanailya.061983@postgrespro.ru", "phone": "+70680049154"}
0005432384223	7FCFAA	0981 191865	RADIK ZAKHAROV	{"phone": "+70710180379"}
0005432384224	7FCFAA	7413 056395	NADEZHDA ROMANOVA	{"phone": "+70415604636"}
0005432384225	48094C	8796 288191	NATALYA GAVRILOVA	{"phone": "+70862497521"}
0005432384226	48094C	4540 378039	VERA KRASNOVA	{"email": "v.krasnova.041969@postgrespro.ru", "phone": "+70270129833"}
0005432384227	720729	4624 985799	ALEKSANDR TARASOV	{"email": "a.tarasov-14061970@postgrespro.ru", "phone": "+70826587931"}
0005432384228	B85E49	6158 437851	ALEKSEY NIKITIN	{"phone": "+70989806055"}
0005432384229	B85E49	5252 550362	VYACHESLAV SAVELEV	{"phone": "+70974665906"}
0005432390114	E91CEC	0194 521983	ARTEM NIKITIN	{"phone": "+70191169689"}
0005432384230	B59F9A	2206 214123	YULIYA KOROLEVA	{"email": "koroleva.y_1979@postgrespro.ru", "phone": "+70501495897"}
0005432384231	4B9BD2	6223 458902	MARINA ABRAMOVA	{"phone": "+70501480280"}
0005432384232	3501B9	3588 327061	OLEG IVANOV	{"email": "o.ivanov_13021977@postgrespro.ru", "phone": "+70282544411"}
0005432384233	3F9E9A	1172 828874	ALEKSEY AFANASEV	{"phone": "+70674029875"}
0005432384234	C337D6	2251 231781	EDUARD EGOROV	{"email": "eegorov.061967@postgrespro.ru", "phone": "+70328931868"}
0005432384235	63E9C8	5412 229032	ALEKSANDR GRIGOREV	{"email": "a_grigorev-061967@postgrespro.ru", "phone": "+70714777390"}
0005432384236	C0121D	2974 095352	KSENIYA KULIKOVA	{"phone": "+70875026626"}
0005432384237	C0121D	1513 779543	EVA PAVLOVA	{"email": "pavlova_e_091968@postgrespro.ru", "phone": "+70101470629"}
0005432384238	C0121D	8977 447120	DENIS SERGEEV	{"phone": "+70375636795"}
0005432384239	782754	7127 237049	MARIYA KAZAKOVA	{"phone": "+70981350022"}
0005432384240	6F925D	6180 871744	VALENTINA POLYAKOVA	{"email": "vpolyakova-23111969@postgrespro.ru", "phone": "+70351113934"}
0005432384241	6F925D	1178 377249	EVGENIYA SEMENOVA	{"phone": "+70134901617"}
0005432384242	32FB6E	9363 697965	OKSANA SOROKINA	{"phone": "+70388198613"}
0005432384243	036DD0	4824 418741	NIKOLAY KUZNECOV	{"email": "nikolaykuznecov-23091980@postgrespro.ru", "phone": "+70690194455"}
0005432384244	3BE676	0459 151816	NINA SEMENOVA	{"email": "semenovan1970@postgrespro.ru", "phone": "+70557016725"}
0005432384245	3BE676	1919 235589	EVGENIYA ZAKHAROVA	{"phone": "+70548957605"}
0005432384246	2AB480	8079 359325	GALINA SCHERBAKOVA	{"phone": "+70654205495"}
0005432384247	4DB382	0735 818302	ALFIYA ZHURAVLEVA	{"phone": "+70741925269"}
0005432384248	902607	8561 461609	ALEKSEY FEDOROV	{"email": "fedorov-aleksey-28121970@postgrespro.ru", "phone": "+70668799947"}
0005432384249	7CFE4A	9793 344041	ALEKSEY KUZNECOV	{"phone": "+70100632450"}
0005432384250	023876	3251 986199	ROMAN GAVRILOV	{"email": "gavrilov.r031972@postgrespro.ru", "phone": "+70210329502"}
0005432384251	C7851E	8483 717514	NIKOLAY PETROV	{"email": "petrov.n_01041976@postgrespro.ru", "phone": "+70059355324"}
0005432384252	BCF102	1470 162763	ANTON ZHUKOV	{"phone": "+70833794611"}
0005432384253	BCF102	6235 895229	NINA PETROVA	{"email": "nina_petrova_04041975@postgrespro.ru", "phone": "+70132961451"}
0005432384254	C052A3	8182 253088	VERA MAKAROVA	{"phone": "+70668377328"}
0005432384255	11CB97	4166 272275	VALENTINA KUZNECOVA	{"email": "kuznecova-v07041975@postgrespro.ru", "phone": "+70367692615"}
0005432384256	D26FEE	4507 760780	IVAN MEDVEDEV	{"email": "medvedev_ivan26041976@postgrespro.ru", "phone": "+70879224016"}
0005432384257	D93A69	1936 954842	ROMAN YAKOVLEV	{"email": "yakovlev_roman021978@postgrespro.ru", "phone": "+70535476088"}
0005432384258	943030	4911 592259	DIANA FROLOVA	{"email": "d.frolova_091970@postgrespro.ru", "phone": "+70005326214"}
0005432384259	7E044D	5064 332992	BORIS OSIPOV	{"email": "boris_osipov_21051983@postgrespro.ru", "phone": "+70669190776"}
0005432384260	24DA81	7404 046135	OLEG MEDVEDEV	{"email": "o.medvedev.26071963@postgrespro.ru", "phone": "+70228253855"}
0005432384261	24DA81	3584 744776	LYUDMILA ERMAKOVA	{"email": "l.ermakova_081971@postgrespro.ru", "phone": "+70100749188"}
0005432384262	B0A867	6129 150623	OLGA MELNIKOVA	{"email": "melnikova-o-1976@postgrespro.ru", "phone": "+70255779297"}
0005432384263	B0A867	5258 021056	ANDREY NAZAROV	{"phone": "+70666847010"}
0005432384264	6DEE73	0511 446192	EVGENIY MOROZOV	{"email": "evgeniymorozov-011967@postgrespro.ru", "phone": "+70012423707"}
0005432384265	EF2C85	6068 394056	SVETLANA FROLOVA	{"phone": "+70750859684"}
0005432384266	EF2C85	1377 695985	MARIYA EFIMOVA	{"email": "efimova.m-121970@postgrespro.ru", "phone": "+70775917342"}
0005432384267	511F44	7506 191429	VADIM NIKOLAEV	{"email": "vadim-nikolaev1961@postgrespro.ru", "phone": "+70715347119"}
0005432384268	6DFD43	3149 614475	MARINA FROLOVA	{"email": "m-frolova_021981@postgrespro.ru", "phone": "+70471038075"}
0005432384269	3A7B05	9735 373961	EVGENIY DENISOV	{"email": "denisove_081969@postgrespro.ru", "phone": "+70622427743"}
0005432384270	47B1C9	9492 108596	LILIYA ZAKHAROVA	{"email": "zakharova-liliya.28061966@postgrespro.ru", "phone": "+70796005703"}
0005432384271	DF8981	7061 141650	ALEKSANDR BELOV	{"email": "belov.a-08011967@postgrespro.ru", "phone": "+70165357645"}
0005432384272	34BC29	6619 187016	DARYA SIDOROVA	{"email": "sidorova-darya29061974@postgrespro.ru", "phone": "+70971964289"}
0005432384273	34BC29	4492 036770	MAKSIM KRASNOV	{"phone": "+70682579731"}
0005432384274	9D7191	5630 767028	NINA SOROKINA	{"email": "sorokinan_17031977@postgrespro.ru", "phone": "+70570191568"}
0005432384275	9D7191	6744 970408	ELENA AFANASEVA	{"email": "elena_afanaseva_061969@postgrespro.ru", "phone": "+70664752816"}
0005432384276	57B768	7797 821155	RAISA KOMAROVA	{"email": "raisa-komarova_1993@postgrespro.ru", "phone": "+70147654863"}
0005432384277	57B768	1025 857201	TATYANA KOVALEVA	{"phone": "+70696434653"}
0005432384278	A2E252	6148 300864	ALEKSANDR MATVEEV	{"email": "matveev-aleksandr.021981@postgrespro.ru", "phone": "+70175252847"}
0005432384279	D53250	7821 506206	KIRILL KULIKOV	{"phone": "+70287808623"}
0005432384280	D53250	1145 494108	LUIZA MASLOVA	{"email": "masloval_27021969@postgrespro.ru", "phone": "+70965390377"}
0005432384281	D53250	8370 672598	RAISA KUZNECOVA	{"email": "kuznecova-r1969@postgrespro.ru", "phone": "+70672079395"}
0005432384282	DC1CF8	4009 841606	VASILIY MAKAROV	{"phone": "+70722393035"}
0005432384283	DC1CF8	5609 798285	OLGA KALININA	{"email": "olga.kalinina-15041983@postgrespro.ru", "phone": "+70385380373"}
0005432384284	97503C	2595 235464	ANASTASIYA KAZAKOVA	{"email": "akazakova_07121972@postgrespro.ru", "phone": "+70562945297"}
0005432384285	0098BD	7463 525127	ALEKSANDR KISELEV	{"phone": "+70963272323"}
0005432384286	1E3F46	8424 856344	IVAN KAZAKOV	{"phone": "+70757197591"}
0005432384287	A90D10	6232 800635	ANNA SERGEEVA	{"phone": "+70996380769"}
0005432384288	D212D5	6099 491247	MAKSIM GORBUNOV	{"email": "maksim-gorbunov.06051976@postgrespro.ru", "phone": "+70743245278"}
0005432384289	D212D5	3694 692964	ARINA KUZNECOVA	{"email": "a.kuznecova111984@postgrespro.ru", "phone": "+70263311786"}
0005432384290	69BB3A	4191 615408	OLESYA POPOVA	{"phone": "+70767210352"}
0005432384291	ED32F3	7942 825743	VLADIMIR VOLKOV	{"phone": "+70889206291"}
0005432384292	ED32F3	8789 054453	ALEKSANDR AFANASEV	{"phone": "+70564591059"}
0005432384293	78485F	7821 171361	GENNADIY ISAEV	{"email": "isaevg01061976@postgrespro.ru", "phone": "+70716353896"}
0005432384294	AAB63A	4481 931799	LYUBOV FOMINA	{"phone": "+70974217960"}
0005432384295	B721F7	2816 184493	TATYANA ANTONOVA	{"phone": "+70015881419"}
0005432384296	A2F7D5	6688 120260	LYUDMILA IVANOVA	{"email": "ivanova-l-1961@postgrespro.ru", "phone": "+70193278964"}
0005432384297	190EE9	8663 315468	ALEKSANDR ZAYCEV	{"phone": "+70016491544"}
0005432384298	190EE9	6627 251638	IRINA YAKOVLEVA	{"email": "yakovleva_irina-1980@postgrespro.ru", "phone": "+70801998045"}
0005432384299	D4D18A	0960 490292	NADEZHDA MIRONOVA	{"email": "mironovanadezhda.071979@postgrespro.ru", "phone": "+70778953141"}
0005432384300	78E998	7091 327347	DARYA TARASOVA	{"email": "tarasova-d-02051959@postgrespro.ru", "phone": "+70660565806"}
0005432384301	86FE42	1575 769514	NATALYA ALEKSANDROVA	{"phone": "+70675792227"}
0005432384302	8560FD	7307 266167	ANATOLIY CHERNOV	{"email": "chernov-anatoliy_061967@postgrespro.ru", "phone": "+70755513871"}
0005432384303	8560FD	9631 043465	SERGEY KOROLEV	{"phone": "+70780234733"}
0005432384304	6CADB8	5892 760608	GALINA KOLESNIKOVA	{"email": "kolesnikovag-1972@postgrespro.ru", "phone": "+70861888605"}
0005432384305	DA7E2A	5315 135859	ALEKSANDR KUZMIN	{"email": "akuzmin1964@postgrespro.ru", "phone": "+70184292823"}
0005432384306	DA7E2A	9994 917338	NINA NIKOLAEVA	{"email": "nnikolaeva-061966@postgrespro.ru", "phone": "+70323260226"}
0005432384307	386E29	4131 595234	POLINA IVANOVA	{"phone": "+70063327203"}
0005432384308	8E2EDF	1434 507776	TATYANA KUZNECOVA	{"email": "kuznecovat03041971@postgrespro.ru", "phone": "+70349779401"}
0005432384309	B50C76	3546 910462	MIKHAIL ABRAMOV	{"email": "abramov.m-021982@postgrespro.ru", "phone": "+70538428331"}
0005432384310	F968E6	9001 866288	ANATOLIY KUZNECOV	{"email": "kuznecov-anatoliy111973@postgrespro.ru", "phone": "+70038387863"}
0005432384311	3F066B	3587 777055	VLADIMIR MARTYNOV	{"email": "martynovvladimir.1969@postgrespro.ru", "phone": "+70807416857"}
0005432384312	6762B8	4502 813801	TATYANA ZAYCEVA	{"phone": "+70218528333"}
0005432384313	7D2315	9297 787873	NADEZHDA NESTEROVA	{"phone": "+70763232933"}
0005432384314	F8C66C	8060 453894	ALEKSEY KONOVALOV	{"email": "aleksey-konovalov1975@postgrespro.ru", "phone": "+70245898522"}
0005432384315	F8C66C	4417 074714	VIKTORIYA BOGDANOVA	{"email": "v_bogdanova.1981@postgrespro.ru", "phone": "+70972785700"}
0005432384316	F237E1	5454 839964	MATVEY KUZNECOV	{"email": "matveykuznecov_1975@postgrespro.ru", "phone": "+70033118800"}
0005432384317	D773CF	5865 741941	ELENA MATVEEVA	{"phone": "+70308786442"}
0005432384318	BC8C52	1304 202790	OLEG POPOV	{"phone": "+70424875653"}
0005432384319	BC8C52	6941 853802	DMITRIY ALEKSANDROV	{"phone": "+70627977854"}
0005432384320	DDF3F9	2781 132315	MARIYA KULIKOVA	{"email": "mariyakulikova12121975@postgrespro.ru", "phone": "+70548875707"}
0005432384321	DDF3F9	8926 655871	NELLI SERGEEVA	{"email": "sergeeva.n_1960@postgrespro.ru", "phone": "+70791172039"}
0005432384322	D5CA5D	6008 228672	GERMAN MELNIKOV	{"phone": "+70593082575"}
0005432384323	D5CA5D	1512 676050	VLADIMIR BONDARENKO	{"email": "bondarenko_vladimir121976@postgrespro.ru", "phone": "+70020305661"}
0005432384324	3C8522	1714 037270	ELENA RODIONOVA	{"email": "elenarodionova-20081977@postgrespro.ru", "phone": "+70325316644"}
0005432384325	AD1DCE	0866 355782	TATYANA MASLOVA	{"email": "tatyana_maslova1973@postgrespro.ru", "phone": "+70209968642"}
0005432384326	33741C	5888 625102	TATYANA MASLOVA	{"phone": "+70453067685"}
0005432384327	576B8C	7760 930010	ILNUR SOROKIN	{"phone": "+70844304498"}
0005432384328	576B8C	1145 318598	ELENA MIRONOVA	{"phone": "+70078303515"}
0005432384329	576B8C	3860 024628	TATYANA EFIMOVA	{"email": "efimova_t_1965@postgrespro.ru", "phone": "+70434146293"}
0005432384330	B1311B	3379 111032	DINA KAZAKOVA	{"phone": "+70624376157"}
0005432384331	57B2D0	9425 010760	ANATOLIY IVANOV	{"phone": "+70937694494"}
0005432384332	57B2D0	8375 601015	ANASTASIYA KOVALEVA	{"phone": "+70407017273"}
0005432384333	F6F338	6985 856471	ELENA ALEKSANDROVA	{"phone": "+70515006613"}
0005432384334	F6F338	1850 761356	TIMOFEY ANTONOV	{"email": "t.antonov.091965@postgrespro.ru", "phone": "+70819777542"}
0005432384335	F6F338	6236 114542	ALEKSEY NIKOLAEV	{"email": "nikolaev.a.1969@postgrespro.ru", "phone": "+70858291689"}
0005432384336	D56F95	1534 038771	GALINA GUSEVA	{"phone": "+70058294851"}
0005432384337	D56F95	2864 491425	VLADIMIR KUZNECOV	{"email": "vkuznecov-111958@postgrespro.ru", "phone": "+70860044907"}
0005432384338	3AC1BA	9886 479497	VYACHESLAV TIKHONOV	{"email": "tikhonovvyacheslav091969@postgrespro.ru", "phone": "+70083713561"}
0005432384339	F6A256	2343 431012	SERGEY NIKOLAEV	{"email": "sergeynikolaev_02091964@postgrespro.ru", "phone": "+70691074505"}
0005432384340	83D0AF	9819 353539	INNA ALEKSEEVA	{"phone": "+70361709160"}
0005432384341	83D0AF	0873 880691	OLGA MOISEEVA	{"email": "moiseeva.olga02071973@postgrespro.ru", "phone": "+70187484220"}
0005432384342	83D0AF	9947 929010	MARIYA NIKITINA	{"phone": "+70901752944"}
0005432384343	3DA0CB	8191 363556	MARIYA MIKHAYLOVA	{"phone": "+70089907380"}
0005432390003	84C398	7794 439749	VLADIMIR SOROKIN	{"phone": "+70870596082"}
0005432389933	38CB81	2976 579084	NADEZHDA KOROLEVA	{"phone": "+70325838606"}
0005432389934	38CB81	6241 061597	SVYATOSLAV ZAKHAROV	{"email": "zakharov_s121966@postgrespro.ru", "phone": "+70563352589"}
0005432389935	AD9A43	1322 826773	NATALYA ROMANOVA	{"phone": "+70478485505"}
0005432389936	AD9A43	5189 866210	VYACHESLAV SOKOLOV	{"email": "v_sokolov.24021974@postgrespro.ru", "phone": "+70032340270"}
0005432389937	BF3B53	8961 288508	GALINA IVANOVA	{"email": "g_ivanova-1962@postgrespro.ru", "phone": "+70146311135"}
0005432389938	4B4BC6	9739 726096	GENNADIY ANDREEV	{"email": "andreev_g-111968@postgrespro.ru", "phone": "+70202583192"}
0005432389939	D9AE2C	9831 551492	ALEKSEY KAZAKOV	{"phone": "+70658345128"}
0005432389940	2B711C	3099 177945	ALEKSEY MAKAROV	{"phone": "+70461723688"}
0005432389941	FD4FEF	6914 390646	YAN ZHUKOV	{"email": "zhukov-y-1969@postgrespro.ru", "phone": "+70777967178"}
0005432389942	AC8D01	1996 190799	NINA MASLOVA	{"email": "ninamaslova.11111972@postgrespro.ru", "phone": "+70308962626"}
0005432389943	70C4F3	2488 024381	OLGA ILINA	{"email": "o-ilina_1963@postgrespro.ru", "phone": "+70335966655"}
0005432389944	436043	6818 286146	DMITRIY SOKOLOV	{"phone": "+70688254338"}
0005432389945	3B836C	0536 152934	KSENIYA ZHURAVLEVA	{"email": "k.zhuravleva24051980@postgrespro.ru", "phone": "+70703985571"}
0005432389946	62D814	4615 995435	RAVIL GUSEV	{"email": "rgusev.11121972@postgrespro.ru", "phone": "+70216096802"}
0005432389947	0901B5	0810 281703	ALEKSANDRA POPOVA	{"phone": "+70553127008"}
0005432389948	DD5D82	0502 162958	ANDREY NAUMOV	{"email": "naumov_a-09041980@postgrespro.ru", "phone": "+70884631963"}
0005432389949	DD5D82	1385 338019	LIDIYA PETROVA	{"email": "petrova.lidiya06101972@postgrespro.ru", "phone": "+70183352384"}
0005432389950	CE7761	6574 268513	NINA LAZAREVA	{"email": "nlazareva_1973@postgrespro.ru", "phone": "+70213543667"}
0005432389951	E242EF	9894 829863	ALEKSANDR BORISOV	{"email": "aleksandr.borisov_081963@postgrespro.ru", "phone": "+70691168069"}
0005432389952	E242EF	1857 526749	ALEKSEY ZAKHAROV	{"email": "zakharova1965@postgrespro.ru", "phone": "+70869388917"}
0005432389953	86A380	6111 845708	VALENTINA MIRONOVA	{"phone": "+70854310083"}
0005432389954	812DDB	2805 876697	ANASTASIYA POPOVA	{"email": "anastasiya-popova101973@postgrespro.ru", "phone": "+70209221791"}
0005432389955	812DDB	4094 189211	ELENA ZAKHAROVA	{"phone": "+70988845050"}
0005432389956	57C06A	3205 473522	ANNA MAKAROVA	{"email": "a_makarova-071973@postgrespro.ru", "phone": "+70315809930"}
0005432389957	99A566	8506 777087	ANDREY KUZNECOV	{"phone": "+70937008049"}
0005432389958	99A566	6054 813827	MAKSIM ORLOV	{"phone": "+70924146135"}
0005432389959	EE401F	8960 431460	KSENIYA KONOVALOVA	{"email": "kseniya-konovalova_29031986@postgrespro.ru", "phone": "+70870887657"}
0005432389960	772E6D	3550 565829	LYUDMILA BOGDANOVA	{"email": "lyudmila-bogdanova1985@postgrespro.ru", "phone": "+70682921520"}
0005432389961	772E6D	5025 707728	KHALIDA KAZAKOVA	{"phone": "+70818805900"}
0005432389962	A2E829	0882 342209	ELENA BORISOVA	{"phone": "+70346331887"}
0005432389963	6CFB77	0851 200015	GALINA SOROKINA	{"email": "sorokinag121965@postgrespro.ru", "phone": "+70130571997"}
0005432389964	6F092E	5804 232040	DENIS TIKHONOV	{"email": "tikhonovdenis.10091965@postgrespro.ru", "phone": "+70194081252"}
0005432389965	6E2584	2910 628519	NIKOLAY GRIGOREV	{"phone": "+70547745373"}
0005432389966	F8CB9D	4759 847970	VLADIMIR VASILEV	{"phone": "+70965037292"}
0005432389967	F8CB9D	8440 476825	ANASTASIYA ZHUKOVA	{"email": "a.zhukova.1979@postgrespro.ru", "phone": "+70506771236"}
0005432389968	F7986F	3333 734310	RASHID MIKHAYLOV	{"email": "rmikhaylov-1968@postgrespro.ru", "phone": "+70899963937"}
0005432389969	08A9A7	7268 396811	MARGARITA IVANOVA	{"email": "ivanova_m15061980@postgrespro.ru", "phone": "+70761492882"}
0005432389970	08A9A7	1894 710245	YURIY BELOV	{"email": "belov-yuriy.1982@postgrespro.ru", "phone": "+70748244090"}
0005432389971	0EC339	1149 193232	MARINA IVANOVA	{"email": "ivanova-m1971@postgrespro.ru", "phone": "+70460866470"}
0005432389972	85237E	8592 514697	DMITRIY TIMOFEEV	{"email": "timofeev-d031966@postgrespro.ru", "phone": "+70323717261"}
0005432389973	807BD2	2367 283446	EKATERINA NAUMOVA	{"phone": "+70169481350"}
0005432389974	AE6E9B	3978 947033	SERGEY VASILEV	{"phone": "+70077555658"}
0005432389975	94D534	7013 442532	PAVEL KOZLOV	{"phone": "+70838127322"}
0005432389976	94D534	8547 809450	DARYA PETROVA	{"email": "dpetrova.031972@postgrespro.ru", "phone": "+70574163814"}
0005432389977	C33132	8887 847064	EVGENIY MIKHAYLOV	{"email": "mikhaylov_evgeniy.101966@postgrespro.ru", "phone": "+70062989666"}
0005432389978	C33132	1038 957720	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov-061980@postgrespro.ru", "phone": "+70257642855"}
0005432389979	E9647C	0443 285830	PETR NIKOLAEV	{"email": "petrnikolaev.1972@postgrespro.ru", "phone": "+70392128582"}
0005432389980	C3A5A8	2590 195059	VYACHESLAV MAKSIMOV	{"email": "vyacheslav_maksimov.1973@postgrespro.ru", "phone": "+70434061493"}
0005432389981	1475AB	2496 235858	MIKHAIL KARPOV	{"email": "karpov-mikhail061973@postgrespro.ru", "phone": "+70245098623"}
0005432389982	B38A80	0531 787758	ARTEM KUZNECOV	{"email": "artem.kuznecov_071968@postgrespro.ru", "phone": "+70062782427"}
0005432389983	B38A80	8312 187163	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov_03021972@postgrespro.ru", "phone": "+70069821106"}
0005432389984	E52BF5	9263 590198	MIKHAIL SHEVCHENKO	{"phone": "+70235131624"}
0005432389985	C06FD7	6227 657812	ALEKSANDR PETROV	{"email": "apetrov.12011977@postgrespro.ru", "phone": "+70064665912"}
0005432389986	E2173D	6192 396669	BORIS NOVIKOV	{"email": "b.novikov061969@postgrespro.ru", "phone": "+70446369755"}
0005432389987	9D8718	8566 960316	IRINA GUSEVA	{"email": "irina.guseva_15031961@postgrespro.ru", "phone": "+70337198749"}
0005432389988	9D8718	0828 680605	MIKHAIL NAZAROV	{"phone": "+70068771212"}
0005432389989	FF81FA	6051 570442	VLADIMIR ZHURAVLEV	{"phone": "+70127318296"}
0005432389990	FF81FA	1053 497792	LYUBOV SOROKINA	{"phone": "+70067037118"}
0005432389991	5C38C8	5520 202442	OLGA MIKHAYLOVA	{"email": "olga-mikhaylova.1965@postgrespro.ru", "phone": "+70412856965"}
0005432389992	BFF00A	4554 272998	OLGA KONDRATEVA	{"phone": "+70911043377"}
0005432389993	BFF00A	2083 548972	ALENA EGOROVA	{"email": "alena.egorova051970@postgrespro.ru", "phone": "+70313206321"}
0005432389994	4D8B20	4836 854243	ELENA ABRAMOVA	{"email": "e.abramova-20011983@postgrespro.ru", "phone": "+70428838785"}
0005432389995	4D8B20	4844 424229	EKATERINA KOLESNIKOVA	{"phone": "+70217951012"}
0005432389996	4D8B20	7748 567287	MARGARITA ROMANOVA	{"email": "romanova-m.1973@postgrespro.ru", "phone": "+70469677775"}
0005432389997	0DF1C8	2617 905276	MARAT MOISEEV	{"phone": "+70112290273"}
0005432389998	694235	0239 439461	TATYANA SIDOROVA	{"phone": "+70476577899"}
0005432389999	694235	4806 220336	ANDREY NAUMOV	{"phone": "+70124232877"}
0005432390000	94E87D	4475 283456	VALENTINA DENISOVA	{"email": "valentina.denisova-121978@postgrespro.ru", "phone": "+70560113605"}
0005432390001	303055	4470 852403	VLADIMIR MAKAROV	{"phone": "+70842926212"}
0005432390002	6C53C7	5656 255753	ALEKSANDR VLASOV	{"email": "a.vlasov.111969@postgrespro.ru", "phone": "+70916141468"}
0005432390004	84C398	4681 165090	ALLA KUDRYASHOVA	{"phone": "+70529638323"}
0005432390005	1F7286	1613 227292	ZINAIDA ABRAMOVA	{"phone": "+70852752857"}
0005432390006	B55A60	0964 366245	KIRA NIKIFOROVA	{"phone": "+70589083909"}
0005432390007	EEAAEB	0699 234046	RASHIT RODIONOV	{"email": "rashit.rodionov.15071972@postgrespro.ru", "phone": "+70765445917"}
0005432390008	7A1BE1	8119 192066	TAMARA TARASOVA	{"email": "tarasova.t081973@postgrespro.ru", "phone": "+70105571547"}
0005432390009	56D28A	4196 333772	NINA VASILEVA	{"phone": "+70262393973"}
0005432390010	56D28A	9956 590976	ELENA KUZMINA	{"email": "elenakuzmina-09121957@postgrespro.ru", "phone": "+70310441301"}
0005432390011	CE7F73	9706 973823	ALEKSANDR ZHUKOV	{"phone": "+70818113206"}
0005432390012	F0EE49	8494 306933	VASILIY SERGEEV	{"email": "v.sergeev_071959@postgrespro.ru", "phone": "+70993947884"}
0005432390013	9C5A26	5523 473781	ANDREY TARASOV	{"email": "tarasov-andrey_1968@postgrespro.ru", "phone": "+70800504518"}
0005432390014	B94D53	9440 456634	EDUARD FROLOV	{"email": "frolov_e.1966@postgrespro.ru", "phone": "+70149222442"}
0005432390015	B94D53	9609 148977	EKATERINA MIRONOVA	{"email": "e.mironova051977@postgrespro.ru", "phone": "+70120380981"}
0005432390016	C8647C	0109 315249	ANDREY BARANOV	{"email": "baranov_a-20021963@postgrespro.ru", "phone": "+70377152186"}
0005432390017	C8647C	1577 785012	LYUDMILA POLYAKOVA	{"email": "polyakova_l_1962@postgrespro.ru", "phone": "+70826987781"}
0005432390018	C665E9	1591 220888	LIDIYA STEPANOVA	{"email": "lidiya.stepanova_31121969@postgrespro.ru", "phone": "+70344872491"}
0005432390019	1FD2F0	4642 855376	LARISA SOKOLOVA	{"phone": "+70810783855"}
0005432390020	1FD2F0	6268 509841	ALEKSEY IVANOV	{"email": "aleksey.ivanov_1977@postgrespro.ru", "phone": "+70482959681"}
0005432390021	1FD2F0	9117 191363	EVGENIY MELNIKOV	{"phone": "+70150670493"}
0005432390022	7795D4	2720 108760	TATYANA VASILEVA	{"email": "t.vasileva.101966@postgrespro.ru", "phone": "+70286459859"}
0005432390023	7795D4	7577 972792	MAKSIM FEDOROV	{"phone": "+70029199298"}
0005432390024	4E1B76	3318 195920	KIRILL KULIKOV	{"email": "kulikov_kirill_1975@postgrespro.ru", "phone": "+70816507587"}
0005432390025	8CD17A	7482 233003	DARYA ZAYCEVA	{"phone": "+70275034373"}
0005432390026	8CD17A	3618 748394	EGOR GRIGOREV	{"email": "egorgrigorev1970@postgrespro.ru", "phone": "+70223463130"}
0005432390027	FBF5D5	3972 005839	ANZHELA NIKITINA	{"email": "anzhela.nikitina121960@postgrespro.ru", "phone": "+70826542278"}
0005432390028	355F0D	0088 044356	ROZALIYA ALEKSANDROVA	{"phone": "+70563717946"}
0005432390029	3885AC	9788 965269	MARINA KUZNECOVA	{"phone": "+70285829316"}
0005432390030	7B3D4F	0749 220295	LYUDMILA SAVELEVA	{"email": "saveleva.lyudmila_1968@postgrespro.ru", "phone": "+70709536363"}
0005432390031	A36DD6	1672 503676	ANNA IVANOVA	{"email": "ivanovaanna-1970@postgrespro.ru", "phone": "+70430974503"}
0005432390032	CD6B58	2156 533174	OLGA ALEKSANDROVA	{"email": "o.aleksandrova20081981@postgrespro.ru", "phone": "+70455511492"}
0005432390033	357B8C	8127 185682	NATALIYA KUZMINA	{"phone": "+70015916776"}
0005432390034	CF610D	1017 745948	VASILIY TARASOV	{"phone": "+70637056337"}
0005432390035	373EEA	4391 646877	MARIYA MOROZOVA	{"email": "morozova_m_19071984@postgrespro.ru", "phone": "+70870118620"}
0005432390036	CF51BE	0521 149887	ANASTASIYA ANDREEVA	{"email": "andreeva_a.021976@postgrespro.ru", "phone": "+70266698491"}
0005432390037	51B29D	4903 908837	VYACHESLAV CHERNOV	{"email": "chernovvyacheslav1974@postgrespro.ru", "phone": "+70461867678"}
0005432390038	51B29D	7698 369725	ARSEN RODIONOV	{"email": "rodionov-arsen_1968@postgrespro.ru", "phone": "+70312816706"}
0005432390039	C72F55	0610 206688	NINA VASILEVA	{"phone": "+70719439837"}
0005432390040	F44A15	0053 250075	ALEKSANDRA IVANOVA	{"phone": "+70158324609"}
0005432390041	F44A15	0942 661668	ALEKSEY ANDREEV	{"email": "andreev_a.1980@postgrespro.ru", "phone": "+70329323304"}
0005432390042	4BF20B	6417 683270	ALEKSANDR SOKOLOV	{"email": "sokolov.a-041972@postgrespro.ru", "phone": "+70212312974"}
0005432390043	4BF20B	5773 930322	NELLYA MIKHAYLOVA	{"phone": "+70833295105"}
0005432390044	EE55E9	4379 206257	EKATERINA MIRONOVA	{"email": "mironova-ekaterina.1975@postgrespro.ru", "phone": "+70713287237"}
0005432390045	EE55E9	0036 692932	POLINA IVANOVA	{"phone": "+70042469384"}
0005432390046	B7EEBD	9219 725588	MARINA NAZAROVA	{"email": "nazarova_m_1982@postgrespro.ru", "phone": "+70602148974"}
0005432390047	B7EEBD	2058 100667	OLGA ROMANOVA	{"phone": "+70978804751"}
0005432390048	B75BF9	8639 633618	MAKSIM ALEKSEEV	{"email": "alekseevmaksim26031975@postgrespro.ru", "phone": "+70113674124"}
0005432390049	B75BF9	2637 144278	LYUBOV MEDVEDEVA	{"phone": "+70260400675"}
0005432390050	B75BF9	7934 195034	ANNA MAKSIMOVA	{"phone": "+70653546241"}
0005432390051	29729B	9379 625749	ALINA KUDRYASHOVA	{"phone": "+70658268119"}
0005432390052	024C03	6394 079042	NAIL SOKOLOV	{"email": "nail.sokolov_1975@postgrespro.ru", "phone": "+70833014318"}
0005432390053	50F837	3324 575106	ANAIT BARANOVA	{"email": "baranova-anait121974@postgrespro.ru", "phone": "+70431000483"}
0005432390054	50F837	2166 667023	DMITRIY POPOV	{"email": "popov_dmitriy.1972@postgrespro.ru", "phone": "+70024561166"}
0005432390055	50F837	6951 296444	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d-1985@postgrespro.ru", "phone": "+70960618326"}
0005432390056	50F837	7411 589800	TATYANA VLASOVA	{"email": "vlasova_tatyana1977@postgrespro.ru", "phone": "+70370107318"}
0005432390057	409770	2720 419348	GALINA MOISEEVA	{"phone": "+70726013093"}
0005432390058	409770	4930 649595	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin051982@postgrespro.ru", "phone": "+70363915994"}
0005432390059	409770	8460 802400	LYUBOV MOISEEVA	{"phone": "+70594898174"}
0005432390060	3F5D99	0423 205920	OLEG IVANOV	{"email": "ivanov.oleg1985@postgrespro.ru", "phone": "+70506985341"}
0005432390061	2E3F82	0645 284472	KONSTANTIN ANDREEV	{"email": "andreev_konstantin.07101965@postgrespro.ru", "phone": "+70279699948"}
0005432390062	FCFCE8	6103 779353	NIKOLAY POPOV	{"phone": "+70731714216"}
0005432390063	FCFCE8	9257 778645	VASILIY DAVYDOV	{"phone": "+70160550295"}
0005432390064	90A7A3	2177 319517	SVETLANA FOMINA	{"email": "s-fomina.1964@postgrespro.ru", "phone": "+70499940792"}
0005432390065	DC5F1A	7114 874932	LYUDMILA ILINA	{"email": "l-ilina_101976@postgrespro.ru", "phone": "+70495185636"}
0005432390066	D2E836	9511 285146	OLGA FEDOROVA	{"phone": "+70170804324"}
0005432390067	B93313	0914 204657	FILIPP SIDOROV	{"email": "sidorov_filipp-051982@postgrespro.ru", "phone": "+70751813097"}
0005432390068	EBB970	1458 411488	SERGEY GORBUNOV	{"phone": "+70779895481"}
0005432390069	EBB970	9951 969026	VIKTORIYA STEPANOVA	{"email": "vstepanova_1979@postgrespro.ru", "phone": "+70418309238"}
0005432390070	DBB836	2752 179144	DENIS SIDOROV	{"email": "sidorov-d_051958@postgrespro.ru", "phone": "+70536158749"}
0005432390071	DBB836	9647 396165	RASHID VLASOV	{"email": "vlasov_r.1969@postgrespro.ru", "phone": "+70404367006"}
0005432390072	DBB836	4204 525796	ALEKSANDR PAVLOV	{"phone": "+70254492590"}
0005432390073	E4AC35	7187 691024	VASILIY EGOROV	{"email": "egorov_v-121967@postgrespro.ru", "phone": "+70958442123"}
0005432390074	4BAF25	8311 813422	ELENA POPOVA	{"phone": "+70006562966"}
0005432390075	D0A7D8	3477 305097	ELENA EFIMOVA	{"phone": "+70514961928"}
0005432390076	B08027	6936 725356	SOFIYA VASILEVA	{"phone": "+70233670753"}
0005432390077	3268C4	7014 669767	VLADIMIR MOISEEV	{"email": "moiseevvladimir16011982@postgrespro.ru", "phone": "+70837952844"}
0005432390078	84D46D	8865 954335	ALEKSANDRA PAVLOVA	{"phone": "+70804644514"}
0005432390079	5C638F	0424 896178	MIKHAIL POPOV	{"email": "m-popov081972@postgrespro.ru", "phone": "+70977779830"}
0005432390080	BAAD3F	9958 568809	NATALYA MAKSIMOVA	{"email": "maksimova_n_1956@postgrespro.ru", "phone": "+70217357348"}
0005432390081	6084C3	7585 307181	MIKHAIL MAKAROV	{"email": "m_makarov041990@postgrespro.ru", "phone": "+70744831209"}
0005432390082	6084C3	0352 190271	RAISA DMITRIEVA	{"email": "r_dmitrieva-08121967@postgrespro.ru", "phone": "+70181910502"}
0005432390083	8F3DE2	1932 173194	VASILIY MOROZOV	{"email": "morozov_vasiliy_27091966@postgrespro.ru", "phone": "+70410106013"}
0005432390084	C77FEE	2669 318920	YAROSLAV ALEKSANDROV	{"email": "yaroslav-aleksandrov1967@postgrespro.ru", "phone": "+70282483560"}
0005432390085	C77FEE	6930 650685	IGOR SMIRNOV	{"email": "smirnov_igor-011959@postgrespro.ru", "phone": "+70457296488"}
0005432390086	CE8C4D	5539 368775	VIKTOR GRIGOREV	{"phone": "+70937618184"}
0005432390087	6F03A1	5481 286985	VALENTINA ZHURAVLEVA	{"phone": "+70605111181"}
0005432390088	047047	8841 601846	ARKADIY NIKOLAEV	{"phone": "+70985722120"}
0005432390089	BE5FCE	9104 052906	DARYA NOVIKOVA	{"phone": "+70583263857"}
0005432390090	BE5FCE	1120 387890	EVGENIYA EGOROVA	{"phone": "+70401540069"}
0005432390091	BE5FCE	9669 370531	DAMIR MIRONOV	{"email": "damir.mironov-09041977@postgrespro.ru", "phone": "+70379269368"}
0005432390092	FE895F	3859 068224	LYUBOV ANISIMOVA	{"phone": "+70940420536"}
0005432390093	FE895F	2427 961837	MARINA VASILEVA	{"phone": "+70156249027"}
0005432390094	0659DA	5683 189835	ANDREY MOROZOV	{"email": "andrey.morozov-101963@postgrespro.ru", "phone": "+70358253725"}
0005432390095	68BC42	5956 665857	OLGA POLYAKOVA	{"email": "opolyakova_17021957@postgrespro.ru", "phone": "+70280425680"}
0005432390096	68BC42	7103 403574	ALEKSANDRA MAKAROVA	{"phone": "+70836190681"}
0005432390097	F1C111	5957 351397	NINA VOLKOVA	{"email": "nina-volkova-041979@postgrespro.ru", "phone": "+70235274185"}
0005432390098	F1C111	9421 304107	DIANA NIKITINA	{"phone": "+70412042409"}
0005432390099	A123D5	3512 700112	YULIYA KOMAROVA	{"email": "y-komarova_05041969@postgrespro.ru", "phone": "+70518260391"}
0005432390100	A123D5	3843 746033	OLESYA KISELEVA	{"phone": "+70634116241"}
0005432390101	995AEF	4837 179065	RUDOLF MELNIKOV	{"email": "melnikov-r.19081976@postgrespro.ru", "phone": "+70735678139"}
0005432390102	34BB65	0529 844478	ELENA ROMANOVA	{"email": "romanova.e_1984@postgrespro.ru", "phone": "+70615205893"}
0005432390103	A31016	4479 345776	LARISA MAKAROVA	{"email": "larisa_makarova.14101964@postgrespro.ru", "phone": "+70869704464"}
0005432390104	A31016	6158 414929	ANDREY ORLOV	{"phone": "+70361917646"}
0005432390105	7D2F36	0678 402346	VLADIMIR ZAKHAROV	{"phone": "+70521380713"}
0005432390106	7D2F36	2829 596525	EVGENIYA NIKIFOROVA	{"email": "evgeniya-nikiforova-31101972@postgrespro.ru", "phone": "+70388834033"}
0005432390107	7EEC1A	3516 686311	ANTON NIKITIN	{"email": "nikitinanton_01091957@postgrespro.ru", "phone": "+70858160925"}
0005432390108	7EEC1A	9090 299091	SERGEY FEDOTOV	{"phone": "+70012131790"}
0005432390109	717D44	3006 366513	VALERIY KISELEV	{"phone": "+70807007912"}
0005432390110	9DD39C	2383 452313	VSEVOLOD NIKOLAEV	{"phone": "+70657632409"}
0005432390111	9F256F	7478 204211	YANA ILINA	{"email": "yana_ilina_30041971@postgrespro.ru", "phone": "+70390088371"}
0005432390112	9F256F	5858 006446	IVAN ILIN	{"email": "ilin.i.24071966@postgrespro.ru", "phone": "+70100951748"}
0005432390113	64FFE3	7552 747690	IVAN NIKOLAEV	{"phone": "+70998110442"}
0005432390115	4EE67B	0146 009101	LARISA MAKSIMOVA	{"email": "larisa_maksimova_20071963@postgrespro.ru", "phone": "+70891134473"}
0005432390116	442C16	4531 737723	MARIYA VOROBEVA	{"email": "mariya-vorobeva041972@postgrespro.ru", "phone": "+70963124356"}
0005432390117	CAACD5	5417 019081	DANIIL YAKOVLEV	{"email": "daniil.yakovlev-1983@postgrespro.ru", "phone": "+70009973457"}
0005432390118	CAACD5	1355 683893	DMITRIY DMITRIEV	{"email": "dmitriev.dmitriy-1967@postgrespro.ru", "phone": "+70130914749"}
0005432390119	CAACD5	2907 788889	MARINA KULIKOVA	{"email": "kulikovam.1970@postgrespro.ru", "phone": "+70103424567"}
0005432390120	509D0F	2457 594822	OLGA KOMAROVA	{"email": "komarovao.07081965@postgrespro.ru", "phone": "+70071701539"}
0005432390121	A31A1C	1721 543621	IVAN AFANASEV	{"email": "ivan-afanasev_07041963@postgrespro.ru", "phone": "+70663282387"}
0005432390122	27B589	4803 553309	SVETLANA MATVEEVA	{"phone": "+70307800942"}
0005432390123	4121E7	6990 701613	GALINA ANDREEVA	{"phone": "+70826994894"}
0005432390124	FD92A1	7989 022000	SERGEY NAZAROV	{"phone": "+70586462480"}
0005432390125	FD92A1	1792 212917	MARIYA NOVIKOVA	{"phone": "+70830786629"}
0005432390126	11C154	7931 401889	VLADISLAV ORLOV	{"email": "orlov_vladislav-18081974@postgrespro.ru", "phone": "+70288716229"}
0005432390127	11C154	9971 713941	KRISTINA NIKITINA	{"email": "knikitina.1969@postgrespro.ru", "phone": "+70654275560"}
0005432390128	5324DE	2553 917215	IRINA VOROBEVA	{"phone": "+70129326704"}
0005432390129	F67BB5	8085 149028	TATYANA TIMOFEEVA	{"email": "tatyana_timofeeva01101953@postgrespro.ru", "phone": "+70842855023"}
0005432390130	01F703	1212 868298	TATYANA PETROVA	{"email": "petrovat081984@postgrespro.ru", "phone": "+70830483685"}
0005432390131	F9D68E	0424 948482	KONSTANTIN SEMENOV	{"phone": "+70139911649"}
0005432390132	F9D68E	0282 535207	IGOR KUZNECOV	{"phone": "+70461984288"}
0005432390133	F9D68E	3249 141220	ELENA MELNIKOVA	{"phone": "+70235577545"}
0005432390134	959CE3	2177 802195	ALEKSANDR ABRAMOV	{"email": "abramov.a30081964@postgrespro.ru", "phone": "+70669363977"}
0005432390135	8DC09C	6005 357247	DANIIL ALEKSEEV	{"email": "alekseev_daniil-13051968@postgrespro.ru", "phone": "+70113333699"}
0005432390136	601163	4573 346499	BULAT SIDOROV	{"phone": "+70126740340"}
0005432390137	9B1E8E	1765 182316	MARIYA CHERNOVA	{"phone": "+70435074928"}
0005432390138	F5EC64	2464 023811	IGOR BORISOV	{"email": "borisovigor.081960@postgrespro.ru", "phone": "+70204830695"}
0005432390139	8DBACF	0248 885651	ANNA MAKSIMOVA	{"phone": "+70317509823"}
0005432390140	CC2D1B	0975 326442	POLINA VOLKOVA	{"email": "p_volkova_1960@postgrespro.ru", "phone": "+70660880941"}
0005432390141	811941	8537 661450	ELVIRA ISAEVA	{"email": "isaevaelvira_121977@postgrespro.ru", "phone": "+70351103144"}
0005432390142	E47A35	0824 797916	ALEKSANDR IVANOV	{"phone": "+70706126130"}
0005432390143	16229F	0863 446683	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey.081965@postgrespro.ru", "phone": "+70063752058"}
0005432390144	16229F	6778 210427	LYUDMILA EGOROVA	{"email": "l_egorova_03081967@postgrespro.ru", "phone": "+70281459512"}
0005432390145	12C7BA	1985 105858	ALENA EGOROVA	{"email": "alena_egorova051981@postgrespro.ru", "phone": "+70012144749"}
0005432390146	12C7BA	0770 696117	LYUBOV POPOVA	{"phone": "+70016371676"}
0005432390147	12C7BA	2530 554391	SERGEY ZHURAVLEV	{"email": "zhuravlev_sergey_09041973@postgrespro.ru", "phone": "+70465101824"}
0005432390148	C04C0D	4457 021006	TATYANA FADEEVA	{"phone": "+70829133563"}
0005432390149	C04C0D	1036 504024	MIKHAIL ANDREEV	{"email": "andreev_mikhail_20051971@postgrespro.ru", "phone": "+70746205134"}
0005432390150	9815E4	7386 926450	ANNA EGOROVA	{"phone": "+70770798218"}
0005432390151	035E4A	8946 721152	SERGEY MEDVEDEV	{"phone": "+70105519579"}
0005432390152	035E4A	8731 917412	VALERIY KISELEV	{"email": "v_kiselev-091976@postgrespro.ru", "phone": "+70368954436"}
0005432390153	EEB134	0505 960935	ANDREY GRIGOREV	{"email": "andrey-grigorev-1960@postgrespro.ru", "phone": "+70812278512"}
0005432390154	D61442	4191 514606	YURIY SOROKIN	{"phone": "+70513434673"}
0005432390155	2778F3	4463 382545	IRINA IVANOVA	{"phone": "+70829652882"}
0005432390156	0DB887	0109 152338	ALEKSEY MEDVEDEV	{"phone": "+70103336025"}
0005432390157	0DB887	2263 652953	ALEKSANDR PETROV	{"phone": "+70234091923"}
0005432390158	7D7978	4391 986159	RAISA MASLOVA	{"email": "maslovar-1962@postgrespro.ru", "phone": "+70436485552"}
0005432390159	7D7978	9547 310834	TATYANA ARKHIPOVA	{"email": "arkhipova_tatyana-111974@postgrespro.ru", "phone": "+70427174638"}
0005432390160	7D7978	3510 251690	ALEKSANDR MOROZOV	{"email": "a_morozov1964@postgrespro.ru", "phone": "+70813388365"}
0005432390161	CF309E	8367 494069	TATYANA POLYAKOVA	{"email": "polyakova.tatyana1976@postgrespro.ru", "phone": "+70533917539"}
0005432390162	CF309E	0545 699688	VIKTOR VOLKOV	{"email": "viktor.volkov.011980@postgrespro.ru", "phone": "+70343291017"}
0005432390163	EF1165	7689 209914	GALINA KONOVALOVA	{"email": "g-konovalova_021986@postgrespro.ru", "phone": "+70371537595"}
0005432390164	FA9361	3177 977176	VERA IVANOVA	{"phone": "+70926462477"}
0005432390165	DA5CD4	2350 099512	MAKSIM ZAKHAROV	{"phone": "+70845049152"}
0005432390166	72E5ED	6804 426755	YULIYA NIKITINA	{"phone": "+70928526556"}
0005432390167	3D2525	0221 342389	TAMARA KONOVALOVA	{"phone": "+70022000744"}
0005432390168	C9C219	1104 590741	STANISLAV NIKITIN	{"phone": "+70359395426"}
0005432390169	56F4BB	8505 000712	ILYA YAKOVLEV	{"phone": "+70438747582"}
0005432390170	346471	1341 789004	ANASTASIYA SOKOLOVA	{"email": "anastasiyasokolova_091960@postgrespro.ru", "phone": "+70696446743"}
0005432390171	BC638E	3044 348328	ALLA VASILEVA	{"phone": "+70475172039"}
0005432390172	3F9C02	9395 928535	MARINA YAKOVLEVA	{"email": "m-yakovleva_121980@postgrespro.ru", "phone": "+70604032282"}
0005432390173	E6541B	5280 188144	RIMMA RODIONOVA	{"email": "r.rodionova_1981@postgrespro.ru", "phone": "+70906530194"}
0005432390174	9DC9B7	7504 759857	ELENA SAVELEVA	{"phone": "+70825295767"}
0005432390175	9EED14	1372 635730	MARIANNA IVANOVA	{"email": "m_ivanova.071980@postgrespro.ru", "phone": "+70497109027"}
0005432390176	AA7044	0108 708227	NADEZHDA EFREMOVA	{"phone": "+70400678458"}
0005432390177	AA7044	6749 561464	TATYANA STEPANOVA	{"email": "stepanova.tatyana_1978@postgrespro.ru", "phone": "+70580654006"}
0005432390178	56B2D9	1950 301122	YURIY SEMENOV	{"phone": "+70298673375"}
0005432390179	56B2D9	7785 797023	DENIS SMIRNOV	{"email": "smirnovdenis-29111981@postgrespro.ru", "phone": "+70507842799"}
0005432390180	DCF407	2500 715775	ANDREY BORISOV	{"email": "aborisov_011965@postgrespro.ru", "phone": "+70723289909"}
0005432390181	87522C	5174 611721	ANNA OVCHINNIKOVA	{"email": "ovchinnikova.anna.041966@postgrespro.ru", "phone": "+70222775317"}
0005432390182	87522C	0650 656153	IVAN SCHERBAKOV	{"email": "i_scherbakov09041975@postgrespro.ru", "phone": "+70642236741"}
0005432390183	B33FDF	2478 478143	ROMAN IVANOV	{"phone": "+70964114317"}
0005432390184	06B4F2	0631 713813	SERGEY KONOVALOV	{"phone": "+70789554519"}
0005432390185	174DD2	9833 327769	ROMAN MARTYNOV	{"phone": "+70494533018"}
0005432390186	27DE7B	6789 867508	YURIY ABRAMOV	{"phone": "+70614247017"}
0005432390187	EC65D0	0443 337808	TAMARA BELYAEVA	{"email": "belyaeva_tamara.1981@postgrespro.ru", "phone": "+70270682361"}
0005432390188	4CEA37	9268 933124	KRISTINA ZAKHAROVA	{"email": "zakharova-k_061968@postgrespro.ru", "phone": "+70287153344"}
0005432390189	54082D	9271 779632	EVGENIY MAKAROV	{"phone": "+70737993707"}
0005432390190	1C4601	7398 331627	SERGEY AFANASEV	{"email": "afanasev_s.10071964@postgrespro.ru", "phone": "+70230053675"}
0005432390191	57D5B7	1538 168073	GALINA ZAYCEVA	{"email": "g_zayceva30111977@postgrespro.ru", "phone": "+70521499618"}
0005432390192	57D5B7	7737 648603	MARGARITA MAKSIMOVA	{"phone": "+70508476637"}
0005432390193	57D5B7	1901 225700	ALEKSANDR NOVIKOV	{"phone": "+70640391538"}
0005432390194	E9102D	3321 315260	ARMEN DMITRIEV	{"phone": "+70634888626"}
0005432390195	E9102D	6332 586469	VALENTINA IVANOVA	{"email": "vivanova-1972@postgrespro.ru", "phone": "+70155217941"}
0005432390196	AFA97F	8098 722556	NATALYA NESTEROVA	{"email": "nesterova.natalya111971@postgrespro.ru", "phone": "+70231735444"}
0005432390197	0560CA	3732 309313	ALEKSANDR KOZLOV	{"phone": "+70395852007"}
0005432390198	0560CA	4949 512820	VERONIKA YUDINA	{"email": "yudina-veronika121963@postgrespro.ru", "phone": "+70294796838"}
0005432390199	8D74BA	5638 296681	NADEZHDA POPOVA	{"email": "popova.n_28121962@postgrespro.ru", "phone": "+70423945527"}
0005432390200	D00CD8	1834 703554	ARINA BORISOVA	{"phone": "+70203674776"}
0005432390201	B13C79	4659 387599	SERGEY MAKAROV	{"email": "s.makarov031962@postgrespro.ru", "phone": "+70098190837"}
0005432390202	AA0C43	6621 966147	ALEKSANDR SOLOVEV	{"phone": "+70805774296"}
0005432390203	08BFCD	2544 525554	LYUDMILA VASILEVA	{"email": "vasileval1978@postgrespro.ru", "phone": "+70899937564"}
0005432390204	49B1B7	4853 287815	ALEKSANDR SERGEEV	{"email": "sergeev-a_011972@postgrespro.ru", "phone": "+70257207505"}
0005432390205	49B1B7	1565 731710	EVGENIY FROLOV	{"phone": "+70857980943"}
0005432390206	D5F759	9403 405718	NATALYA KOROLEVA	{"email": "nkoroleva1993@postgrespro.ru", "phone": "+70466038329"}
0005432390207	8283D5	5008 076243	DENIS SEMENOV	{"email": "denis_semenov.1971@postgrespro.ru", "phone": "+70219263274"}
0005432390208	DF62B4	4571 392266	IRINA PAVLOVA	{"email": "pavlovairina.1971@postgrespro.ru", "phone": "+70451358748"}
0005432390209	DF62B4	1858 215392	RAVIL KONOVALOV	{"phone": "+70712495370"}
0005432390210	29F58B	7019 018617	ELENA FEDOROVA	{"email": "fedorovaelena-18101981@postgrespro.ru", "phone": "+70921030781"}
0005432390211	29F58B	2216 598537	NIKOLAY AFANASEV	{"phone": "+70657919608"}
0005432390212	29F58B	8756 667020	IRINA NAZAROVA	{"email": "nazarova_irina.101960@postgrespro.ru", "phone": "+70403229169"}
0005432390213	49F06B	7759 708826	MAYYA VOLKOVA	{"phone": "+70944796001"}
0005432390214	472E51	3688 801530	VLADIMIR MOROZOV	{"email": "v.morozov-25091964@postgrespro.ru", "phone": "+70278305634"}
0005432390215	472E51	4407 951632	OLESYA TIKHONOVA	{"phone": "+70171967847"}
0005432390216	03FF8D	7185 649179	GENNADIY IVANOV	{"phone": "+70941742926"}
0005432390217	E9A2EF	6485 114674	NATALYA KUZMINA	{"phone": "+70926890655"}
0005432390218	B9179C	7091 366251	VIKTOR EGOROV	{"phone": "+70636408778"}
0005432390219	B9179C	6894 329519	ALEKSEY SOLOVEV	{"phone": "+70884440152"}
0005432390220	65D17C	0032 135767	YURIY SCHERBAKOV	{"email": "scherbakov-yuriy.051974@postgrespro.ru", "phone": "+70616554979"}
0005432390221	C8AB99	3318 960803	ANDREY NIKITIN	{"email": "nikitin-a.091967@postgrespro.ru", "phone": "+70922949936"}
0005432390222	C8AB99	6709 844258	ANDREY MARTYNOV	{"phone": "+70842089022"}
0005432390223	C8AB99	1844 456516	VERONIKA ABRAMOVA	{"phone": "+70621729211"}
0005432390224	82E11A	9881 738838	LILIYA FOMINA	{"email": "fomina-liliya.1980@postgrespro.ru", "phone": "+70238986761"}
0005432390225	82E11A	0016 134591	ALEKSANDR PAVLOV	{"email": "a.pavlov_30111978@postgrespro.ru", "phone": "+70965286102"}
0005432390226	5B0E8D	3338 923041	ANDREY DENISOV	{"phone": "+70938282383"}
0005432390227	0DBE94	3498 157882	NATALYA ILINA	{"phone": "+70354270529"}
0005432390228	7C86D8	0180 512201	YURIY SOKOLOV	{"phone": "+70292673046"}
0005432390229	7C86D8	9672 799637	VALENTINA LOGINOVA	{"phone": "+70230994493"}
0005432390230	7C86D8	4222 115672	GALINA IVANOVA	{"email": "ivanova-galina1969@postgrespro.ru", "phone": "+70769775156"}
0005432390231	63C03A	2589 960415	SERGEY MEDVEDEV	{"phone": "+70551400815"}
0005432390232	E758F3	1832 424087	ALEKSANDRA IVANOVA	{"phone": "+70105064375"}
0005432390233	E758F3	2997 540113	MARIYA GERASIMOVA	{"phone": "+70244171856"}
0005432390234	834ACD	2813 808586	ANNA LUKYANOVA	{"phone": "+70540841366"}
0005432390235	B9C245	7224 020779	LARISA ORLOVA	{"phone": "+70884133891"}
0005432390295	B81757	5090 952432	ANATOLIY SIDOROV	{"phone": "+70778697820"}
0005432390236	B9C245	9158 372197	ANTONINA KONOVALOVA	{"email": "konovalova-antonina15041966@postgrespro.ru", "phone": "+70605176641"}
0005432390237	B9C245	0492 624158	TATYANA PAVLOVA	{"phone": "+70241921492"}
0005432390238	0C0A14	6640 620095	ARTUR ZAYCEV	{"email": "zaycev.artur-071965@postgrespro.ru", "phone": "+70429823121"}
0005432390239	99C271	7064 118940	ALEKSEY NIKOLAEV	{"phone": "+70268263281"}
0005432390240	456C5E	5840 568045	NIKITA KOROLEV	{"email": "nikita-korolev-121968@postgrespro.ru", "phone": "+70587386910"}
0005432390241	456C5E	1062 095615	DMITRIY OSIPOV	{"email": "osipov_dmitriy_041971@postgrespro.ru", "phone": "+70341929847"}
0005432390242	6ED501	6374 762157	DARYA PETROVA	{"email": "petrova-darya_1971@postgrespro.ru", "phone": "+70178434814"}
0005432390243	6ED501	6748 952922	ZINAIDA DAVYDOVA	{"email": "zdavydova.091973@postgrespro.ru", "phone": "+70845119174"}
0005432390244	08F950	5467 116206	KIRILL MOROZOV	{"phone": "+70473098168"}
0005432390245	08F950	7218 484169	VIKTOR MAKAROV	{"phone": "+70970015470"}
0005432390246	395702	6115 955043	ANDREY SOROKIN	{"phone": "+70504466458"}
0005432390247	395702	1633 301267	GALINA FILATOVA	{"phone": "+70167779387"}
0005432390248	C13A48	5618 614563	YURIY ALEKSANDROV	{"email": "aleksandrovyuriy061977@postgrespro.ru", "phone": "+70931989544"}
0005432390249	F1E14B	5626 748493	ALEKSANDR SOROKIN	{"phone": "+70544125163"}
0005432390250	CFB48A	1037 129194	LIDIYA KOLESNIKOVA	{"email": "lidiya_kolesnikova1964@postgrespro.ru", "phone": "+70933960180"}
0005432390251	50CB8F	6710 292458	EKATERINA FEDOROVA	{"phone": "+70602464560"}
0005432390252	50CB8F	5268 085498	SVETLANA SOROKINA	{"email": "sorokina.s-021971@postgrespro.ru", "phone": "+70688776413"}
0005432390253	F8F6B9	3602 274513	TATYANA PAVLOVA	{"email": "t-pavlova.21111981@postgrespro.ru", "phone": "+70639954848"}
0005432390254	A5BAEA	9109 999786	GALINA EGOROVA	{"email": "egorova.g-051984@postgrespro.ru", "phone": "+70011597007"}
0005432390255	A5BAEA	8954 579033	VYACHESLAV FEDOROV	{"phone": "+70976687079"}
0005432390256	EDD6D6	1407 001842	ALEKSANDRA TARASOVA	{"email": "tarasovaaleksandra.081967@postgrespro.ru", "phone": "+70174104995"}
0005432390257	EDD6D6	1448 489428	IRINA GRISHINA	{"phone": "+70501125015"}
0005432390258	EDD6D6	5189 405423	IRINA YUDINA	{"phone": "+70365023234"}
0005432390259	090537	5844 363610	DMITRIY MELNIKOV	{"email": "dmitriy-melnikov08031969@postgrespro.ru", "phone": "+70490401325"}
0005432390260	090537	9085 350835	VALERIY GAVRILOV	{"email": "valeriygavrilov1979@postgrespro.ru", "phone": "+70304577775"}
0005432390261	A2E7DF	0171 117157	YULIYA IVANOVA	{"phone": "+70538901260"}
0005432390262	A2E7DF	1108 274812	MARYAM FEDOROVA	{"email": "fedorovamaryam_27071962@postgrespro.ru", "phone": "+70439674159"}
0005432390263	5B2999	2261 760295	SERGEY MAKAROV	{"phone": "+70696545389"}
0005432390264	D930E3	4260 332010	EVGENIYA TIKHONOVA	{"email": "tikhonovae_02111981@postgrespro.ru", "phone": "+70702856196"}
0005432390265	D930E3	9830 606088	EKATERINA LUKYANOVA	{"email": "ekaterina_lukyanova-1976@postgrespro.ru", "phone": "+70743065548"}
0005432390266	ECF654	5005 826917	NIKOLAY ISAEV	{"email": "isaev-n_1971@postgrespro.ru", "phone": "+70100877799"}
0005432390267	B885E7	1637 221522	SERGEY NOVIKOV	{"email": "sergey.novikov1971@postgrespro.ru", "phone": "+70218542336"}
0005432390268	D58FD8	0369 174669	DMITRIY KUZNECOV	{"phone": "+70677197982"}
0005432390269	8292F2	6747 691229	VALENTINA PAVLOVA	{"email": "valentina.pavlova_1966@postgrespro.ru", "phone": "+70774611021"}
0005432390270	7C01FD	7112 661563	OLGA GORBUNOVA	{"phone": "+70156577004"}
0005432390271	7DF92E	6284 915706	ALEKSEY SIDOROV	{"email": "aleksey-sidorov_051976@postgrespro.ru", "phone": "+70542156232"}
0005432390272	42ABDC	1865 543950	ELENA KOZLOVA	{"email": "kozlova-elena-1966@postgrespro.ru", "phone": "+70426023608"}
0005432390273	6318EE	8951 835971	ANATOLIY SMIRNOV	{"phone": "+70209293172"}
0005432390274	6318EE	8906 220867	ARTEM SOKOLOV	{"email": "a.sokolov111975@postgrespro.ru", "phone": "+70929819172"}
0005432390275	691918	7855 951143	GRIGORIY EGOROV	{"phone": "+70254743012"}
0005432390276	691918	3215 175138	MAKSIM IVANOV	{"phone": "+70631993903"}
0005432390277	A93206	9696 839966	SVETLANA AFANASEVA	{"email": "svetlanaafanaseva_06061968@postgrespro.ru", "phone": "+70333896373"}
0005432390278	005A18	4186 015700	MARINA ALEKSANDROVA	{"email": "aleksandrovam031964@postgrespro.ru", "phone": "+70227968226"}
0005432390279	005A18	6433 217256	VITALIY GAVRILOV	{"phone": "+70245575947"}
0005432390280	82435A	7433 456842	IRINA KRASNOVA	{"email": "krasnova_irina-1971@postgrespro.ru", "phone": "+70091935759"}
0005432390281	82435A	1192 102268	OLGA CHERNOVA	{"phone": "+70176357435"}
0005432390282	905CE5	9467 020963	FARIDA MELNIKOVA	{"phone": "+70819208199"}
0005432390283	905CE5	2529 609258	VADIM SERGEEV	{"phone": "+70281278813"}
0005432390284	E793EC	5597 074880	VERA POPOVA	{"email": "popova-v-08041983@postgrespro.ru", "phone": "+70954749740"}
0005432390285	5649CC	7927 714899	NADEZHDA NIKITINA	{"phone": "+70958221416"}
0005432390286	920B41	6996 009800	GALINA ALEKSEEVA	{"email": "alekseeva.galina031978@postgrespro.ru", "phone": "+70625672491"}
0005432390287	64A2FB	1029 337539	OLGA ILINA	{"phone": "+70953402092"}
0005432390288	DA89A9	0076 624522	ANDREY KUDRYASHOV	{"phone": "+70549380458"}
0005432390289	F45AF7	2242 330369	LIDIYA ALEKSANDROVA	{"phone": "+70989421333"}
0005432390290	13B327	4353 278672	VLADIMIR ORLOV	{"email": "vladimir-orlov_091968@postgrespro.ru", "phone": "+70177051123"}
0005432390291	8838D9	2839 502170	VADIM IVANOV	{"email": "vadimivanov121966@postgrespro.ru", "phone": "+70242492561"}
0005432390292	3694D8	5363 491294	ALEKSANDR KONOVALOV	{"email": "konovalov.aleksandr101980@postgrespro.ru", "phone": "+70443481835"}
0005432390293	527FB0	1792 759846	VLADIMIR KUZNECOV	{"email": "kuznecov-v.1970@postgrespro.ru", "phone": "+70479922012"}
0005432390294	B81757	0642 213446	TATYANA KUZMINA	{"email": "kuzmina.tatyana25031977@postgrespro.ru", "phone": "+70674037864"}
0005432390296	92E3BD	3909 874541	TATYANA KRASNOVA	{"email": "tatyana-krasnova_051972@postgrespro.ru", "phone": "+70153726224"}
0005432390297	EDDBFC	7298 556780	LYUBOV KUZNECOVA	{"phone": "+70688661455"}
0005432390298	F6B60A	7551 038613	ULYANA SEMENOVA	{"phone": "+70604072939"}
0005432390299	F17DB9	9140 946795	KSENIYA KARPOVA	{"email": "kkarpova_111972@postgrespro.ru", "phone": "+70374406987"}
0005432390300	60842A	0469 497331	IGOR MAKAROV	{"email": "igor_makarov_1965@postgrespro.ru", "phone": "+70119960765"}
0005432390301	31D6D9	7874 863742	VLADIMIR VASILEV	{"phone": "+70357066688"}
0005432390302	CDC946	0550 384569	TATYANA KUZNECOVA	{"email": "kuznecovat-10041979@postgrespro.ru", "phone": "+70388113582"}
0005432390303	E24B1D	1521 211400	DAMIR KAZAKOV	{"email": "kazakov-d_1968@postgrespro.ru", "phone": "+70379524255"}
0005432390304	A6C3B7	2984 498516	ALEKSEY SOKOLOV	{"phone": "+70441203291"}
0005432390305	8C0D74	4946 734768	SERGEY MOROZOV	{"phone": "+70821752375"}
0005432390306	8C0D74	3157 639400	LYUCIYA GAVRILOVA	{"phone": "+70478651956"}
0005432390307	59AAF5	1486 076094	KRISTINA ERMAKOVA	{"phone": "+70775807949"}
0005432390308	C2B6F3	2720 328144	MARIYA AKIMOVA	{"phone": "+70834166606"}
0005432390309	6FC2DD	0538 889634	IRINA MARTYNOVA	{"email": "martynova_irina.1975@postgrespro.ru", "phone": "+70571343294"}
0005432390310	B1A60C	1854 447314	DARYA KUZNECOVA	{"phone": "+70319007533"}
0005432390311	B1A60C	7913 316889	EVGENIY NIKITIN	{"phone": "+70050445579"}
0005432390312	5F1145	1950 029697	ALEKSANDR KUZNECOV	{"email": "a-kuznecov.21031982@postgrespro.ru", "phone": "+70788175377"}
0005432390313	A85856	6406 707644	NATALYA ZAKHAROVA	{"email": "n-zakharova121976@postgrespro.ru", "phone": "+70398365510"}
0005432390314	A85856	2552 831116	NIKOLAY DENISOV	{"phone": "+70634624136"}
0005432390315	019417	5430 175679	TATYANA GERASIMOVA	{"phone": "+70842188012"}
0005432390316	7D3955	3081 251278	YULIYA SERGEEVA	{"email": "yuliya_sergeeva101975@postgrespro.ru", "phone": "+70877718004"}
0005432390317	1F2DF7	5043 043436	ANASTASIYA NAZAROVA	{"email": "nazarovaa-01121977@postgrespro.ru", "phone": "+70748247670"}
0005432390318	1F2DF7	7426 973513	SVETLANA IVANOVA	{"email": "ivanova.s-30121980@postgrespro.ru", "phone": "+70665583110"}
0005432390319	8770CE	0951 546639	ALEKSEY ABRAMOV	{"phone": "+70044442673"}
0005432390320	638B0A	5850 064755	GALINA TROFIMOVA	{"email": "trofimova_galina.1983@postgrespro.ru", "phone": "+70050218745"}
0005432390321	638B0A	6353 021975	NATALYA ANDREEVA	{"phone": "+70501215301"}
0005432390322	511E6E	3759 884458	VLADIMIR SEMENOV	{"email": "vladimir.semenov_12121977@postgrespro.ru", "phone": "+70888312450"}
0005432390323	511E6E	2625 900299	YULIYA ILINA	{"phone": "+70138647566"}
0005432390324	7CF557	4424 064922	VIKTORIYA MAKSIMOVA	{"email": "maksimovav1967@postgrespro.ru", "phone": "+70454785024"}
0005432390325	7CF557	4589 649142	ELENA FADEEVA	{"phone": "+70325791464"}
0005432390326	6160F4	7617 659729	ILYA NOVIKOV	{"phone": "+70215842136"}
0005432390327	6160F4	1784 393764	ALEKSANDR PETROV	{"email": "petrovaleksandr-061975@postgrespro.ru", "phone": "+70498765610"}
0005432390328	6160F4	8357 540080	VIKTOR FEDOROV	{"email": "fedorov_v_1980@postgrespro.ru", "phone": "+70950503252"}
0005432390329	09159F	6792 787603	ARTUR EGOROV	{"phone": "+70605646815"}
0005432390330	B6DAE3	3787 627577	YAROSLAV NAZAROV	{"email": "nazarov-y_1972@postgrespro.ru", "phone": "+70863953537"}
0005432390331	087EAC	4071 636050	VALERIY FILIPPOV	{"email": "vfilippov.08071958@postgrespro.ru", "phone": "+70831136110"}
0005432390332	FE9655	6203 938781	IVAN FEDOROV	{"phone": "+70353132841"}
0005432390333	FE9655	1474 156168	NATALYA ANDREEVA	{"email": "n_andreeva-1973@postgrespro.ru", "phone": "+70817051152"}
0005432390334	FE9655	5409 054733	NADEZHDA ORLOVA	{"email": "nadezhda.orlova-011969@postgrespro.ru", "phone": "+70324733511"}
0005432390335	AC7B92	4518 261165	ELIZAVETA ORLOVA	{"phone": "+70723228020"}
0005432390336	3CA669	3739 357645	EVGENIY KUZNECOV	{"email": "kuznecov.e121968@postgrespro.ru", "phone": "+70060155663"}
0005432390337	9154E6	8869 104313	PETR ANTONOV	{"email": "antonov.p_1975@postgrespro.ru", "phone": "+70085673562"}
0005432390338	7D7FE6	2152 823292	GENNADIY GERASIMOV	{"email": "gerasimov-g_041985@postgrespro.ru", "phone": "+70442790829"}
0005432390339	7D7FE6	4859 657558	NADEZHDA POPOVA	{"email": "popova-nadezhda_011976@postgrespro.ru", "phone": "+70775347445"}
0005432390340	CCE5BD	4397 539011	VERONIKA GRISHINA	{"phone": "+70325274865"}
0005432390341	8EC7C0	8143 792125	GALINA RYABOVA	{"email": "galina.ryabova1977@postgrespro.ru", "phone": "+70432108091"}
0005432390342	0A6CEB	6851 659028	VERA MOROZOVA	{"phone": "+70538530027"}
0005432390343	2197C9	9737 670500	SERGEY MIRONOV	{"phone": "+70618307662"}
0005432390344	2197C9	4366 838748	OLGA DANILOVA	{"phone": "+70610369505"}
0005432390345	7C2D2B	4110 442434	ALLA KUZNECOVA	{"email": "allakuznecova1974@postgrespro.ru", "phone": "+70150759705"}
0005432390346	7C2D2B	9890 842926	VALERIY DAVYDOV	{"email": "davydov.v02071973@postgrespro.ru", "phone": "+70805894492"}
0005432390347	93CC3C	4468 928093	OLGA TROFIMOVA	{"phone": "+70332656988"}
0005432390348	5CE081	4029 222908	ZAKHAR TIMOFEEV	{"phone": "+70859919229"}
0005432390349	5CE081	4653 927969	LYUBOV POPOVA	{"phone": "+70762341807"}
0005432390350	70823F	4407 742837	IGOR SIDOROV	{"phone": "+70257641524"}
0005432390351	4E8A0F	3554 834519	GALINA KOVALEVA	{"email": "gkovaleva1970@postgrespro.ru", "phone": "+70030195168"}
0005432390352	040BAE	4843 190162	NADEZHDA GERASIMOVA	{"phone": "+70197377261"}
0005432390353	D57A76	6395 602507	OLGA KONDRATEVA	{"email": "kondrateva_o.08011976@postgrespro.ru", "phone": "+70468792450"}
0005432390354	D57A76	0859 808816	ROZA SERGEEVA	{"phone": "+70501172909"}
0005432390355	C06122	7280 143131	SERGEY GORBUNOV	{"email": "sergey.gorbunov-031973@postgrespro.ru", "phone": "+70956978685"}
0005432390356	3D2406	4223 831746	VERONIKA KUZMINA	{"phone": "+70693036432"}
0005432390357	DD5339	4405 298516	ELIZAVETA NAUMOVA	{"phone": "+70799930866"}
0005432390358	01FEFC	0081 513737	MIKHAIL DMITRIEV	{"email": "mikhaildmitriev-021975@postgrespro.ru", "phone": "+70102098895"}
0005432390359	3A94CC	2666 056238	NATALYA POPOVA	{"email": "popova.n1968@postgrespro.ru", "phone": "+70588767769"}
0005432390360	ED64F6	2539 801913	EKATERINA LOGINOVA	{"email": "e.loginova_26111972@postgrespro.ru", "phone": "+70795827848"}
0005432390361	6B72CE	1279 564998	EVGENIY VOLKOV	{"email": "volkov_evgeniy1983@postgrespro.ru", "phone": "+70715920720"}
0005432390362	6B72CE	6401 224991	ALEKSEY MOROZOV	{"phone": "+70727315161"}
0005432390363	6CAD60	9544 907865	ANDREY SEMENOV	{"email": "andrey.semenov_11061975@postgrespro.ru", "phone": "+70318352158"}
0005432390364	6CAD60	9511 412913	LILIYA RODIONOVA	{"phone": "+70719909203"}
0005432390365	6CAD60	1271 806805	SERGEY NOVIKOV	{"phone": "+70035109218"}
0005432390366	644E63	5696 376185	LIDIYA KALININA	{"email": "l.kalinina_121967@postgrespro.ru", "phone": "+70438387464"}
0005432390367	F4B4C3	9324 652968	MARIYA VASILEVA	{"email": "vasileva-m-081964@postgrespro.ru", "phone": "+70712901330"}
0005432390368	895FE9	1325 219409	VLADIMIR MAKSIMOV	{"email": "v_maksimov-031973@postgrespro.ru", "phone": "+70641681696"}
0005432390369	FCD531	1676 904638	NINA VASILEVA	{"phone": "+70971711315"}
0005432390370	BE18F1	9716 629962	ALEKSANDR IVANOV	{"phone": "+70012033308"}
0005432390371	BE18F1	3697 087414	ANASTASIYA ANTONOVA	{"phone": "+70656003819"}
0005432390372	1C266A	9660 985617	MAKSIM SCHERBAKOV	{"email": "maksim_scherbakov14111978@postgrespro.ru", "phone": "+70165290289"}
0005432390373	1C266A	9854 919079	ELENA SOROKINA	{"phone": "+70410103720"}
0005432390374	B61DBE	3743 277738	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir1984@postgrespro.ru", "phone": "+70282837133"}
0005432390375	333BC7	4276 574992	VLADIMIR RODIONOV	{"email": "rodionovvladimir-121971@postgrespro.ru", "phone": "+70437152423"}
0005432390376	1CC983	6699 862283	VENERA VOROBEVA	{"phone": "+70483293473"}
0005432390377	86714A	4549 395693	EKATERINA BORISOVA	{"email": "e-borisova_10061961@postgrespro.ru", "phone": "+70474872378"}
0005432390378	4C1D52	5901 517276	RAISA TROFIMOVA	{"phone": "+70314914952"}
0005432390379	D3C6D6	1655 516265	NIKOLAY MAKAROV	{"email": "makarov-nikolay.18101970@postgrespro.ru", "phone": "+70469613156"}
0005432390380	EBDCD0	8719 019448	KRISTINA VASILEVA	{"phone": "+70617113552"}
0005432390381	3751C9	0884 723932	ALEKSANDR DENISOV	{"email": "a-denisov.05101973@postgrespro.ru", "phone": "+70857999589"}
0005432390382	27405C	9894 466777	ALEKSANDR DAVYDOV	{"phone": "+70758246657"}
0005432390383	27405C	0503 519627	NAIL SAVELEV	{"email": "n_savelev.031974@postgrespro.ru", "phone": "+70714804072"}
0005432390384	3D0958	4495 876529	LYUDMILA MIRONOVA	{"email": "mironoval101973@postgrespro.ru", "phone": "+70501749982"}
0005432390385	318090	0618 462046	LYUDMILA ZAYCEVA	{"phone": "+70412783281"}
0005432390386	038804	3186 512412	DENIS POPOV	{"phone": "+70163683155"}
0005432390387	BEE8AE	2040 050069	VLADIMIR YAKOVLEV	{"email": "yakovlev_vladimir_1975@postgrespro.ru", "phone": "+70506360301"}
0005432390388	CB330C	5895 941663	TATYANA GORBUNOVA	{"phone": "+70578639349"}
0005432390389	BE99AF	9811 531943	GALINA SAVELEVA	{"phone": "+70263926928"}
0005432390390	594416	0873 288736	TATYANA DANILOVA	{"phone": "+70695718138"}
0005432390391	9BD751	5267 345756	ALEKSANDRA TARASOVA	{"email": "tarasova-a081964@postgrespro.ru", "phone": "+70345215115"}
0005432390392	602F0E	7738 500821	ALEKSANDR SIDOROV	{"phone": "+70226192678"}
0005432390393	A401B7	6192 390665	SVETLANA KOROLEVA	{"email": "svetlana.koroleva_20051970@postgrespro.ru", "phone": "+70870834777"}
0005432390394	03624C	9773 433549	ALEKSANDR TIMOFEEV	{"phone": "+70917447608"}
0005432390395	533A35	2892 162395	ANTONINA MOISEEVA	{"phone": "+70674038596"}
0005432390396	533A35	3499 398553	ALEKSANDRA KRASNOVA	{"email": "akrasnova06021979@postgrespro.ru", "phone": "+70624035801"}
0005432390397	533A35	0676 088930	ALEKSANDR MAKAROV	{"email": "amakarov-1977@postgrespro.ru", "phone": "+70615338958"}
0005432390398	E19187	8715 749271	MIKHAIL MELNIKOV	{"phone": "+70390708933"}
0005432390399	E19187	2541 956648	IRINA EGOROVA	{"email": "irina_egorova1972@postgrespro.ru", "phone": "+70316176401"}
0005432390400	50BE2E	2208 315264	TATYANA TITOVA	{"email": "t-titova.08041979@postgrespro.ru", "phone": "+70342480809"}
0005432390401	E4EB79	5658 865443	NIKOLAY KUZNECOV	{"phone": "+70619686956"}
0005432390402	071E13	0358 631729	NATALIYA YUDINA	{"email": "yudina_n1974@postgrespro.ru", "phone": "+70615814690"}
0005432390403	155C6F	6417 340581	NADEZHDA IVANOVA	{"email": "n.ivanova_05091979@postgrespro.ru", "phone": "+70392075089"}
0005432390404	9ED76A	7725 319349	OLGA MARTYNOVA	{"email": "martynova_o-23111968@postgrespro.ru", "phone": "+70284417941"}
0005432390405	E7A925	5384 963218	LYUDMILA ABRAMOVA	{"email": "abramova.lyudmila.1962@postgrespro.ru", "phone": "+70329617949"}
0005432390406	483F58	9732 106020	NINA BELOVA	{"email": "belova-nina_26061978@postgrespro.ru", "phone": "+70337563183"}
0005432390407	29B4F9	8823 274006	TATYANA POPOVA	{"email": "popova_t_17041978@postgrespro.ru", "phone": "+70975328434"}
0005432390408	28A9DE	1473 023542	ELIZAVETA LOGINOVA	{"email": "loginova-e_13021975@postgrespro.ru", "phone": "+70941421251"}
0005432390409	F33E00	8576 792548	EKATERINA ZAYCEVA	{"email": "ekaterina-zayceva.081978@postgrespro.ru", "phone": "+70903650459"}
0005432390410	F33E00	2222 861641	KIRILL SAVELEV	{"phone": "+70672830675"}
0005432390411	9C2D29	2376 695443	ALEKSANDR FROLOV	{"email": "frolov.aleksandr.021977@postgrespro.ru", "phone": "+70324542272"}
0005432390412	9C2D29	7394 528258	NINA SOKOLOVA	{"phone": "+70320070527"}
0005432390413	9C2D29	5380 020014	ANDREY KISELEV	{"email": "a-kiselev1969@postgrespro.ru", "phone": "+70561905056"}
0005432390414	80D83D	8128 495232	TATYANA FOMINA	{"phone": "+70890269948"}
0005432390415	8BE633	5187 310464	VIKTOR KONOVALOV	{"email": "konovalovviktor.10051976@postgrespro.ru", "phone": "+70630411208"}
0005432390416	8BE633	5555 494105	YURIY FILIPPOV	{"phone": "+70114029253"}
0005432390417	C7381D	1154 619547	SVETLANA MAKAROVA	{"phone": "+70735246244"}
0005432390418	690A4C	4415 467900	ELENA MELNIKOVA	{"email": "elena.melnikova_101976@postgrespro.ru", "phone": "+70676223584"}
0005432390419	C5FE66	1828 299042	PAVEL EGOROV	{"phone": "+70921750269"}
0005432390420	E0C3EC	4433 473481	IVAN NOVIKOV	{"email": "ivan-novikov-1976@postgrespro.ru", "phone": "+70904941245"}
0005432390421	E0C3EC	9836 536541	VALENTINA ARKHIPOVA	{"email": "arkhipovavalentina04051978@postgrespro.ru", "phone": "+70365444943"}
0005432390422	DC4A1A	3513 909065	ANNA VASILEVA	{"email": "annavasileva-12121971@postgrespro.ru", "phone": "+70749653228"}
0005432390423	0FCAEF	3153 982271	IVAN KOZLOV	{"email": "kozlov_i1977@postgrespro.ru", "phone": "+70254077068"}
0005432390424	BFD23E	4543 261662	OLGA DENISOVA	{"phone": "+70232056138"}
0005432390425	4CEE66	0058 664967	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey_1975@postgrespro.ru", "phone": "+70952268045"}
0005432390426	A3A694	1857 684044	VLADIMIR TARASOV	{"email": "vladimir.tarasov-16091975@postgrespro.ru", "phone": "+70417321529"}
0005432390427	A61ED7	2744 020535	DARYA YUDINA	{"email": "d_yudina_01091975@postgrespro.ru", "phone": "+70012098836"}
0005432390428	A61ED7	4750 807248	LILIYA KOZLOVA	{"email": "kozloval-1968@postgrespro.ru", "phone": "+70223066133"}
0005432390429	3C11C9	0273 203431	NINA EFREMOVA	{"email": "n_efremova-111974@postgrespro.ru", "phone": "+70327274273"}
0005432390430	9F7856	9020 333517	OLGA SOROKINA	{"phone": "+70850791704"}
0005432390431	9F7856	0211 288342	LYUBOV CHERNOVA	{"phone": "+70284677695"}
0005432390432	9F7856	8860 693023	ANATOLIY MEDVEDEV	{"email": "medvedev_a-1964@postgrespro.ru", "phone": "+70990380933"}
0005432390433	F31DFC	9607 964999	VITALIY EGOROV	{"phone": "+70677174653"}
0005432390434	F31DFC	8505 330438	EVGENIY ALEKSEEV	{"email": "evgeniy.alekseev1966@postgrespro.ru", "phone": "+70332985208"}
0005432390435	1E00DF	9889 857564	ANASTASIYA SMIRNOVA	{"phone": "+70053529883"}
0005432390436	C27731	6255 968380	ELENA VOLKOVA	{"phone": "+70631956278"}
0005432390437	C27731	1000 191071	VIKTOR KULIKOV	{"email": "kulikovv1975@postgrespro.ru", "phone": "+70777546121"}
0005432390438	499494	1160 723968	ALEKSEY PETROV	{"email": "petrov.aleksey_1969@postgrespro.ru", "phone": "+70410387540"}
0005432390439	499494	6306 360886	ALEKSANDR DENISOV	{"email": "a-denisov-071980@postgrespro.ru", "phone": "+70400452532"}
0005432390440	32E598	3005 916246	PETR ROMANOV	{"phone": "+70982736486"}
0005432390441	32E598	7351 472381	ALEKSANDR ALEKSANDROV	{"email": "a.aleksandrov.061973@postgrespro.ru", "phone": "+70826198374"}
0005432390442	A376E3	0603 806345	ANDREY POPOV	{"email": "andrey_popov08071977@postgrespro.ru", "phone": "+70868375598"}
0005432390443	A376E3	4093 777744	SERGEY KUZNECOV	{"phone": "+70215605218"}
0005432390444	2873EC	1001 825239	EVGENIY ALEKSEEV	{"email": "e.alekseev-101972@postgrespro.ru", "phone": "+70921392738"}
0005432390445	2873EC	8761 687007	SEMEN MOISEEV	{"phone": "+70756530437"}
0005432390446	BF2F92	9074 575855	VLADISLAV TARASOV	{"email": "tarasov_vladislav-091972@postgrespro.ru", "phone": "+70037124045"}
0005432390447	BF2F92	7581 383445	SERGEY BELOV	{"phone": "+70743308369"}
0005432390448	BF2F92	9168 553250	SVETLANA NIKOLAEVA	{"email": "svetlana.nikolaeva_1964@postgrespro.ru", "phone": "+70901218067"}
0005432390449	357EE5	1658 996699	DANIIL KRASNOV	{"email": "daniil.krasnov.101961@postgrespro.ru", "phone": "+70454537348"}
0005432390450	A29734	9980 999119	SOFYA VASILEVA	{"phone": "+70080002015"}
0005432390451	877636	7601 135465	VERA TARASOVA	{"phone": "+70299411048"}
0005432390452	877636	2368 455634	SERGEY VASILEV	{"email": "sergeyvasilev_011978@postgrespro.ru", "phone": "+70324801560"}
0005432390453	8DE06D	8917 603846	VLADISLAV MIKHAYLOV	{"phone": "+70093087306"}
0005432390454	8DE06D	6595 911122	SERGEY YAKOVLEV	{"phone": "+70323802152"}
0005432390455	CC480F	4114 828587	VLADIMIR KUZMIN	{"phone": "+70211791480"}
0005432390456	CC480F	9248 271304	RAFAIL FEDOROV	{"phone": "+70371077455"}
0005432390457	3C89E2	3640 164049	TAMARA IVANOVA	{"email": "tamara-ivanova-29101975@postgrespro.ru", "phone": "+70506042719"}
0005432390458	C7A4E6	7404 877590	SERGEY MAKSIMOV	{"phone": "+70090705240"}
0005432390459	C7A4E6	6326 975468	TAMARA NAZAROVA	{"phone": "+70898139387"}
0005432390460	9B3901	3223 962934	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov_1976@postgrespro.ru", "phone": "+70205497957"}
0005432390461	393CC1	5872 609481	LIDIYA ABRAMOVA	{"email": "abramova-l031972@postgrespro.ru", "phone": "+70426625541"}
0005432390462	393CC1	7132 699431	MARIYA SMIRNOVA	{"email": "smirnova_mariya-1974@postgrespro.ru", "phone": "+70899310516"}
0005432390463	AEDC94	7654 447991	SERGEY KOROLEV	{"phone": "+70504132890"}
0005432390464	BAABF7	5945 987271	VALENTINA RYABOVA	{"email": "valentina_ryabova1963@postgrespro.ru", "phone": "+70647243885"}
0005432390465	1B79CB	3110 928707	ALEKSANDR ROMANOV	{"phone": "+70084864073"}
0005432390466	4819A9	0866 531905	VITALIY PETROV	{"phone": "+70255071445"}
0005432390467	4819A9	0435 588450	ALEKSEY KOROLEV	{"email": "aleksey_korolev1965@postgrespro.ru", "phone": "+70320794704"}
0005432390468	44F60C	6258 050607	VIKTORIYA LAZAREVA	{"phone": "+70326739506"}
0005432390469	44F60C	0110 671385	MARIYA ZAKHAROVA	{"email": "zakharova_mariya_121970@postgrespro.ru", "phone": "+70687331323"}
0005432390470	555CC6	2826 658016	RENATA TITOVA	{"email": "titova.renata_06041965@postgrespro.ru", "phone": "+70649005091"}
0005432390471	555CC6	9344 187063	ZOYA BARANOVA	{"phone": "+70177814534"}
0005432390472	555CC6	4160 152254	TATYANA CHERNOVA	{"email": "t-chernova_111984@postgrespro.ru", "phone": "+70036341221"}
0005432390473	670913	9025 811032	NADEZHDA ORLOVA	{"email": "nadezhda.orlova-07071970@postgrespro.ru", "phone": "+70471159025"}
0005432390474	71B9C5	0239 524368	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr-01081967@postgrespro.ru", "phone": "+70109325501"}
0005432390475	71B9C5	3923 065273	VLADIMIR GUSEV	{"phone": "+70162495865"}
0005432390476	1664B0	6479 755090	MARIYA MOISEEVA	{"email": "mariyamoiseeva15091967@postgrespro.ru", "phone": "+70220595283"}
0005432390477	074C2B	0528 224990	NATALYA MAKAROVA	{"phone": "+70970507207"}
0005432390478	074C2B	5549 720265	TAMARA ABRAMOVA	{"email": "abramova_tamara.1966@postgrespro.ru", "phone": "+70664947376"}
0005432390479	2EA15B	9296 606098	ALEKSANDR POPOV	{"email": "popova.20041975@postgrespro.ru", "phone": "+70408920439"}
0005432390480	2EA15B	7727 980348	VIKTORIYA MEDVEDEVA	{"phone": "+70428734780"}
0005432390481	42EB56	0252 393736	ALLA DMITRIEVA	{"email": "dmitrieva-a1970@postgrespro.ru", "phone": "+70843377501"}
0005432390482	951360	5456 887967	ANDREY NOVIKOV	{"email": "novikov_andrey_1968@postgrespro.ru", "phone": "+70797393482"}
0005432390483	951360	9317 249180	RAMIL ALEKSEEV	{"phone": "+70940732832"}
0005432390484	2AD2B6	9265 625976	LYUDMILA KOVALEVA	{"email": "lyudmila-kovaleva.041975@postgrespro.ru", "phone": "+70881060972"}
0005432390485	F1EFAF	0536 053692	ANDREY KUDRYASHOV	{"phone": "+70511910534"}
0005432390486	F1EFAF	5531 990938	SERGEY KUDRYASHOV	{"phone": "+70861380283"}
0005432391945	45F595	8804 423986	STANISLAV BELOV	{"email": "belov.s_041972@postgrespro.ru", "phone": "+70108632235"}
0005432391946	1864DB	7024 919017	MARIYA ALEKSEEVA	{"email": "m.alekseeva-1968@postgrespro.ru", "phone": "+70684056077"}
0005432391947	CD8A9E	5600 586530	SVETLANA KUDRYASHOVA	{"phone": "+70035939854"}
0005432391948	B109D7	3415 794217	VALENTINA MOROZOVA	{"email": "morozova_v-051971@postgrespro.ru", "phone": "+70188003158"}
0005432391949	B109D7	3847 532344	SVETLANA SAVELEVA	{"email": "saveleva.svetlana1984@postgrespro.ru", "phone": "+70369730137"}
0005432391950	A81B66	0927 375155	DARYA ORLOVA	{"phone": "+70034368644"}
0005432391951	A81B66	4728 547132	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr1968@postgrespro.ru", "phone": "+70254850942"}
0005432391952	28523C	3722 455711	KRISTINA SEMENOVA	{"phone": "+70150637137"}
0005432391953	79E4C0	9867 712377	VLADIMIR MAKAROV	{"email": "makarov_vladimir.28041962@postgrespro.ru", "phone": "+70983401865"}
0005432391954	79E4C0	8645 876566	EVGENIYA KUDRYASHOVA	{"phone": "+70860468072"}
0005432391955	DE453D	9796 319913	NAILYA MIRONOVA	{"phone": "+70567097114"}
0005432391956	75FFD3	9847 956417	SERGEY MARTYNOV	{"email": "martynov.s_011990@postgrespro.ru", "phone": "+70134674659"}
0005432391957	F82697	7059 643236	ANNA STEPANOVA	{"phone": "+70391824970"}
0005432391958	F82697	8340 211680	VLADISLAV ZAYCEV	{"phone": "+70400200206"}
0005432391959	A840F7	2799 403198	OLGA MATVEEVA	{"phone": "+70893354306"}
0005432391960	A840F7	7407 433155	IRINA MELNIKOVA	{"email": "irina-melnikova28071973@postgrespro.ru", "phone": "+70720417652"}
0005432391961	52437A	9448 179903	NIKOLAY ZHUKOV	{"email": "zhukovn-1975@postgrespro.ru", "phone": "+70879946627"}
0005432391962	62EA02	7575 275573	ALEKSANDR ILIN	{"phone": "+70596405240"}
0005432391963	92AD89	8525 345461	ILYA MIKHAYLOV	{"email": "mikhaylov.i111964@postgrespro.ru", "phone": "+70820176758"}
0005432391964	92AD89	1131 649870	VLADIMIR KISELEV	{"phone": "+70323070991"}
0005432391965	EEE92C	9867 937766	LYUBOV KOZLOVA	{"phone": "+70348765769"}
0005432391966	EEE92C	5195 837257	IRINA STEPANOVA	{"phone": "+70968455068"}
0005432391967	B9A882	9173 956546	ANDREY KOROLEV	{"email": "korolev_andrey29101977@postgrespro.ru", "phone": "+70544825960"}
0005432391968	F31C07	1668 827390	ALEKSEY POPOV	{"email": "popov_aleksey_23041970@postgrespro.ru", "phone": "+70444793513"}
0005432391969	F31C07	6935 761770	MIKHAIL KISELEV	{"phone": "+70840056105"}
0005432391970	17644D	0546 192852	MAKSIM SAVELEV	{"phone": "+70452857025"}
0005432391971	F6659F	3012 883776	GALINA KUZNECOVA	{"phone": "+70256138047"}
0005432391972	087327	1811 212229	GALINA EGOROVA	{"phone": "+70175952950"}
0005432391973	90583A	4221 585312	SERGEY MELNIKOV	{"phone": "+70958285316"}
0005432391974	90583A	1833 736123	VIKTOR MAKSIMOV	{"phone": "+70568008529"}
0005432391975	7CAE04	5920 879172	PETR IVANOV	{"phone": "+70693275803"}
0005432391976	2F2226	0529 836694	NIKOLAY AFANASEV	{"phone": "+70416117072"}
0005432391977	2F2226	6837 725916	MARINA MAKAROVA	{"email": "makarova_marina22081983@postgrespro.ru", "phone": "+70548902622"}
0005432391978	4E44BA	2643 447853	ANDREY VASILEV	{"email": "vasilev_a08031964@postgrespro.ru", "phone": "+70494793948"}
0005432391979	4E44BA	1310 648948	EVGENIYA SOLOVEVA	{"phone": "+70967333596"}
0005432391980	7356E9	3151 521919	VLADIMIR FILIPPOV	{"phone": "+70567343328"}
0005432391981	BCC255	3301 682473	MIKHAIL MELNIKOV	{"email": "mikhailmelnikov_071971@postgrespro.ru", "phone": "+70939236589"}
0005432391982	BCC255	7864 946761	VLADIMIR VOLKOV	{"email": "volkov.vladimir-03051969@postgrespro.ru", "phone": "+70015104331"}
0005432391983	BCC255	9696 850273	YANA YUDINA	{"email": "yyudina.041983@postgrespro.ru", "phone": "+70520298528"}
0005432391984	606200	7014 579811	SVETLANA MARTYNOVA	{"email": "s.martynova.1972@postgrespro.ru", "phone": "+70797317587"}
0005432391985	606200	3851 772660	VASILIY KAZAKOV	{"phone": "+70807938236"}
0005432391986	9E71EC	4618 582222	MIKHAIL FEDOTOV	{"phone": "+70516037070"}
0005432391987	0516F9	6606 921037	LYUBOV KUZNECOVA	{"phone": "+70733136022"}
0005432391988	AA33D6	2099 262775	ANDREY ANTONOV	{"phone": "+70873663747"}
0005432391989	2DE596	4743 725776	VALERIY PETROV	{"email": "v_petrov.14061971@postgrespro.ru", "phone": "+70408325490"}
0005432391990	6CE59E	8357 990909	ANASTASIYA ISAEVA	{"phone": "+70579408398"}
0005432391991	63B50A	4324 241788	MARINA RYABOVA	{"email": "ryabova-m-23121968@postgrespro.ru", "phone": "+70446879426"}
0005432391992	38E5D2	9200 094635	ANTONINA FILIPPOVA	{"email": "antonina_filippova_20071975@postgrespro.ru", "phone": "+70663694906"}
0005432391993	CE3AE8	2593 348498	DMITRIY SERGEEV	{"email": "sergeev-dmitriy-29011964@postgrespro.ru", "phone": "+70910700392"}
0005432391994	CE3AE8	1714 495020	EKATERINA SEMENOVA	{"email": "e.semenova22081973@postgrespro.ru", "phone": "+70571423052"}
0005432391995	5DA839	6924 245928	VIKTOR TIKHONOV	{"phone": "+70937767346"}
0005432391996	5DA839	0128 691527	OLGA BELOVA	{"email": "olgabelova_1972@postgrespro.ru", "phone": "+70889583483"}
0005432391997	8E3AB7	2930 610148	IVAN MAKAROV	{"email": "makarovivan13021977@postgrespro.ru", "phone": "+70743772529"}
0005432391998	838D43	4909 539268	ARTUR ZAYCEV	{"email": "zaycev.artur-121971@postgrespro.ru", "phone": "+70529595388"}
0005432391999	838D43	5769 543105	OLGA BARANOVA	{"phone": "+70255930314"}
0005432392000	82996E	2047 531331	KONSTANTIN SOROKIN	{"email": "konstantin.sorokin-1962@postgrespro.ru", "phone": "+70539089269"}
0005432392001	40B1A3	0127 879843	ARINA ANDREEVA	{"phone": "+70282730165"}
0005432392002	40B1A3	3680 373292	VALENTINA EGOROVA	{"phone": "+70462456819"}
0005432392003	597B8D	8800 668316	TATYANA VLASOVA	{"email": "tatyanavlasova_20021971@postgrespro.ru", "phone": "+70415542454"}
0005432392004	597B8D	9554 536614	NIKOLAY SOKOLOV	{"email": "sokolov.n_14031977@postgrespro.ru", "phone": "+70295035435"}
0005432392005	74BEC4	8351 232198	PAVEL VASILEV	{"phone": "+70251281025"}
0005432392006	74BEC4	7681 891918	TATYANA SOKOLOVA	{"phone": "+70335588211"}
0005432392007	DAB005	7064 378044	GENNADIY VOLKOV	{"phone": "+70605434789"}
0005432392008	C2056D	5167 882603	NINA GUSEVA	{"phone": "+70047306154"}
0005432392009	BAF42A	8674 618119	OLGA DENISOVA	{"phone": "+70439006148"}
0005432392010	5D87D1	9252 727388	GALINA LOGINOVA	{"phone": "+70628500794"}
0005432392011	D44418	5011 117231	KLAVDIYA FEDOROVA	{"phone": "+70970903828"}
0005432392012	E9CE92	7964 647911	DARYA PETROVA	{"email": "d-petrova_121959@postgrespro.ru", "phone": "+70786861092"}
0005432392013	E9CE92	1402 345345	GALINA KONDRATEVA	{"phone": "+70250080513"}
0005432392014	5A3A88	6657 730216	TAMARA MAKSIMOVA	{"phone": "+70559815988"}
0005432392015	38A650	8886 864592	MAKSIM KOROLEV	{"email": "korolev.maksim11051970@postgrespro.ru", "phone": "+70227905324"}
0005432392016	A8C8B4	3688 531240	ELENA YUDINA	{"phone": "+70307003257"}
0005432392017	A8C8B4	3297 183534	MARINA ZOTOVA	{"email": "zotova-m.071968@postgrespro.ru", "phone": "+70394887040"}
0005432392018	ECCE80	3812 827503	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.natalya121970@postgrespro.ru", "phone": "+70128215671"}
0005432392019	AE1305	6392 322509	INNA TITOVA	{"phone": "+70577325983"}
0005432392020	AE1305	6862 299750	EKATERINA GERASIMOVA	{"phone": "+70473069909"}
0005432392021	064589	8060 473243	MARIYA PAVLOVA	{"phone": "+70964218696"}
0005432392022	064589	1881 870221	OKSANA FILIPPOVA	{"email": "o.filippova_111965@postgrespro.ru", "phone": "+70238204638"}
0005432392023	C1D480	5521 366868	LYUBOV ILINA	{"phone": "+70879619224"}
0005432392024	C1D480	1796 771121	GENNADIY PAVLOV	{"phone": "+70550774281"}
0005432392025	8D78D3	4538 655587	OLGA VASILEVA	{"phone": "+70281565980"}
0005432392026	9A4F15	6575 988291	ALEKSANDR KUZMIN	{"phone": "+70437660781"}
0005432392027	C8F164	6953 453283	VIKTORIYA NOVIKOVA	{"phone": "+70277620838"}
0005432392028	372F1F	0682 861375	PETR POPOV	{"email": "popov-petr.1958@postgrespro.ru", "phone": "+70404399998"}
0005432392029	5FCB00	2056 331465	ELIZAVETA TROFIMOVA	{"email": "elizaveta.trofimova.1970@postgrespro.ru", "phone": "+70716425405"}
0005432392030	DF4537	3410 687303	GALINA MAKSIMOVA	{"email": "maksimova.g.1967@postgrespro.ru", "phone": "+70307343630"}
0005432392031	2A7775	9136 741641	ALEVTINA ZAYCEVA	{"email": "a.zayceva061968@postgrespro.ru", "phone": "+70822742462"}
0005432392032	4B22F6	2154 717237	VALERIY ZAYCEV	{"phone": "+70557173686"}
0005432392033	A15285	1949 413486	YULIYA KISELEVA	{"phone": "+70139533095"}
0005432392034	A15285	5553 400601	NATALYA ALEKSEEVA	{"email": "natalya_alekseeva-1975@postgrespro.ru", "phone": "+70179719292"}
0005432392035	8C18A6	2776 423468	ANNA KUDRYASHOVA	{"phone": "+70478798951"}
0005432392036	8C18A6	8879 675804	LYUBOV AKIMOVA	{"email": "lyubovakimova1964@postgrespro.ru", "phone": "+70057450773"}
0005432392037	722EC2	2304 270123	ANASTASIYA KUZMINA	{"phone": "+70135073011"}
0005432392038	B8FDA1	2555 330668	SVETLANA LAZAREVA	{"phone": "+70587890494"}
0005432392039	52D08A	8287 188762	ANTON ROMANOV	{"phone": "+70183253389"}
0005432392040	3D1C73	6545 030292	ALEKSANDR TARASOV	{"phone": "+70051754913"}
0005432392041	F53B2F	9115 923078	NADEZHDA FILATOVA	{"email": "nadezhda.filatova.121959@postgrespro.ru", "phone": "+70660268375"}
0005432392042	5B00C5	7563 025048	FARIDA ANTONOVA	{"phone": "+70472412401"}
0005432392043	43781B	5393 118610	NATALYA ZOTOVA	{"email": "n_zotova121966@postgrespro.ru", "phone": "+70649974832"}
0005432392044	43781B	6025 922911	MIKHAIL GORBUNOV	{"phone": "+70586214859"}
0005432392045	7980CE	5053 427024	SERGEY YAKOVLEV	{"phone": "+70060031889"}
0005432392046	7980CE	9793 700156	PETR SAVELEV	{"email": "savelevpetr081965@postgrespro.ru", "phone": "+70238148492"}
0005432392047	787E8A	1581 095392	MIKHAIL NIKOLAEV	{"phone": "+70215469850"}
0005432392048	787E8A	6623 006913	SOFYA SOROKINA	{"email": "sorokina_sofya-19021964@postgrespro.ru", "phone": "+70217045381"}
0005432392049	2730EC	8901 364292	IVAN NAZAROV	{"phone": "+70600007272"}
0005432392050	77A909	1991 060855	OLGA ZOTOVA	{"email": "o_zotova_051971@postgrespro.ru", "phone": "+70472593015"}
0005432392051	77A909	1052 712855	IRINA MIRONOVA	{"phone": "+70931253212"}
0005432392052	2EE478	2081 077775	MIKHAIL KUZMIN	{"email": "m_kuzmin-15051979@postgrespro.ru", "phone": "+70768819036"}
0005432392053	2EE478	6136 327342	TATYANA NESTEROVA	{"phone": "+70916542268"}
0005432392054	832CD6	2987 535480	VIKTORIYA IVANOVA	{"phone": "+70987676023"}
0005432392055	20A648	0242 541266	OLGA TARASOVA	{"email": "otarasova1960@postgrespro.ru", "phone": "+70928106311"}
0005432392056	B5E27B	5578 359101	ELIZAVETA SAVELEVA	{"email": "saveleva_e-1978@postgrespro.ru", "phone": "+70386131360"}
0005432392057	75F8E7	2655 368048	SERGEY BELOV	{"email": "belov-s1959@postgrespro.ru", "phone": "+70347446738"}
0005432392058	51FCDB	3834 574839	ARTUR SEMENOV	{"phone": "+70014511632"}
0005432392059	51FCDB	3718 525183	OLESYA SIDOROVA	{"email": "sidorova-olesya-061969@postgrespro.ru", "phone": "+70079452769"}
0005432392060	127DB3	5861 431151	ELENA YAKOVLEVA	{"email": "eyakovleva.1972@postgrespro.ru", "phone": "+70665755071"}
0005432392061	127DB3	3713 846871	VIKTOR YAKOVLEV	{"email": "yakovlev-viktor.22121966@postgrespro.ru", "phone": "+70475760421"}
0005432392062	DBAD32	2649 033383	PAVEL KUZMIN	{"phone": "+70449416503"}
0005432392063	9DD63E	2339 904288	NURIYA POPOVA	{"phone": "+70980923349"}
0005432392064	CD3F65	1895 167336	ZULFIYA KARPOVA	{"phone": "+70276918213"}
0005432392065	CD3F65	6068 749604	YURIY BORISOV	{"phone": "+70489331150"}
0005432392066	AA3335	0571 322145	ALEKSANDR MEDVEDEV	{"email": "medvedeva_13061979@postgrespro.ru", "phone": "+70721894616"}
0005432392067	AA3335	8935 988585	ANDREY OSIPOV	{"email": "osipov_a.051973@postgrespro.ru", "phone": "+70323773738"}
0005432392068	A2AC92	9753 952105	SERGEY KOZLOV	{"email": "sergey-kozlov1961@postgrespro.ru", "phone": "+70895743978"}
0005432392069	E2A5DC	4155 100070	IGOR YAKOVLEV	{"email": "i-yakovlev16061975@postgrespro.ru", "phone": "+70232047994"}
0005432392070	2D8B93	2410 563676	LYUBOV KAZAKOVA	{"email": "lyubov_kazakova22101972@postgrespro.ru", "phone": "+70172517187"}
0005432392071	F769EA	4241 066025	OLEG ILIN	{"email": "ilin_oleg_041974@postgrespro.ru", "phone": "+70037550967"}
0005432392072	F769EA	4539 643977	ALEKSANDR GERASIMOV	{"email": "gerasimova1973@postgrespro.ru", "phone": "+70400781193"}
0005432392073	186902	9148 650512	DMITRIY KOROLEV	{"email": "korolevdmitriy.071979@postgrespro.ru", "phone": "+70226395553"}
0005432392074	A80D48	6941 355913	VADIM FEDOROV	{"phone": "+70905315395"}
0005432392075	A80D48	1822 484991	ANDREY MIRONOV	{"email": "mironov-andrey-061972@postgrespro.ru", "phone": "+70583680062"}
0005432392076	C412CE	6838 700661	ELENA IVANOVA	{"email": "eivanova12091965@postgrespro.ru", "phone": "+70000564300"}
0005432392077	28BAC8	2907 957239	IRINA POPOVA	{"phone": "+70772411659"}
0005432392078	4DADF2	4940 947703	ELENA SIDOROVA	{"email": "elena_sidorova-1965@postgrespro.ru", "phone": "+70791945421"}
0005432392079	4DADF2	7726 623422	ALEVTINA MAKSIMOVA	{"email": "a-maksimova_15111977@postgrespro.ru", "phone": "+70219592395"}
0005432392080	031E5E	3209 705148	VSEVOLOD ZHURAVLEV	{"phone": "+70218220406"}
0005432392081	C9E17C	7671 619612	ANDREY KULIKOV	{"email": "a-kulikov_15021974@postgrespro.ru", "phone": "+70369458225"}
0005432392082	2BA46C	0736 878555	ELENA PAVLOVA	{"email": "e-pavlova-14091967@postgrespro.ru", "phone": "+70050405739"}
0005432392083	194EB7	2442 184058	OLEG TIMOFEEV	{"email": "timofeev-o-28121966@postgrespro.ru", "phone": "+70353455882"}
0005432392084	017561	5233 633116	ANATOLIY CHERNOV	{"phone": "+70554469127"}
0005432392085	017561	6279 074826	NIKOLAY MIRONOV	{"phone": "+70340632186"}
0005432394032	46D0AA	5425 170469	NATALYA AKIMOVA	{"email": "natalya-akimova-1957@postgrespro.ru", "phone": "+70041215577"}
0005432394033	A525A4	0792 464047	VADIM KULIKOV	{"email": "vadim.kulikov-21011969@postgrespro.ru", "phone": "+70162359137"}
0005432394034	E27E1F	0632 265356	VLADIMIR KUZNECOV	{"email": "vkuznecov.031972@postgrespro.ru", "phone": "+70728229563"}
0005432394035	34895A	3851 644629	ELENA NAUMOVA	{"email": "enaumova_051974@postgrespro.ru", "phone": "+70560879080"}
0005432394036	922BD8	6480 106589	ALINA EGOROVA	{"email": "alina.egorova03011966@postgrespro.ru", "phone": "+70048566514"}
0005432394037	8CCBF7	2808 643507	ALEVTINA LAZAREVA	{"phone": "+70256336625"}
0005432394038	8CCBF7	0350 830883	GENNADIY IVANOV	{"email": "ivanov.g_29031976@postgrespro.ru", "phone": "+70727233131"}
0005432394039	1DF5AD	6388 861132	MARIYA CHERNOVA	{"email": "chernova-m.14121964@postgrespro.ru", "phone": "+70667092836"}
0005432394040	F42B17	8608 762548	ELENA TROFIMOVA	{"email": "trofimova-e.1970@postgrespro.ru", "phone": "+70887742142"}
0005432394041	FD1610	4490 529902	NIKOLAY MIKHAYLOV	{"phone": "+70562834664"}
0005432394042	981FF2	0892 492415	LYUDMILA FILATOVA	{"phone": "+70437594957"}
0005432394043	573A8F	8866 262693	TATYANA LUKYANOVA	{"phone": "+70933198143"}
0005432394044	D5E298	2648 795152	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_05021968@postgrespro.ru", "phone": "+70345546697"}
0005432394045	D5E298	4792 379000	ANATOLIY ZAYCEV	{"phone": "+70238387086"}
0005432394046	80D852	3975 358258	GALINA TIKHONOVA	{"phone": "+70373957073"}
0005432394047	D91BB3	6116 733900	ELENA ALEKSANDROVA	{"email": "ealeksandrova11071972@postgrespro.ru", "phone": "+70378750914"}
0005432394048	05AED1	4943 874287	MARIYA PAVLOVA	{"email": "m.pavlova-1962@postgrespro.ru", "phone": "+70466309167"}
0005432394049	FD4AA2	5383 553641	ANNA SEMENOVA	{"email": "a-semenova10061970@postgrespro.ru", "phone": "+70961351448"}
0005432394050	FD4AA2	4985 570856	NIKOLAY FEDOROV	{"email": "fedorov-n-03051974@postgrespro.ru", "phone": "+70561729413"}
0005432394051	FD2CB8	4765 099410	ANTON KUZNECOV	{"phone": "+70917018576"}
0005432394052	97C0E6	8412 536441	ALEKSANDR GUSEV	{"email": "aleksandr-gusev19071967@postgrespro.ru", "phone": "+70365599734"}
0005432394053	3939A1	7978 037013	VERONIKA FEDOROVA	{"email": "veronika_fedorova_05031982@postgrespro.ru", "phone": "+70118579815"}
0005432394054	DF0434	6049 983887	IVAN MOISEEV	{"phone": "+70147832388"}
0005432394055	4AB188	0201 371857	VIKTOR NIKOLAEV	{"phone": "+70213158898"}
0005432394056	4AB188	0365 896491	NINA NAZAROVA	{"email": "nazarova.nina-041960@postgrespro.ru", "phone": "+70029519524"}
0005432394057	D75B49	9417 073100	ALBERT ALEKSEEV	{"phone": "+70157032955"}
0005432394058	D75B49	1445 159362	ALEKSEY BORISOV	{"phone": "+70903614927"}
0005432394059	4D9A75	7121 436212	ALEKSEY ALEKSANDROV	{"email": "aleksandrova1976@postgrespro.ru", "phone": "+70042588439"}
0005432394060	5473CB	1111 321483	ALEKSEY ZAKHAROV	{"phone": "+70804144042"}
0005432394061	E045B8	5716 062422	ELENA VOROBEVA	{"phone": "+70295816416"}
0005432394062	72B4CF	4160 462600	MAKSIM ALEKSEEV	{"phone": "+70221277503"}
0005432394063	72B4CF	3903 411997	TATYANA IVANOVA	{"phone": "+70307510292"}
0005432394064	72B4CF	6774 259488	TATYANA AKIMOVA	{"email": "akimova-t.021971@postgrespro.ru", "phone": "+70682914227"}
0005432394065	5F4819	4412 605959	NADEZHDA LAZAREVA	{"email": "n-lazareva_031983@postgrespro.ru", "phone": "+70127505720"}
0005432394066	C0D364	6055 273866	SERGEY KULIKOV	{"phone": "+70595035457"}
0005432394067	0A83CC	8532 667662	ALEKSANDR YAKOVLEV	{"phone": "+70473560181"}
0005432394068	133557	3336 317151	VERA NAZAROVA	{"email": "nazarova-v_1963@postgrespro.ru", "phone": "+70997382187"}
0005432394069	FBA173	9540 669533	OLEG ZAYCEV	{"phone": "+70920108121"}
0005432394070	FBA173	9209 895482	OKSANA NIKOLAEVA	{"email": "o.nikolaeva.22061964@postgrespro.ru", "phone": "+70808406354"}
0005432394071	FBBED6	9735 130539	RAISA KULIKOVA	{"phone": "+70447697517"}
0005432394072	FBBED6	8693 397286	NINA FROLOVA	{"phone": "+70078434229"}
0005432394073	DD72CA	9905 931372	DMITRIY ORLOV	{"phone": "+70050493145"}
0005432394074	DD72CA	0259 638104	LARISA SCHERBAKOVA	{"phone": "+70666727808"}
0005432394075	AAD059	4469 453094	ARTEM NIKITIN	{"phone": "+70583266172"}
0005432394076	AAD059	7861 012534	MIKHAIL ANDREEV	{"phone": "+70025052029"}
0005432394077	45295C	1169 777867	ELENA MAKSIMOVA	{"email": "e-maksimova-1975@postgrespro.ru", "phone": "+70755442868"}
0005432394078	9BE714	3520 687194	NIKITA POPOV	{"email": "popov.nikita-1971@postgrespro.ru", "phone": "+70951328571"}
0005432394079	9BE714	3193 695844	SERGEY ALEKSEEV	{"phone": "+70519425827"}
0005432394080	CF47FB	3283 820630	ANATOLIY KUZNECOV	{"email": "kuznecov-anatoliy021976@postgrespro.ru", "phone": "+70008696400"}
0005432394081	29C0B4	7393 066583	AZAT POPOV	{"phone": "+70529901059"}
0005432394082	29C0B4	0005 173126	LYUDMILA ALEKSEEVA	{"email": "l_alekseeva1970@postgrespro.ru", "phone": "+70221867560"}
0005432394083	227D46	0550 495164	OKSANA NAZAROVA	{"email": "oksananazarova061973@postgrespro.ru", "phone": "+70751728762"}
0005432394084	B2D636	9583 782922	LILIYA BELYAEVA	{"email": "belyaevaliliya-1969@postgrespro.ru", "phone": "+70283131295"}
0005432394085	8BDEBD	6100 109883	VIKTOR STEPANOV	{"phone": "+70087164309"}
0005432394086	F29484	7569 583019	ALEKSEY SMIRNOV	{"email": "smirnov_a-1974@postgrespro.ru", "phone": "+70476431215"}
0005432394087	F29484	3590 593354	ANNA VOLKOVA	{"email": "volkovaanna09101973@postgrespro.ru", "phone": "+70998612716"}
0005432394088	2307F7	6462 044731	NIKOLAY SCHERBAKOV	{"phone": "+70274160189"}
0005432394089	4E0FFA	0372 546565	NATALIYA NAZAROVA	{"email": "nataliyanazarova_11101969@postgrespro.ru", "phone": "+70773221145"}
0005432394090	3B64B4	9719 081937	ANATOLIY TARASOV	{"email": "tarasov.a_091957@postgrespro.ru", "phone": "+70443798355"}
0005432394091	3B64B4	1007 993229	ROZA SIDOROVA	{"email": "r-sidorova111974@postgrespro.ru", "phone": "+70670923125"}
0005432394092	DB7D09	0466 317861	VASILIY NAUMOV	{"email": "v-naumov-101977@postgrespro.ru", "phone": "+70953138609"}
0005432394093	DB7D09	9357 391975	OLGA KUZNECOVA	{"phone": "+70409201511"}
0005432394094	5E5FDA	5183 372408	ALEKSANDRA SOLOVEVA	{"email": "aleksandra.soloveva.1960@postgrespro.ru", "phone": "+70361419632"}
0005432394095	5E5FDA	1039 090478	MARINA BORISOVA	{"phone": "+70172800841"}
0005432394096	5E5FDA	1240 650779	NATALIYA PAVLOVA	{"phone": "+70404826068"}
0005432394097	278796	6022 782096	LYUBOV TROFIMOVA	{"email": "lyubov.trofimova.1975@postgrespro.ru", "phone": "+70637796671"}
0005432394098	278796	3167 742017	LILIYA GERASIMOVA	{"phone": "+70686166666"}
0005432394099	F10F22	9693 319969	VERA SEMENOVA	{"email": "semenova-v_18021972@postgrespro.ru", "phone": "+70105628112"}
0005432394100	95D15C	0778 808700	NATALYA KUZNECOVA	{"phone": "+70502402101"}
0005432394101	5A0325	5951 614702	YURIY MAKSIMOV	{"email": "maksimov_yuriy.1973@postgrespro.ru", "phone": "+70817329211"}
0005432394102	68D510	3576 688162	OLGA KAZAKOVA	{"phone": "+70384353424"}
0005432394103	68D510	1313 036885	YULIYA EFREMOVA	{"email": "yuliya-efremova.1982@postgrespro.ru", "phone": "+70370872087"}
0005432394104	02ADCC	0582 732303	TAMARA ZHUKOVA	{"phone": "+70603983033"}
0005432394105	119C1B	0060 340009	SERGEY PAVLOV	{"email": "pavlov_sergey.121971@postgrespro.ru", "phone": "+70891478905"}
0005432394106	119C1B	7800 116278	YURIY MIKHAYLOV	{"phone": "+70066094714"}
0005432394107	237248	4141 382914	LYUDMILA ZAYCEVA	{"phone": "+70572240350"}
0005432394108	237248	5440 915825	ZOYA KULIKOVA	{"email": "kulikova-zoya_051974@postgrespro.ru", "phone": "+70167303300"}
0005432394109	B8ED45	7386 228081	IVAN SAVELEV	{"email": "savelev.ivan.18051971@postgrespro.ru", "phone": "+70648727638"}
0005432394110	D6424C	6161 954918	GALINA BORISOVA	{"phone": "+70031634799"}
0005432394111	D6424C	2628 030330	ALEKSEY KAZAKOV	{"email": "alekseykazakov.04031980@postgrespro.ru", "phone": "+70484125302"}
0005432394112	551BF2	7726 058859	ALEKSANDR VOROBEV	{"phone": "+70751999156"}
0005432394113	7212DF	4035 257600	LEONID MOISEEV	{"phone": "+70262210734"}
0005432394114	F06889	6849 359563	ROMAN CHERNOV	{"phone": "+70458844188"}
0005432394115	F06889	0193 420445	ALEKSEY SOLOVEV	{"email": "a_solovev.1976@postgrespro.ru", "phone": "+70338141861"}
0005432394116	339D1C	5172 988611	RINAT SCHERBAKOV	{"phone": "+70105444070"}
0005432394117	FDADED	2588 020134	NATALYA LOGINOVA	{"phone": "+70164433598"}
0005432394118	B2DC2E	4135 109571	IGOR SEMENOV	{"email": "igor.semenov_1964@postgrespro.ru", "phone": "+70845972639"}
0005432394119	B2DC2E	6651 073861	TATYANA MAKAROVA	{"phone": "+70030493895"}
0005432394120	B2DC2E	9428 354708	ALEKSANDRA FEDOROVA	{"email": "afedorova-1966@postgrespro.ru", "phone": "+70582456735"}
0005432394121	AD3DCB	5925 699703	EVGENIY MIKHAYLOV	{"email": "evgeniymikhaylov_1960@postgrespro.ru", "phone": "+70692818252"}
0005432394122	20084B	7629 709375	VALENTINA YAKOVLEVA	{"phone": "+70763297344"}
0005432394123	20084B	0283 884359	PELAGEYA POPOVA	{"email": "popova-pelageya-1976@postgrespro.ru", "phone": "+70213832694"}
0005432394124	BBE161	0689 952097	VALENTINA NIKOLAEVA	{"email": "valentina-nikolaeva.041969@postgrespro.ru", "phone": "+70812787792"}
0005432394125	BBE161	6274 632837	VIKTOR VOROBEV	{"phone": "+70607037835"}
0005432394126	70D9A6	1416 448903	VALENTINA FILIPPOVA	{"phone": "+70442090986"}
0005432394127	70D9A6	9677 361285	TAMARA NOVIKOVA	{"phone": "+70936321355"}
0005432394128	C02048	2761 456682	ANASTASIYA MIKHAYLOVA	{"email": "a.mikhaylova_071988@postgrespro.ru", "phone": "+70860381983"}
0005432394129	0EA7A9	1217 988418	VIKTOR BARANOV	{"email": "baranovviktor-1975@postgrespro.ru", "phone": "+70777694562"}
0005432394130	0EA7A9	8402 910068	TATYANA VOROBEVA	{"phone": "+70322411517"}
0005432394131	8235E8	3128 966698	EVGENIY EGOROV	{"email": "e.egorov.29111970@postgrespro.ru", "phone": "+70870349596"}
0005432394132	916968	0205 529807	IRINA BORISOVA	{"phone": "+70280555609"}
0005432394133	E5143B	2852 891711	ELENA IVANOVA	{"email": "elenaivanova.011981@postgrespro.ru", "phone": "+70929162642"}
0005432394134	AFF826	1314 454611	OKSANA FILIPPOVA	{"email": "oksana-filippova_021974@postgrespro.ru", "phone": "+70755662986"}
0005432394135	AFF826	2379 841544	ALEKSEY ILIN	{"phone": "+70556541137"}
0005432394136	AFF826	0078 681048	YURIY MOROZOV	{"email": "morozovy-021975@postgrespro.ru", "phone": "+70337257742"}
0005432394137	B883F9	3091 357954	NATALYA VASILEVA	{"email": "vasilevan-04031964@postgrespro.ru", "phone": "+70774558249"}
0005432394138	613CF9	0422 677975	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr_26031965@postgrespro.ru", "phone": "+70672459074"}
0005432394139	395A6A	7594 350464	ANATOLIY OSIPOV	{"phone": "+70167080196"}
0005432394140	395A6A	4852 355675	NADEZHDA CHERNOVA	{"phone": "+70033943272"}
0005432394141	7A0C6A	9542 631968	NIKOLAY OSIPOV	{"phone": "+70880237591"}
0005432394142	3A3DEC	2689 071000	DMITRIY SERGEEV	{"email": "sergeev.d1965@postgrespro.ru", "phone": "+70317647176"}
0005432394143	1254C3	6081 375276	MAKSIM KISELEV	{"email": "kiselevmaksim.03121966@postgrespro.ru", "phone": "+70630954560"}
0005432394144	544686	3527 339627	GALINA MEDVEDEVA	{"email": "medvedeva_galina.1971@postgrespro.ru", "phone": "+70228869558"}
0005432394145	C679B8	8478 736696	VALERIY MELNIKOV	{"phone": "+70989828603"}
0005432394146	F855F2	6810 825891	SERGEY SCHERBAKOV	{"phone": "+70542910676"}
0005432394147	FE06D6	5473 022825	MATVEY GUSEV	{"email": "gusevm17101976@postgrespro.ru", "phone": "+70493727768"}
0005432394148	FE06D6	8243 718407	ALEKSANDR PAVLOV	{"phone": "+70148654248"}
0005432394149	364B03	2670 358484	ANDREY BARANOV	{"email": "andreybaranov.061962@postgrespro.ru", "phone": "+70501363796"}
0005432394150	DA4A61	0445 315224	KAMIL FILIPPOV	{"email": "filippov.k-17081973@postgrespro.ru", "phone": "+70689161861"}
0005432394151	DA4A61	2794 796152	LYUBOV LUKYANOVA	{"phone": "+70528641874"}
0005432394152	DA4A61	9068 752639	ALISA KRASNOVA	{"phone": "+70961595907"}
0005432394153	CBADCC	2123 584102	VERA SMIRNOVA	{"email": "v-smirnova_031979@postgrespro.ru", "phone": "+70901513874"}
0005432394154	CBADCC	4952 485423	OLGA TIMOFEEVA	{"phone": "+70403142948"}
0005432394155	88CBD9	6369 802169	SERGEY GERASIMOV	{"email": "gerasimov-s-031961@postgrespro.ru", "phone": "+70700756103"}
0005432394156	AB386F	1832 751336	NATALYA EGOROVA	{"phone": "+70563237912"}
0005432394157	FDD388	0883 362818	OLGA MIKHAYLOVA	{"phone": "+70837594319"}
0005432394158	558239	5801 546241	ALEKSANDR MAKAROV	{"email": "amakarov-18051966@postgrespro.ru", "phone": "+70033145193"}
0005432394159	668377	4635 848924	MARIYA NOVIKOVA	{"phone": "+70082437763"}
0005432394160	123B4A	1375 859259	ALEKSANDR ZHUKOV	{"email": "a_zhukov-1964@postgrespro.ru", "phone": "+70547644481"}
0005432394161	123B4A	3946 587409	IRAIDA RODIONOVA	{"email": "i-rodionova121979@postgrespro.ru", "phone": "+70334851647"}
0005432394162	00A421	6872 313041	ARINA EGOROVA	{"email": "egorovaarina_031978@postgrespro.ru", "phone": "+70962101834"}
0005432394163	C71822	4849 487949	ALEKSANDR POPOV	{"email": "popov-a.05051969@postgrespro.ru", "phone": "+70403683118"}
0005432394164	C71822	9363 280873	ANATOLIY VOLKOV	{"email": "anatoliyvolkov.1975@postgrespro.ru", "phone": "+70593534209"}
0005432394165	7C8FD2	3804 839380	TATYANA KOMAROVA	{"phone": "+70353906805"}
0005432394166	C4B829	3424 945747	NIKOLAY KUZMIN	{"phone": "+70188207955"}
0005432394167	2CBAE6	1438 456102	VITALIY ZAKHAROV	{"email": "zakharov-vitaliy091971@postgrespro.ru", "phone": "+70564240281"}
0005432394168	84294D	9833 796943	VALENTINA SAVELEVA	{"phone": "+70104558452"}
0005432394169	9AD77A	2130 941321	RAFAIL GERASIMOV	{"phone": "+70125691449"}
0005432394170	9AD77A	5692 142018	ALEKSEY DAVYDOV	{"phone": "+70872063451"}
0005432394171	3BCE0F	2754 293179	VERA OSIPOVA	{"email": "osipova_v_101972@postgrespro.ru", "phone": "+70159357574"}
0005432394172	3DC0EA	5856 329652	DANILA MAKAROV	{"email": "makarov.danila10061965@postgrespro.ru", "phone": "+70950470343"}
0005432394173	3DC0EA	1133 417430	VALERIYA OSIPOVA	{"phone": "+70566174816"}
0005432394174	66DB16	5205 379222	NATALYA KUZNECOVA	{"phone": "+70048256443"}
0005432394175	66DB16	8521 792728	ILYA ILIN	{"phone": "+70129121748"}
0005432394176	970180	1122 681307	VALERIY KUZMIN	{"email": "kuzminvaleriy25121968@postgrespro.ru", "phone": "+70344793056"}
0005432394177	970180	1372 803938	ANNA KUZNECOVA	{"email": "kuznecova_a1971@postgrespro.ru", "phone": "+70483350372"}
0005432394178	1C0ED7	7195 449276	DMITRIY VOROBEV	{"email": "vorobev_d.081973@postgrespro.ru", "phone": "+70339485107"}
0005432394179	4426FE	4791 460532	NADEZHDA LUKYANOVA	{"email": "nadezhda-lukyanova081972@postgrespro.ru", "phone": "+70329185238"}
0005432394180	79AC1A	6033 327365	ANNA SERGEEVA	{"phone": "+70608682259"}
0005432394181	E59E05	6827 064199	DMITRIY SCHERBAKOV	{"phone": "+70688699329"}
0005432394182	E59E05	3579 325242	LIDIYA ZAKHAROVA	{"phone": "+70942435290"}
0005432394183	D36742	6135 746216	ANTONINA MOROZOVA	{"email": "antonina_morozova-121972@postgrespro.ru", "phone": "+70148264055"}
0005432394184	D36742	2514 864298	VLADIMIR KUZNECOV	{"phone": "+70010180399"}
0005432394185	897576	2920 249495	ELENA OVCHINNIKOVA	{"email": "ovchinnikovaelena-1972@postgrespro.ru", "phone": "+70504154035"}
0005432394186	434538	2000 864366	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr.1969@postgrespro.ru", "phone": "+70233901080"}
0005432394187	434538	2346 332655	MIKHAIL PAVLOV	{"phone": "+70049608261"}
0005432394188	F18C9A	3687 538472	YANA FROLOVA	{"email": "frolova_y02021960@postgrespro.ru", "phone": "+70863813980"}
0005432394189	F18C9A	0848 231226	SEMEN SAVELEV	{"phone": "+70262260761"}
0005432394190	8E950A	0555 927284	KIRILL NIKITIN	{"phone": "+70859318321"}
0005432394191	047630	2480 745707	SVETLANA SOKOLOVA	{"phone": "+70103677075"}
0005432394192	236B5D	2258 031842	VIKTOR ILIN	{"email": "viktor_ilin_11101978@postgrespro.ru", "phone": "+70751933584"}
0005432394193	DAB49C	4308 216310	ANASTASIYA MOROZOVA	{"email": "anastasiya_morozova081974@postgrespro.ru", "phone": "+70617462060"}
0005432394194	F66463	0121 292743	ANATOLIY PAVLOV	{"email": "apavlov_31071969@postgrespro.ru", "phone": "+70061527385"}
0005432394195	150C04	3171 447362	TATYANA CHERNOVA	{"phone": "+70016022191"}
0005432394196	150C04	5777 536415	NATALYA ZHUKOVA	{"email": "natalyazhukova-1969@postgrespro.ru", "phone": "+70796339241"}
0005432394197	150C04	9559 787350	ROMAN EGOROV	{"email": "r-egorov.1984@postgrespro.ru", "phone": "+70506978000"}
0005432394198	6DB280	4186 344524	YULIYA KOZLOVA	{"email": "kozlova.y.1983@postgrespro.ru", "phone": "+70761764435"}
0005432394199	6DB280	8714 161646	VALENTINA BOGDANOVA	{"email": "bogdanova_v.03031967@postgrespro.ru", "phone": "+70202731359"}
0005432394200	37DC0B	5006 750999	DMITRIY ILIN	{"phone": "+70333794934"}
0005432394201	37DC0B	8099 022956	ANNA NIKOLAEVA	{"phone": "+70617418630"}
0005432394202	458B80	0788 705523	SERGEY TARASOV	{"email": "sergey-tarasov_1962@postgrespro.ru", "phone": "+70844081390"}
0005432394203	458B80	4387 002579	ALISHER VOROBEV	{"email": "alisher_vorobev.081977@postgrespro.ru", "phone": "+70532223648"}
0005432394204	CE9B38	3167 338519	VLADIMIR POPOV	{"email": "v.popov_1959@postgrespro.ru", "phone": "+70256232553"}
0005432394205	20A0A2	4849 281776	ANATOLIY KONOVALOV	{"email": "anatoliy_konovalov_021983@postgrespro.ru", "phone": "+70849346472"}
0005432394206	FE3903	6630 466465	ANDREY ILIN	{"email": "a.ilin-1965@postgrespro.ru", "phone": "+70138903704"}
0005432394207	4554DB	4476 469317	ALEKSEY ISAEV	{"phone": "+70531988379"}
0005432394208	294ED3	2846 413470	MARIYA DANILOVA	{"email": "danilova.mariya.26021979@postgrespro.ru", "phone": "+70892659815"}
0005432394209	A7090C	9304 431666	VALERIY NIKITIN	{"email": "nikitin-v.14061972@postgrespro.ru", "phone": "+70838309024"}
0005432394210	3A4658	4003 961690	LYUBOV KUDRYASHOVA	{"email": "lkudryashova.1976@postgrespro.ru", "phone": "+70672452134"}
0005432394211	3A4658	3623 266055	SERGEY ZAYCEV	{"email": "zaycevs-24021970@postgrespro.ru", "phone": "+70336956949"}
0005432394212	1F63B0	6202 080369	LYUDMILA SERGEEVA	{"phone": "+70429744425"}
0005432394213	BC3C63	3791 867714	DINA YAKOVLEVA	{"phone": "+70337620845"}
0005432394214	BC3C63	8175 618449	VALENTINA ORLOVA	{"email": "orlova.v-1979@postgrespro.ru", "phone": "+70786325448"}
0005432394215	BC3C63	3557 064923	MARIYA KONDRATEVA	{"phone": "+70301048596"}
0005432394216	454299	2525 054369	MIKHAIL ZAYCEV	{"email": "zaycev_m08121969@postgrespro.ru", "phone": "+70765909310"}
0005432394217	BD9293	0600 475175	MARIANNA KARPOVA	{"email": "karpova.marianna.041970@postgrespro.ru", "phone": "+70203060327"}
0005432394218	BD9293	6697 728232	ALEKSEY KOZLOV	{"phone": "+70850825586"}
0005432394219	34F62C	7338 187631	VITALIY ZAYCEV	{"phone": "+70884558613"}
0005432394220	34F62C	5610 689904	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov.051979@postgrespro.ru", "phone": "+70038300284"}
0005432394221	40A65A	3876 541116	SERGEY IVANOV	{"phone": "+70664490969"}
0005432394222	40A65A	6911 247505	IRINA ALEKSEEVA	{"phone": "+70658582016"}
0005432394223	7ECA1D	7708 878554	OLEG IVANOV	{"phone": "+70519330778"}
0005432394224	7ECA1D	3017 973376	SERGEY VASILEV	{"phone": "+70585338236"}
0005432396207	FA8A83	3403 644042	ALEKSANDR IVANOV	{"phone": "+70677673303"}
0005432396170	562D26	7191 566737	OLEG NAUMOV	{"email": "naumov.o_031977@postgrespro.ru", "phone": "+70892609104"}
0005432396171	400132	4027 033492	EKATERINA KOZLOVA	{"email": "kozlova_ekaterina.021980@postgrespro.ru", "phone": "+70889965240"}
0005432396172	400132	4136 935283	LEONID VASILEV	{"phone": "+70128082589"}
0005432396173	FA5478	4718 682955	NADEZHDA ZAYCEVA	{"email": "nadezhda-zayceva_10101987@postgrespro.ru", "phone": "+70682152187"}
0005432396174	EF73BA	5635 370112	VASILIY MELNIKOV	{"email": "vasiliymelnikov_1962@postgrespro.ru", "phone": "+70521238530"}
0005432396175	4D714F	9949 014608	ALEKSANDR KOZLOV	{"phone": "+70546176967"}
0005432396176	4D714F	9685 791034	IVAN ROMANOV	{"phone": "+70221461406"}
0005432396177	E80315	4681 959660	LEONTIY KUZMIN	{"email": "kuzmin_leontiy1978@postgrespro.ru", "phone": "+70773783126"}
0005432396178	E80315	3677 514733	TATYANA ZAKHAROVA	{"email": "t-zakharova041974@postgrespro.ru", "phone": "+70545684945"}
0005432396179	B89A27	8081 566719	ANNA ZAKHAROVA	{"email": "anna_zakharova-021958@postgrespro.ru", "phone": "+70739942039"}
0005432396180	B89A27	4403 214520	VYACHESLAV KUZNECOV	{"phone": "+70236656832"}
0005432396181	0A14D7	9495 230309	ALEKSEY PETROV	{"email": "petrov.aleksey.1987@postgrespro.ru", "phone": "+70875460534"}
0005432396182	0A14D7	8879 423020	GALINA SERGEEVA	{"email": "sergeeva-galina-1957@postgrespro.ru", "phone": "+70755492979"}
0005432396183	22DD7C	1519 947973	ARINA ALEKSEEVA	{"email": "arina-alekseeva_1981@postgrespro.ru", "phone": "+70556786031"}
0005432396184	8AA05A	0717 627443	VIKTORIYA IVANOVA	{"phone": "+70591971510"}
0005432396306	F923BD	7054 337650	VIKTOR KRASNOV	{"phone": "+70243122059"}
0005432396185	95334C	2420 140180	OLGA SOROKINA	{"email": "olga_sorokina_29101969@postgrespro.ru", "phone": "+70651156906"}
0005432396186	95334C	9530 191821	ALEKSEY MAKAROV	{"email": "makarov-a.29061972@postgrespro.ru", "phone": "+70013493090"}
0005432396187	F8D1AC	4679 427035	MAKSIM KAZAKOV	{"phone": "+70180031645"}
0005432396188	8F974E	7426 083188	VIKTOR MAKSIMOV	{"phone": "+70481791718"}
0005432396189	36202E	0816 530362	LYUDMILA ORLOVA	{"phone": "+70774898835"}
0005432396190	B81800	0030 814916	LEONID IVANOV	{"email": "livanov-11101974@postgrespro.ru", "phone": "+70342746797"}
0005432396191	B81800	6516 262498	SANIYA SIDOROVA	{"phone": "+70046418067"}
0005432396192	8E50A1	5249 888447	GENNADIY MATVEEV	{"email": "matveev_g-021964@postgrespro.ru", "phone": "+70612170907"}
0005432396193	200C83	0197 531737	SERGEY IVANOV	{"email": "ivanov_s.21041959@postgrespro.ru", "phone": "+70883701646"}
0005432396194	5E6419	6660 608560	MARINA AFANASEVA	{"phone": "+70015448124"}
0005432396195	5E6419	9389 452734	TAMARA YUDINA	{"phone": "+70082577606"}
0005432396196	DCF76E	4327 771200	GENNADIY DENISOV	{"email": "denisov_g_1970@postgrespro.ru", "phone": "+70886520283"}
0005432396197	A4163A	8801 458094	SERGEY KUZNECOV	{"email": "s-kuznecov14031963@postgrespro.ru", "phone": "+70000847098"}
0005432396198	23308F	5669 833775	ANDREY SOKOLOV	{"email": "sokolov_andrey.031972@postgrespro.ru", "phone": "+70754526986"}
0005432396199	0A8B93	4969 350590	ALEKSANDR ANTONOV	{"email": "antonov-a091970@postgrespro.ru", "phone": "+70479921448"}
0005432396200	0A8B93	6103 535779	LYUDMILA GRISHINA	{"email": "grishina_l_1967@postgrespro.ru", "phone": "+70963170359"}
0005432396201	599017	7138 039633	DARYA FROLOVA	{"email": "frolova-darya-28111973@postgrespro.ru", "phone": "+70547182314"}
0005432396202	7BE3E7	0176 333038	IVAN CHERNOV	{"phone": "+70180316833"}
0005432396203	7BE3E7	3814 425707	YAROSLAV VLASOV	{"phone": "+70701991001"}
0005432396204	6EAFED	8505 360014	VLADISLAV KRASNOV	{"phone": "+70689387711"}
0005432396205	AE0E81	5340 374788	TATYANA BARANOVA	{"phone": "+70079856466"}
0005432396206	AE0E81	4736 518684	GRIGORIY MOISEEV	{"phone": "+70774639942"}
0005432396208	CB568A	8520 947699	DMITRIY EGOROV	{"phone": "+70177063401"}
0005432396209	CB568A	7467 137087	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov-041973@postgrespro.ru", "phone": "+70468556141"}
0005432396210	67A2AF	6053 686391	GALINA NAUMOVA	{"email": "naumovagalina091976@postgrespro.ru", "phone": "+70092992255"}
0005432396211	834F3E	3815 784547	ANNA NAZAROVA	{"email": "anazarova_1972@postgrespro.ru", "phone": "+70039998440"}
0005432396212	31C6DA	1425 475901	ALEKSANDR ANDREEV	{"phone": "+70618786677"}
0005432396213	948F4B	5898 841234	TATYANA SIDOROVA	{"email": "tatyanasidorova-27021977@postgrespro.ru", "phone": "+70845171499"}
0005432396214	948F4B	2788 496865	YURIY MEDVEDEV	{"phone": "+70561401409"}
0005432396215	BD6701	6315 066860	SERGEY EGOROV	{"email": "sergeyegorov_081969@postgrespro.ru", "phone": "+70544243395"}
0005432396216	1BC3AE	6373 944376	NATALYA OVCHINNIKOVA	{"phone": "+70809544109"}
0005432396217	1C6FA8	4971 958213	DARYA TITOVA	{"email": "d_titova.1978@postgrespro.ru", "phone": "+70398412985"}
0005432396218	1C6FA8	1899 729755	EVGENIY VASILEV	{"email": "evgeniy.vasilev_031972@postgrespro.ru", "phone": "+70401752030"}
0005432396219	CA7D11	7692 839045	ANNA NIKOLAEVA	{"email": "a.nikolaeva_1965@postgrespro.ru", "phone": "+70120303019"}
0005432396220	2002BD	5312 823322	YURIY EGOROV	{"email": "y.egorov-28051975@postgrespro.ru", "phone": "+70846608040"}
0005432396221	FD3710	1067 943287	KONSTANTIN ABRAMOV	{"phone": "+70629138772"}
0005432396222	A173DF	7681 550547	PAVEL VOROBEV	{"phone": "+70729397154"}
0005432396223	FF30DB	5626 687088	VALERIY GRIGOREV	{"email": "grigorevv.1974@postgrespro.ru", "phone": "+70544392298"}
0005432396224	85128A	8702 527279	MAKSIM MIKHAYLOV	{"email": "m-mikhaylov_1959@postgrespro.ru", "phone": "+70292401608"}
0005432396225	85128A	3237 546886	ALEKSANDR FEDOROV	{"email": "fedorova.1972@postgrespro.ru", "phone": "+70599796330"}
0005432396226	663AB7	4301 318799	GALINA PETROVA	{"email": "g_petrova-28061965@postgrespro.ru", "phone": "+70354884718"}
0005432396227	663AB7	2848 655301	ARTEM KRASNOV	{"email": "artem-krasnov_23061970@postgrespro.ru", "phone": "+70338290452"}
0005432396228	21D962	3016 303074	SERGEY PAVLOV	{"phone": "+70872003842"}
0005432396229	658216	2431 732444	LYUDMILA MAKAROVA	{"phone": "+70019037079"}
0005432396230	C867EC	3195 329861	SERGEY VOLKOV	{"phone": "+70347578131"}
0005432396231	95BB30	1169 235897	IRINA POPOVA	{"email": "i-popova_06021979@postgrespro.ru", "phone": "+70935199408"}
0005432396232	DCA50A	8057 421875	TATYANA MOROZOVA	{"email": "morozova.t.1957@postgrespro.ru", "phone": "+70455260730"}
0005432396233	68F2E0	6887 198398	ZINAIDA BOGDANOVA	{"email": "zinaidabogdanova_1957@postgrespro.ru", "phone": "+70080982120"}
0005432396234	61E3F1	6019 383503	ALEKSANDR ALEKSANDROV	{"phone": "+70573418656"}
0005432396235	F40FD0	2850 443768	DMITRIY BONDARENKO	{"phone": "+70277934455"}
0005432396236	E8ED80	0076 734381	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.svetlana_031971@postgrespro.ru", "phone": "+70908875344"}
0005432396237	659418	8227 193316	MIKHAIL NIKOLAEV	{"email": "nikolaevmikhail-101972@postgrespro.ru", "phone": "+70449920443"}
0005432396238	659418	2170 696529	LYUBOV ABRAMOVA	{"phone": "+70682700647"}
0005432396239	B248E2	1957 512093	ALEKSEY ANDREEV	{"phone": "+70762542692"}
0005432396240	A9ED99	5074 268010	SERGEY GUSEV	{"phone": "+70352224342"}
0005432396241	A9ED99	6979 148118	MIKHAIL KUDRYASHOV	{"email": "mikhail-kudryashov.031957@postgrespro.ru", "phone": "+70146661239"}
0005432396242	2303AC	0985 281922	IGOR SEMENOV	{"email": "isemenov.101961@postgrespro.ru", "phone": "+70395051555"}
0005432396243	4C1ADD	1193 917810	ELENA FILIPPOVA	{"phone": "+70210646456"}
0005432396244	A6C202	1538 081119	SERGEY POPOV	{"email": "sergeypopov.18031970@postgrespro.ru", "phone": "+70389762417"}
0005432396245	B9E048	2818 519525	IRINA ISAEVA	{"email": "i_isaeva15071976@postgrespro.ru", "phone": "+70306956528"}
0005432396246	063151	1534 131260	OLGA NESTEROVA	{"phone": "+70972108966"}
0005432396247	6AEF01	4579 919834	ARTEM SCHERBAKOV	{"phone": "+70523580712"}
0005432396248	06B5AD	6070 137027	IGOR NIKOLAEV	{"phone": "+70479999090"}
0005432396249	1E825E	7074 369767	TATYANA ALEKSANDROVA	{"phone": "+70322265173"}
0005432396250	0C032E	0196 645702	MIKHAIL KULIKOV	{"phone": "+70626592931"}
0005432396251	0C032E	9350 228842	OLEG KUDRYASHOV	{"phone": "+70012321269"}
0005432396252	47DC7B	9628 543907	RUSLAN NAUMOV	{"email": "naumov.r_1977@postgrespro.ru", "phone": "+70101106475"}
0005432396253	47DC7B	2878 114018	VADIM KUZNECOV	{"phone": "+70100061485"}
0005432396254	EDF5EA	3931 409702	NINA BELYAEVA	{"email": "belyaeva.nina.101968@postgrespro.ru", "phone": "+70673659244"}
0005432396255	0421E9	8429 274255	VERA ZHURAVLEVA	{"phone": "+70560170456"}
0005432396256	889A31	5459 424069	DIANA ANTONOVA	{"phone": "+70176003631"}
0005432396257	767315	0229 517976	MAYYA ANTONOVA	{"email": "antonova.m.1982@postgrespro.ru", "phone": "+70924328588"}
0005432396258	E2DDD0	3857 303251	EVGENIYA GERASIMOVA	{"email": "gerasimova-evgeniya.05111971@postgrespro.ru", "phone": "+70803411708"}
0005432396259	A54955	9467 747473	EVGENIY YAKOVLEV	{"phone": "+70945587998"}
0005432396260	12719C	3684 802671	SVETLANA PAVLOVA	{"email": "svetlanapavlova1973@postgrespro.ru", "phone": "+70377656560"}
0005432396261	864C16	6120 763585	VLADIMIR ZHUKOV	{"email": "zhukov-v_31031971@postgrespro.ru", "phone": "+70247815913"}
0005432396262	804A8E	1586 869965	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev_101985@postgrespro.ru", "phone": "+70501300934"}
0005432396263	8DB2D5	2266 074375	VLADIMIR BELOV	{"email": "vladimir-belov.111970@postgrespro.ru", "phone": "+70753691715"}
0005432396264	8DB2D5	4164 285327	NINA DENISOVA	{"email": "nina.denisova-1973@postgrespro.ru", "phone": "+70356243750"}
0005432396265	A18664	1861 749120	ALEKSANDR ZHUKOV	{"email": "azhukov_1963@postgrespro.ru", "phone": "+70331864235"}
0005432396266	A18664	4927 295848	LIDIYA BELOVA	{"phone": "+70460498335"}
0005432396267	FC432B	5780 219994	TATYANA SOLOVEVA	{"phone": "+70030498881"}
0005432396268	E1D5A8	4399 812070	NINA VASILEVA	{"email": "vasileva-nina_19111957@postgrespro.ru", "phone": "+70986937804"}
0005432396269	7E3F3F	9069 410871	ALEKSANDR FROLOV	{"phone": "+70335257606"}
0005432396270	7E3F3F	0100 122669	ALEKSEY BORISOV	{"phone": "+70740511803"}
0005432396271	4DEC4D	9114 287323	LIDIYA POPOVA	{"phone": "+70598764146"}
0005432396272	10222D	4945 091079	KIRILL IVANOV	{"phone": "+70184727695"}
0005432396273	E8A336	3445 537450	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev.1978@postgrespro.ru", "phone": "+70010025304"}
0005432396274	E8A336	7872 637061	GLEB STEPANOV	{"phone": "+70665910474"}
0005432396275	FC9506	5620 064312	KONSTANTIN BARANOV	{"phone": "+70104717001"}
0005432396276	F56B2E	3704 552746	KLAVDIYA ALEKSEEVA	{"email": "klavdiya_alekseeva1972@postgrespro.ru", "phone": "+70345769660"}
0005432396277	F56B2E	8042 909503	IRINA STEPANOVA	{"phone": "+70049160038"}
0005432396278	29B965	3686 767568	TATYANA SOLOVEVA	{"email": "soloveva.t.13061965@postgrespro.ru", "phone": "+70154622910"}
0005432396279	082CB4	9850 545197	VASILIY KUZNECOV	{"email": "kuznecov.vasiliy_1973@postgrespro.ru", "phone": "+70629388749"}
0005432396280	082CB4	5351 906941	ANATOLIY STEPANOV	{"phone": "+70047704916"}
0005432396281	1BC6B2	3425 368207	GALINA KULIKOVA	{"email": "kulikovag.1961@postgrespro.ru", "phone": "+70382418201"}
0005432396282	1BC6B2	6594 500911	VERA SCHERBAKOVA	{"phone": "+70851984311"}
0005432396283	511B16	2881 690264	RAISA NIKITINA	{"phone": "+70286387195"}
0005432396284	F87159	8415 822975	LIDIYA POLYAKOVA	{"email": "polyakova-l.23101963@postgrespro.ru", "phone": "+70657087908"}
0005432396285	289A8A	1984 859983	NATALYA KOLESNIKOVA	{"phone": "+70712394968"}
0005432396286	AD721C	8696 487590	ZINAIDA ZAKHAROVA	{"email": "zakharova-z13011967@postgrespro.ru", "phone": "+70096919605"}
0005432396287	70C3F5	8104 120479	VIKTORIYA TROFIMOVA	{"phone": "+70956801280"}
0005432396288	5D7BE7	3548 234403	EKATERINA LAZAREVA	{"phone": "+70395624851"}
0005432396289	5D7BE7	9220 251430	ZHANNA BELYAEVA	{"phone": "+70287734023"}
0005432396290	618C28	0839 390151	ALEKSEY OSIPOV	{"email": "aosipov-1981@postgrespro.ru", "phone": "+70576647217"}
0005432396291	618C28	4620 297017	IRINA KOROLEVA	{"email": "korolevairina-041982@postgrespro.ru", "phone": "+70146984867"}
0005432396292	618C28	2576 516627	OLGA SOROKINA	{"phone": "+70434139191"}
0005432396293	26A6E3	8100 793991	OLGA SERGEEVA	{"email": "sergeeva.o_1973@postgrespro.ru", "phone": "+70091990891"}
0005432396294	26A6E3	9901 579358	MARIYA SIDOROVA	{"phone": "+70161707885"}
0005432396295	D407F8	7987 061921	EKATERINA NOVIKOVA	{"phone": "+70612159363"}
0005432396296	82C067	4995 132624	ALEKSANDRA KUZNECOVA	{"email": "a-kuznecova.011967@postgrespro.ru", "phone": "+70913763913"}
0005432396297	82C067	0347 472558	KONSTANTIN STEPANOV	{"phone": "+70006513918"}
0005432396298	54F7F6	3100 678911	NINA TIMOFEEVA	{"email": "n_timofeeva_071966@postgrespro.ru", "phone": "+70429204656"}
0005432396299	54F7F6	3149 528140	VITALIY VOROBEV	{"email": "vorobev.vitaliy-1972@postgrespro.ru", "phone": "+70953861438"}
0005432396300	54F7F6	0451 555361	SVETLANA FILATOVA	{"email": "s_filatova.071976@postgrespro.ru", "phone": "+70241203639"}
0005432396301	D5426F	0536 472148	NIKOLAY BORISOV	{"phone": "+70156324945"}
0005432396302	D41255	1030 784884	VLADIMIR DENISOV	{"phone": "+70690984518"}
0005432396303	D41255	4023 111143	VASILIY MIKHAYLOV	{"email": "vasiliy.mikhaylov_09031966@postgrespro.ru", "phone": "+70715077863"}
0005432396304	1073BC	8168 401861	ALEKSEY MOISEEV	{"email": "a_moiseev.17111971@postgrespro.ru", "phone": "+70963959277"}
0005432396305	299CA1	8713 689972	ANNA MAKAROVA	{"email": "a.makarova-22041974@postgrespro.ru", "phone": "+70458222625"}
0005432396307	EECBEF	6025 909992	ALEKSANDR ZHUKOV	{"phone": "+70569486668"}
0005432396308	EECBEF	6572 830502	LYUBOV RYABOVA	{"email": "lryabova.01011965@postgrespro.ru", "phone": "+70851309523"}
0005432396309	3856A8	4523 570312	LIDIYA TARASOVA	{"phone": "+70452494885"}
0005432396310	524D92	0317 145161	SERGEY BORISOV	{"phone": "+70091473321"}
0005432396311	79CD3C	9943 174290	DANIIL OSIPOV	{"email": "d-osipov-01021968@postgrespro.ru", "phone": "+70268757203"}
0005432396312	79CD3C	1517 666290	DMITRIY SCHERBAKOV	{"email": "scherbakov-dmitriy_111964@postgrespro.ru", "phone": "+70512864716"}
0005432396313	151022	1470 433359	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-1960@postgrespro.ru", "phone": "+70479871642"}
0005432396314	B32AB3	7972 770174	ALEKSANDR SIDOROV	{"phone": "+70615124583"}
0005432396315	DAB2D9	4107 168200	ELENA KUZNECOVA	{"phone": "+70188459049"}
0005432396316	B893D0	3264 862404	FELIKS SEMENOV	{"phone": "+70868949816"}
0005432396317	AF727A	3972 914603	SVETLANA SIDOROVA	{"email": "sidorova_svetlana1978@postgrespro.ru", "phone": "+70317820899"}
0005432396318	DC9F01	3007 119791	NINA KRASNOVA	{"email": "n_krasnova.051973@postgrespro.ru", "phone": "+70222424308"}
0005432396319	DC9F01	2237 064258	ILMIRA MIRONOVA	{"phone": "+70969592094"}
0005432396320	F27D2A	7006 329676	TATYANA SEMENOVA	{"email": "semenova_tatyana.081969@postgrespro.ru", "phone": "+70109031306"}
0005432396321	BCCCAB	2260 975188	SVETLANA KUDRYASHOVA	{"email": "kudryashova.s_20061973@postgrespro.ru", "phone": "+70929298679"}
0005432396322	17970E	7137 849726	KLAVDIYA NIKOLAEVA	{"email": "nikolaeva-k1972@postgrespro.ru", "phone": "+70142380267"}
0005432396323	17970E	5277 372229	TATYANA SOKOLOVA	{"phone": "+70149245947"}
0005432396324	D6F6C9	8594 186379	VALERIY FEDOTOV	{"phone": "+70830486977"}
0005432396325	7F5398	1674 105686	YULIYA NESTEROVA	{"email": "nesterovay_1963@postgrespro.ru", "phone": "+70984740349"}
0005432396326	A521C5	2002 559267	NIKITA ZHUKOV	{"phone": "+70726735167"}
0005432396327	A521C5	1394 103694	VASILIY NIKOLAEV	{"phone": "+70916838345"}
0005432396328	E34543	4485 573610	VLADIMIR VASILEV	{"phone": "+70678760759"}
0005432396329	B46931	6787 473868	VYACHESLAV BONDARENKO	{"email": "bondarenkov_24121972@postgrespro.ru", "phone": "+70435027457"}
0005432396330	05E267	9516 956370	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov_08031970@postgrespro.ru", "phone": "+70183226985"}
0005432396331	05E267	2489 399984	VYACHESLAV NIKOLAEV	{"email": "v-nikolaev_1970@postgrespro.ru", "phone": "+70727398591"}
0005432396332	9C39C1	2658 512775	YULIYA MATVEEVA	{"phone": "+70393429254"}
0005432396333	9C39C1	4255 104254	OLGA BORISOVA	{"phone": "+70365925761"}
0005432396334	9395FF	7059 972758	VYACHESLAV ORLOV	{"phone": "+70614346583"}
0005432396335	A6DE3A	9500 028019	KONSTANTIN DENISOV	{"phone": "+70874072525"}
0005432396336	2D75F6	8697 536975	ANNA ISAEVA	{"email": "anna.isaeva.041965@postgrespro.ru", "phone": "+70118792860"}
0005432396337	A83E08	0767 595189	OKSANA KUZNECOVA	{"email": "o.kuznecova.04121985@postgrespro.ru", "phone": "+70157799370"}
0005432396338	1EE080	8441 381015	ANATOLIY KRASNOV	{"email": "krasnova.1985@postgrespro.ru", "phone": "+70392651242"}
0005432396339	1EE080	5156 650862	VALERIYA POPOVA	{"phone": "+70991952545"}
0005432396340	15809B	8518 970687	RIMMA FILIPPOVA	{"phone": "+70665823860"}
0005432396341	15809B	2484 859581	ALIYA SOKOLOVA	{"email": "a-sokolova_1966@postgrespro.ru", "phone": "+70891233312"}
0005432396342	5C821F	4309 154635	RUSTAM SEMENOV	{"phone": "+70575081978"}
0005432396343	6FB84E	5387 170584	ANTONINA ANTONOVA	{"phone": "+70572378576"}
0005432396344	6FD6BF	3615 122540	ALEKSANDR YAKOVLEV	{"phone": "+70053937183"}
0005432396345	4B01B3	0436 755921	GRIGORIY PETROV	{"email": "grigoriy.petrov03061969@postgrespro.ru", "phone": "+70395119695"}
0005432396346	39EBDE	5461 236781	ANATOLIY CHERNOV	{"phone": "+70848230775"}
0005432396347	39EBDE	6453 199029	VIKTOR SERGEEV	{"phone": "+70313922812"}
0005432396348	CA7647	0942 580446	ARTUR ANTONOV	{"email": "arturantonov_1976@postgrespro.ru", "phone": "+70772010699"}
0005432396349	9F08BD	5116 948455	BORIS KONOVALOV	{"phone": "+70957671905"}
0005432396350	5FB8E0	7001 996289	ALEKSEY BELOV	{"phone": "+70458787758"}
0005432396351	5FB8E0	7027 855679	SVETLANA NAZAROVA	{"email": "s_nazarova.111965@postgrespro.ru", "phone": "+70907860913"}
0005432396352	58838D	2965 245855	YURIY ROMANOV	{"email": "yuriy.romanov-011974@postgrespro.ru", "phone": "+70781400998"}
0005432396353	A5E8B3	7819 506746	SVETLANA IVANOVA	{"phone": "+70806239375"}
0005432396354	85F2EF	7202 217056	LYUDMILA DANILOVA	{"phone": "+70687615774"}
0005432396355	3220C2	1972 558634	MARIYA SCHERBAKOVA	{"email": "m_scherbakova.1975@postgrespro.ru", "phone": "+70977673736"}
0005432396356	5F1009	0907 845705	TATYANA PAVLOVA	{"email": "tatyana_pavlova_041978@postgrespro.ru", "phone": "+70730666130"}
0005432396357	5F1009	6868 203890	IGNAT POPOV	{"email": "popov.i.121977@postgrespro.ru", "phone": "+70009708540"}
0005432396358	1E96D0	9249 313146	LYUBOV PAVLOVA	{"email": "pavlova_l.091976@postgrespro.ru", "phone": "+70220864956"}
0005432398129	83221B	5442 052554	IGOR TIMOFEEV	{"phone": "+70848669766"}
0005432398130	83221B	2165 573613	SERGEY KUZNECOV	{"phone": "+70237076933"}
0005432398131	5B05E6	8304 451076	VALERIYA MAKAROVA	{"email": "v_makarova-011962@postgrespro.ru", "phone": "+70623443311"}
0005432398132	0AD8C7	0967 884879	SERGEY AFANASEV	{"phone": "+70955361938"}
0005432398133	68E645	7748 480312	NINA SERGEEVA	{"phone": "+70596867953"}
0005432398134	68E645	1282 615823	IVAN KRASNOV	{"phone": "+70020290975"}
0005432398135	BFCA1F	4837 177834	VIKTOR KUZNECOV	{"email": "v-kuznecov.091966@postgrespro.ru", "phone": "+70084679572"}
0005432398136	90C450	9879 200851	ELENA NIKITINA	{"phone": "+70440033092"}
0005432398137	874168	9152 977910	NADEZHDA ZAKHAROVA	{"phone": "+70122181512"}
0005432398138	874168	2191 004560	LYUBOV SOLOVEVA	{"phone": "+70556004184"}
0005432398139	DDC63A	0012 059874	NATALYA IVANOVA	{"phone": "+70072395986"}
0005432398140	DDC63A	9990 420949	SERGEY KOZLOV	{"phone": "+70509988646"}
0005432398141	DDC63A	1570 594736	LARISA MIRONOVA	{"phone": "+70484287485"}
0005432398142	B35221	3004 894682	ALEKSANDR FROLOV	{"email": "a_frolov.071969@postgrespro.ru", "phone": "+70013116194"}
0005432398143	7B6E5C	8277 298322	YULIYA STEPANOVA	{"email": "stepanova-y-071975@postgrespro.ru", "phone": "+70708008463"}
0005432398144	7B6E5C	7199 291304	VLADIMIR POPOV	{"phone": "+70398793190"}
0005432398145	7B6E5C	9713 917235	ANNA SOKOLOVA	{"email": "sokolova_anna_02061970@postgrespro.ru", "phone": "+70247601335"}
0005432398146	B04E44	1782 032947	KIRILL DMITRIEV	{"phone": "+70116409739"}
0005432398147	B11C8C	3571 757009	YURIY PAVLOV	{"email": "y_pavlov-18121972@postgrespro.ru", "phone": "+70155594284"}
0005432398148	B11C8C	1340 204805	ALEKSANDR IVANOV	{"phone": "+70815020662"}
0005432398149	AA7A98	4691 106945	SERGEY DENISOV	{"phone": "+70401437458"}
0005432398150	66CA35	7500 724127	IRINA KONDRATEVA	{"phone": "+70007633873"}
0005432398151	CF3179	6905 817618	KONSTANTIN FOMIN	{"email": "k-fomin101965@postgrespro.ru", "phone": "+70689608228"}
0005432398152	15FA45	7447 380298	MIKHAIL CHERNOV	{"phone": "+70187473711"}
0005432398153	149054	2976 188761	ANNA ZOTOVA	{"email": "anna_zotova.15071977@postgrespro.ru", "phone": "+70507671131"}
0005432398154	5B17AC	8275 238951	MARIYA FILIPPOVA	{"phone": "+70685790879"}
0005432398155	3E085A	3354 291162	VLADISLAV PAVLOV	{"phone": "+70183352137"}
0005432398156	3E085A	9336 740178	ELENA MAKAROVA	{"phone": "+70255876005"}
0005432398157	D87CDC	3298 222456	DANIIL FEDOTOV	{"phone": "+70791401149"}
0005432398158	F4EE5A	5042 275135	RAISA LEBEDEVA	{"phone": "+70435365384"}
0005432398159	F4EE5A	7855 482567	ANTON SAVELEV	{"phone": "+70544195662"}
0005432398160	27BAB0	2486 706655	ANTONINA ZOTOVA	{"phone": "+70370128991"}
0005432398161	27BAB0	8265 979767	TAMARA VLASOVA	{"phone": "+70477158554"}
0005432398162	944927	6602 274892	LILIYA SOLOVEVA	{"email": "soloveva.liliya-1969@postgrespro.ru", "phone": "+70486707719"}
0005432398163	FFA4C5	3467 656288	ANNA ALEKSANDROVA	{"phone": "+70396902924"}
0005432398164	33F573	1843 965679	YURIY ZHUKOV	{"phone": "+70679289086"}
0005432398165	26E4DB	6605 034262	DANILA ANDREEV	{"email": "d-andreev_10031962@postgrespro.ru", "phone": "+70879053036"}
0005432398166	3F3867	3356 257995	NINA VASILEVA	{"email": "ninavasileva-02091976@postgrespro.ru", "phone": "+70141598296"}
0005432398167	3F3867	9460 937807	ALEKSANDR POPOV	{"email": "popov-aleksandr091969@postgrespro.ru", "phone": "+70856452845"}
0005432398168	DA7D75	2123 901186	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov_091964@postgrespro.ru", "phone": "+70569349458"}
0005432398169	5A14D0	2513 182507	NADEZHDA GAVRILOVA	{"email": "gavrilova-nadezhda-26091974@postgrespro.ru", "phone": "+70733758949"}
0005432398170	5A14D0	4376 288828	LIDIYA BELOVA	{"email": "belova-lidiya_021981@postgrespro.ru", "phone": "+70095319134"}
0005432398171	5B5782	4081 447339	DMITRIY TIMOFEEV	{"phone": "+70193428756"}
0005432398172	5B5782	5161 657015	VALENTINA DENISOVA	{"email": "valentina.denisova-26111970@postgrespro.ru", "phone": "+70499905497"}
0005432398173	FDE875	7807 275189	SERGEY MATVEEV	{"phone": "+70393709715"}
0005432398174	3A841F	9769 731210	SERGEY GAVRILOV	{"phone": "+70189746482"}
0005432398175	3A841F	7904 922373	TAMARA GERASIMOVA	{"email": "gerasimova-tamara061972@postgrespro.ru", "phone": "+70881197454"}
0005432398176	9893BE	8775 945879	VLADIMIR BORISOV	{"phone": "+70020645430"}
0005432398177	9893BE	2009 291612	LYUBOV TIKHONOVA	{"phone": "+70364730435"}
0005432398178	9893BE	6472 044492	ALENA IVANOVA	{"email": "ivanova.a03091975@postgrespro.ru", "phone": "+70018938397"}
0005432398179	7D1D7A	1928 506296	VADIM VASILEV	{"email": "vasilev.vadim02021978@postgrespro.ru", "phone": "+70096134588"}
0005432398180	25C9CA	9766 084793	ELENA POPOVA	{"email": "e-popova.1968@postgrespro.ru", "phone": "+70125784432"}
0005432398181	3A1135	7179 900650	NIKOLAY NAZAROV	{"email": "nikolay.nazarov.1969@postgrespro.ru", "phone": "+70223839090"}
0005432398182	26D0AE	9631 380801	GALINA IVANOVA	{"phone": "+70427294300"}
0005432398183	26D0AE	4119 929978	KLAVDIYA KUZNECOVA	{"email": "kuznecova_k.1965@postgrespro.ru", "phone": "+70372973192"}
0005432398184	3AAF92	3247 848563	ARTEM MOROZOV	{"email": "artem_morozov18091979@postgrespro.ru", "phone": "+70855787722"}
0005432398185	3AAF92	7038 010292	PAVEL VASILEV	{"phone": "+70852623455"}
0005432398186	38DCC3	3343 503826	INESSA BELYAEVA	{"email": "ibelyaeva-061973@postgrespro.ru", "phone": "+70808563966"}
0005432398187	38DCC3	2170 908702	LARISA VOLKOVA	{"email": "lvolkova-05121971@postgrespro.ru", "phone": "+70972242899"}
0005432398188	C00478	9263 267478	EVGENIY KARPOV	{"phone": "+70933549763"}
0005432398189	9A04D1	3903 995471	ILYA ORLOV	{"email": "ilyaorlov_1974@postgrespro.ru", "phone": "+70575617589"}
0005432398190	3DE30B	2692 269604	VYACHESLAV AFANASEV	{"phone": "+70427022072"}
0005432398191	46FAEA	6508 153032	VASILIY MELNIKOV	{"email": "vasiliy_melnikov-031969@postgrespro.ru", "phone": "+70469006995"}
0005432398192	BDD139	1489 229481	YURIY KUZMIN	{"email": "kuzminy-1962@postgrespro.ru", "phone": "+70570012848"}
0005432398193	BDD139	1463 252243	OLGA RODIONOVA	{"email": "o.rodionova1971@postgrespro.ru", "phone": "+70603349321"}
0005432398194	DBF32C	8154 284780	GALINA NIKOLAEVA	{"email": "galina-nikolaeva.1970@postgrespro.ru", "phone": "+70132013948"}
0005432398195	A56F37	6007 669594	ALENA ZHUKOVA	{"phone": "+70527508244"}
0005432398196	BAC844	7103 054199	ALENA CHERNOVA	{"email": "alenachernova_071971@postgrespro.ru", "phone": "+70859631016"}
0005432398197	BAC844	2995 419425	VALENTINA BORISOVA	{"phone": "+70744932126"}
0005432398198	BAC844	2816 205754	SVETLANA KUDRYASHOVA	{"email": "kudryashovasvetlana-21011977@postgrespro.ru", "phone": "+70639173713"}
0005432398199	70A1E1	3952 738596	SERGEY IVANOV	{"email": "ivanovsergey.27111970@postgrespro.ru", "phone": "+70514772502"}
0005432398200	A85568	3873 651046	SVETLANA OSIPOVA	{"email": "sosipova-101972@postgrespro.ru", "phone": "+70363373044"}
0005432398201	A85568	6528 202250	ALEKSANDR MATVEEV	{"phone": "+70804454880"}
0005432398202	A85568	4718 816927	ANDREY KUZMIN	{"phone": "+70587944811"}
0005432398203	54C8AC	7331 840194	OLEG ZAKHAROV	{"phone": "+70384867649"}
0005432398204	2BD49B	5897 588495	VIKTOR SHEVCHENKO	{"email": "viktor.shevchenko-12011972@postgrespro.ru", "phone": "+70933043254"}
0005432398205	2BD49B	0298 179374	ALEKSANDR VASILEV	{"email": "a-vasilev.27041969@postgrespro.ru", "phone": "+70349066164"}
0005432398206	E4C640	0543 345223	ALEKSANDR NIKOLAEV	{"phone": "+70758869443"}
0005432398207	EC94BC	5919 823602	MAKSIM SERGEEV	{"phone": "+70988566525"}
0005432398208	EC94BC	9047 686472	YURIY TIKHONOV	{"email": "tikhonovy1974@postgrespro.ru", "phone": "+70963326632"}
0005432398209	EC94BC	1363 127885	ALEKSANDR MARTYNOV	{"phone": "+70195511035"}
0005432398210	5AE225	0993 320963	VYACHESLAV KUZNECOV	{"phone": "+70597293016"}
0005432398211	A21AC0	8490 646241	MAKSIM IVANOV	{"email": "ivanov_maksim-1976@postgrespro.ru", "phone": "+70466538680"}
0005432398212	A21AC0	8241 809819	ANASTASIYA KUZMINA	{"phone": "+70030980861"}
0005432398213	DD39C9	0085 843297	OLGA FROLOVA	{"email": "o_frolova_20071964@postgrespro.ru", "phone": "+70313014582"}
0005432398214	CD7E73	7733 200218	DANIIL DAVYDOV	{"phone": "+70482276086"}
0005432398215	CD7E73	6404 202197	ALEKSANDRA VOLKOVA	{"phone": "+70473843279"}
0005432398216	AD6902	0195 797247	ANDREY SAVELEV	{"phone": "+70848957686"}
0005432398217	EA5C02	6611 037432	IVAN DENISOV	{"email": "denisov-i_041977@postgrespro.ru", "phone": "+70269144579"}
0005432398218	C9A187	1042 444612	STANISLAV BARANOV	{"email": "baranov.stanislav071980@postgrespro.ru", "phone": "+70649918715"}
0005432398219	834613	2267 798461	ALEKSANDR BARANOV	{"email": "baranov.a05021961@postgrespro.ru", "phone": "+70798594729"}
0005432398220	0012E3	7367 064895	TATYANA ORLOVA	{"email": "orlova_t_28041985@postgrespro.ru", "phone": "+70300461807"}
0005432398221	34AC31	1810 468803	VLADIMIR TARASOV	{"phone": "+70430229082"}
0005432398222	34AC31	5462 408108	IVAN POPOV	{"email": "ipopov1968@postgrespro.ru", "phone": "+70092808504"}
0005432398223	8D6A72	3907 694797	IRINA SEMENOVA	{"phone": "+70113900203"}
0005432398224	8D6A72	6576 262671	TATYANA SOKOLOVA	{"phone": "+70384150345"}
0005432398225	5F1C41	4788 611275	MARGARITA ANDREEVA	{"email": "andreeva.m-081972@postgrespro.ru", "phone": "+70349436776"}
0005432398226	E61492	6885 024084	VLADIMIR NOVIKOV	{"phone": "+70815724406"}
0005432398227	C3BBCD	0270 900143	ALEKSANDR BORISOV	{"phone": "+70785061149"}
0005432398228	C3BBCD	4109 678389	VASILIY VASILEV	{"phone": "+70075285319"}
0005432398229	776B25	4583 379985	TAMARA MAKAROVA	{"email": "tamara_makarova.061985@postgrespro.ru", "phone": "+70690933492"}
0005432398230	D41296	2850 703917	ALEKSEY NAUMOV	{"phone": "+70852890400"}
0005432398231	2D1D9F	0429 014010	TAISIYA ANDREEVA	{"phone": "+70122216736"}
0005432398232	2D1D9F	9651 092021	TATYANA VOLKOVA	{"email": "tatyana_volkova_071975@postgrespro.ru", "phone": "+70385788140"}
0005432398233	0D7DAE	3780 133239	TAISIYA VLASOVA	{"phone": "+70361284859"}
0005432398234	FEF2CD	5662 200469	ANNA MATVEEVA	{"email": "anna_matveeva.091979@postgrespro.ru", "phone": "+70748059543"}
0005432398235	B2002F	1592 180318	EKATERINA NIKITINA	{"phone": "+70922079608"}
0005432398236	EAE06E	8584 950798	OLGA NIKITINA	{"email": "nikitina.o-22051977@postgrespro.ru", "phone": "+70684283489"}
0005432398237	381256	3950 556749	NATALIYA PETROVA	{"email": "n.petrova.101965@postgrespro.ru", "phone": "+70875328368"}
0005432398238	381256	9527 364740	SERGEY KUDRYASHOV	{"phone": "+70427293476"}
0005432398239	E4492F	4902 103401	EVGENIY FROLOV	{"email": "e_frolov.28101963@postgrespro.ru", "phone": "+70710198919"}
0005432398240	BEE38C	6193 413188	NATALYA ORLOVA	{"email": "n.orlova-031978@postgrespro.ru", "phone": "+70419966412"}
0005432398241	198AB1	7810 431060	ALINA ANDREEVA	{"email": "alina_andreeva_27071981@postgrespro.ru", "phone": "+70948516233"}
0005432398242	198AB1	5669 388431	GALINA KUZNECOVA	{"email": "kuznecova.g12121981@postgrespro.ru", "phone": "+70555064486"}
0005432398243	F452EA	4756 526929	VASILIY ALEKSEEV	{"email": "vasiliyalekseev_1967@postgrespro.ru", "phone": "+70861077501"}
0005432398244	F452EA	7454 333813	ALENA SOKOLOVA	{"phone": "+70742521741"}
0005432398245	F452EA	9942 464075	ELIZAVETA KUDRYASHOVA	{"phone": "+70357169516"}
0005432398246	0DC24D	0584 606395	ELENA IVANOVA	{"email": "e_ivanova17031972@postgrespro.ru", "phone": "+70808858875"}
0005432398247	0DC24D	7825 357854	NATALYA SIDOROVA	{"email": "n.sidorova-1972@postgrespro.ru", "phone": "+70273700445"}
0005432398248	FD548D	1996 404244	MARIYA GAVRILOVA	{"phone": "+70343945549"}
0005432398249	50AE20	1162 199809	IRINA ABRAMOVA	{"email": "irinaabramova.021974@postgrespro.ru", "phone": "+70647082029"}
0005432398250	0FC9B3	3398 553630	VITALIY NIKOLAEV	{"email": "v_nikolaev071980@postgrespro.ru", "phone": "+70236144042"}
0005432398251	1969C9	9121 059878	ANTONINA KUZMINA	{"email": "kuzmina_antonina_101969@postgrespro.ru", "phone": "+70073367672"}
0005432398252	DC6B96	9699 148137	VYACHESLAV GRIGOREV	{"email": "grigorev_vyacheslav_121977@postgrespro.ru", "phone": "+70392693049"}
0005432398253	5C921B	9051 895915	VASILIY VASILEV	{"email": "vvasilev-01041968@postgrespro.ru", "phone": "+70071884690"}
0005432398254	A53622	0404 999273	IGOR SEMENOV	{"email": "semenov.igor.051977@postgrespro.ru", "phone": "+70027132940"}
0005432398255	C8C0EC	2013 628800	VLADIMIR NAUMOV	{"email": "naumov_vladimir-051978@postgrespro.ru", "phone": "+70728152457"}
0005432398256	5D6A0A	6692 977449	ALENA KUZNECOVA	{"email": "alenakuznecova27111962@postgrespro.ru", "phone": "+70931827326"}
0005432398257	5D6A0A	5854 775098	SERGEY SEMENOV	{"phone": "+70575966648"}
0005432398258	A9DD14	8572 031822	VALENTINA DANILOVA	{"email": "valentinadanilova_101967@postgrespro.ru", "phone": "+70861177180"}
0005432398259	ED5096	0621 982998	VIKTOR TIMOFEEV	{"email": "timofeev-viktor.14041969@postgrespro.ru", "phone": "+70425171128"}
0005432398260	806D4F	5902 468237	YULIYA OSIPOVA	{"phone": "+70612402324"}
0005432398261	95B95B	7767 785110	LIDIYA ANDREEVA	{"phone": "+70189510749"}
0005432398262	95B95B	7470 367575	SERGEY SAVELEV	{"email": "savelev.sergey.19081973@postgrespro.ru", "phone": "+70387057032"}
0005432398263	EC5529	0772 594484	YURIY SEMENOV	{"phone": "+70837073365"}
0005432398264	EC5529	8732 761338	ELENA MIRONOVA	{"email": "mironova_e-09041976@postgrespro.ru", "phone": "+70050771893"}
0005432398265	85B7B2	4356 695937	NINA IVANOVA	{"email": "ivanovanina021973@postgrespro.ru", "phone": "+70930037388"}
0005432398266	E89D39	6812 669073	TATYANA SOKOLOVA	{"email": "sokolova_tatyana-26041981@postgrespro.ru", "phone": "+70790381366"}
0005432398267	316973	2397 910238	MIKHAIL VOROBEV	{"email": "mvorobev-1971@postgrespro.ru", "phone": "+70473742613"}
0005432398268	853DDE	5986 323010	IGOR ORLOV	{"email": "orlov.igor-1981@postgrespro.ru", "phone": "+70411235100"}
0005432398269	8924E0	0877 588031	MARINA IVANOVA	{"phone": "+70948418105"}
0005432398270	8924E0	9993 016393	VALENTINA KULIKOVA	{"email": "kulikova_v.17111979@postgrespro.ru", "phone": "+70698786511"}
0005432398271	5B2A7E	6911 217323	IVAN NIKITIN	{"email": "i.nikitin_26061960@postgrespro.ru", "phone": "+70622646734"}
0005432398272	99B4C2	3008 813599	YURIY MAKSIMOV	{"email": "maksimov.yuriy_1965@postgrespro.ru", "phone": "+70741612731"}
0005432398273	B378CF	7386 097633	LIDIYA YAKOVLEVA	{"email": "l_yakovleva121988@postgrespro.ru", "phone": "+70680060221"}
0005432398274	B378CF	8104 233532	ANGELINA IVANOVA	{"email": "angelina.ivanova-081970@postgrespro.ru", "phone": "+70173775263"}
0005432398275	65708A	3905 210819	SERGEY TARASOV	{"email": "sergey.tarasov.021972@postgrespro.ru", "phone": "+70475006076"}
0005432398276	B0A19B	7067 289646	DIANA ABRAMOVA	{"email": "abramovad-051971@postgrespro.ru", "phone": "+70472519381"}
0005432398277	CCC797	2732 745423	MAKSIM KOZLOV	{"email": "m-kozlov-1977@postgrespro.ru", "phone": "+70358205286"}
0005432398278	E1638C	2144 298458	VLADIMIR KUZNECOV	{"email": "kuznecov.v.1976@postgrespro.ru", "phone": "+70814878620"}
0005432398279	24C224	7287 234591	TATYANA IVANOVA	{"email": "tivanova.011965@postgrespro.ru", "phone": "+70202437550"}
0005432398280	ECB1D7	3774 517340	LYUDMILA MAKAROVA	{"phone": "+70303774493"}
0005432398281	A6C35C	5609 729982	TAMARA POPOVA	{"email": "popova.tamara10111957@postgrespro.ru", "phone": "+70344818538"}
0005432398282	A6C35C	4957 447095	MARINA VOROBEVA	{"email": "vorobeva-m1977@postgrespro.ru", "phone": "+70063382705"}
0005432398283	407F03	5741 035293	VASILIY ORLOV	{"email": "orlovv071971@postgrespro.ru", "phone": "+70476162340"}
0005432398284	407F03	8501 390126	NINA ANISIMOVA	{"phone": "+70108518504"}
0005432398285	CC0E1A	2314 089445	IRINA ALEKSEEVA	{"phone": "+70511335710"}
0005432398286	22181A	3728 184643	SERGEY VASILEV	{"phone": "+70603043374"}
0005432398287	C5B27E	4737 491837	MIKHAIL FEDOROV	{"email": "m.fedorov-1977@postgrespro.ru", "phone": "+70645589156"}
0005432398288	C5B27E	5765 070785	LYUDMILA KUZMINA	{"email": "kuzmina-lyudmila.20111970@postgrespro.ru", "phone": "+70233194519"}
0005432398289	C5B27E	4446 053538	ALEKSEY KAZAKOV	{"email": "kazakov.a-09101968@postgrespro.ru", "phone": "+70446422826"}
0005432398290	70F4DA	1668 845029	GALINA VLASOVA	{"email": "galina_vlasova28121972@postgrespro.ru", "phone": "+70405352689"}
0005432398291	886E8F	6970 937772	KRISTINA MIKHAYLOVA	{"email": "kmikhaylova_121971@postgrespro.ru", "phone": "+70005848218"}
0005432398292	CEE4B4	1882 937648	TATYANA SERGEEVA	{"email": "sergeeva.t-25091968@postgrespro.ru", "phone": "+70773539621"}
0005432398293	9BFE5F	2390 660323	VALENTINA SERGEEVA	{"email": "sergeeva-valentina-061976@postgrespro.ru", "phone": "+70967522634"}
0005432398294	1CDAAD	2314 302232	VALENTINA VASILEVA	{"phone": "+70115071598"}
0005432398295	1CDAAD	3752 758866	NATALIYA PAVLOVA	{"phone": "+70435539400"}
0005432398296	4C369B	3514 484585	VALENTINA YUDINA	{"email": "valentina.yudina_1970@postgrespro.ru", "phone": "+70062240629"}
0005432398297	3080CA	9758 354161	ZINAIDA NIKOLAEVA	{"email": "nikolaevaz-29031977@postgrespro.ru", "phone": "+70494822791"}
0005432398298	F68297	8663 427258	NATALYA MIKHAYLOVA	{"email": "nmikhaylova-1963@postgrespro.ru", "phone": "+70078467555"}
0005432398299	F68297	9184 034990	SVETLANA KRASNOVA	{"email": "krasnova-s.1972@postgrespro.ru", "phone": "+70051915024"}
0005432398300	3FA697	5540 803000	SOFIYA BORISOVA	{"phone": "+70931371769"}
0005432398301	68630B	9707 369083	ZINAIDA BORISOVA	{"phone": "+70124990479"}
0005432398302	CFF6BD	0279 209830	MARINA DMITRIEVA	{"phone": "+70931652958"}
0005432398303	CFF6BD	4423 869200	ALEKSEY KRASNOV	{"email": "alekseykrasnov-091971@postgrespro.ru", "phone": "+70316596331"}
0005432398304	0D382F	1981 002742	TAMARA ANDREEVA	{"email": "andreeva-tamara1974@postgrespro.ru", "phone": "+70616833910"}
0005432400056	3DB7B1	5461 580076	PAVEL KONOVALOV	{"phone": "+70729123746"}
0005432400057	3DB7B1	9576 876376	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova_1977@postgrespro.ru", "phone": "+70686167686"}
0005432400058	13BAF1	5536 805986	NIKOLAY ZAYCEV	{"email": "zaycev.nikolay-011972@postgrespro.ru", "phone": "+70912243251"}
0005432400059	13BAF1	6295 316583	NINA KOMAROVA	{"email": "n-komarova_061968@postgrespro.ru", "phone": "+70351536780"}
0005432400060	822191	3773 685464	SHAMIL MEDVEDEV	{"email": "medvedevshamil-1973@postgrespro.ru", "phone": "+70139452743"}
0005432400061	C51420	2430 206134	SERGEY BARANOV	{"email": "s-baranov011971@postgrespro.ru", "phone": "+70571693447"}
0005432400062	B46962	4011 447317	VIKTOR BELOV	{"phone": "+70066394596"}
0005432400063	976BCF	2624 253651	IVAN STEPANOV	{"email": "stepanov.i-27031980@postgrespro.ru", "phone": "+70688185358"}
0005432400064	1E467E	2105 091343	VLADIMIR KOZLOV	{"phone": "+70176546516"}
0005432400065	584B65	9436 953073	YAROSLAV NIKITIN	{"email": "ynikitin.071983@postgrespro.ru", "phone": "+70122199839"}
0005432423625	4471CC	4064 106456	GALINA ZHURAVLEVA	{"phone": "+70283620363"}
0005432400066	9A6691	6660 494414	ALEKSANDR EGOROV	{"email": "aegorov061976@postgrespro.ru", "phone": "+70761815184"}
0005432400067	6F4CA6	6125 473754	ANDREY DMITRIEV	{"phone": "+70536835376"}
0005432400068	6F4CA6	1175 903138	VALENTINA POPOVA	{"email": "v.popova28031973@postgrespro.ru", "phone": "+70178330253"}
0005432400069	AD67D6	0131 511029	MIKHAIL KUZMIN	{"phone": "+70581976898"}
0005432400070	AF5547	5777 354292	ELLA YAKOVLEVA	{"email": "yakovleva-e_14051969@postgrespro.ru", "phone": "+70072822076"}
0005432400071	AF5547	1366 090262	EKATERINA ZOTOVA	{"email": "e.zotova_24021975@postgrespro.ru", "phone": "+70263413278"}
0005432400072	0CD417	5440 324602	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrova-elizaveta_1985@postgrespro.ru", "phone": "+70742489088"}
0005432400073	1A85C9	8219 195085	NIKOLAY CHERNOV	{"phone": "+70059283009"}
0005432400074	335B8D	1015 121308	ANDREY MAKAROV	{"email": "a.makarov-22071971@postgrespro.ru", "phone": "+70883237085"}
0005432400075	166B34	8664 387068	EKATERINA VASILEVA	{"email": "vasileva_ekaterina_061980@postgrespro.ru", "phone": "+70430513273"}
0005432400076	166B34	6860 619959	MAKSIM MIRONOV	{"email": "mmironov-1968@postgrespro.ru", "phone": "+70512534376"}
0005432400077	65DDC8	8161 102361	NADEZHDA ANDREEVA	{"phone": "+70238807887"}
0005432400078	C8823F	3932 014455	ROMAN FEDOROV	{"email": "fedorov.roman091966@postgrespro.ru", "phone": "+70358478377"}
0005432400079	C8823F	8375 385534	INNA SIDOROVA	{"email": "sidorova_inna.20091974@postgrespro.ru", "phone": "+70025188554"}
0005432400080	BA4AED	9833 184826	OLGA KUDRYASHOVA	{"email": "kudryashova-o29021968@postgrespro.ru", "phone": "+70791799745"}
0005432400081	BA4AED	1028 401984	FARIDA ZAYCEVA	{"phone": "+70560432792"}
0005432400082	995A80	3760 947195	ELENA GORBUNOVA	{"email": "gorbunovaelena.1979@postgrespro.ru", "phone": "+70770243511"}
0005432400083	995A80	8518 254014	ALEKSANDR KAZAKOV	{"email": "kazakov.a-22061979@postgrespro.ru", "phone": "+70248321995"}
0005432400084	995A80	5415 023553	YULIYA YAKOVLEVA	{"email": "yakovleva.yuliya25061966@postgrespro.ru", "phone": "+70641448146"}
0005432400085	2D4EF0	4313 923043	DMITRIY NIKITIN	{"phone": "+70078646290"}
0005432400086	93BF78	5030 382286	VLADISLAV POPOV	{"phone": "+70154922147"}
0005432400087	0F8E5D	6850 023060	ANDREY KUZNECOV	{"email": "andrey.kuznecov-101964@postgrespro.ru", "phone": "+70376184960"}
0005432400088	A06693	3814 997250	SVETLANA KARPOVA	{"email": "karpovas_1969@postgrespro.ru", "phone": "+70505893966"}
0005432400089	A06693	0537 583695	DMITRIY DENISOV	{"email": "d.denisov_071969@postgrespro.ru", "phone": "+70890041090"}
0005432400090	A06693	4168 947480	PRASKOVYA EGOROVA	{"email": "p_egorova-051992@postgrespro.ru", "phone": "+70565413903"}
0005432400091	64762F	9285 840354	OKSANA POPOVA	{"email": "o-popova.1962@postgrespro.ru", "phone": "+70781336633"}
0005432400092	11C389	5156 424390	TATYANA CHERNOVA	{"email": "chernova.t-1980@postgrespro.ru", "phone": "+70884150301"}
0005432400093	3A043B	6509 942760	MIKHAIL KUZMIN	{"email": "kuzmin.m-041977@postgrespro.ru", "phone": "+70701764107"}
0005432400094	3A043B	2185 486402	FLYURA KOZLOVA	{"phone": "+70565267413"}
0005432400095	3A043B	9166 337028	ANDREY BELOV	{"phone": "+70644375312"}
0005432400096	152111	3642 769112	NATALYA DANILOVA	{"phone": "+70757165353"}
0005432400097	763A8A	5344 903348	IVAN MOISEEV	{"phone": "+70774453706"}
0005432400098	450B92	3707 287054	EVGENIY GUSEV	{"email": "e-gusev.28121976@postgrespro.ru", "phone": "+70296873909"}
0005432400099	450B92	3826 295733	NADEZHDA FADEEVA	{"phone": "+70563538205"}
0005432400100	ADAE46	3311 494340	TATYANA IVANOVA	{"email": "t.ivanova.1982@postgrespro.ru", "phone": "+70530689452"}
0005432400101	6619D1	1017 006576	ALEKSANDR KOZLOV	{"email": "akozlov_09051969@postgrespro.ru", "phone": "+70959828483"}
0005432400102	85DB65	0388 237015	VLADIMIR IVANOV	{"email": "vivanov_121979@postgrespro.ru", "phone": "+70902750852"}
0005432400103	85DB65	9205 935370	DARYA KUZNECOVA	{"phone": "+70832055902"}
0005432400104	7746EF	6986 589650	STANISLAV KUZMIN	{"phone": "+70656254946"}
0005432400105	404F9D	5783 975563	ALEKSEY ANDREEV	{"email": "alekseyandreev-1960@postgrespro.ru", "phone": "+70413551756"}
0005432400106	404F9D	3461 076570	ELIZAVETA DANILOVA	{"email": "e-danilova_1972@postgrespro.ru", "phone": "+70295060267"}
0005432400107	D4D527	4712 126569	ARTEM BONDARENKO	{"email": "artembondarenko.1975@postgrespro.ru", "phone": "+70546506454"}
0005432400108	555F3F	0235 838763	RAISA YAKOVLEVA	{"email": "r_yakovleva_1978@postgrespro.ru", "phone": "+70494891365"}
0005432400109	10C8B1	3337 616161	NADEZHDA NIKITINA	{"phone": "+70149804832"}
0005432400110	EA3F25	5213 333926	GALINA AFANASEVA	{"email": "afanasevagalina09081967@postgrespro.ru", "phone": "+70818910651"}
0005432400111	A41545	8967 901762	TAMARA SMIRNOVA	{"phone": "+70929610066"}
0005432400112	A41545	2668 783396	ELENA MIKHAYLOVA	{"phone": "+70453735328"}
0005432400113	757EB1	8915 863252	EVGENIY KULIKOV	{"email": "evgeniykulikov-031975@postgrespro.ru", "phone": "+70887639135"}
0005432400114	309F97	0849 484317	ARTEM ALEKSANDROV	{"email": "a_aleksandrov.1977@postgrespro.ru", "phone": "+70227507187"}
0005432400115	FC358C	4611 239174	VALENTINA BORISOVA	{"phone": "+70346187585"}
0005432400116	CD1CE0	4307 086353	ELENA SCHERBAKOVA	{"phone": "+70152582479"}
0005432400117	CBDAC3	7443 920677	MARIYA SEMENOVA	{"phone": "+70893229742"}
0005432400118	FC625C	4904 635108	EKATERINA VASILEVA	{"phone": "+70178517238"}
0005432400119	9073AF	8810 880153	ANATOLIY FROLOV	{"phone": "+70287041881"}
0005432400120	A43232	0006 224622	SVETLANA NAZAROVA	{"phone": "+70728330206"}
0005432400121	A43232	2614 317954	NATALYA KOLESNIKOVA	{"email": "kolesnikova.natalya-16051982@postgrespro.ru", "phone": "+70167724471"}
0005432400122	074EB9	7647 465487	VYACHESLAV SERGEEV	{"phone": "+70210839621"}
0005432400123	DF616C	4869 515600	PAVEL OSIPOV	{"email": "osipov.p_1963@postgrespro.ru", "phone": "+70324638662"}
0005432400124	2B5F4F	6022 341681	YURIY KUZNECOV	{"email": "y.kuznecov.1968@postgrespro.ru", "phone": "+70629136399"}
0005432400125	2B5F4F	9706 107556	SVETLANA TARASOVA	{"email": "tarasova_svetlana.1973@postgrespro.ru", "phone": "+70620223790"}
0005432400126	6E91B1	3908 727985	OLGA OSIPOVA	{"email": "oosipova-101979@postgrespro.ru", "phone": "+70124727334"}
0005432400127	9E40EC	7243 515250	MARIYA BORISOVA	{"email": "borisova.mariya1966@postgrespro.ru", "phone": "+70542273806"}
0005432400128	E4591A	0220 905718	TATYANA SIDOROVA	{"email": "sidorova-tatyana_24121973@postgrespro.ru", "phone": "+70511047683"}
0005432400129	E4591A	4404 856298	MARIYA LEBEDEVA	{"phone": "+70131277114"}
0005432400130	E4591A	3080 489408	OLGA SOKOLOVA	{"phone": "+70456461546"}
0005432400131	672F2D	4260 287350	SERGEY POPOV	{"phone": "+70567160402"}
0005432400132	672F2D	2741 186240	VALENTINA KAZAKOVA	{"email": "v.kazakova-09111974@postgrespro.ru", "phone": "+70541850783"}
0005432400133	4690B7	0400 443977	DANIIL KOROLEV	{"email": "d_korolev_09121967@postgrespro.ru", "phone": "+70538337892"}
0005432400134	4690B7	1429 704116	ELENA KUZNECOVA	{"phone": "+70424752083"}
0005432400135	8D180C	3950 819875	TATYANA BELYAEVA	{"phone": "+70294144653"}
0005432400136	8D180C	6678 432446	MARIYA SEMENOVA	{"email": "semenovamariya.1969@postgrespro.ru", "phone": "+70743517964"}
0005432400137	C2B949	6369 267392	LYUBOV DENISOVA	{"email": "denisova-lyubov-08121966@postgrespro.ru", "phone": "+70014507399"}
0005432400138	E1F7CE	6270 197004	NIKOLAY GUSEV	{"email": "ngusev_30111977@postgrespro.ru", "phone": "+70524199986"}
0005432400139	E1F7CE	9094 009815	NAIL BELOV	{"email": "nailbelov-04121964@postgrespro.ru", "phone": "+70370553386"}
0005432400140	D9078A	5078 444642	ALEKSANDR BARANOV	{"phone": "+70815183097"}
0005432400141	D9078A	1233 136024	NATALIYA KOMAROVA	{"email": "komarova_nataliya-08041978@postgrespro.ru", "phone": "+70308435361"}
0005432400142	BA449A	3011 662477	KRISTINA MAKAROVA	{"phone": "+70123977580"}
0005432400143	E22450	0297 926827	ALEKSANDR KUZNECOV	{"phone": "+70622570978"}
0005432400144	E22450	8749 080471	ZINAIDA KISELEVA	{"phone": "+70147471682"}
0005432400145	E22450	8776 212142	IRINA DAVYDOVA	{"email": "davydova-irina22091968@postgrespro.ru", "phone": "+70917712045"}
0005432400146	BA8E06	9472 435836	SERGEY VOLKOV	{"email": "volkov_sergey.15061968@postgrespro.ru", "phone": "+70179099219"}
0005432400147	26C117	0041 357584	DANILA GRIGOREV	{"email": "danilagrigorev-11051962@postgrespro.ru", "phone": "+70479982293"}
0005432400148	2830D2	9680 247034	MARAT SCHERBAKOV	{"email": "scherbakov_m1972@postgrespro.ru", "phone": "+70292380912"}
0005432400149	2830D2	0116 567464	ELENA KOMAROVA	{"phone": "+70563932654"}
0005432400150	BB5F7B	5467 747623	DINA KOROLEVA	{"phone": "+70163428650"}
0005432400151	BB5F7B	8547 572733	ANDREY MAKSIMOV	{"phone": "+70316160480"}
0005432400152	BB5F7B	7927 432436	ELENA KULIKOVA	{"email": "e_kulikova-1966@postgrespro.ru", "phone": "+70424972013"}
0005432400153	AB3028	8767 083412	TATYANA EGOROVA	{"phone": "+70435783223"}
0005432400154	B7BBAE	4615 656109	AYRAT IVANOV	{"phone": "+70246293363"}
0005432400155	B7BBAE	1637 194958	IRINA TARASOVA	{"email": "tarasova-irina.121974@postgrespro.ru", "phone": "+70121973807"}
0005432400156	A9F499	0990 782011	MARINA OVCHINNIKOVA	{"phone": "+70800920247"}
0005432400157	79D922	7584 583106	PAVEL RODIONOV	{"email": "pavel_rodionov-31071971@postgrespro.ru", "phone": "+70073519909"}
0005432400158	27A7B8	1927 205179	ELENA VLASOVA	{"phone": "+70800621232"}
0005432400159	0798CE	0373 816284	LYUBOV KOZLOVA	{"email": "kozlova-l.10081969@postgrespro.ru", "phone": "+70810934414"}
0005432400160	8D2704	1916 299510	ELENA POPOVA	{"phone": "+70811797156"}
0005432400161	8D2704	3177 996210	IRINA GERASIMOVA	{"email": "irina_gerasimova071969@postgrespro.ru", "phone": "+70519411258"}
0005432400162	D52E59	0473 215141	VIKTOR SAVELEV	{"phone": "+70997357519"}
0005432400163	495E7D	4340 000538	ANTON FILIPPOV	{"email": "anton_filippov_1966@postgrespro.ru", "phone": "+70866475037"}
0005432400164	495E7D	6090 483850	TATYANA GAVRILOVA	{"phone": "+70967541814"}
0005432400165	FC9383	7278 434971	OLGA ROMANOVA	{"phone": "+70638210774"}
0005432400166	FC9383	2931 337522	TATYANA ZHURAVLEVA	{"email": "t_zhuravleva_16061981@postgrespro.ru", "phone": "+70822202030"}
0005432400167	033510	0379 286147	NATALYA MARTYNOVA	{"phone": "+70598013783"}
0005432400168	7B8D85	5701 480220	SERGEY ALEKSANDROV	{"phone": "+70174787612"}
0005432400169	438B3E	3085 205239	BORIS STEPANOV	{"email": "stepanov_boris27071970@postgrespro.ru", "phone": "+70445612109"}
0005432400170	1B93F9	9429 614900	TATYANA POPOVA	{"email": "t-popova_1974@postgrespro.ru", "phone": "+70748192391"}
0005432400171	708BCC	8843 395434	ANTONINA NIKITINA	{"phone": "+70055231206"}
0005432400172	708BCC	0100 083297	RUSLAN MOISEEV	{"phone": "+70154227056"}
0005432400173	9C28A1	6322 842208	VIKTOR MOISEEV	{"phone": "+70576367876"}
0005432400174	484F5C	9666 614243	VADIM SERGEEV	{"phone": "+70150119701"}
0005432400175	484F5C	3634 318361	KONSTANTIN GUSEV	{"phone": "+70151540268"}
0005432400176	FF82B7	5156 328795	NADEZHDA NIKITINA	{"email": "nadezhda_nikitina08091980@postgrespro.ru", "phone": "+70110660669"}
0005432400177	151A26	3857 735305	ANNA SOLOVEVA	{"phone": "+70452602933"}
0005432400178	151A26	9223 503719	VIKTOR SOKOLOV	{"phone": "+70830000722"}
0005432400179	B7A17E	8708 227375	GENNADIY KUZMIN	{"phone": "+70511250809"}
0005432400180	4E43A9	1858 845878	OLGA MIKHAYLOVA	{"email": "olgamikhaylova.1967@postgrespro.ru", "phone": "+70742456935"}
0005432400181	64055A	7912 610541	MARINA MEDVEDEVA	{"email": "medvedeva_marina.1973@postgrespro.ru", "phone": "+70480152104"}
0005432400182	64055A	7055 514435	LIDIYA IVANOVA	{"email": "ivanova.lidiya_051966@postgrespro.ru", "phone": "+70182826619"}
0005432400183	9F1837	5987 242768	RAILYA IVANOVA	{"phone": "+70357951969"}
0005432400184	07B340	1230 310478	EKATERINA MATVEEVA	{"email": "matveeva.ekaterina1971@postgrespro.ru", "phone": "+70975407373"}
0005432400185	C51110	3445 968205	NATALYA FOMINA	{"email": "nfomina31071971@postgrespro.ru", "phone": "+70971337626"}
0005432400186	37DC2D	6295 686330	EVGENIYA GAVRILOVA	{"email": "gavrilova.evgeniya_1970@postgrespro.ru", "phone": "+70833158133"}
0005432400187	147159	8272 337465	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr-021975@postgrespro.ru", "phone": "+70999578257"}
0005432400188	CB5DDD	4400 722381	DMITRIY ZHURAVLEV	{"email": "zhuravlev_d-111977@postgrespro.ru", "phone": "+70094463404"}
0005432400189	9B9C5B	8773 303306	SVETLANA ILINA	{"email": "s-ilina-25081980@postgrespro.ru", "phone": "+70997582657"}
0005432400190	FC34CB	2763 427703	KLAVDIYA MATVEEVA	{"email": "matveeva.klavdiya_06101966@postgrespro.ru", "phone": "+70442660781"}
0005432400191	FC34CB	8849 252560	RUSLAN ROMANOV	{"phone": "+70569915062"}
0005432400192	7F4092	4502 161463	ALENA GAVRILOVA	{"phone": "+70856458397"}
0005432400193	7F4092	2906 279553	DMITRIY ROMANOV	{"email": "romanov.dmitriy-18101962@postgrespro.ru", "phone": "+70581376893"}
0005432400194	8E4D3B	0743 081854	TAMARA EFREMOVA	{"email": "efremova.t15061962@postgrespro.ru", "phone": "+70690820091"}
0005432400195	CA9BFD	3186 407619	YURIY MATVEEV	{"email": "matveevyuriy-1958@postgrespro.ru", "phone": "+70110654344"}
0005432400196	CA9BFD	1332 825238	ANATOLIY MOISEEV	{"phone": "+70751017359"}
0005432400197	C91AE1	6268 748032	DARYA ARKHIPOVA	{"email": "arkhipova-darya.05111975@postgrespro.ru", "phone": "+70212227940"}
0005432400198	C91AE1	8057 799121	ANASTASIYA NIKIFOROVA	{"email": "a-nikiforova-1970@postgrespro.ru", "phone": "+70057631646"}
0005432400199	4D9020	8362 287568	ANDREY FEDOROV	{"phone": "+70667871268"}
0005432400200	4D9020	8956 740849	LIDIYA DANILOVA	{"email": "l_danilova.041980@postgrespro.ru", "phone": "+70674333402"}
0005432400201	74D9D6	0746 562036	VIKTOR SOROKIN	{"phone": "+70941166941"}
0005432400202	991515	2575 382205	ANASTASIYA KUZNECOVA	{"phone": "+70167971112"}
0005432400203	F3A334	9541 603529	ANNA LEBEDEVA	{"email": "anna-lebedeva-05051977@postgrespro.ru", "phone": "+70001400600"}
0005432400204	F9B772	0491 229962	ANNA SERGEEVA	{"phone": "+70164008126"}
0005432400205	D5E5E3	4731 263536	MARAT KUZNECOV	{"phone": "+70052754661"}
0005432400206	D5E5E3	9100 906865	EVGENIY SEMENOV	{"email": "semenov_e_031959@postgrespro.ru", "phone": "+70634915464"}
0005432400207	8BBBDA	3531 877138	FEDOR GORBUNOV	{"phone": "+70938521445"}
0005432400208	8BBBDA	4924 153560	ELENA KUZNECOVA	{"phone": "+70387981638"}
0005432400209	221E8E	7119 094736	TATYANA ARKHIPOVA	{"email": "tatyanaarkhipova-1960@postgrespro.ru", "phone": "+70634347305"}
0005432400210	6FAE03	2654 784330	NIKOLAY POPOV	{"phone": "+70612939592"}
0005432400211	95D88E	3852 779085	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana-1985@postgrespro.ru", "phone": "+70437053306"}
0005432400212	95D88E	7082 872551	NADEZHDA STEPANOVA	{"phone": "+70157464987"}
0005432400213	9A526A	4432 915134	ALEKSANDR GUSEV	{"phone": "+70911178113"}
0005432400214	E9A3B1	5467 269587	PETR VLASOV	{"phone": "+70185977171"}
0005432400215	E9A3B1	3786 272533	TATYANA TARASOVA	{"email": "tarasovatatyana-1969@postgrespro.ru", "phone": "+70867058966"}
0005432400216	037E69	5028 290212	VLADISLAV KAZAKOV	{"email": "kazakov.v.14051974@postgrespro.ru", "phone": "+70157196909"}
0005432400217	84838E	1062 218003	VALENTINA EGOROVA	{"email": "vegorova22061970@postgrespro.ru", "phone": "+70881269896"}
0005432400218	84838E	6850 064458	NIKOLAY ROMANOV	{"email": "romanov.n_061982@postgrespro.ru", "phone": "+70225764775"}
0005432400219	7D1409	0174 071425	IVAN EGOROV	{"phone": "+70075272798"}
0005432400220	71DB75	0229 302830	VITALIY KUZNECOV	{"email": "kuznecov_vitaliy.021979@postgrespro.ru", "phone": "+70361733158"}
0005432400221	71DB75	4741 699850	VLADIMIR SERGEEV	{"email": "sergeevvladimir1977@postgrespro.ru", "phone": "+70753740063"}
0005432400222	E7D243	1439 023085	ANNA IVANOVA	{"email": "ivanova_anna17051977@postgrespro.ru", "phone": "+70008860006"}
0005432400223	BBC0F1	3179 529344	LIDIYA NOVIKOVA	{"email": "lidiyanovikova-29041978@postgrespro.ru", "phone": "+70737959595"}
0005432423604	BD2E55	7441 304505	SERGEY VOROBEV	{"email": "vorobevs_111976@postgrespro.ru", "phone": "+70917511110"}
0005432423605	6CDEA5	7688 070175	ALEKSANDR BORISOV	{"phone": "+70462301230"}
0005432423606	C2FAD4	6158 418112	STEPAN SEMENOV	{"phone": "+70177709246"}
0005432423607	AE3A63	9202 133357	VITALIY SCHERBAKOV	{"email": "scherbakov_vitaliy1967@postgrespro.ru", "phone": "+70694613785"}
0005432423608	A20FC2	9841 263659	NIKOLAY POPOV	{"phone": "+70464072920"}
0005432423609	ADD726	0188 910696	YULIYA PAVLOVA	{"phone": "+70927393640"}
0005432423610	DE3A8C	1507 045500	VLADIMIR KOZLOV	{"email": "vkozlov_101977@postgrespro.ru", "phone": "+70419710412"}
0005432423611	0EE09B	5353 747738	GEORGIY FEDOROV	{"email": "fedorov.georgiy.1975@postgrespro.ru", "phone": "+70009320044"}
0005432423612	29F3B5	2579 722668	SERGEY KISELEV	{"email": "s.kiselev_1968@postgrespro.ru", "phone": "+70869644078"}
0005432423613	2E3B87	1191 133744	POLINA KISELEVA	{"email": "pkiseleva.1969@postgrespro.ru", "phone": "+70186815395"}
0005432423614	2E3B87	6176 697784	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr101974@postgrespro.ru", "phone": "+70469259029"}
0005432423615	76D3C7	8992 334350	VITALIY SEMENOV	{"phone": "+70203541028"}
0005432423616	0CB7FA	2420 146432	PELAGEYA ZHUKOVA	{"email": "pzhukova29041968@postgrespro.ru", "phone": "+70697876226"}
0005432423617	9D0138	5404 600119	KSENIYA GERASIMOVA	{"phone": "+70837026263"}
0005432423618	173EF7	2984 090832	VLADIMIR GAVRILOV	{"phone": "+70822609928"}
0005432423619	FBE8E8	0875 884148	SERGEY GORBUNOV	{"email": "gorbunovsergey_15041970@postgrespro.ru", "phone": "+70447858941"}
0005432423620	FBE8E8	3575 142992	SVETLANA BELOVA	{"phone": "+70889616286"}
0005432423621	A338D3	0650 974025	NATALYA BARANOVA	{"phone": "+70682819998"}
0005432423622	E99CED	2940 528173	ALEKSANDR ILIN	{"phone": "+70797614399"}
0005432423623	E99CED	8230 098818	VERA PAVLOVA	{"email": "vera-pavlova_021970@postgrespro.ru", "phone": "+70741735922"}
0005432423624	2DF802	1498 942951	NIKOLAY BARANOV	{"email": "baranov-n-1954@postgrespro.ru", "phone": "+70335301991"}
0005432423626	4471CC	7331 946900	KRISTINA NOVIKOVA	{"phone": "+70337517891"}
0005432423627	F58C9A	9654 560842	ALEKSANDR AFANASEV	{"email": "afanasev_a-1966@postgrespro.ru", "phone": "+70384474876"}
0005432423628	AE2782	2361 427186	VLADIMIR MOISEEV	{"email": "v_moiseev071974@postgrespro.ru", "phone": "+70415214005"}
0005432423629	AEB0E9	8282 181972	VLADIMIR TARASOV	{"phone": "+70211833665"}
0005432423630	AEB0E9	3954 059765	LIDIYA SOKOLOVA	{"phone": "+70012742162"}
0005432423631	4A1FD7	7390 594765	MARIYA TIMOFEEVA	{"email": "mtimofeeva071973@postgrespro.ru", "phone": "+70889867043"}
0005432423632	4A1FD7	6088 475059	ANDREY OSIPOV	{"email": "osipov_a_14081974@postgrespro.ru", "phone": "+70402788867"}
0005432423633	192657	0806 733820	NIKOLAY ORLOV	{"email": "orlov-n031975@postgrespro.ru", "phone": "+70995671312"}
0005432423634	659D11	4144 788676	VLADISLAV KUZNECOV	{"email": "vladislav-kuznecov1983@postgrespro.ru", "phone": "+70197818808"}
0005432423635	1EB0AC	1906 905753	NINA MEDVEDEVA	{"phone": "+70026320627"}
0005432423636	8335A0	2599 409809	DANILA BARANOV	{"phone": "+70470022097"}
0005432423637	C8C0AD	7620 235761	ALEKSEY MELNIKOV	{"email": "a.melnikov.061967@postgrespro.ru", "phone": "+70769264673"}
0005432423638	23F0DD	3555 061793	ANTONINA AKIMOVA	{"email": "antonina_akimova.011962@postgrespro.ru", "phone": "+70652195946"}
0005432423639	23F0DD	6975 025434	ALEKSANDR SEMENOV	{"phone": "+70266710101"}
0005432423640	6A1F71	6517 606273	RAFIK DENISOV	{"email": "denisov-r_01091962@postgrespro.ru", "phone": "+70512047838"}
0005432423641	C07282	3004 497312	GALINA SOKOLOVA	{"phone": "+70473066888"}
0005432423642	2E771E	3208 216062	VIKTOR PAVLOV	{"phone": "+70019446443"}
0005432423643	3F9110	7960 442175	ELENA IVANOVA	{"phone": "+70752482226"}
0005432423644	41FD51	3913 328266	YURIY PETROV	{"phone": "+70117696835"}
0005432423645	E617A6	7576 616494	NADEZHDA EGOROVA	{"email": "egorova-n_1971@postgrespro.ru", "phone": "+70540270429"}
0005432423646	E617A6	2648 933755	SERGEY EGOROV	{"phone": "+70036722957"}
0005432423647	457AA2	9268 364839	NADEZHDA ANTONOVA	{"phone": "+70537592933"}
0005432423648	F0A8CC	6640 931226	MIKHAIL SEMENOV	{"phone": "+70526982796"}
0005432423649	D8966C	5222 713594	YULIYA SOROKINA	{"email": "y-sorokina.12111974@postgrespro.ru", "phone": "+70926538078"}
0005432423650	D2E283	8936 242357	LILIYA VOLKOVA	{"email": "volkova_liliya_1973@postgrespro.ru", "phone": "+70320755903"}
0005432423651	E4DCA2	9629 360431	OLGA MATVEEVA	{"phone": "+70837932922"}
0005432423652	94C504	4860 616455	LYUBOV EFIMOVA	{"email": "efimova.lyubov-06041977@postgrespro.ru", "phone": "+70595445872"}
0005432423653	C4A1DF	0604 902031	YURIY SHEVCHENKO	{"email": "shevchenko.yuriy-12121973@postgrespro.ru", "phone": "+70651013468"}
0005432423654	D07F52	8780 874227	MARIYA ABRAMOVA	{"phone": "+70382006822"}
0005432423655	78B2F7	0956 889631	PAVEL GUSEV	{"phone": "+70935523269"}
0005432423656	78B2F7	9984 284866	OLESYA STEPANOVA	{"phone": "+70188720028"}
0005432423657	78B2F7	7379 987096	ALEKSANDR SAVELEV	{"phone": "+70857623246"}
0005432423658	CB96D2	6009 888637	MARIYA KOROLEVA	{"phone": "+70346175510"}
0005432423659	CB96D2	8017 882862	ANDREY SIDOROV	{"email": "andrey_sidorov.14011978@postgrespro.ru", "phone": "+70745617881"}
0005432423660	636211	4885 310742	NATALYA DANILOVA	{"email": "natalya_danilova1969@postgrespro.ru", "phone": "+70858153088"}
0005432423661	F09CB7	4769 197261	NIKOLAY POPOV	{"email": "popovnikolay.12031973@postgrespro.ru", "phone": "+70393823722"}
0005432423662	B151CE	9644 931773	IVAN STEPANOV	{"email": "ivan_stepanov_1980@postgrespro.ru", "phone": "+70539089585"}
0005432423663	B151CE	6394 997870	EKATERINA MAKSIMOVA	{"email": "maksimova_ekaterina021964@postgrespro.ru", "phone": "+70739607560"}
0005432423664	7699C3	3957 933015	VALENTINA VOLKOVA	{"email": "vvolkova1983@postgrespro.ru", "phone": "+70994933658"}
0005432423665	7699C3	9237 614682	ALEKSEY KUZMIN	{"email": "a.kuzmin121972@postgrespro.ru", "phone": "+70727051132"}
0005432423666	23193E	5720 105037	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov_041976@postgrespro.ru", "phone": "+70709346992"}
0005432423667	23193E	7525 947353	LARISA YUDINA	{"phone": "+70029554097"}
0005432423668	D0C015	9451 601753	NIKOLAY MIKHAYLOV	{"phone": "+70665648512"}
0005432423669	D0C015	0848 821220	MARIYA KAZAKOVA	{"phone": "+70318780336"}
0005432423670	3445FF	5126 563251	ALEKSEY NOVIKOV	{"email": "a_novikov-26051973@postgrespro.ru", "phone": "+70817192581"}
0005432423671	6A132E	2023 079929	TAMARA MAKAROVA	{"phone": "+70633044404"}
0005432423672	DAB3D8	5372 980667	ALEKSEY KISELEV	{"email": "kiselev-a.021973@postgrespro.ru", "phone": "+70210671323"}
0005432423673	E9437C	6027 932491	ELENA MATVEEVA	{"email": "e_matveeva_06071984@postgrespro.ru", "phone": "+70802223699"}
0005432423674	9B34C6	0851 788504	EKATERINA TITOVA	{"email": "ekaterina-titova101974@postgrespro.ru", "phone": "+70257034213"}
0005432423675	9B34C6	5876 096399	ALEVTINA KOROLEVA	{"email": "alevtina_koroleva_1980@postgrespro.ru", "phone": "+70498700504"}
0005432423676	31BBF7	1023 479357	GALINA GAVRILOVA	{"email": "gavrilovagalina-02011972@postgrespro.ru", "phone": "+70797048755"}
0005432423677	F41DE2	2461 524863	ALEKSEY MEDVEDEV	{"email": "medvedevaleksey1969@postgrespro.ru", "phone": "+70723140512"}
0005432423678	032231	0499 398855	NAIL TIKHONOV	{"phone": "+70297959785"}
0005432423679	032231	5161 867166	EKATERINA PAVLOVA	{"email": "pavlova.e-06031977@postgrespro.ru", "phone": "+70018464182"}
0005432423680	1661BC	5975 914629	MARIYA VASILEVA	{"phone": "+70935034458"}
0005432423681	1661BC	9942 805583	TATYANA ALEKSEEVA	{"phone": "+70575952524"}
0005432423682	66FE13	6782 696974	TAMARA VOROBEVA	{"email": "t.vorobeva.051967@postgrespro.ru", "phone": "+70943914867"}
0005432423683	DCFB7A	1560 697218	NINA ZAYCEVA	{"phone": "+70100710391"}
0005432423684	DCFB7A	2746 138403	VIKTORIYA AFANASEVA	{"email": "afanaseva_viktoriya.04061985@postgrespro.ru", "phone": "+70745912163"}
0005432424107	AB0363	2477 226165	MARIYA ROMANOVA	{"phone": "+70856429669"}
0005432423685	26B333	3358 616166	ANDREY MATVEEV	{"email": "matveev.andrey101978@postgrespro.ru", "phone": "+70916588930"}
0005432423686	667663	4346 163984	ALEKSANDRA ORLOVA	{"email": "orlova.a1971@postgrespro.ru", "phone": "+70895347219"}
0005432423687	96E5A3	2269 139707	ANDREY SERGEEV	{"phone": "+70804906257"}
0005432423688	96E5A3	7888 362442	DMITRIY ZAYCEV	{"email": "zaycevd_29091978@postgrespro.ru", "phone": "+70069027228"}
0005432423689	4DE10C	2033 175198	ALEKSEY FROLOV	{"phone": "+70603167198"}
0005432423690	B04D2E	9482 214264	NATALYA KOROLEVA	{"phone": "+70693015466"}
0005432423691	C91A20	4399 562125	VASILIY STEPANOV	{"phone": "+70605894852"}
0005432423692	BB5A9F	2389 131503	OLGA POPOVA	{"email": "o_popova-1980@postgrespro.ru", "phone": "+70924476296"}
0005432423693	BB5A9F	8120 632592	IGOR ZAYCEV	{"phone": "+70828035727"}
0005432423694	8DA1BB	0253 374742	ALEKSANDR EGOROV	{"phone": "+70071084630"}
0005432423695	8DA1BB	1659 886203	DANIYA DENISOVA	{"email": "denisova_daniya_04021954@postgrespro.ru", "phone": "+70250443894"}
0005432423696	9E1EF6	1768 304709	GALINA MEDVEDEVA	{"phone": "+70502812156"}
0005432423697	F2502E	4640 471514	VITALIY GUSEV	{"phone": "+70036308694"}
0005432423698	50A7D8	6743 074615	RUSLAN BORISOV	{"phone": "+70438665697"}
0005432423699	50A7D8	1639 682401	NATALYA PAVLOVA	{"phone": "+70329602615"}
0005432423700	625276	9253 761034	NATALYA FILIPPOVA	{"phone": "+70112355729"}
0005432423701	625276	4396 755523	TAMARA CHERNOVA	{"phone": "+70087060288"}
0005432423702	A4EEB4	0006 153930	ELENA LOGINOVA	{"email": "loginova-e1974@postgrespro.ru", "phone": "+70992234628"}
0005432423703	A4EEB4	0535 322400	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey.061981@postgrespro.ru", "phone": "+70903585433"}
0005432423704	DBF4C1	0493 456958	DARYA EGOROVA	{"email": "darya-egorova-1970@postgrespro.ru", "phone": "+70452403807"}
0005432423705	64F5A4	1144 917519	VALERIYA SMIRNOVA	{"email": "valeriya_smirnova07071966@postgrespro.ru", "phone": "+70860171958"}
0005432423706	F99ACF	6966 410758	IGOR BELOV	{"phone": "+70367745842"}
0005432423707	89056E	6978 630013	KIRILL STEPANOV	{"email": "k-stepanov.12091983@postgrespro.ru", "phone": "+70365947104"}
0005432423708	E8BB28	6077 101615	SERGEY OSIPOV	{"email": "osipovsergey.03091970@postgrespro.ru", "phone": "+70567133965"}
0005432423709	106CB4	9664 290685	SERGEY FILIPPOV	{"phone": "+70575812234"}
0005432423710	24D754	8983 320641	SERGEY BARANOV	{"email": "sbaranov101961@postgrespro.ru", "phone": "+70918274610"}
0005432423711	DB0FE1	4597 589381	SERGEY SOKOLOV	{"email": "s.sokolov-051963@postgrespro.ru", "phone": "+70600717316"}
0005432423712	DB0FE1	4138 315713	LYUDMILA AKIMOVA	{"email": "lyudmilaakimova.01111967@postgrespro.ru", "phone": "+70924641859"}
0005432423713	DB0FE1	2818 627799	NIKOLAY KUZMIN	{"phone": "+70671160877"}
0005432423714	D45D8E	9100 992592	ALEKSANDR ANDREEV	{"email": "aleksandrandreev.1977@postgrespro.ru", "phone": "+70893887838"}
0005432423715	2768F9	0393 874447	NATALYA VOROBEVA	{"phone": "+70184112131"}
0005432423716	4119A9	6403 905877	SERGEY NIKOLAEV	{"email": "nikolaev-s031974@postgrespro.ru", "phone": "+70516113384"}
0005432423717	71466A	6299 371104	ALEKSEY PAVLOV	{"phone": "+70987954053"}
0005432423718	DD6C98	7125 376023	SAMVEL ZAKHAROV	{"phone": "+70636150729"}
0005432423719	6E1CD0	1970 177783	OLGA MIKHAYLOVA	{"phone": "+70893698281"}
0005432423720	6E1CD0	2872 645571	YURIY VOLKOV	{"phone": "+70635912579"}
0005432423721	5209B2	4308 309625	VERA GUSEVA	{"email": "vguseva.1973@postgrespro.ru", "phone": "+70463130821"}
0005432423722	86BCF8	7097 597650	ELENA KULIKOVA	{"phone": "+70813549423"}
0005432423723	86BCF8	1413 980895	SVETLANA MAKAROVA	{"email": "smakarova.1976@postgrespro.ru", "phone": "+70846390663"}
0005432423724	86BCF8	2604 429254	YULIYA SEMENOVA	{"phone": "+70425055322"}
0005432423725	40DE1B	0740 023952	VALERIY VASILEV	{"email": "vasilevvaleriy.1971@postgrespro.ru", "phone": "+70618002106"}
0005432423726	34119F	8894 479817	MARINA SOROKINA	{"email": "sorokina-m011975@postgrespro.ru", "phone": "+70045535457"}
0005432423727	1DFBC7	7799 488788	NIKOLAY IVANOV	{"phone": "+70412671321"}
0005432423728	1DFBC7	1696 291171	NINA DENISOVA	{"phone": "+70005496172"}
0005432423729	1A6311	7216 799470	IRINA NIKOLAEVA	{"email": "i-nikolaeva04121970@postgrespro.ru", "phone": "+70363452221"}
0005432423730	1A6311	9789 033909	NIKOLAY ALEKSEEV	{"phone": "+70879655882"}
0005432423731	654AB5	6623 308770	ALEKSEY ILIN	{"email": "aleksey-ilin_041965@postgrespro.ru", "phone": "+70864529176"}
0005432423732	07645B	9351 050303	IRINA MAKAROVA	{"email": "makarovairina_1962@postgrespro.ru", "phone": "+70465434948"}
0005432423733	07645B	1091 985332	ANDREY BORISOV	{"email": "a_borisov061976@postgrespro.ru", "phone": "+70324326041"}
0005432423734	480572	6176 744852	ALBERT KARPOV	{"phone": "+70805033081"}
0005432423735	F6D2CF	6332 442371	MARTA STEPANOVA	{"email": "stepanovamarta-031966@postgrespro.ru", "phone": "+70446022388"}
0005432423736	3541CD	7015 800483	VALENTINA MEDVEDEVA	{"email": "valentina-medvedeva1976@postgrespro.ru", "phone": "+70876631486"}
0005432423737	3541CD	8280 868915	ARTEM AFANASEV	{"email": "artemafanasev_15101985@postgrespro.ru", "phone": "+70236879974"}
0005432423738	3541CD	9330 151197	VALERIY KOROLEV	{"phone": "+70540813330"}
0005432423739	1CD2DC	3123 979564	LYUDMILA OVCHINNIKOVA	{"phone": "+70297737286"}
0005432423740	195218	6520 154425	OLEG KUDRYASHOV	{"email": "kudryashov.oleg_081966@postgrespro.ru", "phone": "+70208968318"}
0005432423741	195218	4523 665037	GALINA KUZNECOVA	{"email": "kuznecova-galina.1964@postgrespro.ru", "phone": "+70619418039"}
0005432423742	139925	6952 853077	SVETLANA EGOROVA	{"email": "egorova.svetlana.1971@postgrespro.ru", "phone": "+70322171688"}
0005432423743	98522B	5082 845750	IRINA SIDOROVA	{"email": "sidorova.irina-1968@postgrespro.ru", "phone": "+70581935233"}
0005432423744	98522B	4633 370924	NIKOLAY GAVRILOV	{"phone": "+70670072174"}
0005432424108	AB0363	5496 670699	ALEKSANDR ZHUKOV	{"phone": "+70807522750"}
0005432423745	F6804B	0770 021548	EVGENIY ANTONOV	{"email": "evgeniyantonov1965@postgrespro.ru", "phone": "+70466391531"}
0005432423746	F6804B	4619 253203	TATYANA VOLKOVA	{"email": "volkova_tatyana.02061960@postgrespro.ru", "phone": "+70008052492"}
0005432423747	93BEFA	9108 340881	VLADIMIR ABRAMOV	{"email": "abramovvladimir_19041969@postgrespro.ru", "phone": "+70262180244"}
0005432423748	33071F	7388 524736	VIKTORIYA KUZNECOVA	{"email": "viktoriya-kuznecova1970@postgrespro.ru", "phone": "+70062154217"}
0005432423749	0D88BF	2025 230992	SVETLANA IVANOVA	{"phone": "+70329511779"}
0005432423750	118027	5405 100337	NIKITA SERGEEV	{"phone": "+70829550977"}
0005432423807	3196C0	0048 315403	EVGENIY SCHERBAKOV	{"phone": "+70171532952"}
0005432423751	118027	6817 032661	VIKTORIYA ROMANOVA	{"email": "viktoriya_romanova_17101971@postgrespro.ru", "phone": "+70844326932"}
0005432423752	118027	9680 702793	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr_041988@postgrespro.ru", "phone": "+70793697852"}
0005432423753	45DFF7	1912 156329	FEDOR SEMENOV	{"phone": "+70479262374"}
0005432423754	31BFCB	5887 890886	MIKHAIL KISELEV	{"phone": "+70381612674"}
0005432423755	ACC507	7638 539728	REGINA ROMANOVA	{"phone": "+70915763733"}
0005432423756	944FC8	9573 240071	ALEVTINA SEMENOVA	{"phone": "+70282593591"}
0005432423757	944FC8	1160 032399	LYUDMILA POPOVA	{"phone": "+70346412138"}
0005432423758	E15848	8812 992525	TATYANA FOMINA	{"phone": "+70717338705"}
0005432423759	E15848	0847 936387	VALERIY IVANOV	{"email": "valeriy_ivanov1982@postgrespro.ru", "phone": "+70863256739"}
0005432423760	BA1AE5	7045 529261	RAFAIL ANDREEV	{"email": "andreev_rafail.11121978@postgrespro.ru", "phone": "+70181500470"}
0005432423761	BA1AE5	2897 677609	SERGEY IVANOV	{"email": "ivanov_s.1960@postgrespro.ru", "phone": "+70597036892"}
0005432423762	73CF9D	7717 647618	OLEG FILIPPOV	{"phone": "+70232120503"}
0005432423763	AA609C	4856 815957	OLGA MAKAROVA	{"phone": "+70118109162"}
0005432423764	011C0F	5905 761699	YULIYA ROMANOVA	{"email": "romanova_yuliya_061976@postgrespro.ru", "phone": "+70245679763"}
0005432423765	6A3302	5978 336378	ANNA VOLKOVA	{"phone": "+70239984261"}
0005432423766	6A3302	5409 157485	RUSLAN KOZLOV	{"email": "r.kozlov031960@postgrespro.ru", "phone": "+70397079639"}
0005432423767	85C05C	0426 202625	NIKOLAY PAVLOV	{"phone": "+70204318730"}
0005432423768	85C05C	9026 400462	OLGA KOZLOVA	{"email": "okozlova-1968@postgrespro.ru", "phone": "+70626484177"}
0005432423769	146A77	2040 431736	TIMUR ZAKHAROV	{"phone": "+70740351578"}
0005432423770	49AE56	2553 988105	KONSTANTIN DENISOV	{"email": "konstantin.denisov.111974@postgrespro.ru", "phone": "+70202302521"}
0005432423771	F9CF5A	5546 702278	STEPAN PAVLOV	{"email": "pavlov-stepan_041970@postgrespro.ru", "phone": "+70668789476"}
0005432423772	6C81B2	7398 542574	SERGEY ZAKHAROV	{"phone": "+70657329501"}
0005432423773	973877	1022 678701	OLESYA TITOVA	{"phone": "+70698136179"}
0005432423774	973877	4255 238353	OLEG SEMENOV	{"email": "semenovo.051972@postgrespro.ru", "phone": "+70359250102"}
0005432423775	886A7E	8874 595537	SABINA SMIRNOVA	{"phone": "+70454629933"}
0005432423776	886A7E	2675 294627	MARIANNA IVANOVA	{"email": "ivanovamarianna.021972@postgrespro.ru", "phone": "+70582053829"}
0005432423777	C02C12	8160 951652	VLADIMIR MEDVEDEV	{"phone": "+70819237517"}
0005432423778	C02C12	2928 367803	NINA EFREMOVA	{"email": "efremova-n.101966@postgrespro.ru", "phone": "+70973574217"}
0005432423779	7F6F1E	5437 653901	ANDREY NAUMOV	{"email": "a-naumov-121975@postgrespro.ru", "phone": "+70798319144"}
0005432423780	1D040A	8833 130196	SERGEY ZAYCEV	{"phone": "+70838203528"}
0005432423781	1D040A	4731 299387	OLGA POPOVA	{"phone": "+70399430464"}
0005432423782	7F3EEC	2172 432242	ELINA SMIRNOVA	{"email": "elina_smirnova1963@postgrespro.ru", "phone": "+70937242092"}
0005432423783	74B8BA	8295 861220	ALEKSEY DENISOV	{"phone": "+70719706370"}
0005432423784	74B8BA	6492 645541	GENNADIY NOVIKOV	{"email": "g.novikov_101981@postgrespro.ru", "phone": "+70277040807"}
0005432423785	AA61CC	0347 120594	SHAVKAT VOLKOV	{"email": "shavkat_volkov-041989@postgrespro.ru", "phone": "+70598416926"}
0005432423786	AA61CC	9741 161984	SEMEN ABRAMOV	{"phone": "+70513351203"}
0005432423787	A6CD18	8601 147434	MARIYA PAVLOVA	{"phone": "+70424683633"}
0005432423788	53367E	9611 716347	ALEKSANDRA SERGEEVA	{"phone": "+70017975649"}
0005432423789	29F6D0	9624 904073	ANNA SCHERBAKOVA	{"email": "annascherbakova_101967@postgrespro.ru", "phone": "+70344994081"}
0005432423790	29F6D0	3779 605573	SERGEY KAZAKOV	{"email": "kazakovs_121970@postgrespro.ru", "phone": "+70804827657"}
0005432423791	6FA770	2021 995713	TATYANA ORLOVA	{"email": "torlova1969@postgrespro.ru", "phone": "+70939559471"}
0005432423792	E10DBC	7245 677906	MIKHAIL VOROBEV	{"email": "m_vorobev_021973@postgrespro.ru", "phone": "+70292564583"}
0005432423793	35940F	3110 990071	ELENA KOROLEVA	{"phone": "+70788639369"}
0005432423794	35940F	4541 206568	MIKHAIL SOLOVEV	{"email": "solovev.mikhail1978@postgrespro.ru", "phone": "+70263605774"}
0005432423795	632979	5747 985162	VIKTOR KISELEV	{"phone": "+70490208007"}
0005432423796	481F80	0893 067497	NIKOLAY FROLOV	{"phone": "+70021823436"}
0005432423797	147924	6381 346128	DENIS AFANASEV	{"phone": "+70163243962"}
0005432423798	3183DE	7832 745220	MIKHAIL EGOROV	{"email": "mikhail.egorov1976@postgrespro.ru", "phone": "+70790150471"}
0005432423799	B03382	9378 527880	ELENA KAZAKOVA	{"email": "e.kazakova.17031974@postgrespro.ru", "phone": "+70873586579"}
0005432423800	889846	4760 919756	TATYANA FILIPPOVA	{"email": "tfilippova-1971@postgrespro.ru", "phone": "+70137546671"}
0005432423801	889846	6937 498324	VALENTINA ABRAMOVA	{"email": "valentina-abramova06091966@postgrespro.ru", "phone": "+70566016281"}
0005432423802	FCD073	1657 405277	RAISA TIKHONOVA	{"email": "r-tikhonova_05111963@postgrespro.ru", "phone": "+70923299400"}
0005432423803	358C62	3648 888475	NIKOLAY SEMENOV	{"phone": "+70192260032"}
0005432423804	358C62	9003 293835	LIDIYA ILINA	{"phone": "+70821683154"}
0005432423805	E62F20	4546 667100	YURIY FROLOV	{"email": "frolov.yuriy15091974@postgrespro.ru", "phone": "+70941428492"}
0005432423806	3196C0	0080 010162	GERMAN FOMIN	{"phone": "+70844834944"}
0005432423808	A02E5D	7627 185027	OLGA AKIMOVA	{"phone": "+70247143125"}
0005432423809	45FC80	5293 789071	IGOR MOISEEV	{"email": "moiseevi121965@postgrespro.ru", "phone": "+70781671334"}
0005432423810	188BF0	1498 377338	YULIYA VLASOVA	{"email": "yuliya-vlasova-18081966@postgrespro.ru", "phone": "+70288728306"}
0005432423811	BEB6A9	8047 918020	NADEZHDA MAKAROVA	{"email": "nadezhda-makarova-20031964@postgrespro.ru", "phone": "+70826067127"}
0005432423812	BEB6A9	9520 668991	NIKOLAY ROMANOV	{"email": "nikolay-romanov_081973@postgrespro.ru", "phone": "+70558253464"}
0005432423813	6B8681	3275 344753	NIKOLAY VOLKOV	{"email": "volkovnikolay.21091955@postgrespro.ru", "phone": "+70544698848"}
0005432423814	BC47CC	1389 770067	ELENA GAVRILOVA	{"email": "gavrilovaelena-1970@postgrespro.ru", "phone": "+70814584749"}
0005432423815	C9C9CC	8938 231369	VIOLETTA GORBUNOVA	{"email": "violettagorbunova_10091974@postgrespro.ru", "phone": "+70905720901"}
0005432423816	BB4F7B	7924 057454	SERGEY FILIPPOV	{"email": "sergey.filippov.1971@postgrespro.ru", "phone": "+70916885606"}
0005432423817	F2876C	0050 161233	ANATOLIY DENISOV	{"phone": "+70262989816"}
0005432423818	80B838	0753 816948	MARIYA MIKHAYLOVA	{"email": "mariyamikhaylova.08031966@postgrespro.ru", "phone": "+70212240565"}
0005432423819	FAFD72	5399 584323	ANDREY SHEVCHENKO	{"email": "ashevchenko-1979@postgrespro.ru", "phone": "+70747749936"}
0005432423820	0A79E6	2736 815341	ZOYA FILIPPOVA	{"email": "zfilippova28111971@postgrespro.ru", "phone": "+70721779396"}
0005432423821	0A79E6	8061 348195	ALISA DANILOVA	{"email": "adanilova-111976@postgrespro.ru", "phone": "+70175899734"}
0005432423822	0A79E6	4072 792078	TATYANA KARPOVA	{"email": "karpova_t1971@postgrespro.ru", "phone": "+70516582007"}
0005432423823	0A79E6	3345 112180	LIDIYA MOROZOVA	{"email": "morozovalidiya_081979@postgrespro.ru", "phone": "+70304933755"}
0005432423824	1AC173	8479 948360	VLADIMIR SCHERBAKOV	{"phone": "+70472038937"}
0005432423825	7FE421	2481 421113	DENIS KUZNECOV	{"email": "d_kuznecov_07121976@postgrespro.ru", "phone": "+70673366706"}
0005432423826	18CCF5	2554 787172	TATYANA KUZMINA	{"phone": "+70975330605"}
0005432423827	18CCF5	2307 714052	ANTON KISELEV	{"phone": "+70738083915"}
0005432423828	448DDB	7364 220437	ALBERT MEDVEDEV	{"email": "amedvedev.1965@postgrespro.ru", "phone": "+70567951118"}
0005432423829	800FC7	4141 230699	MARINA NIKITINA	{"phone": "+70425419179"}
0005432423830	800FC7	7293 501293	VIKTOR KUZMIN	{"phone": "+70343305224"}
0005432423831	32DE7A	9126 712578	OLGA LEBEDEVA	{"phone": "+70431301218"}
0005432423832	CDFD30	7805 428326	NATALYA SIDOROVA	{"phone": "+70651934639"}
0005432423833	61346C	2138 068838	VLADIMIR VOLKOV	{"phone": "+70174906424"}
0005432423834	18EC11	3299 938561	NIKOLAY FEDOROV	{"phone": "+70985803943"}
0005432423835	981209	0086 902741	VITALIY PAVLOV	{"email": "vitaliy_pavlov-16081963@postgrespro.ru", "phone": "+70128814336"}
0005432423836	6DA7B2	5976 101527	MARIYA TIKHONOVA	{"phone": "+70240523789"}
0005432423837	29B18D	0656 317748	LYUDMILA KALININA	{"email": "kalinina.lyudmila-061969@postgrespro.ru", "phone": "+70746569829"}
0005432423838	29B18D	7360 142525	ROZA KUDRYASHOVA	{"email": "kudryashovar_071972@postgrespro.ru", "phone": "+70732804516"}
0005432423839	E0D4BF	8722 039827	VLADIMIR NOVIKOV	{"email": "novikovv041979@postgrespro.ru", "phone": "+70158106493"}
0005432423840	D51FB0	3065 497593	ILYA FEDOTOV	{"phone": "+70769230888"}
0005432423841	D51FB0	9129 158215	VLADIMIR ISAEV	{"phone": "+70602610090"}
0005432423842	D51FB0	9975 139936	ANASTASIYA FOMINA	{"email": "anastasiyafomina.1972@postgrespro.ru", "phone": "+70269960270"}
0005432423843	417AD2	7096 804144	ANDREY RODIONOV	{"phone": "+70547525734"}
0005432423844	417AD2	9420 800328	ELENA NIKITINA	{"email": "e_nikitina.1970@postgrespro.ru", "phone": "+70802410783"}
0005432423845	C99D66	7128 254093	EKATERINA KULIKOVA	{"email": "e_kulikova_08031968@postgrespro.ru", "phone": "+70476394587"}
0005432423846	74C19C	5359 445680	RAFAEL MAKSIMOV	{"email": "r-maksimov1975@postgrespro.ru", "phone": "+70508356685"}
0005432423847	D663C1	3354 866208	IGOR KUZMIN	{"email": "i.kuzmin-15031968@postgrespro.ru", "phone": "+70157850767"}
0005432423848	D663C1	0453 440970	DENIS KISELEV	{"phone": "+70907650176"}
0005432423849	626820	3872 866053	ALEKSANDR SAVELEV	{"email": "savelev_a_10061970@postgrespro.ru", "phone": "+70117319711"}
0005432423850	2F0D07	2994 169936	SVETLANA GUSEVA	{"email": "s.guseva.1962@postgrespro.ru", "phone": "+70409021049"}
0005432423851	2F0D07	1503 044032	BORIS KULIKOV	{"email": "kulikovboris.051969@postgrespro.ru", "phone": "+70621185785"}
0005432423852	33C2A2	7935 824579	ALINA RYABOVA	{"email": "a.ryabova_1977@postgrespro.ru", "phone": "+70440783375"}
0005432423853	B97472	1162 398625	OLGA OVCHINNIKOVA	{"email": "olgaovchinnikova.25121979@postgrespro.ru", "phone": "+70399954356"}
0005432423854	0B37CC	6826 095850	OLESYA POPOVA	{"phone": "+70158199037"}
0005432423855	C88D20	9428 435466	ARKADIY NOVIKOV	{"phone": "+70441063713"}
0005432423856	348FCA	8010 939410	LIDIYA MARTYNOVA	{"email": "lidiya.martynova20041979@postgrespro.ru", "phone": "+70036476174"}
0005432423857	348FCA	5332 571564	YURIY KONOVALOV	{"phone": "+70970763798"}
0005432423858	F33A41	8363 328602	ELENA SEMENOVA	{"phone": "+70680890080"}
0005432423859	F33A41	7423 752483	VLADIMIR KUZNECOV	{"phone": "+70588365346"}
0005432423860	E639F9	6282 303031	VYACHESLAV NOVIKOV	{"email": "novikov_vyacheslav1980@postgrespro.ru", "phone": "+70294182841"}
0005432423861	06DED5	0909 201866	ALEKSEY FEDOTOV	{"email": "a_fedotov-1982@postgrespro.ru", "phone": "+70624874717"}
0005432423862	8263CB	3826 881413	ALEKSEY ANDREEV	{"phone": "+70133617424"}
0005432423863	8263CB	8928 510857	ZOYA ZHUKOVA	{"email": "zzhukova.1970@postgrespro.ru", "phone": "+70021296705"}
0005432423864	D8A8A3	0829 003929	ELDAR IVANOV	{"phone": "+70173253477"}
0005432423865	B9FB29	6983 811855	OLGA SOKOLOVA	{"email": "olgasokolova-08121968@postgrespro.ru", "phone": "+70541618185"}
0005432423866	B9FB29	3296 091100	VASILIY KULIKOV	{"phone": "+70109047311"}
0005432423867	521658	1826 236212	SVETLANA IVANOVA	{"email": "svetlana-ivanova-011974@postgrespro.ru", "phone": "+70211205888"}
0005432423868	F55751	7238 963451	YANA FILIPPOVA	{"phone": "+70657818595"}
0005432423869	2F72B2	6550 143858	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey_1966@postgrespro.ru", "phone": "+70157932505"}
0005432423870	E9C7BC	0218 668237	ELENA POPOVA	{"phone": "+70212452017"}
0005432423871	ADE818	7296 100748	ALEKSEY MARTYNOV	{"email": "martynov_a-03031980@postgrespro.ru", "phone": "+70156781584"}
0005432423872	ADE818	4407 353194	ANASTASIYA NIKOLAEVA	{"email": "anastasiya.nikolaeva.1977@postgrespro.ru", "phone": "+70159957701"}
0005432423873	45FE4D	5635 374111	SERGEY PETROV	{"email": "petrov-sergey-11111964@postgrespro.ru", "phone": "+70640395571"}
0005432423874	45FE4D	0900 473827	SVETLANA AKIMOVA	{"phone": "+70038619928"}
0005432423875	3C4D79	0220 300035	LIYA KUDRYASHOVA	{"email": "liya-kudryashova_121970@postgrespro.ru", "phone": "+70416343268"}
0005432423876	1F1240	2309 416775	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev_04081970@postgrespro.ru", "phone": "+70321998362"}
0005432423877	1F1240	7316 747854	VLADIMIR ORLOV	{"email": "v.orlov_091971@postgrespro.ru", "phone": "+70721842259"}
0005432423878	1F1240	3956 865759	DARYA LAZAREVA	{"phone": "+70635721814"}
0005432423879	56C033	6498 450852	TATYANA MAKAROVA	{"phone": "+70355697025"}
0005432423880	56C033	8563 864123	LIDIYA LAZAREVA	{"email": "lazareva_lidiya.091970@postgrespro.ru", "phone": "+70856662455"}
0005432423881	3C2EC6	6249 699443	TAISIYA VLASOVA	{"phone": "+70435829789"}
0005432423882	BCFEC4	6863 470560	NATALIYA ANTONOVA	{"phone": "+70429892760"}
0005432423883	BCFEC4	1609 776229	ALEKSEY FOMIN	{"phone": "+70258051490"}
0005432423884	9113BB	3753 106493	KAMIL SMIRNOV	{"phone": "+70546463815"}
0005432423885	00287A	1358 603736	ELENA STEPANOVA	{"email": "stepanovae.1970@postgrespro.ru", "phone": "+70296185318"}
0005432423886	00287A	8200 440106	VALENTIN ROMANOV	{"email": "v.romanov_051979@postgrespro.ru", "phone": "+70478407777"}
0005432423887	63D4A9	8503 130399	TATYANA ZHURAVLEVA	{"email": "zhuravleva.t-091977@postgrespro.ru", "phone": "+70992630994"}
0005432423888	375E02	5697 440844	ELENA FROLOVA	{"email": "frolovae23121980@postgrespro.ru", "phone": "+70623549006"}
0005432423889	375E02	8307 189685	RAISA CHERNOVA	{"email": "raisa.chernova.21091964@postgrespro.ru", "phone": "+70331947176"}
0005432423890	C1FA04	6457 037721	ILYA GORBUNOV	{"phone": "+70468158889"}
0005432423891	1CF21E	0107 109074	ANTONINA TIKHONOVA	{"phone": "+70000912786"}
0005432423892	C0A7A8	1759 726004	ANASTASIYA FEDOROVA	{"email": "fedorova.anastasiya121964@postgrespro.ru", "phone": "+70811068886"}
0005432423893	2626CA	0095 338270	DMITRIY ALEKSEEV	{"phone": "+70140406748"}
0005432423894	A34AB5	8972 129949	NADEZHDA ILINA	{"email": "n_ilina091955@postgrespro.ru", "phone": "+70640088157"}
0005432423895	A34AB5	5427 504509	MIKHAIL SOLOVEV	{"phone": "+70613916094"}
0005432423896	C926F2	9420 776156	VYACHESLAV SIDOROV	{"email": "sidorov.vyacheslav-051971@postgrespro.ru", "phone": "+70326456902"}
0005432423897	A67331	1052 967118	RENAT BORISOV	{"phone": "+70925721825"}
0005432423898	C00751	6845 330001	YURIY MIKHAYLOV	{"email": "yuriy-mikhaylov_041975@postgrespro.ru", "phone": "+70345206272"}
0005432423899	CB1372	3519 235913	ELIZAVETA FILIPPOVA	{"phone": "+70315292249"}
0005432423900	025BD1	6394 011084	LILIYA KOVALEVA	{"phone": "+70316218330"}
0005432423901	025BD1	3408 904444	ALEKSANDR KUZMIN	{"email": "akuzmin111966@postgrespro.ru", "phone": "+70441126034"}
0005432423902	D56B94	5953 037754	ALENA KRASNOVA	{"phone": "+70901697315"}
0005432423903	D56B94	7202 657643	MAKSIM MIRONOV	{"phone": "+70025962627"}
0005432423904	3A5CE5	6604 216087	VLADIMIR KUDRYASHOV	{"phone": "+70875190064"}
0005432423905	3A5CE5	3337 625551	SERGEY ISAEV	{"phone": "+70037424495"}
0005432423906	A318B1	3111 222953	LYUDMILA KUZMINA	{"email": "lyudmila-kuzmina-1968@postgrespro.ru", "phone": "+70505718798"}
0005432423907	A318B1	5554 887962	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr1965@postgrespro.ru", "phone": "+70294819365"}
0005432423908	643D20	7987 920341	ALEKSANDR GRIGOREV	{"phone": "+70604771146"}
0005432423909	540558	6984 059808	SVETLANA BORISOVA	{"email": "borisova-svetlana_04091972@postgrespro.ru", "phone": "+70515887673"}
0005432423910	ACB8D0	3676 296566	LARISA GUSEVA	{"phone": "+70061234573"}
0005432423911	499986	4838 590422	EVGENIY ZHURAVLEV	{"phone": "+70398716967"}
0005432423912	149FBB	7839 805691	ELENA BOGDANOVA	{"email": "bogdanova_e_1972@postgrespro.ru", "phone": "+70030616852"}
0005432423913	1585AF	9681 229511	SERGEY MAKAROV	{"email": "makarov.s_1970@postgrespro.ru", "phone": "+70577182554"}
0005432423914	A8A0B1	7014 278684	OLGA MIKHAYLOVA	{"email": "mikhaylovaolga1977@postgrespro.ru", "phone": "+70499018193"}
0005432423915	A8A0B1	4695 321137	VALENTINA SMIRNOVA	{"phone": "+70353398162"}
0005432423916	3E574B	7468 739030	OLGA IVANOVA	{"phone": "+70415722461"}
0005432423917	3E574B	9097 243918	TAISIYA TARASOVA	{"phone": "+70043474034"}
0005432423918	3E574B	2662 818031	VYACHESLAV KUZNECOV	{"phone": "+70346467927"}
0005432423919	55BD40	1836 426180	YULIYA MAKSIMOVA	{"email": "maksimovay051972@postgrespro.ru", "phone": "+70991159742"}
0005432423920	F67434	9470 142529	IRINA SERGEEVA	{"email": "sergeeva.i121982@postgrespro.ru", "phone": "+70212545586"}
0005432423921	3C281A	4276 904173	YULIYA MATVEEVA	{"phone": "+70723802367"}
0005432423922	F0482B	1160 744247	YULIYA FILIPPOVA	{"email": "y-filippova.23061981@postgrespro.ru", "phone": "+70094320792"}
0005432423923	034379	7563 101181	MIKHAIL MIRONOV	{"email": "mironov-m_081970@postgrespro.ru", "phone": "+70787198138"}
0005432423924	034379	3245 554669	ALEKSANDR PETROV	{"email": "petrova-14121976@postgrespro.ru", "phone": "+70430084995"}
0005432423925	2E1D5D	4667 566928	IRINA KOROLEVA	{"email": "irina_koroleva.111971@postgrespro.ru", "phone": "+70124166401"}
0005432423926	2E1D5D	4278 256302	ELENA VASILEVA	{"email": "vasileva-elena12031964@postgrespro.ru", "phone": "+70502266181"}
0005432423927	2E1D5D	6227 837877	MARINA MOISEEVA	{"email": "moiseeva.m_28041978@postgrespro.ru", "phone": "+70374589526"}
0005432423928	921504	3770 470157	SERGEY FEDOTOV	{"email": "sergeyfedotov.10081973@postgrespro.ru", "phone": "+70760099427"}
0005432423929	867D17	1799 947796	SVETLANA TROFIMOVA	{"phone": "+70117155244"}
0005432423930	E85811	5547 691229	ANNA KUZNECOVA	{"email": "kuznecovaa19081976@postgrespro.ru", "phone": "+70171181943"}
0005432423931	D6CDAE	1409 012605	SERGEY SEMENOV	{"phone": "+70730404269"}
0005432423932	55A560	3107 266225	MARINA OVCHINNIKOVA	{"email": "m.ovchinnikova13121977@postgrespro.ru", "phone": "+70091770907"}
0005432423933	55A560	9433 358296	ALEKSEY KAZAKOV	{"phone": "+70526084665"}
0005432423934	81F65C	2339 634295	OLGA ZOTOVA	{"email": "zotovao.061964@postgrespro.ru", "phone": "+70189889756"}
0005432423935	5D02F2	1160 174319	ZULFIYA KUZMINA	{"email": "zulfiya.kuzmina_1961@postgrespro.ru", "phone": "+70577899554"}
0005432423936	C80B18	9540 495559	TATYANA KUZNECOVA	{"email": "kuznecova-t_051977@postgrespro.ru", "phone": "+70261609931"}
0005432423937	807A71	7825 141770	TATYANA IVANOVA	{"email": "ivanova.tatyana-121977@postgrespro.ru", "phone": "+70025480571"}
0005432423938	AA1CFC	0119 074198	GALINA PAVLOVA	{"phone": "+70129002110"}
0005432423939	A8C73E	0616 936321	MARINA ANISIMOVA	{"email": "anisimova.marina_1974@postgrespro.ru", "phone": "+70628622670"}
0005432423940	A5FB84	6495 200655	VALENTINA KOMAROVA	{"phone": "+70349093849"}
0005432423941	A5FB84	3549 546505	TATYANA KONDRATEVA	{"email": "tatyana_kondrateva_08051976@postgrespro.ru", "phone": "+70441455803"}
0005432423942	048FA6	0591 076239	NATALYA BELOVA	{"phone": "+70604916805"}
0005432423943	24C4FD	8392 288641	SVETLANA NOVIKOVA	{"email": "svetlana-novikova.051969@postgrespro.ru", "phone": "+70182694324"}
0005432423944	377213	9104 050282	SERGEY CHERNOV	{"email": "chernov_s.23061960@postgrespro.ru", "phone": "+70555031921"}
0005432423945	014555	5612 623460	ZINAIDA ORLOVA	{"email": "zinaida_orlova_121975@postgrespro.ru", "phone": "+70783526161"}
0005432423946	014555	6053 518783	LYUDMILA ANISIMOVA	{"email": "lyudmila_anisimova121985@postgrespro.ru", "phone": "+70600969588"}
0005432423947	C5B25B	6653 582042	KSENIYA MAKAROVA	{"phone": "+70098204673"}
0005432423948	F03B8E	0143 495318	ARTUR OSIPOV	{"email": "osipov-artur-111981@postgrespro.ru", "phone": "+70391710010"}
0005432423949	C6C76C	3223 147548	ALEKSANDR IVANOV	{"email": "ivanov_a.02041967@postgrespro.ru", "phone": "+70677884113"}
0005432423950	BB6E27	7306 695123	VIKTOR GRIGOREV	{"phone": "+70915279750"}
0005432423951	57F43C	6163 508932	SERGEY BORISOV	{"email": "sergey.borisov081966@postgrespro.ru", "phone": "+70517978751"}
0005432423952	57F43C	9816 346117	ALEKSEY SHEVCHENKO	{"phone": "+70598008282"}
0005432423953	B9D28B	3115 459407	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov-10031989@postgrespro.ru", "phone": "+70903207750"}
0005432423954	1A4CC8	8744 381118	VIKTOR GUSEV	{"email": "viktor_gusev23121975@postgrespro.ru", "phone": "+70586646668"}
0005432423955	127561	7231 874825	ALINA SMIRNOVA	{"phone": "+70902707785"}
0005432423956	2E7F06	0282 524332	PAVEL SMIRNOV	{"phone": "+70636522455"}
0005432423957	971468	1813 346454	ROMAN CHERNOV	{"phone": "+70483994072"}
0005432423958	F2C3AD	5596 810474	NATALIYA VLASOVA	{"phone": "+70080619672"}
0005432423959	948F4A	5431 233209	TATYANA TITOVA	{"phone": "+70069942649"}
0005432423960	487B4B	8997 761748	ALINA SIDOROVA	{"phone": "+70873148976"}
0005432423961	373BD2	4884 054758	ALEKSANDR SAVELEV	{"phone": "+70671059138"}
0005432423962	D143DD	2646 878942	MIKHAIL FEDOROV	{"phone": "+70807472971"}
0005432423963	DC8A15	3890 955480	SVETLANA ABRAMOVA	{"email": "abramova-svetlana.1969@postgrespro.ru", "phone": "+70867473814"}
0005432423964	DC8A15	7853 058990	VALENTINA FOMINA	{"phone": "+70443209784"}
0005432423965	8F659C	4349 773024	VALENTINA FROLOVA	{"phone": "+70448590613"}
0005432423966	8F659C	5377 937649	VADIM POPOV	{"phone": "+70813248101"}
0005432423967	AE1B02	2346 722968	GENNADIY POPOV	{"phone": "+70936622872"}
0005432423968	CD4985	8720 201660	YULIYA KOMAROVA	{"email": "yuliya_komarova_25041982@postgrespro.ru", "phone": "+70768142655"}
0005432423969	86FC32	1913 153391	ROMAN FEDOTOV	{"phone": "+70550358470"}
0005432423970	54726A	0695 684435	OLEG PAVLOV	{"email": "oleg_pavlov.121970@postgrespro.ru", "phone": "+70637042467"}
0005432423971	54726A	0592 929929	EVGENIY MAKAROV	{"phone": "+70903794360"}
0005432423972	54726A	0598 593251	LYUDMILA IVANOVA	{"phone": "+70902703098"}
0005432423973	C8DC9D	7340 947089	YANA BORISOVA	{"email": "borisovay-011970@postgrespro.ru", "phone": "+70716462279"}
0005432423974	15919C	8525 596666	IVAN SMIRNOV	{"email": "i.smirnov111968@postgrespro.ru", "phone": "+70326523148"}
0005432423975	BA3EB3	7885 574463	ANGELINA LUKYANOVA	{"email": "lukyanova_a-071977@postgrespro.ru", "phone": "+70847947337"}
0005432423976	80CFD1	0141 633362	ANASTASIYA KOROLEVA	{"phone": "+70787488451"}
0005432423977	A0DB03	4241 092882	ALEKSEY DAVYDOV	{"email": "davydov_aleksey.111984@postgrespro.ru", "phone": "+70945577681"}
0005432423978	5FFC9F	1784 979900	VALENTINA SOLOVEVA	{"email": "soloveva-v_011987@postgrespro.ru", "phone": "+70871794017"}
0005432423979	E8A947	0661 673434	EVGENIY SOROKIN	{"phone": "+70244959456"}
0005432423980	69F2F3	2062 391861	VADIM MIKHAYLOV	{"phone": "+70022989684"}
0005432423981	5DCFFB	0078 163227	GALINA RODIONOVA	{"email": "rodionova-galina.021982@postgrespro.ru", "phone": "+70811674987"}
0005432423982	5DCFFB	4347 011566	DANILA SAVELEV	{"phone": "+70487834844"}
0005432423983	5DCFFB	2704 479429	ALEKSEY BELOV	{"phone": "+70319477595"}
0005432423984	588AAF	7279 151137	VERA KUZMINA	{"phone": "+70626967627"}
0005432423985	254DD7	8104 139836	MARIYA VOLKOVA	{"email": "volkova.mariya.1972@postgrespro.ru", "phone": "+70095069513"}
0005432423986	254DD7	4152 434411	VLADISLAV ZHURAVLEV	{"email": "vzhuravlev_19101965@postgrespro.ru", "phone": "+70725346302"}
0005432423987	CCC495	2991 607585	GEORGIY GAVRILOV	{"phone": "+70037935702"}
0005432423988	044035	9788 514810	IGOR PAVLOV	{"phone": "+70407541138"}
0005432423989	044035	9150 534452	ALEKSANDR MARTYNOV	{"phone": "+70453980691"}
0005432423990	9984DD	2586 053424	ANDREY BARANOV	{"email": "baranovandrey_17071972@postgrespro.ru", "phone": "+70984383584"}
0005432423991	AE10F4	2524 529642	DMITRIY FEDOTOV	{"email": "dmitriy_fedotov1976@postgrespro.ru", "phone": "+70639087771"}
0005432423992	AE10F4	1327 193451	SERGEY KUZMIN	{"phone": "+70938434558"}
0005432423993	AE10F4	9406 238030	VIKTOR YAKOVLEV	{"phone": "+70511305384"}
0005432423994	ABBA55	6821 918553	ANNA MIRONOVA	{"email": "mironova_a-071975@postgrespro.ru", "phone": "+70397810078"}
0005432423995	FC74DE	8155 641464	VYACHESLAV KULIKOV	{"email": "v_kulikov-091970@postgrespro.ru", "phone": "+70218442044"}
0005432423996	827BFD	6441 948762	SERGEY MAKAROV	{"email": "s-makarov_03081964@postgrespro.ru", "phone": "+70262774809"}
0005432423997	1FBDC2	4399 064915	ANDREY MIKHAYLOV	{"phone": "+70247818191"}
0005432423998	1FBDC2	0468 328798	ANASTASIYA BORISOVA	{"email": "borisova_a.1973@postgrespro.ru", "phone": "+70558711175"}
0005432423999	F1EDD6	0867 523394	EVGENIYA KOZLOVA	{"email": "kozlovaevgeniya_1967@postgrespro.ru", "phone": "+70598618652"}
0005432424000	E123D3	1891 597570	NIKOLAY KULIKOV	{"email": "n.kulikov_1972@postgrespro.ru", "phone": "+70551963228"}
0005432424001	B42F41	2529 830467	ALEKSANDR DMITRIEV	{"email": "dmitriev_a_06081967@postgrespro.ru", "phone": "+70745717662"}
0005432424002	B42F41	3643 064179	EVGENIY ISAEV	{"phone": "+70871050198"}
0005432424003	B42F41	1778 226419	ROZALIYA IVANOVA	{"email": "ivanovar-1984@postgrespro.ru", "phone": "+70276747682"}
0005432424004	269D8B	9260 506074	EVGENIYA KULIKOVA	{"phone": "+70948924273"}
0005432424005	FE47A0	4515 464500	MIKHAIL NAZAROV	{"email": "mnazarov_1958@postgrespro.ru", "phone": "+70253479601"}
0005432424006	FE47A0	5036 047046	ALEKSANDR IVANOV	{"email": "ivanov_a1970@postgrespro.ru", "phone": "+70732272910"}
0005432424007	78F07E	7281 780181	VYACHESLAV DAVYDOV	{"phone": "+70325593341"}
0005432424008	6E5E79	7120 995539	ALEKSEY EGOROV	{"email": "egorov-aleksey-101970@postgrespro.ru", "phone": "+70996559829"}
0005432424009	E54E77	7182 530358	TATYANA KAZAKOVA	{"phone": "+70158179752"}
0005432424010	11BCA7	4636 956298	VYACHESLAV TIKHONOV	{"email": "tikhonovv071977@postgrespro.ru", "phone": "+70130616388"}
0005432424011	9EF36C	9322 076339	ALEKSANDRA ISAEVA	{"phone": "+70846992482"}
0005432424012	B1A5E2	0153 525235	RIMMA SMIRNOVA	{"email": "r_smirnova-22111980@postgrespro.ru", "phone": "+70593412487"}
0005432424013	380453	9893 966800	ALEKSANDR KARPOV	{"phone": "+70517598249"}
0005432424014	4C9F49	6029 874395	MAKSIM ALEKSEEV	{"email": "m.alekseev_14121970@postgrespro.ru", "phone": "+70118116304"}
0005432424015	1DAD96	7097 235380	ANTONINA VOLKOVA	{"phone": "+70167882919"}
0005432424016	23F610	6800 980530	EKATERINA DAVYDOVA	{"phone": "+70082218196"}
0005432424017	818D42	8622 738630	OLGA IVANOVA	{"phone": "+70807663169"}
0005432424018	818D42	3417 134041	ROMAN NOVIKOV	{"email": "r.novikov-21081978@postgrespro.ru", "phone": "+70423506685"}
0005432424019	1300F3	0922 296181	TATYANA IVANOVA	{"email": "ivanova.tatyana.11051970@postgrespro.ru", "phone": "+70901963110"}
0005432424020	BA74B4	3404 161735	VALENTINA MOISEEVA	{"email": "valentina-moiseeva_051972@postgrespro.ru", "phone": "+70570698041"}
0005432424021	1F4F22	5644 461344	IRINA ZHUKOVA	{"phone": "+70447435516"}
0005432424022	079B13	1661 999518	VIKTOR TARASOV	{"email": "tarasov_v.031963@postgrespro.ru", "phone": "+70776766903"}
0005432424023	97665C	0661 225497	SERGEY MOROZOV	{"email": "morozov.s_16101965@postgrespro.ru", "phone": "+70974946593"}
0005432424024	F0C8EB	7415 926067	NADEZHDA ARKHIPOVA	{"phone": "+70752076397"}
0005432424025	EDF242	6688 228736	DMITRIY NAUMOV	{"phone": "+70518149048"}
0005432424026	EDF242	1015 182538	NADEZHDA KRASNOVA	{"email": "n-krasnova-1976@postgrespro.ru", "phone": "+70297703104"}
0005432424027	69D4DD	5917 510657	RAVIL MAKSIMOV	{"phone": "+70721850284"}
0005432424028	69D4DD	4663 420356	VASILIY KONOVALOV	{"phone": "+70276419267"}
0005432424029	C0D30B	8394 089768	VIKTOR GRIGOREV	{"email": "viktor.grigorev021973@postgrespro.ru", "phone": "+70777494838"}
0005432424030	842B9D	9703 608789	SERGEY KUZMIN	{"email": "sergey_kuzmin_111981@postgrespro.ru", "phone": "+70961385160"}
0005432424031	8012DB	8660 848016	VALENTINA VOLKOVA	{"email": "volkova.v-1981@postgrespro.ru", "phone": "+70805772874"}
0005432424032	AF23A5	6843 947106	ALBINA DENISOVA	{"phone": "+70970359263"}
0005432424033	AF23A5	4420 917937	NATALYA MAKSIMOVA	{"phone": "+70862992196"}
0005432424034	7C7EF4	3776 704047	ANATOLIY SERGEEV	{"phone": "+70506812950"}
0005432424035	B696E4	1367 356901	ELENA SEMENOVA	{"email": "elena_semenova-13031974@postgrespro.ru", "phone": "+70562453367"}
0005432424036	B696E4	3712 412135	SVETLANA IVANOVA	{"phone": "+70703869256"}
0005432424037	B696E4	2636 533593	IOSIF KAZAKOV	{"email": "iosif_kazakov1979@postgrespro.ru", "phone": "+70722784297"}
0005432424038	948CE3	1055 441019	EVGENIY SMIRNOV	{"phone": "+70238553949"}
0005432424039	357C7B	9570 958047	YURIY SERGEEV	{"email": "y.sergeev.1976@postgrespro.ru", "phone": "+70398854032"}
0005432424040	357C7B	6078 156628	NIKITA GUSEV	{"phone": "+70560631413"}
0005432424041	6350FA	9803 975356	YULIYA EGOROVA	{"phone": "+70024859754"}
0005432424042	F42AE6	0102 900068	VIKTOR ILIN	{"email": "ilin.viktor011968@postgrespro.ru", "phone": "+70738118124"}
0005432424043	F42AE6	2300 259025	LYUBOV ZAKHAROVA	{"phone": "+70796456940"}
0005432424044	65FA7D	0817 951753	NINA ZAYCEVA	{"email": "zaycevanina_13091967@postgrespro.ru", "phone": "+70623167154"}
0005432424045	781BBE	0651 210402	ELENA EGOROVA	{"email": "egorovaelena_1972@postgrespro.ru", "phone": "+70955235548"}
0005432424046	91D266	7263 300086	OLGA EGOROVA	{"email": "egorova-o09051971@postgrespro.ru", "phone": "+70339145365"}
0005432424047	91D266	0191 236155	GALINA SEMENOVA	{"phone": "+70686997748"}
0005432424048	DBA0AD	7260 578068	VASILIY MAKAROV	{"phone": "+70746610011"}
0005432424049	ED08DB	9239 357081	NATALYA KARPOVA	{"email": "karpova.n_1968@postgrespro.ru", "phone": "+70075954521"}
0005432424050	ED08DB	3999 600581	LYUDMILA FILATOVA	{"phone": "+70745496402"}
0005432424051	3E8B6A	4710 490443	SEMEN IVANOV	{"email": "sivanov.27041966@postgrespro.ru", "phone": "+70173593189"}
0005432424052	3E8B6A	6011 063246	ELIZAVETA IVANOVA	{"email": "elizaveta-ivanova-1969@postgrespro.ru", "phone": "+70638998626"}
0005432424053	9DA77C	6069 169395	VLADISLAV GAVRILOV	{"email": "gavrilov-v-011976@postgrespro.ru", "phone": "+70693502165"}
0005432424054	9DA77C	7149 480537	VLADIMIR PAVLOV	{"phone": "+70874082480"}
0005432424055	9DA77C	5209 410784	ELIZAVETA ABRAMOVA	{"phone": "+70674751797"}
0005432424056	7DF3BE	1442 248358	VALERIY GUSEV	{"email": "v-gusev.1981@postgrespro.ru", "phone": "+70831330053"}
0005432424057	7DF3BE	0847 513719	SERGEY PETROV	{"phone": "+70239813853"}
0005432424058	0D599A	7133 278086	ALEKSANDR NIKITIN	{"phone": "+70277078985"}
0005432424059	13A3CD	2842 307728	OLGA ANDREEVA	{"phone": "+70941340510"}
0005432424060	0C6EC0	8267 179370	LYUDMILA MATVEEVA	{"email": "lyudmilamatveeva-041973@postgrespro.ru", "phone": "+70026440859"}
0005432424061	DF1E31	8005 996424	NINA PAVLOVA	{"phone": "+70862324287"}
0005432424062	DF1E31	2906 401600	KSENIYA ZHUKOVA	{"phone": "+70754959637"}
0005432424063	DF1E31	1753 305133	TAMARA DMITRIEVA	{"email": "dmitrievatamara-1975@postgrespro.ru", "phone": "+70963723278"}
0005432424064	3C1A89	1708 331110	SERGEY IVANOV	{"email": "s.ivanov_1978@postgrespro.ru", "phone": "+70060482338"}
0005432424065	744515	6049 486789	KRISTINA GERASIMOVA	{"email": "gerasimovakristina.1966@postgrespro.ru", "phone": "+70743123900"}
0005432424066	34C87C	5722 832164	ALEKSANDR ZAYCEV	{"phone": "+70669983082"}
0005432424067	D919FF	8210 415811	ANDREY SOKOLOV	{"phone": "+70042567119"}
0005432424068	E4C748	3623 245360	ALEKSEY STEPANOV	{"phone": "+70989657900"}
0005432424069	E4C748	2773 076836	SERGEY GUSEV	{"phone": "+70504905481"}
0005432424070	972618	2969 131406	ANDREY SOLOVEV	{"phone": "+70316008240"}
0005432424071	972618	6291 250584	SERGEY TARASOV	{"phone": "+70941879281"}
0005432424072	4556B5	8125 986406	DARYA MOROZOVA	{"email": "morozova.darya-25061967@postgrespro.ru", "phone": "+70665295324"}
0005432424073	4556B5	6920 480469	LIDIYA ORLOVA	{"phone": "+70504894752"}
0005432424074	12E93D	9062 020022	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey_101975@postgrespro.ru", "phone": "+70846780173"}
0005432424075	5F5CBA	6339 846535	VERA ERMAKOVA	{"email": "v_ermakova-07041961@postgrespro.ru", "phone": "+70595854487"}
0005432424076	5F5CBA	0716 010253	ELENA RYABOVA	{"email": "ryabova.elena_22101970@postgrespro.ru", "phone": "+70088350974"}
0005432424077	5F5CBA	3469 838963	SVETLANA ANTONOVA	{"phone": "+70943168772"}
0005432424078	FF254B	1321 966562	EVGENIY KUZNECOV	{"phone": "+70567786257"}
0005432424079	FF254B	5268 951157	DENIS SCHERBAKOV	{"email": "scherbakov-d071962@postgrespro.ru", "phone": "+70010107553"}
0005432424080	40F622	9555 717785	ROMAN ANDREEV	{"phone": "+70858830522"}
0005432424081	F45EC9	2954 436620	MADINA RODIONOVA	{"phone": "+70891987878"}
0005432424082	0DE1F9	0119 241151	ELENA TIKHONOVA	{"phone": "+70904720873"}
0005432424083	0DE1F9	1519 997514	ELENA ZHUKOVA	{"email": "zhukovae.02101963@postgrespro.ru", "phone": "+70047541840"}
0005432424084	31BAF7	5333 013360	VERA EFIMOVA	{"email": "v.efimova-1972@postgrespro.ru", "phone": "+70546509693"}
0005432424085	230F40	9101 658111	VALENTINA TIMOFEEVA	{"phone": "+70507776829"}
0005432424086	230F40	6050 645300	KIRILL IVANOV	{"phone": "+70551394319"}
0005432424087	230F40	1216 621503	ANTONINA MOISEEVA	{"phone": "+70611563407"}
0005432424088	8FD26D	5584 427378	ANNA VOLKOVA	{"email": "volkovaa15011980@postgrespro.ru", "phone": "+70510206990"}
0005432424089	2B0E89	3793 612245	NINA NESTEROVA	{"phone": "+70521485134"}
0005432424090	7D8759	8979 990793	ALEKSEY VASILEV	{"email": "vasilevaleksey.101971@postgrespro.ru", "phone": "+70629853187"}
0005432424091	E5606A	1002 776007	STANISLAV SERGEEV	{"phone": "+70699575332"}
0005432424092	068502	1429 456868	NIKOLAY POPOV	{"email": "n_popov.02041961@postgrespro.ru", "phone": "+70932514903"}
0005432424093	068502	0406 732262	ALEKSANDRA KUZNECOVA	{"phone": "+70952183725"}
0005432424094	28F401	0860 607975	TATYANA KUZNECOVA	{"email": "kuznecova_t-10101974@postgrespro.ru", "phone": "+70152429945"}
0005432424095	E0477C	9827 679009	ELENA FROLOVA	{"email": "frolova.e.1975@postgrespro.ru", "phone": "+70731428599"}
0005432424096	4A3F42	9739 511427	TAMARA MAKAROVA	{"phone": "+70814830037"}
0005432424097	DFB313	5170 501442	EKATERINA MIKHAYLOVA	{"email": "mikhaylova_e1978@postgrespro.ru", "phone": "+70778564608"}
0005432424098	F1AE6E	2592 795694	ALBERT NAZAROV	{"email": "albert.nazarov-06021969@postgrespro.ru", "phone": "+70580772364"}
0005432424099	F1AE6E	4298 563835	SVETLANA CHERNOVA	{"phone": "+70044729358"}
0005432424100	F1AE6E	3324 026362	KONSTANTIN MAKSIMOV	{"phone": "+70576724006"}
0005432424101	F1AE6E	5622 791658	NATALYA MAKSIMOVA	{"phone": "+70666082055"}
0005432424102	A14794	8094 219959	NIKITA GAVRILOV	{"email": "gavrilovnikita-19031972@postgrespro.ru", "phone": "+70246406245"}
0005432424103	D2C6D2	9009 808385	MARIYA ALEKSEEVA	{"email": "alekseeva-m-081979@postgrespro.ru", "phone": "+70759995426"}
0005432424104	D2C6D2	3889 521389	LARISA SMIRNOVA	{"email": "larisa_smirnova.091972@postgrespro.ru", "phone": "+70714727012"}
0005432424105	EE44AF	8658 675638	SVETLANA VASILEVA	{"phone": "+70774418544"}
0005432424106	8C76F8	4512 459899	PLATON POPOV	{"phone": "+70994625223"}
0005432424109	AB0363	7741 806430	ANNA MATVEEVA	{"phone": "+70355195576"}
0005432424110	2038E8	2374 092286	GALINA SOROKINA	{"email": "sorokina-g.101973@postgrespro.ru", "phone": "+70844811057"}
0005432424111	2038E8	6297 702843	VIKTOR ZHUKOV	{"phone": "+70928649235"}
0005432424112	2038E8	2738 509202	VLADIMIR EGOROV	{"phone": "+70276049791"}
0005432424113	25A1C6	1269 203208	EKATERINA FOMINA	{"email": "e_fomina_27081965@postgrespro.ru", "phone": "+70881362193"}
0005432424114	1A7492	8207 411218	DARYA MASLOVA	{"email": "maslova_darya.27101962@postgrespro.ru", "phone": "+70619278496"}
0005432424115	E5F7BD	3628 243737	MAKSIM GRIGOREV	{"email": "grigorevmaksim.1962@postgrespro.ru", "phone": "+70112538860"}
0005432424116	E5F7BD	0390 108393	EKATERINA POTAPOVA	{"email": "e_potapova1972@postgrespro.ru", "phone": "+70280969333"}
0005432424117	6EC5F1	6832 977303	GALINA KRASNOVA	{"phone": "+70617501306"}
0005432424118	6EC5F1	9227 798176	ALEKSEY NAZAROV	{"email": "nazarov_a.1978@postgrespro.ru", "phone": "+70689524593"}
0005432424119	E14686	5420 963771	LEONID KUZNECOV	{"email": "kuznecovleonid041962@postgrespro.ru", "phone": "+70215180374"}
0005432424120	E14686	3753 824087	NIKITA ROMANOV	{"phone": "+70581264096"}
0005432424121	409CA2	5949 975075	PAVEL SCHERBAKOV	{"phone": "+70393121548"}
0005432424122	A00551	1101 461786	MARAT MEDVEDEV	{"email": "marat.medvedev_101961@postgrespro.ru", "phone": "+70125839614"}
0005432424123	BEDCB2	9917 283949	SVETLANA BORISOVA	{"email": "borisova-s07091978@postgrespro.ru", "phone": "+70223712052"}
0005432424124	260C39	2055 697928	DIANA MOROZOVA	{"phone": "+70041924275"}
0005432424125	260C39	8419 145293	SERGEY KAZAKOV	{"phone": "+70084029563"}
0005432424126	260C39	5368 978637	ANNA SERGEEVA	{"email": "annasergeeva1972@postgrespro.ru", "phone": "+70238407701"}
0005432424127	0F2915	3882 249244	VALERIYA TIMOFEEVA	{"phone": "+70395451074"}
0005432424128	0F2915	8577 371551	ANDREY CHERNOV	{"email": "chernov_andrey.101985@postgrespro.ru", "phone": "+70901267278"}
0005432424129	BF5144	8493 670101	ANTONINA GUSEVA	{"phone": "+70481317966"}
0005432424130	AF19A5	8917 837827	IRINA IVANOVA	{"email": "ivanova-i.1977@postgrespro.ru", "phone": "+70711335781"}
0005432424131	2B7F2E	7949 113345	VASILIY KUZNECOV	{"phone": "+70444064128"}
0005432424132	BA6B60	1370 635611	EVGENIYA MIRONOVA	{"phone": "+70643158643"}
0005432424133	873F58	3284 123212	VALERIY SEMENOV	{"phone": "+70663720087"}
0005432424134	873F58	6361 765277	SERGEY ZAYCEV	{"phone": "+70106193279"}
0005432424135	01022D	4966 945042	VYACHESLAV MAKAROV	{"email": "makarov.v_091974@postgrespro.ru", "phone": "+70914358810"}
0005432424136	F5F4B8	7867 388260	NIKOLAY SMIRNOV	{"email": "smirnov-n111979@postgrespro.ru", "phone": "+70762032645"}
0005432424137	691369	1507 079277	YULIYA FILATOVA	{"phone": "+70260923382"}
0005432424138	32E16F	7246 457123	SERGEY MOISEEV	{"phone": "+70778082150"}
0005432424139	32E16F	5649 175835	VLADIMIR EGOROV	{"email": "vladimiregorov28051968@postgrespro.ru", "phone": "+70764183936"}
0005432424140	487205	8811 907670	ALEKSANDR DENISOV	{"email": "denisov.a081972@postgrespro.ru", "phone": "+70107052499"}
0005432424141	9EB819	7635 748478	ELENA SAVELEVA	{"email": "saveleva_elena_1975@postgrespro.ru", "phone": "+70186892075"}
0005432424142	9EB819	9958 914129	VLADISLAV BARANOV	{"email": "baranov.vladislav.1962@postgrespro.ru", "phone": "+70340571808"}
0005432424143	F7EE0C	4508 089860	OLGA GAVRILOVA	{"phone": "+70147194938"}
0005432424144	1AF7C4	2691 291836	ALBINA AKIMOVA	{"phone": "+70207096499"}
0005432424145	1AF7C4	7969 505803	VYACHESLAV IVANOV	{"email": "vyacheslav_ivanov.061978@postgrespro.ru", "phone": "+70269413567"}
0005432424146	17DD82	8837 093642	OLEG PAVLOV	{"email": "pavlov_o-1981@postgrespro.ru", "phone": "+70005494925"}
0005432424147	E7B4F6	3833 091106	VYACHESLAV PETROV	{"email": "petrovvyacheslav-25041981@postgrespro.ru", "phone": "+70930999250"}
0005432424148	E7B4F6	8148 457229	VALERIYA FROLOVA	{"email": "frolovav1974@postgrespro.ru", "phone": "+70709993053"}
0005432424149	9BA790	8953 348936	VALENTINA SEMENOVA	{"email": "semenovav_08101965@postgrespro.ru", "phone": "+70231190362"}
0005432424150	51D038	9344 201301	ALEKSEY KUZNECOV	{"phone": "+70384367781"}
0005432424151	51D038	1106 368967	NATALYA RODIONOVA	{"email": "rodionovan_031970@postgrespro.ru", "phone": "+70236263417"}
0005432424152	C8A222	8415 434738	ANATOLIY FEDOTOV	{"email": "a.fedotov.1976@postgrespro.ru", "phone": "+70769858136"}
0005432424153	DCBAFC	6327 757817	NADEZHDA EFREMOVA	{"email": "n.efremova071980@postgrespro.ru", "phone": "+70646765668"}
0005432424154	B56622	6370 242466	IREK GERASIMOV	{"email": "gerasimov-irek_041986@postgrespro.ru", "phone": "+70528505449"}
0005432424155	001E92	2872 614613	ANDREY ZAYCEV	{"phone": "+70562158554"}
0005432424156	DA0F11	4388 510085	SERGEY YAKOVLEV	{"phone": "+70303551788"}
0005432424157	DA0F11	0860 966379	ELENA SOKOLOVA	{"email": "sokolovae.121978@postgrespro.ru", "phone": "+70512550457"}
0005432424158	CD2FC7	3450 617800	VYACHESLAV ZAYCEV	{"phone": "+70181844838"}
0005432424159	CD2FC7	2626 754803	MARIYA SAVELEVA	{"email": "savelevamariya.1961@postgrespro.ru", "phone": "+70147009541"}
0005432424160	E59472	2363 836961	NINA GUSEVA	{"phone": "+70095161357"}
0005432424161	4B215B	6993 504828	MARGARITA MIKHAYLOVA	{"email": "mikhaylova-margarita-1970@postgrespro.ru", "phone": "+70508095565"}
0005432424162	09D904	9392 366188	EKATERINA NESTEROVA	{"phone": "+70055424340"}
0005432424163	C7FFD1	4443 962714	LYUBOV ABRAMOVA	{"email": "abramova_l.081975@postgrespro.ru", "phone": "+70323679066"}
0005432424164	F6E49B	5396 015778	NADEZHDA LOGINOVA	{"email": "loginova-nadezhda_1972@postgrespro.ru", "phone": "+70846885970"}
0005432424165	54D625	3558 639172	SERGEY IVANOV	{"email": "ivanov_s_05031968@postgrespro.ru", "phone": "+70191873349"}
0005432424166	211016	7580 850928	ANNA MALYSHEVA	{"email": "a.malysheva_051955@postgrespro.ru", "phone": "+70313754248"}
0005432424167	5A0B4A	2466 005095	VIKTOR SCHERBAKOV	{"phone": "+70646901972"}
0005432424168	519D07	4635 026775	VIKTORIYA EGOROVA	{"phone": "+70757282192"}
0005432424169	896F15	1219 375704	PAVEL FOMIN	{"phone": "+70027969490"}
0005432424170	F0410E	1967 914936	SERGEY SOROKIN	{"phone": "+70664635614"}
0005432424171	F0410E	2487 996222	VLADIMIR SIDOROV	{"email": "vladimirsidorov.07041992@postgrespro.ru", "phone": "+70535068477"}
0005432424172	FF4CA8	5662 642971	ROMAN NOVIKOV	{"phone": "+70033357307"}
0005432424173	FF4CA8	5442 058338	DIANA KOZLOVA	{"phone": "+70537822492"}
0005432424174	6972AD	9684 660698	MARIYA NIKOLAEVA	{"phone": "+70844563644"}
0005432424175	6972AD	9550 185488	ALEKSEY KULIKOV	{"email": "alekseykulikov-021966@postgrespro.ru", "phone": "+70032690303"}
0005432424176	4C8F63	3956 289690	ALEKSANDR BARANOV	{"phone": "+70970022593"}
0005432424177	C27CAA	0687 260030	KSENIYA KOZLOVA	{"phone": "+70563305410"}
0005432424178	F8912A	2800 255521	MARINA DAVYDOVA	{"email": "davydovamarina_021974@postgrespro.ru", "phone": "+70646020773"}
0005432424179	F8912A	0058 014182	RAISA EGOROVA	{"phone": "+70222462159"}
0005432424180	4D05E3	7995 842979	YULIYA DMITRIEVA	{"phone": "+70366721777"}
0005432424181	4D05E3	1095 848101	VIKTOR GORBUNOV	{"phone": "+70236207860"}
0005432424182	0DFCF6	2442 719745	VASILIY GRIGOREV	{"email": "grigorev.v_26061978@postgrespro.ru", "phone": "+70912719688"}
0005432424183	E5D67D	4880 398874	ALEKSANDR IVANOV	{"email": "a-ivanov.061973@postgrespro.ru", "phone": "+70115386311"}
0005432424184	DE552E	9238 902554	VALENTINA SERGEEVA	{"phone": "+70656653609"}
0005432424185	65E1E9	6108 311153	ANNA KONDRATEVA	{"phone": "+70311608702"}
0005432424186	65E1E9	3328 060399	LEONID ZAKHAROV	{"phone": "+70431998865"}
0005432424187	0DB7D3	5631 104484	ROMAN POPOV	{"phone": "+70188412797"}
0005432424188	D9708B	7506 435761	TATYANA MAKSIMOVA	{"phone": "+70306049183"}
0005432424189	F2E46C	6016 641520	NELLI DENISOVA	{"phone": "+70493334610"}
0005432424190	0081C5	4552 856108	IRINA KOROLEVA	{"phone": "+70112081627"}
0005432424191	A846F2	9832 636381	ALEKSEY NOVIKOV	{"email": "a-novikov051973@postgrespro.ru", "phone": "+70424661684"}
0005432424192	A780F4	6204 596390	RIMMA IVANOVA	{"phone": "+70243354355"}
0005432424193	3235F8	3830 957082	TATYANA LUKYANOVA	{"email": "lukyanovatatyana1957@postgrespro.ru", "phone": "+70132611177"}
0005432424194	B0A06F	7688 829119	ANATOLIY MOROZOV	{"email": "morozov-a-1973@postgrespro.ru", "phone": "+70854665651"}
0005432424195	B0A06F	9463 501099	EKATERINA IVANOVA	{"email": "ekaterina.ivanova_23071978@postgrespro.ru", "phone": "+70528869308"}
0005432424196	A6FA70	1689 230509	MAKSIM MOROZOV	{"phone": "+70462092325"}
0005432424197	088DBD	0538 732033	VLADIMIR NOVIKOV	{"email": "v.novikov1972@postgrespro.ru", "phone": "+70740295614"}
0005432424198	0FC87C	5750 378172	EVA DANILOVA	{"email": "e-danilova021967@postgrespro.ru", "phone": "+70677852783"}
0005432424199	E84738	1063 221842	ALEKSEY ALEKSANDROV	{"phone": "+70164418572"}
0005432424256	BD6D0C	6960 722497	ALEKSEY SERGEEV	{"phone": "+70518724684"}
0005432424257	BD6D0C	5036 627474	LYUDMILA SEMENOVA	{"phone": "+70360880826"}
0005432424200	436C72	4102 227226	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey111980@postgrespro.ru", "phone": "+70867145071"}
0005432424201	DC5C3F	1221 874647	DENIS PAVLOV	{"phone": "+70250644414"}
0005432424202	1F73BE	4271 231614	VERA ZHUKOVA	{"phone": "+70379656729"}
0005432424203	B852DE	2245 666181	VALENTINA AFANASEVA	{"email": "afanaseva_valentina-011989@postgrespro.ru", "phone": "+70133878099"}
0005432424204	B852DE	5079 726598	VIKTOR MELNIKOV	{"email": "melnikov.viktor-071964@postgrespro.ru", "phone": "+70527139983"}
0005432424205	A087A2	4837 307217	SVETLANA IVANOVA	{"phone": "+70862859193"}
0005432424206	A547CE	2791 489369	ANASTASIYA ANDREEVA	{"phone": "+70778737660"}
0005432424207	81DEC9	8810 221532	LYUBOV ILINA	{"phone": "+70159010762"}
0005432424208	85BB00	5950 053389	DMITRIY GORBUNOV	{"phone": "+70180963614"}
0005432424209	FE2115	5784 578094	LYUBOV BELYAEVA	{"email": "belyaeva.l.10051973@postgrespro.ru", "phone": "+70196326413"}
0005432424210	FE2115	3836 093712	GRIGORIY IVANOV	{"phone": "+70197150026"}
0005432424211	8520A4	6468 660758	ALEKSANDRA ABRAMOVA	{"email": "aleksandra-abramova-22021966@postgrespro.ru", "phone": "+70338619317"}
0005432424212	8520A4	7226 240129	OKSANA IVANOVA	{"phone": "+70254359189"}
0005432424213	47C299	8071 982921	ALEVTINA NAZAROVA	{"email": "nazarova_alevtina05031969@postgrespro.ru", "phone": "+70557396765"}
0005432424214	47C299	6545 220978	VASILIY ANTONOV	{"email": "antonov_v-27071973@postgrespro.ru", "phone": "+70234416547"}
0005432424215	EFFAD2	3800 442321	ALEKSANDR DMITRIEV	{"phone": "+70437033506"}
0005432424216	EFFAD2	3254 991370	NIKOLAY DMITRIEV	{"phone": "+70155218806"}
0005432424217	FA1083	3947 867681	ANASTASIYA ILINA	{"phone": "+70934883635"}
0005432424218	BC86E1	4116 908401	OLGA KUZMINA	{"phone": "+70596796298"}
0005432424219	BC86E1	3710 686037	GALINA NOVIKOVA	{"phone": "+70454125652"}
0005432424220	146938	5550 687066	DENIS ZAYCEV	{"email": "denis_zaycev-061965@postgrespro.ru", "phone": "+70453525235"}
0005432424221	146938	2388 110190	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova_15101970@postgrespro.ru", "phone": "+70648332155"}
0005432424222	37AF03	6165 476321	ALLA ZHUKOVA	{"email": "zhukova.a_1970@postgrespro.ru", "phone": "+70925461709"}
0005432424223	EA7F56	4175 384727	ALIYA ZAYCEVA	{"phone": "+70146894317"}
0005432424224	EA7F56	4956 006995	VALENTINA MIRONOVA	{"email": "valentina-mironova.01111966@postgrespro.ru", "phone": "+70612420793"}
0005432424225	4010F9	6430 545777	ELIZAVETA SEMENOVA	{"email": "semenova_elizaveta-1982@postgrespro.ru", "phone": "+70338783903"}
0005432424226	153728	4015 821436	NATALYA GUSEVA	{"email": "gusevan_031968@postgrespro.ru", "phone": "+70483122959"}
0005432424227	153728	7721 792623	EVGENIY GRIGOREV	{"phone": "+70871669796"}
0005432424228	3F3E0E	5920 793353	ANNA NIKOLAEVA	{"phone": "+70558677931"}
0005432424229	1AD720	2433 342155	VLADIMIR SIDOROV	{"email": "v-sidorov-091975@postgrespro.ru", "phone": "+70456260656"}
0005432424230	1AD720	9196 212410	ALEKSEY MIRONOV	{"email": "amironov-1968@postgrespro.ru", "phone": "+70345008055"}
0005432424231	E92A12	5186 722355	ROMAN PETROV	{"email": "petrovr071967@postgrespro.ru", "phone": "+70476378200"}
0005432424232	385C88	2507 186165	EGOR SOLOVEV	{"phone": "+70090401053"}
0005432424233	97D26A	9188 724558	ARSENIY ANDREEV	{"phone": "+70830034950"}
0005432424234	97D26A	0056 118355	ANNA KONOVALOVA	{"email": "konovalova_a.13041977@postgrespro.ru", "phone": "+70690851388"}
0005432424235	64F78F	1459 783491	VLADIMIR RODIONOV	{"email": "rodionov-v-1969@postgrespro.ru", "phone": "+70055277302"}
0005432424236	64F78F	6497 855087	ALEKSEY ZAYCEV	{"email": "zaycev.a_1987@postgrespro.ru", "phone": "+70887132392"}
0005432424237	BB8E5D	8556 437523	ANNA AFANASEVA	{"email": "afanaseva.anna-1967@postgrespro.ru", "phone": "+70295640138"}
0005432424238	BB8E5D	0478 236920	ZOYA ABRAMOVA	{"email": "abramova-z_121977@postgrespro.ru", "phone": "+70589850887"}
0005432424239	5CEC9D	6118 996360	VLADIMIR MOISEEV	{"phone": "+70140712323"}
0005432424240	F0F10A	1383 370636	NELYA TARASOVA	{"email": "n.tarasova.111954@postgrespro.ru", "phone": "+70313179503"}
0005432424241	302BC1	5332 034456	DMITRIY IVANOV	{"phone": "+70222038715"}
0005432424242	6A5CEB	3832 659324	EVGENIYA BOGDANOVA	{"phone": "+70561522810"}
0005432424243	C7AEB3	0267 497352	ELENA TARASOVA	{"email": "tarasova_elena-1973@postgrespro.ru", "phone": "+70303091212"}
0005432424244	14F7A9	5278 052424	MAKSIM FILIPPOV	{"email": "filippov-m-1965@postgrespro.ru", "phone": "+70884098802"}
0005432424245	E74495	7515 088543	OLGA SCHERBAKOVA	{"phone": "+70538956460"}
0005432424246	E74495	9827 426290	OLGA NOVIKOVA	{"email": "novikova_olga011966@postgrespro.ru", "phone": "+70095781211"}
0005432424247	1189C4	5572 019658	TAMARA SOKOLOVA	{"email": "sokolova_t_011972@postgrespro.ru", "phone": "+70796403409"}
0005432424248	54BD57	2146 506669	SERGEY FROLOV	{"email": "sergey-frolov1964@postgrespro.ru", "phone": "+70529507157"}
0005432424249	73C53D	0497 427235	NADEZHDA TIKHONOVA	{"phone": "+70862383796"}
0005432424250	73C53D	5657 345799	ALEKSANDR EGOROV	{"email": "aleksandr-egorov_1967@postgrespro.ru", "phone": "+70444858495"}
0005432424251	647D8E	4078 805321	ELZA ISAEVA	{"email": "e.isaeva061969@postgrespro.ru", "phone": "+70549696184"}
0005432424252	01FA39	8760 708664	SVETLANA GUSEVA	{"email": "s-guseva031972@postgrespro.ru", "phone": "+70141665907"}
0005432424253	533A4A	1638 101949	GALIYA LAZAREVA	{"email": "galiyalazareva.1959@postgrespro.ru", "phone": "+70695752403"}
0005432424254	A6653F	0153 478643	EKATERINA ZAKHAROVA	{"email": "zakharova.e_1957@postgrespro.ru", "phone": "+70606423976"}
0005432424255	A3C38F	2777 765113	KAMILA BORISOVA	{"phone": "+70607024834"}
0005432424258	CE8619	4941 732672	LYUBOV FROLOVA	{"phone": "+70926465825"}
0005432424259	332D53	6888 263498	ANASTASIYA IVANOVA	{"email": "anastasiya-ivanova-071967@postgrespro.ru", "phone": "+70890945533"}
0005432424260	332D53	3209 898865	EKATERINA KUZNECOVA	{"phone": "+70167139565"}
0005432424261	77B4F3	6256 797567	ALEKSANDRA KARPOVA	{"phone": "+70832914660"}
0005432424262	FF9763	3181 367698	LYUBOV ANTONOVA	{"email": "antonova.l.1978@postgrespro.ru", "phone": "+70725593887"}
0005432424263	FF9763	1433 857734	ANATOLIY NIKOLAEV	{"email": "nikolaev-a.15061981@postgrespro.ru", "phone": "+70483736210"}
0005432424264	341E9B	6353 791525	ANDREY ALEKSANDROV	{"email": "aleksandrov.a-1985@postgrespro.ru", "phone": "+70472913192"}
0005432424265	341E9B	4804 858056	VASILIY ZHUKOV	{"phone": "+70717477782"}
0005432424266	D77318	9411 753912	RIMMA KARPOVA	{"email": "r_karpova-13071974@postgrespro.ru", "phone": "+70781845430"}
0005432424267	0B76D1	0389 099744	ALEKSEY NOVIKOV	{"phone": "+70244363045"}
0005432424268	185C41	1655 511483	RUSLAN ANTONOV	{"phone": "+70498711704"}
0005432424269	94C870	0499 129827	ELENA GERASIMOVA	{"email": "elenagerasimova-1957@postgrespro.ru", "phone": "+70569096166"}
0005432424270	94C870	4939 879797	VIKTOR ABRAMOV	{"phone": "+70328361573"}
0005432424271	94C870	1923 348833	ALEKSANDR GUSEV	{"phone": "+70040402152"}
0005432424272	10BA61	9604 292536	MIKHAIL POPOV	{"phone": "+70394569154"}
0005432424273	6C70E3	7259 871372	DENIS PAVLOV	{"phone": "+70492044273"}
0005432424274	6C70E3	2679 415112	OLEG PAVLOV	{"email": "opavlov_28121969@postgrespro.ru", "phone": "+70457307249"}
0005432424275	6C70E3	0571 034266	MARINA GERASIMOVA	{"phone": "+70081417142"}
0005432424276	C9ED33	9627 684244	DANIYA NOVIKOVA	{"email": "novikova.d_1975@postgrespro.ru", "phone": "+70875734691"}
0005432424277	66F26C	6744 691329	ANDREY FILIPPOV	{"email": "filippov_andrey01091975@postgrespro.ru", "phone": "+70396349633"}
0005432424278	0DC746	0943 233018	ANATOLIY OSIPOV	{"phone": "+70203668461"}
0005432424279	CF64BE	4963 642560	SERGEY POPOV	{"email": "s_popov.1968@postgrespro.ru", "phone": "+70317703957"}
0005432424280	CF64BE	0498 148850	SVETLANA ZAKHAROVA	{"phone": "+70781197925"}
0005432424281	D85316	7943 356915	TATYANA IVANOVA	{"email": "ivanovat011979@postgrespro.ru", "phone": "+70445531913"}
0005432424282	E05351	3941 810969	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr.16121975@postgrespro.ru", "phone": "+70431290970"}
0005432424283	E05351	0841 731774	MIKHAIL ZAYCEV	{"phone": "+70938756851"}
0005432424284	0687D8	2327 782701	ALBINA ISAEVA	{"phone": "+70609034294"}
0005432424285	0E96D4	7049 482211	RAISA KAZAKOVA	{"phone": "+70741592589"}
0005432424286	5EBF86	1024 873631	SERGEY DAVYDOV	{"email": "sergey.davydov_1979@postgrespro.ru", "phone": "+70648918095"}
0005432424287	3B918F	9835 417156	VLADIMIR PAVLOV	{"phone": "+70261639063"}
0005432424288	3B918F	0730 621147	DANIIL STEPANOV	{"phone": "+70853811722"}
0005432424289	17784B	0952 212806	LYUDMILA KUDRYASHOVA	{"email": "lyudmila_kudryashova.081969@postgrespro.ru", "phone": "+70919450675"}
0005432424290	17784B	9028 636455	ROMAN NIKOLAEV	{"email": "r.nikolaev-1984@postgrespro.ru", "phone": "+70115805481"}
0005432424291	5A1EF2	5504 606681	MARINA SOKOLOVA	{"email": "sokolovamarina1971@postgrespro.ru", "phone": "+70512556592"}
0005432424292	D0C247	2674 766715	MARIYA ROMANOVA	{"phone": "+70866954225"}
0005432424293	07AC0F	9843 313123	RASHIT KUZNECOV	{"email": "rashit-kuznecov-09051983@postgrespro.ru", "phone": "+70932735397"}
0005432424294	07AC0F	8717 071794	MARIYA KISELEVA	{"email": "kiselevamariya.10051974@postgrespro.ru", "phone": "+70954186272"}
0005432424295	499F3C	1035 679630	ALEKSANDR EGOROV	{"email": "egorovaleksandr_121971@postgrespro.ru", "phone": "+70079210500"}
0005432424296	499F3C	5473 881769	ANGELINA OSIPOVA	{"email": "angelina_osipova.1978@postgrespro.ru", "phone": "+70889462761"}
0005432424297	CDC371	0547 354100	ELENA KUDRYASHOVA	{"phone": "+70259764669"}
0005432424298	E5B6F0	1636 540137	ANTONINA MIKHAYLOVA	{"phone": "+70079252919"}
0005432424299	A17366	8549 488201	NINA STEPANOVA	{"email": "stepanova-n1968@postgrespro.ru", "phone": "+70887817810"}
0005432424300	A17366	6402 248685	RAIL CHERNOV	{"email": "railchernov-02041972@postgrespro.ru", "phone": "+70709480010"}
0005432424301	D15B72	0425 288889	VADIM IVANOV	{"email": "vadim.ivanov.021976@postgrespro.ru", "phone": "+70340176909"}
0005432424302	D15B72	2455 992924	NIKOLAY MAKSIMOV	{"phone": "+70353563369"}
0005432424303	F6080E	8740 097929	TAISIYA MOROZOVA	{"phone": "+70244323402"}
0005432424304	F369E4	2151 979567	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.12121975@postgrespro.ru", "phone": "+70391353456"}
0005432424305	2298FD	7502 880568	NADEZHDA OSIPOVA	{"phone": "+70606152414"}
0005432424306	3B54B0	6625 270828	LYUBOV KARPOVA	{"email": "karpova_l1965@postgrespro.ru", "phone": "+70692272635"}
0005432424307	3B54B0	4783 285435	VLADIMIR IVANOV	{"email": "vivanov_12121970@postgrespro.ru", "phone": "+70289290138"}
0005432424308	BC4A39	7850 785254	VLADIMIR NOVIKOV	{"phone": "+70124977276"}
0005432424309	451C61	6413 711765	EVGENIYA VOLKOVA	{"email": "evgeniya-volkova.20041979@postgrespro.ru", "phone": "+70070629753"}
0005432424310	738014	9710 844041	SOFIYA VOLKOVA	{"email": "sofiyavolkova1987@postgrespro.ru", "phone": "+70947303884"}
0005432424311	BAED62	4855 348677	VITALIY YAKOVLEV	{"phone": "+70703038877"}
0005432424312	7A66E4	9129 255397	RAISA KUZNECOVA	{"phone": "+70419333660"}
0005432424313	7C2A52	9012 530793	VALENTINA IVANOVA	{"email": "ivanovav.18041962@postgrespro.ru", "phone": "+70299891237"}
0005432424314	EE9AD4	2033 620517	ARTEM SOLOVEV	{"phone": "+70153855111"}
0005432424315	D56366	5094 488533	RINAT GORBUNOV	{"email": "gorbunov-rinat_1960@postgrespro.ru", "phone": "+70985000306"}
0005432424316	07BA6F	8913 865776	LYUDMILA KUZNECOVA	{"phone": "+70007521954"}
0005432424317	1A6BAE	3353 960068	ALEKSANDR GUSEV	{"email": "aleksandrgusev27041971@postgrespro.ru", "phone": "+70674922361"}
0005432424318	98CD00	5464 281792	VERONIKA IVANOVA	{"phone": "+70332307184"}
0005432424319	A1034C	2336 761765	VERA ANISIMOVA	{"email": "anisimova-v_1986@postgrespro.ru", "phone": "+70126769685"}
0005432424320	1200E2	1090 154929	ANDREY KOZLOV	{"email": "kozlova091970@postgrespro.ru", "phone": "+70813493711"}
0005432424321	41B9C1	9189 276445	ALEKSANDR VOROBEV	{"email": "a_vorobev_1978@postgrespro.ru", "phone": "+70041131332"}
0005432424322	41B9C1	2675 197194	LYUDMILA POPOVA	{"phone": "+70083853233"}
0005432424323	E3443F	8939 735266	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov.031969@postgrespro.ru", "phone": "+70792430827"}
0005432424324	616C40	6539 790676	EVGENIY ILIN	{"email": "ilin.e_1980@postgrespro.ru", "phone": "+70472369621"}
0005432424325	616C40	1279 215990	VALENTINA MAKAROVA	{"phone": "+70325513525"}
0005432424326	AE5E98	0278 960898	SVETLANA TIKHONOVA	{"phone": "+70119352867"}
0005432424327	AE5E98	1058 700768	ALISHER GRIGOREV	{"phone": "+70515810179"}
0005432424328	4677AB	7399 967285	ANDREY FOMIN	{"phone": "+70838788703"}
0005432424329	AF87E7	1712 445977	OLGA MOISEEVA	{"phone": "+70978814417"}
0005432424330	DA3D90	3621 246925	OLGA SERGEEVA	{"phone": "+70829402954"}
0005432424331	DCF9C1	0078 652761	ALEKSANDR SOLOVEV	{"phone": "+70557222176"}
0005432424332	8695AA	8345 221567	VALERIY KUZNECOV	{"email": "kuznecovv-1963@postgrespro.ru", "phone": "+70053588914"}
0005432424333	F74C52	9629 477614	ANDREY OSIPOV	{"phone": "+70756311364"}
0005432424334	F5B6F5	1167 717512	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey011972@postgrespro.ru", "phone": "+70356683316"}
0005432424335	113A40	1608 848307	VIOLETTA KRASNOVA	{"email": "v.krasnova-031970@postgrespro.ru", "phone": "+70074213381"}
0005432424336	1126F2	5281 490922	ALEKSANDRA PAVLOVA	{"email": "apavlova-09061971@postgrespro.ru", "phone": "+70376182055"}
0005432424337	1126F2	9479 423236	IVAN ZAYCEV	{"email": "zaycev_i.07011971@postgrespro.ru", "phone": "+70265072997"}
0005432424338	4D32F7	7626 050435	MAKSIM SHEVCHENKO	{"phone": "+70527225166"}
0005432424339	3CA927	1806 866988	TATYANA ROMANOVA	{"phone": "+70032929067"}
0005432424340	E37C1D	5417 547256	IRINA SIDOROVA	{"email": "irina.sidorova_01021973@postgrespro.ru", "phone": "+70586149226"}
0005432424341	F976AE	0645 062476	OLGA ZOTOVA	{"phone": "+70379149019"}
0005432424342	F976AE	6053 503304	GRIGORIY KUZNECOV	{"phone": "+70953147812"}
0005432424343	A3AC0C	8269 974119	NADEZHDA ZOTOVA	{"phone": "+70035406588"}
0005432424344	1A6F66	8052 374260	ALEKSANDR NIKOLAEV	{"phone": "+70419699122"}
0005432424345	E9DD9D	6494 627271	TATYANA NAUMOVA	{"phone": "+70726039777"}
0005432424346	23BE8E	0892 590710	NATALYA POTAPOVA	{"phone": "+70806262618"}
0005432424347	23BE8E	2634 612067	LARISA ORLOVA	{"email": "orlova_larisa-1969@postgrespro.ru", "phone": "+70806472129"}
0005432424348	4FE5D0	4295 349585	AMINA KOROLEVA	{"phone": "+70087071952"}
0005432424349	968D47	1313 894581	GALINA MOROZOVA	{"email": "g-morozova-1983@postgrespro.ru", "phone": "+70833560539"}
0005432424350	5A2BDA	0045 895751	YURIY GUSEV	{"email": "y-gusev.061978@postgrespro.ru", "phone": "+70638321193"}
0005432424351	F0E9E3	3210 359875	EVGENIYA KUZNECOVA	{"phone": "+70220217048"}
0005432424352	F4F178	8557 031583	ELENA VOROBEVA	{"phone": "+70759050784"}
0005432424353	F4F178	1793 749194	ANNA GUSEVA	{"phone": "+70410846058"}
0005432424354	69CFB4	8227 272290	NINA DMITRIEVA	{"email": "dmitrievanina.13031982@postgrespro.ru", "phone": "+70357965977"}
0005432424355	7A7A1F	9003 697845	FEDOR MAKAROV	{"phone": "+70267662019"}
0005432424356	50C91D	0980 860817	NINA PAVLOVA	{"phone": "+70529832011"}
0005432424357	FB30C0	3791 792055	YULIYA MIRONOVA	{"email": "y.mironova08091975@postgrespro.ru", "phone": "+70959910701"}
0005432424358	FB30C0	9648 928802	MIKHAIL MAKAROV	{"phone": "+70064179508"}
0005432424359	33902F	0138 880314	ELENA FEDOROVA	{"email": "elena.fedorova-1979@postgrespro.ru", "phone": "+70089003782"}
0005432424360	E45FD1	0551 543375	ALEKSEY BARANOV	{"email": "aleksey-baranov-1974@postgrespro.ru", "phone": "+70611280965"}
0005432424361	A85E41	9882 883318	LYUDMILA TROFIMOVA	{"email": "trofimova-lyudmila.111966@postgrespro.ru", "phone": "+70236925965"}
0005432424362	73411C	1942 233983	LIDIYA ALEKSEEVA	{"email": "lidiyaalekseeva22061968@postgrespro.ru", "phone": "+70543150772"}
0005432424363	73411C	5593 163921	NATALYA NIKITINA	{"phone": "+70137706890"}
0005432424364	62DDF3	4347 835102	LARISA VASILEVA	{"phone": "+70834103464"}
0005432424365	CD9153	0015 067098	YURIY KUZNECOV	{"email": "kuznecov_yuriy-13011976@postgrespro.ru", "phone": "+70171644231"}
0005432424366	CE5364	6586 102736	DANIIL YAKOVLEV	{"email": "yakovlev_d_1970@postgrespro.ru", "phone": "+70225522405"}
0005432424367	5E6AAC	4773 756238	GENNADIY KULIKOV	{"phone": "+70753867841"}
0005432424368	5E6AAC	9846 439726	PETR KRASNOV	{"email": "petrkrasnov_1981@postgrespro.ru", "phone": "+70626528152"}
0005432424369	5E6AAC	7577 719784	ELENA POPOVA	{"email": "popova.e_1972@postgrespro.ru", "phone": "+70895183336"}
0005432424370	8EAA4A	7778 720724	LYUDMILA FILATOVA	{"phone": "+70731639978"}
0005432424371	6763FC	3523 344643	OLGA MOISEEVA	{"phone": "+70035438285"}
0005432424372	D09F7C	4306 833012	DAMIR KUZNECOV	{"email": "kuznecovdamir021980@postgrespro.ru", "phone": "+70711130580"}
0005432424373	D09F7C	6799 986502	ANNA DENISOVA	{"phone": "+70710722586"}
0005432424374	E8AFC8	5689 562299	ELENA NAZAROVA	{"email": "nazarova_elena051978@postgrespro.ru", "phone": "+70609041531"}
0005432424375	E8AFC8	2699 109054	SERGEY ANDREEV	{"email": "andreev_sergey_121979@postgrespro.ru", "phone": "+70569192081"}
0005432424376	B3D985	5538 015917	ELDAR STEPANOV	{"email": "e.stepanov1968@postgrespro.ru", "phone": "+70446230738"}
0005432424377	B3D985	2033 021249	MARIYA MEDVEDEVA	{"phone": "+70751393833"}
0005432424378	99A4B6	3503 636298	NINA NOVIKOVA	{"email": "n_novikova1969@postgrespro.ru", "phone": "+70711093039"}
0005432424379	99A4B6	5203 107778	OLGA KUZNECOVA	{"phone": "+70828553003"}
0005432424380	40F542	6123 616530	ALEKSANDR MEDVEDEV	{"email": "medvedeva-1977@postgrespro.ru", "phone": "+70999455361"}
0005432424381	204FB7	6453 590899	YURIY ZAYCEV	{"phone": "+70242772601"}
0005432424382	204FB7	8334 205119	VALENTIN ZAYCEV	{"email": "zaycev-valentin16101963@postgrespro.ru", "phone": "+70577712136"}
0005432424383	E9A0E2	4452 295545	VALENTINA KUZNECOVA	{"email": "kuznecova_v_1972@postgrespro.ru", "phone": "+70762672278"}
0005432424384	A82BFF	5910 094172	ALBERT TARASOV	{"email": "a.tarasov101974@postgrespro.ru", "phone": "+70418736858"}
0005432424385	CE7688	3940 999771	ALEKSANDR ZHURAVLEV	{"phone": "+70557012594"}
0005432424386	604760	5681 754683	YURIY ZAYCEV	{"phone": "+70361133901"}
0005432424387	745A6E	7335 346820	VYACHESLAV VLASOV	{"email": "vlasov-vyacheslav.031972@postgrespro.ru", "phone": "+70347534147"}
0005432424388	17002C	5511 773023	NATALIYA DENISOVA	{"phone": "+70210989556"}
0005432424389	17002C	2421 832739	NIKOLAY PETROV	{"phone": "+70210891023"}
0005432424390	9C9006	4572 130542	MARGARITA YAKOVLEVA	{"phone": "+70662226956"}
0005432424391	9C9006	5552 190314	NADEZHDA FILIPPOVA	{"phone": "+70636515565"}
0005432424392	C22B53	0057 705063	SERGEY POPOV	{"phone": "+70460164349"}
0005432424393	10702E	4120 001651	ANNA MARTYNOVA	{"email": "martynova-a.051969@postgrespro.ru", "phone": "+70542036660"}
0005432424394	F7C448	0721 030977	GALINA SEMENOVA	{"email": "g.semenova-121971@postgrespro.ru", "phone": "+70467647737"}
0005432424395	F7C448	1289 880696	NINA POPOVA	{"email": "nina_popova-10071970@postgrespro.ru", "phone": "+70460042036"}
0005432424396	2E124B	5834 216474	YULIYA NIKOLAEVA	{"email": "nikolaeva.y_1963@postgrespro.ru", "phone": "+70148486824"}
0005432424397	751B64	2011 647995	VIKTOR KULIKOV	{"email": "viktor.kulikov-07091974@postgrespro.ru", "phone": "+70646428751"}
0005432424398	751B64	9326 594144	KSENIYA VOLKOVA	{"email": "k-volkova1967@postgrespro.ru", "phone": "+70380601116"}
0005432424399	449F36	7804 645504	VLADISLAV VLASOV	{"email": "vlasov.vladislav.1961@postgrespro.ru", "phone": "+70533792767"}
0005432424400	85A081	9040 125993	ANTONINA ZAKHAROVA	{"email": "antonina_zakharova-1964@postgrespro.ru", "phone": "+70196121415"}
0005432424401	B8B314	7589 055895	TAMARA KONOVALOVA	{"phone": "+70278190527"}
0005432424402	B8B314	4352 943464	VALERIYA VOLKOVA	{"phone": "+70521689822"}
0005432424403	86EE63	0630 210904	KSENIYA ALEKSANDROVA	{"email": "kaleksandrova-1976@postgrespro.ru", "phone": "+70215209644"}
0005432424404	86EE63	6300 465378	NIKITA FOMIN	{"email": "nfomin111961@postgrespro.ru", "phone": "+70153001779"}
0005432424405	48B9F6	8203 399972	TATYANA GERASIMOVA	{"phone": "+70331945795"}
0005432424406	48B9F6	1085 565075	VLADIMIR IVANOV	{"email": "v.ivanov.22071966@postgrespro.ru", "phone": "+70871971079"}
0005432424407	829218	2833 192736	SVETLANA KOLESNIKOVA	{"email": "svetlanakolesnikova-31071983@postgrespro.ru", "phone": "+70116872697"}
0005432424408	92E971	0364 128270	ALEKSANDRA ZAKHAROVA	{"email": "aleksandra-zakharova_061983@postgrespro.ru", "phone": "+70011432116"}
0005432424409	92E971	6559 136330	VLADIMIR IVANOV	{"email": "vladimir.ivanov_121966@postgrespro.ru", "phone": "+70859176607"}
0005432424702	8B11F5	9136 483666	SEMEN FEDOROV	{"phone": "+70891248998"}
0005432424410	33EA83	8779 086061	GALINA MOROZOVA	{"email": "morozova_galina_1981@postgrespro.ru", "phone": "+70046346902"}
0005432424411	33EA83	3509 550512	VITALIY DENISOV	{"email": "denisov.vitaliy.20101961@postgrespro.ru", "phone": "+70890840285"}
0005432424412	9B509D	9207 147263	VASILIY GORBUNOV	{"email": "v_gorbunov_18021966@postgrespro.ru", "phone": "+70263214009"}
0005432424413	6D3DD5	7338 168568	ANNA MIKHAYLOVA	{"email": "amikhaylova-14051974@postgrespro.ru", "phone": "+70814173548"}
0005432424414	3070A8	8673 955870	SVETLANA KUZMINA	{"email": "kuzmina-svetlana_1961@postgrespro.ru", "phone": "+70546092545"}
0005432424415	3070A8	7211 392674	OKSANA SIDOROVA	{"phone": "+70429690318"}
0005432424416	ABA958	6049 999145	GRIGORIY MEDVEDEV	{"email": "medvedev_grigoriy.08051965@postgrespro.ru", "phone": "+70774849542"}
0005432424417	ABA958	8788 883335	OKSANA LUKYANOVA	{"phone": "+70878274639"}
0005432424418	43D6C6	9389 771848	ALENA BORISOVA	{"email": "a_borisova.1972@postgrespro.ru", "phone": "+70955037895"}
0005432424419	9C2B3A	0085 985325	SANIYA LEBEDEVA	{"email": "saniya_lebedeva.1968@postgrespro.ru", "phone": "+70591031038"}
0005432424420	9C2B3A	1193 692500	ALEKSANDRA ALEKSEEVA	{"email": "aleksandra.alekseeva_081981@postgrespro.ru", "phone": "+70752219131"}
0005432424421	9C2B3A	7510 497357	VALENTINA ANDREEVA	{"email": "valentinaandreeva-01111977@postgrespro.ru", "phone": "+70157310590"}
0005432424422	1ABD92	8554 388108	TATYANA KOLESNIKOVA	{"email": "kolesnikova.tatyana_021979@postgrespro.ru", "phone": "+70391126296"}
0005432424423	2BC853	0855 694990	IRINA KOROLEVA	{"email": "irina.koroleva-1976@postgrespro.ru", "phone": "+70948177260"}
0005432424424	A5B7BE	7329 771357	LYUBOV BELYAEVA	{"email": "belyaevalyubov.041974@postgrespro.ru", "phone": "+70841859179"}
0005432424425	A5B7BE	8991 902582	SERGEY KUZNECOV	{"email": "sergey_kuznecov.1967@postgrespro.ru", "phone": "+70591961160"}
0005432424426	6851CB	8535 701101	ANDREY BORISOV	{"email": "andrey.borisov19091963@postgrespro.ru", "phone": "+70964378412"}
0005432424427	9691C6	1726 722877	SERGEY IVANOV	{"phone": "+70824394561"}
0005432424428	509DC4	8508 424865	IVAN NOVIKOV	{"phone": "+70545607977"}
0005432424429	6310E4	6531 787471	VALERIY ORLOV	{"email": "valeriy-orlov.061974@postgrespro.ru", "phone": "+70800064700"}
0005432424430	B035EA	0631 199468	LYUBOV FEDOROVA	{"phone": "+70642653270"}
0005432424431	DCAB73	9406 725826	NATALYA CHERNOVA	{"email": "n.chernova_1970@postgrespro.ru", "phone": "+70633680883"}
0005432424432	500845	6335 151382	YANA ISAEVA	{"phone": "+70512395512"}
0005432424433	85F903	6472 309089	DMITRIY MOROZOV	{"email": "morozovd1964@postgrespro.ru", "phone": "+70589837225"}
0005432424434	1D9603	4448 783300	ZHANNA POPOVA	{"email": "popovaz_12081974@postgrespro.ru", "phone": "+70543336323"}
0005432424435	1D9603	2486 250719	EVGENIY ABRAMOV	{"email": "e-abramov1962@postgrespro.ru", "phone": "+70601137270"}
0005432424436	CB33D4	6934 500894	MARINA KOROLEVA	{"phone": "+70058708881"}
0005432424437	CB33D4	5571 981537	ANNA PETROVA	{"email": "annapetrova.19111974@postgrespro.ru", "phone": "+70081057165"}
0005432424438	17046E	2827 231287	PAVEL IVANOV	{"phone": "+70101640324"}
0005432424439	CCBCA9	8853 341863	MARINA KOZLOVA	{"phone": "+70019966308"}
0005432424440	0409C4	9930 015219	MAKSIM OSIPOV	{"phone": "+70261725337"}
0005432424441	E640F7	6356 977291	VIKTOR MELNIKOV	{"email": "melnikov_v27111973@postgrespro.ru", "phone": "+70696156224"}
0005432424442	E640F7	9515 681505	YURIY NIKITIN	{"email": "yuriy_nikitin_091969@postgrespro.ru", "phone": "+70271050298"}
0005432424443	E640F7	7538 475529	PELAGEYA VOLKOVA	{"email": "pelageya_volkova1979@postgrespro.ru", "phone": "+70626807265"}
0005432424444	CBA716	8629 892731	IRINA ANDREEVA	{"phone": "+70949219336"}
0005432424445	EDD2E0	4661 794381	GALINA VOROBEVA	{"phone": "+70781923965"}
0005432424446	EDD2E0	5083 022133	ALEKSANDR POPOV	{"email": "popov_aleksandr.1956@postgrespro.ru", "phone": "+70723703199"}
0005432424447	F09532	0568 647536	VITALIY GUSEV	{"phone": "+70456155804"}
0005432424448	5B565B	6810 551135	IGOR MATVEEV	{"phone": "+70526914194"}
0005432424449	AE5CAB	2408 716109	ZOYA ZAKHAROVA	{"email": "zakharova.z-21041976@postgrespro.ru", "phone": "+70114243828"}
0005432424450	EF05DF	6961 343318	ANDREY YAKOVLEV	{"email": "a-yakovlev-26081969@postgrespro.ru", "phone": "+70548923786"}
0005432424451	A5F66F	7984 885948	NIKOLAY DAVYDOV	{"phone": "+70647826847"}
0005432424452	4DCB96	2087 713680	LIDIYA FEDOROVA	{"phone": "+70057942190"}
0005432424453	4DCB96	4693 372851	MARINA SOKOLOVA	{"email": "m-sokolova-1973@postgrespro.ru", "phone": "+70461957335"}
0005432424454	29F3D1	3463 671184	EVGENIYA DANILOVA	{"phone": "+70626275587"}
0005432424455	380B53	1507 294320	SOFYA EGOROVA	{"email": "sofya_egorova1978@postgrespro.ru", "phone": "+70693464496"}
0005432424456	6AD536	6911 905790	RAISA ANTONOVA	{"phone": "+70683161104"}
0005432424457	00467E	4298 780671	DENIS VOROBEV	{"email": "vorobevdenis.021970@postgrespro.ru", "phone": "+70339842161"}
0005432424458	00467E	9527 540089	IVAN VASILEV	{"phone": "+70192806169"}
0005432424459	E18CE6	3817 335070	KONSTANTIN ZHURAVLEV	{"email": "konstantin-zhuravlev02081981@postgrespro.ru", "phone": "+70724637210"}
0005432424460	A99C7B	4574 239034	NIKITA MOROZOV	{"email": "morozovnikita_1976@postgrespro.ru", "phone": "+70704381492"}
0005432424461	0CC474	3161 706778	ANASTASIYA PAVLOVA	{"phone": "+70321378963"}
0005432424462	DE662D	6753 528926	VALENTINA KONOVALOVA	{"phone": "+70595149545"}
0005432424463	056F01	9025 159720	OLGA OSIPOVA	{"email": "olga.osipova1969@postgrespro.ru", "phone": "+70011400567"}
0005432424464	0BCB29	4265 944486	ALEKSANDRA ANISIMOVA	{"email": "aleksandraanisimova-1983@postgrespro.ru", "phone": "+70793037166"}
0005432424465	0BCB29	6018 230175	VLADIMIR DENISOV	{"phone": "+70836771308"}
0005432424466	F0BE0F	5539 117010	ANDREY GORBUNOV	{"email": "a-gorbunov.091974@postgrespro.ru", "phone": "+70018948338"}
0005432424467	9772C3	1496 372658	DENIS VOLKOV	{"phone": "+70675562216"}
0005432424937	89034F	5602 343671	NADEZHDA KISELEVA	{"phone": "+70724837545"}
0005432424468	9FED80	7705 180173	RAISA MAKSIMOVA	{"email": "r-maksimova-111977@postgrespro.ru", "phone": "+70555736610"}
0005432424469	12001D	6948 359859	SERGEY MARTYNOV	{"email": "martynov_sergey-1973@postgrespro.ru", "phone": "+70805418025"}
0005432424470	12001D	5418 633720	KARINA MIRONOVA	{"email": "mironovak-27111968@postgrespro.ru", "phone": "+70431926673"}
0005432424471	12001D	3413 716298	ELENA SEMENOVA	{"phone": "+70026851128"}
0005432424472	346779	8434 263641	NADEZHDA KOZLOVA	{"phone": "+70776919516"}
0005432424473	58E2E6	5570 555792	ALEKSEY GRIGOREV	{"phone": "+70575129689"}
0005432424474	58E2E6	7295 037258	EGOR KUZMIN	{"email": "egor_kuzmin.09021967@postgrespro.ru", "phone": "+70251686581"}
0005432424475	1A2843	6340 210319	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-1971@postgrespro.ru", "phone": "+70989000851"}
0005432424476	1A2843	6952 463084	ANASTASIYA PAVLOVA	{"email": "anastasiya_pavlova08071980@postgrespro.ru", "phone": "+70587410418"}
0005432424477	35BEA4	0567 948752	EKATERINA VLASOVA	{"phone": "+70916367411"}
0005432424478	35BEA4	2266 443444	MARIYA KAZAKOVA	{"phone": "+70950907023"}
0005432424479	B75B07	0963 937510	NATALYA MIRONOVA	{"email": "natalya-mironova_1963@postgrespro.ru", "phone": "+70001558811"}
0005432424480	726362	2882 718485	NIKOLAY KUZNECOV	{"email": "n.kuznecov.091973@postgrespro.ru", "phone": "+70219387381"}
0005432424481	142456	9482 737961	LYUBOV KOZLOVA	{"phone": "+70643552452"}
0005432424482	0AB798	4717 288451	ANNA DMITRIEVA	{"email": "a.dmitrieva-24011980@postgrespro.ru", "phone": "+70361487434"}
0005432424483	B5E39D	3620 158650	ALEKSANDR TIKHONOV	{"email": "aleksandr_tikhonov.09051969@postgrespro.ru", "phone": "+70010315591"}
0005432424484	B5E39D	9801 855383	RUSLAN ZAKHAROV	{"phone": "+70384837746"}
0005432424485	A13649	4139 403127	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova.15101976@postgrespro.ru", "phone": "+70508631219"}
0005432424486	A13649	6834 829943	ELENA VOROBEVA	{"phone": "+70919574442"}
0005432424487	5DF500	3505 608179	VIKTOR KARPOV	{"phone": "+70323000559"}
0005432424488	6905B0	9322 322354	VLADIMIR SIDOROV	{"email": "sidorov-v-02071986@postgrespro.ru", "phone": "+70515227888"}
0005432424489	CADCD4	8360 028938	TATYANA NOVIKOVA	{"phone": "+70475057959"}
0005432424490	F987B1	3624 596640	VLADISLAV NIKITIN	{"email": "v.nikitin.08051970@postgrespro.ru", "phone": "+70079011568"}
0005432424491	8C3891	7566 330011	ALEKSEY SEMENOV	{"phone": "+70700925338"}
0005432424492	18BC58	3265 917093	VASILIY KARPOV	{"email": "vasiliy_karpov.101972@postgrespro.ru", "phone": "+70955642483"}
0005432424493	18BC58	1670 072311	NATALYA BORISOVA	{"email": "borisova.n-08101972@postgrespro.ru", "phone": "+70150312722"}
0005432424494	A9ECAB	7794 673512	TATYANA LEBEDEVA	{"email": "tatyanalebedeva-29111979@postgrespro.ru", "phone": "+70349270859"}
0005432424495	A9ECAB	0086 945299	LYUDMILA IVANOVA	{"email": "ivanova_l_071977@postgrespro.ru", "phone": "+70777133721"}
0005432424496	4FB7D7	8319 514054	ALEKSANDR POPOV	{"email": "popovaleksandr-1969@postgrespro.ru", "phone": "+70732984461"}
0005432424497	C45B1E	2601 006193	MAKSIM KULIKOV	{"email": "m.kulikov.1978@postgrespro.ru", "phone": "+70223566054"}
0005432424498	A08F50	9789 501221	VIKTOR KRASNOV	{"email": "krasnov.viktor.101967@postgrespro.ru", "phone": "+70474692183"}
0005432424499	A08F50	1805 840351	LYUBOV NESTEROVA	{"email": "l.nesterova_031977@postgrespro.ru", "phone": "+70756220147"}
0005432424500	DD4651	1649 795742	NIKOLAY KUZMIN	{"phone": "+70811254214"}
0005432424501	DD4651	6921 745292	SVETLANA MOROZOVA	{"phone": "+70357657284"}
0005432424502	80C3A1	7991 857535	ANNA SEMENOVA	{"email": "annasemenova1964@postgrespro.ru", "phone": "+70819760482"}
0005432424503	80C3A1	7243 551012	TAMARA KONOVALOVA	{"email": "t-konovalova_021984@postgrespro.ru", "phone": "+70780139449"}
0005432424504	3C659C	9758 581722	IVAN BONDARENKO	{"email": "bondarenko-i05011964@postgrespro.ru", "phone": "+70912181852"}
0005432424505	9EAD2F	8095 514431	OLGA KOZLOVA	{"email": "kozlovaolga-14031963@postgrespro.ru", "phone": "+70796194699"}
0005432424506	9EAD2F	3451 348738	ANTONINA FILATOVA	{"email": "antonina.filatova051983@postgrespro.ru", "phone": "+70371297502"}
0005432424507	9EAD2F	6913 357117	VALERIY KARPOV	{"email": "karpovv_071974@postgrespro.ru", "phone": "+70541631517"}
0005432424508	B0BE82	3335 140875	SERGEY GERASIMOV	{"email": "gerasimov.s_1972@postgrespro.ru", "phone": "+70792397949"}
0005432424509	B0BE82	1504 172828	ALEKSANDRA IVANOVA	{"phone": "+70488160900"}
0005432424510	FD070F	7339 675807	EKATERINA SMIRNOVA	{"phone": "+70001020513"}
0005432424511	C4BA49	9735 486158	VLADIMIR KULIKOV	{"email": "kulikov-v_05041983@postgrespro.ru", "phone": "+70310819648"}
0005432424512	CBAB39	0435 330330	SERGEY NOVIKOV	{"phone": "+70589024270"}
0005432424513	175AD6	1205 589730	ZHANNA AFANASEVA	{"email": "afanaseva_zhanna_1988@postgrespro.ru", "phone": "+70276692223"}
0005432424514	DEA925	8774 110398	NINA ORLOVA	{"phone": "+70200058783"}
0005432424515	7F2175	7532 137049	IRINA FEDOROVA	{"email": "ifedorova.24021971@postgrespro.ru", "phone": "+70543309777"}
0005432424516	9ABA56	9847 035909	ALEKSANDR KOZLOV	{"phone": "+70031848060"}
0005432424517	E7167E	3816 222489	LYUDMILA KUZMINA	{"email": "kuzminalyudmila.101965@postgrespro.ru", "phone": "+70588160220"}
0005432424518	E7167E	8526 890485	RUSTAM IVANOV	{"email": "rustamivanov01061972@postgrespro.ru", "phone": "+70116302414"}
0005432424519	6E9D60	7278 186675	SOFIYA PETROVA	{"email": "petrova-s25101972@postgrespro.ru", "phone": "+70806514893"}
0005432424520	9EB648	5882 349342	YURIY NOVIKOV	{"phone": "+70471351128"}
0005432424521	56F6A7	2098 326018	RINAT OSIPOV	{"phone": "+70679694811"}
0005432424522	56F6A7	8311 172264	VYACHESLAV MOISEEV	{"phone": "+70372221393"}
0005432424523	4B538B	4845 027851	GALINA SEMENOVA	{"phone": "+70704581107"}
0005432424524	AEB986	0390 271436	VIKTOR STEPANOV	{"phone": "+70072089657"}
0005432424525	695A27	1742 338120	LYUDMILA YAKOVLEVA	{"email": "yakovleva-lyudmila.05121967@postgrespro.ru", "phone": "+70455664954"}
0005432424526	695A27	7174 508240	ANTONINA MOISEEVA	{"email": "moiseeva-a-21091974@postgrespro.ru", "phone": "+70869594366"}
0005432424527	95EE99	5673 475554	ALEKSANDR GRIGOREV	{"phone": "+70411299058"}
0005432424528	95EE99	5177 561019	NIKOLAY KRASNOV	{"phone": "+70351026629"}
0005432424529	F4EFF7	1288 906040	EKATERINA MOISEEVA	{"phone": "+70028103323"}
0005432424530	76CD60	4307 006323	TAMARA GERASIMOVA	{"email": "tgerasimova.18081963@postgrespro.ru", "phone": "+70436982820"}
0005432424531	1D2AE6	1409 034520	RUSTEM FROLOV	{"phone": "+70824879729"}
0005432424532	1D2AE6	8743 063931	YULIYA SOROKINA	{"email": "y-sorokina-1968@postgrespro.ru", "phone": "+70765948498"}
0005432424533	1D2AE6	8747 613760	DARYA KUZMINA	{"phone": "+70062940531"}
0005432424534	4954CB	6411 723177	NIKOLAY CHERNOV	{"phone": "+70305999901"}
0005432424535	EB4899	4280 482787	DMITRIY SMIRNOV	{"email": "smirnov_d_1975@postgrespro.ru", "phone": "+70046539168"}
0005432424536	F05CAE	6370 844168	ALENA POPOVA	{"email": "popovaa1970@postgrespro.ru", "phone": "+70857943062"}
0005432424537	B4C11F	1976 697198	VALERIY TARASOV	{"email": "vtarasov.081967@postgrespro.ru", "phone": "+70086069322"}
0005432424538	735860	1541 121543	DENIS CHERNOV	{"email": "chernov-denis.091969@postgrespro.ru", "phone": "+70083964188"}
0005432424539	B6E153	8123 922420	VIKTORIYA MOISEEVA	{"email": "vmoiseeva121971@postgrespro.ru", "phone": "+70722906932"}
0005432424540	BABF53	6239 630398	TAMARA ANTONOVA	{"phone": "+70414409252"}
0005432424541	E36584	5171 423055	ELENA MATVEEVA	{"email": "e_matveeva1970@postgrespro.ru", "phone": "+70212498492"}
0005432424542	E36584	1676 420553	GALINA MAKAROVA	{"phone": "+70916375440"}
0005432424543	CC75CA	3893 089506	ALEKSANDR CHERNOV	{"email": "chernov-a.15081974@postgrespro.ru", "phone": "+70773092309"}
0005432424544	E30AD4	2112 449442	ANNA KUDRYASHOVA	{"phone": "+70953750776"}
0005432424545	9F99AA	7902 314563	NIKOLAY MAKAROV	{"email": "n_makarov111976@postgrespro.ru", "phone": "+70833666330"}
0005432424546	9F99AA	4139 652001	YURIY BELOV	{"email": "yuriy-belov.26061973@postgrespro.ru", "phone": "+70276043382"}
0005432424547	9F99AA	1663 472086	BOGDAN VASILEV	{"phone": "+70328259639"}
0005432424548	370060	6377 260759	VADIM ISAEV	{"email": "isaev_vadim-04061967@postgrespro.ru", "phone": "+70798898594"}
0005432424549	370060	1686 639970	VLADIMIR VLASOV	{"email": "vlasov-vladimir07021981@postgrespro.ru", "phone": "+70787064014"}
0005432424550	0BAD05	8132 656723	SEMEN NOVIKOV	{"email": "novikovsemen21071976@postgrespro.ru", "phone": "+70486974986"}
0005432424551	ED8B61	2235 426613	STANISLAV ROMANOV	{"email": "s-romanov_101974@postgrespro.ru", "phone": "+70392643860"}
0005432424552	D1DBC3	7559 873200	MAKSIM ABRAMOV	{"email": "m-abramov-1967@postgrespro.ru", "phone": "+70392927465"}
0005432424553	C65A67	4142 250448	DMITRIY TARASOV	{"email": "tarasov-d1966@postgrespro.ru", "phone": "+70318720105"}
0005432424554	31142E	9648 308034	KAMIL ORLOV	{"email": "kamilorlov-1973@postgrespro.ru", "phone": "+70017776402"}
0005432424555	A4EF13	7333 445642	NIKOLAY CHERNOV	{"phone": "+70390969500"}
0005432424556	AB52FD	7946 031141	IVAN RODIONOV	{"phone": "+70301832196"}
0005432424557	AB52FD	9180 679535	SERGEY KAZAKOV	{"email": "kazakov-s.13071963@postgrespro.ru", "phone": "+70546301568"}
0005432424558	2E5B73	2146 033824	MARINA PETROVA	{"phone": "+70854387391"}
0005432424559	2E5B73	7635 601259	VERA DANILOVA	{"email": "vera_danilova_041985@postgrespro.ru", "phone": "+70976519938"}
0005432424560	5F9673	8134 852473	EKATERINA ZAKHAROVA	{"email": "zakharova.e21011984@postgrespro.ru", "phone": "+70436829827"}
0005432424561	8BBA8C	3853 699450	RAISA KOZLOVA	{"phone": "+70129604783"}
0005432424562	BEA4ED	3375 744349	YURIY VASILEV	{"phone": "+70906180126"}
0005432424563	4F7A81	1945 399277	MARIYA ANTONOVA	{"email": "antonova.mariya_1978@postgrespro.ru", "phone": "+70213418121"}
0005432424564	4A81BF	6085 166676	NATALYA BORISOVA	{"email": "borisovan-1983@postgrespro.ru", "phone": "+70546475713"}
0005432424565	4A81BF	7191 395015	ALEKSANDR ALEKSEEV	{"phone": "+70683711755"}
0005432424566	ADCACE	8303 913943	OLEG VASILEV	{"email": "o.vasilev_15031975@postgrespro.ru", "phone": "+70565057100"}
0005432424567	ADCACE	9247 912840	GALINA NESTEROVA	{"email": "nesterovagalina_1977@postgrespro.ru", "phone": "+70220089752"}
0005432424568	834BF4	8210 870530	EKATERINA GAVRILOVA	{"email": "gavrilova_ekaterina31101975@postgrespro.ru", "phone": "+70040395645"}
0005432424569	A5A5D8	5807 119843	ANTONINA CHERNOVA	{"phone": "+70194457663"}
0005432424570	A5A5D8	7489 153235	VLADIMIR KOZLOV	{"email": "kozlov-v1968@postgrespro.ru", "phone": "+70952886636"}
0005432424571	0CC008	5483 327184	MAKSIM FILIPPOV	{"email": "maksim-filippov-26101971@postgrespro.ru", "phone": "+70753806132"}
0005432424572	0CC008	4250 212396	ROZA ISAEVA	{"phone": "+70448038351"}
0005432424573	E193E3	3179 992452	NIKOLAY KOZLOV	{"email": "nikolay.kozlov1979@postgrespro.ru", "phone": "+70184529160"}
0005432424574	8C13C2	8585 533465	YURIY ALEKSEEV	{"email": "y.alekseev-081973@postgrespro.ru", "phone": "+70377468537"}
0005432424575	2495EC	3094 307582	LARISA PAVLOVA	{"email": "larisa.pavlova.1970@postgrespro.ru", "phone": "+70984091070"}
0005432424576	7108FA	2960 751493	VIKTORIYA SIDOROVA	{"phone": "+70895844502"}
0005432424577	E9AC6C	4875 813449	GALINA ANTONOVA	{"phone": "+70404678937"}
0005432424578	E9AC6C	5889 299560	VLADIMIR MIRONOV	{"email": "vladimir.mironov1967@postgrespro.ru", "phone": "+70219082892"}
0005432424579	53B267	8830 122888	NATALYA SOROKINA	{"email": "sorokina-n.1979@postgrespro.ru", "phone": "+70942199638"}
0005432424580	53B267	3243 509139	ALEKSANDR ANTONOV	{"phone": "+70921910551"}
0005432424581	C50BC2	1854 726666	VALENTINA ROMANOVA	{"email": "vromanova-111968@postgrespro.ru", "phone": "+70486305801"}
0005432424582	9D75F2	5767 219004	VALENTINA PETROVA	{"phone": "+70668402695"}
0005432424583	9D75F2	3214 258362	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov1982@postgrespro.ru", "phone": "+70626405214"}
0005432424584	C063F6	8056 721025	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev_1968@postgrespro.ru", "phone": "+70503731393"}
0005432424585	7B076E	8998 928905	ANNA MIKHAYLOVA	{"email": "mikhaylovaa.091977@postgrespro.ru", "phone": "+70108536838"}
0005432424586	987F71	5512 156840	TATYANA NESTEROVA	{"email": "nesterova.t_1966@postgrespro.ru", "phone": "+70354793077"}
0005432424587	983E76	0182 626275	ZULFIYA KOLESNIKOVA	{"phone": "+70721343335"}
0005432424588	F251DC	6585 897120	ANASTASIYA NIKITINA	{"phone": "+70715278212"}
0005432424589	917BC8	9676 759068	TATYANA KULIKOVA	{"email": "t-kulikova13101971@postgrespro.ru", "phone": "+70120624114"}
0005432424590	E18475	6080 882248	EKATERINA FROLOVA	{"phone": "+70743875845"}
0005432424591	6DB6ED	5866 910783	GALINA NOVIKOVA	{"email": "novikovag.05051979@postgrespro.ru", "phone": "+70156974489"}
0005432424592	22AD20	9126 129173	ALEKSANDR MOROZOV	{"email": "morozovaleksandr-071964@postgrespro.ru", "phone": "+70046876988"}
0005432424593	076B69	2259 181995	IVAN ZAYCEV	{"email": "i-zaycev.1971@postgrespro.ru", "phone": "+70595784756"}
0005432424594	076B69	6117 026620	VALENTINA POPOVA	{"phone": "+70117818831"}
0005432424595	83BD5D	1841 339931	EVGENIY SEMENOV	{"email": "semenov_evgeniy.1968@postgrespro.ru", "phone": "+70815167837"}
0005432424596	735A22	4143 357799	LYUDMILA NIKITINA	{"email": "nikitina_lyudmila-18011969@postgrespro.ru", "phone": "+70439513239"}
0005432424597	5A2F86	8192 395392	TATYANA MASLOVA	{"phone": "+70820613801"}
0005432424598	5A2F86	8917 917299	IRINA FILIPPOVA	{"email": "filippova.irina.13051977@postgrespro.ru", "phone": "+70963224315"}
0005432424599	5A2F86	9661 002528	ALEKSANDR ORLOV	{"email": "aorlov-1979@postgrespro.ru", "phone": "+70513648619"}
0005432424600	C2221B	0315 619164	ALEKSEY ZHUKOV	{"phone": "+70886091430"}
0005432424601	C2221B	4365 889797	STEPAN KUZNECOV	{"phone": "+70521499595"}
0005432424602	8B8B5F	3104 894318	ALEKSANDRA ZAYCEVA	{"email": "zayceva-a.051982@postgrespro.ru", "phone": "+70984985384"}
0005432424603	71FF3A	7075 100583	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr-1967@postgrespro.ru", "phone": "+70500209515"}
0005432424604	2AE1E9	2765 609265	YURIY KOZLOV	{"phone": "+70294634389"}
0005432424605	1EB946	2456 104393	VIKTOR STEPANOV	{"email": "v_stepanov_071972@postgrespro.ru", "phone": "+70145945211"}
0005432424606	5BC4C7	7777 573083	OLGA ISAEVA	{"email": "isaeva-o_1984@postgrespro.ru", "phone": "+70852064491"}
0005432424607	E74670	9713 435868	IGOR DAVYDOV	{"email": "davydovigor1989@postgrespro.ru", "phone": "+70194706124"}
0005432424608	9FC954	7732 124136	OKSANA MELNIKOVA	{"email": "o_melnikova.041985@postgrespro.ru", "phone": "+70340926690"}
0005432424609	96D8C7	9168 727376	LYUDMILA ILINA	{"phone": "+70757581082"}
0005432424610	7B4BC9	0080 441950	IRINA GERASIMOVA	{"email": "gerasimovairina_24031980@postgrespro.ru", "phone": "+70365796621"}
0005432424611	B36CF9	5487 483823	RUSLAN YAKOVLEV	{"email": "r-yakovlev.29031961@postgrespro.ru", "phone": "+70101332775"}
0005432424612	B36CF9	9559 481316	EKATERINA YAKOVLEVA	{"phone": "+70665159856"}
0005432424613	B612C1	0840 673595	IRINA IVANOVA	{"phone": "+70242490778"}
0005432424614	0775CA	1293 044603	ALEKSANDR AFANASEV	{"phone": "+70073777133"}
0005432424615	964033	2722 648498	GALINA SMIRNOVA	{"email": "g.smirnova.1980@postgrespro.ru", "phone": "+70692791137"}
0005432424616	249885	9470 489853	VIKTORIYA FROLOVA	{"email": "frolova_viktoriya05091968@postgrespro.ru", "phone": "+70654236733"}
0005432424617	4E1551	7224 888690	ALEKSANDR NAZAROV	{"phone": "+70616217705"}
0005432424618	4E1551	1049 011103	DMITRIY SCHERBAKOV	{"email": "dscherbakov_1982@postgrespro.ru", "phone": "+70717582243"}
0005432424619	6CB0CE	1302 505470	MARINA BARANOVA	{"phone": "+70061924967"}
0005432424620	0EE5C0	3466 003183	VSEVOLOD MOROZOV	{"phone": "+70946853749"}
0005432424621	A471DB	7145 225673	ALBINA KUZNECOVA	{"email": "kuznecova-a081964@postgrespro.ru", "phone": "+70074577965"}
0005432424622	BBBB56	6863 977556	TATYANA FILIPPOVA	{"email": "filippovat071981@postgrespro.ru", "phone": "+70277218121"}
0005432424623	AA8803	3760 690518	OKSANA POPOVA	{"phone": "+70973088593"}
0005432424624	DE4856	1900 230246	RAISA SOLOVEVA	{"phone": "+70750421622"}
0005432424625	DE4856	4759 344821	EKATERINA FROLOVA	{"email": "frolova-ekaterina-03081979@postgrespro.ru", "phone": "+70419073818"}
0005432424626	B59D72	3859 632975	NATALYA NESTEROVA	{"email": "natalya-nesterova1967@postgrespro.ru", "phone": "+70392953471"}
0005432424627	B59D72	5590 014470	PAVEL STEPANOV	{"phone": "+70536974485"}
0005432424628	918A7B	3598 384380	VLADIMIR ALEKSEEV	{"email": "alekseev.v_02111963@postgrespro.ru", "phone": "+70208339876"}
0005432424629	62EBDA	0723 463887	PETR EGOROV	{"phone": "+70819638904"}
0005432424630	62EBDA	5817 438169	SERGEY KULIKOV	{"email": "kulikov.sergey1974@postgrespro.ru", "phone": "+70852373837"}
0005432424631	42EDA9	7917 635846	ALEKSANDR FROLOV	{"email": "frolov-aleksandr17061969@postgrespro.ru", "phone": "+70846309585"}
0005432424632	42EDA9	0691 549181	OKSANA FEDOROVA	{"email": "o_fedorova-101957@postgrespro.ru", "phone": "+70528285191"}
0005432424633	5C7740	9180 592790	EDUARD GUSEV	{"email": "eduard-gusev_24031981@postgrespro.ru", "phone": "+70148650943"}
0005432424634	5C7740	4708 460634	PAVEL KUZNECOV	{"phone": "+70503539699"}
0005432424635	5C7740	8786 205338	LIDIYA SEMENOVA	{"phone": "+70928393519"}
0005432424636	9E2D84	8971 248089	GRIGORIY VOROBEV	{"phone": "+70855115086"}
0005432424637	ACC5DC	5162 056829	EVGENIY STEPANOV	{"email": "stepanov-e_22011970@postgrespro.ru", "phone": "+70155983089"}
0005432424638	ACC5DC	6749 545515	EVGENIY KRASNOV	{"email": "krasnove121966@postgrespro.ru", "phone": "+70791236254"}
0005432424639	ACC5DC	8088 524328	MIKHAIL NIKOLAEV	{"phone": "+70139739666"}
0005432424640	D87F90	3328 421540	SERGEY EGOROV	{"phone": "+70114924556"}
0005432424641	EC095F	8300 880682	NIKOLAY MARTYNOV	{"email": "nikolay.martynov_01031968@postgrespro.ru", "phone": "+70233784533"}
0005432424642	EC095F	2541 530609	NADEZHDA TITOVA	{"email": "titova.nadezhda-1972@postgrespro.ru", "phone": "+70987953316"}
0005432424643	078805	8745 004533	LARISA ANTONOVA	{"email": "antonova.larisa.1968@postgrespro.ru", "phone": "+70174631480"}
0005432424644	078805	9107 954621	IGOR BONDARENKO	{"email": "i-bondarenko_111979@postgrespro.ru", "phone": "+70703128718"}
0005432424645	A7ED36	7230 582885	SVETLANA ALEKSANDROVA	{"phone": "+70708827310"}
0005432424646	A7ED36	6326 568593	ALEKSANDR KRASNOV	{"email": "a.krasnov-1970@postgrespro.ru", "phone": "+70455956746"}
0005432424647	6E463B	5309 929130	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov1980@postgrespro.ru", "phone": "+70668403243"}
0005432424648	38A662	5272 766072	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov.1975@postgrespro.ru", "phone": "+70131057287"}
0005432424649	38A662	7930 128392	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov1964@postgrespro.ru", "phone": "+70594675396"}
0005432424650	192007	1037 321998	ANDREY IVANOV	{"phone": "+70797290227"}
0005432424651	6F7EDE	5440 481850	ELENA DANILOVA	{"phone": "+70700907898"}
0005432424652	94BAB8	7497 802165	VERA MOISEEVA	{"email": "vera.moiseeva-111965@postgrespro.ru", "phone": "+70756315402"}
0005432424653	DAECCD	7181 596400	EVGENIY ROMANOV	{"phone": "+70383301074"}
0005432424654	5785AC	8646 598379	EKATERINA KOZLOVA	{"phone": "+70249783860"}
0005432424655	F5B45C	7239 454725	SERGEY MEDVEDEV	{"email": "s-medvedev1981@postgrespro.ru", "phone": "+70004149192"}
0005432424656	F5B45C	6413 810289	ARINA KULIKOVA	{"phone": "+70838593504"}
0005432424657	BBCC78	9828 033325	ANDREY IVANOV	{"email": "ivanov.andrey.071963@postgrespro.ru", "phone": "+70617452576"}
0005432424658	0203BF	6275 483567	IGOR ROMANOV	{"email": "igor_romanov-19031974@postgrespro.ru", "phone": "+70130873981"}
0005432424659	E62E33	6029 097054	OKSANA KOLESNIKOVA	{"email": "kolesnikova-o25031969@postgrespro.ru", "phone": "+70197140725"}
0005432424660	E62E33	8022 642861	MIKHAIL KOZLOV	{"email": "mikhail.kozlov-1977@postgrespro.ru", "phone": "+70977759885"}
0005432424661	DBBC1D	5373 082491	NINA MAKSIMOVA	{"phone": "+70000569549"}
0005432424662	DBBC1D	9415 233074	RINAT CHERNOV	{"email": "rinat_chernov_031969@postgrespro.ru", "phone": "+70450061248"}
0005432424663	8CE76E	5303 524936	ELENA YAKOVLEVA	{"email": "yakovleva-e.061977@postgrespro.ru", "phone": "+70463581994"}
0005432424664	8CE76E	4269 310247	ANNA LAZAREVA	{"email": "lazareva.anna_27051962@postgrespro.ru", "phone": "+70324826108"}
0005432424665	145BE0	9912 384148	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila-1972@postgrespro.ru", "phone": "+70850267093"}
0005432424666	078F5F	5264 271326	NIKOLAY MOISEEV	{"email": "nmoiseev-1965@postgrespro.ru", "phone": "+70849950887"}
0005432424667	2A0FE7	6762 117745	IRINA MIKHAYLOVA	{"phone": "+70125338654"}
0005432424668	6A239A	9499 473683	VYACHESLAV NAZAROV	{"phone": "+70826465096"}
0005432424669	D2C052	7927 101356	DMITRIY GAVRILOV	{"email": "d_gavrilov-02071970@postgrespro.ru", "phone": "+70328511777"}
0005432424670	DD3AE7	7418 290786	OLEG DENISOV	{"phone": "+70842450300"}
0005432424671	87FBD5	7546 449342	ALEKSEY GRIGOREV	{"email": "grigorev_a-21011982@postgrespro.ru", "phone": "+70850071279"}
0005432424672	8D8834	2888 856774	EVGENIYA KUZNECOVA	{"email": "ekuznecova-1978@postgrespro.ru", "phone": "+70410288594"}
0005432424673	E266CD	4532 313744	DMITRIY KUDRYASHOV	{"email": "kudryashov-dmitriy1968@postgrespro.ru", "phone": "+70693931291"}
0005432424674	26FA60	7865 247546	FEDOR SEMENOV	{"email": "f-semenov06071963@postgrespro.ru", "phone": "+70954964707"}
0005432424675	5435E6	2577 984640	DMITRIY MAKAROV	{"phone": "+70533205109"}
0005432424676	DCD1BA	8774 871332	OLGA MATVEEVA	{"email": "olga.matveeva_1979@postgrespro.ru", "phone": "+70877070189"}
0005432424677	DCD1BA	1290 770087	ANDREY POPOV	{"phone": "+70245242713"}
0005432424678	873B56	7444 805986	MARGARITA PETROVA	{"email": "petrova-margarita.1957@postgrespro.ru", "phone": "+70495237468"}
0005432424679	E29D20	7342 724017	VLADISLAV MEDVEDEV	{"email": "medvedevvladislav-1965@postgrespro.ru", "phone": "+70820331323"}
0005432424680	77ABB6	5088 746048	GALINA IVANOVA	{"phone": "+70001298089"}
0005432424681	0653B5	4414 096999	TATYANA ZHUKOVA	{"email": "zhukova.t.1971@postgrespro.ru", "phone": "+70946783002"}
0005432424682	57A4DA	7767 363617	ELENA LUKYANOVA	{"email": "e-lukyanova05121974@postgrespro.ru", "phone": "+70370212035"}
0005432424683	CBA310	4441 577234	ANTONINA SAVELEVA	{"email": "savelevaantonina_12061967@postgrespro.ru", "phone": "+70076559023"}
0005432424684	DA3241	6060 844351	SERGEY VOROBEV	{"email": "sergey_vorobev061975@postgrespro.ru", "phone": "+70825968212"}
0005432424685	DA3241	0725 769997	NIKITA ANTONOV	{"phone": "+70322846754"}
0005432424686	2CC504	2744 340053	DANILA OSIPOV	{"phone": "+70537604612"}
0005432424687	2CC504	6191 026459	LILIYA EFREMOVA	{"email": "efremova.liliya-1974@postgrespro.ru", "phone": "+70686014231"}
0005432424688	90BAF3	3186 849815	LYUDMILA ISAEVA	{"phone": "+70187507427"}
0005432424689	90BAF3	8911 352809	SULTAN ANDREEV	{"phone": "+70175205881"}
0005432424690	9A6E58	8937 159910	ANNA MASLOVA	{"phone": "+70107150173"}
0005432424691	969FC3	2968 768046	IRINA ILINA	{"phone": "+70939875313"}
0005432424692	7B49E1	8912 884580	IVAN ALEKSEEV	{"email": "ivanalekseev-1967@postgrespro.ru", "phone": "+70243071611"}
0005432424693	29498B	3925 519817	AYRAT VOLKOV	{"email": "volkov_ayrat-28011965@postgrespro.ru", "phone": "+70072087689"}
0005432424694	AA3F67	9428 430444	SERGEY SCHERBAKOV	{"phone": "+70227030041"}
0005432424695	AA3F67	9145 304128	VYACHESLAV MIKHAYLOV	{"email": "vyacheslavmikhaylov.29111980@postgrespro.ru", "phone": "+70496941461"}
0005432424696	4E9503	3248 135440	ALEKSANDR SOROKIN	{"phone": "+70212549739"}
0005432424697	CC34A5	9430 010069	IGOR EGOROV	{"email": "igoregorov.041984@postgrespro.ru", "phone": "+70393984611"}
0005432424698	4768A4	5236 792378	NAILYA POTAPOVA	{"phone": "+70071160371"}
0005432424699	AEF404	5866 463618	VIKTOR FOMIN	{"phone": "+70062979184"}
0005432424700	549DD2	6773 296864	BORIS SERGEEV	{"phone": "+70219032160"}
0005432424701	7A4DD4	9646 965618	OLGA KUZNECOVA	{"phone": "+70959358874"}
0005432424703	E3766A	0815 992661	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev25031970@postgrespro.ru", "phone": "+70311397600"}
0005432424704	5EBA90	3637 485380	VALENTINA SCHERBAKOVA	{"email": "scherbakova.v04061967@postgrespro.ru", "phone": "+70770650343"}
0005432424705	5DCD4A	9000 549190	VADIM POPOV	{"phone": "+70112062807"}
0005432424706	069883	9198 246724	ANTON MATVEEV	{"email": "anton_matveev-09071971@postgrespro.ru", "phone": "+70996570750"}
0005432424707	9C1B3A	7896 503400	ZINAIDA LAZAREVA	{"email": "z.lazareva111964@postgrespro.ru", "phone": "+70531148529"}
0005432424708	9C1B3A	0372 655999	EVGENIY DAVYDOV	{"email": "davydovevgeniy051982@postgrespro.ru", "phone": "+70735166966"}
0005432424709	80B785	9774 097015	NADEZHDA PAVLOVA	{"email": "pavlova.n021971@postgrespro.ru", "phone": "+70309772225"}
0005432424710	21D0D4	8555 659834	ILNUR KISELEV	{"email": "i.kiselev-111977@postgrespro.ru", "phone": "+70284926470"}
0005432424711	71D37C	9143 624601	ANASTASIYA POLYAKOVA	{"email": "polyakova_a24061964@postgrespro.ru", "phone": "+70526355847"}
0005432424712	71D37C	4059 337685	LIDIYA PETROVA	{"email": "l_petrova28011965@postgrespro.ru", "phone": "+70485949713"}
0005432424713	AA3F4A	3643 717522	ALEKSANDR ANDREEV	{"phone": "+70805239109"}
0005432424714	AA3F4A	8246 011205	NADEZHDA POPOVA	{"email": "nadezhdapopova-1973@postgrespro.ru", "phone": "+70742297992"}
0005432424715	AB148F	6135 117293	VASILIY KRASNOV	{"email": "v_krasnov20031964@postgrespro.ru", "phone": "+70432154168"}
0005432424716	6BE07C	0426 417825	ALEKSANDR PAVLOV	{"phone": "+70596623049"}
0005432424717	AC3B3B	7339 772703	SVETLANA GERASIMOVA	{"phone": "+70991037180"}
0005432424718	DC9FDD	2448 532584	NIKOLAY ILIN	{"phone": "+70799931495"}
0005432424719	DC9FDD	9972 924630	LYUDMILA ABRAMOVA	{"email": "abramova.l.01121975@postgrespro.ru", "phone": "+70881371474"}
0005432424720	DC9FDD	8153 281570	VALENTINA ALEKSEEVA	{"phone": "+70697817425"}
0005432424721	9EB7D5	0278 194721	YULIYA ALEKSEEVA	{"phone": "+70122674467"}
0005432424722	9EB7D5	5073 214242	MAKSIM KUDRYASHOV	{"phone": "+70500307289"}
0005432424723	F86A09	7507 127471	TIMUR IVANOV	{"email": "ivanov_t091969@postgrespro.ru", "phone": "+70317490187"}
0005432424724	9363BA	4716 007517	ALEKSEY ZHUKOV	{"phone": "+70006792080"}
0005432424725	0D951C	2969 590653	YULIYA RODIONOVA	{"phone": "+70620745662"}
0005432424726	0D951C	1340 433226	GEORGIY ZAYCEV	{"email": "gzaycev1963@postgrespro.ru", "phone": "+70781861134"}
0005432424727	45031E	1122 570208	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev23121978@postgrespro.ru", "phone": "+70323420694"}
0005432424728	BA3469	4233 654818	VLADISLAV NOVIKOV	{"email": "novikov_vladislav_081976@postgrespro.ru", "phone": "+70300830552"}
0005432424729	1C8EE2	7344 751263	EKATERINA KOLESNIKOVA	{"phone": "+70785998319"}
0005432424730	1C8EE2	6219 316983	ANNA BARANOVA	{"email": "baranova-a_05051975@postgrespro.ru", "phone": "+70445046727"}
0005432424731	1C8EE2	6847 958040	LADA ZAKHAROVA	{"email": "l-zakharova_18101968@postgrespro.ru", "phone": "+70517553579"}
0005432424732	6CA2E5	2047 625834	ALEKSANDR MOROZOV	{"email": "a-morozov_111973@postgrespro.ru", "phone": "+70004375447"}
0005432424733	2D12D0	9164 755912	IRINA GRISHINA	{"phone": "+70071725529"}
0005432424734	1CA2D4	6211 073755	YULIYA FEDOROVA	{"email": "y.fedorova1967@postgrespro.ru", "phone": "+70371756027"}
0005432424735	57EC03	3052 667531	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr.29081975@postgrespro.ru", "phone": "+70491255476"}
0005432424736	57EC03	5147 580529	ANTONINA FILIPPOVA	{"email": "a_filippova17081964@postgrespro.ru", "phone": "+70304025199"}
0005432424737	5CCEFE	5124 689155	SEMEN VASILEV	{"email": "s.vasilev1967@postgrespro.ru", "phone": "+70643650706"}
0005432424738	3D84B6	6579 899575	VLADISLAV KONOVALOV	{"email": "konovalov_vladislav.24091967@postgrespro.ru", "phone": "+70384772106"}
0005432424739	3D84B6	2172 358180	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev03081973@postgrespro.ru", "phone": "+70934497107"}
0005432424740	4B006E	4147 107532	VENIAMIN SIDOROV	{"email": "veniamin-sidorov_1977@postgrespro.ru", "phone": "+70046908922"}
0005432424741	F62946	8641 895012	LIDIYA KAZAKOVA	{"phone": "+70672438805"}
0005432424742	D0E4AC	3346 022538	YULIYA BARANOVA	{"phone": "+70441471181"}
0005432424743	3D10BF	0894 665559	VASILIY MATVEEV	{"phone": "+70429069749"}
0005432424744	C76882	9663 047637	VIKTOR VOLKOV	{"email": "v.volkov-1966@postgrespro.ru", "phone": "+70181859484"}
0005432424745	EE0C78	1658 239824	GALINA AKIMOVA	{"email": "akimova-galina031980@postgrespro.ru", "phone": "+70364724466"}
0005432424746	E7D8C0	4876 432407	ALEKSEY KRASNOV	{"phone": "+70468882647"}
0005432424747	E7D8C0	6927 838489	NIKOLAY FEDOROV	{"phone": "+70649401866"}
0005432424748	A40F6F	1146 416406	TATYANA ILINA	{"email": "ilina.tatyana121982@postgrespro.ru", "phone": "+70772977197"}
0005432424749	A40F6F	0904 489237	IGOR BARANOV	{"phone": "+70888843480"}
0005432424750	A40F6F	1847 074767	ANASTASIYA IVANOVA	{"email": "a-ivanova.031965@postgrespro.ru", "phone": "+70031912463"}
0005432424751	736DFE	0425 618185	ALEKSEY TARASOV	{"phone": "+70675284528"}
0005432424752	736DFE	3398 104994	VASILIY KUZNECOV	{"phone": "+70127419450"}
0005432424753	7D2CFA	6682 966854	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov_21121968@postgrespro.ru", "phone": "+70701153627"}
0005432424754	7D2CFA	6449 361739	MAKSIM YAKOVLEV	{"phone": "+70370908089"}
0005432424755	18FF6C	8840 735678	ELENA SOROKINA	{"phone": "+70874505784"}
0005432424756	1EC017	9885 519150	NINA TIKHONOVA	{"phone": "+70523365066"}
0005432424813	655BCB	1949 931528	OLGA EFREMOVA	{"phone": "+70546050178"}
0005432424757	1EC017	4902 941771	RUSLAN DMITRIEV	{"email": "dmitriev-r101972@postgrespro.ru", "phone": "+70294906609"}
0005432424758	1FFA41	9982 256800	SERGEY SERGEEV	{"email": "sergeev-sergey.011966@postgrespro.ru", "phone": "+70016259338"}
0005432424759	09B0FD	2448 232423	ELENA SMIRNOVA	{"phone": "+70741921288"}
0005432424760	CDB639	1951 405568	ALLA KONOVALOVA	{"email": "alla-konovalova.22091967@postgrespro.ru", "phone": "+70849879627"}
0005432424761	BA91C4	4379 465796	OLGA ROMANOVA	{"email": "romanova-o-05021978@postgrespro.ru", "phone": "+70275914633"}
0005432424762	052E37	0237 343894	VALENTINA NOVIKOVA	{"email": "valentina_novikova.04101981@postgrespro.ru", "phone": "+70339428152"}
0005432424763	4A695B	8649 139757	ANASTASIYA ISAEVA	{"email": "a_isaeva.17031966@postgrespro.ru", "phone": "+70706947593"}
0005432424764	4A695B	6979 973089	LYUBOV SMIRNOVA	{"phone": "+70947062145"}
0005432424765	C3C090	0725 313995	KONSTANTIN FROLOV	{"phone": "+70301895974"}
0005432424766	F4B290	9656 226257	VIKTORIYA TIMOFEEVA	{"phone": "+70469122873"}
0005432424767	F4B290	3145 007682	SERGEY NIKITIN	{"email": "sergey_nikitin1980@postgrespro.ru", "phone": "+70308053688"}
0005432424768	AAC53E	6578 722179	ALEKSANDR STEPANOV	{"phone": "+70412340072"}
0005432424769	AAC53E	6560 459112	NATALYA KAZAKOVA	{"email": "kazakovan_05011967@postgrespro.ru", "phone": "+70903039485"}
0005432424770	111EC5	2917 668576	ELENA KUZNECOVA	{"phone": "+70867384266"}
0005432424771	2CA1B0	9956 662702	ANDREY PAVLOV	{"email": "andrey.pavlov_061963@postgrespro.ru", "phone": "+70304049022"}
0005432424772	AC4536	8532 817790	DMITRIY POPOV	{"email": "dmitriy-popov_1967@postgrespro.ru", "phone": "+70573570582"}
0005432424773	801067	0389 237370	EKATERINA FEDOROVA	{"email": "e_fedorova.1970@postgrespro.ru", "phone": "+70248106913"}
0005432424774	B99C96	3288 807004	OLGA IVANOVA	{"email": "o_ivanova-29031962@postgrespro.ru", "phone": "+70954336865"}
0005432424775	B99C96	5882 448149	ALEKSEY KOZLOV	{"phone": "+70409566136"}
0005432424776	E5E602	0310 712170	LYUDMILA BOGDANOVA	{"phone": "+70745992776"}
0005432424777	E5E602	2773 716629	SVETLANA MIKHAYLOVA	{"email": "mikhaylovasvetlana_111976@postgrespro.ru", "phone": "+70986479704"}
0005432424778	E5E602	0791 401869	NATALYA IVANOVA	{"phone": "+70026356562"}
0005432424779	C1241B	8954 703068	PAVEL VASILEV	{"email": "p-vasilev.1958@postgrespro.ru", "phone": "+70347439026"}
0005432424780	8F32A6	6149 145462	NIKOLAY MOROZOV	{"phone": "+70792805111"}
0005432424781	8F32A6	7096 691138	NIKOLAY SERGEEV	{"phone": "+70909193424"}
0005432424782	8F32A6	4243 510568	MIKHAIL ANDREEV	{"email": "andreev.m1974@postgrespro.ru", "phone": "+70400049077"}
0005432424783	AE132F	8308 293158	VIKTOR BORISOV	{"phone": "+70581065128"}
0005432424784	D83083	9195 838001	VALENTIN PETROV	{"phone": "+70896719832"}
0005432424785	6EB746	2983 164146	DIANA SMIRNOVA	{"phone": "+70969091217"}
0005432424786	6EB746	6848 648376	GALIYA ZAYCEVA	{"phone": "+70816168810"}
0005432424787	B00415	8265 909299	NATALIYA TIMOFEEVA	{"phone": "+70980550377"}
0005432424788	D293BD	2226 188938	SERGEY SCHERBAKOV	{"phone": "+70551830485"}
0005432424789	D293BD	8071 270022	SERGEY KOROLEV	{"phone": "+70355496081"}
0005432424790	8B4C81	7929 839479	LARISA EGOROVA	{"email": "egorova-larisa_1969@postgrespro.ru", "phone": "+70271196820"}
0005432424791	8B4C81	4030 881407	VALENTINA KUDRYASHOVA	{"phone": "+70865393573"}
0005432424792	A07286	3993 029532	KRISTINA MEDVEDEVA	{"email": "kmedvedeva30051963@postgrespro.ru", "phone": "+70234147990"}
0005432424793	49A9E5	9145 805986	FARIDA LUKYANOVA	{"email": "farida_lukyanova-19121970@postgrespro.ru", "phone": "+70485896946"}
0005432424794	2F43C0	7843 288697	NIKOLAY MIRONOV	{"email": "mironov_n_071977@postgrespro.ru", "phone": "+70888925378"}
0005432424795	EEC2B0	9468 700778	ELIZAVETA PETROVA	{"phone": "+70024918319"}
0005432424796	312E7B	7565 155999	DMITRIY MAKAROV	{"email": "makarov-d_1976@postgrespro.ru", "phone": "+70269953297"}
0005432424797	C4689A	3924 297920	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov_031976@postgrespro.ru", "phone": "+70594041328"}
0005432424798	5E99F5	0092 210842	NATALYA MARTYNOVA	{"email": "martynova-n091980@postgrespro.ru", "phone": "+70228621849"}
0005432424799	76AED4	8281 874950	LIDIYA GORBUNOVA	{"email": "gorbunova.l.14071962@postgrespro.ru", "phone": "+70489191191"}
0005432424800	76AED4	2244 691783	YULIYA KOROLEVA	{"phone": "+70685984139"}
0005432424801	7AB54D	4741 004276	LARISA TIMOFEEVA	{"email": "l-timofeeva-051981@postgrespro.ru", "phone": "+70582661108"}
0005432424802	81778E	9518 308175	YULIYA ZAYCEVA	{"email": "yuliya_zayceva_1984@postgrespro.ru", "phone": "+70948610386"}
0005432424803	81778E	5931 564591	DMITRIY ILIN	{"email": "d_ilin-1964@postgrespro.ru", "phone": "+70091832693"}
0005432424804	6697EA	4842 480678	VLADIMIR FEDOROV	{"phone": "+70527515253"}
0005432424805	6697EA	4008 815485	KLAVDIYA SEMENOVA	{"phone": "+70480667819"}
0005432424806	1D4FF4	7158 247934	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev.1976@postgrespro.ru", "phone": "+70677916193"}
0005432424807	48531B	1183 633908	LYUBOV FEDOROVA	{"email": "lyubov_fedorova1972@postgrespro.ru", "phone": "+70561662425"}
0005432424808	FDBDF6	7786 639446	SVETLANA SEMENOVA	{"phone": "+70449438017"}
0005432424809	9A9CB6	8151 050066	MIKHAIL ROMANOV	{"email": "m-romanov_1977@postgrespro.ru", "phone": "+70615541644"}
0005432424810	9A9CB6	9326 747588	NATALYA ZAKHAROVA	{"phone": "+70557298435"}
0005432424811	9A9CB6	1947 132158	ANNA EGOROVA	{"email": "aegorova03031967@postgrespro.ru", "phone": "+70368917893"}
0005432424812	62D196	0912 704247	ELENA SOROKINA	{"phone": "+70665623348"}
0005432424814	8E32CA	0701 603837	VLADISLAV GAVRILOV	{"phone": "+70579679880"}
0005432424815	0861CC	2199 004546	ANNA VLASOVA	{"email": "vlasovaanna.1970@postgrespro.ru", "phone": "+70749083387"}
0005432424816	A48727	3857 440892	MIKHAIL KISELEV	{"email": "mkiselev.051973@postgrespro.ru", "phone": "+70184336722"}
0005432424817	A48727	4011 534876	ALEKSANDR KULIKOV	{"email": "kulikova10091971@postgrespro.ru", "phone": "+70529425442"}
0005432424818	4A275B	3630 856681	TATYANA POPOVA	{"email": "tatyana-popova.051974@postgrespro.ru", "phone": "+70843543768"}
0005432424819	1FF8DE	2659 092325	VALENTINA AFANASEVA	{"phone": "+70692567180"}
0005432424820	1FF8DE	8192 919057	ALEKSEY BARANOV	{"email": "baranov_aleksey_05011970@postgrespro.ru", "phone": "+70504929525"}
0005432424821	BA457F	7289 742520	TATYANA FOMINA	{"phone": "+70361791748"}
0005432424822	053306	8136 793375	ALEKSANDR ALEKSANDROV	{"email": "a_aleksandrov-021973@postgrespro.ru", "phone": "+70704936123"}
0005432424823	13219D	7718 252272	NADEZHDA KULIKOVA	{"phone": "+70077776513"}
0005432424824	24A8FC	2946 955133	ALEKSANDR FILIPPOV	{"email": "filippov.a_03121967@postgrespro.ru", "phone": "+70874741266"}
0005432424825	24A8FC	6948 536188	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr.31071981@postgrespro.ru", "phone": "+70424007488"}
0005432424826	F33BF8	5134 988362	LYUBOV MELNIKOVA	{"email": "lyubov_melnikova1968@postgrespro.ru", "phone": "+70806548164"}
0005432424827	F33BF8	1654 732961	LIDIYA FEDOROVA	{"phone": "+70890080590"}
0005432424828	5F44AC	1517 691525	DMITRIY MELNIKOV	{"phone": "+70356625624"}
0005432424829	330F78	8635 002063	LILIYA TARASOVA	{"email": "tarasova-l_111970@postgrespro.ru", "phone": "+70443485164"}
0005432424830	B330A1	2706 943586	SVETLANA FEDOROVA	{"email": "fedorova_svetlana.09091968@postgrespro.ru", "phone": "+70476794053"}
0005432424831	9BEB33	1662 379450	EVGENIY ISAEV	{"email": "evgeniy_isaev.1968@postgrespro.ru", "phone": "+70103985632"}
0005432424832	9BEB33	5948 989764	IRINA SERGEEVA	{"email": "sergeevairina-26031977@postgrespro.ru", "phone": "+70959223248"}
0005432424833	F78C84	4583 992879	ILYA SCHERBAKOV	{"email": "ilya_scherbakov.041973@postgrespro.ru", "phone": "+70823016611"}
0005432424834	6FDF4C	6708 133799	YURIY NIKOLAEV	{"email": "nikolaev-yuriy.1954@postgrespro.ru", "phone": "+70534405468"}
0005432424835	9FA807	2835 362596	VLADIMIR IVANOV	{"phone": "+70905878264"}
0005432424836	26A848	4608 833414	GALINA KOROLEVA	{"phone": "+70948333640"}
0005432424837	B26FDA	3301 344336	SERGEY SOROKIN	{"email": "sergey.sorokin_041980@postgrespro.ru", "phone": "+70194067019"}
0005432424838	EAE4F1	0456 608972	VLADIMIR SEMENOV	{"phone": "+70377573613"}
0005432424839	EAE4F1	7604 292506	OLGA VOROBEVA	{"email": "vorobeva.olga-23031970@postgrespro.ru", "phone": "+70520798871"}
0005432424840	EE7B50	9407 900779	YURIY MEDVEDEV	{"email": "yuriy-medvedev1978@postgrespro.ru", "phone": "+70132701287"}
0005432424841	EE7B50	0981 266551	RAISA SEMENOVA	{"email": "semenova_raisa.26051962@postgrespro.ru", "phone": "+70309549521"}
0005432424842	064701	4371 472578	NATALYA KOLESNIKOVA	{"phone": "+70539457668"}
0005432424843	763604	3330 323760	ALENA KUDRYASHOVA	{"email": "a.kudryashova_26051978@postgrespro.ru", "phone": "+70513754398"}
0005432424844	763604	1992 277634	MARINA GUSEVA	{"email": "gusevam13121968@postgrespro.ru", "phone": "+70117104057"}
0005432424845	763604	3089 598355	KLAVDIYA KUZNECOVA	{"email": "kuznecova_klavdiya_101977@postgrespro.ru", "phone": "+70266451143"}
0005432424846	F24A8C	2069 800180	RUSLAN KUZNECOV	{"email": "kuznecov-r.041971@postgrespro.ru", "phone": "+70553162428"}
0005432424847	F24A8C	7072 141409	VLADISLAV ZHUKOV	{"email": "zhukovv091966@postgrespro.ru", "phone": "+70174798597"}
0005432424848	00471D	1464 884380	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov.011965@postgrespro.ru", "phone": "+70673362019"}
0005432424849	CA0B5E	9488 182526	MARIYA DMITRIEVA	{"email": "dmitrievam-111977@postgrespro.ru", "phone": "+70477517310"}
0005432424850	3A4E1A	8741 455464	ZOYA BELOVA	{"email": "z_belova-1966@postgrespro.ru", "phone": "+70307800921"}
0005432424851	C37985	0176 937752	ELENA EGOROVA	{"phone": "+70048397736"}
0005432424852	BAA58D	8203 386187	LYUDMILA KUZMINA	{"phone": "+70840380046"}
0005432424853	DEADDF	9328 989553	VASILIY ABRAMOV	{"email": "abramov-v1980@postgrespro.ru", "phone": "+70867355757"}
0005432424854	C88622	2848 489816	TATYANA POPOVA	{"email": "t-popova08091963@postgrespro.ru", "phone": "+70407353490"}
0005432424855	C88622	3372 152966	DENIS TIKHONOV	{"phone": "+70421884276"}
0005432424856	C88622	1074 680300	DANIL ISAEV	{"email": "danilisaev-1973@postgrespro.ru", "phone": "+70751933771"}
0005432424857	5D5940	6316 902435	KONSTANTIN MEDVEDEV	{"phone": "+70211313913"}
0005432424858	5D5940	7211 184794	IGOR CHERNOV	{"email": "chernovi_021974@postgrespro.ru", "phone": "+70410654328"}
0005432424859	5D5940	5588 594184	ANDREY ANTONOV	{"phone": "+70443471703"}
0005432424860	79E3ED	5218 269380	VERONIKA MOISEEVA	{"email": "vmoiseeva.1967@postgrespro.ru", "phone": "+70796525289"}
0005432424861	212149	9080 683926	SERGEY POPOV	{"phone": "+70704033146"}
0005432424862	F98F82	9485 331923	ELENA FROLOVA	{"phone": "+70865691291"}
0005432424863	BE8AEA	3819 609389	IRINA GUSEVA	{"email": "gusevairina_24041965@postgrespro.ru", "phone": "+70362627321"}
0005432424864	8D6580	1532 575311	IRINA VLASOVA	{"phone": "+70003759634"}
0005432424865	8D6580	8821 416408	MARIYA YAKOVLEVA	{"phone": "+70159985066"}
0005432424866	8D6580	2625 612109	PAVEL MIRONOV	{"phone": "+70779067847"}
0005432424867	8D6580	8264 000154	ZINAIDA FOMINA	{"email": "fomina-zinaida_1974@postgrespro.ru", "phone": "+70774904803"}
0005432424868	2D1FC0	2237 092872	ALEKSANDR NAZAROV	{"phone": "+70182852232"}
0005432424869	9BDE87	1089 017902	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-111976@postgrespro.ru", "phone": "+70817627211"}
0005432424870	03E504	9551 614097	ANNA LUKYANOVA	{"email": "alukyanova1974@postgrespro.ru", "phone": "+70710489381"}
0005432424871	03E504	2027 940872	IVAN DENISOV	{"phone": "+70832359981"}
0005432424872	6DAED6	3784 164146	LYUDMILA STEPANOVA	{"email": "stepanova-lyudmila-071953@postgrespro.ru", "phone": "+70849384922"}
0005432424873	606257	9826 102310	VALENTINA YAKOVLEVA	{"email": "yakovlevav-1975@postgrespro.ru", "phone": "+70195279612"}
0005432424874	606257	2459 312705	EKATERINA MATVEEVA	{"email": "matveeva-ekaterina101971@postgrespro.ru", "phone": "+70933365156"}
0005432424875	BA175A	9127 691789	KSENIYA VOROBEVA	{"phone": "+70703724973"}
0005432424876	BA175A	4966 550296	ANZHELIKA MOROZOVA	{"phone": "+70284865843"}
0005432424877	3BFDF9	9371 941042	SERGEY NIKOLAEV	{"phone": "+70631980048"}
0005432424878	3BFDF9	5358 109255	TATYANA ZAKHAROVA	{"email": "zakharovatatyana-21011980@postgrespro.ru", "phone": "+70638953754"}
0005432424879	EA8F72	7412 634388	ALEKSANDRA ROMANOVA	{"phone": "+70835802266"}
0005432424880	E93806	3413 934317	IVAN GERASIMOV	{"email": "i-gerasimov.27101972@postgrespro.ru", "phone": "+70670209738"}
0005432424881	B0D6E7	0202 339763	ALEKSANDR NIKOLAEV	{"phone": "+70643511615"}
0005432424882	7364B5	9902 294556	ALEKSANDR SERGEEV	{"phone": "+70085855792"}
0005432424883	7364B5	5701 914500	VLADIMIR POPOV	{"email": "popov-v051972@postgrespro.ru", "phone": "+70544390499"}
0005432424884	DE435A	3988 312903	VLADISLAV OSIPOV	{"phone": "+70749960366"}
0005432424885	2ACEE2	1957 243032	FANIYA KRASNOVA	{"email": "krasnovafaniya1962@postgrespro.ru", "phone": "+70328360598"}
0005432424886	D80742	0623 837898	VYACHESLAV PETROV	{"phone": "+70439596564"}
0005432424887	08179E	4636 636050	KRISTINA DANILOVA	{"email": "danilova.kristina051972@postgrespro.ru", "phone": "+70325212276"}
0005432424888	8A6643	9028 494812	NAILYA IVANOVA	{"email": "ivanovan1967@postgrespro.ru", "phone": "+70860138648"}
0005432424889	F56AF2	5763 687466	TATYANA RYABOVA	{"email": "tatyana.ryabova-16111972@postgrespro.ru", "phone": "+70223138109"}
0005432424890	EAC344	5060 601623	ANASTASIYA KOMAROVA	{"email": "anastasiyakomarova07091965@postgrespro.ru", "phone": "+70293104361"}
0005432424891	EAC344	1134 099668	ALEKSANDR YAKOVLEV	{"phone": "+70145006678"}
0005432424892	EAC344	2835 611101	YULIYA KUDRYASHOVA	{"email": "y_kudryashova_081965@postgrespro.ru", "phone": "+70337878384"}
0005432424893	0E7782	6365 055400	LYUDMILA KRASNOVA	{"phone": "+70214338218"}
0005432424894	83EE61	3197 568759	VLADISLAV KRASNOV	{"email": "v_krasnov.1960@postgrespro.ru", "phone": "+70478752804"}
0005432424895	707C24	0719 297230	VALENTINA ZAKHAROVA	{"email": "valentina_zakharova_061977@postgrespro.ru", "phone": "+70923517009"}
0005432424896	BD103B	2566 401855	ANDREY TARASOV	{"email": "tarasov_a.031988@postgrespro.ru", "phone": "+70080387848"}
0005432424897	BD103B	8862 547234	MIKHAIL ALEKSEEV	{"phone": "+70473577272"}
0005432424898	37816F	4016 520871	ALENA LAZAREVA	{"email": "lazareva.alena.051969@postgrespro.ru", "phone": "+70748611827"}
0005432424899	A7D478	8951 104634	ANDREY RODIONOV	{"email": "andrey.rodionov.041968@postgrespro.ru", "phone": "+70466031257"}
0005432424900	7F6271	1327 778710	ANTONINA ISAEVA	{"email": "antonina_isaeva.1968@postgrespro.ru", "phone": "+70379671566"}
0005432424901	F4A36C	2887 151585	TATYANA ROMANOVA	{"email": "romanovat.1974@postgrespro.ru", "phone": "+70254272526"}
0005432424902	F4A36C	9676 420394	ANASTASIYA TROFIMOVA	{"email": "trofimova.a_1986@postgrespro.ru", "phone": "+70287967409"}
0005432424903	F4A36C	0304 086602	ELENA SOKOLOVA	{"phone": "+70791473837"}
0005432424904	B18A5E	9165 793764	NIKOLAY SHEVCHENKO	{"phone": "+70779132427"}
0005432424905	B18A5E	4832 842378	ELENA ANTONOVA	{"email": "e-antonova.071978@postgrespro.ru", "phone": "+70703401974"}
0005432424906	340780	9040 798716	ANTON SOKOLOV	{"email": "sokolov-a_1971@postgrespro.ru", "phone": "+70917254520"}
0005432424907	082125	1018 436610	NATALYA ANDREEVA	{"email": "nandreeva091981@postgrespro.ru", "phone": "+70954807359"}
0005432424908	AB56F9	3741 289216	EVGENIY ILIN	{"email": "ilin.evgeniy_28101963@postgrespro.ru", "phone": "+70719388491"}
0005432424909	AB56F9	0635 430311	ALENA OVCHINNIKOVA	{"email": "alenaovchinnikova15071959@postgrespro.ru", "phone": "+70504770604"}
0005432424910	764580	5240 032999	IRINA ZAYCEVA	{"phone": "+70653801028"}
0005432424911	7B897B	5516 504015	IRINA ZAYCEVA	{"phone": "+70433466428"}
0005432424912	F2A1FD	3999 116410	ALEKSEY DENISOV	{"email": "a_denisov.011972@postgrespro.ru", "phone": "+70352717646"}
0005432424913	83B6AC	6890 915022	NIKOLAY ILIN	{"phone": "+70584350959"}
0005432424914	C0547B	8636 933409	OLGA PAVLOVA	{"phone": "+70954459847"}
0005432424915	89ED7B	2783 461986	SVETLANA TIKHONOVA	{"email": "s-tikhonova.07121974@postgrespro.ru", "phone": "+70910005300"}
0005432424916	89ED7B	5882 255327	ALEKSANDR GRIGOREV	{"phone": "+70801978022"}
0005432424917	CC6B37	4368 007212	LIDIYA NAUMOVA	{"email": "naumova-lidiya1968@postgrespro.ru", "phone": "+70596096042"}
0005432424918	CC6B37	9898 926525	SERGEY SMIRNOV	{"email": "smirnov-sergey.13101976@postgrespro.ru", "phone": "+70230997319"}
0005432424919	D1443F	3145 487373	OLEG KRASNOV	{"email": "krasnov_o_18101975@postgrespro.ru", "phone": "+70177744063"}
0005432424920	28F659	7546 724112	MAKSIM ZAKHAROV	{"email": "zakharov.maksim_101989@postgrespro.ru", "phone": "+70693440989"}
0005432424921	28F659	7684 526526	NIKITA IVANOV	{"email": "ivanov-nikita-25021978@postgrespro.ru", "phone": "+70213860593"}
0005432424922	B783F2	5134 551062	NAZAR ISAEV	{"phone": "+70796945463"}
0005432424923	77F1B5	1521 471522	NINA ANTONOVA	{"email": "n.antonova_24101968@postgrespro.ru", "phone": "+70560980471"}
0005432424924	77F1B5	2502 313648	VITALIY DENISOV	{"phone": "+70346401822"}
0005432424925	793F2D	6935 124010	ELENA SERGEEVA	{"email": "elena.sergeeva011971@postgrespro.ru", "phone": "+70750139530"}
0005432424926	7EEF39	7050 026185	ANDREY OSIPOV	{"phone": "+70051333578"}
0005432424927	20669B	7952 983447	YULIYA ROMANOVA	{"email": "yuliyaromanova.19101982@postgrespro.ru", "phone": "+70648100060"}
0005432424928	778885	1680 560439	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov061961@postgrespro.ru", "phone": "+70716806487"}
0005432424929	778885	6158 494508	VALENTINA SEMENOVA	{"email": "valentina.semenova1963@postgrespro.ru", "phone": "+70694070670"}
0005432424930	5F9169	8308 288443	ANNA NAUMOVA	{"email": "anna.naumova_1979@postgrespro.ru", "phone": "+70122552096"}
0005432424931	95343D	2824 769477	MAKSIM KOZLOV	{"email": "kozlovmaksim121966@postgrespro.ru", "phone": "+70379709048"}
0005432424932	6B324C	1829 497317	TATYANA MAKAROVA	{"phone": "+70687734248"}
0005432424933	7CFDCD	0795 880582	ANNA FROLOVA	{"phone": "+70095015073"}
0005432424934	6F57FB	6182 504573	LYUDMILA EGOROVA	{"email": "lyudmila_egorova.031979@postgrespro.ru", "phone": "+70734327645"}
0005432424935	6F57FB	0337 523194	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin.02121966@postgrespro.ru", "phone": "+70799715017"}
0005432424936	B1396C	0454 477327	EKATERINA ALEKSEEVA	{"phone": "+70852346706"}
0005432424938	89034F	2683 431663	YANA STEPANOVA	{"email": "stepanovay-1972@postgrespro.ru", "phone": "+70486333264"}
0005432424939	026A51	1229 701841	ELEONORA NIKITINA	{"phone": "+70321557658"}
0005432424940	026A51	4245 027641	VARVARA AFANASEVA	{"phone": "+70364808529"}
0005432424941	A1FE04	9489 986067	TATYANA DANILOVA	{"phone": "+70179824522"}
0005432424942	A1FE04	3085 309936	ANASTASIYA SOKOLOVA	{"email": "asokolova_1964@postgrespro.ru", "phone": "+70435221143"}
0005432424943	75E166	4864 432641	DMITRIY DAVYDOV	{"email": "dmitriy-davydov071972@postgrespro.ru", "phone": "+70210349973"}
0005432424944	6E0C21	2390 428803	YURIY KUZNECOV	{"email": "kuznecov-y_1967@postgrespro.ru", "phone": "+70297833627"}
0005432424945	BAF806	2275 927832	ALEKSANDR EGOROV	{"email": "aleksandr.egorov.02021970@postgrespro.ru", "phone": "+70954387046"}
0005432424946	BAF806	5496 764602	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr_1973@postgrespro.ru", "phone": "+70522602659"}
0005432424947	0F7EEE	1183 795708	VIKTOR SMIRNOV	{"email": "viktor.smirnov-1967@postgrespro.ru", "phone": "+70564610778"}
0005432424948	11E643	4718 658646	TATYANA LEBEDEVA	{"email": "tatyana_lebedeva19061968@postgrespro.ru", "phone": "+70104961830"}
0005432424949	631EEC	0220 242277	VALENTINA MELNIKOVA	{"phone": "+70123291389"}
0005432424950	631EEC	8275 146979	NIKOLAY ROMANOV	{"phone": "+70800583243"}
0005432424951	10347E	1376 193826	VLADIMIR SMIRNOV	{"email": "smirnovv_1973@postgrespro.ru", "phone": "+70475800171"}
0005432424952	FF9A8C	8695 087940	NATALYA NESTEROVA	{"email": "nnesterova_051970@postgrespro.ru", "phone": "+70515355832"}
0005432424953	FF9A8C	8480 275080	IRINA ZHUKOVA	{"phone": "+70131343261"}
0005432424954	53F202	9935 732731	VLADIMIR AFANASEV	{"phone": "+70724022299"}
0005432424955	215763	2478 547097	RAMIL FILIPPOV	{"email": "filippovr.11101960@postgrespro.ru", "phone": "+70069766008"}
0005432424956	215763	6917 766105	ANASTASIYA KUZNECOVA	{"phone": "+70543760881"}
0005432424957	70823E	0596 964083	GRIGORIY IVANOV	{"email": "ivanov-g_11081982@postgrespro.ru", "phone": "+70984140549"}
0005432424958	70823E	3353 475512	OLEG KUZNECOV	{"email": "oleg_kuznecov_1966@postgrespro.ru", "phone": "+70524182369"}
0005432424959	70823E	3814 810711	EVGENIY ANTONOV	{"email": "antonov.e1965@postgrespro.ru", "phone": "+70145988929"}
0005432424960	70823E	5925 928600	SERGEY BONDARENKO	{"email": "bondarenko.sergey-04031973@postgrespro.ru", "phone": "+70962070109"}
0005432424961	72CFBA	6990 379836	EGOR RODIONOV	{"phone": "+70992709976"}
0005432424962	74B7CC	8246 956845	TATYANA KUZNECOVA	{"email": "kuznecova-t.081971@postgrespro.ru", "phone": "+70835091300"}
0005432424963	74B7CC	1940 991081	VIKTORIYA OVCHINNIKOVA	{"email": "v_ovchinnikova1981@postgrespro.ru", "phone": "+70897931580"}
0005432424964	F99C00	7767 379194	GRIGORIY ABRAMOV	{"phone": "+70559210699"}
0005432424965	F99C00	0453 066481	IRINA KOROLEVA	{"email": "i_koroleva-06121970@postgrespro.ru", "phone": "+70737112027"}
0005432424966	B5A57F	3896 511985	DMITRIY ZAKHAROV	{"phone": "+70598941895"}
0005432424967	B5A57F	5536 281427	ROMAN PAVLOV	{"phone": "+70575405246"}
0005432424968	7411D1	4293 790562	ANDREY KUZNECOV	{"email": "kuznecov.andrey_06091965@postgrespro.ru", "phone": "+70015260030"}
0005432424969	47D25D	5711 928434	VYACHESLAV DMITRIEV	{"email": "v.dmitriev-1973@postgrespro.ru", "phone": "+70112253973"}
0005432424970	735C92	2053 370341	NIKITA ANTONOV	{"email": "antonov.nikita_051979@postgrespro.ru", "phone": "+70206324701"}
0005432424971	590695	2243 586844	PAVEL IVANOV	{"phone": "+70014015873"}
0005432424972	90A911	5820 211396	ELENA KONOVALOVA	{"email": "e_konovalova1975@postgrespro.ru", "phone": "+70795940094"}
0005432424973	B79BF0	1747 487643	ALEKSANDR PETROV	{"email": "petrov_a1983@postgrespro.ru", "phone": "+70485640326"}
0005432424974	B79BF0	2267 790044	DENIS FROLOV	{"phone": "+70200577563"}
0005432424975	2AE5B0	3348 192931	ANGELINA GRISHINA	{"email": "grishina_a-051971@postgrespro.ru", "phone": "+70706389431"}
0005432424976	556162	3956 464221	ANNA BOGDANOVA	{"email": "bogdanova-a081979@postgrespro.ru", "phone": "+70675692071"}
0005432424977	5BAE13	4676 199668	ANTON ZAKHAROV	{"phone": "+70868678549"}
0005432424978	89B497	4646 068944	EDUARD KUZNECOV	{"email": "eduard.kuznecov.111978@postgrespro.ru", "phone": "+70603217894"}
0005432424979	116A50	8238 809831	VLADIMIR KARPOV	{"email": "karpovvladimir29061977@postgrespro.ru", "phone": "+70107109975"}
0005432424980	7406CF	1997 378354	VLADIMIR PETROV	{"phone": "+70913707547"}
0005432424981	7406CF	4923 066265	NADEZHDA LOGINOVA	{"phone": "+70396762661"}
0005432424982	2C135A	6558 767321	YULIYA IVANOVA	{"email": "y-ivanova11081963@postgrespro.ru", "phone": "+70020388907"}
0005432424983	2FFE12	8192 330767	DAMIR PAVLOV	{"email": "pavlovdamir_1972@postgrespro.ru", "phone": "+70140763453"}
0005432424984	2FFE12	3403 595676	VLADIMIR MAKSIMOV	{"phone": "+70938076490"}
0005432424985	3314AD	0702 190239	NINA MIKHAYLOVA	{"phone": "+70483085769"}
0005432424986	AE0359	3898 128130	SVETLANA STEPANOVA	{"phone": "+70945573123"}
0005432424987	5B8416	6711 921907	VADIM ALEKSANDROV	{"phone": "+70344669051"}
0005432424988	3434CB	3861 076822	VLADIMIR SOROKIN	{"email": "sorokin.v_011972@postgrespro.ru", "phone": "+70730918404"}
0005432424989	E14ADD	5021 523908	LYUBOV KONOVALOVA	{"email": "konovalova-lyubov-12041969@postgrespro.ru", "phone": "+70448851161"}
0005432424990	C0E7FF	5842 718589	TATYANA TARASOVA	{"phone": "+70193248713"}
0005432424991	9AE63F	1128 974491	NINA ANDREEVA	{"phone": "+70597783966"}
0005432424992	9AE63F	6043 747740	TATYANA VOROBEVA	{"email": "t.vorobeva_1962@postgrespro.ru", "phone": "+70389378800"}
0005432424993	763158	2603 717254	ALBERT EGOROV	{"email": "albertegorov.021972@postgrespro.ru", "phone": "+70950882373"}
0005432424994	119BCA	8999 046472	MARIYA KUZNECOVA	{"email": "m-kuznecova_111977@postgrespro.ru", "phone": "+70449649427"}
0005432424995	3DDD7A	3347 819959	ANATOLIY GAVRILOV	{"email": "anatoliygavrilov-04041974@postgrespro.ru", "phone": "+70553416553"}
0005432424996	3DDD7A	2708 683425	YULIYA TROFIMOVA	{"email": "yuliya_trofimova_1974@postgrespro.ru", "phone": "+70260833868"}
0005432424997	3DDD7A	6557 986648	MAYA FEDOROVA	{"phone": "+70120624233"}
0005432424998	0C7F05	3543 661174	ANTON GAVRILOV	{"email": "a_gavrilov_1975@postgrespro.ru", "phone": "+70445669326"}
0005432424999	0C7F05	8257 648289	ALEKSANDR ZAYCEV	{"email": "aleksandrzaycev_01121986@postgrespro.ru", "phone": "+70346037679"}
0005432425000	0C7F05	1828 479860	PAVEL FEDOROV	{"email": "fedorov-pavel1970@postgrespro.ru", "phone": "+70127335355"}
0005432425001	836A00	3586 291325	VIKTOR NIKOLAEV	{"email": "vnikolaev.1971@postgrespro.ru", "phone": "+70468604613"}
0005432425002	836A00	2800 119718	ELENA DENISOVA	{"phone": "+70930470848"}
0005432425003	B7789B	1946 768028	TATYANA VOROBEVA	{"phone": "+70829226206"}
0005432425004	72B757	2758 096898	LIDIYA NAZAROVA	{"phone": "+70812740433"}
0005432425005	856375	5198 640341	SVETLANA KULIKOVA	{"phone": "+70119929925"}
0005432425006	32AF55	6013 027569	KONSTANTIN ZAKHAROV	{"phone": "+70583362465"}
0005432425007	32AF55	2396 777563	MAKSIM SHEVCHENKO	{"email": "shevchenko_maksim_1980@postgrespro.ru", "phone": "+70866358057"}
0005432425008	A02E30	2086 979911	ANTON GERASIMOV	{"email": "a-gerasimov051980@postgrespro.ru", "phone": "+70319210880"}
0005432425009	C69FD4	9240 252027	MARAT SHEVCHENKO	{"email": "m.shevchenko_1974@postgrespro.ru", "phone": "+70473054287"}
0005432425010	EBB515	4725 279408	ELENA MIRONOVA	{"email": "elena_mironova_101975@postgrespro.ru", "phone": "+70211174039"}
0005432425011	28BCA3	8453 613676	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir-1977@postgrespro.ru", "phone": "+70927120801"}
0005432425012	28BCA3	2647 643956	NATALYA IVANOVA	{"phone": "+70482452699"}
0005432425013	0605E8	8469 083401	VYACHESLAV ANDREEV	{"phone": "+70469478119"}
0005432425014	42C096	3750 133161	TAMARA NOVIKOVA	{"phone": "+70026241183"}
0005432425015	E9A13B	3291 713759	OLGA ROMANOVA	{"email": "olga-romanova.1980@postgrespro.ru", "phone": "+70431158272"}
0005432425016	3B52D3	5248 700446	ROMAN SOKOLOV	{"email": "roman_sokolov.1964@postgrespro.ru", "phone": "+70078026021"}
0005432425017	3B52D3	4020 689247	ALEKSANDR KUZMIN	{"phone": "+70632261671"}
0005432425018	3B52D3	4747 912875	OLGA ORLOVA	{"email": "olga.orlova.031978@postgrespro.ru", "phone": "+70416467996"}
0005432425019	35E97A	5748 112369	ELENA NIKITINA	{"email": "e-nikitina_071972@postgrespro.ru", "phone": "+70423990493"}
0005432425020	4AD4EA	4692 534590	TATYANA SIDOROVA	{"email": "tatyana.sidorova_1973@postgrespro.ru", "phone": "+70814291688"}
0005432425021	4AD4EA	7060 492314	LIDIYA SOROKINA	{"phone": "+70468803237"}
0005432425022	7CE0E2	1241 957702	VALENTINA IVANOVA	{"email": "valentina-ivanova_01011965@postgrespro.ru", "phone": "+70794242760"}
0005432425023	5348ED	2290 505161	IRINA MASLOVA	{"email": "maslova-i.061974@postgrespro.ru", "phone": "+70443034031"}
0005432425024	E020CD	9364 779419	NIKOLAY SIDOROV	{"phone": "+70654480084"}
0005432425025	1D685B	6664 740553	LILIYA ALEKSEEVA	{"phone": "+70476374854"}
0005432425026	A6F434	6550 714750	ALEKSANDR KUZMIN	{"email": "kuzmin.a-18061969@postgrespro.ru", "phone": "+70227775902"}
0005432425027	DFCAC2	5800 957650	ANDREY KUZNECOV	{"email": "kuznecov_a_12011973@postgrespro.ru", "phone": "+70290474903"}
0005432425028	645974	3357 777924	LIDIYA ILINA	{"phone": "+70724274336"}
0005432425029	7C31E4	6694 559448	SERGEY VASILEV	{"email": "sergeyvasilev_10061979@postgrespro.ru", "phone": "+70872582397"}
0005432425030	7C31E4	3312 546170	GALINA SOROKINA	{"phone": "+70132893249"}
0005432425031	17F553	3921 899398	VALERIYA YUDINA	{"email": "yudina-v1975@postgrespro.ru", "phone": "+70249933816"}
0005432425032	17F553	8010 487579	NATALYA KUZMINA	{"email": "kuzmina.n.091965@postgrespro.ru", "phone": "+70994801971"}
0005432425033	42925C	6202 871000	ZULFIYA NOVIKOVA	{"phone": "+70472749175"}
0005432425034	3E0F45	5482 475945	ANDREY FEDOTOV	{"phone": "+70285367726"}
0005432425035	3E0F45	5770 349235	MARAT IVANOV	{"phone": "+70944615599"}
0005432425036	90E7CE	6593 946063	VLADISLAV TARASOV	{"phone": "+70326523159"}
0005432425037	8F7E22	5545 209371	VLADIMIR MARTYNOV	{"email": "martynov_v1972@postgrespro.ru", "phone": "+70660738241"}
0005432425038	C4D460	3923 888059	ANDREY SOLOVEV	{"phone": "+70182988602"}
0005432425039	C6C21E	5838 284382	NADEZHDA GRISHINA	{"email": "nadezhda.grishina_1967@postgrespro.ru", "phone": "+70642698207"}
0005432425040	534ACD	4991 166098	ALEKSEY PAVLOV	{"phone": "+70166810192"}
0005432425041	E2B6DE	4571 134671	ALEKSANDR VOROBEV	{"email": "vorobev.aleksandr-121964@postgrespro.ru", "phone": "+70017082098"}
0005432425042	D03BAB	0239 795495	MARIYA KUZNECOVA	{"phone": "+70162770896"}
0005432425043	D03BAB	8020 726509	ELENA VASILEVA	{"phone": "+70484349421"}
0005432425044	AD8FFE	0017 429271	NIKOLAY EGOROV	{"phone": "+70360688228"}
0005432425045	79A025	4046 390923	VALENTINA ALEKSEEVA	{"phone": "+70417871889"}
0005432425046	51983C	3814 624001	VIKTOR KUZNECOV	{"phone": "+70829775780"}
0005432425047	51983C	8577 690273	ANATOLIY EGOROV	{"phone": "+70687683397"}
0005432425048	AFB4A8	0450 653158	EVGENIY KONOVALOV	{"phone": "+70249460024"}
0005432425049	0B8EB3	4915 714118	GALINA YAKOVLEVA	{"phone": "+70334379559"}
0005432425050	B0F5D6	4622 912551	ALEKSANDR SEMENOV	{"phone": "+70718428815"}
0005432425051	B0F5D6	9246 473236	ALEKSEY KONOVALOV	{"email": "a-konovalov-18061956@postgrespro.ru", "phone": "+70450541254"}
0005432425052	05D77F	2219 529941	RENAT VOROBEV	{"email": "renatvorobev.121972@postgrespro.ru", "phone": "+70759742637"}
0005432425053	BC4E0D	8461 348431	TATYANA KOZLOVA	{"email": "kozlovatatyana-21011976@postgrespro.ru", "phone": "+70424077598"}
0005432425054	084837	5485 366985	KAMIL ROMANOV	{"phone": "+70147795664"}
0005432425055	084837	8102 414715	OLGA MOROZOVA	{"email": "morozova.olga.081975@postgrespro.ru", "phone": "+70259931744"}
0005432425056	084837	3408 851964	ZOYA KOZLOVA	{"email": "kozlova-zoya_1971@postgrespro.ru", "phone": "+70944514072"}
0005432425057	5D86D0	5340 341442	SERGEY ALEKSEEV	{"email": "s-alekseev_021990@postgrespro.ru", "phone": "+70531145921"}
0005432425058	3D5B16	6282 262020	GALINA NESTEROVA	{"phone": "+70925745115"}
0005432425059	2EAD56	3422 583279	LYUBOV MIKHAYLOVA	{"phone": "+70789159381"}
0005432425060	FC67E0	3996 791446	IVAN BELOV	{"phone": "+70428985702"}
0005432425061	FC67E0	5515 612692	ALEKSANDR IVANOV	{"email": "a.ivanov1978@postgrespro.ru", "phone": "+70988396340"}
0005432425062	84D0B3	5622 342682	VLADIMIR SHEVCHENKO	{"email": "vladimir_shevchenko.05041966@postgrespro.ru", "phone": "+70886578024"}
0005432425063	3C56BC	6005 393727	RAISA IVANOVA	{"email": "raisa_ivanova-1979@postgrespro.ru", "phone": "+70297476268"}
0005432425064	3C56BC	7873 561358	LEONID ZHURAVLEV	{"phone": "+70999750608"}
0005432425065	145426	2213 046416	VALENTINA DANILOVA	{"phone": "+70599607372"}
0005432425066	145426	4047 757205	SERGEY ANDREEV	{"phone": "+70631241528"}
0005432425067	97E318	1366 789406	SERGEY KOROLEV	{"email": "s-korolev_091956@postgrespro.ru", "phone": "+70008502265"}
0005432425068	97E318	4933 421871	OLGA TIMOFEEVA	{"phone": "+70510822222"}
0005432425069	480382	8824 395015	GALINA NIKOLAEVA	{"phone": "+70526272817"}
0005432425070	12F503	8446 173911	KSENIYA MARTYNOVA	{"email": "k_martynova-1967@postgrespro.ru", "phone": "+70746351182"}
0005432425071	53BC09	5962 688836	ALEKSANDR ALEKSEEV	{"phone": "+70671316868"}
0005432425072	2ED7D5	0034 196237	TAMARA SOKOLOVA	{"email": "tamara.sokolova-1972@postgrespro.ru", "phone": "+70863319739"}
0005432425073	27A7D4	0065 415490	EVGENIY PETROV	{"phone": "+70639681659"}
0005432425074	39FC71	9884 157266	POLINA VOLKOVA	{"phone": "+70765526775"}
0005432425075	EAE4C2	1575 833066	MARIYA DANILOVA	{"phone": "+70687881455"}
0005432425076	EBE751	6539 992467	VIKTORIYA ROMANOVA	{"phone": "+70988384378"}
0005432425077	9932DA	2432 107767	ANNA ROMANOVA	{"email": "romanova-anna_031971@postgrespro.ru", "phone": "+70113022460"}
0005432425078	D68926	9051 013447	OLGA VOLKOVA	{"email": "volkovaolga-1960@postgrespro.ru", "phone": "+70911310298"}
0005432425079	0324B4	6096 469030	VLADIMIR KRASNOV	{"email": "v-krasnov02011975@postgrespro.ru", "phone": "+70228887495"}
0005432425080	0324B4	0139 588217	ANNA TROFIMOVA	{"phone": "+70254309795"}
0005432425081	0324B4	7660 846932	ELMIRA DENISOVA	{"email": "denisovae-061981@postgrespro.ru", "phone": "+70953474946"}
0005432425082	32BDE4	6458 803071	SERGEY FROLOV	{"email": "sfrolov_041963@postgrespro.ru", "phone": "+70213051046"}
0005432425083	32BDE4	2057 401903	ALEKSANDR IVANOV	{"email": "aleksandrivanov.031976@postgrespro.ru", "phone": "+70559386692"}
0005432425084	CBDD78	3636 445661	VLADIMIR SERGEEV	{"email": "sergeevv101979@postgrespro.ru", "phone": "+70113958330"}
0005432425085	D54A7F	1038 684837	LYUBOV MELNIKOVA	{"email": "l-melnikova_05101981@postgrespro.ru", "phone": "+70092978841"}
0005432425086	D54A7F	6861 041569	RAMIL SEMENOV	{"email": "semenov-r_05031979@postgrespro.ru", "phone": "+70001037755"}
0005432425087	43C8B8	3636 626653	VLADIMIR SCHERBAKOV	{"phone": "+70528350178"}
0005432425088	1262C0	3427 138077	KARINA KUZNECOVA	{"phone": "+70587043545"}
0005432425089	424086	8967 426667	VLADIMIR FOMIN	{"phone": "+70671544684"}
0005432425090	37999C	6440 056957	VITALIY PAVLOV	{"phone": "+70697538947"}
0005432425091	37999C	9610 786364	LIDIYA SCHERBAKOVA	{"phone": "+70448897022"}
0005432425092	3C0A1F	5132 745589	OLGA RODIONOVA	{"email": "rodionova.olga.1966@postgrespro.ru", "phone": "+70677434826"}
0005432425093	8A53A9	8176 560094	MARINA KONOVALOVA	{"email": "marinakonovalova1978@postgrespro.ru", "phone": "+70675834304"}
0005432425094	8A53A9	7365 864637	DIANA IVANOVA	{"email": "diana.ivanova-1971@postgrespro.ru", "phone": "+70357589487"}
0005432425095	FED9CB	2033 177687	DMITRIY FEDOROV	{"email": "fedorov-dmitriy.011976@postgrespro.ru", "phone": "+70362905697"}
0005432425096	44947B	6767 167105	VERA POPOVA	{"phone": "+70436507465"}
0005432425097	44947B	7398 217572	OKSANA ILINA	{"email": "oilina-021966@postgrespro.ru", "phone": "+70234981528"}
0005432425098	B06E3B	1544 247310	ALEKSEY KULIKOV	{"email": "alekseykulikov.28111974@postgrespro.ru", "phone": "+70808923425"}
0005432425099	B06E3B	9313 787253	LYUDMILA KUZMINA	{"phone": "+70663061116"}
0005432425100	BB7782	1538 857816	ALEKSANDRA FILIPPOVA	{"phone": "+70548012244"}
0005432425101	BB7782	8334 381196	ARTEM BARANOV	{"email": "baranov.a_28051969@postgrespro.ru", "phone": "+70530803557"}
0005432425102	34E93D	5869 268187	LYUDMILA GUSEVA	{"email": "lyudmila_guseva1971@postgrespro.ru", "phone": "+70030745281"}
0005432425103	202700	5608 596291	DMITRIY CHERNOV	{"phone": "+70761454394"}
0005432425104	202700	8982 467899	ELENA ORLOVA	{"email": "orlovae_1967@postgrespro.ru", "phone": "+70095537197"}
0005432425105	783198	3576 927923	NIKOLAY BONDARENKO	{"phone": "+70244235156"}
0005432425106	728744	3176 941848	SVETLANA KULIKOVA	{"email": "s.kulikova1972@postgrespro.ru", "phone": "+70647323476"}
0005432425107	053686	3896 038676	MARIYA KUZMINA	{"phone": "+70921606779"}
0005432425108	053686	6336 315937	OLGA ZHURAVLEVA	{"phone": "+70020241181"}
0005432425109	053686	2114 874103	PAVEL AFANASEV	{"email": "afanasevpavel.03021961@postgrespro.ru", "phone": "+70745831957"}
0005432425110	BC01D8	1617 472358	EVGENIY KULIKOV	{"email": "evgeniy-kulikov-1969@postgrespro.ru", "phone": "+70238714617"}
0005432425111	568145	7034 632763	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov031960@postgrespro.ru", "phone": "+70249194700"}
0005432425112	D0595A	9369 023158	DARYA DMITRIEVA	{"phone": "+70124087678"}
0005432425113	AD7FB4	5031 550029	ROMAN ANTONOV	{"email": "antonov-roman_1964@postgrespro.ru", "phone": "+70886678661"}
0005432425114	16DEEC	2305 994852	REGINA TROFIMOVA	{"phone": "+70749704517"}
0005432425115	16DEEC	3802 730336	DMITRIY SHEVCHENKO	{"email": "shevchenko.dmitriy071974@postgrespro.ru", "phone": "+70226750277"}
0005432425116	8FF55D	2892 419532	ILYA SMIRNOV	{"phone": "+70398055342"}
0005432425117	8FF55D	2755 658962	VIKTOR KOROLEV	{"email": "korolev_v-031979@postgrespro.ru", "phone": "+70032188081"}
0005432425118	96AB74	5328 355683	ELENA PETROVA	{"email": "epetrova-1975@postgrespro.ru", "phone": "+70398046527"}
0005432425119	727013	1566 379268	EKATERINA ANTONOVA	{"email": "antonova-ekaterina-30111977@postgrespro.ru", "phone": "+70527658082"}
0005432425120	5FB146	8010 701918	GALINA IVANOVA	{"email": "givanova-19101983@postgrespro.ru", "phone": "+70203702797"}
0005432425121	A49B68	6068 610201	KLAVDIYA CHERNOVA	{"email": "klavdiya.chernova-31011966@postgrespro.ru", "phone": "+70703100758"}
0005432425122	A49B68	3820 883125	MARINA KOMAROVA	{"phone": "+70085503280"}
0005432425123	7E7E35	6634 863163	VLADIMIR GAVRILOV	{"email": "v.gavrilov081966@postgrespro.ru", "phone": "+70531555579"}
0005432425124	23170C	6115 250445	VALENTINA DANILOVA	{"phone": "+70160815279"}
0005432425125	28748D	5495 965444	SAMIR KISELEV	{"email": "kiselev-samir.31011976@postgrespro.ru", "phone": "+70229268913"}
0005432425126	577BB4	6310 187979	VLADIMIR ALEKSEEV	{"phone": "+70116353249"}
0005432425127	577BB4	9354 858462	NINA SOKOLOVA	{"email": "sokolova_n051972@postgrespro.ru", "phone": "+70880862423"}
0005432425128	577BB4	9649 162305	NIKOLAY VASILEV	{"email": "n.vasilev.05101973@postgrespro.ru", "phone": "+70521963882"}
0005432425129	2B4B9D	1950 833487	VITALIY MOISEEV	{"email": "vitaliy-moiseev_1969@postgrespro.ru", "phone": "+70743195953"}
0005432425130	CC9763	2143 170554	NINA TITOVA	{"email": "titovan23091964@postgrespro.ru", "phone": "+70209925262"}
0005432425131	2C577E	1783 748053	TATYANA SAVELEVA	{"email": "savelevat061980@postgrespro.ru", "phone": "+70401765074"}
0005432425132	8112AC	1004 548823	TATYANA MASLOVA	{"phone": "+70221292998"}
0005432425133	45B7CB	2968 471482	NIKOLAY KULIKOV	{"email": "n_kulikov30101962@postgrespro.ru", "phone": "+70127737965"}
0005432425134	42F537	6842 110874	ALEKSANDRA ZAKHAROVA	{"phone": "+70052550779"}
0005432425135	80E40C	2628 717741	OLGA MAKAROVA	{"email": "o-makarova-1959@postgrespro.ru", "phone": "+70186643245"}
0005432425136	80E40C	9073 883526	ARTEM PETROV	{"email": "artem.petrov021966@postgrespro.ru", "phone": "+70679938973"}
0005432425137	D25D0C	6819 534560	OLESYA TITOVA	{"phone": "+70272967968"}
0005432425138	221F83	1375 700568	SVETLANA ZHURAVLEVA	{"email": "svetlana-zhuravleva.10071986@postgrespro.ru", "phone": "+70816874972"}
0005432425139	3906C1	6501 219471	MAKSIM FROLOV	{"phone": "+70188837125"}
0005432425140	93E353	5206 550762	NIKOLAY ZAKHAROV	{"email": "zakharov_nikolay081975@postgrespro.ru", "phone": "+70328242950"}
0005432425141	640295	2064 887439	NIKOLAY MAKAROV	{"email": "nmakarov_1971@postgrespro.ru", "phone": "+70377503037"}
0005432425142	AF6FCC	2232 523614	ANNA TITOVA	{"phone": "+70831506809"}
0005432425143	9BB867	3652 897874	RUMIYA IVANOVA	{"email": "ivanovarumiya-03011969@postgrespro.ru", "phone": "+70148928077"}
0005432425144	5A1114	7885 208696	MIKHAIL MAKSIMOV	{"phone": "+70921196542"}
0005432425145	C8ADA7	6642 746975	SHAMIL SERGEEV	{"email": "shamilsergeev-1966@postgrespro.ru", "phone": "+70274126442"}
0005432425146	264554	2245 730407	VALERIY MIKHAYLOV	{"email": "valeriymikhaylov011961@postgrespro.ru", "phone": "+70778045067"}
0005432425147	264554	5501 139147	VLADIMIR VLASOV	{"phone": "+70470397086"}
0005432425148	264554	1195 670085	YURIY NIKOLAEV	{"phone": "+70072634055"}
0005432425149	BF6170	5097 831166	ANASTASIYA NAZAROVA	{"email": "anastasiya_nazarova031966@postgrespro.ru", "phone": "+70722818546"}
0005432425150	7EF1EA	2584 573826	ANDREY KOZLOV	{"email": "a_kozlov.1954@postgrespro.ru", "phone": "+70823966552"}
0005432425151	7EF1EA	0200 812441	MIKHAIL ANDREEV	{"email": "mandreev-26051978@postgrespro.ru", "phone": "+70301673793"}
0005432425152	FCF36A	0752 085297	NIKOLAY NOVIKOV	{"email": "novikov-n1962@postgrespro.ru", "phone": "+70391341822"}
0005432425153	FCF36A	9177 688303	ALEKSANDR MOROZOV	{"phone": "+70599196509"}
0005432425154	AEBC0F	8998 183572	NINA SOKOLOVA	{"phone": "+70367359070"}
0005432425155	AEBC0F	3635 115336	EVGENIY BORISOV	{"email": "e.borisov_27021974@postgrespro.ru", "phone": "+70801591705"}
0005432425156	A53523	6826 620052	ANDREY KISELEV	{"phone": "+70019694762"}
0005432425157	A53523	5014 754772	SERGEY IVANOV	{"phone": "+70093551222"}
0005432425158	A53523	5987 938227	NATALYA IVANOVA	{"email": "nivanova.1986@postgrespro.ru", "phone": "+70145682154"}
0005432425159	AFC5A3	6356 879210	LYUDMILA NIKOLAEVA	{"phone": "+70900677503"}
0005432425160	AFC5A3	5814 379696	FAINA KRASNOVA	{"email": "fainakrasnova.041988@postgrespro.ru", "phone": "+70810003104"}
0005432425161	546F43	1758 881750	ALEKSANDR FROLOV	{"email": "aleksandr_frolov-1966@postgrespro.ru", "phone": "+70063334564"}
0005432425162	546F43	3570 677443	EVGENIY KAZAKOV	{"phone": "+70093523080"}
0005432425163	53E885	5141 403999	KRISTINA MELNIKOVA	{"phone": "+70778089851"}
0005432425164	457380	7055 550650	VASILIY GERASIMOV	{"email": "v-gerasimov.061969@postgrespro.ru", "phone": "+70227821236"}
0005432425165	457380	6576 173639	ANASTASIYA YAKOVLEVA	{"email": "anastasiya_yakovleva_27021988@postgrespro.ru", "phone": "+70607801302"}
0005432425166	457380	1542 534112	MAKSIM DAVYDOV	{"email": "maksim-davydov-1964@postgrespro.ru", "phone": "+70825934732"}
0005432425167	12F3EC	5530 884707	EVGENIY KOZLOV	{"phone": "+70221434007"}
0005432425168	C29021	7910 162743	ARINA ROMANOVA	{"phone": "+70546132907"}
0005432425169	A35DCC	0558 685030	ALEKSEY POPOV	{"phone": "+70307671525"}
0005432425170	11F72B	5065 080368	ROMAN FEDOROV	{"email": "fedorov_r_071977@postgrespro.ru", "phone": "+70767393514"}
0005432425171	C91494	6107 567364	OLGA GERASIMOVA	{"email": "o-gerasimova-1978@postgrespro.ru", "phone": "+70807385510"}
0005432425172	C94944	6769 199379	ALINA NIKOLAEVA	{"email": "a_nikolaeva061973@postgrespro.ru", "phone": "+70119833551"}
0005432425173	7694EF	6354 307941	ANZHELA PETROVA	{"email": "a-petrova-1958@postgrespro.ru", "phone": "+70698382470"}
0005432425174	EAD5EB	1486 102862	MAKSIM ISAEV	{"phone": "+70424747090"}
0005432425175	B9912B	9748 503950	EKATERINA PETROVA	{"phone": "+70114475148"}
0005432425176	B9912B	1128 785591	EKATERINA TARASOVA	{"phone": "+70729368372"}
0005432425177	B9912B	9474 920012	ANVAR MELNIKOV	{"email": "anvar-melnikov08121976@postgrespro.ru", "phone": "+70774399733"}
0005432425178	6B409C	9371 724746	VLADIMIR ANDREEV	{"phone": "+70406201944"}
0005432425179	26D97E	3520 244685	LYUDMILA SOLOVEVA	{"email": "soloveva-l15121969@postgrespro.ru", "phone": "+70639661949"}
0005432425180	26D97E	3588 482421	VALERIY NIKITIN	{"phone": "+70742931892"}
0005432425181	26D97E	8088 390947	SERGEY ISAEV	{"phone": "+70421127851"}
0005432425182	49D89D	7545 455804	ALBINA KOZLOVA	{"email": "kozlova_albina_1977@postgrespro.ru", "phone": "+70060057748"}
0005432425183	B5A1CF	6454 484233	TAMARA BELOVA	{"email": "belova-t.02101973@postgrespro.ru", "phone": "+70616996819"}
0005432425184	64C7CD	7536 217121	MIKHAIL NIKOLAEV	{"email": "nikolaev.m_24091973@postgrespro.ru", "phone": "+70465018427"}
0005432425185	B55824	5299 754244	SERGEY ZAKHAROV	{"email": "zakharovsergey1973@postgrespro.ru", "phone": "+70104616329"}
0005432425186	A8424D	5056 837917	GALINA VLASOVA	{"email": "vlasova-galina_1970@postgrespro.ru", "phone": "+70883744833"}
0005432425187	58FD5F	7561 660566	YULIYA TROFIMOVA	{"email": "y-trofimova-31031972@postgrespro.ru", "phone": "+70719163874"}
0005432425188	58FD5F	8423 432887	NATALYA TROFIMOVA	{"email": "natalyatrofimova05121981@postgrespro.ru", "phone": "+70382903240"}
0005432425189	45A16F	6462 317577	OLGA IVANOVA	{"email": "ivanova-o06011965@postgrespro.ru", "phone": "+70295787025"}
0005432425190	45A16F	6559 007221	TATYANA DANILOVA	{"email": "tatyanadanilova_011971@postgrespro.ru", "phone": "+70408416226"}
0005432425191	E990D7	0894 061541	ALEKSEY SEMENOV	{"email": "aleksey-semenov_111972@postgrespro.ru", "phone": "+70153706616"}
0005432425192	BCDD2A	9205 019876	NATALYA EFIMOVA	{"phone": "+70362081172"}
0005432425193	11BBC9	6799 483501	OLGA MOISEEVA	{"email": "moiseeva_o.20071959@postgrespro.ru", "phone": "+70905764683"}
0005432425194	1C96B1	9200 636516	LYUDMILA ZAKHAROVA	{"phone": "+70492604995"}
0005432425195	1C96B1	0223 028182	VADIM TIKHONOV	{"email": "tikhonov-vadim25071970@postgrespro.ru", "phone": "+70547040043"}
0005432425196	172EAC	5315 691272	MIKHAIL NIKITIN	{"email": "nikitin_mikhail_1981@postgrespro.ru", "phone": "+70057088761"}
0005432425197	172EAC	5712 212325	VLADISLAV MAKAROV	{"email": "vladislav_makarov011982@postgrespro.ru", "phone": "+70187209743"}
0005432425198	DF339B	2899 615921	LYUBOV ZAYCEVA	{"phone": "+70084013574"}
0005432425199	DF339B	8259 203491	VIKTOR STEPANOV	{"email": "stepanov-viktor-31031983@postgrespro.ru", "phone": "+70333439347"}
0005432425200	0E8873	8477 317150	KIRILL SOROKIN	{"email": "kirill_sorokin-1977@postgrespro.ru", "phone": "+70736076778"}
0005432425201	D9403C	9662 259631	DANIL FEDOROV	{"email": "fedorov.danil_031989@postgrespro.ru", "phone": "+70433871057"}
0005432425202	D9403C	4216 165187	IGOR PAVLOV	{"phone": "+70310557463"}
0005432425203	2BACD3	8821 435485	IVAN NIKOLAEV	{"email": "nikolaev.ivan1977@postgrespro.ru", "phone": "+70658761220"}
0005432425204	AF1B8A	8966 854265	VASILIY AFANASEV	{"phone": "+70039863785"}
0005432425205	E3AC37	7511 714682	ALINA FOMINA	{"email": "fominaalina-091985@postgrespro.ru", "phone": "+70732458520"}
0005432425206	E3AC37	3355 734947	VLADIMIR MIRONOV	{"email": "vladimir_mironov-21061975@postgrespro.ru", "phone": "+70796895266"}
0005432425207	E3AC37	5381 886964	DMITRIY MAKSIMOV	{"email": "maksimov.dmitriy_26101958@postgrespro.ru", "phone": "+70133485275"}
0005432425208	895548	4363 653950	VENERA BORISOVA	{"email": "borisova_v-24121980@postgrespro.ru", "phone": "+70693775212"}
0005432425209	895548	5760 052414	SERGEY DAVYDOV	{"email": "davydov_s-101963@postgrespro.ru", "phone": "+70658775743"}
0005432425210	C27F65	8984 863397	KONSTANTIN VOROBEV	{"phone": "+70935775948"}
0005432425211	C27F65	6157 030167	MAKSIM KOZLOV	{"email": "mkozlov_05121984@postgrespro.ru", "phone": "+70258162692"}
0005432425212	7538A8	9341 227883	SOFYA KOZLOVA	{"phone": "+70986456543"}
0005432425213	7538A8	9752 468842	VERA NOVIKOVA	{"phone": "+70689221426"}
0005432425214	3CD0C1	6331 640393	NADEZHDA MALYSHEVA	{"phone": "+70899303454"}
0005432425215	15E0DF	9530 825711	TATYANA MATVEEVA	{"phone": "+70899374266"}
0005432425216	15E0DF	5582 891715	TATYANA FEDOROVA	{"email": "fedorova.t-1967@postgrespro.ru", "phone": "+70916590616"}
0005432425217	719E91	7077 879833	ELENA MIRONOVA	{"email": "e_mironova-1971@postgrespro.ru", "phone": "+70784375299"}
0005432425218	D2CF67	1326 128968	VLADIMIR MELNIKOV	{"email": "melnikovvladimir-1975@postgrespro.ru", "phone": "+70577025018"}
0005432425219	C1A6B3	1105 867448	IVAN SMIRNOV	{"email": "ismirnov-28031966@postgrespro.ru", "phone": "+70151997002"}
0005432425220	F14633	8140 956899	YULIYA POTAPOVA	{"phone": "+70829532871"}
0005432425221	F14633	4469 438562	ALEKSEY KUZMIN	{"email": "kuzmin-aleksey18071971@postgrespro.ru", "phone": "+70760685449"}
0005432425222	5867C3	8896 549863	GALINA MELNIKOVA	{"email": "galina.melnikova_1960@postgrespro.ru", "phone": "+70190652285"}
0005432425223	5867C3	6419 464948	ARTEM GERASIMOV	{"phone": "+70976859018"}
0005432425224	A2C9C5	5351 333337	SVETLANA POPOVA	{"phone": "+70760542089"}
0005432425225	DCAC09	0394 508399	RAMIL AFANASEV	{"phone": "+70174493220"}
0005432425226	588E9C	9817 211988	ELIZAVETA ORLOVA	{"email": "orlova.e_18031975@postgrespro.ru", "phone": "+70571503153"}
0005432425227	3D81AD	1497 268874	ANTONINA POPOVA	{"email": "popovaantonina-1978@postgrespro.ru", "phone": "+70468204770"}
0005432425228	CCCE38	9990 289035	GALINA ZAKHAROVA	{"phone": "+70301873405"}
0005432425229	B99B9F	4942 221932	VALERIY POPOV	{"email": "popovv1960@postgrespro.ru", "phone": "+70000662100"}
0005432425230	6E9F58	0343 368829	VERA KOROLEVA	{"email": "koroleva-v.21081980@postgrespro.ru", "phone": "+70355441742"}
0005432425231	DEB74C	8312 230276	ALEKSANDR NIKITIN	{"phone": "+70944369216"}
0005432425232	8625C0	6059 731384	NINA MATVEEVA	{"email": "matveeva_nina-111968@postgrespro.ru", "phone": "+70378780061"}
0005432425233	8625C0	0083 905166	ARTEM OSIPOV	{"email": "osipov.artem_23111962@postgrespro.ru", "phone": "+70022873392"}
0005432425234	4E1F13	3210 334968	TATYANA MAKSIMOVA	{"phone": "+70723270825"}
0005432425235	7F6DD6	4572 003841	ANTON EGOROV	{"phone": "+70474408610"}
0005432425236	DA24E4	7855 870608	SERGEY KUZNECOV	{"phone": "+70204918899"}
0005432425237	DF9CF0	3454 734713	LYUBOV KOMAROVA	{"email": "l.komarova061968@postgrespro.ru", "phone": "+70676725910"}
0005432425238	DF9CF0	8247 003284	ANNA KUZNECOVA	{"email": "anna_kuznecova061979@postgrespro.ru", "phone": "+70064904278"}
0005432425239	4CD087	1900 291102	VYACHESLAV SIDOROV	{"phone": "+70949856403"}
0005432425240	4CD087	8335 346684	NATALYA SMIRNOVA	{"phone": "+70316389221"}
0005432425241	CEC759	2056 904928	DMITRIY ANTONOV	{"email": "antonov.d121969@postgrespro.ru", "phone": "+70349253364"}
0005432425242	CEC759	1532 159775	ZHANNA KALININA	{"phone": "+70884751704"}
0005432425243	CEC759	2310 724375	ALEKSEY PAVLOV	{"phone": "+70075196536"}
0005432425244	6EA2A7	8346 585087	OLGA IVANOVA	{"phone": "+70237131010"}
0005432425245	6EA2A7	9825 433096	ELIZAVETA TARASOVA	{"phone": "+70270499508"}
0005432425246	6EA2A7	5905 729096	ROMAN KARPOV	{"email": "karpov.roman1970@postgrespro.ru", "phone": "+70492671442"}
0005432425247	9E5557	0388 552696	MIKHAIL MAKAROV	{"phone": "+70046999083"}
0005432425248	4DCFC5	4771 257422	VLADIMIR IVANOV	{"phone": "+70998190371"}
0005432425249	5DB3F5	3306 910231	MARIYA GERASIMOVA	{"email": "mariya_gerasimova1975@postgrespro.ru", "phone": "+70908138557"}
0005432425250	5DB3F5	4866 439084	ELENA MARTYNOVA	{"phone": "+70633017626"}
0005432425251	5DB3F5	9357 407040	ALEKSANDR KUZMIN	{"phone": "+70271491534"}
0005432425252	05BC9B	7228 512970	ANDREY AFANASEV	{"email": "andrey-afanasev.28011977@postgrespro.ru", "phone": "+70307623249"}
0005432425253	3F961D	8811 531494	DMITRIY NAZAROV	{"email": "nazarov.d1971@postgrespro.ru", "phone": "+70660625899"}
0005432425254	96D1B3	0781 466499	MIKHAIL KULIKOV	{"email": "kulikov.m07021970@postgrespro.ru", "phone": "+70747371358"}
0005432425255	DB5D8E	5923 459746	MARIYA NAZAROVA	{"phone": "+70572582272"}
0005432425256	DB5D8E	2757 342061	VLADIMIR ZAYCEV	{"phone": "+70816396368"}
0005432425257	E9C847	2913 732325	NIKOLAY NOVIKOV	{"email": "n-novikov1960@postgrespro.ru", "phone": "+70065706608"}
0005432425314	AC4AFD	0579 176323	SVETLANA ANISIMOVA	{"phone": "+70334127909"}
0005432425258	7120E6	5982 958714	MIKHAIL SERGEEV	{"email": "sergeev.mikhail_081973@postgrespro.ru", "phone": "+70350466693"}
0005432425259	7120E6	2374 046880	LIDIYA STEPANOVA	{"phone": "+70753821115"}
0005432425260	EA21BF	0954 710052	ALEKSANDR IVANOV	{"phone": "+70148138885"}
0005432425261	EA21BF	8032 547443	ALEKSANDRA ERMAKOVA	{"phone": "+70103939407"}
0005432425262	3DCAD2	3314 378925	VLADIMIR MOROZOV	{"phone": "+70928777430"}
0005432425263	B83B2F	1249 627408	DANIIL BELOV	{"email": "belov-d-10051982@postgrespro.ru", "phone": "+70553655638"}
0005432425264	5700A7	8419 383137	YULIYA KONOVALOVA	{"phone": "+70507713551"}
0005432425265	999F23	0521 968265	ELENA ROMANOVA	{"phone": "+70111630295"}
0005432425266	999F23	8092 089832	DMITRIY MEDVEDEV	{"email": "dmedvedev031977@postgrespro.ru", "phone": "+70300253894"}
0005432425267	5CEE75	8431 529299	DMITRIY ZAYCEV	{"email": "d_zaycev-1968@postgrespro.ru", "phone": "+70111545706"}
0005432425268	5CEE75	7565 107413	SOFYA FROLOVA	{"phone": "+70293954477"}
0005432425269	D06210	1721 299113	ALEKSANDR FEDOTOV	{"phone": "+70717264951"}
0005432425270	2A45B0	5945 713308	LYUDMILA KUZNECOVA	{"phone": "+70520805266"}
0005432425271	F1B864	6553 247385	MAKSIM KONOVALOV	{"email": "konovalovmaksim.1974@postgrespro.ru", "phone": "+70496543928"}
0005432425272	F1B864	4786 327194	MARINA ARKHIPOVA	{"email": "marina_arkhipova-111983@postgrespro.ru", "phone": "+70830364201"}
0005432425273	54AB23	2411 648339	LEONID MIKHAYLOV	{"phone": "+70995805941"}
0005432425274	54AB23	6293 661777	IVAN MAKSIMOV	{"phone": "+70599050736"}
0005432425275	29E30B	5828 477437	DARYA MELNIKOVA	{"phone": "+70919165214"}
0005432425276	29E30B	8518 745054	ANASTASIYA BARANOVA	{"email": "anastasiyabaranova.13111980@postgrespro.ru", "phone": "+70916412200"}
0005432425277	FDA75C	8777 505740	ALEKSEY ANDREEV	{"email": "andreevaleksey061985@postgrespro.ru", "phone": "+70433773897"}
0005432425278	C5B3FA	8797 164209	KLAVDIYA SOLOVEVA	{"email": "klavdiya-soloveva1981@postgrespro.ru", "phone": "+70310450266"}
0005432425279	C5B3FA	4791 972121	IRINA ANISIMOVA	{"phone": "+70091106046"}
0005432425280	4BD2B8	2776 044628	IRINA MAKSIMOVA	{"email": "maksimova_irina-101989@postgrespro.ru", "phone": "+70934436309"}
0005432425281	303EEA	6176 964684	MARIYA KARPOVA	{"phone": "+70605533137"}
0005432425282	303EEA	4454 988769	RAISA KALININA	{"phone": "+70953058840"}
0005432425283	303EEA	0744 847365	ALEKSANDR SMIRNOV	{"phone": "+70325898669"}
0005432425284	A019A7	5588 805004	KIRILL VASILEV	{"email": "kirill-vasilev_011977@postgrespro.ru", "phone": "+70743567763"}
0005432425285	A019A7	3962 007206	LYUDMILA GORBUNOVA	{"email": "gorbunova_l-1968@postgrespro.ru", "phone": "+70325257221"}
0005432425286	C2986E	2050 742530	KIRILL DMITRIEV	{"phone": "+70056961623"}
0005432425287	C2986E	5745 960996	IGOR MARTYNOV	{"email": "martynov_i-081968@postgrespro.ru", "phone": "+70534891107"}
0005432425288	2C1BEF	4177 578414	SERGEY GUSEV	{"email": "sgusev091973@postgrespro.ru", "phone": "+70175814001"}
0005432425289	8ECDE4	5832 454444	NATALYA NOVIKOVA	{"phone": "+70633530229"}
0005432425290	0473C4	1687 581124	TAMARA NESTEROVA	{"email": "nesterova-t_1970@postgrespro.ru", "phone": "+70056096994"}
0005432425291	4F3B49	6326 093692	INNA DENISOVA	{"email": "denisova.i-10061976@postgrespro.ru", "phone": "+70948456983"}
0005432425292	54D734	6720 819020	OLGA ARKHIPOVA	{"phone": "+70658928937"}
0005432425293	D7F1C4	1161 692724	DARYA KUDRYASHOVA	{"email": "kudryashova_darya_03081969@postgrespro.ru", "phone": "+70579586090"}
0005432425294	E47374	1687 111969	EKATERINA GUSEVA	{"email": "e_guseva.101976@postgrespro.ru", "phone": "+70649213346"}
0005432425295	E47374	2790 100846	MAKSIM KULIKOV	{"email": "kulikov.maksim1978@postgrespro.ru", "phone": "+70989290713"}
0005432425296	F94525	1383 173555	MIKHAIL KISELEV	{"phone": "+70001038186"}
0005432425297	E050FB	3804 408858	EVGENIY KRASNOV	{"email": "krasnov-e-011971@postgrespro.ru", "phone": "+70556701436"}
0005432425298	4F077B	2886 458571	IGOR ZAKHAROV	{"email": "zakharov-i_1975@postgrespro.ru", "phone": "+70249369329"}
0005432425299	88BFFB	5544 736513	OLGA NAUMOVA	{"email": "naumova_olga.1974@postgrespro.ru", "phone": "+70702083558"}
0005432425300	736019	4076 903252	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.031970@postgrespro.ru", "phone": "+70962326964"}
0005432425301	10EC9F	3732 910299	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov.1976@postgrespro.ru", "phone": "+70466742951"}
0005432425302	10EC9F	6341 520503	VITALIY FROLOV	{"email": "vitaliy-frolov24121983@postgrespro.ru", "phone": "+70508599227"}
0005432425303	22FBF4	4227 388656	ANDREY MAKAROV	{"phone": "+70775130023"}
0005432425304	979ABA	1265 667822	ALEKSANDR FEDOROV	{"email": "a_fedorov1964@postgrespro.ru", "phone": "+70805472414"}
0005432425305	BBEEEE	6156 815960	ALEKSANDR VLASOV	{"phone": "+70957834844"}
0005432425306	1D86E9	0065 007144	ALEKSANDR IVANOV	{"email": "a-ivanov.1972@postgrespro.ru", "phone": "+70435913367"}
0005432425307	1D86E9	2422 470210	LYUDMILA POTAPOVA	{"phone": "+70915303011"}
0005432425308	FA1B60	8283 418067	TATYANA ZHURAVLEVA	{"email": "tzhuravleva-01051968@postgrespro.ru", "phone": "+70554624149"}
0005432425309	FA1B60	6092 401130	VIKTOR GERASIMOV	{"phone": "+70157522295"}
0005432425310	FA1B60	2097 459555	ALEKSANDR EGOROV	{"phone": "+70253362379"}
0005432425311	67FD56	2847 095665	VASILIY DENISOV	{"email": "vdenisov1976@postgrespro.ru", "phone": "+70140835496"}
0005432425312	67FD56	8422 485058	LILIYA MAKAROVA	{"email": "l.makarova_20051968@postgrespro.ru", "phone": "+70699565385"}
0005432425313	60EFF4	5341 398042	VALERIYA MAKSIMOVA	{"email": "maksimova-valeriya-061972@postgrespro.ru", "phone": "+70494026646"}
0005432425315	AC4AFD	1513 148778	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov_1981@postgrespro.ru", "phone": "+70736248169"}
0005432425316	10CD2A	3470 538303	RINAT MIRONOV	{"email": "mironov.r-021965@postgrespro.ru", "phone": "+70083975188"}
0005432425317	CA7A90	3397 413919	EMMA KUZMINA	{"phone": "+70267513296"}
0005432425318	3954C1	9769 709319	MARIYA POPOVA	{"phone": "+70343830948"}
0005432425319	3954C1	0110 926532	EKATERINA TARASOVA	{"phone": "+70870164040"}
0005432425320	3954C1	0065 110923	EKATERINA SOROKINA	{"phone": "+70218410513"}
0005432425321	3962B9	1875 102398	ALBINA OSIPOVA	{"phone": "+70630480985"}
0005432425322	584895	9123 369602	VLADIMIR IVANOV	{"email": "ivanov.v1973@postgrespro.ru", "phone": "+70927597519"}
0005432425323	A04BBD	9899 061570	NATALYA PAVLOVA	{"email": "pavlovan_1968@postgrespro.ru", "phone": "+70809633231"}
0005432425324	2D2610	4081 805189	IVAN STEPANOV	{"phone": "+70893446787"}
0005432425325	2D2610	7022 575886	ANDREY PETROV	{"email": "petrov.a-041975@postgrespro.ru", "phone": "+70727340967"}
0005432425326	2D2610	7045 237918	BORIS GORBUNOV	{"email": "gorbunov-b_021978@postgrespro.ru", "phone": "+70580081166"}
0005432425327	DAEA54	9362 167838	VIKTOR KAZAKOV	{"email": "v.kazakov-051979@postgrespro.ru", "phone": "+70621946205"}
0005432425328	A2413C	0534 085041	GALINA NIKOLAEVA	{"email": "nikolaeva_galina-1965@postgrespro.ru", "phone": "+70183354655"}
0005432425329	A2413C	5888 477766	LYUBOV GUSEVA	{"email": "lyubov_guseva02061964@postgrespro.ru", "phone": "+70549695070"}
0005432425330	076670	3188 611006	ANTON IVANOV	{"phone": "+70553452446"}
0005432425331	5D9B5E	5121 947654	OLGA ALEKSEEVA	{"email": "alekseevaolga071973@postgrespro.ru", "phone": "+70763068533"}
0005432425332	184C66	3061 204770	NIKOLAY KUZNECOV	{"email": "n-kuznecov_1977@postgrespro.ru", "phone": "+70466545422"}
0005432425333	52D2ED	4704 806343	SERGEY KOROLEV	{"email": "korolev.s1972@postgrespro.ru", "phone": "+70295791920"}
0005432425334	FFA476	8270 411977	ELENA BOGDANOVA	{"email": "e-bogdanova_071979@postgrespro.ru", "phone": "+70103926152"}
0005432425335	FFA476	7869 255807	IVAN GERASIMOV	{"phone": "+70787109737"}
0005432425336	725A34	6257 590181	MARINA FILATOVA	{"email": "m.filatova.071967@postgrespro.ru", "phone": "+70433128243"}
0005432425337	34183B	4666 740992	ANDREY KARPOV	{"email": "karpovandrey071979@postgrespro.ru", "phone": "+70113253405"}
0005432425338	AB138B	4177 908909	RAISA ZOTOVA	{"email": "zotova-raisa.28121963@postgrespro.ru", "phone": "+70286384926"}
0005432425339	AB138B	4459 138824	SERGEY BONDARENKO	{"email": "bondarenko-s.1975@postgrespro.ru", "phone": "+70679615133"}
0005432425340	FF3B43	4507 572213	ELIZAVETA NIKOLAEVA	{"phone": "+70154545983"}
0005432425341	D562FF	0564 003516	MARIYA NAZAROVA	{"email": "nazarovam.031971@postgrespro.ru", "phone": "+70406368179"}
0005432425342	1028ED	0641 951876	VALERIY NAZAROV	{"phone": "+70903828131"}
0005432425343	2C7FA2	9111 443052	MARINA NIKITINA	{"email": "nikitinamarina_1985@postgrespro.ru", "phone": "+70370064349"}
0005432425344	47B934	1070 967509	ANTON MAKSIMOV	{"email": "amaksimov_1984@postgrespro.ru", "phone": "+70333099687"}
0005432425345	47B934	8334 517784	DMITRIY ZAKHAROV	{"email": "d-zakharov.1958@postgrespro.ru", "phone": "+70600001955"}
0005432425346	EF9F26	8945 528926	IRINA ZAYCEVA	{"phone": "+70420041667"}
0005432425347	EF9F26	2120 591103	NIKOLAY VOLKOV	{"email": "volkov-nikolay_25091970@postgrespro.ru", "phone": "+70662600191"}
0005432425348	50AD2A	4240 010163	KLAVDIYA ANDREEVA	{"email": "klavdiya-andreeva-1983@postgrespro.ru", "phone": "+70422515118"}
0005432425349	FD0185	4955 270133	RAUZA PETROVA	{"phone": "+70382148004"}
0005432425350	385C8B	1100 450680	ANASTASIYA MIRONOVA	{"email": "mironovaanastasiya.101969@postgrespro.ru", "phone": "+70440814282"}
0005432425351	CD8615	3634 394622	OLEG BONDARENKO	{"email": "o.bondarenko.24111976@postgrespro.ru", "phone": "+70276248781"}
0005432425352	CD8615	9468 804742	ANTONINA VASILEVA	{"email": "vasileva_a.19051972@postgrespro.ru", "phone": "+70696655180"}
0005432425353	4C411B	4439 113818	ALEKSEY MATVEEV	{"phone": "+70333311296"}
0005432425354	8E7720	0607 158054	IRINA KISELEVA	{"phone": "+70495295486"}
0005432425355	5DEFE5	1454 987357	EVGENIY ABRAMOV	{"phone": "+70245084799"}
0005432425356	C1DC68	1005 631747	VALENTINA ANDREEVA	{"email": "v_andreeva_121965@postgrespro.ru", "phone": "+70180945536"}
0005432425357	E64A23	4688 139607	NATALYA LAZAREVA	{"phone": "+70506615741"}
0005432425358	E64A23	4358 920866	SERGEY MIRONOV	{"phone": "+70906963916"}
0005432425359	F10A39	5795 126229	VYACHESLAV ANDREEV	{"phone": "+70755800389"}
0005432425360	388953	7643 520848	MAKSIM FEDOROV	{"phone": "+70318241207"}
0005432425361	EE879C	0609 591104	ANNA LUKYANOVA	{"phone": "+70139525874"}
0005432425362	EE879C	0229 167884	ELENA PETROVA	{"phone": "+70044895610"}
0005432425363	EE879C	5078 076801	EVGENIY KUZMIN	{"phone": "+70318613965"}
0005432425364	D01BB6	6929 814241	VIKTOR ANDREEV	{"email": "viktorandreev-111968@postgrespro.ru", "phone": "+70756452539"}
0005432425365	C66290	8548 643547	VERA NAZAROVA	{"email": "vera.nazarova061983@postgrespro.ru", "phone": "+70951801753"}
0005432425366	C66290	2674 689817	MARIYA NOVIKOVA	{"email": "mnovikova.1963@postgrespro.ru", "phone": "+70993324417"}
0005432425367	96A3E0	6285 594929	ANASTASIYA ILINA	{"phone": "+70743636304"}
0005432425368	621CD7	9588 687680	DENIS PAVLOV	{"email": "pavlov_denis_061971@postgrespro.ru", "phone": "+70189392252"}
0005432425369	887F58	8925 148079	VERA MAKAROVA	{"email": "vera-makarova_081971@postgrespro.ru", "phone": "+70798839557"}
0005432425370	7BF51A	1080 437332	TAMARA VOLKOVA	{"email": "volkovat_23031977@postgrespro.ru", "phone": "+70328470514"}
0005432425371	564936	0450 444527	NIKOLAY VASILEV	{"email": "vasilevn-1982@postgrespro.ru", "phone": "+70597639740"}
0005432425372	60339C	6628 076682	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva-011971@postgrespro.ru", "phone": "+70960430164"}
0005432425373	60339C	9446 402391	ILNUR MATVEEV	{"email": "imatveev_061969@postgrespro.ru", "phone": "+70356134794"}
0005432425374	6C0422	1501 898731	SVETLANA ZOTOVA	{"phone": "+70236738578"}
0005432425375	B0FF55	5945 673871	ALBINA AKIMOVA	{"phone": "+70163537772"}
0005432425376	2BC45C	3726 652943	ALEKSEY DENISOV	{"phone": "+70044119368"}
0005432425377	39F35A	5416 959161	NIKOLAY MAKAROV	{"email": "makarov_n.01101977@postgrespro.ru", "phone": "+70809122419"}
0005432425378	932160	6455 376021	GALINA ALEKSEEVA	{"phone": "+70384049931"}
0005432425379	932160	3845 105331	OLGA BORISOVA	{"email": "olgaborisova1965@postgrespro.ru", "phone": "+70235528423"}
0005432425380	495448	7124 270564	ANDREY BARANOV	{"phone": "+70655837808"}
0005432425381	CB2FFD	6304 155418	VLADIMIR KOZLOV	{"email": "kozlovv07121972@postgrespro.ru", "phone": "+70448448526"}
0005432425382	04F54C	1457 930871	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov.09121980@postgrespro.ru", "phone": "+70340751007"}
0005432425383	04F54C	9304 947525	ELENA VOLKOVA	{"phone": "+70865573700"}
0005432425384	C91918	7438 928605	LIDIYA IVANOVA	{"phone": "+70152518529"}
0005432425385	DD9C28	1092 011883	YULIYA MOISEEVA	{"phone": "+70107953993"}
0005432425386	9FEAB2	6436 161161	YULIYA FADEEVA	{"email": "fadeevay-1963@postgrespro.ru", "phone": "+70232450807"}
0005432425387	E16AFD	0262 754137	GULNARA SMIRNOVA	{"email": "smirnovagulnara_051976@postgrespro.ru", "phone": "+70432750225"}
0005432425388	D2A860	3267 762235	MILANA EFIMOVA	{"phone": "+70112637541"}
0005432425389	D2A860	6386 186111	OLGA NIKOLAEVA	{"email": "nikolaeva-olga.101963@postgrespro.ru", "phone": "+70991449770"}
0005432425390	1AC5D7	6921 141210	LYUDMILA IVANOVA	{"phone": "+70101426858"}
0005432425391	8753E9	1685 920930	ZOYA KONDRATEVA	{"email": "z.kondrateva081971@postgrespro.ru", "phone": "+70866199233"}
0005432425392	8A630A	0772 334650	DENIS YAKOVLEV	{"email": "yakovlev_denis011971@postgrespro.ru", "phone": "+70093760944"}
0005432425393	B2D322	4846 721405	SERGEY SERGEEV	{"phone": "+70250351829"}
0005432425394	7E94D4	3925 086600	VIKTOR VLASOV	{"phone": "+70652268244"}
0005432425395	4E2BB6	9915 688450	ALEKSEY GRIGOREV	{"email": "aleksey-grigorev-28041967@postgrespro.ru", "phone": "+70107940862"}
0005432425396	3EB2FD	4689 099779	NATALYA KUDRYASHOVA	{"email": "kudryashovan-04051982@postgrespro.ru", "phone": "+70452025353"}
0005432425397	B6799A	2663 231146	ELENA OSIPOVA	{"email": "elenaosipova_1979@postgrespro.ru", "phone": "+70230217922"}
0005432425398	B6799A	3944 934505	VERONIKA MARTYNOVA	{"email": "veronika_martynova.071973@postgrespro.ru", "phone": "+70465330299"}
0005432425399	B6799A	2312 029935	OKSANA MOISEEVA	{"phone": "+70764820822"}
0005432425400	E5D253	8139 716093	EVGENIYA GORBUNOVA	{"phone": "+70388276715"}
0005432425401	E41028	5337 180995	ALBINA ANTONOVA	{"email": "albina.antonova-24051975@postgrespro.ru", "phone": "+70654615866"}
0005432425402	E41028	3919 039679	ALINA MOISEEVA	{"phone": "+70616035710"}
0005432425403	E41028	6347 760327	SERGEY SERGEEV	{"phone": "+70250034620"}
0005432425404	912CDE	1537 544698	VLADIMIR BONDARENKO	{"email": "v-bondarenko1964@postgrespro.ru", "phone": "+70307309316"}
0005432425405	76411D	3633 179462	ELENA SOLOVEVA	{"phone": "+70325840285"}
0005432425406	76411D	4935 966262	LYUDMILA BARANOVA	{"phone": "+70136579091"}
0005432425407	8B9839	6302 618209	NATALYA NIKOLAEVA	{"email": "natalyanikolaeva121971@postgrespro.ru", "phone": "+70331859770"}
0005432425408	AD5378	9215 661670	NADEZHDA KOROLEVA	{"phone": "+70469157369"}
0005432425409	AD5378	5345 106554	SERAFIMA ANDREEVA	{"email": "sandreeva_1974@postgrespro.ru", "phone": "+70282109406"}
0005432425410	FA72BB	8672 184154	ROZA KRASNOVA	{"email": "krasnova-roza-061970@postgrespro.ru", "phone": "+70160245062"}
0005432425411	0E6908	9687 765898	NADEZHDA SMIRNOVA	{"email": "n.smirnova-041980@postgrespro.ru", "phone": "+70237259177"}
0005432425412	464C20	4229 685682	IRINA KULIKOVA	{"phone": "+70818418193"}
0005432425413	660F5B	1355 547570	TATYANA ROMANOVA	{"email": "t.romanova071974@postgrespro.ru", "phone": "+70784436558"}
0005432425414	660F5B	3072 445337	ALEKSANDR FROLOV	{"email": "frolovaleksandr_06121970@postgrespro.ru", "phone": "+70043311597"}
0005432425415	660F5B	2714 858485	NATALYA EGOROVA	{"email": "n-egorova_011980@postgrespro.ru", "phone": "+70725994302"}
0005432425416	76657B	8878 742359	VERA MAKSIMOVA	{"email": "maksimova-v08021977@postgrespro.ru", "phone": "+70596111315"}
0005432425417	76657B	1204 881879	GALINA ALEKSANDROVA	{"email": "aleksandrova.galina_1973@postgrespro.ru", "phone": "+70738819637"}
0005432425418	2626AD	8466 963434	VLADIMIR GRIGOREV	{"email": "v.grigorev.30041965@postgrespro.ru", "phone": "+70073848088"}
0005432425419	4D3DE3	8174 153666	ANTON KUZNECOV	{"email": "anton.kuznecov-1979@postgrespro.ru", "phone": "+70039008435"}
0005432425420	4D3DE3	9570 400734	DENIS VOROBEV	{"phone": "+70698692012"}
0005432425421	4D3DE3	4980 489293	ALEKSANDR MIKHAYLOV	{"phone": "+70679939337"}
0005432425422	231839	3886 570289	MARIYA IVANOVA	{"email": "ivanova.mariya121958@postgrespro.ru", "phone": "+70391742001"}
0005432425423	231839	6693 265249	OLGA SOLOVEVA	{"phone": "+70520307959"}
0005432425424	897B45	6648 828381	LYUDMILA ISAEVA	{"phone": "+70655582369"}
0005432425425	325868	5868 573728	NIKOLAY MELNIKOV	{"email": "nikolay_melnikov_011974@postgrespro.ru", "phone": "+70734983819"}
0005432425426	325868	3059 989113	MIKHAIL NIKOLAEV	{"email": "mikhail-nikolaev.18051972@postgrespro.ru", "phone": "+70714825668"}
0005432425427	D6CA8C	3201 226526	ANDREY NIKOLAEV	{"email": "a-nikolaev061970@postgrespro.ru", "phone": "+70491662835"}
0005432425428	B3F3F8	8056 361342	ALEKSEY PAVLOV	{"phone": "+70220312948"}
0005432425429	B3F3F8	5068 028857	MAKSIM SOKOLOV	{"email": "maksim-sokolov-25051972@postgrespro.ru", "phone": "+70034588224"}
0005432425430	DE913A	8557 937574	SVETLANA KOVALEVA	{"email": "s.kovaleva-1973@postgrespro.ru", "phone": "+70124247383"}
0005432425431	627FAC	5551 048646	SERGEY ZAYCEV	{"phone": "+70013367198"}
0005432425432	627FAC	8892 680648	OLGA MOROZOVA	{"email": "morozovao-18031978@postgrespro.ru", "phone": "+70661972353"}
0005432425433	6E54EC	1316 560161	ALEKSEY KRASNOV	{"phone": "+70032368474"}
0005432425434	F80521	0087 288855	VARVARA MARTYNOVA	{"phone": "+70542219901"}
0005432425435	17012C	0730 105308	DANILA SAVELEV	{"email": "danila-savelev_1968@postgrespro.ru", "phone": "+70363906084"}
0005432425436	EE022D	0894 052995	VLADIMIR IVANOV	{"email": "vladimirivanov-051965@postgrespro.ru", "phone": "+70752112711"}
0005432425437	24873C	9700 339694	TATYANA ZAYCEVA	{"phone": "+70263058782"}
0005432425438	AC6F5D	9691 782077	DMITRIY NOVIKOV	{"phone": "+70272351506"}
0005432425439	6D4E8B	5991 085217	MIKHAIL KULIKOV	{"phone": "+70199507169"}
0005432425440	9F6930	7606 983048	IRINA GORBUNOVA	{"email": "gorbunova-i.1973@postgrespro.ru", "phone": "+70576421039"}
0005432425441	0DAFAC	4422 747581	MARIYA IVANOVA	{"phone": "+70431676855"}
0005432425442	16678B	1113 022343	SVETLANA MAKSIMOVA	{"email": "s_maksimova_021974@postgrespro.ru", "phone": "+70609850647"}
0005432425443	BA8C62	9008 072500	NATALYA ZOTOVA	{"email": "zotova-natalya011970@postgrespro.ru", "phone": "+70668123583"}
0005432425444	BA8C62	4233 153458	MAKSIM DENISOV	{"email": "denisov.maksim061973@postgrespro.ru", "phone": "+70049661041"}
0005432425445	BA8C62	4411 018543	RISHAT MIRONOV	{"phone": "+70639159733"}
0005432425446	EFF1C8	8505 822302	OLGA SEMENOVA	{"email": "olga_semenova.031978@postgrespro.ru", "phone": "+70852837130"}
0005432425447	EFF1C8	6988 367439	NATALYA MALYSHEVA	{"phone": "+70451401019"}
0005432425448	93D950	1392 545060	PAVEL MAKSIMOV	{"email": "maksimov-pavel-041984@postgrespro.ru", "phone": "+70737829446"}
0005432425449	87B40E	2744 275169	OLGA ERMAKOVA	{"email": "ermakova.olga-23051980@postgrespro.ru", "phone": "+70839264937"}
0005432425450	9882C0	8331 694492	TATYANA YUDINA	{"phone": "+70556867083"}
0005432425451	17367F	0645 337782	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov_15101957@postgrespro.ru", "phone": "+70022059690"}
0005432425452	17367F	0893 579029	VIKTOR ALEKSEEV	{"email": "v-alekseev23051968@postgrespro.ru", "phone": "+70895568693"}
0005432425453	2229EF	3025 979718	GULSINA LEBEDEVA	{"phone": "+70800624398"}
0005432425454	2229EF	8823 199097	VALERIY NIKITIN	{"phone": "+70251205310"}
0005432425455	569671	4812 436462	EKATERINA STEPANOVA	{"phone": "+70572895570"}
0005432425456	569671	1676 346425	LYUDMILA MARTYNOVA	{"phone": "+70298550527"}
0005432425457	F062B5	5364 641778	NIKITA FILIPPOV	{"email": "filippov-nikita-1972@postgrespro.ru", "phone": "+70010914251"}
0005432425458	DBE894	0838 303701	VIKTOR MOROZOV	{"email": "viktormorozov1966@postgrespro.ru", "phone": "+70068332967"}
0005432425459	142FEF	3389 901661	IRINA RODIONOVA	{"email": "irodionova_1968@postgrespro.ru", "phone": "+70366709648"}
0005432425460	142FEF	4907 390476	VALERIY BORISOV	{"email": "borisov.valeriy-021974@postgrespro.ru", "phone": "+70304437728"}
0005432425461	142FEF	2070 726604	MARINA BELOVA	{"email": "m-belova1988@postgrespro.ru", "phone": "+70386885894"}
0005432425462	7F0EF5	0154 745667	EVGENIY SERGEEV	{"email": "evgeniy_sergeev.28071966@postgrespro.ru", "phone": "+70258619181"}
0005432425463	641BE3	4189 362829	PETR ANDREEV	{"phone": "+70155440347"}
0005432425464	25DC83	1301 493959	VALENTINA VASILEVA	{"email": "valentina_vasileva.1969@postgrespro.ru", "phone": "+70633095514"}
0005432425465	86978F	0132 377663	DMITRIY MAKAROV	{"email": "makarov-dmitriy21101980@postgrespro.ru", "phone": "+70833363049"}
0005432425466	A3A125	8472 775572	ALEKSANDR ALEKSEEV	{"phone": "+70646021112"}
0005432425467	1852DB	0651 244830	EKATERINA FILIPPOVA	{"phone": "+70381806569"}
0005432425468	A3FB1C	8928 532602	NATALIYA FEDOROVA	{"phone": "+70049210503"}
0005432425469	691185	7238 482635	VITALIY KUZNECOV	{"phone": "+70380775991"}
0005432425470	812A38	0091 034278	EVGENIY ZAKHAROV	{"phone": "+70969119702"}
0005432425471	812A38	9882 327895	RAMIL BELOV	{"phone": "+70519418414"}
0005432425472	075D5C	9815 192257	ARTEM SOROKIN	{"email": "artem_sorokin16091964@postgrespro.ru", "phone": "+70949631565"}
0005432425473	075D5C	5829 733765	ALEKSANDR ISAEV	{"phone": "+70143466332"}
0005432425474	1EA8C9	6875 836789	DINARA CHERNOVA	{"email": "dinarachernova051973@postgrespro.ru", "phone": "+70973178380"}
0005432425475	DF45D2	7538 050441	ALEKSEY NIKITIN	{"phone": "+70344966289"}
0005432425476	D05840	1727 508114	VIKTOR KUZNECOV	{"email": "kuznecov-viktor-22091974@postgrespro.ru", "phone": "+70175430660"}
0005432425477	D05840	2644 741211	TATYANA KOZLOVA	{"phone": "+70068238211"}
0005432425478	39079F	3283 245540	GALINA KUDRYASHOVA	{"phone": "+70475495370"}
0005432425479	12B7EB	6100 721228	ANTON MATVEEV	{"email": "antonmatveev-101971@postgrespro.ru", "phone": "+70400546593"}
0005432425480	09BF4B	7885 848759	SERGEY KOROLEV	{"phone": "+70718760873"}
0005432425481	7C95FA	8574 932637	ANATOLIY YAKOVLEV	{"email": "ayakovlev1967@postgrespro.ru", "phone": "+70009891946"}
0005432425482	6971F1	2974 342810	VLADIMIR BELOV	{"phone": "+70183865100"}
0005432425483	6971F1	4128 053253	OLGA SIDOROVA	{"phone": "+70128507949"}
0005432425484	CA28A2	3240 103053	TAISIYA ILINA	{"email": "ilina_taisiya.16041972@postgrespro.ru", "phone": "+70929610875"}
0005432425485	D235ED	8445 197119	ANDREY IVANOV	{"email": "ivanov.a.20051978@postgrespro.ru", "phone": "+70646699901"}
0005432425486	D235ED	9511 960080	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova.101965@postgrespro.ru", "phone": "+70100066813"}
0005432425487	16ABA6	6469 722495	NIKOLAY IVANOV	{"phone": "+70872907230"}
0005432425488	81FEA6	0402 294788	TAMARA POLYAKOVA	{"phone": "+70155155466"}
0005432425489	7B2B25	3573 858159	OLGA KOROLEVA	{"email": "koroleva_o.1977@postgrespro.ru", "phone": "+70293571646"}
0005432425490	6515C4	6520 515441	VLADIMIR GRIGOREV	{"email": "grigorevv.1971@postgrespro.ru", "phone": "+70412196193"}
0005432425491	A9785A	8973 076145	ANASTASIYA DENISOVA	{"email": "denisova-a.081978@postgrespro.ru", "phone": "+70717156337"}
0005432425492	A9785A	9311 846596	KIRILL MOROZOV	{"email": "morozov-kirill_23011967@postgrespro.ru", "phone": "+70195501509"}
0005432425493	51D865	7987 569388	VARVARA FADEEVA	{"phone": "+70677766031"}
0005432425494	51E943	9293 076759	ALEKSANDR IVANOV	{"phone": "+70111391671"}
0005432425495	0CE8E9	7367 621315	ANDREY BONDARENKO	{"phone": "+70880041041"}
0005432425496	0CE8E9	1525 998221	VERA KONOVALOVA	{"phone": "+70199718402"}
0005432425497	1414D2	4462 676099	NIKOLAY KRASNOV	{"phone": "+70747893833"}
0005432425498	1414D2	8930 992083	ANNA MAKAROVA	{"phone": "+70254273731"}
0005432425499	C4686F	4316 895409	NINA FILIPPOVA	{"email": "n_filippova-1971@postgrespro.ru", "phone": "+70746616566"}
0005432425500	9AFE7D	4594 366715	NATALYA LUKYANOVA	{"email": "lukyanova_natalya_051969@postgrespro.ru", "phone": "+70225020637"}
0005432425501	3E32A9	7110 665513	SERGEY MOISEEV	{"email": "moiseev-sergey071974@postgrespro.ru", "phone": "+70236277482"}
0005432425502	3E32A9	0254 426306	MAKSIM ZAYCEV	{"email": "zaycev.maksim_1981@postgrespro.ru", "phone": "+70965899721"}
0005432425503	A971DD	8665 090561	NIKOLAY GERASIMOV	{"email": "gerasimov_n1983@postgrespro.ru", "phone": "+70563635626"}
0005432425504	A2A743	0804 419432	ANATOLIY BORISOV	{"email": "a.borisov.1971@postgrespro.ru", "phone": "+70464241406"}
0005432425505	A2A743	4903 225827	MILENA FILATOVA	{"email": "milena_filatova_1976@postgrespro.ru", "phone": "+70355900711"}
0005432425506	2E175C	0589 015361	MARIYA FEDOROVA	{"email": "fedorova_m_041960@postgrespro.ru", "phone": "+70930426479"}
0005432425507	2E175C	2745 832714	NATALYA NIKITINA	{"phone": "+70341690283"}
0005432425508	DC6788	6544 999944	ALENA KAZAKOVA	{"email": "kazakovaalena051968@postgrespro.ru", "phone": "+70718573735"}
0005432425509	59B18D	1393 777821	ANATOLIY CHERNOV	{"phone": "+70560537559"}
0005432425510	03F0A3	0104 552933	YANA KUZNECOVA	{"phone": "+70420535088"}
0005432425511	03F0A3	2068 978326	INNA ISAEVA	{"email": "isaeva-i.011975@postgrespro.ru", "phone": "+70493723952"}
0005432425512	C4BF70	4380 272392	OKSANA GAVRILOVA	{"email": "gavrilova-oksana-1964@postgrespro.ru", "phone": "+70230601395"}
0005432425513	C4BF70	2856 003655	YURIY POPOV	{"phone": "+70799752704"}
0005432425514	7EC9DF	8128 019143	NIKOLAY ROMANOV	{"phone": "+70959962976"}
0005432425515	1F4392	8053 056741	VLADIMIR TARASOV	{"email": "vladimir-tarasov-011975@postgrespro.ru", "phone": "+70220376732"}
0005432425516	910D2C	2815 610250	ANNA FADEEVA	{"email": "fadeeva_a011969@postgrespro.ru", "phone": "+70886622288"}
0005432425517	910D2C	5751 961006	ANDREY ALEKSEEV	{"email": "andreyalekseev_101968@postgrespro.ru", "phone": "+70158232492"}
0005432425518	4433B1	8652 386322	NATALYA SCHERBAKOVA	{"email": "scherbakova-natalya-071976@postgrespro.ru", "phone": "+70040784498"}
0005432425519	516081	9055 794587	ELENA KUZNECOVA	{"email": "ekuznecova1973@postgrespro.ru", "phone": "+70914655887"}
0005432425520	96FB89	2367 237840	MARINA GRISHINA	{"email": "m_grishina021975@postgrespro.ru", "phone": "+70373886405"}
0005432425521	BBD085	4788 334414	INNA KOMAROVA	{"phone": "+70429990254"}
0005432425522	BBD085	4849 652512	EVGENIYA LUKYANOVA	{"email": "e.lukyanova_11041974@postgrespro.ru", "phone": "+70493058371"}
0005432425523	E15A95	2244 965135	PAVEL SHEVCHENKO	{"phone": "+70957681241"}
0005432425524	83AE54	7082 147429	ELDAR ZAYCEV	{"email": "eldar-zaycev_14061974@postgrespro.ru", "phone": "+70014552251"}
0005432425525	83AE54	0041 071326	LYUDMILA PAVLOVA	{"phone": "+70241326191"}
0005432425526	02E947	4323 912938	LYUBOV IVANOVA	{"email": "ivanova.l_1972@postgrespro.ru", "phone": "+70385920532"}
0005432425527	4EA461	0605 194236	NIKOLAY VASILEV	{"email": "vasilev.nikolay_041971@postgrespro.ru", "phone": "+70012849396"}
0005432425528	4EA461	8572 635988	ANNA KUZNECOVA	{"email": "kuznecova-a.031972@postgrespro.ru", "phone": "+70029517426"}
0005432425529	7F1538	7814 179244	TATYANA SOROKINA	{"email": "t-sorokina.041971@postgrespro.ru", "phone": "+70350060539"}
0005432425530	A53582	0098 638403	AYRAT DAVYDOV	{"phone": "+70728831457"}
0005432425531	1A9CCD	2542 691297	EGOR KRASNOV	{"email": "egor_krasnov17051973@postgrespro.ru", "phone": "+70101837028"}
0005432425532	1A9CCD	2893 450354	YULIYA KUZNECOVA	{"phone": "+70674545499"}
0005432425533	87BB01	0322 559217	IRINA NIKOLAEVA	{"email": "nikolaeva-i.02121971@postgrespro.ru", "phone": "+70033831845"}
0005432425534	4390C9	0701 934917	ALEKSANDR SOLOVEV	{"phone": "+70517865355"}
0005432425535	56289A	6379 054723	ALLA KUZNECOVA	{"phone": "+70234580886"}
0005432425536	F648E4	0233 066734	ANNA GORBUNOVA	{"email": "gorbunova-a.071970@postgrespro.ru", "phone": "+70712079156"}
0005432425537	3C4826	3032 015035	LIDIYA TROFIMOVA	{"email": "ltrofimova-1960@postgrespro.ru", "phone": "+70959196715"}
0005432425538	3C4826	7895 085088	OLGA FROLOVA	{"email": "olga_frolova_051979@postgrespro.ru", "phone": "+70658457067"}
0005432425539	BCAFC1	4139 830352	DMITRIY DMITRIEV	{"phone": "+70819373002"}
0005432425540	BCAFC1	2751 489051	TATYANA ZHUKOVA	{"email": "t-zhukova_071976@postgrespro.ru", "phone": "+70033686316"}
0005432425541	0CF401	9803 608940	RUZALIYA KOLESNIKOVA	{"email": "ruzaliyakolesnikova-121974@postgrespro.ru", "phone": "+70674090703"}
0005432425542	1DC688	6509 601204	SERGEY STEPANOV	{"email": "s_stepanov.25031967@postgrespro.ru", "phone": "+70450236359"}
0005432425543	3B17D0	8961 922362	VASILIY SOKOLOV	{"email": "sokolovvasiliy-031974@postgrespro.ru", "phone": "+70949360314"}
0005432425544	79FCB1	5291 528252	DARYA TARASOVA	{"email": "tarasovadarya_1960@postgrespro.ru", "phone": "+70877049289"}
0005432425545	79FCB1	8385 736794	NADEZHDA PETROVA	{"phone": "+70843692296"}
0005432425546	6690F8	3378 095444	VALENTINA STEPANOVA	{"email": "stepanova_valentina-15071968@postgrespro.ru", "phone": "+70870285003"}
0005432425547	6690F8	0114 698009	NADEZHDA KONOVALOVA	{"email": "n-konovalova.15111971@postgrespro.ru", "phone": "+70340792010"}
0005432425548	316FF2	9075 734183	ILYA PETROV	{"email": "ilyapetrov_1969@postgrespro.ru", "phone": "+70390631603"}
0005432425549	8D2AC8	9700 296915	BORIS PETROV	{"phone": "+70284444792"}
0005432425550	8D03FB	0995 688035	MAKSIM IVANOV	{"email": "m.ivanov-10021971@postgrespro.ru", "phone": "+70955195289"}
0005432425551	8C99F8	7969 595881	LYUBOV BORISOVA	{"email": "lyubov.borisova.25071973@postgrespro.ru", "phone": "+70702582029"}
0005432425552	464CAC	7096 625798	MADINA KONDRATEVA	{"email": "madina.kondrateva-051971@postgrespro.ru", "phone": "+70911145543"}
0005432425553	525F78	5969 156693	ALLA TROFIMOVA	{"email": "trofimova.alla_021971@postgrespro.ru", "phone": "+70618921295"}
0005432425554	D30CB1	1402 271408	MARIYA YAKOVLEVA	{"phone": "+70173137137"}
0005432425555	B6FF8D	5991 083976	SERGEY KRASNOV	{"email": "sergeykrasnov-1960@postgrespro.ru", "phone": "+70722728787"}
0005432425556	AD00AF	1657 963351	ALEKSANDR SERGEEV	{"phone": "+70894935582"}
0005432425557	AD00AF	6637 239473	OLGA KAZAKOVA	{"email": "o.kazakova_1975@postgrespro.ru", "phone": "+70513612485"}
0005432425558	C70E34	4418 288981	MARIYA BELOVA	{"phone": "+70724543121"}
0005432425559	008A80	9554 871908	MILANA KUDRYASHOVA	{"email": "m_kudryashova.1972@postgrespro.ru", "phone": "+70454443451"}
0005432425560	008A80	0748 597691	ANTONINA KUZNECOVA	{"phone": "+70239736564"}
0005432425561	727241	0648 702642	ANZHELIKA ALEKSEEVA	{"phone": "+70389828480"}
0005432425562	97D370	0244 071546	NADEZHDA OSIPOVA	{"email": "n_osipova_1970@postgrespro.ru", "phone": "+70566265532"}
0005432425563	7CF221	9679 691999	VLADIMIR POPOV	{"email": "popovvladimir_1975@postgrespro.ru", "phone": "+70987341964"}
0005432425564	B002B4	9051 667559	ALEKSANDRA NIKOLAEVA	{"phone": "+70520585330"}
0005432425565	167FE2	1779 934543	EKATERINA MOISEEVA	{"email": "e_moiseeva1973@postgrespro.ru", "phone": "+70242164787"}
0005432425566	733B98	1885 326568	ALBINA MEDVEDEVA	{"phone": "+70651297944"}
0005432425567	733B98	6889 189119	POLINA VOROBEVA	{"phone": "+70938751251"}
0005432425568	E6ABB1	1543 717269	FEDOR MIRONOV	{"email": "f_mironov_071980@postgrespro.ru", "phone": "+70544225641"}
0005432425569	7C041D	2883 696879	ALEKSANDR SHEVCHENKO	{"phone": "+70312263242"}
0005432425570	73F1E2	3616 149248	ANNA VLASOVA	{"phone": "+70780947502"}
0005432425571	FB37E8	0937 479799	ELENA KUDRYASHOVA	{"phone": "+70884306506"}
0005432425572	FB37E8	3747 728540	IRINA NAUMOVA	{"email": "naumova-i-1985@postgrespro.ru", "phone": "+70449746029"}
0005432425573	D6C44A	1242 495250	ALEKSEY ZAKHAROV	{"phone": "+70144880279"}
0005432425574	D6C44A	0644 359392	MAKSIM VASILEV	{"email": "m_vasilev-25051976@postgrespro.ru", "phone": "+70060645680"}
0005432425575	29F629	6843 340613	NADEZHDA KOMAROVA	{"phone": "+70837700110"}
0005432425576	4A0E5E	3544 119624	DMITRIY IVANOV	{"phone": "+70328865310"}
0005432425577	4A0E5E	3419 725621	TAMARA DENISOVA	{"phone": "+70024872534"}
0005432425578	0FB55A	4018 947248	VERA PETROVA	{"phone": "+70467678510"}
0005432425579	A1FEBE	9000 483940	EKATERINA KOROLEVA	{"phone": "+70457646608"}
0005432425580	A1FEBE	8297 738649	OLESYA GERASIMOVA	{"email": "gerasimova.o05041972@postgrespro.ru", "phone": "+70524022578"}
0005432425581	482E6B	8511 141444	OLGA NIKITINA	{"email": "olga.nikitina_061975@postgrespro.ru", "phone": "+70981427952"}
0005432425582	8FCDC4	8650 427776	TATYANA DMITRIEVA	{"email": "tatyana-dmitrieva19061962@postgrespro.ru", "phone": "+70595026274"}
0005432425583	51B6E1	3217 592090	TATYANA NESTEROVA	{"phone": "+70749687964"}
0005432425584	A1C3DA	9785 723299	VLADIMIR KUDRYASHOV	{"email": "kudryashovv_1985@postgrespro.ru", "phone": "+70260841233"}
0005432425585	A1C3DA	4958 854136	ZOYA YAKOVLEVA	{"phone": "+70671692121"}
0005432425586	72438D	4831 212877	ANDREY VLASOV	{"phone": "+70302839783"}
0005432425587	72438D	7850 951997	NINA LAZAREVA	{"email": "lazareva_nina1976@postgrespro.ru", "phone": "+70849449858"}
0005432425588	D09761	8279 299798	VASILIY STEPANOV	{"email": "stepanovvasiliy_041971@postgrespro.ru", "phone": "+70797404889"}
0005432425589	22DF98	3357 270905	OLGA GUSEVA	{"email": "gusevao-1968@postgrespro.ru", "phone": "+70486771526"}
0005432425590	22DF98	3940 548511	MARAT DENISOV	{"email": "marat.denisov.071963@postgrespro.ru", "phone": "+70943814417"}
0005432425591	F69173	0400 762157	ANASTASIYA SEMENOVA	{"email": "semenova-anastasiya.1980@postgrespro.ru", "phone": "+70494451622"}
0005432425592	F69173	8309 353245	MARIYA IVANOVA	{"phone": "+70985657349"}
0005432425593	BC8A29	5565 678496	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko_20111983@postgrespro.ru", "phone": "+70882361345"}
0005432425594	6A19D0	2283 924808	RIMMA MIKHAYLOVA	{"email": "mikhaylova-rimma16071971@postgrespro.ru", "phone": "+70925036987"}
0005432425595	6A19D0	2882 060893	TATYANA ALEKSEEVA	{"email": "talekseeva-1971@postgrespro.ru", "phone": "+70335553536"}
0005432425596	B9AA21	8616 165749	IRINA KOROLEVA	{"email": "irinakoroleva_1972@postgrespro.ru", "phone": "+70935819681"}
0005432425597	B9AA21	6069 602226	ALEKSEY SCHERBAKOV	{"phone": "+70310405137"}
0005432425598	13379E	3018 987762	EKATERINA MIKHAYLOVA	{"email": "mikhaylova.ekaterina08011974@postgrespro.ru", "phone": "+70628010001"}
0005432425599	C331EC	9729 508064	OLGA ZHUKOVA	{"phone": "+70455438348"}
0005432425600	C331EC	2748 253769	ALBINA ANDREEVA	{"email": "a_andreeva011972@postgrespro.ru", "phone": "+70604042238"}
0005432425601	C331EC	9351 965846	YURIY CHERNOV	{"email": "chernov-y20031983@postgrespro.ru", "phone": "+70427479209"}
0005432425602	001D9D	6952 791035	GALINA MAKSIMOVA	{"email": "g_maksimova17111975@postgrespro.ru", "phone": "+70758920111"}
0005432425603	BEF0F5	4708 472009	OKSANA TARASOVA	{"phone": "+70751726585"}
0005432425604	BEF0F5	6729 452590	MARIYA MASLOVA	{"phone": "+70019310016"}
0005432425605	D2AFBE	0888 975915	ANNA KULIKOVA	{"email": "akulikova-16101979@postgrespro.ru", "phone": "+70293149016"}
0005432425606	7AFBC7	0416 934882	ELENA EGOROVA	{"email": "e-egorova-12061973@postgrespro.ru", "phone": "+70761687743"}
0005432425607	C18DDA	1830 033899	SERGEY MAKAROV	{"email": "makarov-s_1974@postgrespro.ru", "phone": "+70941369053"}
0005432425608	C18DDA	6607 090388	NINA FROLOVA	{"email": "frolova.nina_081981@postgrespro.ru", "phone": "+70344952835"}
0005432425609	122B5E	5308 229159	ANDREY SOKOLOV	{"phone": "+70117496062"}
0005432425610	122B5E	8618 119959	IVAN POPOV	{"email": "popov_ivan_29111971@postgrespro.ru", "phone": "+70940470598"}
0005432425611	E7EF57	4126 435958	TATYANA PAVLOVA	{"email": "pavlovatatyana_18041971@postgrespro.ru", "phone": "+70456502538"}
0005432425612	9C62EF	0898 616973	MAKSIM SOLOVEV	{"phone": "+70753048813"}
0005432425613	2DBEEB	3087 764045	ANDREY BELOV	{"phone": "+70441751292"}
0005432425614	1A1000	2088 960455	ANDREY BORISOV	{"email": "borisov_a-1984@postgrespro.ru", "phone": "+70994918489"}
0005432425615	2CCCD7	8560 878746	VALENTINA ZHUKOVA	{"phone": "+70426524242"}
0005432425616	9817D7	9292 431224	VERONIKA KUZNECOVA	{"email": "v_kuznecova-25071970@postgrespro.ru", "phone": "+70937354883"}
0005432425617	3313B6	0328 355296	VLADISLAV NIKITIN	{"phone": "+70704475410"}
0005432425618	48658F	3869 428089	YANA MATVEEVA	{"phone": "+70494561735"}
0005432425619	5E526C	8118 100017	YAROSLAV GAVRILOV	{"email": "yaroslavgavrilov1980@postgrespro.ru", "phone": "+70190013878"}
0005432425620	C2B622	8574 862771	NATALYA TIKHONOVA	{"phone": "+70527231105"}
0005432425621	3A5F68	1410 500673	LYUDMILA KOZLOVA	{"email": "kozlovalyudmila_18051981@postgrespro.ru", "phone": "+70676749808"}
0005432425622	3A5F68	0132 391251	SVETLANA KUZNECOVA	{"email": "svetlanakuznecova1960@postgrespro.ru", "phone": "+70164777813"}
0005432425623	F08621	6716 062394	OLESYA IVANOVA	{"phone": "+70927868757"}
0005432425624	F08621	2615 159260	PETR STEPANOV	{"phone": "+70766842471"}
0005432425625	F08621	6365 162846	VITALIY VOLKOV	{"email": "v.volkov-051976@postgrespro.ru", "phone": "+70156566467"}
0005432425626	E6484A	9905 163332	TIMOFEY ALEKSEEV	{"email": "t.alekseev_1980@postgrespro.ru", "phone": "+70184610604"}
0005432425627	1027BE	0170 771925	LYUDMILA KOROLEVA	{"phone": "+70136965905"}
0005432425628	1027BE	7554 764543	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov-041976@postgrespro.ru", "phone": "+70228646850"}
0005432425629	49C3BB	7909 063899	IVAN BORISOV	{"email": "borisovi.13111980@postgrespro.ru", "phone": "+70367842129"}
0005432425630	04BBA0	4893 661851	VLADIMIR VOLKOV	{"email": "volkov.v_021977@postgrespro.ru", "phone": "+70615485926"}
0005432425631	5DF4EC	1476 704522	LYUDMILA KOROLEVA	{"email": "lkoroleva_1970@postgrespro.ru", "phone": "+70919236227"}
0005432425632	5DF4EC	7128 894730	ARTEM MOISEEV	{"email": "moiseev.a_111973@postgrespro.ru", "phone": "+70127353940"}
0005432425633	DED09D	4839 696607	ALEKSANDR KOZLOV	{"email": "a-kozlov_1976@postgrespro.ru", "phone": "+70700712541"}
0005432425634	F9569D	1159 254741	VLADIMIR AFANASEV	{"email": "afanasev-v_14081966@postgrespro.ru", "phone": "+70275011447"}
0005432425635	EC43F9	0302 450671	MARINA ABRAMOVA	{"phone": "+70438260443"}
0005432425636	DCB6D0	7755 182566	TATYANA NIKITINA	{"email": "nikitina_tatyana.21091971@postgrespro.ru", "phone": "+70646735468"}
0005432425637	A79153	1862 382409	VLADIMIR SERGEEV	{"email": "v-sergeev.021986@postgrespro.ru", "phone": "+70023110188"}
0005432425638	132689	7976 896407	ANASTASIYA FILATOVA	{"email": "anastasiya.filatova-07021966@postgrespro.ru", "phone": "+70120493604"}
0005432425639	F7A2B1	3335 476594	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr-1971@postgrespro.ru", "phone": "+70290121594"}
0005432425640	9F856C	9779 656060	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov091977@postgrespro.ru", "phone": "+70850289205"}
0005432425641	9F856C	9039 220708	IGOR KUZMIN	{"email": "igor_kuzmin-041978@postgrespro.ru", "phone": "+70753164319"}
0005432425642	9F856C	0558 758697	VALENTIN VOROBEV	{"phone": "+70850274278"}
0005432425643	0DC9C1	5966 347447	LEYLA ISAEVA	{"phone": "+70657803434"}
0005432425644	56583F	9095 170676	VLADIMIR FROLOV	{"email": "frolov_vladimir11091975@postgrespro.ru", "phone": "+70493734841"}
0005432425645	236255	8282 846981	ALINA GUSEVA	{"email": "gusevaa.101973@postgrespro.ru", "phone": "+70497114956"}
0005432425705	052A8C	1015 945504	OLGA POTAPOVA	{"phone": "+70239939152"}
0005432425646	236255	7642 632766	NATALYA GUSEVA	{"email": "guseva-n1965@postgrespro.ru", "phone": "+70722941920"}
0005432425647	F28073	3490 051129	ANATOLIY FROLOV	{"phone": "+70229012247"}
0005432425648	091D68	4723 188436	MARIYA PAVLOVA	{"email": "m_pavlova.26011970@postgrespro.ru", "phone": "+70096157808"}
0005432425649	010084	2591 539736	NINA SMIRNOVA	{"phone": "+70714200612"}
0005432425650	010084	8949 827480	YURIY KULIKOV	{"phone": "+70967190452"}
0005432425651	68410F	7900 455238	ALEKSANDR KOROLEV	{"email": "a.korolev.121975@postgrespro.ru", "phone": "+70916268298"}
0005432425652	8B7AEE	6929 486375	SERGEY AFANASEV	{"email": "sergeyafanasev081983@postgrespro.ru", "phone": "+70166818739"}
0005432425653	E2D246	5878 237445	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov_071982@postgrespro.ru", "phone": "+70447318964"}
0005432425654	E2D246	6633 570078	MIKHAIL IVANOV	{"email": "ivanov.m-021967@postgrespro.ru", "phone": "+70876251119"}
0005432425655	4AFCA7	2467 146985	RAISA YAKOVLEVA	{"email": "r.yakovleva_081979@postgrespro.ru", "phone": "+70556393051"}
0005432425656	C14DA6	6318 227397	SVETLANA ARKHIPOVA	{"email": "s.arkhipova.031982@postgrespro.ru", "phone": "+70113544726"}
0005432425657	C14DA6	9514 819894	LYUDMILA SEMENOVA	{"phone": "+70947983775"}
0005432425658	F35651	8983 811257	ALINA KUZMINA	{"email": "a.kuzmina_02021972@postgrespro.ru", "phone": "+70328464103"}
0005432425659	F35651	2699 283774	ILYAS FEDOTOV	{"phone": "+70970617807"}
0005432425660	B422CB	2328 486468	VASILISA YUDINA	{"email": "yudina_v.071972@postgrespro.ru", "phone": "+70195661113"}
0005432425661	24A135	6029 574713	ALEKSANDR DMITRIEV	{"email": "dmitrieva.071978@postgrespro.ru", "phone": "+70695403224"}
0005432425662	A93684	5638 345049	IRINA IVANOVA	{"phone": "+70118519945"}
0005432425663	608C3B	9419 308930	NATALYA KUDRYASHOVA	{"phone": "+70769026597"}
0005432425664	608C3B	1382 614418	TATYANA ZAYCEVA	{"email": "tatyana_zayceva-081971@postgrespro.ru", "phone": "+70985696396"}
0005432425665	E922B4	7908 843132	NELLI ANTONOVA	{"email": "n.antonova28121971@postgrespro.ru", "phone": "+70692672459"}
0005432425666	6CF2D1	8907 187452	EKATERINA ISAEVA	{"email": "isaeva.ekaterina051976@postgrespro.ru", "phone": "+70726462658"}
0005432425667	423438	1531 414155	LIDIYA MATVEEVA	{"email": "lidiya_matveeva_1970@postgrespro.ru", "phone": "+70331090737"}
0005432425668	AFEB7A	1733 377185	OLGA IVANOVA	{"phone": "+70757232760"}
0005432425669	D7EE09	1792 644194	SERGEY MAKAROV	{"email": "sergey_makarov.12021965@postgrespro.ru", "phone": "+70339268143"}
0005432425670	E8B016	6118 940616	MARINA SAVELEVA	{"email": "saveleva.m011982@postgrespro.ru", "phone": "+70838954122"}
0005432425671	E8B016	3607 154493	GALINA KRASNOVA	{"email": "galinakrasnova091981@postgrespro.ru", "phone": "+70979763625"}
0005432425672	E81257	5971 957251	NIKITA MOROZOV	{"email": "morozov_n1975@postgrespro.ru", "phone": "+70340402721"}
0005432425673	061922	9917 935649	MARINA ZAKHAROVA	{"phone": "+70316917395"}
0005432425674	412B79	5362 665246	NIKITA ILIN	{"phone": "+70962016673"}
0005432425675	71044F	3638 385425	ANDREY MIKHAYLOV	{"phone": "+70052331911"}
0005432425676	2EFCED	6498 615510	NIKOLAY VOLKOV	{"phone": "+70306720885"}
0005432425677	2EFCED	4446 107641	ANNA VASILEVA	{"phone": "+70840578976"}
0005432425678	2EFCED	0594 518358	RAZIYA LEBEDEVA	{"phone": "+70112894564"}
0005432425679	5B117C	8857 040023	ANASTASIYA MAKAROVA	{"phone": "+70825185382"}
0005432425680	0EB2F3	1729 958611	TAISIYA ARKHIPOVA	{"email": "t_arkhipova06061972@postgrespro.ru", "phone": "+70395305456"}
0005432425681	0EB2F3	7971 987563	GLEB SERGEEV	{"email": "sergeevg_09011965@postgrespro.ru", "phone": "+70777834806"}
0005432425682	0EB2F3	3993 309487	ELENA VASILEVA	{"email": "elena_vasileva.1968@postgrespro.ru", "phone": "+70132763828"}
0005432425683	37526E	0461 706701	ALEKSEY SCHERBAKOV	{"phone": "+70515124960"}
0005432425684	A2A9BE	8421 409068	ALEKSEY IVANOV	{"phone": "+70547795753"}
0005432425685	47F555	5711 124509	ANATOLIY ISAEV	{"email": "isaev-a081974@postgrespro.ru", "phone": "+70445076650"}
0005432425686	47F555	5207 453171	VERONIKA NIKOLAEVA	{"phone": "+70498355952"}
0005432425687	8FBB67	7674 333772	GENNADIY ANTONOV	{"email": "gennadiy-antonov13111979@postgrespro.ru", "phone": "+70594419482"}
0005432425688	4994B5	3495 033761	OLESYA ISAEVA	{"email": "oisaeva-1975@postgrespro.ru", "phone": "+70221851614"}
0005432425689	A0E08B	2730 358169	OLGA KUZNECOVA	{"email": "kuznecova_o-1972@postgrespro.ru", "phone": "+70516060280"}
0005432425690	28B2FF	9966 727851	IRINA NIKOLAEVA	{"email": "i-nikolaeva-031975@postgrespro.ru", "phone": "+70378949648"}
0005432425691	28B2FF	6714 032162	IVAN SCHERBAKOV	{"phone": "+70759221926"}
0005432425692	DCC369	7218 820430	VASILIY FEDOTOV	{"phone": "+70716703526"}
0005432425693	DCC369	8395 650762	ANNA POPOVA	{"phone": "+70162027611"}
0005432425694	31CC1D	1825 004054	IGOR IVANOV	{"phone": "+70926003885"}
0005432425695	7F2F21	2841 324206	VALERIYA SMIRNOVA	{"phone": "+70124599733"}
0005432425696	7F2F21	4039 505860	RAFAIL BARANOV	{"email": "rafail.baranov_101960@postgrespro.ru", "phone": "+70510218348"}
0005432425697	7F2F21	3879 720817	ALEKSEY KAZAKOV	{"email": "aleksey.kazakov-25121968@postgrespro.ru", "phone": "+70411480068"}
0005432425698	C4ACD6	2758 915599	VERA SCHERBAKOVA	{"phone": "+70518063924"}
0005432425699	C4ACD6	2377 263773	DIANA MAKAROVA	{"email": "d-makarova_121960@postgrespro.ru", "phone": "+70436002378"}
0005432425700	EDFE12	7834 838440	NADEZHDA DENISOVA	{"phone": "+70418615861"}
0005432425701	F189DB	9233 601676	ALEKSANDRA ZAKHAROVA	{"email": "a-zakharova1977@postgrespro.ru", "phone": "+70714854380"}
0005432425702	6B73EA	4298 089897	ALEKSANDRA IVANOVA	{"email": "aleksandraivanova.11031974@postgrespro.ru", "phone": "+70545154521"}
0005432425703	68FBC9	1544 990149	YULIYA STEPANOVA	{"email": "yuliya-stepanova041973@postgrespro.ru", "phone": "+70061055413"}
0005432425704	052A8C	9211 037249	ANATOLIY OSIPOV	{"email": "a_osipov.05011970@postgrespro.ru", "phone": "+70609465736"}
0005432425706	663500	8776 884391	TATYANA OSIPOVA	{"email": "osipova_t_1968@postgrespro.ru", "phone": "+70475712060"}
0005432425707	D15B83	6354 162590	LIDIYA SOROKINA	{"phone": "+70024859573"}
0005432425708	D15B83	8385 734695	OLGA SAVELEVA	{"phone": "+70394636175"}
0005432425709	D15B83	9033 384245	ILYA ORLOV	{"email": "orlov.i.081978@postgrespro.ru", "phone": "+70160150487"}
0005432425710	C5C7C0	4397 375008	SERGEY SOLOVEV	{"email": "solovev_s-05091970@postgrespro.ru", "phone": "+70056194963"}
0005432425711	F7736F	1437 717100	OLEG ZHURAVLEV	{"email": "zhuravlevoleg.1968@postgrespro.ru", "phone": "+70815082251"}
0005432425712	A44134	2264 862830	ARSENIY VASILEV	{"email": "vasilev.a-1972@postgrespro.ru", "phone": "+70394810929"}
0005432425713	A44134	1217 023217	TATYANA ANISIMOVA	{"phone": "+70748849554"}
0005432425714	6B14A1	1930 418954	ALEKSEY MEDVEDEV	{"email": "medvedev_a_08061977@postgrespro.ru", "phone": "+70564657077"}
0005432425715	6B14A1	6216 375641	IRINA STEPANOVA	{"phone": "+70341464924"}
0005432425716	1C53C7	2917 501893	OLGA LUKYANOVA	{"phone": "+70736331524"}
0005432425717	EB06BF	1337 373246	DMITRIY SOKOLOV	{"email": "d_sokolov_1966@postgrespro.ru", "phone": "+70643106119"}
0005432425718	3FDA5F	7538 862698	VALERIY FROLOV	{"phone": "+70830939334"}
0005432425719	3FDA5F	2680 652517	ELENA FEDOROVA	{"email": "fedorova_e_19091959@postgrespro.ru", "phone": "+70166853315"}
0005432425720	C84D2A	0343 363184	ALENA STEPANOVA	{"phone": "+70728524977"}
0005432425721	0760F8	2014 241541	YAROSLAV NAUMOV	{"phone": "+70146406978"}
0005432425722	0760F8	8444 265686	ZOYA MASLOVA	{"email": "maslova.z.081973@postgrespro.ru", "phone": "+70556797970"}
0005432425723	C1A119	0825 115531	VADIM IVANOV	{"phone": "+70562533721"}
0005432425724	977B0B	9095 721118	VYACHESLAV SOROKIN	{"email": "sorokin.vyacheslav-021970@postgrespro.ru", "phone": "+70491304699"}
0005432425725	F6C076	0640 658007	NADEZHDA KUZNECOVA	{"email": "kuznecovan.22041977@postgrespro.ru", "phone": "+70692973558"}
0005432425726	F6C076	8207 495960	VALENTINA ANISIMOVA	{"phone": "+70266502395"}
0005432425727	0EE9A7	6774 736974	GALINA EGOROVA	{"phone": "+70640525579"}
0005432425728	0EE9A7	8280 610345	NIKOLAY BARANOV	{"email": "n_baranov-1979@postgrespro.ru", "phone": "+70639979324"}
0005432425729	56E4FC	9661 286352	NATALIYA MELNIKOVA	{"email": "nataliya_melnikova-24071972@postgrespro.ru", "phone": "+70852568722"}
0005432425730	2E984C	7675 015136	VIKTORIYA ANDREEVA	{"email": "andreeva-v1964@postgrespro.ru", "phone": "+70188452071"}
0005432425731	2E984C	3931 065825	VADIM VLASOV	{"email": "vlasov-vadim1964@postgrespro.ru", "phone": "+70099846141"}
0005432425732	08E3FA	7329 960306	TATYANA MAKAROVA	{"phone": "+70191608166"}
0005432425733	7C2E46	9847 874677	YURIY KUDRYASHOV	{"email": "kudryashov.y121971@postgrespro.ru", "phone": "+70333817378"}
0005432425734	982576	7322 658284	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr.13071979@postgrespro.ru", "phone": "+70238440977"}
0005432425735	97CF93	4145 166855	RUZALIYA KALININA	{"phone": "+70183439790"}
0005432425736	538025	1555 663648	VITALIY FOMIN	{"email": "fominv-1971@postgrespro.ru", "phone": "+70601345890"}
0005432425737	B27B60	0483 304919	ALEKSANDR MAKAROV	{"email": "a_makarov_1967@postgrespro.ru", "phone": "+70969432513"}
0005432425738	864752	5789 454267	ALEKSANDR POPOV	{"email": "popov-a.051971@postgrespro.ru", "phone": "+70080434300"}
0005432425739	DB3D80	8731 571087	ELENA CHERNOVA	{"email": "elena_chernova02101963@postgrespro.ru", "phone": "+70219664772"}
0005432425740	160789	6019 530393	ELENA NAUMOVA	{"phone": "+70484843854"}
0005432425741	160789	6548 079526	NADEZHDA YUDINA	{"phone": "+70804976745"}
0005432425742	7F1119	7176 248768	ALLA VASILEVA	{"phone": "+70564930682"}
0005432425743	A61189	6288 419332	ALEKSEY SHEVCHENKO	{"email": "ashevchenko.1973@postgrespro.ru", "phone": "+70812048571"}
0005432425744	A61189	7197 245254	OLGA GORBUNOVA	{"email": "gorbunova.olga.051964@postgrespro.ru", "phone": "+70860516437"}
0005432425745	CA9A29	4972 070174	ELENA ORLOVA	{"phone": "+70447345254"}
0005432425746	CA9A29	0433 054104	MAKSIM KUZMIN	{"email": "kuzmin.maksim_031957@postgrespro.ru", "phone": "+70605322922"}
0005432425747	481123	6496 326459	NIKITA ALEKSANDROV	{"email": "aleksandrovnikita-1970@postgrespro.ru", "phone": "+70024488910"}
0005432425748	570ED4	5625 735591	ALEKSANDR TIMOFEEV	{"phone": "+70695189140"}
0005432425749	570ED4	1693 623922	MARINA GUSEVA	{"email": "gusevam051969@postgrespro.ru", "phone": "+70658962522"}
0005432425750	570ED4	9466 581895	FARID GUSEV	{"email": "gusev-farid.1964@postgrespro.ru", "phone": "+70582676023"}
0005432425751	62758A	0378 792604	DMITRIY ANTONOV	{"email": "d-antonov-1970@postgrespro.ru", "phone": "+70697807112"}
0005432425752	62758A	9529 860651	ANNA IVANOVA	{"email": "ivanova.a-20051954@postgrespro.ru", "phone": "+70587121108"}
0005432425753	4A784E	2414 502816	SERGEY NAZAROV	{"email": "s.nazarov_1983@postgrespro.ru", "phone": "+70478954086"}
0005432425754	D9A6CC	3420 134421	IRINA FEDOROVA	{"email": "fedorova_irina.04031968@postgrespro.ru", "phone": "+70182680433"}
0005432425755	3D29B4	6312 026277	NATALYA MOROZOVA	{"email": "natalya-morozova-1976@postgrespro.ru", "phone": "+70782600887"}
0005432425756	3D29B4	1022 508671	ANDREY ZAKHAROV	{"phone": "+70167472216"}
0005432425757	1263A0	5742 426543	VITALIY KUZMIN	{"phone": "+70093148849"}
0005432425758	1263A0	8445 304434	TATYANA SOLOVEVA	{"email": "soloveva.t_30071977@postgrespro.ru", "phone": "+70121591506"}
0005432425759	235DC0	7571 367895	ALEKSEY SOKOLOV	{"phone": "+70859549932"}
0005432425760	E7468E	0963 953999	SANIYA MAKAROVA	{"phone": "+70593372989"}
0005432425761	E7468E	0432 860341	KSENIYA KONOVALOVA	{"phone": "+70074624241"}
0005432425762	C02364	1612 523050	DARYA MOISEEVA	{"email": "d.moiseeva28101969@postgrespro.ru", "phone": "+70761110152"}
0005432425763	458C7F	4709 056903	ELENA KULIKOVA	{"phone": "+70612527322"}
0005432425764	5F5178	4721 446794	ALEKSANDR IVANOV	{"phone": "+70171665012"}
0005432425765	41F3CC	7119 945380	SERGEY ANDREEV	{"phone": "+70001858599"}
0005432425766	46540B	7321 370476	SERGEY SMIRNOV	{"phone": "+70933427194"}
0005432425767	46540B	8876 669422	OLGA MAKSIMOVA	{"email": "olga_maksimova.1969@postgrespro.ru", "phone": "+70253237257"}
0005432425768	CEB82B	4061 994634	ELENA BELOVA	{"email": "e_belova.02101973@postgrespro.ru", "phone": "+70316061092"}
0005432425769	C9468B	9465 765925	GALINA ISAEVA	{"email": "isaeva_galina111973@postgrespro.ru", "phone": "+70765085242"}
0005432425770	C9468B	0293 635283	DENIS YAKOVLEV	{"email": "yakovlev-denis1983@postgrespro.ru", "phone": "+70225760115"}
0005432425771	C9468B	7997 574603	MARINA VLASOVA	{"email": "vlasova.m.121978@postgrespro.ru", "phone": "+70620898096"}
0005432425772	906F56	6796 027532	VLADIMIR RODIONOV	{"email": "v.rodionov-1976@postgrespro.ru", "phone": "+70990226592"}
0005432425773	906F56	8493 853892	ALEKSEY SEMENOV	{"phone": "+70053461381"}
0005432425774	09BFDC	9633 286698	VLADISLAV BONDARENKO	{"email": "bondarenkov1970@postgrespro.ru", "phone": "+70712672210"}
0005432425775	09BFDC	8686 737732	TALGAT MEDVEDEV	{"email": "medvedev-talgat12081975@postgrespro.ru", "phone": "+70977701051"}
0005432425776	D05BDE	7744 788699	VARVARA MIRONOVA	{"email": "mironova-varvara-1961@postgrespro.ru", "phone": "+70720204317"}
0005432425777	21560D	6307 678486	RIMMA KAZAKOVA	{"email": "r-kazakova_041974@postgrespro.ru", "phone": "+70098878273"}
0005432425778	21560D	8638 820235	MARIYA SEMENOVA	{"phone": "+70946716111"}
0005432425779	BBA70C	3777 065655	ANNA EGOROVA	{"phone": "+70718152889"}
0005432425780	BBA70C	8062 839361	IVAN ZAKHAROV	{"phone": "+70331908980"}
0005432425781	C2DFC5	6589 431543	ANATOLIY IVANOV	{"email": "a.ivanov-081969@postgrespro.ru", "phone": "+70563453293"}
0005432425782	A3183E	4358 649725	NATALYA MEDVEDEVA	{"phone": "+70886011529"}
0005432425783	D51D2A	8711 712341	ALEKSEY KISELEV	{"email": "aleksey_kiselev_121968@postgrespro.ru", "phone": "+70280577628"}
0005432425784	88A657	6863 735862	NINA SERGEEVA	{"email": "sergeevan.081964@postgrespro.ru", "phone": "+70461052703"}
0005432425785	6018AE	5067 196867	DARYA KUZNECOVA	{"phone": "+70947901984"}
0005432425786	B13AAE	6034 769290	EVGENIY POPOV	{"email": "popov_evgeniy081983@postgrespro.ru", "phone": "+70036400771"}
0005432425787	8549C3	3309 573572	RUSLAN SEMENOV	{"email": "semenov_r101975@postgrespro.ru", "phone": "+70453355787"}
0005432425788	EEFB76	0302 492079	YURIY TARASOV	{"email": "yuriy-tarasov_01061966@postgrespro.ru", "phone": "+70885216136"}
0005432425789	BF8032	6200 385859	KRISTINA MEDVEDEVA	{"email": "medvedeva-k-11051968@postgrespro.ru", "phone": "+70055888606"}
0005432425790	40E452	7481 808192	LYUBOV IVANOVA	{"email": "lyubov-ivanova.25031970@postgrespro.ru", "phone": "+70517072064"}
0005432425791	B53894	8284 155580	LIDIYA MAKSIMOVA	{"email": "l.maksimova.23021964@postgrespro.ru", "phone": "+70999315692"}
0005432425792	B53894	5858 603905	VITALIY PETROV	{"phone": "+70857492547"}
0005432425793	44DB03	8427 910333	ELENA FILIPPOVA	{"email": "filippova.elena-1965@postgrespro.ru", "phone": "+70509384088"}
0005432425794	176C93	7141 727261	DANIL SIDOROV	{"email": "danil.sidorov1975@postgrespro.ru", "phone": "+70122871607"}
0005432425795	D21209	0796 835501	MARAT SHEVCHENKO	{"phone": "+70995711245"}
0005432425796	D21209	8320 339375	ANNA ZHURAVLEVA	{"email": "zhuravleva.anna_1977@postgrespro.ru", "phone": "+70448330122"}
0005432425797	D21209	0597 501683	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr091974@postgrespro.ru", "phone": "+70967843804"}
0005432425798	28E67D	9540 517357	TAMARA POLYAKOVA	{"phone": "+70687309793"}
0005432425799	28E67D	6576 401576	ALEKSEY MOROZOV	{"phone": "+70575087866"}
0005432425800	B60A4D	9428 798906	PAVEL BORISOV	{"phone": "+70467120823"}
0005432425801	B60A4D	4523 702437	NIKOLAY KUZNECOV	{"phone": "+70636278957"}
0005432425802	80E067	4800 831501	LARISA IVANOVA	{"email": "larisa-ivanova-091963@postgrespro.ru", "phone": "+70178059881"}
0005432425803	C440BC	5006 380223	ELENA EGOROVA	{"email": "e.egorova-1970@postgrespro.ru", "phone": "+70447923491"}
0005432425804	1D9196	0744 394633	MARINA SOLOVEVA	{"phone": "+70188180287"}
0005432425805	1D9196	6685 290970	ALEKSANDR DMITRIEV	{"email": "a.dmitriev-02031966@postgrespro.ru", "phone": "+70091901632"}
0005432425806	CA974A	7881 476765	IVAN VOLKOV	{"phone": "+70097916867"}
0005432425807	11A944	3666 516614	SVETLANA FILIPPOVA	{"phone": "+70124174332"}
0005432425808	FFD6E5	6766 656412	DMITRIY SMIRNOV	{"email": "d_smirnov.1975@postgrespro.ru", "phone": "+70535119527"}
0005432425809	857207	4452 900160	NATALIYA FOMINA	{"email": "n_fomina-12061960@postgrespro.ru", "phone": "+70841041605"}
0005432425810	00434B	8825 358742	TATYANA EFIMOVA	{"phone": "+70757825358"}
0005432425811	3FA6DF	0793 305297	SVETLANA SOLOVEVA	{"phone": "+70200511695"}
0005432425812	E2F7B8	1216 482974	FATIMA KISELEVA	{"email": "kiselevaf31011964@postgrespro.ru", "phone": "+70665404373"}
0005432425813	E2F7B8	9473 760708	DMITRIY PETROV	{"email": "dmitriy-petrov-30081975@postgrespro.ru", "phone": "+70710355982"}
0005432425814	8FF660	7861 885402	SVETLANA RODIONOVA	{"email": "s-rodionova011974@postgrespro.ru", "phone": "+70763506842"}
0005432425815	C90E28	8680 884901	VALENTINA ZOTOVA	{"phone": "+70137030998"}
0005432425816	0497D7	2561 018488	ANATOLIY SOKOLOV	{"email": "a_sokolov.041970@postgrespro.ru", "phone": "+70666423428"}
0005432425817	0497D7	6687 820637	IRINA PETROVA	{"email": "irina_petrova-22101976@postgrespro.ru", "phone": "+70717701953"}
0005432425818	9971B8	4516 363946	MIKHAIL PAVLOV	{"phone": "+70101217211"}
0005432425819	D519BB	2255 168809	GALINA SIDOROVA	{"email": "sidorova_galina-1980@postgrespro.ru", "phone": "+70259436817"}
0005432425820	D519BB	4081 748368	ELENA GERASIMOVA	{"email": "elenagerasimova-1968@postgrespro.ru", "phone": "+70626914832"}
0005432425821	4053B3	9130 103205	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev1967@postgrespro.ru", "phone": "+70441655376"}
0005432425822	BF6761	0032 140478	TATYANA MATVEEVA	{"email": "matveeva.tatyana.1968@postgrespro.ru", "phone": "+70735610751"}
0005432425823	BF6761	6576 335969	ANDREY SOKOLOV	{"phone": "+70420276612"}
0005432425824	CF499F	4762 890850	SERGEY MOISEEV	{"email": "moiseevs-1974@postgrespro.ru", "phone": "+70456456232"}
0005432425825	D87072	6594 545060	NIKOLAY ZHUKOV	{"email": "zhukov-n-091968@postgrespro.ru", "phone": "+70867275459"}
0005432425826	1FA9CE	1575 913547	KSENIYA TARASOVA	{"email": "k-tarasova1973@postgrespro.ru", "phone": "+70436381395"}
0005432425827	FA2637	7054 197301	MARIYA IVANOVA	{"phone": "+70534584173"}
0005432425828	FA2637	9978 297722	TAMARA NIKOLAEVA	{"phone": "+70786659355"}
0005432425829	6A348A	0715 211221	ZINAIDA LAZAREVA	{"email": "zinaida.lazareva-01061962@postgrespro.ru", "phone": "+70713171689"}
0005432425830	6A348A	4495 883609	TAMARA AKIMOVA	{"email": "akimovatamara-1973@postgrespro.ru", "phone": "+70722583094"}
0005432425831	88D39A	3842 686710	LIDIYA MALYSHEVA	{"phone": "+70610378931"}
0005432425832	9D0404	5501 447533	MIKHAIL MELNIKOV	{"phone": "+70077255785"}
0005432425833	68CFC3	6323 693491	NATALYA KISELEVA	{"phone": "+70720040770"}
0005432425834	68CFC3	4178 913464	DMITRIY ANDREEV	{"email": "andreevd1988@postgrespro.ru", "phone": "+70669857724"}
0005432425835	68CFC3	2681 552628	NATALYA BOGDANOVA	{"phone": "+70490539632"}
0005432425836	7A5F0F	0883 795840	VASILIY IVANOV	{"phone": "+70168011338"}
0005432425837	27B62F	1780 036597	OKSANA KONOVALOVA	{"email": "konovalova_oksana-1972@postgrespro.ru", "phone": "+70997425441"}
0005432425838	CFBC1B	7027 365440	NIKOLAY YAKOVLEV	{"email": "yakovlev-n121976@postgrespro.ru", "phone": "+70503081489"}
0005432425839	CA4B84	5627 342520	ANTON PAVLOV	{"phone": "+70161584636"}
0005432425840	B23283	6419 237558	ANNA VOLKOVA	{"email": "a.volkova-23091972@postgrespro.ru", "phone": "+70599176729"}
0005432425841	3F394B	7900 762299	SERGEY GERASIMOV	{"email": "sergey-gerasimov.28031980@postgrespro.ru", "phone": "+70976291084"}
0005432425842	3F394B	8795 077589	PETR IVANOV	{"phone": "+70437451362"}
0005432425843	6BEA6A	3553 469941	VALERIY POPOV	{"email": "popov.valeriy.1983@postgrespro.ru", "phone": "+70828448633"}
0005432425844	73D4F6	5854 064607	ANGELINA KUDRYASHOVA	{"phone": "+70392249182"}
0005432425845	7567A5	7211 828081	NADEZHDA ZAYCEVA	{"email": "zayceva.n1962@postgrespro.ru", "phone": "+70108977254"}
0005432425846	7567A5	8658 902752	KIRILL POPOV	{"email": "k.popov081959@postgrespro.ru", "phone": "+70772533571"}
0005432425847	7567A5	9856 727152	MIKHAIL KOROLEV	{"email": "m_korolev-27061979@postgrespro.ru", "phone": "+70451663656"}
0005432425848	70DB2C	0136 363222	ARTEM ZHUKOV	{"email": "zhukova07031967@postgrespro.ru", "phone": "+70031070801"}
0005432425849	70DB2C	1624 043252	ANATOLIY IVANOV	{"email": "a-ivanov.051972@postgrespro.ru", "phone": "+70058505582"}
0005432425850	DE0BA8	4354 919567	SERGEY ILIN	{"phone": "+70908823292"}
0005432425851	555A7C	4701 909524	OKSANA POPOVA	{"email": "popova.o1956@postgrespro.ru", "phone": "+70000703721"}
0005432425852	555A7C	4267 947748	VYACHESLAV FILIPPOV	{"email": "filippovvyacheslav-1966@postgrespro.ru", "phone": "+70153745039"}
0005432425853	555A7C	0452 398441	ANNA IVANOVA	{"email": "ivanova-a-021953@postgrespro.ru", "phone": "+70925218868"}
0005432425854	2ED90A	3924 850010	MARGARITA TITOVA	{"email": "mtitova1963@postgrespro.ru", "phone": "+70422581944"}
0005432425855	BF3BF6	1035 550607	SERGEY ROMANOV	{"phone": "+70507701058"}
0005432425856	BF3BF6	5873 610364	ELENA VASILEVA	{"phone": "+70523423023"}
0005432425857	72D1F6	4887 971408	ALEKSANDR PETROV	{"email": "a_petrov051965@postgrespro.ru", "phone": "+70916124856"}
0005432425858	D1BEED	9287 617858	TAISIYA VASILEVA	{"phone": "+70586210122"}
0005432425859	D1BEED	7884 050336	ANATOLIY NIKOLAEV	{"phone": "+70349988887"}
0005432425860	D1BEED	2604 383744	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov.121959@postgrespro.ru", "phone": "+70733418288"}
0005432425861	268BB8	5803 901602	MARIYA MARTYNOVA	{"email": "m-martynova05121979@postgrespro.ru", "phone": "+70144827103"}
0005432425862	316DD6	4678 229005	VLADIMIR ZHURAVLEV	{"email": "vladimir-zhuravlev.19031973@postgrespro.ru", "phone": "+70965110046"}
0005432425863	316DD6	3029 409249	GRIGORIY PAVLOV	{"phone": "+70822281605"}
0005432425864	028FF0	6737 131464	VLADIMIR MOROZOV	{"phone": "+70628754746"}
0005432425865	8BA695	7998 572440	SVETLANA KUZMINA	{"phone": "+70339741855"}
0005432425866	8BA695	8256 842964	MARGARITA ROMANOVA	{"email": "romanova-m.1968@postgrespro.ru", "phone": "+70852391485"}
0005432425867	419CFB	2354 179309	YULIYA NAZAROVA	{"email": "ynazarova121974@postgrespro.ru", "phone": "+70455111043"}
0005432425868	419CFB	9686 267905	VIKTOR ZHURAVLEV	{"phone": "+70203355334"}
0005432425869	F896FF	0752 582199	EVGENIY BELOV	{"phone": "+70145651743"}
0005432425870	FA3C80	1991 722956	OLGA DANILOVA	{"phone": "+70300430357"}
0005432425871	6419BA	5061 551498	ALEKSANDRA SOLOVEVA	{"phone": "+70382343636"}
0005432425872	C0AD04	1326 649134	NINA SIDOROVA	{"phone": "+70705455317"}
0005432425873	BC2756	1251 889006	ANATOLIY OSIPOV	{"phone": "+70025925792"}
0005432425874	0414D9	5292 425870	ALEKSEY MAKSIMOV	{"email": "maksimovaleksey_1974@postgrespro.ru", "phone": "+70910926134"}
0005432425875	CEFE72	7412 577398	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-valentina_05111968@postgrespro.ru", "phone": "+70609011771"}
0005432425876	A7BD70	7336 339675	GENNADIY STEPANOV	{"email": "gennadiystepanov1978@postgrespro.ru", "phone": "+70811404877"}
0005432425877	53A9E1	6465 134531	VALERIY NIKOLAEV	{"phone": "+70399757979"}
0005432425878	53A9E1	4778 152680	OLGA DENISOVA	{"email": "o-denisova-09041973@postgrespro.ru", "phone": "+70633675511"}
0005432425879	FBB9C9	6701 297092	VYACHESLAV STEPANOV	{"email": "vyacheslavstepanov.061983@postgrespro.ru", "phone": "+70542211075"}
0005432425880	FBB9C9	1989 127471	TAMARA EGOROVA	{"phone": "+70649132751"}
0005432425881	B66C38	6579 334851	OLEG ZHUKOV	{"email": "o_zhukov.1972@postgrespro.ru", "phone": "+70119817260"}
0005432425882	D02270	2228 818661	KIRILL ROMANOV	{"email": "romanovk-23011965@postgrespro.ru", "phone": "+70909640277"}
0005432425883	68142E	0063 017445	TAMARA ERMAKOVA	{"email": "ermakova_t.031980@postgrespro.ru", "phone": "+70353913188"}
0005432425884	68142E	9518 884312	NATALYA IVANOVA	{"phone": "+70666958502"}
0005432425885	AD5D79	5268 558401	EVDOKIYA EGOROVA	{"email": "eegorova1980@postgrespro.ru", "phone": "+70315313694"}
0005432425886	D2941A	7968 613964	ANDREY KUZNECOV	{"phone": "+70527452265"}
0005432425887	9CC566	3943 145181	VALENTINA GRISHINA	{"email": "v.grishina-051972@postgrespro.ru", "phone": "+70748511991"}
0005432425888	2FEF6B	0775 777484	MIKHAIL MAKAROV	{"email": "mikhail_makarov.02021965@postgrespro.ru", "phone": "+70863832493"}
0005432425889	2FEF6B	3709 104514	LYUBOV KARPOVA	{"email": "karpovalyubov-05061974@postgrespro.ru", "phone": "+70187467470"}
0005432425890	46470D	9872 730000	NIKOLAY IVANOV	{"email": "ivanovnikolay.111967@postgrespro.ru", "phone": "+70426159709"}
0005432425891	C913BE	0338 911334	TAMARA POPOVA	{"email": "popova_tamara.1968@postgrespro.ru", "phone": "+70936529236"}
0005432425892	737FEB	9248 510459	VLADIMIR KRASNOV	{"phone": "+70521829088"}
0005432425893	85F19E	4587 592085	SERGEY VOLKOV	{"phone": "+70398860767"}
0005432425894	85F19E	0785 630041	IVAN DENISOV	{"email": "denisov-ivan-1967@postgrespro.ru", "phone": "+70300077456"}
0005432425895	3C60BC	6462 148914	VYACHESLAV FILIPPOV	{"email": "v.filippov-1962@postgrespro.ru", "phone": "+70585493526"}
0005432425896	3C60BC	6401 192820	DENIS FROLOV	{"phone": "+70115571801"}
0005432425897	802298	6818 321763	VARVARA BELYAEVA	{"email": "varvara_belyaeva-14061982@postgrespro.ru", "phone": "+70773896456"}
0005432425898	B2AF8E	7056 499469	IRINA ARKHIPOVA	{"phone": "+70302110041"}
0005432425899	0568CB	7280 832424	OLGA STEPANOVA	{"phone": "+70733295377"}
0005432425900	37895B	7758 245008	LILIYA SIDOROVA	{"phone": "+70720908174"}
0005432425901	37895B	2435 753369	TAMARA MOROZOVA	{"phone": "+70359800768"}
0005432425902	520EE9	6475 013041	MAKSIM PAVLOV	{"phone": "+70910782152"}
0005432425903	520EE9	6522 678639	EKATERINA MELNIKOVA	{"email": "melnikova.ekaterina_11041971@postgrespro.ru", "phone": "+70902313213"}
0005432425904	30841E	4708 451841	ELENA GUSEVA	{"phone": "+70875805544"}
0005432425905	03DDBC	8127 554306	ELENA KONOVALOVA	{"email": "elena.konovalova-09091980@postgrespro.ru", "phone": "+70200952997"}
0005432425906	03DDBC	0973 327150	ANTONINA FILIPPOVA	{"phone": "+70188812004"}
0005432425907	0804AC	0122 302703	TATYANA MIKHAYLOVA	{"phone": "+70292493893"}
0005432425908	3F24F0	5189 713673	RAISA ARKHIPOVA	{"phone": "+70885750436"}
0005432425909	3F24F0	1280 323138	NIKOLAY GAVRILOV	{"phone": "+70228632408"}
0005432425910	009AAD	8699 211372	NAIL SERGEEV	{"phone": "+70020493162"}
0005432425911	009AAD	0835 814848	MIKHAIL MIRONOV	{"email": "mikhailmironov.1973@postgrespro.ru", "phone": "+70219583787"}
0005432425912	CB42FE	6658 728776	LYUBOV GUSEVA	{"email": "lyubovguseva-03101976@postgrespro.ru", "phone": "+70947326685"}
0005432425913	AE7154	8783 911579	ELENA POPOVA	{"phone": "+70821084812"}
0005432425914	FFE069	8540 453347	VLADIMIR DAVYDOV	{"phone": "+70319372042"}
0005432425915	521DD0	8890 603576	ELENA KOVALEVA	{"email": "elenakovaleva_22121968@postgrespro.ru", "phone": "+70781453721"}
0005432425916	600B0A	0740 295426	EVGENIY SCHERBAKOV	{"email": "scherbakov.evgeniy.15121980@postgrespro.ru", "phone": "+70780190636"}
0005432425917	7BD603	6044 492026	PRASKOVYA FILIPPOVA	{"phone": "+70608202687"}
0005432425918	A0EDC7	8095 902867	MARIYA STEPANOVA	{"email": "mstepanova_09051974@postgrespro.ru", "phone": "+70032311094"}
0005432425919	A0EDC7	2324 139270	IGOR KUZMIN	{"email": "igor.kuzmin_1965@postgrespro.ru", "phone": "+70663395993"}
0005432425920	64271A	9618 059043	ALEKSANDR ANDREEV	{"email": "aleksandrandreev_101976@postgrespro.ru", "phone": "+70249427110"}
0005432425921	64271A	7358 166482	LILIYA GUSEVA	{"phone": "+70937889040"}
0005432425922	DF6028	8298 033421	ELENA POPOVA	{"email": "e_popova_06101976@postgrespro.ru", "phone": "+70304886312"}
0005432425923	3372FF	7951 687940	MARIYA NIKITINA	{"email": "m_nikitina21061981@postgrespro.ru", "phone": "+70298326747"}
0005432425924	5FB0B2	5758 598095	ALEKSANDR BARANOV	{"phone": "+70762476868"}
0005432425925	53739A	1424 206208	OLESYA IVANOVA	{"email": "o.ivanova.1969@postgrespro.ru", "phone": "+70998325544"}
0005432425926	53739A	8907 986487	ALEKSANDR MOROZOV	{"phone": "+70147405936"}
0005432425927	C89330	4830 811786	ALEKSEY SOKOLOV	{"phone": "+70977123254"}
0005432425928	1FDA34	4944 479371	ROMAN CHERNOV	{"phone": "+70283730139"}
0005432425929	5C8734	0561 868468	EVGENIYA EFIMOVA	{"phone": "+70118701182"}
0005432425930	A14364	6570 991720	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova021960@postgrespro.ru", "phone": "+70504572032"}
0005432425931	A14364	1337 351056	NINA KUZNECOVA	{"phone": "+70229142244"}
0005432425932	B83E30	5545 790118	VASILIY FILIPPOV	{"phone": "+70778780980"}
0005432425933	B83E30	9714 579913	PETR GORBUNOV	{"email": "petr.gorbunov-1973@postgrespro.ru", "phone": "+70086682590"}
0005432425934	DF366C	1204 007877	ANATOLIY BORISOV	{"email": "borisov_anatoliy.01091978@postgrespro.ru", "phone": "+70036104127"}
0005432425935	CC2DF0	3322 131070	ALEKSANDR BORISOV	{"email": "borisov.a.1974@postgrespro.ru", "phone": "+70150081836"}
0005432425936	CC2DF0	7761 132000	OLESYA KOLESNIKOVA	{"email": "kolesnikova_olesya_19041965@postgrespro.ru", "phone": "+70011493437"}
0005432425937	19C7B3	4579 097739	YULIYA ILINA	{"phone": "+70765362716"}
0005432425938	19C7B3	5513 045455	ILYA KOZLOV	{"phone": "+70683599078"}
0005432425939	3FA82E	7747 714138	VIKTOR FOMIN	{"phone": "+70771478502"}
0005432425940	3FA82E	1347 990663	NINA SOKOLOVA	{"phone": "+70532357274"}
0005432425941	1006F0	5865 950541	MIKHAIL GRIGOREV	{"email": "mikhail-grigorev-1976@postgrespro.ru", "phone": "+70391295647"}
0005432425942	F7359C	0347 987458	OLGA MELNIKOVA	{"phone": "+70389506587"}
0005432425943	69E7D9	3643 737405	MARIYA POPOVA	{"email": "popova-m.101987@postgrespro.ru", "phone": "+70512190692"}
0005432425944	69E7D9	5179 677412	ANASTASIYA AFANASEVA	{"phone": "+70517059376"}
0005432425945	3B4D5C	1760 481716	RUSLAN SCHERBAKOV	{"email": "ruslan-scherbakov_04011970@postgrespro.ru", "phone": "+70003877237"}
0005432425946	985C05	0018 737477	EVGENIY SOKOLOV	{"phone": "+70038505868"}
0005432425947	985C05	8431 955958	VALENTINA EGOROVA	{"email": "v-egorova.1968@postgrespro.ru", "phone": "+70567995340"}
0005432425948	1EF8F1	0510 505707	ANNA TITOVA	{"phone": "+70650273194"}
0005432425949	8BEA3A	7783 849424	NINA KUZNECOVA	{"email": "ninakuznecova1970@postgrespro.ru", "phone": "+70892535874"}
0005432425950	8BEA3A	1046 347670	OLEG SERGEEV	{"phone": "+70324714009"}
0005432425951	B0D27F	3235 222242	EKATERINA VASILEVA	{"phone": "+70288316933"}
0005432425952	6E3653	5245 327094	SERGEY RODIONOV	{"email": "rodionov_s081964@postgrespro.ru", "phone": "+70371113978"}
0005432425953	6E3653	0384 828618	OLEG ZAYCEV	{"phone": "+70955318262"}
0005432425954	6D9189	5356 145666	MARIYA FROLOVA	{"email": "frolova_m.22091975@postgrespro.ru", "phone": "+70041698655"}
0005432425955	22D7BC	5788 688277	VALENTINA NIKITINA	{"phone": "+70896823976"}
0005432425956	B45E38	6146 357488	YULIYA TITOVA	{"email": "yuliya_titova-061970@postgrespro.ru", "phone": "+70624186983"}
0005432425957	ECB673	0698 729121	TATYANA ABRAMOVA	{"email": "abramova-tatyana_011966@postgrespro.ru", "phone": "+70051632596"}
0005432425958	9D6A53	8508 594573	ANDREY SOKOLOV	{"phone": "+70132018861"}
0005432425959	ABE175	4783 579375	EKATERINA GORBUNOVA	{"email": "gorbunovaekaterina081979@postgrespro.ru", "phone": "+70418401243"}
0005432425960	ABE175	6286 291199	DMITRIY SOKOLOV	{"phone": "+70081224840"}
0005432425961	ABE175	3170 937012	NARIMAN POPOV	{"email": "popov_n_15011993@postgrespro.ru", "phone": "+70094297623"}
0005432425962	0D127E	8526 447572	VERA KARPOVA	{"email": "vera-karpova.1970@postgrespro.ru", "phone": "+70154194407"}
0005432425963	0D127E	6142 195912	LYUDMILA KUZMINA	{"email": "kuzmina_lyudmila1973@postgrespro.ru", "phone": "+70344495100"}
0005432425964	B7AB98	4318 461372	OLGA KOMAROVA	{"email": "o.komarova-1970@postgrespro.ru", "phone": "+70609843925"}
0005432425965	61CC81	0374 769892	ELENA SOROKINA	{"email": "sorokinae1962@postgrespro.ru", "phone": "+70152330920"}
0005432425966	61CC81	3718 120863	VLADISLAV TARASOV	{"email": "vtarasov31081967@postgrespro.ru", "phone": "+70687828416"}
0005432425967	0C697B	5502 552386	DENIS KULIKOV	{"phone": "+70514119567"}
0005432425968	6C3165	1037 075818	IVAN MAKAROV	{"phone": "+70275428377"}
0005432425969	6C3165	7869 810680	SVETLANA DMITRIEVA	{"phone": "+70299601069"}
0005432425970	C003E5	4713 705670	IGOR SIDOROV	{"email": "igor.sidorov-04081962@postgrespro.ru", "phone": "+70644298366"}
0005432425971	51A15F	9616 738604	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena_061972@postgrespro.ru", "phone": "+70262606630"}
0005432425972	C8CFD9	2026 941682	DARYA ANTONOVA	{"phone": "+70607194417"}
0005432425973	22BFA7	9922 976176	VIKTOR FEDOROV	{"phone": "+70749053541"}
0005432425974	FD0E36	5091 981407	VIKTORIYA IVANOVA	{"email": "vivanova1964@postgrespro.ru", "phone": "+70611333726"}
0005432425975	FD0E36	4531 970445	ALEKSANDR RODIONOV	{"email": "rodionova_1969@postgrespro.ru", "phone": "+70386156424"}
0005432425976	C775EE	8004 185252	IRINA GORBUNOVA	{"phone": "+70470873101"}
0005432425977	C775EE	2067 723944	ANNA EGOROVA	{"email": "egorova_anna_24081972@postgrespro.ru", "phone": "+70106148056"}
0005432425978	C775EE	7079 865903	ANDREY MOISEEV	{"email": "andrey.moiseev13091972@postgrespro.ru", "phone": "+70430546809"}
0005432425979	580D59	1236 213589	NIKOLAY DMITRIEV	{"email": "n_dmitriev.121970@postgrespro.ru", "phone": "+70148895047"}
0005432425980	580D59	3624 659347	KLAVDIYA ANTONOVA	{"phone": "+70138371594"}
0005432425981	950860	9142 480915	TIMOFEY GRIGOREV	{"email": "grigorev_t-23121975@postgrespro.ru", "phone": "+70085779027"}
0005432425982	13DF4F	4290 989257	OLGA KISELEVA	{"email": "olga-kiseleva-1966@postgrespro.ru", "phone": "+70919331921"}
0005432425983	CC90E6	1020 488563	TATYANA ORLOVA	{"phone": "+70886653080"}
0005432425984	F87C5C	3701 678944	VLADIMIR BELOV	{"email": "vladimir_belov101979@postgrespro.ru", "phone": "+70741714721"}
0005432425985	E53976	7958 897821	ALINA TIKHONOVA	{"email": "alina-tikhonova_1970@postgrespro.ru", "phone": "+70494947359"}
0005432425986	9E6B33	1417 155962	MARIYA IVANOVA	{"phone": "+70783439178"}
0005432425987	9E6B33	2132 666131	ANATOLIY ALEKSANDROV	{"phone": "+70255778393"}
0005432425988	B98712	7524 022647	KONSTANTIN NOVIKOV	{"email": "novikov.k-1958@postgrespro.ru", "phone": "+70752463506"}
0005432425989	1D06ED	0847 126373	SERGEY SMIRNOV	{"phone": "+70048034301"}
0005432425990	CF1B2C	1920 742136	ALEKSEY MOISEEV	{"phone": "+70187054701"}
0005432425991	CF1B2C	3074 968626	YULIYA KAZAKOVA	{"phone": "+70839377843"}
0005432425992	2251D1	8734 510474	RUSLAN KARPOV	{"phone": "+70421604111"}
0005432425993	1831DD	6136 866020	NIKOLAY POPOV	{"phone": "+70678409700"}
0005432425994	3BC403	6312 801069	LYUDMILA ROMANOVA	{"phone": "+70493832443"}
0005432425995	ECBE19	4187 556986	NIKITA KONOVALOV	{"phone": "+70686334586"}
0005432425996	6B15F2	9842 838790	MARINA LUKYANOVA	{"email": "m-lukyanova1978@postgrespro.ru", "phone": "+70220058332"}
0005432425997	6B15F2	0816 810407	VIKTOR KUZNECOV	{"phone": "+70199627054"}
0005432425998	4356B9	5391 264807	VLADIMIR MOISEEV	{"email": "v-moiseev_15081978@postgrespro.ru", "phone": "+70944641110"}
0005432425999	BDC81D	0176 545681	OLGA VASILEVA	{"phone": "+70707197244"}
0005432426000	BDC81D	1375 097855	MAKSIM DAVYDOV	{"email": "maksim-davydov121965@postgrespro.ru", "phone": "+70041577416"}
0005432426001	D49927	7230 098775	ROMAN MAKAROV	{"phone": "+70214279535"}
0005432426002	D49927	1127 969858	NIKOLAY KARPOV	{"phone": "+70418469516"}
0005432426003	D49927	7516 834479	GALINA POTAPOVA	{"email": "galinapotapova_18011973@postgrespro.ru", "phone": "+70462307598"}
0005432426004	AE8633	4918 114744	NADEZHDA KONOVALOVA	{"email": "n_konovalova_071979@postgrespro.ru", "phone": "+70448667966"}
0005432426005	AE8633	0299 384510	ALEKSANDR EGOROV	{"phone": "+70634007374"}
0005432426006	E801F0	7889 125771	YURIY SIDOROV	{"email": "y_sidorov.031974@postgrespro.ru", "phone": "+70811869918"}
0005432426007	E801F0	0701 232321	YULIYA PETROVA	{"email": "y_petrova_1976@postgrespro.ru", "phone": "+70719634569"}
0005432426008	2AEF97	4057 841616	ANTONINA MEDVEDEVA	{"email": "medvedevaantonina_1968@postgrespro.ru", "phone": "+70230063793"}
0005432426009	A52ED2	8884 677154	NIKOLAY MARTYNOV	{"email": "nikolay_martynov031974@postgrespro.ru", "phone": "+70815764144"}
0005432426010	64FE64	4611 026628	ANTON FEDOROV	{"email": "fedorovanton.1973@postgrespro.ru", "phone": "+70855650989"}
0005432426011	7B7E84	0736 758573	DMITRIY SOKOLOV	{"phone": "+70874471348"}
0005432426012	DD5593	4028 899853	NIKOLAY VOROBEV	{"phone": "+70285327648"}
0005432426013	DD5593	2495 171076	EKATERINA LUKYANOVA	{"phone": "+70266950636"}
0005432426014	D6AFE8	6509 957290	LYUDMILA MAKAROVA	{"phone": "+70836412520"}
0005432426015	28A3D1	2244 602582	LEONID KUZMIN	{"email": "leonid.kuzmin011962@postgrespro.ru", "phone": "+70193690019"}
0005432426016	EF2804	4905 907112	AZAT MELNIKOV	{"email": "azat_melnikov1982@postgrespro.ru", "phone": "+70520912458"}
0005432426017	231620	6886 622067	SERGEY KULIKOV	{"phone": "+70390482612"}
0005432426018	231620	5609 067456	MARIYA ALEKSANDROVA	{"email": "aleksandrova-m.031971@postgrespro.ru", "phone": "+70293587050"}
0005432426019	47F94D	1675 639209	NADEZHDA KUZNECOVA	{"phone": "+70933220166"}
0005432426020	2DB6F5	8940 090977	ELIZAVETA SERGEEVA	{"phone": "+70861334788"}
0005432426021	2DB6F5	0440 929902	SVETLANA FILIPPOVA	{"phone": "+70457478948"}
0005432426022	320324	8113 274511	NATALYA MIRONOVA	{"phone": "+70107090850"}
0005432426023	BC760E	1612 792035	GLEB KARPOV	{"email": "gleb-karpov_15101965@postgrespro.ru", "phone": "+70079380338"}
0005432426024	BC760E	3639 809506	OLGA SOROKINA	{"email": "olgasorokina091981@postgrespro.ru", "phone": "+70320003734"}
0005432426025	6BE1D0	9445 884216	SERGEY MEDVEDEV	{"email": "sergey-medvedev_011974@postgrespro.ru", "phone": "+70780349599"}
0005432426026	76609B	5370 198561	LARISA FROLOVA	{"email": "frolova_l1974@postgrespro.ru", "phone": "+70095891617"}
0005432426027	9B6EF3	4727 902261	VLADIMIR DENISOV	{"email": "vdenisov-1970@postgrespro.ru", "phone": "+70955289767"}
0005432426028	9B6EF3	0965 537244	NINA TARASOVA	{"email": "tarasova-n.011977@postgrespro.ru", "phone": "+70005548203"}
0005432426029	7DA559	0020 930518	OLGA OSIPOVA	{"email": "osipova_o-061982@postgrespro.ru", "phone": "+70458207619"}
0005432426030	E90444	9180 518861	ANDREY MIRONOV	{"phone": "+70425793158"}
0005432426031	B590BC	8526 287609	SAMIR BONDARENKO	{"email": "bondarenko_samir-01051975@postgrespro.ru", "phone": "+70260629859"}
0005432426032	B590BC	1695 210797	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov-041981@postgrespro.ru", "phone": "+70292177458"}
0005432426033	B590BC	1906 402330	VERA KOVALEVA	{"email": "kovaleva-vera1981@postgrespro.ru", "phone": "+70545721585"}
0005432426034	27F4CB	4509 258997	ALEVTINA SOLOVEVA	{"email": "soloveva.alevtina-1972@postgrespro.ru", "phone": "+70462378829"}
0005432426035	A8BE34	6177 864442	NINA LEBEDEVA	{"email": "ninalebedeva081979@postgrespro.ru", "phone": "+70006623023"}
0005432426036	A8BE34	5059 386071	GENNADIY ABRAMOV	{"email": "abramov_gennadiy_011973@postgrespro.ru", "phone": "+70936819412"}
0005432426037	EB7D42	9763 204928	ALINA GAVRILOVA	{"email": "gavrilova-alina.27061989@postgrespro.ru", "phone": "+70581413307"}
0005432426038	EB7D42	2420 215806	IVAN VASILEV	{"email": "vasilev-ivan_16091965@postgrespro.ru", "phone": "+70279257726"}
0005432426039	67B7FB	5823 779860	SERGEY DAVYDOV	{"phone": "+70778335535"}
0005432426040	D9BEFB	4021 952427	DANILA CHERNOV	{"phone": "+70352365869"}
0005432426041	D9BEFB	2350 485419	VIKTOR NAZAROV	{"phone": "+70782123770"}
0005432426042	EDB277	7193 380827	LYUBOV MAKAROVA	{"email": "makarova_lyubov_1975@postgrespro.ru", "phone": "+70791380067"}
0005432426043	041C71	8338 073825	STEPAN NIKITIN	{"email": "s-nikitin_1977@postgrespro.ru", "phone": "+70493145118"}
0005432426044	8FAA77	7450 977596	VERONIKA ALEKSEEVA	{"phone": "+70258772710"}
0005432426045	8FAA77	2344 205931	SERGEY ROMANOV	{"email": "romanovs_20111972@postgrespro.ru", "phone": "+70374903267"}
0005432426046	963D74	7068 346188	ALEKSEY BELOV	{"email": "belov_aleksey_1967@postgrespro.ru", "phone": "+70973608043"}
0005432426047	963D74	0483 682640	MAKSIM NOVIKOV	{"email": "maksim.novikov-091976@postgrespro.ru", "phone": "+70447175380"}
0005432426048	90A446	1959 320756	MILENA EGOROVA	{"email": "egorova_m_28041962@postgrespro.ru", "phone": "+70619961307"}
0005432426049	96C307	5919 021917	ANASTASIYA VASILEVA	{"email": "vasileva.anastasiya.1991@postgrespro.ru", "phone": "+70978447673"}
0005432426050	04ECE9	5475 236638	ANASTASIYA SIDOROVA	{"email": "asidorova_29081969@postgrespro.ru", "phone": "+70040135395"}
0005432426051	0B40C6	6067 818685	VERONIKA ANDREEVA	{"phone": "+70220519364"}
0005432426052	0021AA	8343 551070	VALENTINA KRASNOVA	{"phone": "+70999695003"}
0005432426053	3E92B1	8138 190511	EGOR MEDVEDEV	{"email": "e_medvedev-081969@postgrespro.ru", "phone": "+70829438242"}
0005432426054	2F1BC4	4728 313354	NIKOLAY MOROZOV	{"phone": "+70871462777"}
0005432426055	8DE741	1777 784103	MIKHAIL IVANOV	{"email": "mikhailivanov.21061978@postgrespro.ru", "phone": "+70796992315"}
0005432426056	8DE741	9969 004963	ANDREY IVANOV	{"email": "ivanov.andrey14111976@postgrespro.ru", "phone": "+70319225944"}
0005432426057	8D3670	7724 517990	MARIYA OVCHINNIKOVA	{"email": "mariyaovchinnikova_14121963@postgrespro.ru", "phone": "+70343830750"}
0005432426058	0E0393	9147 000458	MARINA IVANOVA	{"email": "marinaivanova_071986@postgrespro.ru", "phone": "+70006398478"}
0005432426059	0E0393	1184 351220	ARTUR ANDREEV	{"email": "andreev-artur02041974@postgrespro.ru", "phone": "+70574103463"}
0005432426060	5A0674	6063 612829	VLADIMIR IVANOV	{"phone": "+70697929103"}
0005432426061	864BC4	5312 889649	NATALYA VOROBEVA	{"email": "vorobevanatalya26031975@postgrespro.ru", "phone": "+70385050208"}
0005432426062	937B13	3710 762372	ALEKSEY ANDREEV	{"phone": "+70054538957"}
0005432426063	937B13	1991 329089	TATYANA OVCHINNIKOVA	{"email": "tatyana_ovchinnikova.041974@postgrespro.ru", "phone": "+70821950707"}
0005432426064	F49E87	4364 652482	ELMIRA ANDREEVA	{"email": "andreeva-e-1974@postgrespro.ru", "phone": "+70899540799"}
0005432426065	00DCB8	0169 204141	VALERIY ZAKHAROV	{"email": "zakharovvaleriy1971@postgrespro.ru", "phone": "+70002060587"}
0005432426066	00DCB8	5204 482721	ELENA MELNIKOVA	{"email": "melnikova.elena_1970@postgrespro.ru", "phone": "+70048135347"}
0005432426067	5D7374	1834 909369	MARIYA IVANOVA	{"email": "ivanova-m-111977@postgrespro.ru", "phone": "+70895830144"}
0005432426068	454992	5545 985401	VLADIMIR ANDREEV	{"phone": "+70468009609"}
0005432426069	2BF1FE	0911 002717	TAGIR SAVELEV	{"email": "savelev-t021973@postgrespro.ru", "phone": "+70419879600"}
0005432426070	2BF1FE	9710 622658	MARIYA KAZAKOVA	{"phone": "+70633932476"}
0005432426071	9E81DA	4485 179815	VALENTINA ERMAKOVA	{"phone": "+70199396900"}
0005432426072	05EF11	0983 206730	OKSANA SOLOVEVA	{"phone": "+70936046935"}
0005432426073	05EF11	6389 104758	EVGENIYA TITOVA	{"email": "titova-e-051964@postgrespro.ru", "phone": "+70421613028"}
0005432426074	E2B4D1	3148 460250	NATALYA KUZNECOVA	{"phone": "+70422684845"}
0005432426075	E2B4D1	9789 591149	IRINA SOKOLOVA	{"email": "i-sokolova_1973@postgrespro.ru", "phone": "+70554283721"}
0005432426076	CAE350	1265 727305	IVAN MOROZOV	{"phone": "+70453843936"}
0005432426077	821D9A	9077 338386	TATYANA KOROLEVA	{"email": "koroleva_t.041991@postgrespro.ru", "phone": "+70915797681"}
0005432426078	314569	7823 584215	VITALIY CHERNOV	{"phone": "+70948700816"}
0005432427106	C7AECE	6026 048406	MARINA KAZAKOVA	{"phone": "+70239356803"}
0005432427107	0AFEC6	6412 895936	ROMAN ROMANOV	{"email": "r.romanov_011975@postgrespro.ru", "phone": "+70216497731"}
0005432427108	43ED9F	3802 448750	MIKHAIL TIKHONOV	{"phone": "+70296896635"}
0005432427109	43ED9F	8922 547333	EVGENIY VOLKOV	{"phone": "+70963644261"}
0005432427110	6B0910	8633 116182	ALEKSANDRA KALININA	{"email": "kalinina.aleksandra_06091970@postgrespro.ru", "phone": "+70067440503"}
0005432427111	FF3762	7868 987844	DMITRIY DMITRIEV	{"email": "dmitriev_dmitriy.121964@postgrespro.ru", "phone": "+70255650331"}
0005432427112	FF3762	9508 587251	EVGENIY GERASIMOV	{"email": "gerasimov_evgeniy_121981@postgrespro.ru", "phone": "+70725968456"}
0005432427113	F1CD04	0485 458404	DARYA DAVYDOVA	{"email": "davydova-d091971@postgrespro.ru", "phone": "+70675086913"}
0005432427114	F1CD04	8377 441277	IRINA SOLOVEVA	{"email": "soloveva.irina.061975@postgrespro.ru", "phone": "+70493730568"}
0005432427115	918E2A	5324 527634	ANATOLIY FEDOTOV	{"email": "anatoliy-fedotov111971@postgrespro.ru", "phone": "+70470565266"}
0005432427116	BFF386	4610 122264	MARGARITA BELYAEVA	{"email": "belyaevam14061968@postgrespro.ru", "phone": "+70285965083"}
0005432427117	5133EC	3909 100249	ALEKSANDR FILIPPOV	{"phone": "+70564645662"}
0005432427118	B3032B	3074 137982	RAIL GERASIMOV	{"email": "gerasimov.r.121969@postgrespro.ru", "phone": "+70050663065"}
0005432427119	535919	7870 148891	ALEKSANDR EGOROV	{"phone": "+70814613341"}
0005432427120	123D03	9511 025790	DARYA POPOVA	{"phone": "+70828698517"}
0005432427121	ECDC6A	9875 990337	IRINA ZAKHAROVA	{"email": "irina_zakharova_051972@postgrespro.ru", "phone": "+70176771610"}
0005432427122	6DC616	7832 002679	ILDAR ZAYCEV	{"email": "zaycevi_121962@postgrespro.ru", "phone": "+70074910873"}
0005432427123	EBF20F	9648 168486	ELENA VLASOVA	{"phone": "+70180905299"}
0005432427124	EBF20F	8346 281999	SERGEY DENISOV	{"phone": "+70453690891"}
0005432427125	83CE51	3127 562462	KONSTANTIN KAZAKOV	{"phone": "+70227957228"}
0005432427126	83CE51	2392 252205	DMITRIY MEDVEDEV	{"phone": "+70288046556"}
0005432427127	644F54	6798 282617	ALEKSANDR KULIKOV	{"email": "kulikova.021968@postgrespro.ru", "phone": "+70924063489"}
0005432427128	644F54	2738 666646	MARINA IVANOVA	{"email": "ivanova_marina.1983@postgrespro.ru", "phone": "+70864811840"}
0005432427129	644F54	3063 172501	ELENA PETROVA	{"email": "elena_petrova_19101966@postgrespro.ru", "phone": "+70498042177"}
0005432427130	B1FDB7	0602 860516	ALEKSANDR ROMANOV	{"phone": "+70587829154"}
0005432427131	B1FDB7	5799 947642	OLGA STEPANOVA	{"email": "o_stepanova31101976@postgrespro.ru", "phone": "+70770546928"}
0005432427132	690DAC	8024 821089	EVGENIY NOVIKOV	{"phone": "+70222345178"}
0005432427133	8F2282	6548 477270	MIKHAIL ABRAMOV	{"phone": "+70382224936"}
0005432427134	D0DCE4	6407 767701	ELENA BARANOVA	{"email": "e.baranova.011967@postgrespro.ru", "phone": "+70033866698"}
0005432427135	864AEC	3110 471493	TATYANA PETROVA	{"email": "petrova-tatyana.30091981@postgrespro.ru", "phone": "+70533175468"}
0005432427136	DF5832	8542 430745	EGOR MELNIKOV	{"email": "e_melnikov_011985@postgrespro.ru", "phone": "+70791550431"}
0005432427137	E64B0B	0395 751409	EVGENIY SERGEEV	{"email": "sergeevevgeniy.081970@postgrespro.ru", "phone": "+70998420604"}
0005432427138	6941E0	0458 960702	NIKOLAY FEDOROV	{"email": "fedorov.nikolay1974@postgrespro.ru", "phone": "+70035381603"}
0005432427139	6941E0	2764 774291	MARIYA KRASNOVA	{"email": "krasnovamariya1964@postgrespro.ru", "phone": "+70735755018"}
0005432427140	D29E48	7918 394949	ALEKSEY GAVRILOV	{"phone": "+70347398717"}
0005432427141	8AFE92	3040 473949	ANNA KULIKOVA	{"phone": "+70304366155"}
0005432427142	A7AF96	0659 565053	ALEKSANDR VOLKOV	{"phone": "+70659826127"}
0005432427143	A7AF96	0430 943971	ALEKSANDR STEPANOV	{"email": "aleksandrstepanov021965@postgrespro.ru", "phone": "+70246813448"}
0005432427144	4B6607	5410 338617	VALENTIN FEDOROV	{"email": "fedorov.valentin_1982@postgrespro.ru", "phone": "+70620921443"}
0005432427145	B1279D	0161 649737	DENIS KARPOV	{"phone": "+70613035230"}
0005432427146	E97EC2	2421 524480	LYUDMILA DANILOVA	{"phone": "+70914622356"}
0005432427147	591BAA	8936 725316	ANATOLIY SOKOLOV	{"email": "anatoliy-sokolov031970@postgrespro.ru", "phone": "+70419254108"}
0005432427148	591BAA	8650 559710	YULIYA GERASIMOVA	{"email": "gerasimova_y.21101963@postgrespro.ru", "phone": "+70344138062"}
0005432427149	45A043	6993 240403	EKATERINA IVANOVA	{"phone": "+70983848512"}
0005432427150	FD976D	6393 781769	GALINA OSIPOVA	{"email": "osipova.g-14081966@postgrespro.ru", "phone": "+70655371522"}
0005432427151	C4455B	9961 569909	POLINA TARASOVA	{"phone": "+70592108114"}
0005432427152	C4455B	9417 232345	SVETLANA MATVEEVA	{"email": "matveevasvetlana-1990@postgrespro.ru", "phone": "+70768823269"}
0005432427153	C4455B	8681 790632	VADIM MIRONOV	{"email": "mironovvadim.16091980@postgrespro.ru", "phone": "+70756097726"}
0005432427154	B1565F	3325 473870	MARIYA ILINA	{"email": "ilina-mariya-071973@postgrespro.ru", "phone": "+70533693747"}
0005432427155	BA96DB	3728 289550	ELENA ANDREEVA	{"email": "elena.andreeva16121970@postgrespro.ru", "phone": "+70426666138"}
0005432427156	356ADA	2417 565109	AYRAT MAKAROV	{"phone": "+70235578904"}
0005432427157	356ADA	5142 030922	IGOR NIKITIN	{"phone": "+70263829735"}
0005432427158	E08D82	6289 788693	GALINA BELOVA	{"email": "gbelova1969@postgrespro.ru", "phone": "+70754818022"}
0005432427159	92DFE4	1671 436715	ELENA PAVLOVA	{"email": "elena_pavlova-021967@postgrespro.ru", "phone": "+70808819499"}
0005432427160	92DFE4	5865 301064	EKATERINA ZOTOVA	{"phone": "+70672466170"}
0005432427161	1B3E61	9392 816035	IVAN SOLOVEV	{"email": "solovevivan_1973@postgrespro.ru", "phone": "+70967789952"}
0005432427162	1B3E61	5078 612192	NINA TITOVA	{"phone": "+70506011177"}
0005432427163	1B3E61	2435 727038	VLADIMIR KARPOV	{"email": "vladimir_karpov.081977@postgrespro.ru", "phone": "+70763962492"}
0005432427164	12D2B1	6976 287532	EVGENIYA OVCHINNIKOVA	{"email": "ovchinnikova-evgeniya-06051966@postgrespro.ru", "phone": "+70249185465"}
0005432427165	6C7506	1639 916716	SERGEY SEMENOV	{"email": "semenov.sergey13041982@postgrespro.ru", "phone": "+70675970773"}
0005432427166	87089E	9615 347077	OLGA RODIONOVA	{"email": "rodionova-olga-051968@postgrespro.ru", "phone": "+70552173749"}
0005432427167	48D94D	0648 152142	ELENA AKIMOVA	{"email": "elena.akimova28021963@postgrespro.ru", "phone": "+70952038026"}
0005432427168	5BA040	3196 807383	ZAKHAR RODIONOV	{"email": "z.rodionov.04011977@postgrespro.ru", "phone": "+70845810071"}
0005432427169	5BA040	3382 244977	ANGELINA KUDRYASHOVA	{"email": "angelina.kudryashova03041963@postgrespro.ru", "phone": "+70180257900"}
0005432427170	9B8FDF	6796 899614	ANASTASIYA AKIMOVA	{"phone": "+70572539824"}
0005432427171	3FB0AB	6450 294385	VERA GUSEVA	{"phone": "+70203324518"}
0005432427172	3FB0AB	5850 368738	VALERIYA KUZMINA	{"phone": "+70616766980"}
0005432427173	3FB0AB	4379 173070	SERGEY ZAKHAROV	{"phone": "+70759004659"}
0005432427174	6C2719	9025 105591	NINA DMITRIEVA	{"email": "ndmitrieva.1986@postgrespro.ru", "phone": "+70989317722"}
0005432427175	846E91	4844 797150	VYACHESLAV STEPANOV	{"phone": "+70961645632"}
0005432427176	846E91	0234 864311	MARINA KUZNECOVA	{"email": "kuznecovamarina_31081975@postgrespro.ru", "phone": "+70655019487"}
0005432427177	846E91	8526 320917	VLADIMIR EGOROV	{"phone": "+70508125038"}
0005432427178	7ECC1E	3200 298378	TATYANA FADEEVA	{"email": "fadeevatatyana.1978@postgrespro.ru", "phone": "+70203673925"}
0005432427179	4B76DD	1021 368620	RINAT SAVELEV	{"email": "r.savelev-1970@postgrespro.ru", "phone": "+70626008604"}
0005432427180	4B76DD	5949 887046	MARIYA KARPOVA	{"phone": "+70568058133"}
0005432427181	654B4C	2751 547895	ANNA OSIPOVA	{"phone": "+70876774765"}
0005432427182	AD8CCE	4182 908355	LYUDMILA DENISOVA	{"phone": "+70714649898"}
0005432427183	AD8CCE	6278 279887	ALLA NIKOLAEVA	{"email": "nikolaeva.a.15021974@postgrespro.ru", "phone": "+70686611707"}
0005432427184	B816B4	3920 841712	YURIY KISELEV	{"email": "kiselev-yuriy.18111971@postgrespro.ru", "phone": "+70509384130"}
0005432427185	BBCDD7	7229 138451	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov-1976@postgrespro.ru", "phone": "+70513281857"}
0005432427186	BBCDD7	5931 936297	ALISA SERGEEVA	{"email": "alisa.sergeeva-17041970@postgrespro.ru", "phone": "+70545540181"}
0005432427187	977DD1	2333 981064	MARGARITA PETROVA	{"phone": "+70256194194"}
0005432427188	403ED9	4263 618186	GERMAN VOROBEV	{"phone": "+70283113952"}
0005432427189	4FB8DD	9721 264250	NIKOLAY RODIONOV	{"email": "rodionovnikolay.1974@postgrespro.ru", "phone": "+70317762799"}
0005432427190	51AF5E	8885 799081	DARYA FEDOROVA	{"email": "fedorova_d24021966@postgrespro.ru", "phone": "+70170938035"}
0005432427191	51AF5E	2859 940543	TATYANA KONDRATEVA	{"email": "kondrateva.tatyana-1967@postgrespro.ru", "phone": "+70089401188"}
0005432427192	51AF5E	8484 235093	ANASTASIYA KUZMINA	{"email": "anastasiyakuzmina-02091973@postgrespro.ru", "phone": "+70145444279"}
0005432427193	5046A5	3841 860063	VIKTOR NAZAROV	{"email": "nazarov_v_111981@postgrespro.ru", "phone": "+70717961173"}
0005432427194	34DDD2	8025 987682	ROZA ALEKSANDROVA	{"phone": "+70132014243"}
0005432427195	A174C3	7912 968328	LYUDMILA KRASNOVA	{"email": "l_krasnova.011974@postgrespro.ru", "phone": "+70180484858"}
0005432427196	F11FF9	4083 958181	NIKOLAY SERGEEV	{"phone": "+70533594169"}
0005432427197	51CBD6	4779 430563	YURIY BARANOV	{"email": "baranovyuriy-121973@postgrespro.ru", "phone": "+70052520734"}
0005432427198	E459F2	5474 186795	SERGEY PETROV	{"email": "petrov-sergey-1969@postgrespro.ru", "phone": "+70617688081"}
0005432427199	E459F2	4196 794937	MIKHAIL IVANOV	{"email": "mikhailivanov1985@postgrespro.ru", "phone": "+70989245127"}
0005432427200	4CE590	8462 801353	VLADIMIR BORISOV	{"phone": "+70492916725"}
0005432427201	495B62	8734 445554	ALEKSEY YAKOVLEV	{"email": "ayakovlev1969@postgrespro.ru", "phone": "+70454337533"}
0005432427202	495B62	7064 162598	ALEKSANDR BORISOV	{"email": "borisov-aleksandr.05081975@postgrespro.ru", "phone": "+70437907285"}
0005432427203	495B62	7903 825282	EVGENIY KAZAKOV	{"email": "evgeniy-kazakov.1970@postgrespro.ru", "phone": "+70950012962"}
0005432427204	367464	0180 810096	VALENTINA KARPOVA	{"phone": "+70101852714"}
0005432427205	DC3D73	0418 990113	YULIYA VOROBEVA	{"email": "yuliyavorobeva-27061975@postgrespro.ru", "phone": "+70464048538"}
0005432427206	5CA175	0996 090118	SVETLANA NIKOLAEVA	{"phone": "+70659266183"}
0005432427207	5CA175	1798 214946	OLEG KUDRYASHOV	{"email": "o_kudryashov_19081960@postgrespro.ru", "phone": "+70208980853"}
0005432427208	234717	5929 769895	ANDREY SAVELEV	{"email": "savelev_a-111982@postgrespro.ru", "phone": "+70379810642"}
0005432427209	C72914	0768 887742	PETR MATVEEV	{"email": "matveev.petr1978@postgrespro.ru", "phone": "+70703636732"}
0005432428867	8BBD40	7203 195624	VYACHESLAV BORISOV	{"email": "borisov.v091966@postgrespro.ru", "phone": "+70202052119"}
0005432428868	315116	4794 714621	VYACHESLAV ZAKHAROV	{"phone": "+70951207538"}
0005432428869	9175FC	6829 475620	VALENTINA ORLOVA	{"email": "valentinaorlova011963@postgrespro.ru", "phone": "+70619891173"}
0005432428870	E5D919	8335 735673	YURIY VASILEV	{"email": "vasilev-yuriy_20111978@postgrespro.ru", "phone": "+70933032972"}
0005432428871	E5D919	5532 475316	SVETLANA MELNIKOVA	{"email": "svetlanamelnikova-101974@postgrespro.ru", "phone": "+70793146450"}
0005432428872	B0F73F	9114 893448	EVGENIYA ALEKSEEVA	{"email": "alekseeva_evgeniya041979@postgrespro.ru", "phone": "+70051288222"}
0005432428873	B0F73F	9172 619897	MIKHAIL NIKITIN	{"email": "nikitinmikhail-081978@postgrespro.ru", "phone": "+70062456230"}
0005432428874	AD9380	8314 443745	NIKOLAY MOROZOV	{"email": "nikolay.morozov1977@postgrespro.ru", "phone": "+70537077349"}
0005432428875	F6E1AA	9028 626607	LYUBOV SERGEEVA	{"phone": "+70704189827"}
0005432428876	F6E1AA	0216 198944	ELIZAVETA TARASOVA	{"email": "e.tarasova_26061965@postgrespro.ru", "phone": "+70276095747"}
0005432428877	EEADBF	7041 441709	SVETLANA ANTONOVA	{"phone": "+70335715522"}
0005432428878	EEADBF	1117 876567	ALEKSANDRA VOLKOVA	{"phone": "+70388881475"}
0005432428879	A14010	0815 889667	NIKOLAY TIKHONOV	{"email": "tikhonov.nikolay_1973@postgrespro.ru", "phone": "+70923661230"}
0005432428880	CC5405	3188 015975	VALERIY ISAEV	{"phone": "+70677390499"}
0005432428881	EFDEF3	4703 775847	TATYANA EGOROVA	{"email": "egorova.t101972@postgrespro.ru", "phone": "+70426163585"}
0005432428882	EFDEF3	9827 398783	MARAT NIKITIN	{"email": "nikitinm011971@postgrespro.ru", "phone": "+70238133725"}
0005432428883	300AE8	1821 321278	ELIZAVETA MELNIKOVA	{"phone": "+70856000908"}
0005432428884	518101	8477 852206	ALENA POPOVA	{"phone": "+70340402400"}
0005432428885	ECEF4F	1996 906698	MIKHAIL CHERNOV	{"phone": "+70401573305"}
0005432428886	85EED8	2082 957392	MARAT PETROV	{"phone": "+70582471169"}
0005432428887	85EED8	3901 268572	TAMARA BELOVA	{"phone": "+70161298456"}
0005432428888	F75202	4973 058018	TATYANA SOROKINA	{"email": "sorokina_tatyana.1965@postgrespro.ru", "phone": "+70171550018"}
0005432428889	F75202	0151 963348	VYACHESLAV ZAKHAROV	{"phone": "+70836661322"}
0005432428890	5206B8	5824 678983	TATYANA GUSEVA	{"email": "gusevat_111968@postgrespro.ru", "phone": "+70664164878"}
0005432428891	5206B8	1271 961029	ELENA ALEKSANDROVA	{"email": "aleksandrovae10051971@postgrespro.ru", "phone": "+70099922079"}
0005432428892	0FB0EA	8793 869823	ALEKSANDR BELOV	{"phone": "+70286455711"}
0005432428893	0FB0EA	6878 561318	NATALYA KUZMINA	{"email": "natalya_kuzmina_101970@postgrespro.ru", "phone": "+70094736514"}
0005432428894	8714DC	5131 069750	GALINA IVANOVA	{"phone": "+70175236418"}
0005432428895	5832B7	2698 657642	OLGA KARPOVA	{"email": "o_karpova1980@postgrespro.ru", "phone": "+70471065677"}
0005432428896	BA4D93	3741 714507	ANDREY SEMENOV	{"phone": "+70729924774"}
0005432428897	BA4D93	0387 165680	MARIYA MELNIKOVA	{"phone": "+70058247598"}
0005432428898	53C7B9	1409 367764	NADEZHDA TIKHONOVA	{"phone": "+70747562416"}
0005432428899	2B9362	4975 461194	TATYANA VOLKOVA	{"email": "volkova-t.20061965@postgrespro.ru", "phone": "+70293707825"}
0005432428900	BF2B4F	2040 296764	TAMARA TIMOFEEVA	{"phone": "+70219700581"}
0005432428901	BF2B4F	4752 189709	VALENTINA KAZAKOVA	{"email": "v-kazakova_26081969@postgrespro.ru", "phone": "+70899931533"}
0005432428902	AB0C26	8124 551868	TATYANA BELOVA	{"email": "tatyana-belova_011967@postgrespro.ru", "phone": "+70390671192"}
0005432428903	BC1F90	4517 105233	GULNARA ALEKSANDROVA	{"email": "gulnara_aleksandrova-1956@postgrespro.ru", "phone": "+70115169419"}
0005432428904	B7DFDF	3720 811953	TATYANA NIKOLAEVA	{"phone": "+70527500131"}
0005432428905	B7DFDF	0649 362888	VIKTOR FEDOTOV	{"email": "fedotov_viktor-23041982@postgrespro.ru", "phone": "+70106188867"}
0005432428906	988BBE	3223 594037	ANATOLIY POPOV	{"phone": "+70137992058"}
0005432428907	18260A	3266 749979	ANNA POPOVA	{"email": "popova.anna-03091965@postgrespro.ru", "phone": "+70016425884"}
0005432428908	D8C7E7	2420 394135	MARINA KOROLEVA	{"email": "m_koroleva.1972@postgrespro.ru", "phone": "+70776372907"}
0005432428909	6F3755	8297 903543	ELIZAVETA EFIMOVA	{"email": "efimova.e-1977@postgrespro.ru", "phone": "+70765018295"}
0005432428910	D203CE	0915 160925	GALINA BORISOVA	{"email": "galinaborisova_051972@postgrespro.ru", "phone": "+70128594454"}
0005432428911	768A9A	8631 516677	SVETLANA KUZNECOVA	{"email": "s.kuznecova.1961@postgrespro.ru", "phone": "+70665414782"}
0005432428912	768A9A	4490 525370	VLADIMIR GORBUNOV	{"email": "gorbunov.vladimir.1959@postgrespro.ru", "phone": "+70528278847"}
0005432428913	6A6845	9033 083241	LYUBOV KOROLEVA	{"email": "lyubov-koroleva-1972@postgrespro.ru", "phone": "+70220093465"}
0005432428914	42231B	8449 188799	ALESYA TITOVA	{"email": "titova_alesya.1969@postgrespro.ru", "phone": "+70735439554"}
0005432428915	9155E9	0224 569293	YULIYA KOMAROVA	{"email": "ykomarova_1984@postgrespro.ru", "phone": "+70666070363"}
0005432428916	BBFCC7	7782 079125	ALSU ZHURAVLEVA	{"email": "zhuravleva.alsu_20091960@postgrespro.ru", "phone": "+70237766199"}
0005432428917	CF6F56	7941 719277	LYUDMILA KARPOVA	{"phone": "+70025643986"}
0005432428918	CF6F56	6395 418975	IVAN NIKITIN	{"phone": "+70186424568"}
0005432428919	CF6F56	9535 188980	VALERIY MOISEEV	{"phone": "+70329826393"}
0005432428920	A4B342	1588 937086	DARINA MAKSIMOVA	{"email": "d.maksimova-20021968@postgrespro.ru", "phone": "+70828153895"}
0005432428921	3F75EA	2165 753492	ARTEM ZAKHAROV	{"email": "artem_zakharov-25101972@postgrespro.ru", "phone": "+70702044257"}
0005432428922	3F75EA	0697 704532	SVETLANA SCHERBAKOVA	{"email": "svetlana_scherbakova-041967@postgrespro.ru", "phone": "+70545240812"}
0005432428923	59279E	9285 130207	TATYANA FROLOVA	{"phone": "+70916813585"}
0005432428924	59279E	9991 943657	EVGENIYA ANDREEVA	{"phone": "+70836239110"}
0005432428925	169590	0748 677930	IGOR SAVELEV	{"phone": "+70306972770"}
0005432428926	33588D	7933 929078	NATALYA POTAPOVA	{"phone": "+70007273577"}
0005432428927	020433	1986 952145	YULIYA CHERNOVA	{"phone": "+70952075708"}
0005432428928	020433	2262 909322	VALERIY ZAYCEV	{"email": "valeriy-zaycev_051971@postgrespro.ru", "phone": "+70836792475"}
0005432428929	F3D0D8	6237 229751	ANASTASIYA ZHURAVLEVA	{"phone": "+70046299642"}
0005432428930	1E0CBB	2897 869514	LYUBOV POPOVA	{"phone": "+70349994334"}
0005432428931	DF1ECB	4310 729998	YULIYA EGOROVA	{"phone": "+70428453588"}
0005432428932	DF1ECB	6207 029295	NATALYA DAVYDOVA	{"email": "davydovanatalya_29051969@postgrespro.ru", "phone": "+70671823126"}
0005432428933	204ACD	9405 205557	TATYANA TARASOVA	{"phone": "+70478387301"}
0005432428934	204ACD	5403 731849	ARTEM NIKOLAEV	{"phone": "+70246990739"}
0005432428935	7980B7	1448 290210	OLGA GAVRILOVA	{"email": "gavrilovaolga1972@postgrespro.ru", "phone": "+70422161363"}
0005432428936	7980B7	9704 540315	ALEKSEY EGOROV	{"email": "egorov_aleksey021978@postgrespro.ru", "phone": "+70594871579"}
0005432428937	7980B7	0293 329620	ILYA PAVLOV	{"phone": "+70186183721"}
0005432428938	920855	1184 422399	SERGEY ZAYCEV	{"phone": "+70696429112"}
0005432428939	8F01E2	3465 989651	ALEKSANDR SERGEEV	{"email": "sergeeva_01121973@postgrespro.ru", "phone": "+70566166442"}
0005432428940	8CC288	1896 172862	EKATERINA GAVRILOVA	{"phone": "+70653041110"}
0005432428941	8CC288	6002 719432	NADEZHDA KALININA	{"email": "nadezhda-kalinina1960@postgrespro.ru", "phone": "+70100009187"}
0005432428942	9C723B	4342 191598	OLGA KUZNECOVA	{"phone": "+70871173047"}
0005432428943	FE15C1	4030 444158	VLADIMIR KISELEV	{"email": "kiselev-vladimir031985@postgrespro.ru", "phone": "+70231573074"}
0005432428944	FE15C1	3415 499768	ANTON IVANOV	{"email": "ivanov-a031970@postgrespro.ru", "phone": "+70341058188"}
0005432428945	03E51A	4763 940792	NATALIYA KALININA	{"phone": "+70345611703"}
0005432428946	658FF9	5000 750182	IRINA GRISHINA	{"phone": "+70646572496"}
0005432428947	5D3C73	8786 472954	ALEKSANDR KUZNECOV	{"email": "kuznecova25061972@postgrespro.ru", "phone": "+70674347488"}
0005432428948	16530F	2882 452726	NADEZHDA FEDOROVA	{"email": "nfedorova.1972@postgrespro.ru", "phone": "+70299295563"}
0005432428949	595FE8	6402 136838	OLGA MOISEEVA	{"phone": "+70255350031"}
0005432428950	595FE8	5710 995454	VIKTOR ZHURAVLEV	{"phone": "+70364995250"}
0005432428951	6AAEE2	1736 152150	ANGELINA KARPOVA	{"phone": "+70193986555"}
0005432428952	870F0B	8710 851194	MARIYA MOROZOVA	{"phone": "+70842389597"}
0005432428953	870F0B	3585 421618	SERGEY MAKAROV	{"email": "makarovsergey_081969@postgrespro.ru", "phone": "+70851830208"}
0005432428954	00BAF7	2271 150014	OLGA SMIRNOVA	{"email": "olga-smirnova_18091973@postgrespro.ru", "phone": "+70842584817"}
0005432428955	60EF94	5788 513089	ELENA GORBUNOVA	{"email": "egorbunova.1971@postgrespro.ru", "phone": "+70590547130"}
0005432428956	60EF94	5168 890398	OLEG NOVIKOV	{"email": "novikovoleg.10011963@postgrespro.ru", "phone": "+70891893450"}
0005432428957	231FA5	8502 016479	YULIYA KOZLOVA	{"email": "kozlova_y30091968@postgrespro.ru", "phone": "+70439599165"}
0005432428958	231FA5	1707 972709	DMITRIY IVANOV	{"phone": "+70455325314"}
0005432428959	F99BB1	4673 112743	MARINA DENISOVA	{"email": "marina_denisova-15081974@postgrespro.ru", "phone": "+70105373302"}
0005432428960	9FA800	7053 033952	IGOR SCHERBAKOV	{"email": "i-scherbakov071977@postgrespro.ru", "phone": "+70132104820"}
0005432428961	2F7949	1886 799719	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr_1970@postgrespro.ru", "phone": "+70330604837"}
0005432428962	063FCC	0195 679293	ALEKSEY IVANOV	{"phone": "+70834177487"}
0005432428963	95A7D5	8181 927276	ALEKSANDR MAKAROV	{"phone": "+70277563514"}
0005432428964	F11E00	9034 929456	NATALYA POPOVA	{"phone": "+70094955228"}
0005432428965	32EC67	1607 343582	ALEKSANDR OSIPOV	{"phone": "+70522558861"}
0005432428966	78A677	0494 682447	KRISTINA ISAEVA	{"phone": "+70510890336"}
0005432428967	AF060C	1810 407914	VENIAMIN GAVRILOV	{"phone": "+70499366796"}
0005432428968	4C54D0	6615 857287	NINA TIKHONOVA	{"phone": "+70699816736"}
0005432428969	09B685	3337 870901	KONSTANTIN VOROBEV	{"email": "k.vorobev_071958@postgrespro.ru", "phone": "+70826538844"}
0005432428970	09B685	8771 107966	ALEKSANDR NAZAROV	{"email": "nazarov_a-1966@postgrespro.ru", "phone": "+70817142156"}
0005432428971	09B685	5867 347029	RASHID KUZNECOV	{"email": "rashid-kuznecov_22021973@postgrespro.ru", "phone": "+70018462587"}
0005432428972	1A15EB	7970 817485	IRINA FADEEVA	{"phone": "+70944946330"}
0005432428973	75F734	8336 837495	VALERIYA LOGINOVA	{"email": "valeriya.loginova.101975@postgrespro.ru", "phone": "+70065969164"}
0005432428974	75F734	8496 029073	ELENA ROMANOVA	{"email": "romanovae-18081970@postgrespro.ru", "phone": "+70546112585"}
0005432428975	75F734	4134 765462	VLADIMIR PAVLOV	{"email": "pavlov_v.20121981@postgrespro.ru", "phone": "+70938633634"}
0005432428976	4CFFB3	4131 478109	SERGEY TARASOV	{"phone": "+70187025411"}
0005432428977	4CFFB3	4445 877992	ELIZAVETA MIKHAYLOVA	{"phone": "+70060567089"}
0005432428978	D54B5C	3099 517963	TAMARA MELNIKOVA	{"phone": "+70821712107"}
0005432428979	00E313	7608 523245	ANNA MEDVEDEVA	{"email": "medvedeva.a02071978@postgrespro.ru", "phone": "+70889510712"}
0005432428980	31DE86	5883 995687	VALERIYA GERASIMOVA	{"phone": "+70434452320"}
0005432428981	6451F2	9974 170362	STANISLAV BELOV	{"phone": "+70882780236"}
0005432428982	A0D7A9	3451 747181	ANDREY KOZLOV	{"phone": "+70625264945"}
0005432428983	ADF1BE	6045 192541	RAISA ALEKSEEVA	{"email": "raisaalekseeva051972@postgrespro.ru", "phone": "+70917842082"}
0005432428984	A76E3E	5976 929535	DIANA GAVRILOVA	{"phone": "+70977698467"}
0005432428985	76E4E4	4790 699696	ALEKSEY KRASNOV	{"email": "krasnov_aleksey01091982@postgrespro.ru", "phone": "+70226216452"}
0005432428986	76E4E4	7759 654538	NIKOLAY KUZMIN	{"phone": "+70337117746"}
0005432428987	4F7A5F	3632 479677	ALEKSANDR FROLOV	{"email": "aleksandr-frolov_1972@postgrespro.ru", "phone": "+70177665360"}
0005432428988	4586F7	5843 026819	OLEG POPOV	{"email": "popov-o_1978@postgrespro.ru", "phone": "+70333134289"}
0005432428989	A4A1B1	2523 001950	RAISA VOLKOVA	{"email": "volkova.raisa_031973@postgrespro.ru", "phone": "+70005575390"}
0005432428990	60FCB3	6514 627382	VERA FOMINA	{"email": "vfomina091978@postgrespro.ru", "phone": "+70046298132"}
0005432428991	60FCB3	9219 529543	DANIL MIRONOV	{"email": "mironovd10021967@postgrespro.ru", "phone": "+70270577002"}
0005432428992	B3BB7F	4866 984335	ALEKSANDR MAKAROV	{"phone": "+70339316343"}
0005432428993	B3BB7F	0692 893003	MARIYA PETROVA	{"phone": "+70384107197"}
0005432428994	B3BB7F	4403 332836	MAKSIM MOROZOV	{"phone": "+70578199223"}
0005432428995	D1A384	9145 530656	NADEZHDA IVANOVA	{"email": "n-ivanova1982@postgrespro.ru", "phone": "+70047664705"}
0005432428996	D1A384	4078 665635	ALIK VOROBEV	{"phone": "+70144410250"}
0005432428997	D1A384	6705 432880	EVGENIY ROMANOV	{"phone": "+70249865352"}
0005432428998	1BCF1E	6814 976412	LYUDMILA EFREMOVA	{"email": "efremoval-04021976@postgrespro.ru", "phone": "+70930416227"}
0005432428999	032497	6431 278028	NATALIYA AKIMOVA	{"email": "nataliya_akimova071970@postgrespro.ru", "phone": "+70707761178"}
0005432429000	2FC264	1501 209366	TATYANA BOGDANOVA	{"email": "t.bogdanova.1972@postgrespro.ru", "phone": "+70216206182"}
0005432429001	2FC264	2854 857952	NINA TARASOVA	{"email": "tarasova_n.111968@postgrespro.ru", "phone": "+70211773395"}
0005432429002	3FF9C2	2531 097803	VLADISLAV FROLOV	{"phone": "+70943875548"}
0005432429003	2C04C2	4990 399793	ZHANNA NAUMOVA	{"email": "naumova-zhanna.05121971@postgrespro.ru", "phone": "+70280726560"}
0005432429004	254791	0562 271540	ANDREY MIRONOV	{"phone": "+70495906276"}
0005432429005	254791	4795 899653	TATYANA GAVRILOVA	{"phone": "+70757736413"}
0005432429006	06AF63	1943 175629	VADIM ROMANOV	{"phone": "+70451362862"}
0005432429007	209CD3	5318 450344	GALINA KUZNECOVA	{"phone": "+70391247113"}
0005432429008	209CD3	8545 411932	MIKHAIL ALEKSANDROV	{"phone": "+70932034710"}
0005432429009	F46420	3049 057214	MARIYA BOGDANOVA	{"email": "m-bogdanova_031966@postgrespro.ru", "phone": "+70860362136"}
0005432429010	F46420	7498 487495	GULNARA ALEKSEEVA	{"phone": "+70873396617"}
0005432429011	F46420	8725 381814	ALEKSEY ZAKHAROV	{"phone": "+70093693913"}
0005432429012	0CF192	2812 008019	SNEZHANA VOLKOVA	{"email": "s-volkova.24071977@postgrespro.ru", "phone": "+70843770850"}
0005432429013	0CF192	5486 254219	GALINA ILINA	{"phone": "+70884641898"}
0005432429014	FC506A	4047 805527	ELIZAVETA BARANOVA	{"email": "baranova_elizaveta_12111971@postgrespro.ru", "phone": "+70724770686"}
0005432429015	FC506A	8970 847983	NINA MAKSIMOVA	{"email": "maksimovan.03011963@postgrespro.ru", "phone": "+70646704894"}
0005432429016	FC506A	4783 802778	EKATERINA TROFIMOVA	{"phone": "+70392061010"}
0005432429017	DB28C1	2544 723068	GENNADIY NIKITIN	{"phone": "+70056603562"}
0005432429018	AFF8AC	8967 626180	SERGEY EGOROV	{"email": "egorov.s.081970@postgrespro.ru", "phone": "+70808222302"}
0005432429019	2D548F	5870 543321	RAISA ALEKSANDROVA	{"email": "aleksandrova-raisa.051974@postgrespro.ru", "phone": "+70946362634"}
0005432429020	2D548F	2071 034662	TATYANA VOROBEVA	{"phone": "+70137761484"}
0005432429021	ABB211	5944 222851	GALINA IVANOVA	{"phone": "+70138626376"}
0005432429022	4A820D	0829 629798	EVGENIY FROLOV	{"email": "evgeniy.frolov1965@postgrespro.ru", "phone": "+70310661592"}
0005432429023	FC147D	0937 558640	VERA ILINA	{"phone": "+70563222203"}
0005432429024	FC147D	4515 567232	RODION NAUMOV	{"email": "naumov_rodion-041970@postgrespro.ru", "phone": "+70857160168"}
0005432429025	FB8B9B	0451 742326	MARIYA NIKOLAEVA	{"phone": "+70594759390"}
0005432429026	FB8B9B	0146 229122	MARIYA PAVLOVA	{"phone": "+70545461158"}
0005432429027	FB8B9B	5267 882145	NINA MIKHAYLOVA	{"phone": "+70545620823"}
0005432429028	20EB0A	8545 184191	MAKSIM ZHUKOV	{"phone": "+70414006005"}
0005432429029	20EB0A	0570 133747	RADIK TIMOFEEV	{"email": "timofeev-radik-101978@postgrespro.ru", "phone": "+70055965862"}
0005432429030	87732C	7167 973087	IRINA KOROLEVA	{"phone": "+70866009724"}
0005432429031	84066A	5325 037650	YURIY SOROKIN	{"phone": "+70002989669"}
0005432429032	84066A	7206 576569	MARFA NOVIKOVA	{"email": "novikovam111982@postgrespro.ru", "phone": "+70264308164"}
0005432429033	84066A	7560 566964	RAFAIL NIKOLAEV	{"email": "nikolaev_r-26061977@postgrespro.ru", "phone": "+70582177028"}
0005432429034	81B525	3546 050614	SERGEY KUZNECOV	{"email": "sergey_kuznecov-081973@postgrespro.ru", "phone": "+70320962049"}
0005432430800	187977	7947 993325	ALLA AKIMOVA	{"email": "a_akimova-02071976@postgrespro.ru", "phone": "+70861198016"}
0005432430801	187977	9847 398674	NADEZHDA ZAKHAROVA	{"email": "zakharova_nadezhda25041977@postgrespro.ru", "phone": "+70826287877"}
0005432430802	2BD441	4200 593174	TIMOFEY YAKOVLEV	{"phone": "+70938420603"}
0005432430803	3AC0FB	3640 963455	TATYANA RODIONOVA	{"email": "rodionova.tatyana-071975@postgrespro.ru", "phone": "+70843615944"}
0005432430804	3E595F	5539 194207	IBRAGIM IVANOV	{"email": "ibragim.ivanov_041967@postgrespro.ru", "phone": "+70379603508"}
0005432430805	3E595F	8736 597924	RASIM SMIRNOV	{"email": "smirnovr061981@postgrespro.ru", "phone": "+70818185523"}
0005432430806	3E595F	3809 847431	NELLYA BELOVA	{"phone": "+70441390082"}
0005432430807	397FDC	7379 987535	LARISA POPOVA	{"phone": "+70169030463"}
0005432430808	A09E91	3596 667196	EGOR EGOROV	{"phone": "+70755561725"}
0005432430809	6A7DF5	4276 378678	ANASTASIYA ZAYCEVA	{"phone": "+70517952876"}
0005432430810	197237	2466 212427	SERGEY KONOVALOV	{"phone": "+70436156159"}
0005432430811	197237	4712 995714	TAMARA SEMENOVA	{"phone": "+70626438792"}
0005432430812	197237	2633 607444	ROMAN PETROV	{"email": "petrov-roman031982@postgrespro.ru", "phone": "+70736124103"}
0005432430813	8298F1	7950 073823	KRISTINA SMIRNOVA	{"email": "smirnova_kristina.121976@postgrespro.ru", "phone": "+70006295932"}
0005432430814	04B7A2	4721 215582	SNEZHANA PAVLOVA	{"email": "pavlovas-21081971@postgrespro.ru", "phone": "+70957628607"}
0005432430815	04B7A2	3207 952728	ANASTASIYA ROMANOVA	{"email": "romanova_a1971@postgrespro.ru", "phone": "+70154180100"}
0005432430816	465981	6660 628813	TATYANA PETROVA	{"email": "t-petrova1973@postgrespro.ru", "phone": "+70159093413"}
0005432430817	23342A	3062 653666	EVGENIY KAZAKOV	{"email": "kazakov_e25101970@postgrespro.ru", "phone": "+70168620477"}
0005432430818	23342A	6332 335894	LYUDMILA FROLOVA	{"email": "frolova-l121973@postgrespro.ru", "phone": "+70372093967"}
0005432430819	351408	1306 070347	VLADIMIR ABRAMOV	{"email": "vladimir-abramov.041981@postgrespro.ru", "phone": "+70228605190"}
0005432430820	351408	0934 463496	ANNA MAKAROVA	{"email": "makarova-a-01091962@postgrespro.ru", "phone": "+70838903573"}
0005432430821	177141	4906 863213	OLGA FEDOROVA	{"phone": "+70730929216"}
0005432430822	EBA5F9	1831 572444	VLADIMIR MAKAROV	{"phone": "+70469392480"}
0005432430823	EBA5F9	7468 465649	NATALIYA VASILEVA	{"email": "n_vasileva.021977@postgrespro.ru", "phone": "+70577643456"}
0005432430824	EBA5F9	7700 859824	ALEKSEY MAKSIMOV	{"phone": "+70889556528"}
0005432430825	3B5EC8	3047 457043	SERGEY POPOV	{"email": "popov_sergey.061977@postgrespro.ru", "phone": "+70108820252"}
0005432430826	8ECCCA	9895 702204	SHAMIL KAZAKOV	{"email": "kazakovs091968@postgrespro.ru", "phone": "+70377375821"}
0005432430827	6ABF89	0716 156307	TATYANA BELOVA	{"phone": "+70994826311"}
0005432430828	6ABF89	8943 776547	ANDREY KRASNOV	{"phone": "+70266287298"}
0005432430829	CAB98F	4556 276715	OKSANA PAVLOVA	{"phone": "+70780462422"}
0005432430830	F5FAAB	6973 069446	NADEZHDA LEBEDEVA	{"phone": "+70994427360"}
0005432430831	709FD0	4578 815024	GRIGORIY ZAKHAROV	{"email": "zakharov-grigoriy-1970@postgrespro.ru", "phone": "+70923470683"}
0005432430832	9EC4A0	3891 008456	LEONID KUZNECOV	{"email": "leonid.kuznecov121972@postgrespro.ru", "phone": "+70795497846"}
0005432430833	AAD869	7805 702125	SVETLANA IVANOVA	{"email": "ivanova.svetlana.23081968@postgrespro.ru", "phone": "+70571756584"}
0005432430834	657DDA	1500 012199	NIKOLAY NIKITIN	{"email": "nikolay-nikitin-1968@postgrespro.ru", "phone": "+70624404509"}
0005432430835	657DDA	0966 066043	ANNA POPOVA	{"email": "anna.popova16091979@postgrespro.ru", "phone": "+70281128540"}
0005432430836	A63A93	3513 333262	ANDREY POPOV	{"phone": "+70181906400"}
0005432430837	04058A	5487 641734	TATYANA SAVELEVA	{"email": "savelevat_12061981@postgrespro.ru", "phone": "+70322578762"}
0005432430838	EE8AE4	3975 560952	VIKTOR VLASOV	{"email": "viktor_vlasov_121974@postgrespro.ru", "phone": "+70973987751"}
0005432430839	EE8AE4	0386 290711	NINA OSIPOVA	{"phone": "+70293700712"}
0005432430840	E93372	8301 480920	TATYANA NAZAROVA	{"email": "t_nazarova091964@postgrespro.ru", "phone": "+70739651561"}
0005432430841	22AD7B	5024 595392	GALINA NIKIFOROVA	{"email": "nikiforova_g031969@postgrespro.ru", "phone": "+70129875144"}
0005432430842	49C4DB	5266 101040	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev-13121964@postgrespro.ru", "phone": "+70276860245"}
0005432430843	57EBC3	6241 445312	VIKTOR FROLOV	{"phone": "+70946356878"}
0005432430844	85078E	8432 239166	YURIY GUSEV	{"phone": "+70492583991"}
0005432430845	662BAC	2019 786008	ALEKSANDR NIKITIN	{"phone": "+70065802255"}
0005432430846	E01909	3263 991194	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay_051968@postgrespro.ru", "phone": "+70365909219"}
0005432430847	7AE483	6618 745035	YURIY MEDVEDEV	{"email": "yuriy_medvedev.031977@postgrespro.ru", "phone": "+70858825264"}
0005432430848	DF9802	4565 786751	SERGEY MAKAROV	{"phone": "+70462025976"}
0005432430849	83ED3B	6793 122931	OLGA ANDREEVA	{"email": "o.andreeva.25051971@postgrespro.ru", "phone": "+70474814982"}
0005432430850	A7D601	3468 193227	NINA MAKAROVA	{"phone": "+70993240995"}
0005432430851	A7D601	9604 601945	EKATERINA DAVYDOVA	{"phone": "+70122445485"}
0005432430852	D91374	3019 108736	DARYA VOLKOVA	{"phone": "+70050139120"}
0005432430853	D91374	4476 817948	VYACHESLAV KONOVALOV	{"phone": "+70036519884"}
0005432430854	DBC98C	8138 431902	LIDIYA LEBEDEVA	{"phone": "+70502763268"}
0005432430855	DBC98C	4488 496232	NATALYA KRASNOVA	{"email": "natalya.krasnova-1973@postgrespro.ru", "phone": "+70198369813"}
0005432430856	4B43C2	3634 921012	ALEKSANDR ABRAMOV	{"phone": "+70657463203"}
0005432430857	43C381	0478 115631	YULIYA PAVLOVA	{"email": "pavlovay-111990@postgrespro.ru", "phone": "+70697643418"}
0005432430858	634E3A	5060 812889	EVGENIY SCHERBAKOV	{"email": "scherbakov-evgeniy_101972@postgrespro.ru", "phone": "+70949987046"}
0005432430859	A2BD90	8703 729252	RINAT RODIONOV	{"phone": "+70687555386"}
0005432430860	B9FB16	7790 708348	NATALYA LUKYANOVA	{"email": "natalya-lukyanova_111974@postgrespro.ru", "phone": "+70981175346"}
0005432430861	B21F47	9732 144594	GENNADIY KONOVALOV	{"email": "konovalov-g061976@postgrespro.ru", "phone": "+70329367942"}
0005432430862	6E4101	4975 924507	ELENA KOZLOVA	{"email": "kozlova.e02041972@postgrespro.ru", "phone": "+70276901155"}
0005432430863	819F23	0104 285668	LARISA VASILEVA	{"phone": "+70292030981"}
0005432430864	8E8BD7	4580 748933	YULIYA SERGEEVA	{"phone": "+70591590263"}
0005432430865	8E8BD7	5211 139710	VLADIMIR KUZNECOV	{"phone": "+70288918184"}
0005432430866	4D6A12	5460 919094	EMILIYA FOMINA	{"email": "fomina.emiliya-121973@postgrespro.ru", "phone": "+70903043022"}
0005432430867	303BA9	4245 136620	VALENTINA KULIKOVA	{"email": "kulikova_v.011981@postgrespro.ru", "phone": "+70379867533"}
0005432430868	303BA9	8663 559848	ANTON SERGEEV	{"phone": "+70010757324"}
0005432430869	4B71A4	1029 203994	GRIGORIY NAZAROV	{"email": "g_nazarov1965@postgrespro.ru", "phone": "+70893630429"}
0005432430870	8F87E1	7418 363617	NADEZHDA LAZAREVA	{"phone": "+70695687914"}
0005432430871	9175EA	3254 556873	VLADISLAV KUZNECOV	{"email": "v_kuznecov.1976@postgrespro.ru", "phone": "+70806267235"}
0005432430872	1E31A1	6151 091025	ALEKSANDRA GAVRILOVA	{"email": "gavrilova.a1972@postgrespro.ru", "phone": "+70950840531"}
0005432430873	6E0F89	6505 787575	NIKOLAY FEDOTOV	{"email": "nikolay_fedotov081987@postgrespro.ru", "phone": "+70464512677"}
0005432430874	F2394A	4072 479834	KIRILL KULIKOV	{"email": "kulikov-kirill1973@postgrespro.ru", "phone": "+70957505894"}
0005432430875	CCA5D9	1129 514397	TATYANA AFANASEVA	{"phone": "+70506354013"}
0005432430876	CCA5D9	0697 774719	ELINA KUZNECOVA	{"phone": "+70458961273"}
0005432430877	F4AFA2	7113 314621	YULIYA KISELEVA	{"phone": "+70904862213"}
0005432430878	AB2161	3902 061899	ELENA VASILEVA	{"email": "vasileva_elena_18051981@postgrespro.ru", "phone": "+70060129826"}
0005432430879	739520	8808 586277	NATALYA BORISOVA	{"email": "n_borisova.09031955@postgrespro.ru", "phone": "+70256246268"}
0005432430880	739520	4984 140300	KARINA KRASNOVA	{"email": "krasnovakarina-17121972@postgrespro.ru", "phone": "+70454410601"}
0005432430881	289845	0320 247452	ZOYA VOLKOVA	{"email": "zvolkova-1967@postgrespro.ru", "phone": "+70751071297"}
0005432430882	723ACC	8221 510655	SVETLANA ZAKHAROVA	{"phone": "+70575279810"}
0005432430883	32F96B	7689 676007	LARISA STEPANOVA	{"email": "stepanova.larisa.12081982@postgrespro.ru", "phone": "+70894043454"}
0005432430884	32F96B	6870 084019	GENNADIY IVANOV	{"email": "gennadiy.ivanov14051967@postgrespro.ru", "phone": "+70246491144"}
0005432430885	32F96B	5914 027767	MARIYA POPOVA	{"phone": "+70863496104"}
0005432430886	3AA701	5866 612341	RAMAZAN POPOV	{"email": "ramazanpopov-1961@postgrespro.ru", "phone": "+70702470913"}
0005432430887	BA7073	4911 540108	MARAT MELNIKOV	{"email": "m-melnikov.10091980@postgrespro.ru", "phone": "+70079802170"}
0005432430888	BA7073	5493 355174	SERGEY KRASNOV	{"email": "krasnov.s16111975@postgrespro.ru", "phone": "+70765388059"}
0005432430889	12842C	9821 976491	IVAN KARPOV	{"phone": "+70978274964"}
0005432430890	82E504	1257 256583	TATYANA CHERNOVA	{"phone": "+70904916862"}
0005432430891	006D1A	9236 409469	VASILIY KULIKOV	{"email": "kulikov_v_07011967@postgrespro.ru", "phone": "+70607388279"}
0005432430892	D3F1EF	9054 381388	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir-1979@postgrespro.ru", "phone": "+70809332403"}
0005432430893	9608AD	7091 929759	ANDREY MAKSIMOV	{"email": "maksimov.andrey-101971@postgrespro.ru", "phone": "+70664975212"}
0005432430894	C381F7	8569 907811	DENIS TIKHONOV	{"phone": "+70816513477"}
0005432430895	C381F7	2363 393247	NADEZHDA MOROZOVA	{"email": "morozova-nadezhda-1967@postgrespro.ru", "phone": "+70680873559"}
0005432430896	4D9405	2887 930133	ANATOLIY TIMOFEEV	{"email": "anatoliy.timofeev_1973@postgrespro.ru", "phone": "+70583815473"}
0005432430897	4D9405	9843 485546	SERGEY GAVRILOV	{"email": "gavrilovsergey_13051973@postgrespro.ru", "phone": "+70098242385"}
0005432430898	F9A67D	3711 918334	LYUDMILA MAKSIMOVA	{"phone": "+70728496926"}
0005432430899	D5DC1C	3050 136690	NINA ORLOVA	{"phone": "+70431707118"}
0005432430900	105CD4	3033 194299	EVGENIY VOLKOV	{"email": "e-volkov011975@postgrespro.ru", "phone": "+70353358385"}
0005432430901	1BC123	2439 342335	DARYA DANILOVA	{"email": "ddanilova.1979@postgrespro.ru", "phone": "+70924158241"}
0005432430902	1BC123	2665 164316	NATALYA POPOVA	{"phone": "+70861709086"}
0005432430903	305052	2891 498978	VERA IVANOVA	{"phone": "+70361830861"}
0005432430904	4C0993	5417 760738	VLADIMIR SEMENOV	{"email": "v_semenov-051964@postgrespro.ru", "phone": "+70722918234"}
0005432430905	4C0993	0352 215502	ALEKSEY FROLOV	{"phone": "+70125797965"}
0005432430906	37E645	5737 264707	EKATERINA NIKOLAEVA	{"phone": "+70503566991"}
0005432430907	6D088B	9947 331559	GALINA BELOVA	{"phone": "+70862101911"}
0005432430908	6D088B	1518 487050	ARTEM ILIN	{"email": "ilin_a.1968@postgrespro.ru", "phone": "+70987392717"}
0005432430909	9207FD	1201 021134	DMITRIY ZHURAVLEV	{"email": "dmitriyzhuravlev.08021974@postgrespro.ru", "phone": "+70688435621"}
0005432430910	F44CF7	3043 477699	KONSTANTIN SERGEEV	{"phone": "+70321293506"}
0005432430911	CB2907	3871 748565	MARIYA KOZLOVA	{"phone": "+70925928594"}
0005432430912	83F647	4405 810104	GALINA FILIPPOVA	{"phone": "+70884761627"}
0005432430913	81FF4F	3258 818060	IVAN SAVELEV	{"phone": "+70517380651"}
0005432430914	81FF4F	9852 613696	GENNADIY VOROBEV	{"email": "g_vorobev.31051965@postgrespro.ru", "phone": "+70386005991"}
0005432430915	24C7A6	1524 629857	OLGA MOROZOVA	{"email": "morozovaolga-1969@postgrespro.ru", "phone": "+70437933644"}
0005432430916	24C7A6	3394 430181	KRISTINA MOROZOVA	{"email": "kristina_morozova-01051964@postgrespro.ru", "phone": "+70445255876"}
0005432430917	AE8996	0586 952185	NATALYA ZHUKOVA	{"email": "zhukovanatalya_29091978@postgrespro.ru", "phone": "+70792090568"}
0005432430918	B8B883	4980 552616	ELENA IVANOVA	{"phone": "+70213455761"}
0005432430919	1355CE	6242 425041	MIKHAIL GERASIMOV	{"phone": "+70368542875"}
0005432430920	041B49	0196 472481	ALEKSANDR MATVEEV	{"phone": "+70673137917"}
0005432430921	758CE8	2088 186907	GALINA SERGEEVA	{"email": "galina.sergeeva.1976@postgrespro.ru", "phone": "+70411095598"}
0005432430922	758CE8	8795 008588	ALEKSEY KUZNECOV	{"phone": "+70835302636"}
0005432430923	6A49FF	4399 911144	ALEKSANDR IVANOV	{"phone": "+70846369763"}
0005432430924	6A49FF	3254 311984	VERA TARASOVA	{"phone": "+70105191543"}
0005432430925	953CF5	5948 789874	RUSLAN SCHERBAKOV	{"email": "scherbakov-r.1971@postgrespro.ru", "phone": "+70919458397"}
0005432430926	DD211E	3295 340076	ANDREY AFANASEV	{"phone": "+70820718867"}
0005432430927	D46A6F	1661 964668	ARMEN KONOVALOV	{"email": "konovalova071972@postgrespro.ru", "phone": "+70010794770"}
0005432433591	CACC88	4787 542876	VIKTOR MATVEEV	{"phone": "+70202479564"}
0005432430928	D46A6F	4052 816818	PAVEL ALEKSEEV	{"email": "alekseevp_1966@postgrespro.ru", "phone": "+70305306686"}
0005432430929	6719CB	6954 676845	NINA ALEKSEEVA	{"email": "alekseeva_n-061966@postgrespro.ru", "phone": "+70514860427"}
0005432430930	6719CB	6290 436505	ALENA AKIMOVA	{"phone": "+70034539589"}
0005432430931	632FF2	6269 141131	SERGEY FEDOTOV	{"email": "s-fedotov051973@postgrespro.ru", "phone": "+70884502422"}
0005432430932	52804A	9632 026373	VITALIY MEDVEDEV	{"phone": "+70534956004"}
0005432430933	52804A	5605 281826	SVETLANA MIRONOVA	{"phone": "+70374131280"}
0005432430934	289D04	9610 071990	GENNADIY KRASNOV	{"email": "krasnov.gennadiy05081966@postgrespro.ru", "phone": "+70664561902"}
0005432430935	9A8451	8689 396920	SERGEY PAVLOV	{"email": "pavlov.s-30071978@postgrespro.ru", "phone": "+70298824621"}
0005432430936	9A8451	1796 490593	ANZHELA FROLOVA	{"email": "anzhela.frolova03051981@postgrespro.ru", "phone": "+70527066139"}
0005432430937	9A8451	8374 496913	VIKTOR KUZNECOV	{"email": "kuznecovviktor.02041963@postgrespro.ru", "phone": "+70627952332"}
0005432430938	8F9B76	4287 196863	LARISA FROLOVA	{"email": "frolova.l.1967@postgrespro.ru", "phone": "+70017641685"}
0005432430939	CF51FE	0632 974062	ELENA ZHUKOVA	{"phone": "+70135111034"}
0005432430940	F027B7	4668 187664	NIKOLAY GRIGOREV	{"email": "grigorev_n_04041974@postgrespro.ru", "phone": "+70469456330"}
0005432430941	F027B7	2964 981793	VIKTOR KOROLEV	{"email": "vkorolev-1976@postgrespro.ru", "phone": "+70477710062"}
0005432430942	701DF4	0899 418203	EVGENIY POPOV	{"email": "e_popov.15021965@postgrespro.ru", "phone": "+70450064689"}
0005432430943	CDA51A	5399 943108	OLGA ANDREEVA	{"phone": "+70643023530"}
0005432430944	D65BB0	3055 641524	NINA VASILEVA	{"phone": "+70137711982"}
0005432430945	4D4307	0929 278070	VERA YAKOVLEVA	{"email": "yakovleva-vera_24011977@postgrespro.ru", "phone": "+70550041974"}
0005432430946	128C3E	8918 214351	VALENTIN SMIRNOV	{"phone": "+70944832361"}
0005432430947	2F374F	5719 599607	ZAKHAR GUSEV	{"email": "gusev-zakhar_1977@postgrespro.ru", "phone": "+70083463106"}
0005432430948	C414D4	5887 796018	ZHANNA DAVYDOVA	{"email": "davydova-zhanna.01031973@postgrespro.ru", "phone": "+70117115343"}
0005432430949	C414D4	1126 360747	NIKITA SEMENOV	{"phone": "+70782847433"}
0005432430950	F17601	9495 437571	OLGA MAKAROVA	{"phone": "+70952538904"}
0005432430951	A8246A	1174 304089	LIDIYA AKIMOVA	{"email": "akimova_l081969@postgrespro.ru", "phone": "+70851792944"}
0005432430952	87BD72	9402 952530	VLADIMIR NIKOLAEV	{"email": "v-nikolaev091968@postgrespro.ru", "phone": "+70903380000"}
0005432430953	87BD72	9374 590073	GULSHAT ANDREEVA	{"phone": "+70478580647"}
0005432430954	2BA020	7994 557014	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov.19021986@postgrespro.ru", "phone": "+70587978595"}
0005432430955	2BA020	5507 047462	LYUDMILA ZOTOVA	{"email": "zotova.lyudmila-1966@postgrespro.ru", "phone": "+70674039651"}
0005432430956	503A31	2946 420201	ANATOLIY SOKOLOV	{"email": "sokolov-a-1972@postgrespro.ru", "phone": "+70629962757"}
0005432430957	A34187	8296 432101	VLADIMIR YAKOVLEV	{"email": "yakovlevv.30101970@postgrespro.ru", "phone": "+70884287280"}
0005432430958	A34187	3312 354463	NIKOLAY FILIPPOV	{"phone": "+70052822474"}
0005432430959	5292C7	8149 899226	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov011970@postgrespro.ru", "phone": "+70123305103"}
0005432430960	6DBD9B	7345 504179	ALEKSANDR PAVLOV	{"phone": "+70940938391"}
0005432430961	2F723A	1855 084920	VLADIMIR GORBUNOV	{"email": "v.gorbunov.021991@postgrespro.ru", "phone": "+70124094927"}
0005432430962	2F723A	0952 324834	NADEZHDA ZOTOVA	{"phone": "+70513791494"}
0005432430963	E7E7D1	5298 306935	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_aleksandr_1975@postgrespro.ru", "phone": "+70389820247"}
0005432430964	E7E7D1	2360 769906	YANA POLYAKOVA	{"phone": "+70553096845"}
0005432430965	F9A09E	6717 259031	NADEZHDA ALEKSEEVA	{"email": "nadezhdaalekseeva-121973@postgrespro.ru", "phone": "+70436283653"}
0005432430966	F9A09E	6636 324408	ANASTASIYA NAUMOVA	{"email": "anastasiya_naumova.121967@postgrespro.ru", "phone": "+70900730212"}
0005432430967	82316A	4302 224789	OLEG EGOROV	{"email": "egorov.o.01031977@postgrespro.ru", "phone": "+70557635858"}
0005432430968	82316A	0949 126238	IGOR KULIKOV	{"email": "i-kulikov-01051975@postgrespro.ru", "phone": "+70244861043"}
0005432430969	82316A	9657 269229	VIKTOR MAKSIMOV	{"phone": "+70715234709"}
0005432430970	04914D	6634 342695	MARIYA SAVELEVA	{"email": "mariya_saveleva_05091974@postgrespro.ru", "phone": "+70035212076"}
0005432430971	E7827E	0779 013929	YULIYA SEMENOVA	{"email": "semenovayuliya_06091964@postgrespro.ru", "phone": "+70306630753"}
0005432430972	3914C7	0534 109099	TATYANA BELOVA	{"phone": "+70449760992"}
0005432430973	FED314	6693 335274	ALEKSEY DAVYDOV	{"email": "davydov_a_031982@postgrespro.ru", "phone": "+70303778564"}
0005432430974	64DD2E	1948 473117	TAMARA ZHUKOVA	{"email": "zhukova.t.18081977@postgrespro.ru", "phone": "+70378404388"}
0005432430975	8A7A3E	6840 329691	OLGA MATVEEVA	{"email": "o-matveeva1964@postgrespro.ru", "phone": "+70661452809"}
0005432433582	8A08FF	5040 118592	NATALYA KAZAKOVA	{"phone": "+70425074922"}
0005432433583	DB1ED1	7436 081156	VALERIYA KAZAKOVA	{"email": "vkazakova_021979@postgrespro.ru", "phone": "+70067206049"}
0005432433584	DB1ED1	2082 221372	VYACHESLAV BARANOV	{"email": "baranovvyacheslav.041966@postgrespro.ru", "phone": "+70812895345"}
0005432433585	E94EE2	8320 241981	VIKTORIYA POTAPOVA	{"email": "potapova_viktoriya.1958@postgrespro.ru", "phone": "+70492699400"}
0005432433586	E94EE2	3302 256559	SERGEY SOLOVEV	{"email": "sergey.solovev-041979@postgrespro.ru", "phone": "+70046339063"}
0005432433587	B2A473	6075 952783	LYUBOV FOMINA	{"phone": "+70128535955"}
0005432433588	B2A473	3093 518230	ANDREY SOKOLOV	{"email": "a-sokolov_09091972@postgrespro.ru", "phone": "+70475518897"}
0005432433589	CACC88	9345 802816	VALENTINA ZAYCEVA	{"phone": "+70467624619"}
0005432433590	CACC88	6314 080158	SERGEY MIRONOV	{"email": "sergey.mironov_1971@postgrespro.ru", "phone": "+70349129697"}
0005432433592	E64559	2217 909184	IRINA SOROKINA	{"phone": "+70825771835"}
0005432433593	DB77A7	4670 287358	NATALYA DENISOVA	{"phone": "+70771538964"}
0005432433594	C5F786	3001 857437	GENNADIY ALEKSEEV	{"email": "g-alekseev1976@postgrespro.ru", "phone": "+70862269920"}
0005432433595	09A03C	1943 177468	TATYANA KAZAKOVA	{"email": "t-kazakova_1977@postgrespro.ru", "phone": "+70630836138"}
0005432433596	CD0E40	2061 804413	GENNADIY TIKHONOV	{"phone": "+70765220681"}
0005432433597	8236AC	9842 325372	KONSTANTIN POPOV	{"email": "popov.k1973@postgrespro.ru", "phone": "+70150256566"}
0005432433598	0AC0AF	1036 642332	FEDOR FEDOROV	{"phone": "+70107635024"}
0005432433599	20C1C4	2768 875237	NIKOLAY KISELEV	{"phone": "+70975025748"}
0005432433600	20C1C4	3181 721211	VLADISLAV KAZAKOV	{"email": "vladislav_kazakov_1963@postgrespro.ru", "phone": "+70655747835"}
0005432433601	8DABA9	3919 983646	OLGA IVANOVA	{"email": "oivanova.071975@postgrespro.ru", "phone": "+70472892925"}
0005432433602	A31887	8207 544348	VLADIMIR GAVRILOV	{"email": "gavrilov.v_04041969@postgrespro.ru", "phone": "+70224297784"}
0005432433603	36694F	5590 437975	TATYANA KUZNECOVA	{"phone": "+70479111441"}
0005432433604	36694F	3676 664200	ANNA LUKYANOVA	{"email": "a_lukyanova_111972@postgrespro.ru", "phone": "+70237590235"}
0005432433605	5CC730	2908 654837	ANNA FROLOVA	{"phone": "+70161855987"}
0005432433606	C5A6D7	8440 882305	NATALYA CHERNOVA	{"phone": "+70422448596"}
0005432433607	C5A6D7	1771 211437	STANISLAV ABRAMOV	{"phone": "+70596671830"}
0005432433608	829050	1695 187644	STEPAN SIDOROV	{"phone": "+70033472903"}
0005432433609	A00D4E	5516 398491	OLGA STEPANOVA	{"email": "olga.stepanova-1979@postgrespro.ru", "phone": "+70647168677"}
0005432433610	A00D4E	6109 873921	VIKTOR KONOVALOV	{"phone": "+70028250942"}
0005432433611	145035	4704 017360	OLGA SOKOLOVA	{"email": "sokolova.o.1974@postgrespro.ru", "phone": "+70342165363"}
0005432433612	145035	7632 989069	ROMAN ABRAMOV	{"email": "abramov_roman_21021978@postgrespro.ru", "phone": "+70738624292"}
0005432433613	486FCF	7359 089043	NATALYA YAKOVLEVA	{"phone": "+70611180287"}
0005432433614	EF2636	1110 628593	SERGEY ISAEV	{"phone": "+70940198066"}
0005432433615	648FBD	9498 705844	KRISTINA SAVELEVA	{"phone": "+70947283037"}
0005432433616	648FBD	2636 152283	ALEKSEY SHEVCHENKO	{"email": "aleksey_shevchenko31051961@postgrespro.ru", "phone": "+70413153256"}
0005432433617	E50FD8	0347 882319	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov-1968@postgrespro.ru", "phone": "+70813343176"}
0005432433618	E50FD8	0221 321814	VYACHESLAV MOROZOV	{"email": "morozovvyacheslav.111978@postgrespro.ru", "phone": "+70057138708"}
0005432433619	E50FD8	2458 578421	SERGEY POPOV	{"email": "s-popov101972@postgrespro.ru", "phone": "+70546367030"}
0005432433620	D3C2F7	3348 036520	NATALYA NOVIKOVA	{"phone": "+70018573726"}
0005432433621	92C649	5241 594245	SERGEY SERGEEV	{"phone": "+70720183089"}
0005432433622	92C649	6793 343784	IRINA KUZMINA	{"phone": "+70994016871"}
0005432433623	C0C1B6	3353 066403	ALEKSANDRA ORLOVA	{"email": "orlova_aleksandra_081975@postgrespro.ru", "phone": "+70886034943"}
0005432433624	C0C1B6	0099 139530	NINA ABRAMOVA	{"email": "nabramova_1975@postgrespro.ru", "phone": "+70429481656"}
0005432433625	701A04	2558 714234	LYUDMILA SERGEEVA	{"email": "lsergeeva.101971@postgrespro.ru", "phone": "+70374333921"}
0005432433626	505810	7342 112091	MIKHAIL KOZLOV	{"email": "kozlov-m_1972@postgrespro.ru", "phone": "+70108656649"}
0005432433627	E24B57	7931 957612	VERA EFIMOVA	{"email": "efimova_vera_1977@postgrespro.ru", "phone": "+70455515110"}
0005432433628	9EA05C	1748 894523	YULIYA ARKHIPOVA	{"email": "arkhipova-y.08031978@postgrespro.ru", "phone": "+70881220659"}
0005432433629	862866	4487 910344	ALEKSANDRA PETROVA	{"phone": "+70117206466"}
0005432433630	94D3F4	3634 706988	LYUBOV KULIKOVA	{"email": "l-kulikova-061959@postgrespro.ru", "phone": "+70689515250"}
0005432433631	A0EA72	8595 586253	EVELINA ALEKSANDROVA	{"email": "evelina_aleksandrova1972@postgrespro.ru", "phone": "+70542582422"}
0005432433632	814712	5673 596158	SVYATOSLAV FEDOROV	{"phone": "+70237054605"}
0005432433633	EC55DE	9233 709062	LYUBOV NOVIKOVA	{"phone": "+70496278816"}
0005432433634	288DD5	5466 668751	ARSENIY VASILEV	{"email": "a.vasilev-101975@postgrespro.ru", "phone": "+70427977549"}
0005432433635	675586	7276 465267	ALEKSEY KAZAKOV	{"phone": "+70847375422"}
0005432433636	675586	6109 046354	KHASAN SERGEEV	{"email": "sergeevkhasan_1960@postgrespro.ru", "phone": "+70209092024"}
0005432433637	BB2172	0194 786288	NIKITA SERGEEV	{"email": "nikita.sergeev.06081962@postgrespro.ru", "phone": "+70965209080"}
0005432433638	BB2172	3744 662784	ELIZAVETA DMITRIEVA	{"phone": "+70053737469"}
0005432433639	0A2085	1649 510693	SVETLANA DAVYDOVA	{"email": "s-davydova-1972@postgrespro.ru", "phone": "+70763094331"}
0005432433640	E36C7A	6986 467068	VASILIY VOROBEV	{"email": "v.vorobev-1974@postgrespro.ru", "phone": "+70984962084"}
0005432433641	6D0FBB	2742 901602	NINA KUZNECOVA	{"email": "n-kuznecova-1976@postgrespro.ru", "phone": "+70732405199"}
0005432433642	4DA68B	8758 449687	ANATOLIY DAVYDOV	{"email": "a.davydov_121979@postgrespro.ru", "phone": "+70753701920"}
0005432433643	D93D69	7581 640239	NATALYA YAKOVLEVA	{"phone": "+70365277122"}
0005432433644	A81414	3595 961587	VALENTINA SCHERBAKOVA	{"email": "v.scherbakova30051976@postgrespro.ru", "phone": "+70442313236"}
0005432433645	6F8CD3	7848 329052	ROMAN ANDREEV	{"email": "andreev-roman-1972@postgrespro.ru", "phone": "+70927178060"}
0005432433646	43BBD6	5396 375100	EVGENIY KRASNOV	{"phone": "+70019755938"}
0005432433647	43BBD6	1461 628106	SERGEY IVANOV	{"phone": "+70885881227"}
0005432433648	5845FD	7759 875378	VALERIY VOLKOV	{"email": "v_volkov-061977@postgrespro.ru", "phone": "+70544093696"}
0005432433649	0488F7	4923 873527	LIDIYA SAVELEVA	{"email": "l-saveleva101981@postgrespro.ru", "phone": "+70149663776"}
0005432433650	6DAD42	2508 293046	ALEKSEY VASILEV	{"email": "alekseyvasilev-1975@postgrespro.ru", "phone": "+70512679697"}
0005432433651	9917E3	4846 970690	OLGA ALEKSEEVA	{"phone": "+70193296408"}
0005432433652	9917E3	9479 703091	GALINA DANILOVA	{"email": "danilova.g_1970@postgrespro.ru", "phone": "+70864358238"}
0005432433653	9917E3	9369 832519	ILDAR NIKOLAEV	{"phone": "+70506571290"}
0005432433654	F83CA7	4131 578428	DARINA DMITRIEVA	{"phone": "+70874570637"}
0005432433655	F83CA7	2222 719152	ALEKSANDR FEDOROV	{"phone": "+70541300986"}
0005432433656	B002B6	7201 554012	YURIY PETROV	{"email": "yuriypetrov.041963@postgrespro.ru", "phone": "+70414231274"}
0005432433657	9B994D	3407 485269	NINA SEMENOVA	{"email": "nina_semenova-15121966@postgrespro.ru", "phone": "+70820830846"}
0005432433658	F3B699	0788 573061	OLGA MOROZOVA	{"email": "omorozova.12091982@postgrespro.ru", "phone": "+70631567731"}
0005432433659	77FAF4	7656 295633	IGOR PAVLOV	{"phone": "+70263820668"}
0005432433660	EDB261	1886 237759	OLGA BOGDANOVA	{"phone": "+70152606345"}
0005432433661	EDB261	1021 933048	TATYANA MAKSIMOVA	{"email": "tatyanamaksimova_1974@postgrespro.ru", "phone": "+70977495179"}
0005432433662	FAC81C	9510 494298	DARYA AKIMOVA	{"email": "akimova_darya.1972@postgrespro.ru", "phone": "+70327475541"}
0005432433663	FAC81C	2672 155754	MIKHAIL SIDOROV	{"email": "m.sidorov.1967@postgrespro.ru", "phone": "+70054357863"}
0005432433664	BB0186	2029 312998	LYUBOV FILIPPOVA	{"phone": "+70366787339"}
0005432433665	BB0186	7279 882595	YURIY ABRAMOV	{"phone": "+70360802663"}
0005432433666	39EF9C	9263 135653	ANNA GUSEVA	{"phone": "+70016186975"}
0005432433667	72D27D	0791 898790	MARIYA ANDREEVA	{"email": "andreeva.mariya-1977@postgrespro.ru", "phone": "+70727867199"}
0005432433668	72D27D	8242 723935	ALENA NIKITINA	{"email": "alenanikitina.041975@postgrespro.ru", "phone": "+70433145953"}
0005432433669	8F9920	6436 128396	VIKTORIYA PAVLOVA	{"email": "v.pavlova041980@postgrespro.ru", "phone": "+70049302810"}
0005432433670	196B54	5817 449642	DANIIL ABRAMOV	{"email": "dabramov1961@postgrespro.ru", "phone": "+70625389118"}
0005432433671	6FD54E	1870 586845	ZINAIDA SCHERBAKOVA	{"phone": "+70942174914"}
0005432433672	71876A	8137 047503	TATYANA MARTYNOVA	{"phone": "+70502042916"}
0005432433673	71876A	2015 161812	ELENA GAVRILOVA	{"email": "gavrilova_e-10011979@postgrespro.ru", "phone": "+70107444448"}
0005432433674	71876A	2486 625658	YURIY NAUMOV	{"phone": "+70223091620"}
0005432433675	A1A25A	4921 451491	DARYA NESTEROVA	{"email": "darya_nesterova.1970@postgrespro.ru", "phone": "+70235140159"}
0005432433676	A1A25A	9002 368739	NATALYA IVANOVA	{"email": "ivanova.natalya.28051973@postgrespro.ru", "phone": "+70741549430"}
0005432433677	B1B4FF	3617 024149	IRINA ZAKHAROVA	{"email": "izakharova_10011968@postgrespro.ru", "phone": "+70538859452"}
0005432433678	B1B4FF	9669 090082	VALENTINA NIKOLAEVA	{"phone": "+70185099041"}
0005432433679	B1B4FF	7587 035349	LYUDMILA GRISHINA	{"email": "grishina_l_1962@postgrespro.ru", "phone": "+70687611550"}
0005432433680	97A163	7902 489855	ANNA VOLKOVA	{"email": "avolkova-111976@postgrespro.ru", "phone": "+70261537710"}
0005432433681	CB5D97	5030 691838	VLADIMIR NIKOLAEV	{"phone": "+70934592618"}
0005432433682	597404	0418 077826	VIKTORIYA ZHUKOVA	{"phone": "+70658438004"}
0005432433683	D6DF6F	5145 873100	DMITRIY ZAKHAROV	{"phone": "+70442069138"}
0005432433684	5DACC5	4117 200610	STEPAN KUZNECOV	{"phone": "+70699887403"}
0005432433685	EE5683	1678 287171	ALEKSANDR ILIN	{"phone": "+70246219072"}
0005432433686	7D36A3	9130 394011	ARINA BORISOVA	{"email": "a_borisova_101965@postgrespro.ru", "phone": "+70875205677"}
0005432433687	7D36A3	6572 382144	ALEKSANDR ALEKSEEV	{"phone": "+70408425188"}
0005432433688	B9F725	7672 722357	KIRILL KUZMIN	{"email": "k-kuzmin.031970@postgrespro.ru", "phone": "+70011772088"}
0005432433689	06F882	7140 855106	SERGEY KOZLOV	{"email": "kozlov-sergey061973@postgrespro.ru", "phone": "+70315856665"}
0005432433690	06F882	1099 103328	ALEKSANDR KUZNECOV	{"phone": "+70339294003"}
0005432433691	217F67	3261 581515	GALINA OVCHINNIKOVA	{"email": "g_ovchinnikova.1973@postgrespro.ru", "phone": "+70617464000"}
0005432433692	217F67	5422 397394	LYUDMILA MOROZOVA	{"email": "morozoval.011955@postgrespro.ru", "phone": "+70755536226"}
0005432433693	B296AD	1153 626710	MARINA KISELEVA	{"email": "m_kiseleva.041973@postgrespro.ru", "phone": "+70309470880"}
0005432433694	E1C047	2124 207476	IVAN BORISOV	{"email": "ivan-borisov.1977@postgrespro.ru", "phone": "+70661864222"}
0005432433695	A979E2	4057 503134	YULIYA FILIPPOVA	{"phone": "+70386826206"}
0005432433696	D70040	2513 511971	LYUBOV NAUMOVA	{"phone": "+70585273541"}
0005432433697	4ACD6B	8772 334458	VALENTINA SEMENOVA	{"phone": "+70060467018"}
0005432433698	1F80CF	7993 472106	VASILIY MAKAROV	{"email": "makarovv_1974@postgrespro.ru", "phone": "+70245747331"}
0005432433699	1F80CF	5174 705315	ALEKSANDR KOZLOV	{"phone": "+70902773706"}
0005432433700	7473D4	0424 773431	VLADIMIR ROMANOV	{"phone": "+70033476983"}
0005432433701	041C3B	1094 006039	SVETLANA MIRONOVA	{"email": "mironova_s1972@postgrespro.ru", "phone": "+70808627640"}
0005432433702	969652	9529 914974	VIKTOR DAVYDOV	{"email": "v_davydov1980@postgrespro.ru", "phone": "+70230580243"}
0005432433703	52E808	0558 337705	ALEKSANDR SAVELEV	{"phone": "+70227741558"}
0005432433704	B4F4A2	7449 007296	VLADIMIR ALEKSANDROV	{"phone": "+70117666604"}
0005432433705	B4F4A2	1055 312140	ALEVTINA GRISHINA	{"phone": "+70146045398"}
0005432433706	4EBFE0	8416 918283	ANDREY KARPOV	{"phone": "+70867928669"}
0005432433707	BD0E29	0770 273447	LILIYA MATVEEVA	{"phone": "+70522392654"}
0005432433708	9D2648	0617 753698	IRINA FILIPPOVA	{"email": "filippova.i-1968@postgrespro.ru", "phone": "+70647976002"}
0005432433709	1AAB5B	2151 516815	RUSLAN KUZMIN	{"phone": "+70067364909"}
0005432433710	1AAB5B	7076 835655	MARIYA GAVRILOVA	{"email": "mariya.gavrilova_121973@postgrespro.ru", "phone": "+70349400466"}
0005432433711	A71CAA	1625 899541	ALEKSEY TARASOV	{"email": "tarasova.071966@postgrespro.ru", "phone": "+70969821828"}
0005432433712	A71CAA	7209 457794	KRISTINA SIDOROVA	{"email": "kristinasidorova-041981@postgrespro.ru", "phone": "+70977370021"}
0005432433713	7C5FBC	2557 897916	VALERIY YAKOVLEV	{"email": "yakovlevvaleriy24051971@postgrespro.ru", "phone": "+70823419464"}
0005432433714	91E640	4293 007036	ANDREY CHERNOV	{"email": "chernova.01121968@postgrespro.ru", "phone": "+70317056347"}
0005432433715	3CC6B9	3438 537253	NADEZHDA ILINA	{"email": "n.ilina-071974@postgrespro.ru", "phone": "+70716868852"}
0005432433716	A01529	6555 770040	VALENTIN KUZNECOV	{"email": "v_kuznecov1972@postgrespro.ru", "phone": "+70344232243"}
0005432433717	08B4AD	5617 441310	MARINA KONDRATEVA	{"email": "m.kondrateva-1980@postgrespro.ru", "phone": "+70806824747"}
0005432433718	08B4AD	5226 041392	YULIYA SMIRNOVA	{"phone": "+70610400445"}
0005432433719	E5D08D	3251 326750	DARYA YAKOVLEVA	{"email": "yakovlevad1975@postgrespro.ru", "phone": "+70642741876"}
0005432433720	110902	4608 768195	DARYA PAVLOVA	{"email": "darya_pavlova.18111993@postgrespro.ru", "phone": "+70720087547"}
0005432433721	37362E	9536 764001	ANATOLIY SMIRNOV	{"email": "smirnov.anatoliy.1967@postgrespro.ru", "phone": "+70430354884"}
0005432433722	1D9573	1897 088204	YURIY MATVEEV	{"phone": "+70621922786"}
0005432433723	4ACBE9	8704 193301	TAMARA DAVYDOVA	{"phone": "+70512007461"}
0005432433724	452669	0171 049924	ALEKSANDRA KUZNECOVA	{"email": "aleksandra-kuznecova-1972@postgrespro.ru", "phone": "+70934797085"}
0005432433725	CF1ECE	4273 217696	GENNADIY TIMOFEEV	{"email": "timofeevg.021970@postgrespro.ru", "phone": "+70139811946"}
0005432433726	7F8C4A	4308 025420	EKATERINA KUZNECOVA	{"email": "ekaterina.kuznecova1971@postgrespro.ru", "phone": "+70004408938"}
0005432433727	2A2F67	5503 863951	LIDIYA CHERNOVA	{"email": "lidiya_chernova-061975@postgrespro.ru", "phone": "+70434501022"}
0005432433728	FDFD1A	3279 612592	ANASTASIYA MAKAROVA	{"email": "makarova_anastasiya-111969@postgrespro.ru", "phone": "+70184042907"}
0005432433729	9EEE49	6771 210586	ELENA KARPOVA	{"phone": "+70663267442"}
0005432433730	9EEE49	6810 739471	VLADIMIR MAKSIMOV	{"email": "maksimov_v-06051963@postgrespro.ru", "phone": "+70500684886"}
0005432433731	229D4F	7624 007662	SVETLANA PAVLOVA	{"email": "pavlova.s14111982@postgrespro.ru", "phone": "+70911828929"}
0005432433732	229D4F	8001 288731	NIKITA SCHERBAKOV	{"phone": "+70828841841"}
0005432433733	9EF8D9	1515 914883	DARYA FILIPPOVA	{"email": "filippova_darya.091963@postgrespro.ru", "phone": "+70064326021"}
0005432433734	27E1A2	9496 100514	ELENA KULIKOVA	{"phone": "+70348055906"}
0005432433735	27E1A2	7564 219476	VALERIY KUZMIN	{"phone": "+70788270020"}
0005432433736	27E1A2	3485 853393	ALEKSEY MARTYNOV	{"email": "martynov_a03121974@postgrespro.ru", "phone": "+70955279147"}
0005432433737	67D6C9	3031 599286	ALEKSEY KUZNECOV	{"phone": "+70902278446"}
0005432433738	C798E8	1422 390865	NATALYA GORBUNOVA	{"email": "n-gorbunova.111979@postgrespro.ru", "phone": "+70377282520"}
0005432433739	CF6AF2	0531 877425	OLGA KOROLEVA	{"phone": "+70944192162"}
0005432433740	CF6AF2	4193 307033	VYACHESLAV KRASNOV	{"email": "krasnov.v_1968@postgrespro.ru", "phone": "+70285299522"}
0005432433741	CF6AF2	7209 472410	VASILIY GAVRILOV	{"phone": "+70244620351"}
0005432433742	57FD70	4756 989238	VADIM MAKSIMOV	{"phone": "+70064122245"}
0005432433743	57FD70	2589 631727	VIKTORIYA CHERNOVA	{"phone": "+70570467492"}
0005432433744	450E7D	1044 654051	KONSTANTIN STEPANOV	{"email": "konstantinstepanov_1978@postgrespro.ru", "phone": "+70933910120"}
0005432433745	450E7D	4881 221369	ULYANA DANILOVA	{"phone": "+70988383224"}
0005432433746	3BC62E	7376 192118	VLADIMIR PAVLOV	{"phone": "+70804373720"}
0005432433747	1B02BC	9129 361282	EGOR FILIPPOV	{"email": "egorfilippov.1974@postgrespro.ru", "phone": "+70139869575"}
0005432433748	6429FC	4780 863383	MIKHAIL KUZMIN	{"email": "mikhail-kuzmin.12041973@postgrespro.ru", "phone": "+70051121790"}
0005432433749	20C7E1	3755 497153	DANIIL OSIPOV	{"email": "osipov_daniil-1974@postgrespro.ru", "phone": "+70913657999"}
0005432433750	291230	8864 180268	DARINA KONDRATEVA	{"phone": "+70264993060"}
0005432433751	D4D55F	9442 851738	YURIY NAZAROV	{"email": "nazarov-y_1980@postgrespro.ru", "phone": "+70295965984"}
0005432433752	7FC473	8995 684647	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir-1975@postgrespro.ru", "phone": "+70520944518"}
0005432433753	E92765	0495 073255	SERGEY SAVELEV	{"phone": "+70378084364"}
0005432433754	565F4C	5727 738306	DANILA PAVLOV	{"email": "d_pavlov.1967@postgrespro.ru", "phone": "+70809154814"}
0005432433755	565F4C	3293 442637	VIKTORIYA GORBUNOVA	{"email": "vgorbunova-1967@postgrespro.ru", "phone": "+70666310718"}
0005432433756	565F4C	3944 417454	LYUBOV DAVYDOVA	{"email": "lyubov.davydova-20021966@postgrespro.ru", "phone": "+70841636292"}
0005432433757	7836D0	5782 391198	SVETLANA KUDRYASHOVA	{"email": "svetlana.kudryashova_1978@postgrespro.ru", "phone": "+70890226063"}
0005432433758	212308	5736 588132	MURAD KOROLEV	{"phone": "+70683948018"}
0005432433759	212308	6977 520585	ANNA KARPOVA	{"phone": "+70257914949"}
0005432433760	A6F795	5026 183541	IVAN PAVLOV	{"email": "pavlov_ivan_061967@postgrespro.ru", "phone": "+70058058244"}
0005432433761	32AF20	5892 538981	KLAVDIYA FILIPPOVA	{"email": "k-filippova_1968@postgrespro.ru", "phone": "+70337889337"}
0005432433762	32AF20	5660 042147	BORIS SEMENOV	{"email": "semenovboris_1963@postgrespro.ru", "phone": "+70531554901"}
0005432433763	32AF20	5323 817672	SERGEY NIKOLAEV	{"email": "nikolaev.s121974@postgrespro.ru", "phone": "+70221838249"}
0005432433764	5307EE	7985 825003	LYUDMILA MIKHAYLOVA	{"phone": "+70251041303"}
0005432433765	3EC0A3	7798 892210	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov.1958@postgrespro.ru", "phone": "+70145136153"}
0005432433766	6769F9	1027 705542	NATALYA ZAKHAROVA	{"email": "nzakharova-10021978@postgrespro.ru", "phone": "+70604130244"}
0005432433767	C74D56	2049 409530	TATYANA SOLOVEVA	{"email": "tatyanasoloveva091969@postgrespro.ru", "phone": "+70987069872"}
0005432433768	C74D56	4392 301077	NIKOLAY ANDREEV	{"email": "n.andreev.1978@postgrespro.ru", "phone": "+70087527978"}
0005432433769	4465D0	1192 088619	VADIM ANTONOV	{"email": "antonov.v.1974@postgrespro.ru", "phone": "+70881102142"}
0005432433770	9441D4	0564 380991	NATALYA GERASIMOVA	{"email": "gerasimova_n.08101966@postgrespro.ru", "phone": "+70948734439"}
0005432433771	36A0CA	0932 646626	IRINA IVANOVA	{"phone": "+70525317454"}
0005432433772	F7C132	5333 884081	SERGEY PETROV	{"email": "petrov.s021975@postgrespro.ru", "phone": "+70679214151"}
0005432433773	9264BE	3136 661997	ANDREY BELOV	{"phone": "+70545838662"}
0005432433774	AE3B02	8685 984567	ANATOLIY ZAKHAROV	{"email": "anatoliy_zakharov-01091976@postgrespro.ru", "phone": "+70380027958"}
0005432433775	82E517	6425 456209	MILENA KOMAROVA	{"phone": "+70577756551"}
0005432433776	82E517	8544 933335	IVAN BORISOV	{"phone": "+70167086813"}
0005432433777	052DF6	9626 656181	LYUDMILA GERASIMOVA	{"phone": "+70913072559"}
0005432433778	C82D2C	8976 362027	SERGEY BONDARENKO	{"email": "sergeybondarenko_15011974@postgrespro.ru", "phone": "+70714553303"}
0005432433779	C82D2C	6094 780980	MIKHAIL MAKSIMOV	{"email": "m-maksimov_14071973@postgrespro.ru", "phone": "+70671244941"}
0005432433780	CE1A70	7148 474564	TAMARA ALEKSANDROVA	{"email": "taleksandrova_20021962@postgrespro.ru", "phone": "+70570065470"}
0005432433781	CE1A70	6791 175224	TAMARA SIDOROVA	{"phone": "+70569622059"}
0005432433782	CE1A70	3423 252314	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov_1962@postgrespro.ru", "phone": "+70799329208"}
0005432433783	15F156	6047 218610	NADEZHDA DAVYDOVA	{"email": "ndavydova.091969@postgrespro.ru", "phone": "+70941254882"}
0005432433784	2B3C31	4872 349356	LYUDMILA SIDOROVA	{"email": "sidorova-l_011977@postgrespro.ru", "phone": "+70003530636"}
0005432433785	2B3C31	0783 299953	NATALYA KUZNECOVA	{"email": "kuznecova-n_17111976@postgrespro.ru", "phone": "+70697130098"}
0005432433786	8A2176	8787 540355	SVETLANA NAZAROVA	{"phone": "+70057289430"}
0005432433787	59EA36	7101 508569	ELENA NESTEROVA	{"phone": "+70296571401"}
0005432433788	24E613	9630 785939	VALENTINA ANTONOVA	{"phone": "+70062277828"}
0005432433789	43765D	9124 459029	VALENTINA NESTEROVA	{"phone": "+70588125724"}
0005432433790	DFB351	8262 944397	VLADIMIR KULIKOV	{"phone": "+70514919680"}
0005432433791	DFB351	2630 517118	TATYANA MOISEEVA	{"phone": "+70754001409"}
0005432433792	53BA45	2831 506963	VERA NIKITINA	{"email": "nikitina_v_031979@postgrespro.ru", "phone": "+70482455550"}
0005432433793	655555	7449 940987	GENNADIY PAVLOV	{"phone": "+70737117047"}
0005432433794	69951D	3497 998763	ALEKSEY MOISEEV	{"phone": "+70312246993"}
0005432433795	558AF8	9037 693980	SVETLANA SAVELEVA	{"phone": "+70043294486"}
0005432433796	F951AA	3015 105453	VITALIY MIKHAYLOV	{"phone": "+70369563903"}
0005432433797	B2D225	2038 498625	VALENTINA IVANOVA	{"phone": "+70140734439"}
0005432433798	B2D225	8707 026688	ALEKSEY MATVEEV	{"email": "amatveev-071966@postgrespro.ru", "phone": "+70126047547"}
0005432433799	E64416	6652 276564	VERA PETROVA	{"email": "v-petrova.1974@postgrespro.ru", "phone": "+70293996608"}
0005432433800	968CA3	4706 577064	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr_07121967@postgrespro.ru", "phone": "+70700640980"}
0005432433801	968CA3	2342 368520	NIKOLAY ZAKHAROV	{"phone": "+70709572682"}
0005432433802	8B47A6	0829 639594	SERGEY POPOV	{"phone": "+70119710277"}
0005432433803	9880D9	2462 404118	MATVEY ZHUKOV	{"phone": "+70747354359"}
0005432433804	619B41	2713 199485	GALINA PETROVA	{"email": "galina.petrova-091981@postgrespro.ru", "phone": "+70968515586"}
0005432433805	E2632E	7480 932301	OLEG ILIN	{"email": "ilin.oleg-1969@postgrespro.ru", "phone": "+70003172063"}
0005432433806	C438DC	3565 455928	NINA TARASOVA	{"email": "ntarasova_1980@postgrespro.ru", "phone": "+70184389476"}
0005432433807	C438DC	1811 932892	OLGA RODIONOVA	{"phone": "+70555870151"}
0005432433808	F49B64	9875 943427	ALEKSANDR SIDOROV	{"phone": "+70432231215"}
0005432433809	79D614	7460 829095	MARAT GORBUNOV	{"phone": "+70696171122"}
0005432433810	79D614	7656 862702	OLGA NESTEROVA	{"email": "o_nesterova111967@postgrespro.ru", "phone": "+70684231251"}
0005432433811	5E57C7	4440 157747	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko.1967@postgrespro.ru", "phone": "+70293335566"}
0005432433812	AE6765	4117 968899	GALINA IVANOVA	{"phone": "+70203229823"}
0005432433813	25062E	1430 457398	VLADISLAV KUZNECOV	{"email": "kuznecov-v04091979@postgrespro.ru", "phone": "+70570926918"}
0005432433814	0B662D	5975 052966	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov051973@postgrespro.ru", "phone": "+70064745958"}
0005432433815	0B662D	0421 498133	NATALYA ZAYCEVA	{"email": "n_zayceva-22101967@postgrespro.ru", "phone": "+70499125877"}
0005432433816	3C8894	3927 864296	LYUBOV POPOVA	{"email": "popoval.27041971@postgrespro.ru", "phone": "+70264080023"}
0005432433817	144503	2263 531825	ANDREY KULIKOV	{"phone": "+70480622657"}
0005432433818	C2B56F	4966 265759	LYUBOV ERMAKOVA	{"email": "ermakova-l011966@postgrespro.ru", "phone": "+70957537112"}
0005432433819	3801F6	1395 977559	ELENA SOROKINA	{"email": "esorokina.17051986@postgrespro.ru", "phone": "+70070503258"}
0005432433820	E4E71B	2164 849712	GALINA DMITRIEVA	{"phone": "+70355838984"}
0005432433821	507844	9498 960589	OLGA OVCHINNIKOVA	{"phone": "+70777856463"}
0005432433822	46D74D	4780 018789	ALEKSEY NAUMOV	{"phone": "+70341380677"}
0005432433823	005D5D	4683 602933	VLADIMIR PETROV	{"email": "vladimir-petrov_02051974@postgrespro.ru", "phone": "+70381547456"}
0005432433824	97E666	5205 483825	RAISA ZAKHAROVA	{"email": "raisa-zakharova_1963@postgrespro.ru", "phone": "+70479275129"}
0005432433825	AB7D67	3895 399805	NADEZHDA KOZLOVA	{"email": "kozlova.nadezhda-21011965@postgrespro.ru", "phone": "+70398970975"}
0005432433826	BE1654	6911 656636	OLGA ANDREEVA	{"phone": "+70133071436"}
0005432433827	EC1043	2225 978442	ILYA EGOROV	{"phone": "+70194323880"}
0005432433828	EC1043	6444 280884	ALEKSANDR GAVRILOV	{"phone": "+70719057776"}
0005432433829	FD84A0	6965 313983	NATALYA MOROZOVA	{"phone": "+70995767273"}
0005432433830	795615	2759 781473	VLADIMIR MAKSIMOV	{"phone": "+70959624467"}
0005432433831	795615	8110 311354	LIDIYA PETROVA	{"phone": "+70660349848"}
0005432433832	E468E2	6718 482019	STANISLAV KAZAKOV	{"phone": "+70157925855"}
0005432433833	B827EE	7385 523120	ANGELINA KUZNECOVA	{"email": "kuznecova-angelina051974@postgrespro.ru", "phone": "+70443510781"}
0005432433834	F6C7C7	1205 197957	SVETLANA KONDRATEVA	{"email": "s_kondrateva04121970@postgrespro.ru", "phone": "+70842839036"}
0005432433835	F6C7C7	0945 068538	SERGEY SERGEEV	{"phone": "+70076174388"}
0005432433836	AA44B5	3942 962775	GALINA FROLOVA	{"email": "g.frolova031961@postgrespro.ru", "phone": "+70485595630"}
0005432433837	F5FD97	2346 240393	ALEKSANDR RODIONOV	{"phone": "+70518281278"}
0005432433838	F5FD97	7642 707360	ELENA VOROBEVA	{"phone": "+70689351010"}
0005432433839	22912E	9548 955401	ELENA TIMOFEEVA	{"email": "timofeeva-elena_09101973@postgrespro.ru", "phone": "+70403074248"}
0005432433840	22912E	3447 280981	ANATOLIY NAZAROV	{"phone": "+70897093182"}
0005432433841	7817FC	4282 447259	OLGA DENISOVA	{"phone": "+70299923135"}
0005432433842	7817FC	1840 144660	MARIYA KOROLEVA	{"email": "mariya.koroleva-15091959@postgrespro.ru", "phone": "+70298816322"}
0005432459061	B8F11A	3440 217896	ANDREY SEMENOV	{"phone": "+70340258619"}
0005432458956	17CE31	6190 312246	ALEKSANDRA BELYAEVA	{"phone": "+70083891746"}
0005432458957	66F220	0149 005437	RAISA KUDRYASHOVA	{"email": "raisa_kudryashova.111967@postgrespro.ru", "phone": "+70461098953"}
0005432458958	66F220	6326 146395	ULYANA DENISOVA	{"email": "ulyana-denisova061970@postgrespro.ru", "phone": "+70751456747"}
0005432458959	66F220	4715 684046	OLGA MOISEEVA	{"email": "moiseevao_12041971@postgrespro.ru", "phone": "+70632725565"}
0005432458960	500704	8804 275173	EVGENIY MAKAROV	{"email": "e_makarov13091980@postgrespro.ru", "phone": "+70865281641"}
0005432458961	789D50	4682 815910	GRIGORIY SAVELEV	{"email": "g-savelev.1970@postgrespro.ru", "phone": "+70347226237"}
0005432458962	CCD636	5694 114183	IRINA LOGINOVA	{"email": "loginova-i-071975@postgrespro.ru", "phone": "+70235358142"}
0005432458963	675E61	6470 158892	ELENA POPOVA	{"phone": "+70692298342"}
0005432458964	2323B7	0342 031696	ALEKSANDR MELNIKOV	{"phone": "+70914332080"}
0005432458965	EFF298	3136 066269	NIKITA PAVLOV	{"phone": "+70180436655"}
0005432458966	C72E75	1593 486482	IRINA DANILOVA	{"phone": "+70168662690"}
0005432458967	EE05F3	1195 664783	RAMIL BARANOV	{"phone": "+70420819479"}
0005432458968	EE05F3	7651 535496	MIKHAIL MOROZOV	{"phone": "+70567562932"}
0005432458969	26ACF0	8886 225394	ALEKSEY KRASNOV	{"phone": "+70057757863"}
0005432458970	26ACF0	8633 499163	OLGA FOMINA	{"phone": "+70053666076"}
0005432458971	04F564	9398 294799	ALEKSANDR MARTYNOV	{"email": "aleksandr-martynov.16041978@postgrespro.ru", "phone": "+70891168582"}
0005432458972	04F564	1934 575037	NINA SAVELEVA	{"email": "nsaveleva_011976@postgrespro.ru", "phone": "+70238898283"}
0005432458973	0A2A00	6425 888518	ALEKSEY TIKHONOV	{"email": "tikhonovaleksey-1983@postgrespro.ru", "phone": "+70956569798"}
0005432458974	8B8853	9152 608157	GALINA ERMAKOVA	{"phone": "+70418687306"}
0005432458975	A5F3DF	2496 586451	VYACHESLAV EGOROV	{"email": "egorov-vyacheslav.021982@postgrespro.ru", "phone": "+70750082366"}
0005432458976	4D5806	7388 916321	DENIS ISAEV	{"phone": "+70846771499"}
0005432458977	4D5806	1074 505042	IRINA KUZNECOVA	{"phone": "+70625412347"}
0005432458978	D33F26	9882 808354	ANDREY NIKOLAEV	{"email": "nikolaev_a.011969@postgrespro.ru", "phone": "+70389643127"}
0005432458979	0E16F6	0873 779228	OLEG OSIPOV	{"email": "olegosipov041965@postgrespro.ru", "phone": "+70845176522"}
0005432458980	5711EC	8801 674996	VLADIMIR POPOV	{"phone": "+70681257741"}
0005432458981	53100F	6875 365372	ALEKSANDRA SAVELEVA	{"email": "saveleva.aleksandra-031975@postgrespro.ru", "phone": "+70957819235"}
0005432458982	D281AD	6377 808047	GEORGIY PETROV	{"email": "g_petrov121976@postgrespro.ru", "phone": "+70890140082"}
0005432458983	501863	4327 015687	BORIS STEPANOV	{"phone": "+70320565386"}
0005432458984	878806	5579 514519	MIKHAIL SERGEEV	{"email": "sergeev.mikhail_28061980@postgrespro.ru", "phone": "+70957437232"}
0005432458985	878806	9279 540308	ALEKSANDR NOVIKOV	{"email": "aleksandrnovikov-09111980@postgrespro.ru", "phone": "+70566947198"}
0005432458986	B24944	2660 229611	POLINA NAZAROVA	{"email": "pnazarova.1973@postgrespro.ru", "phone": "+70671028875"}
0005432458987	077975	0569 100144	KONSTANTIN MIRONOV	{"email": "mironov_k1968@postgrespro.ru", "phone": "+70177031346"}
0005432458988	40A801	2227 545259	BORIS BONDARENKO	{"email": "boris.bondarenko.091978@postgrespro.ru", "phone": "+70277727382"}
0005432458989	E0818C	3473 191897	LYUBOV RODIONOVA	{"email": "lyubov.rodionova111978@postgrespro.ru", "phone": "+70944206280"}
0005432458990	E0818C	8592 992421	VERA NESTEROVA	{"phone": "+70129288970"}
0005432458991	3C293C	2895 263721	YULIYA FOMINA	{"email": "y_fomina_1974@postgrespro.ru", "phone": "+70846342606"}
0005432458992	3353F2	6598 805348	RAISA DAVYDOVA	{"email": "rdavydova_1968@postgrespro.ru", "phone": "+70519517761"}
0005432458993	BC3611	0286 652243	ALINA GUSEVA	{"phone": "+70369794527"}
0005432458994	94137D	9415 490254	PAVEL NIKOLAEV	{"phone": "+70007376810"}
0005432458995	E67077	6813 919741	POLINA IVANOVA	{"phone": "+70993225313"}
0005432458996	E67077	1166 140074	TATYANA FOMINA	{"email": "fomina_t-011970@postgrespro.ru", "phone": "+70120899750"}
0005432458997	BCA916	1632 009537	MIKHAIL FOMIN	{"phone": "+70323689436"}
0005432458998	B0D4F4	3262 660594	VALERIY GERASIMOV	{"email": "valeriy_gerasimov-1980@postgrespro.ru", "phone": "+70577129264"}
0005432458999	EC46FA	7528 478790	VALENTINA MAKAROVA	{"email": "valentinamakarova-1973@postgrespro.ru", "phone": "+70832212680"}
0005432459000	ACAD46	4663 432414	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a_14081965@postgrespro.ru", "phone": "+70105346555"}
0005432459001	ACAD46	8859 066286	VALENTINA STEPANOVA	{"phone": "+70315723692"}
0005432459002	ACAD46	4818 561858	ANDREY RODIONOV	{"email": "rodionov.a_071973@postgrespro.ru", "phone": "+70669455138"}
0005432459003	8F9B49	4238 669147	VIKTOR ZAYCEV	{"phone": "+70240515295"}
0005432459004	916542	6363 480927	KLAVDIYA TIMOFEEVA	{"email": "timofeeva_klavdiya.1964@postgrespro.ru", "phone": "+70910721137"}
0005432459119	810FD0	9203 079645	ANDREY PETROV	{"phone": "+70606891655"}
0005432459005	916542	4057 608318	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova.1967@postgrespro.ru", "phone": "+70511649050"}
0005432459006	499724	8299 293877	ANASTASIYA SAVELEVA	{"phone": "+70310391299"}
0005432459007	73DFFC	9724 975694	STEPAN CHERNOV	{"phone": "+70351510245"}
0005432459008	73DFFC	3151 975405	TAMARA LUKYANOVA	{"phone": "+70864812650"}
0005432459009	B8D47F	8215 082113	ALLA NAZAROVA	{"email": "nazarova_alla_1977@postgrespro.ru", "phone": "+70179240818"}
0005432459010	F49446	0381 722251	ANDREY BORISOV	{"email": "andrey.borisov021989@postgrespro.ru", "phone": "+70447176291"}
0005432459011	F49446	5988 163719	VERA YAKOVLEVA	{"phone": "+70261243848"}
0005432459012	B80035	4829 329907	VLADIMIR POPOV	{"phone": "+70675584004"}
0005432459013	19D30C	9000 290431	VYACHESLAV KUZMIN	{"email": "vkuzmin.24071976@postgrespro.ru", "phone": "+70048674291"}
0005432459014	3006F3	3124 249167	VALENTINA NAZAROVA	{"email": "nazarovav.04011970@postgrespro.ru", "phone": "+70347275431"}
0005432459015	72B92C	7713 722800	IRINA PETROVA	{"email": "irina_petrova_021973@postgrespro.ru", "phone": "+70826969705"}
0005432459016	72B92C	8916 930380	LYUDMILA KOLESNIKOVA	{"email": "lyudmila_kolesnikova04081966@postgrespro.ru", "phone": "+70619004463"}
0005432459017	67E37F	4678 944694	TATYANA VOLKOVA	{"phone": "+70177731340"}
0005432459018	AFA7D8	1463 286525	ALBINA KUZMINA	{"email": "albinakuzmina.1966@postgrespro.ru", "phone": "+70195721124"}
0005432459019	02B990	6393 579102	RINAT SIDOROV	{"email": "r_sidorov.111979@postgrespro.ru", "phone": "+70308724566"}
0005432459020	02B990	9750 919590	LYUDMILA KULIKOVA	{"email": "l-kulikova-1964@postgrespro.ru", "phone": "+70777509615"}
0005432459021	C3265D	4940 054052	VITALIY BARANOV	{"email": "vbaranov-01081981@postgrespro.ru", "phone": "+70300570981"}
0005432459022	C3265D	1844 729848	RUSTAM BARANOV	{"email": "baranovrustam_1968@postgrespro.ru", "phone": "+70490896317"}
0005432459023	B85F28	2993 922266	GALINA RODIONOVA	{"email": "grodionova-1971@postgrespro.ru", "phone": "+70261113726"}
0005432459024	0B1AC7	6673 141835	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya.1976@postgrespro.ru", "phone": "+70115649082"}
0005432459025	1456DB	8745 663913	LYUBOV KUZNECOVA	{"email": "kuznecova.l.101983@postgrespro.ru", "phone": "+70186598020"}
0005432459026	F85FF0	7829 972205	ALEKSANDR STEPANOV	{"phone": "+70096102902"}
0005432459027	F85FF0	6194 878883	ELENA KUZNECOVA	{"phone": "+70800198983"}
0005432459028	5DBE86	5759 318406	NADEZHDA FROLOVA	{"phone": "+70759880230"}
0005432459029	F33EAF	8772 453316	DARYA ZHUKOVA	{"phone": "+70673510160"}
0005432459030	F33EAF	1111 344415	NIKOLAY ORLOV	{"email": "n-orlov.081956@postgrespro.ru", "phone": "+70724847626"}
0005432459031	48527D	9245 877852	VALENTINA SOKOLOVA	{"email": "valentina.sokolova-1975@postgrespro.ru", "phone": "+70844478946"}
0005432459032	F66973	5453 390358	ZINAIDA MASLOVA	{"email": "zinaida-maslova_1970@postgrespro.ru", "phone": "+70278916068"}
0005432459033	F66973	6482 220912	SERGEY GERASIMOV	{"email": "gerasimov-sergey.1978@postgrespro.ru", "phone": "+70297134877"}
0005432459034	EBBAD9	8431 472692	OLEG KUZNECOV	{"phone": "+70926083100"}
0005432459035	C6BF38	6106 392183	VYACHESLAV NIKOLAEV	{"phone": "+70199897610"}
0005432459036	D96E5E	7993 400561	ALEKSANDR DMITRIEV	{"phone": "+70910550052"}
0005432459037	D96E5E	6673 132086	EVGENIY SAVELEV	{"phone": "+70133790632"}
0005432459038	ADDFC0	2963 046079	VLADIMIR KRASNOV	{"phone": "+70439545373"}
0005432459039	8CB5EB	3406 578994	SOFYA VLASOVA	{"phone": "+70770089614"}
0005432459040	8CB5EB	0782 538881	MATVEY MOROZOV	{"phone": "+70871952625"}
0005432459041	DD4510	3051 942982	LARISA KOROLEVA	{"email": "koroleva_larisa-1980@postgrespro.ru", "phone": "+70646615539"}
0005432459042	DD4510	5609 710348	ALEKSEY DMITRIEV	{"email": "dmitriev.aleksey121965@postgrespro.ru", "phone": "+70032409704"}
0005432459043	2082C1	7625 364480	ANTON RODIONOV	{"phone": "+70058119645"}
0005432459044	626500	8740 519431	LYUDMILA RYABOVA	{"email": "l-ryabova.18091976@postgrespro.ru", "phone": "+70899115725"}
0005432459045	626500	3060 674574	NIKOLAY YAKOVLEV	{"email": "yakovlev.nikolay.051983@postgrespro.ru", "phone": "+70964830959"}
0005432459046	B5E5DA	0994 044217	EKATERINA MARTYNOVA	{"phone": "+70173912731"}
0005432459047	7C51DA	2414 572068	LYUDMILA NAUMOVA	{"email": "l.naumova_28121964@postgrespro.ru", "phone": "+70727315850"}
0005432459048	D829E0	1951 159526	ALEKSANDR NOVIKOV	{"phone": "+70041966482"}
0005432459049	23CB3A	6898 458084	EKATERINA KONOVALOVA	{"phone": "+70991976649"}
0005432459050	23CB3A	2950 762848	FEDOR SEMENOV	{"phone": "+70897525782"}
0005432459051	6793B2	4615 867654	NINA ZHUKOVA	{"phone": "+70674987909"}
0005432459052	1C8DE9	9308 051713	ARTEM ANDREEV	{"email": "artemandreev_05111978@postgrespro.ru", "phone": "+70362322411"}
0005432459053	8F7A09	1387 571054	ALEKSANDR VASILEV	{"phone": "+70454350158"}
0005432459054	121A26	3618 034113	OLGA POTAPOVA	{"phone": "+70040192967"}
0005432459055	121A26	3378 054987	VASILISA ILINA	{"email": "vasilisa_ilina1974@postgrespro.ru", "phone": "+70177262621"}
0005432459056	C0099F	2992 326669	VLADA MASLOVA	{"phone": "+70934176092"}
0005432459057	C0099F	8028 048573	NATALYA TIKHONOVA	{"phone": "+70558672906"}
0005432459058	699BEE	9706 567492	ANDREY GORBUNOV	{"email": "gorbunov-a-081976@postgrespro.ru", "phone": "+70548965085"}
0005432459059	699BEE	2736 459277	VLADIMIR POPOV	{"phone": "+70151773987"}
0005432459060	B8F11A	2953 329427	YURIY KARPOV	{"email": "y-karpov.1959@postgrespro.ru", "phone": "+70717340146"}
0005432459062	B282A6	8528 736899	VIKTOR ZAKHAROV	{"email": "zakharovviktor_051973@postgrespro.ru", "phone": "+70911989581"}
0005432459063	DA9E21	4775 984345	ALEKSANDR TIKHONOV	{"phone": "+70091041526"}
0005432459064	AA5075	9208 451231	ANDREY ALEKSEEV	{"phone": "+70488362535"}
0005432459065	AA5075	5550 652412	DMITRIY ZHUKOV	{"email": "d-zhukov091979@postgrespro.ru", "phone": "+70235279257"}
0005432459066	48F343	3942 803881	LYUBOV MALYSHEVA	{"phone": "+70116048178"}
0005432459067	977732	1768 752149	VALENTIN KUZNECOV	{"email": "kuznecov.valentin.1975@postgrespro.ru", "phone": "+70222153168"}
0005432459068	977732	1388 874384	VLADISLAV FEDOTOV	{"phone": "+70262345926"}
0005432459069	E5FCE9	4903 046234	VITALIY RODIONOV	{"phone": "+70439637667"}
0005432459070	46D4D3	5179 158450	MARIYA KONDRATEVA	{"phone": "+70054372857"}
0005432459071	91B48C	6476 389718	NINA KAZAKOVA	{"phone": "+70257319046"}
0005432459072	85EB98	5238 270331	SERGEY SERGEEV	{"email": "sergeev-s_081960@postgrespro.ru", "phone": "+70782755467"}
0005432459073	5B0276	3411 632312	KIRILL ORLOV	{"email": "orlov-kirill-16101967@postgrespro.ru", "phone": "+70406829552"}
0005432459074	ACB4F8	7995 689345	ANTON ZAYCEV	{"phone": "+70169404280"}
0005432459075	FCAF92	1034 968483	ALEKSEY ISAEV	{"phone": "+70223283834"}
0005432459076	DAC2EB	8885 166598	ANNA EFREMOVA	{"email": "efremovaa021975@postgrespro.ru", "phone": "+70282953658"}
0005432459077	29F560	9058 873905	ALEKSEY FEDOROV	{"phone": "+70968205105"}
0005432459078	2ECE2A	4372 467690	VLADISLAV SCHERBAKOV	{"email": "vladislavscherbakov1977@postgrespro.ru", "phone": "+70323748470"}
0005432459079	08AADB	1918 135172	PAVEL KONOVALOV	{"phone": "+70381840331"}
0005432459080	15FD32	0663 100234	ALEKSEY IVANOV	{"email": "aleksey.ivanov_03121965@postgrespro.ru", "phone": "+70237908100"}
0005432459081	15FD32	6608 093906	LYUDMILA KONOVALOVA	{"phone": "+70831460623"}
0005432459082	131E80	8186 733087	ALEKSEY RODIONOV	{"email": "rodionova.12061982@postgrespro.ru", "phone": "+70764318389"}
0005432459083	970ACD	6401 849623	INNA BOGDANOVA	{"email": "bogdanova_i.18061984@postgrespro.ru", "phone": "+70507338021"}
0005432459084	5CDE7D	1433 351821	ZINAIDA TIKHONOVA	{"phone": "+70689814648"}
0005432459085	1A2057	4005 254076	OLGA GAVRILOVA	{"email": "olgagavrilova_22041975@postgrespro.ru", "phone": "+70083704227"}
0005432459086	E2D1B3	4164 933390	VALENTIN GAVRILOV	{"phone": "+70523608727"}
0005432459087	3CC6FB	8924 831968	TATYANA KONDRATEVA	{"phone": "+70511547824"}
0005432459088	0E8032	8074 295725	KRISTINA KISELEVA	{"email": "kkiseleva_091964@postgrespro.ru", "phone": "+70388693172"}
0005432459089	C5E5B7	1084 793331	KRISTINA KALININA	{"phone": "+70395390647"}
0005432459090	93C2F4	3744 409802	ILNUR SHEVCHENKO	{"email": "i.shevchenko_1968@postgrespro.ru", "phone": "+70912833796"}
0005432459091	93C2F4	9225 324344	TIMOFEY ZAKHAROV	{"phone": "+70967713519"}
0005432459092	B946A9	2113 967910	ALEKSANDR SAVELEV	{"email": "a.savelev12091989@postgrespro.ru", "phone": "+70826620182"}
0005432459093	AFBB88	8351 705798	SERGEY EGOROV	{"email": "egorov_s1979@postgrespro.ru", "phone": "+70888504626"}
0005432459094	AFBB88	6121 047321	VALERIY KUZNECOV	{"email": "kuznecov-valeriy_071968@postgrespro.ru", "phone": "+70832087181"}
0005432459095	AFBB88	6964 298561	VITALIY VASILEV	{"email": "vasilev-v.071980@postgrespro.ru", "phone": "+70461169749"}
0005432459096	8D26CE	1175 957195	IRINA PETROVA	{"phone": "+70345147470"}
0005432459097	8D26CE	3048 240237	NATALYA ABRAMOVA	{"email": "n.abramova_20071974@postgrespro.ru", "phone": "+70564159306"}
0005432459098	BC4B74	5490 726388	DAMIR FEDOTOV	{"phone": "+70330757028"}
0005432459099	9102EE	1791 935386	MARIYA ERMAKOVA	{"email": "ermakova_m1985@postgrespro.ru", "phone": "+70838696855"}
0005432459100	B45726	1801 354176	ANNA NIKOLAEVA	{"email": "a-nikolaeva1968@postgrespro.ru", "phone": "+70441094356"}
0005432459101	B45726	0176 338001	DARYA KOZLOVA	{"phone": "+70656912592"}
0005432459102	A15D1E	7053 810643	ALEKSANDRA MARTYNOVA	{"email": "a.martynova.041969@postgrespro.ru", "phone": "+70997043733"}
0005432459103	43A864	4262 941328	DMITRIY MATVEEV	{"email": "dmatveev-1988@postgrespro.ru", "phone": "+70150866233"}
0005432459104	63F752	0085 263480	ANNA GERASIMOVA	{"phone": "+70555129712"}
0005432459105	63F752	2380 454216	IRINA LOGINOVA	{"email": "i_loginova.071964@postgrespro.ru", "phone": "+70508564115"}
0005432459106	96A6B7	9186 453611	NADEZHDA VASILEVA	{"phone": "+70089301359"}
0005432459107	96A6B7	3534 600448	VITALIY GUSEV	{"phone": "+70283913152"}
0005432459108	0D9F7B	1730 918774	DMITRIY SERGEEV	{"phone": "+70370494394"}
0005432459109	0D9F7B	4287 029883	OLGA ANTONOVA	{"phone": "+70119547325"}
0005432459110	0D9F7B	8755 048895	OLGA DAVYDOVA	{"email": "o.davydova-28091972@postgrespro.ru", "phone": "+70691265482"}
0005432459111	38734F	2002 258533	LYUDMILA KUDRYASHOVA	{"phone": "+70022962578"}
0005432459112	7CA7E7	6523 951856	KLAVDIYA KULIKOVA	{"phone": "+70530056961"}
0005432459113	11D298	7895 226026	ALEKSEY KUZNECOV	{"phone": "+70145355177"}
0005432459114	11D298	0429 008152	NATALYA SAVELEVA	{"phone": "+70639708781"}
0005432459115	7A097E	9952 208948	MARIYA KONDRATEVA	{"phone": "+70192250953"}
0005432459116	B74567	9501 648772	LARISA KUZNECOVA	{"phone": "+70291647564"}
0005432459117	ED5B61	6752 538099	NADEZHDA STEPANOVA	{"phone": "+70444811582"}
0005432459118	6C55AB	9670 845624	KONSTANTIN NIKOLAEV	{"email": "knikolaev_09081972@postgrespro.ru", "phone": "+70853399381"}
0005432459120	96AD27	2256 088111	VASILIY SCHERBAKOV	{"email": "scherbakovv-13091971@postgrespro.ru", "phone": "+70263456215"}
0005432459121	62E8CB	0182 031899	DIANA VOLKOVA	{"email": "d_volkova.1970@postgrespro.ru", "phone": "+70097247591"}
0005432459122	6DDBAA	0259 528972	VALENTINA NIKITINA	{"phone": "+70300050970"}
0005432459123	A1B9C6	2539 140583	LYUBOV KRASNOVA	{"phone": "+70817210527"}
0005432459124	6C0C11	7879 625238	OLGA KUZNECOVA	{"email": "kuznecovaolga121975@postgrespro.ru", "phone": "+70908545281"}
0005432459125	6C0C11	9101 058777	YURIY PETROV	{"email": "petrov_y1963@postgrespro.ru", "phone": "+70822919813"}
0005432459126	6C0C11	9852 706904	ALEKSEY VOROBEV	{"phone": "+70798966810"}
0005432459127	D50BD4	3948 299432	ALEKSEY POPOV	{"phone": "+70413668885"}
0005432459128	D50BD4	0829 809350	EKATERINA KOLESNIKOVA	{"email": "e-kolesnikova-1976@postgrespro.ru", "phone": "+70571674038"}
0005432459129	D5EB88	3307 679524	NADEZHDA LAZAREVA	{"email": "lazareva-nadezhda_121967@postgrespro.ru", "phone": "+70882424418"}
0005432459130	D5EB88	1160 672781	VLADIMIR KRASNOV	{"email": "vladimir-krasnov101975@postgrespro.ru", "phone": "+70988575468"}
0005432459131	9EFE47	0394 897206	MARK KAZAKOV	{"phone": "+70963574400"}
0005432459132	99571D	4070 357556	ANNA NIKITINA	{"phone": "+70531422268"}
0005432459133	08BEF0	8843 757418	SERGEY MARTYNOV	{"email": "martynov_s_1975@postgrespro.ru", "phone": "+70416147311"}
0005432459134	1C4849	9740 783978	NIKOLAY KOZLOV	{"phone": "+70568037010"}
0005432459135	61FB39	0240 172244	ZHANNA NIKITINA	{"email": "z-nikitina.1972@postgrespro.ru", "phone": "+70397703310"}
0005432459136	CD3E69	9156 519370	PAVEL TIMOFEEV	{"phone": "+70549034482"}
0005432459137	CD3E69	1873 193082	IRINA VASILEVA	{"email": "vasilevai_1969@postgrespro.ru", "phone": "+70713214405"}
0005432459138	F2AB8F	9739 636380	TATYANA PAVLOVA	{"email": "t_pavlova02071969@postgrespro.ru", "phone": "+70709731723"}
0005432459139	C7276E	0014 989404	IRINA SEMENOVA	{"phone": "+70618399241"}
0005432459140	32E693	8496 387211	MAKSIM PETROV	{"phone": "+70527091909"}
0005432459141	386B23	2857 936014	ARINA KISELEVA	{"email": "kiselevaarina08111963@postgrespro.ru", "phone": "+70232259405"}
0005432459142	8E087F	0451 511976	ELENA YAKOVLEVA	{"email": "eyakovleva_031984@postgrespro.ru", "phone": "+70808185196"}
0005432459143	49375A	3486 860179	NATALYA MAKSIMOVA	{"phone": "+70137384337"}
0005432459144	E1148C	3708 939179	MAKSIM NAZAROV	{"email": "m-nazarov.1973@postgrespro.ru", "phone": "+70491421320"}
0005432459145	9F0384	4052 762937	POLINA ALEKSEEVA	{"phone": "+70313483767"}
0005432459146	E3B776	0016 031493	ELENA SERGEEVA	{"email": "sergeevaelena_1965@postgrespro.ru", "phone": "+70585642857"}
0005432459147	E3B776	0651 662944	VALENTINA SMIRNOVA	{"phone": "+70313400058"}
0005432459148	BAED30	0769 380556	ALEKSANDR SOKOLOV	{"phone": "+70815937404"}
0005432459149	BAED30	1695 068434	VIKTOR DENISOV	{"phone": "+70958008325"}
0005432459150	98A3F6	3062 550243	LYUBOV MIKHAYLOVA	{"phone": "+70804242371"}
0005432459151	98A3F6	6360 381098	TATYANA SCHERBAKOVA	{"phone": "+70780278904"}
0005432459152	98A3F6	8352 886638	NADEZHDA NIKITINA	{"email": "n.nikitina_1958@postgrespro.ru", "phone": "+70144717662"}
0005432459153	ED1C45	0971 547911	KONSTANTIN KULIKOV	{"email": "kulikov-k_1968@postgrespro.ru", "phone": "+70524015519"}
0005432459154	ED1C45	7086 334990	PAVEL ZAKHAROV	{"email": "zakharov_pavel.1970@postgrespro.ru", "phone": "+70251252141"}
0005432459155	D17F83	4711 172985	VLADIMIR KARPOV	{"email": "v.karpov101979@postgrespro.ru", "phone": "+70072995074"}
0005432459156	D17F83	6498 456371	NIKOLAY ZAYCEV	{"phone": "+70748938037"}
0005432459157	D17F83	0256 726549	NIKOLAY GAVRILOV	{"phone": "+70654161162"}
0005432459158	2E7FA9	3257 565868	VLADISLAV MOROZOV	{"email": "morozov.vladislav.1984@postgrespro.ru", "phone": "+70317042692"}
0005432459159	BEE49D	7097 945674	OLEG SMIRNOV	{"email": "smirnov-o_1982@postgrespro.ru", "phone": "+70213392761"}
0005432459160	BEE49D	4460 750967	LARISA MAKAROVA	{"phone": "+70185590739"}
0005432459161	E95EF8	6331 134688	IGOR TIMOFEEV	{"email": "igor_timofeev-071968@postgrespro.ru", "phone": "+70722790133"}
0005432459162	7ECAA2	9420 605662	ELENA IVANOVA	{"phone": "+70408615118"}
0005432459163	D51281	8684 760484	TATYANA LUKYANOVA	{"phone": "+70480265137"}
0005432459164	D51281	1124 865046	VALENTIN FROLOV	{"email": "frolovvalentin03111979@postgrespro.ru", "phone": "+70638339248"}
0005432459165	65AAFC	3072 869838	ILYA ZAKHAROV	{"phone": "+70843401500"}
0005432459166	65AAFC	3121 096876	DARYA NIKITINA	{"email": "nikitina_darya.03011988@postgrespro.ru", "phone": "+70268833472"}
0005432459167	3A6F87	8088 108185	LYUBOV KUZMINA	{"email": "kuzmina-l_25101980@postgrespro.ru", "phone": "+70955664349"}
0005432459168	AE9A81	8100 261363	ALEKSEY IVANOV	{"email": "aleksey.ivanov1976@postgrespro.ru", "phone": "+70406567045"}
0005432459169	9EE7FB	2894 306401	GENNADIY VOLKOV	{"email": "g_volkov.091969@postgrespro.ru", "phone": "+70491777638"}
0005432459170	9EE7FB	8807 374410	VLADIMIR AFANASEV	{"email": "v.afanasev-1967@postgrespro.ru", "phone": "+70562153086"}
0005432459171	29453D	8341 394313	NATALIYA SERGEEVA	{"email": "sergeevanataliya1971@postgrespro.ru", "phone": "+70106576615"}
0005432459172	2C3E17	8515 399813	RAFIK CHERNOV	{"email": "r.chernov-05081962@postgrespro.ru", "phone": "+70929043180"}
0005432459173	E2E8EB	5370 821257	ELMIRA LUKYANOVA	{"phone": "+70858747655"}
0005432459174	437C56	1611 314690	NIKOLAY VLASOV	{"phone": "+70833820379"}
0005432459175	437C56	4648 401381	VALERIY PAVLOV	{"email": "v-pavlov_15041984@postgrespro.ru", "phone": "+70363228600"}
0005432459176	437C56	5565 781839	GALINA DANILOVA	{"email": "danilovag031969@postgrespro.ru", "phone": "+70853893878"}
0005432459177	4E2059	6171 374019	NINA ORLOVA	{"email": "orlova_nina-14071964@postgrespro.ru", "phone": "+70908177400"}
0005432459178	40377A	7016 479862	ANDREY KULIKOV	{"phone": "+70924146141"}
0005432459179	40377A	9498 850218	NIKITA TIMOFEEV	{"email": "n.timofeev-1968@postgrespro.ru", "phone": "+70749616680"}
0005432459180	B3D895	9527 237190	TAMARA ALEKSANDROVA	{"phone": "+70535525165"}
0005432459181	99DA38	8143 536927	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr1969@postgrespro.ru", "phone": "+70727318992"}
0005432459182	99DA38	2858 342658	YAKOV NAUMOV	{"phone": "+70080399683"}
0005432459183	0F561E	5271 610424	ALEKSANDR SERGEEV	{"phone": "+70974730032"}
0005432459184	39CDD4	0616 154898	NIKITA ABRAMOV	{"phone": "+70011062400"}
0005432459185	2A5BB8	1210 282500	ALEKSANDR ALEKSANDROV	{"phone": "+70990828218"}
0005432459186	2A5BB8	5421 808575	VIKTOR KARPOV	{"phone": "+70284730920"}
0005432459187	F461E4	3756 838192	YURIY ABRAMOV	{"email": "abramovy27041975@postgrespro.ru", "phone": "+70774851763"}
0005432459188	F461E4	1890 164757	ELENA MALYSHEVA	{"phone": "+70445870860"}
0005432459189	889B51	3223 154996	VLADIMIR KONOVALOV	{"email": "konovalovvladimir_20111976@postgrespro.ru", "phone": "+70645367651"}
0005432459190	F7082A	4868 414435	NIKOLAY MIKHAYLOV	{"phone": "+70346609999"}
0005432459191	F7082A	3740 199041	ALEKSEY ANDREEV	{"phone": "+70669705074"}
0005432459192	C4AF7B	8217 623588	MIKHAIL KUZMIN	{"phone": "+70852302796"}
0005432459193	C74BBD	9446 345887	ARTEM ZAYCEV	{"email": "artem-zaycev_03031981@postgrespro.ru", "phone": "+70247225790"}
0005432459194	C74BBD	4743 479350	SOFIYA ISAEVA	{"email": "isaeva_sofiya.03071965@postgrespro.ru", "phone": "+70595908854"}
0005432459195	B1B4D3	3861 385800	NIKOLAY SOLOVEV	{"phone": "+70586139827"}
0005432459196	4F2492	2291 687056	GALINA FEDOROVA	{"email": "fedorova.galina_051966@postgrespro.ru", "phone": "+70099155581"}
0005432459197	D9D92E	8038 078724	KSENIYA KUDRYASHOVA	{"email": "k-kudryashova-1984@postgrespro.ru", "phone": "+70030429180"}
0005432459198	72C262	7119 663038	ANATOLIY EGOROV	{"email": "a.egorov-051970@postgrespro.ru", "phone": "+70434948446"}
0005432459199	F8296D	2971 055175	LYUDMILA DANILOVA	{"phone": "+70423454180"}
0005432459200	F8296D	8362 291642	LARISA MAKSIMOVA	{"phone": "+70490276736"}
0005432459201	8532BF	7639 907861	ANNA ZOTOVA	{"phone": "+70494333547"}
0005432459202	05D686	2018 069303	MAKSIM MAKAROV	{"phone": "+70777708910"}
0005432459203	2384C6	5040 098876	DANILA MATVEEV	{"phone": "+70095488420"}
0005432459204	2384C6	3781 283987	FEDOR ZAKHAROV	{"phone": "+70933923002"}
0005432459205	9A5952	7801 724150	ANTONINA MAKAROVA	{"phone": "+70410509106"}
0005432459206	6FDAD0	8110 926323	VLADIMIR EGOROV	{"email": "vladimiregorov.19081975@postgrespro.ru", "phone": "+70724201269"}
0005432459207	6FDAD0	8339 050478	LIDIYA ALEKSEEVA	{"phone": "+70167587289"}
0005432459208	A10F15	8426 698028	TATYANA KALININA	{"phone": "+70773601510"}
0005432459209	A10F15	2680 707467	IRINA SERGEEVA	{"email": "sergeeva_i12081973@postgrespro.ru", "phone": "+70539843405"}
0005432459210	A10F15	1155 805311	ARTEM MATVEEV	{"email": "artemmatveev-20111966@postgrespro.ru", "phone": "+70772923334"}
0005432459211	08ED13	7029 863625	VLADIMIR VOLKOV	{"email": "vladimirvolkov-31011969@postgrespro.ru", "phone": "+70593158912"}
0005432459212	08ED13	7147 225655	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a1971@postgrespro.ru", "phone": "+70116798440"}
0005432459213	161EF5	9894 590741	OLGA NIKITINA	{"phone": "+70884225079"}
0005432459214	220EA9	2488 749919	MARIYA LUKYANOVA	{"phone": "+70070025284"}
0005432459215	78F8EB	2532 932569	ELIZAVETA KISELEVA	{"email": "kiseleva_e051971@postgrespro.ru", "phone": "+70033026931"}
0005432459216	78F8EB	2446 566322	ALEKSANDR SOLOVEV	{"email": "a-solovev_07041974@postgrespro.ru", "phone": "+70403875087"}
0005432459217	D26140	5853 242801	ROMAN GORBUNOV	{"phone": "+70982205580"}
0005432459218	44DCD5	3545 654969	MAKSIM MIRONOV	{"email": "mironov-m_21101966@postgrespro.ru", "phone": "+70619629877"}
0005432459219	B3B109	5507 304719	ALEKSANDR MIRONOV	{"email": "mironova.01031974@postgrespro.ru", "phone": "+70025757634"}
0005432459220	35EB3B	0013 086151	TATYANA NIKIFOROVA	{"email": "nikiforova_tatyana-1963@postgrespro.ru", "phone": "+70735711579"}
0005432459221	35EB3B	3965 135640	MARINA NIKOLAEVA	{"email": "nikolaevam-061972@postgrespro.ru", "phone": "+70583461454"}
0005432459222	28FCD8	4289 554827	SERGEY MAKAROV	{"email": "s.makarov.061980@postgrespro.ru", "phone": "+70555840230"}
0005432459223	3CFDE2	8598 303627	DARYA YAKOVLEVA	{"phone": "+70908388242"}
0005432459224	3CFDE2	9365 227907	RUSTAM TIMOFEEV	{"email": "timofeev-rustam_26081968@postgrespro.ru", "phone": "+70715398191"}
0005432459225	4E142A	8487 563912	POLINA SERGEEVA	{"phone": "+70471811234"}
0005432459226	7C17BB	0401 129783	ANTONINA VOLKOVA	{"phone": "+70247329681"}
0005432459227	7C17BB	0297 188079	SVETLANA SEMENOVA	{"phone": "+70856929204"}
0005432459228	7F299F	4873 100406	LYUDMILA POPOVA	{"email": "popova_l23031981@postgrespro.ru", "phone": "+70664160675"}
0005432459229	7F299F	5174 252316	SERGEY BORISOV	{"email": "sergey.borisov.091978@postgrespro.ru", "phone": "+70556672423"}
0005432459230	E998B1	5204 215945	ANDREY SERGEEV	{"email": "sergeev_andrey_1966@postgrespro.ru", "phone": "+70843669687"}
0005432459231	C1C239	4030 369158	NINA MOROZOVA	{"phone": "+70850220618"}
0005432459232	5D293B	3008 683203	ALEKSEY AFANASEV	{"email": "afanasev_aleksey.31011971@postgrespro.ru", "phone": "+70948775158"}
0005432459233	BD3CCE	5381 356547	VYACHESLAV BORISOV	{"phone": "+70179221791"}
0005432459234	3F53B1	6521 547350	IRINA ZAYCEVA	{"email": "irina.zayceva061971@postgrespro.ru", "phone": "+70687770587"}
0005432459235	2EDF11	0618 017555	NIKOLAY YAKOVLEV	{"phone": "+70438593025"}
0005432459236	2EDF11	7527 875496	ALEKSANDRA DENISOVA	{"email": "denisova.a-19061964@postgrespro.ru", "phone": "+70465370326"}
0005432459237	3F0705	0813 463334	SERGEY SOLOVEV	{"email": "ssolovev-1958@postgrespro.ru", "phone": "+70766586917"}
0005432459238	1503A9	0935 404375	NADEZHDA SIDOROVA	{"email": "sidorova_nadezhda-1978@postgrespro.ru", "phone": "+70658904953"}
0005432459239	EE0823	2636 698007	AMIR NIKITIN	{"phone": "+70617863226"}
0005432459240	EE0823	0663 177247	VALENTINA VOLKOVA	{"email": "v.volkova.011974@postgrespro.ru", "phone": "+70070957080"}
0005432459241	579260	0945 261862	VIKTOR ILIN	{"email": "ilin_v06101973@postgrespro.ru", "phone": "+70689237816"}
0005432459242	666CAF	3974 620457	VADIM KRASNOV	{"phone": "+70552014660"}
0005432459243	1FA218	9836 408542	MARINA KUZNECOVA	{"email": "kuznecova_marina.1964@postgrespro.ru", "phone": "+70444972368"}
0005432459244	B8C69A	1452 905338	DMITRIY MIKHAYLOV	{"phone": "+70709094206"}
0005432459245	B8C69A	9323 042236	MARIANNA MIRONOVA	{"phone": "+70549687869"}
0005432459246	4050F0	8162 759875	NADEZHDA KUZNECOVA	{"email": "kuznecova-n-30071969@postgrespro.ru", "phone": "+70657890651"}
0005432459247	4530CD	8746 869264	LYUDMILA SOROKINA	{"phone": "+70643349973"}
0005432459248	78F2F7	4928 524006	VERA FILIPPOVA	{"phone": "+70266395421"}
0005432459249	0815E6	7668 718017	VASILIY KUZNECOV	{"phone": "+70886721239"}
0005432459250	0815E6	0462 803936	ANNA KUZMINA	{"phone": "+70921859471"}
0005432459251	3A2C60	1083 418826	SVETLANA DMITRIEVA	{"email": "dmitrieva.svetlana_28071971@postgrespro.ru", "phone": "+70929684432"}
0005432459252	3A2C60	7898 793625	ANATOLIY STEPANOV	{"email": "stepanov_a-1964@postgrespro.ru", "phone": "+70455841923"}
0005432459253	D92213	6091 274168	SERGEY STEPANOV	{"email": "stepanov-sergey-051971@postgrespro.ru", "phone": "+70167593516"}
0005432459254	D92213	2233 490088	FEDOR YAKOVLEV	{"email": "fedor.yakovlev10101970@postgrespro.ru", "phone": "+70368684068"}
0005432459255	F95AB0	6101 933575	VIKTOR FILIPPOV	{"phone": "+70751041692"}
0005432459256	1B79FC	5307 944524	VADIM KOROLEV	{"email": "vadimkorolev.1965@postgrespro.ru", "phone": "+70075555069"}
0005432459257	C517D0	3144 667332	ANDREY MOROZOV	{"email": "morozova-13071977@postgrespro.ru", "phone": "+70736843114"}
0005432459258	C517D0	9658 256199	IVAN MARTYNOV	{"email": "i_martynov.011972@postgrespro.ru", "phone": "+70479478820"}
0005432459259	F2A2E5	9470 795166	OLGA MELNIKOVA	{"email": "melnikova_o-08071973@postgrespro.ru", "phone": "+70157503271"}
0005432459260	21AEE9	1071 227935	ARTEM ZAKHAROV	{"phone": "+70242111296"}
0005432459261	90A782	2498 773386	VIKTOR TARASOV	{"email": "v_tarasov-011972@postgrespro.ru", "phone": "+70200021402"}
0005432459262	119D70	2889 249293	IGOR SOLOVEV	{"phone": "+70031438138"}
0005432459263	652DFB	5383 472042	ALEKSANDR MARTYNOV	{"email": "martynov_a_31011966@postgrespro.ru", "phone": "+70088792564"}
0005432459264	85803F	2307 643033	RAISA NESTEROVA	{"email": "raisa.nesterova.24121973@postgrespro.ru", "phone": "+70846505229"}
0005432459265	19359E	7851 968660	RAISA MATVEEVA	{"email": "matveeva-raisa_24101959@postgrespro.ru", "phone": "+70887367360"}
0005432459266	19359E	0653 221321	VLADIMIR YAKOVLEV	{"phone": "+70250200611"}
0005432459267	543864	9247 937194	NIKOLAY KUZMIN	{"phone": "+70938563502"}
0005432459268	A94134	7592 024957	ARTUR ZAYCEV	{"email": "zayceva-101979@postgrespro.ru", "phone": "+70610387546"}
0005432459269	59C07A	2455 130537	VALENTINA CHERNOVA	{"phone": "+70436066702"}
0005432459270	026311	3162 085782	NATALIYA ORLOVA	{"email": "norlova-18081972@postgrespro.ru", "phone": "+70299481137"}
0005432459271	026311	3530 087197	ARTEM NIKITIN	{"email": "anikitin_011970@postgrespro.ru", "phone": "+70513430971"}
0005432459272	5F20B8	4212 063980	ANNA CHERNOVA	{"email": "chernova.a-1972@postgrespro.ru", "phone": "+70365563168"}
0005432459273	5F20B8	2694 508768	SOFIYA NESTEROVA	{"phone": "+70724141622"}
0005432459274	9E4D75	6428 128526	LEV TARASOV	{"phone": "+70856283590"}
0005432459275	FAF4EF	3454 652606	DMITRIY NOVIKOV	{"phone": "+70336659701"}
0005432459276	A34FBA	5874 748238	ELENA BOGDANOVA	{"email": "bogdanova_e.091957@postgrespro.ru", "phone": "+70476080299"}
0005432459277	C98145	4194 861192	ROMAN KOZLOV	{"phone": "+70309078476"}
0005432459278	C98145	5780 182016	ALEKSEY MOROZOV	{"email": "morozov_aleksey_1971@postgrespro.ru", "phone": "+70000148752"}
0005432459279	9E303A	3211 071779	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov-1970@postgrespro.ru", "phone": "+70259956300"}
0005432459280	8485B2	4183 833327	POLINA ZHURAVLEVA	{"phone": "+70337240345"}
0005432459281	BC1202	1313 811813	IRINA NIKOLAEVA	{"phone": "+70746430678"}
0005432459282	8B1F83	8773 468143	VLADIMIR YAKOVLEV	{"email": "vladimiryakovlev021974@postgrespro.ru", "phone": "+70243604072"}
0005432459283	9CB513	4543 891533	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr1976@postgrespro.ru", "phone": "+70247323292"}
0005432459284	9CB513	7880 036556	NIKITA SEMENOV	{"phone": "+70338961075"}
0005432459285	CE6330	6989 313592	ILYA MELNIKOV	{"email": "i-melnikov_28041973@postgrespro.ru", "phone": "+70710632681"}
0005432459286	CE6330	4779 654877	IRINA SOROKINA	{"email": "sorokina.irina_031977@postgrespro.ru", "phone": "+70795284882"}
0005432459287	29AEE1	8220 351669	MARINA ANDREEVA	{"email": "m_andreeva-09051968@postgrespro.ru", "phone": "+70650481870"}
0005432459288	75288D	3132 834830	EVGENIY KOZLOV	{"phone": "+70353358218"}
0005432459289	CDF8A1	8367 628424	IRINA NESTEROVA	{"email": "nesterovai_1967@postgrespro.ru", "phone": "+70584332006"}
0005432459290	9B5FAF	7091 172216	SVETLANA KOROLEVA	{"phone": "+70834796199"}
0005432459291	1FE1F1	1418 778244	DMITRIY SHEVCHENKO	{"phone": "+70537298775"}
0005432459292	BC9CCE	9771 155534	ANTON IVANOV	{"email": "anton-ivanov.08081969@postgrespro.ru", "phone": "+70093512334"}
0005432459293	B6C812	3541 556482	ALEKSANDR SAVELEV	{"phone": "+70714959188"}
0005432459294	C21685	2268 089097	DMITRIY MAKAROV	{"phone": "+70259626121"}
0005432459295	47AADE	0810 671868	EVGENIYA FOMINA	{"email": "evgeniyafomina-1960@postgrespro.ru", "phone": "+70780820088"}
0005432459296	FC2472	7952 327408	OLGA BORISOVA	{"email": "o_borisova.06091973@postgrespro.ru", "phone": "+70483238207"}
0005432459297	7F425B	3770 268364	EVGENIY MAKSIMOV	{"email": "e.maksimov02061972@postgrespro.ru", "phone": "+70183063271"}
0005432459298	07DCCE	5531 874757	LILIYA KARPOVA	{"email": "liliya-karpova.121976@postgrespro.ru", "phone": "+70076024034"}
0005432459299	51A5C7	3165 205241	SHAMIL NAUMOV	{"email": "naumovshamil-1970@postgrespro.ru", "phone": "+70822142371"}
0005432459300	BF5C95	6720 955077	OLGA MALYSHEVA	{"email": "olgamalysheva091979@postgrespro.ru", "phone": "+70409499013"}
0005432459301	BF5C95	5287 717185	MARINA GAVRILOVA	{"email": "marina.gavrilova_06071967@postgrespro.ru", "phone": "+70401531729"}
0005432459302	0DF967	4904 976007	DMITRIY PETROV	{"email": "d-petrov081980@postgrespro.ru", "phone": "+70504229922"}
0005432459303	0DF967	7433 401588	STEPAN ANDREEV	{"email": "s_andreev_041972@postgrespro.ru", "phone": "+70384145709"}
0005432459304	0DF967	4729 343511	VYACHESLAV MOISEEV	{"email": "moiseevv041977@postgrespro.ru", "phone": "+70858075488"}
0005432459305	18AA89	2107 511918	GALINA SEMENOVA	{"email": "galina-semenova_1969@postgrespro.ru", "phone": "+70769989420"}
0005432459306	C91AA1	2840 315077	ALEKSEY CHERNOV	{"email": "chernov_a.041973@postgrespro.ru", "phone": "+70845673343"}
0005432459307	C91AA1	0058 678017	TATYANA MIRONOVA	{"email": "mironova-t_081973@postgrespro.ru", "phone": "+70271580247"}
0005432459308	D7A037	8325 621803	ALBINA YAKOVLEVA	{"phone": "+70713539098"}
0005432459309	D7A037	8913 101911	NATALYA KOLESNIKOVA	{"phone": "+70829689960"}
0005432459310	CE0D45	7371 480038	YULIYA MASLOVA	{"phone": "+70069340353"}
0005432459311	CE0D45	4971 842941	LIDIYA LUKYANOVA	{"phone": "+70010210753"}
0005432459312	CE0D45	0365 177522	ARINA MALYSHEVA	{"phone": "+70288960872"}
0005432459313	B5C255	5701 705280	MIKHAIL BARANOV	{"phone": "+70881719197"}
0005432459314	B5C255	0514 312486	VLADIMIR KISELEV	{"phone": "+70662838470"}
0005432459315	52CB24	8963 169299	LYUBOV KUZMINA	{"phone": "+70174050861"}
0005432459316	52CB24	1534 045314	ANASTASIYA IVANOVA	{"email": "ivanova-anastasiya-1970@postgrespro.ru", "phone": "+70473008043"}
0005432459317	677FB4	5550 237137	YURIY ZHURAVLEV	{"phone": "+70967651445"}
0005432459318	12D0E0	1244 281702	VLADISLAV ROMANOV	{"phone": "+70896292486"}
0005432459319	3BBAF2	8915 966590	MAKSIM NIKOLAEV	{"email": "maksim-nikolaev16101982@postgrespro.ru", "phone": "+70495532642"}
0005432459320	3B5A53	7643 452421	OLEG MAKAROV	{"email": "oleg_makarov.01091971@postgrespro.ru", "phone": "+70829112596"}
0005432459321	3B5A53	7454 788707	VALENTINA LOGINOVA	{"phone": "+70067058315"}
0005432459322	631592	7352 527568	TATYANA KULIKOVA	{"phone": "+70656015886"}
0005432459323	AE41A3	1409 209349	NIKOLAY FILIPPOV	{"phone": "+70378238491"}
0005432459324	9F5E11	8417 166324	OLGA KUDRYASHOVA	{"phone": "+70429048453"}
0005432459325	F94308	4960 710710	ANDREY IVANOV	{"phone": "+70283071908"}
0005432459326	F94308	0130 565005	MIKHAIL ABRAMOV	{"email": "m-abramov_061984@postgrespro.ru", "phone": "+70166846258"}
0005432459327	ED369E	3550 502921	SERGEY KARPOV	{"phone": "+70197971513"}
0005432459328	3DB754	5523 474087	IRINA BELYAEVA	{"email": "belyaeva-irina.091976@postgrespro.ru", "phone": "+70206133267"}
0005432459329	15B19A	8150 179733	MARIYA KRASNOVA	{"phone": "+70551109945"}
0005432459330	C9D250	9585 427550	YAKOV KRASNOV	{"email": "krasnov.yakov-10101959@postgrespro.ru", "phone": "+70331111344"}
0005432459331	BEEF73	3406 726981	DMITRIY NIKOLAEV	{"phone": "+70297241226"}
0005432459332	574C18	6652 713644	YULIYA GORBUNOVA	{"email": "gorbunova-yuliya121976@postgrespro.ru", "phone": "+70831282414"}
0005432459333	2C58DF	4849 005339	ANDREY FOMIN	{"phone": "+70283063282"}
0005432459334	2C58DF	5804 618305	VALENTINA MOROZOVA	{"email": "morozova.valentina_15021977@postgrespro.ru", "phone": "+70491800472"}
0005432459335	35E7E1	9478 673028	ARTEM GUSEV	{"email": "guseva_27041974@postgrespro.ru", "phone": "+70010997262"}
0005432459336	9564E4	7670 570639	SVETLANA SOROKINA	{"email": "svetlana.sorokina_091979@postgrespro.ru", "phone": "+70991982960"}
0005432459337	902F8B	5166 249346	ALEKSANDRA KAZAKOVA	{"phone": "+70302863100"}
0005432459338	203475	4531 426721	ELENA MOROZOVA	{"phone": "+70831181564"}
0005432459339	FD4C77	2340 751217	YURIY PAVLOV	{"email": "y.pavlov-04091982@postgrespro.ru", "phone": "+70540612171"}
0005432459340	EE0047	6478 720578	ANTONINA TARASOVA	{"email": "tarasova-antonina.17111972@postgrespro.ru", "phone": "+70711322992"}
0005432459341	EE0047	2058 726934	ALEKSANDR BELOV	{"email": "aleksandrbelov101971@postgrespro.ru", "phone": "+70022210295"}
0005432459342	0F69FB	8257 315858	VERA ZOTOVA	{"phone": "+70319499376"}
0005432459343	32A85B	5823 651239	YULIYA STEPANOVA	{"email": "yuliya-stepanova-06021972@postgrespro.ru", "phone": "+70685538257"}
0005432459344	32A85B	6804 242232	OLGA VLASOVA	{"email": "olgavlasova-19091972@postgrespro.ru", "phone": "+70066287779"}
0005432459345	7E9EFC	7491 465208	TATYANA AKIMOVA	{"phone": "+70925618061"}
0005432459346	2672A5	4550 357528	SERGEY FEDOROV	{"phone": "+70069365179"}
0005432459347	2672A5	8032 951369	EGOR DENISOV	{"email": "egor.denisov011977@postgrespro.ru", "phone": "+70975311902"}
0005432459348	C65308	4910 379677	DMITRIY TIMOFEEV	{"email": "d.timofeev_26061983@postgrespro.ru", "phone": "+70025735032"}
0005432459349	5751B5	1356 912404	PAVEL NIKITIN	{"email": "nikitinpavel25011967@postgrespro.ru", "phone": "+70102485217"}
0005432459350	5751B5	1586 779746	NATALYA ZAYCEVA	{"phone": "+70288010986"}
0005432459351	5751B5	4295 516243	EVGENIY KUZNECOV	{"email": "kuznecov_evgeniy09051971@postgrespro.ru", "phone": "+70831624758"}
0005432459352	D7BE4D	0254 263583	MARIYA EFIMOVA	{"email": "efimova-m.1963@postgrespro.ru", "phone": "+70014256251"}
0005432459353	D7BE4D	2145 060489	VLADIMIR SCHERBAKOV	{"phone": "+70636246586"}
0005432459354	D123E9	1982 481954	OLEG ABRAMOV	{"email": "abramovoleg-1977@postgrespro.ru", "phone": "+70302285829"}
0005432459355	D123E9	1830 327381	NINA NIKITINA	{"email": "nina.nikitina.1969@postgrespro.ru", "phone": "+70646514259"}
0005432459356	D123E9	6728 575569	TATYANA MAKSIMOVA	{"email": "t.maksimova.1982@postgrespro.ru", "phone": "+70372722739"}
0005432459357	D123E9	3324 927510	LIDIYA NIKITINA	{"phone": "+70749525732"}
0005432459358	C9F6BE	7153 370374	OLGA ALEKSEEVA	{"email": "olga-alekseeva.1977@postgrespro.ru", "phone": "+70250315726"}
0005432459359	C9F6BE	5883 988157	MARINA ISAEVA	{"phone": "+70303900000"}
0005432459360	D11E97	9189 836752	OLGA BELYAEVA	{"email": "o_belyaeva-14121970@postgrespro.ru", "phone": "+70220591393"}
0005432459361	D11E97	5217 969834	VLADIMIR GAVRILOV	{"phone": "+70879318222"}
0005432459362	13C220	5857 844697	ANATOLIY ABRAMOV	{"phone": "+70789274402"}
0005432459363	3FDE09	4581 810299	ANDREY POPOV	{"phone": "+70125445616"}
0005432459364	41B65B	9338 487535	ALEKSEY KUDRYASHOV	{"phone": "+70965926770"}
0005432459365	250120	5997 690421	SERGEY SMIRNOV	{"phone": "+70106229850"}
0005432459366	250120	5040 901110	PETR IVANOV	{"email": "petr_ivanov-13031968@postgrespro.ru", "phone": "+70442791408"}
0005432459367	305AA3	3023 127413	TATYANA DMITRIEVA	{"email": "dmitrievat.1982@postgrespro.ru", "phone": "+70457796515"}
0005432459368	31DA0A	4025 345048	ANNA KULIKOVA	{"email": "akulikova-081967@postgrespro.ru", "phone": "+70275992230"}
0005432459369	B61B79	2291 279466	LARISA GERASIMOVA	{"phone": "+70551117313"}
0005432459370	04E9B6	0950 929999	EVGENIY MIKHAYLOV	{"phone": "+70529252447"}
0005432459371	1CBC85	2515 182012	DMITRIY NAZAROV	{"email": "dnazarov_071969@postgrespro.ru", "phone": "+70678968670"}
0005432459372	56FDCF	8326 282062	ALEKSANDR CHERNOV	{"email": "a_chernov-1964@postgrespro.ru", "phone": "+70655928053"}
0005432459373	1EB3A4	7317 773595	NATALYA EGOROVA	{"email": "n_egorova.1975@postgrespro.ru", "phone": "+70524884668"}
0005432459374	24FB5C	9103 150373	VADIM KULIKOV	{"phone": "+70317816149"}
0005432459375	D6BBEF	2093 123498	GALINA GUSEVA	{"email": "guseva.galina02051965@postgrespro.ru", "phone": "+70286814218"}
0005432459376	502F7A	9521 293089	DMITRIY ZAKHAROV	{"phone": "+70974528469"}
0005432459377	DF12CB	3844 570597	VLADIMIR KONOVALOV	{"email": "konovalovv.24121966@postgrespro.ru", "phone": "+70486695379"}
0005432459378	189A14	7237 489713	KONSTANTIN SCHERBAKOV	{"email": "kscherbakov1983@postgrespro.ru", "phone": "+70861139897"}
0005432459379	72B092	7026 604988	SERGEY TIMOFEEV	{"email": "timofeev.s.051968@postgrespro.ru", "phone": "+70223607354"}
0005432459380	FC274E	9620 092136	VALERIYA OSIPOVA	{"phone": "+70368397180"}
0005432459381	FC274E	0941 159946	ROMAN AFANASEV	{"email": "romanafanasev-14071957@postgrespro.ru", "phone": "+70121475263"}
0005432459382	8F7FA5	5614 149317	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov061972@postgrespro.ru", "phone": "+70897923171"}
0005432459383	53E675	3154 124583	BORIS KOROLEV	{"phone": "+70751953813"}
0005432459384	4F3E1D	1870 163390	INESSA FILIPPOVA	{"email": "filippova_inessa21081974@postgrespro.ru", "phone": "+70218125056"}
0005432459385	4F3E1D	9607 957136	VLADISLAV MAKAROV	{"phone": "+70807866462"}
0005432459386	C615C2	4738 220839	SERGEY NAZAROV	{"phone": "+70768428269"}
0005432459387	41396E	2748 702876	TATYANA VOROBEVA	{"phone": "+70948572542"}
0005432459388	B01FB2	4216 032795	SVETLANA FEDOROVA	{"phone": "+70074851454"}
0005432459389	D4C9BA	8380 639260	DMITRIY IVANOV	{"email": "dmitriyivanov-1973@postgrespro.ru", "phone": "+70163979021"}
0005432459390	D4C9BA	2181 224254	ALEKSEY SEMENOV	{"phone": "+70015992798"}
0005432459391	AE7659	5180 925081	VASILIY ILIN	{"phone": "+70212395920"}
0005432459392	AE7659	6553 915382	LYUBOV FROLOVA	{"phone": "+70882455072"}
0005432459393	50CC8B	6173 396050	LYUBOV TITOVA	{"phone": "+70173696582"}
0005432459394	50CC8B	7635 737402	NIKOLAY ZAYCEV	{"phone": "+70218782634"}
0005432459395	408DD6	8475 279050	ALEKSANDR NIKITIN	{"email": "nikitin.a.1976@postgrespro.ru", "phone": "+70627944619"}
0005432459396	408DD6	4469 068941	NIKOLAY SAVELEV	{"email": "savelev-n-1969@postgrespro.ru", "phone": "+70175745878"}
0005432459397	3E3C35	7208 780232	ELENA MAKSIMOVA	{"email": "emaksimova-061976@postgrespro.ru", "phone": "+70077259281"}
0005432459398	82F2CA	6255 368198	ANDREY NOVIKOV	{"email": "andrey.novikov.021971@postgrespro.ru", "phone": "+70120027106"}
0005432459399	82F2CA	2049 752885	IRINA GORBUNOVA	{"email": "gorbunova-irina.15091966@postgrespro.ru", "phone": "+70823941337"}
0005432459400	239636	2389 434595	VITALIY ILIN	{"phone": "+70941994420"}
0005432459401	6CF3A6	9698 061970	VALENTINA ANDREEVA	{"email": "andreeva-valentina-1969@postgrespro.ru", "phone": "+70301468097"}
0005432459402	0C0102	2908 304014	YURIY SCHERBAKOV	{"phone": "+70866868821"}
0005432459403	422CCA	9840 685653	SERGEY GRIGOREV	{"email": "sergey_grigorev.07041974@postgrespro.ru", "phone": "+70923526560"}
0005432459404	63A0BF	8878 815058	KIRILL KOROLEV	{"phone": "+70893951183"}
0005432459405	3326C3	5639 371791	ANTON MOROZOV	{"phone": "+70147443644"}
0005432459406	F3A612	7364 655879	MARIYA DAVYDOVA	{"phone": "+70003020422"}
0005432459407	F7D2F0	9065 808143	RAFAEL ORLOV	{"phone": "+70929191548"}
0005432459408	610A01	2858 353634	MARIYA DENISOVA	{"phone": "+70787200053"}
0005432459409	D8FFB8	9637 547580	ALEKSANDR KRASNOV	{"phone": "+70156706754"}
0005432459410	D8FFB8	8117 350346	DENIS KUDRYASHOV	{"email": "d.kudryashov.1975@postgrespro.ru", "phone": "+70491623207"}
0005432459411	C9EBC9	2693 702079	KONSTANTIN IVANOV	{"email": "ivanov-k_1977@postgrespro.ru", "phone": "+70855923763"}
0005432459412	AA3939	1232 293707	LIDIYA KUZNECOVA	{"phone": "+70488019229"}
0005432459413	DF3078	4073 198325	OLGA ALEKSANDROVA	{"email": "o_aleksandrova_1971@postgrespro.ru", "phone": "+70234052041"}
0005432459414	9D45EB	1739 574387	VERA ROMANOVA	{"email": "v-romanova-1956@postgrespro.ru", "phone": "+70772520868"}
0005432459415	9D45EB	5936 804727	VALENTINA GUSEVA	{"phone": "+70541315322"}
0005432459416	03E04A	9833 484798	VALERIY KUZMIN	{"email": "kuzmin.v1975@postgrespro.ru", "phone": "+70798432402"}
0005432459417	03E04A	0485 637213	OKSANA AFANASEVA	{"phone": "+70243764348"}
0005432459418	03E04A	3502 090570	EKATERINA IVANOVA	{"phone": "+70390717165"}
0005432459419	03E04A	9199 134501	NATALYA MATVEEVA	{"phone": "+70009992646"}
0005432459420	8BBAB5	3357 321671	ANNA TIMOFEEVA	{"email": "timofeeva.a_31081964@postgrespro.ru", "phone": "+70094505216"}
0005432459421	7EF0AA	9688 485985	MARIYA GRISHINA	{"email": "grishina.mariya-1970@postgrespro.ru", "phone": "+70179558450"}
0005432459422	CA6CE5	1761 192068	MIKHAIL VASILEV	{"email": "vasilev_m.1969@postgrespro.ru", "phone": "+70017871574"}
0005432459423	CA6CE5	5678 130852	ELIZAVETA EFIMOVA	{"phone": "+70161448918"}
0005432459424	CA6CE5	6111 696970	VERA SOROKINA	{"phone": "+70901575107"}
0005432459425	08AFC3	1977 831127	IRINA NESTEROVA	{"email": "nesterova-i071969@postgrespro.ru", "phone": "+70922702084"}
0005432459426	4BCB23	6616 075625	KAMILA FEDOROVA	{"email": "fedorova_k-1976@postgrespro.ru", "phone": "+70615477302"}
0005432459427	30EED1	6086 192633	YURIY FILIPPOV	{"email": "filippov.y_1971@postgrespro.ru", "phone": "+70993915944"}
0005432459428	BE7F03	0735 007167	EDUARD ZAYCEV	{"phone": "+70346885290"}
0005432459429	6C97AF	8079 245580	ALEKSANDR VLASOV	{"phone": "+70432745022"}
0005432459430	646289	9995 490154	VALENTINA KRASNOVA	{"phone": "+70358451421"}
0005432459431	646289	8665 700201	NATALYA NESTEROVA	{"email": "nesterova_natalya_121964@postgrespro.ru", "phone": "+70621467814"}
0005432459432	24482C	2983 703401	MAKSIM SCHERBAKOV	{"phone": "+70575092196"}
0005432459433	24482C	6547 793784	VALENTINA DENISOVA	{"phone": "+70698156021"}
0005432459434	14A0A7	7451 337182	ALEKSEY BONDARENKO	{"email": "bondarenko-aleksey_121978@postgrespro.ru", "phone": "+70913299392"}
0005432459435	E7C052	4667 137774	SERGEY OSIPOV	{"email": "osipov_s.101973@postgrespro.ru", "phone": "+70026102181"}
0005432459436	E7C052	7922 241555	ZINAIDA FILIPPOVA	{"email": "filippova-z.111964@postgrespro.ru", "phone": "+70539107334"}
0005432459437	D05CB4	8687 174606	NINA FROLOVA	{"phone": "+70839278120"}
0005432459438	D05CB4	6425 315479	IGOR RODIONOV	{"email": "rodionov.i_041972@postgrespro.ru", "phone": "+70113689306"}
0005432459439	110D45	2155 420002	ILDAR SIDOROV	{"phone": "+70190571586"}
0005432459440	EBCFC4	7594 000522	NATALYA GORBUNOVA	{"phone": "+70385149096"}
0005432459441	D91ACB	2768 187598	EKATERINA KRASNOVA	{"email": "ekaterinakrasnova_1971@postgrespro.ru", "phone": "+70746048229"}
0005432459442	64C2C8	0879 872222	VLADIMIR ZAKHAROV	{"phone": "+70427436984"}
0005432459443	64C2C8	3759 120752	TAMARA ALEKSANDROVA	{"email": "tamara.aleksandrova_1975@postgrespro.ru", "phone": "+70911399284"}
0005432459444	3FC197	0804 655136	SERGEY BORISOV	{"phone": "+70743967749"}
0005432459445	D94D3C	8515 604351	VLADIMIR CHERNOV	{"email": "v_chernov_30121977@postgrespro.ru", "phone": "+70489340565"}
0005432459446	D94D3C	9350 817028	ANASTASIYA PAVLOVA	{"phone": "+70167917952"}
0005432459447	046B70	4741 099892	EVDOKIYA IVANOVA	{"email": "e_ivanova1970@postgrespro.ru", "phone": "+70165418020"}
0005432459448	046B70	6406 280764	TATYANA DAVYDOVA	{"phone": "+70488347761"}
0005432459449	36258F	6095 844396	MAKSIM FOMIN	{"phone": "+70472078531"}
0005432459450	E66181	7911 260175	GEORGIY ZHUKOV	{"phone": "+70201527844"}
0005432459451	33F5F7	8666 882337	ANATOLIY TIMOFEEV	{"phone": "+70248883229"}
0005432459452	33F5F7	9039 234683	DARYA ROMANOVA	{"email": "dromanova_091973@postgrespro.ru", "phone": "+70627289062"}
0005432459453	AF1AFE	5147 523472	EKATERINA DMITRIEVA	{"email": "ekaterina_dmitrieva.1962@postgrespro.ru", "phone": "+70767902618"}
0005432459454	094B9A	0348 587484	NIKOLAY KRASNOV	{"email": "krasnovnikolay-081977@postgrespro.ru", "phone": "+70683076912"}
0005432459511	85A6B6	5314 430963	DARYA BARANOVA	{"phone": "+70638137841"}
0005432459455	094B9A	1604 939908	MAKSIM MIRONOV	{"email": "mironovmaksim.031980@postgrespro.ru", "phone": "+70421086192"}
0005432459456	D90A73	6652 290300	RADIK KAZAKOV	{"email": "kazakov.r1967@postgrespro.ru", "phone": "+70257157907"}
0005432459457	D90A73	3276 506085	VLADIMIR AFANASEV	{"phone": "+70342149972"}
0005432459458	D90A73	4338 316755	LYUDMILA KULIKOVA	{"email": "kulikova.lyudmila1974@postgrespro.ru", "phone": "+70954908058"}
0005432459459	49B75C	1392 864450	ILYAS TIKHONOV	{"phone": "+70640005650"}
0005432459460	B01E49	5087 992591	VIKTOR MEDVEDEV	{"email": "viktor-medvedev1973@postgrespro.ru", "phone": "+70701506443"}
0005432459461	D13D17	4685 214636	TATYANA KUZNECOVA	{"email": "kuznecova.t1964@postgrespro.ru", "phone": "+70449005717"}
0005432459462	D13D17	8460 832012	SERGEY BORISOV	{"email": "borisov_s_1964@postgrespro.ru", "phone": "+70487775468"}
0005432459463	080F7D	5360 765623	ANDREY PAVLOV	{"email": "a_pavlov_031980@postgrespro.ru", "phone": "+70495169413"}
0005432459464	080F7D	4179 372935	PAVEL MIKHAYLOV	{"email": "mikhaylov-pavel-061974@postgrespro.ru", "phone": "+70321302678"}
0005432459465	269C76	8351 705440	OLGA GAVRILOVA	{"phone": "+70163472826"}
0005432459466	92046B	7774 276114	LIDIYA NIKITINA	{"email": "nikitinal-081963@postgrespro.ru", "phone": "+70729338865"}
0005432459467	083508	3011 409727	ALEKSANDR ALEKSEEV	{"email": "aleksandr-alekseev_101968@postgrespro.ru", "phone": "+70051868820"}
0005432459468	D85A2D	3651 899327	EKATERINA KRASNOVA	{"phone": "+70122312639"}
0005432459469	65AFEA	5697 731718	ELENA LOGINOVA	{"email": "loginova.elena1977@postgrespro.ru", "phone": "+70081852454"}
0005432459470	65AFEA	7067 036659	VARVARA BARANOVA	{"phone": "+70604996473"}
0005432459471	375798	9166 827877	MIKHAIL IVANOV	{"phone": "+70785557119"}
0005432459472	9DE7EA	9232 350574	EVGENIYA TARASOVA	{"phone": "+70154585859"}
0005432459473	9DE7EA	0851 301131	IRINA YUDINA	{"email": "irina_yudina-22051958@postgrespro.ru", "phone": "+70673814565"}
0005432459474	F0E878	6773 340952	TATYANA MIRONOVA	{"phone": "+70833361621"}
0005432459475	F0E878	6632 147006	ALEKSANDR AFANASEV	{"email": "a.afanasev051970@postgrespro.ru", "phone": "+70963797471"}
0005432459476	2508BF	1446 988713	VIKTOR NIKOLAEV	{"email": "viktor.nikolaev_1979@postgrespro.ru", "phone": "+70558407108"}
0005432459477	31723B	7353 308351	NINA KOROLEVA	{"phone": "+70644437893"}
0005432459478	85136D	1009 494958	LARISA NIKOLAEVA	{"phone": "+70549811742"}
0005432459479	379DBB	8587 284623	FATYMA NIKIFOROVA	{"email": "f.nikiforova101976@postgrespro.ru", "phone": "+70146366876"}
0005432459480	915DA3	5041 235001	NADEZHDA MEDVEDEVA	{"phone": "+70418462193"}
0005432459481	7138BF	1944 975603	ALEKSANDR SAVELEV	{"email": "asavelev_12021971@postgrespro.ru", "phone": "+70933287525"}
0005432459482	606302	4193 785500	ALBINA POPOVA	{"phone": "+70389082095"}
0005432459483	606302	7744 461060	RAISA MAKSIMOVA	{"phone": "+70576871571"}
0005432459484	3373D8	2076 235251	ZINAIDA KONOVALOVA	{"email": "konovalova.z1975@postgrespro.ru", "phone": "+70479928793"}
0005432459485	8FE0D3	9491 445636	RAISA NESTEROVA	{"email": "raisa.nesterova.081972@postgrespro.ru", "phone": "+70988878306"}
0005432459486	E5E187	7951 845385	TAMARA ZAKHAROVA	{"email": "zakharova.t-1965@postgrespro.ru", "phone": "+70481874113"}
0005432459487	0A4816	0653 985591	ALEKSEY MATVEEV	{"email": "alekseymatveev.02091965@postgrespro.ru", "phone": "+70036799110"}
0005432459488	17641C	6956 690660	GALINA TARASOVA	{"email": "tarasova.g-011957@postgrespro.ru", "phone": "+70890956150"}
0005432459489	17641C	5429 709489	VIKTOR NOVIKOV	{"email": "viktornovikov_101962@postgrespro.ru", "phone": "+70585652764"}
0005432459490	C4CEBE	0627 510416	LILIYA KISELEVA	{"phone": "+70568195740"}
0005432459491	8EB2C5	2242 720179	VLADIMIR MOROZOV	{"phone": "+70810983025"}
0005432459492	2A2680	6919 739354	MARINA KOMAROVA	{"phone": "+70357696514"}
0005432459493	2A2680	2985 106389	YAKOV CHERNOV	{"email": "y-chernov-1972@postgrespro.ru", "phone": "+70045991474"}
0005432459494	6C46E2	1874 444217	MARIANNA PAVLOVA	{"phone": "+70431726496"}
0005432459495	6C46E2	7218 101804	ALENA ROMANOVA	{"phone": "+70628235179"}
0005432459496	513B49	9732 822845	IVAN TARASOV	{"phone": "+70515842582"}
0005432459497	B3418E	4155 572716	VIKTOR VOROBEV	{"email": "vorobev_viktor.101970@postgrespro.ru", "phone": "+70389366089"}
0005432459498	CD9BCF	3367 346014	ALEKSANDR KUZNECOV	{"email": "a_kuznecov_1978@postgrespro.ru", "phone": "+70372520761"}
0005432459499	36A70C	5151 571306	VITALIY ROMANOV	{"phone": "+70156158311"}
0005432459500	D51FEF	5532 498192	ANATOLIY FEDOROV	{"email": "fedorov_anatoliy-081967@postgrespro.ru", "phone": "+70569055879"}
0005432459501	D51FEF	6936 898976	NATALIYA DMITRIEVA	{"phone": "+70320722970"}
0005432459502	F14468	7231 041769	VIKTOR KRASNOV	{"email": "krasnov.v081979@postgrespro.ru", "phone": "+70312163955"}
0005432459503	3B3DB3	9469 739361	IVAN SAVELEV	{"phone": "+70499047342"}
0005432459504	D9A3F8	3729 163886	ZOYA KUZNECOVA	{"email": "kuznecova_zoya_1975@postgrespro.ru", "phone": "+70364131293"}
0005432459505	4DA5B5	3542 162233	ALEKSANDRA SERGEEVA	{"email": "sergeeva-aleksandra-111967@postgrespro.ru", "phone": "+70220666580"}
0005432459506	9EB6EC	4200 784532	MARIYA EFREMOVA	{"phone": "+70419609578"}
0005432459507	B54DD7	6253 247554	MIKHAIL MAKAROV	{"email": "m_makarov.031970@postgrespro.ru", "phone": "+70122028687"}
0005432459508	6DF542	5726 135045	NADEZHDA STEPANOVA	{"email": "n-stepanova_031967@postgrespro.ru", "phone": "+70688826758"}
0005432459509	6DF542	9922 297965	VLADISLAV EGOROV	{"email": "v.egorov_1985@postgrespro.ru", "phone": "+70672920218"}
0005432459510	85A6B6	3297 621769	TATYANA ILINA	{"phone": "+70046192492"}
0005432459512	C0A72A	7718 178662	NATALYA VOLKOVA	{"email": "volkova_natalya.121970@postgrespro.ru", "phone": "+70978263635"}
0005432459513	C0A72A	6306 631358	NATALYA VOROBEVA	{"phone": "+70430859697"}
0005432459514	9D9F63	7966 654147	NADEZHDA DAVYDOVA	{"email": "nadezhdadavydova061975@postgrespro.ru", "phone": "+70257005876"}
0005432459515	9D9F63	9553 203182	LARISA VOROBEVA	{"email": "l-vorobeva1969@postgrespro.ru", "phone": "+70972571704"}
0005432459516	DBA2F3	5391 708149	TATYANA ZAKHAROVA	{"phone": "+70912480499"}
0005432459517	B0F7E1	4355 143925	OLEG KISELEV	{"phone": "+70767057250"}
0005432459518	B0F7E1	4039 781665	ALEKSEY DENISOV	{"phone": "+70518629876"}
0005432459519	069E34	8292 854925	NIKOLAY BONDARENKO	{"phone": "+70951936874"}
0005432459520	069E34	4315 285664	ALEKSEY VOLKOV	{"email": "volkov_a.20091973@postgrespro.ru", "phone": "+70854923568"}
0005432459521	202A54	5016 990137	ANDREY MAKSIMOV	{"email": "maksimovandrey-1968@postgrespro.ru", "phone": "+70283918855"}
0005432459522	202A54	7837 341483	KLAVDIYA VLASOVA	{"phone": "+70909784888"}
0005432459523	5BF32E	9569 531876	NATALIYA ILINA	{"email": "nilina-1974@postgrespro.ru", "phone": "+70953274538"}
0005432459524	5E6FEE	3860 732312	ANDREY ZAKHAROV	{"email": "zakharovandrey-1964@postgrespro.ru", "phone": "+70540690056"}
0005432459525	5E6FEE	3643 839743	SVETLANA NIKIFOROVA	{"phone": "+70886381754"}
0005432459526	D03DFA	2128 545196	ANDREY VASILEV	{"phone": "+70799044607"}
0005432459527	110697	4679 928417	IVAN ZAKHAROV	{"email": "zakharov.i-021986@postgrespro.ru", "phone": "+70751018872"}
0005432459528	8CEED7	6993 846495	SERGEY NIKITIN	{"email": "nikitin.s.121984@postgrespro.ru", "phone": "+70851132580"}
0005432459529	1989D2	3163 573438	GALINA LEBEDEVA	{"phone": "+70103746213"}
0005432459530	1989D2	6840 411377	IGOR POPOV	{"phone": "+70728051829"}
0005432459531	2A8871	7583 020681	ALEKSANDR BONDARENKO	{"phone": "+70445328525"}
0005432459532	6C2FF0	0841 605421	LARISA KUZMINA	{"email": "kuzminalarisa03031977@postgrespro.ru", "phone": "+70283302791"}
0005432459533	298C2C	4627 028852	EVGENIY SAVELEV	{"email": "evgeniy-savelev_041980@postgrespro.ru", "phone": "+70268207603"}
0005432459534	298C2C	8380 370757	ALEKSEY SOROKIN	{"email": "sorokina1975@postgrespro.ru", "phone": "+70289958484"}
0005432459535	20CF44	8594 252502	VIKTOR SOLOVEV	{"email": "solovev.viktor1978@postgrespro.ru", "phone": "+70787737434"}
0005432459536	20CF44	3567 799114	MARINA KOROLEVA	{"phone": "+70966250509"}
0005432459537	E3BE5E	4481 762733	LYUDMILA KUZNECOVA	{"phone": "+70721676606"}
0005432459538	E3BE5E	0573 972491	VENERA ORLOVA	{"phone": "+70312125088"}
0005432459539	58DC89	6482 966913	ILNUR KUZMIN	{"phone": "+70420166131"}
0005432459540	40071E	6651 465611	GALINA PETROVA	{"email": "petrova_g_1965@postgrespro.ru", "phone": "+70500797482"}
0005432459541	08F39C	2080 222947	NIKOLAY MAKAROV	{"email": "n.makarov111973@postgrespro.ru", "phone": "+70590752814"}
0005432459542	FD0D81	1974 251813	ALEKSEY ANDREEV	{"email": "andreev.a.1974@postgrespro.ru", "phone": "+70953618282"}
0005432459543	4B699F	3396 051006	FANIS BONDARENKO	{"email": "bondarenko-f-1965@postgrespro.ru", "phone": "+70952176423"}
0005432459544	4B699F	9734 106553	GULSINA FROLOVA	{"phone": "+70451996249"}
0005432459545	A9FE99	4840 300641	VLADIMIR MELNIKOV	{"email": "v_melnikov071976@postgrespro.ru", "phone": "+70186311661"}
0005432459546	E1794B	1523 728121	OLGA VOROBEVA	{"email": "olga-vorobeva_1965@postgrespro.ru", "phone": "+70631178859"}
0005432459547	E1794B	5399 367734	MARGARITA SOLOVEVA	{"phone": "+70785901102"}
0005432459548	E1794B	6531 970116	NATALYA SEMENOVA	{"phone": "+70580429679"}
0005432459549	D13D27	8440 881240	ELENA IVANOVA	{"email": "elena_ivanova081975@postgrespro.ru", "phone": "+70582108073"}
0005432459550	7839D4	5477 610178	NADEZHDA DENISOVA	{"phone": "+70506180121"}
0005432459551	7839D4	2920 549440	NELLYA BOGDANOVA	{"phone": "+70147775628"}
0005432459552	7839D4	5326 141027	KIRILL MARTYNOV	{"phone": "+70483756566"}
0005432459553	7839D4	0945 034936	MAKSIM CHERNOV	{"phone": "+70488610539"}
0005432459554	0ED4F1	1723 132211	ALEKSANDR DMITRIEV	{"phone": "+70841379858"}
0005432459555	5DB440	9290 378484	ALEKSEY NOVIKOV	{"email": "anovikov121964@postgrespro.ru", "phone": "+70842030752"}
0005432459556	037C13	5529 893131	ALEKSANDR ISAEV	{"email": "isaevaleksandr-061971@postgrespro.ru", "phone": "+70224758809"}
0005432459557	BE36E2	8847 768751	VALERIYA NIKITINA	{"phone": "+70839653632"}
0005432459558	AC7267	2392 515177	DMITRIY ZHUKOV	{"email": "zhukov_d-19011962@postgrespro.ru", "phone": "+70764712312"}
0005432459559	B196F6	9860 515940	TATYANA ERMAKOVA	{"phone": "+70222686861"}
0005432459560	B196F6	5913 571130	LYUDMILA FILATOVA	{"phone": "+70697813585"}
0005432459561	B196F6	5878 190715	ALEKSANDR VASILEV	{"email": "vasilev_a.1967@postgrespro.ru", "phone": "+70283441379"}
0005432459562	E84244	6840 545517	GENNADIY ILIN	{"phone": "+70198844556"}
0005432459563	E84244	1491 475813	ANASTASIYA NIKOLAEVA	{"email": "nikolaevaa_28101980@postgrespro.ru", "phone": "+70611006453"}
0005432459564	9240FE	3393 529530	KARINA FILATOVA	{"email": "filatovak-1962@postgrespro.ru", "phone": "+70208549105"}
0005432459565	9240FE	7977 731682	ANNA SEMENOVA	{"email": "semenova.anna_051975@postgrespro.ru", "phone": "+70965631637"}
0005432459566	54CE7E	3103 156748	IRINA VOLKOVA	{"email": "volkova_i17121961@postgrespro.ru", "phone": "+70109878953"}
0005432459567	54CE7E	0530 830071	OKSANA MIRONOVA	{"email": "o.mironova061963@postgrespro.ru", "phone": "+70032080860"}
0005432459733	4D66AD	1188 108897	ANATOLIY ALEKSANDROV	{"phone": "+70026585460"}
0005432459568	8F6511	3529 009509	VLADIMIR SAVELEV	{"email": "savelevv.27031973@postgrespro.ru", "phone": "+70790769516"}
0005432459569	E5CDB1	2938 403929	RAIL BORISOV	{"phone": "+70996504940"}
0005432459570	E5CDB1	2332 117504	VASILIY KOROLEV	{"email": "vkorolev_011973@postgrespro.ru", "phone": "+70760630487"}
0005432459571	ED2E8F	3090 963860	ANDREY MARTYNOV	{"phone": "+70552192693"}
0005432459572	ED2E8F	7430 151485	SERAFIMA TARASOVA	{"phone": "+70030924974"}
0005432459573	59E620	1039 169867	LYUDMILA ISAEVA	{"email": "lyudmila-isaeva_29081969@postgrespro.ru", "phone": "+70706530000"}
0005432459574	59E620	3227 474416	VENIAMIN IVANOV	{"email": "v_ivanov.02041974@postgrespro.ru", "phone": "+70207973780"}
0005432459575	E14BE0	3635 412360	VIKTORIYA KUZMINA	{"phone": "+70309110086"}
0005432459576	6D1432	7463 584888	IVAN ANDREEV	{"email": "andreev-ivan13021966@postgrespro.ru", "phone": "+70081489392"}
0005432459577	6D1432	5990 463546	ALEKSEY NAZAROV	{"phone": "+70438099713"}
0005432459578	5099CB	8834 962833	EKATERINA SEMENOVA	{"phone": "+70812210140"}
0005432459579	5099CB	9306 592063	DENIS ZHURAVLEV	{"phone": "+70725224289"}
0005432459580	CA482B	9470 963083	YURIY FROLOV	{"phone": "+70194800003"}
0005432459581	76ED38	8483 096322	NELYA NOVIKOVA	{"email": "nelyanovikova.13051975@postgrespro.ru", "phone": "+70218231928"}
0005432459582	7D6A60	8504 367959	TATYANA NIKOLAEVA	{"email": "tatyana_nikolaeva031965@postgrespro.ru", "phone": "+70646420581"}
0005432459583	B9BA75	8876 145187	ANATOLIY SCHERBAKOV	{"email": "scherbakov-a.1979@postgrespro.ru", "phone": "+70296165140"}
0005432459584	B9BA75	2878 341924	MIKHAIL STEPANOV	{"email": "stepanov-m_1965@postgrespro.ru", "phone": "+70490858826"}
0005432459585	B9BA75	9974 272153	VIKTORIYA VOROBEVA	{"email": "v_vorobeva.011978@postgrespro.ru", "phone": "+70385016336"}
0005432459586	2A9868	6195 143980	VALENTINA BELOVA	{"email": "belova_valentina_091972@postgrespro.ru", "phone": "+70852383152"}
0005432459587	2A9868	3279 880066	ALEKSANDR ZAKHAROV	{"email": "zakharov_a.011972@postgrespro.ru", "phone": "+70883792590"}
0005432459588	2A9868	6349 819474	MAKSIM DMITRIEV	{"email": "mdmitriev-17101967@postgrespro.ru", "phone": "+70192143534"}
0005432459589	DC193A	6740 754996	ALEKSANDR MAKSIMOV	{"email": "a-maksimov1979@postgrespro.ru", "phone": "+70428068599"}
0005432459590	7BCEA4	6431 993562	VIKTOR YAKOVLEV	{"email": "viktor-yakovlev.15061962@postgrespro.ru", "phone": "+70357217150"}
0005432459591	D729AE	1960 740513	NADEZHDA MAKSIMOVA	{"phone": "+70051029077"}
0005432459592	D729AE	3950 850544	OKSANA VASILEVA	{"email": "o-vasileva101972@postgrespro.ru", "phone": "+70422000882"}
0005432459593	7A8FFD	5192 964110	MARIYA TARASOVA	{"email": "tarasova.m-1967@postgrespro.ru", "phone": "+70717289349"}
0005432459594	0EF99C	1612 806261	ANNA LOGINOVA	{"phone": "+70310790730"}
0005432459595	6805D6	4136 716271	ELENA ROMANOVA	{"email": "elena.romanova.30101975@postgrespro.ru", "phone": "+70984165518"}
0005432459596	C03ADA	5790 326073	KIRILL KUZNECOV	{"email": "kuznecov-k_1973@postgrespro.ru", "phone": "+70864550238"}
0005432459597	055A5E	9318 856311	FEDOR SIDOROV	{"phone": "+70440655235"}
0005432459598	055A5E	7833 614242	VLADIMIR FROLOV	{"email": "frolovvladimir-051972@postgrespro.ru", "phone": "+70798163879"}
0005432459599	315874	3044 634246	NADEZHDA BORISOVA	{"phone": "+70881217938"}
0005432459600	E9587F	1672 703115	VALENTINA POPOVA	{"email": "v.popova.1968@postgrespro.ru", "phone": "+70046191558"}
0005432459601	792181	5011 833458	ANDREY MIKHAYLOV	{"email": "a-mikhaylov_051968@postgrespro.ru", "phone": "+70399382495"}
0005432459602	DA3C0B	6964 532975	TATYANA EFIMOVA	{"phone": "+70360088162"}
0005432459603	DA3C0B	2034 899506	TAMARA PETROVA	{"phone": "+70314292724"}
0005432459604	91A623	9977 200452	VERA MIRONOVA	{"email": "veramironova-011971@postgrespro.ru", "phone": "+70847944934"}
0005432459605	858618	4552 771624	VLADISLAV MATVEEV	{"email": "matveevv021974@postgrespro.ru", "phone": "+70863783108"}
0005432459606	18041E	8876 543428	RENATA AKIMOVA	{"email": "r-akimova_21051968@postgrespro.ru", "phone": "+70548493954"}
0005432459607	18041E	8421 996493	VIKTORIYA DMITRIEVA	{"email": "viktoriyadmitrieva_09101979@postgrespro.ru", "phone": "+70540745659"}
0005432459608	E0C437	8601 527136	DMITRIY NAUMOV	{"email": "d_naumov051973@postgrespro.ru", "phone": "+70631849618"}
0005432459609	E0C437	5619 332551	LARISA MIRONOVA	{"email": "mironovalarisa-051981@postgrespro.ru", "phone": "+70497688472"}
0005432459610	F00E3D	6387 868628	ALEKSANDR BELOV	{"email": "belov-a1966@postgrespro.ru", "phone": "+70005836095"}
0005432459611	F00E3D	8218 695084	VLADIMIR SCHERBAKOV	{"phone": "+70132686259"}
0005432459612	F00E3D	1471 456638	LARISA ABRAMOVA	{"email": "abramova-larisa-1981@postgrespro.ru", "phone": "+70456314155"}
0005432459613	1D91D3	3947 129688	TAMARA CHERNOVA	{"phone": "+70480376178"}
0005432459614	F75AB7	0611 153193	ALEKSANDRA KUZNECOVA	{"email": "a.kuznecova-09071966@postgrespro.ru", "phone": "+70688567009"}
0005432459615	F75AB7	9885 979981	MIKHAIL TARASOV	{"phone": "+70867263196"}
0005432459616	495802	8564 950219	TATYANA SOROKINA	{"email": "tsorokina_061975@postgrespro.ru", "phone": "+70864004796"}
0005432459617	1CA271	9518 003965	MARINA NIKOLAEVA	{"email": "nikolaevamarina24051967@postgrespro.ru", "phone": "+70476357916"}
0005432459618	7A77E1	2331 765380	ELENA EGOROVA	{"email": "elena-egorova.1973@postgrespro.ru", "phone": "+70907465321"}
0005432459619	3B43AA	0212 486174	VIKTOR TARASOV	{"email": "vtarasov.1973@postgrespro.ru", "phone": "+70539929401"}
0005432459620	7567A9	7098 086770	SERGEY KUZNECOV	{"email": "kuznecov-sergey.031960@postgrespro.ru", "phone": "+70390872068"}
0005432459621	7567A9	9871 309193	ZHANNA VASILEVA	{"email": "vasileva-z-011967@postgrespro.ru", "phone": "+70480537429"}
0005432459622	68718D	6215 221388	IVAN FILIPPOV	{"email": "filippovi.1979@postgrespro.ru", "phone": "+70804037875"}
0005432459623	68718D	6375 859107	RAIS ILIN	{"email": "ilinr1971@postgrespro.ru", "phone": "+70930044895"}
0005432459624	B7CA41	6691 527888	ALINA ILINA	{"email": "alinailina31011965@postgrespro.ru", "phone": "+70707547200"}
0005432459625	9C9065	9369 908031	EGOR ALEKSANDROV	{"email": "e-aleksandrov-061979@postgrespro.ru", "phone": "+70987609822"}
0005432459626	9C9065	3065 206317	MARIYA SIDOROVA	{"email": "mariyasidorova_121979@postgrespro.ru", "phone": "+70533002319"}
0005432459627	12B43D	0632 051466	MARIYA GERASIMOVA	{"email": "gerasimova.mariya-14071971@postgrespro.ru", "phone": "+70115743648"}
0005432459628	DBE567	5151 384353	EVGENIY KISELEV	{"email": "kiselev.e02051963@postgrespro.ru", "phone": "+70070660842"}
0005432459629	572F67	7644 740076	OLGA MARTYNOVA	{"phone": "+70679570757"}
0005432459630	EF74CB	2107 808212	DMITRIY SMIRNOV	{"phone": "+70591314396"}
0005432459631	EF74CB	6570 601178	EVGENIY BORISOV	{"email": "evgeniy_borisov.1965@postgrespro.ru", "phone": "+70404595234"}
0005432459632	EF74CB	7009 020030	ARINA FILIPPOVA	{"email": "filippova-a_1964@postgrespro.ru", "phone": "+70045719787"}
0005432459633	61819C	8793 068526	VALENTIN ANTONOV	{"phone": "+70415171797"}
0005432459634	61819C	3915 443179	VLADIMIR KULIKOV	{"phone": "+70981393588"}
0005432459635	61819C	9682 991210	SERGEY NAZAROV	{"email": "nazarov_sergey-1961@postgrespro.ru", "phone": "+70122395213"}
0005432459636	BBB207	5479 695627	ALEKSEY SERGEEV	{"phone": "+70550058263"}
0005432459637	7E31B9	7829 142366	EKATERINA STEPANOVA	{"email": "stepanova-e101962@postgrespro.ru", "phone": "+70909519431"}
0005432459638	7E31B9	8885 374106	MARIYA FOMINA	{"phone": "+70676044093"}
0005432459639	D17DF9	4600 384423	OLGA NIKITINA	{"email": "nikitina.olga-12121976@postgrespro.ru", "phone": "+70248164971"}
0005432459640	D17DF9	4041 139144	IRINA SEMENOVA	{"phone": "+70797687297"}
0005432459641	D17DF9	9221 414868	RAFAIL POPOV	{"email": "rafail.popov1962@postgrespro.ru", "phone": "+70073729419"}
0005432459642	9E4161	6078 607625	EVGENIY VOLKOV	{"phone": "+70588612259"}
0005432459643	9E4161	5729 544998	NATALYA DENISOVA	{"email": "natalya.denisova-1980@postgrespro.ru", "phone": "+70728260718"}
0005432459644	8DA7EC	3547 286359	VIKTOR SCHERBAKOV	{"email": "viktor.scherbakov_29121976@postgrespro.ru", "phone": "+70732914416"}
0005432459645	BD8AF2	8876 389090	ANDREY CHERNOV	{"phone": "+70357782836"}
0005432459646	823E6F	1016 836132	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov.1971@postgrespro.ru", "phone": "+70013053429"}
0005432459647	C30FBE	7784 088962	NAILYA VOLKOVA	{"phone": "+70357767177"}
0005432459648	C30FBE	9131 074971	ALENA EGOROVA	{"email": "egorovaa-22021968@postgrespro.ru", "phone": "+70340407619"}
0005432459649	E3C47A	9001 375043	POLINA PAVLOVA	{"phone": "+70603166277"}
0005432459650	E3C47A	5685 035792	VSEVOLOD ANTONOV	{"email": "antonov_v_021971@postgrespro.ru", "phone": "+70201465019"}
0005432459651	98C88C	2855 572162	ANDREY SERGEEV	{"phone": "+70310359070"}
0005432459652	4678AD	7021 935345	ARSENIY NOVIKOV	{"phone": "+70177184998"}
0005432459653	4678AD	1242 953642	ALEKSEY MATVEEV	{"email": "matveev.aleksey-29021972@postgrespro.ru", "phone": "+70382972470"}
0005432459654	87013A	3675 929151	IRINA LAZAREVA	{"email": "irina_lazareva.1965@postgrespro.ru", "phone": "+70427893889"}
0005432459655	87013A	5148 620853	LYUBOV MELNIKOVA	{"phone": "+70724772907"}
0005432459656	466E31	4263 403984	OLEG KOZLOV	{"phone": "+70215828846"}
0005432459657	912402	2589 065007	VYACHESLAV ALEKSANDROV	{"email": "vyacheslav.aleksandrov1967@postgrespro.ru", "phone": "+70880437683"}
0005432459658	912402	1667 194483	LARISA KUZNECOVA	{"phone": "+70610078797"}
0005432459659	93690B	1886 293132	OLEG SHEVCHENKO	{"phone": "+70690298364"}
0005432459660	BBDE76	8712 041504	ANNA RODIONOVA	{"phone": "+70841407940"}
0005432459661	BBDE76	0908 526295	LYUDMILA PETROVA	{"phone": "+70097216350"}
0005432459662	15AB39	1662 000185	MIKHAIL MAKAROV	{"phone": "+70666306505"}
0005432459663	15AB39	2703 800207	MARIYA KARPOVA	{"phone": "+70574625752"}
0005432459664	E63315	6750 746901	NIKITA KUZNECOV	{"email": "nikita.kuznecov-1988@postgrespro.ru", "phone": "+70653013794"}
0005432459665	B8B454	0159 443495	IRINA ILINA	{"email": "irina_ilina-1969@postgrespro.ru", "phone": "+70988751281"}
0005432459666	B8B454	8106 124283	NATALYA ZAKHAROVA	{"email": "zakharova_n_071983@postgrespro.ru", "phone": "+70086090769"}
0005432459667	B8B454	4665 203504	ALEKSANDR MIKHAYLOV	{"phone": "+70189040053"}
0005432459668	B0CFBA	4024 278139	ELENA ZHURAVLEVA	{"phone": "+70943628256"}
0005432459669	B0CFBA	0929 856509	STEPAN CHERNOV	{"phone": "+70364687646"}
0005432459670	0DF9DE	2170 150840	LYUDMILA MATVEEVA	{"email": "matveeva_l.17101975@postgrespro.ru", "phone": "+70687477521"}
0005432459671	0DF9DE	4118 906116	MARIYA RYABOVA	{"email": "ryabovam_1962@postgrespro.ru", "phone": "+70158532130"}
0005432459672	99A35F	4536 065802	OLGA GERASIMOVA	{"phone": "+70110491264"}
0005432459673	E3742B	8494 271309	OLGA SOLOVEVA	{"email": "olgasoloveva_021973@postgrespro.ru", "phone": "+70218709207"}
0005432459674	E3742B	6823 437436	VALERIY VASILEV	{"email": "vasilev.valeriy30041976@postgrespro.ru", "phone": "+70137400589"}
0005432459675	E3742B	2793 864628	ILYA NAUMOV	{"email": "naumov.ilya-22091979@postgrespro.ru", "phone": "+70840484805"}
0005432459676	A1E2F5	4418 075440	KSENIYA TROFIMOVA	{"email": "kseniyatrofimova_06021978@postgrespro.ru", "phone": "+70228607405"}
0005432459677	A1E2F5	1160 951608	VALENTINA SCHERBAKOVA	{"email": "v.scherbakova_03081958@postgrespro.ru", "phone": "+70200141323"}
0005432459678	0913C3	4020 866828	LYUDMILA AFANASEVA	{"email": "afanaseva_lyudmila.03121960@postgrespro.ru", "phone": "+70279847444"}
0005432459679	B69985	6548 256450	ANASTASIYA BORISOVA	{"email": "a-borisova_061971@postgrespro.ru", "phone": "+70275363764"}
0005432459680	A35FAD	7043 233298	SULTAN VOLKOV	{"email": "volkovsultan-28091972@postgrespro.ru", "phone": "+70832782927"}
0005432459681	A35FAD	2822 352791	EVGENIYA ERMAKOVA	{"email": "eermakova-1983@postgrespro.ru", "phone": "+70908428451"}
0005432459682	2B7A66	0738 655503	ANDREY SCHERBAKOV	{"email": "a.scherbakov1974@postgrespro.ru", "phone": "+70027239578"}
0005432459683	DBF5FF	4315 965804	ELENA EFIMOVA	{"phone": "+70152075765"}
0005432459684	AB9643	3919 469630	MIKHAIL MOISEEV	{"phone": "+70677360294"}
0005432459685	AB9643	7869 865637	ANNA NAUMOVA	{"phone": "+70713717675"}
0005432459686	983820	3386 161791	IVAN DAVYDOV	{"email": "ivan.davydov.061978@postgrespro.ru", "phone": "+70898582652"}
0005432459687	983820	2341 524953	VIKTOR ZAYCEV	{"email": "zaycev.v_021971@postgrespro.ru", "phone": "+70156722887"}
0005432459688	FF48A1	6152 330029	TATYANA FILIPPOVA	{"email": "tatyanafilippova.23031967@postgrespro.ru", "phone": "+70332998021"}
0005432459689	67B803	2791 170294	SVETLANA SOKOLOVA	{"phone": "+70938359715"}
0005432459690	67B803	6904 584068	MARGARITA KUDRYASHOVA	{"email": "m.kudryashova.20061974@postgrespro.ru", "phone": "+70106952434"}
0005432459691	873778	3941 354454	OLGA MATVEEVA	{"phone": "+70949138346"}
0005432459692	64C011	1255 866048	NATALYA TITOVA	{"email": "titova-natalya-04111985@postgrespro.ru", "phone": "+70738545544"}
0005432459693	64C011	6623 225304	SVETLANA FROLOVA	{"email": "frolova-svetlana_061971@postgrespro.ru", "phone": "+70310248351"}
0005432459694	7EBABE	3652 866319	SVETLANA ANTONOVA	{"phone": "+70908444371"}
0005432459695	7EBABE	5914 020632	GALINA VASILEVA	{"phone": "+70570818667"}
0005432459696	BDACCA	3793 660459	ALEKSANDR NOVIKOV	{"phone": "+70249924792"}
0005432459697	4C03BC	9240 932513	IRINA EFIMOVA	{"email": "i-efimova_02091963@postgrespro.ru", "phone": "+70565844695"}
0005432459698	4C03BC	6603 176300	OLEG ILIN	{"phone": "+70356488158"}
0005432459699	4C03BC	4378 984886	DMITRIY ALEKSANDROV	{"email": "dmitriy-aleksandrov081977@postgrespro.ru", "phone": "+70912308942"}
0005432459700	A94BD9	0700 373906	NATALYA ANDREEVA	{"email": "natalyaandreeva.091977@postgrespro.ru", "phone": "+70815569969"}
0005432459701	37CD32	1041 836845	NATALYA VASILEVA	{"email": "n-vasileva10031967@postgrespro.ru", "phone": "+70396995844"}
0005432459702	37CD32	2496 724630	MARIYA VASILEVA	{"email": "mariya.vasileva.071969@postgrespro.ru", "phone": "+70836588324"}
0005432459703	37CD32	3861 795575	ALEKSANDR MIRONOV	{"email": "a_mironov.111985@postgrespro.ru", "phone": "+70445985232"}
0005432459704	B89A25	7205 460410	IRINA MOROZOVA	{"email": "i.morozova-1979@postgrespro.ru", "phone": "+70197223763"}
0005432459705	17E760	6510 454303	OLGA PAVLOVA	{"phone": "+70612500628"}
0005432459706	BBECC8	1198 620485	NIKOLAY FROLOV	{"email": "n-frolov1969@postgrespro.ru", "phone": "+70156665077"}
0005432459707	BBECC8	4106 294717	LILIYA IVANOVA	{"email": "l-ivanova26101970@postgrespro.ru", "phone": "+70276165658"}
0005432459708	4FDF2C	4860 126207	YULIYA NIKOLAEVA	{"email": "nikolaeva_y-21011969@postgrespro.ru", "phone": "+70005444846"}
0005432459709	4FDF2C	5026 164691	IVAN PETROV	{"email": "petrov_ivan_101970@postgrespro.ru", "phone": "+70756969229"}
0005432459710	FB914F	7851 697945	IGOR BORISOV	{"email": "igorborisov-111975@postgrespro.ru", "phone": "+70538130821"}
0005432459711	FB914F	0202 044634	ALENA PAVLOVA	{"email": "a.pavlova091985@postgrespro.ru", "phone": "+70056560124"}
0005432459712	FB914F	4468 320571	ALEKSANDR FROLOV	{"email": "a.frolov.10021985@postgrespro.ru", "phone": "+70534689380"}
0005432459713	35281F	8664 181857	IRINA KAZAKOVA	{"email": "kazakova-i_101979@postgrespro.ru", "phone": "+70232966419"}
0005432459714	14758A	1306 232038	RUSTYAM SCHERBAKOV	{"email": "r_scherbakov_1975@postgrespro.ru", "phone": "+70131687398"}
0005432459715	14758A	5262 164684	MARYAM SAVELEVA	{"email": "maryam-saveleva.051972@postgrespro.ru", "phone": "+70518864762"}
0005432459716	C79B42	4018 478672	KSENIYA BOGDANOVA	{"phone": "+70463139965"}
0005432459717	C79B42	9059 652880	POLINA MAKAROVA	{"phone": "+70303646827"}
0005432459718	C55B87	3251 100766	LYUBOV POTAPOVA	{"email": "potapovalyubov-02031969@postgrespro.ru", "phone": "+70808689370"}
0005432459719	D3160B	2534 167636	GALINA ZOTOVA	{"phone": "+70288070143"}
0005432459720	988B0A	2105 058591	VIKTOR MAKAROV	{"phone": "+70945425369"}
0005432459721	FFB91D	2672 709025	VERONIKA MOROZOVA	{"phone": "+70842616023"}
0005432459722	59F652	4682 641254	RAISA SERGEEVA	{"phone": "+70384778252"}
0005432459723	59F652	2998 795522	MAKSIM SEMENOV	{"email": "semenovmaksim-08021963@postgrespro.ru", "phone": "+70582996562"}
0005432459724	10D986	7038 254340	VALENTINA SERGEEVA	{"email": "v-sergeeva-051965@postgrespro.ru", "phone": "+70979457327"}
0005432459725	70BD73	0688 599937	ALEKSANDR SEMENOV	{"phone": "+70305692117"}
0005432459726	70BD73	2914 408924	ELIZAVETA SAVELEVA	{"phone": "+70196518145"}
0005432459727	70BD73	2792 109053	IRINA FEDOROVA	{"phone": "+70480141799"}
0005432459728	286519	9276 102759	MARGARITA KOROLEVA	{"email": "koroleva_m-16021973@postgrespro.ru", "phone": "+70034055494"}
0005432459729	7EBB26	4863 154205	VALENTINA ZAKHAROVA	{"email": "zakharovavalentina.05041989@postgrespro.ru", "phone": "+70511001200"}
0005432459730	B36AE5	7493 512593	NADEZHDA MIKHAYLOVA	{"email": "n-mikhaylova1977@postgrespro.ru", "phone": "+70503587645"}
0005432459731	B416EC	1819 583013	ALIYA EFIMOVA	{"phone": "+70095603800"}
0005432459732	4D66AD	0444 245673	NINA KRASNOVA	{"email": "n_krasnova.1979@postgrespro.ru", "phone": "+70145427004"}
0005432459734	853E78	5322 853449	YULIYA ARKHIPOVA	{"email": "yuliya_arkhipova_30031973@postgrespro.ru", "phone": "+70425418044"}
0005432459735	C7E29B	5320 446573	TATYANA KOROLEVA	{"phone": "+70749817300"}
0005432459736	60ED2B	8733 132849	VALENTINA ZAYCEVA	{"email": "zayceva_valentina-041976@postgrespro.ru", "phone": "+70794056631"}
0005432459737	383D5F	5928 338147	ALEKSANDR STEPANOV	{"email": "stepanov-a_1983@postgrespro.ru", "phone": "+70979238918"}
0005432459738	383D5F	9226 409378	ELIZAVETA KOZLOVA	{"email": "ekozlova021974@postgrespro.ru", "phone": "+70600487307"}
0005432459739	383D5F	0098 972624	ANDREY BARANOV	{"email": "a_baranov.13031976@postgrespro.ru", "phone": "+70375597816"}
0005432459740	471C9F	6184 210314	NINA CHERNOVA	{"email": "nina_chernova1967@postgrespro.ru", "phone": "+70280600913"}
0005432459741	982302	1968 859862	ALEKSEY FROLOV	{"email": "frolov.aleksey_041976@postgrespro.ru", "phone": "+70851142322"}
0005432459742	61ED9D	1328 088521	VYACHESLAV KUZNECOV	{"phone": "+70619266088"}
0005432459743	69611E	0410 272105	ANATOLIY KRASNOV	{"phone": "+70631573301"}
0005432459744	E1CA15	0131 535462	IVAN PETROV	{"phone": "+70427534347"}
0005432459745	DFEDC9	8019 256001	ANDREY VOLKOV	{"email": "andrey-volkov.10031972@postgrespro.ru", "phone": "+70727035131"}
0005432459746	8BD0D7	8556 780566	GRIGORIY FEDOROV	{"phone": "+70219490979"}
0005432459747	FF362D	8371 403715	VALENTINA MOROZOVA	{"phone": "+70603931153"}
0005432459748	4944BA	2269 108421	MAKSIM TARASOV	{"phone": "+70194632085"}
0005432459749	113159	2139 807714	NINA ZHUKOVA	{"phone": "+70956672373"}
0005432459750	D479C3	6777 234850	ALEKSEY GORBUNOV	{"email": "aleksey.gorbunov.03011981@postgrespro.ru", "phone": "+70392884426"}
0005432459751	D10B54	7913 820202	MIKHAIL NIKITIN	{"email": "nikitin_mikhail_1972@postgrespro.ru", "phone": "+70481381249"}
0005432459752	5930A1	8158 081995	LYUBOV NAZAROVA	{"email": "nazarova.lyubov19071973@postgrespro.ru", "phone": "+70407563778"}
0005432459753	DA483E	1125 931960	VIKTOR IVANOV	{"email": "ivanov-v.101977@postgrespro.ru", "phone": "+70149975466"}
0005432459754	B0D275	7755 444296	VERA TITOVA	{"email": "v-titova_091976@postgrespro.ru", "phone": "+70626938597"}
0005432459755	8C3E06	9716 908541	MATVEY IVANOV	{"email": "ivanov_matvey-1968@postgrespro.ru", "phone": "+70792044435"}
0005432459756	DA4960	5329 021904	EKATERINA ZAKHAROVA	{"email": "e-zakharova061975@postgrespro.ru", "phone": "+70241125381"}
0005432459757	B84F14	6080 736065	DMITRIY OSIPOV	{"email": "dosipov-08031966@postgrespro.ru", "phone": "+70764092410"}
0005432459758	BFED3C	8485 826389	SVETLANA MOROZOVA	{"phone": "+70299675420"}
0005432459759	0101FF	2831 900635	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.15041964@postgrespro.ru", "phone": "+70117062279"}
0005432459760	0101FF	1602 285816	ALEKSANDR POPOV	{"email": "popov.aleksandr_071973@postgrespro.ru", "phone": "+70834680206"}
0005432459761	0468C0	9353 090543	EKATERINA KALININA	{"email": "kalininaekaterina19121964@postgrespro.ru", "phone": "+70777673214"}
0005432459762	ACEBA3	0453 496993	ALEKSEY SEMENOV	{"email": "semenovaleksey_101980@postgrespro.ru", "phone": "+70308566799"}
0005432459763	D2AD12	8226 694309	ALEKSEY SCHERBAKOV	{"phone": "+70754840979"}
0005432459764	76CBC3	2242 099444	VASILISA ORLOVA	{"phone": "+70258136298"}
0005432459765	76CBC3	5579 617611	KIRA PETROVA	{"phone": "+70116537275"}
0005432459766	1FBD59	4629 132982	DIANA IVANOVA	{"phone": "+70318412807"}
0005432459767	3DA591	2488 350654	IVAN DENISOV	{"phone": "+70126912183"}
0005432459768	3DA591	0172 660046	KLAVDIYA KOROLEVA	{"phone": "+70102452584"}
0005432459769	39202D	9415 570530	TATYANA ANISIMOVA	{"phone": "+70102666994"}
0005432459770	39202D	7308 493323	VYACHESLAV SOLOVEV	{"phone": "+70244338246"}
0005432459771	DCABD2	6229 499704	SVETLANA KONOVALOVA	{"phone": "+70488214952"}
0005432459772	B232B6	4239 541339	GALINA GRISHINA	{"phone": "+70597220992"}
0005432459773	6C7D30	7597 671305	DMITRIY ILIN	{"phone": "+70948775157"}
0005432459774	EC5FDD	7337 623680	NIKOLAY POPOV	{"phone": "+70001455177"}
0005432459775	33BB4D	4461 427443	ALEKSEY VOLKOV	{"phone": "+70003146232"}
0005432459776	33BB4D	7616 960014	DMITRIY PETROV	{"email": "petrov.d-031969@postgrespro.ru", "phone": "+70205799796"}
0005432459777	3A24DB	4893 804190	SOFYA KONOVALOVA	{"email": "sofya-konovalova-1978@postgrespro.ru", "phone": "+70953054479"}
0005432459778	DAF038	2256 869188	YULIYA ZHUKOVA	{"phone": "+70611319364"}
0005432459779	7EF235	7598 155905	ELENA STEPANOVA	{"phone": "+70772098869"}
0005432459780	C281C6	6113 916677	VLADIMIR ANTONOV	{"email": "v_antonov.11111971@postgrespro.ru", "phone": "+70510148353"}
0005432459781	45C0E7	7948 424724	ALEKSANDRA PETROVA	{"phone": "+70752875544"}
0005432459782	45C0E7	9244 755968	OLGA NAUMOVA	{"phone": "+70337235088"}
0005432459783	1B2C4E	3149 154132	OLESYA MATVEEVA	{"phone": "+70986855965"}
0005432459784	1B2C4E	8513 491610	SERGEY VASILEV	{"email": "sergey.vasilev.18051973@postgrespro.ru", "phone": "+70309337869"}
0005432459785	2CBBC6	0992 384614	DARYA KOZLOVA	{"phone": "+70239405887"}
0005432459786	2CBBC6	1345 748812	EVGENIY GORBUNOV	{"email": "evgeniy_gorbunov-071974@postgrespro.ru", "phone": "+70254858975"}
0005432459787	C339A0	9253 844791	YULIYA ILINA	{"phone": "+70605241723"}
0005432459788	2B5992	8963 737807	SERGEY BELOV	{"phone": "+70784909034"}
0005432459789	08E6AD	7996 801452	ANTON MELNIKOV	{"phone": "+70238253757"}
0005432459790	26FBBA	6470 909851	NIKOLAY EGOROV	{"email": "nikolay-egorov_1965@postgrespro.ru", "phone": "+70135979251"}
0005432459791	619365	5720 893876	IRINA ALEKSANDROVA	{"phone": "+70151794210"}
0005432459792	ECE78E	1311 003655	OLGA POPOVA	{"phone": "+70390641627"}
0005432459793	ECE78E	6737 758877	MARIYA LOGINOVA	{"phone": "+70643028514"}
0005432459794	04D9B9	1963 393785	ARTEM MARTYNOV	{"phone": "+70823961299"}
0005432459795	0519C4	3467 478690	SVETLANA MEDVEDEVA	{"phone": "+70341138652"}
0005432459796	A842B0	8193 780593	VYACHESLAV SCHERBAKOV	{"phone": "+70299698543"}
0005432459797	A842B0	9427 998092	SVETLANA KULIKOVA	{"phone": "+70559931008"}
0005432459798	A842B0	7109 649465	VLADIMIR FROLOV	{"phone": "+70238908256"}
0005432459799	66F89D	1945 062492	IVAN NAUMOV	{"phone": "+70714694863"}
0005432459800	CFA783	7862 883772	NATALYA KOZLOVA	{"email": "nkozlova.1970@postgrespro.ru", "phone": "+70477387697"}
0005432459801	CFA783	7239 108971	NIKITA ALEKSEEV	{"email": "alekseev-nikita.01061980@postgrespro.ru", "phone": "+70176437730"}
0005432459802	1AF5E5	1342 257587	ELENA SCHERBAKOVA	{"email": "e-scherbakova071976@postgrespro.ru", "phone": "+70856926152"}
0005432459803	BBC3D4	4658 392617	ANATOLIY KAZAKOV	{"email": "anatoliy.kazakov.27121976@postgrespro.ru", "phone": "+70341175679"}
0005432459804	58459D	8998 375416	GENNADIY GERASIMOV	{"phone": "+70240823060"}
0005432459805	58459D	9940 956915	RUSLAN PAVLOV	{"phone": "+70269726549"}
0005432459806	58459D	6042 112000	NATALYA ROMANOVA	{"phone": "+70331097929"}
0005432459807	49C65C	5195 700700	SERGEY DENISOV	{"phone": "+70800488219"}
0005432459808	713066	4462 378814	DMITRIY MELNIKOV	{"email": "melnikov_dmitriy1974@postgrespro.ru", "phone": "+70388888869"}
0005432459809	9FD35B	9569 542317	MIKHAIL NIKOLAEV	{"phone": "+70942540384"}
0005432459810	A10190	4039 111104	ELENA LOGINOVA	{"email": "elenaloginova.1970@postgrespro.ru", "phone": "+70537731828"}
0005432459811	A10190	0633 807073	PAVEL DENISOV	{"email": "p-denisov29031973@postgrespro.ru", "phone": "+70151120238"}
0005432459812	A10190	8439 089113	ALEKSANDR KARPOV	{"email": "karpova021976@postgrespro.ru", "phone": "+70685100983"}
0005432459813	E96D22	3100 415799	ELENA SIDOROVA	{"phone": "+70617287161"}
0005432459814	2FB7F3	7659 563324	DENIS KONOVALOV	{"email": "d-konovalov-19111969@postgrespro.ru", "phone": "+70719346496"}
0005432459815	2FB7F3	8394 032822	SVETLANA BELYAEVA	{"email": "s.belyaeva_1970@postgrespro.ru", "phone": "+70965671922"}
0005432459816	AAAC56	4959 363836	LYUBOV MELNIKOVA	{"email": "melnikova-l071986@postgrespro.ru", "phone": "+70590782501"}
0005432459817	A10A99	0659 683192	SERGEY SOROKIN	{"phone": "+70847819972"}
0005432459818	A10A99	0921 863683	NATALYA VOLKOVA	{"email": "volkovanatalya_06041978@postgrespro.ru", "phone": "+70524849446"}
0005432459819	2F8C5E	9703 583175	ANVAR MATVEEV	{"email": "a.matveev.121986@postgrespro.ru", "phone": "+70838096060"}
0005432459820	46ED55	3507 059357	IRINA VASILEVA	{"phone": "+70962014392"}
0005432459821	582F83	6944 710626	MAKSIM SMIRNOV	{"email": "smirnov.maksim071982@postgrespro.ru", "phone": "+70539283994"}
0005432459822	442810	4300 642231	SERGEY NIKOLAEV	{"email": "s.nikolaev1969@postgrespro.ru", "phone": "+70770673124"}
0005432459823	442810	5036 678821	IRINA CHERNOVA	{"phone": "+70982002281"}
0005432459824	AE22E4	8403 427364	DMITRIY KRASNOV	{"phone": "+70743773176"}
0005432459825	AE22E4	8390 453490	TAISA ZAKHAROVA	{"phone": "+70356521055"}
0005432459826	0BB046	1293 650741	OLEG KUZNECOV	{"email": "o-kuznecov111986@postgrespro.ru", "phone": "+70143150918"}
0005432459827	D69E3A	8412 589808	SAMIR CHERNOV	{"email": "s_chernov.06091978@postgrespro.ru", "phone": "+70938512859"}
0005432459828	6BFD5A	6534 222738	MAKSIM FEDOROV	{"email": "m_fedorov-1973@postgrespro.ru", "phone": "+70303564901"}
0005432459829	66049D	3175 122613	VASILIY MELNIKOV	{"email": "melnikovvasiliy-09121967@postgrespro.ru", "phone": "+70282004556"}
0005432459830	193184	4276 024459	ALBINA MOISEEVA	{"email": "moiseeva_albina_091969@postgrespro.ru", "phone": "+70497230360"}
0005432459831	193184	9209 436150	SERGEY POPOV	{"phone": "+70016429383"}
0005432459832	F23B6B	9341 712347	IVAN MAKAROV	{"phone": "+70505524949"}
0005432459833	F5193E	1269 501410	IRINA MATVEEVA	{"phone": "+70113339228"}
0005432459834	F5193E	6492 892583	GALINA EFREMOVA	{"email": "galina.efremova_19021993@postgrespro.ru", "phone": "+70976567940"}
0005432459835	1AC886	6230 303415	EVGENIY KUZNECOV	{"phone": "+70996203364"}
0005432459836	93F176	4503 466892	YULIYA DAVYDOVA	{"email": "davydova.y_1969@postgrespro.ru", "phone": "+70813936221"}
0005432459837	E263FA	8976 684547	OLGA SAVELEVA	{"phone": "+70726863362"}
0005432459838	0C34BB	6847 583775	DENIS ABRAMOV	{"email": "denisabramov-28041967@postgrespro.ru", "phone": "+70414839833"}
0005432459839	C138F5	9019 020627	YURIY KARPOV	{"email": "yuriy-karpov_1983@postgrespro.ru", "phone": "+70679088895"}
0005432459840	54A9D0	2428 041891	ALEKSANDR BORISOV	{"phone": "+70175776718"}
0005432459841	AE71C2	9861 149899	EKATERINA ALEKSEEVA	{"email": "alekseevae1970@postgrespro.ru", "phone": "+70319180659"}
0005432459842	C627B0	0569 886852	VASILIY PAVLOV	{"phone": "+70208938138"}
0005432459843	C627B0	4061 460590	TATYANA ANISIMOVA	{"email": "anisimova_tatyana_29111970@postgrespro.ru", "phone": "+70105955258"}
0005432459844	1B3A8F	4254 444045	ELENA KISELEVA	{"email": "kiseleva_elena.20111973@postgrespro.ru", "phone": "+70558238011"}
0005432459845	BF2726	7998 034666	ANNA KOZLOVA	{"phone": "+70023135711"}
0005432459846	99513B	6693 933284	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr121971@postgrespro.ru", "phone": "+70575948406"}
0005432459847	99513B	4008 043800	ELENA BORISOVA	{"phone": "+70030146155"}
0005432459848	99513B	2011 088554	ALEKSANDR RODIONOV	{"email": "a_rodionov-25081966@postgrespro.ru", "phone": "+70102002712"}
0005432459849	99513B	0867 459187	MARIYA DAVYDOVA	{"email": "mariya_davydova.071971@postgrespro.ru", "phone": "+70025581071"}
0005432459850	20201C	5720 918655	ALEKSANDR DAVYDOV	{"phone": "+70710370540"}
0005432459851	F4D468	2297 477332	IVAN KISELEV	{"phone": "+70386784889"}
0005432459852	C00AE2	4557 834587	VLADIMIR IVANOV	{"email": "ivanov.v.1974@postgrespro.ru", "phone": "+70325901387"}
0005432459853	2C5440	1707 918188	YURIY KOZLOV	{"phone": "+70236842765"}
0005432459854	DB5477	3589 014201	PETR TIMOFEEV	{"email": "timofeevpetr.081973@postgrespro.ru", "phone": "+70421083372"}
0005432459855	DB5477	7772 419069	EKATERINA KOZLOVA	{"email": "e_kozlova30051962@postgrespro.ru", "phone": "+70607339408"}
0005432459856	7EF6BE	6352 162639	IVAN ZAYCEV	{"phone": "+70808551875"}
0005432459857	5C42B4	3663 126989	VLADIMIR NAZAROV	{"email": "v.nazarov-1969@postgrespro.ru", "phone": "+70629253436"}
0005432459858	ACB53E	5969 161906	DENIS AFANASEV	{"email": "afanasev.d.071971@postgrespro.ru", "phone": "+70380542591"}
0005432459859	1385F9	6426 297532	ELENA KUZMINA	{"email": "kuzmina-elena_111972@postgrespro.ru", "phone": "+70935045604"}
0005432459860	1F131D	8694 682750	OLEG PAVLOV	{"email": "pavlov_o03051977@postgrespro.ru", "phone": "+70087214001"}
0005432459861	1F131D	2861 883968	MIKHAIL KOZLOV	{"email": "kozlov.mikhail_1973@postgrespro.ru", "phone": "+70243928104"}
0005432459862	353301	8569 402673	ANATOLIY VLASOV	{"email": "vlasov-a_31031967@postgrespro.ru", "phone": "+70534714789"}
0005432459863	FE3BD0	4208 425902	KARINA ERMAKOVA	{"phone": "+70132919192"}
0005432459864	A7452B	1551 566480	VASILIY SEMENOV	{"phone": "+70439886212"}
0005432459865	A7452B	7529 134837	VLADIMIR KOROLEV	{"phone": "+70687417127"}
0005432459866	A7452B	0586 786589	LYUBOV FEDOROVA	{"email": "lyubov.fedorova1978@postgrespro.ru", "phone": "+70617683023"}
0005432459867	889C0A	4504 610853	ZHANNA ERMAKOVA	{"phone": "+70686819472"}
0005432459868	10CB2C	9206 791547	LYUBOV GORBUNOVA	{"phone": "+70476864920"}
0005432459869	AB22AA	0941 812308	DMITRIY FOMIN	{"email": "fomin.d-09021984@postgrespro.ru", "phone": "+70680142103"}
0005432459870	11D935	9632 452017	ALEKSANDR MIKHAYLOV	{"phone": "+70021170293"}
0005432459871	15F47A	5380 972431	SVETLANA POPOVA	{"phone": "+70784859023"}
0005432459872	D557C8	7707 460044	ANDREY FILIPPOV	{"email": "filippova.081973@postgrespro.ru", "phone": "+70691005494"}
0005432459873	362706	4717 910321	VLADISLAV RODIONOV	{"email": "v_rodionov.23111972@postgrespro.ru", "phone": "+70528231141"}
0005432459874	362706	1848 840069	KONSTANTIN BARANOV	{"email": "baranov-konstantin.1967@postgrespro.ru", "phone": "+70068326512"}
0005432459875	A68A87	6373 571885	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva1969@postgrespro.ru", "phone": "+70104926930"}
0005432459876	7BDA15	2701 662944	EKATERINA MAKSIMOVA	{"phone": "+70475655154"}
0005432459877	BA8011	5515 492148	VALENTINA PETROVA	{"email": "valentina.petrova_1980@postgrespro.ru", "phone": "+70497897369"}
0005432459878	3A6785	5812 433263	VALENTINA MEDVEDEVA	{"phone": "+70035093620"}
0005432459879	3779A4	6169 964714	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_1982@postgrespro.ru", "phone": "+70051135883"}
0005432459880	3D8844	8015 316441	SERGEY SCHERBAKOV	{"phone": "+70039871443"}
0005432459881	3D8844	8641 057196	VALERIY PETROV	{"email": "valeriy_petrov.1972@postgrespro.ru", "phone": "+70209455382"}
0005432459882	4DAEB2	2799 208586	IRINA RODIONOVA	{"phone": "+70227027404"}
0005432459883	529120	0663 019096	VIKTOR KUZMIN	{"phone": "+70134106569"}
0005432459884	529120	4564 122378	MAKSIM IVANOV	{"email": "maksim_ivanov.1975@postgrespro.ru", "phone": "+70444283052"}
0005432459885	5BA200	4371 850932	VIKTOR KUZNECOV	{"email": "viktorkuznecov-021971@postgrespro.ru", "phone": "+70153387905"}
0005432459886	5BA200	9129 373097	VITALIY CHERNOV	{"phone": "+70916769078"}
0005432459887	B37902	6053 922454	ELENA ALEKSANDROVA	{"phone": "+70009181511"}
0005432459888	52C870	8464 740456	ALEKSANDR KUZNECOV	{"phone": "+70258331386"}
0005432459889	D3B0DC	0237 831684	SVETLANA SAVELEVA	{"phone": "+70916330656"}
0005432459890	6CC859	0371 672636	NINA POTAPOVA	{"email": "potapova_nina-071973@postgrespro.ru", "phone": "+70230623111"}
0005432459891	6CC859	3832 904595	VALENTINA STEPANOVA	{"email": "stepanovav031967@postgrespro.ru", "phone": "+70551602628"}
0005432459892	076889	9466 176186	ANNA KOROLEVA	{"phone": "+70139940402"}
0005432459893	076889	1174 605166	ZOYA MOROZOVA	{"email": "zoya-morozova_1969@postgrespro.ru", "phone": "+70702621244"}
0005432459894	529AF7	7949 144018	ANTONINA RYABOVA	{"phone": "+70120820429"}
0005432459895	AF4F75	5190 457914	STANISLAV NAZAROV	{"phone": "+70314680278"}
0005432459896	8D45F7	2971 425038	VALERIY SEMENOV	{"phone": "+70175045028"}
0005432459897	DF4FF4	2974 887687	VALENTINA LEBEDEVA	{"email": "v.lebedeva-26061972@postgrespro.ru", "phone": "+70098588921"}
0005432459898	F75F37	1686 377750	YURIY IVANOV	{"phone": "+70872323985"}
0005432459899	F75F37	1691 701350	MARIYA OVCHINNIKOVA	{"email": "ovchinnikovam_121973@postgrespro.ru", "phone": "+70848106108"}
0005432459900	EB55F3	1370 715766	RAISA IVANOVA	{"phone": "+70334292835"}
0005432459901	F90C3C	2446 056814	ALEKSANDR VLASOV	{"phone": "+70996141229"}
0005432459902	F90C3C	1721 976280	OLGA KOROLEVA	{"phone": "+70012564007"}
0005432459903	1D390B	9813 249154	DMITRIY GAVRILOV	{"phone": "+70495695285"}
0005432459904	1D390B	1366 485121	MIKHAIL ALEKSANDROV	{"email": "mikhailaleksandrov03101975@postgrespro.ru", "phone": "+70166887518"}
0005432459905	06B851	8333 327562	GENNADIY AFANASEV	{"phone": "+70079966822"}
0005432459906	06B851	0603 900446	DAMIR FEDOROV	{"phone": "+70825953232"}
0005432459907	22775F	9672 833702	SVETLANA GAVRILOVA	{"email": "gavrilovas011974@postgrespro.ru", "phone": "+70035111102"}
0005432459908	AF768D	4629 056751	NIKOLAY MEDVEDEV	{"phone": "+70310678213"}
0005432459909	C9FC09	5995 135699	YURIY PETROV	{"phone": "+70817150955"}
0005432459910	778B39	6381 020372	NIKOLAY PETROV	{"email": "n.petrov02121964@postgrespro.ru", "phone": "+70192873732"}
0005432459911	778B39	3003 872897	TATYANA GRISHINA	{"email": "grishinat_01091969@postgrespro.ru", "phone": "+70096681482"}
0005432459912	A41D68	8649 453352	ROMAN ROMANOV	{"email": "romanov_r-1971@postgrespro.ru", "phone": "+70813743681"}
0005432459913	A41D68	2500 079484	DMITRIY ROMANOV	{"phone": "+70777136012"}
0005432459914	C44223	9561 024237	OKSANA MASLOVA	{"email": "oksana-maslova041969@postgrespro.ru", "phone": "+70098369343"}
0005432459915	CF80AC	7699 365740	EVA TIMOFEEVA	{"phone": "+70744283179"}
0005432459916	2E6F2D	4928 621206	DMITRIY AFANASEV	{"email": "d_afanasev.1961@postgrespro.ru", "phone": "+70349880253"}
0005432459917	14E6BF	8210 086201	YURIY DENISOV	{"email": "denisov.y-1977@postgrespro.ru", "phone": "+70872621548"}
0005432459918	F7B548	4934 908460	ANDREY MAKAROV	{"email": "makarov.a.1975@postgrespro.ru", "phone": "+70680614242"}
0005432459919	9919F3	4999 077875	ANDREY ANTONOV	{"email": "antonov_a.1964@postgrespro.ru", "phone": "+70784167252"}
0005432459920	4B7A20	5072 451736	ELENA ILINA	{"email": "elena_ilina_121971@postgrespro.ru", "phone": "+70956009969"}
0005432459921	AD7FB3	4056 071875	VARVARA IVANOVA	{"email": "varvara.ivanova06041967@postgrespro.ru", "phone": "+70578459383"}
0005432459922	AD7FB3	7768 174220	ALEKSANDRA AFANASEVA	{"email": "aleksandra.afanaseva_1978@postgrespro.ru", "phone": "+70667688222"}
0005432459923	45F328	8627 013812	EKATERINA KOZLOVA	{"email": "ekaterina.kozlova111977@postgrespro.ru", "phone": "+70089113137"}
0005432459924	6DCC50	0528 482850	OLGA MEDVEDEVA	{"email": "medvedevaolga_1972@postgrespro.ru", "phone": "+70705028378"}
0005432459925	962BF3	9972 857097	VALENTINA FADEEVA	{"phone": "+70998517147"}
0005432459926	CE6EEB	3544 994257	OLEG FILIPPOV	{"email": "filippov.o.041975@postgrespro.ru", "phone": "+70611050135"}
0005432459927	CE6EEB	2755 295104	NINA ROMANOVA	{"phone": "+70099720602"}
0005432459928	C4B765	2718 050128	MAKSIM SHEVCHENKO	{"email": "shevchenko_m-031961@postgrespro.ru", "phone": "+70450610251"}
0005432459929	8951F6	9198 648079	ELENA VLASOVA	{"email": "e.vlasova.121966@postgrespro.ru", "phone": "+70540087424"}
0005432459930	8951F6	6719 742706	VALENTINA ALEKSEEVA	{"email": "alekseeva.v1970@postgrespro.ru", "phone": "+70472054924"}
0005432459931	956F41	1239 357867	ILYA CHERNOV	{"email": "ichernov071974@postgrespro.ru", "phone": "+70891100525"}
0005432459932	4FC4DF	4360 177648	YURIY KUZMIN	{"phone": "+70921509505"}
0005432459933	4FC4DF	6081 661179	LEONID SMIRNOV	{"phone": "+70779895872"}
0005432459934	31EA21	9699 668903	ARMEN KARPOV	{"phone": "+70706309646"}
0005432459935	470D3D	4851 343692	SERGEY KRASNOV	{"phone": "+70123219459"}
0005432459936	470D3D	5550 361677	DARYA MAKAROVA	{"phone": "+70188634794"}
0005432459937	C481B7	4004 796569	VITALIY ANDREEV	{"email": "andreevvitaliy_1968@postgrespro.ru", "phone": "+70291970033"}
0005432459938	1D6FC7	4155 260059	SVETLANA GRISHINA	{"email": "svetlanagrishina.041969@postgrespro.ru", "phone": "+70368942681"}
0005432459939	828DE9	8062 082834	VLADIMIR NIKITIN	{"email": "vladimirnikitin_071974@postgrespro.ru", "phone": "+70680533072"}
0005432459940	828DE9	6645 116502	VLADIMIR SEMENOV	{"phone": "+70701420971"}
0005432459941	E6B0D4	0043 094142	KSENIYA NOVIKOVA	{"email": "novikovakseniya1969@postgrespro.ru", "phone": "+70142679353"}
0005432459942	48FD7A	1548 230808	EVGENIY BARANOV	{"phone": "+70690799700"}
0005432459943	5DC449	7607 776771	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda05071978@postgrespro.ru", "phone": "+70500659691"}
0005432459944	5DC449	9603 139844	LYUBOV SEMENOVA	{"phone": "+70904361470"}
0005432459945	184A20	5635 307564	NINA POLYAKOVA	{"phone": "+70698052128"}
0005432459946	184A20	5546 769022	SVETLANA POPOVA	{"email": "svetlanapopova.1971@postgrespro.ru", "phone": "+70893836304"}
0005432459947	AAB820	3846 948007	TATYANA MATVEEVA	{"email": "matveevatatyana-1957@postgrespro.ru", "phone": "+70658575352"}
0005432459948	873B1D	7810 491896	LYUDMILA KULIKOVA	{"email": "lyudmilakulikova_12031966@postgrespro.ru", "phone": "+70934339505"}
0005432459949	873B1D	3159 672466	EDUARD BELOV	{"phone": "+70287303787"}
0005432459950	873B1D	9425 276318	NATALYA RODIONOVA	{"phone": "+70262378636"}
0005432459951	B580B1	2427 193971	LILIYA BORISOVA	{"phone": "+70413892012"}
0005432459952	EDCD57	9792 381546	SERGEY KRASNOV	{"email": "sergeykrasnov101974@postgrespro.ru", "phone": "+70701242013"}
0005432459953	EDCD57	8044 155754	MARIYA NIKITINA	{"phone": "+70457914047"}
0005432459954	CD8C11	4617 275916	VARVARA MAKSIMOVA	{"email": "maksimova-v.121966@postgrespro.ru", "phone": "+70304072886"}
0005432459955	03B088	6485 255765	IRINA GERASIMOVA	{"email": "irinagerasimova.15081969@postgrespro.ru", "phone": "+70014676762"}
0005432459956	03B088	7949 164745	NADEZHDA VOROBEVA	{"phone": "+70707507367"}
0005432459957	839EBF	4441 601466	MARIYA GORBUNOVA	{"email": "mariya-gorbunova.27021974@postgrespro.ru", "phone": "+70138897203"}
0005432460014	48C56F	6175 406261	NIKOLAY TIMOFEEV	{"phone": "+70737110777"}
0005432459958	839EBF	2310 725457	OLEG ZAYCEV	{"email": "olegzaycev111974@postgrespro.ru", "phone": "+70977248746"}
0005432459959	839EBF	4844 993414	LYUBOV SOROKINA	{"email": "sorokinalyubov-1978@postgrespro.ru", "phone": "+70544771316"}
0005432459960	988585	4343 481941	ELENA KUZMINA	{"phone": "+70961261698"}
0005432459961	E57220	2362 455786	ALEKSANDR PETROV	{"email": "petrova-031977@postgrespro.ru", "phone": "+70860684549"}
0005432459962	E57220	4579 993375	ANATOLIY VOLKOV	{"email": "volkov-a-03011975@postgrespro.ru", "phone": "+70757707835"}
0005432459963	E57220	8002 578938	ZINAIDA FROLOVA	{"phone": "+70340261282"}
0005432459964	86CE79	6011 241276	KIRA FADEEVA	{"email": "fadeevak.071979@postgrespro.ru", "phone": "+70383335238"}
0005432459965	DE3588	3381 833442	ALEKSANDR NOVIKOV	{"phone": "+70382799918"}
0005432459966	DE3588	0473 375305	OLGA SMIRNOVA	{"email": "o.smirnova-021969@postgrespro.ru", "phone": "+70952880120"}
0005432459967	DE3588	7901 936220	ALEKSANDR VASILEV	{"phone": "+70980698501"}
0005432459968	9A3B18	3294 232099	IRINA TIMOFEEVA	{"phone": "+70767487593"}
0005432459969	4A9363	3210 874523	KIRILL SERGEEV	{"email": "kirill_sergeev.1968@postgrespro.ru", "phone": "+70222636616"}
0005432459970	026080	3406 453357	LYUDMILA ZAYCEVA	{"phone": "+70707214241"}
0005432459971	026080	2029 531016	VALENTINA IVANOVA	{"email": "valentina_ivanova-18031973@postgrespro.ru", "phone": "+70263185177"}
0005432459972	561CE4	9903 187335	MARIYA FROLOVA	{"email": "m-frolova.1959@postgrespro.ru", "phone": "+70168442450"}
0005432459973	561CE4	5600 599541	LIDIYA SOLOVEVA	{"email": "lidiya.soloveva.121969@postgrespro.ru", "phone": "+70395874140"}
0005432459974	D4B566	8865 231959	ALEKSEY SOLOVEV	{"email": "solovev_aleksey-15011970@postgrespro.ru", "phone": "+70248660677"}
0005432459975	72A603	5246 998063	SVETLANA KUZNECOVA	{"phone": "+70431046721"}
0005432459976	E08C03	8057 913408	VERA KOROLEVA	{"phone": "+70395168329"}
0005432459977	73C2E4	1890 086089	VALENTINA VOROBEVA	{"phone": "+70140334038"}
0005432459978	0BA37E	1895 544986	YANA FADEEVA	{"phone": "+70025364386"}
0005432459979	4E9D82	9939 897445	VASILIY CHERNOV	{"email": "vasiliy-chernov.29071974@postgrespro.ru", "phone": "+70096732103"}
0005432459980	43ADFF	9061 062513	IGOR ZAYCEV	{"phone": "+70972195889"}
0005432459981	43ADFF	2128 022383	NATALYA POLYAKOVA	{"email": "n-polyakova081969@postgrespro.ru", "phone": "+70342930061"}
0005432459982	43ADFF	8286 016386	DARYA ZAKHAROVA	{"phone": "+70797774474"}
0005432459983	77020B	5778 929180	ALEKSANDR FOMIN	{"phone": "+70856018579"}
0005432459984	FB6C33	9097 499866	ALEKSANDR MAKSIMOV	{"phone": "+70990220859"}
0005432459985	606E45	3300 891530	VALENTINA SIDOROVA	{"email": "sidorovav.30121971@postgrespro.ru", "phone": "+70065363252"}
0005432459986	606E45	7507 487085	IRINA OSIPOVA	{"email": "irina.osipova-28111970@postgrespro.ru", "phone": "+70773527750"}
0005432459987	E26672	3325 050092	SERGEY DENISOV	{"email": "s.denisov-11021971@postgrespro.ru", "phone": "+70491719537"}
0005432459988	655B46	4939 284371	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-a.25081977@postgrespro.ru", "phone": "+70016399962"}
0005432459989	5797D2	3826 452041	LYUDMILA ABRAMOVA	{"phone": "+70268872946"}
0005432459990	144F60	0199 272051	DANIIL KUDRYASHOV	{"email": "kudryashov_d_061977@postgrespro.ru", "phone": "+70631118247"}
0005432459991	144F60	2792 658008	NATALYA FROLOVA	{"phone": "+70328948905"}
0005432459992	767D5A	6936 681953	VLADISLAV MIRONOV	{"phone": "+70930435907"}
0005432459993	531F46	5495 450580	SVETLANA ZAYCEVA	{"email": "zaycevasvetlana_16071972@postgrespro.ru", "phone": "+70860179377"}
0005432459994	18B0FA	8434 040558	SERGEY SMIRNOV	{"email": "sergey-smirnov-1970@postgrespro.ru", "phone": "+70684683727"}
0005432459995	3A753A	6128 052793	TATYANA KOLESNIKOVA	{"email": "tatyanakolesnikova-011982@postgrespro.ru", "phone": "+70155391340"}
0005432459996	3A753A	4270 811230	TATYANA KUZNECOVA	{"email": "t_kuznecova031975@postgrespro.ru", "phone": "+70966612996"}
0005432459997	E455C5	8563 805142	YAROSLAVA GAVRILOVA	{"phone": "+70191651688"}
0005432459998	4096AD	9299 853679	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov_21101969@postgrespro.ru", "phone": "+70562637561"}
0005432459999	73CDED	4018 095019	NAILYA OVCHINNIKOVA	{"phone": "+70069082824"}
0005432460000	73CDED	5088 071878	MARIYA BELYAEVA	{"email": "mariya-belyaeva_1968@postgrespro.ru", "phone": "+70291365443"}
0005432460001	7BD129	6194 270931	NINA DMITRIEVA	{"phone": "+70930817046"}
0005432460002	8A41D9	7182 027234	ALLA KRASNOVA	{"phone": "+70948146673"}
0005432460003	D591F1	0283 907042	IGOR DMITRIEV	{"email": "dmitrievi_1977@postgrespro.ru", "phone": "+70586546636"}
0005432460004	4ADEF7	3683 189609	ZINAIDA KALININA	{"email": "kalinina-zinaida-1968@postgrespro.ru", "phone": "+70158558136"}
0005432460005	4ADEF7	1747 222126	SERGEY ABRAMOV	{"phone": "+70309137828"}
0005432460006	4B85DF	0003 043600	MARIYA ZAKHAROVA	{"phone": "+70016260177"}
0005432460007	4B85DF	7286 273756	SERGEY KISELEV	{"email": "s_kiselev_011972@postgrespro.ru", "phone": "+70105736007"}
0005432460008	4B85DF	5245 239873	SERGEY GRIGOREV	{"phone": "+70995040736"}
0005432460009	C3CCE2	7065 479081	MAKSIM MAKSIMOV	{"email": "maksimov_maksim_12111981@postgrespro.ru", "phone": "+70502192928"}
0005432460010	C3CCE2	2781 643762	ALEKSANDRA GORBUNOVA	{"phone": "+70418353170"}
0005432460011	C3CCE2	8943 611078	ELENA BELOVA	{"phone": "+70316096649"}
0005432460012	711022	0710 584948	EVGENIYA MOROZOVA	{"email": "morozova-evgeniya23061975@postgrespro.ru", "phone": "+70880462714"}
0005432460013	48C56F	1801 750721	MARIYA ORLOVA	{"email": "m_orlova06021983@postgrespro.ru", "phone": "+70216703415"}
0005432460015	129489	7343 573926	RAIS ZHURAVLEV	{"email": "zhuravlev_rais_1961@postgrespro.ru", "phone": "+70270688672"}
0005432460016	129489	0558 644929	NADEZHDA PETROVA	{"email": "petrova-nadezhda.18071965@postgrespro.ru", "phone": "+70953419664"}
0005432460017	CD8117	8303 691231	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakova-aleksandra19021960@postgrespro.ru", "phone": "+70400007127"}
0005432460018	5CABD4	1804 181324	ALEKSEY ALEKSEEV	{"email": "aleksey.alekseev111979@postgrespro.ru", "phone": "+70197472451"}
0005432460019	819BBD	7510 158710	EVGENIYA SMIRNOVA	{"email": "smirnovae-1968@postgrespro.ru", "phone": "+70325947296"}
0005432460201	2D8680	0807 303655	OLGA GRISHINA	{"phone": "+70894298573"}
0005432460020	9B3B5B	1786 166892	TAMARA KRASNOVA	{"email": "krasnova-t_1983@postgrespro.ru", "phone": "+70984876029"}
0005432460021	9B3B5B	1946 486578	VYACHESLAV TIMOFEEV	{"email": "v-timofeev.10111971@postgrespro.ru", "phone": "+70200604150"}
0005432460022	B1B6F7	5349 141077	SVETLANA YAKOVLEVA	{"phone": "+70413785452"}
0005432460023	7938F9	3114 144642	VASILIY ZHUKOV	{"phone": "+70083010256"}
0005432460024	0DCD0C	4426 502709	VERA BELOVA	{"email": "belova.vera_1970@postgrespro.ru", "phone": "+70242346924"}
0005432460025	4FCD0A	4359 294694	NINA POPOVA	{"phone": "+70510241719"}
0005432460026	080E5A	8851 519453	SERGEY ZAYCEV	{"email": "zaycev-s_1975@postgrespro.ru", "phone": "+70086562876"}
0005432460027	080E5A	7896 480647	NATALYA KUZNECOVA	{"phone": "+70173598120"}
0005432460028	74D633	6740 730167	PETR MAKSIMOV	{"email": "maksimov-petr.1973@postgrespro.ru", "phone": "+70137035378"}
0005432460029	EBBA38	0044 376466	LYUBOV KOROLEVA	{"email": "koroleva-lyubov.1973@postgrespro.ru", "phone": "+70360158247"}
0005432460030	EBBA38	7378 886558	OLEG NAUMOV	{"phone": "+70320035550"}
0005432460031	011203	6471 144009	ELENA MEDVEDEVA	{"phone": "+70789872426"}
0005432460032	61043A	8462 313326	VIKTOR RODIONOV	{"phone": "+70276843266"}
0005432460033	61043A	6807 314863	ALEKSANDR SMIRNOV	{"phone": "+70572567607"}
0005432460034	978074	0939 095383	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov.1976@postgrespro.ru", "phone": "+70741750731"}
0005432460035	C2974C	4339 439115	SVETLANA ANTONOVA	{"phone": "+70762868049"}
0005432460036	89E546	1676 806010	OLGA TROFIMOVA	{"email": "olga_trofimova_17071973@postgrespro.ru", "phone": "+70040820194"}
0005432460037	1F7064	9899 983761	TATYANA SEMENOVA	{"email": "semenova.t02121984@postgrespro.ru", "phone": "+70569710018"}
0005432460038	1F7064	5327 474115	EMMA ILINA	{"email": "ilina_emma-27121983@postgrespro.ru", "phone": "+70300653028"}
0005432460039	67AB25	0920 165181	STEPAN ZHUKOV	{"phone": "+70470458756"}
0005432460040	67AB25	9974 531148	MILENA IVANOVA	{"phone": "+70083272474"}
0005432460041	548039	1342 502714	ELENA MOISEEVA	{"email": "moiseevaelena.07021967@postgrespro.ru", "phone": "+70693571491"}
0005432460042	41D522	9729 863171	ANTON ZAKHAROV	{"email": "a.zakharov_021975@postgrespro.ru", "phone": "+70390043562"}
0005432460043	72C89C	2979 731479	VLADIMIR EGOROV	{"email": "egorovv-04061972@postgrespro.ru", "phone": "+70308794360"}
0005432460044	72C89C	9975 969953	DENIS VLASOV	{"phone": "+70942275656"}
0005432460045	7934A9	6997 202922	POLINA KUZNECOVA	{"phone": "+70400902459"}
0005432460046	41EF38	4319 595575	POLINA MELNIKOVA	{"email": "polina-melnikova061968@postgrespro.ru", "phone": "+70828986315"}
0005432460047	3F2090	6560 083367	TATYANA SOLOVEVA	{"phone": "+70771135895"}
0005432460048	6CA3E4	1948 867353	LIDIYA ROMANOVA	{"phone": "+70748896086"}
0005432460049	966DF6	6538 297896	DARYA KOROLEVA	{"email": "koroleva_darya_091972@postgrespro.ru", "phone": "+70828281910"}
0005432460050	966DF6	7700 784899	ALEKSANDR BELOV	{"email": "belov_a_21121967@postgrespro.ru", "phone": "+70093319883"}
0005432460051	F11FA9	7056 924771	ALEKSANDR PETROV	{"email": "petrov.a-10021970@postgrespro.ru", "phone": "+70277387347"}
0005432460052	FD9B82	9963 149278	ALEKSANDR BORISOV	{"phone": "+70379888554"}
0005432460053	98FC59	5604 004166	YURIY STEPANOV	{"email": "yuriy.stepanov-091978@postgrespro.ru", "phone": "+70124052400"}
0005432460054	CBE823	3136 342042	EVGENIY ANTONOV	{"phone": "+70674685388"}
0005432460055	405D3F	4189 307881	GEORGIY OSIPOV	{"phone": "+70808297429"}
0005432460056	6CAF92	1485 998846	DMITRIY DENISOV	{"phone": "+70399208071"}
0005432460057	B746C9	4949 103376	RAISA ERMAKOVA	{"phone": "+70788711604"}
0005432460058	BBA9F6	3118 378817	OLEG CHERNOV	{"phone": "+70951456667"}
0005432460059	17A245	9825 475399	MAKSIM SCHERBAKOV	{"email": "mscherbakov-1977@postgrespro.ru", "phone": "+70327477677"}
0005432460060	17A245	9121 500233	VLADIMIR SOROKIN	{"phone": "+70940880227"}
0005432460061	1C13C6	2790 915024	ALEKSEY VASILEV	{"phone": "+70023343875"}
0005432460062	1C13C6	3879 402671	MARINA KUZMINA	{"email": "kuzmina-m.011967@postgrespro.ru", "phone": "+70175624128"}
0005432460063	43CAA0	8966 487522	TATYANA KRASNOVA	{"email": "tatyana-krasnova.091968@postgrespro.ru", "phone": "+70913913886"}
0005432460064	2AA150	2410 776555	EVGENIY SMIRNOV	{"phone": "+70387269372"}
0005432460065	2A3BFA	9526 667548	ALEKSANDR MARTYNOV	{"email": "aleksandr.martynov_011967@postgrespro.ru", "phone": "+70180801114"}
0005432460066	70BABF	3911 684449	ALEKSANDR TIMOFEEV	{"phone": "+70011142326"}
0005432460067	E462DD	8783 301723	LIDIYA PAVLOVA	{"email": "l.pavlova31101973@postgrespro.ru", "phone": "+70517274289"}
0005432460068	E462DD	5437 384960	MAKSIM ZAYCEV	{"phone": "+70809146722"}
0005432460069	B431E3	1555 078863	TATYANA FADEEVA	{"email": "fadeevat-06121972@postgrespro.ru", "phone": "+70680406208"}
0005432460070	81C16C	8327 384837	EVGENIY CHERNOV	{"email": "chernov_e051971@postgrespro.ru", "phone": "+70862649038"}
0005432460071	66BC24	4553 871095	ELENA KONOVALOVA	{"phone": "+70510873509"}
0005432460072	66BC24	6725 627286	OLGA ZAKHAROVA	{"email": "zakharova.olga-121962@postgrespro.ru", "phone": "+70241330563"}
0005432460073	3B95A6	5989 933921	IVAN SHEVCHENKO	{"email": "shevchenko_i-071979@postgrespro.ru", "phone": "+70065188105"}
0005432460074	3B95A6	9415 503361	ALEKSEY PAVLOV	{"email": "a.pavlov.1973@postgrespro.ru", "phone": "+70839640207"}
0005432460075	3B95A6	2412 513130	VLADIMIR VOLKOV	{"phone": "+70918172563"}
0005432460076	3B95A6	7107 261286	MIKHAIL SEMENOV	{"phone": "+70277813033"}
0005432460077	3B95A6	5187 205384	NINA SOROKINA	{"phone": "+70056017455"}
0005432460078	222783	9883 647535	PAVEL ISAEV	{"email": "isaevpavel_10091977@postgrespro.ru", "phone": "+70402069648"}
0005432460079	F74284	9982 690871	VALERIY POPOV	{"email": "popovvaleriy-12041960@postgrespro.ru", "phone": "+70228858732"}
0005432460080	F74284	1344 530562	VASILISA POPOVA	{"email": "v-popova-021961@postgrespro.ru", "phone": "+70544318011"}
0005432460081	6F3C75	1551 994977	ILYA MELNIKOV	{"email": "i-melnikov_17061972@postgrespro.ru", "phone": "+70641940352"}
0005432460082	68E8A8	3025 821624	NINA VOLKOVA	{"phone": "+70745968647"}
0005432460083	8861FA	1604 349472	ANTONINA POPOVA	{"email": "popovaa_25071981@postgrespro.ru", "phone": "+70585068623"}
0005432460084	8861FA	7723 531656	ANDREY ALEKSEEV	{"phone": "+70221195648"}
0005432460085	BC9955	4965 821627	OLGA AKIMOVA	{"email": "oakimova1983@postgrespro.ru", "phone": "+70634195205"}
0005432460086	DD8243	6655 684727	VLADIMIR IVANOV	{"email": "v-ivanov-021974@postgrespro.ru", "phone": "+70744273701"}
0005432460087	E9AA78	4180 499278	VLADIMIR SERGEEV	{"phone": "+70295112821"}
0005432460088	661666	3544 606403	MARIYA NAUMOVA	{"phone": "+70706003637"}
0005432460089	661666	5625 860525	OLGA SMIRNOVA	{"email": "olgasmirnova-14051962@postgrespro.ru", "phone": "+70332314791"}
0005432460090	CD04A6	1898 010464	VALENTINA SOKOLOVA	{"phone": "+70867521076"}
0005432460091	D80357	5596 858434	ANNA BORISOVA	{"phone": "+70109676264"}
0005432460092	D80357	8736 328677	NATALYA VLASOVA	{"email": "natalya_vlasova-24051966@postgrespro.ru", "phone": "+70372645928"}
0005432460093	9E7404	3803 797874	ANNA TITOVA	{"phone": "+70733091121"}
0005432460094	1A027D	6412 509485	KSENIYA ZHUKOVA	{"email": "k_zhukova.1971@postgrespro.ru", "phone": "+70244673703"}
0005432460095	DF82E0	3269 681187	ARTEM MIKHAYLOV	{"email": "mikhaylov-artem-24121973@postgrespro.ru", "phone": "+70372599647"}
0005432460096	DF82E0	4325 327373	NATALYA IVANOVA	{"phone": "+70680365073"}
0005432460097	DF82E0	3668 719838	OLGA ARKHIPOVA	{"phone": "+70861117194"}
0005432460098	6CCDB5	2855 977183	PAVEL KOZLOV	{"phone": "+70254068134"}
0005432460099	A02B99	1658 615306	AMINA KOVALEVA	{"phone": "+70186987095"}
0005432460100	A02B99	6409 729057	YULIYA POPOVA	{"phone": "+70377553058"}
0005432460101	7973A5	5789 831602	VIKTOR NIKITIN	{"phone": "+70397914695"}
0005432460102	594193	8471 125715	PELAGEYA ZHURAVLEVA	{"phone": "+70092119490"}
0005432460103	594193	5928 540193	VIKTOR ZAKHAROV	{"phone": "+70898699533"}
0005432460104	8E60A3	5704 125023	VYACHESLAV KOZLOV	{"phone": "+70546945051"}
0005432460105	8E60A3	2997 654090	MAKSIM BARANOV	{"email": "maksim-baranov1974@postgrespro.ru", "phone": "+70804593082"}
0005432460106	CFC28A	9142 800431	NINA MIKHAYLOVA	{"phone": "+70857675663"}
0005432460107	7BA4A1	5132 858780	VASILIY MELNIKOV	{"email": "v-melnikov_1981@postgrespro.ru", "phone": "+70282223985"}
0005432460108	B6B5D3	4273 854329	IRINA AFANASEVA	{"email": "afanaseva_i121976@postgrespro.ru", "phone": "+70595321562"}
0005432460109	AE7333	7269 744234	OLEG MAKAROV	{"email": "makarov-o-051964@postgrespro.ru", "phone": "+70168421612"}
0005432460110	AE7333	3740 601304	NATALYA YAKOVLEVA	{"phone": "+70602220403"}
0005432460111	C72068	7772 889382	MARIYA LAZAREVA	{"phone": "+70944529173"}
0005432460112	11C645	5813 411303	VALERIY EGOROV	{"email": "egorov_valeriy091971@postgrespro.ru", "phone": "+70067651727"}
0005432460113	11C645	6374 460711	VYACHESLAV ABRAMOV	{"email": "abramov-vyacheslav-1959@postgrespro.ru", "phone": "+70183787109"}
0005432460114	FBF12E	3114 868088	KONSTANTIN POPOV	{"phone": "+70397284293"}
0005432460115	FBF12E	4826 730461	SERGEY FOMIN	{"email": "s-fomin1960@postgrespro.ru", "phone": "+70457624155"}
0005432460116	CB6EA9	6186 204834	VARVARA OSIPOVA	{"email": "osipova_varvara.07111967@postgrespro.ru", "phone": "+70306830809"}
0005432460117	CB6EA9	0457 285492	ANATOLIY KULIKOV	{"email": "a_kulikov011982@postgrespro.ru", "phone": "+70338811110"}
0005432460118	3B1ACB	1578 727188	IGOR MELNIKOV	{"phone": "+70106171572"}
0005432460119	3B1ACB	0000 619390	ELIZAVETA LUKYANOVA	{"email": "lukyanova.elizaveta-101978@postgrespro.ru", "phone": "+70043826190"}
0005432460120	ECBA38	8029 089943	ALEKSANDR TARASOV	{"phone": "+70458235690"}
0005432460121	3011C6	9999 913541	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov.1972@postgrespro.ru", "phone": "+70576668355"}
0005432460122	646CC3	5939 711458	NIKOLAY PAVLOV	{"phone": "+70770700522"}
0005432460123	06BCBB	3409 163296	NINA ANDREEVA	{"phone": "+70493785728"}
0005432460124	06BCBB	2282 123320	GENNADIY AFANASEV	{"email": "g_afanasev1969@postgrespro.ru", "phone": "+70667927929"}
0005432460125	F36960	9052 360812	ALEKSANDR PETROV	{"email": "aleksandr.petrov-1979@postgrespro.ru", "phone": "+70292322603"}
0005432460126	F36960	2730 476624	TATYANA DAVYDOVA	{"email": "davydova-t.20061981@postgrespro.ru", "phone": "+70246288447"}
0005432460127	3367BB	7250 148482	VALENTINA MIRONOVA	{"email": "mironovavalentina-1960@postgrespro.ru", "phone": "+70240483828"}
0005432460128	3367BB	5091 850985	LIDIYA MAKAROVA	{"email": "l.makarova_1964@postgrespro.ru", "phone": "+70575588537"}
0005432460129	187DC1	4816 393765	ANTON FILIPPOV	{"email": "antonfilippov_17081964@postgrespro.ru", "phone": "+70988856641"}
0005432460130	E682C0	6590 852053	LYUDMILA SEMENOVA	{"phone": "+70810756472"}
0005432460131	06A327	0873 417034	ALEKSANDRA IVANOVA	{"phone": "+70489304732"}
0005432460132	7D1AA3	4556 042618	ALEKSANDR EGOROV	{"email": "a-egorov-071960@postgrespro.ru", "phone": "+70272032009"}
0005432460133	8062D5	5869 001082	MILANA ABRAMOVA	{"phone": "+70701427588"}
0005432460134	DD0029	3005 403719	IRINA PETROVA	{"email": "ipetrova-15101975@postgrespro.ru", "phone": "+70420921546"}
0005432460135	2F34E4	5053 421416	VLADIMIR MELNIKOV	{"phone": "+70091143639"}
0005432460136	2F34E4	2644 204333	TIMUR MIKHAYLOV	{"email": "mikhaylov_timur1979@postgrespro.ru", "phone": "+70303895389"}
0005432460137	D6EF56	1802 721816	GALINA EFIMOVA	{"email": "efimova.galina_10021979@postgrespro.ru", "phone": "+70100635001"}
0005432460138	D6EF56	2494 101031	LYUDMILA PAVLOVA	{"phone": "+70838723250"}
0005432460139	658BCE	7985 438235	ROMAN FOMIN	{"email": "roman-fomin.081970@postgrespro.ru", "phone": "+70353347780"}
0005432460140	E9EACF	3942 849437	STANISLAV MAKSIMOV	{"phone": "+70773452776"}
0005432460141	638E98	9481 678980	NIKOLAY FEDOROV	{"email": "fedorov.n-1965@postgrespro.ru", "phone": "+70880172007"}
0005432460142	B59655	2000 033756	VLADIMIR NIKOLAEV	{"email": "nikolaev_v041965@postgrespro.ru", "phone": "+70130106401"}
0005432460143	6F5D13	4170 648539	LYUDMILA KULIKOVA	{"email": "kulikova-l.111969@postgrespro.ru", "phone": "+70704410260"}
0005432460144	88651B	8376 183473	OLGA SEMENOVA	{"email": "olga-semenova.031977@postgrespro.ru", "phone": "+70070653539"}
0005432460145	68EFB9	7360 619805	MARIYA FADEEVA	{"phone": "+70490024048"}
0005432460146	68EFB9	8222 179241	VALERIY MEDVEDEV	{"phone": "+70114877745"}
0005432460147	EE94DC	0749 423218	NINA MAKSIMOVA	{"email": "n.maksimova30031959@postgrespro.ru", "phone": "+70971081471"}
0005432460148	579847	0323 892674	GALINA SMIRNOVA	{"phone": "+70073935098"}
0005432460149	CB8455	4410 018665	RUSHANIYA NESTEROVA	{"email": "rushaniya-nesterova.061975@postgrespro.ru", "phone": "+70606324927"}
0005432460150	CB8455	4899 304147	VERA KAZAKOVA	{"phone": "+70910440305"}
0005432460151	506086	9107 899119	YULIYA MATVEEVA	{"email": "matveeva.yuliya_011978@postgrespro.ru", "phone": "+70265729193"}
0005432460152	5A6A64	5022 727704	SERGEY NAUMOV	{"phone": "+70428766669"}
0005432460153	06F964	8599 941847	EKATERINA ZAKHAROVA	{"email": "zakharova.e-051967@postgrespro.ru", "phone": "+70013791385"}
0005432460154	06F964	3572 189055	DMITRIY ZAYCEV	{"email": "dmitriy_zaycev.1973@postgrespro.ru", "phone": "+70171220908"}
0005432460155	9C8051	2594 555053	ANTON PETROV	{"phone": "+70691786624"}
0005432460156	9C8051	8992 781578	NIKITA POPOV	{"email": "n.popov1962@postgrespro.ru", "phone": "+70195966463"}
0005432460157	C4BE13	6022 264079	KONSTANTIN GERASIMOV	{"email": "k_gerasimov_031956@postgrespro.ru", "phone": "+70412114247"}
0005432460158	677324	1817 638089	NIKOLAY MIKHAYLOV	{"phone": "+70738629347"}
0005432460159	677324	8580 588935	ALEKSEY VASILEV	{"phone": "+70755890362"}
0005432460160	920F17	2271 881320	NIKOLAY ABRAMOV	{"email": "n.abramov1975@postgrespro.ru", "phone": "+70321447856"}
0005432460161	7F5779	0042 332757	SERAFIMA KUZNECOVA	{"email": "serafimakuznecova_24121968@postgrespro.ru", "phone": "+70724174893"}
0005432460162	12EB4B	6116 459148	TATYANA FROLOVA	{"email": "frolova-t_091983@postgrespro.ru", "phone": "+70571707510"}
0005432460163	12EB4B	5755 623311	ELEONORA FROLOVA	{"phone": "+70541507418"}
0005432460164	7A8A93	9146 466356	PELAGEYA IVANOVA	{"email": "ivanova-pelageya_1966@postgrespro.ru", "phone": "+70734737434"}
0005432460165	BCA5EC	4158 709090	VALERIYA KULIKOVA	{"phone": "+70983252675"}
0005432460166	3533EB	6118 755124	NADEZHDA MELNIKOVA	{"email": "melnikovanadezhda.13111971@postgrespro.ru", "phone": "+70787700052"}
0005432460167	147FB1	6619 484500	VYACHESLAV MAKAROV	{"phone": "+70229382633"}
0005432460168	352384	4816 024647	OKSANA LOGINOVA	{"email": "loginova_o1972@postgrespro.ru", "phone": "+70457357177"}
0005432460169	352384	0786 354552	ALEKSEY KOZLOV	{"email": "a_kozlov-17011986@postgrespro.ru", "phone": "+70494524740"}
0005432460170	1D2102	2315 085696	TAMARA KUZNECOVA	{"email": "t_kuznecova121974@postgrespro.ru", "phone": "+70329245823"}
0005432460171	B36D68	1734 764800	OLEG NAUMOV	{"phone": "+70693615863"}
0005432460172	F6D342	3566 661323	DMITRIY POPOV	{"email": "popov.d_1965@postgrespro.ru", "phone": "+70588713173"}
0005432460173	C0473E	9256 161993	VITALIY MIKHAYLOV	{"email": "mikhaylov_vitaliy-03071972@postgrespro.ru", "phone": "+70482213167"}
0005432460174	C0473E	3904 114221	MAKSIM SIDOROV	{"email": "msidorov_051986@postgrespro.ru", "phone": "+70759414199"}
0005432460175	F45C8E	8166 215922	ANDREY MIKHAYLOV	{"phone": "+70290449292"}
0005432460176	F45C8E	1694 517115	LIDIYA ALEKSANDROVA	{"email": "aleksandrova.l-121966@postgrespro.ru", "phone": "+70676770662"}
0005432460177	15E632	7718 439591	DMITRIY CHERNOV	{"phone": "+70392225087"}
0005432460178	ACE49D	5657 903907	ALEKSEY DMITRIEV	{"phone": "+70384101874"}
0005432460179	ACE49D	3838 165927	MARINA MELNIKOVA	{"phone": "+70999621241"}
0005432460180	B760E9	8369 113686	NIKOLAY DMITRIEV	{"phone": "+70074258814"}
0005432460181	A92F1D	6791 513993	ILYA ABRAMOV	{"email": "abramov.i.061971@postgrespro.ru", "phone": "+70945775883"}
0005432460182	A92F1D	7062 140668	GALINA BORISOVA	{"phone": "+70287838158"}
0005432460183	A92F1D	8647 829238	ALEKSANDR ILIN	{"email": "ilin-a_1973@postgrespro.ru", "phone": "+70274240440"}
0005432460184	7B87B1	0144 225153	MARINA OSIPOVA	{"email": "osipova_marina-04051966@postgrespro.ru", "phone": "+70165616397"}
0005432460185	5E8779	8924 063338	DENIS MELNIKOV	{"phone": "+70195357980"}
0005432460186	5E8779	9453 493670	SVETLANA KOMAROVA	{"email": "svetlanakomarova-1983@postgrespro.ru", "phone": "+70433736010"}
0005432460187	673A10	1067 918065	ANASTASIYA ZAYCEVA	{"phone": "+70047940315"}
0005432460188	673A10	3770 095756	YURIY MATVEEV	{"email": "matveev.yuriy1982@postgrespro.ru", "phone": "+70959747534"}
0005432460189	673A10	3458 952595	RASHID SAVELEV	{"phone": "+70554672932"}
0005432460190	359869	5927 350356	ARINA LEBEDEVA	{"phone": "+70250488473"}
0005432460191	359869	2570 140375	EVGENIY SCHERBAKOV	{"phone": "+70585518820"}
0005432460192	C1828A	0130 259468	EVGENIY ORLOV	{"phone": "+70545591570"}
0005432460193	1EFEF6	8367 045763	PAVEL MAKAROV	{"email": "pavel_makarov1974@postgrespro.ru", "phone": "+70160119640"}
0005432460194	450978	6020 858177	SERGEY KARPOV	{"email": "karpovsergey.071968@postgrespro.ru", "phone": "+70767670626"}
0005432460195	450978	8674 878330	TATYANA PAVLOVA	{"phone": "+70041148446"}
0005432460196	450978	7124 311840	TATYANA SOLOVEVA	{"phone": "+70648230259"}
0005432460197	450978	8054 357767	YULIYA KUZNECOVA	{"email": "kuznecova-y-111975@postgrespro.ru", "phone": "+70785499628"}
0005432460198	FACADF	8563 825759	ANTON ZAKHAROV	{"email": "zakharova-111972@postgrespro.ru", "phone": "+70718171307"}
0005432460199	CAEBEE	5354 593915	VLADIMIR IVANOV	{"phone": "+70785616053"}
0005432460200	CAEBEE	1804 406863	OLGA KARPOVA	{"email": "karpova-o.1954@postgrespro.ru", "phone": "+70851549707"}
0005432460202	BAD299	6359 168800	OLEG KULIKOV	{"phone": "+70157499443"}
0005432460203	BAD299	7731 429716	ALEKSEY IVANOV	{"email": "aleksey-ivanov02031969@postgrespro.ru", "phone": "+70232087893"}
0005432460204	1F5C62	7977 331371	VLADISLAV FROLOV	{"phone": "+70458046885"}
0005432460205	465FB6	8190 510967	OLGA GUSEVA	{"phone": "+70476055875"}
0005432460206	465FB6	8095 334408	GALINA KUZNECOVA	{"phone": "+70633523596"}
0005432460207	87818D	1620 741489	ELENA KOROLEVA	{"email": "elena-koroleva.24051977@postgrespro.ru", "phone": "+70943421594"}
0005432460208	371CF0	1442 010682	FAINA TROFIMOVA	{"email": "faina.trofimova.11031978@postgrespro.ru", "phone": "+70763311547"}
0005432460209	9AD14E	1373 963868	EVGENIY DMITRIEV	{"email": "evgeniy.dmitriev031968@postgrespro.ru", "phone": "+70296927877"}
0005432460210	3B965C	9041 312633	TATYANA MAKAROVA	{"email": "makarova_t.1963@postgrespro.ru", "phone": "+70370821788"}
0005432460211	A13E2C	9365 728342	RIMMA RODIONOVA	{"phone": "+70593547034"}
0005432460212	6FCA09	6909 155833	NATALYA MELNIKOVA	{"email": "natalyamelnikova09031983@postgrespro.ru", "phone": "+70117523744"}
0005432460213	E6B53F	2956 384066	TATYANA ZAYCEVA	{"email": "zayceva_tatyana061963@postgrespro.ru", "phone": "+70181024195"}
0005432460214	E6B53F	4150 393959	TATYANA STEPANOVA	{"email": "stepanova-t_25051970@postgrespro.ru", "phone": "+70700637998"}
0005432460215	CF6407	9010 388483	ARKADIY EGOROV	{"email": "a-egorov-111972@postgrespro.ru", "phone": "+70092232069"}
0005432460216	2629CF	4420 328260	NADEZHDA KONOVALOVA	{"phone": "+70911323777"}
0005432460217	FF6DBF	1238 481748	IVAN KULIKOV	{"email": "ikulikov14121974@postgrespro.ru", "phone": "+70979973952"}
0005432460218	50C433	1594 288349	VERA FROLOVA	{"email": "v-frolova.18051969@postgrespro.ru", "phone": "+70915454084"}
0005432460219	35E0EF	7762 830441	EVGENIY MAKSIMOV	{"phone": "+70796556973"}
0005432460220	6ACEE1	3917 773665	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya_1971@postgrespro.ru", "phone": "+70292047837"}
0005432460221	1C5AE5	7139 896122	PAVEL DMITRIEV	{"email": "dmitriev.pavel_121978@postgrespro.ru", "phone": "+70095110344"}
0005432460222	B87D95	7450 153690	LYUDMILA IVANOVA	{"phone": "+70659497029"}
0005432460223	B87D95	9930 316732	ANASTASIYA BORISOVA	{"phone": "+70921033858"}
0005432460224	B87D95	8237 314552	LYUDMILA NIKIFOROVA	{"email": "lyudmila-nikiforova.1971@postgrespro.ru", "phone": "+70782456199"}
0005432460225	9B711E	4148 857023	ELENA LEBEDEVA	{"email": "lebedeva.elena.27121973@postgrespro.ru", "phone": "+70503460738"}
0005432460226	FB72E9	4070 992847	KRISTINA GRISHINA	{"email": "kristina-grishina_1971@postgrespro.ru", "phone": "+70169317304"}
0005432460227	3854E3	5657 053459	TAISIYA DANILOVA	{"phone": "+70635919518"}
0005432460228	57EB77	8955 461069	ZINAIDA MEDVEDEVA	{"email": "zinaida_medvedeva_1970@postgrespro.ru", "phone": "+70332114672"}
0005432460229	57EB77	8262 357931	ALEKSEY ZAYCEV	{"email": "zaycev.a-1971@postgrespro.ru", "phone": "+70933582383"}
0005432460230	5E59A1	2989 397465	SVETLANA FADEEVA	{"email": "sfadeeva1972@postgrespro.ru", "phone": "+70500493893"}
0005432460231	40F381	5326 662009	MARINA NESTEROVA	{"email": "nesterova-marina_021972@postgrespro.ru", "phone": "+70832740422"}
0005432460232	E373BF	2707 630639	ELENA DANILOVA	{"phone": "+70334012996"}
0005432460233	DC080B	6934 483815	ELENA DANILOVA	{"phone": "+70176856333"}
0005432460234	DC080B	3952 009217	ALEKSANDR DAVYDOV	{"phone": "+70685589369"}
0005432460235	A58412	2156 336981	VALERIYA ZAYCEVA	{"email": "vzayceva1963@postgrespro.ru", "phone": "+70533905058"}
0005432460236	2B3267	6835 547049	NATALYA MEDVEDEVA	{"phone": "+70561020785"}
0005432460237	2B3267	4759 084131	OLGA KOROLEVA	{"phone": "+70499658435"}
0005432460238	C27D46	5208 193233	NAIL EGOROV	{"phone": "+70431318576"}
0005432460239	C27D46	9652 788110	NATALYA PETROVA	{"phone": "+70558493657"}
0005432460240	B43856	6172 739595	NATALYA BELOVA	{"email": "natalya.belova.1973@postgrespro.ru", "phone": "+70232553245"}
0005432460241	89C635	7346 294703	GALINA POPOVA	{"phone": "+70396485968"}
0005432460242	983F68	4625 555248	RASHID KUZMIN	{"phone": "+70022945216"}
0005432460243	D9B6D0	8054 862180	OLGA BELYAEVA	{"phone": "+70859995937"}
0005432460244	8F92AE	9019 560143	IVAN NIKITIN	{"email": "i_nikitin.22021975@postgrespro.ru", "phone": "+70361468687"}
0005432460245	22D272	8651 387682	MARIYA ERMAKOVA	{"phone": "+70298499940"}
0005432460246	412DF1	4507 341223	PETR GRIGOREV	{"email": "grigorev.p1976@postgrespro.ru", "phone": "+70626505533"}
0005432460247	20EEE4	3269 300247	VALERIY NIKOLAEV	{"phone": "+70275059910"}
0005432460248	20EEE4	1863 620541	ELENA KALININA	{"email": "elena.kalinina.1967@postgrespro.ru", "phone": "+70384396494"}
0005432460249	7C7376	5633 492615	VIKTORIYA NESTEROVA	{"email": "vnesterova27031971@postgrespro.ru", "phone": "+70741782478"}
0005432460250	C1C483	0710 382672	ALEKSANDR NAZAROV	{"phone": "+70311351854"}
0005432460251	07DFB4	5720 461662	ALEKSANDR MIRONOV	{"phone": "+70270307530"}
0005432460252	3ADD4D	9679 085359	RAISA AKIMOVA	{"email": "rakimova_121970@postgrespro.ru", "phone": "+70089564876"}
0005432460253	82A61D	6320 814717	ALEKSANDR KAZAKOV	{"phone": "+70783297120"}
0005432460254	350F62	1809 035234	SERGEY KISELEV	{"email": "s-kiselev-041976@postgrespro.ru", "phone": "+70948118791"}
0005432460255	585C08	9191 722954	ANATOLIY KUZNECOV	{"phone": "+70362042518"}
0005432460256	243DE8	6581 780325	YULIYA SEMENOVA	{"email": "semenova.yuliya.1962@postgrespro.ru", "phone": "+70562553912"}
0005432460257	243DE8	5392 077075	VIKTOR VLASOV	{"email": "vlasov.v021977@postgrespro.ru", "phone": "+70124224298"}
0005432460258	1FFBDA	1845 856534	LIDIYA POPOVA	{"phone": "+70198857722"}
0005432460259	1FFBDA	1514 676645	DMITRIY CHERNOV	{"email": "chernovd_27101965@postgrespro.ru", "phone": "+70808649746"}
0005432460260	45BE2B	8386 517421	STANISLAV KRASNOV	{"email": "s_krasnov1966@postgrespro.ru", "phone": "+70129652312"}
0005432460261	C15CC6	8372 533928	YURIY IVANOV	{"email": "ivanov_y.081976@postgrespro.ru", "phone": "+70382658646"}
0005432460262	C15CC6	1423 916668	EVGENIY FEDOROV	{"phone": "+70633669212"}
0005432460263	239D6F	2384 245808	YULIYA KULIKOVA	{"phone": "+70716505325"}
0005432460264	408230	9456 468587	NADEZHDA FROLOVA	{"phone": "+70960060891"}
0005432460265	408230	0939 309595	OLGA ZHURAVLEVA	{"phone": "+70229755300"}
0005432460266	C0846B	2665 131060	OLGA ALEKSEEVA	{"email": "olga.alekseeva_22091973@postgrespro.ru", "phone": "+70895658148"}
0005432460267	C0846B	7260 993327	LYUDMILA FEDOROVA	{"phone": "+70680217299"}
0005432460268	7F10AF	4343 373684	ALEKSANDR ROMANOV	{"email": "romanov_a_111983@postgrespro.ru", "phone": "+70753919224"}
0005432460269	7F10AF	6943 864217	OLGA EFREMOVA	{"email": "o_efremova.1964@postgrespro.ru", "phone": "+70844948789"}
0005432460270	4FEE39	5622 141934	OLGA MARTYNOVA	{"email": "o_martynova1967@postgrespro.ru", "phone": "+70852534089"}
0005432460271	9626A4	7577 243290	RUSTAM KONOVALOV	{"phone": "+70548950683"}
0005432460272	AFFF18	2193 454903	DANIL DMITRIEV	{"phone": "+70265165688"}
0005432460273	B2DC01	9218 619389	ALEKSEY AFANASEV	{"phone": "+70077915636"}
0005432460274	B2DC01	9526 256372	ANDREY MOROZOV	{"email": "morozova061969@postgrespro.ru", "phone": "+70493429532"}
0005432460275	A5599B	4575 200046	ZOYA MAKSIMOVA	{"phone": "+70685754177"}
0005432460276	C95D62	0533 244704	MARIYA MAKAROVA	{"email": "makarovam.18011972@postgrespro.ru", "phone": "+70649212930"}
0005432460277	68A149	3036 844270	NIKOLAY KULIKOV	{"email": "kulikov_nikolay_1976@postgrespro.ru", "phone": "+70535376227"}
0005432460278	4F9EBD	3989 948092	GALINA OSIPOVA	{"email": "osipova-g.1971@postgrespro.ru", "phone": "+70892533509"}
0005432460279	345750	1178 646837	TATYANA ZAYCEVA	{"phone": "+70345128254"}
0005432460280	B65F0C	4711 615796	ALEKSANDR MIKHAYLOV	{"phone": "+70614913321"}
0005432460281	BD23DD	0080 595532	OLGA SCHERBAKOVA	{"email": "scherbakovao1970@postgrespro.ru", "phone": "+70160932517"}
0005432460282	6C5CDE	3642 593966	ROMAN TARASOV	{"phone": "+70000653120"}
0005432460283	35DB6A	3615 264230	TATYANA KOMAROVA	{"phone": "+70803129315"}
0005432460284	7820A4	6498 900769	GALINA ERMAKOVA	{"email": "galinaermakova.01051967@postgrespro.ru", "phone": "+70595568268"}
0005432460285	4FD39E	8848 942876	MIKHAIL PAVLOV	{"email": "pavlov.mikhail111969@postgrespro.ru", "phone": "+70643134496"}
0005432460286	4FD39E	0547 125343	ROZALIYA ANTONOVA	{"email": "antonovar.1971@postgrespro.ru", "phone": "+70476007390"}
0005432460287	D8063D	6940 893773	YANA KONOVALOVA	{"email": "konovalova-yana1981@postgrespro.ru", "phone": "+70007449127"}
0005432460288	F44466	4961 411457	NADEZHDA KISELEVA	{"email": "nadezhdakiseleva-071975@postgrespro.ru", "phone": "+70904806233"}
0005432460289	AEC9BB	2901 294597	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev.20071970@postgrespro.ru", "phone": "+70604328642"}
0005432460290	901E2B	9701 941920	LYUDMILA MIRONOVA	{"phone": "+70444654237"}
0005432460291	901E2B	7628 140110	RASIM DAVYDOV	{"email": "davydov_r1982@postgrespro.ru", "phone": "+70273704178"}
0005432460292	608589	6887 220740	ALEKSANDR VLASOV	{"phone": "+70730270976"}
0005432460293	7BE339	7796 967237	NELLI ANDREEVA	{"email": "andreevanelli_14101973@postgrespro.ru", "phone": "+70595443940"}
0005432460294	7BE339	6284 538278	VALENTINA MOROZOVA	{"phone": "+70875235018"}
0005432460295	F6FDBB	6811 390390	MIKHAIL SOKOLOV	{"email": "mikhailsokolov.1985@postgrespro.ru", "phone": "+70976046048"}
0005432460296	4ECDEC	4390 907564	ALEKSANDR FROLOV	{"email": "frolov-a-31101969@postgrespro.ru", "phone": "+70566749987"}
0005432460297	CE4664	6258 757374	ALEKSANDR MARTYNOV	{"phone": "+70079035306"}
0005432460298	CE4664	8125 905179	NADEZHDA KRASNOVA	{"phone": "+70224441170"}
0005432460299	E8BEE0	1598 460282	ELENA VOROBEVA	{"email": "elenavorobeva-101978@postgrespro.ru", "phone": "+70510698165"}
0005432460300	13807F	1020 287078	STANISLAV PETROV	{"email": "petrov-stanislav_1981@postgrespro.ru", "phone": "+70013580360"}
0005432460301	C90246	7581 433468	VLADIMIR KUZMIN	{"email": "kuzminvladimir-011981@postgrespro.ru", "phone": "+70272482123"}
0005432460302	C90246	0119 109036	LILIYA SERGEEVA	{"email": "sergeevaliliya-22081969@postgrespro.ru", "phone": "+70001354564"}
0005432460303	F053F3	6939 239560	ARTEM NAZAROV	{"email": "anazarov03061975@postgrespro.ru", "phone": "+70485186141"}
0005432460304	BBABC8	6640 186222	ALEKSANDR ZAYCEV	{"email": "a.zaycev071981@postgrespro.ru", "phone": "+70179522100"}
0005432460305	A58967	9525 299748	GENNADIY ORLOV	{"email": "orlov_g1983@postgrespro.ru", "phone": "+70300913943"}
0005432460306	A58967	9857 152699	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.03041967@postgrespro.ru", "phone": "+70450046360"}
0005432460307	724043	4571 982616	VITALIY KOROLEV	{"phone": "+70921809595"}
0005432460308	4DFE77	2724 174720	YULIYA VLASOVA	{"phone": "+70241293500"}
0005432460309	97D95F	8606 002517	NIKOLAY POPOV	{"email": "npopov.1977@postgrespro.ru", "phone": "+70386559792"}
0005432460310	0EAD44	8837 613984	VLADISLAV SOKOLOV	{"email": "sokolov.vladislav031968@postgrespro.ru", "phone": "+70308706770"}
0005432460311	749B44	0355 958732	SVETLANA KONOVALOVA	{"email": "s.konovalova041973@postgrespro.ru", "phone": "+70090799475"}
0005432460312	30D017	3608 351120	LYUBOV SMIRNOVA	{"email": "lyubov_smirnova_25031969@postgrespro.ru", "phone": "+70092495125"}
0005432460313	30D017	4948 562087	TATYANA BELOVA	{"email": "belova.t_18011974@postgrespro.ru", "phone": "+70470068751"}
0005432460314	93C7D5	2048 720272	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov1963@postgrespro.ru", "phone": "+70350652468"}
0005432460315	93C7D5	0663 652860	DENIS SCHERBAKOV	{"email": "d_scherbakov11111969@postgrespro.ru", "phone": "+70157310674"}
0005432460316	B82325	3674 285413	LYUDMILA GERASIMOVA	{"email": "gerasimova-l101975@postgrespro.ru", "phone": "+70089220436"}
0005432460317	902CA4	7694 623667	YULIYA NIKIFOROVA	{"email": "nikiforovay-1971@postgrespro.ru", "phone": "+70555431558"}
0005432460318	902CA4	0438 916820	VALENTINA ANDREEVA	{"phone": "+70271199578"}
0005432460319	902CA4	4218 187458	GALINA VASILEVA	{"phone": "+70646643759"}
0005432460320	D8A8F9	9535 126009	LYUDMILA KULIKOVA	{"phone": "+70336887286"}
0005432460321	D8A8F9	6697 915335	ANATOLIY NIKOLAEV	{"email": "anatoliy-nikolaev_29041969@postgrespro.ru", "phone": "+70014337666"}
0005432460322	D8A8F9	6402 975017	ALIYA SCHERBAKOVA	{"phone": "+70470893876"}
0005432460323	D599F4	9156 380664	TATYANA MAKSIMOVA	{"phone": "+70486260113"}
0005432460324	4C10CA	9292 442124	OLGA TARASOVA	{"phone": "+70065979813"}
0005432460325	B045B1	9365 251462	MAKSIM PETROV	{"email": "petrov_m.06071970@postgrespro.ru", "phone": "+70940144739"}
0005432460326	B045B1	8632 115784	GALINA KONDRATEVA	{"phone": "+70619339530"}
0005432460327	2D2996	2990 889934	IRINA LOGINOVA	{"email": "irina.loginova_1967@postgrespro.ru", "phone": "+70929451086"}
0005432460328	25E831	1925 647754	EVGENIY FEDOROV	{"phone": "+70377648134"}
0005432460329	F09701	4201 758929	VERONIKA KONOVALOVA	{"email": "konovalova_v-1961@postgrespro.ru", "phone": "+70325397745"}
0005432460330	F09701	1509 255727	NATALYA BELYAEVA	{"email": "natalya.belyaeva_1976@postgrespro.ru", "phone": "+70484545936"}
0005432460331	F09701	5463 017614	ELENA KOZLOVA	{"phone": "+70793326060"}
0005432460332	168F51	4255 605201	VLADIMIR STEPANOV	{"email": "stepanov_v_11031974@postgrespro.ru", "phone": "+70512072671"}
0005432460333	83C7E4	2232 924706	OLGA SMIRNOVA	{"email": "smirnovaolga07111980@postgrespro.ru", "phone": "+70663944713"}
0005432460334	0365E4	1169 490360	ANDREY SIDOROV	{"phone": "+70799964288"}
0005432460335	C64548	5571 269072	LYUBOV MAKAROVA	{"phone": "+70871144177"}
0005432460336	A64800	6515 692204	RAISA LEBEDEVA	{"phone": "+70909420785"}
0005432460337	E6834E	5706 308617	NATALIYA EFIMOVA	{"phone": "+70432752811"}
0005432460338	E6834E	1706 860308	NADEZHDA PETROVA	{"phone": "+70529943965"}
0005432460339	5C6C7C	8061 486197	ALEKSANDR ZHUKOV	{"email": "zhukov-aleksandr_041970@postgrespro.ru", "phone": "+70626139029"}
0005432460340	BA0657	7762 121317	SERGEY NIKOLAEV	{"email": "nikolaev_s-14021978@postgrespro.ru", "phone": "+70713906005"}
0005432460341	BA0657	1715 632948	ALEKSANDR NOVIKOV	{"email": "novikova-1966@postgrespro.ru", "phone": "+70825993395"}
0005432460342	0ED007	7785 156074	YAN TARASOV	{"email": "tarasov_yan.091978@postgrespro.ru", "phone": "+70377367780"}
0005432460343	698209	3043 007020	SVETLANA BORISOVA	{"phone": "+70835460010"}
0005432460344	6DD8C7	8355 422067	ANATOLIY GORBUNOV	{"email": "gorbunovanatoliy-051976@postgrespro.ru", "phone": "+70797584586"}
0005432460345	6DD8C7	7642 752258	SERGEY SOLOVEV	{"email": "s_solovev-1987@postgrespro.ru", "phone": "+70478853396"}
0005432460346	457E56	3192 159728	LARISA MELNIKOVA	{"phone": "+70320216084"}
0005432460347	457E56	9936 995448	GALINA VOROBEVA	{"email": "vorobeva-galina1970@postgrespro.ru", "phone": "+70209973070"}
0005432460348	AD4793	0763 762262	ANASTASIYA ZAKHAROVA	{"phone": "+70204385210"}
0005432460349	5FF6C5	8032 690893	EVGENIY FOMIN	{"email": "fomin_e041978@postgrespro.ru", "phone": "+70307872030"}
0005432460350	CCC28F	0139 331222	LIDIYA NIKOLAEVA	{"phone": "+70891677498"}
0005432460351	9414A7	3219 670901	OLGA TITOVA	{"email": "titova-olga.111980@postgrespro.ru", "phone": "+70880406873"}
0005432460352	BB47A3	8862 510200	VLADIMIR SERGEEV	{"email": "sergeev_v.1994@postgrespro.ru", "phone": "+70692701846"}
0005432460353	F44429	9390 856396	ILYA KUZNECOV	{"email": "kuznecov_ilya1981@postgrespro.ru", "phone": "+70190427703"}
0005432460354	F44429	1801 823284	MARINA STEPANOVA	{"phone": "+70662194358"}
0005432460355	F44429	5096 735547	ILFAT POPOV	{"email": "ilfatpopov.081958@postgrespro.ru", "phone": "+70211628434"}
0005432460356	BC8EA6	0326 289246	YANA MASLOVA	{"email": "maslovay_061965@postgrespro.ru", "phone": "+70898687292"}
0005432460357	C80983	7544 505399	ALEKSANDRA SOROKINA	{"email": "sorokina-a1970@postgrespro.ru", "phone": "+70994780056"}
0005432460358	AA0AAF	5812 420607	ANTONINA KUZMINA	{"phone": "+70381205202"}
0005432460359	3E0C5B	5927 222664	VIKTORIYA EFREMOVA	{"phone": "+70138993533"}
0005432460360	3E0C5B	6650 001088	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr1972@postgrespro.ru", "phone": "+70850549954"}
0005432460361	2EDE45	2404 042838	EKATERINA POLYAKOVA	{"phone": "+70682649994"}
0005432460362	2EDE45	6162 178264	OLGA KULIKOVA	{"phone": "+70530234667"}
0005432460363	DCE575	9682 780851	RUFINA NIKIFOROVA	{"email": "rufina.nikiforova.30041969@postgrespro.ru", "phone": "+70599863300"}
0005432460364	DCE575	2964 266619	LYUBOV FILATOVA	{"email": "filatovalyubov-101967@postgrespro.ru", "phone": "+70895958770"}
0005432460365	8E35B2	6419 019781	NADEZHDA SERGEEVA	{"email": "n.sergeeva_021964@postgrespro.ru", "phone": "+70050309584"}
0005432460366	60BE1D	2487 418313	VALENTINA IVANOVA	{"email": "valentinaivanova051972@postgrespro.ru", "phone": "+70980324197"}
0005432460367	F87897	7930 727727	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov-1977@postgrespro.ru", "phone": "+70078512727"}
0005432460368	E2149A	9400 122393	IRINA PETROVA	{"phone": "+70095550700"}
0005432460369	A9C305	3784 932805	ALEKSANDR KONOVALOV	{"phone": "+70359567981"}
0005432460370	20139B	5441 896367	IVAN ANDREEV	{"phone": "+70618360714"}
0005432460371	B098DF	5967 242327	RINAT MELNIKOV	{"email": "rinat.melnikov_011976@postgrespro.ru", "phone": "+70389986838"}
0005432460372	232844	4683 853925	NADEZHDA LOGINOVA	{"email": "nadezhda_loginova20061978@postgrespro.ru", "phone": "+70121645649"}
0005432460373	232844	4972 189024	IRINA ANTONOVA	{"email": "iantonova-1969@postgrespro.ru", "phone": "+70590615192"}
0005432460374	9A015A	8752 892007	NADEZHDA KUZMINA	{"phone": "+70425588063"}
0005432460375	9A015A	9206 665083	OLEG CHERNOV	{"phone": "+70541771864"}
0005432460376	D497F9	3989 348517	ALEKSANDR NAZAROV	{"email": "a.nazarov_1980@postgrespro.ru", "phone": "+70210402953"}
0005432460377	D497F9	2734 886823	DMITRIY ALEKSANDROV	{"email": "d.aleksandrov_15031976@postgrespro.ru", "phone": "+70072842660"}
0005432460378	C2CBC0	0507 201753	LYUDMILA KOMAROVA	{"email": "komarova-l11041970@postgrespro.ru", "phone": "+70807752681"}
0005432460379	C2CBC0	5101 876463	ANDREY AFANASEV	{"email": "afanasev-a.25031972@postgrespro.ru", "phone": "+70606353067"}
0005432460380	C2CBC0	9229 460456	ANASTASIYA NAUMOVA	{"phone": "+70402145793"}
0005432460381	80A55F	7260 862808	SERGEY ZHURAVLEV	{"email": "zhuravlev-sergey-07051971@postgrespro.ru", "phone": "+70337341461"}
0005432460382	6144AD	1195 677592	ANATOLIY ZAYCEV	{"phone": "+70274623290"}
0005432460383	089C82	8211 500900	EVGENIYA DENISOVA	{"email": "evgeniya_denisova.10091974@postgrespro.ru", "phone": "+70502369743"}
0005432460384	AF76DA	8893 215633	EKATERINA DAVYDOVA	{"phone": "+70684814446"}
0005432460385	AF76DA	7926 072433	LARISA SOKOLOVA	{"phone": "+70523144070"}
0005432460386	AD8DA1	0168 135812	ANTON POPOV	{"phone": "+70518586184"}
0005432460387	2CD5DC	7715 455592	ARMEN ANTONOV	{"email": "antonov_a-1968@postgrespro.ru", "phone": "+70127746773"}
0005432460388	C68CE6	9160 189707	DMITRIY POPOV	{"phone": "+70054680611"}
0005432460389	C68CE6	4368 816234	EKATERINA GAVRILOVA	{"phone": "+70049147776"}
0005432460390	C68CE6	5737 126253	ALEKSANDR SEMENOV	{"email": "semenov.a_011978@postgrespro.ru", "phone": "+70998011608"}
0005432460391	75F156	4737 174723	YURIY SCHERBAKOV	{"phone": "+70144461605"}
0005432460392	E5927D	0700 825482	LYUDMILA POLYAKOVA	{"phone": "+70062256654"}
0005432460393	E5927D	4941 111815	LYUDMILA NIKITINA	{"email": "nikitinalyudmila_1979@postgrespro.ru", "phone": "+70922192518"}
0005432460394	465B91	9198 338629	IRINA ROMANOVA	{"phone": "+70305099136"}
0005432460395	465B91	5334 299728	EKATERINA IVANOVA	{"email": "ivanova.e_14021977@postgrespro.ru", "phone": "+70628456675"}
0005432460396	BA18EC	1716 184337	ANDREY SIDOROV	{"phone": "+70496541201"}
0005432460397	6633D0	2531 923016	VALENTINA LUKYANOVA	{"email": "lukyanovav.031972@postgrespro.ru", "phone": "+70690113119"}
0005432460398	C553E1	8622 390280	SAMVEL SCHERBAKOV	{"email": "s.scherbakov17021963@postgrespro.ru", "phone": "+70806573465"}
0005432460399	53EF32	9779 567211	ALINA IVANOVA	{"email": "ivanova_a.1982@postgrespro.ru", "phone": "+70318330497"}
0005432460400	561518	6348 008475	NATALYA IVANOVA	{"email": "n_ivanova.28091969@postgrespro.ru", "phone": "+70145918915"}
0005432460401	699494	9819 292200	KONSTANTIN ANTONOV	{"email": "konstantin_antonov-011975@postgrespro.ru", "phone": "+70531175551"}
0005432460402	3254A4	5946 110189	ANATOLIY MIKHAYLOV	{"email": "mikhaylov.anatoliy.16091973@postgrespro.ru", "phone": "+70120305206"}
0005432460403	3254A4	7189 958256	ANASTASIYA GORBUNOVA	{"phone": "+70354019347"}
0005432460404	3254A4	2208 562631	SEMEN ZAKHAROV	{"phone": "+70975958069"}
0005432460405	56D6AB	0630 712780	KIRILL SHEVCHENKO	{"phone": "+70807576603"}
0005432460406	56D6AB	7051 724908	ALEKSANDRA SMIRNOVA	{"phone": "+70539813561"}
0005432460407	0C6E35	8005 674957	TATYANA SOLOVEVA	{"email": "tatyana-soloveva-021971@postgrespro.ru", "phone": "+70951582743"}
0005432460408	0C6E35	7138 885973	DARYA GAVRILOVA	{"phone": "+70740866070"}
0005432460409	3CD4B2	4122 981379	ZINAIDA TIMOFEEVA	{"email": "zinaida_timofeeva121963@postgrespro.ru", "phone": "+70622780645"}
0005432460410	3CD4B2	6675 463678	MARINA TARASOVA	{"phone": "+70436371911"}
0005432460411	E18FFF	2801 605769	ANNA SERGEEVA	{"email": "sergeeva.anna.17041969@postgrespro.ru", "phone": "+70326743170"}
0005432460412	C768EA	3516 947058	ANDREY POPOV	{"email": "andreypopov-10071975@postgrespro.ru", "phone": "+70301021797"}
0005432460413	2EC0E8	3225 067838	GALINA MIKHAYLOVA	{"phone": "+70789476468"}
0005432460414	2EC0E8	3250 548045	POLINA NAZAROVA	{"email": "pnazarova1971@postgrespro.ru", "phone": "+70563329713"}
0005432460415	F3A6FE	5617 583417	ANDREY DENISOV	{"phone": "+70440156303"}
0005432460416	D98D8D	7683 511293	EVGENIY DENISOV	{"phone": "+70139414967"}
0005432460417	D98D8D	4868 379726	GALINA FEDOROVA	{"phone": "+70348598231"}
0005432460418	9858F2	7534 863221	ALEKSANDR ANDREEV	{"phone": "+70303818591"}
0005432460419	66FB04	5470 543572	TATYANA SOKOLOVA	{"email": "tatyana-sokolova-04101980@postgrespro.ru", "phone": "+70771088704"}
0005432460420	65A2B8	9632 630982	NATALYA VOLKOVA	{"email": "volkovanatalya01071976@postgrespro.ru", "phone": "+70761088576"}
0005432460421	7550E4	0431 544818	YURIY SOROKIN	{"phone": "+70920215127"}
0005432460422	7550E4	3930 896458	OLEG ROMANOV	{"email": "romanov_o1954@postgrespro.ru", "phone": "+70116426726"}
0005432460423	242EF7	0776 674693	NATALYA KOROLEVA	{"email": "n.koroleva1965@postgrespro.ru", "phone": "+70856372242"}
0005432460424	885C5C	4721 359106	EKATERINA EGOROVA	{"email": "egorova-e121971@postgrespro.ru", "phone": "+70966126028"}
0005432460425	885C5C	2997 799962	TATYANA STEPANOVA	{"phone": "+70728038926"}
0005432460426	A6A206	4963 612191	LYUDMILA IVANOVA	{"email": "ivanoval021978@postgrespro.ru", "phone": "+70223335078"}
0005432460427	A1E7BF	4950 571028	IGOR NIKITIN	{"phone": "+70202527327"}
0005432460428	2DB37F	4704 558129	NINA AKIMOVA	{"email": "n-akimova_19071955@postgrespro.ru", "phone": "+70488686124"}
0005432460429	2DB37F	7675 706489	RASHID BARANOV	{"email": "r-baranov031962@postgrespro.ru", "phone": "+70909788921"}
0005432460430	1126D2	3467 336706	VLADIMIR CHERNOV	{"email": "vchernov091976@postgrespro.ru", "phone": "+70862342542"}
0005432460431	2E801E	0894 914911	TATYANA POTAPOVA	{"phone": "+70148438796"}
0005432460432	2E801E	1677 711305	TATYANA NAUMOVA	{"email": "naumovat-24041967@postgrespro.ru", "phone": "+70936986119"}
0005432460433	108696	3451 547075	RUSTAM KONOVALOV	{"email": "konovalov_r-11111975@postgrespro.ru", "phone": "+70480169643"}
0005432460434	108696	5813 207165	SERGEY PETROV	{"email": "spetrov1971@postgrespro.ru", "phone": "+70037442546"}
0005432460435	781042	2691 202654	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov.071976@postgrespro.ru", "phone": "+70851541568"}
0005432460436	781042	9155 604091	ELENA BOGDANOVA	{"email": "elena-bogdanova02031965@postgrespro.ru", "phone": "+70029371201"}
0005432460437	0CC60B	1718 080542	MIKHAIL MARTYNOV	{"phone": "+70812987567"}
0005432460438	4F71C9	6862 503296	ALEKSANDRA GAVRILOVA	{"email": "a.gavrilova-1970@postgrespro.ru", "phone": "+70362737588"}
0005432460439	974E5F	8997 686516	DENIS NOVIKOV	{"email": "novikov_denis-29031972@postgrespro.ru", "phone": "+70120931531"}
0005432460440	EB46C3	5050 887973	VIKTOR GRIGOREV	{"email": "v_grigorev.28051964@postgrespro.ru", "phone": "+70208576141"}
0005432460441	D72538	3811 110796	VLADIMIR GORBUNOV	{"phone": "+70219126186"}
0005432460442	2B1E6C	0802 556411	VALENTINA POLYAKOVA	{"email": "v_polyakova081976@postgrespro.ru", "phone": "+70670833548"}
0005432460443	2B1E6C	3159 572855	SVETLANA MEDVEDEVA	{"email": "medvedevas071969@postgrespro.ru", "phone": "+70917003252"}
0005432460444	9C9FB0	7327 120944	STANISLAV STEPANOV	{"phone": "+70047700486"}
0005432460445	F915D3	7421 122274	VALENTINA RODIONOVA	{"phone": "+70735420815"}
0005432460446	E7706E	8070 825897	ANATOLIY PAVLOV	{"email": "pavlov.a-1971@postgrespro.ru", "phone": "+70922838027"}
0005432460447	14B5E9	8133 806572	VLADIMIR BARANOV	{"phone": "+70260499798"}
0005432460448	181CA8	9854 839768	TATYANA NESTEROVA	{"phone": "+70012462542"}
0005432460449	9D93CF	0418 869827	ANDREY ZAYCEV	{"email": "andrey_zaycev-061978@postgrespro.ru", "phone": "+70065565950"}
0005432460450	9D93CF	4710 761478	MAKSIM RODIONOV	{"email": "rodionov_m_1977@postgrespro.ru", "phone": "+70679294301"}
0005432460451	7EF2A5	6369 495368	PAVEL ALEKSANDROV	{"email": "paleksandrov1965@postgrespro.ru", "phone": "+70453605953"}
0005432460452	7EF2A5	4023 632903	YULIYA OSIPOVA	{"phone": "+70160592786"}
0005432460453	8C00FA	4390 141452	IVAN POPOV	{"email": "ivan.popov06081958@postgrespro.ru", "phone": "+70210235665"}
0005432460454	8C00FA	2780 866295	STEPAN KOROLEV	{"phone": "+70809186487"}
0005432460455	3F428C	9433 781244	ALENA SERGEEVA	{"phone": "+70184476700"}
0005432460456	938662	8009 407895	ALEKSEY PETROV	{"email": "apetrov-091974@postgrespro.ru", "phone": "+70978191434"}
0005432460457	9ADC12	6307 199307	IVAN NAZAROV	{"phone": "+70750734057"}
0005432460458	70CB90	2018 996027	ANATOLIY IVANOV	{"email": "ivanov-a1970@postgrespro.ru", "phone": "+70175383568"}
0005432460459	96412F	6123 393868	IGOR ZAYCEV	{"email": "igor.zaycev-061969@postgrespro.ru", "phone": "+70796997472"}
0005432460460	96412F	2527 310574	ANATOLIY KONOVALOV	{"phone": "+70046090977"}
0005432460461	96412F	5099 889378	DMITRIY SAVELEV	{"email": "savelev_dmitriy04101967@postgrespro.ru", "phone": "+70355518454"}
0005432460462	F6DA44	7893 853788	LARISA KUZMINA	{"phone": "+70346558656"}
0005432460463	057C1C	1263 799122	YULIYA NAZAROVA	{"phone": "+70609811230"}
0005432460464	057C1C	8406 290043	VASILISA YAKOVLEVA	{"email": "yakovlevavasilisa_17061980@postgrespro.ru", "phone": "+70737670531"}
0005432460465	A68E5E	1919 845697	DMITRIY PETROV	{"email": "petrov.d121977@postgrespro.ru", "phone": "+70632766944"}
0005432460466	A68E5E	3122 917984	NIKITA ALEKSEEV	{"email": "n-alekseev.1966@postgrespro.ru", "phone": "+70079343041"}
0005432460467	ECB936	8740 928993	MATVEY FEDOTOV	{"email": "fedotov.matvey_081973@postgrespro.ru", "phone": "+70272557949"}
0005432460468	6F6793	1551 393785	IRINA MARTYNOVA	{"email": "martynova-i12051979@postgrespro.ru", "phone": "+70129022489"}
0005432460469	1FB4CE	9317 166019	NIKITA NIKITIN	{"email": "nikitin-n.1973@postgrespro.ru", "phone": "+70601784629"}
0005432460470	1FB4CE	3695 694356	YULIYA IVANOVA	{"phone": "+70025429623"}
0005432460471	704541	4468 020370	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr-28041978@postgrespro.ru", "phone": "+70349270368"}
0005432460472	515449	2122 953383	TATYANA EGOROVA	{"phone": "+70970701414"}
0005432460473	515449	3849 516476	VYACHESLAV OSIPOV	{"email": "osipov.vyacheslav.091977@postgrespro.ru", "phone": "+70802552286"}
0005432460474	CECDD7	6894 624790	MILANA ARKHIPOVA	{"phone": "+70495265696"}
0005432460475	CECDD7	8787 433259	ALEKSEY NOVIKOV	{"phone": "+70634813804"}
0005432460476	431B6F	7159 268604	IRINA SMIRNOVA	{"email": "i_smirnova-1968@postgrespro.ru", "phone": "+70649855764"}
0005432460477	431B6F	4593 082598	TATYANA PAVLOVA	{"email": "tatyana.pavlova-1979@postgrespro.ru", "phone": "+70544595787"}
0005432460478	8E513D	4089 273972	KONSTANTIN SHEVCHENKO	{"email": "shevchenko_konstantin_1972@postgrespro.ru", "phone": "+70848596543"}
0005432460479	75DC0D	1690 313491	IVAN BARANOV	{"email": "ibaranov_111967@postgrespro.ru", "phone": "+70128784508"}
0005432460480	75DC0D	4018 407870	MIKHAIL CHERNOV	{"phone": "+70940337544"}
0005432460481	F8360B	9262 223742	IVAN EGOROV	{"phone": "+70345017875"}
0005432460482	866F27	8746 045090	GENNADIY POPOV	{"email": "gennadiy.popov.061976@postgrespro.ru", "phone": "+70606546745"}
0005432460483	FE58B1	8478 390464	ANNA KUZMINA	{"email": "kuzminaa1978@postgrespro.ru", "phone": "+70464070408"}
0005432460484	FE58B1	6874 856184	LYUDMILA KALININA	{"email": "lkalinina05011966@postgrespro.ru", "phone": "+70981646997"}
0005432460485	FDD471	0017 799659	ZUKHRA SOROKINA	{"email": "zukhra.sorokina_081973@postgrespro.ru", "phone": "+70954671955"}
0005432460486	FDD471	8647 551357	DMITRIY MOROZOV	{"email": "morozov_d1971@postgrespro.ru", "phone": "+70866112868"}
0005432460487	AB885C	2829 405367	ROMAN PAVLOV	{"email": "roman-pavlov_121962@postgrespro.ru", "phone": "+70401352086"}
0005432460488	C8A21C	6459 995426	GENNADIY ORLOV	{"phone": "+70520857699"}
0005432460489	C8A21C	1520 699328	ANTONINA IVANOVA	{"email": "ivanova.antonina.02021968@postgrespro.ru", "phone": "+70880272423"}
0005432460490	C8A21C	2332 060516	MIKHAIL KUDRYASHOV	{"email": "m_kudryashov-1965@postgrespro.ru", "phone": "+70149643295"}
0005432460491	2161AF	6884 724176	VIKTOR BORISOV	{"phone": "+70573857123"}
0005432460492	8EAA22	8399 885291	ARINA SCHERBAKOVA	{"phone": "+70614001435"}
0005432460493	AB298F	2045 166309	SHAMIL PAVLOV	{"phone": "+70475995333"}
0005432460494	DB9DFB	2621 405112	LYUBOV SOLOVEVA	{"phone": "+70565471354"}
0005432460495	20A945	7166 876649	PETR KULIKOV	{"phone": "+70037697240"}
0005432460496	817EE4	9274 995166	ALEKSANDR ILIN	{"phone": "+70793850610"}
0005432460497	05F6C3	1888 340159	ANDREY STEPANOV	{"phone": "+70071548453"}
0005432460498	780B5D	9921 837355	ANDREY AFANASEV	{"email": "aafanasev.18121969@postgrespro.ru", "phone": "+70126050079"}
0005432460499	C5D47F	6894 608469	ANZHELA TIKHONOVA	{"email": "a.tikhonova_1977@postgrespro.ru", "phone": "+70772885543"}
0005432460500	C5D47F	4763 307972	YULIYA VASILEVA	{"email": "vasileva_y.1970@postgrespro.ru", "phone": "+70315144224"}
0005432460501	E102A4	1762 077468	OLEG PETROV	{"phone": "+70381064329"}
0005432460502	E102A4	2315 521444	DIANA POPOVA	{"email": "d_popova.1979@postgrespro.ru", "phone": "+70426702138"}
0005432460503	1BC2BE	6594 015420	IRINA AFANASEVA	{"email": "iafanaseva-1970@postgrespro.ru", "phone": "+70126577784"}
0005432460504	1BC2BE	7949 668917	TATYANA ROMANOVA	{"email": "tromanova071981@postgrespro.ru", "phone": "+70830574155"}
0005432460505	549E77	3324 292533	BORIS KULIKOV	{"email": "bkulikov1987@postgrespro.ru", "phone": "+70247598576"}
0005432460506	6C21B8	1408 895189	RAISA FADEEVA	{"phone": "+70100306010"}
0005432460507	6C21B8	3704 017196	OLEG MATVEEV	{"phone": "+70421183181"}
0005432460508	6C21B8	9722 510946	EMIL NOVIKOV	{"phone": "+70505439487"}
0005432460509	200FA9	6293 624753	MARINA SOKOLOVA	{"phone": "+70484283628"}
0005432460510	B3B959	8622 144723	SERGEY NIKOLAEV	{"email": "nikolaevsergey.041970@postgrespro.ru", "phone": "+70772708605"}
0005432460511	B3B959	4744 107209	DIANA OVCHINNIKOVA	{"email": "d.ovchinnikova.07051970@postgrespro.ru", "phone": "+70700006373"}
0005432460512	9F1FAE	1448 223372	NIKOLAY MAKAROV	{"phone": "+70364480602"}
0005432460513	9F1FAE	9274 673059	TATYANA KOROLEVA	{"phone": "+70270932448"}
0005432460514	A0AE9B	2523 293989	EKATERINA SIDOROVA	{"email": "ekaterina-sidorova-1965@postgrespro.ru", "phone": "+70072604894"}
0005432460515	A545B1	7204 163737	ZHANNA MOROZOVA	{"phone": "+70804808038"}
0005432460516	B980C9	5699 297533	TATYANA AKIMOVA	{"phone": "+70811621195"}
0005432460517	B980C9	5808 282133	VALERIY SMIRNOV	{"email": "valeriysmirnov1973@postgrespro.ru", "phone": "+70266558946"}
0005432460518	2E3297	4040 470572	LYUDMILA MATVEEVA	{"phone": "+70033861581"}
0005432460519	2E3297	9543 127252	YAROSLAV ROMANOV	{"email": "yaroslav_romanov.1978@postgrespro.ru", "phone": "+70201869763"}
0005432460520	2E3297	5561 504563	POLINA TIKHONOVA	{"email": "tikhonova.polina-06021973@postgrespro.ru", "phone": "+70229970113"}
0005432460521	C5F9B2	0245 829043	OLGA ZAKHAROVA	{"phone": "+70870665657"}
0005432460522	C5F9B2	7158 686448	VLADIMIR BORISOV	{"email": "borisov-v041983@postgrespro.ru", "phone": "+70268272961"}
0005432460523	1264E9	1434 755593	ANDREY ABRAMOV	{"email": "andrey_abramov1971@postgrespro.ru", "phone": "+70684291409"}
0005432460524	50A548	9220 397990	NIKOLAY EGOROV	{"email": "egorovnikolay_1982@postgrespro.ru", "phone": "+70486356470"}
0005432460525	50A548	9911 154769	YURIY SERGEEV	{"phone": "+70011510196"}
0005432460526	3CDAE5	6360 196005	YURIY NOVIKOV	{"email": "novikov.yuriy.011974@postgrespro.ru", "phone": "+70393182389"}
0005432460527	345A44	0780 406760	VALERIY ZHUKOV	{"phone": "+70660041982"}
0005432460528	345A44	7001 379847	DMITRIY ROMANOV	{"email": "dromanov19041974@postgrespro.ru", "phone": "+70520759722"}
0005432460529	BB992A	6397 631656	YURIY SMIRNOV	{"email": "y-smirnov.31071970@postgrespro.ru", "phone": "+70736973734"}
0005432460530	E09455	0546 730746	SVETLANA NIKITINA	{"email": "s-nikitina111974@postgrespro.ru", "phone": "+70173936406"}
0005432460531	E09455	8207 701084	EVGENIY FOMIN	{"email": "evgeniyfomin-1977@postgrespro.ru", "phone": "+70631809781"}
0005432460532	3FEEC5	2190 673752	VADIM SOKOLOV	{"phone": "+70021827678"}
0005432460533	3FEEC5	8695 791333	ALEKSANDRA ZHURAVLEVA	{"email": "zhuravleva-aleksandra.111960@postgrespro.ru", "phone": "+70614495143"}
0005432460534	B615C5	2231 496802	KONSTANTIN ORLOV	{"email": "konstantin_orlov_041980@postgrespro.ru", "phone": "+70007797125"}
0005432460535	0C50EF	9352 934886	VLADIMIR CHERNOV	{"email": "chernovv-27061968@postgrespro.ru", "phone": "+70063694822"}
0005432460536	0C50EF	7243 804451	ANZHELIKA KUZNECOVA	{"phone": "+70580550850"}
0005432460537	933BD6	8524 643527	LEYLA NOVIKOVA	{"email": "leyla_novikova06071968@postgrespro.ru", "phone": "+70807019236"}
0005432460538	E3588C	8698 480330	OLGA MALYSHEVA	{"phone": "+70992258011"}
0005432460539	9631C1	0764 147173	ANNA VASILEVA	{"email": "vasileva_a.19071968@postgrespro.ru", "phone": "+70870701796"}
0005432460540	9631C1	6466 102606	ANGELINA KOLESNIKOVA	{"phone": "+70950669699"}
0005432460541	9631C1	6385 764552	MARIYA CHERNOVA	{"email": "mchernova.1976@postgrespro.ru", "phone": "+70434022845"}
0005432460542	830556	7349 658408	SERGEY VASILEV	{"email": "sergey-vasilev30051976@postgrespro.ru", "phone": "+70341225988"}
0005432460543	565E23	5702 198404	ANATOLIY PAVLOV	{"phone": "+70250264470"}
0005432460544	D07D5C	1807 237738	LYAYSAN GERASIMOVA	{"email": "gerasimoval-26081967@postgrespro.ru", "phone": "+70397535270"}
0005432460545	4B6BB9	3393 546560	TAISIYA IVANOVA	{"email": "ivanova.t1968@postgrespro.ru", "phone": "+70698978402"}
0005432460546	798CDA	6882 695932	TATYANA KUZNECOVA	{"email": "kuznecova_t-071974@postgrespro.ru", "phone": "+70513525888"}
0005432460547	285555	9087 577747	OLGA KOMAROVA	{"email": "o-komarova-081973@postgrespro.ru", "phone": "+70235543148"}
0005432460548	5CA609	3299 248402	VERA FEDOROVA	{"email": "v.fedorova-1979@postgrespro.ru", "phone": "+70659905633"}
0005432460549	5CA609	9137 767514	ALEKSANDRA FOMINA	{"email": "aleksandra_fomina.22091962@postgrespro.ru", "phone": "+70661763959"}
0005432460550	7A9DA2	7350 661748	EVGENIY NIKOLAEV	{"email": "enikolaev_1953@postgrespro.ru", "phone": "+70331909383"}
0005432460551	21338A	5497 168367	DMITRIY DAVYDOV	{"email": "davydov.dmitriy-29071977@postgrespro.ru", "phone": "+70252793261"}
0005432460552	94D384	9894 188571	MARAT ILIN	{"email": "ilin_marat_18041970@postgrespro.ru", "phone": "+70748012069"}
0005432460553	12D508	1157 947924	SERGEY SAVELEV	{"email": "s.savelev05011973@postgrespro.ru", "phone": "+70148785211"}
0005432460554	14B9A4	4353 334050	ANTONINA RODIONOVA	{"email": "arodionova_24051970@postgrespro.ru", "phone": "+70012086126"}
0005432460555	14B9A4	0768 728913	SVETLANA LAZAREVA	{"email": "s_lazareva021979@postgrespro.ru", "phone": "+70618280661"}
0005432460556	A71878	8891 761461	TATYANA NIKITINA	{"email": "nikitina-tatyana_31031970@postgrespro.ru", "phone": "+70329846294"}
0005432460557	94384F	2921 092132	RAFAIL BELOV	{"email": "r-belov_24061970@postgrespro.ru", "phone": "+70016229432"}
0005432460558	572EAF	3769 367654	NIKOLAY DMITRIEV	{"email": "n_dmitriev111978@postgrespro.ru", "phone": "+70479820383"}
0005432460559	B6FD34	7392 049708	IRINA POLYAKOVA	{"phone": "+70756622071"}
0005432460560	47A7B5	2137 655186	DANILA EGOROV	{"phone": "+70856620997"}
0005432460561	47A7B5	9471 423094	TATYANA ANTONOVA	{"phone": "+70046785546"}
0005432460562	5BDD70	5621 155335	VALENTINA PETROVA	{"phone": "+70415126724"}
0005432460563	80B4E3	9941 683371	SERGEY FILIPPOV	{"phone": "+70466946264"}
0005432460564	80B4E3	9508 931923	GALINA ISAEVA	{"phone": "+70986556746"}
0005432460565	38F686	0154 223710	LARISA PAVLOVA	{"email": "pavlova-l_11051968@postgrespro.ru", "phone": "+70667938503"}
0005432460566	DBD452	5123 618675	TATYANA PETROVA	{"email": "petrova_tatyana101970@postgrespro.ru", "phone": "+70344755446"}
0005432460567	247992	6041 033428	TATYANA NIKOLAEVA	{"phone": "+70015957677"}
0005432460568	247992	4773 153989	NIKOLAY PETROV	{"phone": "+70093044116"}
0005432460569	068D5E	6885 624578	ALEKSANDR BONDARENKO	{"phone": "+70230580125"}
0005432460570	068D5E	9405 297929	ANDREY TIKHONOV	{"phone": "+70695780500"}
0005432460571	54462C	9789 273450	YURIY SMIRNOV	{"email": "yuriy_smirnov-1978@postgrespro.ru", "phone": "+70795804718"}
0005432460572	54462C	3148 787283	DAMIR POPOV	{"email": "damir-popov30101967@postgrespro.ru", "phone": "+70904447131"}
0005432460573	54462C	1706 158592	YURIY POPOV	{"phone": "+70424449445"}
0005432460574	A843B1	7896 952237	MAKSIM NIKOLAEV	{"phone": "+70049617533"}
0005432460575	6BB566	5267 912897	ARTEM KUZNECOV	{"email": "artem.kuznecov_1974@postgrespro.ru", "phone": "+70138220208"}
0005432460576	6BB566	3699 453997	MARINA EFREMOVA	{"phone": "+70701035589"}
0005432460577	0142DA	7170 297266	RAISA OSIPOVA	{"email": "osipova_r_17011974@postgrespro.ru", "phone": "+70378501732"}
0005432460578	A2EDAE	8732 909883	NATALYA ROMANOVA	{"email": "romanova.natalya04031974@postgrespro.ru", "phone": "+70593867596"}
0005432460579	E9CF92	6295 509288	DIANA VOLKOVA	{"phone": "+70794515238"}
0005432460580	E9CF92	2768 725625	VIKTOR NIKITIN	{"email": "nikitin_v1965@postgrespro.ru", "phone": "+70281119178"}
0005432460581	E9CF92	8767 330146	ALEKSANDR EGOROV	{"phone": "+70552335966"}
0005432460582	89060D	9338 195847	ANDREY STEPANOV	{"phone": "+70081873530"}
0005432460583	C69D76	3421 985138	TATYANA SAVELEVA	{"phone": "+70262135897"}
0005432460584	C69D76	7760 238673	SERGEY VOROBEV	{"email": "svorobev_111962@postgrespro.ru", "phone": "+70167944761"}
0005432460585	F2FC9E	7068 677030	VALENTINA MAKSIMOVA	{"email": "v_maksimova_121966@postgrespro.ru", "phone": "+70460764266"}
0005432460586	B94D2C	7797 953133	VALERIY IVANOV	{"phone": "+70175308458"}
0005432460587	B94D2C	8707 962382	DMITRIY MAKAROV	{"phone": "+70482468012"}
0005432460588	B5113E	3553 563028	NINA KUZMINA	{"email": "nina_kuzmina-12071989@postgrespro.ru", "phone": "+70840480158"}
0005432460589	B5113E	0176 801583	DENIS ANTONOV	{"email": "denisantonov041967@postgrespro.ru", "phone": "+70949116276"}
0005432460590	2C2F6F	8049 065655	ELENA SMIRNOVA	{"email": "smirnova.elena-24081961@postgrespro.ru", "phone": "+70717253545"}
0005432460591	CD9608	9911 769665	ALLA EFIMOVA	{"phone": "+70750349079"}
0005432460592	8A3F56	5605 492630	VLADIMIR ABRAMOV	{"phone": "+70495182270"}
0005432460593	8A3F56	8400 202655	LILIYA ZHUKOVA	{"phone": "+70415113698"}
0005432460594	7F3813	7579 630619	VLADIMIR IVANOV	{"phone": "+70797502222"}
0005432460595	96644B	1239 791099	MARAT FROLOV	{"email": "m-frolov_1974@postgrespro.ru", "phone": "+70386249477"}
0005432460596	856CAC	5745 961231	IVAN FILIPPOV	{"email": "ivan-filippov111978@postgrespro.ru", "phone": "+70201091836"}
0005432460597	856CAC	8022 280777	DMITRIY MATVEEV	{"email": "d.matveev.11121976@postgrespro.ru", "phone": "+70150130997"}
0005432460598	4D3A20	9248 551469	ANDREY PAVLOV	{"phone": "+70977928806"}
0005432460599	04C9B0	5480 420870	IVAN DENISOV	{"email": "idenisov_31081977@postgrespro.ru", "phone": "+70891634954"}
0005432460600	D78185	4678 307868	MARINA EFIMOVA	{"phone": "+70663814705"}
0005432460601	FC1903	4129 385689	VIKTOR KUDRYASHOV	{"email": "viktor_kudryashov101976@postgrespro.ru", "phone": "+70950288047"}
0005432460602	FC1903	0939 540764	NATALYA ANDREEVA	{"phone": "+70452473113"}
0005432460603	BD4A1C	5004 345424	NADEZHDA ORLOVA	{"phone": "+70502129651"}
0005432460604	BD4A1C	6153 030485	ALEKSANDR SMIRNOV	{"email": "a-smirnov19061976@postgrespro.ru", "phone": "+70684912764"}
0005432460605	9ADC55	0156 261893	LILIYA SEMENOVA	{"email": "semenova.l.14111977@postgrespro.ru", "phone": "+70766318993"}
0005432460606	9ADC55	3058 912660	NURIYA ZAKHAROVA	{"email": "nzakharova.28101975@postgrespro.ru", "phone": "+70170425945"}
0005432460607	96F455	1789 524708	SERGEY POPOV	{"email": "popovs-1972@postgrespro.ru", "phone": "+70548811493"}
0005432460608	96F455	8585 474085	LYUDMILA NIKOLAEVA	{"email": "lyudmila-nikolaeva-111978@postgrespro.ru", "phone": "+70167357528"}
0005432460609	31D797	2039 637973	DENIS ILIN	{"email": "d.ilin1968@postgrespro.ru", "phone": "+70457984925"}
0005432460610	B1B3A3	5972 668211	ILYA MAKAROV	{"phone": "+70803658807"}
0005432460611	326AA2	2069 467965	VLADIMIR NIKOLAEV	{"email": "nikolaev_v-1956@postgrespro.ru", "phone": "+70921241644"}
0005432460612	31C98C	8421 341571	GALINA BELOVA	{"phone": "+70344924317"}
0005432460613	B8B4EF	1744 435728	VERA NIKOLAEVA	{"phone": "+70895466082"}
0005432460614	EED836	7567 008351	ALINA EGOROVA	{"phone": "+70836608318"}
0005432460615	C5C167	6159 341828	YURIY ZHURAVLEV	{"phone": "+70498152852"}
0005432460616	C5C167	8930 301898	LYUBOV SAVELEVA	{"phone": "+70122579122"}
0005432460617	C85C99	0178 641852	SVETLANA KOROLEVA	{"email": "koroleva-svetlana.1977@postgrespro.ru", "phone": "+70885220695"}
0005432460618	6BF5B9	2609 711047	NATALYA LEBEDEVA	{"email": "lebedeva.n-14051964@postgrespro.ru", "phone": "+70400812090"}
0005432460619	47E6B9	9380 741151	NINA KAZAKOVA	{"phone": "+70723353051"}
0005432460620	704193	4010 617640	VIKTOR ZAYCEV	{"phone": "+70376634800"}
0005432460621	AE565F	5701 664174	SERGEY ANDREEV	{"phone": "+70964847842"}
0005432460622	AE565F	5414 821540	VADIM EGOROV	{"email": "egorov.vadim_1974@postgrespro.ru", "phone": "+70840677284"}
0005432460623	24C5FA	1176 503654	KONSTANTIN VOROBEV	{"phone": "+70776624781"}
0005432460624	7C1B51	8614 857720	MARIYA KOZLOVA	{"email": "kozlova_mariya.061966@postgrespro.ru", "phone": "+70343011856"}
0005432460625	BED5C3	7443 170881	ANGELINA POLYAKOVA	{"phone": "+70417791806"}
0005432460626	099FB3	2920 304811	VIKTORIYA BORISOVA	{"phone": "+70524995306"}
0005432460627	6D0368	0311 931638	ARTEMIY ZAKHAROV	{"phone": "+70405226719"}
0005432460628	97D392	8078 333673	DANIL FROLOV	{"email": "frolov.danil_03021977@postgrespro.ru", "phone": "+70417944924"}
0005432460629	97D392	1886 181339	SERGEY FEDOTOV	{"email": "fedotov_sergey_1971@postgrespro.ru", "phone": "+70474710452"}
0005432460630	B79427	8217 183366	NIKITA FEDOTOV	{"email": "nikita.fedotov22041975@postgrespro.ru", "phone": "+70376198846"}
0005432460631	C9570B	4165 060120	DMITRIY KUZNECOV	{"phone": "+70871019547"}
0005432460632	C9570B	1016 132056	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev051974@postgrespro.ru", "phone": "+70395047500"}
0005432460633	7A874D	8853 463093	MARIYA KOZLOVA	{"phone": "+70044768668"}
0005432460634	644B37	8089 839956	ARSENIY KRASNOV	{"email": "akrasnov1989@postgrespro.ru", "phone": "+70734349073"}
0005432460635	898D75	4551 605732	YULIYA ORLOVA	{"email": "yuliya.orlova1977@postgrespro.ru", "phone": "+70501467946"}
0005432460636	898D75	7687 603327	YULIYA ABRAMOVA	{"phone": "+70791180765"}
0005432460637	898D75	1198 317705	IVAN IVANOV	{"email": "i-ivanov-21031982@postgrespro.ru", "phone": "+70841756240"}
0005432460638	898D75	5282 685934	SVETLANA ZHURAVLEVA	{"email": "zhuravleva.s11071972@postgrespro.ru", "phone": "+70194601638"}
0005432460639	C0872E	5525 307899	OLGA KONOVALOVA	{"email": "olga-konovalova_051975@postgrespro.ru", "phone": "+70186895932"}
0005432460640	A89BBD	2197 290595	ALEKSANDR ZAYCEV	{"phone": "+70454747237"}
0005432460641	D5E1E7	0077 311246	VLADIMIR ISAEV	{"email": "isaevv.091965@postgrespro.ru", "phone": "+70939922982"}
0005432460642	0A1F93	1298 100461	SERGEY EGOROV	{"email": "egorovs-27041969@postgrespro.ru", "phone": "+70105242334"}
0005432460643	0A1F93	3592 262783	DARYA KISELEVA	{"email": "darya_kiseleva-061969@postgrespro.ru", "phone": "+70251843564"}
0005432460644	4941A2	5796 120722	NATALIYA RYABOVA	{"email": "n_ryabova27101970@postgrespro.ru", "phone": "+70992652852"}
0005432460645	AD1B21	7124 977359	OLGA NAZAROVA	{"email": "nazarova_o1968@postgrespro.ru", "phone": "+70611038907"}
0005432460646	AD1B21	3296 421812	ILYA SCHERBAKOV	{"phone": "+70841813758"}
0005432460647	AD1B21	7460 005244	GALINA DMITRIEVA	{"email": "g_dmitrieva_1965@postgrespro.ru", "phone": "+70753707636"}
0005432460648	0E2E03	6712 449273	LUIZA ANDREEVA	{"phone": "+70660085054"}
0005432460649	B1CEF2	1854 768964	EVDOKIYA KUZMINA	{"phone": "+70687607088"}
0005432460650	B1CEF2	1516 286826	ANATOLIY ZAYCEV	{"email": "zayceva_27111976@postgrespro.ru", "phone": "+70966737544"}
0005432460651	0B6F4A	2732 581903	VERA IVANOVA	{"phone": "+70200242812"}
0005432460652	17C8A3	2249 084892	ANTONINA EGOROVA	{"email": "antonina-egorova06031967@postgrespro.ru", "phone": "+70559669591"}
0005432460653	1D2411	3920 344589	YULIYA MARTYNOVA	{"phone": "+70323731331"}
0005432460654	1D2411	5077 630157	ARTEM GORBUNOV	{"email": "gorbunovartem.15051980@postgrespro.ru", "phone": "+70802717352"}
0005432460655	451E92	0042 758867	KRISTINA NIKOLAEVA	{"phone": "+70729976255"}
0005432460656	0605F0	8579 041326	ANDREY YAKOVLEV	{"email": "a-yakovlev1974@postgrespro.ru", "phone": "+70405608363"}
0005432460657	2E52C9	1518 398009	NATALYA NAZAROVA	{"email": "n-nazarova_1971@postgrespro.ru", "phone": "+70089620389"}
0005432460658	D7D394	1849 037478	SVETLANA POTAPOVA	{"email": "potapovasvetlana10011965@postgrespro.ru", "phone": "+70385454576"}
0005432460659	2A8B55	8454 544870	SERGEY IVANOV	{"phone": "+70057840573"}
0005432460660	5DEBA1	8280 697259	EVELINA MAKSIMOVA	{"email": "maksimova.evelina-021969@postgrespro.ru", "phone": "+70151338359"}
0005432460661	F624E9	3754 307764	PETR SERGEEV	{"phone": "+70341169042"}
0005432460662	20716C	1576 966123	VALENTIN IVANOV	{"phone": "+70518156732"}
0005432460663	42A6C1	5341 690977	IVAN PAVLOV	{"email": "ivan.pavlov_1961@postgrespro.ru", "phone": "+70282918945"}
0005432460664	E0F5D5	9237 158581	TATYANA ANDREEVA	{"email": "andreeva_tatyana1969@postgrespro.ru", "phone": "+70431379769"}
0005432460665	FA90F4	3599 105653	SERGEY KARPOV	{"email": "skarpov18081977@postgrespro.ru", "phone": "+70571572578"}
0005432460666	4C6618	4386 985235	DARYA GERASIMOVA	{"email": "gerasimovad.061977@postgrespro.ru", "phone": "+70066906814"}
0005432460667	10E60F	6776 983917	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov.1988@postgrespro.ru", "phone": "+70624877261"}
0005432460668	78382E	2929 444156	IVAN NIKITIN	{"phone": "+70004858869"}
0005432460669	A4267E	5341 812213	IRINA MAKAROVA	{"email": "i-makarova.061969@postgrespro.ru", "phone": "+70258236366"}
0005432460670	A4267E	6840 575628	YURIY KONOVALOV	{"email": "konovalov.y031969@postgrespro.ru", "phone": "+70971710992"}
0005432460671	EE3241	0515 237976	DMITRIY VOROBEV	{"phone": "+70491691770"}
0005432460672	EE3241	4127 836575	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr071968@postgrespro.ru", "phone": "+70219914979"}
0005432460673	524F56	1503 939369	NADEZHDA KOLESNIKOVA	{"email": "kolesnikova_nadezhda.26101979@postgrespro.ru", "phone": "+70261783761"}
0005432460674	A5101C	8283 840287	ZINAIDA ZAKHAROVA	{"phone": "+70423763325"}
0005432460914	E551AF	8928 724226	OLEG SMIRNOV	{"phone": "+70902586566"}
0005432460675	D9CE04	3952 662586	ELENA VASILEVA	{"email": "evasileva.1964@postgrespro.ru", "phone": "+70407204471"}
0005432460676	CBBF0B	4725 120815	LILIYA DENISOVA	{"email": "liliya-denisova.26011971@postgrespro.ru", "phone": "+70973273522"}
0005432460677	ED41DA	0592 165456	BORIS FILIPPOV	{"email": "filippov-b1968@postgrespro.ru", "phone": "+70775101638"}
0005432460678	2A89B0	1178 559344	VASILIY EGOROV	{"email": "egorov.vasiliy-05021961@postgrespro.ru", "phone": "+70082512048"}
0005432460679	FB81B2	1641 828276	VIKTORIYA SERGEEVA	{"phone": "+70769806074"}
0005432460680	28EDE2	2345 857771	MIKHAIL SERGEEV	{"phone": "+70314041731"}
0005432460681	1EACCA	5282 775809	VALERIY AFANASEV	{"email": "afanasev_v-011977@postgrespro.ru", "phone": "+70223790846"}
0005432460682	1EACCA	0539 771984	MIKHAIL ANDREEV	{"phone": "+70360059965"}
0005432460683	E61D7C	6731 158543	OLGA KONOVALOVA	{"phone": "+70403600954"}
0005432460684	BD82CB	5876 499568	ANASTASIYA GRISHINA	{"email": "anastasiya-grishina-02111972@postgrespro.ru", "phone": "+70921593020"}
0005432460685	4CC116	6996 859191	ANNA SCHERBAKOVA	{"phone": "+70594487849"}
0005432460686	E09EFC	8081 509619	VLADIMIR YAKOVLEV	{"email": "yakovlev_vladimir01061969@postgrespro.ru", "phone": "+70396395782"}
0005432460687	BC658E	8621 579799	ROMAN ILIN	{"phone": "+70325368461"}
0005432460688	BC658E	1006 683280	DMITRIY KAZAKOV	{"email": "d-kazakov_1977@postgrespro.ru", "phone": "+70252810498"}
0005432460689	5E812B	9600 594431	LYUDMILA POLYAKOVA	{"email": "lyudmila_polyakova.1975@postgrespro.ru", "phone": "+70743862136"}
0005432460690	0AFB55	3551 235487	VITALIY KARPOV	{"phone": "+70134842057"}
0005432460691	7E0622	8747 777604	VLADIMIR ZHURAVLEV	{"phone": "+70399142825"}
0005432460692	4A4F18	6916 764827	YULIYA FILIPPOVA	{"email": "filippova.yuliya.20051973@postgrespro.ru", "phone": "+70308933154"}
0005432460693	1658EC	3458 292376	TAISA KARPOVA	{"email": "karpova-taisa-031988@postgrespro.ru", "phone": "+70457969243"}
0005432460694	3EE88D	1024 954864	EVGENIY KISELEV	{"email": "kiselev-e_051975@postgrespro.ru", "phone": "+70268478070"}
0005432460695	93ACA9	4494 421666	SERGEY STEPANOV	{"email": "stepanov.s1972@postgrespro.ru", "phone": "+70073243078"}
0005432460696	7F2DD1	3205 373291	LYUDMILA OSIPOVA	{"phone": "+70278339802"}
0005432460697	231283	9041 021418	ALEKSANDR TIMOFEEV	{"email": "a_timofeev.1975@postgrespro.ru", "phone": "+70367851930"}
0005432460698	0E236D	4781 467766	NADEZHDA PETROVA	{"email": "petrova_nadezhda-1979@postgrespro.ru", "phone": "+70994839462"}
0005432460699	D36A4A	4870 040869	GULFIYA BORISOVA	{"phone": "+70133845703"}
0005432460700	6106B8	2599 453609	DMITRIY BONDARENKO	{"phone": "+70398089694"}
0005432460701	8B237E	7047 598021	NIKOLAY POPOV	{"email": "popovn_31051967@postgrespro.ru", "phone": "+70469575394"}
0005432460702	83D485	9795 559644	ILMIRA KUZMINA	{"phone": "+70683587438"}
0005432460703	83D485	2146 124224	SERGEY NIKOLAEV	{"phone": "+70167684778"}
0005432460704	AD545E	5280 101535	ALEKSEY KUDRYASHOV	{"email": "kudryashova.051979@postgrespro.ru", "phone": "+70435814891"}
0005432460705	AD545E	7151 760480	DANIL KUZMIN	{"email": "d.kuzmin_1959@postgrespro.ru", "phone": "+70234541535"}
0005432460706	46BAE8	7580 766565	NADEZHDA NESTEROVA	{"phone": "+70238795604"}
0005432460707	3F68A3	0896 469602	PETR GERASIMOV	{"email": "gerasimov-petr.21121966@postgrespro.ru", "phone": "+70582581412"}
0005432460708	D35EE2	1121 681974	POLINA NOVIKOVA	{"email": "novikova_polina1966@postgrespro.ru", "phone": "+70446918854"}
0005432460709	CEE65A	0785 284640	VLADIMIR ZAKHAROV	{"phone": "+70193771459"}
0005432460710	901969	5002 421402	PETR NOVIKOV	{"email": "novikov_petr.1969@postgrespro.ru", "phone": "+70022194912"}
0005432460711	901969	2355 151158	VIKTORIYA CHERNOVA	{"phone": "+70152134771"}
0005432460712	901969	6722 240632	VITALIY ZAYCEV	{"phone": "+70697858351"}
0005432460713	E413E8	5051 629002	BORIS KRASNOV	{"phone": "+70106526924"}
0005432460714	CD8E18	4931 780604	ELENA MAKSIMOVA	{"phone": "+70439384699"}
0005432460715	CD8E18	3425 148793	PETR RODIONOV	{"phone": "+70338219181"}
0005432460716	831437	1350 784478	ALEKSANDR CHERNOV	{"email": "chernov-a-30061977@postgrespro.ru", "phone": "+70270526555"}
0005432460717	831437	1692 247887	NATALYA SMIRNOVA	{"email": "smirnova_n.121975@postgrespro.ru", "phone": "+70694411059"}
0005432460718	1C1962	6994 733126	ALLA MIKHAYLOVA	{"email": "mikhaylova_alla.081964@postgrespro.ru", "phone": "+70593745372"}
0005432460719	EA9750	8391 439920	YURIY DMITRIEV	{"email": "dmitriev-y_1959@postgrespro.ru", "phone": "+70271667707"}
0005432460720	EA9750	4386 368675	OLGA ARKHIPOVA	{"email": "olga.arkhipova_1963@postgrespro.ru", "phone": "+70664490424"}
0005432460721	961395	9950 835972	GENNADIY ZAKHAROV	{"phone": "+70994937054"}
0005432460722	89D7C6	0774 992150	IVAN ZHUKOV	{"email": "zhukov.i1984@postgrespro.ru", "phone": "+70961456477"}
0005432460723	79D14F	7360 623326	NATALYA YAKOVLEVA	{"email": "yakovleva.natalya-1968@postgrespro.ru", "phone": "+70793927993"}
0005432460724	8C8349	7701 580762	MARIYA VOLKOVA	{"phone": "+70586774053"}
0005432460725	4EE34A	4569 015011	NINA SERGEEVA	{"email": "nsergeeva.071980@postgrespro.ru", "phone": "+70572413034"}
0005432460726	4EE34A	1347 685245	DIANA BELOVA	{"email": "d.belova-01091968@postgrespro.ru", "phone": "+70905183869"}
0005432460727	D5CA6A	7909 432688	ANDREY ZAKHAROV	{"email": "zakharovandrey28041967@postgrespro.ru", "phone": "+70626248909"}
0005432460728	2688CD	1242 618613	MIKHAIL DENISOV	{"phone": "+70515836911"}
0005432460729	2688CD	3756 665166	NINA KOMAROVA	{"phone": "+70058147401"}
0005432460730	D959CC	5865 952942	TATYANA KUZMINA	{"email": "t-kuzmina061977@postgrespro.ru", "phone": "+70084843995"}
0005432460731	D959CC	9386 322571	BULAT FROLOV	{"phone": "+70295917446"}
0005432460732	92BB89	5099 053595	TAMARA NAZAROVA	{"email": "nazarova-tamara_1979@postgrespro.ru", "phone": "+70333064858"}
0005432460733	E9CCCB	7196 851882	IRINA GORBUNOVA	{"email": "irina.gorbunova031969@postgrespro.ru", "phone": "+70263015697"}
0005432460734	7DBA35	0971 454700	SERGEY NIKOLAEV	{"email": "s.nikolaev1978@postgrespro.ru", "phone": "+70544943952"}
0005432460735	E8C670	0163 085051	DARYA IVANOVA	{"email": "ivanovad.1984@postgrespro.ru", "phone": "+70174921058"}
0005432460736	64F4F8	0555 147754	NATALYA MELNIKOVA	{"email": "melnikova-n_061978@postgrespro.ru", "phone": "+70053301910"}
0005432460737	1BBDE5	6741 528885	ALEKSANDR FOMIN	{"email": "fomina.1963@postgrespro.ru", "phone": "+70511607989"}
0005432460738	964A4E	9110 197385	OLEG ROMANOV	{"email": "romanovoleg-30011974@postgrespro.ru", "phone": "+70143880889"}
0005432460739	D598D5	1051 658310	SERGEY KUZNECOV	{"phone": "+70983241126"}
0005432460740	D598D5	3650 275102	YURIY SERGEEV	{"email": "sergeev_y_101968@postgrespro.ru", "phone": "+70695071878"}
0005432460741	7B9617	8427 751332	VALERIY TIMOFEEV	{"email": "timofeev.valeriy22071969@postgrespro.ru", "phone": "+70801799776"}
0005432460742	C7EACC	8099 024118	IVAN ALEKSEEV	{"phone": "+70177736471"}
0005432460743	3379BC	7833 977755	SERGEY FEDOTOV	{"email": "fedotov_s.17091975@postgrespro.ru", "phone": "+70123474227"}
0005432460744	C72CF6	6846 272240	ELENA ZAKHAROVA	{"phone": "+70597294011"}
0005432460745	55CA10	7326 207579	YAKOV CHERNOV	{"phone": "+70632563224"}
0005432460746	55CA10	0993 075731	LYUDMILA GAVRILOVA	{"phone": "+70173560461"}
0005432460747	B5D808	9001 904461	IRINA NOVIKOVA	{"email": "novikova-i091978@postgrespro.ru", "phone": "+70763663860"}
0005432460748	B5D808	8600 306244	ALEKSANDR KULIKOV	{"phone": "+70994141490"}
0005432460749	714DDF	0689 842460	VITALIY SOLOVEV	{"email": "solovev_v_1978@postgrespro.ru", "phone": "+70800670922"}
0005432460750	04E71B	3371 431731	LIDIYA VOLKOVA	{"phone": "+70771879381"}
0005432460751	04E71B	1352 816019	VIKTOR ANDREEV	{"phone": "+70157317680"}
0005432460752	BF5A60	5392 586152	NATALYA KUZNECOVA	{"email": "kuznecova_natalya.10111988@postgrespro.ru", "phone": "+70078924446"}
0005432460753	3D20AC	7735 277304	DARYA ALEKSANDROVA	{"phone": "+70548261744"}
0005432460754	3D20AC	8340 883325	YURIY MIKHAYLOV	{"email": "mikhaylov_yuriy1966@postgrespro.ru", "phone": "+70414948975"}
0005432460755	4D1963	6710 274592	IRINA MALYSHEVA	{"email": "malysheva.i_1973@postgrespro.ru", "phone": "+70157658251"}
0005432460756	4D1963	9295 441418	BORIS MOISEEV	{"email": "moiseev-boris1974@postgrespro.ru", "phone": "+70169349055"}
0005432460757	48F809	3108 818589	ELENA NIKIFOROVA	{"email": "nikiforova-elena-1971@postgrespro.ru", "phone": "+70795702224"}
0005432460758	3D10EB	7804 097036	INNA ZAKHAROVA	{"email": "i-zakharova_1984@postgrespro.ru", "phone": "+70162532448"}
0005432460759	E478D8	8180 643790	SVETLANA RODIONOVA	{"email": "rodionova.s-11021964@postgrespro.ru", "phone": "+70334944697"}
0005432460760	E478D8	2653 380306	ANDREY NAUMOV	{"phone": "+70597616745"}
0005432460761	E478D8	8816 116405	VLADIMIR NOVIKOV	{"email": "vladimir-novikov_1981@postgrespro.ru", "phone": "+70629864772"}
0005432460762	6A0309	6659 236908	ANDREY SCHERBAKOV	{"phone": "+70475807577"}
0005432460763	37922C	6196 730489	TIMOFEY ANDREEV	{"phone": "+70610334274"}
0005432460764	0763EE	4490 168550	MIKHAIL SERGEEV	{"phone": "+70597593177"}
0005432460765	0763EE	1938 468497	EVGENIY KONOVALOV	{"email": "konovalov.evgeniy22101980@postgrespro.ru", "phone": "+70404558225"}
0005432460766	C421D7	3331 533178	NIKOLAY PETROV	{"email": "npetrov.061970@postgrespro.ru", "phone": "+70966419295"}
0005432460767	B43286	4028 518286	VALENTINA KUZNECOVA	{"email": "kuznecova.v.1974@postgrespro.ru", "phone": "+70321568176"}
0005432460768	46DA29	1467 981938	ALEKSANDR SOROKIN	{"phone": "+70649310902"}
0005432460769	915DA5	4016 420594	NATALYA IVANOVA	{"email": "ivanova-n-11071980@postgrespro.ru", "phone": "+70359587146"}
0005432460770	30F3B5	7187 950075	MARIYA PETROVA	{"email": "petrova_mariya.081976@postgrespro.ru", "phone": "+70187426762"}
0005432460771	30F3B5	5165 049259	EVGENIY NOVIKOV	{"phone": "+70649033769"}
0005432460772	30F3B5	0678 496981	ZOYA NAUMOVA	{"email": "znaumova.041973@postgrespro.ru", "phone": "+70335971558"}
0005432460773	5EE71A	9244 593412	NATALYA KONOVALOVA	{"email": "natalya_konovalova_1965@postgrespro.ru", "phone": "+70034689368"}
0005432460774	E1927E	1396 428186	DANIL AFANASEV	{"phone": "+70747341330"}
0005432460775	F1417F	6470 883838	ALBERT NIKITIN	{"phone": "+70414141560"}
0005432460776	F1417F	7298 539084	LYUBOV KOLESNIKOVA	{"phone": "+70316907692"}
0005432460777	F890A1	8764 528398	ANTONINA LUKYANOVA	{"phone": "+70389692291"}
0005432460778	75A1E5	7527 990558	SERGEY FILIPPOV	{"phone": "+70342607636"}
0005432460779	75A1E5	1151 404434	IGOR ROMANOV	{"email": "igorromanov_31031971@postgrespro.ru", "phone": "+70270408685"}
0005432460780	7CE5DD	3166 129548	ANGELINA OSIPOVA	{"email": "osipovaa-1964@postgrespro.ru", "phone": "+70798065952"}
0005432460781	B2981F	2189 922572	TATYANA NESTEROVA	{"phone": "+70802252083"}
0005432460782	B2981F	7057 661768	ANASTASIYA DAVYDOVA	{"phone": "+70160876965"}
0005432460783	5218AC	4645 259608	VIKTOR ROMANOV	{"email": "v_romanov021981@postgrespro.ru", "phone": "+70110707234"}
0005432460784	5218AC	5294 644238	STEPAN DMITRIEV	{"email": "stepandmitriev111976@postgrespro.ru", "phone": "+70437595197"}
0005432460785	5218AC	7673 248171	ANNA TARASOVA	{"email": "tarasova_a_1961@postgrespro.ru", "phone": "+70459748616"}
0005432460786	3DD6B6	8759 732190	ALEKSANDR GRIGOREV	{"email": "aleksandr-grigorev.1971@postgrespro.ru", "phone": "+70564884745"}
0005432460787	03FA43	5777 073931	YURIY NIKITIN	{"phone": "+70309438200"}
0005432460788	C136B7	5918 479816	OLGA FEDOROVA	{"email": "ofedorova.1970@postgrespro.ru", "phone": "+70246482570"}
0005432460789	12CCCA	4480 326213	VYACHESLAV SHEVCHENKO	{"phone": "+70389053516"}
0005432460790	7EB9FB	4638 180012	TATYANA NOVIKOVA	{"email": "tatyananovikova_1974@postgrespro.ru", "phone": "+70544500642"}
0005432460791	7EB9FB	5400 114155	MARIYA LAZAREVA	{"phone": "+70227888108"}
0005432460792	96E9CA	3409 953615	VADIM ZAKHAROV	{"email": "zakharov_vadim1972@postgrespro.ru", "phone": "+70476514748"}
0005432460793	96E9CA	1224 734797	TATYANA PAVLOVA	{"email": "pavlova.t02121967@postgrespro.ru", "phone": "+70305059145"}
0005432460794	6DF2B4	3224 729418	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr_12031971@postgrespro.ru", "phone": "+70384412977"}
0005432460795	58D190	3367 626651	ZAKHAR ZAKHAROV	{"email": "zakharzakharov.1967@postgrespro.ru", "phone": "+70503340477"}
0005432460853	8BCB7C	1520 684604	NATALYA ORLOVA	{"phone": "+70748539408"}
0005432460796	58D190	6631 341476	IRINA DANILOVA	{"email": "i_danilova.011959@postgrespro.ru", "phone": "+70010471174"}
0005432460797	0A37D2	3540 962530	MARAT ANDREEV	{"email": "marat.andreev-1977@postgrespro.ru", "phone": "+70894008416"}
0005432460798	8FEAA0	8157 561655	DMITRIY MELNIKOV	{"phone": "+70782632975"}
0005432460799	DA8DDA	8265 365281	EKATERINA SOKOLOVA	{"phone": "+70807332879"}
0005432460800	75DAE5	2078 138581	ELENA DANILOVA	{"phone": "+70022085093"}
0005432460801	75DAE5	3801 061003	ILYAS BONDARENKO	{"phone": "+70248103219"}
0005432460802	6E5D33	4201 828504	TATYANA ROMANOVA	{"phone": "+70007824840"}
0005432460803	D66EDF	4987 836094	ANASTASIYA VLASOVA	{"phone": "+70624363014"}
0005432460804	BEB60D	9588 588772	MARIYA NAUMOVA	{"phone": "+70208307009"}
0005432460805	BEB60D	0496 185307	VALENTINA ZHUKOVA	{"phone": "+70767314969"}
0005432460806	3DB64E	2546 731417	DMITRIY PAVLOV	{"email": "dmitriy.pavlov1973@postgrespro.ru", "phone": "+70232324291"}
0005432460807	B6D77C	3594 276145	SERGEY FROLOV	{"phone": "+70009321569"}
0005432460808	B6D77C	1275 103762	NIKOLAY ZAYCEV	{"phone": "+70285932938"}
0005432460809	B64D1E	1091 234617	IVAN FOMIN	{"email": "ifomin1966@postgrespro.ru", "phone": "+70106202717"}
0005432460810	502495	9908 091731	IRINA FOMINA	{"phone": "+70565626337"}
0005432460811	D0D744	0076 498171	IVAN ROMANOV	{"email": "romanovi_1967@postgrespro.ru", "phone": "+70319674754"}
0005432460812	D0D744	9868 012803	EVGENIY ANDREEV	{"email": "andreev_evgeniy_14071964@postgrespro.ru", "phone": "+70775350727"}
0005432460813	59AAEC	2795 478980	ANDREY KULIKOV	{"phone": "+70478877475"}
0005432460814	E57924	5435 643307	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay-1978@postgrespro.ru", "phone": "+70831576526"}
0005432460815	0A946C	8148 572714	OKSANA PETROVA	{"phone": "+70688636193"}
0005432460816	38AFA6	6299 708059	ANASTASIYA NAZAROVA	{"email": "a.nazarova-121965@postgrespro.ru", "phone": "+70717566828"}
0005432460817	5D2282	0135 038308	EVGENIY ANTONOV	{"email": "antonove-1973@postgrespro.ru", "phone": "+70039855158"}
0005432460818	63B374	2799 443487	OLGA CHERNOVA	{"phone": "+70034885987"}
0005432460819	63B374	8188 251295	RODION MAKSIMOV	{"phone": "+70836228392"}
0005432460820	63B374	9324 702267	RENAT SAVELEV	{"phone": "+70411147863"}
0005432460821	6096E1	3851 351871	GEORGIY PETROV	{"phone": "+70071062313"}
0005432460822	6096E1	8206 675509	SERGEY SAVELEV	{"email": "savelev_sergey-1975@postgrespro.ru", "phone": "+70857145819"}
0005432460823	1D2DF8	3170 765384	MAKSIM GUSEV	{"email": "gusev.m041967@postgrespro.ru", "phone": "+70261549785"}
0005432460824	1D2DF8	3940 387063	NADEZHDA NIKITINA	{"email": "nikitina.n_1979@postgrespro.ru", "phone": "+70563058404"}
0005432460825	4C6BD6	6218 752051	ELENA PAVLOVA	{"phone": "+70522004866"}
0005432460826	4C6BD6	4234 490042	IRINA IVANOVA	{"email": "i.ivanova22081975@postgrespro.ru", "phone": "+70810169493"}
0005432460827	D7BD1F	7317 214360	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey011960@postgrespro.ru", "phone": "+70844635131"}
0005432460828	1BF00A	3345 974471	ALEKSANDR KULIKOV	{"email": "kulikov-a-1970@postgrespro.ru", "phone": "+70557848924"}
0005432460829	EBDAA5	0427 458496	ARTEM ROMANOV	{"phone": "+70720850963"}
0005432460830	0006F5	9260 101020	TATYANA SCHERBAKOVA	{"email": "t_scherbakova041975@postgrespro.ru", "phone": "+70528987541"}
0005432460831	0006F5	1046 330827	SOFYA VOROBEVA	{"phone": "+70744950331"}
0005432460832	CFFC9B	5628 153206	ALEKSEY SIDOROV	{"email": "asidorov-08081972@postgrespro.ru", "phone": "+70111164652"}
0005432460833	CFFC9B	5083 448434	RINAT ANTONOV	{"email": "r_antonov1987@postgrespro.ru", "phone": "+70063873585"}
0005432460834	6F151B	4189 502174	GRIGORIY NIKITIN	{"phone": "+70821338697"}
0005432460835	744E64	7854 155674	ANATOLIY VOLKOV	{"phone": "+70768117583"}
0005432460836	744E64	2709 613855	NATALYA SMIRNOVA	{"email": "natalya-smirnova_1970@postgrespro.ru", "phone": "+70050240023"}
0005432460837	629324	5952 365864	ELENA BARANOVA	{"phone": "+70646041197"}
0005432460838	2178A0	1722 566296	ALEKSEY TARASOV	{"email": "aleksey.tarasov.18081970@postgrespro.ru", "phone": "+70810506683"}
0005432460839	2178A0	7416 867465	VALERIYA FILIPPOVA	{"email": "filippovav_1972@postgrespro.ru", "phone": "+70377318536"}
0005432460840	CD7AF8	7217 586397	KLAVDIYA STEPANOVA	{"email": "stepanovak-011972@postgrespro.ru", "phone": "+70419451940"}
0005432460841	DDD48C	4174 413753	LYUDMILA ROMANOVA	{"phone": "+70679220423"}
0005432460842	A6BC5E	0017 507227	ROMAN MAKAROV	{"phone": "+70832077431"}
0005432460843	C7B8BC	6174 957525	NINA ARKHIPOVA	{"phone": "+70998071932"}
0005432460844	C7B8BC	2617 557027	SERGEY VASILEV	{"email": "s.vasilev-061961@postgrespro.ru", "phone": "+70762865486"}
0005432460845	7DAF0E	0817 075034	NINA PAVLOVA	{"email": "pavlovan.1968@postgrespro.ru", "phone": "+70864209955"}
0005432460846	69CE58	1572 428131	TIMOFEY NIKITIN	{"phone": "+70093092497"}
0005432460847	C85C8C	1641 395223	VLADIMIR MAKSIMOV	{"phone": "+70976341818"}
0005432460848	97C2CD	9486 562812	VYACHESLAV IVANOV	{"phone": "+70613286789"}
0005432460849	97C2CD	9031 811263	VALERIY MELNIKOV	{"phone": "+70885388915"}
0005432460850	1DD819	6626 068672	IVAN FEDOTOV	{"phone": "+70904055429"}
0005432460851	52A579	9417 985413	OKSANA ALEKSEEVA	{"email": "alekseeva.oksana-26031955@postgrespro.ru", "phone": "+70038564047"}
0005432460852	54AF16	9886 848753	VLADISLAV NIKOLAEV	{"email": "vnikolaev_16121971@postgrespro.ru", "phone": "+70241040576"}
0005432460915	D031AA	8948 176031	SERGEY KUZNECOV	{"phone": "+70101189058"}
0005432460854	F10B9F	1303 441747	VALERIY GERASIMOV	{"email": "gerasimov_v-04051973@postgrespro.ru", "phone": "+70756359628"}
0005432460855	DC090C	6159 237182	YULIYA SIDOROVA	{"email": "y.sidorova.061968@postgrespro.ru", "phone": "+70101309457"}
0005432460856	605AAB	0214 127173	GALINA NAUMOVA	{"email": "gnaumova.10091969@postgrespro.ru", "phone": "+70444459306"}
0005432460857	605AAB	8449 269428	MARINA KUZNECOVA	{"email": "kuznecova_m10101973@postgrespro.ru", "phone": "+70282755460"}
0005432460858	5ECE20	5393 986418	ELENA TIKHONOVA	{"email": "elenatikhonova031975@postgrespro.ru", "phone": "+70629432370"}
0005432460859	5ECE20	7545 670768	OLGA DAVYDOVA	{"phone": "+70596811184"}
0005432460860	7AAF61	3245 859387	NADEZHDA KOROLEVA	{"phone": "+70672141586"}
0005432460861	7AAF61	2669 489805	TAMARA OSIPOVA	{"phone": "+70904747760"}
0005432460862	9234A1	9098 053633	ANDREY GRIGOREV	{"email": "a.grigorev_1980@postgrespro.ru", "phone": "+70291680318"}
0005432460863	9234A1	6568 613372	ELENA BOGDANOVA	{"phone": "+70536460138"}
0005432460864	D3D084	2292 629005	GULFIYA SERGEEVA	{"email": "gulfiya.sergeeva1965@postgrespro.ru", "phone": "+70408291748"}
0005432460865	4B791D	9585 151770	VALENTIN MOISEEV	{"email": "moiseevv.081968@postgrespro.ru", "phone": "+70985064435"}
0005432460866	0B0B63	7678 219639	KSENIYA KUZNECOVA	{"email": "kseniyakuznecova02101970@postgrespro.ru", "phone": "+70995799115"}
0005432460867	F4F915	6168 325226	NINA POTAPOVA	{"email": "nina-potapova-061978@postgrespro.ru", "phone": "+70364391401"}
0005432460868	F4F915	2429 086282	IRINA STEPANOVA	{"email": "stepanova.irina-061978@postgrespro.ru", "phone": "+70316649029"}
0005432460869	C6528B	8822 789799	IRINA MAKSIMOVA	{"phone": "+70170385476"}
0005432460870	C6528B	2420 129707	OLGA ANDREEVA	{"phone": "+70742111317"}
0005432460871	76D2B6	7993 577234	MIKHAIL NIKITIN	{"email": "mikhailnikitin.22021967@postgrespro.ru", "phone": "+70519364733"}
0005432460872	E499A1	4563 808538	VALERIY ROMANOV	{"phone": "+70046584875"}
0005432460873	892F48	1036 520708	EVGENIY KUZNECOV	{"phone": "+70981035493"}
0005432460874	2F11DF	2545 728538	EKATERINA ALEKSEEVA	{"email": "alekseeva.e.121971@postgrespro.ru", "phone": "+70762879403"}
0005432460875	B7A037	5788 699622	NIKOLAY ZAYCEV	{"email": "n.zaycev_13061978@postgrespro.ru", "phone": "+70163339296"}
0005432460876	B7A037	1324 113494	MARTA ZAKHAROVA	{"phone": "+70857700851"}
0005432460877	95A8CF	5704 076245	TAMARA PAVLOVA	{"email": "tamara.pavlova_07021961@postgrespro.ru", "phone": "+70324853974"}
0005432460878	31DC27	8966 036682	SERGEY PETROV	{"phone": "+70190739941"}
0005432460879	31DC27	0929 077999	ZINAIDA NIKOLAEVA	{"email": "z_nikolaeva.23101982@postgrespro.ru", "phone": "+70223936901"}
0005432460880	C78A89	9521 487628	TATYANA SOROKINA	{"email": "t_sorokina-011970@postgrespro.ru", "phone": "+70635914998"}
0005432460881	C78A89	9669 796318	YURIY ROMANOV	{"phone": "+70707019066"}
0005432460882	9C6271	3209 600572	NINA ZOTOVA	{"phone": "+70175074898"}
0005432460883	9C6271	4051 983929	OLGA FROLOVA	{"phone": "+70487066024"}
0005432460884	068F89	5887 395985	RIFAT PETROV	{"phone": "+70427106103"}
0005432460885	CD82D3	0638 307485	VLADIMIR NOVIKOV	{"phone": "+70989727260"}
0005432460886	CD82D3	7859 941528	DMITRIY ALEKSANDROV	{"phone": "+70530953479"}
0005432460887	F8AD05	7810 967097	SOFYA MALYSHEVA	{"phone": "+70375185398"}
0005432460888	F8AD05	1055 614485	VLADISLAV VLASOV	{"phone": "+70551560469"}
0005432460889	F8AD05	8561 546096	YURIY SEMENOV	{"phone": "+70760262659"}
0005432460890	B46401	1703 108141	ANATOLIY PETROV	{"phone": "+70773024238"}
0005432460891	DE74CB	0254 615797	VIKTOR TIKHONOV	{"email": "tikhonov.v091986@postgrespro.ru", "phone": "+70469594219"}
0005432460892	C3F41E	6416 400526	VALENTINA DENISOVA	{"phone": "+70595957483"}
0005432460893	C3F41E	5220 429957	SVETLANA MEDVEDEVA	{"email": "s_medvedeva.051972@postgrespro.ru", "phone": "+70580341679"}
0005432460894	C3F41E	4601 285275	EVGENIY KUZNECOV	{"email": "e.kuznecov-1973@postgrespro.ru", "phone": "+70114767419"}
0005432460895	7330F1	0812 424716	ALEKSEY STEPANOV	{"phone": "+70892570135"}
0005432460896	7330F1	8398 766813	LYUDMILA KONOVALOVA	{"email": "konovalovalyudmila1968@postgrespro.ru", "phone": "+70480508898"}
0005432460897	7330F1	4037 374355	ELENA TARASOVA	{"email": "tarasova_e.101974@postgrespro.ru", "phone": "+70115553344"}
0005432460898	E5BDE8	4116 167768	MIKHAIL MIRONOV	{"phone": "+70329361067"}
0005432460899	32031E	1391 661003	SVETLANA MIRONOVA	{"email": "mironova.svetlana_1967@postgrespro.ru", "phone": "+70275540281"}
0005432460900	82C149	4098 120414	DENIS FEDOROV	{"email": "fedorov_denis-17041976@postgrespro.ru", "phone": "+70173495401"}
0005432460901	31AED3	1206 253914	VLADIMIR SERGEEV	{"email": "vsergeev_051982@postgrespro.ru", "phone": "+70110720527"}
0005432460902	8922BA	8511 867938	IGOR SOROKIN	{"email": "sorokinigor_1979@postgrespro.ru", "phone": "+70454888516"}
0005432460903	8922BA	7040 356306	VYACHESLAV FROLOV	{"email": "frolov_v_061984@postgrespro.ru", "phone": "+70234127016"}
0005432460904	8922BA	4182 122078	MAKSIM KUZNECOV	{"phone": "+70278159440"}
0005432460905	8073CF	0568 643568	POLINA ANDREEVA	{"phone": "+70018124354"}
0005432460906	84FD42	7333 866553	ALINA KOZLOVA	{"email": "kozlovaalina-111963@postgrespro.ru", "phone": "+70337049645"}
0005432460907	84FD42	8062 979025	TAISIYA FROLOVA	{"email": "t_frolova-111982@postgrespro.ru", "phone": "+70804082429"}
0005432460908	58E3FA	9326 499967	SERGEY GRIGOREV	{"email": "grigorev.s1978@postgrespro.ru", "phone": "+70761559789"}
0005432460909	A6624F	3789 194170	ANNA KULIKOVA	{"email": "kulikovaanna_101976@postgrespro.ru", "phone": "+70643425306"}
0005432460910	A575A4	2519 965562	SERGEY NIKOLAEV	{"phone": "+70947815967"}
0005432460911	A575A4	5706 182657	OLGA KALININA	{"email": "okalinina-04061973@postgrespro.ru", "phone": "+70780716410"}
0005432460912	1F6242	8208 672230	MIKHAIL IVANOV	{"email": "ivanov.m-1964@postgrespro.ru", "phone": "+70922241182"}
0005432460913	E551AF	4725 765091	OLGA PETROVA	{"phone": "+70857599445"}
0005432460916	D031AA	9405 582491	ANNA NESTEROVA	{"email": "nesterova-a.05081969@postgrespro.ru", "phone": "+70000065230"}
0005432460917	93C611	9866 339648	TATYANA KOZLOVA	{"email": "t_kozlova.10011973@postgrespro.ru", "phone": "+70467932939"}
0005432460918	93C611	9944 055460	IVAN IVANOV	{"phone": "+70114277683"}
0005432460919	86D826	8026 083255	PETR KARPOV	{"email": "karpovp_09021966@postgrespro.ru", "phone": "+70941605294"}
0005432460920	7DA078	8036 895896	LYUBOV SAVELEVA	{"phone": "+70955365924"}
0005432460921	7DA078	1652 949914	OLEG MIRONOV	{"email": "mironov-oleg.061975@postgrespro.ru", "phone": "+70865043184"}
0005432460922	7DA078	0173 580857	IVAN KISELEV	{"email": "kiselevi101976@postgrespro.ru", "phone": "+70689463762"}
0005432460923	DA7656	4419 236587	LIDIYA MIRONOVA	{"phone": "+70634797886"}
0005432460924	980DC8	7494 145443	MIKHAIL SCHERBAKOV	{"phone": "+70196639700"}
0005432460925	C2206A	0545 870600	ELENA KOROLEVA	{"email": "koroleva_elena-04021974@postgrespro.ru", "phone": "+70085797916"}
0005432460926	9E02EE	8934 390891	ANDREY NOVIKOV	{"email": "a_novikov1972@postgrespro.ru", "phone": "+70601538742"}
0005432460927	B31382	5393 198683	MIKHAIL IVANOV	{"email": "m.ivanov.091970@postgrespro.ru", "phone": "+70145248820"}
0005432460928	BED9D5	9643 115467	ALEKSANDR PAVLOV	{"phone": "+70225003009"}
0005432460929	BED9D5	8183 006507	OLGA VOLKOVA	{"phone": "+70217860997"}
0005432460930	BED9D5	2279 541513	IGOR TIKHONOV	{"email": "i-tikhonov-051965@postgrespro.ru", "phone": "+70143883123"}
0005432460931	CA5C71	3541 341561	IGOR GUSEV	{"email": "gusev_i_071974@postgrespro.ru", "phone": "+70868916895"}
0005432460932	F5F6D8	4368 292536	YURIY MOISEEV	{"email": "moiseev_yuriy.29101966@postgrespro.ru", "phone": "+70066371551"}
0005432460933	354EA7	8644 314534	ROMAN IVANOV	{"phone": "+70960474439"}
0005432460934	96B302	1338 226995	VALENTIN OSIPOV	{"phone": "+70518473948"}
0005432460935	96B302	1552 903074	DMITRIY ROMANOV	{"phone": "+70153614835"}
0005432460936	96B302	3553 138784	LYUBOV MATVEEVA	{"email": "lmatveeva-1976@postgrespro.ru", "phone": "+70273097122"}
0005432460937	F70AFB	7217 999917	DMITRIY YAKOVLEV	{"phone": "+70027924955"}
0005432460938	F70AFB	1780 727015	MIKHAIL SCHERBAKOV	{"phone": "+70421308010"}
0005432460939	084515	8716 487703	SERGEY SHEVCHENKO	{"email": "sergey_shevchenko011965@postgrespro.ru", "phone": "+70415857109"}
0005432460940	084515	5748 551521	GALINA GORBUNOVA	{"email": "g_gorbunova.041963@postgrespro.ru", "phone": "+70779383468"}
0005432460941	77FD42	7230 717154	VLADIMIR VLASOV	{"phone": "+70842142943"}
0005432460942	C3B572	0237 665416	ARTEM DMITRIEV	{"phone": "+70246066652"}
0005432460943	C3B572	6822 617261	MAKSIM MAKAROV	{"phone": "+70918919489"}
0005432460944	E4A9E0	8390 312664	ELENA ZAKHAROVA	{"phone": "+70886188849"}
0005432460945	AC564A	0466 516580	ALEKSEY TARASOV	{"email": "tarasov-aleksey1978@postgrespro.ru", "phone": "+70137348458"}
0005432460946	01B267	9353 474273	SERGEY PAVLOV	{"phone": "+70305555244"}
0005432460947	83E502	8086 901093	GALINA STEPANOVA	{"phone": "+70379328119"}
0005432460948	5D8A78	0023 134316	OKSANA SIDOROVA	{"phone": "+70075235055"}
0005432460949	5D8A78	4933 279065	MAKSIM KUZNECOV	{"phone": "+70346587964"}
0005432460950	1C9809	3343 242931	ANTON DENISOV	{"email": "denisov_a091964@postgrespro.ru", "phone": "+70599732737"}
0005432460951	1C9809	6399 854362	DMITRIY GORBUNOV	{"phone": "+70911299631"}
0005432460952	70FA16	3705 472144	IVAN KULIKOV	{"phone": "+70809243470"}
0005432460953	70FA16	5485 339906	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr.121970@postgrespro.ru", "phone": "+70426331289"}
0005432460954	A0F974	3167 922277	ANDREY SIDOROV	{"phone": "+70998968572"}
0005432460955	7FF115	2988 714102	OLGA OVCHINNIKOVA	{"phone": "+70201742247"}
0005432460956	0CA576	9115 369958	VIKTORIYA NOVIKOVA	{"email": "viktoriyanovikova-051978@postgrespro.ru", "phone": "+70105892633"}
0005432460957	0CA576	1461 940959	ANDREY GORBUNOV	{"phone": "+70866436591"}
0005432460958	0CA576	6366 177525	IVAN KOROLEV	{"phone": "+70701735319"}
0005432460959	73FDD0	5861 204047	VLADISLAV STEPANOV	{"email": "vladislav.stepanov101968@postgrespro.ru", "phone": "+70798447968"}
0005432460960	A34BD0	4247 145112	ALEKSANDR FOMIN	{"email": "aleksandr.fomin-02101982@postgrespro.ru", "phone": "+70572750473"}
0005432460961	3E7FA2	5089 541326	LARISA STEPANOVA	{"phone": "+70950268402"}
0005432460962	3E7FA2	6817 547512	STEPAN DENISOV	{"phone": "+70828651388"}
0005432460963	DDA88D	1182 679263	VERA ISAEVA	{"email": "isaeva-vera.1976@postgrespro.ru", "phone": "+70808800488"}
0005432460964	48EE5A	3582 443989	IVAN MAKSIMOV	{"phone": "+70001687340"}
0005432460965	14DBFA	9383 163846	NIKOLAY VLASOV	{"phone": "+70289349077"}
0005432460966	1DB14F	1219 047688	LYUDMILA PAVLOVA	{"email": "pavlova_l.031980@postgrespro.ru", "phone": "+70647281642"}
0005432460967	B57FF6	8923 008259	ALEKSEY KUZNECOV	{"phone": "+70846510896"}
0005432460968	C95225	2628 592556	YAROSLAV SHEVCHENKO	{"email": "shevchenko_yaroslav_1974@postgrespro.ru", "phone": "+70547954242"}
0005432460969	92D3F4	4811 154490	OLESYA STEPANOVA	{"email": "stepanova.olesya.061978@postgrespro.ru", "phone": "+70591649555"}
0005432460970	9E6FC2	7001 688388	KRISTINA PETROVA	{"email": "kristina.petrova-20121960@postgrespro.ru", "phone": "+70426818039"}
0005432460971	A204EE	3737 222902	NINA MOISEEVA	{"email": "nmoiseeva.1966@postgrespro.ru", "phone": "+70740620844"}
0005432460972	B715EC	8423 427814	VIKTOR KOROLEV	{"email": "v-korolev_081973@postgrespro.ru", "phone": "+70729327627"}
0005432460973	B715EC	9487 024918	VALENTINA MAKAROVA	{"phone": "+70654638773"}
0005432460974	1A610E	0905 153385	YULIYA MALYSHEVA	{"email": "yuliya-malysheva_1968@postgrespro.ru", "phone": "+70336034209"}
0005432460975	1A610E	6044 946799	KLAVDIYA NESTEROVA	{"phone": "+70507720583"}
0005432460976	53FB5A	9026 989710	MIKHAIL FEDOROV	{"phone": "+70646050645"}
0005432460977	205A0C	4045 663455	SVETLANA MATVEEVA	{"email": "s-matveeva-071962@postgrespro.ru", "phone": "+70357433549"}
0005432460978	821B63	3358 493644	NATALYA PETROVA	{"phone": "+70877586593"}
0005432460979	683E3B	4261 186832	ELENA KISELEVA	{"email": "kiseleva.elena-06031966@postgrespro.ru", "phone": "+70715159821"}
0005432460980	683E3B	9621 625245	ELENA SIDOROVA	{"phone": "+70352078537"}
0005432460981	E7BC6C	0616 751969	VLADISLAV VLASOV	{"phone": "+70385638506"}
0005432460982	E7BC6C	0573 210275	NATALYA POPOVA	{"phone": "+70007527748"}
0005432460983	2B1EB8	2143 237746	YULIYA SOROKINA	{"phone": "+70223332683"}
0005432460984	5DECC4	7392 582023	SVETLANA NESTEROVA	{"email": "nesterovas_081971@postgrespro.ru", "phone": "+70520860424"}
0005432460985	1E01EB	0766 507240	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev.041979@postgrespro.ru", "phone": "+70175220261"}
0005432460986	92ECD9	2504 346283	VITALIY GRIGOREV	{"phone": "+70180708801"}
0005432460987	319354	8312 810371	ANTONINA EFREMOVA	{"email": "a-efremova.091977@postgrespro.ru", "phone": "+70009131171"}
0005432460988	013F28	8835 879175	LYUDMILA GUSEVA	{"phone": "+70276980476"}
0005432460989	44C937	1148 229019	SVETLANA ZOTOVA	{"phone": "+70317168569"}
0005432460990	7FEE46	5475 051476	ELENA MAKSIMOVA	{"phone": "+70984011493"}
0005432460991	7FEE46	4415 811005	VLADIMIR ILIN	{"phone": "+70747277101"}
0005432460992	143340	6515 040500	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov051970@postgrespro.ru", "phone": "+70922244176"}
0005432460993	1A82D6	8998 733888	ANNA FILIPPOVA	{"phone": "+70866178313"}
0005432460994	1A82D6	5131 690140	IRINA VLASOVA	{"email": "irina_vlasova.071957@postgrespro.ru", "phone": "+70874748250"}
0005432460995	F993B6	1331 773740	ANDREY VOLKOV	{"email": "volkov-andrey.21091966@postgrespro.ru", "phone": "+70495612314"}
0005432460996	F67399	8564 657833	DENIS TARASOV	{"phone": "+70141269503"}
0005432460997	ABC0CE	5039 711188	OLGA MOISEEVA	{"phone": "+70089087262"}
0005432460998	ABC0CE	6238 838093	LYUBOV IVANOVA	{"email": "lyubov-ivanova_26091974@postgrespro.ru", "phone": "+70139548835"}
0005432460999	ABC0CE	6720 397758	VLADIMIR ROMANOV	{"email": "romanovv.20121967@postgrespro.ru", "phone": "+70489671742"}
0005432461000	720F10	1972 884689	ANTONIDA LAZAREVA	{"phone": "+70934647707"}
0005432461001	720F10	5736 216980	ALISA GORBUNOVA	{"email": "a.gorbunova011971@postgrespro.ru", "phone": "+70577062796"}
0005432461002	BBE104	3775 051443	DMITRIY EGOROV	{"email": "egorovd1983@postgrespro.ru", "phone": "+70956695032"}
0005432461003	CA4974	5799 957815	ALEKSANDR MAKAROV	{"phone": "+70385293497"}
0005432461004	A4CC36	9977 958311	ANDREY DMITRIEV	{"phone": "+70155560438"}
0005432461005	916535	6839 418426	MAKSIM POPOV	{"phone": "+70545057700"}
0005432461006	05BD77	7210 515439	YULIYA ANDREEVA	{"email": "andreevay.031975@postgrespro.ru", "phone": "+70769615038"}
0005432461007	BB98A7	9036 138500	ANDREY NOVIKOV	{"email": "novikov-a_1982@postgrespro.ru", "phone": "+70221549011"}
0005432461008	F7F1A0	2195 683204	VASILIY MOROZOV	{"phone": "+70679851762"}
0005432461009	33FBA7	9439 423187	ALEKSEY SCHERBAKOV	{"email": "scherbakovaleksey.101955@postgrespro.ru", "phone": "+70537912117"}
0005432461010	33FBA7	4367 653436	MAKSIM SOROKIN	{"phone": "+70948638221"}
0005432461011	056CDC	2591 248680	ELENA DENISOVA	{"phone": "+70185325232"}
0005432461012	B08491	2122 889647	KIRILL IVANOV	{"email": "ivanovkirill.101979@postgrespro.ru", "phone": "+70089268543"}
0005432461013	F8AE19	6137 877544	MIKHAIL SMIRNOV	{"phone": "+70324699648"}
0005432461014	F8AE19	6203 784394	NIKITA FOMIN	{"email": "nfomin-05071979@postgrespro.ru", "phone": "+70096982647"}
0005432461015	EFA334	3851 945930	NATALYA NIKOLAEVA	{"phone": "+70979143764"}
0005432461016	EFA334	2898 407014	NIKOLAY MEDVEDEV	{"email": "medvedev-nikolay_05031968@postgrespro.ru", "phone": "+70508252936"}
0005432461017	EFE38C	8715 063115	MARINA MIRONOVA	{"phone": "+70916348450"}
0005432461018	CD0214	2614 549075	ANGELINA IVANOVA	{"phone": "+70701399520"}
0005432461019	CD0214	9627 414468	ALEKSEY BELOV	{"email": "aleksey-belov-06021966@postgrespro.ru", "phone": "+70681813051"}
0005432461020	2B31A9	4272 699643	OLEG TARASOV	{"phone": "+70360210280"}
0005432461021	F9FB5E	0038 698900	IRINA KUZNECOVA	{"email": "kuznecovairina-06051981@postgrespro.ru", "phone": "+70050891158"}
0005432461022	8231A7	4104 050395	GENNADIY BARANOV	{"phone": "+70096806244"}
0005432461023	8231A7	3128 477153	KLAVDIYA FEDOROVA	{"phone": "+70523645325"}
0005432461024	8231A7	3663 290806	RAISA KUZNECOVA	{"phone": "+70491702525"}
0005432461025	5CF7D4	2167 337058	VADIM ISAEV	{"phone": "+70325396099"}
0005432461026	1A629C	8634 513682	VLADIMIR SOROKIN	{"email": "sorokin.vladimir.1978@postgrespro.ru", "phone": "+70202795445"}
0005432461027	FBE3BE	2581 349384	LYUDMILA MARTYNOVA	{"email": "l.martynova_1982@postgrespro.ru", "phone": "+70705892418"}
0005432461028	FBE3BE	3131 743971	NATALIYA KALININA	{"email": "kalinina.nataliya.011960@postgrespro.ru", "phone": "+70883588859"}
0005432461029	CA443A	1967 909352	DMITRIY SEMENOV	{"email": "dmitriy-semenov-1974@postgrespro.ru", "phone": "+70233415485"}
0005432461030	B71B32	5323 953531	SVETLANA DMITRIEVA	{"phone": "+70925844277"}
0005432461031	2B6E69	2203 337996	MARINA BORISOVA	{"phone": "+70453613824"}
0005432461032	F7AECB	1429 705534	ELENA ERMAKOVA	{"email": "eermakova1970@postgrespro.ru", "phone": "+70401205843"}
0005432461033	1196CD	4544 856044	KONSTANTIN ZHURAVLEV	{"phone": "+70144143376"}
0005432461034	C932B4	2581 259993	NATALYA MALYSHEVA	{"email": "malysheva-natalya_1970@postgrespro.ru", "phone": "+70771264928"}
0005432461035	C932B4	7626 841397	OLGA OSIPOVA	{"email": "olgaosipova.1973@postgrespro.ru", "phone": "+70076015333"}
0005432461036	A83280	0867 250752	VITALIY IVANOV	{"email": "ivanovvitaliy-20121968@postgrespro.ru", "phone": "+70990076154"}
0005432461037	E4D306	3910 923600	ANDREY EGOROV	{"email": "andrey.egorov-031971@postgrespro.ru", "phone": "+70166289589"}
0005432461038	E4D306	5560 364183	LARISA DENISOVA	{"email": "ldenisova1971@postgrespro.ru", "phone": "+70272250112"}
0005432461039	812797	2391 953101	NIKOLAY NIKITIN	{"phone": "+70568228407"}
0005432461040	812797	7001 034246	VLADISLAV TARASOV	{"phone": "+70714798915"}
0005432461041	5B708D	1789 425063	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov1958@postgrespro.ru", "phone": "+70416282331"}
0005432461042	DD0D54	1662 750918	GALINA IVANOVA	{"email": "galina_ivanova-21061976@postgrespro.ru", "phone": "+70361925256"}
0005432461043	008FD0	1340 514972	ALEKSANDR MOROZOV	{"email": "amorozov.08061965@postgrespro.ru", "phone": "+70131103128"}
0005432461044	211F1A	3109 444993	EKATERINA POLYAKOVA	{"phone": "+70278484834"}
0005432461045	211F1A	7455 254118	ZINAIDA ILINA	{"phone": "+70744198074"}
0005432461046	211F1A	8527 435286	MARIYA PETROVA	{"email": "mariya.petrova-1974@postgrespro.ru", "phone": "+70561241878"}
0005432461047	9EDC0D	9489 610716	DMITRIY MAKAROV	{"phone": "+70568587764"}
0005432461048	9EDC0D	0013 255583	POLINA ALEKSEEVA	{"email": "polina_alekseeva1978@postgrespro.ru", "phone": "+70795986818"}
0005432461049	C33795	2093 010917	KLIM SERGEEV	{"email": "sergeev-klim-1972@postgrespro.ru", "phone": "+70159628035"}
0005432461050	C33795	5837 288649	VALENTIN ILIN	{"email": "ilin_v-02081970@postgrespro.ru", "phone": "+70101106359"}
0005432461051	373F5A	5152 659083	RUSLAN NOVIKOV	{"phone": "+70442684091"}
0005432461052	373F5A	7759 680845	DMITRIY BORISOV	{"phone": "+70351005583"}
0005432461053	3B071D	3303 725529	ELENA STEPANOVA	{"phone": "+70096689487"}
0005432461054	3B071D	9868 440141	NADEZHDA KUZNECOVA	{"email": "kuznecova_n-091960@postgrespro.ru", "phone": "+70717070775"}
0005432461055	A16C38	4280 057161	LYUDMILA FOMINA	{"phone": "+70382261554"}
0005432461056	A16C38	6882 819291	VALENTINA ALEKSANDROVA	{"email": "aleksandrovavalentina.11071975@postgrespro.ru", "phone": "+70878114528"}
0005432461057	E31CC7	3771 880554	SERGEY ZAYCEV	{"phone": "+70391265259"}
0005432461058	0F1D85	4271 903429	KONSTANTIN ILIN	{"email": "ilin_konstantin-31071969@postgrespro.ru", "phone": "+70462959874"}
0005432461059	189890	9987 155508	LYUBOV POTAPOVA	{"phone": "+70365770349"}
0005432461060	189890	6971 130697	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr-091972@postgrespro.ru", "phone": "+70226207354"}
0005432461061	DEA470	7212 397930	SERGEY MIRONOV	{"email": "smironov-06011978@postgrespro.ru", "phone": "+70282673980"}
0005432461062	12D531	5996 216009	VLADIMIR MELNIKOV	{"phone": "+70454611162"}
0005432461063	CC4E36	3658 586049	ALEKSEY TARASOV	{"email": "tarasov-a_081976@postgrespro.ru", "phone": "+70079707315"}
0005432461064	CC4E36	0862 778687	IVAN FEDOROV	{"email": "fedorov_i011966@postgrespro.ru", "phone": "+70178763331"}
0005432461065	116E90	0343 586576	EGOR KOROLEV	{"phone": "+70488546364"}
0005432461066	116E90	7115 234431	TATYANA PAVLOVA	{"phone": "+70525603953"}
0005432461067	1E56C4	4985 838611	TATYANA IVANOVA	{"phone": "+70163201060"}
0005432461068	BE3506	5767 872654	RUSTAM GUSEV	{"email": "rustam-gusev.03101956@postgrespro.ru", "phone": "+70543607755"}
0005432461069	303334	9028 187926	ANDREY KUZNECOV	{"phone": "+70197870243"}
0005432461070	303334	5472 274657	VASILIY SOKOLOV	{"email": "vasiliy-sokolov-051972@postgrespro.ru", "phone": "+70002350346"}
0005432461071	268622	0538 543612	SERGEY BELOV	{"email": "belov_s_15101974@postgrespro.ru", "phone": "+70595846399"}
0005432461072	DF5CDE	0964 010946	IVAN MAKAROV	{"email": "makarov.i031974@postgrespro.ru", "phone": "+70464168079"}
0005432461073	DF5CDE	3119 040100	MIKHAIL ANDREEV	{"email": "andreev_mikhail_1972@postgrespro.ru", "phone": "+70980366814"}
0005432461074	D16539	5436 221749	IRINA FILATOVA	{"phone": "+70121278660"}
0005432461075	475F17	5504 834874	NATALYA FEDOROVA	{"email": "fedorovan1966@postgrespro.ru", "phone": "+70307180155"}
0005432461076	475F17	4496 681998	VLADIMIR ANDREEV	{"email": "vladimir.andreev-1963@postgrespro.ru", "phone": "+70415012974"}
0005432461077	729684	8511 317325	EKATERINA KUDRYASHOVA	{"phone": "+70767975735"}
0005432461078	729684	7939 603730	LIDIYA IVANOVA	{"phone": "+70860570814"}
0005432461079	61BEA2	7499 993538	NINA FEDOROVA	{"phone": "+70967541805"}
0005432461080	61BEA2	1018 803079	YURIY BARANOV	{"email": "yuriybaranov14091975@postgrespro.ru", "phone": "+70201064231"}
0005432461081	8AF7FF	8513 140114	ANASTASIYA GUSEVA	{"email": "aguseva_021976@postgrespro.ru", "phone": "+70515645048"}
0005432461082	21F873	0487 424726	ANNA KUZNECOVA	{"email": "anna.kuznecova-031978@postgrespro.ru", "phone": "+70327450865"}
0005432461083	65A1FD	3874 375785	OLGA EGOROVA	{"email": "olgaegorova-091971@postgrespro.ru", "phone": "+70523561619"}
0005432461084	C4548C	3676 232718	GALINA NOVIKOVA	{"email": "novikova-galina.1970@postgrespro.ru", "phone": "+70189378208"}
0005432461085	0C73EA	0429 951318	VASILIY KUZMIN	{"email": "v-kuzmin1963@postgrespro.ru", "phone": "+70567964083"}
0005432461086	0C73EA	8599 382470	ZINAIDA POPOVA	{"phone": "+70013524753"}
0005432461087	80625E	5908 492804	LIDIYA SMIRNOVA	{"phone": "+70754603888"}
0005432461088	09C42F	8757 854554	IGOR NAUMOV	{"email": "naumovi.1975@postgrespro.ru", "phone": "+70708597956"}
0005432461089	09C42F	2705 314275	ELENA IVANOVA	{"phone": "+70880969413"}
0005432461090	09C42F	6156 140721	DMITRIY SERGEEV	{"email": "sergeev_dmitriy1963@postgrespro.ru", "phone": "+70618890833"}
0005432461091	0E1911	8467 729983	TATYANA SCHERBAKOVA	{"email": "tatyanascherbakova-10061974@postgrespro.ru", "phone": "+70429618463"}
0005432461092	3611DE	6106 172637	VITALIY VOLKOV	{"email": "v_volkov1974@postgrespro.ru", "phone": "+70558438075"}
0005432461093	E640C3	1578 490045	VITALIY YAKOVLEV	{"phone": "+70650814987"}
0005432461094	B715B2	0075 821784	ALEKSEY KOZLOV	{"phone": "+70107052233"}
0005432461095	B715B2	1424 526792	OLGA SCHERBAKOVA	{"email": "o_scherbakova_1971@postgrespro.ru", "phone": "+70236621837"}
0005432461096	A614FF	1460 711382	VLADIMIR VOLKOV	{"email": "volkov_v.06101970@postgrespro.ru", "phone": "+70725459364"}
0005432461097	95C63A	2788 461037	IRINA ALEKSEEVA	{"phone": "+70318865594"}
0005432461098	95C63A	1597 477827	NIKOLAY KUZNECOV	{"phone": "+70652612618"}
0005432461099	F447B5	8795 355494	SERGEY KUZNECOV	{"phone": "+70727892789"}
0005432461100	4D5B22	0193 549014	EVGENIY NOVIKOV	{"email": "novikov_e.121976@postgrespro.ru", "phone": "+70209652173"}
0005432461101	4D5B22	3696 497122	GENNADIY ALEKSEEV	{"phone": "+70541275910"}
0005432461102	4D5B22	3139 366352	ELIZAVETA NIKIFOROVA	{"email": "nikiforova.e.101969@postgrespro.ru", "phone": "+70628340796"}
0005432461103	A5C789	4470 746548	VLADIMIR CHERNOV	{"phone": "+70227924375"}
0005432461104	6B0D17	6831 204258	ALEKSANDR SIDOROV	{"email": "a-sidorov1980@postgrespro.ru", "phone": "+70161920071"}
0005432461105	CD1449	2629 320321	OLGA MIRONOVA	{"email": "olgamironova_101972@postgrespro.ru", "phone": "+70834607155"}
0005432461106	83F106	3809 306114	ANNA MARTYNOVA	{"email": "anna_martynova011973@postgrespro.ru", "phone": "+70626866641"}
0005432461107	83F106	4654 732296	GEORGIY KUDRYASHOV	{"email": "gkudryashov_27101968@postgrespro.ru", "phone": "+70469085546"}
0005432461108	18663B	5248 624642	OLGA ZAKHAROVA	{"email": "zakharova.o-121980@postgrespro.ru", "phone": "+70244811463"}
0005432461109	2A65A2	6050 814989	LIDIYA ROMANOVA	{"email": "romanova_l.1972@postgrespro.ru", "phone": "+70347871092"}
0005432461110	3F9777	9189 241008	GENNADIY DENISOV	{"email": "denisov-gennadiy.30071968@postgrespro.ru", "phone": "+70714582906"}
0005432461111	3F9777	7587 405328	NINA IVANOVA	{"phone": "+70808096674"}
0005432461112	3F9777	6491 031286	ANDREY KARPOV	{"phone": "+70157450898"}
0005432461113	070789	0290 126927	VIKTOR VOLKOV	{"phone": "+70644079084"}
0005432461114	887AA9	4363 417765	NIKOLAY TIMOFEEV	{"phone": "+70794133391"}
0005432461115	D1B954	1963 981559	VALENTINA KOLESNIKOVA	{"phone": "+70023941734"}
0005432461116	BCB7F4	3083 228426	ELENA PETROVA	{"email": "petrova_e11041975@postgrespro.ru", "phone": "+70195775369"}
0005432461117	5CCF16	0377 947568	ANATOLIY FEDOTOV	{"email": "anatoliyfedotov_1975@postgrespro.ru", "phone": "+70670781760"}
0005432461118	5CCF16	8528 559281	EVGENIYA ISAEVA	{"email": "evgeniya.isaeva.091985@postgrespro.ru", "phone": "+70253850437"}
0005432461119	1B1CC9	9395 877797	ARTUR MAKAROV	{"phone": "+70847407755"}
0005432461120	1B1CC9	8228 959354	ALEKSANDR CHERNOV	{"email": "a_chernov.31071966@postgrespro.ru", "phone": "+70606786668"}
0005432461121	44ED64	5484 321107	LYUBOV DAVYDOVA	{"email": "l_davydova.1969@postgrespro.ru", "phone": "+70451805771"}
0005432461122	C4BE65	3799 413825	IRINA MEDVEDEVA	{"phone": "+70205465036"}
0005432461123	955402	7103 524847	SERGEY TIKHONOV	{"phone": "+70048405224"}
0005432461124	1AC744	3400 905388	ALEKSANDR MIRONOV	{"phone": "+70888100068"}
0005432461125	AE27AD	8368 933435	EVGENIY YAKOVLEV	{"phone": "+70139097196"}
0005432461126	3EF09F	9654 236734	ALEKSANDR KARPOV	{"email": "karpov-a28041976@postgrespro.ru", "phone": "+70162211440"}
0005432461127	694BDB	2674 163539	KIRILL ZHURAVLEV	{"phone": "+70255571422"}
0005432461128	CB811D	4055 853017	NATALYA DAVYDOVA	{"email": "natalya_davydova-10051980@postgrespro.ru", "phone": "+70774316428"}
0005432461129	CB811D	3625 582815	YULIYA EGOROVA	{"email": "egorova.y-28111953@postgrespro.ru", "phone": "+70852848516"}
0005432461130	6EBBFD	1853 294759	NATALYA SMIRNOVA	{"email": "n-smirnova1968@postgrespro.ru", "phone": "+70885628628"}
0005432461131	3023EE	6984 770720	IGOR ANTONOV	{"phone": "+70401712515"}
0005432461132	47B73F	9835 995400	STANISLAV FEDOTOV	{"email": "fedotov.s.24111965@postgrespro.ru", "phone": "+70594635943"}
0005432461133	47B73F	3585 075961	NINA GAVRILOVA	{"email": "gavrilova-nina_27091976@postgrespro.ru", "phone": "+70493910236"}
0005432461134	5D3B2C	1450 524505	GENNADIY SMIRNOV	{"phone": "+70548104480"}
0005432461358	F1294B	3539 849414	DMITRIY IVANOV	{"phone": "+70095057665"}
0005432461135	5D3B2C	8873 970648	NIKITA FOMIN	{"email": "n_fomin1973@postgrespro.ru", "phone": "+70864306521"}
0005432461136	125998	3920 795099	OLGA SEMENOVA	{"phone": "+70274899907"}
0005432461137	125998	1222 016314	GENNADIY MAKAROV	{"email": "gennadiymakarov.1978@postgrespro.ru", "phone": "+70326117301"}
0005432461138	5C10AA	2913 879306	ANASTASIYA KUZNECOVA	{"phone": "+70854071662"}
0005432461139	EBEF6F	2875 987850	YURIY KUZNECOV	{"phone": "+70465610237"}
0005432461140	EBEF6F	2161 453368	ALEKSANDRA ABRAMOVA	{"phone": "+70205770116"}
0005432461141	057D57	1282 687728	KLAVDIYA RODIONOVA	{"phone": "+70414169953"}
0005432461142	057D57	9017 340567	ARTEM POPOV	{"email": "popova_07031976@postgrespro.ru", "phone": "+70565237313"}
0005432461143	057D57	2264 996106	VERA EGOROVA	{"email": "egorova.v_1988@postgrespro.ru", "phone": "+70984579115"}
0005432461144	F7580A	6482 364837	VIKTOR ZHURAVLEV	{"email": "zhuravlev.viktor.1966@postgrespro.ru", "phone": "+70460737070"}
0005432461145	82A0F1	5294 948262	YURIY KARPOV	{"phone": "+70724615225"}
0005432461146	F66626	9156 525731	RUSLAN FEDOTOV	{"email": "rfedotov-1980@postgrespro.ru", "phone": "+70976265105"}
0005432461147	F66626	6687 798049	RUSTAM KUZNECOV	{"phone": "+70331235228"}
0005432461148	5AEE3E	1053 506086	ALBERT ZHURAVLEV	{"email": "zhuravleva-11011972@postgrespro.ru", "phone": "+70870679348"}
0005432461149	1F4FEA	0430 914086	DENIS IVANOV	{"email": "ivanov-d-1970@postgrespro.ru", "phone": "+70961181482"}
0005432461150	1F4FEA	9934 475088	PAVEL DAVYDOV	{"email": "davydovpavel18071974@postgrespro.ru", "phone": "+70613155998"}
0005432461151	E0520B	5541 353917	OLEG MOISEEV	{"email": "omoiseev-1975@postgrespro.ru", "phone": "+70765385197"}
0005432461152	E0520B	2680 842862	SVETLANA GERASIMOVA	{"phone": "+70887224906"}
0005432461153	B78EF5	1942 940844	TATYANA KULIKOVA	{"email": "kulikova.t-081970@postgrespro.ru", "phone": "+70997404765"}
0005432461154	91DDE0	2268 079396	YURIY POPOV	{"email": "popovy1988@postgrespro.ru", "phone": "+70678632257"}
0005432461155	91DDE0	6637 462883	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_121974@postgrespro.ru", "phone": "+70269530261"}
0005432461156	D51AAF	1045 628596	LYUDMILA SOLOVEVA	{"phone": "+70402208133"}
0005432461157	D51AAF	8910 933199	TATYANA KUZNECOVA	{"phone": "+70066942956"}
0005432461275	6A4E4C	9773 276459	YAROSLAV SEMENOV	{"phone": "+70823381705"}
0005432461158	07F345	3675 105235	YURIY BORISOV	{"email": "borisov-yuriy_051973@postgrespro.ru", "phone": "+70502208884"}
0005432461159	076727	5336 102414	ALEKSEY DAVYDOV	{"phone": "+70843472034"}
0005432461160	076727	3033 248202	VALERIY RODIONOV	{"email": "valeriyrodionov-02021972@postgrespro.ru", "phone": "+70631913764"}
0005432461161	A0AF73	2955 487363	SERGEY NOVIKOV	{"phone": "+70943906894"}
0005432461162	A0AF73	5988 697480	VIKTORIYA KRASNOVA	{"phone": "+70716924539"}
0005432461163	3CEF44	3359 820534	SAMIRA ZAYCEVA	{"phone": "+70939717430"}
0005432461164	3CEF44	4935 349816	SERGEY RODIONOV	{"phone": "+70057653763"}
0005432461165	DD6F30	9214 610342	ALEKSANDR GRIGOREV	{"phone": "+70017042536"}
0005432461166	19B8B0	0027 593530	MARINA NESTEROVA	{"phone": "+70286606596"}
0005432461167	A1D099	5049 688933	ANATOLIY MEDVEDEV	{"phone": "+70438914764"}
0005432461168	A1D099	8916 557749	VALENTINA MEDVEDEVA	{"phone": "+70156779485"}
0005432461169	A1D099	2822 105765	VIKTOR FEDOROV	{"phone": "+70108030887"}
0005432461170	BCA395	6901 157631	NATALYA SEMENOVA	{"email": "natalyasemenova.121975@postgrespro.ru", "phone": "+70652414646"}
0005432461171	4B8FB0	0923 234498	NATALYA CHERNOVA	{"phone": "+70617094090"}
0005432461172	D5BDD6	4422 697915	IGOR EGOROV	{"email": "egorovigor_21021980@postgrespro.ru", "phone": "+70451177040"}
0005432461173	C1790A	6349 258638	LIDIYA ZAKHAROVA	{"phone": "+70686351022"}
0005432461174	C1790A	5384 650437	NATALIYA RODIONOVA	{"phone": "+70990749803"}
0005432461175	55E583	4331 277988	VLADIMIR PAVLOV	{"email": "v.pavlov.031977@postgrespro.ru", "phone": "+70313700910"}
0005432461176	55E583	8644 523414	SERGEY SIDOROV	{"email": "sidorov.s111969@postgrespro.ru", "phone": "+70042074107"}
0005432461177	1372AF	1177 517916	LYUBOV SMIRNOVA	{"phone": "+70086644017"}
0005432461178	1372AF	2459 119543	TATYANA VOROBEVA	{"email": "t.vorobeva1981@postgrespro.ru", "phone": "+70607316925"}
0005432461179	1372AF	4346 469261	ALEKSANDR BARANOV	{"email": "baranov-aleksandr_25121969@postgrespro.ru", "phone": "+70722717680"}
0005432461180	358AF8	4930 143205	SAMIR SEMENOV	{"email": "s-semenov31101977@postgrespro.ru", "phone": "+70896113752"}
0005432461181	1E341C	6438 195112	EVGENIY DAVYDOV	{"email": "e_davydov.071963@postgrespro.ru", "phone": "+70762756445"}
0005432461182	1E341C	2467 876526	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr_1974@postgrespro.ru", "phone": "+70144125471"}
0005432461183	C528B7	8835 975805	ALEKSANDR KUZMIN	{"phone": "+70236359893"}
0005432461184	018F8C	2056 574432	VIKTOR IVANOV	{"email": "ivanov_v_1977@postgrespro.ru", "phone": "+70046713492"}
0005432461185	727F94	1696 156173	EVGENIY ZAYCEV	{"phone": "+70277753991"}
0005432461186	33CF67	5184 263966	LIDIYA ZAKHAROVA	{"phone": "+70053574879"}
0005432461187	E25999	7155 184405	DARYA KOZLOVA	{"email": "daryakozlova.1981@postgrespro.ru", "phone": "+70524365395"}
0005432461188	FB41EC	2141 441142	EVGENIY KOROLEV	{"phone": "+70083784199"}
0005432461189	FB41EC	2735 912936	KARINA ERMAKOVA	{"email": "kermakova_30071978@postgrespro.ru", "phone": "+70111801718"}
0005432461190	D93F2E	7487 403002	ALEKSEY STEPANOV	{"email": "stepanovaleksey_17101970@postgrespro.ru", "phone": "+70639001523"}
0005432461191	95E423	8281 599443	SVETLANA MIKHAYLOVA	{"phone": "+70328316020"}
0005432461192	91B4F5	3515 934923	NADEZHDA YUDINA	{"email": "yudina_nadezhda-22021976@postgrespro.ru", "phone": "+70250903000"}
0005432461193	91B4F5	3541 019992	ANATOLIY STEPANOV	{"email": "stepanov-a101978@postgrespro.ru", "phone": "+70376898826"}
0005432461194	F42120	3251 068447	ALEKSANDR ILIN	{"phone": "+70496966862"}
0005432461362	A2BF47	3097 619162	EVGENIY FEDOTOV	{"phone": "+70728097548"}
0005432461195	76699A	8932 090154	ALEKSEY SOROKIN	{"email": "a_sorokin_06041978@postgrespro.ru", "phone": "+70445092914"}
0005432461196	8F64CD	1090 425595	KIRILL SHEVCHENKO	{"email": "shevchenkok051979@postgrespro.ru", "phone": "+70869473350"}
0005432461197	851F0A	0765 431412	NINA MELNIKOVA	{"email": "melnikova_nina111969@postgrespro.ru", "phone": "+70539008076"}
0005432461198	59FEB1	9148 540954	ALEKSANDR SOKOLOV	{"phone": "+70680754696"}
0005432461199	1697EB	4781 662700	OLGA ERMAKOVA	{"email": "ermakova_olga29081962@postgrespro.ru", "phone": "+70098621551"}
0005432461200	F6D253	4960 907501	MIKHAIL MAKAROV	{"email": "m_makarov.1978@postgrespro.ru", "phone": "+70162872789"}
0005432461201	88AE8D	8558 828053	DENIS SAVELEV	{"email": "savelev_denis-091965@postgrespro.ru", "phone": "+70427315017"}
0005432461202	88AE8D	9209 506771	PETR NAUMOV	{"email": "naumov_p-091986@postgrespro.ru", "phone": "+70256522056"}
0005432461203	88AE8D	8684 817925	SERGEY VLASOV	{"phone": "+70962682183"}
0005432461204	E00C84	9012 566929	DENIS NIKOLAEV	{"phone": "+70552279064"}
0005432461205	E00C84	6627 495073	ILYA KUDRYASHOV	{"phone": "+70827284683"}
0005432461206	566E32	0441 208354	NIKOLAY AFANASEV	{"email": "afanasev.nikolay_12061983@postgrespro.ru", "phone": "+70115518711"}
0005432461207	566E32	7704 923152	GALINA MEDVEDEVA	{"email": "medvedeva.galina.1968@postgrespro.ru", "phone": "+70931900588"}
0005432461208	CB46FE	2209 776370	ALEKSANDR SMIRNOV	{"phone": "+70730687726"}
0005432461209	CB46FE	1113 922521	VALENTINA GUSEVA	{"email": "gusevavalentina_1965@postgrespro.ru", "phone": "+70464775007"}
0005432461210	33AC4B	3661 275853	VLADIMIR TARASOV	{"phone": "+70769074231"}
0005432461211	5150B6	9196 227700	EMMA ILINA	{"phone": "+70754135822"}
0005432461212	8264AF	3311 024611	ALEKSEY STEPANOV	{"phone": "+70084811746"}
0005432461213	BAEFBF	8301 062709	TIMUR POPOV	{"phone": "+70800628804"}
0005432461214	639812	7227 953608	ALFIYA SEMENOVA	{"email": "semenova.alfiya.041965@postgrespro.ru", "phone": "+70253905072"}
0005432461215	639812	2540 876320	TAMARA GORBUNOVA	{"email": "tgorbunova-1965@postgrespro.ru", "phone": "+70813405137"}
0005432461216	613540	4044 243795	KIRILL NAZAROV	{"email": "nazarov.kirill_111974@postgrespro.ru", "phone": "+70208585222"}
0005432461217	3C02A2	1240 309273	VLADIMIR KOZLOV	{"email": "kozlov-vladimir.041967@postgrespro.ru", "phone": "+70055524346"}
0005432461218	D69C3C	6912 441939	ALEKSANDR ZAKHAROV	{"phone": "+70031680409"}
0005432461219	9F6F1A	0701 759530	OLGA MELNIKOVA	{"email": "o.melnikova-21111968@postgrespro.ru", "phone": "+70125834242"}
0005432461220	9F6F1A	3517 703627	NIKOLAY BORISOV	{"email": "n.borisov-21051975@postgrespro.ru", "phone": "+70118232624"}
0005432461221	EE07D2	6667 098646	YULIYA FADEEVA	{"phone": "+70025152901"}
0005432461222	088140	2263 761757	SERGEY MAKAROV	{"phone": "+70056697201"}
0005432461223	F77DB0	1502 156836	TAMARA ROMANOVA	{"email": "tamararomanova-1974@postgrespro.ru", "phone": "+70765179804"}
0005432461224	F77DB0	3798 191422	LILIYA GRISHINA	{"phone": "+70252880500"}
0005432461225	07F9A1	5142 663739	YURIY NAUMOV	{"phone": "+70258916613"}
0005432461226	6CF217	2623 565488	MAKSIM MIKHAYLOV	{"email": "maksimmikhaylov.1975@postgrespro.ru", "phone": "+70295290724"}
0005432461227	6CF217	9370 170341	MARIYA ROMANOVA	{"phone": "+70368303469"}
0005432461228	5E4C40	5254 076929	NINA BELYAEVA	{"phone": "+70386627718"}
0005432461229	6B0F65	8332 705988	MAKSIM MIKHAYLOV	{"email": "mikhaylov-maksim1977@postgrespro.ru", "phone": "+70763847430"}
0005432461230	700EA4	3648 994387	VERA PETROVA	{"phone": "+70905010758"}
0005432461231	897B2F	9317 600962	OLEG ROMANOV	{"phone": "+70012729803"}
0005432461232	0CAEB9	7804 982702	ALEKSANDR SEMENOV	{"email": "semenov.a-021968@postgrespro.ru", "phone": "+70670537916"}
0005432461233	0CAEB9	0141 653117	ELENA NIKITINA	{"email": "elena_nikitina25011973@postgrespro.ru", "phone": "+70075088473"}
0005432461234	86A95F	4725 541465	ALEKSANDR ZAKHAROV	{"email": "zakharova-29071966@postgrespro.ru", "phone": "+70182318969"}
0005432461235	974B1D	8113 922952	EKATERINA KARPOVA	{"phone": "+70797760020"}
0005432461236	974B1D	9033 630959	ANNA SEMENOVA	{"email": "semenova-anna_111965@postgrespro.ru", "phone": "+70903633342"}
0005432461237	F59C82	7627 295145	LYUBOV MARTYNOVA	{"phone": "+70018287389"}
0005432461238	F59C82	2032 890897	GUZEL GERASIMOVA	{"email": "gerasimova.guzel_1972@postgrespro.ru", "phone": "+70253875761"}
0005432461239	BB07B4	7922 621923	PELAGEYA ERMAKOVA	{"email": "p_ermakova-1967@postgrespro.ru", "phone": "+70328749251"}
0005432461240	BB07B4	5070 735674	OLGA POLYAKOVA	{"phone": "+70530928893"}
0005432461241	93C7B2	0214 702225	VLADIMIR IVANOV	{"email": "vladimir-ivanov_1970@postgrespro.ru", "phone": "+70670557760"}
0005432461242	93C7B2	6864 072603	MIKHAIL VASILEV	{"email": "m_vasilev_19031967@postgrespro.ru", "phone": "+70956878761"}
0005432461243	204C65	2539 010271	NINA LAZAREVA	{"email": "nlazareva_081978@postgrespro.ru", "phone": "+70981392543"}
0005432461244	DEA3BB	5053 910645	NINA NIKOLAEVA	{"email": "n-nikolaeva1971@postgrespro.ru", "phone": "+70224230290"}
0005432461245	60FB72	9215 356304	SERGEY KOZLOV	{"email": "kozlov_sergey_09041976@postgrespro.ru", "phone": "+70108081782"}
0005432461246	CBE991	6037 318550	LEONID MATVEEV	{"phone": "+70813155722"}
0005432461247	CBE991	0415 273530	VLADISLAV VOLKOV	{"phone": "+70369804505"}
0005432461248	67E244	7249 151520	VLADIMIR ANDREEV	{"email": "vladimirandreev-1979@postgrespro.ru", "phone": "+70425084456"}
0005432461249	67E244	5304 421544	ZOYA DAVYDOVA	{"email": "zoya.davydova.021967@postgrespro.ru", "phone": "+70502022908"}
0005432461250	23FE0F	3754 897499	VALENTINA VASILEVA	{"phone": "+70171916211"}
0005432461251	23FE0F	9032 264859	ROMAN EGOROV	{"email": "romanegorov-1980@postgrespro.ru", "phone": "+70774580099"}
0005432461252	23FE0F	8529 953898	YURIY SMIRNOV	{"phone": "+70763380788"}
0005432461253	19FD60	6912 798065	RUDOLF SIDOROV	{"email": "rudolfsidorov-081969@postgrespro.ru", "phone": "+70996174144"}
0005432461254	19FD60	9133 126219	EKATERINA NIKITINA	{"email": "ekaterinanikitina-061960@postgrespro.ru", "phone": "+70128572171"}
0005432461255	F70ACD	8211 343050	ANGELINA BARANOVA	{"email": "a_baranova-071974@postgrespro.ru", "phone": "+70650740904"}
0005432461256	F70ACD	6991 689084	IRINA ZAKHAROVA	{"email": "zakharova.i31101967@postgrespro.ru", "phone": "+70777986198"}
0005432461257	F70ACD	7900 096237	KLAVDIYA ILINA	{"email": "ilina.k-1966@postgrespro.ru", "phone": "+70229515921"}
0005432461258	AD209F	4544 442851	GENNADIY SEMENOV	{"phone": "+70519217356"}
0005432461259	2B3E56	5240 154055	ALEKSEY DMITRIEV	{"email": "dmitriev.a1965@postgrespro.ru", "phone": "+70708664510"}
0005432461260	DB2263	2943 868744	ELENA OVCHINNIKOVA	{"phone": "+70106257450"}
0005432461261	D98B1B	5275 754714	ANTON SCHERBAKOV	{"email": "scherbakov_anton-021972@postgrespro.ru", "phone": "+70848080265"}
0005432461262	4BDCAD	2560 899996	NIKOLAY SERGEEV	{"phone": "+70785246890"}
0005432461263	4BDCAD	1953 787152	GALINA VASILEVA	{"email": "vasileva_galina121974@postgrespro.ru", "phone": "+70208382283"}
0005432461264	024B15	8765 635549	NINA MOISEEVA	{"email": "moiseeva.n_21021980@postgrespro.ru", "phone": "+70070222536"}
0005432461265	37FD7D	8767 683244	ANDREY BARANOV	{"email": "baranova_08031968@postgrespro.ru", "phone": "+70677793422"}
0005432461266	8D82CE	2224 642406	NIKOLAY GERASIMOV	{"phone": "+70767432434"}
0005432461267	278AD2	7650 331477	VALENTINA VASILEVA	{"email": "valentina_vasileva.1979@postgrespro.ru", "phone": "+70484515594"}
0005432461268	8A91E3	3431 607996	OLGA ZAYCEVA	{"email": "o_zayceva.1982@postgrespro.ru", "phone": "+70860677327"}
0005432461269	D7D34F	8818 624507	NATALYA LEBEDEVA	{"email": "lebedeva_n091969@postgrespro.ru", "phone": "+70499736707"}
0005432461270	E91DDA	8341 537691	VLADISLAV KUZNECOV	{"email": "vladislav_kuznecov_1983@postgrespro.ru", "phone": "+70792320155"}
0005432461271	E4ADAE	4054 457792	OLGA VOLKOVA	{"phone": "+70467502697"}
0005432461272	18B841	6331 710417	OLGA ZAKHAROVA	{"email": "o_zakharova.1974@postgrespro.ru", "phone": "+70477712456"}
0005432461273	18B841	4481 021210	NADEZHDA IVANOVA	{"email": "ivanova_n041973@postgrespro.ru", "phone": "+70272063797"}
0005432461274	18B841	4909 393015	VASILIY VOLKOV	{"email": "vasiliy-volkov_22031971@postgrespro.ru", "phone": "+70757521974"}
0005432461276	6DA63F	9944 729874	YANA POLYAKOVA	{"phone": "+70810650588"}
0005432461277	A17F58	4466 471114	VIKTORIYA MAKAROVA	{"phone": "+70553014287"}
0005432461278	A17F58	5411 601516	NIKOLAY GERASIMOV	{"phone": "+70624703314"}
0005432461279	B4459A	3542 040699	DANIIL GORBUNOV	{"email": "dgorbunov.1978@postgrespro.ru", "phone": "+70049179203"}
0005432461280	C8FBFA	9447 622113	NINA NIKOLAEVA	{"email": "nina_nikolaeva.17091962@postgrespro.ru", "phone": "+70762644857"}
0005432461281	C8FBFA	1398 260512	IGOR RODIONOV	{"phone": "+70616819260"}
0005432461282	C8FBFA	8850 305960	OLGA KAZAKOVA	{"phone": "+70491159566"}
0005432461283	2B6B27	5565 676953	VALENTINA KRASNOVA	{"email": "krasnovav_16061982@postgrespro.ru", "phone": "+70086010628"}
0005432461284	9E804A	5977 061192	GUZEL MOROZOVA	{"email": "g.morozova.02051978@postgrespro.ru", "phone": "+70641833667"}
0005432461285	872279	4599 141223	GALINA PAVLOVA	{"email": "pavlova-galina15051970@postgrespro.ru", "phone": "+70587229236"}
0005432461286	D4E9DC	9234 648485	KHALIDA MOROZOVA	{"email": "morozovak_041982@postgrespro.ru", "phone": "+70056440647"}
0005432461287	3EA1D4	1856 385261	ELENA DMITRIEVA	{"email": "elena_dmitrieva101983@postgrespro.ru", "phone": "+70924836285"}
0005432461288	3EA1D4	7583 930827	KRISTINA POTAPOVA	{"email": "potapova.kristina.1979@postgrespro.ru", "phone": "+70001931612"}
0005432461289	3EA1D4	2448 600266	VITALIY SEMENOV	{"phone": "+70411562151"}
0005432461290	3EA1D4	6561 845136	OKSANA DENISOVA	{"email": "denisovao-121966@postgrespro.ru", "phone": "+70570799720"}
0005432461291	8E4EE8	9697 394725	NINA ZOTOVA	{"email": "zotova-n_1976@postgrespro.ru", "phone": "+70446255337"}
0005432461292	D25342	1708 794390	ANDREY ORLOV	{"email": "orlov.a.1973@postgrespro.ru", "phone": "+70131581693"}
0005432461293	D25342	7947 008897	ILYA DMITRIEV	{"phone": "+70151632272"}
0005432461294	ADAD2A	1561 806720	ILSHAT ROMANOV	{"email": "ilshat-romanov.031979@postgrespro.ru", "phone": "+70716091619"}
0005432461295	ADAD2A	7699 772383	RAISA NIKOLAEVA	{"email": "nikolaevar_041971@postgrespro.ru", "phone": "+70242861588"}
0005432461296	570188	1917 687160	ANATOLIY ROMANOV	{"phone": "+70531231030"}
0005432461297	9A4C49	7032 074057	VIKTOR BELOV	{"email": "viktor.belov.1966@postgrespro.ru", "phone": "+70783052795"}
0005432461298	66D725	8204 263966	VLADIMIR GORBUNOV	{"phone": "+70143614485"}
0005432461299	3A8280	3794 561217	ANNA ANISIMOVA	{"phone": "+70978281959"}
0005432461300	1C1199	9768 946522	EVGENIY YAKOVLEV	{"phone": "+70700160756"}
0005432461301	4CF61F	2967 860648	ALEKSANDR KUZNECOV	{"phone": "+70040477879"}
0005432461302	CE5451	7056 986149	OLEG PETROV	{"email": "petrov-o-121975@postgrespro.ru", "phone": "+70603159788"}
0005432461303	2349A0	7065 392024	NATALYA SEMENOVA	{"email": "semenova_natalya031975@postgrespro.ru", "phone": "+70455470788"}
0005432461304	2349A0	1645 074442	ALEKSEY MATVEEV	{"phone": "+70193991916"}
0005432461305	CD2578	5765 731813	LYUBOV KUZNECOVA	{"phone": "+70437315045"}
0005432461306	D86960	2693 110095	INNA ZAYCEVA	{"email": "zaycevai.011977@postgrespro.ru", "phone": "+70668371812"}
0005432461307	D86960	1574 212100	MIKHAIL PAVLOV	{"email": "m-pavlov.1978@postgrespro.ru", "phone": "+70265225508"}
0005432461308	40CDEE	5325 190423	INNA FROLOVA	{"email": "innafrolova1970@postgrespro.ru", "phone": "+70269881949"}
0005432461309	40CDEE	5436 750684	VALENTINA ABRAMOVA	{"email": "abramova-valentina_1979@postgrespro.ru", "phone": "+70798978435"}
0005432461310	E44E15	8179 023043	SERGEY ZAKHAROV	{"phone": "+70491137625"}
0005432461311	E44E15	4232 217803	ANASTASIYA KOROLEVA	{"phone": "+70943322265"}
0005432461312	E7BA13	2016 960992	VYACHESLAV SEMENOV	{"email": "semenov_vyacheslav_20071964@postgrespro.ru", "phone": "+70756306766"}
0005432461313	E7BA13	0375 038613	VIKTOR EGOROV	{"email": "egorov.v_051963@postgrespro.ru", "phone": "+70928017210"}
0005432461314	161A1D	4980 181254	MARIYA VASILEVA	{"email": "mariyavasileva-04021962@postgrespro.ru", "phone": "+70973319166"}
0005432461315	161A1D	5235 572760	GEORGIY VOLKOV	{"phone": "+70539997432"}
0005432461316	FEB0B4	4152 765514	MAKSIM DENISOV	{"phone": "+70432145762"}
0005432461317	CE786A	4635 038675	VERA EFREMOVA	{"email": "efremova-v.061970@postgrespro.ru", "phone": "+70832636393"}
0005432461318	CE786A	8191 120828	VERONIKA SOKOLOVA	{"email": "v-sokolova.071966@postgrespro.ru", "phone": "+70268562163"}
0005432461319	B3E2A6	8206 849819	NINA SIDOROVA	{"phone": "+70383066062"}
0005432461320	05479B	5051 397159	LYUBOV POPOVA	{"email": "lpopova_091972@postgrespro.ru", "phone": "+70384826493"}
0005432461321	8FB7B7	1136 032604	IRAIDA ZAKHAROVA	{"email": "iraida-zakharova-22051979@postgrespro.ru", "phone": "+70651689145"}
0005432461322	8FB7B7	1692 090734	ANATOLIY KUZMIN	{"phone": "+70587858566"}
0005432461323	AD7095	2934 956237	KONSTANTIN BONDARENKO	{"email": "bondarenko_konstantin_12111973@postgrespro.ru", "phone": "+70627672932"}
0005432461324	5E7D76	7343 988307	LYUDMILA KAZAKOVA	{"email": "l_kazakova.1961@postgrespro.ru", "phone": "+70338474699"}
0005432461325	B81C88	2345 268438	TIMUR MELNIKOV	{"phone": "+70976762210"}
0005432461326	458C7E	5882 947971	FANIYA STEPANOVA	{"phone": "+70886273215"}
0005432461327	C1667A	5169 070451	OLGA GERASIMOVA	{"phone": "+70755054042"}
0005432461328	1B9F07	8124 016447	DARYA VOLKOVA	{"email": "volkova-darya1971@postgrespro.ru", "phone": "+70608799549"}
0005432461329	DB05E1	9469 170990	OKSANA STEPANOVA	{"email": "ostepanova.04081966@postgrespro.ru", "phone": "+70015024085"}
0005432461330	ED78FA	4674 114089	EVGENIY MIKHAYLOV	{"email": "mikhaylov-e.20091963@postgrespro.ru", "phone": "+70301588940"}
0005432461331	B4C5A7	2940 653286	ANASTASIYA KOZLOVA	{"email": "kozlova_anastasiya-101978@postgrespro.ru", "phone": "+70704066656"}
0005432461332	B4C5A7	4088 068773	EVELINA RODIONOVA	{"email": "rodionova-evelina091961@postgrespro.ru", "phone": "+70603212669"}
0005432461333	B7AA76	3646 900290	SERGEY KUZNECOV	{"phone": "+70605134590"}
0005432461334	B7AA76	9510 971882	VALENTINA POPOVA	{"phone": "+70727593531"}
0005432461335	FC4C47	4043 346976	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova_18051965@postgrespro.ru", "phone": "+70080842539"}
0005432461336	2539D0	1612 604102	VIKTORIYA KAZAKOVA	{"phone": "+70672290432"}
0005432461337	1D4A16	7992 619388	VYACHESLAV MOROZOV	{"email": "vyacheslav.morozov_081974@postgrespro.ru", "phone": "+70532685822"}
0005432461338	1D4A16	9492 076261	OLGA MOROZOVA	{"phone": "+70660855264"}
0005432461339	C3E1DD	4392 744948	KLAVDIYA GRISHINA	{"phone": "+70910520054"}
0005432461340	9AAB2D	3753 936831	ALEKSANDR POPOV	{"phone": "+70290953997"}
0005432461341	E819A5	4407 171490	OLGA KOROLEVA	{"phone": "+70224922854"}
0005432461342	DDE87A	5309 403374	ANDREY CHERNOV	{"email": "chernov_a-011970@postgrespro.ru", "phone": "+70964787743"}
0005432461343	B32328	2459 479762	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev.041965@postgrespro.ru", "phone": "+70002936243"}
0005432461344	18EC48	2808 233151	TATYANA SEMENOVA	{"phone": "+70709562556"}
0005432461345	B95C58	4381 013401	ILNAR FROLOV	{"phone": "+70414116963"}
0005432461346	403A0F	1962 226884	NADEZHDA MIRONOVA	{"phone": "+70600299365"}
0005432461347	403A0F	2284 721083	OLESYA IVANOVA	{"email": "o.ivanova-09091976@postgrespro.ru", "phone": "+70363956379"}
0005432461348	8B626B	0283 571647	ANNA SOKOLOVA	{"email": "annasokolova.24091972@postgrespro.ru", "phone": "+70079946989"}
0005432461349	C50258	9530 354596	IRINA SIDOROVA	{"email": "i_sidorova-101974@postgrespro.ru", "phone": "+70120105511"}
0005432461350	98D703	5877 725827	EKATERINA SOROKINA	{"email": "ekaterinasorokina_30111969@postgrespro.ru", "phone": "+70695555389"}
0005432461351	2352F8	9262 867396	OLGA POPOVA	{"email": "olga-popova_1963@postgrespro.ru", "phone": "+70919898399"}
0005432461352	2352F8	4723 746001	SERGEY POPOV	{"email": "sergeypopov1962@postgrespro.ru", "phone": "+70155238983"}
0005432461353	E07BD5	0810 068838	VERA BELYAEVA	{"email": "verabelyaeva-24041966@postgrespro.ru", "phone": "+70142191310"}
0005432461354	02F88F	5514 578155	OLGA ERMAKOVA	{"phone": "+70100133341"}
0005432461355	7FFB33	8999 884536	SERGEY SMIRNOV	{"email": "s_smirnov-1955@postgrespro.ru", "phone": "+70657829224"}
0005432461356	7FFB33	7506 445709	OLEG GERASIMOV	{"email": "oleg-gerasimov-12011965@postgrespro.ru", "phone": "+70863591354"}
0005432461357	F1294B	5642 259438	LYUBOV ALEKSANDROVA	{"email": "aleksandrova_lyubov1971@postgrespro.ru", "phone": "+70183848462"}
0005432461359	3BBE02	9575 066650	PAVEL KOZLOV	{"phone": "+70877611527"}
0005432461360	B3FB99	2704 288076	VLADIMIR SIDOROV	{"email": "sidorovv-13071963@postgrespro.ru", "phone": "+70987369082"}
0005432461361	9F5638	6535 035246	DENIS MIRONOV	{"email": "d.mironov.07111982@postgrespro.ru", "phone": "+70248348750"}
0005432461363	FD7D11	5955 548952	PAVEL MOROZOV	{"email": "pavel.morozov01091978@postgrespro.ru", "phone": "+70705854552"}
0005432461364	FD7D11	7235 621572	RADIK FOMIN	{"email": "radik-fomin_121982@postgrespro.ru", "phone": "+70590191112"}
0005432461365	DF4A72	2993 113437	VITALIY NIKOLAEV	{"email": "nikolaev.v-071972@postgrespro.ru", "phone": "+70268237555"}
0005432461366	3838B0	8026 245885	TATYANA KOZLOVA	{"email": "t.kozlova_1962@postgrespro.ru", "phone": "+70525913007"}
0005432461367	3838B0	4854 217954	LARISA STEPANOVA	{"phone": "+70915004009"}
0005432461368	D6D720	9921 925186	IRINA SOLOVEVA	{"phone": "+70580983888"}
0005432461369	D6D720	4725 038183	ANDREY KUZMIN	{"email": "kuzmina.121968@postgrespro.ru", "phone": "+70891241722"}
0005432461370	C810A6	2117 342163	GALINA PETROVA	{"email": "galinapetrova_081985@postgrespro.ru", "phone": "+70938829787"}
0005432461371	4B5EA1	9229 468020	NADEZHDA SEMENOVA	{"phone": "+70993159565"}
0005432461372	D40A28	5031 083252	IVAN ZAKHAROV	{"phone": "+70765479149"}
0005432461373	51332B	2894 247358	GALINA KOROLEVA	{"email": "galina-koroleva_02011972@postgrespro.ru", "phone": "+70590655293"}
0005432461374	CF750A	9708 022440	MIKHAIL POPOV	{"email": "popovmikhail_041975@postgrespro.ru", "phone": "+70084073262"}
0005432461375	880DC9	3769 535473	ANDREY KULIKOV	{"email": "a.kulikov071970@postgrespro.ru", "phone": "+70241763859"}
0005432461376	C6FBFB	0064 447413	EVGENIY NIKITIN	{"phone": "+70476286835"}
0005432461377	6CE9C3	2364 190273	VIKTORIYA BELOVA	{"phone": "+70307467950"}
0005432461378	6CE9C3	6512 339009	ALEKSANDR IVANOV	{"phone": "+70928118276"}
0005432461379	6CE9C3	3382 181740	OLEG MOROZOV	{"phone": "+70178204450"}
0005432461380	901CCB	9199 300127	ANZHELIKA FROLOVA	{"email": "frolova_anzhelika_01101978@postgrespro.ru", "phone": "+70972836506"}
0005432461381	14D4ED	1000 940231	TATYANA SMIRNOVA	{"phone": "+70235736642"}
0005432461382	20D509	6933 173292	ROMAN ABRAMOV	{"phone": "+70946974422"}
0005432461383	198EBA	2500 616058	MARINA ILINA	{"email": "marina_ilina28011978@postgrespro.ru", "phone": "+70856992227"}
0005432461384	457328	4605 555116	TATYANA ANDREEVA	{"email": "andreeva.tatyana-051970@postgrespro.ru", "phone": "+70386693015"}
0005432461385	BE5C8C	9596 428794	ELENA KUZNECOVA	{"email": "ekuznecova_1965@postgrespro.ru", "phone": "+70371022459"}
0005432461386	BE5C8C	0100 657265	TATYANA FOMINA	{"email": "tfomina031977@postgrespro.ru", "phone": "+70193601861"}
0005432461387	66615D	1886 605521	ANTON BARANOV	{"phone": "+70645424271"}
0005432461388	8137B0	2824 040396	VIKTOR POPOV	{"phone": "+70610550490"}
0005432461389	16DCA6	4351 925841	GALINA MAKAROVA	{"email": "galina_makarova-09081973@postgrespro.ru", "phone": "+70300573056"}
0005432461390	722FEA	3510 388221	LYUBOV ZAKHAROVA	{"email": "zakharova-lyubov25031983@postgrespro.ru", "phone": "+70470489176"}
0005432461391	E6EE92	0678 907971	SERGEY SHEVCHENKO	{"email": "s.shevchenko071970@postgrespro.ru", "phone": "+70982669086"}
0005432461392	9E788A	4279 735623	RUSTAM DAVYDOV	{"email": "davydov_r-081964@postgrespro.ru", "phone": "+70385272909"}
0005432461393	B4A93B	6993 293097	ANDREY EGOROV	{"email": "a_egorov.12111965@postgrespro.ru", "phone": "+70826244319"}
0005432461394	00DDDA	5426 058919	ANATOLIY PAVLOV	{"email": "pavlov_anatoliy-06011976@postgrespro.ru", "phone": "+70148146244"}
0005432461395	E65249	8611 822863	TATYANA SOLOVEVA	{"email": "tatyana-soloveva-25091969@postgrespro.ru", "phone": "+70127959234"}
0005432461396	1008EA	4506 171671	ALEKSANDR FROLOV	{"email": "aleksandr.frolov-27111965@postgrespro.ru", "phone": "+70620698483"}
0005432461397	912774	2264 899964	DMITRIY YAKOVLEV	{"phone": "+70037543353"}
0005432461398	912774	6354 320862	SOFIYA VOROBEVA	{"email": "s.vorobeva-071965@postgrespro.ru", "phone": "+70493725473"}
0005432461399	912774	5765 901492	VASILIY BONDARENKO	{"email": "v_bondarenko_081968@postgrespro.ru", "phone": "+70095702578"}
0005432461400	912774	2778 401584	TATYANA EFREMOVA	{"phone": "+70452827531"}
0005432461401	C98BD5	7698 501750	IVAN SAVELEV	{"phone": "+70609908804"}
0005432461402	C98BD5	2670 312112	LIYA MEDVEDEVA	{"phone": "+70685594668"}
0005432461403	8CC0D3	2962 088792	GALINA MAKAROVA	{"phone": "+70439222662"}
0005432461404	8CC0D3	7375 864193	NIKOLAY IVANOV	{"phone": "+70428414966"}
0005432461405	9240B6	6326 695863	TATYANA OSIPOVA	{"email": "tatyana_osipova-061970@postgrespro.ru", "phone": "+70054241509"}
0005432461406	62D07B	7046 689151	VLADIMIR SCHERBAKOV	{"phone": "+70726749415"}
0005432461407	F8DF97	4821 521262	EVGENIY MATVEEV	{"email": "matveev_e1980@postgrespro.ru", "phone": "+70102042443"}
0005432461408	9D164F	7322 273106	IVAN IVANOV	{"email": "i_ivanov101982@postgrespro.ru", "phone": "+70219650046"}
0005432461409	8EC86C	0946 448815	TATYANA CHERNOVA	{"phone": "+70264662492"}
0005432461410	6F7F16	5301 503537	TATYANA IVANOVA	{"email": "ivanovatatyana1960@postgrespro.ru", "phone": "+70688227416"}
0005432461411	6F7F16	6173 555433	PAVEL MEDVEDEV	{"phone": "+70491006009"}
0005432461412	B864C1	8887 312839	TATYANA KUZNECOVA	{"email": "t-kuznecova1978@postgrespro.ru", "phone": "+70329969882"}
0005432461413	BF77E1	3760 390323	ALEKSANDR BARANOV	{"phone": "+70238710892"}
0005432461414	95B051	4838 009243	ANDREY SAVELEV	{"phone": "+70741122479"}
0005432461415	95B051	4911 948676	MARINA MIKHAYLOVA	{"phone": "+70760368930"}
0005432461416	9985C4	0622 990101	DENIS SMIRNOV	{"phone": "+70626354916"}
0005432461417	D69830	1887 999090	VLADIMIR NIKOLAEV	{"email": "nikolaev.v_05071975@postgrespro.ru", "phone": "+70668754153"}
0005432461418	D69830	9834 085639	EVGENIY VOLKOV	{"phone": "+70412812418"}
0005432461419	5357B6	4860 461551	ALEKSEY AFANASEV	{"phone": "+70804044387"}
0005432461420	EA45BA	7716 755769	NADEZHDA FILATOVA	{"phone": "+70029409265"}
0005432461421	B7FB4F	2434 748553	ELENA KUZNECOVA	{"phone": "+70763042418"}
0005432461422	B7FB4F	5029 241484	ARSENIY RODIONOV	{"phone": "+70758483730"}
0005432461423	C6E10E	8474 331412	VALENTINA PETROVA	{"phone": "+70557862240"}
0005432461424	E1EE81	4361 180132	VALERIY VLASOV	{"phone": "+70931456170"}
0005432461425	E1EE81	3606 527181	LYUBOV POLYAKOVA	{"email": "polyakova_l.1973@postgrespro.ru", "phone": "+70218630666"}
0005432461426	B09C0B	3140 226972	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay.24111986@postgrespro.ru", "phone": "+70096174041"}
0005432461427	B09C0B	8386 332814	IVAN IVANOV	{"phone": "+70976478810"}
0005432461428	EE1AF9	5141 513394	SVETLANA POPOVA	{"email": "spopova_1959@postgrespro.ru", "phone": "+70658102791"}
0005432461429	424C44	1906 840625	LYUBOV CHERNOVA	{"email": "lyubov.chernova_061973@postgrespro.ru", "phone": "+70984206585"}
0005432461430	0FB67F	9193 752841	NATALYA ZOTOVA	{"phone": "+70234715205"}
0005432461431	106614	4265 758864	IVAN KARPOV	{"email": "karpov_ivan1974@postgrespro.ru", "phone": "+70189273561"}
0005432461432	43DF89	5485 024205	SVETLANA FEDOROVA	{"phone": "+70271552110"}
0005432461433	F5F3ED	8583 129601	ZINAIDA KRASNOVA	{"phone": "+70370896561"}
0005432461434	687FF4	4737 835662	MARINA SOKOLOVA	{"phone": "+70310428613"}
0005432461435	6E4970	1862 298552	YULIYA ILINA	{"email": "yuliya_ilina-1979@postgrespro.ru", "phone": "+70935959023"}
0005432461436	547A8B	5322 300080	LYUBOV BARANOVA	{"email": "baranoval.15081978@postgrespro.ru", "phone": "+70695572401"}
0005432461437	E26133	9646 882940	EVGENIYA KISELEVA	{"phone": "+70691212654"}
0005432461438	E26133	1126 032825	ELENA STEPANOVA	{"email": "e.stepanova1975@postgrespro.ru", "phone": "+70731845945"}
0005432461439	E26133	0715 980155	ALEKSEY KARPOV	{"email": "aleksey_karpov_1967@postgrespro.ru", "phone": "+70738585121"}
0005432461440	07F326	2384 573694	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v-1972@postgrespro.ru", "phone": "+70464751026"}
0005432461441	273399	4103 306986	ANGELINA SIDOROVA	{"email": "a.sidorova.051981@postgrespro.ru", "phone": "+70238114456"}
0005432461442	86EEEC	4200 597054	OLGA KUZNECOVA	{"phone": "+70352804886"}
0005432461443	86EEEC	5123 690583	EKATERINA MAKSIMOVA	{"phone": "+70136433199"}
0005432461444	20A7CA	1786 085262	VALERIYA SIDOROVA	{"email": "sidorova_valeriya_101981@postgrespro.ru", "phone": "+70935838321"}
0005432461445	2D7A29	8470 000382	LYUDMILA NIKITINA	{"phone": "+70723101067"}
0005432461446	2D7A29	9306 499774	NATALYA EGOROVA	{"phone": "+70311203572"}
0005432462478	8BFC1B	6092 694063	IGOR DMITRIEV	{"phone": "+70867981960"}
0005432462479	8BFC1B	8406 884151	IRINA FEDOROVA	{"phone": "+70204750336"}
0005432462480	063EA2	6988 785130	OLEG ANDREEV	{"email": "andreev_oleg-121962@postgrespro.ru", "phone": "+70515390349"}
0005432462481	67A73E	7047 009463	OLESYA LOGINOVA	{"email": "loginova_olesya-051975@postgrespro.ru", "phone": "+70374703093"}
0005432462482	AAC2A1	6899 472635	ANZHELIKA TIMOFEEVA	{"email": "timofeevaa.1974@postgrespro.ru", "phone": "+70775650309"}
0005432462483	AAC2A1	7517 121470	MARIYA CHERNOVA	{"email": "chernova.mariya_19121978@postgrespro.ru", "phone": "+70272822710"}
0005432462484	AAC2A1	3366 284595	RINAT GUSEV	{"phone": "+70681822088"}
0005432462485	BCF9C7	0353 612964	OLGA KRASNOVA	{"phone": "+70041080621"}
0005432462486	BCF9C7	2498 090132	ANTON DMITRIEV	{"email": "dmitriev_a.06021976@postgrespro.ru", "phone": "+70274835676"}
0005432462487	8C4AA1	2165 442565	ANATOLIY POPOV	{"phone": "+70263593351"}
0005432462488	097750	4612 193903	SVETLANA AKIMOVA	{"email": "svetlana_akimova_051970@postgrespro.ru", "phone": "+70690027241"}
0005432462489	BD239E	9408 892315	TAMARA MATVEEVA	{"phone": "+70973437731"}
0005432462490	EAFFCC	0872 621217	ARINA SOKOLOVA	{"phone": "+70307220314"}
0005432462491	43616B	9792 227459	IRINA TARASOVA	{"email": "tarasova.i-02111986@postgrespro.ru", "phone": "+70575025528"}
0005432462492	3E80CC	8062 198006	ANTONINA MIKHAYLOVA	{"phone": "+70090788436"}
0005432462493	968860	4411 690146	VIKTOR ZHURAVLEV	{"phone": "+70286809718"}
0005432462494	A83A69	2222 410328	ALEKSANDR SOKOLOV	{"email": "sokolovaleksandr.28091966@postgrespro.ru", "phone": "+70434690742"}
0005432462495	A83A69	0398 951900	SABINA KOROLEVA	{"phone": "+70512990322"}
0005432462496	C79D12	0431 546400	VLADIMIR FROLOV	{"email": "frolov.v-11041966@postgrespro.ru", "phone": "+70299730130"}
0005432462497	7348D9	8107 864606	MAKSIM EGOROV	{"email": "maksim-egorov.1969@postgrespro.ru", "phone": "+70507311597"}
0005432462498	7348D9	0788 140672	ELENA ZOTOVA	{"email": "zotova_elena_1978@postgrespro.ru", "phone": "+70092232506"}
0005432462499	7348D9	6197 777086	ALENA MAKAROVA	{"email": "alenamakarova_041972@postgrespro.ru", "phone": "+70966586585"}
0005432462500	FBD536	2983 525682	ZINAIDA OVCHINNIKOVA	{"email": "ovchinnikovazinaida1970@postgrespro.ru", "phone": "+70442600741"}
0005432462501	FBD536	7049 930820	TATYANA YUDINA	{"email": "tyudina_101976@postgrespro.ru", "phone": "+70319461869"}
0005432462502	BD4CDE	7765 371884	ALEKSANDR SIDOROV	{"phone": "+70073836359"}
0005432462503	277B01	2398 763896	DMITRIY KONOVALOV	{"phone": "+70710221571"}
0005432462504	277B01	3528 904587	ELENA BORISOVA	{"email": "borisovaelena-1967@postgrespro.ru", "phone": "+70055193814"}
0005432462505	C402AF	6316 612717	LYUBOV NESTEROVA	{"phone": "+70780634222"}
0005432462506	C402AF	5630 282532	KIRILL ORLOV	{"phone": "+70013174138"}
0005432462507	62CEE6	1467 913453	DMITRIY VOROBEV	{"phone": "+70863196807"}
0005432462508	F5B90F	7576 351420	YURIY KUZMIN	{"phone": "+70712604023"}
0005432462509	F5B90F	6918 860801	MARGARITA KONOVALOVA	{"phone": "+70291243712"}
0005432462510	DF12D8	0534 136486	NIKOLAY ANDREEV	{"phone": "+70985259538"}
0005432462511	DFC4A0	9923 240579	KONSTANTIN ANDREEV	{"email": "konstantinandreev081969@postgrespro.ru", "phone": "+70488588421"}
0005432462512	ADF816	3483 044510	VIKTOR GRIGOREV	{"phone": "+70294381995"}
0005432462513	55AAC3	8709 162576	ALEVTINA FROLOVA	{"phone": "+70438567874"}
0005432462514	628762	0893 008788	ALEKSANDR MARTYNOV	{"email": "a.martynov.30101961@postgrespro.ru", "phone": "+70243934037"}
0005432462515	628762	2494 448308	TAMARA POTAPOVA	{"phone": "+70279105956"}
0005432462516	28F1BD	3061 005831	VIKTOR KISELEV	{"email": "viktor.kiselev.12031968@postgrespro.ru", "phone": "+70999157666"}
0005432462517	34AB2A	8409 074433	MARINA SOROKINA	{"email": "msorokina.1968@postgrespro.ru", "phone": "+70622491893"}
0005432462518	34AB2A	6951 714315	TATYANA VOLKOVA	{"email": "tatyanavolkova-04061971@postgrespro.ru", "phone": "+70409912756"}
0005432462519	469490	0575 582340	TATYANA IVANOVA	{"phone": "+70358319183"}
0005432462520	469490	6052 870117	ANDREY SAVELEV	{"email": "saveleva_29121968@postgrespro.ru", "phone": "+70873653888"}
0005432462521	8C6E85	1088 119022	VALERIY BONDARENKO	{"email": "bondarenkovaleriy.1963@postgrespro.ru", "phone": "+70134742317"}
0005432462522	8C6E85	6903 935927	ANATOLIY PAVLOV	{"email": "anatoliy-pavlov1959@postgrespro.ru", "phone": "+70879956066"}
0005432462523	8C6E85	3621 102867	ALEKSANDR VOROBEV	{"email": "vorobev_a_071972@postgrespro.ru", "phone": "+70270561336"}
0005432462524	3EF443	3052 022701	AYRAT KRASNOV	{"email": "krasnova.011979@postgrespro.ru", "phone": "+70339012752"}
0005432462525	946195	5646 620836	ELENA TARASOVA	{"phone": "+70251710052"}
0005432462526	D9C349	8048 870382	PETR PETROV	{"phone": "+70356692497"}
0005432462527	BD2C64	8057 099350	IVAN AFANASEV	{"phone": "+70430400403"}
0005432462528	BD2C64	2638 406016	VALENTINA BELYAEVA	{"email": "belyaeva.valentina_09011987@postgrespro.ru", "phone": "+70849885174"}
0005432462529	CF5005	7568 081677	MIKHAIL NOVIKOV	{"email": "m_novikov111971@postgrespro.ru", "phone": "+70485736614"}
0005432462530	67B117	3853 829775	ELENA IVANOVA	{"email": "elena-ivanova_1980@postgrespro.ru", "phone": "+70221673694"}
0005432462531	5D391A	8308 279205	VASILIY NIKOLAEV	{"email": "nikolaevvasiliy-1967@postgrespro.ru", "phone": "+70280251146"}
0005432462532	5D391A	5794 547510	VITALIY NIKOLAEV	{"email": "v.nikolaev_1986@postgrespro.ru", "phone": "+70846203501"}
0005432462533	74838E	6373 021005	MARIYA VLASOVA	{"phone": "+70705929273"}
0005432462534	836167	6291 964482	VALERIY DMITRIEV	{"email": "dmitriev_valeriy.121974@postgrespro.ru", "phone": "+70210447226"}
0005432462535	82C552	8410 725723	VERA VOROBEVA	{"phone": "+70298653171"}
0005432462536	A87EA4	5938 117560	NATALYA FILIPPOVA	{"email": "nfilippova1967@postgrespro.ru", "phone": "+70433676218"}
0005432462537	A87EA4	4213 140061	LYUDMILA POLYAKOVA	{"phone": "+70757159164"}
0005432462538	F4816C	2212 330976	SERGEY FROLOV	{"email": "frolov_sergey20061976@postgrespro.ru", "phone": "+70212504250"}
0005432462539	9C540A	0804 681790	MAKSIM BORISOV	{"email": "borisovmaksim.29101966@postgrespro.ru", "phone": "+70540796778"}
0005432462540	1AB014	4304 897150	DMITRIY RODIONOV	{"phone": "+70908512290"}
0005432462541	32A43D	2186 307577	MARIYA PAVLOVA	{"phone": "+70643625450"}
0005432462542	BA86CE	8598 025194	ANATOLIY NIKOLAEV	{"email": "a_nikolaev_29041966@postgrespro.ru", "phone": "+70242205739"}
0005432462543	DB36F6	4235 263382	VALENTINA KISELEVA	{"email": "kiseleva.valentina-081965@postgrespro.ru", "phone": "+70156516673"}
0005432462544	320586	4065 222451	DANILA FOMIN	{"email": "danilafomin_1962@postgrespro.ru", "phone": "+70363335730"}
0005432462545	8A8306	6030 882700	KLAVDIYA KUZNECOVA	{"phone": "+70452851326"}
0005432462546	086834	4538 287094	NADEZHDA SERGEEVA	{"phone": "+70679275667"}
0005432526017	92A15F	0495 229507	LILIYA ZAKHAROVA	{"phone": "+70452838120"}
0005432462547	086834	1583 654227	ALEKSEY SMIRNOV	{"email": "smirnov.aleksey011964@postgrespro.ru", "phone": "+70847474906"}
0005432462548	BCD720	1632 905130	LYUBOV MOROZOVA	{"phone": "+70248055554"}
0005432462549	F6F430	0450 294173	DANIIL IVANOV	{"phone": "+70424487433"}
0005432462550	F8FB1A	5326 796486	SERGEY EGOROV	{"email": "segorov.101972@postgrespro.ru", "phone": "+70282242804"}
0005432462551	E17E0A	3321 001572	IGOR IVANOV	{"phone": "+70224085144"}
0005432462552	E17E0A	8524 014251	VALERIY VOLKOV	{"phone": "+70110969158"}
0005432462553	BF1A94	6888 141305	ELIZAVETA AKIMOVA	{"phone": "+70729096122"}
0005432462554	BF1A94	0218 103997	VALERIY FEDOROV	{"email": "fedorovvaleriy_1987@postgrespro.ru", "phone": "+70776006108"}
0005432462555	B0437B	9205 084428	ANDREY FEDOROV	{"email": "afedorov.1971@postgrespro.ru", "phone": "+70882373430"}
0005432462556	453C86	3043 877851	OLGA BORISOVA	{"phone": "+70856224679"}
0005432462557	4935EC	5121 880012	ELENA PETROVA	{"email": "elenapetrova011969@postgrespro.ru", "phone": "+70976758205"}
0005432462558	10014E	1077 843456	ARTEM KOZLOV	{"email": "artem_kozlov-03061969@postgrespro.ru", "phone": "+70602932977"}
0005432462559	F6DA57	6303 405591	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov.1971@postgrespro.ru", "phone": "+70896263826"}
0005432462560	DBB306	8666 546655	VLADIMIR ROMANOV	{"email": "vladimir-romanov-031970@postgrespro.ru", "phone": "+70433736424"}
0005432462561	DBB306	7813 056568	MIKHAIL DAVYDOV	{"email": "m_davydov.121960@postgrespro.ru", "phone": "+70550808490"}
0005432462562	350A42	1765 921093	MARIYA KOLESNIKOVA	{"phone": "+70568092421"}
0005432462563	350A42	6969 422274	ALEKSEY SHEVCHENKO	{"phone": "+70340776554"}
0005432462564	D08E9E	5256 670802	DIANA SEMENOVA	{"email": "d-semenova.061975@postgrespro.ru", "phone": "+70095261886"}
0005432462565	AB7E8C	3439 457085	OLGA POLYAKOVA	{"email": "polyakova.olga_04071981@postgrespro.ru", "phone": "+70560913815"}
0005432462566	997561	5477 951193	ALEKSANDR FEDOTOV	{"email": "fedotova_061978@postgrespro.ru", "phone": "+70420028889"}
0005432462567	997561	7386 399687	VLADIMIR STEPANOV	{"email": "vladimir.stepanov011981@postgrespro.ru", "phone": "+70053485558"}
0005432462568	AA0177	0450 588545	NINA LOGINOVA	{"email": "loginova_nina-031977@postgrespro.ru", "phone": "+70048765554"}
0005432462569	AA0177	8216 671562	LIDIYA OSIPOVA	{"phone": "+70933618768"}
0005432462570	96CE99	7388 749079	VITALIY NIKITIN	{"email": "nikitin-v.011972@postgrespro.ru", "phone": "+70720563833"}
0005432462571	96CE99	3153 055485	NATALYA NOVIKOVA	{"email": "n_novikova_17071971@postgrespro.ru", "phone": "+70761868820"}
0005432462572	6B36F1	5252 208469	VASILIY MELNIKOV	{"phone": "+70469982893"}
0005432462573	ACAEDA	4437 985272	ALEKSANDR FROLOV	{"phone": "+70361749815"}
0005432462574	36F418	6991 648666	LILIYA BELYAEVA	{"email": "belyaevaliliya24091972@postgrespro.ru", "phone": "+70989785155"}
0005432462575	92593D	3795 995413	MARIYA KUZNECOVA	{"phone": "+70171461494"}
0005432462576	92593D	2058 730989	KSENIYA FADEEVA	{"phone": "+70641816568"}
0005432462581	49C0C4	1544 287583	IVAN MIKHAYLOV	{"email": "imikhaylov23081978@postgrespro.ru", "phone": "+70784516293"}
0005432462582	718431	7023 653072	VARVARA SEMENOVA	{"phone": "+70636109638"}
0005432462583	E4C92A	8514 276498	TATYANA MALYSHEVA	{"phone": "+70825909996"}
0005432525634	EB7C96	4290 039316	EVGENIY ANDREEV	{"email": "andreevevgeniy05071965@postgrespro.ru", "phone": "+70976090935"}
0005432525635	0B9E4A	1129 706992	NATALYA OVCHINNIKOVA	{"phone": "+70652579442"}
0005432525636	F86E2C	2967 185949	IRINA SMIRNOVA	{"email": "irina-smirnova-051971@postgrespro.ru", "phone": "+70444997849"}
0005432525637	F86E2C	7846 039036	LIDIYA IVANOVA	{"phone": "+70967733232"}
0005432525638	D49B5D	4293 904128	EVDOKIYA LEBEDEVA	{"phone": "+70855914709"}
0005432525639	D49B5D	1499 739595	YURIY ALEKSEEV	{"phone": "+70233839890"}
0005432525640	FC4D54	2628 430855	SERGEY SOKOLOV	{"email": "sokolov_s.1976@postgrespro.ru", "phone": "+70648373249"}
0005432525641	5CCA73	9295 150199	IRINA ZAYCEVA	{"phone": "+70398520210"}
0005432525642	1004F1	3022 048076	DMITRIY BONDARENKO	{"phone": "+70360828357"}
0005432525643	1004F1	5639 137499	IRINA MOROZOVA	{"email": "morozovairina121961@postgrespro.ru", "phone": "+70596993069"}
0005432525644	E5EC2A	8751 912308	EVGENIYA TARASOVA	{"email": "tarasova_e-011973@postgrespro.ru", "phone": "+70823085552"}
0005432525645	E5EC2A	4787 975076	RAISA FOMINA	{"phone": "+70037641418"}
0005432525646	65B9AC	4021 350437	MARIYA LEBEDEVA	{"phone": "+70847903215"}
0005432525647	65B9AC	7662 065925	IGOR MEDVEDEV	{"phone": "+70407240187"}
0005432525648	5C20EA	4107 149963	OLGA KRASNOVA	{"phone": "+70143289334"}
0005432525649	ADC9A0	2398 960664	ALEKSEY PETROV	{"email": "alekseypetrov-24121980@postgrespro.ru", "phone": "+70340959870"}
0005432525650	49A944	7102 144066	VLADIMIR SERGEEV	{"email": "sergeev-vladimir.1965@postgrespro.ru", "phone": "+70062078666"}
0005432525651	C431ED	0302 349178	YULIYA BELOVA	{"phone": "+70228460163"}
0005432525652	AB8B37	6494 469590	SERGEY GRIGOREV	{"email": "grigorev_sergey-16061973@postgrespro.ru", "phone": "+70732466125"}
0005432525653	73CB55	2292 955497	DMITRIY VASILEV	{"email": "dvasilev091970@postgrespro.ru", "phone": "+70410395227"}
0005432525654	219411	5756 085883	ILDAR RODIONOV	{"email": "ildar.rodionov_30051968@postgrespro.ru", "phone": "+70046951321"}
0005432525655	219411	6449 027880	MAKSIM KUZMIN	{"email": "m-kuzmin_1981@postgrespro.ru", "phone": "+70765797482"}
0005432525656	3572CD	4645 094410	IRINA KONOVALOVA	{"email": "i-konovalova-1968@postgrespro.ru", "phone": "+70182483497"}
0005432525657	704BD1	0282 955021	ALEKSANDR NAZAROV	{"email": "a.nazarov101978@postgrespro.ru", "phone": "+70317558193"}
0005432525658	704BD1	3612 306446	LYUBOV POTAPOVA	{"phone": "+70845540857"}
0005432525659	537BC7	8025 537715	SERGEY MOROZOV	{"email": "morozovsergey_10011968@postgrespro.ru", "phone": "+70911421938"}
0005432525660	005558	2763 978438	SOFYA ZAKHAROVA	{"email": "s.zakharova_17031961@postgrespro.ru", "phone": "+70519616351"}
0005432525661	51E6DF	4973 742431	ALLA KOROLEVA	{"email": "a-koroleva.051977@postgrespro.ru", "phone": "+70930134419"}
0005432525662	51E6DF	2380 347498	MARIYA ISAEVA	{"email": "isaeva-mariya.27041966@postgrespro.ru", "phone": "+70071055287"}
0005432525663	6ED2FE	0830 813350	VASILIY KARPOV	{"email": "vasiliykarpov.18011975@postgrespro.ru", "phone": "+70312062814"}
0005432525664	C75291	9308 655447	NINA EGOROVA	{"email": "ninaegorova_111962@postgrespro.ru", "phone": "+70415210734"}
0005432525665	C75291	1824 371623	SVETLANA KISELEVA	{"phone": "+70427898903"}
0005432525666	5EE8A2	9784 517586	MARIYA NAZAROVA	{"phone": "+70697208669"}
0005432525667	5EE8A2	3824 677457	VALERIY BELOV	{"phone": "+70019733525"}
0005432525668	063F00	8114 670235	LYUDMILA KONDRATEVA	{"phone": "+70489721946"}
0005432525669	E6D6B4	5948 164626	ALEKSEY MAKAROV	{"email": "makarov.a111974@postgrespro.ru", "phone": "+70183850598"}
0005432525670	E6D6B4	5323 190023	RAISA DANILOVA	{"email": "danilova-raisa-1966@postgrespro.ru", "phone": "+70075294533"}
0005432525671	7FBB3B	6788 111103	RUSTAM MAKSIMOV	{"email": "maksimov-r.1959@postgrespro.ru", "phone": "+70512385050"}
0005432525672	423298	4732 661241	DANIIL KUZNECOV	{"phone": "+70121764630"}
0005432525673	4C68C2	1816 034574	MARIYA ZAYCEVA	{"email": "zayceva_mariya_1967@postgrespro.ru", "phone": "+70399976535"}
0005432525731	ED8828	6517 531966	MAKSIM MARTYNOV	{"phone": "+70032897552"}
0005432525674	617372	4153 788435	VLADIMIR SMIRNOV	{"email": "v_smirnov_1974@postgrespro.ru", "phone": "+70878584888"}
0005432525675	617372	9849 556000	EVGENIY IVANOV	{"phone": "+70379433534"}
0005432525676	BD88B7	7739 589893	EVGENIYA TITOVA	{"phone": "+70926967149"}
0005432525677	CDE010	1968 858210	MARIYA KOROLEVA	{"email": "koroleva.m_18101961@postgrespro.ru", "phone": "+70277362734"}
0005432525678	3A7F64	9117 799467	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov_1971@postgrespro.ru", "phone": "+70612438403"}
0005432525679	3A7F64	6655 877385	ALEVTINA POPOVA	{"email": "a-popova_1970@postgrespro.ru", "phone": "+70683470506"}
0005432525680	60A60C	8791 832955	ELIZAVETA EFIMOVA	{"phone": "+70390804342"}
0005432525681	72EA31	6360 785025	VALENTINA IVANOVA	{"phone": "+70900836000"}
0005432525682	D7F9B4	8510 495535	DARYA ZHUKOVA	{"phone": "+70026864394"}
0005432525683	0A48A5	8153 965357	ARINA ZOTOVA	{"phone": "+70050367066"}
0005432525684	048361	8851 814871	OLGA ANISIMOVA	{"phone": "+70524629326"}
0005432525685	048361	4777 570044	ZLATA KISELEVA	{"email": "kiseleva_zlata-13011967@postgrespro.ru", "phone": "+70510941761"}
0005432525686	7DA0C0	4468 841719	VLADIMIR DENISOV	{"phone": "+70716200367"}
0005432525687	ABCD8F	7616 119027	NIKOLAY SOKOLOV	{"email": "sokolov.n_091970@postgrespro.ru", "phone": "+70054239414"}
0005432525688	9B11B5	0289 295862	VIKTOR SCHERBAKOV	{"phone": "+70467864701"}
0005432525689	9B11B5	0916 364243	ELENA PAVLOVA	{"phone": "+70796164076"}
0005432525690	836985	1756 667569	OLEG ALEKSEEV	{"phone": "+70124767520"}
0005432525691	836985	6319 070876	EGOR VASILEV	{"email": "egor-vasilev_24041974@postgrespro.ru", "phone": "+70045884104"}
0005432525692	D6F3B6	0140 011591	OLGA SOROKINA	{"phone": "+70324185203"}
0005432525693	6A0378	1451 316023	VALENTINA SEMENOVA	{"email": "semenovav071968@postgrespro.ru", "phone": "+70321110656"}
0005432525694	FA4815	1765 101402	NADEZHDA FOMINA	{"phone": "+70504932292"}
0005432525695	A160CC	4012 780559	MAKSIM SMIRNOV	{"email": "smirnovm_1977@postgrespro.ru", "phone": "+70975983151"}
0005432525696	E15407	8653 666453	RENAT ABRAMOV	{"phone": "+70389957494"}
0005432525697	E15407	3926 567908	VALERIY GUSEV	{"email": "gusev-valeriy20071970@postgrespro.ru", "phone": "+70739780489"}
0005432525698	7A97B7	2844 703069	ZOYA KUZMINA	{"phone": "+70166993101"}
0005432525699	A64AB1	9303 052358	IVAN NIKOLAEV	{"phone": "+70146243680"}
0005432525700	A64AB1	1159 104473	ALEKSANDR KONOVALOV	{"email": "konovalov.a-071970@postgrespro.ru", "phone": "+70122175417"}
0005432525701	DDD398	5064 704345	IVAN MIRONOV	{"email": "mironov_ivan1965@postgrespro.ru", "phone": "+70071752199"}
0005432525702	71059B	8122 391356	MARIYA SOROKINA	{"email": "m_sorokina_061977@postgrespro.ru", "phone": "+70277039534"}
0005432525703	BE2A35	8352 038272	ANASTASIYA SERGEEVA	{"phone": "+70534852556"}
0005432525704	BC341D	7430 236073	DMITRIY ISAEV	{"phone": "+70646174079"}
0005432525705	BC341D	2328 415448	DARYA AFANASEVA	{"email": "afanaseva.darya_1986@postgrespro.ru", "phone": "+70898890187"}
0005432525706	219BF4	1619 691058	SVETLANA PETROVA	{"phone": "+70746136544"}
0005432525707	219BF4	6168 006457	EDUARD SERGEEV	{"phone": "+70725188827"}
0005432525708	D46CFD	7800 009089	VERA MIKHAYLOVA	{"phone": "+70893330217"}
0005432525709	C99020	6008 393865	NIKOLAY POPOV	{"phone": "+70188177143"}
0005432525710	9EB2C1	0612 850564	VLADIMIR BONDARENKO	{"phone": "+70955115738"}
0005432525711	E4A6D0	0690 659249	ELENA MASLOVA	{"phone": "+70806646857"}
0005432525712	8FCECC	8029 032131	KRISTINA TIKHONOVA	{"email": "kristinatikhonova-24021968@postgrespro.ru", "phone": "+70887405913"}
0005432525713	C20AAC	4768 999151	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov-1967@postgrespro.ru", "phone": "+70931447046"}
0005432525714	C51924	0731 789891	VLADISLAV MOISEEV	{"email": "v_moiseev1979@postgrespro.ru", "phone": "+70538522932"}
0005432525715	C51924	8879 750760	STANISLAV NIKOLAEV	{"phone": "+70680440477"}
0005432525716	D5EBE8	6651 776900	RIMMA MIRONOVA	{"email": "mironovar_28021965@postgrespro.ru", "phone": "+70735705393"}
0005432525717	D5EBE8	8141 292209	ALEKSANDR ALEKSEEV	{"email": "a.alekseev05031969@postgrespro.ru", "phone": "+70609055007"}
0005432525718	6C4FF2	4438 540212	EVGENIY KUZNECOV	{"phone": "+70696337890"}
0005432525719	6F9F62	9087 070937	OLGA GERASIMOVA	{"phone": "+70164011148"}
0005432525720	6F9F62	8145 114219	VLADISLAV BONDARENKO	{"email": "bondarenko-vladislav.031977@postgrespro.ru", "phone": "+70229012794"}
0005432526018	947683	5168 847487	NIKOLAY GRIGOREV	{"phone": "+70510613821"}
0005432525721	B7B22F	1352 553917	MARIYA IVANOVA	{"email": "mariya_ivanova.05121975@postgrespro.ru", "phone": "+70158768159"}
0005432525722	7E66C0	2084 950859	MATVEY KISELEV	{"email": "kiselevm021974@postgrespro.ru", "phone": "+70887392571"}
0005432525723	11B1C9	3159 631321	KONSTANTIN DENISOV	{"phone": "+70492955827"}
0005432525724	11B1C9	3138 723001	ZINAIDA SCHERBAKOVA	{"email": "zinaida_scherbakova_1965@postgrespro.ru", "phone": "+70519327248"}
0005432525725	508669	4029 490759	YANA SIDOROVA	{"email": "yanasidorova.17021972@postgrespro.ru", "phone": "+70387300572"}
0005432525726	B821A1	7009 925440	ELENA KUZNECOVA	{"phone": "+70198504237"}
0005432525727	B821A1	7881 120602	LIDIYA ROMANOVA	{"email": "romanova_lidiya1982@postgrespro.ru", "phone": "+70563807537"}
0005432525728	AFFF99	8842 782559	NIKOLAY IVANOV	{"email": "nikolay-ivanov_081971@postgrespro.ru", "phone": "+70848117394"}
0005432525729	AFFF99	1243 767734	VASILIY KUDRYASHOV	{"phone": "+70990577797"}
0005432525730	799C85	5367 396517	ILYA MAKAROV	{"phone": "+70439237161"}
0005432525732	ED8828	4397 981967	ANDREY TARASOV	{"email": "tarasov.andrey_28041981@postgrespro.ru", "phone": "+70855759659"}
0005432525733	316E63	4818 801381	VIKTOR ZHURAVLEV	{"phone": "+70780738450"}
0005432525734	DA1264	9925 138358	ROMAN ANTONOV	{"email": "r_antonov_09101977@postgrespro.ru", "phone": "+70750426834"}
0005432525735	8ADF3C	3016 884735	MARINA NAZAROVA	{"email": "nazarova-m10071984@postgrespro.ru", "phone": "+70370821381"}
0005432525736	750BCA	9121 331931	IVAN MAKAROV	{"email": "imakarov-12011968@postgrespro.ru", "phone": "+70331877337"}
0005432525737	750BCA	6243 923282	NATALYA DENISOVA	{"email": "natalya_denisova1965@postgrespro.ru", "phone": "+70621487911"}
0005432525738	5188E7	7724 632944	NATALYA MAKSIMOVA	{"email": "maksimova.natalya-1974@postgrespro.ru", "phone": "+70307217367"}
0005432525739	037999	1275 986511	ALEKSANDR GERASIMOV	{"email": "gerasimova-24051980@postgrespro.ru", "phone": "+70956023676"}
0005432525740	C1E868	2086 180938	EVGENIY SOKOLOV	{"email": "e-sokolov.1970@postgrespro.ru", "phone": "+70408422478"}
0005432525741	5D186B	9880 253895	SERGEY TARASOV	{"email": "tarasov-s-041975@postgrespro.ru", "phone": "+70128045896"}
0005432525742	639DEC	3383 842232	LIDIYA ANTONOVA	{"email": "lidiyaantonova011975@postgrespro.ru", "phone": "+70637248084"}
0005432525743	639DEC	4013 320595	MAKSIM MEDVEDEV	{"email": "m_medvedev-1978@postgrespro.ru", "phone": "+70523383569"}
0005432525744	FB6AF2	3075 809875	EVGENIYA MIRONOVA	{"phone": "+70220977031"}
0005432525745	590EB3	2611 020098	TATYANA FROLOVA	{"phone": "+70681249052"}
0005432525746	590EB3	5326 010764	VALERIY MAKAROV	{"phone": "+70265348580"}
0005432525747	8C0C0B	6233 794731	PAVEL SOKOLOV	{"phone": "+70421489804"}
0005432525748	8C0C0B	8280 733956	LYUBOV SEMENOVA	{"email": "lyubov-semenova_031960@postgrespro.ru", "phone": "+70206228390"}
0005432525749	323CD2	6111 768760	ELVIRA GAVRILOVA	{"phone": "+70276772414"}
0005432525750	C99B3B	3838 833963	SERGEY FEDOTOV	{"phone": "+70029482783"}
0005432525751	C99B3B	9233 948327	PAVEL EGOROV	{"phone": "+70549384987"}
0005432525752	DF8AF6	0926 446032	VALERIY ILIN	{"email": "ilin-v_031983@postgrespro.ru", "phone": "+70349794904"}
0005432525753	2E54B6	1084 532304	SVETLANA PETROVA	{"phone": "+70865993038"}
0005432525754	8E0DB0	4820 876134	DARYA GUSEVA	{"phone": "+70432283821"}
0005432525755	CC8E0C	2612 667815	VADIM MIRONOV	{"phone": "+70798357703"}
0005432525756	CC8E0C	2931 564402	TAMARA ISAEVA	{"email": "tamara.isaeva1976@postgrespro.ru", "phone": "+70131096342"}
0005432525757	0C1014	1349 034374	KSENIYA EFREMOVA	{"phone": "+70677758927"}
0005432525758	896DF6	9432 716197	ANASTASIYA STEPANOVA	{"phone": "+70447234789"}
0005432525759	20FFEC	7495 346303	DIANA MEDVEDEVA	{"email": "diana.medvedeva.1970@postgrespro.ru", "phone": "+70111640515"}
0005432525760	4E45BB	7049 208810	IRINA GERASIMOVA	{"phone": "+70549011283"}
0005432525761	D7F996	2480 438379	VERA MOISEEVA	{"email": "veramoiseeva.11041981@postgrespro.ru", "phone": "+70077174609"}
0005432525762	EE0869	9868 905379	YULIYA SERGEEVA	{"phone": "+70654732332"}
0005432525763	C1FD35	8097 437811	TATYANA SERGEEVA	{"phone": "+70374194331"}
0005432525764	25AA77	0729 401903	VITALIY EGOROV	{"email": "vitaliy_egorov.031960@postgrespro.ru", "phone": "+70501872789"}
0005432525765	E7392F	4601 515351	ALEKSANDRA DMITRIEVA	{"phone": "+70853004023"}
0005432525766	AA153A	6027 569710	MARIYA FOMINA	{"phone": "+70620174144"}
0005432525767	AA153A	3185 367727	NINA OSIPOVA	{"email": "ninaosipova071968@postgrespro.ru", "phone": "+70700065689"}
0005432525768	3ECA50	9288 866570	LIDIYA SOKOLOVA	{"email": "l.sokolova.17071977@postgrespro.ru", "phone": "+70751948141"}
0005432525769	C3B950	7427 921505	NINA MOROZOVA	{"email": "ninamorozova1972@postgrespro.ru", "phone": "+70601781320"}
0005432525770	C3B950	6964 595290	ELENA ANTONOVA	{"email": "elena_antonova.1987@postgrespro.ru", "phone": "+70666515647"}
0005432525771	774353	9810 482083	RAISA SEMENOVA	{"email": "rsemenova-081983@postgrespro.ru", "phone": "+70738003994"}
0005432525772	362748	9552 143693	VIKTOR KRASNOV	{"email": "krasnovviktor-051982@postgrespro.ru", "phone": "+70441686697"}
0005432525773	362748	5464 019785	LYUBOV SMIRNOVA	{"email": "l.smirnova1975@postgrespro.ru", "phone": "+70031061164"}
0005432525774	A930DB	8442 787796	ALEKSEY SMIRNOV	{"phone": "+70831676421"}
0005432525775	D825F1	2910 079785	ARTEM NIKOLAEV	{"email": "nikolaev_a_01061973@postgrespro.ru", "phone": "+70846000146"}
0005432525776	D825F1	1713 339964	VALENTINA FOMINA	{"phone": "+70174344789"}
0005432525777	E1E05B	2538 511174	EGOR IVANOV	{"email": "ivanove-21071978@postgrespro.ru", "phone": "+70437233212"}
0005432525778	E1E05B	0705 601797	ZOYA MATVEEVA	{"email": "matveeva_z_1983@postgrespro.ru", "phone": "+70265531007"}
0005432525779	3ACA37	5174 169148	VYACHESLAV EGOROV	{"phone": "+70917354904"}
0005432525780	A0E922	0605 097347	ALEKSANDR FILIPPOV	{"phone": "+70643948927"}
0005432526078	9464FD	3283 503737	EKATERINA ZHUKOVA	{"phone": "+70696704176"}
0005432525781	5FA034	7352 840020	NADEZHDA KUZNECOVA	{"email": "nadezhdakuznecova.041983@postgrespro.ru", "phone": "+70779477933"}
0005432525782	5FA034	9644 719323	ALEKSEY SOROKIN	{"phone": "+70849214630"}
0005432525783	26E737	8213 832330	LYUBOV FILIPPOVA	{"email": "filippova-l1967@postgrespro.ru", "phone": "+70787316188"}
0005432525784	5969BD	7414 460804	DARYA TIKHONOVA	{"phone": "+70864526070"}
0005432525785	B32C27	3867 267101	VIKTORIYA KONDRATEVA	{"email": "kondrateva-v-25011968@postgrespro.ru", "phone": "+70985091198"}
0005432525786	B32C27	0066 363834	ALEKSANDR NIKOLAEV	{"phone": "+70959401927"}
0005432525787	B32C27	5613 592364	GALINA KOROLEVA	{"email": "korolevag.12021973@postgrespro.ru", "phone": "+70567136721"}
0005432525788	A8BA74	2103 920250	ELENA GAVRILOVA	{"email": "e.gavrilova.1971@postgrespro.ru", "phone": "+70943831583"}
0005432525789	A8BA74	7660 259487	MARINA RYABOVA	{"phone": "+70698993172"}
0005432525790	A8BA74	8081 793836	ANASTASIYA ZHUKOVA	{"email": "anastasiya_zhukova.25051969@postgrespro.ru", "phone": "+70294317124"}
0005432525791	AD9F3E	6869 129576	PAVEL KONOVALOV	{"email": "konovalov.p.071977@postgrespro.ru", "phone": "+70783525694"}
0005432525792	AD9F3E	8174 494267	LYUDMILA VOROBEVA	{"email": "vorobeval.031974@postgrespro.ru", "phone": "+70688421733"}
0005432525793	AD9F3E	5200 188481	MARIYA KOLESNIKOVA	{"email": "kolesnikova-m-1971@postgrespro.ru", "phone": "+70503648662"}
0005432525794	32AE73	2448 601447	OLGA KULIKOVA	{"phone": "+70785126093"}
0005432525795	213118	8833 642548	ANDREY MAKSIMOV	{"phone": "+70478122000"}
0005432525796	A50131	1499 863135	VLADIMIR MIRONOV	{"phone": "+70420647414"}
0005432525797	0F288E	6468 819995	ANASTASIYA YUDINA	{"email": "a.yudina.03121976@postgrespro.ru", "phone": "+70816556936"}
0005432525798	5FAD2C	2668 642046	ALEKSANDR RODIONOV	{"phone": "+70132285022"}
0005432525799	5F6176	1965 810410	NATALYA KUZNECOVA	{"email": "n-kuznecova-18111966@postgrespro.ru", "phone": "+70507903033"}
0005432525800	5F6176	7282 726630	ILYA ABRAMOV	{"email": "abramov_ilya-041968@postgrespro.ru", "phone": "+70902864608"}
0005432525801	09BB97	3040 712309	VIKTOR SIDOROV	{"email": "sidorovviktor081980@postgrespro.ru", "phone": "+70510121664"}
0005432525802	A531E7	2312 117807	NATALYA KUZNECOVA	{"email": "n.kuznecova1954@postgrespro.ru", "phone": "+70386765034"}
0005432525803	A531E7	9742 598987	MAKSIM IVANOV	{"phone": "+70298745363"}
0005432525804	A531E7	2215 507178	ARTEM MELNIKOV	{"email": "amelnikov1977@postgrespro.ru", "phone": "+70381325368"}
0005432525805	524A87	3948 310955	FILIPP TIMOFEEV	{"phone": "+70347958454"}
0005432525806	209E0E	3248 260104	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey.1981@postgrespro.ru", "phone": "+70793973798"}
0005432525807	209E0E	1972 830517	RAISA KUZNECOVA	{"phone": "+70941648603"}
0005432525808	17448B	7755 755912	DMITRIY SOKOLOV	{"email": "sokolovdmitriy1974@postgrespro.ru", "phone": "+70068976518"}
0005432525809	4A790F	9569 985303	ANTONINA EFREMOVA	{"email": "antoninaefremova29041973@postgrespro.ru", "phone": "+70934071011"}
0005432525810	4A790F	8528 202570	ALEKSANDR KUZNECOV	{"phone": "+70429927556"}
0005432525811	4BDD2F	8823 400139	VALENTINA SOLOVEVA	{"email": "soloveva_v-1964@postgrespro.ru", "phone": "+70106909233"}
0005432525812	4BDD2F	5767 117198	IREK STEPANOV	{"email": "stepanov_irek_101958@postgrespro.ru", "phone": "+70169456539"}
0005432525813	4E8D5E	1253 938325	ELENA FROLOVA	{"phone": "+70027601420"}
0005432525814	4E8D5E	8834 069891	NATALYA NESTEROVA	{"phone": "+70230420373"}
0005432525815	347FEE	3191 944619	VALENTIN TIKHONOV	{"phone": "+70366798861"}
0005432525816	347FEE	1948 866218	MARINA SCHERBAKOVA	{"phone": "+70214654877"}
0005432525817	360C5A	6643 813998	DMITRIY MIKHAYLOV	{"phone": "+70765210633"}
0005432525818	701ACD	4604 704650	OLGA MELNIKOVA	{"phone": "+70128429668"}
0005432525819	701ACD	2465 194034	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr1981@postgrespro.ru", "phone": "+70261426901"}
0005432525820	BACC97	0065 482670	NATALYA ANDREEVA	{"email": "andreeva-natalya.041980@postgrespro.ru", "phone": "+70309738653"}
0005432525821	AF7C3E	8131 101420	ELENA STEPANOVA	{"email": "estepanova1960@postgrespro.ru", "phone": "+70851807656"}
0005432525822	AF7C3E	1788 541117	MIKHAIL GERASIMOV	{"phone": "+70537621440"}
0005432525823	DEEBB7	4934 877007	SERGEY FROLOV	{"phone": "+70695368633"}
0005432525824	DEEBB7	5092 796857	VYACHESLAV ALEKSEEV	{"email": "vyacheslavalekseev.1971@postgrespro.ru", "phone": "+70402108019"}
0005432525825	B8D02A	1819 630725	SERGEY KULIKOV	{"phone": "+70996165835"}
0005432525826	B8D02A	0216 983198	ALEVTINA KUZMINA	{"phone": "+70448276615"}
0005432525827	B8D02A	1920 207866	ANTONINA FILIPPOVA	{"phone": "+70027351211"}
0005432525828	83FFB9	8405 464324	ALEKSANDR AFANASEV	{"phone": "+70289877341"}
0005432525829	BB596A	0796 483362	OLEG GAVRILOV	{"email": "oleggavrilov_1978@postgrespro.ru", "phone": "+70467848782"}
0005432525830	BB596A	9545 429035	ALEKSANDR SERGEEV	{"phone": "+70460814571"}
0005432525831	980DE0	5157 610885	SVETLANA BOGDANOVA	{"email": "svetlanabogdanova.031976@postgrespro.ru", "phone": "+70354259631"}
0005432525832	980DE0	9644 260505	INGA RYABOVA	{"phone": "+70696865305"}
0005432525833	551EC9	8711 585060	VERA MARTYNOVA	{"phone": "+70414649501"}
0005432525834	72E7E9	4700 123875	EVGENIYA KULIKOVA	{"email": "kulikova.e-061975@postgrespro.ru", "phone": "+70125559544"}
0005432525835	891491	9834 017039	EKATERINA PAVLOVA	{"phone": "+70620750812"}
0005432525836	BF9D22	1154 087784	DAMIR MARTYNOV	{"phone": "+70653397028"}
0005432525837	13B6CD	7926 385281	TATYANA FOMINA	{"email": "fomina.tatyana-111972@postgrespro.ru", "phone": "+70727860459"}
0005432525838	13B6CD	4194 499652	VERA IVANOVA	{"phone": "+70674656578"}
0005432525839	F5AF51	4535 453015	EVGENIY VOROBEV	{"email": "vorobev_evgeniy-061969@postgrespro.ru", "phone": "+70370663793"}
0005432525840	D43720	5309 835658	EVGENIY VOROBEV	{"phone": "+70848324921"}
0005432525841	D0796F	2387 395787	EKATERINA ROMANOVA	{"email": "ekaterina_romanova-1979@postgrespro.ru", "phone": "+70153527318"}
0005432525842	D0796F	5987 620027	ELENA STEPANOVA	{"email": "elena-stepanova.031975@postgrespro.ru", "phone": "+70742116168"}
0005432525843	68C198	2205 484528	GEORGIY MAKAROV	{"email": "georgiy.makarov.101972@postgrespro.ru", "phone": "+70242312137"}
0005432525844	16536F	6064 617280	MARINA GUSEVA	{"email": "gusevam-1980@postgrespro.ru", "phone": "+70010861654"}
0005432525845	16536F	2955 270388	MAYYA ARKHIPOVA	{"phone": "+70042760577"}
0005432525846	EA092D	8187 043827	ANATOLIY FILIPPOV	{"phone": "+70695150747"}
0005432525847	EA092D	1323 818764	SERGEY SMIRNOV	{"phone": "+70641643990"}
0005432525848	1B6A7E	4535 359302	ALINA NESTEROVA	{"email": "nesterova_alina-07121963@postgrespro.ru", "phone": "+70594274969"}
0005432525849	9D42FA	8621 393611	EGOR SOLOVEV	{"phone": "+70710587492"}
0005432525850	F4FEC2	3055 793828	NATALYA BOGDANOVA	{"phone": "+70611392500"}
0005432525851	F57916	9270 614528	INNA POPOVA	{"phone": "+70008319169"}
0005432525852	F6E84C	3736 978300	NATALYA IVANOVA	{"email": "ivanova-natalya12101973@postgrespro.ru", "phone": "+70276598905"}
0005432525853	F6E84C	0287 293569	ALEKSANDRA VOLKOVA	{"email": "aleksandra_volkova.24031970@postgrespro.ru", "phone": "+70190044030"}
0005432525854	E717A0	4805 772609	NATALIYA ANTONOVA	{"email": "antonova_nataliya01071971@postgrespro.ru", "phone": "+70085346683"}
0005432525855	A127A6	2503 893885	ANDREY KUZNECOV	{"email": "kuznecovandrey.041985@postgrespro.ru", "phone": "+70806087128"}
0005432525856	097BAB	3422 040583	EKATERINA SEMENOVA	{"phone": "+70565685736"}
0005432525857	097BAB	0861 238747	ANDREY ILIN	{"phone": "+70433862487"}
0005432525858	EB9760	3094 580802	VADIM VASILEV	{"email": "v.vasilev_1972@postgrespro.ru", "phone": "+70755570261"}
0005432525859	EB9760	4699 588588	LYAYSAN MAKAROVA	{"email": "l_makarova_021969@postgrespro.ru", "phone": "+70269112283"}
0005432525860	EB9760	0838 164155	LYUDMILA NAZAROVA	{"phone": "+70853232607"}
0005432525861	9E6A1A	9895 980674	VLADIMIR PETROV	{"phone": "+70744563576"}
0005432525862	15980C	5068 307408	MARINA EGOROVA	{"phone": "+70721979130"}
0005432525863	15980C	2541 737548	ALEKSANDR BARANOV	{"phone": "+70830283210"}
0005432525864	6541CE	0023 435509	DENIS FEDOTOV	{"email": "fedotov_denis_061968@postgrespro.ru", "phone": "+70972476006"}
0005432525865	BD92E9	0447 285909	NIKOLAY PAVLOV	{"email": "nikolay-pavlov.25081969@postgrespro.ru", "phone": "+70770969989"}
0005432525866	968DC7	4070 530395	ALEKSANDRA GRISHINA	{"phone": "+70723884387"}
0005432525867	3A017A	6714 285089	ARTUR PETROV	{"phone": "+70188793547"}
0005432525868	344C39	0709 503981	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda111966@postgrespro.ru", "phone": "+70192112014"}
0005432525869	344C39	3529 998280	VALENTINA MEDVEDEVA	{"email": "valentina_medvedeva.28051969@postgrespro.ru", "phone": "+70102483772"}
0005432525870	CDEAA6	8743 708561	MIKHAIL BORISOV	{"email": "mikhail-borisov.071978@postgrespro.ru", "phone": "+70636357601"}
0005432525871	F5D31C	9954 256666	YURIY SEMENOV	{"email": "yuriy_semenov.01071974@postgrespro.ru", "phone": "+70589231475"}
0005432525872	F5D31C	0115 872249	NATALYA PETROVA	{"phone": "+70939127251"}
0005432525873	1BC631	7388 360866	VALERIYA ABRAMOVA	{"email": "abramova.valeriya-10121979@postgrespro.ru", "phone": "+70773570120"}
0005432525874	C19F8F	0464 901350	ZOYA TITOVA	{"email": "z.titova1981@postgrespro.ru", "phone": "+70672415737"}
0005432525875	CA7F75	6688 975703	ILYA POPOV	{"email": "ilya_popov.031970@postgrespro.ru", "phone": "+70471373152"}
0005432525876	0A4B08	3681 600887	RIFAT DENISOV	{"phone": "+70638426237"}
0005432525877	D97D9C	9430 673286	RAISA MAKAROVA	{"phone": "+70690235653"}
0005432525878	783CBB	7521 122187	ANNA KOVALEVA	{"phone": "+70695941483"}
0005432525879	783CBB	0781 014101	DIANA ZHURAVLEVA	{"phone": "+70647190615"}
0005432525880	0CD5DE	3710 331118	DANILA TIKHONOV	{"phone": "+70387842855"}
0005432525881	39DB07	2840 488806	ALEKSANDR KUZMIN	{"email": "a.kuzmin_1978@postgrespro.ru", "phone": "+70736267202"}
0005432525882	39DB07	2483 383279	ELENA KOZLOVA	{"phone": "+70792243215"}
0005432525883	1F0C58	6934 437225	MARIYA KUZNECOVA	{"email": "m_kuznecova_29121972@postgrespro.ru", "phone": "+70370830102"}
0005432525884	B86CA7	0993 056188	DMITRIY ORLOV	{"phone": "+70621162360"}
0005432525885	0934FC	5903 500988	GALINA IVANOVA	{"phone": "+70557244788"}
0005432525886	0934FC	7481 860564	DMITRIY MAKAROV	{"phone": "+70245660872"}
0005432525887	0934FC	0044 947532	ELENA POTAPOVA	{"phone": "+70099123693"}
0005432525888	606C30	4027 438026	VIKTOR ANDREEV	{"email": "andreevviktor1961@postgrespro.ru", "phone": "+70246036002"}
0005432525889	E51568	7776 384747	ALEKSANDR KUZMIN	{"email": "kuzmin-a-1968@postgrespro.ru", "phone": "+70471022046"}
0005432525890	6682DF	3355 559211	EGOR POPOV	{"email": "popov.e1977@postgrespro.ru", "phone": "+70415208666"}
0005432525891	6682DF	7528 294178	VIKTOR STEPANOV	{"phone": "+70519937762"}
0005432525892	237263	5845 036558	VALENTIN KUZNECOV	{"email": "v.kuznecov_1987@postgrespro.ru", "phone": "+70224978138"}
0005432525893	7643E2	8085 968231	SERGEY SHEVCHENKO	{"phone": "+70138199320"}
0005432525894	7643E2	7983 623031	VIKTORIYA VOLKOVA	{"email": "volkovaviktoriya-20061966@postgrespro.ru", "phone": "+70710715475"}
0005432525895	F5F2AB	0695 307136	NADEZHDA ALEKSEEVA	{"phone": "+70351299855"}
0005432525896	F5F2AB	6951 676231	NATALIYA DAVYDOVA	{"phone": "+70894943364"}
0005432525897	6B8C97	5170 554791	ALEKSANDR GERASIMOV	{"email": "gerasimov.a-041975@postgrespro.ru", "phone": "+70676258154"}
0005432525898	6B8C97	2348 406661	YURIY KISELEV	{"phone": "+70992972717"}
0005432525899	DE82C0	4547 989802	IVAN IVANOV	{"email": "ivan.ivanov_25021966@postgrespro.ru", "phone": "+70151797797"}
0005432526233	2F8C69	7207 860145	SVETLANA TARASOVA	{"phone": "+70682403367"}
0005432525900	DE82C0	4097 902930	NURIYA KAZAKOVA	{"email": "kazakova_n_1975@postgrespro.ru", "phone": "+70355059819"}
0005432525901	9FC6F5	8385 293593	ANDREY VASILEV	{"phone": "+70160425658"}
0005432525902	9FC6F5	7442 778267	ALEKSEY VOLKOV	{"phone": "+70368325062"}
0005432525903	9FC6F5	6644 289321	OKSANA SEMENOVA	{"email": "oksana-semenova12071966@postgrespro.ru", "phone": "+70985182258"}
0005432525904	6B73AB	7313 104278	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin01041979@postgrespro.ru", "phone": "+70221376534"}
0005432525905	6B73AB	1993 907934	TATYANA NIKITINA	{"phone": "+70249519768"}
0005432525906	3B76A6	7618 150616	ANASTASIYA KISELEVA	{"email": "kiseleva-anastasiya26121979@postgrespro.ru", "phone": "+70622000924"}
0005432525907	EB80F7	2697 632873	EVGENIY ZAKHAROV	{"email": "zakharovevgeniy_1970@postgrespro.ru", "phone": "+70194025385"}
0005432525908	EB80F7	2109 062806	ALEKSEY NAUMOV	{"email": "naumov_aleksey-21071971@postgrespro.ru", "phone": "+70303237037"}
0005432525909	B9FDC0	7775 410267	TAMARA KONOVALOVA	{"email": "tamara_konovalova_1951@postgrespro.ru", "phone": "+70144859290"}
0005432525910	3759FC	3855 582965	ROZA FOMINA	{"phone": "+70075281381"}
0005432525911	3759FC	7272 491235	DENIS MIKHAYLOV	{"email": "denis_mikhaylov.121969@postgrespro.ru", "phone": "+70006289145"}
0005432525912	3759FC	2568 105191	ALISA KOVALEVA	{"phone": "+70097799575"}
0005432525913	9849A4	0320 460746	TATYANA ANDREEVA	{"email": "tatyanaandreeva_1981@postgrespro.ru", "phone": "+70743857157"}
0005432525914	9849A4	9920 557263	VITALIY IVANOV	{"email": "ivanovvitaliy1969@postgrespro.ru", "phone": "+70172481315"}
0005432525915	090937	3411 729360	VASILIY KUZNECOV	{"phone": "+70690168235"}
0005432525916	090937	1776 468241	DENIS KUZMIN	{"email": "denis.kuzmin_031970@postgrespro.ru", "phone": "+70909244214"}
0005432525917	8E64FE	6218 542377	VLADIMIR STEPANOV	{"phone": "+70606880461"}
0005432525918	8E64FE	3171 399685	ALEKSANDR IVANOV	{"phone": "+70458993936"}
0005432525919	8E64FE	5006 607684	VITALIY TIKHONOV	{"phone": "+70406259695"}
0005432525920	125B0E	6065 750427	ANASTASIYA ARKHIPOVA	{"email": "a.arkhipova-031974@postgrespro.ru", "phone": "+70780428433"}
0005432525921	125B0E	3327 654108	ANDREY SHEVCHENKO	{"phone": "+70886601808"}
0005432525922	A5881C	1289 936777	ROMAN SMIRNOV	{"email": "smirnov-r.071968@postgrespro.ru", "phone": "+70839547394"}
0005432525923	D99B6C	5938 974533	MARIYA FILIPPOVA	{"email": "filippova_mariya.1976@postgrespro.ru", "phone": "+70380156053"}
0005432525924	D99B6C	8890 377978	NIKOLAY KUZNECOV	{"email": "kuznecov-n_1968@postgrespro.ru", "phone": "+70244962004"}
0005432525925	695A54	3151 072001	OLGA GERASIMOVA	{"email": "gerasimova.o1971@postgrespro.ru", "phone": "+70472292306"}
0005432525926	695A54	7203 353270	EKATERINA FILIPPOVA	{"email": "ekaterina_filippova_24111966@postgrespro.ru", "phone": "+70789182105"}
0005432525927	4D4945	6582 100695	NATALYA MOROZOVA	{"phone": "+70299835653"}
0005432525928	4D4945	6418 635008	VLADIMIR KOROLEV	{"phone": "+70171839206"}
0005432525929	CB45D8	8847 784320	GALINA ANDREEVA	{"phone": "+70043479643"}
0005432525930	CB45D8	3950 709031	DANIL MAKSIMOV	{"phone": "+70667087882"}
0005432525931	E6A4FE	2972 513419	ALEKSANDR ZHUKOV	{"phone": "+70871683100"}
0005432525932	E6A4FE	0581 802421	MARIYA KUZMINA	{"phone": "+70916261795"}
0005432525933	8DAEF5	8718 103291	GALINA KOLESNIKOVA	{"phone": "+70702969467"}
0005432525934	6E74B0	5193 439651	NINA EFREMOVA	{"email": "nina_efremova.061970@postgrespro.ru", "phone": "+70637502573"}
0005432525935	6EF022	9529 593971	GALINA GAVRILOVA	{"email": "gavrilovagalina-19041977@postgrespro.ru", "phone": "+70430468982"}
0005432525936	68AD6E	7987 544738	NATALYA YUDINA	{"phone": "+70024419376"}
0005432525937	31B818	8017 314257	ANASTASIYA MAKSIMOVA	{"email": "anastasiya-maksimova.1969@postgrespro.ru", "phone": "+70996312621"}
0005432525938	31B818	1737 709593	ALEKSANDR ROMANOV	{"phone": "+70692623235"}
0005432525939	8D207E	2419 857792	YULIYA EGOROVA	{"phone": "+70418713519"}
0005432525940	C7AEC1	5150 174050	ALEKSANDR NAZAROV	{"email": "nazarova-18101966@postgrespro.ru", "phone": "+70852657527"}
0005432525941	C7AEC1	6713 002388	VIKTORIYA MEDVEDEVA	{"phone": "+70164851436"}
0005432525942	BB06FF	2550 198804	IVAN BONDARENKO	{"phone": "+70415914255"}
0005432525943	35BCA9	9768 615352	GENNADIY AFANASEV	{"phone": "+70856586623"}
0005432525944	B87892	7763 082152	KARINA VLASOVA	{"email": "vlasova.karina_071964@postgrespro.ru", "phone": "+70412202949"}
0005432525945	B87892	1078 928118	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov071979@postgrespro.ru", "phone": "+70145434058"}
0005432525946	A31B83	4835 551293	ELENA ALEKSANDROVA	{"phone": "+70773233400"}
0005432525947	77850C	5275 691463	ELIZAVETA STEPANOVA	{"email": "estepanova1983@postgrespro.ru", "phone": "+70067577602"}
0005432525948	77850C	5465 428295	IGOR FILIPPOV	{"phone": "+70941056828"}
0005432525949	71B84D	1726 653540	VLADIMIR IVANOV	{"phone": "+70987774563"}
0005432525950	20CAF8	5716 484380	VALERIY SMIRNOV	{"email": "valeriy-smirnov.111973@postgrespro.ru", "phone": "+70451337949"}
0005432525951	C1AE8C	1081 467887	DARYA KOROLEVA	{"email": "koroleva-d.061980@postgrespro.ru", "phone": "+70460109513"}
0005432525952	BE7821	5398 446457	VLADIMIR SCHERBAKOV	{"phone": "+70763389557"}
0005432525953	BE7821	3808 616426	VALENTINA FILATOVA	{"email": "valentina_filatova-04021961@postgrespro.ru", "phone": "+70258992850"}
0005432525954	E6D1D9	4630 233328	ANZHELIKA VASILEVA	{"email": "anzhelika-vasileva-1977@postgrespro.ru", "phone": "+70601458848"}
0005432526623	B0BCA5	8460 686760	YURIY VASILEV	{"phone": "+70508886471"}
0005432525955	E6D1D9	0404 022558	ALEKSEY SHEVCHENKO	{"email": "shevchenkoaleksey1982@postgrespro.ru", "phone": "+70649778464"}
0005432525956	051975	9129 167770	VASILIY SEMENOV	{"phone": "+70708687011"}
0005432525957	BC076B	2875 302772	EVGENIY SERGEEV	{"phone": "+70160646283"}
0005432525958	BC076B	9951 944979	SERGEY NIKOLAEV	{"email": "sergey-nikolaev.111967@postgrespro.ru", "phone": "+70141785770"}
0005432525959	EB63DA	2994 086478	OLEG AFANASEV	{"email": "afanasev-o-121963@postgrespro.ru", "phone": "+70344476444"}
0005432525960	C6A12D	3556 366223	MIKHAIL STEPANOV	{"phone": "+70585635159"}
0005432525961	C6A12D	7534 938147	EVGENIY BELOV	{"phone": "+70859768737"}
0005432525962	847C98	6311 292455	NATALYA MOROZOVA	{"email": "n_morozova-08121969@postgrespro.ru", "phone": "+70791876159"}
0005432525963	847C98	3434 243782	IVAN ZHUKOV	{"phone": "+70736061596"}
0005432525964	0A147A	2198 115774	LYUDMILA KALININA	{"email": "kalinina_lyudmila14061974@postgrespro.ru", "phone": "+70081687569"}
0005432525965	0A147A	2640 025317	TIMUR ZAYCEV	{"phone": "+70411655376"}
0005432525966	C43D8C	3571 025828	MARIYA ISAEVA	{"email": "isaeva.mariya-22061979@postgrespro.ru", "phone": "+70856368338"}
0005432525967	A46593	3785 190421	VASILIY ANDREEV	{"phone": "+70190485410"}
0005432525968	A46593	2835 068570	VLADIMIR SMIRNOV	{"email": "v_smirnov-16041971@postgrespro.ru", "phone": "+70790842145"}
0005432525969	26099C	8997 307533	SERGEY MOROZOV	{"email": "morozov-sergey-30051970@postgrespro.ru", "phone": "+70256055310"}
0005432525970	5F8185	9495 624490	LYUDMILA ERMAKOVA	{"email": "lyudmilaermakova-041969@postgrespro.ru", "phone": "+70194833788"}
0005432525971	5F8185	8763 274740	VALENTIN SERGEEV	{"phone": "+70290102525"}
0005432525972	C7CDE9	9782 264875	ALEKSANDR GRIGOREV	{"email": "a_grigorev_1960@postgrespro.ru", "phone": "+70134251836"}
0005432525973	A1F1E7	7991 879727	ANASTASIYA ROMANOVA	{"email": "romanova.a28121968@postgrespro.ru", "phone": "+70311044445"}
0005432525974	0B7325	1094 403218	ALBINA ZAKHAROVA	{"email": "azakharova_1967@postgrespro.ru", "phone": "+70430480984"}
0005432525975	A536E4	7962 526262	SVETLANA ROMANOVA	{"phone": "+70720080376"}
0005432525976	B86A9E	9553 698079	SERGEY GAVRILOV	{"phone": "+70686984049"}
0005432525977	443796	3911 884331	ALEKSANDR ALEKSEEV	{"phone": "+70874824754"}
0005432525978	609F07	4379 173402	MARGARITA PETROVA	{"email": "petrova_margarita_29011970@postgrespro.ru", "phone": "+70289042980"}
0005432525979	1107EB	6838 873933	NADEZHDA VOLKOVA	{"email": "volkovan13071960@postgrespro.ru", "phone": "+70332398891"}
0005432525980	1107EB	7190 130446	VALENTINA KUZNECOVA	{"email": "vkuznecova041977@postgrespro.ru", "phone": "+70318342027"}
0005432525981	52784D	3373 313382	MARGARITA BOGDANOVA	{"email": "margarita-bogdanova_08111963@postgrespro.ru", "phone": "+70042214251"}
0005432525982	52784D	7806 492180	VLADIMIR KUZNECOV	{"phone": "+70771011338"}
0005432525983	5FE0F7	4301 878728	MARSEL KUZNECOV	{"email": "m-kuznecov1961@postgrespro.ru", "phone": "+70708877349"}
0005432525984	85D77A	8946 378500	IRINA POTAPOVA	{"email": "i-potapova101973@postgrespro.ru", "phone": "+70887676655"}
0005432525985	85D77A	6164 024592	MARIYA KONOVALOVA	{"phone": "+70585217077"}
0005432525986	85D77A	8000 348840	OLGA KUDRYASHOVA	{"phone": "+70239799534"}
0005432525987	54C2B9	1940 405421	LYUDMILA KUZMINA	{"email": "l_kuzmina-30031957@postgrespro.ru", "phone": "+70854328655"}
0005432525988	17A843	8926 936907	DMITRIY FEDOTOV	{"email": "dmitriyfedotov1977@postgrespro.ru", "phone": "+70806672588"}
0005432525989	5C6DC2	9644 630058	VYACHESLAV DMITRIEV	{"email": "dmitriev.vyacheslav.051973@postgrespro.ru", "phone": "+70243076742"}
0005432525990	7B137B	7123 262167	RINAT KOZLOV	{"email": "kozlov.r_051980@postgrespro.ru", "phone": "+70369504899"}
0005432525991	7B137B	2381 574554	YULIYA POPOVA	{"email": "popova_y26031971@postgrespro.ru", "phone": "+70616255061"}
0005432525992	14E1AA	2640 448844	NIKOLAY KUDRYASHOV	{"phone": "+70623581420"}
0005432525993	D2F9FE	9392 117914	VLADIMIR NOVIKOV	{"email": "novikov-v_1985@postgrespro.ru", "phone": "+70189965101"}
0005432525994	B36C60	2673 231956	EVGENIY FROLOV	{"email": "e-frolov.121969@postgrespro.ru", "phone": "+70554242798"}
0005432525995	720AD4	0916 812998	NATALYA AKIMOVA	{"phone": "+70879847420"}
0005432525996	193993	8745 751833	ELENA LAZAREVA	{"phone": "+70815351424"}
0005432525997	193993	3981 011638	VLADIMIR ALEKSEEV	{"phone": "+70580365531"}
0005432525998	10FB07	0293 066923	SVYATOSLAV MOISEEV	{"email": "s_moiseev-1974@postgrespro.ru", "phone": "+70978958695"}
0005432525999	892972	4636 782211	NATALIYA TIMOFEEVA	{"phone": "+70266592407"}
0005432526000	070C7C	1292 669256	MILANA ZOTOVA	{"email": "mzotova-17031972@postgrespro.ru", "phone": "+70629131280"}
0005432526001	1C78E0	8137 923666	OLGA DENISOVA	{"phone": "+70269798892"}
0005432526002	D085AD	8463 957136	TATYANA NIKOLAEVA	{"email": "tatyana_nikolaeva1967@postgrespro.ru", "phone": "+70853389035"}
0005432526003	D085AD	4082 233876	IRINA ZAYCEVA	{"phone": "+70687711207"}
0005432526004	A55AEC	6052 122895	SERGEY STEPANOV	{"phone": "+70302794043"}
0005432526005	A55AEC	1296 033967	VALERIY GORBUNOV	{"email": "gorbunov.v.19061967@postgrespro.ru", "phone": "+70879799218"}
0005432526006	C29AFA	8709 524959	TAMARA MELNIKOVA	{"email": "melnikova_t-111971@postgrespro.ru", "phone": "+70249178311"}
0005432526007	F30BC4	0484 327932	ALEKSANDR KARPOV	{"phone": "+70197872695"}
0005432526008	F30BC4	2924 878295	LYUBOV ROMANOVA	{"phone": "+70465713502"}
0005432526009	249C1B	3032 753711	ALEKSEY STEPANOV	{"phone": "+70287186774"}
0005432526624	2EBB0F	0485 788212	GEORGIY YAKOVLEV	{"phone": "+70051573225"}
0005432526010	1F7AAE	8312 490470	TATYANA LOGINOVA	{"email": "loginova.tatyana-041970@postgrespro.ru", "phone": "+70441563951"}
0005432526011	81932B	5578 367674	ANDREY DENISOV	{"email": "denisov-a_14041968@postgrespro.ru", "phone": "+70604444097"}
0005432526012	81932B	6686 411816	ALEKSANDR SIDOROV	{"email": "sidorov.a_1969@postgrespro.ru", "phone": "+70583853519"}
0005432526013	AF493C	6365 262994	KONSTANTIN ABRAMOV	{"phone": "+70097030914"}
0005432526014	AF493C	6639 485896	SVETLANA KUZMINA	{"email": "svetlana_kuzmina.1968@postgrespro.ru", "phone": "+70972350037"}
0005432526015	99D87D	3038 482699	VADIM KOROLEV	{"phone": "+70217763987"}
0005432526016	6DE4D0	6685 795823	MARGARITA TROFIMOVA	{"email": "m-trofimova_081966@postgrespro.ru", "phone": "+70303433915"}
0005432526019	61179F	9035 058331	ILYA KUZNECOV	{"email": "kuznecovilya_31121972@postgrespro.ru", "phone": "+70679079515"}
0005432526020	A545BF	2696 327551	VALENTINA BOGDANOVA	{"email": "bogdanova_valentina.05111977@postgrespro.ru", "phone": "+70732549228"}
0005432526021	739723	6388 700504	NIKOLAY ANDREEV	{"email": "andreev-nikolay1968@postgrespro.ru", "phone": "+70793228192"}
0005432526022	739723	6776 729512	LILIYA GORBUNOVA	{"phone": "+70458572468"}
0005432526023	AEA5D4	7920 553547	LYUDMILA SCHERBAKOVA	{"phone": "+70706894624"}
0005432526024	ED1A11	9128 161603	ANTON MOISEEV	{"phone": "+70043515209"}
0005432526025	3C9973	1220 179002	LYUDMILA ZHUKOVA	{"email": "lyudmila-zhukova.30121978@postgrespro.ru", "phone": "+70500117975"}
0005432526026	97D82F	9443 007645	KLARA SOROKINA	{"phone": "+70345394857"}
0005432526027	4A021A	0113 734069	LYUBOV TARASOVA	{"email": "l-tarasova-1975@postgrespro.ru", "phone": "+70726187880"}
0005432526028	4A021A	6174 229194	IVAN ABRAMOV	{"email": "abramovi13101974@postgrespro.ru", "phone": "+70680123216"}
0005432526029	185AC1	8630 935991	MAYYA RODIONOVA	{"phone": "+70927527104"}
0005432526030	3137A9	3481 083968	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.nikolay-091965@postgrespro.ru", "phone": "+70410298083"}
0005432526031	3137A9	4307 331225	VALERIY ALEKSEEV	{"phone": "+70912293314"}
0005432526032	F28AB7	3182 461419	ANNA MARTYNOVA	{"email": "amartynova-16061980@postgrespro.ru", "phone": "+70491420193"}
0005432526033	48033B	4691 666085	ALEKSEY NIKITIN	{"email": "alekseynikitin.08111971@postgrespro.ru", "phone": "+70731495970"}
0005432526034	48033B	7953 679809	ALESYA SERGEEVA	{"phone": "+70365196454"}
0005432526035	440C28	1912 539363	IVAN ZAKHAROV	{"phone": "+70806842774"}
0005432526036	7AD863	5208 833162	VASILIY KUZNECOV	{"email": "kuznecovv-02031983@postgrespro.ru", "phone": "+70082755383"}
0005432526037	7AD863	7237 215456	TAMARA MIKHAYLOVA	{"phone": "+70368689019"}
0005432526038	7AD863	8364 948555	VLADIMIR SERGEEV	{"phone": "+70385358695"}
0005432526039	A5C6DC	7078 624295	VERA VASILEVA	{"phone": "+70797302959"}
0005432526040	F0F6BE	2575 670810	TATYANA GUSEVA	{"phone": "+70943125269"}
0005432526041	F0F6BE	4935 953656	VIKTOR KUZNECOV	{"email": "viktor.kuznecov_13051977@postgrespro.ru", "phone": "+70118869718"}
0005432526042	FC4BCB	8990 389955	MIKHAIL EGOROV	{"email": "m.egorov.1965@postgrespro.ru", "phone": "+70080129346"}
0005432526043	1866FD	4276 311198	ROMAN MELNIKOV	{"phone": "+70476775441"}
0005432526044	869755	0226 372769	VIKTOR KUZNECOV	{"phone": "+70353019287"}
0005432526045	FD9CCD	4157 117766	VALENTINA ALEKSEEVA	{"phone": "+70037573592"}
0005432526046	FD9CCD	8299 673644	OLGA NIKITINA	{"email": "onikitina-20081977@postgrespro.ru", "phone": "+70498182520"}
0005432526047	3495D3	7007 885541	IRINA STEPANOVA	{"email": "stepanova.i_061975@postgrespro.ru", "phone": "+70122703760"}
0005432526048	3495D3	8741 864618	VALERIY GERASIMOV	{"phone": "+70702089321"}
0005432526049	55A47E	6962 506496	ANASTASIYA YAKOVLEVA	{"email": "yakovleva_anastasiya-051963@postgrespro.ru", "phone": "+70127359767"}
0005432526050	55A47E	1146 309044	NATALYA TIKHONOVA	{"phone": "+70425143651"}
0005432526051	E62A72	4145 482723	EVGENIYA VASILEVA	{"email": "vasilevaevgeniya1974@postgrespro.ru", "phone": "+70326531349"}
0005432526052	372472	0223 345825	ALEKSANDRA LEBEDEVA	{"phone": "+70936615267"}
0005432526053	372472	9648 281258	NADEZHDA VOLKOVA	{"email": "n_volkova081978@postgrespro.ru", "phone": "+70405323058"}
0005432526054	86BA70	5464 304106	RIMMA NIKITINA	{"phone": "+70248153768"}
0005432526055	0940D2	0487 234233	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov.1975@postgrespro.ru", "phone": "+70833182919"}
0005432526056	0940D2	5790 502918	YURIY ORLOV	{"email": "orlov.y-1970@postgrespro.ru", "phone": "+70244160921"}
0005432526057	E62786	6690 934714	ALINA KOROLEVA	{"email": "koroleva_a12111962@postgrespro.ru", "phone": "+70889684048"}
0005432526058	E62786	7174 625862	VALERIY MAKSIMOV	{"email": "maksimov_valeriy21061969@postgrespro.ru", "phone": "+70046307251"}
0005432526059	E62786	9744 288197	OKSANA EFREMOVA	{"phone": "+70611240597"}
0005432526060	E62786	1714 536764	LYUBOV KOZLOVA	{"phone": "+70233210731"}
0005432526061	C965FE	9436 582288	ALEKSANDR NAZAROV	{"email": "nazarov-a.05071975@postgrespro.ru", "phone": "+70888207020"}
0005432526062	D2856B	9966 867149	ROMAN IVANOV	{"phone": "+70469996530"}
0005432526063	47AA32	8935 048356	ALEKSANDR FROLOV	{"email": "aleksandr_frolov-061980@postgrespro.ru", "phone": "+70057572078"}
0005432526064	47AA32	7298 592113	TAMARA POPOVA	{"phone": "+70833968095"}
0005432526065	47AA32	0253 630518	ALEKSEY KUZNECOV	{"email": "kuznecov_a1967@postgrespro.ru", "phone": "+70944858747"}
0005432526066	124789	2985 543042	ANATOLIY SAVELEV	{"email": "savelev_a.25071963@postgrespro.ru", "phone": "+70176795308"}
0005432526067	124789	0814 294214	TATYANA ILINA	{"email": "tatyana-ilina.1976@postgrespro.ru", "phone": "+70859731157"}
0005432526068	124789	8865 421122	PAVEL TIKHONOV	{"email": "pavel_tikhonov-05121976@postgrespro.ru", "phone": "+70465891781"}
0005432526069	896478	1789 739395	NATALYA MOISEEVA	{"phone": "+70656642320"}
0005432526070	220081	4022 514360	OLGA POTAPOVA	{"email": "potapova_olga121954@postgrespro.ru", "phone": "+70176226419"}
0005432526071	220081	8476 507360	NATALIYA MARTYNOVA	{"email": "nataliyamartynova-011979@postgrespro.ru", "phone": "+70843617024"}
0005432526072	C6ECE4	7840 464065	YURIY ABRAMOV	{"email": "abramov-y-30031973@postgrespro.ru", "phone": "+70378837526"}
0005432526073	5D59AB	2651 278594	LIDIYA PETROVA	{"email": "petrovalidiya.1975@postgrespro.ru", "phone": "+70431493810"}
0005432526074	8F8C9D	8983 111312	NATALYA KOMAROVA	{"phone": "+70321636152"}
0005432526075	879CE9	8936 103160	MIKHAIL SHEVCHENKO	{"phone": "+70867330055"}
0005432526076	716C98	0311 636935	SERGEY MAKAROV	{"email": "s.makarov08101970@postgrespro.ru", "phone": "+70679679298"}
0005432526077	DB17AA	7095 575413	MARIYA SCHERBAKOVA	{"phone": "+70421918352"}
0005432526079	9B628B	5134 287970	LARISA NIKOLAEVA	{"phone": "+70497916405"}
0005432526080	B734CA	0290 807578	NIKOLAY ZAKHAROV	{"phone": "+70090974170"}
0005432526081	24246A	4022 736391	OKSANA FROLOVA	{"email": "frolova.oksana-121970@postgrespro.ru", "phone": "+70409306926"}
0005432526082	9E1D3B	4293 169709	ALEKSANDR MATVEEV	{"phone": "+70324840868"}
0005432526083	D2E01D	3254 064327	VERA OVCHINNIKOVA	{"email": "vera.ovchinnikova101972@postgrespro.ru", "phone": "+70923783279"}
0005432526084	D2E01D	6721 253513	MARIYA VOLKOVA	{"phone": "+70300351462"}
0005432526085	1CDD24	8442 088573	DMITRIY NOVIKOV	{"email": "d-novikov-08041976@postgrespro.ru", "phone": "+70018699861"}
0005432526086	1CDD24	9719 088217	EVGENIY DAVYDOV	{"email": "davydov-e111976@postgrespro.ru", "phone": "+70306793626"}
0005432526087	DF1B36	6575 742241	NADEZHDA CHERNOVA	{"email": "nchernova_111971@postgrespro.ru", "phone": "+70942881862"}
0005432526088	DF1B36	8707 126376	OLESYA VOLKOVA	{"phone": "+70140848796"}
0005432526089	7C2298	7269 622557	OKSANA BOGDANOVA	{"email": "o-bogdanova-09051976@postgrespro.ru", "phone": "+70541396421"}
0005432526090	AED0F5	0418 307676	ALEKSEY SERGEEV	{"email": "a_sergeev18121973@postgrespro.ru", "phone": "+70844743478"}
0005432526091	C5E16B	7103 838536	SERGEY SERGEEV	{"phone": "+70113901167"}
0005432526092	C5E16B	2821 681064	ELENA DENISOVA	{"email": "elena_denisova-17091976@postgrespro.ru", "phone": "+70118132910"}
0005432526093	7E6253	6273 139761	TATYANA VOLKOVA	{"phone": "+70569353854"}
0005432526094	F21BCE	1403 902108	ANNA PAVLOVA	{"phone": "+70223281854"}
0005432526095	232A85	0363 984062	LYUBOV SCHERBAKOVA	{"phone": "+70413566089"}
0005432526096	5D2761	1181 244376	IRINA IVANOVA	{"phone": "+70227113651"}
0005432526097	5D2761	4754 152842	PAVEL ROMANOV	{"phone": "+70164266446"}
0005432526098	AA2065	8168 856799	VASILIY BELOV	{"email": "belov.vasiliy28111973@postgrespro.ru", "phone": "+70826880314"}
0005432526099	AA2065	2689 081150	ALEKSANDR POPOV	{"phone": "+70233160522"}
0005432526100	631B42	5023 916509	LIDIYA KULIKOVA	{"email": "kulikovalidiya.031981@postgrespro.ru", "phone": "+70354183489"}
0005432526101	B3301A	5052 924821	LIDIYA ALEKSEEVA	{"phone": "+70002291042"}
0005432526102	16DA56	3538 204390	IVAN TIMOFEEV	{"email": "timofeev_ivan-29031976@postgrespro.ru", "phone": "+70804526369"}
0005432526103	16DA56	7417 673153	ULYANA MAKAROVA	{"email": "makarova_u.13121969@postgrespro.ru", "phone": "+70331665755"}
0005432526104	FF1BC2	5618 189827	ALEKSEY ZHUKOV	{"email": "zhukov-aleksey.111980@postgrespro.ru", "phone": "+70835311384"}
0005432526105	75A7DA	7660 904445	LYUDMILA SOKOLOVA	{"phone": "+70168974768"}
0005432526106	915495	8132 658242	TATYANA KOVALEVA	{"email": "kovalevatatyana_12101970@postgrespro.ru", "phone": "+70851407637"}
0005432526107	9F5052	2521 086590	EDUARD KUZMIN	{"email": "kuzmin.e_111971@postgrespro.ru", "phone": "+70483399924"}
0005432526108	9F5052	4887 073456	NATALYA EGOROVA	{"email": "n_egorova1971@postgrespro.ru", "phone": "+70206115498"}
0005432526109	B80414	7247 137510	NATALYA VOROBEVA	{"phone": "+70882969789"}
0005432526110	AD17C8	9795 398954	GALINA EFREMOVA	{"phone": "+70333052429"}
0005432526111	3EBE66	9489 764048	DENIS GUSEV	{"email": "dgusev.30071967@postgrespro.ru", "phone": "+70152676122"}
0005432526112	3EBE66	2337 275057	DMITRIY NIKITIN	{"phone": "+70268640557"}
0005432526113	893291	3636 876388	NIKOLAY SCHERBAKOV	{"phone": "+70203576167"}
0005432526114	893291	7486 959158	ANDREY EGOROV	{"phone": "+70018566749"}
0005432526115	7A6F0B	6953 708152	ANDREY ZAKHAROV	{"phone": "+70478401672"}
0005432526116	BADFBD	5753 854092	MIKHAIL MOROZOV	{"email": "mikhail_morozov1964@postgrespro.ru", "phone": "+70247982115"}
0005432526117	CA8686	3059 734237	ANATOLIY ANDREEV	{"email": "andreev-anatoliy_091974@postgrespro.ru", "phone": "+70902737634"}
0005432526118	189CAA	8639 098088	ANDREY SCHERBAKOV	{"email": "andrey.scherbakov.021979@postgrespro.ru", "phone": "+70528405187"}
0005432526119	52B09A	9132 274609	OLGA MIKHAYLOVA	{"phone": "+70967657615"}
0005432526120	52B09A	3132 079835	RUSLAN SMIRNOV	{"email": "smirnov_ruslan1963@postgrespro.ru", "phone": "+70258211025"}
0005432526121	0DC78A	1376 729509	YULIYA PETROVA	{"email": "ypetrova_1968@postgrespro.ru", "phone": "+70495358695"}
0005432526122	0DC78A	2903 388785	MARIYA DMITRIEVA	{"email": "dmitrieva.m.061974@postgrespro.ru", "phone": "+70078501636"}
0005432526123	756D4F	8172 595828	DMITRIY GUSEV	{"phone": "+70451285238"}
0005432526124	454053	4148 922502	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy-101973@postgrespro.ru", "phone": "+70520448933"}
0005432526125	ECE5F3	7474 726914	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova-1975@postgrespro.ru", "phone": "+70161849177"}
0005432526126	F2701B	5158 811406	YURIY FROLOV	{"phone": "+70811262474"}
0005432526127	F2701B	5182 171151	LYUDMILA KOROLEVA	{"email": "lyudmilakoroleva.1967@postgrespro.ru", "phone": "+70984079534"}
0005432526128	EA3FB6	5821 996183	LEONID MIRONOV	{"email": "mironov-l011974@postgrespro.ru", "phone": "+70105344868"}
0005432526129	87A89A	9553 552921	VLADISLAV KOZLOV	{"email": "kozlov_v27101980@postgrespro.ru", "phone": "+70396903622"}
0005432526130	E6519C	7383 537918	ANATOLIY ZAYCEV	{"phone": "+70724155754"}
0005432526131	AC6925	1501 909051	ELENA IVANOVA	{"email": "eivanova_21061968@postgrespro.ru", "phone": "+70128780322"}
0005432526132	AC45E8	6613 052352	OLEG VOLKOV	{"email": "o-volkov_1974@postgrespro.ru", "phone": "+70321921283"}
0005432526133	388597	1589 605681	ELENA MEDVEDEVA	{"email": "medvedeva.elena_08111976@postgrespro.ru", "phone": "+70450169694"}
0005432526134	186694	3534 744664	VERA GRISHINA	{"email": "grishinav121972@postgrespro.ru", "phone": "+70086137198"}
0005432526135	2A701C	4151 686881	OKSANA KULIKOVA	{"phone": "+70526985422"}
0005432526136	A7ED5B	2129 336752	KIRILL TARASOV	{"phone": "+70977317956"}
0005432526137	5AC2D1	0951 751963	ALEKSEY ISAEV	{"email": "isaevaleksey_1972@postgrespro.ru", "phone": "+70306672432"}
0005432526138	232930	5331 513553	ELENA TIKHONOVA	{"email": "tikhonovaelena.1970@postgrespro.ru", "phone": "+70762686643"}
0005432526139	6EFEBD	8998 502775	NATALYA ZHURAVLEVA	{"email": "n_zhuravleva.081979@postgrespro.ru", "phone": "+70401015758"}
0005432526140	6EFEBD	3309 319450	MARIYA ARKHIPOVA	{"phone": "+70783534823"}
0005432526141	2DEE7E	8722 419009	OLGA KISELEVA	{"email": "olga-kiseleva-1982@postgrespro.ru", "phone": "+70170204157"}
0005432526142	651B81	6629 911761	SERGEY FILIPPOV	{"phone": "+70592180787"}
0005432526143	927431	3884 033394	DARYA YAKOVLEVA	{"email": "darya.yakovleva1965@postgrespro.ru", "phone": "+70612775235"}
0005432526144	F37C38	4153 209011	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_aleksandr-1971@postgrespro.ru", "phone": "+70402019213"}
0005432526145	DA2DC2	3389 766520	SERGEY SCHERBAKOV	{"phone": "+70374223939"}
0005432526146	DA2DC2	7684 476636	NADEZHDA SMIRNOVA	{"phone": "+70502308140"}
0005432526147	77F902	4871 603030	NADEZHDA EFIMOVA	{"phone": "+70887114877"}
0005432526148	84A035	6094 767390	MAKSIM VASILEV	{"email": "vasilev-m.051966@postgrespro.ru", "phone": "+70316918397"}
0005432526149	357A0D	7477 715759	TATYANA AFANASEVA	{"phone": "+70630332866"}
0005432526150	5918C2	8471 834047	EVGENIY SOKOLOV	{"email": "e-sokolov_111982@postgrespro.ru", "phone": "+70994296770"}
0005432526151	5918C2	9980 644721	ROMAN SOLOVEV	{"phone": "+70332453242"}
0005432526152	AA1F0E	2022 672770	EVDOKIYA IVANOVA	{"email": "e-ivanova.021969@postgrespro.ru", "phone": "+70145259713"}
0005432526153	AA1F0E	9824 193951	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev19111971@postgrespro.ru", "phone": "+70253379316"}
0005432526154	FEB631	9296 659281	KSENIYA KULIKOVA	{"phone": "+70453232974"}
0005432526155	E05ABB	4756 729616	PETR ANDREEV	{"email": "petr_andreev.051968@postgrespro.ru", "phone": "+70980993500"}
0005432526156	D17E9E	2256 490781	DENIS MOISEEV	{"phone": "+70087080945"}
0005432526157	D17E9E	9086 079969	EVGENIY ANTONOV	{"phone": "+70182049666"}
0005432526158	B5F36F	5042 363241	OLESYA KOZLOVA	{"phone": "+70819274937"}
0005432526159	1478DB	3985 629084	TATYANA ROMANOVA	{"phone": "+70400736711"}
0005432526160	3BA9E0	9279 310026	ANATOLIY VOLKOV	{"email": "volkov.a_29011978@postgrespro.ru", "phone": "+70405682118"}
0005432526161	568B37	3719 603583	TALGAT KUZNECOV	{"email": "kuznecovt-1967@postgrespro.ru", "phone": "+70242435244"}
0005432526162	F91623	7559 512729	TATYANA DMITRIEVA	{"phone": "+70566288886"}
0005432526163	F81BBE	8135 093137	FEDOR SERGEEV	{"phone": "+70840100443"}
0005432526164	F81BBE	4951 929927	NADEZHDA NOVIKOVA	{"phone": "+70900603299"}
0005432526165	649587	9520 632742	MARIYA AFANASEVA	{"phone": "+70871670830"}
0005432526166	D298F6	2298 632945	ALINA DANILOVA	{"phone": "+70819837153"}
0005432526167	160F1C	5346 522178	ZHANNA OSIPOVA	{"email": "osipova-z_1977@postgrespro.ru", "phone": "+70029616929"}
0005432526168	049EEC	4720 574673	VIKTOR ILIN	{"phone": "+70318008173"}
0005432526169	E806DA	0770 395552	ALEKSANDR FEDOTOV	{"email": "aleksandrfedotov-041986@postgrespro.ru", "phone": "+70995335230"}
0005432526170	67BA7E	0134 928316	NIKOLAY KULIKOV	{"phone": "+70282343577"}
0005432526171	FC3D1E	2169 397921	SERGEY ZAKHAROV	{"phone": "+70475075811"}
0005432526172	6E895A	2115 104119	IGOR EGOROV	{"email": "egorov-i-1985@postgrespro.ru", "phone": "+70558724468"}
0005432526173	EFC082	9425 259136	RAISA FILATOVA	{"phone": "+70437467196"}
0005432526174	EFC082	0410 806300	SERGEY VOLKOV	{"phone": "+70018421476"}
0005432526175	EFC082	1455 270571	OLGA BOGDANOVA	{"email": "obogdanova.14031966@postgrespro.ru", "phone": "+70043257618"}
0005432526176	5EEEEA	7646 528380	ALEKSANDR GORBUNOV	{"phone": "+70903980747"}
0005432526177	8551E8	3698 013211	ANNA KOROLEVA	{"phone": "+70514391632"}
0005432526178	8551E8	0592 610992	ALEKSEY ILIN	{"email": "ilin_aleksey011977@postgrespro.ru", "phone": "+70730947856"}
0005432526179	4F1021	7807 000026	OKSANA SCHERBAKOVA	{"phone": "+70643594644"}
0005432526180	819873	6034 276267	EVGENIY POPOV	{"phone": "+70941680859"}
0005432526181	819873	9960 692212	ANATOLIY ILIN	{"email": "ailin.23061965@postgrespro.ru", "phone": "+70121035388"}
0005432526182	C00928	6901 014788	ELENA GAVRILOVA	{"email": "gavrilova.elena_15091982@postgrespro.ru", "phone": "+70121357706"}
0005432526183	D6C2B6	3953 895534	ARTEM GORBUNOV	{"phone": "+70893748361"}
0005432526184	AB08F8	4578 870127	ANATOLIY VLASOV	{"email": "anatoliy.vlasov.071969@postgrespro.ru", "phone": "+70615197232"}
0005432526185	1B1D58	1853 784208	EDUARD GUSEV	{"email": "e_gusev-031967@postgrespro.ru", "phone": "+70218087002"}
0005432526186	1B1D58	2818 640249	ANTONINA ANDREEVA	{"email": "andreevaantonina_06051978@postgrespro.ru", "phone": "+70188353945"}
0005432526187	450698	4088 423846	ALEKSEY NIKITIN	{"email": "anikitin091984@postgrespro.ru", "phone": "+70239011746"}
0005432526188	450698	4471 194963	TATYANA ALEKSEEVA	{"email": "alekseeva.t.1974@postgrespro.ru", "phone": "+70911754734"}
0005432526189	7BBB6B	1632 736792	FEDOR KONOVALOV	{"phone": "+70323180150"}
0005432526190	E3B2DB	4887 567574	GENNADIY ORLOV	{"email": "gennadiy_orlov_28021970@postgrespro.ru", "phone": "+70411661548"}
0005432526191	DF9744	5847 390639	VLADIMIR SOROKIN	{"email": "sorokin-v_021981@postgrespro.ru", "phone": "+70125168826"}
0005432526192	0421D0	4683 752326	VLADIMIR MIRONOV	{"email": "v-mironov1959@postgrespro.ru", "phone": "+70279457652"}
0005432526193	63FE76	8081 345753	LIDIYA PETROVA	{"email": "l-petrova-081982@postgrespro.ru", "phone": "+70791667552"}
0005432526194	D23F8B	4682 381464	NATALYA KUZMINA	{"email": "kuzmina_n-07111969@postgrespro.ru", "phone": "+70102467889"}
0005432526195	267645	2058 662074	NIKOLAY SOLOVEV	{"phone": "+70854447894"}
0005432526196	267645	6745 015180	ALEKSANDR PETROV	{"phone": "+70290627835"}
0005432526197	3397E4	4149 009032	LYUBOV KOLESNIKOVA	{"phone": "+70299854942"}
0005432526198	B466BF	4198 749716	VIKTORIYA MELNIKOVA	{"email": "vmelnikova.1976@postgrespro.ru", "phone": "+70846938817"}
0005432526199	CCDF37	8891 864600	VALERIY MIKHAYLOV	{"email": "mikhaylovvaleriy-1975@postgrespro.ru", "phone": "+70875331414"}
0005432526200	9FB263	7406 236392	DANIIL MARTYNOV	{"phone": "+70426924737"}
0005432526201	53AB7D	6132 045877	SVETLANA MOROZOVA	{"email": "morozova.svetlana.1962@postgrespro.ru", "phone": "+70512900937"}
0005432526202	53AB7D	5013 045022	VITALIY POPOV	{"email": "popov_vitaliy-041983@postgrespro.ru", "phone": "+70376327439"}
0005432526203	E4F083	7211 265328	EVGENIY YAKOVLEV	{"email": "yakovlev.evgeniy1972@postgrespro.ru", "phone": "+70650402247"}
0005432526204	A18670	0448 593855	NATALYA IVANOVA	{"phone": "+70852838614"}
0005432526205	2F5588	9337 239409	ANTONINA TIKHONOVA	{"email": "tikhonovaantonina_01011974@postgrespro.ru", "phone": "+70801370047"}
0005432526206	2F5588	9038 519074	EKATERINA PAVLOVA	{"email": "pavlovae-081982@postgrespro.ru", "phone": "+70927663806"}
0005432526207	2F5588	6171 914561	ALEKSEY SERGEEV	{"phone": "+70856513010"}
0005432526208	97F5A4	1442 258550	LARISA VLASOVA	{"email": "l-vlasova.18091968@postgrespro.ru", "phone": "+70199319753"}
0005432526209	298242	5388 297750	ILYA VASILEV	{"email": "i.vasilev.1979@postgrespro.ru", "phone": "+70730708932"}
0005432526210	E35A42	0890 234256	EKATERINA PETROVA	{"email": "ekaterina_petrova061969@postgrespro.ru", "phone": "+70326880725"}
0005432526211	E35A42	8169 468002	ELENA NOVIKOVA	{"email": "novikova-e_101985@postgrespro.ru", "phone": "+70558210084"}
0005432526212	49E83C	0113 850121	RINAT ILIN	{"email": "ilinrinat_1982@postgrespro.ru", "phone": "+70763863326"}
0005432526213	3B9A54	5779 464347	TATYANA SMIRNOVA	{"phone": "+70645083111"}
0005432526214	CA6E8E	7474 975451	VALERIY IVANOV	{"email": "valeriyivanov.1982@postgrespro.ru", "phone": "+70586993303"}
0005432526215	362D5F	8913 939025	FLYURA RODIONOVA	{"email": "rodionova_flyura-101962@postgrespro.ru", "phone": "+70437680037"}
0005432526216	F401E6	9718 556387	ALEKSANDR ABRAMOV	{"phone": "+70804986093"}
0005432526217	641B20	6677 321191	NATALYA MAKSIMOVA	{"email": "maksimova.natalya_10011978@postgrespro.ru", "phone": "+70849451982"}
0005432526218	641B20	9442 667119	VERA KALININA	{"email": "kalinina-v_111976@postgrespro.ru", "phone": "+70391182605"}
0005432526219	6DFC1C	1538 018522	DIANA EGOROVA	{"email": "degorova_081973@postgrespro.ru", "phone": "+70067497774"}
0005432526220	5E1F68	6168 447097	LILIYA ANTONOVA	{"email": "antonovaliliya.22121962@postgrespro.ru", "phone": "+70505156965"}
0005432526221	BCDA1A	4970 780405	DENIS NIKOLAEV	{"email": "d-nikolaev1968@postgrespro.ru", "phone": "+70623227498"}
0005432526222	BCDA1A	8827 601381	LYUBOV KISELEVA	{"phone": "+70988680078"}
0005432526223	2E8913	8384 805683	ELENA BOGDANOVA	{"phone": "+70010307179"}
0005432526224	0E7F22	8988 039218	GRIGORIY KISELEV	{"email": "kiselev-g-1973@postgrespro.ru", "phone": "+70952412309"}
0005432526225	FE2AF9	3990 689499	LYUBOV SCHERBAKOVA	{"email": "scherbakova_lyubov_111959@postgrespro.ru", "phone": "+70484254200"}
0005432526226	8769E7	3202 050660	ARTEM ALEKSANDROV	{"phone": "+70152037866"}
0005432526227	AEA69E	5522 649925	VERA PETROVA	{"phone": "+70487715969"}
0005432526228	79525A	5252 213161	NIKITA ZAKHAROV	{"email": "zakharovn-1974@postgrespro.ru", "phone": "+70867770100"}
0005432526229	09884F	8529 965243	LIDIYA BARANOVA	{"email": "baranova-l_031972@postgrespro.ru", "phone": "+70838587178"}
0005432526230	09884F	2809 463688	NINA TITOVA	{"email": "nina_titova-1982@postgrespro.ru", "phone": "+70345492011"}
0005432526231	045313	1583 015239	NIKITA ISAEV	{"phone": "+70498739034"}
0005432526232	97D506	0150 013934	ANTONINA NIKITINA	{"email": "antonina-nikitina.111987@postgrespro.ru", "phone": "+70462413835"}
0005432526234	6C0000	2940 167672	OLEG IVANOV	{"email": "o-ivanov_021975@postgrespro.ru", "phone": "+70157274111"}
0005432526235	40FAC4	8318 251067	VLADIMIR BONDARENKO	{"email": "bondarenko_v_091980@postgrespro.ru", "phone": "+70731367255"}
0005432526236	36A8A4	7749 939118	SERGEY ROMANOV	{"phone": "+70955101531"}
0005432526237	159544	7204 568578	ANDREY IVANOV	{"phone": "+70437099727"}
0005432526238	EAD467	7849 974078	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov_1954@postgrespro.ru", "phone": "+70415098153"}
0005432526239	872030	7600 894728	ANASTASIYA KOROLEVA	{"phone": "+70228931293"}
0005432526240	872030	2895 349561	NINA MAKAROVA	{"email": "makarova_nina-23061962@postgrespro.ru", "phone": "+70734326719"}
0005432526241	872030	5155 061466	LYUBOV AKIMOVA	{"phone": "+70989746126"}
0005432526242	F940EC	5113 948703	GALINA NESTEROVA	{"email": "g.nesterova_1979@postgrespro.ru", "phone": "+70753747393"}
0005432526243	E30D41	8534 973923	EVGENIY AFANASEV	{"email": "evgeniyafanasev071971@postgrespro.ru", "phone": "+70548303887"}
0005432526244	299B7A	4173 188488	MAKSIM NAUMOV	{"phone": "+70501839823"}
0005432526245	EC7CD0	5717 457938	KSENIYA ERMAKOVA	{"email": "ermakovak_1960@postgrespro.ru", "phone": "+70624006647"}
0005432526246	5D0CF6	3481 670551	RUFIYA ZAKHAROVA	{"phone": "+70119820110"}
0005432526247	D2997A	5855 063786	VLADIMIR MIRONOV	{"email": "mironov.vladimir_051967@postgrespro.ru", "phone": "+70968898658"}
0005432526248	E864AD	7710 883268	ALEKSANDR VOROBEV	{"email": "a_vorobev031981@postgrespro.ru", "phone": "+70565975483"}
0005432526249	74E18E	9931 792518	IVAN RODIONOV	{"phone": "+70203990078"}
0005432526250	74E18E	3142 086972	ANNA ZAYCEVA	{"email": "zayceva_anna-20121962@postgrespro.ru", "phone": "+70302569226"}
0005432526251	D40A32	2368 049736	ALEKSANDR POPOV	{"phone": "+70208954738"}
0005432526252	22322A	4526 343784	OLEG MOISEEV	{"phone": "+70183958071"}
0005432526253	22322A	2270 929028	VALERIY POPOV	{"email": "valeriy_popov-111972@postgrespro.ru", "phone": "+70381532001"}
0005432526254	1DFE60	9895 028065	VLADIMIR BORISOV	{"email": "vladimir_borisov_1982@postgrespro.ru", "phone": "+70974694459"}
0005432526255	1DFE60	0229 003742	VALERIY MAKAROV	{"phone": "+70777742008"}
0005432526256	5DBFCE	5684 564216	INNA SCHERBAKOVA	{"email": "scherbakova_inna-13121966@postgrespro.ru", "phone": "+70844990241"}
0005432526257	F13B3D	4124 443361	YULIYA PETROVA	{"phone": "+70570231171"}
0005432526258	EEF237	3968 054358	VERA KARPOVA	{"email": "vera-karpova_061974@postgrespro.ru", "phone": "+70888701536"}
0005432526259	448CBB	2558 626663	ANASTASIYA SERGEEVA	{"phone": "+70577762906"}
0005432526260	0E4446	8612 761362	MARIYA MIKHAYLOVA	{"email": "m.mikhaylova_09071972@postgrespro.ru", "phone": "+70578638638"}
0005432526261	751D1A	5482 447036	VARVARA LUKYANOVA	{"email": "lukyanovavarvara-1979@postgrespro.ru", "phone": "+70790611814"}
0005432526262	3C999F	9875 486621	ZOYA KARPOVA	{"email": "karpova_zoya_091968@postgrespro.ru", "phone": "+70319628465"}
0005432526263	3C999F	0497 656797	IREK IVANOV	{"email": "i-ivanov15061964@postgrespro.ru", "phone": "+70107996803"}
0005432526264	40AAAB	4733 315225	TAMARA TARASOVA	{"email": "tarasova-tamara.041966@postgrespro.ru", "phone": "+70325931554"}
0005432526265	3CD0F3	5202 252376	SOFYA KUZMINA	{"email": "kuzminas-29051975@postgrespro.ru", "phone": "+70201998235"}
0005432526266	54EEED	4070 279405	YULIYA NIKOLAEVA	{"email": "yuliyanikolaeva-23011968@postgrespro.ru", "phone": "+70807225141"}
0005432526267	E7C90E	5083 803989	YURIY KRASNOV	{"email": "yuriy-krasnov03071975@postgrespro.ru", "phone": "+70286864032"}
0005432526268	5F3292	1443 651235	RINAT PETROV	{"email": "rpetrov021972@postgrespro.ru", "phone": "+70610469293"}
0005432526269	5F3292	4474 016455	ALENA MIKHAYLOVA	{"phone": "+70076603268"}
0005432526270	C3C162	7718 580736	ALEKSEY VLASOV	{"email": "vlasov_aleksey_21021968@postgrespro.ru", "phone": "+70716154671"}
0005432526271	65B91D	9740 470002	NADEZHDA EGOROVA	{"email": "egorovan01031977@postgrespro.ru", "phone": "+70828168392"}
0005432526272	65B91D	2279 145889	NINA ALEKSEEVA	{"email": "alekseeva-nina.051982@postgrespro.ru", "phone": "+70371769427"}
0005432526273	1C56CA	0975 092194	GALINA MEDVEDEVA	{"email": "g_medvedeva-041975@postgrespro.ru", "phone": "+70114461635"}
0005432526274	2DE034	5314 103192	ELENA VOROBEVA	{"email": "e_vorobeva26041990@postgrespro.ru", "phone": "+70341147875"}
0005432526275	2DE034	3197 720859	NAILYA KARPOVA	{"phone": "+70801423660"}
0005432526276	7A22BA	5938 721214	VALENTINA BORISOVA	{"phone": "+70339135164"}
0005432526277	9C56F2	5622 687073	TAMARA SMIRNOVA	{"phone": "+70941891776"}
0005432526278	F0F525	5711 274818	ALEKSANDR VASILEV	{"phone": "+70142191335"}
0005432526279	F0F525	9708 999027	MIKHAIL SCHERBAKOV	{"email": "scherbakovm_15011972@postgrespro.ru", "phone": "+70407854137"}
0005432526280	F0F525	2729 128339	ALBINA KARPOVA	{"phone": "+70137421408"}
0005432526281	C33342	8558 824326	ALEKSEY ALEKSEEV	{"phone": "+70128200707"}
0005432526282	C33342	9361 321163	ELENA KARPOVA	{"email": "elenakarpova-1973@postgrespro.ru", "phone": "+70561138451"}
0005432526283	9F3A78	6287 143914	VLADIMIR KAZAKOV	{"phone": "+70288697252"}
0005432526284	F86CE9	3238 709273	EVA AKIMOVA	{"phone": "+70659412467"}
0005432526285	493159	4215 891193	YURIY MIKHAYLOV	{"phone": "+70644128202"}
0005432526286	4AACF3	9809 734523	ALEKSANDR ZHUKOV	{"email": "zhukova121956@postgrespro.ru", "phone": "+70102463751"}
0005432526287	EBF4F5	5637 640378	FEDOR MAKSIMOV	{"phone": "+70706310594"}
0005432526288	005FBD	8619 652505	ANZHELIKA PETROVA	{"email": "a.petrova.1981@postgrespro.ru", "phone": "+70547924800"}
0005432526289	0476C7	0517 623309	ALEKSEY TIKHONOV	{"email": "a-tikhonov-07111974@postgrespro.ru", "phone": "+70999836015"}
0005432526290	588F66	3478 013004	KSENIYA ROMANOVA	{"phone": "+70110417311"}
0005432526291	2493BC	9585 010163	NATALYA ZHUKOVA	{"phone": "+70657212417"}
0005432526292	CF0BCC	7314 355375	EKATERINA SMIRNOVA	{"email": "smirnovae_041971@postgrespro.ru", "phone": "+70071928060"}
0005432526293	BE145B	0697 636521	SERGEY POPOV	{"phone": "+70454939539"}
0005432526294	E88531	3683 073084	VERA MATVEEVA	{"phone": "+70732380202"}
0005432526295	AF167F	1858 047561	SERGEY SOROKIN	{"email": "sergey.sorokin.041977@postgrespro.ru", "phone": "+70397391602"}
0005432526296	FCA97B	8614 473843	VALERIY SERGEEV	{"email": "sergeev_valeriy16041975@postgrespro.ru", "phone": "+70164064070"}
0005432526297	8276CF	0410 931696	LYUDMILA ARKHIPOVA	{"email": "arkhipova_lyudmila_1970@postgrespro.ru", "phone": "+70188772394"}
0005432526298	AC766A	5715 534588	FEDOR ORLOV	{"email": "fedor.orlov_14061968@postgrespro.ru", "phone": "+70399398649"}
0005432526299	AC766A	6306 099876	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir031975@postgrespro.ru", "phone": "+70059437924"}
0005432526300	0BE72D	5721 582959	ALEKSANDR FROLOV	{"email": "aleksandr-frolov121976@postgrespro.ru", "phone": "+70013745629"}
0005432526301	0BE72D	7900 955017	VLADIMIR VASILEV	{"email": "vladimirvasilev12031975@postgrespro.ru", "phone": "+70328334229"}
0005432526302	CF7422	4152 510924	VALENTINA LOGINOVA	{"phone": "+70937664032"}
0005432526303	CF7422	6915 291580	TATYANA SOKOLOVA	{"email": "sokolova_tatyana-101985@postgrespro.ru", "phone": "+70727624844"}
0005432526304	CF7422	1123 341648	NATALIYA RYABOVA	{"phone": "+70030026489"}
0005432526305	A82C96	9137 219363	ANDREY EGOROV	{"email": "egorov.andrey.111978@postgrespro.ru", "phone": "+70878927109"}
0005432526306	A82C96	0646 700997	EVGENIY KARPOV	{"phone": "+70418504273"}
0005432526307	D372AA	0633 388895	TATYANA NAUMOVA	{"phone": "+70168453991"}
0005432526308	31EC4A	4081 083979	NATALYA MELNIKOVA	{"email": "nmelnikova021974@postgrespro.ru", "phone": "+70535260899"}
0005432526309	A80D10	6997 029130	RASIM TIKHONOV	{"phone": "+70733967290"}
0005432526310	81BA55	9165 278006	ELENA SOROKINA	{"email": "sorokinae-18011960@postgrespro.ru", "phone": "+70914899632"}
0005432526311	81BA55	5032 740844	RINAT VOROBEV	{"email": "r_vorobev_1972@postgrespro.ru", "phone": "+70788391276"}
0005432526312	704702	7966 205675	VLADIMIR KRASNOV	{"email": "krasnov-v-111975@postgrespro.ru", "phone": "+70287092830"}
0005432526313	4B330E	0565 013012	ANNA GAVRILOVA	{"phone": "+70160225742"}
0005432526314	F7BA0E	6512 112550	MILANA PAVLOVA	{"email": "milanapavlova1970@postgrespro.ru", "phone": "+70807348944"}
0005432526315	67E976	3880 433337	YURIY VASILEV	{"email": "y_vasilev.1964@postgrespro.ru", "phone": "+70117603803"}
0005432526316	B8B3B4	0587 379187	ANDREY ILIN	{"email": "andrey.ilin-101971@postgrespro.ru", "phone": "+70723875370"}
0005432526317	CE2BAD	4659 478459	LARISA BORISOVA	{"phone": "+70093452921"}
0005432526318	C2A201	2330 850505	ALFIYA KUZNECOVA	{"email": "kuznecovaa_1980@postgrespro.ru", "phone": "+70982176420"}
0005432526319	20E5C4	2361 022920	STANISLAV NAUMOV	{"phone": "+70784838684"}
0005432526320	20E5C4	7739 215670	ANASTASIYA SOROKINA	{"phone": "+70841533654"}
0005432526321	D74D8C	6260 405059	TATYANA YUDINA	{"phone": "+70215063295"}
0005432526322	495556	6719 067641	PAVEL FOMIN	{"phone": "+70830658929"}
0005432526323	495556	5703 567901	NINA KAZAKOVA	{"phone": "+70792958876"}
0005432526324	9B831D	7400 382222	ILYA GRIGOREV	{"email": "grigorev.i.30071973@postgrespro.ru", "phone": "+70754089761"}
0005432526325	9B831D	5910 603690	VALENTINA ZAYCEVA	{"email": "valentina-zayceva.29051970@postgrespro.ru", "phone": "+70401562371"}
0005432526326	971959	2644 763957	YURIY PETROV	{"email": "petrovyuriy-03081970@postgrespro.ru", "phone": "+70942236605"}
0005432526327	C4DCBE	7951 296268	SERGEY SAVELEV	{"phone": "+70684550909"}
0005432526328	C4DCBE	7455 932830	NATALIYA NOVIKOVA	{"email": "n_novikova.1977@postgrespro.ru", "phone": "+70394081171"}
0005432526329	3F3750	3897 610748	TATYANA SOKOLOVA	{"phone": "+70082516864"}
0005432526330	0295D2	7954 075652	VALERIY MIKHAYLOV	{"email": "mikhaylov-valeriy.1982@postgrespro.ru", "phone": "+70035690916"}
0005432526331	DC5F94	8032 246484	KRISTINA NIKITINA	{"phone": "+70923436389"}
0005432526332	572609	2349 251214	VLADIMIR KUZNECOV	{"phone": "+70683739900"}
0005432526333	572609	8283 182277	GALINA KOROLEVA	{"phone": "+70040387008"}
0005432526334	572609	6956 471574	VIKTOR KAZAKOV	{"email": "kazakov.viktor_1977@postgrespro.ru", "phone": "+70664417115"}
0005432526335	C6BF6A	1579 678965	NATALYA POTAPOVA	{"email": "npotapova_13011974@postgrespro.ru", "phone": "+70641510166"}
0005432526336	F43ADB	8653 179405	TIGRAN VASILEV	{"phone": "+70608803527"}
0005432526337	84CCCB	7282 492319	ERIK KUZNECOV	{"email": "ekuznecov.021974@postgrespro.ru", "phone": "+70380233903"}
0005432526338	84CCCB	9486 039466	DANILA KOZLOV	{"email": "dkozlov.031975@postgrespro.ru", "phone": "+70446207573"}
0005432526339	866C83	5128 924439	GALINA MIRONOVA	{"email": "mironova_g.1972@postgrespro.ru", "phone": "+70190250711"}
0005432526340	D50C84	4473 464858	ALEKSEY ZAKHAROV	{"email": "zakharov_a-19021968@postgrespro.ru", "phone": "+70511406125"}
0005432526341	D50C84	0292 821616	ELENA ZOTOVA	{"email": "elena.zotova1973@postgrespro.ru", "phone": "+70304123488"}
0005432526509	6060F8	3487 633234	ALEKSANDR AFANASEV	{"phone": "+70327286322"}
0005432526342	343B0A	2056 166825	NIKOLAY ANDREEV	{"email": "andreev_nikolay-29061962@postgrespro.ru", "phone": "+70981218184"}
0005432526737	72B261	2142 283649	ELENA VLASOVA	{"phone": "+70576787376"}
0005432526343	B8B0AB	1186 685726	ALEKSEY MOROZOV	{"email": "morozov.a31081977@postgrespro.ru", "phone": "+70659947570"}
0005432526344	B8B0AB	4595 185179	NATALYA FOMINA	{"email": "fomina.natalya_29051974@postgrespro.ru", "phone": "+70977861407"}
0005432526345	B8B0AB	5279 682605	KONSTANTIN ZAYCEV	{"phone": "+70567965034"}
0005432526346	03266B	8686 253722	ALENA MOISEEVA	{"phone": "+70011033055"}
0005432526347	3DE9A1	0727 587213	NIKOLAY ANTONOV	{"phone": "+70643211080"}
0005432526348	D83DA7	1121 656343	ALEKSANDR KULIKOV	{"phone": "+70125455364"}
0005432526349	26A3C9	2540 692290	ANDREY MEDVEDEV	{"email": "medvedev_a.071979@postgrespro.ru", "phone": "+70826103380"}
0005432526350	9127B6	3616 239334	DENIS GRIGOREV	{"phone": "+70695658892"}
0005432526351	36CA3D	4235 601560	OLGA BOGDANOVA	{"phone": "+70904781056"}
0005432526352	B7A103	9506 543659	NADEZHDA ARKHIPOVA	{"phone": "+70959132841"}
0005432526353	FFD9E7	1890 482069	OLGA KUZNECOVA	{"email": "kuznecova_o-1964@postgrespro.ru", "phone": "+70801839010"}
0005432526354	FFD9E7	7532 882014	NATALYA SCHERBAKOVA	{"email": "n-scherbakova_23101974@postgrespro.ru", "phone": "+70443939661"}
0005432526355	868CA4	3639 775554	ALEKSANDR MATVEEV	{"phone": "+70587631816"}
0005432526356	B29BBE	8257 722427	VLADIMIR MATVEEV	{"email": "matveev_vladimir1964@postgrespro.ru", "phone": "+70621766352"}
0005432526357	B29BBE	6174 956948	ALEKSANDRA SERGEEVA	{"phone": "+70779018100"}
0005432526358	AEACDA	6731 870233	GALINA MAKAROVA	{"email": "gmakarova.14101968@postgrespro.ru", "phone": "+70696256517"}
0005432526359	AEACDA	3657 676242	ROMAN YAKOVLEV	{"email": "yakovlev.r_121969@postgrespro.ru", "phone": "+70250662771"}
0005432526360	88CB3F	5514 521410	DMITRIY SMIRNOV	{"phone": "+70272908477"}
0005432526361	88CB3F	8087 633711	VSEVOLOD FROLOV	{"email": "vsevolod_frolov.091969@postgrespro.ru", "phone": "+70206290250"}
0005432526362	88CB3F	3788 130491	NATALYA EGOROVA	{"email": "n.egorova-1963@postgrespro.ru", "phone": "+70600651892"}
0005432526363	B78D1D	7260 138700	VASILISA KOLESNIKOVA	{"phone": "+70930250250"}
0005432526364	B78D1D	0982 712565	ANATOLIY ILIN	{"phone": "+70887364012"}
0005432526365	BFB0F6	3663 346655	YULIYA KUZMINA	{"phone": "+70095559172"}
0005432526366	BFB0F6	4751 046886	SERGEY FILIPPOV	{"email": "filippov_s1982@postgrespro.ru", "phone": "+70995336056"}
0005432526367	D3E08A	3973 199217	OKSANA ERMAKOVA	{"email": "ermakovao.1973@postgrespro.ru", "phone": "+70487195166"}
0005432526368	F049C4	4330 679986	EVGENIY DAVYDOV	{"email": "e_davydov1966@postgrespro.ru", "phone": "+70918258033"}
0005432526369	41C69D	9733 520278	ALEKSANDR KOZLOV	{"email": "kozlov-a.1960@postgrespro.ru", "phone": "+70703244301"}
0005432526370	424CD9	1418 970063	ELENA GAVRILOVA	{"phone": "+70538446428"}
0005432526371	107827	3907 089223	NADEZHDA AKIMOVA	{"email": "akimova-nadezhda051968@postgrespro.ru", "phone": "+70103436813"}
0005432526372	62B75C	1909 406659	RUSTAM YAKOVLEV	{"email": "ryakovlev-30061968@postgrespro.ru", "phone": "+70241042925"}
0005432526373	7913C8	8470 597933	VALENTINA ANTONOVA	{"email": "valentina_antonova_10031977@postgrespro.ru", "phone": "+70208710939"}
0005432526374	A44C29	7173 771313	SERAFIM KRASNOV	{"email": "krasnov.s-041980@postgrespro.ru", "phone": "+70741946933"}
0005432526375	F8ED7C	4890 640899	ALEKSANDR PETROV	{"phone": "+70687594952"}
0005432526376	F8ED7C	5190 813807	PETR BELOV	{"email": "p-belov_03051975@postgrespro.ru", "phone": "+70177312126"}
0005432526377	AA6960	4667 826251	ALEKSANDR KOZLOV	{"phone": "+70013907870"}
0005432526378	1BE753	5409 530478	OLGA NAUMOVA	{"email": "olga_naumova081986@postgrespro.ru", "phone": "+70940986447"}
0005432526379	1BE753	3922 651257	ZOYA KONOVALOVA	{"email": "konovalova.z_12081967@postgrespro.ru", "phone": "+70268853317"}
0005432526380	7F6383	4126 194660	NIKOLAY ANTONOV	{"phone": "+70489068792"}
0005432526381	7F6383	2748 569999	DENIS ISAEV	{"email": "d.isaev-081974@postgrespro.ru", "phone": "+70195337942"}
0005432526382	8D5D02	4340 192963	IVAN KOZLOV	{"email": "kozlov_ivan1977@postgrespro.ru", "phone": "+70773746480"}
0005432526383	8D5D02	6268 261246	ANDREY ORLOV	{"phone": "+70987584838"}
0005432526384	B23C17	1558 377333	OLGA KUZNECOVA	{"phone": "+70472667044"}
0005432526385	B23C17	9549 978259	LYUBOV SAVELEVA	{"email": "lyubov-saveleva13071976@postgrespro.ru", "phone": "+70927096317"}
0005432526386	BD6981	9740 692287	EKATERINA SIDOROVA	{"phone": "+70409194709"}
0005432526387	816184	6973 795504	RIMMA DENISOVA	{"email": "rimma_denisova.1970@postgrespro.ru", "phone": "+70739983048"}
0005432526388	816184	0888 833326	NATALYA SEMENOVA	{"phone": "+70766666748"}
0005432526389	DB01E6	0908 923453	GALINA POPOVA	{"email": "galina-popova081979@postgrespro.ru", "phone": "+70875232717"}
0005432526390	3D89AB	8698 312917	KIRA KONOVALOVA	{"phone": "+70860457566"}
0005432526391	1385B6	1413 757133	VLADIMIR POPOV	{"phone": "+70673976608"}
0005432526392	EEE407	1204 667307	EGOR EGOROV	{"email": "egorov_e_19121985@postgrespro.ru", "phone": "+70217085903"}
0005432526393	EEE407	1670 999587	MARIYA TIKHONOVA	{"phone": "+70090841220"}
0005432526394	0C0B7F	3690 692858	ANDREY KISELEV	{"email": "kiselev_andrey_07081968@postgrespro.ru", "phone": "+70141142371"}
0005432526395	499AFC	3939 138487	VERA SERGEEVA	{"phone": "+70110321838"}
0005432526396	7D79ED	3721 963468	ALEKSANDR GRIGOREV	{"phone": "+70445365066"}
0005432526397	531A92	7023 412331	TATYANA SEMENOVA	{"phone": "+70461110426"}
0005432526398	A270B5	3482 213370	SVETLANA GAVRILOVA	{"email": "svetlana_gavrilova-07061970@postgrespro.ru", "phone": "+70818039168"}
0005432526399	E5B7B4	6681 747868	IGOR IVANOV	{"email": "igor.ivanov-031973@postgrespro.ru", "phone": "+70334208992"}
0005432526400	034FE2	1372 548883	LYUDMILA NIKIFOROVA	{"phone": "+70029531278"}
0005432526401	B4BC23	3946 820398	LYUBOV MASLOVA	{"email": "lmaslova-111972@postgrespro.ru", "phone": "+70393334536"}
0005432526402	B4BC23	9245 850869	NADEZHDA KONOVALOVA	{"email": "konovalova.n.1971@postgrespro.ru", "phone": "+70814623185"}
0005432526403	A257DE	9177 890682	PAVEL ORLOV	{"email": "orlov-pavel_19061980@postgrespro.ru", "phone": "+70886769825"}
0005432526404	5A61CB	4732 709650	POLINA KOMAROVA	{"email": "komarova.p1974@postgrespro.ru", "phone": "+70789593833"}
0005432526405	02BB2B	3217 993731	TATYANA KRASNOVA	{"email": "krasnova-t.111970@postgrespro.ru", "phone": "+70179084688"}
0005432526406	5C6FFB	4650 361144	GENNADIY NIKOLAEV	{"phone": "+70556901184"}
0005432526407	DD658F	6877 351931	ARTEM SHEVCHENKO	{"phone": "+70851412794"}
0005432526408	A58CD5	1585 687773	VIKTOR MIKHAYLOV	{"phone": "+70241246238"}
0005432526409	A58CD5	1913 885613	SERGEY ZAKHAROV	{"phone": "+70233492840"}
0005432526410	B93905	7319 922830	VIKTOR DAVYDOV	{"email": "v-davydov-02011966@postgrespro.ru", "phone": "+70791843912"}
0005432526411	CED3F4	9879 465632	VIKTOR MOROZOV	{"email": "viktor_morozov-17021972@postgrespro.ru", "phone": "+70916280447"}
0005432526412	A24BA0	0412 225978	ELENA PAVLOVA	{"email": "elena-pavlova.101979@postgrespro.ru", "phone": "+70497036002"}
0005432526413	8427F0	5560 979555	GALINA POPOVA	{"email": "galina.popova.20061977@postgrespro.ru", "phone": "+70995588159"}
0005432526414	A8A876	1504 436009	GUZEL POPOVA	{"phone": "+70800653163"}
0005432526415	828271	7191 854994	ELENA EFIMOVA	{"phone": "+70921796964"}
0005432526416	828271	4094 755587	VERA DAVYDOVA	{"email": "davydovav_23091960@postgrespro.ru", "phone": "+70940299865"}
0005432526417	4A410A	9799 920104	OLGA KUZNECOVA	{"email": "o_kuznecova_101970@postgrespro.ru", "phone": "+70424861715"}
0005432526418	534C92	3880 002070	ELENA KOROLEVA	{"email": "e-koroleva-091975@postgrespro.ru", "phone": "+70598333222"}
0005432526419	192351	5500 765781	YURIY SCHERBAKOV	{"email": "yuriy.scherbakov_071978@postgrespro.ru", "phone": "+70788930113"}
0005432526420	97081A	0700 536383	GULFIYA MALYSHEVA	{"phone": "+70944038026"}
0005432526421	97081A	9778 925368	ALEKSANDR SOROKIN	{"email": "a-sorokin.081973@postgrespro.ru", "phone": "+70868197087"}
0005432526422	4B1B9C	1816 247327	VLADIMIR MOROZOV	{"phone": "+70134553505"}
0005432526423	4B1B9C	7793 662300	IGOR ANDREEV	{"phone": "+70019944036"}
0005432526424	C87EF5	8188 332914	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova.anastasiya_111966@postgrespro.ru", "phone": "+70927790572"}
0005432526425	432FA8	5867 614602	NATALYA CHERNOVA	{"email": "n-chernova061966@postgrespro.ru", "phone": "+70625432154"}
0005432526426	A8E28F	4795 560870	ISLAM SHEVCHENKO	{"phone": "+70588264120"}
0005432526427	E683AC	5153 833455	ALEKSANDR MOROZOV	{"phone": "+70252100771"}
0005432526428	E683AC	8626 664202	DAMIR IVANOV	{"email": "ivanov-d-16041969@postgrespro.ru", "phone": "+70444413729"}
0005432526429	027F5E	4541 796055	VALENTINA DENISOVA	{"phone": "+70092897050"}
0005432526430	027F5E	7512 472452	EKATERINA KISELEVA	{"email": "kiseleva-e-031977@postgrespro.ru", "phone": "+70809393529"}
0005432526431	93BFDA	6302 401227	IRINA PETROVA	{"email": "ipetrova.021979@postgrespro.ru", "phone": "+70856865091"}
0005432526432	B6FE45	7490 042497	ALEKSANDR NAUMOV	{"email": "naumov.a_1963@postgrespro.ru", "phone": "+70129347377"}
0005432526433	B6FE45	2553 156637	MIKHAIL VASILEV	{"email": "vasilev_mikhail021983@postgrespro.ru", "phone": "+70370662616"}
0005432526915	64C930	5687 105170	VLADIMIR NAZAROV	{"phone": "+70174383558"}
0005432526434	B6FE45	1335 889814	SERGEY ORLOV	{"email": "orlov_s011982@postgrespro.ru", "phone": "+70536324211"}
0005432526435	F9FB54	3971 659733	ALEKSANDR KUZNECOV	{"phone": "+70027227979"}
0005432526436	C2CFAE	4339 732521	IRINA PETROVA	{"email": "petrova_irina-061976@postgrespro.ru", "phone": "+70107593147"}
0005432526437	E49668	5399 921763	OLGA ZAYCEVA	{"email": "zayceva_o081984@postgrespro.ru", "phone": "+70007048425"}
0005432526438	E78E52	0111 250468	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov_13101988@postgrespro.ru", "phone": "+70810768019"}
0005432526439	E78E52	3208 236859	STANISLAV DMITRIEV	{"email": "dmitriev-s_16111967@postgrespro.ru", "phone": "+70546362199"}
0005432526440	E78E52	8652 278172	OLGA ALEKSEEVA	{"email": "alekseevaolga-1982@postgrespro.ru", "phone": "+70468431808"}
0005432526441	36EDC5	5001 978373	ZOYA VASILEVA	{"phone": "+70656423150"}
0005432526442	36EDC5	9319 341971	DMITRIY VLASOV	{"email": "vlasov.dmitriy_31101968@postgrespro.ru", "phone": "+70941944234"}
0005432526443	DB8946	8747 014817	ALEKSANDR ZHUKOV	{"email": "zhukov_aleksandr05111965@postgrespro.ru", "phone": "+70751810476"}
0005432526444	EF2815	6654 966892	OLEG MELNIKOV	{"email": "omelnikov_051978@postgrespro.ru", "phone": "+70032882415"}
0005432526445	798880	2754 758584	IVAN ORLOV	{"phone": "+70881807109"}
0005432526446	A56C6E	5927 419770	YURIY ANDREEV	{"email": "y-andreev_02121972@postgrespro.ru", "phone": "+70512860109"}
0005432526447	A56C6E	1606 637346	ALEKSANDR IVANOV	{"email": "ivanova-02031972@postgrespro.ru", "phone": "+70865138467"}
0005432526448	18FECE	4300 371993	VYACHESLAV EGOROV	{"phone": "+70434625691"}
0005432526449	E815C4	5210 688177	OLEG NAUMOV	{"email": "naumov-o_1980@postgrespro.ru", "phone": "+70989069006"}
0005432526450	E815C4	3163 105663	LYUDMILA KOMAROVA	{"email": "komarova_l_011974@postgrespro.ru", "phone": "+70314938823"}
0005432526451	4F1500	2713 751420	VALENTINA ZAYCEVA	{"phone": "+70982471067"}
0005432526452	B9971E	6958 263523	NIKITA DAVYDOV	{"email": "davydov-n_26111986@postgrespro.ru", "phone": "+70157011005"}
0005432526453	B9971E	7851 977339	LIDIYA SEMENOVA	{"email": "l_semenova_1963@postgrespro.ru", "phone": "+70738981367"}
0005432526454	B9971E	0739 962121	ANDREY DAVYDOV	{"email": "andrey-davydov.081969@postgrespro.ru", "phone": "+70267164210"}
0005432526455	B9971E	7771 733093	ALEKSANDR EGOROV	{"email": "aleksandr_egorov28111962@postgrespro.ru", "phone": "+70567066230"}
0005432526456	789EF4	2650 951271	LIDIYA GERASIMOVA	{"email": "lidiyagerasimova.05031968@postgrespro.ru", "phone": "+70973878250"}
0005432526457	D832A5	8626 442534	VLADIMIR KOROLEV	{"email": "korolevvladimir.05051974@postgrespro.ru", "phone": "+70663014708"}
0005432526458	FFE24C	5275 621569	EVGENIY ZAKHAROV	{"phone": "+70896146549"}
0005432526459	FFE24C	9482 448425	OLGA MEDVEDEVA	{"email": "medvedeva_olga23081977@postgrespro.ru", "phone": "+70140282550"}
0005432526460	6B499F	5011 122198	SVETLANA KUZNECOVA	{"phone": "+70188364954"}
0005432526461	AAFAE5	0523 720872	SERGEY FROLOV	{"email": "frolov-sergey-121963@postgrespro.ru", "phone": "+70314920597"}
0005432526462	AAFAE5	8190 513347	PAVEL VLASOV	{"email": "vlasovpavel.23071975@postgrespro.ru", "phone": "+70291580359"}
0005432526463	3B210A	9337 518403	GERMAN DENISOV	{"email": "denisov.g.31051969@postgrespro.ru", "phone": "+70463423686"}
0005432526464	62B450	4122 766686	TIMOFEY KONOVALOV	{"email": "tkonovalov-041976@postgrespro.ru", "phone": "+70943460591"}
0005432526465	25299E	3936 749741	VIKTORIYA RYABOVA	{"phone": "+70816703258"}
0005432526466	25299E	7126 991089	YULIYA MOROZOVA	{"email": "yuliya-morozova_121965@postgrespro.ru", "phone": "+70176352759"}
0005432526467	B87B06	2088 690014	DMITRIY DMITRIEV	{"phone": "+70016871215"}
0005432526468	F1A12B	4575 091783	ALEKSANDR NIKOLAEV	{"phone": "+70105608797"}
0005432526469	F1A12B	9676 600353	NATALYA MOROZOVA	{"phone": "+70154534222"}
0005432526470	65379D	5465 004251	YULIYA SOROKINA	{"email": "sorokina.yuliya-14031970@postgrespro.ru", "phone": "+70124722832"}
0005432526471	E78796	9835 884433	VALENTINA NESTEROVA	{"email": "vnesterova.07081963@postgrespro.ru", "phone": "+70140097602"}
0005432526472	C23A78	0737 351965	GALINA SOKOLOVA	{"email": "sokolova.galina_20121972@postgrespro.ru", "phone": "+70807448473"}
0005432526473	C23A78	2645 121706	SERGEY KONOVALOV	{"email": "sergey.konovalov_09051979@postgrespro.ru", "phone": "+70139668278"}
0005432526474	477505	7483 949501	VALENTINA TROFIMOVA	{"phone": "+70875647509"}
0005432526475	E6172F	5680 982530	VLADISLAV SCHERBAKOV	{"phone": "+70028724498"}
0005432526476	DE6001	8010 212344	DANILA VOROBEV	{"email": "danila_vorobev.1974@postgrespro.ru", "phone": "+70505196688"}
0005432526477	2BA7BC	9980 816507	OLGA KUZNECOVA	{"email": "okuznecova.011972@postgrespro.ru", "phone": "+70993532870"}
0005432526478	2BA7BC	0485 987451	VLADIMIR ZAYCEV	{"email": "zaycevv_1970@postgrespro.ru", "phone": "+70182551359"}
0005432526479	B3390C	1893 970700	NATALYA ZAKHAROVA	{"phone": "+70978081417"}
0005432526480	787620	0812 232919	OLESYA MIKHAYLOVA	{"email": "o-mikhaylova_1975@postgrespro.ru", "phone": "+70282006116"}
0005432526481	4EA240	2799 259785	ELENA GERASIMOVA	{"phone": "+70256260823"}
0005432526482	FB543D	2243 337617	VERA BARANOVA	{"email": "vera_baranova-06041979@postgrespro.ru", "phone": "+70870197108"}
0005432526483	63701B	0416 941061	SVETLANA TIMOFEEVA	{"phone": "+70649450376"}
0005432526484	04726B	6421 892379	MARGARITA FOMINA	{"phone": "+70683544782"}
0005432526485	04726B	9261 050143	VLADIMIR IVANOV	{"phone": "+70191261063"}
0005432526486	CE305C	9593 078703	ALEKSEY MARTYNOV	{"email": "amartynov071968@postgrespro.ru", "phone": "+70033369617"}
0005432526487	26318D	3115 998690	EKATERINA LAZAREVA	{"phone": "+70431398690"}
0005432526488	7102E1	5684 351494	ANTONINA SOLOVEVA	{"phone": "+70467000390"}
0005432526489	BCD212	2136 509693	EVGENIY MELNIKOV	{"phone": "+70016985500"}
0005432526490	BCD212	9634 120701	VASILIY ZAKHAROV	{"phone": "+70807094741"}
0005432526491	8754A7	3315 705536	ALEKSANDR FROLOV	{"phone": "+70134216549"}
0005432526492	E3CEB0	5289 842714	NINA EGOROVA	{"email": "nina-egorova1975@postgrespro.ru", "phone": "+70624706578"}
0005432526493	14EADD	9667 429477	MARIYA KOMAROVA	{"email": "mariya-komarova_041982@postgrespro.ru", "phone": "+70795000164"}
0005432526494	0EFE04	7950 399324	MIKHAIL KUZNECOV	{"email": "kuznecovm_1977@postgrespro.ru", "phone": "+70419903771"}
0005432526495	49EC81	8864 964736	ALEKSANDR TARASOV	{"phone": "+70997331507"}
0005432526496	3D1E12	8380 360358	SERGEY SIDOROV	{"email": "sidorov.s.1973@postgrespro.ru", "phone": "+70414971809"}
0005432526497	D9FBA3	7646 284987	ALEKSANDR SEMENOV	{"phone": "+70553502156"}
0005432526498	D9FBA3	7833 123558	GRIGORIY DAVYDOV	{"phone": "+70625972273"}
0005432526499	EBFF2B	8111 101153	ELENA KALININA	{"phone": "+70811016953"}
0005432526500	06A2E6	3309 831700	LYUDMILA YUDINA	{"phone": "+70593156748"}
0005432526501	CA8182	0768 423934	VALENTINA POPOVA	{"phone": "+70341600258"}
0005432526502	5967A2	8916 637757	VERA ZOTOVA	{"email": "zotova.v-041980@postgrespro.ru", "phone": "+70145787096"}
0005432526503	B5FCDE	6557 876110	SERGEY KUZNECOV	{"email": "sergeykuznecov-31031969@postgrespro.ru", "phone": "+70940604558"}
0005432526504	33980D	2742 053386	LYUDMILA ROMANOVA	{"email": "romanova-l.1969@postgrespro.ru", "phone": "+70166911016"}
0005432526505	33980D	6695 644447	OLGA ALEKSEEVA	{"email": "o_alekseeva_021973@postgrespro.ru", "phone": "+70987631597"}
0005432526506	AE65FD	4176 029241	MARIYA FROLOVA	{"phone": "+70757614709"}
0005432526507	1B2F50	4103 623045	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-v.021972@postgrespro.ru", "phone": "+70567862020"}
0005432526508	D8D546	8378 437419	DMITRIY BORISOV	{"phone": "+70371462976"}
0005432526510	6060F8	4333 249931	ANASTASIYA NIKOLAEVA	{"phone": "+70884220903"}
0005432526511	A9A4E8	0062 368184	ANATOLIY MAKAROV	{"email": "makarovanatoliy_071966@postgrespro.ru", "phone": "+70537839129"}
0005432526512	855F67	4137 404929	ALEKSANDR KISELEV	{"phone": "+70139763712"}
0005432526513	AB9279	7939 783876	NIKOLAY ALEKSEEV	{"phone": "+70913581682"}
0005432526514	AB9279	6150 183084	NIKOLAY SMIRNOV	{"email": "nikolaysmirnov-1985@postgrespro.ru", "phone": "+70764123216"}
0005432526515	1C7953	9941 959084	SERGEY MOROZOV	{"email": "morozov_sergey1981@postgrespro.ru", "phone": "+70151183691"}
0005432526516	FB44F5	0497 266815	MIKHAIL FROLOV	{"email": "mfrolov.1967@postgrespro.ru", "phone": "+70652266490"}
0005432526517	11D1B4	4464 976560	NATALYA AFANASEVA	{"phone": "+70989676797"}
0005432526518	50C563	7452 444038	MIKHAIL GORBUNOV	{"phone": "+70804224661"}
0005432526519	9431C7	6405 636268	KRISTINA ALEKSEEVA	{"email": "kristina-alekseeva-061957@postgrespro.ru", "phone": "+70191070456"}
0005432526520	9431C7	5958 310761	SERGEY SHEVCHENKO	{"phone": "+70026747306"}
0005432526521	347D16	4094 634661	STANISLAV FEDOTOV	{"email": "s-fedotov.11021972@postgrespro.ru", "phone": "+70414336473"}
0005432526522	347D16	8728 481466	ANASTASIYA NAZAROVA	{"email": "nazarovaa1972@postgrespro.ru", "phone": "+70837610768"}
0005432526523	35F85F	1559 308379	ALEKSEY VOLKOV	{"phone": "+70891071315"}
0005432526524	CDBE42	0976 456377	ANATOLIY IVANOV	{"phone": "+70024641951"}
0005432526525	1B4FB6	2794 534575	VIKTOR KOZLOV	{"email": "kozlovviktor.13051966@postgrespro.ru", "phone": "+70255142010"}
0005432526526	1B4FB6	7661 487985	OLGA KOROLEVA	{"email": "koroleva.olga.10041969@postgrespro.ru", "phone": "+70504017244"}
0005432526527	A09A68	5510 349843	ALEKSANDR MARTYNOV	{"phone": "+70222361304"}
0005432526528	A09A68	2163 333408	OLGA ZAYCEVA	{"email": "zayceva-olga_1981@postgrespro.ru", "phone": "+70169255106"}
0005432526529	B6C5E5	4527 828939	YURIY KUZMIN	{"phone": "+70116624508"}
0005432526530	3C939D	5081 482049	AMIR OSIPOV	{"email": "osipovamir-071973@postgrespro.ru", "phone": "+70188684803"}
0005432526531	ACAAD8	8011 039308	EVGENIY GRIGOREV	{"phone": "+70131409238"}
0005432526532	D5E5C9	0403 758682	TATYANA IVANOVA	{"email": "t-ivanova.1958@postgrespro.ru", "phone": "+70904129382"}
0005432526533	3C28CF	2342 855244	GALINA SAVELEVA	{"email": "saveleva.galina-11081987@postgrespro.ru", "phone": "+70040175542"}
0005432526534	3EE5E4	1105 212066	GALINA BORISOVA	{"email": "borisova_g_1960@postgrespro.ru", "phone": "+70175158938"}
0005432526535	0FD8D4	4973 233618	ALEKSEY CHERNOV	{"email": "achernov_111972@postgrespro.ru", "phone": "+70997604008"}
0005432526536	1B7C11	2262 520892	SERGEY MOROZOV	{"phone": "+70419853577"}
0005432526537	1B7C11	7593 109205	ALEKSEY POPOV	{"phone": "+70453657706"}
0005432526538	3CA311	0376 059589	VLADIMIR TIKHONOV	{"email": "tikhonov.vladimir-011980@postgrespro.ru", "phone": "+70457994330"}
0005432526539	A890B6	8240 615190	ALEKSEY RODIONOV	{"phone": "+70705378603"}
0005432526540	A890B6	5688 149551	GENNADIY ZHUKOV	{"email": "zhukov-gennadiy-041980@postgrespro.ru", "phone": "+70355574935"}
0005432526541	A890B6	9919 469677	IVAN KRASNOV	{"phone": "+70360599505"}
0005432526542	DDCB9D	7541 368213	ANNA DAVYDOVA	{"email": "davydova.anna_14051982@postgrespro.ru", "phone": "+70756342343"}
0005432526543	DDCB9D	3140 506591	TATYANA MAKAROVA	{"phone": "+70197339259"}
0005432526544	C5DEC2	5557 346446	KIRILL FEDOTOV	{"phone": "+70865189308"}
0005432526545	C5DEC2	4016 227922	ALBERT IVANOV	{"email": "aivanov1955@postgrespro.ru", "phone": "+70364466277"}
0005432526546	38076A	0502 188562	DENIS NOVIKOV	{"phone": "+70616251320"}
0005432526547	7276FA	4985 198157	GALINA KULIKOVA	{"email": "gkulikova1979@postgrespro.ru", "phone": "+70558242703"}
0005432526548	AEFF48	2226 906163	VLADIMIR MATVEEV	{"email": "matveevvladimir31031975@postgrespro.ru", "phone": "+70387390251"}
0005432526549	42CCCF	4168 225544	ANTON AFANASEV	{"email": "afanasev-anton.1971@postgrespro.ru", "phone": "+70366620619"}
0005432526550	8574AC	5009 179575	SERGEY ANDREEV	{"email": "andreev_sergey-26071967@postgrespro.ru", "phone": "+70658265036"}
0005432526551	59B588	3533 612171	ALEKSEY ZHURAVLEV	{"phone": "+70481187469"}
0005432526552	4A127C	1184 163524	GENNADIY GUSEV	{"email": "gennadiygusev_07101972@postgrespro.ru", "phone": "+70439643685"}
0005432526553	4A127C	3928 112444	LYUBOV ROMANOVA	{"email": "l-romanova1986@postgrespro.ru", "phone": "+70981736160"}
0005432526554	12151A	6411 940323	SERGEY SMIRNOV	{"email": "smirnov-sergey.1967@postgrespro.ru", "phone": "+70822471222"}
0005432526555	12151A	2737 563497	TAMARA ANISIMOVA	{"phone": "+70172681601"}
0005432526556	831D35	1408 741387	NIKITA SMIRNOV	{"email": "smirnov_n-011973@postgrespro.ru", "phone": "+70200798644"}
0005432526557	6A5D32	9713 625292	NIKOLAY KUZMIN	{"email": "nkuzmin03081966@postgrespro.ru", "phone": "+70521404916"}
0005432526558	420D1D	4094 003790	GALINA STEPANOVA	{"phone": "+70117710604"}
0005432526559	DF814B	3115 541739	NINA ROMANOVA	{"email": "romanova.n_20051968@postgrespro.ru", "phone": "+70768652140"}
0005432526560	DF814B	4322 965133	IVAN EGOROV	{"phone": "+70294563132"}
0005432526561	DF814B	8237 403538	VLADIMIR TIKHONOV	{"email": "tikhonov_vladimir.1977@postgrespro.ru", "phone": "+70718394141"}
0005432526562	8D1C1E	7114 726252	ALEKSANDR MAKAROV	{"phone": "+70894973005"}
0005432526563	232CA9	3630 519973	TATYANA IVANOVA	{"phone": "+70941489159"}
0005432526564	343E57	3534 532473	EVGENIY FROLOV	{"email": "frolov_e.1971@postgrespro.ru", "phone": "+70382230799"}
0005432526565	4F3131	3987 445447	ELENA KONOVALOVA	{"phone": "+70064035033"}
0005432526566	A6D52F	1463 219220	VALENTINA PETROVA	{"phone": "+70434606181"}
0005432526567	68475D	9595 535956	IRINA MOISEEVA	{"email": "imoiseeva-1964@postgrespro.ru", "phone": "+70889754498"}
0005432526568	B81451	5203 503611	NATALYA ANDREEVA	{"email": "andreeva.n_091972@postgrespro.ru", "phone": "+70592949373"}
0005432526569	0F8D37	1145 979032	VLADIMIR ROMANOV	{"phone": "+70827383019"}
0005432526570	60CA66	2679 484346	LYUDMILA OSIPOVA	{"phone": "+70717558153"}
0005432526571	F8E3A9	9613 935971	VYACHESLAV IVANOV	{"email": "ivanov-vyacheslav.041974@postgrespro.ru", "phone": "+70502498323"}
0005432526572	45EAAE	8314 703974	RAISA SEMENOVA	{"phone": "+70379959854"}
0005432526573	45EAAE	9072 506496	LYUDMILA PETROVA	{"phone": "+70651333703"}
0005432526574	45EAAE	4524 990280	SERGEY KUZNECOV	{"email": "kuznecov-sergey1977@postgrespro.ru", "phone": "+70480089809"}
0005432526575	2F146D	7766 488464	DENIS BONDARENKO	{"email": "denis_bondarenko21061969@postgrespro.ru", "phone": "+70351628952"}
0005432526576	E12FFF	4272 147953	OLGA ROMANOVA	{"phone": "+70078393150"}
0005432526577	7872D0	4931 599004	MARINA NIKITINA	{"email": "nikitina-marina_011964@postgrespro.ru", "phone": "+70811730604"}
0005432526578	C7EE94	2006 045818	GALINA IVANOVA	{"phone": "+70954464362"}
0005432526579	AE114A	6854 125855	LIDIYA ZHUKOVA	{"email": "l_zhukova-1978@postgrespro.ru", "phone": "+70795081290"}
0005432526580	C1AA32	5381 297060	GULNARA PAVLOVA	{"phone": "+70937082296"}
0005432526581	0CA148	4247 168330	ALEKSEY KRASNOV	{"email": "krasnov.aleksey-081975@postgrespro.ru", "phone": "+70055925051"}
0005432526582	B6EE0B	0737 060579	ALEKSANDRA SOKOLOVA	{"email": "sokolovaa_1972@postgrespro.ru", "phone": "+70567126809"}
0005432526583	47C97F	8091 183929	SERGEY STEPANOV	{"email": "stepanovsergey.29051979@postgrespro.ru", "phone": "+70272776525"}
0005432526584	3FA9A0	7103 511045	OLGA VOLKOVA	{"phone": "+70515893442"}
0005432526585	3FA9A0	1243 485406	NADEZHDA ZAKHAROVA	{"email": "zakharovan_051976@postgrespro.ru", "phone": "+70200775729"}
0005432526586	0FBE9B	7202 381084	ANATOLIY PETROV	{"phone": "+70608572977"}
0005432526587	A75A7F	4418 042391	MAKSIM GUSEV	{"phone": "+70682140542"}
0005432526588	0D7AF2	1935 272912	IVAN ANDREEV	{"email": "andreev_ivan.1980@postgrespro.ru", "phone": "+70617228156"}
0005432526589	FF22EB	6712 270993	IVAN KRASNOV	{"phone": "+70993048619"}
0005432526590	FF22EB	2140 152431	ANASTASIYA KONDRATEVA	{"email": "kondrateva.anastasiya-1976@postgrespro.ru", "phone": "+70871402877"}
0005432526591	7ADD99	5502 911697	NADEZHDA SIDOROVA	{"email": "sidorovan1969@postgrespro.ru", "phone": "+70607548953"}
0005432526592	7ADD99	0947 458184	OLESYA KUZNECOVA	{"phone": "+70249914404"}
0005432526593	7ADD99	9224 019177	GENNADIY CHERNOV	{"phone": "+70464054141"}
0005432526594	46CBB1	2624 461691	OLGA KAZAKOVA	{"phone": "+70927668047"}
0005432526595	A3C8A8	5954 408783	ALEKSEY SOROKIN	{"email": "alekseysorokin_091968@postgrespro.ru", "phone": "+70373697834"}
0005432526596	816959	9856 004015	LARISA GRISHINA	{"phone": "+70586210995"}
0005432526597	B29033	0065 934571	VALENTINA MIKHAYLOVA	{"phone": "+70429775518"}
0005432526598	B29033	6062 860989	OLESYA KUZMINA	{"phone": "+70219276014"}
0005432526599	BA0F05	3735 525858	ELENA SMIRNOVA	{"phone": "+70544893594"}
0005432526600	BA0F05	9987 407082	ALEKSANDR MARTYNOV	{"email": "martynov.a-081963@postgrespro.ru", "phone": "+70403504972"}
0005432526601	02855D	3114 494128	ALEKSANDR EGOROV	{"phone": "+70113379355"}
0005432526602	5AD9CD	3812 634195	OLGA IVANOVA	{"email": "ivanova_o.101974@postgrespro.ru", "phone": "+70288596815"}
0005432526603	AAED79	8204 094266	ANTON MOROZOV	{"phone": "+70759545612"}
0005432526604	AAED79	2809 124192	LYUBOV MASLOVA	{"email": "l.maslova-081977@postgrespro.ru", "phone": "+70769091750"}
0005432526605	3C171B	8893 310278	ALEKSANDR SHEVCHENKO	{"phone": "+70472300613"}
0005432526606	3C171B	4933 945642	ANASTASIYA GRISHINA	{"email": "agrishina_23041966@postgrespro.ru", "phone": "+70617332398"}
0005432526607	878BF7	1699 248504	LYUBOV MOROZOVA	{"email": "morozova.lyubov-1978@postgrespro.ru", "phone": "+70288121662"}
0005432526608	878BF7	9523 756880	NATALYA DANILOVA	{"phone": "+70263963172"}
0005432526609	0AEA0B	2402 137201	VASILISA NAUMOVA	{"phone": "+70897649281"}
0005432526610	A355BC	6640 434717	ALEKSEY BELOV	{"phone": "+70397644483"}
0005432526611	7D3BA7	5578 714017	NIKOLAY EGOROV	{"email": "nikolay_egorov-06051974@postgrespro.ru", "phone": "+70376359720"}
0005432526612	7D3BA7	3807 895515	ANDREY GRIGOREV	{"phone": "+70224961620"}
0005432526613	D8BF7B	2662 160483	VIKTOR ANDREEV	{"email": "v.andreev1973@postgrespro.ru", "phone": "+70189710048"}
0005432526614	73B3E7	7582 474916	IRINA TARASOVA	{"phone": "+70671188642"}
0005432526615	74B1A2	7197 616135	IVAN KISELEV	{"email": "kiselevivan-09121976@postgrespro.ru", "phone": "+70884023479"}
0005432526616	74B1A2	2545 573321	EVGENIY MIKHAYLOV	{"phone": "+70065421955"}
0005432526617	23B1A8	6922 984390	MARAT ILIN	{"email": "m-ilin_1973@postgrespro.ru", "phone": "+70392526605"}
0005432526618	378A95	2973 894538	ANASTASIYA SERGEEVA	{"email": "sergeeva_anastasiya28081970@postgrespro.ru", "phone": "+70316825893"}
0005432526619	378A95	8400 880976	NIKOLAY MIKHAYLOV	{"email": "n-mikhaylov-14121967@postgrespro.ru", "phone": "+70180553078"}
0005432526620	A1A979	3132 686433	VLADIMIR FROLOV	{"email": "vladimir_frolov-02031974@postgrespro.ru", "phone": "+70380891474"}
0005432526621	A1A979	9635 679534	LYUBOV PETROVA	{"email": "l-petrova19011968@postgrespro.ru", "phone": "+70835376366"}
0005432526622	1613AE	4198 155842	GALINA MOROZOVA	{"email": "morozovag051968@postgrespro.ru", "phone": "+70179303366"}
0005432526625	36F7D8	1295 922032	MARIYA GRISHINA	{"email": "grishina_mariya1982@postgrespro.ru", "phone": "+70931706943"}
0005432526626	701756	3206 689911	YULIYA ZHUKOVA	{"phone": "+70538092996"}
0005432526627	D4ABBB	5566 387103	LEONID YAKOVLEV	{"phone": "+70462625844"}
0005432526628	9E379E	3101 956031	IVAN DAVYDOV	{"phone": "+70401148053"}
0005432526629	9E379E	6512 814973	EKATERINA DENISOVA	{"phone": "+70793551495"}
0005432526630	9E379E	3461 039836	ELENA KUZNECOVA	{"email": "e-kuznecova_121969@postgrespro.ru", "phone": "+70674443357"}
0005432526631	9E379E	3502 099598	VALERIYA PAVLOVA	{"email": "pavlova-valeriya.31031975@postgrespro.ru", "phone": "+70552205575"}
0005432526632	F758B5	2763 699708	ELIZAVETA ZHURAVLEVA	{"phone": "+70685182017"}
0005432526633	6443AE	2187 626175	VLADIMIR MAKAROV	{"email": "makarov.vladimir-1969@postgrespro.ru", "phone": "+70520039601"}
0005432526634	BCB48E	0772 814469	EKATERINA SEMENOVA	{"email": "ekaterina_semenova-15061974@postgrespro.ru", "phone": "+70119995163"}
0005432526635	BCB48E	2683 694309	LEONID ANTONOV	{"email": "antonov-l-10101974@postgrespro.ru", "phone": "+70874658039"}
0005432526636	22028A	0452 169015	LYUBOV KUZMINA	{"email": "kuzminalyubov_03121980@postgrespro.ru", "phone": "+70223472540"}
0005432526637	F96B61	3980 359540	VERA NAZAROVA	{"email": "vera_nazarova.26071970@postgrespro.ru", "phone": "+70521735902"}
0005432526638	DEB932	6972 713105	PAVEL STEPANOV	{"phone": "+70760611274"}
0005432526639	4D0509	5874 042210	GENNADIY FEDOROV	{"email": "fedorov-g13071975@postgrespro.ru", "phone": "+70788197795"}
0005432526640	C0A57B	0468 458544	GALINA ANDREEVA	{"phone": "+70813834774"}
0005432526641	C0A57B	9305 671182	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko1978@postgrespro.ru", "phone": "+70856078879"}
0005432526642	0A13E7	2662 401444	EKATERINA ILINA	{"email": "ilina-e071965@postgrespro.ru", "phone": "+70012650169"}
0005432526643	0A13E7	0404 200684	ELENA KISELEVA	{"email": "kiseleva-e091974@postgrespro.ru", "phone": "+70008339529"}
0005432526644	0A13E7	5305 134191	RAISA ZHUKOVA	{"email": "raisa_zhukova_1974@postgrespro.ru", "phone": "+70862186023"}
0005432526645	A00FC9	7603 667066	TATYANA POPOVA	{"phone": "+70629852813"}
0005432526646	920161	1786 445766	ALEKSANDR ANTONOV	{"phone": "+70027260746"}
0005432526647	D4EAB1	3068 935643	TATYANA ILINA	{"phone": "+70768171231"}
0005432526648	D4EAB1	5976 669215	ELINA POPOVA	{"phone": "+70487890658"}
0005432526649	47F1C9	8397 922318	ANNA GUSEVA	{"email": "a.guseva12021974@postgrespro.ru", "phone": "+70996883250"}
0005432526650	4CBFA6	2679 923791	DARYA KOZLOVA	{"phone": "+70131892638"}
0005432526651	4CBFA6	5363 467351	ANATOLIY KUZMIN	{"email": "anatoliy-kuzmin.1964@postgrespro.ru", "phone": "+70540809642"}
0005432526652	4CBFA6	4126 207962	DARYA TIMOFEEVA	{"email": "darya-timofeeva_011970@postgrespro.ru", "phone": "+70423546807"}
0005432526653	EB6E35	7453 948506	ARTEM BORISOV	{"phone": "+70417875456"}
0005432526654	5102A8	7731 282535	PETR ZAYCEV	{"email": "p-zaycev-16051974@postgrespro.ru", "phone": "+70122944547"}
0005432526655	2AEEE4	9660 621962	SERGEY VOLKOV	{"phone": "+70955301972"}
0005432526656	2AEEE4	9561 130065	ANNA SEMENOVA	{"email": "semenova.a_17041975@postgrespro.ru", "phone": "+70604584784"}
0005432526657	65D690	1103 402147	SERGEY MAKSIMOV	{"phone": "+70675475497"}
0005432526658	65D690	1301 820537	MARIYA FILATOVA	{"email": "filatova.mariya-121955@postgrespro.ru", "phone": "+70494737579"}
0005432526659	3B8E1A	3445 293568	EKATERINA DAVYDOVA	{"phone": "+70991386450"}
0005432526660	9CD815	0186 101000	MARIYA NAZAROVA	{"phone": "+70627093258"}
0005432526661	B6FBD7	6137 788096	VASILIY SERGEEV	{"email": "vasiliysergeev17111959@postgrespro.ru", "phone": "+70658215552"}
0005432526662	B6FBD7	6483 631518	VALENTINA SCHERBAKOVA	{"phone": "+70589467498"}
0005432526663	1EF8F6	4636 851217	EVGENIYA KOROLEVA	{"email": "evgeniya.koroleva.1971@postgrespro.ru", "phone": "+70080304480"}
0005432526664	0D0451	8070 799255	ARINA EFIMOVA	{"email": "efimova_arina_011976@postgrespro.ru", "phone": "+70542568952"}
0005432526665	0D0451	4662 137642	STANISLAV FEDOROV	{"phone": "+70845577550"}
0005432526666	E94F20	8229 592950	ALEKSANDRA SERGEEVA	{"phone": "+70404461260"}
0005432526667	E94F20	3878 096244	ALEKSEY KUZNECOV	{"email": "a_kuznecov-10031977@postgrespro.ru", "phone": "+70624635050"}
0005432526668	482042	5970 707237	ARTUR FILIPPOV	{"email": "a-filippov-1971@postgrespro.ru", "phone": "+70052985468"}
0005432526669	482042	0564 357799	YULIYA KUZNECOVA	{"email": "y_kuznecova-071973@postgrespro.ru", "phone": "+70607646949"}
0005432526670	BB641B	6617 836090	RUSTAM MIRONOV	{"email": "r-mironov041979@postgrespro.ru", "phone": "+70231063790"}
0005432526671	BB641B	2375 798281	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr111984@postgrespro.ru", "phone": "+70745256103"}
0005432526672	9C4CA6	0437 828459	PETR GERASIMOV	{"phone": "+70018160002"}
0005432526673	58B560	8885 394135	ALEKSANDR SHEVCHENKO	{"phone": "+70864087654"}
0005432526674	EA45A5	8664 115192	VALERIY EGOROV	{"phone": "+70258691038"}
0005432526675	EEDEA1	8669 810599	DAMIR SOLOVEV	{"email": "dsolovev091981@postgrespro.ru", "phone": "+70630864536"}
0005432526676	B99205	4687 330739	GALINA AKIMOVA	{"phone": "+70522980563"}
0005432526677	397E76	0749 734578	ALEKSANDR TIMOFEEV	{"email": "aleksandr.timofeev-061970@postgrespro.ru", "phone": "+70698124327"}
0005432526678	C21873	4246 041876	VALENTINA FILATOVA	{"phone": "+70572655812"}
0005432526679	7F80AC	1902 900816	NIKOLAY DAVYDOV	{"phone": "+70823503939"}
0005432526680	61ED65	7785 956461	SERGEY GRIGOREV	{"phone": "+70327903330"}
0005432526681	6FD51B	4450 316955	IGOR MATVEEV	{"email": "matveev_i-11021964@postgrespro.ru", "phone": "+70898947009"}
0005432526682	6FD51B	4039 856995	ANATOLIY SIDOROV	{"email": "anatoliy-sidorov011969@postgrespro.ru", "phone": "+70620750425"}
0005432526683	DD87EC	4496 633584	ALEKSANDR VLASOV	{"email": "a_vlasov1970@postgrespro.ru", "phone": "+70694259050"}
0005432526684	DD87EC	4688 449868	EVGENIY DMITRIEV	{"phone": "+70041485081"}
0005432526685	6A64A1	0121 492060	LILIYA KALININA	{"email": "l_kalinina.1985@postgrespro.ru", "phone": "+70359240324"}
0005432526686	C8A072	6953 791017	OLGA BOGDANOVA	{"phone": "+70393771025"}
0005432526687	C8A072	3610 635942	SERGEY VLASOV	{"email": "vlasov-sergey.031982@postgrespro.ru", "phone": "+70514903607"}
0005432526688	C8A072	9554 511322	ANASTASIYA SMIRNOVA	{"email": "smirnova_a-12021971@postgrespro.ru", "phone": "+70116163382"}
0005432526689	9841E4	0049 451497	KIRILL SIDOROV	{"email": "kirill.sidorov1961@postgrespro.ru", "phone": "+70096550313"}
0005432526690	8D1C3E	3384 794036	RAISA FROLOVA	{"email": "frolova_r-15121974@postgrespro.ru", "phone": "+70833220276"}
0005432526691	A03130	7035 926306	ANASTASIYA YUDINA	{"phone": "+70924913396"}
0005432526692	A03130	2570 728851	BOGDAN SCHERBAKOV	{"phone": "+70001257675"}
0005432526693	A0E974	5161 420098	IVAN MAKAROV	{"email": "ivan_makarov-27051984@postgrespro.ru", "phone": "+70671543644"}
0005432526694	A0E974	4542 914371	IVAN MATVEEV	{"email": "i_matveev-081960@postgrespro.ru", "phone": "+70212175722"}
0005432526695	A0E974	9116 104072	BORIS SEMENOV	{"phone": "+70587796451"}
0005432526696	6F1C1C	1849 449485	EKATERINA EFREMOVA	{"email": "e_efremova011965@postgrespro.ru", "phone": "+70779922910"}
0005432526697	6F1C1C	4318 870156	VASILIY BARANOV	{"email": "baranov_vasiliy_101975@postgrespro.ru", "phone": "+70156143288"}
0005432526698	BD8D03	1049 283903	SVETLANA POTAPOVA	{"email": "svetlana-potapova.031976@postgrespro.ru", "phone": "+70094963707"}
0005432526699	E9089C	9481 294912	ALEKSEY FILIPPOV	{"email": "filippov_aleksey_1980@postgrespro.ru", "phone": "+70868507971"}
0005432526700	E9089C	0712 410872	OLGA CHERNOVA	{"phone": "+70309331394"}
0005432526701	B5D9C5	9532 374093	VLADISLAV BARANOV	{"phone": "+70525037791"}
0005432526702	FA8548	0152 127543	VALENTINA ISAEVA	{"email": "isaevav.09011972@postgrespro.ru", "phone": "+70273172005"}
0005432526703	2C32D2	1730 246650	ANTON MAKAROV	{"email": "anton.makarov-09031969@postgrespro.ru", "phone": "+70422741576"}
0005432526704	A19C0B	5140 528469	ANNA LAZAREVA	{"email": "anna.lazareva.1961@postgrespro.ru", "phone": "+70517893781"}
0005432526705	A19C0B	8519 953110	INGA SOKOLOVA	{"email": "i-sokolova.13061966@postgrespro.ru", "phone": "+70501920481"}
0005432526706	A19C0B	0466 522437	OLEG SIDOROV	{"phone": "+70608472722"}
0005432526707	FAE1FE	7189 016270	ANDREY ALEKSEEV	{"email": "alekseev-andrey-06041979@postgrespro.ru", "phone": "+70787451339"}
0005432526708	42BBC7	5687 496370	INNA MELNIKOVA	{"phone": "+70682195182"}
0005432526709	42BBC7	7661 984856	ALINA NOVIKOVA	{"email": "alinanovikova_21071966@postgrespro.ru", "phone": "+70275580725"}
0005432526710	25CB82	3181 165559	MARIYA YAKOVLEVA	{"email": "m_yakovleva-091977@postgrespro.ru", "phone": "+70780200549"}
0005432526711	E269DE	5322 372358	YAROSLAV NOVIKOV	{"phone": "+70228345120"}
0005432526712	B647F5	5215 019951	DIANA PETROVA	{"phone": "+70493889301"}
0005432526713	0E6FFB	6707 528622	IRINA DANILOVA	{"email": "i.danilova_1975@postgrespro.ru", "phone": "+70189676050"}
0005432526714	1E147D	7418 166704	ILYA CHERNOV	{"email": "chernov_ilya.09121977@postgrespro.ru", "phone": "+70014966181"}
0005432526715	7CFFA6	3304 915289	EKATERINA KOROLEVA	{"phone": "+70246688886"}
0005432526716	D66782	1121 086783	VERA TROFIMOVA	{"phone": "+70219579500"}
0005432526717	058F1D	9310 197041	OLEG ABRAMOV	{"phone": "+70239900364"}
0005432526718	39CC91	4901 577565	NIKOLAY ZAKHAROV	{"email": "n.zakharov25051978@postgrespro.ru", "phone": "+70248864351"}
0005432526719	F3A79B	2537 809784	ELMIRA TIMOFEEVA	{"phone": "+70156343740"}
0005432526720	DBFB75	5760 010383	MIKHAIL VOROBEV	{"phone": "+70120668607"}
0005432526721	DBFB75	5861 322365	SERGEY ZAKHAROV	{"phone": "+70395749983"}
0005432526722	B8300A	9264 911420	DMITRIY MAKSIMOV	{"phone": "+70657874551"}
0005432526723	B8300A	9921 654849	SERGEY PETROV	{"phone": "+70879817569"}
0005432526724	01D458	9693 743076	DANILA STEPANOV	{"phone": "+70316709393"}
0005432526725	E1A0DB	8140 315251	VIKTOR POPOV	{"email": "viktorpopov.1966@postgrespro.ru", "phone": "+70714389644"}
0005432526726	496F2D	9740 861112	ZINAIDA FROLOVA	{"phone": "+70124143082"}
0005432526727	2DADAB	1593 400796	MARIYA POPOVA	{"phone": "+70478108397"}
0005432526728	2DADAB	3867 288091	SERGEY DENISOV	{"phone": "+70091198260"}
0005432526729	2DADAB	0395 009926	EKATERINA NOVIKOVA	{"email": "e.novikova_101961@postgrespro.ru", "phone": "+70036178137"}
0005432526730	4CE118	6984 117847	VALENTINA ZAYCEVA	{"phone": "+70357861260"}
0005432526731	4CE118	9638 336777	VIKTOR SOROKIN	{"phone": "+70027332796"}
0005432526732	48A8B3	0135 972290	DMITRIY TARASOV	{"email": "tarasov-dmitriy_1974@postgrespro.ru", "phone": "+70321672281"}
0005432526733	48A8B3	9555 491414	MARINA MOROZOVA	{"email": "marinamorozova26121973@postgrespro.ru", "phone": "+70704654108"}
0005432526734	608A57	8076 621870	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova021968@postgrespro.ru", "phone": "+70601082453"}
0005432526735	608A57	1709 442124	ALEKSANDR MOROZOV	{"email": "morozovaleksandr-1976@postgrespro.ru", "phone": "+70486355350"}
0005432526736	72B261	9520 791807	ALEKSANDR ILIN	{"phone": "+70717836433"}
0005432526738	25B805	4837 832110	ALEKSANDR NIKITIN	{"phone": "+70506199128"}
0005432526739	E184ED	9272 120294	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko.07111961@postgrespro.ru", "phone": "+70166148615"}
0005432526740	E22FEF	9162 313094	IGOR BELOV	{"email": "igor_belov15011964@postgrespro.ru", "phone": "+70701682507"}
0005432526741	107E4F	8292 892113	ALEKSEY KISELEV	{"phone": "+70968872093"}
0005432526742	7C5CAF	4746 526013	VLADIMIR KOROLEV	{"phone": "+70063385792"}
0005432526743	7C5CAF	9789 832449	NATALYA IVANOVA	{"email": "n_ivanova.1968@postgrespro.ru", "phone": "+70175528122"}
0005432526744	A74469	6213 683625	TIMOFEY SERGEEV	{"email": "sergeev-timofey.1976@postgrespro.ru", "phone": "+70799841260"}
0005432526745	A74469	2359 663903	VIKTOR KUZMIN	{"email": "kuzmin-v1974@postgrespro.ru", "phone": "+70687013467"}
0005432526746	664268	8942 981952	IGOR POPOV	{"email": "popov.i091978@postgrespro.ru", "phone": "+70361139393"}
0005432526747	513E11	1865 825989	EVGENIY CHERNOV	{"email": "chernov-e-17101975@postgrespro.ru", "phone": "+70592208336"}
0005432526748	513E11	1445 985117	TAISIYA KALININA	{"email": "taisiya-kalinina.1971@postgrespro.ru", "phone": "+70094480559"}
0005432526749	AB8AA5	0639 093494	MARGARITA ZAKHAROVA	{"email": "m_zakharova-1972@postgrespro.ru", "phone": "+70906983357"}
0005432526750	AB8AA5	6188 610567	ANNA BOGDANOVA	{"email": "anna.bogdanova_1972@postgrespro.ru", "phone": "+70466100400"}
0005432526751	6AF0F4	2462 254711	KRISTINA DENISOVA	{"phone": "+70190447970"}
0005432526752	30CADE	0738 109161	VLADIMIR IVANOV	{"email": "ivanov.v1976@postgrespro.ru", "phone": "+70671289563"}
0005432526753	9B2EC5	5903 126342	VALENTIN MEDVEDEV	{"phone": "+70778261158"}
0005432526754	9B2EC5	7728 074782	NATALYA ANISIMOVA	{"email": "anisimova_n20041973@postgrespro.ru", "phone": "+70947657488"}
0005432526755	C854A1	6010 286480	TATYANA KOMAROVA	{"email": "tatyana.komarova06091977@postgrespro.ru", "phone": "+70167705227"}
0005432526756	C854A1	2997 555915	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr_1971@postgrespro.ru", "phone": "+70717621216"}
0005432526757	9912B5	5528 059725	KLAVDIYA VOLKOVA	{"email": "volkovaklavdiya-1975@postgrespro.ru", "phone": "+70452857582"}
0005432526758	5D4D69	6721 726953	VERA PETROVA	{"email": "verapetrova1976@postgrespro.ru", "phone": "+70420180098"}
0005432526759	5D4D69	5730 926278	DENIS GORBUNOV	{"phone": "+70377085213"}
0005432526760	0E6DEF	1647 692672	IGOR VOROBEV	{"email": "ivorobev-1974@postgrespro.ru", "phone": "+70496722637"}
0005432526761	B6DE09	3141 540357	NIKOLAY KUZNECOV	{"phone": "+70839295186"}
0005432526762	112753	3664 641315	MIKHAIL PETROV	{"phone": "+70966980656"}
0005432526763	53BF1B	6221 953144	ALEKSEY FEDOTOV	{"email": "a.fedotov061972@postgrespro.ru", "phone": "+70177473048"}
0005432526764	05DBB6	9190 619218	ANTONINA KUZNECOVA	{"phone": "+70920918660"}
0005432526765	AA9E90	1037 722100	VLADISLAV ANTONOV	{"phone": "+70697829351"}
0005432526766	9AA3D0	7483 455301	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda.19111971@postgrespro.ru", "phone": "+70228112695"}
0005432526767	9AA3D0	6556 364305	EKATERINA DAVYDOVA	{"email": "ekaterina-davydova091983@postgrespro.ru", "phone": "+70940019679"}
0005432526768	9AA3D0	5595 095300	DIANA SMIRNOVA	{"phone": "+70343093706"}
0005432526769	798D1B	0658 993505	GENNADIY SHEVCHENKO	{"email": "shevchenko-gennadiy-06051983@postgrespro.ru", "phone": "+70532388730"}
0005432526770	54E043	3386 487991	SERGEY TIMOFEEV	{"email": "timofeevs01071973@postgrespro.ru", "phone": "+70086087954"}
0005432526771	8D6713	3759 288084	NINA KUDRYASHOVA	{"email": "kudryashova_nina.16071966@postgrespro.ru", "phone": "+70229814045"}
0005432526772	8D6713	3899 782161	LYUDMILA GUSEVA	{"email": "guseval_101968@postgrespro.ru", "phone": "+70133994091"}
0005432526773	278607	4738 143962	ELENA MELNIKOVA	{"email": "melnikova-e.081978@postgrespro.ru", "phone": "+70317498662"}
0005432526774	3ECA31	7166 967847	ANTONINA GAVRILOVA	{"email": "gavrilovaantonina1969@postgrespro.ru", "phone": "+70573553499"}
0005432526775	3E46D2	0355 763240	VALENTINA SAVELEVA	{"phone": "+70375308624"}
0005432526776	3E46D2	4984 981002	YULIYA VOLKOVA	{"phone": "+70017372858"}
0005432526777	270926	1396 314548	ALEKSANDR ZAKHAROV	{"phone": "+70400764398"}
0005432526778	270926	1049 923707	MAKSIM DMITRIEV	{"phone": "+70673402143"}
0005432526779	420C2A	3945 455607	MAKSIM DAVYDOV	{"phone": "+70354965475"}
0005432526780	25FFB7	4350 478282	YURIY YAKOVLEV	{"phone": "+70935398825"}
0005432526781	25FFB7	9891 549173	ROMAN SCHERBAKOV	{"email": "r.scherbakov.1977@postgrespro.ru", "phone": "+70042907701"}
0005432526782	F16106	8128 389937	MIKHAIL ZAYCEV	{"phone": "+70768474497"}
0005432526783	0B026A	1954 919163	NIKOLAY PAVLOV	{"email": "pavlov_nikolay17021977@postgrespro.ru", "phone": "+70214639731"}
0005432526784	0B026A	3919 555943	ROSTISLAV KULIKOV	{"phone": "+70000742640"}
0005432526785	1C5EC9	0403 548059	VALENTINA KUZMINA	{"email": "valentina_kuzmina1974@postgrespro.ru", "phone": "+70699701694"}
0005432526786	1C5EC9	1500 109365	ALEKSEY NOVIKOV	{"phone": "+70164966344"}
0005432526787	1C5EC9	9927 491947	SERGEY SMIRNOV	{"phone": "+70117815640"}
0005432526788	1C5EC9	4938 232626	VALENTINA MOROZOVA	{"email": "morozova_v-04101974@postgrespro.ru", "phone": "+70125919318"}
0005432526789	E5DC52	2030 273065	GALINA BELYAEVA	{"email": "belyaeva_galina.21061967@postgrespro.ru", "phone": "+70681054471"}
0005432526790	E5DC52	1084 542454	NATALYA VASILEVA	{"email": "vasilevan-1971@postgrespro.ru", "phone": "+70902909456"}
0005432526791	E8464E	9227 672357	MAKSIM STEPANOV	{"phone": "+70705573743"}
0005432526792	6ABBDB	4315 183624	EVGENIYA NIKITINA	{"phone": "+70862528789"}
0005432526793	5E64E7	1128 089993	ANASTASIYA FEDOROVA	{"phone": "+70805120098"}
0005432526794	6E66EF	2663 824433	IRINA KUZMINA	{"phone": "+70903842657"}
0005432526795	6E66EF	5759 590972	TATYANA AFANASEVA	{"email": "afanaseva-t1968@postgrespro.ru", "phone": "+70158569628"}
0005432526796	5E5584	2171 369984	SERGEY MAKAROV	{"phone": "+70119591614"}
0005432526797	962007	2303 554458	EVGENIYA AKIMOVA	{"email": "akimova-evgeniya03081978@postgrespro.ru", "phone": "+70078885122"}
0005432526798	65E6EF	4947 343248	ELENA FROLOVA	{"email": "frolovae.071977@postgrespro.ru", "phone": "+70516800315"}
0005432526799	65E6EF	5815 429357	KSENIYA ROMANOVA	{"email": "romanova.kseniya101980@postgrespro.ru", "phone": "+70192576979"}
0005432526800	AC7713	5650 084664	ARKADIY PETROV	{"email": "arkadiypetrov_1966@postgrespro.ru", "phone": "+70585512566"}
0005432526801	B1029F	9180 056799	NIKITA SOKOLOV	{"email": "sokolov-nikita-011970@postgrespro.ru", "phone": "+70247915770"}
0005432526802	29E891	5553 893560	LIDIYA OSIPOVA	{"phone": "+70998744105"}
0005432526803	354CE9	7408 214639	NINA BELOVA	{"phone": "+70724446058"}
0005432526804	291BAD	0468 742629	VLADIMIR TIMOFEEV	{"phone": "+70322348749"}
0005432526805	291BAD	0830 844606	ANATOLIY FOMIN	{"email": "afomin-24031974@postgrespro.ru", "phone": "+70849537140"}
0005432526806	8A0D24	8417 832647	OKSANA KUZMINA	{"phone": "+70087688911"}
0005432526807	9F6C25	0945 416318	ALEKSANDR POPOV	{"phone": "+70448498685"}
0005432526808	9F6C25	5988 117810	LYUBOV ANISIMOVA	{"email": "lanisimova_24071961@postgrespro.ru", "phone": "+70156994186"}
0005432526809	735007	0297 961388	VIKTOR MAKAROV	{"phone": "+70173883165"}
0005432526810	7D7A70	0847 610554	ELINA EGOROVA	{"email": "eegorova081975@postgrespro.ru", "phone": "+70403125785"}
0005432526811	981661	3235 963496	NATALYA VLASOVA	{"phone": "+70344804030"}
0005432526812	579C96	1839 332367	SVETLANA TIMOFEEVA	{"phone": "+70508525908"}
0005432526813	579C96	3930 516651	VLADISLAV NIKITIN	{"phone": "+70635553186"}
0005432526814	0694D3	3196 685234	MARYAM KOROLEVA	{"phone": "+70693436569"}
0005432526815	A8F6F5	6116 096308	EVGENIY SEMENOV	{"email": "esemenov-03121969@postgrespro.ru", "phone": "+70910601208"}
0005432526816	A8F6F5	9080 938143	NATALYA PETROVA	{"email": "n-petrova-05081974@postgrespro.ru", "phone": "+70725404521"}
0005432526817	30A32E	6530 752902	RAISA SOROKINA	{"email": "sorokina-r031975@postgrespro.ru", "phone": "+70141089508"}
0005432526818	033DF1	5562 179752	IRINA NOVIKOVA	{"phone": "+70615550115"}
0005432526819	C46471	7201 035487	EKATERINA NAZAROVA	{"phone": "+70448837320"}
0005432526820	F02833	3995 859575	ANATOLIY ZAKHAROV	{"email": "a_zakharov_1973@postgrespro.ru", "phone": "+70587740763"}
0005432526821	65ACDE	1532 344836	EVGENIY STEPANOV	{"phone": "+70829486051"}
0005432526822	65ACDE	9285 849230	SOFIYA MAKAROVA	{"phone": "+70118398093"}
0005432526823	B42AA1	2363 713408	NATALIYA ORLOVA	{"phone": "+70544515788"}
0005432526824	B42AA1	9340 630989	EVGENIY IVANOV	{"email": "ivanov_e_06101979@postgrespro.ru", "phone": "+70473523562"}
0005432526825	57E3B9	1547 830701	ANDREY VOLKOV	{"phone": "+70813458265"}
0005432526826	57E3B9	5259 144753	ALEKSEY BARANOV	{"email": "baranov-aleksey.071969@postgrespro.ru", "phone": "+70314828535"}
0005432526827	FB6360	3897 221047	SERGEY ZAYCEV	{"phone": "+70654820532"}
0005432526828	64521B	4025 323695	ALEKSANDR VOLKOV	{"email": "a-volkov091970@postgrespro.ru", "phone": "+70238770605"}
0005432526829	64521B	1548 099810	GENNADIY ILIN	{"email": "g_ilin.1979@postgrespro.ru", "phone": "+70571379403"}
0005432526830	464AE8	9127 972357	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev_1971@postgrespro.ru", "phone": "+70561470545"}
0005432526831	10B2B2	7663 506790	EKATERINA FEDOROVA	{"phone": "+70350651009"}
0005432526832	4F7464	9641 106359	ANDREY VASILEV	{"email": "andrey.vasilev_011980@postgrespro.ru", "phone": "+70256105304"}
0005432526833	BD8D60	6274 510390	ALEKSANDRA LUKYANOVA	{"phone": "+70882860621"}
0005432526834	8FE25C	3983 136077	OLGA EGOROVA	{"email": "olga.egorova-1972@postgrespro.ru", "phone": "+70285119455"}
0005432526835	8FE25C	3857 248766	VLADIMIR SOROKIN	{"email": "vladimir.sorokin.1972@postgrespro.ru", "phone": "+70969315096"}
0005432526836	784A2E	4126 556284	GALINA KULIKOVA	{"phone": "+70453830080"}
0005432526837	35E05E	2631 206650	ALEKSANDR MELNIKOV	{"email": "a-melnikov11061975@postgrespro.ru", "phone": "+70706882759"}
0005432526838	358F63	7354 070492	SERGEY BONDARENKO	{"email": "sergey-bondarenko1973@postgrespro.ru", "phone": "+70661379031"}
0005432526839	358F63	8428 296667	YURIY MEDVEDEV	{"phone": "+70031785553"}
0005432526840	84791C	2503 127621	ANATOLIY GAVRILOV	{"phone": "+70461800185"}
0005432526841	C4C959	5884 772729	ALEKSEY AFANASEV	{"phone": "+70348800308"}
0005432526842	476969	6651 726101	ELENA KISELEVA	{"email": "kiseleva.elena081968@postgrespro.ru", "phone": "+70347514735"}
0005432526843	DCEF96	1168 956782	NATALYA TITOVA	{"phone": "+70099526658"}
0005432526844	DCEF96	4124 411484	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-aleksandr_081974@postgrespro.ru", "phone": "+70246781607"}
0005432526845	374697	6558 649569	ANTONINA TROFIMOVA	{"email": "a_trofimova-14071977@postgrespro.ru", "phone": "+70350412198"}
0005432526846	374697	7271 493085	ZHANNA YUDINA	{"phone": "+70083048047"}
0005432526847	AD16B1	3225 129345	IRINA KUZMINA	{"phone": "+70942358430"}
0005432526848	AD16B1	8724 168151	TATYANA KOVALEVA	{"email": "kovaleva_t_121960@postgrespro.ru", "phone": "+70356549439"}
0005432526849	4DDD9D	4214 206732	LYUBOV NAUMOVA	{"phone": "+70736594981"}
0005432526850	E48362	7646 505291	YURIY GORBUNOV	{"email": "y.gorbunov041973@postgrespro.ru", "phone": "+70007905118"}
0005432526851	E48362	5668 430959	MIKHAIL POPOV	{"phone": "+70400598576"}
0005432526852	E48362	5296 924263	ALINA KONOVALOVA	{"email": "a-konovalova-091975@postgrespro.ru", "phone": "+70372772137"}
0005432526853	F03729	5799 021282	VALENTINA SOLOVEVA	{"phone": "+70326047185"}
0005432526854	F03729	0304 576329	ELVIRA PAVLOVA	{"email": "pavlovae1977@postgrespro.ru", "phone": "+70517736935"}
0005432527033	0220F7	6465 996929	ALEKSANDRA KAZAKOVA	{"phone": "+70464320481"}
0005432526855	F03729	7993 540905	MIKHAIL ILIN	{"email": "milin.1971@postgrespro.ru", "phone": "+70247642017"}
0005432526856	3A5645	9461 213598	DARYA BOGDANOVA	{"email": "bogdanova_darya.1969@postgrespro.ru", "phone": "+70187652433"}
0005432526857	1A1645	1938 429945	TATYANA KRASNOVA	{"email": "krasnova.t_111978@postgrespro.ru", "phone": "+70632218686"}
0005432526858	4EF482	9587 322888	OLGA LAZAREVA	{"phone": "+70370288706"}
0005432526859	F642A0	1909 722274	ANDREY AFANASEV	{"phone": "+70417666044"}
0005432526860	F117F8	2533 363114	SERGEY KOZLOV	{"email": "kozlov_s-1963@postgrespro.ru", "phone": "+70735050734"}
0005432526861	46AEA0	4267 866446	ANATOLIY GAVRILOV	{"phone": "+70006892438"}
0005432526862	46AEA0	3594 763996	OLGA EFREMOVA	{"email": "efremovaolga.15111968@postgrespro.ru", "phone": "+70794590358"}
0005432526863	1A2904	2141 239132	IGOR GORBUNOV	{"phone": "+70477427160"}
0005432526864	1A2904	3941 155666	ALEKSANDR ZHUKOV	{"email": "zhukov_a.19081960@postgrespro.ru", "phone": "+70105366701"}
0005432526865	BC1AA0	0382 812502	ELENA ORLOVA	{"phone": "+70069619353"}
0005432526866	BC1AA0	7723 969714	ANNA NAZAROVA	{"phone": "+70140034607"}
0005432526867	28519A	4372 898504	NATALYA NIKITINA	{"phone": "+70186385258"}
0005432526868	A6735D	9893 868782	DMITRIY MATVEEV	{"email": "d_matveev.1978@postgrespro.ru", "phone": "+70596762335"}
0005432526869	A6735D	6740 416080	VERONIKA VASILEVA	{"email": "vasileva.veronika-031971@postgrespro.ru", "phone": "+70733094845"}
0005432526870	321876	1543 510574	NIKOLAY GORBUNOV	{"phone": "+70506655570"}
0005432526871	321876	5358 467930	ALIYA SEMENOVA	{"email": "semenova-a04071972@postgrespro.ru", "phone": "+70159126939"}
0005432526872	FFDA76	3368 191414	NIKOLAY ZAKHAROV	{"phone": "+70529346718"}
0005432526873	FFDA76	5558 909876	LYUDMILA KONDRATEVA	{"email": "lyudmila.kondrateva31071967@postgrespro.ru", "phone": "+70444607377"}
0005432526874	B8B346	4775 786934	LYUDMILA LUKYANOVA	{"email": "lukyanovalyudmila24011977@postgrespro.ru", "phone": "+70594884065"}
0005432526875	676343	7410 611824	RAISA MEDVEDEVA	{"phone": "+70056362655"}
0005432526876	201768	7438 705552	VALENTINA KRASNOVA	{"phone": "+70636397578"}
0005432526877	201768	0111 965964	MAKSIM BARANOV	{"email": "baranovm_1977@postgrespro.ru", "phone": "+70256872068"}
0005432526878	7D5D3B	1917 079615	DENIS BELOV	{"email": "belov_denis-1968@postgrespro.ru", "phone": "+70646693848"}
0005432526879	076EB3	9321 671982	ANASTASIYA IVANOVA	{"phone": "+70754110967"}
0005432526880	E38BB8	9138 537867	ELENA RODIONOVA	{"phone": "+70015874057"}
0005432526881	E38BB8	0880 826401	ANDREY ABRAMOV	{"phone": "+70813936625"}
0005432526882	593484	9493 023834	OLGA BELOVA	{"email": "olga_belova121967@postgrespro.ru", "phone": "+70096238789"}
0005432526883	7C6E3C	0119 651428	NATALYA EGOROVA	{"email": "natalya-egorova_1978@postgrespro.ru", "phone": "+70141447279"}
0005432526884	FAE0FD	6509 919211	GALINA ERMAKOVA	{"email": "ermakova-galina_111965@postgrespro.ru", "phone": "+70967363996"}
0005432526885	3D026D	3985 047698	EKATERINA SMIRNOVA	{"phone": "+70345104495"}
0005432526886	FA6BC0	3121 339401	NATALIYA STEPANOVA	{"email": "nstepanova_041972@postgrespro.ru", "phone": "+70315906792"}
0005432526887	F138D0	3136 116450	TATYANA BORISOVA	{"phone": "+70926368741"}
0005432526888	F138D0	4838 320692	IVAN ILIN	{"email": "ivan.ilin-17021976@postgrespro.ru", "phone": "+70655844212"}
0005432526889	6033FF	5826 300504	ALEKSANDR BORISOV	{"email": "borisov.aleksandr-20041975@postgrespro.ru", "phone": "+70665997686"}
0005432526890	32EAE5	6352 995567	VLADIMIR KULIKOV	{"phone": "+70092423448"}
0005432526891	206DE8	6218 765203	ALEKSANDR BELOV	{"phone": "+70064398791"}
0005432526892	206DE8	1651 819389	SERGEY ANDREEV	{"phone": "+70845659845"}
0005432526893	DF82BF	2537 333366	VALENTINA KOMAROVA	{"email": "komarova_v_1979@postgrespro.ru", "phone": "+70698600100"}
0005432526894	5F15F7	7837 254707	ANTON KAZAKOV	{"phone": "+70324515827"}
0005432526895	834FA9	1722 990425	NIKOLAY POPOV	{"email": "nikolay.popov-071975@postgrespro.ru", "phone": "+70609250699"}
0005432526896	AD0BC4	1204 165346	YURIY ZAYCEV	{"phone": "+70170346290"}
0005432526897	CF4635	8428 856478	DENIS NIKOLAEV	{"phone": "+70977722964"}
0005432526898	CF4635	1422 608175	TATYANA FILIPPOVA	{"phone": "+70061180056"}
0005432526899	734DB2	5337 214451	VLADIMIR SOROKIN	{"email": "vladimirsorokin-101967@postgrespro.ru", "phone": "+70099620709"}
0005432526900	729A48	6811 547559	NIKITA AFANASEV	{"phone": "+70179637231"}
0005432526901	729A48	2289 726808	LYUDMILA MAKSIMOVA	{"phone": "+70221347871"}
0005432526902	3E6828	3857 082105	LIDIYA IVANOVA	{"email": "ivanoval-021966@postgrespro.ru", "phone": "+70139341695"}
0005432526903	01D094	0584 349996	MAKSIM KOZLOV	{"email": "kozlov-m-1976@postgrespro.ru", "phone": "+70133723547"}
0005432526904	D99FED	1725 947234	VLADIMIR VOROBEV	{"email": "v_vorobev_01041975@postgrespro.ru", "phone": "+70568837499"}
0005432527072	6264CA	0234 790099	TATYANA LUKYANOVA	{"phone": "+70838781228"}
0005432526905	807DF6	1464 145837	ALEKSANDRA VOLKOVA	{"email": "aleksandra-volkova_1973@postgrespro.ru", "phone": "+70083998160"}
0005432526906	866769	1106 705094	RAISA KARPOVA	{"phone": "+70537584257"}
0005432526907	866769	5479 365996	OLGA KOVALEVA	{"email": "kovaleva_olga.1977@postgrespro.ru", "phone": "+70055903726"}
0005432526908	1F3F49	2037 913544	MARINA FROLOVA	{"phone": "+70619668805"}
0005432526909	47FCCF	3216 028118	EVGENIY MEDVEDEV	{"phone": "+70626177963"}
0005432526910	47FCCF	9073 169447	TATYANA FILIPPOVA	{"phone": "+70913217895"}
0005432526911	75C1DB	4787 280057	VALENTINA TARASOVA	{"email": "v-tarasova04101962@postgrespro.ru", "phone": "+70073707896"}
0005432526912	2A15E7	3089 387301	NIKITA AFANASEV	{"phone": "+70336551708"}
0005432526913	2A15E7	6454 115792	NIKOLAY MELNIKOV	{"email": "n-melnikov.081965@postgrespro.ru", "phone": "+70761769906"}
0005432526914	9E1F09	3991 257396	MIKHAIL SAVELEV	{"email": "savelev-m-1972@postgrespro.ru", "phone": "+70033046149"}
0005432526916	64C930	3021 353923	LARISA IVANOVA	{"email": "ivanova_l1979@postgrespro.ru", "phone": "+70514159196"}
0005432526917	89429F	3467 543117	NATALYA SERGEEVA	{"email": "n.sergeeva.27041981@postgrespro.ru", "phone": "+70541429707"}
0005432526918	4AC30A	0658 629036	ANTONINA KUZMINA	{"email": "antonina_kuzmina01061969@postgrespro.ru", "phone": "+70775196676"}
0005432526919	4AC30A	4046 475211	ANNA PAVLOVA	{"email": "apavlova.1974@postgrespro.ru", "phone": "+70538736757"}
0005432526920	A83236	9159 798809	ANNA GUSEVA	{"email": "guseva_anna_071965@postgrespro.ru", "phone": "+70733117266"}
0005432526921	ED6B41	7138 788548	ANNA SOLOVEVA	{"email": "anna.soloveva.1966@postgrespro.ru", "phone": "+70119432645"}
0005432526922	ED6B41	9352 787392	ANDREY VLASOV	{"email": "avlasov.1970@postgrespro.ru", "phone": "+70845081492"}
0005432526923	19D8DF	7083 467317	ARTEM SEMENOV	{"phone": "+70753613699"}
0005432526924	B0AB22	8168 516618	VLADIMIR ANTONOV	{"phone": "+70989890135"}
0005432526925	B0AB22	6632 821204	ELENA TIMOFEEVA	{"email": "timofeeva.e_14011987@postgrespro.ru", "phone": "+70530789179"}
0005432526926	B0AB22	2449 563624	MARINA LEBEDEVA	{"email": "marina.lebedeva-03091976@postgrespro.ru", "phone": "+70581042802"}
0005432526927	BE930A	3957 239060	LYUDMILA GAVRILOVA	{"email": "l-gavrilova-26101977@postgrespro.ru", "phone": "+70570880597"}
0005432526928	699BED	3876 828574	NIKOLAY ZAKHAROV	{"email": "n.zakharov-1972@postgrespro.ru", "phone": "+70939175380"}
0005432526929	179952	2350 736912	VLADIMIR IVANOV	{"email": "v.ivanov_1971@postgrespro.ru", "phone": "+70821915563"}
0005432526930	B29C09	1796 288302	OLEG KAZAKOV	{"phone": "+70717315856"}
0005432526931	B29C09	6137 075629	FEDOR PAVLOV	{"phone": "+70078168909"}
0005432526932	ADBDA5	9276 132786	TAISA ALEKSANDROVA	{"email": "aleksandrovat-1972@postgrespro.ru", "phone": "+70851152820"}
0005432526933	8028A1	1850 052313	NIKOLAY VASILEV	{"email": "nikolay-vasilev_1964@postgrespro.ru", "phone": "+70395537430"}
0005432526934	B124A4	4602 266469	NATALYA AFANASEVA	{"phone": "+70557094195"}
0005432526935	B124A4	5332 008480	VALENTIN MAKAROV	{"phone": "+70168378595"}
0005432526936	218453	8131 622524	SVETLANA LAZAREVA	{"phone": "+70411659290"}
0005432526937	E01F5D	6319 519992	NIKOLAY KUZNECOV	{"email": "n_kuznecov04031972@postgrespro.ru", "phone": "+70052361153"}
0005432526938	C98583	3605 094064	VYACHESLAV ISAEV	{"phone": "+70813916301"}
0005432526939	B41561	2723 266288	YULIYA KOVALEVA	{"phone": "+70536053923"}
0005432526940	89950A	4789 919419	SERGEY VASILEV	{"email": "vasilevs_041967@postgrespro.ru", "phone": "+70022183434"}
0005432526941	05FB41	2160 772386	ELENA BORISOVA	{"phone": "+70494578208"}
0005432526942	05FB41	8986 236338	GALINA CHERNOVA	{"phone": "+70718147965"}
0005432526943	BDC298	8687 447589	VITALIY MATVEEV	{"email": "matveevvitaliy_24021969@postgrespro.ru", "phone": "+70074452457"}
0005432526944	0B3D29	8270 607850	NATALYA YAKOVLEVA	{"phone": "+70171309234"}
0005432526945	0B3D29	8194 067281	VYACHESLAV SERGEEV	{"email": "sergeev_v_111966@postgrespro.ru", "phone": "+70200431522"}
0005432526946	91AC0F	1700 251001	YURIY TARASOV	{"phone": "+70738119301"}
0005432526947	91AC0F	8247 819393	ELENA NOVIKOVA	{"phone": "+70774798961"}
0005432526948	56EB6F	7576 893019	DINA SEMENOVA	{"email": "d_semenova-111962@postgrespro.ru", "phone": "+70166231628"}
0005432526949	03EC73	4866 412075	YURIY DENISOV	{"email": "ydenisov.1962@postgrespro.ru", "phone": "+70930583109"}
0005432526950	03EC73	1087 678083	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr-21021968@postgrespro.ru", "phone": "+70476500365"}
0005432526951	1A39A9	3505 979594	LYUBOV RODIONOVA	{"email": "rodionova.lyubov_111977@postgrespro.ru", "phone": "+70793214286"}
0005432526952	ED393E	1107 850860	VLADIMIR DENISOV	{"phone": "+70629124552"}
0005432526953	58C6B7	1266 309057	TAMARA KISELEVA	{"phone": "+70925624537"}
0005432526954	2A1B5E	0672 541553	VALENTINA EFIMOVA	{"email": "efimova_v.051971@postgrespro.ru", "phone": "+70000029423"}
0005432526955	2A1B5E	1320 465617	MARINA EFREMOVA	{"email": "marina_efremova.1981@postgrespro.ru", "phone": "+70158950460"}
0005432526956	ACE156	3927 983792	ANDREY FILIPPOV	{"email": "filippov-andrey.111973@postgrespro.ru", "phone": "+70867076123"}
0005432527236	8DC7FB	3199 062278	ARTEM ABRAMOV	{"phone": "+70134430478"}
0005432526957	ACE156	7685 102411	MIKHAIL MAKAROV	{"email": "makarovm-081966@postgrespro.ru", "phone": "+70976116032"}
0005432526958	AFE8B5	9223 795356	GULSINA LEBEDEVA	{"email": "gulsina.lebedeva071979@postgrespro.ru", "phone": "+70408638056"}
0005432526959	08287F	3447 346370	SERGEY ANDREEV	{"email": "sergey_andreev-021976@postgrespro.ru", "phone": "+70578388495"}
0005432526960	08287F	2201 290577	NINA KOROLEVA	{"email": "korolevan-1973@postgrespro.ru", "phone": "+70368553742"}
0005432526961	5731DF	2558 259553	RAISA KAZAKOVA	{"email": "r_kazakova_1969@postgrespro.ru", "phone": "+70917753231"}
0005432526962	9A36CC	4390 677416	SVETLANA ZAYCEVA	{"email": "zayceva-svetlana.1970@postgrespro.ru", "phone": "+70450767566"}
0005432526963	9A36CC	8851 611707	VYACHESLAV ZHUKOV	{"email": "zhukov_vyacheslav1971@postgrespro.ru", "phone": "+70352211541"}
0005432526964	D69F02	3855 708440	RAFAIL KRASNOV	{"email": "r.krasnov-10101967@postgrespro.ru", "phone": "+70264670013"}
0005432526965	6ACEF7	6261 124731	ANTONINA TIKHONOVA	{"email": "a.tikhonova.1968@postgrespro.ru", "phone": "+70235743747"}
0005432526966	6ACEF7	2240 011505	NIKOLAY MELNIKOV	{"phone": "+70217991985"}
0005432526967	37251C	5984 761556	VYACHESLAV KAZAKOV	{"email": "vkazakov_081965@postgrespro.ru", "phone": "+70187017108"}
0005432526968	F70649	8939 232628	ELENA SEMENOVA	{"email": "semenova-e.121980@postgrespro.ru", "phone": "+70720696961"}
0005432526969	F70649	7854 643775	ROMAN BARANOV	{"email": "baranov-roman-1970@postgrespro.ru", "phone": "+70043682812"}
0005432526970	165EE2	4728 928149	SOFIYA SOLOVEVA	{"phone": "+70209553216"}
0005432526971	A75FAF	8454 780340	VALERIY BORISOV	{"email": "valeriy_borisov.09121969@postgrespro.ru", "phone": "+70690625745"}
0005432526972	A75FAF	9534 613397	MARINA MAKSIMOVA	{"email": "maksimova_m061975@postgrespro.ru", "phone": "+70475935165"}
0005432526973	737EE2	0239 706760	OLGA KUZNECOVA	{"email": "o-kuznecova_27021969@postgrespro.ru", "phone": "+70865366820"}
0005432526974	737EE2	9359 079529	VLADIMIR TIKHONOV	{"phone": "+70122688361"}
0005432526975	737EE2	5249 641566	NIKITA KUZNECOV	{"email": "kuznecov.n121974@postgrespro.ru", "phone": "+70441318174"}
0005432526976	88CE8D	5277 079084	SVETLANA NAZAROVA	{"email": "nazarova-svetlana_1964@postgrespro.ru", "phone": "+70392705392"}
0005432526977	88CE8D	9964 702051	VIKTOR KAZAKOV	{"email": "kazakov.v_1998@postgrespro.ru", "phone": "+70730225587"}
0005432526978	E07576	3123 075286	ROMAN GRIGOREV	{"email": "r_grigorev011989@postgrespro.ru", "phone": "+70017147428"}
0005432526979	850316	8801 876694	ANATOLIY MAKAROV	{"phone": "+70881166916"}
0005432526980	850316	9241 810510	ANASTASIYA FADEEVA	{"email": "fadeevaanastasiya_25071968@postgrespro.ru", "phone": "+70060696988"}
0005432526981	9217D2	1493 445732	TATYANA KOZLOVA	{"email": "tatyana-kozlova_1966@postgrespro.ru", "phone": "+70927358263"}
0005432526982	95EF77	9634 010882	NIKOLAY MEDVEDEV	{"email": "medvedev_n.1976@postgrespro.ru", "phone": "+70755879574"}
0005432526983	F936AB	3616 344525	TATYANA POPOVA	{"email": "t_popova-1966@postgrespro.ru", "phone": "+70221410516"}
0005432526984	7D0DD0	7208 845135	ALEKSANDR VLASOV	{"email": "vlasov-a-17051982@postgrespro.ru", "phone": "+70887498887"}
0005432526985	7D0DD0	0165 598185	NATALYA VASILEVA	{"phone": "+70239902810"}
0005432526986	696847	6454 288572	ILYA MATVEEV	{"phone": "+70555108341"}
0005432526987	46DB6C	6498 760326	EKATERINA TITOVA	{"phone": "+70019654451"}
0005432526988	15C541	8006 422538	VYACHESLAV PAVLOV	{"phone": "+70405317619"}
0005432526989	BCFE55	9022 804006	ANDREY FEDOROV	{"phone": "+70292375302"}
0005432526990	BCFE55	7124 880173	EKATERINA MOROZOVA	{"email": "ekaterina_morozova_121972@postgrespro.ru", "phone": "+70831273317"}
0005432526991	2184FF	1575 914881	IRINA PAVLOVA	{"phone": "+70672941322"}
0005432526992	1D0D33	9377 053618	LYUBOV ANISIMOVA	{"email": "anisimoval-13011975@postgrespro.ru", "phone": "+70920945781"}
0005432526993	814018	3064 195632	ALEFTINA NOVIKOVA	{"phone": "+70331088216"}
0005432526994	E74BC7	3368 077584	VLADIMIR KULIKOV	{"phone": "+70630660130"}
0005432526995	D12B0A	7690 139177	VALERIY SCHERBAKOV	{"email": "v_scherbakov-19011984@postgrespro.ru", "phone": "+70321921751"}
0005432526996	B61599	6908 112985	DMITRIY FILIPPOV	{"phone": "+70412332970"}
0005432526997	F57211	1534 883725	VIKTOR KOZLOV	{"email": "kozlov.viktor061963@postgrespro.ru", "phone": "+70820366850"}
0005432526998	D22860	7050 483298	ANNA OVCHINNIKOVA	{"phone": "+70141363723"}
0005432526999	D22860	5223 228431	ALEKSANDR MATVEEV	{"phone": "+70400651104"}
0005432527000	F5439F	5911 482507	MIKHAIL KUZNECOV	{"email": "kuznecovm_011975@postgrespro.ru", "phone": "+70988004190"}
0005432527001	F5439F	5952 332765	YULIYA GORBUNOVA	{"email": "gorbunovayuliya111966@postgrespro.ru", "phone": "+70673087417"}
0005432527002	54079B	8539 551466	LYUDMILA RYABOVA	{"phone": "+70965301559"}
0005432527003	54079B	3289 490945	NINA KUZNECOVA	{"phone": "+70065988284"}
0005432527004	BFE79B	1585 309169	ALEKSANDR MAKAROV	{"phone": "+70342578165"}
0005432527005	BFE79B	8428 275555	SERGEY GORBUNOV	{"email": "sergey.gorbunov_081968@postgrespro.ru", "phone": "+70266648603"}
0005432527006	BFE79B	9617 712266	ALEKSANDR PETROV	{"phone": "+70105841822"}
0005432527007	9CC58A	6944 674714	ALEKSANDR MIRONOV	{"email": "a.mironov_1971@postgrespro.ru", "phone": "+70947387634"}
0005432527008	9CC58A	7108 056518	ARTEM ILIN	{"phone": "+70218562042"}
0005432527009	C3989D	9321 643455	LYUDMILA VASILEVA	{"email": "vasileva-l_1965@postgrespro.ru", "phone": "+70883709810"}
0005432527010	C3989D	8160 388485	OLGA SEMENOVA	{"email": "o_semenova-071974@postgrespro.ru", "phone": "+70414352555"}
0005432527011	47F22E	3585 638479	ALEKSEY IVANOV	{"email": "aivanov.26021965@postgrespro.ru", "phone": "+70706059343"}
0005432527012	85F10A	7336 520373	PAVEL MAKSIMOV	{"email": "p_maksimov-16041966@postgrespro.ru", "phone": "+70707036433"}
0005432527013	85F10A	5963 301603	ILYA IVANOV	{"phone": "+70948955544"}
0005432527014	609DFC	2579 291635	IRINA NIKOLAEVA	{"email": "nikolaeva_irina13111966@postgrespro.ru", "phone": "+70397755493"}
0005432527015	609DFC	9063 650386	LYUDMILA FEDOROVA	{"email": "fedorova.l.091971@postgrespro.ru", "phone": "+70699231722"}
0005432527016	B9EED0	5368 689470	NATALYA IVANOVA	{"phone": "+70698632847"}
0005432527017	B9EED0	0797 984718	ANNA VOROBEVA	{"phone": "+70061602309"}
0005432527018	0F56B5	6470 795347	IGOR RODIONOV	{"email": "rodionov_igor27021966@postgrespro.ru", "phone": "+70452185611"}
0005432527019	0F56B5	6477 607556	LYUBOV MAKSIMOVA	{"phone": "+70101929352"}
0005432527020	0F56B5	1659 856008	ALEKSANDR VASILEV	{"phone": "+70759076968"}
0005432527021	D41621	2190 584130	ANNA GRISHINA	{"phone": "+70973594183"}
0005432527022	4D9226	0938 442194	VALENTINA ARKHIPOVA	{"phone": "+70774651485"}
0005432527023	F70EC6	7029 559160	ALFIYA ZAKHAROVA	{"email": "zakharova_alfiya-1974@postgrespro.ru", "phone": "+70192144451"}
0005432527024	A73212	9704 499880	IRINA SIDOROVA	{"phone": "+70332122992"}
0005432527025	FCE013	3803 658135	VLADIMIR FILIPPOV	{"phone": "+70810552775"}
0005432527026	88CCA9	9332 221089	ILYA SERGEEV	{"email": "ilyasergeev_021982@postgrespro.ru", "phone": "+70523032897"}
0005432527027	A5429F	2031 320570	MARIYA EFIMOVA	{"phone": "+70600271911"}
0005432527028	B0E65B	1509 910157	ALEKSANDR EGOROV	{"email": "a_egorov1978@postgrespro.ru", "phone": "+70105099779"}
0005432527029	072F26	2909 322540	VIKTORIYA RODIONOVA	{"email": "v.rodionova-101966@postgrespro.ru", "phone": "+70998515044"}
0005432527030	072F26	5317 321142	KLAVDIYA KONDRATEVA	{"phone": "+70172271835"}
0005432527031	072F26	8605 392513	ARTEM KUZMIN	{"phone": "+70230216189"}
0005432527032	D37D62	6331 016870	ANASTASIYA BORISOVA	{"phone": "+70537652080"}
0005432527034	0220F7	4963 343599	MAKSIM MELNIKOV	{"email": "melnikov-maksim_04051966@postgrespro.ru", "phone": "+70485944344"}
0005432527035	08862D	8513 074656	TATYANA SOROKINA	{"email": "sorokina_tatyana.16081976@postgrespro.ru", "phone": "+70653915020"}
0005432527036	D950D2	6557 445928	ANDREY KULIKOV	{"email": "kulikova011973@postgrespro.ru", "phone": "+70450569519"}
0005432527037	D950D2	9020 038881	VYACHESLAV SIDOROV	{"email": "vyacheslav_sidorov.061966@postgrespro.ru", "phone": "+70189569109"}
0005432527038	D950D2	0272 099935	EKATERINA ZAYCEVA	{"email": "e_zayceva1968@postgrespro.ru", "phone": "+70311557356"}
0005432527039	6E2352	5574 922856	PAVEL SIDOROV	{"phone": "+70891868071"}
0005432527040	76E21E	9265 637170	DENIS YAKOVLEV	{"phone": "+70055148551"}
0005432527041	AD3869	3293 571323	DMITRIY NOVIKOV	{"phone": "+70242569597"}
0005432527042	AD3869	5271 681098	NATALYA MIKHAYLOVA	{"email": "natalya_mikhaylova.091966@postgrespro.ru", "phone": "+70007464131"}
0005432527043	6A32E7	5443 479214	ELENA BARANOVA	{"email": "elena-baranova05031971@postgrespro.ru", "phone": "+70978363027"}
0005432527044	6A32E7	5901 555330	TATYANA ZAKHAROVA	{"phone": "+70029968981"}
0005432527045	3FB9D7	6325 270421	NINA YAKOVLEVA	{"phone": "+70965295506"}
0005432527046	8E6C4C	4410 449490	YULIYA FROLOVA	{"phone": "+70734775887"}
0005432527047	547B27	3465 383084	RUSLAN TIKHONOV	{"email": "tikhonov.ruslan_1965@postgrespro.ru", "phone": "+70791407094"}
0005432527048	547B27	7003 852893	VLADIMIR IVANOV	{"email": "ivanovv_31121978@postgrespro.ru", "phone": "+70375144611"}
0005432527049	547B27	6539 546124	ELENA FEDOROVA	{"phone": "+70221617709"}
0005432527050	DD0345	7204 683894	OLGA SAVELEVA	{"email": "olga-saveleva.29091976@postgrespro.ru", "phone": "+70168203382"}
0005432527051	2ADC95	4264 704186	PRASKOVYA DENISOVA	{"phone": "+70062408874"}
0005432527052	0DA05F	8908 218743	EKATERINA DENISOVA	{"phone": "+70846371937"}
0005432527053	78D73C	7115 500786	TATYANA OVCHINNIKOVA	{"phone": "+70835296772"}
0005432527054	78D73C	9367 426698	MIKHAIL GRIGOREV	{"phone": "+70958715658"}
0005432527055	A454D7	5036 068108	SERGEY GORBUNOV	{"email": "sergey_gorbunov_1970@postgrespro.ru", "phone": "+70577285229"}
0005432527056	A454D7	6608 111392	ANATOLIY KISELEV	{"phone": "+70871040719"}
0005432527057	A3C1A7	1807 215153	TATYANA FOMINA	{"email": "fomina_t121971@postgrespro.ru", "phone": "+70939338995"}
0005432527058	601ECE	5577 963433	ANTON GAVRILOV	{"email": "gavrilovanton-101966@postgrespro.ru", "phone": "+70248751760"}
0005432527059	C28D91	8929 525613	ELENA KUZNECOVA	{"phone": "+70348461534"}
0005432527060	C28D91	1032 965001	ALEKSANDR KRASNOV	{"phone": "+70399451555"}
0005432527061	C28D91	0204 617525	ALEKSANDR MATVEEV	{"email": "amatveev-03061970@postgrespro.ru", "phone": "+70256795037"}
0005432527062	F69C77	6930 004801	IGOR MIKHAYLOV	{"phone": "+70032700023"}
0005432527063	5437DD	4181 236099	TATYANA KULIKOVA	{"phone": "+70616268440"}
0005432527064	1525AE	0513 793596	VALERIY VOROBEV	{"phone": "+70866887667"}
0005432527065	1525AE	7267 099199	ANDREY BELOV	{"phone": "+70406095118"}
0005432527066	1ACA12	7147 649771	YURIY BARANOV	{"phone": "+70230953543"}
0005432527067	DD6F8E	0988 908322	PAVEL OSIPOV	{"email": "osipov-pavel_1975@postgrespro.ru", "phone": "+70851378155"}
0005432527068	DD6F8E	0960 456246	OKSANA KUZNECOVA	{"email": "o-kuznecova-19081974@postgrespro.ru", "phone": "+70623550006"}
0005432527069	DD6F8E	7686 888487	OLGA FEDOROVA	{"email": "ofedorova031978@postgrespro.ru", "phone": "+70787288776"}
0005432527070	90F246	8849 880522	SERGEY ZAYCEV	{"email": "szaycev-27121967@postgrespro.ru", "phone": "+70784950400"}
0005432527071	F011C0	0345 140474	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko-1957@postgrespro.ru", "phone": "+70507165822"}
0005432527073	BEEDD9	7623 915557	KARINA TIKHONOVA	{"phone": "+70143680549"}
0005432527074	BAD61E	1658 629166	TATYANA MELNIKOVA	{"phone": "+70444999102"}
0005432527075	BAD61E	9636 554172	TATYANA FADEEVA	{"email": "fadeeva_t-1985@postgrespro.ru", "phone": "+70538195198"}
0005432527076	4EFA65	2728 409605	VIKTORIYA PAVLOVA	{"email": "pavlova_v_031979@postgrespro.ru", "phone": "+70371157053"}
0005432527077	A5C178	0608 044717	NIKOLAY SOROKIN	{"phone": "+70436296580"}
0005432527078	69E765	7357 777852	ANATOLIY ZAYCEV	{"phone": "+70924568429"}
0005432527079	A45E5B	8807 590278	ELENA MAKAROVA	{"phone": "+70104686992"}
0005432527080	6BBF7C	4662 600028	ALINA ZAKHAROVA	{"phone": "+70535662534"}
0005432527081	6BBF7C	1555 958702	NIKOLAY MOROZOV	{"phone": "+70225638268"}
0005432527082	6BBF7C	9254 245636	VASILIY FILIPPOV	{"phone": "+70181558153"}
0005432527083	7D4E54	4174 979772	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-05011971@postgrespro.ru", "phone": "+70363990037"}
0005432527084	EB9676	7968 386350	DMITRIY SERGEEV	{"email": "dmitriysergeev.021969@postgrespro.ru", "phone": "+70669912811"}
0005432527085	EB9676	4852 334080	ELENA FADEEVA	{"phone": "+70912649485"}
0005432527086	E456CD	0480 672372	VITALIY MELNIKOV	{"phone": "+70814894358"}
0005432527087	E456CD	3001 768255	ANASTASIYA FROLOVA	{"email": "anastasiyafrolova08061973@postgrespro.ru", "phone": "+70345407646"}
0005432527088	207AFA	5252 186710	MARINA OSIPOVA	{"email": "osipovamarina.091969@postgrespro.ru", "phone": "+70268619209"}
0005432527089	4706D0	1599 727726	MARIYA NIKIFOROVA	{"email": "nikiforova_m.14101974@postgrespro.ru", "phone": "+70862064687"}
0005432527090	4706D0	5117 966121	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.1984@postgrespro.ru", "phone": "+70960753078"}
0005432527091	86A99C	0995 593186	KSENIYA MAKAROVA	{"email": "makarova_kseniya12081979@postgrespro.ru", "phone": "+70430458047"}
0005432527092	B6D2DE	0610 115012	YAKOV SOROKIN	{"email": "yakov-sorokin_1973@postgrespro.ru", "phone": "+70476884332"}
0005432527093	76E0D7	3600 467059	ILYA RODIONOV	{"email": "i-rodionov.1974@postgrespro.ru", "phone": "+70611645470"}
0005432527094	CBFB42	7680 131630	GALINA SERGEEVA	{"phone": "+70116872080"}
0005432527095	CBFB42	8417 540308	ALEKSEY SIDOROV	{"phone": "+70983014190"}
0005432527096	966154	0607 444558	VYACHESLAV FEDOROV	{"email": "fedorov.v1965@postgrespro.ru", "phone": "+70314304911"}
0005432527097	0C9781	3564 375507	ALEKSEY ZHURAVLEV	{"email": "a_zhuravlev.09011967@postgrespro.ru", "phone": "+70842418443"}
0005432527098	5F9D92	1529 491013	NIKOLAY MOROZOV	{"email": "morozov_n.1966@postgrespro.ru", "phone": "+70387355363"}
0005432527099	3DB5B7	0190 598926	EVGENIYA MIKHAYLOVA	{"email": "evgeniya_mikhaylova1963@postgrespro.ru", "phone": "+70655413717"}
0005432527100	D30AC5	7441 842762	VLADIMIR NAUMOV	{"email": "vladimir-naumov.111972@postgrespro.ru", "phone": "+70681264443"}
0005432527101	D30AC5	7928 938208	ANNA SCHERBAKOVA	{"phone": "+70911649104"}
0005432527102	1BA5D1	9310 175569	OLEG MIKHAYLOV	{"email": "mikhaylovoleg_071978@postgrespro.ru", "phone": "+70191105726"}
0005432527103	876506	9457 758784	SVETLANA ERMAKOVA	{"email": "ermakova.svetlana-14011974@postgrespro.ru", "phone": "+70599415252"}
0005432527104	FDD76D	6694 367155	YULIYA FROLOVA	{"phone": "+70502290180"}
0005432527105	2AAF06	0981 862854	ALEKSANDR TIKHONOV	{"phone": "+70785955546"}
0005432527106	B053EF	7381 900996	ALBINA LEBEDEVA	{"email": "lebedeva-a.19081962@postgrespro.ru", "phone": "+70969545686"}
0005432527107	B053EF	5611 274577	KONSTANTIN KOZLOV	{"email": "kkozlov24111983@postgrespro.ru", "phone": "+70674877975"}
0005432527108	7DEFEB	7045 820597	ALEKSEY ZAKHAROV	{"phone": "+70648918544"}
0005432527109	7DEFEB	8051 916900	ELENA STEPANOVA	{"phone": "+70135918099"}
0005432527110	0A3BAC	7829 893001	SERGEY POPOV	{"email": "s-popov1969@postgrespro.ru", "phone": "+70105895923"}
0005432527111	0A3BAC	9183 635627	OLGA GAVRILOVA	{"email": "gavrilova_olga.25051961@postgrespro.ru", "phone": "+70483760197"}
0005432527112	388E77	1494 851572	IRINA MELNIKOVA	{"email": "melnikova-i_1985@postgrespro.ru", "phone": "+70067744533"}
0005432527113	388E77	8466 100182	ALEKSEY MELNIKOV	{"email": "aleksey.melnikov1982@postgrespro.ru", "phone": "+70181974195"}
0005432527114	E12F5B	3796 194170	IGOR ZAYCEV	{"email": "zaycev-igor1972@postgrespro.ru", "phone": "+70524614705"}
0005432527115	E12F5B	6590 382627	RAMIS NOVIKOV	{"phone": "+70698485148"}
0005432527116	17E1F0	5178 733583	ALEKSEY GERASIMOV	{"email": "gerasimov.a_30111983@postgrespro.ru", "phone": "+70204548004"}
0005432527117	F6E2F0	7200 877733	DMITRIY SCHERBAKOV	{"phone": "+70494658237"}
0005432527118	B021C7	0551 603974	ARSENIY ALEKSEEV	{"email": "alekseeva-081971@postgrespro.ru", "phone": "+70874965166"}
0005432527119	5BC80C	8791 711308	RUSLAN MIRONOV	{"phone": "+70917185463"}
0005432527120	31D1A2	4156 385481	NIKOLAY BARANOV	{"phone": "+70729993711"}
0005432527121	31D1A2	0381 518043	RAMIS SOLOVEV	{"email": "rsolovev1969@postgrespro.ru", "phone": "+70576693547"}
0005432527122	AF9B18	6956 452301	ARTUR IVANOV	{"email": "artur.ivanov_091972@postgrespro.ru", "phone": "+70451552625"}
0005432527123	BBD296	2919 718250	MARIYA VOLKOVA	{"email": "volkova_m.1961@postgrespro.ru", "phone": "+70716126337"}
0005432527124	34AABB	7740 518784	SERGEY FEDOROV	{"email": "sfedorov-1980@postgrespro.ru", "phone": "+70822880468"}
0005432527125	608A37	5878 199529	LIDIYA IVANOVA	{"email": "l-ivanova-121975@postgrespro.ru", "phone": "+70900273426"}
0005432527126	C836BC	1593 352566	DANIIL MAKAROV	{"email": "daniil_makarov1970@postgrespro.ru", "phone": "+70579288289"}
0005432527127	C836BC	7369 529894	EGOR MOROZOV	{"phone": "+70940256256"}
0005432527128	13D9E0	3640 326076	MARAT ILIN	{"email": "marat-ilin021969@postgrespro.ru", "phone": "+70363228749"}
0005432527129	13D9E0	8262 487833	SERGEY YAKOVLEV	{"email": "yakovlevsergey.20101975@postgrespro.ru", "phone": "+70528368428"}
0005432527130	13D9E0	1434 985717	NATALIYA NIKOLAEVA	{"phone": "+70625262628"}
0005432527131	4BF52D	9105 968764	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr-021978@postgrespro.ru", "phone": "+70017343474"}
0005432527132	864F9A	7286 661057	LYUBOV IVANOVA	{"phone": "+70365647335"}
0005432527133	0B52F7	4895 860201	SVETLANA ZHUKOVA	{"email": "svetlanazhukova_15061971@postgrespro.ru", "phone": "+70102647296"}
0005432527134	0B52F7	2201 717678	TATYANA YAKOVLEVA	{"phone": "+70313175020"}
0005432527135	0B52F7	0286 216887	ELENA SMIRNOVA	{"phone": "+70964715977"}
0005432527136	1480FB	0546 551597	NATALYA NESTEROVA	{"phone": "+70628921961"}
0005432527137	1480FB	2583 999886	NATALYA DENISOVA	{"phone": "+70320025751"}
0005432527138	260440	4240 754444	SOFYA MOISEEVA	{"phone": "+70591180088"}
0005432527139	44F709	3582 002240	ELENA SEMENOVA	{"phone": "+70099792054"}
0005432527140	8131A1	0501 906523	NADEZHDA YUDINA	{"phone": "+70647542596"}
0005432527141	ED3243	4571 626530	MAKSIM FILIPPOV	{"phone": "+70209549319"}
0005432527142	8A11E2	2744 057805	GEORGIY MAKSIMOV	{"email": "maksimovgeorgiy-121969@postgrespro.ru", "phone": "+70691680733"}
0005432527143	7F5820	0633 417618	EVGENIY PAVLOV	{"email": "pavlov.e1964@postgrespro.ru", "phone": "+70427793961"}
0005432527144	A0C73C	9741 187106	ALEKSEY PAVLOV	{"phone": "+70914009521"}
0005432527145	FDD9AD	5042 523708	ANDREY MIKHAYLOV	{"email": "a_mikhaylov.18081977@postgrespro.ru", "phone": "+70850628809"}
0005432527146	FDD9AD	5296 155376	OLGA KOVALEVA	{"email": "okovaleva16021965@postgrespro.ru", "phone": "+70187603499"}
0005432527147	783F80	0863 618944	ANNA BORISOVA	{"email": "borisovaa-1970@postgrespro.ru", "phone": "+70259139394"}
0005432527148	783F80	2249 388543	DMITRIY KARPOV	{"email": "dmitriy_karpov1964@postgrespro.ru", "phone": "+70441377884"}
0005432527149	9BBB59	7996 737122	PETR PETROV	{"phone": "+70654065344"}
0005432527150	9BBB59	3730 078177	NINA ANDREEVA	{"email": "andreevan_12061989@postgrespro.ru", "phone": "+70001418956"}
0005432527151	A118B5	6863 465244	VIKTORIYA BELOVA	{"phone": "+70571492732"}
0005432527152	A118B5	2076 548306	POLINA SMIRNOVA	{"email": "smirnova-p_021963@postgrespro.ru", "phone": "+70782644188"}
0005432527153	8B91E9	7539 297656	EKATERINA SIDOROVA	{"email": "e.sidorova.15111969@postgrespro.ru", "phone": "+70767147371"}
0005432527154	D2545F	8541 921957	ANNA VOROBEVA	{"phone": "+70641492406"}
0005432527155	F47D9A	4097 885369	VIKTORIYA POPOVA	{"email": "viktoriya.popova.101979@postgrespro.ru", "phone": "+70332770508"}
0005432527156	F47D9A	5348 030958	EKATERINA SOROKINA	{"email": "sorokina_ekaterina_031973@postgrespro.ru", "phone": "+70728706257"}
0005432527157	7DA3B8	8347 184985	NIKOLAY KUZNECOV	{"phone": "+70140518765"}
0005432527158	7DA3B8	2415 976199	SALAVAT VASILEV	{"email": "salavat_vasilev.031975@postgrespro.ru", "phone": "+70772623000"}
0005432527159	0B126C	8504 146300	ANDREY VOROBEV	{"phone": "+70272948168"}
0005432527160	13A500	5337 387432	TATYANA ANDREEVA	{"phone": "+70128423757"}
0005432527161	8EB0F2	8934 341590	NIKITA NIKOLAEV	{"email": "nikolaev-n23021989@postgrespro.ru", "phone": "+70289436319"}
0005432527162	B82C15	8593 971212	TAMARA ROMANOVA	{"phone": "+70867536459"}
0005432527163	01F789	6195 597381	PETR CHERNOV	{"email": "chernov.petr-28111977@postgrespro.ru", "phone": "+70676634196"}
0005432527164	F55501	2151 461419	GENNADIY SOROKIN	{"phone": "+70232036399"}
0005432527165	F732D2	3916 581752	NATALYA ORLOVA	{"phone": "+70983883032"}
0005432527166	F732D2	7433 898286	EKATERINA PAVLOVA	{"email": "pavlova.ekaterina_051969@postgrespro.ru", "phone": "+70078694115"}
0005432527167	F12915	2814 089427	KSENIYA YAKOVLEVA	{"phone": "+70794145425"}
0005432527168	916C53	8514 101627	NIKITA KAZAKOV	{"email": "kazakovn_081971@postgrespro.ru", "phone": "+70244167093"}
0005432527169	38337F	7287 069563	VLADISLAV ZHURAVLEV	{"email": "zhuravlev.v-15031979@postgrespro.ru", "phone": "+70598683066"}
0005432527170	1BBC0A	1929 317799	NATALYA BELYAEVA	{"email": "n-belyaeva1971@postgrespro.ru", "phone": "+70826420714"}
0005432527171	1BBC0A	1131 470816	GRIGORIY SOLOVEV	{"email": "g-solovev_12061976@postgrespro.ru", "phone": "+70428117756"}
0005432527172	2DE9A7	3129 159873	VALENTINA IVANOVA	{"phone": "+70799302551"}
0005432527173	992925	3870 233448	ALEKSANDRA KUZNECOVA	{"phone": "+70423093301"}
0005432527174	992925	6328 693743	NATALYA PAVLOVA	{"email": "n_pavlova14101967@postgrespro.ru", "phone": "+70325902704"}
0005432527175	EAC266	5513 525029	SERGEY SHEVCHENKO	{"email": "shevchenko.s_1975@postgrespro.ru", "phone": "+70186936457"}
0005432527176	E57BB3	1432 963289	SOFYA SIDOROVA	{"email": "sofya_sidorova_04121965@postgrespro.ru", "phone": "+70334201339"}
0005432527177	4555DE	8228 378734	IVAN ZHURAVLEV	{"email": "zhuravlevivan-1969@postgrespro.ru", "phone": "+70825998959"}
0005432527178	6F9A7D	2528 255474	ALEKSEY ZAKHAROV	{"phone": "+70110492085"}
0005432527179	ED08A1	3508 374607	MAKSIM KUZNECOV	{"phone": "+70240415128"}
0005432527180	81F714	3991 772746	KONSTANTIN MEDVEDEV	{"email": "konstantinmedvedev101971@postgrespro.ru", "phone": "+70039407433"}
0005432527181	A726CB	3168 491738	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova-1980@postgrespro.ru", "phone": "+70554910436"}
0005432527182	76F6A5	5581 415602	PAVEL FEDOROV	{"email": "fedorov_p02121973@postgrespro.ru", "phone": "+70013188849"}
0005432527183	50D8C9	8267 268582	OLGA ABRAMOVA	{"phone": "+70531593343"}
0005432527184	50D8C9	9763 837130	YURIY KUZMIN	{"phone": "+70213319429"}
0005432527185	50D8C9	1239 998182	ANATOLIY BELOV	{"email": "a_belov101979@postgrespro.ru", "phone": "+70290839939"}
0005432527186	6DB9DF	8837 142889	ANDREY SOROKIN	{"email": "sorokin.a-1983@postgrespro.ru", "phone": "+70392512548"}
0005432527187	1F9BF1	3143 172384	ANTON GRIGOREV	{"email": "anton_grigorev.1971@postgrespro.ru", "phone": "+70044559961"}
0005432527188	7E78D4	9621 161448	ALEKSANDR MOROZOV	{"email": "a-morozov.08111969@postgrespro.ru", "phone": "+70273317612"}
0005432527189	F0D67D	7310 669543	GALINA ISAEVA	{"email": "isaevag.17021974@postgrespro.ru", "phone": "+70356805526"}
0005432527190	B2A3DC	8369 799309	TATYANA TARASOVA	{"phone": "+70832768711"}
0005432527191	9C9F39	3143 578038	ALENA LAZAREVA	{"email": "lazareva_alena-011980@postgrespro.ru", "phone": "+70451860277"}
0005432527192	D5DB0D	5951 349656	REGINA KONDRATEVA	{"phone": "+70222647777"}
0005432527193	FAF765	4616 150741	ALEKSANDR IVANOV	{"email": "ivanov.a-091964@postgrespro.ru", "phone": "+70972490392"}
0005432527194	4FF02F	3896 944145	ELENA MAKAROVA	{"phone": "+70712524513"}
0005432527195	AF2ACF	7040 361164	ILNAR SIDOROV	{"phone": "+70821088754"}
0005432527196	10E99F	0948 277308	ALENA MIRONOVA	{"email": "alena_mironova.091977@postgrespro.ru", "phone": "+70698111597"}
0005432527197	10E99F	2216 680801	DMITRIY SCHERBAKOV	{"phone": "+70120348698"}
0005432527198	5EF556	2847 693648	ILYA VLASOV	{"email": "vlasov.ilya-1981@postgrespro.ru", "phone": "+70204937994"}
0005432527199	5EF556	6812 117279	LYUDMILA SIDOROVA	{"phone": "+70086212132"}
0005432527200	220E01	5113 157389	SERGEY KULIKOV	{"phone": "+70027255440"}
0005432527201	220E01	8005 647764	IVAN BORISOV	{"phone": "+70414756328"}
0005432527202	1D7BE1	3083 964041	GRIGORIY SAVELEV	{"email": "g_savelev_15091964@postgrespro.ru", "phone": "+70127627914"}
0005432527203	5CA6F0	4905 707622	NIKOLAY MAKSIMOV	{"phone": "+70162635851"}
0005432527204	AA9921	8828 582424	TATYANA VOLKOVA	{"email": "volkova_tatyana-1972@postgrespro.ru", "phone": "+70084724037"}
0005432527205	AA9921	9261 510946	NADEZHDA FEDOROVA	{"email": "fedorova-n_1976@postgrespro.ru", "phone": "+70781432717"}
0005432527206	2AD276	2825 171666	SERGEY PAVLOV	{"phone": "+70289545271"}
0005432527207	2AD276	4789 121639	ALENA NOVIKOVA	{"email": "alena.novikova1968@postgrespro.ru", "phone": "+70905947594"}
0005432527208	88F14E	2882 550563	SERGEY IVANOV	{"phone": "+70596502424"}
0005432527209	8ADACC	2364 517155	ALEKSEY ILIN	{"email": "ilin_aleksey26031979@postgrespro.ru", "phone": "+70923332127"}
0005432527210	0A6971	2605 387281	VITALIY KOZLOV	{"email": "kozlov-v_1987@postgrespro.ru", "phone": "+70662026207"}
0005432527211	409D55	5439 376089	ANZHELIKA NESTEROVA	{"phone": "+70838588821"}
0005432527212	E7D11B	4106 172663	YURIY NIKOLAEV	{"phone": "+70972620309"}
0005432527213	E7D11B	5341 338781	VLADIMIR POPOV	{"phone": "+70333151662"}
0005432527214	E7D11B	4230 542438	TATYANA ALEKSEEVA	{"phone": "+70457408831"}
0005432527215	688C03	4984 844185	ELIZAVETA BORISOVA	{"email": "borisova-e.03071970@postgrespro.ru", "phone": "+70626938870"}
0005432527216	5BF04B	4894 543347	RAISA KAZAKOVA	{"phone": "+70462972404"}
0005432527217	A37199	8326 938213	EVGENIY ALEKSEEV	{"email": "evgeniy-alekseev1987@postgrespro.ru", "phone": "+70484377114"}
0005432527218	430E02	4375 666352	MARIYA PETROVA	{"phone": "+70457323710"}
0005432527219	430E02	9784 215365	YURIY NAZAROV	{"phone": "+70674790077"}
0005432527220	79021E	6126 877483	ILYAS ROMANOV	{"email": "ilyas-romanov.011971@postgrespro.ru", "phone": "+70463280438"}
0005432527221	01BE65	0675 917147	TAMARA ZAYCEVA	{"email": "t-zayceva23121985@postgrespro.ru", "phone": "+70469588244"}
0005432527222	01BE65	7508 772237	NINA VASILEVA	{"phone": "+70660884597"}
0005432527223	F32FEC	7286 833641	VALENTIN DENISOV	{"email": "valentin-denisov_041979@postgrespro.ru", "phone": "+70242325273"}
0005432527224	BAC7DB	5359 235848	SERGEY SCHERBAKOV	{"email": "sscherbakov.041979@postgrespro.ru", "phone": "+70361609173"}
0005432527225	A6FD60	8215 233038	TATYANA SOROKINA	{"email": "sorokina.tatyana-05011968@postgrespro.ru", "phone": "+70502053816"}
0005432527226	C5A483	6355 000905	LYUBOV OSIPOVA	{"email": "lyubov-osipova_16051976@postgrespro.ru", "phone": "+70467060679"}
0005432527227	B14053	2851 151834	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir_051972@postgrespro.ru", "phone": "+70332741720"}
0005432527228	DF1546	7020 571850	ARINA IVANOVA	{"phone": "+70935367691"}
0005432527229	E281B1	2159 166347	LYUDMILA BELYAEVA	{"email": "belyaeva_l1970@postgrespro.ru", "phone": "+70422798604"}
0005432527230	F32A1E	8218 594477	DARYA BOGDANOVA	{"email": "darya.bogdanova.1985@postgrespro.ru", "phone": "+70139258163"}
0005432527231	F32A1E	8265 066039	VITALIY BORISOV	{"email": "v.borisov.1979@postgrespro.ru", "phone": "+70014442337"}
0005432527232	5B071F	0204 403131	ANASTASIYA GORBUNOVA	{"email": "gorbunova.a_051968@postgrespro.ru", "phone": "+70402170560"}
0005432527233	5B071F	4622 731503	NINA TITOVA	{"phone": "+70904717750"}
0005432527234	B36AB7	3194 628249	VIKTOR FEDOTOV	{"phone": "+70147486747"}
0005432527235	B36AB7	3744 950757	VALENTINA MAKSIMOVA	{"email": "maksimova.v15011974@postgrespro.ru", "phone": "+70393170671"}
0005432527237	527B7C	8728 219398	NIKOLAY VASILEV	{"email": "n_vasilev-081965@postgrespro.ru", "phone": "+70854111518"}
0005432527238	A49CF5	2306 957419	LARISA BORISOVA	{"phone": "+70360042907"}
0005432527239	E02C59	3651 368826	SERGEY MEDVEDEV	{"phone": "+70651620817"}
0005432527240	53A391	0619 910018	VERONIKA ILINA	{"phone": "+70413868173"}
0005432527241	301DFE	6049 066785	OLGA SOKOLOVA	{"email": "o-sokolova-1969@postgrespro.ru", "phone": "+70832242360"}
0005432527242	1A2751	7886 607414	VLADIMIR SERGEEV	{"phone": "+70369973893"}
0005432527243	85BF1F	7889 909088	EVGENIY KUZNECOV	{"email": "evgeniy-kuznecov.101971@postgrespro.ru", "phone": "+70306713769"}
0005432527244	325A88	6896 656496	VIKTOR PETROV	{"phone": "+70090562037"}
0005432527245	8F2846	9779 988832	VALENTINA NIKITINA	{"phone": "+70052228105"}
0005432527246	74CA0C	7203 508157	SVETLANA MOISEEVA	{"email": "moiseeva.svetlana.1981@postgrespro.ru", "phone": "+70937054641"}
0005432527247	E49A82	4034 864556	NIKOLAY STEPANOV	{"email": "stepanov_nikolay.05031981@postgrespro.ru", "phone": "+70186736209"}
0005432527248	5F72F3	2497 043918	ANTONINA MOROZOVA	{"phone": "+70149418719"}
0005432527249	B6069F	9140 274876	STANISLAV ABRAMOV	{"email": "stanislav-abramov_09111969@postgrespro.ru", "phone": "+70638346169"}
0005432527250	D54381	2712 235185	YURIY MOISEEV	{"phone": "+70499096850"}
0005432527251	D54381	3490 707999	ANNA SCHERBAKOVA	{"email": "anna.scherbakova1974@postgrespro.ru", "phone": "+70431879992"}
0005432527252	4364CF	2825 610758	FEDOR PAVLOV	{"email": "fedor.pavlov091967@postgrespro.ru", "phone": "+70567644502"}
0005432527253	594098	0406 936890	LYUBOV PAVLOVA	{"phone": "+70587935923"}
0005432527254	594098	4080 859672	TATYANA AFANASEVA	{"email": "afanaseva.t121975@postgrespro.ru", "phone": "+70337316181"}
0005432527255	77DF34	2821 343238	IGOR KUZNECOV	{"email": "igorkuznecov051974@postgrespro.ru", "phone": "+70003040453"}
0005432527256	77DF34	7262 719374	GRIGORIY IVANOV	{"email": "ivanov-grigoriy_28021960@postgrespro.ru", "phone": "+70314142092"}
0005432527257	7CCABE	5738 355489	GALINA ZHUKOVA	{"email": "zhukova_g_081971@postgrespro.ru", "phone": "+70076479600"}
0005432527258	7CCABE	8094 418046	ALEKSEY BARANOV	{"phone": "+70144239838"}
0005432527259	071498	8595 750875	EKATERINA VLASOVA	{"email": "e_vlasova.031972@postgrespro.ru", "phone": "+70391259487"}
0005432527260	7BDB15	6922 256051	IGOR ANDREEV	{"email": "iandreev.31101975@postgrespro.ru", "phone": "+70507284537"}
0005432527261	40720D	0204 153582	TAMARA POPOVA	{"phone": "+70914007148"}
0005432527262	6F72A2	9784 577081	OKSANA STEPANOVA	{"phone": "+70874102505"}
0005432527263	84ABAC	7853 969792	ANASTASIYA FOMINA	{"phone": "+70291664710"}
0005432527264	84ABAC	8116 957155	SVETLANA TIKHONOVA	{"email": "s.tikhonova_28021977@postgrespro.ru", "phone": "+70936253848"}
0005432527265	F50686	0624 588906	EKATERINA IVANOVA	{"email": "ivanovaekaterina_07091982@postgrespro.ru", "phone": "+70131988042"}
0005432527266	F50686	0789 198945	ALEKSEY BELOV	{"email": "abelov-011974@postgrespro.ru", "phone": "+70386624049"}
0005432527267	DAC91E	8951 412457	NATALYA ROMANOVA	{"email": "romanova.natalya-091992@postgrespro.ru", "phone": "+70349522586"}
0005432527268	BE04D2	3661 278163	ARTEM MOROZOV	{"phone": "+70196326249"}
0005432527269	573ADD	5759 737555	DENIS SEMENOV	{"email": "denis.semenov.071974@postgrespro.ru", "phone": "+70046276480"}
0005432527270	573ADD	0040 074976	VIKTORIYA ANDREEVA	{"phone": "+70379572099"}
0005432527271	FB093D	7970 404158	NINA GORBUNOVA	{"phone": "+70577506554"}
0005432527272	FB093D	8156 000971	KIRILL FOMIN	{"phone": "+70616647194"}
0005432527273	DAD837	7840 532386	TATYANA KUZMINA	{"email": "t_kuzmina1975@postgrespro.ru", "phone": "+70379865273"}
0005432527332	41E1DB	5943 201758	PETR ZAKHAROV	{"phone": "+70298689807"}
0005432527274	1A9E78	1461 570101	SERGEY NAUMOV	{"email": "naumovsergey_1970@postgrespro.ru", "phone": "+70384809735"}
0005432527275	1A9E78	6270 360950	VALERIY ORLOV	{"phone": "+70731615564"}
0005432527276	1B68B3	1424 497752	ALINA ORLOVA	{"email": "orlova-a-1967@postgrespro.ru", "phone": "+70480736060"}
0005432527277	8590F6	8268 519818	VLADIMIR ZHUKOV	{"phone": "+70764154545"}
0005432527278	124739	8682 348017	ALBINA KONOVALOVA	{"email": "albinakonovalova1972@postgrespro.ru", "phone": "+70273656136"}
0005432527279	BB5539	2333 418900	IRINA DMITRIEVA	{"phone": "+70007627609"}
0005432527280	27AAFC	5075 202333	TAGIR ISAEV	{"email": "tisaev_1974@postgrespro.ru", "phone": "+70056291559"}
0005432527281	BF7822	5966 729652	ALEKSEY VLASOV	{"email": "a.vlasov-1968@postgrespro.ru", "phone": "+70475518018"}
0005432527282	BF7822	0272 803367	SERGEY BELOV	{"email": "sergey_belov-06091965@postgrespro.ru", "phone": "+70686334787"}
0005432527283	2E05A5	0187 935838	NIKITA BELOV	{"email": "belov_nikita-1973@postgrespro.ru", "phone": "+70883551101"}
0005432527284	2E05A5	9925 550643	VIKTORIYA KOROLEVA	{"phone": "+70528936507"}
0005432527285	70399F	0580 757459	ALEKSANDR SERGEEV	{"email": "sergeev_a_1985@postgrespro.ru", "phone": "+70164699803"}
0005432527286	DA3A60	3942 327558	ALEKSANDR VASILEV	{"email": "a-vasilev.071971@postgrespro.ru", "phone": "+70252829776"}
0005432527287	399968	4754 309994	ALEKSEY KUDRYASHOV	{"email": "kudryashov-aleksey1974@postgrespro.ru", "phone": "+70258823079"}
0005432527288	399968	2030 228444	MIKHAIL POPOV	{"phone": "+70836998565"}
0005432527289	18777B	2165 773426	VALENTINA KUZNECOVA	{"phone": "+70897386062"}
0005432527290	AD8156	5649 463173	LYUBOV BORISOVA	{"email": "borisova_l-011957@postgrespro.ru", "phone": "+70537192622"}
0005432527291	AD8156	2147 857159	VALERIY CHERNOV	{"phone": "+70895446402"}
0005432527292	81D3C1	9547 320786	ZINAIDA SOKOLOVA	{"email": "sokolovazinaida061968@postgrespro.ru", "phone": "+70625299738"}
0005432527293	DC239B	4533 946648	VIKTOR MOROZOV	{"phone": "+70337865315"}
0005432527294	166696	2704 370318	KIRILL RODIONOV	{"email": "kirill-rodionov-14021965@postgrespro.ru", "phone": "+70773477714"}
0005432527295	166696	0030 606388	LIDIYA STEPANOVA	{"email": "l-stepanova_061971@postgrespro.ru", "phone": "+70810092685"}
0005432527296	626B7C	6256 923910	NIKOLAY KONOVALOV	{"email": "n-konovalov-091962@postgrespro.ru", "phone": "+70959208532"}
0005432527297	0137A3	7373 114135	VADIM VLASOV	{"phone": "+70651328771"}
0005432527298	AC15C0	7094 612087	ALEKSANDR SCHERBAKOV	{"phone": "+70355752700"}
0005432527299	AC15C0	1383 059262	LYUBOV MARTYNOVA	{"email": "martynova_lyubov-1976@postgrespro.ru", "phone": "+70669426048"}
0005432527300	39D493	3903 736811	RUSLAN PETROV	{"phone": "+70866169553"}
0005432527301	39D493	9433 143476	NATALIYA BORISOVA	{"phone": "+70697891253"}
0005432527302	D03EFC	6437 618417	ANATOLIY ABRAMOV	{"email": "abramovanatoliy-17041976@postgrespro.ru", "phone": "+70850406202"}
0005432527303	D6AC3C	8140 284688	ANNA FILATOVA	{"email": "a_filatova_061967@postgrespro.ru", "phone": "+70492248077"}
0005432527304	5626B0	7837 894055	NATALYA KOLESNIKOVA	{"email": "kolesnikova.natalya_121965@postgrespro.ru", "phone": "+70074375416"}
0005432527305	A04934	2851 920817	NIKOLAY KUDRYASHOV	{"phone": "+70754716896"}
0005432527306	A04934	1027 867278	ANTONINA KOZLOVA	{"email": "antoninakozlova.16101973@postgrespro.ru", "phone": "+70837470858"}
0005432527307	A2968E	0056 951250	VALENTINA ANTONOVA	{"phone": "+70422810341"}
0005432527308	A2968E	2210 636990	SERGEY KUDRYASHOV	{"email": "kudryashov-s.1977@postgrespro.ru", "phone": "+70840375864"}
0005432527309	1CC718	3502 690159	ANATOLIY KUZNECOV	{"email": "kuznecov.anatoliy.30101975@postgrespro.ru", "phone": "+70408932860"}
0005432527310	1CC718	1126 791273	ILYA CHERNOV	{"email": "chernov.i-22071969@postgrespro.ru", "phone": "+70914191612"}
0005432527311	B75892	2057 002459	ILDAR KULIKOV	{"phone": "+70654550480"}
0005432527312	9BC05E	4043 414965	NATALYA MOISEEVA	{"email": "natalya-moiseeva051974@postgrespro.ru", "phone": "+70936920154"}
0005432527313	B8142A	5367 472825	POLINA MIRONOVA	{"email": "mironovapolina111971@postgrespro.ru", "phone": "+70168720703"}
0005432527314	B8142A	4162 403861	KONSTANTIN VOLKOV	{"phone": "+70990792783"}
0005432527315	923FE5	5452 642172	NADEZHDA MAKSIMOVA	{"email": "maksimova-n101971@postgrespro.ru", "phone": "+70403574025"}
0005432527316	923FE5	6124 530561	IVAN MOROZOV	{"email": "morozovi111964@postgrespro.ru", "phone": "+70732578594"}
0005432527317	2B3ECC	5593 144791	TATYANA BARANOVA	{"phone": "+70593951029"}
0005432527318	233AA4	7669 019634	RUSLAN FILIPPOV	{"email": "filippovr_06081979@postgrespro.ru", "phone": "+70310690370"}
0005432527319	29E174	5616 259465	VIKTOR IVANOV	{"phone": "+70867013618"}
0005432527320	9D9DCF	2516 103242	ELENA KUDRYASHOVA	{"email": "elenakudryashova_07041973@postgrespro.ru", "phone": "+70766409630"}
0005432527321	9D9DCF	1317 088659	MARIYA ABRAMOVA	{"email": "m-abramova_1975@postgrespro.ru", "phone": "+70213015529"}
0005432527322	3C2FBA	9537 849500	IRINA PAVLOVA	{"email": "i-pavlova051968@postgrespro.ru", "phone": "+70898973653"}
0005432527323	3C2FBA	3428 121395	KRISTINA SCHERBAKOVA	{"email": "k-scherbakova-1965@postgrespro.ru", "phone": "+70322715479"}
0005432527324	3C2FBA	5607 278027	GALINA STEPANOVA	{"phone": "+70325229750"}
0005432527325	D31F58	8576 658675	LILIYA NIKOLAEVA	{"email": "l_nikolaeva-31011971@postgrespro.ru", "phone": "+70639327343"}
0005432527326	000012	9091 269355	TAMARA ZAYCEVA	{"email": "tamarazayceva-1971@postgrespro.ru", "phone": "+70749401734"}
0005432527327	1076E0	0797 120132	MARINA IVANOVA	{"phone": "+70144087748"}
0005432527328	31CBD3	0558 306843	TAMARA KUZNECOVA	{"phone": "+70195443980"}
0005432527329	31CBD3	9644 541984	EVGENIY ILIN	{"phone": "+70267371326"}
0005432527330	E75BAF	7184 771150	SVETLANA NESTEROVA	{"email": "svetlana-nesterova-16091973@postgrespro.ru", "phone": "+70554433565"}
0005432527331	4C463C	7458 934931	TATYANA VOLKOVA	{"email": "t.volkova25021983@postgrespro.ru", "phone": "+70396995683"}
0005432527333	3B8E4D	1651 920797	DIANA BORISOVA	{"phone": "+70794946341"}
0005432527334	BAE953	1290 744838	SVETLANA RODIONOVA	{"email": "svetlanarodionova.061968@postgrespro.ru", "phone": "+70882453550"}
0005432527335	ACD0E3	9421 024422	VLADIMIR STEPANOV	{"email": "stepanov_v.111964@postgrespro.ru", "phone": "+70600880251"}
0005432527336	6AC46A	6980 426865	TAMARA ILINA	{"email": "tamarailina-091972@postgrespro.ru", "phone": "+70291609960"}
0005432527337	674311	1949 885534	VIKTORIYA ZOTOVA	{"email": "viktoriya-zotova-101978@postgrespro.ru", "phone": "+70948136260"}
0005432527338	6F404D	5911 258561	NADEZHDA KRASNOVA	{"phone": "+70567348351"}
0005432527339	88A222	5192 043496	RUSLAN FOMIN	{"email": "rfomin-101979@postgrespro.ru", "phone": "+70745933783"}
0005432527340	654883	3677 861676	MARGARITA LEBEDEVA	{"phone": "+70754956527"}
0005432527341	21AA33	0003 914939	SERGEY PETROV	{"phone": "+70727090388"}
0005432527342	279174	8814 353508	ANASTASIYA MASLOVA	{"email": "maslova_anastasiya.061971@postgrespro.ru", "phone": "+70480141353"}
0005432527343	279174	8383 478341	LYAYSAN ILINA	{"phone": "+70796728261"}
0005432527344	954721	5523 156144	VALENTINA POLYAKOVA	{"email": "polyakovavalentina.22101981@postgrespro.ru", "phone": "+70663184193"}
0005432527345	380644	4966 639870	VLADIMIR VASILEV	{"email": "vladimir_vasilev.11061954@postgrespro.ru", "phone": "+70268483503"}
0005432527346	03F37A	0576 267379	OKSANA PETROVA	{"email": "o.petrova-06051966@postgrespro.ru", "phone": "+70557896540"}
0005432527347	E37EDD	3406 673672	VYACHESLAV MOROZOV	{"phone": "+70828000915"}
0005432527348	727D4B	4682 272489	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev.01071968@postgrespro.ru", "phone": "+70038130378"}
0005432527349	7626DC	2444 256367	KRISTINA SEMENOVA	{"phone": "+70285968252"}
0005432527350	9EAB49	7579 178868	MIKHAIL SCHERBAKOV	{"email": "m.scherbakov.1969@postgrespro.ru", "phone": "+70959767068"}
0005432527351	9EAB49	8423 375043	VIKTORIYA BORISOVA	{"email": "viktoriya_borisova22021985@postgrespro.ru", "phone": "+70562930908"}
0005432527352	9EAB49	4627 672524	NIKOLAY CHERNOV	{"phone": "+70916108404"}
0005432527353	C91644	3260 898356	NATALYA VASILEVA	{"email": "vasileva-n-25071967@postgrespro.ru", "phone": "+70458793817"}
0005432527354	BC812C	3598 176283	RASHID MOROZOV	{"email": "morozov.r1986@postgrespro.ru", "phone": "+70698751952"}
0005432527355	BC812C	9263 014787	VLADIMIR PETROV	{"email": "petrov-vladimir1967@postgrespro.ru", "phone": "+70548474857"}
0005432527356	DB66AF	6263 004498	IRINA ILINA	{"phone": "+70210266453"}
0005432527357	9BD321	0312 639875	TATYANA ZHUKOVA	{"phone": "+70746062219"}
0005432527358	5B404C	2494 233782	VASILISA MEDVEDEVA	{"email": "medvedeva-v08061973@postgrespro.ru", "phone": "+70473405594"}
0005432527359	A4653D	6530 226270	VALERIY MOROZOV	{"phone": "+70955387119"}
0005432527360	A4653D	2392 852470	IVAN VLASOV	{"email": "vlasov_i_28091987@postgrespro.ru", "phone": "+70485854963"}
0005432527361	138126	5697 130039	ANNA FEDOROVA	{"phone": "+70554258117"}
0005432527362	138126	5726 534345	ELENA GAVRILOVA	{"phone": "+70611798829"}
0005432527363	E21228	2011 743156	TATYANA VASILEVA	{"phone": "+70794692413"}
0005432527364	C1D3C1	3272 125686	SAMIR POPOV	{"phone": "+70555596211"}
0005432527365	A24974	4938 666250	MIKHAIL KULIKOV	{"phone": "+70090623188"}
0005432527366	25613A	7924 694971	VASILIY ILIN	{"email": "vasiliy_ilin.081970@postgrespro.ru", "phone": "+70490605450"}
0005432527367	F6EAA4	9762 347700	ALEKSEY ZAYCEV	{"email": "zaycev_a-1972@postgrespro.ru", "phone": "+70034893726"}
0005432527368	B02C9A	7310 360880	RIMMA VOLKOVA	{"phone": "+70892422341"}
0005432527369	B02C9A	5823 232362	SERGEY ORLOV	{"phone": "+70259198270"}
0005432527370	6BA6C6	1604 238774	ANASTASIYA PETROVA	{"phone": "+70030389321"}
0005432527371	FC9644	6116 126841	VIKTOR GAVRILOV	{"email": "gavrilov.viktor-091971@postgrespro.ru", "phone": "+70802300563"}
0005432527372	1FB6C4	2489 522052	LYUDMILA EGOROVA	{"email": "lyudmila_egorova-28061978@postgrespro.ru", "phone": "+70616583746"}
0005432527373	9B1F73	7301 804987	ALEKSANDR SOROKIN	{"email": "asorokin_28121975@postgrespro.ru", "phone": "+70198020990"}
0005432527374	A84FCF	3808 755019	YULIYA PAVLOVA	{"email": "pavlova_yuliya.1975@postgrespro.ru", "phone": "+70056378912"}
0005432527375	A84FCF	6374 393803	ALEKSANDR YAKOVLEV	{"phone": "+70598554066"}
0005432527376	A84FCF	2228 640416	TIMUR ZAKHAROV	{"phone": "+70784537309"}
0005432527377	B70AF3	7387 084376	NATALYA FADEEVA	{"phone": "+70959866680"}
0005432527378	98B722	9906 958194	VADIM VLASOV	{"phone": "+70327206227"}
0005432527379	43D376	6720 450398	ELIZAVETA DANILOVA	{"phone": "+70229518552"}
0005432527380	43D376	0842 436799	MIKHAIL ORLOV	{"email": "mikhailorlov25041971@postgrespro.ru", "phone": "+70694065856"}
0005432527381	9A4CB8	6039 126699	SERGEY DENISOV	{"phone": "+70734569536"}
0005432527382	7D91E1	1157 784773	VIKTOR PAVLOV	{"phone": "+70176773119"}
0005432527383	65CD78	6919 723587	VYACHESLAV POPOV	{"email": "popov-vyacheslav_1982@postgrespro.ru", "phone": "+70025697628"}
0005432527384	BC3BB7	4223 047137	DENIS KARPOV	{"phone": "+70460800543"}
0005432527385	BC3BB7	4859 910903	MARINA TROFIMOVA	{"email": "trofimova_marina.121978@postgrespro.ru", "phone": "+70375561826"}
0005432527386	F84AA8	8370 441891	LYUBOV PETROVA	{"email": "petrovalyubov121969@postgrespro.ru", "phone": "+70600221691"}
0005432527387	F84AA8	4535 664739	EVGENIYA PETROVA	{"phone": "+70175640198"}
0005432527388	682235	8551 284954	VALENTINA KOLESNIKOVA	{"email": "v-kolesnikova_1966@postgrespro.ru", "phone": "+70068856188"}
0005432527389	682235	3751 370516	ELENA NIKOLAEVA	{"email": "elena.nikolaeva-1978@postgrespro.ru", "phone": "+70198504669"}
0005432527390	AB99D2	8381 903712	MIKHAIL NOVIKOV	{"phone": "+70643072515"}
0005432527391	D76A13	6518 959738	RUSTAM ANDREEV	{"phone": "+70132895770"}
0005432527392	EC0900	3334 618330	EVGENIY NIKITIN	{"email": "nikitin-evgeniy-28071963@postgrespro.ru", "phone": "+70401393502"}
0005432527393	32C6CB	8643 366192	LEONID KUZMIN	{"email": "kuzmin-leonid_1978@postgrespro.ru", "phone": "+70728154228"}
0005432527394	693004	4324 740738	VIKTOR MAKSIMOV	{"phone": "+70409006623"}
0005432527395	7F5979	0194 438445	LYUBOV SOLOVEVA	{"phone": "+70776004008"}
0005432527396	C4111A	0301 531221	ANDREY ZAYCEV	{"phone": "+70371684689"}
0005432527397	699C07	5695 900314	VERA STEPANOVA	{"email": "vstepanova121970@postgrespro.ru", "phone": "+70467024574"}
0005432527398	823747	8836 694168	NATALYA FROLOVA	{"phone": "+70185127527"}
0005432527399	823747	7723 844743	NADEZHDA SOKOLOVA	{"phone": "+70679337200"}
0005432527400	9328A8	7604 925245	TAGIR KISELEV	{"email": "tagir_kiselev_03051979@postgrespro.ru", "phone": "+70370993320"}
0005432527401	9328A8	1001 366710	EKATERINA KALININA	{"phone": "+70119132450"}
0005432527402	F360C1	1940 445671	NINA MAKAROVA	{"email": "makarova_nina_1976@postgrespro.ru", "phone": "+70519135957"}
0005432527403	0BCEA4	3106 019258	ANNA IVANOVA	{"phone": "+70981505687"}
0005432527404	A1507A	5398 205910	MIKHAIL SOROKIN	{"email": "m.sorokin-031984@postgrespro.ru", "phone": "+70921424579"}
0005432527405	FF180D	0124 191522	YURIY FOMIN	{"phone": "+70731097509"}
0005432527406	3E8B59	0810 833509	NADEZHDA FEDOROVA	{"email": "n-fedorova-25061969@postgrespro.ru", "phone": "+70330137429"}
0005432527407	616636	7439 405767	IVAN NAUMOV	{"phone": "+70296220855"}
0005432527408	616636	2796 555165	VALENTIN ZAKHAROV	{"email": "valentinzakharov111977@postgrespro.ru", "phone": "+70913042420"}
0005432527409	616636	2542 884178	DMITRIY GRIGOREV	{"phone": "+70060461256"}
0005432527410	27191D	6308 355371	ILMIRA ZAYCEVA	{"phone": "+70739460568"}
0005432527411	CEBA72	4633 463332	VALENTINA EGOROVA	{"phone": "+70990385573"}
0005432527412	E29EBF	9870 116064	AZAT KUZNECOV	{"phone": "+70860856243"}
0005432527413	AAED0E	3393 366818	LYUDMILA GUSEVA	{"email": "guseva_l29091982@postgrespro.ru", "phone": "+70733011628"}
0005432527414	00EC69	5195 515903	GENNADIY KISELEV	{"email": "kiselev-gennadiy_051987@postgrespro.ru", "phone": "+70885419279"}
0005432527415	2E2EC4	7803 609162	VLADIMIR CHERNOV	{"phone": "+70265042665"}
0005432527416	FD5BFC	5123 896692	VALERIY SEMENOV	{"email": "semenov-valeriy-23111965@postgrespro.ru", "phone": "+70281209606"}
0005432527417	FD5BFC	0676 042649	STANISLAV MEDVEDEV	{"phone": "+70167115180"}
0005432527418	ECEE7A	9264 558522	IGOR KUZNECOV	{"email": "kuznecov_igor_1966@postgrespro.ru", "phone": "+70857638891"}
0005432527419	F37EAF	8801 481833	YURIY MATVEEV	{"phone": "+70809166287"}
0005432527420	F37EAF	9761 924701	NIKITA STEPANOV	{"email": "nikita.stepanov_121978@postgrespro.ru", "phone": "+70001852709"}
0005432527421	4F512B	4983 098062	NIKOLAY KUZMIN	{"email": "kuzmin-n.04111968@postgrespro.ru", "phone": "+70188381869"}
0005432527422	76F0E7	2206 097767	ANTONINA DAVYDOVA	{"phone": "+70242561605"}
0005432527423	FCCAF1	1002 877675	NINA POPOVA	{"email": "nina-popova-071975@postgrespro.ru", "phone": "+70031564844"}
0005432527424	8C5089	3816 189751	MARIYA KOLESNIKOVA	{"phone": "+70709040634"}
0005432527425	EC727A	7096 259290	EKATERINA ANTONOVA	{"phone": "+70887863168"}
0005432527426	540091	7725 700269	VALENTINA NESTEROVA	{"email": "valentina_nesterova_081969@postgrespro.ru", "phone": "+70069271088"}
0005432527427	BBFA8F	6355 848905	ELENA KARPOVA	{"email": "elena-karpova-31031975@postgrespro.ru", "phone": "+70605543059"}
0005432527428	BBFA8F	2632 363226	NINA MELNIKOVA	{"email": "n-melnikova_31071967@postgrespro.ru", "phone": "+70122407077"}
0005432527429	BBFA8F	6715 784945	TATYANA EGOROVA	{"email": "egorova_tatyana.041982@postgrespro.ru", "phone": "+70735847270"}
0005432527430	E2E633	3987 030045	OKSANA GRISHINA	{"phone": "+70763727282"}
0005432527431	A4C1DA	2515 918317	NINA ERMAKOVA	{"email": "ermakova.nina.041978@postgrespro.ru", "phone": "+70731738718"}
0005432527432	5B80B4	2774 396903	VLADIMIR TIMOFEEV	{"email": "timofeev_vladimir.08051980@postgrespro.ru", "phone": "+70239692068"}
0005432527433	5B80B4	5073 303605	ULYANA SOROKINA	{"phone": "+70183036992"}
0005432527434	B076B6	4342 823184	MARIYA MAKSIMOVA	{"phone": "+70276638117"}
0005432527435	64E0FE	2546 900460	VALENTINA FILIPPOVA	{"email": "filippovav.071975@postgrespro.ru", "phone": "+70133963204"}
0005432527436	12DE1C	3136 780476	VALENTINA GERASIMOVA	{"phone": "+70658964100"}
0005432527437	12DE1C	9399 992274	EVGENIYA VASILEVA	{"phone": "+70596564203"}
0005432527438	DAD349	9505 217884	NIKOLAY FEDOTOV	{"phone": "+70584648889"}
0005432527439	9AFAEF	0729 897702	VIKTORIYA NESTEROVA	{"email": "vnesterova_25051984@postgrespro.ru", "phone": "+70588623323"}
0005432527440	B6652D	4510 696731	ANNA AFANASEVA	{"email": "anna-afanaseva-1989@postgrespro.ru", "phone": "+70899141604"}
0005432527441	B6652D	4223 188918	DMITRIY SERGEEV	{"email": "d-sergeev101977@postgrespro.ru", "phone": "+70111812508"}
0005432527442	EE158F	6586 335236	PETR IVANOV	{"phone": "+70766082980"}
0005432527443	EE158F	4880 461707	SERGEY DAVYDOV	{"email": "davydov-sergey_31071977@postgrespro.ru", "phone": "+70284300924"}
0005432527444	854A34	9306 865613	RASHIT KOZLOV	{"email": "r-kozlov-23011986@postgrespro.ru", "phone": "+70908720646"}
0005432527445	854A34	4408 753776	AYRAT NAUMOV	{"email": "naumovayrat_1978@postgrespro.ru", "phone": "+70263063452"}
0005432527446	15C5BF	7820 514861	IVAN POPOV	{"phone": "+70583228159"}
0005432527447	69C601	8199 067183	ANATOLIY SMIRNOV	{"phone": "+70177393880"}
0005432527448	69C601	5174 148388	ALEKSANDRA FADEEVA	{"email": "fadeeva.aleksandra_02091980@postgrespro.ru", "phone": "+70835647377"}
0005432527449	31FC4A	3515 370868	LYUBOV ORLOVA	{"email": "orlova_l051972@postgrespro.ru", "phone": "+70657810187"}
0005432527450	31FC4A	7420 293252	RAFAEL MIKHAYLOV	{"email": "mikhaylov_rafael_22081976@postgrespro.ru", "phone": "+70515486012"}
0005432527451	31FC4A	4488 271868	OLGA SOKOLOVA	{"phone": "+70667727142"}
0005432527452	545125	7961 544953	INNA RODIONOVA	{"phone": "+70806005199"}
0005432527453	9A6F3C	7184 288583	SERGEY FROLOV	{"email": "sfrolov.071971@postgrespro.ru", "phone": "+70397857390"}
0005432527454	9A6F3C	7275 258994	DMITRIY SIDOROV	{"email": "dmitriy_sidorov_031967@postgrespro.ru", "phone": "+70047462101"}
0005432527455	9A6F3C	8580 158893	DARYA CHERNOVA	{"email": "dchernova-1970@postgrespro.ru", "phone": "+70159719993"}
0005432527456	082201	5500 086340	VLADIMIR GORBUNOV	{"email": "gorbunovvladimir_1967@postgrespro.ru", "phone": "+70254925118"}
0005432527457	13F276	0659 444761	OLESYA AKIMOVA	{"phone": "+70582717877"}
0005432527458	235D4B	1568 564354	ANNA POPOVA	{"email": "popovaa-1982@postgrespro.ru", "phone": "+70057694679"}
0005432527459	235D4B	6688 280742	VALENTINA EGOROVA	{"email": "v-egorova-12021975@postgrespro.ru", "phone": "+70264763636"}
0005432527905	ECFF5E	9451 845928	LIDIYA FEDOROVA	{"phone": "+70704163250"}
0005432527460	AC7F06	6150 653996	MIKHAIL VASILEV	{"email": "vasilev_mikhail-1978@postgrespro.ru", "phone": "+70495052220"}
0005432527461	67D1E8	3342 798151	NATALYA OSIPOVA	{"phone": "+70966344608"}
0005432527518	DDD9BA	3847 987202	VLADIMIR ZHURAVLEV	{"phone": "+70720331603"}
0005432527462	5580A4	5886 679267	FEDOR IVANOV	{"email": "ivanovf-031977@postgrespro.ru", "phone": "+70025845319"}
0005432527463	99B7F8	8707 335233	ANDREY IVANOV	{"phone": "+70120530786"}
0005432527464	99B7F8	2309 929360	IRINA ANISIMOVA	{"email": "anisimova_i_28061968@postgrespro.ru", "phone": "+70403042127"}
0005432527465	47B987	0314 886424	ZINAIDA ILINA	{"email": "ilina-z1976@postgrespro.ru", "phone": "+70295113782"}
0005432527466	BE3F21	1932 691107	GENNADIY IVANOV	{"phone": "+70735990592"}
0005432527467	BE3F21	0360 867984	ANNA MOROZOVA	{"phone": "+70359638783"}
0005432527468	E5125C	2418 270392	TATYANA KRASNOVA	{"email": "krasnova-t_13051984@postgrespro.ru", "phone": "+70057000092"}
0005432527469	E5125C	7966 362351	NATALYA PAVLOVA	{"phone": "+70346929355"}
0005432527470	E5125C	4696 559891	ALEKSANDR ANTONOV	{"phone": "+70853376449"}
0005432527471	E32841	9991 221634	DMITRIY VLASOV	{"email": "d_vlasov_031982@postgrespro.ru", "phone": "+70220460441"}
0005432527472	E2FA66	7151 967411	VERA MAKSIMOVA	{"email": "maksimova-v_111979@postgrespro.ru", "phone": "+70041754847"}
0005432527473	11653E	0021 667011	VLADIMIR KOZLOV	{"email": "v.kozlov.20071969@postgrespro.ru", "phone": "+70997655058"}
0005432527474	49AF48	2575 948905	VERA KOVALEVA	{"phone": "+70123813967"}
0005432527475	346C0A	7382 126844	ILYA IVANOV	{"phone": "+70341458190"}
0005432527476	346C0A	7721 955414	NIKOLAY BARANOV	{"phone": "+70125418494"}
0005432527477	55D28E	7673 308049	GERMAN TARASOV	{"phone": "+70051524114"}
0005432527478	115F0D	5077 147554	LYUBOV KOROLEVA	{"email": "koroleva-lyubov.01091978@postgrespro.ru", "phone": "+70407040474"}
0005432527479	94B6A4	6242 281301	SERGEY ALEKSEEV	{"email": "s-alekseev061969@postgrespro.ru", "phone": "+70356959736"}
0005432527480	94B6A4	9747 234913	ANTON ZAKHAROV	{"phone": "+70406746894"}
0005432527481	2ECC00	0613 907320	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev011968@postgrespro.ru", "phone": "+70367802928"}
0005432527482	2ECC00	7617 361473	YULIYA SAVELEVA	{"email": "y.saveleva-1959@postgrespro.ru", "phone": "+70661966815"}
0005432527483	49C651	9023 498637	KRISTINA FILATOVA	{"phone": "+70435076749"}
0005432527484	49C651	1034 807631	MIKHAIL ANDREEV	{"email": "andreevmikhail.12021986@postgrespro.ru", "phone": "+70482128806"}
0005432527485	E3D053	5513 791737	NIKITA MIRONOV	{"phone": "+70595648612"}
0005432527486	1BBAD7	9836 575835	MARIYA FROLOVA	{"phone": "+70626167240"}
0005432527487	1BBAD7	3409 696424	OLGA VASILEVA	{"email": "o.vasileva_1971@postgrespro.ru", "phone": "+70892745180"}
0005432527488	FCA334	3848 550124	ILYA KOROLEV	{"phone": "+70338678726"}
0005432527489	55FE53	8194 428740	ALLA SMIRNOVA	{"phone": "+70138199088"}
0005432527490	843258	8816 686682	RADIK MARTYNOV	{"email": "martynovradik-061963@postgrespro.ru", "phone": "+70402037820"}
0005432527491	843258	0851 395956	OLGA IVANOVA	{"phone": "+70648960041"}
0005432527492	D1580D	8790 142605	VLADIMIR MELNIKOV	{"phone": "+70938071349"}
0005432527493	D1580D	9412 121505	ALEKSANDR NAZAROV	{"email": "nazarov.a_121974@postgrespro.ru", "phone": "+70214197641"}
0005432527494	6B49BE	3489 741575	ANDREY EGOROV	{"email": "aegorov-071974@postgrespro.ru", "phone": "+70830405339"}
0005432527495	0CAF3F	5826 327980	ALEKSANDR KOROLEV	{"phone": "+70381683187"}
0005432527496	A4FD5B	8440 715951	DAMIR KUZNECOV	{"email": "kuznecov-d.1964@postgrespro.ru", "phone": "+70095858735"}
0005432527497	A4FD5B	7816 732956	NIKOLAY SIDOROV	{"email": "sidorov-n16101980@postgrespro.ru", "phone": "+70799890664"}
0005432527498	22C02F	0305 641216	LYUDMILA GUSEVA	{"email": "lyudmila-guseva_081979@postgrespro.ru", "phone": "+70097135980"}
0005432527499	99EB33	5224 596185	NIKOLAY NIKITIN	{"phone": "+70000719425"}
0005432527500	FD854D	5620 455804	LEV ZAYCEV	{"email": "zaycev-lev.081983@postgrespro.ru", "phone": "+70817502432"}
0005432527501	FD854D	9641 989207	SERGEY PETROV	{"email": "petrov_sergey-1967@postgrespro.ru", "phone": "+70433873657"}
0005432527502	433451	3607 823649	NIKITA NIKITIN	{"phone": "+70260147802"}
0005432527503	2BFA44	5832 154809	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov.1983@postgrespro.ru", "phone": "+70158779201"}
0005432527504	2BFA44	6639 888417	PAVEL BARANOV	{"phone": "+70157573501"}
0005432527505	00F97B	4592 187679	VALERIY KRASNOV	{"email": "krasnov.valeriy_1980@postgrespro.ru", "phone": "+70302007298"}
0005432527506	2084F2	5094 197482	SVETLANA KOROLEVA	{"phone": "+70447891147"}
0005432527507	5598D2	5702 026729	EVGENIY ZHURAVLEV	{"phone": "+70365215120"}
0005432527508	D7417B	1493 429146	SERGEY KUZNECOV	{"phone": "+70421437917"}
0005432527509	D7417B	1886 380476	MARINA KOZLOVA	{"email": "marina.kozlova16031972@postgrespro.ru", "phone": "+70227811219"}
0005432527510	067003	1468 230305	VITALIY KONOVALOV	{"phone": "+70287588611"}
0005432527689	89E6FC	8068 632682	ALEKSANDRA ALEKSANDROVA	{"phone": "+70654402506"}
0005432527511	067003	5914 229743	VADIM KRASNOV	{"email": "vadim-krasnov-08031970@postgrespro.ru", "phone": "+70206695123"}
0005432527512	067003	2917 985635	IVAN SCHERBAKOV	{"phone": "+70723729213"}
0005432527513	365B2A	5537 576725	VITALIY YAKOVLEV	{"phone": "+70268493177"}
0005432527514	365B2A	2868 428599	ALEKSEY IVANOV	{"email": "ivanov_a_051977@postgrespro.ru", "phone": "+70125717039"}
0005432527515	DD9258	0804 259923	VALERIY VASILEV	{"email": "v.vasilev-1972@postgrespro.ru", "phone": "+70832534774"}
0005432527906	6E0513	6642 890548	VIKTORIYA FADEEVA	{"phone": "+70552916962"}
0005432527516	4922F9	5693 544228	NATALYA IVANOVA	{"email": "ivanova-n.081956@postgrespro.ru", "phone": "+70259366096"}
0005432527517	DDD9BA	1509 212542	NATALYA PETROVA	{"phone": "+70136187313"}
0005432527519	4258E3	7787 509581	ALEKSANDR EGOROV	{"email": "egorov-a_10081965@postgrespro.ru", "phone": "+70154364254"}
0005432527520	4FC448	0454 559114	SERGEY POPOV	{"phone": "+70865085637"}
0005432527521	4FC448	5202 943550	LYUDMILA ISAEVA	{"phone": "+70159356906"}
0005432527522	7BF4FB	1908 370621	TAISIYA SOKOLOVA	{"phone": "+70583591096"}
0005432527523	7BF4FB	4029 556755	EVGENIY PETROV	{"email": "e.petrov.1977@postgrespro.ru", "phone": "+70514150954"}
0005432527524	7BF4FB	4553 788823	ZOYA KISELEVA	{"email": "zoya-kiseleva.011973@postgrespro.ru", "phone": "+70184256750"}
0005432527525	E32E25	4120 133593	VIKTOR ANDREEV	{"email": "andreev_v-1981@postgrespro.ru", "phone": "+70404775817"}
0005432527526	5F3A35	6148 161142	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov.20021974@postgrespro.ru", "phone": "+70151601947"}
0005432527527	5F3A35	2037 448075	ELENA FROLOVA	{"email": "frolova-elena-13031971@postgrespro.ru", "phone": "+70033068592"}
0005432527528	3D622F	4248 480477	VIKTORIYA ZHUKOVA	{"phone": "+70863606460"}
0005432527529	4D2C62	4322 338889	MARGARITA MOISEEVA	{"phone": "+70031531857"}
0005432527530	BACC4E	5287 071440	VLADIMIR KRASNOV	{"phone": "+70676515887"}
0005432527531	4372C2	1776 532149	ALEKSEY KOZLOV	{"email": "aleksey.kozlov_1965@postgrespro.ru", "phone": "+70452198285"}
0005432527532	267C19	6463 000687	SERAFIMA ZAKHAROVA	{"email": "zakharova_serafima_051973@postgrespro.ru", "phone": "+70698528880"}
0005432527533	E13CEE	6836 926930	ALEKSEY BELOV	{"phone": "+70741416829"}
0005432527534	E13CEE	1365 921867	TAMARA MIKHAYLOVA	{"email": "mikhaylovatamara.081974@postgrespro.ru", "phone": "+70589353818"}
0005432527535	27EC49	3329 586124	VALENTINA MIKHAYLOVA	{"phone": "+70127357801"}
0005432527536	3EB49C	5147 270598	POLINA ZHURAVLEVA	{"phone": "+70625640114"}
0005432527537	A01E4C	0211 308869	ANASTASIYA GUSEVA	{"email": "anastasiya.guseva.061972@postgrespro.ru", "phone": "+70692334714"}
0005432527538	A01E4C	2839 852869	VIKTOR NAUMOV	{"phone": "+70449736458"}
0005432527539	CDE900	1534 914995	VENIAMIN NIKOLAEV	{"email": "nikolaevv_1978@postgrespro.ru", "phone": "+70834830388"}
0005432527540	6E3636	2486 546716	LARISA NIKOLAEVA	{"email": "lnikolaeva04031975@postgrespro.ru", "phone": "+70593924623"}
0005432527541	6E3636	5809 215770	IRINA AKIMOVA	{"email": "i-akimova1954@postgrespro.ru", "phone": "+70065130402"}
0005432527542	0E1930	9390 909703	IGOR NOVIKOV	{"phone": "+70669124545"}
0005432527543	0E1930	7843 603235	SVETLANA KUZMINA	{"email": "kuzminasvetlana-03091969@postgrespro.ru", "phone": "+70286828364"}
0005432527544	87CE52	8740 807697	OLEG NOVIKOV	{"email": "oleg-novikov011984@postgrespro.ru", "phone": "+70962825346"}
0005432527545	41247F	5687 054686	IVAN PETROV	{"email": "i-petrov28041970@postgrespro.ru", "phone": "+70277094901"}
0005432527546	421A9E	7061 770933	EKATERINA GORBUNOVA	{"phone": "+70894684328"}
0005432527547	421A9E	7416 674352	SERGEY NOVIKOV	{"email": "sergeynovikov.29031963@postgrespro.ru", "phone": "+70128022608"}
0005432527548	83EAAB	0069 679640	VITALIY POPOV	{"email": "vitaliy-popov-1984@postgrespro.ru", "phone": "+70330848555"}
0005432527549	55C87E	0758 832089	GEORGIY GUSEV	{"email": "georgiy_gusev31071976@postgrespro.ru", "phone": "+70091988888"}
0005432527550	55C87E	7914 699556	VLADIMIR MOROZOV	{"phone": "+70690903334"}
0005432527551	375D24	7139 233014	NADEZHDA ZHUKOVA	{"phone": "+70697626502"}
0005432527552	375D24	5984 271068	ELENA KOROLEVA	{"phone": "+70617282413"}
0005432527553	25E538	4403 159516	NATALYA MOROZOVA	{"email": "morozova.n.071975@postgrespro.ru", "phone": "+70385778754"}
0005432527554	2B370C	6024 911963	TATYANA BELOVA	{"email": "belova_tatyana25011974@postgrespro.ru", "phone": "+70750252846"}
0005432527555	79E182	0576 964458	MARIYA PETROVA	{"email": "m_petrova041985@postgrespro.ru", "phone": "+70000274687"}
0005432527556	79E182	8649 450959	ANNA KUZNECOVA	{"phone": "+70511283211"}
0005432527557	DEF76D	8327 735492	ILYA ILIN	{"email": "i_ilin.111976@postgrespro.ru", "phone": "+70300367160"}
0005432527558	C4C592	3124 052815	SVETLANA POLYAKOVA	{"email": "polyakova.svetlana-1966@postgrespro.ru", "phone": "+70566716306"}
0005432527559	19DB49	7496 290885	DIANA KUZMINA	{"phone": "+70453843170"}
0005432527560	19DB49	1625 634308	RASHID PAVLOV	{"email": "rpavlov1963@postgrespro.ru", "phone": "+70572741329"}
0005432527561	14F4AA	6544 222257	SERGEY ROMANOV	{"email": "sergey-romanov_02041971@postgrespro.ru", "phone": "+70509711096"}
0005432527562	008FD2	2306 603220	LYUDMILA SOROKINA	{"phone": "+70647147968"}
0005432527563	997004	2156 427094	NIKOLAY SCHERBAKOV	{"email": "nikolay.scherbakov_1967@postgrespro.ru", "phone": "+70444956224"}
0005432527564	997004	6645 846163	NINA MIKHAYLOVA	{"email": "mikhaylova.nina-081977@postgrespro.ru", "phone": "+70471951411"}
0005432527565	557C4E	0925 604835	REGINA SOKOLOVA	{"phone": "+70384797289"}
0005432527566	ADCFFE	3223 132548	ALEKSEY VASILEV	{"email": "avasilev061973@postgrespro.ru", "phone": "+70004623809"}
0005432527567	DD8C14	8150 897452	IRAIDA VOLKOVA	{"email": "iraida-volkova071978@postgrespro.ru", "phone": "+70303663488"}
0005432527568	DD8C14	1794 522590	MARIYA YUDINA	{"email": "mariya-yudina-011974@postgrespro.ru", "phone": "+70609168187"}
0005432527569	FBD11C	5930 402615	VLADIMIR GRIGOREV	{"phone": "+70580807568"}
0005432527570	64064D	1350 975489	TATYANA NAZAROVA	{"email": "nazarova-tatyana.19011965@postgrespro.ru", "phone": "+70059908764"}
0005432527571	64064D	1818 625807	ANATOLIY MIKHAYLOV	{"email": "anatoliy_mikhaylov-091962@postgrespro.ru", "phone": "+70546152922"}
0005432527572	D14FB2	1159 618997	ALEKSEY ZHURAVLEV	{"phone": "+70487887588"}
0005432527573	9A8731	3502 751200	ARTEM SERGEEV	{"phone": "+70984452943"}
0005432527574	9A8731	9930 098300	NIKOLAY MOROZOV	{"phone": "+70522144146"}
0005432527575	E72CA7	1569 763387	VERA BELOVA	{"email": "vera-belova-05071983@postgrespro.ru", "phone": "+70994149693"}
0005432527576	FE04F1	4228 339852	LARISA ORLOVA	{"email": "larisaorlova.031969@postgrespro.ru", "phone": "+70416740476"}
0005432527577	FE04F1	0149 713230	OKSANA SOKOLOVA	{"email": "sokolova.o-1964@postgrespro.ru", "phone": "+70552357948"}
0005432527578	D038E8	6326 283169	NATALYA ORLOVA	{"email": "natalyaorlova011957@postgrespro.ru", "phone": "+70952191013"}
0005432527579	D038E8	7506 327058	YULIYA NIKIFOROVA	{"phone": "+70323958772"}
0005432527580	9B678D	3419 631565	OLGA DENISOVA	{"phone": "+70331041005"}
0005432527581	9B678D	2256 023449	ELENA ANDREEVA	{"phone": "+70163940023"}
0005432527582	F1E392	7704 063693	VLADIMIR NAZAROV	{"email": "v_nazarov081955@postgrespro.ru", "phone": "+70954948715"}
0005432527583	F1E392	1789 162746	IGOR POPOV	{"phone": "+70828868991"}
0005432527584	C56076	6185 913156	YULIYA VASILEVA	{"email": "yvasileva.1972@postgrespro.ru", "phone": "+70469256327"}
0005432527585	C56076	0346 140607	ANATOLIY KISELEV	{"email": "kiselev.a_041971@postgrespro.ru", "phone": "+70253064644"}
0005432527586	41F87D	2652 309328	YURIY KAZAKOV	{"phone": "+70430875199"}
0005432527587	41F87D	6136 682139	IRINA DANILOVA	{"email": "irina.danilova-02081970@postgrespro.ru", "phone": "+70475786064"}
0005432527588	49A7E2	9420 298837	ALEKSANDR SMIRNOV	{"phone": "+70989838064"}
0005432527589	49A7E2	8395 731491	EVGENIY AFANASEV	{"phone": "+70041208518"}
0005432527590	7F4117	4251 129287	OLGA IVANOVA	{"email": "olga_ivanova_021968@postgrespro.ru", "phone": "+70808916490"}
0005432527591	869549	9237 868899	PAVEL TARASOV	{"email": "paveltarasov_101980@postgrespro.ru", "phone": "+70648645679"}
0005432527592	596D19	3899 105203	DMITRIY KONOVALOV	{"email": "konovalov-d.19071968@postgrespro.ru", "phone": "+70650562414"}
0005432527593	A8029D	0948 346382	EVGENIY AFANASEV	{"email": "afanasev.evgeniy-061972@postgrespro.ru", "phone": "+70434781175"}
0005432527594	F1E8BE	5920 192218	NIKITA ALEKSEEV	{"email": "nalekseev1955@postgrespro.ru", "phone": "+70808648358"}
0005432527595	45C003	1418 380707	KRISTINA KOZLOVA	{"phone": "+70852360333"}
0005432527596	45C003	5628 419061	ANTONINA ANDREEVA	{"phone": "+70557512518"}
0005432527597	3CA426	6981 791118	POLINA PETROVA	{"phone": "+70964756262"}
0005432527598	3CA426	4097 807437	SERGEY TIMOFEEV	{"phone": "+70769985694"}
0005432527599	013A10	0848 674927	IRINA ABRAMOVA	{"email": "abramova_i1984@postgrespro.ru", "phone": "+70112105829"}
0005432527600	E6EA1A	6689 971931	GALINA ANTONOVA	{"email": "galina_antonova_021974@postgrespro.ru", "phone": "+70436809980"}
0005432527601	618D90	2854 084207	EMIL ALEKSANDROV	{"email": "aleksandrove1972@postgrespro.ru", "phone": "+70991319505"}
0005432527602	618D90	2710 694062	NINA GERASIMOVA	{"phone": "+70151272414"}
0005432527603	AC35AB	7116 307720	ELENA GORBUNOVA	{"email": "e.gorbunova1978@postgrespro.ru", "phone": "+70220506552"}
0005432527604	E878ED	0479 619652	VALENTINA MAKAROVA	{"phone": "+70490630141"}
0005432527605	E878ED	7289 127841	TATYANA KONOVALOVA	{"phone": "+70908711125"}
0005432527606	851DBE	4791 792436	SERGEY BORISOV	{"email": "s-borisov-061967@postgrespro.ru", "phone": "+70694935558"}
0005432527607	851DBE	1438 203197	IVAN MOROZOV	{"phone": "+70851518007"}
0005432527608	A4FD69	5860 625508	DENIS GRIGOREV	{"phone": "+70784056026"}
0005432527609	1AA95B	8130 290433	ALEKSEY BONDARENKO	{"email": "bondarenko.a_24031976@postgrespro.ru", "phone": "+70822771918"}
0005432527610	1AA95B	9662 333227	NATALYA PAVLOVA	{"phone": "+70333080128"}
0005432527611	AAAA5D	0672 002434	VLADIMIR NIKOLAEV	{"email": "v.nikolaev1975@postgrespro.ru", "phone": "+70230321103"}
0005432527612	AAAA5D	7248 041287	SERGEY KARPOV	{"phone": "+70824839960"}
0005432527613	AAAA5D	8307 101056	EVGENIY VOLKOV	{"phone": "+70137515513"}
0005432527614	0959EC	1625 360673	NIKOLAY FILIPPOV	{"phone": "+70328250872"}
0005432527615	69E202	5838 885229	ELMIRA ANISIMOVA	{"phone": "+70168681700"}
0005432527616	1B4C55	6708 310207	KHALIDA CHERNOVA	{"email": "chernova_k101967@postgrespro.ru", "phone": "+70778320686"}
0005432527617	CA957E	5107 832398	SERGEY KUZNECOV	{"phone": "+70946953434"}
0005432527618	987440	0936 726904	VLADIMIR ILIN	{"phone": "+70893676793"}
0005432527619	987440	0555 906228	TAMARA NESTEROVA	{"email": "t-nesterova.011974@postgrespro.ru", "phone": "+70394926989"}
0005432527620	49368F	4888 940828	OLGA ROMANOVA	{"phone": "+70617134922"}
0005432527621	DB1192	7231 650784	ELENA MAKSIMOVA	{"email": "elena-maksimova1967@postgrespro.ru", "phone": "+70469420657"}
0005432527622	DB1192	3068 795616	MIKHAIL IVANOV	{"phone": "+70476711772"}
0005432527623	DB1192	3897 148166	EKATERINA KOROLEVA	{"email": "koroleva-e_1968@postgrespro.ru", "phone": "+70813432201"}
0005432527624	43ED32	2098 425238	VLADIMIR MOISEEV	{"email": "vladimir_moiseev-29011969@postgrespro.ru", "phone": "+70436976767"}
0005432527625	DD5C74	3251 859011	ANNA IVANOVA	{"email": "a.ivanova-1966@postgrespro.ru", "phone": "+70463335491"}
0005432527626	DD5C74	7207 259616	MARINA KONDRATEVA	{"phone": "+70047714565"}
0005432527627	3A8C33	4429 914248	SVETLANA KUZNECOVA	{"email": "s.kuznecova-30061979@postgrespro.ru", "phone": "+70800153884"}
0005432527628	738A43	3190 173630	MIKHAIL SCHERBAKOV	{"phone": "+70168162873"}
0005432527629	738A43	9333 225554	MATVEY CHERNOV	{"phone": "+70129374242"}
0005432527630	07837F	3235 057747	IGOR KUZNECOV	{"phone": "+70187488978"}
0005432527631	07837F	6752 189074	VIKTOR MAKAROV	{"email": "makarov_v_1974@postgrespro.ru", "phone": "+70866638316"}
0005432527632	840D87	1364 820615	YURIY ZHUKOV	{"phone": "+70163582605"}
0005432527633	840D87	4755 742663	ANASTASIYA MALYSHEVA	{"email": "malyshevaanastasiya1968@postgrespro.ru", "phone": "+70939660809"}
0005432527634	342725	4869 458791	GUZEL SOKOLOVA	{"email": "sokolova-g.041968@postgrespro.ru", "phone": "+70925679539"}
0005432527635	1D0837	1764 998774	ANNA MOISEEVA	{"phone": "+70524469659"}
0005432527636	E5728B	1847 936960	VLADIMIR TIKHONOV	{"email": "tikhonov-vladimir-1976@postgrespro.ru", "phone": "+70607270771"}
0005432527637	D7AB6C	4153 854608	VLADIMIR NIKITIN	{"phone": "+70398534158"}
0005432527638	6BC568	7098 809129	VLADIMIR DAVYDOV	{"phone": "+70004405968"}
0005432527639	6BC568	2976 537128	SVETLANA KONDRATEVA	{"email": "skondrateva1968@postgrespro.ru", "phone": "+70210017634"}
0005432527640	E2C848	6171 494230	MAKSIM PAVLOV	{"phone": "+70111746239"}
0005432527641	811AA2	9680 878422	EKATERINA SMIRNOVA	{"phone": "+70875187557"}
0005432527642	F7CF2F	3652 947885	ALEKSANDR DAVYDOV	{"email": "a-davydov.06121976@postgrespro.ru", "phone": "+70758776414"}
0005432527643	196932	4731 893848	NADEZHDA MALYSHEVA	{"email": "malysheva_nadezhda_28061967@postgrespro.ru", "phone": "+70696904390"}
0005432527644	0BAFAB	5701 636784	VIKTOR KUZMIN	{"phone": "+70272641634"}
0005432527645	997B8E	3355 792285	ALEKSANDR KONOVALOV	{"email": "a-konovalov-1982@postgrespro.ru", "phone": "+70351521123"}
0005432527646	5A02EB	0000 698843	ZINAIDA GERASIMOVA	{"email": "zinaida_gerasimova_061965@postgrespro.ru", "phone": "+70806850072"}
0005432527647	C90BC6	5251 558879	NIKOLAY DAVYDOV	{"email": "davydovnikolay_1973@postgrespro.ru", "phone": "+70229960197"}
0005432527648	4B77B9	6975 246745	SERGEY NAUMOV	{"email": "sergey.naumov1969@postgrespro.ru", "phone": "+70246285873"}
0005432527649	D244F4	6463 550293	SERGEY STEPANOV	{"email": "s.stepanov-081984@postgrespro.ru", "phone": "+70020948520"}
0005432527650	D244F4	8333 605513	ANATOLIY GERASIMOV	{"email": "gerasimov-anatoliy15081971@postgrespro.ru", "phone": "+70906529489"}
0005432527651	408716	2684 983602	EKATERINA KUZMINA	{"email": "kuzmina.e_1972@postgrespro.ru", "phone": "+70321414371"}
0005432527652	408716	3860 019376	ELENA VOLKOVA	{"email": "volkova_e_02081977@postgrespro.ru", "phone": "+70117111044"}
0005432527653	C469AF	2425 772668	LIDIYA ALEKSANDROVA	{"phone": "+70195787349"}
0005432527654	B81A08	6145 138408	ELENA MOROZOVA	{"email": "morozova-elena-011971@postgrespro.ru", "phone": "+70353709187"}
0005432527655	520F61	1511 734391	ALEKSANDRA DANILOVA	{"email": "a_danilova-12111963@postgrespro.ru", "phone": "+70678595852"}
0005432527656	520F61	7713 118888	VLADIMIR DMITRIEV	{"phone": "+70500999602"}
0005432527657	89EA3F	1701 285932	VLADIMIR STEPANOV	{"email": "stepanov_v-1962@postgrespro.ru", "phone": "+70161402392"}
0005432527658	995151	1023 101732	ROMAN NIKITIN	{"email": "nikitin_roman_1962@postgrespro.ru", "phone": "+70334425374"}
0005432527659	995151	4483 981747	TAMARA MATVEEVA	{"phone": "+70814525268"}
0005432527660	124665	8709 033736	EGOR POPOV	{"email": "e-popov-1982@postgrespro.ru", "phone": "+70405604191"}
0005432527661	5838D0	8925 970228	IRINA KOROLEVA	{"email": "korolevai_25091970@postgrespro.ru", "phone": "+70801808772"}
0005432527662	E3A447	1885 925964	LYUBOV FEDOROVA	{"phone": "+70057644702"}
0005432527663	E3A447	1547 420999	DMITRIY SOKOLOV	{"phone": "+70067115439"}
0005432527664	BE5884	1629 027873	NATALYA YAKOVLEVA	{"phone": "+70267214483"}
0005432527665	BE5884	1464 303047	VYACHESLAV AFANASEV	{"phone": "+70504845820"}
0005432527666	BE5884	8165 194324	EVGENIY RODIONOV	{"email": "e.rodionov.1974@postgrespro.ru", "phone": "+70035964870"}
0005432527667	5333BA	9718 489396	NADEZHDA NIKITINA	{"email": "n.nikitina-01101984@postgrespro.ru", "phone": "+70261731016"}
0005432527668	5333BA	6525 331113	EVGENIY BELOV	{"email": "belov_e_081975@postgrespro.ru", "phone": "+70313716693"}
0005432527669	42B9B2	1741 162985	ALEKSEY KUDRYASHOV	{"email": "a-kudryashov-1970@postgrespro.ru", "phone": "+70199597485"}
0005432527670	42B9B2	2100 024604	ALEKSANDR VASILEV	{"phone": "+70373010197"}
0005432527671	B0D02F	2899 316619	NADEZHDA FROLOVA	{"email": "nadezhda_frolova.081978@postgrespro.ru", "phone": "+70800095941"}
0005432527672	B0D02F	4334 699297	RAISA NAUMOVA	{"phone": "+70784645405"}
0005432527673	B0D02F	3030 679323	YURIY ORLOV	{"phone": "+70383923490"}
0005432527674	A13181	0708 975766	EVGENIY NIKITIN	{"phone": "+70301847715"}
0005432527675	6B84FC	7506 404843	ANNA RYABOVA	{"phone": "+70959717253"}
0005432527676	AC3D73	2222 932336	ALEKSANDR ALEKSEEV	{"email": "alekseev-a.121964@postgrespro.ru", "phone": "+70112210365"}
0005432527677	A1ED7C	0470 248353	OKSANA VOLKOVA	{"email": "oksana_volkova091969@postgrespro.ru", "phone": "+70756251736"}
0005432527678	A1ED7C	1541 055893	VYACHESLAV AFANASEV	{"email": "afanasevvyacheslav_09101970@postgrespro.ru", "phone": "+70815289946"}
0005432527679	A1ED7C	6660 808423	LIDIYA KAZAKOVA	{"email": "lidiya-kazakova1971@postgrespro.ru", "phone": "+70643657764"}
0005432527680	B604DC	0731 802469	LYUDMILA DENISOVA	{"email": "denisovalyudmila1968@postgrespro.ru", "phone": "+70643834999"}
0005432527681	C2C17C	2594 646603	SERGEY PETROV	{"phone": "+70985032484"}
0005432527682	65E24A	2247 004012	ALSU IVANOVA	{"email": "a-ivanova-04021975@postgrespro.ru", "phone": "+70570211375"}
0005432527683	C1CC9A	7593 635760	NINA NESTEROVA	{"email": "nesterova-n18121964@postgrespro.ru", "phone": "+70073117008"}
0005432527684	C1CC9A	6939 989021	ARTEM SMIRNOV	{"email": "smirnov_artem061977@postgrespro.ru", "phone": "+70768177530"}
0005432527685	FA4671	4688 690980	STANISLAV KOROLEV	{"phone": "+70931697466"}
0005432527686	3710B9	8923 461497	LIDIYA SCHERBAKOVA	{"phone": "+70682969323"}
0005432527687	3710B9	9727 650675	ALEKSANDRA LEBEDEVA	{"email": "aleksandra_lebedeva_051980@postgrespro.ru", "phone": "+70175475361"}
0005432527688	3710B9	2864 073300	EGOR KUZNECOV	{"email": "egor.kuznecov071966@postgrespro.ru", "phone": "+70657627130"}
0005432527690	9489EF	7767 192692	EGOR ZAYCEV	{"email": "zaycevegor_051975@postgrespro.ru", "phone": "+70347739223"}
0005432527691	C81498	9839 340140	DANIIL IVANOV	{"phone": "+70890157482"}
0005432527692	C81498	8381 480979	DANIL FROLOV	{"email": "frolov.danil-101979@postgrespro.ru", "phone": "+70816711356"}
0005432527693	5BC141	4138 457548	EGOR MAKAROV	{"phone": "+70788575612"}
0005432527694	0A5146	6927 979289	VALERIY KUZMIN	{"email": "kuzmin-valeriy.091979@postgrespro.ru", "phone": "+70256247818"}
0005432527695	0A5146	5270 983411	SVETLANA STEPANOVA	{"email": "s.stepanova.1961@postgrespro.ru", "phone": "+70111617729"}
0005432527696	9DDD64	2098 960879	DANILA MIKHAYLOV	{"phone": "+70263460733"}
0005432527697	A1A4E7	9773 484527	LARISA ILINA	{"email": "ilina_larisa_1967@postgrespro.ru", "phone": "+70383671089"}
0005432527698	DFE8F9	5739 150825	IRINA KISELEVA	{"phone": "+70577607120"}
0005432527699	371B58	6662 633774	LYUBOV KONOVALOVA	{"phone": "+70512537141"}
0005432527700	306594	1077 147871	STANISLAV SOROKIN	{"email": "sorokin-stanislav071975@postgrespro.ru", "phone": "+70917386021"}
0005432527701	306594	1918 116450	ANASTASIYA VOLKOVA	{"email": "anastasiya-volkova_1975@postgrespro.ru", "phone": "+70925779837"}
0005432527702	EDFB9B	1867 900655	ANNA ILINA	{"email": "a_ilina_1973@postgrespro.ru", "phone": "+70794560217"}
0005432527703	EDFB9B	4139 228771	IRINA ZAKHAROVA	{"email": "i.zakharova_1981@postgrespro.ru", "phone": "+70035795146"}
0005432527704	25213A	2396 027688	ELENA KOZLOVA	{"phone": "+70846813126"}
0005432527705	25213A	1137 083045	MARGARITA BORISOVA	{"phone": "+70816884331"}
0005432527706	C047E6	1492 951157	MAKSIM TIKHONOV	{"email": "m-tikhonov-101967@postgrespro.ru", "phone": "+70627243809"}
0005432527707	C047E6	5740 879700	LYUDMILA ILINA	{"email": "lyudmilailina_1972@postgrespro.ru", "phone": "+70703991581"}
0005432527708	C047E6	4224 399664	YURIY MOROZOV	{"phone": "+70250849703"}
0005432527709	155DBA	1119 038492	SNEZHANA SIDOROVA	{"email": "snezhanasidorova-30091979@postgrespro.ru", "phone": "+70581469619"}
0005432527710	155DBA	2197 300611	VIKTORIYA SMIRNOVA	{"email": "smirnova-viktoriya-05031965@postgrespro.ru", "phone": "+70601115138"}
0005432527711	B37082	1012 339762	VIKTOR KUZNECOV	{"email": "kuznecov.v.17101975@postgrespro.ru", "phone": "+70221061542"}
0005432527712	B5983B	8120 791272	OLGA TARASOVA	{"phone": "+70420585292"}
0005432527713	B5983B	4187 586374	ALEKSANDR POPOV	{"email": "a_popov.1979@postgrespro.ru", "phone": "+70636377404"}
0005432527714	889C19	9762 744234	ELENA MALYSHEVA	{"phone": "+70420093041"}
0005432527715	EC801A	5177 974019	VYACHESLAV IVANOV	{"email": "v.ivanov-081980@postgrespro.ru", "phone": "+70268348233"}
0005432527716	AFEF3E	4593 836943	VIKTOR TIMOFEEV	{"phone": "+70515658983"}
0005432527717	C6A035	1811 255380	VIKTOR NAUMOV	{"email": "v-naumov1968@postgrespro.ru", "phone": "+70349907710"}
0005432527718	1A6937	2847 177959	LYUBOV POPOVA	{"email": "l_popova.27051965@postgrespro.ru", "phone": "+70296695163"}
0005432527719	1A6937	7974 985587	VLADIMIR PAVLOV	{"phone": "+70800861098"}
0005432527720	B2D063	8785 471367	GENNADIY EGOROV	{"email": "gennadiyegorov-1971@postgrespro.ru", "phone": "+70361397030"}
0005432527721	1A78C4	4827 973867	BORIS MATVEEV	{"email": "borismatveev_1969@postgrespro.ru", "phone": "+70173352989"}
0005432527722	78EA7D	5278 569213	VALERIY TARASOV	{"phone": "+70697329398"}
0005432527723	1B7F82	6594 035597	ELENA MELNIKOVA	{"phone": "+70855643630"}
0005432527724	13BF19	7262 069450	VIKTOR AFANASEV	{"email": "afanasev.viktor.17101970@postgrespro.ru", "phone": "+70892574692"}
0005432527725	E00687	0928 489075	LARISA ZHURAVLEVA	{"phone": "+70927860377"}
0005432527726	41446E	4393 733626	IRINA KUZNECOVA	{"phone": "+70504544789"}
0005432527727	756A02	3792 861652	OLGA SIDOROVA	{"email": "olga.sidorova.14101965@postgrespro.ru", "phone": "+70876933565"}
0005432527728	3E2ADE	0580 776935	GENNADIY ZAKHAROV	{"phone": "+70333458759"}
0005432527729	3E2ADE	9898 031155	NATALYA LUKYANOVA	{"phone": "+70472147148"}
0005432527730	3E2ADE	2339 937616	VLADIMIR PAVLOV	{"email": "vladimir.pavlov-1980@postgrespro.ru", "phone": "+70836776775"}
0005432527731	9E108D	9051 245140	MAKSIM BELOV	{"email": "belovmaksim21071972@postgrespro.ru", "phone": "+70228053592"}
0005432527732	7CF0A4	1853 218960	OLGA TARASOVA	{"phone": "+70986920535"}
0005432527733	A6E418	7313 111401	GALINA KISELEVA	{"phone": "+70645666528"}
0005432527734	A6E418	0969 516301	KRISTINA ARKHIPOVA	{"email": "arkhipova_kristina-28101973@postgrespro.ru", "phone": "+70769545178"}
0005432527735	07D170	5035 867851	DAMIR SOKOLOV	{"email": "sokolov.damir_121972@postgrespro.ru", "phone": "+70675015524"}
0005432527736	FF8C3C	8030 099124	SVETLANA VLASOVA	{"email": "svetlana.vlasova-19071987@postgrespro.ru", "phone": "+70238040336"}
0005432527737	6920DC	5795 904013	TATYANA KUZMINA	{"email": "t.kuzmina.18111969@postgrespro.ru", "phone": "+70774501796"}
0005432527738	A1D705	8820 697065	MAKSIM ALEKSANDROV	{"phone": "+70895999198"}
0005432527739	769323	3666 030011	MIKHAIL FILIPPOV	{"email": "filippovm-07101977@postgrespro.ru", "phone": "+70758941943"}
0005432527740	769323	9945 929234	YULIYA FEDOROVA	{"email": "fedorova-yuliya101977@postgrespro.ru", "phone": "+70859982241"}
0005432527741	0BEB1E	5961 491228	BORIS SERGEEV	{"email": "boris-sergeev1979@postgrespro.ru", "phone": "+70654686504"}
0005432527742	0BEB1E	8148 579324	MIKHAIL PAVLOV	{"phone": "+70582912325"}
0005432527743	7E3D5E	2802 100502	VERA DMITRIEVA	{"email": "dmitrieva.vera.111969@postgrespro.ru", "phone": "+70340668216"}
0005432527744	7E3D5E	3896 377181	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya-1975@postgrespro.ru", "phone": "+70423490051"}
0005432527745	8B2ABF	0913 462542	OLEG FEDOTOV	{"phone": "+70186767667"}
0005432527746	8B2ABF	5986 794603	ALEKSANDR NIKOLAEV	{"phone": "+70770820362"}
0005432527747	FF35D2	5582 689630	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a-28051978@postgrespro.ru", "phone": "+70601585845"}
0005432527748	FF35D2	0751 263776	NATALYA GERASIMOVA	{"phone": "+70185199441"}
0005432527749	6C3BA5	2433 854578	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin13091972@postgrespro.ru", "phone": "+70167921418"}
0005432527750	1BDE70	3823 248975	OLGA ALEKSEEVA	{"phone": "+70941205977"}
0005432527751	75B99B	2828 856830	AZAT SAVELEV	{"phone": "+70307021459"}
0005432527752	F36C73	7212 979641	VIKTORIYA VASILEVA	{"email": "viktoriya_vasileva-01011974@postgrespro.ru", "phone": "+70095541528"}
0005432527753	F36C73	5733 617619	SERGEY GAVRILOV	{"email": "sergeygavrilov081976@postgrespro.ru", "phone": "+70057646687"}
0005432527754	C9D4DC	7834 395132	ALEKSANDR GRIGOREV	{"phone": "+70670509916"}
0005432527755	EA0A7C	3404 200490	MAKSIM FILIPPOV	{"phone": "+70458412006"}
0005432527756	1C2F3A	7885 741498	ZINAIDA VASILEVA	{"email": "zinaida_vasileva.11021974@postgrespro.ru", "phone": "+70259302772"}
0005432527757	1C2F3A	7148 420527	RUSTEM YAKOVLEV	{"phone": "+70595061922"}
0005432527758	AC624F	1481 193954	ANASTASIYA IVANOVA	{"phone": "+70328803882"}
0005432527759	702266	5238 296003	ELENA KUZNECOVA	{"email": "kuznecova-e101969@postgrespro.ru", "phone": "+70289440519"}
0005432527760	702266	7521 987132	NIKOLAY SMIRNOV	{"email": "n-smirnov.1975@postgrespro.ru", "phone": "+70008048588"}
0005432527761	6514BC	2512 850738	MARIYA ILINA	{"email": "mariya_ilina.13071970@postgrespro.ru", "phone": "+70767233981"}
0005432527762	7BCDD8	5647 486886	TATYANA ANDREEVA	{"phone": "+70739813679"}
0005432527763	376DB1	0460 768144	TATYANA MAKSIMOVA	{"phone": "+70313309550"}
0005432527764	376DB1	2392 473945	BOGDAN KUZNECOV	{"email": "kuznecov-bogdan09121976@postgrespro.ru", "phone": "+70937146645"}
0005432527765	18EE11	2650 220587	SERGEY POPOV	{"email": "popov-s_011965@postgrespro.ru", "phone": "+70053095601"}
0005432527766	3F94CE	2745 506693	GALINA MELNIKOVA	{"phone": "+70265582898"}
0005432527767	3F94CE	6585 475366	SERGEY VASILEV	{"email": "vasilev-sergey-27041972@postgrespro.ru", "phone": "+70575939427"}
0005432527768	78E115	1046 289949	SVETLANA DAVYDOVA	{"email": "s_davydova_16051963@postgrespro.ru", "phone": "+70730437941"}
0005432527769	78E115	6936 242280	ANDREY RODIONOV	{"phone": "+70581535553"}
0005432527770	78E115	2401 024158	VIKTORIYA KRASNOVA	{"email": "v.krasnova_101965@postgrespro.ru", "phone": "+70816200699"}
0005432527771	3B2F7A	4501 060870	VIKTOR FOMIN	{"email": "fominviktor_23101982@postgrespro.ru", "phone": "+70321627944"}
0005432527772	C6FEE2	4170 770061	ELENA SEMENOVA	{"email": "semenova-elena_041977@postgrespro.ru", "phone": "+70527103363"}
0005432527773	56AB59	4982 454329	KONSTANTIN FILIPPOV	{"phone": "+70004699330"}
0005432527774	0D49FA	8332 159554	ALINA RODIONOVA	{"email": "rodionova-alina1976@postgrespro.ru", "phone": "+70066529015"}
0005432527775	855739	7608 095243	YURIY KUZNECOV	{"email": "yuriykuznecov_051966@postgrespro.ru", "phone": "+70270105085"}
0005432527776	297560	5499 160431	VLADIMIR TARASOV	{"phone": "+70616388683"}
0005432527777	4A10C4	8817 052398	SVETLANA KULIKOVA	{"phone": "+70116534069"}
0005432527778	4E12F1	2999 044038	SERGEY FILIPPOV	{"email": "sergeyfilippov-1972@postgrespro.ru", "phone": "+70231469532"}
0005432527779	4E12F1	7773 438149	VASILISA PETROVA	{"phone": "+70386791911"}
0005432527780	6E85FB	6653 445727	ALEKSEY KOROLEV	{"phone": "+70763799953"}
0005432527781	A5E736	2948 363157	SERGEY AFANASEV	{"email": "s.afanasev.1967@postgrespro.ru", "phone": "+70419704380"}
0005432527782	A8C235	8429 867950	GALINA KOVALEVA	{"email": "kovalevagalina041985@postgrespro.ru", "phone": "+70702518678"}
0005432527783	A8C235	6495 918382	STEPAN GORBUNOV	{"phone": "+70623502140"}
0005432527784	1EC8AC	8569 407362	VYACHESLAV VOROBEV	{"phone": "+70277538786"}
0005432527785	FF85FB	8951 397220	KLAVDIYA OSIPOVA	{"phone": "+70865886691"}
0005432527786	4D4FAE	6400 546755	IGOR GORBUNOV	{"email": "gorbunov.i-1975@postgrespro.ru", "phone": "+70899347069"}
0005432527787	4D4FAE	5313 669628	ILYA GUSEV	{"email": "i_gusev.12121971@postgrespro.ru", "phone": "+70343036897"}
0005432527788	D48075	8087 663987	MIKHAIL KONOVALOV	{"email": "konovalov.m-111977@postgrespro.ru", "phone": "+70810931215"}
0005432527789	D1BB26	6535 024569	GALINA IVANOVA	{"phone": "+70591513929"}
0005432527790	C3E93E	1614 494892	OLESYA SEMENOVA	{"phone": "+70612772219"}
0005432527791	C3E93E	7282 158508	VITALIY IVANOV	{"email": "ivanov.vitaliy-1974@postgrespro.ru", "phone": "+70698688443"}
0005432527792	9657AD	7783 481005	ELENA MOROZOVA	{"phone": "+70420972226"}
0005432527793	9657AD	9003 042139	VALENTINA SOROKINA	{"email": "vsorokina1969@postgrespro.ru", "phone": "+70211599382"}
0005432527794	998455	2499 777642	ZINAIDA BELOVA	{"email": "z-belova11081962@postgrespro.ru", "phone": "+70504259863"}
0005432527795	998455	3957 627467	YULIYA KOROLEVA	{"phone": "+70232783154"}
0005432527796	28DC26	9251 374598	VLADISLAV ANTONOV	{"email": "v.antonov061972@postgrespro.ru", "phone": "+70947088669"}
0005432527797	FBD50D	8098 873699	ELINA NIKITINA	{"phone": "+70981771013"}
0005432527798	40DB60	8791 690794	VLADIMIR MATVEEV	{"email": "matveev_vladimir-061976@postgrespro.ru", "phone": "+70977615453"}
0005432527799	12CFCC	5249 524264	ANDREY SOKOLOV	{"phone": "+70849414014"}
0005432527800	06C1ED	4201 058736	DMITRIY ISAEV	{"phone": "+70457198799"}
0005432527801	0CF922	5664 404139	NINA FROLOVA	{"email": "frolova-n041975@postgrespro.ru", "phone": "+70992603295"}
0005432527802	C6B3A9	4661 117330	ANASTASIYA KOVALEVA	{"email": "kovaleva_anastasiya111980@postgrespro.ru", "phone": "+70311034307"}
0005432527803	C6B3A9	3878 962208	DENIS ZHURAVLEV	{"phone": "+70392461082"}
0005432527804	891EE3	6796 664092	ALEKSANDR GUSEV	{"phone": "+70533549787"}
0005432527805	891EE3	8206 993160	VIKTOR SEMENOV	{"email": "semenov.v-1976@postgrespro.ru", "phone": "+70369618612"}
0005432527806	86DFF9	4115 105324	TAISIYA EFREMOVA	{"email": "taisiya-efremova_25121975@postgrespro.ru", "phone": "+70186018186"}
0005432527807	E4232D	6268 017781	YULIYA STEPANOVA	{"email": "y.stepanova-091982@postgrespro.ru", "phone": "+70197445674"}
0005432527808	1AE1F7	8745 499191	NINA ISAEVA	{"phone": "+70086565807"}
0005432527809	8E023A	7107 132321	LYUBOV MELNIKOVA	{"phone": "+70709556771"}
0005432527810	66599D	8374 219695	GULSHAT SAVELEVA	{"email": "gulshat.saveleva051970@postgrespro.ru", "phone": "+70825631936"}
0005432527811	F0341F	7815 968923	NIKOLAY MIKHAYLOV	{"email": "nikolaymikhaylov_091967@postgrespro.ru", "phone": "+70560883111"}
0005432527812	D1D49A	9922 315960	OLGA KRASNOVA	{"phone": "+70476482705"}
0005432527813	D1D49A	3427 502790	SERGEY GAVRILOV	{"email": "s.gavrilov_1968@postgrespro.ru", "phone": "+70695789454"}
0005432527814	AECFCF	7438 963063	ANNA POPOVA	{"email": "popova-anna_061965@postgrespro.ru", "phone": "+70536441403"}
0005432527815	E4D42A	0016 872580	ELENA ANTONOVA	{"email": "e_antonova.26011971@postgrespro.ru", "phone": "+70642743959"}
0005432527816	121A29	2400 872002	EVGENIY DENISOV	{"email": "denisov-e_021967@postgrespro.ru", "phone": "+70802269746"}
0005432527817	28A1EA	7566 654571	ANDREY KUZNECOV	{"email": "andrey-kuznecov1973@postgrespro.ru", "phone": "+70535529945"}
0005432527818	7278B1	9572 331335	ANATOLIY ANDREEV	{"email": "andreev.a_23021967@postgrespro.ru", "phone": "+70092055626"}
0005432527819	0AAA52	7498 958146	EVGENIY ORLOV	{"phone": "+70313120563"}
0005432527820	B1F9A2	4855 403313	ELENA FADEEVA	{"phone": "+70675785893"}
0005432527821	66980F	0252 882125	NATALYA OSIPOVA	{"email": "n.osipova.22081967@postgrespro.ru", "phone": "+70073645401"}
0005432527822	CCCA1B	4775 270399	VALENTINA RODIONOVA	{"email": "rodionova-valentina-08101964@postgrespro.ru", "phone": "+70782055547"}
0005432527823	1FA73B	8722 209035	VALERIY SOROKIN	{"phone": "+70184501714"}
0005432527824	B1816E	6958 277514	KONSTANTIN OSIPOV	{"phone": "+70901504558"}
0005432527825	E5E088	3312 772663	VASILIY KUZNECOV	{"phone": "+70036210143"}
0005432527826	ACDF0A	3761 147042	ANTON MEDVEDEV	{"phone": "+70724924529"}
0005432527827	09D231	1928 572743	IRINA RODIONOVA	{"email": "rodionova.i14121981@postgrespro.ru", "phone": "+70515772933"}
0005432527828	BD2A08	6889 639294	VITALIY OSIPOV	{"phone": "+70129351530"}
0005432527829	84F61E	3991 305207	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev_1971@postgrespro.ru", "phone": "+70051547183"}
0005432527830	F3CB9B	2473 665167	MAKSIM BONDARENKO	{"email": "bondarenko-maksim_1970@postgrespro.ru", "phone": "+70737613496"}
0005432527831	FEB1E0	1180 089908	OKSANA NIKOLAEVA	{"phone": "+70426421391"}
0005432527832	CA925D	7942 404998	VALENTINA OSIPOVA	{"phone": "+70904475390"}
0005432527833	9655F6	2953 908894	BULAT MOISEEV	{"email": "b-moiseev_20081978@postgrespro.ru", "phone": "+70563039743"}
0005432527834	F5210B	2867 911842	IGOR SOKOLOV	{"phone": "+70507751586"}
0005432527835	3BAA97	4076 453051	LYUBOV ZAKHAROVA	{"phone": "+70144110865"}
0005432527836	4A34FA	0224 599627	VIKTOR ILIN	{"phone": "+70610936408"}
0005432527837	4A34FA	2993 582404	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev-081969@postgrespro.ru", "phone": "+70294533867"}
0005432527838	3BB830	8807 020037	NIKOLAY FEDOROV	{"email": "fedorov.nikolay-011971@postgrespro.ru", "phone": "+70269833981"}
0005432527839	C5A873	9664 258547	NATALIYA YAKOVLEVA	{"phone": "+70954529223"}
0005432527840	C5A873	3061 522581	VLADIMIR SHEVCHENKO	{"email": "vshevchenko.051973@postgrespro.ru", "phone": "+70960029173"}
0005432527841	6D8A03	7984 119003	SVETLANA ZHURAVLEVA	{"phone": "+70680551203"}
0005432527842	056398	4700 519522	PAVEL FILIPPOV	{"phone": "+70706097230"}
0005432527843	72E646	7936 679293	ELENA EFREMOVA	{"email": "efremova_elena121982@postgrespro.ru", "phone": "+70028414550"}
0005432527844	72E646	9266 443256	NIKOLAY VASILEV	{"phone": "+70779893238"}
0005432527845	5AF6D1	1481 587015	ALEKSEY BORISOV	{"email": "borisov-a1968@postgrespro.ru", "phone": "+70233487897"}
0005432527846	383E4D	3240 177827	ANASTASIYA SOROKINA	{"phone": "+70612807935"}
0005432527847	383E4D	3228 444876	LYUDMILA BELYAEVA	{"email": "belyaeval-021970@postgrespro.ru", "phone": "+70092063725"}
0005432527848	9AEE0A	5298 262795	SAMVEL POPOV	{"phone": "+70986029554"}
0005432527849	9AEE0A	3845 561234	IRINA BOGDANOVA	{"email": "bogdanova.i.25111987@postgrespro.ru", "phone": "+70190624171"}
0005432527850	E47A50	0482 224450	NIKOLAY GRIGOREV	{"phone": "+70641352153"}
0005432527851	C93AFF	8667 859935	IRINA BARANOVA	{"phone": "+70697730186"}
0005432527852	29BF4E	5124 230719	ILYA TIKHONOV	{"email": "ilya_tikhonov25051971@postgrespro.ru", "phone": "+70522924456"}
0005432527853	29BF4E	8872 176470	EVGENIYA LEBEDEVA	{"phone": "+70976536997"}
0005432527854	1EEDD8	5068 170098	GALINA IVANOVA	{"email": "ivanovagalina021969@postgrespro.ru", "phone": "+70441648509"}
0005432527855	12CD14	3452 374562	ANNA VASILEVA	{"email": "anna_vasileva_1984@postgrespro.ru", "phone": "+70894887701"}
0005432527856	264395	9032 046613	SERGEY ANDREEV	{"email": "andreev-s.1971@postgrespro.ru", "phone": "+70533242821"}
0005432527857	0E5C0F	6626 042538	VIKTOR MATVEEV	{"email": "v.matveev_1979@postgrespro.ru", "phone": "+70693898532"}
0005432527858	0E5C0F	5338 795779	VIKTORIYA MOISEEVA	{"phone": "+70897434594"}
0005432527859	9AB684	8140 796896	ALEKSANDR ILIN	{"phone": "+70627742688"}
0005432527860	9AB684	4581 163368	ALEKSANDR EGOROV	{"phone": "+70110804314"}
0005432527861	8CE38F	0058 453982	DANIS KISELEV	{"phone": "+70665355378"}
0005432527862	8CE38F	8729 912788	EMIL RODIONOV	{"phone": "+70096429985"}
0005432527863	3E589D	1654 152912	SERGEY BARANOV	{"email": "baranov-s-16031976@postgrespro.ru", "phone": "+70699742063"}
0005432527864	3E589D	7511 162917	ILDAR ANDREEV	{"phone": "+70068235860"}
0005432527865	3E589D	2389 036778	SERGEY TARASOV	{"phone": "+70957334145"}
0005432527866	70A1F5	8869 472950	MAKSIM BARANOV	{"email": "maksim.baranov1968@postgrespro.ru", "phone": "+70528058753"}
0005432527867	FBAAD8	5369 582384	DMITRIY SOROKIN	{"phone": "+70740186499"}
0005432527868	5376A7	7202 857488	ANVAR MIRONOV	{"email": "a.mironov_101964@postgrespro.ru", "phone": "+70775953652"}
0005432527869	340FC0	6374 211093	LYUDMILA KOMAROVA	{"email": "l_komarova.24031966@postgrespro.ru", "phone": "+70703759928"}
0005432527870	ED82E6	7044 911359	SERGEY ZHUKOV	{"phone": "+70195839394"}
0005432527871	F0A5C8	5741 655557	ANASTASIYA KRASNOVA	{"phone": "+70289702502"}
0005432527872	A81B69	3247 726202	VITALIY ROMANOV	{"email": "v.romanov-20041975@postgrespro.ru", "phone": "+70028806705"}
0005432527873	A81B69	5443 786403	VLADIMIR ZHURAVLEV	{"phone": "+70359880342"}
0005432527874	63FFFD	1721 869534	LEV KUZNECOV	{"phone": "+70299332572"}
0005432527875	63FFFD	5199 999122	IRINA POPOVA	{"email": "i-popova_051975@postgrespro.ru", "phone": "+70994228648"}
0005432527876	F923AF	0365 359759	OLGA TROFIMOVA	{"email": "olga_trofimova.021972@postgrespro.ru", "phone": "+70417729225"}
0005432527877	6F0B6B	3092 456194	TATYANA MATVEEVA	{"phone": "+70674735226"}
0005432527878	6F0B6B	4614 719593	EKATERINA ALEKSEEVA	{"phone": "+70715394796"}
0005432527879	7B1B5C	3650 253229	SERGEY GRIGOREV	{"email": "s.grigorev071968@postgrespro.ru", "phone": "+70644280454"}
0005432527880	7B1B5C	0088 289522	VLADISLAV SIDOROV	{"email": "sidorovvladislav_13101964@postgrespro.ru", "phone": "+70674064561"}
0005432527881	AF1980	0827 885958	MARINA SERGEEVA	{"email": "sergeeva_m05071961@postgrespro.ru", "phone": "+70529766782"}
0005432527882	C1A668	4085 382306	EVGENIY KUDRYASHOV	{"email": "kudryashov-evgeniy.1973@postgrespro.ru", "phone": "+70372138024"}
0005432527883	C1A668	2839 979429	ANNA MATVEEVA	{"email": "anna-matveeva.111976@postgrespro.ru", "phone": "+70890458225"}
0005432527884	14C617	9089 702798	ELENA ROMANOVA	{"phone": "+70292766791"}
0005432527885	89902F	5959 262335	NIKOLAY FEDOROV	{"phone": "+70029060904"}
0005432527886	89902F	6556 905377	EVGENIYA KUDRYASHOVA	{"email": "kudryashova_evgeniya-14011970@postgrespro.ru", "phone": "+70407009795"}
0005432527887	AED9D6	4050 691898	IRINA VOROBEVA	{"phone": "+70782611187"}
0005432527888	193D4B	0083 648303	SERGEY NIKITIN	{"email": "nikitin_s.21031973@postgrespro.ru", "phone": "+70949649350"}
0005432527889	193D4B	6607 322894	OLGA VASILEVA	{"phone": "+70202659206"}
0005432527890	BB8BB1	7369 909404	ELENA KOZLOVA	{"email": "kozlova-e-011976@postgrespro.ru", "phone": "+70945232911"}
0005432527891	AA52F7	3803 544676	NAILYA NESTEROVA	{"email": "nesterova_n.101975@postgrespro.ru", "phone": "+70279104792"}
0005432527892	0CC45B	0593 184418	ROMAN ALEKSEEV	{"email": "roman_alekseev071968@postgrespro.ru", "phone": "+70441297544"}
0005432527893	235404	3073 788082	ALEKSANDRA KULIKOVA	{"phone": "+70405393616"}
0005432527894	235404	7478 452041	ZINAIDA MELNIKOVA	{"email": "z.melnikova.051969@postgrespro.ru", "phone": "+70918262103"}
0005432527895	2DAC1D	5856 887939	MARIYA AFANASEVA	{"phone": "+70498096694"}
0005432527896	2DAC1D	5690 800158	VIKTORIYA OVCHINNIKOVA	{"email": "viktoriyaovchinnikova_1977@postgrespro.ru", "phone": "+70497490779"}
0005432527897	062F23	0819 484706	VLADIMIR SOROKIN	{"phone": "+70159211749"}
0005432527898	024B31	4044 569321	MARGARITA LAZAREVA	{"phone": "+70491143939"}
0005432527899	5C3D62	1494 295587	ALBINA ZHUKOVA	{"email": "azhukova.25111974@postgrespro.ru", "phone": "+70128147050"}
0005432527900	5C3D62	8863 007526	VYACHESLAV DMITRIEV	{"email": "dmitriev.v.1978@postgrespro.ru", "phone": "+70894903571"}
0005432527901	5C3D62	9200 428296	ELENA KOMAROVA	{"phone": "+70457661783"}
0005432527902	ED46A6	9546 561137	ARTEM MAKAROV	{"email": "makarov-artem.1979@postgrespro.ru", "phone": "+70774647439"}
0005432527903	DE7462	1456 268166	RAISA MEDVEDEVA	{"email": "medvedeva.raisa.1968@postgrespro.ru", "phone": "+70113127027"}
0005432527904	0D4247	2845 153837	TATYANA NIKOLAEVA	{"email": "tatyana_nikolaeva.22031971@postgrespro.ru", "phone": "+70197479745"}
0005432527907	23025A	7429 083187	NATALYA RODIONOVA	{"phone": "+70318128895"}
0005432527908	23025A	0303 124085	ALEKSANDR FEDOROV	{"phone": "+70175930909"}
0005432527909	993CCA	8128 192961	LILIYA YAKOVLEVA	{"email": "liliya-yakovleva081972@postgrespro.ru", "phone": "+70526760700"}
0005432527910	F71B2B	7975 912131	GALINA MIRONOVA	{"phone": "+70361169090"}
0005432527911	20F6E1	5312 486061	MIKHAIL KISELEV	{"phone": "+70041569486"}
0005432527912	20F6E1	8847 176645	SERGEY GERASIMOV	{"email": "gerasimovs15081966@postgrespro.ru", "phone": "+70529407140"}
0005432527913	71EB44	5735 172907	SERGEY VLASOV	{"email": "vlasovsergey22041971@postgrespro.ru", "phone": "+70954487820"}
0005432527914	74A978	6587 589306	ILYA CHERNOV	{"phone": "+70560840706"}
0005432527915	5CE727	6643 824782	NINA KUZNECOVA	{"email": "ninakuznecova.021969@postgrespro.ru", "phone": "+70952908153"}
0005432527916	20AAB9	0697 037724	RUSTAM ZHUKOV	{"email": "zhukov.rustam_1961@postgrespro.ru", "phone": "+70410443842"}
0005432527917	20AAB9	6913 820523	VALENTINA KULIKOVA	{"email": "valentinakulikova-1972@postgrespro.ru", "phone": "+70157036219"}
0005432527918	A621F0	5871 263152	ELENA DENISOVA	{"email": "denisova.elena.01021969@postgrespro.ru", "phone": "+70193421520"}
0005432527919	A621F0	3499 063527	VALERIY STEPANOV	{"email": "valeriy-stepanov15081969@postgrespro.ru", "phone": "+70375372318"}
0005432527920	8ACE38	7240 925049	ILDAR TARASOV	{"email": "ildartarasov-1971@postgrespro.ru", "phone": "+70332386213"}
0005432527921	8ACE38	1714 811470	IGOR FROLOV	{"email": "ifrolov101982@postgrespro.ru", "phone": "+70466862622"}
0005432527922	693B46	7468 440988	VALENTINA TARASOVA	{"email": "vtarasova081973@postgrespro.ru", "phone": "+70710799083"}
0005432527923	57FC98	7632 658096	ANNA KUZNECOVA	{"phone": "+70906877839"}
0005432527924	ABF5A4	9883 691703	OLEG GAVRILOV	{"phone": "+70186673905"}
0005432527925	FC125D	2527 999029	EDUARD KUZMIN	{"email": "eduard-kuzmin03011972@postgrespro.ru", "phone": "+70378339672"}
0005432527926	FC125D	2486 022526	SVETLANA KUZNECOVA	{"phone": "+70301676682"}
0005432527927	177AE9	3362 377055	EKATERINA PETROVA	{"email": "ekaterina_petrova031972@postgrespro.ru", "phone": "+70555515174"}
0005432527928	0C3698	1107 109852	ALEKSANDR PAVLOV	{"phone": "+70029185221"}
0005432527929	DAAD27	6404 468150	VYACHESLAV DENISOV	{"phone": "+70308035940"}
0005432527930	DAAD27	1442 921755	SERGEY DMITRIEV	{"email": "dmitriev_sergey29081977@postgrespro.ru", "phone": "+70468979414"}
0005432527931	3731FF	9101 499062	ANATOLIY NIKITIN	{"phone": "+70062091249"}
0005432527932	D73AED	5521 394850	NAIL SMIRNOV	{"phone": "+70998390655"}
0005432527933	EFD044	9475 970292	GALINA KRASNOVA	{"email": "galina.krasnova1985@postgrespro.ru", "phone": "+70112354740"}
0005432527934	F2D98C	8458 851038	SVETLANA BORISOVA	{"email": "borisova.svetlana_1954@postgrespro.ru", "phone": "+70874334935"}
0005432527935	545325	3855 160073	VLADIMIR MEDVEDEV	{"phone": "+70219127806"}
0005432527936	700E23	7892 706520	VLADIMIR KARPOV	{"email": "karpovv.1972@postgrespro.ru", "phone": "+70001458738"}
0005432527937	0F4DB4	9580 217569	NIKOLAY NIKOLAEV	{"phone": "+70308274146"}
0005432527938	F9BCF7	5120 594261	NATALYA FROLOVA	{"phone": "+70525614179"}
0005432527939	D78C78	2632 896476	IRINA SOKOLOVA	{"phone": "+70825467664"}
0005432527940	961521	5528 931935	SVETLANA FROLOVA	{"phone": "+70970036103"}
0005432527941	961521	3799 563238	NELLI NIKOLAEVA	{"phone": "+70055553673"}
0005432527942	6315FD	9267 710427	KONSTANTIN TIMOFEEV	{"email": "ktimofeev-1972@postgrespro.ru", "phone": "+70444026935"}
0005432527943	6315FD	0496 713122	VIKTOR MARTYNOV	{"phone": "+70898414612"}
0005432527944	6315FD	2443 575068	VALENTINA KALININA	{"phone": "+70672878436"}
0005432527945	58D964	6690 720885	NIKITA ANDREEV	{"phone": "+70421761641"}
0005432527946	03FB74	3804 198446	NADEZHDA BELOVA	{"email": "nadezhda-belova061973@postgrespro.ru", "phone": "+70143208108"}
0005432527947	D3F06B	8817 731190	VASILIY SMIRNOV	{"phone": "+70001033469"}
0005432527948	D3F06B	4080 808594	TATYANA IVANOVA	{"phone": "+70260641677"}
0005432527949	D3F06B	1910 773046	VALENTINA DMITRIEVA	{"email": "dmitrievav.121967@postgrespro.ru", "phone": "+70218897539"}
0005432527950	E44806	7104 775400	FARIT KRASNOV	{"phone": "+70520774426"}
0005432527951	E44806	6958 688296	ANDREY SOROKIN	{"phone": "+70914816887"}
0005432527952	ED854E	1954 147396	SERGEY GERASIMOV	{"phone": "+70124499416"}
0005432527953	719E94	3127 263112	EKATERINA SOLOVEVA	{"phone": "+70165410434"}
0005432527954	0C8D89	1658 637856	VERA NIKITINA	{"email": "nikitinav-1975@postgrespro.ru", "phone": "+70942174120"}
0005432527955	60572C	1892 482260	MARIYA KUZNECOVA	{"email": "mkuznecova011980@postgrespro.ru", "phone": "+70013289523"}
0005432527956	ED465A	8601 850535	RAISA MIKHAYLOVA	{"email": "r.mikhaylova_18091976@postgrespro.ru", "phone": "+70681400295"}
0005432527957	ED465A	3290 209307	VALENTINA TROFIMOVA	{"email": "v-trofimova26081968@postgrespro.ru", "phone": "+70027735034"}
0005432527958	ED465A	6187 217613	SERGEY CHERNOV	{"email": "chernovsergey.08101960@postgrespro.ru", "phone": "+70354941153"}
0005432527959	9A3C0C	1507 683307	EVGENIYA KONOVALOVA	{"email": "evgeniya-konovalova-1961@postgrespro.ru", "phone": "+70352082807"}
0005432527960	DB7136	4199 735515	KONSTANTIN KUZNECOV	{"phone": "+70114991683"}
0005432527961	5064DA	8527 016874	NIKOLAY VOROBEV	{"phone": "+70667912930"}
0005432527962	B09D24	0944 249147	MARIYA KOZLOVA	{"phone": "+70896583111"}
0005432527963	B09D24	3210 871670	VALENTINA SIDOROVA	{"email": "vsidorova.25111970@postgrespro.ru", "phone": "+70734429943"}
0005432527964	41337E	1401 202021	ANDREY GAVRILOV	{"phone": "+70543594290"}
0005432527965	41337E	2406 357575	PAVEL SIDOROV	{"email": "sidorov_pavel-121973@postgrespro.ru", "phone": "+70802806088"}
0005432527966	271FA0	7265 898022	KSENIYA TIMOFEEVA	{"phone": "+70641179514"}
0005432527967	271FA0	7041 665425	EVGENIY YAKOVLEV	{"phone": "+70152044021"}
0005432527968	271FA0	8975 049300	ARSENIY PETROV	{"phone": "+70416999152"}
0005432527969	461752	8267 090779	NADEZHDA MOROZOVA	{"email": "morozova.n1974@postgrespro.ru", "phone": "+70050883469"}
0005432527970	56C7ED	9813 108870	IRINA KUZNECOVA	{"phone": "+70212641494"}
0005432527971	56C7ED	8808 389413	SERGEY MAKAROV	{"email": "makarov_sergey_031977@postgrespro.ru", "phone": "+70231190643"}
0005432527972	1EC067	9625 480820	SVETLANA VOROBEVA	{"email": "vorobeva_svetlana12061982@postgrespro.ru", "phone": "+70274576796"}
0005432527973	2E075E	4312 039928	IRINA LOGINOVA	{"email": "irina-loginova-101970@postgrespro.ru", "phone": "+70495555522"}
0005432527974	2E075E	2114 539220	SERGEY ANDREEV	{"email": "andreev.s.091973@postgrespro.ru", "phone": "+70407892314"}
0005432527975	C9E9DC	7447 292508	VIKTOR FOMIN	{"email": "fominv.081966@postgrespro.ru", "phone": "+70860090496"}
0005432527976	3A1F56	8787 295576	VLADIMIR FILIPPOV	{"email": "filippov.v.041973@postgrespro.ru", "phone": "+70609707486"}
0005432527977	AAAE2E	8001 583204	PAVEL SOROKIN	{"phone": "+70530299101"}
0005432527978	56A7FB	3254 561371	EKATERINA MELNIKOVA	{"email": "melnikova-ekaterina.1975@postgrespro.ru", "phone": "+70223026310"}
0005432527979	56A7FB	1337 235276	INNA ZAKHAROVA	{"phone": "+70726083802"}
0005432527980	416ED6	5387 321376	RUSLAN KUDRYASHOV	{"email": "kudryashov_ruslan_1978@postgrespro.ru", "phone": "+70036150758"}
0005432527981	1E700A	6706 499525	VLADIMIR MIKHAYLOV	{"email": "vladimirmikhaylov17091976@postgrespro.ru", "phone": "+70658804123"}
0005432527982	1E700A	5008 630490	SERGEY MATVEEV	{"phone": "+70524187985"}
0005432527983	63C057	8626 578927	PETR TIKHONOV	{"phone": "+70686933878"}
0005432527984	526805	3626 824300	LILIYA FROLOVA	{"email": "frolova_liliya.17021974@postgrespro.ru", "phone": "+70983997980"}
0005432527985	526805	2663 479814	IRINA ZHURAVLEVA	{"phone": "+70526932612"}
0005432527986	526805	9693 400771	YURIY ANDREEV	{"phone": "+70029272767"}
0005432527987	021CD1	9090 238160	SOFIYA MOISEEVA	{"phone": "+70262209647"}
0005432527988	27C7CB	7289 390014	VIKTOR TIMOFEEV	{"phone": "+70120196769"}
0005432527989	800F03	4089 369158	DANIIL CHERNOV	{"phone": "+70391340617"}
0005432527990	800F03	3501 031729	ALEKSANDR ZHURAVLEV	{"phone": "+70121741058"}
0005432527991	E4244A	0376 563434	EVGENIY MARTYNOV	{"phone": "+70836601954"}
0005432527992	E4244A	3746 945324	RAISA SOLOVEVA	{"email": "solovevaraisa-1971@postgrespro.ru", "phone": "+70535970679"}
0005432527993	B87D87	6932 522249	ALEKSANDR KOROLEV	{"email": "korolevaleksandr1974@postgrespro.ru", "phone": "+70506922880"}
0005432527994	2EE375	5751 649554	SERGEY NIKOLAEV	{"phone": "+70348916719"}
0005432527995	2EE375	7165 418281	VIKTOR FEDOTOV	{"email": "fedotov.viktor.1973@postgrespro.ru", "phone": "+70720085010"}
0005432527996	01DCE2	8628 568722	YURIY FEDOTOV	{"email": "fedotov_yuriy.1962@postgrespro.ru", "phone": "+70623733156"}
0005432527997	25341B	2236 432404	VLADIMIR KISELEV	{"email": "v.kiselev101974@postgrespro.ru", "phone": "+70714707744"}
0005432527998	4EE29F	8879 453427	YURIY SIDOROV	{"phone": "+70590987049"}
0005432527999	E4F63F	9635 830751	ARTEM GAVRILOV	{"email": "artemgavrilov_031969@postgrespro.ru", "phone": "+70134189565"}
0005432528000	6EFE6C	0345 231466	ROMAN KUDRYASHOV	{"email": "kudryashov-roman-061968@postgrespro.ru", "phone": "+70660216184"}
0005432528001	54366E	2164 556968	OLGA SEMENOVA	{"email": "semenova.olga-101979@postgrespro.ru", "phone": "+70599756622"}
0005432528002	54366E	7482 331286	TATYANA FROLOVA	{"email": "t-frolova13111974@postgrespro.ru", "phone": "+70296507114"}
0005432528003	C98F8B	9002 887743	IGOR KUZNECOV	{"phone": "+70679140099"}
0005432528004	C98F8B	8269 639547	ELVIRA VLASOVA	{"email": "vlasova-elvira1957@postgrespro.ru", "phone": "+70343915868"}
0005432528005	6E280E	4603 339487	GALINA KISELEVA	{"phone": "+70465950403"}
0005432528006	63CB91	1674 507245	PAVEL POPOV	{"email": "popov-pavel071967@postgrespro.ru", "phone": "+70309919202"}
0005432528007	63CB91	6771 843361	OLGA KUDRYASHOVA	{"phone": "+70697614979"}
0005432528008	D71E82	6593 717119	VIKTOR STEPANOV	{"phone": "+70888946130"}
0005432528009	611C3B	3769 666507	VALENTINA NAZAROVA	{"email": "nazarova-valentina-1970@postgrespro.ru", "phone": "+70221783883"}
0005432528010	43BE62	1439 448519	ZOYA EGOROVA	{"phone": "+70471538573"}
0005432528011	43BE62	0708 909736	MIKHAIL SCHERBAKOV	{"phone": "+70730096926"}
0005432528012	5B3527	2875 663774	ALEKSANDR EGOROV	{"phone": "+70378411096"}
0005432528013	316511	3495 107429	VALENTINA LAZAREVA	{"phone": "+70962021886"}
0005432528014	660499	7065 351992	LYUBOV POTAPOVA	{"phone": "+70210964590"}
0005432528015	DFE159	7863 790424	PELAGEYA SERGEEVA	{"email": "sergeeva_p_28061966@postgrespro.ru", "phone": "+70061365440"}
0005432528016	680522	4704 780636	VASILIY ZHUKOV	{"email": "zhukov.v-1981@postgrespro.ru", "phone": "+70665752961"}
0005432528017	F7115D	1402 130744	VLADIMIR KUDRYASHOV	{"email": "kudryashov_vladimir.031988@postgrespro.ru", "phone": "+70348017278"}
0005432528018	CDEB57	6907 074523	OLGA POTAPOVA	{"email": "potapova.o14101958@postgrespro.ru", "phone": "+70605280518"}
0005432528019	D2D57B	4674 320615	IRINA STEPANOVA	{"email": "stepanova.i_17101972@postgrespro.ru", "phone": "+70189935158"}
0005432528020	D2D57B	0878 557790	DENIS NIKITIN	{"email": "dnikitin1966@postgrespro.ru", "phone": "+70915673746"}
0005432528021	124D05	8407 246687	TATYANA VOLKOVA	{"phone": "+70450924075"}
0005432528022	3E2E25	9033 919524	MAKSIM IVANOV	{"email": "m-ivanov-19041957@postgrespro.ru", "phone": "+70070883376"}
0005432528023	279E80	2747 255139	MARIYA KUZNECOVA	{"email": "mkuznecova_031972@postgrespro.ru", "phone": "+70125778027"}
0005432528024	E98D66	8279 043974	MARIYA MOROZOVA	{"email": "mariya.morozova081973@postgrespro.ru", "phone": "+70146532759"}
0005432528025	E98D66	5479 693330	TATYANA IVANOVA	{"email": "t_ivanova.1970@postgrespro.ru", "phone": "+70410941959"}
0005432528026	F34CA1	6966 595196	ZINAIDA LOGINOVA	{"email": "zloginova.14021966@postgrespro.ru", "phone": "+70763035816"}
0005432528027	5F9766	5466 744499	EKATERINA ILINA	{"email": "ilina_e.051973@postgrespro.ru", "phone": "+70199184128"}
0005432528028	1C85E2	4338 778610	GALIYA KOVALEVA	{"phone": "+70088018009"}
0005432528029	70798C	2067 253003	IRINA FROLOVA	{"phone": "+70027214075"}
0005432528030	4756D7	0324 112295	VIKTORIYA LAZAREVA	{"phone": "+70751017388"}
0005432528031	A43713	9553 587045	GALINA TIMOFEEVA	{"phone": "+70157234958"}
0005432528032	AD361E	7690 483206	VIKTOR MOISEEV	{"phone": "+70275461037"}
0005432528033	73A0E1	9934 505577	NADEZHDA MAKAROVA	{"phone": "+70444751824"}
0005432528034	EA8494	5739 637270	MIKHAIL AFANASEV	{"email": "m-afanasev-20091971@postgrespro.ru", "phone": "+70269454545"}
0005432528035	EA8494	1300 455080	ANASTASIYA ROMANOVA	{"phone": "+70577458588"}
0005432528036	A84D6C	8272 911702	NIKOLAY SERGEEV	{"email": "nikolay_sergeev_19011968@postgrespro.ru", "phone": "+70224033948"}
0005432528037	1A2E09	7130 481903	TATYANA GAVRILOVA	{"email": "t.gavrilova091974@postgrespro.ru", "phone": "+70794006502"}
0005432528038	8BF724	4975 150947	MIKHAIL MIKHAYLOV	{"email": "mikhaylov.mikhail_14121963@postgrespro.ru", "phone": "+70302665791"}
0005432528039	8BF724	3558 319469	LIYA KUZNECOVA	{"email": "kuznecova-l.28081963@postgrespro.ru", "phone": "+70608048769"}
0005432528040	97FAC4	3441 872576	RAFAIL ALEKSANDROV	{"email": "r.aleksandrov_051969@postgrespro.ru", "phone": "+70373210558"}
0005432528041	97FAC4	0674 356508	TATYANA ALEKSANDROVA	{"email": "tatyana-aleksandrova.111977@postgrespro.ru", "phone": "+70005435687"}
0005432528042	97FAC4	7069 507009	OLGA VOROBEVA	{"email": "vorobeva.o.23031965@postgrespro.ru", "phone": "+70162386128"}
0005432528043	97FAC4	1111 584055	TAMARA SMIRNOVA	{"phone": "+70723466189"}
0005432528044	4E3E95	1636 708821	ARTEM MAKSIMOV	{"phone": "+70323304017"}
0005432528045	097D34	1888 931183	ANNA SOROKINA	{"email": "a.sorokina-041978@postgrespro.ru", "phone": "+70161753959"}
0005432528046	C83312	1371 228272	VIKTOR POPOV	{"email": "v-popov-22081982@postgrespro.ru", "phone": "+70273018369"}
0005432528047	DA49EE	6920 459385	VALERIY SIDOROV	{"email": "sidorov-valeriy_011965@postgrespro.ru", "phone": "+70275377284"}
0005432528048	8EDEF0	4122 871444	GENNADIY ZHUKOV	{"email": "g.zhukov23081965@postgrespro.ru", "phone": "+70734915722"}
0005432528049	BD6BD6	9367 584720	IVAN CHERNOV	{"phone": "+70111213217"}
0005432528050	BD6BD6	8621 628591	IGOR STEPANOV	{"phone": "+70511429921"}
0005432528051	8EE05C	8367 966871	EDUARD KUDRYASHOV	{"email": "eduard-kudryashov-26021978@postgrespro.ru", "phone": "+70053446328"}
0005432528052	8EE05C	5570 785228	MARINA NIKIFOROVA	{"email": "marina-nikiforova-1974@postgrespro.ru", "phone": "+70649689307"}
0005432528053	D0F4F3	1072 315024	MARIYA ARKHIPOVA	{"email": "arkhipova.mariya_1974@postgrespro.ru", "phone": "+70434787757"}
0005432528054	5A620C	0824 777527	TATYANA POTAPOVA	{"email": "tatyana.potapova-1970@postgrespro.ru", "phone": "+70225819571"}
0005432528055	2B8918	4387 587125	ELENA KUZNECOVA	{"phone": "+70473450798"}
0005432528056	7357E2	6787 686566	OLEG ANDREEV	{"email": "andreev_o-091977@postgrespro.ru", "phone": "+70575194351"}
0005432528057	7357E2	0081 097799	NIKOLAY RODIONOV	{"email": "nikolay_rodionov-1977@postgrespro.ru", "phone": "+70130868030"}
0005432528058	A5C282	1546 075589	DENIS FROLOV	{"phone": "+70398267076"}
0005432528059	FF2434	6218 745767	ANASTASIYA KUZNECOVA	{"email": "akuznecova.011975@postgrespro.ru", "phone": "+70968925505"}
0005432528060	FF2434	3923 712329	VALERIY ORLOV	{"phone": "+70058402710"}
0005432528061	775336	6809 381246	ANNA KUZMINA	{"email": "anna_kuzmina_02081965@postgrespro.ru", "phone": "+70484852521"}
0005432528062	775336	8642 020609	DMITRIY PAVLOV	{"phone": "+70187327364"}
0005432528063	E75A7F	4690 411627	SVETLANA NIKIFOROVA	{"email": "s-nikiforova05011969@postgrespro.ru", "phone": "+70338704585"}
0005432528064	F88EB8	8950 629840	NATALYA SOKOLOVA	{"email": "n.sokolova13011977@postgrespro.ru", "phone": "+70813671632"}
0005432528065	3A2D55	7618 093136	ALEKSANDR TIKHONOV	{"email": "atikhonov091979@postgrespro.ru", "phone": "+70704494919"}
0005432528066	3A2D55	6188 136948	ANATOLIY IVANOV	{"phone": "+70132921400"}
0005432528067	3A2D55	1856 102658	ALEKSEY GERASIMOV	{"email": "gerasimov_aleksey-011963@postgrespro.ru", "phone": "+70755423967"}
0005432528068	6BAB5F	9616 628776	ALEKSANDRA MELNIKOVA	{"phone": "+70630257349"}
0005432528069	375711	9365 906483	DARYA NIKITINA	{"email": "nikitinadarya-1972@postgrespro.ru", "phone": "+70168163897"}
0005432528070	D46473	0029 622987	NIKOLAY GRIGOREV	{"phone": "+70159582562"}
0005432528071	B0BFB1	1391 697425	ANNA MAKAROVA	{"phone": "+70407828444"}
0005432528072	C2EA67	7615 183940	IVAN NAZAROV	{"email": "nazarov-ivan_08011980@postgrespro.ru", "phone": "+70221938013"}
0005432528073	7C7667	2374 298472	SERGEY ZAKHAROV	{"email": "sergey_zakharov_1965@postgrespro.ru", "phone": "+70517497794"}
0005432528074	7C7667	7568 020677	AIDA CHERNOVA	{"email": "chernova_a.121968@postgrespro.ru", "phone": "+70207682872"}
0005432528075	E1B155	3928 085806	TATYANA AKIMOVA	{"email": "t.akimova_29121966@postgrespro.ru", "phone": "+70192142203"}
0005432528076	E44A95	2408 929069	EVGENIY MELNIKOV	{"phone": "+70177332296"}
0005432528077	85B9CF	2729 783058	ALEKSANDR KUZMIN	{"email": "a.kuzmin-1966@postgrespro.ru", "phone": "+70331158676"}
0005432528078	85B9CF	8571 703510	ANATOLIY DMITRIEV	{"email": "dmitrieva1968@postgrespro.ru", "phone": "+70109320440"}
0005432528079	ADDD61	0821 874119	ALEKSEY IVANOV	{"phone": "+70600347442"}
0005432528080	11BB78	4863 719820	YURIY KUDRYASHOV	{"email": "y_kudryashov_1969@postgrespro.ru", "phone": "+70869376586"}
0005432528081	0B098E	6275 114959	TATYANA FEDOROVA	{"email": "fedorova_t-061982@postgrespro.ru", "phone": "+70208901123"}
0005432528082	27C269	2701 319513	ARTEM FILIPPOV	{"phone": "+70831026362"}
0005432528083	27C269	9967 577325	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.081978@postgrespro.ru", "phone": "+70176315061"}
0005432528084	2D2B01	3801 038349	NIKOLAY ZAYCEV	{"email": "zaycev.n-081965@postgrespro.ru", "phone": "+70201140708"}
0005432528085	2D2B01	1195 317128	ELENA MIRONOVA	{"email": "elena.mironova-021979@postgrespro.ru", "phone": "+70320988850"}
0005432528086	1CA468	9853 971466	TATYANA VASILEVA	{"email": "t_vasileva-1964@postgrespro.ru", "phone": "+70591851067"}
0005432528087	A53CE8	0964 871833	IRINA IVANOVA	{"email": "ivanova_irina-1966@postgrespro.ru", "phone": "+70759946410"}
0005432528088	95D3B6	7597 766206	EVGENIY ROMANOV	{"phone": "+70781225780"}
0005432528089	F0D495	0384 969625	MIKHAIL MIRONOV	{"phone": "+70977095191"}
0005432528090	F0D495	0731 605996	LYUBOV ZAKHAROVA	{"email": "lyubov-zakharova_021968@postgrespro.ru", "phone": "+70896056582"}
0005432528091	EC6545	0652 066692	OLGA IVANOVA	{"phone": "+70166011346"}
0005432528092	ED3CA1	0744 551371	YURIY NAUMOV	{"email": "y_naumov_1958@postgrespro.ru", "phone": "+70215009201"}
0005432528093	ED3CA1	6845 890735	SERGEY MAKAROV	{"email": "sergey-makarov.1968@postgrespro.ru", "phone": "+70909271478"}
0005432528094	6FF19C	8570 199905	NIKITA KRASNOV	{"email": "krasnov.nikita1965@postgrespro.ru", "phone": "+70352827942"}
0005432528095	8082C1	7153 856769	VALENTINA KOZLOVA	{"phone": "+70176419144"}
0005432528096	4BFA94	5624 727212	TATYANA OSIPOVA	{"phone": "+70871713135"}
0005432528097	2822BF	9325 041046	ALEKSEY GUSEV	{"email": "gusev_aleksey.1970@postgrespro.ru", "phone": "+70850285595"}
0005432528098	A3861C	5923 280785	NATALYA ILINA	{"phone": "+70796217602"}
0005432528099	058C53	9633 806478	DMITRIY PETROV	{"email": "dmitriy_petrov_1966@postgrespro.ru", "phone": "+70144975429"}
0005432528100	4B6DC0	3015 462567	ALEKSANDR MOROZOV	{"phone": "+70200401000"}
0005432528101	4B6DC0	6903 831063	LYUBOV BELOVA	{"email": "beloval041968@postgrespro.ru", "phone": "+70064106504"}
0005432528102	BE917F	2449 738079	ADELINA KUZNECOVA	{"email": "adelina-kuznecova-071972@postgrespro.ru", "phone": "+70156471591"}
0005432528103	641C06	7607 884258	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov_12071974@postgrespro.ru", "phone": "+70190231535"}
0005432528104	D24E4A	7574 974838	RINAT ZHUKOV	{"email": "r.zhukov-30091974@postgrespro.ru", "phone": "+70722101035"}
0005432528105	833E6B	4417 300590	TATYANA KAZAKOVA	{"phone": "+70531453960"}
0005432528106	7BBE08	7936 648878	EKATERINA MOROZOVA	{"email": "emorozova_22011971@postgrespro.ru", "phone": "+70532508104"}
0005432528107	7BBE08	7965 231113	RAISA SCHERBAKOVA	{"phone": "+70086147918"}
0005432528108	7BBE08	1770 476170	YURIY FROLOV	{"phone": "+70222141350"}
0005432528109	100BEE	7208 363173	TATYANA IVANOVA	{"email": "ivanova_tatyana_031972@postgrespro.ru", "phone": "+70298048246"}
0005432528110	100BEE	4890 633025	ALEKSEY ABRAMOV	{"email": "abramov_aleksey_121971@postgrespro.ru", "phone": "+70413504909"}
0005432528111	1B73AF	4936 359905	ANDREY VLASOV	{"phone": "+70422932880"}
0005432528112	1B73AF	1573 271376	EVGENIY STEPANOV	{"email": "stepanov-e_1981@postgrespro.ru", "phone": "+70330435064"}
0005432528113	5A34C7	1316 232534	ALEKSANDR MAKSIMOV	{"email": "maksimov.a_051967@postgrespro.ru", "phone": "+70615725566"}
0005432528114	16FBD1	4428 195987	YULIYA KULIKOVA	{"phone": "+70037210290"}
0005432528115	16FBD1	9250 699666	FAIL KUZNECOV	{"email": "f.kuznecov-31051989@postgrespro.ru", "phone": "+70409700962"}
0005432528116	16FBD1	1201 118074	YURIY ANDREEV	{"email": "y_andreev.06111972@postgrespro.ru", "phone": "+70718837350"}
0005432528117	65EC22	3644 078935	KARIM BORISOV	{"email": "karim-borisov.1969@postgrespro.ru", "phone": "+70499270660"}
0005432528118	65EC22	9754 662510	SERGEY MAKAROV	{"email": "sergey_makarov.24121979@postgrespro.ru", "phone": "+70749978446"}
0005432528119	65EC22	2887 807990	ALEKSEY MIRONOV	{"phone": "+70442032248"}
0005432528120	7E793A	4318 407341	NATALYA ORLOVA	{"phone": "+70559289946"}
0005432528121	7E793A	5908 316091	VASILIY PAVLOV	{"email": "v-pavlov-1974@postgrespro.ru", "phone": "+70648010879"}
0005432528122	7E793A	6012 434249	SVETLANA NIKOLAEVA	{"email": "svetlana.nikolaeva21121954@postgrespro.ru", "phone": "+70148814558"}
0005432528123	F473EC	1011 317945	NATALYA KOZLOVA	{"email": "n_kozlova_011971@postgrespro.ru", "phone": "+70223880715"}
0005432528124	680E00	8234 121508	SERGEY KUZNECOV	{"email": "sergeykuznecov-1968@postgrespro.ru", "phone": "+70529886009"}
0005432528125	680E00	2680 016466	OLGA MAKAROVA	{"email": "makarova-olga1968@postgrespro.ru", "phone": "+70910852829"}
0005432528126	91E6B8	6904 450554	YURIY MOROZOV	{"phone": "+70629905946"}
0005432528127	57E7A8	7107 764705	VLADIMIR VASILEV	{"phone": "+70888827369"}
0005432528128	C8EA49	9401 881274	ILYA EGOROV	{"email": "ilya.egorov_101968@postgrespro.ru", "phone": "+70433769668"}
0005432528129	4FC7B7	7025 152381	ALEKSEY MAKSIMOV	{"phone": "+70354843364"}
0005432528130	4FC7B7	8345 732125	ALEKSANDRA SEMENOVA	{"phone": "+70910557651"}
0005432528131	11C8B0	6167 397242	ANDREY MOISEEV	{"phone": "+70773652262"}
0005432528132	1FA7C2	2104 051404	NINA FROLOVA	{"email": "nfrolova07081975@postgrespro.ru", "phone": "+70348047429"}
0005432528133	D3CA20	3857 802940	DMITRIY KISELEV	{"email": "kiselevdmitriy.1979@postgrespro.ru", "phone": "+70172611530"}
0005432528134	D3CA20	1222 921875	VALENTIN KULIKOV	{"phone": "+70714561633"}
0005432528135	B0F9F4	4207 884242	ARINA KUZNECOVA	{"phone": "+70968696404"}
0005432528136	E9FD27	4405 790315	RAFIK MAKAROV	{"email": "rafikmakarov_071974@postgrespro.ru", "phone": "+70594593692"}
0005432528137	6C1E6C	4079 028109	NATALYA NIKIFOROVA	{"email": "nnikiforova-22031973@postgrespro.ru", "phone": "+70928946763"}
0005432528138	D64C9F	8847 234541	BORIS YAKOVLEV	{"email": "b.yakovlev-1969@postgrespro.ru", "phone": "+70796928049"}
0005432528139	392D12	1755 623619	SVETLANA MEDVEDEVA	{"email": "s_medvedeva_051974@postgrespro.ru", "phone": "+70216211150"}
0005432528140	F98B7A	1123 444750	NINA KAZAKOVA	{"email": "n_kazakova.1970@postgrespro.ru", "phone": "+70562560132"}
0005432528141	552DE9	5382 536471	YULIYA POPOVA	{"email": "y_popova1968@postgrespro.ru", "phone": "+70365980959"}
0005432528142	80AD4E	0773 513926	STEPAN ZAKHAROV	{"phone": "+70406165284"}
0005432528143	6BE271	2531 597445	ALEKSEY SOLOVEV	{"email": "solovev-a.06041968@postgrespro.ru", "phone": "+70519185409"}
0005432528144	6BE271	0883 819352	LIDIYA FROLOVA	{"phone": "+70832320291"}
0005432528145	DE9371	8442 869434	ALEKSANDR ANDREEV	{"phone": "+70965548254"}
0005432528146	8AD482	9426 386469	ALINA IVANOVA	{"email": "aivanova_27121969@postgrespro.ru", "phone": "+70483045932"}
0005432528147	3CF441	4902 243026	VALENTINA ZHUKOVA	{"phone": "+70336362922"}
0005432528148	791231	4657 632528	ALBINA EFIMOVA	{"phone": "+70449505690"}
0005432528149	028109	0136 311765	YULIYA TARASOVA	{"email": "y_tarasova.09051970@postgrespro.ru", "phone": "+70408301998"}
0005432528150	028109	6707 114282	IRINA FILIPPOVA	{"phone": "+70938772614"}
0005432528151	3E242A	0580 819237	TATYANA STEPANOVA	{"email": "tatyana_stepanova.1973@postgrespro.ru", "phone": "+70313715686"}
0005432528152	ACBEF5	0379 224162	ALEKSEY TARASOV	{"email": "tarasova_17121977@postgrespro.ru", "phone": "+70760255518"}
0005432528153	A2A859	4715 794130	OLESYA ZAYCEVA	{"phone": "+70968868296"}
0005432528154	A2A859	4502 989313	SVETLANA KAZAKOVA	{"email": "kazakova_svetlana-25021981@postgrespro.ru", "phone": "+70767469216"}
0005432528155	C85CF7	8400 497273	DARYA FROLOVA	{"email": "frolovad_1966@postgrespro.ru", "phone": "+70913922523"}
0005432528156	151F65	1767 660670	DMITRIY YAKOVLEV	{"phone": "+70213732282"}
0005432528157	FDF425	2398 164371	IRINA SCHERBAKOVA	{"phone": "+70770911502"}
0005432528158	464E90	5444 234768	SERGEY ROMANOV	{"email": "sergey-romanov-20071964@postgrespro.ru", "phone": "+70085342894"}
0005432528159	8889D1	0113 431101	EVGENIY IVANOV	{"phone": "+70184343384"}
0005432528160	9153A7	4494 270636	EKATERINA KISELEVA	{"email": "kiselevaekaterina-061968@postgrespro.ru", "phone": "+70534721015"}
0005432528161	9153A7	9113 309276	SERGEY MIRONOV	{"phone": "+70327032583"}
0005432528162	94A47E	0902 896527	NINA ZAYCEVA	{"phone": "+70526456781"}
0005432528163	94A47E	9405 403631	OLGA KISELEVA	{"email": "o_kiseleva.26051975@postgrespro.ru", "phone": "+70816556546"}
0005432528164	6F38BB	7797 627588	TATYANA FILIPPOVA	{"phone": "+70303129095"}
0005432528165	6F38BB	3955 044642	NINA YUDINA	{"email": "yudina-n.051975@postgrespro.ru", "phone": "+70590179383"}
0005432528166	6F38BB	5088 235503	ELENA KOROLEVA	{"email": "elena.koroleva-1973@postgrespro.ru", "phone": "+70819683844"}
0005432528167	0E59C7	0562 446413	VALERIY NAUMOV	{"email": "valeriy.naumov1972@postgrespro.ru", "phone": "+70587700406"}
0005432528168	6B8CEB	3168 997219	ALINA EFIMOVA	{"phone": "+70066447781"}
0005432528169	7D4C9D	6775 042415	DINA ALEKSANDROVA	{"email": "aleksandrova.d.031979@postgrespro.ru", "phone": "+70473583812"}
0005432528170	2A3A4B	0958 311258	TAMARA EGOROVA	{"phone": "+70210601467"}
0005432528171	599E44	6158 814291	VIKTOR MIRONOV	{"phone": "+70453554385"}
0005432528172	83E0C4	9594 983063	EVGENIY ILIN	{"phone": "+70482398204"}
0005432528173	83E0C4	6015 562034	NINA VLASOVA	{"phone": "+70365668370"}
0005432528174	11BB6D	8334 958841	ANDREY IVANOV	{"phone": "+70679824066"}
0005432528175	FD7B3D	2836 215356	GALINA RODIONOVA	{"phone": "+70196090879"}
0005432528176	3EAF6D	4492 033412	NIKOLAY PETROV	{"phone": "+70282477306"}
0005432528177	728B3A	8475 360223	ALEKSEY MAKAROV	{"email": "makarov-a081959@postgrespro.ru", "phone": "+70523793851"}
0005432528178	A964BD	7161 951387	ANTON SAVELEV	{"phone": "+70225158857"}
0005432528179	7E89D6	5457 198461	ULYANA ISAEVA	{"email": "isaeva.ulyana-19061983@postgrespro.ru", "phone": "+70639046502"}
0005432528180	7E89D6	6021 175451	ALEKSANDR FEDOROV	{"phone": "+70198346708"}
0005432528181	68D3C8	1692 870601	IRINA POLYAKOVA	{"phone": "+70590824167"}
0005432528182	D9747F	0857 723559	ALEKSEY ZAKHAROV	{"email": "zakharov.a22021972@postgrespro.ru", "phone": "+70636797801"}
0005432528183	D9747F	9814 573475	OLEG KRASNOV	{"email": "krasnovo_1970@postgrespro.ru", "phone": "+70456869733"}
0005432528184	C6DC4F	0526 194236	ANATOLIY ILIN	{"phone": "+70184833994"}
0005432528185	C6DC4F	7652 038634	MAKSIM IVANOV	{"email": "maksim.ivanov_1973@postgrespro.ru", "phone": "+70092844533"}
0005432528186	8F45D1	5886 132131	VLADIMIR POPOV	{"phone": "+70623104971"}
0005432528187	FFF2BD	6732 545348	TATYANA TARASOVA	{"email": "tatyana_tarasova1975@postgrespro.ru", "phone": "+70595764418"}
0005432528188	3DC15F	6544 055112	KRISTINA BELOVA	{"email": "kristinabelova-25091960@postgrespro.ru", "phone": "+70247229271"}
0005432528189	3DC15F	6054 314478	IRINA ERMAKOVA	{"email": "ermakova-i.091980@postgrespro.ru", "phone": "+70642695938"}
0005432528190	3DC15F	4517 028861	VYACHESLAV ANDREEV	{"email": "andreevvyacheslav05021973@postgrespro.ru", "phone": "+70375527575"}
0005432528191	BBE90D	1484 383227	ANASTASIYA LAZAREVA	{"email": "lazarevaanastasiya.1984@postgrespro.ru", "phone": "+70929543616"}
0005432528192	69150C	3320 279097	EKATERINA SMIRNOVA	{"email": "ekaterina_smirnova_041967@postgrespro.ru", "phone": "+70983993908"}
0005432528193	69150C	5246 725323	SVETLANA LUKYANOVA	{"phone": "+70018457479"}
0005432528194	9228EF	5470 175210	SERGEY SCHERBAKOV	{"phone": "+70422497093"}
0005432528195	C726B6	3927 039359	ALEKSANDR GORBUNOV	{"phone": "+70395265939"}
0005432528196	23B783	8365 927214	VLADIMIR ZHUKOV	{"email": "v.zhukov-1969@postgrespro.ru", "phone": "+70572726023"}
0005432528197	0E8A36	4560 296982	IRINA GORBUNOVA	{"email": "gorbunova_irina_051969@postgrespro.ru", "phone": "+70731888002"}
0005432528198	92BA68	7677 777836	VALERIY SOKOLOV	{"phone": "+70949483318"}
0005432528199	DB62EA	3746 469747	ANDREY MOROZOV	{"email": "a_morozov_21011978@postgrespro.ru", "phone": "+70047865717"}
0005432528200	DB62EA	2959 056641	ARTEM KUZNECOV	{"phone": "+70560737450"}
0005432528201	DB62EA	1826 877547	MIKHAIL FEDOROV	{"phone": "+70170090851"}
0005432528202	ECD038	8228 743264	MIKHAIL KRASNOV	{"phone": "+70471261588"}
0005432528203	463336	9481 324196	ANDREY MEDVEDEV	{"email": "andrey.medvedev-101961@postgrespro.ru", "phone": "+70203830580"}
0005432528204	A65BA1	4300 903146	MARIYA IVANOVA	{"email": "ivanovamariya-071978@postgrespro.ru", "phone": "+70594107946"}
0005432528205	A65BA1	9405 036281	ARTEM NOVIKOV	{"email": "anovikov21081976@postgrespro.ru", "phone": "+70084528601"}
0005432528206	A65BA1	0449 673598	TATYANA FEDOROVA	{"phone": "+70245500952"}
0005432528207	B9D3D3	7252 904557	LYUDMILA FROLOVA	{"email": "lyudmila.frolova-081968@postgrespro.ru", "phone": "+70978394039"}
0005432528208	B9D3D3	1895 531262	ALIYA TIMOFEEVA	{"email": "timofeeva-a081973@postgrespro.ru", "phone": "+70269009727"}
0005432528209	21C98F	1852 130018	ARSENIY TIKHONOV	{"phone": "+70400131326"}
0005432528210	21C98F	0904 389491	SERGEY FROLOV	{"email": "sergey.frolov1967@postgrespro.ru", "phone": "+70931318419"}
0005432528211	F8DCFA	9176 087492	OLEG ZHURAVLEV	{"phone": "+70402065427"}
0005432528212	F8DCFA	0350 089152	NADEZHDA NOVIKOVA	{"phone": "+70177219243"}
0005432528213	FB6FEC	0727 919816	VLADIMIR ANTONOV	{"email": "antonov.vladimir23101968@postgrespro.ru", "phone": "+70840024933"}
0005432528214	48B48C	2085 915114	VALENTINA KUZMINA	{"phone": "+70659907795"}
0005432528215	73B5F2	2115 365104	OLGA NESTEROVA	{"phone": "+70695371212"}
0005432528216	73B5F2	9834 420957	SVETLANA KOVALEVA	{"phone": "+70739610549"}
0005432528217	7D36BC	9485 734475	ANDREY KUZNECOV	{"email": "a-kuznecov-1964@postgrespro.ru", "phone": "+70522430823"}
0005432528218	6051D1	8204 568346	NIKOLAY FEDOROV	{"email": "fedorov.nikolay25091970@postgrespro.ru", "phone": "+70262762165"}
0005432528219	6051D1	1901 105336	ALEKSANDR BELOV	{"phone": "+70948602931"}
0005432528220	A2B410	4392 656859	ROMAN EGOROV	{"phone": "+70041548564"}
0005432528221	FBC21B	3579 016129	ALEKSEY YAKOVLEV	{"email": "alekseyyakovlev.25081982@postgrespro.ru", "phone": "+70296335031"}
0005432528222	44A682	5869 788412	OLEG GRIGOREV	{"email": "grigorev-o031962@postgrespro.ru", "phone": "+70990846542"}
0005432528223	44A682	8615 751243	SERGEY GRIGOREV	{"phone": "+70391310015"}
0005432528224	F1CE40	5253 741065	VERA KULIKOVA	{"email": "kulikova_vera.02021977@postgrespro.ru", "phone": "+70994378306"}
0005432528225	4EBDEE	0739 810721	LYUDMILA DENISOVA	{"phone": "+70843970479"}
0005432528226	F50093	1794 630655	ZINAIDA KUZNECOVA	{"email": "kuznecova-zinaida-091966@postgrespro.ru", "phone": "+70517786808"}
0005432528227	5EAC96	9239 975402	ALINA BARANOVA	{"email": "baranova_a-1980@postgrespro.ru", "phone": "+70622569769"}
0005432528467	D2D738	2974 697676	SVETLANA EGOROVA	{"phone": "+70302948728"}
0005432528228	5EAC96	7818 968189	VLADIMIR KUDRYASHOV	{"email": "v_kudryashov_121980@postgrespro.ru", "phone": "+70783181821"}
0005432528229	4585DE	6490 853762	ALEKSEY SMIRNOV	{"phone": "+70046425075"}
0005432528230	07424B	2999 486976	BORIS SOKOLOV	{"phone": "+70489306743"}
0005432528231	95D33E	5025 891389	ANDREY ZHURAVLEV	{"email": "azhuravlev1969@postgrespro.ru", "phone": "+70231454364"}
0005432528232	95D33E	0336 403584	SERGEY KUZNECOV	{"email": "kuznecov-s1984@postgrespro.ru", "phone": "+70905187430"}
0005432528233	7C0116	5481 906394	ARKADIY TARASOV	{"phone": "+70491286627"}
0005432528234	C1B5D5	6751 499454	EKATERINA SEMENOVA	{"email": "semenova-ekaterina-091967@postgrespro.ru", "phone": "+70563475291"}
0005432528235	C1B5D5	3307 160147	SVETLANA MAKSIMOVA	{"email": "maksimova_svetlana.23091976@postgrespro.ru", "phone": "+70555732636"}
0005432528236	C1B5D5	6096 073591	DANIIL KONOVALOV	{"phone": "+70396680645"}
0005432528237	C01F7D	1499 379077	EVGENIY BELOV	{"email": "belov.e1981@postgrespro.ru", "phone": "+70198879828"}
0005432528238	4A3140	6787 914498	YURIY POPOV	{"phone": "+70314998571"}
0005432528239	C13058	6540 141076	LYUDMILA VOROBEVA	{"phone": "+70444158968"}
0005432528240	C13058	7873 741217	ANATOLIY MAKAROV	{"phone": "+70645473950"}
0005432528241	1A3BDE	7232 894535	OLEG PAVLOV	{"phone": "+70280235011"}
0005432528242	46EABD	1946 088104	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov_1984@postgrespro.ru", "phone": "+70748714679"}
0005432528243	46EABD	8891 497923	TATYANA DENISOVA	{"phone": "+70687396069"}
0005432528244	FC403F	4482 193747	IRINA BORISOVA	{"email": "borisovairina_121975@postgrespro.ru", "phone": "+70327566293"}
0005432528245	D677DA	6847 334532	SERGEY IVANOV	{"phone": "+70593955073"}
0005432528246	870043	3788 466063	ANASTASIYA VLASOVA	{"email": "avlasova.1970@postgrespro.ru", "phone": "+70076611158"}
0005432528247	A0869A	2038 517160	YURIY OSIPOV	{"email": "osipov.y031965@postgrespro.ru", "phone": "+70872017299"}
0005432528248	A0869A	4708 472827	YANA TROFIMOVA	{"email": "yana_trofimova.1974@postgrespro.ru", "phone": "+70134768195"}
0005432528249	D0909A	5066 336985	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila05021975@postgrespro.ru", "phone": "+70287532810"}
0005432528250	4DCD9A	4505 924420	YULIYA IVANOVA	{"phone": "+70455060696"}
0005432528251	EADA50	7801 531877	ELIZAVETA ZHURAVLEVA	{"phone": "+70542513782"}
0005432528252	7AF803	7226 176189	YURIY BORISOV	{"email": "y.borisov.071962@postgrespro.ru", "phone": "+70653230230"}
0005432528253	CD5157	1149 611474	TAISIYA ERMAKOVA	{"phone": "+70186354026"}
0005432528254	CD5157	7242 463790	KLAVDIYA ROMANOVA	{"phone": "+70596594463"}
0005432528255	61EEEF	9227 296347	ZOYA ORLOVA	{"phone": "+70697026907"}
0005432528256	61EEEF	8022 929155	MARINA MARTYNOVA	{"email": "marina_martynova_041984@postgrespro.ru", "phone": "+70124408734"}
0005432528257	3796A1	3821 178003	OLGA FILIPPOVA	{"email": "filippova.olga-1979@postgrespro.ru", "phone": "+70885545991"}
0005432528258	3796A1	3368 109676	ELENA KONOVALOVA	{"email": "elena_konovalova1972@postgrespro.ru", "phone": "+70126805375"}
0005432528259	8F6801	4989 728920	ARTUR KUZNECOV	{"phone": "+70349508552"}
0005432528260	3DC2AF	0786 976757	MIKHAIL SOROKIN	{"phone": "+70789086377"}
0005432528261	3DC2AF	8970 241421	NATALYA LEBEDEVA	{"phone": "+70077749958"}
0005432528262	20F3CA	1443 655696	ANNA LAZAREVA	{"email": "lazareva-a.18101975@postgrespro.ru", "phone": "+70158569142"}
0005432528263	20F3CA	8429 634034	TAMARA MOROZOVA	{"email": "morozovat-1972@postgrespro.ru", "phone": "+70157363237"}
0005432528264	395769	9411 413831	GALINA FADEEVA	{"email": "galina_fadeeva071954@postgrespro.ru", "phone": "+70267964157"}
0005432528265	F215E3	4367 019487	LARISA BORISOVA	{"phone": "+70173754781"}
0005432528266	F215E3	3440 683096	IRINA BORISOVA	{"email": "borisova.irina-1984@postgrespro.ru", "phone": "+70597474132"}
0005432528267	3AEA73	4000 504984	VLADIMIR AFANASEV	{"email": "afanasev.vladimir.12041976@postgrespro.ru", "phone": "+70125003227"}
0005432528268	7BF1B9	8000 670001	ALEKSANDR BONDARENKO	{"phone": "+70652319141"}
0005432528269	7BF1B9	0068 898946	ANDREY AFANASEV	{"phone": "+70999517665"}
0005432528270	2E7E18	0479 095533	GALINA BELOVA	{"phone": "+70180498736"}
0005432528271	2E7E18	3987 978038	EVGENIYA KOLESNIKOVA	{"phone": "+70178410082"}
0005432528272	63EFB2	9294 837021	ALEKSEY IVANOV	{"phone": "+70837301317"}
0005432528273	63EFB2	7475 238904	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr_061965@postgrespro.ru", "phone": "+70191221095"}
0005432528274	E47FA2	9100 672745	MATVEY SOROKIN	{"email": "m-sorokin1972@postgrespro.ru", "phone": "+70068332624"}
0005432528275	E16849	5534 852483	MARIYA KRASNOVA	{"phone": "+70107771504"}
0005432528276	33A11A	9932 532141	OKSANA POPOVA	{"email": "popova-oksana.071973@postgrespro.ru", "phone": "+70027961570"}
0005432528277	C0A709	2103 076526	YULIYA NOVIKOVA	{"phone": "+70647801702"}
0005432528278	99AFB3	7868 599728	ELENA DENISOVA	{"email": "denisova-elena-17111959@postgrespro.ru", "phone": "+70663754090"}
0005432528279	6BA067	3758 134951	ALEKSEY KUDRYASHOV	{"phone": "+70518509370"}
0005432528280	6BA067	3362 603603	ARSENIY FILIPPOV	{"phone": "+70207787350"}
0005432528281	6BA067	4649 366615	IRINA VASILEVA	{"email": "i-vasileva_021974@postgrespro.ru", "phone": "+70432467623"}
0005432528282	6A08B7	6906 364478	PRASKOVYA SAVELEVA	{"phone": "+70791917880"}
0005432528283	6A08B7	9004 314933	IRINA ZHURAVLEVA	{"email": "zhuravleva-irina-121981@postgrespro.ru", "phone": "+70447058768"}
0005432528284	469BEA	7799 378636	LYUDMILA IVANOVA	{"email": "ivanova_l121973@postgrespro.ru", "phone": "+70189197352"}
0005432528285	469BEA	6401 140656	LARISA AFANASEVA	{"email": "larisaafanaseva_1960@postgrespro.ru", "phone": "+70001306179"}
0005432528286	3ADE3B	9420 356319	VLADIMIR FEDOTOV	{"phone": "+70579409023"}
0005432528287	D6AC58	0945 848543	ROMAN KISELEV	{"email": "romankiselev121959@postgrespro.ru", "phone": "+70551798975"}
0005432528288	D735D6	0119 121003	ALEKSANDR SERGEEV	{"email": "a_sergeev_1976@postgrespro.ru", "phone": "+70535334010"}
0005432528289	EFB538	8818 305092	VLADIMIR TIMOFEEV	{"email": "v_timofeev081965@postgrespro.ru", "phone": "+70898612183"}
0005432528290	6F8EE5	0107 415588	ANATOLIY PETROV	{"email": "a.petrov121967@postgrespro.ru", "phone": "+70123964401"}
0005432528291	6F8EE5	9441 585915	NIKOLAY BARANOV	{"phone": "+70705458269"}
0005432528292	4877D0	3931 955789	ANDREY SOLOVEV	{"phone": "+70363863859"}
0005432528293	4877D0	1434 004991	VERA ANTONOVA	{"email": "antonova_vera.1979@postgrespro.ru", "phone": "+70590018037"}
0005432528294	560F1E	6125 685045	MARGARITA ORLOVA	{"phone": "+70983321448"}
0005432528295	1437D5	0858 222575	VENERA TROFIMOVA	{"email": "vtrofimova-101983@postgrespro.ru", "phone": "+70053248988"}
0005432528296	1AE4DA	7804 495271	YURIY KARPOV	{"email": "y.karpov1972@postgrespro.ru", "phone": "+70356267392"}
0005432528297	1AE4DA	7047 302443	DARYA KONOVALOVA	{"email": "d_konovalova.101973@postgrespro.ru", "phone": "+70213035483"}
0005432528298	0111B8	4183 531285	ALEKSANDR EGOROV	{"email": "aleksandr-egorov-1974@postgrespro.ru", "phone": "+70752964745"}
0005432528299	0111B8	7338 719536	NIKOLAY YAKOVLEV	{"phone": "+70018753251"}
0005432528300	0111B8	3143 362739	MARIYA IVANOVA	{"phone": "+70687789449"}
0005432528301	3C8EE2	2527 081094	ANNA MIKHAYLOVA	{"email": "anna.mikhaylova_1978@postgrespro.ru", "phone": "+70806764924"}
0005432528302	3C8EE2	9617 302390	OKSANA POPOVA	{"email": "oksana_popova041963@postgrespro.ru", "phone": "+70235005881"}
0005432528303	BF10AC	9081 029665	LYUDMILA KOROLEVA	{"phone": "+70504641588"}
0005432528304	BF10AC	5093 788748	VERA ISAEVA	{"email": "visaeva-1968@postgrespro.ru", "phone": "+70282110418"}
0005432528305	1CEB43	7099 427179	VALENTINA SOKOLOVA	{"email": "valentina.sokolova.18121974@postgrespro.ru", "phone": "+70006458929"}
0005432528306	1CEB43	3447 745315	NADEZHDA SIDOROVA	{"email": "nadezhda-sidorova_121976@postgrespro.ru", "phone": "+70579567336"}
0005432528307	F50C37	8397 864770	LIDIYA KAZAKOVA	{"email": "kazakoval.1970@postgrespro.ru", "phone": "+70640224154"}
0005432528308	F50C37	3119 933458	EKATERINA KOROLEVA	{"email": "koroleva-e_1965@postgrespro.ru", "phone": "+70580705717"}
0005432528309	F50C37	4504 778985	RASHIT MIKHAYLOV	{"email": "mikhaylovrashit-03071978@postgrespro.ru", "phone": "+70688583381"}
0005432528310	2B3664	0182 488701	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila04031969@postgrespro.ru", "phone": "+70313675569"}
0005432528311	A17975	1496 798766	EKATERINA KISELEVA	{"email": "kiseleva-e.051966@postgrespro.ru", "phone": "+70169557268"}
0005432528312	82618E	6868 429309	TATYANA LAZAREVA	{"email": "lazareva-t-21081981@postgrespro.ru", "phone": "+70370141846"}
0005432528313	B91522	9429 743495	VLADIMIR SHEVCHENKO	{"email": "vladimir_shevchenko25111970@postgrespro.ru", "phone": "+70798970173"}
0005432528314	362550	1523 282575	RAVIL VOLKOV	{"email": "volkov-r_29101965@postgrespro.ru", "phone": "+70607251286"}
0005432528315	362550	2701 891013	ELENA NAZAROVA	{"email": "nazarova.e.111973@postgrespro.ru", "phone": "+70998249992"}
0005432528316	3A4617	2839 314183	IRINA MELNIKOVA	{"email": "melnikovairina101976@postgrespro.ru", "phone": "+70162569996"}
0005432528317	CFA0BA	5892 306094	ALEKSANDR SEMENOV	{"phone": "+70039690974"}
0005432528318	CFA0BA	2310 156828	ALEKSANDR MOROZOV	{"phone": "+70710463522"}
0005432528319	B1432B	5117 011371	GEORGIY FROLOV	{"email": "frolovg.091976@postgrespro.ru", "phone": "+70494557608"}
0005432528320	FED697	1687 304785	SERGEY SHEVCHENKO	{"phone": "+70683548772"}
0005432528321	FED697	4983 040100	OLESYA NESTEROVA	{"email": "nesterovaolesya-111979@postgrespro.ru", "phone": "+70089001997"}
0005432528322	5D93BB	5952 698332	PAVEL SEMENOV	{"phone": "+70551019246"}
0005432528323	5D93BB	7892 801405	SERGEY GORBUNOV	{"phone": "+70767568610"}
0005432528324	AC7423	3106 703359	LYUDMILA MAKAROVA	{"phone": "+70194936067"}
0005432528325	AC7423	0079 345572	ALEKSEY SCHERBAKOV	{"phone": "+70474765623"}
0005432528326	F9DB0A	7054 756497	ALEKSANDR KUZNECOV	{"email": "kuznecov.a19021981@postgrespro.ru", "phone": "+70967360399"}
0005432528327	E7C027	9540 734562	YAROSLAV SOKOLOV	{"phone": "+70956584143"}
0005432528328	A8FF66	2928 599132	ANATOLIY KULIKOV	{"email": "kulikov-anatoliy-27051967@postgrespro.ru", "phone": "+70650691367"}
0005432528329	A8FF66	3984 922752	KLAVDIYA MAKSIMOVA	{"phone": "+70266178885"}
0005432528330	6ADAE6	4948 921904	OLEG RODIONOV	{"phone": "+70609045961"}
0005432528331	C500CA	8099 199878	MARIYA RODIONOVA	{"email": "rodionova_mariya.091975@postgrespro.ru", "phone": "+70453932201"}
0005432528332	1DDF89	9082 438294	ANASTASIYA FEDOROVA	{"phone": "+70855484908"}
0005432528333	3BA0B7	9673 062778	KSENIYA TARASOVA	{"email": "k-tarasova061968@postgrespro.ru", "phone": "+70664223503"}
0005432528334	75ACC3	5067 479928	NIKOLAY STEPANOV	{"email": "stepanovn_1968@postgrespro.ru", "phone": "+70932750006"}
0005432528335	75ACC3	5001 784558	PRASKOVYA MAKSIMOVA	{"phone": "+70550035558"}
0005432528336	4FF36A	8372 898439	ALEKSANDR SAVELEV	{"phone": "+70244407572"}
0005432528337	4FF36A	3374 400073	VYACHESLAV TIKHONOV	{"email": "tikhonovvyacheslav-02121965@postgrespro.ru", "phone": "+70224890190"}
0005432528338	E9E56B	0224 014498	ALEKSANDR NIKOLAEV	{"phone": "+70133190196"}
0005432528339	059C61	5642 908915	STEPAN KOROLEV	{"phone": "+70051683593"}
0005432528340	059C61	4633 096071	DENIS ALEKSEEV	{"email": "alekseev-denis_30041975@postgrespro.ru", "phone": "+70145406873"}
0005432528341	4E8403	8084 629491	ALEKSEY NOVIKOV	{"email": "novikov-a_101974@postgrespro.ru", "phone": "+70949268730"}
0005432528342	51BCC6	8047 198163	VASILIY MOROZOV	{"phone": "+70237295636"}
0005432528343	51BCC6	5220 633149	NIKOLAY PAVLOV	{"phone": "+70083767953"}
0005432528344	8FDEA5	9406 232662	IVAN OSIPOV	{"email": "ivan.osipov-06071963@postgrespro.ru", "phone": "+70635832026"}
0005432528345	A6F00C	6503 668005	PAVEL ZAYCEV	{"email": "p-zaycev111960@postgrespro.ru", "phone": "+70115735864"}
0005432528346	A6F00C	4503 177609	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr30111979@postgrespro.ru", "phone": "+70235364571"}
0005432528347	A37F5D	7438 145529	ALEKSANDR ISAEV	{"email": "isaev_a.101986@postgrespro.ru", "phone": "+70490371353"}
0005432528348	A5BCAB	0875 771724	ELENA PETROVA	{"phone": "+70003490970"}
0005432528349	32B30C	7696 424366	VERA ISAEVA	{"email": "v.isaeva-031969@postgrespro.ru", "phone": "+70384738898"}
0005432528350	32B30C	8662 400655	MARGARITA PAVLOVA	{"phone": "+70050156816"}
0005432528351	7E364C	1152 330851	KONSTANTIN PAVLOV	{"email": "k.pavlov_1965@postgrespro.ru", "phone": "+70056083158"}
0005432528352	9E9084	6759 109482	NIKOLAY SERGEEV	{"email": "sergeev_n_1976@postgrespro.ru", "phone": "+70248148441"}
0005432528353	A608C2	9372 359766	YURIY NIKITIN	{"phone": "+70365925276"}
0005432528354	18F66D	1006 070967	YURIY VASILEV	{"email": "vasilev.yuriy.041976@postgrespro.ru", "phone": "+70250367035"}
0005432528355	BB7983	9197 939815	VLADIMIR NOVIKOV	{"phone": "+70343556529"}
0005432528356	E7C811	1166 978153	ELVIRA POTAPOVA	{"phone": "+70383883315"}
0005432528357	E7C811	4683 447041	MARIYA MEDVEDEVA	{"phone": "+70240085934"}
0005432528358	E7C811	6041 605666	SERGEY BORISOV	{"email": "borisov-sergey29111977@postgrespro.ru", "phone": "+70317433273"}
0005432528359	E7C811	0806 829562	TATYANA ZAKHAROVA	{"phone": "+70822785741"}
0005432528360	22E19A	3073 581743	OLGA IVANOVA	{"email": "ivanova.o.31011974@postgrespro.ru", "phone": "+70835090678"}
0005432528361	415AEC	5471 838857	EKATERINA SIDOROVA	{"email": "sidorova-e-041972@postgrespro.ru", "phone": "+70006991667"}
0005432528362	415AEC	0076 914156	YULIYA GORBUNOVA	{"email": "yuliya-gorbunova_071981@postgrespro.ru", "phone": "+70806889678"}
0005432528363	7A2034	6377 152959	TAISIYA KUZNECOVA	{"phone": "+70600897685"}
0005432528364	531319	3880 965360	KIRILL MIKHAYLOV	{"email": "kirill.mikhaylov-1976@postgrespro.ru", "phone": "+70275648722"}
0005432528365	FF0331	1434 818033	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr.20101972@postgrespro.ru", "phone": "+70728787434"}
0005432528366	FF0331	5302 865122	FEDOR IVANOV	{"phone": "+70473531909"}
0005432528367	3BCA7E	7054 543732	PAVEL AFANASEV	{"phone": "+70907716594"}
0005432528368	053CF8	8366 781500	ANATOLIY BARANOV	{"email": "baranov.anatoliy_07061975@postgrespro.ru", "phone": "+70106828826"}
0005432528369	053CF8	8309 597961	TAMARA STEPANOVA	{"email": "t.stepanova.101972@postgrespro.ru", "phone": "+70713830526"}
0005432528370	053CF8	0714 244796	VALENTINA VOROBEVA	{"email": "vorobevav_041972@postgrespro.ru", "phone": "+70408518236"}
0005432528371	F63A98	2270 290932	GERMAN VASILEV	{"phone": "+70457429053"}
0005432528372	C0435C	1053 207361	OLEG RODIONOV	{"email": "rodionovo_1961@postgrespro.ru", "phone": "+70884945085"}
0005432528373	BD21CB	9723 330492	IGOR OSIPOV	{"phone": "+70539585608"}
0005432528374	BD21CB	2814 529182	ARINA KUZNECOVA	{"email": "arina.kuznecova_1976@postgrespro.ru", "phone": "+70429163458"}
0005432528375	D48731	1520 697066	YURIY ZAKHAROV	{"email": "zakharov-yuriy_06101972@postgrespro.ru", "phone": "+70280252375"}
0005432528376	D48731	8217 751817	VLADIMIR POPOV	{"email": "v_popov-041981@postgrespro.ru", "phone": "+70471875834"}
0005432528377	7E3B0C	7828 632271	VLADISLAV SEMENOV	{"email": "semenovvladislav-25041965@postgrespro.ru", "phone": "+70484620815"}
0005432528378	8A8DF8	8619 402389	SERGEY SMIRNOV	{"phone": "+70583138508"}
0005432528379	57D5CC	9390 785918	ALEKSANDR SMIRNOV	{"phone": "+70134098881"}
0005432528380	DDEC1D	6412 033291	EKATERINA PETROVA	{"phone": "+70208216741"}
0005432528381	DDEC1D	5049 502892	ANTON SAVELEV	{"phone": "+70647400707"}
0005432528382	47C10B	4216 781437	ZINAIDA KOMAROVA	{"phone": "+70843006470"}
0005432528383	A54639	2886 833007	DENIS KONOVALOV	{"email": "d-konovalov-111962@postgrespro.ru", "phone": "+70778923316"}
0005432528384	5B7CD7	0672 036684	IVAN POPOV	{"phone": "+70025907762"}
0005432528385	5B7CD7	5140 650093	NINA DMITRIEVA	{"phone": "+70698071255"}
0005432528386	5B7CD7	5217 502181	MARINA ROMANOVA	{"email": "romanovamarina_051959@postgrespro.ru", "phone": "+70068630554"}
0005432528387	D36CC1	4889 454067	TATYANA SEMENOVA	{"email": "tsemenova061972@postgrespro.ru", "phone": "+70644288295"}
0005432528388	24A740	8406 839860	NIKOLAY IVANOV	{"phone": "+70397919639"}
0005432528389	F3D85E	7829 875944	NADEZHDA NIKOLAEVA	{"phone": "+70076150289"}
0005432528390	F3D85E	0720 690995	PETR SOROKIN	{"email": "p.sorokin.1973@postgrespro.ru", "phone": "+70228668932"}
0005432528391	475D78	3392 773259	ALEKSANDR TIMOFEEV	{"email": "timofeev.a.03051979@postgrespro.ru", "phone": "+70275267139"}
0005432528392	18CD90	4615 810266	MARIYA ANDREEVA	{"email": "mariya.andreeva_061972@postgrespro.ru", "phone": "+70176697170"}
0005432528393	18CD90	0499 404901	ANDREY GUSEV	{"phone": "+70459240130"}
0005432528394	A84CA4	6513 992925	OLEG CHERNOV	{"email": "olegchernov_081987@postgrespro.ru", "phone": "+70321083141"}
0005432528395	A84CA4	7584 996767	MARIYA GERASIMOVA	{"phone": "+70078664280"}
0005432528396	B45BF9	3997 492893	ALEKSANDRA SMIRNOVA	{"phone": "+70493740085"}
0005432528397	B45BF9	9116 550820	GLEB NIKITIN	{"email": "nikitin_g.101971@postgrespro.ru", "phone": "+70476339641"}
0005432528398	C205A4	1594 741577	ALEKSEY PETROV	{"phone": "+70998641043"}
0005432528399	3B9B07	2376 905111	YURIY KUDRYASHOV	{"email": "kudryashov-yuriy-19071961@postgrespro.ru", "phone": "+70919334610"}
0005432528400	9ECC62	4524 121116	MARGARITA ANDREEVA	{"phone": "+70228298562"}
0005432528401	3C3C74	2914 708617	NIKOLAY PAVLOV	{"email": "pavlovnikolay_011970@postgrespro.ru", "phone": "+70705375446"}
0005432528402	3C3C74	4552 240689	NIKOLAY KUZNECOV	{"phone": "+70971564310"}
0005432528403	3C3C74	8697 480747	IRINA SOROKINA	{"phone": "+70919892507"}
0005432528404	847107	8416 017599	TATYANA MAKAROVA	{"email": "tatyana-makarova.1963@postgrespro.ru", "phone": "+70652001052"}
0005432528405	E013BC	8733 945850	DMITRIY OSIPOV	{"email": "dmitriy-osipov.031967@postgrespro.ru", "phone": "+70858190355"}
0005432528406	914725	1913 266338	MAKSIM IVANOV	{"email": "ivanov.m.29091968@postgrespro.ru", "phone": "+70420181659"}
0005432528407	7133FE	3722 529498	NATALYA SIDOROVA	{"email": "natalya-sidorova111973@postgrespro.ru", "phone": "+70656700773"}
0005432528408	A49E13	8722 522812	LYUBOV PAVLOVA	{"phone": "+70337746452"}
0005432528409	BBA4EF	9350 417068	SERGEY GUSEV	{"phone": "+70744356480"}
0005432528410	CDCA37	3313 512812	MIKHAIL SIDOROV	{"phone": "+70017807161"}
0005432528411	B14174	1473 092099	NINA SOLOVEVA	{"phone": "+70974969556"}
0005432528412	7E6F82	3381 680626	NATALYA PETROVA	{"email": "petrovanatalya-07111979@postgrespro.ru", "phone": "+70745263376"}
0005432528413	1F1499	9309 452914	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana-07021969@postgrespro.ru", "phone": "+70959538341"}
0005432528414	C3FDBC	5314 663466	NADEZHDA POPOVA	{"phone": "+70172477563"}
0005432528415	0230C4	3037 390984	KONSTANTIN DAVYDOV	{"phone": "+70930986713"}
0005432528416	C0CD0E	7450 136971	YULIYA MIKHAYLOVA	{"email": "mikhaylova_yuliya-1987@postgrespro.ru", "phone": "+70883155726"}
0005432528417	7CDED4	3216 640682	LYUBOV PETROVA	{"email": "lpetrova.1974@postgrespro.ru", "phone": "+70657897969"}
0005432528418	1AC963	0106 638388	YULIYA ROMANOVA	{"phone": "+70892642097"}
0005432528419	0E21FB	6181 427378	DMITRIY FROLOV	{"phone": "+70259161759"}
0005432528420	87F642	3053 033465	OLGA FROLOVA	{"phone": "+70005389897"}
0005432528421	87F642	9144 568134	EVGENIY STEPANOV	{"phone": "+70554208731"}
0005432528422	9B30DB	7335 472860	ROZA NIKOLAEVA	{"phone": "+70853044927"}
0005432528423	EF1B15	7788 652447	VALENTIN POPOV	{"phone": "+70123750002"}
0005432528424	5C9D32	6873 345162	ELENA LEBEDEVA	{"phone": "+70616334809"}
0005432528425	5C9D32	5572 900919	VIKTOR MOROZOV	{"phone": "+70799022422"}
0005432528426	5C9D32	2407 838173	OLEG MAKSIMOV	{"email": "omaksimov.10101992@postgrespro.ru", "phone": "+70934079937"}
0005432528427	069EF5	9262 814467	NATALYA ANDREEVA	{"phone": "+70094853544"}
0005432528428	069EF5	2078 084937	ALEKSEY MAKAROV	{"phone": "+70783268122"}
0005432528429	BF11E2	6265 840173	NATALIYA NIKOLAEVA	{"email": "nikolaeva-nataliya-26121979@postgrespro.ru", "phone": "+70010568440"}
0005432528430	BF11E2	1043 434888	LYUDMILA GAVRILOVA	{"email": "lgavrilova-1975@postgrespro.ru", "phone": "+70104319014"}
0005432528431	8974F9	0078 948169	YURIY IVANOV	{"phone": "+70656406357"}
0005432528432	8974F9	3578 920921	LYUDMILA DENISOVA	{"phone": "+70549176481"}
0005432528433	CEA912	1593 803609	VLADIMIR BELOV	{"phone": "+70549722143"}
0005432528434	25F318	3250 795146	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir-02091970@postgrespro.ru", "phone": "+70784209659"}
0005432528435	089459	5062 463065	GALINA OSIPOVA	{"email": "osipova-galina1970@postgrespro.ru", "phone": "+70552901332"}
0005432528436	589C4E	9796 549795	ALEKSANDRA NIKIFOROVA	{"email": "nikiforova.aleksandra-20031982@postgrespro.ru", "phone": "+70936401766"}
0005432528437	589C4E	6225 633048	SERGEY ROMANOV	{"email": "romanov_s-051974@postgrespro.ru", "phone": "+70508178992"}
0005432528438	364580	1439 826026	IVAN MIKHAYLOV	{"phone": "+70473971807"}
0005432528439	BEA9DE	1470 501817	NIKOLAY STEPANOV	{"phone": "+70969872058"}
0005432528440	BEA9DE	3544 907419	MAKSIM FROLOV	{"email": "maksim.frolov.20081963@postgrespro.ru", "phone": "+70245018784"}
0005432528441	5A7A90	9047 132156	EKATERINA ALEKSANDROVA	{"phone": "+70484317266"}
0005432528442	58CE5E	3503 545766	ALEKSEY KUDRYASHOV	{"email": "kudryashova_091972@postgrespro.ru", "phone": "+70902978477"}
0005432528443	C2385A	2037 874139	MIKHAIL EGOROV	{"phone": "+70815371984"}
0005432528444	061A7D	7749 761521	YULIYA ANTONOVA	{"phone": "+70852616695"}
0005432528445	40815E	8465 935539	NATALYA IVANOVA	{"email": "natalya-ivanova111973@postgrespro.ru", "phone": "+70112375922"}
0005432528446	B470BE	2163 060594	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana_1959@postgrespro.ru", "phone": "+70564346307"}
0005432528447	9F0F41	6965 570104	ALEKSANDR BELOV	{"phone": "+70720539987"}
0005432528448	4A1220	0009 356936	OLGA ERMAKOVA	{"email": "ermakova.o-031985@postgrespro.ru", "phone": "+70510318084"}
0005432528449	4A1220	4495 607053	MARGARITA TARASOVA	{"email": "tarasovamargarita.1990@postgrespro.ru", "phone": "+70148492623"}
0005432528450	71FDD0	8588 078275	ANTONINA EGOROVA	{"phone": "+70077328235"}
0005432528451	BF1021	0294 191476	RUSLAN VOROBEV	{"email": "rvorobev.101983@postgrespro.ru", "phone": "+70716055053"}
0005432528452	BF1021	9823 274148	TAMARA IVANOVA	{"phone": "+70223709797"}
0005432528453	FBEAD1	9436 079163	IRINA KRASNOVA	{"email": "krasnovairina_07121967@postgrespro.ru", "phone": "+70411236874"}
0005432528454	EBE568	2385 521595	VALERIYA SMIRNOVA	{"email": "valeriya.smirnova-11101972@postgrespro.ru", "phone": "+70272497431"}
0005432528455	EBE568	8078 743348	NATALYA NIKITINA	{"email": "n.nikitina.1971@postgrespro.ru", "phone": "+70792337935"}
0005432528456	FC0B40	8056 888130	IVAN NOVIKOV	{"phone": "+70646877257"}
0005432528457	639ED0	3351 342171	VITALIY KULIKOV	{"phone": "+70977217849"}
0005432528458	639ED0	8159 192815	SERGEY PETROV	{"email": "petrov_s-21071967@postgrespro.ru", "phone": "+70088715045"}
0005432528459	AA549E	1224 836587	MARIYA MAKAROVA	{"phone": "+70515515619"}
0005432528460	E6A5BE	0182 893094	VALERIY SAVELEV	{"email": "savelev_v_111969@postgrespro.ru", "phone": "+70001570570"}
0005432528461	E6A5BE	1591 461497	IVAN NIKITIN	{"email": "ivannikitin-28121970@postgrespro.ru", "phone": "+70058099905"}
0005432528462	70A508	5588 196493	MAKSIM OSIPOV	{"phone": "+70173569316"}
0005432528463	70A508	5792 171068	ARTEM ANDREEV	{"phone": "+70639588439"}
0005432528464	70A508	6680 557572	MARINA ROMANOVA	{"phone": "+70593892492"}
0005432528798	95FBC4	6267 647837	PAVEL OSIPOV	{"phone": "+70386173932"}
0005432528465	21F52B	7467 541592	YURIY TARASOV	{"email": "y_tarasov_061970@postgrespro.ru", "phone": "+70986491265"}
0005432528466	D2D738	7616 675008	ALEKSANDR YAKOVLEV	{"phone": "+70981113572"}
0005432528468	C87D92	3971 744930	VLADIMIR DENISOV	{"phone": "+70167240368"}
0005432528469	C87D92	3182 819651	VLADIMIR GERASIMOV	{"email": "gerasimov_vladimir_10041971@postgrespro.ru", "phone": "+70057287740"}
0005432528470	C87D92	7447 076175	SERGEY MAKSIMOV	{"phone": "+70258174927"}
0005432528471	CC7743	2698 357635	MARIYA IVANOVA	{"phone": "+70725675942"}
0005432528472	9B93F2	2058 189801	NATALYA ZHURAVLEVA	{"email": "zhuravleva.natalya-011978@postgrespro.ru", "phone": "+70448225538"}
0005432528473	8412B6	5340 425905	SOFIYA KUZNECOVA	{"email": "s-kuznecova1984@postgrespro.ru", "phone": "+70443950787"}
0005432528474	8412B6	2230 847269	VLADIMIR FILIPPOV	{"email": "vladimirfilippov-051973@postgrespro.ru", "phone": "+70089070982"}
0005432528475	242F61	2896 507839	MAKSIM MAKAROV	{"phone": "+70388969706"}
0005432528476	462AD3	9147 335156	SERGEY ZHURAVLEV	{"email": "sergey_zhuravlev.05041974@postgrespro.ru", "phone": "+70007561142"}
0005432528477	027044	8710 155649	BORIS SOROKIN	{"phone": "+70290962721"}
0005432528478	027044	5884 852907	VLADIMIR YAKOVLEV	{"email": "v-yakovlev_1974@postgrespro.ru", "phone": "+70971772108"}
0005432528479	027044	5934 502870	ANATOLIY SOKOLOV	{"phone": "+70992694929"}
0005432528480	BEC5DE	9084 593014	VLADISLAV SHEVCHENKO	{"email": "vshevchenko27121971@postgrespro.ru", "phone": "+70161690725"}
0005432528481	1ACD10	0242 652874	OLGA DMITRIEVA	{"email": "odmitrieva07081977@postgrespro.ru", "phone": "+70963693316"}
0005432528482	6EFC81	5728 998056	ELENA NIKITINA	{"phone": "+70140038221"}
0005432528483	CC61DC	8066 493201	MAKSIM KUZNECOV	{"email": "kuznecov-m.051975@postgrespro.ru", "phone": "+70037267711"}
0005432528484	8183DB	4768 336930	ELIZAVETA SOKOLOVA	{"email": "sokolova.elizaveta-021953@postgrespro.ru", "phone": "+70653125096"}
0005432528485	2A364E	9673 820976	MARINA SOLOVEVA	{"email": "marinasoloveva_111977@postgrespro.ru", "phone": "+70013645986"}
0005432528486	693E91	6522 795108	VLADIMIR FILIPPOV	{"phone": "+70314550467"}
0005432528487	693E91	5636 781266	ANDREY SMIRNOV	{"email": "a_smirnov_11111968@postgrespro.ru", "phone": "+70700591735"}
0005432528488	FE3B1D	6001 250265	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a_29121970@postgrespro.ru", "phone": "+70526248749"}
0005432528489	234BBB	3215 883312	VALERIY KONOVALOV	{"email": "valeriy-konovalov-081976@postgrespro.ru", "phone": "+70310769972"}
0005432528490	234BBB	7045 917366	SERGEY ALEKSANDROV	{"email": "aleksandrov-sergey_1974@postgrespro.ru", "phone": "+70314136257"}
0005432528491	15F886	1164 733666	OKSANA NIKIFOROVA	{"phone": "+70415550809"}
0005432528492	EB1460	0101 473485	GALINA POPOVA	{"email": "popova_g1972@postgrespro.ru", "phone": "+70588989007"}
0005432528493	A7F35B	5912 164635	STANISLAV KUZNECOV	{"email": "kuznecov-stanislav_05031976@postgrespro.ru", "phone": "+70016887547"}
0005432528494	022B32	8931 228564	SVETLANA ANISIMOVA	{"phone": "+70037803896"}
0005432528495	3795B5	8703 007380	ZINAIDA NESTEROVA	{"email": "zinaida-nesterova.02111967@postgrespro.ru", "phone": "+70411813566"}
0005432528496	DB630E	8641 707122	TATYANA ZHURAVLEVA	{"email": "tzhuravleva_1971@postgrespro.ru", "phone": "+70456727219"}
0005432528497	DB630E	8088 108573	VIKTORIYA NOVIKOVA	{"email": "viktoriya.novikova_1974@postgrespro.ru", "phone": "+70236291874"}
0005432528498	F4820F	9757 467815	NATALYA GERASIMOVA	{"email": "natalya-gerasimova_04051975@postgrespro.ru", "phone": "+70602249096"}
0005432528499	CD4C41	0434 191376	ALEKSEY ANTONOV	{"phone": "+70389341461"}
0005432528500	CD4C41	7345 491189	ALEKSANDR YAKOVLEV	{"phone": "+70126146508"}
0005432528501	CD4C41	9970 210098	FARID SERGEEV	{"email": "farid_sergeev-1977@postgrespro.ru", "phone": "+70533524740"}
0005432528502	D14343	9664 467845	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova.24041965@postgrespro.ru", "phone": "+70521742895"}
0005432528503	A6D857	5282 736357	VALENTINA NESTEROVA	{"phone": "+70732709927"}
0005432528504	A6D857	5029 354829	ANASTASIYA OVCHINNIKOVA	{"email": "anastasiya-ovchinnikova_061969@postgrespro.ru", "phone": "+70878508698"}
0005432528505	1BB1EF	7672 193696	ANATOLIY NIKITIN	{"email": "anatoliynikitin_23101976@postgrespro.ru", "phone": "+70015175099"}
0005432528506	1BB1EF	5625 430967	NATALYA MOISEEVA	{"email": "moiseeva_n011958@postgrespro.ru", "phone": "+70082738991"}
0005432528507	BC5431	9301 758061	ANDREY ANDREEV	{"phone": "+70503390318"}
0005432528508	BC5431	6127 823291	EVGENIY GUSEV	{"phone": "+70582293964"}
0005432528509	E4E34D	6064 889272	IRINA EGOROVA	{"email": "egorova-irina.04071966@postgrespro.ru", "phone": "+70291583398"}
0005432528510	03A9AE	3880 705867	LIDIYA PAVLOVA	{"phone": "+70420716100"}
0005432528511	8C1AE7	5221 732455	GALINA LUKYANOVA	{"phone": "+70398920134"}
0005432528512	2D3FF4	7923 544111	ALEKSANDR POPOV	{"email": "popovaleksandr.1968@postgrespro.ru", "phone": "+70842768092"}
0005432528513	2D3FF4	7770 113151	ANDREY BELOV	{"phone": "+70621925699"}
0005432528514	2D3FF4	7336 173114	ALEKSANDRA VOLKOVA	{"phone": "+70269875405"}
0005432528515	07C43F	8683 225927	TATYANA NIKITINA	{"email": "t-nikitina_031980@postgrespro.ru", "phone": "+70478572926"}
0005432528516	31E946	4144 598413	ANGELINA NAUMOVA	{"phone": "+70813138384"}
0005432528517	E6679A	6921 859449	ARTEM TIKHONOV	{"phone": "+70716153233"}
0005432528518	061041	2430 716029	OKSANA MELNIKOVA	{"phone": "+70256851380"}
0005432528519	061041	6761 330743	GRIGORIY MIRONOV	{"email": "mironovg.09081971@postgrespro.ru", "phone": "+70918975822"}
0005432528520	6BC264	9042 590469	SERGEY SERGEEV	{"email": "s_sergeev-1961@postgrespro.ru", "phone": "+70152362485"}
0005432528521	6BC264	3900 890097	DENIS SOKOLOV	{"phone": "+70211680255"}
0005432528522	6BC264	8516 785655	SVETLANA LUKYANOVA	{"email": "lukyanova_svetlana-02021982@postgrespro.ru", "phone": "+70208848655"}
0005432528523	D38FAA	9072 801370	GALINA ANTONOVA	{"phone": "+70941092127"}
0005432528524	D38FAA	0464 259321	VLADIMIR POPOV	{"phone": "+70026759615"}
0005432528525	6B7A8E	1905 006750	ANZHELA RODIONOVA	{"email": "anzhela.rodionova.081977@postgrespro.ru", "phone": "+70024608016"}
0005432528526	5346AA	8763 092855	TATYANA PAVLOVA	{"phone": "+70563823776"}
0005432528527	B2A75B	8402 513363	SERGEY DAVYDOV	{"email": "davydov.sergey.121991@postgrespro.ru", "phone": "+70230142413"}
0005432528528	62B410	9375 032745	MARGARITA KUZNECOVA	{"email": "margarita_kuznecova.07011977@postgrespro.ru", "phone": "+70173080492"}
0005432528529	285390	0920 585221	YURIY ROMANOV	{"phone": "+70533055570"}
0005432528530	285390	2785 782736	VLADISLAV DMITRIEV	{"email": "vladislavdmitriev-081966@postgrespro.ru", "phone": "+70671826074"}
0005432528531	4DA773	3233 106202	IVAN IVANOV	{"email": "i_ivanov-1977@postgrespro.ru", "phone": "+70585178771"}
0005432528532	7C0754	8020 263859	ALEKSEY MARTYNOV	{"email": "martynov-a071966@postgrespro.ru", "phone": "+70970001203"}
0005432528533	000DC5	3335 261030	SERGEY GRIGOREV	{"phone": "+70272018265"}
0005432528534	000DC5	2419 598419	SVETLANA YAKOVLEVA	{"phone": "+70575139635"}
0005432528535	2BC8F7	9009 941035	YURIY KOROLEV	{"email": "ykorolev111981@postgrespro.ru", "phone": "+70618802325"}
0005432528536	2BC8F7	2728 019888	TATYANA OVCHINNIKOVA	{"email": "tatyana.ovchinnikova1976@postgrespro.ru", "phone": "+70780579696"}
0005432528537	087F65	6332 655978	EVGENIY NIKOLAEV	{"phone": "+70751499486"}
0005432528538	628EAE	0677 010545	MATVEY IVANOV	{"email": "ivanov.matvey.1969@postgrespro.ru", "phone": "+70779189391"}
0005432528539	C75155	9692 476447	VIKTOR KISELEV	{"email": "kiselev-v-1976@postgrespro.ru", "phone": "+70322746537"}
0005432528540	94A10F	9987 940827	VERA PAVLOVA	{"email": "pavlova.v20061965@postgrespro.ru", "phone": "+70141775939"}
0005432528541	94A10F	6640 979775	DMITRIY TARASOV	{"email": "d-tarasov-13011960@postgrespro.ru", "phone": "+70019539085"}
0005432528542	94A10F	7450 070001	EKATERINA MELNIKOVA	{"email": "melnikova.e_1973@postgrespro.ru", "phone": "+70076279574"}
0005432528543	94A10F	1076 029193	VYACHESLAV MEDVEDEV	{"email": "medvedev-v-30061959@postgrespro.ru", "phone": "+70363163221"}
0005432528544	9E526E	0081 071186	EVGENIY DAVYDOV	{"email": "e_davydov-1983@postgrespro.ru", "phone": "+70326152294"}
0005432528545	9E526E	0382 407201	DARYA FROLOVA	{"email": "frolova-darya_1979@postgrespro.ru", "phone": "+70296186352"}
0005432528546	9E526E	7231 762204	EKATERINA ZOTOVA	{"phone": "+70758237114"}
0005432528547	6C2DFF	6619 591045	ANDREY GAVRILOV	{"email": "gavrilov-andrey-03011966@postgrespro.ru", "phone": "+70448558617"}
0005432528548	746B2D	5561 097730	GALINA IVANOVA	{"email": "ivanova_galina_12081977@postgrespro.ru", "phone": "+70723637489"}
0005432528549	746B2D	2297 860856	ANATOLIY DAVYDOV	{"phone": "+70198505988"}
0005432528550	67EC17	4236 873144	ALEVTINA STEPANOVA	{"email": "stepanova_a-021967@postgrespro.ru", "phone": "+70634428592"}
0005432528551	67EC17	8189 113645	ALEKSANDR FEDOTOV	{"phone": "+70165577550"}
0005432528552	67EC17	8287 085192	DARYA ANDREEVA	{"phone": "+70415877523"}
0005432528553	14B599	8964 382871	MARINA POPOVA	{"email": "m.popova_1966@postgrespro.ru", "phone": "+70687706192"}
0005432528554	123A85	9900 689545	LYUDMILA MELNIKOVA	{"phone": "+70513759566"}
0005432528555	8C440A	7017 528097	MARIYA LAZAREVA	{"phone": "+70438519934"}
0005432528556	33EC3C	5284 066362	VIKTOR NIKITIN	{"email": "v.nikitin_10061981@postgrespro.ru", "phone": "+70020551017"}
0005432528557	4E7167	1354 453969	EVGENIY FEDOTOV	{"email": "fedotov-evgeniy04021977@postgrespro.ru", "phone": "+70232947039"}
0005432528558	4E7167	2341 762849	SERGEY MATVEEV	{"email": "s-matveev_1962@postgrespro.ru", "phone": "+70239053619"}
0005432528559	37E42C	1565 096057	ANDREY MOROZOV	{"email": "morozova-1970@postgrespro.ru", "phone": "+70227044814"}
0005432528560	37E42C	1357 807812	YANA ANTONOVA	{"phone": "+70974805451"}
0005432528561	37E42C	3272 434252	NATALYA BOGDANOVA	{"phone": "+70334987447"}
0005432528562	A531C4	6206 212096	SERGEY IVANOV	{"phone": "+70319436734"}
0005432528563	33FC71	1299 543738	IRINA AFANASEVA	{"email": "afanaseva_irina-1978@postgrespro.ru", "phone": "+70857822710"}
0005432528564	33FC71	4681 187982	VALENTINA MOISEEVA	{"email": "valentina_moiseeva.22041975@postgrespro.ru", "phone": "+70591233045"}
0005432528565	F66DB8	6641 510455	LYUDMILA MAKAROVA	{"email": "l-makarova-18101974@postgrespro.ru", "phone": "+70384280191"}
0005432528566	7364D8	9901 724888	LYUBOV VASILEVA	{"email": "lyubov.vasileva_1964@postgrespro.ru", "phone": "+70259593384"}
0005432528567	BCA112	3123 020228	ANATOLIY EGOROV	{"email": "anatoliy.egorov-1971@postgrespro.ru", "phone": "+70040612707"}
0005432528568	CD1287	4411 537294	EVGENIYA KUZMINA	{"phone": "+70381806272"}
0005432528569	7E1097	9705 672194	ALEKSANDR NOVIKOV	{"email": "aleksandr_novikov-05121975@postgrespro.ru", "phone": "+70054279648"}
0005432528570	EB5A20	1013 997255	DMITRIY STEPANOV	{"phone": "+70569230638"}
0005432528571	EB5A20	8046 660083	IVAN PETROV	{"email": "petrov-ivan1971@postgrespro.ru", "phone": "+70114292386"}
0005432528572	6D6DBE	9377 358128	GALINA FOMINA	{"email": "g-fomina.23071974@postgrespro.ru", "phone": "+70711165506"}
0005432528573	6C3ED2	1275 232369	ALEKSANDR MOROZOV	{"email": "morozov_a011981@postgrespro.ru", "phone": "+70421030480"}
0005432528799	3156FB	7352 338261	GENNADIY MIRONOV	{"phone": "+70646610793"}
0005432528574	CCB55A	3668 742637	TAMARA SCHERBAKOVA	{"email": "scherbakova_t.26101970@postgrespro.ru", "phone": "+70800008129"}
0005432528575	FCC30C	8933 672071	DMITRIY EGOROV	{"phone": "+70540590646"}
0005432528576	63530F	6779 745786	DANIL SOLOVEV	{"phone": "+70278470124"}
0005432528577	0C2B78	0755 474487	EKATERINA SAVELEVA	{"phone": "+70893097571"}
0005432528578	0C2B78	5372 387147	IRINA VASILEVA	{"phone": "+70095572476"}
0005432528579	698644	1684 242521	OLGA GORBUNOVA	{"phone": "+70115381053"}
0005432528580	698644	1759 181957	ALI MAKAROV	{"phone": "+70109093158"}
0005432528581	698644	2767 106909	DMITRIY VOLKOV	{"email": "volkov.d1965@postgrespro.ru", "phone": "+70567136381"}
0005432528582	E34917	4766 525004	LYUDMILA MELNIKOVA	{"phone": "+70346571872"}
0005432528583	2123BC	4378 890977	ANDREY VOLKOV	{"phone": "+70611345796"}
0005432528584	2123BC	0011 274338	NATALYA KUDRYASHOVA	{"phone": "+70954500797"}
0005432528585	01E788	2716 884399	ANDREY FEDOROV	{"email": "fedorov-andrey-031971@postgrespro.ru", "phone": "+70409408233"}
0005432528586	52304F	8921 852104	VALENTINA TARASOVA	{"phone": "+70682727887"}
0005432528587	E367DF	7300 755912	NATALYA KUDRYASHOVA	{"phone": "+70146319500"}
0005432528588	31D0EB	1439 978720	KIRILL VLASOV	{"phone": "+70667088190"}
0005432528589	3534DD	1947 764365	LEYLA KOLESNIKOVA	{"email": "leylakolesnikova051974@postgrespro.ru", "phone": "+70960678722"}
0005432528590	3534DD	8998 905388	LEV SEMENOV	{"phone": "+70769610248"}
0005432528591	AB488A	0875 140670	DMITRIY PAVLOV	{"phone": "+70033530604"}
0005432528592	D05E42	7081 372020	NADEZHDA VASILEVA	{"phone": "+70006728790"}
0005432528593	D05E42	1033 997155	ELENA LAZAREVA	{"email": "e_lazareva-1969@postgrespro.ru", "phone": "+70367901810"}
0005432528594	D05E42	7565 746017	ALEKSEY KRASNOV	{"phone": "+70871637985"}
0005432528595	650C97	5767 317965	YURIY SHEVCHENKO	{"email": "y_shevchenko_1971@postgrespro.ru", "phone": "+70915917384"}
0005432528596	143493	0498 704054	SVETLANA IVANOVA	{"email": "ivanova-svetlana.16111979@postgrespro.ru", "phone": "+70920493215"}
0005432528597	143493	5996 506587	NIKOLAY NAUMOV	{"phone": "+70925688462"}
0005432528598	143493	7088 186589	DARYA ERMAKOVA	{"phone": "+70195424070"}
0005432528599	274292	7079 086293	ANNA SOROKINA	{"email": "sorokinaanna1975@postgrespro.ru", "phone": "+70754821660"}
0005432528600	538019	2947 747507	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana_1974@postgrespro.ru", "phone": "+70582812741"}
0005432528601	FB7CC9	8073 662492	SVETLANA AFANASEVA	{"email": "s.afanaseva.061980@postgrespro.ru", "phone": "+70954745930"}
0005432528602	55F559	4707 267714	ANNA MARTYNOVA	{"phone": "+70971268082"}
0005432528603	55F559	3486 728612	ALEKSANDR FROLOV	{"email": "frolovaleksandr12021968@postgrespro.ru", "phone": "+70402966652"}
0005432528604	55F559	5857 267301	GEVORG MOISEEV	{"email": "g-moiseev15011978@postgrespro.ru", "phone": "+70070329629"}
0005432528605	CB0C34	6097 882731	NINA MAKAROVA	{"email": "makarova_nina1974@postgrespro.ru", "phone": "+70638075934"}
0005432528606	C8499A	0284 663658	SERGEY SEMENOV	{"email": "ssemenov.21061967@postgrespro.ru", "phone": "+70654635115"}
0005432528607	7C7E6E	6059 767083	EKATERINA SEMENOVA	{"email": "ekaterina_semenova.111970@postgrespro.ru", "phone": "+70151282219"}
0005432528608	E203F0	3896 021323	VALENTINA POTAPOVA	{"phone": "+70520883906"}
0005432528609	88CB3C	9678 981428	LIDIYA GRISHINA	{"phone": "+70722269059"}
0005432528610	6FC92A	4475 821832	MIKHAIL FEDOTOV	{"phone": "+70351695491"}
0005432528611	4E21E5	8971 365243	IVAN PAVLOV	{"phone": "+70979346235"}
0005432528612	C83DB9	6331 051510	NINA ZHURAVLEVA	{"phone": "+70986786882"}
0005432528613	47C7BC	5701 818001	DENIS ZAYCEV	{"email": "zaycevdenis-061980@postgrespro.ru", "phone": "+70758054914"}
0005432528614	59FB94	6003 476101	ANDREY MEDVEDEV	{"phone": "+70245909421"}
0005432528615	EF0B88	4562 228497	SERGEY SAVELEV	{"email": "savelevs.071974@postgrespro.ru", "phone": "+70708013033"}
0005432528616	69C355	5017 540589	EVGENIY ROMANOV	{"email": "romanov-evgeniy_1965@postgrespro.ru", "phone": "+70568362117"}
0005432528617	2B9580	1945 022494	ANTONINA GUSEVA	{"phone": "+70569261894"}
0005432528618	2B9580	7862 425796	KIRILL KISELEV	{"email": "kiselev_k051981@postgrespro.ru", "phone": "+70731356609"}
0005432528619	1A18D2	2954 940669	ELENA ANDREEVA	{"email": "andreeva_e09021979@postgrespro.ru", "phone": "+70575232876"}
0005432528620	1A18D2	9043 813615	VLADIMIR SEMENOV	{"phone": "+70025103070"}
0005432528621	9B6962	5681 770562	YAROSLAV MOISEEV	{"phone": "+70459893922"}
0005432528622	89DEBA	7905 859505	GALINA MEDVEDEVA	{"email": "galina-medvedeva_27111964@postgrespro.ru", "phone": "+70183195227"}
0005432528623	89DEBA	1555 835089	VIKTOR IVANOV	{"phone": "+70900814844"}
0005432528624	89DEBA	4056 506986	NATALYA ARKHIPOVA	{"email": "arkhipova_natalya-1979@postgrespro.ru", "phone": "+70061090682"}
0005432528625	881533	0944 675334	ZOYA KUZNECOVA	{"phone": "+70707111430"}
0005432528626	25B0E3	2038 774007	NINA KRASNOVA	{"phone": "+70715949833"}
0005432528627	25B0E3	3490 415749	ULYANA VASILEVA	{"email": "ulyana-vasileva.051969@postgrespro.ru", "phone": "+70851121842"}
0005432528628	0A1926	4704 037298	ANASTASIYA RODIONOVA	{"phone": "+70617180260"}
0005432528629	4E6492	4701 571440	IVAN ANTONOV	{"email": "i.antonov_28091962@postgrespro.ru", "phone": "+70705886438"}
0005432528630	8118F9	0335 574915	ELENA NOVIKOVA	{"phone": "+70329126049"}
0005432528631	8118F9	0504 839253	ALEKSANDR KUZNECOV	{"email": "kuznecov.a.24111964@postgrespro.ru", "phone": "+70316939973"}
0005432528632	DE95D0	9106 255027	ALESYA OSIPOVA	{"phone": "+70105407454"}
0005432528633	62995C	2042 430673	LYUDMILA GRISHINA	{"email": "grishina_lyudmila.26101968@postgrespro.ru", "phone": "+70863169989"}
0005432528634	62995C	1268 274721	VALENTINA SOKOLOVA	{"phone": "+70249196137"}
0005432528635	62995C	2167 232471	ANNA FEDOROVA	{"phone": "+70900465836"}
0005432528636	6C4E2C	2731 107590	ANDREY ZAYCEV	{"email": "andrey.zaycev10031964@postgrespro.ru", "phone": "+70177301851"}
0005432528637	6D96CE	4512 514221	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov-041963@postgrespro.ru", "phone": "+70882670585"}
0005432528638	6D96CE	3178 347635	AZAT KISELEV	{"email": "azat.kiselev-1963@postgrespro.ru", "phone": "+70412941295"}
0005432528639	6D96CE	3063 873185	ELENA NIKIFOROVA	{"phone": "+70427556839"}
0005432528640	E89887	5198 794178	ELENA DAVYDOVA	{"phone": "+70103688755"}
0005432528641	F5825B	5055 979371	RAMIL NOVIKOV	{"phone": "+70835288171"}
0005432528642	F5825B	9798 534920	POLINA KARPOVA	{"phone": "+70225654632"}
0005432528643	3FDD1E	2513 810436	DENIS PETROV	{"email": "denis_petrov031965@postgrespro.ru", "phone": "+70293582149"}
0005432528644	F9B340	4923 242548	NADEZHDA LUKYANOVA	{"phone": "+70050857671"}
0005432528645	F9B340	0147 043093	ALEKSEY KUDRYASHOV	{"phone": "+70239460933"}
0005432528646	838E1B	6846 070727	PETR SHEVCHENKO	{"email": "petr-shevchenko-1967@postgrespro.ru", "phone": "+70707898902"}
0005432528647	838E1B	1573 530088	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin-1968@postgrespro.ru", "phone": "+70736293688"}
0005432528648	838E1B	0139 969059	INESSA KARPOVA	{"phone": "+70287308608"}
0005432528649	CEA418	0762 720568	ANATOLIY FROLOV	{"email": "afrolov_011977@postgrespro.ru", "phone": "+70218277709"}
0005432528650	51E692	3367 696364	ALEKSANDR KONOVALOV	{"email": "konovalova1961@postgrespro.ru", "phone": "+70554360730"}
0005432528651	C16737	9387 900802	NATALYA POTAPOVA	{"email": "potapova_natalya.1979@postgrespro.ru", "phone": "+70820008857"}
0005432528652	8A4F15	1487 264412	ALEKSANDR VOLKOV	{"email": "volkov-a.1964@postgrespro.ru", "phone": "+70924688831"}
0005432528653	404168	5779 153232	TAMARA ZAYCEVA	{"email": "zayceva_tamara_18011978@postgrespro.ru", "phone": "+70211124012"}
0005432528654	04BB81	1181 187035	OLEG VASILEV	{"phone": "+70024884570"}
0005432528655	E797B2	6612 829161	SVETLANA ILINA	{"email": "ilina_s_1974@postgrespro.ru", "phone": "+70712633446"}
0005432528656	E797B2	4958 558295	DENIS KOROLEV	{"phone": "+70708105488"}
0005432528657	6B4032	4980 926184	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_03051968@postgrespro.ru", "phone": "+70664095940"}
0005432528658	6B4032	1716 594009	SEMEN MELNIKOV	{"email": "semen-melnikov21121977@postgrespro.ru", "phone": "+70782175696"}
0005432528659	3DF9FF	3985 077579	VLADIMIR IVANOV	{"phone": "+70574183589"}
0005432528660	48CDD0	2629 546144	LYUBOV CHERNOVA	{"email": "chernova_l-14071968@postgrespro.ru", "phone": "+70028870298"}
0005432528661	0D65D3	1117 052885	NATALYA KOROLEVA	{"phone": "+70065938244"}
0005432528662	0D65D3	2754 230186	ELENA POPOVA	{"phone": "+70659867068"}
0005432528663	18DF8D	1564 756276	ELENA ISAEVA	{"email": "elenaisaeva_17011967@postgrespro.ru", "phone": "+70128063976"}
0005432528664	DD040B	6064 283192	ALEKSEY ANDREEV	{"email": "a_andreev-27041983@postgrespro.ru", "phone": "+70369700549"}
0005432528665	5BE4CA	8425 265531	ANDREY SOLOVEV	{"phone": "+70106970162"}
0005432528666	4B552F	6293 662031	ANTONINA KONDRATEVA	{"phone": "+70371860697"}
0005432528667	AB1042	7739 589187	SERGEY KUZNECOV	{"phone": "+70019761656"}
0005432528668	DF208C	2371 092422	SERGEY MEDVEDEV	{"phone": "+70988048919"}
0005432528669	F9F34C	1497 515673	EVGENIY SOKOLOV	{"phone": "+70701802931"}
0005432528670	444E40	7896 214093	LIDIYA BARANOVA	{"email": "l.baranova.071967@postgrespro.ru", "phone": "+70200863128"}
0005432528671	C5D757	6409 766834	ANDREY SOKOLOV	{"phone": "+70257624552"}
0005432528672	082564	3794 016160	MARIYA TIKHONOVA	{"email": "m_tikhonova_27111978@postgrespro.ru", "phone": "+70948066615"}
0005432528673	06634A	8797 023131	ANDREY MAKSIMOV	{"email": "a_maksimov.1962@postgrespro.ru", "phone": "+70531034292"}
0005432528674	06634A	5975 788836	GENNADIY EGOROV	{"phone": "+70401628417"}
0005432528675	6E9EE2	3160 172530	ALEKSANDRA YUDINA	{"email": "aleksandra_yudina041961@postgrespro.ru", "phone": "+70647984315"}
0005432528676	6E9EE2	1414 066537	ELENA KUZNECOVA	{"email": "kuznecova.e_1968@postgrespro.ru", "phone": "+70060057161"}
0005432528677	6E9EE2	3972 428044	MARIYA KARPOVA	{"email": "m_karpova.1972@postgrespro.ru", "phone": "+70079167897"}
0005432528678	4C4B70	3546 866431	DANIIL GORBUNOV	{"phone": "+70632441595"}
0005432528679	4C4B70	4080 984674	STANISLAV ZAKHAROV	{"phone": "+70706463483"}
0005432528680	97E60F	3722 718218	SERAFIMA DAVYDOVA	{"email": "davydova-serafima.25111972@postgrespro.ru", "phone": "+70691316238"}
0005432528681	97E60F	7502 292954	ANASTASIYA SERGEEVA	{"email": "sergeeva-a04111979@postgrespro.ru", "phone": "+70461075602"}
0005432528682	3DF4AC	2200 456185	LYUBOV ANTONOVA	{"email": "lyubov.antonova071972@postgrespro.ru", "phone": "+70497184914"}
0005432528683	0358AE	8116 337223	ARSENIY MOROZOV	{"email": "arseniy-morozov101979@postgrespro.ru", "phone": "+70585074216"}
0005432528684	A21DC8	3553 906842	RAISA FEDOROVA	{"phone": "+70686942639"}
0005432528685	E6965F	3858 827991	DMITRIY BARANOV	{"phone": "+70894712254"}
0005432528686	E6965F	4860 322410	ELENA SMIRNOVA	{"phone": "+70825303081"}
0005432528687	E6965F	6420 201170	ELENA MOROZOVA	{"email": "emorozova-1963@postgrespro.ru", "phone": "+70052436783"}
0005432528688	D88DB9	1070 880602	RAFAIL GERASIMOV	{"phone": "+70120305526"}
0005432528689	D88DB9	2785 688006	MARIYA ZHURAVLEVA	{"phone": "+70338497132"}
0005432528690	6AF1C8	8921 147862	ELENA GUSEVA	{"phone": "+70038148232"}
0005432528691	7A0B36	0977 903871	ALEKSANDR BELOV	{"phone": "+70537841817"}
0005432528692	EFC56E	4262 716452	LYUDMILA KAZAKOVA	{"email": "lyudmila_kazakova.061970@postgrespro.ru", "phone": "+70972837009"}
0005432528693	E6EFC6	9182 585470	ELENA MELNIKOVA	{"phone": "+70928251168"}
0005432528694	E6EFC6	1605 789790	YURIY FEDOTOV	{"email": "y-fedotov-1982@postgrespro.ru", "phone": "+70501722705"}
0005432528695	E6EFC6	8832 126616	ELENA DMITRIEVA	{"phone": "+70729334140"}
0005432528696	4F4CD6	7636 981221	VALERIY STEPANOV	{"phone": "+70437449795"}
0005432528697	839573	0385 113126	TATYANA ISAEVA	{"email": "t-isaeva.071987@postgrespro.ru", "phone": "+70115238341"}
0005432528698	839573	5709 754163	TATYANA YAKOVLEVA	{"phone": "+70074020746"}
0005432528699	839573	6559 128307	ALEKSANDR MATVEEV	{"phone": "+70737657476"}
0005432528700	F7007E	7331 368096	TATYANA KOROLEVA	{"phone": "+70764882485"}
0005432528701	5593A3	0586 563320	ZHANNA GERASIMOVA	{"phone": "+70796266286"}
0005432528702	5593A3	9397 296317	IVAN PAVLOV	{"email": "pavlov-ivan_1972@postgrespro.ru", "phone": "+70570827961"}
0005432528703	ABFB26	2106 817758	MARGARITA TIMOFEEVA	{"email": "m.timofeeva01061968@postgrespro.ru", "phone": "+70514999616"}
0005432528704	BA74F3	3659 647945	VLADIMIR KARPOV	{"phone": "+70636861244"}
0005432528705	BA74F3	9782 857275	IRINA VASILEVA	{"phone": "+70709452665"}
0005432528706	7BCC8A	5810 281178	NATALYA PETROVA	{"email": "petrova-natalya1972@postgrespro.ru", "phone": "+70156312606"}
0005432528707	70B571	6119 833277	OLGA TIKHONOVA	{"email": "tikhonova-olga-30011977@postgrespro.ru", "phone": "+70742625620"}
0005432528708	70B571	3439 947010	MARIYA KUZMINA	{"phone": "+70367592842"}
0005432528709	C13310	2198 348155	IRINA OSIPOVA	{"phone": "+70080739161"}
0005432528710	4CF28D	4764 569736	MARIYA NAUMOVA	{"phone": "+70639814790"}
0005432528711	4CF28D	5363 773098	SERGEY FROLOV	{"email": "s_frolov_1977@postgrespro.ru", "phone": "+70758828033"}
0005432528712	FC2B85	6885 524935	VLADIMIR ANTONOV	{"phone": "+70358580485"}
0005432528713	04BE51	0072 678622	LIDIYA FROLOVA	{"phone": "+70873942804"}
0005432528714	04BE51	1384 990290	ELIZAVETA MOISEEVA	{"email": "moiseeva-elizaveta-29071974@postgrespro.ru", "phone": "+70879288448"}
0005432528715	5BF614	4411 113211	VERONIKA VLASOVA	{"email": "vlasova_veronika071968@postgrespro.ru", "phone": "+70689120534"}
0005432528716	5BF614	9054 441439	TATYANA IVANOVA	{"phone": "+70308527442"}
0005432528717	ACDFB9	3422 036906	NATALYA ZAYCEVA	{"email": "natalyazayceva-1962@postgrespro.ru", "phone": "+70791781577"}
0005432528718	ACDFB9	2153 577112	ILNAR OSIPOV	{"email": "osipov-ilnar_07101974@postgrespro.ru", "phone": "+70488625344"}
0005432528719	828C84	8794 421221	TATYANA BORISOVA	{"phone": "+70077489009"}
0005432528720	828C84	3542 161623	VYACHESLAV BONDARENKO	{"email": "v.bondarenko-121976@postgrespro.ru", "phone": "+70346932590"}
0005432528721	83917D	1795 919225	SOFYA ZHUKOVA	{"email": "zhukova-s.1973@postgrespro.ru", "phone": "+70426210847"}
0005432528722	83917D	8910 942062	GALINA LAZAREVA	{"email": "lazareva_galina03061965@postgrespro.ru", "phone": "+70589566625"}
0005432528723	9B4E09	2673 300432	GRIGORIY STEPANOV	{"phone": "+70125020483"}
0005432528724	9B4E09	8369 307755	NATALIYA KUZNECOVA	{"email": "n.kuznecova_29111975@postgrespro.ru", "phone": "+70832650460"}
0005432528725	A7F51A	1457 500254	NATALYA VASILEVA	{"phone": "+70192780615"}
0005432528726	A7F51A	2873 494903	ALEKSANDR OSIPOV	{"email": "aleksandrosipov19021973@postgrespro.ru", "phone": "+70462654055"}
0005432528727	95BFCD	2402 855125	ILDAR ALEKSEEV	{"email": "alekseev-ildar-08071963@postgrespro.ru", "phone": "+70875457792"}
0005432528728	8619A6	7415 893918	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir_23061966@postgrespro.ru", "phone": "+70812262963"}
0005432528729	8619A6	4864 216081	LYUBOV KUZNECOVA	{"email": "kuznecoval-1969@postgrespro.ru", "phone": "+70972213940"}
0005432528730	13CB7C	9070 958467	KSENIYA NIKITINA	{"email": "k-nikitina.1961@postgrespro.ru", "phone": "+70219938165"}
0005432528731	13CB7C	3720 126414	VADIM KOROLEV	{"phone": "+70046129203"}
0005432528732	E8E266	8602 446981	SERGEY KUZMIN	{"phone": "+70763127872"}
0005432528733	879222	2782 019907	VALENTINA GORBUNOVA	{"email": "gorbunova_valentina1966@postgrespro.ru", "phone": "+70723148065"}
0005432528734	5C573A	5542 646017	VASILIY VOLKOV	{"phone": "+70961628770"}
0005432528735	5C573A	6141 416820	VALENTINA MAKAROVA	{"phone": "+70101565468"}
0005432528736	E6B4EF	1130 409889	OLGA KUZMINA	{"email": "o.kuzmina1964@postgrespro.ru", "phone": "+70771718760"}
0005432528737	E6B4EF	5868 299439	TAMARA PAVLOVA	{"email": "tamara_pavlova_1977@postgrespro.ru", "phone": "+70416456097"}
0005432528738	E6B4EF	5544 676190	LYUBOV NAUMOVA	{"phone": "+70554711728"}
0005432528739	F0D849	0971 117518	SERGEY FEDOROV	{"email": "sergey-fedorov_24071979@postgrespro.ru", "phone": "+70096374795"}
0005432528740	C075A8	4799 976253	VERA FILATOVA	{"phone": "+70836801493"}
0005432528741	D9943C	3519 751808	TATYANA SCHERBAKOVA	{"email": "scherbakova.tatyana.071984@postgrespro.ru", "phone": "+70115970124"}
0005432528742	ACADC9	8710 161437	YURIY ROMANOV	{"email": "romanov_y-26121981@postgrespro.ru", "phone": "+70039357040"}
0005432528743	78F7E6	2837 500189	EVGENIY KUZMIN	{"email": "kuzmine-1971@postgrespro.ru", "phone": "+70146446639"}
0005432528744	BA8BD9	2239 253719	SERGEY GORBUNOV	{"email": "sergey.gorbunov-081977@postgrespro.ru", "phone": "+70389130489"}
0005432528745	BA8BD9	8525 580731	ALEKSANDR KAZAKOV	{"email": "kazakova_05021968@postgrespro.ru", "phone": "+70182720707"}
0005432528746	5E2215	2343 826966	ALEKSANDR IVANOV	{"email": "aivanov.15041972@postgrespro.ru", "phone": "+70752032186"}
0005432528747	2E106B	2432 446871	ANATOLIY BORISOV	{"email": "anatoliy_borisov1969@postgrespro.ru", "phone": "+70192602984"}
0005432528748	F32A64	7284 822854	RAISA ROMANOVA	{"email": "raisa_romanova_1962@postgrespro.ru", "phone": "+70283909781"}
0005432528749	327E16	8682 479840	ANASTASIYA GORBUNOVA	{"phone": "+70396431195"}
0005432528750	7C65D0	2848 553066	VIKTORIYA EGOROVA	{"email": "v_egorova.16041971@postgrespro.ru", "phone": "+70091983845"}
0005432528751	7C65D0	5898 196150	LYUBOV KOROLEVA	{"email": "l.koroleva_1971@postgrespro.ru", "phone": "+70051026251"}
0005432528752	2F93C8	4742 544195	INNA ISAEVA	{"email": "isaeva.i.051974@postgrespro.ru", "phone": "+70251832153"}
0005432528753	20D004	2290 241642	LYUDMILA FILATOVA	{"phone": "+70656144684"}
0005432528754	A1E6EE	2031 906520	ELENA KOVALEVA	{"phone": "+70475609749"}
0005432528755	9CF9C1	2282 133090	ALEKSANDR MOROZOV	{"phone": "+70568223003"}
0005432528756	E5600B	5281 593815	VALENTINA POPOVA	{"phone": "+70363871315"}
0005432528757	3C8EA1	7634 217282	VLADIMIR GERASIMOV	{"email": "gerasimov_vladimir.1965@postgrespro.ru", "phone": "+70012201385"}
0005432528758	3C8EA1	2903 187352	LARISA POPOVA	{"email": "l.popova-23031969@postgrespro.ru", "phone": "+70946797787"}
0005432528759	71B16E	0340 437244	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva1972@postgrespro.ru", "phone": "+70673268619"}
0005432528760	71B16E	3663 100968	MAKSIM KUZMIN	{"phone": "+70813107281"}
0005432528761	F30684	1083 667418	MARIYA NIKIFOROVA	{"phone": "+70190148105"}
0005432528762	3B8597	6233 438970	ALEKSANDR KOZLOV	{"phone": "+70191169989"}
0005432528763	544548	0013 078891	MARIYA ROMANOVA	{"email": "romanova-m10011944@postgrespro.ru", "phone": "+70713927753"}
0005432528764	DAD2F5	7543 440902	TATYANA KAZAKOVA	{"email": "kazakova.tatyana_30061980@postgrespro.ru", "phone": "+70788665828"}
0005432528765	B7E164	8344 099262	ANNA MAKSIMOVA	{"email": "maksimova.anna_1963@postgrespro.ru", "phone": "+70092485968"}
0005432528766	A6ECF7	7738 061588	LEONID POPOV	{"email": "lpopov.13091960@postgrespro.ru", "phone": "+70308774685"}
0005432528767	DBE17B	8313 886092	MIKHAIL ROMANOV	{"phone": "+70055414805"}
0005432528768	4081FA	3040 281776	LYUBOV FOMINA	{"email": "lyubov_fomina.071972@postgrespro.ru", "phone": "+70389787093"}
0005432528769	B79C5F	7031 747977	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova101976@postgrespro.ru", "phone": "+70166055871"}
0005432528770	E00624	7942 133223	YANA TARASOVA	{"phone": "+70064028413"}
0005432528771	D30C2D	5692 299921	ARKADIY TIKHONOV	{"phone": "+70182788551"}
0005432528772	D30C2D	7924 080612	EVGENIY KISELEV	{"email": "kiseleve-29071985@postgrespro.ru", "phone": "+70537765810"}
0005432528773	202A58	8925 553440	ALLA NIKOLAEVA	{"email": "nikolaeva.a.21031972@postgrespro.ru", "phone": "+70954768248"}
0005432528774	246946	9450 505475	TATYANA BOGDANOVA	{"phone": "+70714811618"}
0005432528775	CBB6BC	3304 676795	YULIYA SERGEEVA	{"email": "yuliya.sergeeva1974@postgrespro.ru", "phone": "+70336929742"}
0005432528776	CBB6BC	7178 453687	ANDREY ALEKSANDROV	{"phone": "+70956275310"}
0005432528777	0F388D	7082 014377	OLGA STEPANOVA	{"phone": "+70614383627"}
0005432528778	0F388D	6589 574910	ALEKSEY FEDOTOV	{"email": "fedotov_aleksey_09031969@postgrespro.ru", "phone": "+70318328542"}
0005432528779	45D6B0	6586 008674	OLESYA EGOROVA	{"email": "o.egorova.12111972@postgrespro.ru", "phone": "+70331641209"}
0005432528780	E073FD	3406 467800	VLADISLAV SEMENOV	{"email": "vsemenov.021979@postgrespro.ru", "phone": "+70598313449"}
0005432528781	51B3C7	4178 259543	IGOR GAVRILOV	{"phone": "+70606592015"}
0005432528782	69E41F	7398 228356	TATYANA VLASOVA	{"email": "vlasova-t1958@postgrespro.ru", "phone": "+70461334616"}
0005432528783	C89F9F	2802 511662	ARTEM VLASOV	{"phone": "+70734015499"}
0005432528784	C89F9F	7286 436148	TATYANA KISELEVA	{"email": "kiseleva-t1975@postgrespro.ru", "phone": "+70051481321"}
0005432528785	3EB4DB	7742 779906	DARYA NAZAROVA	{"email": "nazarova-d_071967@postgrespro.ru", "phone": "+70641553896"}
0005432528786	3EB4DB	6327 668615	SVETLANA NOVIKOVA	{"email": "novikova_s-14031966@postgrespro.ru", "phone": "+70778313401"}
0005432528787	323A31	1745 047477	ALEKSANDR DMITRIEV	{"email": "admitriev.22021975@postgrespro.ru", "phone": "+70156924992"}
0005432528788	1718EA	8998 111156	ANATOLIY KARPOV	{"email": "anatoliy.karpov1971@postgrespro.ru", "phone": "+70471576154"}
0005432528789	1718EA	5696 552608	PAVEL ZAYCEV	{"email": "zaycevp071958@postgrespro.ru", "phone": "+70684666777"}
0005432528790	55FA98	8751 940146	ELENA VASILEVA	{"phone": "+70447431638"}
0005432528791	30CEC4	2745 623786	DMITRIY IVANOV	{"phone": "+70106214221"}
0005432528792	30CEC4	2081 551965	MIKHAIL KISELEV	{"phone": "+70179726446"}
0005432528793	470EE0	7737 335374	VALENTINA EGOROVA	{"phone": "+70975986858"}
0005432528794	847223	7942 711467	SERGEY ISAEV	{"phone": "+70401156698"}
0005432528795	847223	4721 612367	VASILIY ANTONOV	{"email": "vasiliy-antonov.28101976@postgrespro.ru", "phone": "+70301494157"}
0005432528796	95FBC4	6668 286511	ANTONINA ALEKSANDROVA	{"phone": "+70173867073"}
0005432528797	95FBC4	7150 783538	TATYANA MAKSIMOVA	{"email": "tatyana_maksimova1962@postgrespro.ru", "phone": "+70376972328"}
0005432528800	ECE86A	3985 692716	NATALYA KUZNECOVA	{"email": "kuznecovanatalya_10031980@postgrespro.ru", "phone": "+70108937491"}
0005432528801	6A75AB	9070 644749	ANATOLIY VOLKOV	{"phone": "+70954783930"}
0005432528802	6A75AB	9606 974349	GYUZEL NOVIKOVA	{"phone": "+70735242574"}
0005432528803	362866	3746 900807	LIDIYA VOLKOVA	{"email": "volkovalidiya-23021969@postgrespro.ru", "phone": "+70909681745"}
0005432528804	56D9E0	8835 452459	LYUBOV SOKOLOVA	{"phone": "+70096295805"}
0005432528805	5CBB07	2398 650442	NINA GRISHINA	{"phone": "+70453760752"}
0005432528806	4A31C5	7516 890120	SVETLANA SMIRNOVA	{"phone": "+70974307984"}
0005432528807	4A31C5	8356 507000	VERA VOROBEVA	{"phone": "+70871859252"}
0005432528808	7B1577	4341 328014	ANNA GORBUNOVA	{"email": "agorbunova031973@postgrespro.ru", "phone": "+70772202575"}
0005432528809	C553D7	3297 314003	SERGEY FEDOTOV	{"phone": "+70931182672"}
0005432528810	180348	3539 287865	VIKTORIYA BOGDANOVA	{"phone": "+70163708581"}
0005432528811	7E9D4E	1727 561895	VIKTORIYA GUSEVA	{"email": "v-guseva03121972@postgrespro.ru", "phone": "+70990311032"}
0005432528812	7E9D4E	9619 036362	PAVEL PAVLOV	{"phone": "+70537976503"}
0005432528813	7E9D4E	4742 941061	TAMARA ALEKSANDROVA	{"phone": "+70554151870"}
0005432528814	7D93E7	6062 962373	VALENTIN SOLOVEV	{"email": "valentinsolovev.1972@postgrespro.ru", "phone": "+70530324305"}
0005432528815	3BE706	7351 763396	TAMARA ILINA	{"phone": "+70497745122"}
0005432528816	3BE706	8504 418551	LYUDMILA MOROZOVA	{"phone": "+70375421753"}
0005432528817	2942DF	9370 971704	ILYA KUZNECOV	{"email": "ilya.kuznecov_021983@postgrespro.ru", "phone": "+70682697261"}
0005432528818	E8E17B	0310 135407	ELIZAVETA NESTEROVA	{"email": "nesterovaelizaveta-1969@postgrespro.ru", "phone": "+70717113998"}
0005432528819	E8E17B	6237 102697	ALEKSANDRA SERGEEVA	{"email": "sergeeva.aleksandra-10041981@postgrespro.ru", "phone": "+70381974877"}
0005432528820	5A9AA0	6304 826146	NINA MIRONOVA	{"email": "nina.mironova.1968@postgrespro.ru", "phone": "+70044835244"}
0005432528821	5A9AA0	8738 259556	NIKITA SMIRNOV	{"email": "smirnov.nikita-1984@postgrespro.ru", "phone": "+70635935487"}
0005432528822	5A9AA0	5499 974369	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir1972@postgrespro.ru", "phone": "+70347832615"}
0005432528823	07D8DC	7823 973266	NATALYA TIMOFEEVA	{"phone": "+70723193643"}
0005432528824	54D717	9117 891826	SVETLANA KOVALEVA	{"email": "skovaleva_13021969@postgrespro.ru", "phone": "+70340456784"}
0005432528825	6D133C	2024 642654	ELENA MATVEEVA	{"phone": "+70618290742"}
0005432528826	E2334A	7227 896816	KIRILL FILIPPOV	{"phone": "+70629905112"}
0005432528827	E2334A	9698 543117	VLADIMIR VLASOV	{"email": "vlasov_vladimir061968@postgrespro.ru", "phone": "+70752841256"}
0005432528828	F79758	8065 012546	VALERIYA FADEEVA	{"phone": "+70111092635"}
0005432528829	F79758	3516 840653	IVAN TARASOV	{"phone": "+70297048241"}
0005432528830	AE77CE	9733 930626	IVAN ALEKSANDROV	{"email": "ivan.aleksandrov-1992@postgrespro.ru", "phone": "+70301514174"}
0005432528831	2F342D	3818 480893	ELIZAVETA KOVALEVA	{"email": "elizaveta_kovaleva_06081966@postgrespro.ru", "phone": "+70948304781"}
0005432528832	B82618	9641 685752	DMITRIY PAVLOV	{"phone": "+70719091317"}
0005432528833	38C311	3139 921943	VLADIMIR SAVELEV	{"email": "savelev-v-1959@postgrespro.ru", "phone": "+70781480576"}
0005432528834	FF241C	1076 374959	LYUBOV BORISOVA	{"phone": "+70740815919"}
0005432528835	FF241C	9667 186464	SERGEY KOZLOV	{"email": "kozlovsergey_1969@postgrespro.ru", "phone": "+70433838465"}
0005432528836	B0BEE8	3375 220701	VLADIMIR NIKOLAEV	{"email": "vladimir-nikolaev-031972@postgrespro.ru", "phone": "+70091882756"}
0005432528837	A6955D	3390 164718	ELENA KUZNECOVA	{"email": "ekuznecova-091993@postgrespro.ru", "phone": "+70193443830"}
0005432528838	F01AF9	4271 810509	KONSTANTIN VOROBEV	{"email": "vorobev.k071971@postgrespro.ru", "phone": "+70472418746"}
0005432528839	F01AF9	1703 368775	EVGENIYA EGOROVA	{"email": "egorova_evgeniya_14101974@postgrespro.ru", "phone": "+70023850902"}
0005432528840	781F42	9763 810997	ANASTASIYA MOROZOVA	{"email": "morozova-a_121983@postgrespro.ru", "phone": "+70388797316"}
0005432528841	7D4E31	1985 299921	GALINA NIKOLAEVA	{"email": "nikolaeva_g_1975@postgrespro.ru", "phone": "+70126513049"}
0005432528842	BB633C	9421 710413	MARIYA ANTONOVA	{"phone": "+70922837623"}
0005432528843	BB633C	5305 647359	NADEZHDA KULIKOVA	{"email": "n_kulikova1970@postgrespro.ru", "phone": "+70992457347"}
0005432528844	F8D9EA	3527 991946	LILIYA EGOROVA	{"email": "egorova_l_17051970@postgrespro.ru", "phone": "+70878390296"}
0005432528845	909AF2	2820 656866	ALEKSANDR SOLOVEV	{"email": "solovev-a1974@postgrespro.ru", "phone": "+70129140669"}
0005432528846	EA953F	7014 530919	TATYANA PAVLOVA	{"phone": "+70178139929"}
0005432528847	15CCE0	7890 076741	SERGEY FOMIN	{"phone": "+70353939197"}
0005432528848	4399CB	3472 016291	MARGARITA PAVLOVA	{"email": "margarita_pavlova-091979@postgrespro.ru", "phone": "+70788338092"}
0005432528849	4399CB	1144 086211	TIMUR ANDREEV	{"phone": "+70361879629"}
0005432528850	25D292	0212 577370	VLADIMIR POPOV	{"email": "v_popov_13081974@postgrespro.ru", "phone": "+70719701574"}
0005432528851	91200C	5041 533500	IGOR NAZAROV	{"email": "inazarov1964@postgrespro.ru", "phone": "+70808797369"}
0005432528852	164A12	8770 970710	TAMARA PETROVA	{"email": "petrova-tamara.111978@postgrespro.ru", "phone": "+70949980446"}
0005432528853	5D1F20	1912 485807	ALEKSEY KULIKOV	{"phone": "+70985060531"}
0005432528854	4D8F76	0711 670585	VLADIMIR POPOV	{"email": "popov-vladimir-111974@postgrespro.ru", "phone": "+70635287087"}
0005432528855	9810F5	6738 198056	SERGEY IVANOV	{"phone": "+70883814114"}
0005432528856	9810F5	5853 935228	GENNADIY ZAKHAROV	{"phone": "+70029069231"}
0005432528857	D15D15	8393 423236	ELENA IVANOVA	{"email": "elena_ivanova14101966@postgrespro.ru", "phone": "+70837308027"}
0005432528858	7DA061	7008 283090	GALINA MATVEEVA	{"phone": "+70438238079"}
0005432528859	7DA061	2514 704271	VALENTIN GAVRILOV	{"email": "valentingavrilov04011968@postgrespro.ru", "phone": "+70492232460"}
0005432528860	7DA061	7443 560769	ALEKSANDR FROLOV	{"email": "a-frolov-091972@postgrespro.ru", "phone": "+70489576412"}
0005432528861	8A119E	6129 084589	IVAN TARASOV	{"phone": "+70839106878"}
0005432528862	658517	7994 911329	GALINA GUSEVA	{"email": "galinaguseva.111984@postgrespro.ru", "phone": "+70116281494"}
0005432528863	C7E3E7	2679 822784	DMITRIY IVANOV	{"email": "dmitriy_ivanov.091970@postgrespro.ru", "phone": "+70230688963"}
0005432528864	C7E3E7	2954 255803	ZINAIDA STEPANOVA	{"email": "stepanova_z.06021983@postgrespro.ru", "phone": "+70452766049"}
0005432528865	C7E3E7	5646 816091	VERONIKA MOROZOVA	{"email": "morozova.veronika-1965@postgrespro.ru", "phone": "+70323468028"}
0005432528866	C7E3E7	1788 420226	IRINA ZHUKOVA	{"phone": "+70738572835"}
0005432528867	01D044	4514 245475	IGOR DAVYDOV	{"email": "i.davydov1977@postgrespro.ru", "phone": "+70505820415"}
0005432528868	4E690E	2308 623061	RITA MELNIKOVA	{"email": "melnikova-r011971@postgrespro.ru", "phone": "+70354919807"}
0005432528869	8CF267	2798 280234	VYACHESLAV TIMOFEEV	{"phone": "+70367513370"}
0005432528870	DD0FC9	1165 812666	LILIYA KUZNECOVA	{"phone": "+70421123927"}
0005432528871	10F34D	5929 490440	ALEKSANDR EGOROV	{"phone": "+70849970668"}
0005432528872	10F34D	4690 376178	OLGA KUZMINA	{"email": "kuzmina_olga-101971@postgrespro.ru", "phone": "+70092156194"}
0005432528873	4F43B6	7812 443302	ANDREY FEDOROV	{"phone": "+70822450788"}
0005432528874	9D928A	1956 744384	ZINAIDA VOLKOVA	{"phone": "+70682232626"}
0005432528875	653120	7719 269818	NATALYA KULIKOVA	{"email": "kulikova_n_1982@postgrespro.ru", "phone": "+70682832360"}
0005432528876	653120	2775 996981	VYACHESLAV ZAYCEV	{"phone": "+70924985365"}
0005432528877	A0CD62	3455 967477	OLEG SCHERBAKOV	{"email": "scherbakov_oleg.1970@postgrespro.ru", "phone": "+70190183223"}
0005432528878	914DE6	4763 937419	PAVEL FEDOROV	{"phone": "+70238138196"}
0005432528879	2CE8C8	7407 206288	SHAMIL OSIPOV	{"phone": "+70148215886"}
0005432528880	8F87EE	3556 936651	EVGENIY KRASNOV	{"email": "krasnov.evgeniy.1975@postgrespro.ru", "phone": "+70012508137"}
0005432528881	D7404C	2173 740491	TATYANA MARTYNOVA	{"phone": "+70338419506"}
0005432528882	D7404C	5653 591741	VALENTINA LOGINOVA	{"email": "loginova_v1968@postgrespro.ru", "phone": "+70283751070"}
0005432528883	D7404C	0314 815353	ELENA RYABOVA	{"phone": "+70629711834"}
0005432528884	D7404C	1276 768180	OLGA OVCHINNIKOVA	{"phone": "+70520515134"}
0005432528885	9D53D8	5947 879474	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_valentina-1967@postgrespro.ru", "phone": "+70555498712"}
0005432528886	9D53D8	7100 011684	OLEG SMIRNOV	{"email": "o.smirnov-1972@postgrespro.ru", "phone": "+70962040238"}
0005432528887	3B8130	5172 671396	TAGIR FROLOV	{"email": "frolov.t1977@postgrespro.ru", "phone": "+70366055133"}
0005432528888	3B8130	6045 816204	ANDREY MIKHAYLOV	{"phone": "+70752782858"}
0005432528889	88ABF0	2193 431669	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr.1963@postgrespro.ru", "phone": "+70825603108"}
0005432528890	F0D544	1537 145829	ALEKSEY NOVIKOV	{"phone": "+70329902118"}
0005432528891	D61FE9	8407 924366	VALENTINA POPOVA	{"phone": "+70065652723"}
0005432528892	D61FE9	8441 299639	YURIY TIMOFEEV	{"phone": "+70048378996"}
0005432528893	E328BF	1454 825461	NADEZHDA TIMOFEEVA	{"email": "timofeevanadezhda.1969@postgrespro.ru", "phone": "+70677783371"}
0005432528894	E328BF	6999 477780	LYUBOV SERGEEVA	{"email": "l_sergeeva-06081973@postgrespro.ru", "phone": "+70633836591"}
0005432528895	B6AB79	2519 154102	VASILIY GAVRILOV	{"phone": "+70933871718"}
0005432528896	B6AB79	9899 182010	ALEKSANDR STEPANOV	{"email": "stepanova1981@postgrespro.ru", "phone": "+70520925827"}
0005432528897	173EFA	5764 666206	GALINA RODIONOVA	{"email": "galinarodionova04051968@postgrespro.ru", "phone": "+70920592370"}
0005432528898	1E21C8	2746 825490	IRINA NESTEROVA	{"phone": "+70831985642"}
0005432528899	243C3B	6925 751349	KONSTANTIN KARPOV	{"phone": "+70504686107"}
0005432528900	869ABE	2345 422277	ANGELINA TIMOFEEVA	{"email": "timofeeva-a_081982@postgrespro.ru", "phone": "+70667850222"}
0005432528901	869ABE	1663 277695	MARTA KUZNECOVA	{"email": "kuznecova_m-27061968@postgrespro.ru", "phone": "+70472669705"}
0005432528902	AB356A	5421 248180	OLEG SEMENOV	{"email": "o-semenov-1967@postgrespro.ru", "phone": "+70019911906"}
0005432528903	F706E2	6183 457730	VALENTINA KOROLEVA	{"email": "v_koroleva1971@postgrespro.ru", "phone": "+70292380902"}
0005432528904	8A2720	4996 607812	SVETLANA TARASOVA	{"email": "svetlana-tarasova121975@postgrespro.ru", "phone": "+70066982000"}
0005432528905	8A2720	1718 941398	MARINA KUZMINA	{"email": "kuzminamarina_1969@postgrespro.ru", "phone": "+70429453740"}
0005432528906	2ED1C1	9852 381422	MIKHAIL KARPOV	{"email": "karpov-m-1987@postgrespro.ru", "phone": "+70473916942"}
0005432528907	2ED1C1	2091 181014	MARINA NAUMOVA	{"email": "naumovamarina081972@postgrespro.ru", "phone": "+70118218178"}
0005432528908	D075A9	0164 095227	MAKSIM MAKAROV	{"email": "m_makarov021960@postgrespro.ru", "phone": "+70733594889"}
0005432528909	12C0DB	4897 872443	PETR BORISOV	{"email": "borisov.p.1970@postgrespro.ru", "phone": "+70662664171"}
0005432528910	67CEDA	2827 904724	OLGA POPOVA	{"email": "olga-popova1981@postgrespro.ru", "phone": "+70885773217"}
0005432528911	106E4A	6184 872656	MIKHAIL KAZAKOV	{"phone": "+70380974630"}
0005432528912	80904C	9408 708296	ZINAIDA RYABOVA	{"phone": "+70130897869"}
0005432528913	80904C	6090 489499	MARINA ROMANOVA	{"email": "marina-romanova_23031971@postgrespro.ru", "phone": "+70287162062"}
0005432528914	3D1F4C	9381 086266	NIKOLAY POPOV	{"phone": "+70792658502"}
0005432528915	A7FCF9	3063 895327	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_07031969@postgrespro.ru", "phone": "+70897771111"}
0005432528916	A7FCF9	4397 810769	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr_111964@postgrespro.ru", "phone": "+70904992699"}
0005432528917	6AB477	4500 566571	VIKTOR NOVIKOV	{"email": "novikov_viktor.021979@postgrespro.ru", "phone": "+70448275152"}
0005432528918	CCFF63	2898 952539	SERGEY EGOROV	{"email": "egorovs.051983@postgrespro.ru", "phone": "+70517752029"}
0005432528919	21FB57	9044 460946	VALENTINA EFIMOVA	{"phone": "+70011940489"}
0005432528920	183666	2144 574753	ZINAIDA KULIKOVA	{"email": "z-kulikova29051971@postgrespro.ru", "phone": "+70822451788"}
0005432528921	D9CB9B	3743 422124	DMITRIY MELNIKOV	{"email": "melnikovdmitriy_17021973@postgrespro.ru", "phone": "+70968292808"}
0005432528922	D9CB9B	5247 426855	ALENA FEDOROVA	{"email": "a-fedorova-10071973@postgrespro.ru", "phone": "+70132422595"}
0005432528923	D9CB9B	4817 323829	ELIZAVETA KONOVALOVA	{"phone": "+70807636416"}
0005432528924	CD51AB	4954 492068	ALEKSANDRA KOROLEVA	{"email": "aleksandrakoroleva.101970@postgrespro.ru", "phone": "+70248911801"}
0005432528925	458626	9030 041411	TATYANA PETROVA	{"email": "petrova.t_1970@postgrespro.ru", "phone": "+70652942220"}
0005432528926	458626	6624 269025	OLGA VOLKOVA	{"phone": "+70770917545"}
0005432528927	73DDB5	7837 343223	EKATERINA KAZAKOVA	{"email": "kazakova.e-08061979@postgrespro.ru", "phone": "+70117397695"}
0005432528928	73DDB5	1403 473411	NIKOLAY FROLOV	{"phone": "+70064301347"}
0005432528929	E5B018	7073 305930	LYUDMILA YAKOVLEVA	{"email": "yakovleva_l06071970@postgrespro.ru", "phone": "+70946525839"}
0005432528930	F49C85	6999 675230	NATALYA TITOVA	{"email": "titova_natalya-1974@postgrespro.ru", "phone": "+70046900533"}
0005432528931	F49C85	0195 105831	TATYANA KUZMINA	{"email": "kuzmina_tatyana-19041980@postgrespro.ru", "phone": "+70956970595"}
0005432528932	F49C85	4525 859919	EKATERINA ANDREEVA	{"email": "andreeva-ekaterina1967@postgrespro.ru", "phone": "+70165461036"}
0005432528933	5278F2	5931 891229	EVDOKIYA PETROVA	{"phone": "+70870196795"}
0005432528934	5278F2	4933 844888	POLINA BELOVA	{"email": "belovap26061970@postgrespro.ru", "phone": "+70704667129"}
0005432528935	AF791A	6014 149681	DARYA BELOVA	{"email": "belova.d-1962@postgrespro.ru", "phone": "+70254049307"}
0005432528936	F7EFF3	4158 736388	KIRA CHERNOVA	{"phone": "+70765225969"}
0005432528937	491DDE	7556 748590	TAMARA IVANOVA	{"phone": "+70401403783"}
0005432528938	DB1EBE	8946 236629	ALEKSANDR MEDVEDEV	{"phone": "+70065138867"}
0005432528939	DB1EBE	8606 064829	ALEKSEY ZHURAVLEV	{"email": "zhuravlevaleksey01061972@postgrespro.ru", "phone": "+70281169033"}
0005432528940	1C4996	0342 855863	MAKSIM SHEVCHENKO	{"email": "shevchenkom.021962@postgrespro.ru", "phone": "+70701430997"}
0005432528941	D7E17F	7565 142888	TATYANA MIKHAYLOVA	{"phone": "+70282330541"}
0005432528942	3862E4	1976 504954	RUSLAN TIKHONOV	{"phone": "+70800811992"}
0005432528943	3862E4	8154 235628	VALERIY SCHERBAKOV	{"email": "v-scherbakov-25051981@postgrespro.ru", "phone": "+70789214933"}
0005432528944	66A529	4546 746073	MARAT GERASIMOV	{"email": "m.gerasimov011971@postgrespro.ru", "phone": "+70893592377"}
0005432528945	BFE5AE	6337 143355	LYUDMILA KUZMINA	{"email": "lyudmila_kuzmina-1979@postgrespro.ru", "phone": "+70323524105"}
0005432528946	BFE5AE	7652 252869	ALEKSANDR OSIPOV	{"phone": "+70798668874"}
0005432528947	F41248	3937 479237	NATALYA RYABOVA	{"email": "nryabova-10111969@postgrespro.ru", "phone": "+70217901274"}
0005432528948	8960CF	4773 847151	VYACHESLAV VLASOV	{"email": "vlasovv.111973@postgrespro.ru", "phone": "+70256746723"}
0005432528949	79DFF7	4809 402006	PAVEL KUZMIN	{"email": "pkuzmin-1972@postgrespro.ru", "phone": "+70005033171"}
0005432528950	F6B63E	5501 462590	EKATERINA BORISOVA	{"email": "ekaterina.borisova-071974@postgrespro.ru", "phone": "+70819652214"}
0005432528951	F0B1CB	4572 872798	VERONIKA RYABOVA	{"email": "ryabova-veronika24021971@postgrespro.ru", "phone": "+70895599937"}
0005432528952	C90F5D	0177 108413	ALEKSANDR SCHERBAKOV	{"phone": "+70557408124"}
0005432528953	C90F5D	4447 664800	LYUBOV KULIKOVA	{"email": "kulikova-l051980@postgrespro.ru", "phone": "+70277520202"}
0005432528954	6DED26	7005 348491	VALENTINA KUDRYASHOVA	{"email": "kudryashova.v-1969@postgrespro.ru", "phone": "+70495088106"}
0005432528955	6DED26	7531 161479	LYUDMILA TROFIMOVA	{"email": "trofimova_l-1971@postgrespro.ru", "phone": "+70718324474"}
0005432528956	C91690	9995 377589	ANDREY SOKOLOV	{"phone": "+70670636576"}
0005432528957	C91690	5387 653255	MARIYA PETROVA	{"email": "petrova_mariya021985@postgrespro.ru", "phone": "+70339813235"}
0005432528958	641BC6	6151 352988	ELENA PAVLOVA	{"phone": "+70813980147"}
0005432528959	C546B7	0974 123315	EVGENIY SEMENOV	{"phone": "+70144398149"}
0005432528960	C546B7	8451 811030	NATALYA SERGEEVA	{"phone": "+70896887398"}
0005432528961	C08A25	2097 367456	ROZALIYA NESTEROVA	{"email": "nesterova.rozaliya-27031967@postgrespro.ru", "phone": "+70260398908"}
0005432528962	C08A25	3860 856670	ANASTASIYA ZHUKOVA	{"email": "a_zhukova011982@postgrespro.ru", "phone": "+70829227797"}
0005432528963	C08A25	7500 037479	ALEKSANDR TARASOV	{"phone": "+70581571901"}
0005432528964	EAEF52	8533 008677	SVETLANA ILINA	{"phone": "+70748711523"}
0005432528965	EAEF52	3163 867603	VIKTOR DENISOV	{"phone": "+70309334664"}
0005432529135	AA3365	2158 691965	DANIL ZAKHAROV	{"phone": "+70956471638"}
0005432528966	97482D	8055 057394	VLADIMIR MEDVEDEV	{"email": "vladimir-medvedev_111981@postgrespro.ru", "phone": "+70035533900"}
0005432528967	653778	9419 579797	ELENA FEDOROVA	{"email": "elena-fedorova081975@postgrespro.ru", "phone": "+70643616646"}
0005432528968	653778	3274 852929	ALEKSANDR KOZLOV	{"email": "a.kozlov28051957@postgrespro.ru", "phone": "+70049718848"}
0005432528969	1FEFCA	2575 137009	NINA NIKITINA	{"email": "nina_nikitina_041966@postgrespro.ru", "phone": "+70453929482"}
0005432528970	A1B696	0275 551972	MIKHAIL MATVEEV	{"phone": "+70527830132"}
0005432528971	A1B696	0146 793073	VADIM IVANOV	{"phone": "+70699408332"}
0005432528972	F0790C	0607 636744	ALEKSANDR TARASOV	{"phone": "+70986849656"}
0005432528973	F0790C	5567 245068	LARISA VOLKOVA	{"email": "volkoval-081959@postgrespro.ru", "phone": "+70217471707"}
0005432528974	9A1038	7172 874810	ANATOLIY MELNIKOV	{"phone": "+70080770668"}
0005432528975	9A1038	0651 590688	GALINA ZAKHAROVA	{"phone": "+70816705705"}
0005432528976	CD79F9	5728 522780	OLESYA SOROKINA	{"phone": "+70764982586"}
0005432528977	5055A3	1856 357060	SVETLANA MATVEEVA	{"phone": "+70334273540"}
0005432528978	5055A3	3672 606284	EVGENIY KUZMIN	{"phone": "+70543636172"}
0005432528979	D87EF9	6767 896544	ALEKSEY MEDVEDEV	{"phone": "+70022711200"}
0005432528980	D87EF9	8366 187196	VIKTORIYA DAVYDOVA	{"email": "davydova-v-10121970@postgrespro.ru", "phone": "+70653942546"}
0005432528981	B55D41	6134 983752	LIDIYA KARPOVA	{"phone": "+70454082705"}
0005432528982	D63084	0580 119973	NADEZHDA PETROVA	{"email": "nadezhdapetrova-26021987@postgrespro.ru", "phone": "+70893419628"}
0005432528983	08F4DD	8520 312678	VALERIY PETROV	{"email": "petrov-v05121981@postgrespro.ru", "phone": "+70277277386"}
0005432528984	08F4DD	9404 794672	NIKOLAY ZAKHAROV	{"email": "zakharov.n021965@postgrespro.ru", "phone": "+70247287929"}
0005432528985	DE9B3C	1134 263796	VLADIMIR EGOROV	{"email": "v-egorov021974@postgrespro.ru", "phone": "+70226552518"}
0005432528986	AB7980	7918 943141	NATALYA ARKHIPOVA	{"email": "n_arkhipova1984@postgrespro.ru", "phone": "+70000268697"}
0005432528987	AB7980	6822 810652	IRINA KAZAKOVA	{"phone": "+70077694267"}
0005432528988	A8B0E0	8965 734734	GALINA POTAPOVA	{"email": "potapova-galina-101972@postgrespro.ru", "phone": "+70678263830"}
0005432528989	A8B0E0	2725 600760	ALEKSANDR FEDOROV	{"phone": "+70183270522"}
0005432528990	CAF2C4	3158 563268	SVETLANA STEPANOVA	{"email": "stepanova-s041974@postgrespro.ru", "phone": "+70449707034"}
0005432528991	CB234B	9342 427441	EKATERINA BOGDANOVA	{"email": "bogdanova.e-1984@postgrespro.ru", "phone": "+70437724456"}
0005432528992	5C7C78	5272 481148	GALINA SIDOROVA	{"email": "gsidorova_091974@postgrespro.ru", "phone": "+70160744336"}
0005432528993	5C7C78	0803 391206	MIKHAIL MELNIKOV	{"email": "melnikov-m.25071977@postgrespro.ru", "phone": "+70389963765"}
0005432528994	3D1365	0541 234725	NATALYA KRASNOVA	{"email": "n-krasnova12051970@postgrespro.ru", "phone": "+70139386111"}
0005432528995	60E488	9405 918750	MARIYA KUZNECOVA	{"phone": "+70839745087"}
0005432528996	1EBEAB	9435 090328	NADEZHDA IVANOVA	{"phone": "+70596869151"}
0005432528997	577131	1777 815943	NADEZHDA DMITRIEVA	{"email": "dmitrieva-n_101966@postgrespro.ru", "phone": "+70870773633"}
0005432528998	49347C	8367 783736	NADEZHDA NOVIKOVA	{"phone": "+70612083158"}
0005432528999	93F6EC	6924 190778	NATALYA DMITRIEVA	{"phone": "+70791483987"}
0005432529000	93F6EC	5776 282132	OLEG PETROV	{"email": "petrov.oleg.091974@postgrespro.ru", "phone": "+70718347229"}
0005432529001	05BBA7	8839 440110	ELENA TARASOVA	{"phone": "+70097077311"}
0005432529002	05BBA7	4979 861271	ARSENIY YAKOVLEV	{"email": "yakovleva.081975@postgrespro.ru", "phone": "+70201959524"}
0005432529003	735DC9	6510 335446	YURIY KUZNECOV	{"phone": "+70885213712"}
0005432529004	735DC9	1115 218350	NAILYA VASILEVA	{"phone": "+70583931844"}
0005432529005	5F2BEA	8668 521913	LEV GORBUNOV	{"email": "lev.gorbunov.1966@postgrespro.ru", "phone": "+70154213034"}
0005432529006	344B8F	0408 096812	VLADIMIR NIKITIN	{"phone": "+70999379705"}
0005432529007	EDB0E2	6032 615395	SERGEY SERGEEV	{"email": "sergeev.sergey_1972@postgrespro.ru", "phone": "+70324403638"}
0005432529008	23A222	5134 468561	VLADIMIR ANDREEV	{"phone": "+70863738365"}
0005432529009	23A222	4531 049390	NADEZHDA GORBUNOVA	{"phone": "+70148092334"}
0005432529010	5D0216	4756 779793	GALINA IVANOVA	{"email": "galina-ivanova-061969@postgrespro.ru", "phone": "+70656473173"}
0005432529011	5D0216	1199 471889	ALEKSANDR NIKITIN	{"email": "a_nikitin.021981@postgrespro.ru", "phone": "+70013654832"}
0005432529012	F337E9	2882 514663	TAMARA MIKHAYLOVA	{"phone": "+70039459050"}
0005432529013	F93DAE	6228 134801	KAMILA DAVYDOVA	{"phone": "+70484089080"}
0005432529014	C90BAD	2353 096123	MAKSIM FEDOROV	{"email": "fedorovm_021970@postgrespro.ru", "phone": "+70488988273"}
0005432529015	C90BAD	1967 184536	PAVEL FOMIN	{"email": "fomin.p-1972@postgrespro.ru", "phone": "+70704989116"}
0005432529016	A28622	2008 190414	ELENA ZOTOVA	{"phone": "+70291204307"}
0005432529017	A28622	5073 460699	KIRILL BORISOV	{"email": "borisov-kirill.061963@postgrespro.ru", "phone": "+70956924643"}
0005432529018	4B6FB0	7367 148747	RAISA PAVLOVA	{"email": "pavlovaraisa.11051970@postgrespro.ru", "phone": "+70045912495"}
0005432529019	4B6FB0	0462 435669	ALEKSEY TIKHONOV	{"email": "alekseytikhonov.17061980@postgrespro.ru", "phone": "+70276773452"}
0005432529020	E1B4AA	6422 406330	ALEKSEY KOZLOV	{"phone": "+70056133362"}
0005432529021	E1B4AA	9927 062282	VALERIY GORBUNOV	{"phone": "+70711851944"}
0005432529022	E1B4AA	4843 617499	SERGEY MOISEEV	{"email": "sergey-moiseev-08021980@postgrespro.ru", "phone": "+70674341769"}
0005432529023	341420	9998 654414	MARGARITA KUZMINA	{"phone": "+70786291043"}
0005432529024	341420	7745 584307	IRINA KUZNECOVA	{"phone": "+70535376222"}
0005432529025	7B3663	6731 071602	SERGEY ANTONOV	{"email": "antonov_s25121971@postgrespro.ru", "phone": "+70585187548"}
0005432529026	BB1D0B	9412 094039	PAVEL OSIPOV	{"phone": "+70552319208"}
0005432529027	5F756D	7274 573542	MARIYA LUKYANOVA	{"email": "lukyanova_m-08121975@postgrespro.ru", "phone": "+70050111695"}
0005432529028	5F756D	5087 997836	DIANA BELOVA	{"email": "d_belova_031970@postgrespro.ru", "phone": "+70080770123"}
0005432529029	106AC3	9853 824415	SERGEY IVANOV	{"email": "ivanov_sergey_25021967@postgrespro.ru", "phone": "+70098641532"}
0005432529030	C08D2F	8745 557212	ILDAR EGOROV	{"phone": "+70040916551"}
0005432529031	9DC269	7045 248735	SERGEY ILIN	{"phone": "+70294121767"}
0005432529032	4B32E2	7935 517626	IRINA BOGDANOVA	{"phone": "+70523338321"}
0005432529033	D21CA4	2543 062433	ELENA KOLESNIKOVA	{"phone": "+70189492925"}
0005432529034	D9C7A7	5229 005954	ALEKSANDR ZHUKOV	{"email": "a-zhukov.28011973@postgrespro.ru", "phone": "+70302796595"}
0005432529035	38BB8B	0290 747023	SERGEY MAKAROV	{"email": "makarovsergey_1970@postgrespro.ru", "phone": "+70352232552"}
0005432529036	38BB8B	0573 923839	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila101978@postgrespro.ru", "phone": "+70408580779"}
0005432529037	38BB8B	5650 752468	ANDREY TIKHONOV	{"email": "a-tikhonov_031979@postgrespro.ru", "phone": "+70729369540"}
0005432529038	201746	7573 015641	ELENA PETROVA	{"email": "elena.petrova-18121962@postgrespro.ru", "phone": "+70953071358"}
0005432529039	201746	5848 472209	DENIS STEPANOV	{"phone": "+70909733941"}
0005432529040	DFDA49	2665 241241	SERGEY KUZNECOV	{"phone": "+70065038450"}
0005432529041	682E09	8165 847542	ALEKSANDR KISELEV	{"phone": "+70945444538"}
0005432529042	682E09	4688 014897	MIKHAIL SOKOLOV	{"phone": "+70433502111"}
0005432529043	45C452	6752 174457	SERGEY ISAEV	{"email": "sisaev1962@postgrespro.ru", "phone": "+70909255167"}
0005432529044	45C452	7188 339191	VIKTOR GUSEV	{"email": "gusev.v.28081972@postgrespro.ru", "phone": "+70843045586"}
0005432529045	6DD6F7	9577 959859	NIKITA KOZLOV	{"email": "n-kozlov-03121966@postgrespro.ru", "phone": "+70798798239"}
0005432529046	826654	2997 930736	ANDREY IVANOV	{"email": "ivanov_andrey.1969@postgrespro.ru", "phone": "+70193002945"}
0005432529047	96003C	7310 763063	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr.1973@postgrespro.ru", "phone": "+70798772499"}
0005432529048	E372E7	1241 521493	VADIM SAVELEV	{"email": "vsavelev_101972@postgrespro.ru", "phone": "+70154264971"}
0005432529049	E372E7	9969 890739	ANATOLIY GRIGOREV	{"email": "grigorev_a-1962@postgrespro.ru", "phone": "+70711252607"}
0005432529050	E81F19	2963 047941	VASILIY MAKAROV	{"email": "v.makarov071976@postgrespro.ru", "phone": "+70924215768"}
0005432529051	135D0B	0887 800410	ELMIRA LAZAREVA	{"email": "elmira-lazareva1975@postgrespro.ru", "phone": "+70610371032"}
0005432529052	ECCE4B	1512 999523	VLADIMIR RODIONOV	{"email": "rodionov.vladimir091980@postgrespro.ru", "phone": "+70050513466"}
0005432529053	ECCE4B	3670 822153	ALISA MELNIKOVA	{"email": "amelnikova-1977@postgrespro.ru", "phone": "+70251384783"}
0005432529054	8ABA3E	3710 537455	ANDREY DAVYDOV	{"email": "andrey-davydov-1973@postgrespro.ru", "phone": "+70657376159"}
0005432529055	1427F5	5051 233513	ANNA KISELEVA	{"email": "a.kiseleva-071979@postgrespro.ru", "phone": "+70867725635"}
0005432529056	7725DF	4705 285943	BULAT ANDREEV	{"phone": "+70916673603"}
0005432529057	FAD4C5	1642 750725	MARINA ZAKHAROVA	{"email": "marinazakharova_23041964@postgrespro.ru", "phone": "+70456217803"}
0005432529058	C43790	2057 170845	RIMMA MASLOVA	{"phone": "+70624709609"}
0005432529059	BC6164	7536 454921	ANASTASIYA KISELEVA	{"email": "a_kiseleva_081975@postgrespro.ru", "phone": "+70356209329"}
0005432529060	24A3DD	7280 523403	GALINA ABRAMOVA	{"phone": "+70121204003"}
0005432529061	A86CE6	4074 287617	ALEKSANDR ILIN	{"email": "a.ilin25051967@postgrespro.ru", "phone": "+70139317817"}
0005432529062	A86CE6	1949 933775	EKATERINA PETROVA	{"phone": "+70661854881"}
0005432529063	770F7A	7324 759899	DENIS ROMANOV	{"phone": "+70100426383"}
0005432529064	770F7A	1800 907228	OLGA ZHUKOVA	{"email": "zhukova.o_071975@postgrespro.ru", "phone": "+70779251893"}
0005432529065	A36C40	6735 826289	ANDREY SERGEEV	{"email": "sergeevandrey-24121977@postgrespro.ru", "phone": "+70781622866"}
0005432529066	76F241	2683 588546	IRINA SAVELEVA	{"phone": "+70404242993"}
0005432529067	00F31C	7382 667153	NATALYA BELYAEVA	{"email": "n-belyaeva1976@postgrespro.ru", "phone": "+70133080916"}
0005432529068	00F31C	2594 106736	ELENA MOROZOVA	{"email": "e.morozova_031975@postgrespro.ru", "phone": "+70963047111"}
0005432529069	5A495E	1615 181742	OLGA PAVLOVA	{"email": "olga-pavlova-1972@postgrespro.ru", "phone": "+70449878497"}
0005432529070	7A59E7	2462 884441	VIKTOR KUZNECOV	{"email": "v-kuznecov.1974@postgrespro.ru", "phone": "+70624906947"}
0005432529071	B18DCC	1299 440663	LYUDMILA LUKYANOVA	{"phone": "+70270113830"}
0005432529072	3C8479	6394 030100	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov1980@postgrespro.ru", "phone": "+70142736837"}
0005432529073	4514C5	9039 810076	TATYANA ALEKSEEVA	{"email": "alekseeva_tatyana01021963@postgrespro.ru", "phone": "+70382129938"}
0005432529074	8E0393	8335 500739	VADIM GAVRILOV	{"phone": "+70849211586"}
0005432529075	0DC369	4512 300904	SVETLANA MALYSHEVA	{"phone": "+70083008520"}
0005432529076	0DC369	8593 387812	LYUBOV VASILEVA	{"phone": "+70428803512"}
0005432529077	8C059A	2861 600434	OLEG MIRONOV	{"phone": "+70761871052"}
0005432529078	7023EA	2521 246142	ANDREY KUZNECOV	{"email": "a_kuznecov_24091974@postgrespro.ru", "phone": "+70796730557"}
0005432529079	7023EA	8435 413172	PETR BORISOV	{"email": "petr-borisov_15091983@postgrespro.ru", "phone": "+70129206513"}
0005432529080	10B3AC	8080 194809	TATYANA GERASIMOVA	{"phone": "+70134427403"}
0005432529081	2B3005	2286 569371	ANASTASIYA POPOVA	{"email": "a.popova_1970@postgrespro.ru", "phone": "+70800436954"}
0005432529082	2F5CD4	5742 673638	ANASTASIYA YAKOVLEVA	{"email": "a-yakovleva.1980@postgrespro.ru", "phone": "+70501552535"}
0005432529083	2F5CD4	3961 994336	ILDAR ZAKHAROV	{"phone": "+70792744312"}
0005432529084	40A1C9	2426 400609	ELIZAVETA STEPANOVA	{"phone": "+70723284957"}
0005432529085	40A1C9	3529 807002	NATALYA DANILOVA	{"email": "danilova.n_10051977@postgrespro.ru", "phone": "+70781493869"}
0005432529086	E34A9F	8697 542804	NATALYA FROLOVA	{"phone": "+70325578814"}
0005432529087	7708F8	8837 582570	NATALYA STEPANOVA	{"phone": "+70528982030"}
0005432529088	7708F8	8109 450039	MIKHAIL MATVEEV	{"phone": "+70758561928"}
0005432529089	0C7BD5	5079 952827	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana1976@postgrespro.ru", "phone": "+70082875628"}
0005432529090	0C7BD5	7806 716503	IRINA TIKHONOVA	{"email": "tikhonova_i.20051971@postgrespro.ru", "phone": "+70867588228"}
0005432529091	04BB76	9998 690901	RUSTEM MOISEEV	{"email": "moiseev_r1982@postgrespro.ru", "phone": "+70865188912"}
0005432529092	04BB76	5170 190980	VERA SEMENOVA	{"email": "semenovavera24071967@postgrespro.ru", "phone": "+70970754718"}
0005432529093	BF59A4	5364 250058	SERGEY VASILEV	{"phone": "+70498759858"}
0005432529094	7E02C9	4858 861588	ELENA MARTYNOVA	{"phone": "+70061048627"}
0005432529095	691B6F	2640 399341	MARIYA KOROLEVA	{"phone": "+70533969646"}
0005432529096	0DD3E4	9807 175923	ILYA RODIONOV	{"email": "rodionov-ilya-1975@postgrespro.ru", "phone": "+70636917171"}
0005432529097	5ADB44	7776 847289	ELENA KULIKOVA	{"phone": "+70574866488"}
0005432529098	5ADB44	8304 113886	PAVEL FROLOV	{"phone": "+70000812755"}
0005432529099	9BC0EF	9183 792528	YURIY DENISOV	{"phone": "+70407123031"}
0005432529100	1D31C0	7139 645068	OLGA VASILEVA	{"phone": "+70566324365"}
0005432529101	3D42F4	4919 638559	ELENA TIKHONOVA	{"email": "elena-tikhonova-021966@postgrespro.ru", "phone": "+70808850051"}
0005432529102	3F2767	1294 396837	ANDREY SERGEEV	{"phone": "+70764585142"}
0005432529103	3F2767	1551 028489	ELENA SAVELEVA	{"phone": "+70143085551"}
0005432529104	3F2767	6563 632210	TATYANA POLYAKOVA	{"phone": "+70125789918"}
0005432529105	C24AAF	1809 157094	ALEKSANDR KOZLOV	{"email": "kozlov_a.15071977@postgrespro.ru", "phone": "+70980996174"}
0005432529106	807733	6010 744958	SERGEY STEPANOV	{"phone": "+70628942948"}
0005432529107	A1102F	4705 315352	ANDREY SOROKIN	{"phone": "+70531095968"}
0005432529108	A1102F	5447 244315	NADEZHDA ZAKHAROVA	{"email": "zakharova-nadezhda.1961@postgrespro.ru", "phone": "+70672162834"}
0005432529109	4E3535	9211 122813	SOFYA EGOROVA	{"email": "segorova_121959@postgrespro.ru", "phone": "+70617383162"}
0005432529110	E2388A	1229 857460	NATALYA PETROVA	{"phone": "+70314530601"}
0005432529111	E2388A	9445 213616	DMITRIY MAKSIMOV	{"email": "dmaksimov101976@postgrespro.ru", "phone": "+70006697558"}
0005432529112	8437A9	4669 036882	DENIS KUDRYASHOV	{"phone": "+70577759551"}
0005432529113	5E81A1	4621 241767	EKATERINA MOISEEVA	{"phone": "+70709163758"}
0005432529114	5E81A1	2839 439821	SVETLANA FILIPPOVA	{"phone": "+70944757188"}
0005432529115	027D90	2850 750740	OLGA TARASOVA	{"phone": "+70284046950"}
0005432529116	027D90	5373 460413	SERGEY FEDOROV	{"phone": "+70995473493"}
0005432529117	8BDD13	8492 842463	DMITRIY SERGEEV	{"phone": "+70008763516"}
0005432529118	8BDD13	4799 352543	SERGEY KUZMIN	{"email": "s_kuzmin.1986@postgrespro.ru", "phone": "+70500081695"}
0005432529119	8BDD13	4917 993989	MIKHAIL BARANOV	{"phone": "+70216307932"}
0005432529120	474D11	2612 041832	ELENA VOLKOVA	{"email": "volkova_e19091974@postgrespro.ru", "phone": "+70689360969"}
0005432529121	3A4FE2	4184 564904	ANASTASIYA POPOVA	{"phone": "+70570336182"}
0005432529122	FE4E4A	5057 097599	YULIYA KAZAKOVA	{"email": "ykazakova1965@postgrespro.ru", "phone": "+70914355408"}
0005432529123	FE4E4A	8042 755341	ANDREY IVANOV	{"phone": "+70405464509"}
0005432529124	79C746	3780 686014	AZAT MAKAROV	{"email": "makarov-azat1978@postgrespro.ru", "phone": "+70584565695"}
0005432529125	79C746	2711 228596	MARIYA DMITRIEVA	{"phone": "+70471275719"}
0005432529126	1C0CD9	8021 777239	MARINA VOLKOVA	{"phone": "+70909961615"}
0005432529127	000917	0337 045121	VERONIKA NIKOLAEVA	{"phone": "+70741983382"}
0005432529128	A84470	8190 968322	DANIS MIKHAYLOV	{"phone": "+70892728176"}
0005432529129	A84470	3488 009581	OLGA KOROLEVA	{"phone": "+70207249235"}
0005432529130	28736F	5453 511490	NIKITA TIKHONOV	{"email": "tikhonov_nikita-091971@postgrespro.ru", "phone": "+70479475016"}
0005432529131	28736F	2295 438049	VALERIY FEDOTOV	{"email": "fedotov_v.1970@postgrespro.ru", "phone": "+70717325714"}
0005432529132	DA4C4D	1279 633204	ZINAIDA KULIKOVA	{"email": "zinaida.kulikova-26031962@postgrespro.ru", "phone": "+70581589515"}
0005432529133	DA4C4D	4677 849446	VALERIY ANDREEV	{"phone": "+70610946885"}
0005432529134	780F1F	4504 145971	LYUDMILA SOROKINA	{"email": "lyudmila_sorokina.111973@postgrespro.ru", "phone": "+70077828129"}
0005432529136	C90100	2728 801066	OLGA KUZMINA	{"phone": "+70203161875"}
0005432529137	91229B	0797 631649	ILDAR RODIONOV	{"email": "ildar_rodionov_02011971@postgrespro.ru", "phone": "+70261129219"}
0005432529138	E17318	0877 759030	ELENA POPOVA	{"phone": "+70641962388"}
0005432529139	E17318	1300 118298	VLADIMIR ZHURAVLEV	{"phone": "+70012751709"}
0005432529140	E17318	1550 579639	VALENTINA VASILEVA	{"email": "valentina_vasileva-1962@postgrespro.ru", "phone": "+70855683932"}
0005432529141	8D6576	2729 085940	LYUBOV BARANOVA	{"phone": "+70327154405"}
0005432529142	8D6576	4189 446218	EVGENIY AFANASEV	{"phone": "+70277710330"}
0005432529143	96D706	8323 434523	NINA VASILEVA	{"email": "n.vasileva111963@postgrespro.ru", "phone": "+70318408826"}
0005432529144	D10276	2958 020957	DAMIR SAVELEV	{"phone": "+70284412639"}
0005432529145	6AF602	0385 316284	ALEKSANDR ANDREEV	{"email": "a.andreev_061973@postgrespro.ru", "phone": "+70242303952"}
0005432529146	6AF602	0718 760738	ARTEM IVANOV	{"phone": "+70930180872"}
0005432529147	BE0963	3643 212287	ANDREY KARPOV	{"phone": "+70470777067"}
0005432529148	BE0963	8077 460731	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov1962@postgrespro.ru", "phone": "+70394450165"}
0005432529149	40CE6D	4276 925859	LUIZA KUZNECOVA	{"email": "kuznecova.luiza_121966@postgrespro.ru", "phone": "+70840865253"}
0005432529150	40CE6D	7292 678034	VALENTINA ZHUKOVA	{"phone": "+70555675502"}
0005432529151	89B7BC	8971 812736	GENNADIY NAZAROV	{"email": "nazarov_gennadiy_1969@postgrespro.ru", "phone": "+70521818870"}
0005432529152	89B7BC	8859 815945	PAVEL MARTYNOV	{"phone": "+70709926516"}
0005432529153	1EB218	0978 376745	ELENA YUDINA	{"email": "elena_yudina-1965@postgrespro.ru", "phone": "+70878899248"}
0005432529154	F70BB0	4931 488652	NATALYA CHERNOVA	{"phone": "+70965057928"}
0005432529155	CAA931	3815 863442	ANATOLIY NAUMOV	{"email": "a.naumov-1960@postgrespro.ru", "phone": "+70545505371"}
0005432529156	0B6356	7982 106704	SVETLANA TARASOVA	{"phone": "+70731975117"}
0005432529157	78E9DE	7556 062079	OLGA SIDOROVA	{"email": "sidorova-olga1976@postgrespro.ru", "phone": "+70273739158"}
0005432529158	D99366	1707 334869	VERONIKA ANISIMOVA	{"phone": "+70315069217"}
0005432529159	23C448	2417 857653	NINA BOGDANOVA	{"phone": "+70388459991"}
0005432529160	C5216C	7963 174187	LYUDMILA MARTYNOVA	{"email": "martynova.lyudmila.1970@postgrespro.ru", "phone": "+70853246775"}
0005432529161	B15E31	1905 152906	OLEG ZHURAVLEV	{"email": "o-zhuravlev.1969@postgrespro.ru", "phone": "+70730050046"}
0005432529162	ED9953	2845 511398	EGOR IVANOV	{"email": "ivanov.e.1967@postgrespro.ru", "phone": "+70719736663"}
0005432529163	860AEA	3038 353259	MARIYA ORLOVA	{"email": "mariya-orlova-1971@postgrespro.ru", "phone": "+70163351433"}
0005432529164	22EE68	2400 969750	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr.28021964@postgrespro.ru", "phone": "+70686602529"}
0005432529165	0B03F7	4847 116973	VITALIY MEDVEDEV	{"email": "medvedev-v.1977@postgrespro.ru", "phone": "+70813964082"}
0005432529166	483BE8	1670 196740	NADEZHDA LAZAREVA	{"phone": "+70026641477"}
0005432529167	483BE8	7675 971258	EVDOKIYA KUZNECOVA	{"email": "kuznecova.e_09021974@postgrespro.ru", "phone": "+70572159891"}
0005432529168	DF61E7	3788 683027	LEONID KUZNECOV	{"email": "kuznecov_leonid16081971@postgrespro.ru", "phone": "+70484564937"}
0005432529169	33570C	8940 908975	ZINAIDA NIKITINA	{"email": "nikitina_zinaida_061982@postgrespro.ru", "phone": "+70147393776"}
0005432529170	1291CA	4885 709386	MARIYA KALININA	{"email": "kalinina-mariya-13031981@postgrespro.ru", "phone": "+70330776607"}
0005432529171	C6FC71	5952 086412	KIRILL KUZMIN	{"email": "k.kuzmin17031982@postgrespro.ru", "phone": "+70370312507"}
0005432529172	97CFD0	3835 566652	SERGEY SMIRNOV	{"phone": "+70803554242"}
0005432529173	97CFD0	0799 082276	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr.091974@postgrespro.ru", "phone": "+70444422237"}
0005432529174	95D810	0612 927090	ALINA KUZMINA	{"email": "alina-kuzmina_1976@postgrespro.ru", "phone": "+70199659540"}
0005432529175	95D810	6801 092187	EKATERINA SOLOVEVA	{"email": "ekaterina.soloveva1979@postgrespro.ru", "phone": "+70019336952"}
0005432529176	9CC7C8	2068 036739	SVETLANA MEDVEDEVA	{"phone": "+70207486660"}
0005432529177	636A53	2266 095480	ARTEM ANDREEV	{"email": "andreev.artem_09021975@postgrespro.ru", "phone": "+70857167176"}
0005432529178	97B6B9	7497 249980	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov1972@postgrespro.ru", "phone": "+70018689600"}
0005432529179	8A06E4	1323 681048	ANATOLIY ANTONOV	{"email": "a.antonov.1969@postgrespro.ru", "phone": "+70452495467"}
0005432529180	DF3E2E	1302 086487	SEMEN KONOVALOV	{"phone": "+70330729320"}
0005432529181	A40890	5282 983058	ALEKSANDR KAZAKOV	{"phone": "+70267808109"}
0005432529182	A40890	6203 977549	NATALYA KUZNECOVA	{"phone": "+70958879620"}
0005432529183	63D5B7	0607 184689	VLADISLAV DAVYDOV	{"email": "v.davydov_091971@postgrespro.ru", "phone": "+70065004188"}
0005432529184	63D5B7	1957 023195	TATYANA GORBUNOVA	{"phone": "+70080837363"}
0005432529185	63D5B7	4094 243791	NIKOLAY GRIGOREV	{"phone": "+70866489668"}
0005432529186	7D30D7	1903 504427	ROMAN KAZAKOV	{"email": "kazakov_r-1967@postgrespro.ru", "phone": "+70437317180"}
0005432529187	1F9E7D	0314 891662	MAKSIM POPOV	{"email": "maksim_popov-1978@postgrespro.ru", "phone": "+70263731893"}
0005432529188	291260	2527 760847	NIKOLAY NIKOLAEV	{"phone": "+70508570380"}
0005432529189	BBEEFC	4341 144760	NIKOLAY OSIPOV	{"email": "osipovnikolay.16071969@postgrespro.ru", "phone": "+70250190471"}
0005432529245	017AB2	4196 174860	MARIANNA GRISHINA	{"phone": "+70534441195"}
0005432529414	24663A	9698 260487	ALFIYA IVANOVA	{"phone": "+70244178619"}
0005432529190	BBEEFC	2240 744825	NINA FROLOVA	{"email": "n-frolova_1971@postgrespro.ru", "phone": "+70882116299"}
0005432529191	39BC63	9291 811785	ANDREY POPOV	{"email": "apopov11121971@postgrespro.ru", "phone": "+70378362769"}
0005432529192	A6134C	6521 029548	LYUDMILA PETROVA	{"phone": "+70567793239"}
0005432529193	D4250F	4390 909002	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_1965@postgrespro.ru", "phone": "+70999017106"}
0005432529194	8836FC	9616 805936	YURIY KUZNECOV	{"phone": "+70453126772"}
0005432529195	8836FC	8984 516715	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova1969@postgrespro.ru", "phone": "+70661461380"}
0005432529196	3511ED	2511 573225	SVETLANA VOLKOVA	{"email": "svetlana-volkova091982@postgrespro.ru", "phone": "+70632805606"}
0005432529197	911EC5	6366 795307	IGOR SOKOLOV	{"email": "sokolov_i_051971@postgrespro.ru", "phone": "+70899715190"}
0005432529198	F4248F	7268 867753	ANTON NAZAROV	{"phone": "+70617938314"}
0005432529199	9BC691	9423 231134	ALEKSANDR MAKAROV	{"phone": "+70309086535"}
0005432529200	AEAEDE	5187 123136	ALBINA POPOVA	{"email": "popovaalbina101975@postgrespro.ru", "phone": "+70678511020"}
0005432529201	AEAEDE	9552 023876	ANDREY ZAYCEV	{"email": "andrey.zaycev_121970@postgrespro.ru", "phone": "+70120477290"}
0005432529202	38557E	1675 800977	GALINA LOGINOVA	{"phone": "+70111310211"}
0005432529203	8F95A0	6646 543549	ELENA OVCHINNIKOVA	{"email": "ovchinnikova-e.05101977@postgrespro.ru", "phone": "+70016816970"}
0005432529204	8F95A0	2534 534834	SVETLANA MAKAROVA	{"email": "makarova-svetlana_071974@postgrespro.ru", "phone": "+70274071732"}
0005432529205	12685A	4026 843283	VALENTINA PAVLOVA	{"phone": "+70034069815"}
0005432529206	12685A	5685 953459	ANDREY MAKSIMOV	{"email": "a.maksimov-1973@postgrespro.ru", "phone": "+70544799977"}
0005432529207	12685A	6104 296805	ALEKSANDR MAKAROV	{"phone": "+70432856574"}
0005432529208	1C7EA9	6066 116373	SERGEY MARTYNOV	{"email": "sergeymartynov_28021975@postgrespro.ru", "phone": "+70816674420"}
0005432529209	1C7EA9	2996 561176	VALENTINA PAVLOVA	{"email": "pavlova.valentina-1962@postgrespro.ru", "phone": "+70276112645"}
0005432529210	3295A9	8326 775683	ANATOLIY VOLKOV	{"email": "volkov.anatoliy02021966@postgrespro.ru", "phone": "+70569973102"}
0005432529211	D147A1	2012 507933	ZOYA SOROKINA	{"phone": "+70203786854"}
0005432529212	242996	2970 776013	NIKOLAY DMITRIEV	{"phone": "+70880378908"}
0005432529213	23AE7F	0565 413845	OLGA POTAPOVA	{"phone": "+70503636729"}
0005432529214	0EA4DB	6510 307662	YURIY ABRAMOV	{"email": "yuriy-abramov_1963@postgrespro.ru", "phone": "+70106941246"}
0005432529215	E6919B	4127 284943	SAMIRA OVCHINNIKOVA	{"email": "ovchinnikova.s1979@postgrespro.ru", "phone": "+70850171071"}
0005432529216	732827	9023 301139	ANASTASIYA MOISEEVA	{"email": "a.moiseeva_1978@postgrespro.ru", "phone": "+70655193618"}
0005432529217	3110D8	5248 001576	SVETLANA SOLOVEVA	{"phone": "+70130955553"}
0005432529218	3B53AC	5378 135490	ANNA FILATOVA	{"phone": "+70929059569"}
0005432529219	1712CA	5531 058521	SERGEY SHEVCHENKO	{"email": "shevchenko-s.01011965@postgrespro.ru", "phone": "+70744418241"}
0005432529220	ED2231	1603 271751	ANNA POPOVA	{"phone": "+70068570992"}
0005432529221	0BB19D	3723 704521	OLGA ABRAMOVA	{"email": "abramova_olga_1982@postgrespro.ru", "phone": "+70848802722"}
0005432529222	039EFB	4607 973152	YULIYA NAZAROVA	{"phone": "+70523839680"}
0005432529223	039EFB	5108 455108	EVGENIY KULIKOV	{"phone": "+70168384653"}
0005432529224	017A18	4606 512606	GENNADIY KUDRYASHOV	{"phone": "+70307322562"}
0005432529225	99AA8C	6531 787696	ALEVTINA NIKITINA	{"email": "nikitina_alevtina-011975@postgrespro.ru", "phone": "+70865294853"}
0005432529226	99AA8C	5787 494630	TATYANA KOROLEVA	{"email": "korolevatatyana-121977@postgrespro.ru", "phone": "+70485173235"}
0005432529227	99AA8C	2475 413373	ELENA KUZMINA	{"phone": "+70767956522"}
0005432529228	2B42BF	6274 065091	IRINA POTAPOVA	{"email": "potapovairina.1985@postgrespro.ru", "phone": "+70879591880"}
0005432529229	2B42BF	9885 356731	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr-1976@postgrespro.ru", "phone": "+70630111806"}
0005432529230	1D0BBA	4620 313141	ANASTASIYA KULIKOVA	{"phone": "+70370304012"}
0005432529231	1D0BBA	9960 711747	NINA ARKHIPOVA	{"email": "arkhipovanina121983@postgrespro.ru", "phone": "+70654541003"}
0005432529232	173D62	6255 688053	YULIYA RODIONOVA	{"email": "yuliya_rodionova1977@postgrespro.ru", "phone": "+70657662532"}
0005432529233	173D62	3739 809298	VIKTORIYA KISELEVA	{"phone": "+70103049728"}
0005432529234	A0CC1E	5150 883168	RUSLAN SHEVCHENKO	{"email": "shevchenkoruslan.041972@postgrespro.ru", "phone": "+70633706146"}
0005432529235	971046	6869 795709	ELENA OSIPOVA	{"email": "osipova_e-1968@postgrespro.ru", "phone": "+70422930511"}
0005432529236	971046	4474 582665	NATALYA KOLESNIKOVA	{"phone": "+70078370114"}
0005432529237	2DCF3F	0770 168122	ALEKSEY MATVEEV	{"email": "matveeva.13111963@postgrespro.ru", "phone": "+70697685334"}
0005432529238	7B49EC	1396 338814	YURIY SOKOLOV	{"email": "sokolovy.011979@postgrespro.ru", "phone": "+70149232718"}
0005432529239	B70E0A	1888 283753	YANA KAZAKOVA	{"email": "kazakova-yana_02101974@postgrespro.ru", "phone": "+70207924092"}
0005432529240	F7E4BA	9510 037732	DARYA ERMAKOVA	{"phone": "+70894038220"}
0005432529241	552318	8068 176340	DARYA AKIMOVA	{"phone": "+70153744955"}
0005432529242	9C2539	3206 042040	ANASTASIYA STEPANOVA	{"email": "anastasiyastepanova15111966@postgrespro.ru", "phone": "+70228025595"}
0005432529243	73F9DB	4353 262199	SVETLANA BELYAEVA	{"email": "belyaeva_svetlana-1986@postgrespro.ru", "phone": "+70103870005"}
0005432529244	73F9DB	7847 959921	VLADIMIR IVANOV	{"email": "v-ivanov27011978@postgrespro.ru", "phone": "+70639795840"}
0005432529246	712995	0337 408350	SERGEY DMITRIEV	{"email": "dmitriev_sergey1963@postgrespro.ru", "phone": "+70428632167"}
0005432529247	2B5673	4363 932590	ELENA PETROVA	{"email": "e.petrova_1967@postgrespro.ru", "phone": "+70480506341"}
0005432529248	84DD49	3124 615842	VALERIYA PETROVA	{"phone": "+70961532884"}
0005432529249	84DD49	2897 889883	ALEKSANDR ALEKSEEV	{"phone": "+70417411389"}
0005432529250	04DE97	2196 458152	DMITRIY KRASNOV	{"phone": "+70152378550"}
0005432529251	04DE97	4559 729387	EVGENIY KRASNOV	{"phone": "+70415158057"}
0005432529252	80B6E4	1114 190158	NINA KISELEVA	{"phone": "+70908603361"}
0005432529253	9DD271	2450 659143	NADEZHDA EFREMOVA	{"email": "efremova.n.091969@postgrespro.ru", "phone": "+70435860851"}
0005432529254	9DD271	0389 783908	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov_v.15091972@postgrespro.ru", "phone": "+70416602852"}
0005432529255	9DD271	8767 702407	KRISTINA DANILOVA	{"email": "danilovak-111976@postgrespro.ru", "phone": "+70653835967"}
0005432529256	1CBA68	8131 314397	GALIYA ERMAKOVA	{"phone": "+70750734673"}
0005432529257	EFA36E	0800 718736	ANASTASIYA GORBUNOVA	{"phone": "+70336180965"}
0005432529258	50E599	5204 899222	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana_111973@postgrespro.ru", "phone": "+70101720214"}
0005432529259	E387E8	0370 322596	SVETLANA ROMANOVA	{"email": "s-romanova061983@postgrespro.ru", "phone": "+70123207622"}
0005432529260	9572E5	2058 128346	VYACHESLAV TIMOFEEV	{"phone": "+70604118304"}
0005432529261	9572E5	4086 110849	NINA KRASNOVA	{"phone": "+70052013174"}
0005432529262	9572E5	1310 593659	ALEKSANDR MIKHAYLOV	{"phone": "+70212810428"}
0005432529263	F3B004	0912 146378	EKATERINA KUZNECOVA	{"email": "e_kuznecova.27051973@postgrespro.ru", "phone": "+70836923361"}
0005432529264	536F68	4234 407321	STANISLAV GORBUNOV	{"phone": "+70843131163"}
0005432529265	536F68	0856 536124	IRINA SOKOLOVA	{"email": "irinasokolova_1972@postgrespro.ru", "phone": "+70570746163"}
0005432529266	E6B5B6	5709 253916	RUDOLF CHERNOV	{"email": "chernov_rudolf-05031971@postgrespro.ru", "phone": "+70966175878"}
0005432529267	E6B5B6	4005 524253	ALEKSEY ILIN	{"phone": "+70432886607"}
0005432529268	261A5B	8816 204370	LYUBOV SOROKINA	{"phone": "+70438731935"}
0005432529269	8820B0	0991 835590	ELENA GORBUNOVA	{"email": "e.gorbunova-1961@postgrespro.ru", "phone": "+70968149772"}
0005432529270	CCA937	0323 492584	ANTON BORISOV	{"email": "borisov-anton_13021967@postgrespro.ru", "phone": "+70896139544"}
0005432529271	0909CB	7344 413951	EKATERINA KUZNECOVA	{"phone": "+70084339511"}
0005432529272	8E46B7	9610 037874	NADEZHDA SEMENOVA	{"phone": "+70370297429"}
0005432529273	E72CF9	7611 527131	GALINA IVANOVA	{"phone": "+70798780241"}
0005432529274	E72CF9	1062 819821	VERA STEPANOVA	{"phone": "+70083703301"}
0005432529275	190017	6509 006896	EVGENIYA NOVIKOVA	{"email": "novikova.e_021984@postgrespro.ru", "phone": "+70045583670"}
0005432529276	E7DB4B	5081 526758	ANASTASIYA GAVRILOVA	{"email": "anastasiya-gavrilova1975@postgrespro.ru", "phone": "+70384471327"}
0005432529277	E7DB4B	1999 889629	KIRILL STEPANOV	{"phone": "+70231834066"}
0005432529278	E7DB4B	2512 062705	YURIY BELOV	{"email": "yuriybelov_01021974@postgrespro.ru", "phone": "+70971049174"}
0005432529279	4131EA	9978 634965	VLADIMIR ALEKSEEV	{"email": "alekseevv.1978@postgrespro.ru", "phone": "+70016895191"}
0005432529280	B969A4	2031 943775	TATYANA AKIMOVA	{"email": "tatyana-akimova061977@postgrespro.ru", "phone": "+70699514469"}
0005432529281	E7C87D	6718 673732	YULIYA NIKIFOROVA	{"email": "nikiforovayuliya-24021969@postgrespro.ru", "phone": "+70843820379"}
0005432529282	E7C87D	1751 823619	ANDREY GRIGOREV	{"phone": "+70807976944"}
0005432529283	A2A5A3	7377 691645	ALEKSANDRA KUZMINA	{"email": "kuzmina.aleksandra20091971@postgrespro.ru", "phone": "+70531141367"}
0005432529284	A2A5A3	8397 639287	VLADIMIR MAKSIMOV	{"phone": "+70782590068"}
0005432529285	A2A5A3	2045 275018	NATALIYA POPOVA	{"phone": "+70553362741"}
0005432529286	19A1C8	2340 312757	SERGEY KOZLOV	{"phone": "+70106974161"}
0005432529287	19A1C8	6295 474472	ANNA IVANOVA	{"phone": "+70623667811"}
0005432529288	19A1C8	6223 821018	MAKSIM GORBUNOV	{"phone": "+70619073833"}
0005432529289	15F024	6541 216725	ZHANNA KUZNECOVA	{"phone": "+70981563445"}
0005432529290	15F024	3366 297946	DMITRIY IVANOV	{"phone": "+70662362106"}
0005432529291	CF30D7	6343 744920	MIKHAIL ANDREEV	{"phone": "+70120751193"}
0005432529292	CF30D7	6240 265650	ALEKSANDR BORISOV	{"email": "aleksandr.borisov_25081987@postgrespro.ru", "phone": "+70595155519"}
0005432529293	E825CA	4044 200999	VERA KOLESNIKOVA	{"phone": "+70161178896"}
0005432529294	E825CA	7406 990041	POLINA ZAKHAROVA	{"email": "polina_zakharova-19031977@postgrespro.ru", "phone": "+70330673471"}
0005432529295	A189FF	1907 772863	NADEZHDA ANDREEVA	{"email": "n.andreeva_011964@postgrespro.ru", "phone": "+70501005343"}
0005432529296	9841C7	6751 913737	NATALYA ALEKSEEVA	{"phone": "+70171097332"}
0005432529297	530B4D	6483 598620	VASILIY MATVEEV	{"phone": "+70287638762"}
0005432529298	530B4D	8133 219391	MARIYA VASILEVA	{"phone": "+70699654430"}
0005432529299	D61812	3717 852199	VLADIMIR BELOV	{"email": "vbelov1980@postgrespro.ru", "phone": "+70754694447"}
0005432529300	F1EED6	3941 431156	ELMIRA KOZLOVA	{"phone": "+70553388175"}
0005432529301	A4EA2C	4818 769519	TAISIYA LAZAREVA	{"phone": "+70122730346"}
0005432529302	A4EA2C	5730 794911	LYUBOV PAVLOVA	{"phone": "+70944251957"}
0005432529303	DCEABC	2352 686423	VALENTINA SEMENOVA	{"email": "v.semenova031956@postgrespro.ru", "phone": "+70641211092"}
0005432529304	7A8E1F	4099 736884	ALEKSANDR ORLOV	{"email": "orlov-a-1977@postgrespro.ru", "phone": "+70364444031"}
0005432529305	64FE06	6256 759486	VLADIMIR SOROKIN	{"phone": "+70524406288"}
0005432529306	B10DC3	3463 865908	GEORGIY IVANOV	{"email": "givanov_28101972@postgrespro.ru", "phone": "+70421724240"}
0005432529307	B10DC3	4768 589208	NINA KUZNECOVA	{"email": "ninakuznecova-26011975@postgrespro.ru", "phone": "+70149642211"}
0005432529308	EE25B8	6378 260438	SERGEY MELNIKOV	{"phone": "+70913052229"}
0005432529309	44367E	3362 055040	MARAT RODIONOV	{"phone": "+70697479686"}
0005432529310	B25494	5090 457965	VALENTINA KOZLOVA	{"email": "valentina_kozlova-23051970@postgrespro.ru", "phone": "+70760019226"}
0005432529311	B25494	7455 015293	TATYANA KULIKOVA	{"email": "tatyanakulikova.1968@postgrespro.ru", "phone": "+70181921370"}
0005432529312	1C26CF	2420 275174	ANATOLIY VOROBEV	{"email": "vorobeva.091976@postgrespro.ru", "phone": "+70761472557"}
0005432529313	D1EC5E	0863 088495	ANTON PETROV	{"email": "petrov.anton1963@postgrespro.ru", "phone": "+70343491347"}
0005432529314	D1EC5E	0967 080589	SERGEY KUZNECOV	{"email": "sergey-kuznecov.101976@postgrespro.ru", "phone": "+70835879929"}
0005432529315	10900C	7899 291269	ELIZAVETA MAKSIMOVA	{"email": "elizavetamaksimova_011974@postgrespro.ru", "phone": "+70205184646"}
0005432529316	10900C	4919 596367	VASILIY POPOV	{"phone": "+70491056460"}
0005432529317	10900C	7129 685257	VLADIMIR DENISOV	{"email": "v.denisov-12031969@postgrespro.ru", "phone": "+70370249423"}
0005432529318	E80B1B	4135 353179	SERGEY FILIPPOV	{"email": "s-filippov.06061978@postgrespro.ru", "phone": "+70805397098"}
0005432529319	14D0B6	9798 893829	DANILA KUZNECOV	{"phone": "+70184597068"}
0005432529320	4CB6FE	0893 033570	ELENA IVANOVA	{"email": "e.ivanova-011966@postgrespro.ru", "phone": "+70212252640"}
0005432529321	4CB6FE	1259 239269	LYUBOV KUZNECOVA	{"phone": "+70494539657"}
0005432529322	B8F0D2	3615 178799	SEMEN KULIKOV	{"phone": "+70142410809"}
0005432529323	C05447	2655 097757	NADEZHDA KRASNOVA	{"email": "krasnovanadezhda21021984@postgrespro.ru", "phone": "+70468631019"}
0005432529324	C05447	6492 887472	TATYANA KARPOVA	{"phone": "+70880176180"}
0005432529325	BF8D09	2873 983031	DMITRIY ZAKHAROV	{"email": "zakharov_d-15081961@postgrespro.ru", "phone": "+70110341411"}
0005432529326	2D4D2A	0598 295102	OKSANA BOGDANOVA	{"email": "oksana.bogdanova.28041970@postgrespro.ru", "phone": "+70274721280"}
0005432529327	83F395	1901 127541	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr-021974@postgrespro.ru", "phone": "+70822655773"}
0005432529328	AC7238	3139 972409	LYUDMILA TITOVA	{"phone": "+70856285786"}
0005432529329	AC7238	5536 536436	VALERIY MELNIKOV	{"phone": "+70745329265"}
0005432529330	B2E4BC	3744 003752	ALEKSANDR SOKOLOV	{"phone": "+70428215219"}
0005432529331	B2E4BC	5988 296208	ALEKSANDR IVANOV	{"email": "a-ivanov.11061975@postgrespro.ru", "phone": "+70987402663"}
0005432529332	A23576	3724 184574	VLADIMIR NAUMOV	{"email": "naumov_vladimir_1971@postgrespro.ru", "phone": "+70405506685"}
0005432529333	A23576	3786 586239	ANNA FEDOROVA	{"email": "a-fedorova.10011972@postgrespro.ru", "phone": "+70984909297"}
0005432529334	A5B271	4378 342156	RAFAEL PETROV	{"phone": "+70964391180"}
0005432529335	5D85FF	1942 868627	ALEKSANDRA ILINA	{"email": "aleksandra-ilina_28051968@postgrespro.ru", "phone": "+70858076152"}
0005432529336	2B195C	2607 654664	LYUBOV KOLESNIKOVA	{"email": "kolesnikoval_19061972@postgrespro.ru", "phone": "+70694995640"}
0005432529337	2B195C	5951 812323	OLGA KOZLOVA	{"email": "okozlova061972@postgrespro.ru", "phone": "+70616807386"}
0005432529338	B21975	1775 582704	KARINA NIKITINA	{"email": "k-nikitina1966@postgrespro.ru", "phone": "+70327439985"}
0005432529339	B21975	7819 223991	ANTON RODIONOV	{"phone": "+70627806625"}
0005432529340	B21975	1668 252476	VALENTINA PAVLOVA	{"email": "pavlova.valentina061974@postgrespro.ru", "phone": "+70095844499"}
0005432529341	4786F2	6807 045402	VLADIMIR OSIPOV	{"email": "osipovvladimir.16081977@postgrespro.ru", "phone": "+70207907060"}
0005432529342	4786F2	9112 851793	SERGEY BORISOV	{"phone": "+70210544366"}
0005432529343	4B4239	8102 061079	NIKOLAY NAUMOV	{"email": "n_naumov-23101981@postgrespro.ru", "phone": "+70655306225"}
0005432529344	44109B	1799 615015	LYUBOV ALEKSEEVA	{"email": "l_alekseeva.1968@postgrespro.ru", "phone": "+70983862354"}
0005432529345	EA6078	4091 733875	PETR PETROV	{"email": "petr-petrov.08111960@postgrespro.ru", "phone": "+70928012149"}
0005432529346	83B19A	8138 390821	VLADIMIR SAVELEV	{"email": "vladimirsavelev031979@postgrespro.ru", "phone": "+70119724067"}
0005432529347	83B19A	9004 759115	IRINA KOLESNIKOVA	{"phone": "+70890842118"}
0005432529348	0212A1	7071 260744	LILIYA MIRONOVA	{"email": "l-mironova-12081970@postgrespro.ru", "phone": "+70523017657"}
0005432529349	ACD382	9104 103284	MIKHAIL GRIGOREV	{"email": "grigorev.mikhail091966@postgrespro.ru", "phone": "+70935298232"}
0005432529350	ACD382	8260 373415	ANTON SEMENOV	{"email": "anton-semenov.03111964@postgrespro.ru", "phone": "+70655429486"}
0005432529351	EB4FF1	2830 476168	VALENTINA VLASOVA	{"email": "vlasova.v02021956@postgrespro.ru", "phone": "+70471898462"}
0005432529352	32BEC5	4928 329215	ALEKSEY KUZNECOV	{"phone": "+70503660068"}
0005432529353	E1E1A2	5534 279690	MARIYA NESTEROVA	{"email": "nesterova.mariya.17121973@postgrespro.ru", "phone": "+70918369065"}
0005432529354	7EAB5A	2956 765787	LEONID SIDOROV	{"phone": "+70020552090"}
0005432529355	7EAB5A	6311 351204	VALENTINA SOKOLOVA	{"phone": "+70875427879"}
0005432529356	F94D77	2935 373285	MAKSIM ALEKSEEV	{"phone": "+70582021032"}
0005432529357	9942EF	6842 764441	YURIY FROLOV	{"phone": "+70464874101"}
0005432529358	BDF407	2912 751472	ANDREY NIKOLAEV	{"email": "andreynikolaev_1980@postgrespro.ru", "phone": "+70124588147"}
0005432529359	BDF407	9162 405412	ELENA KONOVALOVA	{"email": "konovalova_elena_021978@postgrespro.ru", "phone": "+70444285794"}
0005432529360	BDF407	7260 688292	PETR ABRAMOV	{"phone": "+70392769899"}
0005432529361	2CA61C	5506 625638	DMITRIY NOVIKOV	{"email": "novikov-dmitriy-091966@postgrespro.ru", "phone": "+70502208930"}
0005432529362	890A9C	6227 567799	ALEKSANDR MELNIKOV	{"email": "a_melnikov-21061965@postgrespro.ru", "phone": "+70306401113"}
0005432529363	890A9C	8766 718822	IRINA KUZNECOVA	{"phone": "+70647860699"}
0005432529364	1458EF	5418 089830	VALENTIN NOVIKOV	{"phone": "+70627295581"}
0005432529365	629A06	7958 055230	ALEKSANDR KUZNECOV	{"phone": "+70547216029"}
0005432529366	629A06	4395 945981	KONSTANTIN VOLKOV	{"email": "volkov-konstantin_10091980@postgrespro.ru", "phone": "+70600189680"}
0005432529367	667F76	1301 776750	GALINA PETROVA	{"email": "petrova.g-021968@postgrespro.ru", "phone": "+70162080244"}
0005432529368	0624C9	3479 965579	ZINAIDA KULIKOVA	{"email": "kulikova-zinaida.081970@postgrespro.ru", "phone": "+70226078533"}
0005432529369	0624C9	8417 313684	ARINA ARKHIPOVA	{"phone": "+70212027272"}
0005432529370	5D44DE	9139 419246	ANNA POLYAKOVA	{"email": "polyakova_a21021966@postgrespro.ru", "phone": "+70219787714"}
0005432529371	5B6CBA	0991 828114	NADEZHDA BARANOVA	{"phone": "+70825935456"}
0005432529372	D7A06F	4907 294408	TIGRAN KAZAKOV	{"email": "kazakovt21041982@postgrespro.ru", "phone": "+70141646608"}
0005432529373	D7A06F	2505 608091	ANDREY SOROKIN	{"phone": "+70185764447"}
0005432529374	9EA2E6	3004 136986	EVGENIY KONOVALOV	{"phone": "+70267125031"}
0005432529375	F5E678	0846 253522	KONSTANTIN ROMANOV	{"email": "konstantinromanov-22041978@postgrespro.ru", "phone": "+70577533597"}
0005432529376	F5E678	1071 570994	NATALYA ZAKHAROVA	{"phone": "+70850604239"}
0005432529377	1E5B78	7511 917302	ANNA BOGDANOVA	{"phone": "+70161050684"}
0005432529378	12C302	9600 772316	NATALYA FROLOVA	{"phone": "+70915458706"}
0005432529379	E8B21A	3870 801208	VLADIMIR SHEVCHENKO	{"email": "vladimirshevchenko_051967@postgrespro.ru", "phone": "+70511407703"}
0005432529380	3267A9	6553 698048	NIKOLAY ANDREEV	{"email": "nikolayandreev061971@postgrespro.ru", "phone": "+70504149809"}
0005432529381	630BD9	7750 197978	VALENTINA FILIPPOVA	{"phone": "+70177249006"}
0005432529382	DF7B7A	0088 529072	NADEZHDA NIKOLAEVA	{"phone": "+70981753562"}
0005432529383	DF7B7A	4621 168695	ANASTASIYA FROLOVA	{"phone": "+70737768505"}
0005432529384	5D771B	5952 455325	MARIYA VASILEVA	{"phone": "+70687815264"}
0005432529385	55ABB9	7407 906910	NIKITA KISELEV	{"phone": "+70082123331"}
0005432529386	608BEC	3003 157897	KIRILL IVANOV	{"phone": "+70030694496"}
0005432529387	608BEC	6681 901503	ALEKSEY FEDOROV	{"phone": "+70436644550"}
0005432529388	1FE3F9	6150 950748	YURIY VASILEV	{"email": "yuriyvasilev09051973@postgrespro.ru", "phone": "+70814259970"}
0005432529389	1FE3F9	9641 669558	VERA MEDVEDEVA	{"phone": "+70042676583"}
0005432529390	5A26EB	3328 320241	NIKOLAY GRIGOREV	{"phone": "+70419344337"}
0005432529391	400292	9028 539388	VLADIMIR ALEKSANDROV	{"email": "aleksandrovv.10031975@postgrespro.ru", "phone": "+70619062141"}
0005432529392	71F491	9093 063762	NATALYA KARPOVA	{"phone": "+70833933493"}
0005432529393	C60A54	3656 342811	OKSANA CHERNOVA	{"phone": "+70260725968"}
0005432529394	4F9B62	7895 584844	DARYA EFREMOVA	{"email": "efremova-darya.07071962@postgrespro.ru", "phone": "+70766109990"}
0005432529395	EBD381	4079 802129	ALEKSANDR NAUMOV	{"email": "naumov.a041960@postgrespro.ru", "phone": "+70678312495"}
0005432529396	EBD381	0664 084713	YURIY NAZAROV	{"email": "yuriy-nazarov_111973@postgrespro.ru", "phone": "+70407312058"}
0005432529397	BD4AB8	5278 953942	NINA DENISOVA	{"phone": "+70895531639"}
0005432529398	F749EA	6717 423520	VIKTOR NAUMOV	{"phone": "+70603664769"}
0005432529399	F749EA	4947 886207	ANTON MIRONOV	{"email": "mironovanton-20111967@postgrespro.ru", "phone": "+70468189932"}
0005432529400	E50C0A	0764 191035	ILYA ROMANOV	{"email": "romanovilya_06111958@postgrespro.ru", "phone": "+70177348359"}
0005432529401	E18C24	8540 034629	EKATERINA NIKIFOROVA	{"email": "nikiforovaekaterina_02041977@postgrespro.ru", "phone": "+70539757835"}
0005432529402	8AF03D	6855 213913	VIKTOR KUZNECOV	{"email": "kuznecov-v05101976@postgrespro.ru", "phone": "+70137018536"}
0005432529403	D5CB49	4868 714404	SERGEY NAZAROV	{"phone": "+70857130861"}
0005432529404	659524	6944 478097	PELAGEYA SIDOROVA	{"phone": "+70779963285"}
0005432529405	CD9E75	8666 853995	ANDREY ZHURAVLEV	{"email": "zhuravlev_andrey1967@postgrespro.ru", "phone": "+70485150694"}
0005432529406	53521D	8747 102680	TATYANA VASILEVA	{"email": "tatyana-vasileva1960@postgrespro.ru", "phone": "+70842341447"}
0005432529407	53521D	1150 721342	NIKOLAY NIKITIN	{"email": "nikitin_nikolay-19101971@postgrespro.ru", "phone": "+70851444690"}
0005432529408	53521D	5609 019627	IGOR BELOV	{"phone": "+70731969583"}
0005432529409	8A20D5	9147 389795	VLADIMIR GAVRILOV	{"email": "gavrilovvladimir_1970@postgrespro.ru", "phone": "+70785249501"}
0005432529410	F6FD3F	7084 679605	OLEG RODIONOV	{"email": "rodionov.o_031967@postgrespro.ru", "phone": "+70177822960"}
0005432529411	B1E9FE	8649 869190	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr1974@postgrespro.ru", "phone": "+70489032019"}
0005432529412	9EBCD6	7929 790994	ALEKSANDR ZHUKOV	{"phone": "+70686140931"}
0005432529413	24663A	7079 640911	NIKOLAY FEDOTOV	{"phone": "+70673863732"}
0005432529415	3B1D3A	5870 592272	MIKHAIL IVANOV	{"email": "ivanov-m.1976@postgrespro.ru", "phone": "+70791320200"}
0005432529416	283407	3241 495557	VLADIMIR SAVELEV	{"phone": "+70219291769"}
0005432529417	B91F01	2804 036681	KONSTANTIN ZAKHAROV	{"email": "konstantinzakharov.1983@postgrespro.ru", "phone": "+70068275973"}
0005432529418	3584D8	1350 614476	YURIY TARASOV	{"email": "yuriy-tarasov1972@postgrespro.ru", "phone": "+70423228091"}
0005432529419	3584D8	4057 671466	VLADIMIR ROMANOV	{"phone": "+70398321246"}
0005432529420	F346D7	7559 159192	EKATERINA ISAEVA	{"email": "isaeva_ekaterina-081961@postgrespro.ru", "phone": "+70773520946"}
0005432529421	F52387	5356 027290	OLGA NAUMOVA	{"email": "naumova-olga.25061975@postgrespro.ru", "phone": "+70194145448"}
0005432529422	F52387	6398 997644	VALERIY CHERNOV	{"phone": "+70221366119"}
0005432529423	BAB3B2	5285 444110	YURIY KUZMIN	{"phone": "+70299161779"}
0005432529424	BAB3B2	2959 101980	YURIY YAKOVLEV	{"phone": "+70721883029"}
0005432529425	76B633	2884 535109	ANNA FILIPPOVA	{"phone": "+70249033921"}
0005432529426	76B633	6990 337798	ALEKSEY NIKOLAEV	{"email": "nikolaev.aleksey-16041976@postgrespro.ru", "phone": "+70358053064"}
0005432529427	52D9EF	1408 168553	SVETLANA PETROVA	{"email": "petrovas-121981@postgrespro.ru", "phone": "+70852187080"}
0005432529428	3EE523	1602 628690	ELIZAVETA KOROLEVA	{"phone": "+70925268356"}
0005432529429	913809	1828 872691	YULIYA DAVYDOVA	{"phone": "+70975828806"}
0005432529430	A6667E	4915 968926	KIRILL NIKITIN	{"email": "nikitin_k_1969@postgrespro.ru", "phone": "+70027791322"}
0005432529431	0D5F1E	3755 339859	VLADIMIR IVANOV	{"phone": "+70859623119"}
0005432529432	C0D3DA	0350 842081	SERGEY NAUMOV	{"email": "naumov-s.1974@postgrespro.ru", "phone": "+70064273413"}
0005432529433	85D19D	6070 720598	ELENA NIKITINA	{"phone": "+70762138823"}
0005432529434	91433C	1692 565928	VITALIY VLASOV	{"email": "vlasov_vitaliy.091973@postgrespro.ru", "phone": "+70726587614"}
0005432529435	2EEE47	1703 119025	NINA FILIPPOVA	{"email": "filippova_nina-021969@postgrespro.ru", "phone": "+70734943472"}
0005432529436	A69DD8	7542 027045	ALEKSANDR ORLOV	{"phone": "+70857036025"}
0005432529437	3C2C7E	0585 562111	ALEKSANDR SIDOROV	{"phone": "+70232094466"}
0005432529438	3C2C7E	2947 129713	SVETLANA KAZAKOVA	{"email": "kazakova-s.081970@postgrespro.ru", "phone": "+70545318613"}
0005432529439	5CAAC8	0101 225132	ANATOLIY TIMOFEEV	{"phone": "+70701130240"}
0005432529440	EE1810	4879 615886	ALEKSANDR EGOROV	{"email": "egorovaleksandr.08011972@postgrespro.ru", "phone": "+70200833996"}
0005432529441	EE1810	4907 410033	GALINA KOZLOVA	{"phone": "+70907694013"}
0005432529442	F8D669	6240 537114	ANNA FOMINA	{"email": "fomina-a-03031984@postgrespro.ru", "phone": "+70627494129"}
0005432529443	F8D669	7864 500388	KLAVDIYA KUZNECOVA	{"phone": "+70073377034"}
0005432529444	F8D669	9307 199323	ARTUR PAVLOV	{"email": "a-pavlov_29101967@postgrespro.ru", "phone": "+70915905401"}
0005432529445	AB2B54	1648 726461	ALEKSANDRA ZHURAVLEVA	{"email": "a-zhuravleva.1973@postgrespro.ru", "phone": "+70466286260"}
0005432529446	AB2B54	1284 451758	SERGEY ALEKSEEV	{"email": "alekseev_sergey.08081972@postgrespro.ru", "phone": "+70527300784"}
0005432529447	9B2820	5314 334841	VITALIY POPOV	{"phone": "+70166898463"}
0005432529448	DF859C	7895 221354	YULIYA AFANASEVA	{"email": "afanaseva.yuliya13111963@postgrespro.ru", "phone": "+70514535723"}
0005432529449	93AE20	4655 472363	ALEKSEY ZAKHAROV	{"email": "azakharov.20021969@postgrespro.ru", "phone": "+70538099146"}
0005432529450	DEE206	0255 524635	LYUBOV CHERNOVA	{"email": "lyubov-chernova.29121967@postgrespro.ru", "phone": "+70738771444"}
0005432529451	6D0FD1	7155 301819	TATYANA PETROVA	{"email": "petrova_t101982@postgrespro.ru", "phone": "+70834867530"}
0005432529452	C55330	2509 966130	OLEG VOLKOV	{"email": "olegvolkov.09091973@postgrespro.ru", "phone": "+70863560399"}
0005432529453	614D0A	5619 239903	YAROSLAV KONOVALOV	{"email": "konovalov-y_1973@postgrespro.ru", "phone": "+70287827079"}
0005432529454	C7C3FF	2473 388563	GALINA MAKAROVA	{"email": "gmakarova.1971@postgrespro.ru", "phone": "+70135086087"}
0005432529455	C7C3FF	8504 148851	ELENA MALYSHEVA	{"phone": "+70581986396"}
0005432529456	220C72	7441 111185	ANASTASIYA NESTEROVA	{"phone": "+70690596778"}
0005432529457	B96FB6	1289 965762	ELENA FEDOROVA	{"phone": "+70687798388"}
0005432529458	CD4E15	2060 537548	MAKSIM NAUMOV	{"email": "naumov-m_121966@postgrespro.ru", "phone": "+70689453121"}
0005432529459	CD4E15	9844 304239	ANASTASIYA MOROZOVA	{"email": "morozovaa-09061976@postgrespro.ru", "phone": "+70090380524"}
0005432529460	D38CB4	0862 257093	TATYANA LUKYANOVA	{"email": "tlukyanova-1969@postgrespro.ru", "phone": "+70056258699"}
0005432529461	59A6DA	7548 170707	NATALYA KUZMINA	{"email": "kuzmina_natalya.1964@postgrespro.ru", "phone": "+70189128131"}
0005432529462	59A6DA	2603 552880	RAISA FEDOROVA	{"email": "fedorova-r.051974@postgrespro.ru", "phone": "+70462539089"}
0005432529463	437EC3	6667 174837	ALEKSEY NIKOLAEV	{"phone": "+70418759192"}
0005432529464	437EC3	4513 556910	YULIYA RODIONOVA	{"email": "rodionova.yuliya-05011966@postgrespro.ru", "phone": "+70927079837"}
0005432529465	437EC3	5575 443710	SERGEY MAKAROV	{"phone": "+70685528268"}
0005432529466	533490	0834 224880	EKATERINA IVANOVA	{"phone": "+70993191500"}
0005432529467	533490	5214 311533	NATALYA BORISOVA	{"email": "n_borisova.011977@postgrespro.ru", "phone": "+70584884679"}
0005432529468	333D3D	7600 295251	VALENTINA MIKHAYLOVA	{"phone": "+70141925007"}
0005432529580	EDE6E1	6954 059076	VALENTINA LEBEDEVA	{"phone": "+70437118095"}
0005432529747	970F58	7639 963728	ROZALIYA NAZAROVA	{"phone": "+70455981415"}
0005432529469	AA21CB	6655 102578	SERGEY SIDOROV	{"email": "sidorovs.111974@postgrespro.ru", "phone": "+70691697233"}
0005432529470	C513DB	3756 567375	YURIY ISAEV	{"email": "isaev.y-061971@postgrespro.ru", "phone": "+70396813345"}
0005432529471	A7CEAF	5470 487451	VERA KONOVALOVA	{"email": "v_konovalova28091965@postgrespro.ru", "phone": "+70829903298"}
0005432529472	197C7E	2486 947811	LYUDMILA MELNIKOVA	{"email": "melnikovalyudmila.1972@postgrespro.ru", "phone": "+70579406566"}
0005432529473	97A70C	9149 221943	ANNA POPOVA	{"email": "popova_anna101978@postgrespro.ru", "phone": "+70673588191"}
0005432529474	0D7055	3744 561878	LIDIYA GORBUNOVA	{"email": "lidiya.gorbunova.051963@postgrespro.ru", "phone": "+70055668846"}
0005432529653	423BCF	1946 511060	GRIGORIY MAKAROV	{"phone": "+70065479555"}
0005432529475	471711	2999 760276	VADIM ALEKSANDROV	{"email": "aleksandrov-vadim30111970@postgrespro.ru", "phone": "+70910448818"}
0005432529476	471711	1340 577204	ILYA ROMANOV	{"email": "romanov_ilya-071975@postgrespro.ru", "phone": "+70325715256"}
0005432529477	3CEC10	4281 512767	ANTON MIKHAYLOV	{"email": "mikhaylov_anton_1972@postgrespro.ru", "phone": "+70826305065"}
0005432529478	A75281	9767 756867	INNA MASLOVA	{"phone": "+70600043977"}
0005432529479	A75281	9794 731035	ALEKSANDR PAVLOV	{"phone": "+70147676732"}
0005432529480	20B75A	3439 760155	NATALIYA IVANOVA	{"phone": "+70054732863"}
0005432529481	9D488E	5623 622543	POLINA ZOTOVA	{"email": "zotova-polina_1979@postgrespro.ru", "phone": "+70212606435"}
0005432529482	819612	0521 654461	ELENA IVANOVA	{"email": "ivanova_e111967@postgrespro.ru", "phone": "+70188939548"}
0005432529483	819612	3873 459734	KIRILL ZHURAVLEV	{"phone": "+70893494096"}
0005432529484	BEB23F	9111 158898	OLGA EFREMOVA	{"phone": "+70168468141"}
0005432529485	4B7F53	3796 603734	MARINA DENISOVA	{"email": "denisova.m.11051980@postgrespro.ru", "phone": "+70620384788"}
0005432529486	4B7F53	0635 650432	ELIZAVETA SOLOVEVA	{"email": "soloveva-e08031973@postgrespro.ru", "phone": "+70644474972"}
0005432529487	20F2F5	9834 338025	MARTA KUZNECOVA	{"email": "kuznecova_m.03011968@postgrespro.ru", "phone": "+70956246735"}
0005432529488	C35899	3462 852489	MIKHAIL POPOV	{"email": "m_popov-13091978@postgrespro.ru", "phone": "+70780912569"}
0005432529489	F0C2C5	3762 565913	VASILIY SOLOVEV	{"email": "vasiliy-solovev.081975@postgrespro.ru", "phone": "+70332504515"}
0005432529490	88E63D	5342 892016	POLINA CHERNOVA	{"email": "chernovap28071966@postgrespro.ru", "phone": "+70128849607"}
0005432529491	1F5529	5863 496578	TATYANA KONDRATEVA	{"phone": "+70433526173"}
0005432529492	1F5529	6635 284476	ALEKSEY DENISOV	{"phone": "+70007647602"}
0005432529493	D44FF7	8988 839569	VLADIMIR KRASNOV	{"email": "v-krasnov.20091978@postgrespro.ru", "phone": "+70980362858"}
0005432529494	C12571	1200 459736	ALEKSEY OSIPOV	{"phone": "+70022065500"}
0005432529495	C12571	1382 218106	NATALYA KOROLEVA	{"phone": "+70915858112"}
0005432529496	C12571	9277 938436	KSENIYA POPOVA	{"phone": "+70188702744"}
0005432529497	7E5F1F	9381 403465	PAVEL ANDREEV	{"phone": "+70283099924"}
0005432529498	91A9EC	6668 394883	NIKOLAY ALEKSANDROV	{"email": "aleksandrovn02091976@postgrespro.ru", "phone": "+70255638399"}
0005432529499	EAA6C7	8085 076866	VLADIMIR SEMENOV	{"phone": "+70201151423"}
0005432529500	EAA6C7	0520 370947	YURIY SEMENOV	{"email": "y.semenov_27011969@postgrespro.ru", "phone": "+70476307908"}
0005432529501	7452DE	4994 962944	EVGENIY SMIRNOV	{"phone": "+70343570793"}
0005432529502	0DF7C3	6008 336697	ALBINA SOLOVEVA	{"email": "soloveva.albina.12121966@postgrespro.ru", "phone": "+70626114458"}
0005432529503	0DF7C3	3836 427494	SERGEY TIKHONOV	{"email": "tikhonovsergey21021980@postgrespro.ru", "phone": "+70834766161"}
0005432529504	5F2DE4	6710 592889	KIRILL FILIPPOV	{"phone": "+70507377128"}
0005432529505	5F2DE4	1647 418340	NIKOLAY KULIKOV	{"email": "nkulikov_08071962@postgrespro.ru", "phone": "+70064844652"}
0005432529506	5F2DE4	1869 129798	DARYA DAVYDOVA	{"email": "davydova.darya.1959@postgrespro.ru", "phone": "+70231464277"}
0005432529507	741F67	8336 020042	NIKOLAY TIKHONOV	{"email": "n-tikhonov-1973@postgrespro.ru", "phone": "+70857109161"}
0005432529508	741F67	5768 098485	VLADIMIR NAZAROV	{"phone": "+70819797615"}
0005432529509	5E67F3	8851 720438	MIKHAIL VOROBEV	{"email": "vorobev_m_11081979@postgrespro.ru", "phone": "+70379749414"}
0005432529510	9070C2	6567 696657	SERGEY NAZAROV	{"email": "sergeynazarov_121971@postgrespro.ru", "phone": "+70021296284"}
0005432529511	668726	1881 131390	TATYANA DMITRIEVA	{"email": "tatyana-dmitrieva1969@postgrespro.ru", "phone": "+70308577971"}
0005432529512	9B74FA	7839 363368	TAMARA FADEEVA	{"phone": "+70449402512"}
0005432529513	9B74FA	7652 941478	ALEKSANDR SMIRNOV	{"phone": "+70616359410"}
0005432529514	C8877B	3556 099375	ANASTASIYA KONOVALOVA	{"email": "konovalova.anastasiya27011974@postgrespro.ru", "phone": "+70921634193"}
0005432529515	C8877B	2302 927592	LYUDMILA KUZNECOVA	{"email": "kuznecova-l071973@postgrespro.ru", "phone": "+70208400888"}
0005432529516	C7E6CA	4818 456662	MIKHAIL KULIKOV	{"phone": "+70103774274"}
0005432529517	C7E6CA	0674 788999	NATALYA DMITRIEVA	{"email": "dmitrieva.natalya1970@postgrespro.ru", "phone": "+70635287440"}
0005432529518	00A9AF	7745 866837	VALENTINA NIKITINA	{"phone": "+70480413788"}
0005432529519	8C0469	3857 915845	EVGENIY NIKOLAEV	{"email": "e_nikolaev-031970@postgrespro.ru", "phone": "+70380030810"}
0005432529520	8C0469	9430 991265	GEORGIY ISAEV	{"phone": "+70121162829"}
0005432529521	F8021E	4760 561128	SVETLANA BELYAEVA	{"email": "belyaeva-s-02081979@postgrespro.ru", "phone": "+70647143699"}
0005432529522	F8021E	9464 251121	NATALYA ILINA	{"phone": "+70611306523"}
0005432529523	6F036F	7017 219531	VARVARA KISELEVA	{"phone": "+70962323122"}
0005432529524	F6A184	7363 427945	NADEZHDA POPOVA	{"email": "nadezhda.popova-121978@postgrespro.ru", "phone": "+70973303042"}
0005432529525	388BF0	2106 050853	SVETLANA TIMOFEEVA	{"email": "svetlana_timofeeva.1974@postgrespro.ru", "phone": "+70680194490"}
0005432529526	A6AD6E	8176 468231	YURIY SOKOLOV	{"phone": "+70734670343"}
0005432529527	A6AD6E	2369 702100	VALENTINA BARANOVA	{"phone": "+70392538332"}
0005432529528	A83E69	1895 152023	DMITRIY DENISOV	{"phone": "+70950432040"}
0005432529529	ECE45A	1752 779340	LYUDMILA BORISOVA	{"phone": "+70962788990"}
0005432529530	973E4A	1953 291258	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov-31101971@postgrespro.ru", "phone": "+70058001278"}
0005432529531	BC378B	4385 228365	ANNA DANILOVA	{"phone": "+70752491529"}
0005432529532	BC378B	1490 677317	LIDIYA IVANOVA	{"phone": "+70823923750"}
0005432529533	A63FC8	5503 984845	ZOYA KRASNOVA	{"phone": "+70709896163"}
0005432529534	A63FC8	2915 875269	SERGEY SCHERBAKOV	{"email": "scherbakovsergey.10011954@postgrespro.ru", "phone": "+70072796612"}
0005432529535	3976CD	9765 204444	TATYANA ROMANOVA	{"email": "romanovat071983@postgrespro.ru", "phone": "+70185388603"}
0005432529536	833C7C	7001 556998	NATALYA GORBUNOVA	{"phone": "+70268536715"}
0005432529537	05212C	0896 901870	SERGEY SOKOLOV	{"email": "sokolov.sergey.1966@postgrespro.ru", "phone": "+70450161476"}
0005432529538	05212C	4839 125782	SOFYA KUZMINA	{"email": "kuzminasofya.1976@postgrespro.ru", "phone": "+70702912791"}
0005432529539	089832	0997 799891	NIKOLAY SAVELEV	{"phone": "+70847316120"}
0005432529540	C6A70A	1943 561104	NINA KRASNOVA	{"phone": "+70436671020"}
0005432529541	C6A70A	2181 717849	YULIYA GUSEVA	{"email": "guseva_y_121974@postgrespro.ru", "phone": "+70607254288"}
0005432529542	239305	9369 024604	OLGA MIKHAYLOVA	{"phone": "+70750187337"}
0005432529543	5095C5	2873 960547	LYUDMILA KONDRATEVA	{"email": "l-kondrateva-071977@postgrespro.ru", "phone": "+70914648009"}
0005432529544	9AB217	9090 908474	ELENA MALYSHEVA	{"email": "malysheva_elena051964@postgrespro.ru", "phone": "+70666438283"}
0005432529545	B492B6	8806 456747	POLINA KAZAKOVA	{"phone": "+70160578526"}
0005432529546	B492B6	5892 168777	OLGA NIKITINA	{"phone": "+70100183867"}
0005432529547	48CA9D	1172 944533	ALEKSEY FROLOV	{"phone": "+70252106178"}
0005432529548	9BADD8	0018 855498	ANASTASIYA ZHUKOVA	{"phone": "+70714195550"}
0005432529549	6523D8	8670 417340	SERGEY VOROBEV	{"email": "vorobev-sergey_081970@postgrespro.ru", "phone": "+70165292304"}
0005432529550	4B567E	1050 927887	MIKHAIL RODIONOV	{"phone": "+70612922417"}
0005432529551	79D134	4381 008897	LIDIYA CHERNOVA	{"email": "chernovalidiya121983@postgrespro.ru", "phone": "+70598518997"}
0005432529552	0787E7	9505 272179	VIKTOR FILIPPOV	{"email": "v_filippov_28031974@postgrespro.ru", "phone": "+70975970022"}
0005432529553	49348D	4812 969170	ALEKSANDR FROLOV	{"phone": "+70535571081"}
0005432529554	8346E0	4931 305693	DMITRIY SEMENOV	{"email": "semenov_dmitriy.071959@postgrespro.ru", "phone": "+70764148903"}
0005432529555	68C202	3850 394724	GALINA KAZAKOVA	{"email": "kazakova-g.111971@postgrespro.ru", "phone": "+70765981474"}
0005432529556	FE3EC7	3829 361747	VIKTOR PETROV	{"phone": "+70587988061"}
0005432529557	437425	2438 604586	NINA DAVYDOVA	{"email": "ndavydova_1962@postgrespro.ru", "phone": "+70008950516"}
0005432529558	116F2E	9824 335352	ELIZAVETA TITOVA	{"phone": "+70583830175"}
0005432529559	47CE87	3088 777521	KARINA EGOROVA	{"phone": "+70294197842"}
0005432529560	80DEF4	1745 596653	EKATERINA SERGEEVA	{"email": "sergeeva_e091965@postgrespro.ru", "phone": "+70767063888"}
0005432529561	849444	7366 032962	ALEKSANDR SOKOLOV	{"email": "a.sokolov-1984@postgrespro.ru", "phone": "+70755866856"}
0005432529562	832E8A	2731 965386	ANNA MELNIKOVA	{"email": "anna-melnikova-07041976@postgrespro.ru", "phone": "+70792796802"}
0005432529563	15FA35	7964 124257	KIRILL KISELEV	{"email": "kiselev_kirill-1977@postgrespro.ru", "phone": "+70388854116"}
0005432529564	B49BD0	7719 495715	YURIY SOKOLOV	{"phone": "+70222817325"}
0005432529565	C8BB48	8464 000151	MIKHAIL ZAYCEV	{"email": "zaycev-m.091967@postgrespro.ru", "phone": "+70107389234"}
0005432529566	7218E9	7756 249608	VLADIMIR GORBUNOV	{"phone": "+70754351145"}
0005432529567	A25953	1130 887590	VERA STEPANOVA	{"email": "vstepanova_1968@postgrespro.ru", "phone": "+70351549847"}
0005432529568	6F1E15	0780 710529	ANTON MEDVEDEV	{"phone": "+70933685437"}
0005432529569	700CB3	7390 394043	KIRILL VOLKOV	{"email": "k_volkov111971@postgrespro.ru", "phone": "+70241959186"}
0005432529570	4EF541	5752 808054	KSENIYA AKIMOVA	{"email": "k.akimova081980@postgrespro.ru", "phone": "+70168304795"}
0005432529571	4EF541	7268 004359	GALINA ABRAMOVA	{"email": "galina_abramova_1981@postgrespro.ru", "phone": "+70503733094"}
0005432529572	9E3975	4690 580961	VLADIMIR BORISOV	{"phone": "+70583496623"}
0005432529573	7031BE	8661 580634	EVGENIY MIRONOV	{"phone": "+70208764141"}
0005432529574	D894F2	3447 700138	ANNA STEPANOVA	{"phone": "+70201078165"}
0005432529575	D6D56D	4316 693778	BOGDAN NOVIKOV	{"phone": "+70039769674"}
0005432529576	8D5930	0547 451694	SERGEY MELNIKOV	{"email": "sergey_melnikov.1983@postgrespro.ru", "phone": "+70847143732"}
0005432529577	085B37	0170 630753	TAISIYA DENISOVA	{"email": "t-denisova101984@postgrespro.ru", "phone": "+70805423445"}
0005432529578	085B37	0441 157811	ALEKSANDR ILIN	{"email": "ilin_a_23091962@postgrespro.ru", "phone": "+70108028497"}
0005432529579	398DB9	5983 654217	TATYANA MASLOVA	{"phone": "+70637691629"}
0005432529581	7204FB	4427 555099	VALENTINA BORISOVA	{"email": "valentina-borisova1968@postgrespro.ru", "phone": "+70895132479"}
0005432529582	7204FB	9691 367480	ROMAN VOROBEV	{"phone": "+70152480380"}
0005432529583	64DD14	1574 219335	MAKSIM BARANOV	{"phone": "+70898162977"}
0005432529584	890E23	3137 106214	VERA STEPANOVA	{"email": "stepanova.v-1963@postgrespro.ru", "phone": "+70097086273"}
0005432529585	890E23	1144 729638	NADEZHDA RYABOVA	{"email": "nadezhdaryabova1971@postgrespro.ru", "phone": "+70991290039"}
0005432529586	1B39B3	2230 946532	SERGEY SIDOROV	{"email": "s.sidorov.30071966@postgrespro.ru", "phone": "+70639810491"}
0005432529587	AE7C33	6927 921843	MAKSIM SERGEEV	{"phone": "+70803458304"}
0005432529588	F92992	1794 214588	LYUDMILA ORLOVA	{"phone": "+70705159626"}
0005432529589	F92992	4720 708670	DARYA EGOROVA	{"phone": "+70632212261"}
0005432529590	F92992	1938 035495	PETR ABRAMOV	{"email": "abramov_p1983@postgrespro.ru", "phone": "+70968441493"}
0005432529591	2736D6	3561 990304	ALEKSANDR ZHUKOV	{"email": "a.zhukov061983@postgrespro.ru", "phone": "+70150529143"}
0005432529592	DD1077	4478 058808	ALINA KAZAKOVA	{"email": "alina-kazakova031975@postgrespro.ru", "phone": "+70043288144"}
0005432529593	5F8CC9	3002 714059	IRINA RODIONOVA	{"phone": "+70358249384"}
0005432529594	5F8CC9	3862 994140	MARINA SCHERBAKOVA	{"email": "scherbakova_marina.091975@postgrespro.ru", "phone": "+70585293773"}
0005432529595	B4D36A	4341 647618	NINA ANDREEVA	{"email": "ninaandreeva.07121969@postgrespro.ru", "phone": "+70407183829"}
0005432529596	E81B91	2091 963598	VIKTORIYA NIKITINA	{"email": "nikitina.viktoriya1976@postgrespro.ru", "phone": "+70577931701"}
0005432529597	433B55	7727 050903	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov12021982@postgrespro.ru", "phone": "+70613698540"}
0005432529598	57112F	4096 448952	ALEKSEY FEDOROV	{"email": "aleksey-fedorov_051975@postgrespro.ru", "phone": "+70775129035"}
0005432529599	57112F	0893 319752	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev.28011974@postgrespro.ru", "phone": "+70009581033"}
0005432529600	A5DECB	6206 891769	SERGEY ZHUKOV	{"email": "zhukov.s041967@postgrespro.ru", "phone": "+70486330703"}
0005432529601	A5DECB	4334 930278	SERGEY CHERNOV	{"email": "sergey.chernov-20011964@postgrespro.ru", "phone": "+70848823185"}
0005432529602	54DB8D	7354 219107	VIKTORIYA ANISIMOVA	{"email": "viktoriya_anisimova-1973@postgrespro.ru", "phone": "+70596856616"}
0005432529603	3E43DE	0578 989491	NELLI NESTEROVA	{"phone": "+70558715646"}
0005432529604	6557EB	7696 060115	ZINAIDA NAZAROVA	{"email": "znazarova051974@postgrespro.ru", "phone": "+70565128969"}
0005432529605	BB0375	1169 086091	TAMARA NIKOLAEVA	{"email": "nikolaeva_tamara-081978@postgrespro.ru", "phone": "+70007066219"}
0005432529606	BBE4AD	2891 277755	SERGEY KOZLOV	{"phone": "+70504407592"}
0005432529607	F8E39D	1821 496762	ANASTASIYA SMIRNOVA	{"phone": "+70033872040"}
0005432529608	F8E39D	7557 862011	VALENTIN OSIPOV	{"email": "valentin-osipov-26091965@postgrespro.ru", "phone": "+70237164663"}
0005432529609	4C6C69	8444 532897	ALEKSANDR DENISOV	{"email": "a_denisov.051968@postgrespro.ru", "phone": "+70770996062"}
0005432529610	D99C4B	0900 985485	ALEKSEY DAVYDOV	{"phone": "+70229545109"}
0005432529611	D99C4B	9246 630577	GENNADIY SOKOLOV	{"email": "gennadiysokolov27081979@postgrespro.ru", "phone": "+70006549152"}
0005432529612	3B8071	5989 189610	YURIY FILIPPOV	{"phone": "+70366007365"}
0005432529613	D5CDEB	4953 249621	ALLA MEDVEDEVA	{"phone": "+70757524248"}
0005432529614	D5CDEB	7416 733080	VALENTINA BELOVA	{"phone": "+70794399734"}
0005432529615	FC156D	9422 661940	VIKTOR NIKOLAEV	{"email": "nikolaev.v-1967@postgrespro.ru", "phone": "+70331112043"}
0005432529616	FC156D	9465 934375	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov_1980@postgrespro.ru", "phone": "+70540715612"}
0005432529617	342D1F	0265 543462	VASILIY POPOV	{"email": "popov_vasiliy.1969@postgrespro.ru", "phone": "+70606017458"}
0005432529618	5BAD06	6753 912846	ZULFIYA SOKOLOVA	{"email": "z_sokolova_1993@postgrespro.ru", "phone": "+70965783426"}
0005432529619	1C38C9	1436 963829	LYUDMILA DENISOVA	{"phone": "+70931523228"}
0005432529620	F28066	0130 466386	DMITRIY ILIN	{"email": "ilin-dmitriy091977@postgrespro.ru", "phone": "+70278544388"}
0005432529621	06D1CB	8107 381578	GENNADIY ZAYCEV	{"phone": "+70359206249"}
0005432529622	E0FEE9	3567 920633	VIKTOR GORBUNOV	{"phone": "+70319037420"}
0005432529623	8717B0	0920 721064	SVETLANA SERGEEVA	{"email": "sergeevasvetlana051985@postgrespro.ru", "phone": "+70253172353"}
0005432529624	8717B0	2382 932769	VLADIMIR POPOV	{"phone": "+70300906014"}
0005432529625	DB6021	3661 377310	ELENA BOGDANOVA	{"phone": "+70005651646"}
0005432529626	0FE1F6	7333 969645	EVGENIYA SIDOROVA	{"email": "evgeniya.sidorova-1972@postgrespro.ru", "phone": "+70055859691"}
0005432529627	C6DF9E	8276 473999	ELENA KUZNECOVA	{"email": "ekuznecova-04011963@postgrespro.ru", "phone": "+70304193603"}
0005432529628	7FAC84	0194 271524	VLADIMIR DENISOV	{"email": "v_denisov_091980@postgrespro.ru", "phone": "+70538456097"}
0005432529629	4DE899	4733 939671	NATALYA RYABOVA	{"phone": "+70110863898"}
0005432529630	B41B8A	2321 249219	SVETLANA IVANOVA	{"email": "s.ivanova_21031975@postgrespro.ru", "phone": "+70261403373"}
0005432529631	B41B8A	1265 496996	GENNADIY KUDRYASHOV	{"email": "kudryashov_g-29071975@postgrespro.ru", "phone": "+70339529294"}
0005432529632	E37CDE	3965 104263	VLADIMIR KONOVALOV	{"email": "konovalov-vladimir.1963@postgrespro.ru", "phone": "+70870519673"}
0005432529633	1D7902	8697 800160	VLADIMIR POPOV	{"email": "popov_vladimir_1980@postgrespro.ru", "phone": "+70670840183"}
0005432529634	DDA08F	6562 840666	GALINA SOKOLOVA	{"phone": "+70444919512"}
0005432529691	AE2A3F	2470 663985	TAMARA NAUMOVA	{"phone": "+70184371144"}
0005432529635	543B70	9788 493363	PELAGEYA ISAEVA	{"email": "isaeva_p_10111980@postgrespro.ru", "phone": "+70821935870"}
0005432529636	543B70	8858 054851	PETR GRIGOREV	{"phone": "+70216482390"}
0005432529637	543B70	4813 924828	ALEKSANDR SOROKIN	{"phone": "+70430830132"}
0005432529638	ADB7FA	0067 458020	KRISTINA MASLOVA	{"email": "maslova.kristina.02051960@postgrespro.ru", "phone": "+70665160996"}
0005432529639	3DC82F	8531 653971	MATVEY FROLOV	{"phone": "+70049070558"}
0005432529640	D61E86	1020 957726	SERGEY NAUMOV	{"email": "naumov.sergey.27111968@postgrespro.ru", "phone": "+70902140306"}
0005432529641	C1B5E8	6896 020199	POLINA POLYAKOVA	{"phone": "+70223214993"}
0005432529642	C1B5E8	8030 968226	ELIZAVETA KUZMINA	{"email": "ekuzmina071968@postgrespro.ru", "phone": "+70085265491"}
0005432529643	172B7A	0013 595627	NATALYA RODIONOVA	{"email": "n.rodionova06091980@postgrespro.ru", "phone": "+70520021216"}
0005432529644	172B7A	2017 185996	GALINA ZHURAVLEVA	{"email": "galina-zhuravleva_12091974@postgrespro.ru", "phone": "+70824213467"}
0005432529645	BC4FDE	5897 293171	VIKTOR MELNIKOV	{"phone": "+70476521452"}
0005432529646	965739	6491 350221	VIKTOR TIMOFEEV	{"email": "viktor_timofeev_05021973@postgrespro.ru", "phone": "+70118177127"}
0005432529647	BB0857	1527 769733	PAVEL SMIRNOV	{"phone": "+70887915206"}
0005432529648	1A5814	6694 041427	GENNADIY ALEKSEEV	{"phone": "+70066114341"}
0005432529649	6AEE19	0603 417308	MAKSIM SOROKIN	{"phone": "+70594200507"}
0005432529650	240067	0858 015032	ANTONINA ORLOVA	{"email": "antoninaorlova_1977@postgrespro.ru", "phone": "+70861099529"}
0005432529651	82A4F3	6027 550142	MARINA MAKSIMOVA	{"phone": "+70590347720"}
0005432529652	423BCF	5656 710101	VLADISLAV NOVIKOV	{"email": "vladislav-novikov.101973@postgrespro.ru", "phone": "+70528588938"}
0005432529654	343555	3964 397144	DMITRIY AFANASEV	{"phone": "+70834180441"}
0005432529655	293B08	5943 098132	VITALIY ZAYCEV	{"email": "zaycevv-12021974@postgrespro.ru", "phone": "+70768176264"}
0005432529656	DB7350	3579 105567	NINA YAKOVLEVA	{"phone": "+70686777174"}
0005432529657	629C6C	9410 189484	SVETLANA KUZMINA	{"email": "kuzmina_s.071966@postgrespro.ru", "phone": "+70665406228"}
0005432529658	629C6C	4278 141426	TATYANA SOKOLOVA	{"phone": "+70063355505"}
0005432529659	3A2439	7782 698651	EVGENIY SCHERBAKOV	{"email": "e-scherbakov_02041974@postgrespro.ru", "phone": "+70988696098"}
0005432529660	CF51A4	2007 738674	DIANA BARANOVA	{"phone": "+70133041327"}
0005432529661	4C4127	4189 276630	IGOR ZHUKOV	{"phone": "+70347906425"}
0005432529662	4C4127	6027 458278	DARYA KUZNECOVA	{"phone": "+70735764952"}
0005432529663	FC2AA3	2357 505822	GEORGIY VOLKOV	{"phone": "+70182415947"}
0005432529664	FC2AA3	8276 511195	SERGEY FROLOV	{"phone": "+70251188641"}
0005432529665	FC2AA3	5322 889293	ILNUR MAKSIMOV	{"email": "ilnurmaksimov_1962@postgrespro.ru", "phone": "+70689863634"}
0005432529666	EF70B3	7747 232041	ELENA POPOVA	{"email": "popova_e_041967@postgrespro.ru", "phone": "+70606720163"}
0005432529667	F30316	3254 460961	GALINA SAVELEVA	{"email": "galina.saveleva.1974@postgrespro.ru", "phone": "+70236620384"}
0005432529668	F30316	0835 954034	SERGEY FOMIN	{"email": "fomin.s1974@postgrespro.ru", "phone": "+70897996064"}
0005432529669	58D67A	1988 523117	ANNA SCHERBAKOVA	{"email": "scherbakova.anna_1972@postgrespro.ru", "phone": "+70765556021"}
0005432529670	58D67A	5161 939340	SERGEY SERGEEV	{"phone": "+70708919206"}
0005432529671	3D36E7	6679 456768	VALENTINA GRISHINA	{"email": "v_grishina.1976@postgrespro.ru", "phone": "+70200356692"}
0005432529672	FE6FFB	5615 838974	VLADISLAV NIKOLAEV	{"phone": "+70270800984"}
0005432529673	FE6FFB	7580 700552	ANATOLIY NAZAROV	{"email": "nazarovanatoliy_28021979@postgrespro.ru", "phone": "+70420746819"}
0005432529674	FA8FD2	5071 367086	ELENA ZHURAVLEVA	{"phone": "+70286276546"}
0005432529675	925F24	2950 121893	ALEKSEY MAKAROV	{"phone": "+70041484898"}
0005432529676	925F24	9545 901521	ANASTASIYA LEBEDEVA	{"phone": "+70283829570"}
0005432529677	12F286	9850 297351	MIKHAIL FROLOV	{"phone": "+70146458262"}
0005432529678	5AF2AA	4605 389534	OLGA DMITRIEVA	{"phone": "+70457413292"}
0005432529679	C4FE52	9702 140961	DMITRIY MIKHAYLOV	{"email": "dmitriy-mikhaylov_25121980@postgrespro.ru", "phone": "+70189045783"}
0005432529680	C4FE52	8579 696632	LYUDMILA ROMANOVA	{"phone": "+70362482283"}
0005432529681	AAF0CB	7108 360012	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir-30061978@postgrespro.ru", "phone": "+70381448845"}
0005432529682	AAF0CB	3662 156152	IVAN IVANOV	{"email": "i.ivanov30041972@postgrespro.ru", "phone": "+70089945120"}
0005432529683	19D0F5	1636 622657	SVETLANA TITOVA	{"email": "s.titova_1971@postgrespro.ru", "phone": "+70911006298"}
0005432529684	933977	4983 262710	MAKSIM SOROKIN	{"phone": "+70894356105"}
0005432529685	8185A7	4646 690398	OLGA KARPOVA	{"phone": "+70327471276"}
0005432529686	E8CEA7	1456 027524	NIKOLAY AFANASEV	{"email": "nikolay.afanasev1964@postgrespro.ru", "phone": "+70025796835"}
0005432529687	3B6DCC	7323 209967	VASILIY ANTONOV	{"phone": "+70103291943"}
0005432529688	AF54D9	5567 049792	YULIYA PETROVA	{"email": "petrovay-071958@postgrespro.ru", "phone": "+70829547324"}
0005432529689	DCE232	0865 619061	IRINA KOROLEVA	{"email": "irina-koroleva091968@postgrespro.ru", "phone": "+70409744024"}
0005432529690	48AC7A	9749 151045	VERONIKA MAKSIMOVA	{"email": "maksimova.veronika_1975@postgrespro.ru", "phone": "+70424000941"}
0005432529692	A60A43	0671 704311	EVGENIYA IVANOVA	{"email": "ivanova-evgeniya.1968@postgrespro.ru", "phone": "+70256129003"}
0005432529693	A60A43	8237 336376	ANASTASIYA ZAKHAROVA	{"email": "zakharova.anastasiya_25051971@postgrespro.ru", "phone": "+70190638792"}
0005432529694	A60A43	7620 294872	MARIYA NAUMOVA	{"email": "m.naumova_1973@postgrespro.ru", "phone": "+70228685330"}
0005432529695	C2C58D	5925 714272	OLGA NAZAROVA	{"email": "onazarova.10091970@postgrespro.ru", "phone": "+70890287693"}
0005432529696	C2C58D	8040 776451	IGOR KUZNECOV	{"email": "i_kuznecov111978@postgrespro.ru", "phone": "+70015463070"}
0005432529697	C27885	1837 822015	SERGEY MEDVEDEV	{"email": "medvedev-sergey.1965@postgrespro.ru", "phone": "+70227700709"}
0005432529698	35F5F1	3852 559194	ALEKSANDR VASILEV	{"email": "vasilev_a1976@postgrespro.ru", "phone": "+70759556989"}
0005432529699	B6B1F8	3069 225405	ANDREY ALEKSEEV	{"email": "a.alekseev061975@postgrespro.ru", "phone": "+70048093051"}
0005432529700	B6B1F8	9349 958512	ALEKSEY IVANOV	{"email": "aleksey.ivanov-041972@postgrespro.ru", "phone": "+70574630462"}
0005432529701	BF87DC	2721 269029	NIKOLAY PETROV	{"phone": "+70304513747"}
0005432529702	2A3A1B	2211 931651	OLGA VLASOVA	{"phone": "+70973313571"}
0005432529703	CB26F6	8031 245333	OLGA KOVALEVA	{"email": "kovalevaolga081982@postgrespro.ru", "phone": "+70837214457"}
0005432529704	CB26F6	5803 697164	EKATERINA KUZMINA	{"email": "e.kuzmina-091967@postgrespro.ru", "phone": "+70418907118"}
0005432529705	E18A38	9537 386254	NIKOLAY NOVIKOV	{"phone": "+70853548791"}
0005432529706	E94D97	7360 935880	VLADIMIR ILIN	{"email": "vladimir_ilin-04081966@postgrespro.ru", "phone": "+70044969583"}
0005432529707	856069	2235 397006	SERGEY ZAKHAROV	{"phone": "+70552441755"}
0005432529708	856069	8628 540164	VALENTINA MIKHAYLOVA	{"email": "v_mikhaylova-1975@postgrespro.ru", "phone": "+70989613722"}
0005432529709	02F40F	8668 423479	LIDIYA BORISOVA	{"email": "borisova-l_031966@postgrespro.ru", "phone": "+70915639554"}
0005432529710	60C638	3843 131079	VLADIMIR YAKOVLEV	{"phone": "+70267846341"}
0005432529711	46CAC6	6001 752287	VALERIY VOROBEV	{"phone": "+70436944086"}
0005432529712	F9425F	7930 437049	TATYANA VASILEVA	{"phone": "+70066032613"}
0005432529713	75BBE8	4628 053282	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr-16041969@postgrespro.ru", "phone": "+70722951880"}
0005432529714	E07800	1093 907455	EKATERINA KUZNECOVA	{"email": "kuznecova-e-061973@postgrespro.ru", "phone": "+70810660290"}
0005432529715	3D2446	5035 894711	NATALYA ILINA	{"email": "n.ilina_1967@postgrespro.ru", "phone": "+70462686836"}
0005432529716	3D2446	7316 782071	DMITRIY ZAKHAROV	{"email": "zakharov.dmitriy091978@postgrespro.ru", "phone": "+70757435095"}
0005432529717	F68755	6642 868250	ALEKSANDR DMITRIEV	{"phone": "+70364059150"}
0005432529718	F52E29	2055 869899	VLADIMIR SAVELEV	{"email": "v-savelev111973@postgrespro.ru", "phone": "+70184906130"}
0005432529719	F52E29	7944 567466	RASIM MAKAROV	{"phone": "+70179266685"}
0005432529720	F52E29	7366 691680	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova.071976@postgrespro.ru", "phone": "+70494959497"}
0005432529721	D86F52	9081 737409	ANDREY PAVLOV	{"email": "pavlov-a_061968@postgrespro.ru", "phone": "+70153955411"}
0005432529722	D86F52	7572 391579	VLADIMIR KONOVALOV	{"email": "vkonovalov13091974@postgrespro.ru", "phone": "+70652802658"}
0005432529723	7C2235	1292 913336	EKATERINA MOROZOVA	{"email": "e.morozova1956@postgrespro.ru", "phone": "+70006399313"}
0005432529724	7C2235	5627 017732	YURIY GORBUNOV	{"email": "yuriy-gorbunov.1981@postgrespro.ru", "phone": "+70261269477"}
0005432529725	B0B244	3248 460654	VYACHESLAV KUZMIN	{"email": "kuzminv.28031965@postgrespro.ru", "phone": "+70333045752"}
0005432529726	55C4BC	3513 211209	ALINA KARPOVA	{"email": "alina.karpova-09031970@postgrespro.ru", "phone": "+70643954194"}
0005432529727	AE5400	7194 359758	ELENA KAZAKOVA	{"phone": "+70032367872"}
0005432529728	834544	8032 929855	SERGEY MOISEEV	{"email": "moiseev.s_04121989@postgrespro.ru", "phone": "+70569698942"}
0005432529729	834544	9938 786621	SVETLANA BELYAEVA	{"email": "belyaeva_svetlana-051973@postgrespro.ru", "phone": "+70370352291"}
0005432529730	834544	3736 695220	DARYA SAVELEVA	{"email": "darya.saveleva_12111975@postgrespro.ru", "phone": "+70113523509"}
0005432529731	B1DC68	4163 810771	DMITRIY FROLOV	{"phone": "+70746292598"}
0005432529732	F8D8AF	8910 621174	IVAN STEPANOV	{"email": "stepanov_ivan031977@postgrespro.ru", "phone": "+70275982942"}
0005432529733	61C5CC	0441 636928	ALEKSANDR OSIPOV	{"phone": "+70006207335"}
0005432529734	61C5CC	3414 145312	ANNA IVANOVA	{"email": "anna.ivanova.1966@postgrespro.ru", "phone": "+70413214095"}
0005432529735	1F2499	2670 486031	NATALYA KOROLEVA	{"email": "natalya.koroleva.1972@postgrespro.ru", "phone": "+70075333923"}
0005432529736	763803	9794 790938	NIKITA ZAKHAROV	{"phone": "+70055479101"}
0005432529737	FCB224	6246 743567	NADEZHDA KOLESNIKOVA	{"phone": "+70524781869"}
0005432529738	161DD3	3803 040577	MARINA KOVALEVA	{"email": "kovalevam-31121975@postgrespro.ru", "phone": "+70835138764"}
0005432529739	0E66BB	4569 916596	RADIK MARTYNOV	{"phone": "+70744407647"}
0005432529740	1AE8DF	3293 892180	EVGENIY IVANOV	{"phone": "+70768402599"}
0005432529741	F718D5	7101 331096	ANDREY KARPOV	{"email": "karpov_andrey_1970@postgrespro.ru", "phone": "+70495390428"}
0005432529742	EA3154	9300 681720	YURIY ANDREEV	{"phone": "+70161922912"}
0005432529743	EA3154	6074 961094	DENIS FILIPPOV	{"email": "filippovdenis-1979@postgrespro.ru", "phone": "+70240957594"}
0005432529744	6157D1	8555 074680	OLEG SCHERBAKOV	{"phone": "+70458414681"}
0005432529745	A74E3B	3632 805121	VIKTOR KUZNECOV	{"phone": "+70234413498"}
0005432529746	A74E3B	4658 696042	VYACHESLAV NAUMOV	{"email": "v-naumov.1967@postgrespro.ru", "phone": "+70479872902"}
0005432529748	C7CDA9	0563 041183	RAMIL NAUMOV	{"email": "naumovramil.1971@postgrespro.ru", "phone": "+70257459107"}
0005432529749	562944	6787 759316	MIKHAIL SMIRNOV	{"phone": "+70235840207"}
0005432529750	562944	2025 001497	RAISA KUZNECOVA	{"phone": "+70252089187"}
0005432529751	DD05BA	5096 647911	VALENTINA BELYAEVA	{"email": "valentina-belyaeva-011962@postgrespro.ru", "phone": "+70869687522"}
0005432529752	12B5A5	4082 992613	ALEKSANDR GERASIMOV	{"phone": "+70041563173"}
0005432529753	415916	1971 558098	ELENA MAKSIMOVA	{"phone": "+70462136049"}
0005432529754	E79F88	0681 156080	NATALIYA MAKAROVA	{"email": "makarovanataliya-1965@postgrespro.ru", "phone": "+70788219873"}
0005432529755	E35CDE	3928 472792	VLADIMIR SIDOROV	{"email": "vsidorov-1982@postgrespro.ru", "phone": "+70031773794"}
0005432529756	ADAC97	3852 099072	LYUBOV MELNIKOVA	{"phone": "+70031459137"}
0005432529757	848231	7547 791293	OLGA PAVLOVA	{"email": "pavlova-o1972@postgrespro.ru", "phone": "+70951803506"}
0005432529758	848231	5982 917935	VLADIMIR VOROBEV	{"phone": "+70359414921"}
0005432529759	971628	1051 944359	MIKHAIL MEDVEDEV	{"email": "m.medvedev1976@postgrespro.ru", "phone": "+70763096503"}
0005432529760	981C50	5541 732721	VLADIMIR GERASIMOV	{"email": "gerasimovv-1988@postgrespro.ru", "phone": "+70799800546"}
0005432529761	512CF9	4194 598699	ANNA OSIPOVA	{"email": "annaosipova-1973@postgrespro.ru", "phone": "+70536264509"}
0005432529762	B2783A	8175 921625	DARYA ZAKHAROVA	{"email": "d.zakharova-111980@postgrespro.ru", "phone": "+70360430235"}
0005432529763	69BA2C	2346 774483	YURIY NIKITIN	{"phone": "+70350163060"}
0005432529764	21EFD7	4954 627122	RAUF OSIPOV	{"email": "osipovrauf-041973@postgrespro.ru", "phone": "+70452664770"}
0005432529765	21EFD7	3516 358982	NATALYA ZHUKOVA	{"email": "zhukova-natalya.031972@postgrespro.ru", "phone": "+70470752750"}
0005432529766	339A81	2208 467591	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey_14111976@postgrespro.ru", "phone": "+70971910396"}
0005432529767	C4C291	5305 113581	IRAIDA FILIPPOVA	{"email": "filippovairaida.1966@postgrespro.ru", "phone": "+70765178642"}
0005432529768	EA84BF	0903 591185	VLADISLAV FEDOROV	{"email": "fedorov-vladislav.1958@postgrespro.ru", "phone": "+70773952075"}
0005432529769	FF959B	1458 288079	SVETLANA MASLOVA	{"email": "smaslova1968@postgrespro.ru", "phone": "+70215665696"}
0005432529770	FF959B	6036 479957	VIKTOR NAUMOV	{"email": "viktornaumov_1971@postgrespro.ru", "phone": "+70346006471"}
0005432529771	80E3C2	5686 717987	VLADIMIR KUDRYASHOV	{"email": "kudryashov.v_25061965@postgrespro.ru", "phone": "+70579881815"}
0005432529772	EE0DEC	9615 038284	LYUDMILA KOROLEVA	{"phone": "+70439044547"}
0005432529773	8713DE	4987 799920	NATALYA MARTYNOVA	{"phone": "+70284588350"}
0005432529774	6957BC	6153 329076	ALBINA BELYAEVA	{"email": "belyaeva-albina011976@postgrespro.ru", "phone": "+70497956843"}
0005432529775	14DE64	7391 084120	ELENA ROMANOVA	{"phone": "+70783848989"}
0005432529776	01C551	9946 631897	OLGA POPOVA	{"phone": "+70540830210"}
0005432529777	01C551	2657 342518	EVGENIY MOISEEV	{"email": "moiseev_e-051987@postgrespro.ru", "phone": "+70841585428"}
0005432529778	07E7D3	6939 192483	SVETLANA TIMOFEEVA	{"email": "timofeeva_s111978@postgrespro.ru", "phone": "+70106281647"}
0005432529779	2B6C37	8050 613217	EGOR PETROV	{"phone": "+70872497665"}
0005432529780	70846B	7361 619868	VLADIMIR NIKOLAEV	{"email": "nikolaevv.101973@postgrespro.ru", "phone": "+70370509467"}
0005432529781	FD39C2	0996 902846	IVAN CHERNOV	{"email": "i-chernov.16101971@postgrespro.ru", "phone": "+70373805971"}
0005432529782	DD00B6	0312 017530	SERGEY IVANOV	{"email": "sergey-ivanov-111975@postgrespro.ru", "phone": "+70281906496"}
0005432529783	DD00B6	9710 976786	NATALIYA SOROKINA	{"email": "nataliya_sorokina_1954@postgrespro.ru", "phone": "+70875311101"}
0005432529784	639980	2940 969361	EGOR RODIONOV	{"email": "erodionov1970@postgrespro.ru", "phone": "+70934019321"}
0005432529785	639980	7929 655756	VIKTORIYA ALEKSANDROVA	{"email": "aleksandrova_v.1965@postgrespro.ru", "phone": "+70680861679"}
0005432529786	1ABEEC	1400 393316	EVGENIY TIMOFEEV	{"phone": "+70639686497"}
0005432529787	1ABEEC	0940 402208	ELENA TIKHONOVA	{"email": "tikhonova.e-111970@postgrespro.ru", "phone": "+70311524609"}
0005432529788	5ED0F4	3293 645231	ALEKSANDR KOZLOV	{"email": "kozlov_a.27091964@postgrespro.ru", "phone": "+70606630137"}
0005432529789	52E226	4171 558238	ANASTASIYA TITOVA	{"email": "titova-anastasiya-1969@postgrespro.ru", "phone": "+70615136472"}
0005432529790	99AD4B	2901 079346	ARTEM FROLOV	{"phone": "+70748502065"}
0005432529791	228A32	6681 310776	TAMARA IVANOVA	{"email": "ivanova-tamara-1979@postgrespro.ru", "phone": "+70852972476"}
0005432529792	60C081	9870 519064	GALINA KOROLEVA	{"phone": "+70540075345"}
0005432529793	B8A641	7257 874310	ELENA SAVELEVA	{"email": "elena.saveleva1978@postgrespro.ru", "phone": "+70594960874"}
0005432529794	BA4231	1286 653341	RENAT SHEVCHENKO	{"phone": "+70445216570"}
0005432529795	BA4231	9907 510830	NINA FROLOVA	{"phone": "+70410832565"}
0005432529796	9C40C6	1229 739045	VASILIY SEMENOV	{"email": "vasiliy.semenov_1970@postgrespro.ru", "phone": "+70703469110"}
0005432529797	F26916	3953 716704	SERGEY KUZNECOV	{"email": "kuznecov.sergey.14031954@postgrespro.ru", "phone": "+70990153429"}
0005432529798	72DE9D	5631 994275	ZLATA LEBEDEVA	{"phone": "+70877255233"}
0005432529799	72DE9D	9227 094141	ELENA DAVYDOVA	{"phone": "+70305724778"}
0005432529800	72DE9D	5132 805304	OKSANA SEMENOVA	{"email": "semenovao-1962@postgrespro.ru", "phone": "+70867228658"}
0005432529801	72DE9D	7001 223400	ALEKSANDR ALEKSEEV	{"email": "alekseev.a_23111971@postgrespro.ru", "phone": "+70066250311"}
0005432529802	CD9B0F	4584 245297	RENAT NIKITIN	{"email": "nikitin_r-27111963@postgrespro.ru", "phone": "+70105874288"}
0005432529803	CD9B0F	7343 723429	ANZHELA MOISEEVA	{"phone": "+70642171198"}
0005432529804	E46D0B	9657 382516	SOFIYA GRISHINA	{"email": "sofiya_grishina-1984@postgrespro.ru", "phone": "+70465764594"}
0005432529805	12DB4B	2740 995300	DARYA VLASOVA	{"email": "vlasova-darya.08031987@postgrespro.ru", "phone": "+70855892728"}
0005432529806	12DB4B	2099 715581	IVAN FROLOV	{"phone": "+70748976828"}
0005432529807	46233A	6882 838726	ILMIR ILIN	{"phone": "+70504556953"}
0005432529808	46233A	9514 694309	ALEKSANDR ANDREEV	{"phone": "+70327682415"}
0005432529809	46233A	7484 542598	NATALIYA KALININA	{"phone": "+70263664294"}
0005432529810	22F962	0295 346115	NIKOLAY SCHERBAKOV	{"phone": "+70653487438"}
0005432529811	22F962	0555 268645	ILSHAT MIRONOV	{"email": "ilshatmironov.101970@postgrespro.ru", "phone": "+70339653309"}
0005432529812	1C6989	5243 566685	EVGENIYA GRISHINA	{"phone": "+70753776029"}
0005432529813	1C6989	6003 581842	MARIYA CHERNOVA	{"email": "chernova_m.04111962@postgrespro.ru", "phone": "+70018869237"}
0005432529814	C00289	5309 472093	RAISA EFREMOVA	{"email": "efremova-r14041973@postgrespro.ru", "phone": "+70905792098"}
0005432529815	0E2A64	3690 840550	ANDREY SOROKIN	{"phone": "+70824803889"}
0005432529816	FEFF43	7705 360208	VALENTINA POPOVA	{"phone": "+70207323110"}
0005432529817	1AC96E	1317 692911	VALENTIN ANTONOV	{"phone": "+70430782899"}
0005432529818	8733C8	3291 414948	YANA SOKOLOVA	{"email": "y_sokolova1958@postgrespro.ru", "phone": "+70217678290"}
0005432529819	79ADC5	2567 420736	RAISA EGOROVA	{"phone": "+70346108382"}
0005432529820	79ADC5	1011 966144	SVETLANA MAKAROVA	{"phone": "+70193191377"}
0005432529821	18E5E4	5064 201083	SERGEY KUZMIN	{"email": "kuzminsergey_1979@postgrespro.ru", "phone": "+70489635105"}
0005432529822	6D1B11	1300 772137	ANASTASIYA NOVIKOVA	{"email": "novikovaanastasiya_06011972@postgrespro.ru", "phone": "+70678739374"}
0005432529823	02B008	4478 350085	DARYA DAVYDOVA	{"email": "davydova-darya.011974@postgrespro.ru", "phone": "+70847378042"}
0005432529824	813547	2678 795256	MARINA GUSEVA	{"email": "mguseva_27041974@postgrespro.ru", "phone": "+70660138944"}
0005432529825	D6FDD7	3083 483498	SERGEY SERGEEV	{"phone": "+70036960119"}
0005432529826	A1C73F	0582 116993	EGOR DMITRIEV	{"email": "dmitriev_e-061974@postgrespro.ru", "phone": "+70105129770"}
0005432529827	454837	1698 900940	SVETLANA KUDRYASHOVA	{"email": "kudryashovasvetlana-01101978@postgrespro.ru", "phone": "+70202840454"}
0005432529828	454837	1890 742091	ANTONINA NIKITINA	{"email": "a-nikitina.051971@postgrespro.ru", "phone": "+70683236088"}
0005432529829	676819	0007 143757	MAKSIM VOLKOV	{"email": "volkov.maksim-051965@postgrespro.ru", "phone": "+70975606623"}
0005432529830	36BF7B	4343 653549	DMITRIY ZHUKOV	{"phone": "+70463205499"}
0005432529831	36BF7B	5774 949065	ELENA DANILOVA	{"email": "e_danilova_02081974@postgrespro.ru", "phone": "+70237548136"}
0005432529832	DEAFA4	9908 976483	ALEKSANDR KAZAKOV	{"phone": "+70866895420"}
0005432529833	7934EF	5042 660201	VALERIY GORBUNOV	{"phone": "+70430322649"}
0005432529834	127D23	0410 334380	IVAN DENISOV	{"phone": "+70793033687"}
0005432529835	709479	7057 563051	LYUDMILA GUSEVA	{"email": "lyudmila-guseva_11021972@postgrespro.ru", "phone": "+70157176283"}
0005432529836	00D396	1925 823494	ANNA ANDREEVA	{"email": "annaandreeva011964@postgrespro.ru", "phone": "+70383506463"}
0005432529837	00D396	6240 417520	TATYANA PETROVA	{"email": "petrova_tatyana091974@postgrespro.ru", "phone": "+70711145131"}
0005432529838	80B3A1	5816 623040	ALEKSANDR GRIGOREV	{"phone": "+70433402438"}
0005432529839	80B3A1	9306 259485	RAISA SOROKINA	{"email": "r-sorokina_061966@postgrespro.ru", "phone": "+70949867172"}
0005432529840	FA1F3B	5949 444955	NADEZHDA KOLESNIKOVA	{"email": "kolesnikova_nadezhda.29011967@postgrespro.ru", "phone": "+70106690070"}
0005432529841	F416C0	6923 809779	ANTON VASILEV	{"phone": "+70831104126"}
0005432529842	F416C0	5801 328880	VLADIMIR BARANOV	{"phone": "+70184797791"}
0005432529843	D5B177	4872 811924	OLEG PETROV	{"email": "oleg-petrov-101974@postgrespro.ru", "phone": "+70835575794"}
0005432529844	D5B177	5296 763940	EVGENIY TIKHONOV	{"email": "evgeniy-tikhonov-29041969@postgrespro.ru", "phone": "+70286347442"}
0005432529845	F86B5A	7820 904460	OLGA SERGEEVA	{"phone": "+70917511787"}
0005432529846	DA6EA6	7434 132101	SANIYA MATVEEVA	{"email": "matveeva-s1958@postgrespro.ru", "phone": "+70613787507"}
0005432529847	F0BEE1	8937 599533	VADIM SOLOVEV	{"phone": "+70942361984"}
0005432529848	F0BEE1	8940 422113	ANTONINA VASILEVA	{"phone": "+70114602613"}
0005432529849	6FB35B	8768 800604	RAISA SCHERBAKOVA	{"email": "raisascherbakova-1976@postgrespro.ru", "phone": "+70627653341"}
0005432529850	CBC75D	0496 241473	VIKTORIYA STEPANOVA	{"email": "stepanova.v28071957@postgrespro.ru", "phone": "+70188578072"}
0005432529851	5E26D2	2306 594419	RAISA KRASNOVA	{"email": "krasnova.r_081970@postgrespro.ru", "phone": "+70050735334"}
0005432529852	A98783	1393 339158	VERA PETROVA	{"email": "vera-petrova.1960@postgrespro.ru", "phone": "+70263423448"}
0005432529853	10D96E	4769 948275	NADEZHDA KULIKOVA	{"phone": "+70714888732"}
0005432529854	BF7942	8291 722201	OKSANA MELNIKOVA	{"email": "melnikova.oksana.06041968@postgrespro.ru", "phone": "+70371401273"}
0005432529855	46704D	5242 130979	OKSANA SEMENOVA	{"phone": "+70646480790"}
0005432529856	46704D	3288 580891	LIDIYA BOGDANOVA	{"email": "bogdanova-l07061979@postgrespro.ru", "phone": "+70498412026"}
0005432529857	AC85AD	5606 205195	NINA POPOVA	{"phone": "+70552558789"}
0005432529858	27E371	8552 407804	ELENA KOROLEVA	{"phone": "+70560798066"}
0005432529859	C5B493	2177 911260	ANASTASIYA KUZMINA	{"email": "a-kuzmina-011983@postgrespro.ru", "phone": "+70020798228"}
0005432529860	A40BC8	8972 579585	ALEKSANDR SERGEEV	{"phone": "+70326295438"}
0005432529861	E8B8B3	0452 324595	RUSLAN NOVIKOV	{"email": "r-novikov.1971@postgrespro.ru", "phone": "+70025500741"}
0005432529862	F25DD0	5444 203605	YULIYA SOKOLOVA	{"phone": "+70639369000"}
0005432529863	518C61	4735 543566	ALEKSEY KAZAKOV	{"email": "kazakov-a.21091971@postgrespro.ru", "phone": "+70983247255"}
0005432529864	12C997	9972 071222	TAMARA ANDREEVA	{"email": "tamaraandreeva20011981@postgrespro.ru", "phone": "+70793765935"}
0005432529865	B8334F	3564 845302	NATALYA KALININA	{"email": "natalyakalinina-19031965@postgrespro.ru", "phone": "+70378003967"}
0005432529866	B8334F	0519 601943	DMITRIY SMIRNOV	{"phone": "+70604043721"}
0005432529867	B8334F	6763 107040	ANNA KOROLEVA	{"phone": "+70094897477"}
0005432529868	28C12F	1930 377661	RIMMA AFANASEVA	{"email": "rimma-afanaseva_1985@postgrespro.ru", "phone": "+70447695955"}
0005432529869	28C12F	6142 635572	POLINA BELYAEVA	{"phone": "+70283303563"}
0005432529870	E66EF1	0844 335174	ANATOLIY MARTYNOV	{"phone": "+70015055143"}
0005432529871	225D1F	7692 903562	ALEKSANDR NOVIKOV	{"phone": "+70422542064"}
0005432529872	225D1F	3602 257166	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.1963@postgrespro.ru", "phone": "+70852082900"}
0005432529873	18E88D	2250 282648	ELIZAVETA KOZLOVA	{"phone": "+70027166136"}
0005432529874	07852F	6836 411428	VALENTIN GUSEV	{"phone": "+70663687336"}
0005432529875	C4B82B	2838 014310	OLGA YAKOVLEVA	{"phone": "+70702432285"}
0005432529876	4A31E6	3493 552149	TATYANA MALYSHEVA	{"phone": "+70062046579"}
0005432529877	C76078	1547 075040	OLGA MOROZOVA	{"email": "o-morozova.16091968@postgrespro.ru", "phone": "+70805219888"}
0005432529878	C76078	2591 795083	YANA DANILOVA	{"email": "y-danilova121963@postgrespro.ru", "phone": "+70442828871"}
0005432529879	369860	5930 392058	OKSANA MALYSHEVA	{"email": "malyshevao20081965@postgrespro.ru", "phone": "+70230515150"}
0005432529880	369860	0627 454779	ILYA KOZLOV	{"email": "ilyakozlov20111966@postgrespro.ru", "phone": "+70196349539"}
0005432529881	09384A	6391 687517	MAKSIM ZAKHAROV	{"email": "zakharovmaksim1973@postgrespro.ru", "phone": "+70019795917"}
0005432529882	B19EED	7957 158570	PRASKOVYA TITOVA	{"email": "titova.p_17061967@postgrespro.ru", "phone": "+70863611945"}
0005432529883	6D7400	0322 966219	NINA RYABOVA	{"phone": "+70324793159"}
0005432529884	7B348F	2812 018779	VLADIMIR VOLKOV	{"email": "vladimir.volkov-1978@postgrespro.ru", "phone": "+70587108515"}
0005432529885	7824DC	9837 469152	PLATON GORBUNOV	{"phone": "+70975888881"}
0005432529886	10065A	3507 839562	ALEKSEY FEDOROV	{"email": "fedorov.a.25051980@postgrespro.ru", "phone": "+70114813224"}
0005432529887	10065A	1205 359814	ROMAN VLASOV	{"phone": "+70897749062"}
0005432529888	2A48C7	0370 548795	LARISA POPOVA	{"email": "l_popova.1970@postgrespro.ru", "phone": "+70068389691"}
0005432529889	E7DC69	7768 593653	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov1970@postgrespro.ru", "phone": "+70671541532"}
0005432529890	BAA1D8	5393 697262	TATYANA POPOVA	{"email": "popova_t.1975@postgrespro.ru", "phone": "+70448322926"}
0005432529891	F23137	6454 342580	ALEKSANDR KOROLEV	{"phone": "+70228587831"}
0005432529892	515B74	9783 757807	EKATERINA SOKOLOVA	{"phone": "+70504083374"}
0005432529893	4E52EA	6580 270396	NADEZHDA PETROVA	{"email": "petrova-nadezhda-1980@postgrespro.ru", "phone": "+70026781350"}
0005432529894	E81C9A	1368 220013	TATYANA ZAKHAROVA	{"email": "zakharova-t_091973@postgrespro.ru", "phone": "+70134359722"}
0005432529895	E81C9A	7441 242157	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr.031965@postgrespro.ru", "phone": "+70589203748"}
0005432529896	8A0882	1392 403334	DARYA BORISOVA	{"phone": "+70263913566"}
0005432529897	848BCA	4752 495616	ANASTASIYA PAVLOVA	{"phone": "+70810971316"}
0005432529898	848BCA	9552 732052	PAVEL ILIN	{"phone": "+70106017366"}
0005432529899	848BCA	9547 003727	ANNA SIDOROVA	{"phone": "+70396573316"}
0005432529900	8CC251	6448 210020	TATYANA NAUMOVA	{"phone": "+70214244043"}
0005432529901	4FC985	8688 701798	OLGA TROFIMOVA	{"email": "trofimova.o1974@postgrespro.ru", "phone": "+70959106049"}
0005432529902	051128	7038 584802	GALINA SMIRNOVA	{"phone": "+70437444829"}
0005432529903	B858D5	1977 002430	VYACHESLAV TIKHONOV	{"email": "v.tikhonov1971@postgrespro.ru", "phone": "+70005194155"}
0005432529904	E4F857	6009 145390	ALEKSANDR IVANOV	{"email": "aleksandrivanov-1972@postgrespro.ru", "phone": "+70390746008"}
0005432529905	2F1459	2958 614175	TAMARA VOLKOVA	{"email": "volkova_t.1966@postgrespro.ru", "phone": "+70412794658"}
0005432529906	CFB5E1	8804 212297	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-1964@postgrespro.ru", "phone": "+70612996164"}
0005432529907	04E19E	3685 419961	MARINA BELYAEVA	{"phone": "+70127594819"}
0005432529908	A889AB	9714 286027	NATALYA LUKYANOVA	{"email": "n.lukyanova_1974@postgrespro.ru", "phone": "+70659820823"}
0005432529909	42E92F	3444 881281	ALEKSANDR ALEKSEEV	{"phone": "+70532015920"}
0005432529910	42E92F	6171 774066	NATALYA GORBUNOVA	{"phone": "+70674525633"}
0005432529911	42E92F	6100 319982	VALENTINA KUZMINA	{"email": "kuzminavalentina_1966@postgrespro.ru", "phone": "+70125072280"}
0005432529912	332791	8073 935970	SOFYA SEMENOVA	{"email": "semenova-s.03121966@postgrespro.ru", "phone": "+70635254195"}
0005432529913	332791	8454 137170	VASILIY FILIPPOV	{"phone": "+70524039917"}
0005432529914	F38B2E	0632 966643	LYUDMILA IVANOVA	{"email": "ivanova.l1961@postgrespro.ru", "phone": "+70166522061"}
0005432529915	10A9F5	0072 803200	GENNADIY ANDREEV	{"email": "andreev_gennadiy_29041981@postgrespro.ru", "phone": "+70460361363"}
0005432529916	ADE84A	0320 917565	VLADIMIR DAVYDOV	{"email": "v-davydov_30101974@postgrespro.ru", "phone": "+70859659683"}
0005432529917	ADE84A	6276 858426	LYUDMILA SOROKINA	{"phone": "+70850349537"}
0005432529918	420605	2195 028957	ELENA TIKHONOVA	{"email": "tikhonovae.1962@postgrespro.ru", "phone": "+70144486695"}
0005432529919	420605	8535 848114	OLGA DAVYDOVA	{"email": "olga_davydova.1964@postgrespro.ru", "phone": "+70725685621"}
0005432529920	6E0C75	6035 451789	VIKTOR MEDVEDEV	{"phone": "+70236444802"}
0005432529921	6E0C75	6305 664639	ARTUR KUZMIN	{"email": "kuzmin-a1963@postgrespro.ru", "phone": "+70352180238"}
0005432529922	291D93	4640 903939	EKATERINA IVANOVA	{"email": "e-ivanova.1972@postgrespro.ru", "phone": "+70743266927"}
0005432529923	83FA9F	3608 721747	VALENTINA ROMANOVA	{"phone": "+70643752883"}
0005432529924	8EC636	0976 355623	TATYANA LUKYANOVA	{"phone": "+70879387613"}
0005432529925	8EC636	5161 334331	EVGENIY NAUMOV	{"phone": "+70326357715"}
0005432529926	ECACEA	5163 813515	VYACHESLAV SHEVCHENKO	{"email": "vyacheslav-shevchenko_041972@postgrespro.ru", "phone": "+70459562265"}
0005432529927	40F611	8734 802203	ALEKSANDR TIKHONOV	{"phone": "+70797073011"}
0005432529928	CA8D91	5031 902631	ELENA LAZAREVA	{"phone": "+70766833912"}
0005432529929	206227	8880 083757	KIRILL YAKOVLEV	{"email": "yakovlev_k091967@postgrespro.ru", "phone": "+70511788425"}
0005432529930	206227	8244 634310	OLGA TARASOVA	{"email": "olgatarasova_1971@postgrespro.ru", "phone": "+70263762007"}
0005432529931	6A7490	6739 662787	KRISTINA SOROKINA	{"phone": "+70290303845"}
0005432529932	2EE656	1703 371977	NATALYA GERASIMOVA	{"phone": "+70860310387"}
0005432529933	1A566B	7392 628757	SERGEY KISELEV	{"email": "s.kiselev_041971@postgrespro.ru", "phone": "+70338363261"}
0005432529934	1A566B	3504 416283	VLADIMIR NOVIKOV	{"email": "novikov.v-1980@postgrespro.ru", "phone": "+70119327283"}
0005432529935	C1C975	5749 778179	ANDREY KUZNECOV	{"phone": "+70813225275"}
0005432529936	C1C975	6994 283290	VASILISA POPOVA	{"email": "popova.vasilisa061975@postgrespro.ru", "phone": "+70728287151"}
0005432529937	C1C975	5516 258731	FEDOR IVANOV	{"email": "ivanovfedor.01061978@postgrespro.ru", "phone": "+70310605826"}
0005432529938	971AFD	9069 600236	STANISLAV FEDOROV	{"email": "sfedorov-17031956@postgrespro.ru", "phone": "+70657927580"}
0005432529939	971AFD	8238 920675	IVAN SERGEEV	{"email": "sergeev.ivan_30121977@postgrespro.ru", "phone": "+70049771812"}
0005432529940	21C017	4628 474487	ANATOLIY SMIRNOV	{"phone": "+70560624200"}
0005432529941	08C821	8235 503632	VLADIMIR SERGEEV	{"email": "sergeev-vladimir-031982@postgrespro.ru", "phone": "+70522007697"}
0005432529942	08C821	8591 033604	LARISA MEDVEDEVA	{"email": "medvedeva.l1962@postgrespro.ru", "phone": "+70087983973"}
0005432529943	08C821	8244 485388	LYUDMILA NOVIKOVA	{"email": "novikova.lyudmila_1986@postgrespro.ru", "phone": "+70660713654"}
0005432529944	2283A7	5320 098230	DMITRIY ANDREEV	{"email": "andreev_d-101977@postgrespro.ru", "phone": "+70237182772"}
0005432529945	C6B074	5454 947931	ANNA OSIPOVA	{"phone": "+70121811709"}
0005432529946	C6B074	9620 584004	ARTEM NAZAROV	{"email": "nazarovartem1968@postgrespro.ru", "phone": "+70628245627"}
0005432529947	F72F8D	8869 668437	VASILIY IVANOV	{"email": "v_ivanov.071963@postgrespro.ru", "phone": "+70167047798"}
0005432529948	00D984	0913 553585	GALINA ZHUKOVA	{"phone": "+70592398201"}
0005432529949	6A2109	4391 116991	ALEKSEY CHERNOV	{"phone": "+70566389295"}
0005432529950	ACF384	7459 249355	PAVEL KUZNECOV	{"email": "pkuznecov111990@postgrespro.ru", "phone": "+70846480009"}
0005432529951	FFC069	0188 644266	TATYANA ANDREEVA	{"phone": "+70994838634"}
0005432529952	439B65	6150 373545	ALEKSANDR ILIN	{"phone": "+70753352029"}
0005432529953	439B65	7881 405957	LIDIYA DMITRIEVA	{"phone": "+70828008461"}
0005432529954	353061	6773 429463	ALEKSANDR SAVELEV	{"email": "asavelev.21061972@postgrespro.ru", "phone": "+70418928726"}
0005432529955	353061	0602 088167	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova081988@postgrespro.ru", "phone": "+70812630298"}
0005432529956	353061	8256 443751	MIKHAIL KUZNECOV	{"phone": "+70768559146"}
0005432529957	E99A06	5053 267140	OLESYA NIKIFOROVA	{"phone": "+70071913399"}
0005432529958	598273	0860 105285	ANASTASIYA BOGDANOVA	{"email": "bogdanova-a.1961@postgrespro.ru", "phone": "+70729355475"}
0005432529959	7AEE21	5085 706777	ANZHELIKA MARTYNOVA	{"email": "anzhelika.martynova_31081980@postgrespro.ru", "phone": "+70494094997"}
0005432529960	7AEE21	7420 389756	VALENTINA SEMENOVA	{"email": "semenovavalentina111971@postgrespro.ru", "phone": "+70304732836"}
0005432529961	1FAEEF	9584 212637	TIMUR NOVIKOV	{"email": "novikovtimur.1960@postgrespro.ru", "phone": "+70705492403"}
0005432529962	160075	0122 754222	VIKTORIYA BELOVA	{"email": "belova.viktoriya-14061977@postgrespro.ru", "phone": "+70015135189"}
0005432529963	481EDE	5239 038134	ALEKSANDR IVANOV	{"email": "ivanov_a-041973@postgrespro.ru", "phone": "+70076906068"}
0005432529964	5AD9ED	6169 055231	NIKOLAY RODIONOV	{"email": "rodionov_nikolay.1953@postgrespro.ru", "phone": "+70046859937"}
0005432529965	786FB7	3653 144912	VLADIMIR SMIRNOV	{"email": "v_smirnov.021976@postgrespro.ru", "phone": "+70628262342"}
0005432529966	80B51A	7571 352963	DMITRIY KARPOV	{"email": "karpov.dmitriy.121975@postgrespro.ru", "phone": "+70736418822"}
0005432529967	498431	1734 819682	ALEKSEY TIKHONOV	{"phone": "+70453351771"}
0005432529968	1A41C4	4149 776566	ANASTASIYA TITOVA	{"phone": "+70145155186"}
0005432529969	DEF1E0	7387 796541	ARTEM MAKAROV	{"email": "a_makarov051974@postgrespro.ru", "phone": "+70454407269"}
0005432529970	DEF1E0	9718 798946	ALEKSANDR PETROV	{"email": "petrov_aleksandr.23081971@postgrespro.ru", "phone": "+70399848665"}
0005432529971	355972	5744 836354	NATALYA KUDRYASHOVA	{"email": "kudryashova-n-29061968@postgrespro.ru", "phone": "+70092451546"}
0005432529972	355972	5316 195293	ANASTASIYA DENISOVA	{"phone": "+70227927719"}
0005432529973	DDB68C	4794 486205	SERGEY MIKHAYLOV	{"email": "mikhaylov-sergey28021982@postgrespro.ru", "phone": "+70258938068"}
0005432529974	736C86	0139 702360	ELENA KAZAKOVA	{"email": "elena.kazakova.121981@postgrespro.ru", "phone": "+70363635160"}
0005432529975	736C86	7818 374286	IRINA MAKAROVA	{"email": "irina.makarova-1955@postgrespro.ru", "phone": "+70899355740"}
0005432529976	736C86	6126 191070	VIKTOR GAVRILOV	{"email": "gavrilovv13071979@postgrespro.ru", "phone": "+70178748611"}
0005432529977	736C86	1864 121245	EVGENIY SAVELEV	{"email": "evgeniy.savelev.03021964@postgrespro.ru", "phone": "+70110111500"}
0005432529978	4F8998	2448 014472	NIKOLAY SOKOLOV	{"email": "n_sokolov-021972@postgrespro.ru", "phone": "+70510165233"}
0005432529979	BBB7A0	7124 689136	MARIYA SOROKINA	{"phone": "+70277785303"}
0005432529980	1D6A21	1393 060091	LIDIYA ANTONOVA	{"phone": "+70562530989"}
0005432529981	4FCA10	3570 986011	DANIIL DMITRIEV	{"phone": "+70411258896"}
0005432529982	20E78D	3197 889957	ALEKSANDR FROLOV	{"phone": "+70746867527"}
0005432529983	EB6826	5818 087138	VIKTOR YAKOVLEV	{"phone": "+70782827403"}
0005432529984	D8A2EB	9202 844483	NATALYA ZAKHAROVA	{"email": "n_zakharova1968@postgrespro.ru", "phone": "+70467177753"}
0005432529985	8F097D	2965 332418	SVETLANA KOMAROVA	{"phone": "+70619732760"}
0005432529986	8F097D	6829 315341	VYACHESLAV GERASIMOV	{"email": "gerasimov_vyacheslav_041981@postgrespro.ru", "phone": "+70839886069"}
0005432529987	5283A2	8353 461395	SVETLANA ALEKSEEVA	{"phone": "+70004546870"}
0005432529988	5283A2	5187 401804	KRISTINA KULIKOVA	{"phone": "+70628645062"}
0005432529989	0033A2	3338 472793	ANASTASIYA SIDOROVA	{"phone": "+70959245777"}
0005432529990	0033A2	2376 527742	ANASTASIYA VOLKOVA	{"phone": "+70694060210"}
0005432529991	B7BF82	3797 861987	EVGENIY SIDOROV	{"email": "sidorove-23031986@postgrespro.ru", "phone": "+70341643370"}
0005432529992	B7BF82	2252 354817	ALEKSEY VLASOV	{"phone": "+70276499206"}
0005432529993	C514E2	1831 463329	IGOR STEPANOV	{"email": "stepanov-i.051979@postgrespro.ru", "phone": "+70942623642"}
0005432529994	F29CC8	7654 894664	PRASKOVYA OVCHINNIKOVA	{"phone": "+70759464921"}
0005432529995	50CF08	3740 199864	YURIY ZHURAVLEV	{"phone": "+70629210253"}
0005432529996	50CF08	4648 845947	RUSLAN NOVIKOV	{"email": "ruslan_novikov_111974@postgrespro.ru", "phone": "+70455798394"}
0005432529997	1E4284	9030 845877	SERGEY DENISOV	{"phone": "+70714131444"}
0005432529998	0008F4	6872 995157	YULIYA CHERNOVA	{"phone": "+70449972365"}
0005432529999	654515	8993 944221	ELENA MIKHAYLOVA	{"phone": "+70245629041"}
0005432530000	654515	0867 325603	NADEZHDA ALEKSANDROVA	{"email": "n.aleksandrova.1974@postgrespro.ru", "phone": "+70104619284"}
0005432530001	F8B21F	5813 107434	ANNA NIKITINA	{"email": "nikitinaanna1970@postgrespro.ru", "phone": "+70468321934"}
0005432530002	209D43	7927 816632	GENNADIY FROLOV	{"email": "frolovg_1971@postgrespro.ru", "phone": "+70259158910"}
0005432530003	209D43	3499 411005	NINA MOISEEVA	{"phone": "+70405248280"}
0005432530004	7A9057	1785 846214	TATYANA NOVIKOVA	{"email": "novikovat.1973@postgrespro.ru", "phone": "+70927538394"}
0005432530005	7A9057	2728 568048	ALEKSEY MAKAROV	{"phone": "+70049019485"}
0005432530006	BB6215	1332 675043	RAFIK KISELEV	{"phone": "+70926511703"}
0005432530007	BB6215	7299 390275	DENIS IVANOV	{"email": "denis.ivanov.1969@postgrespro.ru", "phone": "+70413865923"}
0005432530008	43005D	1506 915600	VYACHESLAV ZHURAVLEV	{"phone": "+70702298922"}
0005432530009	43005D	1047 001654	DMITRIY FEDOTOV	{"phone": "+70472775816"}
0005432530010	4B2E24	7918 532015	SERGEY PAVLOV	{"email": "sergeypavlov15121967@postgrespro.ru", "phone": "+70371264145"}
0005432530011	4B2E24	0781 104122	ELLA ERMAKOVA	{"email": "ella_ermakova-31121970@postgrespro.ru", "phone": "+70278200307"}
0005432530012	BF802A	2567 598423	ROMAN VLASOV	{"phone": "+70805581890"}
0005432530013	861752	9392 702628	VYACHESLAV ZAKHAROV	{"email": "zakharov.vyacheslav-1970@postgrespro.ru", "phone": "+70571613803"}
0005432530014	861752	0571 638178	GALINA SEMENOVA	{"phone": "+70031811001"}
0005432530015	CBF337	8184 228423	ALEKSANDR PETROV	{"phone": "+70520660857"}
0005432530016	751096	9536 876916	OLGA ORLOVA	{"phone": "+70699866498"}
0005432530017	2A21C2	1230 878479	NADEZHDA KUZNECOVA	{"phone": "+70824633295"}
0005432530018	3A4F21	4600 852770	LYUBOV GUSEVA	{"email": "guseva-l_1967@postgrespro.ru", "phone": "+70038702366"}
0005432530019	2CFF87	8433 831785	LYUDMILA NAZAROVA	{"email": "l_nazarova_011968@postgrespro.ru", "phone": "+70817454722"}
0005432530020	2CFF87	5175 874956	ELENA MIKHAYLOVA	{"email": "mikhaylova_e071980@postgrespro.ru", "phone": "+70419233203"}
0005432530021	B0F099	8259 546721	LYUBOV EFIMOVA	{"email": "lyubov-efimova_1962@postgrespro.ru", "phone": "+70701598832"}
0005432530022	1F3496	4870 949658	EVGENIYA ALEKSEEVA	{"phone": "+70177082040"}
0005432530023	1F3496	6036 854081	MARIYA SCHERBAKOVA	{"email": "m_scherbakova-1971@postgrespro.ru", "phone": "+70777783944"}
0005432530024	4F4832	7735 913865	MARIYA CHERNOVA	{"phone": "+70661444865"}
0005432530025	E2F241	4025 616026	OLGA NIKIFOROVA	{"phone": "+70369405038"}
0005432530026	3FEEA9	9237 828451	ALEKSANDRA RODIONOVA	{"phone": "+70800242228"}
0005432530027	D13DC7	9345 529167	ELENA KOZLOVA	{"email": "kozlovaelena_091970@postgrespro.ru", "phone": "+70755647399"}
0005432530028	8B65EF	6865 586244	TIGRAN MAKSIMOV	{"email": "maksimov-t-1970@postgrespro.ru", "phone": "+70266628212"}
0005432530029	3BF00D	1912 397218	RAISA STEPANOVA	{"email": "stepanova_r-08041970@postgrespro.ru", "phone": "+70911283495"}
0005432530030	1A5247	4759 158455	ALEKSEY PETROV	{"phone": "+70233755059"}
0005432530031	0B6002	7398 966388	VERONIKA EGOROVA	{"email": "egorova-v.24111982@postgrespro.ru", "phone": "+70614806242"}
0005432530032	B76A65	2147 383941	ELENA SOROKINA	{"email": "sorokina-e19111980@postgrespro.ru", "phone": "+70813041134"}
0005432530033	C0483B	4130 674707	ALEKSEY NAZAROV	{"email": "nazarov_a.111976@postgrespro.ru", "phone": "+70004567891"}
0005432530034	EE4C83	0215 887536	VLADIMIR FROLOV	{"phone": "+70899590538"}
0005432530035	ADAEA0	7645 606518	IVAN KUZNECOV	{"email": "kuznecovivan1987@postgrespro.ru", "phone": "+70083011925"}
0005432530036	D36A5C	6811 965807	MIKHAIL KUZNECOV	{"email": "m_kuznecov.09021976@postgrespro.ru", "phone": "+70320276286"}
0005432530037	866D78	0412 364669	TATYANA KRASNOVA	{"email": "krasnova.t_021973@postgrespro.ru", "phone": "+70347608124"}
0005432530038	866D78	1535 576910	AZAT ZHURAVLEV	{"phone": "+70893492737"}
0005432530039	866D78	2688 975475	ELENA POPOVA	{"phone": "+70939509535"}
0005432530040	142190	5262 276300	VLADIMIR KUZMIN	{"email": "kuzminv.1964@postgrespro.ru", "phone": "+70683928766"}
0005432530041	142190	3481 782662	VERA KOVALEVA	{"email": "v_kovaleva.1965@postgrespro.ru", "phone": "+70483660576"}
0005432530042	FF63B0	3791 223250	OLGA IVANOVA	{"email": "ivanova_o-111977@postgrespro.ru", "phone": "+70695374027"}
0005432530043	258319	5061 614273	MARIYA LUKYANOVA	{"email": "m-lukyanova-101975@postgrespro.ru", "phone": "+70260698545"}
0005432530044	B7EE97	5038 028087	VASILIY IVANOV	{"email": "vivanov-1965@postgrespro.ru", "phone": "+70649608044"}
0005432530045	9B6874	5868 427798	TATYANA BORISOVA	{"email": "t-borisova21101976@postgrespro.ru", "phone": "+70866957519"}
0005432530046	9B6874	4783 519878	SOFYA SIDOROVA	{"email": "sidorovas.1977@postgrespro.ru", "phone": "+70071968336"}
0005432530047	3FFD4B	0953 750655	SERGEY BARANOV	{"email": "sergey_baranov-1966@postgrespro.ru", "phone": "+70065335441"}
0005432530048	033FBE	0309 773388	SERGEY SIDOROV	{"phone": "+70882942657"}
0005432530049	E97D8B	1474 865912	IRINA ZHUKOVA	{"email": "i_zhukova1965@postgrespro.ru", "phone": "+70773126903"}
0005432530050	A64E3C	0874 757680	IVAN ABRAMOV	{"email": "abramov-ivan_021976@postgrespro.ru", "phone": "+70241221105"}
0005432530051	377151	1880 762864	TATYANA AFANASEVA	{"email": "afanaseva_t02121973@postgrespro.ru", "phone": "+70381350001"}
0005432530052	377151	6940 287168	ANGELINA KUZNECOVA	{"phone": "+70271616869"}
0005432530053	DF3EF0	8801 513347	OLESYA FOMINA	{"email": "fomina_olesya12051975@postgrespro.ru", "phone": "+70448323560"}
0005432530054	55BFF8	1058 430883	ANDREY ANTONOV	{"email": "aantonov.041971@postgrespro.ru", "phone": "+70273686009"}
0005432530055	38BAEE	1653 282593	RAISA ABRAMOVA	{"email": "r_abramova-22081971@postgrespro.ru", "phone": "+70406412845"}
0005432530056	D025FF	9659 088403	OLGA BELOVA	{"email": "o_belova.13051978@postgrespro.ru", "phone": "+70649368154"}
0005432530057	47AD36	4177 903396	IRINA KRASNOVA	{"email": "irina.krasnova061977@postgrespro.ru", "phone": "+70418329260"}
0005432530058	CA44A5	0799 940096	YULIYA IVANOVA	{"email": "ivanova_yuliya121978@postgrespro.ru", "phone": "+70963473063"}
0005432530059	CA44A5	8796 043800	VERA IVANOVA	{"email": "ivanovavera.18041968@postgrespro.ru", "phone": "+70167072279"}
0005432530060	D11586	9384 022017	VITALIY ILIN	{"email": "v.ilin27021960@postgrespro.ru", "phone": "+70439151853"}
0005432530061	F34357	7556 075117	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev1966@postgrespro.ru", "phone": "+70944089093"}
0005432530062	5D5138	4407 842120	VLADIMIR ZAYCEV	{"phone": "+70901821242"}
0005432530063	5D5138	4301 127072	IRINA SAVELEVA	{"phone": "+70255434726"}
0005432530064	8E6C37	6984 099666	IGOR SHEVCHENKO	{"phone": "+70965434671"}
0005432530065	8E6C37	0045 900831	VYACHESLAV ZAKHAROV	{"phone": "+70462083345"}
0005432530066	83908C	6703 188657	OLGA DENISOVA	{"email": "denisovao_1976@postgrespro.ru", "phone": "+70892617994"}
0005432530067	1909FD	6099 849913	VYACHESLAV KRASNOV	{"email": "v.krasnov-071975@postgrespro.ru", "phone": "+70022401100"}
0005432530068	6DE053	4440 568447	GALINA NESTEROVA	{"phone": "+70895251298"}
0005432530069	394248	7674 415601	ANATOLIY FOMIN	{"phone": "+70460562542"}
0005432530070	2BFC09	1474 903172	NIKOLAY MAKSIMOV	{"phone": "+70305011218"}
0005432530071	DF1B83	3385 346818	ANDREY PAVLOV	{"email": "a.pavlov.18121978@postgrespro.ru", "phone": "+70904636778"}
0005432530072	D1A6A9	0497 270237	IVAN MIRONOV	{"phone": "+70970136112"}
0005432530073	32E718	1938 215086	ELENA FEDOROVA	{"email": "e_fedorova-29071975@postgrespro.ru", "phone": "+70406412734"}
0005432530074	1867A9	8491 916401	EKATERINA SIDOROVA	{"phone": "+70385412993"}
0005432530075	BCA5B8	9029 378681	ANDREY SOROKIN	{"email": "asorokin1970@postgrespro.ru", "phone": "+70732098950"}
0005432530076	6EC0A0	9235 344290	NATALYA DENISOVA	{"phone": "+70803344172"}
0005432530077	4F7116	5461 482158	VALENTINA ALEKSANDROVA	{"phone": "+70668974576"}
0005432530078	163AB2	5209 153956	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov_1979@postgrespro.ru", "phone": "+70090683988"}
0005432530079	163AB2	0906 601944	EKATERINA KOZLOVA	{"phone": "+70203224149"}
0005432530080	163AB2	9691 121419	ALEKSANDR NIKOLAEV	{"phone": "+70439479812"}
0005432530136	755C6D	0784 806386	LIDIYA NIKITINA	{"phone": "+70793101001"}
0005432530081	7C3CA6	2729 724393	LEONID MIRONOV	{"email": "leonid.mironov.01091959@postgrespro.ru", "phone": "+70704229594"}
0005432530082	7C3CA6	6570 797137	KONSTANTIN NIKOLAEV	{"email": "k-nikolaev041976@postgrespro.ru", "phone": "+70040976319"}
0005432530083	8DA8FE	9013 914107	LARISA NESTEROVA	{"phone": "+70845066358"}
0005432530084	9B3EA5	1457 397977	TATYANA MOROZOVA	{"email": "t.morozova.1968@postgrespro.ru", "phone": "+70610385311"}
0005432530085	9B3EA5	5613 314871	OLEG ILIN	{"phone": "+70137647860"}
0005432530086	1D63CC	3511 699858	EVGENIY OSIPOV	{"email": "osipov_e-13031981@postgrespro.ru", "phone": "+70959715403"}
0005432530087	27DFE5	1251 139425	IRINA STEPANOVA	{"phone": "+70476845230"}
0005432530088	626692	8084 925804	ANVAR MIKHAYLOV	{"email": "mikhaylov_a.021975@postgrespro.ru", "phone": "+70400821321"}
0005432530089	402CFA	3752 482549	ZINAIDA NAZAROVA	{"phone": "+70175952193"}
0005432530090	CCD9C6	3267 980885	DMITRIY IVANOV	{"phone": "+70771021375"}
0005432530091	C77808	8446 389168	TATYANA RODIONOVA	{"phone": "+70011687480"}
0005432530092	D86123	2077 070032	ARTUR MIKHAYLOV	{"phone": "+70690532296"}
0005432530093	B3D16E	7857 090312	LYUDMILA SEMENOVA	{"email": "semenova_l.14121978@postgrespro.ru", "phone": "+70108778590"}
0005432530094	42CD7C	6491 075202	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev.1967@postgrespro.ru", "phone": "+70460866052"}
0005432530095	C08FFB	7155 468208	DAMIR VASILEV	{"email": "vasilev_damir_18011961@postgrespro.ru", "phone": "+70681485277"}
0005432530096	8DFBC4	5671 316901	LYUBOV DAVYDOVA	{"email": "davydova.l_21111974@postgrespro.ru", "phone": "+70668329745"}
0005432530097	7DF0CB	1641 845204	ANASTASIYA TITOVA	{"phone": "+70120867180"}
0005432530098	92088B	2428 410121	VERA MOROZOVA	{"phone": "+70968428892"}
0005432530099	1917F1	9520 629724	VERA GUSEVA	{"email": "v.guseva.031961@postgrespro.ru", "phone": "+70940148873"}
0005432530100	93A3E8	5165 646834	ANDREY NOVIKOV	{"email": "andreynovikov_1972@postgrespro.ru", "phone": "+70803087774"}
0005432530101	93A3E8	3089 625540	ANDREY KAZAKOV	{"phone": "+70465301827"}
0005432530102	93A3E8	0361 000828	TATYANA EGOROVA	{"email": "tatyana-egorova_1982@postgrespro.ru", "phone": "+70491622033"}
0005432530103	D82029	4358 035987	OLGA NIKIFOROVA	{"phone": "+70194382265"}
0005432530104	3BCCB0	5923 150658	YANINA SERGEEVA	{"phone": "+70313941296"}
0005432530105	2C871E	8809 146311	YURIY KOZLOV	{"email": "yuriy-kozlov_081971@postgrespro.ru", "phone": "+70695382507"}
0005432530106	2C871E	0164 923337	EVGENIYA KOMAROVA	{"email": "evgeniya-komarova30071983@postgrespro.ru", "phone": "+70263191694"}
0005432530107	5626E9	0305 436658	VLADIMIR PETROV	{"email": "petrovvladimir081990@postgrespro.ru", "phone": "+70306300577"}
0005432530108	E03105	3202 389158	KARINA TROFIMOVA	{"email": "trofimova_karina-1976@postgrespro.ru", "phone": "+70373192024"}
0005432530109	E03105	5280 638778	ELIZAVETA BELYAEVA	{"email": "belyaevaelizaveta121969@postgrespro.ru", "phone": "+70092038186"}
0005432530110	E03105	4082 364045	VLADIMIR DAVYDOV	{"email": "davydovvladimir_051968@postgrespro.ru", "phone": "+70648856559"}
0005432530111	1E54D2	6585 704835	ARTEM EGOROV	{"email": "artem.egorov-1974@postgrespro.ru", "phone": "+70690512312"}
0005432530112	1E54D2	1391 552878	ANTON GAVRILOV	{"email": "a.gavrilov02091965@postgrespro.ru", "phone": "+70148059498"}
0005432530113	6A88B1	5014 311792	YURIY NAZAROV	{"phone": "+70651851716"}
0005432530114	AF247C	8978 396442	VLADIMIR ANDREEV	{"email": "andreevv.1978@postgrespro.ru", "phone": "+70145629477"}
0005432530115	AF247C	2884 174457	TIMUR EGOROV	{"email": "timuregorov.25121988@postgrespro.ru", "phone": "+70729159578"}
0005432530116	AF247C	3791 977983	VALENTINA NIKOLAEVA	{"email": "valentina_nikolaeva_12021970@postgrespro.ru", "phone": "+70088946068"}
0005432530117	7F6EE6	3304 516485	EVGENIYA KAZAKOVA	{"email": "evgeniyakazakova_09101979@postgrespro.ru", "phone": "+70229113975"}
0005432530118	7F6EE6	6537 697640	EKATERINA MELNIKOVA	{"phone": "+70017940472"}
0005432530119	634CCE	1054 427094	YURIY KOZLOV	{"phone": "+70913953483"}
0005432530120	EA5709	1425 817722	NATALYA VOLKOVA	{"email": "volkovan_10121963@postgrespro.ru", "phone": "+70856424473"}
0005432530121	EA5709	9127 504842	VLADISLAV NOVIKOV	{"phone": "+70824654385"}
0005432530122	78ACF1	2597 068872	NATALYA ZAKHAROVA	{"email": "zakharova_natalya-1972@postgrespro.ru", "phone": "+70827982476"}
0005432530123	78ACF1	9526 042530	VITALIY OSIPOV	{"email": "vitaliy-osipov-031976@postgrespro.ru", "phone": "+70477790068"}
0005432530124	D279D3	6967 887384	ALEKSEY POPOV	{"email": "popov.a-071976@postgrespro.ru", "phone": "+70625331256"}
0005432530125	D3AFD5	9946 948478	SERGEY KISELEV	{"phone": "+70993530803"}
0005432530126	25C7F5	9763 415278	LYUBOV VASILEVA	{"phone": "+70637177785"}
0005432530127	299CA6	8482 090941	ANDREY KUZNECOV	{"phone": "+70568525019"}
0005432530128	594D56	6010 554571	ANNA RODIONOVA	{"email": "rodionovaanna27091971@postgrespro.ru", "phone": "+70555297134"}
0005432530129	594D56	3454 953008	VLADIMIR KRASNOV	{"phone": "+70996538534"}
0005432530130	054055	9724 782074	LILIYA SOKOLOVA	{"phone": "+70430632723"}
0005432530131	5F377E	3934 536572	OLGA PETROVA	{"phone": "+70608180024"}
0005432530132	9D7C0D	7719 610291	SERGEY BONDARENKO	{"phone": "+70268104627"}
0005432530133	9D7C0D	2954 670545	ELENA YAKOVLEVA	{"email": "yakovleva-e_04081967@postgrespro.ru", "phone": "+70078530121"}
0005432530134	BDFA31	9885 396150	VLADIMIR MATVEEV	{"email": "matveevv.1964@postgrespro.ru", "phone": "+70277501410"}
0005432530135	A1B078	2654 645989	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov.1972@postgrespro.ru", "phone": "+70570498460"}
0005432530137	CF2FE0	4645 230150	IVAN KUZNECOV	{"email": "ivan-kuznecov.111970@postgrespro.ru", "phone": "+70516531524"}
0005432530138	007784	2573 284228	VALERIY VASILEV	{"phone": "+70245145335"}
0005432530139	1EB5D9	7212 667503	NIKOLAY KONOVALOV	{"email": "nikolaykonovalov-1976@postgrespro.ru", "phone": "+70433299273"}
0005432530140	1EB5D9	6038 435714	ALEKSEY TIKHONOV	{"email": "tikhonov-a-1967@postgrespro.ru", "phone": "+70152200542"}
0005432530141	8486B2	8331 684967	ANATOLIY SOROKIN	{"phone": "+70968218647"}
0005432530142	8E8174	0647 787237	VLADIMIR SERGEEV	{"email": "sergeev-vladimir.1980@postgrespro.ru", "phone": "+70871051346"}
0005432530143	123EC9	9468 986291	PAVEL BONDARENKO	{"email": "bondarenko_pavel-07081964@postgrespro.ru", "phone": "+70277469747"}
0005432530144	AC4431	7243 736644	ANASTASIYA NOVIKOVA	{"phone": "+70672810668"}
0005432530145	AC4431	7217 267270	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova.l-111974@postgrespro.ru", "phone": "+70386526018"}
0005432530146	C3B23D	6187 994944	RUSLAN KISELEV	{"email": "kiselevr1981@postgrespro.ru", "phone": "+70372185113"}
0005432530147	DDD8D8	5019 170396	NINA SERGEEVA	{"email": "n.sergeeva_21111967@postgrespro.ru", "phone": "+70624145058"}
0005432530148	DDFB8C	4226 412789	ELENA GORBUNOVA	{"phone": "+70525326018"}
0005432530149	ECCA5F	7529 732435	ANASTASIYA NIKOLAEVA	{"email": "a_nikolaeva.1983@postgrespro.ru", "phone": "+70372162624"}
0005432530150	FBB8C9	7876 719746	KLAVDIYA MOROZOVA	{"phone": "+70418278672"}
0005432530151	867A9F	6947 107345	GALINA SERGEEVA	{"phone": "+70707798816"}
0005432530152	867A9F	5719 184661	ALEKSANDRA LEBEDEVA	{"phone": "+70086752826"}
0005432530153	E3C828	3497 318973	OLEG ZAYCEV	{"email": "oleg.zaycev-07041971@postgrespro.ru", "phone": "+70537444899"}
0005432530154	75E15E	6629 520611	STEPAN MATVEEV	{"email": "matveev_stepan.29071988@postgrespro.ru", "phone": "+70125656006"}
0005432530155	861A82	7395 086408	ALEKSEY ANTONOV	{"email": "aleksey.antonov_031967@postgrespro.ru", "phone": "+70620495864"}
0005432530156	3CE00A	0469 603688	VALENTINA NAZAROVA	{"phone": "+70774219427"}
0005432530157	DEC136	0897 177656	MIKHAIL GERASIMOV	{"email": "gerasimovmikhail_081958@postgrespro.ru", "phone": "+70296133365"}
0005432530158	5ABDB2	3676 042896	RAFAIL IVANOV	{"email": "ivanov-r.25101969@postgrespro.ru", "phone": "+70835897208"}
0005432530159	5ABDB2	6385 819528	SERGEY FEDOTOV	{"phone": "+70721219677"}
0005432530160	B25EC4	1031 664673	LIDIYA ZAYCEVA	{"phone": "+70988182558"}
0005432530161	B25EC4	2754 781096	VLADIMIR FILIPPOV	{"phone": "+70355378918"}
0005432530162	3E5118	8596 852594	ELENA LOGINOVA	{"email": "loginovae_20031971@postgrespro.ru", "phone": "+70555290202"}
0005432530163	DD0246	3853 640552	MIKHAIL KUZNECOV	{"email": "kuznecovm1977@postgrespro.ru", "phone": "+70108607370"}
0005432530164	F21618	2801 990765	VIKTORIYA SMIRNOVA	{"phone": "+70137588348"}
0005432530165	324F64	8214 103630	ANDREY KUZNECOV	{"phone": "+70501695040"}
0005432530166	324F64	8437 266293	ALENA ZAKHAROVA	{"phone": "+70108716381"}
0005432530167	37B69D	0058 758739	ALEKSEY GAVRILOV	{"email": "gavrilov.aleksey1979@postgrespro.ru", "phone": "+70478463929"}
0005432530168	C6829F	9892 329345	NATALYA KOZLOVA	{"email": "n_kozlova-031975@postgrespro.ru", "phone": "+70855545652"}
0005432530169	C6829F	8632 990107	VLADISLAV MARTYNOV	{"email": "martynovv.29101966@postgrespro.ru", "phone": "+70986511296"}
0005432530170	3C92C6	0271 245017	DARYA OSIPOVA	{"phone": "+70251070527"}
0005432530171	CB4293	0573 299499	IGOR NIKOLAEV	{"email": "nikolaev_i1960@postgrespro.ru", "phone": "+70567564875"}
0005432530172	F99C01	1746 512771	IRINA POPOVA	{"email": "popova-i_111966@postgrespro.ru", "phone": "+70041395369"}
0005432530173	F99C01	4460 270531	YURIY SHEVCHENKO	{"email": "shevchenkoyuriy.051976@postgrespro.ru", "phone": "+70345318425"}
0005432530174	C90AC6	6938 859222	EVGENIY NOVIKOV	{"email": "e-novikov-10041965@postgrespro.ru", "phone": "+70685770920"}
0005432530175	C90AC6	1004 060660	ANDREY ZAKHAROV	{"email": "a_zakharov-03051975@postgrespro.ru", "phone": "+70450360559"}
0005432530176	A66F09	9919 236534	ELENA PETROVA	{"phone": "+70099893026"}
0005432530177	A66F09	1289 840857	VLADISLAV ALEKSEEV	{"email": "alekseevv.121972@postgrespro.ru", "phone": "+70010924473"}
0005432530178	0A1F2C	5639 472425	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov1961@postgrespro.ru", "phone": "+70233196006"}
0005432530179	E13654	4420 568168	MAKSIM TIKHONOV	{"email": "tikhonovmaksim-091974@postgrespro.ru", "phone": "+70433608553"}
0005432530180	11B636	4282 344645	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_071973@postgrespro.ru", "phone": "+70122836124"}
0005432530181	BA6BB3	1695 441562	SOFYA NESTEROVA	{"phone": "+70702929916"}
0005432530182	689238	1900 147281	MARIYA OSIPOVA	{"email": "mariya_osipova-04071977@postgrespro.ru", "phone": "+70193812330"}
0005432530183	70A693	5600 213899	NATALYA NIKOLAEVA	{"email": "nikolaeva-n-10021976@postgrespro.ru", "phone": "+70075153588"}
0005432530184	BB37C5	6329 130002	NATALYA SCHERBAKOVA	{"email": "scherbakova-natalya-23071976@postgrespro.ru", "phone": "+70939987041"}
0005432530185	BB37C5	9537 302722	DIANA MOROZOVA	{"phone": "+70696421703"}
0005432530186	BB37C5	3453 221002	OKSANA BELOVA	{"email": "oksanabelova-23031980@postgrespro.ru", "phone": "+70967093586"}
0005432530187	BE7DA6	1711 561668	NIKITA SOROKIN	{"phone": "+70384711721"}
0005432530188	44C7A2	7628 870831	OLGA MELNIKOVA	{"email": "olgamelnikova1977@postgrespro.ru", "phone": "+70577408843"}
0005432530189	44C7A2	7122 196851	ELENA ANTONOVA	{"phone": "+70698940567"}
0005432530190	7B5129	1439 654895	VLADIMIR GUSEV	{"phone": "+70099322232"}
0005432530191	D48B2A	3647 282324	OLGA KUZMINA	{"phone": "+70225556471"}
0005432530192	6EBA60	0003 227461	OLGA ZOTOVA	{"email": "olga.zotova-1978@postgrespro.ru", "phone": "+70515270794"}
0005432530193	6EBA60	2790 971386	ANNA PAVLOVA	{"phone": "+70593998923"}
0005432530194	CBB508	5526 778655	SVETLANA KUZMINA	{"email": "kuzmina.s111970@postgrespro.ru", "phone": "+70677297126"}
0005432530195	CBB508	7817 234172	NELLI ZHUKOVA	{"email": "nelli_zhukova28071975@postgrespro.ru", "phone": "+70371107508"}
0005432530196	4B8BBE	7140 143426	OLEG IVANOV	{"phone": "+70590122992"}
0005432530197	4B8BBE	3455 189289	GALINA GAVRILOVA	{"email": "gavrilova.galina071963@postgrespro.ru", "phone": "+70927907224"}
0005432530198	4B8BBE	0344 852482	IVAN KUZMIN	{"email": "ivan-kuzmin031972@postgrespro.ru", "phone": "+70862951568"}
0005432530199	CDDBAD	3912 986323	ALEKSANDRA BARANOVA	{"phone": "+70826170291"}
0005432530200	A98D55	7168 754652	ANNA ORLOVA	{"email": "orlovaanna_23101974@postgrespro.ru", "phone": "+70061149501"}
0005432530201	49350B	1560 661112	DIANA MAKAROVA	{"phone": "+70451134407"}
0005432530202	5C9F0C	3184 891640	ELENA SOKOLOVA	{"phone": "+70130446751"}
0005432530203	D84862	3354 271797	VASILIY KOROLEV	{"phone": "+70191930739"}
0005432530204	4B9468	9226 550565	NELLYA TARASOVA	{"email": "n_tarasova14021978@postgrespro.ru", "phone": "+70248530146"}
0005432530205	9EC03F	5205 618235	ROZA NESTEROVA	{"phone": "+70342466998"}
0005432530206	C27DAD	5689 417575	VLADIMIR ILIN	{"phone": "+70562788630"}
0005432530207	0258A3	3728 875945	ALEKSANDRA KAZAKOVA	{"email": "kazakova_aleksandra121971@postgrespro.ru", "phone": "+70957422629"}
0005432530208	3ED38F	1363 846647	PAVEL VLASOV	{"phone": "+70285937590"}
0005432530209	54F9DE	1762 898998	GERMAN ZAKHAROV	{"email": "zakharov_g_1961@postgrespro.ru", "phone": "+70841496781"}
0005432530210	CAA6A3	6586 072378	TAMARA LUKYANOVA	{"phone": "+70100378861"}
0005432530211	CAA6A3	6189 918297	ALEKSANDR GERASIMOV	{"email": "a_gerasimov061957@postgrespro.ru", "phone": "+70273892571"}
0005432530212	CAA6A3	1538 628583	PETR MATVEEV	{"email": "matveevp-1966@postgrespro.ru", "phone": "+70238609819"}
0005432530213	2B916E	0652 996761	ANASTASIYA NIKITINA	{"email": "anastasiya.nikitina.061988@postgrespro.ru", "phone": "+70376803205"}
0005432530214	2B916E	0593 615246	ANNA LAZAREVA	{"email": "lazarevaanna1969@postgrespro.ru", "phone": "+70467750452"}
0005432530215	2B916E	9598 358928	EGOR GUSEV	{"email": "guseve.26081969@postgrespro.ru", "phone": "+70294968027"}
0005432530216	154F0C	2563 199594	PAVEL CHERNOV	{"phone": "+70147511917"}
0005432530217	0ABD84	6527 766798	NATALYA VOLKOVA	{"email": "volkova-n-021968@postgrespro.ru", "phone": "+70147491002"}
0005432530218	13F131	0930 797018	NATALIYA SEMENOVA	{"phone": "+70311024665"}
0005432530219	C41C91	5133 620710	VIKTORIYA KUZMINA	{"phone": "+70844902192"}
0005432530220	C41C91	0978 886012	KLAVDIYA MOISEEVA	{"phone": "+70464955325"}
0005432530221	BAE81D	4121 046866	ELENA MATVEEVA	{"email": "matveeva.elena1970@postgrespro.ru", "phone": "+70952353631"}
0005432530222	BAE81D	8333 637522	IGOR SERGEEV	{"phone": "+70235748956"}
0005432530223	BAE81D	6051 448876	EVGENIY KUZMIN	{"email": "kuzmin_e_19101974@postgrespro.ru", "phone": "+70137056579"}
0005432530224	39C0C4	0700 112098	ALEKSEY SEMENOV	{"email": "semenovaleksey-1974@postgrespro.ru", "phone": "+70552912439"}
0005432530225	39C0C4	8121 412128	DARYA ZOTOVA	{"phone": "+70803936503"}
0005432530226	AC3125	0840 832332	VLADISLAV ZHURAVLEV	{"phone": "+70217754532"}
0005432530227	B46267	4420 448675	ALEKSANDR SOKOLOV	{"email": "asokolov_061977@postgrespro.ru", "phone": "+70285566964"}
0005432530228	B46267	0198 907085	YULIYA ANDREEVA	{"phone": "+70208489847"}
0005432530229	DCE6EE	9829 839901	PAVEL KARPOV	{"phone": "+70340430664"}
0005432530230	2EFAF2	2566 460617	MIKHAIL MOROZOV	{"email": "mikhail.morozov_31081967@postgrespro.ru", "phone": "+70499053568"}
0005432530231	6CC302	7735 017518	ALEKSEY ALEKSEEV	{"phone": "+70055262290"}
0005432530232	75DF82	4826 958324	SERGEY GERASIMOV	{"email": "sergeygerasimov.03031975@postgrespro.ru", "phone": "+70173672593"}
0005432530233	75DF82	8373 691327	NAIL DENISOV	{"email": "denisovnail31071966@postgrespro.ru", "phone": "+70757344714"}
0005432530234	75DF82	1946 811782	GALINA EGOROVA	{"phone": "+70328123144"}
0005432530235	9433BD	6272 690052	VIKTOR MAKAROV	{"phone": "+70959491156"}
0005432530236	9433BD	9206 322799	ALEVTINA KUDRYASHOVA	{"phone": "+70328362170"}
0005432530237	7C39D2	3535 108518	LYUBOV SAVELEVA	{"email": "saveleva.l-041970@postgrespro.ru", "phone": "+70101378767"}
0005432530238	7C39D2	7934 973543	TATYANA MIKHAYLOVA	{"phone": "+70803084661"}
0005432530239	0AA635	7695 471642	OLGA NOVIKOVA	{"email": "novikova_olga-03091973@postgrespro.ru", "phone": "+70174018255"}
0005432530240	0AA635	5042 334133	VALENTINA SIDOROVA	{"email": "vsidorova-1964@postgrespro.ru", "phone": "+70311241302"}
0005432530241	AC4CE8	6624 886873	ZAKHAR SAVELEV	{"email": "z.savelev071973@postgrespro.ru", "phone": "+70117987712"}
0005432530242	C6A546	8195 060460	YURIY CHERNOV	{"phone": "+70949842247"}
0005432530243	C6A546	5114 486300	TATYANA DAVYDOVA	{"phone": "+70296614908"}
0005432530244	C6A546	3136 520818	GENNADIY TARASOV	{"email": "tarasov-g1991@postgrespro.ru", "phone": "+70456047456"}
0005432530245	82D89D	8207 115519	ALINA SMIRNOVA	{"phone": "+70832098554"}
0005432530246	82D89D	0460 262327	SERGEY POPOV	{"email": "s.popov-29111958@postgrespro.ru", "phone": "+70591248420"}
0005432530247	251758	9906 225814	VIKTOR GERASIMOV	{"phone": "+70875041438"}
0005432530248	D7FCA9	5852 819645	ANDREY MATVEEV	{"email": "matveev_a.02041985@postgrespro.ru", "phone": "+70008627861"}
0005432530249	C2A84C	9434 229827	ZOYA KUZMINA	{"phone": "+70645923296"}
0005432530250	C2A84C	4344 564531	OKSANA VASILEVA	{"phone": "+70390857880"}
0005432530251	3A53E7	1610 002151	ALEKSANDR FROLOV	{"email": "frolova-1971@postgrespro.ru", "phone": "+70327768007"}
0005432530252	3B635E	5590 934461	VALERIY KULIKOV	{"phone": "+70057130729"}
0005432530253	36B49B	6407 450035	ALEKSEY BORISOV	{"email": "aleksey_borisov-17111974@postgrespro.ru", "phone": "+70816416769"}
0005432530254	EFEBA3	7191 273292	IVAN IVANOV	{"email": "ivanov.i_1967@postgrespro.ru", "phone": "+70346926131"}
0005432530255	1D356A	8261 584632	VYACHESLAV DAVYDOV	{"phone": "+70619433173"}
0005432530256	1D356A	3395 080852	VLADISLAV KUZNECOV	{"phone": "+70087429131"}
0005432530257	D2C569	7843 682561	ALEKSEY PETROV	{"email": "petrov-a25121978@postgrespro.ru", "phone": "+70439660542"}
0005432530258	7B1DA0	1545 338797	NIKITA IVANOV	{"email": "ivanov-n22041973@postgrespro.ru", "phone": "+70419149871"}
0005432530259	7B1DA0	8386 622407	SVETLANA TIMOFEEVA	{"email": "timofeeva-s.021980@postgrespro.ru", "phone": "+70014949679"}
0005432530260	5FDC41	3952 496565	DANILA SCHERBAKOV	{"email": "scherbakov_danila.021973@postgrespro.ru", "phone": "+70492383981"}
0005432530261	48BF5F	1772 644364	MARINA SIDOROVA	{"phone": "+70801635877"}
0005432530262	694398	3864 136246	DIANA GERASIMOVA	{"email": "gerasimova_d.071964@postgrespro.ru", "phone": "+70076652862"}
0005432530263	871893	9021 301821	SVETLANA KISELEVA	{"phone": "+70998562755"}
0005432530264	871893	9537 446089	GALINA SMIRNOVA	{"email": "g_smirnova.1968@postgrespro.ru", "phone": "+70003388826"}
0005432530265	BA39CB	9148 187853	ELENA ERMAKOVA	{"phone": "+70791473266"}
0005432530266	12D7DD	5882 217042	ROMAN CHERNOV	{"phone": "+70876413549"}
0005432530267	12D7DD	1958 118259	VYACHESLAV SMIRNOV	{"phone": "+70035513026"}
0005432530268	FD6C95	4268 405247	KARINA MEDVEDEVA	{"email": "kmedvedeva_04051976@postgrespro.ru", "phone": "+70498503473"}
0005432530269	FD6C95	9203 935683	NATALYA NOVIKOVA	{"phone": "+70264031875"}
0005432530270	614E95	0412 202640	NIKOLAY IVANOV	{"email": "nivanov_1973@postgrespro.ru", "phone": "+70921277521"}
0005432530271	0AD1A5	1264 710069	ANDREY VASILEV	{"email": "avasilev_1975@postgrespro.ru", "phone": "+70660956796"}
0005432530272	31C988	9374 073863	TAMARA NIKOLAEVA	{"email": "tnikolaeva1957@postgrespro.ru", "phone": "+70032028252"}
0005432530273	616789	9681 009861	NATALYA VASILEVA	{"email": "vasileva-natalya.1971@postgrespro.ru", "phone": "+70884376647"}
0005432530274	0063CA	3470 325144	FEDOR SHEVCHENKO	{"email": "shevchenko-f.1966@postgrespro.ru", "phone": "+70381105809"}
0005432530275	F2B380	9203 590190	DANILA CHERNOV	{"phone": "+70629698447"}
0005432530276	9F8623	3045 591509	VLADISLAV GRIGOREV	{"email": "grigorev_v-081964@postgrespro.ru", "phone": "+70447534811"}
0005432530277	B06F1C	8810 674489	NATALYA KOZLOVA	{"email": "kozlova_n.12101969@postgrespro.ru", "phone": "+70195565533"}
0005432530278	552EDC	5011 385651	VLADIMIR NIKOLAEV	{"email": "vladimir-nikolaev-28091978@postgrespro.ru", "phone": "+70082415481"}
0005432530279	3A24EB	8190 825460	TATYANA ALEKSANDROVA	{"email": "aleksandrovatatyana.111982@postgrespro.ru", "phone": "+70941329255"}
0005432530280	CDE9EB	3865 846933	SERGEY KUDRYASHOV	{"email": "kudryashov_s.1973@postgrespro.ru", "phone": "+70013279096"}
0005432530281	BCD94E	6137 183637	PETR FEDOROV	{"email": "petrfedorov-091961@postgrespro.ru", "phone": "+70509626886"}
0005432530282	DB9A5D	9915 894642	MAKSIM SHEVCHENKO	{"email": "shevchenko_m.061976@postgrespro.ru", "phone": "+70927375236"}
0005432530283	204FB1	8316 534597	ELENA VASILEVA	{"email": "vasileva-e.1975@postgrespro.ru", "phone": "+70924389816"}
0005432530284	204FB1	0652 540225	IRINA AFANASEVA	{"phone": "+70546040134"}
0005432530285	B6C7BE	5552 284687	EKATERINA ZAKHAROVA	{"phone": "+70977525414"}
0005432530286	2F3F4B	6550 059127	DARYA MOROZOVA	{"phone": "+70744523266"}
0005432530287	2F3F4B	4389 571670	IVAN NAZAROV	{"phone": "+70429243864"}
0005432530288	464881	3926 866559	SVETLANA IVANOVA	{"email": "svetlana-ivanova-1971@postgrespro.ru", "phone": "+70663783465"}
0005432530289	3C804F	6193 403680	NADEZHDA ZHURAVLEVA	{"email": "n-zhuravleva.011973@postgrespro.ru", "phone": "+70522704558"}
0005432530290	3C804F	5210 171179	ANATOLIY SHEVCHENKO	{"phone": "+70770544310"}
0005432530291	02FA75	0253 335961	VLADIMIR ROMANOV	{"email": "romanov.v_28111971@postgrespro.ru", "phone": "+70109794716"}
0005432530292	02FA75	0230 121718	VADIM FROLOV	{"email": "frolov_v_03031973@postgrespro.ru", "phone": "+70979374354"}
0005432530293	788B5A	2949 537483	DMITRIY KULIKOV	{"phone": "+70517273514"}
0005432530294	893726	5514 498301	NADEZHDA CHERNOVA	{"phone": "+70560676318"}
0005432530295	893726	8080 692678	LIDIYA ANISIMOVA	{"phone": "+70169812855"}
0005432530296	821FE4	1001 799618	ZINAIDA GERASIMOVA	{"email": "gerasimova.zinaida1967@postgrespro.ru", "phone": "+70962258736"}
0005432530297	821FE4	5096 389395	ANASTASIYA ORLOVA	{"phone": "+70220835331"}
0005432530298	821FE4	2568 726261	ANASTASIYA RODIONOVA	{"email": "a-rodionova-1969@postgrespro.ru", "phone": "+70298542701"}
0005432530299	F85B52	4960 310763	NATALYA BORISOVA	{"phone": "+70186324612"}
0005432530300	9B3624	3310 726039	EVGENIY POPOV	{"email": "evgeniy_popov_16041968@postgrespro.ru", "phone": "+70479065509"}
0005432530301	AD4E49	7056 364690	VALERIYA POPOVA	{"email": "popova_valeriya-09061965@postgrespro.ru", "phone": "+70662321372"}
0005432530302	6EC8AF	9396 196457	VLADISLAV TIMOFEEV	{"phone": "+70866539203"}
0005432530303	7C2B46	0289 108424	ARINA ZAYCEVA	{"email": "zayceva.a-1974@postgrespro.ru", "phone": "+70906967152"}
0005432530304	908807	4704 264687	ELENA SOKOLOVA	{"email": "sokolova.elena.1977@postgrespro.ru", "phone": "+70619260119"}
0005432530305	8417D3	6227 795557	VLADIMIR BORISOV	{"email": "borisovvladimir-1977@postgrespro.ru", "phone": "+70025915505"}
0005432530306	8417D3	4988 661342	ALEKSEY ROMANOV	{"phone": "+70193156668"}
0005432530307	57BB42	0098 145503	YULIYA KONOVALOVA	{"phone": "+70234568250"}
0005432530308	94B303	8968 555110	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav031980@postgrespro.ru", "phone": "+70465837264"}
0005432530309	8DF990	3674 974037	NADEZHDA IVANOVA	{"phone": "+70596516876"}
0005432530310	8DF990	0560 907956	ALEKSANDR KOROLEV	{"email": "korolev-aleksandr.09051970@postgrespro.ru", "phone": "+70355336012"}
0005432530311	8DF990	7762 189093	VALENTINA NESTEROVA	{"phone": "+70537229497"}
0005432530312	12EFF4	2995 864996	ALEKSEY RODIONOV	{"phone": "+70973897132"}
0005432530313	12EFF4	8595 253898	VIKTOR ZHURAVLEV	{"phone": "+70284014850"}
0005432530314	32B176	8057 570842	VITALIY BARANOV	{"email": "vitaliybaranov-1971@postgrespro.ru", "phone": "+70797720320"}
0005432530315	32B176	4101 995366	VLADIMIR PETROV	{"email": "petrov.v.05061974@postgrespro.ru", "phone": "+70866577804"}
0005432530316	32B176	3347 818271	ALEKSANDR DENISOV	{"email": "denisov-aleksandr-111974@postgrespro.ru", "phone": "+70499465768"}
0005432530317	BEE138	8997 188423	MIKHAIL MOROZOV	{"phone": "+70673040421"}
0005432530318	B0BEC1	7436 428282	DIANA RODIONOVA	{"email": "rodionova_diana1979@postgrespro.ru", "phone": "+70485211896"}
0005432530319	337A7E	6180 393182	ANNA PAVLOVA	{"phone": "+70539722459"}
0005432530320	9E2ABC	5738 504533	GENNADIY GAVRILOV	{"email": "g-gavrilov.1975@postgrespro.ru", "phone": "+70006710003"}
0005432530321	9E2ABC	3152 433498	KIRILL SERGEEV	{"email": "k-sergeev111973@postgrespro.ru", "phone": "+70350667554"}
0005432530322	61D96C	0041 252124	SVETLANA ABRAMOVA	{"phone": "+70677125829"}
0005432530323	8697DD	7619 441618	VIOLETTA FEDOROVA	{"email": "fedorova.v111963@postgrespro.ru", "phone": "+70611633479"}
0005432530324	8697DD	7131 976504	EKATERINA SOKOLOVA	{"phone": "+70554841530"}
0005432530325	5D4A05	8409 615571	EGOR PAVLOV	{"phone": "+70973215110"}
0005432530326	5D4A05	6105 149893	VLADISLAV BORISOV	{"email": "borisov-v.1973@postgrespro.ru", "phone": "+70334000391"}
0005432530327	299FD6	8076 369522	VLADIMIR KUZMIN	{"phone": "+70566826526"}
0005432530328	A01091	5148 355870	ALEVTINA LEBEDEVA	{"email": "lebedeva_a.091974@postgrespro.ru", "phone": "+70654495801"}
0005432530329	D971C5	3395 789712	LYUDMILA SERGEEVA	{"email": "sergeevalyudmila14101971@postgrespro.ru", "phone": "+70981321275"}
0005432530330	8D2157	9850 083802	NADEZHDA VLASOVA	{"email": "nadezhda-vlasova1969@postgrespro.ru", "phone": "+70066191440"}
0005432530331	8CBA37	1893 337529	MARGARITA MASLOVA	{"phone": "+70990898689"}
0005432530332	8CBA37	5522 223017	ANATOLIY FEDOROV	{"phone": "+70783298373"}
0005432530333	67655F	0669 109136	OLGA KISELEVA	{"email": "kiseleva.o_021966@postgrespro.ru", "phone": "+70796572763"}
0005432530334	D2959B	5426 800224	NATALYA BARANOVA	{"email": "natalya_baranova.13011975@postgrespro.ru", "phone": "+70005070298"}
0005432530335	D2959B	3089 123078	NINA BARANOVA	{"phone": "+70035267979"}
0005432530336	1255B9	3895 642380	NATALYA VOROBEVA	{"email": "vorobevan-13101972@postgrespro.ru", "phone": "+70139914915"}
0005432530337	88932E	1376 405456	ALEKSANDR SMIRNOV	{"email": "smirnova.071964@postgrespro.ru", "phone": "+70203455959"}
0005432530338	FE630B	4193 990753	ANNA GORBUNOVA	{"phone": "+70606557526"}
0005432530339	FE630B	5416 446780	NIKOLAY KUZNECOV	{"phone": "+70640561273"}
0005432530340	900DA8	7397 720015	VALENTINA KONDRATEVA	{"email": "v_kondrateva_01111966@postgrespro.ru", "phone": "+70772587007"}
0005432530341	43CA19	8287 662385	ALEKSANDR MATVEEV	{"phone": "+70707846960"}
0005432530342	43CA19	7806 584884	ALEKSANDR YAKOVLEV	{"email": "yakovleva.1966@postgrespro.ru", "phone": "+70522687972"}
0005432530343	34E47C	2877 136728	EVGENIY KAZAKOV	{"email": "e-kazakov05021975@postgrespro.ru", "phone": "+70950705318"}
0005432530344	34E47C	6492 843648	RAFIK VASILEV	{"email": "vasilevrafik1967@postgrespro.ru", "phone": "+70480421665"}
0005432530345	AE7C72	9354 323552	KLAVDIYA SEMENOVA	{"email": "semenova-k-11081971@postgrespro.ru", "phone": "+70544164031"}
0005432530346	1B3248	5710 967914	ALEKSANDRA NAZAROVA	{"phone": "+70317516656"}
0005432530347	B3CBBF	1147 924176	ALEKSANDR ABRAMOV	{"email": "abramov_a_09051970@postgrespro.ru", "phone": "+70447232430"}
0005432530348	B3CBBF	3749 535656	ALEKSANDR ZHUKOV	{"phone": "+70004340183"}
0005432530349	0B8046	9457 152062	ALEKSEY IVANOV	{"phone": "+70872380298"}
0005432530350	0B8046	0291 875954	VIKTOR MATVEEV	{"phone": "+70087892245"}
0005432530351	32C9CC	8296 777098	TAMARA GUSEVA	{"email": "tamara_guseva06011980@postgrespro.ru", "phone": "+70402869762"}
0005432530352	229192	6014 158953	SERGEY FILIPPOV	{"email": "filippov_sergey_1968@postgrespro.ru", "phone": "+70545415615"}
0005432530353	EE6229	8698 979615	ALEKSANDR ORLOV	{"email": "aleksandrorlov061967@postgrespro.ru", "phone": "+70157743863"}
0005432530354	EE6229	9707 312349	VLADISLAV PAVLOV	{"phone": "+70247781935"}
0005432530355	6AEC24	2526 830546	MARINA MELNIKOVA	{"email": "melnikovamarina101978@postgrespro.ru", "phone": "+70968759706"}
0005432530356	CFD302	6504 420131	DMITRIY TARASOV	{"email": "tarasovdmitriy051986@postgrespro.ru", "phone": "+70714533377"}
0005432530357	CFD302	8465 961160	MARINA IVANOVA	{"phone": "+70702993861"}
0005432530358	AA3B1D	5105 960669	ALEKSANDRA NAZAROVA	{"email": "a.nazarova1978@postgrespro.ru", "phone": "+70082142193"}
0005432530359	672AF3	6241 058470	VALENTINA VLASOVA	{"email": "valentina_vlasova121972@postgrespro.ru", "phone": "+70088913983"}
0005432530360	211B0A	2162 874498	ANATOLIY KONOVALOV	{"phone": "+70048999970"}
0005432530361	06201D	3793 802300	TATYANA ARKHIPOVA	{"email": "tatyanaarkhipova111970@postgrespro.ru", "phone": "+70357439502"}
0005432530362	D2DB1E	4369 260850	EVGENIY ABRAMOV	{"phone": "+70424089427"}
0005432530363	4DD87A	3376 843928	ALEKSANDR FOMIN	{"phone": "+70497974297"}
0005432530364	E6DE3C	8946 391987	VLADIMIR KUDRYASHOV	{"phone": "+70014440083"}
0005432530365	CD0453	3224 648233	ALEKSEY POPOV	{"phone": "+70211230020"}
0005432530366	E2AAFF	0468 215786	SERGEY GAVRILOV	{"email": "sergey-gavrilov-061969@postgrespro.ru", "phone": "+70873159892"}
0005432530367	148136	1241 517248	DENIS NIKOLAEV	{"phone": "+70571044677"}
0005432530368	148136	3003 966946	LIDIYA DAVYDOVA	{"phone": "+70710020066"}
0005432530369	78536B	1877 106545	NATALYA ZAKHAROVA	{"email": "natalya_zakharova12111973@postgrespro.ru", "phone": "+70711383385"}
0005432530370	6B5407	8217 140027	IRINA DMITRIEVA	{"email": "idmitrieva31081975@postgrespro.ru", "phone": "+70765964092"}
0005432530371	81D529	1341 865447	SERGEY IVANOV	{"email": "sergey_ivanov.011981@postgrespro.ru", "phone": "+70675942742"}
0005432530372	81D529	5441 419997	RAISA KUZNECOVA	{"email": "raisa-kuznecova06081965@postgrespro.ru", "phone": "+70599616269"}
0005432530373	B1C23E	6192 675707	DMITRIY FEDOTOV	{"phone": "+70542996965"}
0005432530374	328855	9956 427708	ALEKSANDR VOLKOV	{"phone": "+70291301737"}
0005432530375	B2A890	1687 351056	EKATERINA ILINA	{"phone": "+70399362313"}
0005432530376	8AE6E8	0564 078263	ELMIRA SMIRNOVA	{"phone": "+70455821954"}
0005432530377	AA8C9B	4949 288230	VLADIMIR MIRONOV	{"phone": "+70290909382"}
0005432530378	BC968D	6552 159254	RUSLAN VOLKOV	{"email": "volkovruslan19081965@postgrespro.ru", "phone": "+70995055831"}
0005432530379	EF577C	4002 916902	LIDIYA ZOTOVA	{"phone": "+70826813431"}
0005432530380	EF577C	9705 619118	ALEKSANDR IVANOV	{"phone": "+70116390052"}
0005432530381	D3AB89	2152 462114	NATALYA DMITRIEVA	{"phone": "+70624788516"}
0005432530382	D3AB89	7887 554543	ANATOLIY MAKAROV	{"email": "anatoliy_makarov.041971@postgrespro.ru", "phone": "+70377986676"}
0005432530383	7F6C79	0887 229907	MARINA GERASIMOVA	{"phone": "+70765815457"}
0005432530384	7F6C79	5108 743063	IGOR MELNIKOV	{"phone": "+70046143746"}
0005432530385	EFB627	6002 898103	VYACHESLAV DMITRIEV	{"phone": "+70237057222"}
0005432530386	756BE2	1777 877441	DIANA KUZNECOVA	{"email": "kuznecova_diana_1981@postgrespro.ru", "phone": "+70671687722"}
0005432530387	E8C27B	1529 129647	SVETLANA IVANOVA	{"phone": "+70454986524"}
0005432530388	5CA73D	4430 347022	PETR KONOVALOV	{"email": "petrkonovalov-1972@postgrespro.ru", "phone": "+70259242017"}
0005432530389	131CC6	8171 829448	SERGEY MIRONOV	{"phone": "+70338598278"}
0005432530390	131CC6	0076 731538	SVETLANA MELNIKOVA	{"email": "s_melnikova_25111982@postgrespro.ru", "phone": "+70386347870"}
0005432530391	70B3A7	3169 486175	SVETLANA MAKSIMOVA	{"phone": "+70123342584"}
0005432530392	70B3A7	5566 250901	EVGENIYA RODIONOVA	{"email": "rodionova-evgeniya_1971@postgrespro.ru", "phone": "+70127511755"}
0005432530393	14AEA0	6539 861749	LYUDMILA MIRONOVA	{"email": "l-mironova061955@postgrespro.ru", "phone": "+70762687455"}
0005432530394	6075B9	7021 460707	EVGENIY ROMANOV	{"phone": "+70829888823"}
0005432530395	6075B9	5075 578447	VALERIY VASILEV	{"email": "vasilev.valeriy29031982@postgrespro.ru", "phone": "+70716371425"}
0005432530396	6075B9	8991 412818	VYACHESLAV DAVYDOV	{"phone": "+70838763654"}
0005432530397	A4BB40	3046 936948	TATYANA KUZNECOVA	{"email": "t.kuznecova-24111969@postgrespro.ru", "phone": "+70997943963"}
0005432530398	12C7AA	8717 636808	PAVEL GUSEV	{"phone": "+70821353665"}
0005432530399	5E5200	9965 177727	POLINA MAKAROVA	{"phone": "+70010308975"}
0005432530400	5E5200	0712 990440	TATYANA TIKHONOVA	{"email": "t_tikhonova_061965@postgrespro.ru", "phone": "+70757614699"}
0005432530401	1D1546	8712 601750	ANTONIDA FROLOVA	{"email": "frolova_a_121969@postgrespro.ru", "phone": "+70723308969"}
0005432530402	987764	4281 264715	VLADIMIR BORISOV	{"email": "borisov.vladimir1979@postgrespro.ru", "phone": "+70195547885"}
0005432530403	987764	9585 298878	ILYA FROLOV	{"phone": "+70429167583"}
0005432530404	B19516	8126 445715	OLGA ZOTOVA	{"email": "ozotova-21071958@postgrespro.ru", "phone": "+70655205067"}
0005432530405	926F9C	1346 419900	VLADIMIR ZAYCEV	{"email": "v.zaycev-17071974@postgrespro.ru", "phone": "+70726930795"}
0005432530406	DAB212	3748 267513	NADEZHDA PAVLOVA	{"email": "pavlova_n.1974@postgrespro.ru", "phone": "+70450994551"}
0005432530407	DAB212	4213 807074	MARIYA FROLOVA	{"email": "mariya-frolova_031979@postgrespro.ru", "phone": "+70673146708"}
0005432530408	475661	9837 545044	ANGELINA MAKAROVA	{"phone": "+70175308915"}
0005432530409	475661	7809 347851	ALEKSEY EGOROV	{"phone": "+70198016101"}
0005432530410	8865E9	3966 027095	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov_18101964@postgrespro.ru", "phone": "+70442416928"}
0005432530411	9C9B96	9547 706274	IRINA KUZMINA	{"email": "i-kuzmina.10101973@postgrespro.ru", "phone": "+70161988277"}
0005432530412	3782D9	2177 498091	OLGA IVANOVA	{"phone": "+70102648173"}
0005432530413	362453	3605 241869	YULIYA MARTYNOVA	{"phone": "+70870648309"}
0005432530414	362453	0151 559445	VENIAMIN ZHUKOV	{"email": "zhukov-v-111965@postgrespro.ru", "phone": "+70847885158"}
0005432530415	71DB9B	3275 093099	ANDREY SHEVCHENKO	{"email": "shevchenko.a-121989@postgrespro.ru", "phone": "+70041407532"}
0005432530416	F8F37B	7761 741386	DENIS IVANOV	{"phone": "+70720982479"}
0005432530417	F27F7C	1979 568989	NINA SIDOROVA	{"email": "n_sidorova.021964@postgrespro.ru", "phone": "+70818170315"}
0005432530418	54939C	0135 511349	DMITRIY SCHERBAKOV	{"email": "dscherbakov30011965@postgrespro.ru", "phone": "+70899444082"}
0005432530419	B150F1	6639 547054	LYUDMILA AKIMOVA	{"phone": "+70167407790"}
0005432530420	B150F1	7350 991960	ALEKSANDR ZHUKOV	{"phone": "+70936659882"}
0005432530421	A51976	7841 288155	ELENA EFREMOVA	{"phone": "+70301716898"}
0005432530422	E5CC39	5611 162948	ADELINA NIKOLAEVA	{"email": "adelina-nikolaeva20091980@postgrespro.ru", "phone": "+70491778166"}
0005432530423	7561F3	3220 725147	GALINA GAVRILOVA	{"phone": "+70653178173"}
0005432530424	7561F3	5999 894705	OLESYA AFANASEVA	{"email": "afanaseva_o_09011981@postgrespro.ru", "phone": "+70497753762"}
0005432530425	00CEA1	3403 518758	YURIY MARTYNOV	{"email": "martynov-y01011965@postgrespro.ru", "phone": "+70423863911"}
0005432530426	00CEA1	2880 983046	DARYA GUSEVA	{"email": "darya_guseva1964@postgrespro.ru", "phone": "+70198542674"}
0005432530601	34704A	9861 615236	LEV NIKOLAEV	{"phone": "+70620070821"}
0005432530427	E2EDC3	1807 531761	ELENA STEPANOVA	{"email": "elena-stepanova.05011977@postgrespro.ru", "phone": "+70502360314"}
0005432530428	49104E	2908 995340	MARIYA KRASNOVA	{"email": "krasnovam-13061981@postgrespro.ru", "phone": "+70707962903"}
0005432530429	49104E	8333 994976	EKATERINA SOKOLOVA	{"phone": "+70819923864"}
0005432530430	CFEFEF	7809 123422	MARIYA SOKOLOVA	{"email": "msokolova1968@postgrespro.ru", "phone": "+70807775141"}
0005432530431	CC3A18	5971 571134	NIKOLAY PETROV	{"phone": "+70410451959"}
0005432530432	CC3A18	7283 445494	RENAT DAVYDOV	{"phone": "+70047539577"}
0005432530433	C2C26D	2091 681218	MARGARITA KONOVALOVA	{"email": "mkonovalova-1973@postgrespro.ru", "phone": "+70503254958"}
0005432530434	45EFD5	6227 294083	ALEKSANDR MIKHAYLOV	{"phone": "+70914137410"}
0005432530435	B5BB15	4574 539773	ALEKSEY TIKHONOV	{"email": "tikhonova_1967@postgrespro.ru", "phone": "+70168580876"}
0005432530436	3C4279	7287 808011	TATYANA AFANASEVA	{"email": "t.afanaseva.031964@postgrespro.ru", "phone": "+70273564866"}
0005432530437	3C4279	9097 845180	EVA RYABOVA	{"email": "eva.ryabova-021978@postgrespro.ru", "phone": "+70381894801"}
0005432530438	394246	3552 826541	ANDREY IVANOV	{"phone": "+70098642975"}
0005432530439	3A3FCF	4196 448192	ALEKSANDRA AKIMOVA	{"email": "akimova_aleksandra-041955@postgrespro.ru", "phone": "+70403855134"}
0005432530440	990D6F	9801 323817	NATALYA IVANOVA	{"phone": "+70550727937"}
0005432530441	990D6F	2005 494979	RAISA KUZNECOVA	{"email": "kuznecova_raisa051977@postgrespro.ru", "phone": "+70395881043"}
0005432530442	C1CDF6	8266 818611	IVAN ABRAMOV	{"phone": "+70744004681"}
0005432530443	C1CDF6	1918 630750	LYUDMILA IVANOVA	{"email": "l-ivanova_30031967@postgrespro.ru", "phone": "+70698203452"}
0005432530444	9ED378	4695 955104	VLADA TARASOVA	{"email": "tarasova_v061966@postgrespro.ru", "phone": "+70017810471"}
0005432530445	0BB4F4	1118 185224	OLEG GORBUNOV	{"email": "gorbunov_oleg111979@postgrespro.ru", "phone": "+70990385766"}
0005432530446	74BF04	4678 943069	OLEG KUZMIN	{"email": "oleg-kuzmin_1963@postgrespro.ru", "phone": "+70473547480"}
0005432530447	74BF04	6445 376526	EVGENIY NIKITIN	{"email": "nikitine-14051979@postgrespro.ru", "phone": "+70265192742"}
0005432530448	74BF04	4219 578497	YULIYA MALYSHEVA	{"phone": "+70118535028"}
0005432530449	F43F8D	7876 708985	VALENTINA NAZAROVA	{"email": "valentina-nazarova.1980@postgrespro.ru", "phone": "+70732729048"}
0005432530450	F43F8D	8987 232571	SVETLANA KOLESNIKOVA	{"phone": "+70801050208"}
0005432530451	F43F8D	1720 616848	YULIYA POPOVA	{"phone": "+70131197304"}
0005432530452	129940	0352 252104	EKATERINA ARKHIPOVA	{"phone": "+70938797373"}
0005432530453	84D481	0719 334901	NADEZHDA IVANOVA	{"phone": "+70432514547"}
0005432530454	96ADBF	8084 921058	ALEKSANDR KUZMIN	{"email": "kuzmin.a.1979@postgrespro.ru", "phone": "+70740305968"}
0005432530455	B59A6B	2668 173036	STANISLAV IVANOV	{"phone": "+70904823178"}
0005432530456	CC47C5	7581 933708	NIKOLAY MAKAROV	{"email": "nikolay-makarov1967@postgrespro.ru", "phone": "+70244878921"}
0005432530457	BD66B0	5945 951256	ELENA ANTONOVA	{"email": "e_antonova_031973@postgrespro.ru", "phone": "+70958685124"}
0005432530458	BD66B0	7220 603363	IRINA MELNIKOVA	{"phone": "+70164189888"}
0005432530459	0EE625	1319 961330	YULIYA BELOVA	{"phone": "+70012511952"}
0005432530460	3EA279	7629 555842	YULIYA KONDRATEVA	{"phone": "+70220091069"}
0005432530461	717F15	3414 197605	SERGEY VASILEV	{"email": "vasilevs_01021978@postgrespro.ru", "phone": "+70156907212"}
0005432530462	9ED493	4877 676156	ELENA IVANOVA	{"email": "ivanova-elena-12081977@postgrespro.ru", "phone": "+70285238496"}
0005432530463	7A05B5	2597 764031	SERGEY SERGEEV	{"email": "sergeev-s-091971@postgrespro.ru", "phone": "+70420220248"}
0005432530464	4B19F8	8600 795492	NADEZHDA NESTEROVA	{"email": "nesterova.nadezhda-02121968@postgrespro.ru", "phone": "+70889155733"}
0005432530465	4B19F8	9928 132304	ALEKSANDR GRIGOREV	{"phone": "+70912327816"}
0005432530466	EB760C	8056 812811	ALEKSANDR POPOV	{"email": "popov_aleksandr.041977@postgrespro.ru", "phone": "+70454064473"}
0005432530467	FC445D	2436 875270	VITALIY ABRAMOV	{"email": "abramov-v-1968@postgrespro.ru", "phone": "+70641256976"}
0005432530468	FC445D	9649 534542	ZINAIDA TIMOFEEVA	{"phone": "+70709715638"}
0005432530469	FC445D	3241 265289	PETR BELOV	{"email": "pbelov07081982@postgrespro.ru", "phone": "+70423600091"}
0005432530470	7C56CE	7239 298125	ALEKSANDR FEDOTOV	{"email": "fedotov_a-1969@postgrespro.ru", "phone": "+70001873690"}
0005432530471	12B70F	0132 598893	STANISLAV STEPANOV	{"phone": "+70275217241"}
0005432530472	12B70F	3472 140869	OLEG TIMOFEEV	{"phone": "+70480881725"}
0005432530473	12B70F	4416 883532	YANA MAKSIMOVA	{"email": "maksimova.y1965@postgrespro.ru", "phone": "+70559730652"}
0005432530474	F926B1	9195 891522	ANDREY MIKHAYLOV	{"phone": "+70852735543"}
0005432530475	AC794B	7896 681709	ILDAR GRIGOREV	{"email": "igrigorev_02031975@postgrespro.ru", "phone": "+70704886789"}
0005432530476	986D19	4714 353282	VLADIMIR PETROV	{"phone": "+70764291960"}
0005432530477	553703	3062 030463	EKATERINA MEDVEDEVA	{"email": "ekaterina-medvedeva09051956@postgrespro.ru", "phone": "+70414044093"}
0005432530478	7A5E1A	9516 508845	VLADIMIR VASILEV	{"phone": "+70724707200"}
0005432530479	7A5E1A	8977 132032	IGOR FEDOROV	{"email": "igor_fedorov-02081973@postgrespro.ru", "phone": "+70950646361"}
0005432530480	54BE21	3489 657848	LYUBOV SAVELEVA	{"phone": "+70742303245"}
0005432530481	9968A4	3114 791504	ALEKSEY IVANOV	{"email": "ivanova.101961@postgrespro.ru", "phone": "+70163727033"}
0005432530482	94FDD8	7028 722588	MARIYA FOMINA	{"phone": "+70379091675"}
0005432530483	2E709E	4069 589278	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova061965@postgrespro.ru", "phone": "+70694121686"}
0005432530484	2E709E	9496 456189	TAMARA KALININA	{"email": "kalinina_t-30051976@postgrespro.ru", "phone": "+70102830721"}
0005432530485	F6E09D	2765 294438	VLADIMIR MAKAROV	{"email": "makarov-v-20091969@postgrespro.ru", "phone": "+70884339062"}
0005432530486	D1525D	2693 470749	LYUDMILA IVANOVA	{"email": "ivanova.l.011973@postgrespro.ru", "phone": "+70526671965"}
0005432530487	D1525D	2217 005292	ANNA EGOROVA	{"phone": "+70315503419"}
0005432530488	2F8C14	4194 886077	SERGEY POPOV	{"phone": "+70218107213"}
0005432530489	FF6323	5904 637664	NINA ANTONOVA	{"email": "antonova_n15081973@postgrespro.ru", "phone": "+70095990591"}
0005432530490	FF6323	8720 432014	OLEG STEPANOV	{"email": "stepanov_o.091976@postgrespro.ru", "phone": "+70622412459"}
0005432530491	F3F16B	7984 964638	DMITRIY GERASIMOV	{"phone": "+70377011610"}
0005432530492	3C6D1A	7476 280274	OLEG NIKOLAEV	{"email": "oleg-nikolaev_21111982@postgrespro.ru", "phone": "+70482782387"}
0005432530493	1B24C8	5291 455989	GEORGIY EGOROV	{"email": "egorovg071975@postgrespro.ru", "phone": "+70572770305"}
0005432530494	EA87BD	5645 374912	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey_071971@postgrespro.ru", "phone": "+70622114013"}
0005432530495	7BB5F1	9220 407498	LYUDMILA MIKHAYLOVA	{"phone": "+70871515412"}
0005432530496	CA019D	6052 109539	ANASTASIYA STEPANOVA	{"email": "a_stepanova1977@postgrespro.ru", "phone": "+70233263507"}
0005432530497	362A9D	4499 905491	ALEKSANDR PETROV	{"email": "petrov_aleksandr-1977@postgrespro.ru", "phone": "+70260157556"}
0005432530498	362A9D	9887 416619	ZOYA VASILEVA	{"email": "vasileva-z_1976@postgrespro.ru", "phone": "+70367059263"}
0005432530499	2D49C9	6766 917837	ANATOLIY BORISOV	{"email": "a_borisov.011982@postgrespro.ru", "phone": "+70466450150"}
0005432530500	FB7902	1165 243053	KARINA TIKHONOVA	{"email": "ktikhonova041977@postgrespro.ru", "phone": "+70254135723"}
0005432530501	FB7902	4920 868353	EVGENIY VASILEV	{"phone": "+70190105586"}
0005432530502	C17AE7	4872 032081	KSENIYA KRASNOVA	{"phone": "+70625512363"}
0005432530503	A71ADD	3539 738488	GALINA EGOROVA	{"email": "egorova_galina-061976@postgrespro.ru", "phone": "+70190926396"}
0005432530504	B438DA	7860 852549	ELENA KOLESNIKOVA	{"email": "kolesnikova_e-06111974@postgrespro.ru", "phone": "+70303307752"}
0005432530505	2E7D7D	5522 901145	ALEKSEY BELOV	{"email": "abelov.041987@postgrespro.ru", "phone": "+70548890468"}
0005432530506	C38D07	6234 664631	ROMAN MAKSIMOV	{"phone": "+70874805239"}
0005432530507	C38D07	2789 421805	ANTON NAZAROV	{"email": "nazarovanton1965@postgrespro.ru", "phone": "+70696099809"}
0005432530508	C38D07	1041 891839	RAISA BORISOVA	{"email": "raisa-borisova.07121962@postgrespro.ru", "phone": "+70172504166"}
0005432530509	52238E	2321 646251	VITALIY FEDOROV	{"phone": "+70369322645"}
0005432530510	52238E	4582 510056	VALENTINA NIKITINA	{"email": "nikitina_valentina-04031975@postgrespro.ru", "phone": "+70195474307"}
0005432530511	287592	1480 703077	MARINA ROMANOVA	{"phone": "+70785772428"}
0005432530512	687433	1014 420997	RAUF VOLKOV	{"email": "rauf.volkov_29111966@postgrespro.ru", "phone": "+70095376170"}
0005432530513	3AEC95	3344 741922	EVGENIY SMIRNOV	{"phone": "+70399745960"}
0005432530514	3E86EA	9409 017282	SVETLANA KUZNECOVA	{"phone": "+70304413976"}
0005432530515	6108C3	1310 698664	VLADIMIR PETROV	{"phone": "+70575564717"}
0005432530516	6108C3	6443 946902	ILYA POPOV	{"email": "popov_ilya_05031973@postgrespro.ru", "phone": "+70635340460"}
0005432530517	6108C3	8384 471391	DMITRIY VOLKOV	{"phone": "+70510812792"}
0005432530518	0117E7	2552 158209	OLGA MOROZOVA	{"email": "olga-morozova.111973@postgrespro.ru", "phone": "+70493962092"}
0005432530519	AB86BE	7533 636212	VERONIKA STEPANOVA	{"phone": "+70795890908"}
0005432530520	DB40B5	6318 106158	TATYANA ZHURAVLEVA	{"phone": "+70854544689"}
0005432530521	B99D5B	0396 728737	LYUBOV MALYSHEVA	{"email": "lyubovmalysheva.021963@postgrespro.ru", "phone": "+70150421155"}
0005432530522	B99D5B	2975 669154	ALEKSANDR KUZNECOV	{"phone": "+70565227470"}
0005432530523	5CF186	8900 959022	ANTON FROLOV	{"email": "frolov-anton_03011970@postgrespro.ru", "phone": "+70543928465"}
0005432530524	5CF186	8966 121989	ANDREY KUZNECOV	{"email": "kuznecova1983@postgrespro.ru", "phone": "+70190910184"}
0005432530525	5CF186	3481 261145	NINA GUSEVA	{"phone": "+70513593387"}
0005432530526	989EA6	0573 626057	VERA ORLOVA	{"email": "vorlova-121971@postgrespro.ru", "phone": "+70729755624"}
0005432530695	79BDEA	6599 781588	VALENTINA TIKHONOVA	{"phone": "+70390138247"}
0005432530527	530FFF	0670 432959	GALINA KARPOVA	{"email": "g.karpova_1976@postgrespro.ru", "phone": "+70314750912"}
0005432530528	6BC3EF	5396 611875	ELENA MELNIKOVA	{"email": "e_melnikova.1969@postgrespro.ru", "phone": "+70556522631"}
0005432530529	9DAA27	1755 148325	ANATOLIY MOROZOV	{"phone": "+70087198402"}
0005432530530	6DDE25	9728 237009	VERA LOGINOVA	{"email": "vloginova-25121965@postgrespro.ru", "phone": "+70675596704"}
0005432530531	963B23	4496 408691	SERGEY MOISEEV	{"email": "sergey_moiseev_21081974@postgrespro.ru", "phone": "+70707288655"}
0005432530532	963B23	2794 143010	TATYANA KUZMINA	{"email": "tatyana_kuzmina_121977@postgrespro.ru", "phone": "+70176446598"}
0005432530533	963B23	0716 168785	ROMAN TIKHONOV	{"phone": "+70718872336"}
0005432530534	963B23	0791 711736	SERGEY BORISOV	{"email": "sergey.borisov1968@postgrespro.ru", "phone": "+70584032202"}
0005432530535	756F9E	0594 138802	ANDREY MIKHAYLOV	{"email": "andrey.mikhaylov-1961@postgrespro.ru", "phone": "+70460987451"}
0005432530536	9082E0	5991 104649	MARINA LAZAREVA	{"email": "lazarevam_031972@postgrespro.ru", "phone": "+70029251623"}
0005432530537	C8E6C0	5536 105679	MARINA FILIPPOVA	{"email": "m-filippova-14011972@postgrespro.ru", "phone": "+70048013215"}
0005432530538	E19B01	3199 360192	EVGENIY KISELEV	{"email": "kiselev-evgeniy1969@postgrespro.ru", "phone": "+70721326643"}
0005432530539	E19B01	8119 500929	MIKHAIL MOROZOV	{"phone": "+70560044005"}
0005432530540	F8E35B	3137 087285	VYACHESLAV ZHURAVLEV	{"email": "v.zhuravlev-1963@postgrespro.ru", "phone": "+70286391407"}
0005432530541	7624D6	9383 231983	ANNA MEDVEDEVA	{"email": "medvedeva-anna27031974@postgrespro.ru", "phone": "+70475087229"}
0005432530542	7624D6	7171 030357	DMITRIY ALEKSANDROV	{"phone": "+70719207986"}
0005432530543	70EDDF	1200 759609	TATYANA ALEKSEEVA	{"email": "alekseeva-t_09031973@postgrespro.ru", "phone": "+70480392098"}
0005432530544	AD068D	9834 653542	SERGEY KAZAKOV	{"email": "s_kazakov-1968@postgrespro.ru", "phone": "+70574229457"}
0005432530545	F532C2	3786 271307	MATVEY FEDOROV	{"phone": "+70751826970"}
0005432530546	F532C2	7940 804631	ALEKSANDR AFANASEV	{"email": "a.afanasev.1960@postgrespro.ru", "phone": "+70383035633"}
0005432530547	155BC2	5968 600451	SERGEY ALEKSEEV	{"email": "alekseev.s_021967@postgrespro.ru", "phone": "+70985547958"}
0005432530548	155BC2	2460 487592	ALENA KUZNECOVA	{"email": "kuznecovaa-1958@postgrespro.ru", "phone": "+70695338723"}
0005432530549	9C1B29	2168 963097	ARTEM BORISOV	{"email": "borisov-artem12071980@postgrespro.ru", "phone": "+70362216997"}
0005432530550	1E4CD0	4036 512831	MARINA VASILEVA	{"phone": "+70260258359"}
0005432530551	1E4CD0	5976 033994	NURIYA ANDREEVA	{"phone": "+70204217363"}
0005432530552	9D0ACB	1059 507211	YURIY MIRONOV	{"phone": "+70700077465"}
0005432530553	9D0ACB	7224 115820	VLADIMIR KUZMIN	{"email": "kuzminv-061973@postgrespro.ru", "phone": "+70710307449"}
0005432530554	5FD922	3205 850485	TATYANA POPOVA	{"email": "t.popova08061979@postgrespro.ru", "phone": "+70962167499"}
0005432530555	5FD922	0242 846940	IRINA IVANOVA	{"phone": "+70123801285"}
0005432530556	6469D9	6535 541535	NATALIYA ANDREEVA	{"phone": "+70235166271"}
0005432530557	6469D9	9151 084726	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr_061971@postgrespro.ru", "phone": "+70385783573"}
0005432530558	6469D9	4609 808458	DMITRIY DAVYDOV	{"phone": "+70451832266"}
0005432530559	5C6F5B	0951 021195	SERGEY MIKHAYLOV	{"phone": "+70334555672"}
0005432530560	96C8F6	4000 894380	VALERIY SOKOLOV	{"email": "v-sokolov-1970@postgrespro.ru", "phone": "+70293477681"}
0005432530561	1D98D2	2346 832181	GALINA KOROLEVA	{"email": "koroleva-galina.22021978@postgrespro.ru", "phone": "+70244817553"}
0005432530562	13FCEC	1596 852432	ALEKSEY ABRAMOV	{"phone": "+70091282941"}
0005432530563	13FCEC	9268 635246	VALENTINA SEMENOVA	{"email": "v_semenova1977@postgrespro.ru", "phone": "+70430305452"}
0005432530564	AF5019	2135 771421	VLADIMIR GAVRILOV	{"email": "v_gavrilov21101982@postgrespro.ru", "phone": "+70020218175"}
0005432530565	5607F8	0604 588781	ZAKHAR TIMOFEEV	{"email": "timofeev-z_06031968@postgrespro.ru", "phone": "+70664641719"}
0005432530566	35D0E1	6072 046160	OLEG MIKHAYLOV	{"email": "oleg.mikhaylov_05121965@postgrespro.ru", "phone": "+70833539827"}
0005432530567	35D0E1	7138 537382	MARIYA RODIONOVA	{"phone": "+70472385075"}
0005432530568	39C4DC	9080 666598	VLADIMIR RODIONOV	{"email": "vladimir_rodionov-1980@postgrespro.ru", "phone": "+70074859327"}
0005432530569	81C769	9144 680683	VERA ROMANOVA	{"phone": "+70230094651"}
0005432530570	F25CAD	9480 347682	SERGEY KUZMIN	{"phone": "+70656911554"}
0005432530571	4430F0	5923 961670	ALEKSANDR ORLOV	{"phone": "+70784553245"}
0005432530572	4430F0	5620 622009	VIKTORIYA SIDOROVA	{"email": "sidorova_v-101977@postgrespro.ru", "phone": "+70704417798"}
0005432530573	B00EE5	9388 491869	SERGEY IVANOV	{"phone": "+70398098280"}
0005432530574	630D45	4301 372848	ALEKSANDR AFANASEV	{"email": "a.afanasev.1974@postgrespro.ru", "phone": "+70829641946"}
0005432530575	630D45	1726 652169	VALENTINA RODIONOVA	{"phone": "+70680989964"}
0005432530576	C6E22C	7279 397165	GALINA PETROVA	{"phone": "+70438490339"}
0005432530577	662696	4426 419907	PRASKOVYA KOROLEVA	{"email": "praskovyakoroleva_25091968@postgrespro.ru", "phone": "+70141186857"}
0005432530578	2A4191	3195 562951	ANDREY IVANOV	{"email": "a-ivanov101976@postgrespro.ru", "phone": "+70081001284"}
0005432530579	FA879F	2102 267491	LYUCIYA BELYAEVA	{"email": "belyaeva_lyuciya.1979@postgrespro.ru", "phone": "+70821518740"}
0005432530580	47C18A	4029 255480	GEORGIY KRASNOV	{"email": "krasnov-g.03061974@postgrespro.ru", "phone": "+70931550930"}
0005432530581	ADD33E	7198 795452	LYUDMILA CHERNOVA	{"phone": "+70583939372"}
0005432530582	D5FE18	1643 818554	ANNA KAZAKOVA	{"email": "a.kazakova_26071984@postgrespro.ru", "phone": "+70856160598"}
0005432530583	860C1C	2680 424132	TAMARA BORISOVA	{"phone": "+70933851111"}
0005432530584	D6F8E9	9800 996502	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_a1973@postgrespro.ru", "phone": "+70384037067"}
0005432530585	D6F8E9	9861 760758	ELENA MASLOVA	{"email": "elena.maslova-22031978@postgrespro.ru", "phone": "+70376121930"}
0005432530586	AA6623	6129 177763	VALERIYA MOISEEVA	{"email": "valeriya_moiseeva_1971@postgrespro.ru", "phone": "+70195003841"}
0005432530587	4B3349	6395 134318	NATALYA ERMAKOVA	{"email": "ermakovanatalya_31121975@postgrespro.ru", "phone": "+70141910811"}
0005432530588	378749	1288 010946	NATALYA FEDOROVA	{"phone": "+70390004194"}
0005432530589	90620F	5299 776355	NATALYA TIKHONOVA	{"email": "tikhonova.natalya-091958@postgrespro.ru", "phone": "+70685279650"}
0005432530590	B93D4D	4615 756446	PETR KUZNECOV	{"phone": "+70568830887"}
0005432530591	FE08AD	3573 018876	GENNADIY ISAEV	{"email": "isaev-gennadiy_1976@postgrespro.ru", "phone": "+70868447053"}
0005432530592	E519B6	7664 065920	SOFIYA YUDINA	{"email": "sofiya-yudina-041978@postgrespro.ru", "phone": "+70465469907"}
0005432530593	DE9F34	3345 067238	ALEKSANDR SOKOLOV	{"phone": "+70708195155"}
0005432530594	DE9F34	7590 030874	ALESYA BORISOVA	{"email": "borisova_alesya_27041976@postgrespro.ru", "phone": "+70984239772"}
0005432530595	DE9F34	8135 458381	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov_05041963@postgrespro.ru", "phone": "+70965206138"}
0005432530596	E4C365	0682 295733	ANASTASIYA ISAEVA	{"email": "anastasiyaisaeva.1982@postgrespro.ru", "phone": "+70347180012"}
0005432530597	3D8014	5023 906710	TATYANA KUZMINA	{"phone": "+70606184635"}
0005432530598	DAD101	5362 592328	OKSANA ORLOVA	{"email": "o.orlova_1967@postgrespro.ru", "phone": "+70138921647"}
0005432530599	DAD101	9940 349470	ELVIRA MOROZOVA	{"email": "elviramorozova13041965@postgrespro.ru", "phone": "+70972317683"}
0005432530600	34704A	6219 734921	DAVID ANDREEV	{"email": "andreev-d25041972@postgrespro.ru", "phone": "+70191634615"}
0005432530602	90ED18	0151 082563	IRAIDA NAZAROVA	{"phone": "+70189645799"}
0005432530603	89CF97	2413 976007	ELENA ORLOVA	{"email": "orlova-e_011972@postgrespro.ru", "phone": "+70556033502"}
0005432530604	89CF97	9188 933900	ELENA MAKAROVA	{"email": "e_makarova061970@postgrespro.ru", "phone": "+70402409438"}
0005432530605	C1C61F	5473 595427	NATALYA KUZNECOVA	{"email": "n.kuznecova_1970@postgrespro.ru", "phone": "+70353592404"}
0005432530606	500F9B	3722 696691	VLADIMIR VLASOV	{"email": "vladimir-vlasov_1970@postgrespro.ru", "phone": "+70771647756"}
0005432530607	500F9B	2419 979618	NATALYA MAKAROVA	{"phone": "+70431568256"}
0005432530608	3F4701	8944 403201	NATALYA ROMANOVA	{"phone": "+70504314726"}
0005432530609	F3D654	4881 914009	MIKHAIL SAVELEV	{"phone": "+70454980902"}
0005432530610	F3D654	8141 951652	NINA EGOROVA	{"phone": "+70196946259"}
0005432530611	C564B1	1435 656868	LYUDMILA MOROZOVA	{"phone": "+70464509782"}
0005432530612	28768B	9570 554065	NIKITA BELOV	{"phone": "+70066602352"}
0005432530613	28768B	2713 625271	ARTEM ROMANOV	{"phone": "+70814388254"}
0005432530614	E9150B	5001 509658	ANDREY MOISEEV	{"email": "andreymoiseev_1977@postgrespro.ru", "phone": "+70360515748"}
0005432530615	866B93	5692 172172	ALEKSANDRA ABRAMOVA	{"phone": "+70592476839"}
0005432530616	AA15C0	3903 619822	VLADISLAV FEDOTOV	{"phone": "+70562259059"}
0005432530617	AA15C0	2212 471879	ALEKSEY MOISEEV	{"email": "a_moiseev17081968@postgrespro.ru", "phone": "+70557709304"}
0005432530618	971CFA	6597 141120	ILDAR KONOVALOV	{"email": "konovalov-ildar1975@postgrespro.ru", "phone": "+70157294963"}
0005432530619	982149	4794 923926	ANDREY MOROZOV	{"phone": "+70701156159"}
0005432530620	982149	2152 780698	ALEKSEY IVANOV	{"email": "ivanov.aleksey-101983@postgrespro.ru", "phone": "+70066729692"}
0005432530621	7B7E3A	8688 772328	YURIY PETROV	{"email": "yuriy-petrov_1977@postgrespro.ru", "phone": "+70113444319"}
0005432530622	7B7E3A	3634 854315	KONSTANTIN KUZMIN	{"email": "kuzminkonstantin-041970@postgrespro.ru", "phone": "+70632092201"}
0005432530623	ED4C54	6743 620133	KSENIYA PETROVA	{"email": "k-petrova_03041974@postgrespro.ru", "phone": "+70710506704"}
0005432530624	919383	7188 588684	YULIYA VASILEVA	{"email": "vasilevayuliya-031973@postgrespro.ru", "phone": "+70597429645"}
0005432530625	737D01	9432 664429	NIKITA ILIN	{"phone": "+70038786325"}
0005432530626	737D01	4179 666251	SERGEY SOLOVEV	{"phone": "+70802241616"}
0005432530627	A714D7	9512 440635	TATYANA KRASNOVA	{"email": "krasnovat_1974@postgrespro.ru", "phone": "+70923403004"}
0005432530628	7E6CD8	7909 430269	MIKHAIL DENISOV	{"phone": "+70850383774"}
0005432530629	CC3ED0	2833 331694	DARYA PETROVA	{"phone": "+70924082719"}
0005432530630	24C911	4407 500409	NIKOLAY MOROZOV	{"phone": "+70314244223"}
0005432530631	24C911	5030 175155	GENNADIY MELNIKOV	{"phone": "+70380678553"}
0005432530632	22918E	6601 911757	YURIY GAVRILOV	{"email": "y-gavrilov_31121971@postgrespro.ru", "phone": "+70623932856"}
0005432530633	22918E	6128 831231	EGOR NIKITIN	{"phone": "+70885085430"}
0005432530634	25857F	3951 018599	ANDREY DMITRIEV	{"email": "andrey_dmitriev_15091965@postgrespro.ru", "phone": "+70289566444"}
0005432530635	F4FF71	2514 211015	ANNA NAUMOVA	{"phone": "+70482100221"}
0005432530636	9268BF	1463 351906	YURIY KUZNECOV	{"email": "kuznecov_y_1964@postgrespro.ru", "phone": "+70565438404"}
0005432530637	E06FA8	2477 053286	MARINA MAKAROVA	{"phone": "+70868821755"}
0005432530638	E06FA8	8516 792057	NIKOLAY NIKOLAEV	{"email": "nikolaev-n-02021957@postgrespro.ru", "phone": "+70955025545"}
0005432530639	415157	5632 863256	GULIYA KARPOVA	{"phone": "+70973108389"}
0005432530640	415157	1577 521592	OLGA TARASOVA	{"phone": "+70764801472"}
0005432530641	CAC607	0847 284333	GALINA TIMOFEEVA	{"email": "timofeeva_g_081981@postgrespro.ru", "phone": "+70571418538"}
0005432530642	1FEFDD	8996 350404	PAVEL EGOROV	{"phone": "+70127349187"}
0005432530643	1FEFDD	0149 731079	LYUDMILA MIKHAYLOVA	{"phone": "+70502263827"}
0005432530644	EE4CB5	2244 273577	DENIS MIKHAYLOV	{"email": "mikhaylov-d-10071974@postgrespro.ru", "phone": "+70778060520"}
0005432530645	2FB5EC	3975 689861	LYUBOV ISAEVA	{"phone": "+70617767235"}
0005432530646	D4065A	2367 422121	TIMUR KUZNECOV	{"phone": "+70422248922"}
0005432530647	D4065A	4719 720940	ZHANNA OSIPOVA	{"phone": "+70049149148"}
0005432530648	54E06A	3347 322306	VLADIMIR NOVIKOV	{"phone": "+70924028669"}
0005432530649	B135EA	6406 452106	OKSANA KAZAKOVA	{"phone": "+70216714779"}
0005432530650	B135EA	1692 973724	VALENTINA ILINA	{"email": "valentina-ilina061975@postgrespro.ru", "phone": "+70252361772"}
0005432530651	747B02	7829 847519	VITALIY SERGEEV	{"email": "sergeev.v081966@postgrespro.ru", "phone": "+70176454875"}
0005432530652	874463	0835 231207	VASILIY ZHUKOV	{"phone": "+70234320237"}
0005432530653	CEA36F	4800 888873	DENIS GERASIMOV	{"phone": "+70951187403"}
0005432530654	CEA36F	8535 687191	SERGEY POPOV	{"email": "sergeypopov_111972@postgrespro.ru", "phone": "+70280655398"}
0005432530655	7CA8E7	5636 695243	GALINA SIDOROVA	{"email": "galina_sidorova.07011975@postgrespro.ru", "phone": "+70983382330"}
0005432530656	7CA8E7	1882 374603	DANIL ZHURAVLEV	{"phone": "+70523300841"}
0005432530657	847C73	3955 412286	PAVEL SEMENOV	{"email": "pavel_semenov1970@postgrespro.ru", "phone": "+70864798187"}
0005432530658	847C73	1360 400026	MAKSIM BARANOV	{"email": "maksim-baranov-27121965@postgrespro.ru", "phone": "+70279695842"}
0005432530659	239259	7655 729619	SERGEY GORBUNOV	{"phone": "+70337354938"}
0005432530660	239259	8160 849336	ANASTASIYA KOZLOVA	{"phone": "+70862124588"}
0005432530661	EF11C3	1149 898884	NAIL ZAYCEV	{"phone": "+70035043534"}
0005432530662	EF11C3	8331 041469	TIMOFEY ORLOV	{"phone": "+70273812931"}
0005432530663	03072F	8181 455301	MAKSIM IVANOV	{"email": "m_ivanov.071971@postgrespro.ru", "phone": "+70881762310"}
0005432530664	383F41	0871 916223	VALENTIN GAVRILOV	{"phone": "+70874900745"}
0005432530665	383F41	7417 711732	ELIZAVETA PAVLOVA	{"phone": "+70531416428"}
0005432530666	E80173	1581 136129	VALERIY GRIGOREV	{"email": "v_grigorev_061974@postgrespro.ru", "phone": "+70529627171"}
0005432530667	E80173	9349 038298	ALEKSEY DMITRIEV	{"email": "alekseydmitriev_091962@postgrespro.ru", "phone": "+70895762586"}
0005432530668	E8E32F	0068 266044	TATYANA VASILEVA	{"phone": "+70240958418"}
0005432530669	E8E32F	2464 358439	MAKSIM FEDOTOV	{"phone": "+70638775434"}
0005432530670	B20B7E	2915 003225	MARIYA ORLOVA	{"email": "orlova_mariya1975@postgrespro.ru", "phone": "+70482274056"}
0005432530671	5585CE	3802 136338	SERGEY IVANOV	{"email": "s.ivanov-14101973@postgrespro.ru", "phone": "+70156269588"}
0005432530672	DE15E8	1029 969366	GALINA VASILEVA	{"phone": "+70671084286"}
0005432530673	DE15E8	3521 223699	VLADIMIR FROLOV	{"phone": "+70476527080"}
0005432530674	CAB72F	2884 999406	SVETLANA YAKOVLEVA	{"email": "s.yakovleva1981@postgrespro.ru", "phone": "+70141161544"}
0005432530675	CAB72F	6131 115022	IRAIDA ILINA	{"email": "ilinai1975@postgrespro.ru", "phone": "+70288055102"}
0005432530676	CAB72F	7654 002406	TATYANA MIKHAYLOVA	{"phone": "+70710785984"}
0005432530677	CD11E9	7025 775232	ANDREY AFANASEV	{"phone": "+70595259728"}
0005432530678	DD2AA7	7715 182664	VALENTINA NESTEROVA	{"email": "vnesterova.091983@postgrespro.ru", "phone": "+70940152967"}
0005432530679	D67E95	9199 572533	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr.06041964@postgrespro.ru", "phone": "+70044987377"}
0005432530680	FF7F7C	6821 394850	ILYA SOROKIN	{"email": "i.sorokin1976@postgrespro.ru", "phone": "+70779615021"}
0005432530681	FF7F7C	1084 707054	MARINA BELOVA	{"phone": "+70612486752"}
0005432530682	FF7F7C	0514 994519	ANTONINA ANTONOVA	{"email": "antonova.antonina041957@postgrespro.ru", "phone": "+70232329356"}
0005432530683	5470D9	8829 384774	ALEKSANDRA GUSEVA	{"phone": "+70260934857"}
0005432530684	5470D9	0319 297790	EVGENIY MOROZOV	{"email": "e_morozov_1968@postgrespro.ru", "phone": "+70068055959"}
0005432530685	9947DB	2373 577964	ALEVTINA KISELEVA	{"email": "kiseleva.a071962@postgrespro.ru", "phone": "+70460014841"}
0005432530686	9947DB	2644 972579	NINA FILIPPOVA	{"email": "n.filippova101977@postgrespro.ru", "phone": "+70945145229"}
0005432530687	1A0F93	3092 834024	ZINAIDA MATVEEVA	{"phone": "+70596275327"}
0005432530688	1A0F93	9072 508622	TATYANA IVANOVA	{"phone": "+70277163074"}
0005432530689	69495D	9282 838477	DMITRIY YAKOVLEV	{"email": "yakovlevdmitriy.30081971@postgrespro.ru", "phone": "+70499235412"}
0005432530690	C80A56	1416 752708	MARINA NIKITINA	{"phone": "+70709095599"}
0005432530691	C80A56	0213 410089	ALEKSEY DMITRIEV	{"phone": "+70984128217"}
0005432530692	AAEA3A	1653 449697	NINA LUKYANOVA	{"phone": "+70603237246"}
0005432530693	AAEA3A	3869 308338	IVAN ABRAMOV	{"email": "abramovi031980@postgrespro.ru", "phone": "+70272534383"}
0005432530694	AAEA3A	1919 942049	OLGA ANDREEVA	{"email": "andreevaolga.061968@postgrespro.ru", "phone": "+70586117583"}
0005432530696	79BDEA	8199 250486	ANTONIDA IVANOVA	{"email": "aivanova_061979@postgrespro.ru", "phone": "+70009734648"}
0005432530697	663D09	6081 446569	ELENA ALEKSEEVA	{"email": "elena.alekseeva041972@postgrespro.ru", "phone": "+70321140685"}
0005432530698	663D09	6106 977547	NATALYA KOROLEVA	{"phone": "+70136321058"}
0005432530699	DF8D7E	8460 725902	ANTONINA KUZNECOVA	{"email": "kuznecova_antonina.051964@postgrespro.ru", "phone": "+70115455825"}
0005432530700	D54C69	4057 574942	VLADISLAV MIKHAYLOV	{"phone": "+70213378710"}
0005432530701	D54C69	8521 824684	DARYA FEDOROVA	{"email": "fedorova_darya-1960@postgrespro.ru", "phone": "+70882607740"}
0005432530702	05F7C0	5105 973840	NATALYA MOROZOVA	{"phone": "+70118078918"}
0005432530703	05F7C0	8067 579842	VLADIMIR NOVIKOV	{"phone": "+70942497416"}
0005432530704	1BB710	9809 672901	DMITRIY ALEKSEEV	{"email": "alekseevd25111976@postgrespro.ru", "phone": "+70092581884"}
0005432530705	7A30B4	6659 078676	TATYANA VASILEVA	{"email": "tatyanavasileva_1973@postgrespro.ru", "phone": "+70537392573"}
0005432530706	7D1CFA	8899 922428	ANNA FEDOROVA	{"email": "anna-fedorova_05101960@postgrespro.ru", "phone": "+70946246938"}
0005432530707	8FD631	9042 351302	NIKOLAY ISAEV	{"phone": "+70681717043"}
0005432530708	8FD631	3190 485129	OLGA GAVRILOVA	{"email": "gavrilova-olga.121967@postgrespro.ru", "phone": "+70085612410"}
0005432530709	2833D9	9782 186155	VYACHESLAV FILIPPOV	{"phone": "+70021125538"}
0005432530710	2833D9	5440 730855	ANASTASIYA NIKITINA	{"phone": "+70415361250"}
0005432530711	771BCC	8414 885706	RAISA TROFIMOVA	{"email": "raisa.trofimova111973@postgrespro.ru", "phone": "+70539127143"}
0005432530712	3BEC08	4006 280481	TATYANA MATVEEVA	{"email": "matveeva-t_1971@postgrespro.ru", "phone": "+70131090362"}
0005432530713	DFDCEC	8425 319568	NATALYA POPOVA	{"email": "natalya_popova-1967@postgrespro.ru", "phone": "+70473170653"}
0005432530714	DFDCEC	4615 528609	NIKOLAY KAZAKOV	{"phone": "+70128107285"}
0005432530715	C2B279	4671 903311	ANTONINA ROMANOVA	{"email": "a_romanova.011968@postgrespro.ru", "phone": "+70976928600"}
0005432530716	C2B279	1379 673120	VLADIMIR BELOV	{"phone": "+70325925561"}
0005432530717	C2B279	1218 101784	REGINA ZOTOVA	{"phone": "+70868278282"}
0005432530718	B2985C	0467 239235	ALEKSANDR SCHERBAKOV	{"phone": "+70723976352"}
0005432530719	0A5D1C	1602 566759	GALINA MIRONOVA	{"email": "mironova_galina_25091978@postgrespro.ru", "phone": "+70847556006"}
0005432530720	0A5D1C	6063 832957	DMITRIY ILIN	{"email": "ilind.101963@postgrespro.ru", "phone": "+70853514740"}
0005432530721	5A26A1	2451 610613	ANATOLIY SOKOLOV	{"email": "anatoliy-sokolov1977@postgrespro.ru", "phone": "+70452350312"}
0005432530722	5A26A1	7615 491225	ANTON KUZNECOV	{"phone": "+70237651767"}
0005432530723	EB491D	6712 505694	VALERIYA MEDVEDEVA	{"email": "v_medvedeva.1972@postgrespro.ru", "phone": "+70010787136"}
0005432530724	56EF84	6949 541113	LYUBOV NOVIKOVA	{"email": "novikova-lyubov_1961@postgrespro.ru", "phone": "+70651792471"}
0005432530725	56EF84	8983 366179	IRINA NIKOLAEVA	{"phone": "+70696948698"}
0005432530726	10B84F	3062 045876	ANDREY IVANOV	{"email": "ivanov.andrey.1974@postgrespro.ru", "phone": "+70656121787"}
0005432530727	F39FE0	7972 154310	PAVEL BONDARENKO	{"phone": "+70336981092"}
0005432530728	3D4C0C	0469 012235	ALEKSEY CHERNOV	{"phone": "+70036440760"}
0005432530729	CCCC22	8676 294457	GALINA RODIONOVA	{"phone": "+70047649842"}
0005432530730	0D8AE9	2989 745209	VLADIMIR NIKITIN	{"phone": "+70940785579"}
0005432530731	5146F6	5740 812453	NINA POPOVA	{"email": "nina.popova.08091971@postgrespro.ru", "phone": "+70764828552"}
0005432530732	5146F6	8687 934175	ALEKSANDR NOVIKOV	{"email": "a_novikov.13091981@postgrespro.ru", "phone": "+70100400098"}
0005432530733	EAD140	3945 368639	VALERIY POPOV	{"email": "vpopov_091961@postgrespro.ru", "phone": "+70791462587"}
0005432530734	0BBE21	4222 513137	VASILIY SOKOLOV	{"phone": "+70721316027"}
0005432530735	0BBE21	8516 741835	ELENA OSIPOVA	{"email": "e-osipova-071963@postgrespro.ru", "phone": "+70837964754"}
0005432530736	4BFD9D	2050 423300	GALINA VOLKOVA	{"email": "galina-volkova_26011957@postgrespro.ru", "phone": "+70917520829"}
0005432530737	4BFD9D	7885 075814	VERA EGOROVA	{"email": "egorova-v_1971@postgrespro.ru", "phone": "+70114313191"}
0005432530738	C83CEF	3653 656627	SERGEY FEDOROV	{"phone": "+70457691228"}
0005432530739	C83CEF	8451 382312	MIKHAIL NIKITIN	{"phone": "+70269947353"}
0005432530740	CD3320	0400 364750	YURIY ROMANOV	{"phone": "+70174494420"}
0005432530741	CD3320	6709 056146	INNA PETROVA	{"email": "i.petrova111969@postgrespro.ru", "phone": "+70695344480"}
0005432530742	FE8A74	9994 221858	NATALYA ANTONOVA	{"phone": "+70504837676"}
0005432530743	712B57	8077 557919	GALINA ANDREEVA	{"phone": "+70480309764"}
0005432530744	712B57	0796 196568	VALERIY KRASNOV	{"phone": "+70832437531"}
0005432530745	712B57	4546 711302	EKATERINA IVANOVA	{"phone": "+70710079801"}
0005432530746	689D91	9359 202633	VLADIMIR POPOV	{"email": "popov-v_081978@postgrespro.ru", "phone": "+70392773207"}
0005432530747	689D91	5605 279513	ALEKSANDR VASILEV	{"phone": "+70278660858"}
0005432530748	1066D0	5342 795987	ANDREY SHEVCHENKO	{"email": "shevchenko_a.071967@postgrespro.ru", "phone": "+70514648380"}
0005432530749	A15732	1126 336659	SVETLANA OSIPOVA	{"email": "osipovas_1971@postgrespro.ru", "phone": "+70574200920"}
0005432530750	A15732	8183 070654	ANTONINA KOROLEVA	{"email": "koroleva-a1973@postgrespro.ru", "phone": "+70537425879"}
0005432530751	5E65DF	9243 988720	TATYANA TARASOVA	{"email": "tarasova-tatyana-041974@postgrespro.ru", "phone": "+70875611231"}
0005432530752	F1758B	8896 437205	NATALYA NAUMOVA	{"email": "n-naumova_1958@postgrespro.ru", "phone": "+70613271449"}
0005432530753	F7EFF6	0329 572805	ELVIRA OSIPOVA	{"phone": "+70649361835"}
0005432530754	BEDF41	6211 303658	LYUBOV EGOROVA	{"phone": "+70156120325"}
0005432530755	355503	2133 702505	IGOR NOVIKOV	{"phone": "+70216503178"}
0005432530756	0A2916	1380 828145	VIKTORIYA MOISEEVA	{"phone": "+70011344829"}
0005432530757	9F1B75	5218 198971	ANASTASIYA DANILOVA	{"phone": "+70960262148"}
0005432530758	4B90F2	2587 636255	OLGA SIDOROVA	{"phone": "+70840852731"}
0005432530759	4B90F2	9229 712105	NIKOLAY ORLOV	{"phone": "+70707783424"}
0005432530760	AE6BCF	2937 951350	MIKHAIL RODIONOV	{"phone": "+70077765789"}
0005432530761	AE6BCF	9635 664953	VLADIMIR DMITRIEV	{"email": "vladimirdmitriev26071974@postgrespro.ru", "phone": "+70028509351"}
0005432530762	AE6BCF	7179 097677	STEPAN CHERNOV	{"phone": "+70337808253"}
0005432530763	486B95	1650 921644	RUSLAN ZHURAVLEV	{"email": "r_zhuravlev16041969@postgrespro.ru", "phone": "+70332494584"}
0005432530764	486B95	0150 405338	SVETLANA CHERNOVA	{"email": "svetlanachernova_111988@postgrespro.ru", "phone": "+70855399889"}
0005432530765	6CFD44	3992 312381	MARIYA NAUMOVA	{"email": "mariya-naumova-12051979@postgrespro.ru", "phone": "+70149250297"}
0005432530766	A949DF	3372 170273	MIKHAIL EGOROV	{"email": "egorovmikhail-111972@postgrespro.ru", "phone": "+70153095082"}
0005432530767	A949DF	4279 468514	IGOR SOROKIN	{"email": "igor.sorokin.101977@postgrespro.ru", "phone": "+70064671401"}
0005432530768	9EFFB4	2398 426835	GALINA POPOVA	{"phone": "+70087907905"}
0005432530769	366047	0344 081472	VIKTOR VOLKOV	{"email": "volkovviktor16041994@postgrespro.ru", "phone": "+70574323441"}
0005432530770	91C822	6176 253657	ARSENIY IVANOV	{"phone": "+70323330602"}
0005432530771	850735	8619 880250	VALERIY NAZAROV	{"email": "v_nazarov-21061974@postgrespro.ru", "phone": "+70209986320"}
0005432530772	09E4A4	3269 685339	ANASTASIYA GUSEVA	{"phone": "+70832747218"}
0005432530773	FCFD35	7558 920644	ALEKSANDR KONOVALOV	{"phone": "+70073352110"}
0005432530774	032FB1	4693 158586	MARAT NAUMOV	{"phone": "+70216426033"}
0005432530775	032FB1	5784 609822	VALENTINA MAKAROVA	{"phone": "+70290866918"}
0005432530776	7968B7	2502 362450	OLGA ABRAMOVA	{"phone": "+70656051953"}
0005432530777	7968B7	4392 771472	ANATOLIY GUSEV	{"email": "a-gusev121978@postgrespro.ru", "phone": "+70518605237"}
0005432530778	3BB802	8051 722470	SERGEY NOVIKOV	{"email": "s.novikov_1967@postgrespro.ru", "phone": "+70364427115"}
0005432530779	0569B2	2371 614205	IVAN KRASNOV	{"email": "ivankrasnov041971@postgrespro.ru", "phone": "+70555541977"}
0005432530780	BD8AB6	7291 523726	ANNA VLASOVA	{"email": "vlasova-anna-021972@postgrespro.ru", "phone": "+70718778005"}
0005432530781	5C1333	7242 268454	ALEKSANDR ISAEV	{"phone": "+70035170551"}
0005432530782	42F0B0	2379 204476	GALINA KOZLOVA	{"email": "galina-kozlova-21041976@postgrespro.ru", "phone": "+70044269603"}
0005432530783	42F0B0	0966 166310	NATALYA SAVELEVA	{"phone": "+70442688859"}
0005432530784	0C803C	7943 985455	ALEKSANDR MELNIKOV	{"phone": "+70881669019"}
0005432530785	0C803C	1538 972639	OLGA ZHURAVLEVA	{"email": "o.zhuravleva.23041982@postgrespro.ru", "phone": "+70153457944"}
0005432530786	224B0D	5633 461875	TAMARA KISELEVA	{"phone": "+70715409309"}
0005432530787	FDFE0E	3565 682637	SERGEY ILIN	{"email": "silin.041962@postgrespro.ru", "phone": "+70474070536"}
0005432530788	1F097B	2978 883380	RIMA AKIMOVA	{"email": "rima.akimova_1968@postgrespro.ru", "phone": "+70401853566"}
0005432530789	A1364E	4870 086977	LARISA EFIMOVA	{"email": "larisa-efimova.1966@postgrespro.ru", "phone": "+70737085896"}
0005432530790	283DFB	6564 153489	VITALIY MELNIKOV	{"email": "melnikov.vitaliy.1972@postgrespro.ru", "phone": "+70856378276"}
0005432530791	E280AB	5887 867208	LYUDMILA MAKAROVA	{"email": "lyudmilamakarova-1971@postgrespro.ru", "phone": "+70383011167"}
0005432530792	E280AB	1012 463054	OKSANA DMITRIEVA	{"email": "dmitrieva_o.1962@postgrespro.ru", "phone": "+70800905254"}
0005432530793	043317	7795 813274	ANASTASIYA DAVYDOVA	{"email": "davydovaanastasiya.1974@postgrespro.ru", "phone": "+70227852674"}
0005432530794	0DA97E	0331 795243	NADEZHDA KUZNECOVA	{"email": "nadezhda.kuznecova1978@postgrespro.ru", "phone": "+70692493830"}
0005432530795	0DA97E	6335 320708	MARINA ZAKHAROVA	{"phone": "+70545558194"}
0005432530796	83CD75	4260 390073	ANNA KUZMINA	{"phone": "+70156284991"}
0005432530797	C27536	2970 324607	ANASTASIYA VASILEVA	{"phone": "+70036791055"}
0005432530798	21FE26	1986 942423	ANNA MIKHAYLOVA	{"phone": "+70300561227"}
0005432530799	DF82C1	3781 009457	ALEKSEY NIKOLAEV	{"phone": "+70588897168"}
0005432530800	306F25	4591 540110	NATALYA VOLKOVA	{"email": "n_volkova.071964@postgrespro.ru", "phone": "+70248032357"}
0005432530801	3F0018	4168 805215	PAVEL FOMIN	{"phone": "+70948487789"}
0005432530802	CFF662	7762 112255	LYUDMILA KULIKOVA	{"email": "lyudmilakulikova_011982@postgrespro.ru", "phone": "+70749939991"}
0005432530803	26910D	6750 958046	KIRILL YAKOVLEV	{"email": "kirill_yakovlev091971@postgrespro.ru", "phone": "+70392168957"}
0005432530804	1BDD1E	9852 266312	YULIYA IVANOVA	{"email": "yuliyaivanova_031966@postgrespro.ru", "phone": "+70491426645"}
0005432530805	1BDD1E	3633 434266	YULIYA NAUMOVA	{"phone": "+70757882123"}
0005432530806	748D53	0245 439696	NIKITA ROMANOV	{"email": "romanov.nikita01121971@postgrespro.ru", "phone": "+70341335354"}
0005432530807	748D53	0790 186946	ANNA MALYSHEVA	{"email": "a-malysheva1969@postgrespro.ru", "phone": "+70850413668"}
0005432530808	1986F8	7917 280572	DMITRIY BORISOV	{"phone": "+70259613613"}
0005432530809	004391	0479 545583	TATYANA ORLOVA	{"phone": "+70529152691"}
0005432530810	8459C6	5355 150036	RAISA SOROKINA	{"email": "sorokinaraisa_09121964@postgrespro.ru", "phone": "+70924196744"}
0005432530811	796FB1	2181 724520	ALLA KARPOVA	{"email": "a.karpova.01031982@postgrespro.ru", "phone": "+70424261581"}
0005432530812	D76D04	9418 272963	EKATERINA ERMAKOVA	{"phone": "+70155099301"}
0005432530813	CA7E10	7955 222858	YULIYA BORISOVA	{"phone": "+70995166510"}
0005432530814	2A9BEE	5743 235394	MIKHAIL SMIRNOV	{"phone": "+70153281609"}
0005432530815	5AF2F1	6656 389816	LEONID DMITRIEV	{"email": "leonid-dmitriev-15091976@postgrespro.ru", "phone": "+70420324871"}
0005432530816	5AF2F1	5636 708615	IVAN TARASOV	{"email": "tarasov.i-25091972@postgrespro.ru", "phone": "+70130829842"}
0005432530817	E66C3E	9992 400221	ELIZAVETA IVANOVA	{"phone": "+70735937007"}
0005432530818	8767ED	6107 622563	ANNA MAKSIMOVA	{"email": "maksimovaanna-081982@postgrespro.ru", "phone": "+70929931204"}
0005432530819	8767ED	3005 454466	MIKHAIL ZHURAVLEV	{"phone": "+70487773897"}
0005432530820	7A6B39	5433 427455	SERGEY MARTYNOV	{"phone": "+70983369688"}
0005432530821	74D416	6012 111015	ALEKSANDR SOLOVEV	{"phone": "+70644352239"}
0005432530822	F9ED8B	6566 744519	MATRENA VASILEVA	{"phone": "+70445009568"}
0005432530823	F9ED8B	4921 119968	IVAN SCHERBAKOV	{"phone": "+70859737280"}
0005432530824	F9ED8B	7656 339497	LYUDMILA SERGEEVA	{"email": "sergeeva.lyudmila.011974@postgrespro.ru", "phone": "+70881695524"}
0005432530825	F9ED8B	9948 999392	ALBERT POPOV	{"email": "popov.albert18121971@postgrespro.ru", "phone": "+70484497797"}
0005432530826	8A1040	0478 391152	DMITRIY MOROZOV	{"email": "morozov.d-24051977@postgrespro.ru", "phone": "+70824021306"}
0005432530827	8A1040	1291 431350	LYUBOV KOVALEVA	{"phone": "+70553545193"}
0005432530828	3AD3DA	4679 698550	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr_01091973@postgrespro.ru", "phone": "+70049368450"}
0005432530829	3AD3DA	3774 047333	PAVEL ANDREEV	{"email": "andreev.p101965@postgrespro.ru", "phone": "+70947328755"}
0005432530830	3AD3DA	5101 432398	OLGA CHERNOVA	{"email": "chernovaolga.1972@postgrespro.ru", "phone": "+70968750852"}
0005432530831	58974A	6660 868631	SERGEY KUZNECOV	{"phone": "+70498331411"}
0005432530832	58974A	6304 823973	VIKTORIYA KOMAROVA	{"email": "komarova.v-22011973@postgrespro.ru", "phone": "+70500669036"}
0005432530833	CCEBF0	5025 423113	MIKHAIL MAKAROV	{"email": "makarovmikhail.1959@postgrespro.ru", "phone": "+70664368984"}
0005432530834	A5AC42	1331 801346	ANNA MALYSHEVA	{"email": "a_malysheva_1977@postgrespro.ru", "phone": "+70170255754"}
0005432530835	79FD14	3116 688235	ILMIRA VASILEVA	{"phone": "+70773346874"}
0005432530836	C4AC71	8007 071953	VASILIY FROLOV	{"email": "v_frolov-081967@postgrespro.ru", "phone": "+70043402880"}
0005432530837	C4AC71	2166 457441	NADEZHDA ZAKHAROVA	{"phone": "+70100091065"}
0005432530838	C4AC71	0917 020645	SERGEY PAVLOV	{"email": "s_pavlov-1959@postgrespro.ru", "phone": "+70393759717"}
0005432530839	C4AC71	9575 166884	RAISA ANTONOVA	{"email": "raisa-antonova_25011972@postgrespro.ru", "phone": "+70144170895"}
0005432530840	C4AC71	3413 660192	SERGEY SIDOROV	{"phone": "+70162553533"}
0005432530841	CDB87D	4448 407621	VLADIMIR MOISEEV	{"email": "v_moiseev-19091970@postgrespro.ru", "phone": "+70261526992"}
0005432530842	7B2D21	6994 354069	RAISA BARANOVA	{"email": "r.baranova.1976@postgrespro.ru", "phone": "+70619252215"}
0005432530843	F8E957	2739 752224	VALENTINA FILATOVA	{"email": "filatova_valentina_28051963@postgrespro.ru", "phone": "+70300011121"}
0005432530844	FDBD6B	7960 590560	ALEKSANDR MAKAROV	{"email": "makarov-a_031978@postgrespro.ru", "phone": "+70895387538"}
0005432530845	FDBD6B	4458 091687	SERGEY NAZAROV	{"email": "nazarov_sergey1981@postgrespro.ru", "phone": "+70811565079"}
0005432530846	316DFD	3782 863247	IRINA KOZLOVA	{"phone": "+70974601822"}
0005432530847	316DFD	0735 874557	VASILIY KONOVALOV	{"email": "v-konovalov1969@postgrespro.ru", "phone": "+70717112572"}
0005432530848	705AAF	4573 278953	OLEG EGOROV	{"email": "oegorov021973@postgrespro.ru", "phone": "+70497650870"}
0005432530849	0569FB	4533 733927	VALENTINA MOROZOVA	{"email": "vmorozova_1961@postgrespro.ru", "phone": "+70664618020"}
0005432530850	8EC940	5507 033720	DANIIL KOZLOV	{"email": "kozlovd-041976@postgrespro.ru", "phone": "+70575947365"}
0005432530851	8EC940	9653 544584	NATALYA ANTONOVA	{"phone": "+70094414994"}
0005432530852	2071C6	2295 640749	ANASTASIYA VOLKOVA	{"email": "avolkova.1963@postgrespro.ru", "phone": "+70859301781"}
0005432530853	2071C6	1905 000587	GEORGIY OSIPOV	{"email": "osipov-g.1973@postgrespro.ru", "phone": "+70494248692"}
0005432530854	3797A6	3803 652858	ALEKSANDR ANDREEV	{"phone": "+70612226829"}
0005432530855	3797A6	8163 393348	SERGEY KOZLOV	{"email": "sergeykozlov.101968@postgrespro.ru", "phone": "+70650504164"}
0005432530856	3797A6	7376 813581	VADIM VASILEV	{"phone": "+70123435821"}
0005432530857	C538C7	3668 601171	SERGEY BARANOV	{"phone": "+70794551834"}
0005432530858	C538C7	5410 030989	TATYANA SERGEEVA	{"phone": "+70481923653"}
0005432530859	63DFAC	5694 250274	PAVEL AFANASEV	{"email": "pavel_afanasev_091970@postgrespro.ru", "phone": "+70514134647"}
0005432530860	597A39	1212 697891	OLESYA VASILEVA	{"phone": "+70342625967"}
0005432530861	00558F	3069 687092	LIDIYA MOISEEVA	{"phone": "+70037449115"}
0005432530862	E2FF00	1775 334142	ZOYA ILINA	{"phone": "+70670085123"}
0005432530863	A1A7EC	4545 722158	VLADIMIR SAVELEV	{"email": "vladimirsavelev.1977@postgrespro.ru", "phone": "+70601472545"}
0005432530864	A1A7EC	0222 032991	EVGENIY ZAKHAROV	{"email": "e.zakharov_1963@postgrespro.ru", "phone": "+70580718279"}
0005432530865	976A4F	3631 767542	YULIYA LEBEDEVA	{"email": "yuliya_lebedeva.1976@postgrespro.ru", "phone": "+70319944975"}
0005432530866	976A4F	0740 536940	ANDREY KUDRYASHOV	{"phone": "+70511553422"}
0005432530867	86C6F6	0715 058153	IVAN BORISOV	{"phone": "+70930876997"}
0005432530868	DE5A18	5899 403198	IRINA LUKYANOVA	{"email": "lukyanova-i.03081957@postgrespro.ru", "phone": "+70198588880"}
0005432530869	DE5A18	3091 558373	OLEG PETROV	{"email": "opetrov_1964@postgrespro.ru", "phone": "+70892298666"}
0005432530870	27F513	9496 517108	ALEKSEY NOVIKOV	{"phone": "+70423249429"}
0005432530871	27F513	2564 553690	LYUBOV NOVIKOVA	{"phone": "+70665070015"}
0005432530872	9AA392	6414 463177	NADEZHDA KOMAROVA	{"phone": "+70238405793"}
0005432530873	9AA392	1193 568834	KLAVDIYA KOZLOVA	{"email": "kozlova-k1967@postgrespro.ru", "phone": "+70615536497"}
0005432530874	12303B	5712 719832	ARTEMIY BONDARENKO	{"email": "bondarenko-artemiy.101983@postgrespro.ru", "phone": "+70641588949"}
0005432530875	8CF4AB	4633 394295	LARISA PETROVA	{"email": "lpetrova_071955@postgrespro.ru", "phone": "+70278538599"}
0005432530876	8CF4AB	6266 140000	NINA DMITRIEVA	{"email": "dmitrievan.17091975@postgrespro.ru", "phone": "+70561188877"}
0005432530877	8D8607	9229 102948	ALEKSEY KARPOV	{"email": "a-karpov.071963@postgrespro.ru", "phone": "+70639731255"}
0005432530878	0AA9B8	9594 850563	ALEKSEY VASILEV	{"phone": "+70222581028"}
0005432530879	E4F571	5868 797553	MARIYA SMIRNOVA	{"phone": "+70068124481"}
0005432530880	2D17D4	1771 203764	MARIYA DENISOVA	{"email": "mariya.denisova1987@postgrespro.ru", "phone": "+70859246544"}
0005432530881	BDD599	4002 908899	NATALYA GAVRILOVA	{"email": "ngavrilova_1969@postgrespro.ru", "phone": "+70786010265"}
0005432530882	4A8B1C	8990 928518	RAUZA IVANOVA	{"phone": "+70758538377"}
0005432530883	BCCE80	1340 021924	EVGENIY BORISOV	{"email": "e_borisov19011963@postgrespro.ru", "phone": "+70633777451"}
0005432530884	372088	1421 680967	ALEKSANDR NIKOLAEV	{"phone": "+70465045692"}
0005432530885	3057B4	7791 918768	GULFIYA KOROLEVA	{"email": "g_koroleva_051966@postgrespro.ru", "phone": "+70415470151"}
0005432530886	13C688	8939 797034	ANASTASIYA MAKAROVA	{"phone": "+70103987621"}
0005432530887	32353D	3800 757293	VLADIMIR KUZNECOV	{"phone": "+70398994046"}
0005432530888	32353D	6454 002398	ANNA AKIMOVA	{"email": "akimova.a-031973@postgrespro.ru", "phone": "+70549634500"}
0005432530889	0A2BDF	7660 735641	LYUBOV ANTONOVA	{"phone": "+70849942478"}
0005432530890	D64AA0	0651 053450	STANISLAV PETROV	{"email": "s_petrov1968@postgrespro.ru", "phone": "+70598345709"}
0005432530891	D64AA0	3264 766859	NADEZHDA NOVIKOVA	{"email": "n-novikova.1968@postgrespro.ru", "phone": "+70308914552"}
0005432530892	2C86C5	2338 435301	SVETLANA KULIKOVA	{"email": "kulikova-s_09021960@postgrespro.ru", "phone": "+70372843722"}
0005432530893	2C86C5	0888 374512	NATALYA LAZAREVA	{"phone": "+70040796691"}
0005432530894	6052DF	0976 290152	LYUDMILA KOZLOVA	{"email": "l.kozlova081959@postgrespro.ru", "phone": "+70805893755"}
0005432530895	6052DF	9910 515108	SERGEY AFANASEV	{"email": "afanasevsergey.1969@postgrespro.ru", "phone": "+70093727831"}
0005432530896	21BF46	7733 027727	ANNA NESTEROVA	{"email": "nesterova-a-1972@postgrespro.ru", "phone": "+70933431382"}
0005432530897	11A024	7385 791100	GRIGORIY MIRONOV	{"email": "grigoriy-mironov.1974@postgrespro.ru", "phone": "+70801712612"}
0005432530898	11A024	0649 825106	IGOR VOLKOV	{"email": "i_volkov.11081964@postgrespro.ru", "phone": "+70052552478"}
0005432530899	8C3C2B	6323 134168	GALINA FILIPPOVA	{"phone": "+70394374515"}
0005432530900	8C3C2B	3220 332459	LYUDMILA KUDRYASHOVA	{"phone": "+70467554436"}
0005432530901	8C3C2B	7987 593094	GALINA SEMENOVA	{"email": "g.semenova_1971@postgrespro.ru", "phone": "+70094264289"}
0005432530902	14DFBD	1602 307497	NATALYA SOROKINA	{"email": "n_sorokina.25041971@postgrespro.ru", "phone": "+70170008132"}
0005432530903	14DFBD	3773 387926	ANATOLIY KUZNECOV	{"email": "kuznecov_a-1975@postgrespro.ru", "phone": "+70584815301"}
0005432530904	08DD49	3493 816861	ARINA LOGINOVA	{"email": "arina-loginova.07011974@postgrespro.ru", "phone": "+70352341096"}
0005432530905	8455C1	6732 979430	IRINA SEMENOVA	{"phone": "+70417447399"}
0005432530906	9D2B81	7439 068793	LARISA STEPANOVA	{"phone": "+70025749735"}
0005432530907	9D2B81	7519 484053	LYUBOV ISAEVA	{"email": "isaeval1968@postgrespro.ru", "phone": "+70041551162"}
0005432530908	9D2B81	5521 757018	NIKITA ILIN	{"email": "ilin-nikita111969@postgrespro.ru", "phone": "+70083590911"}
0005432530909	014DBF	3096 632538	VASILIY MEDVEDEV	{"email": "vmedvedev.1979@postgrespro.ru", "phone": "+70883195088"}
0005432530910	014DBF	9856 342133	KLAVDIYA NOVIKOVA	{"email": "novikova_k071973@postgrespro.ru", "phone": "+70782167751"}
0005432530911	A59DD6	2890 783573	LYUDMILA IVANOVA	{"phone": "+70474409058"}
0005432530912	A59DD6	7646 156542	SVETLANA FEDOROVA	{"email": "s-fedorova-121966@postgrespro.ru", "phone": "+70521506646"}
0005432530913	597CAC	0679 384815	REGINA SOROKINA	{"phone": "+70940095459"}
0005432530914	597CAC	0337 430083	VERA SAVELEVA	{"phone": "+70793926826"}
0005432530915	DE97AC	0758 434619	ALINA MOROZOVA	{"email": "morozova.a.05121960@postgrespro.ru", "phone": "+70155611703"}
0005432530916	7EF759	2352 631174	VALENTIN SOLOVEV	{"email": "v_solovev15021961@postgrespro.ru", "phone": "+70552953367"}
0005432530917	7B1A12	9370 904877	IVAN MOISEEV	{"phone": "+70774513602"}
0005432531194	88E627	9715 851623	EVGENIY VOLKOV	{"phone": "+70000231473"}
0005432530918	7B1A12	7544 362217	TATYANA LUKYANOVA	{"email": "tatyana_lukyanova051969@postgrespro.ru", "phone": "+70730193139"}
0005432530919	1B956D	0878 649599	IRINA IVANOVA	{"phone": "+70986621773"}
0005432530920	3DA72C	2261 806882	INNA MEDVEDEVA	{"email": "medvedeva-inna_09061966@postgrespro.ru", "phone": "+70665803972"}
0005432530921	D39AFE	3212 812217	ALINA MIKHAYLOVA	{"email": "mikhaylova.alina_1971@postgrespro.ru", "phone": "+70825330326"}
0005432530922	D39AFE	2691 619983	ELENA ROMANOVA	{"email": "romanova.elena-11111959@postgrespro.ru", "phone": "+70395944799"}
0005432530923	D39AFE	5156 010847	SVETLANA IVANOVA	{"email": "ivanova.svetlana-1971@postgrespro.ru", "phone": "+70685337673"}
0005432530924	8A821D	3267 624937	ANATOLIY ANDREEV	{"phone": "+70357860780"}
0005432530925	8A821D	3126 555167	SVETLANA DMITRIEVA	{"phone": "+70510099589"}
0005432530926	1FD5C1	2498 841432	NATALYA SCHERBAKOVA	{"phone": "+70598454591"}
0005432530927	1FD5C1	3022 908291	ALEKSANDR SIDOROV	{"email": "sidorov-a-1974@postgrespro.ru", "phone": "+70583354265"}
0005432530928	C8C982	0517 548120	ULYANA SOLOVEVA	{"email": "usoloveva.1977@postgrespro.ru", "phone": "+70293022897"}
0005432530929	AA5653	3897 921088	NADEZHDA NIKITINA	{"phone": "+70283858917"}
0005432530930	AA5653	6386 372680	OLGA ZAYCEVA	{"email": "zayceva_o-1968@postgrespro.ru", "phone": "+70139101110"}
0005432530931	AA5653	1749 501270	SOFIYA SMIRNOVA	{"email": "sofiya-smirnova011983@postgrespro.ru", "phone": "+70814384299"}
0005432530932	3100BE	8053 235789	EKATERINA KRASNOVA	{"email": "krasnovaekaterina14081987@postgrespro.ru", "phone": "+70031168764"}
0005432530933	05285F	6796 126746	IGOR BONDARENKO	{"phone": "+70230420718"}
0005432530934	D56AD5	5436 173953	STANISLAV SIDOROV	{"phone": "+70055274376"}
0005432530935	D56AD5	6020 932218	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev_121965@postgrespro.ru", "phone": "+70113013240"}
0005432530936	9452A6	0009 438898	OKSANA ALEKSEEVA	{"phone": "+70860325701"}
0005432530937	BCBB98	9016 550027	STEPAN SMIRNOV	{"email": "s_smirnov-01051972@postgrespro.ru", "phone": "+70988345131"}
0005432530938	58111C	8861 714417	OLGA KULIKOVA	{"email": "o.kulikova10011987@postgrespro.ru", "phone": "+70543965137"}
0005432530939	B81116	9015 080966	MIKHAIL KARPOV	{"phone": "+70174373419"}
0005432530940	847F03	8907 655861	ANATOLIY NIKOLAEV	{"phone": "+70248016776"}
0005432530941	E04E86	4853 338512	KSENIYA PETROVA	{"phone": "+70676757917"}
0005432530942	42D7EE	0206 156996	KAPITALINA ZAYCEVA	{"email": "kapitalinazayceva1981@postgrespro.ru", "phone": "+70251874530"}
0005432530943	42D7EE	4784 669306	VIKTOR KRASNOV	{"phone": "+70755399298"}
0005432530944	636004	6615 266100	OLEG STEPANOV	{"phone": "+70685189204"}
0005432530945	636004	9537 653413	RUSLAN MAKSIMOV	{"email": "ruslan.maksimov121973@postgrespro.ru", "phone": "+70594965033"}
0005432530946	636004	0044 322269	IVAN VASILEV	{"phone": "+70775651385"}
0005432530947	066E02	5579 120299	LIDIYA ISAEVA	{"email": "isaeva-l-30091968@postgrespro.ru", "phone": "+70181684072"}
0005432530948	F1DC2B	2688 466432	GERMAN BARANOV	{"phone": "+70909628606"}
0005432530949	CD38C5	5667 249263	EGOR SERGEEV	{"phone": "+70837810034"}
0005432530950	6B7ECA	0547 633372	EVGENIY GAVRILOV	{"email": "e-gavrilov_12031978@postgrespro.ru", "phone": "+70263369733"}
0005432530951	6B7ECA	3201 687343	DANIIL SAVELEV	{"phone": "+70120431986"}
0005432530952	B6B818	0250 736275	LYUDMILA OSIPOVA	{"email": "osipova_lyudmila_1963@postgrespro.ru", "phone": "+70481238567"}
0005432530953	527AA7	7019 597116	TATYANA SOKOLOVA	{"email": "tsokolova.1975@postgrespro.ru", "phone": "+70408483978"}
0005432530954	527AA7	2316 832282	SVETLANA ANTONOVA	{"email": "antonovasvetlana-081973@postgrespro.ru", "phone": "+70437155652"}
0005432530955	600CF2	0885 771128	VIKTORIYA SAVELEVA	{"email": "saveleva.viktoriya19121976@postgrespro.ru", "phone": "+70851853710"}
0005432530956	1F371E	0482 493361	VASILIY KISELEV	{"email": "kiselev_vasiliy1972@postgrespro.ru", "phone": "+70414969518"}
0005432530957	1F371E	0673 787783	ZINAIDA MAKAROVA	{"email": "z-makarova_18081971@postgrespro.ru", "phone": "+70690218032"}
0005432530958	319CD3	2015 728406	ALEKSANDR MOROZOV	{"email": "morozova22031976@postgrespro.ru", "phone": "+70200019193"}
0005432530959	EB2ECB	7510 928058	SERGEY ZAKHAROV	{"email": "zakharov_s.12031961@postgrespro.ru", "phone": "+70426769906"}
0005432530960	EB2ECB	5230 491005	SERGEY EGOROV	{"email": "egorov_sergey-111974@postgrespro.ru", "phone": "+70580539299"}
0005432530961	13F620	4236 952948	ALLA SMIRNOVA	{"phone": "+70205233139"}
0005432530962	9255B6	8405 546832	ANNA SCHERBAKOVA	{"phone": "+70966791322"}
0005432530963	AFA7E1	3277 022976	ANTON FEDOROV	{"email": "anton_fedorov.1971@postgrespro.ru", "phone": "+70514642821"}
0005432530964	AFA7E1	8235 885998	EKATERINA MAKSIMOVA	{"email": "maksimova-e031973@postgrespro.ru", "phone": "+70541806457"}
0005432530965	AFA7E1	1765 476019	VIKTOR VOLKOV	{"phone": "+70140228682"}
0005432530966	FDD2ED	1773 187861	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr-04091976@postgrespro.ru", "phone": "+70090422274"}
0005432530967	6D0C4B	9949 400302	OLGA MAKSIMOVA	{"email": "maksimova.o-1964@postgrespro.ru", "phone": "+70877568755"}
0005432530968	6D0C4B	5356 288429	OLGA MIRONOVA	{"email": "omironova.1979@postgrespro.ru", "phone": "+70119531092"}
0005432530969	26F5D9	0177 787355	SERGEY KRASNOV	{"email": "krasnov.sergey_04031970@postgrespro.ru", "phone": "+70230877073"}
0005432530970	26F5D9	5310 544004	ANNA FILIPPOVA	{"email": "filippovaa.1975@postgrespro.ru", "phone": "+70636701105"}
0005432530971	92BCEA	5275 414918	OLGA MAKSIMOVA	{"email": "o.maksimova_06021964@postgrespro.ru", "phone": "+70390827354"}
0005432530972	70E665	4439 943064	EGOR POPOV	{"phone": "+70396500436"}
0005432530973	1FA3EA	5954 914229	PETR SAVELEV	{"email": "savelevpetr_1958@postgrespro.ru", "phone": "+70835957830"}
0005432530974	1FA3EA	9928 921866	SERGEY NOVIKOV	{"email": "novikov.s_21011970@postgrespro.ru", "phone": "+70975023639"}
0005432530975	7618F9	5726 646212	ANASTASIYA POPOVA	{"phone": "+70578878167"}
0005432530976	7618F9	7342 462628	SAMIR GRIGOREV	{"email": "samir.grigorev_22081972@postgrespro.ru", "phone": "+70469840646"}
0005432530977	B0BC41	0537 372402	IVAN ISAEV	{"email": "isaev_i_091971@postgrespro.ru", "phone": "+70120612012"}
0005432530978	9D6DB9	9600 940418	ANDREY IVANOV	{"phone": "+70200331472"}
0005432530979	1A09D4	7798 417209	IRINA VOROBEVA	{"email": "vorobevairina12081972@postgrespro.ru", "phone": "+70533769791"}
0005432530980	1A09D4	9212 463895	MIKHAIL KAZAKOV	{"phone": "+70484303550"}
0005432530981	0DA444	9657 112487	MIKHAIL GORBUNOV	{"email": "mikhailgorbunov.01051963@postgrespro.ru", "phone": "+70737419072"}
0005432530982	35B5EE	0662 323055	KONSTANTIN KAZAKOV	{"email": "konstantin-kazakov_05121963@postgrespro.ru", "phone": "+70800065015"}
0005432530983	89C8A8	4916 954426	DANIIL NIKOLAEV	{"phone": "+70988371877"}
0005432530984	494AD6	8358 797771	IRINA ROMANOVA	{"email": "irina-romanova-081968@postgrespro.ru", "phone": "+70445131893"}
0005432530985	6BAC14	8337 682883	ALEKSEY ANDREEV	{"phone": "+70934267466"}
0005432530986	285F89	3993 107856	GALINA KUZNECOVA	{"email": "kuznecovag.061976@postgrespro.ru", "phone": "+70664626113"}
0005432530987	D3A6D2	7965 998406	EKATERINA MALYSHEVA	{"email": "malysheva.e.041976@postgrespro.ru", "phone": "+70271381180"}
0005432530988	6C0FB3	3590 338285	ANDREY ABRAMOV	{"email": "andreyabramov051966@postgrespro.ru", "phone": "+70787274086"}
0005432530989	6C0FB3	3960 621312	REGINA KULIKOVA	{"email": "rkulikova.1965@postgrespro.ru", "phone": "+70558361155"}
0005432530990	6C0FB3	5045 550110	NADEZHDA KOLESNIKOVA	{"email": "kolesnikovanadezhda.031960@postgrespro.ru", "phone": "+70168018175"}
0005432530991	78852E	3655 216610	PAVEL SCHERBAKOV	{"email": "scherbakovp-1978@postgrespro.ru", "phone": "+70500194819"}
0005432530992	574095	0107 568018	DINA VASILEVA	{"phone": "+70469388533"}
0005432530993	574095	8332 294260	ALEKSANDR MEDVEDEV	{"email": "medvedev.aleksandr.1969@postgrespro.ru", "phone": "+70480017183"}
0005432530994	7BD2CF	5653 655442	VIKTOR KOZLOV	{"phone": "+70389821116"}
0005432530995	8D906B	7714 500499	MIKHAIL KUZMIN	{"email": "kuzmin-m14051973@postgrespro.ru", "phone": "+70767239334"}
0005432530996	F2EC55	7064 721859	ALEKSANDRA PETROVA	{"phone": "+70104505003"}
0005432530997	A637F1	8835 901353	TIMUR SEMENOV	{"email": "timur.semenov-051976@postgrespro.ru", "phone": "+70944891475"}
0005432530998	DEED2E	6614 513963	TATYANA TITOVA	{"email": "titova-tatyana_12041962@postgrespro.ru", "phone": "+70439495163"}
0005432530999	AFADD2	3050 091245	LYUDMILA NIKOLAEVA	{"email": "l.nikolaeva.1967@postgrespro.ru", "phone": "+70204944061"}
0005432531000	6A8FF1	1675 946145	YULIYA DANILOVA	{"phone": "+70288252648"}
0005432531001	5AABE3	5521 738210	DANIL EGOROV	{"email": "egorov.d.22071963@postgrespro.ru", "phone": "+70296667122"}
0005432531002	3DE065	0404 978305	VLADISLAV PAVLOV	{"phone": "+70704090611"}
0005432531003	069EB2	7237 921642	IVAN KISELEV	{"phone": "+70968098938"}
0005432531004	069EB2	8989 450001	MARAT KUZNECOV	{"email": "kuznecov-m.24011972@postgrespro.ru", "phone": "+70744332816"}
0005432531005	CE3529	5600 795687	TATYANA KUDRYASHOVA	{"email": "kudryashova.tatyana_031975@postgrespro.ru", "phone": "+70585634729"}
0005432531006	078EFF	9491 637438	GALINA ANTONOVA	{"phone": "+70535181791"}
0005432531007	078EFF	3686 759944	LARISA MIRONOVA	{"phone": "+70433632515"}
0005432531008	078EFF	6615 844411	MATVEY SHEVCHENKO	{"email": "m.shevchenko111978@postgrespro.ru", "phone": "+70394327144"}
0005432531009	1294B9	6181 193675	SERGEY IVANOV	{"email": "ivanov-sergey-11051973@postgrespro.ru", "phone": "+70103728248"}
0005432531010	B312C0	4780 540235	VADIM MOISEEV	{"phone": "+70875204104"}
0005432531011	B312C0	3488 653565	ANDREY FEDOTOV	{"email": "afedotov-25101964@postgrespro.ru", "phone": "+70004823420"}
0005432531012	6BE13F	5007 706377	PAVEL SIDOROV	{"email": "pavel.sidorov_1984@postgrespro.ru", "phone": "+70965555667"}
0005432531013	2A5BC7	2098 734432	NADEZHDA FROLOVA	{"phone": "+70384492685"}
0005432531014	FDA0AC	0088 388278	PAVEL IVANOV	{"phone": "+70806121835"}
0005432531015	FDA0AC	6495 345401	EVA ARKHIPOVA	{"email": "arkhipova-eva-25011975@postgrespro.ru", "phone": "+70145739571"}
0005432531016	0B1827	2979 768460	ALEKSEY KONOVALOV	{"email": "konovalovaleksey.1974@postgrespro.ru", "phone": "+70902624182"}
0005432531017	0C1A33	4062 037427	ANNA EGOROVA	{"phone": "+70386646428"}
0005432531018	0C1A33	0192 766185	TATYANA FROLOVA	{"phone": "+70992220408"}
0005432531019	C55BB0	6317 517745	ANDREY KRASNOV	{"phone": "+70993695489"}
0005432531020	C55BB0	8160 397477	GALINA VASILEVA	{"email": "galina-vasileva081977@postgrespro.ru", "phone": "+70113803418"}
0005432531021	D8516D	8761 900985	MARIYA MATVEEVA	{"email": "mariya_matveeva.1972@postgrespro.ru", "phone": "+70595223654"}
0005432531022	64384A	0486 294652	IVAN SMIRNOV	{"email": "ivan_smirnov021975@postgrespro.ru", "phone": "+70475261357"}
0005432531023	D84112	2208 792223	KONSTANTIN MOROZOV	{"phone": "+70917345677"}
0005432531024	D84112	5413 329885	NATALYA DAVYDOVA	{"email": "davydova.natalya09101968@postgrespro.ru", "phone": "+70729909032"}
0005432531025	94F6B6	3399 867241	DENIS GRIGOREV	{"email": "dgrigorev07041961@postgrespro.ru", "phone": "+70261522527"}
0005432531026	94F6B6	8500 691549	VLADIMIR STEPANOV	{"phone": "+70881627397"}
0005432531027	17780C	6465 665591	VALENTINA KOROLEVA	{"email": "valentinakoroleva_26011965@postgrespro.ru", "phone": "+70626048514"}
0005432531028	17780C	6084 618139	NIKOLAY VOLKOV	{"email": "volkov_nikolay-1966@postgrespro.ru", "phone": "+70453164699"}
0005432531029	B0EBE3	9125 847216	DMITRIY KRASNOV	{"email": "krasnovdmitriy14061975@postgrespro.ru", "phone": "+70202437123"}
0005432531030	C948DF	8341 368308	NINA YAKOVLEVA	{"email": "yakovlevanina1971@postgrespro.ru", "phone": "+70759056671"}
0005432531031	7AD393	4651 553257	VALENTINA DANILOVA	{"email": "danilova.valentina.1980@postgrespro.ru", "phone": "+70649288154"}
0005432531032	7AD393	3213 311601	ILYA ANTONOV	{"phone": "+70479551070"}
0005432531033	4CF8AB	1924 087805	FEDOR MIKHAYLOV	{"email": "f-mikhaylov-031983@postgrespro.ru", "phone": "+70759566740"}
0005432531034	4CF8AB	4273 213842	SVETLANA DMITRIEVA	{"phone": "+70258490532"}
0005432531035	372619	7278 509078	ARTUR SOLOVEV	{"phone": "+70091570849"}
0005432531036	C44200	1034 557197	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-valentina-1960@postgrespro.ru", "phone": "+70304194427"}
0005432531037	CDC9BD	6341 683147	GALINA DENISOVA	{"phone": "+70789495669"}
0005432531038	2A5E03	4776 316890	SOFIYA SMIRNOVA	{"phone": "+70672289909"}
0005432531039	D23932	3249 322748	ZINAIDA KUZNECOVA	{"email": "zinaida_kuznecova-011974@postgrespro.ru", "phone": "+70864783899"}
0005432531040	6D2C60	1272 317375	YULIYA FROLOVA	{"email": "yuliya-frolova-01121973@postgrespro.ru", "phone": "+70025699579"}
0005432531041	6D2C60	8924 006123	YURIY ANTONOV	{"email": "yuriy-antonov.041979@postgrespro.ru", "phone": "+70683424153"}
0005432531042	EA54B3	4478 175031	ALEKSANDRA VASILEVA	{"phone": "+70043030583"}
0005432531043	A3CFF2	6486 653100	ALEKSANDR DMITRIEV	{"email": "a_dmitriev.101968@postgrespro.ru", "phone": "+70923325334"}
0005432531044	6C3244	5700 108655	YURIY MAKSIMOV	{"email": "yuriy.maksimov_031972@postgrespro.ru", "phone": "+70238156021"}
0005432531045	739E36	1986 017227	ELENA KUDRYASHOVA	{"email": "e_kudryashova.051965@postgrespro.ru", "phone": "+70687228087"}
0005432531046	68430D	7172 434932	SERGEY VASILEV	{"phone": "+70877364120"}
0005432531047	5E94A1	5547 485270	IGOR STEPANOV	{"phone": "+70343474697"}
0005432531048	D11758	8364 168882	ANATOLIY MAKAROV	{"phone": "+70629726085"}
0005432531049	1C05D7	9693 625620	ELENA AFANASEVA	{"phone": "+70272003885"}
0005432531050	AA6F34	6326 031248	VLADIMIR EGOROV	{"phone": "+70629590100"}
0005432531051	5ADB12	9369 720136	IVAN TIMOFEEV	{"phone": "+70763700337"}
0005432531052	5ADB12	4753 731314	TATYANA ISAEVA	{"email": "isaeva-tatyana-1972@postgrespro.ru", "phone": "+70762670539"}
0005432531053	4B3EAF	2544 494895	DENIS SOKOLOV	{"phone": "+70122964690"}
0005432531054	4B3EAF	1170 614500	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n.07091972@postgrespro.ru", "phone": "+70880676847"}
0005432531055	6512B6	5209 506574	YURIY ABRAMOV	{"phone": "+70017869521"}
0005432531056	4BA768	1929 698580	SERGEY KRASNOV	{"email": "krasnov_s_04121974@postgrespro.ru", "phone": "+70635040324"}
0005432531057	63368F	3247 465326	NINA DENISOVA	{"phone": "+70577001302"}
0005432531058	EE3E70	1721 828216	RUSLAN IVANOV	{"phone": "+70996078143"}
0005432531059	EE3E70	8166 356548	NIKOLAY KOROLEV	{"email": "n-korolev-22101963@postgrespro.ru", "phone": "+70594824625"}
0005432531060	2F3F52	3455 200105	GALINA VASILEVA	{"phone": "+70222276981"}
0005432531061	D60D2E	4853 392075	VIKTOR FEDOTOV	{"email": "fedotov-viktor-1980@postgrespro.ru", "phone": "+70419832766"}
0005432531062	4C2EF6	1270 567168	EVDOKIYA FROLOVA	{"phone": "+70533764032"}
0005432531063	4C2EF6	1715 214146	ANDREY SMIRNOV	{"email": "smirnovandrey031980@postgrespro.ru", "phone": "+70185282183"}
0005432531064	9419FE	4080 695526	SVETLANA VASILEVA	{"email": "vasilevas021972@postgrespro.ru", "phone": "+70314254316"}
0005432531065	2661C8	1567 003654	ANDREY KUZNECOV	{"phone": "+70057310311"}
0005432531066	0005F4	7027 209576	NIKOLAY KUDRYASHOV	{"email": "n_kudryashov_21071969@postgrespro.ru", "phone": "+70339070063"}
0005432531067	0005F4	6776 055230	MARIYA POLYAKOVA	{"phone": "+70111081744"}
0005432531068	250310	2672 178577	VERA MALYSHEVA	{"email": "v_malysheva041977@postgrespro.ru", "phone": "+70519933930"}
0005432531069	250310	0091 293269	SVETLANA VOLKOVA	{"email": "svetlana.volkova_061971@postgrespro.ru", "phone": "+70933308522"}
0005432531070	EFCFCB	0427 147477	VLADIMIR MAKAROV	{"email": "makarov-vladimir-1960@postgrespro.ru", "phone": "+70500086824"}
0005432531071	EFCFCB	8542 421153	KLAVDIYA MELNIKOVA	{"phone": "+70511373267"}
0005432531072	0430D4	9755 790981	SVETLANA NOVIKOVA	{"phone": "+70283943024"}
0005432531073	0430D4	1404 670069	ELENA MAKSIMOVA	{"phone": "+70424405879"}
0005432531074	0430D4	2835 764291	NATALYA NAUMOVA	{"phone": "+70913121956"}
0005432531075	52221E	1398 770609	GALINA SMIRNOVA	{"email": "smirnova-galina-24011978@postgrespro.ru", "phone": "+70799005391"}
0005432531076	3674C3	5297 006133	ANDREY SIDOROV	{"email": "andrey_sidorov_09021975@postgrespro.ru", "phone": "+70651843789"}
0005432531077	97DCE2	7686 717396	NINA IVANOVA	{"email": "ivanova.n.1978@postgrespro.ru", "phone": "+70025903471"}
0005432531078	97DCE2	4685 858844	DMITRIY BELOV	{"phone": "+70871691121"}
0005432531079	ADB8D9	3899 437820	MARAT FOMIN	{"phone": "+70317701448"}
0005432531315	5C67C8	6433 712822	ALISA ILINA	{"phone": "+70411224988"}
0005432531080	ADB8D9	8824 962930	PETR MATVEEV	{"email": "p_matveev25081971@postgrespro.ru", "phone": "+70675357486"}
0005432531081	ADB8D9	5942 772436	VALENTINA NAZAROVA	{"phone": "+70585489078"}
0005432531082	827763	7070 944001	MARIYA SIDOROVA	{"email": "sidorovam.1971@postgrespro.ru", "phone": "+70763959316"}
0005432531083	827763	6833 530792	SERGEY ALEKSEEV	{"phone": "+70107553552"}
0005432531084	3B52B2	0511 209045	NATALYA MAKAROVA	{"email": "makarovanatalya.1981@postgrespro.ru", "phone": "+70901709097"}
0005432531085	8D5FF9	0653 107105	DENIS GERASIMOV	{"phone": "+70573868221"}
0005432531086	8D5FF9	8556 546455	PAVEL ANDREEV	{"phone": "+70495001650"}
0005432531087	8D5FF9	6372 385320	NATALYA STEPANOVA	{"email": "stepanovanatalya-1983@postgrespro.ru", "phone": "+70233971399"}
0005432531088	A2344B	1875 498881	ANNA IVANOVA	{"email": "ivanova_a.29101970@postgrespro.ru", "phone": "+70501285969"}
0005432531089	A2344B	7196 302265	ALEKSEY ILIN	{"email": "a.ilin03111959@postgrespro.ru", "phone": "+70669344307"}
0005432531090	F1B3A1	7937 189568	VARVARA STEPANOVA	{"email": "stepanova_varvara-021979@postgrespro.ru", "phone": "+70005578747"}
0005432531091	541778	2349 575545	LYUDMILA GERASIMOVA	{"email": "gerasimova-lyudmila_041972@postgrespro.ru", "phone": "+70894193982"}
0005432531092	C9F64E	7609 512335	NATALYA BORISOVA	{"email": "nborisova1979@postgrespro.ru", "phone": "+70389015405"}
0005432531093	6304F5	1994 439156	MIKHAIL KOZLOV	{"email": "kozlov_mikhail.031973@postgrespro.ru", "phone": "+70203353434"}
0005432531094	6304F5	6459 685687	EVGENIYA MOROZOVA	{"phone": "+70925700799"}
0005432531095	50B677	2144 757313	NIKOLAY IVANOV	{"phone": "+70856464480"}
0005432531096	147DEB	3275 441951	MARINA KUZNECOVA	{"phone": "+70879622474"}
0005432531097	147DEB	1233 313504	ALEKSEY SMIRNOV	{"phone": "+70268084203"}
0005432531098	2B81FF	5205 330446	MIKHAIL ZAYCEV	{"email": "mikhail.zaycev.071978@postgrespro.ru", "phone": "+70365305785"}
0005432531099	3DCE18	1048 001125	SVETLANA KONOVALOVA	{"phone": "+70322916722"}
0005432531100	FE84E9	3620 712869	NIKOLAY POPOV	{"phone": "+70182781624"}
0005432531101	B26DF0	6266 314742	SERGEY KUZNECOV	{"phone": "+70701363790"}
0005432531102	B26DF0	3619 094428	ALEKSANDR KARPOV	{"phone": "+70982496449"}
0005432531103	ED2117	9523 657348	NATALYA NIKITINA	{"email": "n-nikitina09071982@postgrespro.ru", "phone": "+70299853114"}
0005432531104	ED2117	9632 532162	VIKTOR NIKITIN	{"phone": "+70921390109"}
0005432531105	F4740B	1174 298074	ANDREY KULIKOV	{"phone": "+70629402685"}
0005432531106	B76D81	4269 840012	VLADIMIR VASILEV	{"phone": "+70447325575"}
0005432531107	D290B4	8270 322156	LIDIYA ORLOVA	{"email": "orlova.l.03121962@postgrespro.ru", "phone": "+70252762802"}
0005432531108	C05892	1373 270164	KRISTINA MAKAROVA	{"email": "makarova.kristina081976@postgrespro.ru", "phone": "+70372441630"}
0005432531109	9BF497	0880 025999	ANTONINA ANDREEVA	{"email": "aandreeva021967@postgrespro.ru", "phone": "+70710485300"}
0005432531110	9BF497	7151 185815	SERGEY NAZAROV	{"email": "nazarov-s_021975@postgrespro.ru", "phone": "+70149756056"}
0005432531111	A51465	1778 715751	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a.071983@postgrespro.ru", "phone": "+70626603251"}
0005432531112	83448A	7026 594013	ALBINA FROLOVA	{"phone": "+70872099229"}
0005432531113	2F6DDB	9112 574233	VENERA TROFIMOVA	{"phone": "+70715468203"}
0005432531114	2F6DDB	3579 255000	ANTONINA POPOVA	{"email": "antonina-popova-021978@postgrespro.ru", "phone": "+70837935986"}
0005432531115	EBE4A9	6531 461639	DANIL FROLOV	{"phone": "+70107150936"}
0005432531116	2967D6	9502 946745	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila-111972@postgrespro.ru", "phone": "+70796084658"}
0005432531117	0C1A41	1449 670396	TATYANA ZOTOVA	{"email": "tatyana.zotova1967@postgrespro.ru", "phone": "+70963185238"}
0005432531118	8ABCAC	2620 107297	POLINA SERGEEVA	{"email": "polina.sergeeva.1976@postgrespro.ru", "phone": "+70159411631"}
0005432531119	8ABCAC	1800 585302	LYUBOV KULIKOVA	{"email": "l.kulikova021980@postgrespro.ru", "phone": "+70817192526"}
0005432531120	E10247	6995 467965	VALENTINA ALEKSEEVA	{"email": "alekseevavalentina.1960@postgrespro.ru", "phone": "+70496181318"}
0005432531121	68CA90	5731 663138	LIDIYA PAVLOVA	{"phone": "+70481346924"}
0005432531122	68CA90	3156 153664	ROBERT IVANOV	{"email": "r.ivanov-1972@postgrespro.ru", "phone": "+70768080393"}
0005432531123	433DBF	0074 682502	MIKHAIL SOROKIN	{"email": "mikhail-sorokin19021970@postgrespro.ru", "phone": "+70606287071"}
0005432531124	DF409D	3100 913710	GALINA VOROBEVA	{"phone": "+70261753126"}
0005432531125	DF409D	4148 855662	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov071971@postgrespro.ru", "phone": "+70224752718"}
0005432531126	7DBF35	2610 156929	ANDREY SAVELEV	{"phone": "+70044176355"}
0005432531127	66BF22	3660 340133	TATYANA FOMINA	{"email": "fomina-t071973@postgrespro.ru", "phone": "+70568906131"}
0005432531128	2F5F4A	0446 819479	ZINAIDA KUZNECOVA	{"email": "zinaida.kuznecova.03011973@postgrespro.ru", "phone": "+70129418390"}
0005432531129	07A491	9888 147897	LARISA AKIMOVA	{"phone": "+70787944881"}
0005432531130	07A491	1686 560439	VADIM KUDRYASHOV	{"email": "kudryashovv.1971@postgrespro.ru", "phone": "+70603538172"}
0005432531131	07A491	8246 582670	KSENIYA SOROKINA	{"email": "k-sorokina081962@postgrespro.ru", "phone": "+70486213148"}
0005432531132	85BC4F	9337 781846	VLADIMIR ROMANOV	{"email": "romanov_v-121974@postgrespro.ru", "phone": "+70614018922"}
0005432531133	BE2526	6604 538940	VALENTINA NIKIFOROVA	{"email": "v-nikiforova-28061964@postgrespro.ru", "phone": "+70712355155"}
0005432531134	BE2526	8138 649699	TATYANA KALININA	{"phone": "+70688809763"}
0005432531135	BE2526	3781 895065	ARTEM FROLOV	{"email": "frolov_artem021967@postgrespro.ru", "phone": "+70853620094"}
0005432531136	BE6CDC	0515 010492	SVETLANA FEDOROVA	{"email": "svetlana_fedorova_031974@postgrespro.ru", "phone": "+70720524568"}
0005432531137	BE6CDC	9160 281560	ILYA MARTYNOV	{"email": "ilya_martynov-111962@postgrespro.ru", "phone": "+70205699102"}
0005432531138	6894E5	0599 407417	ALBINA YUDINA	{"phone": "+70401211591"}
0005432531139	6894E5	6238 549054	MARGARITA FILIPPOVA	{"email": "m.filippova_121977@postgrespro.ru", "phone": "+70706700706"}
0005432531140	C81B88	4475 958067	VITALIY ZHURAVLEV	{"email": "vzhuravlev.13041983@postgrespro.ru", "phone": "+70606677206"}
0005432531141	1616E6	0902 144081	ZINAIDA KAZAKOVA	{"email": "kazakova-zinaida.1971@postgrespro.ru", "phone": "+70528711686"}
0005432531142	47F09C	8976 952731	POLINA KARPOVA	{"email": "karpova.polina1981@postgrespro.ru", "phone": "+70507458816"}
0005432531143	FA5FD9	5932 831986	ELENA FROLOVA	{"email": "elena.frolova_011972@postgrespro.ru", "phone": "+70744244432"}
0005432531144	8A36A4	2874 294649	SOFYA DENISOVA	{"email": "denisova-sofya.05121971@postgrespro.ru", "phone": "+70395946795"}
0005432531145	FECFC4	2327 295238	IGOR PAVLOV	{"phone": "+70700670307"}
0005432531146	FECFC4	8951 018158	ANTON SOKOLOV	{"phone": "+70858660057"}
0005432531147	A1AA51	6394 094681	ALEKSEY MOROZOV	{"phone": "+70097154701"}
0005432531148	A1AA51	0396 389875	EKATERINA MOROZOVA	{"phone": "+70497217204"}
0005432531149	ED82AB	9421 503220	SERGEY KUZNECOV	{"phone": "+70547403623"}
0005432531150	ED82AB	2455 393231	YAROSLAV MEDVEDEV	{"phone": "+70617066629"}
0005432531151	B61F58	2845 595904	VLADIMIR SERGEEV	{"email": "vladimirsergeev_12051975@postgrespro.ru", "phone": "+70552587784"}
0005432531152	B61F58	5936 608125	ANDREY ALEKSEEV	{"email": "andrey-alekseev_081965@postgrespro.ru", "phone": "+70709452586"}
0005432531153	617F77	4522 009587	DARYA PAVLOVA	{"email": "pavlova-darya06101960@postgrespro.ru", "phone": "+70365392433"}
0005432531154	96B661	0310 922513	IVAN YAKOVLEV	{"email": "yakovlev.i.23061977@postgrespro.ru", "phone": "+70910071065"}
0005432531155	96B661	3596 738785	KSENIYA NIKOLAEVA	{"phone": "+70285391244"}
0005432531156	4DCE39	0374 621651	LYUDMILA AFANASEVA	{"email": "afanaseva-lyudmila_05041980@postgrespro.ru", "phone": "+70654157058"}
0005432531157	4DCE39	1865 656053	MARINA NOVIKOVA	{"email": "mnovikova_1964@postgrespro.ru", "phone": "+70224057712"}
0005432531158	306179	6358 761952	RAFAEL MATVEEV	{"phone": "+70238604765"}
0005432531159	F86470	5379 020186	ELENA MATVEEVA	{"email": "matveeva_elena.01101975@postgrespro.ru", "phone": "+70614951700"}
0005432531160	F86470	7728 959369	KLAVDIYA FEDOROVA	{"email": "fedorova_klavdiya.02031964@postgrespro.ru", "phone": "+70357440744"}
0005432531161	08BC6C	2518 762681	YURIY GRIGOREV	{"phone": "+70080176777"}
0005432531162	08BC6C	6353 800729	MARIYA TARASOVA	{"email": "tarasova_mariya-1961@postgrespro.ru", "phone": "+70169823118"}
0005432531163	5D1BC5	7405 403505	NADEZHDA FILATOVA	{"phone": "+70816013806"}
0005432531164	CBF5FC	6634 205390	LIDIYA EFIMOVA	{"email": "l.efimova.111978@postgrespro.ru", "phone": "+70696586494"}
0005432531165	658DF6	1870 288746	SVETLANA SMIRNOVA	{"phone": "+70168272954"}
0005432531166	658DF6	2256 780084	OLGA TROFIMOVA	{"phone": "+70539683777"}
0005432531167	9204E0	5247 387699	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_14081975@postgrespro.ru", "phone": "+70766150619"}
0005432531168	9204E0	6032 828654	NATALYA CHERNOVA	{"phone": "+70785940307"}
0005432531169	4CAB35	6203 648298	OLGA LUKYANOVA	{"phone": "+70711362438"}
0005432531170	4CAB35	3849 179741	SERGEY EGOROV	{"email": "egorov_s_15021979@postgrespro.ru", "phone": "+70315739152"}
0005432531171	66FA3D	7981 093548	NATALIYA KRASNOVA	{"email": "krasnova-n31081972@postgrespro.ru", "phone": "+70667606505"}
0005432531172	03E831	2675 046372	EVGENIY KUZMIN	{"email": "kuzmin-evgeniy.121974@postgrespro.ru", "phone": "+70668679548"}
0005432531173	03E831	4031 000263	DMITRIY KRASNOV	{"email": "krasnov_d31101967@postgrespro.ru", "phone": "+70404092033"}
0005432531174	5DECE2	2311 029485	NINA NESTEROVA	{"email": "nesterova_nina1977@postgrespro.ru", "phone": "+70987350209"}
0005432531175	5DECE2	1868 080953	TAMARA MARTYNOVA	{"email": "tamara_martynova.03051973@postgrespro.ru", "phone": "+70736863518"}
0005432531176	D924FD	4634 475416	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov.01101980@postgrespro.ru", "phone": "+70596626207"}
0005432531177	ED0FB2	4926 837883	VLADIMIR ROMANOV	{"email": "v.romanov27031976@postgrespro.ru", "phone": "+70846379482"}
0005432531178	6CD148	4888 002699	YURIY SOKOLOV	{"email": "yuriysokolov021968@postgrespro.ru", "phone": "+70207610624"}
0005432531179	6CD148	6881 408980	MAKSIM VASILEV	{"email": "vasilev.maksim_061977@postgrespro.ru", "phone": "+70218558508"}
0005432531180	1E68A2	1462 211788	LARISA VOROBEVA	{"phone": "+70724337856"}
0005432531181	79646E	6509 627740	VALENTINA MIKHAYLOVA	{"email": "valentina-mikhaylova_17111978@postgrespro.ru", "phone": "+70045132972"}
0005432531182	985A6A	5253 376615	ALEKSANDR NIKITIN	{"phone": "+70144406602"}
0005432531183	F2C54C	7241 756706	ZHANNA MATVEEVA	{"email": "matveeva-zhanna_111965@postgrespro.ru", "phone": "+70543916433"}
0005432531184	EC051F	1933 463660	OKSANA KUZMINA	{"email": "oksanakuzmina1976@postgrespro.ru", "phone": "+70537977805"}
0005432531185	EC051F	6801 117301	TATYANA VLASOVA	{"phone": "+70394955590"}
0005432531186	1F59B3	0382 768678	NADEZHDA YAKOVLEVA	{"phone": "+70499432009"}
0005432531187	8120A6	3695 889212	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr_1968@postgrespro.ru", "phone": "+70717414389"}
0005432531188	CF84A1	4339 493356	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaa_091971@postgrespro.ru", "phone": "+70430629408"}
0005432531189	CF84A1	4249 186573	MARIYA NIKITINA	{"phone": "+70813238792"}
0005432531190	CE3EF2	7986 819679	VLADIMIR IVANOV	{"phone": "+70633645459"}
0005432531191	4360AA	7328 626206	VLADISLAV NIKOLAEV	{"phone": "+70181239919"}
0005432531192	A2C259	1830 955984	EVGENIY MAKAROV	{"email": "makarov.evgeniy.1977@postgrespro.ru", "phone": "+70533558832"}
0005432531193	A2C259	0557 907607	SERGEY EGOROV	{"phone": "+70215939507"}
0005432531195	88E627	7821 541100	ILSHAT FILIPPOV	{"email": "filippovi.111975@postgrespro.ru", "phone": "+70464098560"}
0005432531196	8D49AE	9332 537066	SERGEY DMITRIEV	{"email": "s-dmitriev-071974@postgrespro.ru", "phone": "+70817040880"}
0005432531197	8D49AE	0707 031450	VLADIMIR SCHERBAKOV	{"phone": "+70435173264"}
0005432531198	485867	3249 775128	YURIY SIDOROV	{"email": "yuriy-sidorov.071983@postgrespro.ru", "phone": "+70372052444"}
0005432531199	485867	5230 584012	GALINA ANDREEVA	{"phone": "+70525161102"}
0005432531200	485867	3021 235122	NATALYA IVANOVA	{"email": "natalya_ivanova_091970@postgrespro.ru", "phone": "+70450111940"}
0005432531201	6A3CD2	1259 927191	YAROSLAV NIKITIN	{"email": "nikitinyaroslav_061965@postgrespro.ru", "phone": "+70418264466"}
0005432531202	6A3CD2	5049 607287	VALENTINA MIRONOVA	{"email": "mironova.valentina.031957@postgrespro.ru", "phone": "+70302232983"}
0005432531203	3B34F0	6822 103701	NATALYA PAVLOVA	{"email": "n.pavlova1969@postgrespro.ru", "phone": "+70972129455"}
0005432531204	3A4EC5	4029 066329	LEONID MAKAROV	{"phone": "+70125491142"}
0005432531205	186605	4235 976159	IGOR NAZAROV	{"phone": "+70761780020"}
0005432531206	B6A6EA	0248 417523	OLEG VLASOV	{"phone": "+70315193444"}
0005432531207	B6A6EA	9247 013529	VLADIMIR DAVYDOV	{"email": "davydov_vladimir.31011972@postgrespro.ru", "phone": "+70618887089"}
0005432531208	93EEE5	7656 830239	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev091967@postgrespro.ru", "phone": "+70697987486"}
0005432531209	F49224	0403 699946	ILYA FEDOTOV	{"email": "fedotov.ilya-15071972@postgrespro.ru", "phone": "+70741149593"}
0005432531210	458F0A	2074 290270	ALMIRA TIKHONOVA	{"email": "tikhonova.a-101973@postgrespro.ru", "phone": "+70526975313"}
0005432531211	458F0A	9691 729272	OLEG VASILEV	{"email": "vasilev.o-23061958@postgrespro.ru", "phone": "+70680793268"}
0005432531212	458F0A	6245 446055	IRINA ABRAMOVA	{"email": "irina-abramova_1967@postgrespro.ru", "phone": "+70918894245"}
0005432531213	4A6644	5259 500154	ANDREY EGOROV	{"phone": "+70725458321"}
0005432531214	4EA799	5271 730331	GALINA KUZMINA	{"email": "kuzmina.galina_021973@postgrespro.ru", "phone": "+70508864899"}
0005432531215	73422E	2391 872279	ALEKSEY VLASOV	{"email": "aleksey-vlasov.1984@postgrespro.ru", "phone": "+70234478272"}
0005432531216	73422E	6095 472036	NATALYA VASILEVA	{"email": "natalya_vasileva-26051966@postgrespro.ru", "phone": "+70903455516"}
0005432531217	99EFCD	3794 794540	ANNA TARASOVA	{"phone": "+70777491582"}
0005432531218	69AA8D	9853 689742	VALENTINA KOLESNIKOVA	{"phone": "+70817678576"}
0005432531219	0E4CA0	9102 670229	ANNA SIDOROVA	{"email": "asidorova1974@postgrespro.ru", "phone": "+70072306398"}
0005432531220	15FA51	1116 362836	NIKOLAY MOISEEV	{"phone": "+70920003023"}
0005432531221	15FA51	1623 333860	VASILIY MAKAROV	{"phone": "+70195947106"}
0005432531222	4E5B16	0699 091540	GALINA EFIMOVA	{"email": "galina_efimova_011972@postgrespro.ru", "phone": "+70978167152"}
0005432531223	54A56A	8476 883533	VLADIMIR SMIRNOV	{"phone": "+70360197068"}
0005432531224	54A56A	8150 373911	SERGEY OSIPOV	{"phone": "+70015929944"}
0005432531225	DF9034	3976 133986	TATYANA MAKSIMOVA	{"email": "tatyanamaksimova_061982@postgrespro.ru", "phone": "+70557948971"}
0005432531226	DF9034	6017 354360	SERGEY ANDREEV	{"phone": "+70946861758"}
0005432531227	4AB691	0242 854927	ANASTASIYA ARKHIPOVA	{"phone": "+70414575723"}
0005432531228	4AB691	6696 877297	ELENA ANTONOVA	{"email": "elena_antonova-31081974@postgrespro.ru", "phone": "+70884099586"}
0005432531229	0F7CED	6302 282195	KLAVDIYA LEBEDEVA	{"phone": "+70221961961"}
0005432531230	7CAE51	1292 984445	ALLA FILATOVA	{"email": "filatova_alla-031965@postgrespro.ru", "phone": "+70722375402"}
0005432531231	74CDFA	4195 247436	LARISA KULIKOVA	{"email": "larisa_kulikova_25011980@postgrespro.ru", "phone": "+70196577346"}
0005432531232	F69293	6834 311436	SOFIYA ILINA	{"email": "ilina.sofiya-041975@postgrespro.ru", "phone": "+70187816967"}
0005432531233	253C2B	7532 045739	ELENA AKIMOVA	{"email": "eakimova_25041958@postgrespro.ru", "phone": "+70620849290"}
0005432531234	1991DA	9507 419474	MARIYA BOGDANOVA	{"phone": "+70737887004"}
0005432531235	1991DA	4909 503364	LYUBOV NOVIKOVA	{"phone": "+70277441740"}
0005432531236	845EF5	8530 850061	OLEG MATVEEV	{"phone": "+70048761360"}
0005432531237	845EF5	7954 619712	INNA EFREMOVA	{"phone": "+70668194100"}
0005432531238	72B649	4363 600407	TATYANA ROMANOVA	{"phone": "+70102148655"}
0005432531239	5A3BD0	4028 876177	VLADIMIR ZAYCEV	{"email": "zaycevvladimir.1976@postgrespro.ru", "phone": "+70028364619"}
0005432531240	BB541F	9198 295547	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov_02101981@postgrespro.ru", "phone": "+70817844029"}
0005432531241	34B1EC	7403 121897	EKATERINA PETROVA	{"email": "petrova.e1959@postgrespro.ru", "phone": "+70715243216"}
0005432531242	F54FD4	2802 677706	YULIYA ANTONOVA	{"phone": "+70752054177"}
0005432531243	7473E5	4554 103604	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr.011967@postgrespro.ru", "phone": "+70915891152"}
0005432531244	B98173	6470 246727	DANILA SOLOVEV	{"phone": "+70079073855"}
0005432531245	F4F54D	9720 914182	IVAN SMIRNOV	{"email": "ismirnov.30111964@postgrespro.ru", "phone": "+70004235650"}
0005432531246	F4F54D	7509 557307	NIKOLAY AFANASEV	{"email": "afanasevnikolay031976@postgrespro.ru", "phone": "+70696685061"}
0005432531247	2C606C	4275 535064	YURIY KUDRYASHOV	{"email": "kudryashov_y.1968@postgrespro.ru", "phone": "+70564782534"}
0005432531248	2C606C	0957 711001	ALEKSANDR YAKOVLEV	{"email": "ayakovlev_25081970@postgrespro.ru", "phone": "+70965949944"}
0005432531249	32FB32	4210 952509	EVGENIY KUZNECOV	{"email": "evgeniy-kuznecov.011975@postgrespro.ru", "phone": "+70521016637"}
0005432531250	32FB32	6720 771339	OLGA EFIMOVA	{"email": "o.efimova1971@postgrespro.ru", "phone": "+70677881403"}
0005432531251	32FB32	9042 967089	YURIY EGOROV	{"email": "yuriyegorov.13061976@postgrespro.ru", "phone": "+70549873548"}
0005432531252	D144F0	7317 739447	ANATOLIY KUZNECOV	{"email": "anatoliy.kuznecov_071975@postgrespro.ru", "phone": "+70060775690"}
0005432531253	F6D018	6231 140855	RAISA FEDOROVA	{"email": "raisa_fedorova-031983@postgrespro.ru", "phone": "+70237494526"}
0005432531254	912662	8753 495663	VYACHESLAV EGOROV	{"email": "egorovvyacheslav27021968@postgrespro.ru", "phone": "+70763665701"}
0005432531255	912662	7465 391032	TAMARA IVANOVA	{"email": "t.ivanova.1985@postgrespro.ru", "phone": "+70765103584"}
0005432531256	4D5B0D	9349 265111	SERGEY SERGEEV	{"email": "sergeevs081975@postgrespro.ru", "phone": "+70386220083"}
0005432531257	41A3D1	1835 047983	OLEG VOLKOV	{"phone": "+70099859696"}
0005432531258	0E59FB	2259 837014	ANASTASIYA ZAKHAROVA	{"email": "zakharovaanastasiya_27061977@postgrespro.ru", "phone": "+70219811785"}
0005432531259	95E70C	6141 239780	GENNADIY STEPANOV	{"phone": "+70530428251"}
0005432531260	79EF8A	6258 039490	ANNA VOROBEVA	{"phone": "+70686618797"}
0005432531261	AC0BB4	0461 929007	SVETLANA BELYAEVA	{"email": "belyaevasvetlana1974@postgrespro.ru", "phone": "+70971791252"}
0005432531262	FA77DB	5573 599205	ANDREY AFANASEV	{"phone": "+70239121553"}
0005432531263	C11351	5757 222815	LYUDMILA AFANASEVA	{"phone": "+70160270407"}
0005432531264	BE655C	7206 876833	ALEKSEY ZHURAVLEV	{"email": "zhuravlev-aleksey.19071970@postgrespro.ru", "phone": "+70555586262"}
0005432531265	F29ECB	5106 852391	NATALYA KARPOVA	{"phone": "+70767094817"}
0005432531266	AB2CBC	4369 910783	ANASTASIYA SOLOVEVA	{"email": "soloveva-anastasiya-041981@postgrespro.ru", "phone": "+70010750036"}
0005432531267	AB2CBC	8408 929133	MARINA LEBEDEVA	{"email": "m_lebedeva-1970@postgrespro.ru", "phone": "+70595552570"}
0005432531268	AA7D86	8948 240081	DMITRIY PAVLOV	{"email": "dmitriy.pavlov-1974@postgrespro.ru", "phone": "+70806276412"}
0005432531269	FBFE33	2806 951442	EVGENIY VOLKOV	{"phone": "+70111252257"}
0005432531270	FBFE33	0134 846412	NIKOLAY NIKITIN	{"email": "nnikitin_1973@postgrespro.ru", "phone": "+70289511053"}
0005432531271	D8C925	8252 672086	ALEKSEY DENISOV	{"email": "a_denisov21041986@postgrespro.ru", "phone": "+70770756118"}
0005432531272	1EA41A	0302 369991	EVGENIY ALEKSANDROV	{"phone": "+70358102149"}
0005432531273	28352D	3430 886306	NATALYA POPOVA	{"email": "n-popova1967@postgrespro.ru", "phone": "+70195105035"}
0005432531274	32C8AB	4298 603155	IRINA IVANOVA	{"email": "i-ivanova-10011976@postgrespro.ru", "phone": "+70844268465"}
0005432531275	32C8AB	4244 807458	ALEKSEY POPOV	{"email": "popov.a101978@postgrespro.ru", "phone": "+70469205488"}
0005432531276	3F94AA	9749 785714	ELENA DENISOVA	{"phone": "+70357585545"}
0005432531277	DEF2F9	9656 184060	SVETLANA EGOROVA	{"phone": "+70651070737"}
0005432531278	DEF2F9	9538 251201	LYUDMILA IVANOVA	{"email": "lyudmilaivanova-31071973@postgrespro.ru", "phone": "+70040250017"}
0005432531279	85D931	9946 885128	SERGEY KRASNOV	{"email": "sergey.krasnov.15051973@postgrespro.ru", "phone": "+70051741519"}
0005432531280	85D931	8149 028292	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaa.1975@postgrespro.ru", "phone": "+70410919083"}
0005432531281	2F4556	0013 542516	OLEG POPOV	{"email": "opopov-1968@postgrespro.ru", "phone": "+70691675779"}
0005432531282	2F4556	5524 052151	ALEKSANDRA NAZAROVA	{"phone": "+70220859949"}
0005432531283	FBEE4C	8781 708842	VYACHESLAV ALEKSEEV	{"phone": "+70801134451"}
0005432531284	FBEE4C	0057 131669	DMITRIY SCHERBAKOV	{"phone": "+70269281424"}
0005432531285	78D879	5474 902919	NIKOLAY SOKOLOV	{"email": "nikolay_sokolov.1973@postgrespro.ru", "phone": "+70591929862"}
0005432531286	954EE7	5972 680557	TATYANA KONOVALOVA	{"email": "konovalova.t.09031975@postgrespro.ru", "phone": "+70033175543"}
0005432531287	954EE7	6101 388297	GALINA KAZAKOVA	{"phone": "+70842158589"}
0005432531288	B29B7A	0830 867565	ANATOLIY NIKOLAEV	{"email": "nikolaev_anatoliy12041985@postgrespro.ru", "phone": "+70545706261"}
0005432531289	B29B7A	1463 953702	NIKOLAY MIRONOV	{"email": "mironov.nikolay_041958@postgrespro.ru", "phone": "+70607694036"}
0005432531290	B29B7A	5047 323354	IRINA KUZNECOVA	{"email": "i_kuznecova_1974@postgrespro.ru", "phone": "+70241906729"}
0005432531291	58A40C	1002 493689	NATALYA ALEKSEEVA	{"email": "n_alekseeva13071963@postgrespro.ru", "phone": "+70843269250"}
0005432531292	7526A6	8264 323472	ALEKSEY GUSEV	{"phone": "+70244142169"}
0005432531293	7526A6	0741 550381	VLADIMIR STEPANOV	{"phone": "+70424280314"}
0005432531294	F7C538	5737 580592	VLADIMIR PETROV	{"email": "vladimir.petrov_1978@postgrespro.ru", "phone": "+70811290362"}
0005432531295	F7C538	5987 205080	OLEG MIKHAYLOV	{"email": "oleg.mikhaylov_1974@postgrespro.ru", "phone": "+70290869845"}
0005432531296	1D2DF5	9216 041817	BORIS EGOROV	{"phone": "+70469130571"}
0005432531297	D411D3	6473 512435	ALEKSANDR DAVYDOV	{"email": "a.davydov14051976@postgrespro.ru", "phone": "+70994714067"}
0005432531298	E72A33	4001 408519	VALENTIN DMITRIEV	{"email": "dmitrievvalentin.26101975@postgrespro.ru", "phone": "+70826566645"}
0005432531299	6640EC	2528 302350	ANZHELIKA VOLKOVA	{"email": "volkova-a-051972@postgrespro.ru", "phone": "+70650390142"}
0005432531300	9E400C	5358 256917	MILENA VASILEVA	{"phone": "+70858524153"}
0005432531301	16B460	3930 332425	TATYANA MELNIKOVA	{"email": "tatyana-melnikova1969@postgrespro.ru", "phone": "+70051206501"}
0005432531302	0AA111	2377 673044	EGOR MELNIKOV	{"email": "melnikove_021972@postgrespro.ru", "phone": "+70214946755"}
0005432531303	939E07	0230 193531	NATALYA PETROVA	{"phone": "+70808238669"}
0005432531304	939E07	2925 265367	ANASTASIYA KOZLOVA	{"phone": "+70431560676"}
0005432531305	147335	6805 656727	GEVORG MEDVEDEV	{"phone": "+70281176274"}
0005432531306	147335	8791 639392	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey071967@postgrespro.ru", "phone": "+70615041320"}
0005432531307	AB743E	7165 035109	MAKSIM YAKOVLEV	{"email": "yakovlev_m-011964@postgrespro.ru", "phone": "+70915065452"}
0005432531308	3421A1	6303 605283	OLGA SOROKINA	{"email": "olga.sorokina_121974@postgrespro.ru", "phone": "+70775598265"}
0005432531309	3421A1	1625 022901	ANDREY BORISOV	{"phone": "+70304746703"}
0005432531310	5295E7	7724 970056	ELZA MASLOVA	{"email": "maslova-e-15051963@postgrespro.ru", "phone": "+70833620689"}
0005432531311	798411	5296 278197	ELENA KARPOVA	{"email": "elena_karpova.071984@postgrespro.ru", "phone": "+70405367991"}
0005432531312	798411	1981 288242	SEMEN GRIGOREV	{"phone": "+70068327517"}
0005432531313	61614F	7641 156608	YULIYA ZHURAVLEVA	{"phone": "+70879150539"}
0005432531314	5C67C8	6979 412578	IRINA IVANOVA	{"phone": "+70350497824"}
0005432531316	359330	2250 906758	SERGEY KARPOV	{"email": "karpov.sergey19051972@postgrespro.ru", "phone": "+70896470765"}
0005432531317	C52139	3250 944391	MARIYA EFIMOVA	{"phone": "+70463509310"}
0005432531318	C52139	2665 110698	IVAN ALEKSANDROV	{"phone": "+70120622016"}
0005432531319	C52139	3996 084143	ANDREY POPOV	{"email": "a_popov_111979@postgrespro.ru", "phone": "+70185262129"}
0005432531320	660DE5	5069 839840	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko.1966@postgrespro.ru", "phone": "+70316835077"}
0005432531321	B4B436	2712 401796	SVETLANA MOROZOVA	{"email": "s-morozova.1978@postgrespro.ru", "phone": "+70008859123"}
0005432531322	5CFEAD	1052 548401	VLADIMIR SIDOROV	{"phone": "+70589022946"}
0005432531323	5CFEAD	1565 117929	SERGEY PETROV	{"phone": "+70717491539"}
0005432531324	A39173	6040 598302	ALEKSANDR ANDREEV	{"phone": "+70170978617"}
0005432531325	94715F	4679 988413	KRISTINA POPOVA	{"email": "kristina_popova1965@postgrespro.ru", "phone": "+70922459116"}
0005432531326	BB57A1	5417 435442	YURIY STEPANOV	{"phone": "+70701509029"}
0005432531327	209B0F	7990 181539	SERGEY BORISOV	{"phone": "+70268832446"}
0005432531328	1F9F52	8146 078206	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov-1976@postgrespro.ru", "phone": "+70559712032"}
0005432531329	858099	8908 557350	ALEKSEY TIMOFEEV	{"phone": "+70896235857"}
0005432531330	F68A83	6474 460958	MARIYA KULIKOVA	{"phone": "+70713821559"}
0005432531331	F68A83	8135 269832	ALISA BELYAEVA	{"email": "belyaeva-alisa_071969@postgrespro.ru", "phone": "+70042479964"}
0005432531332	F68A83	9096 922545	IVAN NOVIKOV	{"email": "i.novikov-1978@postgrespro.ru", "phone": "+70851875110"}
0005432531333	ACBD96	4914 020162	NATALYA SOLOVEVA	{"phone": "+70208402195"}
0005432531334	A85358	3505 071681	GRIGORIY KAZAKOV	{"email": "kazakov.grigoriy.1974@postgrespro.ru", "phone": "+70106033397"}
0005432531335	43598E	9098 253635	VASILIY MOROZOV	{"phone": "+70415198697"}
0005432531336	43598E	8928 292966	IRINA DENISOVA	{"phone": "+70222853230"}
0005432531337	375BF5	5584 611406	DMITRIY KARPOV	{"phone": "+70487345395"}
0005432531338	342207	8965 624956	OLGA MIKHAYLOVA	{"phone": "+70617603052"}
0005432531339	2C105C	1935 313064	VALERIY POPOV	{"phone": "+70426009336"}
0005432531340	24213E	4543 742039	YANINA KUZMINA	{"email": "kuzmina_yanina1968@postgrespro.ru", "phone": "+70184841833"}
0005432531341	56D948	8303 068380	SERGEY NIKITIN	{"email": "snikitin1972@postgrespro.ru", "phone": "+70191248850"}
0005432531342	56D948	9139 085656	RUSLAN YAKOVLEV	{"phone": "+70632969131"}
0005432531343	D594FE	1673 306168	NIKOLAY KRASNOV	{"phone": "+70701683040"}
0005432531344	0C91AE	8071 717402	NATALYA VASILEVA	{"email": "vasileva-n-1973@postgrespro.ru", "phone": "+70919022407"}
0005432531345	4F6731	9228 426039	LYUBOV SOROKINA	{"phone": "+70702790949"}
0005432531346	4F6731	8171 384230	ANDREY POPOV	{"phone": "+70484458267"}
0005432531347	7B10B9	6125 731143	ZINAIDA GERASIMOVA	{"phone": "+70154234106"}
0005432531348	7B10B9	3052 860839	ELENA MARTYNOVA	{"email": "e.martynova-1970@postgrespro.ru", "phone": "+70460263909"}
0005432531349	6FDAAE	1960 998868	VALENTINA KALININA	{"email": "kalinina_valentina-1961@postgrespro.ru", "phone": "+70692180649"}
0005432531350	6FDAAE	7854 312268	NIKOLAY SEMENOV	{"phone": "+70001311696"}
0005432531351	79F40F	4850 303616	ANDREY NIKOLAEV	{"email": "andrey.nikolaev-29081978@postgrespro.ru", "phone": "+70279783826"}
0005432531352	79F40F	2597 127558	SERGEY MIKHAYLOV	{"email": "mikhaylov.sergey.29041982@postgrespro.ru", "phone": "+70366789266"}
0005432531353	AB3020	4655 676739	OLGA MIRONOVA	{"phone": "+70191337803"}
0005432531354	AB3020	6290 563767	SERGEY BELOV	{"email": "sergeybelov1975@postgrespro.ru", "phone": "+70051042064"}
0005432531355	5C1DA2	2817 667450	ALINA KAZAKOVA	{"phone": "+70185688297"}
0005432531356	61E2A2	0923 270722	OLGA ISAEVA	{"email": "isaeva.olga-081974@postgrespro.ru", "phone": "+70817899805"}
0005432531357	61E2A2	4668 746166	ANATOLIY VLASOV	{"email": "vlasov_anatoliy1971@postgrespro.ru", "phone": "+70483747107"}
0005432531358	8FE77D	2259 094300	VASILIY DENISOV	{"phone": "+70000903925"}
0005432531359	8FE77D	2605 996770	EKATERINA FILIPPOVA	{"phone": "+70388240334"}
0005432531360	BA9FC1	1563 182943	SERGEY GRIGOREV	{"phone": "+70107510463"}
0005432531361	BA9FC1	3826 163550	YURIY MAKSIMOV	{"phone": "+70934790392"}
0005432531362	BA9FC1	5415 578157	ILFAT VOLKOV	{"email": "ilfatvolkov.22121967@postgrespro.ru", "phone": "+70313908219"}
0005432531363	FCA894	6774 013145	DENIS BORISOV	{"email": "denis.borisov_04091971@postgrespro.ru", "phone": "+70510076408"}
0005432531364	FCA894	4916 609049	ANASTASIYA ANISIMOVA	{"phone": "+70067189823"}
0005432531365	3F0844	2201 708742	VALENTINA MOROZOVA	{"email": "morozova_v.1969@postgrespro.ru", "phone": "+70118516229"}
0005432531366	3F0844	5038 075191	VYACHESLAV RODIONOV	{"email": "rodionov-v_1976@postgrespro.ru", "phone": "+70976483446"}
0005432531367	F4F4EA	6181 157291	NADEZHDA PETROVA	{"phone": "+70046662616"}
0005432531368	154635	4406 504868	ARINA VASILEVA	{"email": "arina_vasileva1986@postgrespro.ru", "phone": "+70622560962"}
0005432531369	08DBAC	5833 764014	OKSANA KOZLOVA	{"email": "kozlovaoksana_1955@postgrespro.ru", "phone": "+70569449468"}
0005432531370	6BCC5A	2774 559618	SVETLANA KONDRATEVA	{"phone": "+70113298011"}
0005432531371	6BCC5A	4192 989560	FAINA NAUMOVA	{"email": "f-naumova_1967@postgrespro.ru", "phone": "+70869536166"}
0005432531372	56979F	3454 346322	MARIYA GUSEVA	{"email": "m.guseva.1977@postgrespro.ru", "phone": "+70101926027"}
0005432531373	796282	4649 696462	YULIYA TARASOVA	{"email": "y_tarasova.27121963@postgrespro.ru", "phone": "+70272423558"}
0005432531374	D65D95	1203 723958	ARTEM KUZNECOV	{"phone": "+70373458304"}
0005432531375	D65D95	5870 918160	VIKTORIYA MATVEEVA	{"phone": "+70677228532"}
0005432531376	CE7094	0487 991398	ROMAN KUZNECOV	{"email": "r.kuznecov1976@postgrespro.ru", "phone": "+70658864451"}
0005432531377	A2AD3B	6694 598911	SOFIYA MIRONOVA	{"email": "mironovas-1965@postgrespro.ru", "phone": "+70297974206"}
0005432531378	A2AD3B	4149 794338	TAMARA GORBUNOVA	{"phone": "+70923306306"}
0005432531379	985A45	0755 076980	YULIYA KOMAROVA	{"email": "komarova_y_1974@postgrespro.ru", "phone": "+70584292221"}
0005432531380	985A45	3028 181249	NATALYA BELOVA	{"phone": "+70141358456"}
0005432531381	58902F	9427 630803	KONSTANTIN POPOV	{"phone": "+70374754062"}
0005432531382	58902F	7866 769913	RENATA PETROVA	{"phone": "+70043299451"}
0005432531383	4DD9DD	3858 276432	ALEKSANDR GERASIMOV	{"phone": "+70852365863"}
0005432531384	E07DAA	0263 428706	YULIYA GUSEVA	{"email": "guseva_y.1966@postgrespro.ru", "phone": "+70573361601"}
0005432531385	E07DAA	4207 694367	GULFIYA KOROLEVA	{"phone": "+70974155771"}
0005432531386	95DF3F	8542 653142	RUSTEM ZAKHAROV	{"phone": "+70545036323"}
0005432531387	4E36DB	3684 849333	TAMARA STEPANOVA	{"phone": "+70525232145"}
0005432531388	4E36DB	7875 858004	MADINA AKIMOVA	{"phone": "+70504356419"}
0005432531389	D21395	6459 472828	ELIZAVETA IVANOVA	{"email": "ivanova.e.051969@postgrespro.ru", "phone": "+70570243857"}
0005432531390	D21395	1104 251759	KRISTINA IVANOVA	{"email": "k_ivanova-1975@postgrespro.ru", "phone": "+70157978416"}
0005432531391	3441F4	5262 701085	YULIYA ANTONOVA	{"email": "yuliya.antonova-1969@postgrespro.ru", "phone": "+70059573619"}
0005432531392	3441F4	3639 128206	NADEZHDA MELNIKOVA	{"phone": "+70016070224"}
0005432531393	E1EEFB	6547 300019	IVAN ILIN	{"email": "ilin-i_1970@postgrespro.ru", "phone": "+70237344435"}
0005432531394	E1EEFB	4557 825074	VLADIMIR NAUMOV	{"phone": "+70257850760"}
0005432531395	E358C3	2405 078404	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir.30101982@postgrespro.ru", "phone": "+70775253198"}
0005432531396	A7311F	6563 667205	OLGA KULIKOVA	{"phone": "+70888652668"}
0005432531397	E8BA31	6638 845925	IRINA KULIKOVA	{"email": "kulikova_irina061976@postgrespro.ru", "phone": "+70300363324"}
0005432531398	A7C7FD	5306 752046	SVETLANA IVANOVA	{"email": "s.ivanova1980@postgrespro.ru", "phone": "+70629266898"}
0005432531399	7D1E77	5056 600085	VLADISLAV BORISOV	{"email": "vladislavborisov_17081975@postgrespro.ru", "phone": "+70778362321"}
0005432531400	C377B3	8898 981331	ANDREY IVANOV	{"phone": "+70343662500"}
0005432531401	320638	2264 001278	EVGENIY SCHERBAKOV	{"phone": "+70342769691"}
0005432531402	E7726B	1885 438617	DMITRIY VOLKOV	{"phone": "+70465489949"}
0005432531403	E7726B	3622 167954	ANDREY TARASOV	{"phone": "+70154712511"}
0005432531404	E7726B	4977 812913	SVETLANA ANTONOVA	{"email": "s.antonova_1971@postgrespro.ru", "phone": "+70769255008"}
0005432531405	41A1C4	2511 964488	SERGEY SMIRNOV	{"phone": "+70586038933"}
0005432531406	993321	6706 575084	NIKOLAY IVANOV	{"phone": "+70071542135"}
0005432531407	993321	7191 258428	ANDREY ALEKSANDROV	{"email": "aleksandrov_andrey-101973@postgrespro.ru", "phone": "+70197212133"}
0005432531408	C1C0E1	2551 974411	LYUDMILA POPOVA	{"phone": "+70052765929"}
0005432531409	D1AA48	9394 799110	SVETLANA SMIRNOVA	{"phone": "+70077784804"}
0005432531410	D1AA48	3181 672311	ALBINA TITOVA	{"phone": "+70707618131"}
0005432531411	D0CC6E	1924 979945	GRIGORIY ORLOV	{"email": "orlov_g.031976@postgrespro.ru", "phone": "+70081350186"}
0005432531412	063160	1630 747671	VALENTINA BELYAEVA	{"email": "belyaeva.valentina.07121966@postgrespro.ru", "phone": "+70730682823"}
0005432531413	521C38	9680 069454	KSENIYA IVANOVA	{"email": "kivanova-071985@postgrespro.ru", "phone": "+70303729937"}
0005432531414	521C38	8235 361231	VIKTOR ALEKSANDROV	{"email": "aleksandrovv_061973@postgrespro.ru", "phone": "+70586867884"}
0005432531415	521C38	4678 721576	SERGEY ORLOV	{"email": "s.orlov-1967@postgrespro.ru", "phone": "+70751603595"}
0005432531416	1EF72E	0014 839811	ANDREY STEPANOV	{"phone": "+70223988218"}
0005432531417	1E5956	9699 124796	IRINA POLYAKOVA	{"email": "irina_polyakova.23021970@postgrespro.ru", "phone": "+70024370635"}
0005432531418	1E5956	7185 787465	LARISA STEPANOVA	{"phone": "+70247306172"}
0005432531419	EF7334	2886 108474	MAKSIM VASILEV	{"phone": "+70991719692"}
0005432531420	92F905	8558 383431	YULIYA ALEKSANDROVA	{"email": "aleksandrova_y_04041979@postgrespro.ru", "phone": "+70475048708"}
0005432531421	A4F75F	7757 431144	YULIYA ANDREEVA	{"phone": "+70727287740"}
0005432531422	979C90	6709 385248	ELENA BELOVA	{"email": "e.belova.1972@postgrespro.ru", "phone": "+70103243133"}
0005432531423	979C90	9871 809166	RINAT MARTYNOV	{"email": "rmartynov14011970@postgrespro.ru", "phone": "+70387086237"}
0005432531424	6965BC	3981 594186	NATALIYA OVCHINNIKOVA	{"email": "nataliya-ovchinnikova_071973@postgrespro.ru", "phone": "+70922620445"}
0005432531425	09D596	1353 608041	MIKHAIL YAKOVLEV	{"phone": "+70628309455"}
0005432531426	F57587	0323 533266	DARINA VASILEVA	{"email": "d_vasileva_1968@postgrespro.ru", "phone": "+70149176886"}
0005432531427	F57587	6743 698287	ALEKSANDR GRIGOREV	{"email": "aleksandr.grigorev.26081964@postgrespro.ru", "phone": "+70275036880"}
0005432531428	B603E2	9968 061620	TATYANA DMITRIEVA	{"phone": "+70989986059"}
0005432531429	130C5B	8715 112714	VIKTOR TARASOV	{"email": "v-tarasov1955@postgrespro.ru", "phone": "+70210831815"}
0005432531430	E203FA	3955 213228	TATYANA KRASNOVA	{"phone": "+70740325321"}
0005432531431	E203FA	1676 862696	EKATERINA STEPANOVA	{"email": "stepanovaekaterina041966@postgrespro.ru", "phone": "+70471081677"}
0005432531432	7467F9	6657 327153	ALEKSANDR ILIN	{"phone": "+70898145636"}
0005432531433	1B0EE8	5001 910492	YURIY GORBUNOV	{"phone": "+70828846826"}
0005432531434	1B0EE8	9868 242053	MARINA SCHERBAKOVA	{"phone": "+70815821005"}
0005432531435	FB88E4	7707 519203	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov.11121984@postgrespro.ru", "phone": "+70853387433"}
0005432531436	FB88E4	4901 864944	EVGENIY RODIONOV	{"email": "rodionov_evgeniy23051982@postgrespro.ru", "phone": "+70376963996"}
0005432531437	CE459C	3249 998897	ALEKSANDR PAVLOV	{"phone": "+70337023599"}
0005432531438	7472FE	4066 003425	VLADIMIR TIMOFEEV	{"phone": "+70309012394"}
0005432531439	7472FE	0641 417946	TATYANA MIKHAYLOVA	{"email": "mikhaylova.tatyana_18091968@postgrespro.ru", "phone": "+70868647135"}
0005432531440	6E4737	1377 163906	EKATERINA FOMINA	{"email": "fominaekaterina_041972@postgrespro.ru", "phone": "+70132599174"}
0005432531441	F6E2CB	8463 494196	ARTEM YAKOVLEV	{"phone": "+70653064302"}
0005432531442	5844C0	4654 378435	SAMIRA MOROZOVA	{"email": "morozova_s.091967@postgrespro.ru", "phone": "+70297478325"}
0005432531443	5844C0	9741 874886	GALINA TIKHONOVA	{"email": "tikhonova.galina.10071967@postgrespro.ru", "phone": "+70082321991"}
0005432531444	4F49CE	2588 494532	DARYA TARASOVA	{"phone": "+70025409035"}
0005432531445	4F49CE	2159 344136	TATYANA SOLOVEVA	{"email": "t-soloveva-18091981@postgrespro.ru", "phone": "+70100461883"}
0005432531446	1EBF4C	7581 145746	ANTON GAVRILOV	{"phone": "+70852684017"}
0005432531447	23B395	9661 405574	ANNA STEPANOVA	{"phone": "+70970205405"}
0005432531448	ED0B09	6438 584748	ALEKSEY MOISEEV	{"phone": "+70286385978"}
0005432531449	B0EEF4	4206 972450	ELENA ISAEVA	{"phone": "+70456549516"}
0005432531450	D0642F	4135 479239	ALEKSANDRA EFREMOVA	{"email": "a-efremova12121970@postgrespro.ru", "phone": "+70472309408"}
0005432531451	236809	0537 108964	EVGENIY FROLOV	{"email": "e_frolov_16101967@postgrespro.ru", "phone": "+70921869179"}
0005432531452	236809	8405 988764	RUSLAN NIKITIN	{"email": "ruslan_nikitin121969@postgrespro.ru", "phone": "+70575880484"}
0005432531453	A8975F	7522 419222	VLADIMIR SERGEEV	{"email": "v-sergeev101974@postgrespro.ru", "phone": "+70366823212"}
0005432531454	E66EF0	9406 292289	MIKHAIL KAZAKOV	{"email": "m-kazakov_11071972@postgrespro.ru", "phone": "+70450345984"}
0005432531455	646501	1260 701208	TAMARA BORISOVA	{"phone": "+70900360886"}
0005432531456	0BA098	6649 442883	NIKOLAY KISELEV	{"email": "n.kiselev.081971@postgrespro.ru", "phone": "+70400367803"}
0005432531457	72CC1B	1973 256380	MAKSIM GORBUNOV	{"email": "maksim_gorbunov-04071975@postgrespro.ru", "phone": "+70220579369"}
0005432531458	28E733	2589 788706	VALENTINA ISAEVA	{"phone": "+70262216158"}
0005432531459	28E733	1635 038702	ALEKSANDR KUZNECOV	{"phone": "+70981987588"}
0005432531460	456609	7098 154257	LYUDMILA MEDVEDEVA	{"phone": "+70251235413"}
0005432531461	456609	4437 211396	NIKOLAY AFANASEV	{"phone": "+70959244074"}
0005432531462	3139F8	1728 826739	ALEKSEY IVANOV	{"phone": "+70666741405"}
0005432531463	3139F8	9186 926123	SERGEY EGOROV	{"phone": "+70211138252"}
0005432531464	913D4D	8625 400670	ALEKSANDR KUZNECOV	{"phone": "+70959328081"}
0005432531465	913D4D	8318 354031	VERA GRISHINA	{"email": "grishinavera1981@postgrespro.ru", "phone": "+70189587637"}
0005432531466	3DE64F	9010 903561	VLADIMIR FEDOROV	{"phone": "+70160473688"}
0005432531467	109DEA	4929 531907	VALENTINA MATVEEVA	{"phone": "+70578832763"}
0005432531468	A20956	1768 436690	NATALYA SAVELEVA	{"phone": "+70745568518"}
0005432531469	61C57C	7997 390304	ALEKSANDR IVANOV	{"email": "a-ivanov-1975@postgrespro.ru", "phone": "+70529978948"}
0005432531470	694C7C	2015 235325	OLGA MAKAROVA	{"email": "makarova-o-1966@postgrespro.ru", "phone": "+70977148770"}
0005432531471	ABC4CD	6189 231672	KLAVDIYA NOVIKOVA	{"email": "k_novikova.14011968@postgrespro.ru", "phone": "+70436552993"}
0005432531472	872747	5983 950371	OLEG PETROV	{"email": "petrov.oleg051972@postgrespro.ru", "phone": "+70743098334"}
0005432531473	872747	4050 120389	ANATOLIY NIKOLAEV	{"email": "anatoliy-nikolaev-01111966@postgrespro.ru", "phone": "+70508362997"}
0005432531474	18E1CA	8660 835510	KSENIYA SIDOROVA	{"email": "sidorova.k_041978@postgrespro.ru", "phone": "+70239269777"}
0005432531475	868591	1052 822599	YURIY ABRAMOV	{"email": "abramov-yuriy_091967@postgrespro.ru", "phone": "+70419904846"}
0005432531476	CE029A	5733 270537	RAISA MOROZOVA	{"phone": "+70390648818"}
0005432531477	FE36B5	7469 541470	ANNA ALEKSANDROVA	{"email": "aleksandrovaa_081976@postgrespro.ru", "phone": "+70272036467"}
0005432531478	FE36B5	3044 548678	KIRILL EGOROV	{"email": "kegorov_1975@postgrespro.ru", "phone": "+70087806502"}
0005432531479	61D240	6042 389031	OLGA VASILEVA	{"phone": "+70744685041"}
0005432531480	A7C57F	0859 547991	VALENTIN KUDRYASHOV	{"phone": "+70769133220"}
0005432531481	A7C57F	0923 983781	MARIYA CHERNOVA	{"phone": "+70877888833"}
0005432531482	3B3797	3528 855513	GALINA KUZNECOVA	{"email": "kuznecova-g_24101983@postgrespro.ru", "phone": "+70942415738"}
0005432531483	9C2AA3	8623 899667	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_1967@postgrespro.ru", "phone": "+70321949492"}
0005432531484	9C2AA3	9514 550873	NATALIYA KUZMINA	{"phone": "+70190999042"}
0005432531485	9C2AA3	3292 492797	NINA NIKITINA	{"email": "nina_nikitina-1966@postgrespro.ru", "phone": "+70691661592"}
0005432531486	9C2AA3	5031 959235	IVAN YAKOVLEV	{"phone": "+70721034783"}
0005432531487	DB898D	8208 755850	ZINAIDA BORISOVA	{"phone": "+70318099430"}
0005432531488	407A63	7617 822113	OLGA KUZNECOVA	{"phone": "+70524433493"}
0005432531489	D22795	7137 983338	RAISA ALEKSEEVA	{"email": "raisa_alekseeva-061962@postgrespro.ru", "phone": "+70489192192"}
0005432531490	D22795	3813 335231	OLGA PAVLOVA	{"phone": "+70897950948"}
0005432531491	71C3FA	7857 152270	YULIYA GERASIMOVA	{"phone": "+70230026026"}
0005432531492	807FA0	8103 674064	ALEKSANDR SCHERBAKOV	{"phone": "+70023261667"}
0005432531493	807FA0	7285 163045	MIKHAIL KUZNECOV	{"phone": "+70783306680"}
0005432531494	D19A57	7613 013340	IGOR SEMENOV	{"email": "igor_semenov06021984@postgrespro.ru", "phone": "+70225572438"}
0005432531495	34A6C2	9461 497534	GALINA VASILEVA	{"phone": "+70579921543"}
0005432531496	34A6C2	8087 349469	DMITRIY DENISOV	{"email": "denisov_dmitriy-24031962@postgrespro.ru", "phone": "+70428934726"}
0005432531497	D5FFC7	1674 194816	LARISA IVANOVA	{"email": "ivanova-l.051972@postgrespro.ru", "phone": "+70120313649"}
0005432531498	D5FFC7	3613 793600	SERGEY MELNIKOV	{"email": "melnikov_sergey1984@postgrespro.ru", "phone": "+70982606226"}
0005432531499	D5FFC7	0944 639193	ALENA ARKHIPOVA	{"email": "alena_arkhipova-1970@postgrespro.ru", "phone": "+70472710617"}
0005432531500	952B5E	5486 342588	NAIL GORBUNOV	{"email": "nail-gorbunov1974@postgrespro.ru", "phone": "+70980221848"}
0005432531501	952B5E	5447 271449	LYUBOV ISAEVA	{"phone": "+70178357817"}
0005432531502	7AE7B1	8525 314984	OKSANA KULIKOVA	{"phone": "+70807370569"}
0005432531503	7AE7B1	5604 789361	ALEKSEY FROLOV	{"email": "a.frolov_1969@postgrespro.ru", "phone": "+70618479353"}
0005432531504	1792D8	4127 479480	KIRILL DMITRIEV	{"phone": "+70331461001"}
0005432531505	D1F244	8923 696395	IRINA SOROKINA	{"phone": "+70898035608"}
0005432531506	3FEA22	7546 851608	SOFYA AKIMOVA	{"email": "akimova_s-1974@postgrespro.ru", "phone": "+70539275513"}
0005432531507	3FEA22	7233 237647	SERGEY DENISOV	{"phone": "+70116262601"}
0005432531508	CD317B	1426 926281	VIKTORIYA EGOROVA	{"email": "egorova-v_31011976@postgrespro.ru", "phone": "+70587429643"}
0005432531509	201150	3646 056648	NIKOLAY OSIPOV	{"phone": "+70330472691"}
0005432531510	BD0325	5440 871419	ANNA TIKHONOVA	{"phone": "+70778495850"}
0005432531511	BF0CE9	8440 400943	VIKTOR TARASOV	{"phone": "+70637612339"}
0005432531512	BF0CE9	7320 293747	ALEKSANDR KUZMIN	{"phone": "+70922438524"}
0005432531513	555A65	4801 420042	INNA FEDOROVA	{"email": "fedorova-inna_1983@postgrespro.ru", "phone": "+70878630920"}
0005432531514	555A65	4263 363400	ANASTASIYA VOROBEVA	{"phone": "+70835752630"}
0005432531515	89D10E	6867 500250	SERGEY MIKHAYLOV	{"phone": "+70034382627"}
0005432531516	97EC5A	5942 311855	NATALYA SEMENOVA	{"email": "semenova-n.06071973@postgrespro.ru", "phone": "+70123392085"}
0005432531517	30669E	4842 097510	YURIY SAVELEV	{"phone": "+70365934940"}
0005432531518	8631AB	0048 783481	VLADIMIR FROLOV	{"email": "vladimir.frolov1973@postgrespro.ru", "phone": "+70390747509"}
0005432531519	31D26E	1283 288551	LYUDMILA GERASIMOVA	{"email": "gerasimoval.20031967@postgrespro.ru", "phone": "+70406228528"}
0005432531520	D7E4F1	7070 515002	RAFAIL FROLOV	{"phone": "+70514078972"}
0005432531521	885598	0194 413221	NATALYA KUZMINA	{"email": "kuzmina.natalya23031964@postgrespro.ru", "phone": "+70316877568"}
0005432531522	FD4BE4	4474 400178	NIKOLAY ROMANOV	{"email": "romanov-nikolay_061973@postgrespro.ru", "phone": "+70518167607"}
0005432531523	9021CC	2456 099751	NINA EGOROVA	{"email": "ninaegorova-011984@postgrespro.ru", "phone": "+70844724831"}
0005432531524	D19A4B	2609 937497	VIKTOR PETROV	{"phone": "+70199463403"}
0005432531525	D19A4B	6549 612474	ALEKSANDRA PAVLOVA	{"email": "a_pavlova1969@postgrespro.ru", "phone": "+70543631894"}
0005432531526	A85AD2	6187 821378	ANASTASIYA TARASOVA	{"phone": "+70056850470"}
0005432531527	BF9E3B	3454 919500	NATALYA KUZNECOVA	{"phone": "+70611926863"}
0005432531528	302F36	8665 460149	SERGEY ALEKSANDROV	{"email": "aleksandrovs_1983@postgrespro.ru", "phone": "+70157582803"}
0005432531529	C061BC	6766 843408	TAMARA SERGEEVA	{"email": "t-sergeeva.30011978@postgrespro.ru", "phone": "+70697874420"}
0005432531530	54657A	8070 791834	YAKOV MOISEEV	{"email": "y.moiseev1985@postgrespro.ru", "phone": "+70921896739"}
0005432531586	4E16FE	4589 627710	KLAVDIYA SOROKINA	{"phone": "+70092714945"}
0005432531531	744D0D	3291 349450	MARINA DENISOVA	{"email": "marina_denisova03081972@postgrespro.ru", "phone": "+70670323996"}
0005432531532	FEA009	4669 673948	ANGELINA IVANOVA	{"phone": "+70287254504"}
0005432531533	FEA009	2177 885552	ALEKSANDR PETROV	{"email": "petrov_a24091974@postgrespro.ru", "phone": "+70530035861"}
0005432531534	E77D33	2856 297172	NATALIYA TROFIMOVA	{"phone": "+70571582139"}
0005432531535	ACB0D7	6763 939945	SERGEY MOROZOV	{"phone": "+70056725517"}
0005432531536	81A66A	0204 785021	LYUDMILA ZHUKOVA	{"email": "zhukovalyudmila.1981@postgrespro.ru", "phone": "+70967771735"}
0005432531537	81A66A	0699 399637	EKATERINA IVANOVA	{"phone": "+70694680641"}
0005432531538	668E50	5486 252760	MIKHAIL DMITRIEV	{"phone": "+70151312958"}
0005432531539	3E485F	7509 405998	OLGA IVANOVA	{"email": "o.ivanova-1978@postgrespro.ru", "phone": "+70184661032"}
0005432531540	5A3948	2786 832566	MAKSIM ZAKHAROV	{"email": "maksim.zakharov-31071977@postgrespro.ru", "phone": "+70881319564"}
0005432531541	5A3948	3347 206787	OLGA VASILEVA	{"email": "vasileva_olga.1971@postgrespro.ru", "phone": "+70450564891"}
0005432531542	BCC657	9945 136781	OLGA PAVLOVA	{"email": "pavlova.olga011981@postgrespro.ru", "phone": "+70857165270"}
0005432531543	8624C9	6272 261158	OKSANA CHERNOVA	{"phone": "+70926972493"}
0005432531544	6AAB95	2434 775924	YULIYA TIKHONOVA	{"email": "yuliya.tikhonova_011981@postgrespro.ru", "phone": "+70914064880"}
0005432531545	562EFA	2164 772066	OLEG GORBUNOV	{"email": "o-gorbunov081989@postgrespro.ru", "phone": "+70079095475"}
0005432531546	562EFA	7631 496861	GENNADIY IVANOV	{"email": "ivanov.g09071955@postgrespro.ru", "phone": "+70234607327"}
0005432531547	769B2E	7712 844805	NATALYA PAVLOVA	{"phone": "+70628873020"}
0005432531548	FAD298	0626 610951	TATYANA IVANOVA	{"email": "ivanova-t.061979@postgrespro.ru", "phone": "+70787424079"}
0005432531549	E52B58	5625 613616	LYUBOV SMIRNOVA	{"phone": "+70756826584"}
0005432531550	805268	6277 466975	MARGARITA ROMANOVA	{"phone": "+70474446623"}
0005432531551	805268	3927 024060	OLEG ROMANOV	{"phone": "+70687502784"}
0005432531552	73B16B	2893 674901	TATYANA SOKOLOVA	{"phone": "+70117203240"}
0005432531553	73B16B	6785 039674	VLADIMIR GRIGOREV	{"phone": "+70412344600"}
0005432531554	328075	4900 203466	VALENTINA MOROZOVA	{"email": "morozovavalentina-22031971@postgrespro.ru", "phone": "+70814332436"}
0005432531555	F79A3E	3557 684622	DMITRIY GRIGOREV	{"phone": "+70962161568"}
0005432531556	3B18F7	5460 139371	ALEKSANDRA KUDRYASHOVA	{"email": "kudryashova.a051974@postgrespro.ru", "phone": "+70901766928"}
0005432531557	3B18F7	8571 639925	ANNA GERASIMOVA	{"email": "anna-gerasimova_23061971@postgrespro.ru", "phone": "+70008625551"}
0005432531558	375914	4785 069079	ELENA GERASIMOVA	{"phone": "+70527819805"}
0005432531559	375914	9878 121560	VLADIMIR VLASOV	{"phone": "+70025801824"}
0005432531560	3D0616	3752 151690	KONSTANTIN SEMENOV	{"email": "semenov_konstantin.25011980@postgrespro.ru", "phone": "+70452341440"}
0005432531561	A2C5EA	9993 267008	EKATERINA MIKHAYLOVA	{"phone": "+70398967545"}
0005432531562	7E11DC	5431 335884	VALERIYA KAZAKOVA	{"email": "vkazakova-17041975@postgrespro.ru", "phone": "+70354067501"}
0005432531563	7E11DC	9815 929818	VLADISLAV OSIPOV	{"phone": "+70451903279"}
0005432531564	10890B	8843 480406	DMITRIY MIKHAYLOV	{"email": "d.mikhaylov1976@postgrespro.ru", "phone": "+70237555127"}
0005432531565	10890B	1955 674505	DMITRIY VASILEV	{"phone": "+70910847062"}
0005432531566	A6BCBA	3853 713594	MARIYA MASLOVA	{"email": "maslova.mariya-061975@postgrespro.ru", "phone": "+70132092734"}
0005432531567	9F0A19	1964 996999	NADEZHDA CHERNOVA	{"phone": "+70154108080"}
0005432531568	9F0A19	3774 186483	EVGENIY EGOROV	{"email": "evgeniy_egorov11011965@postgrespro.ru", "phone": "+70129943192"}
0005432531569	E70427	2192 572803	LARISA OSIPOVA	{"email": "osipova-l17081980@postgrespro.ru", "phone": "+70575004874"}
0005432531570	E70427	9872 939198	ALEKSEY EGOROV	{"email": "egorov_aleksey.1984@postgrespro.ru", "phone": "+70810892034"}
0005432531571	A3778F	6646 251691	ANDREY ORLOV	{"email": "andrey-orlov101981@postgrespro.ru", "phone": "+70308038662"}
0005432531572	1A0789	8356 747297	NIKOLAY NIKOLAEV	{"phone": "+70764929111"}
0005432531573	5486F3	9350 596743	MARIYA KAZAKOVA	{"email": "m-kazakova.1974@postgrespro.ru", "phone": "+70797182970"}
0005432531574	1464D7	7671 340255	OKSANA EFREMOVA	{"email": "oefremova1980@postgrespro.ru", "phone": "+70849825665"}
0005432531575	2091E6	1975 276587	NIKOLAY ISAEV	{"email": "nikolay.isaev.1969@postgrespro.ru", "phone": "+70379602294"}
0005432531576	3244BF	4252 211200	DARYA FADEEVA	{"email": "fadeeva-darya_091972@postgrespro.ru", "phone": "+70390163357"}
0005432531577	DF288E	6094 164710	VALENTINA ABRAMOVA	{"phone": "+70099553112"}
0005432531578	DF288E	7588 006142	VALENTINA ABRAMOVA	{"phone": "+70797434145"}
0005432531579	A38730	4326 262620	VIKTORIYA ANISIMOVA	{"phone": "+70169705291"}
0005432531580	9D8344	7969 625247	MARIYA GAVRILOVA	{"email": "gavrilova_mariya07051974@postgrespro.ru", "phone": "+70375791669"}
0005432531581	B8815D	3800 913921	OLEG ISAEV	{"phone": "+70813569477"}
0005432531582	3372FE	4721 577477	VASILIY TARASOV	{"email": "v_tarasov.1975@postgrespro.ru", "phone": "+70210465581"}
0005432531583	3372FE	9212 930113	ALEKSANDR DAVYDOV	{"email": "davydova.061982@postgrespro.ru", "phone": "+70257528020"}
0005432531584	95D486	5348 776053	YULIYA KUZNECOVA	{"email": "kuznecova.yuliya-1986@postgrespro.ru", "phone": "+70148656157"}
0005432531585	484265	7926 989403	VALENTINA PAVLOVA	{"email": "valentina-pavlova.1982@postgrespro.ru", "phone": "+70906580855"}
0005432531587	B91EB9	2819 112901	VLADIMIR DAVYDOV	{"email": "v.davydov.26021969@postgrespro.ru", "phone": "+70456541474"}
0005432531588	B91EB9	3180 509695	YULIYA KARPOVA	{"email": "yuliya_karpova021971@postgrespro.ru", "phone": "+70239718327"}
0005432531589	3A8247	6933 471467	DMITRIY SOLOVEV	{"email": "dmitriy-solovev.1969@postgrespro.ru", "phone": "+70180800840"}
0005432531590	41963A	6527 075929	ARTEM SMIRNOV	{"email": "smirnov_artem-1969@postgrespro.ru", "phone": "+70754739040"}
0005432531591	41963A	6106 435712	YULIYA LUKYANOVA	{"phone": "+70240642648"}
0005432531592	41963A	8509 311515	NATALYA ALEKSEEVA	{"email": "alekseeva.natalya.1967@postgrespro.ru", "phone": "+70633288762"}
0005432531593	211AF2	9338 377960	VASILIY IVANOV	{"email": "ivanov.vasiliy_1972@postgrespro.ru", "phone": "+70216002736"}
0005432531594	211AF2	5100 248870	ANTON SAVELEV	{"phone": "+70160106937"}
0005432531595	211AF2	8644 477370	VIKTOR MIKHAYLOV	{"phone": "+70492001302"}
0005432531596	211AF2	1677 470496	MIKHAIL CHERNOV	{"phone": "+70414713994"}
0005432531597	3B906B	1855 987696	ANZHELA NESTEROVA	{"phone": "+70472001119"}
0005432531598	3B906B	1843 320925	ANTON IVANOV	{"email": "ivanov.anton.121964@postgrespro.ru", "phone": "+70456581544"}
0005432531599	3B906B	2928 683416	ILYA GUSEV	{"phone": "+70404033365"}
0005432531600	1EB64B	6108 950952	NIKOLAY MEDVEDEV	{"phone": "+70091743426"}
0005432531601	952643	5140 679709	VLADIMIR ANDREEV	{"email": "andreevvladimir071977@postgrespro.ru", "phone": "+70133791527"}
0005432531602	952643	6773 395261	ALENA YAKOVLEVA	{"phone": "+70756180179"}
0005432531603	74F351	8440 782441	NADEZHDA KRASNOVA	{"email": "krasnova_nadezhda1980@postgrespro.ru", "phone": "+70780319975"}
0005432531604	372CDF	0834 527376	LYUDMILA SCHERBAKOVA	{"phone": "+70213999310"}
0005432531605	6BD86E	1621 885181	TAMARA NIKITINA	{"email": "tamara-nikitina-011978@postgrespro.ru", "phone": "+70431032698"}
0005432531606	59630D	9235 268901	LYUDMILA ANISIMOVA	{"phone": "+70965369815"}
0005432531607	CC558A	1344 968819	SERAFIMA PAVLOVA	{"phone": "+70291978799"}
0005432531608	CD67CC	1725 645335	VLADIMIR ANDREEV	{"phone": "+70193502177"}
0005432531609	3508C0	2454 924405	VERA IVANOVA	{"phone": "+70842128591"}
0005432531610	41CDBF	6313 636442	VLADIMIR DENISOV	{"email": "denisov.vladimir_07061979@postgrespro.ru", "phone": "+70500327477"}
0005432531611	9E2A23	8890 724749	GALINA LOGINOVA	{"phone": "+70516193601"}
0005432531612	058F75	2583 367177	GENNADIY NIKOLAEV	{"phone": "+70336507387"}
0005432531613	058F75	3635 326313	VLADIMIR SOROKIN	{"email": "v_sorokin.1962@postgrespro.ru", "phone": "+70344211345"}
0005432531614	AAD789	9693 676782	ALLA PAVLOVA	{"phone": "+70089063334"}
0005432531615	8E161A	7471 607269	ALEKSANDR DAVYDOV	{"email": "a-davydov-1976@postgrespro.ru", "phone": "+70058789094"}
0005432531616	173CCA	7641 048048	IRINA FEDOROVA	{"phone": "+70838560515"}
0005432531617	E0A0A8	8187 753223	ANDREY PAVLOV	{"email": "a-pavlov1967@postgrespro.ru", "phone": "+70973168109"}
0005432531618	C65E1D	8150 873723	ELENA SEMENOVA	{"email": "semenovaelena16011968@postgrespro.ru", "phone": "+70643892720"}
0005432531619	44F89E	7400 509038	ALEKSEY YAKOVLEV	{"email": "aleksey_yakovlev_1971@postgrespro.ru", "phone": "+70696806128"}
0005432531620	44F89E	3344 462935	SHAMIL KUZNECOV	{"email": "shamil.kuznecov1976@postgrespro.ru", "phone": "+70646689848"}
0005432531621	3D423E	5023 115051	SERGEY ZAKHAROV	{"phone": "+70375713687"}
0005432531622	3D423E	8669 370463	NADEZHDA ZAKHAROVA	{"email": "nadezhda.zakharova-121976@postgrespro.ru", "phone": "+70422803947"}
0005432531623	AA21DB	2047 296269	ANASTASIYA AFANASEVA	{"email": "afanaseva_a.24081976@postgrespro.ru", "phone": "+70473719434"}
0005432531624	60ED0F	3606 621576	ANATOLIY ALEKSANDROV	{"phone": "+70758200138"}
0005432531625	60ED0F	5612 330872	NIKOLAY VOROBEV	{"email": "vorobev.nikolay_10031970@postgrespro.ru", "phone": "+70979807119"}
0005432531626	6E7C2B	3652 549690	VALERIY VOLKOV	{"phone": "+70633997894"}
0005432531627	6E7C2B	0834 700486	SERGEY KUZNECOV	{"email": "kuznecov.s.26121978@postgrespro.ru", "phone": "+70800951011"}
0005432531628	802DE2	7207 815067	ALEKSANDR VASILEV	{"email": "a.vasilev.1980@postgrespro.ru", "phone": "+70914494517"}
0005432531629	0049CB	8225 686185	LIDIYA NAUMOVA	{"email": "naumoval.1972@postgrespro.ru", "phone": "+70936330804"}
0005432531630	0049CB	8234 284468	OLGA KONOVALOVA	{"phone": "+70052981919"}
0005432531631	D750B5	6713 541111	IVAN KAZAKOV	{"phone": "+70395744254"}
0005432531632	71AC9B	8374 806603	NATALYA LAZAREVA	{"phone": "+70030977059"}
0005432531633	8D26E7	3667 492049	NATALYA FADEEVA	{"email": "n-fadeeva031966@postgrespro.ru", "phone": "+70385923607"}
0005432531634	DB8574	9271 541297	ANDREY SERGEEV	{"email": "a-sergeev.22031974@postgrespro.ru", "phone": "+70358770527"}
0005432531635	C96D19	7154 859571	OLESYA FILATOVA	{"email": "filatova_olesya.1972@postgrespro.ru", "phone": "+70494986149"}
0005432531636	E34F9D	8519 720716	VALENTINA MATVEEVA	{"email": "v_matveeva.01111980@postgrespro.ru", "phone": "+70026764914"}
0005432531637	091448	5717 141224	VITALIY VOLKOV	{"phone": "+70159489713"}
0005432531638	238C3C	5041 883055	VARVARA DAVYDOVA	{"email": "v-davydova-021967@postgrespro.ru", "phone": "+70203687335"}
0005432531639	238C3C	0801 729938	NIKOLAY KUZNECOV	{"phone": "+70783881691"}
0005432531640	A9442D	0034 730030	ELENA SEMENOVA	{"email": "semenova.elena_1980@postgrespro.ru", "phone": "+70363739874"}
0005432531641	D1398D	0791 350491	MARINA POLYAKOVA	{"email": "polyakova-marina.17081983@postgrespro.ru", "phone": "+70120625269"}
0005432531642	3C6985	6876 740800	TATYANA ZAYCEVA	{"email": "zayceva-t-051971@postgrespro.ru", "phone": "+70179009953"}
0005432531643	3C6985	1769 564342	ANATOLIY ZAKHAROV	{"phone": "+70694838942"}
0005432531644	2D374B	0410 688751	MARIYA ABRAMOVA	{"email": "abramova_mariya.081980@postgrespro.ru", "phone": "+70408118538"}
0005432531645	2D374B	1885 273940	SVETLANA MIRONOVA	{"email": "mironova_svetlana_03071971@postgrespro.ru", "phone": "+70640027018"}
0005432531646	2D374B	3279 907192	NIKOLAY SIDOROV	{"email": "sidorovn.051973@postgrespro.ru", "phone": "+70860420659"}
0005432531647	E9EFB4	6356 368765	EVGENIY FROLOV	{"phone": "+70181891827"}
0005432531648	CB7EB0	5000 490560	TATYANA CHERNOVA	{"phone": "+70954569423"}
0005432531649	D9E629	1873 643295	OLGA KRASNOVA	{"phone": "+70794634150"}
0005432531650	D9E629	8814 856469	VALENTINA TARASOVA	{"phone": "+70393718196"}
0005432531651	D3ECD6	7346 903716	OLGA RODIONOVA	{"phone": "+70803406808"}
0005432531652	2DC08D	3768 322412	MAKSIM POPOV	{"phone": "+70131521327"}
0005432531653	A3ABE3	4905 948520	GALINA FEDOROVA	{"phone": "+70535218984"}
0005432531654	F146E3	0079 325151	EMIL RODIONOV	{"phone": "+70967544570"}
0005432531655	F146E3	0708 916913	YULIYA PETROVA	{"phone": "+70276186147"}
0005432531656	3DF0F8	8534 538805	EVGENIY AFANASEV	{"phone": "+70518508821"}
0005432531657	3DF0F8	3167 797517	SERGEY MOROZOV	{"phone": "+70721183419"}
0005432531658	AC7D87	8057 553384	LIDIYA KUZNECOVA	{"phone": "+70698315381"}
0005432531659	AC7D87	6952 142777	ALEKSEY ZAYCEV	{"email": "zaycev.a-091977@postgrespro.ru", "phone": "+70807383708"}
0005432531660	96F292	0055 765705	VLADIMIR KRASNOV	{"phone": "+70937279382"}
0005432531661	D561BD	6023 757138	ELENA SEMENOVA	{"phone": "+70014563524"}
0005432531662	D561BD	2472 601349	MARIYA TARASOVA	{"email": "tarasova_m.12111969@postgrespro.ru", "phone": "+70022591493"}
0005432531663	C4D78A	7569 301798	RAISA NOVIKOVA	{"phone": "+70007571471"}
0005432531664	C4D78A	5520 480125	NATALIYA EFIMOVA	{"email": "efimova.nataliya13081971@postgrespro.ru", "phone": "+70299040330"}
0005432531665	F1CE42	3866 300530	SVETLANA BELOVA	{"email": "belova-s051968@postgrespro.ru", "phone": "+70828795566"}
0005432531666	7077B2	4532 869309	RAVILYA IVANOVA	{"email": "ravilya-ivanova_10071972@postgrespro.ru", "phone": "+70385597587"}
0005432531667	7077B2	2797 057692	ANGELINA IVANOVA	{"email": "angelina-ivanova_1966@postgrespro.ru", "phone": "+70974630846"}
0005432531668	7077B2	6943 519001	PRASKOVYA KUDRYASHOVA	{"phone": "+70064204978"}
0005432531669	06BC2F	7026 417309	DENIS NOVIKOV	{"phone": "+70317973617"}
0005432531670	95D1D0	3475 042705	TATYANA FILIPPOVA	{"email": "filippova_t.27111976@postgrespro.ru", "phone": "+70805490438"}
0005432531671	5FFEAE	9240 249194	SVETLANA MAKSIMOVA	{"phone": "+70340196268"}
0005432531672	E85CC4	3806 280042	KSENIYA IVANOVA	{"phone": "+70948590277"}
0005432531673	5B5DA4	7292 988396	KSENIYA KOVALEVA	{"email": "kovaleva_kseniya.13061979@postgrespro.ru", "phone": "+70119495055"}
0005432531674	5B5DA4	5817 058581	BORIS MARTYNOV	{"phone": "+70985758749"}
0005432531675	5B5DA4	3693 802423	ALEKSANDR GUSEV	{"email": "gusevaleksandr_25051975@postgrespro.ru", "phone": "+70437814334"}
0005432531676	07A591	7806 316885	MIKHAIL NAUMOV	{"phone": "+70596334410"}
0005432531677	FAC6B7	3664 675761	YULIYA KOROLEVA	{"phone": "+70069430499"}
0005432531678	CAB8ED	8289 548953	RAIS POPOV	{"phone": "+70635172135"}
0005432531679	C1FADF	3611 134704	GALINA FROLOVA	{"email": "galina-frolova.01081972@postgrespro.ru", "phone": "+70352373115"}
0005432531680	C1FADF	2545 811046	MARIYA NAUMOVA	{"phone": "+70142395468"}
0005432531681	D2484D	2664 860273	ALEKSANDR IVANOV	{"phone": "+70527297414"}
0005432531682	D6AE86	8578 588721	NATALIYA ILINA	{"email": "ilinanataliya.02021964@postgrespro.ru", "phone": "+70270190959"}
0005432531683	6D01AD	8885 233137	OLEG PETROV	{"email": "petrov-o_101981@postgrespro.ru", "phone": "+70231063626"}
0005432531684	147A84	7681 158402	DANIL NIKOLAEV	{"email": "nikolaevd_24031971@postgrespro.ru", "phone": "+70303304484"}
0005432531685	146A3F	0047 987660	MARIYA VOLKOVA	{"phone": "+70364722457"}
0005432531686	146A3F	2267 415446	TATYANA NESTEROVA	{"phone": "+70668473812"}
0005432531687	2E57A8	0433 753655	NINA LAZAREVA	{"phone": "+70792360899"}
0005432531688	2E57A8	5686 589659	TAMARA ZAYCEVA	{"phone": "+70492866805"}
0005432531689	5C5642	0036 931236	GALINA ILINA	{"phone": "+70747844641"}
0005432531690	5C5642	1360 080464	ALEKSEY ISAEV	{"phone": "+70636931832"}
0005432531691	CFAE14	1961 563257	TATYANA SOKOLOVA	{"phone": "+70775059616"}
0005432531692	99CEC4	7734 219182	ILYA IVANOV	{"phone": "+70219417416"}
0005432531693	676760	6627 572964	MARGARITA MATVEEVA	{"phone": "+70463120566"}
0005432531694	A063CB	2374 485565	DANIIL DAVYDOV	{"phone": "+70136553691"}
0005432531695	87A9F0	1123 558387	VALERIY GAVRILOV	{"email": "gavrilov.valeriy_011969@postgrespro.ru", "phone": "+70852463251"}
0005432531696	87A9F0	4633 761676	YULIYA MEDVEDEVA	{"phone": "+70199857908"}
0005432531697	6C9A5E	8813 103015	ELIZAVETA TARASOVA	{"phone": "+70858116050"}
0005432531698	6C9A5E	3208 285008	YULIYA OVCHINNIKOVA	{"email": "ovchinnikovayuliya19111971@postgrespro.ru", "phone": "+70207906848"}
0005432531699	4046E0	6944 907856	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov-30101972@postgrespro.ru", "phone": "+70527242264"}
0005432531700	3C32FF	3762 477521	MARIYA ZAYCEVA	{"email": "m_zayceva_18021972@postgrespro.ru", "phone": "+70158102812"}
0005432531701	47F5A1	7135 272089	GENNADIY PAVLOV	{"email": "gennadiy-pavlov-1964@postgrespro.ru", "phone": "+70379166746"}
0005432531702	CC0757	0575 870721	SAID ROMANOV	{"email": "romanov-said_1960@postgrespro.ru", "phone": "+70773762806"}
0005432531703	09C504	1350 088276	VALERIY AFANASEV	{"email": "valeriyafanasev-25121971@postgrespro.ru", "phone": "+70377591215"}
0005432531704	09C504	9797 514304	ALEKSANDR ZHUKOV	{"email": "a-zhukov01121975@postgrespro.ru", "phone": "+70249677527"}
0005432531705	6A6F55	9476 474149	KONSTANTIN MAKAROV	{"email": "makarovkonstantin29021992@postgrespro.ru", "phone": "+70442762196"}
0005432531706	EC649D	6273 275721	VALENTINA SERGEEVA	{"email": "valentinasergeeva-1971@postgrespro.ru", "phone": "+70299790533"}
0005432531707	EC649D	4287 108160	ALFIYA TIMOFEEVA	{"email": "alfiyatimofeeva1986@postgrespro.ru", "phone": "+70164912514"}
0005432531708	5529EF	0622 009501	MIKHAIL KOZLOV	{"email": "mikhail.kozlov-041968@postgrespro.ru", "phone": "+70510760168"}
0005432531709	5D7CFD	8782 969577	TATYANA POPOVA	{"phone": "+70349424860"}
0005432531710	445FA3	2469 973367	DMITRIY EGOROV	{"phone": "+70181681760"}
0005432531711	57776F	7778 204368	ANDREY IVANOV	{"email": "andrey_ivanov_10031969@postgrespro.ru", "phone": "+70768875585"}
0005432531712	F6A110	4270 698882	VIKTOR ANTONOV	{"email": "antonov_v-13031971@postgrespro.ru", "phone": "+70003383561"}
0005432531713	3020D8	5292 177175	OKSANA STEPANOVA	{"email": "oksana-stepanova-14021964@postgrespro.ru", "phone": "+70484693226"}
0005432531714	CD1032	1470 041408	IRINA POPOVA	{"email": "popovairina.061980@postgrespro.ru", "phone": "+70156414024"}
0005432531715	800A29	4841 888716	ANATOLIY MARTYNOV	{"email": "martynov_anatoliy-07081968@postgrespro.ru", "phone": "+70358862945"}
0005432531716	EABB20	1366 157255	OLGA MIRONOVA	{"email": "mironova-o.041972@postgrespro.ru", "phone": "+70019745765"}
0005432531717	2D445E	1307 165543	ALEKSANDR BELOV	{"email": "belovaleksandr.1977@postgrespro.ru", "phone": "+70649824185"}
0005432531718	68BE0D	9912 792033	ILDAR ALEKSANDROV	{"email": "ildaraleksandrov.27071974@postgrespro.ru", "phone": "+70010620061"}
0005432531719	0AA00F	0752 515249	SERGEY ORLOV	{"phone": "+70384985420"}
0005432531720	5A4A99	5184 129554	ANTONINA ZAYCEVA	{"phone": "+70272895522"}
0005432531721	5A4A99	9203 066403	MARIYA KUZNECOVA	{"phone": "+70370931800"}
0005432531722	24FACD	5056 576340	NATALYA EFREMOVA	{"email": "efremovan-29031975@postgrespro.ru", "phone": "+70501737442"}
0005432531723	F0765E	1391 782746	ELENA IVANOVA	{"email": "ivanovaelena-1968@postgrespro.ru", "phone": "+70385165798"}
0005432531724	F0765E	9151 514697	ANATOLIY FILIPPOV	{"phone": "+70828948493"}
0005432531725	2A1862	6660 516677	GENNADIY NIKOLAEV	{"email": "gennadiy_nikolaev_031975@postgrespro.ru", "phone": "+70522667343"}
0005432531726	EF1303	7467 243015	SERGEY POPOV	{"phone": "+70592009224"}
0005432531727	EF1303	9228 207327	ELVINA ZAYCEVA	{"email": "zayceva.elvina_09011980@postgrespro.ru", "phone": "+70544578843"}
0005432531728	91231E	2792 362559	DAVID EGOROV	{"email": "d.egorov.021970@postgrespro.ru", "phone": "+70636218092"}
0005432531729	91231E	4794 771586	SVETLANA KONDRATEVA	{"phone": "+70842662113"}
0005432531730	C72A51	2855 352038	ALLA ANDREEVA	{"email": "andreeva-alla051973@postgrespro.ru", "phone": "+70446898749"}
0005432531731	C72A51	5088 764376	NADEZHDA MIRONOVA	{"email": "nadezhda-mironova.111956@postgrespro.ru", "phone": "+70496536982"}
0005432531732	488A0D	9503 878633	IGOR KONOVALOV	{"email": "konovalov-igor-1966@postgrespro.ru", "phone": "+70597631828"}
0005432531733	B20096	8648 878159	VLADIMIR KISELEV	{"email": "kiselevvladimir_071963@postgrespro.ru", "phone": "+70362516416"}
0005432531734	E9A939	3082 173645	OLGA KRASNOVA	{"phone": "+70057932706"}
0005432531735	E9A939	4779 470419	MARIYA FROLOVA	{"phone": "+70254818971"}
0005432531736	3F2392	4420 556201	VLADIMIR SERGEEV	{"phone": "+70133747478"}
0005432531737	07AF13	7749 963172	SVETLANA IVANOVA	{"email": "sivanova-12121966@postgrespro.ru", "phone": "+70657775855"}
0005432531738	84A748	9046 342302	ELIZAVETA GRISHINA	{"email": "grishinae1980@postgrespro.ru", "phone": "+70778984894"}
0005432531739	B2136D	7246 746699	ALEKSEY SOKOLOV	{"email": "sokolovaleksey-13051978@postgrespro.ru", "phone": "+70516562949"}
0005432531740	F9A2E2	9488 004423	NADEZHDA SOKOLOVA	{"email": "sokolova-n.1976@postgrespro.ru", "phone": "+70963276032"}
0005432531741	F9A2E2	2303 253906	SVETLANA CHERNOVA	{"email": "chernova.svetlana1984@postgrespro.ru", "phone": "+70522279938"}
0005432531742	D70FF8	4997 568580	EVGENIY SOKOLOV	{"email": "evgeniy.sokolov.1971@postgrespro.ru", "phone": "+70964733591"}
0005432531743	D70FF8	2496 931493	ANDREY IVANOV	{"phone": "+70958216219"}
0005432531744	16C852	4611 969178	STANISLAV KUZNECOV	{"email": "stanislav_kuznecov.1973@postgrespro.ru", "phone": "+70477267991"}
0005432531745	9F3013	8975 453017	RUSLAN KRASNOV	{"email": "krasnov_r.01091977@postgrespro.ru", "phone": "+70458416053"}
0005432531746	9F3013	3553 054075	ANTON FROLOV	{"email": "anton.frolov_1972@postgrespro.ru", "phone": "+70596391621"}
0005432531747	F583CB	3556 622659	GALINA YAKOVLEVA	{"phone": "+70720909908"}
0005432531748	F583CB	5313 540918	ELENA IVANOVA	{"phone": "+70881026165"}
0005432531749	F583CB	1765 592658	VIKTOR FOMIN	{"phone": "+70515588441"}
0005432531750	417518	9602 130215	VALENTINA VASILEVA	{"phone": "+70774499339"}
0005432531751	AD20F9	2707 941428	VALENTINA BOGDANOVA	{"phone": "+70416354943"}
0005432531752	3925BF	1753 674781	NADEZHDA ALEKSEEVA	{"email": "nadezhda_alekseeva_04031972@postgrespro.ru", "phone": "+70499611316"}
0005432531753	EAE36F	4843 642686	GALINA BARANOVA	{"phone": "+70221232663"}
0005432531754	EAE36F	0955 996460	ALEKSANDR IVANOV	{"email": "ivanov.a-22031975@postgrespro.ru", "phone": "+70684619165"}
0005432531755	772B92	2872 011746	VIKTORIYA DANILOVA	{"phone": "+70858706056"}
0005432531756	17C1E8	9354 996823	ALEKSANDR PETROV	{"email": "petrov_aleksandr1972@postgrespro.ru", "phone": "+70486243434"}
0005432531757	F01448	5464 494078	NATALYA NOVIKOVA	{"phone": "+70342084931"}
0005432531758	B3E66E	6019 393440	KARINA KOROLEVA	{"email": "karinakoroleva_1985@postgrespro.ru", "phone": "+70785385064"}
0005432531759	B3E66E	1121 413936	ALEKSEY DAVYDOV	{"email": "aleksey-davydov.051967@postgrespro.ru", "phone": "+70236089687"}
0005432531760	405590	6363 565720	IGOR ORLOV	{"phone": "+70960954535"}
0005432531761	405590	8201 807089	TAMARA OSIPOVA	{"phone": "+70249636381"}
0005432531762	405590	2184 262709	LIDIYA FILIPPOVA	{"phone": "+70650436903"}
0005432531763	405590	6968 107629	ARINA SOKOLOVA	{"phone": "+70470358164"}
0005432531764	331D40	4992 942303	EVGENIY ALEKSEEV	{"phone": "+70128019105"}
0005432531765	2AE2FD	4881 335057	IVAN NAZAROV	{"email": "nazarovivan.031968@postgrespro.ru", "phone": "+70110784718"}
0005432531766	2AE2FD	0215 166382	ALEKSANDR SEMENOV	{"phone": "+70511116517"}
0005432531767	2AE2FD	3682 733560	ZHANNA ZHURAVLEVA	{"email": "zhanna.zhuravleva.25121974@postgrespro.ru", "phone": "+70072112385"}
0005432531768	AE8D29	9636 780630	NIKOLAY KRASNOV	{"phone": "+70869068490"}
0005432531769	AE8D29	7501 079929	VLADIMIR BELOV	{"phone": "+70613096469"}
0005432531770	CF9C00	7414 916643	MAKSIM PETROV	{"email": "petrov_m041971@postgrespro.ru", "phone": "+70201619799"}
0005432531771	ACDD32	8605 328497	SERGEY SERGEEV	{"email": "sergey.sergeev.011964@postgrespro.ru", "phone": "+70385773150"}
0005432531772	965253	5644 809886	MARIYA KULIKOVA	{"email": "kulikova-mariya-081979@postgrespro.ru", "phone": "+70067907108"}
0005432531773	965253	5823 242216	SAMIRA SCHERBAKOVA	{"email": "scherbakovas-1962@postgrespro.ru", "phone": "+70918642468"}
0005432531774	F57F0B	5973 968181	SVETLANA KOZLOVA	{"email": "skozlova-27061963@postgrespro.ru", "phone": "+70262787739"}
0005432531775	31CF2E	2939 666759	ALEKSEY YAKOVLEV	{"phone": "+70086484714"}
0005432531776	E1D87B	4496 129614	VLADIMIR ANDREEV	{"phone": "+70650505829"}
0005432531777	E99182	0008 261935	OLGA KOROLEVA	{"email": "olgakoroleva.091983@postgrespro.ru", "phone": "+70341684611"}
0005432531778	8EC300	5246 462680	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov021959@postgrespro.ru", "phone": "+70737103122"}
0005432531779	B77BDA	9954 308436	ARTEM ANDREEV	{"email": "artemandreev1964@postgrespro.ru", "phone": "+70152493396"}
0005432531780	E499B8	7527 518146	NADEZHDA LOGINOVA	{"phone": "+70991548508"}
0005432531781	E499B8	8171 663161	DMITRIY DENISOV	{"email": "d.denisov.1982@postgrespro.ru", "phone": "+70675118256"}
0005432531782	0C024A	3659 124213	ANTONINA ALEKSANDROVA	{"phone": "+70911030886"}
0005432531783	944932	7292 828047	ANTON FROLOV	{"email": "anton_frolov1973@postgrespro.ru", "phone": "+70292836202"}
0005432531784	AE656C	6315 542626	OLESYA TIKHONOVA	{"phone": "+70281244043"}
0005432531785	5AA1EC	6479 067425	YURIY POPOV	{"email": "y_popov-1975@postgrespro.ru", "phone": "+70237616345"}
0005432531786	A6D2BD	6788 965527	MIKHAIL DMITRIEV	{"phone": "+70848576588"}
0005432531787	6CF68F	4544 425415	KLAVDIYA BOGDANOVA	{"email": "bogdanova_klavdiya-16031976@postgrespro.ru", "phone": "+70484469558"}
0005432531788	1C552D	9434 783212	NADEZHDA NOVIKOVA	{"email": "nadezhda_novikova-1965@postgrespro.ru", "phone": "+70057007819"}
0005432531789	778BC7	8184 222392	ALEKSEY DAVYDOV	{"email": "davydov_aleksey.1976@postgrespro.ru", "phone": "+70762054080"}
0005432531790	477BA0	9230 014613	MARINA DANILOVA	{"phone": "+70073868311"}
0005432531791	4467F1	3002 988776	YULIYA ZAYCEVA	{"email": "yuliya_zayceva_02121982@postgrespro.ru", "phone": "+70619805633"}
0005432531792	F2EC58	7946 986800	ROMAN BELOV	{"email": "romanbelov.30071975@postgrespro.ru", "phone": "+70766320974"}
0005432531793	F2EC58	5107 944423	NINA NAZAROVA	{"phone": "+70640667634"}
0005432531794	96CC9E	9799 478427	IVAN EGOROV	{"phone": "+70013940821"}
0005432531795	3E7DBF	8060 038697	LIDIYA FILIPPOVA	{"phone": "+70050331345"}
0005432531796	FB10FD	2520 142526	DMITRIY IVANOV	{"email": "dmitriy_ivanov-03101990@postgrespro.ru", "phone": "+70696785863"}
0005432531797	004403	1858 953608	EKATERINA VASILEVA	{"email": "vasileva_ekaterina10071976@postgrespro.ru", "phone": "+70496528407"}
0005432531798	004403	1837 438731	MARIYA TARASOVA	{"email": "m.tarasova1968@postgrespro.ru", "phone": "+70182912025"}
0005432531799	0B2FB4	1889 514609	ALINA BELOVA	{"email": "a.belova.021973@postgrespro.ru", "phone": "+70326352952"}
0005432531800	0B2FB4	3844 630401	DENIS ORLOV	{"phone": "+70444407967"}
0005432531801	CD3D33	0640 458024	ALEKSANDR TIMOFEEV	{"email": "timofeev-a-051969@postgrespro.ru", "phone": "+70998911959"}
0005432531802	A2932C	8246 035948	MARIYA ABRAMOVA	{"phone": "+70096605254"}
0005432531803	A2932C	1014 503834	OKSANA POLYAKOVA	{"phone": "+70460353379"}
0005432531804	DFEAA4	9344 643334	TAMARA NIKITINA	{"email": "tamaranikitina_22121986@postgrespro.ru", "phone": "+70955813887"}
0005432531805	920B5C	7002 138753	VITALIY MELNIKOV	{"phone": "+70013423855"}
0005432531806	920B5C	2528 050581	NATALYA ZHURAVLEVA	{"phone": "+70882640928"}
0005432531807	08563D	6244 452673	OLGA SERGEEVA	{"phone": "+70744048056"}
0005432531808	08563D	7711 875408	KIRILL YAKOVLEV	{"email": "yakovlev-k081960@postgrespro.ru", "phone": "+70171566791"}
0005432531809	D60ADF	8376 315537	KAMIL ZAKHAROV	{"phone": "+70199569556"}
0005432531810	D60ADF	7095 541767	OLESYA TARASOVA	{"email": "o_tarasova.28061974@postgrespro.ru", "phone": "+70835356822"}
0005432531811	A1A545	1676 231075	IRINA VOROBEVA	{"phone": "+70584302561"}
0005432531812	935172	7940 467449	OLGA MOROZOVA	{"phone": "+70233239373"}
0005432531813	935172	5580 477698	FARID VASILEV	{"email": "fvasilev_1986@postgrespro.ru", "phone": "+70641519429"}
0005432531814	935172	9416 327688	POLINA ZOTOVA	{"phone": "+70595560577"}
0005432531815	4ED4E9	4395 399539	SVETLANA GORBUNOVA	{"email": "s.gorbunova-09061960@postgrespro.ru", "phone": "+70556754836"}
0005432531816	4ED4E9	2558 570443	IRINA NAUMOVA	{"phone": "+70403658018"}
0005432531817	8A1F79	6109 120126	VERA MIRONOVA	{"email": "vera.mironova.1972@postgrespro.ru", "phone": "+70865694694"}
0005432531818	239439	1439 073567	KONSTANTIN MELNIKOV	{"phone": "+70926052745"}
0005432531819	49243E	9954 226888	RAIL KUZMIN	{"email": "kuzminr1975@postgrespro.ru", "phone": "+70730925001"}
0005432531820	CAD921	1249 139727	OLGA RYABOVA	{"email": "o-ryabova-1967@postgrespro.ru", "phone": "+70418659906"}
0005432531821	7021DF	1615 321803	NATALIYA KUZNECOVA	{"email": "nataliya.kuznecova1957@postgrespro.ru", "phone": "+70361563356"}
0005432531822	7021DF	1219 849977	SERGEY ZAYCEV	{"email": "sergey-zaycev-1971@postgrespro.ru", "phone": "+70788536317"}
0005432531823	B2AB28	0833 497599	GENNADIY SEMENOV	{"phone": "+70773822108"}
0005432531824	F93923	7970 124422	GALINA KULIKOVA	{"email": "galinakulikova1968@postgrespro.ru", "phone": "+70486045921"}
0005432531825	F93923	8176 827027	SERGEY YAKOVLEV	{"email": "s.yakovlev.22051959@postgrespro.ru", "phone": "+70201460439"}
0005432531826	F93923	3726 353183	YULIYA ANDREEVA	{"phone": "+70558664729"}
0005432531827	05AAE6	7541 846163	IRINA MAKAROVA	{"email": "irina.makarova.041973@postgrespro.ru", "phone": "+70424049587"}
0005432531828	20B360	5324 815120	KONSTANTIN SHEVCHENKO	{"phone": "+70043002615"}
0005432531829	01CE51	1324 997728	YULIYA EFREMOVA	{"email": "y_efremova1965@postgrespro.ru", "phone": "+70882887547"}
0005432531830	01CE51	5874 110386	VLADISLAV NAZAROV	{"email": "vladislavnazarov-1972@postgrespro.ru", "phone": "+70960782302"}
0005432531831	29DFBD	2962 253588	ALEKSEY ABRAMOV	{"email": "abramov_aleksey_111971@postgrespro.ru", "phone": "+70836660018"}
0005432531832	4517B1	3006 423244	ALEKSEY ANTONOV	{"email": "alekseyantonov_18031971@postgrespro.ru", "phone": "+70788249870"}
0005432531833	4517B1	6735 441652	PAVEL MIKHAYLOV	{"email": "mikhaylov_pavel-081960@postgrespro.ru", "phone": "+70922993425"}
0005432531834	4517B1	0114 801999	ELENA SOROKINA	{"email": "sorokina_elena.1960@postgrespro.ru", "phone": "+70031992364"}
0005432531835	FB4804	5713 296781	VALENTINA ISAEVA	{"email": "v_isaeva29121971@postgrespro.ru", "phone": "+70626682694"}
0005432531836	8CC160	7500 258090	STANISLAV GUSEV	{"email": "stanislav.gusev-031973@postgrespro.ru", "phone": "+70563377044"}
0005432531837	C05961	8056 659608	EDUARD KUZNECOV	{"email": "eduard.kuznecov-20051965@postgrespro.ru", "phone": "+70931814201"}
0005432531838	3E449B	6377 485631	KSENIYA GERASIMOVA	{"email": "gerasimova-k.21011972@postgrespro.ru", "phone": "+70737410082"}
0005432531839	3E449B	2199 713147	ELVIRA MELNIKOVA	{"phone": "+70538661818"}
0005432531840	CF1967	0039 000394	TATYANA EGOROVA	{"email": "egorovat.081967@postgrespro.ru", "phone": "+70704073076"}
0005432531841	CF1967	3515 359412	ALEKSANDR VOLKOV	{"phone": "+70000627129"}
0005432531842	E95C46	3660 230385	RUSTEM BORISOV	{"phone": "+70828365817"}
0005432531843	E95C46	2387 057122	IOSIF KUDRYASHOV	{"email": "iosif.kudryashov051974@postgrespro.ru", "phone": "+70328604677"}
0005432531844	7592C9	5433 052549	OLGA KISELEVA	{"email": "kiseleva.o.1970@postgrespro.ru", "phone": "+70174551264"}
0005432531845	029996	8063 719711	VALENTINA KUZNECOVA	{"email": "kuznecova.v.16081965@postgrespro.ru", "phone": "+70480583782"}
0005432531846	029996	2659 472872	ARTUR PAVLOV	{"email": "artur-pavlov-1965@postgrespro.ru", "phone": "+70922439565"}
0005432533240	FE92C5	0998 489352	SERGEY MATVEEV	{"email": "matveev.s09041978@postgrespro.ru", "phone": "+70259713555"}
0005432533241	70DBD9	7637 679335	SVETLANA DAVYDOVA	{"phone": "+70531733725"}
0005432533242	70DBD9	0371 145211	NATALYA PAVLOVA	{"phone": "+70427409278"}
0005432533243	05C43C	5198 864530	IGOR PETROV	{"email": "i-petrov.051977@postgrespro.ru", "phone": "+70149786636"}
0005432533244	05C43C	2497 427906	SERGEY IVANOV	{"phone": "+70353064790"}
0005432533245	C9718F	6653 283122	ANATOLIY KAZAKOV	{"email": "a-kazakov_30121966@postgrespro.ru", "phone": "+70399477574"}
0005432533246	C9718F	0224 388545	TATYANA LAZAREVA	{"email": "tatyana_lazareva.1977@postgrespro.ru", "phone": "+70405065241"}
0005432533247	00E444	5889 912888	KIRILL STEPANOV	{"email": "k.stepanov041978@postgrespro.ru", "phone": "+70245308445"}
0005432533248	00E444	7174 474638	NAILYA LEBEDEVA	{"email": "n.lebedeva.081979@postgrespro.ru", "phone": "+70454495531"}
0005432533249	7AA0E3	6837 687522	VALERIYA TIMOFEEVA	{"phone": "+70093626185"}
0005432533250	1916C6	2488 205603	RUSLAN KUDRYASHOV	{"email": "kudryashov.ruslan-061965@postgrespro.ru", "phone": "+70950596863"}
0005432533251	71AF9A	6499 610990	SERGEY FROLOV	{"email": "frolov-sergey121967@postgrespro.ru", "phone": "+70150918100"}
0005432533252	9509E8	1585 021240	NIKOLAY RODIONOV	{"email": "n_rodionov_081976@postgrespro.ru", "phone": "+70776283341"}
0005432533253	603293	1703 701141	LYUDMILA EFIMOVA	{"phone": "+70057137096"}
0005432533254	1A65FE	9746 197249	TATYANA IVANOVA	{"email": "tatyanaivanova1971@postgrespro.ru", "phone": "+70437917797"}
0005432533255	E6C943	5223 547843	NADEZHDA MATVEEVA	{"email": "n-matveeva_1982@postgrespro.ru", "phone": "+70130474559"}
0005432533256	E7A5CF	8868 769235	NIKOLAY ORLOV	{"email": "nikolay.orlov-1962@postgrespro.ru", "phone": "+70791118115"}
0005432533257	E7A5CF	8559 404815	VLADIMIR PAVLOV	{"phone": "+70888718004"}
0005432533258	FF7775	9251 123071	NATALYA VOLKOVA	{"email": "volkovan_1975@postgrespro.ru", "phone": "+70314309940"}
0005432533259	961740	0566 693906	ZOYA NESTEROVA	{"phone": "+70829106153"}
0005432533260	EE13CF	4511 446055	NINA KOVALEVA	{"email": "ninakovaleva.1963@postgrespro.ru", "phone": "+70012439293"}
0005432533261	6ED177	3127 204337	LYUBOV BORISOVA	{"phone": "+70120765582"}
0005432533262	6ED177	8338 085985	LYUDMILA KUZMINA	{"phone": "+70850051473"}
0005432533263	965031	1045 074581	IVAN NOVIKOV	{"phone": "+70889916169"}
0005432533264	FDAF46	6071 683533	ILYA ZAYCEV	{"phone": "+70373217122"}
0005432533265	FDAF46	7192 106739	SERGEY VOLKOV	{"phone": "+70277310446"}
0005432533266	D49894	4818 569698	ALEKSANDR SOKOLOV	{"email": "asokolov061971@postgrespro.ru", "phone": "+70467930843"}
0005432533267	F57F36	8374 566707	VIKTOR IVANOV	{"phone": "+70850529989"}
0005432533268	F57F36	3853 995740	YULIYA OSIPOVA	{"email": "yuliya-osipova051975@postgrespro.ru", "phone": "+70503036407"}
0005432533269	7D7C68	8304 751466	NADEZHDA SERGEEVA	{"email": "sergeeva.nadezhda-1972@postgrespro.ru", "phone": "+70064205290"}
0005432533270	7D7C68	2336 656794	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev_091971@postgrespro.ru", "phone": "+70883196324"}
0005432533271	7D7C68	0459 576274	TAMARA ORLOVA	{"email": "torlova_071976@postgrespro.ru", "phone": "+70651133506"}
0005432533272	FAEDFC	5314 054255	IGOR KISELEV	{"email": "kiselev.i.08061974@postgrespro.ru", "phone": "+70822074112"}
0005432533273	34DF7D	1143 504902	NADEZHDA BELOVA	{"phone": "+70594854461"}
0005432533274	2815E4	0957 445511	VIKTOR KOZLOV	{"email": "viktor.kozlov_03031975@postgrespro.ru", "phone": "+70230975082"}
0005432533275	5AFD42	5579 268058	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay22041970@postgrespro.ru", "phone": "+70788027510"}
0005432533276	4B01FB	4874 285111	OLGA GUSEVA	{"email": "olgaguseva-071971@postgrespro.ru", "phone": "+70180530807"}
0005432533277	3CF879	5762 015580	MATVEY KOZLOV	{"phone": "+70458446053"}
0005432533278	3CF879	9536 281787	RAISA ANDREEVA	{"email": "andreeva-r051971@postgrespro.ru", "phone": "+70225870536"}
0005432533279	3CF879	8229 644452	ALEKSANDR MIRONOV	{"email": "a_mironov_1968@postgrespro.ru", "phone": "+70797472781"}
0005432533280	BE6A06	0563 805868	YANA DMITRIEVA	{"phone": "+70853263594"}
0005432533281	BE6A06	4543 382277	GALINA VASILEVA	{"phone": "+70644688753"}
0005432533282	C5A309	5836 655554	GALINA EGOROVA	{"phone": "+70514812501"}
0005432533283	C5A309	7678 229199	ANATOLIY DENISOV	{"phone": "+70172605140"}
0005432533284	C5A309	4398 437037	VALENTINA IVANOVA	{"phone": "+70984089757"}
0005432533285	EC1912	3806 383650	EDUARD POPOV	{"email": "popov.e.111967@postgrespro.ru", "phone": "+70795858075"}
0005432533286	2B6058	2778 550161	NATALYA POPOVA	{"email": "natalya_popova.20091974@postgrespro.ru", "phone": "+70431706188"}
0005432533287	9C6B6D	2923 470585	VADIM POPOV	{"email": "v.popov_031989@postgrespro.ru", "phone": "+70225067247"}
0005432533288	13519D	9734 462452	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-aleksandr.05091967@postgrespro.ru", "phone": "+70326560908"}
0005432533289	6BFC1A	9861 877334	ANDREY MEDVEDEV	{"email": "medvedev-a_031984@postgrespro.ru", "phone": "+70766261931"}
0005432533290	6BFC1A	2923 727071	DMITRIY FROLOV	{"email": "dmitriy-frolov-08011955@postgrespro.ru", "phone": "+70759436091"}
0005432533291	115A74	6864 223663	LARISA MASLOVA	{"email": "maslova_l_1978@postgrespro.ru", "phone": "+70239982613"}
0005432533292	04BE68	1748 280506	ALEKSANDRA ZHURAVLEVA	{"email": "a.zhuravleva31011982@postgrespro.ru", "phone": "+70980174444"}
0005432533293	3DEA77	2432 426879	TAGIR GAVRILOV	{"email": "gavrilovtagir1971@postgrespro.ru", "phone": "+70742481822"}
0005432533294	3DEA77	1481 824089	OKSANA KOVALEVA	{"phone": "+70642277491"}
0005432533295	3DEA77	9787 178542	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila.09101971@postgrespro.ru", "phone": "+70494890294"}
0005432533296	3DEA77	8061 389046	NADEZHDA KUZNECOVA	{"phone": "+70973122491"}
0005432533297	6F6D72	2673 596176	DANILA MAKAROV	{"phone": "+70289776992"}
0005432533298	D6A517	1921 278574	VIKTORIYA ISAEVA	{"email": "isaevav-121977@postgrespro.ru", "phone": "+70534331374"}
0005432533299	D86775	1042 566497	LARISA MALYSHEVA	{"phone": "+70781682842"}
0005432533300	D86775	6739 818372	NATALYA DMITRIEVA	{"phone": "+70548040011"}
0005432533301	E5E33C	2542 034328	RIFAT NOVIKOV	{"email": "novikov.rifat_1968@postgrespro.ru", "phone": "+70114934381"}
0005432533302	E5E33C	5757 766514	NINA SEMENOVA	{"phone": "+70309276331"}
0005432533303	4153B0	5549 850069	SVETLANA DENISOVA	{"phone": "+70303277477"}
0005432533304	F14743	0325 799196	TATYANA NIKIFOROVA	{"phone": "+70741172920"}
0005432533305	07CBD2	8266 386090	RAISA PETROVA	{"email": "petrova-r-21091964@postgrespro.ru", "phone": "+70815038422"}
0005432533306	07CBD2	8287 882119	SERGEY NIKOLAEV	{"email": "sergey.nikolaev_1971@postgrespro.ru", "phone": "+70847210322"}
0005432533307	4A77CB	5858 024797	MARIYA BARANOVA	{"email": "baranovam.1980@postgrespro.ru", "phone": "+70754107352"}
0005432533308	355964	6084 497876	ALEKSANDR PETROV	{"email": "aleksandrpetrov_031973@postgrespro.ru", "phone": "+70667822126"}
0005432533309	355964	0156 000708	ELENA SOKOLOVA	{"phone": "+70416327507"}
0005432533310	4E2CB2	8244 194693	DINARA NESTEROVA	{"email": "dinara-nesterova_23071966@postgrespro.ru", "phone": "+70382198198"}
0005432533311	4E2CB2	7493 846575	ROMAN ANDREEV	{"phone": "+70638086503"}
0005432533312	93BD4F	6145 370448	YULIYA ALEKSANDROVA	{"email": "yaleksandrova-101969@postgrespro.ru", "phone": "+70970957832"}
0005432533313	853979	0483 983497	MIKHAIL BORISOV	{"email": "borisov-m_1967@postgrespro.ru", "phone": "+70170371027"}
0005432533314	FB0CB3	3462 599682	VENIAMIN GAVRILOV	{"phone": "+70980106225"}
0005432533315	FB0CB3	3571 907410	NATALYA KONDRATEVA	{"email": "kondratevan-1969@postgrespro.ru", "phone": "+70093085861"}
0005432533316	894DF9	8515 303124	SERGEY NAZAROV	{"phone": "+70163099619"}
0005432533317	B33706	3042 455818	ELIZAVETA SOLOVEVA	{"email": "elizaveta-soloveva.20021972@postgrespro.ru", "phone": "+70389541795"}
0005432533318	E70DDF	3104 741382	TAISIYA FILIPPOVA	{"phone": "+70433972086"}
0005432533319	01F318	8244 075094	IVAN DENISOV	{"email": "i-denisov19091971@postgrespro.ru", "phone": "+70126576917"}
0005432533320	62FF59	9277 091667	SERGEY SOKOLOV	{"email": "s_sokolov.03051979@postgrespro.ru", "phone": "+70693221676"}
0005432533321	165A17	3471 781632	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a_031981@postgrespro.ru", "phone": "+70758505837"}
0005432533322	DCA486	3196 146625	ANTONINA KARPOVA	{"email": "karpova.a.1974@postgrespro.ru", "phone": "+70511464979"}
0005432533323	DCA486	0437 488780	ALEKSANDR GUSEV	{"phone": "+70708879688"}
0005432533324	57C920	9501 140672	OLGA FROLOVA	{"email": "frolova-o_10071972@postgrespro.ru", "phone": "+70910355614"}
0005432533325	9379AC	3255 960200	SERGEY DMITRIEV	{"email": "s.dmitriev.27051978@postgrespro.ru", "phone": "+70049361160"}
0005432533326	9379AC	0404 833153	MARIYA EFREMOVA	{"email": "efremovamariya-1983@postgrespro.ru", "phone": "+70885023638"}
0005432533327	1844DE	7351 096480	YULIYA SEMENOVA	{"email": "semenova-yuliya.1960@postgrespro.ru", "phone": "+70774111028"}
0005432533328	1844DE	6642 551605	OLEG KOROLEV	{"phone": "+70512153741"}
0005432533329	4E65FF	3735 195632	IVAN YAKOVLEV	{"email": "yakovlev.i.01031968@postgrespro.ru", "phone": "+70829036203"}
0005432533330	4E65FF	4463 613059	DANILA MAKAROV	{"phone": "+70102680990"}
0005432533331	498988	8174 842750	VASILIY SMIRNOV	{"email": "smirnovvasiliy24101973@postgrespro.ru", "phone": "+70865799110"}
0005432533332	BF9801	9941 085400	ALEKSANDR POPOV	{"email": "popov.a-081977@postgrespro.ru", "phone": "+70216504187"}
0005432533333	886F43	3857 983134	ELIZAVETA DENISOVA	{"email": "edenisova_031977@postgrespro.ru", "phone": "+70999877651"}
0005432533334	EEC104	4000 922135	DMITRIY TIMOFEEV	{"email": "dmitriy.timofeev_05091969@postgrespro.ru", "phone": "+70051712310"}
0005432533335	EEC104	1379 486555	ALEKSEY GORBUNOV	{"phone": "+70575770239"}
0005432533336	9C194E	1143 117682	EGOR VASILEV	{"phone": "+70326782965"}
0005432533337	090812	6999 524293	LYUDMILA ANISIMOVA	{"phone": "+70804385637"}
0005432533338	7A4C73	5176 979731	VALERIY KUZNECOV	{"email": "kuznecovv_071970@postgrespro.ru", "phone": "+70849518631"}
0005432533339	5CEA23	2721 370508	DMITRIY ORLOV	{"phone": "+70887587019"}
0005432533340	1C1207	9359 800737	EDUARD KUZMIN	{"email": "kuzmin_eduard_1969@postgrespro.ru", "phone": "+70249149979"}
0005432533341	DE13F1	1675 832819	MARINA MARTYNOVA	{"email": "martynova.m_1969@postgrespro.ru", "phone": "+70268373354"}
0005432533342	DE13F1	8923 886738	DARYA IVANOVA	{"email": "darya.ivanova_09011968@postgrespro.ru", "phone": "+70954994457"}
0005432533343	85E1B2	2735 048785	ALEKSANDR DENISOV	{"email": "a-denisov17091966@postgrespro.ru", "phone": "+70882176069"}
0005432533344	C576F8	9428 504194	ALEKSEY SCHERBAKOV	{"email": "scherbakov.a-1977@postgrespro.ru", "phone": "+70206219030"}
0005432533345	C576F8	4846 228590	VLADIMIR DENISOV	{"email": "vdenisov.01021976@postgrespro.ru", "phone": "+70170323526"}
0005432533346	18DD17	7459 947192	SERGEY ZHURAVLEV	{"email": "s_zhuravlev.1985@postgrespro.ru", "phone": "+70000527315"}
0005432533347	2F00EA	8853 992029	TATYANA PAVLOVA	{"email": "tatyana-pavlova.051963@postgrespro.ru", "phone": "+70501545652"}
0005432533348	2F00EA	3832 694677	ANTON ILIN	{"email": "antonilin.1966@postgrespro.ru", "phone": "+70941722436"}
0005432533349	3A6269	8608 473982	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr-06111970@postgrespro.ru", "phone": "+70098472109"}
0005432533350	3A6269	5472 529583	GALINA PAVLOVA	{"email": "pavlovag121969@postgrespro.ru", "phone": "+70410235876"}
0005432533351	9619BE	3686 213734	SERGEY PETROV	{"phone": "+70726830280"}
0005432533352	087341	9920 167507	VERA KOROLEVA	{"email": "vkoroleva-101983@postgrespro.ru", "phone": "+70315271391"}
0005432533353	9FA1CD	1369 453328	VITALIY KULIKOV	{"email": "kulikov.vitaliy.1974@postgrespro.ru", "phone": "+70551005207"}
0005432533354	6CEF30	0453 794857	NADEZHDA VASILEVA	{"phone": "+70854231241"}
0005432533355	6CEF30	3922 060093	ALEKSANDRA KALININA	{"email": "kalinina.a_12121977@postgrespro.ru", "phone": "+70305756586"}
0005432533356	9415A8	3786 265689	VLADIMIR PAVLOV	{"phone": "+70938412719"}
0005432533357	744C80	1798 552417	VYACHESLAV POPOV	{"email": "vpopov_28061967@postgrespro.ru", "phone": "+70130619162"}
0005432533358	FF6384	8177 502685	DMITRIY MEDVEDEV	{"phone": "+70603281162"}
0005432533359	FF6384	8268 899087	RASIM MOROZOV	{"phone": "+70202687145"}
0005432533360	26C4F4	4434 862527	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a.1980@postgrespro.ru", "phone": "+70951356456"}
0005432533361	E38464	4471 518717	ALESYA EFREMOVA	{"email": "efremova_a_07091974@postgrespro.ru", "phone": "+70586538894"}
0005432533362	69757E	7832 683993	KIRILL STEPANOV	{"phone": "+70240974387"}
0005432533363	69757E	4497 192090	ANDREY KUZNECOV	{"email": "a-kuznecov.041981@postgrespro.ru", "phone": "+70697730700"}
0005432533364	DB085C	7573 296779	ALFIYA KALININA	{"email": "kalinina.alfiya_13101982@postgrespro.ru", "phone": "+70645535974"}
0005432533365	6520C6	0535 659599	TAMARA MEDVEDEVA	{"phone": "+70209690439"}
0005432533366	5BEF3C	0816 259389	VYACHESLAV FEDOTOV	{"email": "v.fedotov_1971@postgrespro.ru", "phone": "+70234076435"}
0005432533367	AB0EC3	1764 223347	YURIY MELNIKOV	{"email": "y.melnikov_081977@postgrespro.ru", "phone": "+70952384833"}
0005432533368	787E66	0591 317704	MARIYA SERGEEVA	{"phone": "+70238224079"}
0005432533369	D50D1E	5859 916846	EVGENIY KRASNOV	{"email": "krasnov.evgeniy-04041972@postgrespro.ru", "phone": "+70182254437"}
0005432533370	F45512	5533 834269	ALEKSANDR SAVELEV	{"phone": "+70625911964"}
0005432533371	83A399	8219 062184	VASILIY TARASOV	{"phone": "+70077792221"}
0005432533372	03B3D0	0340 197997	ALEKSEY KOROLEV	{"email": "a-korolev.041979@postgrespro.ru", "phone": "+70247678038"}
0005432533373	78AFA6	9008 576622	YULIYA FEDOROVA	{"phone": "+70183758009"}
0005432533374	63256B	2435 920947	ALEKSANDR ZAYCEV	{"email": "a.zaycev-1978@postgrespro.ru", "phone": "+70765130819"}
0005432533375	63256B	5378 914359	NATALYA FEDOROVA	{"phone": "+70331907461"}
0005432533376	171671	0846 843985	RAISA ZAKHAROVA	{"email": "zakharovaraisa.051971@postgrespro.ru", "phone": "+70927148231"}
0005432533377	BBABED	3630 811851	PAVEL MIRONOV	{"email": "mironovpavel-1966@postgrespro.ru", "phone": "+70667164264"}
0005432533378	BBABED	2971 144611	GENNADIY NAZAROV	{"email": "nazarov_g-051970@postgrespro.ru", "phone": "+70673026119"}
0005432533379	A41D96	0872 147839	NIKOLAY GUSEV	{"phone": "+70610221565"}
0005432535880	ED3629	0285 539698	STANISLAV IVANOV	{"phone": "+70810264905"}
0005432535745	605B96	2306 031910	ALEKSANDR ZAKHAROV	{"email": "a-zakharov_1971@postgrespro.ru", "phone": "+70409730773"}
0005432535746	D18DDD	2459 163554	SOFIYA ANISIMOVA	{"email": "anisimovasofiya.06041971@postgrespro.ru", "phone": "+70077040808"}
0005432535747	D435AA	8855 361547	GALINA PETROVA	{"phone": "+70130518610"}
0005432535748	D435AA	2760 076978	MIKHAIL IVANOV	{"phone": "+70941002136"}
0005432535749	2C8064	0749 729019	DMITRIY KULIKOV	{"email": "dmitriy-kulikov-011973@postgrespro.ru", "phone": "+70871847237"}
0005432535750	1B7ED4	0716 141788	VERA SERGEEVA	{"phone": "+70516328704"}
0005432535751	115CB0	0700 518192	IGOR GERASIMOV	{"phone": "+70336371244"}
0005432535752	115CB0	9794 019655	EVGENIY ROMANOV	{"email": "romanov_e04121965@postgrespro.ru", "phone": "+70729080104"}
0005432535753	83B5FC	4783 849725	FEDOR SHEVCHENKO	{"phone": "+70132459261"}
0005432535754	F9C8AC	7825 486271	VALENTINA BORISOVA	{"phone": "+70915466962"}
0005432535755	F9C8AC	9067 170432	OLEG VOROBEV	{"phone": "+70326065037"}
0005432535756	95773F	4852 107475	NINA SOLOVEVA	{"email": "nina_soloveva-031971@postgrespro.ru", "phone": "+70625897568"}
0005432535757	95773F	8721 144406	MARGARITA SERGEEVA	{"email": "sergeeva_margarita091972@postgrespro.ru", "phone": "+70154632369"}
0005432535758	B1772F	7056 522128	ANATOLIY BONDARENKO	{"email": "bondarenko.anatoliy08091972@postgrespro.ru", "phone": "+70030286825"}
0005432535759	22C6E2	8353 461010	IRINA ROMANOVA	{"email": "romanovai-031978@postgrespro.ru", "phone": "+70665256528"}
0005432535760	6B43B2	2962 346849	NADEZHDA VOLKOVA	{"phone": "+70211340564"}
0005432535761	6B43B2	2549 337169	SVETLANA FROLOVA	{"email": "s-frolova_25091970@postgrespro.ru", "phone": "+70136951916"}
0005432535762	91FB94	7608 291183	NATALIYA KONDRATEVA	{"email": "kondratevan-1978@postgrespro.ru", "phone": "+70104690482"}
0005432535763	91FB94	0937 093518	LYUBOV KULIKOVA	{"phone": "+70834963392"}
0005432535764	59BCB3	9044 618908	IGOR ZAKHAROV	{"email": "igor.zakharov_1983@postgrespro.ru", "phone": "+70298248388"}
0005432535765	59BCB3	0476 154530	YULIYA ROMANOVA	{"phone": "+70754866138"}
0005432535766	414684	0076 278911	YULIYA ROMANOVA	{"phone": "+70452098924"}
0005432535767	414684	8001 868355	NATALYA POTAPOVA	{"phone": "+70842640623"}
0005432535768	4C63C2	2459 729063	FEDOR SEMENOV	{"phone": "+70688348087"}
0005432535769	4C63C2	8605 936033	TATYANA SERGEEVA	{"email": "tatyana_sergeeva.09111980@postgrespro.ru", "phone": "+70924480168"}
0005432535770	F7D11F	5905 449452	SERGEY GERASIMOV	{"phone": "+70458456377"}
0005432535771	F7D11F	1329 986288	ANDREY MAKAROV	{"email": "amakarov-041968@postgrespro.ru", "phone": "+70741670776"}
0005432535772	A9671F	8231 047719	ARTEM SOKOLOV	{"email": "sokolova.08111971@postgrespro.ru", "phone": "+70202638330"}
0005432535773	511E76	3499 884650	ALEKSANDR MIRONOV	{"email": "mironovaleksandr_011976@postgrespro.ru", "phone": "+70720790305"}
0005432535774	F16E28	9838 413125	RAILYA KUZNECOVA	{"phone": "+70328271214"}
0005432535775	11E113	8151 991446	NADEZHDA BARANOVA	{"email": "baranova_n-021971@postgrespro.ru", "phone": "+70435312128"}
0005432535776	17557D	6435 978609	ELENA PETROVA	{"phone": "+70914393273"}
0005432535777	17557D	0636 587870	LYUDMILA KUZMINA	{"phone": "+70120531938"}
0005432535778	565288	7292 063009	VERONIKA KOMAROVA	{"email": "veronika-komarova-021979@postgrespro.ru", "phone": "+70502576872"}
0005432535779	813C06	6261 560785	KIRILL KULIKOV	{"email": "kulikov-kirill1963@postgrespro.ru", "phone": "+70297121221"}
0005432535780	720F99	0093 028531	OLGA SMIRNOVA	{"phone": "+70293632190"}
0005432535781	EEC816	1295 162906	VALERIY KOZLOV	{"email": "valeriy.kozlov15021972@postgrespro.ru", "phone": "+70318646643"}
0005432535782	A0CBD9	5029 256122	IGOR ZAKHAROV	{"phone": "+70961406964"}
0005432535783	A0CBD9	4355 733643	VLADIMIR SCHERBAKOV	{"phone": "+70946948272"}
0005432535784	78A0A5	9914 809680	GALINA EFREMOVA	{"email": "galina.efremova_1964@postgrespro.ru", "phone": "+70386409020"}
0005432535785	94BFAE	5900 721258	VALERIYA SEMENOVA	{"phone": "+70666998896"}
0005432535786	0C193D	7543 555008	VERA FILIPPOVA	{"email": "vfilippova.28071969@postgrespro.ru", "phone": "+70244691769"}
0005432535787	0C193D	9461 933534	YULIYA ANTONOVA	{"phone": "+70539395629"}
0005432535788	8EF469	9199 930109	ANASTASIYA NOVIKOVA	{"email": "anastasiya-novikova_121969@postgrespro.ru", "phone": "+70477799040"}
0005432535789	7A070E	6755 758323	TAMARA ORLOVA	{"email": "t-orlova_1963@postgrespro.ru", "phone": "+70256669766"}
0005432535790	70E8DC	6068 337950	RAMIL ZAKHAROV	{"email": "zakharov.ramil_1966@postgrespro.ru", "phone": "+70415209083"}
0005432535791	D0C0F0	6676 406530	NATALYA TROFIMOVA	{"phone": "+70730337341"}
0005432535792	880097	1183 744089	ILONA ROMANOVA	{"email": "romanova.i.121965@postgrespro.ru", "phone": "+70957386838"}
0005432535793	D139C7	2533 114667	NADEZHDA OSIPOVA	{"email": "osipova_nadezhda.1976@postgrespro.ru", "phone": "+70118738587"}
0005432535794	C1E8C4	2703 185293	ALEKSEY ZAYCEV	{"email": "a-zaycev_021981@postgrespro.ru", "phone": "+70398435629"}
0005432535795	8CF4AD	4727 873182	ELENA SOKOLOVA	{"email": "e.sokolova1969@postgrespro.ru", "phone": "+70610230977"}
0005432535796	808015	0440 309943	ALEKSEY NIKITIN	{"phone": "+70814796862"}
0005432535797	20690E	2076 199119	DENIS ANDREEV	{"phone": "+70322746976"}
0005432535798	C97AFA	4139 138758	YULIYA SOKOLOVA	{"email": "yuliya_sokolova_1966@postgrespro.ru", "phone": "+70904963834"}
0005432535799	AE6091	5233 165084	OLEG TARASOV	{"email": "tarasov_oleg_1973@postgrespro.ru", "phone": "+70456773245"}
0005432535800	AE6091	6216 062354	TATYANA FILATOVA	{"email": "tatyana_filatova_1976@postgrespro.ru", "phone": "+70648542410"}
0005432535801	AE6091	8735 455323	ALEKSANDR MOROZOV	{"email": "aleksandr-morozov1980@postgrespro.ru", "phone": "+70525063197"}
0005432535802	57B133	8150 070909	MARGARITA SMIRNOVA	{"email": "m.smirnova.04051981@postgrespro.ru", "phone": "+70077281382"}
0005432535803	692F2C	9022 017873	ZHANNA GUSEVA	{"phone": "+70145832066"}
0005432535804	692F2C	5415 196176	ALEKSANDR DENISOV	{"phone": "+70978780742"}
0005432535805	818ACB	5592 365870	ANASTASIYA MOROZOVA	{"phone": "+70170996835"}
0005432535806	818ACB	9372 346307	ALEKSANDR ABRAMOV	{"email": "abramov-a021975@postgrespro.ru", "phone": "+70969859603"}
0005432535807	822114	8155 470318	VADIM OSIPOV	{"phone": "+70724712052"}
0005432535808	29E10A	3699 764307	ANTONINA TROFIMOVA	{"email": "a.trofimova.041975@postgrespro.ru", "phone": "+70815869089"}
0005432535809	1170A9	8206 802224	SERGEY ZHURAVLEV	{"email": "zhuravlev.sergey1975@postgrespro.ru", "phone": "+70187117998"}
0005432535810	E50EA2	7704 402158	TATYANA NESTEROVA	{"phone": "+70037950670"}
0005432535811	E50EA2	0317 219930	OLGA NOVIKOVA	{"email": "novikova.olga_1961@postgrespro.ru", "phone": "+70360288301"}
0005432535812	392D09	6842 396293	VALENTINA BORISOVA	{"phone": "+70217672843"}
0005432535813	42B2FA	2966 864318	IRAIDA OSIPOVA	{"email": "osipova.iraida-05101979@postgrespro.ru", "phone": "+70243262286"}
0005432535814	76D388	0001 486249	ANNA SCHERBAKOVA	{"phone": "+70232520299"}
0005432535815	B2D01C	9100 733586	LYUDMILA VASILEVA	{"email": "lvasileva.13121975@postgrespro.ru", "phone": "+70267573179"}
0005432535816	B2D01C	6367 562437	NIKOLAY FROLOV	{"phone": "+70079118677"}
0005432535817	76A231	6187 969694	VLADIMIR KAZAKOV	{"email": "kazakovvladimir_13071973@postgrespro.ru", "phone": "+70216076841"}
0005432535818	76A231	6919 254632	VIKTOR KRASNOV	{"phone": "+70416545882"}
0005432535819	A72750	1546 783716	TATYANA MAKAROVA	{"email": "tatyanamakarova.081967@postgrespro.ru", "phone": "+70123095914"}
0005432535820	F94E62	6033 373173	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov-1976@postgrespro.ru", "phone": "+70776037425"}
0005432535821	F94E62	2207 252466	VASILIY DENISOV	{"phone": "+70204193840"}
0005432535822	C23984	7212 923316	ELENA SOKOLOVA	{"email": "sokolova-e-1967@postgrespro.ru", "phone": "+70012668934"}
0005432535823	C23984	5420 814157	VALENTINA AFANASEVA	{"email": "vafanaseva_1970@postgrespro.ru", "phone": "+70561490071"}
0005432535824	2B0A5F	2216 128356	STANISLAV KUZNECOV	{"email": "stanislavkuznecov.1985@postgrespro.ru", "phone": "+70401048917"}
0005432535825	E0BECF	7440 791336	ANATOLIY KUZNECOV	{"email": "anatoliy_kuznecov_031984@postgrespro.ru", "phone": "+70719408301"}
0005432535826	E0BECF	5980 842409	NIKOLAY MELNIKOV	{"phone": "+70818783020"}
0005432535827	9432A7	7784 916173	IVAN OSIPOV	{"email": "osipov-ivan_03011976@postgrespro.ru", "phone": "+70354877553"}
0005432535828	B57169	2415 676877	ZINAIDA NESTEROVA	{"email": "nesterova-zinaida_041973@postgrespro.ru", "phone": "+70968700451"}
0005432535829	6FDCF2	4243 919320	FEDOR KUZNECOV	{"email": "kuznecov.fedor-08091964@postgrespro.ru", "phone": "+70144322282"}
0005432535830	6F05E8	7034 417343	VLADIMIR ZAKHAROV	{"phone": "+70177138728"}
0005432535831	ADF9AB	9643 945977	DMITRIY DENISOV	{"phone": "+70211931225"}
0005432535832	7F4F04	6338 028436	IGOR KUDRYASHOV	{"email": "kudryashov.i-021978@postgrespro.ru", "phone": "+70056362859"}
0005432535833	3ED7B8	4326 156338	ALEKSANDR KRASNOV	{"email": "aleksandr_krasnov-1971@postgrespro.ru", "phone": "+70272072457"}
0005432535834	820ADC	0920 472273	ANASTASIYA ARKHIPOVA	{"email": "arkhipova.a-071982@postgrespro.ru", "phone": "+70690445209"}
0005432535835	E2060D	0001 212613	IRINA ZAKHAROVA	{"phone": "+70370929000"}
0005432535836	AD5C36	5669 595935	ALEKSEY NOVIKOV	{"phone": "+70530939137"}
0005432535837	AD5C36	6781 777029	ALEKSEY SEMENOV	{"phone": "+70302382545"}
0005432535838	68DE99	6094 849859	OLEG DMITRIEV	{"email": "dmitriev.oleg-091974@postgrespro.ru", "phone": "+70883370157"}
0005432535839	046274	3335 838378	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr031979@postgrespro.ru", "phone": "+70075458213"}
0005432535840	046274	6625 413712	LYUDMILA AFANASEVA	{"phone": "+70804433240"}
0005432535841	7308C4	6652 903670	VLADIMIR KUZMIN	{"email": "vkuzmin_20061965@postgrespro.ru", "phone": "+70122617131"}
0005432535842	F8EC43	6655 118982	TAMARA NIKITINA	{"phone": "+70710517803"}
0005432535843	3521F8	4116 056181	MARIYA VLASOVA	{"phone": "+70792932925"}
0005432535844	17B31F	7765 025710	VERA POLYAKOVA	{"email": "polyakova-vera-1971@postgrespro.ru", "phone": "+70841061234"}
0005432535845	17B31F	1227 037790	EVGENIYA VOLKOVA	{"email": "evolkova-111964@postgrespro.ru", "phone": "+70015279952"}
0005432535846	362ADE	5343 098509	GALINA GORBUNOVA	{"phone": "+70324671855"}
0005432535847	2BA7AF	0050 923090	LILIYA MEDVEDEVA	{"email": "lmedvedeva.1974@postgrespro.ru", "phone": "+70563883640"}
0005432535848	82067C	2729 897523	NIKOLAY VLASOV	{"phone": "+70690617334"}
0005432535849	19BCFA	4811 840249	OKSANA GAVRILOVA	{"phone": "+70642070254"}
0005432535850	FEA44B	2631 402759	VLADIMIR ILIN	{"email": "ilin-vladimir13121969@postgrespro.ru", "phone": "+70295483987"}
0005432535851	0B94BF	8543 218257	KSENIYA FEDOROVA	{"email": "k-fedorova.14041977@postgrespro.ru", "phone": "+70068789031"}
0005432535852	0B94BF	0628 182384	NADEZHDA SERGEEVA	{"email": "nadezhdasergeeva_25011974@postgrespro.ru", "phone": "+70726974712"}
0005432535853	915DC8	6960 026774	LYUBOV OSIPOVA	{"phone": "+70912038133"}
0005432535854	915DC8	3617 624450	ALEKSANDRA IVANOVA	{"phone": "+70443694912"}
0005432535855	FCB1B8	8236 342278	MIKHAIL EGOROV	{"phone": "+70484129028"}
0005432535856	FCB1B8	3149 056905	SVETLANA VLASOVA	{"phone": "+70684089595"}
0005432535857	FCB1B8	1550 403612	IRINA BELOVA	{"email": "belova-irina1967@postgrespro.ru", "phone": "+70590219755"}
0005432535858	76F6D5	2485 357968	VLADIMIR MAKAROV	{"phone": "+70889812864"}
0005432535859	2CCFAB	1822 301378	OLGA AKIMOVA	{"email": "o-akimova.1966@postgrespro.ru", "phone": "+70075148438"}
0005432535860	2CCFAB	9505 303815	YULIYA KAZAKOVA	{"email": "kazakovay-081966@postgrespro.ru", "phone": "+70552919832"}
0005432535861	2CCFAB	5722 090416	ALEKSANDR MAKAROV	{"phone": "+70181501010"}
0005432535862	E1EB3C	1551 249280	SERGEY NIKITIN	{"phone": "+70952365028"}
0005432535863	B02245	0207 690710	GALINA MATVEEVA	{"phone": "+70081865747"}
0005432535864	B02245	2761 876887	VALENTINA FILATOVA	{"phone": "+70309147317"}
0005432535865	7B0836	4177 556975	RUFINA BOGDANOVA	{"email": "rufina_bogdanova-1977@postgrespro.ru", "phone": "+70361602978"}
0005432535866	1947C9	5960 617203	ANTONINA VASILEVA	{"email": "vasileva_a.21031975@postgrespro.ru", "phone": "+70496630117"}
0005432535867	EAD97F	0817 313895	VYACHESLAV KUZNECOV	{"phone": "+70896648818"}
0005432535868	EC8508	0645 778988	ALEKSANDR TIMOFEEV	{"phone": "+70434136178"}
0005432535869	AEA7A2	7807 106603	ANNA MAKAROVA	{"phone": "+70260420498"}
0005432535870	34A4F2	2280 477353	RUMIYA MELNIKOVA	{"phone": "+70399211034"}
0005432535871	34A4F2	5559 350227	OKSANA LUKYANOVA	{"phone": "+70286778744"}
0005432535872	BEF32D	8587 395117	YURIY PAVLOV	{"email": "y_pavlov_1979@postgrespro.ru", "phone": "+70617436642"}
0005432535873	BEF32D	9422 127569	ALEKSANDR SEMENOV	{"phone": "+70873596420"}
0005432535874	DDF361	0488 460548	GALINA ANDREEVA	{"phone": "+70738278083"}
0005432535875	DDF361	1624 021835	VALENTINA OSIPOVA	{"email": "valentina-osipova071979@postgrespro.ru", "phone": "+70901409773"}
0005432535876	A2E730	7499 695808	ANDREY ZHUKOV	{"email": "zhukov_a.1983@postgrespro.ru", "phone": "+70938482695"}
0005432535877	A2E730	8654 507395	MARIYA ZAKHAROVA	{"email": "mariyazakharova_1984@postgrespro.ru", "phone": "+70477498227"}
0005432535878	6CBC9C	5749 792582	RINAT ANDREEV	{"phone": "+70049907834"}
0005432535879	6CBC9C	1977 375967	RAISA ALEKSANDROVA	{"email": "raisa-aleksandrova.011978@postgrespro.ru", "phone": "+70043163166"}
0005432535881	ED3629	6873 554636	NINA MIRONOVA	{"email": "nmironova_121977@postgrespro.ru", "phone": "+70177866409"}
0005432535882	E435D4	5825 069368	RINAT SEMENOV	{"phone": "+70040278719"}
0005432535883	E435D4	4091 652124	ALEKSANDR VOLKOV	{"phone": "+70097651396"}
0005432535884	B2A6D7	7727 484037	VLADIMIR ZAKHAROV	{"email": "v_zakharov-1975@postgrespro.ru", "phone": "+70428849318"}
0005432535885	EFB71F	2560 344502	ANDREY FEDOTOV	{"phone": "+70421043084"}
0005432535886	EFB71F	2982 975368	VERA NAZAROVA	{"email": "v_nazarova_1972@postgrespro.ru", "phone": "+70151027537"}
0005432535887	CDB933	0300 495837	ALLA KRASNOVA	{"email": "alla_krasnova021971@postgrespro.ru", "phone": "+70477373364"}
0005432535888	EDF969	4712 939772	ALIYA KISELEVA	{"phone": "+70641959311"}
0005432535889	F705FC	4992 899652	DMITRIY MELNIKOV	{"email": "melnikov-d1975@postgrespro.ru", "phone": "+70403689901"}
0005432535890	B5371B	7557 079115	MILANA MEDVEDEVA	{"phone": "+70132286067"}
0005432535891	790630	1980 734046	NATALYA KOLESNIKOVA	{"phone": "+70803078105"}
0005432535892	790630	6890 879996	ZINAIDA NIKIFOROVA	{"email": "nikiforovaz021973@postgrespro.ru", "phone": "+70848001693"}
0005432535893	C274E0	9886 849518	MARIYA KOZLOVA	{"email": "kozlova.mariya_111984@postgrespro.ru", "phone": "+70533631383"}
0005432535894	0C7DB7	4087 634367	LYUDMILA NAZAROVA	{"phone": "+70982503052"}
0005432535895	0C7DB7	6596 382500	ROMAN SCHERBAKOV	{"phone": "+70593098598"}
0005432535896	C2396E	9756 888615	OLEG MIKHAYLOV	{"phone": "+70877273894"}
0005432535897	0A481B	6896 383271	ILYA SCHERBAKOV	{"email": "ilya_scherbakov-13041971@postgrespro.ru", "phone": "+70066015173"}
0005432535898	CB3644	2399 377064	DMITRIY POPOV	{"phone": "+70781439526"}
0005432535899	CB3644	0936 810927	TATYANA KALININA	{"email": "kalinina_t_091983@postgrespro.ru", "phone": "+70200315814"}
0005432535900	A835D5	4883 225116	NATALIYA VASILEVA	{"email": "vasileva-n-01051978@postgrespro.ru", "phone": "+70327844982"}
0005432535901	B33304	5606 775364	IGOR ZAYCEV	{"phone": "+70685216330"}
0005432535902	B33304	6177 889822	ELENA TROFIMOVA	{"phone": "+70774493813"}
0005432535903	B33304	9066 901105	TATYANA MAKSIMOVA	{"phone": "+70956054035"}
0005432535904	BD77FE	0305 896037	ALEKSANDR SOROKIN	{"phone": "+70336714360"}
0005432535905	BD77FE	5211 317921	ANATOLIY KARPOV	{"email": "karpov-a-11031977@postgrespro.ru", "phone": "+70701578563"}
0005432535906	999C38	9411 086499	GALINA KUZNECOVA	{"phone": "+70574410142"}
0005432535907	9D5997	8659 922068	SEMEN CHERNOV	{"phone": "+70857585159"}
0005432535908	F57E0E	0939 354860	EDUARD ROMANOV	{"email": "romanov-e_031968@postgrespro.ru", "phone": "+70573357123"}
0005432535909	67B2DE	7358 260449	EVGENIY FEDOROV	{"phone": "+70581591918"}
0005432535910	8AA666	4760 212482	GRIGORIY TIMOFEEV	{"phone": "+70431057684"}
0005432535911	00BDA8	6707 253036	LYUDMILA KUZMINA	{"phone": "+70882085171"}
0005432535912	BD79FE	9130 738306	OLGA SERGEEVA	{"phone": "+70515577186"}
0005432535913	BD79FE	5810 155450	TATYANA BELOVA	{"phone": "+70361386361"}
0005432535914	FAF3A8	4375 228620	NADEZHDA NESTEROVA	{"phone": "+70411100285"}
0005432535915	E6B9A0	8471 466322	ALENA ZOTOVA	{"phone": "+70690678221"}
0005432535916	48C1FE	4218 262083	SVETLANA MEDVEDEVA	{"phone": "+70680775719"}
0005432535917	255E2C	9229 847802	SVETLANA ROMANOVA	{"email": "s_romanova23121985@postgrespro.ru", "phone": "+70531570541"}
0005432535918	B369CD	7445 746883	TATYANA KALININA	{"phone": "+70461217556"}
0005432535919	451AB5	5219 474955	ZHANNA SOLOVEVA	{"phone": "+70055901609"}
0005432535920	971D66	8402 939895	KRISTINA PAVLOVA	{"email": "kpavlova03011960@postgrespro.ru", "phone": "+70126514818"}
0005432535921	644B12	0366 784513	VIKTOR MAKAROV	{"email": "v-makarov-20111966@postgrespro.ru", "phone": "+70713378995"}
0005432535922	452885	8081 017132	VALENTINA GRISHINA	{"email": "valentina_grishina-1974@postgrespro.ru", "phone": "+70178855572"}
0005432535923	18D943	8632 839162	KSENIYA EFIMOVA	{"email": "kseniya.efimova-1971@postgrespro.ru", "phone": "+70442159004"}
0005432535924	18D943	5211 585838	YURIY SOROKIN	{"phone": "+70762778718"}
0005432535925	E713D5	0342 880299	OKSANA NIKITINA	{"phone": "+70775554404"}
0005432535926	7CB17B	9879 741240	ALEKSANDR ISAEV	{"phone": "+70446742530"}
0005432535927	450B23	8019 034353	TATYANA NAZAROVA	{"phone": "+70517383749"}
0005432535928	450B23	8879 266634	OLEG FILIPPOV	{"email": "oleg.filippov.011965@postgrespro.ru", "phone": "+70231120963"}
0005432535929	C82F51	5535 338244	ALEKSEY ROMANOV	{"phone": "+70817212594"}
0005432535930	C82F51	6406 689619	GALINA GERASIMOVA	{"email": "g.gerasimova.15021968@postgrespro.ru", "phone": "+70351733085"}
0005432535931	012AC6	0208 551606	ANATOLIY NOVIKOV	{"phone": "+70794379442"}
0005432535932	012AC6	8442 374557	PETR MOROZOV	{"email": "p_morozov111976@postgrespro.ru", "phone": "+70104418857"}
0005432535933	BB9307	7690 896010	RAISA KOROLEVA	{"email": "raisa_koroleva_1976@postgrespro.ru", "phone": "+70349722782"}
0005432535934	BB9307	7087 163164	ANATOLIY FILIPPOV	{"phone": "+70102296544"}
0005432535935	BB9307	3407 981923	OLGA KALININA	{"phone": "+70698605435"}
0005432535936	09F593	1423 111628	NINA KARPOVA	{"email": "nina.karpova_1970@postgrespro.ru", "phone": "+70796781123"}
0005432535937	09F593	9817 942758	LIDIYA SOROKINA	{"email": "lidiya_sorokina_121971@postgrespro.ru", "phone": "+70787468432"}
0005432535938	09F593	2052 320377	ANDREY ZAYCEV	{"email": "a-zaycev-1970@postgrespro.ru", "phone": "+70173563716"}
0005432535939	B798A6	1550 287890	SERGEY OSIPOV	{"phone": "+70306304709"}
0005432535940	B798A6	7111 790029	LARISA SERGEEVA	{"email": "sergeeva-larisa.18091966@postgrespro.ru", "phone": "+70837612717"}
0005432535941	FB707D	2897 278352	ANASTASIYA MARTYNOVA	{"email": "martynovaa1978@postgrespro.ru", "phone": "+70558467740"}
0005432535942	FB707D	6104 539714	OLESYA ZAKHAROVA	{"email": "zakharova.o19061972@postgrespro.ru", "phone": "+70829501234"}
0005432535943	FE3524	0103 383140	DENIS KOROLEV	{"phone": "+70098204773"}
0005432535944	6D4CB6	5506 729313	YAKOV KUZNECOV	{"email": "kuznecov.yakov_17071968@postgrespro.ru", "phone": "+70559281563"}
0005432535945	6D4CB6	3091 002534	MIKHAIL NOVIKOV	{"phone": "+70094359292"}
0005432535946	0FDE35	5601 299703	YURIY CHERNOV	{"email": "yuriy_chernov.1961@postgrespro.ru", "phone": "+70611879174"}
0005432535947	BC8A82	3974 115948	KSENIYA FILIPPOVA	{"phone": "+70249087816"}
0005432535948	424842	3115 998528	DENIS KISELEV	{"email": "kiselevdenis_071967@postgrespro.ru", "phone": "+70487320682"}
0005432535949	5605AC	3344 497607	VLADIMIR PETROV	{"email": "vladimirpetrov-1969@postgrespro.ru", "phone": "+70359535998"}
0005432535950	3FCFCE	1283 594040	ELIZAVETA GUSEVA	{"email": "e_guseva.1980@postgrespro.ru", "phone": "+70286531755"}
0005432535951	3FCFCE	0877 804645	ALEKSANDR VLASOV	{"email": "vlasovaleksandr-011976@postgrespro.ru", "phone": "+70473060826"}
0005432535952	ACFBCC	4726 442427	YURIY PAVLOV	{"email": "pavlov_yuriy-04061969@postgrespro.ru", "phone": "+70317450149"}
0005432535953	8FCB61	8293 121761	ALBERT ZAYCEV	{"phone": "+70035097713"}
0005432535954	0131C8	2473 606906	VLADISLAV NIKITIN	{"phone": "+70685702290"}
0005432535955	0131C8	2996 626804	PETR VASILEV	{"phone": "+70056817327"}
0005432535956	89C7DF	6124 078118	SERGEY IVANOV	{"phone": "+70731633928"}
0005432535957	41975D	1678 531770	VALERIY TARASOV	{"phone": "+70992888446"}
0005432535958	8AF9CF	8771 064781	VADIM GAVRILOV	{"phone": "+70484247545"}
0005432535959	B0E362	4061 173816	NATALYA NOVIKOVA	{"phone": "+70498481357"}
0005432535960	2C0067	6233 918086	PETR ORLOV	{"email": "orlov.petr.06061974@postgrespro.ru", "phone": "+70263213299"}
0005432535961	171811	9802 365488	ELENA IVANOVA	{"email": "ivanova.elena1960@postgrespro.ru", "phone": "+70945326814"}
0005432535962	729DB3	2437 849246	VALENTINA POPOVA	{"email": "v_popova_17101980@postgrespro.ru", "phone": "+70220091536"}
0005432535963	45F0B0	4307 497968	NIKOLAY SCHERBAKOV	{"email": "nikolay-scherbakov.1965@postgrespro.ru", "phone": "+70186379277"}
0005432535964	E1CE6B	5363 101065	ELENA ROMANOVA	{"email": "elena_romanova_051981@postgrespro.ru", "phone": "+70171778511"}
0005432535965	C3BFAA	6880 158848	NATALYA MARTYNOVA	{"phone": "+70922109686"}
0005432535966	C3BFAA	3472 978060	VLADIMIR ANTONOV	{"phone": "+70299292120"}
0005432535967	FEC071	6609 549623	LYUDMILA KUZMINA	{"phone": "+70951609440"}
0005432535968	56ECFC	2557 385015	ANDREY MOISEEV	{"email": "moiseev-a-1976@postgrespro.ru", "phone": "+70694922701"}
0005432535969	CC56CD	3718 729066	NATALYA PAVLOVA	{"email": "n.pavlova-1972@postgrespro.ru", "phone": "+70523381220"}
0005432535970	AB966A	1463 752767	EVGENIY SEMENOV	{"email": "semenov-evgeniy.1972@postgrespro.ru", "phone": "+70107958149"}
0005432535971	AC71C0	0432 313173	ELENA GAVRILOVA	{"phone": "+70422517149"}
0005432535972	AC71C0	9867 742320	TATYANA POPOVA	{"email": "tatyanapopova-031975@postgrespro.ru", "phone": "+70134502686"}
0005432535973	561263	3856 239601	IRINA TARASOVA	{"phone": "+70927577002"}
0005432535974	6CADF0	9621 780528	TATYANA EFREMOVA	{"email": "tatyana_efremova30101962@postgrespro.ru", "phone": "+70850741324"}
0005432535975	6A88F7	0129 315129	YULIYA NAZAROVA	{"phone": "+70177922642"}
0005432535976	470E7E	7629 896773	ELENA DAVYDOVA	{"email": "e_davydova081972@postgrespro.ru", "phone": "+70405419268"}
0005432535977	2F82E3	7361 227961	VALENTINA DENISOVA	{"phone": "+70815457984"}
0005432535978	2F82E3	9625 417211	PAVEL VOLKOV	{"email": "volkov_pavel1983@postgrespro.ru", "phone": "+70197973437"}
0005432535979	8D61D7	8526 310616	LYUBOV BORISOVA	{"phone": "+70001646237"}
0005432537022	6473D4	0932 355165	MARIYA NIKIFOROVA	{"phone": "+70730158228"}
0005432537023	B66219	2424 436417	DMITRIY KUZMIN	{"phone": "+70671402904"}
0005432537024	B66219	4226 790959	VALERIY YAKOVLEV	{"phone": "+70918836525"}
0005432537025	109B02	7769 750073	DENIS SEMENOV	{"email": "semenov_denis.061962@postgrespro.ru", "phone": "+70659923066"}
0005432537026	109B02	7778 502031	MIKHAIL TARASOV	{"phone": "+70879256464"}
0005432537027	109B02	3818 410823	GALINA LEBEDEVA	{"email": "lebedeva-g.24031965@postgrespro.ru", "phone": "+70797000298"}
0005432537028	08DC8A	6778 549209	NINA PETROVA	{"email": "n.petrova_01031974@postgrespro.ru", "phone": "+70044024873"}
0005432537029	08DC8A	1224 626155	STANISLAV ISAEV	{"email": "stanislav-isaev.07021974@postgrespro.ru", "phone": "+70701608026"}
0005432537030	A68A46	1411 554538	VALERIY ANDREEV	{"email": "andreev-valeriy.18031971@postgrespro.ru", "phone": "+70874313536"}
0005432537031	5833D4	0273 648104	IGOR OSIPOV	{"phone": "+70664455008"}
0005432537032	7F27D1	2561 474208	VALERIY DAVYDOV	{"phone": "+70041062804"}
0005432537033	3B54BB	5368 241076	DARYA TIKHONOVA	{"email": "tikhonova-d.08031967@postgrespro.ru", "phone": "+70821922130"}
0005432537034	3B54BB	9994 168772	TATYANA SOROKINA	{"phone": "+70510887624"}
0005432537035	3B54BB	1406 902284	DMITRIY KUZMIN	{"email": "dmitriykuzmin.01041984@postgrespro.ru", "phone": "+70814458211"}
0005432537036	FE76BD	6074 205794	ALEKSANDR KUZNECOV	{"phone": "+70130145262"}
0005432537037	FE76BD	2175 782123	EVGENIY ROMANOV	{"email": "evgeniy-romanov_17121975@postgrespro.ru", "phone": "+70091052961"}
0005432537038	69E617	3727 812602	VIKTOR MELNIKOV	{"phone": "+70862329263"}
0005432537039	6331CC	8277 177462	ANATOLIY FEDOROV	{"phone": "+70294708989"}
0005432537040	DE1E5C	9786 851867	GALINA MASLOVA	{"email": "maslovag-17041985@postgrespro.ru", "phone": "+70032911046"}
0005432537041	DE1E5C	0961 092468	VALENTINA NIKITINA	{"phone": "+70511216047"}
0005432537042	199301	8364 109512	EVGENIY SERGEEV	{"phone": "+70999583167"}
0005432537043	199301	3928 413625	SERGEY IVANOV	{"email": "ivanov_sergey1964@postgrespro.ru", "phone": "+70523180403"}
0005432537044	8A9913	4420 114735	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_14041975@postgrespro.ru", "phone": "+70136722226"}
0005432537045	D537FC	0514 355402	ELENA SMIRNOVA	{"email": "smirnova-elena.1953@postgrespro.ru", "phone": "+70582388169"}
0005432537046	1BCB23	9682 854022	ALEKSANDR IVANOV	{"phone": "+70741185760"}
0005432537047	1BCB23	7818 870318	LYUDMILA GORBUNOVA	{"phone": "+70701478741"}
0005432537048	CAF771	6708 001954	MARIYA SEMENOVA	{"phone": "+70720806556"}
0005432537049	F7D395	2447 998402	NATALYA FILATOVA	{"email": "n-filatova071956@postgrespro.ru", "phone": "+70035496291"}
0005432537050	F7D395	6285 879011	IRINA NESTEROVA	{"email": "irina_nesterova-09021981@postgrespro.ru", "phone": "+70562110928"}
0005432537051	92C2D1	6231 207734	YURIY KARPOV	{"email": "yuriy-karpov_1971@postgrespro.ru", "phone": "+70965141455"}
0005432537052	92C2D1	2929 468128	VLADISLAV ALEKSANDROV	{"email": "v.aleksandrov1973@postgrespro.ru", "phone": "+70837405696"}
0005432537053	7027D2	3721 976933	IRINA PAVLOVA	{"email": "pavlova_i.05021962@postgrespro.ru", "phone": "+70356348480"}
0005432537054	33475C	3619 817764	NATALYA ISAEVA	{"email": "isaeva.n.111978@postgrespro.ru", "phone": "+70914081055"}
0005432537055	A55FAF	8074 440265	NATALYA POPOVA	{"email": "popova.natalya-1975@postgrespro.ru", "phone": "+70436189913"}
0005432537056	A55FAF	8764 380029	VLADIMIR SEMENOV	{"phone": "+70234815944"}
0005432537057	781477	9867 774986	VLADIMIR KOZLOV	{"email": "v_kozlov1970@postgrespro.ru", "phone": "+70762128103"}
0005432537058	E5B638	1933 231711	TATYANA RODIONOVA	{"email": "rodionova.t.25081969@postgrespro.ru", "phone": "+70464124346"}
0005432537059	A3A7F0	2073 318002	VLADIMIR DENISOV	{"phone": "+70167688322"}
0005432537060	6F62A0	2659 508336	TATYANA SEMENOVA	{"email": "semenova-t.081955@postgrespro.ru", "phone": "+70091913822"}
0005432537061	F7900C	6068 210656	LYUBOV EGOROVA	{"phone": "+70773145189"}
0005432537062	B0A947	7646 268755	PAVEL GORBUNOV	{"phone": "+70111106027"}
0005432537063	E5EE55	5828 978549	OLGA VASILEVA	{"email": "o_vasileva.21021966@postgrespro.ru", "phone": "+70623314700"}
0005432537064	E5EE55	2331 323927	YURIY BONDARENKO	{"email": "bondarenko_y1992@postgrespro.ru", "phone": "+70217809762"}
0005432537065	8FAA20	2980 398646	TAMARA AFANASEVA	{"email": "tamaraafanaseva.111981@postgrespro.ru", "phone": "+70235779941"}
0005432537066	5B00FE	5886 455274	OLESYA SEMENOVA	{"email": "olesyasemenova_1974@postgrespro.ru", "phone": "+70223247523"}
0005432537067	5B00FE	0514 183799	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr.021973@postgrespro.ru", "phone": "+70881321947"}
0005432537068	7CF987	0074 522848	LYUBOV NIKITINA	{"email": "nikitina-lyubov.1973@postgrespro.ru", "phone": "+70935683254"}
0005432537069	CC0DA0	3713 003119	LYUBOV NOVIKOVA	{"email": "lyubovnovikova011967@postgrespro.ru", "phone": "+70438955383"}
0005432537070	CC0DA0	6734 053742	VIKTOR MARTYNOV	{"email": "martynov.v_1973@postgrespro.ru", "phone": "+70395388681"}
0005432537071	6383CC	1798 626727	ALEKSANDR GORBUNOV	{"phone": "+70253829890"}
0005432537072	EDF830	7196 012394	KRISTINA KUZMINA	{"phone": "+70130858531"}
0005432537073	EDF830	4212 983842	ANASTASIYA DMITRIEVA	{"email": "anastasiya_dmitrieva_051953@postgrespro.ru", "phone": "+70657663754"}
0005432537074	9394CF	3750 589664	OLGA IVANOVA	{"email": "ivanova_o.121971@postgrespro.ru", "phone": "+70393755783"}
0005432537075	DB5753	7182 033752	MARINA KUZNECOVA	{"email": "marina.kuznecova121972@postgrespro.ru", "phone": "+70610010969"}
0005432537076	FFC4A9	2671 929979	TATYANA NIKITINA	{"email": "nikitina_t1971@postgrespro.ru", "phone": "+70413565341"}
0005432537077	DEF789	5320 059273	VALENTINA ANTONOVA	{"email": "antonova.v-1972@postgrespro.ru", "phone": "+70074574514"}
0005432537078	DEF789	9954 234079	ANASTASIYA FEDOROVA	{"phone": "+70968321734"}
0005432537079	39443F	8513 097497	SVETLANA IVANOVA	{"phone": "+70024698456"}
0005432537080	F4FF75	9512 469983	SERGEY GRIGOREV	{"email": "sergey-grigorev1972@postgrespro.ru", "phone": "+70299267593"}
0005432537081	F7A9E5	6735 150238	ELENA MAKSIMOVA	{"phone": "+70853238534"}
0005432537082	AF18AE	7219 674931	SVETLANA ZAKHAROVA	{"email": "svetlana_zakharova1980@postgrespro.ru", "phone": "+70443517637"}
0005432537083	6C038C	2750 477018	VITALIY TARASOV	{"phone": "+70033232713"}
0005432537084	7F02F9	2803 777764	MARIYA KOZLOVA	{"phone": "+70500817085"}
0005432537085	F19903	5226 883740	OLGA PETROVA	{"email": "petrova.o_1973@postgrespro.ru", "phone": "+70764913107"}
0005432537086	F19903	5860 911204	ELENA KRASNOVA	{"phone": "+70574937185"}
0005432537087	62A3E3	4163 066628	IRINA LAZAREVA	{"email": "lazareva_i1978@postgrespro.ru", "phone": "+70947769208"}
0005432537088	62A3E3	8220 039124	FEDOR MAKAROV	{"email": "f_makarov.1975@postgrespro.ru", "phone": "+70646973945"}
0005432537089	8D4DBD	6526 558304	VALERIY PETROV	{"email": "valeriy_petrov1966@postgrespro.ru", "phone": "+70143136845"}
0005432537090	82AE7B	0040 330347	VIKTOR KRASNOV	{"email": "krasnov-v-07111963@postgrespro.ru", "phone": "+70501346825"}
0005432537091	E4AA28	5467 179191	VASILIY GRIGOREV	{"phone": "+70524123327"}
0005432537092	DCDB67	5645 370025	EVGENIY KARPOV	{"phone": "+70061932338"}
0005432537093	269D85	6525 051148	OLGA IVANOVA	{"email": "o.ivanova_1973@postgrespro.ru", "phone": "+70616658906"}
0005432537094	269D85	3666 693426	GALINA KARPOVA	{"email": "karpova.galina1968@postgrespro.ru", "phone": "+70854841363"}
0005432537095	34F30A	2394 123806	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov_1975@postgrespro.ru", "phone": "+70475790631"}
0005432537096	34F30A	2860 288882	ALEKSANDR EGOROV	{"email": "a_egorov-1973@postgrespro.ru", "phone": "+70928275931"}
0005432537097	AEDD23	0102 240551	ELENA KRASNOVA	{"email": "krasnovae_1971@postgrespro.ru", "phone": "+70003767451"}
0005432537098	A99B55	3295 204345	OKSANA ANTONOVA	{"email": "antonova.oksana1970@postgrespro.ru", "phone": "+70911582412"}
0005432537099	A76DE5	8151 980890	IGOR DENISOV	{"email": "igor_denisov1976@postgrespro.ru", "phone": "+70973283948"}
0005432537100	D6AE23	3944 959060	OLESYA ZHURAVLEVA	{"email": "zhuravlevaolesya03091968@postgrespro.ru", "phone": "+70620295737"}
0005432537101	408A5E	5698 724497	LYUBOV SOLOVEVA	{"phone": "+70903343882"}
0005432537102	408A5E	5001 658296	VLADISLAV SOROKIN	{"phone": "+70531715691"}
0005432537103	C34F4C	0564 303230	KLAVDIYA RODIONOVA	{"phone": "+70549722923"}
0005432537104	C34F4C	8507 139463	OLGA KUZMINA	{"phone": "+70091410715"}
0005432537105	92F3D2	7942 006623	ALEKSANDRA DAVYDOVA	{"email": "davydovaa26011979@postgrespro.ru", "phone": "+70875545880"}
0005432537106	445220	0886 720467	IGOR KONOVALOV	{"email": "konovalov_igor_16061976@postgrespro.ru", "phone": "+70006926202"}
0005432537107	445220	7373 073902	ALEKSEY FOMIN	{"email": "aleksey.fomin_051987@postgrespro.ru", "phone": "+70275862543"}
0005432537108	852D5F	2596 181295	ANATOLIY SERGEEV	{"email": "anatoliy_sergeev_26121966@postgrespro.ru", "phone": "+70094121279"}
0005432537109	FC2DAC	4537 443155	NATALYA KONOVALOVA	{"email": "nkonovalova061969@postgrespro.ru", "phone": "+70855544734"}
0005432537110	C3B5F6	6173 441363	VALERIY SERGEEV	{"phone": "+70035006653"}
0005432537111	C6487F	6114 987121	PETR EGOROV	{"phone": "+70604178357"}
0005432537112	C6487F	2358 278510	DENIS KRASNOV	{"phone": "+70727490997"}
0005432537113	5EF3AF	1031 977450	SERGEY NIKITIN	{"email": "s_nikitin-061964@postgrespro.ru", "phone": "+70368716051"}
0005432537114	E2608B	8499 128640	ELENA TIKHONOVA	{"email": "elena.tikhonova_1968@postgrespro.ru", "phone": "+70410443831"}
0005432537115	82B7B7	0999 073530	MARINA KARPOVA	{"email": "m.karpova1983@postgrespro.ru", "phone": "+70976953591"}
0005432537116	FA7840	0757 876677	VADIM TIMOFEEV	{"phone": "+70025484726"}
0005432537117	FA7840	8178 033160	IVAN YAKOVLEV	{"phone": "+70669726922"}
0005432537118	6A4AA4	4582 926490	POLINA EFIMOVA	{"email": "polina.efimova_011967@postgrespro.ru", "phone": "+70675591359"}
0005432537119	38C4A1	2110 796991	ALEKSEY MATVEEV	{"email": "matveev-aleksey061973@postgrespro.ru", "phone": "+70260840118"}
0005432537120	86BF1B	2110 034255	NATALYA SERGEEVA	{"email": "sergeevanatalya-1964@postgrespro.ru", "phone": "+70574757864"}
0005432537121	D03C87	6715 645014	TATYANA SOROKINA	{"email": "t-sorokina-13101959@postgrespro.ru", "phone": "+70432029715"}
0005432537122	D03C87	0670 150208	ELENA KALININA	{"email": "kalininae1977@postgrespro.ru", "phone": "+70741150185"}
0005432537123	04F974	0532 951749	VIKTOR OSIPOV	{"phone": "+70951665456"}
0005432566525	A5D122	0823 874858	EVGENIY OSIPOV	{"phone": "+70648290420"}
0005432566526	A5D122	3468 652864	IRINA KUZMINA	{"phone": "+70111393363"}
0005432566527	E578DA	1536 863807	VENERA FILIPPOVA	{"email": "venera-filippova-30041980@postgrespro.ru", "phone": "+70938031470"}
0005432566528	62101C	2947 989477	YULIYA IVANOVA	{"phone": "+70602688445"}
0005432566529	13FBEE	4639 888170	NATALYA BELOVA	{"phone": "+70082605519"}
0005432566530	EA9938	7046 638683	VIKTORIYA KULIKOVA	{"email": "kulikova-viktoriya19041987@postgrespro.ru", "phone": "+70526358835"}
0005432566531	7386CB	1600 140256	VERA KOROLEVA	{"email": "korolevav1960@postgrespro.ru", "phone": "+70603428602"}
0005432566651	8A64F7	8124 880196	ARTEMIY FEDOROV	{"phone": "+70860943552"}
0005432566532	59B875	0448 668744	VIKTORIYA TIKHONOVA	{"email": "tikhonova_v-071964@postgrespro.ru", "phone": "+70779124195"}
0005432566533	D6B34D	7268 607214	DMITRIY MIKHAYLOV	{"email": "dmitriy_mikhaylov1964@postgrespro.ru", "phone": "+70177748695"}
0005432566534	7EFF81	8427 858621	IGOR MATVEEV	{"email": "igormatveev21051963@postgrespro.ru", "phone": "+70853639201"}
0005432566535	7EFF81	7939 513311	MIKHAIL FOMIN	{"email": "mikhail-fomin.20071971@postgrespro.ru", "phone": "+70311647547"}
0005432566536	D06ACD	1022 177122	OLEG VOROBEV	{"email": "olegvorobev21121964@postgrespro.ru", "phone": "+70131763403"}
0005432566537	28D6B3	6545 971110	OLEG SOKOLOV	{"email": "o-sokolov031970@postgrespro.ru", "phone": "+70176486549"}
0005432566538	026636	0662 626917	SERGEY KONOVALOV	{"phone": "+70762031564"}
0005432566539	026636	3941 599768	REGINA SMIRNOVA	{"email": "regina_smirnova.07121962@postgrespro.ru", "phone": "+70942168245"}
0005432566540	0AD18D	4380 709959	EVGENIY MIRONOV	{"phone": "+70133159461"}
0005432566541	0AD18D	5188 252970	VALENTINA ANISIMOVA	{"phone": "+70798076299"}
0005432566542	976FEF	5481 128317	IRINA SEMENOVA	{"phone": "+70252146452"}
0005432566543	976FEF	0023 698815	ALEKSANDR KUZMIN	{"phone": "+70260670837"}
0005432566544	887F84	9570 877290	MARIYA NAUMOVA	{"phone": "+70353841750"}
0005432566545	428F03	0148 181506	SERGEY EGOROV	{"phone": "+70631204749"}
0005432566546	BF79DB	3922 080376	YULIYA AFANASEVA	{"phone": "+70076515740"}
0005432566547	FA31FA	2442 847769	IVAN MAKAROV	{"email": "i_makarov_09011974@postgrespro.ru", "phone": "+70897819869"}
0005432566548	406A87	9207 281451	DMITRIY ZAYCEV	{"phone": "+70881069877"}
0005432566549	4EEE23	7132 241128	GALINA MAKSIMOVA	{"phone": "+70498074081"}
0005432566550	91E4F7	6317 473165	NATALYA IVANOVA	{"phone": "+70676988087"}
0005432566551	FA07F5	7972 218019	VLADIMIR KUZMIN	{"phone": "+70296829544"}
0005432566552	75C2EA	1852 140407	VALENTINA KUZNECOVA	{"phone": "+70904770124"}
0005432566553	6190B6	2987 982059	VYACHESLAV ZAKHAROV	{"email": "zakharov.vyacheslav_23021967@postgrespro.ru", "phone": "+70569284975"}
0005432566554	C8D607	5997 828968	ANNA TIMOFEEVA	{"email": "atimofeeva.1986@postgrespro.ru", "phone": "+70728451927"}
0005432566555	C8D607	2714 156530	RAILYA FOMINA	{"email": "fomina_railya-1976@postgrespro.ru", "phone": "+70855704869"}
0005432566556	69B3DA	1494 208493	MARIYA GERASIMOVA	{"email": "gerasimova-m27061967@postgrespro.ru", "phone": "+70603352462"}
0005432566557	FDD69B	5551 142194	SERGEY IVANOV	{"phone": "+70876713863"}
0005432566558	53880A	3616 807788	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a_16071976@postgrespro.ru", "phone": "+70504035714"}
0005432566559	67AD73	0808 995247	MAKSIM ZAYCEV	{"email": "m.zaycev.1974@postgrespro.ru", "phone": "+70850301256"}
0005432566560	67AD73	4083 478741	ANDREY MOROZOV	{"phone": "+70525816794"}
0005432566561	4D3974	2955 212585	VENIAMIN NIKOLAEV	{"email": "nikolaev.veniamin-11031972@postgrespro.ru", "phone": "+70235781918"}
0005432566562	8B22B5	1599 426179	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov_011973@postgrespro.ru", "phone": "+70154746645"}
0005432566563	422735	5049 766526	EVGENIY NAZAROV	{"email": "e.nazarov-1972@postgrespro.ru", "phone": "+70944424355"}
0005432566564	BCB526	7612 306989	ILMIR GORBUNOV	{"phone": "+70141624018"}
0005432566565	BCB526	7868 059637	OLGA TIKHONOVA	{"phone": "+70085733474"}
0005432566566	B66C02	5747 309345	ALEKSEY SEMENOV	{"email": "semenov_aleksey.04061983@postgrespro.ru", "phone": "+70087912758"}
0005432566567	30836C	0743 370890	ALEKSANDR ZAKHAROV	{"phone": "+70323762126"}
0005432566568	79D6BA	5168 473650	VASILIY SIDOROV	{"email": "vsidorov_1965@postgrespro.ru", "phone": "+70915004617"}
0005432566569	79D6BA	3501 745252	ANNA EGOROVA	{"phone": "+70017177845"}
0005432566570	79D6BA	8953 073788	DARYA MAKSIMOVA	{"email": "d-maksimova_041971@postgrespro.ru", "phone": "+70277391566"}
0005432566571	9A26EF	5191 338638	NATALYA OVCHINNIKOVA	{"phone": "+70894080280"}
0005432566572	B882F3	1629 362479	ALEKSEY ORLOV	{"email": "orlov_aleksey01021965@postgrespro.ru", "phone": "+70328767123"}
0005432566573	E5D351	0491 190232	ANATOLIY ZAKHAROV	{"email": "zakharovanatoliy101967@postgrespro.ru", "phone": "+70161356913"}
0005432566574	E5D351	6018 689116	SERGEY VOROBEV	{"email": "vorobev-s.1976@postgrespro.ru", "phone": "+70550358698"}
0005432566575	FABDAD	9913 876959	SERGEY EGOROV	{"phone": "+70969302204"}
0005432566576	C17C2A	1614 607814	IRINA VLASOVA	{"email": "vlasovairina-121962@postgrespro.ru", "phone": "+70363550214"}
0005432566577	C28C28	4046 826545	ALEFTINA KRASNOVA	{"email": "krasnova_aleftina-29051977@postgrespro.ru", "phone": "+70898249275"}
0005432566578	353B9C	9031 510491	SVETLANA ORLOVA	{"email": "sorlova07081974@postgrespro.ru", "phone": "+70598581436"}
0005432566579	353B9C	9988 477610	VLADIMIR VOLKOV	{"phone": "+70606073289"}
0005432566580	AF1245	8901 468060	ANATOLIY GORBUNOV	{"email": "gorbunov-a-28051982@postgrespro.ru", "phone": "+70606964330"}
0005432566581	2FE726	9720 926808	VIKTORIYA SERGEEVA	{"email": "sergeeva.viktoriya.1977@postgrespro.ru", "phone": "+70151779572"}
0005432566582	FC5E52	0726 859451	OLEG NIKITIN	{"email": "olegnikitin1983@postgrespro.ru", "phone": "+70252316550"}
0005432566583	FC5E52	3669 200167	MARIYA MAKSIMOVA	{"email": "maksimovam.02121969@postgrespro.ru", "phone": "+70235588524"}
0005432566584	DF01C3	5220 529951	NIKOLAY GORBUNOV	{"phone": "+70459219668"}
0005432566585	DF01C3	4235 247837	VERA KUDRYASHOVA	{"email": "vera_kudryashova_071973@postgrespro.ru", "phone": "+70192252135"}
0005432566586	B64962	9715 166322	LYUDMILA KONDRATEVA	{"email": "kondrateva.l.1965@postgrespro.ru", "phone": "+70316538870"}
0005432566587	3412F5	4617 839991	YULIYA ZHURAVLEVA	{"email": "yzhuravleva1977@postgrespro.ru", "phone": "+70415672801"}
0005432566588	3412F5	4726 053076	NADEZHDA NIKOLAEVA	{"phone": "+70087425718"}
0005432566589	C9776C	4185 274212	SVETLANA YUDINA	{"email": "s.yudina1971@postgrespro.ru", "phone": "+70039657597"}
0005432566590	C9776C	4972 736510	SERGEY KARPOV	{"phone": "+70919191043"}
0005432566591	21ADED	4888 779832	LYUBOV MALYSHEVA	{"email": "lyubov_malysheva19111983@postgrespro.ru", "phone": "+70503329958"}
0005432566592	21ADED	9361 833953	VALENTINA MAKSIMOVA	{"phone": "+70096426703"}
0005432566593	365C86	0652 533623	IGOR SOLOVEV	{"phone": "+70060058123"}
0005432566594	A8BCA0	3348 358642	DMITRIY PAVLOV	{"phone": "+70420990174"}
0005432566595	301A12	5881 120325	ALBERT KUZNECOV	{"phone": "+70181374932"}
0005432566596	301A12	2563 566899	DMITRIY BONDARENKO	{"phone": "+70529997588"}
0005432566597	CABECA	5811 707626	TATYANA FROLOVA	{"email": "frolova.t-1966@postgrespro.ru", "phone": "+70483543175"}
0005432566598	FAF4A6	8002 395117	SVETLANA MOROZOVA	{"email": "morozovas.1962@postgrespro.ru", "phone": "+70403212263"}
0005432566599	45E239	7989 626991	YULIYA NESTEROVA	{"email": "yuliya-nesterova1981@postgrespro.ru", "phone": "+70974916130"}
0005432566600	45E239	7538 059998	NIKITA ZAKHAROV	{"email": "zakharov.n.111973@postgrespro.ru", "phone": "+70131488971"}
0005432566601	1E05A4	3977 685964	RAISA VOLKOVA	{"email": "r_volkova10061974@postgrespro.ru", "phone": "+70919984341"}
0005432566602	1E05A4	5463 191555	ALEKSEY CHERNOV	{"email": "chernov-a-051970@postgrespro.ru", "phone": "+70094632586"}
0005432566603	58E77D	7411 437633	OLGA MOROZOVA	{"email": "olga-morozova.1967@postgrespro.ru", "phone": "+70037402404"}
0005432566604	58E77D	1903 692600	ALEKSANDR ANDREEV	{"email": "a-andreev_1961@postgrespro.ru", "phone": "+70140777084"}
0005432566605	0B9D8E	9489 337008	ALEKSANDR KISELEV	{"email": "kiseleva-1964@postgrespro.ru", "phone": "+70599922572"}
0005432566606	0B9D8E	9429 033164	DANIIL KUZMIN	{"phone": "+70522503303"}
0005432566607	538B7B	8796 851876	GULNARA POPOVA	{"email": "gulnara.popova-08081971@postgrespro.ru", "phone": "+70648947885"}
0005432566608	538B7B	9836 232457	ARTEM PETROV	{"email": "petrov.artem_1973@postgrespro.ru", "phone": "+70540304647"}
0005432566609	4420D5	8448 080494	OLGA KUZNECOVA	{"email": "kuznecova-olga-1963@postgrespro.ru", "phone": "+70204640522"}
0005432566610	4420D5	8929 552714	KIRILL MAKAROV	{"email": "kmakarov13051977@postgrespro.ru", "phone": "+70566819232"}
0005432566611	4420D5	5469 667151	GENNADIY BARANOV	{"phone": "+70824147289"}
0005432566612	1BFE4D	7911 391224	TATYANA KOLESNIKOVA	{"email": "kolesnikova_t.1964@postgrespro.ru", "phone": "+70702725350"}
0005432566613	11B679	9573 135511	ELENA ROMANOVA	{"email": "e-romanova_091975@postgrespro.ru", "phone": "+70268554990"}
0005432566614	ACB300	5198 110576	NATALYA KOVALEVA	{"phone": "+70705847299"}
0005432566615	F8E96E	1204 470522	ALEKSANDR GERASIMOV	{"phone": "+70772928374"}
0005432566616	F8E96E	0554 274395	ILDAR MELNIKOV	{"email": "melnikov_i.23111993@postgrespro.ru", "phone": "+70645293754"}
0005432566617	2E8CFD	9490 303625	MARIYA SMIRNOVA	{"phone": "+70510643133"}
0005432566618	2E8CFD	2958 445346	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov-031968@postgrespro.ru", "phone": "+70975981749"}
0005432566619	4B828F	9179 327857	EGOR FILIPPOV	{"phone": "+70574000850"}
0005432566620	CE1EB2	2965 956433	VERA GUSEVA	{"phone": "+70708505361"}
0005432566621	CE1EB2	0884 681086	NATALYA STEPANOVA	{"phone": "+70417801335"}
0005432566622	0B2D3E	9151 906109	MARIYA POPOVA	{"phone": "+70625270449"}
0005432566623	F615BF	5361 251854	ELENA MIKHAYLOVA	{"phone": "+70997289537"}
0005432566624	131E7B	6394 436962	ANDREY YAKOVLEV	{"phone": "+70422778347"}
0005432566625	131E7B	2399 451747	NATALYA VLASOVA	{"email": "vlasova-natalya.071982@postgrespro.ru", "phone": "+70115241749"}
0005432566626	1C6C5A	7836 816647	NIKITA DENISOV	{"phone": "+70079829277"}
0005432566627	53A8C4	0455 604298	SERGEY SMIRNOV	{"email": "s.smirnov021977@postgrespro.ru", "phone": "+70391019623"}
0005432566628	592A3A	1439 905988	MIKHAIL TARASOV	{"email": "tarasovmikhail-15101978@postgrespro.ru", "phone": "+70156568319"}
0005432566629	D731C8	5395 758195	RAISA MAKSIMOVA	{"phone": "+70715984300"}
0005432566630	B73B9B	8143 757407	SERGEY BORISOV	{"email": "borisovsergey02091967@postgrespro.ru", "phone": "+70097927285"}
0005432566631	C8CEF8	8761 640137	DMITRIY MAKSIMOV	{"phone": "+70609978338"}
0005432566632	A70FD1	1997 923003	SERGEY ZHUKOV	{"phone": "+70002693690"}
0005432566633	A70FD1	7902 133441	ALEKSEY FEDOTOV	{"phone": "+70205127579"}
0005432566634	8CE7E9	6161 913653	ANATOLIY KRASNOV	{"phone": "+70566005036"}
0005432566635	165456	0832 338805	VALENTINA KARPOVA	{"phone": "+70328250920"}
0005432566636	D0454C	3136 643094	DMITRIY EGOROV	{"phone": "+70858345101"}
0005432566637	051B42	0460 312882	LYUDMILA ILINA	{"email": "l_ilina-1968@postgrespro.ru", "phone": "+70691127089"}
0005432566638	051B42	6199 878071	LYUBOV TARASOVA	{"email": "l-tarasova_031982@postgrespro.ru", "phone": "+70051151614"}
0005432566639	ADE14F	0302 911134	TATYANA POPOVA	{"phone": "+70866342387"}
0005432566640	E1B929	7417 881248	DARYA VOROBEVA	{"email": "dvorobeva-051974@postgrespro.ru", "phone": "+70375962562"}
0005432566641	E1B929	6536 939575	DMITRIY VOLKOV	{"email": "volkov.dmitriy.21121974@postgrespro.ru", "phone": "+70020489153"}
0005432566642	46169B	8108 258731	YULIYA LEBEDEVA	{"phone": "+70517567676"}
0005432566643	46169B	8861 717702	TATYANA KUZMINA	{"email": "kuzmina_tatyana25061978@postgrespro.ru", "phone": "+70062373112"}
0005432566644	DECB0A	7431 809451	NIKOLAY KOZLOV	{"email": "nkozlov.1981@postgrespro.ru", "phone": "+70678363277"}
0005432566645	13BEEE	9025 273289	MIKHAIL MAKSIMOV	{"email": "m_maksimov_1968@postgrespro.ru", "phone": "+70533117506"}
0005432566646	6F4A71	1818 413178	LYUDMILA KARPOVA	{"phone": "+70087687264"}
0005432566647	9C19C4	4652 140532	OLESYA POPOVA	{"phone": "+70824134999"}
0005432566648	9C19C4	1369 657920	SVETLANA GORBUNOVA	{"email": "svetlana.gorbunova.051976@postgrespro.ru", "phone": "+70172929796"}
0005432566649	C31323	6772 574300	ALEVTINA MELNIKOVA	{"email": "melnikova_alevtina_1977@postgrespro.ru", "phone": "+70197676920"}
0005432566650	C31323	7969 473624	DANILA SOROKIN	{"phone": "+70332618975"}
0005432566652	6B7435	0480 105945	DANIL STEPANOV	{"email": "stepanovd.011982@postgrespro.ru", "phone": "+70816598994"}
0005432566653	C2D944	4723 785131	OLGA GAVRILOVA	{"email": "o_gavrilova-101970@postgrespro.ru", "phone": "+70982151096"}
0005432566654	672860	9818 294928	IVAN ILIN	{"email": "ivan-ilin1965@postgrespro.ru", "phone": "+70242386138"}
0005432566655	40EB07	3768 015770	ELENA GRISHINA	{"phone": "+70549091055"}
0005432566656	E9E74D	2690 478337	TATYANA IVANOVA	{"email": "t.ivanova-1978@postgrespro.ru", "phone": "+70874463544"}
0005432566657	E9E74D	8655 526481	VIKTOR NOVIKOV	{"email": "viktor-novikov1970@postgrespro.ru", "phone": "+70293801369"}
0005432566658	3AD54E	0443 334614	ANASTASIYA FILIPPOVA	{"phone": "+70602899520"}
0005432566659	79C531	5581 756436	ALEKSANDR KONOVALOV	{"phone": "+70374577241"}
0005432566660	79C531	1869 775142	ALENA ISAEVA	{"email": "a.isaeva.041958@postgrespro.ru", "phone": "+70752402246"}
0005432566661	79C531	8714 712410	MARGARITA YAKOVLEVA	{"phone": "+70857257052"}
0005432566662	2B8FDB	9076 763372	SVETLANA ZAKHAROVA	{"phone": "+70417756347"}
0005432566663	B7F8DE	3864 200381	MARIYA NIKOLAEVA	{"email": "nikolaeva_mariya.101960@postgrespro.ru", "phone": "+70032078708"}
0005432566664	B90505	7806 152117	VALENTINA BELYAEVA	{"phone": "+70308274644"}
0005432566665	ED3A16	6171 815087	EKATERINA RODIONOVA	{"email": "e.rodionova_041961@postgrespro.ru", "phone": "+70526568211"}
0005432566666	ED3A16	4278 430294	RUSLAN MELNIKOV	{"email": "melnikovruslan.31081975@postgrespro.ru", "phone": "+70212208464"}
0005432566667	3DDCFE	9976 811207	YAKOV TIKHONOV	{"phone": "+70195518716"}
0005432566668	3DDCFE	4454 980928	SVETLANA MASLOVA	{"phone": "+70274468415"}
0005432566669	02F3B8	3605 527432	OLEG FEDOROV	{"email": "oleg_fedorov-1967@postgrespro.ru", "phone": "+70748619373"}
0005432566670	1A26F1	4464 723604	LYUBOV BARANOVA	{"email": "baranoval-04061958@postgrespro.ru", "phone": "+70506042520"}
0005432566671	1A26F1	0745 156018	MARGARITA LEBEDEVA	{"phone": "+70798486625"}
0005432566672	C974BF	9980 650185	DENIS NIKITIN	{"email": "nikitin.d07011964@postgrespro.ru", "phone": "+70516041486"}
0005432566673	C10C3B	0757 186791	OLGA IVANOVA	{"phone": "+70970266015"}
0005432566674	A41C57	9869 395016	VALENTINA IVANOVA	{"email": "ivanova-v_05111967@postgrespro.ru", "phone": "+70743489252"}
0005432566675	822317	0730 180926	YULIYA ANISIMOVA	{"phone": "+70153566093"}
0005432566676	822317	3651 888012	ANNA IVANOVA	{"email": "ivanova.anna-1980@postgrespro.ru", "phone": "+70650170124"}
0005432566677	6996F1	3611 300848	PAVEL MIRONOV	{"phone": "+70000294923"}
0005432566678	7AB485	6391 563767	EVGENIY FROLOV	{"phone": "+70207930223"}
0005432566679	7AB485	7420 203713	TATYANA ZOTOVA	{"email": "tatyanazotova_1976@postgrespro.ru", "phone": "+70093396085"}
0005432566680	DBE375	1027 126068	ALEKSANDR STEPANOV	{"phone": "+70354009394"}
0005432566681	FF060B	1179 372515	VALERIY PETROV	{"email": "valeriy_petrov-15031969@postgrespro.ru", "phone": "+70049982685"}
0005432566682	FF060B	7358 079162	RAISA KOZLOVA	{"phone": "+70431273025"}
0005432566683	FF060B	2988 834665	ARTUR KUZNECOV	{"email": "kuznecov.artur_1977@postgrespro.ru", "phone": "+70937979801"}
0005432566684	FF060B	8235 972478	LYUBOV ALEKSEEVA	{"email": "lyubov-alekseeva-05041979@postgrespro.ru", "phone": "+70886361114"}
0005432566685	5BD3CF	3599 884761	ARSENIY SERGEEV	{"phone": "+70589787537"}
0005432566686	C71A54	0667 094377	IVAN BELOV	{"email": "ivanbelov1967@postgrespro.ru", "phone": "+70940883600"}
0005432566687	DDBFE9	9623 506903	OLGA OSIPOVA	{"phone": "+70842938610"}
0005432566688	DDBFE9	1594 892881	ELENA IVANOVA	{"email": "eivanova.011971@postgrespro.ru", "phone": "+70120835591"}
0005432566689	5EFC71	9792 228042	LEONID MAKAROV	{"phone": "+70869896975"}
0005432566690	5EFC71	6695 789653	ANASTASIYA CHERNOVA	{"email": "achernova-29111978@postgrespro.ru", "phone": "+70479373263"}
0005432566691	696972	4814 495811	ALEKSANDR BONDARENKO	{"phone": "+70580006357"}
0005432566692	696972	6631 068308	MARINA SOROKINA	{"email": "sorokina-m1967@postgrespro.ru", "phone": "+70927736715"}
0005432566693	A1FDE8	7919 708060	OLGA KOROLEVA	{"phone": "+70062506148"}
0005432566694	A1FDE8	1500 402752	YULIYA KOZLOVA	{"phone": "+70327348106"}
0005432566695	A1FDE8	5557 276542	ELLA MIKHAYLOVA	{"email": "ella-mikhaylova-011972@postgrespro.ru", "phone": "+70941421737"}
0005432566696	AB7F3A	9801 302944	MARIYA SERGEEVA	{"phone": "+70563690506"}
0005432566697	A683ED	2106 315263	SVETLANA LAZAREVA	{"email": "svetlanalazareva1968@postgrespro.ru", "phone": "+70661103743"}
0005432566698	BED270	9909 903628	NADEZHDA CHERNOVA	{"phone": "+70727392863"}
0005432566699	BED270	1355 474152	DMITRIY KOZLOV	{"phone": "+70210106165"}
0005432566700	BED270	3293 215544	EVGENIY BELOV	{"phone": "+70888914073"}
0005432566701	BED270	2552 270511	VLADIMIR SIDOROV	{"email": "vladimir_sidorov_02081959@postgrespro.ru", "phone": "+70274982151"}
0005432566702	D52AEF	1004 112991	VLADIMIR KUZNECOV	{"email": "v.kuznecov121984@postgrespro.ru", "phone": "+70271118384"}
0005432566703	D52AEF	4708 058080	MARIYA IVANOVA	{"email": "m-ivanova-18101972@postgrespro.ru", "phone": "+70808645510"}
0005432566704	7C6613	5478 940721	LYUBOV KRASNOVA	{"email": "l-krasnova.23041970@postgrespro.ru", "phone": "+70294495824"}
0005432566705	6F90C9	9096 941031	ARTUR VASILEV	{"email": "vasilev_artur_1956@postgrespro.ru", "phone": "+70805408577"}
0005432566706	48DE4D	6454 731283	ALEKSEY SAVELEV	{"phone": "+70180230742"}
0005432566707	48DE4D	0890 744194	LYUDMILA LOGINOVA	{"email": "l-loginova_1972@postgrespro.ru", "phone": "+70806478374"}
0005432566708	A8D9AD	6986 827010	OLGA PAVLOVA	{"phone": "+70073863870"}
0005432566709	CB3624	3551 392093	MARYAM SIDOROVA	{"email": "sidorova-maryam_1981@postgrespro.ru", "phone": "+70740603756"}
0005432566710	CB3624	3785 782247	SVETLANA ALEKSANDROVA	{"email": "s_aleksandrova-1990@postgrespro.ru", "phone": "+70885316325"}
0005432566711	57CB65	6338 762448	LYUBOV BELOVA	{"phone": "+70655136082"}
0005432566712	FFC746	0451 070017	IVAN ISAEV	{"email": "i_isaev1978@postgrespro.ru", "phone": "+70880502868"}
0005432566713	96E006	0100 838727	OLESYA EGOROVA	{"email": "olesya-egorova1981@postgrespro.ru", "phone": "+70574161451"}
0005432566714	96E006	9363 602067	NADEZHDA MAKAROVA	{"email": "makarova_n.111965@postgrespro.ru", "phone": "+70553224517"}
0005432566715	763267	3348 634437	PETR POPOV	{"phone": "+70627307090"}
0005432566716	FE0CD9	8193 699101	ANASTASIYA KOROLEVA	{"phone": "+70313066933"}
0005432566717	553C1F	7646 813250	GALINA PAVLOVA	{"email": "pavlova.galina.1962@postgrespro.ru", "phone": "+70463328875"}
0005432566718	553C1F	5857 416537	VALERIY OSIPOV	{"email": "v-osipov_021976@postgrespro.ru", "phone": "+70354856689"}
0005432566719	1F5E6A	2965 753020	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova_17091975@postgrespro.ru", "phone": "+70443087714"}
0005432566720	55B0A6	8145 656680	TATYANA KULIKOVA	{"email": "kulikovat_1979@postgrespro.ru", "phone": "+70765758115"}
0005432566721	551E36	5141 607876	SERGEY GERASIMOV	{"phone": "+70313011146"}
0005432566722	895237	3183 524678	LYUDMILA ANTONOVA	{"phone": "+70861376035"}
0005432566723	A1B18E	0186 546078	SERGEY SAVELEV	{"email": "savelevs-1979@postgrespro.ru", "phone": "+70685003987"}
0005432566724	49FAF7	9148 761489	ANATOLIY PAVLOV	{"email": "pavlov.a-111975@postgrespro.ru", "phone": "+70659573292"}
0005432566725	03E7BF	9401 746302	DENIS DENISOV	{"phone": "+70729386874"}
0005432566726	11E4F6	7598 058784	OLGA KOMAROVA	{"email": "komarova-olga.071984@postgrespro.ru", "phone": "+70232631363"}
0005432566727	08E637	2400 796316	NATALYA MIKHAYLOVA	{"phone": "+70250952419"}
0005432566728	B4C732	3465 102016	GALINA ZHUKOVA	{"phone": "+70772657740"}
0005432566729	D1AFE2	1082 649625	LILIYA GUSEVA	{"email": "guseva_l_1963@postgrespro.ru", "phone": "+70046895655"}
0005432566730	D1AFE2	2686 283894	ALEKSANDR NIKOLAEV	{"phone": "+70996350781"}
0005432566731	CF52AC	4912 047149	SERGEY KOROLEV	{"phone": "+70652461571"}
0005432566732	601510	5151 305652	TATYANA MOROZOVA	{"phone": "+70225775298"}
0005432566733	601510	6113 228273	VALENTINA IVANOVA	{"phone": "+70957225123"}
0005432566734	DCFA71	5929 177239	ELENA BORISOVA	{"email": "elena-borisova041960@postgrespro.ru", "phone": "+70082654819"}
0005432566735	4262E1	6052 951028	SERGEY STEPANOV	{"email": "s.stepanov_1970@postgrespro.ru", "phone": "+70228543883"}
0005432566736	D9D77D	4176 534680	VALENTINA TIMOFEEVA	{"phone": "+70948450789"}
0005432566737	D3E164	1056 880409	SVETLANA VASILEVA	{"phone": "+70023617072"}
0005432566738	D3E164	2660 155943	ANATOLIY TIMOFEEV	{"phone": "+70396546225"}
0005432566739	130BAD	9632 254593	VALENTINA KONDRATEVA	{"phone": "+70968637374"}
0005432566740	130BAD	3089 193860	GENNADIY YAKOVLEV	{"email": "yakovlev-gennadiy-101963@postgrespro.ru", "phone": "+70223186740"}
0005432566741	7495A4	8878 081447	SVETLANA MAKAROVA	{"phone": "+70858953985"}
0005432566742	7495A4	7023 515887	SERGEY MAKSIMOV	{"email": "sergeymaksimov.04051970@postgrespro.ru", "phone": "+70652101541"}
0005432566743	94C1AB	1592 376963	VIKTOR YAKOVLEV	{"phone": "+70329282929"}
0005432566744	597866	3606 650783	ALEKSANDR KULIKOV	{"phone": "+70148450189"}
0005432566745	B6354F	5601 094467	MAKSIM PAVLOV	{"phone": "+70354937167"}
0005432566746	B6354F	6467 616297	NADEZHDA KUZMINA	{"email": "kuzmina_n_091967@postgrespro.ru", "phone": "+70457544747"}
0005432566747	49E1E1	8753 090168	GULNARA CHERNOVA	{"phone": "+70167020743"}
0005432566748	49E1E1	7489 520773	DENIS ALEKSEEV	{"email": "denis_alekseev.21011963@postgrespro.ru", "phone": "+70497496950"}
0005432566749	5CCF2F	0737 293929	NADEZHDA TIMOFEEVA	{"phone": "+70851097747"}
0005432566750	C842F0	9875 476950	VIKTOR ALEKSEEV	{"email": "alekseev-viktor-1955@postgrespro.ru", "phone": "+70912158115"}
0005432566751	357FE9	2321 318250	MARINA PAVLOVA	{"phone": "+70063912833"}
0005432566752	357FE9	9194 934724	MIKHAIL MELNIKOV	{"email": "melnikov-mikhail-27071986@postgrespro.ru", "phone": "+70081043520"}
0005432566753	28D253	9916 256773	ANNA SCHERBAKOVA	{"phone": "+70789262816"}
0005432566754	28D253	8077 395501	FEDOR FROLOV	{"email": "frolov-fedor_1974@postgrespro.ru", "phone": "+70464621527"}
0005432566755	FE4C72	0844 893737	EKATERINA ZOTOVA	{"email": "ekaterinazotova_1963@postgrespro.ru", "phone": "+70598057331"}
0005432566756	99C890	7150 702727	ZINAIDA SCHERBAKOVA	{"email": "z.scherbakova071970@postgrespro.ru", "phone": "+70896275734"}
0005432566757	8470DA	6071 015960	VLADISLAV EGOROV	{"phone": "+70937705254"}
0005432566758	556158	8510 544795	VIKTORIYA NIKITINA	{"email": "v-nikitina.1952@postgrespro.ru", "phone": "+70287222193"}
0005432566759	556158	1220 219153	TAMARA KUZNECOVA	{"phone": "+70411087933"}
0005432566760	01A549	9355 735320	ALEKSANDR BARANOV	{"phone": "+70196975440"}
0005432566761	01A549	4354 663101	OLGA GAVRILOVA	{"email": "gavrilova_o.23111967@postgrespro.ru", "phone": "+70623115369"}
0005432566762	F86CD9	3330 084449	SERGEY KUZNECOV	{"phone": "+70186543967"}
0005432566763	2BEB89	1853 002547	LYUBOV KOMAROVA	{"email": "komarova-l081960@postgrespro.ru", "phone": "+70903927030"}
0005432566764	025163	3581 258186	SERGEY SOKOLOV	{"email": "s_sokolov.021978@postgrespro.ru", "phone": "+70638820408"}
0005432566765	025163	7805 993861	VALERIY TARASOV	{"email": "valeriy_tarasov.091971@postgrespro.ru", "phone": "+70802871902"}
0005432566766	C340C2	0105 051572	MARIYA SMIRNOVA	{"phone": "+70289409421"}
0005432566767	E532B8	9018 264793	ALEKSANDR ZAYCEV	{"phone": "+70877706886"}
0005432566768	E532B8	6718 505084	YURIY ALEKSANDROV	{"email": "aleksandrov.y-02021976@postgrespro.ru", "phone": "+70063994423"}
0005432566769	A03C19	4628 190357	EKATERINA IVANOVA	{"email": "ivanova.ekaterina-1968@postgrespro.ru", "phone": "+70349442839"}
0005432566770	A03C19	4146 569758	MIKHAIL POPOV	{"email": "mikhailpopov_1967@postgrespro.ru", "phone": "+70951265374"}
0005432566771	50653F	8298 297635	OLGA LUKYANOVA	{"phone": "+70409248983"}
0005432566772	AF30B9	8868 215612	ALEKSANDR KUZNECOV	{"email": "akuznecov_081960@postgrespro.ru", "phone": "+70088456619"}
0005432566773	730B4C	2391 023633	TATYANA GAVRILOVA	{"phone": "+70193861336"}
0005432566774	0181EB	9018 876798	KLAVDIYA MASLOVA	{"phone": "+70982196663"}
0005432566775	53722D	6364 247067	NADEZHDA BELYAEVA	{"email": "belyaevan-1984@postgrespro.ru", "phone": "+70659067218"}
0005432566776	100607	8514 906746	SVETLANA FROLOVA	{"email": "frolovas121969@postgrespro.ru", "phone": "+70842023978"}
0005432566777	898186	3148 835100	FARIDA TIKHONOVA	{"phone": "+70196692080"}
0005432566778	DF9152	3371 250320	VIKTOR FROLOV	{"phone": "+70516596784"}
0005432566779	7CE4A7	8188 084653	OLGA EFREMOVA	{"phone": "+70314251513"}
0005432566947	DB0C95	1645 717570	TATYANA SCHERBAKOVA	{"phone": "+70777669802"}
0005432566780	D4AD65	2253 014929	RAISA GUSEVA	{"email": "guseva.raisa-21101987@postgrespro.ru", "phone": "+70095134528"}
0005432566781	42B264	2051 809562	NIKOLAY RODIONOV	{"phone": "+70391956805"}
0005432566782	94455B	0226 787102	ELENA EGOROVA	{"phone": "+70393358588"}
0005432566783	94455B	8693 409718	ELVIRA BELOVA	{"phone": "+70187486722"}
0005432566784	0AFB45	5020 987770	SERGEY KUZMIN	{"phone": "+70910311412"}
0005432566785	B14CDE	7233 125649	OLGA VOROBEVA	{"email": "vorobeva-olga.26081976@postgrespro.ru", "phone": "+70102249302"}
0005432566786	667DF3	1820 008605	EKATERINA ALEKSANDROVA	{"phone": "+70971886354"}
0005432566787	667DF3	6364 366365	IRINA BELOVA	{"phone": "+70140384739"}
0005432566788	08A500	9625 316206	IVAN OSIPOV	{"email": "osipov.i-1982@postgrespro.ru", "phone": "+70521459521"}
0005432566789	438E86	7834 203939	MARIYA NAZAROVA	{"phone": "+70897698488"}
0005432566790	2A0281	0901 140855	TATYANA KUZMINA	{"email": "kuzminatatyana1964@postgrespro.ru", "phone": "+70227152748"}
0005432566791	2A0281	9106 710304	VARVARA GUSEVA	{"email": "gusevavarvara-17081966@postgrespro.ru", "phone": "+70514750775"}
0005432566792	2A0281	2084 952045	VALENTINA MIRONOVA	{"phone": "+70869461377"}
0005432566793	3D99F3	7476 238203	DMITRIY POPOV	{"email": "dmitriy-popov.1973@postgrespro.ru", "phone": "+70735342622"}
0005432566794	67F08A	2511 014748	TATYANA KUZMINA	{"email": "kuzmina-t1966@postgrespro.ru", "phone": "+70862522215"}
0005432566795	C9C141	9500 266424	ELVIRA MIRONOVA	{"phone": "+70121079302"}
0005432566796	540BB0	4823 302629	ELENA TARASOVA	{"phone": "+70558891703"}
0005432566797	540BB0	4880 042553	IVAN NOVIKOV	{"email": "ivan.novikov061972@postgrespro.ru", "phone": "+70861813635"}
0005432566798	367A4B	6573 035192	OLGA TIKHONOVA	{"email": "otikhonova-011975@postgrespro.ru", "phone": "+70728791079"}
0005432566799	9BFA20	6480 194945	IDA DMITRIEVA	{"phone": "+70708713190"}
0005432566800	9BFA20	3010 034345	VLADIMIR KOROLEV	{"email": "korolevvladimir.091974@postgrespro.ru", "phone": "+70906810664"}
0005432566801	CC3FEE	2208 438728	OLGA BOGDANOVA	{"phone": "+70282341982"}
0005432566802	CC3FEE	4904 900763	MARINA FOMINA	{"email": "fominam_1966@postgrespro.ru", "phone": "+70026694350"}
0005432566803	7EDB63	5480 788381	LEONID FEDOTOV	{"phone": "+70392750985"}
0005432566804	7EDB63	6600 680791	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva-041981@postgrespro.ru", "phone": "+70576268045"}
0005432566805	7EDB63	9303 781565	OKSANA ZAKHAROVA	{"phone": "+70758444057"}
0005432566806	8C04AE	9872 620083	LIDIYA YUDINA	{"phone": "+70106412143"}
0005432566807	AD838F	7717 201460	ANDREY GUSEV	{"email": "gusevandrey-041970@postgrespro.ru", "phone": "+70592084522"}
0005432566808	A2C863	8850 969425	GENNADIY NOVIKOV	{"phone": "+70934213404"}
0005432566809	21EAF3	9753 476461	ELENA ROMANOVA	{"phone": "+70585342905"}
0005432566810	FB8E8A	8839 038168	EVA ISAEVA	{"phone": "+70599438591"}
0005432566811	FB8E8A	3435 688451	PAVEL DAVYDOV	{"phone": "+70961732536"}
0005432566812	42A159	1159 671713	OLESYA MIKHAYLOVA	{"email": "olesya_mikhaylova-031968@postgrespro.ru", "phone": "+70560892378"}
0005432566813	BC1866	5211 483247	VASILIY BARANOV	{"phone": "+70940084731"}
0005432566814	BC1866	1898 602853	OKSANA KOVALEVA	{"phone": "+70576574558"}
0005432566815	7636C5	8264 578817	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr.05011983@postgrespro.ru", "phone": "+70201351207"}
0005432566816	EBD4BE	8994 946374	LYUDMILA FILIPPOVA	{"phone": "+70474524371"}
0005432566817	F7A3A6	9964 124704	LILIYA RYABOVA	{"email": "ryabova-l_20031970@postgrespro.ru", "phone": "+70289806490"}
0005432566818	F7A3A6	2746 815396	OLGA KUZMINA	{"email": "kuzmina_olga031971@postgrespro.ru", "phone": "+70360121531"}
0005432566819	2A6B90	8677 016388	GRIGORIY PETROV	{"phone": "+70013723011"}
0005432566820	B3E8AC	5613 195543	OLGA MAKAROVA	{"email": "o-makarova1965@postgrespro.ru", "phone": "+70804805086"}
0005432566821	B18443	4661 801584	DARYA BORISOVA	{"email": "daryaborisova.111962@postgrespro.ru", "phone": "+70832062286"}
0005432566822	C9BB74	5751 427071	DMITRIY ORLOV	{"email": "dmitriy-orlov_1973@postgrespro.ru", "phone": "+70864144150"}
0005432566823	3E4141	4814 705453	DMITRIY GUSEV	{"phone": "+70234551167"}
0005432566824	3E4141	5546 902067	NADEZHDA MEDVEDEVA	{"email": "nadezhda.medvedeva.041964@postgrespro.ru", "phone": "+70915909752"}
0005432566825	3E4141	3521 700617	ANATOLIY ILIN	{"email": "ilin_anatoliy-1976@postgrespro.ru", "phone": "+70169241297"}
0005432566826	8D4BFA	9029 538269	OLEG KULIKOV	{"phone": "+70982527359"}
0005432566827	8077DA	1785 246758	EVGENIY MARTYNOV	{"email": "emartynov17031970@postgrespro.ru", "phone": "+70328503150"}
0005432566828	D701C5	1522 642360	NATALYA BOGDANOVA	{"email": "bogdanova-n27101973@postgrespro.ru", "phone": "+70381304068"}
0005432566829	D701C5	3513 867858	SERGEY RODIONOV	{"email": "sergeyrodionov-111977@postgrespro.ru", "phone": "+70660339967"}
0005432566830	D9EFA1	2082 821598	MARIYA YAKOVLEVA	{"email": "mariya-yakovleva-011973@postgrespro.ru", "phone": "+70026187432"}
0005432566831	CCF7A7	7249 181122	EKATERINA PAVLOVA	{"email": "pavlova.ekaterina19101973@postgrespro.ru", "phone": "+70268376648"}
0005432566832	736216	7183 202113	VERA ANISIMOVA	{"phone": "+70993205507"}
0005432566833	E8EEEB	8570 295930	ARTUR BORISOV	{"email": "borisov_artur10081973@postgrespro.ru", "phone": "+70064527473"}
0005432566834	5A1CB6	4354 244915	NIKOLAY KUZNECOV	{"phone": "+70765945955"}
0005432566835	941FFA	7293 036902	DARYA MAKSIMOVA	{"phone": "+70357246223"}
0005432566836	941FFA	9586 964182	DARYA GUSEVA	{"email": "darya-guseva.1966@postgrespro.ru", "phone": "+70189657918"}
0005432566837	941FFA	6146 100271	DMITRIY DAVYDOV	{"phone": "+70881584679"}
0005432566838	1FF3AB	5894 180501	NATALYA MIRONOVA	{"phone": "+70931795321"}
0005432566839	896F70	0552 068689	TATYANA ABRAMOVA	{"phone": "+70806466866"}
0005432566840	EB0548	0385 130464	NINA MAKAROVA	{"phone": "+70513462862"}
0005432566841	0DD3CF	1504 980318	ANDREY IVANOV	{"email": "ivanova-1983@postgrespro.ru", "phone": "+70395190802"}
0005432566842	B67772	1058 703017	MIKHAIL VASILEV	{"phone": "+70569139106"}
0005432566843	7734F6	0618 506146	ZINAIDA OSIPOVA	{"email": "zinaida.osipova-051963@postgrespro.ru", "phone": "+70530642719"}
0005432566844	014EC8	2026 846362	LIDIYA SMIRNOVA	{"email": "lidiyasmirnova-1970@postgrespro.ru", "phone": "+70998620953"}
0005432566845	014EC8	4334 499224	ALEKSEY MIRONOV	{"phone": "+70432316232"}
0005432566846	014EC8	7086 849246	MARINA KOROLEVA	{"email": "koroleva_m-30061968@postgrespro.ru", "phone": "+70637240543"}
0005432566847	2A4C94	4682 545604	MIKHAIL KONOVALOV	{"email": "mikhail-konovalov-23071971@postgrespro.ru", "phone": "+70587945356"}
0005432566848	74DA2F	2075 631599	SERGEY CHERNOV	{"phone": "+70924871352"}
0005432566849	1208D1	5222 520651	ALINA SMIRNOVA	{"phone": "+70874524151"}
0005432566850	1208D1	6323 907817	DENIS STEPANOV	{"phone": "+70180910879"}
0005432566851	313E0C	7098 212700	NIKOLAY AFANASEV	{"phone": "+70005998981"}
0005432566852	2B5F51	6253 937605	MARAT RODIONOV	{"email": "maratrodionov_081966@postgrespro.ru", "phone": "+70035883969"}
0005432566853	B77E38	8023 315960	GRIGORIY ZHURAVLEV	{"phone": "+70096020447"}
0005432566854	B77E38	3011 857268	DMITRIY KARPOV	{"email": "karpovdmitriy111969@postgrespro.ru", "phone": "+70279530943"}
0005432566855	EDEEAB	1497 007021	MARIYA LUKYANOVA	{"phone": "+70283271108"}
0005432566856	CB4082	4420 436635	VERONIKA KAZAKOVA	{"email": "v_kazakova.1965@postgrespro.ru", "phone": "+70614796218"}
0005432566857	CDE95B	0130 758099	SVETLANA SCHERBAKOVA	{"phone": "+70296747778"}
0005432566858	63ECB0	1472 027772	VYACHESLAV MOISEEV	{"email": "moiseev.vyacheslav.1984@postgrespro.ru", "phone": "+70015768416"}
0005432566859	22FA7C	5562 816448	IGOR FILIPPOV	{"email": "filippovigor11031969@postgrespro.ru", "phone": "+70353993215"}
0005432566860	C7172E	7075 506705	TATYANA NIKITINA	{"email": "tatyananikitina.25091980@postgrespro.ru", "phone": "+70851023494"}
0005432566861	C7172E	3950 693439	ANNA ZAYCEVA	{"email": "anna_zayceva_21051978@postgrespro.ru", "phone": "+70600822136"}
0005432566862	63FFE3	3384 560688	TATYANA ZHURAVLEVA	{"email": "t.zhuravleva-09071980@postgrespro.ru", "phone": "+70858148554"}
0005432566863	E82622	0474 806452	YURIY ALEKSEEV	{"phone": "+70343658429"}
0005432566864	1011FF	3449 542851	ALEKSEY SOKOLOV	{"email": "a_sokolov_03011970@postgrespro.ru", "phone": "+70729375501"}
0005432566865	263522	0556 470829	VALERIY KUZMIN	{"email": "kuzmin_v-05061972@postgrespro.ru", "phone": "+70427254818"}
0005432566866	C4F0BA	0353 086529	ALEKSEY ISAEV	{"phone": "+70805927391"}
0005432566867	F99AA2	0799 189656	EVGENIY MAKAROV	{"email": "makarov.e031976@postgrespro.ru", "phone": "+70302662413"}
0005432566868	612854	4880 098153	VLADIMIR MAKAROV	{"email": "makarovv061979@postgrespro.ru", "phone": "+70560959631"}
0005432566869	0E10E9	3607 978121	LYUBOV AKIMOVA	{"email": "akimova-l_111982@postgrespro.ru", "phone": "+70896712698"}
0005432566870	0E10E9	1989 915112	YULIYA ANISIMOVA	{"phone": "+70138812977"}
0005432566871	98AC46	4402 885157	ALLA EFIMOVA	{"email": "efimovaalla1982@postgrespro.ru", "phone": "+70791276498"}
0005432566872	E48A2F	8366 997053	DENIS FROLOV	{"phone": "+70081330433"}
0005432566873	E48A2F	8059 583578	ARKADIY MIRONOV	{"email": "a-mironov_1974@postgrespro.ru", "phone": "+70691619643"}
0005432566874	EC668D	3791 515179	GALINA KOVALEVA	{"email": "galina-kovaleva121985@postgrespro.ru", "phone": "+70875774600"}
0005432566875	EC668D	3752 675978	LIDIYA KOZLOVA	{"phone": "+70481160685"}
0005432566876	AC7B14	4774 206023	DIANA SOKOLOVA	{"phone": "+70622077127"}
0005432566877	F5496F	1693 450695	YURIY DAVYDOV	{"phone": "+70967763785"}
0005432566878	D66FCD	8059 109032	VLADIMIR IVANOV	{"phone": "+70840363450"}
0005432566879	58DB4E	7797 523588	OLGA NIKITINA	{"phone": "+70177373177"}
0005432566880	757E55	5731 394289	MIKHAIL ZHURAVLEV	{"phone": "+70506111817"}
0005432566881	A03A1A	2786 978615	ALEKSEY ISAEV	{"phone": "+70945002237"}
0005432566882	A03A1A	8769 512892	ANTON KAZAKOV	{"phone": "+70259410401"}
0005432566883	455715	4323 454750	RINAT ANDREEV	{"email": "andreev.rinat14111972@postgrespro.ru", "phone": "+70132140302"}
0005432566884	289F29	4534 596144	EVDOKIYA BARANOVA	{"phone": "+70654183990"}
0005432566885	289F29	0794 320888	EKATERINA KUZNECOVA	{"email": "ekaterina_kuznecova-02091985@postgrespro.ru", "phone": "+70102241197"}
0005432566886	D78076	0174 422302	IVAN KUZNECOV	{"email": "ikuznecov1984@postgrespro.ru", "phone": "+70229173675"}
0005432566887	6111CE	7791 071228	NATALYA SIDOROVA	{"email": "sidorovanatalya.23051961@postgrespro.ru", "phone": "+70999254165"}
0005432566888	6111CE	9698 795507	ALEKSEY SCHERBAKOV	{"phone": "+70779480090"}
0005432566889	6111CE	0260 135132	SVETLANA KUZNECOVA	{"phone": "+70084809588"}
0005432566890	A00CBC	8035 157427	LYUBOV LAZAREVA	{"phone": "+70477958869"}
0005432566891	48070E	0173 666047	ANATOLIY KARPOV	{"phone": "+70691711397"}
0005432566948	DB0C95	0349 050546	MAKSIM KRASNOV	{"phone": "+70496067686"}
0005432566892	48070E	4002 186705	GALINA POPOVA	{"email": "g.popova.27121976@postgrespro.ru", "phone": "+70167219598"}
0005432566893	C272EA	8971 582360	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov.08061969@postgrespro.ru", "phone": "+70935533063"}
0005432566894	EF971A	6295 584175	ARINA MAKSIMOVA	{"email": "amaksimova-1963@postgrespro.ru", "phone": "+70724725584"}
0005432566895	61054D	9703 235926	TIMOFEY TARASOV	{"phone": "+70289436138"}
0005432566896	61054D	7199 270434	ILYA DENISOV	{"email": "i_denisov.23111969@postgrespro.ru", "phone": "+70263464737"}
0005432566897	297FE1	1645 636521	NATALIYA KUZMINA	{"email": "kuzmina.n_111983@postgrespro.ru", "phone": "+70906537672"}
0005432566898	297FE1	3117 673077	MIKHAIL IVANOV	{"email": "ivanov_m17021981@postgrespro.ru", "phone": "+70957131158"}
0005432566899	80470E	2505 175539	VIKTOR MOROZOV	{"phone": "+70242001888"}
0005432566900	80470E	8060 558814	LYUDMILA PAVLOVA	{"email": "pavlova_lyudmila.071980@postgrespro.ru", "phone": "+70845104564"}
0005432566901	965CC0	2949 411854	OLGA ANDREEVA	{"phone": "+70797062836"}
0005432566902	965CC0	5620 027330	DENIS MARTYNOV	{"email": "d-martynov_1971@postgrespro.ru", "phone": "+70176483588"}
0005432566903	965CC0	4820 332574	EGOR FEDOROV	{"email": "fedorovegor111983@postgrespro.ru", "phone": "+70572048694"}
0005432566904	E2F261	1155 193956	ELENA BELYAEVA	{"phone": "+70694428923"}
0005432566905	904749	9607 479524	ALEKSANDRA ZAKHAROVA	{"email": "zakharova.aleksandra-16101970@postgrespro.ru", "phone": "+70858891370"}
0005432566906	CC734B	5757 397087	ARSENIY BORISOV	{"phone": "+70349047467"}
0005432566907	CC734B	5377 153990	NATALYA VLASOVA	{"phone": "+70747285915"}
0005432566908	EE0503	5523 260454	MIKHAIL VLASOV	{"email": "mikhail-vlasov071964@postgrespro.ru", "phone": "+70676024861"}
0005432566909	110DBC	2558 670290	TATYANA TARASOVA	{"email": "tarasova_tatyana_1980@postgrespro.ru", "phone": "+70942775197"}
0005432566910	D5AFA8	9675 563596	ARSENIY MIRONOV	{"email": "a_mironov-041979@postgrespro.ru", "phone": "+70017174096"}
0005432566911	19D6D0	1158 832796	VLADIMIR MOROZOV	{"email": "morozov-vladimir-1982@postgrespro.ru", "phone": "+70175759905"}
0005432566912	EF69AA	8968 983126	EVDOKIYA VOLKOVA	{"email": "evdokiya_volkova051976@postgrespro.ru", "phone": "+70820439763"}
0005432566913	9E1C26	8202 847998	ANASTASIYA RODIONOVA	{"phone": "+70735773343"}
0005432566914	9E1C26	6497 296942	ALEKSANDR ZAKHAROV	{"phone": "+70032469302"}
0005432566915	9E1C26	7442 643673	MARINA ZOTOVA	{"email": "marinazotova_1977@postgrespro.ru", "phone": "+70308326378"}
0005432566916	BA2733	3116 721567	VALERIY KUZNECOV	{"email": "kuznecov.valeriy.1973@postgrespro.ru", "phone": "+70939726681"}
0005432566917	BA2733	7327 222882	PAVEL BARANOV	{"email": "baranov.pavel17101965@postgrespro.ru", "phone": "+70380266576"}
0005432566918	7D242F	4201 325330	SVETLANA BORISOVA	{"phone": "+70450097575"}
0005432566919	7D242F	6619 738310	VITALIY MAKAROV	{"phone": "+70184045612"}
0005432566920	954E72	8905 753669	YURIY KAZAKOV	{"email": "kazakovyuriy.1972@postgrespro.ru", "phone": "+70067630591"}
0005432566921	954E72	2766 569780	YULIYA YUDINA	{"phone": "+70693422671"}
0005432566922	B971EF	4664 740854	LYUBOV IVANOVA	{"email": "ivanova_lyubov-10041968@postgrespro.ru", "phone": "+70380818502"}
0005432566923	48496F	3010 275189	GALINA KRASNOVA	{"email": "g_krasnova.031963@postgrespro.ru", "phone": "+70028777570"}
0005432566924	48496F	7571 221561	ANATOLIY SMIRNOV	{"phone": "+70757844652"}
0005432566925	FE0865	6512 874541	NATALYA NIKITINA	{"phone": "+70772167765"}
0005432566926	F2BB54	3562 683991	LYUCIYA FROLOVA	{"email": "lyuciya.frolova1979@postgrespro.ru", "phone": "+70146159843"}
0005432566927	F2BB54	7905 558587	NINA IVANOVA	{"email": "nina_ivanova_1966@postgrespro.ru", "phone": "+70886100583"}
0005432566928	F2BB54	1605 979296	ANATOLIY CHERNOV	{"phone": "+70237579101"}
0005432566929	20713E	5041 850460	SERGEY MOISEEV	{"email": "smoiseev_021978@postgrespro.ru", "phone": "+70852615416"}
0005432566930	20713E	2770 738083	VADIM PETROV	{"phone": "+70267394749"}
0005432566931	566E27	6269 921751	LYUBOV FILATOVA	{"email": "lyubov.filatova-071977@postgrespro.ru", "phone": "+70076055563"}
0005432566932	3BB6B4	2018 592794	ANDREY KUZNECOV	{"email": "a_kuznecov.30051972@postgrespro.ru", "phone": "+70854492362"}
0005432566933	589E5D	3036 333618	MIKHAIL MOROZOV	{"phone": "+70705046927"}
0005432566934	589E5D	3315 928590	VIKTOR KULIKOV	{"email": "viktor-kulikov_23061969@postgrespro.ru", "phone": "+70208801115"}
0005432566935	D063DD	6061 032986	ANATOLIY GAVRILOV	{"email": "gavrilov.a011971@postgrespro.ru", "phone": "+70446082722"}
0005432566936	D063DD	0533 799097	TATYANA BOGDANOVA	{"phone": "+70461623695"}
0005432566937	56704C	9580 184940	IVAN ALEKSEEV	{"email": "i_alekseev.1969@postgrespro.ru", "phone": "+70240399510"}
0005432566938	C45C6E	3912 628023	GALINA FROLOVA	{"phone": "+70475998648"}
0005432566939	C45C6E	9655 688092	DMITRIY PETROV	{"email": "petrov.dmitriy.061992@postgrespro.ru", "phone": "+70811251185"}
0005432566940	3EB026	6152 828560	ILDAR SOKOLOV	{"phone": "+70421259695"}
0005432566941	798BBD	0321 639040	VALENTINA KUZNECOVA	{"email": "v-kuznecova.1971@postgrespro.ru", "phone": "+70912994412"}
0005432566942	BA7E61	2050 043885	ILYA KOROLEV	{"email": "ilya.korolev_1964@postgrespro.ru", "phone": "+70549533639"}
0005432566943	BA7E61	9907 954514	MIKHAIL KAZAKOV	{"email": "kazakov_m_1957@postgrespro.ru", "phone": "+70034809781"}
0005432566944	DD6896	8174 093219	ANDREY MAKAROV	{"phone": "+70881228103"}
0005432566945	0E0BAB	9452 566477	ANATOLIY SOROKIN	{"email": "sorokin_anatoliy.16051965@postgrespro.ru", "phone": "+70829086433"}
0005432566946	0E0BAB	9855 858401	EVGENIY KULIKOV	{"email": "kulikove.16101973@postgrespro.ru", "phone": "+70132493402"}
0005432566949	DB0C95	7855 171363	MARINA NIKIFOROVA	{"phone": "+70221902001"}
0005432566950	CFF833	9891 137215	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr_111964@postgrespro.ru", "phone": "+70976616702"}
0005432566951	ED0A95	9862 182440	ALEKSEY PAVLOV	{"phone": "+70770861321"}
0005432566952	A51F81	8632 190862	SERGEY ROMANOV	{"phone": "+70474360701"}
0005432566953	8BBF7B	9599 760093	GEORGIY MAKSIMOV	{"email": "georgiy-maksimov-1964@postgrespro.ru", "phone": "+70363970497"}
0005432566954	F371DD	0399 555950	ALEKSEY GRIGOREV	{"email": "grigorev_a.08071981@postgrespro.ru", "phone": "+70973170079"}
0005432566955	83F6D5	9148 632864	MIKHAIL MEDVEDEV	{"phone": "+70974062311"}
0005432566956	5C1311	4663 946856	ANDREY KONOVALOV	{"email": "a-konovalov_26101973@postgrespro.ru", "phone": "+70378314055"}
0005432566957	5C1311	8013 982098	DMITRIY NAUMOV	{"email": "naumov.dmitriy_101974@postgrespro.ru", "phone": "+70407671142"}
0005432566958	5C1311	3230 162980	ALEKSANDR DAVYDOV	{"phone": "+70633647108"}
0005432566959	A2D0C2	8212 009500	VASILIY MARTYNOV	{"email": "martynov_v14121966@postgrespro.ru", "phone": "+70020397360"}
0005432566960	5D2F5E	3220 457571	ELENA ROMANOVA	{"email": "elena-romanova_04091989@postgrespro.ru", "phone": "+70092522065"}
0005432566961	2A4D54	4598 161973	ELIZAVETA KAZAKOVA	{"email": "e_kazakova_1965@postgrespro.ru", "phone": "+70341991210"}
0005432566962	632C31	5921 490678	ELENA FOMINA	{"email": "fomina-e-10041971@postgrespro.ru", "phone": "+70160223851"}
0005432566963	632C31	9072 499587	DMITRIY MOROZOV	{"email": "morozov.dmitriy1967@postgrespro.ru", "phone": "+70039726989"}
0005432566964	4A271E	3614 774928	TATYANA LAZAREVA	{"phone": "+70794589641"}
0005432566965	38FF46	9064 372789	SERGEY MAKAROV	{"email": "s_makarov021972@postgrespro.ru", "phone": "+70405948449"}
0005432566966	7F805D	2806 691750	TATYANA NIKITINA	{"email": "t-nikitina1978@postgrespro.ru", "phone": "+70388937154"}
0005432566967	AF15AB	6681 286211	ANDREY KARPOV	{"email": "karpov-a-10061968@postgrespro.ru", "phone": "+70379565981"}
0005432566968	17D765	5289 687031	NIKOLAY FROLOV	{"phone": "+70400448470"}
0005432566969	7D9731	1845 006467	VALENTINA IVANOVA	{"phone": "+70495217674"}
0005432566970	71127B	3646 201110	ELENA STEPANOVA	{"email": "stepanova-elena.101976@postgrespro.ru", "phone": "+70360963349"}
0005432566971	71127B	6583 290120	VALENTINA ANTONOVA	{"email": "vantonova-031977@postgrespro.ru", "phone": "+70061483419"}
0005432566972	163940	1212 213356	ANNA ERMAKOVA	{"email": "aermakova.1976@postgrespro.ru", "phone": "+70848808507"}
0005432566973	0D2F49	6611 582744	DMITRIY DAVYDOV	{"email": "dmitriy-davydov05061977@postgrespro.ru", "phone": "+70702564892"}
0005432566974	9E3E47	4730 947305	SERGEY KONOVALOV	{"email": "konovalovsergey051983@postgrespro.ru", "phone": "+70869986590"}
0005432566975	9E3E47	2351 523153	LIDIYA SERGEEVA	{"phone": "+70619719270"}
0005432566976	DA6F3B	0068 322295	ALEKSEY ZHURAVLEV	{"email": "zhuravlev.aleksey.111971@postgrespro.ru", "phone": "+70066737666"}
0005432566977	DD7ECD	9524 921052	VLADIMIR KUDRYASHOV	{"email": "v.kudryashov-23051970@postgrespro.ru", "phone": "+70567061472"}
0005432566978	3B7F66	4244 467603	VARVARA SMIRNOVA	{"email": "smirnova-varvara-1971@postgrespro.ru", "phone": "+70461195669"}
0005432566979	4D7715	0576 038807	VIKTORIYA KOROLEVA	{"email": "viktoriya-koroleva-1973@postgrespro.ru", "phone": "+70087733684"}
0005432566980	4D7715	6455 720323	DMITRIY ZAYCEV	{"email": "zaycev.dmitriy-1972@postgrespro.ru", "phone": "+70290725596"}
0005432566981	8D17C9	6988 128259	ANDREY KUZNECOV	{"phone": "+70076678085"}
0005432566982	ED6AE4	7353 379188	GALINA ZHUKOVA	{"email": "zhukova-g.041972@postgrespro.ru", "phone": "+70838994505"}
0005432566983	DF35A8	0382 932187	KRISTINA GAVRILOVA	{"email": "gavrilovakristina_1974@postgrespro.ru", "phone": "+70216332926"}
0005432566984	38D2D1	5968 827710	ANDREY FILIPPOV	{"phone": "+70150857074"}
0005432566985	38D2D1	5155 563882	VIKTOR KRASNOV	{"email": "krasnov_viktor-15051979@postgrespro.ru", "phone": "+70938169487"}
0005432566986	D7764E	5155 963214	ANNA POPOVA	{"phone": "+70182126859"}
0005432566987	79B7A1	1666 335786	MIKHAIL KUZNECOV	{"phone": "+70549516457"}
0005432566988	43D18F	6088 940864	TATYANA EGOROVA	{"email": "egorovat-081975@postgrespro.ru", "phone": "+70124322234"}
0005432566989	8BB772	7891 832957	ELENA NIKITINA	{"phone": "+70967462029"}
0005432566990	214201	9774 862008	ELENA KUZMINA	{"email": "kuzminaelena_24031968@postgrespro.ru", "phone": "+70593684062"}
0005432566991	214201	9169 480356	ALINA MOISEEVA	{"phone": "+70305114997"}
0005432566992	7DE8F5	6487 492738	YULIYA ISAEVA	{"phone": "+70341120652"}
0005432566993	7DE8F5	5616 858706	ALEKSEY SHEVCHENKO	{"phone": "+70935179491"}
0005432566994	E42563	9937 235862	NINA YAKOVLEVA	{"phone": "+70823721576"}
0005432566995	69A2DB	2283 465234	SVETLANA MOROZOVA	{"email": "svetlana_morozova.1979@postgrespro.ru", "phone": "+70453563068"}
0005432566996	69A2DB	2653 599391	VALENTINA MASLOVA	{"phone": "+70280084276"}
0005432566997	82A7B1	0531 139869	VLADIMIR BORISOV	{"phone": "+70792067930"}
0005432566998	82A7B1	6003 481866	TATYANA ABRAMOVA	{"email": "tabramova.16081967@postgrespro.ru", "phone": "+70900402586"}
0005432566999	86CCDA	6771 551900	NINA PETROVA	{"email": "petrova.n-091975@postgrespro.ru", "phone": "+70883067303"}
0005432567000	A0C104	2831 334826	VALENTINA SEMENOVA	{"phone": "+70093449311"}
0005432567001	561BA6	7137 618152	NATALYA NIKIFOROVA	{"phone": "+70061187135"}
0005432567002	097940	0280 204047	ANASTASIYA ALEKSEEVA	{"phone": "+70304649289"}
0005432567003	9E70CD	1492 285379	RUSLAN GORBUNOV	{"email": "ruslan-gorbunov-021969@postgrespro.ru", "phone": "+70952635722"}
0005432567004	256409	9559 249065	PETR ANDREEV	{"email": "pandreev.051964@postgrespro.ru", "phone": "+70787499011"}
0005432567005	754B43	7550 202925	VLADIMIR SOKOLOV	{"phone": "+70057000098"}
0005432567006	B9A7CA	0177 968011	ALISA VASILEVA	{"email": "vasileva-a.121967@postgrespro.ru", "phone": "+70236073210"}
0005432567007	B9A7CA	4041 963598	TATYANA SERGEEVA	{"email": "sergeeva_tatyana.20041973@postgrespro.ru", "phone": "+70477179817"}
0005432567008	A2FBDA	3588 053842	ZINAIDA SMIRNOVA	{"email": "smirnova_zinaida1967@postgrespro.ru", "phone": "+70034028998"}
0005432567009	A2FBDA	2476 319111	ELENA NAZAROVA	{"email": "nazarova.e.021971@postgrespro.ru", "phone": "+70913622215"}
0005432567129	E3D1C8	6155 284012	TATYANA ALEKSEEVA	{"phone": "+70915225233"}
0005432567010	65E6F3	0487 982190	TATYANA IVANOVA	{"email": "ivanovatatyana.08031960@postgrespro.ru", "phone": "+70613244262"}
0005432567011	4E023C	4798 863452	VIKTOR KUZMIN	{"phone": "+70820345225"}
0005432567012	68EF1C	6653 609892	NADEZHDA NIKITINA	{"phone": "+70534822466"}
0005432567013	E1E51C	6592 601534	RUSTEM ORLOV	{"email": "rustem.orlov_10071959@postgrespro.ru", "phone": "+70829705545"}
0005432567014	3A6096	0556 719130	OLESYA IVANOVA	{"phone": "+70505494036"}
0005432567015	3A6096	3578 030142	SERGEY TIKHONOV	{"email": "tikhonov.s1978@postgrespro.ru", "phone": "+70937753000"}
0005432567016	B5DD74	3010 559945	LILIYA MARTYNOVA	{"email": "martynova-l081982@postgrespro.ru", "phone": "+70573772695"}
0005432567017	EFEC9D	6896 488879	ZOYA SERGEEVA	{"email": "sergeeva_z021980@postgrespro.ru", "phone": "+70894625601"}
0005432567018	EFEC9D	1290 967210	ANTON SERGEEV	{"email": "sergeev-anton-1966@postgrespro.ru", "phone": "+70084619426"}
0005432567019	DD1034	4246 503471	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila-081977@postgrespro.ru", "phone": "+70814519170"}
0005432567020	B07349	9753 532648	ALEKSANDR NAUMOV	{"email": "a.naumov02061979@postgrespro.ru", "phone": "+70221108900"}
0005432567021	1D1392	4432 075748	VLADIMIR KUZNECOV	{"email": "vkuznecov_1966@postgrespro.ru", "phone": "+70131984559"}
0005432567022	E4EF37	2506 826317	ANATOLIY SHEVCHENKO	{"phone": "+70856168058"}
0005432567023	5E1061	6464 407449	TATYANA VASILEVA	{"email": "tatyana.vasileva_14101974@postgrespro.ru", "phone": "+70466334471"}
0005432567024	5E1061	3342 219584	YURIY KUZNECOV	{"phone": "+70073111873"}
0005432567025	E7F98A	8787 509865	MAKSIM KUZNECOV	{"phone": "+70637004803"}
0005432567026	C9CFB0	2600 602702	PAVEL KUDRYASHOV	{"email": "kudryashov_pavel-1984@postgrespro.ru", "phone": "+70421247580"}
0005432567027	5D3875	8833 870642	DMITRIY KOZLOV	{"email": "d.kozlov.1972@postgrespro.ru", "phone": "+70296034317"}
0005432567028	9B9616	4354 281288	ELIZAVETA EGOROVA	{"phone": "+70604353043"}
0005432567029	339C51	6820 093904	IGOR TARASOV	{"phone": "+70491068721"}
0005432567030	339C51	5494 695002	SEMEN VOLKOV	{"email": "volkov.s.24051963@postgrespro.ru", "phone": "+70490784493"}
0005432567031	CD1638	6745 135964	EKATERINA SAVELEVA	{"email": "saveleva-e.10011975@postgrespro.ru", "phone": "+70743659702"}
0005432567032	40DB1F	7608 762389	VALENTINA ARKHIPOVA	{"email": "arkhipova-valentina.051967@postgrespro.ru", "phone": "+70502745640"}
0005432567033	507496	4561 489325	IGOR SOROKIN	{"phone": "+70711289225"}
0005432567034	3D7BAF	8894 203311	ROMAN ZHURAVLEV	{"phone": "+70444622338"}
0005432567035	3D7BAF	3581 381674	EVGENIY NAZAROV	{"email": "enazarov1981@postgrespro.ru", "phone": "+70953470063"}
0005432567036	383F9F	8261 427151	ARTEM SEMENOV	{"email": "semenov_artem-1977@postgrespro.ru", "phone": "+70497044145"}
0005432567037	2674EE	0951 204348	ELENA KUZMINA	{"email": "kuzmina-e_011977@postgrespro.ru", "phone": "+70572698805"}
0005432567038	F1B682	4388 108145	YURIY NAUMOV	{"phone": "+70213097871"}
0005432567039	099836	2681 008769	YULIYA TARASOVA	{"phone": "+70788432174"}
0005432567040	91AE1D	2477 541021	ALEKSANDR ANDREEV	{"phone": "+70273608560"}
0005432567041	57F30C	3768 139098	VLADIMIR ABRAMOV	{"phone": "+70872140103"}
0005432567042	3F59AA	0386 497412	MAKSIM TIMOFEEV	{"email": "timofeev-maksim-04111980@postgrespro.ru", "phone": "+70746169834"}
0005432567043	711BDA	2732 443514	NIKOLAY AFANASEV	{"phone": "+70874152369"}
0005432567044	5ACBE6	7051 824617	ELENA FILIPPOVA	{"email": "e.filippova-22051968@postgrespro.ru", "phone": "+70927582334"}
0005432567045	EA8D77	4830 821356	ALEKSANDR EGOROV	{"email": "egorov.a_021970@postgrespro.ru", "phone": "+70024021333"}
0005432567046	BA57DE	1961 623906	RIMMA MAKSIMOVA	{"phone": "+70919892919"}
0005432567047	BA57DE	5276 032281	SANIYA KOVALEVA	{"phone": "+70443498255"}
0005432567048	18DD9A	5774 273196	SERGEY PETROV	{"email": "sergeypetrov-1971@postgrespro.ru", "phone": "+70805178158"}
0005432567049	C7069A	0844 180928	NIKOLAY VOLKOV	{"email": "n.volkov_011979@postgrespro.ru", "phone": "+70799508982"}
0005432567050	808F7C	5031 902557	ANDREY GRIGOREV	{"email": "andrey-grigorev.1978@postgrespro.ru", "phone": "+70401693491"}
0005432567051	384003	3994 944669	ELENA DANILOVA	{"phone": "+70969848400"}
0005432567052	384003	3201 160559	YULIYA PETROVA	{"phone": "+70996042185"}
0005432567053	6FA4A7	2992 394377	KONSTANTIN ZHURAVLEV	{"email": "konstantin.zhuravlev-061972@postgrespro.ru", "phone": "+70975070010"}
0005432567054	3251EE	3554 122115	SVETLANA ABRAMOVA	{"email": "sabramova-1966@postgrespro.ru", "phone": "+70726549318"}
0005432567055	CFC2C0	6541 979456	MIKHAIL KONOVALOV	{"phone": "+70457485233"}
0005432567056	4E7839	0403 264234	VIKTOR KULIKOV	{"phone": "+70608520539"}
0005432567057	7A00E8	6676 873956	TAMARA POPOVA	{"phone": "+70065496394"}
0005432567058	7A00E8	1327 728678	ARINA VASILEVA	{"email": "vasileva.a_23041964@postgrespro.ru", "phone": "+70250205431"}
0005432567059	7B7F6B	2080 725341	ALEKSEY KUZNECOV	{"phone": "+70792070810"}
0005432567060	7B7F6B	5562 248442	GALINA SAVELEVA	{"email": "saveleva.g.1968@postgrespro.ru", "phone": "+70969560633"}
0005432567061	40E4DD	4659 614177	SERGEY KUZMIN	{"phone": "+70103987934"}
0005432567062	14753A	5309 752303	MARIYA KUDRYASHOVA	{"email": "kudryashova.mariya-03051971@postgrespro.ru", "phone": "+70603638715"}
0005432567063	14753A	6917 505000	YULIYA ZAYCEVA	{"email": "zaycevay_09031974@postgrespro.ru", "phone": "+70100710434"}
0005432567064	2C82AE	2632 053886	ALEKSANDR TARASOV	{"phone": "+70339013689"}
0005432567065	22A155	2138 095410	EVGENIY SOROKIN	{"phone": "+70869572581"}
0005432567066	22A155	3422 875408	EKATERINA BORISOVA	{"phone": "+70947941413"}
0005432567067	B261E0	2234 019970	ELENA AFANASEVA	{"email": "afanaseva-e1970@postgrespro.ru", "phone": "+70752303635"}
0005432567068	B261E0	0717 956704	ALESYA VASILEVA	{"email": "alesyavasileva_1967@postgrespro.ru", "phone": "+70558168251"}
0005432567069	22090D	5632 734691	TATYANA ABRAMOVA	{"email": "abramova_tatyana_101974@postgrespro.ru", "phone": "+70517378508"}
0005432567070	22090D	7982 439485	TATYANA IVANOVA	{"phone": "+70365116896"}
0005432567071	305D38	7746 326800	RAISA FOMINA	{"email": "fomina_r-111972@postgrespro.ru", "phone": "+70138142392"}
0005432567072	677EB6	6336 604692	VALENTINA STEPANOVA	{"email": "stepanova-valentina-25061966@postgrespro.ru", "phone": "+70105008835"}
0005432567073	070177	5330 742916	VLADIMIR VOLKOV	{"email": "v_volkov_1963@postgrespro.ru", "phone": "+70969421628"}
0005432567074	A9E5A1	4174 345743	RIMMA POPOVA	{"email": "r-popova.05111973@postgrespro.ru", "phone": "+70711712884"}
0005432567075	A9AE1D	0331 142337	VLADIMIR ORLOV	{"email": "vladimir-orlov111971@postgrespro.ru", "phone": "+70607582970"}
0005432567076	A9AE1D	3242 818944	ELENA TIMOFEEVA	{"email": "elena.timofeeva011973@postgrespro.ru", "phone": "+70406244497"}
0005432567077	44D4D2	9469 058403	ALEKSANDR PAVLOV	{"phone": "+70559535630"}
0005432567078	4A8976	1952 906750	VLADIMIR GORBUNOV	{"phone": "+70752350255"}
0005432567079	6C8741	1799 693781	NATALYA ABRAMOVA	{"email": "abramova_natalya-081972@postgrespro.ru", "phone": "+70157208218"}
0005432567080	6C8741	1405 296269	NIKOLAY TARASOV	{"phone": "+70013176461"}
0005432567081	6C8741	1010 540493	BULAT KRASNOV	{"email": "bkrasnov1974@postgrespro.ru", "phone": "+70204675617"}
0005432567082	9F25D9	0672 045210	PAVEL ORLOV	{"phone": "+70446759693"}
0005432567083	23BDD4	8463 695932	DMITRIY KAZAKOV	{"phone": "+70719737645"}
0005432567084	1B3417	9280 075315	ARINA EFIMOVA	{"phone": "+70163842406"}
0005432567085	F342D6	6162 517983	ELIZAVETA GRISHINA	{"email": "elizaveta_grishina_01071968@postgrespro.ru", "phone": "+70455032953"}
0005432567086	4B7A7B	6994 215729	YURIY FROLOV	{"phone": "+70139141301"}
0005432567087	A1E4BB	9765 390567	KLAVDIYA SEMENOVA	{"phone": "+70235419927"}
0005432567088	F7CE7E	4096 111388	DMITRIY AFANASEV	{"email": "afanasev.dmitriy-061967@postgrespro.ru", "phone": "+70394969469"}
0005432567089	D0ED14	2977 623547	ANNA IVANOVA	{"phone": "+70486786712"}
0005432567090	27B44D	1854 474300	LYUBOV SIDOROVA	{"email": "l-sidorova-031964@postgrespro.ru", "phone": "+70258692429"}
0005432567091	1302C7	2378 584011	YURIY VOLKOV	{"email": "yvolkov22021970@postgrespro.ru", "phone": "+70588233963"}
0005432567092	D41F88	2905 799190	ZULFIYA GORBUNOVA	{"email": "z.gorbunova.031982@postgrespro.ru", "phone": "+70612844233"}
0005432567093	304F65	5934 448509	NATALYA ANDREEVA	{"email": "andreeva_n.1969@postgrespro.ru", "phone": "+70213788096"}
0005432567094	7E98DB	2966 689602	ANDREY SOKOLOV	{"phone": "+70938711688"}
0005432567095	CBD992	2317 403764	RAUZA MAKSIMOVA	{"email": "rmaksimova_1981@postgrespro.ru", "phone": "+70634987534"}
0005432567096	B62C6C	1278 987996	DMITRIY VOROBEV	{"email": "vorobev_d_1961@postgrespro.ru", "phone": "+70347702829"}
0005432567097	C4C12A	2017 615005	ALEKSANDR MOROZOV	{"phone": "+70386269218"}
0005432567098	C4C12A	5887 980958	NIKITA BELOV	{"email": "belov_nikita.051967@postgrespro.ru", "phone": "+70999733016"}
0005432567099	36537D	7411 447306	EVGENIYA BELOVA	{"email": "e-belova27041978@postgrespro.ru", "phone": "+70838117098"}
0005432567100	36537D	4899 738416	MIKHAIL SIDOROV	{"email": "sidorov.mikhail1969@postgrespro.ru", "phone": "+70144395353"}
0005432567101	B96EB5	5485 205560	PAVEL ANDREEV	{"email": "pavel_andreev_1979@postgrespro.ru", "phone": "+70461099735"}
0005432567102	B96EB5	9425 899591	ANATOLIY SOROKIN	{"email": "sorokin.a-1962@postgrespro.ru", "phone": "+70405402498"}
0005432567103	EF01FF	8996 911793	ARTEM EGOROV	{"phone": "+70367092261"}
0005432567104	EF01FF	6204 245138	ALEKSEY SERGEEV	{"email": "aleksey_sergeev_1973@postgrespro.ru", "phone": "+70353889893"}
0005432567105	CA0902	6243 968750	OLGA POTAPOVA	{"phone": "+70341495084"}
0005432567106	AD8E94	5465 791034	LIDIYA RODIONOVA	{"phone": "+70017705800"}
0005432567107	AD8E94	0430 946088	ALEKSEY TARASOV	{"email": "a-tarasov-101976@postgrespro.ru", "phone": "+70628544884"}
0005432567108	897994	5087 021699	DANILA MATVEEV	{"phone": "+70915002539"}
0005432567109	214190	9742 888763	VYACHESLAV ZAKHAROV	{"phone": "+70044095873"}
0005432567110	C40762	0056 265082	ANATOLIY BELOV	{"email": "belova-1978@postgrespro.ru", "phone": "+70910030543"}
0005432567111	C40762	8837 711846	VALENTINA ZAKHAROVA	{"email": "v_zakharova-1977@postgrespro.ru", "phone": "+70125147062"}
0005432567112	47941D	4601 624522	LYUBOV FILIPPOVA	{"phone": "+70612746207"}
0005432567113	A37DF9	7303 393265	ANASTASIYA PETROVA	{"phone": "+70076589885"}
0005432567114	B35796	9864 972948	MIKHAIL GRIGOREV	{"phone": "+70741725414"}
0005432567115	4C4CE5	9705 830299	VLADIMIR KUZMIN	{"phone": "+70374057586"}
0005432567116	4C4CE5	2236 673532	NATALYA MELNIKOVA	{"phone": "+70948567260"}
0005432567117	4C4CE5	8778 989512	ANDREY MOROZOV	{"email": "a-morozov-121965@postgrespro.ru", "phone": "+70003303625"}
0005432567118	5972C0	0120 876486	VYACHESLAV VASILEV	{"email": "v-vasilev_011984@postgrespro.ru", "phone": "+70848168841"}
0005432567119	5972C0	3562 323939	YURIY FEDOTOV	{"phone": "+70444741708"}
0005432567120	3E07D2	7384 299408	VERA KUZMINA	{"phone": "+70486358178"}
0005432567121	3E07D2	8372 803627	DMITRIY MARTYNOV	{"phone": "+70351800455"}
0005432567122	7B85FB	8412 913078	MIKHAIL SIDOROV	{"email": "m-sidorov-16041971@postgrespro.ru", "phone": "+70448075073"}
0005432567123	7B37AD	5535 941535	OLEG KUZNECOV	{"email": "o.kuznecov1969@postgrespro.ru", "phone": "+70921043626"}
0005432567124	1BB585	3981 538901	VALENTINA SOROKINA	{"email": "v.sorokina-1970@postgrespro.ru", "phone": "+70691898572"}
0005432567125	1371A5	2302 941349	YULIYA VLASOVA	{"phone": "+70489263102"}
0005432567126	E5A08C	9963 898018	VIKTOR MAKSIMOV	{"phone": "+70701037999"}
0005432567127	76D6C1	6812 033571	TATYANA ANISIMOVA	{"phone": "+70990425436"}
0005432567128	9AA0B3	8382 424164	OLEG POPOV	{"email": "popov-oleg08051972@postgrespro.ru", "phone": "+70765650152"}
0005432567130	E3D1C8	7297 846934	ANATOLIY KULIKOV	{"email": "kulikov.anatoliy041980@postgrespro.ru", "phone": "+70004421745"}
0005432567131	822396	2307 559308	DMITRIY SIDOROV	{"email": "dmitriysidorov_1973@postgrespro.ru", "phone": "+70145992522"}
0005432567132	822396	0142 089690	ALENA CHERNOVA	{"phone": "+70351630144"}
0005432567133	857384	6573 201203	IRINA YUDINA	{"email": "yudina-i_1976@postgrespro.ru", "phone": "+70684898939"}
0005432567134	F99533	7165 486338	IVAN SERGEEV	{"email": "sergeev_i-1971@postgrespro.ru", "phone": "+70914732359"}
0005432567135	A95EC1	7088 291502	NINA TARASOVA	{"email": "nina.tarasova.1969@postgrespro.ru", "phone": "+70651313652"}
0005432567136	A95EC1	5570 891292	VLADIMIR KARPOV	{"email": "karpov-vladimir_1970@postgrespro.ru", "phone": "+70054625816"}
0005432567137	DAC40E	3796 490437	ELENA RODIONOVA	{"email": "e.rodionova-051975@postgrespro.ru", "phone": "+70785669655"}
0005432567138	C6A7DA	3909 833765	INNA POPOVA	{"phone": "+70271414916"}
0005432567139	C6A7DA	6432 846397	DMITRIY ABRAMOV	{"phone": "+70351840784"}
0005432567140	84B508	7329 968028	ANASTASIYA NAZAROVA	{"phone": "+70885921933"}
0005432567141	84B508	9892 609353	SERGEY SHEVCHENKO	{"phone": "+70647348287"}
0005432567142	EA8D4C	5465 718735	YAROSLAV KOROLEV	{"phone": "+70305439571"}
0005432567143	EA8D4C	7428 656891	ANATOLIY ZAKHAROV	{"email": "a-zakharov051982@postgrespro.ru", "phone": "+70815087610"}
0005432567144	A8DCFB	3650 511047	NATALYA RODIONOVA	{"email": "rodionova_natalya_041966@postgrespro.ru", "phone": "+70610138339"}
0005432567145	A971E9	4112 423882	VIKTOR POPOV	{"email": "v_popov.26041979@postgrespro.ru", "phone": "+70683125521"}
0005432567146	84A43F	2113 520510	LYUBOV BORISOVA	{"email": "borisova-l-21111965@postgrespro.ru", "phone": "+70447336390"}
0005432567147	2F1CD2	2106 335667	IRINA NAUMOVA	{"email": "inaumova_1966@postgrespro.ru", "phone": "+70526207532"}
0005432567148	BA0B91	7406 077941	LYUBOV KUZMINA	{"email": "kuzmina-l_27121972@postgrespro.ru", "phone": "+70936263221"}
0005432567149	98EC1F	6906 510408	NIKOLAY KAZAKOV	{"phone": "+70528880089"}
0005432567150	9D2F0F	5166 732528	YANA TITOVA	{"email": "y_titova_07111969@postgrespro.ru", "phone": "+70317328409"}
0005432567151	9D2F0F	8378 825624	YURIY NAUMOV	{"phone": "+70910049625"}
0005432567152	9D2F0F	0854 718931	SERGEY MAKAROV	{"email": "smakarov-01031968@postgrespro.ru", "phone": "+70377179513"}
0005432567153	44AAEC	5362 098119	ROMAN SCHERBAKOV	{"email": "scherbakov.roman041982@postgrespro.ru", "phone": "+70098422691"}
0005432567154	A3D9A6	8844 547783	NATALYA KOLESNIKOVA	{"email": "natalya.kolesnikova.15051966@postgrespro.ru", "phone": "+70738899160"}
0005432567155	E3BEB0	4644 914542	EVGENIYA KISELEVA	{"phone": "+70157210179"}
0005432567156	E3BEB0	2446 445105	ANNA MAKSIMOVA	{"phone": "+70275419819"}
0005432567157	F4963F	9469 666164	VADIM GAVRILOV	{"email": "v_gavrilov_22071981@postgrespro.ru", "phone": "+70917436144"}
0005432567158	6CA443	2415 399821	TATYANA KUZMINA	{"email": "kuzminatatyana-1976@postgrespro.ru", "phone": "+70954443703"}
0005432567159	C4C306	4607 856788	VLADIMIR EGOROV	{"phone": "+70656981851"}
0005432567160	13B368	4968 170777	LARISA NESTEROVA	{"phone": "+70719231238"}
0005432567161	13B368	1746 219155	NINA NAZAROVA	{"email": "nazarova-n1971@postgrespro.ru", "phone": "+70052341948"}
0005432567162	490F2C	7072 110397	NADEZHDA KISELEVA	{"phone": "+70946732937"}
0005432567163	D72198	0487 653254	ALEKSEY MIKHAYLOV	{"email": "mikhaylova.1968@postgrespro.ru", "phone": "+70120310073"}
0005432567164	95610C	1231 525042	YURIY MOROZOV	{"phone": "+70156542751"}
0005432567165	F1E3A4	5136 522879	ALEKSEY ZHURAVLEV	{"email": "aleksey-zhuravlev-1970@postgrespro.ru", "phone": "+70535195479"}
0005432567166	B8E0C0	7566 551676	GALINA TITOVA	{"email": "g.titova-20031964@postgrespro.ru", "phone": "+70906548026"}
0005432567167	49B466	5932 102807	ZOYA OVCHINNIKOVA	{"phone": "+70586325551"}
0005432567168	49B466	8187 227663	EDUARD DAVYDOV	{"email": "davydov.e-08101966@postgrespro.ru", "phone": "+70104096735"}
0005432567169	49B466	1356 081837	DMITRIY TIMOFEEV	{"email": "timofeev-d13091976@postgrespro.ru", "phone": "+70000922474"}
0005432567170	8F7F6B	0532 022062	VALERIY ZAKHAROV	{"email": "v-zakharov.061981@postgrespro.ru", "phone": "+70971926919"}
0005432567171	41ADAC	3909 674278	ARTEM KRASNOV	{"email": "krasnov.a041971@postgrespro.ru", "phone": "+70993746222"}
0005432567172	66EC75	8598 845770	ALEFTINA STEPANOVA	{"email": "stepanova_aleftina_061977@postgrespro.ru", "phone": "+70120521023"}
0005432567173	F94386	5782 374315	ALEKSANDR POPOV	{"phone": "+70233435941"}
0005432567174	6A8EE3	8492 193662	VIKTOR GRIGOREV	{"phone": "+70093252936"}
0005432567175	551100	5740 416241	YULIYA GRISHINA	{"phone": "+70071167625"}
0005432567176	CFA597	3559 520617	ALFIYA KOMAROVA	{"email": "komarova.a-1976@postgrespro.ru", "phone": "+70942803509"}
0005432567177	92EC3B	3371 127296	KSENIYA KONDRATEVA	{"phone": "+70726963557"}
0005432567178	F7E204	6770 357957	ARINA ALEKSEEVA	{"phone": "+70312651397"}
0005432567179	F7E204	3782 344449	ILDAR ZAKHAROV	{"email": "zakharovi-061981@postgrespro.ru", "phone": "+70248110541"}
0005432567180	BBFA94	8606 813408	ALEKSEY BORISOV	{"phone": "+70622299372"}
0005432567181	111F8E	7912 476575	PETR SOKOLOV	{"email": "p.sokolov.22081977@postgrespro.ru", "phone": "+70888442870"}
0005432567182	111F8E	7588 136504	DMITRIY GRIGOREV	{"email": "grigorev_dmitriy-07021982@postgrespro.ru", "phone": "+70590122320"}
0005432567183	4F08E2	7560 986230	SERGEY POPOV	{"email": "popov_sergey03021964@postgrespro.ru", "phone": "+70197265962"}
0005432567184	A697B7	2232 994342	VALENTINA LEBEDEVA	{"phone": "+70233320938"}
0005432567185	A697B7	4486 500970	TATYANA ROMANOVA	{"email": "romanova_tatyana14031968@postgrespro.ru", "phone": "+70792154772"}
0005432567186	6213E9	7010 878501	ELENA ZOTOVA	{"phone": "+70869171728"}
0005432567187	16F0EF	5211 684915	KIRILL ZHUKOV	{"email": "kirill.zhukov_13121970@postgrespro.ru", "phone": "+70451015140"}
0005432567544	9D7B12	9434 133286	ALEKSANDR POPOV	{"phone": "+70797539514"}
0005432567188	36F362	0106 009001	LYUBOV BELYAEVA	{"email": "belyaeva_l_121971@postgrespro.ru", "phone": "+70906415374"}
0005432567189	F73D85	7198 899609	DMITRIY TIMOFEEV	{"phone": "+70851330538"}
0005432567190	E87B9A	5747 167599	EVGENIYA OSIPOVA	{"phone": "+70028634951"}
0005432567191	94602E	7870 766506	NIKOLAY ALEKSANDROV	{"phone": "+70376053638"}
0005432567192	94602E	0150 522132	ANTON PETROV	{"email": "antonpetrov_1976@postgrespro.ru", "phone": "+70800250458"}
0005432567193	95D63C	6333 862535	VADIM SERGEEV	{"phone": "+70997944517"}
0005432567194	95D63C	2760 036035	EKATERINA EFREMOVA	{"phone": "+70269064263"}
0005432567195	7B5C51	6557 300228	DANILA RODIONOV	{"email": "d-rodionov_15051976@postgrespro.ru", "phone": "+70909929481"}
0005432567196	CF4107	3957 613041	OLGA KOVALEVA	{"email": "kovalevaolga-1964@postgrespro.ru", "phone": "+70708696779"}
0005432567197	CB244F	7079 564727	RUSTEM VOLKOV	{"phone": "+70909135065"}
0005432567198	2E9728	9753 787458	LARISA POPOVA	{"email": "popova.larisa_101973@postgrespro.ru", "phone": "+70578586005"}
0005432567199	8C59F4	8307 382360	ARSENIY GERASIMOV	{"phone": "+70575184776"}
0005432567200	8C59F4	2040 736041	DARYA PAVLOVA	{"phone": "+70657266227"}
0005432567201	8EC48E	7056 702898	LYUDMILA MOISEEVA	{"email": "moiseeva.l-03111977@postgrespro.ru", "phone": "+70591338743"}
0005432567202	7468B1	4661 601944	TATYANA LEBEDEVA	{"phone": "+70744040674"}
0005432567203	CE17C5	5155 248025	VALENTIN IVANOV	{"email": "v_ivanov.021979@postgrespro.ru", "phone": "+70042128112"}
0005432567204	CE17C5	8266 304362	VERONIKA VASILEVA	{"email": "veronikavasileva_13091966@postgrespro.ru", "phone": "+70095339944"}
0005432567205	0702C7	4123 606159	GALINA BARANOVA	{"phone": "+70096639729"}
0005432567206	9DA6CB	2106 880352	ALEKSEY KOZLOV	{"email": "kozlov.a.1973@postgrespro.ru", "phone": "+70457396851"}
0005432567207	9DA6CB	8259 713202	LIYA BARANOVA	{"phone": "+70511273435"}
0005432567208	268E22	0788 856246	ANATOLIY TIKHONOV	{"phone": "+70072676457"}
0005432567209	7F521E	0460 852024	DMITRIY SHEVCHENKO	{"email": "dshevchenko-1974@postgrespro.ru", "phone": "+70579908207"}
0005432567210	A0D9E9	9574 078872	ZINAIDA EGOROVA	{"phone": "+70256571989"}
0005432567211	A0D9E9	0816 652605	YULIYA TITOVA	{"phone": "+70042013087"}
0005432567212	A0D9E9	9791 592294	VASILIY ALEKSANDROV	{"phone": "+70454505778"}
0005432567213	053B73	8516 514062	POLINA SERGEEVA	{"email": "sergeeva.p.1977@postgrespro.ru", "phone": "+70431934726"}
0005432567214	00AC94	4999 690152	ALINA MELNIKOVA	{"email": "alina_melnikova-1975@postgrespro.ru", "phone": "+70510217826"}
0005432567215	DCA4FB	5132 429443	VLADIMIR KULIKOV	{"phone": "+70572362499"}
0005432567216	DCA4FB	6145 959081	NADEZHDA MIKHAYLOVA	{"email": "n.mikhaylova_07081975@postgrespro.ru", "phone": "+70495874233"}
0005432567217	69DB9E	8159 449007	SERGEY STEPANOV	{"email": "s-stepanov-1985@postgrespro.ru", "phone": "+70522031443"}
0005432567218	81622D	0122 415569	ZAKHAR ZAKHAROV	{"email": "zakharov-z1971@postgrespro.ru", "phone": "+70947497137"}
0005432567219	8102B3	5663 439412	NIKITA YAKOVLEV	{"email": "yakovlev-nikita021970@postgrespro.ru", "phone": "+70412086803"}
0005432567220	E1722D	4441 532386	ALEKSANDR KUZMIN	{"phone": "+70528504312"}
0005432567221	F505E4	8145 252306	RUSLAN GERASIMOV	{"email": "r.gerasimov061966@postgrespro.ru", "phone": "+70281164801"}
0005432567222	56A65A	9159 160875	IVAN GAVRILOV	{"email": "gavrilov.ivan-1962@postgrespro.ru", "phone": "+70473525148"}
0005432567223	56A65A	2253 453264	LARISA ZOTOVA	{"email": "larisa_zotova_021982@postgrespro.ru", "phone": "+70635141413"}
0005432567224	56A65A	8258 703622	EVGENIY MELNIKOV	{"phone": "+70780076217"}
0005432567225	0D28E0	8050 468364	RIMMA ZAYCEVA	{"email": "zayceva.rimma-031966@postgrespro.ru", "phone": "+70355018035"}
0005432567226	0D28E0	5881 829835	NATALYA RYABOVA	{"email": "ryabova_n.11031965@postgrespro.ru", "phone": "+70353392675"}
0005432567227	F9F6DB	1785 329445	VIKTOR SMIRNOV	{"email": "v_smirnov-1964@postgrespro.ru", "phone": "+70528727803"}
0005432567228	DBDDA4	3466 891865	MARIYA EFREMOVA	{"email": "mariya-efremova.041982@postgrespro.ru", "phone": "+70309358704"}
0005432567229	E9A953	8346 721013	VALENTIN IVANOV	{"phone": "+70546344375"}
0005432567230	6475A1	0619 165499	MAKSIM CHERNOV	{"email": "chernov.maksim-08031972@postgrespro.ru", "phone": "+70155979391"}
0005432567231	F5A0E6	9411 094686	VALENTINA KULIKOVA	{"phone": "+70467003747"}
0005432567232	5AF1B9	0178 404153	ALEKSEY SMIRNOV	{"email": "a-smirnov-20091979@postgrespro.ru", "phone": "+70926552479"}
0005432567233	9E6EEE	1251 762728	NINA SOROKINA	{"phone": "+70417665347"}
0005432567234	9E6EEE	8294 047307	NINA GAVRILOVA	{"phone": "+70374513369"}
0005432567235	B3C31F	1983 707164	VYACHESLAV SMIRNOV	{"email": "vyacheslav-smirnov.1982@postgrespro.ru", "phone": "+70242768644"}
0005432567236	B3C31F	2154 650589	ANNA SMIRNOVA	{"phone": "+70337215229"}
0005432567237	13FE14	1392 063225	VLADISLAV KARPOV	{"phone": "+70286566570"}
0005432567238	C5096F	6292 295496	TATYANA NAZAROVA	{"phone": "+70942440219"}
0005432567239	B33BF1	3889 954800	DMITRIY ANDREEV	{"email": "andreev.dmitriy121963@postgrespro.ru", "phone": "+70498217010"}
0005432567240	B33BF1	4678 537479	TATYANA ILINA	{"email": "t-ilina.03071968@postgrespro.ru", "phone": "+70521791524"}
0005432567241	0961A1	8967 072874	ELENA KUZNECOVA	{"email": "e-kuznecova1976@postgrespro.ru", "phone": "+70903140274"}
0005432567242	71297C	1979 707459	VERA SERGEEVA	{"phone": "+70527660411"}
0005432567243	71297C	2568 953962	NINA SEMENOVA	{"email": "semenovanina_19011974@postgrespro.ru", "phone": "+70866517112"}
0005432567244	71297C	9159 096456	OLGA VOLKOVA	{"email": "o-volkova_18041973@postgrespro.ru", "phone": "+70746892337"}
0005432567245	EF365B	5749 527521	ELENA POPOVA	{"email": "popovaelena_111974@postgrespro.ru", "phone": "+70277686867"}
0005432567246	1FEF3A	1927 377443	SERGEY SOROKIN	{"email": "s_sorokin_071975@postgrespro.ru", "phone": "+70466119070"}
0005432567545	DDEF12	5244 381393	MAKSIM SOROKIN	{"phone": "+70298029507"}
0005432567247	1FEF3A	1191 685004	KLAVDIYA SAVELEVA	{"email": "klavdiyasaveleva_04061978@postgrespro.ru", "phone": "+70114000414"}
0005432567248	1FEF3A	9965 133074	ILDAR FEDOROV	{"email": "fedorov.i011971@postgrespro.ru", "phone": "+70422388491"}
0005432567249	3B0459	6607 590310	ALENA IVANOVA	{"phone": "+70662713074"}
0005432567250	ABBC6A	8775 300529	VALERIY VOLKOV	{"email": "valeriyvolkov_1975@postgrespro.ru", "phone": "+70489194424"}
0005432567251	7A555E	9885 721131	TATYANA FILATOVA	{"email": "filatova.tatyana.24071968@postgrespro.ru", "phone": "+70457779257"}
0005432567252	A74D42	6428 384495	TATYANA FOMINA	{"email": "fomina.tatyana.27021962@postgrespro.ru", "phone": "+70418156649"}
0005432567253	0FE28E	7310 896569	YULIYA KOMAROVA	{"phone": "+70963607790"}
0005432567254	D4BBFB	2670 572369	LEONID ANTONOV	{"email": "antonov-leonid-1962@postgrespro.ru", "phone": "+70073075152"}
0005432567255	48B385	3983 365594	ROMAN VASILEV	{"phone": "+70174286289"}
0005432567256	48B385	3266 436931	KRISTINA KARPOVA	{"phone": "+70482543437"}
0005432567257	48B385	0734 958032	MURAT ALEKSANDROV	{"phone": "+70896155203"}
0005432567258	FD86D2	9395 733315	ANASTASIYA TARASOVA	{"email": "tarasova-a_1966@postgrespro.ru", "phone": "+70335910452"}
0005432567259	D65556	5891 417593	SERGEY ROMANOV	{"email": "romanovsergey_071969@postgrespro.ru", "phone": "+70335298436"}
0005432567260	D65556	6289 902098	LARISA PETROVA	{"phone": "+70941667738"}
0005432567261	9FAF40	5522 023632	RUSTAM MOROZOV	{"phone": "+70195868770"}
0005432567262	37ADE4	2677 806652	ALEKSEY KOZLOV	{"email": "aleksey_kozlov25041978@postgrespro.ru", "phone": "+70429291711"}
0005432567263	37ADE4	9090 309170	OLGA PAVLOVA	{"email": "pavlovao.01051980@postgrespro.ru", "phone": "+70606332792"}
0005432567264	22607A	1859 651991	ALEKSANDR DAVYDOV	{"phone": "+70652583835"}
0005432567265	22607A	7592 947222	NINA STEPANOVA	{"email": "nstepanova_18071963@postgrespro.ru", "phone": "+70533758518"}
0005432567266	6C9E03	9405 436580	VIKTOR IVANOV	{"phone": "+70717332525"}
0005432567267	6CA0AC	9532 477883	VIKTOR ANDREEV	{"phone": "+70442145282"}
0005432567268	BC6995	5103 082471	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya_111974@postgrespro.ru", "phone": "+70240014709"}
0005432567269	BC6995	3253 705612	YURIY VOROBEV	{"phone": "+70727925805"}
0005432567270	F63E0F	6472 235623	RAIS FROLOV	{"email": "rais_frolov_1969@postgrespro.ru", "phone": "+70186430054"}
0005432567271	778D78	3759 579948	MARGARITA CHERNOVA	{"phone": "+70586377064"}
0005432567272	778D78	1633 714167	ALEKSANDR NAUMOV	{"email": "naumov.a_1976@postgrespro.ru", "phone": "+70200040443"}
0005432567273	6F1438	3833 233913	EVGENIYA MEDVEDEVA	{"phone": "+70655025942"}
0005432567274	C570C3	2360 168075	TATYANA KALININA	{"phone": "+70169752297"}
0005432567275	C570C3	6016 796055	EVGENIY YAKOVLEV	{"phone": "+70602679477"}
0005432567276	1EF09D	0447 082030	VIKTOR TARASOV	{"email": "tarasov.v-111964@postgrespro.ru", "phone": "+70951053037"}
0005432567277	1EF09D	2518 865462	ALENA BORISOVA	{"email": "borisova_alena111982@postgrespro.ru", "phone": "+70431404726"}
0005432567278	ED81F5	0275 658991	LARISA KUZNECOVA	{"phone": "+70322693865"}
0005432567279	ED81F5	6655 450612	EKATERINA NIKOLAEVA	{"email": "enikolaeva1974@postgrespro.ru", "phone": "+70398000498"}
0005432567280	ED81F5	2034 172061	YULIYA MOISEEVA	{"email": "yuliya.moiseeva.09101970@postgrespro.ru", "phone": "+70942296002"}
0005432567281	3AD168	6177 792844	ALEKSANDRA NIKOLAEVA	{"phone": "+70126624554"}
0005432567282	3AD168	9292 971092	NIKOLAY KOZLOV	{"email": "kozlov-n_011970@postgrespro.ru", "phone": "+70755081551"}
0005432567283	598EA8	1934 239684	TATYANA MALYSHEVA	{"phone": "+70578047421"}
0005432567284	F78E71	1043 167842	PETR KAZAKOV	{"email": "p.kazakov_24021970@postgrespro.ru", "phone": "+70659367129"}
0005432567285	0E76E2	6907 191424	EKATERINA ANTONOVA	{"email": "antonovae-26081979@postgrespro.ru", "phone": "+70952928721"}
0005432567286	674186	6334 070789	ANNA FEDOROVA	{"email": "fedorova-a-04111963@postgrespro.ru", "phone": "+70075995334"}
0005432567287	64EF65	1382 810189	VLADIMIR KUZNECOV	{"email": "kuznecovv_11071966@postgrespro.ru", "phone": "+70094535956"}
0005432567288	64EF65	7272 811551	LYUBOV SERGEEVA	{"email": "sergeevalyubov03091967@postgrespro.ru", "phone": "+70029848039"}
0005432567289	2DF637	7965 330579	ALEKSANDR IVANOV	{"phone": "+70190649341"}
0005432567290	62AFA8	3612 563020	VIKTORIYA KOMAROVA	{"phone": "+70906298715"}
0005432567291	62AFA8	8917 815005	LIDIYA BOGDANOVA	{"email": "bogdanova_l.1971@postgrespro.ru", "phone": "+70830846741"}
0005432567292	B6716F	4404 860279	SERGEY MEDVEDEV	{"email": "s-medvedev_23091957@postgrespro.ru", "phone": "+70531645396"}
0005432567293	1A0A81	5513 685617	EGOR MELNIKOV	{"email": "melnikov.e-111977@postgrespro.ru", "phone": "+70799503393"}
0005432567294	7E0227	8563 596455	ALEVTINA ROMANOVA	{"phone": "+70156017017"}
0005432567295	DB04FA	0161 178863	LARISA PAVLOVA	{"email": "pavlova_larisa_24071972@postgrespro.ru", "phone": "+70558780008"}
0005432567296	79D6A3	3943 405540	TAMARA SIDOROVA	{"email": "t.sidorova_1973@postgrespro.ru", "phone": "+70405553758"}
0005432567297	E884CA	2700 079344	ELENA GUSEVA	{"email": "guseva_elena-051977@postgrespro.ru", "phone": "+70064745745"}
0005432567298	E884CA	7592 301591	EKATERINA BARANOVA	{"phone": "+70909054291"}
0005432567299	52B345	4978 235369	DMITRIY ILIN	{"phone": "+70032945987"}
0005432567300	973C9A	9401 964661	ANTON DAVYDOV	{"phone": "+70334281382"}
0005432567301	973C9A	6584 537841	ALEKSANDR NIKOLAEV	{"email": "anikolaev041977@postgrespro.ru", "phone": "+70778000263"}
0005432567302	973C9A	3672 784459	MILANA MOISEEVA	{"phone": "+70407180922"}
0005432567303	668FA6	6820 331004	ALENA KONDRATEVA	{"phone": "+70799538823"}
0005432567304	CC19A9	6021 681423	VIKTOR KOZLOV	{"email": "viktor-kozlov_04121968@postgrespro.ru", "phone": "+70363660739"}
0005432567305	CC19A9	7015 505815	YULIYA KRASNOVA	{"phone": "+70496506780"}
0005432567779	54535B	1400 002425	LYUBOV ZHURAVLEVA	{"phone": "+70983367045"}
0005432567306	1F6F97	8814 358715	ANATOLIY FROLOV	{"email": "frolov-anatoliy-21011976@postgrespro.ru", "phone": "+70810585731"}
0005432567307	86409D	6613 600085	ALEKSANDRA SCHERBAKOVA	{"phone": "+70549376930"}
0005432567308	197154	8960 540892	VLADIMIR MIKHAYLOV	{"phone": "+70785188990"}
0005432567309	197154	4364 454780	ANATOLIY VOLKOV	{"email": "volkov.anatoliy-1968@postgrespro.ru", "phone": "+70530683935"}
0005432567310	C9497F	3738 362543	KRISTINA MEDVEDEVA	{"email": "kristina-medvedeva.26021964@postgrespro.ru", "phone": "+70382347913"}
0005432567311	F68B60	4494 200462	VLADIMIR IVANOV	{"phone": "+70861906657"}
0005432567312	0ED92E	8579 288405	SERGEY MELNIKOV	{"phone": "+70051301766"}
0005432567313	0ED92E	3381 735319	LYUBOV VASILEVA	{"email": "lyubov.vasileva_081972@postgrespro.ru", "phone": "+70340514723"}
0005432567314	BC8FEB	0811 426230	BOGDAN GRIGOREV	{"email": "b.grigorev011965@postgrespro.ru", "phone": "+70959467575"}
0005432567315	398DE9	6047 803939	ALEKSANDR PAVLOV	{"phone": "+70260139970"}
0005432567316	44524D	8500 199646	DMITRIY PAVLOV	{"phone": "+70961728070"}
0005432567317	44524D	2076 340870	VLADIMIR SOKOLOV	{"phone": "+70830859524"}
0005432567318	8472F5	1470 575607	ELENA KUDRYASHOVA	{"phone": "+70971987074"}
0005432567319	8472F5	6729 351505	VLADIMIR PETROV	{"email": "v.petrov_1955@postgrespro.ru", "phone": "+70079057616"}
0005432567320	70239A	3809 578885	OLGA TIKHONOVA	{"email": "tikhonova_olga30041973@postgrespro.ru", "phone": "+70389788088"}
0005432567321	70239A	3314 678639	SVETLANA IVANOVA	{"email": "ivanova_svetlana_031974@postgrespro.ru", "phone": "+70223683337"}
0005432567322	AE103A	6349 557396	ULYANA MASLOVA	{"email": "maslova_ulyana1968@postgrespro.ru", "phone": "+70434334057"}
0005432567323	A5748E	8926 949491	ANTON ZAYCEV	{"phone": "+70613891225"}
0005432567324	BCE6A9	0269 099881	KLAVDIYA KOROLEVA	{"email": "korolevak1973@postgrespro.ru", "phone": "+70647679780"}
0005432567325	BCE6A9	9825 297298	VIKTOR PAVLOV	{"phone": "+70771465107"}
0005432567326	E72774	0465 189771	MIKHAIL KUZNECOV	{"phone": "+70834795494"}
0005432567327	E72774	0177 846866	GALINA GERASIMOVA	{"email": "gerasimova.g-011972@postgrespro.ru", "phone": "+70758888838"}
0005432567328	A3835F	1566 759894	VERA IVANOVA	{"phone": "+70046628350"}
0005432567329	3C42FE	5737 304885	ALEKSEY KUZNECOV	{"phone": "+70009349934"}
0005432567330	3C42FE	1713 300997	ALEKSANDR GUSEV	{"email": "a.gusev071974@postgrespro.ru", "phone": "+70164895534"}
0005432567331	36FF41	0797 678333	NATALYA NAUMOVA	{"phone": "+70107800256"}
0005432567332	1D44B4	6258 853845	LIDIYA KUDRYASHOVA	{"email": "l_kudryashova041981@postgrespro.ru", "phone": "+70684788218"}
0005432567333	5E4679	5563 673609	YULIYA POLYAKOVA	{"email": "polyakova-y.07091966@postgrespro.ru", "phone": "+70503647590"}
0005432567334	90987B	3449 359620	IVAN MAKAROV	{"email": "makarov-ivan_1979@postgrespro.ru", "phone": "+70730947217"}
0005432567335	C5092C	7926 359676	NIKOLAY BONDARENKO	{"phone": "+70212392457"}
0005432567336	C5092C	6962 140888	SHAMIL GORBUNOV	{"phone": "+70276248434"}
0005432567337	437A8B	0974 798998	VLADIMIR NIKITIN	{"phone": "+70503826551"}
0005432567338	4B711B	2838 050747	NADEZHDA LOGINOVA	{"email": "n.loginova-061977@postgrespro.ru", "phone": "+70256497534"}
0005432567339	4B711B	7994 457509	GALINA MASLOVA	{"email": "maslova.g.011974@postgrespro.ru", "phone": "+70843506331"}
0005432567340	AB7E53	1579 218475	RINAT ZHUKOV	{"email": "zhukov.rinat_011974@postgrespro.ru", "phone": "+70203417126"}
0005432567341	A6DE1E	6852 208671	SOFYA ABRAMOVA	{"phone": "+70409393925"}
0005432567342	DD3A83	9498 640714	ILYA RODIONOV	{"phone": "+70082025792"}
0005432567343	DD3A83	4229 655659	ZINAIDA IVANOVA	{"phone": "+70576793934"}
0005432567344	2DDA0C	6226 839661	MIKHAIL ANTONOV	{"phone": "+70441449655"}
0005432567345	E67CDF	1212 363455	GEORGIY SCHERBAKOV	{"email": "scherbakov.georgiy1975@postgrespro.ru", "phone": "+70513350610"}
0005432567346	573A0B	3386 081732	ILYA PETROV	{"email": "ilya_petrov10021964@postgrespro.ru", "phone": "+70666989237"}
0005432567347	530891	4480 017722	NIKOLAY ZHUKOV	{"phone": "+70891595775"}
0005432567348	057E68	4385 624824	YURIY KUZMIN	{"phone": "+70962752773"}
0005432567349	057E68	0786 292785	IRINA KONOVALOVA	{"phone": "+70311397680"}
0005432567350	EC900F	8711 905543	GALINA KUZMINA	{"phone": "+70455253118"}
0005432567351	EC900F	0566 020432	MAKSIM KOZLOV	{"phone": "+70583108466"}
0005432567352	EC900F	1338 681182	SVETLANA IVANOVA	{"phone": "+70600087117"}
0005432567353	CF05A3	6319 949897	NATALYA ZOTOVA	{"phone": "+70072419456"}
0005432567354	694211	0038 276387	ARINA ROMANOVA	{"email": "romanova_arina.1972@postgrespro.ru", "phone": "+70216539125"}
0005432567355	06A689	9291 178562	KONSTANTIN NAZAROV	{"phone": "+70815801247"}
0005432567356	06A689	5512 192323	NIKOLAY GERASIMOV	{"phone": "+70758428439"}
0005432567357	65B0C3	4923 255423	ARTEM KUZMIN	{"email": "kuzmin-a041969@postgrespro.ru", "phone": "+70241875872"}
0005432567358	69CBCB	2097 957841	LYUBOV DENISOVA	{"email": "denisoval-11061972@postgrespro.ru", "phone": "+70759531575"}
0005432567359	5AACC5	0348 544371	TATYANA VOLKOVA	{"email": "volkova.t-25111970@postgrespro.ru", "phone": "+70184922685"}
0005432567360	800BD5	9804 504496	VLADIMIR FEDOTOV	{"email": "fedotov_v1972@postgrespro.ru", "phone": "+70295478318"}
0005432567361	800BD5	3908 875249	NATALYA PETROVA	{"phone": "+70849587583"}
0005432567362	EC714C	5511 172576	OLGA VASILEVA	{"email": "ovasileva.111974@postgrespro.ru", "phone": "+70411696089"}
0005432567363	0CD82A	7320 114395	BOGDAN ZAKHAROV	{"email": "zakharovbogdan.121978@postgrespro.ru", "phone": "+70058033162"}
0005432567364	1C9E0E	9333 423475	VIKTORIYA ANDREEVA	{"phone": "+70876276439"}
0005432567365	C3631E	8217 273585	NATALYA ANDREEVA	{"email": "andreeva-n.1970@postgrespro.ru", "phone": "+70476404530"}
0005432567366	EA7440	5951 248768	ELENA FROLOVA	{"phone": "+70626864365"}
0005432567780	6E0F06	6416 930524	SERGEY MELNIKOV	{"phone": "+70410791554"}
0005432567367	EA7440	5558 369993	ILNUR KULIKOV	{"email": "ilnur.kulikov-1965@postgrespro.ru", "phone": "+70935811340"}
0005432567368	F02562	6939 752012	ANATOLIY IVANOV	{"phone": "+70334288769"}
0005432567369	196B13	6708 177804	LEYLA NOVIKOVA	{"email": "leylanovikova-021966@postgrespro.ru", "phone": "+70650306099"}
0005432567370	E3ACE3	8543 068435	NADEZHDA ILINA	{"email": "ilina.n041978@postgrespro.ru", "phone": "+70093971835"}
0005432567371	E3ACE3	5083 272754	EKATERINA ABRAMOVA	{"email": "ekaterinaabramova_13021965@postgrespro.ru", "phone": "+70221539072"}
0005432567372	D79238	2604 278769	ANDREY MAKAROV	{"email": "makarov-a1990@postgrespro.ru", "phone": "+70426609049"}
0005432567373	6DDA6F	3561 123751	ILYA BARANOV	{"email": "ilya-baranov021966@postgrespro.ru", "phone": "+70987083206"}
0005432567374	6DDA6F	8641 316179	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov011974@postgrespro.ru", "phone": "+70589831661"}
0005432567375	55295E	4006 780051	GALINA ROMANOVA	{"phone": "+70426204149"}
0005432567376	CD4FA8	3887 838958	ANTON GRIGOREV	{"email": "a-grigorev_02041968@postgrespro.ru", "phone": "+70910222978"}
0005432567377	CD4FA8	6191 071991	DAVID IVANOV	{"email": "ivanov.d_091976@postgrespro.ru", "phone": "+70373689318"}
0005432567378	A56BEA	2883 132742	OLGA ILINA	{"email": "olga_ilina-1965@postgrespro.ru", "phone": "+70382307148"}
0005432567379	98CF56	4033 340814	ILYA TIMOFEEV	{"email": "i_timofeev-1975@postgrespro.ru", "phone": "+70725746930"}
0005432567380	210804	4557 838214	SVETLANA KARPOVA	{"email": "s.karpova_1964@postgrespro.ru", "phone": "+70540750651"}
0005432567381	D1A366	7812 452145	YULIYA MOISEEVA	{"email": "moiseeva-y_1960@postgrespro.ru", "phone": "+70040994204"}
0005432567382	DA16D8	6315 481221	ALEKSEY NOVIKOV	{"email": "novikov_a08031965@postgrespro.ru", "phone": "+70022353113"}
0005432567383	4E46A0	1495 462952	MATVEY MOROZOV	{"phone": "+70028451059"}
0005432567384	441D0E	7539 245985	GENNADIY KARPOV	{"phone": "+70680156160"}
0005432567385	40B68E	3228 170502	NIKOLAY KUZMIN	{"phone": "+70625098915"}
0005432567386	65D840	5794 549165	IRINA POLYAKOVA	{"phone": "+70278184692"}
0005432567387	3BDE65	3049 888222	KIRILL SCHERBAKOV	{"phone": "+70848854758"}
0005432567388	3BDE65	5845 948882	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr14061972@postgrespro.ru", "phone": "+70625244379"}
0005432567389	FF09D2	5775 855614	EKATERINA MOISEEVA	{"email": "e_moiseeva-031981@postgrespro.ru", "phone": "+70025478152"}
0005432567390	EE3AB6	5478 660787	YULIYA KONDRATEVA	{"phone": "+70070029988"}
0005432567391	F807A9	4215 862188	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov.1969@postgrespro.ru", "phone": "+70658692993"}
0005432567392	F807A9	1204 033109	KONSTANTIN MOISEEV	{"email": "konstantinmoiseev13071976@postgrespro.ru", "phone": "+70031650417"}
0005432567393	367B7B	9054 081483	ELENA LOGINOVA	{"email": "elena-loginova.23011963@postgrespro.ru", "phone": "+70183454593"}
0005432567394	697573	7456 489662	OLGA ZAYCEVA	{"phone": "+70368603072"}
0005432567395	697573	0537 054452	IVAN BORISOV	{"phone": "+70734013876"}
0005432567396	5DAE9B	1545 949070	EDGAR ILIN	{"phone": "+70983474464"}
0005432567397	A4BA47	8166 534051	VALENTINA KUZNECOVA	{"email": "v-kuznecova_06061977@postgrespro.ru", "phone": "+70781309717"}
0005432567398	EDBB4A	6211 804342	DMITRIY DAVYDOV	{"email": "davydov_dmitriy1972@postgrespro.ru", "phone": "+70137068252"}
0005432567399	F4974D	4291 638105	VENIAMIN MAKSIMOV	{"phone": "+70828215051"}
0005432567400	F4974D	2607 563169	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova_02061966@postgrespro.ru", "phone": "+70754974968"}
0005432567401	6F9731	8417 895102	MARIYA GERASIMOVA	{"email": "gerasimova-m_1970@postgrespro.ru", "phone": "+70024053533"}
0005432567402	ED66C3	0576 900215	ALEKSANDR SERGEEV	{"email": "sergeeva-05051968@postgrespro.ru", "phone": "+70637186672"}
0005432567403	37822D	4879 152572	NATALYA FADEEVA	{"phone": "+70318005484"}
0005432567404	37822D	4803 469724	EVGENIYA PAVLOVA	{"phone": "+70768019700"}
0005432567405	98E97B	2424 348943	VALENTINA ALEKSANDROVA	{"phone": "+70547447185"}
0005432567406	42E841	8179 491095	SERGEY BORISOV	{"email": "s_borisov.111969@postgrespro.ru", "phone": "+70793156721"}
0005432567407	3A1D43	5909 258518	TATYANA MIRONOVA	{"email": "mironova.tatyana.24111968@postgrespro.ru", "phone": "+70244805239"}
0005432567408	2DFFF5	9850 994336	NIKITA SMIRNOV	{"phone": "+70170060743"}
0005432567409	43F1D0	5290 210613	IRINA EFIMOVA	{"email": "efimova-i_31071967@postgrespro.ru", "phone": "+70078862284"}
0005432567410	43F1D0	0274 074494	NIKOLAY PAVLOV	{"phone": "+70401930755"}
0005432567411	53546E	9423 545278	ANNA VLASOVA	{"email": "a-vlasova_1973@postgrespro.ru", "phone": "+70469311406"}
0005432567412	36642C	1443 791332	PAVEL ANDREEV	{"phone": "+70591014480"}
0005432567413	36642C	9930 624145	TAMARA NAZAROVA	{"email": "nazarovat.111975@postgrespro.ru", "phone": "+70695650931"}
0005432567414	77F803	5934 817134	EGOR ANTONOV	{"phone": "+70908047276"}
0005432567415	FC9FAC	3674 482049	NINA MOISEEVA	{"email": "nina-moiseeva-05031963@postgrespro.ru", "phone": "+70316959938"}
0005432567416	B12EFC	5513 162621	ALEKSANDRA KRASNOVA	{"email": "krasnova.aleksandra121980@postgrespro.ru", "phone": "+70747741727"}
0005432567417	9D578A	4380 236325	RUSLAN KUZNECOV	{"email": "kuznecovruslan_1961@postgrespro.ru", "phone": "+70264819184"}
0005432567418	605698	8752 187430	SVETLANA ANISIMOVA	{"email": "anisimovasvetlana-111985@postgrespro.ru", "phone": "+70634636068"}
0005432567419	F01FEF	5467 019264	NAIL SCHERBAKOV	{"email": "scherbakov.nail.1972@postgrespro.ru", "phone": "+70582989838"}
0005432567420	DB00B9	0445 858415	OLEG ROMANOV	{"phone": "+70989759176"}
0005432567421	7B155B	4019 321007	TIMUR NAZAROV	{"email": "nazarovtimur-24031988@postgrespro.ru", "phone": "+70695242542"}
0005432567422	6A1121	9763 480638	ALEKSEY ZHUKOV	{"phone": "+70598406757"}
0005432567423	6A1121	7310 026596	MARIYA AFANASEVA	{"email": "m.afanaseva-21021968@postgrespro.ru", "phone": "+70312726651"}
0005432567424	6EE4A6	9991 420963	VASILIY SCHERBAKOV	{"phone": "+70866672656"}
0005432567425	2BB3A4	9639 551587	SOFYA ANTONOVA	{"email": "sofyaantonova031965@postgrespro.ru", "phone": "+70396468644"}
0005432567426	2BB3A4	8357 609312	ALEKSEY KOZLOV	{"email": "a.kozlov-03031970@postgrespro.ru", "phone": "+70661085732"}
0005432567427	376606	4542 519658	VALERIY ROMANOV	{"email": "romanov.v_13101980@postgrespro.ru", "phone": "+70996670865"}
0005432567428	376606	7219 600353	EKATERINA RODIONOVA	{"phone": "+70554049590"}
0005432567429	F71F71	6894 170121	ANNA SERGEEVA	{"phone": "+70429532039"}
0005432567430	F71F71	0548 569682	VALENTINA ROMANOVA	{"phone": "+70680788820"}
0005432567431	DCC109	4447 452304	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr05021960@postgrespro.ru", "phone": "+70146552506"}
0005432567432	DCC109	8130 217360	YANA FADEEVA	{"phone": "+70520993729"}
0005432567433	1E962E	6827 335333	TATYANA GUSEVA	{"email": "tguseva-1989@postgrespro.ru", "phone": "+70596310800"}
0005432567434	55E4FF	3773 257094	VYACHESLAV SERGEEV	{"email": "vyacheslav.sergeev.1963@postgrespro.ru", "phone": "+70890691281"}
0005432567435	A428D1	7432 349934	ANASTASIYA POTAPOVA	{"email": "apotapova16081964@postgrespro.ru", "phone": "+70669989610"}
0005432567436	C263B2	3955 228193	NINA AFANASEVA	{"email": "afanasevan-051985@postgrespro.ru", "phone": "+70853537327"}
0005432567437	C67031	2862 992884	IRINA VLASOVA	{"phone": "+70243442201"}
0005432567438	841EB3	8489 707923	MIKHAIL ZAKHAROV	{"email": "mzakharov_1974@postgrespro.ru", "phone": "+70421898647"}
0005432567439	9E27E3	8445 585188	NELYA KUZNECOVA	{"email": "kuznecova.nelya.01111979@postgrespro.ru", "phone": "+70444102519"}
0005432567440	9E27E3	8251 313526	TATYANA POLYAKOVA	{"phone": "+70668047930"}
0005432567441	65C36C	9359 648580	VLADISLAV KUZNECOV	{"phone": "+70686498430"}
0005432567442	E82264	0430 345285	MIKHAIL FEDOROV	{"email": "fedorov.m.121969@postgrespro.ru", "phone": "+70518649678"}
0005432567443	5BD245	1847 778855	GENNADIY NAUMOV	{"email": "naumov.g_1970@postgrespro.ru", "phone": "+70857655455"}
0005432567444	C3E71A	4776 350035	ANTONINA KOVALEVA	{"phone": "+70352604119"}
0005432567445	15F780	4721 661273	VALERIY VASILEV	{"email": "vasilev-v.051980@postgrespro.ru", "phone": "+70126144440"}
0005432567446	CF3AD8	0521 562500	POLINA MAKSIMOVA	{"email": "polina-maksimova081977@postgrespro.ru", "phone": "+70067366445"}
0005432567447	CF3AD8	1100 754866	DMITRIY FEDOROV	{"phone": "+70244368566"}
0005432567448	56A0F9	9110 960197	EGOR KUZNECOV	{"email": "e.kuznecov.10081973@postgrespro.ru", "phone": "+70776847898"}
0005432567449	ABF4E0	9598 274314	MARINA KUZMINA	{"phone": "+70839640321"}
0005432567450	576EA1	6019 864368	VLADIMIR TARASOV	{"email": "tarasov_vladimir.051976@postgrespro.ru", "phone": "+70148161204"}
0005432567451	5896AE	4155 687612	MARGARITA ISAEVA	{"email": "isaevamargarita_021974@postgrespro.ru", "phone": "+70452967239"}
0005432567452	C86C81	3866 088342	ANNA CHERNOVA	{"email": "a.chernova1974@postgrespro.ru", "phone": "+70486705679"}
0005432567453	C86C81	5834 405530	ALEKSANDR GORBUNOV	{"email": "a_gorbunov-29061968@postgrespro.ru", "phone": "+70984560467"}
0005432567454	19714B	6959 399224	LYUDMILA ERMAKOVA	{"email": "lyudmila_ermakova10021968@postgrespro.ru", "phone": "+70010593731"}
0005432567455	2481D4	6348 720777	DMITRIY MATVEEV	{"email": "matveevdmitriy-16041976@postgrespro.ru", "phone": "+70136147422"}
0005432567456	2481D4	0471 695411	TAMARA MIKHAYLOVA	{"phone": "+70549789352"}
0005432567457	3C3C82	0273 975553	MIKHAIL OSIPOV	{"email": "m-osipov.1965@postgrespro.ru", "phone": "+70792946091"}
0005432567458	BAB252	0508 239877	SERGEY ANTONOV	{"email": "antonov-s_041966@postgrespro.ru", "phone": "+70751130787"}
0005432567459	2E065D	2560 403361	NIKITA IVANOV	{"email": "ivanovn06021968@postgrespro.ru", "phone": "+70379972571"}
0005432567460	BAE6DB	7997 299027	OLEG SERGEEV	{"email": "oleg-sergeev-14021966@postgrespro.ru", "phone": "+70903965624"}
0005432567461	28BFE5	8230 429420	LIDIYA KAZAKOVA	{"phone": "+70455762965"}
0005432567462	28BFE5	7931 829297	MARIYA IVANOVA	{"email": "ivanova.mariya-1978@postgrespro.ru", "phone": "+70035066127"}
0005432567463	CCE680	8543 423500	ROMAN PAVLOV	{"email": "pavlov-roman_031976@postgrespro.ru", "phone": "+70965445308"}
0005432567464	068998	0486 100166	NATALYA DENISOVA	{"email": "natalya_denisova-091973@postgrespro.ru", "phone": "+70308497857"}
0005432567465	ECDB85	2242 011251	POLINA NIKITINA	{"phone": "+70151121283"}
0005432567466	764270	3478 047447	ANNA VOROBEVA	{"email": "vorobevaa111969@postgrespro.ru", "phone": "+70722355557"}
0005432567467	FA22DC	5768 163183	VIKTOR YAKOVLEV	{"phone": "+70488603491"}
0005432567468	133B76	3655 242234	LIDIYA MIKHAYLOVA	{"phone": "+70006960848"}
0005432567469	D11E37	7587 712121	VLADIMIR FOMIN	{"email": "fomin.vladimir_121967@postgrespro.ru", "phone": "+70872220791"}
0005432567470	0F0D8C	6640 212102	ANNA MAKSIMOVA	{"phone": "+70735501141"}
0005432567471	9F17B9	7491 537889	NIKOLAY BELOV	{"email": "belov-nikolay1970@postgrespro.ru", "phone": "+70600829981"}
0005432567472	C1D7C5	8722 800499	IREK KAZAKOV	{"phone": "+70363571911"}
0005432567473	D0B865	4389 984684	TAMARA ANDREEVA	{"email": "tamara_andreeva-15081953@postgrespro.ru", "phone": "+70528462664"}
0005432567474	D0B865	4938 405976	ANNA MIKHAYLOVA	{"email": "a_mikhaylova26121968@postgrespro.ru", "phone": "+70793451756"}
0005432567475	841291	2716 239936	MARGARITA GORBUNOVA	{"email": "m.gorbunova.121976@postgrespro.ru", "phone": "+70806327469"}
0005432567476	791024	9748 720469	VALERIY FROLOV	{"email": "frolov-valeriy041977@postgrespro.ru", "phone": "+70221726228"}
0005432567477	BEBA48	5865 118064	TATYANA KUZNECOVA	{"email": "t_kuznecova_041976@postgrespro.ru", "phone": "+70847461177"}
0005432567478	E2433F	4084 701876	PAVEL KUZMIN	{"phone": "+70122632500"}
0005432567479	E2433F	9056 431329	DENIS IVANOV	{"phone": "+70476761860"}
0005432567480	C68C1F	7770 030654	DMITRIY AFANASEV	{"email": "dmitriyafanasev-23021963@postgrespro.ru", "phone": "+70483857073"}
0005432567481	8FCDE1	1738 466126	OLGA FILATOVA	{"phone": "+70837991712"}
0005432567482	8FCDE1	3743 715260	ANATOLIY PETROV	{"email": "anatoliy_petrov.09081960@postgrespro.ru", "phone": "+70326146665"}
0005432567483	EA1823	1461 754503	NINA MATVEEVA	{"email": "matveeva_n28101980@postgrespro.ru", "phone": "+70955946331"}
0005432567484	EA1823	9385 060853	DMITRIY ILIN	{"email": "dmitriy_ilin-111979@postgrespro.ru", "phone": "+70689642618"}
0005432567485	694439	1791 091381	VIKTOR ROMANOV	{"email": "romanov-viktor-18031976@postgrespro.ru", "phone": "+70944600014"}
0005432567486	8BDE82	7834 568857	YULIYA ILINA	{"phone": "+70100719992"}
0005432567487	B830BE	7065 074374	TATYANA ANDREEVA	{"phone": "+70615568100"}
0005432567488	DDDF5D	8752 327618	VIKTOR KULIKOV	{"phone": "+70537613331"}
0005432567489	8AA805	9448 954969	ELENA KONOVALOVA	{"phone": "+70227032037"}
0005432567490	4918A8	7534 824321	SERGEY SMIRNOV	{"email": "sergey.smirnov_05011971@postgrespro.ru", "phone": "+70085418328"}
0005432567491	E1AAB5	7337 273749	LYUDMILA FILIPPOVA	{"phone": "+70120214190"}
0005432567492	E1AAB5	9638 192749	VIKTORIYA KOVALEVA	{"email": "kovalevav.071980@postgrespro.ru", "phone": "+70517352594"}
0005432567493	F2C0F2	8442 033727	RAISA VLASOVA	{"email": "rvlasova-29061974@postgrespro.ru", "phone": "+70575674493"}
0005432567494	8A46BF	3902 024217	ALEKSANDR BORISOV	{"email": "a-borisov_041975@postgrespro.ru", "phone": "+70064234294"}
0005432567495	927B81	7830 195846	ELENA LEBEDEVA	{"phone": "+70354668543"}
0005432567496	927B81	3197 077249	NADEZHDA VASILEVA	{"phone": "+70149032571"}
0005432567497	927B81	4407 067007	OLGA ZAYCEVA	{"phone": "+70694149422"}
0005432567498	2ABE1F	6764 827103	NIKOLAY CHERNOV	{"phone": "+70324571172"}
0005432567499	E37B9C	3178 091838	MARIYA SOLOVEVA	{"phone": "+70279262281"}
0005432567500	819000	5957 285583	GALINA NESTEROVA	{"email": "nesterova-galina041958@postgrespro.ru", "phone": "+70843090777"}
0005432567501	819000	6700 183923	NIKOLAY ROMANOV	{"phone": "+70804003135"}
0005432567502	45EDA0	3012 063713	SERGEY KUZMIN	{"email": "s.kuzmin1975@postgrespro.ru", "phone": "+70880999222"}
0005432567503	45EDA0	1396 964859	ANATOLIY CHERNOV	{"email": "anatoliy-chernov-18061966@postgrespro.ru", "phone": "+70392678704"}
0005432567504	073D0D	8835 588761	VALENTINA KARPOVA	{"email": "vkarpova-20111969@postgrespro.ru", "phone": "+70353695320"}
0005432567505	503FD6	7367 559943	NINA ANISIMOVA	{"phone": "+70290046107"}
0005432567506	503FD6	7207 758625	ZHANNA MELNIKOVA	{"phone": "+70345141256"}
0005432567507	1DA849	2689 846366	SERGEY MOROZOV	{"phone": "+70999330767"}
0005432567508	2ED88A	6405 655427	MIKHAIL FROLOV	{"email": "frolovmikhail.101967@postgrespro.ru", "phone": "+70917482047"}
0005432567509	4DD3B2	4437 424148	SERGEY ILIN	{"phone": "+70788169076"}
0005432567510	4DD3B2	4406 075341	IVAN ABRAMOV	{"phone": "+70256432914"}
0005432567511	17C5C0	8903 700199	ANDREY ANDREEV	{"phone": "+70135810297"}
0005432567512	17C5C0	6201 717443	ANDREY MELNIKOV	{"phone": "+70292246720"}
0005432567513	053231	7803 761541	VIKTOR VLASOV	{"phone": "+70612210995"}
0005432567514	053231	1533 989378	TATYANA GUSEVA	{"email": "guseva.t1974@postgrespro.ru", "phone": "+70960376143"}
0005432567515	087430	9587 574392	ELENA NIKOLAEVA	{"phone": "+70803340530"}
0005432567516	EBCB60	9942 403486	EVGENIYA ZAKHAROVA	{"email": "ezakharova-061967@postgrespro.ru", "phone": "+70412238150"}
0005432567517	323C2E	2253 437494	NATALIYA ZHUKOVA	{"email": "nataliya_zhukova_041964@postgrespro.ru", "phone": "+70864947955"}
0005432567518	323C2E	8327 860011	MILANA ALEKSEEVA	{"phone": "+70864469441"}
0005432567519	DDDD20	7135 982477	IRINA SIDOROVA	{"phone": "+70717198034"}
0005432567520	F24BEA	7079 220658	LYUDMILA NAZAROVA	{"phone": "+70649331094"}
0005432567521	F24BEA	9712 844559	VLADIMIR ZHUKOV	{"email": "zhukov.v-20101981@postgrespro.ru", "phone": "+70995722910"}
0005432567522	F24BEA	7355 539011	BORIS ZAYCEV	{"phone": "+70513101283"}
0005432567523	E6A12E	6509 845925	ALEKSANDR OSIPOV	{"email": "a_osipov121975@postgrespro.ru", "phone": "+70290970889"}
0005432567524	311366	6664 394669	NATALYA POLYAKOVA	{"email": "n-polyakova-081967@postgrespro.ru", "phone": "+70451694753"}
0005432567525	C7D9F5	2518 693571	GENNADIY MEDVEDEV	{"phone": "+70045158183"}
0005432567526	BABD97	4812 129474	EKATERINA MARTYNOVA	{"email": "ekaterinamartynova_091962@postgrespro.ru", "phone": "+70884431439"}
0005432567527	75B335	5812 985787	ARTEM DMITRIEV	{"phone": "+70346791925"}
0005432567528	8631D7	1777 975630	TATYANA FROLOVA	{"email": "tfrolova.1978@postgrespro.ru", "phone": "+70770762096"}
0005432567529	8267D1	1827 459450	DMITRIY VOLKOV	{"email": "volkovdmitriy.1980@postgrespro.ru", "phone": "+70563000485"}
0005432567530	89B249	9568 722012	EVGENIY PETROV	{"phone": "+70543079387"}
0005432567531	89B249	3884 717081	LYUDMILA KUZNECOVA	{"phone": "+70137883636"}
0005432567532	2C7863	5477 495660	PAVEL ANDREEV	{"phone": "+70268666584"}
0005432567533	2C7863	4301 743292	NATALYA BORISOVA	{"email": "borisova.natalya_21081959@postgrespro.ru", "phone": "+70457540127"}
0005432567534	2C7863	2444 762849	GLEB KUZNECOV	{"phone": "+70027667663"}
0005432567535	2C7863	8484 524296	PETR MOISEEV	{"email": "moiseev-p-031981@postgrespro.ru", "phone": "+70813018037"}
0005432567536	7DEF48	3821 729845	IVAN FILIPPOV	{"email": "filippov.ivan-10081969@postgrespro.ru", "phone": "+70771628670"}
0005432567537	214526	1697 119948	ELENA VASILEVA	{"email": "vasileva_elena_1971@postgrespro.ru", "phone": "+70277278998"}
0005432567538	7E0FA7	4124 048955	GALINA RODIONOVA	{"phone": "+70663876380"}
0005432567539	A910A4	1014 397530	LYUDMILA VOROBEVA	{"phone": "+70178071195"}
0005432567540	D75B09	5067 120723	ALEKSEY KARPOV	{"email": "karpov.a_1977@postgrespro.ru", "phone": "+70519056340"}
0005432567541	0D8E4C	1448 745889	SVETLANA SOKOLOVA	{"email": "sokolova.svetlana03081978@postgrespro.ru", "phone": "+70367944310"}
0005432567542	625F52	4594 308365	MARK FILIPPOV	{"phone": "+70725334063"}
0005432567543	1B8D7C	5504 588037	NINA MARTYNOVA	{"email": "martynovanina1965@postgrespro.ru", "phone": "+70790520945"}
0005432567546	DD9A52	3227 655710	ALEKSANDRA ANDREEVA	{"email": "aleksandra-andreeva_051977@postgrespro.ru", "phone": "+70505593985"}
0005432567547	DD9A52	7397 427483	ANNA NAUMOVA	{"email": "a.naumova-1966@postgrespro.ru", "phone": "+70640006601"}
0005432567548	CB227C	3000 360115	SVETLANA MOROZOVA	{"email": "morozova.s30121979@postgrespro.ru", "phone": "+70032248582"}
0005432567549	CB227C	0060 119283	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr-22101965@postgrespro.ru", "phone": "+70777315166"}
0005432567550	82F368	2584 106822	GALINA SCHERBAKOVA	{"phone": "+70495013353"}
0005432567551	82F368	7156 505988	ANDREY KUZNECOV	{"email": "kuznecov.andrey_21031970@postgrespro.ru", "phone": "+70771403084"}
0005432567552	6346D0	7991 640233	NATALYA NESTEROVA	{"email": "nesterovanatalya-041967@postgrespro.ru", "phone": "+70389256462"}
0005432567553	35079C	4860 655976	ARTEM TIKHONOV	{"email": "a_tikhonov.1974@postgrespro.ru", "phone": "+70940223779"}
0005432567554	20E7F0	9125 355422	IRINA IVANOVA	{"email": "iivanova-011980@postgrespro.ru", "phone": "+70550362058"}
0005432567555	254E7F	5959 429577	ANATOLIY ROMANOV	{"phone": "+70943359302"}
0005432567556	7B4A18	0034 747580	FEDOR KAZAKOV	{"email": "kazakov-fedor02061981@postgrespro.ru", "phone": "+70764562049"}
0005432567557	7B4A18	3787 421757	ROMAN DENISOV	{"phone": "+70087530018"}
0005432567558	B38C21	9747 956360	OLGA PETROVA	{"email": "petrovaolga_12111962@postgrespro.ru", "phone": "+70604349041"}
0005432567559	2F368B	6726 697168	ANDREY ZAKHAROV	{"email": "andrey.zakharov_081973@postgrespro.ru", "phone": "+70004502184"}
0005432567560	6ADA77	6000 489605	NIKITA ISAEV	{"email": "n-isaev_19011976@postgrespro.ru", "phone": "+70518090371"}
0005432567561	6ADA77	3888 683169	NADEZHDA KUZNECOVA	{"phone": "+70014474276"}
0005432567562	C84F14	2656 146645	LYUDMILA SMIRNOVA	{"email": "l_smirnova1966@postgrespro.ru", "phone": "+70337377421"}
0005432567563	C84F14	2255 250038	ANTONINA LEBEDEVA	{"phone": "+70801529898"}
0005432567564	C84F14	4545 094014	ALEKSEY ILIN	{"phone": "+70969774914"}
0005432567565	D59328	4903 759092	NINA ZAYCEVA	{"email": "nina-zayceva12111972@postgrespro.ru", "phone": "+70622262019"}
0005432567566	F5685A	9909 259221	EVGENIY GORBUNOV	{"email": "egorbunov-06011975@postgrespro.ru", "phone": "+70931008340"}
0005432567567	F5685A	7840 822409	GALINA SERGEEVA	{"email": "g_sergeeva091969@postgrespro.ru", "phone": "+70195182662"}
0005432567568	3FAB70	3046 370441	VERA YUDINA	{"email": "v-yudina-1972@postgrespro.ru", "phone": "+70302813627"}
0005432567625	4F2C5C	6650 836872	LIDIYA SCHERBAKOVA	{"phone": "+70691625479"}
0005432567569	2910D7	0200 922159	ALEKSANDR SAVELEV	{"email": "savelev_a101981@postgrespro.ru", "phone": "+70467209318"}
0005432567570	2910D7	0374 767866	VALENTIN MARTYNOV	{"phone": "+70243598020"}
0005432567571	C97100	7086 820716	SVETLANA RODIONOVA	{"email": "rodionova-svetlana011976@postgrespro.ru", "phone": "+70099071414"}
0005432567572	F228C0	6466 778657	ANNA BELOVA	{"phone": "+70754038767"}
0005432567573	D3A0FE	5468 340254	VYACHESLAV ZAKHAROV	{"phone": "+70094581463"}
0005432567574	F1F397	8495 570046	YULIYA NIKITINA	{"email": "nikitina-yuliya011975@postgrespro.ru", "phone": "+70199966934"}
0005432567575	4ECF02	8817 760680	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila-03051965@postgrespro.ru", "phone": "+70969622962"}
0005432567576	4ECF02	0980 772854	IRINA ANISIMOVA	{"phone": "+70928463208"}
0005432567577	A84D75	1654 559663	LYUDMILA GORBUNOVA	{"email": "gorbunova_lyudmila.1971@postgrespro.ru", "phone": "+70404698130"}
0005432567578	24DCA0	8807 601075	OLEG GRIGOREV	{"email": "oleggrigorev_1972@postgrespro.ru", "phone": "+70495826076"}
0005432567579	C70222	1408 818896	DINA ZAYCEVA	{"email": "d.zayceva-27101966@postgrespro.ru", "phone": "+70791992075"}
0005432567580	8C7A06	0258 103257	ILYA NAZAROV	{"email": "inazarov06041959@postgrespro.ru", "phone": "+70226992973"}
0005432567581	8C7A06	6528 870783	ALLA FILIPPOVA	{"email": "a_filippova_121976@postgrespro.ru", "phone": "+70728935206"}
0005432567582	B67E84	9896 074277	EVGENIY GORBUNOV	{"email": "evgeniy-gorbunov_21051976@postgrespro.ru", "phone": "+70047687191"}
0005432567583	C4BD2A	0405 942962	SERGEY MEDVEDEV	{"email": "medvedev-sergey-07101968@postgrespro.ru", "phone": "+70295546104"}
0005432567584	EABC2C	1326 749210	ARINA KOROLEVA	{"phone": "+70751205693"}
0005432567585	383796	3443 762306	YULIYA RYABOVA	{"phone": "+70205288879"}
0005432567586	E2B41F	6210 405840	TATYANA TIMOFEEVA	{"email": "ttimofeeva-061977@postgrespro.ru", "phone": "+70583734424"}
0005432567587	314912	0272 997150	ANATOLIY PAVLOV	{"phone": "+70617193696"}
0005432567588	0D5DEC	7080 308810	ILYA VOLKOV	{"email": "ilya_volkov-121976@postgrespro.ru", "phone": "+70155219174"}
0005432567589	0D5DEC	7095 988187	MIKHAIL ORLOV	{"phone": "+70262550920"}
0005432567590	C135A4	9191 502684	ELENA KUZMINA	{"phone": "+70788786632"}
0005432567591	14CCB3	2163 895248	LYUDMILA ORLOVA	{"phone": "+70270668309"}
0005432567592	8BD7A7	0327 345484	DMITRIY KOZLOV	{"phone": "+70638897622"}
0005432567593	C78611	8423 606087	NIKOLAY IVANOV	{"phone": "+70684684490"}
0005432567594	C78611	4331 717704	IRINA ROMANOVA	{"email": "romanovai_05051972@postgrespro.ru", "phone": "+70380174469"}
0005432567595	AD075F	2734 129406	TATYANA KULIKOVA	{"email": "t-kulikova-011964@postgrespro.ru", "phone": "+70089615258"}
0005432567596	92A9B2	5806 162090	VALENTINA FADEEVA	{"email": "v-fadeeva-101973@postgrespro.ru", "phone": "+70967949609"}
0005432567597	92A9B2	4255 519758	SERGEY BELOV	{"phone": "+70249083753"}
0005432567598	08F986	3610 567864	ROMAN IVANOV	{"phone": "+70154939301"}
0005432567599	14C5DB	3996 329266	DINARA BORISOVA	{"email": "borisova_d.021968@postgrespro.ru", "phone": "+70761355607"}
0005432567600	D129C5	3189 216781	NINA MATVEEVA	{"phone": "+70450195746"}
0005432567601	D129C5	4784 964272	NIKOLAY KUZNECOV	{"email": "n.kuznecov-1969@postgrespro.ru", "phone": "+70931196765"}
0005432567602	D5C95F	5982 660245	ALEKSANDR PAVLOV	{"phone": "+70249554458"}
0005432567603	796073	7031 331288	LARISA ABRAMOVA	{"phone": "+70635371447"}
0005432567604	5719C1	9629 758942	LILIYA ZHURAVLEVA	{"email": "zhuravlevaliliya101969@postgrespro.ru", "phone": "+70473005460"}
0005432567605	5719C1	4326 462143	NINA DANILOVA	{"phone": "+70818087567"}
0005432567606	69B23E	1269 908989	VASILIY IVANOV	{"email": "ivanov_v-111962@postgrespro.ru", "phone": "+70762927332"}
0005432567607	69B23E	2192 922142	ALEKSANDR KOZLOV	{"phone": "+70457524780"}
0005432567608	C9ECBC	3470 067560	ANASTASIYA DANILOVA	{"email": "a-danilova_03091982@postgrespro.ru", "phone": "+70156921693"}
0005432567609	EB52B0	7630 582768	YANA NIKOLAEVA	{"email": "yananikolaeva_1962@postgrespro.ru", "phone": "+70797422522"}
0005432567610	EB52B0	5659 572847	EVA VASILEVA	{"phone": "+70221865166"}
0005432567611	B76F57	1914 770385	KRISTINA ZAKHAROVA	{"email": "zakharova-k1986@postgrespro.ru", "phone": "+70537091608"}
0005432567612	B76F57	5375 980054	ALEKSEY SOROKIN	{"email": "a.sorokin.17061986@postgrespro.ru", "phone": "+70107409212"}
0005432567613	7B57B4	6858 040504	ALEKSEY SMIRNOV	{"phone": "+70475208835"}
0005432567614	FE9995	8764 209824	VLADIMIR SHEVCHENKO	{"email": "v-shevchenko.011970@postgrespro.ru", "phone": "+70703809057"}
0005432567615	180ACA	2523 317900	ELENA ANDREEVA	{"email": "eandreeva.1972@postgrespro.ru", "phone": "+70618803074"}
0005432567616	180ACA	2028 039709	RUFIYA NIKOLAEVA	{"email": "rufiya.nikolaeva.041975@postgrespro.ru", "phone": "+70167089041"}
0005432567617	8B41BD	9273 385757	MARIYA YUDINA	{"email": "yudinam.1987@postgrespro.ru", "phone": "+70132012900"}
0005432567618	860C9D	5375 024317	ANTON ZAKHAROV	{"email": "antonzakharov-1957@postgrespro.ru", "phone": "+70823288911"}
0005432567619	860C9D	0480 016438	GALINA ZAKHAROVA	{"email": "g.zakharova-021964@postgrespro.ru", "phone": "+70087647635"}
0005432567620	675B1C	5161 357920	ANATOLIY FOMIN	{"email": "afomin22101969@postgrespro.ru", "phone": "+70822111078"}
0005432567621	F7FDAC	5732 091128	OLGA SEMENOVA	{"phone": "+70049527020"}
0005432567622	2D877C	9674 745677	NIKOLAY ROMANOV	{"phone": "+70556697195"}
0005432567623	469F6C	0571 598725	IVAN SHEVCHENKO	{"email": "shevchenkoivan.1967@postgrespro.ru", "phone": "+70663637294"}
0005432567624	469F6C	5274 124278	ALEKSANDR FILIPPOV	{"phone": "+70584767330"}
0005432567626	29EF37	2640 787187	ANTONINA ALEKSANDROVA	{"email": "aaleksandrova121964@postgrespro.ru", "phone": "+70170566375"}
0005432567627	29EF37	4989 167539	SERGEY PAVLOV	{"email": "sergey-pavlov14101979@postgrespro.ru", "phone": "+70000834523"}
0005432567628	A3B295	3163 676820	DENIS ZAYCEV	{"phone": "+70695179206"}
0005432567629	714370	3285 020457	YANA KUZNECOVA	{"phone": "+70328577771"}
0005432567630	4D2AEC	1852 299343	DMITRIY SAVELEV	{"phone": "+70529720614"}
0005432567631	DF1FA8	0623 405472	VITALIY ALEKSEEV	{"email": "alekseevvitaliy11061974@postgrespro.ru", "phone": "+70089263051"}
0005432567632	DF1FA8	6546 268433	VADIM FROLOV	{"phone": "+70492673295"}
0005432567633	DF1FA8	8693 924784	VERONIKA FEDOROVA	{"email": "veronikafedorova1976@postgrespro.ru", "phone": "+70386374609"}
0005432567634	628C48	1838 318771	ELENA RYABOVA	{"email": "elenaryabova-091961@postgrespro.ru", "phone": "+70687326826"}
0005432567635	E0D798	9453 357505	VALERIY KRASNOV	{"phone": "+70487567248"}
0005432567636	D16C36	8042 551330	VLADIMIR NOVIKOV	{"phone": "+70477849614"}
0005432567637	25CDDE	5330 169107	VENERA MELNIKOVA	{"email": "melnikovavenera-1978@postgrespro.ru", "phone": "+70674931248"}
0005432567638	12B287	2071 938762	OLEG SCHERBAKOV	{"email": "oscherbakov-071976@postgrespro.ru", "phone": "+70270033527"}
0005432567639	74AE96	9565 294267	VALENTINA DMITRIEVA	{"email": "vdmitrieva1974@postgrespro.ru", "phone": "+70764239194"}
0005432567640	74AE96	6036 814302	YURIY NIKITIN	{"email": "yuriy.nikitin.1983@postgrespro.ru", "phone": "+70607393376"}
0005432567641	949729	4831 978507	DENIS SCHERBAKOV	{"email": "denis_scherbakov26041970@postgrespro.ru", "phone": "+70020108059"}
0005432567642	949729	2138 138359	MAKSIM MELNIKOV	{"email": "m_melnikov-031973@postgrespro.ru", "phone": "+70539707747"}
0005432567643	949729	2878 403232	TIMUR GUSEV	{"phone": "+70920757892"}
0005432567644	949729	6094 437453	EVGENIY NIKITIN	{"email": "evgeniy.nikitin-23041973@postgrespro.ru", "phone": "+70503569029"}
0005432567645	81C777	1964 073281	SERGEY ISAEV	{"email": "s-isaev_031956@postgrespro.ru", "phone": "+70213303418"}
0005432567646	D49811	2578 089579	MAKSIM POPOV	{"email": "maksim.popov_101966@postgrespro.ru", "phone": "+70488545352"}
0005432567647	EB1C1D	3202 695450	SERGEY GAVRILOV	{"phone": "+70310263294"}
0005432567648	A6D955	0213 516629	SVETLANA STEPANOVA	{"phone": "+70615862970"}
0005432567649	9285AF	8068 568416	OLEG DENISOV	{"email": "olegdenisov-1970@postgrespro.ru", "phone": "+70428007417"}
0005432567650	9285AF	4326 381211	SERGEY VOLKOV	{"phone": "+70710789936"}
0005432567651	386DC9	5709 878382	TATYANA SOLOVEVA	{"email": "t_soloveva-18091964@postgrespro.ru", "phone": "+70447385877"}
0005432567652	4102EA	2602 746137	KONSTANTIN DENISOV	{"phone": "+70026952525"}
0005432567653	67407B	2831 468908	ARKADIY SAVELEV	{"email": "arkadiysavelev.14051961@postgrespro.ru", "phone": "+70192452945"}
0005432567654	EF25EB	4251 620569	OLGA GERASIMOVA	{"email": "olga-gerasimova-05021969@postgrespro.ru", "phone": "+70001388544"}
0005432567655	243920	7465 050094	ANTON SOROKIN	{"email": "a.sorokin.03011975@postgrespro.ru", "phone": "+70763584467"}
0005432567656	243920	6410 355080	MIKHAIL MARTYNOV	{"phone": "+70078626150"}
0005432567657	0C8477	8765 826904	NIKOLAY MOROZOV	{"phone": "+70322451631"}
0005432567658	6EAA95	3410 576378	DMITRIY PAVLOV	{"email": "dmitriy_pavlov_18071966@postgrespro.ru", "phone": "+70493068762"}
0005432567659	6EAA95	9788 983503	YURIY KRASNOV	{"email": "yuriy.krasnov.031976@postgrespro.ru", "phone": "+70273327825"}
0005432567660	16F542	2421 303248	GALINA KUZNECOVA	{"email": "g.kuznecova1979@postgrespro.ru", "phone": "+70961082763"}
0005432567661	AE4CA0	1189 335381	VALENTINA KOZLOVA	{"phone": "+70350120617"}
0005432567662	3327E2	9313 029432	ALEKSANDR ILIN	{"email": "aleksandrilin_24051962@postgrespro.ru", "phone": "+70091078350"}
0005432567663	3327E2	4784 463160	SERGEY BONDARENKO	{"email": "sergey-bondarenko091975@postgrespro.ru", "phone": "+70456233471"}
0005432567664	861187	2924 442701	ZOYA ALEKSANDROVA	{"email": "zaleksandrova_30081966@postgrespro.ru", "phone": "+70370352280"}
0005432567665	68093B	5078 517367	MIKHAIL PETROV	{"phone": "+70038877306"}
0005432567666	B7A7A0	8733 388780	VLADIMIR MOROZOV	{"email": "morozov.vladimir28041974@postgrespro.ru", "phone": "+70125521842"}
0005432567667	B5A884	5621 785675	LYUDMILA YAKOVLEVA	{"email": "l-yakovleva031983@postgrespro.ru", "phone": "+70862879487"}
0005432567668	C55EC5	5266 250914	VLADIMIR IVANOV	{"phone": "+70378967421"}
0005432567669	C55EC5	8089 271303	ELENA NIKOLAEVA	{"phone": "+70256401106"}
0005432567670	11A35B	7502 830278	ELENA POPOVA	{"email": "e_popova-011970@postgrespro.ru", "phone": "+70213324946"}
0005432567671	11A35B	7811 795560	TATYANA GUSEVA	{"phone": "+70741754810"}
0005432567672	1C5CEB	4580 388381	ANATOLIY KULIKOV	{"email": "anatoliy-kulikov.14091981@postgrespro.ru", "phone": "+70897299987"}
0005432567673	1C5CEB	1346 259452	VALENTINA IVANOVA	{"phone": "+70791931185"}
0005432567674	9B9FDF	8503 100386	LIDIYA SEMENOVA	{"email": "l-semenova_1968@postgrespro.ru", "phone": "+70419069762"}
0005432567675	9B9FDF	3701 656849	DMITRIY SHEVCHENKO	{"email": "dmitriy_shevchenko14041978@postgrespro.ru", "phone": "+70428427906"}
0005432567676	752DB8	2415 374619	IGOR FILIPPOV	{"email": "i.filippov.15051980@postgrespro.ru", "phone": "+70527210168"}
0005432567677	752DB8	7073 693472	EVGENIYA VASILEVA	{"phone": "+70326173994"}
0005432567678	22C209	5765 160952	ALBERT NOVIKOV	{"email": "novikov.albert1970@postgrespro.ru", "phone": "+70449888451"}
0005432567679	86626D	5626 951515	NIKOLAY KRASNOV	{"phone": "+70778587848"}
0005432567680	86626D	0235 668601	KIRILL IVANOV	{"phone": "+70944117272"}
0005432567681	DC4BCD	9550 759694	ALENA ZHUKOVA	{"email": "zhukova-alena.1972@postgrespro.ru", "phone": "+70730628380"}
0005432567682	DC4BCD	3532 584578	ZINAIDA DANILOVA	{"email": "danilova.zinaida_101976@postgrespro.ru", "phone": "+70618344580"}
0005432567683	790D66	1566 613390	OLGA KULIKOVA	{"email": "olgakulikova101976@postgrespro.ru", "phone": "+70397777901"}
0005432567684	790D66	1374 128444	KONSTANTIN KRASNOV	{"email": "krasnov.konstantin.12021970@postgrespro.ru", "phone": "+70777581459"}
0005432567685	790D66	5106 321093	YURIY ANDREEV	{"phone": "+70168669294"}
0005432567686	1B1507	2314 338613	SVETLANA AKIMOVA	{"phone": "+70785142735"}
0005432567687	C788FA	1356 707855	IRINA SOLOVEVA	{"phone": "+70755849204"}
0005432567688	9DC721	4987 658345	MARIYA NESTEROVA	{"email": "nesterova-m_1959@postgrespro.ru", "phone": "+70170957391"}
0005432567689	342B0D	1116 151921	PAVEL DENISOV	{"phone": "+70906976765"}
0005432567690	342B0D	5466 315623	GALINA BELOVA	{"email": "belova.galina_1969@postgrespro.ru", "phone": "+70004908590"}
0005432567691	E20FEC	3797 080179	NIKOLAY MELNIKOV	{"email": "melnikov.n_1974@postgrespro.ru", "phone": "+70283110125"}
0005432567692	240D78	7573 509355	ELENA ZHUKOVA	{"phone": "+70969138366"}
0005432567693	447712	2574 702269	ILDAR BELOV	{"email": "belov.ildar.091965@postgrespro.ru", "phone": "+70875756992"}
0005432567694	F1D909	4901 627730	NINA PAVLOVA	{"email": "n.pavlova-1968@postgrespro.ru", "phone": "+70192037229"}
0005432567695	931344	9277 047549	TATYANA KOROLEVA	{"email": "korolevat_051973@postgrespro.ru", "phone": "+70798545415"}
0005432567696	931344	5832 174859	NIKOLAY DAVYDOV	{"email": "davydov-n.1971@postgrespro.ru", "phone": "+70688652922"}
0005432567697	2FD91E	8134 072446	VIKTOR IVANOV	{"phone": "+70143069039"}
0005432567698	2FD91E	9400 847326	ELENA TITOVA	{"email": "titova_e_1965@postgrespro.ru", "phone": "+70025240070"}
0005432567699	B854F6	3018 876347	DMITRIY ILIN	{"phone": "+70088160076"}
0005432567700	57C2D1	3531 128023	GEORGIY ORLOV	{"phone": "+70994445581"}
0005432567701	B1259E	5323 129423	IGOR KUDRYASHOV	{"email": "kudryashov-i-1973@postgrespro.ru", "phone": "+70076301299"}
0005432567702	B1259E	8587 099799	VALENTINA ZAKHAROVA	{"phone": "+70460170477"}
0005432567703	16F2C4	9864 375355	ELENA NIKITINA	{"email": "elena.nikitina_05101978@postgrespro.ru", "phone": "+70377764786"}
0005432567704	5EEFBF	4924 823733	TATYANA MOROZOVA	{"email": "t_morozova021991@postgrespro.ru", "phone": "+70980964993"}
0005432567705	5EEFBF	8072 602420	ALEKSANDR TIMOFEEV	{"phone": "+70613472831"}
0005432567706	7062EA	6503 802002	DMITRIY MIRONOV	{"email": "d_mironov021962@postgrespro.ru", "phone": "+70772938743"}
0005432567707	F2E686	1256 868924	LYUDMILA IVANOVA	{"phone": "+70923229192"}
0005432567708	F2E686	3063 995518	ALEKSANDR BARANOV	{"email": "baranov_aleksandr011964@postgrespro.ru", "phone": "+70366207563"}
0005432567709	6799A7	9788 268861	ELIZAVETA SOROKINA	{"phone": "+70970893815"}
0005432567710	30644A	5515 922582	STANISLAV SCHERBAKOV	{"phone": "+70282500634"}
0005432567711	819E25	0561 642187	ALEKSANDR GORBUNOV	{"email": "gorbunov_a.041975@postgrespro.ru", "phone": "+70096200650"}
0005432567712	FB33B7	4352 365369	VITALIY VOROBEV	{"email": "vorobev_vitaliy061959@postgrespro.ru", "phone": "+70381941201"}
0005432567713	74C22D	2574 195132	ANDREY FROLOV	{"email": "afrolov-14081967@postgrespro.ru", "phone": "+70136776426"}
0005432567714	2CED26	5275 461387	EGOR FILIPPOV	{"email": "egor.filippov.071973@postgrespro.ru", "phone": "+70025039811"}
0005432567715	2CED26	3683 603868	ALEKSANDR KUZMIN	{"email": "kuzmina.30041964@postgrespro.ru", "phone": "+70340775893"}
0005432567716	0825B9	1585 880511	GALINA LAZAREVA	{"email": "glazareva_01121974@postgrespro.ru", "phone": "+70364496420"}
0005432567717	BF751B	6411 351154	ALEKSANDR ZAKHAROV	{"phone": "+70256544905"}
0005432567718	BF751B	7118 476087	GRIGORIY IVANOV	{"phone": "+70971879097"}
0005432567719	8A5186	1252 587605	GEORGIY VOROBEV	{"email": "vorobevgeorgiy.071978@postgrespro.ru", "phone": "+70689817411"}
0005432567720	0D7395	2202 418639	LIDIYA LUKYANOVA	{"phone": "+70443062197"}
0005432567721	E1E87B	1033 326137	VITALIY SOLOVEV	{"phone": "+70605024305"}
0005432567722	FB7297	1665 684308	YURIY NIKITIN	{"email": "nikitin.y.081968@postgrespro.ru", "phone": "+70138255587"}
0005432567723	532E0E	1616 348128	KONSTANTIN NOVIKOV	{"email": "konstantin-novikov.071959@postgrespro.ru", "phone": "+70841839232"}
0005432567724	3901DC	2514 191318	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov20091980@postgrespro.ru", "phone": "+70309427536"}
0005432567725	3901DC	3512 419851	DMITRIY ISAEV	{"email": "dmitriy-isaev.14091979@postgrespro.ru", "phone": "+70254455173"}
0005432567726	A1F0EE	2406 023047	SERGEY MAKSIMOV	{"email": "smaksimov-031968@postgrespro.ru", "phone": "+70771315883"}
0005432567727	431E3B	0010 632098	GALINA ZAYCEVA	{"phone": "+70839758077"}
0005432567728	A304B4	3785 553383	IGOR NOVIKOV	{"email": "novikovi.111988@postgrespro.ru", "phone": "+70258219157"}
0005432567729	429FA2	4963 819702	YURIY MATVEEV	{"email": "matveev-yuriy.081972@postgrespro.ru", "phone": "+70429408731"}
0005432567730	1F2EBD	1248 573283	ALBERT KRASNOV	{"phone": "+70192953969"}
0005432567731	CD3276	4673 101536	OLEG POPOV	{"email": "oleg-popov-27111977@postgrespro.ru", "phone": "+70463825423"}
0005432567732	9A4675	2802 937555	ELENA ORLOVA	{"phone": "+70290692492"}
0005432567733	9A4675	7889 896077	SVETLANA BORISOVA	{"phone": "+70254264962"}
0005432567734	A34EF6	9938 817385	ELIZAVETA DMITRIEVA	{"phone": "+70018135627"}
0005432567735	6230D4	1728 738399	LYUBOV ANISIMOVA	{"phone": "+70456443870"}
0005432567790	01661B	2646 928990	MARAT SEMENOV	{"phone": "+70924710039"}
0005432567736	A521AF	4561 208768	ALEKSEY TIMOFEEV	{"email": "aleksey.timofeev_1975@postgrespro.ru", "phone": "+70419398247"}
0005432567737	768FA2	3792 016376	NIKOLAY FOMIN	{"phone": "+70850009758"}
0005432567738	BDDCF6	5345 289495	NIKOLAY KISELEV	{"email": "nikolaykiselev-021985@postgrespro.ru", "phone": "+70579377556"}
0005432567739	BDDCF6	9716 820049	DMITRIY NIKITIN	{"email": "dmitriy.nikitin.31031973@postgrespro.ru", "phone": "+70912652322"}
0005432567740	D134DC	1324 240916	VALERIY VASILEV	{"email": "vasilev.v_021971@postgrespro.ru", "phone": "+70619097285"}
0005432567741	55F1EC	3314 994527	OLEG SIDOROV	{"email": "sidorov.o.1971@postgrespro.ru", "phone": "+70073038271"}
0005432567742	04A36D	1375 437245	SVETLANA KARPOVA	{"phone": "+70303237508"}
0005432567743	6461C2	6307 379614	MARGARITA NIKIFOROVA	{"phone": "+70578383100"}
0005432567744	8C2D36	3641 944231	NINA MAKSIMOVA	{"email": "nina_maksimova.1963@postgrespro.ru", "phone": "+70934763856"}
0005432567745	09BE98	0412 937686	YULIYA ANDREEVA	{"email": "andreevayuliya-01121971@postgrespro.ru", "phone": "+70569965536"}
0005432567746	09BE98	4688 969661	NATALYA NAZAROVA	{"email": "natalya.nazarova.06071983@postgrespro.ru", "phone": "+70801502065"}
0005432567747	6DC43A	6299 720604	SERGEY KUZMIN	{"phone": "+70618575913"}
0005432567748	75B02C	1621 882717	VIKTOR DAVYDOV	{"phone": "+70358275016"}
0005432567749	97B9E0	9138 825766	AZAT EGOROV	{"email": "azat-egorov1965@postgrespro.ru", "phone": "+70587498224"}
0005432567750	12788A	5645 912949	MIKHAIL SCHERBAKOV	{"phone": "+70532200769"}
0005432567751	3BB3FC	4083 605356	MILENA VOROBEVA	{"email": "vorobeva_m-1968@postgrespro.ru", "phone": "+70816223699"}
0005432567752	3BB3FC	4750 150156	LYUDMILA MASLOVA	{"email": "lyudmila_maslova_1981@postgrespro.ru", "phone": "+70643362891"}
0005432567753	6CEEF1	1399 470828	DAMIR SIDOROV	{"email": "sidorov_damir_31011968@postgrespro.ru", "phone": "+70068553640"}
0005432567754	BEF923	7599 707891	OLGA GORBUNOVA	{"phone": "+70234721732"}
0005432567755	D8E8E3	8446 584330	LYUDMILA SAVELEVA	{"email": "saveleva.l-1964@postgrespro.ru", "phone": "+70901295491"}
0005432567756	167ADA	1158 510720	YURIY VOROBEV	{"email": "vorobev-yuriy1980@postgrespro.ru", "phone": "+70330054825"}
0005432567757	B5C57E	5200 892073	VITALIY DMITRIEV	{"phone": "+70041431405"}
0005432567758	B5C57E	6100 238523	SVETLANA SMIRNOVA	{"email": "smirnova.s_12091974@postgrespro.ru", "phone": "+70492088945"}
0005432567759	FD1381	6499 979826	SERGEY PAVLOV	{"email": "pavlov.sergey1972@postgrespro.ru", "phone": "+70287394960"}
0005432567760	FD1381	3924 524792	ROMAN ALEKSEEV	{"email": "alekseev-r1976@postgrespro.ru", "phone": "+70948596654"}
0005432567761	B27798	3656 731128	DMITRIY ILIN	{"email": "dmitriyilin031973@postgrespro.ru", "phone": "+70705830830"}
0005432567762	B27798	1947 686532	YURIY FILIPPOV	{"email": "filippov_y_16101967@postgrespro.ru", "phone": "+70294204852"}
0005432567763	CF5FE0	1581 555116	ELENA GORBUNOVA	{"phone": "+70852813366"}
0005432567764	CF5FE0	3322 874652	GALINA PAVLOVA	{"phone": "+70533866971"}
0005432567765	CF5FE0	5991 329894	SVETLANA SEMENOVA	{"email": "ssemenova-21111965@postgrespro.ru", "phone": "+70412549563"}
0005432567766	31F093	0436 711864	LYUDMILA KUZNECOVA	{"phone": "+70323710670"}
0005432567767	31F093	6869 002133	ALBINA IVANOVA	{"phone": "+70194385319"}
0005432567768	B2C2DF	5774 787314	DANIIL MATVEEV	{"email": "daniil_matveev_19051981@postgrespro.ru", "phone": "+70399396071"}
0005432567769	B2C2DF	6670 414833	ALEKSANDR MELNIKOV	{"phone": "+70979051880"}
0005432567770	ECF857	5541 903309	VASILIY NAZAROV	{"email": "nazarov_v.1993@postgrespro.ru", "phone": "+70731335637"}
0005432567771	ECF857	3727 551428	OLGA ERMAKOVA	{"email": "oermakova1970@postgrespro.ru", "phone": "+70645064976"}
0005432567772	1C73E6	5844 215355	NINA ILINA	{"email": "nina-ilina.1983@postgrespro.ru", "phone": "+70661843062"}
0005432567773	88086C	5184 240195	ANTONINA IVANOVA	{"email": "a-ivanova.30031971@postgrespro.ru", "phone": "+70815931201"}
0005432567774	1369CE	0757 214264	ANDREY MAKAROV	{"email": "andreymakarov.11021967@postgrespro.ru", "phone": "+70121645925"}
0005432567775	2A773E	0516 777899	ANNA FILIPPOVA	{"email": "filippovaanna_1990@postgrespro.ru", "phone": "+70253268474"}
0005432567776	CB3AC8	3115 948093	LYUDMILA NAUMOVA	{"email": "naumovalyudmila_30041977@postgrespro.ru", "phone": "+70876922674"}
0005432567777	3D59F0	3401 526088	TATYANA KOMAROVA	{"email": "tatyana_komarova.121967@postgrespro.ru", "phone": "+70472127258"}
0005432567778	54535B	0699 192991	ALEKSANDR CHERNOV	{"email": "chernova.1974@postgrespro.ru", "phone": "+70468300032"}
0005432567781	6E0F06	4447 541178	MAKSIM SERGEEV	{"phone": "+70555318780"}
0005432567782	902A54	9921 499435	LYUDMILA IVANOVA	{"phone": "+70347104687"}
0005432567896	4D13AB	5828 844244	SERGEY MOROZOV	{"phone": "+70810726606"}
0005432567783	FDCB45	6275 822569	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr_1974@postgrespro.ru", "phone": "+70815639565"}
0005432567784	185EE2	5634 502194	NIKITA AFANASEV	{"phone": "+70796893761"}
0005432567785	185EE2	9557 615213	MARINA KUDRYASHOVA	{"phone": "+70050382867"}
0005432567786	185EE2	6117 441600	MIKHAIL MATVEEV	{"phone": "+70284405419"}
0005432567787	6A25B2	5278 962433	SVETLANA ZAKHAROVA	{"phone": "+70395085528"}
0005432567788	DED6BA	0047 070701	LYUDMILA GUSEVA	{"email": "lyudmila.guseva.26071964@postgrespro.ru", "phone": "+70404973559"}
0005432567789	DED6BA	3006 459053	KLAVDIYA ZAYCEVA	{"email": "k.zayceva_29101975@postgrespro.ru", "phone": "+70623127440"}
0005432567791	01661B	7976 818140	DARYA KUZMINA	{"email": "dkuzmina_26061975@postgrespro.ru", "phone": "+70333993145"}
0005432567792	B8C7C3	5369 615617	VITALIY KRASNOV	{"email": "vitaliy.krasnov_061986@postgrespro.ru", "phone": "+70089266219"}
0005432567793	B8C7C3	4562 286594	ANASTASIYA FEDOROVA	{"phone": "+70752087388"}
0005432567794	3DB175	9079 074855	NATALYA NIKITINA	{"email": "nnikitina021975@postgrespro.ru", "phone": "+70766774165"}
0005432567795	3DB175	5981 952872	YULIYA ORLOVA	{"email": "orlovay-06081971@postgrespro.ru", "phone": "+70590842999"}
0005432567796	5DE6ED	0577 714187	LYUDMILA KONOVALOVA	{"email": "lyudmila-konovalova1969@postgrespro.ru", "phone": "+70803302949"}
0005432567797	E5D90B	5709 561751	IVAN SOKOLOV	{"email": "sokolov.i.091978@postgrespro.ru", "phone": "+70960119074"}
0005432567798	E5D90B	3191 366802	MIKHAIL NIKITIN	{"phone": "+70965162561"}
0005432567799	EB8F17	7344 113179	ARTEM KULIKOV	{"email": "akulikov.061975@postgrespro.ru", "phone": "+70629110750"}
0005432567800	44CD31	8589 216860	ALEKSEY SCHERBAKOV	{"phone": "+70588033380"}
0005432567801	8D28B7	9290 633049	VLADIMIR ALEKSEEV	{"phone": "+70116508269"}
0005432567802	2177BF	0568 116909	ALEKSANDR DAVYDOV	{"phone": "+70687265648"}
0005432567803	93A089	8798 743743	OLEG ALEKSANDROV	{"email": "aleksandrov.o_06021965@postgrespro.ru", "phone": "+70889136176"}
0005432567804	93A089	0092 295720	EVGENIY TIMOFEEV	{"phone": "+70923420015"}
0005432567805	B39FE4	8830 401648	EKATERINA IVANOVA	{"email": "ivanovae_121965@postgrespro.ru", "phone": "+70485672839"}
0005432567806	B39FE4	0023 507830	EVGENIY MELNIKOV	{"email": "melnikov-evgeniy021966@postgrespro.ru", "phone": "+70472023365"}
0005432567807	6EE0BC	5643 307588	ELENA IVANOVA	{"email": "ivanova.elena_15071975@postgrespro.ru", "phone": "+70424215727"}
0005432567808	F76512	8784 975466	SEMEN DAVYDOV	{"phone": "+70850619934"}
0005432567809	5122AA	1036 276454	NIKOLAY ISAEV	{"email": "isaevnikolay_11041971@postgrespro.ru", "phone": "+70270748582"}
0005432567810	083539	7921 209198	ANNA PETROVA	{"phone": "+70561035176"}
0005432567811	6E8BF4	4313 404644	GULNARA NIKIFOROVA	{"email": "gnikiforova_1966@postgrespro.ru", "phone": "+70634368271"}
0005432567812	E448A0	2825 106021	YURIY ROMANOV	{"email": "yromanov23081975@postgrespro.ru", "phone": "+70652079676"}
0005432567813	E448A0	6158 402107	NIKITA MATVEEV	{"phone": "+70978413897"}
0005432567814	426220	9389 691876	SERGEY MOROZOV	{"phone": "+70895207939"}
0005432567815	426220	1188 734861	NATALYA ILINA	{"email": "ilinanatalya14081973@postgrespro.ru", "phone": "+70919830496"}
0005432567816	D7147F	4528 016414	LUIZA SOROKINA	{"email": "l.sorokina-101975@postgrespro.ru", "phone": "+70309469601"}
0005432567817	485018	4404 524228	DARYA ILINA	{"phone": "+70802143235"}
0005432567818	152E18	2414 067040	VASILIY AFANASEV	{"email": "afanasev-vasiliy11091972@postgrespro.ru", "phone": "+70475782428"}
0005432567819	152E18	7564 680971	MARINA KRASNOVA	{"email": "m.krasnova-1974@postgrespro.ru", "phone": "+70616041109"}
0005432567820	783498	8660 929482	TATYANA VLASOVA	{"phone": "+70684449776"}
0005432567821	783498	6990 980307	IRINA LUKYANOVA	{"email": "irina.lukyanova1986@postgrespro.ru", "phone": "+70525123277"}
0005432567822	458C21	7369 030746	VLADIMIR SEMENOV	{"email": "semenov.vladimir-21091980@postgrespro.ru", "phone": "+70742314957"}
0005432567823	0F21EC	1061 824660	VITALIY BORISOV	{"email": "borisov_v_05021966@postgrespro.ru", "phone": "+70938232251"}
0005432567824	05685F	4824 311426	OLGA GERASIMOVA	{"email": "o-gerasimova_081974@postgrespro.ru", "phone": "+70417727704"}
0005432567825	A5784B	2085 844503	ANNA VOROBEVA	{"phone": "+70734481453"}
0005432567826	8311A8	6183 209448	NATALIYA RYABOVA	{"email": "ryabovanataliya.031973@postgrespro.ru", "phone": "+70827797136"}
0005432567827	8311A8	6334 238958	DMITRIY CHERNOV	{"email": "dmitriy_chernov_031968@postgrespro.ru", "phone": "+70153156306"}
0005432567828	8311A8	6721 389441	YURIY NIKOLAEV	{"phone": "+70761022497"}
0005432567829	8B7EFA	3802 467308	NIKOLAY AFANASEV	{"phone": "+70151309541"}
0005432567830	D6E088	1107 542115	ANDREY SERGEEV	{"phone": "+70014183264"}
0005432567831	D6E088	8033 058865	ANATOLIY MOROZOV	{"phone": "+70381623563"}
0005432567832	76053F	9144 477780	SERGEY KOZLOV	{"phone": "+70099983769"}
0005432567833	76053F	1118 433513	YURIY KUZMIN	{"phone": "+70324724918"}
0005432567834	76053F	8339 750751	OKSANA STEPANOVA	{"phone": "+70946304680"}
0005432567835	240133	9070 519697	DENIS POPOV	{"phone": "+70603600016"}
0005432567836	14A1A4	1330 740206	VADIM BORISOV	{"phone": "+70624533203"}
0005432567837	675485	0921 914164	SERGEY TIKHONOV	{"phone": "+70226669756"}
0005432567838	ECA942	3427 059332	IRINA IVANOVA	{"email": "ivanovai1954@postgrespro.ru", "phone": "+70865130035"}
0005432567839	43CF4C	8078 735892	ZINAIDA IVANOVA	{"email": "ivanovaz_17121973@postgrespro.ru", "phone": "+70397612858"}
0005432567840	1FF9AE	0310 357788	TATYANA YAKOVLEVA	{"email": "tyakovleva-021978@postgrespro.ru", "phone": "+70018380366"}
0005432567960	2279AF	2650 077931	VERA NAZAROVA	{"phone": "+70622378701"}
0005432567841	FF8439	2995 353857	YURIY ALEKSEEV	{"email": "alekseev-yuriy-091976@postgrespro.ru", "phone": "+70548651176"}
0005432567842	386971	6373 748190	NINA SEMENOVA	{"phone": "+70714714071"}
0005432567843	6778F1	1533 989032	PETR KOZLOV	{"email": "pkozlov_15111967@postgrespro.ru", "phone": "+70416220691"}
0005432567844	902FAE	2847 273018	ALEKSANDR BELOV	{"phone": "+70073991479"}
0005432567845	381F87	2343 030134	TATYANA NIKOLAEVA	{"phone": "+70407473867"}
0005432567846	E2B252	6394 860045	VLADIMIR ALEKSANDROV	{"phone": "+70586471895"}
0005432567847	E2B252	6914 701857	DINARA ALEKSEEVA	{"phone": "+70718820012"}
0005432567848	42207C	1529 415688	IRINA TIKHONOVA	{"email": "tikhonova.irina.021976@postgrespro.ru", "phone": "+70180769935"}
0005432567849	42207C	6039 019405	ANASTASIYA ZAYCEVA	{"email": "a.zayceva_1990@postgrespro.ru", "phone": "+70418479787"}
0005432567850	84333F	6569 976703	VALENTIN VOROBEV	{"phone": "+70862603532"}
0005432567851	84333F	4673 278599	ALEKSEY SIDOROV	{"email": "sidorovaleksey1978@postgrespro.ru", "phone": "+70187378496"}
0005432567852	8BD7B0	2066 885774	ALEKSANDR FILIPPOV	{"phone": "+70621305454"}
0005432567853	7470E3	3491 514581	YULIYA GRISHINA	{"email": "yuliya_grishina.041962@postgrespro.ru", "phone": "+70779072927"}
0005432567854	44ECF6	9936 546083	RAISA ILINA	{"phone": "+70020321590"}
0005432567855	F33458	2571 922909	ANNA MASLOVA	{"email": "a.maslova-1965@postgrespro.ru", "phone": "+70837207788"}
0005432567856	88A3E3	7403 744548	SERGEY VOLKOV	{"phone": "+70538802290"}
0005432567857	F2E45B	0513 547432	ALSU YAKOVLEVA	{"email": "yakovlevaa1974@postgrespro.ru", "phone": "+70490885687"}
0005432567858	C140FD	1736 986169	YULIYA MIKHAYLOVA	{"phone": "+70100932958"}
0005432567859	230D87	7718 046996	ANTONINA KUZMINA	{"email": "antonina.kuzmina_1961@postgrespro.ru", "phone": "+70493093327"}
0005432567860	0FACFE	7277 535048	ANASTASIYA NOVIKOVA	{"phone": "+70440445702"}
0005432567861	0FACFE	5983 836589	NATALYA GUSEVA	{"phone": "+70829672629"}
0005432567862	6F0A59	2346 823092	SOFYA VOROBEVA	{"phone": "+70736345765"}
0005432567863	1E94B1	9103 739194	LYUBOV VASILEVA	{"phone": "+70018099473"}
0005432567864	CCD2BE	2034 704018	VASILIY VOROBEV	{"phone": "+70100922045"}
0005432567865	CCD2BE	7479 882782	ELENA POTAPOVA	{"phone": "+70646235985"}
0005432567866	945CD7	3686 684941	ILYA NOVIKOV	{"email": "novikov.ilya_071972@postgrespro.ru", "phone": "+70772104944"}
0005432567867	E9D77E	2597 364523	OLGA SOLOVEVA	{"phone": "+70092339993"}
0005432567868	7D7FBB	0858 101875	EGOR PETROV	{"email": "petrov_egor-111965@postgrespro.ru", "phone": "+70199306677"}
0005432567869	F4ACAA	6870 624277	SVETLANA TIMOFEEVA	{"phone": "+70453318044"}
0005432567870	F4ACAA	6781 996402	ANNA SIDOROVA	{"phone": "+70102776138"}
0005432567871	BECBEF	7399 010428	VLADIMIR ANDREEV	{"phone": "+70440788318"}
0005432567872	D44F7D	4631 567644	GALINA ZAKHAROVA	{"email": "galina_zakharova121967@postgrespro.ru", "phone": "+70393078439"}
0005432567873	4BD611	4550 828117	NIKOLAY DAVYDOV	{"email": "davydov-nikolay_1970@postgrespro.ru", "phone": "+70252597279"}
0005432567874	4BD611	4684 549045	ANNA PETROVA	{"email": "petrovaa091963@postgrespro.ru", "phone": "+70319749218"}
0005432567875	B1D445	8198 846404	ROMAN IVANOV	{"phone": "+70846413838"}
0005432567876	67DC89	5693 777684	ALINA MASLOVA	{"phone": "+70871428831"}
0005432567877	8AD08F	6419 911318	SVETLANA ROMANOVA	{"email": "svetlana-romanova1974@postgrespro.ru", "phone": "+70971434297"}
0005432567878	8CB789	6713 487187	MARIYA VLASOVA	{"phone": "+70113530313"}
0005432567879	701DDC	3878 098620	VYACHESLAV SHEVCHENKO	{"phone": "+70088425478"}
0005432567880	701DDC	4834 792572	ALEKSEY IVANOV	{"email": "aleksey.ivanov121970@postgrespro.ru", "phone": "+70640985427"}
0005432567881	E4CECE	9944 654436	DMITRIY FROLOV	{"email": "frolovd.031974@postgrespro.ru", "phone": "+70023451742"}
0005432567882	BC96B3	4213 382299	ALEKSEY ILIN	{"email": "a-ilin-1966@postgrespro.ru", "phone": "+70893760605"}
0005432567883	FC55FE	1490 097769	ZARINA MIRONOVA	{"email": "mironova_zarina-091977@postgrespro.ru", "phone": "+70450067905"}
0005432567884	202195	9033 145333	ALEKSEY NAUMOV	{"email": "anaumov.101985@postgrespro.ru", "phone": "+70938900396"}
0005432567885	0F1400	6054 928484	EVGENIY SOROKIN	{"email": "esorokin1973@postgrespro.ru", "phone": "+70786807178"}
0005432567886	5C9EA3	7645 374305	ANNA VASILEVA	{"email": "avasileva_19111981@postgrespro.ru", "phone": "+70474413398"}
0005432567887	E9A3F4	2172 936501	VIKTOR ALEKSEEV	{"phone": "+70333014988"}
0005432567888	E9A3F4	0865 147863	BORIS KUZNECOV	{"email": "bkuznecov_1972@postgrespro.ru", "phone": "+70690603792"}
0005432567889	11B1FA	0987 411925	ANDREY ORLOV	{"email": "orlov_a-1979@postgrespro.ru", "phone": "+70583061518"}
0005432567890	11B1FA	8041 825202	ROMAN NIKOLAEV	{"email": "nikolaev_roman_021971@postgrespro.ru", "phone": "+70738697007"}
0005432567891	F077CB	8583 830501	MIKHAIL NOVIKOV	{"phone": "+70730368155"}
0005432567892	7709D7	9616 676300	NATALYA GAVRILOVA	{"phone": "+70871577197"}
0005432567893	97CAC2	0263 860479	ANNA SOLOVEVA	{"phone": "+70228837492"}
0005432567894	97CAC2	9749 662829	ELIZAVETA KUZNECOVA	{"phone": "+70809076889"}
0005432567895	4D13AB	3050 483906	GALINA NAUMOVA	{"phone": "+70524864360"}
0005432567897	E077B8	5716 204219	MAKSIM POPOV	{"phone": "+70463360473"}
0005432567898	D0BA1E	4142 024188	SOFIYA POPOVA	{"phone": "+70863673718"}
0005432567899	30C451	7374 646372	ELENA MAKAROVA	{"phone": "+70268636584"}
0005432567900	9BA18A	8749 743593	VLADIMIR SMIRNOV	{"phone": "+70983221663"}
0005432567901	7502BA	0042 676060	VIKTORIYA IVANOVA	{"phone": "+70666278179"}
0005432567902	3FD658	3280 157262	AYRAT MELNIKOV	{"email": "ayrat_melnikov1975@postgrespro.ru", "phone": "+70412898725"}
0005432567903	CE0DA4	1087 608129	SVETLANA IVANOVA	{"phone": "+70309698008"}
0005432567904	CE0DA4	7251 949276	DAMIR MOROZOV	{"email": "morozov.damir.07081968@postgrespro.ru", "phone": "+70485769053"}
0005432567905	D1C1F9	2829 560339	ANATOLIY IVANOV	{"email": "anatoliy_ivanov_101971@postgrespro.ru", "phone": "+70593915496"}
0005432567906	D0F71B	5509 171078	VALERIY NIKITIN	{"email": "valeriynikitin-051970@postgrespro.ru", "phone": "+70171065408"}
0005432567907	DCAE44	2196 168638	LYUBOV SERGEEVA	{"email": "l-sergeeva03011972@postgrespro.ru", "phone": "+70666376783"}
0005432567908	0B40A3	4610 049495	IVAN GORBUNOV	{"phone": "+70929643072"}
0005432567909	0B40A3	3559 665366	VASILIY GORBUNOV	{"phone": "+70386446457"}
0005432567910	090194	7163 700110	ANTON SAVELEV	{"email": "savelev-anton.1975@postgrespro.ru", "phone": "+70268605384"}
0005432567911	0D567F	6332 908399	OLGA KISELEVA	{"phone": "+70623556464"}
0005432567912	E81EE6	5145 245625	TAMARA MEDVEDEVA	{"email": "tamara.medvedeva_11111968@postgrespro.ru", "phone": "+70749142894"}
0005432567913	4D289C	9661 675956	ALEKSEY TARASOV	{"phone": "+70177480028"}
0005432567914	96E774	4699 099924	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr_101972@postgrespro.ru", "phone": "+70692464187"}
0005432567915	3715B4	6671 527826	MIKHAIL OSIPOV	{"phone": "+70800714783"}
0005432567916	D7866C	3202 883539	MARGARITA KOROLEVA	{"email": "koroleva.margarita_18051982@postgrespro.ru", "phone": "+70670542411"}
0005432567917	6CF939	5050 749853	NATALYA YUDINA	{"phone": "+70343711326"}
0005432567918	6CF939	4837 784854	OLEG MELNIKOV	{"phone": "+70408639704"}
0005432567919	244437	8127 802816	NATALYA FROLOVA	{"phone": "+70696154177"}
0005432567920	34FB21	2636 622369	YULIYA YAKOVLEVA	{"phone": "+70458924233"}
0005432567921	34FB21	5107 651308	KONSTANTIN VOLKOV	{"email": "konstantin-volkov-071971@postgrespro.ru", "phone": "+70676316197"}
0005432567922	3FBE47	9923 446824	NATALIYA EGOROVA	{"email": "n_egorova.20071978@postgrespro.ru", "phone": "+70364988615"}
0005432567923	FD56A3	2298 078408	MATVEY MIKHAYLOV	{"phone": "+70567420018"}
0005432567924	FDB28F	3914 583619	LIDIYA KISELEVA	{"email": "kiseleva-lidiya.1975@postgrespro.ru", "phone": "+70516648025"}
0005432567925	5C4E67	9323 656985	TATYANA DAVYDOVA	{"phone": "+70812340071"}
0005432567926	564813	3549 503126	VALENTINA GERASIMOVA	{"phone": "+70434572341"}
0005432567927	B76B6F	5571 585869	VALERIYA SOKOLOVA	{"email": "valeriyasokolova_1972@postgrespro.ru", "phone": "+70263321475"}
0005432567928	F72502	9467 349677	IRINA FROLOVA	{"email": "frolova-irina-1981@postgrespro.ru", "phone": "+70311957174"}
0005432567929	A498AA	4821 320398	ELENA PETROVA	{"email": "elena-petrova_28021968@postgrespro.ru", "phone": "+70784711126"}
0005432567930	A498AA	7302 120946	YURIY TARASOV	{"email": "y_tarasov_1985@postgrespro.ru", "phone": "+70164098170"}
0005432567931	3A0913	4898 734683	PELAGEYA TITOVA	{"phone": "+70258279137"}
0005432567932	73AF0A	1574 205123	ALINA IVANOVA	{"email": "ivanova.a_21061965@postgrespro.ru", "phone": "+70795165008"}
0005432567933	512241	1460 599170	NIKOLAY PETROV	{"email": "npetrov-011973@postgrespro.ru", "phone": "+70776793313"}
0005432567934	9634BF	0088 856463	EKATERINA SEMENOVA	{"phone": "+70606405427"}
0005432567935	8EECE7	4994 511211	ALEKSANDRA FROLOVA	{"email": "afrolova.1969@postgrespro.ru", "phone": "+70831623038"}
0005432567936	8EECE7	2865 253496	ANZHELA SEMENOVA	{"phone": "+70441306956"}
0005432567937	6CAD6D	1388 383440	SERGEY VLASOV	{"phone": "+70215777683"}
0005432567938	E8325D	5865 624443	ANASTASIYA TARASOVA	{"email": "a_tarasova-1981@postgrespro.ru", "phone": "+70311720513"}
0005432567939	3F3B3C	3041 065450	ANDREY ORLOV	{"email": "orlova.29041977@postgrespro.ru", "phone": "+70487149865"}
0005432567940	62ABF2	2084 331115	LYUDMILA NIKIFOROVA	{"email": "l_nikiforova_21061971@postgrespro.ru", "phone": "+70748641536"}
0005432567941	40E8AE	4955 601332	ALEKSANDRA VOLKOVA	{"phone": "+70297603335"}
0005432567942	40E8AE	8213 896974	ARTUR SAVELEV	{"email": "savelevartur.091974@postgrespro.ru", "phone": "+70651579434"}
0005432567943	7E01D8	9744 842964	ALEKSANDR KOZLOV	{"phone": "+70636110928"}
0005432567944	8BB16F	0304 207691	DENIS NIKOLAEV	{"email": "nikolaevdenis_05051976@postgrespro.ru", "phone": "+70465998924"}
0005432567945	8BB16F	8556 305428	OLESYA IVANOVA	{"email": "oivanova_24101964@postgrespro.ru", "phone": "+70371773370"}
0005432567946	9570E8	2084 698175	VYACHESLAV NIKITIN	{"email": "nikitinvyacheslav-1975@postgrespro.ru", "phone": "+70667661540"}
0005432567947	7CCB30	4628 920577	ALEKSEY KUZMIN	{"phone": "+70316349831"}
0005432567948	7CCB30	0955 713468	ANASTASIYA MAKAROVA	{"email": "anastasiya_makarova-24101982@postgrespro.ru", "phone": "+70011775412"}
0005432567949	C5E5E3	3036 317194	SERGEY IVANOV	{"email": "ivanov-s.1973@postgrespro.ru", "phone": "+70685181301"}
0005432567950	C3FD4B	8281 140844	NATALYA ZAKHAROVA	{"phone": "+70454486282"}
0005432567951	FA6C4C	1782 793715	RENAT KAZAKOV	{"phone": "+70800182210"}
0005432567952	59F95E	8242 841929	IRINA AFANASEVA	{"email": "iafanaseva20021967@postgrespro.ru", "phone": "+70757734863"}
0005432567953	9C9BFC	3680 763758	GALINA GERASIMOVA	{"email": "gerasimova-g1969@postgrespro.ru", "phone": "+70250541332"}
0005432567954	9C9BFC	0480 608223	NATALYA ISAEVA	{"email": "natalya_isaeva.011966@postgrespro.ru", "phone": "+70785741748"}
0005432567955	A2B276	7821 349693	IGOR ANDREEV	{"phone": "+70985766845"}
0005432567956	42DFF8	5702 739428	ALEKSANDR IVANOV	{"email": "a_ivanov-10081973@postgrespro.ru", "phone": "+70277646671"}
0005432567957	42DFF8	9495 124520	PETR DAVYDOV	{"email": "petrdavydov_021971@postgrespro.ru", "phone": "+70341391822"}
0005432567958	1FF1D0	7416 457184	DANIIL AFANASEV	{"phone": "+70309492032"}
0005432567959	1F85E5	3344 661954	NINA VOROBEVA	{"email": "n_vorobeva.101966@postgrespro.ru", "phone": "+70536000468"}
0005432567961	2279AF	8021 118948	ALEKSEY MELNIKOV	{"email": "melnikov-aleksey-1959@postgrespro.ru", "phone": "+70453297378"}
0005432567962	16451B	3464 391903	EVGENIY ALEKSANDROV	{"email": "aleksandrov_evgeniy_1979@postgrespro.ru", "phone": "+70317794984"}
0005432567963	16451B	7784 923786	NIKOLAY NAZAROV	{"phone": "+70121041949"}
0005432567964	82DFB1	1613 058491	VASILIY NIKITIN	{"email": "nikitin.v-18021969@postgrespro.ru", "phone": "+70365187812"}
0005432567965	1B0657	0772 691840	SERGEY YAKOVLEV	{"email": "sergey_yakovlev071974@postgrespro.ru", "phone": "+70244893016"}
0005432567966	997EC5	8209 512398	YURIY SEMENOV	{"phone": "+70456497945"}
0005432567967	3EC0EB	7540 079875	TATYANA RYABOVA	{"phone": "+70552223066"}
0005432567968	05FA81	8475 152522	NATALIYA MAKSIMOVA	{"phone": "+70486926465"}
0005432567969	196340	0501 608550	YULIANA BELOVA	{"phone": "+70718282671"}
0005432567970	196340	7260 259611	MIKHAIL STEPANOV	{"email": "stepanovmikhail.121970@postgrespro.ru", "phone": "+70202080912"}
0005432567971	5A8563	7872 301204	ALEKSANDR MOROZOV	{"phone": "+70231889226"}
0005432567972	52320E	7160 025724	YULIYA NOVIKOVA	{"phone": "+70047775188"}
0005432567973	8BDC41	2938 485555	TAISIYA MIRONOVA	{"email": "t_mironova-19061966@postgrespro.ru", "phone": "+70831372398"}
0005432567974	8BDC41	4692 935883	ARTEM NAZAROV	{"phone": "+70915638539"}
0005432567975	719C7F	5998 274913	GENNADIY DMITRIEV	{"phone": "+70017050993"}
0005432567976	317DCF	7935 440173	VLADIMIR TIKHONOV	{"phone": "+70520404213"}
0005432567977	F6998B	3659 207705	MAKSIM KAZAKOV	{"email": "maksimkazakov.091960@postgrespro.ru", "phone": "+70251687507"}
0005432567978	B4DB9D	8058 620801	DMITRIY FEDOROV	{"phone": "+70809518828"}
0005432567979	B6191C	9657 941342	ALEKSANDR MIKHAYLOV	{"phone": "+70392038139"}
0005432567980	4C1067	0041 675741	ALEKSEY OSIPOV	{"email": "aleksey-osipov_06081974@postgrespro.ru", "phone": "+70072911265"}
0005432567981	DFC801	9166 779021	YULIYA ANDREEVA	{"phone": "+70985236106"}
0005432567982	A59C80	3195 960276	YURIY BONDARENKO	{"phone": "+70227960840"}
0005432567983	391072	3862 347195	ALEKSEY MOROZOV	{"email": "morozov-a1976@postgrespro.ru", "phone": "+70395513668"}
0005432567984	92C6D6	8391 950391	ALEKSEY BORISOV	{"phone": "+70282267811"}
0005432567985	045282	1732 758007	TAMARA LUKYANOVA	{"phone": "+70980054196"}
0005432567986	59379B	4147 216204	ALEKSANDRA ANTONOVA	{"phone": "+70179337983"}
0005432567987	C13209	9671 215831	EVGENIY ANDREEV	{"phone": "+70378077629"}
0005432567988	CBD51A	4560 252383	ANTON NAZAROV	{"email": "antonnazarov111968@postgrespro.ru", "phone": "+70071420859"}
0005432567989	9C0F6F	2583 004094	ALEKSANDR PETROV	{"email": "a_petrov-1987@postgrespro.ru", "phone": "+70196390572"}
0005432567990	256BEF	7482 166228	ANDREY NOVIKOV	{"email": "novikova.1972@postgrespro.ru", "phone": "+70034756141"}
0005432567991	256BEF	3102 210337	SVETLANA STEPANOVA	{"phone": "+70959019548"}
0005432567992	754ED5	1976 984881	YULIYA NOVIKOVA	{"email": "yuliyanovikova021965@postgrespro.ru", "phone": "+70431490174"}
0005432567993	018558	0127 301730	SERGEY KRASNOV	{"email": "s-krasnov_091972@postgrespro.ru", "phone": "+70638890081"}
0005432567994	018558	4833 188518	OLEG SOROKIN	{"email": "oleg-sorokin_061967@postgrespro.ru", "phone": "+70005369500"}
0005432567995	83EC6A	9712 000224	TATYANA STEPANOVA	{"phone": "+70150012714"}
0005432567996	83EC6A	8554 084032	VALENTIN KOZLOV	{"phone": "+70228286944"}
0005432567997	83EC6A	8158 324428	SERGEY GUSEV	{"phone": "+70910538796"}
0005432567998	B08435	9955 914539	ANNA IVANOVA	{"email": "ivanova_a_10071973@postgrespro.ru", "phone": "+70946967691"}
0005432567999	B08435	0494 310918	YULIYA KUZNECOVA	{"phone": "+70607453879"}
0005432568000	01C97E	5562 145101	KONSTANTIN NOVIKOV	{"phone": "+70874123162"}
0005432568001	A18828	5006 092187	EVGENIY KUDRYASHOV	{"email": "kudryashov.e1972@postgrespro.ru", "phone": "+70344575594"}
0005432568002	C4ED08	4618 241577	LYUBOV GAVRILOVA	{"phone": "+70699843549"}
0005432568003	4D49CD	5927 906525	ELENA BELYAEVA	{"email": "elena_belyaeva-031969@postgrespro.ru", "phone": "+70813519452"}
0005432568004	E865CC	5610 651347	LYUBOV VASILEVA	{"email": "vasileva_l1969@postgrespro.ru", "phone": "+70666808950"}
0005432568005	0CA0C6	1951 282007	IGOR VASILEV	{"email": "igor.vasilev.021970@postgrespro.ru", "phone": "+70681261254"}
0005432568006	8FD723	5119 071581	MIKHAIL ZAKHAROV	{"email": "zakharov-m1979@postgrespro.ru", "phone": "+70511078844"}
0005432568007	8FD723	9507 461696	YULIYA EGOROVA	{"email": "y_egorova_1966@postgrespro.ru", "phone": "+70260605782"}
0005432568008	63F748	7858 980367	EKATERINA KUZMINA	{"phone": "+70220156092"}
0005432568009	FD4126	3922 679544	ALINA KONDRATEVA	{"email": "a_kondrateva-1980@postgrespro.ru", "phone": "+70855580241"}
0005432568010	FD4126	8895 950014	MARIYA ROMANOVA	{"phone": "+70832790291"}
0005432568011	086FFC	3981 810753	ANATOLIY MEDVEDEV	{"email": "a-medvedev_04051963@postgrespro.ru", "phone": "+70460496897"}
0005432568012	086FFC	1824 753589	SERGEY SCHERBAKOV	{"email": "scherbakov-s_071973@postgrespro.ru", "phone": "+70582541739"}
0005432568013	C1DFCC	0000 985415	SERGEY FOMIN	{"email": "fomin-sergey011980@postgrespro.ru", "phone": "+70802612356"}
0005432568014	CAE2F1	3292 262716	NATALYA CHERNOVA	{"phone": "+70409979743"}
0005432568015	30742F	0344 234561	TATYANA BOGDANOVA	{"phone": "+70047373471"}
0005432568016	AF430C	9112 546311	ALEKSANDR POPOV	{"email": "popov.aleksandr.1970@postgrespro.ru", "phone": "+70254677847"}
0005432568017	AF430C	1820 086102	ELENA FROLOVA	{"phone": "+70765277023"}
0005432568018	AC0A2D	6005 313298	YULIYA KISELEVA	{"email": "yuliya.kiseleva-1986@postgrespro.ru", "phone": "+70786836952"}
0005432568019	AC0A2D	5854 260855	ANATOLIY KOZLOV	{"phone": "+70904276881"}
0005432568020	D18760	2397 623516	YURIY ZHUKOV	{"phone": "+70378429887"}
0005432568021	DB2A89	2911 701973	NIKITA VOLKOV	{"phone": "+70577070988"}
0005432568022	027176	8713 797179	VIKTORIYA MAKSIMOVA	{"phone": "+70211096628"}
0005432568023	94A051	4372 740938	SOFIYA SOROKINA	{"phone": "+70504340129"}
0005432568024	BCDD30	2600 487895	MARIYA SIDOROVA	{"email": "m.sidorova-07061978@postgrespro.ru", "phone": "+70191572193"}
0005432568025	BCDD30	9215 971120	LARISA NIKOLAEVA	{"phone": "+70574301063"}
0005432568026	BA1F85	5599 453609	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr.061970@postgrespro.ru", "phone": "+70986211443"}
0005432568027	BA1F85	5797 334488	ALINA MELNIKOVA	{"email": "melnikovaalina_1982@postgrespro.ru", "phone": "+70124888988"}
0005432568028	5DF39A	4081 129343	LYUDMILA KOZLOVA	{"email": "kozlova.l-071963@postgrespro.ru", "phone": "+70565468426"}
0005432568029	E9FF36	2787 531731	ELENA KUZNECOVA	{"phone": "+70815071069"}
0005432568030	C0E51D	0011 426923	ZHANNA KRASNOVA	{"phone": "+70888430900"}
0005432568031	1D735D	8671 030302	VALERIY ALEKSANDROV	{"phone": "+70839878271"}
0005432568032	1D735D	7037 693276	GALINA BOGDANOVA	{"email": "bogdanovag_1966@postgrespro.ru", "phone": "+70789076803"}
0005432568033	91EBBC	4327 929095	DMITRIY KUDRYASHOV	{"email": "dmitriykudryashov-1965@postgrespro.ru", "phone": "+70067380111"}
0005432568034	FFC289	5995 028574	VALENTINA ROMANOVA	{"phone": "+70325254910"}
0005432568035	4F98FD	6874 919886	ELENA ZOTOVA	{"email": "zotovaelena05021968@postgrespro.ru", "phone": "+70104798094"}
0005432568036	4B4E0C	0775 629297	ARKADIY MARTYNOV	{"email": "arkadiymartynov03121966@postgrespro.ru", "phone": "+70474881830"}
0005432568037	4B4E0C	4208 189714	ZOYA KUZNECOVA	{"email": "zoya.kuznecova.1964@postgrespro.ru", "phone": "+70502079353"}
0005432568038	32559B	7923 736977	ALEKSEY KRASNOV	{"email": "a_krasnov12011972@postgrespro.ru", "phone": "+70651850978"}
0005432568039	40E567	8364 172924	SERGEY STEPANOV	{"phone": "+70043049212"}
0005432568040	23C632	0230 720546	VALENTINA GAVRILOVA	{"phone": "+70413719089"}
0005432568041	0A44DE	5422 030392	VASILIY EGOROV	{"email": "vasiliyegorov-06101967@postgrespro.ru", "phone": "+70291499788"}
0005432568042	556ACD	6160 686407	ALLA MAKAROVA	{"phone": "+70372417496"}
0005432568043	556ACD	0622 731201	ALEKSANDR KOZLOV	{"phone": "+70944210692"}
0005432568044	AC5848	2935 527412	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav101987@postgrespro.ru", "phone": "+70612821276"}
0005432568045	AC5848	9754 298410	ANDREY KUZNECOV	{"phone": "+70389375221"}
0005432568046	778B6B	2432 714150	OLGA IVANOVA	{"phone": "+70960375471"}
0005432568047	8A351A	4693 847896	VIKTOR VASILEV	{"email": "vasilev-viktor.1959@postgrespro.ru", "phone": "+70189602854"}
0005432568048	87A452	0433 324354	VIKTORIYA SEMENOVA	{"phone": "+70079756178"}
0005432568049	106FF2	9565 190680	KSENIYA FILIPPOVA	{"phone": "+70338060289"}
0005432568050	106FF2	7472 746219	MARIYA TARASOVA	{"email": "tarasova_m_071973@postgrespro.ru", "phone": "+70238990448"}
0005432568051	106FF2	1738 562074	SERGEY VASILEV	{"email": "sergey-vasilev-1962@postgrespro.ru", "phone": "+70753235139"}
0005432568052	723DA6	1248 034387	ALEKSANDR DAVYDOV	{"phone": "+70896837395"}
0005432568053	E70205	6294 890225	VASILIY EGOROV	{"email": "v.egorov-1982@postgrespro.ru", "phone": "+70318777214"}
0005432568054	BDD56C	1705 156228	EVGENIY TIMOFEEV	{"phone": "+70169682994"}
0005432568055	A071AC	3335 811070	NIKOLAY ALEKSANDROV	{"phone": "+70233497189"}
0005432568056	A071AC	6629 304300	VALENTINA TITOVA	{"email": "vtitova.1974@postgrespro.ru", "phone": "+70232273107"}
0005432568057	A071AC	3025 085170	MARAT FROLOV	{"email": "frolov_marat28021977@postgrespro.ru", "phone": "+70006530620"}
0005432568058	A0654E	3133 403523	OLGA EFREMOVA	{"phone": "+70535022505"}
0005432568059	523BF8	2694 769561	ALENA MARTYNOVA	{"email": "martynovaalena1970@postgrespro.ru", "phone": "+70813140726"}
0005432568060	50176A	8950 131721	GALINA FILATOVA	{"email": "galina.filatova.21121969@postgrespro.ru", "phone": "+70824356692"}
0005432568061	50176A	6486 808845	NATALIYA ABRAMOVA	{"phone": "+70539726009"}
0005432568062	30BA83	5887 885714	VALERIY IVANOV	{"email": "ivanov.valeriy.25081971@postgrespro.ru", "phone": "+70766528744"}
0005432568063	D991F2	0418 103068	ANASTASIYA ZHURAVLEVA	{"email": "azhuravleva.1969@postgrespro.ru", "phone": "+70360656838"}
0005432568064	226672	0834 735625	ALEKSEY KRASNOV	{"phone": "+70127408485"}
0005432568065	96CD9F	0935 235709	RAMIL ANDREEV	{"phone": "+70172816962"}
0005432568066	96CD9F	6081 145807	NATALYA DAVYDOVA	{"phone": "+70728099321"}
0005432568067	CCFB3C	3001 329066	MARAT ZAYCEV	{"email": "maratzaycev.26111983@postgrespro.ru", "phone": "+70311056651"}
0005432568068	CCFB3C	4056 938486	MARINA SOROKINA	{"email": "msorokina_1968@postgrespro.ru", "phone": "+70454104381"}
0005432568069	BACEC4	9021 264820	VASILIY ROMANOV	{"email": "vasiliy.romanov.1978@postgrespro.ru", "phone": "+70045656688"}
0005432568070	500572	0820 520160	PAVEL SMIRNOV	{"email": "p-smirnov.1976@postgrespro.ru", "phone": "+70117408102"}
0005432568071	E49435	0711 138542	ARKADIY SOROKIN	{"email": "a.sorokin-1960@postgrespro.ru", "phone": "+70230758497"}
0005432568072	844801	0444 131107	OLGA GERASIMOVA	{"phone": "+70049431017"}
0005432568073	844801	0987 270509	TATYANA PAVLOVA	{"email": "t_pavlova-1966@postgrespro.ru", "phone": "+70600467517"}
0005432568074	9D27D5	1707 791615	IRINA NAUMOVA	{"email": "inaumova.07031981@postgrespro.ru", "phone": "+70419732720"}
0005432568075	305EE5	2390 281670	ANASTASIYA MARTYNOVA	{"email": "martynova_anastasiya-13011964@postgrespro.ru", "phone": "+70180144186"}
0005432568076	A4B62E	6151 164507	SERGEY STEPANOV	{"email": "sergey.stepanov23041970@postgrespro.ru", "phone": "+70992216517"}
0005432568077	A4B62E	7917 831685	ALENA VOLKOVA	{"phone": "+70593328912"}
0005432568078	EFBA2E	5992 905239	SERGEY FROLOV	{"email": "s.frolov-101968@postgrespro.ru", "phone": "+70063057514"}
0005432568079	EFBA2E	8056 260565	NIKITA DENISOV	{"email": "nikita_denisov.071963@postgrespro.ru", "phone": "+70860278419"}
0005432568080	ED3BB0	6256 062054	DMITRIY KULIKOV	{"phone": "+70466870821"}
0005432568081	E33D46	4331 257179	ARINA GRISHINA	{"phone": "+70554219993"}
0005432568082	D1E76B	2311 340379	NIKOLAY DAVYDOV	{"email": "n.davydov-1973@postgrespro.ru", "phone": "+70822571314"}
0005432568083	D1E76B	5801 861908	ZAKHAR GUSEV	{"email": "zakhar_gusev1976@postgrespro.ru", "phone": "+70377678581"}
0005432568084	D1E76B	9728 400299	EVGENIY VOLKOV	{"phone": "+70163694724"}
0005432568085	225072	2832 044952	SVETLANA MALYSHEVA	{"phone": "+70260912655"}
0005432568086	BC4CCD	6941 993429	KONSTANTIN GUSEV	{"email": "konstantin-gusev1968@postgrespro.ru", "phone": "+70728801509"}
0005432568087	BC4CCD	0450 675762	VLADIMIR ANDREEV	{"phone": "+70503881509"}
0005432568088	8C7E3A	9054 977332	ANATOLIY MATVEEV	{"phone": "+70096804170"}
0005432568089	8C7E3A	9357 230262	VLADIMIR ZHURAVLEV	{"phone": "+70902010671"}
0005432568090	0AF2B0	3509 514273	ZINAIDA NESTEROVA	{"phone": "+70111100201"}
0005432568091	0AF2B0	5456 555335	SERGEY SERGEEV	{"phone": "+70187196779"}
0005432568092	25C2F2	4300 591202	SVETLANA BARANOVA	{"phone": "+70596371374"}
0005432568093	25C2F2	3606 997977	YULIYA SCHERBAKOVA	{"email": "y-scherbakova.111968@postgrespro.ru", "phone": "+70645105820"}
0005432568094	3168C5	9924 187625	GALINA ROMANOVA	{"email": "g-romanova111972@postgrespro.ru", "phone": "+70781861948"}
0005432568095	892F25	9149 072825	LYUBOV TIKHONOVA	{"email": "lyubov_tikhonova_061975@postgrespro.ru", "phone": "+70719916164"}
0005432568096	DF5D67	2240 184011	MARINA NIKIFOROVA	{"email": "nikiforova_marina.1971@postgrespro.ru", "phone": "+70293153185"}
0005432568097	48BA3F	6364 915530	EVGENIY SERGEEV	{"email": "e_sergeev-22061969@postgrespro.ru", "phone": "+70924605047"}
0005432568098	12B670	9231 126592	MIKHAIL NIKITIN	{"phone": "+70907429932"}
0005432568099	91A1AD	3792 159813	ANDREY ZAYCEV	{"email": "zaycev_andrey_1968@postgrespro.ru", "phone": "+70227017365"}
0005432568100	31F81F	7271 296059	NATALIYA MEDVEDEVA	{"phone": "+70680276438"}
0005432568101	6A2295	2105 722587	ANASTASIYA MIKHAYLOVA	{"phone": "+70190329356"}
0005432568102	383895	6241 505272	NATALIYA LOGINOVA	{"phone": "+70508673645"}
0005432568103	BC6FF4	2374 927546	VLADIMIR KISELEV	{"phone": "+70204621313"}
0005432568104	BC6FF4	8278 838000	VITALIY EGOROV	{"email": "egorov.vitaliy25021977@postgrespro.ru", "phone": "+70624190868"}
0005432568105	D77F74	0571 771827	VLADIMIR GORBUNOV	{"phone": "+70566724587"}
0005432568106	D77F74	4012 993014	PAVEL MATVEEV	{"email": "pmatveev-14041972@postgrespro.ru", "phone": "+70192548967"}
0005432568107	6A16F8	4063 934005	YULIYA MIRONOVA	{"email": "y-mironova-081975@postgrespro.ru", "phone": "+70421577706"}
0005432568108	93999C	7982 855268	DARYA DENISOVA	{"email": "denisova_darya.1968@postgrespro.ru", "phone": "+70454542159"}
0005432568109	93999C	4098 743427	ANDREY GAVRILOV	{"email": "a.gavrilov_071974@postgrespro.ru", "phone": "+70330071627"}
0005432568110	2847A0	0694 787206	TATYANA ALEKSEEVA	{"phone": "+70984361988"}
0005432568111	C245BC	7403 447867	VLADIMIR MAKAROV	{"email": "makarov_vladimir-111971@postgrespro.ru", "phone": "+70609600063"}
0005432568112	0C1AE1	9850 586507	ALEKSANDR FROLOV	{"email": "a-frolov-1982@postgrespro.ru", "phone": "+70146375309"}
0005432568113	0C1AE1	9310 439533	IGOR IVANOV	{"phone": "+70699191341"}
0005432568114	CC9838	5568 641668	VIOLETTA EGOROVA	{"email": "egorova-violetta_1970@postgrespro.ru", "phone": "+70685273787"}
0005432568115	02E230	6239 137669	VLADIMIR DENISOV	{"email": "v-denisov_081962@postgrespro.ru", "phone": "+70301203889"}
0005432568116	D32D70	5633 099461	SERGEY TIMOFEEV	{"phone": "+70545532568"}
0005432568117	985ED8	5984 731129	GENNADIY GORBUNOV	{"phone": "+70616557863"}
0005432568118	E07993	2409 404457	ANDREY SIDOROV	{"phone": "+70408494319"}
0005432568119	F31161	0270 482120	IRINA TROFIMOVA	{"email": "trofimova.i-1973@postgrespro.ru", "phone": "+70198620184"}
0005432568120	F31161	4932 960461	GEORGIY ILIN	{"phone": "+70088121317"}
0005432568121	A775C8	0350 209742	VLADIMIR MIRONOV	{"email": "mironovv-101961@postgrespro.ru", "phone": "+70208927655"}
0005432568122	C05402	5492 288510	TATYANA DMITRIEVA	{"email": "dmitrievat.17091981@postgrespro.ru", "phone": "+70472933019"}
0005432568123	AE6B62	0518 686004	IVAN VASILEV	{"phone": "+70594567692"}
0005432568124	AE6B62	4249 413679	IRINA ANDREEVA	{"email": "andreevairina1976@postgrespro.ru", "phone": "+70010430387"}
0005432568125	B7E51A	3642 296596	VLADIMIR KUZNECOV	{"phone": "+70454611024"}
0005432568126	B37915	2784 353380	NURLAN ABRAMOV	{"phone": "+70317689283"}
0005432568127	A73BC9	7537 467532	MARIYA STEPANOVA	{"phone": "+70527608034"}
0005432568128	9180DB	0367 889107	MARIYA MOROZOVA	{"email": "mariya_morozova.26091980@postgrespro.ru", "phone": "+70839490243"}
0005432568129	79C42E	0486 676054	EKATERINA ROMANOVA	{"phone": "+70591806606"}
0005432568130	EA9850	9494 510246	YURIY BORISOV	{"phone": "+70131095162"}
0005432568131	C68FDF	8635 358143	ALEKSEY GRIGOREV	{"email": "a.grigorev.051964@postgrespro.ru", "phone": "+70411116590"}
0005432568132	C68FDF	3600 523870	RAISA KOLESNIKOVA	{"email": "kolesnikova.r.051971@postgrespro.ru", "phone": "+70009151578"}
0005432568133	480F6E	5007 613256	SERGEY TARASOV	{"phone": "+70742428822"}
0005432568134	59991E	4897 463052	ZOYA TROFIMOVA	{"phone": "+70222549047"}
0005432568135	59991E	6477 245930	RITA IVANOVA	{"phone": "+70750374513"}
0005432568136	5BB2D0	6972 105526	SOFIYA FADEEVA	{"phone": "+70505632082"}
0005432568137	959185	9635 011438	NATALYA ANTONOVA	{"phone": "+70552964613"}
0005432568138	DB2EA6	3832 011886	IVAN VLASOV	{"email": "vlasov_ivan-1972@postgrespro.ru", "phone": "+70000615333"}
0005432568139	34665A	9616 808854	TATYANA ROMANOVA	{"email": "romanova-tatyana28011987@postgrespro.ru", "phone": "+70508003734"}
0005432568140	3A1BCA	3277 278905	SERGEY ABRAMOV	{"phone": "+70898188384"}
0005432568141	E6626E	7526 574420	IVAN ISAEV	{"phone": "+70267204791"}
0005432568142	FEB4D4	2558 027019	ANATOLIY PETROV	{"email": "anatoliy_petrov-1962@postgrespro.ru", "phone": "+70128635017"}
0005432568143	FEB4D4	6581 863741	ALEKSEY SERGEEV	{"phone": "+70349433384"}
0005432568144	534E5B	7851 318330	MARIYA BORISOVA	{"phone": "+70800217321"}
0005432568145	38413F	3495 717283	ELENA DMITRIEVA	{"email": "edmitrieva05071968@postgrespro.ru", "phone": "+70575642024"}
0005432568146	38413F	8719 605438	VLADISLAV GORBUNOV	{"phone": "+70902554008"}
0005432568265	5B16D2	6697 119921	ANASTASIYA SMIRNOVA	{"phone": "+70710695841"}
0005432568147	38413F	1790 565276	NATALYA SOKOLOVA	{"email": "sokolovanatalya.06081973@postgrespro.ru", "phone": "+70002863003"}
0005432568148	9981EB	8552 310030	ANTON KUZMIN	{"phone": "+70029374573"}
0005432568149	9981EB	3612 995643	OLGA DENISOVA	{"phone": "+70399050052"}
0005432568150	DA1299	0924 747447	TAMARA MALYSHEVA	{"email": "tamara_malysheva_1961@postgrespro.ru", "phone": "+70999668860"}
0005432568151	BF4711	4387 337777	SERGEY NIKITIN	{"email": "nikitin-sergey-1963@postgrespro.ru", "phone": "+70798948274"}
0005432568152	881002	4587 811983	EVGENIY MOROZOV	{"phone": "+70596210894"}
0005432568153	495CB8	6571 397298	ALLA ANTONOVA	{"phone": "+70777304820"}
0005432568154	13CD90	2281 014481	SVETLANA NAZAROVA	{"phone": "+70730411979"}
0005432568155	8E9276	6216 182269	VIKTORIYA TROFIMOVA	{"email": "viktoriya.trofimova-07041975@postgrespro.ru", "phone": "+70728010912"}
0005432568156	864945	8328 766097	ALEKSANDR STEPANOV	{"email": "a_stepanov.03051976@postgrespro.ru", "phone": "+70322194753"}
0005432568157	87E0FC	1702 606530	DENIS MIRONOV	{"email": "mironov-d.1968@postgrespro.ru", "phone": "+70989848266"}
0005432568158	579AA7	0685 015201	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev.16021956@postgrespro.ru", "phone": "+70182499046"}
0005432568159	579AA7	6017 606003	EKATERINA IVANOVA	{"email": "eivanova1962@postgrespro.ru", "phone": "+70436714217"}
0005432568160	0A9C4B	4605 072095	VLADIMIR NAZAROV	{"email": "nazarov_v27121973@postgrespro.ru", "phone": "+70058453431"}
0005432568161	D0D28F	1097 219234	IVAN DENISOV	{"email": "denisov-i.1963@postgrespro.ru", "phone": "+70618601567"}
0005432568162	D0D28F	1538 535746	SERGEY KRASNOV	{"email": "krasnov_sergey.1959@postgrespro.ru", "phone": "+70079275139"}
0005432568163	8B7B35	6565 473809	LYUDMILA MAKSIMOVA	{"email": "l_maksimova-07011965@postgrespro.ru", "phone": "+70006637916"}
0005432568164	E3CBB2	9088 524996	NIKOLAY DAVYDOV	{"phone": "+70528262298"}
0005432568165	080D85	1277 443697	MIKHAIL KRASNOV	{"phone": "+70295766101"}
0005432568166	41F067	5863 854900	GENNADIY KUZNECOV	{"phone": "+70025227875"}
0005432568167	9C89DC	7173 770547	ELENA MAKAROVA	{"phone": "+70864360901"}
0005432568168	9C89DC	0903 507311	YANA YAKOVLEVA	{"phone": "+70373944447"}
0005432568169	05BB3D	8167 801023	GULFIYA ORLOVA	{"phone": "+70210381673"}
0005432568170	7EF6BC	2486 181384	NINA KUZMINA	{"email": "kuzminan-24021971@postgrespro.ru", "phone": "+70124217331"}
0005432568171	EF4C83	0836 060118	NINA VASILEVA	{"email": "n.vasileva.111972@postgrespro.ru", "phone": "+70027464776"}
0005432568172	362506	9054 037113	NADEZHDA DAVYDOVA	{"email": "davydova.nadezhda.101981@postgrespro.ru", "phone": "+70785534934"}
0005432568173	10C9A3	8508 657524	GENNADIY RODIONOV	{"phone": "+70572439372"}
0005432568174	40EB5F	5637 390313	TATYANA DENISOVA	{"phone": "+70320517743"}
0005432568175	40EB5F	5998 195115	TATYANA LEBEDEVA	{"email": "tatyana_lebedeva-1977@postgrespro.ru", "phone": "+70763517138"}
0005432568176	EBF168	2037 437827	VITALIY BORISOV	{"email": "vitaliy.borisov.29071976@postgrespro.ru", "phone": "+70186444633"}
0005432568177	EBF168	6604 144922	EVGENIYA MATVEEVA	{"email": "matveeva-e.101966@postgrespro.ru", "phone": "+70549531087"}
0005432568178	67F4C2	8133 169820	ALEVTINA BOGDANOVA	{"email": "alevtina.bogdanova_021984@postgrespro.ru", "phone": "+70962485412"}
0005432568179	5D9F0B	4225 547380	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov101984@postgrespro.ru", "phone": "+70884710768"}
0005432568180	5D9F0B	6375 310900	SOFYA GUSEVA	{"email": "sguseva-1964@postgrespro.ru", "phone": "+70490570878"}
0005432568181	5D9F0B	7643 050653	TATYANA ORLOVA	{"email": "orlovat_1961@postgrespro.ru", "phone": "+70628290301"}
0005432568182	5D9F0B	8013 098582	ELENA MOROZOVA	{"phone": "+70464237473"}
0005432568183	EB684E	4752 853393	LYUBOV BELOVA	{"email": "beloval1966@postgrespro.ru", "phone": "+70565240648"}
0005432568184	608CD6	4120 262116	ANDREY CHERNOV	{"email": "chernovandrey-1972@postgrespro.ru", "phone": "+70516473522"}
0005432568185	608CD6	5737 853570	TATYANA ZHUKOVA	{"email": "zhukova_tatyana_1966@postgrespro.ru", "phone": "+70231003109"}
0005432568186	3DFF13	8763 559878	LYUBOV LOGINOVA	{"email": "loginoval.1984@postgrespro.ru", "phone": "+70494584230"}
0005432568187	BE38DC	9780 549988	VIKTOR PETROV	{"email": "viktorpetrov.021976@postgrespro.ru", "phone": "+70977353991"}
0005432568188	BE38DC	9196 492386	ANATOLIY BELOV	{"email": "belov-a.1962@postgrespro.ru", "phone": "+70618879210"}
0005432568189	990BD1	2321 230271	SVETLANA ANTONOVA	{"email": "svetlanaantonova1968@postgrespro.ru", "phone": "+70256949654"}
0005432568190	1C43C1	6983 412286	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva.091974@postgrespro.ru", "phone": "+70491877610"}
0005432568191	3F2296	6710 603491	MIKHAIL IVANOV	{"email": "mikhailivanov.25031959@postgrespro.ru", "phone": "+70376908208"}
0005432568192	5B9F42	2888 401272	ALEKSANDR PETROV	{"phone": "+70726141653"}
0005432568193	E5C1A5	5235 239134	ZINAIDA FADEEVA	{"email": "fadeevazinaida-1968@postgrespro.ru", "phone": "+70260381618"}
0005432568194	E5C1A5	3046 286348	EGOR KUZNECOV	{"phone": "+70752294770"}
0005432568195	E5C1A5	4294 525528	YURIY OSIPOV	{"email": "yuriy.osipov-04051977@postgrespro.ru", "phone": "+70517562466"}
0005432568196	6318C5	9555 555371	VALERIY TARASOV	{"phone": "+70768180857"}
0005432568197	6026FA	8319 010923	IGOR MIRONOV	{"email": "imironov1983@postgrespro.ru", "phone": "+70600764036"}
0005432568198	6026FA	2140 632175	ALEKSANDR ZAKHAROV	{"email": "a-zakharov_1972@postgrespro.ru", "phone": "+70248759884"}
0005432568199	3CB29C	5392 838675	BORIS BELOV	{"phone": "+70007005872"}
0005432568200	1D89B3	4010 098973	DARYA KUZNECOVA	{"phone": "+70101675005"}
0005432568201	AB5786	5634 816910	MIKHAIL IVANOV	{"phone": "+70624809307"}
0005432568202	8CA3C2	1196 603371	NIKOLAY ANTONOV	{"email": "nantonov26031972@postgrespro.ru", "phone": "+70066788690"}
0005432568203	CA830F	5320 250677	TAMARA MARTYNOVA	{"email": "tamara_martynova061975@postgrespro.ru", "phone": "+70265151669"}
0005432568324	09355F	0231 075355	GALINA OVCHINNIKOVA	{"phone": "+70643199790"}
0005432568204	3CCE3F	4497 548402	EKATERINA VOLKOVA	{"email": "e-volkova_1970@postgrespro.ru", "phone": "+70425653971"}
0005432568205	BBE286	7516 148274	EVGENIY SMIRNOV	{"email": "e.smirnov.051964@postgrespro.ru", "phone": "+70459956048"}
0005432568206	BBE286	9424 741225	ANNA NIKIFOROVA	{"phone": "+70958772645"}
0005432568207	BBE286	5741 540024	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov.1979@postgrespro.ru", "phone": "+70399460407"}
0005432568208	78FA20	1051 812138	MARINA TIMOFEEVA	{"phone": "+70933712045"}
0005432568209	6B3C62	2533 601490	IRINA POTAPOVA	{"email": "potapova.irina.1985@postgrespro.ru", "phone": "+70660589454"}
0005432568210	64CC5B	8712 940785	OKSANA KUZNECOVA	{"phone": "+70563922654"}
0005432568211	C89D21	2464 061998	OLGA ZAYCEVA	{"phone": "+70009358841"}
0005432568212	25C31C	8239 989948	OLGA ERMAKOVA	{"phone": "+70913743962"}
0005432568213	45E753	7397 929481	YANA SAVELEVA	{"email": "saveleva-y-30071975@postgrespro.ru", "phone": "+70056667026"}
0005432568214	30A24D	7174 827920	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova-28011967@postgrespro.ru", "phone": "+70565337099"}
0005432568215	30A24D	1919 930855	YURIY ZAYCEV	{"phone": "+70195351722"}
0005432568216	30A24D	3331 888523	IRINA SMIRNOVA	{"email": "i-smirnova.1968@postgrespro.ru", "phone": "+70511007919"}
0005432568217	ADCD38	2762 962601	VALENTINA SEMENOVA	{"phone": "+70435991136"}
0005432568218	D7A902	6154 638179	VASILIY KUZNECOV	{"email": "kuznecovv.02051976@postgrespro.ru", "phone": "+70883535676"}
0005432568219	441418	9627 097221	YURIY SIDOROV	{"email": "sidorov-yuriy_06071966@postgrespro.ru", "phone": "+70085099666"}
0005432568220	441418	4794 221275	VALERIY ZHURAVLEV	{"email": "valeriy-zhuravlev05081976@postgrespro.ru", "phone": "+70602649661"}
0005432568221	FD1781	3111 744668	NINA SEMENOVA	{"email": "nina_semenova_1984@postgrespro.ru", "phone": "+70785602892"}
0005432568222	370BB3	7370 000286	MARINA OSIPOVA	{"phone": "+70529467090"}
0005432568223	4AD464	7672 809480	ANNA FILIPPOVA	{"email": "a-filippova.071980@postgrespro.ru", "phone": "+70543396695"}
0005432568224	034B05	9939 782935	GENNADIY POPOV	{"phone": "+70389108711"}
0005432568225	3A8292	6524 471972	RAISA GERASIMOVA	{"phone": "+70368432230"}
0005432568226	6970D3	4187 881578	SERGEY ZAKHAROV	{"email": "zakharov.s_07071966@postgrespro.ru", "phone": "+70504417049"}
0005432568227	BDB0C6	0723 494061	IRINA ANDREEVA	{"email": "irina-andreeva_1961@postgrespro.ru", "phone": "+70291352273"}
0005432568228	6E2B4D	4498 596485	OKSANA EFREMOVA	{"phone": "+70177463451"}
0005432568229	1CF4BD	9346 715943	EVGENIY KUZNECOV	{"phone": "+70672241216"}
0005432568230	CAD72B	3661 548331	NATALYA TARASOVA	{"phone": "+70361520550"}
0005432568231	C8B7D0	0709 773764	ALISA AFANASEVA	{"email": "afanaseva.alisa.1977@postgrespro.ru", "phone": "+70322267018"}
0005432568232	F2F986	6376 239784	VARVARA NOVIKOVA	{"email": "v.novikova29071972@postgrespro.ru", "phone": "+70217614138"}
0005432568233	938FF3	4836 638254	EVGENIYA SCHERBAKOVA	{"phone": "+70565096990"}
0005432568234	822076	4853 239934	YURIY ROMANOV	{"email": "romanov_y111973@postgrespro.ru", "phone": "+70926048290"}
0005432568235	D480A1	6097 695177	IRINA KULIKOVA	{"phone": "+70455205430"}
0005432568236	C4D6EC	2378 327872	LYUBOV PETROVA	{"phone": "+70496571613"}
0005432568237	27E05E	9410 830702	VYACHESLAV SOKOLOV	{"email": "v-sokolov-1964@postgrespro.ru", "phone": "+70404099705"}
0005432568238	27E05E	3396 885573	MATVEY ALEKSANDROV	{"phone": "+70669297645"}
0005432568239	2BD9B3	9629 819076	YURIY VOLKOV	{"phone": "+70072913059"}
0005432568240	9C2701	8482 210429	ANATOLIY SCHERBAKOV	{"phone": "+70150257979"}
0005432568241	201C27	8092 936700	IVAN KUZNECOV	{"email": "ikuznecov29111978@postgrespro.ru", "phone": "+70657541588"}
0005432568242	606307	5124 742614	TATYANA KOROLEVA	{"email": "tatyana.koroleva-1975@postgrespro.ru", "phone": "+70710502556"}
0005432568243	606307	7067 198419	LYUBOV ANDREEVA	{"email": "l-andreeva.1959@postgrespro.ru", "phone": "+70201765021"}
0005432568244	F36D98	3436 655117	YURIY MAKSIMOV	{"phone": "+70141880319"}
0005432568245	53E3D5	2423 648196	NIKOLAY MAKAROV	{"phone": "+70871135130"}
0005432568246	4DBAEC	4661 622271	VLADIMIR KUZNECOV	{"phone": "+70180677435"}
0005432568247	EE1D6E	2091 805883	RINAT NOVIKOV	{"email": "rinat.novikov1983@postgrespro.ru", "phone": "+70874024872"}
0005432568248	88B6DB	2330 044960	RAISA VASILEVA	{"phone": "+70526124368"}
0005432568249	2BD2D7	2656 373033	GALINA PAVLOVA	{"phone": "+70684003994"}
0005432568250	2BD2D7	4885 582532	ZAKHAR SCHERBAKOV	{"email": "z_scherbakov.1974@postgrespro.ru", "phone": "+70506159670"}
0005432568251	1C9407	6046 211787	LIDIYA KISELEVA	{"email": "kiseleva-l031965@postgrespro.ru", "phone": "+70744776065"}
0005432568252	D60A81	1889 061668	SERGEY ROMANOV	{"email": "romanov-sergey081985@postgrespro.ru", "phone": "+70573402701"}
0005432568253	7B3E3C	4776 329044	KONSTANTIN ABRAMOV	{"email": "kabramov-19061963@postgrespro.ru", "phone": "+70217520373"}
0005432568254	B5237C	7995 911239	RUSTAM ANDREEV	{"phone": "+70982414058"}
0005432568255	CFF6B8	0757 921283	ALEKSANDR NOVIKOV	{"phone": "+70186698255"}
0005432568256	A0AE22	3088 715571	SERGEY MELNIKOV	{"email": "melnikov_sergey_14021977@postgrespro.ru", "phone": "+70781944422"}
0005432568257	A0AE22	8218 555472	RAVIL FROLOV	{"phone": "+70885906369"}
0005432568258	DA73F0	7221 021643	ELENA KUZNECOVA	{"email": "kuznecovae_11091984@postgrespro.ru", "phone": "+70823477018"}
0005432568259	F8F79A	2564 143196	IGOR MIRONOV	{"email": "igor-mironov061969@postgrespro.ru", "phone": "+70159813772"}
0005432568260	43CC61	1340 346143	ELENA POTAPOVA	{"email": "potapova-e06111966@postgrespro.ru", "phone": "+70686211527"}
0005432568261	43CC61	0939 797822	ALEKSANDR SAVELEV	{"phone": "+70769885155"}
0005432568262	174D16	2381 273980	VASILIY FILIPPOV	{"phone": "+70166147058"}
0005432568263	E6FEB3	2670 452728	ALEKSANDR OSIPOV	{"phone": "+70776098980"}
0005432568264	E6FEB3	3966 415513	LYUBOV TIKHONOVA	{"email": "tikhonova.l.081964@postgrespro.ru", "phone": "+70321349449"}
0005432568266	5B16D2	4931 146357	NINA KOVALEVA	{"email": "kovaleva_n_1976@postgrespro.ru", "phone": "+70735852021"}
0005432568267	3AF81F	4220 753237	ALISA NAZAROVA	{"email": "a_nazarova-111973@postgrespro.ru", "phone": "+70441644292"}
0005432568268	C7A481	1697 596304	VLADIMIR ROMANOV	{"phone": "+70105356565"}
0005432568269	7351B9	6608 175183	ANASTASIYA KOZLOVA	{"email": "akozlova051974@postgrespro.ru", "phone": "+70769483794"}
0005432568270	7351B9	6954 336979	IVAN POPOV	{"email": "i_popov-1972@postgrespro.ru", "phone": "+70754080747"}
0005432568271	7351B9	0772 928476	RUSLAN POPOV	{"phone": "+70937779795"}
0005432568272	063E35	3462 134079	VALERIY POPOV	{"email": "valeriy.popov_1977@postgrespro.ru", "phone": "+70239970844"}
0005432568273	B77A45	8222 013863	VLADISLAV MOROZOV	{"phone": "+70111585585"}
0005432568274	C7B6AF	8600 945348	LYUDMILA KOZLOVA	{"phone": "+70101501648"}
0005432568275	1E22EB	1450 350813	EGOR KULIKOV	{"email": "egor.kulikov.121968@postgrespro.ru", "phone": "+70268748433"}
0005432568276	1E22EB	3961 385578	ELMIRA GERASIMOVA	{"email": "gerasimova-elmira031968@postgrespro.ru", "phone": "+70366410977"}
0005432568277	DC935B	8145 081227	ANATOLIY KUZNECOV	{"email": "anatoliy_kuznecov081971@postgrespro.ru", "phone": "+70936569710"}
0005432568278	FD097C	1051 579276	MATVEY VOLKOV	{"email": "volkovmatvey_13011983@postgrespro.ru", "phone": "+70364585592"}
0005432568279	FD097C	6766 874600	NADEZHDA SOROKINA	{"email": "nadezhda.sorokina-25121977@postgrespro.ru", "phone": "+70862618500"}
0005432568280	705E71	0496 351477	TATYANA OSIPOVA	{"email": "tosipova1980@postgrespro.ru", "phone": "+70700748586"}
0005432568281	84E548	1587 036893	VLADIMIR MELNIKOV	{"phone": "+70605839529"}
0005432568282	0F21E7	1815 777549	DMITRIY MELNIKOV	{"phone": "+70701031072"}
0005432568283	0F21E7	5355 964255	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova_lyudmila121964@postgrespro.ru", "phone": "+70941201447"}
0005432568284	8D38DA	0143 404338	NONNA KOZLOVA	{"phone": "+70675348541"}
0005432568285	DDEE8C	3360 565326	IRINA MAKAROVA	{"email": "makarova-irina.28011982@postgrespro.ru", "phone": "+70422024478"}
0005432568286	F234F7	4379 118284	YULIYA NIKITINA	{"email": "nikitina.yuliya09121966@postgrespro.ru", "phone": "+70922257557"}
0005432568287	F234F7	6024 521719	RAISA KULIKOVA	{"phone": "+70186254925"}
0005432568288	74926A	5955 506918	VASILIY SCHERBAKOV	{"email": "scherbakov_v.16121977@postgrespro.ru", "phone": "+70182833094"}
0005432568289	74926A	9197 839566	ELENA MARTYNOVA	{"email": "martynova-e_081970@postgrespro.ru", "phone": "+70538146078"}
0005432568290	74926A	2261 521058	DMITRIY VOLKOV	{"phone": "+70852215249"}
0005432568291	E9387A	4140 355100	ANTONINA BELOVA	{"phone": "+70165620416"}
0005432568292	7CA981	5168 512232	ARTEM MIKHAYLOV	{"phone": "+70968874027"}
0005432568293	29CF16	9284 203044	YULIYA BORISOVA	{"email": "borisova.y_1981@postgrespro.ru", "phone": "+70972464234"}
0005432568294	4BB7FF	4454 686031	EGOR ISAEV	{"email": "e.isaev.061972@postgrespro.ru", "phone": "+70743523219"}
0005432568295	F7E9D2	0101 879795	NINA ANDREEVA	{"phone": "+70954398257"}
0005432568296	F7E9D2	7747 237270	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov111964@postgrespro.ru", "phone": "+70596662416"}
0005432568464	9FBEB8	0103 273141	VLADISLAV FEDOROV	{"phone": "+70049830961"}
0005432568297	3CE25B	6799 332976	LYUBOV FROLOVA	{"email": "frolova-l21071964@postgrespro.ru", "phone": "+70891251467"}
0005432568298	BAF4A7	5488 296849	ANNA SOKOLOVA	{"email": "anna-sokolova-1971@postgrespro.ru", "phone": "+70313256628"}
0005432568299	0A65D4	8445 179374	SERGEY VOLKOV	{"email": "volkovs-041972@postgrespro.ru", "phone": "+70497559733"}
0005432568300	4D8CAC	2362 091547	GULNARA KUZNECOVA	{"phone": "+70625899173"}
0005432568301	C904EE	5947 977122	YURIY ANDREEV	{"email": "andreevyuriy_24011980@postgrespro.ru", "phone": "+70252596226"}
0005432568302	CC6873	6794 754443	PAVEL SCHERBAKOV	{"email": "p-scherbakov091980@postgrespro.ru", "phone": "+70457237941"}
0005432568303	CC6873	8057 095698	VLADIMIR ALEKSEEV	{"phone": "+70500417518"}
0005432568304	FC0CB4	3906 336279	VIKTOR PETROV	{"email": "petrov_viktor1962@postgrespro.ru", "phone": "+70641806856"}
0005432568305	FC0CB4	6550 163821	IGOR MIKHAYLOV	{"phone": "+70391946614"}
0005432568306	77EF39	4837 858142	GEORGIY ORLOV	{"email": "orlov.georgiy09121972@postgrespro.ru", "phone": "+70522555644"}
0005432568307	77EF39	0476 682107	KSENIYA GUSEVA	{"phone": "+70513739301"}
0005432568308	58510B	3141 292186	DARYA ZOTOVA	{"email": "zotova_d1977@postgrespro.ru", "phone": "+70418275810"}
0005432568309	6287F6	6662 644646	NATALYA VASILEVA	{"phone": "+70526626433"}
0005432568310	7FB028	6112 299143	ANDREY KAZAKOV	{"email": "andrey.kazakov-081958@postgrespro.ru", "phone": "+70199414942"}
0005432568311	C48DAD	1736 602013	KIRILL DAVYDOV	{"email": "davydovk-1962@postgrespro.ru", "phone": "+70734553795"}
0005432568312	16B121	1202 757848	NATALYA NIKOLAEVA	{"phone": "+70404003640"}
0005432568313	20D5E9	9962 059778	VALENTINA VASILEVA	{"phone": "+70676655766"}
0005432568314	A9E350	7479 593595	IVAN KARPOV	{"phone": "+70260494947"}
0005432568315	8C3119	2166 404316	ZOYA NIKOLAEVA	{"phone": "+70285085432"}
0005432568316	8C3119	9761 953796	EVGENIY POPOV	{"phone": "+70555304558"}
0005432568317	8C3119	6693 839410	NINA ERMAKOVA	{"email": "ermakovanina-1976@postgrespro.ru", "phone": "+70812934814"}
0005432568318	41CDF3	7532 081165	ANDREY AFANASEV	{"email": "afanasev.a.14091965@postgrespro.ru", "phone": "+70164746261"}
0005432568319	7C693A	0166 463915	IVAN VOROBEV	{"phone": "+70801857862"}
0005432568320	D44D30	4294 728338	SERGEY ABRAMOV	{"email": "abramov_s-1980@postgrespro.ru", "phone": "+70250669473"}
0005432568321	9B2078	9545 809864	ILDAR TARASOV	{"email": "tarasov.ildar.29101974@postgrespro.ru", "phone": "+70841817799"}
0005432568322	F6193F	4280 112445	SVETLANA KOROLEVA	{"email": "koroleva.svetlana.021977@postgrespro.ru", "phone": "+70689479522"}
0005432568323	FE27D1	9497 361509	OLGA ANDREEVA	{"email": "olgaandreeva.1977@postgrespro.ru", "phone": "+70407088372"}
0005432568325	2E29F3	3979 272414	ALINA NIKITINA	{"email": "nikitina.alina-27011969@postgrespro.ru", "phone": "+70243195232"}
0005432568326	86A4E9	4152 659047	EVGENIY TIMOFEEV	{"phone": "+70377702639"}
0005432568327	5BD5DF	7053 215185	VIKTOR TARASOV	{"phone": "+70152131346"}
0005432568328	05A069	4134 752299	VLADIMIR ANDREEV	{"phone": "+70859450126"}
0005432568329	05A069	4889 186512	TIMUR VOLKOV	{"email": "tvolkov-1982@postgrespro.ru", "phone": "+70774269402"}
0005432568330	B11811	6398 194180	VLADIMIR MAKAROV	{"email": "v.makarov.1961@postgrespro.ru", "phone": "+70464221081"}
0005432568331	B11811	3402 629071	ELENA TIMOFEEVA	{"email": "elena_timofeeva-101967@postgrespro.ru", "phone": "+70544052935"}
0005432568332	DBF759	3602 968256	NATALYA VOLKOVA	{"phone": "+70360652279"}
0005432568333	5B185E	9166 899263	ALEKSEY FEDOROV	{"phone": "+70883185701"}
0005432568334	ABE0CB	0835 546041	LYUDMILA KUZMINA	{"phone": "+70412560566"}
0005432568335	ABE0CB	6873 781577	ALEKSANDR SMIRNOV	{"email": "a_smirnov.041970@postgrespro.ru", "phone": "+70750315595"}
0005432568336	FC2908	5056 411566	YAROSLAV DMITRIEV	{"email": "yaroslav-dmitriev.04041970@postgrespro.ru", "phone": "+70279085295"}
0005432568337	2F24A1	1457 058515	ALEKSANDR ZHUKOV	{"phone": "+70376710899"}
0005432568338	832756	2504 934214	RAMZIYA SMIRNOVA	{"phone": "+70991561060"}
0005432568339	832756	4438 304029	ALENA NOVIKOVA	{"email": "novikova-a25081975@postgrespro.ru", "phone": "+70583790790"}
0005432568340	F5EF29	0650 864968	KLAVDIYA POPOVA	{"email": "popovaklavdiya28051974@postgrespro.ru", "phone": "+70485964945"}
0005432568341	B22D6F	2493 073301	OLESYA VASILEVA	{"email": "vasilevao-051978@postgrespro.ru", "phone": "+70627027953"}
0005432568342	FD11FB	1890 106348	ILYA ILIN	{"email": "ilin_i-24121972@postgrespro.ru", "phone": "+70502553652"}
0005432568343	FD11FB	1166 712073	ANDREY SMIRNOV	{"email": "smirnov.andrey091971@postgrespro.ru", "phone": "+70914450822"}
0005432568344	CE8F1B	7464 179369	GULNAZ ALEKSEEVA	{"phone": "+70328765467"}
0005432568345	CE8F1B	0829 013486	IGOR ZAYCEV	{"phone": "+70342980509"}
0005432568346	CE8F1B	8193 815480	MAKSIM SCHERBAKOV	{"email": "scherbakov_maksim1973@postgrespro.ru", "phone": "+70414506301"}
0005432568347	3D4EFA	7313 014265	DMITRIY KUZMIN	{"phone": "+70332233200"}
0005432568348	8C6DED	5023 974088	OLEG DAVYDOV	{"phone": "+70058654042"}
0005432568349	8C6DED	9244 676061	VALERIY GERASIMOV	{"email": "gerasimov.valeriy_14021969@postgrespro.ru", "phone": "+70402844708"}
0005432568350	8C6DED	9710 792680	ANASTASIYA ALEKSEEVA	{"phone": "+70946662810"}
0005432568351	27317E	1775 063739	VIKTORIYA ANDREEVA	{"email": "andreeva_viktoriya-29121968@postgrespro.ru", "phone": "+70774125307"}
0005432568352	27317E	9278 278084	OLGA IVANOVA	{"phone": "+70614705469"}
0005432568353	B713FB	2449 033324	ANDREY MEDVEDEV	{"email": "andreymedvedev-1972@postgrespro.ru", "phone": "+70633878575"}
0005432568354	104990	0344 129612	MARINA ILINA	{"email": "ilina.m-05081971@postgrespro.ru", "phone": "+70926004498"}
0005432568355	D296F0	6188 697046	NATALIYA ZHURAVLEVA	{"email": "zhuravlevanataliya_091975@postgrespro.ru", "phone": "+70457863233"}
0005432568356	D296F0	5119 437520	ALEKSANDR POPOV	{"email": "a-popov.041969@postgrespro.ru", "phone": "+70408484178"}
0005432568357	EF1E9C	1892 032371	VERA MIRONOVA	{"email": "mironovav.1980@postgrespro.ru", "phone": "+70219101515"}
0005432568358	A1F1B9	3158 050015	TATYANA SAVELEVA	{"email": "saveleva_tatyana-091975@postgrespro.ru", "phone": "+70599183949"}
0005432568359	8FD709	1578 833768	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.a1968@postgrespro.ru", "phone": "+70700985168"}
0005432568360	8FD709	3685 584151	TAMARA GAVRILOVA	{"email": "tamara-gavrilova.1974@postgrespro.ru", "phone": "+70946007756"}
0005432568361	96379A	6610 385468	MARINA EGOROVA	{"phone": "+70384987148"}
0005432568362	790BAE	4745 432201	TATYANA SMIRNOVA	{"phone": "+70408914078"}
0005432568363	790BAE	9236 896301	ANTON IVANOV	{"phone": "+70599764855"}
0005432568364	FFE217	9514 905607	MARIYA ILINA	{"email": "ilina_m-041966@postgrespro.ru", "phone": "+70249743501"}
0005432568365	719846	8042 547691	VLADIMIR YAKOVLEV	{"phone": "+70775715527"}
0005432568366	DA3893	1493 424843	ALEKSEY SOLOVEV	{"email": "solovev_a051981@postgrespro.ru", "phone": "+70009920706"}
0005432568367	6C16E6	4087 623299	NINA KAZAKOVA	{"phone": "+70027697197"}
0005432568368	6C16E6	0828 562544	GALINA KUZNECOVA	{"phone": "+70854057253"}
0005432568369	6C16E6	4250 239366	NIKOLAY MAKAROV	{"email": "n_makarov-101967@postgrespro.ru", "phone": "+70662241914"}
0005432568370	E598D5	5482 553276	ELENA PETROVA	{"phone": "+70610425833"}
0005432568371	6E2C68	8076 897793	DAVID SHEVCHENKO	{"phone": "+70020231459"}
0005432568372	1A48C3	1505 314985	VIKTOR KOZLOV	{"phone": "+70240868225"}
0005432568373	25CFFE	7267 105651	RUSLAN KOZLOV	{"email": "kozlovr_081970@postgrespro.ru", "phone": "+70460114113"}
0005432568374	25CFFE	9260 682734	NIKITA NIKOLAEV	{"email": "nikolaev.n.23111977@postgrespro.ru", "phone": "+70101351556"}
0005432568375	58EE9F	0531 961629	TATYANA LOGINOVA	{"email": "loginova_tatyana-061981@postgrespro.ru", "phone": "+70234047383"}
0005432568376	29B24C	8843 058508	ANZHELIKA SMIRNOVA	{"email": "anzhelika_smirnova04021980@postgrespro.ru", "phone": "+70131556875"}
0005432568377	29B24C	5850 633592	MIKHAIL MATVEEV	{"phone": "+70586960786"}
0005432568378	29B24C	7173 427768	NINA NESTEROVA	{"email": "nesterova_nina06121981@postgrespro.ru", "phone": "+70057287316"}
0005432568379	1A52A9	3342 530844	ANNA BELYAEVA	{"phone": "+70995297703"}
0005432568380	1A52A9	9010 741001	BORIS NIKOLAEV	{"email": "b.nikolaev.041973@postgrespro.ru", "phone": "+70341951300"}
0005432568381	1A52A9	4751 777291	BORIS FEDOROV	{"email": "b-fedorov04051958@postgrespro.ru", "phone": "+70398682159"}
0005432568382	35FD72	7078 057515	MARIYA TARASOVA	{"phone": "+70159514471"}
0005432568383	FBD069	1910 482457	VALENTINA POPOVA	{"phone": "+70709301500"}
0005432568384	FBD069	1445 154280	IVAN AFANASEV	{"email": "i-afanasev-1967@postgrespro.ru", "phone": "+70747275107"}
0005432568385	F4FFDA	5821 438703	YURIY PETROV	{"email": "petrov-y_111972@postgrespro.ru", "phone": "+70504177113"}
0005432568386	F4FFDA	7577 029705	EVGENIY TIMOFEEV	{"email": "timofeev-evgeniy-1970@postgrespro.ru", "phone": "+70882746744"}
0005432568387	2C4BA6	4510 340014	GENNADIY TIMOFEEV	{"phone": "+70757250881"}
0005432568388	2C4BA6	6961 982941	TATYANA KOLESNIKOVA	{"email": "tatyana_kolesnikova-011972@postgrespro.ru", "phone": "+70956559701"}
0005432568389	39C68D	1829 408533	SERGEY IVANOV	{"email": "ivanovsergey.19051971@postgrespro.ru", "phone": "+70377143989"}
0005432568390	A99CAA	3546 250144	LYUDMILA BORISOVA	{"phone": "+70555192906"}
0005432568391	A99CAA	1163 710318	NINA NOVIKOVA	{"phone": "+70888184599"}
0005432568392	804B8E	3536 653025	ALEKSANDRA MIRONOVA	{"email": "a-mironova_18081965@postgrespro.ru", "phone": "+70841738176"}
0005432568393	8D4A51	6895 700985	KARIM MELNIKOV	{"email": "melnikov-karim1965@postgrespro.ru", "phone": "+70458978840"}
0005432568394	0518F6	9488 224975	VIKTORIYA VOLKOVA	{"email": "volkova.viktoriya.111975@postgrespro.ru", "phone": "+70870460488"}
0005432568395	FECD62	6906 538952	TATYANA KOZLOVA	{"phone": "+70844193962"}
0005432568396	FECD62	2805 559938	TATYANA OVCHINNIKOVA	{"phone": "+70783708863"}
0005432568397	B4E36E	8465 127614	VASILISA BORISOVA	{"email": "vasilisa-borisova121979@postgrespro.ru", "phone": "+70965946332"}
0005432568398	821975	4142 021605	BORIS MATVEEV	{"email": "b-matveev-1981@postgrespro.ru", "phone": "+70748031154"}
0005432568399	821975	7167 425140	SERGEY BONDARENKO	{"email": "bondarenkos_121966@postgrespro.ru", "phone": "+70578422471"}
0005432568456	59D1C2	2254 821124	IRINA TIKHONOVA	{"phone": "+70079296777"}
0005432568400	821975	5006 560393	VLADIMIR CHERNOV	{"email": "chernov.v_021979@postgrespro.ru", "phone": "+70762036092"}
0005432568401	6190F2	5525 826969	IRINA KOVALEVA	{"phone": "+70853980940"}
0005432568402	6190F2	8746 413188	VALENTIN SHEVCHENKO	{"phone": "+70457209426"}
0005432568403	4EF113	4652 869795	SERGEY ANDREEV	{"email": "s.andreev_051979@postgrespro.ru", "phone": "+70401615147"}
0005432568404	32562A	6073 816889	MARAT KRASNOV	{"phone": "+70226789906"}
0005432568405	32562A	8595 731786	DMITRIY KUZMIN	{"phone": "+70019771142"}
0005432568406	6EBF61	4376 212118	MATVEY NAUMOV	{"email": "matveynaumov.25011960@postgrespro.ru", "phone": "+70826651686"}
0005432568521	EF8ED1	9541 182421	EVGENIY SIDOROV	{"phone": "+70870545867"}
0005432568407	E3BDBC	3666 760584	IRINA AKIMOVA	{"email": "akimovai_101977@postgrespro.ru", "phone": "+70254163268"}
0005432568408	5A232C	6431 605075	VITALIY ORLOV	{"phone": "+70885161139"}
0005432568409	0E70D0	1122 418262	TATYANA PAVLOVA	{"phone": "+70000772244"}
0005432568410	350473	3232 907866	IRINA OSIPOVA	{"email": "osipova_i_061974@postgrespro.ru", "phone": "+70401614316"}
0005432568411	CDEC00	7131 833540	VIKTORIYA GAVRILOVA	{"email": "gavrilova-v-21031978@postgrespro.ru", "phone": "+70499058779"}
0005432568412	5B1CDC	3699 509952	ALEKSANDR KISELEV	{"email": "a_kiselev-06051968@postgrespro.ru", "phone": "+70183023910"}
0005432568413	A72CD3	3228 257732	GALINA KAZAKOVA	{"phone": "+70541185860"}
0005432568414	F7E044	4793 280403	ARSENIY ROMANOV	{"email": "romanov_arseniy-29041985@postgrespro.ru", "phone": "+70077531175"}
0005432568415	F7E044	4012 810744	SVETLANA PAVLOVA	{"email": "svetlana_pavlova031966@postgrespro.ru", "phone": "+70691067995"}
0005432568416	F7E044	3558 284747	ANATOLIY ALEKSANDROV	{"email": "anatoliy-aleksandrov-03081980@postgrespro.ru", "phone": "+70348690897"}
0005432568417	309400	8964 542045	LYUBOV FADEEVA	{"phone": "+70117495714"}
0005432568418	FA0C67	3808 976769	NIKITA IVANOV	{"phone": "+70908016318"}
0005432568419	C87648	1758 024616	ELENA FOMINA	{"email": "fominaelena-1979@postgrespro.ru", "phone": "+70165437310"}
0005432568420	C87648	3322 920266	ARTEM MEDVEDEV	{"email": "medvedeva.06011967@postgrespro.ru", "phone": "+70028997290"}
0005432568421	A774F0	3987 645790	EKATERINA PAVLOVA	{"phone": "+70466548845"}
0005432568422	6D0F2D	2442 674126	ANNA FEDOROVA	{"email": "a_fedorova.1965@postgrespro.ru", "phone": "+70068655113"}
0005432568423	6D0F2D	7098 367841	SNEZHANA SMIRNOVA	{"email": "s-smirnova1984@postgrespro.ru", "phone": "+70230840906"}
0005432568424	6D0F2D	6141 499876	DANIIL NIKOLAEV	{"email": "nikolaev_d.121976@postgrespro.ru", "phone": "+70251633076"}
0005432568425	DFD6E0	9513 140818	ANDREY MAKAROV	{"email": "makarov_a_1962@postgrespro.ru", "phone": "+70438265851"}
0005432568426	C10BE3	9265 259357	KIRILL SEMENOV	{"email": "kirill_semenov-25051974@postgrespro.ru", "phone": "+70643923403"}
0005432568427	301D30	8656 364593	DANILA SOLOVEV	{"email": "solovev_danila.121972@postgrespro.ru", "phone": "+70415179358"}
0005432568428	301D30	1369 991384	ELENA MOROZOVA	{"email": "e-morozova1975@postgrespro.ru", "phone": "+70065756002"}
0005432568429	301D30	5598 374083	VIKTOR MELNIKOV	{"email": "viktor.melnikov_07051975@postgrespro.ru", "phone": "+70738571196"}
0005432568430	4A7F8A	5659 124725	EKATERINA YUDINA	{"phone": "+70895407900"}
0005432568431	C508FF	7671 460591	VALENTIN GUSEV	{"phone": "+70999538566"}
0005432568432	2BDFD4	1005 476678	ANNA MARTYNOVA	{"phone": "+70733367799"}
0005432568433	2BDFD4	2366 578253	VITALIY KUZMIN	{"phone": "+70011244252"}
0005432568434	D21A30	2740 731499	SERGEY KULIKOV	{"phone": "+70968588143"}
0005432568435	D21A30	2078 628554	TAISA VASILEVA	{"email": "taisavasileva.1981@postgrespro.ru", "phone": "+70527570425"}
0005432568436	0CD9A4	5209 028140	YULIYA SERGEEVA	{"phone": "+70700705696"}
0005432568437	C0ED9A	2835 993277	ALEKSEY KONOVALOV	{"phone": "+70120389679"}
0005432568438	C0ED9A	0504 981228	TAMARA LUKYANOVA	{"phone": "+70977166295"}
0005432568439	985648	2045 599075	ELENA NESTEROVA	{"email": "e-nesterova_101981@postgrespro.ru", "phone": "+70564057662"}
0005432568440	1306F4	3678 824963	SOFYA AKIMOVA	{"email": "sakimova-1970@postgrespro.ru", "phone": "+70682860827"}
0005432568441	1306F4	4595 695019	OLGA RYABOVA	{"email": "o-ryabova.22081963@postgrespro.ru", "phone": "+70494119499"}
0005432568442	06D640	8522 890200	VALERIYA ERMAKOVA	{"phone": "+70634853390"}
0005432568443	E9901C	3335 731780	ANDREY CHERNOV	{"phone": "+70678874877"}
0005432568444	7B0288	1661 245854	VALENTINA KRASNOVA	{"email": "valentina-krasnova051963@postgrespro.ru", "phone": "+70271330248"}
0005432568445	7B0288	5227 901091	NADEZHDA KUZNECOVA	{"phone": "+70419515727"}
0005432568446	F21736	7366 989061	NATALYA IVANOVA	{"email": "n.ivanova-091964@postgrespro.ru", "phone": "+70558612466"}
0005432568447	F21736	3543 749985	ALEKSEY POPOV	{"phone": "+70800155968"}
0005432568448	D8326C	4711 546772	TATYANA NIKITINA	{"phone": "+70562968654"}
0005432568449	D8326C	0199 568510	YURIY MEDVEDEV	{"email": "medvedev_y-111971@postgrespro.ru", "phone": "+70998502618"}
0005432568450	FA2420	6312 417116	SERGEY KAZAKOV	{"email": "s_kazakov.111969@postgrespro.ru", "phone": "+70081132136"}
0005432568451	2E7A52	4363 986910	ARKADIY MIKHAYLOV	{"phone": "+70960275345"}
0005432568452	29ACE4	6324 795482	YURIY FEDOTOV	{"email": "fedotov.yuriy_29091977@postgrespro.ru", "phone": "+70149323863"}
0005432568453	8B5275	5929 503593	OLGA NOVIKOVA	{"phone": "+70474254212"}
0005432568454	A0ABEC	7437 211968	VLADIMIR NIKITIN	{"email": "nikitinvladimir.111956@postgrespro.ru", "phone": "+70278198583"}
0005432568455	A0ABEC	8109 395653	RUSTYAM IVANOV	{"email": "ivanov-rustyam17021984@postgrespro.ru", "phone": "+70957234370"}
0005432568457	BF2340	4976 603964	LILIYA VOLKOVA	{"email": "volkovaliliya-15081962@postgrespro.ru", "phone": "+70891866074"}
0005432568458	92A26B	3840 674910	YURIY KOZLOV	{"phone": "+70193127570"}
0005432568459	92A26B	8141 713937	ARKADIY KUZMIN	{"phone": "+70931274671"}
0005432568460	92A26B	5756 760295	ROMAN RODIONOV	{"phone": "+70011394998"}
0005432568461	30508F	2065 723689	SERGEY KULIKOV	{"phone": "+70705913164"}
0005432568462	30508F	2316 024025	LYUBOV ZHURAVLEVA	{"email": "l_zhuravleva-1969@postgrespro.ru", "phone": "+70813935209"}
0005432568463	30508F	4871 961757	IGOR VLASOV	{"email": "igor-vlasov.07091967@postgrespro.ru", "phone": "+70044771150"}
0005432568465	D86918	9042 449225	EKATERINA SOROKINA	{"email": "sorokina_e_1968@postgrespro.ru", "phone": "+70319957569"}
0005432568466	9903D6	8478 610683	MARAT SMIRNOV	{"email": "m_smirnov111974@postgrespro.ru", "phone": "+70998753215"}
0005432568467	720DEA	8622 099333	EKATERINA KAZAKOVA	{"phone": "+70063919066"}
0005432568468	0B8285	8352 752819	ANNA VOLKOVA	{"email": "volkova-a_05011965@postgrespro.ru", "phone": "+70072815163"}
0005432568469	0B8285	8010 911803	NATALIYA BORISOVA	{"email": "borisova.nataliya_28041973@postgrespro.ru", "phone": "+70840576100"}
0005432568470	7939B9	6925 777440	KSENIYA TIKHONOVA	{"email": "kseniya-tikhonova1970@postgrespro.ru", "phone": "+70942568433"}
0005432568471	7939B9	0702 125213	DMITRIY KOROLEV	{"phone": "+70574352758"}
0005432568472	7AB644	9540 011486	RUSLAN KOZLOV	{"email": "kozlov_ruslan-1967@postgrespro.ru", "phone": "+70602858680"}
0005432568473	A808B3	1841 409517	DMITRIY MAKAROV	{"email": "dmitriy.makarov-121964@postgrespro.ru", "phone": "+70885418801"}
0005432568474	19903B	8555 903963	TATYANA CHERNOVA	{"phone": "+70945867630"}
0005432568475	19903B	1662 500331	SOFYA ABRAMOVA	{"phone": "+70975825475"}
0005432568476	F8B4DA	9783 901138	ALEKSANDR SERGEEV	{"phone": "+70785209060"}
0005432568477	EB2040	9320 952927	TIKHON FEDOTOV	{"email": "tfedotov_121967@postgrespro.ru", "phone": "+70358588846"}
0005432568478	327FDA	7009 969417	SERGEY POPOV	{"email": "popov_s08091960@postgrespro.ru", "phone": "+70443760271"}
0005432568479	254EDA	6874 081756	NIKOLAY STEPANOV	{"phone": "+70825927160"}
0005432568480	254EDA	1584 582790	GALINA LOGINOVA	{"email": "loginova-g1969@postgrespro.ru", "phone": "+70042057189"}
0005432568481	05001B	9762 404937	ALEKSANDRA AFANASEVA	{"phone": "+70761443169"}
0005432568482	5D9C01	7803 404904	EVGENIYA GRISHINA	{"email": "evgeniya_grishina.1971@postgrespro.ru", "phone": "+70364313915"}
0005432568483	33F3E4	6756 841724	SOFYA LUKYANOVA	{"email": "sofya_lukyanova.1976@postgrespro.ru", "phone": "+70788417588"}
0005432568484	E29A63	0490 646577	VASILIY STEPANOV	{"email": "stepanovvasiliy-1969@postgrespro.ru", "phone": "+70170459770"}
0005432568485	E29A63	2857 838071	ANDREY NAZAROV	{"phone": "+70722456047"}
0005432568486	37F53B	6027 511935	ELENA AFANASEVA	{"email": "afanaseva-elena-1966@postgrespro.ru", "phone": "+70770064884"}
0005432568487	6DFC9C	8150 712166	YULIYA GRISHINA	{"phone": "+70828134023"}
0005432568488	6DFC9C	3706 101303	EVGENIY GUSEV	{"email": "gusev-evgeniy_091964@postgrespro.ru", "phone": "+70874366621"}
0005432568489	A1D087	7468 432857	TATYANA ZAKHAROVA	{"phone": "+70392864286"}
0005432568490	A1D087	4111 496654	SVETLANA IVANOVA	{"phone": "+70869775655"}
0005432568491	EB5E04	3473 644825	RINAT MELNIKOV	{"email": "rinat.melnikov-1961@postgrespro.ru", "phone": "+70297508435"}
0005432568492	6B783B	7971 866838	PETR ALEKSANDROV	{"phone": "+70896410801"}
0005432568493	9A06C6	0225 852429	VERA KUZNECOVA	{"phone": "+70372559818"}
0005432568494	9A06C6	7334 661885	OLGA POPOVA	{"phone": "+70464097236"}
0005432568495	AD80BF	6632 603622	TATYANA MAKAROVA	{"email": "makarova_tatyana_16061971@postgrespro.ru", "phone": "+70324542588"}
0005432568496	AD80BF	4329 594498	ELENA IVANOVA	{"phone": "+70188226412"}
0005432568497	AD80BF	5368 513267	OKSANA ILINA	{"email": "oksana-ilina-27111969@postgrespro.ru", "phone": "+70055468621"}
0005432568498	91CA45	0362 966826	OKSANA ZHUKOVA	{"phone": "+70609346679"}
0005432568499	91CA45	7767 623834	NIKITA ALEKSEEV	{"phone": "+70176927947"}
0005432568500	6F471C	6748 541993	NATALYA ZAYCEVA	{"email": "n.zayceva-071966@postgrespro.ru", "phone": "+70097625537"}
0005432568501	26F7D5	4714 019873	ELIZAVETA KALININA	{"email": "kalinina.elizaveta18111965@postgrespro.ru", "phone": "+70278202182"}
0005432568502	26F7D5	3658 853469	ANDREY ZAKHAROV	{"email": "zakharov.a-1967@postgrespro.ru", "phone": "+70682438690"}
0005432568503	44D78C	3478 274031	EKATERINA FEDOROVA	{"phone": "+70496884956"}
0005432568504	FBE90E	9868 306455	ANNA GERASIMOVA	{"phone": "+70063600555"}
0005432568505	E552EC	2134 915644	DANIIL GRIGOREV	{"phone": "+70717212515"}
0005432568506	2DEC22	5645 094546	SVETLANA VASILEVA	{"email": "vasileva-s.09071971@postgrespro.ru", "phone": "+70742051120"}
0005432568507	DBABCE	2120 173341	PETR KUZNECOV	{"email": "kuznecovp-06111965@postgrespro.ru", "phone": "+70529886538"}
0005432568508	BE2CEA	8032 634576	NADEZHDA SOKOLOVA	{"email": "nadezhda-sokolova_1965@postgrespro.ru", "phone": "+70071873393"}
0005432568509	D6880D	4401 059861	MIKHAIL NAZAROV	{"phone": "+70849617422"}
0005432568510	42F4B4	0443 029795	LYUBOV GRISHINA	{"phone": "+70836775826"}
0005432568511	AE5590	4442 775643	NADEZHDA MOROZOVA	{"phone": "+70587279951"}
0005432568512	AE5590	8013 064460	GALINA ZAKHAROVA	{"email": "zakharovag.1972@postgrespro.ru", "phone": "+70624805939"}
0005432568513	9BB16E	9294 054015	ARTEM ZAKHAROV	{"email": "zakharov-artem1963@postgrespro.ru", "phone": "+70748900496"}
0005432568514	111855	9442 464428	DANIIL BELOV	{"email": "belov-d-061981@postgrespro.ru", "phone": "+70667304321"}
0005432568515	CFF480	8692 923708	TATYANA IVANOVA	{"email": "tatyana_ivanova121975@postgrespro.ru", "phone": "+70997264041"}
0005432568516	0A8914	0385 934599	NIKOLAY KRASNOV	{"phone": "+70993255040"}
0005432568517	FC197D	6792 720405	LARISA KUZNECOVA	{"email": "larisa.kuznecova1976@postgrespro.ru", "phone": "+70555761893"}
0005432568518	C171FD	3097 550004	NADEZHDA IVANOVA	{"phone": "+70514385567"}
0005432568519	C171FD	1881 419381	PAVEL FEDOROV	{"phone": "+70748462123"}
0005432568520	C171FD	3383 145646	ASIYA SOKOLOVA	{"phone": "+70910837400"}
0005432568522	EF8ED1	4188 788042	EGOR ROMANOV	{"phone": "+70598599137"}
0005432568523	A91E48	3320 203381	ALEKSANDR FOMIN	{"phone": "+70633011446"}
0005432568524	907406	1468 843193	ELENA KUZNECOVA	{"email": "elena-kuznecova.1962@postgrespro.ru", "phone": "+70238690232"}
0005432568525	85A673	6726 302543	NINA TIKHONOVA	{"email": "tikhonova.nina_1974@postgrespro.ru", "phone": "+70748124247"}
0005432568526	ED721D	3743 345823	ELENA TARASOVA	{"email": "etarasova.26101973@postgrespro.ru", "phone": "+70191398649"}
0005432568527	621F1C	3304 275314	NINA YAKOVLEVA	{"phone": "+70602141141"}
0005432568528	CAD2C7	9158 833240	KSENIYA AFANASEVA	{"phone": "+70598992110"}
0005432568529	63383B	1528 737674	VLADIMIR DAVYDOV	{"email": "davydov-vladimir1971@postgrespro.ru", "phone": "+70923663188"}
0005432568530	5A6496	1384 634514	ANTON KUDRYASHOV	{"phone": "+70172697748"}
0005432568531	949808	0986 091762	YULIYA MALYSHEVA	{"phone": "+70158009891"}
0005432568532	949808	7359 531777	DMITRIY NIKOLAEV	{"phone": "+70215587591"}
0005432568533	E8C8EA	7994 556092	OLGA NAZAROVA	{"phone": "+70410240493"}
0005432568534	E8C8EA	2006 056970	DMITRIY DMITRIEV	{"email": "dmitriev.d_10111974@postgrespro.ru", "phone": "+70957535785"}
0005432568535	D9A108	8735 820369	MAKSIM SOROKIN	{"phone": "+70405329587"}
0005432568536	264C29	8140 952915	RAISA KOZLOVA	{"email": "kozlova_r1971@postgrespro.ru", "phone": "+70064539326"}
0005432568537	264C29	7937 011077	TATYANA VOROBEVA	{"phone": "+70474562868"}
0005432568538	BD044B	8532 389772	SERGEY EGOROV	{"phone": "+70936463252"}
0005432568539	BD044B	9105 300342	ALEKSEY KONOVALOV	{"phone": "+70086855251"}
0005432568540	E2DBEE	6768 033208	EVGENIY AFANASEV	{"email": "evgeniy_afanasev.091984@postgrespro.ru", "phone": "+70230330029"}
0005432568541	E2DBEE	6024 766839	MARIYA MAKAROVA	{"email": "mariya.makarova09121965@postgrespro.ru", "phone": "+70512804497"}
0005432568542	D01533	6004 735382	ANTON SERGEEV	{"phone": "+70698391861"}
0005432568543	0E3EAD	4738 326882	VLADIMIR DMITRIEV	{"email": "v_dmitriev.25091971@postgrespro.ru", "phone": "+70268932397"}
0005432568544	8ABC4F	0526 044120	NATALYA FROLOVA	{"email": "natalya-frolova_26051976@postgrespro.ru", "phone": "+70387601476"}
0005432568545	7C7840	1087 508459	ILYA KISELEV	{"email": "kiselevilya.081980@postgrespro.ru", "phone": "+70034547417"}
0005432568546	7C7840	1158 855835	EKATERINA KOROLEVA	{"email": "koroleva-ekaterina.17111969@postgrespro.ru", "phone": "+70808930814"}
0005432568547	CBB8A0	3263 837173	VALERIY PAVLOV	{"phone": "+70054884427"}
0005432568548	6F2446	9041 082186	VSEVOLOD RODIONOV	{"phone": "+70183778797"}
0005432568549	307ED0	8354 739428	ARTEM KUZMIN	{"phone": "+70339317768"}
0005432568550	A1E6A7	2329 060835	NADEZHDA GUSEVA	{"email": "guseva_nadezhda.18011973@postgrespro.ru", "phone": "+70967630181"}
0005432568551	8F6233	6624 971557	ALEKSANDR STEPANOV	{"phone": "+70437445550"}
0005432568552	8F6233	2452 778940	RIMA SEMENOVA	{"phone": "+70384837133"}
0005432568553	2C876C	0736 622430	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr1970@postgrespro.ru", "phone": "+70059445775"}
0005432568554	CF9973	4845 325813	ALEKSEY MAKSIMOV	{"email": "maksimov-a_1978@postgrespro.ru", "phone": "+70286464479"}
0005432568555	CF9973	4564 275305	ALLA TARASOVA	{"email": "alla.tarasova-021982@postgrespro.ru", "phone": "+70201491662"}
0005432568556	28C1FC	6260 906747	MARINA IVANOVA	{"phone": "+70426100308"}
0005432568557	ADE0C5	2851 632528	IVAN ANDREEV	{"email": "andreev.ivan.1971@postgrespro.ru", "phone": "+70130047527"}
0005432568558	AC53D4	4713 334442	LYUBOV KARPOVA	{"email": "lyubov_karpova_051968@postgrespro.ru", "phone": "+70207078392"}
0005432568559	1591DA	7809 886925	VITALIY KOZLOV	{"phone": "+70603583845"}
0005432568560	8FC6D0	5094 898665	ALEKSANDR MEDVEDEV	{"phone": "+70679539374"}
0005432568561	8FC6D0	8978 915269	DARYA NIKOLAEVA	{"email": "nikolaeva-darya.12101970@postgrespro.ru", "phone": "+70258972359"}
0005432568562	EC937E	8221 888818	ULYANA ROMANOVA	{"email": "u_romanova021974@postgrespro.ru", "phone": "+70958781469"}
0005432568563	1B6904	5898 325654	NIKOLAY SMIRNOV	{"phone": "+70845487596"}
0005432568564	1B6904	1445 341367	VLADIMIR ORLOV	{"email": "orlov_vladimir_1970@postgrespro.ru", "phone": "+70640160240"}
0005432568565	8FA74C	3584 626802	IGOR MOROZOV	{"email": "morozov_igor-031962@postgrespro.ru", "phone": "+70952642026"}
0005432568566	549A48	7256 700292	LYUBOV BORISOVA	{"email": "borisova-lyubov-061963@postgrespro.ru", "phone": "+70533170914"}
0005432568567	F85320	2719 140824	VLADISLAV STEPANOV	{"phone": "+70025343374"}
0005432568568	878C0F	6034 895498	ARINA YUDINA	{"email": "yudina.arina.1978@postgrespro.ru", "phone": "+70704073657"}
0005432568569	878C0F	4494 183637	SERGEY NIKOLAEV	{"phone": "+70413064374"}
0005432568570	B5A933	9317 611165	LYUBOV KOROLEVA	{"email": "lyubovkoroleva_1963@postgrespro.ru", "phone": "+70458551578"}
0005432568571	3F4602	2531 268590	VLADIMIR ANTONOV	{"email": "vladimirantonov_111963@postgrespro.ru", "phone": "+70517394252"}
0005432568572	951EE4	1278 963147	ELENA YAKOVLEVA	{"phone": "+70038398214"}
0005432568573	951EE4	5600 202463	IRINA GUSEVA	{"phone": "+70282848732"}
0005432568574	951EE4	8297 513789	ALEKSANDR KOZLOV	{"email": "a_kozlov_21011977@postgrespro.ru", "phone": "+70702959789"}
0005432568575	913B5C	0957 902668	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr.20101973@postgrespro.ru", "phone": "+70613823803"}
0005432568576	913B5C	2106 855707	ALEKSANDR KUZMIN	{"email": "a.kuzmin_1973@postgrespro.ru", "phone": "+70007632807"}
0005432568577	A9AAE9	6939 535474	ANDREY KULIKOV	{"email": "kulikova1967@postgrespro.ru", "phone": "+70431790223"}
0005432568578	67B343	3965 749651	VIKTOR FROLOV	{"email": "frolov-viktor.12111970@postgrespro.ru", "phone": "+70535103300"}
0005432568579	E29AA4	4339 611681	SERGEY KONOVALOV	{"phone": "+70912605047"}
0005432568580	B9BBF5	5016 317999	ANDREY EGOROV	{"email": "egorov_a-041978@postgrespro.ru", "phone": "+70473524617"}
0005432568581	899CCF	7280 632549	EVGENIY POPOV	{"email": "popov-e.091968@postgrespro.ru", "phone": "+70371506960"}
0005432568582	9BF534	3666 065009	YURIY GRIGOREV	{"email": "yuriygrigorev.101973@postgrespro.ru", "phone": "+70203488087"}
0005432568583	FA6920	1714 695243	ARINA BELOVA	{"phone": "+70628002953"}
0005432568584	386F4C	0337 877473	SERGEY KRASNOV	{"phone": "+70989588991"}
0005432568585	386F4C	8221 966367	DMITRIY MEDVEDEV	{"phone": "+70515302469"}
0005432568586	F19DCF	5518 792759	SVETLANA PAVLOVA	{"phone": "+70008792037"}
0005432568587	DC37DD	5301 316490	ELENA ZHUKOVA	{"phone": "+70233463045"}
0005432568588	4A47C5	0429 758609	ALEKSEY GORBUNOV	{"email": "gorbunovaleksey-011976@postgrespro.ru", "phone": "+70627002714"}
0005432568589	4A47C5	8394 478534	ANDREY NIKITIN	{"email": "nikitin.a25051970@postgrespro.ru", "phone": "+70125106620"}
0005432568590	DD1147	1894 825127	LYUDMILA MIRONOVA	{"email": "mironova_l_1975@postgrespro.ru", "phone": "+70781864990"}
0005432568591	DD1147	4608 945616	VLADISLAV KAZAKOV	{"email": "v-kazakov1969@postgrespro.ru", "phone": "+70235827517"}
0005432568592	4C6A82	6288 169872	TATYANA CHERNOVA	{"phone": "+70079251685"}
0005432568593	659A0A	8232 096225	MAKSIM KRASNOV	{"phone": "+70330215624"}
0005432568594	659A0A	2495 350424	NIKOLAY GUSEV	{"phone": "+70117359836"}
0005432568595	DD7F33	0492 207335	TATYANA FILATOVA	{"email": "filatovat041970@postgrespro.ru", "phone": "+70570329605"}
0005432568596	7EDC98	3550 827356	ALEKSEY FEDOTOV	{"email": "fedotov-a1977@postgrespro.ru", "phone": "+70049094260"}
0005432568597	7EDC98	5907 611147	ELENA SIDOROVA	{"email": "elena.sidorova.1976@postgrespro.ru", "phone": "+70565007859"}
0005432568598	AD61AF	9384 385088	OLGA ERMAKOVA	{"phone": "+70039049154"}
0005432568599	655365	4974 407544	VLADIMIR POPOV	{"email": "v_popov1972@postgrespro.ru", "phone": "+70966891174"}
0005432568600	655365	1330 161562	ANAIT EGOROVA	{"phone": "+70150082797"}
0005432568601	CED814	5947 178980	BORIS ROMANOV	{"phone": "+70505893945"}
0005432568602	DDB47C	5256 777257	TATYANA SIDOROVA	{"email": "tatyana_sidorova1973@postgrespro.ru", "phone": "+70660482470"}
0005432568603	6B078B	6872 243047	BORIS SOKOLOV	{"email": "bsokolov-30071966@postgrespro.ru", "phone": "+70472623128"}
0005432568604	CEA29C	3953 155732	YULIYA SAVELEVA	{"phone": "+70630356268"}
0005432568605	CEA29C	2910 271586	KAPITALINA MARTYNOVA	{"email": "martynova.k.1966@postgrespro.ru", "phone": "+70776142492"}
0005432568606	A11EC1	5558 782688	RAVZA NESTEROVA	{"phone": "+70430748183"}
0005432568607	E724B6	4912 564471	ANATOLIY ABRAMOV	{"phone": "+70128148077"}
0005432568608	E724B6	5708 852985	TATYANA ALEKSEEVA	{"email": "talekseeva-1969@postgrespro.ru", "phone": "+70525264900"}
0005432568609	826667	2712 569910	ULYANA AKIMOVA	{"email": "akimova-ulyana_19081967@postgrespro.ru", "phone": "+70706438602"}
0005432568610	826667	2119 780214	EGOR KUZMIN	{"email": "e-kuzmin-101971@postgrespro.ru", "phone": "+70206469084"}
0005432568611	826667	1586 123636	MAKSIM SIDOROV	{"email": "sidorov_maksim_071975@postgrespro.ru", "phone": "+70850717951"}
0005432568612	540212	5261 302715	EVGENIYA VASILEVA	{"phone": "+70093981150"}
0005432568613	540212	8123 247029	ANATOLIY IVANOV	{"email": "anatoliy-ivanov1975@postgrespro.ru", "phone": "+70179004512"}
0005432568614	1A8BBB	4972 090126	GAGIK IVANOV	{"phone": "+70784011034"}
0005432568615	ABA8C2	3565 492227	TATYANA IVANOVA	{"phone": "+70537906046"}
0005432568616	2A9241	9178 130573	ZOYA ZAYCEVA	{"email": "z-zayceva_051973@postgrespro.ru", "phone": "+70833245993"}
0005432568617	B0D60A	9861 769605	VALENTINA FILIPPOVA	{"email": "vfilippova_041966@postgrespro.ru", "phone": "+70977231626"}
0005432568618	B0D60A	9932 513396	LARISA PAVLOVA	{"email": "larisa.pavlova_1969@postgrespro.ru", "phone": "+70371524903"}
0005432568619	0DD823	6154 760740	GALINA MAKAROVA	{"phone": "+70776006854"}
0005432568620	A71EE1	0456 103965	ZULFIYA KONDRATEVA	{"email": "zulfiya_kondrateva_10071971@postgrespro.ru", "phone": "+70056844613"}
0005432568621	30EF03	6186 189316	OLGA IVANOVA	{"email": "ivanova_o_011978@postgrespro.ru", "phone": "+70291660194"}
0005432568622	A9E182	9165 331887	GENNADIY NAUMOV	{"phone": "+70851352110"}
0005432568623	A9E182	8162 813986	ANNA IVANOVA	{"email": "a_ivanova.121969@postgrespro.ru", "phone": "+70816971734"}
0005432568624	BDBCBE	2358 535520	ALEKSANDR MARTYNOV	{"email": "a-martynov.16041976@postgrespro.ru", "phone": "+70526865281"}
0005432568625	7D5F45	6493 501591	ANTON ZAKHAROV	{"email": "azakharov.05011974@postgrespro.ru", "phone": "+70509827844"}
0005432568626	7D5F45	1396 139344	ROMAN NIKITIN	{"phone": "+70594171057"}
0005432568627	D1A234	3732 219824	OLGA MOISEEVA	{"email": "olgamoiseeva-25071964@postgrespro.ru", "phone": "+70386720149"}
0005432568628	FB841F	7980 574064	ALBERT VOLKOV	{"phone": "+70662010772"}
0005432568629	8ACC8A	3239 953598	EVGENIY KULIKOV	{"phone": "+70581334879"}
0005432568630	8ACC8A	4270 527675	ALEKSANDR NOVIKOV	{"email": "novikovaleksandr_25121979@postgrespro.ru", "phone": "+70842600283"}
0005432568631	5028E7	4724 316230	LIDIYA GERASIMOVA	{"email": "gerasimovalidiya-021967@postgrespro.ru", "phone": "+70517118067"}
0005432568632	5028E7	8040 180341	ALISA DENISOVA	{"email": "denisova_alisa-1963@postgrespro.ru", "phone": "+70758964441"}
0005432568633	3FE651	7083 118753	YULIYA IVANOVA	{"email": "y_ivanova.1975@postgrespro.ru", "phone": "+70649023376"}
0005432568634	A66988	2900 670896	YULIYA STEPANOVA	{"phone": "+70415618953"}
0005432568635	282F96	1773 915783	TAMARA KUZNECOVA	{"phone": "+70954023889"}
0005432568636	A87079	7775 170243	TAMARA IVANOVA	{"phone": "+70974549105"}
0005432568637	A87079	1198 449987	LYUDMILA SIDOROVA	{"phone": "+70159767515"}
0005432568638	733279	7733 840335	DMITRIY DAVYDOV	{"phone": "+70665679580"}
0005432568639	733279	8746 522556	ANATOLIY ANTONOV	{"email": "antonov_a-25091973@postgrespro.ru", "phone": "+70743724260"}
0005432568640	7D0192	4478 863407	ANATOLIY MIRONOV	{"email": "mironov-a-15101968@postgrespro.ru", "phone": "+70157608349"}
0005432568641	C980B7	4437 801230	VLADISLAV KARPOV	{"phone": "+70929202700"}
0005432568642	C76802	7204 467155	SVETLANA NIKOLAEVA	{"email": "s-nikolaeva_1970@postgrespro.ru", "phone": "+70959728282"}
0005432568643	5B7870	6114 889706	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova-31121969@postgrespro.ru", "phone": "+70388704014"}
0005432568644	5B7870	7864 207177	SERGEY PAVLOV	{"phone": "+70487849733"}
0005432568645	1C7021	1642 384604	PAVEL PAVLOV	{"email": "p_pavlov.1970@postgrespro.ru", "phone": "+70367778728"}
0005432568646	1C7021	6376 767860	ZOYA NAZAROVA	{"phone": "+70095124609"}
0005432568647	096EBA	7498 257574	OKSANA DMITRIEVA	{"email": "dmitrieva.o_041984@postgrespro.ru", "phone": "+70373891160"}
0005432568648	56ABC4	9482 908758	VLADIMIR NOVIKOV	{"email": "novikovvladimir011972@postgrespro.ru", "phone": "+70438953538"}
0005432568649	5AF511	1888 233936	TATYANA SEMENOVA	{"email": "semenova_tatyana-1974@postgrespro.ru", "phone": "+70483592769"}
0005432568650	5AF511	6179 864798	ZULFIYA FROLOVA	{"phone": "+70914667797"}
0005432568651	E10F20	0105 165120	KLAVDIYA ILINA	{"email": "kilina_02041979@postgrespro.ru", "phone": "+70149818119"}
0005432568652	2C7CCD	4659 841030	ANTONINA KRASNOVA	{"email": "krasnova.antonina_101971@postgrespro.ru", "phone": "+70115816150"}
0005432568653	4B8C06	9915 148242	ALENA EGOROVA	{"email": "a-egorova14071973@postgrespro.ru", "phone": "+70181597593"}
0005432568654	8408FC	0044 489253	ALEKSANDR YAKOVLEV	{"email": "yakovlev_a-091976@postgrespro.ru", "phone": "+70020954966"}
0005432568655	06AB4C	8751 231810	IRINA KUZMINA	{"email": "i_kuzmina_121978@postgrespro.ru", "phone": "+70248619385"}
0005432568656	06AB4C	9889 647062	MARK SOROKIN	{"phone": "+70710311802"}
0005432568657	9F6DBB	1897 680789	KRISTINA YAKOVLEVA	{"phone": "+70965550370"}
0005432568658	5AB73F	4292 853638	ELENA DENISOVA	{"phone": "+70212960174"}
0005432568659	91F9CB	8053 868833	TATYANA GUSEVA	{"email": "t-guseva_071969@postgrespro.ru", "phone": "+70824916053"}
0005432568660	91F9CB	7097 519613	SVETLANA MIRONOVA	{"email": "svetlana-mironova081984@postgrespro.ru", "phone": "+70222277839"}
0005432568661	9004A8	9064 686537	LYUBOV NIKIFOROVA	{"email": "l.nikiforova081967@postgrespro.ru", "phone": "+70791676947"}
0005432568662	71A0A7	3999 376476	OKSANA BOGDANOVA	{"email": "o_bogdanova.11121975@postgrespro.ru", "phone": "+70664601998"}
0005432568663	71A0A7	5320 231992	GENNADIY VASILEV	{"email": "gennadiyvasilev1970@postgrespro.ru", "phone": "+70111272455"}
0005432568664	71A0A7	3701 437049	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_1965@postgrespro.ru", "phone": "+70453364405"}
0005432568665	8A2D1E	8134 009399	EVGENIY KUZMIN	{"phone": "+70476685923"}
0005432568666	F1E4D1	5655 505837	VIKTOR VOROBEV	{"email": "v-vorobev051962@postgrespro.ru", "phone": "+70502724146"}
0005432568667	F219F8	9869 450440	TATYANA NAZAROVA	{"email": "nazarovatatyana_21021967@postgrespro.ru", "phone": "+70815525668"}
0005432568668	F03B83	4969 825519	ANASTASIYA KARPOVA	{"phone": "+70259297398"}
0005432568669	F03B83	5539 035323	DARYA GAVRILOVA	{"phone": "+70791898817"}
0005432568670	F03B83	2221 169346	NATALYA MOROZOVA	{"phone": "+70235696389"}
0005432568671	DD5A7D	3656 660967	MARIYA SERGEEVA	{"email": "sergeeva_m-1963@postgrespro.ru", "phone": "+70270284633"}
0005432568672	DD5A7D	4403 402894	RUSLAN STEPANOV	{"phone": "+70664195188"}
0005432568673	EDB488	5081 386387	ILGIZ POPOV	{"email": "i-popov-011983@postgrespro.ru", "phone": "+70724623339"}
0005432568674	EDB488	5660 766674	ELENA ILINA	{"email": "ilina-elena-1962@postgrespro.ru", "phone": "+70125087457"}
0005432568675	65B33F	8803 670773	YULIYA MIRONOVA	{"phone": "+70938926370"}
0005432568676	BB6A0D	3489 033627	NAZIYA MAKSIMOVA	{"email": "maksimova_naziya-1968@postgrespro.ru", "phone": "+70581769156"}
0005432568677	5558AB	5840 150650	EKATERINA NIKOLAEVA	{"phone": "+70689606739"}
0005432568678	5558AB	8239 060125	TATYANA SMIRNOVA	{"email": "t_smirnova.25111975@postgrespro.ru", "phone": "+70665906776"}
0005432568679	19C54F	1217 083786	KRISTINA TARASOVA	{"email": "kristina_tarasova27041974@postgrespro.ru", "phone": "+70864120177"}
0005432568680	19C54F	1742 741215	VLADIMIR ZHUKOV	{"email": "zhukov_vladimir041974@postgrespro.ru", "phone": "+70145757350"}
0005432568681	23E555	7149 032954	MIKHAIL FROLOV	{"email": "mikhail.frolov_1979@postgrespro.ru", "phone": "+70125688437"}
0005432568682	B22B7B	7201 842078	ROMAN SHEVCHENKO	{"email": "shevchenko.roman.071966@postgrespro.ru", "phone": "+70663375791"}
0005432568683	0F7E4A	9809 268778	SERGEY ANTONOV	{"email": "s.antonov.14071967@postgrespro.ru", "phone": "+70550156135"}
0005432568684	F242E3	6734 399868	DMITRIY FILIPPOV	{"email": "filippovdmitriy19071968@postgrespro.ru", "phone": "+70672737649"}
0005432568685	AD35F9	4118 350061	SERGEY DMITRIEV	{"email": "sergey-dmitriev_121984@postgrespro.ru", "phone": "+70364044485"}
0005432568686	AD35F9	3382 512703	BORIS SCHERBAKOV	{"phone": "+70837792058"}
0005432568687	F1102B	1160 092432	LARISA SOKOLOVA	{"phone": "+70131570573"}
0005432568688	AFA6FF	6497 506769	ELENA NIKOLAEVA	{"email": "elena.nikolaeva.23111970@postgrespro.ru", "phone": "+70083844988"}
0005432568689	27F7EB	5003 499669	VALENTINA TIKHONOVA	{"email": "vtikhonova_1971@postgrespro.ru", "phone": "+70498481778"}
0005432568690	31D128	9380 745213	MIKHAIL YAKOVLEV	{"phone": "+70577088411"}
0005432568691	31D128	0058 503743	VLADIMIR GUSEV	{"phone": "+70091149554"}
0005432568692	31D128	7392 015551	ANTONINA IVANOVA	{"email": "ivanova.a-081969@postgrespro.ru", "phone": "+70014990401"}
0005432568693	62F431	9636 357784	MAKSIM PAVLOV	{"email": "maksimpavlov_13051976@postgrespro.ru", "phone": "+70530332376"}
0005432568694	165EF9	8108 666612	NIKOLAY KULIKOV	{"email": "nikolaykulikov011975@postgrespro.ru", "phone": "+70926601944"}
0005432568695	165EF9	0210 148881	VALENTINA STEPANOVA	{"phone": "+70337294831"}
0005432568696	6D73A9	2540 619238	NADEZHDA ALEKSEEVA	{"phone": "+70303935406"}
0005432568697	DEAC8A	0157 236985	ANDREY OSIPOV	{"phone": "+70817851830"}
0005432568698	8DBE29	7459 649052	SERGEY MIKHAYLOV	{"email": "mikhaylov.sergey.06091968@postgrespro.ru", "phone": "+70688880450"}
0005432568699	7C7C67	1935 624942	VIKTOR NIKITIN	{"phone": "+70214967670"}
0005432568700	F3612E	1240 458289	VLADIMIR KONOVALOV	{"email": "vladimir.konovalov-1971@postgrespro.ru", "phone": "+70866898690"}
0005432568701	B4D839	9491 673620	SERGEY NIKOLAEV	{"phone": "+70043641382"}
0005432568702	5F62ED	7752 654806	TATYANA POPOVA	{"phone": "+70962383347"}
0005432568703	F865F6	9282 919006	NADEZHDA YUDINA	{"email": "yudinan_1970@postgrespro.ru", "phone": "+70744651006"}
0005432568704	F865F6	6934 758508	ROMAN VOLKOV	{"email": "volkovroman.1970@postgrespro.ru", "phone": "+70844138431"}
0005432568705	983EA7	3369 597876	MARGARITA KAZAKOVA	{"email": "m-kazakova-051975@postgrespro.ru", "phone": "+70670366633"}
0005432568706	D2F972	8094 245855	LADA RYABOVA	{"phone": "+70867029678"}
0005432568707	D2F972	4483 015611	VALENTIN FILIPPOV	{"phone": "+70593154868"}
0005432568708	99763E	7252 773959	VIKTOR IVANOV	{"phone": "+70263164752"}
0005432568709	C72837	4027 837966	NATALYA MASLOVA	{"phone": "+70554184465"}
0005432568710	7F7970	1111 313278	SERGEY FROLOV	{"phone": "+70968143273"}
0005432568711	7F7970	9974 504096	ALEKSANDR KUDRYASHOV	{"email": "a-kudryashov-021965@postgrespro.ru", "phone": "+70439171196"}
0005432568712	7F7970	3301 079406	SERGEY MEDVEDEV	{"phone": "+70133420174"}
0005432568713	4E7DAC	4746 516782	DMITRIY SOLOVEV	{"email": "solovevd1972@postgrespro.ru", "phone": "+70596384487"}
0005432568714	2C9531	8532 596424	ALENA KUZMINA	{"email": "akuzmina_011973@postgrespro.ru", "phone": "+70253013137"}
0005432568715	EAEA7D	5978 651554	MARINA KUZNECOVA	{"email": "marina.kuznecova.1969@postgrespro.ru", "phone": "+70179300111"}
0005432568716	EAEA7D	5980 698040	EKATERINA ORLOVA	{"email": "e_orlova1967@postgrespro.ru", "phone": "+70847594650"}
0005432568717	5B79D8	7325 486785	RAFAIL EGOROV	{"email": "rafail.egorov_051974@postgrespro.ru", "phone": "+70881871338"}
0005432568718	B05BDD	6031 075797	NATALYA ZAKHAROVA	{"phone": "+70476336948"}
0005432568719	86FFB9	5945 495285	GRIGORIY ZHURAVLEV	{"phone": "+70569573308"}
0005432568720	86FFB9	5915 462456	KLAVDIYA VASILEVA	{"phone": "+70993088754"}
0005432568721	D5ED8A	5479 353705	SERGEY POPOV	{"phone": "+70752838906"}
0005432568722	333E2E	3522 381759	SERGEY DMITRIEV	{"email": "sergeydmitriev.1976@postgrespro.ru", "phone": "+70784078934"}
0005432568723	93D162	0558 692076	VALENTINA POPOVA	{"phone": "+70783749860"}
0005432568724	4A6799	2399 503997	SERGEY DMITRIEV	{"email": "dmitriev.s-011963@postgrespro.ru", "phone": "+70104895911"}
0005432568725	545A14	7467 049140	OLEG IVANOV	{"phone": "+70115629340"}
0005432568726	43DDF5	5932 279188	VERA OVCHINNIKOVA	{"phone": "+70487677677"}
0005432568727	5F2555	7485 017481	LARISA MAKAROVA	{"phone": "+70358788118"}
0005432568728	5F2555	3635 011625	MARIYA SEMENOVA	{"phone": "+70266939466"}
0005432568729	F85167	2038 516499	VLADIMIR DENISOV	{"email": "v_denisov29031972@postgrespro.ru", "phone": "+70922349807"}
0005432568730	215CC9	7095 315371	EVGENIY KONOVALOV	{"email": "konovalov_e-16101967@postgrespro.ru", "phone": "+70044678189"}
0005432568731	215CC9	5725 365191	OLEG FILIPPOV	{"phone": "+70162514558"}
0005432568732	D397CB	2770 631489	TATYANA NIKIFOROVA	{"email": "nikiforovatatyana21051958@postgrespro.ru", "phone": "+70017838245"}
0005432568733	D397CB	2105 891509	ANDREY FEDOROV	{"phone": "+70160551085"}
0005432568734	654747	5795 678267	EGOR ANTONOV	{"email": "e-antonov-05091963@postgrespro.ru", "phone": "+70402072843"}
0005432568735	654747	4209 570944	ZOYA STEPANOVA	{"email": "stepanova_zoya121971@postgrespro.ru", "phone": "+70999400843"}
0005432568736	5BD351	1326 679121	ANDREY KUZNECOV	{"phone": "+70099910181"}
0005432568737	FE5B38	6230 688060	LIDIYA LAZAREVA	{"email": "lazareva-l.081978@postgrespro.ru", "phone": "+70686165138"}
0005432568738	FE5B38	8207 303109	VLADIMIR MARTYNOV	{"phone": "+70626974843"}
0005432568739	647D0C	3803 307727	ELENA EFIMOVA	{"email": "elena_efimova1975@postgrespro.ru", "phone": "+70942077516"}
0005432568740	DDFA45	9634 614377	ANNA BARANOVA	{"phone": "+70626846890"}
0005432568741	6F01F4	9417 688707	NATALYA BELOVA	{"email": "belovanatalya.051971@postgrespro.ru", "phone": "+70415463877"}
0005432568742	6F01F4	6679 983020	PAVEL MATVEEV	{"email": "matveev.p1974@postgrespro.ru", "phone": "+70611355339"}
0005432569156	CAB905	6405 304123	ELIZAVETA SOROKINA	{"phone": "+70934127382"}
0005432568743	DBF32F	1616 935648	ELENA ALEKSEEVA	{"email": "elena-alekseeva_031973@postgrespro.ru", "phone": "+70992978570"}
0005432568744	9DF8B5	7883 187313	EKATERINA SERGEEVA	{"phone": "+70511166576"}
0005432568745	9DF8B5	7097 378102	VLADIMIR PETROV	{"phone": "+70925257098"}
0005432568746	FED517	2668 317408	YURIY KRASNOV	{"email": "y-krasnov-031962@postgrespro.ru", "phone": "+70690733456"}
0005432568747	1B52DE	7380 301450	ZOYA NIKITINA	{"phone": "+70595385307"}
0005432568748	B05230	9747 951317	OLEG NIKITIN	{"email": "onikitin_1966@postgrespro.ru", "phone": "+70246674978"}
0005432568749	B05230	6428 724413	ROMAN MEDVEDEV	{"phone": "+70224981709"}
0005432568750	AC5092	8477 275043	ELVIRA NOVIKOVA	{"email": "novikova-elvira09051968@postgrespro.ru", "phone": "+70446924660"}
0005432568751	AC5092	4363 926397	INNA SCHERBAKOVA	{"phone": "+70086044353"}
0005432568752	DE2512	1993 027758	LARISA VASILEVA	{"email": "l_vasileva-1974@postgrespro.ru", "phone": "+70885520743"}
0005432568753	DB6D73	2536 848267	GULNARA DENISOVA	{"email": "denisovag-041974@postgrespro.ru", "phone": "+70738982816"}
0005432568754	4B416E	3172 085340	IRINA ANDREEVA	{"email": "andreeva_irina1972@postgrespro.ru", "phone": "+70885468469"}
0005432568755	4B416E	5123 497909	SEMEN FEDOROV	{"phone": "+70247921572"}
0005432568756	A67016	4903 432372	GRIGORIY KUZNECOV	{"phone": "+70424554568"}
0005432568757	A67016	3114 283649	ANDREY OSIPOV	{"phone": "+70235018611"}
0005432568758	948A31	9301 433874	MARIYA KUDRYASHOVA	{"email": "kudryashova.mariya-061959@postgrespro.ru", "phone": "+70928319404"}
0005432568759	948A31	3144 242181	NATALYA IVANOVA	{"email": "ivanovanatalya1976@postgrespro.ru", "phone": "+70580399884"}
0005432568760	F0BBA4	3385 908988	PETR SOROKIN	{"email": "petr_sorokin-101972@postgrespro.ru", "phone": "+70970787201"}
0005432568761	08E3D8	1253 493453	ELENA FADEEVA	{"phone": "+70174968908"}
0005432568762	08E3D8	1602 820714	OLGA SOLOVEVA	{"email": "soloveva_olga-08081977@postgrespro.ru", "phone": "+70977025996"}
0005432568763	5DD731	9813 990240	ELENA NIKITINA	{"phone": "+70803433512"}
0005432568764	2A7B1B	8743 713494	ILYA BORISOV	{"email": "borisov_ilya-061973@postgrespro.ru", "phone": "+70499300992"}
0005432568765	2A7B1B	6216 210276	TAMARA KUZNECOVA	{"phone": "+70027349796"}
0005432568766	2A7B1B	1770 987207	PAVEL NAUMOV	{"email": "naumov.p-101972@postgrespro.ru", "phone": "+70233500964"}
0005432568767	B1D8E9	0483 717703	VLADIMIR RODIONOV	{"email": "rodionovv19091973@postgrespro.ru", "phone": "+70400859762"}
0005432568768	E9B12E	9202 095586	TATYANA POPOVA	{"email": "popova-t_29071975@postgrespro.ru", "phone": "+70551526633"}
0005432568769	9B87CE	6864 351432	NIKOLAY KUZMIN	{"phone": "+70610192877"}
0005432568770	ED82F0	2449 491884	VITALIY ABRAMOV	{"phone": "+70554277904"}
0005432568771	ED82F0	4153 467487	YULIYA NIKOLAEVA	{"phone": "+70640965077"}
0005432568772	6C4F1D	6996 651247	NATALYA NIKITINA	{"email": "n.nikitina-1975@postgrespro.ru", "phone": "+70964105888"}
0005432568773	4DC351	1428 665982	ANDREY ANDREEV	{"phone": "+70589754785"}
0005432568774	3B60DC	8090 369367	YULIYA VOLKOVA	{"phone": "+70092788984"}
0005432568775	3B60DC	9410 314147	EVGENIYA IVANOVA	{"email": "e.ivanova_19031974@postgrespro.ru", "phone": "+70250129843"}
0005432568776	117718	2944 027935	NATALYA IVANOVA	{"email": "ivanova-natalya031965@postgrespro.ru", "phone": "+70567635123"}
0005432568777	AFBFD6	5472 266224	SERGEY GRIGOREV	{"phone": "+70577526426"}
0005432568778	AEE3D2	6654 903952	IVAN MAKAROV	{"phone": "+70926197885"}
0005432568779	AEE3D2	1525 828395	LYUDMILA ISAEVA	{"email": "isaeva-lyudmila_041956@postgrespro.ru", "phone": "+70339823245"}
0005432568780	A259E4	1213 694853	OKSANA POPOVA	{"email": "popova.o_051987@postgrespro.ru", "phone": "+70094337187"}
0005432568781	39F644	0369 100980	ALEKSANDR KISELEV	{"email": "aleksandr-kiselev-15121978@postgrespro.ru", "phone": "+70621408076"}
0005432568782	39F644	1640 778162	MARINA DMITRIEVA	{"phone": "+70924504690"}
0005432568783	6262E7	7818 797585	VERA PETROVA	{"phone": "+70150153739"}
0005432568784	6262E7	8767 335141	SERGEY VOLKOV	{"email": "svolkov_20061977@postgrespro.ru", "phone": "+70085573195"}
0005432568785	24FD55	4091 979170	VLADIMIR GAVRILOV	{"email": "v.gavrilov-111970@postgrespro.ru", "phone": "+70966903858"}
0005432568786	C46FEB	5703 456439	NIKITA GRIGOREV	{"email": "grigorev-nikita1960@postgrespro.ru", "phone": "+70490856998"}
0005432568787	B26004	1495 328723	DMITRIY BELOV	{"email": "belov.dmitriy_041978@postgrespro.ru", "phone": "+70915780976"}
0005432568788	EA7092	8689 122209	MARIYA VOLKOVA	{"email": "mariya_volkova1973@postgrespro.ru", "phone": "+70550969751"}
0005432568789	DB5719	4108 954700	NINA EGOROVA	{"email": "egorova.nina.101974@postgrespro.ru", "phone": "+70803780721"}
0005432568790	F64926	3974 429416	RODION GUSEV	{"email": "rgusev111980@postgrespro.ru", "phone": "+70878872350"}
0005432568791	F64926	7954 266502	MAKSIM ZAKHAROV	{"email": "maksim.zakharov-30071964@postgrespro.ru", "phone": "+70690676314"}
0005432568792	C3CC3A	5636 163229	SVETLANA KUDRYASHOVA	{"email": "skudryashova_1975@postgrespro.ru", "phone": "+70061127004"}
0005432568793	5744C0	2355 540334	LYUBOV IVANOVA	{"phone": "+70231514547"}
0005432568794	5871EB	4124 326736	IGOR KUZMIN	{"email": "i.kuzmin-24121988@postgrespro.ru", "phone": "+70195058479"}
0005432568795	A9B4EC	9903 969196	YULIYA KUZMINA	{"phone": "+70809063326"}
0005432568796	A9B4EC	6829 694095	SERGEY KAZAKOV	{"email": "sergey-kazakov.021967@postgrespro.ru", "phone": "+70998032000"}
0005432568797	3242E2	2090 049012	MAKSIM OSIPOV	{"phone": "+70140651042"}
0005432568798	3242E2	2506 808867	MARIYA CHERNOVA	{"email": "chernova_mariya16011958@postgrespro.ru", "phone": "+70113972332"}
0005432568799	3242E2	6093 151751	IGOR MELNIKOV	{"phone": "+70087290296"}
0005432568800	4E47E3	2888 999695	TATYANA DANILOVA	{"phone": "+70436120388"}
0005432568801	8DB596	8919 998031	FEDOR KUZMIN	{"email": "kuzminfedor1982@postgrespro.ru", "phone": "+70457944568"}
0005432569221	8E00AB	3269 448971	VASILIY NIKOLAEV	{"phone": "+70194668008"}
0005432568802	4DEEC4	2976 398729	ALEKSEY ILIN	{"email": "ilin.aleksey.27031968@postgrespro.ru", "phone": "+70178325793"}
0005432568803	D09820	2562 381394	SERGEY BORISOV	{"phone": "+70655636401"}
0005432568804	420789	3449 939602	TATYANA BOGDANOVA	{"phone": "+70103139888"}
0005432568805	32DC9A	8709 852893	ANDREY GERASIMOV	{"email": "a_gerasimov1971@postgrespro.ru", "phone": "+70884048716"}
0005432568806	98D54F	9555 307508	ELIZAVETA SMIRNOVA	{"phone": "+70914916150"}
0005432568807	98D54F	6205 007388	YURIY KAZAKOV	{"email": "kazakov_y_1975@postgrespro.ru", "phone": "+70402125453"}
0005432568808	20B9C0	8689 689433	ALEKSANDR SOKOLOV	{"email": "sokolova101969@postgrespro.ru", "phone": "+70388528176"}
0005432568809	84CF0A	3862 302854	NATALYA BOGDANOVA	{"phone": "+70681921833"}
0005432568810	AADD46	5945 483262	LYUBOV EGOROVA	{"email": "l_egorova.111972@postgrespro.ru", "phone": "+70830426059"}
0005432568811	50E4E1	1630 042205	VERONIKA KONOVALOVA	{"phone": "+70864060714"}
0005432568812	50E4E1	9667 345391	LYUDMILA SOKOLOVA	{"email": "sokolova.l23091971@postgrespro.ru", "phone": "+70516471787"}
0005432568813	67893F	0492 731878	ANATOLIY SMIRNOV	{"email": "smirnov_a.1984@postgrespro.ru", "phone": "+70565597292"}
0005432568814	67893F	1435 639505	ANNA ANTONOVA	{"email": "a_antonova-1962@postgrespro.ru", "phone": "+70670432150"}
0005432568815	8D1A31	3899 171525	MARINA EGOROVA	{"email": "marina.egorova1972@postgrespro.ru", "phone": "+70129106425"}
0005432568816	8D1A31	7698 762704	TATYANA FROLOVA	{"phone": "+70616292460"}
0005432568817	FCE287	4237 002243	YURIY IVANOV	{"phone": "+70558438737"}
0005432568818	FCE287	8909 982340	GALINA ORLOVA	{"email": "orlovagalina_17081972@postgrespro.ru", "phone": "+70736713446"}
0005432568819	6D3B7D	9684 639966	NADEZHDA CHERNOVA	{"phone": "+70726008827"}
0005432568820	6D3B7D	9544 950176	IGOR KISELEV	{"email": "kiselev_i111971@postgrespro.ru", "phone": "+70276151343"}
0005432568821	E0FF51	8048 354597	MARIYA FADEEVA	{"phone": "+70751644638"}
0005432568822	F22C38	4923 106578	GALINA KONOVALOVA	{"phone": "+70478317071"}
0005432568823	5A0955	0283 850265	NIKOLAY FILIPPOV	{"email": "filippov.n.1965@postgrespro.ru", "phone": "+70275984892"}
0005432568824	2819BD	5291 598901	ELENA FADEEVA	{"email": "fadeeva_e1969@postgrespro.ru", "phone": "+70503640724"}
0005432568825	7A6131	5934 495482	LYUBOV POPOVA	{"email": "lyubov.popova31101980@postgrespro.ru", "phone": "+70877663609"}
0005432568826	7A6131	8232 260009	ILYA POPOV	{"phone": "+70181973674"}
0005432568827	7A6131	4501 823872	VLADIMIR BARANOV	{"email": "baranovvladimir1976@postgrespro.ru", "phone": "+70897852677"}
0005432568828	90D055	9559 603471	TATYANA ANDREEVA	{"email": "tatyana_andreeva-13121974@postgrespro.ru", "phone": "+70685320666"}
0005432568829	90D055	7464 504827	IVAN IVANOV	{"email": "i_ivanov_101964@postgrespro.ru", "phone": "+70053156291"}
0005432568830	6EA5C7	8890 379655	SERGEY KAZAKOV	{"email": "s_kazakov.051965@postgrespro.ru", "phone": "+70425228006"}
0005432568831	B1AA4C	7447 621793	ANTON YAKOVLEV	{"phone": "+70872211018"}
0005432568832	362604	9972 847443	NADEZHDA ZAYCEVA	{"phone": "+70189870921"}
0005432568833	362604	1837 028243	OKSANA SERGEEVA	{"phone": "+70478538943"}
0005432568834	1835FE	6144 630993	NATALYA GUSEVA	{"phone": "+70886898203"}
0005432568835	6EA00C	9434 916059	NATALYA KUZNECOVA	{"phone": "+70919712050"}
0005432568836	892C0A	3674 924373	VALERIYA YAKOVLEVA	{"email": "valeriya_yakovleva.28101974@postgrespro.ru", "phone": "+70745938738"}
0005432568837	59F9D8	3032 977689	OLGA KOZLOVA	{"email": "kozlovaolga.01041968@postgrespro.ru", "phone": "+70641972446"}
0005432568838	C0B155	7773 354263	ALEKSEY IVANOV	{"phone": "+70523071537"}
0005432568839	1A9EBD	4376 556001	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov_041979@postgrespro.ru", "phone": "+70299408347"}
0005432568840	F8D090	1677 814873	OLEG FROLOV	{"email": "frolov-o-1966@postgrespro.ru", "phone": "+70502927846"}
0005432568841	5F4465	7420 515342	IGOR EGOROV	{"email": "egorov.igor_29091963@postgrespro.ru", "phone": "+70076131640"}
0005432568842	93D978	5835 916715	EKATERINA VLASOVA	{"email": "evlasova.16021979@postgrespro.ru", "phone": "+70749900512"}
0005432568843	93D978	0255 335532	VLADIMIR ANTONOV	{"email": "antonov.vladimir-1968@postgrespro.ru", "phone": "+70598484273"}
0005432568844	B69BE8	2548 980189	NINA ZHUKOVA	{"email": "nzhukova_121984@postgrespro.ru", "phone": "+70392100154"}
0005432568845	8D65BC	2412 964248	ALEKSANDR POPOV	{"phone": "+70609395641"}
0005432568846	8D65BC	8024 258628	ALBERT OSIPOV	{"phone": "+70043042925"}
0005432568847	AA4B27	4706 436003	IVAN KUZNECOV	{"phone": "+70458226681"}
0005432568848	558232	7527 312222	SVETLANA KOZLOVA	{"email": "kozlova_s091979@postgrespro.ru", "phone": "+70179297089"}
0005432568849	9C2930	7933 220859	YURIY DAVYDOV	{"email": "y-davydov.16071977@postgrespro.ru", "phone": "+70260910957"}
0005432568850	440C3F	6690 178346	TATYANA KOROLEVA	{"email": "koroleva-t1977@postgrespro.ru", "phone": "+70097111070"}
0005432568851	B4B452	3234 120125	VLADIMIR GRIGOREV	{"email": "v_grigorev-16021969@postgrespro.ru", "phone": "+70320590033"}
0005432568852	B4B452	6901 881241	DMITRIY IVANOV	{"phone": "+70217012255"}
0005432568853	A05826	7267 749547	IRINA IVANOVA	{"phone": "+70795738793"}
0005432568854	A38561	9325 673155	TAMARA LAZAREVA	{"phone": "+70701517919"}
0005432568855	A38561	0837 677586	IVAN KUZMIN	{"email": "kuzmin-ivan-031977@postgrespro.ru", "phone": "+70553083666"}
0005432568856	86E673	8136 764536	YULIYA POTAPOVA	{"email": "ypotapova_1982@postgrespro.ru", "phone": "+70615739405"}
0005432568857	86E673	0704 569575	DENIS SEMENOV	{"phone": "+70488151368"}
0005432568858	377EC4	3400 838077	YULIYA MIKHAYLOVA	{"phone": "+70506755103"}
0005432568859	CE6818	9826 249211	VASILIY KISELEV	{"email": "v.kiselev-06071967@postgrespro.ru", "phone": "+70137524820"}
0005432568860	65B492	9447 531395	EVGENIY FEDOROV	{"phone": "+70393468108"}
0005432568861	65B492	3282 076608	TATYANA VASILEVA	{"phone": "+70443866864"}
0005432568862	A7D7D7	2888 454641	ANNA FILIPPOVA	{"email": "filippova-anna_07031978@postgrespro.ru", "phone": "+70762995071"}
0005432568863	A7D7D7	2423 897072	YURIY GERASIMOV	{"phone": "+70500795643"}
0005432568864	2016EE	5177 092752	ULYANA IVANOVA	{"phone": "+70634581183"}
0005432568865	6EBD52	0341 016739	NIKOLAY SEMENOV	{"email": "n-semenov_091966@postgrespro.ru", "phone": "+70586015502"}
0005432568866	EE4B15	7188 963682	SVETLANA ISAEVA	{"email": "svetlana_isaeva021966@postgrespro.ru", "phone": "+70541214022"}
0005432568867	AA8924	3303 862627	ANNA FROLOVA	{"email": "frolova-anna.02071964@postgrespro.ru", "phone": "+70821139983"}
0005432568868	52363C	6465 618198	IVAN ZAYCEV	{"phone": "+70899574643"}
0005432568869	37D39F	8379 331185	NIKITA KRASNOV	{"phone": "+70602795689"}
0005432568870	37D39F	2329 036858	ANNA EFREMOVA	{"email": "efremova.a.061980@postgrespro.ru", "phone": "+70230163038"}
0005432568871	89CC4E	2550 791977	EKATERINA YUDINA	{"email": "yudina_e_13111985@postgrespro.ru", "phone": "+70480477546"}
0005432568872	7A5217	1686 906905	VLADIMIR MEDVEDEV	{"phone": "+70670085426"}
0005432568873	7A5217	0103 740024	NATALYA YAKOVLEVA	{"email": "yakovleva_n1970@postgrespro.ru", "phone": "+70698457508"}
0005432568874	7B4E29	1089 937926	MARINA ABRAMOVA	{"phone": "+70789977676"}
0005432568875	B291FE	2772 300040	ANTON POPOV	{"email": "popov_a051974@postgrespro.ru", "phone": "+70137702780"}
0005432568876	168D37	2633 430197	SERGEY ROMANOV	{"phone": "+70256347381"}
0005432568877	6EB5A3	2602 216180	ALEKSEY MEDVEDEV	{"phone": "+70638222894"}
0005432568878	191663	0615 378133	OLEG KONOVALOV	{"phone": "+70647736473"}
0005432568879	191663	7944 021281	EKATERINA KOROLEVA	{"email": "ekoroleva_071964@postgrespro.ru", "phone": "+70057639498"}
0005432568880	01E2D4	4893 742861	MATVEY VASILEV	{"phone": "+70963162471"}
0005432568881	2E4D4A	7498 569232	TATYANA ROMANOVA	{"email": "tromanova-1968@postgrespro.ru", "phone": "+70803381313"}
0005432568882	2E4D4A	4162 380286	ALEKSEY AFANASEV	{"phone": "+70753354574"}
0005432568883	2E4D4A	3704 396105	VLADIMIR ORLOV	{"phone": "+70096175269"}
0005432568884	ED693D	6996 204966	SERGEY SEMENOV	{"phone": "+70065880797"}
0005432568885	B01749	5782 369179	ANDREY VOROBEV	{"email": "vorobevandrey101972@postgrespro.ru", "phone": "+70953267779"}
0005432568886	A02B1B	4034 148795	MARIYA ZAYCEVA	{"email": "mariya_zayceva-01121971@postgrespro.ru", "phone": "+70375183349"}
0005432568887	80B943	3891 149750	ANNA KONDRATEVA	{"phone": "+70441181873"}
0005432568888	7445BF	9851 461160	LYUDMILA GUSEVA	{"email": "gusevalyudmila.1964@postgrespro.ru", "phone": "+70877405400"}
0005432568889	EA0095	7064 280968	IRINA KOLESNIKOVA	{"email": "kolesnikova_i_051968@postgrespro.ru", "phone": "+70267737699"}
0005432568890	448892	0058 469356	ELENA ZHUKOVA	{"email": "zhukova.elena1969@postgrespro.ru", "phone": "+70488024088"}
0005432568891	448892	9396 799075	VLADISLAV ISAEV	{"email": "v_isaev.011975@postgrespro.ru", "phone": "+70094394114"}
0005432568892	448892	8250 514890	ZINAIDA KONDRATEVA	{"phone": "+70506516228"}
0005432568893	A1444B	3795 705474	ALENA BARANOVA	{"email": "baranovaa_29121968@postgrespro.ru", "phone": "+70530766306"}
0005432568894	6040B0	1766 441140	ALINA EFREMOVA	{"email": "alina.efremova_081961@postgrespro.ru", "phone": "+70413780060"}
0005432568895	6040B0	3179 439449	NATALYA ALEKSEEVA	{"email": "natalya.alekseeva.08081954@postgrespro.ru", "phone": "+70271522348"}
0005432568896	F27523	4543 213869	VIKTOR FROLOV	{"email": "frolov.viktor16051980@postgrespro.ru", "phone": "+70943991210"}
0005432568897	C33899	3498 036341	EVGENIY POPOV	{"email": "popove_071976@postgrespro.ru", "phone": "+70068457577"}
0005432568898	C33899	8026 516876	ZINAIDA KULIKOVA	{"email": "zinaida-kulikova.15111960@postgrespro.ru", "phone": "+70061155322"}
0005432568899	F9E15B	7351 267517	TATYANA MAKAROVA	{"phone": "+70910164087"}
0005432568900	F9E15B	6740 023028	RUSLAN KOZLOV	{"phone": "+70587785197"}
0005432568901	B80C54	3276 291716	ANNA VLASOVA	{"phone": "+70938899498"}
0005432568902	769825	4602 107509	VYACHESLAV POPOV	{"email": "vyacheslav_popov_111975@postgrespro.ru", "phone": "+70083480058"}
0005432568903	769825	7555 005868	NIKOLAY MIRONOV	{"phone": "+70522451716"}
0005432568904	E1D453	9465 325076	LYUDMILA SERGEEVA	{"email": "sergeeva-lyudmila-121968@postgrespro.ru", "phone": "+70403700734"}
0005432568905	E1D453	9761 385300	ANVAR FILIPPOV	{"phone": "+70026557867"}
0005432568906	822EB9	5581 347330	TATYANA NESTEROVA	{"email": "tatyana.nesterova.091967@postgrespro.ru", "phone": "+70116474100"}
0005432568907	05595B	4691 948044	ANDREY KUZMIN	{"email": "kuzmin.andrey1979@postgrespro.ru", "phone": "+70220351294"}
0005432568908	FFE278	4485 289368	GALINA SOLOVEVA	{"phone": "+70538394583"}
0005432568909	FFE278	4664 057540	ZHANNA SOLOVEVA	{"phone": "+70027481889"}
0005432568910	571F71	6945 798568	YULIYA NIKOLAEVA	{"email": "y-nikolaeva.17081966@postgrespro.ru", "phone": "+70797380556"}
0005432568911	C7BEDF	1398 113745	MARIYA ANDREEVA	{"phone": "+70672065761"}
0005432568912	C7BEDF	3004 247261	OLGA LAZAREVA	{"phone": "+70222580357"}
0005432568913	9714E1	6323 527240	NATALYA ZAKHAROVA	{"email": "zakharova-natalya07121971@postgrespro.ru", "phone": "+70615676853"}
0005432568914	1BF9C7	2478 761079	ELENA POTAPOVA	{"email": "potapova.e.111964@postgrespro.ru", "phone": "+70752804552"}
0005432568915	1BF9C7	2288 758293	ANASTASIYA SERGEEVA	{"email": "sergeeva.a_1973@postgrespro.ru", "phone": "+70120164316"}
0005432568916	3928BE	6849 494329	TATYANA TIKHONOVA	{"email": "tatyana_tikhonova_011972@postgrespro.ru", "phone": "+70247466484"}
0005432568917	3928BE	6344 422149	FARID FEDOROV	{"phone": "+70191394846"}
0005432568918	5416BD	9046 808356	SERGEY POPOV	{"phone": "+70409850704"}
0005432568919	72E98D	4930 339589	ANTON KRASNOV	{"email": "krasnov.anton_041966@postgrespro.ru", "phone": "+70666552589"}
0005432568920	FFC8B5	5403 555435	NADEZHDA KUDRYASHOVA	{"phone": "+70651513230"}
0005432568921	51D41A	6058 819526	ALEKSANDRA KUZNECOVA	{"email": "aleksandrakuznecova.121966@postgrespro.ru", "phone": "+70165630904"}
0005432568922	5C3385	7275 577383	MARIYA MARTYNOVA	{"email": "martynova-m26061975@postgrespro.ru", "phone": "+70027372487"}
0005432568923	935FC5	5197 184586	SERGEY MOROZOV	{"email": "sergey.morozov.1968@postgrespro.ru", "phone": "+70124935412"}
0005432568924	EFDD41	8051 001336	EKATERINA MALYSHEVA	{"phone": "+70275297203"}
0005432568925	655CDC	2447 513662	VASILIY MOROZOV	{"email": "vasiliy.morozov23041983@postgrespro.ru", "phone": "+70942128707"}
0005432568926	F5BB19	9354 075208	SERGEY YAKOVLEV	{"email": "s-yakovlev-1963@postgrespro.ru", "phone": "+70008991218"}
0005432568927	F5BB19	6779 006972	SEMEN ISAEV	{"email": "isaev_semen29031964@postgrespro.ru", "phone": "+70903060301"}
0005432568928	013420	6334 286449	IVAN ANDREEV	{"email": "i-andreev031972@postgrespro.ru", "phone": "+70354397528"}
0005432568929	EBAC4F	7004 382212	VIKTOR DMITRIEV	{"email": "dmitrievv_1971@postgrespro.ru", "phone": "+70704195295"}
0005432568930	EBAC4F	4464 138930	ANDREY KUDRYASHOV	{"phone": "+70509361591"}
0005432568931	E3BFE7	5420 108921	ALEKSANDRA ZAKHAROVA	{"email": "a_zakharova1970@postgrespro.ru", "phone": "+70686535705"}
0005432568932	668C66	7524 745983	LYUDMILA RODIONOVA	{"phone": "+70805536250"}
0005432568933	E75414	6207 292839	ZLATA EFIMOVA	{"email": "efimova-zlata-081968@postgrespro.ru", "phone": "+70186756014"}
0005432568934	E75414	6471 171768	SERGEY PETROV	{"phone": "+70424081504"}
0005432568935	E75414	3239 182518	YULIYA FADEEVA	{"phone": "+70681381036"}
0005432568936	636021	4875 200287	RAFIK BORISOV	{"email": "borisov-rafik-021974@postgrespro.ru", "phone": "+70865684119"}
0005432568937	636021	2326 548565	ALEKSANDR ORLOV	{"phone": "+70174680553"}
0005432568938	4976FA	7855 977302	NIKOLAY ANTONOV	{"email": "antonov.n-121966@postgrespro.ru", "phone": "+70140423185"}
0005432568939	EE4C95	2264 683796	VLADIMIR KRASNOV	{"email": "vladimirkrasnov_021979@postgrespro.ru", "phone": "+70910444227"}
0005432568940	A5E0D1	3856 614914	YAROSLAV OSIPOV	{"phone": "+70548523279"}
0005432568941	A5E0D1	3852 346453	ALEKSANDRA NOVIKOVA	{"email": "novikovaaleksandra-071982@postgrespro.ru", "phone": "+70048219544"}
0005432568942	56A534	3977 817120	SVETLANA KOVALEVA	{"phone": "+70313404953"}
0005432568943	56A534	2302 786205	EVGENIYA IVANOVA	{"email": "ivanova.evgeniya.091974@postgrespro.ru", "phone": "+70554199841"}
0005432568944	1CA158	9175 080688	NIKOLAY KARPOV	{"phone": "+70639488288"}
0005432568945	1CA158	5743 649029	MIKHAIL GERASIMOV	{"phone": "+70382523043"}
0005432568946	1CA158	8187 068251	VLADIMIR IVANOV	{"email": "ivanov-v19011959@postgrespro.ru", "phone": "+70556394171"}
0005432568947	CB705C	0306 055369	LYUDMILA ZAYCEVA	{"email": "zayceva.l111972@postgrespro.ru", "phone": "+70845562697"}
0005432568948	8DE21D	2143 488851	VLADIMIR SHEVCHENKO	{"phone": "+70616112361"}
0005432568949	47C38A	1895 173654	ANNA SERGEEVA	{"email": "sergeevaa-04071969@postgrespro.ru", "phone": "+70714472548"}
0005432568950	C5314E	9624 925482	EVGENIY MELNIKOV	{"email": "evgeniymelnikov.13101967@postgrespro.ru", "phone": "+70327658504"}
0005432568951	930420	3811 506878	ROMAN MAKAROV	{"phone": "+70412550678"}
0005432568952	F6310A	2781 189164	IVAN ANDREEV	{"phone": "+70711287892"}
0005432568953	3807C7	8007 627334	MARINA NAUMOVA	{"email": "naumovamarina_09051964@postgrespro.ru", "phone": "+70641521251"}
0005432568954	6A7B44	5041 032647	ELENA NESTEROVA	{"email": "nesterovae-30071975@postgrespro.ru", "phone": "+70174290943"}
0005432568955	6A7B44	0457 039045	NATALYA MAKAROVA	{"email": "makarovanatalya27071966@postgrespro.ru", "phone": "+70234465607"}
0005432568956	9A9F30	0550 300106	ARSENIY FROLOV	{"email": "a.frolov1970@postgrespro.ru", "phone": "+70792211524"}
0005432568957	470DB8	5540 531993	DAVID ZHUKOV	{"email": "david.zhukov17011962@postgrespro.ru", "phone": "+70482667301"}
0005432568958	470DB8	5716 512880	EVGENIY KAZAKOV	{"phone": "+70453328772"}
0005432568959	470DB8	5965 796264	OLGA ORLOVA	{"phone": "+70207669358"}
0005432568960	063AE6	8030 354323	DARYA NIKOLAEVA	{"phone": "+70368859807"}
0005432568961	063AE6	1477 604331	VLADIMIR PAVLOV	{"email": "v-pavlov-1976@postgrespro.ru", "phone": "+70032287410"}
0005432568962	954267	2270 881699	PELAGEYA KUZNECOVA	{"email": "kuznecovapelageya111969@postgrespro.ru", "phone": "+70817493132"}
0005432568963	716D96	5851 524710	ALEKSEY IVANOV	{"phone": "+70788445951"}
0005432568964	716D96	1162 924400	SVETLANA ORLOVA	{"email": "svetlana_orlova_06031968@postgrespro.ru", "phone": "+70176627261"}
0005432568965	3E029D	6054 421479	NADEZHDA KONDRATEVA	{"phone": "+70892746948"}
0005432568966	4E3E1B	4074 850997	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva_1963@postgrespro.ru", "phone": "+70181895050"}
0005432568967	3CCC3F	2195 120902	ANASTASIYA NESTEROVA	{"phone": "+70001359652"}
0005432568968	102178	5417 210866	SERGEY DENISOV	{"phone": "+70744658062"}
0005432568969	1C3C67	9908 157709	ROMAN GAVRILOV	{"email": "roman.gavrilov.02061979@postgrespro.ru", "phone": "+70855134694"}
0005432568970	04E8F4	2566 654455	ALEKSANDRA SOLOVEVA	{"phone": "+70815052555"}
0005432568971	04E8F4	0052 723201	ARTEM NIKITIN	{"email": "nikitin_artem-27081966@postgrespro.ru", "phone": "+70170116043"}
0005432568972	D8B68C	1380 803149	LYUBOV KONDRATEVA	{"email": "l-kondrateva_1981@postgrespro.ru", "phone": "+70553956197"}
0005432568973	D8B68C	5784 277997	OLEG SERGEEV	{"email": "sergeevoleg_03121966@postgrespro.ru", "phone": "+70275082814"}
0005432568974	DAB0A0	7074 847036	ALEKSANDR KULIKOV	{"phone": "+70705428693"}
0005432568975	DAB0A0	1870 900739	EVGENIY MAKAROV	{"phone": "+70230516718"}
0005432568976	DAB0A0	9848 933320	OLEG NAZAROV	{"email": "oleg-nazarov101974@postgrespro.ru", "phone": "+70121040385"}
0005432568977	54062C	2335 315919	LYUDMILA EFREMOVA	{"email": "lyudmila-efremova041971@postgrespro.ru", "phone": "+70359322011"}
0005432568978	54062C	4685 060601	VLADIMIR MIRONOV	{"email": "mironov-v-1978@postgrespro.ru", "phone": "+70079214730"}
0005432568979	687E1A	4717 414651	NINA TIMOFEEVA	{"phone": "+70946842393"}
0005432568980	B75F74	9190 233315	GALINA ILINA	{"phone": "+70175551681"}
0005432568981	B75F74	7783 340165	ANDREY FILIPPOV	{"email": "andrey_filippov05101971@postgrespro.ru", "phone": "+70530171458"}
0005432568982	742862	7988 278796	YURIY ISAEV	{"phone": "+70825593824"}
0005432568983	742862	7331 361095	VLADIMIR ISAEV	{"email": "isaevv-021965@postgrespro.ru", "phone": "+70025055295"}
0005432568984	742862	2990 651464	TATYANA ZAKHAROVA	{"email": "zakharovat.27081972@postgrespro.ru", "phone": "+70487129589"}
0005432568985	742862	9409 116656	ROMAN ROMANOV	{"email": "romanov-roman.051973@postgrespro.ru", "phone": "+70079189088"}
0005432568986	86C73B	4140 361333	YULIYA BORISOVA	{"phone": "+70068598233"}
0005432568987	E0B084	3661 334117	VLADIMIR PAVLOV	{"email": "vpavlov.061970@postgrespro.ru", "phone": "+70767934232"}
0005432568988	CF6A23	6083 847797	ANASTASIYA ZHURAVLEVA	{"phone": "+70146287356"}
0005432568989	CF6A23	9927 082355	TATYANA DANILOVA	{"email": "danilova-t-1976@postgrespro.ru", "phone": "+70279410578"}
0005432568990	363EC6	2501 664671	TATYANA ZHURAVLEVA	{"email": "zhuravleva_tatyana_1955@postgrespro.ru", "phone": "+70249977456"}
0005432568991	A0C44A	4820 130991	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir011970@postgrespro.ru", "phone": "+70130450726"}
0005432568992	B23685	6502 826529	DARYA SERGEEVA	{"email": "sergeeva_d_28091966@postgrespro.ru", "phone": "+70575003187"}
0005432568993	26BA1D	1785 742940	DMITRIY IVANOV	{"phone": "+70827465633"}
0005432568994	E2B77E	3475 044939	TAISIYA VOLKOVA	{"phone": "+70547401045"}
0005432568995	FE8EB5	8218 323013	EKATERINA MARTYNOVA	{"email": "martynova_ekaterina-061978@postgrespro.ru", "phone": "+70528905000"}
0005432568996	789021	0672 878152	ANNA MIKHAYLOVA	{"phone": "+70589411032"}
0005432568997	FC8BBF	8456 863931	NATALIYA KOROLEVA	{"email": "koroleva.n-121967@postgrespro.ru", "phone": "+70676005252"}
0005432568998	C4B49F	8439 678079	OLGA MATVEEVA	{"email": "matveeva_o.051976@postgrespro.ru", "phone": "+70031215076"}
0005432568999	EBDB7D	3422 975528	YURIY NIKOLAEV	{"email": "y-nikolaev29051969@postgrespro.ru", "phone": "+70121530606"}
0005432569000	718019	2329 417770	ELENA POTAPOVA	{"phone": "+70579402533"}
0005432569001	6982F1	5991 717199	ANNA TITOVA	{"email": "titova.anna_06061973@postgrespro.ru", "phone": "+70945323089"}
0005432569002	43F9FD	5513 422085	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova-1985@postgrespro.ru", "phone": "+70311015119"}
0005432569003	3042E3	1383 659307	LIDIYA GORBUNOVA	{"email": "lidiya_gorbunova-1967@postgrespro.ru", "phone": "+70659116719"}
0005432569004	DAD3E8	0512 678722	ELENA KUZNECOVA	{"phone": "+70565294368"}
0005432569005	DAD3E8	7117 554268	IRINA CHERNOVA	{"phone": "+70895713841"}
0005432569006	DAD3E8	2506 985051	VIKTOR DAVYDOV	{"email": "viktor-davydov1967@postgrespro.ru", "phone": "+70848471809"}
0005432569007	BC3024	3276 826748	TATYANA STEPANOVA	{"email": "tatyana-stepanova_1975@postgrespro.ru", "phone": "+70252087805"}
0005432569008	D35C20	4315 748609	MARIYA SERGEEVA	{"phone": "+70316163209"}
0005432569009	D35C20	8671 185878	SVETLANA PETROVA	{"phone": "+70518080292"}
0005432569010	D35C20	8700 618435	NADEZHDA ZAKHAROVA	{"email": "n-zakharova_02051967@postgrespro.ru", "phone": "+70136622141"}
0005432569011	7A269A	3535 966628	ANNA MIKHAYLOVA	{"email": "annamikhaylova061968@postgrespro.ru", "phone": "+70067317847"}
0005432569012	299464	1997 797233	LYUBOV BELOVA	{"phone": "+70924974347"}
0005432569013	299464	3632 320611	MARIYA TROFIMOVA	{"phone": "+70312002542"}
0005432569014	5F36BF	7476 095659	SVETLANA NAZAROVA	{"phone": "+70181519461"}
0005432569015	5E2BF4	1983 981419	TATYANA SOROKINA	{"email": "sorokina-t011969@postgrespro.ru", "phone": "+70900761498"}
0005432569016	5921CD	9098 244178	NATALIYA LAZAREVA	{"email": "lazarevanataliya15111972@postgrespro.ru", "phone": "+70715110063"}
0005432569017	07D35D	6621 040744	SOFYA ZAYCEVA	{"phone": "+70849994601"}
0005432569018	1DA91A	3861 694933	LYUDMILA STEPANOVA	{"email": "l.stepanova22061981@postgrespro.ru", "phone": "+70187445327"}
0005432569019	958FA2	5615 251505	EKATERINA KUZMINA	{"phone": "+70250907920"}
0005432569020	4F4D24	5071 828296	MIKHAIL SAVELEV	{"phone": "+70802589352"}
0005432569021	ABC1A5	0989 925097	ANDREY MOROZOV	{"email": "morozov-andrey.1977@postgrespro.ru", "phone": "+70201903454"}
0005432569022	ABC1A5	1814 704386	LYUDMILA KUZNECOVA	{"email": "l-kuznecova_15121980@postgrespro.ru", "phone": "+70151681790"}
0005432569023	5ADFA7	8092 154339	LARISA NOVIKOVA	{"phone": "+70054352092"}
0005432569024	F2D2B8	5807 873165	ELENA MAKAROVA	{"phone": "+70479112987"}
0005432569025	CDAA73	2379 109997	ALEKSEY ANDREEV	{"email": "andreev.a_1974@postgrespro.ru", "phone": "+70240892023"}
0005432569026	5B3F0C	5694 968056	NINA KOVALEVA	{"email": "kovaleva-nina-04061973@postgrespro.ru", "phone": "+70800831551"}
0005432569027	5B3F0C	3638 308642	ALEFTINA ISAEVA	{"email": "aleftinaisaeva.1964@postgrespro.ru", "phone": "+70072721777"}
0005432569028	57955E	5677 483164	DMITRIY CHERNOV	{"email": "chernovdmitriy.25111957@postgrespro.ru", "phone": "+70914188862"}
0005432569029	57955E	1340 171166	YURIY MAKAROV	{"email": "makarovy_22041979@postgrespro.ru", "phone": "+70805542971"}
0005432569030	2FA346	8863 956153	OLEG MELNIKOV	{"email": "olegmelnikov_011978@postgrespro.ru", "phone": "+70382456530"}
0005432569031	2FA346	2826 807245	ANTON ANDREEV	{"email": "a-andreev1963@postgrespro.ru", "phone": "+70679741893"}
0005432569032	D63E8A	7832 747508	IGOR ZAKHAROV	{"phone": "+70012097575"}
0005432569033	1A64DA	2131 558025	VASILIY MOISEEV	{"email": "moiseevvasiliy091975@postgrespro.ru", "phone": "+70820819837"}
0005432569034	1A64DA	9610 091476	ALEKSANDR ZAYCEV	{"email": "azaycev-16121967@postgrespro.ru", "phone": "+70317454280"}
0005432569035	35E408	7341 976448	LIDIYA NESTEROVA	{"email": "l-nesterova.1982@postgrespro.ru", "phone": "+70225293524"}
0005432569036	BCD308	8484 128545	LYUDMILA SMIRNOVA	{"phone": "+70055199491"}
0005432569037	FB35F6	5152 887261	SERGEY ISAEV	{"phone": "+70740861773"}
0005432569038	C12BE3	6238 697812	IVAN BARANOV	{"email": "ivan-baranov1972@postgrespro.ru", "phone": "+70640003772"}
0005432569039	AEC0A4	9583 000753	DMITRIY NOVIKOV	{"email": "d_novikov101969@postgrespro.ru", "phone": "+70125640931"}
0005432569040	256BFD	7595 453364	VLADIMIR SEMENOV	{"phone": "+70824490938"}
0005432569041	079846	2875 988168	IGOR MAKAROV	{"phone": "+70170781987"}
0005432569042	079846	8590 094712	NATALYA POTAPOVA	{"email": "natalyapotapova_23081990@postgrespro.ru", "phone": "+70629242014"}
0005432569043	CBE514	0243 241701	ANASTASIYA NAZAROVA	{"phone": "+70367399665"}
0005432569044	FD1778	8128 624563	OLGA TITOVA	{"email": "olgatitova18091977@postgrespro.ru", "phone": "+70510707805"}
0005432569045	0DA61E	2818 809658	ANNA PAVLOVA	{"phone": "+70287350336"}
0005432569046	1103DF	0453 915958	VLADIMIR AFANASEV	{"email": "afanasev-v1974@postgrespro.ru", "phone": "+70901582255"}
0005432569047	1103DF	8875 836047	VLADIMIR MIRONOV	{"phone": "+70979774420"}
0005432569048	02DABA	2227 631756	SVETLANA LUKYANOVA	{"email": "lukyanova-svetlana_29091980@postgrespro.ru", "phone": "+70900550309"}
0005432569049	AD70A0	0301 411959	TATYANA GORBUNOVA	{"phone": "+70647169411"}
0005432569050	AD70A0	3389 792661	TAMARA DANILOVA	{"email": "t-danilova-14031987@postgrespro.ru", "phone": "+70719063062"}
0005432569051	59150F	2433 489559	MIKHAIL FROLOV	{"phone": "+70310939907"}
0005432569052	7C3AF7	9291 677093	ALEKSEY ALEKSEEV	{"phone": "+70220909959"}
0005432569053	D35D78	8891 584581	EKATERINA MARTYNOVA	{"phone": "+70909678954"}
0005432569054	424350	6211 696112	DANILA ZAYCEV	{"phone": "+70453995640"}
0005432569055	7A70DB	1467 494513	ANASTASIYA MASLOVA	{"email": "maslova.a02031959@postgrespro.ru", "phone": "+70566221661"}
0005432569056	756547	3647 587031	NATALYA ORLOVA	{"email": "natalya.orlova.20121967@postgrespro.ru", "phone": "+70779938384"}
0005432569057	756547	4504 484791	PETR KUZNECOV	{"phone": "+70182993930"}
0005432569058	633EA3	1018 827958	MARINA ABRAMOVA	{"email": "m_abramova_081981@postgrespro.ru", "phone": "+70836233177"}
0005432569059	633EA3	5550 791568	SVETLANA ZOTOVA	{"email": "s.zotova071978@postgrespro.ru", "phone": "+70300134740"}
0005432569060	FD0E23	0006 603909	IVAN KULIKOV	{"email": "kulikovivan.29071965@postgrespro.ru", "phone": "+70694000663"}
0005432569061	FD0E23	4830 558922	MAKSIM MELNIKOV	{"phone": "+70006592778"}
0005432569062	FD0E23	2983 322532	NATALYA BELYAEVA	{"phone": "+70455636452"}
0005432569063	D9F191	6144 329195	GALINA NOVIKOVA	{"email": "galinanovikova1975@postgrespro.ru", "phone": "+70653401531"}
0005432569064	D9F191	0363 444959	ARTEM ZAKHAROV	{"email": "artem.zakharov23051969@postgrespro.ru", "phone": "+70025596053"}
0005432569065	30B4F0	9840 476733	DARYA MIKHAYLOVA	{"email": "mikhaylova.d_23031961@postgrespro.ru", "phone": "+70869053583"}
0005432569066	DB4124	3689 238042	TAMARA NIKOLAEVA	{"phone": "+70203032610"}
0005432569067	B7E423	8189 111483	DMITRIY KOZLOV	{"email": "kozlov-dmitriy061983@postgrespro.ru", "phone": "+70874756508"}
0005432569068	839092	3401 773131	IRINA VOLKOVA	{"email": "i.volkova_30061974@postgrespro.ru", "phone": "+70393680624"}
0005432569069	B2D775	2994 180332	MAKSIM ZAKHAROV	{"email": "m_zakharov.1978@postgrespro.ru", "phone": "+70362190240"}
0005432569070	B2D775	2189 196714	OLGA ILINA	{"phone": "+70541685844"}
0005432569071	337A47	1960 882402	ANATOLIY VASILEV	{"phone": "+70059822680"}
0005432569072	207E2A	8617 257325	VLADIMIR GERASIMOV	{"phone": "+70160498321"}
0005432569073	EADB11	3096 516526	ANDREY SHEVCHENKO	{"email": "shevchenko.andrey-011962@postgrespro.ru", "phone": "+70291108755"}
0005432569074	049F24	5871 966875	EKATERINA TIKHONOVA	{"phone": "+70449148084"}
0005432569075	0CEDBD	7040 366638	NIKOLAY DMITRIEV	{"email": "dmitriev.nikolay.29111973@postgrespro.ru", "phone": "+70510373965"}
0005432569076	D6476A	7696 107173	YURIY GAVRILOV	{"email": "gavrilov_y1968@postgrespro.ru", "phone": "+70007778511"}
0005432569077	D6476A	2486 746426	ANDREY KISELEV	{"email": "kiselev_a-1970@postgrespro.ru", "phone": "+70040777876"}
0005432569078	D6476A	8293 545149	ROMAN SCHERBAKOV	{"email": "roman-scherbakov-23081969@postgrespro.ru", "phone": "+70771884759"}
0005432569079	F01E7C	7929 498074	RAMILYA KUZMINA	{"phone": "+70240559795"}
0005432569080	F01E7C	4830 668843	LYUBOV PETROVA	{"email": "lyubovpetrova-1980@postgrespro.ru", "phone": "+70146354742"}
0005432569081	3F42A8	9224 230101	KONSTANTIN SEMENOV	{"email": "semenovkonstantin-021974@postgrespro.ru", "phone": "+70195083911"}
0005432569082	80F5DF	6494 712851	NATALYA KOMAROVA	{"phone": "+70229144447"}
0005432569083	7B94D8	0821 726657	NINA ALEKSEEVA	{"email": "alekseeva-n_1977@postgrespro.ru", "phone": "+70017699159"}
0005432569084	7B94D8	6787 524811	DMITRIY POPOV	{"phone": "+70519299441"}
0005432569085	A2097D	1094 731281	VLADISLAV FROLOV	{"email": "v_frolov05111969@postgrespro.ru", "phone": "+70112040345"}
0005432569086	A2097D	6892 696135	MADINA KOLESNIKOVA	{"phone": "+70856432192"}
0005432569087	1995D0	9060 211294	ALEKSANDRA FROLOVA	{"phone": "+70338655109"}
0005432569088	7B4743	8759 414816	IRINA ARKHIPOVA	{"phone": "+70465343763"}
0005432569089	2331D1	9393 402967	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr-15091972@postgrespro.ru", "phone": "+70718356935"}
0005432569090	2331D1	2486 422427	YULIYA POPOVA	{"email": "popova-yuliya-1976@postgrespro.ru", "phone": "+70179223502"}
0005432569091	55E945	5473 820977	ALEKSANDR MOROZOV	{"phone": "+70887034324"}
0005432569092	F360EF	6829 587712	INNA TARASOVA	{"phone": "+70660002408"}
0005432569093	F360EF	7180 476428	ALEKSANDR GUSEV	{"phone": "+70742991860"}
0005432569094	63097F	8144 596611	IVAN ANDREEV	{"email": "andreev.i-14111980@postgrespro.ru", "phone": "+70585176033"}
0005432569095	63097F	3392 865515	KSENIYA NESTEROVA	{"email": "kseniya.nesterova-111961@postgrespro.ru", "phone": "+70302874438"}
0005432569096	F568BD	9707 827143	LARISA ILINA	{"phone": "+70018196279"}
0005432569097	F568BD	9671 502312	MARIYA KONOVALOVA	{"email": "mariya_konovalova121968@postgrespro.ru", "phone": "+70440831836"}
0005432569222	F3CED3	6962 006742	GALINA BOGDANOVA	{"phone": "+70874591788"}
0005432569098	F01D0E	4729 652733	ANASTASIYA KRASNOVA	{"email": "krasnova-anastasiya011973@postgrespro.ru", "phone": "+70378826587"}
0005432569099	106111	6886 420824	MARINA MARTYNOVA	{"email": "marinamartynova.01051952@postgrespro.ru", "phone": "+70152999302"}
0005432569100	106111	4838 222768	NINA EGOROVA	{"phone": "+70109223059"}
0005432569101	106111	2489 306037	NIKOLAY SOROKIN	{"email": "sorokinnikolay_1976@postgrespro.ru", "phone": "+70235939101"}
0005432569102	4F330C	2456 889548	ANDREY EGOROV	{"email": "egorov_andrey-19111973@postgrespro.ru", "phone": "+70666080879"}
0005432569103	DDAEEC	5700 574819	ALEKSANDR VLASOV	{"phone": "+70118721292"}
0005432569104	AFA5B9	9776 964351	IGOR KULIKOV	{"phone": "+70351044010"}
0005432569105	D7DF00	8298 696995	OLGA TROFIMOVA	{"phone": "+70980845410"}
0005432569106	83746E	8660 052729	VIKTORIYA IVANOVA	{"email": "ivanova.v.1980@postgrespro.ru", "phone": "+70483237289"}
0005432569107	83746E	3784 075514	ANNA YAKOVLEVA	{"email": "a-yakovleva_111976@postgrespro.ru", "phone": "+70079424247"}
0005432569108	30C5FC	8083 741460	NIKOLAY NIKOLAEV	{"phone": "+70845351153"}
0005432569109	30C5FC	4129 371167	GALINA ANDREEVA	{"phone": "+70317819425"}
0005432569110	30C5FC	4259 796418	VERA YAKOVLEVA	{"email": "vera.yakovleva_05101977@postgrespro.ru", "phone": "+70167683760"}
0005432569111	0F5477	9353 407108	EVGENIY VASILEV	{"email": "evgeniy.vasilev111978@postgrespro.ru", "phone": "+70170852763"}
0005432569112	0F5477	1152 488934	AZAT TIKHONOV	{"email": "a-tikhonov_091961@postgrespro.ru", "phone": "+70061909148"}
0005432569113	3AF99E	8582 813935	ANASTASIYA ILINA	{"phone": "+70113474784"}
0005432569114	86A425	0998 552182	IRINA EFIMOVA	{"email": "efimova-irina16121964@postgrespro.ru", "phone": "+70202242766"}
0005432569115	86A425	6120 775089	NINA FOMINA	{"email": "fomina_n18051971@postgrespro.ru", "phone": "+70740509764"}
0005432569116	86A425	4120 177258	RAFIK FOMIN	{"email": "rafik_fomin061978@postgrespro.ru", "phone": "+70072286998"}
0005432569117	FC5DD0	0032 431643	ELIZAVETA KUZNECOVA	{"email": "elizaveta-kuznecova-041984@postgrespro.ru", "phone": "+70819236549"}
0005432569118	1E6D0F	3886 521869	PAVEL KOROLEV	{"phone": "+70103638368"}
0005432569119	1E6D0F	1719 238111	GALINA ROMANOVA	{"phone": "+70755424018"}
0005432569120	BEB38F	9841 926609	VADIM SOKOLOV	{"phone": "+70345939454"}
0005432569121	BEB38F	8643 556067	LIDIYA ANTONOVA	{"email": "lidiya-antonova1975@postgrespro.ru", "phone": "+70164324392"}
0005432569122	432A53	4654 245670	GLEB OSIPOV	{"email": "g_osipov25061971@postgrespro.ru", "phone": "+70601684966"}
0005432569123	2BB260	0944 091769	VLADIMIR BORISOV	{"email": "vladimirborisov_1971@postgrespro.ru", "phone": "+70229356561"}
0005432569124	2BB260	3091 954635	NADEZHDA LUKYANOVA	{"email": "nadezhdalukyanova-29041961@postgrespro.ru", "phone": "+70480508325"}
0005432569181	5056ED	6348 244225	SVETLANA MOROZOVA	{"phone": "+70898999952"}
0005432569125	66B5C8	9600 944543	LILIYA KONDRATEVA	{"email": "l.kondrateva24081957@postgrespro.ru", "phone": "+70853495838"}
0005432569126	F5EA71	7277 763912	ELENA NIKITINA	{"phone": "+70454209312"}
0005432569127	F5EA71	1206 321583	ELENA VASILEVA	{"phone": "+70133021872"}
0005432569128	FE8FC2	1095 153899	DANIIL BONDARENKO	{"phone": "+70215569499"}
0005432569129	F17331	3569 860881	GALINA KUZNECOVA	{"email": "galinakuznecova.1976@postgrespro.ru", "phone": "+70130959958"}
0005432569130	F17331	6443 292526	ANTONINA OSIPOVA	{"email": "osipovaa_051970@postgrespro.ru", "phone": "+70513591794"}
0005432569131	F17331	5827 023455	ALEKSANDR MOROZOV	{"phone": "+70796915346"}
0005432569132	570409	6902 977426	YURIY FILIPPOV	{"email": "yuriy_filippov-01081968@postgrespro.ru", "phone": "+70339875115"}
0005432569133	F5866E	9635 578282	RUSLAN ZHURAVLEV	{"email": "zhuravlev-ruslan.031980@postgrespro.ru", "phone": "+70647176392"}
0005432569134	F5866E	0750 534502	ALEKSANDR BARANOV	{"email": "baranovaleksandr_11041963@postgrespro.ru", "phone": "+70842706234"}
0005432569135	F5866E	4258 378631	ANASTASIYA BORISOVA	{"phone": "+70410432691"}
0005432569136	505D04	9022 903442	YURIY GORBUNOV	{"email": "yuriy-gorbunov.23091971@postgrespro.ru", "phone": "+70395479380"}
0005432569137	BC11B1	1555 124488	ALEKSANDR SERGEEV	{"phone": "+70835843760"}
0005432569138	BC2840	8626 241605	NIKOLAY DMITRIEV	{"phone": "+70956428782"}
0005432569139	BC2840	1985 966476	ALEKSANDR VLASOV	{"email": "aleksandrvlasov.011982@postgrespro.ru", "phone": "+70686522497"}
0005432569140	6B25C7	4901 356251	GENNADIY GERASIMOV	{"email": "gerasimov.g_111958@postgrespro.ru", "phone": "+70432420087"}
0005432569141	6B25C7	1542 360191	OLGA MARTYNOVA	{"phone": "+70700318422"}
0005432569142	49D16D	4528 369289	SERGEY VOROBEV	{"email": "s_vorobev041965@postgrespro.ru", "phone": "+70167644380"}
0005432569143	3A385E	1892 693326	NADEZHDA ROMANOVA	{"phone": "+70641284683"}
0005432569144	A2B251	7641 475683	EVGENIY SEMENOV	{"email": "evgeniy.semenov-1971@postgrespro.ru", "phone": "+70646232039"}
0005432569145	A2B251	8543 101149	ARMEN ANDREEV	{"email": "a-andreev-111958@postgrespro.ru", "phone": "+70618877896"}
0005432569146	1E86DF	2609 354785	ANATOLIY FROLOV	{"phone": "+70590444438"}
0005432569147	A45F3A	9615 051176	SAMIRA NIKOLAEVA	{"email": "snikolaeva_021970@postgrespro.ru", "phone": "+70174597784"}
0005432569148	A45F3A	9274 779703	EGOR ZAKHAROV	{"phone": "+70945308669"}
0005432569149	8EC5B9	0820 660389	SERGEY VOLKOV	{"email": "volkovs_1973@postgrespro.ru", "phone": "+70495761756"}
0005432569150	A1D464	1950 832602	SERGEY RODIONOV	{"email": "sergey_rodionov021976@postgrespro.ru", "phone": "+70325556220"}
0005432569151	A1D464	2739 490716	IRINA ALEKSEEVA	{"email": "alekseeva.irina.091973@postgrespro.ru", "phone": "+70917361128"}
0005432569152	9C7E1A	7128 156524	KONSTANTIN PETROV	{"phone": "+70473362084"}
0005432569153	41E7E3	6265 138894	ALISA TARASOVA	{"phone": "+70809793843"}
0005432569154	41E7E3	0708 484843	ANNA DENISOVA	{"email": "denisova_anna.1973@postgrespro.ru", "phone": "+70996265789"}
0005432569155	08F983	0371 647657	VLADIMIR SMIRNOV	{"phone": "+70352712323"}
0005432569157	6ED2D1	4039 974563	ROMAN MIRONOV	{"email": "mironov-r-1970@postgrespro.ru", "phone": "+70313684919"}
0005432569158	6ED2D1	3433 016724	SERGEY ISAEV	{"email": "s.isaev.14061980@postgrespro.ru", "phone": "+70421084496"}
0005432569159	7893A1	7247 222125	NINA SMIRNOVA	{"email": "smirnovanina061978@postgrespro.ru", "phone": "+70788611977"}
0005432569160	C14291	4423 881305	ANTON YAKOVLEV	{"phone": "+70835051923"}
0005432569161	9B2D81	3183 599197	ALEKSANDR PETROV	{"phone": "+70180277942"}
0005432569162	9B2D81	0450 491275	NATALYA ALEKSEEVA	{"email": "alekseeva_n111971@postgrespro.ru", "phone": "+70124924184"}
0005432569163	A43772	6454 354903	YULIYA KAZAKOVA	{"phone": "+70414850381"}
0005432569164	4F956C	5209 281916	OLGA KUDRYASHOVA	{"phone": "+70939114768"}
0005432569165	4F956C	3804 232751	ELIZAVETA PETROVA	{"phone": "+70711418645"}
0005432569166	E04ED3	9395 469270	VLADIMIR ROMANOV	{"email": "vromanov_28061975@postgrespro.ru", "phone": "+70044374232"}
0005432569167	919C9C	4345 442482	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrovaanastasiya_081959@postgrespro.ru", "phone": "+70546183367"}
0005432569168	74CB14	0200 545752	VERA ZAYCEVA	{"email": "v_zayceva011980@postgrespro.ru", "phone": "+70603500635"}
0005432569169	74CB14	0327 541962	LYUDMILA FILIPPOVA	{"phone": "+70718763401"}
0005432569170	5BB448	0173 838420	OKSANA TIKHONOVA	{"email": "o-tikhonova_07091979@postgrespro.ru", "phone": "+70488217181"}
0005432569171	2E5991	9980 000401	RUSLAN IVANOV	{"email": "ivanov-ruslan111986@postgrespro.ru", "phone": "+70720386799"}
0005432569172	26FCDD	9963 079454	DANILA MATVEEV	{"email": "d.matveev-1969@postgrespro.ru", "phone": "+70065735662"}
0005432569173	D59D97	4255 415525	NINA VOROBEVA	{"phone": "+70411822867"}
0005432569174	D43965	8764 024216	VERA NIKOLAEVA	{"phone": "+70454670675"}
0005432569175	D43965	9726 236148	MARIYA TARASOVA	{"email": "tarasova.m.12121960@postgrespro.ru", "phone": "+70968250488"}
0005432569176	749454	8615 886188	TATYANA BORISOVA	{"phone": "+70523261571"}
0005432569177	749454	7972 850550	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila.06071967@postgrespro.ru", "phone": "+70545082957"}
0005432569178	802811	1162 777562	SERGEY KULIKOV	{"email": "kulikov-s_1965@postgrespro.ru", "phone": "+70729812747"}
0005432569179	802811	3805 519319	SERGEY ZAYCEV	{"phone": "+70416796491"}
0005432569180	EE51CB	6396 512505	ALEKSANDR POPOV	{"phone": "+70532858330"}
0005432569182	6A22DB	0803 966224	POLINA MELNIKOVA	{"phone": "+70985264788"}
0005432569183	1AFCA8	4763 523138	ROMAN SAVELEV	{"email": "savelev_roman-08101969@postgrespro.ru", "phone": "+70887119913"}
0005432569184	1AFCA8	3799 280873	MATVEY GRIGOREV	{"phone": "+70976778055"}
0005432569185	B6FE12	7335 645922	ALBINA SIDOROVA	{"phone": "+70450368922"}
0005432569186	B6FE12	0956 039693	IRINA TROFIMOVA	{"phone": "+70383574729"}
0005432569187	45BD2E	6353 117781	EVGENIY KUZMIN	{"phone": "+70853480211"}
0005432569188	8E6039	4495 726688	NIKITA EGOROV	{"phone": "+70809428617"}
0005432569189	8B8363	5937 200390	LYUDMILA SIDOROVA	{"phone": "+70416682129"}
0005432569190	A0C202	9192 395225	VALENTINA CHERNOVA	{"phone": "+70756155076"}
0005432569191	027C87	2040 334757	YULIYA ALEKSANDROVA	{"email": "y-aleksandrova_1976@postgrespro.ru", "phone": "+70881931328"}
0005432569192	A850FA	3139 964048	OKSANA ZHUKOVA	{"email": "o.zhukova_07121970@postgrespro.ru", "phone": "+70894272661"}
0005432569193	A850FA	0018 636232	GALINA SEMENOVA	{"phone": "+70435047622"}
0005432569194	3A8BCF	8938 212986	VITALIY BORISOV	{"phone": "+70943727251"}
0005432569195	4A6224	2164 078408	ANNA TIKHONOVA	{"phone": "+70953151010"}
0005432569196	A9369F	3178 816992	NADEZHDA NIKITINA	{"phone": "+70974489156"}
0005432569197	A9369F	1611 932077	NADEZHDA KOZLOVA	{"phone": "+70033718738"}
0005432569198	A9369F	0786 740242	IRINA ANDREEVA	{"phone": "+70526269521"}
0005432569199	FCC974	2745 954190	ANATOLIY ZAKHAROV	{"phone": "+70633819698"}
0005432569200	2DE75D	2984 711692	RENAT KUZNECOV	{"email": "renat_kuznecov-08091967@postgrespro.ru", "phone": "+70550657008"}
0005432569201	FFEB1E	4294 463249	POLINA ERMAKOVA	{"email": "ermakova-polina.12101975@postgrespro.ru", "phone": "+70630989022"}
0005432569202	CEFF67	0346 473892	VALERIYA AFANASEVA	{"email": "v_afanaseva1968@postgrespro.ru", "phone": "+70474150488"}
0005432569203	CEFF67	6724 286986	EDUARD ROMANOV	{"phone": "+70857087909"}
0005432569204	DE2A00	8812 703187	BORIS ZHUKOV	{"phone": "+70292872634"}
0005432569205	D69CE2	3780 410598	ARTEM STEPANOV	{"phone": "+70114177753"}
0005432569206	D78C67	0026 083744	ALEKSANDR MAKSIMOV	{"phone": "+70418075407"}
0005432569207	8EF86A	0805 279760	VYACHESLAV DAVYDOV	{"phone": "+70871830307"}
0005432569208	326B93	6265 452458	ALEKSANDR KISELEV	{"phone": "+70042910850"}
0005432569209	326B93	7853 260616	POLINA BORISOVA	{"phone": "+70161459065"}
0005432569210	4CAC5A	9383 863078	OLGA SMIRNOVA	{"phone": "+70787411916"}
0005432569211	A4E2EB	4402 260191	SERGEY ANDREEV	{"email": "sandreev111969@postgrespro.ru", "phone": "+70099547712"}
0005432569212	A4E2EB	1298 993662	DMITRIY ZHUKOV	{"email": "zhukovd071975@postgrespro.ru", "phone": "+70664721489"}
0005432569213	6F3954	3137 569039	SVETLANA KOROLEVA	{"email": "koroleva-s_011968@postgrespro.ru", "phone": "+70127876695"}
0005432569214	F63789	7434 903298	VASILIY ABRAMOV	{"phone": "+70779407198"}
0005432569215	77495A	2853 211641	ALEKSANDR ANDREEV	{"phone": "+70829275118"}
0005432569216	77495A	7040 025278	TATYANA PETROVA	{"email": "petrova-tatyana25011973@postgrespro.ru", "phone": "+70453723454"}
0005432569217	21076A	1930 233133	SVETLANA KARPOVA	{"email": "s.karpova051970@postgrespro.ru", "phone": "+70495961059"}
0005432569218	21076A	6322 701036	ELENA SOKOLOVA	{"email": "sokolova_elena_1974@postgrespro.ru", "phone": "+70495832573"}
0005432569219	80FEE3	1355 014472	RAFAEL ALEKSEEV	{"phone": "+70825266951"}
0005432569220	8E00AB	0269 561591	KSENIYA VASILEVA	{"phone": "+70441523204"}
0005432569223	8DA6C8	8948 512292	ALEKSEY NIKOLAEV	{"phone": "+70481752522"}
0005432569224	EAA888	8793 873964	EVGENIY ANTONOV	{"email": "antonov_e-1963@postgrespro.ru", "phone": "+70547402131"}
0005432569225	EAA888	1573 093012	EVGENIYA SOKOLOVA	{"email": "sokolova.e-031970@postgrespro.ru", "phone": "+70486489629"}
0005432569226	C22840	0025 528667	TAISIYA ALEKSANDROVA	{"email": "t_aleksandrova011972@postgrespro.ru", "phone": "+70646338174"}
0005432569227	C22840	8575 981043	TATYANA MOISEEVA	{"email": "t_moiseeva.1974@postgrespro.ru", "phone": "+70824681353"}
0005432569228	C22840	8153 661901	NINA NESTEROVA	{"email": "nesterova-n.041979@postgrespro.ru", "phone": "+70651162877"}
0005432569229	CE11A0	1696 454564	NADEZHDA BORISOVA	{"email": "n-borisova1965@postgrespro.ru", "phone": "+70592471775"}
0005432569230	8E211D	6835 586370	ROMAN SERGEEV	{"email": "r_sergeev_011972@postgrespro.ru", "phone": "+70778411858"}
0005432569231	8E211D	7575 243175	VALERIYA TARASOVA	{"email": "tarasova_valeriya_29081969@postgrespro.ru", "phone": "+70077147209"}
0005432569232	54F3BC	7627 413801	LIDIYA TIKHONOVA	{"email": "l.tikhonova-1979@postgrespro.ru", "phone": "+70522159158"}
0005432569233	54F3BC	3586 849392	ANDREY SOKOLOV	{"email": "asokolov1966@postgrespro.ru", "phone": "+70755326877"}
0005432569234	C5D883	9095 862685	ZAKHAR KUZMIN	{"phone": "+70095529975"}
0005432569235	8A03C6	8958 783315	YURIY FILIPPOV	{"email": "filippov-y1973@postgrespro.ru", "phone": "+70282472797"}
0005432569236	8A03C6	5176 027892	TATYANA ALEKSEEVA	{"phone": "+70165427163"}
0005432569237	8A03C6	6369 702930	IGOR TIKHONOV	{"email": "i_tikhonov19021981@postgrespro.ru", "phone": "+70456560434"}
0005432569238	806086	8638 572799	ELENA KUZNECOVA	{"email": "ekuznecova041979@postgrespro.ru", "phone": "+70508737265"}
0005432569239	26E03A	2616 133050	ELENA SOKOLOVA	{"email": "elenasokolova-121973@postgrespro.ru", "phone": "+70493483592"}
0005432569240	900555	8123 032073	VITALIY ZAKHAROV	{"phone": "+70266361870"}
0005432569241	B32C4B	8099 844221	SVETLANA NIKITINA	{"email": "svetlananikitina.011980@postgrespro.ru", "phone": "+70799664111"}
0005432569242	058501	8542 843262	IRINA ANTONOVA	{"phone": "+70310131669"}
0005432569243	058501	3222 875815	YURIY SHEVCHENKO	{"email": "shevchenko.yuriy.051977@postgrespro.ru", "phone": "+70435884605"}
0005432569244	D97649	4137 170377	RASHID SEMENOV	{"phone": "+70663847322"}
0005432569245	D97649	1910 794035	NIKOLAY MOROZOV	{"email": "morozov.nikolay.1973@postgrespro.ru", "phone": "+70655495295"}
0005432569246	EDB3E8	1663 584765	VLADISLAV NIKOLAEV	{"email": "nikolaev-vladislav-23081961@postgrespro.ru", "phone": "+70415611726"}
0005432569247	403CE9	6503 354384	DENIS EGOROV	{"email": "denis.egorov_041971@postgrespro.ru", "phone": "+70283669114"}
0005432569248	403CE9	1030 962772	DARYA DENISOVA	{"email": "denisovadarya.01011963@postgrespro.ru", "phone": "+70796648829"}
0005432569249	580B22	2422 076550	NIKOLAY MAKAROV	{"phone": "+70429539269"}
0005432569250	580B22	8315 097455	VADIM MELNIKOV	{"email": "melnikovvadim081977@postgrespro.ru", "phone": "+70056343204"}
0005432569251	B4F9F4	6333 864712	IRINA EFREMOVA	{"phone": "+70238284967"}
0005432569252	2B62D0	6197 757991	VALENTINA KISELEVA	{"email": "vkiseleva.1973@postgrespro.ru", "phone": "+70764755270"}
0005432569253	7E434B	6078 072298	NIKOLAY SEMENOV	{"phone": "+70654748720"}
0005432569254	F0E3E9	4601 917182	DENIS ISAEV	{"email": "isaev-denis_12011972@postgrespro.ru", "phone": "+70467584571"}
0005432569255	7265ED	7416 961619	OLGA ILINA	{"email": "ilina_olga.1987@postgrespro.ru", "phone": "+70159584913"}
0005432569256	FF84DF	7415 627444	NIKITA IVANOV	{"email": "ivanovnikita_1975@postgrespro.ru", "phone": "+70166664044"}
0005432569257	23D735	6187 628104	TATYANA SERGEEVA	{"phone": "+70881103558"}
0005432569258	17F608	9874 384667	MAKSIM GAVRILOV	{"email": "maksimgavrilov_1989@postgrespro.ru", "phone": "+70386038394"}
0005432569259	17F608	9750 687049	ANNA KONDRATEVA	{"phone": "+70029726627"}
0005432569260	386A52	2371 524178	DMITRIY VASILEV	{"phone": "+70928784141"}
0005432569261	C7BF02	8637 511617	VLADISLAV PAVLOV	{"phone": "+70543531690"}
0005432569262	C7BF02	2691 730373	VIKTOR FOMIN	{"phone": "+70423563724"}
0005432569263	6BDEFF	7335 212188	TAMARA MOISEEVA	{"email": "moiseeva_t.011970@postgrespro.ru", "phone": "+70345142654"}
0005432569264	6BDEFF	6725 313023	SERGEY MATVEEV	{"email": "sergey-matveev-1976@postgrespro.ru", "phone": "+70125568697"}
0005432569265	8B9981	0091 947609	VLADIMIR KUZNECOV	{"email": "kuznecov_v_31071969@postgrespro.ru", "phone": "+70899361694"}
0005432569266	9D729C	9788 010947	VALENTINA STEPANOVA	{"email": "stepanova_v_1959@postgrespro.ru", "phone": "+70024078338"}
0005432569267	EFDE50	5917 886509	OLEG BORISOV	{"email": "o-borisov-03041969@postgrespro.ru", "phone": "+70872357937"}
0005432569268	EBBE11	4499 564331	SERGEY SOLOVEV	{"phone": "+70588835494"}
0005432569269	EBBE11	1827 206136	OLEG VASILEV	{"email": "o_vasilev1964@postgrespro.ru", "phone": "+70552744260"}
0005432569270	97448C	5652 731631	EVGENIYA KUZMINA	{"phone": "+70681082525"}
0005432569271	3DEAD4	2644 078498	LYUBOV MALYSHEVA	{"email": "malyshevalyubov_071969@postgrespro.ru", "phone": "+70389605612"}
0005432569272	3DEAD4	6434 651381	VLADIMIR KULIKOV	{"phone": "+70265712997"}
0005432569273	47651F	2541 819948	ALEKSANDR KARPOV	{"phone": "+70563689071"}
0005432569274	0F8252	9109 549849	ANDREY GUSEV	{"phone": "+70976973039"}
0005432569275	96A24A	2993 374399	GULFIYA MIKHAYLOVA	{"phone": "+70616590990"}
0005432569276	495E38	6878 876237	DMITRIY MARTYNOV	{"email": "dmitriy_martynov1966@postgrespro.ru", "phone": "+70288277374"}
0005432569277	2A4823	1469 940746	POLINA BELOVA	{"email": "belovap-03101965@postgrespro.ru", "phone": "+70287939555"}
0005432569278	02D6E7	0204 894407	ANASTASIYA LAZAREVA	{"email": "lazarevaanastasiya_1973@postgrespro.ru", "phone": "+70207026514"}
0005432569279	02D6E7	8572 936948	TATYANA ARKHIPOVA	{"email": "tatyana.arkhipova1970@postgrespro.ru", "phone": "+70782640942"}
0005432569280	02D6E7	3403 825382	ALEKSANDR NAZAROV	{"phone": "+70240036629"}
0005432569281	AC777F	1221 649528	NIKOLAY ABRAMOV	{"email": "abramovnikolay.1967@postgrespro.ru", "phone": "+70719407600"}
0005432569282	AD4738	3788 503084	ZOYA NIKIFOROVA	{"phone": "+70671074976"}
0005432569283	AD4738	8517 991956	ALEKSANDR MATVEEV	{"phone": "+70728632799"}
0005432569284	0809C7	9435 663289	TATYANA MARTYNOVA	{"email": "martynovatatyana.1974@postgrespro.ru", "phone": "+70332432079"}
0005432569285	0809C7	9238 761899	DMITRIY NAZAROV	{"email": "dmitriy_nazarov_121970@postgrespro.ru", "phone": "+70238817709"}
0005432569286	C7B528	4835 520919	VLADIMIR PAVLOV	{"email": "vladimirpavlov21061974@postgrespro.ru", "phone": "+70927253119"}
0005432569287	C7B528	1486 247444	NIKITA TARASOV	{"email": "tarasov-n_30061963@postgrespro.ru", "phone": "+70421249837"}
0005432569288	C7B528	7546 595266	TATYANA LOGINOVA	{"phone": "+70772528659"}
0005432569289	8371C7	6796 093745	VITALIY NOVIKOV	{"phone": "+70946598956"}
0005432569290	F57882	5954 058855	BOGDAN IVANOV	{"phone": "+70567170496"}
0005432569291	3828FC	6516 865342	ZINAIDA MASLOVA	{"email": "z.maslova-021970@postgrespro.ru", "phone": "+70459189145"}
0005432569292	3828FC	2885 217350	RAISA SCHERBAKOVA	{"phone": "+70220438418"}
0005432569293	2CEA1D	8864 015445	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr.101976@postgrespro.ru", "phone": "+70090020920"}
0005432569294	3B5FE5	2006 642970	MIKHAIL KUDRYASHOV	{"email": "kudryashovm1976@postgrespro.ru", "phone": "+70386010821"}
0005432569295	3B5FE5	4658 477353	NATALYA DMITRIEVA	{"email": "dmitrievan061961@postgrespro.ru", "phone": "+70598812345"}
0005432569296	B02A45	0039 878606	TATYANA KOROLEVA	{"email": "tkoroleva1970@postgrespro.ru", "phone": "+70051562827"}
0005432569297	B02A45	1025 333335	VITALIY FEDOROV	{"email": "fedorovv_071978@postgrespro.ru", "phone": "+70437003796"}
0005432569298	772BEE	7972 186476	DANIL STEPANOV	{"email": "stepanov.danil-1971@postgrespro.ru", "phone": "+70181071703"}
0005432569299	171DEB	0884 856218	PETR NIKOLAEV	{"email": "p_nikolaev.1973@postgrespro.ru", "phone": "+70009761613"}
0005432569300	5EC84D	1463 019119	OLEG KUZNECOV	{"phone": "+70893140898"}
0005432569301	1DBDC5	6965 789849	SERGEY SOLOVEV	{"email": "s_solovev121956@postgrespro.ru", "phone": "+70122740224"}
0005432569302	CAF320	0276 591670	ALENA VASILEVA	{"phone": "+70883724195"}
0005432569303	6D8F8E	5375 564113	VITALIY VOLKOV	{"phone": "+70521258045"}
0005432569304	B475E1	2555 474914	OKSANA KUZMINA	{"email": "kuzmina_oksana.19081981@postgrespro.ru", "phone": "+70826481095"}
0005432569305	9B4F71	6247 297173	OLGA ANTONOVA	{"email": "antonova-o-1966@postgrespro.ru", "phone": "+70788683550"}
0005432569306	56C6BA	5830 613117	VIKTOR KUZNECOV	{"phone": "+70353433075"}
0005432569307	86DAEE	2601 654922	ALEKSANDR ANDREEV	{"phone": "+70351453580"}
0005432569308	86DAEE	6129 942982	ALEKSANDR ANDREEV	{"email": "andreevaleksandr_1978@postgrespro.ru", "phone": "+70561956423"}
0005432569309	E9AAEC	0288 526210	MAKSIM SOLOVEV	{"email": "maksim_solovev-1968@postgrespro.ru", "phone": "+70799936521"}
0005432569310	8E9B39	2045 280293	ROMAN NAUMOV	{"email": "naumovroman.1974@postgrespro.ru", "phone": "+70667486477"}
0005432569311	9F13C9	9332 716813	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-16041968@postgrespro.ru", "phone": "+70685719458"}
0005432569312	9F13C9	6691 318038	YULIYA POPOVA	{"phone": "+70110368707"}
0005432569313	759AAC	8483 382628	DMITRIY KONOVALOV	{"phone": "+70738612723"}
0005432569314	BA7DAE	6784 195436	SVETLANA KOZLOVA	{"email": "kozlovas1965@postgrespro.ru", "phone": "+70310025619"}
0005432569315	37D553	4728 255886	MARIYA MEDVEDEVA	{"email": "m-medvedeva.061976@postgrespro.ru", "phone": "+70359693969"}
0005432569316	25AEF1	0892 905899	MARINA FADEEVA	{"email": "marina-fadeeva-031979@postgrespro.ru", "phone": "+70226341337"}
0005432569317	F06568	9131 207901	EKATERINA KUZNECOVA	{"email": "e_kuznecova-1965@postgrespro.ru", "phone": "+70738441697"}
0005432569318	F06568	0588 056622	ALEKSANDR YAKOVLEV	{"phone": "+70961240699"}
0005432569319	3CBB44	2953 107449	VLADISLAV EGOROV	{"phone": "+70166305091"}
0005432569320	9B4B17	5331 025712	ARTEM ALEKSEEV	{"email": "artemalekseev02011980@postgrespro.ru", "phone": "+70513265540"}
0005432569321	1116DE	3536 191997	SERGEY KUDRYASHOV	{"phone": "+70365121754"}
0005432569322	CBDEF0	4837 255838	NINA DMITRIEVA	{"email": "dmitrieva.n_18111974@postgrespro.ru", "phone": "+70685920873"}
0005432569323	F3F8BE	2583 378356	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila-1975@postgrespro.ru", "phone": "+70375025276"}
0005432569324	F95CE4	7119 765534	ELENA FILIPPOVA	{"email": "filippovaelena.11121955@postgrespro.ru", "phone": "+70933605065"}
0005432569325	538FAB	0441 169019	YULIYA DENISOVA	{"email": "denisova.yuliya-061974@postgrespro.ru", "phone": "+70917636881"}
0005432569326	538FAB	8167 728214	GALINA FOMINA	{"phone": "+70800051397"}
0005432569327	538FAB	6427 158940	EKATERINA SOKOLOVA	{"phone": "+70982452676"}
0005432569328	538FAB	6650 129723	ANNA MIRONOVA	{"phone": "+70029023348"}
0005432569329	71A38B	7012 735050	DMITRIY IVANOV	{"email": "dmitriy-ivanov.101973@postgrespro.ru", "phone": "+70784464379"}
0005432569330	71A38B	6211 200013	SERGEY ZAYCEV	{"email": "zaycev.s_111967@postgrespro.ru", "phone": "+70933851889"}
0005432569331	70D8CA	2680 682710	VIKTOR ZAYCEV	{"phone": "+70141974266"}
0005432569332	70D8CA	2956 752253	ANATOLIY BELOV	{"phone": "+70229499466"}
0005432569333	3070CF	2707 667677	MARIYA MIRONOVA	{"phone": "+70313951098"}
0005432569334	3070CF	8842 913649	PELAGEYA ROMANOVA	{"phone": "+70641943044"}
0005432569335	993AE6	3547 909645	OKSANA TIKHONOVA	{"email": "tikhonova.oksana.081966@postgrespro.ru", "phone": "+70614716511"}
0005432569336	26D214	5036 048963	MAKSIM KULIKOV	{"email": "maksim_kulikov19101975@postgrespro.ru", "phone": "+70937010053"}
0005432569337	22CA2C	1647 374028	ALEKSANDR KUZMIN	{"email": "akuzmin-1970@postgrespro.ru", "phone": "+70015826457"}
0005432569338	465CD4	1315 411162	SERGEY YAKOVLEV	{"email": "yakovlev_s.091972@postgrespro.ru", "phone": "+70907689226"}
0005432569339	0AFEBF	1883 985257	VALENTINA SOKOLOVA	{"phone": "+70827541799"}
0005432569340	0AFEBF	4327 289592	VLADIMIR KAZAKOV	{"email": "kazakovvladimir.101963@postgrespro.ru", "phone": "+70690234339"}
0005432569341	51F049	8106 934778	SERGEY ALEKSANDROV	{"phone": "+70320137247"}
0005432569342	5DC3D7	5670 553313	ALEKSEY EGOROV	{"email": "alekseyegorov_121964@postgrespro.ru", "phone": "+70194386098"}
0005432569343	DAA53E	4690 409427	VITALIY SIDOROV	{"email": "sidorov_vitaliy.101958@postgrespro.ru", "phone": "+70714385088"}
0005432569344	DAA53E	0516 167154	ALEKSANDR FEDOROV	{"email": "a.fedorov_10091975@postgrespro.ru", "phone": "+70601856764"}
0005432569345	1CB916	8958 258139	ANASTASIYA FILIPPOVA	{"email": "filippova.a1973@postgrespro.ru", "phone": "+70781361707"}
0005432569346	1CB916	9099 742876	VALENTINA FROLOVA	{"email": "frolova_valentina-1973@postgrespro.ru", "phone": "+70693539675"}
0005432569347	599839	5035 118516	VLADIMIR MIRONOV	{"phone": "+70225471741"}
0005432569348	599839	0446 354684	VLADIMIR GORBUNOV	{"phone": "+70638443436"}
0005432569349	599839	2876 743151	ELENA POPOVA	{"email": "e_popova101976@postgrespro.ru", "phone": "+70201985314"}
0005432569350	7899A9	4897 087270	VLADIMIR KOROLEV	{"email": "v.korolev_1968@postgrespro.ru", "phone": "+70183999797"}
0005432569351	7899A9	3421 538201	OLGA LUKYANOVA	{"email": "lukyanova-olga-011978@postgrespro.ru", "phone": "+70250310629"}
0005432569352	A9BA10	1396 807426	GALINA RYABOVA	{"email": "g-ryabova.121976@postgrespro.ru", "phone": "+70641314120"}
0005432569353	5876FA	4703 829905	GENNADIY NAZAROV	{"phone": "+70059937977"}
0005432569354	114FF4	3348 206314	YULIYA ROMANOVA	{"phone": "+70156238461"}
0005432569355	114FF4	1330 254492	YULIYA BARANOVA	{"phone": "+70891154011"}
0005432569356	E9E6B4	6563 098243	ELENA STEPANOVA	{"email": "elena.stepanova_051962@postgrespro.ru", "phone": "+70629725892"}
0005432569357	9FE5B6	2659 998333	ALEKSANDR DAVYDOV	{"phone": "+70881328193"}
0005432569358	9FE5B6	8838 555347	ALEKSANDR KONOVALOV	{"phone": "+70586260240"}
0005432569359	9FE5B6	4653 110337	NADEZHDA GORBUNOVA	{"email": "nadezhda-gorbunova-1968@postgrespro.ru", "phone": "+70078157423"}
0005432569360	9FE5B6	8934 826987	VALENTINA POPOVA	{"email": "v_popova091974@postgrespro.ru", "phone": "+70573930744"}
0005432569361	151552	2715 599145	DENIS BELOV	{"phone": "+70133291726"}
0005432569362	151552	9207 048864	TATYANA TARASOVA	{"email": "t-tarasova_071969@postgrespro.ru", "phone": "+70554609799"}
0005432569363	48B91D	0828 556993	TAISIYA ARKHIPOVA	{"email": "t-arkhipova.051961@postgrespro.ru", "phone": "+70859774917"}
0005432569364	CA6992	9413 089167	RINAT CHERNOV	{"email": "r_chernov_1974@postgrespro.ru", "phone": "+70166105740"}
0005432569365	9EA965	3344 096305	SERGEY KAZAKOV	{"email": "sergey-kazakov-23041960@postgrespro.ru", "phone": "+70017347417"}
0005432569366	9EA965	8052 347798	ALEKSANDR SAVELEV	{"phone": "+70400983478"}
0005432569367	9EA965	4572 759420	VALENTINA MARTYNOVA	{"email": "martynovavalentina-1968@postgrespro.ru", "phone": "+70814704572"}
0005432569368	40A9E3	9878 875271	MAKSIM VASILEV	{"phone": "+70946361323"}
0005432569369	40A9E3	1070 979323	ALEKSANDR FROLOV	{"email": "frolov_a.07081965@postgrespro.ru", "phone": "+70854525091"}
0005432569370	1F9CA3	4339 696524	OLESYA KUZMINA	{"email": "olesya_kuzmina.091976@postgrespro.ru", "phone": "+70194919850"}
0005432569371	5023D3	8958 539278	ALEKSEY NAZAROV	{"email": "nazarov_a071972@postgrespro.ru", "phone": "+70435740086"}
0005432569372	0A355F	3840 305525	ANTONINA MAKAROVA	{"email": "makarovaa-05021969@postgrespro.ru", "phone": "+70874101413"}
0005432569373	7E6CA7	0852 658254	ANGELINA TARASOVA	{"email": "tarasova_a-13101968@postgrespro.ru", "phone": "+70765084150"}
0005432569374	C68BDF	5052 567490	GALINA AKIMOVA	{"email": "akimova_galina-011980@postgrespro.ru", "phone": "+70184980100"}
0005432569375	AD48ED	2223 924140	MARIYA KUZMINA	{"phone": "+70833394444"}
0005432569376	15B25C	2503 517989	DENIS FEDOROV	{"phone": "+70425498974"}
0005432569377	32502A	9994 646482	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila.20111963@postgrespro.ru", "phone": "+70109460645"}
0005432569378	5EBBB6	9965 845420	EGOR VASILEV	{"phone": "+70298664405"}
0005432569379	795931	8095 709026	SERGEY KOZLOV	{"email": "sergey-kozlov-1963@postgrespro.ru", "phone": "+70406190706"}
0005432569380	795931	0062 987780	ZOYA KRASNOVA	{"phone": "+70252221837"}
0005432569381	795931	4013 006597	OLGA KUDRYASHOVA	{"phone": "+70334670367"}
0005432569382	DAED06	9408 244777	ALEKSANDR ZHURAVLEV	{"email": "a_zhuravlev-20121977@postgrespro.ru", "phone": "+70124418946"}
0005432569383	94D23C	3679 436620	ANATOLIY ALEKSANDROV	{"email": "aaleksandrov051965@postgrespro.ru", "phone": "+70222563917"}
0005432569384	94D23C	5292 254400	OLGA FADEEVA	{"email": "fadeeva_olga-04011962@postgrespro.ru", "phone": "+70319924539"}
0005432569385	A1241F	4456 041313	MAKSIM FOMIN	{"email": "maksim-fomin_30101968@postgrespro.ru", "phone": "+70675900626"}
0005432569386	9CD9A1	8835 151504	VLADIMIR PETROV	{"email": "vpetrov-05061969@postgrespro.ru", "phone": "+70620732064"}
0005432569387	C1F03A	3443 367179	FEDOR NIKOLAEV	{"email": "nikolaev.fedor111979@postgrespro.ru", "phone": "+70927533177"}
0005432569388	DFE6F6	5687 835544	LIDIYA ANTONOVA	{"email": "l-antonova-23021974@postgrespro.ru", "phone": "+70959389352"}
0005432569389	DFE6F6	6278 997441	ELINA ALEKSANDROVA	{"phone": "+70203728243"}
0005432569390	AC628A	4328 141332	ANDREY BONDARENKO	{"email": "andrey_bondarenko-011980@postgrespro.ru", "phone": "+70646389054"}
0005432569391	AC628A	0653 308152	ALEKSANDRA FROLOVA	{"email": "a_frolova_14061976@postgrespro.ru", "phone": "+70855370495"}
0005432569392	BB8C39	7144 391883	ANDREY ALEKSANDROV	{"email": "a.aleksandrov_1965@postgrespro.ru", "phone": "+70952378442"}
0005432569393	3853E4	9143 136936	EVGENIYA KONOVALOVA	{"phone": "+70070435091"}
0005432569394	29A3B0	9142 213857	IVAN ANTONOV	{"phone": "+70371005013"}
0005432569395	29A3B0	0945 855797	MARINA KULIKOVA	{"phone": "+70745543700"}
0005432569396	29A3B0	6274 571247	IGOR MEDVEDEV	{"email": "medvedevigor.11021972@postgrespro.ru", "phone": "+70106746026"}
0005432569397	FCA383	0788 605866	VYACHESLAV SEMENOV	{"phone": "+70598597498"}
0005432569398	48A676	4360 613707	ANDREY GERASIMOV	{"email": "andrey-gerasimov-24081963@postgrespro.ru", "phone": "+70648517059"}
0005432569399	F3C830	2419 075684	VERA KULIKOVA	{"phone": "+70184168464"}
0005432569400	2A1B9F	1400 827974	VALENTINA CHERNOVA	{"phone": "+70625023452"}
0005432569401	E3E879	4021 315690	YURIY MARTYNOV	{"email": "martynovyuriy-1969@postgrespro.ru", "phone": "+70057736742"}
0005432569402	2FB44C	1568 629890	ALEKSANDR DMITRIEV	{"email": "dmitrieva30111976@postgrespro.ru", "phone": "+70062641270"}
0005432569403	54FBC5	8163 345804	SERGEY SOLOVEV	{"phone": "+70948877098"}
0005432569404	54FBC5	9818 855126	VALENTIN KOROLEV	{"email": "v_korolev_05021963@postgrespro.ru", "phone": "+70884241699"}
0005432569405	6EC449	5613 006790	TAMARA IVANOVA	{"email": "tamara-ivanova.20061966@postgrespro.ru", "phone": "+70072620223"}
0005432569406	F32D75	8258 477156	ZOYA KULIKOVA	{"email": "z-kulikova-24101975@postgrespro.ru", "phone": "+70499873377"}
0005432569407	950B3D	0173 147541	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev121973@postgrespro.ru", "phone": "+70587026758"}
0005432569408	3B6F6B	3605 691315	VERA KONOVALOVA	{"email": "vkonovalova_1967@postgrespro.ru", "phone": "+70867904541"}
0005432569409	60A8C3	5962 085737	ZOYA MAKAROVA	{"phone": "+70066891473"}
0005432569410	60A8C3	5499 224047	ALEKSANDR GUSEV	{"phone": "+70769218954"}
0005432569411	60A8C3	9146 719223	SVETLANA KULIKOVA	{"email": "svetlana_kulikova_1972@postgrespro.ru", "phone": "+70445468545"}
0005432569412	1D3052	0389 116054	EKATERINA MIRONOVA	{"phone": "+70894023119"}
0005432569413	5C0E82	6948 300921	ARTEM IVANOV	{"phone": "+70907327233"}
0005432569414	1C1579	9399 723375	BORIS GRIGOREV	{"phone": "+70510296610"}
0005432569415	D63F65	1208 779400	GALINA KUZMINA	{"email": "galinakuzmina22071976@postgrespro.ru", "phone": "+70745071894"}
0005432569416	7D0FD8	7856 803989	VIKTOR SERGEEV	{"email": "v-sergeev-1969@postgrespro.ru", "phone": "+70907516389"}
0005432569417	7D0FD8	6977 187970	TATYANA POPOVA	{"phone": "+70561192354"}
0005432569418	EE157D	3419 065878	NADEZHDA EGOROVA	{"email": "nadezhdaegorova24041972@postgrespro.ru", "phone": "+70491468469"}
0005432569419	0D316F	4915 852130	VASILIY SOKOLOV	{"email": "sokolovvasiliy.1977@postgrespro.ru", "phone": "+70933292791"}
0005432569420	0D316F	2584 612070	ELENA LAZAREVA	{"phone": "+70562726495"}
0005432569421	DE1BCF	8502 898276	TATYANA FEDOROVA	{"email": "t_fedorova-081967@postgrespro.ru", "phone": "+70148099418"}
0005432569422	6BD91A	6127 639208	YULIYA POPOVA	{"phone": "+70224856935"}
0005432569423	6BD91A	2794 368217	MATVEY PAVLOV	{"email": "matvey.pavlov.111971@postgrespro.ru", "phone": "+70051739211"}
0005432569424	FD9618	1489 306547	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr.1962@postgrespro.ru", "phone": "+70391591658"}
0005432569425	53AD5C	1636 116875	NAIL EGOROV	{"phone": "+70963170963"}
0005432569426	E57E5D	5844 055154	INNA KOVALEVA	{"phone": "+70113241311"}
0005432569427	E57E5D	6716 812499	EKATERINA SMIRNOVA	{"phone": "+70791301400"}
0005432569428	E62838	3909 880358	ROMAN KARPOV	{"email": "karpov_r-061962@postgrespro.ru", "phone": "+70711471378"}
0005432569429	CCCD1D	2356 619565	RINAT EGOROV	{"email": "rinat.egorov-1971@postgrespro.ru", "phone": "+70214036479"}
0005432569430	CCCD1D	7288 651780	MARINA ZAKHAROVA	{"email": "zakharova-m_04091965@postgrespro.ru", "phone": "+70387237931"}
0005432571257	15F083	5348 885632	ANTONINA FADEEVA	{"phone": "+70764194447"}
0005432571258	D789C9	8314 435782	KIRILL KUDRYASHOV	{"phone": "+70057642943"}
0005432571259	B847E5	9483 755030	NATALYA STEPANOVA	{"email": "natalya.stepanova-1968@postgrespro.ru", "phone": "+70294299051"}
0005432571260	288559	7110 887338	ALEKSANDR BONDARENKO	{"email": "a-bondarenko-1975@postgrespro.ru", "phone": "+70984339497"}
0005432571261	953FC6	2478 505179	NIKOLAY PAVLOV	{"email": "n.pavlov07011984@postgrespro.ru", "phone": "+70559589360"}
0005432571262	953FC6	4704 190947	NADEZHDA NIKIFOROVA	{"email": "nikiforova-nadezhda_1971@postgrespro.ru", "phone": "+70474337139"}
0005432571263	BC4C98	4410 531260	ANNA DAVYDOVA	{"phone": "+70280816607"}
0005432571264	7F55AF	9738 754956	OLGA EGOROVA	{"phone": "+70396724921"}
0005432571265	7F55AF	8823 778690	OLGA YAKOVLEVA	{"phone": "+70321328389"}
0005432571266	DB994F	0588 964224	KSENIYA NAZAROVA	{"phone": "+70376190068"}
0005432571267	93D148	3639 388164	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin101976@postgrespro.ru", "phone": "+70279080385"}
0005432571268	53C785	3773 008920	VLADIMIR VLASOV	{"phone": "+70714939549"}
0005432571269	8A5B7D	5694 664187	TATYANA SAVELEVA	{"email": "tatyana.saveleva.1974@postgrespro.ru", "phone": "+70060675800"}
0005432571270	881824	7274 435293	ANNA KOMAROVA	{"email": "annakomarova.051965@postgrespro.ru", "phone": "+70946535145"}
0005432571271	881824	3871 706927	GENNADIY SCHERBAKOV	{"email": "scherbakov.g_1976@postgrespro.ru", "phone": "+70877633438"}
0005432571272	CE30BB	1994 561200	OKSANA DMITRIEVA	{"email": "dmitrieva-o.1964@postgrespro.ru", "phone": "+70452749414"}
0005432571273	110EC9	8222 999698	TIMOFEY SCHERBAKOV	{"email": "t-scherbakov_031977@postgrespro.ru", "phone": "+70619250526"}
0005432571274	ED7942	9065 769082	IRINA FEDOROVA	{"phone": "+70561164112"}
0005432571275	A42611	7244 608501	VITALIY PETROV	{"phone": "+70053049831"}
0005432571276	7D0D41	8699 474566	MARIYA DANILOVA	{"phone": "+70903323627"}
0005432571277	BE419A	8969 055044	MAKSIM KOZLOV	{"phone": "+70149168115"}
0005432571278	8AC305	7048 388097	NIKITA DMITRIEV	{"phone": "+70662705527"}
0005432571279	AA0FEE	4315 833645	MARGARITA MARTYNOVA	{"email": "m_martynova16071976@postgrespro.ru", "phone": "+70712387973"}
0005432571280	2EC543	8221 567832	ALINA GRISHINA	{"phone": "+70295314924"}
0005432571281	2CE2DF	8677 865996	YULIYA DENISOVA	{"email": "yuliya-denisova-061971@postgrespro.ru", "phone": "+70621588162"}
0005432571282	2CE2DF	3456 626344	ZINAIDA KUZNECOVA	{"email": "kuznecova-zinaida.10061960@postgrespro.ru", "phone": "+70541262070"}
0005432571283	C540A9	0772 353017	IGOR POPOV	{"email": "ipopov011979@postgrespro.ru", "phone": "+70489433634"}
0005432571284	0EB016	4084 480158	OLGA MEDVEDEVA	{"phone": "+70133757179"}
0005432571285	D08309	8407 742823	OLGA KOROLEVA	{"email": "korolevao.1974@postgrespro.ru", "phone": "+70797659415"}
0005432571286	DAF81C	8114 959774	PETR SMIRNOV	{"email": "smirnovpetr011977@postgrespro.ru", "phone": "+70584388535"}
0005432571287	C1CC94	2002 500933	NINA KRASNOVA	{"phone": "+70662498192"}
0005432571288	3181A1	4300 483853	EKATERINA ISAEVA	{"phone": "+70802366719"}
0005432571289	1F2940	8630 629863	ALEKSEY MIKHAYLOV	{"email": "a_mikhaylov071962@postgrespro.ru", "phone": "+70742298261"}
0005432571290	8A0963	3601 090377	ELENA KOVALEVA	{"email": "kovaleva-elena1976@postgrespro.ru", "phone": "+70794366157"}
0005432571291	4FDC70	8786 126460	VLADIMIR STEPANOV	{"email": "stepanov_v_081972@postgrespro.ru", "phone": "+70265046659"}
0005432571292	4F037C	6400 878900	NIKOLAY NOVIKOV	{"phone": "+70950331379"}
0005432571293	4F037C	7841 311789	ALEKSANDR FEDOTOV	{"phone": "+70665947699"}
0005432571294	BC0C9E	9949 021532	IVAN ABRAMOV	{"email": "ivan.abramov-19091964@postgrespro.ru", "phone": "+70564924003"}
0005432571295	BB7692	0122 669858	MARGARITA IVANOVA	{"phone": "+70936425897"}
0005432571296	4FBD02	8350 998551	NATALYA MIKHAYLOVA	{"email": "mikhaylova_natalya.1972@postgrespro.ru", "phone": "+70011070210"}
0005432571297	BFA55B	9512 659874	ALLA PAVLOVA	{"email": "pavlova-a1973@postgrespro.ru", "phone": "+70385596188"}
0005432571298	609970	8950 081708	ARTEMIY KOZLOV	{"phone": "+70240380725"}
0005432571299	5971DD	0018 324863	MIKHAIL GORBUNOV	{"email": "gorbunov-m1974@postgrespro.ru", "phone": "+70176270577"}
0005432571300	D67348	6399 842432	DENIS SMIRNOV	{"phone": "+70241219539"}
0005432571301	526C97	3555 816980	MARINA BOGDANOVA	{"email": "m-bogdanova_25011964@postgrespro.ru", "phone": "+70227483832"}
0005432571302	6D87D6	0452 374284	OLGA MATVEEVA	{"phone": "+70407721440"}
0005432571303	7C69BE	1063 717014	VERA KOZLOVA	{"phone": "+70544779175"}
0005432571304	7C69BE	3511 829005	RUSTAM MOROZOV	{"email": "rustam-morozov.1970@postgrespro.ru", "phone": "+70508748124"}
0005432571305	ED096A	2777 709288	GLEB KUZNECOV	{"phone": "+70251914087"}
0005432571306	97E2B7	0451 177503	ANTON IVANOV	{"email": "ivanov_anton-03011971@postgrespro.ru", "phone": "+70660220025"}
0005432571307	97E2B7	3268 277203	GALINA POLYAKOVA	{"email": "polyakova.g-20021977@postgrespro.ru", "phone": "+70636320840"}
0005432571308	C1F2B6	7772 511785	LIDIYA SMIRNOVA	{"phone": "+70469772670"}
0005432571309	D4EF47	3331 735207	VLADIMIR DAVYDOV	{"email": "v_davydov.081981@postgrespro.ru", "phone": "+70351664544"}
0005432571310	C58DE3	1440 914321	TATYANA SIDOROVA	{"phone": "+70423080860"}
0005432571311	C58DE3	1606 597807	NIKOLAY PETROV	{"email": "n_petrov-071958@postgrespro.ru", "phone": "+70755271467"}
0005432571312	7D63B3	1307 900273	SVETLANA ANISIMOVA	{"phone": "+70717733418"}
0005432571313	7D63B3	6157 261483	OLGA ZHURAVLEVA	{"phone": "+70667302545"}
0005432571314	7D63B3	5713 751878	NIKOLAY FEDOROV	{"phone": "+70252047886"}
0005432571315	7D63B3	4827 627727	MARINA KUZMINA	{"phone": "+70490483608"}
0005432571316	065F21	1709 282643	EKATERINA PETROVA	{"phone": "+70871195927"}
0005432571317	DCBFCC	2282 575627	NATALYA OSIPOVA	{"email": "n-osipova.30081976@postgrespro.ru", "phone": "+70503742714"}
0005432571318	DCBFCC	9053 555690	TATYANA SERGEEVA	{"email": "t_sergeeva-11091975@postgrespro.ru", "phone": "+70412329399"}
0005432571319	DCBFCC	3510 635459	VLADIMIR IVANOV	{"email": "v.ivanov18051961@postgrespro.ru", "phone": "+70402838952"}
0005432571320	CE8E4D	5053 244826	NIKOLAY EGOROV	{"phone": "+70766575695"}
0005432571321	CE8E4D	1700 147394	SERGEY KRASNOV	{"phone": "+70154787426"}
0005432571322	93CFD1	4968 174345	ANNA ROMANOVA	{"phone": "+70004637887"}
0005432571323	93CFD1	0834 481501	NIKOLAY VASILEV	{"phone": "+70651532627"}
0005432571324	93CFD1	5961 278290	ANASTASIYA ILINA	{"email": "ilina.a_01111976@postgrespro.ru", "phone": "+70915906607"}
0005432571325	C9BA0D	0313 784704	VERONIKA KUZNECOVA	{"phone": "+70799362601"}
0005432571326	C9BA0D	2059 759470	ALEKSANDR POPOV	{"email": "popovaleksandr_1970@postgrespro.ru", "phone": "+70320635646"}
0005432571327	0B34DF	4998 923566	LYUDMILA FROLOVA	{"email": "lyudmila_frolova_1961@postgrespro.ru", "phone": "+70451387055"}
0005432571328	81543C	3713 057528	YURIY KRASNOV	{"email": "krasnovy.1973@postgrespro.ru", "phone": "+70858029980"}
0005432571329	315293	2910 133344	DMITRIY MEDVEDEV	{"email": "d.medvedev.19101970@postgrespro.ru", "phone": "+70630792462"}
0005432571330	315293	6818 104022	ALENA VASILEVA	{"email": "vasileva_alena-051971@postgrespro.ru", "phone": "+70730057809"}
0005432571331	6C2798	4390 004134	LYUBOV POPOVA	{"email": "lyubov-popova.081968@postgrespro.ru", "phone": "+70413692555"}
0005432571332	9D2AC5	3055 788227	MARINA NAZAROVA	{"email": "marinanazarova.27111967@postgrespro.ru", "phone": "+70312957759"}
0005432571333	C5B015	7824 476318	NINA NIKITINA	{"email": "nikitina.n1976@postgrespro.ru", "phone": "+70405590327"}
0005432571334	044ADD	8376 025744	IGOR MOISEEV	{"email": "igor.moiseev-041978@postgrespro.ru", "phone": "+70846289570"}
0005432571335	044ADD	1538 710871	VALENTINA SOROKINA	{"email": "valentina_sorokina011972@postgrespro.ru", "phone": "+70921468622"}
0005432571336	3BFD54	0921 297620	LYUBOV DMITRIEVA	{"email": "lyubov_dmitrieva18111966@postgrespro.ru", "phone": "+70451913484"}
0005432571337	82E40C	3730 477604	VLADISLAV AFANASEV	{"email": "afanasev-vladislav13091971@postgrespro.ru", "phone": "+70321006288"}
0005432571338	307F09	6500 162052	MIKHAIL KAZAKOV	{"phone": "+70945386034"}
0005432571339	C1F6BA	1725 144046	OLGA TROFIMOVA	{"email": "trofimova_olga061975@postgrespro.ru", "phone": "+70915678806"}
0005432571340	C1F6BA	2696 264372	SVETLANA KONOVALOVA	{"phone": "+70516933649"}
0005432571341	C0D0B2	4483 419159	VASILIY DAVYDOV	{"phone": "+70985059040"}
0005432571342	00571B	9981 173602	DMITRIY CHERNOV	{"phone": "+70808942159"}
0005432571343	00571B	4434 520854	DMITRIY NIKOLAEV	{"phone": "+70251306437"}
0005432571344	60E04E	9210 424041	DENIS ANTONOV	{"email": "antonov-denis-1977@postgrespro.ru", "phone": "+70972439624"}
0005432571345	60E04E	1968 240741	EKATERINA GRISHINA	{"email": "grishina.ekaterina.13091972@postgrespro.ru", "phone": "+70369908551"}
0005432571346	C5E225	4794 491955	VALENTINA ZHURAVLEVA	{"email": "valentina.zhuravleva-24081972@postgrespro.ru", "phone": "+70577164804"}
0005432571347	01F101	4464 610700	EKATERINA BORISOVA	{"email": "ekaterinaborisova_1971@postgrespro.ru", "phone": "+70229941592"}
0005432571348	01F101	1937 584552	LARISA NESTEROVA	{"phone": "+70449834254"}
0005432571349	FA6A07	4063 189951	ANDREY KULIKOV	{"phone": "+70918568177"}
0005432571350	FA6A07	6053 522800	LYUDMILA KONDRATEVA	{"phone": "+70361406131"}
0005432571351	16EF80	4652 878517	ALEKSEY CHERNOV	{"email": "aleksey.chernov-16021981@postgrespro.ru", "phone": "+70681663323"}
0005432571352	538DF1	7420 743496	IRINA ABRAMOVA	{"phone": "+70397891431"}
0005432571353	538DF1	8827 455962	LYUBOV NOVIKOVA	{"phone": "+70957936636"}
0005432571354	93F631	5983 394832	SERGEY MARTYNOV	{"email": "s-martynov081969@postgrespro.ru", "phone": "+70432152835"}
0005432571355	8566F4	0413 967692	IRINA KUZNECOVA	{"email": "kuznecova-i.021979@postgrespro.ru", "phone": "+70484194812"}
0005432571356	8566F4	9603 133788	VLADIMIR NIKOLAEV	{"email": "nikolaev_v_1982@postgrespro.ru", "phone": "+70532196403"}
0005432571357	D38A3C	9736 883550	VLADIMIR NOVIKOV	{"email": "vladimir.novikov_1966@postgrespro.ru", "phone": "+70842381940"}
0005432571358	45AB88	4468 722482	LUIZA KARPOVA	{"phone": "+70765522802"}
0005432571359	45AB88	0047 207568	OLEG ZHUKOV	{"phone": "+70309668931"}
0005432571360	68EB35	4846 294330	EVGENIY KUZNECOV	{"email": "ekuznecov-1983@postgrespro.ru", "phone": "+70162941539"}
0005432571361	68EB35	2116 642791	VALENTINA BELYAEVA	{"email": "belyaeva.valentina1965@postgrespro.ru", "phone": "+70058155540"}
0005432571362	191B44	7088 621187	NATALYA KAZAKOVA	{"phone": "+70139816033"}
0005432571363	191B44	1769 246968	NADEZHDA NIKOLAEVA	{"phone": "+70887338846"}
0005432571364	3B5350	8857 585817	NINA KUZNECOVA	{"phone": "+70467952234"}
0005432571365	3B5350	4703 207681	LARISA FILATOVA	{"phone": "+70995053824"}
0005432571366	663D2E	4609 003312	GALINA LAZAREVA	{"email": "lazarevag-26121970@postgrespro.ru", "phone": "+70701188567"}
0005432571367	29456B	2672 489202	ALEKSANDR VASILEV	{"phone": "+70111527924"}
0005432571368	29456B	7157 923122	SERGEY KUZMIN	{"email": "sergey_kuzmin051970@postgrespro.ru", "phone": "+70467586520"}
0005432571369	CDA8C2	8943 273046	SERGEY SOLOVEV	{"phone": "+70402843252"}
0005432571370	911C91	3618 611929	RAMILYA VASILEVA	{"phone": "+70724049729"}
0005432571371	799C2B	6282 923035	NATALYA IVANOVA	{"email": "natalya.ivanova31051978@postgrespro.ru", "phone": "+70416861532"}
0005432571372	EA15B0	0661 770749	KONSTANTIN SCHERBAKOV	{"phone": "+70894841158"}
0005432571373	006906	9657 895257	VLADIMIR SAVELEV	{"phone": "+70897633562"}
0005432571374	006906	6210 623471	SVETLANA KOZLOVA	{"email": "svetlana_kozlova10081971@postgrespro.ru", "phone": "+70950796255"}
0005432571375	925715	1786 231191	ELENA YUDINA	{"phone": "+70413877939"}
0005432571376	9239BE	5462 168433	OLEG FEDOTOV	{"phone": "+70069876795"}
0005432571377	9239BE	3231 067534	ALEKSANDR NIKOLAEV	{"phone": "+70268142130"}
0005432571378	A53348	8859 348260	VIKTOR BORISOV	{"phone": "+70226914992"}
0005432571379	121287	9128 596428	YULIYA ZAYCEVA	{"email": "yuliyazayceva_051969@postgrespro.ru", "phone": "+70470832313"}
0005432571380	E717DC	1737 541199	TATYANA KUZNECOVA	{"email": "tkuznecova_041964@postgrespro.ru", "phone": "+70846066189"}
0005432571381	E717DC	1332 329160	LILIYA BELOVA	{"email": "belova_liliya-121977@postgrespro.ru", "phone": "+70460370407"}
0005432571382	294DA1	4096 899701	VLADIMIR EGOROV	{"phone": "+70726367758"}
0005432571383	294DA1	0742 781782	NATALYA KUZNECOVA	{"email": "kuznecova-natalya-11091973@postgrespro.ru", "phone": "+70241651779"}
0005432571384	79D649	8301 189052	GRIGORIY SOLOVEV	{"email": "g_solovev011988@postgrespro.ru", "phone": "+70388553307"}
0005432571385	79D649	3711 933311	DANILA GERASIMOV	{"email": "danila_gerasimov-07101962@postgrespro.ru", "phone": "+70853286718"}
0005432571386	21B36C	3870 635420	EVGENIY POPOV	{"phone": "+70991258572"}
0005432571387	F7113F	6381 328150	VALERIY ABRAMOV	{"phone": "+70397021368"}
0005432571388	E1798A	0803 207415	DMITRIY YAKOVLEV	{"email": "dmitriy.yakovlev_26071970@postgrespro.ru", "phone": "+70259979693"}
0005432571389	A3E775	9841 361062	INNA POPOVA	{"email": "popova.i-051977@postgrespro.ru", "phone": "+70823749502"}
0005432571390	3571FA	1389 967336	ZOYA LUKYANOVA	{"email": "zoya.lukyanova.1979@postgrespro.ru", "phone": "+70883565890"}
0005432571391	BEB674	5569 233593	YULIYA NESTEROVA	{"email": "y-nesterova-1975@postgrespro.ru", "phone": "+70242059538"}
0005432571392	BEB674	4768 186045	SERGEY BONDARENKO	{"phone": "+70047507229"}
0005432571393	A349DC	7132 469715	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova.24081970@postgrespro.ru", "phone": "+70288237439"}
0005432571394	189649	7041 304848	DIANA KARPOVA	{"phone": "+70118306095"}
0005432571395	189649	5759 329123	ELENA VLASOVA	{"phone": "+70502280214"}
0005432571396	189649	4922 666218	MAKSIM OSIPOV	{"email": "osipovm-081960@postgrespro.ru", "phone": "+70501558120"}
0005432571397	5A9F4B	1711 547132	OLGA ISAEVA	{"phone": "+70258389089"}
0005432571398	8F433F	2411 784698	OLEG ISAEV	{"phone": "+70072008679"}
0005432571399	F7A7EF	6894 527079	KIRILL KUZNECOV	{"email": "kuznecov_k-1986@postgrespro.ru", "phone": "+70077369803"}
0005432571400	A0B6CA	2804 805711	ANNA YAKOVLEVA	{"phone": "+70634971852"}
0005432571401	A0B6CA	8301 594255	KIRA ROMANOVA	{"phone": "+70647321758"}
0005432571402	793C79	5376 784600	KLAVDIYA EGOROVA	{"phone": "+70142246451"}
0005432571403	8E1583	5850 355650	EMMA BELYAEVA	{"email": "ebelyaeva.111970@postgrespro.ru", "phone": "+70076549689"}
0005432571404	E23046	0362 739897	YAKOV NIKOLAEV	{"email": "nikolaev_yakov_29061974@postgrespro.ru", "phone": "+70405971657"}
0005432571405	E23046	5809 605512	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov11051974@postgrespro.ru", "phone": "+70027572621"}
0005432571406	E23046	0919 442673	VALERIY AFANASEV	{"phone": "+70551040435"}
0005432571407	B64D00	0642 042468	ANATOLIY MOISEEV	{"phone": "+70283295213"}
0005432571408	A82B2E	9207 250374	MIKHAIL RODIONOV	{"phone": "+70507121199"}
0005432571409	155218	5098 656947	ALENA TIKHONOVA	{"phone": "+70567118787"}
0005432571410	25F37D	8856 373828	ELIZAVETA SIDOROVA	{"phone": "+70304546910"}
0005432571411	463614	1889 678541	VLADIMIR CHERNOV	{"phone": "+70752494877"}
0005432571412	A5FD0D	8778 445077	NIKOLAY ISAEV	{"email": "n-isaev011968@postgrespro.ru", "phone": "+70932422755"}
0005432571413	672DD4	5430 287318	RUMIYA KOZLOVA	{"email": "rumiya-kozlova_1976@postgrespro.ru", "phone": "+70035019466"}
0005432571414	672DD4	3104 708217	TATYANA MEDVEDEVA	{"email": "tatyana_medvedeva.051977@postgrespro.ru", "phone": "+70698479498"}
0005432571415	7CA4F9	7248 985575	PAVEL AFANASEV	{"phone": "+70443286200"}
0005432571416	7CA4F9	8417 971451	NADEZHDA MAKSIMOVA	{"phone": "+70711513648"}
0005432571417	00F716	2553 790209	OLGA NIKIFOROVA	{"phone": "+70263554205"}
0005432571418	13DD4E	8756 591931	NIKOLAY PETROV	{"phone": "+70974009086"}
0005432571419	BD82DB	4610 916358	SVETLANA YAKOVLEVA	{"email": "s.yakovleva15021979@postgrespro.ru", "phone": "+70483544831"}
0005432571420	090124	6442 740756	VITALIY BORISOV	{"phone": "+70331244414"}
0005432571421	090124	6321 745003	DMITRIY KUZNECOV	{"phone": "+70239732668"}
0005432571422	090124	1792 541651	SVETLANA YAKOVLEVA	{"phone": "+70337142073"}
0005432571423	E823EB	2860 859903	SERGEY ALEKSEEV	{"email": "alekseev_s14121974@postgrespro.ru", "phone": "+70855125817"}
0005432571424	1A956A	8455 358119	ANDREY FROLOV	{"email": "frolov.a-30111962@postgrespro.ru", "phone": "+70985446791"}
0005432571425	15D54B	1207 267563	VIKTORIYA ALEKSEEVA	{"email": "valekseeva-28051975@postgrespro.ru", "phone": "+70980726246"}
0005432571426	15D54B	5135 978442	SERGEY MEDVEDEV	{"email": "medvedev-s_111962@postgrespro.ru", "phone": "+70281404486"}
0005432571427	0B0A42	6878 241143	ALEKSANDR PAVLOV	{"phone": "+70390054849"}
0005432571428	8E7664	2281 907626	SOFIYA SAVELEVA	{"phone": "+70759931779"}
0005432571429	5D8859	2676 115522	EKATERINA OSIPOVA	{"email": "osipova_ekaterina_15101976@postgrespro.ru", "phone": "+70470800451"}
0005432571430	944694	8404 868420	VASILIY ZAKHAROV	{"email": "zakharov_vasiliy_021970@postgrespro.ru", "phone": "+70423808103"}
0005432571431	C20800	3529 693955	ALEKSANDR GUSEV	{"phone": "+70424496023"}
0005432571432	C20800	1368 586632	DILYARA SIDOROVA	{"email": "dilyara.sidorova-16051973@postgrespro.ru", "phone": "+70945873393"}
0005432571433	C20800	4081 261914	ILYA IVANOV	{"phone": "+70814706275"}
0005432571434	8AB9A4	5136 116750	VERONIKA SERGEEVA	{"email": "sergeevaveronika.021977@postgrespro.ru", "phone": "+70156655146"}
0005432571435	B91E96	1874 988572	VERONIKA KONOVALOVA	{"email": "veronikakonovalova.091961@postgrespro.ru", "phone": "+70510611136"}
0005432571436	B91E96	1553 119851	STEPAN SOKOLOV	{"email": "stepan-sokolov.1968@postgrespro.ru", "phone": "+70602114311"}
0005432571437	B91E96	5684 402127	YURIY SOROKIN	{"email": "sorokin_y_1974@postgrespro.ru", "phone": "+70219940968"}
0005432571438	65C1BC	3441 240435	ZAKHAR AFANASEV	{"email": "z-afanasev.101969@postgrespro.ru", "phone": "+70911841969"}
0005432583582	6F6A9F	8487 988959	VIKTOR SEMENOV	{"phone": "+70043567037"}
0005432583583	E798BE	9467 814590	PAVEL ZAKHAROV	{"email": "zakharov-p_1966@postgrespro.ru", "phone": "+70527414255"}
0005432583584	F516B9	9401 045923	ANDREY NAZAROV	{"email": "andreynazarov_031969@postgrespro.ru", "phone": "+70284084316"}
0005432583585	F516B9	0269 838475	NINA VLASOVA	{"phone": "+70899775880"}
0005432583586	023E6B	2204 680657	VASILIY KUZMIN	{"email": "kuzmin.v-21071975@postgrespro.ru", "phone": "+70119658638"}
0005432583587	E0D4FC	0953 748471	SERGEY ORLOV	{"email": "orlov-sergey_14031977@postgrespro.ru", "phone": "+70684430911"}
0005432583588	8DA9A8	8416 500653	PAVEL PETROV	{"phone": "+70284056996"}
0005432583589	491053	6754 957460	LYUBOV VOLKOVA	{"email": "l-volkova1975@postgrespro.ru", "phone": "+70057583184"}
0005432583590	491053	2530 097463	OLGA SERGEEVA	{"phone": "+70505101107"}
0005432583591	DF92A6	0449 341452	TATYANA VASILEVA	{"phone": "+70293592952"}
0005432583592	B0B438	9933 143038	EKATERINA KOROLEVA	{"phone": "+70082623516"}
0005432583593	B0B438	4554 279172	ANASTASIYA KUZNECOVA	{"phone": "+70029150699"}
0005432583594	AA25C0	0991 441572	ALEKSANDRA SMIRNOVA	{"email": "smirnovaa061964@postgrespro.ru", "phone": "+70733134612"}
0005432583595	0AF8A7	6329 178551	RAMILYA KARPOVA	{"email": "karpovar.15121956@postgrespro.ru", "phone": "+70233860775"}
0005432583596	ED2800	5327 211892	NINA DANILOVA	{"email": "nina_danilova_121979@postgrespro.ru", "phone": "+70112152622"}
0005432583597	0306AC	5735 258825	IRINA MARTYNOVA	{"email": "martynovai-071977@postgrespro.ru", "phone": "+70629069093"}
0005432583598	980199	2899 126226	ANNA EFIMOVA	{"phone": "+70460702782"}
0005432583712	AE885B	1334 995234	ALEKSANDR FEDOROV	{"phone": "+70901933194"}
0005432583599	980199	9567 842079	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov-1982@postgrespro.ru", "phone": "+70588131458"}
0005432583600	EEE9BD	5617 245864	SERGEY ABRAMOV	{"email": "sergey.abramov30041984@postgrespro.ru", "phone": "+70119422699"}
0005432583601	EEE9BD	4981 783341	TAMARA SERGEEVA	{"phone": "+70882339093"}
0005432583602	0057F8	8234 842410	ANTON FROLOV	{"email": "frolov-a-1970@postgrespro.ru", "phone": "+70194979221"}
0005432583603	71F621	0915 559221	YULIYA PAVLOVA	{"phone": "+70062623697"}
0005432583604	71F621	0985 737580	FEDOR KONOVALOV	{"phone": "+70369002752"}
0005432583605	DFBD89	7152 305311	OLGA TIKHONOVA	{"phone": "+70722013591"}
0005432583728	D1AED7	7813 880466	NADEZHDA KRASNOVA	{"phone": "+70865272397"}
0005432583606	DFBD89	5224 932908	MAKSIM KONOVALOV	{"email": "konovalov.m28031979@postgrespro.ru", "phone": "+70224009828"}
0005432583607	792B95	2702 995921	SERGEY KUDRYASHOV	{"email": "sergey.kudryashov.031964@postgrespro.ru", "phone": "+70954732837"}
0005432583608	0AACCD	2439 965873	NATALYA ZAKHAROVA	{"phone": "+70440441548"}
0005432583665	D81989	0423 573112	EVGENIY KUZNECOV	{"phone": "+70219023583"}
0005432583609	7E0A21	6627 337680	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova_19061973@postgrespro.ru", "phone": "+70338579325"}
0005432583610	438D01	9902 012770	ANDREY MATVEEV	{"phone": "+70167473495"}
0005432583611	438D01	7411 207587	SVETLANA KOZLOVA	{"email": "svetlana.kozlova-01061963@postgrespro.ru", "phone": "+70361037832"}
0005432583612	213341	3168 680013	IRINA ANDREEVA	{"email": "irina_andreeva011972@postgrespro.ru", "phone": "+70503549736"}
0005432583613	82B221	2244 248322	KONSTANTIN BONDARENKO	{"email": "bondarenko-konstantin_011980@postgrespro.ru", "phone": "+70505084689"}
0005432583614	82B221	8546 563680	VERONIKA ANTONOVA	{"email": "antonovav_23041962@postgrespro.ru", "phone": "+70245850733"}
0005432583615	53F096	3627 639668	LYUBOV PAVLOVA	{"email": "pavlova-lyubov_19071971@postgrespro.ru", "phone": "+70418630468"}
0005432583616	777458	5197 185837	ARINA KUZNECOVA	{"phone": "+70929267386"}
0005432583617	777458	1169 788983	MAYYA ANDREEVA	{"phone": "+70933251164"}
0005432583618	E4746A	2710 153741	SVETLANA YUDINA	{"email": "svetlana-yudina_081971@postgrespro.ru", "phone": "+70894292593"}
0005432583619	69947B	4646 959597	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey_081975@postgrespro.ru", "phone": "+70634781886"}
0005432583620	A324E3	6854 194662	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey_1970@postgrespro.ru", "phone": "+70199876850"}
0005432583621	A324E3	5587 971501	DANIIL NIKITIN	{"email": "daniil.nikitin1976@postgrespro.ru", "phone": "+70375699476"}
0005432583622	07A2E3	4902 885399	ANATOLIY MAKSIMOV	{"email": "maksimov.anatoliy.09061966@postgrespro.ru", "phone": "+70910820587"}
0005432583623	CE8F43	2777 273376	ELENA BORISOVA	{"email": "elenaborisova.14111969@postgrespro.ru", "phone": "+70712975559"}
0005432583624	6330D6	6739 759076	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov.05041978@postgrespro.ru", "phone": "+70268757742"}
0005432583625	576B0A	5647 208027	PAVEL GRIGOREV	{"phone": "+70330992607"}
0005432583626	576B0A	2092 723356	LYUBOV ILINA	{"phone": "+70960258442"}
0005432583627	D74BA2	2743 325101	EVGENIY ANTONOV	{"phone": "+70792422944"}
0005432583628	6ACC93	6754 767680	NIKOLAY MELNIKOV	{"phone": "+70632065387"}
0005432583629	6ACC93	2430 814066	OLEG SIDOROV	{"email": "o_sidorov061968@postgrespro.ru", "phone": "+70533010227"}
0005432583630	CEF1DF	2573 506397	STEPAN FEDOROV	{"phone": "+70035953995"}
0005432583631	CEF1DF	3456 673127	NADEZHDA NIKIFOROVA	{"phone": "+70857489150"}
0005432583632	476CDA	5535 400712	NADEZHDA NOVIKOVA	{"phone": "+70819806461"}
0005432583633	476CDA	8547 664251	VALERIY TIKHONOV	{"phone": "+70426346766"}
0005432583634	476CDA	2828 409754	PAVEL ANTONOV	{"email": "antonov-pavel.1980@postgrespro.ru", "phone": "+70193711370"}
0005432583635	7F1491	7002 312199	ALEKSANDR ILIN	{"phone": "+70967833962"}
0005432583636	4399D5	2789 067702	MIKHAIL GERASIMOV	{"phone": "+70549624334"}
0005432583637	4399D5	1110 567057	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr-26101962@postgrespro.ru", "phone": "+70373705685"}
0005432583638	9BB91C	4620 560296	TATYANA ORLOVA	{"phone": "+70682971652"}
0005432583639	9BB91C	4365 544853	ALEKSANDR ISAEV	{"email": "isaev-aleksandr-21081973@postgrespro.ru", "phone": "+70936446245"}
0005432583640	29265E	5887 385109	LIDIYA SOKOLOVA	{"phone": "+70915772597"}
0005432583641	C6517B	7330 260348	OLEG FROLOV	{"phone": "+70560115931"}
0005432583642	C6517B	6743 149080	VITALIY NAZAROV	{"phone": "+70662262849"}
0005432583643	3D1E46	6750 034336	SERGEY GORBUNOV	{"email": "sergey-gorbunov_27051966@postgrespro.ru", "phone": "+70494556143"}
0005432583644	3DC077	3517 630991	NIKOLAY NAUMOV	{"phone": "+70892540607"}
0005432583645	3DC077	8161 228540	YURIY DENISOV	{"email": "denisovy-1973@postgrespro.ru", "phone": "+70317396389"}
0005432583646	115E11	0028 765726	DANILA POPOV	{"email": "danila-popov.20071971@postgrespro.ru", "phone": "+70067837602"}
0005432583647	F6269A	3873 836923	SERGEY STEPANOV	{"email": "sergey_stepanov_111970@postgrespro.ru", "phone": "+70021929934"}
0005432583648	F6269A	1622 022198	OLEG MEDVEDEV	{"phone": "+70367651820"}
0005432583649	0F69D7	9125 704513	ALEKSEY PETROV	{"phone": "+70513441426"}
0005432583650	F5FD98	1735 239024	ALEKSEY ABRAMOV	{"email": "abramov.aleksey28061978@postgrespro.ru", "phone": "+70784165784"}
0005432583651	BF7237	0007 962647	EGOR KUZMIN	{"phone": "+70336502490"}
0005432583652	80C649	3047 147667	VLADIMIR MATVEEV	{"email": "v.matveev-081961@postgrespro.ru", "phone": "+70425544722"}
0005432583653	EB2F4B	4242 940368	KONSTANTIN SEMENOV	{"phone": "+70061013076"}
0005432583654	4D23AC	7103 912059	RUSLAN VOROBEV	{"phone": "+70220068539"}
0005432583655	4D23AC	4111 276775	RAISA DAVYDOVA	{"email": "davydova_r_16111975@postgrespro.ru", "phone": "+70617693815"}
0005432583656	4D23AC	8080 946462	PETR ALEKSEEV	{"phone": "+70072675454"}
0005432583657	266D39	4141 566982	VALENTINA EFIMOVA	{"phone": "+70206435419"}
0005432583658	4B1569	4172 809151	LILIYA MAKAROVA	{"phone": "+70060976948"}
0005432583659	4B1569	0194 152946	IRINA FEDOROVA	{"email": "fedorovairina.011979@postgrespro.ru", "phone": "+70398429240"}
0005432583660	4B1569	8439 296257	LYUBOV GORBUNOVA	{"email": "gorbunova_lyubov_1968@postgrespro.ru", "phone": "+70484632847"}
0005432583661	542CA7	3070 122709	ALENA TIMOFEEVA	{"phone": "+70201705029"}
0005432583662	E66F3E	2326 569284	VALENTINA ROMANOVA	{"phone": "+70149776687"}
0005432583663	E66F3E	3057 368844	VIKTOR KAZAKOV	{"phone": "+70093586396"}
0005432583664	D027DC	6675 601436	IRINA DENISOVA	{"email": "i.denisova-19051975@postgrespro.ru", "phone": "+70219769544"}
0005432583847	DB9564	6436 560343	ALMIRA IVANOVA	{"phone": "+70928921165"}
0005432583666	3A9EDF	5190 085260	VERA ZAKHAROVA	{"email": "vzakharova1991@postgrespro.ru", "phone": "+70543408009"}
0005432583667	44C4A7	3282 462424	SERGEY FOMIN	{"email": "fomin-sergey.04031975@postgrespro.ru", "phone": "+70753495244"}
0005432583668	9AE086	3682 951426	NIKITA FEDOTOV	{"phone": "+70437458807"}
0005432583669	E9FBE8	8613 607702	NINA EFREMOVA	{"phone": "+70411628089"}
0005432583670	E9FBE8	9214 252316	ULYANA PETROVA	{"email": "petrova_ulyana_011964@postgrespro.ru", "phone": "+70523032966"}
0005432583671	210346	1597 914229	GALINA MOROZOVA	{"email": "morozova.g29011972@postgrespro.ru", "phone": "+70756460889"}
0005432583672	0C3F5E	6905 447743	VALENTINA MAKSIMOVA	{"email": "maksimova.valentina1979@postgrespro.ru", "phone": "+70566616487"}
0005432583673	0C3F5E	3184 980769	VIKTOR OSIPOV	{"email": "osipov_viktor.1970@postgrespro.ru", "phone": "+70476563862"}
0005432583674	E06F15	6180 717996	EKATERINA BOGDANOVA	{"phone": "+70921691642"}
0005432583675	E06F15	3970 771409	IVAN NIKOLAEV	{"phone": "+70941767599"}
0005432583676	E06F15	9246 880957	VALERIYA KARPOVA	{"email": "karpova-v-1986@postgrespro.ru", "phone": "+70752664433"}
0005432583677	5D519A	7468 466408	RISHAT MIRONOV	{"email": "mironov.r_15081980@postgrespro.ru", "phone": "+70703998589"}
0005432583678	DEEF7C	0756 576825	FATIMA NIKOLAEVA	{"phone": "+70657552070"}
0005432583679	DEEF7C	3988 526226	ALEKSANDR NIKOLAEV	{"phone": "+70953172691"}
0005432583680	DEEF7C	1117 552413	VIKTOR MOROZOV	{"phone": "+70550043550"}
0005432583681	2DCA6E	9810 466863	ALEKSEY AFANASEV	{"phone": "+70393726959"}
0005432583682	2DCA6E	3976 126625	VLADISLAV ALEKSANDROV	{"email": "vladislav-aleksandrov_17071977@postgrespro.ru", "phone": "+70721318566"}
0005432583683	59E97A	7929 885171	SVETLANA CHERNOVA	{"email": "svetlana_chernova17011970@postgrespro.ru", "phone": "+70309994799"}
0005432583684	CB083C	8752 581547	ALEKSANDR NIKOLAEV	{"phone": "+70923815357"}
0005432583685	CB083C	7740 158861	VLADISLAV KARPOV	{"email": "karpovvladislav.29031974@postgrespro.ru", "phone": "+70595853719"}
0005432583686	0259E6	6491 378924	VLADIMIR FROLOV	{"phone": "+70586967931"}
0005432583687	0259E6	3583 747707	ALEKSANDRA MAKAROVA	{"phone": "+70170412183"}
0005432583688	C0D3EC	4485 463594	NIKITA SOKOLOV	{"phone": "+70689742299"}
0005432583689	5CC571	0038 331386	YULIYA MATVEEVA	{"email": "matveeva.y_081964@postgrespro.ru", "phone": "+70689767175"}
0005432583690	42F5CF	0060 060367	ELENA STEPANOVA	{"email": "e.stepanova041994@postgrespro.ru", "phone": "+70253269142"}
0005432583691	42F5CF	7365 038412	RAFIK SEMENOV	{"email": "semenov-r-121976@postgrespro.ru", "phone": "+70037057197"}
0005432583692	31B7E6	1309 046993	VARVARA MALYSHEVA	{"email": "malysheva_varvara121972@postgrespro.ru", "phone": "+70510643427"}
0005432583693	F5D940	8954 284701	NIKOLAY MAKAROV	{"phone": "+70243853661"}
0005432583694	89B2C1	6306 712457	TAISIYA NIKOLAEVA	{"phone": "+70514780655"}
0005432583695	D7DA84	8276 686379	SERGEY GUSEV	{"email": "s.gusev-011979@postgrespro.ru", "phone": "+70167134391"}
0005432583696	A9AA8B	4711 314885	VALERIY ANTONOV	{"email": "antonov_v.051968@postgrespro.ru", "phone": "+70080018272"}
0005432583697	A9AA8B	1679 885673	ALEKSEY BELOV	{"phone": "+70058727303"}
0005432583698	DD3D77	2552 968151	MARIYA POLYAKOVA	{"phone": "+70350952306"}
0005432583699	9F3E5E	2050 138191	POLINA KISELEVA	{"phone": "+70574369466"}
0005432583700	9F3E5E	8200 602536	EVGENIY KUZNECOV	{"email": "kuznecov.e12081968@postgrespro.ru", "phone": "+70435895161"}
0005432583701	9F3E5E	8956 240542	DIANA ZAKHAROVA	{"email": "dianazakharova_101974@postgrespro.ru", "phone": "+70767573454"}
0005432583702	D4B495	3441 958754	IRINA SMIRNOVA	{"phone": "+70131135868"}
0005432583703	916F5A	7236 762502	ANNA PAVLOVA	{"phone": "+70483528576"}
0005432583704	916F5A	5739 436977	NINA ANDREEVA	{"phone": "+70097253916"}
0005432583705	1998A5	9283 517897	SVETLANA NIKOLAEVA	{"phone": "+70178531775"}
0005432583706	8904B6	2162 724965	TATYANA PAVLOVA	{"phone": "+70004206300"}
0005432583707	71EE31	4740 042702	SERGEY NIKOLAEV	{"email": "sergey-nikolaev-061964@postgrespro.ru", "phone": "+70469391176"}
0005432583708	9BACAC	1182 095055	DARYA VOLKOVA	{"phone": "+70948995529"}
0005432583709	9BACAC	6920 858983	MIKHAIL VASILEV	{"phone": "+70111484844"}
0005432583710	6D9603	0926 505774	RIFAT KUDRYASHOV	{"email": "rifat_kudryashov.1978@postgrespro.ru", "phone": "+70225191655"}
0005432583711	34C962	4348 597028	SERGEY VOROBEV	{"email": "vorobev_s-31011974@postgrespro.ru", "phone": "+70770991925"}
0005432583713	A84E03	9202 980098	ELENA EFIMOVA	{"phone": "+70746018916"}
0005432583714	4ECCD7	6747 248316	ANDREY MOROZOV	{"phone": "+70682519341"}
0005432583715	C129FE	0455 419757	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev-07011973@postgrespro.ru", "phone": "+70720296617"}
0005432583716	D588E5	6711 721693	NIKOLAY ZHUKOV	{"phone": "+70026345932"}
0005432583717	BAD4DB	5744 762872	YURIY SMIRNOV	{"email": "smirnov.y1981@postgrespro.ru", "phone": "+70710101137"}
0005432583718	9380C3	9627 325174	MARIYA VASILEVA	{"phone": "+70718712493"}
0005432583719	9380C3	4661 047271	VALENTINA MALYSHEVA	{"email": "v_malysheva1971@postgrespro.ru", "phone": "+70486667060"}
0005432583720	E7A2D5	6385 625658	ELMIRA KUZNECOVA	{"email": "kuznecova_elmira021992@postgrespro.ru", "phone": "+70539493716"}
0005432583721	E7A2D5	9564 552044	MARGARITA VLASOVA	{"email": "margarita-vlasova081973@postgrespro.ru", "phone": "+70085889016"}
0005432583722	A6A585	1461 313107	DENIS SAVELEV	{"email": "denis-savelev-04051966@postgrespro.ru", "phone": "+70677859862"}
0005432583723	A6A585	7301 090078	MIKHAIL SHEVCHENKO	{"phone": "+70135248107"}
0005432583724	167774	6173 927162	VLADIMIR BELOV	{"email": "belov_vladimir_19081976@postgrespro.ru", "phone": "+70186810827"}
0005432583725	84C9D9	7449 914562	LEV KRASNOV	{"phone": "+70778806222"}
0005432583726	84C9D9	3086 454393	VERA POLYAKOVA	{"phone": "+70777618222"}
0005432583727	84C9D9	2309 798245	OLGA ANISIMOVA	{"email": "olga-anisimova-081971@postgrespro.ru", "phone": "+70157523818"}
0005432583729	89D3B1	2833 595832	TATYANA ILINA	{"email": "tilina_1971@postgrespro.ru", "phone": "+70491618717"}
0005432583730	E4A17A	8865 960669	TATYANA DMITRIEVA	{"email": "dmitrieva_tatyana_06091967@postgrespro.ru", "phone": "+70521855968"}
0005432583731	E4A17A	9611 582171	ALEKSEY EGOROV	{"email": "aleksey.egorov_091977@postgrespro.ru", "phone": "+70291910212"}
0005432583732	2E11D0	1872 549988	ELENA TROFIMOVA	{"email": "trofimova.elena1968@postgrespro.ru", "phone": "+70664413176"}
0005432583733	86A2E8	6557 796278	GALINA DMITRIEVA	{"phone": "+70839391404"}
0005432583734	C569C7	5040 483871	ZHANNA DMITRIEVA	{"phone": "+70286105895"}
0005432583735	C569C7	6610 513227	ALEKSEY MOROZOV	{"email": "aleksey_morozov15051969@postgrespro.ru", "phone": "+70369352434"}
0005432583736	092DC2	4994 069391	ANATOLIY NAZAROV	{"email": "anatoliy_nazarov1976@postgrespro.ru", "phone": "+70605402940"}
0005432583737	19C642	6800 786163	ALEKSEY PAVLOV	{"email": "pavlov_aleksey.1983@postgrespro.ru", "phone": "+70488203480"}
0005432583738	FEAA88	5280 372371	EKATERINA FILIPPOVA	{"phone": "+70549891183"}
0005432583739	11C45F	6597 102894	MARINA KUZNECOVA	{"email": "marina-kuznecova-051981@postgrespro.ru", "phone": "+70283109662"}
0005432583740	11C45F	7625 995327	ALEKSANDR GUSEV	{"email": "gusev_a_29071970@postgrespro.ru", "phone": "+70539241288"}
0005432583741	2BF1E1	2353 417801	NIKOLAY KUZNECOV	{"phone": "+70759501638"}
0005432583742	266377	4218 765201	VYACHESLAV PETROV	{"phone": "+70845780364"}
0005432583743	266377	6070 528947	TATYANA EFIMOVA	{"phone": "+70945655330"}
0005432583744	266377	7207 444756	ANTONINA ROMANOVA	{"email": "antoninaromanova.1966@postgrespro.ru", "phone": "+70542714795"}
0005432583745	BCB664	1040 839475	GALINA VASILEVA	{"email": "g.vasileva1981@postgrespro.ru", "phone": "+70740329632"}
0005432583746	28D786	0307 658702	NINA ZAYCEVA	{"email": "zayceva.nina16041975@postgrespro.ru", "phone": "+70551740857"}
0005432583747	F94C38	3763 783486	VLADIMIR ALEKSEEV	{"phone": "+70808422730"}
0005432583748	C9F2ED	6883 857860	ELENA ZHURAVLEVA	{"email": "elena-zhuravleva-081974@postgrespro.ru", "phone": "+70271622337"}
0005432583749	C9F2ED	7521 152093	VIKTOR NAUMOV	{"email": "v_naumov.24061966@postgrespro.ru", "phone": "+70612775442"}
0005432583750	36C5BA	4887 080760	NADEZHDA AFANASEVA	{"email": "afanaseva-n071973@postgrespro.ru", "phone": "+70396981571"}
0005432583751	78D2E1	6918 223819	SVETLANA KAZAKOVA	{"email": "kazakova-s_1971@postgrespro.ru", "phone": "+70473283452"}
0005432583752	A7131E	9681 700057	SERGEY ABRAMOV	{"email": "abramov-s_1958@postgrespro.ru", "phone": "+70212459053"}
0005432583753	A7131E	8976 496163	ALIYA CHERNOVA	{"phone": "+70805146454"}
0005432583754	7E1CEC	7693 882529	ANATOLIY KUZNECOV	{"email": "a.kuznecov-27101977@postgrespro.ru", "phone": "+70990829738"}
0005432583755	676C91	8235 863105	ANATOLIY KUZNECOV	{"phone": "+70369217977"}
0005432583756	5D6E5D	8334 097169	MARIYA ARKHIPOVA	{"phone": "+70216714850"}
0005432583757	5D6E5D	6810 078274	SERGEY IVANOV	{"phone": "+70294118926"}
0005432583758	104D1D	6462 431649	ILYA KOZLOV	{"email": "kozlovi-10051967@postgrespro.ru", "phone": "+70770183407"}
0005432583759	83A687	4354 136475	LEONID NOVIKOV	{"email": "l_novikov_1969@postgrespro.ru", "phone": "+70158782148"}
0005432583760	F9F4DA	2417 516838	LYUDMILA DANILOVA	{"phone": "+70873192721"}
0005432583761	F9F4DA	8329 223271	ALEKSANDRA TIMOFEEVA	{"phone": "+70267500184"}
0005432583762	42628E	3288 149563	SERGEY SIDOROV	{"phone": "+70896708680"}
0005432583763	1CD92E	4748 465938	SVETLANA KUZNECOVA	{"email": "kuznecova.s-021968@postgrespro.ru", "phone": "+70719241193"}
0005432583764	7670D0	9716 237592	OKSANA NAUMOVA	{"email": "naumova_oksana1978@postgrespro.ru", "phone": "+70729598891"}
0005432583765	0A8E5D	1385 086662	ARTEM KISELEV	{"email": "kiselevartem-1954@postgrespro.ru", "phone": "+70619617759"}
0005432583766	56F77A	7897 669855	VLADIMIR ZAKHAROV	{"phone": "+70694994750"}
0005432583767	72F3AA	9174 523718	IRINA VOROBEVA	{"phone": "+70864974849"}
0005432583935	1D8E3E	5098 900511	KIRA ILINA	{"phone": "+70951880030"}
0005432583768	200DF4	0853 426941	VASILIY AFANASEV	{"email": "vasiliy.afanasev.071979@postgrespro.ru", "phone": "+70137948271"}
0005432583769	D01E0F	4704 491412	SERGEY ZAKHAROV	{"email": "zakharov-s081957@postgrespro.ru", "phone": "+70101616052"}
0005432583770	28D4A7	8737 827312	DMITRIY IVANOV	{"phone": "+70975810599"}
0005432583771	3FF1BA	4281 537639	IVAN SERGEEV	{"phone": "+70712169019"}
0005432583772	7983A3	6881 763926	DMITRIY IVANOV	{"email": "divanov051974@postgrespro.ru", "phone": "+70221764055"}
0005432583773	16B04C	6887 914692	EKATERINA TIMOFEEVA	{"email": "etimofeeva-1971@postgrespro.ru", "phone": "+70599113045"}
0005432583774	DFE72D	1253 472482	ANTON MELNIKOV	{"phone": "+70299459036"}
0005432583775	BE38F4	5765 703026	LARISA LUKYANOVA	{"phone": "+70321399205"}
0005432583776	BE38F4	9385 157647	IVAN KISELEV	{"email": "kiselev_i_1973@postgrespro.ru", "phone": "+70031132444"}
0005432583777	BE38F4	6054 668832	VLADIMIR DAVYDOV	{"email": "vladimir_davydov-18071977@postgrespro.ru", "phone": "+70295017689"}
0005432583778	BE4F99	5783 142795	AYRAT MELNIKOV	{"phone": "+70200613664"}
0005432583779	BE4F99	5387 865251	VIKTOR STEPANOV	{"phone": "+70291254038"}
0005432583780	D6A89A	5804 523411	STANISLAV KONOVALOV	{"email": "konovalov_stanislav_101966@postgrespro.ru", "phone": "+70829634174"}
0005432583781	5AE829	5484 539344	VLADIMIR SOLOVEV	{"phone": "+70894364989"}
0005432583782	5AE829	5024 582948	EVGENIY IVANOV	{"phone": "+70759052809"}
0005432583783	5AE829	0658 170461	IVAN IVANOV	{"phone": "+70448995003"}
0005432583784	EC799E	4739 373243	NATALYA KUZNECOVA	{"email": "natalya.kuznecova-13111974@postgrespro.ru", "phone": "+70633242399"}
0005432583785	BF2624	8248 117683	ALEKSEY OSIPOV	{"phone": "+70146478983"}
0005432583786	BF2624	6979 236696	ZINAIDA POPOVA	{"phone": "+70303689570"}
0005432583787	AF52A0	9992 844223	LYUBOV SIDOROVA	{"email": "sidoroval1957@postgrespro.ru", "phone": "+70800828353"}
0005432583788	FDA05A	5629 017629	SERGEY DMITRIEV	{"email": "s_dmitriev-121970@postgrespro.ru", "phone": "+70091229168"}
0005432583789	E78901	7586 314447	DMITRIY SMIRNOV	{"email": "dmitriy_smirnov_11081968@postgrespro.ru", "phone": "+70314372898"}
0005432583790	E78901	0064 236313	GALINA MAKAROVA	{"phone": "+70677310414"}
0005432583791	0DA613	4304 960150	ALLA ZOTOVA	{"email": "zotova.a-021960@postgrespro.ru", "phone": "+70204655102"}
0005432583792	0DA613	1082 195049	TATYANA OSIPOVA	{"email": "tatyana.osipova_091969@postgrespro.ru", "phone": "+70312262449"}
0005432583793	633DF1	9492 489795	EVGENIYA ZAKHAROVA	{"phone": "+70212922127"}
0005432583794	633DF1	3753 870954	SERGEY YAKOVLEV	{"email": "yakovlevs091962@postgrespro.ru", "phone": "+70391170990"}
0005432583795	8A1D7C	3538 712929	NINA KUZNECOVA	{"email": "kuznecova-nina-01071968@postgrespro.ru", "phone": "+70451843063"}
0005432583796	8A1D7C	9101 297602	POLINA KOZLOVA	{"email": "kozlova-p.081965@postgrespro.ru", "phone": "+70925459546"}
0005432583797	68634F	4299 332596	GALINA RODIONOVA	{"email": "rodionova_galina.16071975@postgrespro.ru", "phone": "+70970797068"}
0005432583798	0603E0	6659 339317	DMITRIY BONDARENKO	{"email": "dmitriy_bondarenko-021977@postgrespro.ru", "phone": "+70425561799"}
0005432583799	0603E0	5020 186958	IRINA BOGDANOVA	{"email": "irina-bogdanova_1977@postgrespro.ru", "phone": "+70391035331"}
0005432583800	0603E0	2247 790001	VITALIY SHEVCHENKO	{"email": "shevchenkovitaliy.09041977@postgrespro.ru", "phone": "+70110879093"}
0005432583801	BB8613	2932 544835	MAKSIM RODIONOV	{"email": "rodionov-maksim041973@postgrespro.ru", "phone": "+70638562847"}
0005432583802	093BF3	2442 127057	ALEKSEY KOROLEV	{"email": "aleksey_korolev.21021973@postgrespro.ru", "phone": "+70908231873"}
0005432583803	093BF3	5422 957481	MARINA ALEKSEEVA	{"email": "m_alekseeva07021975@postgrespro.ru", "phone": "+70365397525"}
0005432583804	9C2D5C	4471 087189	MARGARITA ALEKSEEVA	{"email": "alekseeva-m.121963@postgrespro.ru", "phone": "+70041917325"}
0005432583805	9C2D5C	5411 647842	GALINA TROFIMOVA	{"email": "trofimova.galina-03041974@postgrespro.ru", "phone": "+70109901315"}
0005432583806	9C2D5C	1921 614463	SERGEY KUDRYASHOV	{"phone": "+70169249549"}
0005432583807	F6B741	5670 915548	TATYANA PETROVA	{"phone": "+70421511477"}
0005432583808	EE0193	1434 560288	VALENTIN SMIRNOV	{"phone": "+70714346082"}
0005432583809	95B776	8174 552117	VALENTINA MAKAROVA	{"phone": "+70359232126"}
0005432583810	68C338	1642 299713	SERGEY NAUMOV	{"email": "s-naumov-28101973@postgrespro.ru", "phone": "+70732546322"}
0005432583811	6660C6	9646 892814	SERGEY KISELEV	{"email": "sergey_kiselev.1973@postgrespro.ru", "phone": "+70002376700"}
0005432583812	26AACA	2854 795497	KSENIYA IVANOVA	{"email": "ivanovakseniya-10081968@postgrespro.ru", "phone": "+70623423024"}
0005432583813	E186C2	6591 024135	IVAN YAKOVLEV	{"email": "yakovlev-ivan_1966@postgrespro.ru", "phone": "+70054158739"}
0005432583814	85639B	0918 861883	ALEKSANDR NIKOLAEV	{"phone": "+70575548758"}
0005432583815	85639B	6899 034863	YULIYA NAUMOVA	{"phone": "+70188013917"}
0005432583816	85639B	0304 960503	VLADIMIR BONDARENKO	{"phone": "+70940273094"}
0005432583817	DFFB36	0038 846701	TATYANA ILINA	{"phone": "+70755351712"}
0005432583818	DFFB36	4003 249081	SVETLANA SOKOLOVA	{"phone": "+70558754986"}
0005432583819	FBE581	1583 153609	DARYA KOVALEVA	{"phone": "+70121916487"}
0005432583820	3AEEE2	0156 124279	DMITRIY CHERNOV	{"phone": "+70123524234"}
0005432583821	3AEEE2	0453 422340	OLGA BOGDANOVA	{"phone": "+70023842908"}
0005432583822	CF428D	4813 283253	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov.24021963@postgrespro.ru", "phone": "+70120834669"}
0005432583823	CF428D	0282 447674	DENIS NOVIKOV	{"email": "denisnovikov_22071971@postgrespro.ru", "phone": "+70026675529"}
0005432583824	EAA4A1	2428 702783	VIKTOR KOROLEV	{"phone": "+70226291813"}
0005432583825	FF0B97	0669 086341	ARTEM STEPANOV	{"phone": "+70264779581"}
0005432583826	FF0B97	0282 770145	IRINA MELNIKOVA	{"email": "melnikova.irina-14021965@postgrespro.ru", "phone": "+70898430976"}
0005432583827	7452C8	4064 753878	IGOR ISAEV	{"email": "i-isaev_111969@postgrespro.ru", "phone": "+70111143298"}
0005432583828	6E11CF	6808 012128	ALINA PETROVA	{"email": "petrova.alina-19071970@postgrespro.ru", "phone": "+70921593358"}
0005432583829	6E11CF	6475 976257	MARIYA MAKAROVA	{"email": "makarova.m_051978@postgrespro.ru", "phone": "+70600046290"}
0005432583830	C68264	9262 380367	NADEZHDA POPOVA	{"email": "n-popova.1968@postgrespro.ru", "phone": "+70301155745"}
0005432583831	3F575E	0474 888773	ALEKSANDR KARPOV	{"phone": "+70996395724"}
0005432583832	3F575E	3536 916429	EKATERINA POPOVA	{"email": "e.popova_1976@postgrespro.ru", "phone": "+70006370139"}
0005432583833	949D31	8232 425089	TATYANA KOROLEVA	{"email": "korolevat_09091966@postgrespro.ru", "phone": "+70420454494"}
0005432583834	6C82F8	9969 626808	VIKTOR NAZAROV	{"email": "nazarov.v-031966@postgrespro.ru", "phone": "+70568158278"}
0005432583835	266156	3794 253358	YURIY DENISOV	{"email": "y-denisov1982@postgrespro.ru", "phone": "+70931529981"}
0005432583836	266156	3850 102493	DMITRIY MARTYNOV	{"phone": "+70440493195"}
0005432583837	266156	6471 509963	NIKOLAY MOROZOV	{"phone": "+70350848479"}
0005432583838	C9C7D1	7226 290640	OLGA NESTEROVA	{"phone": "+70004521782"}
0005432583839	C9C7D1	5532 531528	VALENTINA ILINA	{"phone": "+70331733268"}
0005432583840	E9DA5E	0208 648918	ALEKSANDR NIKOLAEV	{"phone": "+70783691566"}
0005432583841	8EC004	1692 048861	LIDIYA FILATOVA	{"email": "l.filatova.081967@postgrespro.ru", "phone": "+70253905358"}
0005432583842	571E13	3631 470849	ANASTASIYA MAKSIMOVA	{"email": "maksimova_anastasiya13031970@postgrespro.ru", "phone": "+70722810468"}
0005432583843	B329EA	8664 288412	ALEKSANDR PAVLOV	{"phone": "+70211111031"}
0005432583844	D57933	0984 695520	NATALYA MALYSHEVA	{"phone": "+70269328639"}
0005432583845	D57933	3791 392868	ALEKSANDR PETROV	{"email": "aleksandrpetrov-1961@postgrespro.ru", "phone": "+70676358217"}
0005432583846	DB9564	0973 382206	MARIYA GAVRILOVA	{"phone": "+70316325971"}
0005432583848	DB9564	6623 438226	SERGEY DMITRIEV	{"email": "sdmitriev25021980@postgrespro.ru", "phone": "+70268165921"}
0005432583849	D18341	1623 279919	OKSANA SOLOVEVA	{"email": "oksana_soloveva.06071976@postgrespro.ru", "phone": "+70382119061"}
0005432583850	D18341	8798 453071	EVGENIY DENISOV	{"email": "evgeniy_denisov.081968@postgrespro.ru", "phone": "+70412003585"}
0005432583851	380DB3	8383 160345	EVGENIY FROLOV	{"email": "frolov.e-09011965@postgrespro.ru", "phone": "+70999378816"}
0005432583852	5BEE92	4632 581885	DIANA ALEKSANDROVA	{"phone": "+70704942268"}
0005432583853	22DE42	0224 724062	VYACHESLAV MELNIKOV	{"phone": "+70090577421"}
0005432583854	22DE42	4308 567173	YANA KUZNECOVA	{"email": "kuznecova-yana_1952@postgrespro.ru", "phone": "+70841872638"}
0005432583855	22DE42	0051 004094	TATYANA BORISOVA	{"phone": "+70536680979"}
0005432583856	DCF824	4337 111909	RUSTAM FILIPPOV	{"email": "rustam.filippov_10111964@postgrespro.ru", "phone": "+70163085263"}
0005432583857	39F3F6	9019 720748	OLGA KUZNECOVA	{"email": "kuznecovaolga_091984@postgrespro.ru", "phone": "+70010677547"}
0005432583858	39F3F6	1861 675602	DMITRIY PETROV	{"phone": "+70247817859"}
0005432583859	8D8BAF	5834 550971	ROZA KOROLEVA	{"phone": "+70496030466"}
0005432583860	8D7B6B	0108 715245	MIKHAIL GORBUNOV	{"phone": "+70110050454"}
0005432583861	60E97C	7440 230107	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana-01091980@postgrespro.ru", "phone": "+70049486748"}
0005432583862	60E97C	6802 181642	OLGA POLYAKOVA	{"email": "olgapolyakova-1968@postgrespro.ru", "phone": "+70664026051"}
0005432583863	032D3E	6237 055381	LIDIYA GUSEVA	{"email": "l-guseva-11101975@postgrespro.ru", "phone": "+70430602089"}
0005432583864	0439C8	8893 372071	NINA BORISOVA	{"email": "n-borisova061963@postgrespro.ru", "phone": "+70531334294"}
0005432583865	BC1DC1	9560 795536	ALEKSANDR SEMENOV	{"phone": "+70816193138"}
0005432583866	901671	7241 315303	SERGEY FOMIN	{"phone": "+70185147907"}
0005432583867	BC0049	3390 322807	IGOR SOKOLOV	{"phone": "+70777091630"}
0005432583868	2FB188	7246 319697	MIKHAIL RODIONOV	{"phone": "+70362550298"}
0005432583869	2FB188	2446 179200	EGOR NIKOLAEV	{"phone": "+70404294740"}
0005432583870	A15835	7912 557889	DENIS KUZMIN	{"email": "dkuzmin.03041976@postgrespro.ru", "phone": "+70196913090"}
0005432583871	74A7FE	8454 087275	ANATOLIY SOROKIN	{"email": "a_sorokin.04051978@postgrespro.ru", "phone": "+70274257891"}
0005432583872	74A7FE	3765 647088	SVETLANA ROMANOVA	{"phone": "+70859022820"}
0005432583873	FB03BA	2717 166040	LIDIYA KOZLOVA	{"email": "l_kozlova1975@postgrespro.ru", "phone": "+70304251255"}
0005432583874	1C2A03	4975 852303	NATALYA MALYSHEVA	{"email": "malysheva-n031974@postgrespro.ru", "phone": "+70688848838"}
0005432583875	1C2A03	6270 584859	VYACHESLAV GERASIMOV	{"email": "gerasimovv_1982@postgrespro.ru", "phone": "+70315971945"}
0005432583876	27E488	1661 767858	VALENTINA MEDVEDEVA	{"email": "valentina_medvedeva-04061966@postgrespro.ru", "phone": "+70274247940"}
0005432583877	9955D5	1001 221056	OLGA ANTONOVA	{"email": "antonova-olga.1974@postgrespro.ru", "phone": "+70591717697"}
0005432583878	278F49	9602 343088	VYACHESLAV ALEKSEEV	{"phone": "+70175700216"}
0005432583879	988026	5664 190448	ANTONINA KOROLEVA	{"email": "antonina.koroleva-111970@postgrespro.ru", "phone": "+70795630072"}
0005432583880	988026	8914 964720	YURIY RODIONOV	{"phone": "+70065639069"}
0005432583881	F06E4F	5869 059993	YULIYA DAVYDOVA	{"email": "y_davydova1978@postgrespro.ru", "phone": "+70776244139"}
0005432583882	1FFA99	2417 880356	SERGEY KOZLOV	{"email": "s.kozlov_041974@postgrespro.ru", "phone": "+70785210158"}
0005432583883	4247AD	9343 057078	ROMAN MAKAROV	{"email": "makarov-r1976@postgrespro.ru", "phone": "+70217681434"}
0005432583884	6EBC34	0346 740539	EVGENIY SIDOROV	{"email": "sidorov.evgeniy.06061963@postgrespro.ru", "phone": "+70493321368"}
0005432583885	C26DCF	8253 127099	NATALYA MASLOVA	{"email": "maslovan031968@postgrespro.ru", "phone": "+70199786597"}
0005432583886	C26DCF	4421 984625	ANNA POTAPOVA	{"email": "potapovaa_1979@postgrespro.ru", "phone": "+70940239782"}
0005432583887	5DF62B	5689 547545	SERGEY MIKHAYLOV	{"phone": "+70720372500"}
0005432583888	5DF62B	4032 281981	MARGARITA ZAKHAROVA	{"phone": "+70849089488"}
0005432583889	DC90CA	8259 533358	TATYANA LEBEDEVA	{"phone": "+70226098935"}
0005432583890	DC90CA	9413 229662	TAMARA PETROVA	{"email": "tamarapetrova-071972@postgrespro.ru", "phone": "+70660020608"}
0005432583891	E37262	5494 743013	SERGEY KULIKOV	{"email": "s-kulikov.06031967@postgrespro.ru", "phone": "+70283940281"}
0005432583892	E37262	4888 403931	PAVEL SOKOLOV	{"email": "sokolov.p_21101971@postgrespro.ru", "phone": "+70469391563"}
0005432583893	F951F7	8236 774424	ULYANA EFIMOVA	{"email": "efimovaulyana.23011968@postgrespro.ru", "phone": "+70426019843"}
0005432583894	47EFF2	7133 328010	IRINA MATVEEVA	{"phone": "+70151424644"}
0005432583895	85EE20	0718 034842	ALEKSANDR GUSEV	{"email": "gusev.a04121974@postgrespro.ru", "phone": "+70006574382"}
0005432583896	85EE20	6029 923149	VADIM BELOV	{"phone": "+70202888455"}
0005432583897	9B525B	7259 295940	DMITRIY KARPOV	{"email": "d-karpov-1984@postgrespro.ru", "phone": "+70226411640"}
0005432583898	938A77	8746 143501	MARINA MALYSHEVA	{"phone": "+70242479364"}
0005432583899	F698F0	4225 231308	ALEKSANDR GUSEV	{"phone": "+70287219982"}
0005432583900	416400	1997 812504	ANTONINA SMIRNOVA	{"phone": "+70676530127"}
0005432583901	BAEE23	7690 771237	SERGEY SIDOROV	{"phone": "+70890568448"}
0005432583902	E853A9	7665 252611	SERGEY MOISEEV	{"email": "moiseevsergey_29041969@postgrespro.ru", "phone": "+70830963866"}
0005432583903	3D6D38	7983 843431	ALEKSEY FEDOROV	{"email": "aleksey_fedorov-1965@postgrespro.ru", "phone": "+70013583104"}
0005432583904	679D22	1447 428756	ALEKSANDR MOISEEV	{"email": "moiseev_aleksandr01111966@postgrespro.ru", "phone": "+70668128930"}
0005432583905	679D22	8825 898179	YULIYA NAZAROVA	{"phone": "+70093984447"}
0005432583906	F10384	7729 508367	EVGENIY ZHUKOV	{"email": "e-zhukov-1976@postgrespro.ru", "phone": "+70695898124"}
0005432583907	44422C	0216 935260	DARYA POPOVA	{"phone": "+70537768142"}
0005432583908	19B14F	6521 710114	KIRILL KOROLEV	{"phone": "+70994437817"}
0005432583909	8A46D4	4939 870905	VYACHESLAV ANDREEV	{"phone": "+70485165378"}
0005432583910	048213	3817 932453	VIKTOR BORISOV	{"phone": "+70796731729"}
0005432583911	048213	9365 783012	SOFYA KOROLEVA	{"email": "koroleva.s30031968@postgrespro.ru", "phone": "+70244949512"}
0005432583912	048213	9816 674609	VLADIMIR IVANOV	{"email": "vladimir-ivanov-031978@postgrespro.ru", "phone": "+70793523764"}
0005432583913	5E7759	9947 076317	SERGEY SOROKIN	{"phone": "+70130852486"}
0005432583914	0CB323	8269 349444	VERA FADEEVA	{"phone": "+70400680185"}
0005432583915	CA7EAB	2931 581993	NATALYA EGOROVA	{"email": "egorovanatalya-13051969@postgrespro.ru", "phone": "+70064312781"}
0005432583916	8AE85C	0118 116165	VALERIY KUZMIN	{"email": "v_kuzmin.11031972@postgrespro.ru", "phone": "+70727710307"}
0005432583917	8AE85C	8534 399975	SERGEY ABRAMOV	{"phone": "+70931346135"}
0005432583918	12E735	0128 605493	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova_l1968@postgrespro.ru", "phone": "+70914221218"}
0005432583919	12E735	2048 869223	NIKOLAY IVANOV	{"email": "nikolay.ivanov-011983@postgrespro.ru", "phone": "+70366720264"}
0005432583920	17F76C	1041 137966	NATALYA NIKITINA	{"email": "nnikitina_18021966@postgrespro.ru", "phone": "+70126970218"}
0005432583921	45AF76	6304 970624	VASILIY IVANOV	{"phone": "+70766360041"}
0005432583922	B541E6	8956 998272	NATALYA VOLKOVA	{"phone": "+70512699992"}
0005432583923	5BB01C	1832 970344	NIKOLAY KONOVALOV	{"email": "nkonovalov_02061971@postgrespro.ru", "phone": "+70059352698"}
0005432583924	96753E	9157 330990	MAKSIM MELNIKOV	{"email": "mmelnikov_061964@postgrespro.ru", "phone": "+70014917383"}
0005432583925	96753E	7825 415826	MAKSIM VASILEV	{"phone": "+70234031612"}
0005432583926	FFB463	6068 369827	ALEKSANDR ZHUKOV	{"email": "a_zhukov_08071957@postgrespro.ru", "phone": "+70857130970"}
0005432583927	FFB463	3478 284560	ANASTASIYA IVANOVA	{"phone": "+70433887953"}
0005432583928	FFB463	2999 522137	LILIYA GERASIMOVA	{"phone": "+70411027602"}
0005432583929	96152F	4629 879650	SVETLANA NOVIKOVA	{"email": "s.novikova031964@postgrespro.ru", "phone": "+70194373015"}
0005432583930	EE3670	8852 174442	ALEKSANDR MELNIKOV	{"phone": "+70072444301"}
0005432583931	487FAA	1793 257772	EVGENIY BELOV	{"email": "e_belov12111975@postgrespro.ru", "phone": "+70637409389"}
0005432583932	75DF47	2954 565651	LYUDMILA PAVLOVA	{"email": "lpavlova.071967@postgrespro.ru", "phone": "+70614297304"}
0005432583933	A95DFD	3371 586240	ALEKSEY MIKHAYLOV	{"phone": "+70403475999"}
0005432583934	A95DFD	8741 322258	SOFYA EGOROVA	{"email": "egorova_sofya-1976@postgrespro.ru", "phone": "+70890583832"}
0005432583936	1D8E3E	8076 922893	SERGEY VOLKOV	{"email": "volkov_sergey_071980@postgrespro.ru", "phone": "+70091833159"}
0005432583937	CD0789	9518 157423	MAKSIM IVANOV	{"phone": "+70968100800"}
0005432583938	60CA0A	1708 586303	NATALIYA GAVRILOVA	{"phone": "+70860534336"}
0005432583939	9A7007	7409 401936	NADEZHDA ALEKSANDROVA	{"email": "nadezhda-aleksandrova.1966@postgrespro.ru", "phone": "+70868430233"}
0005432583940	9A7007	3953 880447	TATYANA ABRAMOVA	{"phone": "+70458425836"}
0005432583941	F03D19	1485 514523	VALENTINA MEDVEDEVA	{"email": "medvedeva_v.19011983@postgrespro.ru", "phone": "+70679898834"}
0005432583942	F03D19	4283 616923	VALERIY IVANOV	{"email": "valeriy_ivanov_22041967@postgrespro.ru", "phone": "+70777142099"}
0005432583943	C1F390	1140 308028	ALEKSANDR ZHURAVLEV	{"email": "a.zhuravlev.091973@postgrespro.ru", "phone": "+70156039847"}
0005432583944	640AC1	7435 250901	EVGENIYA FILATOVA	{"phone": "+70146148599"}
0005432583945	1E430F	7004 500390	NAIL SEMENOV	{"email": "nail-semenov.071968@postgrespro.ru", "phone": "+70379187834"}
0005432583946	B81634	1656 775208	GALINA NIKOLAEVA	{"phone": "+70348308332"}
0005432583947	B81634	4365 004865	LYUDMILA KULIKOVA	{"email": "kulikova.lyudmila.051976@postgrespro.ru", "phone": "+70235378627"}
0005432583948	B81634	6828 491339	EKATERINA ARKHIPOVA	{"email": "earkhipova24031964@postgrespro.ru", "phone": "+70677897465"}
0005432583949	61D010	2570 820232	ALEKSANDR VOLKOV	{"phone": "+70382338995"}
0005432583950	61D010	4290 386472	ANDREY NIKITIN	{"phone": "+70956145896"}
0005432583951	D34E06	2127 943467	VLADISLAV NOVIKOV	{"email": "novikovvladislav.091968@postgrespro.ru", "phone": "+70036904028"}
0005432583952	4DEF00	5265 186778	LYUBOV KOROLEVA	{"email": "koroleva.l_051967@postgrespro.ru", "phone": "+70245321401"}
0005432583953	6D0DF3	7015 147203	POLINA ANDREEVA	{"email": "polina_andreeva.13021986@postgrespro.ru", "phone": "+70923599743"}
0005432583954	38B7D4	6780 646886	EVGENIY SOKOLOV	{"phone": "+70520775382"}
0005432583955	38B7D4	9421 072059	OLEG KISELEV	{"email": "kiselev.oleg051968@postgrespro.ru", "phone": "+70839371805"}
0005432583956	1BCF13	3696 309859	DMITRIY BONDARENKO	{"email": "d-bondarenko_091969@postgrespro.ru", "phone": "+70318354063"}
0005432583957	1BCF13	6405 021740	MIKHAIL MOROZOV	{"email": "mikhail.morozov_041966@postgrespro.ru", "phone": "+70072920368"}
0005432583958	4ED5A2	6066 490916	KSENIYA VOLKOVA	{"phone": "+70124967621"}
0005432583959	4ED5A2	5893 951921	KIRILL VLASOV	{"phone": "+70249964864"}
0005432583960	4ED5A2	1142 622494	OLGA ALEKSEEVA	{"phone": "+70489435943"}
0005432583961	D5463A	9932 907848	NATALYA TROFIMOVA	{"email": "n.trofimova-021961@postgrespro.ru", "phone": "+70556014265"}
0005432583962	2A3AE9	3003 909110	MIKHAIL SCHERBAKOV	{"phone": "+70595487116"}
0005432583963	4B478D	4120 320981	ZLATA TITOVA	{"email": "titovazlata23061965@postgrespro.ru", "phone": "+70253199619"}
0005432583964	E1367B	6135 629979	OLEG DENISOV	{"phone": "+70637163778"}
0005432583965	E1367B	5266 396607	ALEKSANDR VLASOV	{"email": "avlasov-1978@postgrespro.ru", "phone": "+70088765062"}
0005432583966	E1367B	6310 218829	RAMIL KOZLOV	{"email": "r-kozlov.1970@postgrespro.ru", "phone": "+70630125227"}
0005432583967	8BBE13	1982 358652	ALEKSANDR ILIN	{"email": "ilinaleksandr.1970@postgrespro.ru", "phone": "+70830382218"}
0005432583968	8BBE13	7101 636535	ELENA BORISOVA	{"phone": "+70005465963"}
0005432583969	D69E96	3260 066885	ALLA KISELEVA	{"phone": "+70747959156"}
0005432583970	621C0E	6769 751062	VLADIMIR MIRONOV	{"email": "mironovvladimir-11041974@postgrespro.ru", "phone": "+70898864429"}
0005432583971	621C0E	9317 723119	VLADISLAV EGOROV	{"email": "egorov_v-16061976@postgrespro.ru", "phone": "+70337856657"}
0005432583972	54CD3A	6799 839142	PAVEL EGOROV	{"phone": "+70161810017"}
0005432583973	54CD3A	9201 523778	YURIY FOMIN	{"email": "fomin_y_10011970@postgrespro.ru", "phone": "+70908909951"}
0005432583974	392185	5776 381520	ANASTASIYA ZAYCEVA	{"phone": "+70587080129"}
0005432583975	971C62	1641 734405	OLESYA NIKITINA	{"phone": "+70540252664"}
0005432583976	971C62	6915 974005	VERA KUZNECOVA	{"email": "vkuznecova_1991@postgrespro.ru", "phone": "+70028820632"}
0005432583977	06886A	3646 119044	ANDREY PAVLOV	{"phone": "+70092354046"}
0005432583978	06886A	7982 535324	VALENTINA MIRONOVA	{"phone": "+70571254809"}
0005432583979	853879	1257 812508	MARIYA AFANASEVA	{"email": "afanaseva.mariya.10041959@postgrespro.ru", "phone": "+70671178859"}
0005432583980	B126CC	4782 661467	ANNA FROLOVA	{"email": "frolova.a-1977@postgrespro.ru", "phone": "+70169651828"}
0005432583981	415570	3606 875131	DMITRIY NOVIKOV	{"phone": "+70867468884"}
0005432583982	415570	2050 711310	EVGENIY ROMANOV	{"email": "e_romanov1956@postgrespro.ru", "phone": "+70586658272"}
0005432583983	415570	7545 416684	GALINA MAKAROVA	{"phone": "+70661804108"}
0005432583984	6805AE	2649 440798	TATYANA NIKITINA	{"email": "tatyana-nikitina-27031979@postgrespro.ru", "phone": "+70775277735"}
0005432583985	042837	4763 423128	EVGENIYA ZAKHAROVA	{"phone": "+70532354724"}
0005432583986	042837	7556 089894	RAISA SEMENOVA	{"phone": "+70414179526"}
0005432583987	042837	1860 009656	SAVELIY FILIPPOV	{"email": "filippov_s_17121981@postgrespro.ru", "phone": "+70256788003"}
0005432583988	382827	1119 095968	PETR KUZNECOV	{"email": "pkuznecov011974@postgrespro.ru", "phone": "+70778086222"}
0005432583989	51AC03	5115 402676	PAVEL SOROKIN	{"email": "sorokin-pavel.121972@postgrespro.ru", "phone": "+70654712731"}
0005432583990	98E072	3010 180191	OLEG PETROV	{"phone": "+70508395361"}
0005432583991	504D85	7664 149632	ELIZAVETA POTAPOVA	{"phone": "+70676711612"}
0005432583992	504D85	7706 192159	ANASTASIYA ZHURAVLEVA	{"phone": "+70733130743"}
0005432583993	504D85	5958 422664	OLGA SMIRNOVA	{"phone": "+70123359715"}
0005432583994	526201	1813 534157	IVAN SIDOROV	{"email": "i.sidorov_111962@postgrespro.ru", "phone": "+70761062168"}
0005432583995	C0CA88	8553 039363	NINA KRASNOVA	{"phone": "+70797040647"}
0005432583996	C0CA88	9246 041557	NIKITA ROMANOV	{"email": "romanov-n.14041984@postgrespro.ru", "phone": "+70382422208"}
0005432583997	095178	7220 572921	EKATERINA DAVYDOVA	{"phone": "+70151788371"}
0005432583998	316AE6	5676 747755	LYUCIYA TIKHONOVA	{"phone": "+70876181093"}
0005432583999	4B30A4	9854 514176	ANGELINA NESTEROVA	{"email": "nesterova.angelina_1966@postgrespro.ru", "phone": "+70735108101"}
0005432584000	594393	4691 195727	LIDIYA ANISIMOVA	{"phone": "+70854655661"}
0005432584001	A78B2D	9551 983532	NADEZHDA NIKOLAEVA	{"email": "nadezhda.nikolaeva-1974@postgrespro.ru", "phone": "+70915948194"}
0005432584002	A70E31	3503 033570	IVAN ZAKHAROV	{"email": "zakharov.i-27111958@postgrespro.ru", "phone": "+70810082705"}
0005432584003	A70E31	8354 931177	LYUBOV SOLOVEVA	{"phone": "+70972661845"}
0005432584004	A70E31	6251 988630	ALEKSEY MATVEEV	{"email": "amatveev_061957@postgrespro.ru", "phone": "+70209964338"}
0005432584005	689E6C	9676 965810	EVGENIY ISAEV	{"email": "isaevevgeniy_111968@postgrespro.ru", "phone": "+70817918629"}
0005432584006	D490E7	2340 740121	DMITRIY VOROBEV	{"phone": "+70118360703"}
0005432584007	D490E7	2329 199726	YAROSLAV IVANOV	{"phone": "+70478102972"}
0005432584008	0D76EF	9176 684536	YULIYA IVANOVA	{"phone": "+70275793169"}
0005432584009	37E54F	8081 644555	VALENTINA IVANOVA	{"phone": "+70418411636"}
0005432584010	37E54F	1682 984665	VASILIY KAZAKOV	{"phone": "+70757367084"}
0005432584011	57BFA9	3385 839972	NIKOLAY SEMENOV	{"email": "semenov-nikolay22061972@postgrespro.ru", "phone": "+70929198825"}
0005432584012	8D22A6	4802 547354	VALENTINA MARTYNOVA	{"phone": "+70773603334"}
0005432584013	B0A74E	6718 244470	NELLYA MEDVEDEVA	{"phone": "+70295166248"}
0005432584014	57EDB2	8652 994273	NATALYA EFREMOVA	{"phone": "+70636319492"}
0005432584015	DB38C0	5189 263883	MARIYA IVANOVA	{"phone": "+70630794850"}
0005432584016	9B49A3	2048 334709	MIKHAIL KOZLOV	{"email": "kozlov_m22031962@postgrespro.ru", "phone": "+70166012951"}
0005432584017	9B49A3	4673 659359	ANTON ZAKHAROV	{"email": "anton_zakharov_061977@postgrespro.ru", "phone": "+70571370781"}
0005432584018	9B49A3	7827 225028	MAKSIM NAZAROV	{"email": "maksim_nazarov1972@postgrespro.ru", "phone": "+70545546068"}
0005432584019	519B4F	3787 435030	NATALYA SOLOVEVA	{"phone": "+70963655125"}
0005432584020	B6C4A8	4348 251039	DANIIL BARANOV	{"phone": "+70800452789"}
0005432584021	5EC9B5	2610 994967	VIKTOR KOROLEV	{"phone": "+70407527450"}
0005432584022	D06664	5371 733776	MARIYA ANISIMOVA	{"phone": "+70709576188"}
0005432584023	276A53	2802 072844	MARIYA ERMAKOVA	{"email": "ermakova_mariya-1978@postgrespro.ru", "phone": "+70480211680"}
0005432584024	A136F3	8917 606979	ANASTASIYA NESTEROVA	{"email": "a.nesterova14121967@postgrespro.ru", "phone": "+70645231554"}
0005432584025	B4A30E	9571 718849	ROBERT PETROV	{"phone": "+70702994392"}
0005432584026	878D7B	3689 889235	ALINA NAZAROVA	{"email": "alina.nazarova-091979@postgrespro.ru", "phone": "+70814220256"}
0005432584027	5C0169	4305 532795	ILYA TIMOFEEV	{"phone": "+70841801294"}
0005432584028	E876EA	2077 197855	ALEKSANDRA KUZNECOVA	{"phone": "+70111158166"}
0005432584029	462000	4444 882508	DANIIL POPOV	{"phone": "+70516581001"}
0005432584030	462000	6793 631825	MARINA ANTONOVA	{"email": "marina.antonova25031974@postgrespro.ru", "phone": "+70201806972"}
0005432584031	C0768F	7041 259082	LILIYA ROMANOVA	{"email": "romanova_liliya_071974@postgrespro.ru", "phone": "+70588594612"}
0005432584032	BEDBFA	1602 145511	ALEKSANDR IVANOV	{"phone": "+70460976515"}
0005432584033	BEDBFA	8911 229683	SERGEY OSIPOV	{"email": "osipov.sergey_28101978@postgrespro.ru", "phone": "+70897427451"}
0005432584034	5073B5	5918 474791	IGOR KUZNECOV	{"email": "igor-kuznecov_1976@postgrespro.ru", "phone": "+70500394570"}
0005432584035	9EFF60	3794 765637	ANASTASIYA MELNIKOVA	{"phone": "+70049820421"}
0005432584036	9EFF60	8091 696757	VERA ANDREEVA	{"phone": "+70108119231"}
0005432584037	9EFF60	6048 424723	NATALYA IVANOVA	{"phone": "+70315414610"}
0005432584038	8DF8B8	0215 587150	ELENA SCHERBAKOVA	{"email": "elenascherbakova1984@postgrespro.ru", "phone": "+70322582012"}
0005432584039	8DF8B8	5796 814244	RUSLAN EGOROV	{"phone": "+70813425942"}
0005432584040	20BEEE	6722 358575	ZOYA FILIPPOVA	{"email": "z-filippova-061970@postgrespro.ru", "phone": "+70014166221"}
0005432584041	C3B280	7303 409130	TAMARA NIKITINA	{"phone": "+70861103710"}
0005432584042	C3B280	4571 306027	VALENTIN SOLOVEV	{"phone": "+70222322657"}
0005432584043	D485A0	3637 599622	ANDREY KUZMIN	{"email": "kuzmin.a_19111967@postgrespro.ru", "phone": "+70045151951"}
0005432584044	6A504C	1401 051198	VERA POPOVA	{"email": "v_popova031968@postgrespro.ru", "phone": "+70488280689"}
0005432584045	6A504C	9018 117111	MARIYA GERASIMOVA	{"phone": "+70659528926"}
0005432584046	95299F	8720 653042	ELENA CHERNOVA	{"email": "chernovae13071978@postgrespro.ru", "phone": "+70731728731"}
0005432584047	5952D7	5724 293447	ANDREY KULIKOV	{"phone": "+70154711754"}
0005432584048	A9DC5A	5194 216939	MIKHAIL STEPANOV	{"phone": "+70566315369"}
0005432584049	B6577B	5879 543234	SERGEY IVANOV	{"phone": "+70976697131"}
0005432584050	7EDED2	0462 685727	NADEZHDA IVANOVA	{"email": "n.ivanova1973@postgrespro.ru", "phone": "+70082097014"}
0005432584051	00DDEE	3633 285372	ALINA TARASOVA	{"phone": "+70301264460"}
0005432584052	7B5972	0108 639370	NIKOLAY ROMANOV	{"email": "nromanov.101975@postgrespro.ru", "phone": "+70657370105"}
0005432584053	7B5972	1612 358653	BORIS TIMOFEEV	{"email": "boristimofeev26061978@postgrespro.ru", "phone": "+70853942629"}
0005432584054	8E71A9	4396 362826	YURIY MOROZOV	{"email": "morozov_y-071977@postgrespro.ru", "phone": "+70351306590"}
0005432584055	8E71A9	2933 934765	SERGEY POPOV	{"email": "spopov_101966@postgrespro.ru", "phone": "+70776827202"}
0005432584056	B546A4	0075 207582	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov_09061967@postgrespro.ru", "phone": "+70437973672"}
0005432584057	3BE7AB	6004 475193	EVGENIY BORISOV	{"phone": "+70438280078"}
0005432584058	3BE7AB	0499 933655	MIKHAIL SEMENOV	{"phone": "+70620928129"}
0005432584059	F54F5E	2419 146702	SVETLANA ZAYCEVA	{"email": "s-zayceva051970@postgrespro.ru", "phone": "+70302933460"}
0005432584060	600365	0632 759190	MARIYA EGOROVA	{"phone": "+70964228323"}
0005432584061	600365	6908 651807	SERGEY KULIKOV	{"email": "kulikov.s.081965@postgrespro.ru", "phone": "+70405651250"}
0005432584062	9644F3	9412 352429	OLEG MIKHAYLOV	{"email": "oleg_mikhaylov-1962@postgrespro.ru", "phone": "+70203361189"}
0005432584063	2D5D85	2284 352495	VLADIMIR ROMANOV	{"email": "vladimirromanov1975@postgrespro.ru", "phone": "+70084724971"}
0005432584064	C7101A	7488 524694	ANNA KULIKOVA	{"phone": "+70584628305"}
0005432584065	C7101A	0810 664766	YULIYA PAVLOVA	{"email": "pavlova-y26031976@postgrespro.ru", "phone": "+70318581247"}
0005432584066	FA6F43	9035 859796	VYACHESLAV MEDVEDEV	{"phone": "+70337682142"}
0005432584067	FA6F43	0558 966356	BORIS IVANOV	{"email": "ivanov.b.021976@postgrespro.ru", "phone": "+70309588634"}
0005432584068	190818	7128 979837	VIKTOR PAVLOV	{"email": "pavlov_v.1964@postgrespro.ru", "phone": "+70122704002"}
0005432584069	AEEB99	5680 722741	EDUARD NIKITIN	{"phone": "+70663750282"}
0005432584070	327540	6006 709201	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy011962@postgrespro.ru", "phone": "+70927369729"}
0005432584071	DE7197	1067 794110	BORIS MIKHAYLOV	{"phone": "+70101830378"}
0005432584072	7849FC	2333 858707	PAVEL FOMIN	{"email": "p.fomin-091978@postgrespro.ru", "phone": "+70974111736"}
0005432584073	99E901	3128 716104	KLAVDIYA LEBEDEVA	{"email": "k_lebedeva.051982@postgrespro.ru", "phone": "+70116628221"}
0005432584074	D194B4	2154 185424	NIKITA KAZAKOV	{"email": "kazakovn.03041978@postgrespro.ru", "phone": "+70234371436"}
0005432584075	D194B4	7330 370188	MIKHAIL MARTYNOV	{"email": "martynovmikhail-1960@postgrespro.ru", "phone": "+70607649872"}
0005432584076	9DE555	3372 206575	VALENTINA TIMOFEEVA	{"phone": "+70599692103"}
0005432584077	9DE555	7025 105536	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakova-a.1980@postgrespro.ru", "phone": "+70082126820"}
0005432584078	1D7F97	8924 558760	EVDOKIYA LUKYANOVA	{"email": "e.lukyanova_1973@postgrespro.ru", "phone": "+70402194548"}
0005432584079	1D7F97	7703 072078	NATALYA SIDOROVA	{"email": "sidorovanatalya.1972@postgrespro.ru", "phone": "+70368972314"}
0005432584080	3FD26D	6908 989360	PETR VLASOV	{"phone": "+70170407326"}
0005432584081	3FD26D	4332 576695	ALEKSEY FEDOROV	{"phone": "+70018127819"}
0005432584082	51C030	7118 062067	MARINA KUZNECOVA	{"phone": "+70791745502"}
0005432584083	255AEF	2607 958320	LYUDMILA DANILOVA	{"email": "danilova.l-01031975@postgrespro.ru", "phone": "+70267459113"}
0005432584084	358AB4	8375 488231	NATALYA MIRONOVA	{"phone": "+70231290166"}
0005432584085	358AB4	4160 182586	YURIY TIKHONOV	{"email": "y-tikhonov.031981@postgrespro.ru", "phone": "+70040903806"}
0005432584086	F23A06	8686 243915	SERGEY KUZNECOV	{"phone": "+70192437010"}
0005432584087	00D75A	2482 270308	RAISA IVANOVA	{"phone": "+70639694821"}
0005432584088	D4EBAC	9501 603372	ARMAN SOROKIN	{"email": "sorokin_arman_121975@postgrespro.ru", "phone": "+70206447047"}
0005432584089	2F9FA9	2260 076613	IVAN NIKOLAEV	{"phone": "+70907841419"}
0005432584090	2F9FA9	0415 797938	ANATOLIY TIMOFEEV	{"email": "timofeev.anatoliy-12021966@postgrespro.ru", "phone": "+70299489797"}
0005432584091	A9B97B	8109 671316	OLESYA VOROBEVA	{"email": "vorobeva.o_06021978@postgrespro.ru", "phone": "+70929768117"}
0005432584092	A9B97B	8794 604252	NIKOLAY KUZNECOV	{"email": "n-kuznecov-051959@postgrespro.ru", "phone": "+70569472304"}
0005432584093	921B8F	6128 249912	VALENTINA KUZNECOVA	{"phone": "+70365445775"}
0005432584094	4C4200	5268 172115	DMITRIY PETROV	{"phone": "+70241295545"}
0005432584095	059267	8639 105296	ANTONINA EFIMOVA	{"phone": "+70587125348"}
0005432584096	45D038	7312 885219	ANNA MARTYNOVA	{"email": "martynovaanna.10091963@postgrespro.ru", "phone": "+70278998748"}
0005432584097	45D038	4563 132836	NATALYA SOLOVEVA	{"email": "soloveva.natalya-11041975@postgrespro.ru", "phone": "+70051135703"}
0005432584098	0EFF89	9697 719699	MIKHAIL BARANOV	{"phone": "+70561768357"}
0005432584099	0EFF89	0771 462309	MAKSIM KULIKOV	{"phone": "+70464850600"}
0005432584100	538CAF	6436 922122	NATALYA MIKHAYLOVA	{"phone": "+70119393974"}
0005432584101	538CAF	8034 287024	NINA NOVIKOVA	{"email": "novikova.nina.19101974@postgrespro.ru", "phone": "+70310215417"}
0005432584102	9279D2	9239 215330	VIKTORIYA TIKHONOVA	{"phone": "+70795248540"}
0005432584103	E9F14F	4347 888203	ANTONINA SCHERBAKOVA	{"phone": "+70659960489"}
0005432584104	21CD9A	1447 029862	OLGA MIRONOVA	{"phone": "+70217160350"}
0005432584105	21CD9A	8989 482713	IRINA KONOVALOVA	{"phone": "+70554545535"}
0005432584106	2AE2DB	2640 689869	NADEZHDA ZHUKOVA	{"phone": "+70250845448"}
0005432584107	77C50D	4212 533495	NIKOLAY DMITRIEV	{"email": "dmitriev.n.051974@postgrespro.ru", "phone": "+70338154932"}
0005432584108	9BCA61	4813 045441	VLADIMIR SCHERBAKOV	{"phone": "+70777535208"}
0005432584109	606FB4	2020 065815	EVGENIY MARTYNOV	{"phone": "+70447168495"}
0005432584110	606FB4	6138 803506	FANIYA POPOVA	{"email": "f_popova-011973@postgrespro.ru", "phone": "+70175993614"}
0005432584111	BE0034	7114 098474	TATYANA KULIKOVA	{"email": "tatyana_kulikova.081973@postgrespro.ru", "phone": "+70395153625"}
0005432584112	BE0034	3409 700317	ALEKSANDR ALEKSEEV	{"phone": "+70145572065"}
0005432584113	EBC15B	5340 749907	SERGEY ROMANOV	{"email": "romanov.sergey-24091972@postgrespro.ru", "phone": "+70342556636"}
0005432584114	EFABED	3941 199452	ELENA KALININA	{"phone": "+70659283252"}
0005432584115	E65969	3634 742758	OLGA ANTONOVA	{"phone": "+70158325750"}
0005432584116	E65969	4295 585694	VASILIY ILIN	{"email": "ilin-vasiliy.1964@postgrespro.ru", "phone": "+70390288513"}
0005432584117	08001F	9345 953908	TIMOFEY BORISOV	{"phone": "+70914764368"}
0005432584118	08001F	1316 261110	NATALYA PAVLOVA	{"email": "n.pavlova.20051984@postgrespro.ru", "phone": "+70334163684"}
0005432584119	AE190F	2580 894252	VYACHESLAV ZAYCEV	{"email": "vzaycev-27011972@postgrespro.ru", "phone": "+70324745572"}
0005432584120	2BAF8A	5020 858896	YURIY BARANOV	{"email": "baranovy-1965@postgrespro.ru", "phone": "+70727970924"}
0005432584121	2BAF8A	1205 259671	ELENA KARPOVA	{"phone": "+70731810285"}
0005432584122	5F6425	8320 145392	ARSENIY ILIN	{"email": "ailin.051966@postgrespro.ru", "phone": "+70288378659"}
0005432584123	C206BF	8060 162976	TATYANA ROMANOVA	{"phone": "+70901658248"}
0005432584124	4361E6	0363 797367	ANASTASIYA IVANOVA	{"email": "a_ivanova041969@postgrespro.ru", "phone": "+70469791648"}
0005432584125	4361E6	3934 661572	EVGENIY KUZNECOV	{"email": "kuznecov_e.27101972@postgrespro.ru", "phone": "+70496014654"}
0005432584126	4361E6	0169 180966	OKSANA NIKIFOROVA	{"phone": "+70147093463"}
0005432584127	C1EF3C	2028 383974	SVETLANA EGOROVA	{"email": "svetlana_egorova.031976@postgrespro.ru", "phone": "+70795668900"}
0005432584128	28AA14	3074 150120	OLGA ARKHIPOVA	{"email": "olga_arkhipova.111965@postgrespro.ru", "phone": "+70119831560"}
0005432584129	28AA14	5293 714332	SVETLANA GUSEVA	{"phone": "+70838167507"}
0005432584130	2075A8	1960 930770	NIKOLAY MIRONOV	{"phone": "+70861636512"}
0005432584131	37576C	7785 042852	LIDIYA SCHERBAKOVA	{"phone": "+70596157603"}
0005432584132	C7C259	7131 090664	ELENA PETROVA	{"phone": "+70567233138"}
0005432584133	689952	9833 251432	STEPAN PAVLOV	{"email": "s_pavlov-1976@postgrespro.ru", "phone": "+70059222375"}
0005432584134	630573	5076 502208	LILIYA AFANASEVA	{"phone": "+70335630812"}
0005432584135	630573	3046 306196	VALERIYA TIMOFEEVA	{"phone": "+70613551346"}
0005432584136	21C3C2	0436 278519	MARGARITA ALEKSEEVA	{"phone": "+70183670354"}
0005432584137	21C3C2	9701 764589	NIKOLAY MELNIKOV	{"email": "nikolay_melnikov.25031972@postgrespro.ru", "phone": "+70311602343"}
0005432584138	F499AD	7246 833312	MIKHAIL FEDOROV	{"phone": "+70227829776"}
0005432584139	09995D	1278 261087	SERGEY CHERNOV	{"phone": "+70796232110"}
0005432584140	09995D	4528 192902	SERGEY ABRAMOV	{"phone": "+70645339217"}
0005432584141	0BB054	1053 772532	LYUDMILA ISAEVA	{"phone": "+70802870773"}
0005432584142	C204DD	5180 126065	NIKOLAY PETROV	{"email": "petrov-nikolay.10031984@postgrespro.ru", "phone": "+70994337718"}
0005432584143	0F76C6	0394 390344	NIKOLAY IVANOV	{"phone": "+70375894120"}
0005432584144	B2E732	9864 340624	ANASTASIYA KUZNECOVA	{"phone": "+70813991891"}
0005432584145	1D7297	0080 145589	ZINAIDA PAVLOVA	{"email": "pavlova-z_31071967@postgrespro.ru", "phone": "+70870945749"}
0005432584146	1D7297	5583 865207	NIKOLAY SHEVCHENKO	{"email": "n-shevchenko.21051976@postgrespro.ru", "phone": "+70901097469"}
0005432584147	63C336	0964 019701	ALEKSANDR KUZNECOV	{"phone": "+70739939513"}
0005432584148	9F5B31	9670 248891	ANASTASIYA MALYSHEVA	{"phone": "+70135589491"}
0005432584149	8C024B	1828 535376	KARINA DENISOVA	{"email": "denisovakarina1972@postgrespro.ru", "phone": "+70541230619"}
0005432584150	8C024B	6065 742223	MARINA MIKHAYLOVA	{"email": "mikhaylova-marina.1970@postgrespro.ru", "phone": "+70498898820"}
0005432584151	3CC7FE	6245 611151	SVETLANA BELYAEVA	{"email": "svetlanabelyaeva_28051974@postgrespro.ru", "phone": "+70538806657"}
0005432584152	627DE8	6143 812792	ALEKSANDR VOLKOV	{"phone": "+70204675363"}
0005432584153	627DE8	9141 905383	SVETLANA KONOVALOVA	{"phone": "+70498582002"}
0005432584154	7FCD77	8352 968384	GALINA RYABOVA	{"email": "ryabova_galina-031968@postgrespro.ru", "phone": "+70237817617"}
0005432584155	9391CA	6671 368203	TATYANA KAZAKOVA	{"email": "kazakovat_1971@postgrespro.ru", "phone": "+70236156889"}
0005432584156	08E269	3685 096466	ELIZAVETA ZAYCEVA	{"email": "zayceva-elizaveta_08061962@postgrespro.ru", "phone": "+70264045939"}
0005432584157	D1A9A6	2752 007898	EVGENIY BORISOV	{"phone": "+70347940281"}
0005432584158	D8CD9F	9639 993859	NATALYA EFREMOVA	{"phone": "+70785058961"}
0005432584159	7B1B91	2776 415191	ELENA KOROLEVA	{"email": "koroleva-e.051979@postgrespro.ru", "phone": "+70455496962"}
0005432584160	58F1B2	9235 471208	NADEZHDA VASILEVA	{"email": "n-vasileva_1964@postgrespro.ru", "phone": "+70440302349"}
0005432584161	58F1B2	9344 747702	OLGA YAKOVLEVA	{"phone": "+70911356886"}
0005432584162	D46212	8444 001756	LYUBOV TIKHONOVA	{"email": "ltikhonova_20101976@postgrespro.ru", "phone": "+70126542722"}
0005432584163	3FBA17	4488 554886	ILYA MIKHAYLOV	{"phone": "+70035523610"}
0005432584164	3FBA17	7299 869739	LIDIYA KOROLEVA	{"email": "lidiya_koroleva_16101981@postgrespro.ru", "phone": "+70465817453"}
0005432584165	4340DC	9799 221664	EKATERINA PETROVA	{"phone": "+70252366975"}
0005432584166	745255	3015 655885	FARIT PAVLOV	{"phone": "+70446040795"}
0005432584167	745255	7006 926675	ANATOLIY IVANOV	{"email": "ivanov.a.1965@postgrespro.ru", "phone": "+70217786295"}
0005432584168	635D25	2859 695255	VIKTORIYA ERMAKOVA	{"phone": "+70717762311"}
0005432584169	5F5F99	9114 830569	ANASTASIYA KOZLOVA	{"phone": "+70320641225"}
0005432584170	342844	5359 833586	MARIYA IVANOVA	{"phone": "+70508881302"}
0005432584171	F0B522	0408 565193	ELENA ZHUKOVA	{"email": "zhukova.elena.051968@postgrespro.ru", "phone": "+70275958369"}
0005432584172	609C5C	4375 822774	ALINA GUSEVA	{"phone": "+70580337756"}
0005432584173	413AA9	2193 214742	ALEKSANDR KOROLEV	{"phone": "+70965355475"}
0005432584174	B2B788	7224 731654	ANNA MASLOVA	{"email": "a.maslova_1974@postgrespro.ru", "phone": "+70303613372"}
0005432584175	B2B788	6474 278636	TATYANA GAVRILOVA	{"phone": "+70753980093"}
0005432584176	24C047	9515 305463	SHAMIL BELOV	{"email": "s_belov-051982@postgrespro.ru", "phone": "+70295108448"}
0005432584177	EB9688	6911 249911	YULIYA BORISOVA	{"email": "yuliya_borisova031970@postgrespro.ru", "phone": "+70925127057"}
0005432584178	51D7EA	9134 278343	DENIS NIKITIN	{"email": "d_nikitin-08121961@postgrespro.ru", "phone": "+70242012650"}
0005432584179	51D7EA	0544 218025	ALEKSANDR ALEKSEEV	{"phone": "+70528239433"}
0005432584180	86757B	0538 408123	SERGEY ANDREEV	{"email": "andreevsergey-121975@postgrespro.ru", "phone": "+70676669244"}
0005432584181	56E57E	4576 706568	YANA FEDOROVA	{"phone": "+70656247382"}
0005432584182	340946	5734 944404	EKATERINA PETROVA	{"email": "petrova.e.1989@postgrespro.ru", "phone": "+70891789126"}
0005432584183	B36289	9519 343688	NATALYA LEBEDEVA	{"email": "lebedeva_natalya_20071964@postgrespro.ru", "phone": "+70230461437"}
0005432584184	B36289	2564 214141	VLADIMIR ALEKSANDROV	{"email": "vladimir-aleksandrov-1973@postgrespro.ru", "phone": "+70646519842"}
0005432584185	7E249B	0664 415182	IRINA KONDRATEVA	{"phone": "+70468949674"}
0005432584186	7E249B	6189 671111	TATYANA LOGINOVA	{"phone": "+70935906860"}
0005432584187	95FE04	2302 803131	TATYANA NAZAROVA	{"phone": "+70607965228"}
0005432584188	ABFF1B	7439 213366	NATALYA ZAKHAROVA	{"phone": "+70142559678"}
0005432584189	7C37F2	8251 345814	SVETLANA TIMOFEEVA	{"email": "timofeeva_s-20091972@postgrespro.ru", "phone": "+70993350953"}
0005432584190	D215F2	5338 146026	VITALIY EGOROV	{"email": "egorovv_04091963@postgrespro.ru", "phone": "+70934842873"}
0005432584191	CEC641	8496 662275	SERGEY VOLKOV	{"email": "volkov-sergey-30031978@postgrespro.ru", "phone": "+70319102623"}
0005432584192	10C6BF	5539 630776	LILIYA MALYSHEVA	{"phone": "+70090536272"}
0005432584193	10C6BF	7683 708880	EVGENIY PETROV	{"phone": "+70740803505"}
0005432584194	10C6BF	2962 440230	OLEG KUZMIN	{"email": "okuzmin.1963@postgrespro.ru", "phone": "+70768434223"}
0005432584195	BC8B7E	8445 919197	ALEKSEY MOROZOV	{"email": "morozova-071972@postgrespro.ru", "phone": "+70144235708"}
0005432584196	AE6C02	0733 398249	ANGELINA FEDOROVA	{"email": "fedorova_angelina-101971@postgrespro.ru", "phone": "+70143713662"}
0005432584197	AE6C02	3370 425697	VLADIMIR NIKITIN	{"email": "v.nikitin_14121974@postgrespro.ru", "phone": "+70767471046"}
0005432584198	B991F6	6585 668123	VERA ALEKSANDROVA	{"email": "v_aleksandrova_16031969@postgrespro.ru", "phone": "+70633629700"}
0005432584199	EBF08E	6933 457318	VIKTOR KUZNECOV	{"phone": "+70122613467"}
0005432584200	EBF08E	2049 933865	ALEKSANDRA AKIMOVA	{"email": "aleksandra.akimova121961@postgrespro.ru", "phone": "+70679252377"}
0005432584201	4068CD	2270 157788	VLADIMIR KARPOV	{"email": "v-karpov.09071968@postgrespro.ru", "phone": "+70643988053"}
0005432584202	D6DC1F	9323 756572	RUSLAN IVANOV	{"phone": "+70543220661"}
0005432584203	FBAEDD	8705 250026	VLADIMIR ZHURAVLEV	{"phone": "+70186445956"}
0005432584204	CA8174	5169 465065	ZINAIDA SERGEEVA	{"email": "zinaida_sergeeva-101970@postgrespro.ru", "phone": "+70723227270"}
0005432584205	CA8174	1138 626283	IVAN KOZLOV	{"email": "ivan.kozlov_1976@postgrespro.ru", "phone": "+70719260113"}
0005432584206	65B758	8659 703209	RUSTAM ALEKSEEV	{"email": "rustam.alekseev.1974@postgrespro.ru", "phone": "+70187824514"}
0005432584207	65B758	6108 035215	OLGA IVANOVA	{"phone": "+70379653634"}
0005432584208	8C4504	9966 232820	EKATERINA KUZNECOVA	{"phone": "+70680141522"}
0005432584209	EA5D13	6596 520653	MARK VLASOV	{"email": "mark-vlasov-041967@postgrespro.ru", "phone": "+70477626308"}
0005432584210	560278	8771 924492	TATYANA BELOVA	{"email": "belovat.17051973@postgrespro.ru", "phone": "+70613887102"}
0005432584211	1B7AFB	3858 737173	ALEKSANDR FEDOROV	{"phone": "+70074566740"}
0005432584212	1B7AFB	0439 423682	SERGEY ALEKSEEV	{"phone": "+70012223717"}
0005432584213	6FD47F	5750 328417	MIKHAIL IVANOV	{"phone": "+70442765556"}
0005432584214	836B0B	8517 699890	VALERIY DMITRIEV	{"phone": "+70314451418"}
0005432584215	41BA7E	2765 188504	ANATOLIY SCHERBAKOV	{"email": "anatoliy.scherbakov26011980@postgrespro.ru", "phone": "+70144132716"}
0005432584216	B133F7	2339 284010	ANASTASIYA EGOROVA	{"email": "anastasiya-egorova101963@postgrespro.ru", "phone": "+70598312805"}
0005432584217	524BD2	1223 818668	NADEZHDA KUZMINA	{"email": "n_kuzmina081959@postgrespro.ru", "phone": "+70545709292"}
0005432584218	524BD2	1251 106554	IRINA ZAKHAROVA	{"email": "zakharova_irina-17091972@postgrespro.ru", "phone": "+70908884207"}
0005432584219	7F4FB9	8700 333584	ANTONIDA RYABOVA	{"email": "ryabova_a1970@postgrespro.ru", "phone": "+70571395648"}
0005432584220	9FB905	5463 439753	SERGEY ZAKHAROV	{"phone": "+70683826297"}
0005432584221	9FB905	5940 845926	GEORGIY MARTYNOV	{"email": "georgiymartynov-091973@postgrespro.ru", "phone": "+70701280631"}
0005432584222	CD702D	4215 193342	ALEKSANDR ANDREEV	{"email": "andreev-a14011969@postgrespro.ru", "phone": "+70817743261"}
0005432584223	C34178	4194 760407	STANISLAV SOKOLOV	{"email": "sokolov.s20051967@postgrespro.ru", "phone": "+70810910932"}
0005432584224	E6EF28	5821 415227	NATALYA SEMENOVA	{"email": "semenovan.1961@postgrespro.ru", "phone": "+70996174666"}
0005432584225	DBC04C	1941 186008	EVGENIY DENISOV	{"phone": "+70949637188"}
0005432584226	DBC04C	7464 438567	ALEKSANDR KUZNECOV	{"phone": "+70632036116"}
0005432584227	DBC04C	7145 043588	VLADISLAV KUZNECOV	{"phone": "+70885597393"}
0005432584228	DD20D8	6039 454268	IGOR STEPANOV	{"phone": "+70262596749"}
0005432584229	71F4E1	4311 210181	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev_011981@postgrespro.ru", "phone": "+70461796347"}
0005432584230	71F4E1	2694 342924	TAMARA BOGDANOVA	{"email": "t-bogdanova-1978@postgrespro.ru", "phone": "+70517474872"}
0005432584231	DD65C1	9704 635022	ANDREY SEMENOV	{"phone": "+70010010160"}
0005432584232	DD65C1	1132 173618	VYACHESLAV ZAKHAROV	{"email": "vyacheslav-zakharov041956@postgrespro.ru", "phone": "+70006017609"}
0005432584233	7192BC	0339 083748	ALENA DMITRIEVA	{"email": "dmitrieva_a071968@postgrespro.ru", "phone": "+70329919325"}
0005432584234	51AED7	7278 151369	VIKTOR MAKAROV	{"email": "makarov-v-1967@postgrespro.ru", "phone": "+70706122206"}
0005432584235	51AED7	3442 525993	ALEKSEY KONOVALOV	{"phone": "+70517573504"}
0005432584236	615FF1	8414 525778	TATYANA FADEEVA	{"phone": "+70998893306"}
0005432584237	4C78C8	8895 206777	MIKHAIL TARASOV	{"email": "tarasov-mikhail1971@postgrespro.ru", "phone": "+70060921574"}
0005432584238	10336D	9398 085900	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov08121968@postgrespro.ru", "phone": "+70991958665"}
0005432584239	7C4AEB	4834 166885	MARINA ISAEVA	{"phone": "+70162218388"}
0005432584240	7C4AEB	8502 398803	KRISTINA GERASIMOVA	{"phone": "+70570863371"}
0005432584241	1ADEA4	4104 921228	VALENTINA DAVYDOVA	{"phone": "+70205618422"}
0005432584242	4961F1	6915 556523	NADEZHDA MOROZOVA	{"email": "morozova_n.20041969@postgrespro.ru", "phone": "+70459041271"}
0005432584243	4961F1	9728 800159	EVGENIY SEMENOV	{"email": "semenov_e_091970@postgrespro.ru", "phone": "+70230208892"}
0005432584244	7F71F9	2887 248328	SERGEY TARASOV	{"phone": "+70553302226"}
0005432584245	E6736B	7393 967892	NIKITA IVANOV	{"phone": "+70463424201"}
0005432584246	E6736B	5807 810155	YURIY KUDRYASHOV	{"email": "kudryashov_yuriy_1970@postgrespro.ru", "phone": "+70333706407"}
0005432584247	4A90A4	4306 832517	VIKTOR GRIGOREV	{"email": "grigorev.v02101976@postgrespro.ru", "phone": "+70832530165"}
0005432584248	FE811C	6968 055563	ALEKSANDR PETROV	{"phone": "+70924764375"}
0005432584249	FE811C	3990 830423	ANATOLIY FROLOV	{"email": "frolov-anatoliy-01021973@postgrespro.ru", "phone": "+70070071337"}
0005432584250	9BBD6F	0390 698599	ZINAIDA DAVYDOVA	{"email": "davydova_zinaida22051984@postgrespro.ru", "phone": "+70140515339"}
0005432584251	2CDC0A	5062 634390	NINA NIKITINA	{"phone": "+70128572665"}
0005432584252	3F6736	0393 859797	NIKOLAY PETROV	{"phone": "+70377425664"}
0005432584253	457010	4989 173609	NIKITA BELOV	{"phone": "+70448859663"}
0005432584254	457010	0481 514228	NATALYA KAZAKOVA	{"phone": "+70022833174"}
0005432584255	002365	2924 759341	MARINA KRASNOVA	{"phone": "+70873628891"}
0005432584256	17F52F	4419 452851	FARIDA SIDOROVA	{"email": "farida-sidorova-24061974@postgrespro.ru", "phone": "+70954634483"}
0005432584257	17F52F	9286 198236	ANATOLIY MAKAROV	{"phone": "+70078352672"}
0005432584258	85EC3B	1748 467467	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov1976@postgrespro.ru", "phone": "+70978452236"}
0005432584259	E0FB46	0126 373771	ELENA SERGEEVA	{"email": "e_sergeeva_081973@postgrespro.ru", "phone": "+70752298395"}
0005432584260	EC447E	6727 713816	KIRILL ZAKHAROV	{"email": "zakharov_k17011988@postgrespro.ru", "phone": "+70531099757"}
0005432584261	33BA2F	9393 614222	VYACHESLAV MOROZOV	{"phone": "+70600605945"}
0005432584262	ECD556	4837 232132	RASIM KRASNOV	{"email": "krasnov-r-16121978@postgrespro.ru", "phone": "+70526251509"}
0005432584263	6F0973	1973 492596	MIKHAIL DAVYDOV	{"phone": "+70543188581"}
0005432584264	6F0973	2062 993668	SERGEY MOROZOV	{"phone": "+70114044708"}
0005432584265	636437	5179 671211	ANAIT SMIRNOVA	{"email": "anait-smirnova081970@postgrespro.ru", "phone": "+70803113952"}
0005432584266	A7EB84	1405 774498	VIKTOR MAKSIMOV	{"email": "v-maksimov1959@postgrespro.ru", "phone": "+70061838093"}
0005432584267	A7EB84	4764 104007	LYUDMILA SEMENOVA	{"email": "lyudmila.semenova-1966@postgrespro.ru", "phone": "+70800721564"}
0005432584268	B0304D	7288 929678	NINA DENISOVA	{"phone": "+70785247810"}
0005432584269	B0304D	6817 245483	NATALYA KOVALEVA	{"email": "kovaleva-n.1970@postgrespro.ru", "phone": "+70442743888"}
0005432584270	F01832	7818 062742	VIKTORIYA AFANASEVA	{"email": "afanasevav071971@postgrespro.ru", "phone": "+70517066605"}
0005432584271	6696AB	9374 949017	MARINA STEPANOVA	{"phone": "+70267768549"}
0005432584272	49FDD1	5237 691508	SEMEN KULIKOV	{"email": "kulikov.s-23041971@postgrespro.ru", "phone": "+70365367981"}
0005432584273	AC58B8	1351 165378	ALEKSANDRA VASILEVA	{"email": "a_vasileva051967@postgrespro.ru", "phone": "+70389350507"}
0005432584274	D3AEA0	6322 610436	ANTON VASILEV	{"phone": "+70708930413"}
0005432584275	D3AEA0	0977 425833	EKATERINA KARPOVA	{"phone": "+70346505072"}
0005432584276	C05C5F	4404 598037	VLADIMIR SOROKIN	{"email": "sorokin.v.011978@postgrespro.ru", "phone": "+70212933100"}
0005432584277	C05C5F	1267 616191	ANNA MIKHAYLOVA	{"email": "a-mikhaylova21011984@postgrespro.ru", "phone": "+70397349274"}
0005432584278	0915F6	0645 320157	VERA DMITRIEVA	{"email": "dmitrieva.v-03051957@postgrespro.ru", "phone": "+70447408140"}
0005432584279	93AC66	7051 429119	BOGDAN BARANOV	{"email": "baranov_bogdan031976@postgrespro.ru", "phone": "+70351617956"}
0005432584280	5EF5E0	9614 425260	LEONID AFANASEV	{"email": "afanasev_leonid23041977@postgrespro.ru", "phone": "+70365319335"}
0005432584281	5EF5E0	7480 029475	NINA ZAYCEVA	{"phone": "+70328108493"}
0005432584282	279D5E	4928 712657	OKSANA CHERNOVA	{"phone": "+70811820611"}
0005432584283	DA7561	4386 407112	NIKOLAY SOROKIN	{"phone": "+70659844553"}
0005432584284	6C97B7	5651 757013	PAVEL ALEKSEEV	{"phone": "+70510279960"}
0005432584285	6C97B7	2139 467596	NINA TIKHONOVA	{"phone": "+70795330198"}
0005432584286	1CA870	2306 567891	MIKHAIL ZAYCEV	{"email": "m-zaycev23091966@postgrespro.ru", "phone": "+70286577075"}
0005432584287	1CA870	6399 817383	LYUBOV NESTEROVA	{"phone": "+70404378379"}
0005432584288	553A92	1775 744533	NIKITA POPOV	{"phone": "+70156749339"}
0005432584289	61E6D5	1963 730922	ALEKSANDR NIKITIN	{"phone": "+70976804342"}
0005432584290	DBBCD8	2997 438682	VLADIMIR MAKAROV	{"phone": "+70791821831"}
0005432584291	A0B9BB	1230 612440	ALEKSANDR DAVYDOV	{"phone": "+70491092867"}
0005432584292	9E2633	0947 609606	VLADIMIR MIRONOV	{"phone": "+70429522498"}
0005432584293	4713D1	4655 416640	NINA ERMAKOVA	{"phone": "+70417595885"}
0005432584294	5B9E5A	4886 019632	ALEKSANDR DAVYDOV	{"phone": "+70893845390"}
0005432584295	5B9E5A	0779 342962	VLADIMIR MELNIKOV	{"email": "melnikovvladimir_24041968@postgrespro.ru", "phone": "+70888469301"}
0005432584296	5B9E5A	7688 238451	TATYANA VASILEVA	{"email": "vasileva.tatyana_031969@postgrespro.ru", "phone": "+70854723047"}
0005432584297	5929E1	1379 617117	EKATERINA VLASOVA	{"email": "ekaterina-vlasova-1982@postgrespro.ru", "phone": "+70533782011"}
0005432584298	652D88	5783 698724	SVETLANA ZOTOVA	{"phone": "+70925646271"}
0005432584299	652D88	3944 832385	LYUDMILA PETROVA	{"email": "petrova_lyudmila_15101967@postgrespro.ru", "phone": "+70546280074"}
0005432584300	E767CE	7922 298761	TATYANA FADEEVA	{"email": "fadeevatatyana-121974@postgrespro.ru", "phone": "+70190177332"}
0005432584301	E767CE	8752 454370	EKATERINA RODIONOVA	{"email": "ekaterina_rodionova_29101968@postgrespro.ru", "phone": "+70050423723"}
0005432584302	72BB83	9304 462936	MARIYA FEDOROVA	{"phone": "+70513926691"}
0005432584303	111306	1086 846928	DMITRIY NIKITIN	{"email": "nikitindmitriy_1972@postgrespro.ru", "phone": "+70597924013"}
0005432584304	786344	7081 623301	DENIS ABRAMOV	{"phone": "+70127681625"}
0005432584305	786344	7108 420342	VASILIY NIKITIN	{"phone": "+70510779879"}
0005432584306	CC2CEC	5891 661494	IVAN MAKAROV	{"phone": "+70355782558"}
0005432584307	A1BB73	2178 452347	TATYANA ILINA	{"email": "ilina.tatyana-15011983@postgrespro.ru", "phone": "+70740709080"}
0005432584308	B586A4	2988 353133	POLINA MEDVEDEVA	{"email": "medvedeva.polina_011984@postgrespro.ru", "phone": "+70854638330"}
0005432584309	3D6D51	7448 819069	ANFISA ORLOVA	{"email": "orlova.a.1980@postgrespro.ru", "phone": "+70122322619"}
0005432584310	9F372D	9441 586611	VERA SOROKINA	{"phone": "+70696025611"}
0005432584311	9F372D	6775 685928	KAMIL ZHURAVLEV	{"email": "k_zhuravlev_02051972@postgrespro.ru", "phone": "+70635861078"}
0005432584312	5F8A94	5920 599978	NATALYA PAVLOVA	{"phone": "+70368427547"}
0005432584313	5F8A94	9380 040644	VADIM PETROV	{"email": "petrov_v.041982@postgrespro.ru", "phone": "+70517792293"}
0005432584314	5F8A94	2893 533620	NATALYA OSIPOVA	{"phone": "+70680810005"}
0005432584315	5F8A94	4358 226939	TAMARA MATVEEVA	{"phone": "+70340276030"}
0005432584316	26E534	9772 616798	MAKAR GRIGOREV	{"email": "grigorev_makar_1965@postgrespro.ru", "phone": "+70254026181"}
0005432584317	26E534	4633 164778	ALEKSANDR FILIPPOV	{"email": "aleksandr_filippov121967@postgrespro.ru", "phone": "+70111028343"}
0005432584318	943BE8	8414 111091	EVGENIY DENISOV	{"email": "evgeniydenisov1968@postgrespro.ru", "phone": "+70137978642"}
0005432584319	35A034	1962 530681	MIKHAIL ORLOV	{"phone": "+70065680259"}
0005432584320	30DBB1	9336 880338	TATYANA TARASOVA	{"phone": "+70979406413"}
0005432584321	30DBB1	9286 893581	ANTONINA FILATOVA	{"phone": "+70694452513"}
0005432584322	30DBB1	8764 484487	ALEKSEY MAKSIMOV	{"email": "amaksimov_061974@postgrespro.ru", "phone": "+70184330008"}
0005432584323	AE82F5	2549 960460	LYUDMILA MELNIKOVA	{"email": "melnikoval.111973@postgrespro.ru", "phone": "+70516739686"}
0005432584324	41DC0B	0936 134115	ALEKSEY BORISOV	{"email": "borisovaleksey-051967@postgrespro.ru", "phone": "+70258732916"}
0005432584325	41DC0B	1803 902233	MARIYA TARASOVA	{"email": "tarasova_m1969@postgrespro.ru", "phone": "+70640982423"}
0005432584326	DEA3D2	3626 109616	SERGEY MIKHAYLOV	{"email": "smikhaylov-28081973@postgrespro.ru", "phone": "+70112027624"}
0005432584327	DEA3D2	2132 596065	VIKTOR YAKOVLEV	{"phone": "+70545774022"}
0005432584328	F066DC	8145 943783	VALENTINA GAVRILOVA	{"phone": "+70967047327"}
0005432584329	E81D7F	0764 145588	VLADIMIR ISAEV	{"email": "v.isaev061970@postgrespro.ru", "phone": "+70305566183"}
0005432584330	DCC423	3317 390162	ILYA MAKAROV	{"phone": "+70146463559"}
0005432584331	7E0E80	3556 386324	NINA GERASIMOVA	{"email": "gerasimovan-1986@postgrespro.ru", "phone": "+70638689876"}
0005432584332	08B27A	6458 153015	ANZHELIKA VOROBEVA	{"phone": "+70490267801"}
0005432584333	08B27A	0441 330127	SERGEY KUZMIN	{"email": "s-kuzmin-03011975@postgrespro.ru", "phone": "+70244804450"}
0005432584334	9EA100	4884 290986	IRINA NIKOLAEVA	{"email": "inikolaeva-1970@postgrespro.ru", "phone": "+70881430094"}
0005432584335	57A536	3367 965644	VERA PAVLOVA	{"phone": "+70925491630"}
0005432584336	E75A2C	2291 238348	LEONID NAUMOV	{"email": "naumov-l.071966@postgrespro.ru", "phone": "+70195382250"}
0005432584337	E80A37	4732 807713	VADIM ISAEV	{"email": "isaev_v_091967@postgrespro.ru", "phone": "+70953640404"}
0005432584338	58378A	8456 300135	RAMIL EGOROV	{"email": "egorovr1978@postgrespro.ru", "phone": "+70172335647"}
0005432584339	3CE2B5	4797 690918	TATYANA STEPANOVA	{"email": "stepanova_tatyana.011969@postgrespro.ru", "phone": "+70404554960"}
0005432584340	2C0369	8397 715284	RIMMA SOKOLOVA	{"phone": "+70862402064"}
0005432584341	2C0369	6088 206376	EKATERINA MAKAROVA	{"email": "e-makarova.10041965@postgrespro.ru", "phone": "+70162916130"}
0005432584342	F3A6BD	9888 818937	MARIYA KRASNOVA	{"email": "krasnova-mariya_1981@postgrespro.ru", "phone": "+70747116734"}
0005432584343	78E388	6070 997874	SERGEY KULIKOV	{"phone": "+70389752451"}
0005432584344	CC5340	4243 340776	DMITRIY SOLOVEV	{"phone": "+70098174090"}
0005432584345	8E3565	5956 906166	OLGA PETROVA	{"email": "petrovaolga.1969@postgrespro.ru", "phone": "+70894398800"}
0005432584346	8E3565	1239 205436	IVAN SIDOROV	{"email": "ivan-sidorov_091970@postgrespro.ru", "phone": "+70162220716"}
0005432584347	8E3565	2589 645082	IRINA KOROLEVA	{"phone": "+70772497598"}
0005432584348	C5C5BC	0146 526165	ALEKSANDR TARASOV	{"email": "tarasova.26051985@postgrespro.ru", "phone": "+70632396029"}
0005432584349	9260A7	4014 343534	SERGEY KUZNECOV	{"phone": "+70016143103"}
0005432584350	110CC5	1146 517098	FARID SEMENOV	{"phone": "+70767338970"}
0005432584351	110CC5	3743 524722	VIKTOR SMIRNOV	{"email": "smirnov_v.1977@postgrespro.ru", "phone": "+70630394716"}
0005432584352	110CC5	2698 001359	GALINA TIMOFEEVA	{"email": "timofeeva-galina1971@postgrespro.ru", "phone": "+70483811951"}
0005432584353	D9330A	1901 498587	OLGA TIMOFEEVA	{"phone": "+70124550716"}
0005432584354	795B5B	0203 538199	IGOR DMITRIEV	{"email": "dmitrievi1971@postgrespro.ru", "phone": "+70385282963"}
0005432584355	5DB4EC	5998 770741	YAROSLAV KOZLOV	{"email": "kozlovyaroslav1972@postgrespro.ru", "phone": "+70625095904"}
0005432584356	5DB4EC	5894 424933	NINA ARKHIPOVA	{"email": "n_arkhipova.1961@postgrespro.ru", "phone": "+70408551134"}
0005432584357	E4FD86	9727 925875	RODION BELOV	{"email": "belov.r.011962@postgrespro.ru", "phone": "+70326384339"}
0005432584358	CD610B	9698 413870	VITALIY BONDARENKO	{"phone": "+70826288168"}
0005432584359	38910C	0242 049744	ANDREY FROLOV	{"email": "andrey-frolov_1987@postgrespro.ru", "phone": "+70506026020"}
0005432584360	9077DD	4473 061166	IRAIDA SEMENOVA	{"email": "semenova-i.1965@postgrespro.ru", "phone": "+70292519411"}
0005432584361	72AC22	0620 967198	IRAIDA FILIPPOVA	{"email": "filippovai-02061977@postgrespro.ru", "phone": "+70945418846"}
0005432584362	36261F	9018 234167	EVGENIY STEPANOV	{"email": "stepanov-evgeniy.21101976@postgrespro.ru", "phone": "+70788494433"}
0005432584363	D4B69F	2228 744644	ANASTASIYA NIKITINA	{"phone": "+70683528533"}
0005432584364	735817	9813 670508	VLADIMIR MIRONOV	{"email": "mironov_v-051980@postgrespro.ru", "phone": "+70680508912"}
0005432584365	684D66	0361 038964	NATALIYA GUSEVA	{"email": "guseva-n-1978@postgrespro.ru", "phone": "+70812541975"}
0005432584366	E1D155	5870 245561	VALENTIN ALEKSEEV	{"email": "v-alekseev_10121970@postgrespro.ru", "phone": "+70268008421"}
0005432584367	E1D155	4165 751566	MARGARITA KOLESNIKOVA	{"phone": "+70719236396"}
0005432584368	E93637	5460 699043	ALENA KRASNOVA	{"phone": "+70160442684"}
0005432584369	16E61C	1168 840825	SERGEY CHERNOV	{"phone": "+70437469152"}
0005432584370	51BC85	6289 361068	TAMARA VASILEVA	{"phone": "+70396993567"}
0005432584371	51BC85	2398 858012	VIKTOR SAVELEV	{"phone": "+70316690061"}
0005432584372	0FFFB6	7701 246572	DANIIL FEDOTOV	{"phone": "+70125331122"}
0005432584373	C11257	3493 042312	DMITRIY STEPANOV	{"phone": "+70410104289"}
0005432584374	C11257	3150 852145	AIDA MIKHAYLOVA	{"phone": "+70613186448"}
0005432584375	469115	0358 174919	MARINA ANTONOVA	{"phone": "+70404670247"}
0005432584376	00711E	9344 080019	TATYANA POPOVA	{"phone": "+70733589948"}
0005432584377	DDB4CB	5346 502387	ALEKSEY KISELEV	{"phone": "+70183349715"}
0005432584378	AC532A	9898 126026	STANISLAV ZAYCEV	{"email": "zaycev-s13081978@postgrespro.ru", "phone": "+70094976882"}
0005432584379	AC532A	8041 782963	SERGEY MIKHAYLOV	{"email": "smikhaylov-1989@postgrespro.ru", "phone": "+70241490904"}
0005432584380	83B215	8742 733406	OLGA BOGDANOVA	{"phone": "+70195292639"}
0005432584381	E80817	2969 414850	ELIZAVETA RYABOVA	{"phone": "+70267680961"}
0005432584382	6F0821	8871 413234	DANIL SOKOLOV	{"email": "d_sokolov_051970@postgrespro.ru", "phone": "+70145228782"}
0005432584383	E9D40A	0860 094672	ANASTASIYA VASILEVA	{"phone": "+70670655154"}
0005432584384	E9D40A	0618 171466	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova-1985@postgrespro.ru", "phone": "+70575182556"}
0005432584385	E9D40A	3890 291042	DMITRIY GAVRILOV	{"email": "dmitriy.gavrilov011975@postgrespro.ru", "phone": "+70131673114"}
0005432584386	8F281F	4442 255376	ELENA POPOVA	{"email": "popova.e.101968@postgrespro.ru", "phone": "+70194646354"}
0005432584387	8F281F	4646 577699	KSENIYA BARANOVA	{"email": "kseniya.baranova.1968@postgrespro.ru", "phone": "+70617527043"}
0005432584388	8F281F	6818 313142	GALINA STEPANOVA	{"email": "galina.stepanova.18061967@postgrespro.ru", "phone": "+70502576259"}
0005432584389	E903D7	1044 614639	IVAN KAZAKOV	{"email": "kazakov_i-1988@postgrespro.ru", "phone": "+70140277447"}
0005432584390	E903D7	8044 300306	EVGENIY NOVIKOV	{"phone": "+70610442497"}
0005432584391	0B8887	1494 446223	NADEZHDA IVANOVA	{"phone": "+70417739997"}
0005432584392	602991	5871 069307	EVGENIYA ORLOVA	{"phone": "+70149142733"}
0005432584393	FA73A0	4541 353220	NATALYA BELOVA	{"phone": "+70438686291"}
0005432584394	FA73A0	2232 192121	VIKTOR KOZLOV	{"email": "v_kozlov_121967@postgrespro.ru", "phone": "+70316568748"}
0005432584395	D06C62	4566 817742	ANATOLIY GORBUNOV	{"phone": "+70398706126"}
0005432584396	0206FB	4567 744018	DMITRIY KUZNECOV	{"email": "d.kuznecov-25081971@postgrespro.ru", "phone": "+70961786730"}
0005432584397	0206FB	0588 247937	ALEKSANDR SMIRNOV	{"phone": "+70967447313"}
0005432584398	564158	7901 921669	ALINA EGOROVA	{"email": "egorova.a.111986@postgrespro.ru", "phone": "+70740824751"}
0005432584399	29AA62	5178 059122	MARINA SIDOROVA	{"email": "marina_sidorova-1971@postgrespro.ru", "phone": "+70310030387"}
0005432584400	31400C	5229 756437	YULIYA IVANOVA	{"email": "y.ivanova.02031972@postgrespro.ru", "phone": "+70349170705"}
0005432584401	92F72E	6050 780010	STANISLAV VASILEV	{"phone": "+70571551415"}
0005432584402	DA0BB5	9107 503157	ANASTASIYA BELOVA	{"phone": "+70518187588"}
0005432584403	04FC09	8186 978072	ANATOLIY MOISEEV	{"email": "moiseev.a-011969@postgrespro.ru", "phone": "+70771552810"}
0005432584404	F49320	8976 113503	NIKOLAY BORISOV	{"email": "nikolay.borisov_121981@postgrespro.ru", "phone": "+70793606310"}
0005432584405	447AB7	7223 026321	IRINA MELNIKOVA	{"phone": "+70204287359"}
0005432584406	F04963	7305 838902	VYACHESLAV SHEVCHENKO	{"email": "shevchenkovyacheslav_25041964@postgrespro.ru", "phone": "+70988005341"}
0005432584407	FF0240	2294 666227	KRISTINA MASLOVA	{"email": "kmaslova-26101972@postgrespro.ru", "phone": "+70508761569"}
0005432584408	FF0240	5940 943258	ALEKSANDRA KOZLOVA	{"email": "kozlova-aleksandra-111965@postgrespro.ru", "phone": "+70212545504"}
0005432584409	B2A981	0332 942794	ANATOLIY MIRONOV	{"email": "mironov-a-05101970@postgrespro.ru", "phone": "+70416305429"}
0005432584410	49D828	0300 892487	VITALIY BARANOV	{"email": "v.baranov.12041978@postgrespro.ru", "phone": "+70798205990"}
0005432584411	49D828	3583 360587	DMITRIY ANDREEV	{"email": "andreev.dmitriy1969@postgrespro.ru", "phone": "+70320335202"}
0005432584412	D35405	3879 067350	PRASKOVYA ANTONOVA	{"email": "praskovyaantonova_081971@postgrespro.ru", "phone": "+70210660791"}
0005432584413	D35405	7612 481152	NINA KULIKOVA	{"phone": "+70508287278"}
0005432584414	F328FA	2097 901636	ZOYA YAKOVLEVA	{"phone": "+70510532625"}
0005432584415	97587B	9402 001194	ALLA NESTEROVA	{"email": "nesterova.alla_1967@postgrespro.ru", "phone": "+70581037300"}
0005432584416	85AC7D	6071 002954	NINA RODIONOVA	{"email": "nina-rodionova_031973@postgrespro.ru", "phone": "+70654807364"}
0005432584417	A3CB84	2325 649440	SERGEY ZHURAVLEV	{"phone": "+70704680075"}
0005432584418	A3CB84	4622 470141	VALENTINA BORISOVA	{"phone": "+70424296028"}
0005432584419	5C7790	6436 584970	LIDIYA KOVALEVA	{"email": "l-kovaleva_1967@postgrespro.ru", "phone": "+70944355460"}
0005432584420	7461AD	3509 081363	KIRILL NIKITIN	{"email": "k-nikitin-1976@postgrespro.ru", "phone": "+70383452069"}
0005432584421	2BD48A	5558 768056	VIKTOR IVANOV	{"email": "ivanov-viktor.28101969@postgrespro.ru", "phone": "+70001437106"}
0005432584422	BB98AE	2035 624919	RADIK MAKAROV	{"phone": "+70274154848"}
0005432584423	4EE247	0913 858814	ANTONINA MALYSHEVA	{"email": "antonina-malysheva.041975@postgrespro.ru", "phone": "+70295883999"}
0005432584424	074D23	3418 134057	ALEKSEY KRASNOV	{"phone": "+70273601861"}
0005432584425	074D23	5322 731861	DARYA GAVRILOVA	{"email": "daryagavrilova-041973@postgrespro.ru", "phone": "+70662946515"}
0005432584426	F374E4	0999 539348	ALEKSANDR PETROV	{"email": "petrova1979@postgrespro.ru", "phone": "+70981343046"}
0005432584427	F374E4	0580 132592	TAISIYA ANDREEVA	{"phone": "+70607503766"}
0005432584428	5D9445	9035 694367	SOFYA DMITRIEVA	{"email": "s.dmitrieva-041967@postgrespro.ru", "phone": "+70193970211"}
0005432584429	5D9445	5505 274407	EKATERINA LOGINOVA	{"email": "ekaterina.loginova_1966@postgrespro.ru", "phone": "+70983186416"}
0005432584430	DBDDDB	5043 626417	TATYANA ZOTOVA	{"phone": "+70721333316"}
0005432584431	2A6AB1	5745 774079	VYACHESLAV GORBUNOV	{"email": "vyacheslav.gorbunov061966@postgrespro.ru", "phone": "+70736037082"}
0005432584432	407FDD	8696 178912	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev_30011972@postgrespro.ru", "phone": "+70916106867"}
0005432584433	CE0838	2264 793766	AYRAT FEDOROV	{"phone": "+70217616223"}
0005432584434	237B83	0567 244574	VALENTINA CHERNOVA	{"phone": "+70335551355"}
0005432584435	F5E267	2435 379132	NATALYA FOMINA	{"email": "fominan.111966@postgrespro.ru", "phone": "+70697560331"}
0005432584436	F5E267	1284 514271	ANATOLIY VOLKOV	{"email": "volkov.a_1969@postgrespro.ru", "phone": "+70217270919"}
0005432584437	392FF3	2060 840788	SVETLANA ILINA	{"email": "s-ilina_031982@postgrespro.ru", "phone": "+70593793822"}
0005432584438	A1C111	3097 090560	DARYA ZAYCEVA	{"email": "d-zayceva.111974@postgrespro.ru", "phone": "+70964692743"}
0005432584439	922FF3	6172 163873	IRINA VOLKOVA	{"email": "volkova-i_1966@postgrespro.ru", "phone": "+70408835281"}
0005432584440	534812	8442 092373	DANILA NIKOLAEV	{"email": "danilanikolaev-16091964@postgrespro.ru", "phone": "+70103961803"}
0005432584441	534812	9847 420752	MARINA ANISIMOVA	{"email": "m.anisimova.25021976@postgrespro.ru", "phone": "+70807318384"}
0005432584442	5785DD	6239 588500	VLADIMIR GRIGOREV	{"email": "grigorev.v041969@postgrespro.ru", "phone": "+70748469229"}
0005432584443	5785DD	9620 009231	TATYANA DENISOVA	{"email": "denisovat.15061962@postgrespro.ru", "phone": "+70119340188"}
0005432584444	8F4CC5	1347 343537	DENIS NOVIKOV	{"phone": "+70408765107"}
0005432584445	2220A1	6553 861493	NATALYA POPOVA	{"email": "popovanatalya031974@postgrespro.ru", "phone": "+70476349043"}
0005432584446	2220A1	3850 081465	NIKOLAY ROMANOV	{"phone": "+70526719528"}
0005432584447	2D37BD	2156 953381	YURIY YAKOVLEV	{"email": "yakovlevyuriy.1969@postgrespro.ru", "phone": "+70038955307"}
0005432584448	D443C4	3638 318685	ILYA VOLKOV	{"email": "volkov_i041971@postgrespro.ru", "phone": "+70739010202"}
0005432584449	D443C4	1277 345399	SERGEY GRIGOREV	{"phone": "+70128574741"}
0005432584450	1B2AFA	5835 189169	VALENTINA FEDOROVA	{"email": "fedorova.v-1966@postgrespro.ru", "phone": "+70229518220"}
0005432584451	1B2AFA	4216 283223	ALEKSANDR BORISOV	{"email": "aborisov-041979@postgrespro.ru", "phone": "+70589730782"}
0005432584452	FEE85F	9766 168592	SERGEY FEDOTOV	{"phone": "+70581075535"}
0005432584453	FEE85F	8329 412315	ELIZAVETA KUDRYASHOVA	{"email": "kudryashova-e-041987@postgrespro.ru", "phone": "+70466475922"}
0005432584454	50F3EB	6353 403380	RAMIL KAZAKOV	{"email": "kazakov.r071964@postgrespro.ru", "phone": "+70445111938"}
0005432584455	40A7FD	5824 591782	EMIL KUZNECOV	{"phone": "+70754846622"}
0005432584456	40A7FD	5687 860027	SERGEY IVANOV	{"phone": "+70162082604"}
0005432584457	40A7FD	7008 662736	EVGENIY VOLKOV	{"phone": "+70162148961"}
0005432584458	8A5A33	8343 862006	LYUDMILA SOLOVEVA	{"email": "lsoloveva-1970@postgrespro.ru", "phone": "+70961303955"}
0005432584459	67AAB4	9621 804423	DMITRIY OSIPOV	{"email": "osipov-dmitriy_1973@postgrespro.ru", "phone": "+70093857509"}
0005432584460	67AAB4	3202 923775	PETR FOMIN	{"email": "p.fomin-31071976@postgrespro.ru", "phone": "+70081160797"}
0005432584461	980DEC	3337 727416	NIKOLAY ZAYCEV	{"email": "nikolay_zaycev-09081974@postgrespro.ru", "phone": "+70186203121"}
0005432584462	980DEC	0623 853222	NIKOLAY SHEVCHENKO	{"email": "shevchenko.n_061973@postgrespro.ru", "phone": "+70879781458"}
0005432584463	2D5004	1970 539732	IVAN ROMANOV	{"email": "romanov-i_101966@postgrespro.ru", "phone": "+70206054646"}
0005432584464	23FC8C	3656 564354	VLADIMIR SIDOROV	{"phone": "+70928309525"}
0005432584465	0F34F3	0724 680089	IGOR MAKAROV	{"phone": "+70078997943"}
0005432584466	0F34F3	1613 200715	TATYANA MEDVEDEVA	{"phone": "+70915719506"}
0005432584467	C88C56	6365 538043	IGOR KARPOV	{"email": "igor-karpov_07111979@postgrespro.ru", "phone": "+70806766847"}
0005432584468	221AF8	0723 353471	VALENTINA MASLOVA	{"phone": "+70263681255"}
0005432584469	221AF8	6135 103739	VIKTOR MELNIKOV	{"email": "melnikov-viktor1978@postgrespro.ru", "phone": "+70133155175"}
0005432584470	03545E	6613 816642	VALENTINA MEDVEDEVA	{"phone": "+70654308238"}
0005432584471	27F475	6977 845019	VLADIMIR DENISOV	{"email": "v.denisov_10121974@postgrespro.ru", "phone": "+70911484126"}
0005432584472	27F475	7628 816436	ALEKSANDR KOZLOV	{"email": "a-kozlov.1972@postgrespro.ru", "phone": "+70438410503"}
0005432584473	27F475	3681 493200	VALENTINA DANILOVA	{"email": "danilova-valentina_121971@postgrespro.ru", "phone": "+70796748321"}
0005432584474	144FCB	3732 445795	ANDREY ZAYCEV	{"email": "zaycev.a_1971@postgrespro.ru", "phone": "+70689975691"}
0005432584475	80A5A3	2181 142524	SERGEY VOLKOV	{"email": "sergey.volkov1969@postgrespro.ru", "phone": "+70622116224"}
0005432584476	54696F	3360 598827	IVAN PETROV	{"email": "petrov-ivan14051975@postgrespro.ru", "phone": "+70787864557"}
0005432584477	F34FC2	7023 319330	OLGA MIRONOVA	{"phone": "+70104866509"}
0005432584478	E8962C	7115 277174	VIKTORIYA TARASOVA	{"phone": "+70480876921"}
0005432584479	E8962C	5414 764650	TATYANA SERGEEVA	{"email": "sergeeva-t.011984@postgrespro.ru", "phone": "+70037646543"}
0005432584480	E8962C	7829 483849	NIKOLAY ROMANOV	{"phone": "+70979302426"}
0005432584481	D53BA4	7350 420161	VALERIY EGOROV	{"email": "egorovvaleriy.091984@postgrespro.ru", "phone": "+70756588200"}
0005432584482	C86780	2787 565282	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.s_1969@postgrespro.ru", "phone": "+70787159248"}
0005432584483	552875	5388 756434	NADEZHDA MAKAROVA	{"phone": "+70021835983"}
0005432584484	2582AD	2678 829685	ALEKSEY ALEKSEEV	{"email": "aleksey.alekseev_1972@postgrespro.ru", "phone": "+70518318527"}
0005432584485	601D3D	1977 972957	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr_09021976@postgrespro.ru", "phone": "+70746424824"}
0005432584486	0E362B	7367 374279	VALERIY PAVLOV	{"email": "v_pavlov.1974@postgrespro.ru", "phone": "+70768900651"}
0005432584487	917400	6062 566053	ALEKSANDR KAZAKOV	{"email": "kazakova-20011983@postgrespro.ru", "phone": "+70949855843"}
0005432584488	5DB085	9532 343766	OLESYA ZAYCEVA	{"phone": "+70228500834"}
0005432584489	C26DCD	0108 313633	VLADIMIR VOLKOV	{"phone": "+70447905336"}
0005432584490	5C53BF	2449 246948	ALEKSANDR ZAKHAROV	{"email": "zakharov_a_1967@postgrespro.ru", "phone": "+70504334565"}
0005432584491	1C198D	1740 056087	NIKOLAY RODIONOV	{"email": "n-rodionov.05091971@postgrespro.ru", "phone": "+70281627861"}
0005432584492	A6A4AF	0254 993131	ELENA VOLKOVA	{"phone": "+70671488334"}
0005432584493	AEE7C5	4879 739800	GENNADIY ZAKHAROV	{"email": "zakharov-g1974@postgrespro.ru", "phone": "+70647260593"}
0005432584494	AEE7C5	9154 507406	ALLA ZHURAVLEVA	{"phone": "+70358718206"}
0005432584495	69C162	3454 124658	ALEKSEY MAKAROV	{"email": "alekseymakarov_05011968@postgrespro.ru", "phone": "+70384113811"}
0005432584496	8580D6	2571 676929	EVGENIY POPOV	{"email": "e.popov_121976@postgrespro.ru", "phone": "+70807890061"}
0005432584497	CB35DA	8770 560347	VIKTOR NIKOLAEV	{"email": "viktor-nikolaev_1967@postgrespro.ru", "phone": "+70138457182"}
0005432584498	ED58CE	5107 374381	YURIY ZAKHAROV	{"email": "zakharov_yuriy-1971@postgrespro.ru", "phone": "+70667195624"}
0005432584499	77803F	5417 818176	LARISA IVANOVA	{"phone": "+70971043786"}
0005432584500	77803F	5877 991851	ALEKSEY SERGEEV	{"email": "a.sergeev021982@postgrespro.ru", "phone": "+70112817356"}
0005432584501	00EDF4	9870 784455	ZHANNA LUKYANOVA	{"email": "lukyanova.z051974@postgrespro.ru", "phone": "+70655302344"}
0005432584502	584B45	7681 851882	VALERIY KOZLOV	{"phone": "+70109676735"}
0005432584503	E4808A	3187 479661	NINA ALEKSANDROVA	{"email": "n-aleksandrova_30041971@postgrespro.ru", "phone": "+70334895958"}
0005432584504	E4808A	0156 879670	VASILIY TIKHONOV	{"email": "tikhonovv091970@postgrespro.ru", "phone": "+70050884836"}
0005432584505	D1E7B2	9454 737050	POLINA FILIPPOVA	{"phone": "+70414862557"}
0005432584506	FBA7FB	9731 011369	OLGA BORISOVA	{"email": "olga_borisova13081972@postgrespro.ru", "phone": "+70668135291"}
0005432584507	FBA7FB	7702 883796	ALEKSANDR ZAKHAROV	{"phone": "+70144248774"}
0005432584508	BCB484	3233 504953	SERGEY BORISOV	{"phone": "+70695817695"}
0005432584509	A736F6	8533 112843	MAKSIM BONDARENKO	{"email": "maksimbondarenko30081982@postgrespro.ru", "phone": "+70141806805"}
0005432584510	740657	6556 482115	ANNA NESTEROVA	{"phone": "+70653827944"}
0005432584511	6DC969	0506 012320	NIKOLAY SMIRNOV	{"phone": "+70399760837"}
0005432584512	6DC969	1762 006732	RAFIK ABRAMOV	{"email": "abramov-rafik.21021972@postgrespro.ru", "phone": "+70074500122"}
0005432584513	401858	6013 766098	VLADIMIR YAKOVLEV	{"phone": "+70920668869"}
0005432584514	9A90A8	3331 540661	OLEG MATVEEV	{"email": "matveev_o_17051975@postgrespro.ru", "phone": "+70025002797"}
0005432584515	9A90A8	0331 335691	EKATERINA FADEEVA	{"phone": "+70665793530"}
0005432584516	50B3C9	1889 787698	SOFIYA ERMAKOVA	{"email": "s-ermakova_1981@postgrespro.ru", "phone": "+70103421690"}
0005432584517	50B3C9	8828 980546	NIKOLAY ALEKSANDROV	{"phone": "+70592485088"}
0005432584518	F7E69A	5267 273739	NIKOLAY MELNIKOV	{"email": "n_melnikov_02051971@postgrespro.ru", "phone": "+70240373565"}
0005432584519	F7E69A	6530 329224	OLGA MASLOVA	{"phone": "+70089054791"}
0005432584520	127460	0200 226442	PAVEL DAVYDOV	{"email": "pavel_davydov-12121971@postgrespro.ru", "phone": "+70762689189"}
0005432584521	27E316	9536 289215	VERONIKA VASILEVA	{"phone": "+70875995612"}
0005432584522	27E316	7630 874994	IRINA BORISOVA	{"email": "irinaborisova-02061973@postgrespro.ru", "phone": "+70112984541"}
0005432584523	05E731	5429 402446	PETR ANTONOV	{"phone": "+70234074273"}
0005432584524	05E731	9398 835408	LYUBOV CHERNOVA	{"email": "chernovalyubov051969@postgrespro.ru", "phone": "+70503732699"}
0005432584525	F1E178	9220 943946	NATALYA BORISOVA	{"phone": "+70321355136"}
0005432584526	F1E178	8658 268170	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov.1984@postgrespro.ru", "phone": "+70182893031"}
0005432584527	D94B1C	9595 853351	ANATOLIY ANTONOV	{"phone": "+70383171863"}
0005432584528	1289AA	3072 211408	MARIYA FILATOVA	{"phone": "+70519238234"}
0005432584529	632322	4385 769432	VALENTINA STEPANOVA	{"email": "v.stepanova.051972@postgrespro.ru", "phone": "+70741940824"}
0005432584530	632322	0356 855888	ALEKSANDR VASILEV	{"phone": "+70636240549"}
0005432584531	0AE925	9751 033107	NINA ZAYCEVA	{"email": "nina_zayceva1966@postgrespro.ru", "phone": "+70933599479"}
0005432584532	0AE925	7400 157407	NINA MOROZOVA	{"email": "morozova_n-1962@postgrespro.ru", "phone": "+70604676509"}
0005432584533	E5141D	6183 571547	ANASTASIYA ALEKSANDROVA	{"phone": "+70593336095"}
0005432584534	E5141D	4130 072632	ALFIYA VLASOVA	{"email": "avlasova-28081969@postgrespro.ru", "phone": "+70699309777"}
0005432584535	91A1E2	9080 294627	OLEG BONDARENKO	{"email": "bondarenko_o_101976@postgrespro.ru", "phone": "+70276077980"}
0005432584536	A477AC	6141 898809	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr031973@postgrespro.ru", "phone": "+70503721116"}
0005432584537	A93150	3410 014078	SABINA YUDINA	{"phone": "+70019267533"}
0005432584538	9FA92D	9021 969872	ALEKSEY SCHERBAKOV	{"phone": "+70393668918"}
0005432584539	92E673	1339 636659	RINAT MIRONOV	{"email": "mironov_r_071971@postgrespro.ru", "phone": "+70223545405"}
0005432584540	EE1DFC	9397 926623	MIKHAIL ROMANOV	{"phone": "+70028544509"}
0005432584541	44ABF7	7827 799498	TATYANA GORBUNOVA	{"email": "gorbunova_t021977@postgrespro.ru", "phone": "+70661854624"}
0005432584542	44ABF7	3628 782375	ANASTASIYA DAVYDOVA	{"email": "a_davydova.1971@postgrespro.ru", "phone": "+70819776616"}
0005432584543	191941	2904 314765	ANASTASIYA ZOTOVA	{"email": "zotova-anastasiya1973@postgrespro.ru", "phone": "+70530724459"}
0005432584544	674966	2343 201081	MIKHAIL NAZAROV	{"email": "nazarovm.031970@postgrespro.ru", "phone": "+70768070275"}
0005432584545	A1EAFB	2671 313725	VERONIKA TIMOFEEVA	{"email": "timofeeva-veronika1976@postgrespro.ru", "phone": "+70729507889"}
0005432584546	BB3576	8904 388796	MAKSIM KUZMIN	{"phone": "+70645886483"}
0005432584547	BB3576	6303 692950	TATYANA ANDREEVA	{"phone": "+70289844485"}
0005432584548	BB3576	9222 561842	SERGEY EGOROV	{"email": "egorov-s-1964@postgrespro.ru", "phone": "+70160898805"}
0005432584549	46283A	2519 763925	MIKHAIL IVANOV	{"phone": "+70772088883"}
0005432584550	22C8E1	2616 758893	NIKOLAY ORLOV	{"email": "nikolay.orlov1969@postgrespro.ru", "phone": "+70664687263"}
0005432584551	1016D5	1498 567287	EVGENIYA BORISOVA	{"email": "borisovaevgeniya-021980@postgrespro.ru", "phone": "+70599908295"}
0005432584552	1016D5	9676 483436	RAISA ANTONOVA	{"phone": "+70228717620"}
0005432584553	CAA7D3	8027 512505	MARIYA BELOVA	{"phone": "+70473591873"}
0005432584554	862FB1	4970 843957	NIKOLAY SMIRNOV	{"phone": "+70300185377"}
0005432584555	C47129	2799 505433	YULIYA TIKHONOVA	{"phone": "+70536100173"}
0005432584556	C47129	2844 364447	ELENA VOLKOVA	{"email": "volkova.elena18041962@postgrespro.ru", "phone": "+70817344552"}
0005432584557	677798	2190 671114	KRISTINA EGOROVA	{"email": "kegorova.1975@postgrespro.ru", "phone": "+70261782023"}
0005432584558	C7F570	9891 210335	LYUDMILA SCHERBAKOVA	{"email": "lyudmila_scherbakova121976@postgrespro.ru", "phone": "+70923580023"}
0005432584559	C7F570	3776 297434	ELENA BARANOVA	{"phone": "+70071604217"}
0005432584560	C7F570	9428 626604	GALINA KULIKOVA	{"email": "kulikovagalina_27111978@postgrespro.ru", "phone": "+70377981593"}
0005432584561	7C46D0	3869 246477	GENNADIY SOKOLOV	{"email": "gennadiy_sokolov06091984@postgrespro.ru", "phone": "+70044650951"}
0005432584562	7C46D0	6038 376574	KLARA SEMENOVA	{"phone": "+70433884090"}
0005432584563	B808F6	0194 839735	YURIY EGOROV	{"phone": "+70354666301"}
0005432584564	B808F6	1529 102165	RENAT KOZLOV	{"phone": "+70388689350"}
0005432584565	B808F6	9455 256226	EGOR SERGEEV	{"email": "sergeev-egor.1968@postgrespro.ru", "phone": "+70247239447"}
0005432584566	E0B434	7403 107175	KIRILL SIDOROV	{"email": "sidorov_k-051986@postgrespro.ru", "phone": "+70346200538"}
0005432584567	338CB1	8259 243470	NIKITA RODIONOV	{"email": "nikita.rodionov041974@postgrespro.ru", "phone": "+70294473849"}
0005432584568	95C33D	0634 117896	VLADIMIR NAZAROV	{"email": "nazarov-vladimir-15031965@postgrespro.ru", "phone": "+70371379433"}
0005432584569	14FEE8	2354 209382	ELVIRA KOZLOVA	{"phone": "+70383569115"}
0005432584570	14FEE8	5868 520894	ANNA MEDVEDEVA	{"phone": "+70654870427"}
0005432584571	E39424	0338 948306	IRINA SEMENOVA	{"phone": "+70643975274"}
0005432584572	E39424	8226 744020	ANATOLIY FEDOROV	{"phone": "+70146392949"}
0005432584573	E0245A	3886 872974	EVGENIYA VASILEVA	{"phone": "+70597756467"}
0005432584574	900B58	3473 738743	VYACHESLAV KUZNECOV	{"email": "kuznecov.v-11061969@postgrespro.ru", "phone": "+70709521886"}
0005432584575	900B58	6647 828030	ALEKSANDR CHERNOV	{"phone": "+70960839999"}
0005432584576	900B58	8073 790655	ARTEM SOROKIN	{"phone": "+70841459861"}
0005432584577	8AF69E	0747 702432	NIKOLAY KISELEV	{"phone": "+70947903694"}
0005432584578	054EB8	1599 240876	OLGA OVCHINNIKOVA	{"email": "olgaovchinnikova-20041974@postgrespro.ru", "phone": "+70577897530"}
0005432584579	E3E5C8	1606 514154	POLINA KONDRATEVA	{"email": "kondrateva.polina081978@postgrespro.ru", "phone": "+70929053103"}
0005432584580	9AA133	1476 496741	TATYANA KOROLEVA	{"phone": "+70335659553"}
0005432584581	9AA133	9588 489278	MARIYA FROLOVA	{"phone": "+70419382825"}
0005432584582	709E4A	9640 546939	EVGENIY SIDOROV	{"email": "sidorov.e-18041981@postgrespro.ru", "phone": "+70389104624"}
0005432584583	709E4A	3634 703899	ANTON SEMENOV	{"email": "anton_semenov021969@postgrespro.ru", "phone": "+70976508642"}
0005432584584	569165	8402 266237	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr111978@postgrespro.ru", "phone": "+70302837623"}
0005432584585	569165	5999 734039	IVAN KUZNECOV	{"phone": "+70374009654"}
0005432584586	569165	7965 198460	GENNADIY YAKOVLEV	{"email": "gyakovlev.101968@postgrespro.ru", "phone": "+70411919243"}
0005432584587	A992F9	4235 741768	SERGEY FROLOV	{"phone": "+70136251357"}
0005432584588	A992F9	8821 322615	TATYANA ZAKHAROVA	{"email": "zakharovatatyana.1976@postgrespro.ru", "phone": "+70556389639"}
0005432584589	D4991C	5999 726208	ANNA GUSEVA	{"email": "a.guseva_11031974@postgrespro.ru", "phone": "+70207198300"}
0005432584590	F9DC7B	2986 559308	MIKHAIL SERGEEV	{"email": "sergeev.m.03081975@postgrespro.ru", "phone": "+70507472497"}
0005432584591	C6CF20	4531 687137	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov_061972@postgrespro.ru", "phone": "+70499042404"}
0005432584592	CBD35B	5230 714222	DENIS KOZLOV	{"email": "denis_kozlov.1962@postgrespro.ru", "phone": "+70417552337"}
0005432584593	CBD35B	6827 522965	ELIZAVETA VOLKOVA	{"email": "e-volkova1966@postgrespro.ru", "phone": "+70066719432"}
0005432584594	7DFC81	4548 980655	VLADIMIR MOROZOV	{"phone": "+70451597050"}
0005432584595	7DFC81	5071 908831	VLADIMIR DMITRIEV	{"email": "v_dmitriev.01121965@postgrespro.ru", "phone": "+70430202768"}
0005432584596	7D1F78	5128 111701	EKATERINA ARKHIPOVA	{"email": "e_arkhipova.1968@postgrespro.ru", "phone": "+70423986846"}
0005432584597	B49F1A	2428 803943	ALEKSANDR AFANASEV	{"phone": "+70294276789"}
0005432584598	B116A1	2742 897116	VERA MASLOVA	{"phone": "+70815228959"}
0005432584599	B116A1	0080 872981	OLGA MAKSIMOVA	{"phone": "+70570619796"}
0005432584600	C7CB2B	4734 631299	NINA YUDINA	{"phone": "+70387558789"}
0005432584601	9BA869	8888 981744	VADIM MIRONOV	{"phone": "+70709419061"}
0005432584602	9BA869	7888 959161	MARIYA POPOVA	{"phone": "+70226128341"}
0005432584603	7721B5	1448 945620	SERGEY SIDOROV	{"email": "s-sidorov.1968@postgrespro.ru", "phone": "+70383575841"}
0005432584604	A59BDE	7294 770604	ARINA VOROBEVA	{"phone": "+70602397302"}
0005432584605	A59BDE	0847 258101	NADEZHDA KUZNECOVA	{"email": "kuznecova_n_051964@postgrespro.ru", "phone": "+70622723933"}
0005432584606	5CE88A	9981 771431	TATYANA BELOVA	{"phone": "+70482090429"}
0005432584607	5CE88A	1452 824338	VALENTIN SHEVCHENKO	{"phone": "+70367569108"}
0005432584608	33CB75	5311 944040	DMITRIY KOZLOV	{"phone": "+70351339735"}
0005432584609	66DEE9	3871 281781	RAIS FEDOROV	{"email": "r.fedorov-021968@postgrespro.ru", "phone": "+70990156590"}
0005432584610	3847BB	3457 158676	MIKHAIL KOROLEV	{"email": "m-korolev-05081972@postgrespro.ru", "phone": "+70449208045"}
0005432584611	FF4149	1836 588805	PAVEL ISAEV	{"phone": "+70202794085"}
0005432584612	219439	3074 532147	SOFYA SCHERBAKOVA	{"email": "scherbakova.s-21091980@postgrespro.ru", "phone": "+70533573268"}
0005432584613	219439	7584 695174	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr_1973@postgrespro.ru", "phone": "+70104412207"}
0005432584614	2C236F	1399 399294	ALEKSANDR KOZLOV	{"phone": "+70094641843"}
0005432584615	2C236F	8768 358552	DMITRIY SEMENOV	{"phone": "+70912232104"}
0005432584616	920029	6432 709917	YURIY ALEKSANDROV	{"email": "yuriy_aleksandrov-28011981@postgrespro.ru", "phone": "+70019543699"}
0005432584617	920029	1232 243842	KONSTANTIN NAUMOV	{"phone": "+70278163312"}
0005432584618	14268E	5998 544551	VLADIMIR SIDOROV	{"email": "sidorov-vladimir_09061978@postgrespro.ru", "phone": "+70633395599"}
0005432584619	E02B2C	9612 985028	MIKHAIL KUZNECOV	{"phone": "+70397159953"}
0005432584620	E02B2C	7507 187190	VALENTIN IVANOV	{"email": "ivanov-v_21061970@postgrespro.ru", "phone": "+70667628949"}
0005432584621	B4962B	6489 617053	VLADIMIR KISELEV	{"email": "kiselev_vladimir.02051975@postgrespro.ru", "phone": "+70685446875"}
0005432584622	B4962B	7724 373956	ALEKSEY NAUMOV	{"email": "naumov-aleksey021973@postgrespro.ru", "phone": "+70623637241"}
0005432584623	AEB906	9464 887464	MARIYA KULIKOVA	{"email": "kulikova.mariya-091960@postgrespro.ru", "phone": "+70232850905"}
0005432584624	D196D7	6650 617391	ANATOLIY GORBUNOV	{"email": "gorbunovanatoliy.041969@postgrespro.ru", "phone": "+70061608219"}
0005432584625	D196D7	6427 546471	NINA SMIRNOVA	{"phone": "+70644189969"}
0005432584626	6828DB	7229 833753	YULIYA RYABOVA	{"email": "yryabova-101975@postgrespro.ru", "phone": "+70137514107"}
0005432584627	DAE654	6247 572988	LARISA TIMOFEEVA	{"phone": "+70815934240"}
0005432584628	50C842	6072 234854	NATALYA OSIPOVA	{"email": "osipova_natalya-071985@postgrespro.ru", "phone": "+70488661693"}
0005432584629	50C842	5659 542281	SOFYA ABRAMOVA	{"phone": "+70393918219"}
0005432584630	AF658E	5624 109152	ANATOLIY KISELEV	{"email": "anatoliy.kiselev.09081973@postgrespro.ru", "phone": "+70991813698"}
0005432584631	AF658E	4242 618674	ELENA ABRAMOVA	{"phone": "+70281859293"}
0005432584632	2F696A	7411 496000	VASILISA SAVELEVA	{"email": "vasilisasaveleva_021972@postgrespro.ru", "phone": "+70288080849"}
0005432584633	7770D1	0303 163470	ANASTASIYA SOKOLOVA	{"phone": "+70546009820"}
0005432584634	204AF4	4333 076510	OLGA ROMANOVA	{"phone": "+70586800916"}
0005432584635	3F72DC	9750 245544	ALEKSANDRA ZHURAVLEVA	{"email": "zhuravleva.aleksandra.081967@postgrespro.ru", "phone": "+70910448679"}
0005432584636	4D9D25	1191 271434	VLADISLAV SEMENOV	{"phone": "+70970221159"}
0005432584637	5E9FDB	8715 295456	SEMEN NIKITIN	{"phone": "+70064625645"}
0005432584638	5E9FDB	1381 599557	ROMAN ALEKSANDROV	{"phone": "+70407222808"}
0005432584639	108312	6464 959573	ANNA KONOVALOVA	{"phone": "+70066359148"}
0005432584640	381FFC	0569 164029	IVAN MIKHAYLOV	{"phone": "+70294902249"}
0005432584641	10BB86	9857 269672	ALFIYA ALEKSANDROVA	{"email": "aaleksandrova.091969@postgrespro.ru", "phone": "+70134489958"}
0005432584642	46F4D9	3939 049980	DMITRIY IVANOV	{"phone": "+70453071766"}
0005432584643	D37505	5842 107617	NIKOLAY ALEKSEEV	{"email": "alekseevnikolay16021964@postgrespro.ru", "phone": "+70847260007"}
0005432584644	C4EBFB	1812 233000	MIKHAIL KOZLOV	{"phone": "+70187652524"}
0005432584645	814C9E	4607 080288	VALENTINA VASILEVA	{"phone": "+70974611905"}
0005432584646	D7BA38	9639 263256	MARIYA POLYAKOVA	{"phone": "+70581048807"}
0005432584647	D7BA38	3293 245008	EKATERINA MELNIKOVA	{"phone": "+70066801750"}
0005432584648	5492B3	5067 590432	OLGA YUDINA	{"phone": "+70127954620"}
0005432584649	AC8483	7650 133851	ALEKSANDRA SERGEEVA	{"email": "sergeeva-aleksandra1969@postgrespro.ru", "phone": "+70168599280"}
0005432584650	4E1D31	1170 247196	LILIYA SEMENOVA	{"phone": "+70998169818"}
0005432584651	BB8ABB	0517 360406	IRINA IVANOVA	{"email": "ivanova_irina_041978@postgrespro.ru", "phone": "+70314948391"}
0005432584652	BB8ABB	7579 049226	ALEKSANDR SAVELEV	{"phone": "+70967719413"}
0005432584653	211D34	6673 786658	NIKOLAY GORBUNOV	{"phone": "+70358442685"}
0005432584654	B96B25	9883 400889	SVETLANA FILIPPOVA	{"phone": "+70773982601"}
0005432584655	906F4E	9007 527658	GENNADIY ZHURAVLEV	{"phone": "+70761884972"}
0005432584656	383A65	6181 238797	EKATERINA VOLKOVA	{"email": "volkova_ekaterina.22021974@postgrespro.ru", "phone": "+70578585187"}
0005432584657	383A65	4661 406819	ILYA KULIKOV	{"phone": "+70838416721"}
0005432584658	383A65	7964 769023	EKATERINA BORISOVA	{"phone": "+70482911853"}
0005432584659	B5D3C0	4527 044797	ROMAN ROMANOV	{"phone": "+70303203650"}
0005432584660	B838D5	2765 157656	TATYANA KRASNOVA	{"email": "t.krasnova.041964@postgrespro.ru", "phone": "+70698038742"}
0005432584661	B838D5	1861 994628	ALEKSANDR VASILEV	{"phone": "+70334583881"}
0005432584662	77D0FB	5870 803597	GENNADIY TIKHONOV	{"phone": "+70422307234"}
0005432584663	0B4749	2255 653765	GENNADIY FROLOV	{"phone": "+70406031602"}
0005432584664	13CD79	5257 688005	KONSTANTIN ZAYCEV	{"phone": "+70043341103"}
0005432584665	13CD79	7727 381995	LYUDMILA SMIRNOVA	{"phone": "+70887498229"}
0005432584666	13CD79	0939 268734	ALEKSEY DENISOV	{"email": "adenisov_041965@postgrespro.ru", "phone": "+70579336441"}
0005432584667	5D0DAF	3303 319060	SERGEY ISAEV	{"phone": "+70231352337"}
0005432584668	CDF26F	6227 159480	OLGA SOROKINA	{"email": "olga.sorokina121972@postgrespro.ru", "phone": "+70189252631"}
0005432584669	189514	6066 326608	ROMAN KONOVALOV	{"email": "romankonovalov_04101976@postgrespro.ru", "phone": "+70749045131"}
0005432584670	189514	9639 298017	TATYANA NIKIFOROVA	{"phone": "+70671630757"}
0005432584671	C9677D	9617 912063	ZINAIDA YAKOVLEVA	{"email": "yakovlevaz1968@postgrespro.ru", "phone": "+70059672678"}
0005432584672	C9677D	8923 516047	DMITRIY MOROZOV	{"email": "morozov-d031965@postgrespro.ru", "phone": "+70421785307"}
0005432584673	C0DE31	6652 777857	VALERIY NIKOLAEV	{"email": "nikolaev_valeriy091975@postgrespro.ru", "phone": "+70623297928"}
0005432584674	023F92	8001 585828	SVETLANA MEDVEDEVA	{"email": "svetlana_medvedeva111971@postgrespro.ru", "phone": "+70435890890"}
0005432584675	1A6C88	0289 653710	LYUDMILA BORISOVA	{"email": "borisova-l-11111974@postgrespro.ru", "phone": "+70981879807"}
0005432584676	376876	2429 225036	IRINA SERGEEVA	{"phone": "+70421058627"}
0005432584677	418591	0285 369578	VLADISLAV MOROZOV	{"phone": "+70130854799"}
0005432584678	585C6F	9889 605455	VLADIMIR NAUMOV	{"phone": "+70803397227"}
0005432584679	585C6F	8031 161648	ANASTASIYA BORISOVA	{"email": "anastasiya.borisova1966@postgrespro.ru", "phone": "+70918399545"}
0005432584680	DA1B0F	9503 675317	DILYARA SOROKINA	{"email": "d.sorokina.20091971@postgrespro.ru", "phone": "+70837353112"}
0005432584681	DA1B0F	4803 608854	ANASTASIYA MIKHAYLOVA	{"phone": "+70803230099"}
0005432584682	E6D638	4149 700490	OLGA MARTYNOVA	{"email": "martynovaolga_1983@postgrespro.ru", "phone": "+70518058639"}
0005432584683	E6D638	4162 736616	VLADIMIR NAUMOV	{"phone": "+70098847488"}
0005432584684	CD6133	5892 595219	ANTONINA ANDREEVA	{"phone": "+70406332958"}
0005432584685	2D962B	9749 597911	NIKITA MARTYNOV	{"phone": "+70387572711"}
0005432584686	2D962B	9513 098728	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov_15081979@postgrespro.ru", "phone": "+70688617762"}
0005432584687	2D962B	9494 686687	ANTON KUZNECOV	{"email": "kuznecovanton13081966@postgrespro.ru", "phone": "+70845620983"}
0005432584688	8B4978	7776 062228	AYRAT SMIRNOV	{"email": "a-smirnov101981@postgrespro.ru", "phone": "+70469769844"}
0005432584689	CA7B5A	9002 955060	SERGEY KISELEV	{"email": "s_kiselev17091970@postgrespro.ru", "phone": "+70187924660"}
0005432584690	0D375D	6655 220507	YURIY NIKITIN	{"email": "nikitin_y091978@postgrespro.ru", "phone": "+70602618586"}
0005432584691	C207C2	7603 078857	KONSTANTIN PAVLOV	{"phone": "+70310415765"}
0005432584692	7D7079	3417 060232	DARYA PAVLOVA	{"email": "darya-pavlova-29051968@postgrespro.ru", "phone": "+70458767203"}
0005432584693	CC18C3	1054 693774	ZINAIDA KUZNECOVA	{"phone": "+70886905073"}
0005432584694	91DB25	0644 607258	SERGEY PAVLOV	{"email": "sergey_pavlov-27111972@postgrespro.ru", "phone": "+70741861543"}
0005432584695	C9C326	7613 034082	SVETLANA SOKOLOVA	{"phone": "+70079657126"}
0005432584696	C9C326	4462 699570	YURIY GORBUNOV	{"phone": "+70005509434"}
0005432584697	27B928	0055 952190	IGOR SCHERBAKOV	{"email": "scherbakov.i-02031984@postgrespro.ru", "phone": "+70242645430"}
0005432584698	27B928	8357 447245	ZINAIDA ROMANOVA	{"email": "romanovazinaida_1966@postgrespro.ru", "phone": "+70896141182"}
0005432584699	8EE08B	8538 099457	IRINA PETROVA	{"email": "irina-petrova-10111966@postgrespro.ru", "phone": "+70416602923"}
0005432584700	BD570D	7061 155814	ELIZAVETA ALEKSANDROVA	{"phone": "+70070047352"}
0005432584701	BD570D	5573 384033	VIKTOR POPOV	{"phone": "+70486734863"}
0005432584702	736582	7875 393900	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova23101974@postgrespro.ru", "phone": "+70092468394"}
0005432584703	9A10EE	5721 707539	ALESYA ZHUKOVA	{"phone": "+70877158405"}
0005432584704	9A10EE	8118 188994	RADIK ROMANOV	{"phone": "+70002496619"}
0005432584705	9A10EE	5329 540960	EDUARD SMIRNOV	{"email": "e-smirnov.10121986@postgrespro.ru", "phone": "+70652195377"}
0005432584706	FB3CF9	3426 321353	MARIYA TIMOFEEVA	{"email": "timofeeva.mariya071963@postgrespro.ru", "phone": "+70400524160"}
0005432584707	DEE5F1	1459 930746	NINA SOKOLOVA	{"email": "nina_sokolova-1965@postgrespro.ru", "phone": "+70309971678"}
0005432584708	B78E2A	9360 388680	GALINA ALEKSEEVA	{"email": "alekseeva_g_121974@postgrespro.ru", "phone": "+70309771051"}
0005432584709	D4C584	0215 446278	ALEKSEY FEDOTOV	{"phone": "+70300260010"}
0005432584710	D4C584	2669 551228	EVGENIY SCHERBAKOV	{"email": "e.scherbakov_111973@postgrespro.ru", "phone": "+70290093723"}
0005432584711	D4C584	4056 405123	KIRILL VASILEV	{"email": "vasilev.kirill-111969@postgrespro.ru", "phone": "+70707719110"}
0005432584712	94C411	4795 506799	ZOYA OSIPOVA	{"email": "zoya-osipova-1968@postgrespro.ru", "phone": "+70234002684"}
0005432584713	AB2C25	1328 660313	KLAVDIYA FROLOVA	{"email": "frolova.klavdiya071963@postgrespro.ru", "phone": "+70165334388"}
0005432584714	D6D536	4306 303490	NATALIYA MATVEEVA	{"phone": "+70911072020"}
0005432584715	D6D536	9971 453278	ALEKSANDR ZAKHAROV	{"email": "azakharov_10031978@postgrespro.ru", "phone": "+70917108753"}
0005432584716	D6D536	4023 324655	OLGA RODIONOVA	{"email": "olgarodionova051963@postgrespro.ru", "phone": "+70012486538"}
0005432584717	0DC1B4	0829 191128	NATALYA KISELEVA	{"email": "kiseleva-natalya.08071979@postgrespro.ru", "phone": "+70196888013"}
0005432584718	D7046E	9223 533441	NADEZHDA SOKOLOVA	{"phone": "+70368252585"}
0005432584719	D7046E	7464 519290	DMITRIY IVANOV	{"email": "d_ivanov.081963@postgrespro.ru", "phone": "+70149723191"}
0005432584720	66C67A	1072 539211	ELENA NAZAROVA	{"email": "e-nazarova_1971@postgrespro.ru", "phone": "+70410675379"}
0005432584721	65B2FC	8851 166919	ANASTASIYA PETROVA	{"email": "anastasiya_petrova-1978@postgrespro.ru", "phone": "+70425562015"}
0005432584722	65B2FC	3011 064061	SERGEY SEMENOV	{"phone": "+70579497472"}
0005432584723	DBAB14	4392 499475	IRINA KALININA	{"phone": "+70580956204"}
0005432584724	DBAB14	8448 464638	ARTUR DENISOV	{"email": "denisov_a.1975@postgrespro.ru", "phone": "+70287486343"}
0005432584725	DEDB13	9831 508981	MAKSIM NIKITIN	{"phone": "+70225721219"}
0005432584726	DEDB13	5191 415759	SERGEY NAZAROV	{"phone": "+70975194818"}
0005432584727	BBF184	6860 672352	ANTONINA KUZMINA	{"phone": "+70045218631"}
0005432584728	18CC23	9810 741545	SERGEY MELNIKOV	{"email": "s_melnikov-09031970@postgrespro.ru", "phone": "+70518119355"}
0005432584729	787C0F	7363 048208	ANTONINA YAKOVLEVA	{"email": "yakovlevaa-1973@postgrespro.ru", "phone": "+70324917769"}
0005432584730	CD3BE1	0440 425775	ALEKSANDR KRASNOV	{"phone": "+70609116737"}
0005432584731	CD3BE1	6445 189448	LIDIYA GORBUNOVA	{"email": "gorbunova.l-25071974@postgrespro.ru", "phone": "+70673789048"}
0005432584732	CD3BE1	2805 113006	NADEZHDA SAVELEVA	{"phone": "+70812373156"}
0005432584733	22FCC5	2671 397821	KSENIYA ALEKSANDROVA	{"phone": "+70968406839"}
0005432584734	535C2E	1890 993018	OLEG KONOVALOV	{"phone": "+70234699613"}
0005432584735	2C3092	1685 669337	ANASTASIYA POPOVA	{"phone": "+70382085212"}
0005432584736	404030	6348 035108	VALENTINA SOLOVEVA	{"email": "vsoloveva_1978@postgrespro.ru", "phone": "+70880085783"}
0005432584737	404030	9320 210865	NIKOLAY ALEKSEEV	{"phone": "+70276878665"}
0005432584738	FD8A83	6821 892160	MARIYA KUZNECOVA	{"email": "mariya.kuznecova.121973@postgrespro.ru", "phone": "+70656496577"}
0005432584739	2F6358	5702 902797	TATYANA POPOVA	{"phone": "+70367356081"}
0005432584740	CD1EF5	6883 378344	DMITRIY ALEKSANDROV	{"phone": "+70439910779"}
0005432584741	384622	1396 301039	SERGEY NIKOLAEV	{"email": "sergeynikolaev.011985@postgrespro.ru", "phone": "+70064379656"}
0005432584742	384622	6438 590549	DENIS KRASNOV	{"phone": "+70614870988"}
0005432584743	FACC66	4670 268323	ANASTASIYA TIKHONOVA	{"phone": "+70727508552"}
0005432584744	B297B2	1434 141177	LYUBOV FEDOROVA	{"phone": "+70639174221"}
0005432584745	B297B2	1349 402098	NATALYA MIKHAYLOVA	{"phone": "+70754159423"}
0005432584746	3E85AD	1265 643213	VERA PETROVA	{"phone": "+70309116885"}
0005432584747	3E85AD	4421 130062	ANATOLIY YAKOVLEV	{"email": "yakovleva-1966@postgrespro.ru", "phone": "+70748000310"}
0005432584748	3E85AD	1414 492852	ANNA BORISOVA	{"email": "borisova-anna.1970@postgrespro.ru", "phone": "+70450758458"}
0005432584749	BD494C	8624 587027	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey-121973@postgrespro.ru", "phone": "+70145940706"}
0005432584750	D7426D	1409 996069	LYUDMILA ARKHIPOVA	{"phone": "+70850069628"}
0005432584751	393406	8825 471287	NATALYA DANILOVA	{"email": "danilovanatalya.1987@postgrespro.ru", "phone": "+70740340329"}
0005432584752	C7A162	6753 632290	ANNA POLYAKOVA	{"email": "anna-polyakova_011974@postgrespro.ru", "phone": "+70566768028"}
0005432584753	C7A162	7033 984530	NATALYA ZHURAVLEVA	{"email": "zhuravleva_n-081978@postgrespro.ru", "phone": "+70096778429"}
0005432584754	B03CF5	7551 167196	YULIYA EFIMOVA	{"email": "y.efimova_031976@postgrespro.ru", "phone": "+70499551426"}
0005432584755	B03CF5	8605 451333	ALEKSEY FOMIN	{"email": "a-fomin1981@postgrespro.ru", "phone": "+70748062722"}
0005432584756	CB4062	6063 683113	PAVEL STEPANOV	{"email": "pavel-stepanov1973@postgrespro.ru", "phone": "+70927846173"}
0005432584757	D19361	6978 319068	SVETLANA LEBEDEVA	{"email": "lebedeva-s25021981@postgrespro.ru", "phone": "+70544992756"}
0005432584758	51B88A	3263 043133	VALENTINA KOVALEVA	{"email": "kovalevavalentina_111971@postgrespro.ru", "phone": "+70077037593"}
0005432584759	802CA0	1862 264519	NATALYA ROMANOVA	{"email": "romanovan_1972@postgrespro.ru", "phone": "+70563319747"}
0005432584760	F7E62C	0374 735946	VALERIYA ABRAMOVA	{"email": "abramova_v.1961@postgrespro.ru", "phone": "+70401897951"}
0005432584761	F7E62C	6832 544736	IVAN KAZAKOV	{"phone": "+70359769743"}
0005432584762	3A1227	6807 145797	MARIYA ANISIMOVA	{"email": "anisimova-mariya071971@postgrespro.ru", "phone": "+70863240390"}
0005432584763	3A1227	0423 272618	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov_051961@postgrespro.ru", "phone": "+70609811745"}
0005432584764	3A1227	3330 440156	ALEKSEY NAUMOV	{"email": "aleksey_naumov_1976@postgrespro.ru", "phone": "+70755962311"}
0005432584765	865CD4	1710 618131	EKATERINA MARTYNOVA	{"phone": "+70570980678"}
0005432584766	ECF1E1	4996 838059	ELENA BELYAEVA	{"email": "belyaeva.e_07021960@postgrespro.ru", "phone": "+70175409623"}
0005432584767	AA647D	2857 099465	ELENA TITOVA	{"email": "e-titova-1973@postgrespro.ru", "phone": "+70994931403"}
0005432584768	AA647D	6811 893255	NINA LUKYANOVA	{"phone": "+70396382789"}
0005432584769	B3A603	8588 603672	NATALYA RODIONOVA	{"email": "rodionova_natalya22051969@postgrespro.ru", "phone": "+70114212569"}
0005432584770	FE2B0F	4948 975430	ELENA VLASOVA	{"phone": "+70673557996"}
0005432584771	E21393	6642 004884	LIDIYA ALEKSANDROVA	{"email": "aleksandrova_l-04121964@postgrespro.ru", "phone": "+70932658211"}
0005432584772	E21393	3514 732661	ARTEMIY BELOV	{"phone": "+70444011260"}
0005432584773	E38234	1786 678301	ANNA PAVLOVA	{"phone": "+70419784299"}
0005432584774	E38234	0170 750738	EVGENIY GAVRILOV	{"phone": "+70030263091"}
0005432584775	E38234	4983 305086	NINA AKIMOVA	{"phone": "+70959164178"}
0005432584776	54F2FD	5144 917823	DMITRIY ALEKSEEV	{"email": "dmitriyalekseev-1983@postgrespro.ru", "phone": "+70730326738"}
0005432584777	D84FD4	1928 265906	IGOR BONDARENKO	{"phone": "+70769825479"}
0005432584778	C0BDBA	5369 894091	NATALYA NAZAROVA	{"email": "nazarovan-1986@postgrespro.ru", "phone": "+70013582172"}
0005432584779	6BE52C	4807 379543	SVETLANA KUZMINA	{"email": "svetlana-kuzmina.1978@postgrespro.ru", "phone": "+70398387078"}
0005432584780	6645A5	4508 688252	OLESYA MAKSIMOVA	{"email": "o.maksimova.1968@postgrespro.ru", "phone": "+70107447682"}
0005432584781	6645A5	7940 638747	ALEKSEY ANTONOV	{"email": "a.antonov-29011975@postgrespro.ru", "phone": "+70602043336"}
0005432584782	914FA4	8992 432929	MIKHAIL MEDVEDEV	{"email": "mikhail_medvedev29101967@postgrespro.ru", "phone": "+70985363722"}
0005432584783	914FA4	3419 769725	VLADIMIR VLASOV	{"phone": "+70973494930"}
0005432584784	9D71F1	0534 418188	DANIYA NOVIKOVA	{"phone": "+70265580727"}
0005432584785	3A6387	9167 119230	SERGEY SIDOROV	{"email": "sidorov_sergey121979@postgrespro.ru", "phone": "+70577388356"}
0005432584786	3A6387	3131 041973	NATALYA ANISIMOVA	{"email": "anisimova_n.13011964@postgrespro.ru", "phone": "+70827414823"}
0005432584787	471042	5267 840465	LYUDMILA TIKHONOVA	{"phone": "+70124706083"}
0005432584788	35C590	8929 183251	OLGA ANISIMOVA	{"phone": "+70082893610"}
0005432584789	35C590	4120 182090	ANASTASIYA GORBUNOVA	{"phone": "+70457138592"}
0005432603711	34A497	1416 836878	MARIYA AKIMOVA	{"phone": "+70262668087"}
0005432603767	9ADF6E	6254 603795	EVGENIY KISELEV	{"phone": "+70864164121"}
0005432603642	68A761	8718 426575	MARGARITA KUZMINA	{"email": "kuzmina_margarita-1967@postgrespro.ru", "phone": "+70507712967"}
0005432603643	C73366	3933 854130	LYUDMILA SAVELEVA	{"email": "saveleva-l.1973@postgrespro.ru", "phone": "+70878161503"}
0005432603644	C73366	5073 378826	ELENA EFIMOVA	{"email": "eefimova.26091969@postgrespro.ru", "phone": "+70207734147"}
0005432603645	C73366	7427 371061	TIMOFEY ROMANOV	{"email": "timofey_romanov.101976@postgrespro.ru", "phone": "+70659469845"}
0005432603646	784E28	0560 411750	GRIGORIY SMIRNOV	{"email": "grigoriy-smirnov-061981@postgrespro.ru", "phone": "+70415892720"}
0005432603647	7E6C6D	3756 926662	PAVEL YAKOVLEV	{"email": "yakovlev_p_05111966@postgrespro.ru", "phone": "+70189440242"}
0005432603648	7E6C6D	3257 878322	DARYA MOROZOVA	{"email": "morozova.darya051963@postgrespro.ru", "phone": "+70826660120"}
0005432603649	EBEFDF	7932 705577	LIDIYA VASILEVA	{"email": "lidiya.vasileva.021977@postgrespro.ru", "phone": "+70396870362"}
0005432603650	AE2932	9505 176260	TATYANA OVCHINNIKOVA	{"email": "ovchinnikovat.1966@postgrespro.ru", "phone": "+70092886601"}
0005432603651	AE2932	6800 252619	ALEKSEY IVANOV	{"email": "alekseyivanov_101980@postgrespro.ru", "phone": "+70450780919"}
0005432603652	A06A2A	6481 061218	TATYANA KOROLEVA	{"phone": "+70110701233"}
0005432603653	A06A2A	0664 833360	TATYANA KONOVALOVA	{"email": "konovalova-t-1972@postgrespro.ru", "phone": "+70845821218"}
0005432603654	A06A2A	9150 866265	NIKOLAY PAVLOV	{"phone": "+70790380487"}
0005432603655	FFBF46	3352 763475	ELENA MIRONOVA	{"email": "mironova.e-061968@postgrespro.ru", "phone": "+70182585054"}
0005432603656	5E4423	7541 647025	SVETLANA OVCHINNIKOVA	{"email": "svetlana_ovchinnikova-1967@postgrespro.ru", "phone": "+70845075629"}
0005432603657	5E7847	3585 704391	YURIY RODIONOV	{"email": "rodionov_yuriy-1966@postgrespro.ru", "phone": "+70366559404"}
0005432603658	5B1D23	7412 178305	ANASTASIYA ZHURAVLEVA	{"phone": "+70422426799"}
0005432603659	B84D57	9721 769245	TATYANA ANTONOVA	{"phone": "+70668643323"}
0005432603660	B84D57	9641 365792	TIMOFEY PAVLOV	{"email": "t.pavlov.04091988@postgrespro.ru", "phone": "+70812718229"}
0005432603661	C83355	7495 736223	KLAVDIYA BELOVA	{"phone": "+70285793674"}
0005432603662	0E25E1	3024 605100	ANTONINA NESTEROVA	{"phone": "+70668472016"}
0005432603663	B41C5E	3411 634750	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov-1967@postgrespro.ru", "phone": "+70497569440"}
0005432603664	69F0B8	8578 977234	ANDREY NOVIKOV	{"phone": "+70374284487"}
0005432603665	36AA92	9833 305869	DARYA MIKHAYLOVA	{"phone": "+70670082473"}
0005432603666	3B684A	6569 852441	OLGA ORLOVA	{"phone": "+70470987032"}
0005432603667	6C4EF8	2371 546201	IRINA ZHUKOVA	{"email": "zhukova-i_08081970@postgrespro.ru", "phone": "+70159897431"}
0005432603668	78C637	9062 452199	VLADIMIR VOLKOV	{"email": "vvolkov_04011976@postgrespro.ru", "phone": "+70958676209"}
0005432603669	688A29	7525 687019	NATALYA ANDREEVA	{"email": "andreevan_1970@postgrespro.ru", "phone": "+70449261962"}
0005432603670	D8D35E	3111 447375	PAVEL NAZAROV	{"email": "nazarov-pavel_031982@postgrespro.ru", "phone": "+70542396637"}
0005432603671	B6F54A	7133 569216	LYUBOV ERMAKOVA	{"email": "l-ermakova.1964@postgrespro.ru", "phone": "+70091181375"}
0005432603672	B6F54A	3925 564141	MIKHAIL KUZNECOV	{"email": "m.kuznecov.051963@postgrespro.ru", "phone": "+70877687069"}
0005432603673	98558B	8089 984021	VLADISLAV VOROBEV	{"phone": "+70638882462"}
0005432603674	98558B	7683 513903	ELENA MATVEEVA	{"email": "matveevaelena.24101955@postgrespro.ru", "phone": "+70565530014"}
0005432603675	D89D7D	0021 161151	VALENTINA PAVLOVA	{"phone": "+70648902418"}
0005432603676	D89D7D	1549 775871	EVGENIY TARASOV	{"email": "tarasov_evgeniy_031973@postgrespro.ru", "phone": "+70260960986"}
0005432603677	F967A5	7523 931419	ANASTASIYA SMIRNOVA	{"phone": "+70773120258"}
0005432603678	152A50	2110 968024	SERGEY BORISOV	{"phone": "+70585525232"}
0005432603679	B78FAF	8190 902574	SERGEY PAVLOV	{"phone": "+70273393472"}
0005432603680	A0D4B0	2068 455723	VLADIMIR KISELEV	{"email": "v_kiselev1970@postgrespro.ru", "phone": "+70721305528"}
0005432603681	B11858	2669 448869	ALEKSEY DENISOV	{"phone": "+70632778224"}
0005432603682	BBFE33	4381 278393	GALINA IVANOVA	{"phone": "+70480671219"}
0005432603683	79E0C6	4246 732651	SERGEY BELOV	{"email": "belov.s_1974@postgrespro.ru", "phone": "+70411098172"}
0005432603684	27B670	0984 807011	EGOR MELNIKOV	{"email": "melnikovegor04121963@postgrespro.ru", "phone": "+70825745393"}
0005432603685	003BC1	1966 687582	OLGA KARPOVA	{"email": "o_karpova_031969@postgrespro.ru", "phone": "+70088934010"}
0005432603686	44E33C	9843 302694	ALEKSANDR MATVEEV	{"email": "matveevaleksandr.1966@postgrespro.ru", "phone": "+70240916657"}
0005432603687	1429B2	6360 207640	EVGENIY NIKOLAEV	{"email": "nikolaev_evgeniy1964@postgrespro.ru", "phone": "+70016117353"}
0005432603688	1429B2	9499 179921	EKATERINA PAVLOVA	{"phone": "+70197520900"}
0005432603689	45AB4E	1608 156822	NIKOLAY FROLOV	{"email": "nikolay-frolov_02051970@postgrespro.ru", "phone": "+70414502402"}
0005432603690	45AB4E	6879 551479	GENNADIY FOMIN	{"phone": "+70692396733"}
0005432603691	417E0B	1592 559664	VIKTOR MOROZOV	{"email": "morozov.v1974@postgrespro.ru", "phone": "+70021858701"}
0005432603692	417E0B	1475 235026	MIKHAIL EGOROV	{"email": "mikhail-egorov071964@postgrespro.ru", "phone": "+70409861268"}
0005432603693	A8F93A	1396 849088	VIKTOR KUZNECOV	{"phone": "+70685222982"}
0005432603694	5B9BA2	4987 109988	ROMAN SCHERBAKOV	{"phone": "+70311100342"}
0005432603695	0469E8	6073 159924	ALEKSEY MIKHAYLOV	{"phone": "+70681397357"}
0005432603696	ACA34E	1536 319382	DAMIR KOROLEV	{"email": "d.korolev-021963@postgrespro.ru", "phone": "+70671241374"}
0005432603697	E866B0	1925 180244	TATYANA ANTONOVA	{"email": "antonovatatyana_051966@postgrespro.ru", "phone": "+70597455144"}
0005432603698	514D4A	0406 187264	ANDREY POPOV	{"email": "a.popov_101973@postgrespro.ru", "phone": "+70032375477"}
0005432603699	DFC935	8025 863351	VASILISA MASLOVA	{"phone": "+70676174109"}
0005432603700	78E6E2	4244 312911	SERGEY NOVIKOV	{"phone": "+70435407281"}
0005432603701	02848B	1731 359718	YULIYA BELOVA	{"phone": "+70896022288"}
0005432603702	02848B	6939 112517	EKATERINA OVCHINNIKOVA	{"phone": "+70301705234"}
0005432603703	5AFA03	6955 203974	VERONIKA TIMOFEEVA	{"email": "veronikatimofeeva_1975@postgrespro.ru", "phone": "+70775158745"}
0005432603704	5AFA03	4332 970946	SERGEY TARASOV	{"phone": "+70712111096"}
0005432603705	8F384A	7342 144669	NIKITA DMITRIEV	{"email": "n.dmitriev.1973@postgrespro.ru", "phone": "+70916954255"}
0005432603706	7DA47D	5308 128407	PAVEL SOROKIN	{"email": "pavel_sorokin.09051968@postgrespro.ru", "phone": "+70590013019"}
0005432603707	7DA47D	1150 670847	VLADIMIR AFANASEV	{"email": "afanasev-vladimir.10111977@postgrespro.ru", "phone": "+70745277318"}
0005432603708	7DA47D	0306 046686	LARISA POLYAKOVA	{"email": "larisapolyakova_1963@postgrespro.ru", "phone": "+70201098713"}
0005432603709	7DA47D	5765 795145	VERA YUDINA	{"email": "yudina_vera121981@postgrespro.ru", "phone": "+70680453150"}
0005432603710	843898	8864 307835	ELVIRA VOLKOVA	{"email": "volkovaelvira.1969@postgrespro.ru", "phone": "+70272593782"}
0005432603712	BC8828	4195 881312	VADIM KAZAKOV	{"email": "vkazakov_10051976@postgrespro.ru", "phone": "+70102896767"}
0005432603713	BC8828	8744 853665	YURIY GORBUNOV	{"phone": "+70756893344"}
0005432603714	BC8828	6750 179687	VITALIY SERGEEV	{"email": "vitaliy_sergeev_07101970@postgrespro.ru", "phone": "+70895865864"}
0005432603715	03A27E	8998 348010	OLGA LUKYANOVA	{"email": "olga_lukyanova.1969@postgrespro.ru", "phone": "+70651130248"}
0005432603716	EB26FC	1617 420920	NIKOLAY IVANOV	{"email": "ivanov_nikolay_25071969@postgrespro.ru", "phone": "+70413455136"}
0005432603717	EB26FC	2048 014881	SVETLANA ILINA	{"phone": "+70717018843"}
0005432603718	EB26FC	3987 219513	OLGA SOLOVEVA	{"phone": "+70792151457"}
0005432603719	44925B	7029 303523	OLGA ANISIMOVA	{"email": "anisimovaolga_011977@postgrespro.ru", "phone": "+70755472025"}
0005432603720	2CE24B	3674 852710	VLADIMIR ZHUKOV	{"email": "vladimirzhukov.1979@postgrespro.ru", "phone": "+70469467882"}
0005432603721	CCD48E	6940 000915	EKATERINA NAUMOVA	{"email": "naumova_ekaterina-1978@postgrespro.ru", "phone": "+70292438096"}
0005432603722	CCD48E	5868 967450	ELIZAVETA MIKHAYLOVA	{"email": "mikhaylova_elizaveta.1971@postgrespro.ru", "phone": "+70606439316"}
0005432603723	07AD7E	3189 725789	GENNADIY ALEKSANDROV	{"phone": "+70035130500"}
0005432603724	EAF45E	4726 957120	VLADISLAV ROMANOV	{"email": "v_romanov_1973@postgrespro.ru", "phone": "+70464302514"}
0005432603725	EAF45E	1209 556197	ELENA BELOVA	{"email": "e-belova.091969@postgrespro.ru", "phone": "+70679125761"}
0005432603726	EAF45E	9801 702738	DANILA NOVIKOV	{"email": "novikov_d_1974@postgrespro.ru", "phone": "+70235566400"}
0005432603727	916DE9	3868 275959	ALEKSEY MELNIKOV	{"email": "alekseymelnikov051977@postgrespro.ru", "phone": "+70153631182"}
0005432603728	E5775A	9535 898532	NINA KULIKOVA	{"phone": "+70917011225"}
0005432603729	DBC85A	8990 351621	ANNA GAVRILOVA	{"email": "agavrilova.1979@postgrespro.ru", "phone": "+70731337082"}
0005432603730	DBC85A	7401 610352	GALINA KRASNOVA	{"phone": "+70244363628"}
0005432603731	EF9738	0961 229822	ZARINA SIDOROVA	{"phone": "+70912315891"}
0005432603732	EF9738	3521 537451	SERGEY VOROBEV	{"email": "s-vorobev_01111966@postgrespro.ru", "phone": "+70266065655"}
0005432603733	DD8C7E	4465 874656	SERGEY ZHURAVLEV	{"phone": "+70819394289"}
0005432603734	3D5141	4384 209385	SERGEY MELNIKOV	{"email": "sergeymelnikov071973@postgrespro.ru", "phone": "+70247383373"}
0005432603735	6A46FA	1687 780017	YURIY KUDRYASHOV	{"email": "y-kudryashov.05121976@postgrespro.ru", "phone": "+70190471176"}
0005432603736	041D26	6305 502048	ALEKSANDR PETROV	{"phone": "+70061849150"}
0005432603737	17DBC7	5708 770661	DINARA ANTONOVA	{"email": "d_antonova.071960@postgrespro.ru", "phone": "+70078237394"}
0005432603738	D727D1	8025 407148	TATYANA KOZLOVA	{"phone": "+70812307865"}
0005432603739	D727D1	3171 064565	MARINA IVANOVA	{"phone": "+70757974282"}
0005432603740	D727D1	8698 275381	ANATOLIY POPOV	{"email": "popov-a_29121981@postgrespro.ru", "phone": "+70939616780"}
0005432603741	523060	6440 225820	OLEG MATVEEV	{"email": "matveev.o1961@postgrespro.ru", "phone": "+70860340519"}
0005432603742	4BF094	0962 959860	GALINA KUDRYASHOVA	{"email": "g_kudryashova1974@postgrespro.ru", "phone": "+70095671840"}
0005432603743	5FF6C3	4617 106096	NINA GORBUNOVA	{"email": "gorbunova_n_051973@postgrespro.ru", "phone": "+70463351928"}
0005432603744	698828	1555 636671	VALENTINA SOROKINA	{"phone": "+70548549461"}
0005432603745	893F90	5543 507406	ALEKSANDR BARANOV	{"email": "baranovaleksandr-16111973@postgrespro.ru", "phone": "+70071972275"}
0005432603746	9C1299	3389 316273	KONSTANTIN ROMANOV	{"phone": "+70725512284"}
0005432603747	50645F	3029 867093	ZINAIDA GUSEVA	{"phone": "+70781588625"}
0005432603748	50645F	7615 505550	ANTON KRASNOV	{"phone": "+70719248042"}
0005432603749	AAF3CE	3183 201404	IGOR KUDRYASHOV	{"email": "igor.kudryashov-19091974@postgrespro.ru", "phone": "+70106649766"}
0005432603750	B11D16	3296 240788	LYUDMILA PETROVA	{"email": "lyudmila-petrova_1963@postgrespro.ru", "phone": "+70490651489"}
0005432603751	B9D634	1451 055954	EGOR CHERNOV	{"email": "chernov.egor.1978@postgrespro.ru", "phone": "+70732308087"}
0005432603752	5C1788	4512 988299	STEPAN KISELEV	{"phone": "+70763850643"}
0005432603753	5C99AE	8213 061985	OLGA BORISOVA	{"phone": "+70586042211"}
0005432603754	5C99AE	0826 350137	EKATERINA LEBEDEVA	{"phone": "+70248462753"}
0005432603755	B977DF	9379 682876	ELENA SIDOROVA	{"phone": "+70236785078"}
0005432603756	B977DF	5628 326041	ANATOLIY IVANOV	{"phone": "+70509731397"}
0005432603757	6B1492	8965 014378	MIKHAIL NOVIKOV	{"phone": "+70705359925"}
0005432603758	3B455F	9501 012333	ALEKSANDR ABRAMOV	{"email": "aleksandr_abramov_1976@postgrespro.ru", "phone": "+70348848652"}
0005432603759	9F7E1A	9436 315329	VASILISA MIRONOVA	{"phone": "+70768882476"}
0005432603760	9F7E1A	5528 914260	VITALIY NIKITIN	{"email": "nikitinvitaliy.1961@postgrespro.ru", "phone": "+70648988447"}
0005432603761	81DF78	9868 931318	ANATOLIY ANDREEV	{"email": "andreev.anatoliy_13091966@postgrespro.ru", "phone": "+70460427174"}
0005432603762	F84CB5	0310 386241	ZINAIDA KOVALEVA	{"email": "kovaleva.z-021978@postgrespro.ru", "phone": "+70838121110"}
0005432603763	B3D9D5	0434 361766	ANATOLIY KUDRYASHOV	{"email": "kudryashov-anatoliy_011973@postgrespro.ru", "phone": "+70378636684"}
0005432603764	F54530	5996 323150	VALENTINA KOZLOVA	{"email": "v.kozlova30071973@postgrespro.ru", "phone": "+70295715341"}
0005432603765	87699A	6744 780422	EVGENIY PAVLOV	{"email": "epavlov-1960@postgrespro.ru", "phone": "+70739028450"}
0005432603766	87699A	7850 970560	VIKTOR KISELEV	{"phone": "+70378152477"}
0005432603768	41FF00	0135 215314	VALENTIN BONDARENKO	{"email": "bondarenko.v.1972@postgrespro.ru", "phone": "+70115802098"}
0005432603769	C2B174	1960 792137	RASHIT POPOV	{"email": "rashit-popov_15011961@postgrespro.ru", "phone": "+70057615305"}
0005432603770	C2B174	1620 738994	VIKTOR ROMANOV	{"email": "viktorromanov.1977@postgrespro.ru", "phone": "+70726058422"}
0005432603771	C2B174	9250 729613	VYACHESLAV ABRAMOV	{"phone": "+70027053147"}
0005432603772	C1FBD7	4763 955113	NATALYA VASILEVA	{"email": "n-vasileva.08111964@postgrespro.ru", "phone": "+70795181962"}
0005432603773	AC05D8	0894 070504	NADEZHDA ALEKSEEVA	{"phone": "+70325426409"}
0005432603774	AC05D8	2036 495273	PAVEL ZAKHAROV	{"phone": "+70284682368"}
0005432603775	86D7D6	9054 007118	EVGENIY VOROBEV	{"phone": "+70038479842"}
0005432603776	256CCA	2347 448980	NIKOLAY KUZMIN	{"email": "nkuzmin_1973@postgrespro.ru", "phone": "+70359739523"}
0005432603777	256CCA	7977 928365	NATALYA RODIONOVA	{"email": "rodionova.natalya051980@postgrespro.ru", "phone": "+70685918633"}
0005432603778	2FAE98	7426 791334	ANDREY MAKSIMOV	{"email": "amaksimov-061978@postgrespro.ru", "phone": "+70748116491"}
0005432603779	2FAE98	5860 120723	NATALYA IVANOVA	{"email": "ivanovan-1969@postgrespro.ru", "phone": "+70324850415"}
0005432603780	36569F	1229 927615	PETR KRASNOV	{"email": "krasnovp-1968@postgrespro.ru", "phone": "+70188954641"}
0005432603781	1CBD8B	0425 612342	PAVEL KUZNECOV	{"email": "pavelkuznecov111976@postgrespro.ru", "phone": "+70198655953"}
0005432603782	E08FC0	5863 616347	NATALYA IVANOVA	{"email": "ivanova.n101969@postgrespro.ru", "phone": "+70102439955"}
0005432603783	8858BF	4813 914865	NATALYA STEPANOVA	{"phone": "+70058581468"}
0005432603784	D427BE	8132 525116	ELENA BELOVA	{"email": "elena.belova.30051972@postgrespro.ru", "phone": "+70427473041"}
0005432603785	D427BE	8129 464662	VLADIMIR FOMIN	{"phone": "+70026548954"}
0005432603786	9185A5	5849 530655	TATYANA KRASNOVA	{"phone": "+70072141237"}
0005432603787	CBB7AC	2540 552016	RUSLAN SHEVCHENKO	{"email": "r.shevchenko.021975@postgrespro.ru", "phone": "+70073615540"}
0005432603788	055AE9	1653 985303	TATYANA ZAYCEVA	{"email": "zayceva-tatyana_1965@postgrespro.ru", "phone": "+70452140675"}
0005432603789	EA264E	5567 040341	ALEKSEY KUDRYASHOV	{"email": "akudryashov12101963@postgrespro.ru", "phone": "+70909821276"}
0005432603790	F5A784	5296 420217	EVGENIY ALEKSEEV	{"email": "e.alekseev.1970@postgrespro.ru", "phone": "+70087183326"}
0005432603791	F5A784	3790 891346	PETR FILIPPOV	{"phone": "+70917080858"}
0005432603792	375EA7	9329 869076	SVETLANA KONOVALOVA	{"email": "konovalovas_1980@postgrespro.ru", "phone": "+70325859169"}
0005432603793	2E9833	1704 545595	ALEKSANDR MARTYNOV	{"email": "martynov_a.121973@postgrespro.ru", "phone": "+70208463914"}
0005432603794	1C0FC4	0169 225151	ANATOLIY YAKOVLEV	{"email": "a_yakovlev04071977@postgrespro.ru", "phone": "+70297314395"}
0005432603795	1D5C93	2581 592323	GALINA TIKHONOVA	{"email": "tikhonova-g1971@postgrespro.ru", "phone": "+70428467131"}
0005432603796	B12546	9778 515431	VALENTINA RODIONOVA	{"phone": "+70490263919"}
0005432603797	47451F	4848 060951	MARIYA IVANOVA	{"phone": "+70654481007"}
0005432603798	A94528	4657 680078	MARINA BOGDANOVA	{"phone": "+70848952556"}
0005432603799	2F08FA	6057 060431	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr_101966@postgrespro.ru", "phone": "+70481820173"}
0005432603800	356C72	4289 501769	ALEKSEY PETROV	{"email": "petrov.aleksey-091979@postgrespro.ru", "phone": "+70858791957"}
0005432603801	0E9A5A	9066 477188	LARISA FROLOVA	{"email": "l-frolova1978@postgrespro.ru", "phone": "+70877133323"}
0005432603802	C3BED8	7694 590717	VLADIMIR ABRAMOV	{"email": "v-abramov_03041972@postgrespro.ru", "phone": "+70871855768"}
0005432603803	0CF21C	6464 034088	VASILIY ISAEV	{"phone": "+70261759126"}
0005432603804	5EB24E	6048 263153	MIKHAIL SAVELEV	{"email": "savelev-m_25061967@postgrespro.ru", "phone": "+70273273118"}
0005432603805	5EB24E	3898 750383	ZULFIYA POLYAKOVA	{"email": "polyakovaz.26091979@postgrespro.ru", "phone": "+70585788377"}
0005432603806	A205BC	3394 649352	YULIYA OVCHINNIKOVA	{"email": "ovchinnikova_yuliya041979@postgrespro.ru", "phone": "+70569895827"}
0005432603807	216435	5249 784598	ZINAIDA KUZNECOVA	{"phone": "+70397472627"}
0005432603808	3EF273	9745 917105	ARTEM ISAEV	{"phone": "+70674269966"}
0005432603809	54A0F3	0631 748924	IRINA VASILEVA	{"email": "vasileva-irina101976@postgrespro.ru", "phone": "+70051675242"}
0005432603810	54A0F3	6967 952286	ALISA FROLOVA	{"phone": "+70034769015"}
0005432603811	D517C1	6173 920904	KRISTINA MELNIKOVA	{"email": "melnikova.kristina1967@postgrespro.ru", "phone": "+70750023576"}
0005432603812	DAFFDD	5622 969922	ANASTASIYA EFREMOVA	{"phone": "+70612273146"}
0005432603813	B9FE6D	3921 132707	ALEKSANDR KUZNECOV	{"email": "kuznecova-15121973@postgrespro.ru", "phone": "+70047289032"}
0005432603814	B9FE6D	7324 586128	KIRILL BONDARENKO	{"email": "bondarenko_k29101978@postgrespro.ru", "phone": "+70351484442"}
0005432603815	0897D6	0158 679019	ALEKSEY SCHERBAKOV	{"phone": "+70795722023"}
0005432603816	689ABA	2310 298188	ANNA ZHUKOVA	{"phone": "+70358664580"}
0005432603817	639455	4921 723947	OLGA KOZLOVA	{"phone": "+70108596237"}
0005432603818	639455	8561 554861	GENNADIY MATVEEV	{"email": "matveev-g.091978@postgrespro.ru", "phone": "+70112299622"}
0005432603819	D9A088	2695 483771	VITALIY FOMIN	{"email": "v_fomin_1973@postgrespro.ru", "phone": "+70243824122"}
0005432603820	0ECC96	1516 969334	SERGEY MIKHAYLOV	{"phone": "+70147316024"}
0005432603821	6BB65E	1927 160047	VIKTOR KUZNECOV	{"phone": "+70777052157"}
0005432603822	020B84	2793 939608	ANDREY ROMANOV	{"email": "romanov_a-031969@postgrespro.ru", "phone": "+70452783573"}
0005432603823	FFD451	1583 091626	DMITRIY STEPANOV	{"email": "dstepanov.02041969@postgrespro.ru", "phone": "+70131873779"}
0005432603824	FFD451	4413 916307	NATALYA ANTONOVA	{"email": "antonova-natalya.031969@postgrespro.ru", "phone": "+70720878165"}
0005432603825	FFD451	7514 952500	ANATOLIY PETROV	{"email": "petrov.anatoliy.1969@postgrespro.ru", "phone": "+70663622344"}
0005432603826	C117F1	5361 279831	ANDREY FEDOROV	{"phone": "+70030080276"}
0005432603827	C54E67	9740 115378	TAISIYA CHERNOVA	{"email": "chernova-t.1963@postgrespro.ru", "phone": "+70226651574"}
0005432603828	C54E67	4746 432439	OLEG POPOV	{"email": "olegpopov.031958@postgrespro.ru", "phone": "+70812894667"}
0005432603829	062BFC	8738 681648	ANNA MOISEEVA	{"phone": "+70707407696"}
0005432603830	0177A1	6843 092999	VIKTOR VASILEV	{"email": "vasilev-viktor_1968@postgrespro.ru", "phone": "+70176921232"}
0005432603831	0177A1	1379 201414	DARYA TITOVA	{"email": "darya_titova-071979@postgrespro.ru", "phone": "+70072702179"}
0005432603832	0177A1	6127 134324	DANIIL KUZNECOV	{"email": "kuznecovd_1963@postgrespro.ru", "phone": "+70452829274"}
0005432603833	645109	1399 498641	ELENA VASILEVA	{"email": "elena-vasileva15031971@postgrespro.ru", "phone": "+70369968128"}
0005432603952	36F019	4272 029854	ALEKSANDR IVANOV	{"phone": "+70674573933"}
0005432603834	32B233	6716 617463	GENNADIY FEDOTOV	{"email": "gennadiyfedotov-101977@postgrespro.ru", "phone": "+70895904218"}
0005432603835	8D6805	1863 458257	ANASTASIYA ALEKSANDROVA	{"email": "anastasiya.aleksandrova_011981@postgrespro.ru", "phone": "+70616129266"}
0005432603836	8D6805	1987 129840	EKATERINA ALEKSEEVA	{"email": "ekaterinaalekseeva.1981@postgrespro.ru", "phone": "+70453723323"}
0005432603837	D0698E	3398 728121	ANASTASIYA MAKAROVA	{"phone": "+70005933417"}
0005432603838	697073	3525 692001	SERGEY MAKAROV	{"email": "smakarov_08111977@postgrespro.ru", "phone": "+70083126765"}
0005432603839	697073	5381 899213	ALEKSEY ABRAMOV	{"email": "abramov_a.29101961@postgrespro.ru", "phone": "+70508340438"}
0005432603840	697073	8173 005239	VLADIMIR SOROKIN	{"email": "vladimir-sorokin-111976@postgrespro.ru", "phone": "+70658352330"}
0005432603841	BDF0DE	6816 367731	ALEKSANDR VASILEV	{"email": "vasilev_a1970@postgrespro.ru", "phone": "+70824077628"}
0005432603842	5B5DFF	4056 492470	GALINA CHERNOVA	{"phone": "+70672836177"}
0005432603843	6F36DC	7272 023783	LYUBOV CHERNOVA	{"email": "lyubov.chernova-1984@postgrespro.ru", "phone": "+70467305053"}
0005432603844	F64DCD	7549 726025	LYUDMILA KUZNECOVA	{"phone": "+70554122128"}
0005432603845	6A3B63	9742 634564	VALENTINA MAKAROVA	{"phone": "+70616639799"}
0005432603846	762B2F	9754 421245	VASILIY BONDARENKO	{"phone": "+70378458541"}
0005432603847	2FC5A2	4867 788232	ANTONINA ANDREEVA	{"phone": "+70749724861"}
0005432603848	2FC5A2	3651 707849	NATALYA FROLOVA	{"phone": "+70697557789"}
0005432603849	1EB1EA	2539 518828	ANDREY ZAKHAROV	{"email": "a-zakharov.1973@postgrespro.ru", "phone": "+70415609801"}
0005432603850	85DD99	1009 717880	ELENA MOROZOVA	{"phone": "+70016352639"}
0005432603851	85DD99	2578 440922	PETR KUDRYASHOV	{"phone": "+70927108491"}
0005432603852	85DD99	2491 364548	GALINA ALEKSANDROVA	{"email": "aleksandrova-g-051986@postgrespro.ru", "phone": "+70157406273"}
0005432603853	711EA3	7534 417741	YURIY ROMANOV	{"phone": "+70910370314"}
0005432603854	711EA3	0219 797200	ARMEN KOZLOV	{"email": "a-kozlov-02091973@postgrespro.ru", "phone": "+70362968596"}
0005432603855	711EA3	7859 098040	ALEKSANDR KUZNECOV	{"phone": "+70123147747"}
0005432603856	711EA3	7677 909142	EGOR YAKOVLEV	{"phone": "+70018789564"}
0005432603857	9CF288	0241 802543	LYUDMILA OVCHINNIKOVA	{"phone": "+70128512827"}
0005432603858	9CF288	3672 156074	VALERIYA RYABOVA	{"email": "ryabova_v111968@postgrespro.ru", "phone": "+70372397845"}
0005432603859	956042	1750 609912	EVGENIY POPOV	{"email": "popov_evgeniy121976@postgrespro.ru", "phone": "+70410923516"}
0005432603860	956042	9707 068175	OLEG ANDREEV	{"phone": "+70707139079"}
0005432603861	737A74	1927 565340	IRINA BARANOVA	{"email": "baranova.irina071961@postgrespro.ru", "phone": "+70044326593"}
0005432603862	737A74	2187 198805	ANASTASIYA YAKOVLEVA	{"phone": "+70481298040"}
0005432603863	10AC05	5034 498523	ANNA DMITRIEVA	{"phone": "+70067119732"}
0005432603864	DDA606	9780 521140	VASILIY STEPANOV	{"email": "stepanov.vasiliy.07041973@postgrespro.ru", "phone": "+70277801169"}
0005432603865	6A61AB	3807 877814	RAISA VASILEVA	{"phone": "+70416053493"}
0005432603866	C908C3	5032 188508	TATYANA ILINA	{"phone": "+70649947910"}
0005432603867	C908C3	6472 572550	KLAVDIYA IVANOVA	{"email": "ivanovaklavdiya11101967@postgrespro.ru", "phone": "+70609761987"}
0005432603868	10D4FC	8140 310541	KSENIYA KRASNOVA	{"email": "krasnova.k_1965@postgrespro.ru", "phone": "+70142698496"}
0005432603869	CF923B	0230 240031	ANDREY MOISEEV	{"phone": "+70591685114"}
0005432603870	4797D0	7297 742993	VERA NESTEROVA	{"email": "v.nesterova061968@postgrespro.ru", "phone": "+70270865077"}
0005432603871	4797D0	9263 901056	RIMMA EFREMOVA	{"email": "rimma-efremova04051971@postgrespro.ru", "phone": "+70295847681"}
0005432603872	279620	4816 001089	ALEKSANDR ANDREEV	{"email": "andreev-a.31101978@postgrespro.ru", "phone": "+70736726849"}
0005432603873	279620	9037 129587	SOFIYA TROFIMOVA	{"email": "trofimova_sofiya-02121974@postgrespro.ru", "phone": "+70989872566"}
0005432603874	279620	5153 186042	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_1980@postgrespro.ru", "phone": "+70707059699"}
0005432603875	697ECE	2631 726983	ALEKSANDR GUSEV	{"phone": "+70829585408"}
0005432603876	C62FA7	1556 999148	ROMAN KONOVALOV	{"email": "konovalovr1971@postgrespro.ru", "phone": "+70034980353"}
0005432603877	556AD3	2415 372776	LILIYA ERMAKOVA	{"phone": "+70556983491"}
0005432603878	556AD3	0475 253146	VLADIMIR KUZNECOV	{"phone": "+70720042319"}
0005432603879	9C4CEF	9892 321805	MIKHAIL GORBUNOV	{"phone": "+70144574440"}
0005432603880	9C4CEF	2449 694804	OLGA VASILEVA	{"email": "olga.vasileva-071985@postgrespro.ru", "phone": "+70021033230"}
0005432603881	E51C33	1741 872793	MARIYA KUZMINA	{"email": "m_kuzmina25051964@postgrespro.ru", "phone": "+70582729223"}
0005432603882	DB3983	4029 177820	ALEKSANDRA GERASIMOVA	{"email": "gerasimovaaleksandra-24021978@postgrespro.ru", "phone": "+70932891036"}
0005432603883	DB3983	1192 116016	MARGARITA RODIONOVA	{"email": "mrodionova.25051979@postgrespro.ru", "phone": "+70692832041"}
0005432603884	2C5803	6815 512290	MAKSIM BORISOV	{"email": "mborisov_1973@postgrespro.ru", "phone": "+70893464887"}
0005432603885	6F3D7B	1680 196142	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov16071977@postgrespro.ru", "phone": "+70280412018"}
0005432603886	CEA942	6489 273530	MARIYA KUDRYASHOVA	{"phone": "+70612630215"}
0005432603887	CEA942	8869 717193	MILANA KUZNECOVA	{"email": "kuznecovam.051970@postgrespro.ru", "phone": "+70660311808"}
0005432603888	CECAC3	4658 923251	ALEKSANDR AFANASEV	{"phone": "+70658146692"}
0005432603889	66E9AA	1024 335753	DENIS PAVLOV	{"phone": "+70023953527"}
0005432603890	66E9AA	6033 280801	TATYANA KUZMINA	{"email": "kuzmina-tatyana031980@postgrespro.ru", "phone": "+70778827010"}
0005432603891	66E9AA	3797 264038	ANTONINA ZAKHAROVA	{"phone": "+70608195871"}
0005432603892	B1BA33	3169 347604	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr081969@postgrespro.ru", "phone": "+70623542717"}
0005432603893	1A91C5	5300 488708	VYACHESLAV KULIKOV	{"email": "kulikov.vyacheslav_041966@postgrespro.ru", "phone": "+70645129834"}
0005432603894	1A91C5	1360 035267	VERA VOLKOVA	{"phone": "+70719328590"}
0005432603895	24ED26	8296 430133	IRINA ZHUKOVA	{"email": "zhukova.i-111966@postgrespro.ru", "phone": "+70695798316"}
0005432603896	EEEED2	8749 111984	EKATERINA CHERNOVA	{"phone": "+70338522806"}
0005432603897	62CEC8	1801 108755	LEONID SIDOROV	{"email": "l.sidorov1976@postgrespro.ru", "phone": "+70843196601"}
0005432603898	D8A990	0263 024453	VLADIMIR ZAYCEV	{"email": "vladimir_zaycev091972@postgrespro.ru", "phone": "+70452192552"}
0005432603899	D3F4F1	0045 133755	IVAN PETROV	{"email": "petrov.ivan.1970@postgrespro.ru", "phone": "+70116001245"}
0005432603900	D3F4F1	7731 760413	MARIYA SIDOROVA	{"email": "sidorova.m_08021968@postgrespro.ru", "phone": "+70730542355"}
0005432603901	579F81	9136 043627	EKATERINA MATVEEVA	{"email": "ekaterina.matveeva-1978@postgrespro.ru", "phone": "+70035956387"}
0005432603902	CC3B50	9787 115412	DMITRIY KUZNECOV	{"phone": "+70343601382"}
0005432603903	6264BA	2012 628979	OLGA KUZMINA	{"email": "olgakuzmina.20041972@postgrespro.ru", "phone": "+70319909977"}
0005432603904	B4489B	2014 246299	ANASTASIYA PAVLOVA	{"phone": "+70883417180"}
0005432603905	668E8F	9741 133944	VALENTINA FILATOVA	{"phone": "+70411769232"}
0005432603906	475345	6583 480266	TATYANA KOVALEVA	{"email": "kovalevat.1964@postgrespro.ru", "phone": "+70660689083"}
0005432603907	475345	2560 031600	ALEKSANDRA MAKAROVA	{"phone": "+70655777271"}
0005432603908	1B3C34	9140 123388	MAKSIM ROMANOV	{"email": "m-romanov_011971@postgrespro.ru", "phone": "+70003218659"}
0005432603909	1B3C34	6008 167012	ALEKSEY KUZNECOV	{"email": "akuznecov031968@postgrespro.ru", "phone": "+70837745902"}
0005432603910	F8667E	8072 790127	NINA DAVYDOVA	{"email": "n_davydova_031973@postgrespro.ru", "phone": "+70874573225"}
0005432603911	EFC233	5154 300767	YURIY ANDREEV	{"email": "yuriy_andreev.1964@postgrespro.ru", "phone": "+70693114200"}
0005432603912	EFC233	0224 958565	MIKHAIL SERGEEV	{"phone": "+70153249850"}
0005432603913	E10BBE	6189 234044	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov031967@postgrespro.ru", "phone": "+70496069411"}
0005432603914	E10BBE	6997 228570	ELIZAVETA SOROKINA	{"phone": "+70563253869"}
0005432603915	E10BBE	4213 165731	TAMARA FOMINA	{"email": "fominat11091985@postgrespro.ru", "phone": "+70218904226"}
0005432603916	E10BBE	9977 884649	SEMEN ZAKHAROV	{"email": "semenzakharov-26041979@postgrespro.ru", "phone": "+70290860900"}
0005432603917	B70557	5767 888672	MARIYA TIKHONOVA	{"phone": "+70020169988"}
0005432603918	A228E9	0127 683865	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov.1978@postgrespro.ru", "phone": "+70855272330"}
0005432603919	A228E9	3039 494922	VYACHESLAV GUSEV	{"email": "v.gusev_091967@postgrespro.ru", "phone": "+70477097170"}
0005432603920	997B70	0041 199662	DMITRIY KULIKOV	{"email": "kulikov.d.051979@postgrespro.ru", "phone": "+70376126163"}
0005432603921	A6A962	8009 918139	TATYANA BELYAEVA	{"email": "belyaeva-t.031965@postgrespro.ru", "phone": "+70614444677"}
0005432603922	A6A962	0859 179879	MIKHAIL PETROV	{"phone": "+70464453158"}
0005432603923	2CDDFE	1408 134341	DMITRIY ZAYCEV	{"phone": "+70687051481"}
0005432603924	952991	1976 457795	VLADISLAV ALEKSEEV	{"phone": "+70208302336"}
0005432603925	952991	9618 968671	MARIYA VOLKOVA	{"email": "mariya-volkova-25101982@postgrespro.ru", "phone": "+70836784329"}
0005432603926	4F83BE	2221 208728	ANNA NAUMOVA	{"email": "naumovaa_121976@postgrespro.ru", "phone": "+70615861823"}
0005432603927	E9773C	9366 925676	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena081981@postgrespro.ru", "phone": "+70967671848"}
0005432603928	39B5E5	9667 235449	RAVIL TARASOV	{"email": "tarasovravil.1976@postgrespro.ru", "phone": "+70016545756"}
0005432603929	39B5E5	5427 817392	IGOR KOZLOV	{"phone": "+70882880658"}
0005432603930	785622	7449 455939	VLADIMIR PETROV	{"email": "petrov_vladimir-121973@postgrespro.ru", "phone": "+70597346134"}
0005432603931	AE8D3D	9696 281543	ANDREY ZHURAVLEV	{"phone": "+70657079336"}
0005432603932	AE8D3D	3709 295824	EVGENIY SERGEEV	{"email": "e-sergeev-1970@postgrespro.ru", "phone": "+70402742459"}
0005432603933	AE8D3D	8561 873332	EDUARD SAVELEV	{"email": "eduard.savelev.30081970@postgrespro.ru", "phone": "+70161970278"}
0005432603934	F692F6	9798 899179	VLADIMIR KUZMIN	{"phone": "+70031369980"}
0005432603935	3FF725	5186 703307	NADEZHDA ILINA	{"email": "ilina_n1965@postgrespro.ru", "phone": "+70500297407"}
0005432603936	3FF725	7597 960847	ILYA IVANOV	{"phone": "+70279592162"}
0005432603937	F367F4	1120 333045	SVETLANA SOROKINA	{"email": "sorokina.s-081982@postgrespro.ru", "phone": "+70627211454"}
0005432603938	A88A61	7650 002844	DARYA EGOROVA	{"phone": "+70111544321"}
0005432603939	7FCDA3	8689 967718	SERGEY VOROBEV	{"email": "vorobevsergey.031974@postgrespro.ru", "phone": "+70244677028"}
0005432603940	1B7A3C	1342 103287	DMITRIY ABRAMOV	{"phone": "+70981195611"}
0005432603941	569812	3322 380603	ALEKSEY KISELEV	{"email": "kiselev_aleksey-18081959@postgrespro.ru", "phone": "+70824500423"}
0005432603942	569812	4207 175123	NATALYA MOROZOVA	{"phone": "+70348967418"}
0005432603943	FA5F65	4780 546852	SERGEY ABRAMOV	{"phone": "+70017843793"}
0005432603944	FA5F65	3800 074668	SHAMIL NIKOLAEV	{"phone": "+70285984753"}
0005432603945	4A2A8B	9766 640894	ANASTASIYA SEMENOVA	{"phone": "+70128385605"}
0005432603946	CBFBD4	8408 648236	ANASTASIYA ORLOVA	{"email": "aorlova.031974@postgrespro.ru", "phone": "+70148797719"}
0005432603947	123800	7749 635850	ARTEM ILIN	{"email": "ilin-a_1959@postgrespro.ru", "phone": "+70419199847"}
0005432603948	F58915	9721 813036	MATVEY ORLOV	{"phone": "+70972022869"}
0005432603949	CFD4F8	3384 309430	POLINA IVANOVA	{"email": "polina-ivanova031978@postgrespro.ru", "phone": "+70343483959"}
0005432603950	CFD4F8	2548 191061	DARINA MELNIKOVA	{"phone": "+70517278247"}
0005432603951	DF6460	0024 299684	IGOR IVANOV	{"phone": "+70848661271"}
0005432603953	36F019	8476 841695	SARIYA SERGEEVA	{"phone": "+70052572750"}
0005432603954	7DC306	5748 737461	MARIYA POLYAKOVA	{"phone": "+70312513637"}
0005432603955	7EE8EC	4354 928951	RAISA NESTEROVA	{"email": "nesterovar.091975@postgrespro.ru", "phone": "+70082529371"}
0005432603956	221FB7	4180 265687	NATALYA ZAKHAROVA	{"phone": "+70520319513"}
0005432603957	C15F45	0550 748260	VIKTOR FEDOROV	{"phone": "+70817495394"}
0005432603958	C15F45	3712 431706	VALERIY PAVLOV	{"email": "v-pavlov-1972@postgrespro.ru", "phone": "+70539598498"}
0005432603959	EDB813	8465 899766	SERGEY FEDOTOV	{"email": "fedotov_sergey_061980@postgrespro.ru", "phone": "+70155046687"}
0005432603960	26DABB	8604 018192	EVGENIY YAKOVLEV	{"email": "eyakovlev-27021973@postgrespro.ru", "phone": "+70858976193"}
0005432603961	70718D	5215 101428	TATYANA TITOVA	{"email": "tatyana-titova06081977@postgrespro.ru", "phone": "+70250968414"}
0005432603962	955CA9	0248 868206	VYACHESLAV KUDRYASHOV	{"email": "kudryashov.vyacheslav.1979@postgrespro.ru", "phone": "+70871659400"}
0005432603963	961A7C	1158 205840	KRISTINA KALININA	{"phone": "+70501360113"}
0005432603964	961A7C	1511 532951	TAMARA ISAEVA	{"email": "tamaraisaeva.031965@postgrespro.ru", "phone": "+70362925317"}
0005432603965	961A7C	3013 236193	ANDREY EGOROV	{"phone": "+70106172352"}
0005432603966	CDA2AA	5324 163932	ALEKSEY GAVRILOV	{"phone": "+70887536113"}
0005432603967	CDA2AA	1566 436123	KONSTANTIN FILIPPOV	{"email": "konstantin.filippov1973@postgrespro.ru", "phone": "+70864469587"}
0005432603968	C6D129	4847 023677	PETR DAVYDOV	{"email": "petr.davydov.1966@postgrespro.ru", "phone": "+70436609555"}
0005432603969	2C1C93	6779 880072	ELENA ZHURAVLEVA	{"email": "elenazhuravleva30071964@postgrespro.ru", "phone": "+70727435017"}
0005432603970	611A3A	0830 983053	EKATERINA GORBUNOVA	{"email": "gorbunovae24031976@postgrespro.ru", "phone": "+70499179705"}
0005432603971	D7426F	3942 975627	LIDIYA SERGEEVA	{"phone": "+70290383973"}
0005432603972	C03EF0	0149 990222	DENIS NIKOLAEV	{"email": "nikolaev-d-051975@postgrespro.ru", "phone": "+70860328896"}
0005432603973	57D2B4	2686 230697	ANTONINA ANTONOVA	{"email": "antonova_antonina-041971@postgrespro.ru", "phone": "+70161494042"}
0005432603974	57D2B4	1795 596327	VYACHESLAV SHEVCHENKO	{"phone": "+70581584952"}
0005432603975	CA834E	5094 294780	EGOR NOVIKOV	{"phone": "+70104936700"}
0005432603976	CA834E	5099 721864	OLEG SAVELEV	{"email": "savelev.o_011962@postgrespro.ru", "phone": "+70218337316"}
0005432603977	219BEA	5373 321080	SERGEY ANTONOV	{"email": "antonovs-10051972@postgrespro.ru", "phone": "+70764940056"}
0005432603978	DF7ED4	7796 821905	PELAGEYA KUZNECOVA	{"email": "p-kuznecova-13111961@postgrespro.ru", "phone": "+70312637360"}
0005432603979	EDC451	5034 245743	ELENA NESTEROVA	{"phone": "+70644400251"}
0005432603980	1569C0	5456 780092	ELIZAVETA ANTONOVA	{"email": "e_antonova_061974@postgrespro.ru", "phone": "+70832884142"}
0005432603981	1569C0	4321 619400	ANASTASIYA TITOVA	{"phone": "+70478922977"}
0005432603982	86D7D3	6514 925357	VALERIYA TARASOVA	{"email": "tarasova_v_28031974@postgrespro.ru", "phone": "+70704519032"}
0005432603983	94045A	6384 872003	TATYANA GERASIMOVA	{"phone": "+70695773610"}
0005432603984	94045A	8205 732252	NIKOLAY MOROZOV	{"phone": "+70229047154"}
0005432603985	9D16A9	2316 835346	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr1966@postgrespro.ru", "phone": "+70298101420"}
0005432603986	04E393	4215 804773	SERGEY FILIPPOV	{"phone": "+70846939073"}
0005432603987	C25EF9	1448 415224	TATYANA ANDREEVA	{"email": "andreeva_t.08121966@postgrespro.ru", "phone": "+70872171304"}
0005432603988	987D0E	3659 609671	EKATERINA ROMANOVA	{"phone": "+70103439399"}
0005432603989	C94A01	2862 488975	EGOR KONOVALOV	{"phone": "+70222452093"}
0005432603990	C94A01	7835 040473	VIKTOR MAKAROV	{"email": "viktor_makarov_1983@postgrespro.ru", "phone": "+70494456009"}
0005432603991	DBEC19	3077 950275	SVETLANA MARTYNOVA	{"phone": "+70695648157"}
0005432603992	523A94	4765 425806	VALENTINA MEDVEDEVA	{"email": "medvedevavalentina1980@postgrespro.ru", "phone": "+70641499279"}
0005432603993	523A94	1737 353141	FLYURA ROMANOVA	{"phone": "+70115558536"}
0005432603994	523A94	2329 888351	NIKOLAY IVANOV	{"email": "nivanov1975@postgrespro.ru", "phone": "+70612212290"}
0005432603995	B151AF	0396 319120	ALEKSANDR MELNIKOV	{"email": "amelnikov_1978@postgrespro.ru", "phone": "+70837123195"}
0005432603996	ED2F9E	1498 060414	VALERIY KUZNECOV	{"phone": "+70829853924"}
0005432603997	ED2F9E	9152 387718	MAKSIM NAUMOV	{"phone": "+70912379338"}
0005432603998	B17686	0533 611026	LYUBOV TIMOFEEVA	{"phone": "+70826302727"}
0005432603999	A96CC2	3299 403832	ARTEM ABRAMOV	{"email": "artem.abramov_15111971@postgrespro.ru", "phone": "+70533921809"}
0005432604000	A96CC2	2067 876958	IRINA VOLKOVA	{"email": "volkova-irina-1980@postgrespro.ru", "phone": "+70482901540"}
0005432604001	07E681	3618 355699	ALEKSANDR IVANOV	{"email": "a-ivanov.03091965@postgrespro.ru", "phone": "+70025194350"}
0005432604002	0A6DAA	6686 943371	ELENA KOZLOVA	{"phone": "+70301194125"}
0005432604003	1C9668	6487 590124	ALEKSEY BORISOV	{"email": "borisovaleksey.16121970@postgrespro.ru", "phone": "+70624418857"}
0005432604004	76E916	0335 783518	OLGA FROLOVA	{"phone": "+70779612789"}
0005432604005	A170C9	2439 366207	VIKTOR TIMOFEEV	{"email": "timofeev_v-19071972@postgrespro.ru", "phone": "+70478656232"}
0005432604006	2B8DB4	6349 770595	PAVEL PAVLOV	{"email": "pavel-pavlov.1964@postgrespro.ru", "phone": "+70343705887"}
0005432604007	2B8DB4	5778 684334	SANIYA KUZMINA	{"phone": "+70445001607"}
0005432604008	2B8DB4	8674 671911	NADEZHDA ZAYCEVA	{"phone": "+70869586801"}
0005432604009	E73CA2	0594 945491	NADEZHDA STEPANOVA	{"phone": "+70615965681"}
0005432604010	0635C3	4815 024090	ALEKSANDR EGOROV	{"email": "aleksandr-egorov-26011973@postgrespro.ru", "phone": "+70155679490"}
0005432604011	D67DAB	0479 650987	ALEKSANDRA MOROZOVA	{"phone": "+70575085647"}
0005432604012	690A2B	5732 829766	VLADIMIR KISELEV	{"email": "kiselev.v-121968@postgrespro.ru", "phone": "+70170516483"}
0005432604013	BD9229	1993 461612	VADIM ZHURAVLEV	{"email": "zhuravlev.vadim18111964@postgrespro.ru", "phone": "+70195295372"}
0005432604014	215F5A	1795 968683	VLADIMIR SERGEEV	{"email": "v.sergeev22051981@postgrespro.ru", "phone": "+70117851132"}
0005432604015	215F5A	2510 148269	MARINA KUZNECOVA	{"email": "marina-kuznecova.1966@postgrespro.ru", "phone": "+70153775933"}
0005432604016	79997F	8511 605040	ALEKSANDR SCHERBAKOV	{"phone": "+70420558393"}
0005432604017	891C44	8468 154130	OLEG MOROZOV	{"phone": "+70932146024"}
0005432604018	01F876	3132 018255	ALBERT BELOV	{"phone": "+70995453568"}
0005432604019	74987A	2061 031629	EKATERINA TIMOFEEVA	{"email": "ekaterina.timofeeva-101972@postgrespro.ru", "phone": "+70189218539"}
0005432604020	74987A	5479 720016	ELIZAVETA ZHURAVLEVA	{"phone": "+70789588821"}
0005432604021	2CF207	4606 098133	ANATOLIY IVANOV	{"phone": "+70945049890"}
0005432604022	05DB52	6801 409386	ALEKSANDR ALEKSEEV	{"email": "alekseev-a1975@postgrespro.ru", "phone": "+70395277282"}
0005432604023	05DB52	8754 596774	TATYANA SIDOROVA	{"phone": "+70865228378"}
0005432604024	764699	5922 481998	DANIIL KUZMIN	{"phone": "+70948209390"}
0005432604025	B9E197	9156 685430	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-06011975@postgrespro.ru", "phone": "+70269903770"}
0005432604026	5B9D42	0245 471385	YULIYA FROLOVA	{"phone": "+70828021279"}
0005432604027	5B9D42	0625 571341	VYACHESLAV POPOV	{"email": "popov-vyacheslav.071971@postgrespro.ru", "phone": "+70944195681"}
0005432604028	384AE4	9530 999599	LIDIYA TIMOFEEVA	{"email": "timofeeva.l1973@postgrespro.ru", "phone": "+70971477085"}
0005432604029	44CE87	9368 196455	NINEL ANISIMOVA	{"email": "anisimovan_1978@postgrespro.ru", "phone": "+70819848389"}
0005432604030	D53BF1	3066 714281	SERGEY KOROLEV	{"email": "korolevs_1987@postgrespro.ru", "phone": "+70768344840"}
0005432604031	D53BF1	9863 771285	VLADIMIR EGOROV	{"phone": "+70887284343"}
0005432604032	D53BF1	4814 989577	VALERIY FEDOROV	{"phone": "+70839857030"}
0005432604033	FFC0AB	1852 193901	ALENA DANILOVA	{"email": "danilova_a.1970@postgrespro.ru", "phone": "+70036910597"}
0005432604034	23789F	6590 580185	TATYANA MIKHAYLOVA	{"phone": "+70585211534"}
0005432604035	23789F	6966 090401	VLADIMIR DMITRIEV	{"phone": "+70620784615"}
0005432604036	0C5672	2025 370714	DANIIL KULIKOV	{"phone": "+70151903037"}
0005432604037	77321E	8830 357343	TAMARA KOROLEVA	{"email": "t-koroleva-22011970@postgrespro.ru", "phone": "+70698710874"}
0005432604038	27940F	5064 627445	TATYANA VOROBEVA	{"phone": "+70708777208"}
0005432604039	B3416E	1873 891359	LYUBOV PETROVA	{"email": "lyubov-petrova.111981@postgrespro.ru", "phone": "+70524027938"}
0005432604040	B3416E	6852 471025	VIKTOR IVANOV	{"phone": "+70598884444"}
0005432604041	5FDB58	9747 153729	YANA NOVIKOVA	{"phone": "+70242547196"}
0005432604042	5FDB58	9091 003934	YURIY DMITRIEV	{"email": "y_dmitriev_05101961@postgrespro.ru", "phone": "+70449369555"}
0005432604043	93CF26	6051 056617	RAFAIL SOROKIN	{"phone": "+70432302560"}
0005432604044	566AE8	8874 372493	NIKOLAY OSIPOV	{"phone": "+70973196629"}
0005432604215	2AB3CF	9088 650267	NINA KUZMINA	{"phone": "+70940864427"}
0005432604272	37D80B	1969 246875	LIDIYA ANDREEVA	{"phone": "+70288922593"}
0005432604045	5C09F6	4775 720108	SERGEY SERGEEV	{"email": "s-sergeev_121969@postgrespro.ru", "phone": "+70993898407"}
0005432604046	5C09F6	7088 894318	ROZA ARKHIPOVA	{"email": "arkhipova_r-1972@postgrespro.ru", "phone": "+70486859294"}
0005432604047	10FB66	2851 753013	ELENA MELNIKOVA	{"email": "melnikova-e_1961@postgrespro.ru", "phone": "+70853531593"}
0005432604048	A35DBD	2813 424242	PETR MIKHAYLOV	{"email": "p-mikhaylov1972@postgrespro.ru", "phone": "+70716415030"}
0005432604049	53C20F	5136 672843	ANATOLIY KOROLEV	{"phone": "+70382424368"}
0005432604050	53C20F	0153 396138	TAMARA PAVLOVA	{"email": "pavlova_tamara_1980@postgrespro.ru", "phone": "+70809376618"}
0005432604051	6FDB1F	8222 035068	VLADIMIR DENISOV	{"phone": "+70876036123"}
0005432604052	6FDB1F	1886 418121	TATYANA PETROVA	{"email": "petrovatatyana-1961@postgrespro.ru", "phone": "+70552166332"}
0005432604053	F8B89F	1730 771262	NATALYA ORLOVA	{"email": "natalya.orlova-101973@postgrespro.ru", "phone": "+70162275104"}
0005432604054	6DB308	3912 568807	DMITRIY ABRAMOV	{"phone": "+70136181118"}
0005432604055	6DB308	5815 963220	SERGEY ANTONOV	{"phone": "+70731299033"}
0005432604056	6DB308	3022 426413	RUSLAN ZHURAVLEV	{"phone": "+70265420368"}
0005432604057	5E38BF	8477 176659	NIKOLAY GUSEV	{"phone": "+70140347710"}
0005432604058	E35BAE	2605 227955	NINA KOVALEVA	{"email": "nina_kovaleva-1964@postgrespro.ru", "phone": "+70641849158"}
0005432604059	BDE4C6	9127 691269	MARIYA ANDREEVA	{"email": "andreeva.mariya101974@postgrespro.ru", "phone": "+70169695976"}
0005432604060	BDE4C6	1803 703340	TAISIYA IVANOVA	{"phone": "+70447322477"}
0005432604061	31D695	6842 475138	YURIY TIKHONOV	{"email": "tikhonov-yuriy071957@postgrespro.ru", "phone": "+70237783820"}
0005432604062	F380AD	1432 492291	MARIYA SOKOLOVA	{"email": "sokolova_mariya.1972@postgrespro.ru", "phone": "+70184532579"}
0005432604063	C88FCE	9156 931085	VLADIMIR VLASOV	{"phone": "+70240094858"}
0005432604064	C88FCE	3082 621835	GALINA SMIRNOVA	{"phone": "+70455761138"}
0005432604065	178F29	5064 867781	ZINAIDA MARTYNOVA	{"email": "zinaida.martynova-101974@postgrespro.ru", "phone": "+70224397699"}
0005432604066	178F29	1158 086049	ALEKSANDR SOKOLOV	{"phone": "+70330619315"}
0005432604067	178F29	3483 234641	OLGA GERASIMOVA	{"email": "olga-gerasimova1985@postgrespro.ru", "phone": "+70944974493"}
0005432604068	AD949D	6941 075792	ANTONINA MIRONOVA	{"phone": "+70126739609"}
0005432604069	F6F6E8	8916 329009	VYACHESLAV SOKOLOV	{"phone": "+70199938139"}
0005432604070	B94735	9680 130903	ANNA TARASOVA	{"email": "tarasova.anna1967@postgrespro.ru", "phone": "+70020753604"}
0005432604071	5B9336	0164 088131	VIKTOR NIKITIN	{"phone": "+70416811829"}
0005432604072	6AB258	8770 198079	ANATOLIY NIKITIN	{"phone": "+70835968192"}
0005432604073	31EC02	2620 642944	LYUBOV KOROLEVA	{"phone": "+70326490161"}
0005432604074	CF86D4	6202 204729	ILYA KUZNECOV	{"email": "i.kuznecov_03061982@postgrespro.ru", "phone": "+70186075841"}
0005432604075	61DC04	8402 069166	MIKHAIL FEDOROV	{"phone": "+70858401432"}
0005432604076	203538	4853 475085	MIKHAIL SOLOVEV	{"email": "solovevmikhail-041968@postgrespro.ru", "phone": "+70898472567"}
0005432604077	56ED46	6470 431401	IGOR GRIGOREV	{"phone": "+70719000025"}
0005432604078	C63E2D	7563 226866	ZOYA KOROLEVA	{"phone": "+70382987916"}
0005432604079	0F8C1D	2573 291159	PAVEL MIKHAYLOV	{"email": "pmikhaylov_021974@postgrespro.ru", "phone": "+70647076102"}
0005432604080	34AE91	1426 411126	VASILIY VASILEV	{"email": "vasiliy.vasilev_30081986@postgrespro.ru", "phone": "+70215393502"}
0005432604081	34AE91	0455 996680	VERA FOMINA	{"phone": "+70739435528"}
0005432604082	E31BF6	2566 675660	ILYA ZAKHAROV	{"phone": "+70828264438"}
0005432604083	5AB387	0108 124884	TAMARA SMIRNOVA	{"phone": "+70092272118"}
0005432604084	5AB387	2470 128375	ELIZAVETA ILINA	{"email": "elizaveta.ilina1960@postgrespro.ru", "phone": "+70004037298"}
0005432604085	CA8781	2993 336973	IRINA KOMAROVA	{"phone": "+70589581202"}
0005432604086	5B2DC3	8171 461288	NINA KAZAKOVA	{"email": "kazakova_n_1976@postgrespro.ru", "phone": "+70456770502"}
0005432604087	5B2DC3	6035 107239	DMITRIY GRIGOREV	{"email": "d.grigorev.1968@postgrespro.ru", "phone": "+70773908628"}
0005432604088	DCA5A8	5727 605697	OKSANA PETROVA	{"email": "o-petrova.011964@postgrespro.ru", "phone": "+70786979132"}
0005432604089	DCA5A8	2017 177678	NATALYA NIKOLAEVA	{"email": "natalya_nikolaeva-021977@postgrespro.ru", "phone": "+70575586712"}
0005432604090	A86A94	2692 625737	VALENTINA CHERNOVA	{"phone": "+70055472050"}
0005432604091	A86A94	9048 754242	ZHANNA KUZMINA	{"phone": "+70412780469"}
0005432604092	28506D	3018 640011	ALEKSANDR SOROKIN	{"phone": "+70281694858"}
0005432604093	C4AEFE	3293 595606	VLADISLAV KOZLOV	{"phone": "+70322255915"}
0005432604094	C03ADC	3574 513713	VIKTOR ALEKSANDROV	{"phone": "+70609174386"}
0005432604095	C1C951	3164 807898	GALIYA NAUMOVA	{"email": "galiya.naumova-14101971@postgrespro.ru", "phone": "+70503183343"}
0005432604096	C1C951	5772 000097	MIKHAIL IVANOV	{"phone": "+70085265543"}
0005432604097	2B62F2	7838 985755	OLEG MELNIKOV	{"email": "melnikovoleg-051987@postgrespro.ru", "phone": "+70176535271"}
0005432604098	2B62F2	7288 066575	NINA MEDVEDEVA	{"email": "nina_medvedeva1968@postgrespro.ru", "phone": "+70090265179"}
0005432604099	DFBF77	4287 306484	NINA VOLKOVA	{"email": "volkovan.071972@postgrespro.ru", "phone": "+70526307177"}
0005432604100	452671	4695 736771	DENIS NAZAROV	{"email": "d.nazarov1960@postgrespro.ru", "phone": "+70003535931"}
0005432604101	452671	5526 775515	SERGEY KUZNECOV	{"email": "kuznecov-s-031975@postgrespro.ru", "phone": "+70343768509"}
0005432604102	AFB1B1	4331 355126	OLESYA EFIMOVA	{"email": "olesya_efimova_25071976@postgrespro.ru", "phone": "+70881217537"}
0005432604103	B3A7B4	7346 492165	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev_101965@postgrespro.ru", "phone": "+70676305818"}
0005432604104	B3A7B4	5191 559730	NATALYA STEPANOVA	{"phone": "+70626320298"}
0005432604105	B3A7B4	2854 919159	ALENA ISAEVA	{"email": "isaeva.a-1974@postgrespro.ru", "phone": "+70017231269"}
0005432604106	719CC4	3005 685919	TATYANA MALYSHEVA	{"phone": "+70416410795"}
0005432604107	C7BAA2	0531 994217	EKATERINA VASILEVA	{"phone": "+70529220688"}
0005432604108	C7BAA2	5272 769255	DMITRIY KUZNECOV	{"phone": "+70464619942"}
0005432604109	8CC44A	8510 330396	NIKOLAY KISELEV	{"phone": "+70020597479"}
0005432604110	02B148	7043 982096	LIDIYA VOLKOVA	{"phone": "+70928415621"}
0005432604111	C2F0F8	3808 307875	ANDREY POPOV	{"email": "andrey_popov.1980@postgrespro.ru", "phone": "+70780454260"}
0005432604112	E089DD	0475 429883	STANISLAV NIKOLAEV	{"phone": "+70373619647"}
0005432604113	7FDC5E	6487 200192	EVGENIY TIKHONOV	{"email": "e-tikhonov09021978@postgrespro.ru", "phone": "+70353134834"}
0005432604114	7FDC5E	1876 404947	NATALYA ANDREEVA	{"email": "andreevanatalya_1981@postgrespro.ru", "phone": "+70770313248"}
0005432604115	3E582B	2313 554248	ELENA KALININA	{"email": "kalinina.e-1969@postgrespro.ru", "phone": "+70665557890"}
0005432604116	D11C5C	8952 186021	ANTONINA MIRONOVA	{"email": "amironova.1963@postgrespro.ru", "phone": "+70054034080"}
0005432604117	BC9A9A	9088 781585	VIKTOR KAZAKOV	{"phone": "+70551574859"}
0005432604118	825D8A	5284 171615	NIKITA MELNIKOV	{"email": "nikitamelnikov.1976@postgrespro.ru", "phone": "+70766971266"}
0005432604119	BEC066	2988 636295	ANDREY NIKOLAEV	{"phone": "+70479439217"}
0005432604120	BEC066	7758 463118	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev111958@postgrespro.ru", "phone": "+70995413600"}
0005432604121	2334FC	0660 074261	OLGA OSIPOVA	{"email": "osipova_olga_081970@postgrespro.ru", "phone": "+70328208673"}
0005432604122	2334FC	2902 587531	STANISLAV ZAKHAROV	{"phone": "+70278726592"}
0005432604123	3C51C3	8992 216357	TATYANA ARKHIPOVA	{"phone": "+70740837968"}
0005432604124	3C51C3	1550 310428	EVELINA ORLOVA	{"email": "orlovae1970@postgrespro.ru", "phone": "+70859557683"}
0005432604125	C0996A	5735 564304	ILYA SOROKIN	{"phone": "+70154729275"}
0005432604126	C0996A	8042 437555	EVGENIY SIDOROV	{"phone": "+70952562405"}
0005432604127	8282DB	4430 545393	DARYA SOKOLOVA	{"email": "darya_sokolova.25011980@postgrespro.ru", "phone": "+70471542759"}
0005432604128	BEF27C	2092 115544	NATALYA PETROVA	{"email": "n_petrova121992@postgrespro.ru", "phone": "+70574260668"}
0005432604129	BEF27C	2274 189562	ANZHELA ZAKHAROVA	{"email": "zakharovaa_14041979@postgrespro.ru", "phone": "+70748313217"}
0005432604130	11C073	5970 693508	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-1964@postgrespro.ru", "phone": "+70629353161"}
0005432604131	11C073	5051 058990	DENIS KULIKOV	{"email": "kulikov-denis-061976@postgrespro.ru", "phone": "+70514847306"}
0005432604132	A61EC1	0957 426104	ELIZAVETA KULIKOVA	{"phone": "+70277709220"}
0005432604133	C1C3EE	0211 000842	VYACHESLAV NAZAROV	{"email": "v_nazarov-061973@postgrespro.ru", "phone": "+70317060849"}
0005432604134	C1C3EE	2217 094446	TATYANA MAKSIMOVA	{"phone": "+70753054486"}
0005432604135	EC651F	8672 821174	SVETLANA KOZLOVA	{"phone": "+70150160673"}
0005432604136	EC651F	6550 431631	MARINA KUDRYASHOVA	{"email": "mkudryashova.23051972@postgrespro.ru", "phone": "+70986738239"}
0005432604137	238C05	8438 810475	LYUBOV OSIPOVA	{"email": "osipoval.25021981@postgrespro.ru", "phone": "+70569790768"}
0005432604138	238C05	8309 714145	DANIL KOROLEV	{"email": "danil_korolev.1968@postgrespro.ru", "phone": "+70050329343"}
0005432604139	238C05	5035 274288	BORIS ZAYCEV	{"email": "zaycev-b.101970@postgrespro.ru", "phone": "+70436591499"}
0005432604140	238C05	0287 222899	KRISTINA IVANOVA	{"email": "ivanova_k-28071977@postgrespro.ru", "phone": "+70391997366"}
0005432604141	646D98	5119 802981	VALERIY VASILEV	{"phone": "+70298146128"}
0005432604142	646D98	0417 974405	SERGEY STEPANOV	{"email": "s_stepanov.021975@postgrespro.ru", "phone": "+70778650760"}
0005432604143	4E8802	5141 377339	ELENA LEBEDEVA	{"phone": "+70567296466"}
0005432604144	D59AA5	8809 272319	LIDIYA DMITRIEVA	{"phone": "+70632452951"}
0005432604145	5B5081	9096 260655	ANDREY MARTYNOV	{"email": "a-martynov-1980@postgrespro.ru", "phone": "+70878370028"}
0005432604146	CE9CE8	2425 454875	SERGEY KOZLOV	{"phone": "+70231567773"}
0005432604147	1B1140	4124 818747	ANDREY MIRONOV	{"email": "andreymironov.091983@postgrespro.ru", "phone": "+70831203759"}
0005432604148	B53F83	2364 587421	LIDIYA ZAKHAROVA	{"email": "zakharova-lidiya.091971@postgrespro.ru", "phone": "+70596370120"}
0005432604149	B53F83	6740 145141	OLGA SIDOROVA	{"email": "osidorova.1971@postgrespro.ru", "phone": "+70736764924"}
0005432604150	83B78A	0460 997536	YURIY OSIPOV	{"phone": "+70760740486"}
0005432604151	A86E81	2295 122020	NATALIYA ZHUKOVA	{"email": "zhukovanataliya-26111969@postgrespro.ru", "phone": "+70752688040"}
0005432604152	49F394	8182 425034	YURIY VOLKOV	{"phone": "+70506056366"}
0005432604153	35BECF	1939 298722	ALEKSANDRA NESTEROVA	{"phone": "+70817959535"}
0005432604154	35BECF	0302 109627	SVETLANA NESTEROVA	{"email": "svetlana.nesterova-23081967@postgrespro.ru", "phone": "+70324723914"}
0005432604155	6F9BFC	7934 905170	EVGENIY SIDOROV	{"phone": "+70726975529"}
0005432604156	6F9BFC	2478 043344	EVGENIY NOVIKOV	{"phone": "+70867622518"}
0005432604157	6C8B16	7126 439215	IRINA ANISIMOVA	{"email": "irina-anisimova_1972@postgrespro.ru", "phone": "+70584037975"}
0005432604158	71A640	0840 466129	EKATERINA IVANOVA	{"phone": "+70650743454"}
0005432604159	FE1856	4508 666114	ELENA KONOVALOVA	{"phone": "+70466107109"}
0005432604160	FE1856	5893 714243	VASILIY KUZMIN	{"phone": "+70540901210"}
0005432604161	33820A	9650 597028	ANTON PETROV	{"phone": "+70518161416"}
0005432604162	33820A	7409 444383	ALEKSANDR ZHURAVLEV	{"phone": "+70994260891"}
0005432604163	1CB1D0	6538 328898	LYUBOV NOVIKOVA	{"phone": "+70928046389"}
0005432604164	385D9D	7654 682500	DMITRIY FOMIN	{"email": "dmitriy_fomin071973@postgrespro.ru", "phone": "+70449166060"}
0005432604165	385D9D	6236 430238	ALEKSANDR MIKHAYLOV	{"phone": "+70222358100"}
0005432604166	68016F	9018 575183	ELENA NIKITINA	{"phone": "+70727215505"}
0005432604167	50B215	5132 331640	OLGA BORISOVA	{"phone": "+70805763233"}
0005432604168	50B215	5078 180310	DMITRIY ABRAMOV	{"phone": "+70558435892"}
0005432604169	024649	0547 211374	VIKTOR FILIPPOV	{"phone": "+70302260756"}
0005432604170	569D43	7262 032844	NIKOLAY MEDVEDEV	{"phone": "+70514883924"}
0005432604171	569D43	5656 902216	NADEZHDA FROLOVA	{"phone": "+70399789183"}
0005432604172	C29D13	7248 976875	YURIY SOROKIN	{"phone": "+70927761413"}
0005432604173	07B111	5589 161608	LYUBOV MALYSHEVA	{"email": "malysheva.l_04041977@postgrespro.ru", "phone": "+70438649201"}
0005432604174	0877D7	8000 764050	TAMARA SEMENOVA	{"email": "semenova_tamara-101976@postgrespro.ru", "phone": "+70171246198"}
0005432604175	B6C529	7599 680037	GALINA MAKAROVA	{"phone": "+70120757147"}
0005432604176	9696E5	4561 904582	NIKOLAY SERGEEV	{"phone": "+70883747776"}
0005432604177	8525B1	5298 743259	TIMUR VASILEV	{"phone": "+70373529719"}
0005432604178	55EBA2	8142 581224	ARTEM ANDREEV	{"email": "aandreev-09021970@postgrespro.ru", "phone": "+70823646491"}
0005432604179	202140	4283 620125	ALEKSANDR DAVYDOV	{"phone": "+70777134218"}
0005432604180	F9FC26	5865 669260	PETR TIKHONOV	{"email": "tikhonov.p-041953@postgrespro.ru", "phone": "+70930842726"}
0005432604181	F9FC26	8175 257981	VITALIY PETROV	{"email": "v-petrov-1984@postgrespro.ru", "phone": "+70889277169"}
0005432604182	657C18	0527 615495	SERGEY TARASOV	{"phone": "+70704038469"}
0005432604183	F92928	4478 214088	ALBINA EGOROVA	{"phone": "+70455099674"}
0005432604184	F92928	0421 697035	PETR KAZAKOV	{"phone": "+70376850950"}
0005432604185	5F9457	3925 194373	KIRILL IVANOV	{"email": "ivanovkirill-011970@postgrespro.ru", "phone": "+70148454146"}
0005432604186	D44ACD	8608 721368	OLGA ANDREEVA	{"phone": "+70051756223"}
0005432604187	A6EE99	9624 078300	ALEKSANDRA KOZLOVA	{"phone": "+70327687538"}
0005432604188	A6EE99	1896 946965	VIKTORIYA BELYAEVA	{"phone": "+70147737996"}
0005432604189	F4E400	0331 509458	EKATERINA MATVEEVA	{"email": "matveevae_23031973@postgrespro.ru", "phone": "+70173624433"}
0005432604190	339A93	1756 556978	VIKTOR ZAKHAROV	{"email": "viktor_zakharov-1970@postgrespro.ru", "phone": "+70142607156"}
0005432604191	339A93	0590 252773	IVAN KUZMIN	{"phone": "+70215939538"}
0005432604192	339A93	1792 394931	YURIY MAKSIMOV	{"email": "yuriy.maksimov-15121971@postgrespro.ru", "phone": "+70470830250"}
0005432604193	2BB1D5	1053 353245	ANDREY POPOV	{"email": "apopov.12111968@postgrespro.ru", "phone": "+70449813117"}
0005432604194	F763A3	0584 683318	SVETLANA IVANOVA	{"email": "ivanovas.1978@postgrespro.ru", "phone": "+70501927751"}
0005432604195	9A2A2D	3859 350808	FARIDA TIKHONOVA	{"phone": "+70244618370"}
0005432604196	220B75	5129 419260	NATALYA KOMAROVA	{"email": "n_komarova-04051989@postgrespro.ru", "phone": "+70218638596"}
0005432604197	220B75	5402 517977	EKATERINA BORISOVA	{"email": "ekaterina.borisova.1972@postgrespro.ru", "phone": "+70187101948"}
0005432604198	7D2963	7469 793733	YULIYA MAKAROVA	{"phone": "+70286050999"}
0005432604199	01A733	9639 735342	EVGENIY MELNIKOV	{"phone": "+70028555411"}
0005432604200	01A733	5511 434015	ANATOLIY AFANASEV	{"email": "aafanasev_18041978@postgrespro.ru", "phone": "+70315892319"}
0005432604201	D9CB80	7336 886780	DMITRIY FEDOROV	{"email": "fedorov_dmitriy.24101969@postgrespro.ru", "phone": "+70055614264"}
0005432604202	41036F	8353 697737	ANDREY GAVRILOV	{"phone": "+70148855065"}
0005432604203	41036F	2009 777942	ANASTASIYA PETROVA	{"email": "petrova_a-1974@postgrespro.ru", "phone": "+70000018185"}
0005432604204	4F1CD7	7834 214638	VASILIY KUZNECOV	{"email": "vasiliy-kuznecov-1966@postgrespro.ru", "phone": "+70282735734"}
0005432604205	4F1CD7	8452 322870	IGOR KARPOV	{"phone": "+70705284930"}
0005432604206	BCF8D7	0566 618707	ANATOLIY EGOROV	{"phone": "+70680411254"}
0005432604207	57D64E	2965 964418	VLADISLAV YAKOVLEV	{"phone": "+70908944197"}
0005432604208	57D64E	2404 916397	VERA KUZMINA	{"email": "v.kuzmina_15071960@postgrespro.ru", "phone": "+70070024097"}
0005432604209	57D64E	2102 915551	IRINA SEMENOVA	{"email": "semenovai.1964@postgrespro.ru", "phone": "+70370045619"}
0005432604210	B6C39D	8255 122349	FLYURA EGOROVA	{"email": "egorova_f-1982@postgrespro.ru", "phone": "+70880822149"}
0005432604211	909B39	9254 446766	ANTONINA KOMAROVA	{"email": "komarova_a_1970@postgrespro.ru", "phone": "+70274336533"}
0005432604212	455BA4	7058 614580	VALERIY ROMANOV	{"phone": "+70611907204"}
0005432604213	5D34D4	4456 179354	IRINA SEMENOVA	{"phone": "+70910643403"}
0005432604214	53628D	4140 810913	VALERIY POPOV	{"phone": "+70791274086"}
0005432604216	03A752	7866 164445	ANDREY VOLKOV	{"email": "volkov.a.1973@postgrespro.ru", "phone": "+70714791750"}
0005432604217	216A0E	7566 148520	NADEZHDA KULIKOVA	{"phone": "+70783600964"}
0005432604218	A71ACA	8165 529591	VALERIY NIKOLAEV	{"phone": "+70616339294"}
0005432604219	BED824	0328 450074	IGOR ANTONOV	{"phone": "+70334000424"}
0005432604220	841604	0984 073420	ILYA KUZNECOV	{"email": "kuznecov_i-21081969@postgrespro.ru", "phone": "+70249492453"}
0005432604221	BF6126	6154 799189	GALINA VLASOVA	{"email": "vlasova-galina.1969@postgrespro.ru", "phone": "+70383243575"}
0005432604222	BF6126	2677 762806	KONSTANTIN ALEKSANDROV	{"phone": "+70775660883"}
0005432604223	A99196	8957 782879	ALEKSANDR SOROKIN	{"email": "a_sorokin.20011977@postgrespro.ru", "phone": "+70452431813"}
0005432604224	A99196	3987 289159	TAISIYA GORBUNOVA	{"phone": "+70592788017"}
0005432604225	A602F5	1956 175810	VLADIMIR ZAKHAROV	{"email": "v-zakharov.1975@postgrespro.ru", "phone": "+70369450513"}
0005432604226	A3F063	2152 558844	SERGEY ZAKHAROV	{"phone": "+70429600863"}
0005432604227	2649AB	4997 732703	FAINA MAKSIMOVA	{"phone": "+70745100095"}
0005432604228	2649AB	9034 237697	ANNA ZHUKOVA	{"phone": "+70092246535"}
0005432604229	72759C	0723 158840	EVGENIYA POTAPOVA	{"email": "e.potapova-18081978@postgrespro.ru", "phone": "+70946094227"}
0005432604230	7DDE0B	0990 284181	ANDREY ROMANOV	{"phone": "+70017905743"}
0005432604231	C6F80E	6930 474598	ALENA TARASOVA	{"email": "tarasova_alena.031965@postgrespro.ru", "phone": "+70362700387"}
0005432604232	89EB10	7988 219283	TATYANA DENISOVA	{"phone": "+70293370217"}
0005432604233	89EB10	7061 731532	YURIY SIDOROV	{"email": "sidorov.yuriy.071970@postgrespro.ru", "phone": "+70608009388"}
0005432604234	9C957D	9705 012331	VLADIMIR IVANOV	{"email": "ivanov.vladimir_061965@postgrespro.ru", "phone": "+70468893436"}
0005432604235	9C957D	2961 417527	ANTON SERGEEV	{"email": "a.sergeev.13121966@postgrespro.ru", "phone": "+70468651904"}
0005432604236	9C957D	7440 821203	SERGEY VASILEV	{"phone": "+70853467341"}
0005432604237	27C64D	3237 026190	MARINA KISELEVA	{"phone": "+70359777088"}
0005432604238	82068D	5331 619984	GRIGORIY ROMANOV	{"phone": "+70540688792"}
0005432604239	37E999	1690 849897	NINA SAVELEVA	{"phone": "+70492057722"}
0005432604240	37E999	4059 588361	IRINA KONOVALOVA	{"email": "i-konovalova_31081972@postgrespro.ru", "phone": "+70459876775"}
0005432604241	3123D2	2370 824683	RAFIS KOZLOV	{"email": "r-kozlov_031985@postgrespro.ru", "phone": "+70471510261"}
0005432604242	78EADA	0934 819185	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin-1965@postgrespro.ru", "phone": "+70942975332"}
0005432604243	78EADA	2544 695588	MAKSIM RODIONOV	{"phone": "+70458243530"}
0005432604244	0007A9	7714 889703	ANATOLIY VOLKOV	{"email": "anatoliy_volkov-1977@postgrespro.ru", "phone": "+70938999396"}
0005432604245	92ED51	5059 729919	VYACHESLAV OSIPOV	{"email": "vyacheslavosipov.17011969@postgrespro.ru", "phone": "+70046621118"}
0005432604246	92ED51	9496 839679	VALENTINA MASLOVA	{"email": "maslova.valentina.1976@postgrespro.ru", "phone": "+70045119354"}
0005432604247	E06280	7429 181059	DMITRIY NAUMOV	{"phone": "+70171278714"}
0005432604248	E06280	6236 509420	SERGEY SOKOLOV	{"email": "s-sokolov1976@postgrespro.ru", "phone": "+70368378852"}
0005432604249	B40B12	8165 050390	ANZHELA PAVLOVA	{"phone": "+70542497705"}
0005432604250	A2332A	4179 337901	ANDREY OSIPOV	{"email": "a.osipov_1970@postgrespro.ru", "phone": "+70735039229"}
0005432604251	A2332A	2720 489319	SERGEY MAKAROV	{"phone": "+70167046478"}
0005432604252	DE23E3	3026 862988	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov.09031965@postgrespro.ru", "phone": "+70867684339"}
0005432604253	DE23E3	8020 611485	IGOR ROMANOV	{"email": "i-romanov-021977@postgrespro.ru", "phone": "+70840570469"}
0005432604254	29E0F3	7600 677813	LIDIYA IVANOVA	{"email": "l.ivanova_081963@postgrespro.ru", "phone": "+70371848215"}
0005432604255	29E0F3	6789 371595	LILIYA MALYSHEVA	{"email": "l-malysheva_101986@postgrespro.ru", "phone": "+70489270527"}
0005432604256	DFD372	0654 842706	ANDREY TARASOV	{"phone": "+70793205195"}
0005432604257	AAF6CF	2977 909356	TATYANA OVCHINNIKOVA	{"email": "tatyanaovchinnikova.111980@postgrespro.ru", "phone": "+70475016980"}
0005432604258	075A7E	2283 627574	NIKOLAY KISELEV	{"email": "n-kiselev_1980@postgrespro.ru", "phone": "+70012239306"}
0005432604259	075A7E	5873 128773	ALEKSANDR BARANOV	{"phone": "+70833716801"}
0005432604260	075A7E	0361 177530	VLADIMIR ALEKSEEV	{"phone": "+70449070966"}
0005432604261	9219CB	2450 675424	YURIY ZAKHAROV	{"phone": "+70570962387"}
0005432604262	9219CB	4675 580748	VASILIY ORLOV	{"email": "orlov_vasiliy-15051966@postgrespro.ru", "phone": "+70990968062"}
0005432604263	E462D2	2489 818285	VERA RYABOVA	{"phone": "+70035458414"}
0005432604264	E462D2	0926 361988	ELENA EGOROVA	{"email": "elena_egorova.041975@postgrespro.ru", "phone": "+70268076798"}
0005432604265	629922	6860 936069	VALENTINA GUSEVA	{"phone": "+70882091652"}
0005432604266	629922	5732 512635	DARYA SCHERBAKOVA	{"email": "scherbakova.darya1961@postgrespro.ru", "phone": "+70443804933"}
0005432604267	5E5A6B	2317 554108	VASILIY ORLOV	{"phone": "+70544476581"}
0005432604268	5E5A6B	5573 696958	LIDIYA KISELEVA	{"phone": "+70635420417"}
0005432604269	FB4C8D	4367 549261	YULIYA SERGEEVA	{"phone": "+70467872979"}
0005432604270	ABFAB3	1571 291206	EVGENIY MOROZOV	{"email": "e.morozov-1980@postgrespro.ru", "phone": "+70050961485"}
0005432604271	8BE7D7	2200 748151	SAVELIY ALEKSANDROV	{"phone": "+70568301156"}
0005432604273	08EE5B	5127 272954	MATVEY MIKHAYLOV	{"email": "m_mikhaylov_051967@postgrespro.ru", "phone": "+70184077759"}
0005432604274	E8EABC	0304 799946	SERGEY ZAKHAROV	{"email": "s.zakharov.08101969@postgrespro.ru", "phone": "+70796986802"}
0005432604275	6343ED	0378 991672	OLEG SIDOROV	{"phone": "+70480731137"}
0005432604276	3DCA1F	9163 994450	NINA MAKAROVA	{"phone": "+70191577536"}
0005432604277	D1F535	0482 304559	SVETLANA TIKHONOVA	{"phone": "+70425836339"}
0005432604278	D1F535	7873 453212	RAFAEL VOLKOV	{"phone": "+70415177953"}
0005432604279	052E3D	7084 376373	ISLAM NOVIKOV	{"phone": "+70462020983"}
0005432604280	1497A6	3564 734347	TATYANA VOLKOVA	{"phone": "+70683791639"}
0005432604281	AA2A00	5673 558308	NATALYA YUDINA	{"phone": "+70772150515"}
0005432604282	9DE03A	3764 019039	NIKOLAY MATVEEV	{"email": "matveevn-081968@postgrespro.ru", "phone": "+70311110308"}
0005432604283	9DE03A	2869 974763	SVETLANA ZHUKOVA	{"email": "zhukova-s-101964@postgrespro.ru", "phone": "+70915945798"}
0005432604284	C20B93	7426 021571	ANZHELA FEDOROVA	{"email": "a-fedorova.1967@postgrespro.ru", "phone": "+70643480171"}
0005432604285	C20B93	4339 533762	MAKSIM VASILEV	{"email": "vasilevmaksim-02041968@postgrespro.ru", "phone": "+70242734448"}
0005432604286	C20B93	1004 128895	VLADIMIR NIKOLAEV	{"phone": "+70384137773"}
0005432604287	53935B	2990 450905	VALENTINA GRISHINA	{"email": "v.grishina_061969@postgrespro.ru", "phone": "+70478542399"}
0005432604288	EFEDF4	5531 630453	VALENTINA ZAKHAROVA	{"phone": "+70870230328"}
0005432604289	AD00A6	5045 670741	ANASTASIYA NAUMOVA	{"phone": "+70648736715"}
0005432604290	AD00A6	2924 153798	TATYANA SOROKINA	{"email": "sorokina_t1985@postgrespro.ru", "phone": "+70670999990"}
0005432604291	DB4B6D	1486 630361	YURIY VLASOV	{"phone": "+70427700180"}
0005432604292	49F789	0857 117965	NATALYA KUZNECOVA	{"email": "nkuznecova.091966@postgrespro.ru", "phone": "+70654613807"}
0005432604293	2FD507	6241 070931	VASILIY ZHURAVLEV	{"email": "v.zhuravlev_071976@postgrespro.ru", "phone": "+70431796299"}
0005432604294	2FD507	4592 425033	GALINA IVANOVA	{"phone": "+70332967613"}
0005432604295	80BD75	5753 973572	ANASTASIYA EFIMOVA	{"email": "anastasiya-efimova_1976@postgrespro.ru", "phone": "+70146004786"}
0005432604296	6C46E4	1818 501608	DANIIL IVANOV	{"email": "ivanov-d.041968@postgrespro.ru", "phone": "+70106967360"}
0005432604297	F77C0D	5266 025260	DARYA POPOVA	{"email": "darya.popova-28111960@postgrespro.ru", "phone": "+70443976839"}
0005432604298	3CE7FB	9399 288266	OKSANA SOLOVEVA	{"email": "soloveva.o27081976@postgrespro.ru", "phone": "+70103471056"}
0005432604299	3D5FEA	6077 080755	IGOR KISELEV	{"email": "kiselev.i.07121956@postgrespro.ru", "phone": "+70557768687"}
0005432604300	4D9D97	0888 465037	VERA SEMENOVA	{"phone": "+70612402139"}
0005432604301	A625D4	4371 595462	IRINA POTAPOVA	{"phone": "+70382916746"}
0005432604302	294683	9437 323264	SAVELIY FOMIN	{"phone": "+70405415395"}
0005432604303	294683	3206 437688	DMITRIY VASILEV	{"email": "d-vasilev.09091960@postgrespro.ru", "phone": "+70926960368"}
0005432604304	294683	2528 230992	TIMUR VOROBEV	{"phone": "+70049806308"}
0005432604305	D11E95	3841 767659	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko-1966@postgrespro.ru", "phone": "+70087131833"}
0005432604306	99340F	6439 086631	ROMAN FEDOROV	{"phone": "+70243942128"}
0005432604307	99340F	5411 519166	ALINA KISELEVA	{"email": "alina-kiseleva101977@postgrespro.ru", "phone": "+70819279362"}
0005432604308	99340F	9062 179391	ELENA VASILEVA	{"phone": "+70181537393"}
0005432604309	662C1D	6424 611097	VLADISLAV SOROKIN	{"email": "v.sorokin_09071970@postgrespro.ru", "phone": "+70180521740"}
0005432604310	AE3E71	2486 486587	ELENA KOROLEVA	{"phone": "+70619851711"}
0005432604311	77577D	0918 280537	VALENTINA POPOVA	{"email": "valentinapopova_1974@postgrespro.ru", "phone": "+70774758685"}
0005432604312	A671F9	8876 024305	GALINA GUSEVA	{"email": "guseva.g-1968@postgrespro.ru", "phone": "+70711842446"}
0005432604313	DD87E8	1207 532005	DMITRIY STEPANOV	{"email": "stepanov.dmitriy_051976@postgrespro.ru", "phone": "+70443924709"}
0005432604314	133086	5600 728308	ROZALIYA KONOVALOVA	{"email": "r-konovalova_081979@postgrespro.ru", "phone": "+70847280516"}
0005432604315	689FDC	0367 148941	REGINA MIKHAYLOVA	{"phone": "+70024799494"}
0005432604316	689FDC	8436 091874	ALEKSEY ZAKHAROV	{"email": "zakharov-aleksey_11101973@postgrespro.ru", "phone": "+70711427091"}
0005432604317	5787BA	2766 747969	ELIZAVETA SOLOVEVA	{"email": "e-soloveva_14011975@postgrespro.ru", "phone": "+70105557543"}
0005432604318	87DD48	2928 477617	DMITRIY MEDVEDEV	{"phone": "+70633521925"}
0005432604319	21C47B	0904 493541	TATYANA KONOVALOVA	{"email": "t-konovalova091977@postgrespro.ru", "phone": "+70416796641"}
0005432604320	21C47B	5853 424539	VALENTINA KOVALEVA	{"phone": "+70623853029"}
0005432604321	8C346B	2923 958918	SERGEY KRASNOV	{"email": "skrasnov.1979@postgrespro.ru", "phone": "+70589137267"}
0005432604322	27C257	0551 943659	ALEKSANDR MELNIKOV	{"phone": "+70513336061"}
0005432604323	3923E9	1236 460136	SERGEY ALEKSEEV	{"email": "alekseev_sergey.091970@postgrespro.ru", "phone": "+70541234109"}
0005432604324	3923E9	8297 690576	NADEZHDA MIRONOVA	{"phone": "+70796673109"}
0005432604325	FE5ABB	1554 032976	MAKSIM MEDVEDEV	{"email": "medvedevm1972@postgrespro.ru", "phone": "+70301452567"}
0005432604326	FE5ABB	5467 029156	NADEZHDA ANISIMOVA	{"email": "anisimova.n.21021967@postgrespro.ru", "phone": "+70544707672"}
0005432604327	A1D6A3	1161 622528	IGOR BARANOV	{"email": "baranov.i22111965@postgrespro.ru", "phone": "+70654756793"}
0005432604328	A1D6A3	4741 754397	ELENA TROFIMOVA	{"email": "trofimovae_031971@postgrespro.ru", "phone": "+70204585095"}
0005432604329	9D0E7A	6605 776274	RODION FOMIN	{"phone": "+70666765041"}
0005432604330	43730F	7703 327240	NATALYA MOISEEVA	{"email": "moiseeva-natalya_1975@postgrespro.ru", "phone": "+70227030883"}
0005432604331	43730F	5510 632831	ELENA ROMANOVA	{"phone": "+70054191753"}
0005432604332	50916F	5410 421998	ANASTASIYA MALYSHEVA	{"email": "anastasiya-malysheva_02111976@postgrespro.ru", "phone": "+70412263777"}
0005432604333	50916F	9289 214651	VLADIMIR MARTYNOV	{"email": "martynov_v.23071966@postgrespro.ru", "phone": "+70520537970"}
0005432604334	E2C8CA	7341 167370	DANIIL KULIKOV	{"email": "kulikov-daniil.09061962@postgrespro.ru", "phone": "+70126457354"}
0005432604335	E2C8CA	7071 671824	VLADIMIR STEPANOV	{"phone": "+70742719409"}
0005432604336	ADCBFF	7046 651894	LYUDMILA SEMENOVA	{"email": "semenova.l21081979@postgrespro.ru", "phone": "+70755947439"}
0005432604337	E7FAC2	5981 990887	KRISTINA PAVLOVA	{"email": "pavlova_kristina-1973@postgrespro.ru", "phone": "+70338659677"}
0005432604338	404351	0146 368360	MARGARITA KOROLEVA	{"email": "koroleva-m_051975@postgrespro.ru", "phone": "+70668106372"}
0005432604339	DB94B6	5956 555613	EVGENIYA FROLOVA	{"phone": "+70955255880"}
0005432604340	2A84C4	3912 803599	EKATERINA VOLKOVA	{"email": "volkovae_15091974@postgrespro.ru", "phone": "+70727857799"}
0005432604341	BB3E62	8861 109724	VALENTIN MAKSIMOV	{"phone": "+70008159898"}
0005432604342	1884FA	9011 830855	ILDAR ANTONOV	{"email": "ildar-antonov_25071967@postgrespro.ru", "phone": "+70042606703"}
0005432604343	9F1598	6682 735020	VYACHESLAV BORISOV	{"email": "v-borisov-1971@postgrespro.ru", "phone": "+70915990788"}
0005432604344	9F1598	3473 565638	VALENTINA YAKOVLEVA	{"phone": "+70576297781"}
0005432604345	754263	7326 987481	EVGENIY FROLOV	{"email": "frolov_evgeniy_1981@postgrespro.ru", "phone": "+70172906409"}
0005432604346	05382F	1535 964243	NATALYA ROMANOVA	{"email": "romanova.natalya061978@postgrespro.ru", "phone": "+70640934150"}
0005432604347	F23EDF	4232 822937	IRINA KOVALEVA	{"phone": "+70098405003"}
0005432604348	2480D9	6734 805425	YULIYA MAKAROVA	{"email": "y_makarova061968@postgrespro.ru", "phone": "+70117566487"}
0005432604349	05FE09	4731 366106	RAMIS PAVLOV	{"email": "pavlovramis_041976@postgrespro.ru", "phone": "+70234802371"}
0005432604350	83DEA8	0088 587041	ELENA SCHERBAKOVA	{"phone": "+70910099120"}
0005432604351	E8B95C	9834 049906	VLADIMIR KUZNECOV	{"phone": "+70406951494"}
0005432604352	145571	4388 154877	ALEKSANDRA MIKHAYLOVA	{"email": "aleksandra_mikhaylova041977@postgrespro.ru", "phone": "+70765795125"}
0005432604353	145571	1223 255066	SERGEY SEMENOV	{"phone": "+70482731610"}
0005432604354	145571	1070 641201	YURIY VASILEV	{"phone": "+70996549038"}
0005432604355	145571	5947 992110	ANATOLIY ILIN	{"email": "ilin.a19031975@postgrespro.ru", "phone": "+70330050822"}
0005432604356	FFF5B5	7808 760146	NAILYA FROLOVA	{"email": "n-frolova-30051962@postgrespro.ru", "phone": "+70057977294"}
0005432604357	FFF5B5	8286 394852	ELENA EGOROVA	{"phone": "+70802407870"}
0005432604358	5DC1D3	3829 421965	ANATOLIY VOLKOV	{"email": "volkov.a-1970@postgrespro.ru", "phone": "+70023821411"}
0005432604359	5DC1D3	6630 851995	ANATOLIY GAVRILOV	{"email": "gavrilov.anatoliy.24091986@postgrespro.ru", "phone": "+70377356084"}
0005432604360	DF7A50	7766 316794	RAILYA GUSEVA	{"phone": "+70930325170"}
0005432604361	AE4EE5	8461 147879	IVAN ILIN	{"email": "i-ilin_1969@postgrespro.ru", "phone": "+70169132128"}
0005432604362	FFC68C	5567 295739	LYUDMILA MELNIKOVA	{"phone": "+70076852381"}
0005432604363	359AA0	9783 104326	ALEKSEY NOVIKOV	{"phone": "+70179308355"}
0005432604364	D4453D	9410 638597	ALENA KAZAKOVA	{"phone": "+70582460933"}
0005432604365	15B72D	7240 275941	VLADIMIR YAKOVLEV	{"email": "vladimir.yakovlev1971@postgrespro.ru", "phone": "+70583607811"}
0005432604366	15B72D	9374 958748	MARINA KOZLOVA	{"email": "marina.kozlova.02081968@postgrespro.ru", "phone": "+70545999464"}
0005432604367	2EE7EB	5967 722446	RINAT VOROBEV	{"email": "rinatvorobev_1973@postgrespro.ru", "phone": "+70996439521"}
0005432604368	E63DFA	8722 034658	NADEZHDA POPOVA	{"email": "popova.n.24121973@postgrespro.ru", "phone": "+70843766326"}
0005432604369	C32EA9	2826 636817	ANASTASIYA MELNIKOVA	{"phone": "+70710109234"}
0005432604370	C32EA9	2283 928029	VLADIMIR EGOROV	{"email": "egorov_vladimir22121977@postgrespro.ru", "phone": "+70010346514"}
0005432604371	22D59B	5037 685994	VLADIMIR BARANOV	{"email": "vladimirbaranov1989@postgrespro.ru", "phone": "+70128660548"}
0005432604372	CE50CA	1240 079587	ANASTASIYA BELYAEVA	{"email": "a_belyaeva19011975@postgrespro.ru", "phone": "+70854339505"}
0005432604373	983062	1105 942502	OLGA GORBUNOVA	{"phone": "+70353545523"}
0005432604374	983062	9197 789770	DMITRIY KARPOV	{"email": "d_karpov.1969@postgrespro.ru", "phone": "+70356953778"}
0005432604375	465A3F	3022 500164	LYUBOV KUZNECOVA	{"phone": "+70147719755"}
0005432604376	465A3F	2789 036651	ANATOLIY SMIRNOV	{"email": "smirnov_a_19101975@postgrespro.ru", "phone": "+70963434340"}
0005432604377	64DBC7	3510 760416	ELIZAVETA TROFIMOVA	{"phone": "+70814681727"}
0005432604378	64DBC7	7145 156358	GYUZEL MATVEEVA	{"email": "matveeva.g.051971@postgrespro.ru", "phone": "+70489671193"}
0005432604379	A1CB67	6970 845394	SERGEY ZAYCEV	{"email": "szaycev-1967@postgrespro.ru", "phone": "+70841913308"}
0005432604380	A1CB67	9120 967983	VERA PAVLOVA	{"phone": "+70532272093"}
0005432604381	A1CB67	4039 535119	ELENA ZAYCEVA	{"phone": "+70018025268"}
0005432604382	001A23	1763 005538	MARIYA KULIKOVA	{"phone": "+70683737463"}
0005432604383	001A23	9462 048671	ILYA IVANOV	{"phone": "+70841115590"}
0005432604384	43FD9D	7225 143229	ALEKSANDR FOMIN	{"email": "a_fomin-1987@postgrespro.ru", "phone": "+70493089632"}
0005432604385	43FD9D	6331 021734	NIKOLAY DENISOV	{"email": "n-denisov-1968@postgrespro.ru", "phone": "+70042774473"}
0005432604386	43FD9D	8639 410147	ANNA KUZMINA	{"email": "akuzmina.091961@postgrespro.ru", "phone": "+70502618278"}
0005432604387	07341A	0733 956093	ALEKSEY EGOROV	{"email": "egorov.aleksey.25121975@postgrespro.ru", "phone": "+70327384552"}
0005432604388	07341A	5288 032829	ANTONINA ZHUKOVA	{"email": "antonina-zhukova1967@postgrespro.ru", "phone": "+70167228899"}
0005432604389	84DD9C	8448 355816	VALENTINA ZOTOVA	{"email": "valentinazotova09121969@postgrespro.ru", "phone": "+70280652084"}
0005432604390	9E5466	2932 455800	ANATOLIY SERGEEV	{"phone": "+70925654419"}
0005432604391	CDDEEE	9266 960543	EKATERINA YAKOVLEVA	{"email": "yakovleva-ekaterina.021969@postgrespro.ru", "phone": "+70473310093"}
0005432604392	08A07A	2268 739771	DANILA ZAKHAROV	{"phone": "+70167471408"}
0005432604393	89DB0D	9374 846482	YULIYA FILIPPOVA	{"phone": "+70335185705"}
0005432604394	89DB0D	9499 521774	SVETLANA KOZLOVA	{"email": "kozlova-s-011969@postgrespro.ru", "phone": "+70631669545"}
0005432604395	505236	3219 765887	VLADIMIR TARASOV	{"phone": "+70912802031"}
0005432604396	02500F	0293 216680	ELENA SAVELEVA	{"phone": "+70424122075"}
0005432604397	02500F	2239 446388	ELENA ABRAMOVA	{"email": "eabramova_27071969@postgrespro.ru", "phone": "+70985047735"}
0005432604398	8C6E8F	8378 790381	ALEKSANDRA KAZAKOVA	{"email": "aleksandra-kazakova.23101972@postgrespro.ru", "phone": "+70376043134"}
0005432604399	8C6E8F	8592 722981	MARINA KAZAKOVA	{"phone": "+70845651759"}
0005432604400	83BDBD	4685 550014	OLGA MEDVEDEVA	{"email": "medvedevaolga_29091976@postgrespro.ru", "phone": "+70105679816"}
0005432604401	561981	2456 835924	ALEKSANDR POPOV	{"email": "popov_a-23101968@postgrespro.ru", "phone": "+70423198101"}
0005432604402	3496D9	4272 832172	ANNA VASILEVA	{"phone": "+70009971803"}
0005432604403	5A51D2	2235 379505	GEORGIY ILIN	{"email": "georgiy_ilin.20091973@postgrespro.ru", "phone": "+70386351145"}
0005432604404	C54435	4829 360017	TATYANA KUZMINA	{"phone": "+70922396014"}
0005432604405	C54435	4608 251569	VLADIMIR SAVELEV	{"email": "vladimir.savelev-02071967@postgrespro.ru", "phone": "+70641429603"}
0005432604406	B4C41A	6988 787090	ANATOLIY SIDOROV	{"email": "a.sidorov-06021969@postgrespro.ru", "phone": "+70454964295"}
0005432604407	553FE4	1820 093331	DARYA NIKIFOROVA	{"email": "nikiforovadarya12051964@postgrespro.ru", "phone": "+70639060288"}
0005432604408	553FE4	6094 249804	GALINA POTAPOVA	{"email": "g-potapova051984@postgrespro.ru", "phone": "+70550713534"}
0005432604409	754296	7992 636198	SERGEY MOROZOV	{"phone": "+70470224866"}
0005432604410	7F2015	8476 501652	ANDREY GRIGOREV	{"email": "grigorev-andrey.1965@postgrespro.ru", "phone": "+70386139568"}
0005432604411	F264F2	2643 763424	OLEG YAKOVLEV	{"email": "o.yakovlev-1966@postgrespro.ru", "phone": "+70059128302"}
0005432604412	4C1155	2714 600940	NIKOLAY SEMENOV	{"phone": "+70435316613"}
0005432604413	4C1155	7112 557914	MARIYA BELYAEVA	{"phone": "+70576151861"}
0005432604414	E978E3	3946 186111	ALEKSANDRA ROMANOVA	{"phone": "+70942873345"}
0005432604415	97DBFC	0451 408026	LYUDMILA MAKSIMOVA	{"phone": "+70958170429"}
0005432604416	3D600C	9957 383245	ANASTASIYA PAVLOVA	{"email": "anastasiya_pavlova091962@postgrespro.ru", "phone": "+70763588859"}
0005432604417	633883	7977 342192	VIKTOR GAVRILOV	{"phone": "+70899416222"}
0005432604418	633883	5976 153022	NATALYA ILINA	{"email": "ilina-natalya_071970@postgrespro.ru", "phone": "+70946025848"}
0005432604419	801B0B	4072 659527	VERONIKA POPOVA	{"email": "veronikapopova.1963@postgrespro.ru", "phone": "+70768531411"}
0005432604420	801B0B	4887 332918	ANNA MAKAROVA	{"email": "a.makarova011988@postgrespro.ru", "phone": "+70734598285"}
0005432604421	D75E45	3838 432863	ELENA BELOVA	{"phone": "+70026737632"}
0005432604422	CD50A8	6211 077452	MATVEY NOVIKOV	{"email": "m.novikov1981@postgrespro.ru", "phone": "+70792732006"}
0005432604423	6FC8F8	8022 276823	ANATOLIY KAZAKOV	{"phone": "+70182340625"}
0005432604424	CD1325	8275 035832	ALEKSEY ANDREEV	{"email": "andreeva_03111975@postgrespro.ru", "phone": "+70144697181"}
0005432604425	CD1325	9921 798909	SERGEY SOROKIN	{"email": "sergey-sorokin-101966@postgrespro.ru", "phone": "+70867086937"}
0005432604426	6933D3	6644 123174	PAVEL SAVELEV	{"email": "savelev-pavel.1970@postgrespro.ru", "phone": "+70294339341"}
0005432604427	F5E579	1553 496597	ELENA ILINA	{"email": "eilina021975@postgrespro.ru", "phone": "+70507781721"}
0005432604428	F5E579	7992 321390	YULIYA KOROLEVA	{"email": "koroleva_y1977@postgrespro.ru", "phone": "+70656720146"}
0005432604429	80EA33	4589 725889	NATALYA NIKITINA	{"email": "n.nikitina041983@postgrespro.ru", "phone": "+70573007630"}
0005432604430	64BE88	0955 580342	MIKHAIL ZAKHAROV	{"phone": "+70062538151"}
0005432604431	4B7610	7980 439163	NADEZHDA KARPOVA	{"phone": "+70131060234"}
0005432604432	4B7610	4939 605531	VIKTOR MAKAROV	{"email": "viktormakarov_01111981@postgrespro.ru", "phone": "+70190957800"}
0005432604433	DECEC6	0618 995687	SVETLANA KUZNECOVA	{"phone": "+70653676639"}
0005432604434	DECEC6	8097 064981	LEONID ROMANOV	{"phone": "+70466115019"}
0005432604435	DECEC6	2579 760380	KSENIYA VASILEVA	{"phone": "+70977536912"}
0005432604436	323AA9	8625 239703	ANASTASIYA VASILEVA	{"email": "vasileva-anastasiya_081971@postgrespro.ru", "phone": "+70444683449"}
0005432604437	24CC1C	7712 993119	ELENA KOZLOVA	{"phone": "+70237935589"}
0005432604438	82BE69	9181 240389	ELENA TARASOVA	{"phone": "+70379828181"}
0005432604439	82BE69	6695 410459	KONSTANTIN RODIONOV	{"phone": "+70809896089"}
0005432604440	437086	7992 592164	OLESYA EFREMOVA	{"phone": "+70823512058"}
0005432604441	6D662B	0102 837698	FLYURA ERMAKOVA	{"phone": "+70913844972"}
0005432604442	E7831E	3581 496955	VALENTIN MIRONOV	{"email": "mironov_v-111967@postgrespro.ru", "phone": "+70829172236"}
0005432604443	1D6EBC	3663 761258	VIKTORIYA SOLOVEVA	{"email": "soloveva_viktoriya.031967@postgrespro.ru", "phone": "+70350613722"}
0005432604444	1D6EBC	8704 469345	SERGEY KUZNECOV	{"phone": "+70116370268"}
0005432604445	1EDEF3	7537 347174	DMITRIY RODIONOV	{"phone": "+70330151439"}
0005432604446	16CDA3	1604 661148	LYUBOV SMIRNOVA	{"email": "lyubovsmirnova101966@postgrespro.ru", "phone": "+70148163299"}
0005432604447	8F31DF	4968 645379	DARYA GRISHINA	{"email": "d.grishina-111972@postgrespro.ru", "phone": "+70633616644"}
0005432604448	8F31DF	7136 763113	MAKSIM ANDREEV	{"phone": "+70281817420"}
0005432604449	A2760E	5131 035020	ALEKSANDRA KOROLEVA	{"email": "aleksandrakoroleva_081963@postgrespro.ru", "phone": "+70568073791"}
0005432604450	1FCC50	7961 402492	SERGEY MIKHAYLOV	{"email": "sergey.mikhaylov.30061972@postgrespro.ru", "phone": "+70435844054"}
0005432604451	1FCC50	0172 046636	ALEKSANDR IVANOV	{"email": "ivanova_081980@postgrespro.ru", "phone": "+70788090629"}
0005432604452	718BD9	9218 546555	DARYA FOMINA	{"phone": "+70756806082"}
0005432604453	5BE8D5	7725 750233	MAKSIM MAKSIMOV	{"email": "m_maksimov.041973@postgrespro.ru", "phone": "+70005409293"}
0005432604454	5BE8D5	6537 200210	IRINA KUDRYASHOVA	{"email": "i-kudryashova.1971@postgrespro.ru", "phone": "+70031961058"}
0005432604455	9F1F7B	2351 750237	ZAKHAR KUZMIN	{"email": "zakhar-kuzmin1976@postgrespro.ru", "phone": "+70970334833"}
0005432604456	0DA7B1	0927 235331	ELIZAVETA PETROVA	{"phone": "+70582116579"}
0005432604457	679CA4	4806 538028	IRINA LUKYANOVA	{"phone": "+70858756069"}
0005432604458	23C0AF	2977 060538	SVETLANA NESTEROVA	{"email": "nesterova.svetlana-1976@postgrespro.ru", "phone": "+70770367562"}
0005432604459	8A17EF	7254 687298	VALENTINA MASLOVA	{"phone": "+70540893642"}
0005432604460	359340	7528 268740	EKATERINA FOMINA	{"phone": "+70004440272"}
0005432604461	84CF42	5503 712422	DMITRIY GRIGOREV	{"email": "dmitriy-grigorev.091981@postgrespro.ru", "phone": "+70196947002"}
0005432604462	84CF42	5146 074332	DMITRIY SEMENOV	{"phone": "+70800486552"}
0005432604463	9493D6	8313 784717	IRINA DANILOVA	{"email": "i_danilova.081986@postgrespro.ru", "phone": "+70544442001"}
0005432604464	51A853	7757 097142	DMITRIY KAZAKOV	{"email": "kazakovdmitriy_091958@postgrespro.ru", "phone": "+70297168934"}
0005432604465	98E75B	6258 149215	GULSINA NESTEROVA	{"email": "nesterova.g-14031966@postgrespro.ru", "phone": "+70315514452"}
0005432604466	98E75B	0651 455561	ALEKSANDRA SAVELEVA	{"email": "a.saveleva_041982@postgrespro.ru", "phone": "+70675565183"}
0005432604467	0AF848	8952 353626	DMITRIY TIKHONOV	{"email": "d.tikhonov13111969@postgrespro.ru", "phone": "+70729465686"}
0005432604468	3C9773	0046 368797	IGOR NAZAROV	{"email": "nazarov_igor-051967@postgrespro.ru", "phone": "+70309912561"}
0005432604469	3C9773	3234 093043	RAFAEL DAVYDOV	{"phone": "+70197588360"}
0005432604470	13D015	4129 908121	ILYA GRIGOREV	{"phone": "+70951786908"}
0005432604471	253103	3360 368054	OLGA ZAYCEVA	{"email": "zaycevao111974@postgrespro.ru", "phone": "+70925240959"}
0005432604472	6FF0B3	3178 483187	ROMAN IVANOV	{"email": "ivanov-r-10031981@postgrespro.ru", "phone": "+70756066067"}
0005432604473	07540B	2087 472412	ALEKSANDR KUZMIN	{"phone": "+70138752947"}
0005432604474	223981	4858 917138	TATYANA ORLOVA	{"phone": "+70926235771"}
0005432604475	223981	7375 642360	ALEKSANDR KOZLOV	{"phone": "+70298649619"}
0005432604476	0BA0D1	8070 396443	OKSANA ABRAMOVA	{"email": "oksana-abramova.25121969@postgrespro.ru", "phone": "+70154498843"}
0005432604477	0BA0D1	2270 338282	GALINA IVANOVA	{"email": "g-ivanova-1986@postgrespro.ru", "phone": "+70477087258"}
0005432604478	C22524	6210 389253	SERGEY AFANASEV	{"phone": "+70996186852"}
0005432604479	E50CBC	9680 964862	ANDREY KAZAKOV	{"phone": "+70976844018"}
0005432604480	717982	9430 414132	TAMARA BARANOVA	{"email": "baranova_t021973@postgrespro.ru", "phone": "+70137379219"}
0005432604481	717982	3881 965913	NADEZHDA KOLESNIKOVA	{"email": "nkolesnikova30041967@postgrespro.ru", "phone": "+70065627997"}
0005432604482	670A83	3976 237297	EKATERINA SERGEEVA	{"email": "sergeeva-e.1971@postgrespro.ru", "phone": "+70296290431"}
0005432604483	AD13C6	9929 522103	NIKITA FEDOTOV	{"phone": "+70375995135"}
0005432604484	AD13C6	8455 091949	OLGA KOROLEVA	{"phone": "+70439305832"}
0005432604485	98E817	9513 210247	ANNA KAZAKOVA	{"phone": "+70944521264"}
0005432604486	B3E200	0657 068272	LILIYA DMITRIEVA	{"email": "dmitrievaliliya_051970@postgrespro.ru", "phone": "+70074926262"}
0005432604487	B3E200	4663 452447	ANDREY IVANOV	{"phone": "+70990432012"}
0005432604488	039EC3	8607 150799	OLGA SOKOLOVA	{"phone": "+70101480765"}
0005432604489	5A3455	2942 147547	ANATOLIY MAKSIMOV	{"email": "maksimov-a.1969@postgrespro.ru", "phone": "+70777978057"}
0005432604490	679358	7333 056521	MARIYA FOMINA	{"phone": "+70044634134"}
0005432604491	679358	5359 478172	RAISA MATVEEVA	{"phone": "+70715270933"}
0005432604492	1C2B69	1487 711872	TATYANA SCHERBAKOVA	{"phone": "+70271030904"}
0005432604493	1C2B69	4444 453398	DARYA ZOTOVA	{"phone": "+70295565505"}
0005432604494	A39B8D	8090 254121	RAISA BELYAEVA	{"email": "r_belyaeva1975@postgrespro.ru", "phone": "+70124537894"}
0005432604495	EEE0B8	1449 167642	ARKADIY PETROV	{"email": "a-petrov1975@postgrespro.ru", "phone": "+70062723333"}
0005432604496	86922C	0805 328865	DIANA NOVIKOVA	{"phone": "+70512119640"}
0005432604497	149687	0809 321774	MARAT IVANOV	{"phone": "+70639044552"}
0005432604498	9D7352	5215 420762	VLADIMIR PAVLOV	{"email": "pavlov-v071972@postgrespro.ru", "phone": "+70167981031"}
0005432604499	9D7352	6568 789556	OLEG MIKHAYLOV	{"email": "mikhaylovo_1976@postgrespro.ru", "phone": "+70803160745"}
0005432604500	D3E2DC	2875 290828	NIKITA SOKOLOV	{"phone": "+70763691211"}
0005432604501	D3E2DC	4715 705871	EVGENIY PAVLOV	{"email": "evgeniy-pavlov.1971@postgrespro.ru", "phone": "+70004087369"}
0005432604502	13BF83	1407 983127	ILDUS KUZNECOV	{"phone": "+70499630021"}
0005432604503	C02B7E	6724 078092	VERA LUKYANOVA	{"email": "veralukyanova-031976@postgrespro.ru", "phone": "+70269387594"}
0005432604504	C02B7E	6401 130691	DMITRIY FROLOV	{"phone": "+70193985932"}
0005432604505	BED955	0809 285701	OLEG KOZLOV	{"email": "kozlov.o.05021972@postgrespro.ru", "phone": "+70143585648"}
0005432604506	8B202F	2426 682481	SERGEY KOZLOV	{"email": "s.kozlov.1973@postgrespro.ru", "phone": "+70771968747"}
0005432604507	8B202F	8108 141860	TATYANA ILINA	{"phone": "+70061256072"}
0005432604508	348772	7473 280254	ALINA KOVALEVA	{"phone": "+70403807259"}
0005432604509	FF84A2	6102 465210	NATALYA FROLOVA	{"email": "frolova_n_1964@postgrespro.ru", "phone": "+70256449437"}
0005432604510	57610F	2624 455259	EVGENIY RODIONOV	{"email": "rodionov.evgeniy_021966@postgrespro.ru", "phone": "+70089709212"}
0005432604511	57610F	0828 537722	ZINAIDA MAKSIMOVA	{"phone": "+70924202098"}
0005432604512	F008F8	0132 678028	ANNA RYABOVA	{"email": "ryabova.anna02061973@postgrespro.ru", "phone": "+70002448640"}
0005432604513	F008F8	5713 422364	MARINA PETROVA	{"phone": "+70220670335"}
0005432604514	898713	8506 097990	EVGENIY FILIPPOV	{"email": "filippov_evgeniy_1966@postgrespro.ru", "phone": "+70049942105"}
0005432604515	2DCE74	9695 898095	LYUBOV MOROZOVA	{"phone": "+70832734579"}
0005432604516	011485	3254 279880	VLADIMIR KOZLOV	{"phone": "+70946292732"}
0005432604517	F0385E	1051 107405	IGOR AFANASEV	{"email": "igor.afanasev1968@postgrespro.ru", "phone": "+70889932864"}
0005432604518	1F93EA	0905 050072	NATALYA KUZNECOVA	{"phone": "+70191948577"}
0005432604519	1344D6	8920 832434	ANATOLIY NAUMOV	{"email": "naumova.041960@postgrespro.ru", "phone": "+70836328480"}
0005432604520	3A98D8	8158 383338	TATYANA FROLOVA	{"phone": "+70331881072"}
0005432604521	950A38	0625 939264	ALEKSANDR BORISOV	{"email": "borisovaleksandr-1964@postgrespro.ru", "phone": "+70924161024"}
0005432604522	950A38	3833 462755	ALEKSEY FEDOROV	{"email": "fedorov.a28051963@postgrespro.ru", "phone": "+70329001726"}
0005432604523	D029B2	2704 406372	VALENTINA NESTEROVA	{"phone": "+70975967536"}
0005432604524	7108F5	3166 755004	OLEG KUZNECOV	{"email": "kuznecov_oleg-1964@postgrespro.ru", "phone": "+70292335418"}
0005432604525	9FF362	4058 781698	LIDIYA DAVYDOVA	{"email": "l.davydova061977@postgrespro.ru", "phone": "+70501376526"}
0005432604526	BB3613	0495 727505	ELENA NIKOLAEVA	{"phone": "+70411864163"}
0005432604527	518955	1112 947950	GENNADIY EGOROV	{"phone": "+70465122339"}
0005432604528	518955	5791 284326	EVGENIY STEPANOV	{"phone": "+70807137270"}
0005432604529	83BA6B	3264 482585	NIKOLAY MEDVEDEV	{"email": "medvedev-n1968@postgrespro.ru", "phone": "+70326011698"}
0005432604530	3CB8A1	0231 699196	OLGA VASILEVA	{"phone": "+70756433579"}
0005432604531	3CB8A1	8855 703499	DENIS KOZLOV	{"phone": "+70107274798"}
0005432604532	E88A76	5011 398468	MAKSIM SIDOROV	{"phone": "+70080733061"}
0005432604533	E88A76	7156 101266	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikovalyubov1978@postgrespro.ru", "phone": "+70071155437"}
0005432604534	5F4731	3836 175537	KONSTANTIN FEDOTOV	{"email": "konstantin_fedotov121961@postgrespro.ru", "phone": "+70651335033"}
0005432604535	5BE7A3	4276 921869	ALEKSANDR ILIN	{"phone": "+70106291563"}
0005432604536	5E7618	3246 911922	LARISA FOMINA	{"email": "l_fomina-1965@postgrespro.ru", "phone": "+70289921700"}
0005432604537	D43E2C	4768 048118	YANA KARPOVA	{"phone": "+70059414281"}
0005432604538	BE90D4	3146 387662	LARISA EFIMOVA	{"email": "l_efimova071980@postgrespro.ru", "phone": "+70024348141"}
0005432604539	85DD73	2413 327657	ALBINA RYABOVA	{"email": "ryabova-a-101985@postgrespro.ru", "phone": "+70905556290"}
0005432604540	85DD73	4157 979275	ALEKSANDR IVANOV	{"email": "ivanov_a_1970@postgrespro.ru", "phone": "+70669613211"}
0005432604541	B0047D	1696 229295	VLADIMIR FEDOROV	{"email": "fedorov.vladimir03101981@postgrespro.ru", "phone": "+70986678410"}
0005432604542	3E7ABA	6238 285433	LILIYA VASILEVA	{"phone": "+70671439586"}
0005432604543	8F9537	4364 178589	VLADIMIR GERASIMOV	{"email": "gerasimov_v03031974@postgrespro.ru", "phone": "+70189523043"}
0005432604544	8F9537	9260 849017	ELENA VOLKOVA	{"phone": "+70225532491"}
0005432604545	D3379C	7525 701603	EVGENIYA SEMENOVA	{"email": "semenova_e-1988@postgrespro.ru", "phone": "+70263756323"}
0005432604546	D3379C	3550 698891	DENIS KUZMIN	{"phone": "+70350866664"}
0005432604547	D3379C	9330 590870	MAKSIM ANDREEV	{"phone": "+70794140676"}
0005432604548	670952	6050 837046	OLGA VASILEVA	{"email": "olgavasileva09061964@postgrespro.ru", "phone": "+70219753924"}
0005432604549	670952	6625 381158	VLADIMIR NIKITIN	{"phone": "+70602791522"}
0005432604550	55455F	1060 109333	MARINA ANDREEVA	{"phone": "+70726447634"}
0005432604551	796FD1	7981 651991	MARIYA KOLESNIKOVA	{"phone": "+70949972417"}
0005432604552	AFEF13	4902 828438	YURIY KISELEV	{"phone": "+70160753983"}
0005432604553	AFEF13	2123 497149	VLADISLAV SERGEEV	{"phone": "+70399035101"}
0005432604554	762B10	7962 163523	EKATERINA LUKYANOVA	{"email": "lukyanovaekaterina_111969@postgrespro.ru", "phone": "+70053028893"}
0005432604555	762B10	2475 523452	DANILA KARPOV	{"phone": "+70957138516"}
0005432604556	CAB5F2	0088 803124	VERONIKA TARASOVA	{"email": "tarasovaveronika.021965@postgrespro.ru", "phone": "+70651410298"}
0005432604557	D88510	6658 321553	TATYANA ZAYCEVA	{"email": "tatyana_zayceva1981@postgrespro.ru", "phone": "+70247141044"}
0005432604558	B24B86	3068 397229	ANATOLIY ISAEV	{"email": "isaev.a-101979@postgrespro.ru", "phone": "+70380438851"}
0005432604559	DCA270	6684 304763	MARIYA KUZNECOVA	{"email": "m.kuznecova-13041965@postgrespro.ru", "phone": "+70638422751"}
0005432604560	99B313	8899 728569	MARINA ZAKHAROVA	{"phone": "+70427256771"}
0005432604561	99B313	0710 997379	ROMAN ZHUKOV	{"email": "zhukov.roman_19051973@postgrespro.ru", "phone": "+70934748307"}
0005432604562	D243F8	5977 871041	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov-1969@postgrespro.ru", "phone": "+70020505564"}
0005432604563	D243F8	2145 224327	EVGENIY KISELEV	{"phone": "+70156139080"}
0005432604564	BE7332	0163 929008	NATALYA MOISEEVA	{"email": "nmoiseeva_1965@postgrespro.ru", "phone": "+70364173578"}
0005432604565	48AF4B	9225 765298	ALEKSANDR STEPANOV	{"phone": "+70083721623"}
0005432604566	48AF4B	9969 489618	ZINAIDA MOISEEVA	{"email": "moiseevaz_14091978@postgrespro.ru", "phone": "+70285011529"}
0005432604567	EB2720	5594 499366	ANDREY FEDOROV	{"email": "a-fedorov081971@postgrespro.ru", "phone": "+70851602581"}
0005432604568	EB2720	8469 911193	EGOR KAZAKOV	{"email": "kazakov-egor.1974@postgrespro.ru", "phone": "+70041178530"}
0005432604569	9F8DBB	1471 434384	IRINA MIKHAYLOVA	{"phone": "+70192304388"}
0005432604570	12F5C2	4516 928101	KLAVDIYA KONOVALOVA	{"email": "kkonovalova1968@postgrespro.ru", "phone": "+70380465395"}
0005432604571	C2B304	9369 076228	ALEKSANDR SHEVCHENKO	{"phone": "+70040231415"}
0005432604572	7FFBCD	1446 095293	ALEKSEY MOROZOV	{"phone": "+70083008601"}
0005432604573	8D092A	3807 930888	TATYANA TIKHONOVA	{"email": "tikhonova_t_101968@postgrespro.ru", "phone": "+70647802485"}
0005432604574	EE8CFA	2446 366096	EVGENIY IVANOV	{"phone": "+70441109700"}
0005432604575	EE8CFA	5809 435279	ANDREY NIKITIN	{"email": "a.nikitin-011981@postgrespro.ru", "phone": "+70020532322"}
0005432604576	EE8CFA	3578 817043	DANIIL ZAKHAROV	{"phone": "+70838495637"}
0005432604577	8D5003	0971 657891	IGOR KUDRYASHOV	{"phone": "+70104552939"}
0005432604578	8D5003	4463 017835	NATALYA MIKHAYLOVA	{"email": "mikhaylovan_23071978@postgrespro.ru", "phone": "+70934121472"}
0005432604579	5411CE	6585 679170	VENIAMIN TIKHONOV	{"email": "veniamin-tikhonov.121972@postgrespro.ru", "phone": "+70676901688"}
0005432604580	BBFFD9	4226 866249	VASILIY NAUMOV	{"email": "naumov.vasiliy1967@postgrespro.ru", "phone": "+70412009905"}
0005432604581	0D1714	5703 958772	ANDREY PETROV	{"phone": "+70302492232"}
0005432604582	01AD90	4450 958906	SERGEY KISELEV	{"phone": "+70189717354"}
0005432604583	C389B3	7999 829144	ELENA RODIONOVA	{"email": "e-rodionova1970@postgrespro.ru", "phone": "+70650910376"}
0005432604584	1DEF13	1600 255393	VIKTOR BARANOV	{"email": "v-baranov091981@postgrespro.ru", "phone": "+70558642161"}
0005432604585	1DEF13	2467 826141	OLEG KOROLEV	{"email": "oleg_korolev051980@postgrespro.ru", "phone": "+70029928552"}
0005432604586	E70289	7680 905621	DMITRIY POPOV	{"phone": "+70741638434"}
0005432604587	E70289	3821 045867	VADIM RODIONOV	{"phone": "+70260249767"}
0005432604588	3C0880	5994 794835	NATALYA PETROVA	{"email": "n-petrova051974@postgrespro.ru", "phone": "+70172276737"}
0005432604589	3C0880	4061 207921	SERGEY TARASOV	{"email": "sergey_tarasov.1967@postgrespro.ru", "phone": "+70821093953"}
0005432604590	1A59CA	8806 596217	ALEKSEY ORLOV	{"email": "orlov-a_1977@postgrespro.ru", "phone": "+70478539987"}
0005432604591	596CE5	7784 463409	OLEG SMIRNOV	{"phone": "+70051599256"}
0005432604592	5610EC	6548 402202	NATALIYA KOROLEVA	{"email": "koroleva_nataliya17091986@postgrespro.ru", "phone": "+70642864674"}
0005432604593	5610EC	2479 788043	MARIYA MARTYNOVA	{"phone": "+70622459754"}
0005432604594	159BDC	4169 702223	ELENA TIKHONOVA	{"phone": "+70953158166"}
0005432604595	64EAFA	9950 269953	VLADIMIR VOROBEV	{"email": "vorobev_v.101981@postgrespro.ru", "phone": "+70754701314"}
0005432604596	64EAFA	9197 660608	MARINA SEMENOVA	{"email": "m-semenova.12041973@postgrespro.ru", "phone": "+70366057009"}
0005432604597	55BA25	2839 885664	ALEKSEY PAVLOV	{"email": "pavlovaleksey1972@postgrespro.ru", "phone": "+70894416594"}
0005432604598	55BA25	9373 916877	SERGEY ILIN	{"email": "ilin_s_04051974@postgrespro.ru", "phone": "+70081636639"}
0005432604599	85150F	1345 953904	ELINA NIKITINA	{"email": "e.nikitina.1974@postgrespro.ru", "phone": "+70780764990"}
0005432604600	30D717	4487 060654	NIKOLAY GORBUNOV	{"phone": "+70127382398"}
0005432604601	30D717	0052 295824	PAVEL KISELEV	{"phone": "+70220300401"}
0005432604602	C28001	8661 789109	NATALYA KALININA	{"email": "kalininanatalya-081973@postgrespro.ru", "phone": "+70652268756"}
0005432604603	C28001	5759 511887	ALEKSANDR GORBUNOV	{"email": "gorbunov.a.1981@postgrespro.ru", "phone": "+70295303700"}
0005432604604	CACD5C	2404 997920	NATALIYA ILINA	{"email": "ilinan_23091968@postgrespro.ru", "phone": "+70240269731"}
0005432604605	3F9B2D	5472 160679	ALEKSANDR TIMOFEEV	{"phone": "+70404889303"}
0005432604606	234FA2	5224 529924	LYUDMILA MEDVEDEVA	{"phone": "+70500103222"}
0005432604607	39C670	1404 978722	SVETLANA VOROBEVA	{"phone": "+70034069035"}
0005432604608	4E1737	2856 788600	ANASTASIYA NAZAROVA	{"email": "nazarova.anastasiya.091966@postgrespro.ru", "phone": "+70526307692"}
0005432604609	38B978	0921 496355	OLGA KUZNECOVA	{"email": "o-kuznecova.101967@postgrespro.ru", "phone": "+70512381225"}
0005432604610	F24EA2	2975 725697	NIKOLAY NAZAROV	{"phone": "+70656284878"}
0005432604611	A114A1	2560 496770	IRINA MOROZOVA	{"email": "morozovairina_28041977@postgrespro.ru", "phone": "+70256258263"}
0005432604612	2082FB	3888 235017	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev-1971@postgrespro.ru", "phone": "+70787841745"}
0005432604613	2D2757	5316 937955	ALEKSANDR POPOV	{"email": "popova-011977@postgrespro.ru", "phone": "+70681698040"}
0005432604614	3C0A5B	2084 622546	EMIL YAKOVLEV	{"email": "eyakovlev-091969@postgrespro.ru", "phone": "+70238019968"}
0005432604615	6BEB2A	3821 430820	ILYA KISELEV	{"email": "kiselevilya.031985@postgrespro.ru", "phone": "+70898801533"}
0005432604616	BED295	6570 743217	EVGENIY TIMOFEEV	{"phone": "+70707597767"}
0005432604617	BED295	7657 740868	VARVARA CHERNOVA	{"phone": "+70520518834"}
0005432604618	BED295	6512 680349	NINA BOGDANOVA	{"email": "nina-bogdanova.1960@postgrespro.ru", "phone": "+70069725194"}
0005432604619	F80935	2020 755724	VALENTINA MAKAROVA	{"phone": "+70520625492"}
0005432604620	F80935	1481 505897	ANNA ERMAKOVA	{"email": "ermakova.a021979@postgrespro.ru", "phone": "+70121813749"}
0005432604621	F80935	0927 533149	TATYANA KUZNECOVA	{"phone": "+70410732813"}
0005432604622	D1DAD2	3196 670518	BORIS SAVELEV	{"phone": "+70481266279"}
0005432604623	D1DAD2	8248 072560	ANATOLIY KUZNECOV	{"phone": "+70566422271"}
0005432604624	6C9D7D	0939 707488	OLGA POTAPOVA	{"email": "potapova_olga071976@postgrespro.ru", "phone": "+70647017877"}
0005432604625	9677D9	7073 622268	KONSTANTIN DMITRIEV	{"phone": "+70029663583"}
0005432604626	541C5E	2798 813243	NINA ALEKSANDROVA	{"phone": "+70702557603"}
0005432604627	BC74FC	6914 049342	YURIY ISAEV	{"phone": "+70427636462"}
0005432604628	29DD64	7204 337827	MARGARITA AKIMOVA	{"phone": "+70978149062"}
0005432604629	42E6B3	8537 296687	VLADISLAV SOLOVEV	{"phone": "+70174489187"}
0005432604630	F5500B	5902 085304	EKATERINA DENISOVA	{"email": "ekaterinadenisova_121965@postgrespro.ru", "phone": "+70081711104"}
0005432604631	40DDC7	1279 102326	VALERIY KOZLOV	{"phone": "+70182865585"}
0005432604632	40DDC7	6941 071539	VSEVOLOD ROMANOV	{"phone": "+70743352481"}
0005432604633	A98CE6	0483 034193	SERGEY GAVRILOV	{"email": "sgavrilov-1976@postgrespro.ru", "phone": "+70472860777"}
0005432604634	A98CE6	3147 821125	SERGEY MAKSIMOV	{"email": "sergeymaksimov_031968@postgrespro.ru", "phone": "+70247166233"}
0005432604635	A5D9CD	9599 620008	ALEKSANDR KUZNECOV	{"email": "akuznecov-101974@postgrespro.ru", "phone": "+70869899875"}
0005432604636	DA4193	6065 555579	MIKHAIL PETROV	{"phone": "+70246984056"}
0005432604637	DA4193	1214 360836	MARIYA STEPANOVA	{"phone": "+70782967172"}
0005432604638	35A40A	3804 495213	VLADISLAV BORISOV	{"phone": "+70678045984"}
0005432604639	E4850A	2400 967151	MAKSIM KUZMIN	{"phone": "+70449548390"}
0005432604640	096761	1480 160209	RUSLAN KOZLOV	{"phone": "+70922374477"}
0005432604641	096761	3689 331098	VIKTORIYA MELNIKOVA	{"email": "melnikova.viktoriya_16041964@postgrespro.ru", "phone": "+70958839871"}
0005432604642	BE3673	8299 740904	VALENTINA EGOROVA	{"email": "vegorova081961@postgrespro.ru", "phone": "+70111928009"}
0005432604643	82DB20	2328 144869	LILIYA SAVELEVA	{"email": "saveleva.liliya-1962@postgrespro.ru", "phone": "+70770733791"}
0005432604644	8C0778	8820 740578	NADEZHDA ROMANOVA	{"phone": "+70915399618"}
0005432604645	A3F217	2584 978030	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev.04051982@postgrespro.ru", "phone": "+70765680867"}
0005432604646	93FCD1	8288 012314	MAKSIM PETROV	{"email": "petrov_maksim111964@postgrespro.ru", "phone": "+70926941666"}
0005432604647	EF8581	8963 402454	ELENA AFANASEVA	{"phone": "+70146492419"}
0005432604648	BD870F	3018 987603	LYUBOV PAVLOVA	{"email": "pavlovalyubov_121972@postgrespro.ru", "phone": "+70275199199"}
0005432604649	152E43	5270 537260	MAKSIM KUZNECOV	{"email": "m.kuznecov-11011970@postgrespro.ru", "phone": "+70512923916"}
0005432604650	69953E	2098 245132	OLGA ROMANOVA	{"email": "romanova-o061971@postgrespro.ru", "phone": "+70941128328"}
0005432604651	9F0D98	8528 184655	ALEKSANDR KULIKOV	{"phone": "+70004502817"}
0005432604652	9F0D98	2934 085545	GALINA FILIPPOVA	{"phone": "+70397112918"}
0005432604653	88473D	0565 785114	VIKTOR TARASOV	{"email": "viktor_tarasov_1965@postgrespro.ru", "phone": "+70335243771"}
0005432604654	E67338	3408 508534	NADEZHDA ABRAMOVA	{"email": "abramovanadezhda1974@postgrespro.ru", "phone": "+70459736751"}
0005432604655	7BABEC	5324 729328	OLGA EFREMOVA	{"phone": "+70671905902"}
0005432604656	5F972D	3012 766391	NADEZHDA PAVLOVA	{"email": "nadezhda.pavlova.25051965@postgrespro.ru", "phone": "+70435898760"}
0005432604657	1C8727	4016 174188	EKATERINA FROLOVA	{"phone": "+70985130699"}
0005432604658	324F1F	4873 769216	OLEG FOMIN	{"email": "ofomin05111978@postgrespro.ru", "phone": "+70009317894"}
0005432604659	713697	5516 082178	VYACHESLAV MEDVEDEV	{"phone": "+70908068957"}
0005432604660	D1FE75	4720 412421	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_aleksandr.1977@postgrespro.ru", "phone": "+70225316880"}
0005432604661	99858F	2983 012727	TATYANA VASILEVA	{"email": "vasileva.t_19091967@postgrespro.ru", "phone": "+70087541377"}
0005432604662	99858F	1776 837112	GALINA MIKHAYLOVA	{"phone": "+70368354593"}
0005432604663	99858F	5180 100059	FARIDA NOVIKOVA	{"phone": "+70801960794"}
0005432604664	156031	1218 818348	ALEKSEY GERASIMOV	{"phone": "+70961418475"}
0005432604665	53D47D	5619 218109	NINA FROLOVA	{"phone": "+70976479356"}
0005432604666	AE3A7A	2753 733499	ANASTASIYA NESTEROVA	{"email": "nesterova_a.1958@postgrespro.ru", "phone": "+70579387524"}
0005432604667	EC96DB	2711 091255	LIDIYA PETROVA	{"email": "petroval101974@postgrespro.ru", "phone": "+70951354871"}
0005432604668	9ED13D	5596 944476	ALEKSEY ORLOV	{"phone": "+70290541897"}
0005432604669	857F12	1937 035594	ANDREY KUZNECOV	{"phone": "+70946979448"}
0005432604670	017E66	0219 161033	VLADIMIR DAVYDOV	{"email": "davydov-v1981@postgrespro.ru", "phone": "+70171081162"}
0005432604671	017E66	5593 656310	VIKTOR IVANOV	{"email": "v.ivanov_081969@postgrespro.ru", "phone": "+70735077541"}
0005432604672	2960AC	4506 784757	ALEKSANDR GORBUNOV	{"phone": "+70899834252"}
0005432604673	4BEA85	8040 985148	ILYA SCHERBAKOV	{"email": "scherbakov-ilya_1975@postgrespro.ru", "phone": "+70261549739"}
0005432604674	C8EC92	2970 051981	LILIYA NESTEROVA	{"email": "liliya_nesterova-061983@postgrespro.ru", "phone": "+70267071757"}
0005432604675	C8EC92	5580 988738	OKSANA KULIKOVA	{"email": "oksana.kulikova_1971@postgrespro.ru", "phone": "+70185050809"}
0005432604676	9CC97A	8798 243419	SERGEY MATVEEV	{"email": "matveevsergey1964@postgrespro.ru", "phone": "+70940743723"}
0005432604677	D85F0D	4260 039507	ELENA POPOVA	{"phone": "+70481166876"}
0005432604678	9E48EE	5192 910810	ILDAR MOROZOV	{"email": "morozov-i1981@postgrespro.ru", "phone": "+70738127235"}
0005432604679	306D2A	5310 139085	ALEKSEY NIKITIN	{"email": "nikitin-a_1963@postgrespro.ru", "phone": "+70217785231"}
0005432604680	306D2A	5060 835911	DENIS KUZMIN	{"email": "denis.kuzmin.31071974@postgrespro.ru", "phone": "+70319979963"}
0005432604681	FE0815	5787 073079	ANDREY EGOROV	{"phone": "+70547961502"}
0005432604682	C73098	9700 815426	TATYANA KUZMINA	{"email": "tatyana_kuzmina021966@postgrespro.ru", "phone": "+70125888764"}
0005432604683	E6D875	8055 989029	ALEKSANDR ABRAMOV	{"email": "a-abramov-1969@postgrespro.ru", "phone": "+70197543908"}
0005432604684	008DB1	0108 901043	ALESYA LAZAREVA	{"email": "lazarevaa-23091973@postgrespro.ru", "phone": "+70999903210"}
0005432604685	008DB1	4814 202964	SNEZHANA FROLOVA	{"phone": "+70392191151"}
0005432604686	37B9FF	7542 963709	TATYANA NIKITINA	{"email": "tnikitina-1970@postgrespro.ru", "phone": "+70552965505"}
0005432604687	37B9FF	9845 450195	BORIS KISELEV	{"email": "boris.kiselev18121973@postgrespro.ru", "phone": "+70315121166"}
0005432604688	37B9FF	2907 567429	YANA IVANOVA	{"email": "y-ivanova-041982@postgrespro.ru", "phone": "+70816551157"}
0005432604689	B4D7F6	7930 966770	ALEKSANDR GUSEV	{"email": "aleksandrgusev_121979@postgrespro.ru", "phone": "+70982572678"}
0005432604690	C96FFA	8076 164142	VLADIMIR MEDVEDEV	{"email": "vladimir_medvedev.031965@postgrespro.ru", "phone": "+70875509885"}
0005432604691	34226C	6410 940605	SERGEY TARASOV	{"phone": "+70148659505"}
0005432604692	EBAB38	4153 261980	ALEKSANDR MIRONOV	{"phone": "+70385092362"}
0005432604693	62BFD4	0712 552029	VALERIY MAKSIMOV	{"email": "maksimov_v_1976@postgrespro.ru", "phone": "+70918018168"}
0005432604694	62BFD4	9845 758820	TAMARA KUZMINA	{"phone": "+70246222499"}
0005432604695	635C49	5389 080191	VALENTINA KULIKOVA	{"email": "kulikova_v-021975@postgrespro.ru", "phone": "+70283284478"}
0005432604696	141EED	0636 177910	LYUDMILA ORLOVA	{"phone": "+70761936697"}
0005432604697	141EED	3259 650556	VALENTINA NESTEROVA	{"email": "valentina.nesterova1976@postgrespro.ru", "phone": "+70611060832"}
0005432604698	AB971E	6839 772205	ANASTASIYA TITOVA	{"phone": "+70557166082"}
0005432604699	D0872F	5763 323064	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov011979@postgrespro.ru", "phone": "+70130283234"}
0005432604700	D0872F	5799 042249	NATALYA SEMENOVA	{"email": "semenova-n-081970@postgrespro.ru", "phone": "+70764541904"}
0005432604701	44D3A4	9389 418620	OLGA VLASOVA	{"email": "vlasovao-03091967@postgrespro.ru", "phone": "+70125439035"}
0005432604702	44D3A4	9421 522819	ANNA MIRONOVA	{"email": "a-mironova-10121961@postgrespro.ru", "phone": "+70942937739"}
0005432604703	44D3A4	5318 661771	NATALYA IVANOVA	{"email": "ivanovanatalya28101961@postgrespro.ru", "phone": "+70729062059"}
0005432604704	44D3A4	7662 091068	ALEKSANDR MELNIKOV	{"phone": "+70149341506"}
0005432604705	46B6BC	4311 993976	TATYANA GERASIMOVA	{"email": "gerasimova-t-12081968@postgrespro.ru", "phone": "+70562533246"}
0005432604706	AFB3EB	9819 961937	OKSANA NIKIFOROVA	{"phone": "+70300929951"}
0005432604707	AFB3EB	6650 570296	ANTONINA BARANOVA	{"phone": "+70473229733"}
0005432604708	90F856	7710 220748	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva.1979@postgrespro.ru", "phone": "+70845048566"}
0005432604709	CF7B99	0424 154166	ROMAN ZAKHAROV	{"email": "rzakharov-1981@postgrespro.ru", "phone": "+70952037220"}
0005432604710	CF7B99	2364 780930	EKATERINA FROLOVA	{"phone": "+70003481519"}
0005432604711	A71FF4	8808 868159	GULFIYA YAKOVLEVA	{"email": "gyakovleva.101964@postgrespro.ru", "phone": "+70021167198"}
0005432604712	01EE90	9191 772684	MIKHAIL NIKOLAEV	{"email": "nikolaev_m.26111962@postgrespro.ru", "phone": "+70588149993"}
0005432604713	CC7DA4	0273 085707	ANATOLIY POPOV	{"email": "a_popov.1963@postgrespro.ru", "phone": "+70204122378"}
0005432604714	CC7DA4	2691 314039	SERGEY BELOV	{"email": "sergeybelov_1962@postgrespro.ru", "phone": "+70394519611"}
0005432604715	CC7DA4	2951 684774	DENIS PETROV	{"phone": "+70654670988"}
0005432604716	CC7DA4	8690 518765	IRINA ZAKHAROVA	{"email": "i.zakharova-1978@postgrespro.ru", "phone": "+70877516515"}
0005432604717	632B7A	9394 791382	VERA MAKSIMOVA	{"phone": "+70048754129"}
0005432604718	7A3395	1477 498694	RUSLAN VLASOV	{"email": "vlasov.r13101969@postgrespro.ru", "phone": "+70156930261"}
0005432604719	7A3395	4166 406396	VENIAMIN ZHUKOV	{"phone": "+70962260727"}
0005432604720	E3133D	2857 644431	NADEZHDA BOGDANOVA	{"phone": "+70510344106"}
0005432604721	B24A06	2109 844230	MARAT MELNIKOV	{"phone": "+70659561032"}
0005432604722	B24A06	8461 342555	KAMIL NOVIKOV	{"phone": "+70992921283"}
0005432604723	E3CA8C	7753 301478	IGOR EGOROV	{"phone": "+70505021850"}
0005432604724	5507CA	5897 974839	MARIYA SMIRNOVA	{"email": "smirnovam_20071975@postgrespro.ru", "phone": "+70218035218"}
0005432604725	5507CA	6559 302981	LYUBOV NAUMOVA	{"email": "lyubov.naumova_111975@postgrespro.ru", "phone": "+70436425287"}
0005432604726	C313AE	7475 539555	ELENA KUZNECOVA	{"email": "e_kuznecova_14021966@postgrespro.ru", "phone": "+70941175139"}
0005432604727	81602B	0728 164906	VALENTINA KRASNOVA	{"email": "valentinakrasnova-1971@postgrespro.ru", "phone": "+70501766333"}
0005432604728	24014D	1504 888449	GALINA KALININA	{"phone": "+70145598176"}
0005432604729	34C9F9	0716 779512	DANIIL NAUMOV	{"phone": "+70417599863"}
0005432604730	34C9F9	0708 446701	ANDREY NAZAROV	{"phone": "+70156002792"}
0005432604731	E36843	1423 121603	OKSANA SCHERBAKOVA	{"email": "scherbakova-o_17071982@postgrespro.ru", "phone": "+70023924262"}
0005432604732	E36843	7636 913239	TATYANA MARTYNOVA	{"email": "martynovatatyana.1978@postgrespro.ru", "phone": "+70456743197"}
0005432604733	06B73B	2882 409631	MARIYA PETROVA	{"phone": "+70266128493"}
0005432604734	383404	3195 274048	NIKOLAY FROLOV	{"email": "frolov_nikolay_23051963@postgrespro.ru", "phone": "+70101647380"}
0005432604735	8B7BAD	7346 544822	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.a.1981@postgrespro.ru", "phone": "+70530713212"}
0005432604736	8B7BAD	6711 190711	SVETLANA TARASOVA	{"email": "svetlana-tarasova_14041975@postgrespro.ru", "phone": "+70878224824"}
0005432604737	CE1E4E	1852 016913	SVETLANA MIKHAYLOVA	{"email": "mikhaylova-svetlana-021965@postgrespro.ru", "phone": "+70354227594"}
0005432604738	CE1E4E	7703 500057	VIKTOR KUZNECOV	{"email": "kuznecov.viktor-19111966@postgrespro.ru", "phone": "+70822188114"}
0005432604739	23EC40	1797 787835	ELENA NESTEROVA	{"phone": "+70499615820"}
0005432604740	23EC40	9529 060446	SERGEY ZHUKOV	{"email": "zhukov-s.04121973@postgrespro.ru", "phone": "+70061854224"}
0005432604741	23EC40	2652 831396	ELENA ZHUKOVA	{"phone": "+70353969801"}
0005432604742	23EC40	2041 948446	GALINA POTAPOVA	{"phone": "+70200262613"}
0005432604743	974ED2	9647 697110	ALEKSANDRA EFIMOVA	{"email": "efimova_a.16111978@postgrespro.ru", "phone": "+70771594889"}
0005432604744	974ED2	0911 691670	ALEKSANDRA ANDREEVA	{"email": "andreevaaleksandra-101967@postgrespro.ru", "phone": "+70427146009"}
0005432604745	974ED2	1506 900026	IGOR IVANOV	{"email": "igor_ivanov08011962@postgrespro.ru", "phone": "+70930925351"}
0005432604746	A4E7D9	5591 032154	EVGENIY MAKAROV	{"email": "evgeniy_makarov1980@postgrespro.ru", "phone": "+70696192842"}
0005432604747	978BBC	9849 853095	ALEKSANDR BARANOV	{"phone": "+70061027009"}
0005432604748	978BBC	2197 466888	ARTUR KOZLOV	{"phone": "+70498337908"}
0005432604749	B912AF	5896 043498	NIKOLAY FOMIN	{"phone": "+70800977397"}
0005432604750	B912AF	0592 609206	GENNADIY KUZNECOV	{"email": "kuznecov-gennadiy_03051979@postgrespro.ru", "phone": "+70622755970"}
0005432604751	B912AF	3129 222357	VALENTIN BORISOV	{"email": "v.borisov06081977@postgrespro.ru", "phone": "+70030924981"}
0005432604752	03C888	5732 669639	ELENA KUZNECOVA	{"phone": "+70549631382"}
0005432604753	03C888	1910 301971	MARINA ALEKSEEVA	{"phone": "+70420845875"}
0005432604754	B27BDF	3695 130901	ELIZAVETA SIDOROVA	{"phone": "+70185812762"}
0005432604755	B27BDF	9454 258839	ALEKSEY IVANOV	{"phone": "+70682290510"}
0005432604756	B7423F	7875 294084	VALENTINA DAVYDOVA	{"email": "vdavydova_17011973@postgrespro.ru", "phone": "+70099536142"}
0005432604757	410DC0	1607 961882	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov-021961@postgrespro.ru", "phone": "+70976662434"}
0005432604758	7E791E	1555 284094	VERA BARANOVA	{"email": "baranova_vera.1967@postgrespro.ru", "phone": "+70494008458"}
0005432604759	D33FB0	8905 474464	GALINA POPOVA	{"phone": "+70127707101"}
0005432604760	EC689E	6768 090433	VALENTINA KONOVALOVA	{"phone": "+70887597239"}
0005432604761	EC689E	1613 034513	VLADIMIR KISELEV	{"phone": "+70940500017"}
0005432604762	0E6D29	5523 866070	KLAVDIYA VOLKOVA	{"email": "klavdiya-volkova.23061978@postgrespro.ru", "phone": "+70972521220"}
0005432604763	C92692	3869 969028	OLGA LUKYANOVA	{"email": "olukyanova06041982@postgrespro.ru", "phone": "+70429403365"}
0005432604764	00E3D6	8157 456513	ELENA MELNIKOVA	{"phone": "+70908830786"}
0005432604765	77F8E3	3819 998251	LYUBOV ABRAMOVA	{"phone": "+70825398486"}
0005432604766	147B1F	3122 818720	ELENA GUSEVA	{"email": "elena_guseva-21101965@postgrespro.ru", "phone": "+70055095058"}
0005432604767	147B1F	9156 632292	INNA SMIRNOVA	{"phone": "+70216263482"}
0005432604768	2C4FA4	0616 279260	ELENA TIMOFEEVA	{"email": "timofeevae1959@postgrespro.ru", "phone": "+70882655698"}
0005432604769	2C4FA4	8988 275863	ANASTASIYA NIKOLAEVA	{"phone": "+70528765955"}
0005432604770	42711C	0675 642545	VIKTOR DENISOV	{"phone": "+70180257400"}
0005432604771	42711C	6938 251087	EVGENIY VASILEV	{"email": "vasilev.evgeniy29071971@postgrespro.ru", "phone": "+70396754594"}
0005432604772	D3D7CB	9847 926649	ELENA DAVYDOVA	{"email": "davydova.e-1972@postgrespro.ru", "phone": "+70486020287"}
0005432604773	E25B67	4093 878808	MAKSIM KOROLEV	{"email": "m_korolev-111969@postgrespro.ru", "phone": "+70380405193"}
0005432604774	E25B67	6326 822565	NATALYA BORISOVA	{"phone": "+70037540669"}
0005432604775	E25B67	9716 604917	SERGEY KISELEV	{"email": "skiselev.12051974@postgrespro.ru", "phone": "+70893348802"}
0005432604776	6ADBD6	5789 638551	OLEG MIRONOV	{"email": "mironov-o1966@postgrespro.ru", "phone": "+70206290194"}
0005432604777	E151AC	7198 930412	NIKOLAY TARASOV	{"phone": "+70955370583"}
0005432604778	E151AC	0395 646139	LILIYA SOKOLOVA	{"email": "l-sokolova-1966@postgrespro.ru", "phone": "+70991262973"}
0005432604779	D063CA	7269 408063	IRINA NESTEROVA	{"phone": "+70655619206"}
0005432604780	B32C07	3575 012192	SERGEY MAKSIMOV	{"phone": "+70882329768"}
0005432604781	4310F7	5090 042182	TATYANA SERGEEVA	{"phone": "+70943974212"}
0005432604782	081944	2310 944081	OLGA EGOROVA	{"email": "o_egorova_011983@postgrespro.ru", "phone": "+70745509000"}
0005432604783	AA014B	2068 244322	DANILA KISELEV	{"email": "kiselevd.011974@postgrespro.ru", "phone": "+70585663630"}
0005432604784	E85615	9978 971164	VASILIY NAZAROV	{"email": "nazarov-vasiliy.011974@postgrespro.ru", "phone": "+70740125940"}
0005432604785	7CAD73	5323 133821	VLADIMIR IVANOV	{"email": "ivanov_v.081972@postgrespro.ru", "phone": "+70923702348"}
0005432604786	A8960F	9778 787080	ANZHELA IVANOVA	{"email": "aivanova-021968@postgrespro.ru", "phone": "+70787782480"}
0005432604787	09AC2C	5604 547391	MIKHAIL YAKOVLEV	{"phone": "+70939832679"}
0005432604788	FAE41F	1494 852854	MARINA KOROLEVA	{"email": "korolevamarina1971@postgrespro.ru", "phone": "+70072925829"}
0005432604789	831946	9225 629721	ANDREY MELNIKOV	{"email": "melnikov_a_071963@postgrespro.ru", "phone": "+70201224241"}
0005432604790	43D73E	4818 459108	SERGEY FROLOV	{"phone": "+70180163078"}
0005432604791	43D73E	9113 126080	MARINA BORISOVA	{"phone": "+70007955498"}
0005432604792	3534D9	3019 128507	ALEKSEY KOZLOV	{"phone": "+70552199649"}
0005432604793	3534D9	6723 562574	YURIY KISELEV	{"email": "kiselev.y1969@postgrespro.ru", "phone": "+70609670225"}
0005432604794	671674	0913 361172	IRINA PETROVA	{"email": "petrova-irina1966@postgrespro.ru", "phone": "+70732167034"}
0005432604795	FEE04A	7833 356990	VYACHESLAV SERGEEV	{"phone": "+70590763845"}
0005432604796	FEE04A	1972 737052	EVGENIY GAVRILOV	{"email": "gavrilovevgeniy27021979@postgrespro.ru", "phone": "+70869007681"}
0005432604797	137570	5054 489180	LARISA ZAKHAROVA	{"phone": "+70951920493"}
0005432604798	AD82C3	4715 195204	SERGEY DENISOV	{"phone": "+70426510289"}
0005432604799	AD82C3	7082 784179	ELENA KOZLOVA	{"email": "elenakozlova.1975@postgrespro.ru", "phone": "+70912832970"}
0005432604800	AD82C3	6461 206434	GALINA MELNIKOVA	{"email": "gmelnikova-1972@postgrespro.ru", "phone": "+70647065870"}
0005432604801	5BCB0C	4788 385640	YURIY SAVELEV	{"email": "savelev.yuriy.061968@postgrespro.ru", "phone": "+70674013326"}
0005432604802	5BCB0C	5348 509885	VLADIMIR NAZAROV	{"phone": "+70873514778"}
0005432604803	89DBD3	8971 844171	VALERIY AFANASEV	{"phone": "+70445645047"}
0005432604804	3E419A	9157 531996	OLGA EGOROVA	{"email": "egorova_olga021973@postgrespro.ru", "phone": "+70728512642"}
0005432604805	171605	0186 541520	ARTEM ROMANOV	{"email": "romanov_a061969@postgrespro.ru", "phone": "+70974680710"}
0005432604806	171605	5092 769693	NINA SERGEEVA	{"phone": "+70851899348"}
0005432604807	5F985F	5948 742299	GENNADIY TIKHONOV	{"email": "tikhonov.g_121979@postgrespro.ru", "phone": "+70168283376"}
0005432604808	C67CE7	4636 700267	LYUBOV ALEKSEEVA	{"phone": "+70510113074"}
0005432604809	081D33	3461 334595	ALEKSEY ZHURAVLEV	{"email": "a-zhuravlev-121969@postgrespro.ru", "phone": "+70982602890"}
0005432604810	508360	4347 913628	EVGENIY YAKOVLEV	{"email": "yakovlev-evgeniy.02091969@postgrespro.ru", "phone": "+70450559644"}
0005432604811	A368E4	8047 753072	EVGENIY ZAKHAROV	{"phone": "+70767181097"}
0005432604812	F5EEF9	2161 695434	YULIYA STEPANOVA	{"phone": "+70272302615"}
0005432604813	F5EEF9	5939 602816	DAVID BARANOV	{"email": "baranov-d1971@postgrespro.ru", "phone": "+70742068016"}
0005432604814	8949D0	6090 842308	VLADIMIR DENISOV	{"phone": "+70649227379"}
0005432604815	E71037	9399 817120	VIKTOR PAVLOV	{"email": "v_pavlov_27041974@postgrespro.ru", "phone": "+70227679480"}
0005432604816	E71037	7925 376284	IGOR MEDVEDEV	{"email": "medvedev.i.061962@postgrespro.ru", "phone": "+70457492577"}
0005432604817	E71037	5242 830193	ELENA ANTONOVA	{"email": "eantonova1974@postgrespro.ru", "phone": "+70276980597"}
0005432604818	60D4B9	5481 981586	LYUDMILA SEMENOVA	{"email": "semenova-l-1970@postgrespro.ru", "phone": "+70180070310"}
0005432604819	19B732	2780 947913	VLADIMIR ROMANOV	{"phone": "+70420315163"}
0005432604820	779671	7769 936925	DMITRIY GRIGOREV	{"phone": "+70956463594"}
0005432604821	A7AE0D	4861 267433	ANATOLIY POPOV	{"phone": "+70841654078"}
0005432604822	582A1B	2518 640830	VALENTINA MATVEEVA	{"email": "valentina_matveeva-041965@postgrespro.ru", "phone": "+70919380756"}
0005432604823	EDA85C	8473 505076	OLGA MAKSIMOVA	{"phone": "+70597718971"}
0005432604824	03AD2A	6571 820469	EKATERINA TIKHONOVA	{"phone": "+70174369274"}
0005432604825	03AD2A	8895 772984	DARYA SOROKINA	{"phone": "+70439371484"}
0005432604826	C6B279	0743 403397	VIKTOR SCHERBAKOV	{"email": "scherbakov.viktor_10031976@postgrespro.ru", "phone": "+70411299405"}
0005432604827	B44E8B	1132 699658	VLADIMIR SMIRNOV	{"phone": "+70763702026"}
0005432604828	84E990	3271 646288	ZOYA POPOVA	{"email": "popovaz.101965@postgrespro.ru", "phone": "+70511620162"}
0005432604829	42AAAF	1970 974712	NATALYA MIKHAYLOVA	{"email": "mikhaylovan-041983@postgrespro.ru", "phone": "+70463571718"}
0005432604830	123EBB	9319 374851	MAKSIM GORBUNOV	{"email": "gorbunovmaksim1961@postgrespro.ru", "phone": "+70136867556"}
0005432604831	45069C	0864 267099	VIKTOR ZHUKOV	{"email": "zhukov_viktor-071973@postgrespro.ru", "phone": "+70126922036"}
0005432604832	45069C	7516 528636	ANASTASIYA ARKHIPOVA	{"email": "arkhipova-a.121970@postgrespro.ru", "phone": "+70595496074"}
0005432604833	E80C28	9572 085201	ARTEM KUZMIN	{"email": "kuzmin.artem.011967@postgrespro.ru", "phone": "+70513301265"}
0005432604834	F2D498	7099 963594	EVGENIYA NESTEROVA	{"phone": "+70039359736"}
0005432604835	F0B51D	6877 821421	ALEKSANDR NAZAROV	{"phone": "+70137336043"}
0005432604836	14EB6F	7053 368725	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a_071972@postgrespro.ru", "phone": "+70780574398"}
0005432604837	14EB6F	4202 845963	MARINA TARASOVA	{"phone": "+70409039166"}
0005432604838	14EB6F	7181 309118	DMITRIY ANDREEV	{"email": "andreev.d-22111969@postgrespro.ru", "phone": "+70721457922"}
0005432604839	9D4661	5916 446533	NATALYA BOGDANOVA	{"email": "bogdanova_natalya.071977@postgrespro.ru", "phone": "+70606952689"}
0005432604840	9F63F3	3823 578679	LYUBOV SOKOLOVA	{"email": "l.sokolova_111976@postgrespro.ru", "phone": "+70562979900"}
0005432604841	3940DD	5585 636289	VLADIMIR MAKAROV	{"phone": "+70043531779"}
0005432604842	3940DD	4197 566869	SERGEY ZAYCEV	{"phone": "+70310983252"}
0005432604843	3940DD	1926 806286	IVAN MOROZOV	{"email": "ivan.morozov_20021982@postgrespro.ru", "phone": "+70361136744"}
0005432604844	CCF7BA	3414 045714	ANTONINA KUZNECOVA	{"phone": "+70265099122"}
0005432604845	67EA6A	0554 715103	VERA POPOVA	{"phone": "+70953189685"}
0005432604846	7DBEDC	2426 367795	ALEKSANDR PETROV	{"phone": "+70563632608"}
0005432604847	7DBEDC	7610 266553	SERGEY GAVRILOV	{"email": "sergey_gavrilov031964@postgrespro.ru", "phone": "+70920873305"}
0005432604848	7DBEDC	1933 255531	EKATERINA ZHURAVLEVA	{"email": "ekaterinazhuravleva-1978@postgrespro.ru", "phone": "+70373199146"}
0005432604849	4361D1	3556 895684	EVGENIY BARANOV	{"phone": "+70762987455"}
0005432604850	DCB06E	2715 955819	ELENA SEMENOVA	{"phone": "+70656773529"}
0005432604851	369654	0826 620688	SVETLANA ZAYCEVA	{"email": "s-zayceva_041971@postgrespro.ru", "phone": "+70362571635"}
0005432604852	C088C2	6562 266342	MARAT ABRAMOV	{"email": "mabramov-1965@postgrespro.ru", "phone": "+70185594919"}
0005432604853	5F26C7	1938 877069	NATALYA KUZNECOVA	{"email": "kuznecova-natalya.13091979@postgrespro.ru", "phone": "+70791593753"}
0005432604854	60659E	6025 725872	SERGEY SOLOVEV	{"phone": "+70060653976"}
0005432604855	E20E58	1486 347812	DARYA PETROVA	{"phone": "+70135714735"}
0005432604856	FCBFFF	8327 993292	PAVEL MARTYNOV	{"phone": "+70309289155"}
0005432604857	8039A8	0669 822444	VARVARA TROFIMOVA	{"email": "trofimova.v1978@postgrespro.ru", "phone": "+70211270798"}
0005432604858	200E71	2835 627176	BORIS SHEVCHENKO	{"email": "borisshevchenko_051969@postgrespro.ru", "phone": "+70101826475"}
0005432604859	200E71	5780 120513	VALENTINA ILINA	{"email": "valentina.ilina02081980@postgrespro.ru", "phone": "+70059860317"}
0005432604860	CFF837	6959 393082	DMITRIY SIDOROV	{"email": "dsidorov.1968@postgrespro.ru", "phone": "+70107188531"}
0005432604861	CFF837	8900 253923	DARYA PETROVA	{"email": "darya.petrova.29091967@postgrespro.ru", "phone": "+70673111908"}
0005432604862	49C157	6373 777568	STANISLAV POPOV	{"email": "stanislav-popov.1972@postgrespro.ru", "phone": "+70082035685"}
0005432604863	10E960	0369 415889	MAKSIM VOLKOV	{"phone": "+70520246782"}
0005432604864	150D81	8333 684037	IVAN ZAYCEV	{"email": "ivan_zaycev-29071976@postgrespro.ru", "phone": "+70115453107"}
0005432604865	7F5FBD	1032 584582	VALENTINA FEDOROVA	{"phone": "+70968559615"}
0005432604866	7F5FBD	6407 471587	OLGA NAZAROVA	{"email": "nazarova-olga1975@postgrespro.ru", "phone": "+70503347729"}
0005432604867	3ED536	5200 058841	NATALYA NAUMOVA	{"phone": "+70582213789"}
0005432604868	23D9EA	7516 288446	SVETLANA RODIONOVA	{"phone": "+70952429189"}
0005432604869	286518	2814 821657	NATALYA FOMINA	{"email": "fominan.1959@postgrespro.ru", "phone": "+70060820139"}
0005432604870	ABAA83	9442 345195	SOFIYA IVANOVA	{"phone": "+70103052877"}
0005432604871	3C47CF	8995 170621	SOFYA NOVIKOVA	{"email": "sofya_novikova_111962@postgrespro.ru", "phone": "+70341728152"}
0005432604872	9FD52B	1114 362060	ANDREY ISAEV	{"email": "aisaev-1974@postgrespro.ru", "phone": "+70019002924"}
0005432604873	FF42FA	1002 535951	EKATERINA KUDRYASHOVA	{"phone": "+70397929052"}
0005432604874	78D2DC	6152 976745	SERGEY DENISOV	{"email": "denisov.s1977@postgrespro.ru", "phone": "+70063670024"}
0005432604875	0D5A56	4447 679145	ALLA YUDINA	{"phone": "+70882330120"}
0005432604876	923D25	1996 035372	VIKTOR ROMANOV	{"email": "viktor_romanov1978@postgrespro.ru", "phone": "+70058818393"}
0005432604877	1A70AB	6477 533229	YAROSLAV GERASIMOV	{"email": "ygerasimov1981@postgrespro.ru", "phone": "+70853007136"}
0005432604878	1A70AB	5405 115866	SVETLANA MELNIKOVA	{"phone": "+70085556563"}
0005432604879	38BE04	9861 337977	EVGENIY ZAKHAROV	{"phone": "+70375027946"}
0005432604880	38BE04	7217 820321	SERGEY VOLKOV	{"email": "volkov-s.051965@postgrespro.ru", "phone": "+70504654465"}
0005432604881	7B014C	4693 967046	ALEKSEY IVANOV	{"phone": "+70171140731"}
0005432604882	785E5C	8672 589331	TAMARA NIKITINA	{"phone": "+70714763405"}
0005432604883	A6D2FC	5651 616984	IGOR POPOV	{"email": "i.popov_111979@postgrespro.ru", "phone": "+70010287980"}
0005432604884	321918	6744 003938	VITALIY TARASOV	{"email": "tarasov.v121976@postgrespro.ru", "phone": "+70323779398"}
0005432604885	ECBA59	1871 652087	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova-1970@postgrespro.ru", "phone": "+70876015709"}
0005432604886	ECBA59	0986 628627	YULIYA KAZAKOVA	{"email": "kazakova.y-031974@postgrespro.ru", "phone": "+70162521531"}
0005432604887	651689	0524 786263	ELENA KONDRATEVA	{"phone": "+70661513904"}
0005432604888	651689	9154 165073	LIDIYA BELOVA	{"phone": "+70753230729"}
0005432604889	3C85F1	7157 120169	ELENA LUKYANOVA	{"phone": "+70983771671"}
0005432604890	E14374	5798 748431	ANDREY EGOROV	{"email": "a.egorov-11121972@postgrespro.ru", "phone": "+70736218385"}
0005432604891	E14374	6902 954510	MARINA GORBUNOVA	{"email": "m.gorbunova-12041969@postgrespro.ru", "phone": "+70835060867"}
0005432604892	C882D5	2885 566670	ALEFTINA STEPANOVA	{"email": "a.stepanova.1971@postgrespro.ru", "phone": "+70987546414"}
0005432604893	820C2D	1754 529681	MARIYA STEPANOVA	{"phone": "+70834374312"}
0005432604894	CFFBFE	0080 589619	MARINA PETROVA	{"email": "petrova.m.091978@postgrespro.ru", "phone": "+70397759933"}
0005432604895	CFFBFE	2216 349226	PAVEL PETROV	{"phone": "+70935274809"}
0005432604896	E6FF13	9632 991331	ALEKSANDR FROLOV	{"email": "a_frolov1977@postgrespro.ru", "phone": "+70082901953"}
0005432604897	E6FF13	4296 510920	ALEKSANDR MEDVEDEV	{"phone": "+70627806283"}
0005432604898	F416AE	6040 321723	DENIS STEPANOV	{"phone": "+70699731325"}
0005432604899	F416AE	3559 705545	ANDREY VOLKOV	{"email": "avolkov_23031971@postgrespro.ru", "phone": "+70706566026"}
0005432604900	108B9D	5961 005074	SERGEY NOVIKOV	{"email": "novikov_sergey-08111964@postgrespro.ru", "phone": "+70421401919"}
0005432604901	108B9D	1781 966849	EVGENIYA ROMANOVA	{"phone": "+70764287512"}
0005432604902	624441	2575 356756	ARTEM SEMENOV	{"email": "artemsemenov20011975@postgrespro.ru", "phone": "+70827745652"}
0005432604903	B6C520	1196 497768	NIKOLAY OSIPOV	{"phone": "+70220462351"}
0005432604904	B6C520	4645 190454	ALEKSANDR GRIGOREV	{"phone": "+70283867942"}
0005432604905	4EA38D	1549 802188	EKATERINA KONOVALOVA	{"email": "konovalova-e.20101972@postgrespro.ru", "phone": "+70032910308"}
0005432604906	BEF4AC	5687 349406	ALEKSANDRA MATVEEVA	{"phone": "+70680762910"}
0005432604907	5ECB50	9687 220694	FEDOR CHERNOV	{"phone": "+70844823980"}
0005432604908	9B589C	9058 451954	TATYANA GAVRILOVA	{"email": "gavrilova_tatyana.1976@postgrespro.ru", "phone": "+70056967850"}
0005432604909	9B589C	6498 397340	DENIS TARASOV	{"phone": "+70567016920"}
0005432604910	1CB1A1	8403 095468	ZOYA DMITRIEVA	{"phone": "+70773647279"}
0005432604911	455E62	4975 967643	RIMMA SOKOLOVA	{"phone": "+70857782401"}
0005432604912	5799C4	9712 884865	NATALYA CHERNOVA	{"phone": "+70104301784"}
0005432604913	5799C4	0230 356354	NIKOLAY KUZNECOV	{"phone": "+70035203660"}
0005432604914	5799C4	2007 319340	VLADIMIR GRIGOREV	{"email": "grigorev-v111962@postgrespro.ru", "phone": "+70512702674"}
0005432604915	5799C4	8911 159588	ALEKSANDR NIKOLAEV	{"phone": "+70481137154"}
0005432604916	DEE2AA	9254 731771	OLGA SIDOROVA	{"phone": "+70990137454"}
0005432604917	DEE2AA	2810 757389	LYUBOV CHERNOVA	{"email": "l_chernova.1970@postgrespro.ru", "phone": "+70407119859"}
0005432604918	78FCA2	5381 804550	ALEKSANDR TIKHONOV	{"email": "aleksandr_tikhonov-041973@postgrespro.ru", "phone": "+70497758153"}
0005432604919	78FCA2	2454 628813	YURIY ZAYCEV	{"email": "yuriy.zaycev1977@postgrespro.ru", "phone": "+70348786160"}
0005432604920	8531AC	8339 160053	MARIYA MASLOVA	{"phone": "+70620909540"}
0005432604921	8053D9	4399 997410	GRIGORIY ABRAMOV	{"phone": "+70215008150"}
0005432604922	42BC2B	9657 471891	YURIY KUZNECOV	{"email": "kuznecov-yuriy-1972@postgrespro.ru", "phone": "+70378106155"}
0005432604923	D82BC5	4933 049151	VYACHESLAV OSIPOV	{"email": "osipovv_061971@postgrespro.ru", "phone": "+70789927501"}
0005432604924	D82BC5	3761 838432	GALINA PETROVA	{"phone": "+70125778139"}
0005432604925	46F1CB	8601 138697	VIKTOR SERGEEV	{"email": "viktor_sergeev-30101973@postgrespro.ru", "phone": "+70720334071"}
0005432604926	46F1CB	3576 732742	SERGEY ZAKHAROV	{"email": "zakharov_s-30041968@postgrespro.ru", "phone": "+70414991452"}
0005432604927	33DAB8	2990 267601	DANIIL ABRAMOV	{"email": "abramov-daniil-1965@postgrespro.ru", "phone": "+70408314950"}
0005432604928	33DAB8	9760 764620	VERA SOLOVEVA	{"phone": "+70656466866"}
0005432604929	33DAB8	7842 721945	IGOR DAVYDOV	{"email": "i-davydov011966@postgrespro.ru", "phone": "+70895775425"}
0005432604930	CE1F02	5663 882889	MARGARITA SOROKINA	{"phone": "+70117534022"}
0005432604931	CE1F02	0142 098086	ELENA FILATOVA	{"email": "filatovaelena-1969@postgrespro.ru", "phone": "+70523043521"}
0005432604932	CE1F02	5923 716359	NIKOLAY GAVRILOV	{"email": "n_gavrilov.031974@postgrespro.ru", "phone": "+70254882671"}
0005432604933	1E111B	3801 192126	ANTONINA OVCHINNIKOVA	{"email": "ovchinnikova-a19011980@postgrespro.ru", "phone": "+70177395543"}
0005432604934	39E485	0806 917270	SVETLANA SOROKINA	{"phone": "+70329717003"}
0005432604935	39E485	9971 294254	YAN VASILEV	{"email": "vasilev_yan30121970@postgrespro.ru", "phone": "+70240344462"}
0005432604936	EF4732	4529 028662	NIKOLAY ZAYCEV	{"phone": "+70944222250"}
0005432604937	B85DAD	8258 219588	NATALYA SEMENOVA	{"phone": "+70373248689"}
0005432604938	AF44D6	7429 995687	RUSLAN GORBUNOV	{"email": "gorbunov_ruslan.011975@postgrespro.ru", "phone": "+70331067583"}
0005432604939	AF44D6	8205 190561	KONSTANTIN KUZMIN	{"email": "konstantinkuzmin111967@postgrespro.ru", "phone": "+70912591260"}
0005432604940	9B7D31	5289 030219	SERGEY YAKOVLEV	{"email": "sergeyyakovlev-20041964@postgrespro.ru", "phone": "+70281420250"}
0005432604941	FFE82B	4534 054923	SERGEY SAVELEV	{"email": "savelev.s-071976@postgrespro.ru", "phone": "+70237494480"}
0005432604942	AA9B8E	8047 384900	TAMARA STEPANOVA	{"email": "stepanovat.1972@postgrespro.ru", "phone": "+70855670743"}
0005432604943	AA9B8E	5111 594965	ALEKSEY SEMENOV	{"phone": "+70149578590"}
0005432604944	86B691	8627 249143	ALEKSANDR NAUMOV	{"phone": "+70812345764"}
0005432604945	7F3708	3412 971074	MARINA MIRONOVA	{"email": "mironova.m1970@postgrespro.ru", "phone": "+70672727288"}
0005432604946	D5E25F	3539 784053	VENIAMIN ALEKSEEV	{"phone": "+70540432611"}
0005432604947	D5E25F	0584 034496	SVETLANA KONOVALOVA	{"email": "svetlanakonovalova19011972@postgrespro.ru", "phone": "+70761981990"}
0005432604948	33EC82	7463 226633	VERA PETROVA	{"email": "v_petrova.1965@postgrespro.ru", "phone": "+70622160832"}
0005432604949	77551B	1483 296848	DMITRIY KUZNECOV	{"phone": "+70233913031"}
0005432604950	E8E876	5724 733944	NINA TARASOVA	{"email": "tarasova_nina.13071983@postgrespro.ru", "phone": "+70254316147"}
0005432604951	E8E876	3825 784978	EKATERINA LUKYANOVA	{"phone": "+70926795870"}
0005432604952	59390A	6465 527703	YURIY KULIKOV	{"email": "y_kulikov1974@postgrespro.ru", "phone": "+70121689126"}
0005432604953	71C3C3	9182 831881	ALEKSEY ANTONOV	{"email": "antonov_aleksey-1970@postgrespro.ru", "phone": "+70469221324"}
0005432604954	E16885	4240 533386	STANISLAV KONOVALOV	{"phone": "+70882190573"}
0005432604955	DA1286	6507 036528	ALSU POPOVA	{"email": "a.popova1958@postgrespro.ru", "phone": "+70619121889"}
0005432604956	DA1286	5451 484020	ANNA ILINA	{"email": "ilina.anna.15101977@postgrespro.ru", "phone": "+70220778975"}
0005432604957	92EF56	2650 362443	LEYLA KARPOVA	{"email": "karpova_leyla-1967@postgrespro.ru", "phone": "+70986629543"}
0005432604958	25E29C	4011 094000	VALENTINA POPOVA	{"phone": "+70122698354"}
0005432604959	E85452	3828 617798	ANDREY DAVYDOV	{"email": "andrey.davydov_1972@postgrespro.ru", "phone": "+70386531591"}
0005432604960	BAF51B	4912 941552	OLESYA ANDREEVA	{"phone": "+70021639202"}
0005432604961	27C2F0	9286 759933	NATALYA SERGEEVA	{"phone": "+70973401068"}
0005432604962	E0A55E	6498 212010	NIKOLAY SEMENOV	{"phone": "+70217280188"}
0005432604963	C781B5	0546 354039	VASILIY ZHUKOV	{"email": "zhukov_vasiliy_1975@postgrespro.ru", "phone": "+70067616650"}
0005432604964	12629D	9596 396653	MARIYA ISAEVA	{"phone": "+70621527783"}
0005432604965	12629D	8878 257828	ALEKSEY EGOROV	{"phone": "+70362012339"}
0005432604966	7042F9	4139 073935	ZHANNA STEPANOVA	{"email": "z-stepanova101971@postgrespro.ru", "phone": "+70754530483"}
0005432604967	3E6221	6879 404604	SVETLANA MIKHAYLOVA	{"email": "svetlana.mikhaylova1965@postgrespro.ru", "phone": "+70824052925"}
0005432604968	29ABE5	8844 428632	MARIANNA KRASNOVA	{"email": "krasnova.m021979@postgrespro.ru", "phone": "+70017649257"}
0005432604969	29ABE5	7482 752254	LYUBOV FOMINA	{"phone": "+70061730217"}
0005432604970	E94281	9899 708560	ALENA ALEKSEEVA	{"email": "alekseeva.alena_16031976@postgrespro.ru", "phone": "+70369303882"}
0005432604971	64FEE5	1855 316221	RUSLAN SERGEEV	{"phone": "+70899953001"}
0005432604972	01B707	3720 434101	PAVEL VLASOV	{"email": "vlasov-pavel.121975@postgrespro.ru", "phone": "+70091277431"}
0005432604973	370EE3	5132 956324	VALERIY DMITRIEV	{"phone": "+70390993769"}
0005432604974	105020	9472 822260	OLGA STEPANOVA	{"phone": "+70683621242"}
0005432604975	105020	1566 197020	MAKSIM MATVEEV	{"email": "matveevmaksim031983@postgrespro.ru", "phone": "+70685705329"}
0005432604976	0422C5	7518 214688	YURIY NIKITIN	{"email": "yuriy_nikitin_1979@postgrespro.ru", "phone": "+70900003668"}
0005432604977	8BF97E	3725 257955	EVGENIY EGOROV	{"email": "egorov.e_10111970@postgrespro.ru", "phone": "+70102393262"}
0005432604978	879E3C	1452 085021	ANDREY SHEVCHENKO	{"phone": "+70334986529"}
0005432604979	C11F38	4216 123340	OLEG MAKAROV	{"phone": "+70322645751"}
0005432604980	73430B	2657 505537	BORIS MIKHAYLOV	{"phone": "+70439631407"}
0005432604981	090263	6469 447595	RIMMA MELNIKOVA	{"phone": "+70732089517"}
0005432604982	090263	6734 700922	NELLI TIKHONOVA	{"phone": "+70273523552"}
0005432604983	947BC4	4223 828629	NIKOLAY BELOV	{"email": "nikolaybelov-27101972@postgrespro.ru", "phone": "+70560990763"}
0005432604984	947BC4	5476 632640	VENERA DAVYDOVA	{"email": "venera_davydova041977@postgrespro.ru", "phone": "+70221965857"}
0005432604985	D50612	4188 036189	NADEZHDA SOROKINA	{"email": "sorokinanadezhda-1974@postgrespro.ru", "phone": "+70438562921"}
0005432604986	2F6934	2438 765552	EKATERINA VLASOVA	{"phone": "+70857314724"}
0005432604987	2F6934	7870 984714	LYUDMILA KOROLEVA	{"phone": "+70398757462"}
0005432604988	76AD44	5472 478001	LYUDMILA CHERNOVA	{"email": "chernova-l.11111967@postgrespro.ru", "phone": "+70217869268"}
0005432604989	76AD44	7633 699192	LIDIYA VOROBEVA	{"phone": "+70331888976"}
0005432604990	910FB4	4819 258723	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.a_04051971@postgrespro.ru", "phone": "+70915468828"}
0005432604991	910FB4	1125 913857	ARTEMIY EGOROV	{"email": "egorovartemiy.1965@postgrespro.ru", "phone": "+70520446296"}
0005432604992	C03BC3	8153 355707	ARTEM NOVIKOV	{"phone": "+70247299136"}
0005432604993	577191	9233 434085	OKSANA LAZAREVA	{"email": "lazareva-oksana_031970@postgrespro.ru", "phone": "+70529720661"}
0005432604994	052B5D	1819 644606	ELENA KISELEVA	{"email": "kiseleva.e-21031955@postgrespro.ru", "phone": "+70286406584"}
0005432604995	052B5D	7152 573505	VALENTINA NIKITINA	{"email": "vnikitina_1973@postgrespro.ru", "phone": "+70747247571"}
0005432604996	EE0014	8401 235133	EVGENIY GERASIMOV	{"email": "evgeniy-gerasimov-111970@postgrespro.ru", "phone": "+70058371249"}
0005432604997	9D9F1F	8797 478328	EKATERINA TIMOFEEVA	{"email": "e.timofeeva-121980@postgrespro.ru", "phone": "+70762357759"}
0005432604998	14C34E	5257 565157	GRIGORIY KUZMIN	{"email": "grigoriy_kuzmin-23021970@postgrespro.ru", "phone": "+70721342082"}
0005432605111	2FE2B5	2126 148412	VALENTINA KOMAROVA	{"phone": "+70613332750"}
0005432604999	A8340E	8026 425230	MARIYA AFANASEVA	{"email": "m.afanaseva-1977@postgrespro.ru", "phone": "+70814053780"}
0005432605000	AF4CC3	8021 305545	EVGENIY EGOROV	{"phone": "+70479019692"}
0005432605001	AF4CC3	0113 248034	VIOLETTA KAZAKOVA	{"phone": "+70923684395"}
0005432605002	81CEBD	0705 457748	OLEG SOKOLOV	{"phone": "+70276571065"}
0005432605003	81CEBD	1539 465723	KIRILL VASILEV	{"email": "vasilevk_1965@postgrespro.ru", "phone": "+70499360985"}
0005432605004	EF3266	0634 117000	MARIYA KOMAROVA	{"phone": "+70500245416"}
0005432605005	7189A3	2152 665037	GALINA ZAKHAROVA	{"phone": "+70079638396"}
0005432605006	7189A3	9380 173170	EVGENIY TIKHONOV	{"phone": "+70405042446"}
0005432605007	EDDDBE	8033 843734	LYUDMILA RODIONOVA	{"email": "l_rodionova.30061975@postgrespro.ru", "phone": "+70459347149"}
0005432605008	B8A260	5245 963365	VLADIMIR MARTYNOV	{"phone": "+70021639502"}
0005432605009	A95414	0144 575969	ALEKSEY ALEKSANDROV	{"email": "a-aleksandrov_081976@postgrespro.ru", "phone": "+70771515982"}
0005432605010	0A3D56	5736 080796	EKATERINA YUDINA	{"email": "yudinaekaterina_08091988@postgrespro.ru", "phone": "+70116598642"}
0005432605011	2C265F	2679 042211	NIKOLAY MAKAROV	{"email": "makarov-n04021969@postgrespro.ru", "phone": "+70456583299"}
0005432605012	9F7D41	8517 490519	ALEKSANDR SEMENOV	{"phone": "+70495658256"}
0005432605013	E425E1	1719 664440	OLESYA GERASIMOVA	{"phone": "+70897960030"}
0005432605014	F36CA7	7585 383461	LIDIYA GRISHINA	{"email": "lidiya-grishina1964@postgrespro.ru", "phone": "+70464653312"}
0005432605015	A41716	8566 227958	VALERIY NIKOLAEV	{"phone": "+70924977263"}
0005432605016	A41716	7566 336095	ZOYA MAKSIMOVA	{"phone": "+70172126950"}
0005432605017	A41716	1210 710584	DARYA MARTYNOVA	{"phone": "+70399290078"}
0005432605018	269769	4722 285096	MIKHAIL IVANOV	{"email": "m.ivanov-1973@postgrespro.ru", "phone": "+70423833464"}
0005432605019	269769	5253 000843	VIKTORIYA KRASNOVA	{"email": "v.krasnova041978@postgrespro.ru", "phone": "+70934340027"}
0005432605020	9E37A6	2240 145223	NIKOLAY VASILEV	{"phone": "+70671038569"}
0005432605021	FD5F8F	0232 622074	OLGA POPOVA	{"email": "popova_o_22091977@postgrespro.ru", "phone": "+70363019894"}
0005432605022	3C3676	9151 752839	ARTEM ZAYCEV	{"phone": "+70052344733"}
0005432605023	9A6C57	5799 729476	TATYANA CHERNOVA	{"phone": "+70408152696"}
0005432605024	0234DE	2773 425901	EVGENIY VOLKOV	{"email": "evgeniyvolkov_1968@postgrespro.ru", "phone": "+70479858217"}
0005432605025	60D2D6	8448 591302	MIKHAIL MAKAROV	{"phone": "+70024572748"}
0005432605026	698C7F	2118 406636	IGOR SMIRNOV	{"email": "i.smirnov.1975@postgrespro.ru", "phone": "+70682857391"}
0005432605027	698C7F	9795 836381	VALENTINA NAZAROVA	{"email": "valentinanazarova.111968@postgrespro.ru", "phone": "+70997636495"}
0005432605028	784A46	2067 057267	ANASTASIYA NAZAROVA	{"phone": "+70866157323"}
0005432605029	8135B3	9274 746178	ARKADIY VASILEV	{"email": "arkadiy_vasilev.13121976@postgrespro.ru", "phone": "+70611829092"}
0005432605030	8135B3	8141 993230	LYUDMILA BORISOVA	{"email": "lborisova_23081964@postgrespro.ru", "phone": "+70887773387"}
0005432605031	16115C	4873 997784	EVGENIYA GERASIMOVA	{"email": "evgeniyagerasimova1981@postgrespro.ru", "phone": "+70078113441"}
0005432605032	97ABAB	4968 657949	TATYANA KUZMINA	{"email": "t_kuzmina_30111977@postgrespro.ru", "phone": "+70848289485"}
0005432605033	E5A316	0961 600483	SERGEY GORBUNOV	{"phone": "+70118934665"}
0005432605034	B9A527	2659 361521	TATYANA POLYAKOVA	{"phone": "+70218181915"}
0005432605035	7786F6	6780 396499	IVAN MATVEEV	{"phone": "+70850924097"}
0005432605036	EF93DE	9189 301725	STEPAN KULIKOV	{"phone": "+70411519982"}
0005432605037	EF93DE	3020 423098	ANDREY KULIKOV	{"email": "andrey_kulikov_1963@postgrespro.ru", "phone": "+70213308218"}
0005432605038	EF93DE	0408 616096	VALENTINA FEDOROVA	{"email": "vfedorova_1970@postgrespro.ru", "phone": "+70460647330"}
0005432605039	9408CF	3703 766566	DIANA ZAYCEVA	{"email": "d-zayceva15091963@postgrespro.ru", "phone": "+70489976961"}
0005432605040	B3E83E	4550 246773	EKATERINA ZAKHAROVA	{"phone": "+70265288950"}
0005432605041	420F33	8819 000463	SVETLANA SEMENOVA	{"phone": "+70417509615"}
0005432605042	883370	6670 360856	NIKITA MOROZOV	{"email": "morozov-n.08031975@postgrespro.ru", "phone": "+70909487259"}
0005432605043	883370	2432 068053	LARISA SIDOROVA	{"phone": "+70263632594"}
0005432605044	D31AB3	5165 492671	GALIYA ZAKHAROVA	{"phone": "+70139828124"}
0005432605045	DBABCF	9433 601749	NADEZHDA VASILEVA	{"email": "nadezhda-vasileva-061967@postgrespro.ru", "phone": "+70907752943"}
0005432605046	521A12	1358 093837	GALINA ANISIMOVA	{"email": "ganisimova_1986@postgrespro.ru", "phone": "+70248370586"}
0005432605047	521A12	5069 651307	VALERIY FILIPPOV	{"phone": "+70503714716"}
0005432605048	E3DA51	0483 321460	MAKSIM DENISOV	{"email": "m_denisov-01021974@postgrespro.ru", "phone": "+70214583624"}
0005432605049	DB4B07	2169 373708	MARIYA EGOROVA	{"email": "mariya_egorova_28041986@postgrespro.ru", "phone": "+70471837178"}
0005432605050	DB4B07	9226 053648	VIKTOR MELNIKOV	{"email": "melnikovviktor.041968@postgrespro.ru", "phone": "+70007313829"}
0005432605051	B4DF00	5881 155528	LYUDMILA TIKHONOVA	{"email": "tikhonovalyudmila1969@postgrespro.ru", "phone": "+70930451711"}
0005432605052	C90094	9009 246717	ANATOLIY ISAEV	{"email": "isaev-anatoliy.041971@postgrespro.ru", "phone": "+70323941475"}
0005432605053	C07EEF	1650 115523	VERA POLYAKOVA	{"phone": "+70522280393"}
0005432605054	57888B	0225 705500	ELENA KOROLEVA	{"phone": "+70846946988"}
0005432605055	7C8EA7	5107 442392	ELENA YUDINA	{"email": "elena.yudina.14091971@postgrespro.ru", "phone": "+70143123933"}
0005432605056	20DCE0	8064 843516	YULIYA POPOVA	{"email": "y.popova.1958@postgrespro.ru", "phone": "+70474809112"}
0005432605057	4F88A5	3003 708686	MARINA IVANOVA	{"email": "ivanova_m-03041982@postgrespro.ru", "phone": "+70194863548"}
0005432605058	702449	1170 786731	VITALIY GUSEV	{"email": "vitaliygusev.1971@postgrespro.ru", "phone": "+70460321507"}
0005432605059	63C82E	0989 633676	ZINAIDA GUSEVA	{"phone": "+70704689272"}
0005432605060	0995B0	5088 401744	SERGEY VOLKOV	{"email": "volkov_s061967@postgrespro.ru", "phone": "+70421144824"}
0005432605061	C71C84	1161 566600	ALEFTINA POPOVA	{"phone": "+70342042754"}
0005432605062	75E948	0328 940885	DMITRIY POPOV	{"phone": "+70104737728"}
0005432605063	FE2A5C	6270 119268	DARYA ANDREEVA	{"phone": "+70740384221"}
0005432605064	7CB918	2528 860449	VLADIMIR MOISEEV	{"email": "moiseevvladimir16091981@postgrespro.ru", "phone": "+70740910550"}
0005432605065	759ECD	8755 145129	OLGA TARASOVA	{"email": "tarasova.olga16101977@postgrespro.ru", "phone": "+70736143612"}
0005432605066	38C530	3774 337780	IRINA VLASOVA	{"email": "ivlasova.021974@postgrespro.ru", "phone": "+70084115345"}
0005432605067	2DE09B	9404 150627	VIKTOR EGOROV	{"email": "vegorov_22081969@postgrespro.ru", "phone": "+70283897315"}
0005432605068	C9EE99	5404 266355	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr_031978@postgrespro.ru", "phone": "+70302568248"}
0005432605069	60D432	4002 633856	LYUBOV RODIONOVA	{"email": "rodionovalyubov08071964@postgrespro.ru", "phone": "+70602995328"}
0005432605070	57774E	1806 947386	SERGEY KUZNECOV	{"phone": "+70401241516"}
0005432605071	89B6C2	7247 000949	MARIYA SMIRNOVA	{"email": "smirnova.mariya27101971@postgrespro.ru", "phone": "+70781467533"}
0005432605072	89B6C2	1388 845477	ELENA BARANOVA	{"phone": "+70947696860"}
0005432605073	BAE445	6519 193462	ARTEM GERASIMOV	{"email": "artemgerasimov_1977@postgrespro.ru", "phone": "+70103196908"}
0005432605074	199357	3152 994519	MAKSIM CHERNOV	{"email": "chernovm_04121961@postgrespro.ru", "phone": "+70822980879"}
0005432605075	199357	2797 888023	TAMARA KUZNECOVA	{"phone": "+70233929930"}
0005432605076	D1664B	5341 134935	VITALIY YAKOVLEV	{"phone": "+70547872126"}
0005432605077	1DDED6	4995 676033	NIKOLAY VASILEV	{"email": "nikolayvasilev061967@postgrespro.ru", "phone": "+70896387440"}
0005432605078	1DDED6	8704 559495	YURIY FROLOV	{"phone": "+70130449713"}
0005432605079	CDD814	4393 641683	VLADIMIR ZHUKOV	{"email": "v.zhukov021975@postgrespro.ru", "phone": "+70682514124"}
0005432605080	DF5948	6330 707154	DENIS MATVEEV	{"email": "matveev-denis-21121976@postgrespro.ru", "phone": "+70871482628"}
0005432605081	DF5948	8564 040321	TATYANA SOKOLOVA	{"phone": "+70606816554"}
0005432605082	DF5948	1104 989192	IGOR ZHUKOV	{"email": "i_zhukov.041965@postgrespro.ru", "phone": "+70060716442"}
0005432605083	2FB80E	1336 296801	NATALYA ABRAMOVA	{"email": "abramova-natalya-09071975@postgrespro.ru", "phone": "+70800387645"}
0005432605084	2FB80E	9507 073725	VALERIY IVANOV	{"email": "ivanov_valeriy19081975@postgrespro.ru", "phone": "+70744835310"}
0005432605085	2FB80E	8851 498562	ANTONINA SOROKINA	{"phone": "+70463513184"}
0005432605086	B39842	1446 719036	ALEKSEY GAVRILOV	{"phone": "+70049844423"}
0005432605087	183B63	0884 303634	STEPAN ALEKSEEV	{"phone": "+70618676448"}
0005432605088	657E55	7563 502466	ELIZAVETA TIKHONOVA	{"phone": "+70616354287"}
0005432605089	657E55	2959 348458	MARIYA CHERNOVA	{"phone": "+70997414029"}
0005432605090	657E55	1052 017595	VYACHESLAV EGOROV	{"phone": "+70773864929"}
0005432605091	46815D	1663 067159	SVETLANA STEPANOVA	{"phone": "+70934538246"}
0005432605092	52CC0E	7519 704345	MIKHAIL NAUMOV	{"email": "mnaumov27051980@postgrespro.ru", "phone": "+70404492294"}
0005432605093	52CC0E	3407 575152	ELENA ORLOVA	{"phone": "+70271864950"}
0005432605094	D389AF	0811 999824	DMITRIY FEDOROV	{"email": "dmitriy-fedorov.101978@postgrespro.ru", "phone": "+70984694222"}
0005432605095	D389AF	9980 426369	SERGEY RODIONOV	{"email": "sergeyrodionov-04011968@postgrespro.ru", "phone": "+70139580933"}
0005432605096	294A83	5137 646851	ALEKSANDR MOISEEV	{"phone": "+70568837438"}
0005432605097	294A83	8205 842318	ALEKSANDR SOROKIN	{"phone": "+70980203191"}
0005432605098	C40EA5	1526 581975	ZINAIDA EGOROVA	{"email": "zinaidaegorova_1985@postgrespro.ru", "phone": "+70179398160"}
0005432605099	C40EA5	5982 278794	EKATERINA VOLKOVA	{"phone": "+70435255009"}
0005432605100	20B4F9	8222 999192	NADEZHDA SERGEEVA	{"phone": "+70165525720"}
0005432605101	2649BD	1298 076408	GALINA BARANOVA	{"email": "baranovagalina_1986@postgrespro.ru", "phone": "+70930930806"}
0005432605102	F48903	8051 016876	TATYANA KOROLEVA	{"email": "tatyana_koroleva-1962@postgrespro.ru", "phone": "+70361359839"}
0005432605103	20F1FF	4089 527207	IRINA ABRAMOVA	{"email": "irina.abramova11091968@postgrespro.ru", "phone": "+70337814149"}
0005432605104	8C0F8A	5857 278420	ELENA KARPOVA	{"email": "elena.karpova_18101971@postgrespro.ru", "phone": "+70431994776"}
0005432605105	8C0F8A	8259 979426	YULIYA NIKOLAEVA	{"email": "nikolaeva-yuliya_1968@postgrespro.ru", "phone": "+70991113843"}
0005432605106	8C0F8A	3816 084024	ELENA ANISIMOVA	{"phone": "+70585059950"}
0005432605107	D3390F	0266 454795	YULIYA MIKHAYLOVA	{"phone": "+70648507356"}
0005432605108	E43ECC	9610 296737	VALERIY VOROBEV	{"email": "vvorobev_041981@postgrespro.ru", "phone": "+70025508326"}
0005432605109	7F379B	5364 838161	TATYANA ANTONOVA	{"email": "tatyanaantonova-011974@postgrespro.ru", "phone": "+70592020538"}
0005432605110	2FE2B5	2620 417121	ZOYA KUZMINA	{"email": "z_kuzmina-021971@postgrespro.ru", "phone": "+70451306056"}
0005432605112	7F037D	8719 813184	ARTEM ZAYCEV	{"phone": "+70595219498"}
0005432605113	7F037D	5509 599216	SERGEY KUZMIN	{"email": "kuzmin_sergey-041968@postgrespro.ru", "phone": "+70188994992"}
0005432605114	68EDB8	4457 825024	ALEKSEY BONDARENKO	{"email": "bondarenko-a_1968@postgrespro.ru", "phone": "+70165040248"}
0005432605115	BCE77D	4293 585279	EVGENIYA EGOROVA	{"phone": "+70177385620"}
0005432605116	B02ED0	1871 761897	IGOR MARTYNOV	{"phone": "+70254369753"}
0005432605117	CEA0B1	1642 311462	ALEKSEY BORISOV	{"phone": "+70661366287"}
0005432605118	2CAC3B	9247 238041	LEONID SERGEEV	{"email": "l.sergeev.14011971@postgrespro.ru", "phone": "+70170764190"}
0005432605119	101E26	5913 092121	RINAT KOROLEV	{"email": "korolev.rinat.27051976@postgrespro.ru", "phone": "+70319171154"}
0005432605120	B01D76	9374 705114	VALENTINA PAVLOVA	{"email": "valentina_pavlova.07091964@postgrespro.ru", "phone": "+70789332725"}
0005432605121	E1CD2D	2502 509979	SERGEY FILIPPOV	{"email": "filippov.s.12061969@postgrespro.ru", "phone": "+70911474763"}
0005432605122	E1CD2D	4985 752275	VASILIY SERGEEV	{"phone": "+70810538271"}
0005432605123	A595E0	4845 775938	GALINA MOISEEVA	{"email": "moiseeva.galina021971@postgrespro.ru", "phone": "+70016496480"}
0005432605124	B4C6FB	3795 105734	SERGEY ROMANOV	{"email": "sergey.romanov26071973@postgrespro.ru", "phone": "+70159249944"}
0005432605125	612F40	2127 875080	ALEKSANDR DENISOV	{"email": "aleksandr-denisov-121969@postgrespro.ru", "phone": "+70394792558"}
0005432605126	612F40	3384 349825	ELENA ZHURAVLEVA	{"email": "zhuravleva_e051966@postgrespro.ru", "phone": "+70152600826"}
0005432605127	F2FBD0	1901 681942	ANNA KUZMINA	{"email": "a_kuzmina_1981@postgrespro.ru", "phone": "+70469063523"}
0005432605128	5BB48F	2990 352691	SERGEY SOLOVEV	{"phone": "+70010249241"}
0005432605129	06B7FD	2595 622644	PETR ALEKSEEV	{"phone": "+70599137869"}
0005432605130	06B7FD	3629 392560	NATALIYA VOLKOVA	{"phone": "+70116478379"}
0005432605131	06B7FD	9382 996320	SERGEY POPOV	{"phone": "+70698598372"}
0005432605132	A92F7B	5662 627090	PAVEL STEPANOV	{"email": "pavelstepanov-101971@postgrespro.ru", "phone": "+70368801258"}
0005432605133	F07BBF	8614 564413	VALENTINA NIKOLAEVA	{"phone": "+70907953419"}
0005432605134	9C506E	7582 537410	ALEKSEY KONOVALOV	{"email": "konovalov_a_1960@postgrespro.ru", "phone": "+70710261168"}
0005432605135	8B42DB	7138 294008	VERA MEDVEDEVA	{"phone": "+70886619301"}
0005432605136	8B42DB	0262 330299	ANASTASIYA ANDREEVA	{"phone": "+70821718648"}
0005432605137	F31A3E	4858 423219	DAMIR ROMANOV	{"phone": "+70224532423"}
0005432605138	618695	0775 394884	POLINA KAZAKOVA	{"email": "p-kazakova-041958@postgrespro.ru", "phone": "+70680353668"}
0005432605139	7729AB	8629 295359	LIDIYA NIKOLAEVA	{"email": "nikolaeval_1985@postgrespro.ru", "phone": "+70386043831"}
0005432605140	28F425	1305 561002	ELENA AKIMOVA	{"phone": "+70486078788"}
0005432605141	A161EE	1806 759933	ALEKSANDR KUZMIN	{"email": "kuzmin-a101968@postgrespro.ru", "phone": "+70262833769"}
0005432605142	A161EE	4120 279821	ELENA DAVYDOVA	{"phone": "+70189754767"}
0005432605143	704FB2	8597 743287	ASIYA VASILEVA	{"email": "vasilevaa.05041969@postgrespro.ru", "phone": "+70059559142"}
0005432605144	704FB2	7643 330908	ANDREY PAVLOV	{"email": "pavlova111968@postgrespro.ru", "phone": "+70095222677"}
0005432605145	607D3B	6603 935869	ELENA BORISOVA	{"phone": "+70079360613"}
0005432605146	607D3B	7803 314217	SERGEY ZAKHAROV	{"email": "zakharov_sergey-1977@postgrespro.ru", "phone": "+70529740267"}
0005432605147	F115CC	9470 255750	ELENA ZHUKOVA	{"phone": "+70057562692"}
0005432605148	FCCF74	3467 859180	IGOR ABRAMOV	{"email": "abramov_i.20071971@postgrespro.ru", "phone": "+70251887211"}
0005432605149	87C8CB	9853 765625	SERGEY ORLOV	{"email": "orlov-sergey_041967@postgrespro.ru", "phone": "+70501026913"}
0005432605150	87C8CB	0738 906853	PLATON KISELEV	{"email": "platon-kiselev.041983@postgrespro.ru", "phone": "+70863547514"}
0005432605151	87C8CB	2203 158990	ELENA POLYAKOVA	{"email": "polyakova-e-06021964@postgrespro.ru", "phone": "+70174192155"}
0005432605152	5DFB22	8846 529902	TATYANA NAZAROVA	{"email": "nazarova.t.091982@postgrespro.ru", "phone": "+70458026209"}
0005432605153	5DFB22	2524 758667	EVGENIYA EGOROVA	{"phone": "+70533596207"}
0005432605154	5DFB22	4351 943392	MARINA PETROVA	{"phone": "+70705965624"}
0005432605155	01DE4E	9194 678915	OLGA POPOVA	{"email": "popova.olga1971@postgrespro.ru", "phone": "+70042613887"}
0005432605156	71DDA5	9700 521523	ALEKSANDR ABRAMOV	{"phone": "+70928330120"}
0005432605157	0D2435	4394 344098	LIDIYA GUSEVA	{"email": "guseval-091971@postgrespro.ru", "phone": "+70082422711"}
0005432605158	EAD76D	4601 320821	GALINA DENISOVA	{"phone": "+70052082056"}
0005432605159	EAD76D	5171 103549	ANDREY GERASIMOV	{"email": "a_gerasimov_1975@postgrespro.ru", "phone": "+70717944664"}
0005432605160	EAD76D	6290 641848	PAVEL PETROV	{"email": "petrov.p_111968@postgrespro.ru", "phone": "+70437482105"}
0005432605161	2E7C36	2787 027682	LYUBOV DAVYDOVA	{"email": "lyubov_davydova-08081969@postgrespro.ru", "phone": "+70510729206"}
0005432605162	8D9836	1270 367285	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_09101968@postgrespro.ru", "phone": "+70733830782"}
0005432605163	8D9836	2105 852485	GULNARA KUDRYASHOVA	{"phone": "+70575517271"}
0005432605164	8D9836	4813 936480	MARGARITA VOROBEVA	{"email": "m.vorobeva31051970@postgrespro.ru", "phone": "+70074872753"}
0005432605165	F1CB76	3234 834815	ANDREY NOVIKOV	{"phone": "+70742948535"}
0005432605166	F05613	2694 833709	NIKOLAY KONOVALOV	{"email": "konovalovnikolay.021965@postgrespro.ru", "phone": "+70460587218"}
0005432605167	F05613	4639 140507	ALEKSANDR IVANOV	{"phone": "+70567407404"}
0005432605168	090D07	4683 390272	ALEKSANDR EGOROV	{"email": "a-egorov.1959@postgrespro.ru", "phone": "+70128193457"}
0005432605169	E1B97C	3300 431141	ELENA KRASNOVA	{"email": "elena_krasnova10031970@postgrespro.ru", "phone": "+70443934865"}
0005432605170	2854B2	0348 881438	ALEKSEY SOROKIN	{"phone": "+70220043565"}
0005432605171	B7752D	0948 420635	ARINA MIKHAYLOVA	{"email": "arina-mikhaylova-06041980@postgrespro.ru", "phone": "+70025015940"}
0005432605172	FE42E1	6105 986731	OKSANA CHERNOVA	{"phone": "+70151391277"}
0005432605173	FE42E1	9523 933387	TATYANA MAKAROVA	{"phone": "+70281392797"}
0005432605174	FE42E1	9753 434407	PAVEL NOVIKOV	{"email": "p.novikov03051969@postgrespro.ru", "phone": "+70961878920"}
0005432605175	746CF1	7570 327828	SVETLANA SOKOLOVA	{"email": "s_sokolova12061976@postgrespro.ru", "phone": "+70235596685"}
0005432605176	746CF1	5172 105166	MIKHAIL ILIN	{"email": "ilin_m1967@postgrespro.ru", "phone": "+70124012368"}
0005432605177	BD2438	3611 326213	YULIYA KALININA	{"phone": "+70781301148"}
0005432605178	F9B22D	2479 332866	VERA FROLOVA	{"email": "v.frolova.1973@postgrespro.ru", "phone": "+70227019378"}
0005432605179	AD4C3A	4322 297819	SERGEY STEPANOV	{"phone": "+70168552610"}
0005432605180	97675D	8242 811720	NATALYA GORBUNOVA	{"phone": "+70716318999"}
0005432605181	62FB5C	1140 432821	VLADIMIR DAVYDOV	{"email": "vladimir.davydov.1967@postgrespro.ru", "phone": "+70170297989"}
0005432605182	F956C8	9804 888151	LYUBOV LEBEDEVA	{"email": "l-lebedeva.1962@postgrespro.ru", "phone": "+70465444693"}
0005432605183	F956C8	7844 037988	EKATERINA KOROLEVA	{"email": "koroleva-e18031977@postgrespro.ru", "phone": "+70105957551"}
0005432605184	9D8183	5592 070331	VLADISLAV MARTYNOV	{"email": "martynov.v_1972@postgrespro.ru", "phone": "+70086363973"}
0005432605185	DA313B	0744 543040	MARIYA DAVYDOVA	{"email": "mariya-davydova_1975@postgrespro.ru", "phone": "+70756748590"}
0005432605186	DA313B	0582 547806	IVAN YAKOVLEV	{"email": "i-yakovlev-1983@postgrespro.ru", "phone": "+70985149070"}
0005432605187	92B487	5737 802953	ELENA PETROVA	{"email": "petrova.elena-17091965@postgrespro.ru", "phone": "+70726611606"}
0005432605188	92B487	8918 822806	TAMARA KONOVALOVA	{"email": "t.konovalova-1980@postgrespro.ru", "phone": "+70762653861"}
0005432605189	EED034	8041 022349	NIKOLAY SHEVCHENKO	{"email": "n-shevchenko_15031968@postgrespro.ru", "phone": "+70444097779"}
0005432605190	A16AD7	8472 657863	GLEB FEDOTOV	{"email": "gleb-fedotov-1968@postgrespro.ru", "phone": "+70849356691"}
0005432605191	0682C9	4989 571576	EVGENIY CHERNOV	{"phone": "+70353453313"}
0005432605192	0682C9	5742 234817	ANNA GAVRILOVA	{"phone": "+70651897626"}
0005432605193	FD4562	5737 739745	NADEZHDA MOROZOVA	{"phone": "+70586989806"}
0005432605194	0180D3	0244 181010	NATALYA NIKITINA	{"email": "n_nikitina-1981@postgrespro.ru", "phone": "+70681494707"}
0005432605195	678405	7010 104435	RUDOLF FEDOROV	{"email": "fedorov-rudolf16081967@postgrespro.ru", "phone": "+70936054242"}
0005432605196	678405	7938 267719	KIRILL STEPANOV	{"email": "k-stepanov-23111972@postgrespro.ru", "phone": "+70248152854"}
0005432605197	00673C	6773 086453	ILYA KARPOV	{"email": "ilya_karpov-25091965@postgrespro.ru", "phone": "+70381338661"}
0005432605198	00673C	3556 828897	ELENA DENISOVA	{"phone": "+70031583280"}
0005432605199	BD1A51	0419 212809	MARINA IVANOVA	{"email": "marina_ivanova.21011974@postgrespro.ru", "phone": "+70448342645"}
0005432605200	9553AE	5958 946728	VLADIMIR SMIRNOV	{"phone": "+70401372836"}
0005432605201	9553AE	9914 321679	KSENIYA SERGEEVA	{"phone": "+70342521442"}
0005432605202	C87C45	2686 196802	SERGEY CHERNOV	{"phone": "+70510255012"}
0005432605203	A0008F	2901 037135	VLADIMIR MEDVEDEV	{"email": "medvedevvladimir.031964@postgrespro.ru", "phone": "+70441942716"}
0005432605204	D8C160	4940 838772	SOFYA KOVALEVA	{"phone": "+70929148714"}
0005432605205	28E8A8	8166 106912	VITALIY TIMOFEEV	{"phone": "+70959901542"}
0005432605206	28E8A8	3233 231453	ALENA PAVLOVA	{"email": "pavlova-alena_13061974@postgrespro.ru", "phone": "+70255952810"}
0005432605207	28E8A8	9683 117402	NINA FROLOVA	{"phone": "+70562695620"}
0005432605208	28E8A8	5754 389382	NATALYA NESTEROVA	{"email": "nesterovan-051974@postgrespro.ru", "phone": "+70928247094"}
0005432605209	9F283E	9099 934655	ANZHELIKA TIMOFEEVA	{"phone": "+70717438643"}
0005432605210	9F283E	6931 472560	MARIYA NOVIKOVA	{"phone": "+70986037571"}
0005432605211	CC5DBB	4320 790792	NADEZHDA VOLKOVA	{"phone": "+70218819754"}
0005432605212	CC5DBB	8464 594059	NIKOLAY RODIONOV	{"phone": "+70683645336"}
0005432605213	30A2AE	4426 118459	EVGENIY VASILEV	{"phone": "+70425278876"}
0005432605214	30A2AE	9213 167765	LIDIYA ALEKSEEVA	{"phone": "+70119592994"}
0005432605215	631667	1775 000639	TATYANA POLYAKOVA	{"phone": "+70762337588"}
0005432605216	B00D56	6444 244788	MARIYA SCHERBAKOVA	{"email": "scherbakova-mariya09071976@postgrespro.ru", "phone": "+70145710242"}
0005432605217	7F03ED	7191 089397	RUSLAN KUZNECOV	{"phone": "+70852330884"}
0005432605218	7F03ED	1702 633636	LYUDMILA SOROKINA	{"email": "l.sorokina_1966@postgrespro.ru", "phone": "+70388414377"}
0005432605219	BE0A35	4352 089676	ELENA GAVRILOVA	{"email": "elena_gavrilova12101979@postgrespro.ru", "phone": "+70138008268"}
0005432605220	E1EBE9	2285 913063	NINA SOROKINA	{"phone": "+70926320600"}
0005432605221	E1EBE9	4092 561343	MARIYA KUZNECOVA	{"phone": "+70191344411"}
0005432605222	E1EBE9	9108 127303	YURIY ZAKHAROV	{"email": "zakharovyuriy.1962@postgrespro.ru", "phone": "+70592173557"}
0005432605223	1DAA1A	8786 193087	RAISA NIKITINA	{"phone": "+70051354502"}
0005432605224	75C67E	4938 268296	KRISTINA KONDRATEVA	{"phone": "+70439301607"}
0005432605225	ED3116	0196 015787	VLADIMIR KRASNOV	{"phone": "+70873527656"}
0005432605226	ED3116	4078 651992	ANASTASIYA ISAEVA	{"phone": "+70774775511"}
0005432605227	ED3116	1623 394040	VITALIY GRIGOREV	{"phone": "+70906619119"}
0005432605228	DBB1CB	2590 431032	LYUBOV PETROVA	{"phone": "+70412187894"}
0005432605229	DBB1CB	2934 988134	ELENA NIKOLAEVA	{"email": "nikolaeva.e_091971@postgrespro.ru", "phone": "+70586625739"}
0005432605230	DBB1CB	2415 867708	VLADIMIR VLASOV	{"phone": "+70754922382"}
0005432605231	CDA98A	1070 600900	ANASTASIYA KUZMINA	{"phone": "+70292023532"}
0005432605232	CDA98A	0226 276212	ALEVTINA NESTEROVA	{"phone": "+70114752007"}
0005432605233	B24A7C	7303 246801	ALEKSANDR MAKAROV	{"email": "makarova.081964@postgrespro.ru", "phone": "+70401426738"}
0005432605234	B24A7C	8139 146666	VALERIY NIKOLAEV	{"phone": "+70965496844"}
0005432605235	3B6CEA	8353 902878	ANATOLIY KUZNECOV	{"phone": "+70043179172"}
0005432605236	1813E9	8652 188745	PAVEL IVANOV	{"email": "ivanov-pavel.29061976@postgrespro.ru", "phone": "+70368754162"}
0005432605237	1813E9	6405 425679	GENNADIY NIKITIN	{"phone": "+70101545245"}
0005432605238	40876D	3996 201902	VLADISLAV ZHURAVLEV	{"phone": "+70238192748"}
0005432605239	CEC6C5	5251 212972	LYUBOV POPOVA	{"email": "popovalyubov_051960@postgrespro.ru", "phone": "+70308047202"}
0005432605240	061702	4346 452261	GALINA ALEKSANDROVA	{"email": "aleksandrova.galina.1976@postgrespro.ru", "phone": "+70325966495"}
0005432605241	061702	3269 090895	VASILISA POTAPOVA	{"email": "potapova_vasilisa1970@postgrespro.ru", "phone": "+70285506876"}
0005432605242	293879	9400 045995	ALBINA SAVELEVA	{"phone": "+70613989238"}
0005432605243	293879	5407 306957	SERGEY ANDREEV	{"email": "andreev_s041975@postgrespro.ru", "phone": "+70839096686"}
0005432605244	AF73BB	3629 236128	OLESYA MIKHAYLOVA	{"email": "omikhaylova-121968@postgrespro.ru", "phone": "+70880045901"}
0005432605245	13F452	1366 469365	SANIYA KARPOVA	{"email": "karpova_saniya_1968@postgrespro.ru", "phone": "+70928572526"}
0005432605246	A4971B	7949 727748	IGOR SERGEEV	{"phone": "+70656900211"}
0005432605247	657CFA	5515 689011	ANNA NAZAROVA	{"email": "anazarova-1983@postgrespro.ru", "phone": "+70467292896"}
0005432605248	657CFA	4336 639573	LYUBOV SMIRNOVA	{"email": "lyubov-smirnova.1971@postgrespro.ru", "phone": "+70990359740"}
0005432605249	0C8C91	6431 352948	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir_1984@postgrespro.ru", "phone": "+70692976796"}
0005432605250	0C8C91	4514 487944	LYUBOV NIKOLAEVA	{"email": "nikolaeval.021977@postgrespro.ru", "phone": "+70127963336"}
0005432605251	0C8C91	0317 079865	TATYANA MOROZOVA	{"phone": "+70436668387"}
0005432605252	C42F66	9852 548509	VITALIY FEDOROV	{"email": "v_fedorov-22111969@postgrespro.ru", "phone": "+70733205731"}
0005432605253	C42F66	1245 232938	YURIY MEDVEDEV	{"phone": "+70499474587"}
0005432605254	E7EA7E	0204 927820	NATALYA TROFIMOVA	{"email": "n.trofimova-26121975@postgrespro.ru", "phone": "+70013111776"}
0005432605255	05EB3C	1270 468728	OKSANA IVANOVA	{"email": "oksana.ivanova_1966@postgrespro.ru", "phone": "+70957167061"}
0005432605256	86DD71	3179 488545	TATYANA EFREMOVA	{"email": "t.efremova.20111964@postgrespro.ru", "phone": "+70469900069"}
0005432605257	B3C810	4347 173682	ALENA IVANOVA	{"phone": "+70992773494"}
0005432605258	938F57	7932 163892	DMITRIY PAVLOV	{"email": "d-pavlov.1973@postgrespro.ru", "phone": "+70150680781"}
0005432605259	880D8B	0869 375484	ELENA EFIMOVA	{"phone": "+70100862139"}
0005432605260	44E64A	4927 659933	ARTUR PETROV	{"phone": "+70840323916"}
0005432605261	400FBC	9373 177974	YANA ZHURAVLEVA	{"phone": "+70831217617"}
0005432605262	400FBC	7205 517118	VERA SAVELEVA	{"phone": "+70283863260"}
0005432605263	BB9B1E	1343 309598	DMITRIY RODIONOV	{"email": "rodionovd041966@postgrespro.ru", "phone": "+70814733645"}
0005432605264	86537A	9353 561756	VALENTINA ROMANOVA	{"email": "valentina-romanova.041965@postgrespro.ru", "phone": "+70369809009"}
0005432605265	7E6D50	1917 626806	MILANA KUZMINA	{"email": "kuzmina_m1965@postgrespro.ru", "phone": "+70498495250"}
0005432605266	7E6D50	4753 766016	TAISIYA MIRONOVA	{"phone": "+70834537794"}
0005432605267	7E6D50	1002 410406	KIRILL NIKITIN	{"email": "kirill-nikitin_101978@postgrespro.ru", "phone": "+70568547406"}
0005432605268	E45084	9870 042458	SVETLANA TARASOVA	{"phone": "+70271364338"}
0005432605269	05BC2D	2725 835044	ZINAIDA KUDRYASHOVA	{"email": "kudryashova_zinaida.041969@postgrespro.ru", "phone": "+70226931749"}
0005432605270	C5262F	8457 091388	OLGA EGOROVA	{"phone": "+70644293729"}
0005432605271	C5262F	4991 410290	LYUBOV TIKHONOVA	{"email": "l-tikhonova.10121962@postgrespro.ru", "phone": "+70400872732"}
0005432605272	DEF2EB	7542 410320	OLGA MOISEEVA	{"phone": "+70070979818"}
0005432605273	DEF2EB	5151 720966	NADEZHDA NAUMOVA	{"phone": "+70477858167"}
0005432605274	1A05A3	9678 641755	YURIY SCHERBAKOV	{"phone": "+70164153893"}
0005432605275	1E1775	5488 586106	MARIYA IVANOVA	{"email": "mariyaivanova.1980@postgrespro.ru", "phone": "+70535079878"}
0005432605276	1E1775	8842 996337	MARIYA KUZMINA	{"email": "kuzmina.m121986@postgrespro.ru", "phone": "+70586585280"}
0005432605277	476C68	8117 043488	SERGEY AFANASEV	{"phone": "+70173563163"}
0005432605278	D99900	6297 100999	NATALYA ILINA	{"email": "ilina_natalya1977@postgrespro.ru", "phone": "+70989677348"}
0005432605279	56ED5B	0260 046722	EKATERINA ABRAMOVA	{"phone": "+70373217928"}
0005432605280	530750	6496 915681	RIMMA ZHUKOVA	{"email": "r.zhukova061970@postgrespro.ru", "phone": "+70816085521"}
0005432605281	B206C0	0545 656423	ANTON MAKSIMOV	{"phone": "+70360124041"}
0005432605282	99290F	3045 429548	IVAN BARANOV	{"phone": "+70946627222"}
0005432605283	9EF51E	0699 106966	ANTONINA KOLESNIKOVA	{"phone": "+70733155970"}
0005432605284	501178	8511 824668	ANTONINA DMITRIEVA	{"email": "dmitrieva.a121972@postgrespro.ru", "phone": "+70787098579"}
0005432605285	4E19E5	7226 317001	KONSTANTIN IVANOV	{"phone": "+70003111106"}
0005432605286	4E19E5	8819 355123	OLGA OSIPOVA	{"phone": "+70220774353"}
0005432605287	4E19E5	8758 997376	RAISA IVANOVA	{"email": "ivanova.r.1970@postgrespro.ru", "phone": "+70524613481"}
0005432605288	4A7F6A	5466 192230	VALENTINA MARTYNOVA	{"phone": "+70735752525"}
0005432605289	4A7F6A	9140 824173	ALEKSANDR SEMENOV	{"phone": "+70812470540"}
0005432605290	892AE5	2458 331125	VLADIMIR TIKHONOV	{"phone": "+70298461537"}
0005432605291	AE67A0	6750 322107	NIKOLAY RODIONOV	{"phone": "+70773759984"}
0005432605292	E80AEE	4852 667816	NIKOLAY VOROBEV	{"email": "n-vorobev071970@postgrespro.ru", "phone": "+70754687693"}
0005432605293	E80AEE	8180 457762	OKSANA DMITRIEVA	{"email": "oksana_dmitrieva071961@postgrespro.ru", "phone": "+70875302495"}
0005432605294	F8EF63	5210 126591	ALINA PAVLOVA	{"email": "pavlovaalina_051972@postgrespro.ru", "phone": "+70836179727"}
0005432605295	F8EF63	8625 712916	TATYANA TIKHONOVA	{"phone": "+70548033282"}
0005432605296	3E2C14	4761 395011	IRINA KONOVALOVA	{"phone": "+70035455528"}
0005432605297	85FE10	1277 234122	OLGA KOROLEVA	{"email": "o_koroleva.19091969@postgrespro.ru", "phone": "+70849216198"}
0005432605298	4330B1	4222 579218	DANIIL KOROLEV	{"email": "korolev.daniil.091974@postgrespro.ru", "phone": "+70261984550"}
0005432605299	2AF42D	3763 716039	YULIYA FILIPPOVA	{"email": "filippova_y1968@postgrespro.ru", "phone": "+70582152302"}
0005432605300	2AF42D	0544 552368	YURIY VASILEV	{"phone": "+70137545428"}
0005432605301	23CB06	2305 180499	VYACHESLAV FROLOV	{"email": "frolov-vyacheslav-25031979@postgrespro.ru", "phone": "+70943723287"}
0005432605302	23CB06	0053 586082	GALINA SCHERBAKOVA	{"email": "galinascherbakova_1976@postgrespro.ru", "phone": "+70615566337"}
0005432605303	81748D	2054 232989	OKSANA ERMAKOVA	{"phone": "+70494765748"}
0005432605304	81748D	1738 764436	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr1966@postgrespro.ru", "phone": "+70202145434"}
0005432605305	81748D	6107 847680	SERGEY MIRONOV	{"phone": "+70829356845"}
0005432605306	606BCA	4862 446458	DENIS FEDOTOV	{"email": "fedotov-denis041971@postgrespro.ru", "phone": "+70844723649"}
0005432605307	AA9CCC	1973 585501	TATYANA ILINA	{"email": "tatyana-ilina.28111981@postgrespro.ru", "phone": "+70849477177"}
0005432605308	7EC888	9814 822595	NATALYA TARASOVA	{"email": "tarasova.natalya.09071966@postgrespro.ru", "phone": "+70336367599"}
0005432605309	986F53	8330 708230	YULIYA MAKAROVA	{"phone": "+70512254996"}
0005432605310	986F53	7030 784268	VERA MAKSIMOVA	{"phone": "+70474251045"}
0005432605311	1820E1	8084 669441	ILYA KUZNECOV	{"email": "i.kuznecov-121973@postgrespro.ru", "phone": "+70936097348"}
0005432605312	EE90AD	4378 466729	MARINA KOLESNIKOVA	{"email": "kolesnikova_m111969@postgrespro.ru", "phone": "+70249261221"}
0005432605313	EE90AD	5991 598452	ALEKSEY IVANOV	{"phone": "+70786419141"}
0005432605314	C98176	8964 784385	ELENA MAKSIMOVA	{"phone": "+70343798310"}
0005432605315	9FC0D2	4405 507741	VIKTOR SOROKIN	{"phone": "+70853826351"}
0005432605316	9FC0D2	4020 032177	VALENTINA SEMENOVA	{"phone": "+70723510276"}
0005432605317	ED335B	3014 598022	OLEG SIDOROV	{"phone": "+70882243561"}
0005432605318	ED335B	5986 139297	SERGEY ORLOV	{"email": "orlov_sergey-051971@postgrespro.ru", "phone": "+70172724069"}
0005432605319	457428	9686 139952	IRINA SEMENOVA	{"phone": "+70635489892"}
0005432605320	457428	8601 179791	NATALYA NOVIKOVA	{"email": "n_novikova-061967@postgrespro.ru", "phone": "+70381205435"}
0005432605321	0144C7	0312 130719	TIMOFEY DAVYDOV	{"phone": "+70330516887"}
0005432605322	926CA3	3723 479112	MIKHAIL MIKHAYLOV	{"phone": "+70855583405"}
0005432605323	FF04B3	8400 972270	NADEZHDA VLASOVA	{"phone": "+70486701883"}
0005432605324	FF04B3	4646 855121	ELENA KAZAKOVA	{"phone": "+70822524240"}
0005432605325	D5F577	4508 440080	TATYANA MAKAROVA	{"email": "t-makarova021961@postgrespro.ru", "phone": "+70068194491"}
0005432605326	D5F577	3449 833613	NATALYA IVANOVA	{"phone": "+70381255386"}
0005432605327	BB8976	3371 840453	NIKOLAY MIRONOV	{"phone": "+70941648696"}
0005432605328	BB8976	2165 984020	MIKHAIL KUZMIN	{"email": "kuzminmikhail-111962@postgrespro.ru", "phone": "+70600930103"}
0005432605329	B950C3	3669 108003	ANNA KAZAKOVA	{"phone": "+70948973059"}
0005432605330	C7F565	6188 939327	EKATERINA KOMAROVA	{"email": "e_komarova081961@postgrespro.ru", "phone": "+70841887389"}
0005432605331	C7F565	2060 887046	VALERIY MAKSIMOV	{"email": "vmaksimov-1963@postgrespro.ru", "phone": "+70626841559"}
0005432605332	3E931C	8868 910821	VALENTINA BORISOVA	{"email": "borisova.v.011973@postgrespro.ru", "phone": "+70295815861"}
0005432605333	9A64FA	8147 705697	ELENA KOVALEVA	{"phone": "+70495220376"}
0005432605334	9A64FA	5222 456196	KRISTINA AFANASEVA	{"email": "kristina_afanaseva-05041967@postgrespro.ru", "phone": "+70174809500"}
0005432605335	D178D4	0721 521777	NATALYA GAVRILOVA	{"phone": "+70320312646"}
0005432605336	49A12C	1815 380649	SERGEY MOISEEV	{"email": "moiseev.s-30061963@postgrespro.ru", "phone": "+70050974434"}
0005432605337	C55395	7953 949913	KRISTINA IVANOVA	{"phone": "+70623109017"}
0005432605338	7A146C	2423 903014	VALENTINA KARPOVA	{"email": "valentina-karpova-1969@postgrespro.ru", "phone": "+70172027270"}
0005432605339	A62FB0	6862 598023	ZINAIDA KOMAROVA	{"phone": "+70366435698"}
0005432605340	A62FB0	1997 879966	NINA NESTEROVA	{"phone": "+70723033224"}
0005432605341	A62FB0	9197 478937	IRINA KUZNECOVA	{"email": "kuznecova.i_051968@postgrespro.ru", "phone": "+70329540213"}
0005432605342	507E2F	6991 594555	DENIS MELNIKOV	{"phone": "+70509311060"}
0005432605343	3E35B6	2558 027812	GEORGIY GERASIMOV	{"phone": "+70765011117"}
0005432605344	E99702	7395 098374	ALINA EGOROVA	{"email": "egorova.alina25041976@postgrespro.ru", "phone": "+70543958336"}
0005432605345	296CD6	8986 152475	DENIS ZAKHAROV	{"email": "zakharov_d.06121981@postgrespro.ru", "phone": "+70959616093"}
0005432605346	296CD6	3329 054974	ALEKSANDR GRIGOREV	{"email": "grigorev.a.1971@postgrespro.ru", "phone": "+70156728068"}
0005432605347	DB73B5	9608 741999	SVETLANA IVANOVA	{"phone": "+70846479212"}
0005432605348	F95C44	3994 589411	NADEZHDA KUZMINA	{"email": "kuzminan_1970@postgrespro.ru", "phone": "+70835540755"}
0005432605349	858DD4	6166 724877	NIKOLAY MAKAROV	{"email": "n-makarov1964@postgrespro.ru", "phone": "+70707368173"}
0005432605350	C41A05	2694 560992	SOFYA KUZMINA	{"phone": "+70169210670"}
0005432605351	00AFF6	1236 678803	ELENA GRISHINA	{"email": "elena.grishina_1971@postgrespro.ru", "phone": "+70055660305"}
0005432605352	00AFF6	4589 783491	ALEKSANDR MIRONOV	{"phone": "+70064377440"}
0005432605353	B6DECE	7268 517211	ELENA NIKOLAEVA	{"email": "nikolaeva_e-12091965@postgrespro.ru", "phone": "+70351438341"}
0005432605354	E76E81	4077 265334	LYUBOV POPOVA	{"phone": "+70460390490"}
0005432605355	EC15A3	5069 979719	SOFIYA ALEKSEEVA	{"email": "alekseevas_1978@postgrespro.ru", "phone": "+70162221367"}
0005432605356	6188C1	3393 960592	VALERIY IVANOV	{"phone": "+70046082467"}
0005432605357	4931C3	3822 788445	ANASTASIYA NAUMOVA	{"email": "naumovaa.1971@postgrespro.ru", "phone": "+70678657243"}
0005432605358	4931C3	2184 533218	ALEKSEY MATVEEV	{"email": "matveev_a_02091983@postgrespro.ru", "phone": "+70926975911"}
0005432605359	637B94	7614 579825	ANASTASIYA ALEKSEEVA	{"email": "alekseeva_anastasiya_16011959@postgrespro.ru", "phone": "+70073624587"}
0005432605360	637B94	3257 194769	VALENTINA KOZLOVA	{"email": "valentina-kozlova.021977@postgrespro.ru", "phone": "+70159840917"}
0005432605361	361E5C	1331 558683	ALEKSEY NOVIKOV	{"email": "novikov.aleksey1972@postgrespro.ru", "phone": "+70254859078"}
0005432605362	5D7758	2024 030794	OLGA ZHUKOVA	{"email": "o_zhukova_1973@postgrespro.ru", "phone": "+70420059370"}
0005432605363	9D1306	2825 756848	ALENA FROLOVA	{"phone": "+70782855676"}
0005432605364	9D1306	1390 056885	SERGEY SAVELEV	{"email": "savelev_s-051982@postgrespro.ru", "phone": "+70837381557"}
0005432605365	D56E2B	7260 836167	IVAN KONOVALOV	{"email": "konovalov-i_041963@postgrespro.ru", "phone": "+70530225374"}
0005432605366	3CA3BD	1362 750174	YULIYA KULIKOVA	{"phone": "+70612092082"}
0005432605367	C270CA	4624 219869	VYACHESLAV SEMENOV	{"phone": "+70256075377"}
0005432605368	A4B18F	3044 149881	GENNADIY KUZMIN	{"email": "kuzmin.gennadiy-29081977@postgrespro.ru", "phone": "+70635896459"}
0005432605369	D4A413	7623 373829	ALEKSEY MAKSIMOV	{"phone": "+70153132436"}
0005432605370	600341	9434 315044	ELENA FROLOVA	{"email": "e-frolova.111956@postgrespro.ru", "phone": "+70628330095"}
0005432605371	80C996	0536 254254	OLGA NAZAROVA	{"phone": "+70352477893"}
0005432605372	A945D7	9154 008503	VALERIYA VOLKOVA	{"email": "vvolkova041975@postgrespro.ru", "phone": "+70616011825"}
0005432605373	A945D7	8187 065817	MIKHAIL BORISOV	{"phone": "+70876087075"}
0005432605374	D8674B	0807 923020	ANATOLIY SMIRNOV	{"email": "anatoliy-smirnov.111986@postgrespro.ru", "phone": "+70657515228"}
0005432605375	1D7B81	6516 793243	KLAVDIYA MOISEEVA	{"email": "kmoiseeva.101974@postgrespro.ru", "phone": "+70136957028"}
0005432605376	E357DE	9974 973306	VALENTINA OVCHINNIKOVA	{"email": "valentina-ovchinnikova051985@postgrespro.ru", "phone": "+70108044883"}
0005432605377	E357DE	0730 674957	SERGEY DAVYDOV	{"email": "sergey_davydov-061979@postgrespro.ru", "phone": "+70020115856"}
0005432605378	64E772	8526 140648	VALENTINA YUDINA	{"email": "yudina_v_1981@postgrespro.ru", "phone": "+70148333473"}
0005432605379	64E772	7247 446827	VIKTOR VOLKOV	{"phone": "+70375361284"}
0005432605380	398AFA	6846 865850	TATYANA KOROLEVA	{"email": "korolevat.1973@postgrespro.ru", "phone": "+70793194963"}
0005432605381	398AFA	9378 678978	ALEKSANDR SERGEEV	{"email": "sergeev.aleksandr11051961@postgrespro.ru", "phone": "+70146179217"}
0005432605382	398AFA	2493 708429	KIRILL SIDOROV	{"email": "k.sidorov.28091975@postgrespro.ru", "phone": "+70691851464"}
0005432605383	476037	1398 876597	SERGEY BELOV	{"phone": "+70537491624"}
0005432605384	A162FA	5992 890908	MIKHAIL POPOV	{"email": "popov_mikhail1965@postgrespro.ru", "phone": "+70709538347"}
0005432605385	E7ADD6	9043 175630	TATYANA BELYAEVA	{"phone": "+70719055905"}
0005432605386	E3A5EF	4117 632571	NATALYA SAVELEVA	{"phone": "+70063927995"}
0005432605387	C92DF4	1856 025174	ALEKSANDR GRIGOREV	{"phone": "+70982185142"}
0005432605388	FB37F4	8987 227364	VERA IVANOVA	{"email": "ivanova_v111964@postgrespro.ru", "phone": "+70320059599"}
0005432605389	B2E70D	6902 675111	DARYA KOROLEVA	{"email": "koroleva_darya.22061971@postgrespro.ru", "phone": "+70895657424"}
0005432605390	62E456	2966 582870	VYACHESLAV GORBUNOV	{"email": "gorbunov_v-23051979@postgrespro.ru", "phone": "+70686324352"}
0005432605391	62E456	6375 336828	NINA OVCHINNIKOVA	{"email": "ninaovchinnikova-091964@postgrespro.ru", "phone": "+70643610385"}
0005432605392	752249	3437 690347	IRINA ANDREEVA	{"phone": "+70839481256"}
0005432605393	E4B789	3098 291143	OLGA ZAKHAROVA	{"email": "o.zakharova-1979@postgrespro.ru", "phone": "+70211350598"}
0005432605394	7549C1	8680 938945	ALEKSEY EGOROV	{"email": "a-egorov.15101980@postgrespro.ru", "phone": "+70740969736"}
0005432605395	7549C1	2130 040601	EVGENIY ALEKSANDROV	{"phone": "+70737438631"}
0005432605396	5C55D8	5995 321106	OLGA PAVLOVA	{"phone": "+70226150952"}
0005432605397	340788	8891 322469	LIDIYA ANDREEVA	{"email": "lidiya_andreeva-081983@postgrespro.ru", "phone": "+70087678681"}
0005432605398	26B06E	1628 209365	KONSTANTIN KOROLEV	{"phone": "+70725600359"}
0005432605399	26B06E	8241 594199	DMITRIY NIKOLAEV	{"email": "nikolaev.dmitriy1966@postgrespro.ru", "phone": "+70481597614"}
0005432605400	D1B4C7	2432 623564	TAMARA RYABOVA	{"phone": "+70017140466"}
0005432605401	D1B4C7	9877 798551	LYUDMILA SIDOROVA	{"phone": "+70795840380"}
0005432605402	82DF87	5538 068472	LYUDMILA VASILEVA	{"email": "vasileva.l_061985@postgrespro.ru", "phone": "+70831569475"}
0005432605403	3544C7	9412 232122	SERGEY MIKHAYLOV	{"phone": "+70812230376"}
0005432605404	3544C7	1109 939767	EKATERINA EGOROVA	{"email": "e.egorova.1972@postgrespro.ru", "phone": "+70572257282"}
0005432605405	B331F3	8280 742120	ILYAS NAUMOV	{"email": "naumovilyas_1972@postgrespro.ru", "phone": "+70516214019"}
0005432605406	B331F3	0187 184120	NATALYA KALININA	{"phone": "+70415595203"}
0005432605407	303EA0	8798 905309	IRINA EGOROVA	{"phone": "+70207058475"}
0005432605408	560933	6940 973142	SVETLANA KOLESNIKOVA	{"email": "svetlana-kolesnikova27061978@postgrespro.ru", "phone": "+70917794767"}
0005432605409	29E572	6837 444602	SERGEY BORISOV	{"email": "sergey_borisov-01031967@postgrespro.ru", "phone": "+70354033827"}
0005432605410	38B0D1	7827 844635	SERGEY KUDRYASHOV	{"email": "sergey-kudryashov_1980@postgrespro.ru", "phone": "+70157610027"}
0005432605411	38B0D1	5220 315238	VALERIY BONDARENKO	{"email": "bondarenko.valeriy-23101963@postgrespro.ru", "phone": "+70637220678"}
0005432605412	E23D99	4422 290698	MAKSIM SMIRNOV	{"email": "smirnov-maksim-27081968@postgrespro.ru", "phone": "+70505153028"}
0005432605413	B6F4AE	0497 306520	VASILIY ILIN	{"email": "vasiliy.ilin-1967@postgrespro.ru", "phone": "+70788988200"}
0005432605414	A63ED2	2981 185633	NATALYA VOLKOVA	{"phone": "+70742752633"}
0005432605415	A63ED2	7428 568719	MIKHAIL KOZLOV	{"phone": "+70907480381"}
0005432605416	79A8E0	3741 772085	VADIM FILIPPOV	{"email": "filippov_v-1969@postgrespro.ru", "phone": "+70541702993"}
0005432605417	F5C79F	9851 912456	ARSENIY ZAYCEV	{"email": "zaycev_a-1969@postgrespro.ru", "phone": "+70125523506"}
0005432605418	F5C79F	9611 557007	LEV EGOROV	{"phone": "+70185820103"}
0005432605419	8B1DAE	7975 529326	MARIYA POPOVA	{"email": "mariya_popova.111966@postgrespro.ru", "phone": "+70760702040"}
0005432605420	8B1DAE	4582 794495	POLINA KOZLOVA	{"email": "kozlova_polina-1974@postgrespro.ru", "phone": "+70945205461"}
0005432605421	9AB88C	2690 605569	NIKOLAY SAVELEV	{"email": "nikolay.savelev.061973@postgrespro.ru", "phone": "+70804479254"}
0005432605422	A5349F	8283 549578	ANASTASIYA MATVEEVA	{"email": "a.matveeva_1964@postgrespro.ru", "phone": "+70093697219"}
0005432605423	C4F65D	1486 080963	ANDREY MOROZOV	{"email": "andreymorozov_031971@postgrespro.ru", "phone": "+70813675822"}
0005432605424	8575D5	0928 912099	TATYANA DENISOVA	{"phone": "+70748075942"}
0005432605425	8575D5	2892 438225	ALEKSANDR ANDREEV	{"email": "andreev_a021963@postgrespro.ru", "phone": "+70735132724"}
0005432605426	805EEE	1457 805447	YULIYA ROMANOVA	{"email": "romanova_yuliya_021973@postgrespro.ru", "phone": "+70420462233"}
0005432605427	805EEE	9208 411863	DENIS CHERNOV	{"email": "chernov_denis-04061962@postgrespro.ru", "phone": "+70085380475"}
0005432605428	79DFE3	9237 132518	ZHANNA POLYAKOVA	{"email": "zpolyakova-09051978@postgrespro.ru", "phone": "+70102021250"}
0005432605429	46B03F	2484 140637	ALEKSANDR MOROZOV	{"email": "morozovaleksandr1957@postgrespro.ru", "phone": "+70210061415"}
0005432605430	44006F	8893 601981	ALEKSANDR KUZMIN	{"phone": "+70670899876"}
0005432605431	23AA77	4832 917133	NINA KONDRATEVA	{"phone": "+70187993401"}
0005432605432	81B00B	9259 378971	MIKHAIL GUSEV	{"phone": "+70148854849"}
0005432605433	81B00B	3738 361105	MAKSIM GORBUNOV	{"phone": "+70470329014"}
0005432605434	555557	3941 218787	VLADIMIR MIKHAYLOV	{"email": "vladimirmikhaylov_08061971@postgrespro.ru", "phone": "+70739644394"}
0005432605435	C4C235	3713 944697	ELENA TITOVA	{"phone": "+70666783575"}
0005432605436	C4C235	6993 247569	RAVIL POPOV	{"email": "popovr.24101970@postgrespro.ru", "phone": "+70657531222"}
0005432605437	C4C235	0817 933238	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-1973@postgrespro.ru", "phone": "+70577145128"}
0005432605438	498A3E	6664 471631	ALEKSANDR POPOV	{"phone": "+70776007925"}
0005432605439	3991EA	2446 837313	OLGA NIKITINA	{"phone": "+70249824526"}
0005432605440	3991EA	7545 476770	TAMARA VLASOVA	{"email": "t.vlasova_1970@postgrespro.ru", "phone": "+70935664038"}
0005432605441	9FF0AB	1352 208500	SVETLANA MAKAROVA	{"phone": "+70223942405"}
0005432605442	9FF0AB	1165 214453	VALERIY ZAKHAROV	{"email": "zakharov_v-1979@postgrespro.ru", "phone": "+70927272206"}
0005432605443	9FF0AB	5898 711666	MARIYA MARTYNOVA	{"email": "martynova.m1978@postgrespro.ru", "phone": "+70341604379"}
0005432605444	25B9C5	6984 265074	IRINA IVANOVA	{"email": "ivanova_i-25091979@postgrespro.ru", "phone": "+70145801401"}
0005432605445	4E9081	7247 050943	EKATERINA MELNIKOVA	{"email": "melnikova.e_041980@postgrespro.ru", "phone": "+70468493100"}
0005432605446	F2BF1D	0042 404491	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a1968@postgrespro.ru", "phone": "+70701050246"}
0005432605447	F2BF1D	2743 544825	ANTONINA GORBUNOVA	{"phone": "+70826852233"}
0005432605448	B12F39	7838 148856	MARINA KOMAROVA	{"phone": "+70419789160"}
0005432605449	9D4592	6811 497483	SANIYA FROLOVA	{"email": "s.frolova081972@postgrespro.ru", "phone": "+70573015337"}
0005432605450	045215	0081 345105	EVDOKIYA SOROKINA	{"phone": "+70360757848"}
0005432605451	EEF289	7316 290858	GULNAZ AFANASEVA	{"email": "gulnaz-afanaseva.061959@postgrespro.ru", "phone": "+70272712481"}
0005432605452	279650	9639 513489	ANNA FEDOROVA	{"email": "fedorova.a-111978@postgrespro.ru", "phone": "+70484573741"}
0005432605453	279650	0063 558010	EVGENIY ANDREEV	{"phone": "+70828057459"}
0005432605454	6FA564	2067 607441	ALEKSANDR KOROLEV	{"phone": "+70320632539"}
0005432605455	5549FD	4819 177626	NATALYA SOKOLOVA	{"email": "natalya.sokolova-041974@postgrespro.ru", "phone": "+70573660325"}
0005432605456	38D8B8	6148 025441	ANATOLIY MIKHAYLOV	{"phone": "+70067022251"}
0005432605457	38D8B8	0446 325163	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr25051980@postgrespro.ru", "phone": "+70268254996"}
0005432605458	2F3FEC	0859 847455	ANDREY MOISEEV	{"email": "andreymoiseev_1964@postgrespro.ru", "phone": "+70879778899"}
0005432605459	2F3FEC	8789 286212	LYUBOV RYABOVA	{"email": "l.ryabova27011976@postgrespro.ru", "phone": "+70246253799"}
0005432605460	35BA06	0089 030900	NIKOLAY TIMOFEEV	{"email": "nikolay.timofeev.1961@postgrespro.ru", "phone": "+70945334015"}
0005432605461	35BA06	1272 015106	ANNA ANTONOVA	{"email": "antonovaanna-1971@postgrespro.ru", "phone": "+70137572784"}
0005432605462	35BA06	9116 436365	VIKTOR PETROV	{"email": "petrovv_111976@postgrespro.ru", "phone": "+70055234245"}
0005432605463	58A334	8694 275501	FARIDA PAVLOVA	{"phone": "+70231432966"}
0005432605464	58A334	2263 543874	NADEZHDA VLASOVA	{"email": "vlasova.nadezhda27091970@postgrespro.ru", "phone": "+70029200536"}
0005432605465	58A334	9973 198583	VITALIY GUSEV	{"email": "v_gusev.26081974@postgrespro.ru", "phone": "+70727476756"}
0005432605466	91650D	4748 474989	PAVEL NOVIKOV	{"email": "pavel_novikov.011986@postgrespro.ru", "phone": "+70243032627"}
0005432605467	C327C6	1695 477448	VIKTOR IVANOV	{"phone": "+70715207533"}
0005432605468	C327C6	7940 766489	LIDIYA TARASOVA	{"phone": "+70212643735"}
0005432605469	3D2B3A	0180 170696	ALEKSANDR MEDVEDEV	{"phone": "+70573909918"}
0005432605470	84E0D6	4590 260787	SVETLANA KUZNECOVA	{"email": "kuznecova.s-1976@postgrespro.ru", "phone": "+70094303421"}
0005432605471	7EAAEB	6407 295290	ALEKSANDR KUZMIN	{"phone": "+70149325689"}
0005432605472	7EAAEB	7804 026566	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov.081969@postgrespro.ru", "phone": "+70080253053"}
0005432605473	CAD096	8146 282275	ANASTASIYA LEBEDEVA	{"email": "anastasiya_lebedeva.14111981@postgrespro.ru", "phone": "+70378368427"}
0005432605474	DB5989	1135 879813	ELENA BELYAEVA	{"email": "ebelyaeva_1965@postgrespro.ru", "phone": "+70099781259"}
0005432605475	DB5989	7109 869325	OLGA KRASNOVA	{"email": "krasnovao-1970@postgrespro.ru", "phone": "+70086504426"}
0005432605476	DB5989	8746 672523	ANDREY IVANOV	{"phone": "+70666979051"}
0005432605477	7CCAAC	6304 448773	VALERIY EGOROV	{"phone": "+70026323615"}
0005432605478	7CCAAC	1576 972732	MIKHAIL MAKSIMOV	{"phone": "+70177550833"}
0005432605479	2CBF47	8879 165647	ANNA POPOVA	{"email": "popova-anna_1965@postgrespro.ru", "phone": "+70004615075"}
0005432605480	2CBF47	4934 965810	VLADIMIR KULIKOV	{"phone": "+70210622201"}
0005432605481	619B21	5860 243674	KLAVDIYA RYABOVA	{"phone": "+70324589243"}
0005432605482	619B21	0511 919392	GLEB SAVELEV	{"phone": "+70764228730"}
0005432605483	34E302	3510 978505	LIDIYA VLASOVA	{"phone": "+70485179367"}
0005432605484	308A4A	0323 339466	SERGEY ROMANOV	{"phone": "+70751649888"}
0005432605485	F91E66	8545 785405	EGOR YAKOVLEV	{"phone": "+70738847352"}
0005432605486	81AB6B	1492 968138	NINA FEDOROVA	{"email": "nina-fedorova061976@postgrespro.ru", "phone": "+70619375014"}
0005432605487	767B94	8136 496887	ALEKSANDR YAKOVLEV	{"phone": "+70954604358"}
0005432605488	767B94	3406 599018	YANA TITOVA	{"phone": "+70273879509"}
0005432605489	77ABE7	0880 106305	SVETLANA SMIRNOVA	{"email": "smirnova-svetlana.081972@postgrespro.ru", "phone": "+70720546726"}
0005432605490	765408	7346 148710	OLEG BELOV	{"email": "belovo26011980@postgrespro.ru", "phone": "+70763555444"}
0005432605491	AB554A	5637 504477	LYUDMILA FILIPPOVA	{"email": "filippoval121975@postgrespro.ru", "phone": "+70516317877"}
0005432605492	2F1A8C	6312 071466	YURIY GUSEV	{"phone": "+70332458958"}
0005432605493	2F1A8C	6891 611849	TATYANA KUZNECOVA	{"phone": "+70157852267"}
0005432605494	2F1A8C	0916 176531	ALEKSEY FROLOV	{"email": "frolov_a18011980@postgrespro.ru", "phone": "+70769284478"}
0005432605495	D04B7D	4440 400425	ALEKSEY MAKSIMOV	{"phone": "+70270386458"}
0005432605496	1C5105	2887 034278	VALENTIN KOROLEV	{"email": "v_korolev_20101974@postgrespro.ru", "phone": "+70103554785"}
0005432605497	4BEE35	5956 289885	SVETLANA YAKOVLEVA	{"phone": "+70164735988"}
0005432605498	4BEE35	4194 954533	TATYANA MATVEEVA	{"phone": "+70794747706"}
0005432605499	02DD88	5022 241733	VLADIMIR SOLOVEV	{"email": "solovev_vladimir.27091966@postgrespro.ru", "phone": "+70574004590"}
0005432605500	E8DE80	2050 907880	NATALYA EGOROVA	{"email": "egorova_n.091962@postgrespro.ru", "phone": "+70542173731"}
0005432605501	C51A1F	8953 442409	SERGEY SOKOLOV	{"email": "s.sokolov-011976@postgrespro.ru", "phone": "+70944308469"}
0005432605502	180F3B	0678 609138	ANATOLIY VASILEV	{"phone": "+70409514757"}
0005432605503	180F3B	7739 112057	ALEKSANDR SCHERBAKOV	{"phone": "+70211609957"}
0005432605504	F358E6	2575 218066	LILIYA KONOVALOVA	{"phone": "+70177432760"}
0005432605505	0E3212	5003 937489	YULIYA RODIONOVA	{"phone": "+70812360513"}
0005432605506	CEA373	0428 173938	MARIYA VOLKOVA	{"email": "volkovam.31011975@postgrespro.ru", "phone": "+70125979560"}
0005432605507	B1658A	7342 587138	OLGA KOROLEVA	{"email": "koroleva_olga15051982@postgrespro.ru", "phone": "+70340591194"}
0005432605508	3886C5	8998 413419	ARTUR ANDREEV	{"phone": "+70837397035"}
0005432605509	30C66F	7601 555296	VLADIMIR ANTONOV	{"email": "antonov.vladimir_15061978@postgrespro.ru", "phone": "+70491023018"}
0005432605510	8473FC	7094 248691	LYUBOV ERMAKOVA	{"phone": "+70622453639"}
0005432605511	8473FC	7464 275883	MARINA MIRONOVA	{"email": "mironova_m_1975@postgrespro.ru", "phone": "+70631524130"}
0005432605512	F96DC6	6522 809135	IRINA ERMAKOVA	{"phone": "+70566732353"}
0005432605513	8B461F	8184 315270	ALEKSANDR FOMIN	{"phone": "+70164757944"}
0005432605514	8B461F	0478 582500	OLGA LEBEDEVA	{"phone": "+70311937375"}
0005432605515	26B347	6092 614446	ALEKSANDR KUZNECOV	{"email": "akuznecov071974@postgrespro.ru", "phone": "+70964701323"}
0005432605516	A4D8D0	3658 717239	RAISA ANTONOVA	{"email": "r-antonova021978@postgrespro.ru", "phone": "+70505816333"}
0005432605517	B4C7D1	0166 111659	SVETLANA KULIKOVA	{"phone": "+70833092085"}
0005432605518	B4C7D1	5083 386621	KIRA ANISIMOVA	{"phone": "+70090020893"}
0005432607494	40647E	3366 128269	DENIS ANDREEV	{"phone": "+70568128976"}
0005432607495	25070C	3387 726535	SVETLANA SMIRNOVA	{"phone": "+70244584372"}
0005432607496	F13AF4	0858 468450	NIKOLAY SCHERBAKOV	{"phone": "+70121337226"}
0005432607497	FB9367	7814 926215	IGOR STEPANOV	{"phone": "+70496615768"}
0005432607498	FB9367	3820 599547	ANNA SERGEEVA	{"email": "sergeeva_a_011974@postgrespro.ru", "phone": "+70638759109"}
0005432607499	8EC576	3549 790219	VLADIMIR ABRAMOV	{"email": "v_abramov_1962@postgrespro.ru", "phone": "+70113706360"}
0005432607500	63BD6C	2366 585248	TAMARA FEDOROVA	{"phone": "+70986596790"}
0005432607501	317576	7038 240426	SVETLANA POPOVA	{"email": "s_popova_1971@postgrespro.ru", "phone": "+70973744377"}
0005432607502	BE3C03	9630 076232	NATALYA KUZNECOVA	{"phone": "+70963889792"}
0005432607503	5890C3	8686 988348	OLGA MIKHAYLOVA	{"email": "mikhaylova.olga_1975@postgrespro.ru", "phone": "+70819613809"}
0005432607504	5890C3	4637 791514	VLADIMIR FILIPPOV	{"email": "filippovvladimir.091965@postgrespro.ru", "phone": "+70393367421"}
0005432607505	6D408E	7832 412358	YURIY ZAKHAROV	{"phone": "+70543041401"}
0005432607506	1808E6	2590 246271	NADEZHDA ROMANOVA	{"email": "nadezhda-romanova.1982@postgrespro.ru", "phone": "+70459492027"}
0005432607507	6D80DE	8511 923718	IRINA VASILEVA	{"phone": "+70028202661"}
0005432607508	6D80DE	0803 154048	MIKHAIL PETROV	{"email": "petrovmikhail.1967@postgrespro.ru", "phone": "+70908836025"}
0005432607509	688F25	1680 126444	ALBINA ROMANOVA	{"email": "romanova_albina_1966@postgrespro.ru", "phone": "+70932395418"}
0005432607510	B46F2F	6929 227582	NADEZHDA BELOVA	{"phone": "+70895053046"}
0005432607511	440D6C	5837 624396	ALENA TARASOVA	{"email": "atarasova18101973@postgrespro.ru", "phone": "+70936461940"}
0005432607512	8B31E4	1077 284886	ALEKSANDR MELNIKOV	{"phone": "+70274822593"}
0005432607513	EEB7E0	9168 000764	MARINA TIKHONOVA	{"email": "tikhonova_marina.021981@postgrespro.ru", "phone": "+70696377771"}
0005432607514	EEB7E0	0050 893657	SVETLANA MELNIKOVA	{"phone": "+70185772026"}
0005432607515	663C5A	6319 316330	ANDREY NAZAROV	{"phone": "+70902307580"}
0005432607516	663C5A	9461 429498	TATYANA EFREMOVA	{"phone": "+70993889021"}
0005432607517	663C5A	7372 803898	OLGA GRISHINA	{"phone": "+70790457807"}
0005432607518	8D2982	4681 665418	EVGENIY MEDVEDEV	{"email": "evgeniymedvedev_1961@postgrespro.ru", "phone": "+70091840158"}
0005432607519	1AE705	8019 900839	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.26121974@postgrespro.ru", "phone": "+70742156509"}
0005432607520	7E3685	7235 853286	VERA MASLOVA	{"phone": "+70627575105"}
0005432607521	3229E8	5916 082704	YURIY FEDOROV	{"email": "fedorov_y.121971@postgrespro.ru", "phone": "+70147649113"}
0005432607522	D65E96	7018 852716	ALEKSANDR ANDREEV	{"phone": "+70410717812"}
0005432607523	0CE55F	3720 067005	EKATERINA ABRAMOVA	{"phone": "+70350805347"}
0005432607524	0CE55F	1791 223963	MARIYA ORLOVA	{"phone": "+70813854037"}
0005432607525	A2C453	6939 635738	MARIYA ZAKHAROVA	{"email": "mzakharova.1982@postgrespro.ru", "phone": "+70272879912"}
0005432607526	A2C453	2878 828097	ANATOLIY MELNIKOV	{"phone": "+70446789943"}
0005432607527	A2C453	4687 042091	VLADIMIR PETROV	{"email": "vpetrov_22051966@postgrespro.ru", "phone": "+70209831594"}
0005432607528	850352	1068 157881	VALENTINA KUZNECOVA	{"email": "v-kuznecova10021960@postgrespro.ru", "phone": "+70299264235"}
0005432607529	850352	1403 815324	GALINA GRISHINA	{"email": "grishina-galina_091978@postgrespro.ru", "phone": "+70348185847"}
0005432607530	B64EEC	6195 767928	ALEKSANDR KUZMIN	{"phone": "+70662148051"}
0005432607531	F98F92	5871 865876	ALEKSANDR KISELEV	{"phone": "+70407685128"}
0005432607532	F73AA6	5998 662277	ELENA ERMAKOVA	{"phone": "+70062827618"}
0005432607533	C9FC99	3046 826432	ALEKSEY BARANOV	{"email": "a_baranov_101966@postgrespro.ru", "phone": "+70203506587"}
0005432607534	C9FC99	1308 036989	ALEKSANDRA POPOVA	{"email": "a-popova-20111976@postgrespro.ru", "phone": "+70830054463"}
0005432607535	57E1A2	0051 051247	NATALYA AFANASEVA	{"email": "afanaseva.n-1963@postgrespro.ru", "phone": "+70298939470"}
0005432607536	ADB935	9163 146117	VERA SMIRNOVA	{"email": "smirnovavera-1964@postgrespro.ru", "phone": "+70041884730"}
0005432607537	ADB935	5039 200156	SERGEY NIKITIN	{"email": "s_nikitin.18011970@postgrespro.ru", "phone": "+70191317698"}
0005432607538	ADB935	6731 865167	ALLA DAVYDOVA	{"phone": "+70941363006"}
0005432607539	6B6B40	3500 394463	NAIL SIDOROV	{"email": "sidorovn.1965@postgrespro.ru", "phone": "+70789046701"}
0005432607540	9BB4DA	7552 324477	ALEKSEY BORISOV	{"phone": "+70839112431"}
0005432607541	BC9B16	0378 394049	ANASTASIYA ROMANOVA	{"phone": "+70993094333"}
0005432607542	BC9B16	7059 584807	ROMAN SCHERBAKOV	{"phone": "+70867610341"}
0005432607543	6305DA	0813 244390	OLGA KOROLEVA	{"email": "koroleva.o1976@postgrespro.ru", "phone": "+70078678146"}
0005432607544	3521B4	2477 443927	NATALYA KUZNECOVA	{"phone": "+70733206721"}
0005432607545	A8A4AD	3894 868719	RUSHANIYA MAKAROVA	{"email": "r.makarova.1968@postgrespro.ru", "phone": "+70685518242"}
0005432607546	0A0521	2965 137584	VASILIY ANDREEV	{"email": "andreev-vasiliy_1976@postgrespro.ru", "phone": "+70810280346"}
0005432607547	6DD077	3578 908079	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov_011971@postgrespro.ru", "phone": "+70516110386"}
0005432607548	AD931E	5524 686224	ANATOLIY ZAYCEV	{"email": "a-zaycev_1961@postgrespro.ru", "phone": "+70382093242"}
0005432607549	AD931E	7182 401666	NATALIYA ZOTOVA	{"phone": "+70046797355"}
0005432607550	7B0E31	5106 376561	GALINA SCHERBAKOVA	{"email": "scherbakova-g.13061972@postgrespro.ru", "phone": "+70722192765"}
0005432607551	157FAD	6861 066151	YULIYA ANTONOVA	{"email": "antonova_yuliya_041969@postgrespro.ru", "phone": "+70829286418"}
0005432607552	157FAD	6976 162558	TATYANA AFANASEVA	{"email": "t.afanaseva.1966@postgrespro.ru", "phone": "+70544549964"}
0005432607553	27BC4D	2013 573013	EVGENIY VLASOV	{"email": "vlasov_evgeniy-10011958@postgrespro.ru", "phone": "+70482329695"}
0005432607554	C90913	2818 405528	GALINA POLYAKOVA	{"email": "polyakova_galina.17081977@postgrespro.ru", "phone": "+70913174933"}
0005432607555	C90913	0434 335964	KRISTINA OSIPOVA	{"email": "kristina.osipova041982@postgrespro.ru", "phone": "+70303410922"}
0005432607556	DACA58	3219 096038	MIKHAIL KUDRYASHOV	{"phone": "+70813673642"}
0005432607557	DA35F5	7865 862670	NATALYA SEMENOVA	{"phone": "+70788053624"}
0005432607558	DA35F5	7723 503206	ALEKSANDR KUZMIN	{"phone": "+70384139752"}
0005432607559	DA35F5	1081 997646	ANTON NAUMOV	{"phone": "+70224833586"}
0005432607560	13F67D	9023 137978	TAMARA NIKIFOROVA	{"phone": "+70190608706"}
0005432607561	96CFAB	7766 077191	ANDREY MIRONOV	{"phone": "+70309651189"}
0005432607562	59AB46	8789 786674	ALBERT DMITRIEV	{"phone": "+70672642974"}
0005432607563	9D4988	5967 457728	SERGEY ALEKSEEV	{"email": "alekseevs.1976@postgrespro.ru", "phone": "+70550460486"}
0005432607564	AEC58B	9692 544776	EVGENIY KUZNECOV	{"phone": "+70142152405"}
0005432607565	AEC58B	7424 477876	VIKTOR PETROV	{"phone": "+70940111825"}
0005432607566	38569A	5222 672177	TATYANA IVANOVA	{"email": "tatyana-ivanova.1976@postgrespro.ru", "phone": "+70555806403"}
0005432607567	F785B2	3929 091031	ILYA IVANOV	{"phone": "+70414316463"}
0005432607568	6E0011	5855 529163	RASHID SIDOROV	{"phone": "+70508130393"}
0005432607569	96C5C9	5108 216764	YANA ANDREEVA	{"email": "andreeva_yana.1975@postgrespro.ru", "phone": "+70914572615"}
0005432607570	052EA8	8640 940797	ANNA EGOROVA	{"email": "egorovaa-031979@postgrespro.ru", "phone": "+70008011909"}
0005432607571	052EA8	0896 329600	NATALYA FEDOROVA	{"email": "natalya.fedorova.031965@postgrespro.ru", "phone": "+70817081759"}
0005432607572	5C49FF	0327 251149	DAMIR ORLOV	{"email": "orlov-damir1959@postgrespro.ru", "phone": "+70429066084"}
0005432607573	AC3E6E	6623 737915	ANASTASIYA ABRAMOVA	{"phone": "+70814995132"}
0005432607574	EDAB00	2120 030087	TAMARA FILATOVA	{"email": "filatova_tamara_091973@postgrespro.ru", "phone": "+70404874068"}
0005432607575	4A0416	7824 015672	ALEKSANDR ABRAMOV	{"email": "a_abramov_101978@postgrespro.ru", "phone": "+70917376484"}
0005432607576	4A0416	7053 875298	VLADIMIR SMIRNOV	{"phone": "+70340096831"}
0005432607577	D5A19F	9902 734046	SERGEY TIMOFEEV	{"email": "timofeev_s.081966@postgrespro.ru", "phone": "+70464640358"}
0005432607578	E2C9EE	7604 849219	NATALYA MIRONOVA	{"phone": "+70994607887"}
0005432607579	E05FFB	3817 232223	KRISTINA MALYSHEVA	{"email": "kristina-malysheva.111963@postgrespro.ru", "phone": "+70583019596"}
0005432607580	704415	5274 989258	ANATOLIY KUDRYASHOV	{"email": "akudryashov.07061971@postgrespro.ru", "phone": "+70586181819"}
0005432607581	BF8A7E	6576 475925	YULIYA KOROLEVA	{"email": "yuliya-koroleva-08081968@postgrespro.ru", "phone": "+70099730005"}
0005432607582	BF8A7E	4860 951940	TAMARA VASILEVA	{"email": "t_vasileva-28041977@postgrespro.ru", "phone": "+70428633252"}
0005432607583	5F4F35	8043 144938	ARTEM IVANOV	{"phone": "+70254473919"}
0005432607584	5F4F35	2782 832035	ALEKSEY VASILEV	{"email": "vasilev_aleksey_06061970@postgrespro.ru", "phone": "+70966016871"}
0005432607585	5F4F35	2334 649146	GALINA POPOVA	{"email": "galina.popova061969@postgrespro.ru", "phone": "+70868796496"}
0005432607586	642F49	6155 618008	MARIYA KOMAROVA	{"email": "m.komarova_1966@postgrespro.ru", "phone": "+70335737807"}
0005432607587	759191	9036 146199	VLADIMIR FEDOTOV	{"email": "fedotov_vladimir_111967@postgrespro.ru", "phone": "+70916565145"}
0005432607588	49CE35	7071 099055	IRINA BELYAEVA	{"phone": "+70692814643"}
0005432607589	49CE35	5864 103361	DMITRIY EGOROV	{"phone": "+70076031156"}
0005432607590	AB57DD	6272 391054	EVGENIY TIMOFEEV	{"email": "timofeev_e.09011965@postgrespro.ru", "phone": "+70017606947"}
0005432607591	AB57DD	7203 332514	OKSANA MIKHAYLOVA	{"email": "mikhaylova_o-18091974@postgrespro.ru", "phone": "+70720405788"}
0005432607592	824967	6322 963582	ROMAN SOKOLOV	{"email": "sokolovroman_121974@postgrespro.ru", "phone": "+70922033804"}
0005432607593	2159B7	5965 811727	TAMARA ZHUKOVA	{"email": "t.zhukova_041980@postgrespro.ru", "phone": "+70189998148"}
0005432607594	60F4DC	3686 459647	KAPITALINA TIKHONOVA	{"phone": "+70486404953"}
0005432607595	60F4DC	2433 427141	SVETLANA BORISOVA	{"email": "borisova-svetlana-071987@postgrespro.ru", "phone": "+70283429768"}
0005432607596	60F4DC	9885 484662	YANA TARASOVA	{"email": "tarasova-y1982@postgrespro.ru", "phone": "+70206176343"}
0005432607597	A1713A	8511 678373	ROMAN SOROKIN	{"phone": "+70434649718"}
0005432607598	907C56	8382 032855	STANISLAV GORBUNOV	{"phone": "+70925416825"}
0005432607599	907C56	6902 151530	MARINA FROLOVA	{"email": "m.frolova1971@postgrespro.ru", "phone": "+70887244573"}
0005432607600	DB00C0	1426 994867	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay-09031962@postgrespro.ru", "phone": "+70491234868"}
0005432607601	DB00C0	6677 606658	IRINA KUZNECOVA	{"email": "irina_kuznecova121974@postgrespro.ru", "phone": "+70915473632"}
0005432607602	5A9F86	0171 945426	VALERIY PETROV	{"phone": "+70808740916"}
0005432607603	D9405A	2604 940325	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr.081978@postgrespro.ru", "phone": "+70744003640"}
0005432607604	5431AE	1271 608638	VALENTINA MOROZOVA	{"email": "v_morozova05011980@postgrespro.ru", "phone": "+70716005662"}
0005432607605	5431AE	8386 205504	ALEKSANDRA FEDOROVA	{"email": "afedorova.1974@postgrespro.ru", "phone": "+70343226986"}
0005432607606	2D97A2	5312 614820	ALEKSANDR KUZNECOV	{"phone": "+70210719356"}
0005432607607	2D97A2	5377 567706	KRISTINA BORISOVA	{"phone": "+70364619438"}
0005432607608	333CFA	7037 781527	ALEKSANDR ORLOV	{"email": "orlov-a28021978@postgrespro.ru", "phone": "+70831919360"}
0005432607609	333CFA	8404 947071	NINA BORISOVA	{"email": "n_borisova_031977@postgrespro.ru", "phone": "+70244885408"}
0005432607610	359BCD	9511 023582	VLADIMIR ISAEV	{"email": "isaev-v-15051968@postgrespro.ru", "phone": "+70904516348"}
0005432607611	359BCD	5649 836139	LYUDMILA OVCHINNIKOVA	{"phone": "+70998219105"}
0005432607612	F7CF11	1683 703627	OLGA EGOROVA	{"email": "olga_egorova.29111963@postgrespro.ru", "phone": "+70984891750"}
0005432607613	A41BFD	4261 072422	TATYANA EGOROVA	{"phone": "+70773426371"}
0005432607614	2BB1CA	0427 761299	YAROSLAV POPOV	{"email": "yaroslav-popov.13051969@postgrespro.ru", "phone": "+70504830833"}
0005432607615	BCB0EA	7672 005986	VALENTINA NIKITINA	{"email": "nikitinavalentina1981@postgrespro.ru", "phone": "+70707876988"}
0005432607616	CAB4AE	0713 871494	VLADIMIR MIKHAYLOV	{"phone": "+70822452422"}
0005432607617	60DA36	9705 854508	NIKITA VOROBEV	{"email": "vorobev_n.1972@postgrespro.ru", "phone": "+70182699990"}
0005432607618	2279AB	3698 563010	VLADIMIR ALEKSEEV	{"email": "alekseev-v19061968@postgrespro.ru", "phone": "+70313412965"}
0005432607619	9F5E5D	8228 770164	VITALIY IVANOV	{"email": "ivanov_v.041975@postgrespro.ru", "phone": "+70792049288"}
0005432607620	9F5E5D	9850 034345	GALINA MIKHAYLOVA	{"phone": "+70669399419"}
0005432607621	DDEFAD	0542 926286	RAISA ZHUKOVA	{"email": "r-zhukova_061971@postgrespro.ru", "phone": "+70391949430"}
0005432607622	DD8274	8393 872918	ELVIRA KUZNECOVA	{"email": "kuznecova_elvira.091983@postgrespro.ru", "phone": "+70741009165"}
0005432607623	324CC0	2596 168413	ARTEM SCHERBAKOV	{"phone": "+70116349431"}
0005432607624	890BD1	3265 026392	MARINA NIKIFOROVA	{"email": "nikiforova-marina.051966@postgrespro.ru", "phone": "+70789206760"}
0005432607625	890BD1	7196 505902	ALEKSANDR NIKITIN	{"phone": "+70879961341"}
0005432607626	D09737	1381 188639	FEDOR KAZAKOV	{"phone": "+70261155502"}
0005432607627	D09737	0518 429276	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov.011982@postgrespro.ru", "phone": "+70835892390"}
0005432607628	381B18	5948 623000	OLGA NAZAROVA	{"phone": "+70677468452"}
0005432607629	A463FF	5480 361827	EVGENIYA ANTONOVA	{"email": "evgeniya-antonova.1972@postgrespro.ru", "phone": "+70937815784"}
0005432607630	0372F9	3616 006990	LEONID SEMENOV	{"email": "semenovleonid011979@postgrespro.ru", "phone": "+70388352584"}
0005432607631	0372F9	6242 269412	TAISIYA ZAKHAROVA	{"phone": "+70720196653"}
0005432607632	22B765	7921 227135	ALEKSANDRA SIDOROVA	{"email": "a_sidorova.081985@postgrespro.ru", "phone": "+70525016489"}
0005432607633	22B765	2803 718871	ALEKSEY FROLOV	{"email": "frolov_a.31121973@postgrespro.ru", "phone": "+70496755110"}
0005432607634	22B765	7022 390797	ANASTASIYA BARANOVA	{"email": "baranovaa-27071966@postgrespro.ru", "phone": "+70599234735"}
0005432607635	55AA6A	1689 012508	ELENA MIRONOVA	{"email": "elenamironova17061964@postgrespro.ru", "phone": "+70733895470"}
0005432607636	55AA6A	2932 353753	ZARINA PETROVA	{"phone": "+70207144762"}
0005432607637	55AA6A	9476 780803	ANNA LEBEDEVA	{"email": "a_lebedeva17111965@postgrespro.ru", "phone": "+70390221001"}
0005432607638	91FBAB	5237 438736	VLADIMIR POPOV	{"email": "vladimirpopov_30121976@postgrespro.ru", "phone": "+70195506214"}
0005432607639	7CA921	3568 663067	NATALYA SERGEEVA	{"email": "natalyasergeeva101975@postgrespro.ru", "phone": "+70947500772"}
0005432607640	7CA921	4460 231834	YULIYA MAKAROVA	{"email": "makarova.y.1968@postgrespro.ru", "phone": "+70076314824"}
0005432607641	7CA921	1264 358232	LIDIYA KONOVALOVA	{"email": "konovalovalidiya-081975@postgrespro.ru", "phone": "+70002589532"}
0005432607642	7CA921	8837 769466	OLGA SCHERBAKOVA	{"email": "scherbakovaolga.07111966@postgrespro.ru", "phone": "+70329071423"}
0005432607643	D99A48	2657 020231	VALERIY KUDRYASHOV	{"email": "v_kudryashov-091975@postgrespro.ru", "phone": "+70893837126"}
0005432607644	F11FD0	9429 701371	SERGEY TIMOFEEV	{"email": "sergey-timofeev-1970@postgrespro.ru", "phone": "+70811846100"}
0005432607645	F11FD0	6499 968365	NATALYA DMITRIEVA	{"email": "dmitrieva.n-061970@postgrespro.ru", "phone": "+70285549265"}
0005432607646	320EBB	6760 742529	EKATERINA SOROKINA	{"phone": "+70744434555"}
0005432607647	1B185D	6217 859287	VALENTINA GORBUNOVA	{"email": "gorbunova.v1964@postgrespro.ru", "phone": "+70591576058"}
0005432607648	19D279	7752 011156	SERAFIM GORBUNOV	{"email": "gorbunov-s011976@postgrespro.ru", "phone": "+70410515152"}
0005432607649	19D279	2876 225082	VIKTORIYA GORBUNOVA	{"email": "v-gorbunova061977@postgrespro.ru", "phone": "+70258255489"}
0005432607650	FAB523	3665 330328	LYUDMILA GAVRILOVA	{"email": "lyudmila-gavrilova1975@postgrespro.ru", "phone": "+70559765602"}
0005432607651	8FFEFB	6198 427616	ANATOLIY DMITRIEV	{"phone": "+70516947238"}
0005432607652	8FFEFB	4242 286696	NIKOLAY MAKAROV	{"email": "nikolaymakarov-30111968@postgrespro.ru", "phone": "+70979278127"}
0005432607653	195A17	2471 711897	VIKTOR ZHUKOV	{"phone": "+70014895828"}
0005432607654	A05BD0	7286 374921	DENIS BORISOV	{"phone": "+70716323451"}
0005432607655	C4F510	2865 514874	ELEONORA FEDOROVA	{"email": "fedorova-e12031972@postgrespro.ru", "phone": "+70704183972"}
0005432607656	9289C4	5987 365620	VITALIY MIRONOV	{"phone": "+70778662547"}
0005432607657	7CE6DF	8015 270160	ALEKSANDR BELOV	{"email": "belov-a1985@postgrespro.ru", "phone": "+70055783087"}
0005432607658	7CE6DF	1225 629263	SVETLANA DMITRIEVA	{"email": "svetlanadmitrieva26041978@postgrespro.ru", "phone": "+70756686883"}
0005432607659	F5F170	9095 105766	NIKOLAY FILIPPOV	{"email": "n-filippov-17021975@postgrespro.ru", "phone": "+70306992027"}
0005432607660	D14580	7012 678566	NATALYA KALININA	{"phone": "+70555434302"}
0005432607661	D14580	6060 194430	MAKSIM KONOVALOV	{"email": "m-konovalov.071971@postgrespro.ru", "phone": "+70342407725"}
0005432607662	0CD223	7178 245566	ANATOLIY KUZNECOV	{"email": "a.kuznecov-1956@postgrespro.ru", "phone": "+70214972802"}
0005432607663	0CD223	6115 551635	EVGENIY FEDOTOV	{"email": "fedotove.30111974@postgrespro.ru", "phone": "+70700484498"}
0005432607664	385DBC	5722 181420	ALEKSEY KRASNOV	{"email": "aleksey_krasnov_091971@postgrespro.ru", "phone": "+70237554199"}
0005432607665	385DBC	9701 387135	IGOR KUZNECOV	{"email": "kuznecov.igor-061979@postgrespro.ru", "phone": "+70770226555"}
0005432607666	214738	0831 699180	ARTEM ILIN	{"email": "ilin_a041984@postgrespro.ru", "phone": "+70124780171"}
0005432607667	214738	8503 985521	VALENTINA EGOROVA	{"email": "v.egorova_041977@postgrespro.ru", "phone": "+70015261041"}
0005432607668	6AFFE1	8785 065780	VIKTOR DMITRIEV	{"email": "dmitriev_v1958@postgrespro.ru", "phone": "+70986345254"}
0005432607669	6AFFE1	1949 783515	OLGA STEPANOVA	{"email": "olga-stepanova-1962@postgrespro.ru", "phone": "+70938701962"}
0005432607670	E65E16	1967 744834	NIKOLAY VLASOV	{"email": "nikolay_vlasov-101956@postgrespro.ru", "phone": "+70415473057"}
0005432607671	0AEEC6	5899 472637	DENIS ZHURAVLEV	{"email": "denis_zhuravlev_08091972@postgrespro.ru", "phone": "+70894589186"}
0005432607672	C838D7	3924 458168	TIMUR SERGEEV	{"phone": "+70671395433"}
0005432607673	B9D9B0	6731 447660	LYUBOV KULIKOVA	{"phone": "+70668223596"}
0005432607674	B9D9B0	7040 075533	DANIIL MELNIKOV	{"phone": "+70559401939"}
0005432607675	82A85D	1371 785568	DMITRIY SMIRNOV	{"email": "d_smirnov.1972@postgrespro.ru", "phone": "+70640186698"}
0005432607676	26FF06	4045 120571	LEONID MARTYNOV	{"email": "martynovl.041974@postgrespro.ru", "phone": "+70306223387"}
0005432607677	E72EBA	2926 574526	DMITRIY GUSEV	{"phone": "+70432539870"}
0005432607678	AD2E25	4346 490795	ANASTASIYA SAVELEVA	{"email": "asaveleva-11111972@postgrespro.ru", "phone": "+70473690571"}
0005432607679	BF5975	1706 274758	LARISA SIDOROVA	{"phone": "+70009841062"}
0005432607680	123567	0268 969412	YURIY MOROZOV	{"email": "morozovy1980@postgrespro.ru", "phone": "+70713573756"}
0005432609658	3B1DAA	0457 019695	IRINA KOLESNIKOVA	{"phone": "+70587376620"}
0005432609659	3B1DAA	8487 535493	VLADIMIR ANDREEV	{"email": "vladimir_andreev-18071973@postgrespro.ru", "phone": "+70965164679"}
0005432609660	3B1DAA	3474 790307	ALLA ABRAMOVA	{"phone": "+70269500957"}
0005432609661	C83B00	8235 820221	VYACHESLAV GORBUNOV	{"email": "vyacheslav_gorbunov10051965@postgrespro.ru", "phone": "+70161514145"}
0005432609662	559DD9	6494 877871	DMITRIY MIRONOV	{"email": "mironov_dmitriy.21051970@postgrespro.ru", "phone": "+70639923499"}
0005432609663	559DD9	7332 174192	MAKSIM KAZAKOV	{"email": "kazakov_maksim1969@postgrespro.ru", "phone": "+70574892082"}
0005432609664	D9F15A	3533 392735	ELENA KONOVALOVA	{"phone": "+70250018320"}
0005432609665	2038F1	1036 316721	ANDREY SERGEEV	{"email": "andrey.sergeev061964@postgrespro.ru", "phone": "+70567805987"}
0005432609666	964F14	3891 932960	ARTEM BORISOV	{"phone": "+70551647598"}
0005432609667	11872E	9014 098610	VALERIYA ZAYCEVA	{"email": "vzayceva-1956@postgrespro.ru", "phone": "+70127965444"}
0005432609668	D6FB03	5356 748280	ALEKSANDR GRIGOREV	{"phone": "+70938677730"}
0005432609669	DCF6C0	4250 436434	MARIYA SOLOVEVA	{"email": "m_soloveva_1971@postgrespro.ru", "phone": "+70353527178"}
0005432609670	60EF6D	9860 169475	NATALYA KUZNECOVA	{"email": "natalya-kuznecova_16101974@postgrespro.ru", "phone": "+70300872038"}
0005432609671	60EF6D	8215 599468	ALEKSANDR PAVLOV	{"phone": "+70043637892"}
0005432609672	C6BC50	8749 157450	ZOYA CHERNOVA	{"phone": "+70070548796"}
0005432609673	C6BC50	1479 255565	GULNAZ IVANOVA	{"email": "gulnazivanova041974@postgrespro.ru", "phone": "+70009641514"}
0005432609674	B3B149	0102 333274	ANATOLIY POPOV	{"phone": "+70756654213"}
0005432609675	B3B149	3977 077071	DANIIL GAVRILOV	{"phone": "+70053646327"}
0005432609676	86BE32	1981 243306	ANNA FOMINA	{"phone": "+70840792213"}
0005432609677	86BE32	0631 528189	DMITRIY DMITRIEV	{"email": "dmitriev_d.12011976@postgrespro.ru", "phone": "+70513654672"}
0005432609678	9CD851	9007 781144	LYUDMILA NIKOLAEVA	{"email": "nikolaevalyudmila.051971@postgrespro.ru", "phone": "+70449492266"}
0005432609679	9CD851	5100 335690	DMITRIY SHEVCHENKO	{"phone": "+70271335966"}
0005432609680	9CD851	5693 018679	VALERIYA EGOROVA	{"email": "egorova.valeriya-26041979@postgrespro.ru", "phone": "+70952752873"}
0005432609681	640A90	5004 611445	SERGEY IVANOV	{"email": "sergey.ivanov-101967@postgrespro.ru", "phone": "+70738425605"}
0005432609682	3B44E2	7550 749898	ANNA DAVYDOVA	{"phone": "+70184633674"}
0005432609683	3B44E2	9564 048455	VALERIY YAKOVLEV	{"email": "valeriy-yakovlev1971@postgrespro.ru", "phone": "+70186402726"}
0005432609684	ED08FE	5835 854379	YULIYA DANILOVA	{"email": "yuliya-danilova04111968@postgrespro.ru", "phone": "+70506258001"}
0005432609685	ED08FE	2513 895026	MAKSIM GERASIMOV	{"phone": "+70413097673"}
0005432609686	FF44B2	2135 995370	ALEKSEY VOLKOV	{"phone": "+70369322583"}
0005432609687	77AF81	8078 803352	DANIIL ANDREEV	{"email": "daniilandreev-1974@postgrespro.ru", "phone": "+70398877872"}
0005432609688	77AF81	7526 103646	ALEKSEY KULIKOV	{"phone": "+70103517765"}
0005432609689	6D7026	5985 091673	NIKOLAY MELNIKOV	{"email": "melnikov-nikolay_13091977@postgrespro.ru", "phone": "+70517475334"}
0005432609690	6D7026	2787 754378	ALEKSEY IVANOV	{"email": "ivanovaleksey-1977@postgrespro.ru", "phone": "+70861901695"}
0005432609691	E0BD64	2442 504603	LIDIYA ANTONOVA	{"email": "antonova-l12071979@postgrespro.ru", "phone": "+70908191584"}
0005432609692	CA873F	1831 182273	ELENA KRASNOVA	{"phone": "+70282029730"}
0005432609693	98F27F	3516 863656	ALEKSANDR NAZAROV	{"email": "nazarov.a_25091974@postgrespro.ru", "phone": "+70044665345"}
0005432609694	D3D138	5054 859302	KAMIL ROMANOV	{"phone": "+70431198154"}
0005432609695	A56B4B	0943 756264	VIKTOR BARANOV	{"email": "baranov_v1986@postgrespro.ru", "phone": "+70016626174"}
0005432609696	A56B4B	0875 480305	GALINA KRASNOVA	{"email": "krasnovagalina091963@postgrespro.ru", "phone": "+70612537438"}
0005432609697	7BBFF8	0553 993200	ANATOLIY DMITRIEV	{"email": "dmitriev-a_26091965@postgrespro.ru", "phone": "+70894123249"}
0005432609698	9151FB	4655 694788	ARINA LEBEDEVA	{"phone": "+70606860481"}
0005432609699	E0F2A4	4207 659871	ALINA BELOVA	{"email": "belova_a13021968@postgrespro.ru", "phone": "+70849392105"}
0005432609700	E0F2A4	9397 681902	ELENA SAVELEVA	{"phone": "+70505171597"}
0005432609701	E0F2A4	3475 519403	GALINA IVANOVA	{"phone": "+70443578175"}
0005432609702	E9EF1F	5852 511447	LIDIYA ERMAKOVA	{"phone": "+70761196442"}
0005432609703	836AE4	4137 415869	ELENA FROLOVA	{"email": "e.frolova_1982@postgrespro.ru", "phone": "+70828280916"}
0005432609704	417BD5	6470 345798	AMIR PETROV	{"phone": "+70220466357"}
0005432609705	714625	7675 723247	ANDREY PETROV	{"phone": "+70998928567"}
0005432609706	B55AEE	5267 960508	MARIYA ZAKHAROVA	{"email": "zakharova_mariya-111964@postgrespro.ru", "phone": "+70821719548"}
0005432609707	9375CF	3873 081704	DANIIL SCHERBAKOV	{"phone": "+70312612427"}
0005432609708	B8614C	9333 591731	ARKADIY EGOROV	{"phone": "+70456297607"}
0005432609709	72DC95	9926 078077	VERA KONOVALOVA	{"phone": "+70508612793"}
0005432609710	F4071A	8977 490283	LIDIYA FEDOROVA	{"email": "fedorovalidiya_20071977@postgrespro.ru", "phone": "+70106198269"}
0005432609711	86C7AB	9480 002784	EKATERINA NAZAROVA	{"email": "nazarova_ekaterina021977@postgrespro.ru", "phone": "+70622776020"}
0005432609712	60A48E	8731 652330	OLGA SCHERBAKOVA	{"phone": "+70759340973"}
0005432609713	60A48E	8144 393050	LYUBOV VASILEVA	{"phone": "+70979203370"}
0005432609714	9B46B2	5278 718859	PAVEL FEDOTOV	{"phone": "+70276189466"}
0005432609715	6249A3	6371 689903	KRISTINA IVANOVA	{"email": "ivanovak28041972@postgrespro.ru", "phone": "+70260109859"}
0005432609716	6249A3	3595 276982	TAMARA MALYSHEVA	{"phone": "+70259823368"}
0005432609717	2C28E5	7692 768223	ALEKSANDR VLASOV	{"email": "a-vlasov-111972@postgrespro.ru", "phone": "+70079501483"}
0005432609718	DC4C27	8607 251646	DMITRIY SOROKIN	{"phone": "+70975886730"}
0005432609719	995645	1207 126235	VLADIMIR IVANOV	{"phone": "+70315575423"}
0005432609720	E239E7	6121 453592	ZLATA IVANOVA	{"email": "ivanova-z-17041972@postgrespro.ru", "phone": "+70988237869"}
0005432609721	28220A	0971 657882	OLEG SOLOVEV	{"phone": "+70821692581"}
0005432609722	066A3C	4663 274889	TATYANA MAKSIMOVA	{"email": "maksimovat_07021967@postgrespro.ru", "phone": "+70304265434"}
0005432609723	066A3C	5917 625976	ZAKHAR KONOVALOV	{"email": "zkonovalov-021976@postgrespro.ru", "phone": "+70580037902"}
0005432609724	90AC21	5756 895763	ANDREY MEDVEDEV	{"email": "medvedev.a-11111970@postgrespro.ru", "phone": "+70428584751"}
0005432609725	90AC21	8402 103806	RAFAIL KAZAKOV	{"phone": "+70417332680"}
0005432609726	FC5D44	9979 837308	SERGEY YAKOVLEV	{"email": "syakovlev.02021977@postgrespro.ru", "phone": "+70947138888"}
0005432609727	0E60E1	5565 078665	MATVEY VOLKOV	{"phone": "+70977966291"}
0005432609728	0E60E1	7722 614624	ALEKSEY KOZLOV	{"email": "kozlov_a.1966@postgrespro.ru", "phone": "+70774249007"}
0005432609729	4A009B	1108 966483	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev121974@postgrespro.ru", "phone": "+70407321702"}
0005432609730	DB7C3E	3751 918365	VALENTINA KUZNECOVA	{"email": "kuznecova-v-05071965@postgrespro.ru", "phone": "+70145288742"}
0005432609731	93B94E	2082 024105	TATYANA OSIPOVA	{"email": "osipova_tatyana-1976@postgrespro.ru", "phone": "+70913696391"}
0005432609732	93B94E	7338 935701	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.n.1963@postgrespro.ru", "phone": "+70797995719"}
0005432609733	ED6375	7700 836203	EKATERINA SMIRNOVA	{"phone": "+70507155983"}
0005432609734	8C3840	0805 090497	OLGA TIKHONOVA	{"email": "otikhonova.071973@postgrespro.ru", "phone": "+70823303063"}
0005432609735	0ADB59	5365 835680	VITALIY MOROZOV	{"phone": "+70702664215"}
0005432609736	A23271	2856 524146	ULYANA BOGDANOVA	{"phone": "+70206739221"}
0005432609737	93DFD1	3245 169390	VLADIMIR DENISOV	{"phone": "+70616733231"}
0005432609738	93DFD1	6722 580946	IRINA TIKHONOVA	{"email": "itikhonova_121961@postgrespro.ru", "phone": "+70043835952"}
0005432609739	A34747	0194 980528	ROSTISLAV BORISOV	{"email": "borisovr-1964@postgrespro.ru", "phone": "+70127094083"}
0005432609740	94E774	9906 013614	VLADIMIR NIKITIN	{"phone": "+70348481463"}
0005432609741	94E774	5388 798715	VALENTINA GUSEVA	{"email": "gusevavalentina_1971@postgrespro.ru", "phone": "+70204919888"}
0005432609742	C011BC	4023 195638	OLGA OSIPOVA	{"phone": "+70263240117"}
0005432609743	557D70	9750 405059	ANATOLIY KISELEV	{"email": "a.kiselev_14101977@postgrespro.ru", "phone": "+70016975881"}
0005432609744	C8AEDF	7472 539000	ANNA MAKAROVA	{"email": "annamakarova.081970@postgrespro.ru", "phone": "+70060182107"}
0005432609745	EF975A	2774 136114	ANDREY ROMANOV	{"email": "andrey_romanov121972@postgrespro.ru", "phone": "+70165717853"}
0005432609746	7F1BEC	0536 332254	IRINA YAKOVLEVA	{"email": "yakovlevai091971@postgrespro.ru", "phone": "+70053942168"}
0005432609747	B38336	1939 927267	ANASTASIYA MASLOVA	{"email": "anastasiyamaslova-01101973@postgrespro.ru", "phone": "+70956967224"}
0005432609748	B38336	1737 937341	LIDIYA VOLKOVA	{"email": "lidiyavolkova-011981@postgrespro.ru", "phone": "+70883716465"}
0005432609749	E8E241	2588 026739	ALEKSEY SERGEEV	{"email": "a.sergeev-061973@postgrespro.ru", "phone": "+70836561712"}
0005432609750	F8F283	8797 281730	SVETLANA TARASOVA	{"email": "svetlana.tarasova-061979@postgrespro.ru", "phone": "+70106040869"}
0005432609751	F8F283	7827 188555	KLAVDIYA FILATOVA	{"email": "klavdiya.filatova-1967@postgrespro.ru", "phone": "+70929597052"}
0005432609752	C68B66	7242 014858	ALEKSANDR DENISOV	{"phone": "+70478149598"}
0005432609753	C68B66	9674 039768	OLGA ZAKHAROVA	{"email": "zakharova_o1978@postgrespro.ru", "phone": "+70912372207"}
0005432609754	C68B66	2821 507087	KIRILL TIKHONOV	{"phone": "+70060046995"}
0005432609755	7F9458	7461 822199	EKATERINA VASILEVA	{"email": "evasileva.101966@postgrespro.ru", "phone": "+70989881483"}
0005432609756	7432B8	1491 078782	VALENTIN BARANOV	{"email": "baranov.v-20021980@postgrespro.ru", "phone": "+70074560589"}
0005432609757	7432B8	4935 643409	LIDIYA TARASOVA	{"phone": "+70852206893"}
0005432609758	A00C45	3452 816486	PETR IVANOV	{"email": "pivanov_06041961@postgrespro.ru", "phone": "+70873386057"}
0005432609759	A00C45	8868 607683	YURIY ZHURAVLEV	{"phone": "+70578085846"}
0005432609760	7599F2	4651 435843	ELENA ZOTOVA	{"phone": "+70515342816"}
0005432609761	7599F2	0206 373764	NATALYA KOVALEVA	{"phone": "+70472310674"}
0005432609762	AC7384	4519 161526	VERA RYABOVA	{"phone": "+70704296348"}
0005432609763	FCB593	1873 038129	ELENA FROLOVA	{"phone": "+70725604813"}
0005432609764	2EF291	1788 442428	ANTONINA MARTYNOVA	{"email": "a.martynova-1968@postgrespro.ru", "phone": "+70420297436"}
0005432609765	2EF291	9155 733819	VLADIMIR STEPANOV	{"email": "stepanov-v.061973@postgrespro.ru", "phone": "+70440925459"}
0005432609766	A07DCE	0724 032461	ANTON SOLOVEV	{"phone": "+70855922237"}
0005432609767	6F741F	3194 531658	FANIL MAKAROV	{"email": "f.makarov.1972@postgrespro.ru", "phone": "+70436522094"}
0005432609768	200D3E	5263 900955	OLGA STEPANOVA	{"email": "stepanovaolga_1973@postgrespro.ru", "phone": "+70309149372"}
0005432609769	200D3E	4568 306988	ANTONINA SEMENOVA	{"phone": "+70986537049"}
0005432609770	2F9669	1609 552721	ALEKSEY GORBUNOV	{"phone": "+70878600698"}
0005432609771	031721	0244 938353	ELENA PETROVA	{"email": "petrovaelena.28111971@postgrespro.ru", "phone": "+70727259857"}
0005432609772	044428	4309 040613	DARYA SIDOROVA	{"phone": "+70185402685"}
0005432609773	E4403B	6249 195707	OLGA BORISOVA	{"phone": "+70280386065"}
0005432609774	E4403B	5510 070201	SERGEY GRIGOREV	{"email": "s_grigorev_1974@postgrespro.ru", "phone": "+70298690230"}
0005432609775	D08986	2587 243627	VALERIY SAVELEV	{"email": "vsavelev24121971@postgrespro.ru", "phone": "+70961513465"}
0005432609776	9C2927	8564 567079	VLADISLAV KOZLOV	{"email": "kozlov-vladislav29121974@postgrespro.ru", "phone": "+70687270513"}
0005432609777	23A8D8	0679 889943	KONSTANTIN ZAKHAROV	{"email": "konstantin_zakharov16051960@postgrespro.ru", "phone": "+70894054078"}
0005432609778	DF2154	1670 849426	SVETLANA MAKSIMOVA	{"email": "maksimovasvetlana.081963@postgrespro.ru", "phone": "+70993875441"}
0005432609779	0F87AE	5618 730383	ZAKHAR SMIRNOV	{"email": "zakhar_smirnov-1984@postgrespro.ru", "phone": "+70360966208"}
0005432609780	0F87AE	2443 607924	SVETLANA GUSEVA	{"phone": "+70658836333"}
0005432609781	8DE28A	0629 644337	SERGEY GORBUNOV	{"phone": "+70680331499"}
0005432609782	15FF62	4198 863835	VERA MOROZOVA	{"phone": "+70857788703"}
0005432609783	AE850E	5110 748576	VLADIMIR POPOV	{"email": "vladimir-popov-1971@postgrespro.ru", "phone": "+70740154507"}
0005432609784	112DFA	1570 697975	IVAN MAKAROV	{"phone": "+70955818060"}
0005432609785	892A49	3517 294278	ELENA ANISIMOVA	{"email": "anisimovaelena_051976@postgrespro.ru", "phone": "+70432863438"}
0005432609786	BB9C6B	6116 267419	VALENTINA SERGEEVA	{"email": "sergeevavalentina_19011979@postgrespro.ru", "phone": "+70685878661"}
0005432609787	BB9C6B	1362 763694	ELENA MAKAROVA	{"email": "makarova.elena_16071980@postgrespro.ru", "phone": "+70729348662"}
0005432609788	690BA9	6963 103804	IGOR YAKOVLEV	{"email": "yakovlev-igor.071962@postgrespro.ru", "phone": "+70359219120"}
0005432609789	41EFCD	3209 195842	ALBINA SIDOROVA	{"email": "albina_sidorova_30091981@postgrespro.ru", "phone": "+70182061246"}
0005432609790	49F35B	9166 987646	ALEKSANDR ZAYCEV	{"phone": "+70615971792"}
0005432609791	49F35B	6247 170173	VYACHESLAV YAKOVLEV	{"email": "yakovlev-v1970@postgrespro.ru", "phone": "+70066233730"}
0005432609792	B35616	2139 228592	ANDREY BARANOV	{"email": "abaranov_10031966@postgrespro.ru", "phone": "+70402750738"}
0005432609793	79C7B2	3242 122665	NINA BORISOVA	{"email": "borisova.nina_071975@postgrespro.ru", "phone": "+70495135745"}
0005432609794	79C7B2	7531 142131	ANATOLIY CHERNOV	{"email": "chernova111981@postgrespro.ru", "phone": "+70927971323"}
0005432609795	51C33A	7712 907311	MARINA KUZNECOVA	{"phone": "+70380217720"}
0005432609796	51C33A	8572 336022	NATALYA POPOVA	{"email": "popova.n-081974@postgrespro.ru", "phone": "+70532842255"}
0005432609797	DFD9DF	3302 337097	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-121976@postgrespro.ru", "phone": "+70319273318"}
0005432609798	DFD9DF	1121 142645	SVETLANA POTAPOVA	{"phone": "+70787230971"}
0005432609799	A8497D	7127 924646	IRINA MOROZOVA	{"phone": "+70976370317"}
0005432609800	A8497D	8189 958206	MARINA MIRONOVA	{"phone": "+70059340088"}
0005432609801	954818	3266 471083	EVGENIYA NESTEROVA	{"email": "nesterova_e-27071964@postgrespro.ru", "phone": "+70742994736"}
0005432609802	954818	1476 516535	POLINA MAKAROVA	{"email": "makarova_polina-1965@postgrespro.ru", "phone": "+70227837958"}
0005432609803	06300C	0203 440647	IVAN VOLKOV	{"phone": "+70111576708"}
0005432609804	06300C	0958 519133	MURAD ZHURAVLEV	{"email": "zhuravlev-murad-121971@postgrespro.ru", "phone": "+70244313363"}
0005432609805	06300C	7690 288516	EVGENIY GRIGOREV	{"phone": "+70359298144"}
0005432609806	FF6137	9810 736244	VIKTOR VASILEV	{"email": "vasilev.viktor-1962@postgrespro.ru", "phone": "+70128205106"}
0005432609807	FF6137	6987 135089	DANIIL FILIPPOV	{"phone": "+70203412963"}
0005432609808	FF6137	2139 844736	VALENTIN GRIGOREV	{"email": "grigorev-v1979@postgrespro.ru", "phone": "+70109312495"}
0005432609809	7B1AC0	1559 420191	RAIS MOISEEV	{"phone": "+70076849888"}
0005432609810	7B1AC0	4959 482508	MARIYA ZOTOVA	{"email": "m-zotova.1965@postgrespro.ru", "phone": "+70502080091"}
0005432609811	37E694	5138 157480	RUSHANIYA KOZLOVA	{"phone": "+70588376410"}
0005432609812	37E694	7765 455773	ALEKSEY BORISOV	{"phone": "+70432172136"}
0005432609813	37E694	6036 316274	MILANA SOKOLOVA	{"phone": "+70054685607"}
0005432609814	8933BA	1873 710881	NADEZHDA NOVIKOVA	{"phone": "+70473026919"}
0005432609815	8933BA	9821 406375	VALENTINA KUZNECOVA	{"email": "kuznecova_v_1966@postgrespro.ru", "phone": "+70026883597"}
0005432609816	4BE6A0	5964 613554	MAKSIM MEDVEDEV	{"email": "maksim.medvedev20111973@postgrespro.ru", "phone": "+70996772452"}
0005432609817	01EB12	8091 562858	VLADIMIR OSIPOV	{"email": "osipov-v_1967@postgrespro.ru", "phone": "+70437640855"}
0005432609818	01EB12	3722 546655	ALEKSEY SEMENOV	{"phone": "+70393177316"}
0005432609819	14171F	0134 718471	SERGEY FROLOV	{"phone": "+70977138187"}
0005432609820	14171F	4398 390964	LARISA KUZMINA	{"email": "kuzmina_l1969@postgrespro.ru", "phone": "+70355485680"}
0005432609821	A52081	8668 178072	MARINA FILIPPOVA	{"phone": "+70215088416"}
0005432609822	A52081	0218 859425	ANNA VASILEVA	{"phone": "+70599348399"}
0005432609823	439BF0	5713 349783	VLADISLAV NIKITIN	{"phone": "+70149730313"}
0005432609824	439BF0	1577 726443	DARYA MIKHAYLOVA	{"phone": "+70854774307"}
0005432609825	439BF0	6850 700279	NIKOLAY NIKOLAEV	{"email": "nikolaev_n_021967@postgrespro.ru", "phone": "+70672513771"}
0005432609826	B2F166	0215 011154	ARINA ANDREEVA	{"phone": "+70364749034"}
0005432609827	B2F166	3685 042807	ALENA KUZMINA	{"email": "a_kuzmina111981@postgrespro.ru", "phone": "+70299622202"}
0005432609828	68AE5D	5019 875575	YULIYA IVANOVA	{"phone": "+70829737893"}
0005432609829	422CF2	9403 134669	OLGA KOZLOVA	{"email": "kozlova.o1971@postgrespro.ru", "phone": "+70419180388"}
0005432609830	422CF2	0501 907140	EVGENIY BORISOV	{"phone": "+70916818888"}
0005432609831	3C79B3	9613 870786	ARINA NIKITINA	{"phone": "+70625942163"}
0005432609832	7E1997	9265 833375	SVETLANA GORBUNOVA	{"email": "gorbunova_svetlana_02121976@postgrespro.ru", "phone": "+70575900325"}
0005432609833	7E1997	5654 418407	KIRILL KUZNECOV	{"email": "k.kuznecov.101981@postgrespro.ru", "phone": "+70828067857"}
0005432609834	66304C	1244 467101	VLADIMIR ALEKSANDROV	{"email": "vladimir_aleksandrov-12011979@postgrespro.ru", "phone": "+70659259861"}
0005432609835	65968D	3458 274517	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov-1968@postgrespro.ru", "phone": "+70509559838"}
0005432609836	65968D	3932 654564	OLEG KUZNECOV	{"phone": "+70714645745"}
0005432609837	165641	7303 603640	VALERIYA NOVIKOVA	{"phone": "+70905638342"}
0005432609838	744C69	1743 419673	RADMIR TARASOV	{"email": "tarasov.r28011975@postgrespro.ru", "phone": "+70302191148"}
0005432609839	744C69	5942 318978	ALEKSANDRA GAVRILOVA	{"phone": "+70984962214"}
0005432609840	E23FA2	9366 041687	TATYANA EGOROVA	{"phone": "+70136095412"}
0005432609841	2907B1	4489 453388	VIKTOR SEMENOV	{"email": "semenov_v_1987@postgrespro.ru", "phone": "+70506624238"}
0005432609842	2907B1	4879 879904	EVGENIYA ZHUKOVA	{"phone": "+70704111828"}
0005432609843	E4E2FF	3971 417850	DENIS SCHERBAKOV	{"email": "scherbakov.denis_121973@postgrespro.ru", "phone": "+70585725348"}
0005432609844	168181	4078 258793	VERA DANILOVA	{"phone": "+70993875877"}
0005432609845	309875	2029 459057	TATYANA SOROKINA	{"phone": "+70086838459"}
0005432609846	309875	5874 939048	OLGA ABRAMOVA	{"email": "abramovaolga-1967@postgrespro.ru", "phone": "+70842776024"}
0005432609847	7E17F3	5464 950429	VLADISLAV MIKHAYLOV	{"phone": "+70353314879"}
0005432609848	94D450	7751 496482	DENIS DENISOV	{"phone": "+70039107514"}
0005432609849	56B8E0	1935 433473	SVETLANA MEDVEDEVA	{"email": "svetlana.medvedeva_1970@postgrespro.ru", "phone": "+70150254253"}
0005432609850	E01285	4718 657438	ALEKSANDRA GAVRILOVA	{"email": "gavrilova.a-15121972@postgrespro.ru", "phone": "+70784990388"}
0005432609851	E01285	5078 012041	VIKTOR CHERNOV	{"phone": "+70816622394"}
0005432609852	7BBE52	3060 177733	ANTON NOVIKOV	{"email": "novikov_anton.05111971@postgrespro.ru", "phone": "+70268168828"}
0005432611642	5374EE	2985 249241	LILIYA ANDREEVA	{"email": "andreeva.l_1971@postgrespro.ru", "phone": "+70661966009"}
0005432611643	0B0D0A	0323 633288	LIDIYA MAKAROVA	{"email": "makarova.lidiya.04031971@postgrespro.ru", "phone": "+70347370651"}
0005432611644	7807B9	9179 478720	MARIYA FROLOVA	{"phone": "+70182583873"}
0005432611645	88F56C	6036 521946	NINA ERMAKOVA	{"email": "ermakova-n_1996@postgrespro.ru", "phone": "+70341960242"}
0005432611646	0C5286	4538 488147	YURIY VASILEV	{"email": "yuriy.vasilev011969@postgrespro.ru", "phone": "+70075817042"}
0005432611647	8304E4	1550 018374	OKSANA KUZNECOVA	{"email": "kuznecova.o-08011967@postgrespro.ru", "phone": "+70415833475"}
0005432611648	A63DCE	7100 036902	MIKHAIL ZHURAVLEV	{"phone": "+70585126182"}
0005432611649	C450AE	4970 761272	NATALYA ALEKSANDROVA	{"email": "natalya_aleksandrova.021973@postgrespro.ru", "phone": "+70802060704"}
0005432611650	019460	0607 283951	NIKITA FEDOROV	{"email": "nfedorov111975@postgrespro.ru", "phone": "+70159337272"}
0005432611651	8C68FD	2652 956819	ALBINA MASLOVA	{"phone": "+70458732818"}
0005432611652	F33A69	3782 645469	EVGENIY AFANASEV	{"phone": "+70136810705"}
0005432611653	B75D1B	2094 958538	MARINA FEDOROVA	{"phone": "+70078888185"}
0005432611654	DCBF83	6630 611257	VIKTOR FEDOROV	{"email": "fedorov.v_25061975@postgrespro.ru", "phone": "+70572334760"}
0005432611655	AFB011	9071 911158	LYUBOV CHERNOVA	{"phone": "+70274530897"}
0005432611656	46494D	0850 265371	NINA CHERNOVA	{"email": "chernova-n1974@postgrespro.ru", "phone": "+70641762474"}
0005432611657	2D8F79	3364 710846	SVETLANA ZAYCEVA	{"email": "zaycevas_1973@postgrespro.ru", "phone": "+70492814367"}
0005432611658	4F6273	2385 676683	KLAVDIYA ARKHIPOVA	{"phone": "+70597734531"}
0005432611659	C66B20	5297 359889	MARINA NIKOLAEVA	{"email": "nikolaeva_marina02031971@postgrespro.ru", "phone": "+70776137832"}
0005432611660	C66B20	3233 094482	SVETLANA LAZAREVA	{"phone": "+70037245747"}
0005432611661	E79380	3690 595586	KIRILL TIKHONOV	{"phone": "+70530138988"}
0005432611662	E79380	4290 889364	ALEKSEY ANDREEV	{"email": "a-andreev.011984@postgrespro.ru", "phone": "+70065254002"}
0005432611663	6C9A9D	3031 260847	MIKHAIL ISAEV	{"email": "isaev_m_13011985@postgrespro.ru", "phone": "+70914376231"}
0005432611664	7E76A2	1334 271346	TIMUR RODIONOV	{"email": "rodionovtimur-121982@postgrespro.ru", "phone": "+70570399518"}
0005432611665	D9D091	8306 655388	MARIYA CHERNOVA	{"phone": "+70688782389"}
0005432611666	D9D091	8284 156117	VASILIY KOROLEV	{"phone": "+70478032579"}
0005432611667	6ABDAB	7239 480073	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-e_12121962@postgrespro.ru", "phone": "+70678231941"}
0005432611668	9D9B0C	5154 448297	ELENA SOLOVEVA	{"phone": "+70297345972"}
0005432611669	9D9B0C	2662 093373	ELIZAVETA MOISEEVA	{"email": "e.moiseeva_071972@postgrespro.ru", "phone": "+70090728626"}
0005432611670	669CDB	7486 462957	IVAN IVANOV	{"email": "iivanov-1978@postgrespro.ru", "phone": "+70391030457"}
0005432611671	669CDB	4717 631440	NIKOLAY DAVYDOV	{"phone": "+70079493646"}
0005432611672	27B65E	0461 492179	YURIY FROLOV	{"phone": "+70524695285"}
0005432611673	F97839	7719 558302	VERONIKA ZAKHAROVA	{"email": "veronikazakharova-051984@postgrespro.ru", "phone": "+70732802216"}
0005432611674	F97839	2841 110418	TAMARA ANDREEVA	{"phone": "+70649022267"}
0005432611675	5CA584	4157 907622	TATYANA SERGEEVA	{"phone": "+70845403400"}
0005432611676	28F3EC	2649 042851	TATYANA TARASOVA	{"phone": "+70402640536"}
0005432611677	28F3EC	4244 441126	MARINA FILATOVA	{"email": "filatova-marina.051974@postgrespro.ru", "phone": "+70213425728"}
0005432611678	28F3EC	9802 872227	VIKTORIYA FROLOVA	{"phone": "+70619378309"}
0005432611679	DAE6DF	4703 471710	VALENTINA GAVRILOVA	{"email": "gavrilova.valentina_06021983@postgrespro.ru", "phone": "+70352986724"}
0005432611680	841956	1554 287706	VADIM GUSEV	{"email": "vgusev-121970@postgrespro.ru", "phone": "+70012404560"}
0005432611681	07F7F4	4003 841407	EKATERINA ANISIMOVA	{"email": "anisimova_ekaterina-061971@postgrespro.ru", "phone": "+70378630750"}
0005432611682	302288	0867 366922	ANDREY EGOROV	{"email": "egorova_1982@postgrespro.ru", "phone": "+70917176566"}
0005432611683	221B32	3509 478645	NADEZHDA AFANASEVA	{"email": "afanaseva.n_08041979@postgrespro.ru", "phone": "+70047743217"}
0005432611684	A52962	8489 103405	VIKTOR CHERNOV	{"email": "v-chernov.031982@postgrespro.ru", "phone": "+70496092997"}
0005432611685	D3372F	4650 003937	ANASTASIYA ROMANOVA	{"phone": "+70654462642"}
0005432611686	6A0879	8014 861834	ILYA VOROBEV	{"phone": "+70089180006"}
0005432611687	02B7BB	0395 031397	ALINA DMITRIEVA	{"phone": "+70657365974"}
0005432611688	3B0E70	0892 818254	VLADIMIR STEPANOV	{"phone": "+70354191374"}
0005432611689	67FBB2	1886 806409	SERGEY ABRAMOV	{"phone": "+70009575333"}
0005432611690	CF638D	9588 682969	IRINA DANILOVA	{"phone": "+70643326472"}
0005432611691	97F181	3080 333861	VENIAMIN PETROV	{"phone": "+70243858431"}
0005432611692	97F181	1821 739540	EKATERINA KARPOVA	{"phone": "+70555052493"}
0005432611693	3CFB3C	5076 744551	GALINA EGOROVA	{"phone": "+70385825376"}
0005432611694	420CC9	9245 575235	VIKTOR MIKHAYLOV	{"email": "mikhaylov-viktor_1974@postgrespro.ru", "phone": "+70378273703"}
0005432611695	D74738	8620 562622	ELENA NIKITINA	{"email": "nikitina_elena-011976@postgrespro.ru", "phone": "+70512772270"}
0005432611696	F736A6	1713 549065	ANASTASIYA SAVELEVA	{"email": "a-saveleva_1966@postgrespro.ru", "phone": "+70627925882"}
0005432611697	F736A6	5056 541104	VLADIMIR GRIGOREV	{"phone": "+70672906095"}
0005432611698	F736A6	2468 517842	ALEKSANDR YAKOVLEV	{"phone": "+70483262823"}
0005432611699	631ADF	5130 131512	VLADIMIR KUZMIN	{"email": "kuzmin_v041968@postgrespro.ru", "phone": "+70904920340"}
0005432611700	580997	2781 477399	VALERIY MOISEEV	{"email": "moiseev-v_20081978@postgrespro.ru", "phone": "+70687742238"}
0005432611701	6852AF	7921 826130	PAVEL MAKSIMOV	{"email": "maksimov-p_1970@postgrespro.ru", "phone": "+70311868315"}
0005432611702	6852AF	7099 326141	MIKHAIL KUZNECOV	{"phone": "+70041257347"}
0005432611703	0D8207	5114 665489	VALERIY IVANOV	{"email": "ivanovv101968@postgrespro.ru", "phone": "+70041033411"}
0005432611704	52DA7A	9509 948677	TATYANA VOROBEVA	{"email": "tatyana-vorobeva-10111977@postgrespro.ru", "phone": "+70955837879"}
0005432611705	C1C71B	6457 009808	NADEZHDA EGOROVA	{"email": "n-egorova.1967@postgrespro.ru", "phone": "+70038213670"}
0005432611706	186598	1461 173650	OLGA ALEKSANDROVA	{"email": "olga.aleksandrova.23081971@postgrespro.ru", "phone": "+70178565997"}
0005432611707	A8F453	4969 700784	RAUZA MIRONOVA	{"email": "mironova.r.29011976@postgrespro.ru", "phone": "+70316484297"}
0005432611708	A62F35	1676 918075	YULIYA IVANOVA	{"email": "ivanovay.04071963@postgrespro.ru", "phone": "+70905378629"}
0005432611709	A62F35	3293 216391	ANNA NIKITINA	{"email": "anna.nikitina_061973@postgrespro.ru", "phone": "+70718441482"}
0005432611710	7A85CC	1125 095254	VLADIMIR ROMANOV	{"email": "vladimir-romanov.1982@postgrespro.ru", "phone": "+70927036000"}
0005432611711	7A85CC	8099 957513	IGOR IVANOV	{"phone": "+70620359258"}
0005432611712	BA9BA6	4184 830240	SERGEY GRIGOREV	{"email": "sergeygrigorev_1971@postgrespro.ru", "phone": "+70896237418"}
0005432611713	864C6C	3191 828913	TIMUR PETROV	{"phone": "+70881375564"}
0005432611714	244930	5992 522472	ALLA KAZAKOVA	{"phone": "+70744498528"}
0005432611715	DFD81A	0072 495420	DENIS GAVRILOV	{"phone": "+70372463416"}
0005432611716	606EAC	4316 057245	YURIY MAKSIMOV	{"phone": "+70733543034"}
0005432611717	3ED0D5	8870 654255	VALERIY DENISOV	{"email": "denisov_valeriy-1975@postgrespro.ru", "phone": "+70051180024"}
0005432611718	3ED0D5	2745 191773	IGOR TIMOFEEV	{"email": "timofeevigor.1984@postgrespro.ru", "phone": "+70341765555"}
0005432611719	D857A5	3795 653510	OLGA ALEKSANDROVA	{"email": "olga.aleksandrova1971@postgrespro.ru", "phone": "+70768821276"}
0005432611720	D857A5	8815 881537	VLADIMIR MOROZOV	{"phone": "+70600964969"}
0005432611721	F7B072	3361 534598	ANNA ILINA	{"phone": "+70207212318"}
0005432611722	681971	8230 992233	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova_051982@postgrespro.ru", "phone": "+70969973992"}
0005432611723	562BF1	1176 820329	ALEKSANDR ROMANOV	{"phone": "+70371185209"}
0005432611724	284E8F	7316 114084	ANATOLIY NIKOLAEV	{"email": "anikolaev_06081977@postgrespro.ru", "phone": "+70158177503"}
0005432611725	284E8F	4951 184798	ULYANA MAKSIMOVA	{"email": "ulyana-maksimova.02081972@postgrespro.ru", "phone": "+70266642839"}
0005432611726	83C612	2398 017597	SERGEY YAKOVLEV	{"email": "s-yakovlev091972@postgrespro.ru", "phone": "+70280248281"}
0005432611727	83C612	5473 619035	ALEKSANDRA KOROLEVA	{"phone": "+70057626060"}
0005432611728	4D2FD5	7336 312593	ELIZAVETA MIRONOVA	{"phone": "+70291993611"}
0005432611729	A369AE	4366 383213	LYUDMILA ALEKSEEVA	{"email": "lyudmila-alekseeva101964@postgrespro.ru", "phone": "+70288973982"}
0005432611730	A369AE	4163 881796	ALEKSANDRA SAVELEVA	{"phone": "+70875722995"}
0005432611731	C33893	5486 698777	NIKOLAY SOKOLOV	{"phone": "+70284020324"}
0005432611732	212638	4491 075905	OLESYA MIRONOVA	{"email": "olesyamironova_15101977@postgrespro.ru", "phone": "+70764064909"}
0005432611733	25C6F8	2620 793074	ALEKSEY IVANOV	{"email": "aivanov-1975@postgrespro.ru", "phone": "+70392226317"}
0005432611734	DF4611	4096 095190	SERGEY MOROZOV	{"email": "morozov_s_02071964@postgrespro.ru", "phone": "+70676343194"}
0005432611735	DF4611	9261 617971	OLGA IVANOVA	{"phone": "+70865925439"}
0005432611736	DF4611	2395 482800	EVGENIYA IVANOVA	{"phone": "+70886098770"}
0005432611737	CEB274	1847 251021	LYUBOV SCHERBAKOVA	{"email": "scherbakova_l-041974@postgrespro.ru", "phone": "+70380407593"}
0005432611738	232C9E	6471 841414	LYUBOV KAZAKOVA	{"email": "kazakova.l-1964@postgrespro.ru", "phone": "+70782323998"}
0005432611739	7D1C72	2023 803124	LYUDMILA GRISHINA	{"phone": "+70619307440"}
0005432611740	7D1C72	2343 814853	ALEKSEY MAKAROV	{"email": "makarov.a-081982@postgrespro.ru", "phone": "+70399659759"}
0005432611741	96832B	9230 955299	EVGENIY DAVYDOV	{"phone": "+70798947582"}
0005432611742	4AA6F4	5647 584864	FAINA FILATOVA	{"email": "ffilatova-11101981@postgrespro.ru", "phone": "+70980669676"}
0005432611743	10CCA1	9316 340139	INNA KONDRATEVA	{"phone": "+70364053538"}
0005432611744	10CCA1	2467 658521	VITALIY BARANOV	{"email": "v.baranov1965@postgrespro.ru", "phone": "+70340862299"}
0005432611745	C04A2F	1874 270621	SVETLANA YUDINA	{"email": "svetlanayudina_02041967@postgrespro.ru", "phone": "+70001827864"}
0005432611746	8F9DBE	7695 442026	NADEZHDA NIKITINA	{"email": "nadezhdanikitina-1970@postgrespro.ru", "phone": "+70197785370"}
0005432611747	8F9DBE	9144 364748	ANNA FROLOVA	{"email": "a_frolova-031975@postgrespro.ru", "phone": "+70175262920"}
0005432611748	8F9DBE	6764 619577	EKATERINA PETROVA	{"phone": "+70857025253"}
0005432611749	E4CB3D	0147 360653	ALEKSEY SOKOLOV	{"phone": "+70628418421"}
0005432611750	E4CB3D	3113 674227	MARINA FILIPPOVA	{"email": "m_filippova-11101967@postgrespro.ru", "phone": "+70957669973"}
0005432611751	47A6CF	6533 412284	ANNA FILIPPOVA	{"phone": "+70824823391"}
0005432611752	FF114D	6770 440037	ZINAIDA KULIKOVA	{"phone": "+70057074106"}
0005432611753	2E9C80	8892 604510	TATYANA DANILOVA	{"email": "tatyana-danilova.03051977@postgrespro.ru", "phone": "+70916561378"}
0005432611754	2E9C80	3274 375995	ILYA ABRAMOV	{"phone": "+70665919704"}
0005432611755	2E9C80	2144 066513	ZINAIDA ZHURAVLEVA	{"email": "zhuravleva.z_011985@postgrespro.ru", "phone": "+70842385530"}
0005432611756	6DF9FE	3336 787336	VLADIMIR KUDRYASHOV	{"phone": "+70413388082"}
0005432611757	6DF9FE	6569 925423	ALEKSANDRA MAKSIMOVA	{"email": "maksimova.aleksandra.101985@postgrespro.ru", "phone": "+70855056693"}
0005432611758	2A1407	1293 946517	VIKTOR DMITRIEV	{"phone": "+70200509877"}
0005432611759	99A043	3539 755154	NINA NAUMOVA	{"email": "naumova_nina.011975@postgrespro.ru", "phone": "+70745705013"}
0005432611760	B77907	3072 457430	ANASTASIYA KAZAKOVA	{"email": "kazakovaa081972@postgrespro.ru", "phone": "+70495015527"}
0005432611761	A618BC	4807 844138	OLESYA FROLOVA	{"phone": "+70004646982"}
0005432611762	73354F	6039 109157	DMITRIY FOMIN	{"phone": "+70690549757"}
0005432611763	73354F	9492 275469	ZOYA POLYAKOVA	{"email": "z.polyakova.121962@postgrespro.ru", "phone": "+70661479626"}
0005432611764	79D5E7	4881 964166	YULIYA KOZLOVA	{"phone": "+70905785626"}
0005432611765	79D5E7	1876 537287	RITA YAKOVLEVA	{"email": "r_yakovleva-06041966@postgrespro.ru", "phone": "+70381318310"}
0005432611766	C7CA4F	9501 657648	SVETLANA VASILEVA	{"email": "vasileva_svetlana.03011966@postgrespro.ru", "phone": "+70389101564"}
0005432611767	1FA98C	9734 751826	LYUBOV ZAKHAROVA	{"phone": "+70567387231"}
0005432611768	1FA98C	9750 511980	RUSTAM POPOV	{"phone": "+70304005786"}
0005432611769	5AAFE9	2585 598654	EGOR SAVELEV	{"email": "savelev-egor.1982@postgrespro.ru", "phone": "+70776502477"}
0005432611770	B9AC70	7377 920406	LARISA GORBUNOVA	{"phone": "+70511445900"}
0005432611771	E11A05	3652 304754	KONSTANTIN MOISEEV	{"phone": "+70766969015"}
0005432611772	E11A05	1144 419698	OLGA NIKITINA	{"email": "nikitina_o121981@postgrespro.ru", "phone": "+70164290497"}
0005432611773	FC1BB3	4651 887060	ANDREY DENISOV	{"email": "adenisov-091975@postgrespro.ru", "phone": "+70918144883"}
0005432611774	FC1BB3	6897 820517	TATYANA ALEKSANDROVA	{"phone": "+70700993747"}
0005432611775	A8A150	8613 405504	SERGEY TIKHONOV	{"phone": "+70606909433"}
0005432611776	8D00A8	8642 685051	VALENTINA LEBEDEVA	{"phone": "+70022750449"}
0005432611777	BF5E32	1948 542216	SERGEY ORLOV	{"phone": "+70855588130"}
0005432611778	50A322	5626 934423	NIKOLAY MAKAROV	{"phone": "+70072684337"}
0005432611779	50A322	2705 076255	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr12031984@postgrespro.ru", "phone": "+70219176396"}
0005432611780	D785BC	4169 415866	ALISA TIKHONOVA	{"phone": "+70687641187"}
0005432611781	A23CF4	6557 369223	SERGEY YAKOVLEV	{"email": "s_yakovlev.111976@postgrespro.ru", "phone": "+70366695440"}
0005432611782	AF16E6	2263 612724	SERGEY KAZAKOV	{"phone": "+70306934071"}
0005432611783	AF16E6	2054 630966	RUSTAM VOLKOV	{"phone": "+70933411738"}
0005432611784	C834D9	9511 895643	PAVEL MIRONOV	{"email": "pavelmironov_1978@postgrespro.ru", "phone": "+70419359144"}
0005432611785	FB401E	3806 756786	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir.02061971@postgrespro.ru", "phone": "+70244236734"}
0005432611786	D4CCDC	1517 644797	OLGA LEBEDEVA	{"phone": "+70692917511"}
0005432611787	D4CCDC	5620 963912	TATYANA VOLKOVA	{"phone": "+70884790342"}
0005432611788	2DFCDB	2891 675394	KSENIYA MEDVEDEVA	{"email": "medvedeva.kseniya.021974@postgrespro.ru", "phone": "+70744996791"}
0005432611789	2DFCDB	7749 038770	ANASTASIYA SEMENOVA	{"email": "a_semenova.02071977@postgrespro.ru", "phone": "+70268317227"}
0005432611790	137B74	1435 616966	NINA MIKHAYLOVA	{"email": "mikhaylova_n1976@postgrespro.ru", "phone": "+70322097753"}
0005432611791	137B74	1757 607920	IRINA KUDRYASHOVA	{"phone": "+70894469449"}
0005432611792	FBF378	7771 793898	MAKSIM KULIKOV	{"email": "maksim_kulikov-03061975@postgrespro.ru", "phone": "+70154116113"}
0005432611793	F4E2A2	9073 477073	DINA ZHURAVLEVA	{"phone": "+70340940182"}
0005432611794	5BC44C	8883 204058	ELENA MOROZOVA	{"email": "morozova-elena101977@postgrespro.ru", "phone": "+70791931742"}
0005432611795	5BC44C	9417 763057	ALEKSANDR TIMOFEEV	{"phone": "+70280393024"}
0005432611796	78E390	9778 841695	VIKTOR BARANOV	{"email": "baranov.viktor-031980@postgrespro.ru", "phone": "+70636947655"}
0005432611797	78E390	6607 352640	ALEKSANDR VOLKOV	{"phone": "+70318753951"}
0005432611798	A22527	9416 185475	ALEKSEY MIKHAYLOV	{"phone": "+70343455837"}
0005432611799	64FDFB	9488 535117	NIKITA SMIRNOV	{"phone": "+70458293619"}
0005432611800	CF3C59	7253 247345	NINA KISELEVA	{"email": "kiseleva_n_051963@postgrespro.ru", "phone": "+70081286072"}
0005432611801	CF3C59	4960 261078	VIKTOR GORBUNOV	{"phone": "+70591854639"}
0005432611802	5FCE84	4301 597711	MARIYA KUZNECOVA	{"phone": "+70228170315"}
0005432611803	7B8212	9528 834194	YULIYA FOMINA	{"email": "fomina.yuliya011980@postgrespro.ru", "phone": "+70329417615"}
0005432611804	7B8212	1504 043916	YULIYA KUZNECOVA	{"phone": "+70876992976"}
0005432611805	13E31D	1896 176131	LYUDMILA VASILEVA	{"phone": "+70021017377"}
0005432611806	9F2258	8641 861380	EKATERINA ABRAMOVA	{"phone": "+70279899205"}
0005432611807	5DA47D	0716 118118	SVETLANA ERMAKOVA	{"phone": "+70818480784"}
0005432611808	5DA47D	4428 094736	NIKITA ABRAMOV	{"phone": "+70603969347"}
0005432611809	2E9AB8	0543 398839	ANATOLIY VLASOV	{"email": "anatoliy-vlasov17051967@postgrespro.ru", "phone": "+70654820861"}
0005432611810	2E9AB8	8560 949982	VALENTINA MIKHAYLOVA	{"phone": "+70682494467"}
0005432611811	DDAF2C	6074 273686	ROMAN FILIPPOV	{"email": "filippov.r1976@postgrespro.ru", "phone": "+70475970947"}
0005432611812	5695F7	1898 201812	ZINAIDA MAKSIMOVA	{"phone": "+70556107199"}
0005432611813	50D92D	4932 970693	VERA MATVEEVA	{"email": "matveeva-vera26061973@postgrespro.ru", "phone": "+70632441076"}
0005432611814	50D92D	9583 375750	DARYA ORLOVA	{"email": "d.orlova.15071961@postgrespro.ru", "phone": "+70131027996"}
0005432611815	723123	5702 992623	ANASTASIYA AFANASEVA	{"phone": "+70490566576"}
0005432611816	723123	4682 049791	ELENA MOISEEVA	{"phone": "+70750515176"}
0005432611817	723123	0031 617532	SERGEY OSIPOV	{"phone": "+70487240675"}
0005432611818	07E603	2211 380929	YULIYA POPOVA	{"email": "y-popova17121969@postgrespro.ru", "phone": "+70294038011"}
0005432613843	2B04FA	9136 348260	MARGARITA LOGINOVA	{"phone": "+70096334442"}
0005432613789	119F8B	4391 152660	DARYA KAZAKOVA	{"phone": "+70468516282"}
0005432613790	EA3875	0495 997190	IRINA LUKYANOVA	{"phone": "+70922845130"}
0005432613791	BBF183	9337 026085	ANDREY YAKOVLEV	{"phone": "+70469096633"}
0005432613792	BBF183	4200 349013	VALENTINA CHERNOVA	{"phone": "+70902077357"}
0005432613793	55A679	0111 822329	VLADIMIR ANDREEV	{"phone": "+70776932926"}
0005432613794	8C18C9	8016 052320	MIKHAIL PETROV	{"email": "m.petrov08021968@postgrespro.ru", "phone": "+70119220998"}
0005432613795	04F93A	9553 171583	ANDREY VLASOV	{"email": "vlasovandrey_121966@postgrespro.ru", "phone": "+70486019310"}
0005432613796	04F93A	5618 614776	EKATERINA TITOVA	{"email": "titova_e03021972@postgrespro.ru", "phone": "+70457448273"}
0005432613797	35C6E1	8776 161293	GALINA ISAEVA	{"email": "galina.isaeva_041970@postgrespro.ru", "phone": "+70201141757"}
0005432613798	19EF2B	2409 981198	ANDREY FROLOV	{"email": "a_frolov_20021968@postgrespro.ru", "phone": "+70401369246"}
0005432613799	5F924A	3772 689575	TATYANA LEBEDEVA	{"email": "lebedevatatyana_061974@postgrespro.ru", "phone": "+70408126700"}
0005432613800	56FC78	6737 016552	MARINA BELOVA	{"phone": "+70777347175"}
0005432613801	E46419	1883 473419	VLADIMIR MATVEEV	{"email": "matveev_v.1960@postgrespro.ru", "phone": "+70184609930"}
0005432613802	E46419	9557 534138	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila.1991@postgrespro.ru", "phone": "+70382223636"}
0005432613803	093813	2563 933888	EVGENIY EGOROV	{"phone": "+70747149274"}
0005432613804	0862D0	7105 040288	OLGA POLYAKOVA	{"phone": "+70639176481"}
0005432613805	0862D0	2689 531710	NIKOLAY IVANOV	{"phone": "+70241527823"}
0005432613806	608D21	7817 364305	ZINAIDA MALYSHEVA	{"email": "z-malysheva_1963@postgrespro.ru", "phone": "+70109080570"}
0005432613807	DD2921	3615 729107	VALERIY ORLOV	{"phone": "+70195281063"}
0005432613808	DD2921	8692 083328	ALEKSANDRA ERMAKOVA	{"phone": "+70116320138"}
0005432613809	C29E82	4953 584869	MAKSIM KOZLOV	{"email": "m_kozlov051967@postgrespro.ru", "phone": "+70323598465"}
0005432613810	C29E82	1588 061373	OLGA NIKIFOROVA	{"phone": "+70729851863"}
0005432613811	4520AD	3769 059840	STEPAN KONOVALOV	{"phone": "+70531047249"}
0005432613812	B2C03E	5048 339040	NIKOLAY IVANOV	{"email": "nikolay-ivanov.1969@postgrespro.ru", "phone": "+70882880921"}
0005432613813	6788C3	5324 929700	YULIYA OSIPOVA	{"phone": "+70672658049"}
0005432613814	6788C3	1299 206875	LEONID MELNIKOV	{"email": "melnikovleonid-1980@postgrespro.ru", "phone": "+70249052123"}
0005432613815	0A2D97	9430 591256	ANDREY STEPANOV	{"phone": "+70097212580"}
0005432613816	BCC3DD	4993 026527	TATYANA LAZAREVA	{"phone": "+70165899316"}
0005432613817	BCC3DD	9454 138263	YULIYA YAKOVLEVA	{"email": "yuliyayakovleva-051975@postgrespro.ru", "phone": "+70185135377"}
0005432613818	BCC3DD	4334 937789	YULIYA DAVYDOVA	{"email": "davydova-yuliya_021971@postgrespro.ru", "phone": "+70747486056"}
0005432613819	67761F	0075 149017	RASHID MAKAROV	{"email": "rmakarov_111969@postgrespro.ru", "phone": "+70189702567"}
0005432613820	C3EBCE	8601 029922	ALLA POPOVA	{"email": "a.popova_1974@postgrespro.ru", "phone": "+70115277729"}
0005432613821	C3EBCE	2063 742480	GENNADIY VOROBEV	{"email": "vorobev.gennadiy.1976@postgrespro.ru", "phone": "+70734033181"}
0005432613822	4C16DD	4307 201596	MARIYA PETROVA	{"phone": "+70347227086"}
0005432613823	BB78FD	0027 650528	ELENA KOZLOVA	{"email": "e-kozlova1973@postgrespro.ru", "phone": "+70417725458"}
0005432613824	B2AC59	0690 405650	RAVIL BELOV	{"email": "rbelov-1975@postgrespro.ru", "phone": "+70504577095"}
0005432613825	2CF266	9488 843206	SVETLANA NESTEROVA	{"phone": "+70841172146"}
0005432613826	2CF266	4245 817464	ALEKSEY GERASIMOV	{"phone": "+70125029183"}
0005432613827	BC3019	5621 799159	ALEKSANDR VOLKOV	{"phone": "+70797456003"}
0005432613828	BC3019	1187 684522	MIKHAIL KUDRYASHOV	{"phone": "+70732770842"}
0005432613829	048393	4521 891492	ANDREY FROLOV	{"email": "andrey_frolov_10051974@postgrespro.ru", "phone": "+70340017460"}
0005432613830	048393	1709 154417	ELENA MAKSIMOVA	{"email": "maksimovaelena.051967@postgrespro.ru", "phone": "+70877885949"}
0005432613831	4CA2BD	1641 975633	ANTONINA GUSEVA	{"email": "a.guseva-051974@postgrespro.ru", "phone": "+70081097749"}
0005432613832	4CA2BD	1947 635952	SERGEY SOLOVEV	{"email": "sergey_solovev_20111978@postgrespro.ru", "phone": "+70720188051"}
0005432613833	32245C	6680 230654	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr031974@postgrespro.ru", "phone": "+70069925186"}
0005432613834	32245C	4337 013088	ALEKSEY ANTONOV	{"phone": "+70814543658"}
0005432613835	5957ED	9313 929790	ROMAN MIKHAYLOV	{"email": "mikhaylov.roman12041981@postgrespro.ru", "phone": "+70258929220"}
0005432613836	4844EF	4978 512757	YULIYA POPOVA	{"phone": "+70731798582"}
0005432613837	375026	8334 422979	NINA SERGEEVA	{"phone": "+70829705190"}
0005432613838	375026	0015 378755	ANNA ZAKHAROVA	{"email": "zakharova.a_1970@postgrespro.ru", "phone": "+70153198741"}
0005432613839	AD2D89	3709 120033	VERONIKA POPOVA	{"email": "popova_v.30081963@postgrespro.ru", "phone": "+70464212853"}
0005432613840	787494	2530 607581	OLGA VASILEVA	{"phone": "+70528708735"}
0005432613841	DB5A58	2982 681561	TATYANA MOROZOVA	{"phone": "+70567307890"}
0005432613842	2B04FA	2204 148187	MARIYA ZHUKOVA	{"phone": "+70479312635"}
0005432613844	38FCF3	8153 359527	ELENA FADEEVA	{"email": "e.fadeeva_1964@postgrespro.ru", "phone": "+70064814872"}
0005432613845	AA6F8E	6513 818695	NATALYA OSIPOVA	{"email": "n-osipova_031978@postgrespro.ru", "phone": "+70596976858"}
0005432613846	AA6F8E	5701 261954	RAUZA BELYAEVA	{"email": "belyaeva_rauza.1968@postgrespro.ru", "phone": "+70440640746"}
0005432613847	6E0839	1153 196478	ALEKSANDRA KAZAKOVA	{"email": "aleksandra-kazakova051973@postgrespro.ru", "phone": "+70548673176"}
0005432613848	FA0452	1038 327208	VITALIY SOLOVEV	{"phone": "+70756706187"}
0005432613849	EE4FEF	7238 622784	EVGENIY RODIONOV	{"phone": "+70556995558"}
0005432613850	EE4FEF	5347 753450	ANNA NESTEROVA	{"phone": "+70251223331"}
0005432613851	85BE7F	5060 811654	GALINA NESTEROVA	{"email": "g.nesterova-09071961@postgrespro.ru", "phone": "+70877154463"}
0005432613852	85BE7F	7923 340032	MIKHAIL ALEKSEEV	{"email": "m.alekseev111972@postgrespro.ru", "phone": "+70972774080"}
0005432613853	841F69	8057 645563	ALEKSANDR IVANOV	{"phone": "+70404551857"}
0005432613854	3EEC54	3308 621285	DMITRIY PETROV	{"phone": "+70084278725"}
0005432613855	BAB922	8865 687089	ANATOLIY TARASOV	{"email": "anatoliy.tarasov101967@postgrespro.ru", "phone": "+70333302411"}
0005432613856	4BE98C	2071 005379	SERGEY MIKHAYLOV	{"phone": "+70115751686"}
0005432613857	4BE98C	3525 078604	IRAIDA KUZNECOVA	{"email": "ikuznecova-23101966@postgrespro.ru", "phone": "+70697820350"}
0005432613858	E933F4	7691 326454	NIKOLAY FEDOROV	{"phone": "+70625333543"}
0005432613859	E933F4	7835 935090	ANDREY NAZAROV	{"email": "nazarov_andrey.1965@postgrespro.ru", "phone": "+70651982246"}
0005432613860	A2DFAA	9545 178955	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr041978@postgrespro.ru", "phone": "+70602121993"}
0005432613861	11D1F2	4587 807212	SERGEY KONOVALOV	{"email": "konovalov_s1966@postgrespro.ru", "phone": "+70024786786"}
0005432613862	276D9D	0128 017078	NADEZHDA SEMENOVA	{"email": "nadezhdasemenova.1970@postgrespro.ru", "phone": "+70060311886"}
0005432613863	8B140C	4523 346754	ALEKSEY IVANOV	{"phone": "+70887520652"}
0005432613864	8B140C	6100 089956	ELENA SMIRNOVA	{"phone": "+70716651203"}
0005432613865	0C3018	7586 353435	NADEZHDA BOGDANOVA	{"email": "nadezhda.bogdanova21071978@postgrespro.ru", "phone": "+70333203114"}
0005432613866	2D6B12	5933 640010	NIKITA NOVIKOV	{"email": "novikov-n_011963@postgrespro.ru", "phone": "+70540741732"}
0005432613867	2D6B12	5585 748609	VLADIMIR GERASIMOV	{"email": "v-gerasimov-1987@postgrespro.ru", "phone": "+70115211455"}
0005432613868	7DE7F4	2249 820427	ANDREY MAKAROV	{"phone": "+70465536377"}
0005432613869	42C90D	6164 022804	EVGENIY VASILEV	{"email": "vasilev_evgeniy_1971@postgrespro.ru", "phone": "+70813492781"}
0005432613870	BB8BC7	8864 058161	ZAKHAR NIKITIN	{"email": "z-nikitin101969@postgrespro.ru", "phone": "+70225237918"}
0005432613871	4D9E6F	0757 079717	VLADIMIR ANDREEV	{"phone": "+70466155612"}
0005432613872	2BDA36	4387 809131	VALENTINA MELNIKOVA	{"phone": "+70864946709"}
0005432613873	65ECF0	6236 786278	ELENA AKIMOVA	{"email": "akimova.e.051974@postgrespro.ru", "phone": "+70146914984"}
0005432613874	65ECF0	9428 906640	SVETLANA MARTYNOVA	{"phone": "+70349076375"}
0005432613875	99EF90	3186 715054	ALEKSANDR TARASOV	{"email": "a_tarasov1970@postgrespro.ru", "phone": "+70610093654"}
0005432613876	0968CD	7434 956388	TATYANA MASLOVA	{"email": "tatyana-maslova_1964@postgrespro.ru", "phone": "+70760615914"}
0005432613877	D1A163	3405 457357	NAILYA NOVIKOVA	{"phone": "+70303628232"}
0005432613878	D1A163	9711 712287	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana-051971@postgrespro.ru", "phone": "+70598822941"}
0005432613879	D693D2	2940 476558	NIKOLAY GAVRILOV	{"email": "nikolay-gavrilov.20041963@postgrespro.ru", "phone": "+70859684266"}
0005432613880	D693D2	4019 188020	SOFYA ROMANOVA	{"phone": "+70360631064"}
0005432613881	D693D2	9769 285028	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr.1968@postgrespro.ru", "phone": "+70311975212"}
0005432613882	BF4119	6219 576632	ALEKSANDRA SCHERBAKOVA	{"email": "a_scherbakova_1968@postgrespro.ru", "phone": "+70519587501"}
0005432613883	B5CAE0	3775 909856	NIKITA MATVEEV	{"phone": "+70935168182"}
0005432613884	B5CAE0	4009 079417	ANTONIDA FEDOROVA	{"email": "antonida.fedorova081968@postgrespro.ru", "phone": "+70651955491"}
0005432613885	D5EF77	1975 169101	ARTEMIY IVANOV	{"phone": "+70365779539"}
0005432613886	4D7F85	3752 459909	VALENTINA KOMAROVA	{"phone": "+70096242045"}
0005432613887	4D7F85	5092 427013	NATALYA FROLOVA	{"email": "frolova_natalya-1981@postgrespro.ru", "phone": "+70349597047"}
0005432613888	6B42B7	2814 346709	IVAN FOMIN	{"email": "ifomin.06111976@postgrespro.ru", "phone": "+70724407113"}
0005432613889	6B42B7	8061 361658	VERA ZAKHAROVA	{"email": "v.zakharova.041967@postgrespro.ru", "phone": "+70856406152"}
0005432613890	52915C	9560 362506	ELDAR SIDOROV	{"phone": "+70087395538"}
0005432613891	5F8BC8	0194 027422	MARIYA KUZNECOVA	{"email": "m-kuznecova.1974@postgrespro.ru", "phone": "+70908324942"}
0005432613892	40E9F2	3671 635260	POLINA SAVELEVA	{"phone": "+70110397762"}
0005432613893	40E9F2	1677 792844	MARIYA ZHUKOVA	{"email": "mariya_zhukova.101973@postgrespro.ru", "phone": "+70965502763"}
0005432613894	1CB1AF	5966 189390	VALERIY NAZAROV	{"email": "v_nazarov1975@postgrespro.ru", "phone": "+70834151246"}
0005432613895	256BD6	3780 291713	VADIM ZAKHAROV	{"phone": "+70120851923"}
0005432613896	256BD6	8726 331687	VIKTOR SOKOLOV	{"email": "sokolov_v_1976@postgrespro.ru", "phone": "+70870401702"}
0005432613897	5726A7	8796 390314	VERA SMIRNOVA	{"email": "smirnova_vera.29101981@postgrespro.ru", "phone": "+70561450909"}
0005432613898	C03992	8196 067077	MARIYA MIRONOVA	{"phone": "+70184629837"}
0005432613899	4F49E3	0500 321499	IGOR SEMENOV	{"phone": "+70566348627"}
0005432613900	41A7D5	0088 072131	YURIY ISAEV	{"phone": "+70350249434"}
0005432613901	ECE2B7	2248 989804	VLADIMIR SEMENOV	{"email": "v.semenov_1975@postgrespro.ru", "phone": "+70179900601"}
0005432613902	ECE2B7	6635 804411	ELENA BARANOVA	{"email": "e-baranova.28111977@postgrespro.ru", "phone": "+70634707070"}
0005432613903	085906	6031 317708	OLGA ALEKSEEVA	{"email": "olga-alekseeva_051970@postgrespro.ru", "phone": "+70260571386"}
0005432613904	CF1CC1	4308 332277	ALINA KUZNECOVA	{"phone": "+70667734612"}
0005432613905	CF1CC1	2251 129715	NATALIYA VOLKOVA	{"phone": "+70852269954"}
0005432613906	564CBE	1744 683741	PETR KOZLOV	{"phone": "+70217309657"}
0005432613907	03E56E	1540 914964	GENNADIY ZAKHAROV	{"email": "gennadiy.zakharov-1970@postgrespro.ru", "phone": "+70336426412"}
0005432613908	68A531	6087 244842	SVETLANA FILIPPOVA	{"email": "s_filippova-1979@postgrespro.ru", "phone": "+70463932562"}
0005432613909	68A531	5839 425599	VASILIY SMIRNOV	{"email": "vasiliysmirnov_041973@postgrespro.ru", "phone": "+70524246123"}
0005432613910	B4A3F0	4287 177759	VALENTINA NIKIFOROVA	{"email": "nikiforova-valentina_30061971@postgrespro.ru", "phone": "+70562205134"}
0005432613911	25471D	4804 870673	MIKHAIL SCHERBAKOV	{"email": "mscherbakov_05071970@postgrespro.ru", "phone": "+70289634725"}
0005432613912	805D0A	3530 630623	VALENTINA KOVALEVA	{"email": "v.kovaleva-1971@postgrespro.ru", "phone": "+70203164169"}
0005432613913	805D0A	6601 329440	ALEKSANDR KUZMIN	{"email": "kuzmin_a-1969@postgrespro.ru", "phone": "+70842016859"}
0005432613914	D9839F	6478 116581	LYUDMILA TITOVA	{"phone": "+70629050000"}
0005432613915	D9839F	3405 381519	MARINA GORBUNOVA	{"phone": "+70681202857"}
0005432613916	9A4D0A	0116 753449	GALINA BELYAEVA	{"phone": "+70704476450"}
0005432613917	9A4D0A	6299 577169	SERGEY VOLKOV	{"email": "s.volkov.15121979@postgrespro.ru", "phone": "+70924986317"}
0005432613918	8BEB64	8876 611814	ANNA ZAKHAROVA	{"email": "anna_zakharova.1969@postgrespro.ru", "phone": "+70310516597"}
0005432613919	495BAF	6292 550463	TATYANA RYABOVA	{"phone": "+70936010893"}
0005432613920	495BAF	9722 044561	VLADIMIR BELOV	{"email": "belovv-1971@postgrespro.ru", "phone": "+70190929721"}
0005432613921	8218C2	1373 897948	IVAN MARTYNOV	{"email": "i-martynov.1974@postgrespro.ru", "phone": "+70466573171"}
0005432613922	A89247	1864 112555	ALEKSANDR ORLOV	{"phone": "+70141165210"}
0005432613923	84EC48	6305 905045	GALINA EGOROVA	{"phone": "+70009481009"}
0005432613924	6591E6	0975 874548	NATALYA ZHUKOVA	{"phone": "+70649719583"}
0005432613925	6591E6	0930 414725	NATALIYA IVANOVA	{"phone": "+70222990252"}
0005432613926	6652F3	5656 005210	MAKSIM FEDOROV	{"email": "fedorov-m101970@postgrespro.ru", "phone": "+70373515240"}
0005432613927	43AA63	5193 330399	TATYANA FILIPPOVA	{"email": "filippovat-22061987@postgrespro.ru", "phone": "+70194659726"}
0005432613928	4EE7B0	5418 163847	SERGEY SAVELEV	{"phone": "+70592579465"}
0005432613929	5B4BDF	6162 751458	IVAN TIMOFEEV	{"email": "i-timofeev-06051970@postgrespro.ru", "phone": "+70343086437"}
0005432613930	40FEB4	5239 790171	VYACHESLAV SMIRNOV	{"phone": "+70806430831"}
0005432613931	D07D72	6408 961083	DENIS NOVIKOV	{"phone": "+70040545987"}
0005432613932	D07D72	0060 837457	PAVEL SCHERBAKOV	{"email": "scherbakov-pavel_16111964@postgrespro.ru", "phone": "+70073641802"}
0005432613933	16D73E	5306 282893	VALENTIN CHERNOV	{"email": "chernov_v-08011959@postgrespro.ru", "phone": "+70226598122"}
0005432613934	659107	1479 680540	DMITRIY MAKAROV	{"phone": "+70455834190"}
0005432613935	059018	0811 600021	RAISA VOROBEVA	{"email": "vorobeva.raisa06031969@postgrespro.ru", "phone": "+70629157995"}
0005432613936	059018	2446 035103	ALEKSANDR TARASOV	{"phone": "+70412141114"}
0005432613937	77A623	7212 766824	ZHANNA NAZAROVA	{"email": "z-nazarova-051968@postgrespro.ru", "phone": "+70384266621"}
0005432613938	EF2EE4	2830 480300	ANDREY ILIN	{"email": "ilinandrey-02111978@postgrespro.ru", "phone": "+70094641844"}
0005432613939	2CDD66	2376 337303	MARIYA NIKOLAEVA	{"email": "m_nikolaeva081978@postgrespro.ru", "phone": "+70619661109"}
0005432613940	D99D9E	4880 589044	VIKTOR FEDOTOV	{"phone": "+70305945782"}
0005432613941	D99D9E	1747 725414	PAVEL ANTONOV	{"phone": "+70636855700"}
0005432613942	57CC1C	4625 287926	ALEKSANDR SIDOROV	{"phone": "+70655471020"}
0005432613943	668DB4	1614 710213	ELENA CHERNOVA	{"email": "chernova.e_1977@postgrespro.ru", "phone": "+70634040889"}
0005432613944	668DB4	0517 889771	NURLAN ZAKHAROV	{"phone": "+70212344757"}
0005432613945	E09621	0972 328819	YAKOV ZAKHAROV	{"email": "y_zakharov.1978@postgrespro.ru", "phone": "+70289221941"}
0005432613946	D98100	5891 198077	SOFIYA SMIRNOVA	{"email": "sofiya-smirnova.1980@postgrespro.ru", "phone": "+70327947271"}
0005432613947	A0D95C	9888 769779	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov.021974@postgrespro.ru", "phone": "+70672669377"}
0005432613948	A0D95C	9370 684929	ANASTASIYA LUKYANOVA	{"email": "alukyanova_091966@postgrespro.ru", "phone": "+70097472617"}
0005432613949	D7E001	9373 836066	NIKOLAY ISAEV	{"phone": "+70246637921"}
0005432613950	96EE21	0489 784331	NIKOLAY FROLOV	{"email": "n.frolov.081976@postgrespro.ru", "phone": "+70649964028"}
0005432613951	96EE21	7344 411836	GENNADIY SCHERBAKOV	{"phone": "+70241856777"}
0005432613952	613E16	3731 288282	ELENA FROLOVA	{"phone": "+70654494858"}
0005432613953	613E16	8750 051609	MIKHAIL VLASOV	{"email": "mvlasov_111960@postgrespro.ru", "phone": "+70592388404"}
0005432613954	613E16	6509 451516	ALLA ANDREEVA	{"phone": "+70723554431"}
0005432613955	695591	6649 894875	GALINA MALYSHEVA	{"phone": "+70657724779"}
0005432613956	695591	2117 303345	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr_1964@postgrespro.ru", "phone": "+70334676712"}
0005432613957	695591	2803 875774	DMITRIY BARANOV	{"email": "baranov-dmitriy1975@postgrespro.ru", "phone": "+70688991351"}
0005432613958	037090	1831 234450	MARIYA KUZMINA	{"email": "m.kuzmina-11091964@postgrespro.ru", "phone": "+70029154969"}
0005432613959	F8D461	6270 503689	NATALIYA FROLOVA	{"email": "nataliyafrolova_1975@postgrespro.ru", "phone": "+70228421035"}
0005432613960	F4BCEE	9261 492849	RUSLAN NAUMOV	{"email": "ruslan-naumov-1969@postgrespro.ru", "phone": "+70301389478"}
0005432613961	A06631	3500 843350	NINA TARASOVA	{"email": "tarasova_n.22061958@postgrespro.ru", "phone": "+70216881945"}
0005432613962	FC17F3	0002 116272	DENIS VASILEV	{"phone": "+70306226693"}
0005432613963	EC4D74	2492 021908	DMITRIY POPOV	{"phone": "+70172888735"}
0005432613964	BAD02E	4333 935438	DMITRIY SIDOROV	{"email": "dmitriy.sidorov_07091980@postgrespro.ru", "phone": "+70436289466"}
0005432613965	38B03B	6528 605591	ANASTASIYA ALEKSANDROVA	{"email": "aaleksandrova121963@postgrespro.ru", "phone": "+70645528444"}
0005432613966	DAEF16	3823 784788	MIKHAIL NIKOLAEV	{"phone": "+70358803459"}
0005432613967	4B8AD4	5826 785909	VALENTIN MIRONOV	{"phone": "+70617213666"}
0005432613968	E09D07	8189 287162	VIKTOR TIMOFEEV	{"phone": "+70840491364"}
0005432613969	E09D07	5382 104626	MIKHAIL BORISOV	{"phone": "+70728130105"}
0005432613970	685A5C	0577 692482	ALEKSANDR FILIPPOV	{"email": "filippov.a12101967@postgrespro.ru", "phone": "+70105342076"}
0005432613971	6ED51D	2296 902365	MARIYA TITOVA	{"email": "titova_mariya.011974@postgrespro.ru", "phone": "+70932280602"}
0005432613972	225CDE	2315 349682	SERGEY MOROZOV	{"email": "sergey-morozov.1985@postgrespro.ru", "phone": "+70299552077"}
0005432613973	225CDE	9162 414406	VERA ROMANOVA	{"phone": "+70182350552"}
0005432613974	D64781	5074 446854	VALENTIN ANDREEV	{"email": "vandreev-29111970@postgrespro.ru", "phone": "+70492088638"}
0005432613975	D64781	4177 596760	YULIYA ZHURAVLEVA	{"phone": "+70360622102"}
0005432613976	964465	3691 434441	SVETLANA PAVLOVA	{"phone": "+70989015668"}
0005432613977	967EDC	8959 464147	RAFAIL KONOVALOV	{"phone": "+70629981782"}
0005432613978	9CFDDF	4463 216933	ALEKSEY FEDOROV	{"email": "fedorov_aleksey30091960@postgrespro.ru", "phone": "+70487018201"}
0005432613979	9CFDDF	3954 570085	OLGA VOROBEVA	{"phone": "+70308014940"}
0005432613980	9CFDDF	6260 298395	NIKOLAY YAKOVLEV	{"email": "nikolay-yakovlev_25081976@postgrespro.ru", "phone": "+70413419291"}
0005432613981	4AD36D	7485 905772	IVAN POPOV	{"phone": "+70525472444"}
0005432613982	4AD36D	3755 321363	TATYANA ROMANOVA	{"email": "romanova.t-031965@postgrespro.ru", "phone": "+70898621128"}
0005432620877	B2368F	7969 581128	DENIS ZAYCEV	{"phone": "+70518397792"}
0005432620786	78E179	8329 299243	ZINAIDA PETROVA	{"phone": "+70985266978"}
0005432620787	78E179	7656 137637	PAVEL FILIPPOV	{"email": "pavel-filippov_14041975@postgrespro.ru", "phone": "+70682944060"}
0005432620788	598FDE	6024 392754	MARIYA MAKSIMOVA	{"phone": "+70499635544"}
0005432620789	B823FF	4971 708662	NADEZHDA LEBEDEVA	{"email": "nadezhda-lebedeva_06091974@postgrespro.ru", "phone": "+70371772537"}
0005432620790	0A5022	6861 021626	SHAMIL BARANOV	{"email": "baranovs_1976@postgrespro.ru", "phone": "+70583986799"}
0005432620791	39A8B9	4705 806073	NATALYA ORLOVA	{"email": "natalya.orlova_061976@postgrespro.ru", "phone": "+70301891059"}
0005432620792	FD7F24	4429 195733	OKSANA LOGINOVA	{"email": "o-loginova.121977@postgrespro.ru", "phone": "+70508280344"}
0005432620793	FD7F24	1423 053495	LIDIYA KUZNECOVA	{"phone": "+70586291085"}
0005432620794	B5A5D3	7252 517814	ANASTASIYA BORISOVA	{"phone": "+70090805508"}
0005432620795	EDAB92	0685 475288	VIKTORIYA DANILOVA	{"email": "v.danilova-1963@postgrespro.ru", "phone": "+70005505051"}
0005432620796	EDAB92	8209 119375	IVAN DENISOV	{"phone": "+70084515345"}
0005432620797	FA2CFB	7565 420115	DENIS ANDREEV	{"phone": "+70260239435"}
0005432620798	FA2CFB	3622 621386	ALEKSANDR SERGEEV	{"phone": "+70592790915"}
0005432620799	F725AA	4787 274791	ROMAN KAZAKOV	{"phone": "+70410060441"}
0005432620800	F725AA	9073 049939	IVAN SOKOLOV	{"email": "sokolovivan1965@postgrespro.ru", "phone": "+70811756203"}
0005432620801	1B4483	7193 586928	KLAVDIYA ILINA	{"email": "ilina-klavdiya_1974@postgrespro.ru", "phone": "+70628730805"}
0005432621283	6158C1	8980 307931	DANILA MOISEEV	{"phone": "+70779322426"}
0005432620802	BDE618	2155 089325	OLGA MAKAROVA	{"email": "makarovaolga.31071962@postgrespro.ru", "phone": "+70259974332"}
0005432620803	EA9622	5113 181075	ALEKSANDR DENISOV	{"phone": "+70180223251"}
0005432620804	57B9C2	8249 811266	GEORGIY IVANOV	{"phone": "+70922775290"}
0005432620805	57B9C2	7351 477568	RAFIK MELNIKOV	{"phone": "+70509881813"}
0005432620806	B98F53	4378 152237	ELENA SCHERBAKOVA	{"email": "scherbakovae22021971@postgrespro.ru", "phone": "+70063926311"}
0005432620807	A9FA57	6003 340084	MARIYA CHERNOVA	{"email": "m-chernova-011971@postgrespro.ru", "phone": "+70724077345"}
0005432620808	F3E3FB	5262 094845	LYUDMILA KUDRYASHOVA	{"email": "kudryashova_l_26111972@postgrespro.ru", "phone": "+70656074281"}
0005432620809	6D1A33	7627 950018	NATALIYA GORBUNOVA	{"phone": "+70517601590"}
0005432620810	6D1A33	4094 018853	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr-061972@postgrespro.ru", "phone": "+70883383183"}
0005432620811	6D1A33	6468 010190	SERGEY SOKOLOV	{"email": "sokolov-sergey061964@postgrespro.ru", "phone": "+70589354194"}
0005432620812	D6C8C9	7727 656377	GALINA SMIRNOVA	{"email": "gsmirnova.07091968@postgrespro.ru", "phone": "+70660507630"}
0005432620813	C566F0	9086 857930	DANIIL IVANOV	{"phone": "+70216916839"}
0005432620814	9DFC35	3695 182228	NATALYA ANTONOVA	{"email": "n-antonova-1970@postgrespro.ru", "phone": "+70855411327"}
0005432620815	AA47BB	2139 793434	POLINA ARKHIPOVA	{"phone": "+70063636057"}
0005432620816	AA47BB	1273 336178	ALLA PAVLOVA	{"phone": "+70864588522"}
0005432620817	E7E1C3	2211 183141	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr021971@postgrespro.ru", "phone": "+70941213423"}
0005432620818	E7E1C3	7933 696842	MIKHAIL MOROZOV	{"email": "mikhail-morozov.09121970@postgrespro.ru", "phone": "+70836198615"}
0005432620819	5E2AB7	3790 589271	YULIYA LAZAREVA	{"email": "yuliya.lazareva-1969@postgrespro.ru", "phone": "+70576120833"}
0005432620820	5E2AB7	5649 118733	ANTON KUZNECOV	{"phone": "+70320009545"}
0005432620821	B0B6FF	0954 424907	SERGEY VASILEV	{"email": "vasilev_s.24121964@postgrespro.ru", "phone": "+70978765279"}
0005432620822	2104EE	5102 152042	ANNA ERMAKOVA	{"phone": "+70528490634"}
0005432620823	2104EE	9670 236355	MARYAM SOROKINA	{"email": "sorokina.maryam_121967@postgrespro.ru", "phone": "+70710662847"}
0005432620824	39124E	6782 432934	GENNADIY ISAEV	{"email": "isaev-g1963@postgrespro.ru", "phone": "+70406251295"}
0005432620825	39124E	5100 414635	YULIYA ISAEVA	{"phone": "+70483420616"}
0005432620826	D1ED08	2479 148006	LYUBOV ORLOVA	{"email": "orlovalyubov18101962@postgrespro.ru", "phone": "+70279891909"}
0005432620827	ED1708	7214 748431	PAVEL KOROLEV	{"phone": "+70320621956"}
0005432620828	ED1708	8688 008538	VIKTOR STEPANOV	{"phone": "+70932262554"}
0005432620829	3CE2F8	9860 612364	IVAN YAKOVLEV	{"email": "i.yakovlev06071987@postgrespro.ru", "phone": "+70778251612"}
0005432620830	437009	9201 865349	VALERIY ANTONOV	{"email": "antonov-valeriy-15091973@postgrespro.ru", "phone": "+70211563186"}
0005432620831	437009	7764 288094	ALINA SEMENOVA	{"phone": "+70690514814"}
0005432620832	BC58C6	4828 120506	ELENA ZOTOVA	{"phone": "+70709021914"}
0005432620833	DC9C78	9164 616965	ALEKSEY FOMIN	{"email": "fomin.aleksey1967@postgrespro.ru", "phone": "+70718360684"}
0005432620834	DC9C78	4471 985798	GALINA MEDVEDEVA	{"email": "medvedevagalina.1962@postgrespro.ru", "phone": "+70692983728"}
0005432620835	B92C17	2443 956140	GENNADIY OSIPOV	{"phone": "+70039423926"}
0005432620836	8A278F	4670 658440	EKATERINA OSIPOVA	{"phone": "+70543428881"}
0005432620837	C066FD	7843 847466	NINA SMIRNOVA	{"email": "n_smirnova1980@postgrespro.ru", "phone": "+70035923307"}
0005432620838	C066FD	0811 343920	ANDREY ROMANOV	{"email": "romanov_andrey_1983@postgrespro.ru", "phone": "+70870411150"}
0005432620839	128AD2	7063 287742	ALEKSANDR ZHUKOV	{"email": "zhukov_a-031980@postgrespro.ru", "phone": "+70509837499"}
0005432620840	5986AA	1834 385665	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr_02071967@postgrespro.ru", "phone": "+70308369737"}
0005432620841	BDADA9	5527 653375	VYACHESLAV SERGEEV	{"phone": "+70948095659"}
0005432620842	BDADA9	3677 185628	ALEKSANDR KOZLOV	{"phone": "+70451862766"}
0005432620843	BDADA9	6855 162844	ALEKSEY PETROV	{"email": "petrov-aleksey07061971@postgrespro.ru", "phone": "+70174644509"}
0005432620844	C9D792	7093 650667	VLADIMIR ZAYCEV	{"phone": "+70282303758"}
0005432620845	C1107A	3188 467441	SERGEY VASILEV	{"phone": "+70780235690"}
0005432620846	FD5CC9	7151 750411	ALEKSANDR SCHERBAKOV	{"email": "scherbakova_121982@postgrespro.ru", "phone": "+70925729545"}
0005432620847	74FF81	3520 477433	ALLA ANTONOVA	{"email": "a_antonova_1980@postgrespro.ru", "phone": "+70620013866"}
0005432620848	74FF81	1336 867933	IRINA VOROBEVA	{"phone": "+70073684532"}
0005432620849	971B92	8371 197698	DENIS GERASIMOV	{"email": "d-gerasimov1970@postgrespro.ru", "phone": "+70739392012"}
0005432620850	F97F27	0889 188954	ALBINA NOVIKOVA	{"phone": "+70696663296"}
0005432620851	8723EC	4005 007226	DMITRIY ZHURAVLEV	{"email": "zhuravlevdmitriy_101982@postgrespro.ru", "phone": "+70084168546"}
0005432620852	8723EC	5275 153740	ALEKSEY BELOV	{"email": "belov.aleksey_1973@postgrespro.ru", "phone": "+70055054596"}
0005432620853	E14A63	7378 822186	DARYA AFANASEVA	{"phone": "+70423327497"}
0005432620854	E14A63	6352 784193	NELLI PAVLOVA	{"email": "pavlovan-27011970@postgrespro.ru", "phone": "+70026811050"}
0005432620855	7CCB77	7382 168668	ALEKSEY FEDOTOV	{"email": "a-fedotov.16101971@postgrespro.ru", "phone": "+70872512791"}
0005432620856	7CCB77	9234 331276	DENIS VOROBEV	{"phone": "+70692791765"}
0005432620857	CC6665	8357 745767	ANTON SCHERBAKOV	{"email": "scherbakova.111968@postgrespro.ru", "phone": "+70906119807"}
0005432620858	1C5455	6651 627686	ELENA FILIPPOVA	{"phone": "+70790608105"}
0005432620859	79A836	0847 566320	SERGEY BORISOV	{"phone": "+70651218678"}
0005432620860	79A836	8370 752709	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr_1964@postgrespro.ru", "phone": "+70198350467"}
0005432620861	7045BE	7502 667820	NIKITA YAKOVLEV	{"phone": "+70071147113"}
0005432620862	7045BE	3640 250773	EKATERINA MAKAROVA	{"email": "ekaterina.makarova011984@postgrespro.ru", "phone": "+70356304156"}
0005432620863	42EC2A	8489 458411	TATYANA YUDINA	{"email": "tatyana.yudina17021978@postgrespro.ru", "phone": "+70705043881"}
0005432620864	27C634	5512 782855	SERGEY KUZNECOV	{"phone": "+70411927437"}
0005432620865	860862	8240 106408	DMITRIY KOZLOV	{"email": "kozlov-d_08081970@postgrespro.ru", "phone": "+70094734027"}
0005432620866	B04A93	4552 521761	YURIY FEDOTOV	{"email": "y_fedotov_1966@postgrespro.ru", "phone": "+70992500054"}
0005432620867	F1AA35	1582 690778	GALINA ROMANOVA	{"email": "g-romanova111979@postgrespro.ru", "phone": "+70867164229"}
0005432620868	295D27	9140 766684	SVETLANA STEPANOVA	{"phone": "+70316963549"}
0005432620869	295D27	6313 840440	ELENA KOMAROVA	{"email": "komarova_elena.061978@postgrespro.ru", "phone": "+70159686890"}
0005432620870	39B98F	4045 977059	YULIYA BORISOVA	{"phone": "+70316666574"}
0005432620871	AB2C87	3599 192264	SERGEY CHERNOV	{"email": "chernov.sergey19101966@postgrespro.ru", "phone": "+70189578128"}
0005432620872	4F648D	1611 850147	LYUDMILA VOLKOVA	{"email": "l_volkova-041979@postgrespro.ru", "phone": "+70146724034"}
0005432620873	E1C487	8410 944665	ANATOLIY SIDOROV	{"phone": "+70125093915"}
0005432620874	E1C487	6034 633483	SVETLANA FILIPPOVA	{"email": "s_filippova-101985@postgrespro.ru", "phone": "+70964768586"}
0005432620875	EAA39F	8909 112066	OLGA MOROZOVA	{"phone": "+70182604817"}
0005432620876	9F1858	2938 044831	OKSANA NESTEROVA	{"phone": "+70622493979"}
0005432620878	1BCD15	6140 803277	ELENA MOISEEVA	{"email": "elena-moiseeva-1974@postgrespro.ru", "phone": "+70575362375"}
0005432620879	6B038A	5336 190962	YULIYA OSIPOVA	{"email": "y-osipova-1971@postgrespro.ru", "phone": "+70380213749"}
0005432620880	0A3264	8911 433663	SERGEY KAZAKOV	{"phone": "+70814225439"}
0005432620881	0A3264	4521 508536	ELENA KULIKOVA	{"email": "kulikova.elena22031973@postgrespro.ru", "phone": "+70483005968"}
0005432620882	290DEF	8499 688020	DANIIL DAVYDOV	{"email": "davydovdaniil26111967@postgrespro.ru", "phone": "+70074974430"}
0005432620883	290DEF	9144 085257	VIKTORIYA ALEKSEEVA	{"phone": "+70636868667"}
0005432620884	3858A6	9901 957285	VERA OSIPOVA	{"phone": "+70162846483"}
0005432620885	3858A6	2320 007441	GENNADIY VOLKOV	{"phone": "+70234197827"}
0005432620886	3858A6	8975 733494	ANASTASIYA MOISEEVA	{"phone": "+70810397777"}
0005432620887	3858A6	3038 303966	DMITRIY TIKHONOV	{"phone": "+70915980515"}
0005432620888	EB3FAB	4317 113499	RIMMA GORBUNOVA	{"phone": "+70592964911"}
0005432620889	185322	8711 041374	NIKOLAY VLASOV	{"phone": "+70915456593"}
0005432620890	185322	3838 468020	SERGEY KOZLOV	{"email": "skozlov_1968@postgrespro.ru", "phone": "+70167494212"}
0005432620891	7A2B17	5545 515546	YANA ZHURAVLEVA	{"phone": "+70635359184"}
0005432620892	31E290	6511 185940	ANDREY MELNIKOV	{"email": "amelnikov-041985@postgrespro.ru", "phone": "+70367651521"}
0005432620893	00B9A7	8147 668084	NIKOLAY KUZMIN	{"phone": "+70493106569"}
0005432620894	9DF5F9	2545 858782	DMITRIY ZAKHAROV	{"phone": "+70122974104"}
0005432620895	9DF5F9	7631 572212	VALERIY ANTONOV	{"email": "antonov_valeriy-15011984@postgrespro.ru", "phone": "+70228158718"}
0005432620896	A70527	6817 282247	IGOR DAVYDOV	{"phone": "+70333618977"}
0005432620897	F7243F	4972 751308	VALENTINA ZHUKOVA	{"phone": "+70124866074"}
0005432620898	F38FB4	6188 168909	ANNA FILATOVA	{"phone": "+70461385545"}
0005432620899	3BEE41	5236 488472	SVETLANA ALEKSANDROVA	{"email": "svetlanaaleksandrova15041963@postgrespro.ru", "phone": "+70720971615"}
0005432620900	32096E	4451 962384	MIKHAIL KUZNECOV	{"email": "m_kuznecov111963@postgrespro.ru", "phone": "+70847029869"}
0005432620901	584377	8366 586233	DANIIL ANDREEV	{"phone": "+70068327174"}
0005432620902	584377	0113 658907	ALEVTINA FEDOROVA	{"email": "fedorova-alevtina.11091970@postgrespro.ru", "phone": "+70138433745"}
0005432620903	9633D8	6679 357572	EKATERINA ALEKSEEVA	{"phone": "+70553719880"}
0005432620904	D63F50	2415 925255	OKSANA EFREMOVA	{"phone": "+70624479793"}
0005432620905	D40A79	2200 646149	ELENA FROLOVA	{"email": "e-frolova1964@postgrespro.ru", "phone": "+70658234099"}
0005432620906	CDF03A	0558 455146	MIKHAIL FROLOV	{"phone": "+70148572767"}
0005432620907	D086A7	0691 792574	EVDOKIYA NESTEROVA	{"email": "nesterovaevdokiya.1967@postgrespro.ru", "phone": "+70074256735"}
0005432620908	D086A7	3877 104510	VIKTOR FILIPPOV	{"phone": "+70643532235"}
0005432620909	EA8970	2695 495250	VALENTINA LAZAREVA	{"phone": "+70069348240"}
0005432620910	523653	1867 654980	TATYANA ANDREEVA	{"phone": "+70822568631"}
0005432620911	523653	9108 606602	GENNADIY PAVLOV	{"phone": "+70156024841"}
0005432620912	32443E	6292 747669	VLADIMIR SERGEEV	{"phone": "+70177452597"}
0005432620913	D35163	5236 194359	YURIY MAKAROV	{"email": "yuriy.makarov-25101974@postgrespro.ru", "phone": "+70896594831"}
0005432620914	F407DA	7949 042270	IVAN SOKOLOV	{"phone": "+70362186655"}
0005432620915	B85A78	0086 981579	ALEKSANDR IVANOV	{"phone": "+70346952107"}
0005432620916	A02478	5687 205910	YULIYA EFIMOVA	{"email": "yuliya-efimova.07091971@postgrespro.ru", "phone": "+70061270037"}
0005432620917	A02478	6123 545039	VERONIKA NOVIKOVA	{"email": "veronika-novikova1966@postgrespro.ru", "phone": "+70577827185"}
0005432620918	E0F382	7996 482498	RUSTAM SMIRNOV	{"phone": "+70911123114"}
0005432620919	E0F382	1722 958543	EVGENIYA PETROVA	{"email": "petrova.evgeniya-1968@postgrespro.ru", "phone": "+70593027474"}
0005432620920	10265F	4914 900169	ANATOLIY FOMIN	{"email": "a-fomin051970@postgrespro.ru", "phone": "+70063883004"}
0005432620921	7ACDF6	7380 831060	KONSTANTIN DENISOV	{"email": "denisov.konstantin-1974@postgrespro.ru", "phone": "+70657427342"}
0005432620922	7ACDF6	3662 423325	ALEKSANDR IVANOV	{"phone": "+70930284257"}
0005432620923	952ACA	3756 236566	RAVIL GRIGOREV	{"email": "r.grigorev1970@postgrespro.ru", "phone": "+70807844974"}
0005432620924	952ACA	3428 925990	ELENA VOROBEVA	{"phone": "+70946720134"}
0005432620925	3970B7	4569 165824	VERA AKIMOVA	{"email": "vera.akimova-08031968@postgrespro.ru", "phone": "+70610423535"}
0005432620926	E50F3B	0591 645303	MARIYA IVANOVA	{"phone": "+70274821851"}
0005432620927	20EEAE	8115 714056	NATALYA YAKOVLEVA	{"phone": "+70681557278"}
0005432620928	20EEAE	4616 444980	LYUBOV MIRONOVA	{"email": "l-mironova-1966@postgrespro.ru", "phone": "+70570530127"}
0005432620929	92281D	3534 313635	MAKSIM SEMENOV	{"phone": "+70237953630"}
0005432620930	92281D	0432 689065	ALEKSEY VOLKOV	{"phone": "+70195943518"}
0005432620931	92281D	4673 423855	TATYANA KUZMINA	{"email": "kuzmina.t-011972@postgrespro.ru", "phone": "+70126646511"}
0005432620932	92281D	1692 182908	VLADIMIR ISAEV	{"phone": "+70446091169"}
0005432620933	320A82	3313 863470	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr.1971@postgrespro.ru", "phone": "+70844648047"}
0005432620934	0B4D46	9883 134382	GEORGIY DAVYDOV	{"phone": "+70965217555"}
0005432620935	3D77EF	4100 473213	ELIZAVETA KUZNECOVA	{"phone": "+70140187788"}
0005432620936	3D77EF	9000 287741	VERA MIKHAYLOVA	{"phone": "+70344259407"}
0005432620937	016686	1835 933708	ALEKSANDR MOISEEV	{"phone": "+70229105232"}
0005432620938	D2B804	6274 263015	POLINA TIMOFEEVA	{"phone": "+70385570846"}
0005432620939	4ECE6F	8548 974461	ELIZAVETA KRASNOVA	{"email": "elizaveta-krasnova31121980@postgrespro.ru", "phone": "+70075216174"}
0005432620940	4ECE6F	3701 904410	KLAVDIYA KOROLEVA	{"phone": "+70543280534"}
0005432620941	4ECE6F	6859 897834	ALENA DENISOVA	{"email": "adenisova19041971@postgrespro.ru", "phone": "+70462972273"}
0005432620942	2B3D6E	0765 253745	SVETLANA SERGEEVA	{"email": "s_sergeeva_1981@postgrespro.ru", "phone": "+70906394193"}
0005432620943	2B3D6E	7781 219923	DMITRIY CHERNOV	{"phone": "+70530644780"}
0005432620944	4B09A8	7444 414600	ELENA YUDINA	{"phone": "+70763454229"}
0005432620945	DF43A0	7300 999586	PETR KUZNECOV	{"email": "petr-kuznecov_051973@postgrespro.ru", "phone": "+70292432997"}
0005432620946	DF43A0	2557 860757	GEORGIY DAVYDOV	{"email": "gdavydov.111964@postgrespro.ru", "phone": "+70813786209"}
0005432620947	AA8EF4	6517 194087	TATYANA SERGEEVA	{"email": "sergeeva.tatyana_1980@postgrespro.ru", "phone": "+70387021329"}
0005432620948	AA8EF4	3482 155014	ROMAN IVANOV	{"email": "roman_ivanov-051979@postgrespro.ru", "phone": "+70890011157"}
0005432620949	67BFAA	7649 263609	ANDREY SCHERBAKOV	{"email": "a.scherbakov23031963@postgrespro.ru", "phone": "+70619768201"}
0005432620950	747B94	6360 270539	ANATOLIY FROLOV	{"email": "afrolov1952@postgrespro.ru", "phone": "+70922868650"}
0005432620951	865493	9928 722176	VLADIMIR MARTYNOV	{"phone": "+70953762387"}
0005432620952	60FB75	5225 550284	ALEKSANDR ALEKSANDROV	{"phone": "+70598048062"}
0005432620953	A96CC8	5026 119318	NATALYA MOROZOVA	{"email": "natalya_morozova_07081964@postgrespro.ru", "phone": "+70922913731"}
0005432620954	A96CC8	1286 244994	SVETLANA MAKAROVA	{"email": "makarova-s101975@postgrespro.ru", "phone": "+70708501823"}
0005432620955	239EDC	9692 111195	VASILIY SMIRNOV	{"phone": "+70601898465"}
0005432620956	239EDC	7764 986120	ELENA NOVIKOVA	{"email": "novikovae1963@postgrespro.ru", "phone": "+70925966770"}
0005432620957	DC0395	6009 036550	VIKTOR VOLKOV	{"email": "viktorvolkov.22091975@postgrespro.ru", "phone": "+70173115333"}
0005432620958	9A769F	9734 568758	LIDIYA KONOVALOVA	{"phone": "+70792338628"}
0005432620959	FFCD34	0006 624298	ANATOLIY NAUMOV	{"email": "naumovanatoliy_1977@postgrespro.ru", "phone": "+70843151240"}
0005432620960	C8C0D6	3186 407281	EKATERINA ZAKHAROVA	{"phone": "+70235782613"}
0005432620961	957640	9938 255006	IRINA ANDREEVA	{"phone": "+70349253293"}
0005432620962	E5EC26	0408 352725	YURIY VOLKOV	{"email": "volkov.yuriy-13061962@postgrespro.ru", "phone": "+70526164360"}
0005432620963	A7FEA3	1658 438329	LIDIYA ANTONOVA	{"phone": "+70674378891"}
0005432620964	37B687	4422 863896	ANASTASIYA MAKSIMOVA	{"phone": "+70130365714"}
0005432620965	37B687	5672 310610	VIKTORIYA MOROZOVA	{"email": "morozova.viktoriya_1962@postgrespro.ru", "phone": "+70468436110"}
0005432620966	37B687	6413 304422	NATALYA MOISEEVA	{"phone": "+70268823884"}
0005432620967	9A5DF5	6914 950013	ANNA MATVEEVA	{"email": "matveeva_a.20011978@postgrespro.ru", "phone": "+70826855257"}
0005432620968	9A5DF5	4983 991683	EVGENIYA FROLOVA	{"phone": "+70508149102"}
0005432620969	7B300B	0060 102483	LYUBOV MELNIKOVA	{"email": "lyubovmelnikova_111973@postgrespro.ru", "phone": "+70774272504"}
0005432620970	4A7602	0559 484792	ALEKSANDRA KRASNOVA	{"email": "krasnovaaleksandra1972@postgrespro.ru", "phone": "+70023209758"}
0005432620971	01C43B	7653 811440	ANASTASIYA FOMINA	{"phone": "+70801972517"}
0005432620972	E2A397	5619 411590	LYUBOV KOVALEVA	{"phone": "+70118712467"}
0005432620973	3823FE	1121 896237	ALEKSANDR ZAKHAROV	{"phone": "+70912879035"}
0005432620974	CB0709	7552 136555	MIKHAIL KUZNECOV	{"phone": "+70832047170"}
0005432620975	0495CB	5614 329665	ALINA CHERNOVA	{"phone": "+70892665343"}
0005432620976	6BA5F3	0597 188080	MIKHAIL KOROLEV	{"email": "korolev_mikhail-1975@postgrespro.ru", "phone": "+70965513382"}
0005432620977	F67D0A	7849 651033	GENNADIY KOZLOV	{"email": "kozlovg_14011980@postgrespro.ru", "phone": "+70164791580"}
0005432620978	06D703	5156 348149	TAMARA KUZNECOVA	{"email": "kuznecova_tamara1970@postgrespro.ru", "phone": "+70282489841"}
0005432620979	204A01	2508 147255	ALEKSEY SEMENOV	{"email": "a-semenov1972@postgrespro.ru", "phone": "+70368994478"}
0005432620980	07E6D8	8763 423990	STANISLAV FROLOV	{"email": "frolovs1979@postgrespro.ru", "phone": "+70903821799"}
0005432620981	BA5549	1369 432358	LYUDMILA SOLOVEVA	{"phone": "+70189128998"}
0005432620982	BA5549	3923 925273	VLADIMIR MOISEEV	{"email": "v.moiseev1975@postgrespro.ru", "phone": "+70987513723"}
0005432620983	46DFA9	7499 532618	ALEKSEY GERASIMOV	{"email": "a-gerasimov.25051963@postgrespro.ru", "phone": "+70291122583"}
0005432620984	851875	1921 736029	ALBINA ZHUKOVA	{"email": "albinazhukova_091971@postgrespro.ru", "phone": "+70894620275"}
0005432620985	2F6D61	9479 104872	YULIYA ZAKHAROVA	{"email": "zakharova-y.13111966@postgrespro.ru", "phone": "+70356703371"}
0005432620986	2F6D61	5236 235288	VALERIY SCHERBAKOV	{"email": "scherbakov.v-06021957@postgrespro.ru", "phone": "+70042599763"}
0005432620987	73E0FD	7026 263477	KLARA FILIPPOVA	{"email": "filippova_k_1967@postgrespro.ru", "phone": "+70492194896"}
0005432620988	EEF20E	2531 070102	ALEKSANDR GAVRILOV	{"email": "gavrilov-a27091976@postgrespro.ru", "phone": "+70809468342"}
0005432620989	DEE6FB	1896 968512	GENNADIY IVANOV	{"email": "ivanov-gennadiy.1977@postgrespro.ru", "phone": "+70267092271"}
0005432620990	DEE6FB	7107 098215	ALEKSANDRA MIKHAYLOVA	{"email": "a_mikhaylova_02081965@postgrespro.ru", "phone": "+70195261744"}
0005432620991	36CFC2	6559 603075	ALEKSEY KUZMIN	{"phone": "+70638837250"}
0005432620992	92C480	4192 308402	ANDREY MIKHAYLOV	{"email": "a.mikhaylov-111971@postgrespro.ru", "phone": "+70066216019"}
0005432620993	B8CC6F	7715 821537	ILYA ALEKSANDROV	{"email": "aleksandrovi_021980@postgrespro.ru", "phone": "+70131123074"}
0005432620994	C928D7	9613 884915	ALEKSANDRA SERGEEVA	{"phone": "+70996827952"}
0005432620995	C928D7	2429 321262	SEMEN PETROV	{"email": "petrov-semen_16061979@postgrespro.ru", "phone": "+70605438977"}
0005432620996	C928D7	1578 895487	ALEKSANDR SERGEEV	{"email": "asergeev-061973@postgrespro.ru", "phone": "+70526116331"}
0005432620997	D1B513	8382 208625	NATALYA ORLOVA	{"email": "natalya_orlova-1982@postgrespro.ru", "phone": "+70964226576"}
0005432620998	64D514	5581 094663	LARISA KUZNECOVA	{"email": "l_kuznecova-071984@postgrespro.ru", "phone": "+70937573237"}
0005432620999	844F8F	5284 044341	ANATOLIY RODIONOV	{"email": "rodionov.anatoliy_1974@postgrespro.ru", "phone": "+70203513214"}
0005432621000	844F8F	9356 553739	VERONIKA NESTEROVA	{"email": "veronikanesterova_1965@postgrespro.ru", "phone": "+70990156749"}
0005432621001	CE8195	1732 904753	MARIYA NIKOLAEVA	{"phone": "+70378114539"}
0005432621002	7DB051	5965 560827	OLGA MIKHAYLOVA	{"email": "o.mikhaylova_051975@postgrespro.ru", "phone": "+70515325316"}
0005432621003	D6AE46	8621 346151	VALENTINA GORBUNOVA	{"email": "gorbunova_v_25071969@postgrespro.ru", "phone": "+70074469164"}
0005432621004	D6AE46	9451 049726	ILYA ANTONOV	{"email": "antonov_ilya21091960@postgrespro.ru", "phone": "+70457047449"}
0005432621005	E39BE1	1213 121989	YAKOV SMIRNOV	{"email": "smirnov_yakov1970@postgrespro.ru", "phone": "+70251050785"}
0005432621006	E39BE1	6546 611497	MARIYA KUZNECOVA	{"email": "kuznecova-mariya_01051980@postgrespro.ru", "phone": "+70660583032"}
0005432621007	DA3475	2424 489538	SERGEY KARPOV	{"phone": "+70682599888"}
0005432621008	DA3475	0727 897938	ALSU TIKHONOVA	{"phone": "+70839866375"}
0005432621009	017BA0	4062 977939	SERGEY KUZNECOV	{"email": "kuznecov-sergey-061970@postgrespro.ru", "phone": "+70302042115"}
0005432621010	017BA0	5953 418482	ALEKSEY DENISOV	{"phone": "+70180157705"}
0005432621011	8AD4A0	5069 523459	GALINA ANISIMOVA	{"phone": "+70548154905"}
0005432621012	CAEE52	4458 946684	YURIY KUZMIN	{"email": "yuriy.kuzmin-091977@postgrespro.ru", "phone": "+70214374137"}
0005432621013	FB4803	6245 976465	LYUDMILA DMITRIEVA	{"email": "lyudmila.dmitrieva.06041974@postgrespro.ru", "phone": "+70733106727"}
0005432621014	C26D64	3687 391804	VALENTINA POPOVA	{"phone": "+70949582056"}
0005432621015	B6999E	3763 936480	ALEKSEY KARPOV	{"email": "aleksey_karpov1975@postgrespro.ru", "phone": "+70882012253"}
0005432621016	1F2DB8	8675 465477	VALENTINA GORBUNOVA	{"phone": "+70217531993"}
0005432621017	5AD3B2	8249 231080	ZINAIDA SEMENOVA	{"phone": "+70364162641"}
0005432621018	A3E5CE	5735 368474	ALLA POTAPOVA	{"email": "allapotapova_08011968@postgrespro.ru", "phone": "+70721582309"}
0005432621019	A3E5CE	0165 433138	LILIYA ZAKHAROVA	{"phone": "+70625796218"}
0005432621020	A3E5CE	4241 337735	LYUDMILA TIMOFEEVA	{"phone": "+70289146254"}
0005432621021	A1C0B6	9651 178207	MARGARITA GORBUNOVA	{"email": "gorbunovam1970@postgrespro.ru", "phone": "+70318698417"}
0005432621022	9270CD	2575 616536	TATYANA IVANOVA	{"email": "t.ivanova09041974@postgrespro.ru", "phone": "+70444007992"}
0005432621023	238EAB	3465 693110	EVDOKIYA OSIPOVA	{"email": "e-osipova-061979@postgrespro.ru", "phone": "+70723763602"}
0005432621024	61ACBC	8219 171146	VLADIMIR ANTONOV	{"email": "antonov-v29031975@postgrespro.ru", "phone": "+70912128740"}
0005432621025	61ACBC	0234 608255	PAVEL STEPANOV	{"phone": "+70260046821"}
0005432621026	F793CE	9618 370758	ELENA TARASOVA	{"phone": "+70452029630"}
0005432621027	F793CE	0370 749816	VIKTORIYA FILIPPOVA	{"email": "filippova.viktoriya1984@postgrespro.ru", "phone": "+70010007540"}
0005432621028	F793CE	1156 813908	TATYANA ZOTOVA	{"phone": "+70705156343"}
0005432621029	93AED8	9257 809877	ANDREY STEPANOV	{"email": "stepanov_andrey1964@postgrespro.ru", "phone": "+70629692905"}
0005432621030	93AED8	6100 311018	KLAVDIYA POTAPOVA	{"email": "potapova-k.21051969@postgrespro.ru", "phone": "+70300412963"}
0005432621031	93AED8	0237 188263	VALENTINA LEBEDEVA	{"phone": "+70016674923"}
0005432621032	C23BAD	0307 391739	MARINA FROLOVA	{"phone": "+70354485411"}
0005432621033	C23BAD	8063 069628	MAKSIM MAKAROV	{"phone": "+70611875401"}
0005432621034	075FE7	3166 745952	GALINA KOVALEVA	{"phone": "+70696346354"}
0005432621035	2E7752	0000 667292	ALEKSANDR NOVIKOV	{"phone": "+70632536667"}
0005432621036	7C302C	5542 687563	OLGA KISELEVA	{"phone": "+70884469398"}
0005432621037	7C302C	3299 075993	SERGEY KUZMIN	{"email": "s_kuzmin.121967@postgrespro.ru", "phone": "+70755692965"}
0005432621038	73B885	0369 574260	FEDOR FEDOTOV	{"email": "fedotov.f021974@postgrespro.ru", "phone": "+70551384165"}
0005432621039	73B885	2415 252954	LYUDMILA STEPANOVA	{"phone": "+70923279671"}
0005432621040	F2CAC0	1518 731792	INNA KOZLOVA	{"phone": "+70811646579"}
0005432621041	41D9CB	3197 778134	ANTONINA VASILEVA	{"email": "vasileva-a.091987@postgrespro.ru", "phone": "+70356203843"}
0005432621042	41D9CB	9336 176262	PAVEL MAKAROV	{"email": "p_makarov-1973@postgrespro.ru", "phone": "+70018490968"}
0005432621043	41D9CB	8937 201072	VALENTINA ISAEVA	{"email": "isaeva-v041979@postgrespro.ru", "phone": "+70880829350"}
0005432621044	EF9172	0427 767739	YURIY SAVELEV	{"phone": "+70834901992"}
0005432621045	C78CF0	1446 699437	YULIYA KAZAKOVA	{"email": "kazakova.yuliya.101966@postgrespro.ru", "phone": "+70424058153"}
0005432621046	2F3629	0006 010807	VIKTOR ZAYCEV	{"phone": "+70814742389"}
0005432621047	2F3629	1059 938261	NATALIYA KALININA	{"phone": "+70568190676"}
0005432621048	5A9FB6	6569 388957	NIKOLAY SCHERBAKOV	{"email": "nikolay-scherbakov_1975@postgrespro.ru", "phone": "+70908967914"}
0005432621049	5A9FB6	8267 549856	OLGA STEPANOVA	{"email": "o.stepanova041969@postgrespro.ru", "phone": "+70519062307"}
0005432621050	EF4DFD	7570 731910	SERGEY MIRONOV	{"phone": "+70744983941"}
0005432621051	F2907B	7391 779400	OLEG SERGEEV	{"phone": "+70318674024"}
0005432621052	F2907B	5045 492019	VITALIY VASILEV	{"phone": "+70078809941"}
0005432621053	970169	6094 326953	ANNA POTAPOVA	{"email": "potapova.a20081982@postgrespro.ru", "phone": "+70562812182"}
0005432621054	65A941	3393 928971	EVGENIY RODIONOV	{"phone": "+70081393598"}
0005432621055	E95E7C	6532 090873	ALEKSANDR BONDARENKO	{"email": "a_bondarenko_1972@postgrespro.ru", "phone": "+70971568999"}
0005432621056	B96A22	9957 002309	IRINA GERASIMOVA	{"phone": "+70224875265"}
0005432621057	53CD10	0705 771628	MIKHAIL ORLOV	{"email": "m_orlov.1968@postgrespro.ru", "phone": "+70615635414"}
0005432621058	3E7666	8318 368112	NADEZHDA ALEKSEEVA	{"phone": "+70887423074"}
0005432621059	3E7666	9343 937127	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov.02051971@postgrespro.ru", "phone": "+70279283149"}
0005432621060	6A9B8B	5108 605349	VYACHESLAV BONDARENKO	{"email": "vyacheslavbondarenko.08011969@postgrespro.ru", "phone": "+70374035287"}
0005432621061	6A9B8B	3787 006373	VLADIMIR DENISOV	{"phone": "+70637332851"}
0005432621062	C77DB2	7405 055616	ANASTASIYA KARPOVA	{"email": "karpova-a_1974@postgrespro.ru", "phone": "+70458052707"}
0005432621063	C77DB2	9417 173143	ALEKSEY KRASNOV	{"email": "krasnova_041972@postgrespro.ru", "phone": "+70431710156"}
0005432621064	AC4107	1953 866487	SERGEY TARASOV	{"email": "tarasov_sergey-14091968@postgrespro.ru", "phone": "+70122606830"}
0005432621065	AC4107	5511 399639	ELENA KONOVALOVA	{"phone": "+70453341875"}
0005432621066	8ED9BA	2275 120501	MARIYA SOLOVEVA	{"phone": "+70223155671"}
0005432621067	13B491	8418 560817	NATALYA POTAPOVA	{"email": "potapova_n041981@postgrespro.ru", "phone": "+70706594154"}
0005432621068	382FB8	7412 988925	MARINA GUSEVA	{"phone": "+70554276371"}
0005432621069	864359	6387 693029	NINA EGOROVA	{"email": "ninaegorova1974@postgrespro.ru", "phone": "+70588370314"}
0005432621070	864359	5410 844961	GALINA LEBEDEVA	{"email": "lebedeva-galina051974@postgrespro.ru", "phone": "+70456664724"}
0005432621071	6A7693	0253 129246	DMITRIY FILIPPOV	{"phone": "+70582391109"}
0005432621072	DB6BC6	7688 233067	YURIY SHEVCHENKO	{"email": "shevchenko_y1958@postgrespro.ru", "phone": "+70019396399"}
0005432621073	20849F	0283 774270	ANATOLIY GUSEV	{"phone": "+70021636821"}
0005432621074	CF6946	7228 120689	YULIYA MIRONOVA	{"phone": "+70549463011"}
0005432621075	8A0E98	1466 995144	GALINA KISELEVA	{"email": "kiseleva.g121973@postgrespro.ru", "phone": "+70750721043"}
0005432621076	6D4803	7694 137375	ELENA TIKHONOVA	{"email": "tikhonovae.111976@postgrespro.ru", "phone": "+70132464509"}
0005432621077	F824E6	5619 457277	VALERIY SOKOLOV	{"phone": "+70311340209"}
0005432621078	113D98	5879 523175	SERGEY KUZNECOV	{"email": "sergey.kuznecov-17061974@postgrespro.ru", "phone": "+70157247805"}
0005432621079	4B4232	4503 353408	ALEKSANDRA OVCHINNIKOVA	{"email": "ovchinnikova.a-15101975@postgrespro.ru", "phone": "+70862090630"}
0005432621080	4B4232	3364 403906	TAMARA NIKOLAEVA	{"email": "nikolaeva-t05071962@postgrespro.ru", "phone": "+70798678607"}
0005432621081	07DBC3	8781 260854	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev051963@postgrespro.ru", "phone": "+70743445352"}
0005432621082	A4E642	4461 521487	ALEKSEY NAZAROV	{"phone": "+70265709426"}
0005432621083	A4E642	9848 032535	VIKTOR ORLOV	{"email": "orlov_viktor-1979@postgrespro.ru", "phone": "+70500278432"}
0005432621084	C5D19E	3194 618943	SERGEY GERASIMOV	{"email": "sergey-gerasimov.22111967@postgrespro.ru", "phone": "+70766704650"}
0005432621085	7F6DF0	9760 748438	ALEKSANDR KUZNECOV	{"phone": "+70765009789"}
0005432621086	7F6DF0	2369 847401	NATALYA FOMINA	{"email": "fomina.n101978@postgrespro.ru", "phone": "+70140426596"}
0005432621087	CFF338	2018 182067	OLGA SMIRNOVA	{"phone": "+70500191469"}
0005432621088	CFF338	6462 108034	TIMOFEY MAKAROV	{"phone": "+70774910763"}
0005432621089	A64A51	5451 325221	LYUDMILA KOZLOVA	{"email": "kozlova.l.04101970@postgrespro.ru", "phone": "+70091029081"}
0005432621090	A64A51	4890 175479	ALBINA MAKSIMOVA	{"email": "a_maksimova121971@postgrespro.ru", "phone": "+70307643520"}
0005432621091	F93B3B	5283 198995	NATALYA BARANOVA	{"phone": "+70173197571"}
0005432621092	F93B3B	9417 428525	ELENA KOMAROVA	{"email": "komarovae-06051966@postgrespro.ru", "phone": "+70250288174"}
0005432621093	F93B3B	5792 311797	GLEB MELNIKOV	{"email": "gleb_melnikov_1975@postgrespro.ru", "phone": "+70240332461"}
0005432621094	DC6784	2055 735877	VLADIMIR MATVEEV	{"phone": "+70799970306"}
0005432621095	DC6784	8458 796470	ZINAIDA IVANOVA	{"phone": "+70065677556"}
0005432621096	5B5C0F	8347 580455	ALEKSANDR TIKHONOV	{"phone": "+70456802167"}
0005432621097	739D4B	8481 645929	VERA PAVLOVA	{"email": "vera.pavlova12121976@postgrespro.ru", "phone": "+70440952165"}
0005432621098	136763	3319 943151	VLADIMIR MAKSIMOV	{"phone": "+70291079479"}
0005432621099	26DAA8	3363 932028	NIKOLAY TIMOFEEV	{"email": "nikolay.timofeev1958@postgrespro.ru", "phone": "+70089405257"}
0005432621100	9B1A76	9465 279215	ALLA GRISHINA	{"phone": "+70987824512"}
0005432621101	9B1A76	4231 842794	ANASTASIYA SMIRNOVA	{"phone": "+70803962097"}
0005432621102	820585	8733 243114	VALENTINA ALEKSEEVA	{"email": "valentina_alekseeva_01021973@postgrespro.ru", "phone": "+70187713503"}
0005432621103	0DC7D2	3052 895481	ALEKSEY GAVRILOV	{"email": "alekseygavrilov_121983@postgrespro.ru", "phone": "+70607315874"}
0005432621104	00A297	8663 103017	OLEG FEDOROV	{"email": "oleg_fedorov_011961@postgrespro.ru", "phone": "+70352089144"}
0005432621105	0B92A8	7996 165750	TATYANA PETROVA	{"email": "petrova_tatyana_12111957@postgrespro.ru", "phone": "+70012805964"}
0005432621106	0B92A8	3178 661559	LARISA ZOTOVA	{"phone": "+70795823746"}
0005432621107	0DB59E	8657 490980	PETR SERGEEV	{"email": "p_sergeev-1975@postgrespro.ru", "phone": "+70208836281"}
0005432621108	0DB59E	8941 294422	TAMARA POLYAKOVA	{"phone": "+70129235275"}
0005432621109	574DAF	0879 573091	IVAN KUZNECOV	{"email": "kuznecovivan1969@postgrespro.ru", "phone": "+70000525494"}
0005432621110	574DAF	4351 643558	OLGA MATVEEVA	{"email": "matveeva_o.08021976@postgrespro.ru", "phone": "+70729715682"}
0005432621111	D726AC	1514 261794	EGOR ROMANOV	{"phone": "+70002121778"}
0005432621112	C8E3AF	1987 425886	NATALYA ZHUKOVA	{"phone": "+70985776686"}
0005432621113	D6CB84	5846 134486	TATYANA KOZLOVA	{"phone": "+70266761226"}
0005432621114	925ED8	6606 795377	SOFIYA ILINA	{"phone": "+70640634118"}
0005432621115	44F96F	7624 808048	OLGA NESTEROVA	{"phone": "+70608427980"}
0005432621116	7088B8	9421 788722	MARIYA ZHUKOVA	{"email": "mzhukova1973@postgrespro.ru", "phone": "+70208567719"}
0005432621117	55CD11	3281 692166	NADEZHDA KUZNECOVA	{"phone": "+70352688119"}
0005432621118	80ABB9	4289 653452	VASILIY ZHUKOV	{"email": "v_zhukov21071969@postgrespro.ru", "phone": "+70234664606"}
0005432621119	369B91	7249 541889	GENNADIY ROMANOV	{"email": "romanov_g18071965@postgrespro.ru", "phone": "+70519848290"}
0005432621120	369B91	2504 427407	VLADIMIR KOZLOV	{"phone": "+70990145022"}
0005432621121	418426	8343 720509	GENNADIY SEMENOV	{"phone": "+70171277409"}
0005432621122	ADC88B	6713 420950	KRISTINA VOLKOVA	{"phone": "+70748044680"}
0005432621123	6C0C21	0165 342940	POLINA TROFIMOVA	{"email": "polinatrofimova-12071976@postgrespro.ru", "phone": "+70091463051"}
0005432621124	12DB57	3364 683075	VERA ANISIMOVA	{"email": "anisimova.vera.21041965@postgrespro.ru", "phone": "+70347023129"}
0005432621125	12DB57	1878 910613	ANGELINA ZAKHAROVA	{"email": "zakharova.a-13111974@postgrespro.ru", "phone": "+70330919715"}
0005432621126	208E1B	7452 894420	NINA ARKHIPOVA	{"phone": "+70058069869"}
0005432621127	208E1B	1667 579382	VLADIMIR ORLOV	{"email": "vladimir_orlov1965@postgrespro.ru", "phone": "+70739365600"}
0005432621128	E68D42	8606 092468	OLGA GUSEVA	{"email": "o.guseva_1963@postgrespro.ru", "phone": "+70032061187"}
0005432621129	E68D42	9727 284912	IRINA NIKIFOROVA	{"phone": "+70114105088"}
0005432621130	962C6B	0745 990536	MAKSIM AFANASEV	{"email": "afanasev_m_17041978@postgrespro.ru", "phone": "+70606806356"}
0005432621131	962C6B	0672 432243	IRINA GUSEVA	{"email": "irina_guseva_1981@postgrespro.ru", "phone": "+70396768799"}
0005432621132	998606	2683 377291	RAISA SOROKINA	{"email": "raisa-sorokina1980@postgrespro.ru", "phone": "+70308028625"}
0005432621133	F355A5	0973 545724	VERA STEPANOVA	{"email": "vera.stepanova_1980@postgrespro.ru", "phone": "+70753556487"}
0005432621134	9A3CFD	9152 047936	OLESYA BELOVA	{"email": "belovao_1959@postgrespro.ru", "phone": "+70253817231"}
0005432621135	9A3CFD	3142 887255	GALINA KUZNECOVA	{"phone": "+70783917768"}
0005432621136	EEB088	0877 316364	SERGEY IVANOV	{"phone": "+70772642184"}
0005432621137	99ACC5	5777 114954	SERGEY PAVLOV	{"phone": "+70259740974"}
0005432621138	FEC467	9169 511905	VIKTORIYA KALININA	{"phone": "+70575207497"}
0005432621139	FEC467	1518 179165	OLGA MAKAROVA	{"email": "olga-makarova1974@postgrespro.ru", "phone": "+70096282442"}
0005432621140	367D8B	8512 177357	LYUDMILA ALEKSEEVA	{"email": "lyudmila.alekseeva-1982@postgrespro.ru", "phone": "+70998066929"}
0005432621141	C8BB85	5898 527221	VITALIY OSIPOV	{"email": "v.osipov.16061978@postgrespro.ru", "phone": "+70583783737"}
0005432621142	C8BB85	1266 094806	ALISA RODIONOVA	{"phone": "+70340630685"}
0005432621143	C8BB85	9237 529424	ZAKHAR MOROZOV	{"phone": "+70119835160"}
0005432621144	AEABC9	0755 481177	LYUBOV KOROLEVA	{"email": "korolevalyubov.10081968@postgrespro.ru", "phone": "+70796375217"}
0005432621145	907BFD	2085 233658	ROMAN VASILEV	{"email": "vasilev.r.12071969@postgrespro.ru", "phone": "+70431116343"}
0005432621146	80C214	0617 540786	LYUBOV ZAYCEVA	{"phone": "+70124345528"}
0005432621147	80C214	6030 698659	LYUDMILA KAZAKOVA	{"email": "kazakoval-1977@postgrespro.ru", "phone": "+70843975343"}
0005432621148	1DFC06	4539 257157	VYACHESLAV SMIRNOV	{"phone": "+70773007305"}
0005432621149	1DFC06	2738 868660	ALLA POPOVA	{"email": "alla-popova_27011968@postgrespro.ru", "phone": "+70778822736"}
0005432621150	82DAF5	8426 778747	VALENTINA PAVLOVA	{"phone": "+70131552471"}
0005432621151	2AF42A	1877 509565	ALEKSANDR PAVLOV	{"phone": "+70410012646"}
0005432621152	2AF42A	9342 370194	OLGA ALEKSANDROVA	{"phone": "+70362867198"}
0005432621153	2AF42A	5886 077774	SERGEY ALEKSANDROV	{"email": "aleksandrov.s041968@postgrespro.ru", "phone": "+70522817911"}
0005432621154	78A9F9	0562 631515	DARYA FEDOROVA	{"email": "fedorova-darya.021964@postgrespro.ru", "phone": "+70564007607"}
0005432621155	2E14A7	0332 262069	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev-121971@postgrespro.ru", "phone": "+70674388261"}
0005432621156	AE21DA	1335 718691	IRINA FROLOVA	{"phone": "+70662238118"}
0005432621157	AE21DA	2146 811426	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_04041955@postgrespro.ru", "phone": "+70211315791"}
0005432621158	ED19D0	5480 811779	ALEKSANDR PETROV	{"email": "a-petrov-111975@postgrespro.ru", "phone": "+70079671967"}
0005432621159	9A5043	5020 491226	IRINA ROMANOVA	{"phone": "+70448904704"}
0005432621160	09CEE8	8166 410007	ARTEM ABRAMOV	{"phone": "+70592040619"}
0005432621161	DF0CB8	0198 243462	ANTONINA BORISOVA	{"phone": "+70566925353"}
0005432621162	E39841	8464 605864	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_1973@postgrespro.ru", "phone": "+70879323515"}
0005432621163	B878C3	6552 360711	YULIYA GERASIMOVA	{"email": "gerasimova.yuliya-02061964@postgrespro.ru", "phone": "+70179654765"}
0005432621164	7B166E	7353 142784	KRISTINA SEMENOVA	{"email": "k.semenova_031980@postgrespro.ru", "phone": "+70290143395"}
0005432621165	F96A37	8389 051954	RUZALIYA VASILEVA	{"phone": "+70391887431"}
0005432621166	F4E687	6405 955478	ELENA KOZLOVA	{"phone": "+70641510164"}
0005432621167	901655	3097 452012	KSENIYA GUSEVA	{"phone": "+70928234245"}
0005432621168	896348	3159 968775	GALINA KOVALEVA	{"phone": "+70120100808"}
0005432621169	896348	9484 327312	VASILIY IVANOV	{"email": "ivanov_v-011968@postgrespro.ru", "phone": "+70039097640"}
0005432621170	DA6C74	0345 259035	VALERIYA GORBUNOVA	{"email": "gorbunova-valeriya-101971@postgrespro.ru", "phone": "+70133715808"}
0005432621171	62A560	7608 725047	OLEG VASILEV	{"email": "o_vasilev011974@postgrespro.ru", "phone": "+70773763058"}
0005432621172	12424D	4887 880414	ELENA POLYAKOVA	{"phone": "+70840476843"}
0005432621173	6C70C9	8824 637978	DMITRIY RODIONOV	{"phone": "+70264647855"}
0005432621174	9DFF6B	5812 988003	ANNA NIKITINA	{"phone": "+70980527815"}
0005432621175	CA3B43	5840 128729	LYUDMILA SOROKINA	{"phone": "+70208515552"}
0005432621176	CA3B43	8044 183752	OLGA DMITRIEVA	{"phone": "+70652049776"}
0005432621177	88EAFF	0371 508357	NATALYA KUZMINA	{"phone": "+70968837822"}
0005432621178	88EAFF	1485 069716	YULIYA AKIMOVA	{"phone": "+70105300622"}
0005432621179	72CA86	3634 812388	MAKSIM KOROLEV	{"email": "korolev-m.111966@postgrespro.ru", "phone": "+70000043641"}
0005432621180	8CC610	5467 804790	ELIZAVETA MARTYNOVA	{"email": "emartynova_1979@postgrespro.ru", "phone": "+70744165475"}
0005432621181	DA8FD5	4559 797589	ZINAIDA ILINA	{"phone": "+70431715512"}
0005432621182	DA8FD5	3830 626346	ALEKSANDR GERASIMOV	{"email": "gerasimova_30111967@postgrespro.ru", "phone": "+70432339766"}
0005432621183	710887	3828 857385	ALEKSEY KUZNECOV	{"email": "kuznecov-a_061974@postgrespro.ru", "phone": "+70681512392"}
0005432621184	710887	2954 039602	MARIYA KUZMINA	{"email": "m-kuzmina-071976@postgrespro.ru", "phone": "+70223897390"}
0005432621185	63BDD6	4941 532208	YANA ZHUKOVA	{"email": "zhukova_y.1985@postgrespro.ru", "phone": "+70103503387"}
0005432621186	6521F6	2288 639856	NATALYA MARTYNOVA	{"phone": "+70551127903"}
0005432621187	6521F6	1867 697237	VIKTORIYA ANISIMOVA	{"email": "v-anisimova1981@postgrespro.ru", "phone": "+70437025827"}
0005432621188	81CE9D	3018 990037	EVELINA FOMINA	{"email": "fomina.e-1976@postgrespro.ru", "phone": "+70821272870"}
0005432621189	6F6333	5029 869051	ANATOLIY EGOROV	{"phone": "+70688314607"}
0005432621190	DED4EC	7019 925693	NINA ISAEVA	{"phone": "+70662790139"}
0005432621191	9377D3	5539 472919	VALERIY ZAKHAROV	{"phone": "+70284280930"}
0005432621192	85E959	6070 552534	TATYANA MOROZOVA	{"email": "morozova_tatyana-1972@postgrespro.ru", "phone": "+70024470320"}
0005432621193	0C9A37	2881 957374	NATALYA KUZNECOVA	{"phone": "+70212121325"}
0005432621194	0C9A37	7714 998786	IRINA KUZMINA	{"phone": "+70808199445"}
0005432621195	57F5C8	4575 171184	VALERIYA CHERNOVA	{"email": "valeriya_chernova_081974@postgrespro.ru", "phone": "+70960468963"}
0005432621196	57F5C8	1847 610083	ARTEM SOROKIN	{"email": "sorokinartem.15101970@postgrespro.ru", "phone": "+70892505496"}
0005432621197	57F5C8	1143 772399	TIMUR ZHUKOV	{"phone": "+70113034631"}
0005432621198	BFC869	1137 449410	PAVEL MAKAROV	{"email": "pavel_makarov121978@postgrespro.ru", "phone": "+70949342175"}
0005432621199	B45ADD	2088 330146	SVETLANA SIDOROVA	{"email": "svetlana.sidorova_1979@postgrespro.ru", "phone": "+70387187971"}
0005432621200	B45ADD	2403 421291	TAISIYA GERASIMOVA	{"email": "t.gerasimova1971@postgrespro.ru", "phone": "+70300285489"}
0005432621201	AD91DE	7574 448089	ANTON SOLOVEV	{"email": "a.solovev_1978@postgrespro.ru", "phone": "+70235464011"}
0005432621202	AD91DE	2569 772181	TATYANA KARPOVA	{"email": "karpova-t_101977@postgrespro.ru", "phone": "+70532778271"}
0005432621203	AD91DE	3034 472082	VALERIY SEMENOV	{"phone": "+70716145609"}
0005432621204	984E30	7906 285398	VALENTINA ALEKSANDROVA	{"email": "aleksandrova-valentina19081961@postgrespro.ru", "phone": "+70009796005"}
0005432621205	05D2A8	1426 150678	ANASTASIYA GORBUNOVA	{"phone": "+70531739857"}
0005432621206	685AB4	0771 195305	DMITRIY MOISEEV	{"phone": "+70152280641"}
0005432621207	8AEC8A	9856 845382	YURIY ISAEV	{"phone": "+70099420107"}
0005432621208	0C45A0	0309 002890	ANDREY ANTONOV	{"phone": "+70780539732"}
0005432621209	6C3174	4601 267674	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev.1980@postgrespro.ru", "phone": "+70068558379"}
0005432621210	601083	4881 912398	ZINAIDA LEBEDEVA	{"email": "lebedeva_z29111975@postgrespro.ru", "phone": "+70275651614"}
0005432621211	98BC64	1090 130882	ELENA ZAKHAROVA	{"phone": "+70313360710"}
0005432621212	98BC64	5380 045800	LYUDMILA ZHUKOVA	{"phone": "+70487828830"}
0005432621213	EA7236	2902 694324	ALENA VOROBEVA	{"phone": "+70118572526"}
0005432621214	BF75F1	6018 743861	ELENA OSIPOVA	{"email": "osipova_elena.27041975@postgrespro.ru", "phone": "+70820173081"}
0005432621326	DF231C	2281 094136	ALEKSANDR FEDOTOV	{"phone": "+70424351278"}
0005432621215	A0B760	7746 740226	NATALYA SOROKINA	{"email": "sorokina_natalya1969@postgrespro.ru", "phone": "+70562291243"}
0005432621216	A0B760	4403 772554	OLEG YAKOVLEV	{"email": "yakovlev_oleg-21041976@postgrespro.ru", "phone": "+70171538938"}
0005432621217	D9854E	5472 479354	IRINA GAVRILOVA	{"phone": "+70702102365"}
0005432621218	C83284	3481 022905	LYUBOV TITOVA	{"phone": "+70590461675"}
0005432621219	561676	0846 080880	ANATOLIY KOZLOV	{"phone": "+70502403651"}
0005432621220	561676	3824 397907	TATYANA PETROVA	{"phone": "+70444894349"}
0005432621221	7DD975	5916 949277	DANIIL ALEKSEEV	{"email": "dalekseev1975@postgrespro.ru", "phone": "+70607045039"}
0005432621222	467475	5820 920637	SOFIYA VOROBEVA	{"email": "vorobevas_1987@postgrespro.ru", "phone": "+70686853397"}
0005432621223	B20BC2	6962 102320	EGOR IVANOV	{"email": "ivanov_e1983@postgrespro.ru", "phone": "+70517219770"}
0005432621224	B8305A	3374 977607	EVDOKIYA SERGEEVA	{"email": "sergeeva-evdokiya1972@postgrespro.ru", "phone": "+70397488223"}
0005432621225	AC4603	4599 905380	NATALYA MOROZOVA	{"phone": "+70202793168"}
0005432621226	AC4603	5341 013291	DARYA KUZNECOVA	{"phone": "+70002276667"}
0005432621227	4E7BCB	8491 748881	ANNA VOROBEVA	{"email": "vorobeva-anna1973@postgrespro.ru", "phone": "+70714885350"}
0005432621228	28E3C5	8404 274576	ANATOLIY SIDOROV	{"phone": "+70985167656"}
0005432621229	2D12BF	6981 333218	IGOR GORBUNOV	{"email": "igor.gorbunov-23091967@postgrespro.ru", "phone": "+70295040942"}
0005432621230	542125	5853 627779	NIKOLAY GERASIMOV	{"phone": "+70112673298"}
0005432621231	A462D0	5699 089375	SERGEY GAVRILOV	{"phone": "+70808710111"}
0005432621232	A462D0	7046 919166	EVGENIY FEDOROV	{"phone": "+70803335667"}
0005432621233	09B983	8661 641729	DMITRIY SEMENOV	{"email": "semenov-d-1967@postgrespro.ru", "phone": "+70178630454"}
0005432621234	09B983	8079 257510	MARAT ABRAMOV	{"email": "mabramov.081974@postgrespro.ru", "phone": "+70639360524"}
0005432621235	71035C	6440 750020	GALINA VOLKOVA	{"email": "galina.volkova061971@postgrespro.ru", "phone": "+70888096303"}
0005432621236	A1D1A5	4943 947014	MAKSIM NOVIKOV	{"phone": "+70139862679"}
0005432621237	A1D1A5	0768 266722	ELENA PETROVA	{"phone": "+70149879259"}
0005432621238	A21DC9	3895 230233	EKATERINA PETROVA	{"phone": "+70885329109"}
0005432621239	35D326	3721 298032	LYUBOV VOROBEVA	{"email": "vorobeva-l-031965@postgrespro.ru", "phone": "+70804986238"}
0005432621240	35D326	3860 477538	ANNA ZHURAVLEVA	{"phone": "+70043784052"}
0005432621241	D9B4E5	6319 409474	IRINA SOROKINA	{"phone": "+70161645518"}
0005432621242	83D4A7	0455 002601	YULIYA TARASOVA	{"email": "tarasovay.25051980@postgrespro.ru", "phone": "+70460058462"}
0005432621243	83D4A7	7809 638782	ANASTASIYA KAZAKOVA	{"email": "anastasiya.kazakova.051962@postgrespro.ru", "phone": "+70227046526"}
0005432621244	613A70	4194 982211	SOFYA KAZAKOVA	{"email": "sofya-kazakova1974@postgrespro.ru", "phone": "+70935606562"}
0005432621245	613A70	1982 496744	LIDIYA MIRONOVA	{"email": "lidiyamironova.06041963@postgrespro.ru", "phone": "+70715473547"}
0005432621246	209973	8467 733262	DMITRIY GORBUNOV	{"email": "dmitriy.gorbunov-1979@postgrespro.ru", "phone": "+70315636683"}
0005432621247	209973	2652 791466	IRINA KUZMINA	{"phone": "+70593750628"}
0005432621248	4B7884	6888 518991	MIKHAIL SOKOLOV	{"email": "mikhail.sokolov_021974@postgrespro.ru", "phone": "+70616418803"}
0005432621249	2579CA	4050 765443	ANDREY NIKOLAEV	{"phone": "+70046700757"}
0005432621250	C174D7	9224 920189	IRINA DAVYDOVA	{"email": "davydova_i-011970@postgrespro.ru", "phone": "+70423943374"}
0005432621251	13959D	4279 288952	ELENA LOGINOVA	{"email": "e-loginova.1965@postgrespro.ru", "phone": "+70634774297"}
0005432621252	13959D	3814 418347	GALINA FILIPPOVA	{"email": "filippova_galina_26071976@postgrespro.ru", "phone": "+70405371877"}
0005432621253	DC33D9	4897 825119	ELENA VOLKOVA	{"phone": "+70242430929"}
0005432621254	5E501C	5999 629571	EKATERINA LAZAREVA	{"email": "lazareva-e-021980@postgrespro.ru", "phone": "+70099683359"}
0005432621255	AB842C	4190 026514	ALEKSANDR SIDOROV	{"phone": "+70259837981"}
0005432621256	AB842C	4943 434103	ILONA IVANOVA	{"phone": "+70234848611"}
0005432621257	AB842C	0212 603862	NATALYA RYABOVA	{"email": "nryabova-25121968@postgrespro.ru", "phone": "+70931528115"}
0005432621258	78BFDB	6339 050687	ALEKSANDR BONDARENKO	{"phone": "+70995559473"}
0005432621259	64E5AE	7581 832044	VALERIYA FROLOVA	{"email": "v-frolova_121968@postgrespro.ru", "phone": "+70625783926"}
0005432621260	64E5AE	0649 790893	LYUDMILA IVANOVA	{"email": "lyudmila-ivanova.24091981@postgrespro.ru", "phone": "+70020483728"}
0005432621261	85A9A5	5665 522868	SERGEY ANDREEV	{"phone": "+70136091830"}
0005432621262	85A9A5	2514 362859	SVETLANA NIKITINA	{"phone": "+70389545346"}
0005432621263	2769E5	8014 864993	ANDREY ANDREEV	{"phone": "+70423943635"}
0005432621264	1401AF	0733 401281	IRINA SIDOROVA	{"email": "i.sidorova.1972@postgrespro.ru", "phone": "+70982116488"}
0005432621265	1401AF	6110 443076	RAISA KISELEVA	{"email": "raisa_kiseleva-20111973@postgrespro.ru", "phone": "+70839642861"}
0005432621266	8690E5	9200 777572	NATALYA BORISOVA	{"email": "borisova_n04081962@postgrespro.ru", "phone": "+70707912423"}
0005432621267	1CE22B	0973 784729	PAVEL VLASOV	{"phone": "+70171244880"}
0005432621268	541A88	3518 326665	ANNA VLASOVA	{"email": "vlasova-a_15101968@postgrespro.ru", "phone": "+70179723266"}
0005432621269	541A88	7903 248095	NINA ANTONOVA	{"phone": "+70112659324"}
0005432621270	A9A44E	4993 648835	EKATERINA KUZNECOVA	{"phone": "+70369201129"}
0005432621271	B9F6A1	0412 259050	DARYA ARKHIPOVA	{"email": "arkhipova-d_1988@postgrespro.ru", "phone": "+70458269780"}
0005432621272	D6E62F	3736 376220	VIKTOR FEDOTOV	{"email": "v-fedotov05111976@postgrespro.ru", "phone": "+70154074203"}
0005432621273	D6E62F	3897 488202	LIDIYA MELNIKOVA	{"phone": "+70447732537"}
0005432621274	D6E62F	3279 788802	IVAN MATVEEV	{"email": "matveev-ivan.1977@postgrespro.ru", "phone": "+70384514212"}
0005432621275	35B3F2	6588 487327	LIDIYA LEBEDEVA	{"email": "lebedeva_lidiya-1968@postgrespro.ru", "phone": "+70718722092"}
0005432621276	FCFCA5	6427 504608	LIDIYA MARTYNOVA	{"phone": "+70177010035"}
0005432621277	683CD1	4753 048278	GALINA MIKHAYLOVA	{"email": "galina.mikhaylova.30041974@postgrespro.ru", "phone": "+70656313050"}
0005432621278	9EC7A5	3864 306964	IGOR FEDOROV	{"phone": "+70307502066"}
0005432621279	9EC7A5	1970 429025	GENNADIY IVANOV	{"phone": "+70266884066"}
0005432621280	55F00E	8965 704337	IGOR VLASOV	{"email": "i.vlasov-02031969@postgrespro.ru", "phone": "+70890089396"}
0005432621281	2E94FC	0124 689456	SERGEY ZAYCEV	{"phone": "+70914310313"}
0005432621282	002822	3657 599172	IRINA LOGINOVA	{"email": "loginova_i1971@postgrespro.ru", "phone": "+70466099087"}
0005432621284	6158C1	5187 869536	ALEKSANDR KULIKOV	{"phone": "+70493207254"}
0005432621285	334244	4294 296826	ALEKSANDR KUZNECOV	{"email": "kuznecov-a-101961@postgrespro.ru", "phone": "+70093032442"}
0005432621286	089B9F	8638 357172	PETR PETROV	{"email": "petrov-petr-1968@postgrespro.ru", "phone": "+70036885622"}
0005432621287	550B7F	1425 703529	LIDIYA ZAKHAROVA	{"phone": "+70677461856"}
0005432621288	20AE59	5247 569825	NATALYA IVANOVA	{"email": "natalyaivanova.19031962@postgrespro.ru", "phone": "+70850867814"}
0005432621289	5C0340	3754 644994	PETR FEDOROV	{"phone": "+70275341396"}
0005432621290	5C0340	3337 860747	MAKSIM MARTYNOV	{"email": "m-martynov051976@postgrespro.ru", "phone": "+70417881206"}
0005432621291	5C0340	9652 692753	SERGEY SOROKIN	{"email": "s_sorokin-101966@postgrespro.ru", "phone": "+70859254769"}
0005432621292	A9C6B0	3348 283728	RINAT NOVIKOV	{"email": "r-novikov-1970@postgrespro.ru", "phone": "+70954732994"}
0005432621293	8F5842	2243 128718	VITALIY MAKSIMOV	{"email": "v_maksimov-21071978@postgrespro.ru", "phone": "+70160777102"}
0005432621294	CCD57F	9052 740880	PAVEL DENISOV	{"email": "denisov.pavel_1972@postgrespro.ru", "phone": "+70402374359"}
0005432621295	26F1C5	9232 229200	ROMAN VASILEV	{"email": "vasilev-roman1970@postgrespro.ru", "phone": "+70003448105"}
0005432621296	5E49A2	3160 152281	ALEKSEY ALEKSANDROV	{"email": "a-aleksandrov-04111955@postgrespro.ru", "phone": "+70241303031"}
0005432621297	5E49A2	6942 472945	KONSTANTIN MELNIKOV	{"email": "k_melnikov1976@postgrespro.ru", "phone": "+70990701548"}
0005432621298	73560C	8804 251968	ALEVTINA FROLOVA	{"email": "a_frolova_1965@postgrespro.ru", "phone": "+70383843498"}
0005432621299	7F4A55	4701 150178	VYACHESLAV DMITRIEV	{"phone": "+70452953639"}
0005432621300	9B02A9	5219 206372	NADEZHDA LOGINOVA	{"email": "nadezhdaloginova.16051971@postgrespro.ru", "phone": "+70954224181"}
0005432621301	E45752	6077 137141	VASILIY KAZAKOV	{"email": "kazakov_vasiliy.18011989@postgrespro.ru", "phone": "+70149060341"}
0005432621302	8C6FC1	8575 057815	NATALIYA SERGEEVA	{"email": "sergeeva.nataliya-1976@postgrespro.ru", "phone": "+70566804593"}
0005432621303	0D7DB6	1827 402255	NATALYA YUDINA	{"email": "yudina.n_12061969@postgrespro.ru", "phone": "+70204262158"}
0005432621304	FF4213	4759 369341	VLADIMIR EGOROV	{"email": "egorov.vladimir-1960@postgrespro.ru", "phone": "+70513355432"}
0005432621305	17DE5B	1764 225631	NIKOLAY NIKOLAEV	{"phone": "+70048503342"}
0005432621306	FA6C52	1574 178013	ANNA YAKOVLEVA	{"email": "yakovleva-a.1977@postgrespro.ru", "phone": "+70311460318"}
0005432621307	FA6C52	2369 078488	ALEKSANDR NAUMOV	{"phone": "+70821613960"}
0005432621308	C3464F	7261 354495	VALENTINA DENISOVA	{"email": "valentina.denisova.1978@postgrespro.ru", "phone": "+70439164459"}
0005432621309	5491DA	2878 518711	NADEZHDA GAVRILOVA	{"phone": "+70546714965"}
0005432621310	534932	6537 883584	EVGENIY YAKOVLEV	{"phone": "+70587745117"}
0005432621311	7D97AA	2826 617545	ELENA NIKITINA	{"email": "e.nikitina-1980@postgrespro.ru", "phone": "+70313439661"}
0005432621312	BD6DD5	1546 333709	VLADIMIR PAVLOV	{"email": "vladimirpavlov031984@postgrespro.ru", "phone": "+70510735455"}
0005432621313	BD6DD5	7054 091174	LYUBOV KOROLEVA	{"email": "l-koroleva.1959@postgrespro.ru", "phone": "+70806868741"}
0005432621314	79AEC1	0263 626069	DANIIL KUZNECOV	{"phone": "+70476186045"}
0005432621315	79AEC1	8688 813069	AMIR DENISOV	{"email": "a_denisov-20101966@postgrespro.ru", "phone": "+70689377310"}
0005432621316	79AEC1	3304 365828	LYUBOV TIMOFEEVA	{"email": "timofeeva-lyubov-1978@postgrespro.ru", "phone": "+70705955762"}
0005432621317	715403	9032 971423	KONSTANTIN IVANOV	{"phone": "+70108274961"}
0005432621318	650CBC	5980 309552	RAISA KUDRYASHOVA	{"phone": "+70974973313"}
0005432621319	917627	2171 460363	DIANA KONOVALOVA	{"email": "dianakonovalova_061979@postgrespro.ru", "phone": "+70143637329"}
0005432621320	525EC9	6233 604809	YURIY YAKOVLEV	{"email": "yuriyyakovlev.041974@postgrespro.ru", "phone": "+70346960885"}
0005432621321	525EC9	5533 500424	ALEKSEY FOMIN	{"phone": "+70288321228"}
0005432621322	7C45E0	9784 598718	OLGA NAZAROVA	{"email": "nazarova_olga_111976@postgrespro.ru", "phone": "+70894295460"}
0005432621323	CE6BCA	2523 918741	ELENA LUKYANOVA	{"phone": "+70011477926"}
0005432621324	2AD4BA	8833 983232	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr-031967@postgrespro.ru", "phone": "+70962220215"}
0005432621325	DF231C	5975 092049	SANIYA NIKOLAEVA	{"phone": "+70965370682"}
0005432621327	F26BC8	9183 216758	SERGEY SOLOVEV	{"email": "solovev_s.071982@postgrespro.ru", "phone": "+70712256016"}
0005432621328	F26BC8	9824 225068	NATALYA VASILEVA	{"email": "natalya_vasileva-07121971@postgrespro.ru", "phone": "+70635572495"}
0005432621329	8D837E	2069 756833	YAROSLAV IVANOV	{"phone": "+70837884473"}
0005432621330	1185C8	2638 628964	VYACHESLAV NAZAROV	{"email": "vyacheslav_nazarov.091970@postgrespro.ru", "phone": "+70754885383"}
0005432621331	1185C8	8415 005479	VLADIMIR KOZLOV	{"phone": "+70025449271"}
0005432621332	AD239A	2633 264850	GALINA NIKIFOROVA	{"phone": "+70292710654"}
0005432621333	5E9619	2591 527563	TATYANA MIKHAYLOVA	{"email": "tatyanamikhaylova1988@postgrespro.ru", "phone": "+70177955897"}
0005432621334	5E9619	4035 012958	NIKITA SEMENOV	{"phone": "+70973412847"}
0005432621335	BADE8E	9615 566566	ARTEM IVANOV	{"email": "a_ivanov_20071970@postgrespro.ru", "phone": "+70912926292"}
0005432621336	F6E6C4	8834 966191	NATALYA MOROZOVA	{"email": "morozovanatalya1978@postgrespro.ru", "phone": "+70206163745"}
0005432621337	F6E6C4	2618 182013	SVETLANA IVANOVA	{"email": "sivanova_1966@postgrespro.ru", "phone": "+70226131461"}
0005432621338	81EBF6	6714 939894	ALENA RYABOVA	{"phone": "+70053515495"}
0005432621339	6CF516	3768 452320	IRINA MIKHAYLOVA	{"email": "imikhaylova31101965@postgrespro.ru", "phone": "+70214416594"}
0005432621340	6CF516	3271 968763	ALEKSANDR KARPOV	{"phone": "+70656443414"}
0005432621341	5920E0	5568 726338	ROZA KUZNECOVA	{"email": "kuznecova-r011968@postgrespro.ru", "phone": "+70465423902"}
0005432621342	1F8AAC	8748 719073	ANNA BELOVA	{"phone": "+70924453825"}
0005432621343	1F8AAC	3703 965827	ALEKSANDRA SAVELEVA	{"email": "a.saveleva-1980@postgrespro.ru", "phone": "+70816548788"}
0005432621344	738773	6033 569823	ARINA NIKITINA	{"email": "nikitina.arina.30041969@postgrespro.ru", "phone": "+70498399777"}
0005432621345	09390A	8861 305899	NIKITA GRIGOREV	{"email": "n_grigorev_041972@postgrespro.ru", "phone": "+70930244746"}
0005432621346	09390A	1985 909930	NIKOLAY KAZAKOV	{"phone": "+70301786640"}
0005432621347	09390A	0193 047846	LYUBOV ARKHIPOVA	{"email": "arkhipova-lyubov15051977@postgrespro.ru", "phone": "+70455386263"}
0005432621348	F22A22	8628 094256	ROMAN ROMANOV	{"phone": "+70467566907"}
0005432621349	F6BB04	3586 606460	IVAN KRASNOV	{"phone": "+70369750743"}
0005432621350	543245	0951 383331	MIKHAIL ZHUKOV	{"phone": "+70616893509"}
0005432621351	543245	0782 996825	IGOR ILIN	{"phone": "+70137795046"}
0005432621352	543245	6132 943935	KLAVDIYA FEDOROVA	{"email": "klavdiya-fedorova-22121968@postgrespro.ru", "phone": "+70584916715"}
0005432621353	44647D	0684 278056	IGOR NIKOLAEV	{"phone": "+70958749485"}
0005432621354	44647D	4753 525469	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.11091983@postgrespro.ru", "phone": "+70584907204"}
0005432621355	25995C	4389 375027	YULIYA DAVYDOVA	{"phone": "+70501469912"}
0005432621356	25995C	6137 781269	ARINA GUSEVA	{"phone": "+70789436575"}
0005432621357	173203	7771 773179	TATYANA MAKAROVA	{"email": "t.makarova1987@postgrespro.ru", "phone": "+70023720359"}
0005432621358	7D6F01	9097 617282	RAISA NAZAROVA	{"email": "r-nazarova_1970@postgrespro.ru", "phone": "+70559152806"}
0005432621359	AF8D31	1037 321578	NADEZHDA ABRAMOVA	{"email": "nadezhda-abramova-1973@postgrespro.ru", "phone": "+70712117718"}
0005432621360	E0A2F0	6029 460140	RAFIS IVANOV	{"phone": "+70479166767"}
0005432621361	FA59C8	1698 906167	ANNA MOROZOVA	{"phone": "+70578593187"}
0005432621362	FA59C8	0048 850074	SEMEN POPOV	{"email": "semenpopov16091978@postgrespro.ru", "phone": "+70493920696"}
0005432621363	FA59C8	2194 997709	MATRENA KALININA	{"email": "kalinina-matrena.081972@postgrespro.ru", "phone": "+70731426348"}
0005432621364	F29FE3	9598 405865	TATYANA CHERNOVA	{"email": "chernova-t_03071968@postgrespro.ru", "phone": "+70404781715"}
0005432621365	46E97E	6660 540014	TATYANA NAZAROVA	{"email": "nazarova_t_1979@postgrespro.ru", "phone": "+70326812637"}
0005432621366	46E97E	4050 652979	ANTONINA POPOVA	{"email": "antonina.popova_1971@postgrespro.ru", "phone": "+70696220901"}
0005432621367	5CD2C7	2858 391613	LARISA SMIRNOVA	{"email": "smirnova-larisa.1967@postgrespro.ru", "phone": "+70718990801"}
0005432621368	C18B05	8712 246655	ALEKSANDR AFANASEV	{"phone": "+70213473637"}
0005432621369	C18B05	6774 660569	ANDREY GAVRILOV	{"phone": "+70622664722"}
0005432621370	C18B05	4086 699776	SVETLANA ANDREEVA	{"email": "andreeva_svetlana_111973@postgrespro.ru", "phone": "+70624895979"}
0005432621371	C18B05	9632 634149	EKATERINA ZAKHAROVA	{"phone": "+70088612899"}
0005432621372	27F903	2971 582704	ALEKSANDR KUZNECOV	{"phone": "+70183162650"}
0005432621373	85918B	6356 280331	ANATOLIY KONOVALOV	{"phone": "+70628186886"}
0005432621374	85918B	0049 234686	GRIGORIY DAVYDOV	{"email": "grigoriy.davydov-1965@postgrespro.ru", "phone": "+70810446473"}
0005432621375	CAD4D3	0218 801444	VIKTOR NOVIKOV	{"phone": "+70890097487"}
0005432621376	5EFFE7	9898 639418	ELENA BORISOVA	{"phone": "+70681475730"}
0005432621377	9C06A2	6099 686918	LYUBOV ROMANOVA	{"phone": "+70536337276"}
0005432621378	3D8662	6608 888263	ANASTASIYA SERGEEVA	{"phone": "+70862931090"}
0005432621379	3D8662	6310 453865	ANTONINA IVANOVA	{"email": "a-ivanova_06101972@postgrespro.ru", "phone": "+70222132036"}
0005432621380	3D8662	5003 755609	ANATOLIY RODIONOV	{"phone": "+70107140410"}
0005432621381	141620	7989 711006	ELENA MIRONOVA	{"email": "mironova-elena-11061975@postgrespro.ru", "phone": "+70634068126"}
0005432621382	C64E99	6745 326657	LYUBOV VLASOVA	{"phone": "+70379293981"}
0005432621383	A3A8EA	6032 091463	TAMARA MARTYNOVA	{"email": "martynova_t-121980@postgrespro.ru", "phone": "+70620693913"}
0005432621384	A3A8EA	6114 901459	VALENTINA SCHERBAKOVA	{"email": "scherbakova-v.091960@postgrespro.ru", "phone": "+70618790883"}
0005432621385	A3A8EA	6256 654323	NIKITA ALEKSEEV	{"phone": "+70698053893"}
0005432621386	A3A8EA	8507 583550	VLADIMIR NAUMOV	{"email": "naumov-vladimir_1967@postgrespro.ru", "phone": "+70471589632"}
0005432621387	DF7341	8592 572761	SANIYA SERGEEVA	{"phone": "+70036548756"}
0005432621388	10A1DB	3360 037605	LYUDMILA SIDOROVA	{"email": "lyudmilasidorova_031980@postgrespro.ru", "phone": "+70023581419"}
0005432621389	F03D53	9148 096720	ALEKSEY GUSEV	{"phone": "+70963931424"}
0005432621390	F03D53	9064 433289	NADEZHDA BORISOVA	{"email": "n-borisova1985@postgrespro.ru", "phone": "+70420959046"}
0005432621391	0D332F	9181 089564	TAMARA BORISOVA	{"phone": "+70378915027"}
0005432621392	42DB15	2911 497880	MARGARITA TIMOFEEVA	{"email": "mtimofeeva.091976@postgrespro.ru", "phone": "+70426782398"}
0005432621393	42DB15	0739 904450	MIKHAIL KUZMIN	{"phone": "+70011421214"}
0005432621394	8C6DCD	6694 435806	MAKSIM DAVYDOV	{"phone": "+70930361603"}
0005432621395	60DA8C	5354 101593	MARIYA KUZMINA	{"email": "kuzmina_m21121979@postgrespro.ru", "phone": "+70219356926"}
0005432621396	60DA8C	3403 381351	VASILIY IVANOV	{"phone": "+70007868438"}
0005432621397	079B5C	2939 240604	ANNA KUZMINA	{"email": "kuzmina_anna.1970@postgrespro.ru", "phone": "+70528731758"}
0005432621398	B61CCD	2477 563804	ELENA YAKOVLEVA	{"email": "yakovlevae-01111972@postgrespro.ru", "phone": "+70786441723"}
0005432621399	0E6BE6	3421 012509	ANDREY MELNIKOV	{"phone": "+70711092312"}
0005432621400	F94E5E	4070 915658	GALINA MELNIKOVA	{"email": "galina-melnikova.1972@postgrespro.ru", "phone": "+70746565340"}
0005432621401	2CA54E	9191 776758	VLADIMIR IVANOV	{"email": "v_ivanov-17081979@postgrespro.ru", "phone": "+70772320947"}
0005432621402	49B01F	4432 717488	ANATOLIY KOZLOV	{"phone": "+70311541115"}
0005432621403	DEB182	0799 187361	RAFAEL GUSEV	{"phone": "+70218612674"}
0005432621404	DEB182	2248 418925	ALINA MIRONOVA	{"phone": "+70910610595"}
0005432621405	DEB182	1968 968773	VLADISLAV CHERNOV	{"email": "chernovv.26011974@postgrespro.ru", "phone": "+70896175031"}
0005432621406	A5AD6D	1605 685315	VADIM SCHERBAKOV	{"email": "v.scherbakov101977@postgrespro.ru", "phone": "+70264430596"}
0005432621407	A5AD6D	0593 860434	SVETLANA MAKSIMOVA	{"email": "svetlana-maksimova.1978@postgrespro.ru", "phone": "+70666199685"}
0005432621408	B2BFD5	0639 431890	VALENTINA NOVIKOVA	{"phone": "+70279955352"}
0005432621409	B2BFD5	2348 476869	TAMARA IVANOVA	{"email": "ivanova-tamara_1964@postgrespro.ru", "phone": "+70292510901"}
0005432621410	E34248	3286 948424	DANIL NIKITIN	{"phone": "+70322673185"}
0005432621411	FA6C3B	9263 024778	TARAS STEPANOV	{"phone": "+70052822881"}
0005432621412	8E91BC	6723 193146	ALENA KUZNECOVA	{"email": "alena.kuznecova.03011978@postgrespro.ru", "phone": "+70197415636"}
0005432621413	CBD605	6898 848491	VALENTINA ROMANOVA	{"email": "romanova_valentina.28101975@postgrespro.ru", "phone": "+70197194182"}
0005432621414	BF7DF7	7411 877047	SERGEY SMIRNOV	{"email": "s.smirnov_1964@postgrespro.ru", "phone": "+70987658030"}
0005432621415	58E046	1165 275671	VASILIY ABRAMOV	{"email": "abramovvasiliy.1966@postgrespro.ru", "phone": "+70499625686"}
0005432621416	58E046	7328 750214	SERGEY VASILEV	{"email": "s_vasilev.1962@postgrespro.ru", "phone": "+70555476968"}
0005432621417	3A6EF1	1367 735352	IVAN MAKAROV	{"phone": "+70805394720"}
0005432621418	3A6EF1	1692 009643	LYUBOV ORLOVA	{"email": "lyubov-orlova-1973@postgrespro.ru", "phone": "+70224895932"}
0005432621419	6B88A9	7031 117531	SERGEY GUSEV	{"phone": "+70256957571"}
0005432621420	BFB816	8216 746483	IRINA DMITRIEVA	{"email": "idmitrieva_1965@postgrespro.ru", "phone": "+70449482475"}
0005432621421	BFB816	6179 903373	RINAT SOKOLOV	{"phone": "+70003501530"}
0005432621422	14FBFA	5316 631756	DMITRIY GUSEV	{"email": "gusev.d_08041966@postgrespro.ru", "phone": "+70398439502"}
0005432621423	914C79	6135 684207	NIKOLAY NOVIKOV	{"phone": "+70193821986"}
0005432621424	914C79	8017 732093	ELIZAVETA BARANOVA	{"phone": "+70450751365"}
0005432621425	A0CE98	0857 014582	ZINAIDA ALEKSANDROVA	{"email": "z-aleksandrova_1967@postgrespro.ru", "phone": "+70186288841"}
0005432621426	A0CE98	1372 509722	ARTEM ZAKHAROV	{"email": "zakharov_artem041964@postgrespro.ru", "phone": "+70212090950"}
0005432621427	E22A39	5771 310023	NAIL KUZNECOV	{"email": "kuznecov-n-08081968@postgrespro.ru", "phone": "+70222252937"}
0005432621428	C86746	0027 611420	DENIS EGOROV	{"email": "egorov.d_20021972@postgrespro.ru", "phone": "+70474761112"}
0005432621429	C86746	0332 399085	DMITRIY PAVLOV	{"phone": "+70828314744"}
0005432621430	C4C6D7	7043 797607	VASILIY KOROLEV	{"phone": "+70157085695"}
0005432621431	51B5D2	8322 382202	EKATERINA MAKAROVA	{"phone": "+70438842353"}
0005432621432	51B5D2	4678 334693	NATALYA FEDOROVA	{"email": "natalyafedorova-1970@postgrespro.ru", "phone": "+70306163563"}
0005432621433	2BAC04	5075 002684	RUSLAN VOROBEV	{"phone": "+70556134822"}
0005432621434	2BAC04	8458 215532	GENNADIY PAVLOV	{"email": "pavlovg_081976@postgrespro.ru", "phone": "+70721438310"}
0005432621435	E62C5C	2772 924339	OLGA ZAKHAROVA	{"phone": "+70332361155"}
0005432621436	E62C5C	9182 077866	ILNUR CHERNOV	{"email": "i.chernov_19121976@postgrespro.ru", "phone": "+70074114879"}
0005432621437	CDD7A8	5724 843583	VASILIY NAUMOV	{"phone": "+70388413090"}
0005432621438	CDD7A8	5865 219062	ALEKSEY RODIONOV	{"email": "aleksey_rodionov.051962@postgrespro.ru", "phone": "+70252018685"}
0005432621439	FF64ED	0348 380465	EVGENIYA ANDREEVA	{"phone": "+70367238595"}
0005432621440	0C831F	8248 918071	ULYANA SOLOVEVA	{"phone": "+70692549992"}
0005432621441	0C831F	7688 427226	ELENA SOROKINA	{"email": "sorokinae.1966@postgrespro.ru", "phone": "+70386068614"}
0005432621442	07470D	0293 114693	NIKOLAY IVANOV	{"email": "ivanovn24111977@postgrespro.ru", "phone": "+70870892390"}
0005432621443	07470D	6811 236003	VIKTOR GAVRILOV	{"email": "viktor.gavrilov_13051969@postgrespro.ru", "phone": "+70322843348"}
0005432621444	95F08D	9328 790982	YURIY VASILEV	{"phone": "+70763409379"}
0005432621445	95F08D	7109 947713	NADEZHDA ZAKHAROVA	{"email": "nadezhda_zakharova.091968@postgrespro.ru", "phone": "+70223501899"}
0005432621446	F7FC7D	5089 658497	ILYA MOISEEV	{"email": "moiseev-ilya_101974@postgrespro.ru", "phone": "+70819818809"}
0005432621447	4B696E	8780 955710	MIKHAIL KUZNECOV	{"email": "kuznecov_mikhail051969@postgrespro.ru", "phone": "+70091581711"}
0005432621448	4B696E	3760 604199	SERGEY VOLKOV	{"phone": "+70863771359"}
0005432621449	8D02A0	1096 353835	VITALIY MARTYNOV	{"phone": "+70191634202"}
0005432621450	8D02A0	4954 435832	OLGA STEPANOVA	{"phone": "+70535336189"}
0005432621451	EF4F28	4969 016043	VALENTINA NAZAROVA	{"email": "nazarovav16101971@postgrespro.ru", "phone": "+70879677486"}
0005432621452	EF4F28	1425 036980	TATYANA IVANOVA	{"email": "t_ivanova.1989@postgrespro.ru", "phone": "+70791302799"}
0005432621453	89E2E8	0943 881821	SVETLANA EFIMOVA	{"email": "efimova.s-111975@postgrespro.ru", "phone": "+70381857856"}
0005432621454	FB0A3D	5929 531113	ANDREY KOZLOV	{"email": "andreykozlov-12111971@postgrespro.ru", "phone": "+70965618578"}
0005432621455	0903C9	2370 867969	LYUDMILA KONOVALOVA	{"phone": "+70255336460"}
0005432621456	0903C9	4100 372807	ROMAN ZAKHAROV	{"phone": "+70591130980"}
0005432621457	3F24E5	2593 433203	KONSTANTIN SCHERBAKOV	{"email": "k.scherbakov-26091961@postgrespro.ru", "phone": "+70448387317"}
0005432621458	2D1B5E	4035 134605	DMITRIY KISELEV	{"email": "d_kiselev_021963@postgrespro.ru", "phone": "+70305789111"}
0005432621459	F34079	1769 878451	VALERIY FILIPPOV	{"phone": "+70618234111"}
0005432628585	EB4226	5395 212168	ANTON DAVYDOV	{"phone": "+70548448326"}
0005432628586	5D9E38	1095 044059	VIKTOR MIKHAYLOV	{"phone": "+70478382917"}
0005432628647	493304	0393 951814	NATALYA KONDRATEVA	{"email": "kondrateva.n.011981@postgrespro.ru", "phone": "+70948696470"}
0005432628587	61EAC7	0093 271823	ALEKSANDRA KUZNECOVA	{"email": "kuznecova-aleksandra-041971@postgrespro.ru", "phone": "+70085718770"}
0005432628588	61EAC7	1700 690956	VIKTOR BORISOV	{"phone": "+70092040190"}
0005432628589	A9FE9E	5483 081359	KLIM GORBUNOV	{"phone": "+70131966491"}
0005432628590	A9FE9E	5146 913517	VIKTOR BONDARENKO	{"phone": "+70450547405"}
0005432628591	7ACEF5	3700 830832	EGOR SMIRNOV	{"email": "e_smirnov_041968@postgrespro.ru", "phone": "+70152911718"}
0005432628592	7ACEF5	2950 582616	PAVEL GERASIMOV	{"phone": "+70034033197"}
0005432628593	37DDFA	5353 359953	ALEKSANDR KUZNECOV	{"email": "kuznecov-a.11101971@postgrespro.ru", "phone": "+70413786980"}
0005432628594	0D5AD5	8684 205278	EVGENIY NIKOLAEV	{"phone": "+70452732842"}
0005432628595	9A5F22	8603 835555	VALERIY PAVLOV	{"phone": "+70877787426"}
0005432628596	2BBB6C	1194 373728	LYUBOV ALEKSEEVA	{"phone": "+70585643805"}
0005432628597	AB8701	2761 517835	MAKSIM KUDRYASHOV	{"email": "kudryashov_maksim_21061975@postgrespro.ru", "phone": "+70648108991"}
0005432628598	77DA96	0977 353740	NADEZHDA SMIRNOVA	{"phone": "+70745245587"}
0005432628599	77DA96	2933 948084	NATALYA KUZNECOVA	{"phone": "+70947149406"}
0005432628600	2A0D22	8488 431583	EGOR SCHERBAKOV	{"phone": "+70473736100"}
0005432628601	EBE6DB	1352 225274	MARIANNA ALEKSEEVA	{"email": "alekseeva_m_121968@postgrespro.ru", "phone": "+70127549682"}
0005432628602	2C790F	8411 659799	NATALYA ALEKSEEVA	{"email": "n-alekseeva_121964@postgrespro.ru", "phone": "+70779144306"}
0005432628603	2C790F	5873 130560	LYUBOV KOROLEVA	{"email": "koroleva.lyubov.091983@postgrespro.ru", "phone": "+70024792753"}
0005432628604	F53BFB	0240 988796	VALENTINA KOROLEVA	{"phone": "+70955722200"}
0005432628605	F53BFB	4867 741249	SVETLANA SCHERBAKOVA	{"email": "scherbakovasvetlana1974@postgrespro.ru", "phone": "+70474543013"}
0005432628606	642300	6708 874967	MIKHAIL BARANOV	{"phone": "+70835590236"}
0005432628607	CA0A2E	9370 467114	OLEG KISELEV	{"email": "olegkiselev_01111969@postgrespro.ru", "phone": "+70215489527"}
0005432628608	F00442	9114 234166	ANASTASIYA DMITRIEVA	{"email": "dmitrievaa_06041979@postgrespro.ru", "phone": "+70140274396"}
0005432628609	971D6C	5042 152568	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy1966@postgrespro.ru", "phone": "+70215994687"}
0005432628610	971D6C	2686 578896	SOFIYA SOLOVEVA	{"phone": "+70662119554"}
0005432628611	E91F73	4329 290869	OLGA NIKOLAEVA	{"email": "o_nikolaeva-081979@postgrespro.ru", "phone": "+70294361032"}
0005432628612	E91F73	5322 137235	EKATERINA KUZMINA	{"email": "ekaterina-kuzmina.031968@postgrespro.ru", "phone": "+70933302247"}
0005432628613	68B11D	4789 675905	ANASTASIYA LOGINOVA	{"email": "anastasiya.loginova-06111966@postgrespro.ru", "phone": "+70246928841"}
0005432628614	7C1FE8	4256 435828	LEONID GORBUNOV	{"phone": "+70046215245"}
0005432628615	7C1FE8	4918 653178	GALINA BELYAEVA	{"phone": "+70610468618"}
0005432628616	7C1FE8	1511 986693	VLADISLAV YAKOVLEV	{"phone": "+70026586796"}
0005432628617	ECE366	0745 873873	ALBINA ILINA	{"phone": "+70441143494"}
0005432628618	3038F5	7649 172504	ALEKSANDR VOLKOV	{"phone": "+70685166689"}
0005432628619	6B4B95	0371 992283	ALEKSEY MOISEEV	{"phone": "+70188847438"}
0005432628620	505C26	4741 977499	OLGA SOKOLOVA	{"phone": "+70429282606"}
0005432628621	988079	4208 990486	VERA RODIONOVA	{"phone": "+70820614768"}
0005432628622	CEDDB8	9107 224283	VERA ERMAKOVA	{"email": "ermakova-vera.051971@postgrespro.ru", "phone": "+70184884216"}
0005432628623	0851FE	4384 108702	SVETLANA VASILEVA	{"email": "vasilevasvetlana111976@postgrespro.ru", "phone": "+70802855567"}
0005432628624	DDEC31	6780 148940	ELENA MARTYNOVA	{"phone": "+70230837374"}
0005432628625	7EFDD4	6609 818933	VLADIMIR SEMENOV	{"email": "semenov_v_1983@postgrespro.ru", "phone": "+70410245878"}
0005432628626	7EFDD4	6500 793790	ARTEM SEMENOV	{"phone": "+70580026970"}
0005432628627	A121FD	6359 492713	YURIY AFANASEV	{"phone": "+70462505168"}
0005432628628	EEAE39	8412 069856	VERONIKA SOLOVEVA	{"email": "soloveva-veronika1971@postgrespro.ru", "phone": "+70418109226"}
0005432628629	EEAE39	2600 518464	ELENA IVANOVA	{"email": "ivanova-elena_02021991@postgrespro.ru", "phone": "+70840609282"}
0005432628630	4F8C84	4644 786849	PETR STEPANOV	{"email": "stepanovp121972@postgrespro.ru", "phone": "+70945617897"}
0005432628631	33821C	7801 173027	VASILIY VOLKOV	{"email": "volkovvasiliy.011979@postgrespro.ru", "phone": "+70911161672"}
0005432628632	33821C	5343 470408	NATALYA IVANOVA	{"phone": "+70007499512"}
0005432628633	3EB30F	2380 309442	GALINA KULIKOVA	{"email": "kulikova.galina.1981@postgrespro.ru", "phone": "+70365820497"}
0005432628634	8C7CBB	1881 883148	NONNA NESTEROVA	{"phone": "+70139757852"}
0005432628635	898F50	1932 889932	MARAT ZAKHAROV	{"email": "m_zakharov-061984@postgrespro.ru", "phone": "+70304649616"}
0005432628636	628D0D	0030 883136	NINA BOGDANOVA	{"phone": "+70556386260"}
0005432628637	717899	3194 803817	VALERIY POPOV	{"phone": "+70120321334"}
0005432628638	C7F6BB	5683 466671	ALEKSANDRA ZAKHAROVA	{"email": "zakharova-a-26051964@postgrespro.ru", "phone": "+70749266237"}
0005432628639	B84684	4239 145786	RIMMA RYABOVA	{"email": "r_ryabova_101980@postgrespro.ru", "phone": "+70246817961"}
0005432628640	96A8CC	3104 364308	ALEKSEY TARASOV	{"phone": "+70794746202"}
0005432628641	787600	7801 310670	IVAN POPOV	{"phone": "+70088407233"}
0005432628642	E5072D	2649 780350	ANATOLIY MOROZOV	{"email": "a_morozov051981@postgrespro.ru", "phone": "+70160095900"}
0005432628643	E5072D	1302 861755	SERGEY VOLKOV	{"email": "s-volkov111978@postgrespro.ru", "phone": "+70946111738"}
0005432628644	D6DB59	0851 943777	OLGA BORISOVA	{"email": "olga-borisova121975@postgrespro.ru", "phone": "+70216028976"}
0005432628645	BD4037	2892 742727	VALENTINA NIKOLAEVA	{"email": "nikolaeva-v.1961@postgrespro.ru", "phone": "+70186170201"}
0005432628646	BD4037	4290 351417	ALLA ARKHIPOVA	{"email": "arkhipova.a.031977@postgrespro.ru", "phone": "+70470216161"}
0005432628648	493304	0066 114215	VIKTOR IVANOV	{"email": "viktorivanov.1963@postgrespro.ru", "phone": "+70689705137"}
0005432628649	A980F5	9333 569192	ANATOLIY SCHERBAKOV	{"phone": "+70523339061"}
0005432628650	A980F5	6042 328324	MAKSIM VOLKOV	{"phone": "+70703782865"}
0005432628651	F14B4E	9840 329584	ANDREY ZHURAVLEV	{"email": "zhuravlevandrey_031967@postgrespro.ru", "phone": "+70162643208"}
0005432628652	FB663E	4257 192117	GALINA KOROLEVA	{"email": "g.koroleva1974@postgrespro.ru", "phone": "+70513760941"}
0005432628653	ADEE78	1921 351442	OLGA POPOVA	{"phone": "+70369974034"}
0005432628654	0281EC	1669 972880	ILYA DAVYDOV	{"email": "i_davydov_31101986@postgrespro.ru", "phone": "+70738965878"}
0005432628655	F19505	1686 048042	VLADIMIR ZAKHAROV	{"phone": "+70807327853"}
0005432628656	63997B	8756 726721	PAVEL SEMENOV	{"phone": "+70888454163"}
0005432628657	63997B	9015 615404	NINA KUZNECOVA	{"email": "nina.kuznecova.1967@postgrespro.ru", "phone": "+70933762309"}
0005432628658	A579C5	5062 231761	NINA NOVIKOVA	{"phone": "+70382363208"}
0005432628659	A579C5	6773 721447	SVETLANA MOISEEVA	{"phone": "+70771378853"}
0005432628660	C2FF29	3284 452625	SERGEY ZAKHAROV	{"email": "zakharovsergey_091975@postgrespro.ru", "phone": "+70458878893"}
0005432628661	6F5CA2	4448 649329	VALENTINA SMIRNOVA	{"phone": "+70441199474"}
0005432628662	805B29	4490 859069	NIKOLAY DAVYDOV	{"phone": "+70243360958"}
0005432628663	B70BC9	3134 459101	GALINA ANDREEVA	{"phone": "+70049971025"}
0005432628664	B70BC9	5083 881986	DENIS MAKAROV	{"email": "makarov_denis-09051968@postgrespro.ru", "phone": "+70987072812"}
0005432628665	ABA831	5552 672108	VIKTOR KUZNECOV	{"email": "v.kuznecov.1985@postgrespro.ru", "phone": "+70906018397"}
0005432628666	ABA831	0422 021453	GRIGORIY FILIPPOV	{"email": "filippov.grigoriy.041974@postgrespro.ru", "phone": "+70510679272"}
0005432628667	2C1EA7	6496 236865	VLADIMIR MOISEEV	{"email": "moiseev-vladimir_071965@postgrespro.ru", "phone": "+70686961356"}
0005432628668	FC0F30	7731 794939	OKSANA BORISOVA	{"phone": "+70757567090"}
0005432628669	CE8F13	9531 442505	VLADISLAV OSIPOV	{"phone": "+70703607762"}
0005432628670	094B2B	1554 981334	PETR SERGEEV	{"email": "sergeev-petr-121976@postgrespro.ru", "phone": "+70354953827"}
0005432628671	17395F	2749 715691	MARIYA CHERNOVA	{"email": "m_chernova_18031973@postgrespro.ru", "phone": "+70359892187"}
0005432628672	64CCCE	8482 641453	EVGENIY KAZAKOV	{"phone": "+70489015159"}
0005432628673	64CCCE	1301 211811	IVAN SAVELEV	{"email": "savelev-i-031970@postgrespro.ru", "phone": "+70028878801"}
0005432628674	64CCCE	7353 773567	LYUBOV BELOVA	{"phone": "+70859445504"}
0005432628675	207189	9414 841981	TATYANA PETROVA	{"email": "petrovat22051970@postgrespro.ru", "phone": "+70276976987"}
0005432628676	D27E78	9316 656304	GALINA EFIMOVA	{"phone": "+70711639864"}
0005432628677	F27DE8	8068 621519	ALEKSANDR ALEKSEEV	{"email": "alekseeva.10031979@postgrespro.ru", "phone": "+70928657947"}
0005432628678	F27DE8	1843 562292	KSENIYA SCHERBAKOVA	{"phone": "+70201197394"}
0005432628679	A4CD51	0748 801782	ILYA KUZNECOV	{"email": "ilya-kuznecov_19061978@postgrespro.ru", "phone": "+70818993184"}
0005432628680	02C6D1	1874 100169	EKATERINA ZAYCEVA	{"phone": "+70856951515"}
0005432628681	721D14	1377 660477	DMITRIY MAKAROV	{"phone": "+70748865464"}
0005432628682	8BAD95	1680 349314	OLGA SMIRNOVA	{"phone": "+70005739562"}
0005432628683	CA8547	3955 163197	SERGEY MAKSIMOV	{"phone": "+70280050025"}
0005432628684	CA8547	5635 036105	LYUDMILA PETROVA	{"email": "petrovalyudmila_1968@postgrespro.ru", "phone": "+70956983849"}
0005432628685	B75A7D	4271 885127	MARGARITA LUKYANOVA	{"phone": "+70884045564"}
0005432628686	D7A87E	3543 755993	VALENTINA KULIKOVA	{"phone": "+70056509677"}
0005432628687	B9CDBE	0935 884877	ANASTASIYA KRASNOVA	{"email": "krasnova_a-1973@postgrespro.ru", "phone": "+70562665819"}
0005432628688	EE72D9	0809 362127	NATALYA SMIRNOVA	{"phone": "+70864018398"}
0005432628689	EE72D9	6982 268054	SERGEY MATVEEV	{"email": "sergey_matveev_22121973@postgrespro.ru", "phone": "+70012245774"}
0005432628690	A79499	9985 997623	OLGA KOVALEVA	{"email": "o-kovaleva_1979@postgrespro.ru", "phone": "+70932285295"}
0005432628691	0C114B	6756 000124	OLGA TIKHONOVA	{"email": "tikhonova-olga.23051986@postgrespro.ru", "phone": "+70365185809"}
0005432628692	76EE9F	4343 608753	ALENA KRASNOVA	{"phone": "+70561506905"}
0005432628693	DFA484	0346 185694	VIKTOR STEPANOV	{"email": "stepanov_viktor.081973@postgrespro.ru", "phone": "+70041666227"}
0005432628694	BBACE7	3657 288866	DINARA PAVLOVA	{"email": "pavlova-dinara.011968@postgrespro.ru", "phone": "+70940461873"}
0005432628695	BBACE7	2224 193953	ALEKSANDR SCHERBAKOV	{"email": "scherbakova-21081967@postgrespro.ru", "phone": "+70150213600"}
0005432628696	FE8257	9422 610807	NATALYA PETROVA	{"email": "petrova_natalya.021970@postgrespro.ru", "phone": "+70247180344"}
0005432628697	5F5A1B	2009 947369	ARTEM KUDRYASHOV	{"email": "kudryashov.a-121974@postgrespro.ru", "phone": "+70744619201"}
0005432628698	5F5A1B	8308 520128	PETR AFANASEV	{"phone": "+70510939326"}
0005432628699	633E0E	5631 181774	ALEKSANDR VOLKOV	{"email": "volkova-27091959@postgrespro.ru", "phone": "+70460776664"}
0005432628700	C48CFE	1745 399689	SERGEY GERASIMOV	{"email": "sergey-gerasimov_041962@postgrespro.ru", "phone": "+70600922838"}
0005432628701	462431	4410 096115	VYACHESLAV MIRONOV	{"email": "vmironov.051974@postgrespro.ru", "phone": "+70537591962"}
0005432628702	FA8F47	3153 160658	ARTEM POPOV	{"email": "a.popov.021976@postgrespro.ru", "phone": "+70914198573"}
0005432628703	FA8F47	6091 211639	ALEVTINA OVCHINNIKOVA	{"phone": "+70779305065"}
0005432628704	3FC1C6	9224 205175	IVAN SOROKIN	{"phone": "+70883380524"}
0005432628705	B24908	5736 435426	VLADIMIR ORLOV	{"email": "v_orlov_021964@postgrespro.ru", "phone": "+70062859560"}
0005432628706	B5D183	9368 197062	PETR SMIRNOV	{"phone": "+70227502394"}
0005432628707	B5D183	7255 005590	MAKSIM MAKSIMOV	{"phone": "+70000987400"}
0005432628708	031CA5	0710 792234	YULIYA TARASOVA	{"phone": "+70319795470"}
0005432628709	A3B1DB	2399 757745	ALEKSANDRA MIRONOVA	{"phone": "+70824831471"}
0005432628710	A3B1DB	6578 784685	ALEKSANDR SERGEEV	{"email": "asergeev_1976@postgrespro.ru", "phone": "+70059294937"}
0005432628711	1C1F9A	1432 792850	ANDREY PAVLOV	{"email": "pavlov.andrey.011977@postgrespro.ru", "phone": "+70652894741"}
0005432628712	217F3F	9290 078946	NATALYA AFANASEVA	{"email": "afanaseva_n-1972@postgrespro.ru", "phone": "+70073188386"}
0005432628713	217F3F	4840 335871	RUMIYA ALEKSEEVA	{"email": "r.alekseeva1976@postgrespro.ru", "phone": "+70960581018"}
0005432628714	125859	2580 150170	RUSLAN MATVEEV	{"phone": "+70130438620"}
0005432628715	2F243C	5417 602708	NADEZHDA YAKOVLEVA	{"phone": "+70997865822"}
0005432628716	129E3C	8291 023668	YULIYA PAVLOVA	{"email": "yuliyapavlova_111970@postgrespro.ru", "phone": "+70996224187"}
0005432628717	A1AA3C	2714 319946	LYUDMILA ZHURAVLEVA	{"phone": "+70304216145"}
0005432628718	A1AA3C	0009 481940	OLEG POPOV	{"phone": "+70399295175"}
0005432628719	2444F6	3385 864230	ALEKSEY SOKOLOV	{"email": "sokolovaleksey-1979@postgrespro.ru", "phone": "+70336235435"}
0005432628720	910DCA	3831 902936	GALINA OVCHINNIKOVA	{"phone": "+70254063049"}
0005432628721	7EDA5F	2532 889007	VYACHESLAV KOZLOV	{"phone": "+70961544102"}
0005432628722	A5145B	5255 320525	TAISIYA BELYAEVA	{"email": "t-belyaeva_091979@postgrespro.ru", "phone": "+70204055179"}
0005432628723	A5145B	3666 093492	RINAT KARPOV	{"phone": "+70423543748"}
0005432628724	2DB734	1737 110080	ANATOLIY KUZNECOV	{"phone": "+70641501335"}
0005432628725	438285	3021 097315	VLADIMIR FROLOV	{"email": "frolovvladimir-121962@postgrespro.ru", "phone": "+70492940544"}
0005432628726	438285	8607 642361	NATALYA SEMENOVA	{"phone": "+70839483559"}
0005432628727	6EF21B	7134 381744	TATYANA KULIKOVA	{"email": "tkulikova_1969@postgrespro.ru", "phone": "+70732461411"}
0005432628728	022AE7	2256 756316	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr_1972@postgrespro.ru", "phone": "+70573314537"}
0005432628729	022AE7	0471 960841	ALEKSANDR BORISOV	{"email": "a_borisov_06061962@postgrespro.ru", "phone": "+70926358798"}
0005432628730	1223F5	6431 564963	ANZHELIKA ALEKSEEVA	{"email": "alekseeva-anzhelika_16061960@postgrespro.ru", "phone": "+70971804344"}
0005432628731	1223F5	7943 864531	TAMARA EGOROVA	{"email": "egorova-t1970@postgrespro.ru", "phone": "+70883325333"}
0005432628732	90D920	8468 022170	ARMEN BORISOV	{"email": "aborisov_081972@postgrespro.ru", "phone": "+70379882272"}
0005432628733	90D920	0386 315799	ALEKSANDR MOROZOV	{"email": "aleksandr-morozov_1978@postgrespro.ru", "phone": "+70527990895"}
0005432628734	1D5E11	2505 435851	VYACHESLAV KONOVALOV	{"email": "konovalov-vyacheslav.1975@postgrespro.ru", "phone": "+70586762936"}
0005432628735	1D5E11	5479 510907	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey-01091973@postgrespro.ru", "phone": "+70472413076"}
0005432628736	0EFBB3	8826 016027	ROMAN GERASIMOV	{"email": "gerasimovr.14091962@postgrespro.ru", "phone": "+70767719045"}
0005432628737	569641	8254 102817	SERGEY ROMANOV	{"phone": "+70553364504"}
0005432628738	19D106	5978 412024	OLEG KUZMIN	{"phone": "+70905998482"}
0005432628739	19D106	0132 514910	ALEKSEY SAVELEV	{"email": "a-savelev061972@postgrespro.ru", "phone": "+70762678261"}
0005432628740	B74DA1	0963 455825	IRINA SMIRNOVA	{"phone": "+70763142261"}
0005432628741	010E96	5445 006152	YURIY MAKAROV	{"phone": "+70810335822"}
0005432628742	010E96	8034 400851	ELENA EFREMOVA	{"phone": "+70928772169"}
0005432628743	3FAFFB	1894 653312	DMITRIY MAKAROV	{"phone": "+70553728447"}
0005432628744	13DC10	8619 284613	RAMIL ZAKHAROV	{"phone": "+70748605089"}
0005432628745	7EC57C	8868 698039	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr-031964@postgrespro.ru", "phone": "+70898926902"}
0005432628746	7EC57C	6727 540899	ANDREY ILIN	{"phone": "+70659852155"}
0005432628747	DB6CC7	6625 646339	MAKSIM SERGEEV	{"email": "sergeevmaksim.1972@postgrespro.ru", "phone": "+70760211609"}
0005432628748	DC7E5C	6398 977919	EVGENIY KARPOV	{"email": "karpov.e031969@postgrespro.ru", "phone": "+70653772299"}
0005432628749	DC7E5C	9583 526226	IVAN KULIKOV	{"email": "kulikov_i.1982@postgrespro.ru", "phone": "+70530858725"}
0005432628750	A1AC80	7530 976674	ELIZAVETA KONOVALOVA	{"email": "elizaveta-konovalova_101975@postgrespro.ru", "phone": "+70338281030"}
0005432628751	65C0A4	7324 081980	EGOR STEPANOV	{"email": "stepanov-e.091962@postgrespro.ru", "phone": "+70126597106"}
0005432628752	07C090	9977 276682	NINA BOGDANOVA	{"phone": "+70527864084"}
0005432628753	07C090	6542 436539	ALEKSANDRA KRASNOVA	{"phone": "+70628689832"}
0005432628754	A97049	3311 542867	SERGEY ZAYCEV	{"email": "sergey.zaycev1978@postgrespro.ru", "phone": "+70224330854"}
0005432628755	7AE2B9	5589 987685	GALINA ORLOVA	{"email": "galinaorlova_1984@postgrespro.ru", "phone": "+70559772609"}
0005432628756	8B9D5D	3439 830924	ARTEM POPOV	{"phone": "+70494644580"}
0005432628757	EFFCB0	4817 448412	ALEKSANDR MAKAROV	{"phone": "+70144037061"}
0005432628758	EFFCB0	8556 532808	SEMEN DENISOV	{"email": "s.denisov-15021973@postgrespro.ru", "phone": "+70590997625"}
0005432628759	791410	1603 653069	IVAN SHEVCHENKO	{"email": "ivanshevchenko-1980@postgrespro.ru", "phone": "+70991095392"}
0005432628760	C75492	4570 829981	SVETLANA POPOVA	{"email": "popova.s_1971@postgrespro.ru", "phone": "+70135496313"}
0005432628761	F11E86	4649 716819	NIKOLAY PAVLOV	{"phone": "+70698006642"}
0005432628762	23AE89	8629 343895	ANNA NAZAROVA	{"email": "anna-nazarova-1970@postgrespro.ru", "phone": "+70317781839"}
0005432628763	CA8E19	9986 833799	NATALYA NESTEROVA	{"phone": "+70243169348"}
0005432628764	48C03E	0629 916750	MARIYA DENISOVA	{"email": "mariya_denisova.081968@postgrespro.ru", "phone": "+70389301120"}
0005432628765	48C03E	6516 205791	VALERIY ZAKHAROV	{"email": "valeriy_zakharov-1962@postgrespro.ru", "phone": "+70024416900"}
0005432628766	75EC05	6026 444674	OLGA ROMANOVA	{"phone": "+70208971281"}
0005432628767	A94DEC	4593 221608	TATYANA BELYAEVA	{"email": "tbelyaeva.13111972@postgrespro.ru", "phone": "+70387604520"}
0005432628768	D67B1B	4660 723806	NIKITA ISAEV	{"email": "n-isaev1968@postgrespro.ru", "phone": "+70454975466"}
0005432628769	A2BEF7	8468 953596	SABINA FADEEVA	{"email": "fadeeva-s-031981@postgrespro.ru", "phone": "+70494054779"}
0005432628770	8876E3	5123 195546	VALENTIN MARTYNOV	{"phone": "+70725616846"}
0005432628771	43C0BD	2391 984054	ARINA ANISIMOVA	{"phone": "+70580399585"}
0005432628772	43C0BD	2865 591622	ELIZAVETA KRASNOVA	{"email": "elizaveta.krasnova.1968@postgrespro.ru", "phone": "+70098008949"}
0005432628773	148A0C	5664 102667	VLADIMIR AFANASEV	{"email": "v_afanasev21111979@postgrespro.ru", "phone": "+70895957549"}
0005432628774	58ACB9	2067 865807	LARISA TIKHONOVA	{"email": "ltikhonova26081976@postgrespro.ru", "phone": "+70573226734"}
0005432628775	914A54	4350 701148	VIKTOR VASILEV	{"phone": "+70133887909"}
0005432628776	546B04	5110 992868	NATALYA ISAEVA	{"phone": "+70845795029"}
0005432628777	546B04	5953 928503	ALFIYA SMIRNOVA	{"email": "smirnovaa_1978@postgrespro.ru", "phone": "+70038960637"}
0005432628778	51CD57	8733 327406	ANTON SCHERBAKOV	{"email": "antonscherbakov1962@postgrespro.ru", "phone": "+70043425558"}
0005432628779	B5F8A7	3413 221456	ILYA NAZAROV	{"email": "ilya_nazarov-1959@postgrespro.ru", "phone": "+70622272762"}
0005432628780	2C47F1	7713 874423	DMITRIY KULIKOV	{"email": "dkulikov.041977@postgrespro.ru", "phone": "+70037866917"}
0005432628781	952891	2947 763921	LYUBOV ORLOVA	{"email": "orlova.l_1977@postgrespro.ru", "phone": "+70342606933"}
0005432628782	E27165	5512 462912	SERGEY SMIRNOV	{"phone": "+70496066485"}
0005432628783	E27165	2342 171265	SVETLANA AKIMOVA	{"phone": "+70958245610"}
0005432628784	44343E	1376 200443	OLGA MEDVEDEVA	{"email": "medvedeva-olga.111979@postgrespro.ru", "phone": "+70120972891"}
0005432628785	2284EC	7692 193355	VLADIMIR ALEKSANDROV	{"email": "valeksandrov_20091979@postgrespro.ru", "phone": "+70098752215"}
0005432628786	2284EC	5456 907345	VLADIMIR TIKHONOV	{"email": "tikhonovv_1966@postgrespro.ru", "phone": "+70879399474"}
0005432628787	4AADD6	6502 672438	VIKTOR KOZLOV	{"phone": "+70906078591"}
0005432628788	4AADD6	2571 966020	NINA LOGINOVA	{"email": "ninaloginova14051980@postgrespro.ru", "phone": "+70189947890"}
0005432628789	B2DA7B	2000 077605	ALEVTINA KARPOVA	{"email": "karpovaa_1979@postgrespro.ru", "phone": "+70256637971"}
0005432628790	D53F73	8200 806892	ANDREY AFANASEV	{"phone": "+70963712098"}
0005432628791	B02FC8	8046 218535	BORIS NIKITIN	{"phone": "+70147650510"}
0005432628792	2248F1	0875 732435	VYACHESLAV SOROKIN	{"email": "vyacheslavsorokin1966@postgrespro.ru", "phone": "+70771143505"}
0005432628793	2248F1	2752 721323	MIKHAIL MATVEEV	{"email": "matveev-m07071971@postgrespro.ru", "phone": "+70113264017"}
0005432628794	147227	1162 306716	VLADIMIR KUDRYASHOV	{"email": "vladimir.kudryashov1966@postgrespro.ru", "phone": "+70215096463"}
0005432628795	147227	9495 591805	SVETLANA NOVIKOVA	{"email": "novikova_svetlana-1979@postgrespro.ru", "phone": "+70318170741"}
0005432628796	A42C50	2352 428268	DIANA FROLOVA	{"email": "frolovad_111987@postgrespro.ru", "phone": "+70313000854"}
0005432628797	A42C50	1491 714666	SVETLANA ABRAMOVA	{"phone": "+70760357895"}
0005432628798	8F6911	2222 180891	VALENTINA ZHURAVLEVA	{"phone": "+70871219644"}
0005432628799	8F6911	3299 535351	VALENTIN BORISOV	{"phone": "+70576850682"}
0005432628800	8F6911	9040 882353	NATALIYA MIKHAYLOVA	{"phone": "+70132885951"}
0005432628801	BAED6E	7102 876259	ALEKSANDR GERASIMOV	{"email": "gerasimova-23091968@postgrespro.ru", "phone": "+70694485990"}
0005432628802	5DBA6B	7645 565108	ANTON NIKOLAEV	{"email": "anton_nikolaev_1981@postgrespro.ru", "phone": "+70126019030"}
0005432628803	5DBA6B	4920 499737	IGOR SOLOVEV	{"email": "igor-solovev_20121959@postgrespro.ru", "phone": "+70780088159"}
0005432628804	5DBA6B	8041 811378	MARINA SOLOVEVA	{"email": "soloveva-marina19031997@postgrespro.ru", "phone": "+70051041739"}
0005432628805	21677C	9491 638945	ALEKSANDR NAZAROV	{"phone": "+70754491272"}
0005432628806	21677C	4661 861188	ALLA SAVELEVA	{"email": "a-saveleva.1972@postgrespro.ru", "phone": "+70416856906"}
0005432628807	513B6A	5122 788533	VALENTINA ANDREEVA	{"phone": "+70331961995"}
0005432628808	7EBA6C	6297 193875	VIKTORIYA DANILOVA	{"phone": "+70505611399"}
0005432628809	7EBA6C	9912 251108	ANATOLIY TIKHONOV	{"email": "a.tikhonov-27091983@postgrespro.ru", "phone": "+70241295710"}
0005432628810	2DD6D9	0694 840606	TATYANA IVANOVA	{"phone": "+70421484520"}
0005432628811	7D5626	7618 681277	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr091984@postgrespro.ru", "phone": "+70944091484"}
0005432628812	DD432D	6244 144938	SERGEY NOVIKOV	{"email": "s.novikov.1970@postgrespro.ru", "phone": "+70300143791"}
0005432628813	DD432D	9973 010483	ALEKSANDR SCHERBAKOV	{"phone": "+70908494707"}
0005432628814	926D64	7721 115499	KIRILL POPOV	{"email": "kirill_popov041967@postgrespro.ru", "phone": "+70560111455"}
0005432628815	926D64	6287 778413	TATYANA BORISOVA	{"email": "t-borisova-02071984@postgrespro.ru", "phone": "+70727887912"}
0005432628816	926D64	1823 145706	DARYA BOGDANOVA	{"email": "bogdanova.d-23111976@postgrespro.ru", "phone": "+70378160414"}
0005432628817	0D3B95	6916 882103	SERGEY POPOV	{"phone": "+70255327605"}
0005432628818	0D3B95	9003 984023	YANA PAVLOVA	{"phone": "+70513772827"}
0005432628819	36B984	4355 051855	DARYA ANTONOVA	{"email": "darya.antonova_011984@postgrespro.ru", "phone": "+70387515860"}
0005432628820	AC6418	5757 115385	GENNADIY KISELEV	{"email": "gennadiy_kiselev_1983@postgrespro.ru", "phone": "+70026059824"}
0005432628821	AC6418	4151 912486	ANTON BORISOV	{"email": "a_borisov.06061973@postgrespro.ru", "phone": "+70475425919"}
0005432628822	EF3F89	0948 645811	SERGEY SOKOLOV	{"email": "sergey_sokolov051967@postgrespro.ru", "phone": "+70079010155"}
0005432628823	EF3F89	6276 891241	VIKTOR VOLKOV	{"email": "volkov-viktor1974@postgrespro.ru", "phone": "+70299105133"}
0005432628881	0F993D	5235 023918	ANDREY TIKHONOV	{"phone": "+70914159195"}
0005432628824	D9F270	4365 244915	VLADIMIR FROLOV	{"email": "frolov-v17091968@postgrespro.ru", "phone": "+70168070028"}
0005432628825	DFDF66	8494 940130	NIKOLAY KUZNECOV	{"email": "kuznecovn-09121965@postgrespro.ru", "phone": "+70903009566"}
0005432628826	DFDF66	2155 395793	ELENA TIKHONOVA	{"email": "elena_tikhonova-28091963@postgrespro.ru", "phone": "+70950822598"}
0005432628827	C566CA	3234 087096	EKATERINA KONDRATEVA	{"email": "e_kondrateva1964@postgrespro.ru", "phone": "+70233917974"}
0005432628828	D2EE5F	0632 768754	ALENA IVANOVA	{"phone": "+70551120691"}
0005432628829	83BA0F	1798 116483	YULIYA EGOROVA	{"phone": "+70838775254"}
0005432628830	3C17B4	2396 142955	EVGENIY DENISOV	{"email": "e.denisov21121974@postgrespro.ru", "phone": "+70082192058"}
0005432628831	6B1F6C	6727 966428	TATYANA ZHURAVLEVA	{"email": "zhuravlevat101982@postgrespro.ru", "phone": "+70743678176"}
0005432628832	6B1F6C	6305 954959	VALENTINA TIKHONOVA	{"email": "valentina_tikhonova.23041974@postgrespro.ru", "phone": "+70718393664"}
0005432628833	28A073	6963 002444	MARINA ABRAMOVA	{"email": "marina.abramova04031968@postgrespro.ru", "phone": "+70320722015"}
0005432628834	DAC4E8	6636 116926	PRASKOVYA EGOROVA	{"email": "egorova.p.101980@postgrespro.ru", "phone": "+70487512673"}
0005432628835	52C053	0847 433833	NATALIYA KOMAROVA	{"email": "komarovan.28071971@postgrespro.ru", "phone": "+70734862929"}
0005432628836	3A3650	5145 522325	ALEKSANDRA ANDREEVA	{"phone": "+70857452431"}
0005432628837	6100FD	4593 949709	IRINA VOLKOVA	{"email": "volkova.i031979@postgrespro.ru", "phone": "+70547083271"}
0005432628838	B48695	3729 999349	OLGA MIKHAYLOVA	{"email": "mikhaylova-o1969@postgrespro.ru", "phone": "+70960186075"}
0005432628839	7F2368	2283 779368	VALERIY SIDOROV	{"phone": "+70329086533"}
0005432628840	7F2368	1191 133770	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov-021974@postgrespro.ru", "phone": "+70486701863"}
0005432628841	504459	6908 685373	OLGA AFANASEVA	{"email": "olga.afanaseva091981@postgrespro.ru", "phone": "+70164215161"}
0005432628842	B449C8	3401 855014	MARIYA STEPANOVA	{"email": "m_stepanova1983@postgrespro.ru", "phone": "+70730684249"}
0005432628843	B449C8	4591 410080	ANATOLIY MAKAROV	{"phone": "+70491379860"}
0005432628844	65789A	6043 079764	ELENA VASILEVA	{"phone": "+70015903761"}
0005432628845	8127A2	3427 617396	MIKHAIL IVANOV	{"email": "m-ivanov.27051973@postgrespro.ru", "phone": "+70518600807"}
0005432628846	B32B81	0312 991332	VLADIMIR ZHUKOV	{"email": "v.zhukov_1963@postgrespro.ru", "phone": "+70122167573"}
0005432628847	1DC51A	5906 073288	ANDREY IVANOV	{"phone": "+70369234141"}
0005432628848	51581A	0842 987677	RAFIS MAKSIMOV	{"phone": "+70877128027"}
0005432628849	3BFA7C	1928 477746	EVGENIY STEPANOV	{"email": "e-stepanov1965@postgrespro.ru", "phone": "+70428369340"}
0005432628850	BF8C49	5694 056587	OLGA KULIKOVA	{"email": "okulikova.1972@postgrespro.ru", "phone": "+70375537918"}
0005432628851	58F570	6192 773528	ALEKSANDR KOZLOV	{"phone": "+70583589341"}
0005432628852	008B47	8269 660749	ELIZAVETA IVANOVA	{"phone": "+70265991261"}
0005432628853	906008	0504 883807	TATYANA AKIMOVA	{"email": "akimova-tatyana_1964@postgrespro.ru", "phone": "+70962149759"}
0005432628854	48D7AD	8046 650711	NINA SMIRNOVA	{"email": "smirnova_n.1970@postgrespro.ru", "phone": "+70602776239"}
0005432628855	259C79	1529 953486	RUSTAM KUZNECOV	{"phone": "+70900153801"}
0005432628856	8BFBDE	0484 305576	VLADIMIR TIKHONOV	{"email": "v_tikhonov_1975@postgrespro.ru", "phone": "+70123569646"}
0005432628857	548533	0056 851668	MARIYA EFREMOVA	{"email": "efremova_mariya_11111972@postgrespro.ru", "phone": "+70046156737"}
0005432628858	2C69AE	6683 357024	VYACHESLAV KULIKOV	{"phone": "+70304334245"}
0005432628859	521A1B	1543 677983	ANDREY SEMENOV	{"email": "andrey_semenov1975@postgrespro.ru", "phone": "+70201139902"}
0005432628860	22A9CC	7832 004732	IRINA MOISEEVA	{"phone": "+70032569367"}
0005432628861	7A50BE	8270 382182	VLADIMIR SMIRNOV	{"email": "smirnov-v_07021980@postgrespro.ru", "phone": "+70732444177"}
0005432628862	0F4B73	1876 898471	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov-08091982@postgrespro.ru", "phone": "+70569493248"}
0005432628863	F96E3B	2824 753241	NADEZHDA NIKIFOROVA	{"phone": "+70921746604"}
0005432628864	DF5F68	9894 400990	KIRA FADEEVA	{"email": "fadeevakira.121972@postgrespro.ru", "phone": "+70416661485"}
0005432628920	92E620	4010 986391	OLGA NESTEROVA	{"phone": "+70669506762"}
0005432628865	67E271	1044 003026	FEDOR ZAKHAROV	{"email": "fedorzakharov_111966@postgrespro.ru", "phone": "+70745212918"}
0005432628866	177F2C	1613 616355	ANTONINA AKIMOVA	{"phone": "+70648443384"}
0005432628867	ABD918	0347 215977	MATVEY GORBUNOV	{"email": "m_gorbunov.1970@postgrespro.ru", "phone": "+70698921486"}
0005432628868	ABD918	8602 877729	SERGEY STEPANOV	{"phone": "+70780881884"}
0005432628869	96417A	5151 123327	LILIYA ILINA	{"phone": "+70837398842"}
0005432628870	96417A	1628 139263	ANATOLIY SAVELEV	{"email": "savelev-a.23031969@postgrespro.ru", "phone": "+70825431404"}
0005432628871	0E5691	5242 635746	NATALYA KULIKOVA	{"phone": "+70181617385"}
0005432628872	0E5691	6375 315759	TATYANA OSIPOVA	{"email": "t-osipova_09031986@postgrespro.ru", "phone": "+70175054242"}
0005432628873	6BE892	5290 487362	OLEG TIKHONOV	{"phone": "+70327411513"}
0005432628874	A3E9E8	8844 577569	IGOR NIKITIN	{"email": "i.nikitin091978@postgrespro.ru", "phone": "+70228740448"}
0005432628875	9AD9D6	5838 489471	VLADIMIR TARASOV	{"email": "tarasov-vladimir061972@postgrespro.ru", "phone": "+70974060241"}
0005432628876	59DC39	8133 277384	PAVEL KUZNECOV	{"email": "kuznecov_p26031967@postgrespro.ru", "phone": "+70395106845"}
0005432628877	6666F3	1140 045648	NADEZHDA BORISOVA	{"phone": "+70464141425"}
0005432628878	6666F3	2013 893526	VARVARA SEMENOVA	{"email": "semenovavarvara-121980@postgrespro.ru", "phone": "+70389969334"}
0005432628879	A3F28D	2902 591616	ANATOLIY ZAKHAROV	{"phone": "+70171052113"}
0005432628880	0F993D	2351 527581	LIDIYA LEBEDEVA	{"email": "lebedeva.l31081967@postgrespro.ru", "phone": "+70427452936"}
0005432628882	51BDEE	7497 098545	GALINA AFANASEVA	{"email": "afanaseva_galina-1970@postgrespro.ru", "phone": "+70358243286"}
0005432628883	36215B	3872 903049	ARINA VOLKOVA	{"email": "arinavolkova_08091971@postgrespro.ru", "phone": "+70389105204"}
0005432628884	2BB809	8067 161197	IRINA IVANOVA	{"email": "i-ivanova_071971@postgrespro.ru", "phone": "+70410154062"}
0005432628885	2BB809	3128 797220	ANASTASIYA TIKHONOVA	{"email": "a-tikhonova.10021972@postgrespro.ru", "phone": "+70297827035"}
0005432628886	13E9D9	6417 122816	VADIM CHERNOV	{"email": "vadim-chernov10051968@postgrespro.ru", "phone": "+70009341524"}
0005432628887	13084B	5716 018715	VYACHESLAV KOZLOV	{"email": "kozlovv19041978@postgrespro.ru", "phone": "+70506057885"}
0005432628888	7AF451	7393 798491	ALEKSANDRA ALEKSEEVA	{"email": "alekseeva_aleksandra.101975@postgrespro.ru", "phone": "+70999119259"}
0005432628889	3EC2BF	2646 254837	ALEKSANDR GAVRILOV	{"email": "gavrilov.a.28051973@postgrespro.ru", "phone": "+70514760576"}
0005432628890	CE69FA	2140 421495	TATYANA FOMINA	{"phone": "+70859394592"}
0005432628891	CE69FA	1104 650518	ANDREY GERASIMOV	{"email": "gerasimovandrey.1973@postgrespro.ru", "phone": "+70404709564"}
0005432628892	3D950B	2964 076020	ALEKSANDR MOROZOV	{"email": "morozov-a_22031974@postgrespro.ru", "phone": "+70020162324"}
0005432628893	8DF22F	8267 743651	RAISA KOROLEVA	{"phone": "+70636071908"}
0005432628894	AA7AA5	3940 108402	ULYANA NIKITINA	{"phone": "+70142681465"}
0005432628895	AA7AA5	1349 131747	YULIYA MOISEEVA	{"email": "moiseevay.021979@postgrespro.ru", "phone": "+70220226329"}
0005432628896	B3B41E	6200 913188	OLGA VLASOVA	{"phone": "+70746577406"}
0005432628897	53F253	2952 492581	ALEKSEY ISAEV	{"email": "aisaev.1963@postgrespro.ru", "phone": "+70227830886"}
0005432628898	53F253	5809 884094	ALEKSEY TIMOFEEV	{"email": "timofeev_aleksey1973@postgrespro.ru", "phone": "+70407469500"}
0005432628899	F239B0	2594 056040	ALEKSANDR CHERNOV	{"email": "chernov.a.061984@postgrespro.ru", "phone": "+70761660780"}
0005432628900	F239B0	1678 929571	VALENTINA GORBUNOVA	{"phone": "+70341605509"}
0005432628901	5C5571	9098 554409	VIKTORIYA IVANOVA	{"email": "v.ivanova.071972@postgrespro.ru", "phone": "+70078017594"}
0005432628902	597DD2	1067 987591	VALERIY TIKHONOV	{"email": "tikhonov.v.14021970@postgrespro.ru", "phone": "+70566816885"}
0005432628903	597DD2	8831 498031	TATYANA SEMENOVA	{"email": "t_semenova_041964@postgrespro.ru", "phone": "+70685521317"}
0005432628904	F77B55	4540 327898	ANASTASIYA MARTYNOVA	{"phone": "+70174258142"}
0005432628905	C19094	0675 327475	VALENTINA BOGDANOVA	{"email": "bogdanova-v-101969@postgrespro.ru", "phone": "+70199348763"}
0005432628906	0E580B	1026 374582	OLGA BORISOVA	{"email": "o_borisova061961@postgrespro.ru", "phone": "+70180569413"}
0005432628907	0E580B	5854 201017	TATYANA ALEKSANDROVA	{"email": "tatyana-aleksandrova.10011977@postgrespro.ru", "phone": "+70270385705"}
0005432628908	6A472E	2895 128189	ALENA ZHURAVLEVA	{"email": "zhuravleva_alena.111983@postgrespro.ru", "phone": "+70023427587"}
0005432628909	8042C0	8869 474634	YURIY VASILEV	{"phone": "+70887588723"}
0005432628910	C52C07	6734 771693	TATYANA YAKOVLEVA	{"email": "yakovleva-tatyana_031967@postgrespro.ru", "phone": "+70532806690"}
0005432628911	E0A9DA	1822 661290	ANNA ORLOVA	{"email": "orlova-a_1963@postgrespro.ru", "phone": "+70903823554"}
0005432628912	33FC91	2178 807864	ELVIRA ILINA	{"phone": "+70507333047"}
0005432628913	C18F1E	9952 182773	OLGA ABRAMOVA	{"phone": "+70765160470"}
0005432628914	BD5750	3676 771309	NINA SMIRNOVA	{"phone": "+70701275816"}
0005432628915	BD5750	1056 427285	SERGEY DAVYDOV	{"email": "sergey_davydov_101970@postgrespro.ru", "phone": "+70203490477"}
0005432628916	5A908A	3689 564245	VALENTINA MEDVEDEVA	{"phone": "+70130160068"}
0005432628917	275497	3497 233787	YURIY SOLOVEV	{"email": "solovev_yuriy_24031968@postgrespro.ru", "phone": "+70471094151"}
0005432628918	275497	3218 406188	POLINA SOROKINA	{"email": "psorokina.14091963@postgrespro.ru", "phone": "+70122245884"}
0005432628919	92E620	1430 439854	ANTONINA PETROVA	{"email": "antonina.petrova1960@postgrespro.ru", "phone": "+70485736678"}
0005432628921	7B157E	5876 396261	IRINA NAUMOVA	{"email": "i-naumova111965@postgrespro.ru", "phone": "+70028648890"}
0005432628922	709A52	7169 343503	DIANA NIKITINA	{"phone": "+70278888050"}
0005432628923	B44A79	3186 156603	VYACHESLAV IVANOV	{"phone": "+70020520699"}
0005432628924	B44A79	4548 346406	STEPAN ROMANOV	{"phone": "+70685521668"}
0005432628925	3DA633	2754 818638	OLGA VOROBEVA	{"email": "vorobeva.o-081971@postgrespro.ru", "phone": "+70101121457"}
0005432628926	DEAADD	0206 384202	NATALYA ZAKHAROVA	{"phone": "+70782442690"}
0005432628927	DEAADD	7192 462365	DANIL ANTONOV	{"email": "danil-antonov.26101973@postgrespro.ru", "phone": "+70048249269"}
0005432628928	C95F07	7190 160042	SVETLANA KALININA	{"email": "s-kalinina-1976@postgrespro.ru", "phone": "+70101532958"}
0005432628929	C95F07	0531 535268	MARINA KARPOVA	{"email": "karpova.marina021977@postgrespro.ru", "phone": "+70813692631"}
0005432628930	B021FB	5731 149938	ELENA KAZAKOVA	{"email": "e-kazakova-1964@postgrespro.ru", "phone": "+70439745491"}
0005432628931	B021FB	8458 750482	NATALYA OSIPOVA	{"phone": "+70696342727"}
0005432628932	159295	6849 230007	EDUARD IVANOV	{"email": "eivanov24101973@postgrespro.ru", "phone": "+70838515905"}
0005432628933	2B44B3	0095 282074	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov03101963@postgrespro.ru", "phone": "+70813343884"}
0005432628934	2B44B3	9343 842707	NATALYA FADEEVA	{"email": "natalya_fadeeva-061978@postgrespro.ru", "phone": "+70156006308"}
0005432628935	F49BE9	4442 674326	SERGEY ZHUKOV	{"phone": "+70666365783"}
0005432628936	BACC76	5021 825232	VALERIY SOKOLOV	{"email": "vsokolov_07091965@postgrespro.ru", "phone": "+70623403293"}
0005432628937	BACC76	7291 204839	GERMAN ALEKSEEV	{"email": "alekseev_german_05011970@postgrespro.ru", "phone": "+70393325897"}
0005432628938	9253B9	6044 699187	DMITRIY ABRAMOV	{"phone": "+70192373186"}
0005432628939	DFB5BE	9818 644375	ANASTASIYA SEMENOVA	{"phone": "+70879589868"}
0005432628940	DFB5BE	1172 270776	DARYA RODIONOVA	{"email": "rodionova_darya_1963@postgrespro.ru", "phone": "+70470868689"}
0005432628941	D77A62	5459 936978	EGOR KONOVALOV	{"email": "konovalov-egor.1963@postgrespro.ru", "phone": "+70898308327"}
0005432628942	D77A62	1845 860464	ANNA AKIMOVA	{"phone": "+70749992185"}
0005432628943	BF7C04	4499 672632	NATALYA MAKAROVA	{"email": "makarova_natalya_1968@postgrespro.ru", "phone": "+70843195294"}
0005432628944	8AD86C	7880 257269	VALENTINA KUZNECOVA	{"phone": "+70769294756"}
0005432628945	8AD86C	3825 972016	ALBINA PAVLOVA	{"email": "a-pavlova.18061968@postgrespro.ru", "phone": "+70716248699"}
0005432628946	15ADB4	2963 862776	NINA ROMANOVA	{"email": "romanovanina.121976@postgrespro.ru", "phone": "+70559773116"}
0005432628947	F9CBF3	6034 125776	EVGENIY IVANOV	{"email": "ivanove_1970@postgrespro.ru", "phone": "+70742573605"}
0005432628948	7C5B86	0022 112644	OKSANA LUKYANOVA	{"email": "olukyanova_01071980@postgrespro.ru", "phone": "+70405327152"}
0005432628949	E6F777	2600 861496	IRINA KUDRYASHOVA	{"email": "i-kudryashova.1963@postgrespro.ru", "phone": "+70632805644"}
0005432628950	E6F777	0871 167895	EKATERINA SIDOROVA	{"email": "sidorova-e_1976@postgrespro.ru", "phone": "+70169005414"}
0005432628951	ECBD8A	4684 614703	OLGA SOKOLOVA	{"email": "sokolovao121980@postgrespro.ru", "phone": "+70300888652"}
0005432628952	31D374	1748 188260	YULIYA EFREMOVA	{"email": "efremova_yuliya-21081971@postgrespro.ru", "phone": "+70174753406"}
0005432628953	31E0F3	8853 601373	OLEG EGOROV	{"email": "egorovoleg_11101962@postgrespro.ru", "phone": "+70136384193"}
0005432628954	31E0F3	8428 814752	RODION MIRONOV	{"email": "rodion.mironov1969@postgrespro.ru", "phone": "+70631934081"}
0005432628955	7E251B	4407 707090	ANASTASIYA SEMENOVA	{"phone": "+70825427951"}
0005432628956	7E251B	4619 545241	IRINA DAVYDOVA	{"phone": "+70914023864"}
0005432628957	D36638	7842 328539	NIKOLAY IVANOV	{"email": "ivanov_nikolay.011962@postgrespro.ru", "phone": "+70998449976"}
0005432628958	CF08E5	0524 215328	LIDIYA GUSEVA	{"email": "l_guseva.06041958@postgrespro.ru", "phone": "+70734298725"}
0005432628959	816E35	8140 016101	ARINA DAVYDOVA	{"email": "davydovaarina-29081964@postgrespro.ru", "phone": "+70028567176"}
0005432628960	816E35	5978 895152	OLGA VOROBEVA	{"email": "vorobevao_1965@postgrespro.ru", "phone": "+70558785553"}
0005432628961	1C6A5C	0007 482709	ROMAN IVANOV	{"phone": "+70789983705"}
0005432628962	04FB47	9519 610682	NIKITA KRASNOV	{"phone": "+70486379886"}
0005432628963	896A5F	8413 885083	ELENA MASLOVA	{"email": "maslova-e04071972@postgrespro.ru", "phone": "+70672074559"}
0005432628964	2CFC7E	6148 241213	VLADIMIR OSIPOV	{"email": "osipov.v-111962@postgrespro.ru", "phone": "+70934650557"}
0005432628965	7007A7	3236 204480	NIKOLAY FROLOV	{"email": "nikolay_frolov-091972@postgrespro.ru", "phone": "+70626567070"}
0005432628966	AD49DB	4269 948221	SERGEY FOMIN	{"email": "fomin.sergey_121980@postgrespro.ru", "phone": "+70995004086"}
0005432628967	AD49DB	9320 975159	ALEKSANDRA ISAEVA	{"email": "isaeva-aleksandra1965@postgrespro.ru", "phone": "+70658858157"}
0005432628968	FA255E	9423 138101	OLEG DENISOV	{"email": "denisovoleg.19071964@postgrespro.ru", "phone": "+70713283036"}
0005432628969	FA255E	8464 721425	DANIL IVANOV	{"phone": "+70787023009"}
0005432628970	22C13F	8964 404198	ALEKSANDR FILIPPOV	{"phone": "+70878018084"}
0005432628971	22C13F	0116 527340	TAMARA SCHERBAKOVA	{"phone": "+70739764999"}
0005432628972	B06EFF	9425 984398	VLADIMIR AFANASEV	{"email": "v-afanasev-031974@postgrespro.ru", "phone": "+70306448769"}
0005432628973	B06EFF	0584 236425	VIKTOR KOZLOV	{"phone": "+70989804243"}
0005432628974	DB96CB	8134 818793	NATALYA TITOVA	{"email": "titovanatalya-29091983@postgrespro.ru", "phone": "+70594055569"}
0005432628975	DB96CB	5221 723558	VLADIMIR KUDRYASHOV	{"email": "vladimirkudryashov.26111988@postgrespro.ru", "phone": "+70946127248"}
0005432628976	A895A4	6758 822864	ARTEM ABRAMOV	{"phone": "+70008438372"}
0005432628977	B44665	9425 894719	INNA AFANASEVA	{"email": "innaafanaseva-101976@postgrespro.ru", "phone": "+70383667490"}
0005432628978	7B0D4A	4788 933502	ZINAIDA ZHURAVLEVA	{"email": "zzhuravleva-16071965@postgrespro.ru", "phone": "+70661576236"}
0005432628979	926A0F	6919 561389	MARIYA SEMENOVA	{"phone": "+70445348065"}
0005432628980	238A67	7585 116389	STANISLAV NIKITIN	{"email": "nikitins-30091976@postgrespro.ru", "phone": "+70924430572"}
0005432628981	C2DF52	7842 984537	IGOR SAVELEV	{"email": "savelev.i_071977@postgrespro.ru", "phone": "+70184029591"}
0005432628982	C8F55B	7906 355348	LIDIYA NIKITINA	{"phone": "+70740645163"}
0005432628983	F0A228	9711 096453	PAVEL MOISEEV	{"email": "moiseev-pavel1963@postgrespro.ru", "phone": "+70316058327"}
0005432628984	8AB2F0	6012 493266	ALENA ORLOVA	{"phone": "+70814598699"}
0005432628985	095559	1375 733842	ALEKSEY VASILEV	{"email": "vasileva081974@postgrespro.ru", "phone": "+70682472304"}
0005432628986	16F478	7750 149257	GENNADIY MATVEEV	{"email": "g-matveev06061970@postgrespro.ru", "phone": "+70081589185"}
0005432628987	16F478	3060 737127	EVGENIY SCHERBAKOV	{"email": "e-scherbakov.1970@postgrespro.ru", "phone": "+70592293499"}
0005432628988	F6251C	5831 165636	IGOR DENISOV	{"email": "denisovigor.30041963@postgrespro.ru", "phone": "+70851026823"}
0005432628989	E412E3	0951 658284	OKSANA KOROLEVA	{"phone": "+70695468504"}
0005432628990	E412E3	2147 126100	ALEKSEY MAKAROV	{"email": "makarov.aleksey-1964@postgrespro.ru", "phone": "+70438733593"}
0005432628991	5DCE01	5543 468555	LIDIYA KOZLOVA	{"phone": "+70005032189"}
0005432628992	94C924	1484 661928	DILYARA NIKOLAEVA	{"phone": "+70705830686"}
0005432628993	BAF8F6	1631 889279	ILYA KUZMIN	{"email": "kuzmin.i111953@postgrespro.ru", "phone": "+70103436828"}
0005432628994	C1694F	7319 742552	SOFIYA KONDRATEVA	{"phone": "+70158835121"}
0005432628995	C2DADC	6156 143732	EKATERINA ZHURAVLEVA	{"phone": "+70267082579"}
0005432628996	E23756	8245 107030	NINA LUKYANOVA	{"email": "ninalukyanova091981@postgrespro.ru", "phone": "+70679495966"}
0005432628997	50A1F7	0176 438100	VERA KULIKOVA	{"email": "kulikovav1975@postgrespro.ru", "phone": "+70290133546"}
0005432628998	AF4FBE	3405 932132	ALEKSANDR SMIRNOV	{"email": "smirnova_1962@postgrespro.ru", "phone": "+70719614980"}
0005432628999	BBD4C5	3346 405793	MARIYA TITOVA	{"phone": "+70715114202"}
0005432629000	B70835	6008 450811	SERGEY PETROV	{"email": "s-petrov-19021979@postgrespro.ru", "phone": "+70485258032"}
0005432629001	715F2A	8592 681936	GALINA PAVLOVA	{"phone": "+70402028760"}
0005432629002	60DF68	0385 521004	VIKTORIYA SEMENOVA	{"email": "v-semenova1982@postgrespro.ru", "phone": "+70983283545"}
0005432629003	60DF68	2162 654664	ANTON PAVLOV	{"phone": "+70450267253"}
0005432629004	925782	1418 262384	ALEKSANDR RODIONOV	{"phone": "+70742972841"}
0005432629005	925782	6738 235392	MARIYA MOROZOVA	{"phone": "+70766467944"}
0005432629006	A6EEAA	1680 622212	SERGEY SIDOROV	{"phone": "+70731009555"}
0005432629007	9EA5A4	3731 128269	ANASTASIYA POTAPOVA	{"phone": "+70645422423"}
0005432629008	9EA5A4	3141 388696	YULIYA EFIMOVA	{"phone": "+70840535286"}
0005432629009	84BD4C	4566 109075	ELENA EGOROVA	{"phone": "+70100572095"}
0005432629010	41A815	3486 526848	EVGENIYA SEMENOVA	{"phone": "+70158388437"}
0005432629011	24C5C2	3859 730242	MAKSIM IVANOV	{"email": "ivanovmaksim20051967@postgrespro.ru", "phone": "+70606762213"}
0005432629012	24C5C2	8046 170754	NIKOLAY FEDOROV	{"email": "fedorov-n_101977@postgrespro.ru", "phone": "+70367146819"}
0005432629013	20EEA9	9322 012341	EGOR KONOVALOV	{"email": "konovalove.1971@postgrespro.ru", "phone": "+70627263460"}
0005432629014	98D92A	3101 009484	GAGIK MIKHAYLOV	{"email": "g-mikhaylov_1972@postgrespro.ru", "phone": "+70203674686"}
0005432629015	98D92A	9883 345611	ZINAIDA ALEKSANDROVA	{"phone": "+70417887685"}
0005432629016	FDCA6E	1787 703380	GALINA SCHERBAKOVA	{"email": "gscherbakova081976@postgrespro.ru", "phone": "+70116856620"}
0005432629017	FDCA6E	1367 228321	ALEKSANDR TIKHONOV	{"phone": "+70234050527"}
0005432629018	812A54	0517 688438	MARINA SAVELEVA	{"email": "m-saveleva111980@postgrespro.ru", "phone": "+70995142528"}
0005432629019	FBA889	6898 679274	KSENIYA ILINA	{"phone": "+70275249196"}
0005432629020	9B5810	8459 183305	ANDREY SIDOROV	{"phone": "+70839053466"}
0005432629021	E3B410	0726 677376	NIKOLAY SAVELEV	{"email": "nsavelev_1985@postgrespro.ru", "phone": "+70330212543"}
0005432629022	E3B410	1870 631806	ALEKSANDRA SMIRNOVA	{"email": "smirnova_a_04071978@postgrespro.ru", "phone": "+70031863169"}
0005432629023	A62262	5733 152783	ROMAN NOVIKOV	{"email": "novikov-roman_28031967@postgrespro.ru", "phone": "+70085195519"}
0005432629024	A62262	3913 499547	GRIGORIY GERASIMOV	{"phone": "+70311145208"}
0005432629025	91C266	6439 748274	OLGA MOROZOVA	{"email": "morozovao-1975@postgrespro.ru", "phone": "+70864401399"}
0005432629026	0243F0	2949 687816	NIKITA KAZAKOV	{"phone": "+70139152737"}
0005432629027	BAB9E7	6968 071408	ELENA ANTONOVA	{"email": "elena_antonova051977@postgrespro.ru", "phone": "+70850604532"}
0005432629028	213181	0463 147375	RUSLAN MOISEEV	{"phone": "+70494534277"}
0005432629029	CB269A	9679 681922	ALEKSEY IVANOV	{"email": "ivanov_aleksey.1965@postgrespro.ru", "phone": "+70561995042"}
0005432629030	0C6001	9603 740304	IVAN KUZMIN	{"phone": "+70223909088"}
0005432629031	1D42B7	6599 189398	TIMUR DAVYDOV	{"email": "t-davydov-101964@postgrespro.ru", "phone": "+70614580208"}
0005432629032	3085E4	8298 139358	DMITRIY GRIGOREV	{"phone": "+70596631547"}
0005432629033	52161C	3414 936717	NINA ZOTOVA	{"email": "nina_zotova.06081973@postgrespro.ru", "phone": "+70974805011"}
0005432629034	D07DD7	6678 925124	VIKTOR NIKITIN	{"email": "v_nikitin-1972@postgrespro.ru", "phone": "+70949544435"}
0005432629035	E7C43A	1924 476222	NATALYA KUZMINA	{"phone": "+70137443135"}
0005432629036	EEC322	5880 480085	SVETLANA ZAYCEVA	{"phone": "+70978681056"}
0005432629037	EEC322	8671 099614	OLGA SAVELEVA	{"phone": "+70887562504"}
0005432629038	31680A	9078 624923	EVGENIY KOROLEV	{"phone": "+70436855729"}
0005432629039	25CEA0	9380 526683	OLGA MALYSHEVA	{"email": "malysheva_o.06041964@postgrespro.ru", "phone": "+70938012835"}
0005432629040	25CEA0	0204 538427	ELENA NOVIKOVA	{"email": "e.novikova_03051966@postgrespro.ru", "phone": "+70814457570"}
0005432629041	1D3F61	2679 387965	LIDIYA KUZNECOVA	{"email": "lidiya-kuznecova-011970@postgrespro.ru", "phone": "+70665870118"}
0005432629042	525A2B	2631 630846	SVETLANA EFIMOVA	{"phone": "+70657093587"}
0005432629043	525A2B	1911 580779	PRASKOVYA BOGDANOVA	{"phone": "+70435401373"}
0005432629044	525A2B	6051 070924	ANASTASIYA FEDOROVA	{"phone": "+70723241690"}
0005432629045	153051	7601 159414	GERMAN MOISEEV	{"email": "moiseev_german_101968@postgrespro.ru", "phone": "+70896901748"}
0005432629046	6B76A1	6560 368893	ELENA TIKHONOVA	{"phone": "+70930591315"}
0005432629047	AF474C	5027 373460	ALEKSANDR ISAEV	{"phone": "+70558073069"}
0005432629048	8F40AF	9435 396445	IGOR YAKOVLEV	{"phone": "+70844653386"}
0005432629049	7122C4	0899 740713	ANDREY TIMOFEEV	{"phone": "+70085201988"}
0005432629050	D7CE19	7400 650291	MAKSIM KUZNECOV	{"phone": "+70149173569"}
0005432629051	D7CE19	9828 933355	DANIIL SIDOROV	{"phone": "+70989540733"}
0005432629052	D7CE19	5314 589367	ANNA KOMAROVA	{"phone": "+70495980033"}
0005432629053	2A3BCE	4312 045715	ANASTASIYA YAKOVLEVA	{"email": "anastasiya_yakovleva121965@postgrespro.ru", "phone": "+70305509853"}
0005432629054	B19B3E	6329 501839	ALEKSANDR GERASIMOV	{"phone": "+70037406419"}
0005432629055	B19B3E	7434 563579	VLADISLAV MIKHAYLOV	{"email": "v-mikhaylov_09121978@postgrespro.ru", "phone": "+70195961068"}
0005432629056	BBF780	9849 171699	VASILIY ALEKSANDROV	{"email": "vasiliyaleksandrov_021981@postgrespro.ru", "phone": "+70969496544"}
0005432629057	A177F6	0774 454963	ANTONINA NIKOLAEVA	{"phone": "+70582200017"}
0005432629058	A177F6	1751 758564	VLADISLAV POPOV	{"email": "vladislav-popov.041965@postgrespro.ru", "phone": "+70678702496"}
0005432629059	38A5D0	8878 326172	PETR KRASNOV	{"phone": "+70109750635"}
0005432629060	38A5D0	2980 865601	ALEKSEY FEDOROV	{"email": "fedorov-aleksey_18041973@postgrespro.ru", "phone": "+70996209263"}
0005432629061	D3DCEC	8542 299704	VLADIMIR MOROZOV	{"phone": "+70996690137"}
0005432629062	CC82E7	2431 816939	ELENA BELOVA	{"phone": "+70197003617"}
0005432629063	CC82E7	9716 972640	NIKOLAY ISAEV	{"email": "isaev-n1975@postgrespro.ru", "phone": "+70265809103"}
0005432629064	0A2334	4431 823598	VLADIMIR KONOVALOV	{"phone": "+70726131352"}
0005432629065	0A2334	9535 452348	ANTONINA ZAKHAROVA	{"email": "antonina_zakharova1974@postgrespro.ru", "phone": "+70890807603"}
0005432629066	9BFF3A	2515 407846	NATALIYA ORLOVA	{"phone": "+70460909073"}
0005432629067	BDEE78	9753 178109	TATYANA KUZNECOVA	{"phone": "+70989237431"}
0005432629068	BDEE78	2368 283842	NATALYA YAKOVLEVA	{"phone": "+70968924831"}
0005432629069	F9888A	9763 342001	GALINA CHERNOVA	{"email": "galinachernova-1970@postgrespro.ru", "phone": "+70468738363"}
0005432629070	845B13	6166 581368	ANATOLIY VASILEV	{"email": "vasilev_anatoliy.03101989@postgrespro.ru", "phone": "+70056164895"}
0005432629071	48670A	3210 395720	MIKHAIL NAZAROV	{"phone": "+70419210895"}
0005432629072	F1D182	5976 896286	MILANA MELNIKOVA	{"email": "melnikova_milana1984@postgrespro.ru", "phone": "+70902880295"}
0005432629073	F1D182	8960 949915	VALENTINA MALYSHEVA	{"phone": "+70098181510"}
0005432629074	29DB24	2671 549044	IRINA ANDREEVA	{"phone": "+70453664165"}
0005432629075	6A3E2A	3070 670753	IVAN KAZAKOV	{"phone": "+70378739886"}
0005432629076	6A3E2A	2493 379974	MARIYA GERASIMOVA	{"email": "gerasimova.mariya061979@postgrespro.ru", "phone": "+70104774408"}
0005432629077	5C3168	9072 383640	DENIS CHERNOV	{"email": "d_chernov_20021967@postgrespro.ru", "phone": "+70039387251"}
0005432629078	6B5F60	2879 284327	SERGEY PAVLOV	{"email": "s-pavlov09081969@postgrespro.ru", "phone": "+70039274586"}
0005432629079	6B5F60	6352 324845	YURIY KUZMIN	{"email": "kuzmin-yuriy.03111965@postgrespro.ru", "phone": "+70415204729"}
0005432629080	939387	1850 509199	OLGA PETROVA	{"phone": "+70201526415"}
0005432629081	E6A43B	7869 997247	VALERIY MAKSIMOV	{"email": "maksimov_valeriy.1979@postgrespro.ru", "phone": "+70303119233"}
0005432629082	E6A43B	8020 232021	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_1975@postgrespro.ru", "phone": "+70950394892"}
0005432629083	2B31D2	1038 446153	IVAN MELNIKOV	{"email": "ivan_melnikov_24081974@postgrespro.ru", "phone": "+70397260809"}
0005432629084	717612	8077 592401	YURIY DAVYDOV	{"email": "davydov.yuriy-1970@postgrespro.ru", "phone": "+70531850433"}
0005432629085	07A299	8599 133286	SEMEN VLASOV	{"email": "svlasov.061972@postgrespro.ru", "phone": "+70024532323"}
0005432629086	07A299	8888 322321	VALENTINA BORISOVA	{"email": "borisova.valentina-011979@postgrespro.ru", "phone": "+70512650888"}
0005432629087	66E92E	3295 203991	ANDREY ZAKHAROV	{"phone": "+70663874150"}
0005432629088	43336D	0181 363877	PETR ZHURAVLEV	{"email": "p-zhuravlev-031971@postgrespro.ru", "phone": "+70044221145"}
0005432629089	6C6E88	3220 618624	YURIY NIKOLAEV	{"email": "nikolaevy_071966@postgrespro.ru", "phone": "+70793351201"}
0005432629090	48E3F5	2821 744979	DAVID GRIGOREV	{"phone": "+70754649278"}
0005432629091	48E3F5	5628 429343	TATYANA SOLOVEVA	{"phone": "+70813278610"}
0005432629092	DEE4ED	2860 911335	VALERIY NIKOLAEV	{"email": "nikolaev-valeriy.21081976@postgrespro.ru", "phone": "+70159905582"}
0005432629093	6BECD0	4310 346282	VIKTORIYA KUZNECOVA	{"phone": "+70337286319"}
0005432629094	6BECD0	9638 902291	LARISA ZAYCEVA	{"phone": "+70375070178"}
0005432629095	A51A7A	6544 203004	KHASAN IVANOV	{"phone": "+70522442627"}
0005432629096	A51A7A	2851 847931	TAMARA SIDOROVA	{"phone": "+70416115813"}
0005432629097	70C5F0	3329 136535	ALEKSEY YAKOVLEV	{"phone": "+70266650984"}
0005432629098	70C5F0	7253 349581	LYUBOV NAZAROVA	{"email": "nazarovalyubov.1979@postgrespro.ru", "phone": "+70620127246"}
0005432629099	723DA4	7744 410575	DMITRIY KARPOV	{"email": "d.karpov27041985@postgrespro.ru", "phone": "+70973661450"}
0005432629100	8D44A1	1868 612372	VERA ZAKHAROVA	{"email": "v.zakharova_051980@postgrespro.ru", "phone": "+70500139404"}
0005432629101	07AE10	7191 069301	ALEKSANDR KUZNECOV	{"phone": "+70246983445"}
0005432629102	07AE10	3007 440253	NATALYA POTAPOVA	{"email": "potapova-n.091976@postgrespro.ru", "phone": "+70827880081"}
0005432629103	6E4F01	2098 244944	NATALYA MAKAROVA	{"email": "n_makarova1968@postgrespro.ru", "phone": "+70433491634"}
0005432629104	76DBC6	9314 253130	PETR SHEVCHENKO	{"email": "shevchenko.petr-09091969@postgrespro.ru", "phone": "+70959854690"}
0005432629105	32F894	8044 154173	SVETLANA FILIPPOVA	{"phone": "+70941512988"}
0005432629106	DCB3EB	5722 288765	VALENTIN GERASIMOV	{"phone": "+70459449275"}
0005432629107	DCB3EB	0619 380990	IRINA MIRONOVA	{"email": "irina-mironova041974@postgrespro.ru", "phone": "+70514565064"}
0005432629108	DCB3EB	6808 842107	VLADIMIR MIRONOV	{"phone": "+70958848624"}
0005432629109	DCB3EB	8187 316612	DAMIR ISAEV	{"phone": "+70821310925"}
0005432629110	BB0948	8439 123365	KRISTINA ZAYCEVA	{"email": "kristina_zayceva-101972@postgrespro.ru", "phone": "+70716583066"}
0005432629111	052F41	4341 349833	TAMARA IVANOVA	{"phone": "+70762278219"}
0005432629112	95C7AA	8673 072611	NADEZHDA MIRONOVA	{"email": "nadezhdamironova.101979@postgrespro.ru", "phone": "+70046998640"}
0005432629113	CC58B0	8513 704199	EVGENIY SEMENOV	{"phone": "+70228283224"}
0005432629114	9DF4B2	2941 483629	DMITRIY MAKAROV	{"email": "makarov-d.25041969@postgrespro.ru", "phone": "+70990163261"}
0005432629115	9DF4B2	6613 830355	NADEZHDA KRASNOVA	{"email": "krasnova-n.07011969@postgrespro.ru", "phone": "+70001908109"}
0005432629116	9DF4B2	1394 983059	ILDAR BORISOV	{"phone": "+70912990711"}
0005432629117	5EFD5C	8838 928998	VERA LOGINOVA	{"email": "vloginova.1978@postgrespro.ru", "phone": "+70463797414"}
0005432629118	AE64AF	8431 900162	ALEKSANDR FOMIN	{"email": "afomin_011967@postgrespro.ru", "phone": "+70990537397"}
0005432629119	48D275	7977 850467	VLADIMIR ANTONOV	{"phone": "+70962430458"}
0005432629120	C53C76	4899 571761	GALINA NAUMOVA	{"email": "g-naumova_051977@postgrespro.ru", "phone": "+70866624194"}
0005432629121	8DF391	7815 013657	KARINA SERGEEVA	{"email": "sergeevak09031971@postgrespro.ru", "phone": "+70097017472"}
0005432629122	8DF391	8868 634302	ALEKSANDR AFANASEV	{"phone": "+70148637030"}
0005432629123	369906	8362 760878	ZOYA NIKOLAEVA	{"email": "zoyanikolaeva.111979@postgrespro.ru", "phone": "+70477952563"}
0005432629124	0B1297	0759 675511	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir061978@postgrespro.ru", "phone": "+70676492784"}
0005432629125	08D862	5522 418799	ALEKSANDR SEMENOV	{"email": "semenov.a1963@postgrespro.ru", "phone": "+70584237909"}
0005432629126	7C9B54	3777 191567	VLADIMIR ANDREEV	{"email": "vladimir-andreev-05091971@postgrespro.ru", "phone": "+70114271845"}
0005432629127	9BAB9C	1387 046087	SOFYA KUZMINA	{"email": "sofya.kuzmina-1979@postgrespro.ru", "phone": "+70866432098"}
0005432629128	FDFD7A	1202 685540	ILYA FROLOV	{"email": "ilya-frolov_091983@postgrespro.ru", "phone": "+70355659597"}
0005432629129	5100F0	5355 412522	MARIYA DENISOVA	{"phone": "+70448332427"}
0005432629130	F256BC	2692 547721	MIKHAIL MATVEEV	{"phone": "+70877030952"}
0005432629131	F256BC	0007 781047	ANTON ROMANOV	{"phone": "+70365848686"}
0005432629132	2CBF10	1042 294875	ARMEN KUZMIN	{"email": "kuzminarmen1975@postgrespro.ru", "phone": "+70585504505"}
0005432629133	2CBF10	5783 897106	OLGA SIDOROVA	{"phone": "+70313129787"}
0005432629134	2CBF10	2818 961561	NATALIYA NIKIFOROVA	{"email": "nataliyanikiforova.1972@postgrespro.ru", "phone": "+70206267706"}
0005432629135	CDA05F	3195 113554	VASILIY BORISOV	{"phone": "+70702364906"}
0005432629136	488182	7729 620866	ELENA ALEKSEEVA	{"email": "elenaalekseeva_1964@postgrespro.ru", "phone": "+70589382299"}
0005432629137	33D61A	5225 908320	VIKTOR GAVRILOV	{"email": "gavrilov-v_1968@postgrespro.ru", "phone": "+70243360424"}
0005432629138	33D61A	1012 215872	ZINAIDA DAVYDOVA	{"email": "davydovaz-04081961@postgrespro.ru", "phone": "+70079397461"}
0005432629139	C8B617	1442 210432	NATALYA VOROBEVA	{"phone": "+70988516891"}
0005432629140	DD4167	4533 973534	YURIY TARASOV	{"phone": "+70039568684"}
0005432629141	614F6E	3079 776368	TATYANA ROMANOVA	{"email": "romanovat.1970@postgrespro.ru", "phone": "+70949692919"}
0005432629142	6ED47B	9435 223104	VALERIYA ROMANOVA	{"phone": "+70356947101"}
0005432629143	A40202	5433 248208	NATALYA ZHURAVLEVA	{"phone": "+70184480990"}
0005432629144	72CC64	8174 120841	LYUDMILA IVANOVA	{"phone": "+70857157681"}
0005432629145	72CC64	0481 609980	ALEKSEY KAZAKOV	{"email": "kazakov_aleksey121966@postgrespro.ru", "phone": "+70660505637"}
0005432629146	3B9CE1	9722 010345	VERA VOLKOVA	{"email": "vera-volkova.26011974@postgrespro.ru", "phone": "+70605415227"}
0005432629147	0ADCB0	3222 425851	MARIYA KUZMINA	{"email": "m_kuzmina_1976@postgrespro.ru", "phone": "+70156261246"}
0005432629148	0ADCB0	7467 649957	EKATERINA MOROZOVA	{"phone": "+70564806719"}
0005432629149	509326	5722 685024	MARIYA NAZAROVA	{"email": "nazarova-m1967@postgrespro.ru", "phone": "+70588270375"}
0005432629150	509326	9713 958649	ALBINA ZAKHAROVA	{"phone": "+70937961433"}
0005432629151	74A5C3	6242 381147	MIKHAIL ISAEV	{"email": "m_isaev091974@postgrespro.ru", "phone": "+70200688134"}
0005432629152	74A5C3	4787 969314	TATYANA ALEKSEEVA	{"email": "alekseevatatyana06091976@postgrespro.ru", "phone": "+70748111376"}
0005432629153	3BE794	5179 182985	NATALYA ILINA	{"phone": "+70559715830"}
0005432629154	3BE794	0641 453642	SVETLANA MASLOVA	{"phone": "+70965909688"}
0005432629155	B1FF53	0789 894172	NATALIYA BOGDANOVA	{"phone": "+70214725733"}
0005432629156	10184E	0722 966534	NIKITA PETROV	{"phone": "+70617211146"}
0005432629157	18EDEF	7043 714456	YURIY GAVRILOV	{"phone": "+70185268264"}
0005432629158	C5827D	1034 038139	OLGA GRISHINA	{"email": "olga-grishina-121958@postgrespro.ru", "phone": "+70165942917"}
0005432629159	F71946	2642 795189	KSENIYA SEMENOVA	{"email": "k-semenova-091971@postgrespro.ru", "phone": "+70547808823"}
0005432629160	C675B9	2044 136141	IRINA KOLESNIKOVA	{"email": "irinakolesnikova031971@postgrespro.ru", "phone": "+70787509123"}
0005432629161	B694B9	7793 893574	SVETLANA IVANOVA	{"email": "s-ivanova.18011978@postgrespro.ru", "phone": "+70929697408"}
0005432629162	A82A48	5725 687865	LIDIYA NIKOLAEVA	{"email": "lidiyanikolaeva15071966@postgrespro.ru", "phone": "+70480973736"}
0005432629163	A82A48	8447 954998	ALEFTINA VASILEVA	{"phone": "+70179474991"}
0005432629164	FA745E	0942 049320	LYUBOV POPOVA	{"email": "lyubov.popova1972@postgrespro.ru", "phone": "+70734786401"}
0005432629165	92075B	9447 556261	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov-1969@postgrespro.ru", "phone": "+70687363589"}
0005432629166	92075B	0311 466597	SERGEY BONDARENKO	{"email": "s-bondarenko_061988@postgrespro.ru", "phone": "+70936362324"}
0005432629167	723CE9	5145 673740	MARIYA KUZNECOVA	{"email": "m_kuznecova-1970@postgrespro.ru", "phone": "+70765464274"}
0005432629168	1A24A9	7761 808870	NIKITA SHEVCHENKO	{"phone": "+70771427642"}
0005432629169	1A24A9	3708 802414	TATYANA AKIMOVA	{"email": "akimova.t.20051964@postgrespro.ru", "phone": "+70776192243"}
0005432629170	D7DD21	9732 082726	VALERIY SMIRNOV	{"email": "vsmirnov.1976@postgrespro.ru", "phone": "+70427023430"}
0005432629171	25B592	7915 103491	VLADIMIR BELOV	{"phone": "+70539656652"}
0005432629172	25B592	5402 019357	ANATOLIY BONDARENKO	{"email": "anatoliybondarenko.1968@postgrespro.ru", "phone": "+70310758521"}
0005432629173	C79A36	2421 344689	ARTEM MEDVEDEV	{"email": "artemmedvedev1967@postgrespro.ru", "phone": "+70603639286"}
0005432629174	C79A36	6016 989217	VALENTINA NAZAROVA	{"email": "nazarova.v1967@postgrespro.ru", "phone": "+70440633582"}
0005432629175	AD01C7	4665 641255	IRINA ANISIMOVA	{"email": "ianisimova-041984@postgrespro.ru", "phone": "+70392536030"}
0005432629176	AD01C7	2666 100842	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov09081963@postgrespro.ru", "phone": "+70492476205"}
0005432629177	89B3F3	2599 997649	RAISA EFREMOVA	{"email": "efremova.raisa-021969@postgrespro.ru", "phone": "+70535922779"}
0005432629178	3C2B9C	8565 149247	ANATOLIY NIKITIN	{"email": "nikitinanatoliy.20091971@postgrespro.ru", "phone": "+70888941276"}
0005432629179	3C2B9C	2682 906080	LARISA ZHUKOVA	{"phone": "+70674879540"}
0005432629180	7BAFBF	3018 105744	MATVEY POPOV	{"email": "popov.matvey-27011975@postgrespro.ru", "phone": "+70497428683"}
0005432629181	BDC858	9877 965314	KIRILL GAVRILOV	{"email": "k_gavrilov-1975@postgrespro.ru", "phone": "+70883563020"}
0005432629182	BDC858	1740 238259	MARGARITA KRASNOVA	{"email": "krasnova_m_19011976@postgrespro.ru", "phone": "+70936019486"}
0005432629183	D50F69	3384 798809	ALEKSEY IVANOV	{"phone": "+70816085489"}
0005432629184	A8B618	9514 785100	TATYANA ZAYCEVA	{"email": "tzayceva1974@postgrespro.ru", "phone": "+70754135885"}
0005432629185	DE97C1	7781 581925	EKATERINA POPOVA	{"phone": "+70012237967"}
0005432629186	5CBC87	0167 832699	KLAVDIYA KONDRATEVA	{"email": "k.kondrateva_22111965@postgrespro.ru", "phone": "+70243414389"}
0005432629187	1D7326	3962 010272	ANDREY POPOV	{"email": "a_popov061973@postgrespro.ru", "phone": "+70079574576"}
0005432629188	5A1D51	5943 686003	KONSTANTIN GAVRILOV	{"phone": "+70663922767"}
0005432629189	5A1D51	1350 899372	LYUDMILA ARKHIPOVA	{"email": "l.arkhipova_1971@postgrespro.ru", "phone": "+70171773605"}
0005432629190	CFDF5A	6433 720763	VALENTINA IVANOVA	{"email": "ivanovavalentina1977@postgrespro.ru", "phone": "+70329927930"}
0005432629191	CFDF5A	6793 009225	SERAFIMA MIKHAYLOVA	{"email": "mikhaylovaserafima-1971@postgrespro.ru", "phone": "+70037704249"}
0005432629192	9C10EE	5073 720533	LYUDMILA YAKOVLEVA	{"phone": "+70078908580"}
0005432629193	41F97D	0068 642968	VALERIY SOKOLOV	{"email": "valeriy_sokolov-1963@postgrespro.ru", "phone": "+70512253110"}
0005432629194	87B280	3736 560308	DMITRIY NIKITIN	{"email": "dmitriy-nikitin.011973@postgrespro.ru", "phone": "+70450149193"}
0005432629195	38268C	0882 910458	GALINA PAVLOVA	{"email": "pavlovagalina.041979@postgrespro.ru", "phone": "+70901493481"}
0005432629196	059A29	5152 309533	OLGA ANTONOVA	{"email": "o_antonova.051962@postgrespro.ru", "phone": "+70932859728"}
0005432629197	3D6D5D	0636 219235	TATYANA TIMOFEEVA	{"email": "timofeevat_11051962@postgrespro.ru", "phone": "+70420343403"}
0005432629198	3D6D5D	1056 793275	VALENTIN EGOROV	{"phone": "+70946242864"}
0005432629199	6AAED2	3683 195484	ELENA POLYAKOVA	{"email": "epolyakova-07021977@postgrespro.ru", "phone": "+70919795033"}
0005432629200	C53405	5959 019677	DANILA ANDREEV	{"email": "andreevdanila.021980@postgrespro.ru", "phone": "+70356923306"}
0005432629201	412486	6769 524038	ANASTASIYA BORISOVA	{"phone": "+70153378709"}
0005432629202	4ADF2A	8434 523678	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila-01091973@postgrespro.ru", "phone": "+70998997926"}
0005432629203	ACC073	8657 665587	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr-31101962@postgrespro.ru", "phone": "+70620452495"}
0005432629204	EC15ED	3046 865286	EKATERINA TIKHONOVA	{"email": "tikhonova-e.111970@postgrespro.ru", "phone": "+70024895862"}
0005432629205	8CFA8F	9605 854018	DARYA ORLOVA	{"email": "orlovadarya02051976@postgrespro.ru", "phone": "+70381171691"}
0005432629206	E6834D	4051 988569	ZINAIDA DENISOVA	{"email": "denisova_zinaida.24091974@postgrespro.ru", "phone": "+70974722557"}
0005432629207	B40228	0244 603536	EKATERINA PETROVA	{"phone": "+70648971222"}
0005432629208	D6DC52	0304 887483	GALINA TARASOVA	{"email": "tarasovag1982@postgrespro.ru", "phone": "+70403879145"}
0005432629209	4B2A94	9501 765397	VIKTOR MAKSIMOV	{"phone": "+70416767538"}
0005432629210	11981C	3972 241563	ELENA KOMAROVA	{"email": "elena_komarova-121982@postgrespro.ru", "phone": "+70835867480"}
0005432629211	7645CE	4831 605374	OKSANA IVANOVA	{"email": "oksana-ivanova_1969@postgrespro.ru", "phone": "+70319804844"}
0005432629212	7645CE	5020 093609	MARIYA ALEKSANDROVA	{"email": "aleksandrova.mariya.03041975@postgrespro.ru", "phone": "+70889808359"}
0005432629213	DEBD5E	7435 693058	IDA KUDRYASHOVA	{"email": "i-kudryashova-03051978@postgrespro.ru", "phone": "+70294861916"}
0005432629214	E4866E	9825 882789	IRINA MAKAROVA	{"email": "makarova.i.1963@postgrespro.ru", "phone": "+70991809361"}
0005432629215	9ADA8C	0455 763402	ANATOLIY SERGEEV	{"phone": "+70016824281"}
0005432629216	9ADA8C	7817 671026	SVETLANA VOLKOVA	{"email": "s_volkova-04031979@postgrespro.ru", "phone": "+70651011990"}
0005432629217	8A1277	4099 195846	VERA PAVLOVA	{"phone": "+70313622928"}
0005432629218	D72927	3895 816222	SERGEY MOROZOV	{"email": "sergey-morozov.071984@postgrespro.ru", "phone": "+70040391150"}
0005432629219	F59084	8090 104403	ANDREY SIDOROV	{"email": "a-sidorov_091969@postgrespro.ru", "phone": "+70258386476"}
0005432629220	437671	1991 595001	LYUDMILA GRISHINA	{"phone": "+70205850691"}
0005432629221	437671	5883 189666	VASILIY KAZAKOV	{"email": "v.kazakov.081968@postgrespro.ru", "phone": "+70263006614"}
0005432629222	32674E	3276 521374	LYUDMILA KOZLOVA	{"email": "lyudmila_kozlova11071970@postgrespro.ru", "phone": "+70360418071"}
0005432629223	3CB85C	7708 066484	PAVEL ROMANOV	{"email": "romanovp121972@postgrespro.ru", "phone": "+70188729353"}
0005432629224	3CB85C	8761 647575	IRINA KOROLEVA	{"email": "irina-koroleva_1977@postgrespro.ru", "phone": "+70409878256"}
0005432629225	3CB85C	3543 555780	VALENTIN GORBUNOV	{"email": "v_gorbunov-091970@postgrespro.ru", "phone": "+70578799173"}
0005432629226	1E8986	0693 219905	NATALYA GORBUNOVA	{"phone": "+70316619878"}
0005432629227	C7E961	0714 862916	TATYANA KUZNECOVA	{"phone": "+70576793964"}
0005432629228	5B02F1	5529 823348	ALEKSANDRA MAKAROVA	{"phone": "+70157008269"}
0005432629229	F8691E	6941 838358	ALEKSANDR MELNIKOV	{"phone": "+70570653671"}
0005432629230	F8691E	7501 535630	LEONID PETROV	{"phone": "+70281624180"}
0005432629231	FF53A5	2993 442107	TIMOFEY CHERNOV	{"phone": "+70315993008"}
0005432629232	FF53A5	7778 859559	ELENA KUZNECOVA	{"email": "kuznecova_e.27021973@postgrespro.ru", "phone": "+70236225538"}
0005432629233	EA2C30	0187 233145	VALERIYA ROMANOVA	{"phone": "+70622746993"}
0005432629234	B1F7EF	3452 263697	VLADIMIR IVANOV	{"phone": "+70092483036"}
0005432629235	B1F7EF	8193 392604	MATVEY KAZAKOV	{"phone": "+70551525256"}
0005432629236	B1F7EF	7902 570491	SERGEY SIDOROV	{"phone": "+70554625633"}
0005432629237	FC5002	1076 569903	ZULFIYA PAVLOVA	{"email": "pavlovazulfiya.10081966@postgrespro.ru", "phone": "+70221256881"}
0005432629238	FC5002	4238 056439	EVDOKIYA ERMAKOVA	{"email": "ermakova.e_02061971@postgrespro.ru", "phone": "+70196270870"}
0005432629239	6F4309	9982 210849	OLGA VASILEVA	{"email": "vasileva_olga-051982@postgrespro.ru", "phone": "+70100879251"}
0005432629240	931688	2151 663540	EKATERINA SOROKINA	{"email": "e-sorokina_031979@postgrespro.ru", "phone": "+70236987517"}
0005432629241	931688	1849 044229	NATALYA AKIMOVA	{"phone": "+70048892089"}
0005432629242	9E1719	2842 817886	VLADISLAV KOZLOV	{"phone": "+70223870685"}
0005432629243	497924	3235 225722	VALENTINA KUZMINA	{"email": "kuzmina-v-031985@postgrespro.ru", "phone": "+70891015706"}
0005432629244	4F17EA	0374 628851	ANASTASIYA NIKITINA	{"email": "anastasiya_nikitina.091968@postgrespro.ru", "phone": "+70920141468"}
0005432629245	4F17EA	9293 747211	VIKTOR ZAKHAROV	{"phone": "+70423855284"}
0005432629246	8B1F52	7982 944837	GULSHAT KUZNECOVA	{"email": "g-kuznecova15021983@postgrespro.ru", "phone": "+70453214066"}
0005432629247	921D8C	5362 739810	ANNA ILINA	{"phone": "+70037200885"}
0005432629248	ED062C	2151 219583	VYACHESLAV POPOV	{"email": "popovv011973@postgrespro.ru", "phone": "+70208663246"}
0005432629249	B1796B	8658 293640	MARINA NAUMOVA	{"email": "marinanaumova22061977@postgrespro.ru", "phone": "+70753646883"}
0005432629250	B1796B	5401 400003	SVETLANA CHERNOVA	{"email": "svetlana-chernova.23071978@postgrespro.ru", "phone": "+70788765764"}
0005432629251	33FC95	2098 982762	LYUDMILA KOVALEVA	{"email": "lyudmila.kovaleva_25021977@postgrespro.ru", "phone": "+70326704945"}
0005432629252	E73B42	6133 575253	STEPAN BONDARENKO	{"email": "sbondarenko_1977@postgrespro.ru", "phone": "+70619425531"}
0005432629253	E73B42	2265 122435	DARYA FOMINA	{"email": "fomina_d_1973@postgrespro.ru", "phone": "+70181856225"}
0005432629254	E73B42	6982 339677	VLADIMIR ZHURAVLEV	{"phone": "+70533595737"}
0005432629255	8ED758	1742 563159	NADEZHDA POPOVA	{"email": "npopova09011979@postgrespro.ru", "phone": "+70226342205"}
0005432629256	6EE0C3	8794 781287	VADIM MIRONOV	{"phone": "+70197549010"}
0005432629257	55C30A	0016 045578	ALEKSEY STEPANOV	{"phone": "+70952481419"}
0005432629258	9BC40B	6211 078861	ZOYA EGOROVA	{"email": "zoya.egorova031965@postgrespro.ru", "phone": "+70134627814"}
0005432629259	239A95	3577 144279	SERGEY MOISEEV	{"phone": "+70288513880"}
0005432629260	FA2223	4116 787308	TAGIR SHEVCHENKO	{"email": "t-shevchenko24041977@postgrespro.ru", "phone": "+70479393275"}
0005432629261	FA2223	0503 655550	ELENA BARANOVA	{"phone": "+70607076676"}
0005432629262	FA2223	7885 517713	MILANA KONOVALOVA	{"email": "milana.konovalova-081953@postgrespro.ru", "phone": "+70739722950"}
0005432629263	BB15B6	6332 778331	DENIS ROMANOV	{"email": "dromanov-1975@postgrespro.ru", "phone": "+70129685974"}
0005432629264	BCA3C2	4905 833770	ALEKSEY IVANOV	{"phone": "+70814942961"}
0005432629265	F47FC6	8848 104007	LYUBOV ANTONOVA	{"phone": "+70597032838"}
0005432629266	F47FC6	7967 988162	BORIS KUDRYASHOV	{"phone": "+70896359789"}
0005432629267	EE17BE	5171 330492	MIKHAIL FEDOTOV	{"phone": "+70832768828"}
0005432629268	EE17BE	1592 294624	ALEKSANDR SCHERBAKOV	{"phone": "+70338521257"}
0005432629269	EE17BE	1082 681532	YULIYA POLYAKOVA	{"email": "polyakova-yuliya_1980@postgrespro.ru", "phone": "+70051879551"}
0005432629270	2DA431	4729 605797	NIKOLAY NAUMOV	{"email": "n.naumov.15061966@postgrespro.ru", "phone": "+70971078709"}
0005432629271	6F97F8	6527 686700	IRINA DMITRIEVA	{"phone": "+70577250029"}
0005432629272	32B491	5254 062692	ALEKSEY SERGEEV	{"phone": "+70342409697"}
0005432629273	32B491	5833 995097	ERIK STEPANOV	{"phone": "+70065349610"}
0005432629274	58AE4C	6353 413565	ALEKSANDRA PETROVA	{"email": "a_petrova.021972@postgrespro.ru", "phone": "+70768508695"}
0005432629275	384FA7	4447 691255	ALEKSEY OSIPOV	{"email": "aosipov.26011970@postgrespro.ru", "phone": "+70692691196"}
0005432629276	5AC04D	6128 542164	OLEG SEMENOV	{"email": "o_semenov111971@postgrespro.ru", "phone": "+70900901749"}
0005432629277	5AC04D	0143 769945	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev_01101966@postgrespro.ru", "phone": "+70324536884"}
0005432629278	D24598	5537 401421	IRINA DMITRIEVA	{"email": "irina-dmitrieva-031975@postgrespro.ru", "phone": "+70785615008"}
0005432629279	AD3559	2857 721477	MARGARITA YAKOVLEVA	{"email": "yakovleva-m_121969@postgrespro.ru", "phone": "+70571212214"}
0005432629280	AD3559	9014 603614	VALENTIN SOROKIN	{"phone": "+70496640593"}
0005432629281	A7A6FA	7507 638383	NATALYA MELNIKOVA	{"phone": "+70511667609"}
0005432629282	00C4CA	5619 318660	LYUDMILA KUZNECOVA	{"email": "l.kuznecova_1969@postgrespro.ru", "phone": "+70806998857"}
0005432629283	00C4CA	1790 609074	VIKTOR PETROV	{"phone": "+70469506810"}
0005432629284	17B43E	9779 591048	YURIY SEMENOV	{"phone": "+70197564695"}
0005432629285	73229B	6813 489319	NINA KUZMINA	{"phone": "+70393218941"}
0005432629286	3F74DC	5334 456780	EKATERINA ZAYCEVA	{"phone": "+70279577696"}
0005432629287	4A92CB	4423 432366	GENNADIY KUZMIN	{"email": "kuzmin.gennadiy.12101960@postgrespro.ru", "phone": "+70454079058"}
0005432629288	395531	0469 310491	DENIS NOVIKOV	{"email": "d-novikov-1978@postgrespro.ru", "phone": "+70726408860"}
0005432629289	3AB221	4506 496556	VLADIMIR MOROZOV	{"phone": "+70147518048"}
0005432629290	3AB221	7150 604369	LYUBOV DMITRIEVA	{"email": "dmitrieva_lyubov1980@postgrespro.ru", "phone": "+70050057735"}
0005432629291	3AB221	4786 208293	DARINA DANILOVA	{"phone": "+70493660801"}
0005432629292	16B04A	1741 279168	DMITRIY VASILEV	{"phone": "+70018393575"}
0005432629293	16B04A	5888 985985	LYUBOV KUZNECOVA	{"email": "lkuznecova-19101977@postgrespro.ru", "phone": "+70947094361"}
0005432629294	D6ABBE	1412 384629	YULIYA TARASOVA	{"phone": "+70522507958"}
0005432629295	5A9C0D	3340 260180	ELENA GUSEVA	{"phone": "+70558193208"}
0005432629296	546954	7336 089145	ILYA PETROV	{"phone": "+70120889663"}
0005432632620	A3EF75	0204 586375	VASILIY STEPANOV	{"email": "stepanov-v-121974@postgrespro.ru", "phone": "+70846342972"}
0005432632621	530F63	3322 170566	VITALIY ABRAMOV	{"phone": "+70182706642"}
0005432632622	530F63	3756 269490	OKSANA NAZAROVA	{"phone": "+70502690586"}
0005432632623	690F2E	5673 564165	ANZHELA BORISOVA	{"email": "anzhelaborisova-1972@postgrespro.ru", "phone": "+70113816170"}
0005432632624	385CEE	7890 996871	NATALYA DENISOVA	{"phone": "+70467823596"}
0005432632625	D26795	4276 359681	ANDREY TARASOV	{"email": "tarasova-061973@postgrespro.ru", "phone": "+70667634226"}
0005432632626	D26795	0714 777399	YURIY SMIRNOV	{"phone": "+70618590635"}
0005432632627	05BB6C	6144 254488	ANASTASIYA SOLOVEVA	{"email": "anastasiya.soloveva.1968@postgrespro.ru", "phone": "+70704616766"}
0005432632628	0A24FA	2463 792001	GALINA FEDOROVA	{"phone": "+70933070090"}
0005432632629	4A9276	5498 858244	VASILIY VASILEV	{"email": "vasilev_v_1969@postgrespro.ru", "phone": "+70395106485"}
0005432632630	A37640	2150 033448	NATALYA BARANOVA	{"email": "natalyabaranova.16041971@postgrespro.ru", "phone": "+70568408973"}
0005432632631	6B3848	8970 584821	NATALIYA VOROBEVA	{"phone": "+70035536429"}
0005432632632	44CA61	1096 484872	ALENA POTAPOVA	{"phone": "+70057129742"}
0005432632633	AD5349	0472 620689	ANNA EFIMOVA	{"email": "aefimova111970@postgrespro.ru", "phone": "+70833752106"}
0005432632634	AD5349	0016 232795	OLGA ALEKSEEVA	{"phone": "+70908923617"}
0005432632635	E266DA	0624 903571	VASILIY ALEKSEEV	{"email": "valekseev1962@postgrespro.ru", "phone": "+70826290345"}
0005432632636	4771AD	3369 389332	SERGEY MELNIKOV	{"phone": "+70773069094"}
0005432632637	C64D14	7258 512898	ALEKSANDRA ANTONOVA	{"phone": "+70730301818"}
0005432632638	124C9E	1900 480689	IGOR VOROBEV	{"phone": "+70397607351"}
0005432632639	124C9E	4686 964824	SVETLANA GRISHINA	{"phone": "+70624723735"}
0005432632640	5391DA	4976 482236	KLAVDIYA DMITRIEVA	{"email": "k.dmitrieva11071968@postgrespro.ru", "phone": "+70758675177"}
0005432632641	B49A37	9589 655395	KONSTANTIN NIKITIN	{"phone": "+70490916642"}
0005432632642	692B7F	4422 374019	MARIYA RODIONOVA	{"phone": "+70122721151"}
0005432632643	4ECB68	3555 366067	ANASTASIYA ALEKSEEVA	{"phone": "+70652076574"}
0005432632644	38F21C	5582 635215	DARYA DMITRIEVA	{"email": "dmitrieva-d22061964@postgrespro.ru", "phone": "+70677427899"}
0005432632645	AE848F	2307 288847	VALERIY RODIONOV	{"email": "rodionov-valeriy14121974@postgrespro.ru", "phone": "+70012813832"}
0005432632646	AE848F	6117 651085	ALEKSANDR MAKAROV	{"phone": "+70095800726"}
0005432632647	D229AF	9525 273943	OLEG KUZNECOV	{"email": "olegkuznecov_091976@postgrespro.ru", "phone": "+70994282804"}
0005432632648	D229AF	2043 178936	IGOR ZHUKOV	{"phone": "+70591907370"}
0005432632649	6B333E	6815 124751	SERGEY MIRONOV	{"phone": "+70504535343"}
0005432632650	5283BF	3539 371062	LYUDMILA GUSEVA	{"email": "guseva_l_071966@postgrespro.ru", "phone": "+70868088364"}
0005432632651	5283BF	4974 445370	ANATOLIY STEPANOV	{"phone": "+70081997705"}
0005432632652	53811E	3091 336977	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey-1972@postgrespro.ru", "phone": "+70949422129"}
0005432632653	4A4A9E	9573 004464	NIKOLAY ISAEV	{"phone": "+70312330350"}
0005432632654	7E2637	6567 352149	BORIS ZAYCEV	{"phone": "+70520514061"}
0005432632655	C40D18	3257 719061	ALEKSEY FROLOV	{"phone": "+70538255311"}
0005432632656	C40D18	3644 474977	NIKOLAY KAZAKOV	{"phone": "+70856386638"}
0005432632657	4B6478	1709 177254	TATYANA NIKOLAEVA	{"email": "tatyana-nikolaeva_24041968@postgrespro.ru", "phone": "+70396355303"}
0005432632658	0CDC8F	7002 754437	EKATERINA SERGEEVA	{"email": "sergeeva.ekaterina_111972@postgrespro.ru", "phone": "+70130137388"}
0005432632659	E1194A	4878 368869	ELENA PAVLOVA	{"email": "pavlovaelena071960@postgrespro.ru", "phone": "+70193106095"}
0005432632660	0FD148	3439 729862	TATYANA ABRAMOVA	{"email": "abramovat.1981@postgrespro.ru", "phone": "+70021238583"}
0005432632661	0FD148	5174 663588	ALEKSANDR MEDVEDEV	{"phone": "+70174283265"}
0005432632662	797005	8774 374165	VERA MAKAROVA	{"email": "vera-makarova.29111982@postgrespro.ru", "phone": "+70046672033"}
0005432632663	797005	4600 037709	FEDOR SIDOROV	{"email": "sidorov.f.08091973@postgrespro.ru", "phone": "+70889426087"}
0005432632664	F9FDBA	6019 188290	ELENA SOKOLOVA	{"email": "sokolova.e_1972@postgrespro.ru", "phone": "+70475707754"}
0005432632665	1D9123	7139 213338	ZINAIDA NIKITINA	{"email": "zinaidanikitina-061972@postgrespro.ru", "phone": "+70096252379"}
0005432632666	C944A3	8307 757606	VIKTOR KONOVALOV	{"phone": "+70159704575"}
0005432632667	D425AC	8747 331335	VENERA BELYAEVA	{"email": "belyaeva_venera061979@postgrespro.ru", "phone": "+70176881095"}
0005432632668	133D0A	0993 022027	OLEG VOLKOV	{"phone": "+70467484578"}
0005432632669	133D0A	1744 481937	EVGENIYA KUZNECOVA	{"email": "kuznecovaevgeniya_07061971@postgrespro.ru", "phone": "+70370182369"}
0005432632670	B038EA	4866 693170	DIANA KUZNECOVA	{"phone": "+70050728197"}
0005432632671	B713BD	3598 633400	VERA NESTEROVA	{"phone": "+70416585327"}
0005432632672	F708C4	1541 676306	YURIY SOKOLOV	{"phone": "+70927317894"}
0005432632673	A6FFB0	3162 849017	ANNA NOVIKOVA	{"phone": "+70439959744"}
0005432632674	3DEDFC	0622 002265	IRINA KRASNOVA	{"email": "krasnovai_10051970@postgrespro.ru", "phone": "+70150183348"}
0005432632675	FDA4D3	4320 110369	YULIYA VASILEVA	{"email": "vasileva-yuliya_041971@postgrespro.ru", "phone": "+70759401718"}
0005432632676	983C31	5246 896918	ALINA TARASOVA	{"email": "a_tarasova1968@postgrespro.ru", "phone": "+70832902791"}
0005432632677	EC8E31	4600 557346	NADEZHDA YAKOVLEVA	{"email": "yakovlevanadezhda.08011970@postgrespro.ru", "phone": "+70121822251"}
0005432632678	EC8E31	4231 862859	DMITRIY VLASOV	{"email": "vlasov-d121965@postgrespro.ru", "phone": "+70334667716"}
0005432632679	010798	4485 438596	KLAVDIYA ZHUKOVA	{"phone": "+70972546648"}
0005432632680	21F9BE	6993 240406	MARIYA BORISOVA	{"email": "borisova-mariya-03031970@postgrespro.ru", "phone": "+70408022632"}
0005432632681	AF9AE4	6838 923500	MARIYA ZAKHAROVA	{"email": "mariya-zakharova_08081972@postgrespro.ru", "phone": "+70464702533"}
0005432632682	AF9AE4	5182 091226	LEONID VOLKOV	{"email": "volkov.l.1975@postgrespro.ru", "phone": "+70394994281"}
0005432632683	AF9AE4	2907 787359	ALEKSANDR MIRONOV	{"email": "a-mironov.1975@postgrespro.ru", "phone": "+70186822875"}
0005432632684	05AF7A	7052 638136	ELENA ALEKSEEVA	{"email": "alekseeva_e-1962@postgrespro.ru", "phone": "+70894055101"}
0005432632685	A8A099	6384 276820	RAMIL KUZNECOV	{"phone": "+70982355623"}
0005432632686	A8A099	3605 839135	TATYANA OSIPOVA	{"email": "tatyana.osipova13081966@postgrespro.ru", "phone": "+70223714681"}
0005432632687	594A05	7143 894522	ANDREY BORISOV	{"email": "borisov_a.04031985@postgrespro.ru", "phone": "+70931997550"}
0005432632688	594A05	9995 251246	ANDREY KOROLEV	{"phone": "+70989399631"}
0005432632689	555B52	6045 832838	ALEKSEY FEDOTOV	{"email": "a-fedotov.031975@postgrespro.ru", "phone": "+70166976106"}
0005432632690	555B52	3202 717310	OLGA VOROBEVA	{"email": "olgavorobeva.041990@postgrespro.ru", "phone": "+70109733759"}
0005432632691	76975E	4386 737357	KIRA MOROZOVA	{"email": "morozova_kira041980@postgrespro.ru", "phone": "+70131954022"}
0005432632692	76975E	3669 062071	VALERIY STEPANOV	{"phone": "+70506898874"}
0005432632693	54F343	2578 978020	NIKOLAY ZHURAVLEV	{"email": "n.zhuravlev.1978@postgrespro.ru", "phone": "+70784159291"}
0005432632694	D4C903	2131 310222	IVAN VASILEV	{"email": "ivan_vasilev_28041965@postgrespro.ru", "phone": "+70241126841"}
0005432632695	C00D35	6727 385493	NURIYA NIKITINA	{"email": "nuriya_nikitina_091975@postgrespro.ru", "phone": "+70378794468"}
0005432632696	8F6819	8668 877233	PAVEL NIKOLAEV	{"phone": "+70665328599"}
0005432632697	DBB774	8706 727906	DANILA NAZAROV	{"phone": "+70326930646"}
0005432632698	9068BD	4598 748987	GENNADIY SOKOLOV	{"phone": "+70404304860"}
0005432632699	8A82C9	1124 660911	ELENA ZAYCEVA	{"email": "zaycevae.041971@postgrespro.ru", "phone": "+70795630336"}
0005432632700	9A6563	8253 903491	ALEKSANDR VOLKOV	{"phone": "+70304663263"}
0005432632701	298CE3	3533 866362	NATALYA MASLOVA	{"phone": "+70828589103"}
0005432632702	6E93CB	6644 027455	VALENTINA TROFIMOVA	{"email": "valentinatrofimova1964@postgrespro.ru", "phone": "+70133576442"}
0005432632703	5C0750	2940 193244	YURIY SIDOROV	{"email": "y-sidorov1970@postgrespro.ru", "phone": "+70135944949"}
0005432632704	F059C0	3506 190203	VASILIY IVANOV	{"email": "ivanov.vasiliy1968@postgrespro.ru", "phone": "+70524014403"}
0005432632705	F059C0	9394 226685	NATALYA SAVELEVA	{"phone": "+70939262025"}
0005432632706	79FB01	5224 670465	NIKOLAY GORBUNOV	{"phone": "+70145953514"}
0005432632707	AA53BC	2313 739291	OLGA VOROBEVA	{"email": "vorobeva-o121983@postgrespro.ru", "phone": "+70696217691"}
0005432632708	AA53BC	4045 208703	OLGA ERMAKOVA	{"phone": "+70542137160"}
0005432632709	4C2C13	2209 587020	ANTONINA ERMAKOVA	{"phone": "+70327329866"}
0005432632710	4C2C13	7266 490267	OLGA KONDRATEVA	{"phone": "+70922880721"}
0005432632711	4C2C13	4711 381361	NIKOLAY KONOVALOV	{"phone": "+70971894783"}
0005432632712	30264F	0270 998175	VLADIMIR MAKSIMOV	{"email": "maksimov-v.23071981@postgrespro.ru", "phone": "+70771103629"}
0005432632713	83F22D	6627 837926	ALEKSEY KONOVALOV	{"email": "konovalov.aleksey.08121972@postgrespro.ru", "phone": "+70889505103"}
0005432632714	83F22D	6234 593774	TATYANA YAKOVLEVA	{"phone": "+70567146874"}
0005432632715	F55116	8352 495027	VERA MALYSHEVA	{"email": "v_malysheva.1971@postgrespro.ru", "phone": "+70763003074"}
0005432632716	F55116	4843 305330	LARISA DENISOVA	{"email": "denisova.l_1975@postgrespro.ru", "phone": "+70795023637"}
0005432632717	102E39	8788 869041	SERGEY KOZLOV	{"phone": "+70488772262"}
0005432632718	3107C6	3514 338687	LIDIYA FILATOVA	{"email": "filatova.l-011970@postgrespro.ru", "phone": "+70793808018"}
0005432632719	3107C6	4181 157121	NIKOLAY MELNIKOV	{"phone": "+70162065629"}
0005432632720	50F3F3	0299 723898	VLADIMIR VOLKOV	{"phone": "+70602187247"}
0005432632721	50F3F3	8521 194275	MARIYA POPOVA	{"phone": "+70170621157"}
0005432632722	908CBD	4494 389268	ELENA ORLOVA	{"phone": "+70333245281"}
0005432632723	591EDC	3305 356906	DMITRIY ZHUKOV	{"email": "zhukov-d1975@postgrespro.ru", "phone": "+70322108743"}
0005432632724	0C7023	1850 008940	NATALYA MASLOVA	{"phone": "+70882294875"}
0005432632725	508975	0539 597469	ELENA FROLOVA	{"email": "frolova-elena27071974@postgrespro.ru", "phone": "+70980214312"}
0005432632726	B1D3D9	3904 813989	NATALYA NAZAROVA	{"email": "n_nazarova04111977@postgrespro.ru", "phone": "+70407253625"}
0005432632727	12CFF4	0581 832228	MARINA NIKIFOROVA	{"email": "m-nikiforova.06121974@postgrespro.ru", "phone": "+70773307215"}
0005432632728	1F9291	8164 250301	KSENIYA BELYAEVA	{"email": "belyaeva-kseniya1965@postgrespro.ru", "phone": "+70855833572"}
0005432632729	AAB07A	6355 534931	OLGA GERASIMOVA	{"phone": "+70476255554"}
0005432632730	B85B95	0576 282190	ANASTASIYA SMIRNOVA	{"phone": "+70955502765"}
0005432632731	751AB0	0899 808072	TATYANA GUSEVA	{"email": "t-guseva_051959@postgrespro.ru", "phone": "+70712984290"}
0005432632732	4D121B	0950 994466	TAMARA VASILEVA	{"email": "t.vasileva_02091968@postgrespro.ru", "phone": "+70538443977"}
0005432632733	8173B3	3174 851205	OLGA TITOVA	{"phone": "+70765746827"}
0005432632734	A0B352	4684 526904	LEV VLASOV	{"phone": "+70446810975"}
0005432632735	5B2ED1	0047 877917	MIKHAIL SCHERBAKOV	{"phone": "+70062830575"}
0005432632736	5B2ED1	8575 578839	MARIYA MEDVEDEVA	{"phone": "+70263617709"}
0005432632737	967531	9916 084304	LARISA MATVEEVA	{"email": "larisamatveeva.04041968@postgrespro.ru", "phone": "+70616771564"}
0005432632738	7D1D2B	1665 409385	OLEG SERGEEV	{"phone": "+70125737434"}
0005432632739	BDFB10	7384 998969	VALENTINA TARASOVA	{"email": "tarasovav-15061979@postgrespro.ru", "phone": "+70682256289"}
0005432632740	BDFB10	5532 234197	NIKITA AFANASEV	{"phone": "+70523535283"}
0005432632741	D2F7E2	0370 507752	TAMARA ANDREEVA	{"phone": "+70098140949"}
0005432632742	BCC6B7	1857 548288	PAVEL SAVELEV	{"email": "p.savelev-1969@postgrespro.ru", "phone": "+70626984096"}
0005432632743	F476AC	9578 406326	TATYANA SOKOLOVA	{"phone": "+70140986443"}
0005432632744	43C93F	2041 534929	VALENTINA EFREMOVA	{"phone": "+70753093290"}
0005432632745	02F486	6044 815948	MARIYA BORISOVA	{"phone": "+70607147376"}
0005432632746	19C479	3202 465925	VLADISLAV AFANASEV	{"phone": "+70503238246"}
0005432632747	506BF7	2681 442280	ELENA KUZNECOVA	{"email": "kuznecova-elena.101969@postgrespro.ru", "phone": "+70236570556"}
0005432632748	506BF7	8175 600101	IRINA CHERNOVA	{"phone": "+70683731023"}
0005432632749	CA8CE6	7679 833568	MAKSIM ROMANOV	{"email": "mromanov-061967@postgrespro.ru", "phone": "+70600639937"}
0005432632750	CA8CE6	8803 340790	NATALYA DANILOVA	{"phone": "+70769235865"}
0005432632751	CA8CE6	5568 895175	NATALYA LAZAREVA	{"email": "n-lazareva.1962@postgrespro.ru", "phone": "+70326758432"}
0005432632752	C0B3CD	1939 245795	SVETLANA ERMAKOVA	{"phone": "+70230540569"}
0005432632753	A981E5	5103 585609	VYACHESLAV KAZAKOV	{"email": "kazakovvyacheslav-1965@postgrespro.ru", "phone": "+70375483997"}
0005432632754	A981E5	6855 239527	ANASTASIYA OSIPOVA	{"phone": "+70856032104"}
0005432632755	827238	7363 951873	ELENA FROLOVA	{"phone": "+70193224845"}
0005432632756	827238	8168 543945	MARIYA PETROVA	{"email": "petrova-mariya071979@postgrespro.ru", "phone": "+70513064449"}
0005432632757	827238	6574 529407	DMITRIY MATVEEV	{"email": "dmitriy_matveev.091962@postgrespro.ru", "phone": "+70173291763"}
0005432632758	F9F3B7	1124 724886	OLEG PAVLOV	{"phone": "+70908598015"}
0005432632759	C9F8E0	3658 394583	KRISTINA GORBUNOVA	{"email": "gorbunova.kristina-1984@postgrespro.ru", "phone": "+70520697097"}
0005432632760	619421	9102 490221	SERGEY MOROZOV	{"phone": "+70499875711"}
0005432632761	8D14CD	4667 847704	OLGA FILATOVA	{"phone": "+70595120623"}
0005432632762	A6D182	3331 420915	DENIS SEMENOV	{"email": "semenov-denis-051971@postgrespro.ru", "phone": "+70408039420"}
0005432632763	A6D182	6307 990873	RAISA ZHURAVLEVA	{"email": "raisa-zhuravleva1977@postgrespro.ru", "phone": "+70809187375"}
0005432632764	0B91DC	1786 900771	DMITRIY DAVYDOV	{"phone": "+70560397512"}
0005432632765	0B91DC	3237 085805	NATALYA ZAYCEVA	{"email": "zaycevanatalya1960@postgrespro.ru", "phone": "+70610655695"}
0005432632766	21B440	2760 697466	RAISA GRISHINA	{"phone": "+70891049766"}
0005432632767	00724C	4974 371205	SERGEY ISAEV	{"phone": "+70230132977"}
0005432632768	1CE9C9	2412 086427	ALEKSANDR KRASNOV	{"phone": "+70148363712"}
0005432632769	383A77	1745 155802	ANNA NAZAROVA	{"phone": "+70892778792"}
0005432632770	383A77	6559 300647	NIKOLAY EGOROV	{"phone": "+70896520039"}
0005432632771	8F59A2	4915 818432	GRIGORIY OSIPOV	{"phone": "+70513245255"}
0005432632772	0A4A28	0581 632794	ALEKSANDRA PETROVA	{"email": "aleksandra_petrova-011965@postgrespro.ru", "phone": "+70574376407"}
0005432632773	414C16	6570 652223	ELENA KULIKOVA	{"email": "kulikova.elena_1971@postgrespro.ru", "phone": "+70966944623"}
0005432632774	D6BA4B	3425 297726	ALEKSANDR IVANOV	{"email": "a.ivanov.1978@postgrespro.ru", "phone": "+70374353361"}
0005432632775	27E08C	7554 927148	NATALYA ROMANOVA	{"email": "nromanova_101978@postgrespro.ru", "phone": "+70755468779"}
0005432632776	F32800	5876 129657	IVAN MEDVEDEV	{"email": "medvedev-i.22041966@postgrespro.ru", "phone": "+70787805380"}
0005432632777	F32800	0288 794594	VIKTORIYA DAVYDOVA	{"phone": "+70039601322"}
0005432632778	E9409E	8646 549306	ROMAN MOROZOV	{"email": "roman.morozov.101970@postgrespro.ru", "phone": "+70728603542"}
0005432632779	B43F8A	4044 919197	MIKHAIL GERASIMOV	{"email": "mikhail_gerasimov_111978@postgrespro.ru", "phone": "+70437927626"}
0005432632836	1D9343	4156 883515	YULIYA KOVALEVA	{"phone": "+70381129866"}
0005432632780	48A83D	3309 945081	MIKHAIL KOZLOV	{"email": "mikhail.kozlov.22071963@postgrespro.ru", "phone": "+70673011336"}
0005432632781	48A83D	5104 825304	VALENTINA KUZMINA	{"phone": "+70421709329"}
0005432632782	48A83D	4984 478807	TATYANA MAKSIMOVA	{"phone": "+70666990977"}
0005432632783	BF5853	0945 677696	GALINA ANISIMOVA	{"email": "anisimova-galina-19111968@postgrespro.ru", "phone": "+70752785573"}
0005432632784	BF5853	8767 719840	ALEKSANDR KUZMIN	{"phone": "+70682532862"}
0005432632785	67F878	0166 493431	SERGEY MAKAROV	{"phone": "+70050970707"}
0005432632786	632980	6129 081672	NIKITA KUZNECOV	{"email": "nikita-kuznecov_111970@postgrespro.ru", "phone": "+70394292443"}
0005432632787	632980	4304 273346	OLGA ALEKSEEVA	{"phone": "+70417896926"}
0005432632788	880EBA	6156 514113	OKSANA TIKHONOVA	{"phone": "+70582224929"}
0005432632789	880EBA	7856 578349	ALEKSANDR KOROLEV	{"phone": "+70186463020"}
0005432632790	29FBCE	8028 729431	TATYANA NAZAROVA	{"phone": "+70884037732"}
0005432632791	9643BA	7138 073600	ELIZAVETA KOMAROVA	{"email": "komarovaelizaveta-1971@postgrespro.ru", "phone": "+70152985610"}
0005432632792	CCC860	6784 521487	NINA KOZLOVA	{"email": "nina_kozlova-10101980@postgrespro.ru", "phone": "+70119854779"}
0005432632793	B3A13C	6047 733961	EKATERINA MATVEEVA	{"email": "matveeva.ekaterina.081972@postgrespro.ru", "phone": "+70026521755"}
0005432632794	3EAF4E	0870 286527	VALERIY RODIONOV	{"email": "valeriy.rodionov-1984@postgrespro.ru", "phone": "+70604923623"}
0005432632795	C0E37B	8497 007264	DMITRIY BONDARENKO	{"phone": "+70282172423"}
0005432632796	0C6AA7	0578 336780	ANDREY KUZMIN	{"phone": "+70234057090"}
0005432632797	916503	0556 166381	LYUDMILA GERASIMOVA	{"email": "l.gerasimova-1970@postgrespro.ru", "phone": "+70990306914"}
0005432632798	294DF3	5626 173135	KSENIYA ZOTOVA	{"phone": "+70586611773"}
0005432632799	67944D	1689 974064	VYACHESLAV NIKOLAEV	{"email": "nikolaev.v_051955@postgrespro.ru", "phone": "+70678539118"}
0005432632800	CA06FB	6388 995448	VLADIMIR ALEKSEEV	{"email": "alekseevvladimir.19021966@postgrespro.ru", "phone": "+70691071864"}
0005432632801	669D1E	7146 074527	OLGA PAVLOVA	{"email": "o.pavlova_121971@postgrespro.ru", "phone": "+70905349285"}
0005432632802	669D1E	0327 957192	GENNADIY KUZNECOV	{"email": "gennadiy.kuznecov.101975@postgrespro.ru", "phone": "+70319138302"}
0005432632803	4FB19A	8622 149154	ANATOLIY ILIN	{"phone": "+70433063394"}
0005432632804	4FB19A	0100 772010	SERGEY MAKAROV	{"phone": "+70994620127"}
0005432632805	11A76A	7532 994157	ALEKSANDR MOISEEV	{"phone": "+70502867407"}
0005432632806	7AC051	9415 207746	LYUBOV FEDOROVA	{"email": "lyubov-fedorova.1975@postgrespro.ru", "phone": "+70347785614"}
0005432632807	7AC051	0984 169565	GRIGORIY NAUMOV	{"email": "naumov_g10111977@postgrespro.ru", "phone": "+70570180490"}
0005432632808	CF4566	3963 719708	ANNA MARTYNOVA	{"phone": "+70794809668"}
0005432632809	6B8A21	0885 537925	OLGA ANISIMOVA	{"email": "olga.anisimova-121980@postgrespro.ru", "phone": "+70390360510"}
0005432632810	73D51A	6147 631751	OLGA DANILOVA	{"email": "o_danilova-1965@postgrespro.ru", "phone": "+70913056566"}
0005432632811	E62DD5	1896 837181	VLADIMIR MEDVEDEV	{"phone": "+70741293926"}
0005432632812	A5D8F7	4154 331188	TAMARA VOROBEVA	{"phone": "+70215677147"}
0005432632813	851F84	4358 965637	ARTEM MAKAROV	{"email": "artem-makarov-1970@postgrespro.ru", "phone": "+70808387739"}
0005432632814	851F84	6464 815274	TATYANA KOROLEVA	{"phone": "+70420482801"}
0005432632815	171FF9	1132 708821	DMITRIY MAKAROV	{"email": "d_makarov.17041974@postgrespro.ru", "phone": "+70833046033"}
0005432632816	171FF9	8421 902515	NIKOLAY ANTONOV	{"phone": "+70850038303"}
0005432632817	372462	5863 775536	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr_27081976@postgrespro.ru", "phone": "+70477528028"}
0005432632818	B814BE	5528 996134	EKATERINA KISELEVA	{"email": "e-kiseleva_20061971@postgrespro.ru", "phone": "+70086833854"}
0005432632819	3F54B7	9754 790161	DARYA BELYAEVA	{"phone": "+70975489344"}
0005432632820	3F54B7	4735 905612	ALEKSANDR CHERNOV	{"phone": "+70584958385"}
0005432632821	3F54B7	0515 086907	ANGELINA MOISEEVA	{"phone": "+70739915915"}
0005432632822	FEDEAE	9551 450468	MIKHAIL ISAEV	{"phone": "+70464277509"}
0005432632823	4FFF54	4611 710450	ARTEM IVANOV	{"phone": "+70238292235"}
0005432632824	70C845	1027 228980	ILYA ZHUKOV	{"email": "ilya.zhukov-1974@postgrespro.ru", "phone": "+70179248190"}
0005432632825	653D43	9192 574139	SERGEY SMIRNOV	{"phone": "+70606006391"}
0005432632826	653D43	1488 693471	YURIY KUZNECOV	{"email": "yuriy_kuznecov-02021973@postgrespro.ru", "phone": "+70584508179"}
0005432632827	9620A0	9842 954544	EKATERINA SERGEEVA	{"email": "e.sergeeva.121978@postgrespro.ru", "phone": "+70369691177"}
0005432632828	4C4C86	2587 279345	NATALYA SEMENOVA	{"email": "semenova.natalya_051969@postgrespro.ru", "phone": "+70133788017"}
0005432632829	4C4C86	9810 469657	ANATOLIY FEDOTOV	{"email": "fedotov.a081968@postgrespro.ru", "phone": "+70653722043"}
0005432632830	15E1A7	2645 376433	VLADIMIR IVANOV	{"phone": "+70309961387"}
0005432632831	A0C1F2	3295 511969	STEPAN SMIRNOV	{"phone": "+70827842421"}
0005432632832	49396B	5215 178331	OLEG STEPANOV	{"phone": "+70578816408"}
0005432632833	937223	8414 667970	MARIYA ZAKHAROVA	{"phone": "+70408800185"}
0005432632834	EB9189	1256 502058	MAKSIM TIKHONOV	{"email": "m.tikhonov-04101978@postgrespro.ru", "phone": "+70171733011"}
0005432632835	D9B9C3	7017 058781	DANIYA SOROKINA	{"phone": "+70646698564"}
0005432632837	19DF1B	4162 179919	SERGEY NOVIKOV	{"email": "s_novikov.121969@postgrespro.ru", "phone": "+70321805479"}
0005432632838	BB17C1	8502 738355	VALENTINA VOROBEVA	{"phone": "+70612808580"}
0005432632839	BB17C1	0359 618103	DARYA TIMOFEEVA	{"phone": "+70068849359"}
0005432632840	BB17C1	3346 762825	OKSANA MIKHAYLOVA	{"phone": "+70066774538"}
0005432632841	E4A317	4807 393574	ULYANA MOROZOVA	{"phone": "+70729022762"}
0005432632842	663A1B	3078 467914	MARIYA GORBUNOVA	{"email": "gorbunovam1959@postgrespro.ru", "phone": "+70436653546"}
0005432632843	663A1B	8623 753971	VYACHESLAV ANDREEV	{"email": "andreevvyacheslav21091970@postgrespro.ru", "phone": "+70319624532"}
0005432632844	36B853	9573 778386	VERONIKA ORLOVA	{"email": "v_orlova.1963@postgrespro.ru", "phone": "+70475102459"}
0005432632845	A5AC13	2517 797834	ALEKSANDR SOKOLOV	{"email": "sokolov_a.071966@postgrespro.ru", "phone": "+70787633238"}
0005432632846	490F90	8983 080697	IVAN BONDARENKO	{"email": "bondarenko-ivan_1975@postgrespro.ru", "phone": "+70103896144"}
0005432632847	336395	2236 266076	EVGENIY BELOV	{"email": "evgeniy_belov-24071965@postgrespro.ru", "phone": "+70013157460"}
0005432632848	2C8825	0073 265519	TATYANA NOVIKOVA	{"phone": "+70360370307"}
0005432632849	2C8825	4088 706908	SERGEY VASILEV	{"phone": "+70195383713"}
0005432632850	68AF7D	7299 581101	VIKTOR KUZMIN	{"email": "kuzmin.v_061973@postgrespro.ru", "phone": "+70983282507"}
0005432632851	97235F	0053 768621	VALENTINA NESTEROVA	{"phone": "+70916206784"}
0005432632852	0992F8	1395 226492	DMITRIY MOISEEV	{"phone": "+70230009810"}
0005432632853	0992F8	6192 104717	EVGENIY EGOROV	{"phone": "+70494696567"}
0005432632854	739525	9634 938110	ALEKSEY SAVELEV	{"phone": "+70127273336"}
0005432632855	739525	9217 387574	ROMAN KUZMIN	{"email": "roman_kuzmin04051965@postgrespro.ru", "phone": "+70883271523"}
0005432632856	739525	4436 826706	LYUDMILA FROLOVA	{"email": "lyudmila.frolova-1968@postgrespro.ru", "phone": "+70630744776"}
0005432632857	EDF27E	2666 535205	DMITRIY TIKHONOV	{"phone": "+70813026877"}
0005432632858	1287BF	9991 821391	ANTON KUZNECOV	{"email": "kuznecov-anton-021975@postgrespro.ru", "phone": "+70377966617"}
0005432632859	1287BF	4396 577723	YURIY GRIGOREV	{"phone": "+70979087417"}
0005432632860	1287BF	2880 942527	DANIL KUZNECOV	{"phone": "+70288589896"}
0005432632861	E81127	7529 568457	NADEZHDA KAZAKOVA	{"phone": "+70138572404"}
0005432632862	89BFA8	8842 079333	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr-1967@postgrespro.ru", "phone": "+70573556930"}
0005432632863	18F1C8	1942 090064	ANDREY FILIPPOV	{"email": "filippov_andrey071961@postgrespro.ru", "phone": "+70337128073"}
0005432632864	76D0E3	6014 380517	NATALYA KUZMINA	{"phone": "+70190829897"}
0005432632865	33B0F4	3958 432369	ALEKSANDR SOROKIN	{"email": "asorokin081974@postgrespro.ru", "phone": "+70503297337"}
0005432632866	BD15EC	0181 384481	VIKTOR TARASOV	{"email": "viktortarasov_1965@postgrespro.ru", "phone": "+70334325302"}
0005432632867	BD15EC	3312 283435	ANASTASIYA TROFIMOVA	{"phone": "+70889157454"}
0005432632868	396C3E	2666 615868	OLGA KUZNECOVA	{"email": "o-kuznecova30011963@postgrespro.ru", "phone": "+70977636105"}
0005432632869	D3D9B5	8423 249263	VASILIY ANDREEV	{"phone": "+70868764155"}
0005432632870	D3D9B5	4366 665894	ELIZAVETA KAZAKOVA	{"email": "e-kazakova-1962@postgrespro.ru", "phone": "+70544147254"}
0005432632871	7ED256	3663 451533	EVA IVANOVA	{"phone": "+70549731524"}
0005432632872	7ED256	7018 597552	TATYANA MELNIKOVA	{"email": "melnikovat-19011965@postgrespro.ru", "phone": "+70397858866"}
0005432632873	AFCD68	0357 848889	ALEKSEY NAUMOV	{"phone": "+70889223799"}
0005432632874	9924AB	2570 797362	ARTEM KULIKOV	{"phone": "+70233584857"}
0005432632875	9924AB	0308 119096	VIKTOR DAVYDOV	{"email": "davydov_v-121977@postgrespro.ru", "phone": "+70183109606"}
0005432632876	7E120A	0196 966719	OLGA VOLKOVA	{"phone": "+70657835403"}
0005432632877	DFB090	2705 933905	KIRILL ABRAMOV	{"email": "abramov-kirill1967@postgrespro.ru", "phone": "+70314875060"}
0005432632878	DFB090	8120 671603	ANNA KUZNECOVA	{"email": "a.kuznecova011983@postgrespro.ru", "phone": "+70899621397"}
0005432632879	5C9815	6710 677772	ALBINA MOROZOVA	{"email": "morozova-albina-041974@postgrespro.ru", "phone": "+70693416987"}
0005432632880	5C9815	5368 442968	TATYANA DMITRIEVA	{"phone": "+70635462821"}
0005432632881	426BE1	0846 520152	VALERIY ZHUKOV	{"email": "vzhukov_1970@postgrespro.ru", "phone": "+70841644076"}
0005432632882	426BE1	5069 150593	MARAT ROMANOV	{"phone": "+70681231804"}
0005432632883	7FA742	1115 968471	SVETLANA FROLOVA	{"phone": "+70855746061"}
0005432632884	7FA742	8826 339945	MIKHAIL MATVEEV	{"phone": "+70535979868"}
0005432632885	D5B6D7	0806 169250	SVETLANA POPOVA	{"phone": "+70401946952"}
0005432632886	B45D6B	6674 116178	RAISA BELYAEVA	{"phone": "+70000553238"}
0005432632887	B45D6B	9093 668091	DENIS SERGEEV	{"email": "denis-sergeev.12081968@postgrespro.ru", "phone": "+70441363699"}
0005432632888	46ADFD	1311 995918	VALERIY KUZNECOV	{"email": "valeriykuznecov.12051975@postgrespro.ru", "phone": "+70906544846"}
0005432632889	46ADFD	6773 263351	RODION ALEKSEEV	{"email": "alekseev.rodion_091970@postgrespro.ru", "phone": "+70354674153"}
0005432632890	46ADFD	8759 699022	MARIYA MAKAROVA	{"email": "mariya_makarova-1977@postgrespro.ru", "phone": "+70037390489"}
0005432632891	6FED6C	6942 263046	ALEKSANDR YAKOVLEV	{"phone": "+70126412344"}
0005432632892	6FED6C	7756 828007	GALINA SEMENOVA	{"email": "g_semenova_081976@postgrespro.ru", "phone": "+70442925187"}
0005432632893	DC6FD0	4400 343075	SVETLANA KOROLEVA	{"email": "koroleva_svetlana.16041970@postgrespro.ru", "phone": "+70681236830"}
0005432632894	4EF414	0091 491669	ELENA NESTEROVA	{"phone": "+70596590625"}
0005432632895	84D7DD	3968 280793	MIKHAIL KUZMIN	{"email": "m_kuzmin041963@postgrespro.ru", "phone": "+70914853940"}
0005432632896	A1BC4F	3749 134703	SVETLANA FEDOROVA	{"email": "s.fedorova_031984@postgrespro.ru", "phone": "+70838003121"}
0005432632897	A1101E	3719 441792	EKATERINA MAKAROVA	{"email": "ekaterina_makarova.011984@postgrespro.ru", "phone": "+70044217083"}
0005432632898	A1101E	5498 918699	VLADISLAV NIKOLAEV	{"phone": "+70540080967"}
0005432632899	582BA8	4825 435098	ANDREY SOLOVEV	{"email": "asolovev1980@postgrespro.ru", "phone": "+70082337883"}
0005432632900	DDDB63	3670 362171	PAVEL FILIPPOV	{"email": "filippovp_041971@postgrespro.ru", "phone": "+70453005865"}
0005432632901	DDDB63	7098 822154	EKATERINA OSIPOVA	{"phone": "+70335786611"}
0005432632902	14FB72	2140 299719	MARIYA POPOVA	{"email": "m.popova_1982@postgrespro.ru", "phone": "+70414694894"}
0005432632903	6277CD	5971 146614	MARIANNA BORISOVA	{"email": "m.borisova-1970@postgrespro.ru", "phone": "+70846326019"}
0005432632904	6277CD	9263 062634	IVAN FROLOV	{"phone": "+70306462168"}
0005432632905	588DB3	6554 836098	NATALYA MIKHAYLOVA	{"email": "natalya_mikhaylova-04041978@postgrespro.ru", "phone": "+70138198659"}
0005432632906	5A853C	0449 358513	MARIYA EGOROVA	{"email": "m_egorova-1974@postgrespro.ru", "phone": "+70521078519"}
0005432632907	5A853C	8960 148803	YURIY ALEKSANDROV	{"phone": "+70496264738"}
0005432632908	2135D4	9662 691725	VALERIY VASILEV	{"phone": "+70406765280"}
0005432632909	2135D4	2367 118854	OLGA CHERNOVA	{"email": "olga-chernova_27071971@postgrespro.ru", "phone": "+70935167514"}
0005432632910	1F813B	3055 741349	ANGELINA POPOVA	{"email": "popova_angelina-1971@postgrespro.ru", "phone": "+70899711423"}
0005432632911	0638EA	7108 984389	OLGA SOROKINA	{"phone": "+70860844483"}
0005432632912	E928DB	8838 142500	VLADISLAV PAVLOV	{"phone": "+70216234154"}
0005432632913	736E70	6970 471730	LARISA KRASNOVA	{"email": "krasnova_l_011978@postgrespro.ru", "phone": "+70962934704"}
0005432632914	1567CF	0643 904355	EVGENIY MAKAROV	{"phone": "+70054154242"}
0005432632915	1567CF	7085 978852	VALENTINA ALEKSANDROVA	{"email": "v-aleksandrova_1972@postgrespro.ru", "phone": "+70726117328"}
0005432632916	1567CF	7997 611906	LILIYA LUKYANOVA	{"email": "lukyanova_l.021965@postgrespro.ru", "phone": "+70936252451"}
0005432632917	7E086C	9741 659823	ANATOLIY MIRONOV	{"email": "mironov_a021975@postgrespro.ru", "phone": "+70951074518"}
0005432632918	7E086C	4352 896577	ANATOLIY SEMENOV	{"phone": "+70225777631"}
0005432632919	CD4AE2	1114 841155	NATALYA GRISHINA	{"email": "ngrishina19041969@postgrespro.ru", "phone": "+70731361228"}
0005432632920	CD4AE2	9980 699361	ANNA KALININA	{"email": "annakalinina-1976@postgrespro.ru", "phone": "+70082987642"}
0005432632921	BFE1DB	2781 565141	NATALYA LUKYANOVA	{"phone": "+70455299152"}
0005432632922	A8027E	1106 655442	LIDIYA PETROVA	{"email": "petrova-lidiya_1974@postgrespro.ru", "phone": "+70251851813"}
0005432632923	C55C29	4729 482921	TATYANA ZOTOVA	{"email": "t_zotova.27111962@postgrespro.ru", "phone": "+70184304500"}
0005432632924	A6F5DA	7796 855127	IVAN MIKHAYLOV	{"email": "ivan.mikhaylov_1957@postgrespro.ru", "phone": "+70746813090"}
0005432632925	A6F5DA	6174 618282	ELENA MARTYNOVA	{"phone": "+70140682422"}
0005432632926	94BCFF	4079 827643	MARIYA FILATOVA	{"email": "mariya-filatova-071973@postgrespro.ru", "phone": "+70987283404"}
0005432632927	2D98A6	6400 159477	ANDREY SEMENOV	{"email": "semenov_andrey_071978@postgrespro.ru", "phone": "+70976006482"}
0005432632928	B96DC9	5643 104598	VALENTINA MOROZOVA	{"phone": "+70951319500"}
0005432632929	29F313	9284 148341	MAKSIM KUZNECOV	{"email": "m-kuznecov_111972@postgrespro.ru", "phone": "+70541222246"}
0005432632930	29F313	6577 711934	YURIY MOROZOV	{"email": "morozovy-20101976@postgrespro.ru", "phone": "+70572139002"}
0005432632931	CD9AD1	2989 834751	YURIY MATVEEV	{"phone": "+70900137795"}
0005432632932	23BD55	7509 952928	ALEKSANDRA BOGDANOVA	{"email": "aleksandra_bogdanova.021986@postgrespro.ru", "phone": "+70739811638"}
0005432632933	23BD55	9284 604144	ELENA KONDRATEVA	{"email": "ekondrateva011968@postgrespro.ru", "phone": "+70590965187"}
0005432632934	23BD55	7281 059450	DARYA SMIRNOVA	{"email": "smirnovad-20051975@postgrespro.ru", "phone": "+70309893011"}
0005432632935	B6E8BA	8886 854067	MIKHAIL EGOROV	{"email": "egorov-m.081977@postgrespro.ru", "phone": "+70920338610"}
0005432632936	D2DF46	9688 251898	MAKSIM IVANOV	{"email": "ivanov-m.1973@postgrespro.ru", "phone": "+70526730499"}
0005432632937	BB4EB8	3810 940471	TATYANA SAVELEVA	{"phone": "+70059152699"}
0005432632938	02815B	0147 674259	ALEKSEY STEPANOV	{"email": "a_stepanov.061976@postgrespro.ru", "phone": "+70694665967"}
0005432632939	02815B	5599 666387	DAMIR SOROKIN	{"email": "sorokind.23031982@postgrespro.ru", "phone": "+70753895358"}
0005432632940	51B2D7	0594 969155	SERGEY TARASOV	{"phone": "+70978779833"}
0005432632941	5D235E	3210 422727	DENIS KARPOV	{"phone": "+70663954086"}
0005432632942	5C7491	2759 387502	ANATOLIY VASILEV	{"email": "a_vasilev051973@postgrespro.ru", "phone": "+70598896320"}
0005432632943	423D3B	1043 163586	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr1974@postgrespro.ru", "phone": "+70845548862"}
0005432632944	90305B	9552 191450	ALEKSANDRA KOROLEVA	{"email": "koroleva_a.031974@postgrespro.ru", "phone": "+70883659724"}
0005432632945	C4986E	1164 897001	ELENA MELNIKOVA	{"phone": "+70797368468"}
0005432638915	3329BC	4288 350452	ALEKSANDR KUZNECOV	{"phone": "+70827906736"}
0005432638916	7AE9AF	8447 048541	VALENTINA AFANASEVA	{"email": "v_afanaseva_1981@postgrespro.ru", "phone": "+70661775774"}
0005432638917	7AE9AF	3444 867748	SERGEY YAKOVLEV	{"phone": "+70934108012"}
0005432638918	7AE9AF	2334 222862	PAVEL CHERNOV	{"phone": "+70896079869"}
0005432638919	0DFC00	6498 180101	GALINA EFREMOVA	{"email": "efremova_g-26111978@postgrespro.ru", "phone": "+70091446852"}
0005432638920	0DFC00	0655 795770	NIKOLAY SEMENOV	{"email": "nsemenov27101966@postgrespro.ru", "phone": "+70207834223"}
0005432638921	9CEBFB	9711 641612	DENIS ZAKHAROV	{"email": "zakharovd1973@postgrespro.ru", "phone": "+70993572925"}
0005432638922	9CEBFB	3977 687448	VLADIMIR FEDOROV	{"phone": "+70629969618"}
0005432638923	9CEBFB	2017 393336	KRISTINA KOMAROVA	{"phone": "+70400855789"}
0005432638924	892B84	0165 494944	ALEKSANDR FEDOTOV	{"phone": "+70247881033"}
0005432638925	892B84	0949 428286	OLGA AKIMOVA	{"phone": "+70034428188"}
0005432638926	1C0F6A	1766 467635	YULIYA KOZLOVA	{"phone": "+70125766094"}
0005432638927	1C0F6A	9086 842447	ANDREY ANTONOV	{"phone": "+70396049444"}
0005432638928	6B26FE	7176 967075	LIDIYA VLASOVA	{"phone": "+70834117976"}
0005432638929	683934	2817 635677	NIKOLAY MOROZOV	{"phone": "+70457669279"}
0005432638930	0DD29B	3907 728993	EKATERINA KOZLOVA	{"phone": "+70828826846"}
0005432638931	D317EA	6021 491907	IRINA IVANOVA	{"phone": "+70169759108"}
0005432638932	D317EA	3651 943748	GULFIYA DAVYDOVA	{"email": "g.davydova.061974@postgrespro.ru", "phone": "+70742500184"}
0005432638933	60F6EA	7205 636657	ALENA ILINA	{"email": "ilina-alena_1968@postgrespro.ru", "phone": "+70444182573"}
0005432638934	4A477A	8275 331165	OLGA ZAYCEVA	{"phone": "+70965791876"}
0005432638935	4A477A	3888 457122	TATYANA POPOVA	{"email": "t_popova06071968@postgrespro.ru", "phone": "+70371668921"}
0005432638936	A8A76F	1438 111707	ELENA ZAYCEVA	{"phone": "+70626262213"}
0005432638937	B87493	5957 813725	LYUDMILA TIKHONOVA	{"phone": "+70560331149"}
0005432638938	2DA5AC	5429 220384	ELENA MIKHAYLOVA	{"phone": "+70487460189"}
0005432638939	243480	5840 296647	IVAN KUZNECOV	{"email": "kuznecov.i-061966@postgrespro.ru", "phone": "+70150373290"}
0005432638940	243480	2368 408148	NIKOLAY NIKOLAEV	{"email": "n-nikolaev-23031980@postgrespro.ru", "phone": "+70662867467"}
0005432638941	93A82B	0962 749485	LYUBOV RYABOVA	{"phone": "+70735076403"}
0005432638942	93A82B	5109 353571	OLGA POPOVA	{"phone": "+70602766542"}
0005432638943	22DFE9	1348 944430	EKATERINA GORBUNOVA	{"phone": "+70039603878"}
0005432638944	22DFE9	1319 089815	SERGEY FEDOROV	{"phone": "+70995830281"}
0005432638945	DD3F24	3644 076618	ARTEM BARANOV	{"phone": "+70568375122"}
0005432638946	DD3F24	8063 765454	EKATERINA ZAKHAROVA	{"phone": "+70635265287"}
0005432638947	26B854	6168 492922	GENNADIY TIMOFEEV	{"phone": "+70362119204"}
0005432638948	9D9551	4330 021476	DMITRIY MIKHAYLOV	{"phone": "+70651641197"}
0005432638949	A714E6	3225 235941	SERGEY EGOROV	{"email": "egorov_s-071967@postgrespro.ru", "phone": "+70424615114"}
0005432639066	B7714B	8587 536162	ALINA KISELEVA	{"phone": "+70442941454"}
0005432638950	99F5F9	7433 815048	SEMEN TARASOV	{"email": "s-tarasov.29121978@postgrespro.ru", "phone": "+70240094037"}
0005432638951	EF9E79	6883 917745	ANDREY GRIGOREV	{"email": "grigorev.andrey_27051970@postgrespro.ru", "phone": "+70590258678"}
0005432638952	EF9E79	8370 260092	NINA EGOROVA	{"email": "nina-egorova-16031976@postgrespro.ru", "phone": "+70516976829"}
0005432638953	7B0ECA	8516 681820	PAVEL ZAKHAROV	{"email": "pzakharov_041973@postgrespro.ru", "phone": "+70998726400"}
0005432638954	7B0ECA	5464 353888	SERGEY VASILEV	{"email": "vasilev.sergey_1972@postgrespro.ru", "phone": "+70513925695"}
0005432638955	7B0ECA	6724 922576	YULIYA SEMENOVA	{"phone": "+70073825404"}
0005432638956	792D69	3220 272342	ALEKSANDR KUZNECOV	{"email": "kuznecov.a_26101973@postgrespro.ru", "phone": "+70587076460"}
0005432638957	9E1FBE	3427 202502	SERGEY PAVLOV	{"email": "sergey-pavlov.1965@postgrespro.ru", "phone": "+70955026209"}
0005432638958	9E1FBE	8554 533363	NATALIYA ZAYCEVA	{"email": "zayceva.n.101980@postgrespro.ru", "phone": "+70944792752"}
0005432638959	9E1FBE	8895 412637	TATYANA ROMANOVA	{"email": "romanova.tatyana_1970@postgrespro.ru", "phone": "+70523068386"}
0005432638960	C54782	2274 464016	NATALYA SMIRNOVA	{"phone": "+70607342152"}
0005432638961	4F3051	6260 933406	ARTEM PETROV	{"phone": "+70913886171"}
0005432638962	092325	5538 373217	NIKITA MAKAROV	{"email": "n_makarov.1982@postgrespro.ru", "phone": "+70103655875"}
0005432638963	092325	7859 478343	VERA NIKITINA	{"phone": "+70701686176"}
0005432638964	F54DAA	7811 814439	VYACHESLAV ILIN	{"email": "ilin-vyacheslav1978@postgrespro.ru", "phone": "+70156216013"}
0005432638965	F54DAA	5992 345232	LARISA VOROBEVA	{"phone": "+70912934358"}
0005432638966	4FC747	9183 968728	MATVEY ZAYCEV	{"phone": "+70167448573"}
0005432638967	4FC747	8766 157975	VIKTOR SMIRNOV	{"phone": "+70866890371"}
0005432638968	2C7C37	6265 711135	GLEB GUSEV	{"email": "gleb_gusev_11081975@postgrespro.ru", "phone": "+70126431891"}
0005432638969	8C842D	3878 661222	VLADIMIR MIRONOV	{"email": "vladimir_mironov.01021974@postgrespro.ru", "phone": "+70724552927"}
0005432638970	2BF15F	9178 203769	OLEG GERASIMOV	{"phone": "+70289581882"}
0005432638971	008C21	6932 307300	ARSEN POPOV	{"email": "popovarsen_09121968@postgrespro.ru", "phone": "+70946126270"}
0005432638972	50A999	0735 934450	NIKITA IVANOV	{"phone": "+70292506710"}
0005432638973	6F2A27	6082 001193	ILYA YAKOVLEV	{"email": "ilya-yakovlev_1988@postgrespro.ru", "phone": "+70175802251"}
0005432638974	6F2A27	2125 403640	EVGENIY MELNIKOV	{"email": "melnikov_evgeniy.051967@postgrespro.ru", "phone": "+70700584036"}
0005432638975	5C8235	3382 880683	DMITRIY SEMENOV	{"phone": "+70278040739"}
0005432638976	5C8235	2177 445117	LEONTIY SMIRNOV	{"email": "lsmirnov1977@postgrespro.ru", "phone": "+70979558851"}
0005432638977	5C8235	7680 461193	ANASTASIYA KUDRYASHOVA	{"email": "anastasiya_kudryashova041976@postgrespro.ru", "phone": "+70702455882"}
0005432638978	F9BABB	0919 764893	IVAN VLASOV	{"phone": "+70543958803"}
0005432638979	596AC4	6199 505708	OLGA CHERNOVA	{"email": "o.chernova-11031967@postgrespro.ru", "phone": "+70365851434"}
0005432638980	C88596	3602 738903	RAISA KUZNECOVA	{"email": "r_kuznecova-121975@postgrespro.ru", "phone": "+70600685436"}
0005432638981	D53447	9639 972764	TATYANA FILIPPOVA	{"phone": "+70996173917"}
0005432638982	D53447	0860 466069	SERGEY KUZNECOV	{"phone": "+70993124294"}
0005432638983	437D75	6386 577652	ANATOLIY PAVLOV	{"email": "pavlova-02091976@postgrespro.ru", "phone": "+70191459486"}
0005432638984	437D75	7952 884175	DENIS MIKHAYLOV	{"email": "mikhaylov-d.111965@postgrespro.ru", "phone": "+70984337966"}
0005432638985	C974E7	3897 858464	SVETLANA RODIONOVA	{"phone": "+70218803491"}
0005432638986	C974E7	3378 068140	TATYANA KUZMINA	{"phone": "+70452688368"}
0005432638987	BB859B	8165 829470	ALEKSEY KUZNECOV	{"email": "kuznecov_a-1968@postgrespro.ru", "phone": "+70244679481"}
0005432638988	58A817	7326 410345	NATALYA MIKHAYLOVA	{"email": "mikhaylovan_1978@postgrespro.ru", "phone": "+70959129395"}
0005432638989	9C8E82	9164 744034	NIKOLAY NAZAROV	{"email": "nazarov-nikolay-041976@postgrespro.ru", "phone": "+70928873007"}
0005432638990	D2EF8A	4385 649071	VALENTINA NAZAROVA	{"phone": "+70917110222"}
0005432638991	89955D	5996 906135	YURIY PETROV	{"email": "yuriy.petrov-081977@postgrespro.ru", "phone": "+70911601799"}
0005432638992	CE4AD3	0802 800045	ALEKSANDR ILIN	{"phone": "+70272230840"}
0005432638993	062423	0387 765192	ALEKSANDR SERGEEV	{"phone": "+70888983887"}
0005432638994	144240	3775 134022	FAIL ANTONOV	{"email": "fail_antonov-1965@postgrespro.ru", "phone": "+70557005463"}
0005432638995	144240	3929 722979	ANDREY MEDVEDEV	{"email": "medvedev.a_051974@postgrespro.ru", "phone": "+70933650485"}
0005432638996	80BFD2	4058 011011	ALENA ISAEVA	{"email": "isaeva-a.17051969@postgrespro.ru", "phone": "+70895281139"}
0005432638997	C56212	0155 652761	GALINA MASLOVA	{"email": "g.maslova-121966@postgrespro.ru", "phone": "+70048921935"}
0005432638998	C56212	6799 068360	LIDIYA YAKOVLEVA	{"phone": "+70474929338"}
0005432638999	85DBA6	8237 924730	OLGA VOLKOVA	{"email": "o.volkova.19081976@postgrespro.ru", "phone": "+70039215723"}
0005432639000	2D2D5D	6200 333032	EVGENIY MATVEEV	{"email": "ematveev111970@postgrespro.ru", "phone": "+70878483074"}
0005432639001	BC0A4F	7965 935293	OKSANA VASILEVA	{"phone": "+70112711864"}
0005432639002	4BAD80	1787 073474	IRINA POPOVA	{"email": "i-popova-1963@postgrespro.ru", "phone": "+70248280742"}
0005432639003	7267E8	9531 303522	PRASKOVYA KUZNECOVA	{"email": "kuznecova-p021964@postgrespro.ru", "phone": "+70978565898"}
0005432639004	7267E8	0677 243187	IRINA IVANOVA	{"phone": "+70868547858"}
0005432639005	0A9ACE	3696 744735	VYACHESLAV DMITRIEV	{"email": "vyacheslav.dmitriev_1964@postgrespro.ru", "phone": "+70882468394"}
0005432639006	0A9ACE	8766 514269	ILGIZ GERASIMOV	{"email": "i_gerasimov_1974@postgrespro.ru", "phone": "+70520499436"}
0005432639007	0A9ACE	6875 676166	YURIY DENISOV	{"email": "denisov_yuriy111970@postgrespro.ru", "phone": "+70303681131"}
0005432639008	D1AF10	9622 546722	FEDOR NAZAROV	{"email": "fedor-nazarov071984@postgrespro.ru", "phone": "+70639535020"}
0005432639009	294AE9	0363 295132	NIKITA KAZAKOV	{"phone": "+70188898298"}
0005432639010	1A0B11	3351 842348	SERGEY OSIPOV	{"email": "s.osipov-15041976@postgrespro.ru", "phone": "+70266993255"}
0005432639011	55C5FC	4895 874077	DAMIR DENISOV	{"email": "d-denisov.1977@postgrespro.ru", "phone": "+70058046891"}
0005432639012	84B21A	1249 944422	VLADIMIR TIKHONOV	{"email": "tikhonov_vladimir25021969@postgrespro.ru", "phone": "+70475705277"}
0005432639013	84B21A	9352 679785	ANDREY BARANOV	{"phone": "+70625695721"}
0005432639014	A1741D	6373 137472	ALLA FEDOROVA	{"phone": "+70501883165"}
0005432639015	C4E971	1343 206902	SERGEY IVANOV	{"email": "ivanov_s-29101965@postgrespro.ru", "phone": "+70515681782"}
0005432639016	C4E971	6655 921467	ELENA CHERNOVA	{"email": "e_chernova-27041973@postgrespro.ru", "phone": "+70290652110"}
0005432639017	B2914A	8114 750721	SERGEY VOROBEV	{"email": "sergey-vorobev.081973@postgrespro.ru", "phone": "+70613911654"}
0005432639018	B2914A	4744 285504	YULIYA TIKHONOVA	{"phone": "+70616841823"}
0005432639019	4FD5DC	3659 344473	VALENTINA IVANOVA	{"email": "ivanova_valentina041975@postgrespro.ru", "phone": "+70700783086"}
0005432639020	8121D4	0690 536701	EKATERINA ZAYCEVA	{"phone": "+70486295478"}
0005432639021	F600C8	5815 477304	ALEKSANDR DENISOV	{"phone": "+70310004423"}
0005432639022	76938D	4850 132272	ALEKSANDR ZAYCEV	{"phone": "+70785326552"}
0005432639023	4B0931	4150 221617	STANISLAV PETROV	{"email": "petrov.stanislav_061984@postgrespro.ru", "phone": "+70191650099"}
0005432639024	5E3BBB	0763 422904	MAKSIM MEDVEDEV	{"email": "m.medvedev.1973@postgrespro.ru", "phone": "+70891924122"}
0005432639025	3E59BB	3347 787272	VALENTINA BOGDANOVA	{"email": "valentina.bogdanova111969@postgrespro.ru", "phone": "+70379549968"}
0005432639026	C2E568	3875 699950	EGOR IVANOV	{"email": "ivanov.egor-111977@postgrespro.ru", "phone": "+70711972475"}
0005432639027	B24D71	0536 889010	DMITRIY ABRAMOV	{"email": "abramov-d_091976@postgrespro.ru", "phone": "+70719467174"}
0005432639028	89B5C7	0713 759551	RAISA VASILEVA	{"phone": "+70379140830"}
0005432639029	1FD5C2	3493 186190	OKSANA FILIPPOVA	{"email": "ofilippova.1961@postgrespro.ru", "phone": "+70426885086"}
0005432639030	F6CE9C	6203 530851	NIKOLAY MAKAROV	{"email": "n_makarov.011993@postgrespro.ru", "phone": "+70123405049"}
0005432639031	F3E0AF	3782 522194	YURIY KUZMIN	{"phone": "+70179208177"}
0005432639032	404D4E	8890 575206	ELENA SEMENOVA	{"email": "semenova.elena_1977@postgrespro.ru", "phone": "+70790979710"}
0005432639033	FFE376	8803 512313	ALLA MAKSIMOVA	{"email": "maksimova.a_061984@postgrespro.ru", "phone": "+70791600064"}
0005432639034	1CAF28	6510 041554	SVETLANA SIDOROVA	{"email": "s.sidorova04091967@postgrespro.ru", "phone": "+70154786452"}
0005432639035	6B47EF	4305 362538	OLESYA ZHUKOVA	{"email": "ozhukova-1970@postgrespro.ru", "phone": "+70489092259"}
0005432639036	B83507	4993 712217	NIKOLAY MARTYNOV	{"phone": "+70068116511"}
0005432639037	B83507	8362 870462	VYACHESLAV BORISOV	{"phone": "+70822877919"}
0005432639038	B83507	6477 839628	ANNA KUZMINA	{"phone": "+70736199008"}
0005432639039	E41F94	6244 130775	LEV PAVLOV	{"email": "pavlovlev_08121980@postgrespro.ru", "phone": "+70630980744"}
0005432639040	E41F94	1768 991218	NADEZHDA EGOROVA	{"email": "egorova.n_101978@postgrespro.ru", "phone": "+70675468138"}
0005432639041	63EA5C	3521 013854	ANNA DANILOVA	{"email": "anna_danilova_22061972@postgrespro.ru", "phone": "+70201546245"}
0005432639042	C1F984	9745 631106	ANNA IVANOVA	{"phone": "+70547156997"}
0005432639043	C1F984	9045 321542	ALEKSANDRA GAVRILOVA	{"email": "gavrilova_aleksandra-121971@postgrespro.ru", "phone": "+70219799662"}
0005432639044	2C6638	8437 055512	VARVARA DENISOVA	{"email": "denisova.v_1968@postgrespro.ru", "phone": "+70057725014"}
0005432639045	BDA2C0	7428 787737	VLADIMIR SEMENOV	{"email": "v-semenov-11041966@postgrespro.ru", "phone": "+70889982629"}
0005432639046	1FD622	0451 289776	SERGEY ABRAMOV	{"phone": "+70449344573"}
0005432639047	1FD622	8005 181540	SERGEY MARTYNOV	{"email": "martynov.sergey1967@postgrespro.ru", "phone": "+70413947851"}
0005432639048	D54A7B	2265 582613	YULIYA SAVELEVA	{"email": "savelevayuliya.1975@postgrespro.ru", "phone": "+70302769204"}
0005432639049	DFA36B	9642 186899	ALFIYA CHERNOVA	{"email": "alfiya.chernova_071976@postgrespro.ru", "phone": "+70384666372"}
0005432639050	E44DE0	9353 641844	OLGA SERGEEVA	{"email": "sergeevao-011980@postgrespro.ru", "phone": "+70411549073"}
0005432639051	E44DE0	3152 230899	ALEKSEY VASILEV	{"email": "aleksey-vasilev.12051970@postgrespro.ru", "phone": "+70261040100"}
0005432639052	E44DE0	5060 023275	VALENTINA VASILEVA	{"phone": "+70286624016"}
0005432639053	2F5324	4559 641141	VASILIY ANDREEV	{"email": "vandreev111961@postgrespro.ru", "phone": "+70799598565"}
0005432639054	2F5324	9574 872521	SVETLANA TARASOVA	{"phone": "+70747803645"}
0005432639055	32BDBA	5701 482398	MARINA NESTEROVA	{"phone": "+70496366068"}
0005432639056	32BDBA	8724 543046	VLADIMIR POPOV	{"phone": "+70083244298"}
0005432639057	32BDBA	9657 768823	DARYA NESTEROVA	{"email": "dnesterova.1979@postgrespro.ru", "phone": "+70819897929"}
0005432639058	71EA9A	8908 313204	VLADIMIR FEDOROV	{"phone": "+70450807625"}
0005432639059	71EA9A	4155 647823	IRINA KUZNECOVA	{"email": "i.kuznecova_07021982@postgrespro.ru", "phone": "+70344716546"}
0005432639060	BA2A99	8162 291499	ANDREY KUZMIN	{"email": "andrey.kuzmin-111983@postgrespro.ru", "phone": "+70737946144"}
0005432639061	972782	2809 815026	IRINA NIKOLAEVA	{"email": "irina-nikolaeva.27051970@postgrespro.ru", "phone": "+70390074754"}
0005432639062	FAF97F	1892 236158	ALEKSEY POPOV	{"email": "aleksey-popov.101975@postgrespro.ru", "phone": "+70665214819"}
0005432639063	215458	4975 081711	TIMOFEY SOKOLOV	{"phone": "+70667020061"}
0005432639064	31B5DA	7918 217920	EKATERINA FADEEVA	{"phone": "+70323646463"}
0005432639065	31B5DA	9504 786903	ALENA DENISOVA	{"email": "a-denisova-061973@postgrespro.ru", "phone": "+70335306012"}
0005432639067	D800B2	9085 581445	DENIS STEPANOV	{"email": "stepanov_denis1984@postgrespro.ru", "phone": "+70235273138"}
0005432639068	9DF011	3932 030264	ANASTASIYA ZHURAVLEVA	{"email": "zhuravleva.a1975@postgrespro.ru", "phone": "+70647167176"}
0005432639069	9DF011	6286 893873	MARIYA ANISIMOVA	{"phone": "+70988318436"}
0005432639070	3007C8	3180 376076	ANNA SMIRNOVA	{"phone": "+70033032830"}
0005432639071	CE34EA	5311 415888	TATYANA RYABOVA	{"phone": "+70267056787"}
0005432639072	C32A30	6003 900447	ELENA ANDREEVA	{"phone": "+70278763613"}
0005432639073	E28F29	7545 736688	SERGEY DAVYDOV	{"phone": "+70031833750"}
0005432639074	E28F29	8407 709598	SERGEY YAKOVLEV	{"email": "s-yakovlev.1973@postgrespro.ru", "phone": "+70383583687"}
0005432639185	19535B	8991 812677	ALEKSANDR ABRAMOV	{"phone": "+70608314523"}
0005432639075	875927	4247 122006	ALEKSANDRA MELNIKOVA	{"email": "aleksandra_melnikova01051969@postgrespro.ru", "phone": "+70749945400"}
0005432639076	9BC752	1123 743301	LYUBOV KULIKOVA	{"phone": "+70831868494"}
0005432639077	9BC752	4590 214892	YULIYA LAZAREVA	{"email": "yuliya.lazareva_011979@postgrespro.ru", "phone": "+70657742455"}
0005432639078	BE55DB	5173 011851	VLADISLAV ISAEV	{"phone": "+70606481683"}
0005432639079	A3A891	2607 981538	ELENA POLYAKOVA	{"email": "epolyakova_1960@postgrespro.ru", "phone": "+70768968733"}
0005432639080	A3A891	1031 328933	VIKTORIYA PAVLOVA	{"email": "vpavlova.071975@postgrespro.ru", "phone": "+70737198037"}
0005432639081	2DEE03	3004 451295	DARYA KULIKOVA	{"email": "kulikova.darya.12081976@postgrespro.ru", "phone": "+70190210893"}
0005432639082	1F55CA	0513 993482	ALFIYA FROLOVA	{"email": "a_frolova_1971@postgrespro.ru", "phone": "+70101509908"}
0005432639083	0209D8	6552 828534	RUSLAN GERASIMOV	{"email": "gerasimovruslan051973@postgrespro.ru", "phone": "+70824167226"}
0005432639084	5CF502	7820 716520	VLADISLAV FROLOV	{"email": "vladislav_frolov-24041967@postgrespro.ru", "phone": "+70662789417"}
0005432639085	9C2223	6697 517912	ANTON GAVRILOV	{"phone": "+70869860447"}
0005432639086	BB699A	0533 185362	ALEKSANDRA OSIPOVA	{"email": "osipova_aleksandra081964@postgrespro.ru", "phone": "+70240542873"}
0005432639087	BB699A	2346 576848	MARIYA AKIMOVA	{"phone": "+70919374283"}
0005432639088	EC24FC	0390 180954	NATALIYA KUZNECOVA	{"phone": "+70898160748"}
0005432639089	587CE3	4594 871304	LYUDMILA ALEKSEEVA	{"phone": "+70362469624"}
0005432639090	FDAF60	7945 267977	EKATERINA DANILOVA	{"phone": "+70177193498"}
0005432639091	FDAF60	4307 262168	EVGENIYA RODIONOVA	{"phone": "+70182305076"}
0005432639092	C61AFA	6335 262670	NINA ANDREEVA	{"email": "andreeva.n-1972@postgrespro.ru", "phone": "+70549224390"}
0005432639093	165CF7	3074 425157	DENIS KUZNECOV	{"email": "kuznecovd_23021984@postgrespro.ru", "phone": "+70064948667"}
0005432639094	EF9BD4	2276 661807	TATYANA GERASIMOVA	{"email": "gerasimova-tatyana_041975@postgrespro.ru", "phone": "+70025083369"}
0005432639095	EF9BD4	6469 414796	ANASTASIYA TIMOFEEVA	{"email": "timofeevaanastasiya-081976@postgrespro.ru", "phone": "+70104694582"}
0005432639096	EF9BD4	3739 334821	DMITRIY MAKAROV	{"email": "dmakarov_1968@postgrespro.ru", "phone": "+70106622858"}
0005432639097	7ACF1C	9987 626581	SERGEY ZAYCEV	{"email": "zaycev.sergey-051970@postgrespro.ru", "phone": "+70979929904"}
0005432639098	F066E2	0581 356008	KRISTINA GUSEVA	{"email": "k.guseva.1980@postgrespro.ru", "phone": "+70982489874"}
0005432639099	F066E2	2652 715250	OLGA ISAEVA	{"email": "olga.isaeva_021969@postgrespro.ru", "phone": "+70718388817"}
0005432639100	57D6F9	7832 218084	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev_111966@postgrespro.ru", "phone": "+70157336029"}
0005432639101	708A27	1919 177014	SERGEY KAZAKOV	{"email": "kazakovsergey28041963@postgrespro.ru", "phone": "+70915607345"}
0005432639102	1B82BF	2028 612918	IRINA DMITRIEVA	{"email": "dmitrieva_i101972@postgrespro.ru", "phone": "+70828110230"}
0005432639103	67C3C7	6106 221182	VERA KRASNOVA	{"phone": "+70944810782"}
0005432639104	67C3C7	6438 408148	LYUBOV IVANOVA	{"email": "lyubovivanova.1966@postgrespro.ru", "phone": "+70936588713"}
0005432639105	1DC3AD	5175 711259	VIKTOR IVANOV	{"email": "ivanov.viktor15051976@postgrespro.ru", "phone": "+70324597927"}
0005432639106	9F423D	9366 533280	TATYANA NAZAROVA	{"email": "tatyana_nazarova_071966@postgrespro.ru", "phone": "+70046200746"}
0005432639107	2FFD17	2758 448580	IRINA MELNIKOVA	{"email": "imelnikova_1978@postgrespro.ru", "phone": "+70691855080"}
0005432639108	2FFD17	6846 464646	ANTON MEDVEDEV	{"phone": "+70381018173"}
0005432639109	2FFD17	3638 903056	FAINA ROMANOVA	{"phone": "+70332753836"}
0005432639110	7F49A7	9211 149291	SVETLANA POTAPOVA	{"email": "potapovasvetlana-1967@postgrespro.ru", "phone": "+70103843416"}
0005432639111	A87812	3620 803154	ALFIYA FOMINA	{"phone": "+70703671310"}
0005432639112	A87812	2235 076678	IVAN MOISEEV	{"phone": "+70659711959"}
0005432639113	07365B	1141 358303	DARYA AFANASEVA	{"email": "afanasevadarya_1971@postgrespro.ru", "phone": "+70149705009"}
0005432639114	07365B	7656 216984	KIRA NOVIKOVA	{"email": "kiranovikova.011972@postgrespro.ru", "phone": "+70530871682"}
0005432639115	8D444A	5951 567961	KSENIYA NOVIKOVA	{"email": "kseniyanovikova.081972@postgrespro.ru", "phone": "+70453255116"}
0005432639116	8D444A	1618 962109	IGOR ALEKSANDROV	{"email": "igoraleksandrov27061968@postgrespro.ru", "phone": "+70198495358"}
0005432639117	53910B	7928 394658	MARIANNA DMITRIEVA	{"phone": "+70794627258"}
0005432639118	21F3E1	8683 988177	SERGEY ZAKHAROV	{"phone": "+70410561837"}
0005432639119	21F3E1	9191 219421	ZOYA NAUMOVA	{"phone": "+70287756707"}
0005432639120	5CBF94	5743 475261	ELENA POTAPOVA	{"email": "potapovaelena-051966@postgrespro.ru", "phone": "+70686999337"}
0005432639121	5CBF94	8576 473046	VITALIY SMIRNOV	{"email": "v-smirnov-1973@postgrespro.ru", "phone": "+70251731545"}
0005432639122	A9B667	3230 028763	ELENA FEDOROVA	{"phone": "+70132448619"}
0005432639123	C2D262	5144 979827	SERGEY SEMENOV	{"email": "semenov.s111981@postgrespro.ru", "phone": "+70928579800"}
0005432639124	7D62D2	8908 691798	LARISA NAZAROVA	{"email": "nazaroval.17021955@postgrespro.ru", "phone": "+70385732849"}
0005432639125	CAF1F2	5596 417831	OLGA BORISOVA	{"email": "borisova-o22021980@postgrespro.ru", "phone": "+70907505361"}
0005432639126	AC0622	5544 645256	ELENA IVANOVA	{"email": "ivanovae1968@postgrespro.ru", "phone": "+70752664907"}
0005432639127	AC0622	1144 193289	ANDREY KUZMIN	{"email": "kuzmin_andrey.1971@postgrespro.ru", "phone": "+70461359999"}
0005432639128	37A30D	1298 834586	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov.1974@postgrespro.ru", "phone": "+70875364857"}
0005432639129	2D5EF2	9176 875994	OLGA VOLKOVA	{"email": "volkova-o.031974@postgrespro.ru", "phone": "+70763224057"}
0005432639130	2D5EF2	1633 739936	VALENTINA NOVIKOVA	{"phone": "+70616156777"}
0005432639131	2D5EF2	5801 410554	TATYANA KONOVALOVA	{"phone": "+70341166928"}
0005432639132	37D6A1	9461 213806	TAMARA YUDINA	{"phone": "+70816743140"}
0005432639133	2B1F12	6984 753244	YURIY BARANOV	{"email": "baranov-yuriy.18111973@postgrespro.ru", "phone": "+70580769376"}
0005432639134	28A3B3	1507 824833	SERGEY IVANOV	{"email": "sergeyivanov-1970@postgrespro.ru", "phone": "+70521778772"}
0005432639135	6F6AB1	0301 977495	ANASTASIYA KUZNECOVA	{"phone": "+70270028460"}
0005432639136	B3DA05	9167 203348	SVETLANA SAVELEVA	{"email": "svetlana_saveleva-03071973@postgrespro.ru", "phone": "+70659439421"}
0005432639137	CA68EB	8761 242749	ANNA GUSEVA	{"email": "guseva-a.031969@postgrespro.ru", "phone": "+70049767199"}
0005432639138	CA68EB	3585 890877	VALERIY ANTONOV	{"email": "valeriyantonov_07111969@postgrespro.ru", "phone": "+70970217369"}
0005432639139	E3BBF4	9552 343075	SVETLANA IVANOVA	{"email": "ivanovasvetlana_1963@postgrespro.ru", "phone": "+70467491264"}
0005432639140	BF1574	5035 501274	ALENA ALEKSEEVA	{"email": "alenaalekseeva.02091977@postgrespro.ru", "phone": "+70275117596"}
0005432639141	BF1574	0089 408764	RUSLAN BORISOV	{"email": "borisovruslan.1969@postgrespro.ru", "phone": "+70410721889"}
0005432639200	929827	1273 252163	EVGENIYA SEMENOVA	{"phone": "+70350187291"}
0005432639142	0CDF43	6169 690089	VYACHESLAV RODIONOV	{"email": "v.rodionov-111970@postgrespro.ru", "phone": "+70185710808"}
0005432639143	B5E077	2617 975610	NATALIYA MARTYNOVA	{"email": "nataliya-martynova.22121978@postgrespro.ru", "phone": "+70965780627"}
0005432639144	4679EA	2920 275066	VLADIMIR MOISEEV	{"phone": "+70298120148"}
0005432639145	4679EA	6441 572984	VYACHESLAV SMIRNOV	{"email": "v-smirnov-011981@postgrespro.ru", "phone": "+70994882261"}
0005432639146	9E8DEB	8975 337582	ALINA DMITRIEVA	{"phone": "+70733042387"}
0005432639147	2A0408	7591 962205	ILYA BELOV	{"email": "belov-ilya.1982@postgrespro.ru", "phone": "+70280299957"}
0005432639148	109633	6729 127948	PETR KUZNECOV	{"phone": "+70826200226"}
0005432639149	C5A5F7	2240 154735	GALINA ERMAKOVA	{"email": "ermakova.galina-18051976@postgrespro.ru", "phone": "+70695513467"}
0005432639150	C5A5F7	6613 272794	GALINA KALININA	{"phone": "+70586335519"}
0005432639151	5CF267	3963 381280	TAMARA KARPOVA	{"phone": "+70922855057"}
0005432639152	66934F	1441 114584	IRINA ZHURAVLEVA	{"email": "irina.zhuravleva.1965@postgrespro.ru", "phone": "+70319020706"}
0005432639153	66934F	4182 970899	VLADIMIR ILIN	{"email": "vladimir-ilin19071980@postgrespro.ru", "phone": "+70563556197"}
0005432639154	C4863F	0131 723539	MARINA POTAPOVA	{"phone": "+70576416003"}
0005432639155	C4863F	5421 208607	DARYA MIRONOVA	{"phone": "+70423443305"}
0005432639156	C4863F	9637 912457	DANILA KUZNECOV	{"phone": "+70630002380"}
0005432639157	D466DC	5644 568280	ANNA ZAKHAROVA	{"email": "zakharova-anna-11101981@postgrespro.ru", "phone": "+70815510415"}
0005432639158	D466DC	7748 999846	NADEZHDA MIRONOVA	{"email": "mironova.n011972@postgrespro.ru", "phone": "+70258931756"}
0005432639159	0C393F	3736 924183	NIKOLAY PAVLOV	{"email": "pavlov-nikolay_19111975@postgrespro.ru", "phone": "+70172180802"}
0005432639160	0C393F	2166 572953	EMIL KISELEV	{"email": "emil-kiselev.1971@postgrespro.ru", "phone": "+70597946457"}
0005432639161	EF0370	0911 545812	ELENA VASILEVA	{"email": "vasileva-elena.1973@postgrespro.ru", "phone": "+70170544899"}
0005432639162	7D3BDA	0338 636792	NADEZHDA FILIPPOVA	{"email": "n.filippova.11031972@postgrespro.ru", "phone": "+70146465087"}
0005432639163	4488BA	0424 950551	NURLAN SOKOLOV	{"phone": "+70970922390"}
0005432639164	4488BA	6977 339774	LILIYA ZHUKOVA	{"phone": "+70874719486"}
0005432639165	5AA1DB	9159 087501	OLGA KUZNECOVA	{"phone": "+70047548042"}
0005432639166	5AA1DB	9273 971115	VLADIMIR IVANOV	{"email": "ivanovv081974@postgrespro.ru", "phone": "+70977794898"}
0005432639167	5AA1DB	3836 228847	MARIYA KOMAROVA	{"phone": "+70979498702"}
0005432639168	A4651B	3668 317631	DENIS MIRONOV	{"phone": "+70434981086"}
0005432639169	DA93AB	0319 239738	ALEKSANDRA ZHUKOVA	{"phone": "+70590488602"}
0005432639170	B0FF8D	4923 499218	VIKTOR ABRAMOV	{"phone": "+70709042916"}
0005432639171	B0FF8D	8014 237035	VADIM CHERNOV	{"phone": "+70004956654"}
0005432639172	58BB67	3150 238800	ANTON DMITRIEV	{"email": "a_dmitriev1973@postgrespro.ru", "phone": "+70099993883"}
0005432639173	36BD25	2525 728331	KSENIYA FILATOVA	{"email": "filatova_k.22041977@postgrespro.ru", "phone": "+70246846745"}
0005432639174	36BD25	8562 692239	MARK MAKAROV	{"phone": "+70371178295"}
0005432639175	6CF883	5147 238443	ANASTASIYA GRISHINA	{"email": "grishina.a1973@postgrespro.ru", "phone": "+70043315547"}
0005432639176	23E1F6	9246 351108	SERGEY GRIGOREV	{"email": "grigorev.sergey_051974@postgrespro.ru", "phone": "+70369825496"}
0005432639177	9583DE	1148 244694	OLGA VASILEVA	{"phone": "+70733864786"}
0005432639178	7FD766	1327 782320	SERGEY ILIN	{"phone": "+70555502189"}
0005432639179	E35476	7353 130128	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana-1964@postgrespro.ru", "phone": "+70124161407"}
0005432639180	E35476	9659 275081	IVAN KOROLEV	{"email": "korolev_ivan-02081978@postgrespro.ru", "phone": "+70943292841"}
0005432639181	F58E1B	1115 634745	SERGEY KUZMIN	{"phone": "+70899886181"}
0005432639182	F58E1B	2055 420344	ARTEM STEPANOV	{"phone": "+70916312167"}
0005432639183	38ED41	0528 925475	MARINA MIKHAYLOVA	{"phone": "+70258444044"}
0005432639184	38ED41	1505 783401	VITALIY KOROLEV	{"phone": "+70671232903"}
0005432639186	0E40F2	5010 624464	VASILIY ROMANOV	{"email": "v-romanov.1972@postgrespro.ru", "phone": "+70343195689"}
0005432639187	EC4782	3011 349115	RAVZA VOROBEVA	{"phone": "+70089613639"}
0005432639188	B1C2C1	5090 059439	YULIYA MARTYNOVA	{"phone": "+70550061219"}
0005432639189	91A6E4	6325 607563	ANDREY TIMOFEEV	{"email": "atimofeev011970@postgrespro.ru", "phone": "+70483862302"}
0005432639190	91A6E4	6403 762233	KONSTANTIN DMITRIEV	{"phone": "+70382778294"}
0005432639191	C81CB3	7849 533581	OLEG DAVYDOV	{"phone": "+70944257928"}
0005432639192	C81CB3	3163 330783	VLADIMIR KAZAKOV	{"phone": "+70472081430"}
0005432639193	FB7648	2866 137476	VALENTINA NAZAROVA	{"email": "nazarova_v101962@postgrespro.ru", "phone": "+70473915822"}
0005432639194	1222A7	0335 931425	GULSINA ZAYCEVA	{"phone": "+70303998825"}
0005432639195	A66324	8851 604031	SVETLANA MOROZOVA	{"phone": "+70400636426"}
0005432639196	F26F51	0225 995141	SVETLANA LEBEDEVA	{"email": "svetlanalebedeva_1966@postgrespro.ru", "phone": "+70433013236"}
0005432639197	F26F51	6948 888644	IRINA MEDVEDEVA	{"phone": "+70530581305"}
0005432639198	CA5567	9785 847571	IGOR POPOV	{"phone": "+70647313621"}
0005432639199	929827	2587 065300	GENNADIY GUSEV	{"email": "g.gusev-021982@postgrespro.ru", "phone": "+70019875015"}
0005432639201	1E6359	6439 058120	PAVEL YAKOVLEV	{"phone": "+70780152812"}
0005432639202	3A1A4D	1984 167471	IRINA MELNIKOVA	{"email": "melnikovairina1980@postgrespro.ru", "phone": "+70790593388"}
0005432639203	CE16C4	2607 975960	BOGDAN TIMOFEEV	{"email": "timofeevbogdan.1965@postgrespro.ru", "phone": "+70468940580"}
0005432639204	57E690	6906 898376	LIDIYA FEDOROVA	{"phone": "+70691134976"}
0005432639205	743C7F	4686 477241	EVGENIY KUZMIN	{"email": "ekuzmin_071949@postgrespro.ru", "phone": "+70664343537"}
0005432639206	EE1DB7	7391 638355	VLADIMIR KOZLOV	{"phone": "+70509639708"}
0005432639207	EE1DB7	5024 554795	SOFIYA ZHURAVLEVA	{"email": "s.zhuravleva_19111961@postgrespro.ru", "phone": "+70674851333"}
0005432639208	F4BF99	5632 143264	ANDREY ZAKHAROV	{"email": "a-zakharov_081982@postgrespro.ru", "phone": "+70362510282"}
0005432639209	D89DDA	4356 810579	TATYANA MAKAROVA	{"phone": "+70794688955"}
0005432639210	2B0616	4513 404639	LYUBOV BOGDANOVA	{"email": "lbogdanova_16051975@postgrespro.ru", "phone": "+70480057538"}
0005432639211	65AC1F	3788 363315	ALEKSANDR MATVEEV	{"phone": "+70046994961"}
0005432639212	D6065A	2294 120995	SVETLANA IVANOVA	{"email": "s.ivanova-15041982@postgrespro.ru", "phone": "+70793542415"}
0005432639213	734141	3309 491945	EGOR IVANOV	{"email": "eivanov.101985@postgrespro.ru", "phone": "+70696962729"}
0005432639214	5C0C74	1935 269365	ZINAIDA ZAKHAROVA	{"email": "zzakharova_021979@postgrespro.ru", "phone": "+70039632369"}
0005432639215	17BB6E	6685 400251	GALINA NESTEROVA	{"email": "galinanesterova-031970@postgrespro.ru", "phone": "+70739477832"}
0005432639216	144332	4909 010813	IGOR AFANASEV	{"email": "i-afanasev1969@postgrespro.ru", "phone": "+70925140336"}
0005432639217	144332	9011 727052	TIGRAN KUZNECOV	{"email": "t.kuznecov_26071965@postgrespro.ru", "phone": "+70057400055"}
0005432639218	8BA7DE	0074 945541	IRINA MIRONOVA	{"phone": "+70455929592"}
0005432639219	8BA7DE	1291 587051	NINA KOZLOVA	{"email": "n-kozlova-1971@postgrespro.ru", "phone": "+70704441048"}
0005432639220	9DD7B8	2026 594160	OKSANA KALININA	{"phone": "+70369390413"}
0005432639221	1A0B70	1016 106565	SVETLANA IVANOVA	{"email": "svetlana-ivanova_1973@postgrespro.ru", "phone": "+70801321477"}
0005432639222	9C01CF	4279 726499	SVETLANA BELYAEVA	{"phone": "+70410223680"}
0005432639223	9C01CF	7305 001214	IRINA NIKITINA	{"email": "i_nikitina.06071970@postgrespro.ru", "phone": "+70803563205"}
0005432639224	9C01CF	0704 367788	ANTON MOISEEV	{"email": "a-moiseev.091963@postgrespro.ru", "phone": "+70935815922"}
0005432639225	9C01CF	1336 093802	SERGEY ILIN	{"email": "ilin_s1970@postgrespro.ru", "phone": "+70905327751"}
0005432639226	3E5129	6317 221855	IRINA YUDINA	{"phone": "+70156139984"}
0005432639227	16A3DA	2208 736209	VERA KAZAKOVA	{"phone": "+70401349482"}
0005432639228	16A3DA	3049 246136	SERGEY KUZMIN	{"phone": "+70610273615"}
0005432639229	8EB655	9345 282691	STANISLAV SIDOROV	{"phone": "+70873868467"}
0005432639230	CA1F2F	8021 714125	ALEKSANDR PETROV	{"phone": "+70680218500"}
0005432639231	5F2CC3	3899 227291	NAILYA KOROLEVA	{"email": "nailya_koroleva_1976@postgrespro.ru", "phone": "+70926592656"}
0005432639232	E75DBE	6174 075146	EVGENIY NIKITIN	{"email": "nikitin-evgeniy011988@postgrespro.ru", "phone": "+70517028428"}
0005432639233	E75DBE	4933 717749	FEDOR ZAKHAROV	{"phone": "+70320021437"}
0005432639234	9A081E	1118 346121	YURIY EGOROV	{"email": "egorovyuriy011978@postgrespro.ru", "phone": "+70351031165"}
0005432639235	9A081E	9314 145737	DMITRIY SHEVCHENKO	{"email": "shevchenko.dmitriy111972@postgrespro.ru", "phone": "+70184472682"}
0005432639236	9A081E	2507 456096	VIKTOR MEDVEDEV	{"phone": "+70348534034"}
0005432639237	EBAC6F	8827 266297	MARINA BORISOVA	{"email": "borisova-m-1971@postgrespro.ru", "phone": "+70814706206"}
0005432639238	EBAC6F	5857 436591	INNA SOLOVEVA	{"email": "soloveva_inna_081971@postgrespro.ru", "phone": "+70582315106"}
0005432639239	9B8B73	5015 283342	SERGEY TIMOFEEV	{"phone": "+70406775373"}
0005432639240	9B8B73	5813 748652	SEMEN SOKOLOV	{"phone": "+70501408291"}
0005432639241	0924C7	5844 495049	VERA KONOVALOVA	{"phone": "+70796787781"}
0005432639242	EE7104	8773 797087	LIDIYA SOROKINA	{"email": "sorokina_lidiya-20101975@postgrespro.ru", "phone": "+70858194409"}
0005432639243	7A680E	5932 619405	SERGEY KONOVALOV	{"email": "skonovalov.14071965@postgrespro.ru", "phone": "+70456859335"}
0005432639244	7A680E	8031 701365	SVETLANA EFREMOVA	{"email": "efremovas-11081979@postgrespro.ru", "phone": "+70975758695"}
0005432639245	1433A8	7443 327249	EVGENIY ZHURAVLEV	{"phone": "+70341305337"}
0005432639246	5BECBE	9261 333475	SERGEY ZHURAVLEV	{"email": "zhuravlev_sergey-26021966@postgrespro.ru", "phone": "+70634506517"}
0005432639247	1CBEEB	7302 949816	NATALYA IVANOVA	{"email": "ivanova.natalya.14081974@postgrespro.ru", "phone": "+70629299957"}
0005432639248	671946	7980 679655	KRISTINA DMITRIEVA	{"email": "dmitrievakristina-111961@postgrespro.ru", "phone": "+70460672719"}
0005432639249	671946	0920 685096	VALERIY SHEVCHENKO	{"email": "valeriyshevchenko-121970@postgrespro.ru", "phone": "+70651027986"}
0005432639250	8275CE	2512 487369	OLGA CHERNOVA	{"phone": "+70156427096"}
0005432639251	05EECE	7723 174784	SERGEY DMITRIEV	{"phone": "+70035654846"}
0005432639252	05EECE	2258 822299	SERGEY MAKSIMOV	{"email": "maksimovs11111983@postgrespro.ru", "phone": "+70278243392"}
0005432639253	92CB60	0922 679869	MARIYA GAVRILOVA	{"email": "gavrilova.m_1971@postgrespro.ru", "phone": "+70501694914"}
0005432639254	97CB77	6051 905425	YULIYA ZAYCEVA	{"phone": "+70645951699"}
0005432639255	B3CAF0	1526 764035	KARINA ZHURAVLEVA	{"phone": "+70298155317"}
0005432639368	83C0B7	8293 703297	VYACHESLAV GERASIMOV	{"phone": "+70095543822"}
0005432639256	223C91	8956 274948	ANDREY KUZNECOV	{"email": "andrey.kuznecov-15061969@postgrespro.ru", "phone": "+70975322848"}
0005432639257	223C91	2828 864194	NATALYA DMITRIEVA	{"phone": "+70710991557"}
0005432639258	E79ED2	4340 976950	VERA PETROVA	{"phone": "+70082705748"}
0005432639259	E79ED2	9696 462488	OLGA FROLOVA	{"email": "o_frolova_1974@postgrespro.ru", "phone": "+70624381994"}
0005432639260	55C78E	5151 840354	SERGEY MATVEEV	{"email": "matveevs_1980@postgrespro.ru", "phone": "+70705188448"}
0005432639261	69787B	9221 704532	ANTONIDA DAVYDOVA	{"email": "a-davydova1965@postgrespro.ru", "phone": "+70736464563"}
0005432639262	EEB8EF	5079 438289	DMITRIY IVANOV	{"email": "dmitriy_ivanov.1965@postgrespro.ru", "phone": "+70923456239"}
0005432639263	EEB8EF	6893 765493	EVELINA LOGINOVA	{"phone": "+70847546963"}
0005432639264	C1610D	1503 462745	OLGA IVANOVA	{"phone": "+70716380100"}
0005432639265	8F990F	6793 914822	NIKOLAY ZAKHAROV	{"email": "zakharovn-061961@postgrespro.ru", "phone": "+70809657362"}
0005432639266	8F990F	6920 442102	EGOR KAZAKOV	{"phone": "+70159208251"}
0005432639267	C3A5E5	0086 300922	OLGA NOVIKOVA	{"phone": "+70679594200"}
0005432639268	C3A5E5	9439 327896	VIKTOR FEDOTOV	{"email": "fedotovv_1973@postgrespro.ru", "phone": "+70938976875"}
0005432639269	91F373	3374 974780	VASILIY MATVEEV	{"email": "matveevvasiliy.20081977@postgrespro.ru", "phone": "+70579460832"}
0005432639270	A45562	1703 854148	TAISIYA ZAKHAROVA	{"email": "taisiya_zakharova14011966@postgrespro.ru", "phone": "+70210304570"}
0005432639271	A45562	7062 819705	ELENA SMIRNOVA	{"email": "smirnovaelena_27111964@postgrespro.ru", "phone": "+70166577301"}
0005432639272	5622F8	8565 870908	YURIY KUDRYASHOV	{"phone": "+70956332665"}
0005432639273	315A79	0063 190192	GALINA SOKOLOVA	{"phone": "+70995561997"}
0005432639274	D2B380	9502 204349	NINA NESTEROVA	{"email": "nesterova-n-011975@postgrespro.ru", "phone": "+70481337253"}
0005432639275	D02231	9071 865778	DENIS ALEKSEEV	{"email": "d.alekseev111980@postgrespro.ru", "phone": "+70482018729"}
0005432639276	AB0582	8560 536481	ELENA FROLOVA	{"email": "e.frolova_011987@postgrespro.ru", "phone": "+70584109771"}
0005432639277	3BB35A	7343 156518	NIKOLAY ZAYCEV	{"email": "n_zaycev-1974@postgrespro.ru", "phone": "+70241347719"}
0005432639278	054DFE	4556 680492	ANTON POPOV	{"phone": "+70060152277"}
0005432639279	A5A314	4975 154501	OLGA ZAKHAROVA	{"email": "o-zakharova_24021980@postgrespro.ru", "phone": "+70625292502"}
0005432639280	A5A314	7537 737287	NATALYA GORBUNOVA	{"email": "gorbunova-natalya051964@postgrespro.ru", "phone": "+70082064162"}
0005432639281	85106C	2592 949775	GENNADIY ANDREEV	{"email": "andreev_gennadiy_1973@postgrespro.ru", "phone": "+70458348280"}
0005432639282	0DFEA5	4852 911232	ALINA SMIRNOVA	{"phone": "+70548885259"}
0005432639283	59E66B	3674 329743	VLADIMIR MEDVEDEV	{"email": "vladimir_medvedev-31031975@postgrespro.ru", "phone": "+70593742307"}
0005432639284	37B562	0484 508698	ANDREY TARASOV	{"phone": "+70162873400"}
0005432639285	D7877E	2576 562191	TAMARA IVANOVA	{"phone": "+70875692442"}
0005432639286	D7877E	0806 316744	VLADIMIR SOKOLOV	{"email": "vladimir.sokolov_1966@postgrespro.ru", "phone": "+70549821617"}
0005432639287	72D9B0	0398 268538	NIKOLAY IVANOV	{"phone": "+70954719157"}
0005432639288	CE30C3	4552 356421	NIKOLAY SMIRNOV	{"email": "smirnov.n1977@postgrespro.ru", "phone": "+70863766945"}
0005432639289	CE30C3	1576 914243	NATALIYA DAVYDOVA	{"email": "davydovanataliya.28061981@postgrespro.ru", "phone": "+70926932248"}
0005432639290	CE30C3	7450 353410	VALENTINA KISELEVA	{"email": "vkiseleva-121980@postgrespro.ru", "phone": "+70896279101"}
0005432639291	0288CA	8610 307086	VLADIMIR KUZNECOV	{"phone": "+70658966690"}
0005432639292	0288CA	0501 983324	VLADIMIR GORBUNOV	{"email": "v-gorbunov.1976@postgrespro.ru", "phone": "+70619973951"}
0005432639293	E628F4	6679 054902	NADEZHDA MIKHAYLOVA	{"email": "nadezhda.mikhaylova061964@postgrespro.ru", "phone": "+70096988984"}
0005432639294	E628F4	0629 581927	NATALYA ARKHIPOVA	{"phone": "+70533850376"}
0005432639295	C7D538	0063 774216	VIKTORIYA POPOVA	{"email": "popovaviktoriya061980@postgrespro.ru", "phone": "+70482472361"}
0005432639296	8B1323	7055 894814	ANTON ANTONOV	{"email": "antonov.a_1976@postgrespro.ru", "phone": "+70650214126"}
0005432639297	346BDF	2473 197271	GALINA TROFIMOVA	{"phone": "+70191289430"}
0005432639298	4E1BF4	3110 531105	SVETLANA TIMOFEEVA	{"phone": "+70113229457"}
0005432639299	D43A69	8453 634446	VERA GERASIMOVA	{"email": "gerasimovav27121989@postgrespro.ru", "phone": "+70843029113"}
0005432639300	920EE7	9793 293248	SERGEY GORBUNOV	{"email": "sergeygorbunov071967@postgrespro.ru", "phone": "+70149907670"}
0005432639301	233157	7405 206508	ELENA MAKSIMOVA	{"email": "elena-maksimova01111964@postgrespro.ru", "phone": "+70367245080"}
0005432639302	353AAC	8379 096169	ALEKSEY VASILEV	{"email": "vasilev-a06061967@postgrespro.ru", "phone": "+70118363630"}
0005432639303	353AAC	2991 424665	DARYA BELYAEVA	{"phone": "+70069952200"}
0005432639304	51A732	2469 823397	ANASTASIYA KOVALEVA	{"email": "a_kovaleva_1966@postgrespro.ru", "phone": "+70982627286"}
0005432639305	B37D0C	4870 181747	TAISIYA ZHURAVLEVA	{"phone": "+70084290947"}
0005432639306	B37D0C	7753 631058	VLADIMIR MELNIKOV	{"email": "vladimir-melnikov26121972@postgrespro.ru", "phone": "+70331710426"}
0005432639307	AE9D53	6525 439083	TATYANA SOLOVEVA	{"email": "soloveva_tatyana_1974@postgrespro.ru", "phone": "+70086252018"}
0005432639308	1F1016	8148 439616	LYUDMILA MIKHAYLOVA	{"phone": "+70668940780"}
0005432639309	758502	9930 979217	DARYA ANTONOVA	{"phone": "+70582007645"}
0005432639310	758502	0279 677074	SERGEY SOROKIN	{"phone": "+70537675974"}
0005432639311	758502	7646 452443	ALEKSANDR MAKAROV	{"email": "makarov.a-1978@postgrespro.ru", "phone": "+70635929973"}
0005432639312	EA93FA	9809 557297	VIKTOR RODIONOV	{"email": "rodionov-v101975@postgrespro.ru", "phone": "+70053237853"}
0005432639313	5A4A23	9721 877384	SVETLANA YAKOVLEVA	{"phone": "+70844849618"}
0005432639314	4725E9	9983 222298	ELENA KOVALEVA	{"phone": "+70222360360"}
0005432639315	693789	4223 456231	VERONIKA ZAKHAROVA	{"phone": "+70928262855"}
0005432639316	13BB7C	5113 088334	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr.16061978@postgrespro.ru", "phone": "+70118420008"}
0005432639317	95EB89	2213 880846	ZOYA KUZNECOVA	{"email": "zoya-kuznecova1971@postgrespro.ru", "phone": "+70811997464"}
0005432639318	CC06E3	0655 101364	IVAN AFANASEV	{"phone": "+70595309146"}
0005432639319	CC06E3	6003 459554	VLADIMIR PETROV	{"phone": "+70378640200"}
0005432639320	BB72C4	9607 547979	VALENTINA GRISHINA	{"phone": "+70448215348"}
0005432639321	BB72C4	3117 817721	VLADIMIR KOZLOV	{"email": "kozlov-vladimir_20061971@postgrespro.ru", "phone": "+70753719451"}
0005432639322	3A3804	5813 359886	MARINA GERASIMOVA	{"email": "gerasimova-m011977@postgrespro.ru", "phone": "+70198840408"}
0005432639323	3A3804	0737 810972	VYACHESLAV MOROZOV	{"email": "vyacheslav.morozov121978@postgrespro.ru", "phone": "+70490518865"}
0005432639324	3A3804	3760 933888	ELVIRA MIRONOVA	{"email": "elvira-mironova031972@postgrespro.ru", "phone": "+70352533239"}
0005432639325	197086	6143 071531	EKATERINA MELNIKOVA	{"email": "melnikova.e_051981@postgrespro.ru", "phone": "+70999869303"}
0005432639326	197086	1040 044093	NATALYA PAVLOVA	{"phone": "+70661489722"}
0005432639327	C2E9F9	8218 429680	KIRILL SERGEEV	{"phone": "+70139040757"}
0005432639328	B36709	1175 716588	TATYANA ANTONOVA	{"phone": "+70174827625"}
0005432639329	2A730A	4085 184270	LIDIYA ALEKSANDROVA	{"email": "lidiya.aleksandrova_1968@postgrespro.ru", "phone": "+70089880885"}
0005432639330	2A730A	2397 710813	YURIY PAVLOV	{"email": "y_pavlov121975@postgrespro.ru", "phone": "+70338646635"}
0005432639331	2C806F	3083 735340	FANIYA GAVRILOVA	{"phone": "+70320949010"}
0005432639332	B1DDDA	8582 157068	NADEZHDA OSIPOVA	{"email": "osipova.n-041977@postgrespro.ru", "phone": "+70210984440"}
0005432639333	B1DDDA	5055 758709	IRINA TARASOVA	{"phone": "+70694382080"}
0005432639334	EAAD04	0475 007669	KIRILL ZAKHAROV	{"phone": "+70824748405"}
0005432639335	1E88E3	8707 035433	YULIYA VOROBEVA	{"phone": "+70590519491"}
0005432639336	204D36	6082 886379	RUSLAN VASILEV	{"phone": "+70436220137"}
0005432639337	12B588	2688 971834	VIKTOR KONOVALOV	{"email": "konovalov_v_011966@postgrespro.ru", "phone": "+70055621927"}
0005432639338	12B588	9743 950112	YURIY PAVLOV	{"phone": "+70950921537"}
0005432639339	8B4487	7041 860657	IVAN ABRAMOV	{"email": "abramovivan-1972@postgrespro.ru", "phone": "+70271258339"}
0005432639340	8B4487	3479 064308	VLADIMIR NIKITIN	{"phone": "+70452738162"}
0005432639341	C63021	3528 886180	KIRILL IVANOV	{"phone": "+70059623477"}
0005432639342	C63021	9429 363325	IGOR FEDOTOV	{"email": "i-fedotov1972@postgrespro.ru", "phone": "+70162922723"}
0005432639343	D0E59D	2422 281993	NIKITA AFANASEV	{"phone": "+70433682257"}
0005432639344	091C1F	3884 383775	LYUDMILA KARPOVA	{"email": "lyudmilakarpova-24081974@postgrespro.ru", "phone": "+70861872305"}
0005432639345	253E90	0551 645708	ANDREY PETROV	{"phone": "+70964427171"}
0005432639346	253E90	7002 990783	ANNA KOROLEVA	{"email": "koroleva.anna051970@postgrespro.ru", "phone": "+70527321448"}
0005432639347	3971A8	2722 249533	VLADIMIR BARANOV	{"phone": "+70691373282"}
0005432639348	F0CA84	9414 828390	ANTONINA PAVLOVA	{"phone": "+70815020523"}
0005432639349	261DA5	2409 433243	KARINA POPOVA	{"phone": "+70195351127"}
0005432639350	72ECCA	1556 198857	ALISA PETROVA	{"phone": "+70473223693"}
0005432639351	72ECCA	0073 239368	VITALIY MATVEEV	{"email": "matveev.v-061969@postgrespro.ru", "phone": "+70211730216"}
0005432639352	2CE530	5425 451304	NIKOLAY ILIN	{"email": "ilin.n-19101984@postgrespro.ru", "phone": "+70116183514"}
0005432639353	2CE530	3796 676874	RAISA MOISEEVA	{"phone": "+70664131685"}
0005432639354	61D4CF	6260 272848	OLEG ANDREEV	{"phone": "+70697487405"}
0005432639355	D400A2	7640 677640	EKATERINA ZAKHAROVA	{"phone": "+70689439904"}
0005432639356	BB7324	7690 109557	VALERIY KAZAKOV	{"email": "kazakov-valeriy-03081982@postgrespro.ru", "phone": "+70720492910"}
0005432639357	F6A75B	4199 471834	VALERIYA KALININA	{"phone": "+70450720093"}
0005432639358	E64863	9956 583014	SVYATOSLAV ZAKHAROV	{"phone": "+70059110842"}
0005432639359	98007B	3889 826762	LILIYA GORBUNOVA	{"phone": "+70065422503"}
0005432639360	35358D	5110 824437	VALENTINA MAKSIMOVA	{"phone": "+70402010592"}
0005432639361	35358D	0152 663421	ANDREY RODIONOV	{"phone": "+70666493803"}
0005432639362	C45A6B	6778 356794	NIKOLAY VLASOV	{"phone": "+70967125424"}
0005432639363	6A715B	9991 809222	NIKOLAY EGOROV	{"email": "n-egorov.12091976@postgrespro.ru", "phone": "+70290640378"}
0005432639364	A4340F	8497 904481	SOFYA EGOROVA	{"email": "sofyaegorova-1975@postgrespro.ru", "phone": "+70353963635"}
0005432639365	A4340F	2610 563804	FEDOR NAZAROV	{"email": "nazarov_f-1974@postgrespro.ru", "phone": "+70670770640"}
0005432639366	1D5968	0163 138727	DENIS ZHUKOV	{"phone": "+70091084321"}
0005432639367	83C0B7	4755 793751	SVETLANA KULIKOVA	{"phone": "+70343200991"}
0005432639369	290537	6378 439315	SVETLANA ANTONOVA	{"phone": "+70347101901"}
0005432639370	5B57A8	2252 589788	ALEKSEY POPOV	{"phone": "+70110620715"}
0005432639371	F8FE36	9984 943361	VLADIMIR NAZAROV	{"email": "nazarov.vladimir-06031972@postgrespro.ru", "phone": "+70118737472"}
0005432639372	12E25F	1950 245047	RUSLAN IVANOV	{"phone": "+70526489112"}
0005432639373	FB366C	0914 197511	MARINA KUZNECOVA	{"phone": "+70285463205"}
0005432639374	FB366C	7802 757163	ANNA SCHERBAKOVA	{"email": "anna-scherbakova.051965@postgrespro.ru", "phone": "+70775107495"}
0005432639375	B355FB	9037 011001	VALERIY ROMANOV	{"phone": "+70068025918"}
0005432639376	2EF6C6	1719 853386	NATALYA FEDOROVA	{"email": "fedorova_natalya_031979@postgrespro.ru", "phone": "+70599763397"}
0005432639377	8A968C	4518 722465	BORIS IVANOV	{"email": "bivanov-1971@postgrespro.ru", "phone": "+70011030161"}
0005432639378	8A968C	1364 707771	NIKOLAY KOROLEV	{"phone": "+70532521634"}
0005432639379	9DB0AF	2479 463215	VALERIY MEDVEDEV	{"email": "vmedvedev-05061974@postgrespro.ru", "phone": "+70489349537"}
0005432639380	9DB0AF	1228 422677	DENIS MELNIKOV	{"email": "denis-melnikov081981@postgrespro.ru", "phone": "+70261548526"}
0005432639381	99DF41	5272 244635	ANDREY MIKHAYLOV	{"email": "mikhaylov-andrey-101990@postgrespro.ru", "phone": "+70990758574"}
0005432639382	99DF41	0330 115615	PAVEL PETROV	{"phone": "+70995407544"}
0005432639383	185784	4977 783185	ALEKSANDR POPOV	{"phone": "+70198207407"}
0005432639384	185784	9520 078713	OLESYA KOZLOVA	{"email": "olesya_kozlova1974@postgrespro.ru", "phone": "+70655668901"}
0005432639385	57DC8E	3302 172470	VLADIMIR GERASIMOV	{"phone": "+70202710480"}
0005432639386	501A6D	4569 942733	VALENTINA NAUMOVA	{"email": "naumova_valentina19091968@postgrespro.ru", "phone": "+70883126990"}
0005432639387	3091EF	7104 587310	RAISA KARPOVA	{"email": "raisakarpova.1973@postgrespro.ru", "phone": "+70879879287"}
0005432639388	412D41	5417 928016	LIDIYA KARPOVA	{"email": "karpovalidiya.091966@postgrespro.ru", "phone": "+70471938641"}
0005432639389	412D41	1614 845156	YULIYA CHERNOVA	{"email": "chernova.y-1976@postgrespro.ru", "phone": "+70100902476"}
0005432639390	9290B2	4853 812280	DMITRIY SIDOROV	{"phone": "+70637463118"}
0005432639391	9290B2	7250 171055	MAKSIM TIKHONOV	{"phone": "+70594834946"}
0005432639392	3423CE	1937 392658	OLGA MEDVEDEVA	{"email": "medvedeva-olga-27121979@postgrespro.ru", "phone": "+70290814061"}
0005432639393	15D8D9	7745 547244	NATALYA ZAYCEVA	{"phone": "+70642535598"}
0005432639394	BF8748	6477 129323	OLGA GAVRILOVA	{"phone": "+70696599679"}
0005432639395	280FD3	6205 199418	EGOR PAVLOV	{"email": "pavlov-egor.011972@postgrespro.ru", "phone": "+70395534245"}
0005432639396	280FD3	5425 301252	SERGEY DMITRIEV	{"email": "s.dmitriev041974@postgrespro.ru", "phone": "+70209377939"}
0005432639397	A79357	1132 974381	YURIY SERGEEV	{"phone": "+70358859481"}
0005432639398	838A3D	1248 465812	TATYANA MATVEEVA	{"phone": "+70065250465"}
0005432639399	11F2DC	3716 143547	OLGA VASILEVA	{"email": "olga.vasileva_28121967@postgrespro.ru", "phone": "+70022876296"}
0005432639400	11F2DC	5463 243168	IRINA MEDVEDEVA	{"phone": "+70022853716"}
0005432639401	11F2DC	7847 504568	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr-1977@postgrespro.ru", "phone": "+70470406318"}
0005432639402	C9A268	6775 407553	ALLA LAZAREVA	{"phone": "+70396850898"}
0005432639403	C1FD5C	9881 623109	VIKTOR SMIRNOV	{"phone": "+70873601596"}
0005432639404	C1FD5C	1300 437978	LYUDMILA SOKOLOVA	{"email": "sokolovalyudmila-1967@postgrespro.ru", "phone": "+70262003338"}
0005432639405	01058F	3894 613698	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.20091970@postgrespro.ru", "phone": "+70968883035"}
0005432639406	305F77	5695 944062	NINA KISELEVA	{"email": "nkiseleva1968@postgrespro.ru", "phone": "+70817369686"}
0005432639407	C24BC5	9112 789079	ANNA KONDRATEVA	{"email": "annakondrateva_071967@postgrespro.ru", "phone": "+70394890984"}
0005432639408	C24BC5	3651 669671	ALEKSANDR FROLOV	{"email": "a-frolov-031985@postgrespro.ru", "phone": "+70107225478"}
0005432639409	C24BC5	4717 336813	VALENTINA IVANOVA	{"email": "ivanova_valentina_19031976@postgrespro.ru", "phone": "+70421508451"}
0005432639410	16B8C6	4939 854474	MIKHAIL SEMENOV	{"phone": "+70485383997"}
0005432639411	16B8C6	3946 380179	ANDREY KUZNECOV	{"email": "a.kuznecov_31071981@postgrespro.ru", "phone": "+70978771012"}
0005432639412	F8F7F2	4502 352661	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov.1976@postgrespro.ru", "phone": "+70492223444"}
0005432639413	49672D	2406 730984	ANASTASIYA KRASNOVA	{"email": "krasnovaanastasiya_1982@postgrespro.ru", "phone": "+70957979132"}
0005432639414	17D2A0	8553 047102	MARGARITA KOMAROVA	{"phone": "+70843295824"}
0005432639415	17D2A0	5860 690893	NIKOLAY ZAYCEV	{"phone": "+70366689009"}
0005432639416	BF7BC1	8140 788977	ANNA MIKHAYLOVA	{"email": "annamikhaylova_051960@postgrespro.ru", "phone": "+70826047888"}
0005432639417	E1A36A	5380 857250	VLADIMIR PETROV	{"phone": "+70326663173"}
0005432639418	E1A36A	7183 370586	LYUBOV NESTEROVA	{"phone": "+70727410160"}
0005432639419	992A47	1472 154947	MARIYA SERGEEVA	{"phone": "+70339563014"}
0005432639420	90ADF0	2098 101781	YULIYA KOROLEVA	{"email": "koroleva.yuliya_121965@postgrespro.ru", "phone": "+70069238258"}
0005432639421	90ADF0	3983 853336	OLEG KISELEV	{"phone": "+70496527107"}
0005432639422	65DF3D	0812 717889	OLGA ROMANOVA	{"phone": "+70362529102"}
0005432639423	CBCF5E	1743 541407	DENIS SERGEEV	{"email": "denis.sergeev_25121955@postgrespro.ru", "phone": "+70694429158"}
0005432639424	BEC222	4410 111466	ELENA SOROKINA	{"phone": "+70412528121"}
0005432639425	361173	3337 844631	MADINA LAZAREVA	{"email": "lazareva.madina_1973@postgrespro.ru", "phone": "+70264375905"}
0005432639426	D759B3	1269 203993	ANATOLIY ANDREEV	{"phone": "+70991152281"}
0005432639427	E44704	8666 122035	ALEKSANDR VASILEV	{"phone": "+70922363498"}
0005432639428	E44704	4239 971909	TATYANA KOROLEVA	{"phone": "+70881206089"}
0005432639429	E44704	4395 732634	SAMVEL KOROLEV	{"email": "s-korolev-1963@postgrespro.ru", "phone": "+70576282180"}
0005432639430	194471	3086 866784	SERGEY ANTONOV	{"email": "antonov_sergey-071977@postgrespro.ru", "phone": "+70742142776"}
0005432639431	EE0B27	5326 231979	VITALIY POPOV	{"email": "vitaliy-popov_1972@postgrespro.ru", "phone": "+70798011439"}
0005432639432	EE0B27	4321 933400	ALEKSANDR KUZNECOV	{"phone": "+70292348370"}
0005432639433	EE0B27	3292 660079	MARIYA NAZAROVA	{"email": "nazarova_m-1973@postgrespro.ru", "phone": "+70123670195"}
0005432639434	98FFA4	9453 412053	LYUDMILA VASILEVA	{"phone": "+70751891771"}
0005432639435	98FFA4	8288 471336	ALEKSEY KONOVALOV	{"email": "konovalovaleksey_091977@postgrespro.ru", "phone": "+70949280005"}
0005432639436	63D6D3	0610 017573	RAISA MATVEEVA	{"phone": "+70820697502"}
0005432639437	63D6D3	2443 466736	ROMAN ALEKSEEV	{"phone": "+70218228262"}
0005432639438	400D28	2862 701510	LARISA MIRONOVA	{"phone": "+70039432205"}
0005432639439	400D28	6109 575548	ANNA DENISOVA	{"phone": "+70513651675"}
0005432639440	17852E	0528 327343	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev051968@postgrespro.ru", "phone": "+70087362653"}
0005432639441	17852E	1420 089234	VASILIY EGOROV	{"email": "egorov.vasiliy111968@postgrespro.ru", "phone": "+70885281467"}
0005432639442	A19101	1802 510715	LYUBOV MAKSIMOVA	{"phone": "+70454396020"}
0005432639443	0A7D7C	4802 664608	ELENA VOROBEVA	{"email": "elena_vorobeva_31121966@postgrespro.ru", "phone": "+70998717512"}
0005432639444	2EACC2	3157 646427	ELIZAVETA GUSEVA	{"phone": "+70419839083"}
0005432639445	2EACC2	9446 813638	ALEKSANDR FEDOROV	{"email": "a-fedorov.1964@postgrespro.ru", "phone": "+70543232291"}
0005432639446	2EACC2	6064 893377	ELENA TARASOVA	{"phone": "+70656417885"}
0005432639447	2DAC12	0175 677690	KIRILL ALEKSANDROV	{"email": "aleksandrovk.1968@postgrespro.ru", "phone": "+70069173478"}
0005432639448	2DAC12	7480 355981	ANDREY VASILEV	{"email": "vasilevandrey-1962@postgrespro.ru", "phone": "+70855764643"}
0005432639449	CDADD5	0540 377244	YULIYA KUDRYASHOVA	{"email": "kudryashova-y_07051964@postgrespro.ru", "phone": "+70354567721"}
0005432639450	CDADD5	0165 481603	YURIY DENISOV	{"email": "denisov.yuriy_021977@postgrespro.ru", "phone": "+70733245766"}
0005432639451	D4CEF3	6578 264492	ELENA BARANOVA	{"email": "e_baranova_051975@postgrespro.ru", "phone": "+70212493947"}
0005432639452	D4CEF3	0571 918166	EKATERINA FROLOVA	{"phone": "+70902282100"}
0005432639453	054B12	3432 729053	VALERIY ALEKSEEV	{"email": "alekseev.valeriy1978@postgrespro.ru", "phone": "+70659881902"}
0005432639454	BF3894	8023 027991	BORIS ALEKSEEV	{"email": "balekseev.051962@postgrespro.ru", "phone": "+70567068671"}
0005432639455	0F1DF3	6989 892654	SVETLANA KUZMINA	{"phone": "+70543762159"}
0005432639456	D72DB5	6334 235566	SVETLANA FEDOROVA	{"email": "fedorovas-1973@postgrespro.ru", "phone": "+70244578791"}
0005432639457	D72DB5	4364 620481	ALEKSANDR ZHUKOV	{"phone": "+70600340571"}
0005432639458	096325	4994 281063	OLGA ARKHIPOVA	{"email": "olgaarkhipova_24071977@postgrespro.ru", "phone": "+70234228605"}
0005432639459	096325	7636 548895	ANATOLIY MAKAROV	{"email": "makarov.a_011976@postgrespro.ru", "phone": "+70441567496"}
0005432639460	A51536	2010 528389	DMITRIY POPOV	{"phone": "+70401165673"}
0005432639461	F39862	6586 903919	EKATERINA SCHERBAKOVA	{"phone": "+70970632930"}
0005432639462	F39862	8805 765988	PAVEL PETROV	{"email": "pavel-petrov.05111963@postgrespro.ru", "phone": "+70380890996"}
0005432639463	39792A	6731 289101	VYACHESLAV MATVEEV	{"email": "matveev-vyacheslav_1965@postgrespro.ru", "phone": "+70033362683"}
0005432639464	5B4FD1	9615 497623	MIKHAIL SAVELEV	{"email": "mikhail.savelev_101965@postgrespro.ru", "phone": "+70853380945"}
0005432639465	5B4FD1	9193 364934	NIKOLAY ROMANOV	{"phone": "+70696929667"}
0005432639466	388521	0280 805352	OLESYA BOGDANOVA	{"phone": "+70463080537"}
0005432639467	C85366	2360 044982	MAKSIM SOROKIN	{"email": "m_sorokin071981@postgrespro.ru", "phone": "+70774168554"}
0005432639468	CE868A	5004 076278	LARISA VOROBEVA	{"phone": "+70902358663"}
0005432639469	6A49BE	9786 164688	FEDOR FROLOV	{"phone": "+70666296623"}
0005432639470	7E9917	8818 621179	MARINA ORLOVA	{"phone": "+70079501361"}
0005432639471	8A33DE	8618 916209	TATYANA NOVIKOVA	{"email": "novikovatatyana_1976@postgrespro.ru", "phone": "+70418541645"}
0005432639472	07BA53	3039 279181	GALINA PETROVA	{"phone": "+70830389268"}
0005432639473	915EE8	3741 282082	EKATERINA IVANOVA	{"email": "ivanova-e-091977@postgrespro.ru", "phone": "+70259317087"}
0005432639474	00229F	0093 142357	KONSTANTIN MIRONOV	{"phone": "+70235740484"}
0005432639475	827E9F	5257 013832	IVAN MOISEEV	{"phone": "+70037301272"}
0005432639476	F73E20	2501 578341	MARINA VOROBEVA	{"email": "marina.vorobeva061979@postgrespro.ru", "phone": "+70960749792"}
0005432639477	FE55A0	0055 726681	SERGEY SERGEEV	{"email": "sergeev-sergey-1974@postgrespro.ru", "phone": "+70048658144"}
0005432639478	F33150	4835 720691	NADEZHDA SEMENOVA	{"email": "semenova-nadezhda-091979@postgrespro.ru", "phone": "+70801891006"}
0005432639479	9FB2C3	6934 945192	LILIYA MIKHAYLOVA	{"email": "mikhaylovaliliya_101967@postgrespro.ru", "phone": "+70174030331"}
0005432639480	9FB2C3	3132 739384	ELENA FILATOVA	{"phone": "+70256973160"}
0005432639481	7090DB	1161 061708	YULIYA DAVYDOVA	{"phone": "+70606416956"}
0005432639482	1EA804	9111 988473	NINA NESTEROVA	{"phone": "+70587221975"}
0005432639483	283655	2493 666016	SERGEY SOROKIN	{"email": "sergey-sorokin.051967@postgrespro.ru", "phone": "+70241393232"}
0005432639484	283655	4563 961008	SERGEY KUDRYASHOV	{"email": "kudryashov_sergey-091974@postgrespro.ru", "phone": "+70770427466"}
0005432639485	283655	8715 689968	SERGEY ANDREEV	{"phone": "+70440678049"}
0005432639486	91BA1B	4090 717437	ALBINA BELOVA	{"phone": "+70716047002"}
0005432639487	AC15F2	5564 889674	ANGELINA KOROLEVA	{"email": "angelina-koroleva15091975@postgrespro.ru", "phone": "+70216876152"}
0005432639488	AC15F2	4460 759621	ANDREY FEDOTOV	{"phone": "+70291753609"}
0005432639489	AC15F2	9165 716656	LARISA ZAKHAROVA	{"phone": "+70365709874"}
0005432639490	2BF150	9305 755095	ANDREY ANDREEV	{"phone": "+70493373730"}
0005432639491	4C95F1	4453 229818	ALEKSANDR MELNIKOV	{"email": "melnikov_a_19041968@postgrespro.ru", "phone": "+70751806619"}
0005432639492	3ABD69	7836 094493	NATALYA VLASOVA	{"phone": "+70755103196"}
0005432639493	3ABD69	9712 922107	OKSANA NIKIFOROVA	{"phone": "+70452418837"}
0005432639494	79C669	2754 469682	IRINA MAKSIMOVA	{"phone": "+70874336034"}
0005432639495	1B6CFF	5035 793745	ANTONINA KUZNECOVA	{"email": "kuznecovaa-011969@postgrespro.ru", "phone": "+70516609103"}
0005432639496	6270A7	8659 579178	SERGEY KISELEV	{"email": "kiselev_sergey.101974@postgrespro.ru", "phone": "+70130473186"}
0005432639497	AE92B5	8251 395396	YURIY ISAEV	{"phone": "+70890011287"}
0005432639498	86E70A	8031 340033	NADEZHDA KUZNECOVA	{"phone": "+70123784862"}
0005432639499	86E70A	7400 694001	NATALYA TARASOVA	{"email": "tarasova_n_08081964@postgrespro.ru", "phone": "+70941699527"}
0005432639500	9DB68B	0777 186290	VIKTOR MIKHAYLOV	{"phone": "+70051346710"}
0005432639501	9DB68B	8551 546071	SERGEY STEPANOV	{"email": "stepanov.sergey021968@postgrespro.ru", "phone": "+70456893177"}
0005432639502	2C9669	3075 230501	ANDREY FROLOV	{"email": "andrey.frolov121970@postgrespro.ru", "phone": "+70322943037"}
0005432639503	CBE9CB	4369 011593	IVAN PETROV	{"email": "petrov_ivan_31011973@postgrespro.ru", "phone": "+70542825642"}
0005432639504	CBE9CB	4806 189163	ZINAIDA RODIONOVA	{"phone": "+70384700968"}
0005432639505	CBE9CB	0655 234971	LARISA NOVIKOVA	{"email": "larisanovikova-09041971@postgrespro.ru", "phone": "+70370105379"}
0005432639506	CBE9CB	3714 041607	MARGARITA MAKSIMOVA	{"email": "maksimova_margarita_1979@postgrespro.ru", "phone": "+70956364847"}
0005432639507	5F42BA	1085 436785	TIKHON ORLOV	{"email": "orlovtikhon.051986@postgrespro.ru", "phone": "+70373807066"}
0005432645761	B5A747	5517 653773	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr.021973@postgrespro.ru", "phone": "+70829158752"}
0005432645762	7A0ACA	7218 492009	LYUBOV LEBEDEVA	{"email": "l.lebedeva18071972@postgrespro.ru", "phone": "+70855107129"}
0005432645763	7A0ACA	8920 144983	VLADIMIR IVANOV	{"email": "v_ivanov09111976@postgrespro.ru", "phone": "+70557429316"}
0005432645764	E3BC87	4803 356101	DIANA IVANOVA	{"email": "diana.ivanova-021980@postgrespro.ru", "phone": "+70618019070"}
0005432645765	E3BC87	7922 499636	VALERIY MOISEEV	{"phone": "+70609289894"}
0005432645766	661CA9	1224 500569	DMITRIY IVANOV	{"phone": "+70394999021"}
0005432645767	EFA5D9	0955 590414	MARIYA OSIPOVA	{"phone": "+70200112761"}
0005432645768	CD907F	3594 493556	ALEKSANDR YAKOVLEV	{"phone": "+70705102383"}
0005432645769	B62389	2733 329497	INNA VOLKOVA	{"phone": "+70204808367"}
0005432645770	A1D548	0280 436424	LYUDMILA MAKSIMOVA	{"phone": "+70046662706"}
0005432645771	E2694A	5909 395827	PAVEL DAVYDOV	{"email": "davydovpavel-121967@postgrespro.ru", "phone": "+70314213608"}
0005432645772	1E48E0	6416 193009	ANDREY NIKITIN	{"phone": "+70529941582"}
0005432645773	1E48E0	3139 209146	ARTEM VOLKOV	{"phone": "+70816605346"}
0005432645774	0E1A7F	4064 426681	NIKOLAY PAVLOV	{"phone": "+70892014779"}
0005432645775	0E1A7F	2484 104362	IGOR MAKSIMOV	{"email": "igor.maksimov-1951@postgrespro.ru", "phone": "+70759530947"}
0005432645776	0E1A7F	9719 300098	LYUDMILA AFANASEVA	{"email": "afanasevalyudmila-15071969@postgrespro.ru", "phone": "+70495083133"}
0005432645777	40D92E	8668 421520	GENNADIY POPOV	{"email": "g.popov.21051968@postgrespro.ru", "phone": "+70179673584"}
0005432645778	DE3FFE	1438 359769	VERA FEDOROVA	{"email": "fedorovavera_25021966@postgrespro.ru", "phone": "+70387860977"}
0005432645779	356287	0242 269768	NADEZHDA MASLOVA	{"email": "n.maslova-1972@postgrespro.ru", "phone": "+70406009834"}
0005432645780	AC1713	7973 200822	ELENA MAKSIMOVA	{"email": "maksimova_elena17101977@postgrespro.ru", "phone": "+70110356466"}
0005432645781	AC1713	3947 592218	SERGEY ZHURAVLEV	{"phone": "+70568975792"}
0005432645782	4CB33F	3208 000063	YAN YAKOVLEV	{"email": "yakovlev.y_20061968@postgrespro.ru", "phone": "+70563522450"}
0005432645783	0E0398	6086 207638	RAISA MOROZOVA	{"email": "raisa_morozova1983@postgrespro.ru", "phone": "+70081707899"}
0005432645784	25EAE8	8643 512283	VALERIY SIDOROV	{"email": "sidorovv09031975@postgrespro.ru", "phone": "+70199319099"}
0005432645785	25EAE8	0329 075844	GENNADIY MAKAROV	{"email": "makarov.gennadiy_1972@postgrespro.ru", "phone": "+70463006172"}
0005432645786	25EAE8	2640 946609	YURIY FILIPPOV	{"phone": "+70086544026"}
0005432645787	4B0393	9367 580170	ELENA ISAEVA	{"email": "isaeva_e_1970@postgrespro.ru", "phone": "+70847826139"}
0005432645788	4B0393	0833 006489	VLADIMIR FEDOROV	{"phone": "+70673573952"}
0005432645789	D606C9	3919 940761	ELENA DMITRIEVA	{"email": "elena_dmitrieva-021975@postgrespro.ru", "phone": "+70669398602"}
0005432645790	D606C9	2057 825332	EVGENIY GORBUNOV	{"email": "e_gorbunov091971@postgrespro.ru", "phone": "+70112442013"}
0005432645791	8CABC6	8196 279742	ARTEM PETROV	{"email": "petrov.artem-10011978@postgrespro.ru", "phone": "+70496352821"}
0005432645792	8CABC6	8211 878300	VLADIMIR IVANOV	{"phone": "+70849526688"}
0005432645793	A72A78	3102 887247	SERGEY ORLOV	{"phone": "+70336036735"}
0005432645794	436E35	3066 277133	MARIANNA SERGEEVA	{"email": "sergeeva-m25031967@postgrespro.ru", "phone": "+70297058846"}
0005432645795	0DC12E	9654 905154	NATALYA BORISOVA	{"phone": "+70210993214"}
0005432645796	0DC12E	5691 165303	YULIYA MELNIKOVA	{"phone": "+70508591967"}
0005432645797	4440DF	8156 652258	LYUBOV ZAKHAROVA	{"phone": "+70163161078"}
0005432645798	E88DB2	2123 077600	MARINA MATVEEVA	{"email": "mmatveeva-24101957@postgrespro.ru", "phone": "+70152996609"}
0005432645799	E88DB2	7249 423486	SERGEY GAVRILOV	{"email": "sergey.gavrilov.21041969@postgrespro.ru", "phone": "+70991365039"}
0005432645800	CF7871	6525 852410	ALINA KOROLEVA	{"email": "akoroleva1973@postgrespro.ru", "phone": "+70642839478"}
0005432645801	521CDF	5195 806167	BOGDAN KUZNECOV	{"phone": "+70215265739"}
0005432645802	035281	0218 830946	ELENA VOROBEVA	{"email": "vorobeva_elena.1969@postgrespro.ru", "phone": "+70542742130"}
0005432645803	336CB5	9206 183861	VASILIY MOROZOV	{"email": "vmorozov_011978@postgrespro.ru", "phone": "+70652195670"}
0005432645804	336CB5	0533 502397	OLGA NESTEROVA	{"email": "olganesterova.111976@postgrespro.ru", "phone": "+70307640019"}
0005432645805	1A9CBB	8262 317132	ALEKSEY NIKITIN	{"phone": "+70393910096"}
0005432645806	1A8B62	9767 503376	VIKTORIYA NIKOLAEVA	{"email": "viktoriya-nikolaeva.011974@postgrespro.ru", "phone": "+70027700769"}
0005432645807	177561	0805 450581	YURIY ANDREEV	{"email": "y.andreev-04041964@postgrespro.ru", "phone": "+70755765019"}
0005432645808	177561	0559 004419	LYUBOV VLASOVA	{"phone": "+70023929863"}
0005432645809	325396	8117 004992	ARKADIY MIRONOV	{"email": "a.mironov-1985@postgrespro.ru", "phone": "+70021098578"}
0005432645810	325396	9129 433924	ZINAIDA EGOROVA	{"email": "egorova-zinaida.1975@postgrespro.ru", "phone": "+70224384639"}
0005432645811	5F397F	0623 807551	SERGEY KUZNECOV	{"phone": "+70998313369"}
0005432645812	6D58EF	3147 876203	VLADIMIR IVANOV	{"phone": "+70812487980"}
0005432645813	611465	9974 856668	MATVEY ALEKSEEV	{"email": "matveyalekseev-011980@postgrespro.ru", "phone": "+70652606669"}
0005432645814	3EBA04	2536 026935	MIKHAIL PETROV	{"email": "petrov_m_1975@postgrespro.ru", "phone": "+70420850443"}
0005432645815	D29722	0339 353147	VALERIY KOZLOV	{"email": "vkozlov_27011978@postgrespro.ru", "phone": "+70350389454"}
0005432645816	B82A04	9019 138622	ILYA PAVLOV	{"phone": "+70886248680"}
0005432645817	B82A04	6602 030961	ELENA KUZNECOVA	{"email": "elena_kuznecova_17071980@postgrespro.ru", "phone": "+70214288708"}
0005432645818	7A294A	3682 454580	ANDREY IVANOV	{"phone": "+70462021149"}
0005432645819	7A294A	8645 170312	TAISIYA OSIPOVA	{"phone": "+70678618537"}
0005432645820	A58A46	7991 848197	NINA KAZAKOVA	{"phone": "+70999071703"}
0005432645821	A58A46	3904 759490	ALLA MARTYNOVA	{"email": "martynova-a1975@postgrespro.ru", "phone": "+70395579800"}
0005432645822	E879F5	9817 456979	NIKOLAY SOROKIN	{"phone": "+70048386948"}
0005432645823	1157F3	0464 448227	PAVEL BORISOV	{"email": "borisovp-041974@postgrespro.ru", "phone": "+70894672089"}
0005432645824	1157F3	3279 846178	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr-1974@postgrespro.ru", "phone": "+70336198189"}
0005432645825	D1D7D4	4345 682159	VLADISLAV IVANOV	{"email": "v.ivanov07061972@postgrespro.ru", "phone": "+70630626214"}
0005432645826	A7C274	9811 025273	NADEZHDA KOROLEVA	{"phone": "+70697657614"}
0005432645995	7AF90E	0942 808983	SERGEY SIDOROV	{"phone": "+70249975562"}
0005432645827	50F186	8837 137336	NATALYA LAZAREVA	{"email": "lazareva-natalya101968@postgrespro.ru", "phone": "+70151442224"}
0005432645828	92FD36	9227 203096	SERGEY SIDOROV	{"email": "sidorovsergey-27031969@postgrespro.ru", "phone": "+70186462488"}
0005432645829	92FD36	8218 196747	ELENA NIKITINA	{"phone": "+70310483898"}
0005432645830	DA9015	9112 357352	VIKTOR FILIPPOV	{"phone": "+70414077278"}
0005432645831	7DE2B7	6428 829433	MAKSIM NIKOLAEV	{"phone": "+70986363855"}
0005432645832	7DE2B7	2211 311957	ALEKSEY MATVEEV	{"phone": "+70499990934"}
0005432645833	5E0D3A	3757 488376	LYUBOV IVANOVA	{"email": "ivanova-l-24081965@postgrespro.ru", "phone": "+70577796946"}
0005432645834	5E0D3A	6611 620654	MATVEY DAVYDOV	{"phone": "+70806301234"}
0005432645835	5E0D3A	8731 754861	ROZA GORBUNOVA	{"phone": "+70514618176"}
0005432645836	156904	7382 420573	GENNADIY PAVLOV	{"email": "pavlovg-23081971@postgrespro.ru", "phone": "+70748621942"}
0005432645837	156904	4544 162676	ARMEN TIKHONOV	{"email": "tikhonov_armen051981@postgrespro.ru", "phone": "+70848487054"}
0005432645838	5EF369	9649 093690	ANDREY ALEKSEEV	{"phone": "+70673193256"}
0005432645839	3EF7DD	4358 309082	SVETLANA GORBUNOVA	{"email": "gorbunova_svetlana1968@postgrespro.ru", "phone": "+70962363215"}
0005432645840	B05322	5468 790671	LYUBOV SMIRNOVA	{"email": "smirnova_lyubov-1973@postgrespro.ru", "phone": "+70981096325"}
0005432645841	9511A1	8019 479282	ANDREY SERGEEV	{"phone": "+70045456213"}
0005432645842	E8DAB5	4010 252727	DENIS SCHERBAKOV	{"email": "denisscherbakov021987@postgrespro.ru", "phone": "+70506496383"}
0005432645843	E94272	1293 372928	MIKHAIL NOVIKOV	{"phone": "+70800611219"}
0005432645844	E94272	1923 299852	EVGENIY SCHERBAKOV	{"email": "e.scherbakov_1968@postgrespro.ru", "phone": "+70341478500"}
0005432645845	D5C1C3	5690 695928	VALENTIN KAZAKOV	{"email": "kazakovvalentin_081970@postgrespro.ru", "phone": "+70749946198"}
0005432645846	EA0BDC	5999 303855	KSENIYA ILINA	{"phone": "+70115305107"}
0005432645847	F9361B	8618 707618	SVETLANA SMIRNOVA	{"phone": "+70355528965"}
0005432645848	F9361B	6423 377238	PAVEL DMITRIEV	{"phone": "+70507844656"}
0005432645849	0FC865	8436 927222	RAFAIL ALEKSEEV	{"email": "alekseev-r-15051982@postgrespro.ru", "phone": "+70096169960"}
0005432645850	0FC865	9201 110733	VYACHESLAV STEPANOV	{"email": "stepanovv_1968@postgrespro.ru", "phone": "+70111560558"}
0005432645851	B80E98	1561 800679	KSENIYA BELOVA	{"phone": "+70952771650"}
0005432645852	65CE32	7143 836977	YURIY KOZLOV	{"email": "kozlov.yuriy011964@postgrespro.ru", "phone": "+70029040292"}
0005432645853	8DD012	0724 078763	LEV NOVIKOV	{"phone": "+70666500205"}
0005432645854	2B0CDE	0291 079674	NATALYA ZAKHAROVA	{"phone": "+70315475706"}
0005432645855	CA9A19	2867 750627	ALEKSANDR CHERNOV	{"phone": "+70159531237"}
0005432645856	C85B36	9848 401600	TATYANA KONOVALOVA	{"phone": "+70368032059"}
0005432645857	4FFB91	0748 407864	VERA ZHUKOVA	{"phone": "+70303141597"}
0005432645858	3AD114	1960 121640	NINA SOLOVEVA	{"phone": "+70836342785"}
0005432645859	C69843	2205 043967	VALENTIN ANTONOV	{"phone": "+70054743984"}
0005432645860	C69843	0639 643132	YULIYA SERGEEVA	{"email": "sergeevay.101967@postgrespro.ru", "phone": "+70414562275"}
0005432645861	C0E59B	7836 815158	EVGENIY SMIRNOV	{"phone": "+70392345685"}
0005432645862	3EC52C	5208 231088	ALINA KOLESNIKOVA	{"email": "kolesnikova-alina.1974@postgrespro.ru", "phone": "+70132481943"}
0005432645863	2DF8E9	1662 066954	IRINA MATVEEVA	{"phone": "+70118323033"}
0005432645864	254A33	3156 246917	DMITRIY GUSEV	{"phone": "+70908830630"}
0005432645865	27FBE2	2543 980685	DZHAMILYA ALEKSEEVA	{"phone": "+70891805382"}
0005432645866	568B03	6202 555901	OLGA KOZLOVA	{"email": "o_kozlova1956@postgrespro.ru", "phone": "+70389352798"}
0005432645867	568B03	5487 766603	ALEKSANDR ALEKSEEV	{"phone": "+70151877177"}
0005432645868	7CDEDA	3821 970733	ALENA MELNIKOVA	{"email": "melnikova_alena_1978@postgrespro.ru", "phone": "+70182276562"}
0005432645869	7CDEDA	5959 508753	MARIYA BELOVA	{"email": "m-belova_031970@postgrespro.ru", "phone": "+70734978066"}
0005432645870	8250E6	7974 393320	VALENTINA CHERNOVA	{"email": "v.chernova.051977@postgrespro.ru", "phone": "+70019366281"}
0005432645871	DE8C0B	2488 946447	VYACHESLAV NIKOLAEV	{"phone": "+70350354222"}
0005432645872	DE8C0B	1964 087667	TAMARA VOLKOVA	{"phone": "+70639674717"}
0005432645873	80C628	2029 063606	ANDREY SOKOLOV	{"phone": "+70569786302"}
0005432645874	557A1C	4895 725133	DANIL BELOV	{"phone": "+70474007505"}
0005432645875	28C855	6386 408696	OKSANA STEPANOVA	{"phone": "+70218779776"}
0005432645876	D8014C	7174 759581	EMMA MOROZOVA	{"email": "emma.morozova-27101977@postgrespro.ru", "phone": "+70555831128"}
0005432645877	D8014C	6049 225875	VALENTINA MOISEEVA	{"email": "moiseeva-v.28101970@postgrespro.ru", "phone": "+70797782163"}
0005432645878	EB3F9A	2435 522252	VALENTINA DAVYDOVA	{"phone": "+70874780804"}
0005432645879	EB3F9A	3227 467873	PAVEL ROMANOV	{"phone": "+70257234816"}
0005432645880	B0A11F	2635 025296	EGOR TIKHONOV	{"phone": "+70170173137"}
0005432645881	A8501A	2857 534993	SERGEY PAVLOV	{"email": "sergey.pavlov1981@postgrespro.ru", "phone": "+70297060663"}
0005432645882	52D2DB	6735 966243	PAVEL NOVIKOV	{"phone": "+70610295247"}
0005432645883	52D2DB	5984 088144	LYUDMILA ANDREEVA	{"phone": "+70283784355"}
0005432645996	7AF90E	2389 523545	IVAN VASILEV	{"phone": "+70229715685"}
0005432645884	49A626	2415 027297	ANNA GORBUNOVA	{"email": "a.gorbunova.101964@postgrespro.ru", "phone": "+70970843036"}
0005432645885	0F01A1	6763 561788	ELENA ILINA	{"email": "elenailina.111963@postgrespro.ru", "phone": "+70325843148"}
0005432645886	A9639E	9641 967800	ANASTASIYA MAKAROVA	{"phone": "+70723847456"}
0005432645887	359374	6292 425090	OLGA NAUMOVA	{"email": "o.naumova.1982@postgrespro.ru", "phone": "+70300645573"}
0005432645888	0305F1	8434 465878	TAISIYA KRASNOVA	{"phone": "+70583922132"}
0005432645889	4EDC7D	4529 521342	GALINA ALEKSEEVA	{"phone": "+70378540700"}
0005432645890	351E69	9785 652714	YURIY GRIGOREV	{"email": "grigorevyuriy-14061975@postgrespro.ru", "phone": "+70330177987"}
0005432645891	72CD4C	8957 495124	LARISA DMITRIEVA	{"email": "l-dmitrieva.18091965@postgrespro.ru", "phone": "+70404534229"}
0005432645892	72CD4C	9677 744503	ALEKSEY KUZNECOV	{"email": "a-kuznecov-051979@postgrespro.ru", "phone": "+70760277541"}
0005432645893	52310F	6903 694636	IRINA SOLOVEVA	{"phone": "+70790881343"}
0005432645894	771BB9	6300 379017	VALENTINA TIMOFEEVA	{"phone": "+70838382803"}
0005432645895	3D05B6	8088 727589	EVGENIY PETROV	{"phone": "+70232308985"}
0005432645896	20708C	5840 167413	ELENA SEMENOVA	{"phone": "+70964671609"}
0005432645897	ECB638	5331 281410	PETR KUZNECOV	{"phone": "+70136827289"}
0005432645898	ECB638	1218 320064	LIDIYA IVANOVA	{"phone": "+70201726514"}
0005432645899	ECB638	4668 538820	OLGA IVANOVA	{"phone": "+70958399127"}
0005432645900	DCC916	5601 930569	TAMARA MEDVEDEVA	{"phone": "+70698166707"}
0005432645901	D18435	9301 427265	SVETLANA ALEKSEEVA	{"email": "alekseeva_svetlana.1971@postgrespro.ru", "phone": "+70388325187"}
0005432645902	D18435	0397 939050	POLINA PETROVA	{"email": "petrova_p-021979@postgrespro.ru", "phone": "+70934783847"}
0005432645903	E6A858	1528 507953	ALEKSEY KULIKOV	{"email": "a_kulikov_1970@postgrespro.ru", "phone": "+70570675194"}
0005432645904	A42B13	6502 049572	SVETLANA BOGDANOVA	{"email": "s.bogdanova1981@postgrespro.ru", "phone": "+70006197954"}
0005432645905	A42B13	2199 329419	ALEKSEY MEDVEDEV	{"email": "amedvedev091977@postgrespro.ru", "phone": "+70172957851"}
0005432645906	E2D5AF	7145 641046	ARTUR ORLOV	{"phone": "+70990797274"}
0005432645907	E2D5AF	5108 600263	NINA LOGINOVA	{"email": "loginova.n.1975@postgrespro.ru", "phone": "+70742131692"}
0005432645908	4DB8C3	7946 632056	YULIYA GUSEVA	{"email": "guseva-y_061970@postgrespro.ru", "phone": "+70813459119"}
0005432645909	9FE8CB	5533 871868	LILIYA FOMINA	{"phone": "+70368661344"}
0005432645910	9FE8CB	0159 367631	SVETLANA KAZAKOVA	{"phone": "+70347422816"}
0005432645911	4A74BA	4356 387931	RAISA NIKOLAEVA	{"phone": "+70890894435"}
0005432645912	04687E	0010 464499	SALAVAT VLASOV	{"email": "s_vlasov.11111960@postgrespro.ru", "phone": "+70913777102"}
0005432645913	1FCBE2	6085 010279	ANTONINA GORBUNOVA	{"email": "gorbunova-a_09011980@postgrespro.ru", "phone": "+70536241317"}
0005432645914	367569	9510 439279	KSENIYA CHERNOVA	{"email": "k_chernova.061973@postgrespro.ru", "phone": "+70430890738"}
0005432645915	685E54	0310 713962	ANDREY OSIPOV	{"phone": "+70100998401"}
0005432645916	57ABA6	0736 484363	EVGENIY ZHURAVLEV	{"phone": "+70046428235"}
0005432645917	850EDF	6859 428525	DENIS NAUMOV	{"email": "naumov_d_18101974@postgrespro.ru", "phone": "+70864476638"}
0005432645918	850EDF	1824 561582	VIKTOR FROLOV	{"email": "frolov.viktor-1968@postgrespro.ru", "phone": "+70958854112"}
0005432645919	96CF5A	3600 176491	TATYANA PETROVA	{"email": "petrova-tatyana-15021967@postgrespro.ru", "phone": "+70498397537"}
0005432645920	96CF5A	2361 929468	TAISIYA KOROLEVA	{"phone": "+70740411940"}
0005432645921	745BB6	2658 782562	VALENTINA ALEKSEEVA	{"email": "alekseevavalentina-101968@postgrespro.ru", "phone": "+70300356836"}
0005432645922	5CCB07	4393 044971	ALEKSANDR KAZAKOV	{"phone": "+70690043685"}
0005432645923	F4484A	7137 528329	GRIGORIY KUZNECOV	{"email": "kuznecovg_061975@postgrespro.ru", "phone": "+70912927684"}
0005432645924	430CDA	6543 116442	BORIS ANDREEV	{"email": "andreevboris.29031980@postgrespro.ru", "phone": "+70265158546"}
0005432645925	430CDA	2867 896495	ALLA ANDREEVA	{"phone": "+70308069639"}
0005432645926	675FA7	0196 670891	ULYANA POPOVA	{"phone": "+70935637370"}
0005432645927	D5352E	7790 609837	ALEKSANDR FILIPPOV	{"email": "afilippov.091972@postgrespro.ru", "phone": "+70753526359"}
0005432645928	EE3F82	1887 522120	ANATOLIY POPOV	{"email": "popov.anatoliy1972@postgrespro.ru", "phone": "+70204838635"}
0005432645929	EE3F82	9596 564164	OLGA SOKOLOVA	{"phone": "+70786256142"}
0005432645930	A8B4E8	0071 468668	SERGEY IVANOV	{"email": "sergey.ivanov-03051970@postgrespro.ru", "phone": "+70829485823"}
0005432645931	895C34	0171 230374	YURIY KAZAKOV	{"phone": "+70774012023"}
0005432645932	68C4D7	8500 115744	ANDREY ROMANOV	{"phone": "+70130581679"}
0005432645933	68C4D7	3985 102899	FEDOR FEDOTOV	{"phone": "+70882721157"}
0005432645934	1B314B	4439 679939	ELENA DENISOVA	{"email": "denisova_e.061977@postgrespro.ru", "phone": "+70099461578"}
0005432645935	124A3A	1154 684353	VARVARA NIKIFOROVA	{"phone": "+70658253674"}
0005432645936	E9AD3C	2279 735756	IGOR KUZNECOV	{"phone": "+70260104488"}
0005432645937	3BE639	0018 119580	DENIS EGOROV	{"phone": "+70488785930"}
0005432645938	3BE639	6598 771808	ELENA ISAEVA	{"email": "isaevae-031971@postgrespro.ru", "phone": "+70685904284"}
0005432645939	3BE639	2220 740931	VITALIY PAVLOV	{"phone": "+70947424555"}
0005432645997	9A8CD1	7057 552286	MARYAM KUZNECOVA	{"phone": "+70255283010"}
0005432645940	D9C1C8	9565 778289	ANTONINA OVCHINNIKOVA	{"email": "ovchinnikova-a-22071977@postgrespro.ru", "phone": "+70502218192"}
0005432645941	D9C1C8	2381 119113	LYUBOV EFREMOVA	{"email": "lyubovefremova-051967@postgrespro.ru", "phone": "+70310918356"}
0005432645942	E91DBA	6413 193953	NADEZHDA PAVLOVA	{"email": "pavlova_n.30011971@postgrespro.ru", "phone": "+70283933435"}
0005432645943	5B3669	5571 695030	VYACHESLAV KOZLOV	{"email": "vkozlov111975@postgrespro.ru", "phone": "+70726466985"}
0005432645944	9CD064	0204 993897	VERONIKA KUDRYASHOVA	{"email": "kudryashova.veronika_17011961@postgrespro.ru", "phone": "+70509542789"}
0005432645945	977C0F	1774 007619	ANASTASIYA DAVYDOVA	{"phone": "+70009660708"}
0005432645946	A5AA51	3649 665548	LIDIYA BOGDANOVA	{"phone": "+70232010953"}
0005432645947	B0261C	0358 362202	ANNA KOLESNIKOVA	{"phone": "+70470353906"}
0005432645948	B361D7	1915 842310	LYUBOV OSIPOVA	{"phone": "+70478986598"}
0005432645949	B361D7	8775 428344	ALEKSEY DAVYDOV	{"email": "aleksey_davydov.02101962@postgrespro.ru", "phone": "+70259887410"}
0005432645950	223552	5993 640559	DANIL KRASNOV	{"phone": "+70174509875"}
0005432645951	D72B8C	4842 346387	ARTUR KOZLOV	{"phone": "+70966602694"}
0005432645952	D72B8C	0532 569041	SVETLANA NOVIKOVA	{"phone": "+70933899461"}
0005432645953	28526C	1088 766183	OLGA DMITRIEVA	{"email": "olga_dmitrieva_06051972@postgrespro.ru", "phone": "+70944412977"}
0005432645954	141E83	7127 474795	REGINA MIRONOVA	{"phone": "+70125129395"}
0005432645955	141E83	2743 541773	ANATOLIY IVANOV	{"email": "a.ivanov-25051977@postgrespro.ru", "phone": "+70049269482"}
0005432645956	E61CF3	6154 591060	EKATERINA ANISIMOVA	{"email": "anisimova-e.1977@postgrespro.ru", "phone": "+70876338254"}
0005432645957	C2EEA8	3743 753237	YULIANA NAZAROVA	{"email": "ynazarova_031976@postgrespro.ru", "phone": "+70492176809"}
0005432645958	BA93D4	5522 030358	GALINA KUZNECOVA	{"email": "g.kuznecova041967@postgrespro.ru", "phone": "+70922309766"}
0005432645959	191867	2523 735760	ALEKSANDR TIMOFEEV	{"phone": "+70364471518"}
0005432645960	F118CC	9588 764209	NIKOLAY PETROV	{"phone": "+70471590150"}
0005432645961	F118CC	4770 765083	VASILIY ALEKSEEV	{"email": "v.alekseev-091963@postgrespro.ru", "phone": "+70733279129"}
0005432645962	4AAC96	2431 052782	NADEZHDA ANDREEVA	{"email": "andreeva-n11031975@postgrespro.ru", "phone": "+70893219713"}
0005432645963	4AAC96	1254 173405	IVAN KAZAKOV	{"email": "ikazakov-1970@postgrespro.ru", "phone": "+70009050426"}
0005432645964	56907F	1714 014040	ANZHELIKA POLYAKOVA	{"email": "anzhelikapolyakova.1967@postgrespro.ru", "phone": "+70732899290"}
0005432645965	29BB94	5945 898685	DENIS TARASOV	{"email": "denis.tarasov-1966@postgrespro.ru", "phone": "+70929607975"}
0005432645966	29BB94	1874 899318	IVAN MAKSIMOV	{"phone": "+70492439377"}
0005432645967	06F024	1607 385249	IGOR SERGEEV	{"email": "sergeev.i.21061975@postgrespro.ru", "phone": "+70482846445"}
0005432645968	8424F0	1897 074394	ANDREY KUDRYASHOV	{"phone": "+70178210987"}
0005432645969	1279E5	4411 652944	MIKHAIL BONDARENKO	{"email": "mbondarenko-15031972@postgrespro.ru", "phone": "+70080214363"}
0005432645970	537666	8056 649012	PETR RODIONOV	{"email": "prodionov27041977@postgrespro.ru", "phone": "+70973178890"}
0005432645971	537666	1543 871201	ALEVTINA ANTONOVA	{"email": "antonova_a-1975@postgrespro.ru", "phone": "+70365098748"}
0005432645972	2391FC	3728 068569	DMITRIY SERGEEV	{"email": "sergeevdmitriy.02111962@postgrespro.ru", "phone": "+70245326146"}
0005432645973	2391FC	8321 732678	NIKOLAY IVANOV	{"email": "n_ivanov.081980@postgrespro.ru", "phone": "+70498244414"}
0005432645974	1BE472	2529 258090	OLGA KUZMINA	{"email": "olgakuzmina.1964@postgrespro.ru", "phone": "+70880719589"}
0005432645975	1BE472	9191 275275	MATRENA AKIMOVA	{"email": "akimova_matrena_1965@postgrespro.ru", "phone": "+70445100697"}
0005432645976	1BE472	4526 690945	ZAKHAR TARASOV	{"phone": "+70439146382"}
0005432645977	122CC0	8729 168210	ALEKSEY NAZAROV	{"email": "nazarov_aleksey27121975@postgrespro.ru", "phone": "+70687267011"}
0005432645978	122CC0	3784 853363	ANATOLIY TIKHONOV	{"phone": "+70471110849"}
0005432645979	D7B414	5998 881124	NINA PETROVA	{"email": "nina_petrova_1973@postgrespro.ru", "phone": "+70432671417"}
0005432645980	A1F9A9	4489 126520	DMITRIY PAVLOV	{"email": "dmitriy-pavlov-13121975@postgrespro.ru", "phone": "+70203778224"}
0005432645981	A1F9A9	2023 257468	NIKOLAY KUZNECOV	{"phone": "+70651041244"}
0005432645982	5039C6	6287 775210	MIKHAIL NAUMOV	{"email": "mikhail_naumov.1962@postgrespro.ru", "phone": "+70960696980"}
0005432645983	AAC14C	8712 867107	IRINA LEBEDEVA	{"email": "i_lebedeva.14061973@postgrespro.ru", "phone": "+70766033698"}
0005432645984	AAC14C	1046 399211	DARYA ABRAMOVA	{"email": "abramovadarya-111976@postgrespro.ru", "phone": "+70128762347"}
0005432645985	2A8354	8211 344718	ANASTASIYA DANILOVA	{"phone": "+70471753261"}
0005432645986	81AF08	5491 539359	ANDREY FOMIN	{"email": "a-fomin1972@postgrespro.ru", "phone": "+70488261472"}
0005432645987	A0CA4E	2264 430373	NIKOLAY PAVLOV	{"phone": "+70219281807"}
0005432645988	A0CA4E	4665 405970	MIKHAIL PETROV	{"email": "mikhailpetrov.071977@postgrespro.ru", "phone": "+70213390252"}
0005432645989	A0CA4E	6197 456235	LEONID MEDVEDEV	{"email": "medvedev.l_111970@postgrespro.ru", "phone": "+70647918724"}
0005432645990	27A828	3217 693307	ANDREY POPOV	{"phone": "+70860312323"}
0005432645991	27A828	1729 155000	VALENTIN BARANOV	{"email": "v-baranov1974@postgrespro.ru", "phone": "+70009273892"}
0005432645992	D882B5	5386 853336	ALESYA IVANOVA	{"phone": "+70935493176"}
0005432645993	D882B5	5623 253595	ELENA ILINA	{"email": "e_ilina_30011989@postgrespro.ru", "phone": "+70165838529"}
0005432645994	7AF90E	5343 828748	NATALYA RODIONOVA	{"email": "rodionova_natalya_1982@postgrespro.ru", "phone": "+70587315796"}
0005432645998	7100B0	0973 796316	LILIYA ANISIMOVA	{"phone": "+70703667357"}
0005432645999	4B9F68	8815 558233	SNEZHANA PETROVA	{"phone": "+70312547193"}
0005432646000	B88274	5924 533998	KONSTANTIN SCHERBAKOV	{"phone": "+70823981563"}
0005432646001	7400CA	8576 521996	IGOR SCHERBAKOV	{"email": "igor-scherbakov.10081979@postgrespro.ru", "phone": "+70344184495"}
0005432646002	49ECA9	9258 982099	SERGEY KOZLOV	{"email": "skozlov.1974@postgrespro.ru", "phone": "+70917150168"}
0005432646003	49ECA9	7809 795371	ALESYA KOZLOVA	{"email": "kozlova_a_27031973@postgrespro.ru", "phone": "+70003586603"}
0005432646004	B90BAD	4452 004946	NADEZHDA VASILEVA	{"phone": "+70927651698"}
0005432646005	E90478	4716 904901	MAKSIM NAZAROV	{"email": "maksimnazarov.121973@postgrespro.ru", "phone": "+70125874451"}
0005432646006	D497D8	1305 512747	ALEKSANDR KUZMIN	{"email": "a.kuzmin.1970@postgrespro.ru", "phone": "+70642819983"}
0005432646007	135709	4103 356963	VLADA EGOROVA	{"phone": "+70881345136"}
0005432646008	6E166E	5109 488054	VIKTOR FEDOROV	{"email": "viktor_fedorov-051972@postgrespro.ru", "phone": "+70792611944"}
0005432646009	6E166E	3875 743314	ANNA KONOVALOVA	{"phone": "+70929533190"}
0005432646010	02DDB8	5386 007434	LYUDMILA TIMOFEEVA	{"email": "l-timofeeva1974@postgrespro.ru", "phone": "+70382868134"}
0005432646011	02DDB8	6757 876864	VALERIY BELOV	{"email": "valeriybelov_031976@postgrespro.ru", "phone": "+70427489412"}
0005432646012	F38827	6460 601983	SERGEY FROLOV	{"email": "frolov_s_1983@postgrespro.ru", "phone": "+70803865916"}
0005432646013	84A05D	9630 009155	RUSLAN BARANOV	{"phone": "+70747919075"}
0005432646014	84A05D	5467 757395	VERA VLASOVA	{"email": "v.vlasova1974@postgrespro.ru", "phone": "+70239952459"}
0005432646015	355B25	6890 433457	ALEKSANDR TIMOFEEV	{"phone": "+70446275151"}
0005432646016	221125	4142 654701	VLADIMIR FOMIN	{"email": "vladimir_fomin_31121977@postgrespro.ru", "phone": "+70374986858"}
0005432646017	221125	5523 204892	OLGA ZHUKOVA	{"email": "olga.zhukova1983@postgrespro.ru", "phone": "+70386361528"}
0005432646018	B9529C	2835 851954	ANNA KOZLOVA	{"email": "kozlovaa.051972@postgrespro.ru", "phone": "+70438895109"}
0005432646019	B9529C	0202 067462	VERA VOROBEVA	{"email": "vorobevav_081977@postgrespro.ru", "phone": "+70516789421"}
0005432646020	4B7DEF	2395 036229	SERGEY TIKHONOV	{"phone": "+70753020021"}
0005432646021	9DF5D4	5139 766465	GENNADIY IVANOV	{"phone": "+70523044804"}
0005432646022	9AEAEA	9988 696079	ELENA SAVELEVA	{"phone": "+70165445058"}
0005432646023	0ABC5B	4724 831203	ELENA BOGDANOVA	{"email": "bogdanovaelena04091981@postgrespro.ru", "phone": "+70596403404"}
0005432646024	E1F162	9056 024100	LIDIYA NOVIKOVA	{"phone": "+70742056564"}
0005432646025	6B158B	1921 314460	DENIS PETROV	{"email": "d_petrov-08021968@postgrespro.ru", "phone": "+70071734128"}
0005432646026	6B158B	6566 325837	ELIZAVETA SEMENOVA	{"phone": "+70189678249"}
0005432646027	B8BD00	2819 273350	EVGENIYA BELYAEVA	{"phone": "+70604411158"}
0005432646028	B8BD00	5667 630548	MAKSIM BORISOV	{"phone": "+70927228440"}
0005432646029	CA4BEB	1504 475202	IRINA NESTEROVA	{"email": "nesterovai-1963@postgrespro.ru", "phone": "+70818431954"}
0005432646030	581DD9	1316 946138	GALINA KOZLOVA	{"email": "kozlova_galina-19121968@postgrespro.ru", "phone": "+70077789562"}
0005432646031	6A2DE6	1626 847480	MIKHAIL KULIKOV	{"phone": "+70692579427"}
0005432646032	BDB345	6927 815182	LYUDMILA NESTEROVA	{"email": "lnesterova-1980@postgrespro.ru", "phone": "+70438976239"}
0005432646033	4C7C06	4241 734847	PAVEL SEMENOV	{"phone": "+70227086274"}
0005432646034	E3A798	5527 628289	ELENA MEDVEDEVA	{"phone": "+70132379215"}
0005432646035	C712FB	7684 500302	IVAN MAKAROV	{"email": "makarov.ivan_29111973@postgrespro.ru", "phone": "+70219042708"}
0005432646036	00813F	7097 478346	BORIS GUSEV	{"email": "boris-gusev_1973@postgrespro.ru", "phone": "+70078449189"}
0005432646037	19A15B	5570 139885	DMITRIY KUZNECOV	{"phone": "+70211197184"}
0005432646038	19A15B	4104 830546	NATALYA BORISOVA	{"phone": "+70356593194"}
0005432646039	19A15B	9994 695024	TATYANA ROMANOVA	{"phone": "+70192167585"}
0005432646040	0660CD	5661 115955	NIKOLAY KUZMIN	{"email": "n.kuzmin_16091968@postgrespro.ru", "phone": "+70766793321"}
0005432646041	0660CD	8713 657794	DINARA NIKITINA	{"email": "nikitina.d.12011983@postgrespro.ru", "phone": "+70447203998"}
0005432646042	9128B4	4708 814853	ALEKSEY KAZAKOV	{"phone": "+70422821328"}
0005432646043	9128B4	1643 560035	DMITRIY PETROV	{"phone": "+70061932223"}
0005432646044	CCBEC5	2347 560233	ALEKSEY BORISOV	{"email": "borisov-aleksey.24101963@postgrespro.ru", "phone": "+70662782433"}
0005432646045	CCBEC5	3365 819420	NIKOLAY KULIKOV	{"email": "nikolay-kulikov_021968@postgrespro.ru", "phone": "+70855391779"}
0005432646046	C80D59	2193 334651	EKATERINA KUZNECOVA	{"email": "kuznecova_ekaterina_1983@postgrespro.ru", "phone": "+70091671859"}
0005432646047	C80D59	7316 898021	VIKTORIYA LAZAREVA	{"phone": "+70560698546"}
0005432646048	AFF3E8	3065 681222	NIKITA EGOROV	{"email": "egorov-nikita1982@postgrespro.ru", "phone": "+70746501254"}
0005432646049	AFF3E8	3522 402694	VIKTOR SHEVCHENKO	{"phone": "+70217470212"}
0005432646050	9828B7	2523 839838	LIDIYA KONDRATEVA	{"email": "kondrateva-lidiya_24031971@postgrespro.ru", "phone": "+70320805600"}
0005432646051	9828B7	5513 224145	NATALYA KALININA	{"phone": "+70535281903"}
0005432646052	545F16	7783 991174	DANILA MELNIKOV	{"phone": "+70972906645"}
0005432646053	545F16	6534 300590	POLINA ORLOVA	{"email": "porlova.121981@postgrespro.ru", "phone": "+70030884149"}
0005432646054	545F16	8071 491797	MARGARITA ANDREEVA	{"phone": "+70658850139"}
0005432646055	28D6D5	0601 993048	ELENA PETROVA	{"email": "e.petrova.29051969@postgrespro.ru", "phone": "+70693386858"}
0005432646056	F687D3	6696 482052	KIRILL SERGEEV	{"phone": "+70713574229"}
0005432646057	F687D3	6159 421501	EVGENIY SERGEEV	{"phone": "+70967836288"}
0005432646058	B9757F	7588 058332	MARIYA POTAPOVA	{"phone": "+70377360678"}
0005432646059	674B07	6938 372165	ANNA FOMINA	{"email": "anna-fomina_1978@postgrespro.ru", "phone": "+70702605126"}
0005432646060	5BAC9A	7178 898921	VIKTORIYA SOKOLOVA	{"phone": "+70897386128"}
0005432646061	8C9B4F	5362 867240	MARIYA FOMINA	{"email": "mariya-fomina07051975@postgrespro.ru", "phone": "+70724798083"}
0005432646062	AB4537	8618 258032	LIDIYA SERGEEVA	{"email": "sergeeval_081964@postgrespro.ru", "phone": "+70655537977"}
0005432646063	AB4537	5810 895752	TATYANA KUZMINA	{"phone": "+70875018148"}
0005432646064	74A620	2558 696117	STANISLAV GERASIMOV	{"phone": "+70219614292"}
0005432646065	0FB589	5895 635777	VLADIMIR FEDOROV	{"phone": "+70283687570"}
0005432646066	0FB589	7317 579079	NATALYA KARPOVA	{"email": "natalyakarpova08101972@postgrespro.ru", "phone": "+70996663697"}
0005432646067	2099E1	3127 899561	ILYA KUZNECOV	{"email": "kuznecovi.08031967@postgrespro.ru", "phone": "+70061018435"}
0005432646068	2099E1	3955 931435	IGOR PAVLOV	{"email": "igor_pavlov101975@postgrespro.ru", "phone": "+70360472221"}
0005432646069	61768F	6581 881684	ALEKSANDR ANDREEV	{"phone": "+70697771278"}
0005432646070	F17C3E	1581 150977	VALERIY EGOROV	{"phone": "+70101851951"}
0005432646071	738489	9672 385922	VLADIMIR SOROKIN	{"phone": "+70653698069"}
0005432646072	738489	7607 875048	VALERIYA VASILEVA	{"email": "valeriyavasileva1976@postgrespro.ru", "phone": "+70857762839"}
0005432646073	A8D437	8110 266132	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr-1977@postgrespro.ru", "phone": "+70560730959"}
0005432646074	94C104	5643 128588	NINA KOZLOVA	{"email": "nkozlova-061962@postgrespro.ru", "phone": "+70363186549"}
0005432646075	0496F6	4330 517208	YULIYA KOROLEVA	{"email": "koroleva.yuliya-1966@postgrespro.ru", "phone": "+70709526897"}
0005432646076	0496F6	6252 139704	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr1969@postgrespro.ru", "phone": "+70573016382"}
0005432646077	CA37D7	1965 375136	MARAT VOROBEV	{"email": "vorobev.m.1960@postgrespro.ru", "phone": "+70947720586"}
0005432646078	CA37D7	2348 888976	RENAT KUZNECOV	{"email": "kuznecov.r_101979@postgrespro.ru", "phone": "+70266028464"}
0005432646079	CA37D7	3917 437682	ROMAN FEDOROV	{"email": "r-fedorov-1971@postgrespro.ru", "phone": "+70241270455"}
0005432646080	7C431D	6744 574933	VIKTORIYA OVCHINNIKOVA	{"phone": "+70344747671"}
0005432646081	446E3B	4811 214710	NATALYA POPOVA	{"email": "natalyapopova.25031973@postgrespro.ru", "phone": "+70214168151"}
0005432646082	066978	0215 560949	VALERIY IVANOV	{"email": "ivanov.v_011976@postgrespro.ru", "phone": "+70156282293"}
0005432646083	87D2EC	1816 017223	NIKOLAY IVANOV	{"email": "nivanov18061963@postgrespro.ru", "phone": "+70411245980"}
0005432646084	87D2EC	9924 818903	OLGA KRASNOVA	{"phone": "+70978907222"}
0005432646085	40CCA9	7288 526921	ALEKSANDR BARANOV	{"email": "baranov-aleksandr.021969@postgrespro.ru", "phone": "+70569347748"}
0005432646086	D57269	5577 585833	LEONID KUZMIN	{"phone": "+70154419393"}
0005432646087	C4EFD4	8413 184059	NADEZHDA OSIPOVA	{"email": "nosipova_071977@postgrespro.ru", "phone": "+70371839180"}
0005432646088	184E18	3566 418451	ANATOLIY GERASIMOV	{"email": "gerasimov.a_1972@postgrespro.ru", "phone": "+70970737216"}
0005432646089	184E18	7607 382133	SVETLANA EGOROVA	{"email": "egorova_s.1978@postgrespro.ru", "phone": "+70638163643"}
0005432646090	B42933	9724 517101	ALEKSANDR POPOV	{"phone": "+70169112897"}
0005432646091	D8D974	9729 704384	SVETLANA IVANOVA	{"phone": "+70251963452"}
0005432646092	A8898D	3777 856448	ANDREY VOLKOV	{"email": "andrey.volkov11071977@postgrespro.ru", "phone": "+70589839990"}
0005432646093	572804	5821 085992	GRIGORIY POPOV	{"phone": "+70102508240"}
0005432646094	572804	4334 272611	IRINA VASILEVA	{"email": "vasileva_irina_02031975@postgrespro.ru", "phone": "+70543802373"}
0005432646095	2158F7	3663 404298	ANDREY KARPOV	{"email": "karpov_a.051967@postgrespro.ru", "phone": "+70753133760"}
0005432646096	2158F7	6767 954088	MAKSIM MAKSIMOV	{"phone": "+70529000589"}
0005432646097	0309DE	4485 112882	MIKHAIL MOROZOV	{"email": "m-morozov-1983@postgrespro.ru", "phone": "+70481761895"}
0005432646098	B3DEB4	6235 036173	LEONID IVANOV	{"email": "l_ivanov_111972@postgrespro.ru", "phone": "+70382377064"}
0005432646099	C54399	8641 029438	YURIY KUZMIN	{"email": "y-kuzmin.09101966@postgrespro.ru", "phone": "+70589691194"}
0005432646100	C54399	4291 210139	ILSHAT SAVELEV	{"phone": "+70583951041"}
0005432646101	B36446	9608 381525	VIKTOR ANDREEV	{"email": "vandreev_081980@postgrespro.ru", "phone": "+70491711632"}
0005432646102	07CD8F	8698 567145	NIKOLAY SEMENOV	{"phone": "+70978892891"}
0005432646103	07CD8F	0181 220953	VALENTINA TARASOVA	{"phone": "+70497176225"}
0005432646104	E09278	3436 552476	SERGEY ZAKHAROV	{"phone": "+70564716380"}
0005432646105	E3FCA6	6402 632576	VITALIY KARPOV	{"email": "karpov_vitaliy.061968@postgrespro.ru", "phone": "+70720986180"}
0005432646106	098BB0	0546 192834	KSENIYA VASILEVA	{"email": "vasileva-kseniya09031970@postgrespro.ru", "phone": "+70593673374"}
0005432646107	B6A50D	0154 113599	SVETLANA POPOVA	{"email": "popovas_011964@postgrespro.ru", "phone": "+70474339131"}
0005432646108	B6A50D	4472 282555	IVAN SEMENOV	{"email": "ivan_semenov17011982@postgrespro.ru", "phone": "+70882934909"}
0005432646109	EAAB26	1885 530192	OLGA TIMOFEEVA	{"phone": "+70365600623"}
0005432646110	AE73FD	2348 085026	NIKOLAY PAVLOV	{"email": "pavlovn.071965@postgrespro.ru", "phone": "+70322178018"}
0005432646111	217137	9520 211421	RIMA FILIPPOVA	{"email": "rima.filippova-1973@postgrespro.ru", "phone": "+70837851944"}
0005432646112	9C1A82	9716 209873	ALINA SMIRNOVA	{"email": "smirnova-alina1972@postgrespro.ru", "phone": "+70974595388"}
0005432646113	9E9E37	3862 631279	DARYA SOKOLOVA	{"phone": "+70670798228"}
0005432646114	9E9E37	6739 896618	TATYANA DENISOVA	{"email": "tatyanadenisova-04051977@postgrespro.ru", "phone": "+70141464689"}
0005432646115	9E9E37	2360 057067	ALEKSANDR NOVIKOV	{"phone": "+70975884751"}
0005432646116	A7CC40	4048 673507	ILYA ANDREEV	{"phone": "+70773410039"}
0005432646117	FB47B4	8763 197505	GENNADIY CHERNOV	{"email": "gennadiychernov_20071974@postgrespro.ru", "phone": "+70869712695"}
0005432646118	320BE6	6063 095688	GRIGORIY ANTONOV	{"email": "g_antonov-06041971@postgrespro.ru", "phone": "+70462994455"}
0005432646119	90C91F	4679 446121	SOFYA ANTONOVA	{"phone": "+70569545996"}
0005432646120	DB650C	1891 754550	SERGEY SEMENOV	{"phone": "+70895777895"}
0005432646121	DB650C	1843 288242	NIKITA KULIKOV	{"email": "n_kulikov.081965@postgrespro.ru", "phone": "+70455484877"}
0005432646122	6A74DA	1441 690078	EVGENIY ZAKHAROV	{"email": "ezakharov061972@postgrespro.ru", "phone": "+70787029834"}
0005432646123	6A74DA	0711 321470	ROZA DAVYDOVA	{"phone": "+70757841222"}
0005432646124	0FAFEB	6276 968901	VALERIY KUZNECOV	{"email": "valeriykuznecov101973@postgrespro.ru", "phone": "+70821631852"}
0005432646125	0FAFEB	0253 042501	OLEG ZAKHAROV	{"email": "o.zakharov_1960@postgrespro.ru", "phone": "+70582085565"}
0005432646126	7A0FFD	8726 055937	DMITRIY MOROZOV	{"phone": "+70424641406"}
0005432646127	7A0FFD	6143 949811	ZINAIDA NAZAROVA	{"phone": "+70279478009"}
0005432646128	8F1952	3678 804187	NINA CHERNOVA	{"email": "n.chernova_13031990@postgrespro.ru", "phone": "+70759785646"}
0005432646129	5BDDEE	7008 297797	YURIY MELNIKOV	{"email": "y_melnikov_1967@postgrespro.ru", "phone": "+70981985419"}
0005432646130	7E3BEB	7342 001420	ALLA SMIRNOVA	{"email": "smirnova-alla.1978@postgrespro.ru", "phone": "+70638529068"}
0005432646131	1C65E8	4560 055303	VLADIMIR KONOVALOV	{"phone": "+70357485389"}
0005432646132	1D6D75	8278 175199	ALENA FROLOVA	{"email": "alena.frolova-02101977@postgrespro.ru", "phone": "+70412082701"}
0005432646133	1D6D75	4094 431658	NATALYA SERGEEVA	{"phone": "+70176810953"}
0005432646134	1E4975	9284 185062	SERGEY SOROKIN	{"phone": "+70975745683"}
0005432646135	1E4975	1972 868986	MATRENA VASILEVA	{"email": "matrena_vasileva.24061972@postgrespro.ru", "phone": "+70422171071"}
0005432646136	CAAC7C	6500 687608	PAVEL PAVLOV	{"email": "pavlov_p-1970@postgrespro.ru", "phone": "+70171183399"}
0005432646137	1FC20F	0002 556058	VLADISLAV VLASOV	{"phone": "+70943744409"}
0005432646138	06DBAD	6481 556149	NADEZHDA DENISOVA	{"email": "nadezhda-denisova.27041980@postgrespro.ru", "phone": "+70755352782"}
0005432646139	06DBAD	6685 490913	LIDIYA KUZNECOVA	{"email": "lkuznecova1975@postgrespro.ru", "phone": "+70756270753"}
0005432646140	7989C5	6367 074646	ANNA PETROVA	{"phone": "+70129862200"}
0005432646141	0DD314	3468 865809	YULIYA PAVLOVA	{"phone": "+70060508980"}
0005432646142	0DD314	1830 739190	VLADIMIR MIKHAYLOV	{"phone": "+70971176032"}
0005432646143	00878B	1266 361919	ANNA MALYSHEVA	{"phone": "+70246079554"}
0005432646144	27375E	2148 768220	YURIY YAKOVLEV	{"phone": "+70723159556"}
0005432646145	E0346F	6450 502468	NIKOLAY BONDARENKO	{"email": "nbondarenko12031973@postgrespro.ru", "phone": "+70077197519"}
0005432646146	336952	8798 995560	KHALIDA GRISHINA	{"email": "grishinakhalida071980@postgrespro.ru", "phone": "+70674284479"}
0005432646147	E68DB7	1256 189413	SERGEY FEDOROV	{"phone": "+70295206954"}
0005432646148	8FE5C6	1297 463692	YULIYA EGOROVA	{"phone": "+70243127118"}
0005432646149	4FC9FB	1013 028315	ANTON SHEVCHENKO	{"email": "ashevchenko.021980@postgrespro.ru", "phone": "+70388139093"}
0005432646150	ED96E6	2095 225746	OLGA NIKOLAEVA	{"email": "nikolaeva_o.1989@postgrespro.ru", "phone": "+70393142318"}
0005432646151	3B5F9B	9924 443324	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav16111968@postgrespro.ru", "phone": "+70624106676"}
0005432646152	3B5F9B	8073 962504	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr_28041977@postgrespro.ru", "phone": "+70753252674"}
0005432646153	105CDC	2885 855879	MAKSIM PETROV	{"email": "petrov.m.1967@postgrespro.ru", "phone": "+70869766092"}
0005432646154	0E4B5B	8138 008418	ALEKSANDR SOKOLOV	{"email": "sokolovaleksandr_1981@postgrespro.ru", "phone": "+70207382733"}
0005432646155	F42E3A	1513 512165	ANASTASIYA NESTEROVA	{"phone": "+70222690342"}
0005432646156	70899B	4618 549066	SERGEY POPOV	{"email": "sergey.popov.08121981@postgrespro.ru", "phone": "+70848578429"}
0005432646157	5C028C	3795 394654	ELENA IVANOVA	{"email": "ivanova.e.07041970@postgrespro.ru", "phone": "+70212608790"}
0005432646158	5C028C	9247 626305	RUSLAN DAVYDOV	{"phone": "+70785756895"}
0005432646159	79A361	9575 819872	NADEZHDA MIRONOVA	{"phone": "+70415713295"}
0005432646160	4D36DF	9804 228508	IGOR DENISOV	{"phone": "+70239597150"}
0005432646161	4D36DF	1275 568420	INESSA SIDOROVA	{"phone": "+70648063718"}
0005432646162	4D36DF	2482 087735	ALEKSANDR SMIRNOV	{"phone": "+70133634397"}
0005432646163	B19E94	2900 637895	EKATERINA ABRAMOVA	{"phone": "+70657137530"}
0005432646164	B19E94	5032 997951	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.061977@postgrespro.ru", "phone": "+70560597402"}
0005432646165	7FE092	8882 205827	NIKITA OSIPOV	{"phone": "+70874272317"}
0005432646166	B2E120	8103 217202	EVGENIY SIDOROV	{"email": "sidorovevgeniy_14121975@postgrespro.ru", "phone": "+70459245527"}
0005432646167	832D0B	0901 043566	TAMARA KAZAKOVA	{"email": "kazakova.tamara.06041996@postgrespro.ru", "phone": "+70183081750"}
0005432646168	832D0B	4554 950253	VLADIMIR ZAYCEV	{"email": "zaycevvladimir1966@postgrespro.ru", "phone": "+70132051395"}
0005432646169	CAD6EA	4539 447305	ANATOLIY SHEVCHENKO	{"email": "shevchenko-a_061972@postgrespro.ru", "phone": "+70355912851"}
0005432646170	7BB0B1	8821 301283	VERA NIKITINA	{"email": "vnikitina.1965@postgrespro.ru", "phone": "+70844395063"}
0005432646171	DDA011	4898 300393	ALEKSANDR POPOV	{"phone": "+70843248821"}
0005432646172	D2DCBF	1028 359255	NIKOLAY MATVEEV	{"phone": "+70043574717"}
0005432646173	D2DCBF	1198 571488	IRINA TARASOVA	{"email": "tarasova_i04081971@postgrespro.ru", "phone": "+70489666195"}
0005432646174	D76B47	0760 381093	MAKSIM PAVLOV	{"phone": "+70664837202"}
0005432646175	D76B47	9897 273467	MAKSIM KOZLOV	{"email": "kozlov-m.03071981@postgrespro.ru", "phone": "+70171314924"}
0005432646176	D937E3	7492 392832	NIKITA VOROBEV	{"phone": "+70490758493"}
0005432646177	D937E3	8644 600772	DMITRIY DENISOV	{"email": "d.denisov.081963@postgrespro.ru", "phone": "+70088832500"}
0005432646178	941A6C	3288 073933	ALEKSANDR NIKOLAEV	{"phone": "+70141562872"}
0005432646179	6E3D0E	0246 792273	LIDIYA IVANOVA	{"email": "ivanova-lidiya_031978@postgrespro.ru", "phone": "+70878769474"}
0005432646180	6E3D0E	7510 113726	TATYANA ALEKSEEVA	{"phone": "+70301557993"}
0005432646181	0811E2	9036 034063	OLGA ABRAMOVA	{"email": "o_abramova.061974@postgrespro.ru", "phone": "+70593999691"}
0005432646182	72D5AC	6641 298883	VIKTOR KUZMIN	{"email": "kuzmin_viktor-1967@postgrespro.ru", "phone": "+70041311566"}
0005432646183	72D5AC	7640 204874	ANDREY MIRONOV	{"phone": "+70301861778"}
0005432646184	650FCC	3285 401300	VERONIKA IVANOVA	{"email": "vivanova-14051970@postgrespro.ru", "phone": "+70821846276"}
0005432646185	8199BB	1769 888416	MARAT MIKHAYLOV	{"email": "mikhaylov.m_051962@postgrespro.ru", "phone": "+70520358410"}
0005432646186	8199BB	9407 083583	MARIYA DENISOVA	{"email": "mariyadenisova_031976@postgrespro.ru", "phone": "+70399156177"}
0005432646187	8199BB	5861 835650	LYUDMILA SIDOROVA	{"phone": "+70650855047"}
0005432646188	1EF075	6692 033137	VLADIMIR ALEKSANDROV	{"email": "v-aleksandrov-091959@postgrespro.ru", "phone": "+70499741080"}
0005432646189	E72A82	2577 536056	RAISA ROMANOVA	{"phone": "+70982740070"}
0005432646190	DD9902	5105 749375	IGOR MOISEEV	{"phone": "+70969435722"}
0005432646191	CC3A83	2500 505588	DENIS GUSEV	{"email": "denis.gusev.051961@postgrespro.ru", "phone": "+70058469397"}
0005432646192	CC3A83	7572 037964	NADEZHDA FEDOROVA	{"phone": "+70267866905"}
0005432646193	04A807	9975 431401	LIDIYA SMIRNOVA	{"phone": "+70759060454"}
0005432646194	3130DE	8491 867035	ANNA IVANOVA	{"phone": "+70371370877"}
0005432646195	3130DE	2828 741646	DARYA ANTONOVA	{"email": "daryaantonova-101978@postgrespro.ru", "phone": "+70985187425"}
0005432646196	90E7B6	0998 946764	IGOR FEDOROV	{"email": "fedorovigor.1966@postgrespro.ru", "phone": "+70935874905"}
0005432646197	AA2349	5740 173123	VALENTINA EGOROVA	{"email": "egorova.v.12041970@postgrespro.ru", "phone": "+70610235020"}
0005432646198	E82758	6180 063774	IRINA STEPANOVA	{"phone": "+70957487129"}
0005432646199	156A55	1193 491273	DMITRIY DAVYDOV	{"phone": "+70657188193"}
0005432646200	156A55	1596 294504	EVGENIY FOMIN	{"email": "e.fomin16091970@postgrespro.ru", "phone": "+70243975196"}
0005432646201	4BBFF2	7746 763726	NATALYA MASLOVA	{"phone": "+70644576131"}
0005432646202	4BBFF2	2568 815543	SERGEY KAZAKOV	{"phone": "+70152856743"}
0005432646203	EFB05E	0912 285799	FARIDA ANISIMOVA	{"phone": "+70851472806"}
0005432646204	12307F	2261 727574	LYUBOV POLYAKOVA	{"phone": "+70822965508"}
0005432646205	321615	3301 123230	ALEKSEY MOISEEV	{"email": "moiseeva.1979@postgrespro.ru", "phone": "+70868618943"}
0005432646206	2233E6	3607 584085	VERA TITOVA	{"email": "titova.v.23061989@postgrespro.ru", "phone": "+70521897102"}
0005432646207	2233E6	1152 694576	IRINA SCHERBAKOVA	{"phone": "+70365197792"}
0005432646208	FDFC5F	0032 674244	ALEKSANDR ABRAMOV	{"phone": "+70561060089"}
0005432646209	FDFC5F	1902 966678	VALERIY KOZLOV	{"phone": "+70138600242"}
0005432646210	47CA97	2845 479059	GALINA ANDREEVA	{"phone": "+70360071969"}
0005432646211	31F4EE	2753 362645	ANNA BOGDANOVA	{"email": "annabogdanova_21031979@postgrespro.ru", "phone": "+70350815586"}
0005432646212	31F4EE	4872 301719	ALEKSANDR DAVYDOV	{"email": "a.davydov_25081974@postgrespro.ru", "phone": "+70192551322"}
0005432646213	641600	0670 861029	SVETLANA IVANOVA	{"email": "ivanovas_13091969@postgrespro.ru", "phone": "+70580558200"}
0005432646214	641600	7091 090635	RAISA FILIPPOVA	{"phone": "+70603906937"}
0005432646215	A6EF94	3434 918965	ANNA VASILEVA	{"email": "anna-vasileva-12071978@postgrespro.ru", "phone": "+70501190340"}
0005432646216	C57423	5200 953767	STANISLAV IVANOV	{"email": "s-ivanov041974@postgrespro.ru", "phone": "+70726646307"}
0005432646217	4AC316	7268 736802	SERGEY PAVLOV	{"email": "pavlovs.23051973@postgrespro.ru", "phone": "+70922131699"}
0005432646218	6B4CAE	1848 519718	PETR GRIGOREV	{"email": "petr_grigorev_1977@postgrespro.ru", "phone": "+70656750802"}
0005432646219	6B4CAE	4632 561819	NADEZHDA RODIONOVA	{"email": "rodionova.n061978@postgrespro.ru", "phone": "+70833462016"}
0005432649315	218441	3440 323071	TIGRAN CHERNOV	{"phone": "+70263506919"}
0005432646220	50A8F7	7550 579067	KLAVDIYA ZHURAVLEVA	{"email": "klavdiya_zhuravleva051967@postgrespro.ru", "phone": "+70923112564"}
0005432646221	F0EAAB	6753 387902	EDUARD ZHUKOV	{"phone": "+70305367484"}
0005432646222	F0EAAB	2475 839954	OLGA STEPANOVA	{"email": "stepanova-olga.1978@postgrespro.ru", "phone": "+70587544794"}
0005432646223	A4AC53	2974 752882	SVETLANA TITOVA	{"phone": "+70795120330"}
0005432646224	A4AC53	5246 149586	TAISIYA ILINA	{"email": "ilina_taisiya.1969@postgrespro.ru", "phone": "+70665549415"}
0005432646225	23D905	9282 953800	OKSANA GRISHINA	{"phone": "+70694870478"}
0005432646226	582AA3	7420 004333	VASILIY BORISOV	{"email": "borisov_v1969@postgrespro.ru", "phone": "+70553955070"}
0005432646227	096432	1706 245022	ANNA POPOVA	{"phone": "+70088632948"}
0005432646228	096432	3653 759432	SERGEY BONDARENKO	{"email": "sergey.bondarenko1967@postgrespro.ru", "phone": "+70255209447"}
0005432646229	21284B	9218 579764	ANDREY OSIPOV	{"email": "osipov-andrey.1975@postgrespro.ru", "phone": "+70657342012"}
0005432646230	21284B	8704 556445	LYUBOV POTAPOVA	{"email": "lpotapova_101975@postgrespro.ru", "phone": "+70767226919"}
0005432646231	C2A58E	6693 779374	MARINA KUZNECOVA	{"email": "kuznecovam_1990@postgrespro.ru", "phone": "+70859889199"}
0005432646232	49A7EE	8681 740274	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-aleksandr.1961@postgrespro.ru", "phone": "+70867307757"}
0005432646233	49A7EE	0128 406608	YURIY FEDOTOV	{"email": "fedotov-y_25031965@postgrespro.ru", "phone": "+70733410157"}
0005432646234	49A7EE	3270 247351	LYUBOV SOROKINA	{"email": "sorokinal-07101974@postgrespro.ru", "phone": "+70372198516"}
0005432646235	04308C	5009 700652	VADIM KOROLEV	{"phone": "+70688680524"}
0005432646236	04308C	8106 848549	LIDIYA NESTEROVA	{"phone": "+70618974353"}
0005432646237	04308C	3343 316373	VALENTINA OSIPOVA	{"email": "v_osipova_14061979@postgrespro.ru", "phone": "+70423481407"}
0005432646238	3963EA	2606 829704	ELENA KUZNECOVA	{"email": "kuznecova.elena011975@postgrespro.ru", "phone": "+70640876531"}
0005432646239	3963EA	6167 124941	DENIS MAKSIMOV	{"email": "maksimov_denis_25101974@postgrespro.ru", "phone": "+70125882309"}
0005432646240	3963EA	6877 177541	ALEKSANDR NIKITIN	{"phone": "+70915523063"}
0005432646241	3050B2	6141 850620	TATYANA MOROZOVA	{"email": "tatyanamorozova1974@postgrespro.ru", "phone": "+70067199265"}
0005432646242	3050B2	7857 112204	EVGENIY PETROV	{"email": "petrov.e051965@postgrespro.ru", "phone": "+70514936450"}
0005432646243	482E34	6625 825081	IRINA NIKOLAEVA	{"phone": "+70852790406"}
0005432646244	61A683	1892 348065	VLADIMIR VASILEV	{"email": "vasilev.vladimir13061977@postgrespro.ru", "phone": "+70516491477"}
0005432646245	61A683	2612 467786	ALEKSANDR MIKHAYLOV	{"phone": "+70650938796"}
0005432646246	61A683	5199 007105	ALEKSEY KOZLOV	{"phone": "+70154583690"}
0005432646247	4F1B18	1080 314533	EVGENIYA KONDRATEVA	{"phone": "+70121564652"}
0005432646248	8A62B6	1784 481948	ALEKSANDR FROLOV	{"phone": "+70359303638"}
0005432646249	047E50	9437 061416	VALERIY KOZLOV	{"phone": "+70863464840"}
0005432646250	7E8412	7630 939822	IGOR NAZAROV	{"email": "igor.nazarov_09101979@postgrespro.ru", "phone": "+70014249147"}
0005432646251	7E8412	6820 737724	MIKHAIL KULIKOV	{"email": "m_kulikov-14091976@postgrespro.ru", "phone": "+70963052790"}
0005432646252	FB4863	7615 335503	ALEKSEY SEMENOV	{"phone": "+70509221677"}
0005432646253	CD4D9F	3458 436154	SERGEY POPOV	{"phone": "+70125710070"}
0005432646254	CD4D9F	8456 928127	OLGA NAUMOVA	{"phone": "+70950532412"}
0005432646255	8EEBF4	8585 151891	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov13071979@postgrespro.ru", "phone": "+70394680994"}
0005432646256	2376D0	7678 027691	RAISA MIKHAYLOVA	{"email": "rmikhaylova-18061973@postgrespro.ru", "phone": "+70758509136"}
0005432646257	2376D0	5911 923831	TATYANA FILATOVA	{"phone": "+70063481584"}
0005432646258	D31438	5893 160962	LYUBOV KONOVALOVA	{"email": "konovalovalyubov1968@postgrespro.ru", "phone": "+70932041900"}
0005432646259	237F33	8407 963595	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay-08041972@postgrespro.ru", "phone": "+70839908431"}
0005432646260	4A25E5	4439 102000	EKATERINA MOISEEVA	{"phone": "+70189082309"}
0005432646261	988D2F	8068 734173	YULIYA IVANOVA	{"email": "ivanovay-12021974@postgrespro.ru", "phone": "+70740532884"}
0005432646262	883878	6074 885619	MAKSIM IVANOV	{"phone": "+70866628117"}
0005432646263	A1D563	2193 328838	DARYA BOGDANOVA	{"email": "bogdanova-darya.081971@postgrespro.ru", "phone": "+70237070326"}
0005432646264	74CC07	4897 731777	MARGARITA AFANASEVA	{"email": "m_afanaseva-1967@postgrespro.ru", "phone": "+70919921852"}
0005432646265	40B144	0107 932569	NIKOLAY GERASIMOV	{"email": "n.gerasimov-21021954@postgrespro.ru", "phone": "+70906446863"}
0005432646266	40B144	3124 586025	DMITRIY KULIKOV	{"phone": "+70095324250"}
0005432646267	40B144	0866 721679	GALINA KUZNECOVA	{"email": "kuznecova_galina081978@postgrespro.ru", "phone": "+70940660258"}
0005432646268	C4468E	9840 264750	VALENTINA ANDREEVA	{"phone": "+70490531446"}
0005432646269	5D6D47	0981 715263	GALINA KUZNECOVA	{"email": "galina-kuznecova-27081972@postgrespro.ru", "phone": "+70469922056"}
0005432646270	5D6D47	5339 950358	VALENTINA FROLOVA	{"phone": "+70575093621"}
0005432646271	598F47	0672 179296	VERA BORISOVA	{"phone": "+70985928204"}
0005432646272	CEFED5	3042 404797	NATALYA KOLESNIKOVA	{"email": "natalyakolesnikova.031976@postgrespro.ru", "phone": "+70024743833"}
0005432646273	CEFED5	5936 088392	VALERIY KRASNOV	{"phone": "+70386798694"}
0005432646274	CEFED5	2824 839419	ANATOLIY ISAEV	{"email": "a-isaev_17051957@postgrespro.ru", "phone": "+70485979609"}
0005432646275	03E64F	9539 612917	OLEG KUZNECOV	{"email": "o.kuznecov.021977@postgrespro.ru", "phone": "+70674328786"}
0005432646276	833FA4	0333 691660	TATYANA KRASNOVA	{"phone": "+70404604884"}
0005432646277	D7911A	3772 105926	LIDIYA MAKAROVA	{"email": "makarova-lidiya_16061964@postgrespro.ru", "phone": "+70420474560"}
0005432646278	D9A761	4357 708790	INNA KULIKOVA	{"phone": "+70462243195"}
0005432646279	D9A761	9487 122855	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr.09101974@postgrespro.ru", "phone": "+70963410356"}
0005432646280	ACA1D9	3754 208170	ELENA EGOROVA	{"email": "elena-egorova.14081974@postgrespro.ru", "phone": "+70824945395"}
0005432646281	ACA1D9	3245 262972	NIKOLAY IVANOV	{"email": "nivanov1967@postgrespro.ru", "phone": "+70316338435"}
0005432646282	ACA1D9	4177 722122	ALEKSEY KISELEV	{"email": "alekseykiselev.011972@postgrespro.ru", "phone": "+70140743491"}
0005432646283	534B39	4203 666574	OLGA MAKSIMOVA	{"phone": "+70565949604"}
0005432646284	534B39	4727 965796	IRINA NOVIKOVA	{"email": "novikova-i_011978@postgrespro.ru", "phone": "+70873740125"}
0005432646285	534B39	6371 966136	YURIY KISELEV	{"phone": "+70290720140"}
0005432646286	8E22D2	3912 137521	LYUBOV YAKOVLEVA	{"phone": "+70769842360"}
0005432646287	C66356	1112 419325	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir_1974@postgrespro.ru", "phone": "+70642397658"}
0005432646288	DDAB59	3410 437770	ALEKSEY KAZAKOV	{"email": "a_kazakov.031975@postgrespro.ru", "phone": "+70044895828"}
0005432646289	5C2995	4806 090038	DENIS VASILEV	{"phone": "+70818371886"}
0005432646290	5C2995	5237 110741	NATALYA NAZAROVA	{"phone": "+70583811723"}
0005432646291	BE3C68	8014 989713	VITALIY MARTYNOV	{"phone": "+70388891189"}
0005432646292	3DB346	3057 065590	RUSLAN NOVIKOV	{"email": "novikov.ruslan-1972@postgrespro.ru", "phone": "+70736103393"}
0005432646293	3DB346	3816 235674	ANDREY KOROLEV	{"phone": "+70211871120"}
0005432646294	390F35	3347 040410	VYACHESLAV ABRAMOV	{"email": "vyacheslavabramov.1974@postgrespro.ru", "phone": "+70395731601"}
0005432646295	390F35	2791 539031	LYUBOV KUZMINA	{"email": "lkuzmina.041958@postgrespro.ru", "phone": "+70547940568"}
0005432646296	9ACAEB	9599 626342	SVETLANA VOROBEVA	{"phone": "+70291129113"}
0005432646297	B4E047	9697 199248	ALEKSANDR MOROZOV	{"email": "a-morozov_1964@postgrespro.ru", "phone": "+70769774266"}
0005432646298	B4E047	3120 056520	SOFYA DANILOVA	{"phone": "+70022403247"}
0005432646299	F440E4	4872 151614	IRINA IVANOVA	{"email": "ivanova.irina_1967@postgrespro.ru", "phone": "+70223047013"}
0005432646300	2790F8	2217 184068	ALEKSEY PAVLOV	{"phone": "+70142086331"}
0005432646301	6DBEB6	6173 566414	VLADIMIR ABRAMOV	{"email": "vladimirabramov_071965@postgrespro.ru", "phone": "+70494552550"}
0005432646302	6DBEB6	2837 844432	ALEKSANDR DENISOV	{"email": "denisov.aleksandr_17041968@postgrespro.ru", "phone": "+70984511771"}
0005432646303	80B9FD	8657 041959	ALEKSANDR GUSEV	{"email": "gusevaleksandr.1971@postgrespro.ru", "phone": "+70250932635"}
0005432646304	80B9FD	0348 661286	VIKTOR KUZNECOV	{"phone": "+70676619077"}
0005432646305	5BA496	6287 153923	OLGA MIKHAYLOVA	{"phone": "+70875389043"}
0005432646306	16EE81	1806 661528	VITALIY IVANOV	{"email": "ivanov.v_02041971@postgrespro.ru", "phone": "+70814116645"}
0005432646307	414888	2822 879046	NIKOLAY KOROLEV	{"email": "n-korolev28101977@postgrespro.ru", "phone": "+70653376230"}
0005432646308	47BFE4	8316 407634	ALEKSANDR ISAEV	{"phone": "+70920776542"}
0005432646309	022379	7401 627389	YURIY SCHERBAKOV	{"email": "scherbakov_yuriy_02071968@postgrespro.ru", "phone": "+70472977571"}
0005432646310	E0D011	1291 411713	OLGA BARANOVA	{"phone": "+70330429020"}
0005432646311	42F394	4622 969690	TATYANA IVANOVA	{"email": "ivanovat.06031973@postgrespro.ru", "phone": "+70670090962"}
0005432646312	CE1D93	4857 127830	ALLA SOLOVEVA	{"phone": "+70922887330"}
0005432646313	CE1D93	7364 345857	ANASTASIYA KOZLOVA	{"email": "anastasiyakozlova.1966@postgrespro.ru", "phone": "+70355971674"}
0005432646314	CE1D93	5111 980297	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov-1977@postgrespro.ru", "phone": "+70732649414"}
0005432646315	A1A30E	7627 407952	DANILA ANTONOV	{"email": "danilaantonov-1983@postgrespro.ru", "phone": "+70138221669"}
0005432646316	A1A30E	0839 107989	VLADIMIR RODIONOV	{"email": "vladimir_rodionov.1971@postgrespro.ru", "phone": "+70993126636"}
0005432646317	875815	2260 783871	ALEKSEY OSIPOV	{"phone": "+70028656257"}
0005432646318	875815	1893 455441	SERGEY ZAKHAROV	{"phone": "+70722405577"}
0005432646319	875815	3943 609674	VLADIMIR MIRONOV	{"phone": "+70068380996"}
0005432646320	9534A0	1361 373643	GALINA FOMINA	{"phone": "+70018891671"}
0005432646321	482D22	6298 056551	TATYANA ISAEVA	{"phone": "+70674407536"}
0005432646322	941B9D	0325 647803	NIKOLAY GORBUNOV	{"email": "n.gorbunov_1966@postgrespro.ru", "phone": "+70538872285"}
0005432646323	A6DB89	8793 626766	SVETLANA MAKAROVA	{"phone": "+70350984313"}
0005432646324	206D91	9373 078223	IGOR SMIRNOV	{"phone": "+70253792668"}
0005432646325	8A170A	4380 373953	SOFIYA PETROVA	{"email": "petrovas_061976@postgrespro.ru", "phone": "+70242031416"}
0005432646326	05C3A1	1851 405627	LIDIYA VASILEVA	{"phone": "+70721407485"}
0005432646327	FC33B0	8154 345393	GALINA MELNIKOVA	{"email": "melnikovagalina_08031977@postgrespro.ru", "phone": "+70085568580"}
0005432646328	7A356A	1585 775183	TATYANA ALEKSEEVA	{"phone": "+70304978563"}
0005432646329	892FCB	3946 814380	OLEG KOZLOV	{"email": "kozlov-o-081976@postgrespro.ru", "phone": "+70258229875"}
0005432646330	892FCB	5800 399946	MIKHAIL GUSEV	{"phone": "+70900479715"}
0005432646331	6E6F9C	4935 225512	OLGA NAUMOVA	{"phone": "+70447666825"}
0005432646332	6E6F9C	3330 534583	YURIY CHERNOV	{"phone": "+70148082102"}
0005432646333	ED0C3F	7690 001566	IVAN MIRONOV	{"phone": "+70790054671"}
0005432646334	10B340	9095 003715	LILIYA NIKITINA	{"email": "liliya-nikitina_1976@postgrespro.ru", "phone": "+70986153785"}
0005432646335	FC5B46	2451 162046	TATYANA VOLKOVA	{"email": "tatyanavolkova031978@postgrespro.ru", "phone": "+70411255272"}
0005432646336	FC5B46	0934 788534	ALINA OSIPOVA	{"phone": "+70871215226"}
0005432646337	0C1D50	8039 441345	ALEKSANDRA EGOROVA	{"email": "egorova.a_1972@postgrespro.ru", "phone": "+70663669225"}
0005432646338	16F12D	9334 211444	ALBERT SCHERBAKOV	{"phone": "+70085181970"}
0005432649497	2B4266	5386 862932	YURIY POPOV	{"phone": "+70737261545"}
0005432646339	0C6380	5582 649612	ALBERT MAKSIMOV	{"email": "maksimov_albert031961@postgrespro.ru", "phone": "+70824600099"}
0005432646340	0C6380	2756 466324	ALEKSANDR GRIGOREV	{"phone": "+70418543050"}
0005432646341	437395	8643 622084	EKATERINA LOGINOVA	{"email": "e-loginova1957@postgrespro.ru", "phone": "+70167905420"}
0005432646342	8C482E	1145 348217	DMITRIY KISELEV	{"email": "d-kiselev-1972@postgrespro.ru", "phone": "+70111843950"}
0005432646343	8C482E	3516 730182	ANDREY SERGEEV	{"phone": "+70867461639"}
0005432646344	0A5B92	5622 984492	TATYANA LEBEDEVA	{"phone": "+70429556853"}
0005432646345	4CAF00	0692 431063	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov-18021982@postgrespro.ru", "phone": "+70368597312"}
0005432646346	6FC7FA	1505 705454	VALENTINA PETROVA	{"phone": "+70594545883"}
0005432646347	708AB3	2106 745086	ELENA POTAPOVA	{"phone": "+70977008524"}
0005432646348	1BE199	4380 065750	VALENTINA DENISOVA	{"email": "denisova.valentina_04021972@postgrespro.ru", "phone": "+70222123153"}
0005432646349	09E5CE	5654 490884	VLADIMIR DENISOV	{"phone": "+70101179508"}
0005432646350	09E5CE	3223 786518	ALEKSANDR KISELEV	{"phone": "+70335455106"}
0005432646351	09E5CE	5448 704640	VERA OVCHINNIKOVA	{"phone": "+70002206182"}
0005432646352	DC7BB0	1836 092678	NADEZHDA ARKHIPOVA	{"email": "n-arkhipova.031982@postgrespro.ru", "phone": "+70525504017"}
0005432646353	DC7BB0	2080 178137	NINA PETROVA	{"email": "petrova-n18121974@postgrespro.ru", "phone": "+70109604742"}
0005432646354	BF6E50	4991 526214	TIMOFEY OSIPOV	{"phone": "+70482301311"}
0005432646355	BF6E50	7806 820531	ELENA MOROZOVA	{"email": "e.morozova_041978@postgrespro.ru", "phone": "+70721384276"}
0005432646356	87E3A9	9880 247998	GENNADIY ZHUKOV	{"email": "g-zhukov051962@postgrespro.ru", "phone": "+70311941810"}
0005432646357	BDFC82	2346 815640	LYUBOV AKIMOVA	{"phone": "+70030821282"}
0005432646358	69A6B9	1826 820195	ELENA IVANOVA	{"email": "e.ivanova.1967@postgrespro.ru", "phone": "+70717482900"}
0005432646359	3EDD30	3676 357008	VERA TITOVA	{"email": "vera-titova111985@postgrespro.ru", "phone": "+70265920845"}
0005432646360	3EDD30	8505 020678	OLEG RODIONOV	{"phone": "+70830443120"}
0005432646361	3EDD30	5665 118503	ELENA ZHUKOVA	{"phone": "+70109719585"}
0005432646362	00E3A1	2883 623483	VLADIMIR KUZNECOV	{"phone": "+70182284503"}
0005432646363	1A3767	3509 412198	ANDREY ILIN	{"phone": "+70544184050"}
0005432646364	6040C7	9324 384185	VLADIMIR IVANOV	{"email": "ivanovvladimir_1988@postgrespro.ru", "phone": "+70818667418"}
0005432646365	6040C7	7290 382482	ALEKSEY KOROLEV	{"email": "aleksey-korolev-1974@postgrespro.ru", "phone": "+70052308703"}
0005432646366	548227	2327 097443	OKSANA ZAKHAROVA	{"email": "zakharovaoksana.1967@postgrespro.ru", "phone": "+70111686472"}
0005432646367	87D89A	6196 562079	ANDREY TARASOV	{"email": "tarasov.a.05011970@postgrespro.ru", "phone": "+70836372966"}
0005432646368	87D89A	2695 300144	EKATERINA ANISIMOVA	{"phone": "+70065928912"}
0005432646369	3BD210	8413 907107	SVETLANA NESTEROVA	{"email": "s-nesterova16101966@postgrespro.ru", "phone": "+70237175393"}
0005432646370	67AC6F	7019 418253	SVETLANA ZAKHAROVA	{"email": "zakharovasvetlana_1969@postgrespro.ru", "phone": "+70199482446"}
0005432646371	7FC72D	0856 883014	ALEKSANDR MIRONOV	{"phone": "+70042066439"}
0005432646372	580716	2113 167832	OLEG IVANOV	{"email": "oleg_ivanov-27101970@postgrespro.ru", "phone": "+70152880845"}
0005432646373	FA57A5	0836 669693	STEPAN ZHUKOV	{"phone": "+70309185051"}
0005432646374	B1551E	4139 760173	TATYANA ALEKSANDROVA	{"email": "aleksandrova_t1964@postgrespro.ru", "phone": "+70479195160"}
0005432646375	1D4D22	0628 601249	EKATERINA EFREMOVA	{"email": "efremovae1971@postgrespro.ru", "phone": "+70481086503"}
0005432646376	1D4D22	6604 050914	TATYANA MOROZOVA	{"email": "morozova_t_11081967@postgrespro.ru", "phone": "+70634511117"}
0005432646377	1D4D22	4919 385242	NATALYA VOROBEVA	{"email": "vorobevan.1957@postgrespro.ru", "phone": "+70322610162"}
0005432646378	E0BEB6	5891 458759	SERGEY ALEKSEEV	{"phone": "+70244941423"}
0005432646379	E0BEB6	8865 539834	NATALYA POTAPOVA	{"phone": "+70151201951"}
0005432649296	00AC6D	7947 617026	MARINA BOGDANOVA	{"email": "marina_bogdanova.1962@postgrespro.ru", "phone": "+70351404216"}
0005432649297	9972D6	4341 692519	VYACHESLAV ROMANOV	{"phone": "+70308292544"}
0005432649298	B5FC76	3182 295317	KRISTINA MASLOVA	{"email": "maslova-kristina_1974@postgrespro.ru", "phone": "+70246490791"}
0005432649299	440DE0	0477 857788	OLGA POPOVA	{"phone": "+70989667186"}
0005432649300	440DE0	1534 815963	EVDOKIYA PAVLOVA	{"phone": "+70505161125"}
0005432649301	7607AA	0093 412068	ANNA KOROLEVA	{"email": "korolevaa.1965@postgrespro.ru", "phone": "+70280173209"}
0005432649302	22A2DB	5401 120721	ROMAN DAVYDOV	{"email": "davydov-r.021978@postgrespro.ru", "phone": "+70028129928"}
0005432649303	2C57AD	3079 874801	MAKSIM GORBUNOV	{"phone": "+70866365991"}
0005432649304	B0C590	1992 555846	SERGEY KUZMIN	{"email": "kuzmin_sergey04011965@postgrespro.ru", "phone": "+70799432400"}
0005432649305	700FA6	8277 281015	VIKTORIYA ARKHIPOVA	{"phone": "+70772592921"}
0005432649306	700FA6	1729 290778	NADEZHDA KONDRATEVA	{"phone": "+70290356724"}
0005432649307	AF67AB	2225 850612	STEPAN FROLOV	{"email": "stepanfrolov-1972@postgrespro.ru", "phone": "+70916283874"}
0005432649308	B2E304	4592 992509	POLINA MATVEEVA	{"phone": "+70742644456"}
0005432649309	478233	6612 360506	NIKOLAY ROMANOV	{"phone": "+70575102178"}
0005432649310	E4DA22	7912 188696	ANNA FILATOVA	{"email": "filatova_a.06121979@postgrespro.ru", "phone": "+70934494620"}
0005432649311	097830	8335 334674	VIKTOR NOVIKOV	{"email": "viktor-novikov_1983@postgrespro.ru", "phone": "+70609913492"}
0005432649312	C2395B	3456 456192	ALEKSANDR PETROV	{"email": "aleksandrpetrov-04101964@postgrespro.ru", "phone": "+70668512048"}
0005432649313	6839E9	0603 989675	GALIYA FROLOVA	{"phone": "+70348676950"}
0005432649314	98D770	4395 632909	ALEKSEY KOZLOV	{"phone": "+70786205305"}
0005432649316	CDF689	2984 132890	TATYANA NAZAROVA	{"email": "nazarova-t-1965@postgrespro.ru", "phone": "+70356987213"}
0005432649317	CDF689	0522 614990	RUSLAN NIKITIN	{"email": "r.nikitin-1982@postgrespro.ru", "phone": "+70077663892"}
0005432649318	CDF689	1686 312969	TATYANA OSIPOVA	{"phone": "+70012997292"}
0005432649319	009E4D	3396 295341	NATALYA NIKITINA	{"phone": "+70630773066"}
0005432649320	009E4D	4030 066772	ALEKSEY ZAYCEV	{"email": "zaycev_aleksey_1969@postgrespro.ru", "phone": "+70868528984"}
0005432649321	AA3EBB	7982 620397	ALEKSANDR FEDOTOV	{"email": "fedotov-a-101971@postgrespro.ru", "phone": "+70931955862"}
0005432649322	AA3EBB	1882 111986	IVAN KUZNECOV	{"email": "kuznecov_i-121973@postgrespro.ru", "phone": "+70749797674"}
0005432649323	F9B79E	9061 414800	TATYANA VOLKOVA	{"email": "t.volkova.21091978@postgrespro.ru", "phone": "+70349532218"}
0005432649324	57C14E	6543 912220	SEMEN SMIRNOV	{"email": "smirnov.semen-051984@postgrespro.ru", "phone": "+70728047302"}
0005432649325	57C14E	4752 825153	KRISTINA MASLOVA	{"email": "maslovakristina_021971@postgrespro.ru", "phone": "+70960447587"}
0005432649326	E046B6	5445 598589	VASILIY FROLOV	{"phone": "+70689303746"}
0005432649327	1F731B	1167 804577	DMITRIY OSIPOV	{"email": "osipov_d_1970@postgrespro.ru", "phone": "+70799849902"}
0005432649328	3762AA	5828 884600	TATYANA NIKITINA	{"email": "nikitina.t03031975@postgrespro.ru", "phone": "+70005708346"}
0005432649329	E1F708	5787 850658	SVETLANA SOROKINA	{"phone": "+70734890284"}
0005432649330	CE581C	2470 843965	OLGA NIKITINA	{"email": "nikitina_o1971@postgrespro.ru", "phone": "+70654913296"}
0005432649331	D3D257	4487 797048	IRINA DAVYDOVA	{"email": "irina-davydova-021973@postgrespro.ru", "phone": "+70465694383"}
0005432649332	FE3880	6023 146725	SOFYA ANDREEVA	{"phone": "+70683366874"}
0005432649333	2B0A26	7124 961760	ILYA SCHERBAKOV	{"email": "scherbakov-ilya.051968@postgrespro.ru", "phone": "+70484923052"}
0005432649334	2B0A26	1685 206723	ANASTASIYA EFIMOVA	{"email": "efimova-a_101959@postgrespro.ru", "phone": "+70445926598"}
0005432649335	FA087A	9702 904846	IRINA EFREMOVA	{"email": "efremovai-1982@postgrespro.ru", "phone": "+70943730108"}
0005432649336	FB251C	8988 866421	SERGEY KRASNOV	{"phone": "+70692872652"}
0005432649337	82206B	6612 018615	MARIYA KUDRYASHOVA	{"email": "mkudryashova1977@postgrespro.ru", "phone": "+70562063495"}
0005432649338	82206B	7626 098834	STANISLAV VASILEV	{"email": "s_vasilev.31121970@postgrespro.ru", "phone": "+70475912032"}
0005432649339	28A1C5	9539 831165	ANNA SMIRNOVA	{"phone": "+70160804071"}
0005432649340	28A1C5	0501 016280	ELENA KUZNECOVA	{"email": "kuznecovaelena1975@postgrespro.ru", "phone": "+70164612655"}
0005432649341	28A1C5	5147 707832	VIKTOR KUDRYASHOV	{"email": "kudryashov-v.071982@postgrespro.ru", "phone": "+70965345583"}
0005432649342	3A5BBC	1491 549141	VLADISLAV KUZMIN	{"phone": "+70493392886"}
0005432649343	6848A1	0509 797322	KLAVDIYA ALEKSANDROVA	{"email": "k-aleksandrova_1971@postgrespro.ru", "phone": "+70989667594"}
0005432649344	27F460	6122 153267	OKSANA PAVLOVA	{"email": "pavlova.oksana.12011969@postgrespro.ru", "phone": "+70602777275"}
0005432649345	71D0DD	6363 704864	TAMARA STEPANOVA	{"phone": "+70652666704"}
0005432649346	71D0DD	0507 338769	TAMARA NIKOLAEVA	{"email": "t.nikolaeva_021977@postgrespro.ru", "phone": "+70484140161"}
0005432649347	078B37	5459 781438	EMILIYA PETROVA	{"phone": "+70072796293"}
0005432649348	078B37	3430 865990	VALENTINA PAVLOVA	{"email": "pavlova.v_07041978@postgrespro.ru", "phone": "+70455624281"}
0005432649349	29C218	8242 349772	VYACHESLAV ROMANOV	{"phone": "+70920319707"}
0005432649350	745A61	6815 605038	IRINA POPOVA	{"email": "irina_popova.1966@postgrespro.ru", "phone": "+70748333071"}
0005432649351	745A61	2813 904499	ALEKSEY KUZNECOV	{"phone": "+70855553864"}
0005432649352	CBBB57	7305 179152	ALEKSANDR POPOV	{"phone": "+70496608474"}
0005432649353	BFD7D5	3163 602886	OLGA MOISEEVA	{"phone": "+70071066296"}
0005432649354	BFD7D5	1945 829045	DENIS GORBUNOV	{"phone": "+70535338101"}
0005432649355	B91515	0748 083772	LIDIYA PETROVA	{"phone": "+70810513999"}
0005432649356	B91515	2482 758901	NATALYA LUKYANOVA	{"phone": "+70448569867"}
0005432649357	B7C6EE	8659 374969	YURIY FILIPPOV	{"phone": "+70180258537"}
0005432649358	40BA22	1662 238064	POLINA FADEEVA	{"email": "fadeevap-071983@postgrespro.ru", "phone": "+70172234921"}
0005432649359	40BA22	8414 085747	SERGEY KAZAKOV	{"phone": "+70757067613"}
0005432649360	B23A8F	3510 347338	IGOR MATVEEV	{"phone": "+70124062169"}
0005432649361	056349	9248 495831	SOFIYA CHERNOVA	{"email": "sofiya_chernova-011977@postgrespro.ru", "phone": "+70649764065"}
0005432649362	056349	6580 257594	MIKHAIL MIKHAYLOV	{"phone": "+70285005390"}
0005432649363	3448FA	7975 839345	EVGENIYA FROLOVA	{"email": "evgeniyafrolova-23091978@postgrespro.ru", "phone": "+70807782894"}
0005432649364	5D4340	8151 081378	SERGEY CHERNOV	{"phone": "+70523598298"}
0005432649365	10FF66	0028 356532	ALBINA NOVIKOVA	{"phone": "+70129086968"}
0005432649366	10FF66	4801 532112	EVGENIY IVANOV	{"email": "ivanovevgeniy_1962@postgrespro.ru", "phone": "+70718949854"}
0005432649367	AE38D7	2521 331411	ANNA MAKAROVA	{"email": "makarova_anna23021971@postgrespro.ru", "phone": "+70029250631"}
0005432649368	1D7151	1264 217694	TATYANA SOROKINA	{"email": "sorokina.tatyana_1969@postgrespro.ru", "phone": "+70034524366"}
0005432649369	6199CC	0165 040884	LYUDMILA LUKYANOVA	{"email": "lukyanoval-041971@postgrespro.ru", "phone": "+70585660733"}
0005432649370	9D5EDC	8874 162721	ALEKSANDR SMIRNOV	{"phone": "+70250715896"}
0005432649371	DB55E3	2516 664669	NINA KOROLEVA	{"phone": "+70411010933"}
0005432649372	DB55E3	1438 180478	ANASTASIYA VLASOVA	{"email": "vlasova.anastasiya_111980@postgrespro.ru", "phone": "+70703039898"}
0005432649373	3DBBC5	7782 907299	VALENTINA AFANASEVA	{"phone": "+70549348804"}
0005432649374	97859D	9646 549329	LYUDMILA SIDOROVA	{"email": "sidorova_lyudmila.12081971@postgrespro.ru", "phone": "+70267886410"}
0005432649375	97859D	6280 651909	SVETLANA FEDOROVA	{"phone": "+70462329663"}
0005432649376	97859D	5323 947751	VASILIY ABRAMOV	{"email": "abramov-vasiliy-1971@postgrespro.ru", "phone": "+70158182015"}
0005432649377	FD30F5	8970 993623	ARMEN ABRAMOV	{"phone": "+70342478506"}
0005432649378	FD30F5	5625 669898	MARIYA ORLOVA	{"phone": "+70391847167"}
0005432649379	0678BF	0589 857512	ZINAIDA MEDVEDEVA	{"phone": "+70732151604"}
0005432649380	0678BF	4502 147023	VALERIY GERASIMOV	{"email": "v_gerasimov.15091979@postgrespro.ru", "phone": "+70247189682"}
0005432649381	0F0F4A	0835 391393	VLADIMIR PETROV	{"phone": "+70091459087"}
0005432649382	0F0F4A	1723 845687	IVAN IVANOV	{"phone": "+70869255331"}
0005432649383	C81F43	2373 639043	OLGA SOLOVEVA	{"email": "soloveva_o-111967@postgrespro.ru", "phone": "+70735006120"}
0005432649384	C81F43	1832 586922	YURIY SCHERBAKOV	{"phone": "+70068577070"}
0005432649385	2C0C53	3930 534208	MARINA ORLOVA	{"phone": "+70517152333"}
0005432649386	8174F7	7492 880396	OLGA PETROVA	{"phone": "+70356817334"}
0005432649387	11BFD2	6349 149919	VALENTIN KOZLOV	{"phone": "+70961708841"}
0005432649388	E22691	3737 899933	KLAVDIYA SERGEEVA	{"email": "klavdiya-sergeeva.121981@postgrespro.ru", "phone": "+70506412230"}
0005432649389	4DF3BF	5654 254448	MARINA FILIPPOVA	{"email": "filippovamarina_031966@postgrespro.ru", "phone": "+70472476538"}
0005432649390	9F1585	1105 753949	OLEG KISELEV	{"phone": "+70577145722"}
0005432649391	5DA7DE	6503 083115	TIMUR NOVIKOV	{"email": "tnovikov27061971@postgrespro.ru", "phone": "+70891452732"}
0005432649392	5DA7DE	6067 449986	VYACHESLAV POPOV	{"phone": "+70519906516"}
0005432649393	D9D697	9803 257865	ELENA VOLKOVA	{"phone": "+70675740006"}
0005432649394	D9D697	7942 985941	ROMAN GRIGOREV	{"email": "grigorev.roman-111974@postgrespro.ru", "phone": "+70252873957"}
0005432649395	8BEB82	3043 606547	ELENA ISAEVA	{"phone": "+70566962348"}
0005432649396	224F2E	6898 601050	ALEVTINA BELOVA	{"phone": "+70825971419"}
0005432649397	FBD850	6658 466252	NATALYA GUSEVA	{"email": "guseva.natalya-06041961@postgrespro.ru", "phone": "+70640116023"}
0005432649398	EAF3AA	8901 797711	SVETLANA ARKHIPOVA	{"email": "svetlana_arkhipova_06061977@postgrespro.ru", "phone": "+70202277882"}
0005432649399	B2F1AF	9764 724308	SERGEY IVANOV	{"phone": "+70055271447"}
0005432649400	0BDC02	1146 438206	VLADIMIR YAKOVLEV	{"phone": "+70379153814"}
0005432649401	28D4F6	1678 128670	DENIS PAVLOV	{"email": "denispavlov.011981@postgrespro.ru", "phone": "+70481016072"}
0005432649402	28D4F6	5359 355154	YAROSLAV SIDOROV	{"email": "yaroslav.sidorov_051972@postgrespro.ru", "phone": "+70848040785"}
0005432649403	4E77D7	7806 484036	ANNA NIKITINA	{"email": "a.nikitina16021964@postgrespro.ru", "phone": "+70310198791"}
0005432649404	66DB57	9377 522094	YULIYA KUDRYASHOVA	{"email": "kudryashova_yuliya-1989@postgrespro.ru", "phone": "+70982150567"}
0005432649405	AC2288	1937 439130	ALEKSANDR MATVEEV	{"email": "aleksandrmatveev091979@postgrespro.ru", "phone": "+70652816994"}
0005432649406	E2EF6D	6629 007396	ARTEM NAZAROV	{"email": "a_nazarov1976@postgrespro.ru", "phone": "+70062315938"}
0005432649407	DA6B16	2495 566957	NATALYA IVANOVA	{"email": "ivanova-n-1973@postgrespro.ru", "phone": "+70374357701"}
0005432649408	321AE1	6400 632235	ALEKSEY FROLOV	{"email": "frolov_a.1974@postgrespro.ru", "phone": "+70873822631"}
0005432649409	122CB8	8672 755800	VALERIYA GERASIMOVA	{"email": "v.gerasimova-1968@postgrespro.ru", "phone": "+70883687621"}
0005432649410	1742ED	3431 974373	RINAT IVANOV	{"phone": "+70339356557"}
0005432649411	6A797E	8006 550641	MARGARITA VASILEVA	{"phone": "+70102587734"}
0005432649412	BB8513	6990 139420	ALEKSANDR FOMIN	{"email": "fomin_a26021975@postgrespro.ru", "phone": "+70137448393"}
0005432649413	BB8513	9937 547944	DENIS VASILEV	{"email": "vasilev.d031969@postgrespro.ru", "phone": "+70112189874"}
0005432649414	18BFE2	4819 522073	ALEKSEY ANDREEV	{"phone": "+70828407015"}
0005432649415	670356	3310 621071	KIRILL KARPOV	{"email": "k-karpov051981@postgrespro.ru", "phone": "+70776787212"}
0005432649416	4A5F72	1348 655894	RAISA GORBUNOVA	{"phone": "+70918300899"}
0005432649417	83194A	4879 434231	TATYANA ABRAMOVA	{"phone": "+70534853641"}
0005432649418	2717BB	4431 426315	ELENA EGOROVA	{"phone": "+70084397080"}
0005432649419	C4928B	4412 337742	GEORGIY NIKITIN	{"phone": "+70209938839"}
0005432649420	8EC85A	7543 610331	VASILIY ABRAMOV	{"phone": "+70128044087"}
0005432649421	8EC85A	4983 717224	IRINA MASLOVA	{"email": "maslova_i.061968@postgrespro.ru", "phone": "+70277659493"}
0005432649422	5109FD	4464 148788	NIKOLAY VLASOV	{"phone": "+70367555374"}
0005432649423	5109FD	5222 108989	YAROSLAV VASILEV	{"email": "yaroslav-vasilev.121977@postgrespro.ru", "phone": "+70055138567"}
0005432649424	476B93	9707 942825	OLGA MATVEEVA	{"phone": "+70805764777"}
0005432649425	DB1B30	5742 239001	VALENTINA ZOTOVA	{"phone": "+70355806065"}
0005432649426	DB1B30	0056 455655	TATYANA KULIKOVA	{"email": "tatyana-kulikova.06021983@postgrespro.ru", "phone": "+70952305563"}
0005432649427	43D928	5835 068890	DIANA LAZAREVA	{"email": "lazareva_diana1975@postgrespro.ru", "phone": "+70988069558"}
0005432649428	43D928	8554 358891	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov-26101958@postgrespro.ru", "phone": "+70359003446"}
0005432649429	3B9FD3	3645 257602	NINA SIDOROVA	{"email": "sidorova.nina_02021972@postgrespro.ru", "phone": "+70674548851"}
0005432649430	3B9FD3	6991 371062	ANDREY EGOROV	{"email": "andrey-egorov-1971@postgrespro.ru", "phone": "+70519237030"}
0005432649431	4F249D	3693 703459	VLADIMIR POPOV	{"email": "v_popov111973@postgrespro.ru", "phone": "+70334509131"}
0005432649432	4F249D	9531 034627	VLADIMIR TIMOFEEV	{"phone": "+70332690121"}
0005432649433	6AD25D	5462 663414	VYACHESLAV RODIONOV	{"phone": "+70886019263"}
0005432649434	73B5D3	3319 192538	SERGEY MOROZOV	{"phone": "+70537231078"}
0005432649435	F7A938	0774 008030	LYUDMILA SEMENOVA	{"phone": "+70058917734"}
0005432649436	F7A938	1504 666652	VERA DENISOVA	{"phone": "+70121772145"}
0005432649437	F7A938	6804 880759	MAKSIM KUZNECOV	{"email": "maksim-kuznecov1969@postgrespro.ru", "phone": "+70548972309"}
0005432649438	C35B52	5789 291129	NELLI ABRAMOVA	{"phone": "+70277483746"}
0005432649439	C35B52	1662 162866	SOFIYA SEMENOVA	{"email": "sofiya.semenova.041971@postgrespro.ru", "phone": "+70209043438"}
0005432649440	DB6E55	2822 024750	SVETLANA SCHERBAKOVA	{"phone": "+70680396111"}
0005432649441	DB6E55	3562 816379	ELDAR MAKSIMOV	{"email": "e.maksimov-121965@postgrespro.ru", "phone": "+70000954157"}
0005432649442	2DD070	9730 748799	ANASTASIYA MEDVEDEVA	{"phone": "+70497597589"}
0005432649443	2DD070	1358 809001	MARINA ARKHIPOVA	{"email": "m_arkhipova-1975@postgrespro.ru", "phone": "+70079328425"}
0005432649444	3046E8	8089 862450	SERGEY SEMENOV	{"phone": "+70661173572"}
0005432649445	78EF6B	1396 197864	RIMMA ZOTOVA	{"phone": "+70720765633"}
0005432649446	78EF6B	9028 332112	MARINA FADEEVA	{"email": "fadeeva-marina-061987@postgrespro.ru", "phone": "+70287679560"}
0005432649447	78EF6B	0399 395210	VLADISLAV SMIRNOV	{"phone": "+70122638977"}
0005432649448	78EF6B	5925 144706	TAMARA GAVRILOVA	{"email": "tgavrilova.021978@postgrespro.ru", "phone": "+70804895796"}
0005432649449	95E41C	0895 536879	VALENTINA ISAEVA	{"email": "isaeva.v091966@postgrespro.ru", "phone": "+70931163228"}
0005432649450	95E41C	7359 081208	TAMARA RODIONOVA	{"email": "tamara-rodionova-02081961@postgrespro.ru", "phone": "+70480935608"}
0005432649451	29F638	1758 817127	ELENA MASLOVA	{"phone": "+70728058083"}
0005432649452	29F638	3544 225087	ELLA KULIKOVA	{"email": "kulikovaella_1963@postgrespro.ru", "phone": "+70058993619"}
0005432649453	900FB6	3641 347530	ROMAN SCHERBAKOV	{"phone": "+70896192948"}
0005432649454	230165	4790 643198	MARIYA MAKAROVA	{"email": "mariya-makarova051969@postgrespro.ru", "phone": "+70640646029"}
0005432649455	F64298	4879 222989	PETR ZHURAVLEV	{"phone": "+70877675841"}
0005432649456	F64298	6694 848131	VIKTOR SAVELEV	{"email": "savelev-v041985@postgrespro.ru", "phone": "+70205756887"}
0005432649457	64FB1E	8397 515368	DARYA VOLKOVA	{"phone": "+70532155044"}
0005432649458	3631BD	9119 955398	NINA ALEKSEEVA	{"email": "alekseeva-nina_1963@postgrespro.ru", "phone": "+70393632351"}
0005432649459	3631BD	8110 469412	INGA SIDOROVA	{"phone": "+70691204902"}
0005432649460	3631BD	7244 172188	YULIYA ISAEVA	{"email": "y-isaeva_1968@postgrespro.ru", "phone": "+70555216778"}
0005432649461	724484	6387 531990	GALINA EGOROVA	{"email": "egorova.galina.061964@postgrespro.ru", "phone": "+70067317983"}
0005432649462	0CDD53	3625 888007	PAVEL SOKOLOV	{"phone": "+70923662076"}
0005432649463	B7BDD7	0907 151632	IVAN ZAKHAROV	{"phone": "+70780246828"}
0005432649464	B7BDD7	5873 303279	LYUDMILA SMIRNOVA	{"phone": "+70752224552"}
0005432649465	99840D	0614 709977	EVGENIY KUZMIN	{"phone": "+70344657382"}
0005432649466	99840D	5604 565118	VADIM ALEKSEEV	{"email": "alekseev-vadim-1970@postgrespro.ru", "phone": "+70479106425"}
0005432649467	C2A7AB	8510 727671	EVGENIY KULIKOV	{"email": "e-kulikov_041979@postgrespro.ru", "phone": "+70033964789"}
0005432649468	31B821	3637 501156	STANISLAV EGOROV	{"email": "segorov_111972@postgrespro.ru", "phone": "+70436533257"}
0005432649469	DB6F98	0892 572822	LYUBOV ROMANOVA	{"phone": "+70723816536"}
0005432649470	0BD3A9	2688 590335	SERGEY ZAKHAROV	{"email": "zakharov-s_31101970@postgrespro.ru", "phone": "+70936831360"}
0005432649471	E59C17	7160 052875	ALEKSANDR FROLOV	{"email": "frolov_a_1957@postgrespro.ru", "phone": "+70483149107"}
0005432649472	E59C17	2076 117236	NINA ALEKSEEVA	{"phone": "+70077231092"}
0005432649473	1C378C	7280 146926	EKATERINA KOZLOVA	{"phone": "+70380858847"}
0005432649474	99CF68	4563 125077	VLADIMIR FEDOROV	{"email": "fedorov_v1974@postgrespro.ru", "phone": "+70620809722"}
0005432649475	60DADD	1113 505369	VALERIY NIKITIN	{"phone": "+70714165123"}
0005432649476	628902	6590 258890	GENNADIY MIKHAYLOV	{"email": "mikhaylov.g.051965@postgrespro.ru", "phone": "+70575504121"}
0005432649477	628902	5878 801098	DENIS FROLOV	{"email": "frolov.denis_12031972@postgrespro.ru", "phone": "+70101374138"}
0005432649478	2A8DEB	2726 498437	SVETLANA FROLOVA	{"email": "s_frolova-121976@postgrespro.ru", "phone": "+70832659774"}
0005432649479	51F6AB	4581 599147	ELENA GAVRILOVA	{"email": "gavrilova_elena_1979@postgrespro.ru", "phone": "+70010323191"}
0005432649480	BA0555	9527 113774	MARINA FILIPPOVA	{"email": "filippovamarina.1966@postgrespro.ru", "phone": "+70586058430"}
0005432649481	7EC0A6	2390 729179	EVGENIY STEPANOV	{"phone": "+70890030179"}
0005432649482	7EC0A6	4232 690633	TIMUR ZAKHAROV	{"email": "zakharov.timur-1957@postgrespro.ru", "phone": "+70085080373"}
0005432649483	7EC0A6	7485 808165	RIMMA PAVLOVA	{"email": "pavlova_r.06061976@postgrespro.ru", "phone": "+70807029821"}
0005432649484	3D104B	5533 427120	OLGA YUDINA	{"phone": "+70009544916"}
0005432649485	3D104B	7028 863243	LYUDMILA MIKHAYLOVA	{"email": "lyudmila.mikhaylova.041983@postgrespro.ru", "phone": "+70018191851"}
0005432649486	F6B54B	3131 679108	SERGEY NAZAROV	{"email": "sergey-nazarov-1961@postgrespro.ru", "phone": "+70630424755"}
0005432649487	43E07C	3324 438219	LEONID MELNIKOV	{"phone": "+70817944352"}
0005432649488	63805F	3098 001247	ELENA NIKITINA	{"email": "e.nikitina081961@postgrespro.ru", "phone": "+70953170241"}
0005432649489	0D384B	2190 493269	KAMILLA MAKAROVA	{"phone": "+70058056958"}
0005432649490	E2E300	1828 409753	NADEZHDA VASILEVA	{"phone": "+70407446993"}
0005432649491	9EBEE6	9368 329985	YULIYA IVANOVA	{"email": "yuliya_ivanova_13101979@postgrespro.ru", "phone": "+70088610910"}
0005432649492	936EC5	8202 933188	MARIYA NOVIKOVA	{"phone": "+70481578719"}
0005432649493	66ADA6	2087 977978	ELENA SMIRNOVA	{"phone": "+70700480676"}
0005432649494	29F93B	9626 875179	LILIYA GUSEVA	{"email": "l.guseva1982@postgrespro.ru", "phone": "+70084781860"}
0005432649495	29F93B	4666 150319	GALINA FILATOVA	{"email": "filatovagalina_1967@postgrespro.ru", "phone": "+70823158307"}
0005432649496	29F93B	2160 249091	ALEKSANDR ANDREEV	{"phone": "+70280668707"}
0005432649498	7C63F2	9744 385488	TIMOFEY NOVIKOV	{"phone": "+70552866731"}
0005432649499	89F9FD	8159 960731	IGOR SERGEEV	{"phone": "+70015422285"}
0005432649500	89F9FD	5934 046010	NIKITA MAKAROV	{"email": "nmakarov_1973@postgrespro.ru", "phone": "+70509381442"}
0005432649501	6F2275	0542 153540	IRINA VOLKOVA	{"phone": "+70202411911"}
0005432649502	6F2275	5086 178146	NADEZHDA KUDRYASHOVA	{"email": "n_kudryashova.1962@postgrespro.ru", "phone": "+70580910659"}
0005432649503	6F2275	3337 812652	ANTON KUZNECOV	{"phone": "+70578393986"}
0005432649504	A95EE5	3401 410434	ANTON ISAEV	{"email": "a.isaev_1961@postgrespro.ru", "phone": "+70307829186"}
0005432649505	A95EE5	4364 224579	SERGEY ILIN	{"email": "ilin_s-20011970@postgrespro.ru", "phone": "+70598621579"}
0005432649506	C47F11	7678 138672	LEONID IVANOV	{"phone": "+70793890454"}
0005432649507	C47F11	7331 278508	ALEKSANDR POPOV	{"email": "a.popov-011962@postgrespro.ru", "phone": "+70958333240"}
0005432649508	5A1A57	9242 620682	ARTUR ZAKHAROV	{"phone": "+70637008812"}
0005432649509	5A1A57	6756 843376	RUSLAN DAVYDOV	{"email": "davydov.ruslan.22041978@postgrespro.ru", "phone": "+70249096393"}
0005432649510	720403	0052 697451	VLADIMIR ZAYCEV	{"phone": "+70882456842"}
0005432649511	720403	3424 154333	VALENTINA KUZNECOVA	{"phone": "+70510789206"}
0005432649512	720403	0422 698587	YULIYA RODIONOVA	{"email": "rodionova_y_1969@postgrespro.ru", "phone": "+70989716054"}
0005432649513	2B40CB	8190 209864	ALEKSEY CHERNOV	{"email": "chernovaleksey_011967@postgrespro.ru", "phone": "+70195578114"}
0005432649514	428011	2004 574408	SVETLANA KARPOVA	{"email": "s_karpova1956@postgrespro.ru", "phone": "+70536787582"}
0005432649515	95DC27	6551 686599	VALENTINA AKIMOVA	{"phone": "+70869185686"}
0005432649516	98081E	6702 637801	ALEKSEY IVANOV	{"email": "ivanov-a1976@postgrespro.ru", "phone": "+70400196297"}
0005432649517	A3E73B	5175 467932	IVAN EGOROV	{"phone": "+70377909653"}
0005432649518	A3E73B	4823 379359	LYUDMILA ANISIMOVA	{"email": "lyudmila-anisimova_1963@postgrespro.ru", "phone": "+70804190612"}
0005432649519	302685	1464 574650	OLGA BARANOVA	{"phone": "+70586677628"}
0005432649520	302685	6762 875570	EVGENIY MAKAROV	{"email": "e-makarov1968@postgrespro.ru", "phone": "+70456377939"}
0005432649521	302685	5307 693945	VLADIMIR TARASOV	{"email": "tarasov.v031985@postgrespro.ru", "phone": "+70114483374"}
0005432649522	97E362	1491 346643	VLADIMIR GUSEV	{"email": "vladimir_gusev_061972@postgrespro.ru", "phone": "+70224678549"}
0005432649523	D03841	5398 725286	VLADISLAV ORLOV	{"phone": "+70192914246"}
0005432649524	D03841	1701 210237	IRINA KONOVALOVA	{"phone": "+70932657742"}
0005432649525	D03841	9203 391713	ANTON ALEKSEEV	{"phone": "+70765289279"}
0005432649526	D03841	1217 615466	LIDIYA KULIKOVA	{"phone": "+70638626204"}
0005432649527	9DB2E4	1829 935124	NADEZHDA POPOVA	{"email": "n_popova-25041977@postgrespro.ru", "phone": "+70763723620"}
0005432649528	9DB2E4	8706 768702	ANASTASIYA STEPANOVA	{"phone": "+70436317732"}
0005432649529	A0D008	1406 171466	VALENTINA BORISOVA	{"phone": "+70251314780"}
0005432649530	A0D008	5436 139267	STANISLAV TIMOFEEV	{"phone": "+70400376244"}
0005432649531	CC0776	6014 504665	YURIY ZAKHAROV	{"phone": "+70553600581"}
0005432649532	BFD28B	9263 470114	MIKHAIL ORLOV	{"email": "orlov.mikhail.051978@postgrespro.ru", "phone": "+70377947280"}
0005432649533	BFD28B	3074 998710	NIKOLAY MOROZOV	{"phone": "+70490381325"}
0005432649534	2F81E0	5856 263426	IGOR TARASOV	{"email": "itarasov_1974@postgrespro.ru", "phone": "+70405911475"}
0005432649535	A95369	8852 987422	GALINA MOISEEVA	{"email": "moiseeva-galina041970@postgrespro.ru", "phone": "+70285852671"}
0005432649536	522D15	0521 573017	VIKTOR DAVYDOV	{"email": "v-davydov.1963@postgrespro.ru", "phone": "+70935474480"}
0005432649537	2C18AE	2743 602755	DENIS GORBUNOV	{"email": "denis.gorbunov051967@postgrespro.ru", "phone": "+70521350192"}
0005432649538	EC1351	1598 289046	ANDREY FEDOROV	{"email": "fedorov_a.07091965@postgrespro.ru", "phone": "+70235234307"}
0005432649539	F47541	9852 111707	ALI VASILEV	{"email": "vasilev_a07061975@postgrespro.ru", "phone": "+70835359503"}
0005432649540	307449	2900 815460	LYUDMILA TROFIMOVA	{"email": "l_trofimova-14071966@postgrespro.ru", "phone": "+70717213712"}
0005432649541	307449	2828 354457	VASILIY ISAEV	{"email": "vasiliyisaev_17011975@postgrespro.ru", "phone": "+70212486736"}
0005432649542	7257DD	1157 149318	LIDIYA GERASIMOVA	{"email": "l_gerasimova-1988@postgrespro.ru", "phone": "+70369131503"}
0005432649543	7257DD	3161 716879	SERGEY FILIPPOV	{"email": "filippov.s14071971@postgrespro.ru", "phone": "+70900043951"}
0005432649544	988FE0	3952 010552	ANTON GAVRILOV	{"phone": "+70432759606"}
0005432649545	3BB55C	5772 971509	EVGENIY NIKOLAEV	{"phone": "+70634694172"}
0005432649546	3BB55C	8860 378053	IRINA LAZAREVA	{"phone": "+70565728300"}
0005432649547	3BB55C	6712 845829	MARIYA GUSEVA	{"email": "guseva-mariya.1967@postgrespro.ru", "phone": "+70450299032"}
0005432649548	EFFA26	9707 183007	DMITRIY KUZMIN	{"phone": "+70092169388"}
0005432649549	EFFA26	7335 760642	NATALYA KUDRYASHOVA	{"phone": "+70369779223"}
0005432649550	A18DD5	9814 255044	NATALYA PETROVA	{"email": "natalya.petrova.05101965@postgrespro.ru", "phone": "+70991151359"}
0005432649551	5F0045	5626 142416	ELENA TARASOVA	{"email": "elena-tarasova_1967@postgrespro.ru", "phone": "+70013497310"}
0005432649552	0FE854	1123 589887	VLADIMIR IVANOV	{"phone": "+70608022113"}
0005432649553	B25E55	0060 375572	ALLA SERGEEVA	{"phone": "+70111194525"}
0005432649554	B25E55	0379 594357	DIANA NAZAROVA	{"phone": "+70497769329"}
0005432649555	CAB3C8	7297 509828	NELLYA POPOVA	{"email": "popovan.071967@postgrespro.ru", "phone": "+70396150537"}
0005432649556	44E642	7041 399827	ALENA GAVRILOVA	{"email": "gavrilova-alena_111976@postgrespro.ru", "phone": "+70026709489"}
0005432649557	306432	2004 268729	KIRILL MIKHAYLOV	{"phone": "+70535329415"}
0005432649558	306432	8219 736449	ALEKSANDR PETROV	{"email": "a.petrov_19101969@postgrespro.ru", "phone": "+70720402891"}
0005432649559	33F6CA	9279 157934	POLINA SAVELEVA	{"email": "psaveleva_061969@postgrespro.ru", "phone": "+70548794942"}
0005432649560	49E56C	0527 724391	NADEZHDA KOMAROVA	{"email": "komarova_nadezhda091974@postgrespro.ru", "phone": "+70901564247"}
0005432649561	D39ED2	7499 059195	SERGEY MAKAROV	{"email": "sergey-makarov-121974@postgrespro.ru", "phone": "+70134301039"}
0005432649562	D39ED2	7614 040538	NINA PETROVA	{"email": "nina_petrova-051980@postgrespro.ru", "phone": "+70387168893"}
0005432649563	49C197	0114 051724	ELIZAVETA MAKSIMOVA	{"phone": "+70769390466"}
0005432649564	49C197	7485 976800	SVETLANA CHERNOVA	{"phone": "+70481214086"}
0005432649565	B96D84	2641 690018	ANASTASIYA KULIKOVA	{"phone": "+70138753596"}
0005432649566	B96D84	0101 479182	TATYANA KUZNECOVA	{"email": "kuznecova.t.17061964@postgrespro.ru", "phone": "+70229539416"}
0005432649567	0D635B	6913 857042	IRINA MEDVEDEVA	{"phone": "+70459778146"}
0005432649568	0D635B	3256 206560	ALEKSEY VLASOV	{"phone": "+70911941087"}
0005432649569	EF62D5	5476 297481	VERA PETROVA	{"phone": "+70346065900"}
0005432649570	EF62D5	0206 102111	NATALYA LOGINOVA	{"email": "loginovanatalya_121975@postgrespro.ru", "phone": "+70412277538"}
0005432649571	578A41	2440 410815	SVETLANA KUZNECOVA	{"phone": "+70497805460"}
0005432649572	894EE0	8828 626373	VLADIMIR MELNIKOV	{"email": "melnikovvladimir_1973@postgrespro.ru", "phone": "+70398372218"}
0005432649573	B41192	1168 761923	DENIS MAKAROV	{"phone": "+70350370711"}
0005432649574	C6D62E	6660 374260	YULIYA VOLKOVA	{"phone": "+70742118758"}
0005432649575	C6D62E	2598 783533	VERA TROFIMOVA	{"email": "veratrofimova.1972@postgrespro.ru", "phone": "+70993177336"}
0005432655380	931751	0938 071275	NATALYA FADEEVA	{"phone": "+70554562151"}
0005432655326	DCA89E	7156 161440	EVGENIYA IVANOVA	{"email": "e.ivanova-1972@postgrespro.ru", "phone": "+70090795209"}
0005432655327	DCA89E	8847 318538	ANTON MARTYNOV	{"email": "martynova.021978@postgrespro.ru", "phone": "+70675849250"}
0005432655328	DCA89E	0335 984298	MARIYA KUZNECOVA	{"phone": "+70266874117"}
0005432655329	7ADC4B	1694 600287	SERGEY MARTYNOV	{"phone": "+70892695333"}
0005432655330	7ADC4B	0947 231265	ALBINA SOROKINA	{"phone": "+70884514701"}
0005432655331	93E456	5501 571897	VALENTINA MELNIKOVA	{"phone": "+70727948228"}
0005432655332	046E11	8040 917613	MARIYA BARANOVA	{"email": "mariya_baranova18051975@postgrespro.ru", "phone": "+70487580569"}
0005432655333	046E11	2567 871183	ALEVTINA BELOVA	{"phone": "+70076339455"}
0005432655334	992FF2	9571 103444	KIRILL MELNIKOV	{"email": "k.melnikov-06021977@postgrespro.ru", "phone": "+70343376795"}
0005432655335	424288	9692 298766	ANNA KUZMINA	{"email": "a.kuzmina-1967@postgrespro.ru", "phone": "+70421428041"}
0005432655336	530438	6339 665145	EVGENIY ANTONOV	{"phone": "+70855800278"}
0005432655337	530438	1536 558026	RAISA IVANOVA	{"email": "ivanova_r_021977@postgrespro.ru", "phone": "+70206435941"}
0005432655338	321888	6999 247557	OLGA ZAKHAROVA	{"email": "zakharova.o_081977@postgrespro.ru", "phone": "+70662460688"}
0005432655339	321888	6541 810873	ALEKSANDRA KOZLOVA	{"phone": "+70824117769"}
0005432655340	0DD792	7951 170058	LILIYA POPOVA	{"email": "popova.liliya_29031974@postgrespro.ru", "phone": "+70036882668"}
0005432655341	0DD792	9976 302610	MATVEY MIRONOV	{"phone": "+70036777819"}
0005432655342	DB4FB4	0523 966964	STEPAN KUZNECOV	{"email": "stepan-kuznecov-041968@postgrespro.ru", "phone": "+70033851151"}
0005432655343	3D46E8	7439 806908	VIKTOR SMIRNOV	{"email": "smirnov_viktor25111976@postgrespro.ru", "phone": "+70444879225"}
0005432655344	D5F28E	1487 011619	ELENA ANDREEVA	{"email": "andreeva.elena.121977@postgrespro.ru", "phone": "+70959265245"}
0005432655401	9639E5	0383 562221	MATVEY IVANOV	{"phone": "+70847717840"}
0005432655345	D5F28E	5879 474619	NATALYA ANISIMOVA	{"email": "anisimova_n-101970@postgrespro.ru", "phone": "+70732396847"}
0005432655346	291BE1	2590 603664	MIKHAIL NIKITIN	{"phone": "+70441943130"}
0005432655347	FFB52A	8787 464200	OLESYA VLASOVA	{"email": "ovlasova_121966@postgrespro.ru", "phone": "+70983512683"}
0005432655348	FFB52A	0339 915122	VYACHESLAV MIKHAYLOV	{"phone": "+70311809731"}
0005432655349	45BABA	6012 710586	NADEZHDA MIRONOVA	{"email": "mironova_nadezhda_1972@postgrespro.ru", "phone": "+70416974631"}
0005432655350	AC6848	4511 926339	VADIM GORBUNOV	{"phone": "+70327065011"}
0005432655351	542391	7437 816928	NATALYA GERASIMOVA	{"phone": "+70320474710"}
0005432655352	A3C65C	7210 346570	KLAVDIYA KISELEVA	{"email": "k.kiseleva_07101978@postgrespro.ru", "phone": "+70762795431"}
0005432655353	CF6A5A	1811 495246	GALINA ANISIMOVA	{"email": "anisimova_galina.12051986@postgrespro.ru", "phone": "+70348305362"}
0005432655354	ECF4DD	0793 149362	MARINA SEMENOVA	{"email": "m.semenova-1970@postgrespro.ru", "phone": "+70421087466"}
0005432655355	FC5B9F	8833 426429	MARIYA RYABOVA	{"email": "mariya.ryabova1955@postgrespro.ru", "phone": "+70249326333"}
0005432655356	FC5B9F	8426 693774	ALEKSANDR ANDREEV	{"email": "a-andreev.04051973@postgrespro.ru", "phone": "+70613757495"}
0005432655357	8511EF	6158 705699	GENNADIY KUZMIN	{"phone": "+70824610654"}
0005432655358	8511EF	1314 593002	TATYANA NESTEROVA	{"phone": "+70857581446"}
0005432655359	3C75B4	3400 985071	VIOLETTA MOROZOVA	{"email": "morozova_violetta1965@postgrespro.ru", "phone": "+70630271654"}
0005432655360	42A9F6	0697 987311	IRINA VOLKOVA	{"email": "volkova-irina_1968@postgrespro.ru", "phone": "+70524666966"}
0005432655361	42A9F6	9516 948826	DMITRIY KUZNECOV	{"phone": "+70602381209"}
0005432655362	42A9F6	8164 005211	LYUDMILA NAUMOVA	{"phone": "+70228373135"}
0005432655363	AF3966	7137 631023	SVETLANA ABRAMOVA	{"phone": "+70198617512"}
0005432655364	AF3966	0636 471277	ANNA POTAPOVA	{"email": "a.potapova.05031982@postgrespro.ru", "phone": "+70244821206"}
0005432655365	A189C8	2527 544228	SERGEY MATVEEV	{"email": "matveev-sergey.26031979@postgrespro.ru", "phone": "+70191569344"}
0005432655366	43EBBD	9136 051434	VADIM YAKOVLEV	{"email": "vadim-yakovlev-1979@postgrespro.ru", "phone": "+70983728126"}
0005432655367	43EBBD	4443 042909	KIRILL GORBUNOV	{"email": "kirillgorbunov031976@postgrespro.ru", "phone": "+70793369378"}
0005432655368	43EBBD	6190 165640	SERGEY GAVRILOV	{"email": "sgavrilov021978@postgrespro.ru", "phone": "+70258446729"}
0005432655369	43EBBD	5281 116951	NADEZHDA MARTYNOVA	{"phone": "+70672350803"}
0005432655370	1100F5	5400 642173	MARK ANTONOV	{"email": "antonov.mark_04081974@postgrespro.ru", "phone": "+70820102046"}
0005432655371	1100F5	6781 031400	NAIL FEDOROV	{"email": "fedorovnail021969@postgrespro.ru", "phone": "+70648332962"}
0005432655372	AF92DF	8431 191036	SVETLANA EGOROVA	{"email": "svetlana-egorova.1966@postgrespro.ru", "phone": "+70655152821"}
0005432655373	AF92DF	8638 554259	NATALYA KALININA	{"phone": "+70874325135"}
0005432655374	FFAE0E	6275 221410	IRINA NIKOLAEVA	{"email": "irina.nikolaeva041964@postgrespro.ru", "phone": "+70984466862"}
0005432655375	7276C5	4657 674762	OLGA KRASNOVA	{"email": "krasnova.olga_1982@postgrespro.ru", "phone": "+70429760701"}
0005432655376	7276C5	6043 977158	SERGEY KOROLEV	{"phone": "+70348154648"}
0005432655377	4AB966	0777 190989	ALEKSANDR KISELEV	{"email": "a.kiselev_1971@postgrespro.ru", "phone": "+70750136042"}
0005432655378	4AB966	4963 172966	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov.101978@postgrespro.ru", "phone": "+70012966645"}
0005432655379	E61FC9	2444 212888	VLADIMIR GRIGOREV	{"phone": "+70135574952"}
0005432655381	4D2266	0368 790547	DENIS KONOVALOV	{"email": "konovalov_denis-1977@postgrespro.ru", "phone": "+70165718904"}
0005432655382	CD0DE6	0954 365148	IRINA EGOROVA	{"email": "irinaegorova061970@postgrespro.ru", "phone": "+70953355576"}
0005432655383	CD0DE6	8677 377654	MARINA ORLOVA	{"email": "m-orlova1967@postgrespro.ru", "phone": "+70344973302"}
0005432655384	957B26	3661 957011	GULIYA KALININA	{"phone": "+70869649386"}
0005432655385	957B26	4434 329182	DIANA TIKHONOVA	{"email": "d.tikhonova.08031966@postgrespro.ru", "phone": "+70248897372"}
0005432655386	6B3F84	7391 433937	KONSTANTIN MIRONOV	{"phone": "+70409381612"}
0005432655387	5611FE	7114 795417	OKSANA FEDOROVA	{"phone": "+70384915556"}
0005432655388	620E28	5852 786318	OLGA IVANOVA	{"email": "olga.ivanova_04011972@postgrespro.ru", "phone": "+70735384479"}
0005432655389	843718	9882 153361	ANDREY VASILEV	{"email": "vasilev-andrey1981@postgrespro.ru", "phone": "+70904776478"}
0005432655390	951F1A	2916 138826	RAMIS NIKOLAEV	{"phone": "+70557543031"}
0005432655391	3A743D	5453 087629	ANNA DMITRIEVA	{"email": "anna.dmitrieva1982@postgrespro.ru", "phone": "+70481499701"}
0005432655392	9162A3	2680 595164	EGOR FILIPPOV	{"phone": "+70010672626"}
0005432655393	15A0E5	6716 869965	YULIYA NAUMOVA	{"phone": "+70406887388"}
0005432655394	15A0E5	1986 388969	LYUDMILA NIKOLAEVA	{"phone": "+70247383232"}
0005432655395	78A7B7	6868 921827	EVGENIY ORLOV	{"email": "orlov.evgeniy-1974@postgrespro.ru", "phone": "+70838077916"}
0005432655396	FDB76D	8156 255284	ALEKSANDR DMITRIEV	{"phone": "+70997831087"}
0005432655397	FDB76D	9634 485576	OLGA MAKAROVA	{"phone": "+70710309364"}
0005432655398	309B95	0053 349325	VALENTINA RODIONOVA	{"email": "rodionova_v_1974@postgrespro.ru", "phone": "+70205776498"}
0005432655399	309B95	7220 770667	NADEZHDA DANILOVA	{"email": "danilovan_11031977@postgrespro.ru", "phone": "+70700756925"}
0005432655400	9639E5	9516 546378	ELENA KONOVALOVA	{"email": "konovalova_e_1966@postgrespro.ru", "phone": "+70540904971"}
0005432655402	4228EE	3844 291795	ELENA SMIRNOVA	{"email": "e-smirnova061966@postgrespro.ru", "phone": "+70993793761"}
0005432655403	4228EE	7618 344591	OLGA RODIONOVA	{"phone": "+70725515595"}
0005432655404	4228EE	9226 956479	VALENTINA SMIRNOVA	{"email": "smirnova.valentina.17021977@postgrespro.ru", "phone": "+70927039743"}
0005432655405	82EAAE	8908 525148	LYUDMILA NAZAROVA	{"phone": "+70453661760"}
0005432655406	82EAAE	7785 791743	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov_1956@postgrespro.ru", "phone": "+70406236597"}
0005432655407	38540A	0011 954946	DMITRIY FOMIN	{"phone": "+70878482038"}
0005432655408	52AD64	1866 815270	IVAN KUZNECOV	{"phone": "+70025575725"}
0005432655409	52AD64	7329 557345	LYUDMILA KOMAROVA	{"phone": "+70460844532"}
0005432655410	1E5F6F	7024 840117	ARSENIY VASILEV	{"email": "arseniyvasilev-07011966@postgrespro.ru", "phone": "+70839186872"}
0005432655411	9EDB7F	7494 984808	VLADIMIR SAVELEV	{"email": "vladimir.savelev.30091968@postgrespro.ru", "phone": "+70978844594"}
0005432655412	AD8411	7016 962692	TATYANA PAVLOVA	{"email": "t.pavlova081965@postgrespro.ru", "phone": "+70086921015"}
0005432655413	3F929B	3770 248079	ARINA GUSEVA	{"phone": "+70898223727"}
0005432655414	3F929B	2817 906984	ANTONINA ORLOVA	{"email": "orlova_a_091971@postgrespro.ru", "phone": "+70043936045"}
0005432655415	2CED12	6036 761186	ANTON FOMIN	{"phone": "+70740485490"}
0005432655416	26A888	6910 354910	DMITRIY MELNIKOV	{"email": "d_melnikov.061973@postgrespro.ru", "phone": "+70066230043"}
0005432655417	CF53B8	8729 103635	OLGA BORISOVA	{"phone": "+70914045718"}
0005432655418	CF53B8	5868 544136	ANDREY IVANOV	{"phone": "+70074785889"}
0005432655419	CF53B8	8872 143517	SERGEY KULIKOV	{"email": "s-kulikov071973@postgrespro.ru", "phone": "+70534537502"}
0005432655420	D78E01	4440 977585	SEMEN OSIPOV	{"phone": "+70279744282"}
0005432655421	FB2FBF	8332 463234	ELEONORA SOKOLOVA	{"phone": "+70562275380"}
0005432655422	821B40	5469 147259	RAISA KUZNECOVA	{"email": "kuznecovaraisa_041972@postgrespro.ru", "phone": "+70686991380"}
0005432655423	C3EBB9	3201 618020	ROMAN KRASNOV	{"email": "r_krasnov.1981@postgrespro.ru", "phone": "+70022122241"}
0005432655424	C3EBB9	1097 131856	VALERIY OSIPOV	{"phone": "+70580622462"}
0005432655425	C3EBB9	4576 878385	VALERIY MIKHAYLOV	{"email": "mikhaylov_valeriy.111966@postgrespro.ru", "phone": "+70910198858"}
0005432655426	7709F8	4945 216709	MIKHAIL GUSEV	{"phone": "+70576789556"}
0005432655427	653537	1102 677875	OLEG ANDREEV	{"phone": "+70092527653"}
0005432655548	5E10FC	3340 770946	IGOR SCHERBAKOV	{"phone": "+70810201857"}
0005432655428	653537	9758 458212	MARINA PETROVA	{"email": "mpetrova.041975@postgrespro.ru", "phone": "+70947553473"}
0005432655429	D669DD	2997 949762	KLAVDIYA VLASOVA	{"phone": "+70012493627"}
0005432655430	DC4F21	8550 039609	KONSTANTIN VOLKOV	{"email": "k-volkov-111975@postgrespro.ru", "phone": "+70992700510"}
0005432655431	DC4F21	5954 077967	ALEKSEY KISELEV	{"phone": "+70867814495"}
0005432655432	3DDDA0	6602 606001	MAKSIM PAVLOV	{"email": "maksim.pavlov051962@postgrespro.ru", "phone": "+70566198410"}
0005432655433	BC8AC0	2790 833881	DMITRIY KUZMIN	{"email": "kuzmindmitriy.071968@postgrespro.ru", "phone": "+70753941507"}
0005432655434	BC8AC0	5191 523049	NATALYA PETROVA	{"phone": "+70863417268"}
0005432655435	4A2A28	8506 223028	LYUDMILA SOLOVEVA	{"phone": "+70534547282"}
0005432655436	D71C54	0011 944698	LYUDMILA STEPANOVA	{"phone": "+70970163397"}
0005432655437	578E78	3882 286263	MIKHAIL MAKAROV	{"email": "makarov-mikhail-1979@postgrespro.ru", "phone": "+70339690123"}
0005432655438	578E78	6582 093495	KIRILL KOROLEV	{"phone": "+70043822008"}
0005432655439	C851C8	0132 167071	IGOR NAUMOV	{"email": "naumovigor.1969@postgrespro.ru", "phone": "+70178716737"}
0005432655440	734034	9159 835206	TIMUR IVANOV	{"email": "tivanov08071971@postgrespro.ru", "phone": "+70993407266"}
0005432655441	0B2C61	2429 067820	VALENTINA KISELEVA	{"email": "kiseleva.v-071966@postgrespro.ru", "phone": "+70059118215"}
0005432655442	C17737	2550 700704	ALEKSANDR POPOV	{"email": "a_popov_14121976@postgrespro.ru", "phone": "+70789865297"}
0005432655443	D44DFD	0396 167672	ALEKSEY ZHURAVLEV	{"email": "zhuravlev.aleksey-031976@postgrespro.ru", "phone": "+70927819816"}
0005432655444	BA950E	2966 877334	LYUBOV SOROKINA	{"email": "l-sorokina-14061970@postgrespro.ru", "phone": "+70056170902"}
0005432655445	813F0A	2185 625992	MIKHAIL MOISEEV	{"phone": "+70774975443"}
0005432655446	F13ACD	2423 467623	ANNA KRASNOVA	{"email": "anna-krasnova-17101968@postgrespro.ru", "phone": "+70399857291"}
0005432655447	004346	9032 244845	DENIS KOZLOV	{"phone": "+70255889592"}
0005432655448	004346	6613 500292	ANTON ZHURAVLEV	{"email": "zhuravlev_a061977@postgrespro.ru", "phone": "+70064796241"}
0005432655449	9D7A9F	5337 697411	VASILIY GUSEV	{"email": "gusev_vasiliy10111971@postgrespro.ru", "phone": "+70922533848"}
0005432655450	2144BE	3540 512003	IVAN MAKAROV	{"email": "ivan-makarov.1966@postgrespro.ru", "phone": "+70854860328"}
0005432655451	510583	6435 474022	ANATOLIY KUZNECOV	{"email": "kuznecov_a-08051967@postgrespro.ru", "phone": "+70979221828"}
0005432655452	16497C	3889 047911	ELENA GRISHINA	{"phone": "+70888820797"}
0005432655453	6793D2	7040 892881	IVAN KULIKOV	{"email": "kulikovi061966@postgrespro.ru", "phone": "+70941305842"}
0005432655454	6620C4	6164 482418	VLADIMIR PAVLOV	{"phone": "+70102000106"}
0005432655455	CA0A37	6210 509846	ANTON ANTONOV	{"email": "a-antonov03041972@postgrespro.ru", "phone": "+70581289738"}
0005432655456	952F7E	8232 245929	MAKSIM KUZNECOV	{"phone": "+70661462180"}
0005432655457	668635	2051 210127	DARYA EGOROVA	{"email": "darya-egorova1963@postgrespro.ru", "phone": "+70230264338"}
0005432655458	08A70F	0891 000861	EVGENIY ZAKHAROV	{"email": "ezakharov_09011972@postgrespro.ru", "phone": "+70113080274"}
0005432655459	3CB980	7668 303980	ELENA MOROZOVA	{"email": "elena.morozova-1971@postgrespro.ru", "phone": "+70091082735"}
0005432655460	40CC70	9750 267082	EVGENIYA STEPANOVA	{"phone": "+70173067165"}
0005432655461	09EF22	6312 153014	MIKHAIL SHEVCHENKO	{"phone": "+70881742520"}
0005432655462	09EF22	4840 594337	KRISTINA SIDOROVA	{"phone": "+70470936931"}
0005432655463	4A6B77	5190 141652	MATRENA LEBEDEVA	{"email": "lebedeva.m09091970@postgrespro.ru", "phone": "+70161911377"}
0005432655464	F243C6	0946 591256	ANNA ZAKHAROVA	{"phone": "+70438992553"}
0005432655465	FD67F6	6831 997332	ALINA STEPANOVA	{"phone": "+70497921952"}
0005432655466	FD67F6	0790 207016	IVAN KRASNOV	{"email": "krasnov.i_061968@postgrespro.ru", "phone": "+70452412830"}
0005432655467	34DDC1	4549 424463	ANDREY KULIKOV	{"phone": "+70766993692"}
0005432655468	A262F7	4177 663975	ULYANA TROFIMOVA	{"email": "u.trofimova17021972@postgrespro.ru", "phone": "+70350490954"}
0005432655469	B868F6	6800 496376	MIKHAIL NAUMOV	{"phone": "+70809757511"}
0005432655470	B868F6	7551 793500	MIKHAIL MOROZOV	{"phone": "+70796347696"}
0005432655471	17278C	8333 006644	ANATOLIY MARTYNOV	{"phone": "+70574304593"}
0005432655472	D501FB	6972 687841	DENIS KUZMIN	{"email": "denis_kuzmin1956@postgrespro.ru", "phone": "+70427982354"}
0005432655473	74E12F	1669 741848	ZINAIDA ANDREEVA	{"email": "andreevaz_101982@postgrespro.ru", "phone": "+70720359694"}
0005432655474	74E12F	7783 947962	MARINA BELYAEVA	{"phone": "+70900253396"}
0005432655475	C0F5B2	6556 058622	LIDIYA DENISOVA	{"email": "l_denisova.081960@postgrespro.ru", "phone": "+70642645755"}
0005432655476	025623	5755 060735	SVETLANA POPOVA	{"email": "popovasvetlana07101979@postgrespro.ru", "phone": "+70953204463"}
0005432655477	193031	1681 546564	ELENA PETROVA	{"email": "elena_petrova011982@postgrespro.ru", "phone": "+70895292222"}
0005432655478	193031	1486 234962	ALEKSANDR ZAKHAROV	{"email": "zakharov.a.1969@postgrespro.ru", "phone": "+70659435026"}
0005432655479	BCC060	6094 638210	VALENTINA KOMAROVA	{"phone": "+70663254186"}
0005432655480	BCC060	6006 522011	SERGEY KUZNECOV	{"email": "s-kuznecov.101974@postgrespro.ru", "phone": "+70576415554"}
0005432655481	DB9DDA	8641 739175	YULIYA KONDRATEVA	{"phone": "+70615898765"}
0005432655482	2CA010	2430 934986	YURIY MOISEEV	{"email": "moiseev_yuriy_1973@postgrespro.ru", "phone": "+70341586980"}
0005432655483	2CA010	4312 461046	ELVIRA YUDINA	{"phone": "+70434442649"}
0005432655484	66FD27	3490 843567	VIKTORIYA TROFIMOVA	{"email": "trofimova-v-04091971@postgrespro.ru", "phone": "+70682550210"}
0005432655485	C8F3A7	4544 873986	LEONID DMITRIEV	{"email": "dmitrievl_1963@postgrespro.ru", "phone": "+70824453037"}
0005432655486	1E5D98	3999 720777	NIKOLAY NOVIKOV	{"phone": "+70220255809"}
0005432655487	1E5D98	9586 335109	IRINA VASILEVA	{"email": "vasileva_irina-1960@postgrespro.ru", "phone": "+70944777468"}
0005432655488	1468F4	1775 374533	SERGEY KRASNOV	{"email": "sergey-krasnov-1966@postgrespro.ru", "phone": "+70404826780"}
0005432655489	D0E1E1	4720 550506	DMITRIY IVANOV	{"email": "d.ivanov-081974@postgrespro.ru", "phone": "+70595419022"}
0005432655490	F62B24	7215 361648	RAUF VOROBEV	{"phone": "+70184091651"}
0005432655491	F62B24	5790 420103	EVDOKIYA KARPOVA	{"phone": "+70695598671"}
0005432655492	6B371B	5169 246925	ILDAR SERGEEV	{"email": "sergeev_i-1976@postgrespro.ru", "phone": "+70588193102"}
0005432655493	6B371B	2797 177694	NATALIYA NESTEROVA	{"email": "nesterova-nataliya01041965@postgrespro.ru", "phone": "+70790415302"}
0005432655494	96C04A	5262 388030	ANNA BORISOVA	{"phone": "+70871121339"}
0005432655495	AC2BA1	6091 577701	VIKTOR KOZLOV	{"phone": "+70569352745"}
0005432655496	784542	4287 911481	ARINA SIDOROVA	{"email": "sidorova-arina.1977@postgrespro.ru", "phone": "+70245822983"}
0005432655497	8DE24D	4415 703446	LYUDMILA ORLOVA	{"phone": "+70748608741"}
0005432655498	8DE24D	2202 525855	OLGA ZAKHAROVA	{"email": "zakharova_olga1976@postgrespro.ru", "phone": "+70386306375"}
0005432655499	E83407	8660 077036	VERA KUZNECOVA	{"email": "verakuznecova061976@postgrespro.ru", "phone": "+70693279141"}
0005432655500	A2882C	3171 000642	DMITRIY EGOROV	{"phone": "+70298573095"}
0005432655501	A576E1	5319 718412	VLADIMIR VOROBEV	{"email": "v_vorobev-20051972@postgrespro.ru", "phone": "+70751914168"}
0005432655502	A576E1	7331 812764	VLADISLAV ORLOV	{"phone": "+70028398174"}
0005432655503	A576E1	9872 667224	ANTONINA DANILOVA	{"phone": "+70420511761"}
0005432655504	D88468	8122 855326	MATVEY SCHERBAKOV	{"phone": "+70110252332"}
0005432655505	2D9FE4	2131 940942	TATYANA KONOVALOVA	{"email": "konovalovatatyana.30101979@postgrespro.ru", "phone": "+70209592735"}
0005432655506	04B33F	7777 138844	DANIIL ROMANOV	{"phone": "+70612855498"}
0005432655507	E2BADF	3056 292682	IRINA ZOTOVA	{"email": "i-zotova_25121975@postgrespro.ru", "phone": "+70189686002"}
0005432655508	E2BADF	6406 527316	EVGENIY ANDREEV	{"phone": "+70726593702"}
0005432655509	A92046	5282 774999	TATYANA MEDVEDEVA	{"email": "medvedeva.t-111969@postgrespro.ru", "phone": "+70408339205"}
0005432655510	A92046	7525 163372	VITALIY SIDOROV	{"email": "vitaliy-sidorov1955@postgrespro.ru", "phone": "+70198615099"}
0005432655511	644B9C	1728 360193	SERGEY FILIPPOV	{"email": "sergeyfilippov-1968@postgrespro.ru", "phone": "+70832794550"}
0005432655512	317628	5506 815861	ILNAR KUZMIN	{"phone": "+70061989320"}
0005432655513	317628	7620 219447	AMINA KAZAKOVA	{"phone": "+70668394480"}
0005432655514	71607F	4058 062523	VASILIY ANTONOV	{"phone": "+70059295624"}
0005432655515	EAB2F0	5290 742208	ALEKSANDR ILIN	{"email": "ilin_aleksandr-1973@postgrespro.ru", "phone": "+70199556882"}
0005432655516	F7F873	0776 261865	DENIS FEDOTOV	{"email": "d-fedotov_051987@postgrespro.ru", "phone": "+70263526278"}
0005432655517	8327F3	0829 557316	STANISLAV ZHURAVLEV	{"email": "zhuravlev-stanislav-021969@postgrespro.ru", "phone": "+70022867941"}
0005432655518	8327F3	5021 644060	IVAN VOROBEV	{"phone": "+70015009419"}
0005432655519	51D56D	9189 174987	EGOR PETROV	{"phone": "+70882473325"}
0005432655520	E3CF40	3570 522009	ELENA POPOVA	{"phone": "+70105150936"}
0005432655521	EC4898	8487 826488	LYUDMILA MOISEEVA	{"email": "moiseeva_l.16051973@postgrespro.ru", "phone": "+70830755614"}
0005432655522	EC4898	2949 036022	IVAN MIRONOV	{"phone": "+70105941905"}
0005432655523	C4604F	2994 616580	VALENTINA FROLOVA	{"email": "valentina_frolova-30041977@postgrespro.ru", "phone": "+70410575199"}
0005432655524	3D3E0E	2193 990641	ALEKSANDRA AFANASEVA	{"phone": "+70083428201"}
0005432655525	8B7D41	5285 274035	ELENA KUDRYASHOVA	{"email": "kudryashova-e-041968@postgrespro.ru", "phone": "+70046943376"}
0005432655526	851594	5465 637809	LEONID SAVELEV	{"email": "savelev_leonid1973@postgrespro.ru", "phone": "+70285202171"}
0005432655527	E93159	2596 477852	VITALIY SERGEEV	{"email": "sergeev-vitaliy_1975@postgrespro.ru", "phone": "+70942745587"}
0005432655528	E93159	1263 958097	VERA SOKOLOVA	{"email": "sokolovavera_24121970@postgrespro.ru", "phone": "+70415868065"}
0005432655529	D196B8	4160 427968	YURIY SHEVCHENKO	{"phone": "+70164253703"}
0005432655530	D196B8	0409 378305	ELENA MOROZOVA	{"email": "morozova-e-041977@postgrespro.ru", "phone": "+70771380797"}
0005432655531	D196B8	9390 509698	ALEKSANDRA DMITRIEVA	{"email": "dmitrievaaleksandra_101969@postgrespro.ru", "phone": "+70368629084"}
0005432655532	B6D083	9637 866572	NATALYA EGOROVA	{"email": "natalya-egorova031975@postgrespro.ru", "phone": "+70825896513"}
0005432655533	B6D083	4819 549284	MARINA NOVIKOVA	{"email": "novikova.m.1961@postgrespro.ru", "phone": "+70617079688"}
0005432655534	348F73	9427 874186	LILIYA KOROLEVA	{"phone": "+70919488105"}
0005432655535	348F73	6106 386708	IRINA ISAEVA	{"email": "isaeva-i01051966@postgrespro.ru", "phone": "+70768037825"}
0005432655536	64BE7C	8366 242694	VARVARA KUZMINA	{"phone": "+70881430162"}
0005432655537	907E30	4914 370791	YURIY VOLKOV	{"email": "y_volkov.24081969@postgrespro.ru", "phone": "+70567502579"}
0005432655538	907E30	3722 826490	ALEKSANDR CHERNOV	{"email": "chernova1965@postgrespro.ru", "phone": "+70686088385"}
0005432655539	F3194A	1260 337929	VALENTINA KONOVALOVA	{"phone": "+70843092107"}
0005432655540	F3194A	0915 838105	ZINAIDA KUZNECOVA	{"phone": "+70213822384"}
0005432655541	C98FA8	2279 562827	ALEKSANDR TIKHONOV	{"phone": "+70335614192"}
0005432655542	8F0FAF	4459 760133	NATALIYA KUDRYASHOVA	{"phone": "+70630045946"}
0005432655543	269812	7958 613087	ANDREY ANTONOV	{"phone": "+70528036942"}
0005432655544	F03CC9	6951 739423	TATYANA KUDRYASHOVA	{"phone": "+70512919552"}
0005432655545	F03CC9	7093 280161	ANATOLIY KUZNECOV	{"phone": "+70938318777"}
0005432655546	F0EF3F	2393 160708	LYUBOV KOLESNIKOVA	{"phone": "+70979940133"}
0005432655547	BBD603	0464 183165	YURIY IVANOV	{"phone": "+70403460347"}
0005432655549	5E10FC	6673 823086	VIKTOR SOROKIN	{"email": "vsorokin.27011969@postgrespro.ru", "phone": "+70667518029"}
0005432655550	9AA95E	1781 690279	RAISA KOROLEVA	{"email": "koroleva.raisa-16071972@postgrespro.ru", "phone": "+70672534133"}
0005432655551	686140	4290 229003	VLADIMIR NIKITIN	{"email": "nikitin-v-111970@postgrespro.ru", "phone": "+70274673855"}
0005432655552	4E25DB	3574 386563	VLADIMIR RODIONOV	{"email": "vrodionov_121966@postgrespro.ru", "phone": "+70204074375"}
0005432655553	4E25DB	8112 695086	PETR ROMANOV	{"phone": "+70265793870"}
0005432655554	569F2A	1908 330031	TATYANA FILIPPOVA	{"email": "t-filippova-111981@postgrespro.ru", "phone": "+70227857927"}
0005432655555	93A086	0154 125531	MARINA VASILEVA	{"email": "marina-vasileva.1960@postgrespro.ru", "phone": "+70541346328"}
0005432655556	DCCBA8	9726 141751	GALINA MIKHAYLOVA	{"email": "mikhaylova.galina_1965@postgrespro.ru", "phone": "+70148155875"}
0005432655557	4F481E	1007 440118	SERGEY IVANOV	{"phone": "+70423528681"}
0005432655558	EEB64C	5467 196318	MARIYA KOVALEVA	{"phone": "+70837681948"}
0005432655559	EEB64C	0081 732355	ZINAIDA DAVYDOVA	{"phone": "+70628221356"}
0005432655560	BC7569	4654 811696	SERGEY ZHUKOV	{"phone": "+70712313598"}
0005432655561	BC7569	6783 383308	MAKSIM POPOV	{"email": "popov_maksim.17081970@postgrespro.ru", "phone": "+70831936174"}
0005432655562	AB928F	9374 416252	VITALIY FROLOV	{"phone": "+70674746260"}
0005432655563	E085E1	8183 162038	ROMAN BELOV	{"email": "roman-belov-1970@postgrespro.ru", "phone": "+70258905860"}
0005432655564	F769A2	6651 062304	ANDREY ANDREEV	{"phone": "+70640572814"}
0005432655565	1A7FC8	3802 926010	VITALIY ZHURAVLEV	{"email": "vitaliyzhuravlev101975@postgrespro.ru", "phone": "+70036899838"}
0005432655566	C57862	5786 839055	VARVARA DAVYDOVA	{"email": "varvara_davydova_081971@postgrespro.ru", "phone": "+70864131532"}
0005432655567	7938F7	2043 115687	SERGEY GUSEV	{"email": "s_gusev-1974@postgrespro.ru", "phone": "+70602454946"}
0005432655568	7938F7	7713 025348	ALEKSANDR KUZNECOV	{"phone": "+70025287257"}
0005432655569	9D95BD	7130 410680	VLADIMIR MELNIKOV	{"phone": "+70495407914"}
0005432655570	9D95BD	0744 742377	NATALYA ALEKSEEVA	{"email": "alekseeva.n.081984@postgrespro.ru", "phone": "+70673280992"}
0005432655571	F3736A	4533 252479	ALEKSEY MOISEEV	{"email": "aleksey.moiseev.071969@postgrespro.ru", "phone": "+70260989693"}
0005432655572	F3736A	2670 805943	ELENA ORLOVA	{"phone": "+70255933459"}
0005432655573	F3736A	1531 176443	DARYA MAKAROVA	{"phone": "+70072958403"}
0005432655574	CB8122	5644 552010	SERGEY ALEKSEEV	{"email": "sergey.alekseev.031972@postgrespro.ru", "phone": "+70393556918"}
0005432655575	CB8122	0835 422457	GRIGORIY ANDREEV	{"phone": "+70038254178"}
0005432655576	75382F	3884 513863	EGOR ALEKSEEV	{"phone": "+70969729268"}
0005432655577	B6457D	1972 736457	VASILIY IVANOV	{"email": "vasiliy_ivanov_29041979@postgrespro.ru", "phone": "+70707266643"}
0005432655578	95FEAF	5976 207527	VALENTINA DMITRIEVA	{"phone": "+70531231534"}
0005432655579	95FEAF	7695 509113	ANNA ROMANOVA	{"phone": "+70582647489"}
0005432655580	6486AF	5244 892055	TATYANA KUZNECOVA	{"phone": "+70036283522"}
0005432655581	6486AF	9030 690052	TATYANA ROMANOVA	{"email": "romanova-t_1973@postgrespro.ru", "phone": "+70445976706"}
0005432655582	3F22CB	2600 161689	ZHANNA GERASIMOVA	{"email": "zgerasimova1969@postgrespro.ru", "phone": "+70213235343"}
0005432655583	278E97	0551 582369	PETR BELOV	{"email": "belov-petr_1967@postgrespro.ru", "phone": "+70675978549"}
0005432655584	A6C682	9302 537463	ALEKSEY NIKITIN	{"phone": "+70278971743"}
0005432655585	A6C682	8096 548007	EVGENIY KAZAKOV	{"phone": "+70563706264"}
0005432655586	E9D1CD	4724 599295	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva14061964@postgrespro.ru", "phone": "+70401072287"}
0005432655587	DC9F4A	0674 475241	ALEKSANDR ZAYCEV	{"phone": "+70126688908"}
0005432655588	DC9F4A	8743 818132	ALEKSANDR NOVIKOV	{"phone": "+70000770547"}
0005432655589	674B6D	0796 333967	LILIYA LAZAREVA	{"phone": "+70368175119"}
0005432655590	A0DDDC	7918 937124	TATYANA FILATOVA	{"phone": "+70860595268"}
0005432655591	A0DDDC	4109 246129	SERGEY FILIPPOV	{"phone": "+70378146562"}
0005432655592	B6594F	1694 200372	ALEKSANDR KAZAKOV	{"email": "kazakov-a29041978@postgrespro.ru", "phone": "+70123430686"}
0005432655593	347A3E	8165 790221	NATALYA MAKSIMOVA	{"phone": "+70978157774"}
0005432655594	CBB821	6358 992758	LYUDMILA TIKHONOVA	{"phone": "+70064557448"}
0005432655595	C36DB2	7535 328870	PETR KULIKOV	{"phone": "+70454441223"}
0005432655596	3F7B12	3262 556362	GUZEL BELOVA	{"email": "belova.g.071973@postgrespro.ru", "phone": "+70938406733"}
0005432655597	3D24F7	6772 482479	NADEZHDA YAKOVLEVA	{"phone": "+70162167982"}
0005432655598	E490CA	9313 444959	ILYA MIRONOV	{"email": "imironov_121980@postgrespro.ru", "phone": "+70327828684"}
0005432655599	1C9279	7107 046223	ILYA MATVEEV	{"phone": "+70991996512"}
0005432655600	1C9279	9333 525573	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr1965@postgrespro.ru", "phone": "+70520293513"}
0005432655601	802AD1	7738 540658	YURIY SOKOLOV	{"email": "sokolov_y.041971@postgrespro.ru", "phone": "+70611057233"}
0005432655602	73429F	8310 423517	ALEKSANDR EGOROV	{"phone": "+70495219389"}
0005432655603	D6801E	3588 143241	ILYA PETROV	{"email": "ipetrov_1963@postgrespro.ru", "phone": "+70658725118"}
0005432655604	D6801E	3906 227775	KIRILL DMITRIEV	{"phone": "+70429276481"}
0005432655605	D6801E	1919 517410	ALEKSANDR BONDARENKO	{"phone": "+70568595216"}
0005432655606	5D44D7	9947 927491	VITALIY DENISOV	{"phone": "+70660985033"}
0005432655607	A0E454	6265 343513	VARVARA KUZMINA	{"phone": "+70284750468"}
0005432655608	4A1499	7387 566653	MIKHAIL BORISOV	{"email": "borisov.mikhail-01121969@postgrespro.ru", "phone": "+70395019622"}
0005432655609	98ECC4	0088 894133	TAMARA ROMANOVA	{"phone": "+70834053598"}
0005432655610	7BA157	9851 134416	MAKSIM ZAYCEV	{"phone": "+70259359424"}
0005432655611	019CB3	9776 157403	VALERIY RODIONOV	{"phone": "+70315602042"}
0005432655612	C70853	1194 101605	VERA KUZMINA	{"email": "kuzmina.v_1969@postgrespro.ru", "phone": "+70091291468"}
0005432655613	07B7EA	4404 375790	SVETLANA PETROVA	{"email": "petrovas1983@postgrespro.ru", "phone": "+70493494451"}
0005432655614	8E2FCF	0234 119515	LYUBOV MAKAROVA	{"email": "makarova.lyubov_021972@postgrespro.ru", "phone": "+70004374679"}
0005432655615	8E2FCF	0322 343805	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay.1972@postgrespro.ru", "phone": "+70901384957"}
0005432655616	903A06	7682 920322	MARINA ABRAMOVA	{"email": "m.abramova-1969@postgrespro.ru", "phone": "+70893378955"}
0005432655617	903A06	9932 904272	YULIYA PAVLOVA	{"email": "pavlova_y071987@postgrespro.ru", "phone": "+70872789650"}
0005432655618	EDB397	4396 798458	ALEKSANDR RODIONOV	{"phone": "+70038052232"}
0005432655619	26D029	9845 097838	STEPAN KOZLOV	{"email": "skozlov_1974@postgrespro.ru", "phone": "+70904364753"}
0005432655620	0EFDEE	8157 951379	GENNADIY SCHERBAKOV	{"email": "scherbakov-g-1967@postgrespro.ru", "phone": "+70251256037"}
0005432655621	44A4EE	4862 233730	VALENTINA MIKHAYLOVA	{"phone": "+70265587186"}
0005432655622	A17EAD	8986 708833	IRINA MIKHAYLOVA	{"email": "mikhaylova_i051972@postgrespro.ru", "phone": "+70587105752"}
0005432655623	A17EAD	1598 570267	ROZA ANTONOVA	{"email": "antonova.roza-19091970@postgrespro.ru", "phone": "+70403651628"}
0005432655624	F196F2	9811 720995	SVETLANA ZHUKOVA	{"email": "zhukova-s-28091974@postgrespro.ru", "phone": "+70822670598"}
0005432655625	E1F7ED	1722 671457	NADEZHDA SEMENOVA	{"phone": "+70518518582"}
0005432655626	171148	3832 499845	TATYANA VOLKOVA	{"phone": "+70322748704"}
0005432655627	7A5405	6142 920380	GALINA LOGINOVA	{"phone": "+70201424189"}
0005432655628	594AA8	2140 942763	NIKOLAY ALEKSEEV	{"phone": "+70528250294"}
0005432655629	01B498	0229 297237	NINA NAZAROVA	{"email": "nina_nazarova-1971@postgrespro.ru", "phone": "+70338470695"}
0005432655630	4A1396	0503 534978	VALERIY MARTYNOV	{"phone": "+70862176756"}
0005432655631	4A1396	1973 868248	SERGEY IVANOV	{"email": "sergey.ivanov.021968@postgrespro.ru", "phone": "+70804993247"}
0005432655632	46CF8A	0972 499045	VALENTINA FROLOVA	{"email": "frolova.valentina17041964@postgrespro.ru", "phone": "+70473967065"}
0005432655633	615DCA	5537 411760	SERGEY KUZMIN	{"phone": "+70440492815"}
0005432655634	615DCA	9800 079075	VASILIY ZAYCEV	{"email": "zaycev-v.1984@postgrespro.ru", "phone": "+70602915426"}
0005432655635	615DCA	5592 025190	OLGA NAUMOVA	{"email": "olga.naumova_091967@postgrespro.ru", "phone": "+70254228710"}
0005432655636	962123	8020 836103	NATALYA IVANOVA	{"phone": "+70772225724"}
0005432655637	962123	2751 039231	NATALYA TIKHONOVA	{"email": "n-tikhonova1964@postgrespro.ru", "phone": "+70899864249"}
0005432655638	017BD4	8513 987778	ALEKSANDR KARPOV	{"email": "aleksandr-karpov25031976@postgrespro.ru", "phone": "+70981656172"}
0005432655639	E43706	3471 434002	MARINA MATVEEVA	{"email": "marina_matveeva_1970@postgrespro.ru", "phone": "+70196127509"}
0005432655640	E43706	9953 562085	MARIYA EFREMOVA	{"phone": "+70614414981"}
0005432655641	49210C	9816 145982	VIKTOR SERGEEV	{"phone": "+70944261588"}
0005432655642	F6BBC1	4731 879435	GALINA VOLKOVA	{"phone": "+70685822661"}
0005432655643	5D3689	6124 947932	ALEKSANDR MOISEEV	{"email": "a_moiseev_071970@postgrespro.ru", "phone": "+70439299835"}
0005432655644	76CC36	4634 010113	SERGEY KOZLOV	{"email": "kozlovs_1965@postgrespro.ru", "phone": "+70426592490"}
0005432655645	C9D119	1152 424537	ANDREY ISAEV	{"email": "isaev-a.10121963@postgrespro.ru", "phone": "+70702071008"}
0005432655646	C9D119	0759 909494	ALEKSANDR ANTONOV	{"phone": "+70444024507"}
0005432655647	B92B79	7309 954416	LIDIYA IVANOVA	{"email": "ivanova.lidiya021971@postgrespro.ru", "phone": "+70178648578"}
0005432655648	94BE85	1017 662601	VIKTOR ROMANOV	{"phone": "+70996933943"}
0005432655649	FD05A0	2705 813327	MARIYA TITOVA	{"email": "titovam-03111967@postgrespro.ru", "phone": "+70488029719"}
0005432655650	44F45A	5005 417423	RUSLAN POPOV	{"phone": "+70699428125"}
0005432655651	44F45A	1814 884655	ELIZAVETA OVCHINNIKOVA	{"phone": "+70816929689"}
0005432655652	D3B211	1693 202365	NINA NESTEROVA	{"email": "nnesterova_121973@postgrespro.ru", "phone": "+70217367419"}
0005432655653	425B6B	2412 306613	ALBERT ZAKHAROV	{"phone": "+70161125548"}
0005432655654	6572EA	3731 357945	VIKTOR KUDRYASHOV	{"email": "kudryashovv_05081963@postgrespro.ru", "phone": "+70266949357"}
0005432655655	94B987	9680 896937	ALEKSANDRA SIDOROVA	{"phone": "+70188056543"}
0005432655656	09F578	4847 225060	ALBERT MIRONOV	{"email": "amironov_091979@postgrespro.ru", "phone": "+70243543199"}
0005432655657	282396	9767 621282	GALINA LUKYANOVA	{"email": "galina_lukyanova.1980@postgrespro.ru", "phone": "+70192474782"}
0005432655658	282396	6931 613642	EGOR FILIPPOV	{"phone": "+70123682097"}
0005432655659	C77CE0	3848 358669	TAISIYA IVANOVA	{"phone": "+70937971469"}
0005432655660	643F7D	9872 489146	VIKTOR MATVEEV	{"email": "matveevviktor.10121973@postgrespro.ru", "phone": "+70160339236"}
0005432655661	C5F3CD	3061 824487	OLGA BARANOVA	{"email": "o.baranova_1971@postgrespro.ru", "phone": "+70734065227"}
0005432655662	C5F3CD	7207 838769	MAKSIM KUZMIN	{"phone": "+70855254638"}
0005432655663	F000CF	1200 784323	MIKHAIL KONOVALOV	{"phone": "+70585913647"}
0005432655664	5E0044	0222 034714	ALESYA KOROLEVA	{"email": "koroleva_a-031981@postgrespro.ru", "phone": "+70913117217"}
0005432655665	5E0044	0218 210155	ALEKSANDR ROMANOV	{"phone": "+70959267970"}
0005432655666	429E9B	8772 747628	TATYANA PAVLOVA	{"email": "tatyana-pavlova_1982@postgrespro.ru", "phone": "+70380978468"}
0005432655667	6B41BD	9651 515598	IRINA KUZNECOVA	{"email": "kuznecova_i041966@postgrespro.ru", "phone": "+70305783198"}
0005432655668	210541	6805 969093	VIKTOR FROLOV	{"phone": "+70762814984"}
0005432655669	210541	3640 962564	VALENTINA IVANOVA	{"phone": "+70614744134"}
0005432655670	5912CA	6293 171739	VASILIY KOZLOV	{"email": "kozlov-v_22041964@postgrespro.ru", "phone": "+70798509125"}
0005432655671	302B41	1859 114013	VYACHESLAV STEPANOV	{"email": "stepanov_v.09101971@postgrespro.ru", "phone": "+70987432669"}
0005432655672	302B41	9776 368508	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir.01121979@postgrespro.ru", "phone": "+70735955718"}
0005432655673	B24102	0158 127467	ELENA ISAEVA	{"phone": "+70948658664"}
0005432655674	B24102	7112 347886	YURIY MAKAROV	{"phone": "+70395892256"}
0005432655675	7567A6	1558 459302	SERGEY BELOV	{"email": "sergey-belov_021972@postgrespro.ru", "phone": "+70751658326"}
0005432655676	C9E188	4390 039485	VALENTINA KOVALEVA	{"email": "kovalevavalentina061978@postgrespro.ru", "phone": "+70332791183"}
0005432655677	C9E188	8267 478158	VLADIMIR BORISOV	{"phone": "+70324962693"}
0005432655678	C00A6F	3072 408925	SERGEY KRASNOV	{"email": "skrasnov-061959@postgrespro.ru", "phone": "+70055582803"}
0005432655679	C00A6F	0240 861383	VALENTINA NESTEROVA	{"phone": "+70994783201"}
0005432655680	4F3082	9077 235419	VIKTOR BORISOV	{"phone": "+70678465776"}
0005432655681	4F3082	4420 138385	ANNA BORISOVA	{"email": "anna.borisova.1975@postgrespro.ru", "phone": "+70539570858"}
0005432655682	7EFAF7	4797 646492	NIKITA MAKSIMOV	{"phone": "+70938914034"}
0005432655683	7EFAF7	8416 121730	ALISA SIDOROVA	{"email": "asidorova_15081981@postgrespro.ru", "phone": "+70902629254"}
0005432655684	6F8CBC	0820 254156	MARIYA MIKHAYLOVA	{"phone": "+70547594649"}
0005432655685	C1AE01	1492 510025	SERGEY ZAKHAROV	{"phone": "+70269993775"}
0005432655686	C1AE01	1972 836359	LYUDMILA BELOVA	{"phone": "+70090830897"}
0005432655687	35FBBA	0946 712052	ALEKSANDR VASILEV	{"email": "aleksandrvasilev.1966@postgrespro.ru", "phone": "+70740021475"}
0005432655688	002E3A	5066 294687	TAMARA KUZNECOVA	{"email": "kuznecova-t121982@postgrespro.ru", "phone": "+70755977637"}
0005432655689	002E3A	8500 721647	ALEKSANDR VASILEV	{"phone": "+70626719343"}
0005432655690	5FBFE9	3781 123030	YURIY BONDARENKO	{"email": "bondarenko-yuriy_1978@postgrespro.ru", "phone": "+70787058590"}
0005432655691	C9DC69	6775 869134	ALENA SMIRNOVA	{"email": "smirnovaa-1977@postgrespro.ru", "phone": "+70029390574"}
0005432655692	C9DC69	5931 115688	ANASTASIYA OSIPOVA	{"email": "aosipova-31081964@postgrespro.ru", "phone": "+70127838205"}
0005432655693	C9DC69	4043 230320	VIKTOR MELNIKOV	{"email": "melnikov-viktor.1971@postgrespro.ru", "phone": "+70555274035"}
0005432655694	7E560B	7376 063422	EKATERINA KUZNECOVA	{"email": "e.kuznecova-071974@postgrespro.ru", "phone": "+70476066019"}
0005432655695	7E560B	2838 364988	ANTONINA SMIRNOVA	{"email": "smirnovaa.101959@postgrespro.ru", "phone": "+70967699606"}
0005432655696	4258B8	4273 673011	ALLA KOROLEVA	{"phone": "+70958330690"}
0005432655697	4258B8	6019 504160	VLADIMIR STEPANOV	{"email": "vladimirstepanov1990@postgrespro.ru", "phone": "+70735408121"}
0005432655698	4258B8	4571 965837	OLGA TARASOVA	{"email": "tarasova.olga041974@postgrespro.ru", "phone": "+70132356027"}
0005432655699	F88BB8	9862 346169	IVAN CHERNOV	{"email": "chernov.i.1974@postgrespro.ru", "phone": "+70520155303"}
0005432655700	B2C0D8	6605 278166	ANTONINA GORBUNOVA	{"phone": "+70823506307"}
0005432655701	9C7FB4	3871 155758	ALEKSANDR FROLOV	{"email": "aleksandr-frolov1974@postgrespro.ru", "phone": "+70177221090"}
0005432655702	9C7FB4	8168 899626	SHAMIL NIKITIN	{"email": "shamilnikitin071969@postgrespro.ru", "phone": "+70473415795"}
0005432655703	45803D	7934 691239	YURIY FROLOV	{"email": "yuriyfrolov111982@postgrespro.ru", "phone": "+70558754595"}
0005432655704	45803D	7373 810381	OLGA GUSEVA	{"email": "olga-guseva_05031970@postgrespro.ru", "phone": "+70993426216"}
0005432655705	B9BD94	5536 355560	VIKTOR SMIRNOV	{"email": "smirnov-v_071978@postgrespro.ru", "phone": "+70560749413"}
0005432655706	E5E018	0554 822454	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr.22041978@postgrespro.ru", "phone": "+70089729934"}
0005432655707	BB2A51	3804 484822	POLINA GERASIMOVA	{"email": "gerasimova-polina_27031973@postgrespro.ru", "phone": "+70937094423"}
0005432655708	B6E222	8086 075887	OKSANA IVANOVA	{"email": "ivanova.o-04121987@postgrespro.ru", "phone": "+70292949502"}
0005432655709	E8A9CC	2632 981835	NATALYA VOLKOVA	{"email": "n.volkova-1971@postgrespro.ru", "phone": "+70911647509"}
0005432655710	36DEA9	7891 780721	ALEKSEY SOKOLOV	{"phone": "+70970187474"}
0005432655711	84D23F	7532 199162	GEORGIY POPOV	{"phone": "+70995534338"}
0005432655712	B61F5D	9709 880493	VLADIMIR ORLOV	{"phone": "+70818413967"}
0005432655713	F9E271	0321 107642	ARSENIY NAUMOV	{"email": "arseniy_naumov.1973@postgrespro.ru", "phone": "+70310139492"}
0005432655714	F9E271	3654 957778	VALENTINA RODIONOVA	{"email": "valentina_rodionova_05111965@postgrespro.ru", "phone": "+70452973502"}
0005432655715	1E75C8	5459 984981	IGOR ZAYCEV	{"phone": "+70956459365"}
0005432655716	036846	2206 924656	NADEZHDA BOGDANOVA	{"phone": "+70804594346"}
0005432655717	4B1F73	1093 548480	SERGEY FILIPPOV	{"phone": "+70612989658"}
0005432655718	F964D4	0251 301270	SVETLANA KONOVALOVA	{"email": "konovalova.svetlana13111975@postgrespro.ru", "phone": "+70756536301"}
0005432655719	F41418	1334 295846	KONSTANTIN NIKOLAEV	{"email": "k-nikolaev-06101954@postgrespro.ru", "phone": "+70776116386"}
0005432655720	534E26	6964 915066	ALEKSEY SOLOVEV	{"email": "aleksey_solovev-081979@postgrespro.ru", "phone": "+70884582266"}
0005432655721	534E26	7594 431406	RAVIL MEDVEDEV	{"email": "r-medvedev-1970@postgrespro.ru", "phone": "+70298119613"}
0005432655722	5CA5DA	5935 564496	ALEKSANDR VLASOV	{"email": "avlasov.071979@postgrespro.ru", "phone": "+70868782538"}
0005432655723	CC74D2	0951 898600	VLADIMIR GORBUNOV	{"phone": "+70130448922"}
0005432655724	C83769	4907 687144	ANTONINA MASLOVA	{"email": "maslova.antonina-081981@postgrespro.ru", "phone": "+70866989000"}
0005432655725	C83769	5717 995796	OLGA AFANASEVA	{"phone": "+70000484116"}
0005432655726	207327	1388 695446	ALEKSANDR TIMOFEEV	{"email": "a.timofeev1968@postgrespro.ru", "phone": "+70311531170"}
0005432655727	2EDF98	1062 938632	IGOR ZAYCEV	{"email": "zaycevigor-061979@postgrespro.ru", "phone": "+70916848231"}
0005432655728	FFB5DD	9632 246272	ANTONINA NIKOLAEVA	{"phone": "+70105312700"}
0005432655729	FFB5DD	4452 828503	IVAN VLASOV	{"email": "vlasov_ivan_101971@postgrespro.ru", "phone": "+70021718205"}
0005432655730	CF54D2	4128 156871	GALINA MAKAROVA	{"phone": "+70197494927"}
0005432655731	D95A22	2810 575580	ANDREY NAZAROV	{"email": "a-nazarov071972@postgrespro.ru", "phone": "+70070157142"}
0005432655732	91B6C5	6981 304876	IVAN SOROKIN	{"phone": "+70553125544"}
0005432655733	91B6C5	3103 241245	LYUBOV MOROZOVA	{"phone": "+70782556082"}
0005432655734	FC98E0	2665 138814	IGOR NOVIKOV	{"email": "i-novikov-1973@postgrespro.ru", "phone": "+70664000024"}
0005432655735	B4A2B3	5255 782139	SVETLANA MOROZOVA	{"phone": "+70524255277"}
0005432655736	B4A2B3	6915 782406	VERA KONDRATEVA	{"email": "vera.kondrateva_05121977@postgrespro.ru", "phone": "+70388402162"}
0005432655737	B4A2B3	3940 822146	SERGEY MOROZOV	{"phone": "+70080213165"}
0005432655738	8E859C	4035 469785	LYUDMILA POTAPOVA	{"phone": "+70446172977"}
0005432655739	81625D	3120 791954	ANDREY KARPOV	{"phone": "+70724614944"}
0005432655740	8F4DD3	5572 760631	SERGEY ANDREEV	{"email": "andreev-s_1973@postgrespro.ru", "phone": "+70413979231"}
0005432655741	F248C5	0740 942014	VLADIMIR SIDOROV	{"phone": "+70877960812"}
0005432655742	F248C5	2329 409131	ANNA MAKAROVA	{"email": "anna_makarova-101979@postgrespro.ru", "phone": "+70813485887"}
0005432655743	579824	9454 611982	VALENTINA LUKYANOVA	{"email": "lukyanova.valentina-1967@postgrespro.ru", "phone": "+70102590841"}
0005432655744	837FAC	8028 288731	GENNADIY DMITRIEV	{"email": "dmitriev.gennadiy_07121963@postgrespro.ru", "phone": "+70094505482"}
0005432655745	837FAC	6610 794071	ALEKSANDR OSIPOV	{"email": "aosipov_121975@postgrespro.ru", "phone": "+70840604585"}
0005432655746	6B4908	8638 569953	LIDIYA KAZAKOVA	{"phone": "+70764117052"}
0005432655747	D11DA5	0678 503237	VITALIY OSIPOV	{"phone": "+70798238664"}
0005432655748	87E30E	6815 875525	VADIM SHEVCHENKO	{"email": "shevchenkov-09071981@postgrespro.ru", "phone": "+70519241599"}
0005432655749	E73BB6	3848 475220	ALEKSANDRA MARTYNOVA	{"phone": "+70885494708"}
0005432655750	E73BB6	1259 236188	SERGEY KOZLOV	{"email": "s_kozlov.071969@postgrespro.ru", "phone": "+70393250057"}
0005432655751	106190	9060 050761	NATALIYA VLASOVA	{"email": "vlasova-nataliya_071975@postgrespro.ru", "phone": "+70865596397"}
0005432655752	106190	3924 904296	NINA GRISHINA	{"email": "grishinanina_101967@postgrespro.ru", "phone": "+70445861882"}
0005432655753	106190	5324 711545	VLADISLAV DENISOV	{"phone": "+70779988014"}
0005432655754	877DE7	8533 859690	VYACHESLAV OSIPOV	{"email": "vyacheslav_osipov15121975@postgrespro.ru", "phone": "+70274504902"}
0005432655755	877DE7	2878 740449	DMITRIY ZHUKOV	{"phone": "+70303424443"}
0005432655756	8572D5	5677 765530	NIKOLAY GORBUNOV	{"phone": "+70951885137"}
0005432655757	8572D5	6164 764823	SERGEY POPOV	{"email": "s.popov.1974@postgrespro.ru", "phone": "+70775835636"}
0005432655758	1C39D7	2367 431288	ANNA KUZNECOVA	{"phone": "+70608111571"}
0005432655759	894E4D	1881 074578	LEONID MEDVEDEV	{"email": "leonidmedvedev.081979@postgrespro.ru", "phone": "+70140633136"}
0005432655760	EC4274	9831 955733	VYACHESLAV BELOV	{"phone": "+70997854471"}
0005432655761	C0BB5B	8060 355425	VASILIY VOLKOV	{"email": "volkov.v-091972@postgrespro.ru", "phone": "+70209230809"}
0005432655762	7C4773	0420 010403	KSENIYA SMIRNOVA	{"phone": "+70559512825"}
0005432655763	7C4773	6128 603372	ULYANA SEMENOVA	{"phone": "+70249752968"}
0005432655764	384BDC	1112 773931	OKSANA VOLKOVA	{"email": "oksana_volkova-121977@postgrespro.ru", "phone": "+70164724361"}
0005432655765	384BDC	1787 652874	LYUBOV FADEEVA	{"phone": "+70611458314"}
0005432655766	C40065	5604 793964	IRINA GUSEVA	{"email": "iguseva.04011975@postgrespro.ru", "phone": "+70324285508"}
0005432655767	9C9578	4254 818768	ALEKSANDRA NIKOLAEVA	{"phone": "+70673550346"}
0005432655768	0D1719	4032 198162	ALEKSANDR FOMIN	{"email": "fomin-aleksandr.031969@postgrespro.ru", "phone": "+70114833701"}
0005432655769	7C6577	9690 175216	ALEKSANDR NOVIKOV	{"email": "aleksandr_novikov.011967@postgrespro.ru", "phone": "+70860158494"}
0005432655770	7C6577	7496 277155	ALEKSEY ABRAMOV	{"phone": "+70878090943"}
0005432655771	737BC5	4867 664980	OLGA SIDOROVA	{"email": "o-sidorova_17021988@postgrespro.ru", "phone": "+70117505338"}
0005432655772	737BC5	2885 179589	VYACHESLAV MIKHAYLOV	{"phone": "+70919848820"}
0005432655773	08096E	2976 418964	YURIY PAVLOV	{"phone": "+70752229669"}
0005432655774	77A615	0964 555246	ANDREY MELNIKOV	{"phone": "+70250110452"}
0005432655775	77A615	9320 743078	TATYANA POLYAKOVA	{"phone": "+70530990786"}
0005432655776	3C738C	5521 260124	SAMIRA KUDRYASHOVA	{"email": "samira.kudryashova_13021966@postgrespro.ru", "phone": "+70423012913"}
0005432655777	7A9090	3710 628397	VYACHESLAV FOMIN	{"phone": "+70222035200"}
0005432655778	7A9090	2855 231045	ANASTASIYA PETROVA	{"email": "petrovaa.19011984@postgrespro.ru", "phone": "+70026146402"}
0005432655779	FC0E08	8234 620954	ALEKSEY STEPANOV	{"phone": "+70934078809"}
0005432655780	35F2F3	4405 902423	NIKOLAY ANTONOV	{"email": "nikolay-antonov.1978@postgrespro.ru", "phone": "+70285484058"}
0005432655781	1A5E35	9755 578355	NATALYA LOGINOVA	{"phone": "+70174509601"}
0005432655782	2C9A81	3275 521913	NADEZHDA LEBEDEVA	{"email": "lebedeva_nadezhda1974@postgrespro.ru", "phone": "+70659257566"}
0005432655783	2C9A81	4280 134736	RAISA NESTEROVA	{"phone": "+70674262716"}
0005432655784	E601F4	1767 230772	MIKHAIL PETROV	{"email": "m-petrov061970@postgrespro.ru", "phone": "+70950439589"}
0005432655785	77E528	4899 163304	ZOYA FEDOROVA	{"email": "fedorovazoya22121963@postgrespro.ru", "phone": "+70930508904"}
0005432655786	A9A41B	0630 336809	MARIYA TITOVA	{"email": "titova-m.011982@postgrespro.ru", "phone": "+70165335315"}
0005432655787	A822D3	1066 024604	PAVEL SCHERBAKOV	{"email": "scherbakovpavel.1962@postgrespro.ru", "phone": "+70532083583"}
0005432655788	9CA593	0618 449405	NINA NAZAROVA	{"phone": "+70386160484"}
0005432655789	C5596C	5508 023088	ALEKSANDR MARTYNOV	{"phone": "+70819845104"}
0005432655790	A55C76	7824 437602	ALEKSANDRA SOKOLOVA	{"email": "sokolova.a-31031969@postgrespro.ru", "phone": "+70490673725"}
0005432655791	A55C76	6041 868010	VASILIY CHERNOV	{"email": "chernov_vasiliy-1964@postgrespro.ru", "phone": "+70332476207"}
0005432655792	A1AB8B	6326 520286	SVETLANA TITOVA	{"phone": "+70084859978"}
0005432655793	A1AB8B	8857 871570	DMITRIY FEDOROV	{"email": "dmitriy.fedorov-21061973@postgrespro.ru", "phone": "+70384805014"}
0005432655794	5E6C35	4261 032122	ALEVTINA FROLOVA	{"phone": "+70011688721"}
0005432655795	5E6C35	9793 661784	DARYA FEDOROVA	{"phone": "+70088526392"}
0005432655796	EFCF80	3953 451050	YURIY POPOV	{"email": "popovy.051977@postgrespro.ru", "phone": "+70776104043"}
0005432655797	211796	9226 281501	ANNA SEMENOVA	{"phone": "+70921611404"}
0005432655798	3690D7	0742 706515	ANNA ERMAKOVA	{"phone": "+70741312614"}
0005432655799	71797B	6396 624207	KIRILL PETROV	{"email": "kirill_petrov-1983@postgrespro.ru", "phone": "+70745297912"}
0005432655800	71797B	2404 269964	VLADIMIR MOROZOV	{"phone": "+70240273297"}
0005432655801	96F5DA	7272 887480	TATYANA FOMINA	{"email": "fomina-tatyana_06011961@postgrespro.ru", "phone": "+70951987401"}
0005432655802	96F5DA	0173 406415	ALEKSEY PETROV	{"email": "apetrov_15091977@postgrespro.ru", "phone": "+70520385866"}
0005432655803	96F5DA	5087 329604	DIANA MATVEEVA	{"email": "matveeva.d1976@postgrespro.ru", "phone": "+70600390178"}
0005432655804	B20D4D	6728 755592	ALEKSEY ABRAMOV	{"email": "abramov.aleksey_091968@postgrespro.ru", "phone": "+70957399773"}
0005432655805	A36E60	4396 226717	ZHANNA POTAPOVA	{"email": "z_potapova-1963@postgrespro.ru", "phone": "+70305648825"}
0005432655806	8C58C3	8703 272260	ALEKSANDRA KOVALEVA	{"email": "a-kovaleva-21041985@postgrespro.ru", "phone": "+70592261340"}
0005432655807	8C58C3	5317 522610	MIKHAIL KRASNOV	{"email": "mkrasnov.26031964@postgrespro.ru", "phone": "+70118958257"}
0005432655808	150227	1131 474113	YULIYA ZAKHAROVA	{"phone": "+70492440151"}
0005432655809	150227	7852 353207	LYUDMILA VOLKOVA	{"phone": "+70808932488"}
0005432655810	93F047	6348 353823	GALINA IVANOVA	{"email": "givanova1978@postgrespro.ru", "phone": "+70519367329"}
0005432655811	EA9DD0	9021 103335	ELMIRA VASILEVA	{"email": "vasileva-elmira_1964@postgrespro.ru", "phone": "+70787490219"}
0005432655812	EA9DD0	1166 349855	VLADIMIR MATVEEV	{"email": "matveevvladimir.1972@postgrespro.ru", "phone": "+70713023965"}
0005432655813	D6F92E	7653 039354	NADEZHDA TITOVA	{"email": "titova.nadezhda_1970@postgrespro.ru", "phone": "+70132255571"}
0005432655814	D915EC	8759 044432	VITALIY ROMANOV	{"phone": "+70929451338"}
0005432655815	D915EC	0304 430333	NATALYA RYABOVA	{"email": "ryabova_n.29041971@postgrespro.ru", "phone": "+70150094473"}
0005432655816	5A6730	9139 266383	OKSANA FILATOVA	{"phone": "+70517438719"}
0005432655817	3D5B97	2448 491432	MAKSIM VOROBEV	{"email": "maksim.vorobev.15101978@postgrespro.ru", "phone": "+70218957400"}
0005432655818	3D5B97	0625 583437	SERGEY FOMIN	{"phone": "+70258150130"}
0005432655819	3D5B97	9519 801102	NATALYA SOROKINA	{"email": "natalya.sorokina_041968@postgrespro.ru", "phone": "+70566936296"}
0005432655820	C6A452	0311 985815	KARINA VOLKOVA	{"phone": "+70172407198"}
0005432655821	597915	6173 179414	SVETLANA ZAKHAROVA	{"phone": "+70590850557"}
0005432655822	AA6B17	5078 839948	ANTONINA IVANOVA	{"email": "antonina_ivanova_29091977@postgrespro.ru", "phone": "+70496179217"}
0005432655823	D4E466	2848 601108	DMITRIY VOROBEV	{"email": "d.vorobev-1980@postgrespro.ru", "phone": "+70112180846"}
0005432655824	D3CE2F	7172 965787	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_28021968@postgrespro.ru", "phone": "+70455593571"}
0005432655825	D3CE2F	7145 244697	VALENTINA SOROKINA	{"email": "sorokina.v-011984@postgrespro.ru", "phone": "+70056838050"}
0005432655826	7E66A7	2419 308041	BORIS SMIRNOV	{"phone": "+70595483626"}
0005432655827	2610A4	4729 838912	ANNA BOGDANOVA	{"email": "bogdanova.anna1978@postgrespro.ru", "phone": "+70380555718"}
0005432655828	6F8D03	1477 222002	SERGEY MOISEEV	{"phone": "+70534725414"}
0005432655829	FD9FAC	5855 653269	VIKTORIYA ARKHIPOVA	{"phone": "+70482571803"}
0005432655830	353990	9604 511205	NADEZHDA NESTEROVA	{"phone": "+70379342446"}
0005432655831	353990	6077 887014	ALEKSANDR VLASOV	{"email": "vlasovaleksandr.1979@postgrespro.ru", "phone": "+70734832786"}
0005432655832	7458EF	3043 178697	NATALYA NESTEROVA	{"email": "nesterova.natalya24121977@postgrespro.ru", "phone": "+70694568130"}
0005432655833	AF8158	0723 071415	IRINA SOROKINA	{"email": "isorokina_03121966@postgrespro.ru", "phone": "+70463916769"}
0005432655834	142E48	4494 792238	SVETLANA IVANOVA	{"phone": "+70484008314"}
0005432655835	F8094E	3785 526733	EVGENIYA MOROZOVA	{"email": "morozova_e011971@postgrespro.ru", "phone": "+70191520289"}
0005432655836	AAECE6	3835 179062	ALEKSEY KUZNECOV	{"email": "a.kuznecov.10081977@postgrespro.ru", "phone": "+70380982380"}
0005432655837	FA7CF5	0770 581213	EVGENIY PETROV	{"email": "petrov.e041986@postgrespro.ru", "phone": "+70545263807"}
0005432655838	FA7CF5	6758 422034	ELENA ZAYCEVA	{"phone": "+70032674709"}
0005432655839	AD9235	1586 676823	ANTON ALEKSANDROV	{"phone": "+70101737957"}
0005432655840	687BB6	5569 361220	SERGEY SMIRNOV	{"phone": "+70192169103"}
0005432655841	4E7901	9262 793289	FANIYA TARASOVA	{"phone": "+70346905040"}
0005432655842	42AF6C	3643 699577	VALERIY ILIN	{"phone": "+70480922007"}
0005432655843	42AF6C	0581 568213	ALENA BORISOVA	{"email": "borisovaalena1964@postgrespro.ru", "phone": "+70367065110"}
0005432655844	EE86C4	2042 293691	ALEKSANDR SOLOVEV	{"email": "a-solovev031961@postgrespro.ru", "phone": "+70481015912"}
0005432655845	EE86C4	2304 728733	RINAT ZAYCEV	{"phone": "+70674268137"}
0005432655846	F96707	2741 273346	GALINA VOROBEVA	{"email": "g.vorobeva1976@postgrespro.ru", "phone": "+70234243224"}
0005432655847	F96707	3978 798267	MIKHAIL FILIPPOV	{"phone": "+70274306299"}
0005432655848	EB53C9	5983 523339	TATYANA KOROLEVA	{"phone": "+70093163664"}
0005432655849	EB53C9	6259 262095	MAKSIM STEPANOV	{"email": "stepanov.m-071970@postgrespro.ru", "phone": "+70823559771"}
0005432655850	E96DF3	5272 107235	MAKSIM NAZAROV	{"phone": "+70647600340"}
0005432655851	6869B8	1662 568290	EKATERINA FROLOVA	{"phone": "+70603605016"}
0005432655852	81B7C1	2591 852100	NADEZHDA SERGEEVA	{"phone": "+70325188148"}
0005432655853	90D8D2	8372 993187	LEONID ANDREEV	{"phone": "+70296190432"}
0005432655854	3E0E12	1750 068683	VLADIMIR NIKITIN	{"phone": "+70359393823"}
0005432655855	6CD684	3083 736428	LARISA FILIPPOVA	{"email": "larisa-filippova_10011983@postgrespro.ru", "phone": "+70704849680"}
0005432655856	6CD684	3229 602282	ANASTASIYA GAVRILOVA	{"phone": "+70604405854"}
0005432655857	0FABB1	9289 528181	ELENA NOVIKOVA	{"email": "novikova-elena_10121964@postgrespro.ru", "phone": "+70793849903"}
0005432655858	CEA543	4112 687680	ELENA BELYAEVA	{"email": "elena_belyaeva_04051977@postgrespro.ru", "phone": "+70083569048"}
0005432655859	40787A	4050 392460	ALEKSEY MARTYNOV	{"email": "aleksey-martynov-04051968@postgrespro.ru", "phone": "+70465055653"}
0005432655860	744BC3	2867 525163	NATALYA POPOVA	{"email": "n-popova1973@postgrespro.ru", "phone": "+70118994193"}
0005432655861	E1518F	4265 857188	VALENTINA POPOVA	{"email": "popovavalentina_101986@postgrespro.ru", "phone": "+70452210408"}
0005432655862	7A7337	4517 116189	ALEKSEY NOVIKOV	{"email": "aleksey_novikov_1971@postgrespro.ru", "phone": "+70828188809"}
0005432655863	7A7337	1678 109089	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr_011967@postgrespro.ru", "phone": "+70684064659"}
0005432655864	DDFCB2	4086 717359	MIKHAIL MIKHAYLOV	{"email": "m.mikhaylov081967@postgrespro.ru", "phone": "+70262709396"}
0005432655865	DDFCB2	8459 334883	IRINA MAKSIMOVA	{"phone": "+70163593706"}
0005432655866	F9D350	2063 726221	VALENTINA AFANASEVA	{"email": "afanaseva_valentina-1976@postgrespro.ru", "phone": "+70013070241"}
0005432655867	714F06	4054 716524	NATALYA POPOVA	{"email": "popova.n.18011969@postgrespro.ru", "phone": "+70496823371"}
0005432655868	714F06	8727 862526	LARISA MELNIKOVA	{"email": "lmelnikova_04061974@postgrespro.ru", "phone": "+70652376358"}
0005432655869	98DAAF	4967 146315	VADIM PAVLOV	{"email": "vpavlov.021969@postgrespro.ru", "phone": "+70746266609"}
0005432655870	74A919	9571 143343	ELENA ORLOVA	{"email": "eorlova.1968@postgrespro.ru", "phone": "+70185425584"}
0005432655871	EF2738	5194 135223	EVGENIY ZAYCEV	{"email": "zaycev_e061975@postgrespro.ru", "phone": "+70903976866"}
0005432655872	EF2738	2743 379962	STANISLAV VLASOV	{"phone": "+70190520941"}
0005432655873	4AD4CF	4950 594930	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr1975@postgrespro.ru", "phone": "+70194237395"}
0005432655874	4AD4CF	4621 094419	LYUDMILA KISELEVA	{"phone": "+70962162868"}
0005432655875	4273B9	4726 058908	ANATOLIY NAZAROV	{"email": "anatoliy.nazarov-08011967@postgrespro.ru", "phone": "+70409003313"}
0005432655876	4273B9	6991 333235	SVETLANA KUDRYASHOVA	{"email": "svetlana-kudryashova.03061973@postgrespro.ru", "phone": "+70967386903"}
0005432655877	767ABF	5837 392515	DMITRIY ZAYCEV	{"email": "dzaycev09051970@postgrespro.ru", "phone": "+70590892545"}
0005432655878	767ABF	5663 918767	TAMARA EGOROVA	{"email": "tamara.egorova_071975@postgrespro.ru", "phone": "+70212482100"}
0005432655879	E01978	9362 392517	YULIYA ZAKHAROVA	{"phone": "+70809794491"}
0005432655880	E01978	0323 841553	VLADIMIR KUZNECOV	{"email": "kuznecov.v09061971@postgrespro.ru", "phone": "+70756743368"}
0005432655881	99B86D	0695 211623	ALEKSANDR KONOVALOV	{"email": "konovalov_a_14121981@postgrespro.ru", "phone": "+70238372730"}
0005432655882	2F0EC2	5102 229302	LIDIYA MIKHAYLOVA	{"phone": "+70162762909"}
0005432655883	CE544E	0001 279620	GALINA KONDRATEVA	{"email": "kondrateva_galina1967@postgrespro.ru", "phone": "+70433915659"}
0005432655884	CE544E	1048 201227	OLGA MIRONOVA	{"phone": "+70874962278"}
0005432655885	E47ACA	8079 840523	ALEKSANDRA SOKOLOVA	{"phone": "+70572020587"}
0005432655886	AA54D3	0621 826221	OLGA SIDOROVA	{"email": "sidorova_olga_1969@postgrespro.ru", "phone": "+70600923550"}
0005432655887	88BE44	5378 074162	NATALYA BOGDANOVA	{"email": "bogdanova-n1973@postgrespro.ru", "phone": "+70985624606"}
0005432655888	C283E4	6994 371236	LEONID NIKITIN	{"phone": "+70306958776"}
0005432655889	C283E4	2166 176511	MARINA RODIONOVA	{"phone": "+70010402437"}
0005432655890	C283E4	8800 267780	ELENA ZHURAVLEVA	{"phone": "+70230593587"}
0005432655891	320674	8070 438092	YULIYA KRASNOVA	{"phone": "+70910859682"}
0005432655892	5E83E1	8149 124578	ANDREY YAKOVLEV	{"phone": "+70964338811"}
0005432657515	296DE4	9427 466701	RAISA KISELEVA	{"phone": "+70620874549"}
0005432657393	6E8339	7782 870891	NATALYA ROMANOVA	{"phone": "+70731466023"}
0005432657394	F172B1	1691 294109	ELIZAVETA FADEEVA	{"email": "efadeeva.031970@postgrespro.ru", "phone": "+70503649989"}
0005432657395	0490CA	0088 032922	VLADIMIR PAVLOV	{"email": "vladimir_pavlov-081964@postgrespro.ru", "phone": "+70834904634"}
0005432657396	2DAC72	6546 383420	OLGA VLASOVA	{"email": "vlasova-o.1973@postgrespro.ru", "phone": "+70213315955"}
0005432657397	2DAC72	1827 594672	VLADIMIR KUZMIN	{"phone": "+70586042881"}
0005432657398	DF792B	8811 170100	OLGA ANDREEVA	{"phone": "+70043595614"}
0005432657399	DF792B	2996 331858	SERGEY SEMENOV	{"phone": "+70149077921"}
0005432657400	07FBB3	7215 407029	YURIY BONDARENKO	{"email": "bondarenko_y_12011981@postgrespro.ru", "phone": "+70220727094"}
0005432657401	99F989	3586 784740	MARIYA IVANOVA	{"email": "mariya-ivanova.071973@postgrespro.ru", "phone": "+70267778510"}
0005432657402	662259	7009 447586	NIKOLAY FROLOV	{"email": "nikolay_frolov1962@postgrespro.ru", "phone": "+70728788483"}
0005432657403	662259	4381 706136	TATYANA SERGEEVA	{"phone": "+70342248647"}
0005432657404	3A195E	5283 208476	ANATOLIY EGOROV	{"email": "anatoliy-egorov_091971@postgrespro.ru", "phone": "+70320283079"}
0005432657405	A1D7B0	5768 777933	YURIY SHEVCHENKO	{"email": "shevchenkoyuriy101981@postgrespro.ru", "phone": "+70076896794"}
0005432657406	A1D7B0	3839 026742	GALINA NESTEROVA	{"phone": "+70291587545"}
0005432657407	155DE9	0641 180897	EVA IVANOVA	{"email": "eva_ivanova_011975@postgrespro.ru", "phone": "+70491665009"}
0005432657408	A93C10	8882 132414	YULIYA SOROKINA	{"phone": "+70975538397"}
0005432657409	C74141	6167 444298	MARINA SOROKINA	{"email": "sorokina-m1975@postgrespro.ru", "phone": "+70453597648"}
0005432657410	BAE770	7990 715552	IVAN ANTONOV	{"email": "ivan_antonov.04051980@postgrespro.ru", "phone": "+70127703087"}
0005432657411	8CF778	7999 763820	IGOR DENISOV	{"email": "denisov.i.31101963@postgrespro.ru", "phone": "+70147793551"}
0005432657412	8CF778	7922 181624	SERGEY FEDOTOV	{"email": "fedotovsergey1983@postgrespro.ru", "phone": "+70380104055"}
0005432657413	8CF778	6628 172264	ANATOLIY PETROV	{"email": "petrov_a13071969@postgrespro.ru", "phone": "+70375538606"}
0005432657414	BE0325	5972 915254	ELENA SOROKINA	{"phone": "+70122827810"}
0005432657415	B67747	4202 756217	NIKOLAY MAKAROV	{"phone": "+70825015341"}
0005432657416	B67747	1239 644559	TATYANA GERASIMOVA	{"email": "gerasimova-t1968@postgrespro.ru", "phone": "+70778531508"}
0005432657417	71D240	2207 229219	MAKSIM SEMENOV	{"phone": "+70236802772"}
0005432657418	1A0513	9380 205241	VIKTOR PAVLOV	{"email": "pavlov_viktor.111976@postgrespro.ru", "phone": "+70748089840"}
0005432657419	C9EA06	5779 461544	ALEKSANDRA FROLOVA	{"email": "frolovaa-1964@postgrespro.ru", "phone": "+70690332674"}
0005432657420	C9EA06	9670 722090	ARTEM KOROLEV	{"email": "artem-korolev1966@postgrespro.ru", "phone": "+70789817344"}
0005432657421	558AF5	7786 618535	ANFISA SMIRNOVA	{"email": "smirnova_anfisa22041969@postgrespro.ru", "phone": "+70047098840"}
0005432657422	ACDA68	8638 311524	VALENTINA MAKAROVA	{"phone": "+70345427636"}
0005432657423	1C2CAB	9068 748696	ELENA VASILEVA	{"email": "elenavasileva101954@postgrespro.ru", "phone": "+70036429752"}
0005432657424	1C2CAB	5556 869248	YURIY KISELEV	{"phone": "+70323558978"}
0005432657425	1C2CAB	9094 518066	ELENA KOROLEVA	{"email": "e-koroleva-12121966@postgrespro.ru", "phone": "+70493469724"}
0005432657426	D3ED4D	7239 576823	ELENA BORISOVA	{"email": "e-borisova26091977@postgrespro.ru", "phone": "+70007301362"}
0005432657427	D3ED4D	0617 870824	ALEKSANDRA DENISOVA	{"email": "a.denisova021975@postgrespro.ru", "phone": "+70621760416"}
0005432657428	D3ED4D	7357 901379	EVGENIY KOROLEV	{"phone": "+70692656548"}
0005432657429	2D23D5	2909 328799	IVAN VOROBEV	{"email": "vorobevi_11101973@postgrespro.ru", "phone": "+70043183124"}
0005432657430	FD2E35	5888 619076	MAKSIM DENISOV	{"phone": "+70651896873"}
0005432657431	FD2E35	6791 889343	YURIY AFANASEV	{"email": "yuriy-afanasev-26031972@postgrespro.ru", "phone": "+70191227356"}
0005432657432	5DB021	4564 632882	RAISA KUZNECOVA	{"phone": "+70049111962"}
0005432657433	B86CE7	2202 176529	EKATERINA PETROVA	{"email": "ekaterina-petrova-30031983@postgrespro.ru", "phone": "+70172322062"}
0005432657434	B86CE7	2932 692848	LARISA RODIONOVA	{"email": "rodionova-l.29041975@postgrespro.ru", "phone": "+70476632434"}
0005432657435	22D9EC	3033 782937	YURIY KARPOV	{"email": "karpov.yuriy-061967@postgrespro.ru", "phone": "+70566587820"}
0005432657436	82AABC	8388 981344	GALINA NAUMOVA	{"email": "naumovag-07041964@postgrespro.ru", "phone": "+70119167155"}
0005432657437	82AABC	9593 758966	EKATERINA NESTEROVA	{"email": "nesterova-e17091974@postgrespro.ru", "phone": "+70928039709"}
0005432657438	FCD0D7	4345 102762	LYUBOV YAKOVLEVA	{"email": "yakovleva_lyubov.1965@postgrespro.ru", "phone": "+70264875404"}
0005432657439	FCD0D7	1631 387254	TAMARA KOROLEVA	{"email": "tamara_koroleva1972@postgrespro.ru", "phone": "+70421972311"}
0005432657440	FCD0D7	8513 903043	VIKTOR NIKOLAEV	{"phone": "+70439333963"}
0005432657441	11FA7B	4084 166220	VLADISLAV VLASOV	{"phone": "+70804238342"}
0005432657442	3E7021	9828 893256	LYUDMILA GAVRILOVA	{"email": "gavrilova-l.051979@postgrespro.ru", "phone": "+70804867384"}
0005432657443	7B427A	9715 774427	TATYANA ZAKHAROVA	{"email": "t_zakharova1973@postgrespro.ru", "phone": "+70824727312"}
0005432657444	7B427A	1692 375560	NATALIYA NIKITINA	{"phone": "+70399663490"}
0005432657445	1DEB2D	3862 232838	MARGARITA ILINA	{"phone": "+70384132229"}
0005432657446	C8AC0A	8257 342707	EKATERINA MATVEEVA	{"phone": "+70595728872"}
0005432657447	AB42CA	1880 479107	DMITRIY PAVLOV	{"phone": "+70617981475"}
0005432657448	E22609	7329 016346	LYUDMILA GAVRILOVA	{"email": "gavrilova_l031978@postgrespro.ru", "phone": "+70639578554"}
0005432657449	8E1ACE	1068 155718	MIKHAIL CHERNOV	{"phone": "+70340988996"}
0005432657450	E8B783	0392 730149	VALENTINA DMITRIEVA	{"email": "dmitrieva-valentina-111971@postgrespro.ru", "phone": "+70419080590"}
0005432657451	65E742	8203 925089	NATALYA VLASOVA	{"phone": "+70007614051"}
0005432657452	DCC0C8	7678 221963	ANASTASIYA GORBUNOVA	{"phone": "+70023101339"}
0005432657453	FD683E	4609 260843	EKATERINA ISAEVA	{"email": "ekaterina_isaeva.1971@postgrespro.ru", "phone": "+70820368111"}
0005432657454	FD683E	8565 300809	ARTEM NAZAROV	{"phone": "+70875504219"}
0005432657455	ABE342	5813 791756	NIKITA KRASNOV	{"email": "nikitakrasnov.031974@postgrespro.ru", "phone": "+70421469252"}
0005432657456	14D3A5	8451 851868	ANATOLIY KUZMIN	{"email": "anatoliy.kuzmin1978@postgrespro.ru", "phone": "+70244457197"}
0005432657457	3736B4	6694 984813	GALINA NAZAROVA	{"email": "g.nazarova-061977@postgrespro.ru", "phone": "+70400414489"}
0005432657458	EB3050	9516 051572	ALEKSANDR SOROKIN	{"email": "sorokin_a071965@postgrespro.ru", "phone": "+70201321945"}
0005432657459	EB3050	2285 184521	LYUBOV RODIONOVA	{"email": "rodionovalyubov-1970@postgrespro.ru", "phone": "+70350129742"}
0005432657460	A2A8FF	9950 969015	SERGEY KUZNECOV	{"email": "kuznecov-s.051969@postgrespro.ru", "phone": "+70988314236"}
0005432657461	A2A8FF	0218 736414	LYUBOV EFREMOVA	{"email": "efremova.l-061976@postgrespro.ru", "phone": "+70507142382"}
0005432657462	4A0E48	6949 702632	MAKSIM MAKAROV	{"phone": "+70703355303"}
0005432657463	61C334	5555 674392	VIKTOR PETROV	{"phone": "+70415765978"}
0005432657464	D1DB26	7229 086394	ANDREY POPOV	{"email": "apopov-011973@postgrespro.ru", "phone": "+70559197150"}
0005432657465	81AE59	9701 561149	ARINA POPOVA	{"email": "popova_arina-061974@postgrespro.ru", "phone": "+70572400230"}
0005432657466	20E2DC	4861 469720	ALEKSANDR SERGEEV	{"phone": "+70744859603"}
0005432657467	40A751	9555 361684	ANNA MOROZOVA	{"email": "anna-morozova.27091979@postgrespro.ru", "phone": "+70099061165"}
0005432657468	42C436	6895 020849	DANIIL KUZNECOV	{"email": "daniil_kuznecov_1969@postgrespro.ru", "phone": "+70536728757"}
0005432657469	223B32	9483 139372	DMITRIY KARPOV	{"email": "karpov.d.23071975@postgrespro.ru", "phone": "+70205881187"}
0005432657470	223B32	4143 853324	SVETLANA MOROZOVA	{"phone": "+70162458587"}
0005432657471	17BE37	5045 450819	VLADIMIR DMITRIEV	{"email": "vdmitriev-031967@postgrespro.ru", "phone": "+70604521900"}
0005432657472	CA8703	4637 757148	OKSANA EGOROVA	{"email": "o.egorova22031975@postgrespro.ru", "phone": "+70533538494"}
0005432657473	90333A	4978 455698	VLADISLAV MOISEEV	{"phone": "+70396830219"}
0005432657474	90333A	8070 926013	ALEKSANDR SERGEEV	{"phone": "+70093745424"}
0005432657475	CA15D2	1137 407639	ANDREY ALEKSEEV	{"phone": "+70213630521"}
0005432657476	3E1FDE	1979 267438	MARIYA MOROZOVA	{"phone": "+70010958247"}
0005432657477	A8300B	0682 477025	OLGA LUKYANOVA	{"phone": "+70566737558"}
0005432657478	A675B7	0968 710383	ULYANA MOROZOVA	{"phone": "+70592676215"}
0005432657479	0CF598	9552 964327	MARIYA PAVLOVA	{"phone": "+70765864805"}
0005432657480	68691D	8088 109228	ANATOLIY VLASOV	{"email": "a_vlasov-011966@postgrespro.ru", "phone": "+70049605206"}
0005432657481	D10E08	2722 587202	IVAN NAUMOV	{"phone": "+70566597398"}
0005432657482	90C19A	5862 574027	DANILA KULIKOV	{"email": "d_kulikov.021978@postgrespro.ru", "phone": "+70672894962"}
0005432657483	90C19A	1780 799510	IRINA VASILEVA	{"phone": "+70919805333"}
0005432657484	92EF30	3033 109431	NINA KUZNECOVA	{"email": "kuznecova-nina_17111981@postgrespro.ru", "phone": "+70285928621"}
0005432657485	61D9AD	6331 989465	VYACHESLAV BELOV	{"email": "belov_v-1967@postgrespro.ru", "phone": "+70693791654"}
0005432657486	EBC1D9	9318 316432	NINA FOMINA	{"email": "n.fomina.041978@postgrespro.ru", "phone": "+70017590147"}
0005432657487	EBC1D9	9106 166813	TATYANA BELOVA	{"email": "t-belova-081972@postgrespro.ru", "phone": "+70536834813"}
0005432657488	EBC1D9	6255 515309	MARINA VASILEVA	{"phone": "+70583510715"}
0005432657489	EBC1D9	9421 824772	KONSTANTIN MOROZOV	{"phone": "+70751588584"}
0005432657490	561092	2028 074876	VALERIY ZAYCEV	{"phone": "+70503382303"}
0005432657491	2D632D	0387 203993	SERGEY KUZMIN	{"email": "skuzmin.1975@postgrespro.ru", "phone": "+70573972870"}
0005432657492	993A84	8857 973162	TATYANA DENISOVA	{"email": "t-denisova_26051973@postgrespro.ru", "phone": "+70774768860"}
0005432657493	AECEC2	3943 705940	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin_12061976@postgrespro.ru", "phone": "+70663339786"}
0005432657494	3C375F	8445 739826	OLGA KISELEVA	{"email": "kiselevaolga-1981@postgrespro.ru", "phone": "+70856094133"}
0005432657495	5EFE1D	8485 438923	OKSANA YAKOVLEVA	{"email": "yakovlevaoksana.1988@postgrespro.ru", "phone": "+70049016942"}
0005432657496	5EFE1D	2438 525607	ANNA FEDOROVA	{"phone": "+70683653079"}
0005432657497	5EFE1D	4696 734381	IRINA NOVIKOVA	{"phone": "+70295702460"}
0005432657498	66C8E3	5945 328719	NADEZHDA KUZNECOVA	{"email": "kuznecovan-071968@postgrespro.ru", "phone": "+70649548209"}
0005432657499	66C8E3	7180 723635	VALERIY MOISEEV	{"phone": "+70106258631"}
0005432657500	66C8E3	3216 402847	YURIY KOROLEV	{"phone": "+70067052959"}
0005432657501	C4EBB5	2336 849142	ELENA KONOVALOVA	{"email": "konovalova.elena1966@postgrespro.ru", "phone": "+70427147049"}
0005432657502	B313DB	3721 785635	TATYANA DANILOVA	{"email": "danilova-t.05091954@postgrespro.ru", "phone": "+70503705007"}
0005432657503	BEE713	7666 797277	GLEB KARPOV	{"phone": "+70750497729"}
0005432657504	A54FBB	1992 353572	MAKAR GRIGOREV	{"email": "grigorev.m.051983@postgrespro.ru", "phone": "+70131979204"}
0005432657505	A54FBB	8689 920661	ANNA EGOROVA	{"phone": "+70852821976"}
0005432657506	E0EF4C	0830 340047	ANATOLIY KARPOV	{"email": "a.karpov.031967@postgrespro.ru", "phone": "+70100045191"}
0005432657507	C4C773	1455 715960	ANASTASIYA NOVIKOVA	{"phone": "+70895172320"}
0005432657508	C4C773	5804 751678	NINA ANTONOVA	{"email": "n.antonova12101980@postgrespro.ru", "phone": "+70972933096"}
0005432657509	C3CD71	4646 948243	IGOR IVANOV	{"phone": "+70845273997"}
0005432657510	FE90BF	1192 643519	SERGEY BORISOV	{"phone": "+70131162801"}
0005432657511	43B5F1	6026 903867	BORIS MAKAROV	{"email": "b-makarov-01101981@postgrespro.ru", "phone": "+70707879265"}
0005432657512	C4DEE3	3872 834294	ANASTASIYA GRISHINA	{"email": "grishina_anastasiya09061972@postgrespro.ru", "phone": "+70278570009"}
0005432657513	C4DEE3	4623 316184	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov-02051970@postgrespro.ru", "phone": "+70714403097"}
0005432657514	C4DEE3	7079 157783	ALEKSANDR VASILEV	{"phone": "+70771985705"}
0005432657516	EDDDE9	4270 596105	VERONIKA ANTONOVA	{"email": "veronika-antonova.11021967@postgrespro.ru", "phone": "+70601546264"}
0005432657517	24E745	7563 076439	VITALIY SERGEEV	{"phone": "+70712333727"}
0005432657518	24E745	7158 001726	IRINA FEDOROVA	{"phone": "+70509323434"}
0005432657519	24E745	9746 207275	SNEZHANA GUSEVA	{"phone": "+70216362693"}
0005432657520	378F79	8602 584830	OLGA NOVIKOVA	{"email": "novikova.olga-021977@postgrespro.ru", "phone": "+70825425828"}
0005432657521	B508B5	9792 706905	TATYANA SIDOROVA	{"email": "sidorova.tatyana_071977@postgrespro.ru", "phone": "+70568608915"}
0005432657522	5C6DA5	0488 014470	SERGEY SOROKIN	{"email": "sorokinsergey23071963@postgrespro.ru", "phone": "+70157155257"}
0005432657523	B50473	4319 855207	OLGA CHERNOVA	{"phone": "+70874244217"}
0005432657524	5E6666	2528 704650	OLGA ZAYCEVA	{"email": "ozayceva-1967@postgrespro.ru", "phone": "+70174629894"}
0005432657525	C931E1	3626 708297	STANISLAV KOZLOV	{"phone": "+70389205758"}
0005432657526	C931E1	5268 248130	MARINA NIKITINA	{"email": "marina-nikitina.1971@postgrespro.ru", "phone": "+70663815777"}
0005432657527	18A984	8663 326082	TATYANA VOLKOVA	{"email": "volkovatatyana021979@postgrespro.ru", "phone": "+70546020986"}
0005432657528	18A984	6342 033028	IRINA VOROBEVA	{"phone": "+70471993289"}
0005432657529	ABCFE4	4147 705986	ANATOLIY ANTONOV	{"phone": "+70934634659"}
0005432657530	E92E3B	9727 683092	MILENA ROMANOVA	{"email": "romanova.milena_1978@postgrespro.ru", "phone": "+70926447111"}
0005432657531	7FEC75	2405 998385	SVETLANA ZAKHAROVA	{"phone": "+70572226973"}
0005432657532	7FEC75	4319 794968	ALEKSEY YAKOVLEV	{"phone": "+70430451836"}
0005432657533	C24B4B	8653 424840	LYUBOV KOZLOVA	{"email": "kozlova-lyubov.14021964@postgrespro.ru", "phone": "+70176500125"}
0005432657534	9D7F21	0768 128547	LARISA KOROLEVA	{"email": "koroleva_larisa.1972@postgrespro.ru", "phone": "+70690912927"}
0005432657535	53762F	8966 442578	MIKHAIL GAVRILOV	{"phone": "+70576129222"}
0005432657536	53762F	0161 289419	BORIS KULIKOV	{"email": "b.kulikov091972@postgrespro.ru", "phone": "+70194652518"}
0005432657537	EEBE20	7575 227227	VALENTINA NESTEROVA	{"phone": "+70610022515"}
0005432657538	F6E5F9	0426 819466	GENNADIY NAUMOV	{"phone": "+70846568729"}
0005432657539	80A8B5	1233 428388	YULIYA MATVEEVA	{"phone": "+70765209998"}
0005432657540	313D58	0399 556988	MIKHAIL SOLOVEV	{"email": "solovevm_121970@postgrespro.ru", "phone": "+70790523664"}
0005432657541	313D58	5754 611113	DMITRIY NOVIKOV	{"phone": "+70389577894"}
0005432658616	DF2680	2021 005154	EKATERINA PAVLOVA	{"phone": "+70403828028"}
0005432658578	A4C136	3554 797427	ARTUR MAKSIMOV	{"phone": "+70760222018"}
0005432658555	8A45DA	1800 379555	LARISA MAKSIMOVA	{"phone": "+70639166907"}
0005432658556	8A45DA	9885 754393	NATALYA PAVLOVA	{"email": "natalya.pavlova-1968@postgrespro.ru", "phone": "+70830584081"}
0005432658557	6D32E8	7338 508142	MARIYA ALEKSEEVA	{"phone": "+70114753313"}
0005432658558	7654B9	6961 852294	MAKSIM ZAYCEV	{"email": "zaycev-m-1971@postgrespro.ru", "phone": "+70771843571"}
0005432658559	7654B9	1813 411311	GALINA KOZLOVA	{"email": "kozlova.g1974@postgrespro.ru", "phone": "+70350112630"}
0005432658560	6B3A9E	2357 391913	YULIYA RYABOVA	{"phone": "+70691599054"}
0005432658561	E932DC	3532 982355	KRISTINA KUZMINA	{"phone": "+70193969424"}
0005432658562	58DF4F	4811 720277	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova-1975@postgrespro.ru", "phone": "+70680231002"}
0005432658563	DBB830	0059 403863	MAKSIM MOROZOV	{"email": "maksim_morozov-021966@postgrespro.ru", "phone": "+70920474673"}
0005432658564	C175B6	4130 184969	VIKTOR TARASOV	{"phone": "+70701903249"}
0005432658565	CA038B	0705 767968	ANATOLIY VOLKOV	{"email": "volkov-anatoliy-27051969@postgrespro.ru", "phone": "+70063762422"}
0005432658566	CA038B	7207 382901	ALEKSANDR AFANASEV	{"email": "afanasev.a011970@postgrespro.ru", "phone": "+70996389076"}
0005432658567	A5D6F8	3971 174105	EKATERINA KONDRATEVA	{"phone": "+70105503266"}
0005432658568	F1F858	4782 141280	ANASTASIYA SOROKINA	{"phone": "+70587065393"}
0005432658569	EC7EDA	3130 106437	ANASTASIYA YAKOVLEVA	{"email": "yakovleva-a02021966@postgrespro.ru", "phone": "+70573296096"}
0005432658570	EC7EDA	2663 447520	RAISA IVANOVA	{"phone": "+70358926759"}
0005432658571	EC7EDA	3051 832947	OLEG ISAEV	{"phone": "+70590369458"}
0005432658572	B8692B	5168 714103	KIRILL SIDOROV	{"phone": "+70934489400"}
0005432658573	91E96E	8434 894410	ALEKSANDR DMITRIEV	{"phone": "+70601862114"}
0005432658574	975BED	1714 735788	NADEZHDA SAVELEVA	{"phone": "+70328788104"}
0005432658575	975BED	7743 827051	VLADIMIR SEMENOV	{"email": "vladimir.semenov19041974@postgrespro.ru", "phone": "+70319012659"}
0005432658576	140BEB	9712 416431	ANAIT POPOVA	{"email": "popova-anait-10061978@postgrespro.ru", "phone": "+70923865502"}
0005432658577	140BEB	4556 275392	ALEKSANDR NOVIKOV	{"phone": "+70502671556"}
0005432658579	BF5642	0663 355985	ANTONINA CHERNOVA	{"phone": "+70879075369"}
0005432658580	86B3FD	8626 574312	ANASTASIYA SOROKINA	{"phone": "+70488749887"}
0005432658581	86B3FD	8924 490536	VASILIY NIKITIN	{"email": "nikitin_v11101974@postgrespro.ru", "phone": "+70762912962"}
0005432658582	9D1E14	0718 538801	DANILA STEPANOV	{"phone": "+70952995803"}
0005432658583	AC4D01	6400 218274	LYUDMILA KISELEVA	{"phone": "+70605284293"}
0005432658584	AC4D01	9784 925818	DMITRIY KONOVALOV	{"email": "dmitriy_konovalov091967@postgrespro.ru", "phone": "+70415505000"}
0005432658585	2AA46A	5612 037380	LYUDMILA MAKSIMOVA	{"email": "maksimoval-07041971@postgrespro.ru", "phone": "+70688968972"}
0005432658586	2AA46A	6858 210736	YAROSLAV VLASOV	{"email": "y-vlasov1970@postgrespro.ru", "phone": "+70234828757"}
0005432658587	2AA46A	7294 883334	VITALIY ZAKHAROV	{"phone": "+70329070097"}
0005432658588	B8BA24	5137 027317	NINA ILINA	{"phone": "+70894296646"}
0005432658589	F186CC	5477 592197	SERGEY NIKITIN	{"phone": "+70302442840"}
0005432658590	2EB02E	3387 150481	IRINA TIMOFEEVA	{"phone": "+70336232208"}
0005432658591	67DCC2	4579 759912	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev-10111970@postgrespro.ru", "phone": "+70094676634"}
0005432658592	951CC9	2665 307079	RAIL VASILEV	{"email": "rvasilev-1966@postgrespro.ru", "phone": "+70857944903"}
0005432658593	CAB97C	6876 219496	TATYANA DANILOVA	{"phone": "+70760763314"}
0005432658594	CAB97C	5873 677112	ZLATA FOMINA	{"email": "zfomina1976@postgrespro.ru", "phone": "+70954965409"}
0005432658595	C866F9	1422 604986	ELENA VASILEVA	{"phone": "+70271937117"}
0005432658596	260B25	9766 553575	ALISA ZAYCEVA	{"phone": "+70082017383"}
0005432658597	260B25	7142 552823	ALEKSANDR FOMIN	{"phone": "+70233307443"}
0005432658598	260B25	4171 161480	PRASKOVYA DANILOVA	{"email": "danilova_p1977@postgrespro.ru", "phone": "+70013098306"}
0005432658599	613968	9803 718501	SERGEY CHERNOV	{"email": "chernov-sergey121974@postgrespro.ru", "phone": "+70991584133"}
0005432658600	6AC90C	7409 690818	ARINA ZAYCEVA	{"email": "zaycevaa08071969@postgrespro.ru", "phone": "+70774908251"}
0005432658601	6AC90C	3304 902172	IGOR FEDOROV	{"phone": "+70842964911"}
0005432658602	601552	2705 231179	NATALYA KUZMINA	{"phone": "+70766488257"}
0005432658603	A45422	6701 211176	MARIYA BORISOVA	{"phone": "+70298556902"}
0005432658604	A45422	6639 249619	RAISA KISELEVA	{"email": "r.kiseleva031973@postgrespro.ru", "phone": "+70910356580"}
0005432658605	A45422	6525 158353	SVETLANA ARKHIPOVA	{"email": "arkhipova-svetlana-101961@postgrespro.ru", "phone": "+70469209433"}
0005432658606	8359EB	6780 505398	SERGEY YAKOVLEV	{"email": "yakovlev_s-1975@postgrespro.ru", "phone": "+70565081859"}
0005432658607	8359EB	1655 602804	VLADIMIR VOROBEV	{"phone": "+70952230295"}
0005432658608	8359EB	8224 080213	NATALYA MATVEEVA	{"email": "n.matveeva-021968@postgrespro.ru", "phone": "+70542823586"}
0005432658609	F7C3DA	2337 455303	MAKSIM KUZMIN	{"phone": "+70566623458"}
0005432658610	FF5E2D	1194 239363	NIKOLAY NAUMOV	{"email": "naumovnikolay.1980@postgrespro.ru", "phone": "+70020239998"}
0005432658611	FF5E2D	5794 558216	SERGEY DENISOV	{"phone": "+70661386552"}
0005432658612	D866DC	9856 226917	ANNA ZAYCEVA	{"phone": "+70579884123"}
0005432658613	2B82CE	8009 151264	EKATERINA DENISOVA	{"email": "e-denisova08081977@postgrespro.ru", "phone": "+70285978113"}
0005432658614	B3C886	1071 598888	OLEG MIKHAYLOV	{"email": "o-mikhaylov_071976@postgrespro.ru", "phone": "+70014936234"}
0005432658615	81C1C8	4861 304485	ARTEM FILIPPOV	{"phone": "+70460388745"}
0005432658617	DF2680	9357 163597	NATALYA MOISEEVA	{"email": "moiseeva.natalya.26081978@postgrespro.ru", "phone": "+70580676813"}
0005432658618	FCED34	9772 565115	EKATERINA KUZNECOVA	{"email": "kuznecovaekaterina121970@postgrespro.ru", "phone": "+70476489348"}
0005432658619	FCED34	5735 234061	ELENA TARASOVA	{"email": "tarasova_e_091975@postgrespro.ru", "phone": "+70295076444"}
0005432658620	034354	0265 343927	VALENTINA KONOVALOVA	{"phone": "+70362308789"}
0005432658621	034354	9630 837974	ALEKSEY AFANASEV	{"phone": "+70746069645"}
0005432658622	27D13E	9245 235310	VENERA KISELEVA	{"email": "venera_kiseleva-25101966@postgrespro.ru", "phone": "+70702395333"}
0005432658623	190F17	9669 404561	ANATOLIY KOZLOV	{"phone": "+70635615177"}
0005432658624	560362	1262 420115	PETR IVANOV	{"phone": "+70386243718"}
0005432658625	560362	2196 011037	IVAN MIRONOV	{"phone": "+70010905081"}
0005432658626	50E7FA	3405 352914	NIKOLAY KOZLOV	{"email": "kozlov_nikolay06101982@postgrespro.ru", "phone": "+70383030301"}
0005432658627	50E7FA	3717 898394	TATYANA SOLOVEVA	{"email": "solovevat.19021975@postgrespro.ru", "phone": "+70994724072"}
0005432658628	390A0A	7540 428647	VALENTINA ILINA	{"phone": "+70081360293"}
0005432658629	08FF10	2787 060003	LIDIYA FILIPPOVA	{"phone": "+70731707807"}
0005432658630	E0049D	8666 496684	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov051974@postgrespro.ru", "phone": "+70516294058"}
0005432658631	C29F04	6353 053299	ANDREY FEDOROV	{"email": "fedorovandrey_021970@postgrespro.ru", "phone": "+70010349195"}
0005432658632	522C01	4149 717216	PAVEL KOZLOV	{"phone": "+70858050770"}
0005432658633	CAA48B	7601 425198	OLEG FOMIN	{"phone": "+70808700577"}
0005432658634	6FC8A9	5213 578892	PETR MEDVEDEV	{"phone": "+70736782013"}
0005432658635	0A5802	0468 751056	ILYA ILIN	{"email": "ilin.ilya.26081985@postgrespro.ru", "phone": "+70446136447"}
0005432658636	0A5802	4634 738430	ALEKSANDR OSIPOV	{"email": "osipov.aleksandr011978@postgrespro.ru", "phone": "+70797231936"}
0005432658637	8CCD46	3619 903629	EVGENIY NIKOLAEV	{"email": "evgeniy.nikolaev_111960@postgrespro.ru", "phone": "+70859978839"}
0005432658638	6384DB	9239 649873	FANIYA NESTEROVA	{"phone": "+70774779594"}
0005432658639	6384DB	6554 527200	NADEZHDA ZOTOVA	{"email": "zotovanadezhda.17091978@postgrespro.ru", "phone": "+70779680732"}
0005432658640	AA2CBF	7202 996885	SERGEY ILIN	{"email": "s-ilin.21011971@postgrespro.ru", "phone": "+70944357906"}
0005432658641	06F672	6317 387087	DENIS BORISOV	{"phone": "+70730294944"}
0005432658642	9972A9	2908 130683	EVGENIYA MAKSIMOVA	{"phone": "+70313751336"}
0005432658643	9972A9	8445 013682	OLEG KARPOV	{"phone": "+70082476305"}
0005432658644	12D399	3150 595306	ELENA VLASOVA	{"phone": "+70966230245"}
0005432658645	271930	4058 833707	DMITRIY KOZLOV	{"email": "dkozlov_061969@postgrespro.ru", "phone": "+70758112336"}
0005432658646	EA4DD1	3362 531628	MARIYA KISELEVA	{"email": "kiseleva.mariya.031972@postgrespro.ru", "phone": "+70908657901"}
0005432658647	811C81	5897 089701	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.1968@postgrespro.ru", "phone": "+70642757600"}
0005432658648	801400	7035 793586	YURIY ISAEV	{"email": "isaev.y05041977@postgrespro.ru", "phone": "+70618004889"}
0005432658649	F4AAB1	0689 559665	NATALYA KOZLOVA	{"phone": "+70964111875"}
0005432658650	04460F	5649 035982	OLESYA GERASIMOVA	{"email": "gerasimova-olesya.061977@postgrespro.ru", "phone": "+70282030748"}
0005432658651	F8E701	4467 718357	ELENA NAZAROVA	{"email": "elena.nazarova_1975@postgrespro.ru", "phone": "+70508508086"}
0005432658652	4AAF34	7158 169769	IRINA YAKOVLEVA	{"email": "i-yakovleva.061973@postgrespro.ru", "phone": "+70609418939"}
0005432658653	6AC2EB	8168 003192	LYUBOV IVANOVA	{"phone": "+70558620044"}
0005432658654	C3C658	9532 819797	NINA SIDOROVA	{"email": "sidorova_nina_121985@postgrespro.ru", "phone": "+70519958897"}
0005432658655	C3C658	4668 881182	ILYA ANTONOV	{"email": "antonov-ilya.121984@postgrespro.ru", "phone": "+70842642394"}
0005432659671	DA0F43	1391 470278	ANASTASIYA EGOROVA	{"phone": "+70447462361"}
0005432659672	F46039	2820 921461	VLADIMIR IVANOV	{"phone": "+70083411639"}
0005432659673	8A5B62	5070 344109	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova1966@postgrespro.ru", "phone": "+70147552026"}
0005432659674	A330DA	4196 378432	DIANA KUZNECOVA	{"phone": "+70572946981"}
0005432659675	CF4A9D	6770 433836	SVETLANA VOROBEVA	{"email": "vorobevasvetlana_081980@postgrespro.ru", "phone": "+70412343891"}
0005432659676	CF4A9D	3833 364090	NIKOLAY POPOV	{"email": "n-popov.29021980@postgrespro.ru", "phone": "+70245981959"}
0005432659677	158D2B	1006 842197	ANATOLIY MAKAROV	{"phone": "+70168208201"}
0005432659678	158D2B	4924 631862	BORIS FROLOV	{"email": "b.frolov_29031961@postgrespro.ru", "phone": "+70756515063"}
0005432659679	99C861	0394 285466	LYUDMILA VASILEVA	{"phone": "+70505757386"}
0005432659680	1FCBB9	8319 400350	ROZA FROLOVA	{"email": "frolova-r.1986@postgrespro.ru", "phone": "+70778886687"}
0005432659681	1FCBB9	8425 042676	ANASTASIYA MEDVEDEVA	{"phone": "+70175817255"}
0005432659682	097379	9939 114308	ANASTASIYA IVANOVA	{"email": "a-ivanova1965@postgrespro.ru", "phone": "+70821975643"}
0005432659683	097379	5307 527358	EVDOKIYA EGOROVA	{"email": "e_egorova-1974@postgrespro.ru", "phone": "+70462208045"}
0005432659684	077495	6710 807426	NIKOLAY MELNIKOV	{"email": "melnikov.nikolay111972@postgrespro.ru", "phone": "+70814782243"}
0005432659685	31AB14	1369 488769	TATYANA POPOVA	{"email": "tatyana.popova.12091962@postgrespro.ru", "phone": "+70954165207"}
0005432659686	575C79	8350 969833	VIKTOR FEDOTOV	{"phone": "+70371820676"}
0005432659687	575C79	1695 936964	NINA DANILOVA	{"phone": "+70025800918"}
0005432659688	575C79	7860 292435	ANNA EGOROVA	{"phone": "+70331747788"}
0005432659689	0106C5	0231 640122	ALEKSANDR VASILEV	{"phone": "+70803047133"}
0005432659690	B11835	0402 113915	VYACHESLAV BELOV	{"email": "belov.v.1961@postgrespro.ru", "phone": "+70943189848"}
0005432659691	B11835	5584 745370	TATYANA KARPOVA	{"email": "karpova.tatyana-1977@postgrespro.ru", "phone": "+70969738293"}
0005432659692	4D2BDC	1682 697422	VIKTORIYA ZAKHAROVA	{"phone": "+70651498348"}
0005432659693	4D2BDC	8170 598373	VLADIMIR PETROV	{"email": "petrov.v1973@postgrespro.ru", "phone": "+70199135011"}
0005432659694	3B7F4E	6259 826563	ULYANA GORBUNOVA	{"email": "ulyana-gorbunova031973@postgrespro.ru", "phone": "+70972497510"}
0005432659695	FB6738	7953 945553	VALENTINA LAZAREVA	{"email": "lazareva_v.1980@postgrespro.ru", "phone": "+70085781139"}
0005432659696	FB6738	8379 498977	IRINA SOROKINA	{"phone": "+70876344636"}
0005432659697	69AF1D	3176 047935	LYUBOV GAVRILOVA	{"phone": "+70872293742"}
0005432659698	741771	8584 419726	IGOR ALEKSANDROV	{"email": "aleksandrov-i-11011962@postgrespro.ru", "phone": "+70196716773"}
0005432659699	B181BE	4700 859269	VYACHESLAV SAVELEV	{"email": "savelevvyacheslav_081968@postgrespro.ru", "phone": "+70400514435"}
0005432659700	B734BE	5985 855049	ROMAN KUZNECOV	{"email": "kuznecov-r_1961@postgrespro.ru", "phone": "+70993813196"}
0005432659701	5F461F	9648 051457	ALEKSANDR RODIONOV	{"email": "aleksandr-rodionov1965@postgrespro.ru", "phone": "+70654109506"}
0005432659702	0C00BB	2492 673555	OLGA GUSEVA	{"phone": "+70874397667"}
0005432659703	5D2416	5872 099467	ANNA MAKAROVA	{"email": "amakarova021965@postgrespro.ru", "phone": "+70502700175"}
0005432659704	5D2416	2352 276457	OLESYA ZAKHAROVA	{"phone": "+70780292601"}
0005432659705	8D1B85	9478 900988	ELENA EGOROVA	{"phone": "+70693539599"}
0005432659706	8D1B85	7705 052534	MAKSIM ZHUKOV	{"email": "m-zhukov25071973@postgrespro.ru", "phone": "+70259811279"}
0005432659707	E00425	7080 568965	SERGEY ZAKHAROV	{"email": "zakharov.sergey091972@postgrespro.ru", "phone": "+70741232736"}
0005432659708	22ABF1	9229 227660	ELENA VASILEVA	{"phone": "+70426534732"}
0005432659709	E95F68	8963 774296	VLADIMIR BARANOV	{"email": "baranov_vladimir-081970@postgrespro.ru", "phone": "+70943771914"}
0005432659710	7ECBB2	2122 163348	ANDREY ILIN	{"phone": "+70290217490"}
0005432659711	40F6D4	3247 902927	NIKOLAY ALEKSEEV	{"email": "alekseevn_1964@postgrespro.ru", "phone": "+70813913930"}
0005432659712	40F6D4	2868 883098	KIRILL ANDREEV	{"phone": "+70206221040"}
0005432659713	2C4068	4256 347171	OLGA FOMINA	{"phone": "+70666940455"}
0005432659714	2C4068	8689 178760	VYACHESLAV KARPOV	{"email": "karpovvyacheslav.011978@postgrespro.ru", "phone": "+70069973234"}
0005432659715	F18280	6121 944397	MAKSIM DENISOV	{"email": "denisov-m.03011988@postgrespro.ru", "phone": "+70729715887"}
0005432659716	5E760E	8127 463463	ILYA FROLOV	{"email": "ilyafrolov_1981@postgrespro.ru", "phone": "+70640654068"}
0005432659717	F2A293	6962 000077	INNA SMIRNOVA	{"email": "inna-smirnova-1978@postgrespro.ru", "phone": "+70206976983"}
0005432659718	F2A293	6578 340965	RAIS MIKHAYLOV	{"email": "r-mikhaylov10041965@postgrespro.ru", "phone": "+70526580891"}
0005432659719	94D2FF	9403 892281	EVA SOLOVEVA	{"phone": "+70192278118"}
0005432659720	43939B	8666 944503	DMITRIY MELNIKOV	{"email": "melnikovdmitriy041970@postgrespro.ru", "phone": "+70059901681"}
0005432659721	43939B	1928 602486	ALEKSEY TIMOFEEV	{"email": "timofeev_aleksey10061981@postgrespro.ru", "phone": "+70155124605"}
0005432659722	5A79B9	5715 229502	ALEKSEY ROMANOV	{"email": "alekseyromanov1982@postgrespro.ru", "phone": "+70367680518"}
0005432659723	5A79B9	2580 562165	VALENTINA SMIRNOVA	{"email": "smirnova-v1971@postgrespro.ru", "phone": "+70368965326"}
0005432659724	5A79B9	0478 491831	ELENA MEDVEDEVA	{"phone": "+70922433412"}
0005432659725	3CCB9C	3482 300692	TATYANA GAVRILOVA	{"email": "tatyana.gavrilova.081973@postgrespro.ru", "phone": "+70969446168"}
0005432659726	ED751E	2782 942297	YULIYA KUZMINA	{"email": "y-kuzmina051961@postgrespro.ru", "phone": "+70603641113"}
0005432659727	3ACB45	2564 089695	LILIYA MATVEEVA	{"phone": "+70740892604"}
0005432659728	90FC1C	6855 522101	ANNA BELOVA	{"phone": "+70295968366"}
0005432659729	5FBD62	9303 069317	IRINA MALYSHEVA	{"phone": "+70582380190"}
0005432659730	5FBD62	2415 778182	SVETLANA TIMOFEEVA	{"email": "timofeeva.s-27041976@postgrespro.ru", "phone": "+70524516887"}
0005432659731	1006F5	6313 142178	ALEKSANDR SOROKIN	{"email": "aleksandrsorokin06111977@postgrespro.ru", "phone": "+70803477800"}
0005432659732	1006F5	6195 617588	ALEKSANDR VASILEV	{"phone": "+70072168950"}
0005432659733	50312D	5488 029674	ANDREY NIKITIN	{"email": "a-nikitin.091970@postgrespro.ru", "phone": "+70524055402"}
0005432659734	50312D	6195 528436	SERGEY MAKSIMOV	{"email": "sergey.maksimov_06031985@postgrespro.ru", "phone": "+70906925209"}
0005432659735	4BE759	3957 716535	VASILIY IVANOV	{"email": "v_ivanov071979@postgrespro.ru", "phone": "+70167969370"}
0005432659736	23E8E8	5985 647505	SERGEY POPOV	{"phone": "+70027413751"}
0005432659737	8F4BE1	6063 661430	PETR FOMIN	{"email": "fomin_p22041964@postgrespro.ru", "phone": "+70098842884"}
0005432659738	6F6F8F	5955 424458	ALEKSANDRA MELNIKOVA	{"email": "aleksandra.melnikova05121975@postgrespro.ru", "phone": "+70691164419"}
0005432659739	6F6F8F	4020 003695	OLGA YAKOVLEVA	{"email": "o_yakovleva081985@postgrespro.ru", "phone": "+70399362168"}
0005432659740	6F6F8F	6799 346525	ALINA MELNIKOVA	{"email": "alinamelnikova25111962@postgrespro.ru", "phone": "+70758276694"}
0005432659741	301898	0699 234638	EMILIYA KUDRYASHOVA	{"email": "emiliya-kudryashova_1965@postgrespro.ru", "phone": "+70834100782"}
0005432659742	11F079	0255 846105	VLADIMIR SAVELEV	{"email": "savelevv_16051975@postgrespro.ru", "phone": "+70165498633"}
0005432659743	A84837	2094 306711	RAVILYA SEMENOVA	{"email": "r.semenova.24041967@postgrespro.ru", "phone": "+70238403586"}
0005432659744	A84837	5929 358577	NATALYA LOGINOVA	{"email": "loginova_natalya.1981@postgrespro.ru", "phone": "+70339459665"}
0005432659745	C49C6D	7748 413784	EVGENIYA KUZNECOVA	{"phone": "+70204208740"}
0005432659746	3A4E9A	9185 905618	ALEKSEY SMIRNOV	{"phone": "+70778959019"}
0005432659747	54AF25	2334 685675	EVGENIY MIKHAYLOV	{"email": "evgeniymikhaylov.1968@postgrespro.ru", "phone": "+70410440405"}
0005432659748	E4FA59	9119 800994	ELENA VASILEVA	{"email": "e-vasileva.041968@postgrespro.ru", "phone": "+70097636786"}
0005432659749	0B6464	0652 546434	NIKOLAY MARTYNOV	{"email": "martynov_n-081979@postgrespro.ru", "phone": "+70310894629"}
0005432659750	0B6464	3644 903291	OLGA SOKOLOVA	{"email": "olgasokolova101974@postgrespro.ru", "phone": "+70999631481"}
0005432659751	41915A	0448 547592	ANNA KUZNECOVA	{"email": "kuznecova-anna-12011969@postgrespro.ru", "phone": "+70488412098"}
0005432659752	41915A	6813 090876	LYUDMILA KUZMINA	{"email": "kuzmina.l22071959@postgrespro.ru", "phone": "+70725487570"}
0005432659753	98E22A	9630 443399	ANASTASIYA FILATOVA	{"phone": "+70398794935"}
0005432659754	EC8FD0	4794 882125	ALINA NOVIKOVA	{"email": "a_novikova.27051969@postgrespro.ru", "phone": "+70755777665"}
0005432659755	23A09F	6991 243881	FEDOR RODIONOV	{"email": "f.rodionov_1969@postgrespro.ru", "phone": "+70800137904"}
0005432659756	23A09F	8492 453817	FAINA ISAEVA	{"email": "isaevaf111977@postgrespro.ru", "phone": "+70977919924"}
0005432659757	6573B5	6640 306886	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr-1970@postgrespro.ru", "phone": "+70896596968"}
0005432659758	5FB631	1696 816476	IRINA KUZMINA	{"phone": "+70145204794"}
0005432659759	775DC5	7004 859979	LYUBOV EFIMOVA	{"email": "efimova.lyubov_1975@postgrespro.ru", "phone": "+70972065046"}
0005432659760	0E1492	6432 940484	TATYANA IVANOVA	{"phone": "+70223254166"}
0005432659761	136A83	2827 464496	IRINA POPOVA	{"phone": "+70388420688"}
0005432659762	421CB2	0701 498571	NIKOLAY GORBUNOV	{"phone": "+70434830390"}
0005432659763	421CB2	4591 978063	GALINA KUDRYASHOVA	{"email": "g.kudryashova.021968@postgrespro.ru", "phone": "+70338690813"}
0005432659764	C36FB9	5881 762372	VITALIY MEDVEDEV	{"email": "vitaliymedvedev-30101972@postgrespro.ru", "phone": "+70275096211"}
0005432659765	AC0BEF	7652 370364	DARYA ZAKHAROVA	{"email": "zakharova_d-20031969@postgrespro.ru", "phone": "+70220641029"}
0005432659766	FBE9E0	6331 943580	MIKHAIL MAKAROV	{"email": "mikhail.makarov111969@postgrespro.ru", "phone": "+70360462031"}
0005432659767	FBE9E0	9512 372506	MARIYA ZAYCEVA	{"phone": "+70383611371"}
0005432659768	B88A9B	7672 392929	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev22101980@postgrespro.ru", "phone": "+70532710720"}
0005432659769	7DDC47	9113 779535	TAMARA MELNIKOVA	{"phone": "+70450440871"}
0005432659770	7DDC47	7479 247375	NADEZHDA DENISOVA	{"email": "n.denisova_18041972@postgrespro.ru", "phone": "+70335756008"}
0005432660784	335553	8755 180056	DARYA ANISIMOVA	{"email": "d_anisimova_30111970@postgrespro.ru", "phone": "+70876686281"}
0005432660785	335553	0317 364408	ANZHELIKA ALEKSANDROVA	{"email": "a.aleksandrova.011979@postgrespro.ru", "phone": "+70508536527"}
0005432660786	E7A51B	9361 221477	MARIYA ZHUKOVA	{"phone": "+70344721177"}
0005432660787	E7A51B	5076 319256	IGOR ISAEV	{"email": "i.isaev-14061974@postgrespro.ru", "phone": "+70248385402"}
0005432660788	5D0949	7299 574711	OLGA KUZMINA	{"email": "o_kuzmina_1979@postgrespro.ru", "phone": "+70330090719"}
0005432660789	5D0949	0964 708574	OLGA KOROLEVA	{"email": "olga_koroleva-27081978@postgrespro.ru", "phone": "+70906890968"}
0005432660790	503092	0976 190438	ELENA TITOVA	{"phone": "+70257976265"}
0005432660791	9586F9	5483 965743	SNEZHANA NIKITINA	{"email": "snezhana.nikitina-1965@postgrespro.ru", "phone": "+70601611411"}
0005432660792	9586F9	5319 827001	ALEKSANDRA KRASNOVA	{"phone": "+70630598834"}
0005432660793	409A9B	7298 037373	NADEZHDA NESTEROVA	{"phone": "+70075863915"}
0005432660794	4D0BD9	7363 140701	DIANA KUZMINA	{"email": "d.kuzmina30111972@postgrespro.ru", "phone": "+70021638031"}
0005432660795	F0543F	9864 775894	SERGEY SOKOLOV	{"email": "sokolovs1975@postgrespro.ru", "phone": "+70312696352"}
0005432660796	11AF84	1096 441320	MAKSIM KUZNECOV	{"email": "maksim.kuznecov.1973@postgrespro.ru", "phone": "+70703836216"}
0005432660797	000FAC	4815 783106	EVGENIYA LEBEDEVA	{"email": "evgeniyalebedeva.1968@postgrespro.ru", "phone": "+70794982415"}
0005432660798	AB5E3F	1394 769375	ALEKSANDR NIKOLAEV	{"phone": "+70656959507"}
0005432660799	C8DFD9	2393 231699	ALEKSEY POPOV	{"phone": "+70929104896"}
0005432660800	C8DFD9	7624 990470	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr_09101979@postgrespro.ru", "phone": "+70861093643"}
0005432660801	C8DFD9	1822 555756	SERGEY NIKOLAEV	{"phone": "+70825185960"}
0005432660802	62BEDC	7038 549236	VITALIY SEMENOV	{"phone": "+70738288034"}
0005432660803	39EBC4	2480 673110	VALERIY KUZNECOV	{"email": "kuznecov.valeriy_1970@postgrespro.ru", "phone": "+70683398192"}
0005432660804	5E7955	0275 340119	VIKTORIYA KOZLOVA	{"phone": "+70569213072"}
0005432660805	5E7955	2374 443041	LYUDMILA PAVLOVA	{"email": "pavloval091976@postgrespro.ru", "phone": "+70522420967"}
0005432660806	7F4EE4	6267 329476	KIRILL IVANOV	{"email": "kirill.ivanov_1966@postgrespro.ru", "phone": "+70078697000"}
0005432660807	E1FBC9	1003 377306	OLGA PAVLOVA	{"email": "olga_pavlova.111975@postgrespro.ru", "phone": "+70133903558"}
0005432660808	E28C25	7686 672105	BORIS DENISOV	{"email": "b-denisov101965@postgrespro.ru", "phone": "+70597271567"}
0005432660809	977F84	7059 430928	VALENTINA ABRAMOVA	{"email": "valentina-abramova.011977@postgrespro.ru", "phone": "+70598579278"}
0005432660810	977F84	2045 970782	SERGEY CHERNOV	{"email": "chernov_s.06061967@postgrespro.ru", "phone": "+70204099786"}
0005432660811	A899F4	4620 767443	VYACHESLAV NIKITIN	{"phone": "+70068986087"}
0005432660812	2B8F0A	0524 451724	OLGA NIKITINA	{"email": "o_nikitina-1981@postgrespro.ru", "phone": "+70689592684"}
0005432660813	311DC4	8797 539741	EVA KALININA	{"phone": "+70801216500"}
0005432660814	311DC4	7966 935826	TATYANA KISELEVA	{"email": "t.kiseleva1963@postgrespro.ru", "phone": "+70652933115"}
0005432660815	521F91	8749 617533	GRIGORIY EGOROV	{"phone": "+70353513709"}
0005432660816	521F91	5653 244832	VLADIMIR IVANOV	{"email": "ivanov.v-21031978@postgrespro.ru", "phone": "+70922718320"}
0005432660817	8B80BC	7510 570524	EVGENIY SMIRNOV	{"email": "smirnov-evgeniy_1973@postgrespro.ru", "phone": "+70782625602"}
0005432660818	8B80BC	1506 631173	GALINA PETROVA	{"phone": "+70411887862"}
0005432660819	0F7DC6	5657 128925	MARIYA KOZLOVA	{"email": "kozlovam_15101973@postgrespro.ru", "phone": "+70862560180"}
0005432660820	3D440D	6297 121687	ALEKSANDRA DAVYDOVA	{"phone": "+70494526879"}
0005432660821	13B128	6567 269518	LYUDMILA MALYSHEVA	{"email": "lmalysheva_04011973@postgrespro.ru", "phone": "+70488878685"}
0005432660822	13B128	1935 565584	DMITRIY FEDOROV	{"phone": "+70482511589"}
0005432660823	B67055	4416 972451	VYACHESLAV MATVEEV	{"email": "vyacheslav_matveev.011992@postgrespro.ru", "phone": "+70549783346"}
0005432660824	284CDE	0311 087511	RINAT KUDRYASHOV	{"email": "kudryashov.r.121962@postgrespro.ru", "phone": "+70536869568"}
0005432660825	AC72EE	7981 817180	ZULFIYA NIKOLAEVA	{"phone": "+70375748922"}
0005432660826	0A88BB	5815 295817	VALENTINA ANTONOVA	{"email": "vantonova10091973@postgrespro.ru", "phone": "+70739248529"}
0005432660827	CC5F43	6285 833129	ANNA POTAPOVA	{"phone": "+70635795533"}
0005432660828	1C05C8	3557 738787	OKSANA ERMAKOVA	{"phone": "+70735770088"}
0005432660829	C8D448	5977 904035	NADEZHDA ANDREEVA	{"email": "andreeva-nadezhda.26111986@postgrespro.ru", "phone": "+70230200829"}
0005432660830	042291	6862 763410	NIKOLAY CHERNOV	{"phone": "+70570888690"}
0005432660831	9E1C49	7073 492376	YAROSLAV VOROBEV	{"email": "vorobev_yaroslav.021957@postgrespro.ru", "phone": "+70239229863"}
0005432660832	5ABE12	2416 855009	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov031975@postgrespro.ru", "phone": "+70889271330"}
0005432660833	E31CE1	1085 635517	ALEKSANDR FOMIN	{"phone": "+70921443910"}
0005432660834	E31CE1	7712 497113	OLGA NESTEROVA	{"email": "o.nesterova-09031980@postgrespro.ru", "phone": "+70998622491"}
0005432660835	06150B	8524 561666	ALEKSANDR ANDREEV	{"phone": "+70869205943"}
0005432660836	06150B	4625 418969	MARIYA ALEKSEEVA	{"phone": "+70239700153"}
0005432660837	FA54C1	1686 088936	ZOYA MELNIKOVA	{"email": "zoya_melnikova1966@postgrespro.ru", "phone": "+70848069088"}
0005432660838	FA54C1	2698 808146	VALENTINA FILATOVA	{"phone": "+70687227715"}
0005432660839	8E8C55	6531 726095	LYUBOV DMITRIEVA	{"email": "dmitrieva_lyubov_031976@postgrespro.ru", "phone": "+70266717407"}
0005432660840	C21E6D	1962 249564	IRINA POTAPOVA	{"email": "i_potapova-1964@postgrespro.ru", "phone": "+70055962705"}
0005432660841	C21E6D	4925 900528	ALEKSEY ZAKHAROV	{"phone": "+70249642401"}
0005432660842	1D2F30	3708 352813	OLGA MIRONOVA	{"phone": "+70925074661"}
0005432660843	1D2F30	5913 193700	NIKOLAY BORISOV	{"email": "nikolay-borisov1977@postgrespro.ru", "phone": "+70129974805"}
0005432660844	AF190F	3764 214374	YULIYA ZHUKOVA	{"phone": "+70946402958"}
0005432660845	AF190F	9041 942107	ARTEM SOKOLOV	{"phone": "+70177216426"}
0005432660846	D7BFE4	8521 044421	ALENA SCHERBAKOVA	{"email": "alena-scherbakova.07111973@postgrespro.ru", "phone": "+70984862769"}
0005432660847	0DA745	7132 422690	DMITRIY SERGEEV	{"email": "sergeev_dmitriy041976@postgrespro.ru", "phone": "+70424761190"}
0005432660848	0DA745	3158 707873	VITALIY ZAKHAROV	{"email": "zakharov_vitaliy.061970@postgrespro.ru", "phone": "+70852182871"}
0005432660849	918F46	8711 352139	ELENA MEDVEDEVA	{"phone": "+70911118146"}
0005432660850	FEC268	6420 044474	ELISEY YAKOVLEV	{"email": "yakovlevelisey_101972@postgrespro.ru", "phone": "+70728608533"}
0005432660851	4C7145	8640 884072	VYACHESLAV NAUMOV	{"email": "vyacheslav.naumov_111969@postgrespro.ru", "phone": "+70684964056"}
0005432660852	E3E30A	2855 406026	GALINA GORBUNOVA	{"phone": "+70763636152"}
0005432660853	3C21E2	9851 181822	TAMARA KULIKOVA	{"email": "kulikova.tamara_16021975@postgrespro.ru", "phone": "+70219647414"}
0005432660854	C0D2DB	0502 857491	SVETLANA KAZAKOVA	{"phone": "+70430408904"}
0005432660855	C0D2DB	2755 925713	OLGA IVANOVA	{"email": "oivanova-061968@postgrespro.ru", "phone": "+70521929782"}
0005432660856	02D1D0	1241 776430	GENNADIY NAZAROV	{"phone": "+70767623075"}
0005432660857	3D0DA2	2097 519634	ANDREY SCHERBAKOV	{"phone": "+70300035377"}
0005432660858	25FA0D	8779 023730	EKATERINA IVANOVA	{"phone": "+70437228803"}
0005432660859	F4A881	4592 080455	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy.1977@postgrespro.ru", "phone": "+70953090275"}
0005432660860	CA1A92	2608 262972	IRAIDA VOLKOVA	{"phone": "+70290570508"}
0005432660861	CA1A92	4695 692492	GENNADIY KUZNECOV	{"phone": "+70997287639"}
0005432660862	067AF5	5002 594928	SERGEY KARPOV	{"email": "karpovsergey1972@postgrespro.ru", "phone": "+70381587736"}
0005432660863	067AF5	1896 901856	VADIM MOISEEV	{"email": "v_moiseev_1969@postgrespro.ru", "phone": "+70391141813"}
0005432660864	293126	3843 315825	VIKTOR AFANASEV	{"email": "afanasev.v.1971@postgrespro.ru", "phone": "+70818962503"}
0005432660865	293126	1104 065027	DANIL IVANOV	{"phone": "+70874403181"}
0005432660866	23ECF7	1228 571191	EKATERINA ANDREEVA	{"email": "andreeva_e.011980@postgrespro.ru", "phone": "+70822476439"}
0005432660867	768B3B	4991 121163	NADEZHDA FEDOROVA	{"email": "n.fedorova-1986@postgrespro.ru", "phone": "+70295909246"}
0005432660868	D15B8A	7976 124089	IRINA SIDOROVA	{"phone": "+70004920164"}
0005432660869	D15B8A	8426 406330	VIKTORIYA MOISEEVA	{"email": "vmoiseeva.031981@postgrespro.ru", "phone": "+70153568875"}
0005432660870	D3B9C5	1241 120113	RUSLAN ALEKSANDROV	{"phone": "+70885368320"}
0005432660871	187CF4	7179 204546	YURIY GAVRILOV	{"phone": "+70750279896"}
0005432660872	187CF4	4643 790795	VLADIMIR SEMENOV	{"email": "semenovvladimir18071965@postgrespro.ru", "phone": "+70392419605"}
0005432660873	187CF4	2266 365528	ELENA ZOTOVA	{"phone": "+70675624033"}
0005432660874	55A050	6818 896958	EVGENIYA AFANASEVA	{"phone": "+70301133094"}
0005432660875	214867	9097 026107	ELENA FADEEVA	{"email": "fadeeva_elena-1968@postgrespro.ru", "phone": "+70331961619"}
0005432660876	214867	4824 337328	GALINA KOROLEVA	{"email": "koroleva_galina-091967@postgrespro.ru", "phone": "+70270902628"}
0005432660877	E86BEA	0401 825528	ANATOLIY VASILEV	{"email": "avasilev.101979@postgrespro.ru", "phone": "+70917323460"}
0005432660878	B63909	7275 837860	YURIY FROLOV	{"email": "yuriy_frolov.1977@postgrespro.ru", "phone": "+70357432548"}
0005432660879	B63909	8260 559178	ELENA TROFIMOVA	{"phone": "+70809522813"}
0005432660880	B63909	8032 577652	VIKTOR FILIPPOV	{"phone": "+70944883035"}
0005432660881	13B614	7146 460342	DMITRIY KULIKOV	{"email": "dmitriy-kulikov_10081981@postgrespro.ru", "phone": "+70323461124"}
0005432660882	13B614	9252 607643	ANNA NIKOLAEVA	{"email": "nikolaeva.anna05021972@postgrespro.ru", "phone": "+70680112338"}
0005432661898	BE7ABE	4045 456699	GEORGIY KUZNECOV	{"phone": "+70426527924"}
0005432661899	BE7ABE	8487 892666	TATYANA STEPANOVA	{"email": "stepanova_t_02081980@postgrespro.ru", "phone": "+70429608580"}
0005432661900	741748	1503 178904	SERGEY KARPOV	{"email": "sergey_karpov_091969@postgrespro.ru", "phone": "+70257065201"}
0005432661901	380559	1781 383944	VLADIMIR AFANASEV	{"email": "vladimir-afanasev1977@postgrespro.ru", "phone": "+70531632010"}
0005432661902	E21958	1712 467810	ANDREY MIRONOV	{"phone": "+70886996369"}
0005432661903	E21958	4817 870136	VIKTOR KUZNECOV	{"email": "viktor.kuznecov_13071974@postgrespro.ru", "phone": "+70707221372"}
0005432661904	F73898	7211 757249	ALIYA NAUMOVA	{"email": "naumova.a.1984@postgrespro.ru", "phone": "+70387491455"}
0005432661905	310C99	2513 291842	VADIM TARASOV	{"phone": "+70396060430"}
0005432661906	310C99	5211 278956	KLAVDIYA ZHURAVLEVA	{"email": "zhuravleva-klavdiya.051979@postgrespro.ru", "phone": "+70107216457"}
0005432661907	464278	1920 187846	DARYA YAKOVLEVA	{"email": "dyakovleva_1981@postgrespro.ru", "phone": "+70514270425"}
0005432661908	035E5C	8497 629451	ALEKSEY ZHURAVLEV	{"phone": "+70108162928"}
0005432661909	1DF6E7	5045 542571	VADIM KUZMIN	{"phone": "+70182775806"}
0005432661910	A771FA	8282 662642	GENNADIY GAVRILOV	{"phone": "+70507875194"}
0005432661911	9B4E7F	8167 591901	ANDREY KUDRYASHOV	{"phone": "+70746794178"}
0005432661912	9D0435	6141 805480	NIKOLAY FILIPPOV	{"email": "filippov.nikolay_121969@postgrespro.ru", "phone": "+70308641203"}
0005432661913	95F162	5546 055708	EVGENIY KONOVALOV	{"email": "evgeniy-konovalov071980@postgrespro.ru", "phone": "+70442442812"}
0005432661914	521C53	8234 547529	IVAN IVANOV	{"email": "iivanov-071972@postgrespro.ru", "phone": "+70937136223"}
0005432661915	521C53	2034 201228	ANTONINA KUZNECOVA	{"email": "kuznecova-a-1982@postgrespro.ru", "phone": "+70646601109"}
0005432661916	6FA2DB	9810 962769	VALERIY DENISOV	{"phone": "+70441950993"}
0005432661917	6FA2DB	9169 496783	NINA BORISOVA	{"email": "borisova_nina-02011968@postgrespro.ru", "phone": "+70538369522"}
0005432661918	2F6833	2102 280249	LYUDMILA KUZMINA	{"email": "l_kuzmina101962@postgrespro.ru", "phone": "+70559816490"}
0005432661919	2F6833	5846 611785	STANISLAV NIKOLAEV	{"email": "nikolaev.s-121968@postgrespro.ru", "phone": "+70696343769"}
0005432661920	41C79C	6138 098502	ALEKSANDR FILIPPOV	{"email": "aleksandr_filippov111977@postgrespro.ru", "phone": "+70742085651"}
0005432661921	41C79C	3273 482835	VIKTOR VOLKOV	{"phone": "+70351041728"}
0005432661922	B88D87	6482 883247	ALEKSANDR MAKAROV	{"email": "makarovaleksandr-14041987@postgrespro.ru", "phone": "+70112863373"}
0005432661923	F8E456	1140 694434	ALEKSANDR MIKHAYLOV	{"phone": "+70977116511"}
0005432661924	479330	4357 822428	SERGEY KULIKOV	{"phone": "+70537252778"}
0005432661925	92103B	9459 884783	TATYANA SOKOLOVA	{"email": "sokolovat_081968@postgrespro.ru", "phone": "+70956744925"}
0005432661926	92103B	6120 949545	TAISIYA OVCHINNIKOVA	{"phone": "+70224023130"}
0005432661927	92103B	6297 779059	LYUDMILA NIKITINA	{"email": "lyudmilanikitina.08121965@postgrespro.ru", "phone": "+70101419877"}
0005432661928	17C44A	2330 805977	ALEKSEY KUZMIN	{"phone": "+70443929381"}
0005432661929	F30A75	3028 876598	ALEKSANDR IVANOV	{"phone": "+70713556285"}
0005432661930	F30A75	2038 662106	MARIYA IVANOVA	{"phone": "+70484577391"}
0005432661931	F30A75	6548 820363	OLEG KOZLOV	{"phone": "+70893605619"}
0005432661932	25E248	1124 235841	DENIS KARPOV	{"phone": "+70622320968"}
0005432661933	25E248	3287 863969	NAIL YAKOVLEV	{"email": "nail-yakovlev-09101981@postgrespro.ru", "phone": "+70501198907"}
0005432661934	2C2B15	6763 423061	IRINA GORBUNOVA	{"email": "i-gorbunova02101972@postgrespro.ru", "phone": "+70343186972"}
0005432661935	15658E	7561 282507	IVAN PETROV	{"phone": "+70637549640"}
0005432661936	5C2275	2676 250588	ANDREY MIKHAYLOV	{"email": "mikhaylova.051966@postgrespro.ru", "phone": "+70827376177"}
0005432661937	6C80A4	6350 735166	SERGEY GAVRILOV	{"phone": "+70218200809"}
0005432661938	256817	9130 153303	TAMARA SERGEEVA	{"email": "t.sergeeva16021967@postgrespro.ru", "phone": "+70374937073"}
0005432661939	256817	5976 727420	YULIYA MAKAROVA	{"email": "yuliya_makarova-1968@postgrespro.ru", "phone": "+70994390898"}
0005432661940	256817	7866 621767	MARINA ORLOVA	{"phone": "+70707072530"}
0005432661941	651182	2588 224136	DMITRIY POPOV	{"email": "popov_d10111963@postgrespro.ru", "phone": "+70065218288"}
0005432661942	9560D7	3496 377435	LYUDMILA KONDRATEVA	{"phone": "+70086192702"}
0005432661943	9560D7	6475 976458	ALEKSANDR NAUMOV	{"phone": "+70077565183"}
0005432661944	0C2E5D	1281 207160	INNA VOROBEVA	{"phone": "+70264381723"}
0005432661945	D8AE52	2799 118527	VLADIMIR BORISOV	{"phone": "+70768801616"}
0005432661946	72EE98	8494 077423	LYUDMILA BELYAEVA	{"phone": "+70426345529"}
0005432661947	EA759A	7691 357373	ALEKSEY FILIPPOV	{"phone": "+70229871348"}
0005432661948	EA759A	7539 229246	LYUDMILA VASILEVA	{"email": "vasileva-lyudmila_081971@postgrespro.ru", "phone": "+70943378197"}
0005432661949	E15469	1873 486944	LYUDMILA KUZNECOVA	{"email": "lyudmila.kuznecova.05011975@postgrespro.ru", "phone": "+70642481885"}
0005432661950	A59CEC	0158 779365	NADEZHDA NIKITINA	{"email": "nikitina.nadezhda031987@postgrespro.ru", "phone": "+70023902991"}
0005432661951	A59CEC	6509 215137	ELENA KULIKOVA	{"email": "kulikova_e.1978@postgrespro.ru", "phone": "+70025221694"}
0005432661952	193A12	7551 183598	NATALYA IVANOVA	{"email": "ivanova-n.081959@postgrespro.ru", "phone": "+70568238523"}
0005432661953	3717E9	1004 905105	GALINA MAKAROVA	{"email": "galinamakarova-021987@postgrespro.ru", "phone": "+70892825006"}
0005432661954	CDB6A5	1388 912608	MAKSIM KUZNECOV	{"phone": "+70611105790"}
0005432661955	CDB6A5	1729 169727	ALEKSANDRA DENISOVA	{"phone": "+70286454220"}
0005432661956	DCDC22	9588 506023	LYUBOV ANISIMOVA	{"email": "anisimova-lyubov-1978@postgrespro.ru", "phone": "+70078447152"}
0005432661957	BBD48E	5985 119417	KAPITALINA AFANASEVA	{"phone": "+70574351356"}
0005432661958	850DC3	1076 263517	VLADIMIR NIKOLAEV	{"phone": "+70152318826"}
0005432661959	850DC3	9020 941319	FILIPP ISAEV	{"phone": "+70704680386"}
0005432661960	4C67C2	7362 349851	ANNA GERASIMOVA	{"email": "gerasimova-anna-121961@postgrespro.ru", "phone": "+70750982207"}
0005432661961	2DFE23	9903 734600	VALERIY SEMENOV	{"phone": "+70913177755"}
0005432661962	6335AB	6691 101583	RINAT DAVYDOV	{"phone": "+70673130472"}
0005432661963	EFEF4F	9167 011693	NATALYA SERGEEVA	{"email": "sergeevan-10111977@postgrespro.ru", "phone": "+70501757214"}
0005432661964	EFEF4F	4098 297484	SERGEY ANDREEV	{"phone": "+70982524232"}
0005432661965	3DAF09	2112 760358	MAKSIM SCHERBAKOV	{"phone": "+70595671381"}
0005432661966	2CA761	0589 032760	VLADIMIR GUSEV	{"email": "gusev-v-021975@postgrespro.ru", "phone": "+70320692362"}
0005432661967	51B694	1678 415829	VLADIMIR SOLOVEV	{"phone": "+70522554864"}
0005432661968	51B694	0419 090119	NADEZHDA VOLKOVA	{"phone": "+70553116404"}
0005432661969	0776E8	9230 438561	YULIYA ILINA	{"email": "ilina-y051978@postgrespro.ru", "phone": "+70832091392"}
0005432661970	F1FB44	5802 603859	ANATOLIY SHEVCHENKO	{"email": "a.shevchenko-14121975@postgrespro.ru", "phone": "+70825790685"}
0005432661971	EF479E	2813 207001	ANDREY NAUMOV	{"email": "a-naumov18101968@postgrespro.ru", "phone": "+70435206142"}
0005432661972	EF479E	8053 596825	FARID GERASIMOV	{"email": "gerasimov-farid_021966@postgrespro.ru", "phone": "+70465938458"}
0005432661973	EF479E	8421 827769	DMITRIY ILIN	{"email": "ilin_dmitriy-17111970@postgrespro.ru", "phone": "+70540650548"}
0005432661974	EF479E	5145 920210	VALERIY KUZNECOV	{"phone": "+70118467427"}
0005432661975	454E10	7424 876447	ALEKSEY ZHUKOV	{"email": "alekseyzhukov_061975@postgrespro.ru", "phone": "+70552513552"}
0005432661976	66C90D	1796 793428	PETR SERGEEV	{"phone": "+70946456511"}
0005432661977	66C90D	8156 461824	GALINA ALEKSANDROVA	{"phone": "+70217487546"}
0005432661978	9A3471	4954 453480	ANASTASIYA MAKAROVA	{"email": "amakarova_011970@postgrespro.ru", "phone": "+70371961819"}
0005432661979	CA4668	5388 167165	MARINA FROLOVA	{"email": "frolova-m-27091974@postgrespro.ru", "phone": "+70700911493"}
0005432661980	FF320B	5910 165973	ALEKSEY VASILEV	{"email": "vasilev.aleksey_1967@postgrespro.ru", "phone": "+70457331060"}
0005432661981	AB36C9	8258 241831	VITALIY BORISOV	{"email": "vitaliy-borisov.011966@postgrespro.ru", "phone": "+70657730758"}
0005432661982	AB36C9	9026 049434	SERGEY KUZNECOV	{"phone": "+70995279500"}
0005432661983	36BAE2	8431 059274	IRINA ALEKSEEVA	{"email": "i.alekseeva.1977@postgrespro.ru", "phone": "+70402175846"}
0005432661984	019F09	0855 900272	DMITRIY NIKOLAEV	{"email": "dnikolaev.1971@postgrespro.ru", "phone": "+70077182441"}
0005432661985	334292	9698 082166	ANNA IVANOVA	{"email": "ivanova_a.021966@postgrespro.ru", "phone": "+70649105677"}
0005432661986	334292	8421 561723	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov031968@postgrespro.ru", "phone": "+70663306559"}
0005432661987	B6383C	3701 791816	ELENA VLASOVA	{"email": "elena_vlasova-05021983@postgrespro.ru", "phone": "+70688575904"}
0005432661988	B6383C	1959 930417	ELIZAVETA VASILEVA	{"email": "elizavetavasileva-27031961@postgrespro.ru", "phone": "+70088385644"}
0005432661989	02DF95	7901 523917	DMITRIY KUZNECOV	{"phone": "+70153229669"}
0005432661990	02DF95	1896 407810	NIKITA ZHUKOV	{"phone": "+70146080824"}
0005432661991	48DB6F	9189 897014	FARIDA PAVLOVA	{"email": "pavlovaf-1971@postgrespro.ru", "phone": "+70119199789"}
0005432661992	43141A	3972 644858	NADEZHDA MARTYNOVA	{"email": "martynova-nadezhda.28101978@postgrespro.ru", "phone": "+70530788675"}
0005432661993	43141A	5696 701717	TATYANA STEPANOVA	{"email": "stepanova.tatyana-12031977@postgrespro.ru", "phone": "+70339106192"}
0005432661994	011664	8702 788213	IRINA KARPOVA	{"phone": "+70560438638"}
0005432661995	01FCFE	1147 644855	ANDREY NOVIKOV	{"email": "novikov_andrey_051976@postgrespro.ru", "phone": "+70237346263"}
0005432661996	15212D	6282 907586	TAMARA KUZNECOVA	{"phone": "+70427394902"}
0005432661997	15212D	6800 310929	VALENTINA SCHERBAKOVA	{"phone": "+70474285933"}
0005432663012	5002F1	4600 370112	MARINA SEMENOVA	{"email": "semenovam081978@postgrespro.ru", "phone": "+70254859262"}
0005432663013	C28E58	7305 786076	MAKSIM ILIN	{"phone": "+70603227018"}
0005432663014	C28E58	2634 543450	ANATOLIY KARPOV	{"email": "karpov.a1973@postgrespro.ru", "phone": "+70073201044"}
0005432663015	69127F	4441 141591	IVAN SERGEEV	{"email": "ivan_sergeev-1976@postgrespro.ru", "phone": "+70633557697"}
0005432663016	96C220	7378 109365	DANILA ANTONOV	{"phone": "+70841660192"}
0005432663017	53C961	5813 324238	EVGENIY KUZMIN	{"phone": "+70665124787"}
0005432663018	925D41	3185 863544	OLGA RYABOVA	{"phone": "+70853914775"}
0005432663019	500906	4107 292934	LYUDMILA TITOVA	{"email": "titova-l_061973@postgrespro.ru", "phone": "+70122811812"}
0005432663020	1F2FEB	6990 767293	VYACHESLAV VASILEV	{"phone": "+70716514483"}
0005432663021	1F2FEB	0632 669214	DARYA MIRONOVA	{"phone": "+70642660163"}
0005432663022	E346A1	4761 239207	VADIM FEDOTOV	{"email": "v.fedotov1969@postgrespro.ru", "phone": "+70665801411"}
0005432663023	00067B	1403 773568	DMITRIY SCHERBAKOV	{"email": "d.scherbakov.1968@postgrespro.ru", "phone": "+70407280789"}
0005432663024	3AAEC1	2221 104322	RAISA IVANOVA	{"phone": "+70746706511"}
0005432663025	A89E7F	7749 460074	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova.anastasiya081983@postgrespro.ru", "phone": "+70403213531"}
0005432663026	A89E7F	6858 135600	SAVELIY DAVYDOV	{"email": "sdavydov_1964@postgrespro.ru", "phone": "+70961889045"}
0005432663027	A0F948	8071 099910	SVETLANA DAVYDOVA	{"email": "davydova.svetlana-1987@postgrespro.ru", "phone": "+70321236028"}
0005432663028	8E6B7D	1616 882637	OLEG IVANOV	{"phone": "+70193109032"}
0005432663029	0E4E11	5065 506766	MARIYA MAKSIMOVA	{"email": "mariya_maksimova.16031979@postgrespro.ru", "phone": "+70311985796"}
0005432663030	3BD751	4568 528763	LYUDMILA ORLOVA	{"email": "lorlova.081967@postgrespro.ru", "phone": "+70648788812"}
0005432663031	C68138	2454 380156	KAMIL KULIKOV	{"phone": "+70758208490"}
0005432663032	C68138	9801 137283	ANATOLIY ANTONOV	{"email": "antonov_anatoliy.1971@postgrespro.ru", "phone": "+70848534404"}
0005432663033	C68138	2981 713151	GALINA NIKOLAEVA	{"email": "nikolaevag_041982@postgrespro.ru", "phone": "+70996602734"}
0005432663034	975484	8949 430077	ELIZAVETA LOGINOVA	{"phone": "+70440177693"}
0005432663035	0FE265	3141 542541	IVAN MELNIKOV	{"phone": "+70345313975"}
0005432663036	0FE265	8976 571782	EKATERINA LOGINOVA	{"email": "e.loginova04061985@postgrespro.ru", "phone": "+70720070889"}
0005432663037	76B0A2	2889 252178	GULNAZ VASILEVA	{"email": "gulnazvasileva.11071977@postgrespro.ru", "phone": "+70777610179"}
0005432663038	EB452B	7348 980575	ZINAIDA KOLESNIKOVA	{"email": "kolesnikova_zinaida_1978@postgrespro.ru", "phone": "+70310625994"}
0005432663039	5A50AA	9238 555476	VIKTOR SMIRNOV	{"phone": "+70448010221"}
0005432663040	4480CC	8336 720223	ROMAN DMITRIEV	{"phone": "+70413114258"}
0005432663041	96FC31	8376 311018	ALEKSEY MARTYNOV	{"email": "martynov-aleksey.091952@postgrespro.ru", "phone": "+70130759301"}
0005432663042	100D45	4110 495706	TATYANA MOISEEVA	{"email": "moiseeva_t-25051975@postgrespro.ru", "phone": "+70894584606"}
0005432663043	1C2E67	4417 519246	ALEKSANDR MIRONOV	{"phone": "+70681086217"}
0005432663044	820EF4	8866 115579	VERA ZHURAVLEVA	{"phone": "+70843384152"}
0005432663045	820EF4	4084 366859	VIKTOR SOROKIN	{"email": "v-sorokin04091980@postgrespro.ru", "phone": "+70413082162"}
0005432663046	020A1B	6026 167205	VYACHESLAV KRASNOV	{"phone": "+70936765998"}
0005432663047	257656	6516 147430	ARTEM MEDVEDEV	{"email": "a_medvedev_15031971@postgrespro.ru", "phone": "+70640128438"}
0005432663048	123EBA	8181 565953	LYUBOV KRASNOVA	{"email": "krasnova_l_1972@postgrespro.ru", "phone": "+70662419323"}
0005432663049	172884	9310 517598	VALERIY POPOV	{"phone": "+70860232068"}
0005432663050	172884	8681 604598	KONSTANTIN TARASOV	{"phone": "+70317339516"}
0005432663051	AFA6F6	3356 097937	VALERIYA ZAKHAROVA	{"email": "v_zakharova.1978@postgrespro.ru", "phone": "+70872440394"}
0005432663052	A9D97C	9915 963436	ANASTASIYA ZAKHAROVA	{"email": "a.zakharova-1969@postgrespro.ru", "phone": "+70581374415"}
0005432663053	8A80EC	1357 465420	ZINAIDA NIKIFOROVA	{"phone": "+70495041930"}
0005432663054	64DA91	1647 913120	EVGENIYA STEPANOVA	{"phone": "+70804318587"}
0005432663055	B7D19F	5500 419386	NADEZHDA FROLOVA	{"email": "frolova.n-05071977@postgrespro.ru", "phone": "+70284930243"}
0005432663056	E38626	0479 405568	NURLAN MAKAROV	{"email": "nurlan_makarov-08031968@postgrespro.ru", "phone": "+70732256720"}
0005432663057	E38626	2302 865113	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr-1972@postgrespro.ru", "phone": "+70311882794"}
0005432663058	5A5A34	7692 106182	ELVIRA DENISOVA	{"email": "edenisova-10021968@postgrespro.ru", "phone": "+70057929099"}
0005432663059	46E599	2839 178985	TATYANA AKIMOVA	{"phone": "+70942522135"}
0005432663060	2AAB34	6596 364841	ILMIRA SOKOLOVA	{"phone": "+70822125907"}
0005432663061	0BC9DA	6926 871588	IRINA KUZNECOVA	{"phone": "+70964198359"}
0005432663062	804A4B	2107 077682	ALEKSANDR TIMOFEEV	{"email": "timofeeva1963@postgrespro.ru", "phone": "+70962684796"}
0005432663063	804A4B	0427 639787	ANDREY POPOV	{"email": "popov_a_051973@postgrespro.ru", "phone": "+70260397836"}
0005432663064	33A7A3	6278 976365	ANDREY NOVIKOV	{"phone": "+70818000092"}
0005432663065	ED71FC	8178 418742	VLADISLAV GRIGOREV	{"phone": "+70511676851"}
0005432663066	111FF6	1177 147392	LYUDMILA MAKSIMOVA	{"email": "lyudmila-maksimova_1974@postgrespro.ru", "phone": "+70676591168"}
0005432663067	C4F5BF	3244 303982	LIDIYA KONDRATEVA	{"email": "lidiya.kondrateva-1978@postgrespro.ru", "phone": "+70337050813"}
0005432663068	C4A8A8	4379 255291	EVGENIY KOZLOV	{"email": "kozlov.evgeniy-1971@postgrespro.ru", "phone": "+70132222329"}
0005432663069	15920A	8038 555808	NINA ANISIMOVA	{"phone": "+70238003512"}
0005432663070	15920A	7141 845480	ALEKSEY CHERNOV	{"email": "chernov.a-03071982@postgrespro.ru", "phone": "+70152122601"}
0005432663071	F6721C	8093 549639	NADEZHDA TITOVA	{"email": "nadezhda.titova031970@postgrespro.ru", "phone": "+70337963204"}
0005432663072	3AC131	0617 087510	IRINA EFIMOVA	{"phone": "+70101385079"}
0005432663073	3AC131	6649 807743	YURIY MAKAROV	{"email": "y-makarov-1970@postgrespro.ru", "phone": "+70998143001"}
0005432663074	3AC131	4619 297118	ALEKSANDR GRIGOREV	{"phone": "+70958607999"}
0005432663075	8EF5D1	9292 693568	DMITRIY SOKOLOV	{"email": "d-sokolov_1968@postgrespro.ru", "phone": "+70719023602"}
0005432663076	0BD05D	9722 207387	YURIY ZHUKOV	{"email": "zhukov-yuriy_1983@postgrespro.ru", "phone": "+70744230563"}
0005432663077	A22065	2231 821009	ANNA BELOVA	{"phone": "+70623367180"}
0005432663078	A22065	2584 072922	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.tatyana.061968@postgrespro.ru", "phone": "+70555820714"}
0005432663079	A4D958	7815 376679	IGOR KUZNECOV	{"phone": "+70129241973"}
0005432663080	A4D958	2036 785641	EVGENIY ZAKHAROV	{"phone": "+70592588606"}
0005432663081	E77C42	2331 303190	EVGENIY ANTONOV	{"phone": "+70829084991"}
0005432663082	E77C42	7356 796680	MILANA NIKOLAEVA	{"phone": "+70011567008"}
0005432663083	EB0948	9042 570759	ALEKSANDR STEPANOV	{"email": "stepanov-a.02031970@postgrespro.ru", "phone": "+70365976573"}
0005432663084	22F750	5108 619799	YULIYA KOMAROVA	{"email": "yuliya-komarova-29061979@postgrespro.ru", "phone": "+70546320971"}
0005432663085	22F750	8525 090696	ALEKSANDR KONOVALOV	{"phone": "+70182617008"}
0005432663086	211985	7843 370906	ALEKSANDR KARPOV	{"email": "karpov_aleksandr1970@postgrespro.ru", "phone": "+70071010047"}
0005432663087	211985	9459 146877	MARIYA ROMANOVA	{"phone": "+70609473552"}
0005432663088	E74651	6163 619470	ULYANA GORBUNOVA	{"email": "ulyana.gorbunova071964@postgrespro.ru", "phone": "+70932891943"}
0005432663089	FB31FE	2133 696329	ALEKSANDR ROMANOV	{"phone": "+70527026879"}
0005432663090	69BC60	7823 188140	OLGA ILINA	{"phone": "+70080495709"}
0005432663091	69BC60	4360 993550	OLGA MOROZOVA	{"email": "olgamorozova1973@postgrespro.ru", "phone": "+70645125170"}
0005432663092	E22F8B	0027 991016	ROZA BORISOVA	{"phone": "+70749571283"}
0005432663093	BAE937	3878 350501	VITALIY ABRAMOV	{"email": "vabramov27021969@postgrespro.ru", "phone": "+70954404780"}
0005432663094	BAE937	5533 009185	KAMIL NOVIKOV	{"email": "novikov_kamil_04111973@postgrespro.ru", "phone": "+70558625510"}
0005432663095	BAE937	3829 475728	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov24051978@postgrespro.ru", "phone": "+70084937050"}
0005432663096	62963F	0683 344588	GALINA MOISEEVA	{"email": "moiseeva_g_30071972@postgrespro.ru", "phone": "+70791846716"}
0005432663097	463AE8	0879 412405	EKATERINA ALEKSEEVA	{"phone": "+70568889181"}
0005432663098	B8E98F	7016 346981	SERGEY KARPOV	{"phone": "+70141123696"}
0005432663099	5A1371	7318 798993	OLGA KALININA	{"email": "kalinina-o_03011966@postgrespro.ru", "phone": "+70257018036"}
0005432663100	5BB450	5218 176428	ILYA STEPANOV	{"email": "stepanovi.051962@postgrespro.ru", "phone": "+70101522027"}
0005432663101	BB3E12	3345 608123	MIKHAIL FROLOV	{"email": "mikhail_frolov041974@postgrespro.ru", "phone": "+70877160954"}
0005432663102	C214E1	3787 862554	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev_04011973@postgrespro.ru", "phone": "+70347878888"}
0005432663103	C214E1	5405 787908	MIKHAIL ZAKHAROV	{"phone": "+70453276208"}
0005432663104	C214E1	9587 016526	EVGENIY GUSEV	{"phone": "+70792219267"}
0005432663105	167BD9	3797 956620	SVETLANA MALYSHEVA	{"email": "s.malysheva041967@postgrespro.ru", "phone": "+70925533947"}
0005432663106	167BD9	6127 165111	ELENA BOGDANOVA	{"email": "bogdanovae051970@postgrespro.ru", "phone": "+70406750013"}
0005432663107	AEC430	8570 814004	ANASTASIYA GERASIMOVA	{"email": "anastasiya_gerasimova.1972@postgrespro.ru", "phone": "+70433394799"}
0005432663108	AEC430	8941 325693	ANASTASIYA FROLOVA	{"email": "frolova.anastasiya.27121976@postgrespro.ru", "phone": "+70110284955"}
0005432663109	625C52	5321 998042	VIKTOR SIDOROV	{"email": "v.sidorov031970@postgrespro.ru", "phone": "+70438009350"}
0005432663110	625C52	9736 370713	OLGA FILATOVA	{"phone": "+70617395798"}
0005432663111	625C52	7887 028282	ALEKSANDR GORBUNOV	{"email": "gorbunov_aleksandr.1968@postgrespro.ru", "phone": "+70516045849"}
0005432664113	D9A160	0596 714074	NATALYA TROFIMOVA	{"email": "natalyatrofimova_1982@postgrespro.ru", "phone": "+70439264094"}
0005432664114	3EC258	2824 896890	IRINA ROMANOVA	{"phone": "+70164573554"}
0005432664115	F594B7	8469 230486	ELENA POPOVA	{"email": "epopova-081966@postgrespro.ru", "phone": "+70173586538"}
0005432664116	06FF9F	7311 966792	ANDREY GORBUNOV	{"phone": "+70502776996"}
0005432664117	281083	1681 313614	SVETLANA ERMAKOVA	{"email": "s_ermakova_111970@postgrespro.ru", "phone": "+70143095596"}
0005432664118	84ABA1	1348 070052	ARTEM RODIONOV	{"email": "rodionov_artem-021962@postgrespro.ru", "phone": "+70366443860"}
0005432664119	84ABA1	5891 869018	SERGEY GUSEV	{"email": "sergeygusev-14121967@postgrespro.ru", "phone": "+70709741783"}
0005432664120	AF2BF9	9522 603278	DINA MATVEEVA	{"phone": "+70464026716"}
0005432664121	2788B2	7517 257247	SVETLANA NESTEROVA	{"phone": "+70581222186"}
0005432664122	9B20F6	4712 910081	NATALYA IVANOVA	{"phone": "+70846782203"}
0005432664123	323AF8	3497 144240	ALEKSANDR ISAEV	{"phone": "+70113801768"}
0005432664124	323AF8	1042 226605	NATALIYA OVCHINNIKOVA	{"phone": "+70261064109"}
0005432664125	FD46EF	2025 135327	ANNA BORISOVA	{"phone": "+70915648483"}
0005432664126	26A2D4	9272 846015	OLEG POPOV	{"email": "olegpopov_13121975@postgrespro.ru", "phone": "+70686664228"}
0005432664127	18A40C	8315 149595	VALENTINA GAVRILOVA	{"email": "gavrilova-valentina.12101982@postgrespro.ru", "phone": "+70457388569"}
0005432664128	98952F	6902 795590	VLADIMIR FEDOTOV	{"email": "fedotov-vladimir.1960@postgrespro.ru", "phone": "+70864418439"}
0005432664129	FF266D	3120 035908	MIKHAIL ROMANOV	{"email": "romanovm_14091962@postgrespro.ru", "phone": "+70209003601"}
0005432664130	FF266D	4805 339011	DMITRIY KUZMIN	{"email": "kuzmind1983@postgrespro.ru", "phone": "+70053026634"}
0005432664131	6A53A3	0153 201368	ANASTASIYA IVANOVA	{"email": "ivanova-anastasiya-111983@postgrespro.ru", "phone": "+70157326054"}
0005432664132	9ED5BF	8612 449807	ELENA MELNIKOVA	{"email": "emelnikova_04081960@postgrespro.ru", "phone": "+70969782780"}
0005432664133	9ED5BF	5996 577072	ALEKSANDR MAKAROV	{"phone": "+70561015713"}
0005432664134	9ED5BF	3286 658462	VLADIMIR TARASOV	{"phone": "+70370792157"}
0005432664135	4DEF3A	8976 387816	TATYANA BARANOVA	{"phone": "+70948062614"}
0005432664136	7DF64A	1550 551966	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr.1976@postgrespro.ru", "phone": "+70522522724"}
0005432664137	7DF64A	8957 487014	ALEKSANDR PETROV	{"phone": "+70282408278"}
0005432664138	076A1C	1817 679267	LEONID GRIGOREV	{"email": "lgrigorev.1984@postgrespro.ru", "phone": "+70820405933"}
0005432664139	7AE317	1358 734963	IGOR KULIKOV	{"phone": "+70744673131"}
0005432664140	22D961	8951 358964	ALEKSANDR SIDOROV	{"phone": "+70786301092"}
0005432664141	8D7641	6973 448726	VYACHESLAV MAKAROV	{"phone": "+70327431835"}
0005432664142	8D7641	2872 913924	RAISA NIKOLAEVA	{"email": "raisanikolaeva.22071980@postgrespro.ru", "phone": "+70779427848"}
0005432664143	3D06F9	5919 986231	DANIIL OSIPOV	{"phone": "+70222343198"}
0005432664144	3D06F9	2667 083898	ALENA ANDREEVA	{"phone": "+70626003253"}
0005432664145	22B054	2874 596623	IVAN FEDOTOV	{"phone": "+70721165129"}
0005432664146	DD09EC	3124 212904	VALENTINA AFANASEVA	{"email": "afanaseva.valentina_26121979@postgrespro.ru", "phone": "+70663367310"}
0005432664147	3D65FC	1190 844028	MARINA MOROZOVA	{"email": "morozova.marina081971@postgrespro.ru", "phone": "+70060765551"}
0005432664148	A94097	8521 902622	YULIYA YAKOVLEVA	{"phone": "+70590410357"}
0005432664149	E78E29	5800 081770	ANDREY KUZNECOV	{"phone": "+70871319974"}
0005432664150	815255	5601 647765	MIKHAIL IVANOV	{"email": "mikhail_ivanov05051974@postgrespro.ru", "phone": "+70035905881"}
0005432664151	815255	3940 931868	DARYA SEMENOVA	{"email": "semenovad.16091978@postgrespro.ru", "phone": "+70010045271"}
0005432664152	815255	2318 896348	MARGARITA ZAYCEVA	{"email": "zayceva.m121968@postgrespro.ru", "phone": "+70876658843"}
0005432664153	C8F65F	0247 364846	NADEZHDA KONDRATEVA	{"email": "kondratevan_09031970@postgrespro.ru", "phone": "+70974431356"}
0005432664154	3E720F	7504 248639	LYAYSAN FADEEVA	{"phone": "+70018771912"}
0005432664155	9D10E2	6062 631171	ANNA ZAKHAROVA	{"email": "zakharovaa_011977@postgrespro.ru", "phone": "+70464685231"}
0005432664156	C988AB	4021 178451	DMITRIY YAKOVLEV	{"phone": "+70743306973"}
0005432664157	C988AB	5087 451685	OKSANA MAKSIMOVA	{"email": "maksimova_o-121976@postgrespro.ru", "phone": "+70983765780"}
0005432664158	98F077	7860 976039	MARIYA KARPOVA	{"email": "karpova.m.15101977@postgrespro.ru", "phone": "+70113264069"}
0005432664159	98F077	2514 603842	ANNA SEMENOVA	{"email": "semenova.a041969@postgrespro.ru", "phone": "+70710480808"}
0005432664160	0E8812	9654 092465	PETR IVANOV	{"phone": "+70159404219"}
0005432664161	0E8812	7689 194736	ANDREY KUZNECOV	{"email": "kuznecov_a_1962@postgrespro.ru", "phone": "+70856829362"}
0005432664162	EC0C07	5806 534071	RUZALIYA KUZMINA	{"email": "rkuzmina.1966@postgrespro.ru", "phone": "+70709346146"}
0005432664163	EC0C07	4930 867174	TATYANA NIKOLAEVA	{"email": "nikolaeva_tatyana.1970@postgrespro.ru", "phone": "+70097997517"}
0005432664164	3D884F	1215 683680	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a09111980@postgrespro.ru", "phone": "+70595363236"}
0005432664165	3D884F	8831 144426	DMITRIY ISAEV	{"phone": "+70706267746"}
0005432664166	E87BA7	6023 413529	VIKTOR STEPANOV	{"email": "stepanov-viktor.041974@postgrespro.ru", "phone": "+70821790899"}
0005432664167	79353A	4260 535675	MATVEY NIKOLAEV	{"phone": "+70698952606"}
0005432664168	79353A	7891 621819	NINA GUSEVA	{"email": "ninaguseva1978@postgrespro.ru", "phone": "+70683460629"}
0005432664169	0F9154	3085 697829	TAMARA GORBUNOVA	{"phone": "+70744460116"}
0005432664170	6E50EB	1720 085867	EKATERINA POPOVA	{"email": "popova-ekaterina03011984@postgrespro.ru", "phone": "+70930799512"}
0005432664171	C6D9FC	0003 095606	SERGEY ZAKHAROV	{"email": "zakharov_s071977@postgrespro.ru", "phone": "+70696301982"}
0005432664172	FBDBB3	3566 032131	VASILIY GUSEV	{"email": "gusevv-1970@postgrespro.ru", "phone": "+70861959499"}
0005432664173	784EE9	0273 551966	PAVEL DMITRIEV	{"phone": "+70559767539"}
0005432664174	CFC9BE	2470 605428	EKATERINA VOROBEVA	{"email": "vorobevae1967@postgrespro.ru", "phone": "+70407719015"}
0005432664175	5A368D	0942 631419	NADEZHDA DENISOVA	{"email": "n_denisova.03101977@postgrespro.ru", "phone": "+70658409487"}
0005432664176	C51588	5920 707162	LARISA NIKOLAEVA	{"email": "nikolaeval.1965@postgrespro.ru", "phone": "+70466405093"}
0005432664177	C51588	9063 309656	MIKHAIL SCHERBAKOV	{"email": "scherbakov_m.091976@postgrespro.ru", "phone": "+70211020637"}
0005432664178	5AD4F4	5334 313014	VADIM PETROV	{"phone": "+70725888683"}
0005432664179	7E86F1	4177 813612	ELENA SEMENOVA	{"phone": "+70149828925"}
0005432664180	EE0955	2945 703100	ANATOLIY FILIPPOV	{"email": "afilippov-051974@postgrespro.ru", "phone": "+70261641216"}
0005432664181	EE0955	8390 054841	OLGA SEMENOVA	{"phone": "+70776075660"}
0005432664182	AF8D9B	0382 465636	RUSTAM NAUMOV	{"email": "naumov-r1976@postgrespro.ru", "phone": "+70935361781"}
0005432664183	FF2857	8061 557296	LARISA GAVRILOVA	{"phone": "+70085265450"}
0005432664184	E2BBE3	5801 985418	MIKHAIL TARASOV	{"email": "m-tarasov_30091964@postgrespro.ru", "phone": "+70480859226"}
0005432664185	067888	2181 743725	SVETLANA NIKITINA	{"email": "nikitina-svetlana_1982@postgrespro.ru", "phone": "+70555204201"}
0005432664186	067888	4861 676396	ANDREY DMITRIEV	{"phone": "+70090782215"}
0005432664187	1B23E4	8979 482488	VYACHESLAV PETROV	{"phone": "+70369009931"}
0005432664188	13512A	6012 142862	NATALYA VOLKOVA	{"email": "natalyavolkova-091980@postgrespro.ru", "phone": "+70863240559"}
0005432664189	4C179A	4231 626543	ANNA FILATOVA	{"email": "a.filatova-051977@postgrespro.ru", "phone": "+70734963241"}
0005432664190	AB6004	0347 876859	PETR PETROV	{"email": "petrov_petr.101975@postgrespro.ru", "phone": "+70217561744"}
0005432664191	1B247C	6438 544062	ALEKSEY MEDVEDEV	{"email": "amedvedev_051967@postgrespro.ru", "phone": "+70124255738"}
0005432664192	1B247C	1418 738305	ANDREY TARASOV	{"email": "tarasov_andrey_1974@postgrespro.ru", "phone": "+70707809498"}
0005432664193	A9462F	6582 157527	GALINA ZHURAVLEVA	{"email": "zhuravleva_galina1965@postgrespro.ru", "phone": "+70517651301"}
0005432664194	A9462F	3091 274969	VLADIMIR ZAYCEV	{"phone": "+70134765556"}
0005432664195	5621B2	4036 244175	EKATERINA ANDREEVA	{"email": "andreeva_ekaterina.011969@postgrespro.ru", "phone": "+70018629758"}
0005432664196	178C6D	3897 390149	ALEKSEY FEDOROV	{"email": "fedorov_aleksey.24071973@postgrespro.ru", "phone": "+70864627359"}
0005432664197	072D4A	2052 942626	VIKTOR TIKHONOV	{"phone": "+70535097603"}
0005432664198	82CD4D	2447 168784	RUSLAN MIKHAYLOV	{"phone": "+70263145818"}
0005432664199	82CD4D	1986 786532	TAISIYA POLYAKOVA	{"email": "polyakova_t.1990@postgrespro.ru", "phone": "+70129592901"}
0005432664200	82CD4D	6735 603905	NATALIYA TIKHONOVA	{"email": "nataliya-tikhonova.1974@postgrespro.ru", "phone": "+70287484663"}
0005432664201	45BE18	4661 766644	ELIZAVETA GORBUNOVA	{"email": "gorbunovaelizaveta-061974@postgrespro.ru", "phone": "+70201603703"}
0005432664202	45BE18	5103 820103	NATALYA PETROVA	{"email": "natalyapetrova-1968@postgrespro.ru", "phone": "+70824652477"}
0005432664203	129EEA	8199 892585	ELENA SERGEEVA	{"email": "elena.sergeeva_18061979@postgrespro.ru", "phone": "+70420891332"}
0005432664204	B2C908	7479 222891	ALEKSEY GORBUNOV	{"phone": "+70715520106"}
0005432664205	B2C908	1230 832112	OKSANA FEDOROVA	{"phone": "+70827106567"}
0005432664206	B2C908	8961 271562	DMITRIY MEDVEDEV	{"email": "medvedev_d.111975@postgrespro.ru", "phone": "+70540673054"}
0005432664207	7EE85D	9844 831066	ANDREY NIKOLAEV	{"email": "nikolaev_andrey_1968@postgrespro.ru", "phone": "+70196145799"}
0005432664208	E008C3	7983 577681	SVETLANA NAZAROVA	{"phone": "+70405802936"}
0005432664209	E8AFED	8774 986114	MAKSIM FOMIN	{"phone": "+70155556598"}
0005432664210	E8AFED	9647 454725	DMITRIY NAUMOV	{"email": "dmitriy_naumov.011977@postgrespro.ru", "phone": "+70183053063"}
0005432664211	E8AFED	2647 473749	ELENA ERMAKOVA	{"email": "ermakova_elena_121973@postgrespro.ru", "phone": "+70916241165"}
0005432664212	2298B8	8679 774509	ANATOLIY SERGEEV	{"phone": "+70805812920"}
0005432664213	3DC8E9	9639 947951	ALISA YAKOVLEVA	{"phone": "+70691590318"}
0005432664214	3DC8E9	0298 592286	IRINA BORISOVA	{"email": "borisova-i1966@postgrespro.ru", "phone": "+70972148070"}
0005432664215	3DC8E9	6158 089670	MIKHAIL POPOV	{"phone": "+70939683613"}
0005432665249	E9FD71	9425 848668	ALEKSEY YAKOVLEV	{"phone": "+70077612680"}
0005432665237	1BA0BB	2361 216384	ANASTASIYA ALEKSEEVA	{"email": "alekseevaanastasiya.071975@postgrespro.ru", "phone": "+70577531117"}
0005432665238	913F57	9553 952965	DARYA KUZMINA	{"phone": "+70287063368"}
0005432665239	E8653F	5840 725222	LILIYA OSIPOVA	{"phone": "+70623966489"}
0005432665240	E8653F	5091 876423	IVAN SIDOROV	{"phone": "+70500651610"}
0005432665241	2AFAC5	0450 594218	NIKOLAY FILIPPOV	{"phone": "+70639640906"}
0005432665242	2AFAC5	8761 261663	MARIYA DAVYDOVA	{"email": "davydovamariya_1974@postgrespro.ru", "phone": "+70672076768"}
0005432665243	2AFAC5	7209 252093	DENIS FROLOV	{"email": "frolov-denis-011971@postgrespro.ru", "phone": "+70327423502"}
0005432665244	ABE7B4	3553 197174	VIKTOR MEDVEDEV	{"email": "v.medvedev06111968@postgrespro.ru", "phone": "+70321855751"}
0005432665245	ABE7B4	2581 250658	VLADIMIR SIDOROV	{"phone": "+70520746456"}
0005432665246	A9D1B6	9797 544386	ARINA KAZAKOVA	{"email": "a-kazakova-04081971@postgrespro.ru", "phone": "+70703794539"}
0005432665247	A9D1B6	5117 041560	LYUDMILA IVANOVA	{"phone": "+70960679875"}
0005432665248	A9D1B6	2889 462024	ARINA ZAYCEVA	{"phone": "+70084877077"}
0005432665250	CEA655	7584 289221	ANDREY KUZMIN	{"phone": "+70775529260"}
0005432665251	58FB4D	6121 837746	STANISLAV ZHURAVLEV	{"email": "zhuravlev-s-28031973@postgrespro.ru", "phone": "+70541767921"}
0005432665252	CA31AE	7389 635502	LYUBOV SOKOLOVA	{"phone": "+70847204819"}
0005432665253	2F08A1	7538 416692	ROMAN MOROZOV	{"email": "morozovroman.091969@postgrespro.ru", "phone": "+70452724633"}
0005432665254	EB0C4A	9961 975154	ELIZAVETA RODIONOVA	{"email": "rodionova-elizaveta031976@postgrespro.ru", "phone": "+70845810921"}
0005432665255	1DD4E3	2254 319735	SERGEY KUZNECOV	{"phone": "+70562745201"}
0005432665256	1DD4E3	2582 934276	KIRILL KUZMIN	{"email": "kirillkuzmin.1946@postgrespro.ru", "phone": "+70453178859"}
0005432665257	1DD4E3	1962 883404	NIKOLAY YAKOVLEV	{"phone": "+70016196098"}
0005432665258	326C6A	9670 062668	VALERIY SEMENOV	{"email": "v-semenov111966@postgrespro.ru", "phone": "+70409667606"}
0005432665259	326C6A	0100 557661	TATYANA POPOVA	{"email": "popova-t_1985@postgrespro.ru", "phone": "+70989818431"}
0005432665260	CE6A89	1280 646107	IVAN KOROLEV	{"phone": "+70678207933"}
0005432665261	B8BE4C	6310 098272	IRINA LEBEDEVA	{"phone": "+70865593272"}
0005432665262	8E2C1D	2220 419426	ANDREY STEPANOV	{"phone": "+70159969817"}
0005432665263	E2C61E	3551 710580	MARIYA BELOVA	{"email": "belova_m-1973@postgrespro.ru", "phone": "+70582719077"}
0005432665264	E2C61E	6930 207805	EVDOKIYA SOKOLOVA	{"phone": "+70686112048"}
0005432665265	068ABE	9063 219546	LYUDMILA KOZLOVA	{"email": "l_kozlova.1979@postgrespro.ru", "phone": "+70792426558"}
0005432665266	068ABE	1868 196408	OKSANA NIKITINA	{"email": "nikitina.oksana_031976@postgrespro.ru", "phone": "+70046793697"}
0005432665267	CAC1D9	6261 153185	SVETLANA VOROBEVA	{"email": "vorobeva-s.011984@postgrespro.ru", "phone": "+70244854044"}
0005432665268	B94E3E	5186 290021	NINA ZAKHAROVA	{"phone": "+70105185962"}
0005432665269	10E843	3922 152719	DMITRIY SERGEEV	{"phone": "+70691427181"}
0005432665270	30C8E5	1466 527060	ANASTASIYA SIDOROVA	{"phone": "+70028634777"}
0005432665271	30C8E5	5384 384830	TATYANA KONDRATEVA	{"email": "kondrateva-t.091966@postgrespro.ru", "phone": "+70860635989"}
0005432665272	5B01A1	0983 555607	ANASTASIYA BORISOVA	{"email": "a.borisova121977@postgrespro.ru", "phone": "+70241729587"}
0005432665273	540E8A	3580 207770	ALEKSANDR MAKSIMOV	{"phone": "+70667638504"}
0005432665274	540E8A	8607 475856	KONSTANTIN KULIKOV	{"email": "k-kulikov-10071983@postgrespro.ru", "phone": "+70061530986"}
0005432665275	540E8A	4407 599773	VLADIMIR ZHUKOV	{"phone": "+70956071890"}
0005432665276	77107A	9380 214457	ALLA OSIPOVA	{"phone": "+70418049620"}
0005432665277	9C2DF3	3307 743692	NIKOLAY SMIRNOV	{"email": "n_smirnov.021981@postgrespro.ru", "phone": "+70473797872"}
0005432665278	8B9A2F	0157 887360	ANNA POPOVA	{"email": "popova.a_051968@postgrespro.ru", "phone": "+70417950783"}
0005432665279	884496	9161 195330	NINA BELOVA	{"email": "nina_belova1983@postgrespro.ru", "phone": "+70869336529"}
0005432665280	578443	3513 706888	ALEKSANDR NOVIKOV	{"phone": "+70693623618"}
0005432665281	CC0244	1812 345035	TATYANA GERASIMOVA	{"phone": "+70156972266"}
0005432665282	3FAE81	2399 038794	GALINA TIKHONOVA	{"email": "gtikhonova1968@postgrespro.ru", "phone": "+70772278728"}
0005432665283	3FAE81	5157 488245	ELIZAVETA IVANOVA	{"email": "ivanovae_081975@postgrespro.ru", "phone": "+70417375609"}
0005432665284	C98A44	5776 841211	IRINA SAVELEVA	{"email": "saveleva-irina.051971@postgrespro.ru", "phone": "+70604475662"}
0005432665285	7A47CE	8138 037959	VYACHESLAV ALEKSANDROV	{"email": "aleksandrovv29051962@postgrespro.ru", "phone": "+70527129316"}
0005432665286	2C7890	6772 496875	AYRAT GRIGOREV	{"phone": "+70916269536"}
0005432665287	2C7890	2933 917662	EKATERINA GUSEVA	{"email": "guseva-ekaterina091975@postgrespro.ru", "phone": "+70386356789"}
0005432665288	17478E	2454 755743	SVETLANA ROMANOVA	{"email": "svetlana.romanova_1989@postgrespro.ru", "phone": "+70185218942"}
0005432665289	0BC261	4509 166884	NATALYA NIKOLAEVA	{"email": "nikolaeva_natalya031967@postgrespro.ru", "phone": "+70871571754"}
0005432665290	F2B2FD	0989 384073	MARINA ZAYCEVA	{"email": "m.zayceva.24011963@postgrespro.ru", "phone": "+70135117519"}
0005432665291	9A06EF	3946 594118	MARIYA SOLOVEVA	{"email": "soloveva.m1986@postgrespro.ru", "phone": "+70144704199"}
0005432665292	9A06EF	8138 576273	OLEG KRASNOV	{"phone": "+70474778186"}
0005432665293	9187A4	7350 745387	VALENTINA KUDRYASHOVA	{"phone": "+70500607133"}
0005432665294	1A08AC	5936 794220	SERGEY NIKITIN	{"email": "nikitin.s_1977@postgrespro.ru", "phone": "+70770165639"}
0005432665295	609F6E	7916 014923	ANDREY SEMENOV	{"email": "andreysemenov-1972@postgrespro.ru", "phone": "+70973103522"}
0005432665296	7EC0BE	6785 639913	MARSEL PETROV	{"email": "m_petrov_1964@postgrespro.ru", "phone": "+70726114620"}
0005432665297	7EC0BE	2786 559506	ANNA ALEKSANDROVA	{"email": "annaaleksandrova11091967@postgrespro.ru", "phone": "+70513004207"}
0005432665298	D32653	1072 639955	EKATERINA ANTONOVA	{"phone": "+70962080304"}
0005432665299	6C73E0	8506 560018	OLEG NOVIKOV	{"phone": "+70350844479"}
0005432665300	0960F4	2992 018907	ANATOLIY FROLOV	{"email": "anatoliy-frolov.09081965@postgrespro.ru", "phone": "+70121946979"}
0005432665301	0960F4	9617 056023	LYUBOV KUZNECOVA	{"phone": "+70316347003"}
0005432665302	561C9B	0464 549491	YULIYA IVANOVA	{"email": "y_ivanova-1976@postgrespro.ru", "phone": "+70654847856"}
0005432665303	A62369	9082 209922	VERONIKA SOKOLOVA	{"email": "v_sokolova-1974@postgrespro.ru", "phone": "+70733179141"}
0005432665304	A62369	1935 011275	OLEG MOROZOV	{"email": "oleg_morozov1972@postgrespro.ru", "phone": "+70969950488"}
0005432665305	A62369	8788 434699	ANATOLIY SERGEEV	{"phone": "+70521257977"}
0005432665306	11C029	4490 443644	SERGEY ZHUKOV	{"phone": "+70441169150"}
0005432665307	348589	1132 213524	LYUBOV KAZAKOVA	{"phone": "+70994230172"}
0005432665308	A0F4EE	6360 488189	SVETLANA TARASOVA	{"email": "s-tarasova_121968@postgrespro.ru", "phone": "+70602417063"}
0005432665309	200D63	6701 104246	NAIL NOVIKOV	{"phone": "+70894602835"}
0005432665310	200D63	3740 173519	ELIZAVETA MOROZOVA	{"phone": "+70684154377"}
0005432665311	6161E6	0628 666674	KSENIYA OVCHINNIKOVA	{"phone": "+70134668430"}
0005432665312	66D3E9	8500 559584	ANASTASIYA GUSEVA	{"phone": "+70882925422"}
0005432665313	1449D3	6072 736826	ALEKSANDR SAVELEV	{"phone": "+70366387640"}
0005432665314	EF2ECC	7313 154058	VALENTINA ZHUKOVA	{"email": "valentina.zhukova-18071972@postgrespro.ru", "phone": "+70098978492"}
0005432665315	EF2ECC	7264 376621	NATALIYA BORISOVA	{"email": "nataliya.borisova_011981@postgrespro.ru", "phone": "+70750341858"}
0005432665316	FE120B	7002 445887	SERGEY NOVIKOV	{"phone": "+70885547374"}
0005432665317	FE120B	8262 598185	IVAN SMIRNOV	{"phone": "+70887788852"}
0005432665318	FE120B	7682 123009	SERGEY VOROBEV	{"email": "vorobevs.061981@postgrespro.ru", "phone": "+70644744609"}
0005432665319	5BB6CC	3992 335898	LYUDMILA IVANOVA	{"phone": "+70662824736"}
0005432665320	722736	8707 337897	ALEKSEY FEDOTOV	{"phone": "+70096165047"}
0005432665321	722736	0750 573401	DARYA ANISIMOVA	{"email": "anisimova.darya.1972@postgrespro.ru", "phone": "+70066263748"}
0005432665322	31E321	4005 400030	ANNA SOLOVEVA	{"phone": "+70627082139"}
0005432665323	31E321	9391 683426	VERA EGOROVA	{"phone": "+70296390004"}
0005432665324	72DAD7	2817 133232	RIMMA YUDINA	{"email": "yudina.rimma_13051968@postgrespro.ru", "phone": "+70952194794"}
0005432665325	72DAD7	5400 948284	TIGRAN GAVRILOV	{"email": "gavrilovtigran1968@postgrespro.ru", "phone": "+70110394731"}
0005432665326	CDA708	8837 365876	YANA STEPANOVA	{"email": "stepanovayana06041967@postgrespro.ru", "phone": "+70080549816"}
0005432665327	23960F	7479 581845	DMITRIY MOROZOV	{"email": "morozovdmitriy-061973@postgrespro.ru", "phone": "+70047344383"}
0005432665328	C8B535	0276 985177	ANNA IVANOVA	{"email": "aivanova.101961@postgrespro.ru", "phone": "+70106180726"}
0005432665329	D29BAB	9260 029934	VLADIMIR TIKHONOV	{"email": "tikhonov.v_14081976@postgrespro.ru", "phone": "+70344925931"}
0005432665330	D29BAB	0477 231606	EVGENIY SCHERBAKOV	{"email": "scherbakov-e09081977@postgrespro.ru", "phone": "+70245580114"}
0005432665331	A380E5	8737 844788	VALERIY TARASOV	{"email": "tarasov.valeriy-061982@postgrespro.ru", "phone": "+70917221826"}
0005432665332	279CB3	7784 127078	VERONIKA DANILOVA	{"email": "veronikadanilova_1985@postgrespro.ru", "phone": "+70073250505"}
0005432665333	CD7788	1802 885758	VLADISLAV BELOV	{"phone": "+70010879952"}
0005432665334	6597BA	8097 379509	ANNA FROLOVA	{"phone": "+70155368914"}
0005432665335	7FFC43	0311 131613	ALEKSEY MOROZOV	{"email": "morozova23061973@postgrespro.ru", "phone": "+70130137599"}
0005432665336	7C408C	9694 465844	VLADIMIR KUZMIN	{"email": "kuzmin.v1978@postgrespro.ru", "phone": "+70992627774"}
0005432666351	A42079	5079 888267	YURIY VOROBEV	{"email": "yuriy_vorobev_05101968@postgrespro.ru", "phone": "+70391088792"}
0005432666352	91C786	0045 723891	ANNA MATVEEVA	{"email": "annamatveeva_051973@postgrespro.ru", "phone": "+70517221706"}
0005432666353	91C786	0163 015058	YULIYA PETROVA	{"email": "petrova-yuliya081975@postgrespro.ru", "phone": "+70507673158"}
0005432666354	B12261	8064 059755	ARTEM BARANOV	{"phone": "+70057481793"}
0005432666355	E8CFB5	6254 397262	EMILIYA BARANOVA	{"email": "baranovae_11051966@postgrespro.ru", "phone": "+70137091687"}
0005432666356	621504	3359 754917	SERGEY KOZLOV	{"email": "kozlovsergey-04111966@postgrespro.ru", "phone": "+70008373885"}
0005432666357	621504	3698 860749	ANNA SERGEEVA	{"phone": "+70236539791"}
0005432666358	625E79	6925 630397	VYACHESLAV KUZNECOV	{"email": "v-kuznecov_011985@postgrespro.ru", "phone": "+70877942710"}
0005432666359	1A1EF0	0991 108089	ANASTASIYA ILINA	{"phone": "+70077027896"}
0005432666360	1A1EF0	5978 887039	VADIM GERASIMOV	{"email": "gerasimov-vadim-121978@postgrespro.ru", "phone": "+70935775528"}
0005432666361	7E62BA	7306 633328	OLGA TARASOVA	{"email": "olgatarasova021974@postgrespro.ru", "phone": "+70424413428"}
0005432666362	7E62BA	7480 962137	IRINA BOGDANOVA	{"email": "bogdanova_irina_1968@postgrespro.ru", "phone": "+70365909375"}
0005432666363	3EDDB1	9208 674587	IRINA DAVYDOVA	{"email": "irina.davydova-101976@postgrespro.ru", "phone": "+70940930056"}
0005432666364	3EDDB1	3536 097243	ANASTASIYA ANDREEVA	{"email": "andreeva.anastasiya1975@postgrespro.ru", "phone": "+70347761681"}
0005432666365	B7C060	4620 025667	IVAN MIRONOV	{"email": "ivanmironov.1972@postgrespro.ru", "phone": "+70103592752"}
0005432666366	EFD881	6531 801375	TATYANA SIDOROVA	{"phone": "+70063402562"}
0005432666367	40793C	4353 316442	YULIYA KONDRATEVA	{"email": "kondratevay1970@postgrespro.ru", "phone": "+70949950118"}
0005432666368	40793C	9538 752126	DAMIR NIKOLAEV	{"email": "nikolaev_damir081960@postgrespro.ru", "phone": "+70462668020"}
0005432666369	40793C	8969 114445	IREK POPOV	{"phone": "+70679564287"}
0005432666370	62D9D9	0735 354245	NINA ALEKSEEVA	{"email": "n.alekseeva01071969@postgrespro.ru", "phone": "+70082034511"}
0005432666371	62D9D9	5957 932324	MAKSIM POPOV	{"phone": "+70972642356"}
0005432666372	579D4F	2747 324880	GALINA SCHERBAKOVA	{"phone": "+70283567156"}
0005432666373	C61EB5	3742 840908	TATYANA ANDREEVA	{"email": "andreeva.t_08011960@postgrespro.ru", "phone": "+70177823643"}
0005432666374	D322EB	6558 616616	EVGENIYA ILINA	{"email": "evgeniya.ilina_07021972@postgrespro.ru", "phone": "+70459033412"}
0005432666375	B7A878	8092 774949	ALEKSEY FEDOTOV	{"phone": "+70408827871"}
0005432666376	E0F7B2	4113 725280	ELENA MAKAROVA	{"phone": "+70425106101"}
0005432666377	88570C	6974 008958	VIKTOR EGOROV	{"email": "egorov-v_12021973@postgrespro.ru", "phone": "+70124302752"}
0005432666378	109174	0796 411384	ANNA FROLOVA	{"phone": "+70017561737"}
0005432666379	8DE5C9	7637 548930	SERGEY GAVRILOV	{"phone": "+70744908519"}
0005432666380	CB6430	7191 741118	SERGEY ISAEV	{"phone": "+70334990678"}
0005432666381	BAAE74	4623 162796	ANATOLIY MOISEEV	{"phone": "+70494820443"}
0005432666382	3D8AB2	7174 848279	SERGEY GRIGOREV	{"phone": "+70086144642"}
0005432666383	3F575C	3528 294638	TATYANA PAVLOVA	{"email": "pavlova-tatyana.1968@postgrespro.ru", "phone": "+70572982508"}
0005432666384	3F575C	3026 145617	ANDREY IVANOV	{"phone": "+70308884763"}
0005432666385	A307D4	1207 942194	OKSANA EFIMOVA	{"email": "efimovaoksana04021972@postgrespro.ru", "phone": "+70535845843"}
0005432666386	53F377	9944 003029	ALEKSANDR SAVELEV	{"phone": "+70150877451"}
0005432666387	A39A3F	6858 686667	DENIS BELOV	{"email": "denisbelov_1963@postgrespro.ru", "phone": "+70317860393"}
0005432666388	D7FDFC	8723 278122	EKATERINA PETROVA	{"phone": "+70082715504"}
0005432666389	D7FDFC	4836 190981	GALINA KARPOVA	{"email": "karpova_galina-1972@postgrespro.ru", "phone": "+70731978811"}
0005432666390	D7FDFC	1083 572238	ANDREY BARANOV	{"email": "baranovandrey.21111971@postgrespro.ru", "phone": "+70382614882"}
0005432666391	C86BA3	7979 198188	NADEZHDA SOKOLOVA	{"phone": "+70689140114"}
0005432666392	FD9CD5	4042 494461	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva-27021964@postgrespro.ru", "phone": "+70408416424"}
0005432666393	FD9CD5	7609 845062	VALERIY PETROV	{"phone": "+70365868312"}
0005432666394	0246E9	1564 947974	RUSLAN VASILEV	{"phone": "+70126009151"}
0005432666395	9C5846	4765 879164	ZOYA KONDRATEVA	{"email": "zoya_kondrateva-021969@postgrespro.ru", "phone": "+70437242188"}
0005432666396	19A51C	5099 904110	ALEKSANDR DMITRIEV	{"phone": "+70066934756"}
0005432666397	1D9FA1	7846 453371	VALENTINA MATVEEVA	{"phone": "+70574463948"}
0005432666398	1D9FA1	6487 683187	SOFYA SMIRNOVA	{"phone": "+70715548010"}
0005432666399	B944B4	9641 687997	GALINA LAZAREVA	{"phone": "+70576767744"}
0005432666400	AEDB32	4749 112018	ANTONINA ERMAKOVA	{"email": "antoninaermakova.081968@postgrespro.ru", "phone": "+70327961552"}
0005432666401	74FEF3	2070 811837	OLGA EGOROVA	{"phone": "+70355834167"}
0005432666402	74FEF3	3768 631066	VALERIY KARPOV	{"email": "v.karpov_011983@postgrespro.ru", "phone": "+70614517314"}
0005432666403	3B74C0	6147 076534	ILYA MELNIKOV	{"phone": "+70674133323"}
0005432666404	4129E1	6229 944089	NIKOLAY VOROBEV	{"email": "nikolay.vorobev_06031967@postgrespro.ru", "phone": "+70060555791"}
0005432666405	AD0795	3918 042740	ELLA KOROLEVA	{"email": "ekoroleva.09041980@postgrespro.ru", "phone": "+70217378040"}
0005432666406	AD0795	5063 050282	YURIY SERGEEV	{"phone": "+70620855176"}
0005432666407	AD0795	0721 653313	EKATERINA NIKITINA	{"phone": "+70612300665"}
0005432666408	E9CFD8	8966 848731	KLAVDIYA AFANASEVA	{"email": "k_afanaseva25101962@postgrespro.ru", "phone": "+70386215094"}
0005432666409	E9CFD8	4653 567035	DANIS IVANOV	{"email": "danis-ivanov111979@postgrespro.ru", "phone": "+70883964193"}
0005432666410	B140B2	4294 286656	VERA ZAYCEVA	{"email": "zayceva_vera1980@postgrespro.ru", "phone": "+70101984475"}
0005432666411	09DE70	0927 134340	VLADIMIR ZAYCEV	{"email": "vladimirzaycev.09081973@postgrespro.ru", "phone": "+70122340108"}
0005432666412	8D1388	7794 030076	GALINA ZAYCEVA	{"phone": "+70607221175"}
0005432666413	CE992C	1096 445712	VLADIMIR MELNIKOV	{"email": "v_melnikov_071962@postgrespro.ru", "phone": "+70715935284"}
0005432666414	FB5605	0419 347273	VYACHESLAV SEMENOV	{"email": "semenovvyacheslav30081967@postgrespro.ru", "phone": "+70324469358"}
0005432666415	7DC010	2956 951961	NATALYA BORISOVA	{"email": "borisova-natalya.111974@postgrespro.ru", "phone": "+70844974171"}
0005432666416	DDD349	5356 580239	ALEKSEY BARANOV	{"phone": "+70530530026"}
0005432666417	999EB6	5098 697908	YULIYA SOKOLOVA	{"email": "sokolova.yuliya.051987@postgrespro.ru", "phone": "+70321871627"}
0005432666418	999EB6	8757 287649	YULIYA NAUMOVA	{"email": "naumova-yuliya-1973@postgrespro.ru", "phone": "+70191704611"}
0005432666419	F0484D	7012 972133	BORIS KUDRYASHOV	{"email": "kudryashovb-1976@postgrespro.ru", "phone": "+70006076832"}
0005432666420	D24797	3787 802118	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr_1970@postgrespro.ru", "phone": "+70921107398"}
0005432666421	D24797	5741 441833	YURIY IVANOV	{"email": "y-ivanov_13091963@postgrespro.ru", "phone": "+70744642569"}
0005432666422	D52B9E	2357 817477	EKATERINA FILATOVA	{"email": "filatova-e.18041963@postgrespro.ru", "phone": "+70434280003"}
0005432666423	43B7F1	4287 690410	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova.22121966@postgrespro.ru", "phone": "+70114986520"}
0005432666424	682AB9	5277 626094	KONSTANTIN MOROZOV	{"email": "morozov_k-16011970@postgrespro.ru", "phone": "+70393790613"}
0005432666425	682AB9	6705 805296	MARINA IVANOVA	{"email": "ivanova-m041976@postgrespro.ru", "phone": "+70867649713"}
0005432666426	682AB9	1000 979672	VLADIMIR VOLKOV	{"email": "vladimir-volkov1960@postgrespro.ru", "phone": "+70452013035"}
0005432666427	FFC1E6	0588 085430	ALEKSANDR GAVRILOV	{"phone": "+70456406446"}
0005432666428	FFC1E6	0991 253629	ALEKSANDR MAKSIMOV	{"phone": "+70536998891"}
0005432666429	56A46F	4495 670072	KLAVDIYA DMITRIEVA	{"email": "dmitrieva_klavdiya.14091973@postgrespro.ru", "phone": "+70545423447"}
0005432666430	CEED21	4911 620991	ALEKSANDRA KALININA	{"phone": "+70667539272"}
0005432666431	C256CE	7609 695350	ELENA TIKHONOVA	{"phone": "+70561845517"}
0005432666432	D5DFC3	5693 373241	NIKOLAY POPOV	{"email": "n.popov_24091972@postgrespro.ru", "phone": "+70414811568"}
0005432666433	D5DFC3	1192 318494	IGOR GRIGOREV	{"phone": "+70917243518"}
0005432666434	D9866E	9849 131962	DMITRIY KRASNOV	{"email": "dmitriykrasnov1978@postgrespro.ru", "phone": "+70224709734"}
0005432666435	799A91	7749 265893	SVETLANA AFANASEVA	{"phone": "+70502907638"}
0005432666436	A09853	0494 882552	GALINA KRASNOVA	{"email": "krasnova-galina_02081980@postgrespro.ru", "phone": "+70575992007"}
0005432666437	F0425B	2096 465211	ANDREY SIDOROV	{"phone": "+70149276551"}
0005432666438	F0425B	3795 374586	DANIIL GAVRILOV	{"email": "daniil-gavrilov_13101974@postgrespro.ru", "phone": "+70874309681"}
0005432666439	940485	6329 987676	VENIAMIN ALEKSANDROV	{"phone": "+70468083131"}
0005432666440	5FD3BB	8011 904375	TATYANA BORISOVA	{"phone": "+70656982460"}
0005432666441	1E03E8	9590 733685	PAVEL ORLOV	{"phone": "+70909246134"}
0005432666442	7EB736	2751 523807	KIRILL MELNIKOV	{"phone": "+70896039522"}
0005432666443	8696A9	7792 287813	DMITRIY ALEKSANDROV	{"phone": "+70482922254"}
0005432666444	21114F	7233 536330	LIDIYA SEMENOVA	{"email": "lsemenova_1977@postgrespro.ru", "phone": "+70572095636"}
0005432666445	21114F	9808 509751	VIKTORIYA FOMINA	{"phone": "+70429978913"}
0005432666446	21114F	9534 091061	YURIY STEPANOV	{"email": "yuriystepanov1972@postgrespro.ru", "phone": "+70299502171"}
0005432666447	C67F10	4452 024739	ALEKSANDR ILIN	{"email": "ailin-11021976@postgrespro.ru", "phone": "+70685725887"}
0005432666448	C67F10	4618 851016	PRASKOVYA TARASOVA	{"phone": "+70893285784"}
0005432666449	98977E	6032 024125	ULYANA POLYAKOVA	{"email": "ulyana.polyakova.04041984@postgrespro.ru", "phone": "+70169951000"}
0005432666450	833DE6	3841 485558	KONSTANTIN TIKHONOV	{"email": "konstantintikhonov.1965@postgrespro.ru", "phone": "+70973983252"}
0005432667448	E27B16	0819 188649	NINA SERGEEVA	{"phone": "+70837846757"}
0005432667418	CE1AC9	4681 506189	ALEKSANDRA KONOVALOVA	{"email": "a-konovalova-1965@postgrespro.ru", "phone": "+70766584593"}
0005432667419	BB4336	8201 973749	NATALYA ALEKSANDROVA	{"email": "aleksandrova.n.061972@postgrespro.ru", "phone": "+70923186462"}
0005432667420	319DAF	8220 997472	SVETLANA KOLESNIKOVA	{"email": "kolesnikovasvetlana041973@postgrespro.ru", "phone": "+70524471697"}
0005432667421	5D102B	4809 644018	STEPAN SOROKIN	{"phone": "+70028758583"}
0005432667422	5D102B	1468 596782	EVGENIY BELOV	{"phone": "+70436892384"}
0005432667423	13AC6C	3117 309570	LYUDMILA BORISOVA	{"phone": "+70814346989"}
0005432667424	164706	0389 167757	TATYANA KOLESNIKOVA	{"email": "kolesnikova.tatyana-13071973@postgrespro.ru", "phone": "+70689613173"}
0005432667425	164706	8703 308876	YURIY NAZAROV	{"phone": "+70090695482"}
0005432667426	2A7049	5359 824151	ELENA GORBUNOVA	{"email": "gorbunova_e_1969@postgrespro.ru", "phone": "+70641152737"}
0005432667427	2A7049	8929 386900	EKATERINA NIKIFOROVA	{"phone": "+70518137763"}
0005432667428	CB70BA	9076 027377	ANTONINA KOZLOVA	{"email": "kozlova-a24011980@postgrespro.ru", "phone": "+70977845095"}
0005432667429	E86DA6	9258 013127	OLGA MATVEEVA	{"email": "olga.matveeva-11101972@postgrespro.ru", "phone": "+70684697855"}
0005432667430	93ADA7	4199 866866	KSENIYA GUSEVA	{"email": "guseva-k1970@postgrespro.ru", "phone": "+70200886419"}
0005432667431	93ADA7	2939 757001	KSENIYA MEDVEDEVA	{"email": "medvedeva.kseniya.021972@postgrespro.ru", "phone": "+70801030069"}
0005432667432	283598	6102 818971	YULIYA MOROZOVA	{"phone": "+70398129274"}
0005432667433	283598	1610 368866	VALENTINA IVANOVA	{"email": "valentina-ivanova.091975@postgrespro.ru", "phone": "+70080735032"}
0005432667434	CB7550	9240 644673	VALENTINA VOROBEVA	{"phone": "+70337421711"}
0005432667435	709723	9736 345830	PAVEL MAKAROV	{"phone": "+70855359759"}
0005432667436	709723	7138 948023	VITALIY TARASOV	{"phone": "+70468589536"}
0005432667437	191797	9425 185326	VIKTOR GUSEV	{"phone": "+70146363486"}
0005432667438	191797	9744 216991	VALENTINA TITOVA	{"phone": "+70780332622"}
0005432667439	5FC5D8	4332 486314	YURIY CHERNOV	{"phone": "+70461895892"}
0005432667440	9C1656	3829 727815	BORIS NIKOLAEV	{"email": "boris_nikolaev-041971@postgrespro.ru", "phone": "+70782442505"}
0005432667441	95FD6B	4244 731428	YURIY OSIPOV	{"phone": "+70125569765"}
0005432667442	62A78A	0367 678784	VALERIY KUZNECOV	{"phone": "+70938915006"}
0005432667443	4054FD	4337 056803	SVETLANA ERMAKOVA	{"email": "svetlanaermakova_1981@postgrespro.ru", "phone": "+70351832932"}
0005432667444	B7D644	7036 534317	ALEKSEY MIRONOV	{"phone": "+70849486810"}
0005432667445	D87624	2070 302899	IRINA NAUMOVA	{"email": "i_naumova_18091976@postgrespro.ru", "phone": "+70899603629"}
0005432667446	D87624	7684 069123	NIKOLAY KULIKOV	{"phone": "+70423575798"}
0005432667447	6B4726	4825 114992	ELENA ZAYCEVA	{"email": "elena_zayceva.021967@postgrespro.ru", "phone": "+70150627358"}
0005432667449	E27B16	6680 990139	YAROSLAV KRASNOV	{"phone": "+70515186339"}
0005432667450	EEF17C	0456 274417	VALENTINA ALEKSANDROVA	{"email": "aleksandrovav1972@postgrespro.ru", "phone": "+70765201928"}
0005432667451	97F9D0	1454 937128	SERGEY MAKAROV	{"phone": "+70250072275"}
0005432667452	97F9D0	5869 528450	EGOR DENISOV	{"email": "denisov_e.011962@postgrespro.ru", "phone": "+70023710808"}
0005432667453	897953	3318 988343	TATYANA OSIPOVA	{"phone": "+70116403846"}
0005432667454	2380FF	7034 726573	IVAN ROMANOV	{"phone": "+70280076054"}
0005432667455	2380FF	3936 630749	OLGA SEMENOVA	{"phone": "+70054341492"}
0005432667456	8CDDBB	1659 929977	LYUDMILA NESTEROVA	{"email": "nesterova.l_111964@postgrespro.ru", "phone": "+70039027907"}
0005432667457	70F61B	8427 247055	ALEKSEY BORISOV	{"phone": "+70082665001"}
0005432667458	7DC935	9924 413314	DAMIR KUZNECOV	{"email": "kuznecov-damir041975@postgrespro.ru", "phone": "+70011379528"}
0005432667459	83C7C4	1079 960653	ANNA YAKOVLEVA	{"phone": "+70181730795"}
0005432667460	609E12	5941 832961	GALINA ORLOVA	{"email": "orlova-g.011959@postgrespro.ru", "phone": "+70262623253"}
0005432667461	609E12	6586 231627	VLADIMIR FEDOTOV	{"phone": "+70096171200"}
0005432667462	9E1BC0	4270 313988	TAMARA KONOVALOVA	{"email": "konovalova-tamara.21121977@postgrespro.ru", "phone": "+70170571121"}
0005432667463	9E1BC0	0442 247139	IRINA KOROLEVA	{"phone": "+70538326998"}
0005432667464	63E7E2	9888 639733	VALENTINA CHERNOVA	{"email": "chernova.v1964@postgrespro.ru", "phone": "+70349045319"}
0005432667465	FD52FC	6733 396002	SERGEY ZAKHAROV	{"phone": "+70120888910"}
0005432667466	C62B5F	8677 085398	RAISA LUKYANOVA	{"phone": "+70514120168"}
0005432667467	E0653C	2381 332427	TATYANA MAKSIMOVA	{"phone": "+70202119669"}
0005432667468	E0653C	5668 840355	ANDREY ISAEV	{"phone": "+70072616207"}
0005432667469	F7C339	0533 376911	IRINA MIKHAYLOVA	{"phone": "+70501890247"}
0005432667470	F7C339	3247 029451	RAISA POTAPOVA	{"email": "potapova-raisa12011983@postgrespro.ru", "phone": "+70794022787"}
0005432667471	F5FBAF	7909 294000	VIKTOR TIKHONOV	{"email": "viktor.tikhonov.01111983@postgrespro.ru", "phone": "+70920123000"}
0005432667472	F5FBAF	8904 766766	EKATERINA MIRONOVA	{"phone": "+70442894340"}
0005432667473	E38B52	1670 111066	ANASTASIYA SERGEEVA	{"phone": "+70473520695"}
0005432667474	27F1C1	1350 440929	VYACHESLAV FILIPPOV	{"email": "v.filippov.091964@postgrespro.ru", "phone": "+70567384219"}
0005432667475	27F1C1	0753 800303	ELENA PAVLOVA	{"phone": "+70695189073"}
0005432667476	972FAC	4257 021934	ELENA VOROBEVA	{"email": "e.vorobeva_031977@postgrespro.ru", "phone": "+70144168818"}
0005432667477	B6F528	9387 085393	NIKITA VASILEV	{"email": "vasilev_n_121970@postgrespro.ru", "phone": "+70702038287"}
0005432667478	EEC7B0	9202 672905	SERGEY SOROKIN	{"phone": "+70249547156"}
0005432667479	720F0E	5312 212512	DANIIL ILIN	{"email": "ilin-d-27061969@postgrespro.ru", "phone": "+70597903101"}
0005432667480	C25970	0068 149265	ALEKSANDRA FADEEVA	{"email": "fadeevaa-06061964@postgrespro.ru", "phone": "+70472148427"}
0005432667481	62C9CD	7308 140248	LYUDMILA BELOVA	{"phone": "+70814819820"}
0005432667482	62C9CD	8190 874259	ELENA ZHURAVLEVA	{"phone": "+70643792163"}
0005432667483	D95A52	0797 801715	ALEKSANDR SOROKIN	{"phone": "+70045626395"}
0005432667484	1CAB62	1531 630094	RAISA KOVALEVA	{"email": "kovaleva.raisa_03071978@postgrespro.ru", "phone": "+70376824602"}
0005432667485	1CAB62	4070 805145	VIKTOR ILIN	{"email": "v_ilin_1961@postgrespro.ru", "phone": "+70000656636"}
0005432667486	33A86C	0485 504263	VLADIMIR ANTONOV	{"email": "antonov.v-041965@postgrespro.ru", "phone": "+70549283478"}
0005432667487	C38A36	3474 142003	VLADIMIR ALEKSEEV	{"phone": "+70751451664"}
0005432667488	FD0D48	8086 803831	TATYANA KALININA	{"email": "tkalinina08021967@postgrespro.ru", "phone": "+70388373599"}
0005432667489	CE0E26	3479 249473	MARIYA NIKOLAEVA	{"phone": "+70559895807"}
0005432667490	D08F19	5383 750585	ARTEM MEDVEDEV	{"phone": "+70405414981"}
0005432667491	1C6A53	7921 624448	YULIYA KUZNECOVA	{"email": "y.kuznecova1978@postgrespro.ru", "phone": "+70731175738"}
0005432667492	00D0A0	7395 788525	DARYA FROLOVA	{"phone": "+70911433206"}
0005432667493	00D0A0	0830 789012	IVAN KUZNECOV	{"email": "i.kuznecov-051971@postgrespro.ru", "phone": "+70439999876"}
0005432667494	00D0A0	7814 155309	YURIY MAKSIMOV	{"phone": "+70963670129"}
0005432667495	B115BF	0560 067025	DENIS MAKAROV	{"phone": "+70141421365"}
0005432667496	F5AC73	9241 967708	TATYANA ZOTOVA	{"email": "t_zotova_1977@postgrespro.ru", "phone": "+70814488867"}
0005432667497	0E8A1A	1446 789949	VASILIY PETROV	{"email": "vpetrov_1966@postgrespro.ru", "phone": "+70930273238"}
0005432667498	D9A3F0	8269 968773	LEV DAVYDOV	{"phone": "+70048543008"}
0005432667499	D9A3F0	2443 122643	ALEKSANDR MAKAROV	{"phone": "+70265628000"}
0005432667500	8F1EC2	6890 264648	PAVEL VASILEV	{"phone": "+70025679991"}
0005432667501	0CCEBC	8979 057371	YURIY SOLOVEV	{"email": "solovev_yuriy_27011971@postgrespro.ru", "phone": "+70235182489"}
0005432667502	0CCEBC	7176 861814	OLGA STEPANOVA	{"email": "stepanova.olga-15051960@postgrespro.ru", "phone": "+70000001406"}
0005432667503	0CCEBC	7799 101552	KLAVDIYA ALEKSANDROVA	{"email": "aleksandrova.klavdiya_1967@postgrespro.ru", "phone": "+70203571394"}
0005432667504	6F75A4	5038 024483	ALEKSANDR SOROKIN	{"email": "sorokina05031976@postgrespro.ru", "phone": "+70309205939"}
0005432667505	6F75A4	3929 664793	ALEKSANDR TIMOFEEV	{"email": "timofeeva.1967@postgrespro.ru", "phone": "+70881858935"}
0005432667506	22E1D5	4866 600665	SERGEY SERGEEV	{"phone": "+70091583949"}
0005432667507	22E1D5	9295 226323	ALEKSANDR MARTYNOV	{"phone": "+70607615477"}
0005432667508	CE66BA	5355 740142	SVETLANA AFANASEVA	{"phone": "+70086605974"}
0005432667509	E768D3	0618 337060	LYUDMILA KOZLOVA	{"phone": "+70957283838"}
0005432667510	F00147	2525 437192	VALENTINA VLASOVA	{"phone": "+70325064405"}
0005432667511	CFFDD2	5814 515100	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov_16021974@postgrespro.ru", "phone": "+70978635963"}
0005432667512	18452F	8314 772322	VALENTINA OSIPOVA	{"phone": "+70677656927"}
0005432667513	B59E7C	7486 124306	YULIYA BELOVA	{"phone": "+70479821174"}
0005432667514	B59E7C	5211 136011	DENIS FEDOROV	{"phone": "+70220861791"}
0005432667515	E71DE8	5899 897408	SERGEY PAVLOV	{"email": "pavlov-sergey.1977@postgrespro.ru", "phone": "+70367138467"}
0005432667516	E71DE8	8931 250213	ALEKSANDR STEPANOV	{"email": "stepanov-a_121965@postgrespro.ru", "phone": "+70635669205"}
0005432674863	3ECECE	2921 237669	LEONID GAVRILOV	{"email": "gavrilov.leonid.03071977@postgrespro.ru", "phone": "+70693231757"}
0005432674864	3ECECE	2030 364786	NINA EGOROVA	{"email": "egorova.nina.031973@postgrespro.ru", "phone": "+70763535877"}
0005432674865	3A8B5E	9789 573355	ANGELINA SERGEEVA	{"email": "sergeevaa.101967@postgrespro.ru", "phone": "+70287764548"}
0005432674866	DEB659	0700 330430	MARTA BORISOVA	{"email": "martaborisova1970@postgrespro.ru", "phone": "+70722074983"}
0005432674867	DEB659	9235 829512	LYUDMILA SAVELEVA	{"phone": "+70815326833"}
0005432674868	EED1EC	8858 434591	YULIYA KUZNECOVA	{"phone": "+70065629887"}
0005432674869	A5C9A8	2983 407121	NIKOLAY CHERNOV	{"phone": "+70076007539"}
0005432674870	A77938	3914 980977	VYACHESLAV MAKAROV	{"email": "vyacheslav-makarov.101968@postgrespro.ru", "phone": "+70051150678"}
0005432674871	F19F10	0303 246579	MIKHAIL VOLKOV	{"phone": "+70536963524"}
0005432674872	07292F	0919 572396	ZHANNA AKIMOVA	{"email": "zakimova.051970@postgrespro.ru", "phone": "+70232736490"}
0005432674873	CDAE28	8722 223396	NADEZHDA KRASNOVA	{"phone": "+70493245780"}
0005432674874	CDAE28	4234 699496	LYUDMILA LUKYANOVA	{"email": "lukyanova_l-1983@postgrespro.ru", "phone": "+70416757263"}
0005432674875	248010	7139 097746	ALEKSANDR ANTONOV	{"email": "antonovaleksandr_25021971@postgrespro.ru", "phone": "+70910486280"}
0005432674876	89A03D	8317 639279	NATALYA TIMOFEEVA	{"phone": "+70211855756"}
0005432674877	89A03D	5408 308417	ANDREY KOZLOV	{"email": "kozlov-a10081979@postgrespro.ru", "phone": "+70320092923"}
0005432674878	66F274	0278 869544	MIKHAIL PAVLOV	{"email": "pavlov_m_27021966@postgrespro.ru", "phone": "+70685902732"}
0005432674879	66F274	0989 438851	ANDREY SHEVCHENKO	{"email": "a_shevchenko.08011971@postgrespro.ru", "phone": "+70214972652"}
0005432674880	66F274	4557 261858	ZOYA VASILEVA	{"email": "zvasileva011974@postgrespro.ru", "phone": "+70237848798"}
0005432674881	9B117F	4764 602100	ELENA IVANOVA	{"phone": "+70501009164"}
0005432674882	9B117F	3901 407528	ELENA KUZNECOVA	{"email": "kuznecovae_30101966@postgrespro.ru", "phone": "+70980807127"}
0005432674883	A0E3E9	8685 949154	YAKOV NAZAROV	{"phone": "+70580143320"}
0005432674884	A0E3E9	1735 383789	LYUDMILA MEDVEDEVA	{"email": "lyudmila.medvedeva1976@postgrespro.ru", "phone": "+70428461815"}
0005432674885	C34125	0532 782065	VLADIMIR FEDOTOV	{"email": "fedotovv081974@postgrespro.ru", "phone": "+70326165402"}
0005432674886	C34125	4705 195474	DANIIL BARANOV	{"phone": "+70362767153"}
0005432674887	7E38FF	0997 392604	VASILIY KULIKOV	{"phone": "+70360148364"}
0005432674888	90E6EA	4839 275668	ELENA YAKOVLEVA	{"phone": "+70770774758"}
0005432674889	2A838F	4778 904112	TATYANA BARANOVA	{"phone": "+70433392014"}
0005432674890	A72C37	4373 384770	ALEKSANDR YAKOVLEV	{"phone": "+70283449574"}
0005432674891	E7FB17	1008 180898	ELENA KONDRATEVA	{"phone": "+70696865180"}
0005432674892	E7FB17	4702 488261	DENIS SERGEEV	{"email": "denis_sergeev.28011981@postgrespro.ru", "phone": "+70957390344"}
0005432674893	2167BE	1700 251916	NATALYA ALEKSANDROVA	{"phone": "+70229894918"}
0005432674894	DDDFC2	2710 120641	SERGEY SHEVCHENKO	{"phone": "+70508788968"}
0005432674895	B5EFA1	0202 350497	VYACHESLAV SERGEEV	{"email": "sergeev.v.1957@postgrespro.ru", "phone": "+70629263358"}
0005432674896	DD3BED	5529 862210	ELENA MOROZOVA	{"phone": "+70727683413"}
0005432674897	DD3BED	2780 031958	LYUDMILA IVANOVA	{"phone": "+70464511167"}
0005432674898	A68389	3261 824649	SERGEY FEDOROV	{"phone": "+70700725622"}
0005432674899	9D5BFA	7815 230957	TATYANA POPOVA	{"email": "t.popova.1987@postgrespro.ru", "phone": "+70954908671"}
0005432674900	9D5BFA	3000 158495	KSENIYA ILINA	{"email": "ilina_k_061981@postgrespro.ru", "phone": "+70539949106"}
0005432674901	77CC34	0350 039890	NIKOLAY EGOROV	{"phone": "+70114216193"}
0005432674902	77CC34	5042 752966	VALENTINA DAVYDOVA	{"phone": "+70388844947"}
0005432674903	1591E3	2890 624369	VALENTINA FEDOROVA	{"email": "valentinafedorova-041963@postgrespro.ru", "phone": "+70932848662"}
0005432674904	F7416F	0108 278406	ALEKSANDR FROLOV	{"phone": "+70394226737"}
0005432674905	F7416F	4439 446456	KRISTINA TARASOVA	{"phone": "+70167699019"}
0005432674906	5503C0	0945 568979	ALINA ROMANOVA	{"phone": "+70161124658"}
0005432674907	6FD018	2701 025775	ANASTASIYA VOROBEVA	{"phone": "+70967645164"}
0005432674908	6FD018	0459 226546	KSENIYA IVANOVA	{"phone": "+70772395375"}
0005432674909	E308F1	0585 433927	RUSTAM SOKOLOV	{"email": "rustamsokolov.111966@postgrespro.ru", "phone": "+70681462576"}
0005432674910	6F6668	9871 258083	VYACHESLAV BELOV	{"email": "belov.vyacheslav1978@postgrespro.ru", "phone": "+70937099933"}
0005432674911	6F6668	3993 843192	DARYA SMIRNOVA	{"phone": "+70388330440"}
0005432674912	58571E	7115 784082	ALEKSEY VOLKOV	{"email": "a.volkov.121963@postgrespro.ru", "phone": "+70524379124"}
0005432674913	81F7BC	0633 863715	ANTON SOKOLOV	{"phone": "+70739830213"}
0005432674914	81F7BC	3624 499887	ANTONINA BELYAEVA	{"phone": "+70906478726"}
0005432674915	EA53C0	6265 600654	VLADIMIR PAVLOV	{"email": "vladimirpavlov_1966@postgrespro.ru", "phone": "+70144746248"}
0005432674916	EA53C0	2056 079312	VLADIMIR KUZNECOV	{"email": "kuznecov-v101977@postgrespro.ru", "phone": "+70005972533"}
0005432674917	B09986	0194 945614	NIKOLAY ALEKSEEV	{"email": "nikolay.alekseev1969@postgrespro.ru", "phone": "+70317960807"}
0005432674918	43A990	4938 265898	MARIYA PETROVA	{"email": "petrova.m.011979@postgrespro.ru", "phone": "+70065834871"}
0005432674919	2B7399	0651 533799	DMITRIY ABRAMOV	{"email": "dmitriy.abramov_111977@postgrespro.ru", "phone": "+70519573670"}
0005432674920	DEEB0E	4496 629961	IRINA VASILEVA	{"email": "vasilevai-13051976@postgrespro.ru", "phone": "+70137232916"}
0005432674921	C384CB	7928 386503	DMITRIY KONOVALOV	{"email": "konovalov-d081964@postgrespro.ru", "phone": "+70486644454"}
0005432674922	9F2D2C	6335 873128	VALENTINA TROFIMOVA	{"phone": "+70882154837"}
0005432674923	A76F89	9455 500469	VERA BARANOVA	{"email": "baranova-v.21081967@postgrespro.ru", "phone": "+70976194942"}
0005432674924	E16978	0006 966077	GALINA KUDRYASHOVA	{"email": "kudryashova.g.28091979@postgrespro.ru", "phone": "+70805186313"}
0005432674925	638CC3	3891 339236	MAKSIM PETROV	{"phone": "+70122949241"}
0005432674926	F881C0	8510 135224	VALENTINA ZHURAVLEVA	{"phone": "+70000515160"}
0005432674927	58FD5D	7778 396184	NIKOLAY SHEVCHENKO	{"email": "n_shevchenko.29061972@postgrespro.ru", "phone": "+70671540915"}
0005432674928	8CF9BD	2909 404773	ALEKSEY NOVIKOV	{"phone": "+70171855466"}
0005432674929	EA4BC3	2796 598807	RAISA NOVIKOVA	{"email": "raisa-novikova_1983@postgrespro.ru", "phone": "+70450224810"}
0005432674930	EA4BC3	2713 417957	EVGENIY ORLOV	{"email": "evgeniyorlov061969@postgrespro.ru", "phone": "+70467199265"}
0005432674931	10B8FB	6741 156487	ZOYA SERGEEVA	{"email": "zoya.sergeeva091964@postgrespro.ru", "phone": "+70875632942"}
0005432674932	72949B	3485 686616	VALENTINA FEDOROVA	{"email": "valentina_fedorova.1976@postgrespro.ru", "phone": "+70412297787"}
0005432674933	E50088	8008 392986	EKATERINA SOLOVEVA	{"email": "e.soloveva.1971@postgrespro.ru", "phone": "+70713618562"}
0005432674934	6A225D	3986 299133	NADEZHDA BOGDANOVA	{"phone": "+70958480430"}
0005432674935	C423D0	5405 722155	TAMARA TIKHONOVA	{"email": "tikhonova_t_09111965@postgrespro.ru", "phone": "+70655186187"}
0005432674936	B195A8	5398 619743	OLGA ZOTOVA	{"phone": "+70451425355"}
0005432674937	B195A8	3496 856078	ELENA ARKHIPOVA	{"phone": "+70449625689"}
0005432674938	A9622A	7539 614681	OLGA NESTEROVA	{"phone": "+70782375287"}
0005432674939	5C9FE4	1744 760927	MARINA KALININA	{"phone": "+70227907442"}
0005432674940	5C9FE4	0340 843507	IRINA OVCHINNIKOVA	{"email": "ovchinnikova_i_091973@postgrespro.ru", "phone": "+70491083099"}
0005432674941	D3D9FB	5979 056651	PAVEL TARASOV	{"phone": "+70945858777"}
0005432674942	45BE93	1874 555962	VLADIMIR SOLOVEV	{"phone": "+70120719680"}
0005432674943	6756A1	6051 165516	VYACHESLAV PETROV	{"phone": "+70809445595"}
0005432674944	D17222	0096 502946	STANISLAV KUZNECOV	{"phone": "+70576923413"}
0005432674945	83C59B	9024 930366	MARINA SAVELEVA	{"phone": "+70195134389"}
0005432674946	83C59B	6535 649831	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina_1968@postgrespro.ru", "phone": "+70634418476"}
0005432674947	AA24D3	0877 739282	ALEKSEY PETROV	{"email": "a-petrov_121971@postgrespro.ru", "phone": "+70220792217"}
0005432674948	FBBE33	5195 978837	ANNA VASILEVA	{"phone": "+70541862512"}
0005432674949	A04BF2	1137 599924	VITALIY FEDOTOV	{"phone": "+70863142355"}
0005432674950	E4BADC	2756 239541	ELENA ROMANOVA	{"phone": "+70002838606"}
0005432674951	379849	7511 901394	ALEKSANDR FROLOV	{"phone": "+70919287696"}
0005432674952	7992F0	9529 579935	LILIYA FEDOROVA	{"email": "liliya_fedorova-25011975@postgrespro.ru", "phone": "+70469815232"}
0005432674953	7992F0	8369 237270	NIKOLAY ANDREEV	{"phone": "+70304656534"}
0005432674954	C358CB	4546 132328	ANTONINA RYABOVA	{"phone": "+70697030182"}
0005432674955	C358CB	7740 522453	YULIYA ORLOVA	{"phone": "+70890799123"}
0005432674956	D10638	9796 044805	TATYANA MOROZOVA	{"phone": "+70588269785"}
0005432674957	D10638	2583 036598	ROMAN ZHURAVLEV	{"email": "zhuravlev.roman.15091974@postgrespro.ru", "phone": "+70216348114"}
0005432674958	417E0A	8865 889292	OLGA ILINA	{"phone": "+70771060791"}
0005432674959	417E0A	9524 725474	DMITRIY SIDOROV	{"phone": "+70217376690"}
0005432674960	3C53BA	2290 045685	PAVEL SAVELEV	{"email": "pavel-savelev.1971@postgrespro.ru", "phone": "+70810553697"}
0005432674961	3C53BA	3099 464067	EKATERINA AKIMOVA	{"email": "akimovaekaterina.26011971@postgrespro.ru", "phone": "+70720066668"}
0005432674962	7F42A7	9519 165369	VASILIY EGOROV	{"phone": "+70813958596"}
0005432674963	7F42A7	7924 705247	ALIYA GERASIMOVA	{"phone": "+70611615033"}
0005432674964	627694	0243 668357	VALENTINA RYABOVA	{"email": "v_ryabova_1975@postgrespro.ru", "phone": "+70737959439"}
0005432674965	EBBE66	0863 308856	ALEKSANDR SOLOVEV	{"phone": "+70003550211"}
0005432674966	7D8CF1	2216 454662	ALEKSEY SOKOLOV	{"email": "sokolov-a-23081973@postgrespro.ru", "phone": "+70657372416"}
0005432674967	7D8CF1	3933 431370	AZAT CHERNOV	{"email": "achernov.1977@postgrespro.ru", "phone": "+70387351240"}
0005432674968	51AD7E	8096 610754	DANIL KARPOV	{"phone": "+70387088799"}
0005432674969	51AD7E	2023 053105	VYACHESLAV GUSEV	{"email": "gusevvyacheslav-081978@postgrespro.ru", "phone": "+70157776219"}
0005432674970	928ADE	9227 057834	LIDIYA BELOVA	{"phone": "+70154713644"}
0005432674971	55061D	5584 182674	NATALYA MASLOVA	{"phone": "+70393759666"}
0005432674972	818050	8302 791332	FAINA GUSEVA	{"phone": "+70257158977"}
0005432674973	24595F	8575 072239	STANISLAV TARASOV	{"phone": "+70142505428"}
0005432674974	1F5576	2481 371562	DMITRIY MAKAROV	{"phone": "+70810034790"}
0005432674975	1F5576	4375 745459	ELENA MIKHAYLOVA	{"phone": "+70957404136"}
0005432674976	C41EBF	5796 096754	ALEKSANDR SOROKIN	{"email": "sorokin_a_04011966@postgrespro.ru", "phone": "+70787459897"}
0005432674977	C41EBF	0855 480755	ELENA BORISOVA	{"phone": "+70244458856"}
0005432674978	C41EBF	5396 078020	ELIZAVETA NESTEROVA	{"email": "enesterova-1972@postgrespro.ru", "phone": "+70546715586"}
0005432674979	C41EBF	5602 517290	ANTON EGOROV	{"email": "anton.egorov_1976@postgrespro.ru", "phone": "+70489038238"}
0005432674980	CAF56F	9155 396780	ALEKSEY VOROBEV	{"phone": "+70852666913"}
0005432674981	CAF56F	3439 989530	NATALYA MALYSHEVA	{"phone": "+70172125365"}
0005432674982	B9B34F	7457 384149	SVETLANA IVANOVA	{"email": "svetlana_ivanova041977@postgrespro.ru", "phone": "+70119542005"}
0005432674983	11CD23	7374 000829	LYUBOV MELNIKOVA	{"phone": "+70784285057"}
0005432674984	87BC97	7712 560436	ILYA BORISOV	{"email": "i.borisov12091967@postgrespro.ru", "phone": "+70601843447"}
0005432674985	87BC97	1711 794219	ALEKSANDRA VOROBEVA	{"email": "a-vorobeva-1973@postgrespro.ru", "phone": "+70368330084"}
0005432674986	87BC97	1388 500023	IRINA IVANOVA	{"email": "irina_ivanova.1973@postgrespro.ru", "phone": "+70646089611"}
0005432674987	933FB1	2393 503759	NIKITA OSIPOV	{"email": "osipov.nikita-18051968@postgrespro.ru", "phone": "+70335660864"}
0005432674988	63BBAB	8895 561093	EKATERINA MEDVEDEVA	{"email": "medvedeva.e101983@postgrespro.ru", "phone": "+70421276378"}
0005432674989	63BBAB	4725 870489	ELENA PETROVA	{"email": "epetrova_041975@postgrespro.ru", "phone": "+70632130731"}
0005432674990	E5578A	7754 559418	VARVARA MIKHAYLOVA	{"email": "mikhaylova-v20061968@postgrespro.ru", "phone": "+70664802995"}
0005432674991	5FFDA0	7839 571387	LARISA CHERNOVA	{"email": "chernova.l.081983@postgrespro.ru", "phone": "+70098553761"}
0005432674992	1E70D0	0508 749988	MARIYA CHERNOVA	{"phone": "+70972528284"}
0005432674993	DBF3CC	2267 174158	VASILIY KUDRYASHOV	{"email": "v-kudryashov_1972@postgrespro.ru", "phone": "+70604639932"}
0005432674994	DBF3CC	9907 435156	SVETLANA TIKHONOVA	{"phone": "+70860293153"}
0005432674995	A3874B	1127 584036	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_021960@postgrespro.ru", "phone": "+70588198438"}
0005432674996	AE5C2E	5147 322841	ANVAR PAVLOV	{"phone": "+70913663001"}
0005432674997	AE5C2E	6130 730341	EVGENIY NOVIKOV	{"phone": "+70153018556"}
0005432674998	20255C	7066 049125	LYUDMILA PETROVA	{"email": "lyudmila_petrova-051961@postgrespro.ru", "phone": "+70451436451"}
0005432674999	1BA243	8519 881974	SERGEY ALEKSEEV	{"phone": "+70214281299"}
0005432675000	25A60C	0762 515407	ZLATA ANDREEVA	{"email": "andreeva.z-1970@postgrespro.ru", "phone": "+70484763813"}
0005432675001	8E4432	1845 322501	TAMARA ABRAMOVA	{"email": "t.abramova-09121982@postgrespro.ru", "phone": "+70447085904"}
0005432675002	EAAFA0	3224 847969	TATYANA KUDRYASHOVA	{"email": "t.kudryashova-03121964@postgrespro.ru", "phone": "+70169320497"}
0005432675003	EED07B	7964 889979	OLGA OSIPOVA	{"email": "olga-osipova-1974@postgrespro.ru", "phone": "+70200163493"}
0005432675004	EED07B	4882 147348	NINA MIKHAYLOVA	{"email": "mikhaylova_nina_081979@postgrespro.ru", "phone": "+70197761492"}
0005432675005	7AAB0F	6670 829257	BORIS STEPANOV	{"email": "stepanov-b-1966@postgrespro.ru", "phone": "+70033067954"}
0005432675006	266E7E	0508 855909	DMITRIY GUSEV	{"email": "gusevdmitriy.26051974@postgrespro.ru", "phone": "+70368173664"}
0005432675007	266E7E	0213 926561	VLADIMIR VOLKOV	{"phone": "+70257983646"}
0005432675008	A29BC8	5275 593377	VASILIY MOROZOV	{"email": "vmorozov.1967@postgrespro.ru", "phone": "+70866190551"}
0005432675009	A29BC8	0939 686291	SVETLANA DAVYDOVA	{"email": "sdavydova.081975@postgrespro.ru", "phone": "+70079075704"}
0005432675010	E82A4B	9346 310011	SVETLANA GAVRILOVA	{"phone": "+70785750942"}
0005432675011	3C5D56	4379 233738	LARISA IVANOVA	{"phone": "+70942464892"}
0005432675012	0E2536	6512 815679	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy-31101967@postgrespro.ru", "phone": "+70949995438"}
0005432675013	BDBDDE	3486 061669	EVGENIY BONDARENKO	{"email": "e-bondarenko.17031983@postgrespro.ru", "phone": "+70096807043"}
0005432675014	BDBDDE	9249 903978	ELIZAVETA POPOVA	{"email": "elizaveta.popova_051974@postgrespro.ru", "phone": "+70251126905"}
0005432675015	356C52	6364 073094	ALEKSEY ROMANOV	{"email": "romanov.a_1974@postgrespro.ru", "phone": "+70440381399"}
0005432675016	DBC30D	1425 316337	EKATERINA SOLOVEVA	{"phone": "+70384235282"}
0005432675017	ABBB96	1089 257873	LYUBOV FEDOROVA	{"email": "lyubovfedorova-061978@postgrespro.ru", "phone": "+70499318755"}
0005432675018	ABBB96	9966 092041	YURIY NAUMOV	{"email": "yuriynaumov-13051973@postgrespro.ru", "phone": "+70810416651"}
0005432675019	C1F327	4195 672228	ALEKSEY SOKOLOV	{"phone": "+70561819463"}
0005432675020	C1F327	1321 631603	SVETLANA NIKITINA	{"phone": "+70929932553"}
0005432675021	88E070	0204 007428	KONSTANTIN ALEKSEEV	{"email": "k.alekseev-05081975@postgrespro.ru", "phone": "+70043747162"}
0005432675022	4C61DA	3409 873218	NATALYA IVANOVA	{"email": "natalya-ivanova111971@postgrespro.ru", "phone": "+70728243906"}
0005432675023	4C61DA	8062 434726	YURIY YAKOVLEV	{"phone": "+70415270371"}
0005432675024	41042F	3137 350230	MIKHAIL KUDRYASHOV	{"phone": "+70067987427"}
0005432675025	41042F	7468 449540	GALINA KUZNECOVA	{"email": "galinakuznecova_1974@postgrespro.ru", "phone": "+70936566668"}
0005432675026	A93A5E	1468 927119	MARINA MAKAROVA	{"email": "makarova-marina_1968@postgrespro.ru", "phone": "+70978945506"}
0005432675027	C74F9C	0567 117460	VALERIYA KULIKOVA	{"phone": "+70370483576"}
0005432675028	C74F9C	7967 279993	ALEKSANDR FILIPPOV	{"phone": "+70844899044"}
0005432675029	99F207	1690 177876	SERGEY FOMIN	{"email": "s.fomin_1951@postgrespro.ru", "phone": "+70049867625"}
0005432675030	FEF1E3	7025 478780	IRINA KAZAKOVA	{"phone": "+70555280596"}
0005432675031	456EB4	8532 524293	SERGEY NIKITIN	{"email": "nikitinsergey021971@postgrespro.ru", "phone": "+70805276042"}
0005432675032	456EB4	9305 698812	RAFAIL FROLOV	{"phone": "+70646191301"}
0005432675033	C3A446	0479 279594	ILDAR ANDREEV	{"phone": "+70300844350"}
0005432675034	B2AAA2	1819 167394	EKATERINA ALEKSEEVA	{"email": "ealekseeva.061972@postgrespro.ru", "phone": "+70815347642"}
0005432675035	999202	1682 695874	RISHAT POPOV	{"email": "popov-r-051970@postgrespro.ru", "phone": "+70883583285"}
0005432675036	999202	6269 150217	OLGA BELYAEVA	{"phone": "+70966700171"}
0005432675037	320C7F	8770 384424	SERGEY BORISOV	{"email": "sborisov13071965@postgrespro.ru", "phone": "+70788992712"}
0005432675038	320C7F	4296 489868	ARTEM ROMANOV	{"phone": "+70395975369"}
0005432675039	320C7F	2969 457898	ALEKSANDR CHERNOV	{"phone": "+70807435349"}
0005432675040	A81590	0930 144922	VALENTIN ZHURAVLEV	{"email": "v.zhuravlev081969@postgrespro.ru", "phone": "+70183833723"}
0005432675041	1D49B4	2655 245678	VIKTOR ILIN	{"email": "ilin-v30041990@postgrespro.ru", "phone": "+70762220822"}
0005432675042	1D49B4	9912 884132	VITALIY SOLOVEV	{"phone": "+70772931014"}
0005432675043	5800FC	6730 874902	ELENA KOLESNIKOVA	{"phone": "+70545535055"}
0005432675099	5C7F0F	2452 028979	EVGENIY MOROZOV	{"phone": "+70844262374"}
0005432675044	5800FC	6879 844156	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr_1969@postgrespro.ru", "phone": "+70103972818"}
0005432675045	A84311	3967 503640	STEPAN VASILEV	{"phone": "+70836024636"}
0005432675046	A84311	7133 455136	VASILIY KULIKOV	{"phone": "+70763814388"}
0005432675047	E909D0	4633 358635	OLGA ISAEVA	{"phone": "+70920657681"}
0005432675048	E909D0	3564 939912	ARTEM VASILEV	{"email": "vasilev-artem.121966@postgrespro.ru", "phone": "+70466396178"}
0005432675049	8F57E4	7926 744680	ARTEM MOROZOV	{"email": "morozova.1973@postgrespro.ru", "phone": "+70371558118"}
0005432675050	93082A	1342 168697	ELENA LAZAREVA	{"phone": "+70812565598"}
0005432675051	781EBC	2031 440276	VLADISLAV GERASIMOV	{"email": "gerasimovvladislav_081975@postgrespro.ru", "phone": "+70379169341"}
0005432675052	58C3FC	2026 066509	LYUDMILA MALYSHEVA	{"email": "malysheva-l30111975@postgrespro.ru", "phone": "+70898128339"}
0005432675053	869CE2	3944 137012	VLADIMIR ZHURAVLEV	{"phone": "+70163808710"}
0005432675054	869CE2	0237 014815	IVAN ZHURAVLEV	{"email": "zhuravlev_i-071973@postgrespro.ru", "phone": "+70204794076"}
0005432675055	C9033E	2684 598103	ILYA TIKHONOV	{"email": "itikhonov.1978@postgrespro.ru", "phone": "+70870764507"}
0005432675056	6A4D7B	2139 091736	ALEKSANDR ANDREEV	{"email": "a.andreev.20031971@postgrespro.ru", "phone": "+70060919635"}
0005432675057	C2681E	7739 449861	LARISA VOROBEVA	{"phone": "+70681066187"}
0005432675058	C2681E	3585 587522	SERGEY GORBUNOV	{"email": "gorbunov_s.30011980@postgrespro.ru", "phone": "+70496186707"}
0005432675059	B1BDCF	6479 639134	NATALIYA BELOVA	{"phone": "+70543177126"}
0005432675060	B1BDCF	1257 624016	VLADIMIR KOZLOV	{"phone": "+70013642870"}
0005432675061	5CC5DD	4013 428248	VLADIMIR MOROZOV	{"email": "morozovvladimir.25051981@postgrespro.ru", "phone": "+70692249832"}
0005432675062	B15A63	6421 668345	NIKOLAY VASILEV	{"phone": "+70893160000"}
0005432675063	B15A63	1865 249917	TATYANA KOZLOVA	{"email": "kozlova_t17071976@postgrespro.ru", "phone": "+70822100317"}
0005432675064	C3F8E1	1437 651253	NADEZHDA ANTONOVA	{"phone": "+70987530266"}
0005432675065	6E5257	3486 850721	EGOR ZAYCEV	{"email": "egor_zaycev1966@postgrespro.ru", "phone": "+70649090842"}
0005432675066	6E5257	3627 630665	NINA POPOVA	{"email": "ninapopova_1972@postgrespro.ru", "phone": "+70125481603"}
0005432675067	D1D9DC	2822 205147	TAMARA KISELEVA	{"email": "kiseleva-t-19061980@postgrespro.ru", "phone": "+70859239853"}
0005432675068	38E64B	6342 717456	NATALYA FADEEVA	{"email": "fadeeva.natalya.1972@postgrespro.ru", "phone": "+70358990504"}
0005432675069	38E64B	1825 940961	LYUDMILA ALEKSANDROVA	{"phone": "+70654147698"}
0005432675070	649436	6503 134026	IRINA KONDRATEVA	{"email": "kondrateva.irina.101977@postgrespro.ru", "phone": "+70709540373"}
0005432675071	649436	8587 361533	NINA MAKAROVA	{"phone": "+70076856344"}
0005432675072	EC18C1	2800 702183	VYACHESLAV IVANOV	{"phone": "+70272570396"}
0005432675073	56D913	0299 208123	ALEKSANDR ALEKSEEV	{"phone": "+70586874480"}
0005432675074	7DDB05	7130 747404	YURIY KAZAKOV	{"phone": "+70503361953"}
0005432675075	7DDB05	3868 917253	ALEKSEY KUZMIN	{"email": "aleksey-kuzmin1967@postgrespro.ru", "phone": "+70019745999"}
0005432675076	F49875	8770 750198	ALEKSANDR NIKITIN	{"email": "nikitin_a-1962@postgrespro.ru", "phone": "+70935657581"}
0005432675077	25F4A6	5137 619299	SOFYA SOROKINA	{"email": "ssorokina121964@postgrespro.ru", "phone": "+70344786246"}
0005432675078	864A13	9090 340041	ANDREY KOROLEV	{"email": "korolev_andrey-011975@postgrespro.ru", "phone": "+70294517124"}
0005432675079	B390BB	1415 248723	IRINA STEPANOVA	{"email": "stepanova.irina.101983@postgrespro.ru", "phone": "+70730102243"}
0005432675080	7BBFA8	0217 490476	TATYANA CHERNOVA	{"email": "chernovatatyana1977@postgrespro.ru", "phone": "+70582622535"}
0005432675081	7BBFA8	2969 192832	AMINA VLASOVA	{"email": "a_vlasova_021987@postgrespro.ru", "phone": "+70057475825"}
0005432675082	79C76C	2272 465890	ILYA ANDREEV	{"email": "i.andreev_101976@postgrespro.ru", "phone": "+70862164040"}
0005432675083	18D668	3729 937252	NADEZHDA ILINA	{"phone": "+70334182122"}
0005432675084	892321	8752 602104	OLGA KOMAROVA	{"email": "komarovaolga-18121978@postgrespro.ru", "phone": "+70385802134"}
0005432675085	2C25EE	8867 221526	YURIY MELNIKOV	{"email": "melnikov-yuriy-14031974@postgrespro.ru", "phone": "+70776091741"}
0005432675086	2C25EE	3719 666235	DMITRIY EGOROV	{"phone": "+70790198542"}
0005432675087	2CCBA3	9268 530832	OLGA KUDRYASHOVA	{"phone": "+70902530756"}
0005432675088	AB2E7B	1218 150062	TAMARA NAZAROVA	{"email": "tamara.nazarova_08121979@postgrespro.ru", "phone": "+70275834695"}
0005432675089	ABF257	7345 011606	TATYANA FROLOVA	{"email": "t.frolova111973@postgrespro.ru", "phone": "+70861351082"}
0005432675090	ABF257	7379 894935	TAMARA SOROKINA	{"email": "sorokina-t.1976@postgrespro.ru", "phone": "+70054029259"}
0005432675091	CC4241	6863 363909	TATYANA NIKITINA	{"email": "nikitina_tatyana_071979@postgrespro.ru", "phone": "+70366863156"}
0005432675092	2ED3D8	4885 240260	BULAT BARANOV	{"email": "baranov.b101974@postgrespro.ru", "phone": "+70500631629"}
0005432675093	C71BF3	4084 296534	KONSTANTIN VOLKOV	{"phone": "+70615033794"}
0005432675094	A36459	8763 840745	DANILA MAKAROV	{"phone": "+70750010197"}
0005432675095	A36459	2572 444799	ALEKSANDR MOROZOV	{"phone": "+70315426546"}
0005432675096	A36459	2869 970896	VLADIMIR IVANOV	{"phone": "+70101582657"}
0005432675097	F1AB61	5453 185150	KRISTINA DENISOVA	{"email": "denisova.k.1973@postgrespro.ru", "phone": "+70308925393"}
0005432675098	681068	2096 698031	SERGEY KUZNECOV	{"phone": "+70729669393"}
0005432675100	A20212	7410 027215	TAISIYA NESTEROVA	{"phone": "+70991932393"}
0005432675101	A20212	8616 809631	ANATOLIY PETROV	{"email": "anatoliypetrov-1971@postgrespro.ru", "phone": "+70601150267"}
0005432675102	A20212	5434 487237	ANNA DENISOVA	{"phone": "+70296901239"}
0005432675103	0CA298	5098 698474	IRINA PETROVA	{"phone": "+70585515410"}
0005432675104	0CA298	1489 184734	ANNA DAVYDOVA	{"email": "davydova.anna-21011971@postgrespro.ru", "phone": "+70852650792"}
0005432675105	E8CE08	2845 376067	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov.081974@postgrespro.ru", "phone": "+70184180560"}
0005432675106	4DE06E	4434 245113	NIKOLAY KONOVALOV	{"email": "konovalov_nikolay06041970@postgrespro.ru", "phone": "+70817987783"}
0005432675107	6F7AC1	2720 932743	LYUBOV MIKHAYLOVA	{"email": "mikhaylova_lyubov-13121983@postgrespro.ru", "phone": "+70223131573"}
0005432675108	6F7AC1	8715 281192	ANASTASIYA MELNIKOVA	{"email": "anastasiyamelnikova_1972@postgrespro.ru", "phone": "+70584553971"}
0005432675109	76788C	6881 799111	SERGEY FOMIN	{"phone": "+70005413808"}
0005432675110	76788C	4230 799225	ANDREY VASILEV	{"email": "vasileva.15041978@postgrespro.ru", "phone": "+70341386609"}
0005432675111	A52E67	6388 748925	LIDIYA FEDOROVA	{"phone": "+70205028857"}
0005432675112	A52E67	5459 909975	OLGA BARANOVA	{"email": "baranovaolga_21041967@postgrespro.ru", "phone": "+70776656863"}
0005432675113	A52E67	3062 838003	OLEG ALEKSEEV	{"phone": "+70454218336"}
0005432675114	F58229	0604 634783	MARIYA KOZLOVA	{"phone": "+70430133296"}
0005432675115	ADEB93	2362 386939	SERGEY KULIKOV	{"email": "s.kulikov1973@postgrespro.ru", "phone": "+70591538436"}
0005432675116	ADEB93	1138 651617	FEDOR KARPOV	{"phone": "+70400161468"}
0005432675117	CC3DCB	1284 949835	ALEKSANDR VOLKOV	{"email": "volkova_1968@postgrespro.ru", "phone": "+70442314709"}
0005432675118	535788	8777 753487	ALEKSANDR STEPANOV	{"phone": "+70087474650"}
0005432675119	E9A49A	9371 621753	MIKHAIL IVANOV	{"email": "mikhail.ivanov051971@postgrespro.ru", "phone": "+70890395999"}
0005432675120	E9A49A	1214 394711	ALEKSANDR MEDVEDEV	{"email": "medvedev_a-1961@postgrespro.ru", "phone": "+70747543307"}
0005432675121	EC4946	0898 497766	ARTEM MELNIKOV	{"email": "melnikovartem111968@postgrespro.ru", "phone": "+70011839579"}
0005432675122	9F7641	0522 415455	VALENTIN BORISOV	{"phone": "+70572328269"}
0005432675123	F2F2B2	3373 311133	EVGENIY SEMENOV	{"email": "e_semenov06051966@postgrespro.ru", "phone": "+70338215764"}
0005432675124	E3F373	2416 337521	NIKOLAY ZHURAVLEV	{"phone": "+70684818712"}
0005432675125	E3F373	2575 250434	MARIYA KUZMINA	{"email": "mariya-kuzmina-1973@postgrespro.ru", "phone": "+70483739901"}
0005432675126	E1FAC9	1709 793380	ELIZAVETA TROFIMOVA	{"email": "etrofimova.1976@postgrespro.ru", "phone": "+70029238376"}
0005432675127	CDDB2C	9676 172554	MARIYA SOROKINA	{"phone": "+70910752753"}
0005432675128	8A88D2	7988 594995	ALEKSEY DMITRIEV	{"email": "a-dmitriev_1967@postgrespro.ru", "phone": "+70300478984"}
0005432675129	FFC9B9	8361 896871	VLADIMIR PAVLOV	{"email": "vladimirpavlov111975@postgrespro.ru", "phone": "+70699221537"}
0005432675130	4E8A50	8250 434064	OLGA VOLKOVA	{"phone": "+70631368169"}
0005432675131	D44181	7110 306548	VALENTINA PETROVA	{"phone": "+70486475424"}
0005432675132	D44181	9700 037007	ALENA CHERNOVA	{"phone": "+70057399317"}
0005432675133	F5EC35	3423 355424	OLGA PETROVA	{"email": "o-petrova28041983@postgrespro.ru", "phone": "+70626484538"}
0005432675134	09021B	7292 699933	EKATERINA ZAYCEVA	{"email": "ekaterinazayceva_1964@postgrespro.ru", "phone": "+70451318443"}
0005432675135	278818	7898 313312	ZINAIDA LUKYANOVA	{"email": "zinaida_lukyanova-27011964@postgrespro.ru", "phone": "+70977877557"}
0005432675136	DE33AC	7735 281141	IVAN STEPANOV	{"email": "stepanovivan.081972@postgrespro.ru", "phone": "+70558917998"}
0005432675137	BD16CD	7043 103955	RAISA POPOVA	{"email": "rpopova.051971@postgrespro.ru", "phone": "+70311672127"}
0005432675138	CC7FE4	3377 498892	NURIYA ILINA	{"phone": "+70725765980"}
0005432675139	93DBE5	6036 297423	VYACHESLAV OSIPOV	{"phone": "+70384678748"}
0005432675140	93DBE5	5457 411145	DENIS VASILEV	{"email": "denis.vasilev-19021984@postgrespro.ru", "phone": "+70476252111"}
0005432675141	212AF9	5459 900569	KONSTANTIN ABRAMOV	{"email": "konstantin-abramov_021963@postgrespro.ru", "phone": "+70275840905"}
0005432675142	212AF9	8969 888843	IVAN CHERNOV	{"email": "ichernov101976@postgrespro.ru", "phone": "+70209756897"}
0005432675143	63FF50	5033 490625	NATALIYA SOKOLOVA	{"email": "sokolovanataliya_1975@postgrespro.ru", "phone": "+70617011146"}
0005432675144	9DE786	3497 364671	EGOR DAVYDOV	{"email": "egor-davydov_15031970@postgrespro.ru", "phone": "+70463226574"}
0005432675145	CB4018	1638 804670	ALEKSEY BELOV	{"email": "belovaleksey_101974@postgrespro.ru", "phone": "+70303317343"}
0005432675146	CB4018	0096 620960	DMITRIY KUZMIN	{"email": "kuzmindmitriy_1969@postgrespro.ru", "phone": "+70270769369"}
0005432675147	48932D	7760 864354	ALEKSANDRA MAKSIMOVA	{"email": "maksimova_aleksandra15071960@postgrespro.ru", "phone": "+70705657159"}
0005432675148	48932D	5718 977552	NATALYA MIRONOVA	{"phone": "+70960811328"}
0005432675149	7B5CAE	0416 397543	KRISTINA VOLKOVA	{"phone": "+70953758223"}
0005432675150	7B5CAE	0305 335470	ALEKSANDR SEMENOV	{"email": "asemenov_041979@postgrespro.ru", "phone": "+70629375071"}
0005432675151	F1EB2F	7891 985018	VLADIMIR STEPANOV	{"phone": "+70209898850"}
0005432675152	B06C43	8053 549146	VIKTOR FOMIN	{"phone": "+70612862308"}
0005432675153	BCF70E	8010 627293	VALENTINA MASLOVA	{"email": "maslovav_031974@postgrespro.ru", "phone": "+70643414094"}
0005432675154	18AA1B	0910 477146	DMITRIY VASILEV	{"phone": "+70849374064"}
0005432675155	27AA2E	0373 287761	FEDOR FROLOV	{"email": "frolov.fedor.111974@postgrespro.ru", "phone": "+70052192082"}
0005432675156	2F87DE	1350 572565	FANIYA BELOVA	{"email": "fbelova.1973@postgrespro.ru", "phone": "+70728312512"}
0005432675157	8CA78A	6044 210651	ELENA GAVRILOVA	{"email": "elena_gavrilova.07101969@postgrespro.ru", "phone": "+70239156970"}
0005432675158	F13788	1248 307527	LEONID MAKSIMOV	{"phone": "+70178142184"}
0005432675159	B6D8CC	1661 002127	TATYANA PETROVA	{"phone": "+70981912795"}
0005432675160	D2EB67	9754 908796	DANILA NAZAROV	{"email": "nazarov.danila-14021978@postgrespro.ru", "phone": "+70996237903"}
0005432675161	D2EB67	2190 304812	IVAN VASILEV	{"phone": "+70252161680"}
0005432675162	D2EB67	4112 483238	NADEZHDA VOLKOVA	{"phone": "+70534132413"}
0005432675163	C8A29C	4934 568423	PAVEL GERASIMOV	{"phone": "+70033355528"}
0005432675164	C8A29C	6518 038971	VLADIMIR MAKSIMOV	{"email": "maksimov_vladimir07041970@postgrespro.ru", "phone": "+70740543056"}
0005432675165	136DB2	5065 558010	NATALYA KARPOVA	{"phone": "+70354869838"}
0005432675166	136DB2	0882 126281	PELAGEYA KUZNECOVA	{"email": "pelageyakuznecova_1962@postgrespro.ru", "phone": "+70495029005"}
0005432675167	136DB2	5109 550410	EVGENIY NIKITIN	{"email": "evgeniy-nikitin.03031966@postgrespro.ru", "phone": "+70394028118"}
0005432675168	500384	6320 566553	IGOR ZHURAVLEV	{"phone": "+70478149135"}
0005432675169	5D7922	2130 405110	NADEZHDA BORISOVA	{"phone": "+70858344604"}
0005432675170	02414D	4032 772053	ALEKSANDR GUSEV	{"email": "gusev.a-1971@postgrespro.ru", "phone": "+70292832475"}
0005432675171	02414D	9013 300876	LYUBOV YUDINA	{"phone": "+70460667278"}
0005432675172	5325AD	0606 692302	GALINA BELYAEVA	{"phone": "+70413958779"}
0005432675173	2F14BC	0635 087274	NADEZHDA KOVALEVA	{"phone": "+70804814551"}
0005432675174	2F14BC	7876 874506	ARTEM VOLKOV	{"phone": "+70977144821"}
0005432675175	9A01AD	4060 885117	MIKHAIL VOLKOV	{"phone": "+70195158898"}
0005432675176	E1DBCB	2343 121333	GALINA NAUMOVA	{"phone": "+70786959189"}
0005432675177	E1DBCB	8955 887124	LIDIYA KONDRATEVA	{"email": "kondrateva.lidiya.29111960@postgrespro.ru", "phone": "+70870992077"}
0005432675178	079691	7157 450592	GRIGORIY BARANOV	{"email": "grigoriy-baranov-1963@postgrespro.ru", "phone": "+70303825937"}
0005432675179	59E500	2371 853062	MAKSIM TIKHONOV	{"phone": "+70682516526"}
0005432675180	5180E5	0727 232396	EVGENIYA MIRONOVA	{"email": "emironova.16081971@postgrespro.ru", "phone": "+70274126427"}
0005432675181	FF1087	0828 534386	OLEG NIKITIN	{"phone": "+70946643366"}
0005432675182	21C2FD	3890 804451	IRINA OVCHINNIKOVA	{"phone": "+70601567575"}
0005432675183	21C2FD	8484 130417	ALEKSANDR KULIKOV	{"phone": "+70251089776"}
0005432675184	D14143	9878 186305	SERGEY BELOV	{"phone": "+70169521010"}
0005432675185	D14143	8631 560130	TAMARA MASLOVA	{"phone": "+70216717125"}
0005432675186	0C00F1	7062 594437	DENIS ROMANOV	{"phone": "+70611043791"}
0005432675187	0C00F1	7321 065367	ALEKSANDR ALEKSEEV	{"phone": "+70688870407"}
0005432675188	D91EF4	0558 213216	ALISA POTAPOVA	{"email": "alisa-potapova-07051967@postgrespro.ru", "phone": "+70896018586"}
0005432675189	B213B2	7002 299797	ELIZAVETA SEMENOVA	{"phone": "+70759017219"}
0005432675190	939000	4718 099484	NIKOLAY AFANASEV	{"email": "afanasev.n17071965@postgrespro.ru", "phone": "+70760614916"}
0005432675191	939000	7234 862860	EVGENIY MIRONOV	{"email": "mironovevgeniy_31081968@postgrespro.ru", "phone": "+70488539638"}
0005432675192	37BA76	5565 643038	ANTON SOKOLOV	{"phone": "+70179265134"}
0005432675193	1CCDFF	7045 595226	OLGA LEBEDEVA	{"email": "olga_lebedeva_051977@postgrespro.ru", "phone": "+70741875099"}
0005432675194	987DBC	2205 148125	NINA YUDINA	{"phone": "+70229673352"}
0005432675195	987DBC	4134 775431	SOFYA MARTYNOVA	{"email": "martynova.sofya27031980@postgrespro.ru", "phone": "+70579585361"}
0005432675196	29891A	1860 348904	IGOR BARANOV	{"email": "igor_baranov081969@postgrespro.ru", "phone": "+70289721405"}
0005432675197	29891A	3690 497695	VADIM OSIPOV	{"phone": "+70087016390"}
0005432675198	E1A51C	3613 840157	RUSLAN BELOV	{"phone": "+70109890395"}
0005432675199	E1A51C	0456 129213	GALINA OSIPOVA	{"phone": "+70718681506"}
0005432675200	E1A51C	8942 423084	NIKOLAY SAVELEV	{"email": "nikolay_savelev121962@postgrespro.ru", "phone": "+70057413153"}
0005432675201	DA4EF6	4371 245797	ROMAN KRASNOV	{"email": "krasnov.r-1970@postgrespro.ru", "phone": "+70976340911"}
0005432675202	2DBFA2	1206 244260	ZOYA KONOVALOVA	{"email": "konovalovaz1978@postgrespro.ru", "phone": "+70341567572"}
0005432675203	576CA3	3730 199619	EKATERINA MOROZOVA	{"phone": "+70764770241"}
0005432675204	D14077	7921 935980	VLADIMIR KARPOV	{"phone": "+70772338169"}
0005432675205	936005	1458 223043	VERA NAZAROVA	{"phone": "+70076517383"}
0005432675206	572B65	0370 040530	ANDREY SERGEEV	{"email": "andrey-sergeev_051973@postgrespro.ru", "phone": "+70663404741"}
0005432675207	76A26C	4465 518660	VIKTOR KOROLEV	{"phone": "+70026855333"}
0005432675208	5CCB26	8271 430473	LEONTIY GAVRILOV	{"email": "l.gavrilov-021974@postgrespro.ru", "phone": "+70879350827"}
0005432675209	5CCB26	5957 058497	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir_1971@postgrespro.ru", "phone": "+70894674982"}
0005432675210	FCC3BB	8298 680732	IVAN PETROV	{"email": "ivan_petrov-1983@postgrespro.ru", "phone": "+70852885803"}
0005432675211	6E0F1D	6451 593320	DANILA MATVEEV	{"phone": "+70999851802"}
0005432675212	CC2800	1710 916575	MAYYA SMIRNOVA	{"email": "mayya.smirnova.1966@postgrespro.ru", "phone": "+70026349470"}
0005432675213	6F4DD1	8664 831159	LYUDMILA VOLKOVA	{"email": "l_volkova1971@postgrespro.ru", "phone": "+70654896258"}
0005432675214	6F4DD1	1094 687932	LEONID MELNIKOV	{"phone": "+70511104416"}
0005432675215	561B45	6914 206805	VLADIMIR ILIN	{"email": "vladimir_ilin-30031957@postgrespro.ru", "phone": "+70957848388"}
0005432675216	D6741C	5279 546063	ANASTASIYA FADEEVA	{"phone": "+70783710368"}
0005432675217	4FC52A	8984 370584	VALENTIN NIKOLAEV	{"phone": "+70597099668"}
0005432675218	56AB10	3900 468808	ELENA NAZAROVA	{"email": "elena.nazarova20031973@postgrespro.ru", "phone": "+70623868542"}
0005432675219	0E8F15	6404 620956	EVGENIY ROMANOV	{"phone": "+70055271059"}
0005432675220	B106E4	9115 088270	VERA SOROKINA	{"email": "sorokina.v_02071958@postgrespro.ru", "phone": "+70825144688"}
0005432675221	B106E4	1936 793177	MIKHAIL KOROLEV	{"email": "mikhailkorolev_121979@postgrespro.ru", "phone": "+70204507174"}
0005432675222	1A6778	4050 037902	ALEKSANDRA GAVRILOVA	{"email": "aleksandra-gavrilova-081973@postgrespro.ru", "phone": "+70601833372"}
0005432675223	1A6778	2687 277001	EVGENIY CHERNOV	{"email": "echernov_19091971@postgrespro.ru", "phone": "+70307249061"}
0005432675224	E2A138	7158 133402	NATALYA BELOVA	{"phone": "+70724108022"}
0005432675225	2704D2	8125 551957	NATALYA BELOVA	{"email": "belova.n061978@postgrespro.ru", "phone": "+70701655082"}
0005432675226	2704D2	5080 242506	SERGEY GAVRILOV	{"email": "s.gavrilov.21011971@postgrespro.ru", "phone": "+70835363006"}
0005432675227	2E11AB	0590 703141	EKATERINA MAKAROVA	{"email": "ekaterina_makarova_021977@postgrespro.ru", "phone": "+70892044727"}
0005432675228	C6EEDB	4569 973047	IRINA POPOVA	{"phone": "+70464817901"}
0005432675229	C6EEDB	8671 150937	EVGENIY SEMENOV	{"phone": "+70797468462"}
0005432675230	83CCD8	7359 821307	OLGA MOROZOVA	{"email": "morozova.o02041978@postgrespro.ru", "phone": "+70215755753"}
0005432675231	83CCD8	9533 114021	VITALIY KUZNECOV	{"email": "v.kuznecov_1975@postgrespro.ru", "phone": "+70410225718"}
0005432675232	83CCD8	7467 586436	ZLATA BOGDANOVA	{"email": "zlata-bogdanova041967@postgrespro.ru", "phone": "+70852332647"}
0005432675233	AF7738	3649 231647	ANNA FOMINA	{"phone": "+70279429166"}
0005432675234	AF7738	9909 074406	ALEKSANDR SHEVCHENKO	{"phone": "+70840682229"}
0005432675235	7076D9	5749 779050	NADEZHDA SMIRNOVA	{"phone": "+70668199177"}
0005432675236	44283C	0691 673195	IRINA ANISIMOVA	{"phone": "+70426236908"}
0005432675237	44283C	8126 536831	ALINA ZHURAVLEVA	{"phone": "+70409496761"}
0005432675238	47D014	9564 827204	GRIGORIY MAKAROV	{"phone": "+70702389923"}
0005432675239	EE9158	2701 900352	ALEKSANDR ISAEV	{"phone": "+70401376183"}
0005432675240	EE9158	1784 552858	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova.17061980@postgrespro.ru", "phone": "+70285622383"}
0005432675241	16EFA4	3701 060998	NATALYA ISAEVA	{"phone": "+70321625193"}
0005432675242	9C7ACC	6031 811340	NATALYA KISELEVA	{"phone": "+70473210725"}
0005432675243	AB7644	1323 358741	IVAN STEPANOV	{"phone": "+70458842253"}
0005432675244	076989	4813 120421	MARINA GAVRILOVA	{"email": "m-gavrilova_1981@postgrespro.ru", "phone": "+70756565209"}
0005432675245	076989	2641 488326	ANTON ISAEV	{"phone": "+70854040104"}
0005432675246	CCB615	6973 122410	ELENA KISELEVA	{"email": "elena.kiseleva1965@postgrespro.ru", "phone": "+70803912902"}
0005432675247	BD598C	9730 613408	YULIYA NIKOLAEVA	{"email": "nikolaevayuliya-031970@postgrespro.ru", "phone": "+70441673069"}
0005432675248	BD598C	2213 907981	VLADIMIR ZAKHAROV	{"phone": "+70215612423"}
0005432675249	D65B30	5912 599654	GALINA ABRAMOVA	{"phone": "+70505437480"}
0005432675250	D65B30	5397 627390	YULIYA STEPANOVA	{"phone": "+70117554004"}
0005432675251	5608A4	4013 927378	VLADISLAV VASILEV	{"phone": "+70703884005"}
0005432675252	5608A4	4588 482785	VALERIY POPOV	{"email": "popov-valeriy.061968@postgrespro.ru", "phone": "+70898757847"}
0005432675253	96B985	3049 857398	VALENTINA DANILOVA	{"email": "danilova-v121968@postgrespro.ru", "phone": "+70980604793"}
0005432675254	DBE214	8795 155048	YURIY KUDRYASHOV	{"email": "y.kudryashov.13021978@postgrespro.ru", "phone": "+70693728338"}
0005432675255	C32585	8526 141729	RAFAEL EGOROV	{"email": "egorov_r-10051960@postgrespro.ru", "phone": "+70830130563"}
0005432675256	7DEBB7	5568 350376	NINA KULIKOVA	{"phone": "+70493478967"}
0005432675257	7DEBB7	1353 440242	RUSLAN RODIONOV	{"phone": "+70647303902"}
0005432675258	E23B35	1013 828813	ROBERT TARASOV	{"phone": "+70994527183"}
0005432675259	E23B35	1095 041618	OLGA ANDREEVA	{"phone": "+70483586607"}
0005432675260	E23B35	9852 042221	ANATOLIY KONOVALOV	{"phone": "+70900427673"}
0005432675261	C5CDDE	6622 261037	DENIS KISELEV	{"phone": "+70152570160"}
0005432675262	D647E5	7376 457440	IRINA KUZNECOVA	{"email": "kuznecovai_1969@postgrespro.ru", "phone": "+70067876106"}
0005432675263	6D7E16	7491 179823	SERGEY BARANOV	{"phone": "+70910985732"}
0005432675264	69DF3B	2753 954638	ALEKSANDR MOISEEV	{"phone": "+70705184896"}
0005432675265	0AE340	9750 025251	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr_011974@postgrespro.ru", "phone": "+70995920743"}
0005432675266	0AE340	6920 048582	ALEKSEY KOZLOV	{"phone": "+70992935493"}
0005432675267	0AE340	3304 073560	ALEKSANDR FILIPPOV	{"phone": "+70484447495"}
0005432675268	523557	7514 731576	TATYANA TARASOVA	{"email": "tarasova.t_011975@postgrespro.ru", "phone": "+70094081545"}
0005432675269	523557	8976 138008	ELENA POPOVA	{"email": "epopova-1975@postgrespro.ru", "phone": "+70804527760"}
0005432675270	BDB9A6	9672 147138	SERGEY VOROBEV	{"email": "vorobevsergey.17091956@postgrespro.ru", "phone": "+70196201033"}
0005432675271	7C89B3	0277 608656	EVGENIY ROMANOV	{"email": "e_romanov01081971@postgrespro.ru", "phone": "+70713369933"}
0005432675272	7C89B3	8187 056203	EVGENIY SAVELEV	{"phone": "+70087461616"}
0005432675273	99806F	7074 863161	EVGENIY MATVEEV	{"email": "e-matveev06041977@postgrespro.ru", "phone": "+70283157089"}
0005432675274	6126B3	2419 529293	ALENA TIMOFEEVA	{"phone": "+70783513779"}
0005432675275	6126B3	6791 598727	OLGA NAUMOVA	{"phone": "+70425012324"}
0005432675276	177E75	2434 332747	LYUDMILA SERGEEVA	{"email": "sergeeva-l_111961@postgrespro.ru", "phone": "+70863964207"}
0005432675277	177E75	1052 444902	ALEKSANDR VOROBEV	{"phone": "+70292459814"}
0005432675278	CB8E67	1404 924608	ANASTASIYA POLYAKOVA	{"email": "polyakova.anastasiya.29061974@postgrespro.ru", "phone": "+70570485261"}
0005432675279	CB8E67	2179 912154	ANDREY GUSEV	{"phone": "+70033028890"}
0005432675280	A9AC08	7792 379477	LYUDMILA SERGEEVA	{"email": "sergeevalyudmila.091972@postgrespro.ru", "phone": "+70111659404"}
0005432675281	C370A9	4609 490356	ILYA PETROV	{"email": "petrov-ilya_041973@postgrespro.ru", "phone": "+70793984974"}
0005432675282	C370A9	4105 700277	VYACHESLAV TIMOFEEV	{"email": "v_timofeev_16121960@postgrespro.ru", "phone": "+70130838201"}
0005432675283	32F74B	3615 894449	VIKTORIYA EFIMOVA	{"phone": "+70937322964"}
0005432675284	7124D1	4183 209263	VLADIMIR GUSEV	{"phone": "+70127894116"}
0005432675285	9EF4AE	0682 721361	IVAN KISELEV	{"email": "kiselev_i16061975@postgrespro.ru", "phone": "+70809424187"}
0005432675286	06A21F	1339 366211	EVGENIYA EGOROVA	{"email": "egorova_e111980@postgrespro.ru", "phone": "+70540297519"}
0005432675287	0ECF73	3225 172080	OLEG DAVYDOV	{"email": "davydov_o1976@postgrespro.ru", "phone": "+70101479231"}
0005432675288	E6AA78	1335 108753	VITALIY NOVIKOV	{"phone": "+70277244188"}
0005432675289	F18800	7621 593324	DARYA MAKSIMOVA	{"email": "maksimova_darya_081965@postgrespro.ru", "phone": "+70424005333"}
0005432675290	837B19	5024 031586	OLGA MOROZOVA	{"phone": "+70167104105"}
0005432675291	2406D4	3557 916081	ALLA ANISIMOVA	{"email": "anisimova-alla031976@postgrespro.ru", "phone": "+70474103732"}
0005432675292	6193C1	9681 588710	EVGENIY ZHURAVLEV	{"phone": "+70859699622"}
0005432675293	85DAFB	3417 895484	GALINA NAUMOVA	{"phone": "+70472892851"}
0005432675294	7A4C76	9662 049146	VLADIMIR GORBUNOV	{"phone": "+70625571166"}
0005432675295	6144FA	5412 277196	LARISA CHERNOVA	{"email": "l_chernova02071979@postgrespro.ru", "phone": "+70300879224"}
0005432675296	7F1D7A	5964 041495	DENIS AFANASEV	{"email": "d_afanasev_1971@postgrespro.ru", "phone": "+70247042341"}
0005432675297	7F1D7A	5477 868716	SERGEY BELOV	{"email": "belov-s111968@postgrespro.ru", "phone": "+70321393325"}
0005432675298	5B04F9	8731 549301	SERGEY ISAEV	{"phone": "+70950652482"}
0005432675299	C3F423	5107 243509	MIKHAIL GORBUNOV	{"email": "gorbunov_mikhail061972@postgrespro.ru", "phone": "+70480856700"}
0005432675300	029AE8	6100 813475	ANATOLIY EGOROV	{"email": "egorov.a.061968@postgrespro.ru", "phone": "+70641160374"}
0005432675301	6A21D4	2852 506570	OLEG SOLOVEV	{"email": "oleg.solovev.091973@postgrespro.ru", "phone": "+70598472274"}
0005432675302	CD1C23	7882 281287	SERGEY SMIRNOV	{"email": "smirnov_sergey.11111968@postgrespro.ru", "phone": "+70674585418"}
0005432675303	354D82	7109 619987	ANNA PAVLOVA	{"email": "pavlovaa.1986@postgrespro.ru", "phone": "+70331189709"}
0005432675304	354D82	2164 517040	YANA SMIRNOVA	{"phone": "+70727698382"}
0005432675305	09B45D	3766 039214	NADEZHDA ZAKHAROVA	{"email": "zakharova-n-03111969@postgrespro.ru", "phone": "+70744703696"}
0005432675306	A27B11	2500 046784	OKSANA TIMOFEEVA	{"phone": "+70282989954"}
0005432675307	0FA397	8249 669060	ALEKSANDR ALEKSANDROV	{"phone": "+70197683751"}
0005432675308	320769	7021 459146	OLEG GRIGOREV	{"phone": "+70528165747"}
0005432675309	4B9C56	8162 951644	VIKTOR ABRAMOV	{"phone": "+70887604408"}
0005432675310	14B8B1	7193 047580	VIKTOR VASILEV	{"phone": "+70376485659"}
0005432675311	14B8B1	8362 431365	EVGENIYA MAKAROVA	{"phone": "+70823485538"}
0005432675312	44CD94	9025 154685	ZHANNA KOLESNIKOVA	{"phone": "+70125687644"}
0005432675313	4A4CEF	6868 539937	TIMUR ANDREEV	{"email": "andreev_t011971@postgrespro.ru", "phone": "+70700885934"}
0005432675314	4A4CEF	0352 618361	NATALYA NIKITINA	{"email": "nikitinanatalya30111968@postgrespro.ru", "phone": "+70440898314"}
0005432675315	128993	6546 323507	NIKOLAY SERGEEV	{"email": "sergeevn_13011968@postgrespro.ru", "phone": "+70633611549"}
0005432675316	447FB2	7424 784225	DENIS ZHURAVLEV	{"phone": "+70632913971"}
0005432675317	0584BF	1485 676506	VALERIY SOKOLOV	{"phone": "+70112898578"}
0005432675318	0584BF	2044 417738	ANASTASIYA MAKSIMOVA	{"email": "a.maksimova_1972@postgrespro.ru", "phone": "+70442133545"}
0005432675319	0584BF	1507 922428	RAFAEL SEMENOV	{"phone": "+70426305747"}
0005432675320	DC917F	9913 193487	LYUBOV ZAYCEVA	{"email": "zayceva-lyubov031955@postgrespro.ru", "phone": "+70746171856"}
0005432675321	26F0B6	2895 951422	IBRAGIM KONOVALOV	{"phone": "+70189364506"}
0005432675322	7EE07B	9099 938533	IRINA DENISOVA	{"email": "i.denisova-1980@postgrespro.ru", "phone": "+70350787421"}
0005432675323	5A9D63	2743 337078	NATALYA SIDOROVA	{"email": "sidorova-n011986@postgrespro.ru", "phone": "+70436391243"}
0005432675324	5A9D63	4821 026530	VITALIY OSIPOV	{"email": "osipov.vitaliy_111973@postgrespro.ru", "phone": "+70115928992"}
0005432675325	90BC60	1642 054698	IRINA NAZAROVA	{"email": "irina-nazarova-12041970@postgrespro.ru", "phone": "+70781103845"}
0005432675326	90BC60	1704 037010	RAMILYA ZAYCEVA	{"phone": "+70551299449"}
0005432675327	527FF6	4264 084599	ANTON SMIRNOV	{"email": "smirnovanton031971@postgrespro.ru", "phone": "+70857591040"}
0005432675328	E66DE7	6640 067554	ALEKSANDR ILIN	{"email": "aleksandr_ilin_051968@postgrespro.ru", "phone": "+70913975692"}
0005432675329	E66DE7	0361 109579	ANASTASIYA ISAEVA	{"phone": "+70682652656"}
0005432675330	12E48B	1038 641333	ADELINA NESTEROVA	{"email": "adelina_nesterova041975@postgrespro.ru", "phone": "+70130019183"}
0005432675331	188953	8567 912844	LIDIYA MOROZOVA	{"email": "morozova_lidiya.27021970@postgrespro.ru", "phone": "+70900066278"}
0005432675332	71CFC4	6519 047378	ARTEM STEPANOV	{"email": "stepanov_a.041970@postgrespro.ru", "phone": "+70943784726"}
0005432675333	71CFC4	0539 492588	MIKHAIL MOISEEV	{"email": "mikhailmoiseev_31031960@postgrespro.ru", "phone": "+70633564474"}
0005432675334	6C28D9	7989 736467	MARINA GORBUNOVA	{"phone": "+70082809704"}
0005432675335	6C28D9	0560 256073	ANATOLIY KULIKOV	{"phone": "+70365981932"}
0005432675336	87F1F3	7727 806960	IRINA NOVIKOVA	{"phone": "+70015387837"}
0005432675337	DD84E4	9873 410973	VALENTINA BOGDANOVA	{"email": "vbogdanova-1978@postgrespro.ru", "phone": "+70060562702"}
0005432675338	9E4CAD	1071 671154	VALERIY DENISOV	{"email": "v-denisov011980@postgrespro.ru", "phone": "+70047529633"}
0005432675339	4455A0	9865 918715	KIRILL KUZNECOV	{"phone": "+70932009411"}
0005432675340	9B3D96	3128 014174	RIMMA MEDVEDEVA	{"phone": "+70125408153"}
0005432675341	2D4DB5	1749 996771	SERGEY ANDREEV	{"email": "sergeyandreev-031961@postgrespro.ru", "phone": "+70424995153"}
0005432675342	118D06	4829 101160	YULIYA NESTEROVA	{"phone": "+70762182194"}
0005432675343	B55958	3010 394818	FEDOR VOROBEV	{"phone": "+70738258268"}
0005432675344	B55958	1059 574109	MIKHAIL KOZLOV	{"email": "m-kozlov061962@postgrespro.ru", "phone": "+70628912902"}
0005432675345	0BEA1E	8778 052099	PETR EGOROV	{"phone": "+70819774327"}
0005432675346	0BEA1E	5924 743290	YULIYA VOROBEVA	{"phone": "+70925620547"}
0005432675347	0BEA1E	3907 149360	ANTON VASILEV	{"email": "anton_vasilev31051983@postgrespro.ru", "phone": "+70668195580"}
0005432675348	1B3893	1859 334854	EVGENIY EGOROV	{"email": "egorov-e_1974@postgrespro.ru", "phone": "+70946374872"}
0005432675349	DB2456	6170 000914	DMITRIY EGOROV	{"phone": "+70612870498"}
0005432675350	9CD9F4	7441 310352	ALENA MIKHAYLOVA	{"phone": "+70719758820"}
0005432675351	49C56E	5220 015641	VALENTINA SOROKINA	{"email": "v-sorokina_15021968@postgrespro.ru", "phone": "+70704810384"}
0005432675352	AB2805	6200 205741	VASILIY SAVELEV	{"email": "savelev.vasiliy.24101977@postgrespro.ru", "phone": "+70035789949"}
0005432675353	6301AE	7703 606731	LYUBOV VLASOVA	{"email": "vlasova_lyubov.1969@postgrespro.ru", "phone": "+70080718519"}
0005432675354	D5A2BE	9334 087543	ANATOLIY ANDREEV	{"email": "andreev.anatoliy1968@postgrespro.ru", "phone": "+70350206450"}
0005432675355	1E0A2C	2646 534423	KRISTINA SERGEEVA	{"phone": "+70449107245"}
0005432675356	723A79	0978 039339	ALEKSEY OSIPOV	{"phone": "+70269014762"}
0005432675357	723A79	2778 903330	VALENTINA DAVYDOVA	{"email": "vdavydova1978@postgrespro.ru", "phone": "+70606121856"}
0005432675358	E06614	9606 469375	ILYA STEPANOV	{"email": "ilyastepanov011979@postgrespro.ru", "phone": "+70718796884"}
0005432675359	E06614	6612 926377	ZOYA YUDINA	{"phone": "+70647115931"}
0005432675360	53FF9D	9942 069974	GALINA MAKAROVA	{"email": "makarova-g.071980@postgrespro.ru", "phone": "+70265521308"}
0005432675361	31BE87	7229 921696	NIKOLAY DENISOV	{"email": "denisov-nikolay1974@postgrespro.ru", "phone": "+70754588689"}
0005432675362	5F4C70	9675 589412	DENIS ANTONOV	{"phone": "+70595223065"}
0005432675363	7E6475	8002 608512	MARINA EGOROVA	{"phone": "+70625343956"}
0005432675364	7E6475	8557 507368	ALEKSANDR GORBUNOV	{"phone": "+70237281233"}
0005432675365	2A34FA	1762 334493	MARAT STEPANOV	{"phone": "+70366607511"}
0005432675366	2A34FA	9143 112605	KRISTINA KONOVALOVA	{"phone": "+70317674448"}
0005432675367	2A34FA	0299 881026	VLADIMIR KRASNOV	{"phone": "+70020325714"}
0005432675368	FE7A0B	9596 765969	KONSTANTIN MAKSIMOV	{"email": "k_maksimov-31011975@postgrespro.ru", "phone": "+70585096835"}
0005432675369	FE7A0B	4610 560075	EVGENIYA POTAPOVA	{"email": "potapova-e_1969@postgrespro.ru", "phone": "+70823111555"}
0005432675370	7B000A	6365 958348	DMITRIY ZHURAVLEV	{"phone": "+70992081329"}
0005432675371	7B000A	8612 629797	VALERIY MAKAROV	{"phone": "+70186402230"}
0005432675372	B109A7	9931 061930	OKSANA BARANOVA	{"phone": "+70593879479"}
0005432675373	B109A7	2214 886894	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.031960@postgrespro.ru", "phone": "+70718710553"}
0005432675374	B109A7	4371 221023	NIKOLAY SAVELEV	{"phone": "+70026551376"}
0005432675375	7C0F97	2954 834650	ELENA MARTYNOVA	{"email": "martynova-elena_081971@postgrespro.ru", "phone": "+70075843902"}
0005432675376	C7B553	1380 375383	VERA EFIMOVA	{"phone": "+70794919515"}
0005432675377	C7B553	8312 355337	VLADIMIR FEDOROV	{"phone": "+70045921006"}
0005432675378	D49018	8176 905802	LIDIYA ZHUKOVA	{"email": "lidiyazhukova_031976@postgrespro.ru", "phone": "+70553541563"}
0005432675379	662D2B	0072 355821	IRINA ALEKSEEVA	{"email": "irinaalekseeva051980@postgrespro.ru", "phone": "+70560106239"}
0005432675380	D4FA38	1502 265433	ELENA SEMENOVA	{"email": "semenovaelena1967@postgrespro.ru", "phone": "+70444828433"}
0005432675381	CAD13E	4573 821095	YULIYA ILINA	{"phone": "+70819519750"}
0005432675382	CAD13E	3789 643754	DMITRIY POPOV	{"phone": "+70464620333"}
0005432675383	DD63C6	8803 289422	IGOR KAZAKOV	{"phone": "+70260872621"}
0005432675384	DD63C6	5909 980351	ALISA FEDOROVA	{"phone": "+70528637141"}
0005432675385	591F8D	2819 410054	MARIYA NIKOLAEVA	{"email": "nikolaevam.17101979@postgrespro.ru", "phone": "+70030653463"}
0005432675386	692023	9349 989934	NAIL RODIONOV	{"email": "rodionov_nail.021973@postgrespro.ru", "phone": "+70353843499"}
0005432675387	3DBE91	8784 639955	PETR GERASIMOV	{"email": "petr_gerasimov21021984@postgrespro.ru", "phone": "+70058592162"}
0005432675388	08E61E	6779 147846	VLADIMIR KUZMIN	{"phone": "+70246755377"}
0005432675389	08E61E	0615 216192	VLADIMIR SHEVCHENKO	{"phone": "+70578233143"}
0005432675390	08E61E	8080 009446	VIKTOR SERGEEV	{"email": "sergeev.v_03051970@postgrespro.ru", "phone": "+70463100186"}
0005432675391	0E8A2D	5086 428042	ZHANNA ANDREEVA	{"email": "zhannaandreeva.20091977@postgrespro.ru", "phone": "+70280135087"}
0005432675392	0E8A2D	9405 280164	ALEKSANDR FROLOV	{"phone": "+70474445007"}
0005432675393	93D85E	7697 679539	LEYLA ALEKSANDROVA	{"email": "leyla-aleksandrova.091985@postgrespro.ru", "phone": "+70425936437"}
0005432675394	93D85E	8239 543678	RAMIL KUZMIN	{"phone": "+70641211118"}
0005432675395	A19F58	7212 322223	ANATOLIY MAKSIMOV	{"email": "a-maksimov1971@postgrespro.ru", "phone": "+70005010575"}
0005432675396	A19F58	7185 680087	ANASTASIYA FOMINA	{"phone": "+70796670200"}
0005432675397	6FF7C1	8822 490085	VITALIY MAKAROV	{"email": "vitaliymakarov_17021970@postgrespro.ru", "phone": "+70946827448"}
0005432675398	4A38CE	3740 256468	ALEKSANDR KUZNECOV	{"phone": "+70913866034"}
0005432675399	4A38CE	9316 025634	DMITRIY MOISEEV	{"email": "moiseev-dmitriy.26111969@postgrespro.ru", "phone": "+70532903949"}
0005432675400	262A37	4359 273052	ARTEM SIDOROV	{"email": "a-sidorov-121975@postgrespro.ru", "phone": "+70881926010"}
0005432675401	F83DFB	9448 477219	TATYANA SERGEEVA	{"email": "tatyana_sergeeva-1973@postgrespro.ru", "phone": "+70544946641"}
0005432675402	A6A9C4	7291 438458	ALEKSANDRA BELOVA	{"phone": "+70001548016"}
0005432675403	802538	8451 690406	ALEKSANDR EGOROV	{"phone": "+70192686017"}
0005432675404	F48374	3002 281387	MIKHAIL VOLKOV	{"phone": "+70247574053"}
0005432675405	AC5F05	8224 504509	SERGEY TARASOV	{"email": "sergey_tarasov-031968@postgrespro.ru", "phone": "+70075821088"}
0005432675406	AC5F05	2430 298215	EKATERINA TROFIMOVA	{"phone": "+70542192955"}
0005432675407	AC5F05	4848 181640	KSENIYA FEDOROVA	{"email": "k-fedorova011970@postgrespro.ru", "phone": "+70790998094"}
0005432675408	FB4B66	2983 241419	NADEZHDA RYABOVA	{"email": "nadezhda.ryabova-041969@postgrespro.ru", "phone": "+70946416197"}
0005432675409	EC3ED8	9580 685692	ANDREY GUSEV	{"phone": "+70745606772"}
0005432675410	1CF398	2441 935673	IRINA MARTYNOVA	{"email": "i-martynova_1977@postgrespro.ru", "phone": "+70535868748"}
0005432675411	5C96F8	3208 799264	OLGA ANDREEVA	{"email": "andreevaolga-29051969@postgrespro.ru", "phone": "+70525400737"}
0005432675412	E29CDA	0958 048527	LYUDMILA GRISHINA	{"phone": "+70038122982"}
0005432675413	0FF6C3	6386 664836	VADIM SEMENOV	{"email": "semenov-vadim121970@postgrespro.ru", "phone": "+70905520762"}
0005432675414	CA1650	1497 952970	VALERIY SCHERBAKOV	{"email": "scherbakov.valeriy.1969@postgrespro.ru", "phone": "+70901852850"}
0005432675415	3A6E81	8091 714740	SVETLANA FEDOROVA	{"email": "sfedorova_1977@postgrespro.ru", "phone": "+70727636882"}
0005432675416	76D122	0579 945821	EVGENIY MAKAROV	{"phone": "+70794502738"}
0005432675417	3B6B63	2815 283468	LYUBOV VLASOVA	{"email": "lyubovvlasova_19011978@postgrespro.ru", "phone": "+70214992321"}
0005432675418	0E6474	6961 534443	ROMAN POPOV	{"email": "rpopov031966@postgrespro.ru", "phone": "+70080570825"}
0005432675419	5AC38E	1956 508490	MARINA MEDVEDEVA	{"phone": "+70495198223"}
0005432675420	A74E24	7027 457688	ELENA DENISOVA	{"email": "denisova.elena10111980@postgrespro.ru", "phone": "+70915917591"}
0005432675421	8C022A	6552 219692	ANASTASIYA SERGEEVA	{"email": "anastasiya.sergeeva_1972@postgrespro.ru", "phone": "+70002502730"}
0005432675422	8C022A	5503 707637	GALINA KUZNECOVA	{"phone": "+70005545102"}
0005432675423	719BBD	5264 203737	DMITRIY ZHUKOV	{"email": "dmitriyzhukov_16021976@postgrespro.ru", "phone": "+70556443467"}
0005432675424	719BBD	6679 942671	SERGEY TIMOFEEV	{"phone": "+70982709040"}
0005432675425	E4326B	9792 903343	VITALIY PAVLOV	{"phone": "+70297887488"}
0005432675426	E4326B	5165 586312	GALINA SERGEEVA	{"phone": "+70713905032"}
0005432675427	BE90FE	2551 908840	DARYA IVANOVA	{"phone": "+70242311582"}
0005432675428	B28AE3	1547 465614	VIKTOR MIRONOV	{"email": "v.mironov1983@postgrespro.ru", "phone": "+70488081835"}
0005432675429	B28AE3	1118 513973	OLEG KUZNECOV	{"phone": "+70306539695"}
0005432675430	B28AE3	3963 161030	VYACHESLAV PETROV	{"phone": "+70799728202"}
0005432675431	E0A43D	5270 644543	ALEKSANDR PETROV	{"email": "petrova.101966@postgrespro.ru", "phone": "+70470814443"}
0005432675432	0E2877	2369 259351	NATALYA POPOVA	{"email": "popovan_051967@postgrespro.ru", "phone": "+70374402580"}
0005432675433	605D64	7159 762205	DMITRIY KARPOV	{"email": "karpovd.091970@postgrespro.ru", "phone": "+70851288040"}
0005432675434	3CEE68	0802 074659	IRINA VASILEVA	{"email": "irina_vasileva_1966@postgrespro.ru", "phone": "+70418994474"}
0005432675435	3CEE68	0479 337489	VLADIMIR ZHURAVLEV	{"phone": "+70337466213"}
0005432675436	3CEE68	5772 270998	ELENA KUZNECOVA	{"email": "ekuznecova.05101980@postgrespro.ru", "phone": "+70111447975"}
0005432675437	F7EACE	0339 980254	BULAT FEDOROV	{"phone": "+70416216270"}
0005432675438	F7EACE	8904 008705	VIKTORIYA MIKHAYLOVA	{"phone": "+70676856246"}
0005432675439	B69158	0810 268705	IVAN DMITRIEV	{"phone": "+70568592442"}
0005432675440	B69158	9065 317980	EVGENIY GORBUNOV	{"email": "evgeniy_gorbunov1972@postgrespro.ru", "phone": "+70289561467"}
0005432675441	B69158	1816 737632	NATALYA ARKHIPOVA	{"phone": "+70986221404"}
0005432675442	136D63	8394 944255	NIKOLAY SERGEEV	{"email": "sergeev.nikolay_1968@postgrespro.ru", "phone": "+70284994712"}
0005432675443	137E2D	0887 492739	VALENTINA ANISIMOVA	{"phone": "+70877849850"}
0005432675444	F3C401	5303 643679	RAISA ROMANOVA	{"email": "romanova-r_11031980@postgrespro.ru", "phone": "+70696927449"}
0005432675445	22D9EA	3772 271449	OLGA SERGEEVA	{"phone": "+70169434678"}
0005432675446	6702AD	3108 252573	KLAVDIYA MARTYNOVA	{"email": "klavdiya.martynova-111975@postgrespro.ru", "phone": "+70836682872"}
0005432675447	6702AD	5660 509404	SERGEY MOROZOV	{"email": "morozov.sergey.31031975@postgrespro.ru", "phone": "+70853322085"}
0005432675448	6702AD	7161 707576	LIDIYA DMITRIEVA	{"phone": "+70846303337"}
0005432675449	009852	5834 223719	ALEKSANDRA SIDOROVA	{"phone": "+70357314335"}
0005432675450	2B6E85	4754 223323	SERGEY MIKHAYLOV	{"email": "mikhaylov_s1984@postgrespro.ru", "phone": "+70453642815"}
0005432675451	A2D928	5174 102370	EKATERINA SCHERBAKOVA	{"phone": "+70931661321"}
0005432675452	372344	7566 727939	IRINA NIKITINA	{"phone": "+70779433068"}
0005432675453	67A583	7581 168426	OLGA KULIKOVA	{"email": "kulikova-o111967@postgrespro.ru", "phone": "+70853450739"}
0005432675454	67A583	2338 205705	VALERIY KOZLOV	{"email": "vkozlov1978@postgrespro.ru", "phone": "+70044392471"}
0005432675455	F9F818	4845 966442	ROMAN MOISEEV	{"phone": "+70012260469"}
0005432675456	F9F818	0732 479283	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr-20081974@postgrespro.ru", "phone": "+70046826400"}
0005432675457	1029A2	1588 290720	EKATERINA VASILEVA	{"phone": "+70443422889"}
0005432675458	9D0DF3	6880 240306	ALEKSEY GUSEV	{"phone": "+70569186016"}
0005432675459	FC528F	3327 247640	VLADIMIR SEMENOV	{"email": "semenov-vladimir.1970@postgrespro.ru", "phone": "+70420692153"}
0005432675460	FC528F	4288 862182	OLEG BONDARENKO	{"phone": "+70115426996"}
0005432675461	B439A7	9512 480016	YULIYA STEPANOVA	{"email": "stepanova.yuliya-10081975@postgrespro.ru", "phone": "+70971071898"}
0005432675462	F71E52	2058 735614	DMITRIY DAVYDOV	{"email": "d_davydov101966@postgrespro.ru", "phone": "+70147811763"}
0005432675463	F71E52	9561 765536	ALISA ZAKHAROVA	{"email": "a_zakharova_111971@postgrespro.ru", "phone": "+70810258046"}
0005432675464	EE0D60	5075 087127	MIKHAIL VOLKOV	{"phone": "+70885862410"}
0005432675465	64F526	6302 028339	TAMARA BOGDANOVA	{"email": "tamara_bogdanova1961@postgrespro.ru", "phone": "+70881725426"}
0005432675466	F97BBC	2286 111175	NATALIYA ZOTOVA	{"phone": "+70607130186"}
0005432675467	01E597	1227 535616	EKATERINA SOLOVEVA	{"email": "soloveva.e.05091968@postgrespro.ru", "phone": "+70366659035"}
0005432675468	D24F63	2910 631179	VIKTOR KUZMIN	{"email": "viktor_kuzmin-19051979@postgrespro.ru", "phone": "+70916089882"}
0005432675469	00BA65	6345 957795	OLEG IVANOV	{"phone": "+70837026371"}
0005432675470	7173E7	6778 025481	ALEKSEY SEMENOV	{"email": "semenov_aleksey-1979@postgrespro.ru", "phone": "+70413907434"}
0005432675471	EE560E	0618 953099	ALEKSANDR GRIGOREV	{"phone": "+70259213701"}
0005432675472	EE560E	1881 109320	KLAVDIYA MARTYNOVA	{"email": "klavdiyamartynova-101973@postgrespro.ru", "phone": "+70192310996"}
0005432675473	FBBF42	5232 888637	ALBINA CHERNOVA	{"email": "albinachernova-1961@postgrespro.ru", "phone": "+70669809845"}
0005432675474	304699	7889 265273	LYUDMILA NIKITINA	{"email": "l_nikitina-1979@postgrespro.ru", "phone": "+70327511320"}
0005432675475	3F9ABA	3315 785105	PAVEL KAZAKOV	{"phone": "+70269536732"}
0005432675476	0CA431	7172 861697	VLADIMIR GRIGOREV	{"phone": "+70761234007"}
0005432675477	E7826E	0482 461242	EVGENIYA FILIPPOVA	{"email": "filippova.evgeniya031963@postgrespro.ru", "phone": "+70135006243"}
0005432675478	3A75FE	6157 601418	OLEG TARASOV	{"phone": "+70808921051"}
0005432675479	60089A	4176 886983	ANDREY AFANASEV	{"email": "afanasev_andrey.021971@postgrespro.ru", "phone": "+70449601970"}
0005432675480	AA0EA0	9872 896385	GENNADIY BORISOV	{"email": "g-borisov121973@postgrespro.ru", "phone": "+70511844281"}
0005432675481	0C197B	4769 641920	SERGEY NIKITIN	{"phone": "+70610276638"}
0005432675482	0C197B	5503 006324	ALEKSANDR FILIPPOV	{"email": "afilippov1967@postgrespro.ru", "phone": "+70348794057"}
0005432675483	0C0672	4660 405385	NATALIYA MEDVEDEVA	{"email": "n-medvedeva08061975@postgrespro.ru", "phone": "+70670778172"}
0005432675484	0C0672	4096 697270	VLADIMIR SMIRNOV	{"email": "smirnovvladimir-1971@postgrespro.ru", "phone": "+70701843322"}
0005432675485	7E696B	2754 065357	VIKTOR GERASIMOV	{"email": "gerasimov_v-1970@postgrespro.ru", "phone": "+70044624111"}
0005432675486	839658	6602 732630	PETR CHERNOV	{"email": "chernov-petr.1972@postgrespro.ru", "phone": "+70328610936"}
0005432675487	839658	7900 552872	VALENTINA AFANASEVA	{"phone": "+70277685770"}
0005432675488	DDDC7F	8214 736507	MAKSIM SHEVCHENKO	{"email": "maksimshevchenko_051970@postgrespro.ru", "phone": "+70088105965"}
0005432675489	943A72	4304 892870	MARINA MIKHAYLOVA	{"phone": "+70331025122"}
0005432675490	E28624	2283 326425	ILNUR OSIPOV	{"email": "osipov.ilnur.041981@postgrespro.ru", "phone": "+70588311700"}
0005432675491	E28624	3726 894730	EVGENIY SCHERBAKOV	{"phone": "+70831387950"}
0005432675547	EB811A	2841 499636	VALENTIN PAVLOV	{"phone": "+70193610983"}
0005432675492	252F1A	3943 013142	MIKHAIL ZHURAVLEV	{"email": "zhuravlevmikhail27051969@postgrespro.ru", "phone": "+70511134865"}
0005432675493	07000F	6107 333534	YULIYA NIKIFOROVA	{"phone": "+70494085030"}
0005432675494	3219F3	2951 127142	ALIYA MASLOVA	{"email": "maslova_a_091971@postgrespro.ru", "phone": "+70550562596"}
0005432675495	EEA5C3	2032 499899	SVETLANA MIKHAYLOVA	{"email": "mikhaylova-s.1975@postgrespro.ru", "phone": "+70184768895"}
0005432675496	EEA5C3	6230 848060	VERA MELNIKOVA	{"email": "melnikova-vera_1962@postgrespro.ru", "phone": "+70558495597"}
0005432675497	EEA5C3	2069 542122	LYUBOV BORISOVA	{"email": "l.borisova.081975@postgrespro.ru", "phone": "+70675573933"}
0005432675498	99102D	4204 162650	VALENTINA CHERNOVA	{"email": "v.chernova_1970@postgrespro.ru", "phone": "+70183655679"}
0005432675499	99102D	3970 482275	ALEKSANDR VASILEV	{"email": "a.vasilev04031970@postgrespro.ru", "phone": "+70275754944"}
0005432675500	12CB14	1325 221946	LIDIYA ANDREEVA	{"email": "andreeva_l-121981@postgrespro.ru", "phone": "+70804989209"}
0005432675501	87C572	0309 414517	ROZA FILIPPOVA	{"email": "roza-filippova_121973@postgrespro.ru", "phone": "+70013289982"}
0005432675502	09AF42	8748 383677	ELENA KONOVALOVA	{"phone": "+70257338123"}
0005432675503	F20BBE	4020 739343	ALEKSANDR VASILEV	{"email": "a.vasilev_11021972@postgrespro.ru", "phone": "+70564616373"}
0005432675504	699B54	1862 726157	PETR ZHURAVLEV	{"email": "zhuravlev-petr-051981@postgrespro.ru", "phone": "+70248526866"}
0005432675505	B7A648	4112 617115	LYUBOV KUZNECOVA	{"email": "l-kuznecova_031973@postgrespro.ru", "phone": "+70219050437"}
0005432675506	B7A648	4285 709255	LYUBOV CHERNOVA	{"phone": "+70525969831"}
0005432675507	4170B5	6818 026868	VALENTINA BORISOVA	{"phone": "+70662070813"}
0005432675508	4170B5	3336 501359	VENERA PAVLOVA	{"phone": "+70109693889"}
0005432675509	4170B5	0259 171337	ALLA KRASNOVA	{"phone": "+70746193477"}
0005432675510	7DE810	3245 990328	NIKOLAY BONDARENKO	{"email": "nikolay_bondarenko-051969@postgrespro.ru", "phone": "+70303108635"}
0005432675511	02DA2A	0063 541177	VLADIMIR KUZNECOV	{"phone": "+70374689222"}
0005432675512	D5D20B	8402 113202	NINA FILIPPOVA	{"phone": "+70518103093"}
0005432675513	0E3A51	0338 688078	PAVEL ANTONOV	{"phone": "+70101573901"}
0005432675514	0E3A51	3681 858161	OLEG POPOV	{"phone": "+70857068137"}
0005432675515	490EA9	7443 024834	ALEKSANDR FROLOV	{"email": "frolova.1974@postgrespro.ru", "phone": "+70568274027"}
0005432675516	9A1580	6427 618024	ALEKSEY KRASNOV	{"email": "akrasnov_041970@postgrespro.ru", "phone": "+70716323358"}
0005432675517	9A1580	9440 413035	YULIYA POLYAKOVA	{"email": "y.polyakova1974@postgrespro.ru", "phone": "+70669555290"}
0005432675518	EEC449	6085 850420	FEDOR IVANOV	{"phone": "+70367218406"}
0005432675519	4271B4	2189 915043	VIKTOR ZAKHAROV	{"email": "zakharov_viktor.051968@postgrespro.ru", "phone": "+70795517746"}
0005432675520	706552	8821 139535	YULIYA ALEKSEEVA	{"email": "yuliya-alekseeva.12091969@postgrespro.ru", "phone": "+70401383934"}
0005432675521	775E61	1418 596351	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov1963@postgrespro.ru", "phone": "+70374780758"}
0005432675522	191B0D	7162 348885	VITALIY ROMANOV	{"email": "vromanov08101965@postgrespro.ru", "phone": "+70466305189"}
0005432675523	191B0D	1548 434691	VALERIY NOVIKOV	{"email": "novikov_valeriy061974@postgrespro.ru", "phone": "+70045103631"}
0005432675524	08EC04	3046 744850	YULIYA KISELEVA	{"phone": "+70521528235"}
0005432675525	13F447	5944 800531	SOFIYA KARPOVA	{"email": "karpovas1973@postgrespro.ru", "phone": "+70246250946"}
0005432675526	006603	5773 614637	IGOR KUZNECOV	{"phone": "+70440678004"}
0005432675527	EDD7D4	3303 092997	DENIS PETROV	{"phone": "+70034306927"}
0005432675528	EDD7D4	0909 885412	ALENA KUDRYASHOVA	{"email": "kudryashova.alena.02051973@postgrespro.ru", "phone": "+70782555021"}
0005432675529	EBB757	7800 780170	VIKTOR ZAYCEV	{"phone": "+70891109811"}
0005432675530	EBB757	8174 706622	SVETLANA STEPANOVA	{"email": "svetlanastepanova.121972@postgrespro.ru", "phone": "+70578204451"}
0005432675531	8B8D14	9652 378192	ALENA VOROBEVA	{"phone": "+70612098140"}
0005432675532	3C4E94	1661 207571	VASILIY SCHERBAKOV	{"email": "scherbakov-v_1969@postgrespro.ru", "phone": "+70974832928"}
0005432675533	3C4E94	4139 526627	ZOYA ERMAKOVA	{"phone": "+70052647835"}
0005432675534	D97F01	7991 173178	VLADIMIR ZAYCEV	{"phone": "+70342580936"}
0005432675535	7B229E	1308 207060	DARINA KOROLEVA	{"email": "korolevad-1972@postgrespro.ru", "phone": "+70208539845"}
0005432675536	981A7F	6236 229318	IRINA OSIPOVA	{"email": "osipova_i.121968@postgrespro.ru", "phone": "+70604711289"}
0005432675537	89C461	6764 375071	RAVIL ZAKHAROV	{"email": "zakharovravil.1970@postgrespro.ru", "phone": "+70242396591"}
0005432675538	7DE48E	8070 943527	VALERIY FILIPPOV	{"email": "v_filippov061970@postgrespro.ru", "phone": "+70319709102"}
0005432675539	9BA921	9266 914365	VERA YAKOVLEVA	{"email": "yakovleva.v.1981@postgrespro.ru", "phone": "+70025550353"}
0005432675540	656B1D	3172 147695	TAMARA VOLKOVA	{"email": "tamara_volkova_31011973@postgrespro.ru", "phone": "+70110541411"}
0005432675541	193744	1732 429828	NIKOLAY FEDOROV	{"phone": "+70507040505"}
0005432675542	C4295A	6840 470220	ZLATA KUZNECOVA	{"phone": "+70451011582"}
0005432675543	C4295A	7146 000237	NATALYA FROLOVA	{"email": "frolova-natalya.041965@postgrespro.ru", "phone": "+70016612806"}
0005432675544	B1EAD5	3017 024360	ALEKSANDRA MEDVEDEVA	{"phone": "+70641789694"}
0005432675545	0EBE2E	5258 117770	TATYANA KUZNECOVA	{"phone": "+70683975819"}
0005432675546	0EBE2E	7762 459567	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr101973@postgrespro.ru", "phone": "+70983309414"}
0005432675548	8A72A7	4287 709804	VLADIMIR MAKSIMOV	{"email": "vladimir.maksimov1974@postgrespro.ru", "phone": "+70870092977"}
0005432675549	8A72A7	3571 522480	VIKTOR ROMANOV	{"email": "romanov.viktor.05031970@postgrespro.ru", "phone": "+70523237791"}
0005432675550	B81F5E	4441 131150	NATALYA KRASNOVA	{"email": "krasnova.n.1959@postgrespro.ru", "phone": "+70706558771"}
0005432675551	0A030B	5575 389566	ELENA ZHURAVLEVA	{"email": "ezhuravleva_1975@postgrespro.ru", "phone": "+70034467114"}
0005432675552	F42CCE	1455 683825	EGOR MARTYNOV	{"email": "martynov-egor30031978@postgrespro.ru", "phone": "+70315647492"}
0005432675553	53C5F9	2193 294775	MARINA KARPOVA	{"email": "marina_karpova.13091969@postgrespro.ru", "phone": "+70732966745"}
0005432675554	EE14FE	2021 291761	NIKOLAY MIRONOV	{"phone": "+70546591449"}
0005432675555	3ABF03	4591 712344	VALERIY VLASOV	{"email": "vlasovv.16041970@postgrespro.ru", "phone": "+70487254162"}
0005432675556	3ABF03	0681 229687	TIMOFEY VASILEV	{"email": "vasilev.t021980@postgrespro.ru", "phone": "+70361542871"}
0005432675557	5E467C	7986 910741	IRINA OVCHINNIKOVA	{"email": "irina-ovchinnikova_17091975@postgrespro.ru", "phone": "+70451615157"}
0005432675558	5E467C	2834 960853	LYUDMILA KOVALEVA	{"email": "lyudmila-kovaleva_1970@postgrespro.ru", "phone": "+70899295515"}
0005432675559	FF3B4C	6873 170926	NATALYA VOLKOVA	{"email": "volkova_n17101977@postgrespro.ru", "phone": "+70296040146"}
0005432675560	FF3B4C	6630 371622	ZOYA BORISOVA	{"phone": "+70213839591"}
0005432675561	FF3B4C	6383 683309	ALLA MATVEEVA	{"email": "alla.matveeva.1983@postgrespro.ru", "phone": "+70548270678"}
0005432675562	911AE4	0286 129926	TATYANA DANILOVA	{"phone": "+70849640910"}
0005432675563	59ED47	0219 031704	YULIYA KUZMINA	{"email": "y-kuzmina.091975@postgrespro.ru", "phone": "+70944538571"}
0005432675564	DF744C	9474 522197	OKSANA MIRONOVA	{"phone": "+70393482298"}
0005432675565	131672	8415 818225	RAISA ANTONOVA	{"email": "antonovar-14031959@postgrespro.ru", "phone": "+70369261703"}
0005432675566	FC2653	2747 877732	SVETLANA MAKAROVA	{"email": "makarovas.15091964@postgrespro.ru", "phone": "+70637068178"}
0005432675567	FC2653	1335 321291	IRINA GAVRILOVA	{"email": "i.gavrilova.101966@postgrespro.ru", "phone": "+70005044168"}
0005432675568	FC2653	4764 842827	SERGEY MOROZOV	{"phone": "+70577749176"}
0005432675569	74E7CF	1454 968181	NIKOLAY SHEVCHENKO	{"phone": "+70469763504"}
0005432675570	4B3664	2151 748877	LYUDMILA STEPANOVA	{"phone": "+70699800087"}
0005432675571	656A4C	8552 769531	MAKSIM NAUMOV	{"phone": "+70698382591"}
0005432675572	26311E	1223 386836	VERA NAUMOVA	{"email": "naumova-vera-27111976@postgrespro.ru", "phone": "+70247571126"}
0005432675573	1D76DD	1174 412060	GALINA NIKITINA	{"phone": "+70492849769"}
0005432675574	1D76DD	3613 609991	TATYANA VASILEVA	{"email": "vasileva.t-031982@postgrespro.ru", "phone": "+70514776224"}
0005432675575	883761	0248 902991	AIDA AKIMOVA	{"phone": "+70504254047"}
0005432675576	1A072D	9140 476111	NATALYA SEMENOVA	{"phone": "+70999478484"}
0005432675577	B8B67B	2888 688577	ROMAN BORISOV	{"phone": "+70457096745"}
0005432675578	03EE38	7986 792077	EVGENIYA FILIPPOVA	{"email": "evgeniya_filippova.1968@postgrespro.ru", "phone": "+70975858937"}
0005432675579	03EE38	3041 974814	DARYA PAVLOVA	{"email": "pavlova.d-02041975@postgrespro.ru", "phone": "+70269087164"}
0005432675580	54CC8D	6367 230606	VALENTINA ZAKHAROVA	{"phone": "+70835559094"}
0005432675581	0A68E9	8850 719972	DANIL FROLOV	{"phone": "+70861331328"}
0005432675582	0A68E9	7899 218601	TATYANA TITOVA	{"phone": "+70313394935"}
0005432675583	EA72A5	1705 180199	IRINA KUZNECOVA	{"email": "irina_kuznecova11051978@postgrespro.ru", "phone": "+70832883584"}
0005432675584	955A11	0139 418741	OKSANA KONDRATEVA	{"phone": "+70406190949"}
0005432675585	81C7DA	1620 948786	VERA MASLOVA	{"email": "maslovavera_1973@postgrespro.ru", "phone": "+70670968728"}
0005432675586	81C7DA	5536 790678	IVAN ILIN	{"phone": "+70412642118"}
0005432675587	B67E0C	8200 208012	MARIYA ALEKSEEVA	{"email": "mariyaalekseeva.1969@postgrespro.ru", "phone": "+70059438224"}
0005432677503	0AD807	4600 958574	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov1961@postgrespro.ru", "phone": "+70002881989"}
0005432677504	D234D5	4310 360733	ANDREY MAKAROV	{"email": "a-makarov-10121974@postgrespro.ru", "phone": "+70872924196"}
0005432677505	D234D5	1854 794644	DINA PETROVA	{"phone": "+70330405665"}
0005432677506	D234D5	1021 703486	LIDIYA YAKOVLEVA	{"phone": "+70831505136"}
0005432677507	E0D489	8392 360461	RAISA KUZNECOVA	{"email": "raisa.kuznecova-1965@postgrespro.ru", "phone": "+70948688110"}
0005432677508	630307	2908 637106	OLEG SEMENOV	{"phone": "+70178940674"}
0005432677509	630307	3084 765598	ELENA BOGDANOVA	{"email": "elena.bogdanova_101971@postgrespro.ru", "phone": "+70373055715"}
0005432677510	630307	9222 753878	ALEKSANDR SERGEEV	{"email": "sergeev_a_111976@postgrespro.ru", "phone": "+70882534382"}
0005432677511	7A6E0C	0076 522588	PRASKOVYA BORISOVA	{"email": "borisovap10111962@postgrespro.ru", "phone": "+70214152828"}
0005432677512	7A6E0C	6759 768419	NATALYA GORBUNOVA	{"phone": "+70846583270"}
0005432677513	1FD42B	2332 955199	VALENTINA MAKSIMOVA	{"phone": "+70914248253"}
0005432677514	1FD42B	4830 948676	ALEKSANDR KUZMIN	{"email": "kuzmin_a-10071961@postgrespro.ru", "phone": "+70054500339"}
0005432677515	773F43	7411 100132	ELENA MEDVEDEVA	{"email": "medvedeva_elena-041971@postgrespro.ru", "phone": "+70751881970"}
0005432677516	773F43	6966 609412	VLADIMIR KULIKOV	{"phone": "+70690701492"}
0005432677517	0E0E6E	3920 262672	ELENA FEDOROVA	{"phone": "+70071575710"}
0005432677518	C42029	3638 850378	EKATERINA DENISOVA	{"phone": "+70494774696"}
0005432677519	E6C843	9602 459936	NATALYA MAKAROVA	{"phone": "+70765037582"}
0005432677520	05CA54	3434 755856	GLEB ALEKSANDROV	{"email": "gleb-aleksandrov121976@postgrespro.ru", "phone": "+70854361848"}
0005432677521	BB4809	3097 222053	ANNA TARASOVA	{"phone": "+70339788337"}
0005432677522	BB4809	0467 724951	ELENA LOGINOVA	{"email": "elena-loginova_25091969@postgrespro.ru", "phone": "+70023338658"}
0005432677523	3D8B6A	5395 698994	KSENIYA BELYAEVA	{"phone": "+70510912635"}
0005432677524	4A5240	4353 544515	MAKSIM GAVRILOV	{"email": "gavrilov-m101965@postgrespro.ru", "phone": "+70341669940"}
0005432677525	4A5240	1284 390685	DMITRIY BONDARENKO	{"email": "bondarenko_d-031973@postgrespro.ru", "phone": "+70213622487"}
0005432677526	B16279	3238 321216	SERGEY KOROLEV	{"email": "korolev-s_1982@postgrespro.ru", "phone": "+70881958156"}
0005432677527	8C4922	6325 218952	YURIY ABRAMOV	{"email": "y.abramov.1971@postgrespro.ru", "phone": "+70096969141"}
0005432677528	58C173	4323 847283	ANTON ZHUKOV	{"phone": "+70104826127"}
0005432677529	61261C	2446 665994	EVGENIY SEMENOV	{"phone": "+70395180813"}
0005432677530	244713	2760 465125	ZAKHAR MELNIKOV	{"email": "zakhar_melnikov27111978@postgrespro.ru", "phone": "+70260196670"}
0005432677531	A76FE8	3567 753764	YULIYA BARANOVA	{"phone": "+70006102136"}
0005432677532	A76FE8	3347 585446	PAVEL KRASNOV	{"email": "krasnov.p-28051963@postgrespro.ru", "phone": "+70111130460"}
0005432677533	9E2CD1	1331 991401	TATYANA SMIRNOVA	{"email": "smirnova_t031968@postgrespro.ru", "phone": "+70790461485"}
0005432677534	D4E24E	4729 357413	KIRILL PETROV	{"phone": "+70974717284"}
0005432677535	F6A758	4515 348633	EVGENIY SIDOROV	{"email": "e.sidorov.26061982@postgrespro.ru", "phone": "+70599700975"}
0005432677536	F6A758	0924 571590	LYUDMILA GAVRILOVA	{"email": "gavrilovalyudmila1971@postgrespro.ru", "phone": "+70704007176"}
0005432677537	DA2B54	2872 074322	GALINA GAVRILOVA	{"email": "gavrilova.g-1972@postgrespro.ru", "phone": "+70622244985"}
0005432677538	DA2B54	8750 896725	ANASTASIYA OSIPOVA	{"email": "anastasiya-osipova.1983@postgrespro.ru", "phone": "+70801144145"}
0005432677539	9079EA	1104 721295	DARYA MAKAROVA	{"email": "d_makarova_121973@postgrespro.ru", "phone": "+70438740967"}
0005432677540	54AA14	5407 828606	KLAVDIYA GORBUNOVA	{"phone": "+70959343989"}
0005432677541	54AA14	9214 154248	YURIY BORISOV	{"email": "borisov-y_13041974@postgrespro.ru", "phone": "+70036045153"}
0005432677542	9775D6	3586 133720	RAISA FOMINA	{"email": "fomina-raisa.021970@postgrespro.ru", "phone": "+70658435045"}
0005432677543	9775D6	5497 226835	GALINA MOROZOVA	{"phone": "+70634748925"}
0005432677544	8E0CBC	2714 925319	ARTUR FEDOROV	{"email": "arturfedorov031981@postgrespro.ru", "phone": "+70084089588"}
0005432677545	DD185B	3863 477349	IVAN SERGEEV	{"email": "sergeev.i011965@postgrespro.ru", "phone": "+70994451458"}
0005432677546	55A1F0	6341 391581	EKATERINA KUZMINA	{"email": "kuzminaekaterina.031963@postgrespro.ru", "phone": "+70627674300"}
0005432677547	55A1F0	3565 762229	GALINA VASILEVA	{"phone": "+70690250930"}
0005432677548	17056F	6723 193358	SERGEY MOISEEV	{"email": "moiseev.sergey.24101963@postgrespro.ru", "phone": "+70976943606"}
0005432677549	21BE46	7746 228156	NATALYA MAKAROVA	{"email": "natalya_makarova_061972@postgrespro.ru", "phone": "+70978685078"}
0005432677550	1B8D59	9925 707323	VIKTOR MAKSIMOV	{"phone": "+70034967241"}
0005432677551	5F7EF2	6521 869410	KONSTANTIN RODIONOV	{"email": "rodionov.konstantin-07111966@postgrespro.ru", "phone": "+70712711279"}
0005432677552	7F1FAD	4627 677137	ALEKSANDR IVANOV	{"email": "ivanov-a-13041967@postgrespro.ru", "phone": "+70686605739"}
0005432677553	7F1FAD	3482 263869	SERGEY ALEKSANDROV	{"email": "aleksandrov.sergey-1964@postgrespro.ru", "phone": "+70615895985"}
0005432677554	EFE2EB	4268 531401	YULIYA ANDREEVA	{"phone": "+70060630379"}
0005432677555	04B496	9821 379757	TAMARA YUDINA	{"email": "yudina-tamara_1972@postgrespro.ru", "phone": "+70876473461"}
0005432677556	F5EAA1	9639 268619	OLGA BOGDANOVA	{"phone": "+70172495230"}
0005432677557	F5EAA1	1610 880705	PETR MAKAROV	{"phone": "+70427629907"}
0005432677558	E9B2C3	6560 379077	VIKTORIYA RODIONOVA	{"email": "rodionova_v.01051978@postgrespro.ru", "phone": "+70123226353"}
0005432677559	E9B2C3	5018 093199	DMITRIY TIKHONOV	{"phone": "+70223276060"}
0005432677560	0803D6	6500 521480	VYACHESLAV BELOV	{"email": "v.belov-091970@postgrespro.ru", "phone": "+70380012991"}
0005432677561	0803D6	2978 968916	EVGENIYA NIKITINA	{"phone": "+70082071850"}
0005432677562	F85EC8	5408 566864	POLINA VLASOVA	{"email": "polina-vlasova.021986@postgrespro.ru", "phone": "+70934092480"}
0005432677563	F85EC8	6920 298455	KIRILL NIKITIN	{"phone": "+70098208209"}
0005432677564	A682A1	2494 314817	SERGEY KULIKOV	{"phone": "+70901409461"}
0005432677565	A682A1	6871 885759	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev.031969@postgrespro.ru", "phone": "+70332499072"}
0005432677566	82116B	5903 828523	SERGEY NAZAROV	{"email": "nazarov.sergey.011970@postgrespro.ru", "phone": "+70064830250"}
0005432677567	BCEDE2	9975 522923	OLGA SMIRNOVA	{"email": "olgasmirnova-25101967@postgrespro.ru", "phone": "+70831792100"}
0005432677568	0F6D32	7619 140828	ELENA ERMAKOVA	{"phone": "+70668278533"}
0005432677569	A5A3E0	4441 967697	DENIS TARASOV	{"email": "tarasovd081981@postgrespro.ru", "phone": "+70079321478"}
0005432677570	A019C8	7487 958304	NATALYA IVANOVA	{"phone": "+70816245098"}
0005432677571	A019C8	7276 990870	MIKHAIL OSIPOV	{"phone": "+70281819056"}
0005432677572	3921FF	0239 584425	LYUDMILA NIKIFOROVA	{"phone": "+70031881841"}
0005432677573	D4FD06	7845 495379	ELENA EGOROVA	{"phone": "+70886419569"}
0005432677574	01BD6B	2918 411821	OLGA NESTEROVA	{"email": "nesterova-olga-28041974@postgrespro.ru", "phone": "+70342701873"}
0005432677575	F0AE59	7881 160981	SVETLANA MAKAROVA	{"email": "smakarova-011979@postgrespro.ru", "phone": "+70339768825"}
0005432677576	F0AE59	3925 904230	NATALYA FILATOVA	{"email": "filatovan-02011972@postgrespro.ru", "phone": "+70611208534"}
0005432677577	185323	6478 469063	VLADIMIR SMIRNOV	{"email": "v_smirnov.1959@postgrespro.ru", "phone": "+70681134435"}
0005432677578	6A7EF9	1885 331966	NIKOLAY KARPOV	{"phone": "+70932587495"}
0005432677579	EEFDE1	0132 503235	ALEKSEY SCHERBAKOV	{"phone": "+70711548514"}
0005432677580	F7C00A	5523 541444	MARINA SERGEEVA	{"email": "sergeeva-m.18051973@postgrespro.ru", "phone": "+70328406277"}
0005432677581	F7C00A	5323 738667	DENIS ISAEV	{"email": "disaev18021983@postgrespro.ru", "phone": "+70819732882"}
0005432677582	6A3FB9	4620 348869	NATALYA NOVIKOVA	{"email": "natalya-novikova021975@postgrespro.ru", "phone": "+70791322386"}
0005432677583	6A3FB9	4520 876095	NINA DAVYDOVA	{"email": "davydova_nina-1950@postgrespro.ru", "phone": "+70342964758"}
0005432677584	6A3FB9	7389 337991	ALEKSANDR TARASOV	{"email": "tarasov_a.30051974@postgrespro.ru", "phone": "+70664465254"}
0005432677585	EB3551	8954 393319	EKATERINA TITOVA	{"email": "titova-ekaterina_1968@postgrespro.ru", "phone": "+70359350882"}
0005432677586	ED4339	2311 057404	VASILIY KOZLOV	{"phone": "+70319376743"}
0005432677587	ED4339	4077 683963	GALINA FROLOVA	{"phone": "+70626270300"}
0005432677588	D001F0	3198 127611	LIDIYA KRASNOVA	{"email": "krasnova.l_14031966@postgrespro.ru", "phone": "+70106860950"}
0005432677589	EC86A8	1873 393753	TATYANA KUZNECOVA	{"phone": "+70357845899"}
0005432677590	B23F67	7421 189598	MARINA BORISOVA	{"phone": "+70147541235"}
0005432677591	0AAC3E	7350 435996	ELENA TIMOFEEVA	{"email": "timofeevae.091973@postgrespro.ru", "phone": "+70298093916"}
0005432677592	7DDA79	0289 981310	IRINA BORISOVA	{"email": "borisovai-1975@postgrespro.ru", "phone": "+70286831471"}
0005432677593	7DDA79	3177 285551	VALENTINA TARASOVA	{"email": "tarasova_valentina04011971@postgrespro.ru", "phone": "+70550329470"}
0005432677594	A1D00A	8651 030543	LILIYA NESTEROVA	{"email": "l_nesterova.1965@postgrespro.ru", "phone": "+70004030933"}
0005432677595	A1D00A	7965 121778	ANASTASIYA ANDREEVA	{"email": "anastasiya.andreeva_1965@postgrespro.ru", "phone": "+70809578373"}
0005432677596	A1D00A	6317 829453	ALEKSANDR GRIGOREV	{"phone": "+70969837127"}
0005432677597	B7A95B	5400 020288	EKATERINA KUDRYASHOVA	{"email": "kudryashova.e_16081988@postgrespro.ru", "phone": "+70257969948"}
0005432677598	2E8CE1	5713 668305	ELENA SOROKINA	{"phone": "+70437110011"}
0005432677599	2E8CE1	4401 259214	ANDREY KULIKOV	{"email": "kulikov_andrey-18101977@postgrespro.ru", "phone": "+70023972001"}
0005432677600	45DBFD	2589 768239	DANIYA KOROLEVA	{"phone": "+70436991622"}
0005432677601	45DBFD	1762 518926	ANASTASIYA VASILEVA	{"email": "vasilevaa17031992@postgrespro.ru", "phone": "+70019744582"}
0005432677602	92BD2D	2293 210166	ANNA NOVIKOVA	{"email": "novikova-a.031979@postgrespro.ru", "phone": "+70858313774"}
0005432677603	551117	0825 674219	VIKTOR ZHUKOV	{"phone": "+70495309247"}
0005432677604	9D8A05	6045 721845	ANDREY RODIONOV	{"email": "a.rodionov-27071974@postgrespro.ru", "phone": "+70404066478"}
0005432677605	B9B4EE	8680 671213	SERGEY KAZAKOV	{"email": "sergey-kazakov061974@postgrespro.ru", "phone": "+70564703237"}
0005432677606	B9B4EE	1672 295440	ALEKSANDR NAZAROV	{"phone": "+70355127916"}
0005432677607	B9B4EE	8654 096436	ANNA ROMANOVA	{"email": "anna-romanova-1975@postgrespro.ru", "phone": "+70229701471"}
0005432677608	FA588D	9771 411854	ELENA POPOVA	{"email": "e.popova1984@postgrespro.ru", "phone": "+70467089856"}
0005432677609	4FCDCB	8415 686945	ROZA VASILEVA	{"email": "rvasileva-1963@postgrespro.ru", "phone": "+70822757778"}
0005432677610	E7DCC4	8155 381867	NADEZHDA ZOTOVA	{"email": "n-zotova.1959@postgrespro.ru", "phone": "+70409116729"}
0005432677611	07A8FA	7581 443292	PAVEL CHERNOV	{"phone": "+70601015853"}
0005432677612	07A8FA	2596 152920	ANTON SCHERBAKOV	{"email": "scherbakovanton.25071973@postgrespro.ru", "phone": "+70685247515"}
0005432677613	04FD90	6060 868376	VYACHESLAV MATVEEV	{"email": "matveevv_20051973@postgrespro.ru", "phone": "+70134468884"}
0005432677614	342738	6639 329649	LIDIYA LUKYANOVA	{"email": "lukyanoval_27041965@postgrespro.ru", "phone": "+70069900211"}
0005432677615	451CA9	4696 275728	YULIYA KONDRATEVA	{"phone": "+70665222564"}
0005432677616	396351	1878 791038	ILYAS KISELEV	{"email": "kiselev.i.21011974@postgrespro.ru", "phone": "+70776422536"}
0005432677617	0BA81B	8725 256552	VLADIMIR SHEVCHENKO	{"phone": "+70764253325"}
0005432677618	F7E61D	5866 776927	VALENTINA MELNIKOVA	{"email": "valentina-melnikova.1967@postgrespro.ru", "phone": "+70565830437"}
0005432677619	D1F778	9917 055642	RAISA MOISEEVA	{"email": "moiseevaraisa.1979@postgrespro.ru", "phone": "+70900863390"}
0005432677620	AB7F47	8636 336456	OKSANA MEDVEDEVA	{"email": "oksana_medvedeva061974@postgrespro.ru", "phone": "+70748015605"}
0005432677621	503117	6641 066295	RUSLAN ROMANOV	{"phone": "+70070271923"}
0005432677622	6C7CEF	2682 022709	GALINA KUZMINA	{"email": "kuzmina.galina-30031978@postgrespro.ru", "phone": "+70836553230"}
0005432677623	F11B89	3801 288105	SERGEY KUDRYASHOV	{"email": "kudryashov.s011968@postgrespro.ru", "phone": "+70426489535"}
0005432677624	F11B89	7447 304860	DMITRIY VOLKOV	{"email": "d-volkov-07051953@postgrespro.ru", "phone": "+70418904666"}
0005432677625	5BC16F	0088 497515	EKATERINA KUZMINA	{"phone": "+70738671455"}
0005432677626	667BDA	0556 342946	NATALYA KOLESNIKOVA	{"email": "n.kolesnikova_1967@postgrespro.ru", "phone": "+70587127453"}
0005432677627	667BDA	9665 408953	ANNA STEPANOVA	{"phone": "+70320013759"}
0005432677628	667BDA	9286 627886	SVETLANA FEDOROVA	{"phone": "+70180676505"}
0005432677629	8DFACF	4525 373985	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-1981@postgrespro.ru", "phone": "+70311413063"}
0005432677630	7737AC	5082 946241	NATALYA NIKOLAEVA	{"email": "natalyanikolaeva.24051959@postgrespro.ru", "phone": "+70301678073"}
0005432677631	CD9ED3	0819 506542	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina_15081970@postgrespro.ru", "phone": "+70050553871"}
0005432677632	C1F221	5144 602272	NATALYA SAVELEVA	{"email": "saveleva.n1978@postgrespro.ru", "phone": "+70091004864"}
0005432677633	58B96C	5576 576631	OLGA STEPANOVA	{"email": "stepanova.olga_29111968@postgrespro.ru", "phone": "+70572557391"}
0005432677634	58B96C	0266 890053	GALINA KOLESNIKOVA	{"email": "kolesnikova.g_081973@postgrespro.ru", "phone": "+70716795443"}
0005432677635	84952E	7466 974138	ANDREY SOKOLOV	{"email": "a.sokolov-061974@postgrespro.ru", "phone": "+70411608398"}
0005432677636	3F1BE5	4502 884406	ANDREY SEMENOV	{"email": "semenov.a-061978@postgrespro.ru", "phone": "+70853081980"}
0005432677637	9C8D8C	0073 539055	VLADIMIR TIMOFEEV	{"phone": "+70805460643"}
0005432677638	9C8D8C	0933 925138	NATALYA ANTONOVA	{"phone": "+70154884579"}
0005432677639	2ACE6D	9728 624875	MARIYA GORBUNOVA	{"email": "gorbunovamariya.081977@postgrespro.ru", "phone": "+70983102823"}
0005432677640	2ACE6D	8606 869786	VSEVOLOD MOROZOV	{"phone": "+70385191869"}
0005432677641	FF90FF	4275 924109	NATALIYA ILINA	{"phone": "+70615880789"}
0005432677642	95F2FA	7308 735770	ALEKSANDR POPOV	{"phone": "+70267185453"}
0005432677643	95F2FA	4061 901643	ANATOLIY ALEKSEEV	{"email": "anatoliy_alekseev1968@postgrespro.ru", "phone": "+70282539643"}
0005432677644	3B3FAB	5345 458665	LYUBOV DENISOVA	{"phone": "+70559414774"}
0005432677645	987C55	9126 457784	DENIS SEMENOV	{"email": "d_semenov_101958@postgrespro.ru", "phone": "+70689375197"}
0005432677646	597803	0421 547387	SERGEY ALEKSEEV	{"phone": "+70096144862"}
0005432677647	597803	7533 050353	VADIM SERGEEV	{"email": "sergeev.vadim031987@postgrespro.ru", "phone": "+70113784817"}
0005432677648	0715D4	2046 155689	YURIY ANDREEV	{"phone": "+70591066316"}
0005432677649	ABFACC	9020 416946	VLADIMIR EGOROV	{"email": "egorov_vladimir_17051977@postgrespro.ru", "phone": "+70513836964"}
0005432677650	ABFACC	0260 454624	INNA TIMOFEEVA	{"phone": "+70519802001"}
0005432677651	7BDA2F	4512 047620	ALEKSANDR GERASIMOV	{"email": "gerasimovaleksandr-08111971@postgrespro.ru", "phone": "+70507088563"}
0005432677652	346578	5651 396090	PAVEL ZAKHAROV	{"email": "p-zakharov-04121975@postgrespro.ru", "phone": "+70087985658"}
0005432677653	346578	1654 061490	ELENA FILIPPOVA	{"phone": "+70613939131"}
0005432677654	7020F0	0754 478582	LYUDMILA FILIPPOVA	{"email": "lyudmilafilippova1970@postgrespro.ru", "phone": "+70979468865"}
0005432677655	7020F0	4375 633802	VLADIMIR KUZNECOV	{"phone": "+70220946812"}
0005432677656	911EBC	2790 074705	OLGA FROLOVA	{"phone": "+70618232051"}
0005432677657	E2C93E	5364 791517	NINA ARKHIPOVA	{"email": "narkhipova-1967@postgrespro.ru", "phone": "+70834824074"}
0005432677658	E2C93E	0611 063097	ARTEM KUDRYASHOV	{"email": "artemkudryashov.1970@postgrespro.ru", "phone": "+70756258561"}
0005432677659	5BB048	2301 500280	MAKSIM NIKOLAEV	{"phone": "+70961851482"}
0005432677660	F6DFCD	0086 024103	VLADIMIR POPOV	{"phone": "+70510404529"}
0005432677661	58D45A	9261 275848	MAKSIM MAKAROV	{"phone": "+70526316340"}
0005432677662	3A12C0	6430 213166	TATYANA LUKYANOVA	{"email": "lukyanova-t_121972@postgrespro.ru", "phone": "+70231967533"}
0005432677663	3A12C0	8657 005304	ELENA KOZLOVA	{"email": "kozlovae_06021966@postgrespro.ru", "phone": "+70168378959"}
0005432677664	8585E0	0333 768949	ANDREY ZAKHAROV	{"email": "zakharov.andrey.121973@postgrespro.ru", "phone": "+70128196449"}
0005432677665	CE71A9	7766 058571	TATYANA VOLKOVA	{"email": "tatyana-volkova.1976@postgrespro.ru", "phone": "+70868624575"}
0005432677666	846864	9868 855047	TATYANA DANILOVA	{"email": "tatyanadanilova-1979@postgrespro.ru", "phone": "+70829785486"}
0005432677667	846864	1101 122755	ANATOLIY GAVRILOV	{"phone": "+70342642054"}
0005432677668	21442F	6287 632470	TATYANA BELOVA	{"email": "belova-tatyana061971@postgrespro.ru", "phone": "+70620446182"}
0005432677669	21442F	0492 452329	TAGIR KUZNECOV	{"email": "kuznecov-tagir04091980@postgrespro.ru", "phone": "+70121209726"}
0005432677670	5D044D	3224 689574	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov.081973@postgrespro.ru", "phone": "+70377574043"}
0005432677671	B08477	1928 293133	TATYANA OVCHINNIKOVA	{"email": "ovchinnikovat_1971@postgrespro.ru", "phone": "+70240955178"}
0005432677672	81B040	1119 237406	NADEZHDA KOROLEVA	{"phone": "+70918081863"}
0005432677673	26BEB8	3826 283664	LIDIYA AFANASEVA	{"phone": "+70964068976"}
0005432677674	26BEB8	5907 226838	IRINA NIKOLAEVA	{"email": "nikolaeva.i-19031964@postgrespro.ru", "phone": "+70016588866"}
0005432677675	33F3BD	9760 693539	MIKHAIL KUZNECOV	{"email": "mkuznecov.01111967@postgrespro.ru", "phone": "+70461249957"}
0005432677676	FE8F7B	4410 882453	IRINA VOLKOVA	{"email": "volkova.i1963@postgrespro.ru", "phone": "+70296956444"}
0005432677677	E905B4	9356 215089	ALEKSEY VOROBEV	{"email": "vorobev.a1969@postgrespro.ru", "phone": "+70787009150"}
0005432677678	7AB088	9028 440735	GALINA NIKIFOROVA	{"phone": "+70185618433"}
0005432677679	53CE2C	9949 045197	TATYANA ZHUKOVA	{"email": "t_zhukova_061966@postgrespro.ru", "phone": "+70806200389"}
0005432677680	53CE2C	7821 426196	TATYANA MARTYNOVA	{"email": "t.martynova-1972@postgrespro.ru", "phone": "+70128802214"}
0005432677681	5E97FE	0623 813765	IGOR DENISOV	{"phone": "+70811244089"}
0005432677682	5E97FE	5770 841551	INNA BARANOVA	{"email": "i-baranova.121976@postgrespro.ru", "phone": "+70727573989"}
0005432677683	7BDED5	5673 602140	ELIZAVETA FADEEVA	{"phone": "+70054709753"}
0005432677684	7BDED5	6235 948382	TAISIYA BELOVA	{"email": "belova-taisiya01071974@postgrespro.ru", "phone": "+70742367007"}
0005432677685	8EA0B1	9178 285612	ANTON NIKOLAEV	{"email": "antonnikolaev.23121962@postgrespro.ru", "phone": "+70191661826"}
0005432677686	FE5947	4207 096848	YURIY FOMIN	{"phone": "+70472217532"}
0005432677687	1938B0	2017 819471	ROMAN NOVIKOV	{"email": "roman-novikov-1976@postgrespro.ru", "phone": "+70989600212"}
0005432677688	EF44D3	4283 273071	EVGENIY KUZNECOV	{"phone": "+70057140493"}
0005432677689	0964AC	1234 667764	GAGIK SHEVCHENKO	{"email": "shevchenko-g_1978@postgrespro.ru", "phone": "+70705557155"}
0005432677690	ECD1FA	7775 398935	ELENA RODIONOVA	{"email": "e-rodionova-20111991@postgrespro.ru", "phone": "+70444957281"}
0005432677691	E28B88	5207 668568	ANASTASIYA PAVLOVA	{"phone": "+70915256309"}
0005432677692	E28B88	7500 120363	YULIYA KUZNECOVA	{"email": "kuznecova-y15071980@postgrespro.ru", "phone": "+70699839394"}
0005432692527	91F51F	3894 125144	NATALYA NIKITINA	{"phone": "+70425054855"}
0005432692528	160A42	1985 504943	PAVEL POPOV	{"email": "popovpavel.021965@postgrespro.ru", "phone": "+70360072661"}
0005432692529	CD4E14	9621 295675	ANDREY MATVEEV	{"email": "matveev-a_1964@postgrespro.ru", "phone": "+70616898492"}
0005432692530	CD4E14	3866 921496	DMITRIY PETROV	{"email": "petrov-d_30111982@postgrespro.ru", "phone": "+70768127878"}
0005432692531	3C0A37	2260 303508	ANNA BELOVA	{"email": "a-belova_1966@postgrespro.ru", "phone": "+70341426237"}
0005432692532	FDE7A6	7177 145869	MAKSIM POPOV	{"email": "popov-maksim091967@postgrespro.ru", "phone": "+70751244597"}
0005432692533	D70842	4215 234776	VLADA MEDVEDEVA	{"email": "medvedeva.v061974@postgrespro.ru", "phone": "+70003555148"}
0005432692534	8A9310	0672 082144	IRINA KUZNECOVA	{"email": "i_kuznecova_1973@postgrespro.ru", "phone": "+70364312778"}
0005432692535	9B7DFE	7680 186104	EVGENIYA KAZAKOVA	{"phone": "+70761957639"}
0005432692536	81AB0F	6130 638545	OLGA ERMAKOVA	{"phone": "+70176518752"}
0005432692537	2CC9B1	6337 554437	DMITRIY BARANOV	{"phone": "+70337361407"}
0005432692538	1CF867	6516 863135	SERGEY BELOV	{"phone": "+70096182023"}
0005432692539	1CF867	9100 123343	ELENA ISAEVA	{"email": "isaeva_elena1977@postgrespro.ru", "phone": "+70794923824"}
0005432692540	E0CDCC	4689 471623	ARKADIY DAVYDOV	{"phone": "+70854901516"}
0005432692541	412504	0055 588022	GALINA FILATOVA	{"email": "g-filatova_05071990@postgrespro.ru", "phone": "+70317698192"}
0005432692542	412504	3157 041043	NATALYA NOVIKOVA	{"email": "natalya-novikova.1976@postgrespro.ru", "phone": "+70045474490"}
0005432692543	DCE143	8827 773693	MIKHAIL ZHUKOV	{"phone": "+70767541555"}
0005432692544	400290	0348 660767	KONSTANTIN PAVLOV	{"email": "pavlov_k_1971@postgrespro.ru", "phone": "+70257156709"}
0005432692545	400290	3139 645613	ALEKSEY ZAKHAROV	{"phone": "+70009124244"}
0005432692546	400290	4590 286718	LIDIYA MARTYNOVA	{"email": "martynova.lidiya.121974@postgrespro.ru", "phone": "+70447616339"}
0005432692547	EF1E5A	6104 281483	ANTON KUZNECOV	{"phone": "+70647916748"}
0005432692548	5F99B7	3444 857206	VALENTINA POPOVA	{"phone": "+70751745457"}
0005432692549	131AC0	1285 773854	TATYANA SOROKINA	{"email": "sorokina.tatyana-041977@postgrespro.ru", "phone": "+70152677553"}
0005432692550	131AC0	4389 743183	DANIIL MEDVEDEV	{"phone": "+70345401050"}
0005432692551	ABC983	6569 192341	SVETLANA KOROLEVA	{"phone": "+70942460432"}
0005432692552	07EA4A	0116 634202	VALERIY BONDARENKO	{"email": "bondarenkovaleriy-1969@postgrespro.ru", "phone": "+70087033146"}
0005432692553	8AA182	6654 963659	OLGA OSIPOVA	{"phone": "+70725097359"}
0005432692554	8AA182	2095 316892	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko021973@postgrespro.ru", "phone": "+70187679503"}
0005432692555	8AA182	7448 393978	SVETLANA MAKAROVA	{"phone": "+70921737572"}
0005432692556	44983C	1973 885102	ILGIZ KARPOV	{"email": "karpov_ilgiz081970@postgrespro.ru", "phone": "+70331445858"}
0005432692557	2474A3	4706 350073	ALEKSANDRA VOLKOVA	{"phone": "+70456661940"}
0005432692558	9C275F	3611 109785	EVGENIY TIKHONOV	{"phone": "+70044088012"}
0005432692559	9E7F16	1907 087118	YURIY STEPANOV	{"phone": "+70692353488"}
0005432692560	9E7F16	9674 655037	ELENA GERASIMOVA	{"phone": "+70183899762"}
0005432692561	2B844D	2530 545598	EVGENIY VASILEV	{"email": "evasilev-1986@postgrespro.ru", "phone": "+70185759452"}
0005432692562	2B844D	9206 016470	MIKHAIL ANDREEV	{"email": "andreev_m1983@postgrespro.ru", "phone": "+70627367132"}
0005432692563	E9653B	9668 372867	VALERIY IVANOV	{"email": "v_ivanov_29121967@postgrespro.ru", "phone": "+70320557924"}
0005432692564	E6B204	4850 670249	VIKTORIYA SMIRNOVA	{"phone": "+70748345395"}
0005432692565	433246	8404 974957	MIKHAIL BONDARENKO	{"phone": "+70192419970"}
0005432692566	E3E351	5801 402229	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov-101965@postgrespro.ru", "phone": "+70713673922"}
0005432692567	E3E351	9432 416895	SERGEY MOROZOV	{"email": "morozov_s-24041971@postgrespro.ru", "phone": "+70800096619"}
0005432692568	80D932	8648 136858	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov_18071971@postgrespro.ru", "phone": "+70556959647"}
0005432692569	80D932	3223 348895	ANATOLIY POPOV	{"phone": "+70893463573"}
0005432692570	67D017	3394 530494	ANNA KOROLEVA	{"phone": "+70034165371"}
0005432692571	091D84	2853 321394	VIKTOR MEDVEDEV	{"phone": "+70261896060"}
0005432692572	EEAA70	4433 055349	TAMARA AKIMOVA	{"email": "t-akimova-1991@postgrespro.ru", "phone": "+70646093947"}
0005432692573	C3700E	3603 863862	YURIY GRIGOREV	{"phone": "+70325768011"}
0005432692574	B6C554	6484 471091	NATALYA ILINA	{"phone": "+70171748791"}
0005432692575	B6C554	5418 695840	EVGENIYA BOGDANOVA	{"phone": "+70616780162"}
0005432692576	85C10D	2327 308225	SERGEY BORISOV	{"email": "borisov_s_1968@postgrespro.ru", "phone": "+70942097137"}
0005432692577	85C10D	3577 317622	PAVEL VOROBEV	{"email": "pavel_vorobev-19091961@postgrespro.ru", "phone": "+70240343307"}
0005432692578	ED8323	1062 710313	PETR PETROV	{"phone": "+70470973689"}
0005432692579	A8A94C	4000 615840	YULIYA FEDOROVA	{"email": "fedorova.y_071962@postgrespro.ru", "phone": "+70830203773"}
0005432692580	A8A94C	6159 570521	NINA SOKOLOVA	{"phone": "+70748937110"}
0005432692581	AAE4DD	7893 768003	GALINA ANDREEVA	{"email": "g.andreeva_1963@postgrespro.ru", "phone": "+70547986841"}
0005432692582	095794	9890 373618	OLGA FILIPPOVA	{"phone": "+70254211204"}
0005432692583	051F5B	7410 963965	NIKITA KUZMIN	{"phone": "+70827169869"}
0005432692584	1741EE	8775 507093	VERA MEDVEDEVA	{"phone": "+70317073640"}
0005432692585	1741EE	2909 435655	VLADISLAV MAKAROV	{"phone": "+70444274071"}
0005432692586	1741EE	9455 357561	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr_1978@postgrespro.ru", "phone": "+70617808262"}
0005432692587	4A3612	2489 365538	IVAN GRIGOREV	{"email": "grigorev.ivan1974@postgrespro.ru", "phone": "+70375034547"}
0005432692588	4A3612	3252 446112	OLGA DENISOVA	{"phone": "+70504420270"}
0005432692589	97CCA6	2688 103399	NATALYA PAVLOVA	{"phone": "+70866560239"}
0005432692590	BC081D	4490 467747	VIKTORIYA DENISOVA	{"phone": "+70884607914"}
0005432692591	F29856	4075 406914	SVETLANA FOMINA	{"email": "fomina-s_10091966@postgrespro.ru", "phone": "+70675162372"}
0005432692592	102B29	0777 346940	NIKOLAY FROLOV	{"phone": "+70870675841"}
0005432692593	102B29	7076 707404	EDUARD KUZMIN	{"phone": "+70473484383"}
0005432692594	CBE5AB	7760 764118	VLADIMIR FOMIN	{"phone": "+70347298241"}
0005432692595	CBE5AB	5104 376374	ALEKSANDRA KOLESNIKOVA	{"phone": "+70093452398"}
0005432692596	CBE5AB	0386 639019	VERA FILIPPOVA	{"email": "filippova_v_11021971@postgrespro.ru", "phone": "+70186860217"}
0005432692597	0A0739	0082 848661	ELENA PETROVA	{"email": "epetrova_1977@postgrespro.ru", "phone": "+70500389905"}
0005432692598	65A20E	0793 750731	OLGA GUSEVA	{"email": "guseva.olga.011984@postgrespro.ru", "phone": "+70710485497"}
0005432692599	24041E	8853 871211	MAKSIM VASILEV	{"phone": "+70868516149"}
0005432692600	24041E	8523 636138	ALEKSEY SEMENOV	{"phone": "+70384432461"}
0005432692601	A0E46D	6425 553475	MARINA ANISIMOVA	{"email": "anisimova.m.1964@postgrespro.ru", "phone": "+70048840492"}
0005432692602	0E779E	6494 084729	ALEKSANDR DMITRIEV	{"phone": "+70564040671"}
0005432692603	C3F620	4504 229017	DENIS RODIONOV	{"phone": "+70875055836"}
0005432692604	03EDEA	4897 219251	ILYA ZAKHAROV	{"email": "zakharov-ilya-1991@postgrespro.ru", "phone": "+70989009345"}
0005432692605	A4DD36	4858 372521	VADIM MARTYNOV	{"phone": "+70805335611"}
0005432692606	A4DD36	7471 844224	IRAIDA OSIPOVA	{"email": "osipova.iraida.06051981@postgrespro.ru", "phone": "+70125880591"}
0005432692607	A4DD36	8689 297688	MARINA KUZNECOVA	{"phone": "+70628006267"}
0005432692608	F49993	0013 197258	DARYA KUZNECOVA	{"email": "darya_kuznecova-021983@postgrespro.ru", "phone": "+70725527290"}
0005432692609	064AFC	6160 075298	ANATOLIY GORBUNOV	{"email": "gorbunovanatoliy081959@postgrespro.ru", "phone": "+70147456330"}
0005432692610	064AFC	6096 171450	OKSANA MASLOVA	{"email": "o.maslova_1966@postgrespro.ru", "phone": "+70179589119"}
0005432692611	064AFC	3138 088545	EVGENIYA CHERNOVA	{"phone": "+70473342220"}
0005432692612	627E65	6516 394080	LYUBOV ZAKHAROVA	{"email": "zakharova_lyubov-1965@postgrespro.ru", "phone": "+70181097350"}
0005432692613	627E65	5995 807479	LYUDMILA KRASNOVA	{"phone": "+70621797739"}
0005432692614	480BC1	8737 470119	YURIY MIRONOV	{"email": "yuriy.mironov021972@postgrespro.ru", "phone": "+70111622167"}
0005432692615	D9E461	0104 847199	VASILIY DMITRIEV	{"phone": "+70357344689"}
0005432692616	756403	5614 557291	IRAIDA MEDVEDEVA	{"email": "medvedeva.i-15021973@postgrespro.ru", "phone": "+70852065528"}
0005432692617	756403	9818 466445	ALEKSANDR POPOV	{"email": "popov_aleksandr.30041963@postgrespro.ru", "phone": "+70859388330"}
0005432692618	3A2CB5	0769 981230	SVETLANA VASILEVA	{"email": "vasileva_s07071968@postgrespro.ru", "phone": "+70415710702"}
0005432692619	30AE25	8862 122285	VALENTINA KUZNECOVA	{"phone": "+70145977411"}
0005432692620	B30CAD	0047 599221	EVGENIY GORBUNOV	{"email": "gorbunov-e1965@postgrespro.ru", "phone": "+70726840138"}
0005432692621	B30CAD	1984 977973	SVETLANA ILINA	{"email": "ilina_s.16091974@postgrespro.ru", "phone": "+70039521309"}
0005432692622	14E049	9444 075159	TAMARA SAVELEVA	{"phone": "+70972911928"}
0005432692623	60A4F9	8677 529599	MATVEY KOROLEV	{"email": "m_korolev1969@postgrespro.ru", "phone": "+70071193461"}
0005432692624	60A4F9	4630 413498	TATYANA ZAKHAROVA	{"phone": "+70129551823"}
0005432692625	60A4F9	6202 971124	VLADIMIR BELOV	{"phone": "+70393732565"}
0005432692626	F9E83D	3062 832390	NIKOLAY ROMANOV	{"email": "nikolayromanov-011969@postgrespro.ru", "phone": "+70704641809"}
0005432692627	49F822	1393 506978	SERGEY NIKOLAEV	{"email": "nikolaevsergey.20081960@postgrespro.ru", "phone": "+70976217888"}
0005432692628	342D46	1048 811145	VLADIMIR STEPANOV	{"email": "vstepanov1959@postgrespro.ru", "phone": "+70504422875"}
0005432692629	342D46	7712 091369	GALINA NAUMOVA	{"phone": "+70955834673"}
0005432692630	731321	7593 630211	IRINA POLYAKOVA	{"phone": "+70531335373"}
0005432692631	809491	6995 375309	NATALYA POLYAKOVA	{"email": "polyakova-n-101974@postgrespro.ru", "phone": "+70607652494"}
0005432692632	77989D	7709 561034	LYUBOV DMITRIEVA	{"phone": "+70309118566"}
0005432692633	D4C405	2291 271068	NIKOLAY VOLKOV	{"email": "volkov-nikolay_25091967@postgrespro.ru", "phone": "+70812639217"}
0005432692634	F70EFC	2844 676268	ARTEM FEDOROV	{"email": "a_fedorov_04011971@postgrespro.ru", "phone": "+70187043067"}
0005432692635	481AA9	3204 585456	ARTEM SCHERBAKOV	{"email": "scherbakovartem-1960@postgrespro.ru", "phone": "+70350585758"}
0005432692636	1ECFEF	8898 716714	VITALIY FOMIN	{"email": "v-fomin-17051971@postgrespro.ru", "phone": "+70434124099"}
0005432692637	656554	1874 114534	MIKHAIL NIKITIN	{"phone": "+70787703860"}
0005432692638	929E50	3359 413812	MAKSIM POPOV	{"email": "popov_m-011971@postgrespro.ru", "phone": "+70005327440"}
0005432692639	929E50	3466 031321	NATALYA PETROVA	{"phone": "+70425312223"}
0005432692640	CAB2E0	4303 524672	TAMARA FOMINA	{"email": "fominat111969@postgrespro.ru", "phone": "+70756930948"}
0005432692641	00FCE4	7441 198192	YULIYA SOLOVEVA	{"email": "y_soloveva-1972@postgrespro.ru", "phone": "+70016977991"}
0005432692642	65D7B2	0826 644862	VLADIMIR TARASOV	{"email": "tarasov_v-011974@postgrespro.ru", "phone": "+70215306950"}
0005432692643	CD4AF5	1763 269092	GALINA IVANOVA	{"phone": "+70763569290"}
0005432692644	E8F1BD	5621 199736	NADEZHDA DAVYDOVA	{"phone": "+70559644486"}
0005432692645	5134C6	1411 812487	EGOR KARPOV	{"phone": "+70190863026"}
0005432692646	5134C6	1327 242264	NAILYA DAVYDOVA	{"email": "davydova-n_061979@postgrespro.ru", "phone": "+70155076186"}
0005432692647	5134C6	2746 422518	VLADIMIR MEDVEDEV	{"email": "medvedev-vladimir051979@postgrespro.ru", "phone": "+70346091791"}
0005432692648	5134C6	2187 260413	ALEKSANDR MOROZOV	{"email": "aleksandr-morozov-1970@postgrespro.ru", "phone": "+70121104027"}
0005432692649	F79462	4628 335319	IGOR VASILEV	{"email": "vasilev.i.061968@postgrespro.ru", "phone": "+70066769623"}
0005432692650	A350B0	7522 717957	VLADIMIR STEPANOV	{"phone": "+70499101075"}
0005432692651	CA2BE1	3246 541450	IGOR ABRAMOV	{"email": "igor-abramov15121979@postgrespro.ru", "phone": "+70861804817"}
0005432692652	FDD1C9	7651 131170	EKATERINA ZHUKOVA	{"phone": "+70221339337"}
0005432692653	417C1C	6544 707799	VASILIY MAKSIMOV	{"phone": "+70175222981"}
0005432692654	4A5426	2593 058796	IRINA PETROVA	{"phone": "+70755880205"}
0005432692655	4A5426	8496 908429	KHASAN VOLKOV	{"email": "khasan.volkov.091968@postgrespro.ru", "phone": "+70027683903"}
0005432692656	05C032	2665 463712	ALEKSANDR FEDOTOV	{"phone": "+70349202651"}
0005432692657	0266DA	7745 465749	NADEZHDA ISAEVA	{"phone": "+70571663887"}
0005432692658	0266DA	2959 708826	OLEG DMITRIEV	{"email": "oleg_dmitriev.1975@postgrespro.ru", "phone": "+70184940359"}
0005432692659	1AE672	1755 335789	OLEG KUZNECOV	{"email": "kuznecov-oleg-1976@postgrespro.ru", "phone": "+70155090474"}
0005432692660	1AE672	5571 559353	GENNADIY SCHERBAKOV	{"email": "scherbakov.g_14021965@postgrespro.ru", "phone": "+70264017239"}
0005432692661	6E8176	4723 695013	MATVEY IVANOV	{"phone": "+70512180873"}
0005432692662	6E8176	0955 713046	ANNA KONOVALOVA	{"email": "a.konovalova-121973@postgrespro.ru", "phone": "+70847891469"}
0005432692663	3896B2	9402 355905	EVGENIY PETROV	{"email": "e.petrov-1974@postgrespro.ru", "phone": "+70390919201"}
0005432692664	3896B2	7384 544253	SERGEY FEDOTOV	{"email": "fedotov-sergey.07101968@postgrespro.ru", "phone": "+70549248504"}
0005432692665	30639D	3332 652522	VLADIMIR VOROBEV	{"email": "vorobev_vladimir_021972@postgrespro.ru", "phone": "+70711781111"}
0005432692666	9AE468	4592 466109	MAKSIM ALEKSEEV	{"phone": "+70728977115"}
0005432692667	BE2E69	1432 685823	MARINA KRASNOVA	{"phone": "+70853590871"}
0005432692668	BE2E69	8614 219041	SVETLANA RYABOVA	{"email": "ryabova.svetlana.101976@postgrespro.ru", "phone": "+70856625711"}
0005432692669	F69C70	4616 903884	GALINA MEDVEDEVA	{"email": "galina-medvedeva.27091971@postgrespro.ru", "phone": "+70511551246"}
0005432692670	25CE97	8017 750195	IGOR SHEVCHENKO	{"phone": "+70881804896"}
0005432692671	91F7A7	0360 467169	MARINA DANILOVA	{"email": "danilovam1967@postgrespro.ru", "phone": "+70394870144"}
0005432692672	81733F	1293 917821	DMITRIY MOROZOV	{"email": "morozov_dmitriy_1973@postgrespro.ru", "phone": "+70076091859"}
0005432692673	181BD2	6063 949053	ALEKSEY BONDARENKO	{"phone": "+70911271264"}
0005432692674	7E2BF3	7156 101477	ALEKSANDR MOISEEV	{"phone": "+70467119832"}
0005432692675	7E2BF3	9055 975689	EVGENIY RODIONOV	{"email": "evgeniy.rodionov10041978@postgrespro.ru", "phone": "+70868215479"}
0005432692676	B48973	2815 518697	ANASTASIYA TITOVA	{"email": "anastasiya.titova.16061968@postgrespro.ru", "phone": "+70941086649"}
0005432692677	B48973	8397 267717	MAYYA TITOVA	{"email": "mayyatitova_121975@postgrespro.ru", "phone": "+70368926221"}
0005432692678	AE55F7	7167 247870	ALEKSANDR NIKITIN	{"email": "nikitin_a-051968@postgrespro.ru", "phone": "+70968691639"}
0005432692679	AE55F7	5904 937826	SVETLANA BORISOVA	{"email": "s.borisova1958@postgrespro.ru", "phone": "+70090753560"}
0005432692680	499159	1895 607831	ELENA GAVRILOVA	{"phone": "+70898737384"}
0005432692681	499159	6273 389875	ALEKSANDR IVANOV	{"phone": "+70303958094"}
0005432692682	CAC73C	0950 600567	ELENA GORBUNOVA	{"email": "elena-gorbunova101968@postgrespro.ru", "phone": "+70523743942"}
0005432692683	CAC73C	3483 155363	ALLA KUZNECOVA	{"email": "akuznecova.1977@postgrespro.ru", "phone": "+70466713761"}
0005432692684	598324	5508 864046	LIDIYA NESTEROVA	{"phone": "+70768337428"}
0005432692685	598324	8400 795291	IGOR SOKOLOV	{"phone": "+70452293086"}
0005432692686	098D85	8762 624559	KONSTANTIN ANTONOV	{"email": "antonov.konstantin011967@postgrespro.ru", "phone": "+70614515540"}
0005432692687	171A20	7445 312569	VALERIY MOROZOV	{"email": "morozov_valeriy26061969@postgrespro.ru", "phone": "+70321162021"}
0005432692688	B27367	4674 107155	ALEKSANDR MARTYNOV	{"email": "amartynov.06021969@postgrespro.ru", "phone": "+70236000200"}
0005432692689	34B7FE	8184 208887	ALEKSANDR MOROZOV	{"email": "morozov_a1973@postgrespro.ru", "phone": "+70462310551"}
0005432692690	34B7FE	5121 880108	SVETLANA PETROVA	{"email": "petrova_s_1974@postgrespro.ru", "phone": "+70419283805"}
0005432692691	118FBB	2171 416439	VASILIY NAUMOV	{"email": "naumov_vasiliy.1963@postgrespro.ru", "phone": "+70870851990"}
0005432692692	118FBB	8771 268035	OLESYA IVANOVA	{"phone": "+70236228271"}
0005432692693	DCB8F6	4733 440486	OLGA POPOVA	{"phone": "+70794136739"}
0005432692694	C80102	4590 385284	ALEKSEY ANDREEV	{"email": "andreev_aleksey.1972@postgrespro.ru", "phone": "+70113622346"}
0005432692695	C05665	0125 744217	RUFIYA VASILEVA	{"email": "vasilevarufiya_19061971@postgrespro.ru", "phone": "+70676204636"}
0005432692696	F353DB	9576 485509	MARINA SOROKINA	{"email": "sorokinam.071980@postgrespro.ru", "phone": "+70024397529"}
0005432692697	AA8C60	4023 406290	IVAN KOZLOV	{"email": "kozlov-ivan_02051961@postgrespro.ru", "phone": "+70390980814"}
0005432692698	4CFD5C	1773 913394	DENIS KUZMIN	{"phone": "+70082131571"}
0005432692699	774EBA	8470 917779	IRINA GORBUNOVA	{"phone": "+70131730956"}
0005432692700	774EBA	9476 084729	VLADIMIR SAVELEV	{"email": "v.savelev1973@postgrespro.ru", "phone": "+70321726930"}
0005432692701	F64449	2395 296883	ANGELINA POPOVA	{"phone": "+70938046717"}
0005432692702	A97AA6	6706 167498	VIKTOR KAZAKOV	{"email": "v_kazakov021969@postgrespro.ru", "phone": "+70194577766"}
0005432692703	E404BE	9966 532360	ZINAIDA IVANOVA	{"phone": "+70310647258"}
0005432692704	94E945	3316 546896	ANATOLIY PAVLOV	{"phone": "+70190272663"}
0005432692705	981F00	8908 451513	GALIYA EFIMOVA	{"email": "efimova.g_031971@postgrespro.ru", "phone": "+70874525577"}
0005432692706	33F5E4	0249 851248	VLADIMIR MAKAROV	{"phone": "+70087288624"}
0005432692707	C6E0EE	6445 452233	SERGEY SEMENOV	{"email": "semenov-s_31081972@postgrespro.ru", "phone": "+70998924591"}
0005432692708	C6E0EE	6636 596904	IRINA CHERNOVA	{"email": "ichernova_021990@postgrespro.ru", "phone": "+70865417578"}
0005432692709	C6E0EE	8614 670261	LYUDMILA IVANOVA	{"phone": "+70025510480"}
0005432692710	C22E2B	7791 163109	VYACHESLAV ZHUKOV	{"email": "v-zhukov_13021964@postgrespro.ru", "phone": "+70583939790"}
0005432692711	2804E8	4360 030075	YURIY PETROV	{"email": "petrovyuriy121977@postgrespro.ru", "phone": "+70067250684"}
0005432692712	11EC38	5700 823093	GULNARA TIKHONOVA	{"email": "tikhonova-g-1964@postgrespro.ru", "phone": "+70568206484"}
0005432692713	8F6E84	7338 208359	GENNADIY MOROZOV	{"email": "gennadiymorozov-071981@postgrespro.ru", "phone": "+70456482508"}
0005432692714	6E83AF	9564 613473	NIKOLAY VLASOV	{"email": "nikolay_vlasov_021968@postgrespro.ru", "phone": "+70042116398"}
0005432692715	7989DA	4545 011145	LIDIYA EGOROVA	{"email": "egorova-l_1980@postgrespro.ru", "phone": "+70389504570"}
0005432692716	431333	9006 131578	ALEKSANDR EGOROV	{"email": "egorovaleksandr-031977@postgrespro.ru", "phone": "+70129566033"}
0005432692717	7811F0	9776 231025	ALEKSANDR ABRAMOV	{"email": "abramova_15051975@postgrespro.ru", "phone": "+70760506855"}
0005432692718	F3130A	0373 143999	IGOR NOVIKOV	{"email": "i_novikov18031968@postgrespro.ru", "phone": "+70879693698"}
0005432692719	5DB202	1075 603517	VALENTINA MASLOVA	{"phone": "+70625206633"}
0005432692720	5DB202	5812 342328	LYUDMILA RYABOVA	{"phone": "+70351906722"}
0005432692721	FB3802	8696 702233	ELIZAVETA KOROLEVA	{"email": "elizaveta.koroleva_05061970@postgrespro.ru", "phone": "+70813603065"}
0005432692722	FB3802	8521 228023	ARKADIY BORISOV	{"phone": "+70643850193"}
0005432692723	FB3802	8982 169824	SERGEY ALEKSEEV	{"email": "s_alekseev.24011970@postgrespro.ru", "phone": "+70306429356"}
0005432692724	A564E1	4727 002655	ELENA KOROLEVA	{"email": "ekoroleva_16111971@postgrespro.ru", "phone": "+70404702072"}
0005432692725	6EF45D	8132 677850	LYUDMILA BOGDANOVA	{"phone": "+70778589097"}
0005432692726	B58799	0815 057707	MIKHAIL MEDVEDEV	{"email": "medvedev_mikhail1965@postgrespro.ru", "phone": "+70697035516"}
0005432692727	B58799	1216 163411	NIKOLAY SERGEEV	{"phone": "+70998847032"}
0005432692728	932640	0610 944775	RAISA KUZNECOVA	{"phone": "+70392566326"}
0005432692729	0D3DF7	5101 096121	TATYANA KUZNECOVA	{"phone": "+70105857955"}
0005432692730	0D3DF7	3712 406603	GALINA ZHURAVLEVA	{"email": "g.zhuravleva_061955@postgrespro.ru", "phone": "+70476217251"}
0005432692731	8D3E9E	1776 604967	IRINA NESTEROVA	{"email": "inesterova111973@postgrespro.ru", "phone": "+70158367166"}
0005432692732	A3DA17	5009 671079	TATYANA VASILEVA	{"email": "t.vasileva-1967@postgrespro.ru", "phone": "+70294476369"}
0005432692733	A3DA17	9980 432835	MIKHAIL DMITRIEV	{"email": "dmitriev_m_071978@postgrespro.ru", "phone": "+70656232357"}
0005432692734	814537	5446 906462	EVGENIY MAKAROV	{"email": "e.makarov071985@postgrespro.ru", "phone": "+70050299558"}
0005432692735	362827	5563 866270	KSENIYA FILATOVA	{"phone": "+70111761783"}
0005432692736	362827	4282 839655	TATYANA PETROVA	{"email": "petrova.tatyana.101985@postgrespro.ru", "phone": "+70965929962"}
0005432692737	25C347	0161 452186	VLADIMIR ALEKSEEV	{"email": "v-alekseev13081974@postgrespro.ru", "phone": "+70955529933"}
0005432692738	DBFA50	6317 013447	ROMAN SOLOVEV	{"email": "roman.solovev15061968@postgrespro.ru", "phone": "+70581478966"}
0005432692739	DBFA50	8166 103515	VYACHESLAV MIRONOV	{"phone": "+70373220949"}
0005432692740	CC77D8	9821 246736	OLGA SEMENOVA	{"email": "o.semenova.081989@postgrespro.ru", "phone": "+70205095871"}
0005432692741	6C7C85	5770 330917	VIKTOR SEMENOV	{"email": "semenov-v.1958@postgrespro.ru", "phone": "+70228356258"}
0005432692742	CCEA81	9436 080102	DARYA KOZLOVA	{"email": "daryakozlova.27051972@postgrespro.ru", "phone": "+70503719525"}
0005432692743	CE4011	5477 718527	INNA ZAYCEVA	{"email": "izayceva-031978@postgrespro.ru", "phone": "+70373816317"}
0005432692744	CE4011	6049 472620	RAISA NAZAROVA	{"email": "rnazarova.1978@postgrespro.ru", "phone": "+70611407108"}
0005432692745	058B3A	0427 852170	MARIYA BORISOVA	{"email": "m.borisova_1975@postgrespro.ru", "phone": "+70994188685"}
0005432692746	373506	9621 482967	NIKOLAY ZAKHAROV	{"phone": "+70167335643"}
0005432692747	373506	7875 785136	ALEKSANDR FROLOV	{"email": "a_frolov.1983@postgrespro.ru", "phone": "+70511469292"}
0005432692748	F63131	1376 229657	YULIYA PETROVA	{"phone": "+70549180103"}
0005432692749	F63131	9248 698007	ELENA VASILEVA	{"phone": "+70087593199"}
0005432692750	2525DF	7719 729870	OLEG IVANOV	{"email": "o.ivanov-081960@postgrespro.ru", "phone": "+70588353303"}
0005432692751	6C6205	0283 007651	GALINA FEDOROVA	{"phone": "+70696039764"}
0005432692752	6C6205	9979 850794	OLGA KOZLOVA	{"email": "kozlova.o1958@postgrespro.ru", "phone": "+70993786510"}
0005432692753	D0CEBA	6490 080118	POLINA KOMAROVA	{"phone": "+70442565206"}
0005432692754	2E964A	3609 487342	OLGA POPOVA	{"email": "popovaolga21071988@postgrespro.ru", "phone": "+70938238575"}
0005432692755	2E964A	8346 842638	VITALIY PETROV	{"email": "petrov_v-031969@postgrespro.ru", "phone": "+70583092092"}
0005432692756	9920BF	3220 075232	YURIY SOKOLOV	{"email": "yuriy-sokolov_1977@postgrespro.ru", "phone": "+70714092406"}
0005432692757	04A81C	6122 409425	DMITRIY SEMENOV	{"email": "semenov.d_1966@postgrespro.ru", "phone": "+70994328011"}
0005432692758	08673E	5252 880935	GENNADIY NAZAROV	{"phone": "+70985451692"}
0005432692759	6EAB66	6116 258237	VIKTORIYA KRASNOVA	{"phone": "+70579154210"}
0005432692760	6EAB66	4959 226376	ALEKSANDR BORISOV	{"email": "aleksandr.borisov-15071963@postgrespro.ru", "phone": "+70162349029"}
0005432692761	8B92D6	2274 297928	ALEKSANDR TIMOFEEV	{"email": "timofeev.aleksandr_1964@postgrespro.ru", "phone": "+70170194752"}
0005432692762	8B92D6	8805 537255	MARIYA MIKHAYLOVA	{"phone": "+70047682383"}
0005432692763	79FD93	7188 313511	DENIS SOKOLOV	{"phone": "+70012711219"}
0005432692764	205C02	7007 886216	NIKOLAY KULIKOV	{"phone": "+70283009397"}
0005432692765	205C02	7133 715227	ALEKSANDR ANTONOV	{"email": "a_antonov051968@postgrespro.ru", "phone": "+70598780051"}
0005432692766	7EDAAD	4065 390155	DENIS SEMENOV	{"phone": "+70078858387"}
0005432692767	7217A0	1123 362564	IRINA EGOROVA	{"email": "irina_egorova-1956@postgrespro.ru", "phone": "+70714812660"}
0005432692768	179772	4472 682564	TATYANA MALYSHEVA	{"email": "tatyana-malysheva.1974@postgrespro.ru", "phone": "+70797280668"}
0005432692769	179772	1735 827963	YAROSLAV PAVLOV	{"phone": "+70451802192"}
0005432692770	179772	5366 415019	VLADIMIR SERGEEV	{"email": "vladimir.sergeev-101976@postgrespro.ru", "phone": "+70340315811"}
0005432692771	3F81E6	2459 970634	IVAN MEDVEDEV	{"phone": "+70996452079"}
0005432692772	3F81E6	3325 538212	VITALIY GAVRILOV	{"phone": "+70593614023"}
0005432692773	61361E	9436 230229	DINARA BORISOVA	{"phone": "+70165393447"}
0005432692774	7CEF1A	5049 302083	SERGEY NAZAROV	{"email": "sergeynazarov_1970@postgrespro.ru", "phone": "+70875743424"}
0005432692775	7652C7	4854 919063	YURIY BELOV	{"email": "belov.yuriy.17091973@postgrespro.ru", "phone": "+70217896224"}
0005432692776	9492AC	1775 949795	ANDREY PETROV	{"phone": "+70480716595"}
0005432692777	90F342	1066 624269	DMITRIY FEDOROV	{"phone": "+70164053792"}
0005432692778	90F342	9650 323477	SERGEY VLASOV	{"email": "s-vlasov.1970@postgrespro.ru", "phone": "+70400317975"}
0005432692779	EB8795	5275 983791	ELENA PETROVA	{"email": "petrova.e26031966@postgrespro.ru", "phone": "+70367911420"}
0005432692780	6E3365	8018 275053	SERGEY EGOROV	{"phone": "+70839910379"}
0005432692781	0A01B6	2517 192824	LILIYA KOROLEVA	{"email": "koroleva_l.061975@postgrespro.ru", "phone": "+70284739620"}
0005432692782	0A01B6	6040 886875	LIDIYA MOROZOVA	{"email": "morozova-l.13031983@postgrespro.ru", "phone": "+70098233440"}
0005432692783	0A01B6	2964 846420	ANDREY RODIONOV	{"email": "rodionovandrey-031974@postgrespro.ru", "phone": "+70008313528"}
0005432692784	C21166	7095 675068	ANTONINA EGOROVA	{"email": "aegorova1962@postgrespro.ru", "phone": "+70018259000"}
0005432692785	C21166	1934 106835	KARINA SAVELEVA	{"email": "saveleva-karina1969@postgrespro.ru", "phone": "+70233475223"}
0005432692786	673CCA	9810 693722	OLESYA TIMOFEEVA	{"phone": "+70981302749"}
0005432692787	673CCA	2406 634590	ANNA PETROVA	{"email": "petrovaa.13041977@postgrespro.ru", "phone": "+70234783580"}
0005432692788	D3DF0B	0260 551692	VASILIY ORLOV	{"email": "orlov.vasiliy.011968@postgrespro.ru", "phone": "+70391918752"}
0005432692789	05E327	5736 462193	IRINA AKIMOVA	{"phone": "+70228841514"}
0005432692790	05E327	4758 314625	TATYANA EGOROVA	{"email": "egorova-t19121970@postgrespro.ru", "phone": "+70352212091"}
0005432692791	05E327	5023 343504	IVAN KUZNECOV	{"phone": "+70026649120"}
0005432692792	B2230C	0771 104442	ELIZAVETA ERMAKOVA	{"phone": "+70712743136"}
0005432692793	B2230C	4837 661342	YULIYA VOLKOVA	{"email": "volkova.y-1973@postgrespro.ru", "phone": "+70979525365"}
0005432692794	B2230C	4632 259921	VLADIMIR POPOV	{"email": "v.popov.07101992@postgrespro.ru", "phone": "+70063611792"}
0005432692795	F6756D	8122 809906	EVGENIY MAKAROV	{"email": "makarov.e16091964@postgrespro.ru", "phone": "+70325089277"}
0005432692796	3C4DD2	0683 998858	NIKOLAY MOROZOV	{"email": "nikolay.morozov.04071974@postgrespro.ru", "phone": "+70537079323"}
0005432692797	857B02	5140 204756	ANDREY KUDRYASHOV	{"email": "a.kudryashov-1979@postgrespro.ru", "phone": "+70399026369"}
0005432692798	857B02	7673 965824	TATYANA MASLOVA	{"email": "maslovat.1972@postgrespro.ru", "phone": "+70895187343"}
0005432692799	8B722B	1899 961963	MARIYA VLASOVA	{"phone": "+70449891602"}
0005432692800	8B722B	4938 625372	ALMIRA TARASOVA	{"email": "tarasova_a1970@postgrespro.ru", "phone": "+70561951575"}
0005432692801	453E6E	4901 186892	VIKTOR SOLOVEV	{"phone": "+70198074392"}
0005432692802	453E6E	1437 575755	BORIS SHEVCHENKO	{"phone": "+70062527622"}
0005432692803	6EB49E	6124 964687	NADEZHDA FADEEVA	{"email": "nfadeeva.1978@postgrespro.ru", "phone": "+70834900355"}
0005432692804	C2D704	7972 655017	YANA BORISOVA	{"email": "borisova-y_1979@postgrespro.ru", "phone": "+70519988262"}
0005432692805	3AF0C6	5534 888419	ELVIRA KULIKOVA	{"phone": "+70111744369"}
0005432692806	3AF0C6	3833 591234	DENIS GORBUNOV	{"phone": "+70893877573"}
0005432692807	73C80D	3071 495331	MIKHAIL DENISOV	{"phone": "+70350855797"}
0005432692808	7CB66A	2983 543532	VLADIMIR ZHURAVLEV	{"email": "zhuravlev.v.26071975@postgrespro.ru", "phone": "+70998840025"}
0005432692809	7CB66A	7048 950577	GALINA GAVRILOVA	{"phone": "+70390050648"}
0005432692810	797DC3	8681 917634	MIKHAIL EGOROV	{"phone": "+70330704741"}
0005432692811	EB8E60	3103 399003	EKATERINA OSIPOVA	{"phone": "+70294516526"}
0005432692812	039E84	2001 537395	LIDIYA MASLOVA	{"phone": "+70227701005"}
0005432692813	AA1B1D	2011 463544	ALEKSEY KISELEV	{"email": "a.kiselev.19071959@postgrespro.ru", "phone": "+70555611852"}
0005432692814	AA1B1D	6669 778160	ALEKSANDR KULIKOV	{"phone": "+70492385908"}
0005432692815	EAED5D	8856 272674	ELENA DENISOVA	{"email": "denisova-elena.30111969@postgrespro.ru", "phone": "+70635744595"}
0005432692816	EAED5D	0357 033168	ELENA SMIRNOVA	{"email": "smirnova-elena1967@postgrespro.ru", "phone": "+70421574410"}
0005432692817	644C6E	2398 748645	VIKTORIYA STEPANOVA	{"email": "stepanova.viktoriya.12021965@postgrespro.ru", "phone": "+70868404560"}
0005432692818	B2E4A2	6154 718701	MIKHAIL BELOV	{"phone": "+70688610395"}
0005432692819	6D1A77	8287 056037	ELLA FADEEVA	{"email": "e_fadeeva.28051965@postgrespro.ru", "phone": "+70738964733"}
0005432692820	3122E7	1956 576863	ALEKSANDR BORISOV	{"phone": "+70652313844"}
0005432692821	583417	0479 854099	VASILIY IVANOV	{"email": "ivanov-v_041973@postgrespro.ru", "phone": "+70429665763"}
0005432692822	2E2A5E	9803 123235	LARISA IVANOVA	{"phone": "+70467456519"}
0005432692823	309DC2	2415 211066	SERGEY IVANOV	{"phone": "+70234166128"}
0005432692824	D27F08	3582 937740	ILYA DMITRIEV	{"phone": "+70280741194"}
0005432692825	F157AA	5936 880901	ALEKSANDR MELNIKOV	{"phone": "+70489474399"}
0005432692826	E2AF83	9506 290890	MARINA SIDOROVA	{"phone": "+70005274834"}
0005432692827	E2AF83	4726 610954	VADIM ANDREEV	{"email": "andreev_v.1972@postgrespro.ru", "phone": "+70641340753"}
0005432692828	ADFF5F	0758 523035	ALEKSANDR KOZLOV	{"email": "kozlova_06021967@postgrespro.ru", "phone": "+70211221279"}
0005432692829	312775	1513 249596	OKSANA TITOVA	{"phone": "+70778891067"}
0005432692830	A3EC04	7378 536405	TATYANA YUDINA	{"email": "t-yudina_1967@postgrespro.ru", "phone": "+70770646036"}
0005432692831	A3EC04	6993 662070	DMITRIY PAVLOV	{"phone": "+70612091338"}
0005432692832	A3EC04	8958 902004	OLGA ROMANOVA	{"email": "o.romanova_071972@postgrespro.ru", "phone": "+70846237171"}
0005432692833	4354C2	0122 053308	SERGEY KOZLOV	{"email": "s-kozlov081969@postgrespro.ru", "phone": "+70245239515"}
0005432692834	B7EFB1	7271 357295	PETR RODIONOV	{"phone": "+70469978134"}
0005432692835	B7EFB1	1735 762929	ALEKSANDR IVANOV	{"phone": "+70796496451"}
0005432692836	8ECB96	7378 562116	TATYANA MALYSHEVA	{"phone": "+70207932183"}
0005432692837	AA038B	5249 378437	SERGEY ZAYCEV	{"email": "zaycev_sergey09011984@postgrespro.ru", "phone": "+70653060088"}
0005432692838	AA038B	5706 873045	OLESYA SIDOROVA	{"phone": "+70810748714"}
0005432692839	74D768	0137 701630	VALERIY STEPANOV	{"phone": "+70154463909"}
0005432692840	74D768	4146 222258	MARAT ANDREEV	{"phone": "+70264906946"}
0005432692841	8D58FA	3507 416756	MARINA ISAEVA	{"phone": "+70841397273"}
0005432692842	8D58FA	8746 746194	OKSANA GORBUNOVA	{"email": "gorbunova.oksana011960@postgrespro.ru", "phone": "+70733946063"}
0005432692843	26F80B	9652 683128	MARINA MIKHAYLOVA	{"phone": "+70406252906"}
0005432692844	26F80B	6737 370020	RUSLAN DENISOV	{"phone": "+70942092909"}
0005432692845	26F80B	7941 195613	TATYANA ALEKSEEVA	{"phone": "+70173280640"}
0005432692846	1EAA03	5310 605500	ZAKHAR VASILEV	{"phone": "+70139945538"}
0005432692847	6955F3	8053 368288	TATYANA KRASNOVA	{"email": "krasnova-tatyana071971@postgrespro.ru", "phone": "+70426715779"}
0005432692848	12BF13	1740 725342	VASILIY SOLOVEV	{"email": "solovev.vasiliy.1976@postgrespro.ru", "phone": "+70731174147"}
0005432692849	76682B	5639 893223	ELENA YAKOVLEVA	{"email": "e-yakovleva-1971@postgrespro.ru", "phone": "+70836226787"}
0005432692850	9816EF	8734 028804	RINAT NIKOLAEV	{"email": "nikolaev.r-111984@postgrespro.ru", "phone": "+70857899110"}
0005432692851	9816EF	4518 867875	SERGEY ZAKHAROV	{"email": "sergey_zakharov021972@postgrespro.ru", "phone": "+70306880680"}
0005432692852	5923DB	2309 665713	MARIYA MAKSIMOVA	{"phone": "+70794590363"}
0005432692853	D0842F	8691 167817	TAISIYA POPOVA	{"phone": "+70374686745"}
0005432692854	21F783	2318 094811	ALENA FOMINA	{"email": "fomina-a041968@postgrespro.ru", "phone": "+70581291445"}
0005432692855	9FAC04	4635 731665	NIKITA GUSEV	{"phone": "+70439537590"}
0005432692856	9FAC04	7489 836304	DENIS GUSEV	{"phone": "+70829538445"}
0005432692857	06F969	9201 893057	ANATOLIY RODIONOV	{"email": "rodionov_anatoliy.1978@postgrespro.ru", "phone": "+70409220442"}
0005432692858	9CF9B6	2736 969804	ANATOLIY DENISOV	{"phone": "+70861434441"}
0005432692859	7AD0B2	5115 574799	GENNADIY MIKHAYLOV	{"phone": "+70656236500"}
0005432692860	7AD0B2	1817 641316	ANNA PETROVA	{"email": "petrova.a_1974@postgrespro.ru", "phone": "+70635760608"}
0005432692861	7AD0B2	7887 081011	TATYANA ZAYCEVA	{"email": "t-zayceva.091976@postgrespro.ru", "phone": "+70526947159"}
0005432692862	CA43F4	3923 509228	ANASTASIYA NIKOLAEVA	{"phone": "+70320451484"}
0005432692863	CA43F4	7136 894429	LYUBOV AKIMOVA	{"phone": "+70590753091"}
0005432692864	80937A	2396 217184	LEONID SOROKIN	{"phone": "+70674665034"}
0005432692865	6B06BE	7282 865104	ALEKSANDR KUZMIN	{"email": "a-kuzmin.1980@postgrespro.ru", "phone": "+70472932313"}
0005432692866	6B06BE	7750 198777	TATYANA KOROLEVA	{"email": "t.koroleva.02111965@postgrespro.ru", "phone": "+70432606594"}
0005432692867	6B06BE	3276 778316	OLGA KALININA	{"phone": "+70053009860"}
0005432692868	82920F	5103 748239	TAMARA RYABOVA	{"phone": "+70385275979"}
0005432692869	82920F	2584 913688	DMITRIY DAVYDOV	{"phone": "+70099164345"}
0005432692870	EE4A46	2146 865736	ALEKSEY POPOV	{"email": "popov-aleksey24091977@postgrespro.ru", "phone": "+70537712139"}
0005432692871	EE4A46	7960 041766	VYACHESLAV FEDOROV	{"phone": "+70291679919"}
0005432692872	C480D5	1392 660541	MIKHAIL SCHERBAKOV	{"phone": "+70157886726"}
0005432692873	FCB289	0602 573051	ALEKSANDRA ARKHIPOVA	{"phone": "+70836483659"}
0005432692874	3E7FC7	8417 406237	KONSTANTIN SMIRNOV	{"email": "smirnov.konstantin_031969@postgrespro.ru", "phone": "+70614319082"}
0005432692875	6F6765	3852 596431	SERGEY FOMIN	{"phone": "+70318597069"}
0005432692876	6F6765	3682 899685	VIKTOR KUDRYASHOV	{"email": "kudryashov_v-21111973@postgrespro.ru", "phone": "+70908458815"}
0005432692877	874DA1	9791 612890	VIKTOR ISAEV	{"email": "isaev-v_1974@postgrespro.ru", "phone": "+70423210718"}
0005432692878	874DA1	5459 788799	NIKOLAY STEPANOV	{"email": "nstepanov121961@postgrespro.ru", "phone": "+70800281692"}
0005432692879	EA4DA5	1761 558694	IVAN KUZNECOV	{"email": "i_kuznecov-20031968@postgrespro.ru", "phone": "+70594226886"}
0005432692880	EA4DA5	7233 033601	EVGENIY FROLOV	{"phone": "+70545202352"}
0005432692881	DA897F	4461 077980	TAMARA PAVLOVA	{"email": "pavlova-tamara_1966@postgrespro.ru", "phone": "+70652261092"}
0005432692882	DA897F	1765 434926	VYACHESLAV NAZAROV	{"email": "v.nazarov.07031981@postgrespro.ru", "phone": "+70408134819"}
0005432692883	23B309	9064 766231	PAVEL POPOV	{"email": "popov.p31031975@postgrespro.ru", "phone": "+70816913626"}
0005432692884	353DA5	6117 119368	VITALIY MATVEEV	{"email": "vmatveev091977@postgrespro.ru", "phone": "+70314062861"}
0005432692885	92A2AD	8743 872594	OLGA ZOTOVA	{"email": "olga-zotova_051973@postgrespro.ru", "phone": "+70947736641"}
0005432692886	402304	7788 023211	NATALIYA KISELEVA	{"email": "nataliya.kiseleva-051977@postgrespro.ru", "phone": "+70414752983"}
0005432692887	402304	8038 311754	SVETLANA KALININA	{"email": "kalinina.svetlana_1972@postgrespro.ru", "phone": "+70436509338"}
0005432692888	CE3021	5317 388853	VALENTINA MASLOVA	{"phone": "+70601656592"}
0005432692889	C47515	4361 046172	DMITRIY GUSEV	{"email": "dmitriygusev081981@postgrespro.ru", "phone": "+70710770638"}
0005432692890	A1636C	1946 855806	EMIL MAKSIMOV	{"phone": "+70615392407"}
0005432692891	2799D6	9306 325654	NATALYA PAVLOVA	{"phone": "+70649090903"}
0005432692892	2799D6	5722 827850	NIKOLAY BARANOV	{"email": "baranovn_081962@postgrespro.ru", "phone": "+70391064542"}
0005432692893	F84F50	8313 098938	ELENA KOROLEVA	{"email": "koroleva.e-31051972@postgrespro.ru", "phone": "+70631799746"}
0005432692894	49F235	5670 775977	RIMA FILIPPOVA	{"email": "filippova.r.1971@postgrespro.ru", "phone": "+70203998200"}
0005432692895	39856B	4277 654508	GENNADIY NIKOLAEV	{"email": "nikolaev-gennadiy.26041983@postgrespro.ru", "phone": "+70901859901"}
0005432692896	BC99EA	1097 216403	SERGEY ORLOV	{"phone": "+70839653427"}
0005432692897	EBB17C	8173 783373	NINA PETROVA	{"email": "nina-petrova_13121986@postgrespro.ru", "phone": "+70591972090"}
0005432692898	EBB17C	9084 729167	SERGEY BARANOV	{"email": "sbaranov.14051973@postgrespro.ru", "phone": "+70637526192"}
0005432692899	D798C3	0718 599022	VIKTOR MAKAROV	{"phone": "+70781076472"}
0005432692900	5F79CC	3105 799953	VALERIY ABRAMOV	{"email": "valeriy.abramov.031981@postgrespro.ru", "phone": "+70039007242"}
0005432692901	40D159	4727 645722	ELENA RYABOVA	{"email": "elena.ryabova_071976@postgrespro.ru", "phone": "+70770439329"}
0005432692902	40D159	3831 677554	TAMARA DAVYDOVA	{"email": "davydovat_071966@postgrespro.ru", "phone": "+70363175013"}
0005432692903	F74958	1374 265425	DMITRIY SOKOLOV	{"email": "sokolov-d31051959@postgrespro.ru", "phone": "+70710861152"}
0005432692904	B30FBE	7332 200124	MIKHAIL SCHERBAKOV	{"phone": "+70088343878"}
0005432692905	932C8A	3617 677365	YULIYA SMIRNOVA	{"email": "smirnova-y1981@postgrespro.ru", "phone": "+70180622733"}
0005432692906	3123B8	1542 715460	MIKHAIL MOROZOV	{"email": "morozov_mikhail-1951@postgrespro.ru", "phone": "+70652115014"}
0005432692907	B6ECD7	5768 833023	ILYA POPOV	{"email": "ilya-popov-06121974@postgrespro.ru", "phone": "+70055553080"}
0005432692908	140F31	2844 431263	VALERIYA KOZLOVA	{"phone": "+70465664907"}
0005432692909	43FF8A	0903 017169	OKSANA KALININA	{"phone": "+70461441041"}
0005432692910	C8CB00	5236 626604	NATALYA PETROVA	{"phone": "+70886334296"}
0005432692911	558861	2168 536451	VIKTORIYA KOZLOVA	{"phone": "+70714885052"}
0005432692912	558861	2947 304180	ANASTASIYA KISELEVA	{"phone": "+70281289546"}
0005432692913	18016B	5780 781199	VALENTINA FROLOVA	{"email": "frolovav.051973@postgrespro.ru", "phone": "+70756413860"}
0005432692914	1CE848	4390 804446	TATYANA KALININA	{"phone": "+70432491480"}
0005432692915	1CE848	9127 779035	SERGEY FOMIN	{"email": "fomin-s-031984@postgrespro.ru", "phone": "+70049351934"}
0005432692916	802DB9	3836 994367	NAIL FEDOROV	{"phone": "+70842156139"}
0005432692917	802DB9	3310 817367	OLGA ZHURAVLEVA	{"email": "zhuravleva_olga1961@postgrespro.ru", "phone": "+70984217460"}
0005432692918	B2475C	4652 196955	IGOR MIKHAYLOV	{"phone": "+70257191732"}
0005432692919	28FB9C	4611 618063	YURIY TIMOFEEV	{"email": "timofeev-yuriy-1979@postgrespro.ru", "phone": "+70178802589"}
0005432692920	0A8BD0	9644 921720	LYUDMILA IVANOVA	{"phone": "+70924075118"}
0005432692921	B00365	4141 178981	SNEZHANA KONOVALOVA	{"email": "konovalovas.011986@postgrespro.ru", "phone": "+70201080964"}
0005432692922	8B103D	1705 261086	OLEG FROLOV	{"phone": "+70987307444"}
0005432692923	398A3C	2824 871147	RUSLAN RODIONOV	{"phone": "+70426733441"}
0005432692924	C39154	6062 835222	EDUARD KONOVALOV	{"phone": "+70385192132"}
0005432692925	137AC6	0975 827157	KRISTINA KISELEVA	{"email": "kristina.kiseleva_121961@postgrespro.ru", "phone": "+70651219735"}
0005432692926	27DEF0	6818 700643	ALEKSANDR MIRONOV	{"phone": "+70442680144"}
0005432692927	2F1822	0210 874498	GALINA MAKAROVA	{"email": "g-makarova.1968@postgrespro.ru", "phone": "+70506598408"}
0005432692928	2F1822	7165 289988	VIKTORIYA ANDREEVA	{"email": "viktoriya-andreeva-28081966@postgrespro.ru", "phone": "+70929667411"}
0005432692929	0C3153	4991 643690	SERGEY VASILEV	{"email": "s-vasilev_1968@postgrespro.ru", "phone": "+70623366847"}
0005432692930	31CBC5	2507 884743	TATYANA MEDVEDEVA	{"phone": "+70168879860"}
0005432692931	31CBC5	4306 088715	VALERIY AFANASEV	{"email": "afanasev-v.24011974@postgrespro.ru", "phone": "+70347172570"}
0005432692932	4E122A	6219 859743	TAMARA DENISOVA	{"phone": "+70458144758"}
0005432692933	3EB137	1245 757367	PETR POPOV	{"phone": "+70848344232"}
0005432692934	614ACB	9044 353690	VLADIMIR SAVELEV	{"email": "savelev_vladimir111976@postgrespro.ru", "phone": "+70470457894"}
0005432692935	614ACB	7435 986065	ANDREY VOLKOV	{"email": "a_volkov_101979@postgrespro.ru", "phone": "+70314715468"}
0005432692936	5B1F79	9476 790529	ANDREY POPOV	{"phone": "+70880651709"}
0005432692937	33A2E9	3069 131418	ANTON NAZAROV	{"email": "a-nazarov-091970@postgrespro.ru", "phone": "+70591058039"}
0005432692938	C24320	4980 230973	OLGA PETROVA	{"phone": "+70325492284"}
0005432692939	C24320	1032 726969	TATYANA KUZNECOVA	{"phone": "+70278487728"}
0005432692940	F7BF8D	8225 458592	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey1976@postgrespro.ru", "phone": "+70020234746"}
0005432692941	F7BF8D	1866 792838	NADEZHDA EFREMOVA	{"phone": "+70569934087"}
0005432692942	AB5CEA	8591 344212	OLGA ZAKHAROVA	{"phone": "+70328860257"}
0005432692943	AB5CEA	0993 178494	GLEB ISAEV	{"phone": "+70406262956"}
0005432692944	46DFF6	5010 186395	ANNA KONOVALOVA	{"email": "annakonovalova-111965@postgrespro.ru", "phone": "+70114984378"}
0005432692945	46DFF6	9762 359587	PAVEL ZAKHAROV	{"email": "zakharovpavel.1974@postgrespro.ru", "phone": "+70406012908"}
0005432692946	4A9CA5	7937 000391	LYUBOV ORLOVA	{"email": "lorlova-121973@postgrespro.ru", "phone": "+70494720290"}
0005432692947	3C5DF9	0133 211833	ALENA TIKHONOVA	{"phone": "+70235558513"}
0005432692948	3C5DF9	3705 741935	ALEKSANDR MIKHAYLOV	{"phone": "+70619594413"}
0005432692949	8DC000	9742 084648	MIKHAIL VOROBEV	{"email": "vorobev_mikhail051969@postgrespro.ru", "phone": "+70445759819"}
0005432692950	622BB7	0802 834084	OLGA FROLOVA	{"phone": "+70154925118"}
0005432692951	622BB7	4331 481496	ALISA MARTYNOVA	{"email": "martynova.a.30041965@postgrespro.ru", "phone": "+70697147900"}
0005432692952	C57D1C	3188 475645	MIKHAIL PAVLOV	{"phone": "+70232594447"}
0005432692953	C57D1C	8514 109282	KAMILA SEMENOVA	{"email": "k.semenova-041966@postgrespro.ru", "phone": "+70913904509"}
0005432692954	D3F988	9600 200300	VIKTOR SIDOROV	{"email": "sidorov_viktor-03011967@postgrespro.ru", "phone": "+70390507444"}
0005432692955	D3F988	2977 340891	SERGEY POPOV	{"email": "s_popov_091977@postgrespro.ru", "phone": "+70487778877"}
0005432692956	549532	9993 619779	ANNA KUZNECOVA	{"email": "anna.kuznecova.111967@postgrespro.ru", "phone": "+70659075738"}
0005432692957	549532	0748 255970	ELENA ORLOVA	{"email": "elena.orlova.031982@postgrespro.ru", "phone": "+70953664229"}
0005432692958	549532	6801 566975	ALEKSANDR SCHERBAKOV	{"phone": "+70459844345"}
0005432692959	549532	2609 044823	IRINA VOROBEVA	{"phone": "+70747225684"}
0005432692960	49184E	4734 168108	OLEG ALEKSANDROV	{"phone": "+70579491432"}
0005432692961	5EB793	1739 352451	MATVEY FOMIN	{"email": "fomin_m_1966@postgrespro.ru", "phone": "+70675225215"}
0005432692962	BA52C1	6656 883647	ELENA DENISOVA	{"email": "denisova_elena.06121974@postgrespro.ru", "phone": "+70945558765"}
0005432692963	BA52C1	3186 196443	NIKOLAY EGOROV	{"email": "n-egorov.121982@postgrespro.ru", "phone": "+70023351750"}
0005432692964	CAAC3D	8435 104521	VALERIY GORBUNOV	{"email": "gorbunov.v-041966@postgrespro.ru", "phone": "+70433159009"}
0005432692965	CAAC3D	6229 920422	EGOR GORBUNOV	{"phone": "+70601436485"}
0005432692966	D644B1	3795 263108	SERGEY MARTYNOV	{"email": "smartynov091963@postgrespro.ru", "phone": "+70379730538"}
0005432692967	CBDEFE	4436 536807	VIKTOR PAVLOV	{"phone": "+70738056628"}
0005432692968	86E976	3875 389093	LYUBOV MASLOVA	{"email": "l.maslova101977@postgrespro.ru", "phone": "+70416648999"}
0005432692969	15E6E2	2103 189296	VIKTOR IVANOV	{"email": "ivanov.v_041975@postgrespro.ru", "phone": "+70533656444"}
0005432692970	8F9FCC	4857 758422	NIKOLAY ORLOV	{"phone": "+70220424214"}
0005432692971	8F9FCC	6246 657680	ALEKSANDRA POLYAKOVA	{"email": "polyakovaa_13111971@postgrespro.ru", "phone": "+70699918816"}
0005432692972	8DE75F	8636 132663	SOFYA NESTEROVA	{"phone": "+70576858226"}
0005432692973	915D68	3809 071092	NADEZHDA POTAPOVA	{"email": "nadezhda-potapova-14091975@postgrespro.ru", "phone": "+70836910567"}
0005432692974	915D68	5478 556060	EVGENIYA IVANOVA	{"phone": "+70188178024"}
0005432692975	040EE5	6189 317325	ANDREY KONOVALOV	{"phone": "+70935493490"}
0005432692976	98E0FC	7341 406282	IRINA ALEKSEEVA	{"email": "alekseeva-irina-04061977@postgrespro.ru", "phone": "+70985953860"}
0005432692977	F3AA9B	5071 244213	LYUDMILA CHERNOVA	{"phone": "+70698305674"}
0005432692978	F3AA9B	5709 909503	TATYANA POPOVA	{"email": "tatyana-popova-021969@postgrespro.ru", "phone": "+70291969707"}
0005432692979	37B455	5395 808996	ZINAIDA MELNIKOVA	{"email": "melnikova-zinaida15101971@postgrespro.ru", "phone": "+70706028930"}
0005432692980	BFBC87	8407 798287	ELENA POPOVA	{"email": "e_popova-05041986@postgrespro.ru", "phone": "+70614845325"}
0005432692981	58E08F	8098 609398	ALEKSANDR KUDRYASHOV	{"email": "aleksandr.kudryashov_1977@postgrespro.ru", "phone": "+70434741632"}
0005432692982	E796FB	4475 466994	ARTUR IVANOV	{"email": "aivanov_13071971@postgrespro.ru", "phone": "+70626853729"}
0005432692983	E796FB	7672 034625	YULIYA ORLOVA	{"phone": "+70228156017"}
0005432692984	F4C2C1	4596 791958	LYUDMILA TIKHONOVA	{"phone": "+70092101507"}
0005432692985	119ECE	8366 318856	SERGEY PETROV	{"email": "s.petrov.1977@postgrespro.ru", "phone": "+70449686698"}
0005432692986	7E8C4E	2856 004642	NINA FROLOVA	{"email": "frolovan031988@postgrespro.ru", "phone": "+70595128536"}
0005432692987	7DB9A3	5073 678635	ALEKSEY FOMIN	{"email": "fomin_a_1962@postgrespro.ru", "phone": "+70725418146"}
0005432692988	57A921	6461 977421	VLADIMIR VLASOV	{"phone": "+70693435101"}
0005432692989	57A921	9884 456462	NIKOLAY GAVRILOV	{"phone": "+70694775861"}
0005432692990	B7254F	8508 320661	ALEKSEY MAKAROV	{"email": "aleksey_makarov-1985@postgrespro.ru", "phone": "+70020513005"}
0005432692991	B7254F	5538 076667	LEONID ALEKSANDROV	{"email": "laleksandrov-1982@postgrespro.ru", "phone": "+70263464508"}
0005432692992	788B33	7389 358161	VASILIY ANTONOV	{"email": "vasiliy.antonov.23091984@postgrespro.ru", "phone": "+70701265290"}
0005432692993	788B33	3921 554747	ZINAIDA GAVRILOVA	{"phone": "+70557210302"}
0005432692994	788B33	0898 933448	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya1965@postgrespro.ru", "phone": "+70288152802"}
0005432692995	1306A0	9957 981849	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir.1973@postgrespro.ru", "phone": "+70778590787"}
0005432692996	947274	7997 178268	OLGA VASILEVA	{"phone": "+70089143856"}
0005432692997	5DBC03	9575 423631	IVAN FOMIN	{"phone": "+70470949677"}
0005432692998	760AA4	4340 474228	SERGEY ANDREEV	{"email": "andreev-s-011977@postgrespro.ru", "phone": "+70385901630"}
0005432692999	760AA4	2389 428839	OLESYA ZAKHAROVA	{"email": "olesya-zakharova1974@postgrespro.ru", "phone": "+70755478257"}
0005432693000	7DB615	6312 915718	VLADIMIR SOLOVEV	{"phone": "+70481878216"}
0005432693001	46C08A	4639 019219	TATYANA SEMENOVA	{"email": "semenova.t20011965@postgrespro.ru", "phone": "+70682492162"}
0005432693002	46C08A	5500 197684	TATYANA KOROLEVA	{"email": "koroleva_tatyana_13081982@postgrespro.ru", "phone": "+70449075827"}
0005432693003	9178A0	9011 079308	SERGEY STEPANOV	{"phone": "+70615006618"}
0005432693004	E4B012	9030 621044	ELIZAVETA POPOVA	{"email": "popova_e_031977@postgrespro.ru", "phone": "+70500578725"}
0005432693005	C4ECDE	9714 408570	MARINA KOROLEVA	{"phone": "+70909850292"}
0005432693006	9DE9C5	3955 528119	VALENTINA KONOVALOVA	{"phone": "+70273537102"}
0005432693007	F2E172	3477 171598	ALEKSANDR ANDREEV	{"email": "andreev-a111976@postgrespro.ru", "phone": "+70634885978"}
0005432693008	F2E172	0187 357618	SERGEY MOROZOV	{"email": "s.morozov_1980@postgrespro.ru", "phone": "+70980500412"}
0005432693009	A004BC	5588 568904	OKSANA MALYSHEVA	{"email": "malysheva_oksana-10071961@postgrespro.ru", "phone": "+70228766848"}
0005432693010	0E95E3	9704 173902	ZINAIDA ALEKSEEVA	{"phone": "+70391864437"}
0005432693011	44356B	1131 555830	VALENTINA VASILEVA	{"phone": "+70482523117"}
0005432693012	44356B	8750 207568	ANZHELA SCHERBAKOVA	{"email": "ascherbakova1982@postgrespro.ru", "phone": "+70296141729"}
0005432693013	8AAE5D	6096 983441	ELENA GERASIMOVA	{"phone": "+70614994714"}
0005432693014	8AAE5D	1395 027967	ANDREY FEDOTOV	{"phone": "+70985808688"}
0005432693015	8AAE5D	2026 237537	ALEKSANDRA NAZAROVA	{"phone": "+70926594962"}
0005432693016	4EFE69	5628 428085	GEORGIY SCHERBAKOV	{"email": "georgiy-scherbakov.1975@postgrespro.ru", "phone": "+70816855127"}
0005432693017	4EFE69	6682 930017	VERA SAVELEVA	{"email": "saveleva-vera-1978@postgrespro.ru", "phone": "+70696936550"}
0005432693018	A245DF	7789 873116	IGOR KAZAKOV	{"phone": "+70208817662"}
0005432693019	A245DF	4761 707629	KSENIYA BOGDANOVA	{"phone": "+70352597923"}
0005432693020	36B46D	7627 414473	VLADIMIR NIKOLAEV	{"email": "v.nikolaev-061968@postgrespro.ru", "phone": "+70978295465"}
0005432693021	515AFE	2918 195307	TATYANA POTAPOVA	{"email": "tpotapova-1957@postgrespro.ru", "phone": "+70020291765"}
0005432693022	B60364	9638 483387	GLEB VLASOV	{"email": "vlasov-gleb-021971@postgrespro.ru", "phone": "+70720143875"}
0005432693023	3A2BC0	7576 251539	VIKTOR ANDREEV	{"email": "andreev-viktor.101974@postgrespro.ru", "phone": "+70955311354"}
0005432693024	585ABB	7728 804746	NIKITA SEMENOV	{"email": "n-semenov_1969@postgrespro.ru", "phone": "+70849309199"}
0005432693136	65F181	6857 915757	SVETLANA VASILEVA	{"phone": "+70971928489"}
0005432693025	39B4AF	1037 530960	NINA CHERNOVA	{"email": "ninachernova031975@postgrespro.ru", "phone": "+70774268951"}
0005432693026	39B4AF	6085 165501	VIKTOR SMIRNOV	{"email": "smirnov_viktor.051968@postgrespro.ru", "phone": "+70393406035"}
0005432693027	EFEF68	8874 728760	NIKOLAY OSIPOV	{"phone": "+70503316528"}
0005432693028	F2911C	4821 443526	ROMAN MAKAROV	{"email": "makarov_r101985@postgrespro.ru", "phone": "+70275210190"}
0005432693029	F2911C	5818 972655	IGOR VASILEV	{"email": "vasilev_i-1965@postgrespro.ru", "phone": "+70304444447"}
0005432693030	BE8530	2887 923643	VASILIY VASILEV	{"email": "vasilev_v_31121969@postgrespro.ru", "phone": "+70257538870"}
0005432693031	ACA8D2	8518 424020	ANATOLIY PETROV	{"email": "petrov_a-29071973@postgrespro.ru", "phone": "+70329697738"}
0005432693032	76A30E	9508 237644	LILIYA LAZAREVA	{"phone": "+70943819756"}
0005432693033	6FFC38	7553 335000	ILYA MATVEEV	{"email": "matveev.ilya.1966@postgrespro.ru", "phone": "+70457227606"}
0005432693034	6FFC38	2638 578755	SERGEY FILIPPOV	{"phone": "+70472589676"}
0005432693035	9248AD	1024 965875	IVAN SEMENOV	{"email": "semenovivan_061977@postgrespro.ru", "phone": "+70076214910"}
0005432693036	9248AD	9686 438168	VALENTINA GRISHINA	{"email": "v-grishina-18051978@postgrespro.ru", "phone": "+70497625982"}
0005432693037	9248AD	0652 887404	GULNARA MAKSIMOVA	{"phone": "+70781126648"}
0005432693038	9248AD	7784 032419	DARYA RYABOVA	{"phone": "+70876692919"}
0005432693039	78D6EA	8794 012257	VLADISLAV KRASNOV	{"phone": "+70520662992"}
0005432693040	2C141D	7042 574662	LYUBOV NIKOLAEVA	{"phone": "+70494206248"}
0005432693041	2C141D	9966 538587	FEDOR ILIN	{"phone": "+70769523918"}
0005432693042	BCCDF0	0851 336735	LIDIYA BOGDANOVA	{"phone": "+70306622469"}
0005432693043	B04AB8	7305 189903	SERGEY MAKAROV	{"email": "makarov_s.011974@postgrespro.ru", "phone": "+70111577801"}
0005432693044	EC93DE	0248 744265	ARTEM ANDREEV	{"phone": "+70454963142"}
0005432693045	EC93DE	5394 066281	TAMARA VOROBEVA	{"phone": "+70527240407"}
0005432693046	BB4DDF	8899 231127	VADIM DAVYDOV	{"email": "davydov_vadim.091982@postgrespro.ru", "phone": "+70609354526"}
0005432693047	D6C571	3283 427864	RAISA MEDVEDEVA	{"email": "medvedeva.raisa041978@postgrespro.ru", "phone": "+70943941700"}
0005432693048	8B28BB	7142 464005	VALENTINA VOLKOVA	{"email": "vvolkova_20071981@postgrespro.ru", "phone": "+70573368009"}
0005432693049	2A7F0D	6107 093973	VALENTINA LEBEDEVA	{"email": "lebedeva.v.1967@postgrespro.ru", "phone": "+70766798079"}
0005432693050	657176	7438 205723	PAVEL OSIPOV	{"email": "osipov-pavel.1964@postgrespro.ru", "phone": "+70498540098"}
0005432693051	4EC983	2821 313633	GALINA SOKOLOVA	{"email": "sokolova-galina-1969@postgrespro.ru", "phone": "+70703890983"}
0005432693052	7867D8	6624 120606	MARAT PAVLOV	{"phone": "+70375571337"}
0005432693053	7867D8	9270 180018	SERGEY KRASNOV	{"email": "s.krasnov-14051968@postgrespro.ru", "phone": "+70573298926"}
0005432693054	7867D8	5874 066220	OLGA MOISEEVA	{"email": "moiseeva.olga-1964@postgrespro.ru", "phone": "+70506387343"}
0005432693055	4226BB	6040 413639	VALENTINA GORBUNOVA	{"email": "v.gorbunova15021976@postgrespro.ru", "phone": "+70386786224"}
0005432693056	4226BB	9032 990440	NATALIYA ZAKHAROVA	{"phone": "+70687477276"}
0005432693057	B7ADD7	4715 866748	ALEKSANDR VOLKOV	{"phone": "+70449906863"}
0005432693058	8E005C	4554 253798	KONSTANTIN ALEKSEEV	{"phone": "+70549389971"}
0005432693059	D5F245	1113 891762	VALENTINA KOROLEVA	{"email": "koroleva_valentina-29081958@postgrespro.ru", "phone": "+70984155494"}
0005432693060	1C5C08	9436 711266	SERGEY MELNIKOV	{"phone": "+70920196650"}
0005432693061	5AB0FA	7136 078591	TATYANA TARASOVA	{"phone": "+70926119785"}
0005432693062	55EFC6	5829 837787	ROMAN IVANOV	{"email": "ivanov_r.1961@postgrespro.ru", "phone": "+70157558326"}
0005432693063	CD83CD	3588 105334	VERA GORBUNOVA	{"phone": "+70593931851"}
0005432693064	386CC4	2226 840820	YURIY SCHERBAKOV	{"phone": "+70084248557"}
0005432693065	C76B86	5264 225267	OLGA KULIKOVA	{"email": "kulikova.olga_111974@postgrespro.ru", "phone": "+70284830289"}
0005432693066	3425A4	3944 349518	OLEG KUZNECOV	{"email": "kuznecov_o1968@postgrespro.ru", "phone": "+70282372392"}
0005432693067	7A2DC2	3204 856794	NIKITA ZAKHAROV	{"email": "nzakharov-091974@postgrespro.ru", "phone": "+70334919339"}
0005432693068	CF54B9	6586 734513	LYUBOV GORBUNOVA	{"phone": "+70346359998"}
0005432693069	AF9846	2755 200019	EVGENIYA MALYSHEVA	{"email": "malysheva_evgeniya1969@postgrespro.ru", "phone": "+70361190875"}
0005432693070	8ABBDD	5708 723096	OLGA DANILOVA	{"phone": "+70302727461"}
0005432693071	A0CEFA	5066 282066	EVGENIYA KOROLEVA	{"email": "korolevae_1976@postgrespro.ru", "phone": "+70907500528"}
0005432693072	1D5B37	9511 248753	NATALYA ANISIMOVA	{"email": "anisimova-n_09011975@postgrespro.ru", "phone": "+70027940736"}
0005432693073	6316F0	8927 524702	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-a_20031968@postgrespro.ru", "phone": "+70017892291"}
0005432693074	DC4DBC	2021 665647	IRINA KUZNECOVA	{"email": "kuznecova.irina-121976@postgrespro.ru", "phone": "+70016170809"}
0005432693075	C2BB9C	2240 882961	GALINA BORISOVA	{"email": "borisova.galina_1964@postgrespro.ru", "phone": "+70815190584"}
0005432693076	5529DC	1178 240925	OLGA ANTONOVA	{"email": "antonova.olga-1972@postgrespro.ru", "phone": "+70038728571"}
0005432693077	F136BA	0696 624298	PAVEL NOVIKOV	{"email": "p.novikov_091973@postgrespro.ru", "phone": "+70401005463"}
0005432693078	F136BA	0478 670495	OLGA NESTEROVA	{"email": "nesterova.o.1965@postgrespro.ru", "phone": "+70558660164"}
0005432693079	7E8DD3	3742 563479	SERGEY GUSEV	{"email": "gusev_s.08061978@postgrespro.ru", "phone": "+70492211444"}
0005432693080	A75B89	3754 187215	SEMEN SOROKIN	{"email": "sorokin-s17081959@postgrespro.ru", "phone": "+70136139500"}
0005432693081	383987	7448 124884	OLGA NAZAROVA	{"email": "olga-nazarova_03031978@postgrespro.ru", "phone": "+70753182801"}
0005432693082	4F1881	0671 990011	EKATERINA FILIPPOVA	{"email": "ekaterina.filippova.021979@postgrespro.ru", "phone": "+70616227553"}
0005432693083	2B23D2	2382 026752	EVGENIY POPOV	{"email": "popove-10071970@postgrespro.ru", "phone": "+70283029152"}
0005432693084	A1ADA1	6121 912092	NADEZHDA IVANOVA	{"phone": "+70840530321"}
0005432693085	3FC714	5733 328857	ILMIR CHERNOV	{"email": "chernov_i-26011987@postgrespro.ru", "phone": "+70570811182"}
0005432693086	3FC714	3446 645881	TAMARA ZAKHAROVA	{"email": "t-zakharova.1969@postgrespro.ru", "phone": "+70256080469"}
0005432693087	923FB2	4550 717825	NIKOLAY DAVYDOV	{"phone": "+70142288140"}
0005432693088	923FB2	7941 060425	NURIYA KUZNECOVA	{"phone": "+70803889731"}
0005432693089	1BA49C	4513 417773	TATYANA KUZNECOVA	{"email": "kuznecova.t111968@postgrespro.ru", "phone": "+70313113454"}
0005432693090	7F445E	5942 173340	NINA VOROBEVA	{"email": "vorobeva.nina_14101987@postgrespro.ru", "phone": "+70005431020"}
0005432693091	7F445E	2524 766161	ELENA KUZNECOVA	{"email": "elena.kuznecova-1987@postgrespro.ru", "phone": "+70312103824"}
0005432693092	7F445E	1330 783721	SERGEY MIKHAYLOV	{"phone": "+70188592271"}
0005432693093	6813F7	7205 380931	GALINA TIKHONOVA	{"phone": "+70175563953"}
0005432693094	03CBA4	6046 589714	MARGARITA LAZAREVA	{"phone": "+70452481934"}
0005432693095	03CBA4	0136 348403	LIDIYA MATVEEVA	{"email": "l_matveeva031964@postgrespro.ru", "phone": "+70023507060"}
0005432693096	ACA5A7	5104 299252	ANNA ANTONOVA	{"email": "antonova-anna-121966@postgrespro.ru", "phone": "+70980268612"}
0005432693097	656BB6	4405 849470	NIKOLAY BARANOV	{"phone": "+70837086512"}
0005432693098	656BB6	5766 092853	IRINA NIKIFOROVA	{"email": "i-nikiforova1979@postgrespro.ru", "phone": "+70598440130"}
0005432693099	60E72F	2370 485709	GENNADIY NOVIKOV	{"email": "gennadiy_novikov071972@postgrespro.ru", "phone": "+70397438562"}
0005432693100	34AFAC	5761 559228	IVAN ANDREEV	{"phone": "+70980125340"}
0005432693101	34AFAC	0196 644450	EVGENIY POPOV	{"phone": "+70024018807"}
0005432693102	BEE99F	4522 375274	NATALYA NAZAROVA	{"phone": "+70947586984"}
0005432693103	8766C0	7590 129551	VADIM NIKOLAEV	{"email": "nikolaev.v_29051974@postgrespro.ru", "phone": "+70551101972"}
0005432693104	8766C0	2781 445786	VALENTINA SOLOVEVA	{"phone": "+70073278847"}
0005432693105	00A8F6	0926 482310	DENIS SEMENOV	{"phone": "+70664380264"}
0005432693106	505E86	6954 177407	DMITRIY ISAEV	{"phone": "+70344625844"}
0005432693107	4365C9	7317 130421	SERGEY GORBUNOV	{"email": "sergey.gorbunov31031976@postgrespro.ru", "phone": "+70981451092"}
0005432693108	4365C9	0698 408024	IVAN DAVYDOV	{"phone": "+70238834518"}
0005432693109	02648E	0443 099374	IVAN KULIKOV	{"phone": "+70965603470"}
0005432693110	02648E	9937 568997	RINAT PAVLOV	{"email": "pavlov_r.1974@postgrespro.ru", "phone": "+70350424914"}
0005432693111	71B468	4935 390123	TAISIYA DMITRIEVA	{"email": "dmitrieva.taisiya_041961@postgrespro.ru", "phone": "+70416370068"}
0005432693112	71B468	7663 985048	ANASTASIYA LAZAREVA	{"phone": "+70114019109"}
0005432693113	050F21	5293 295500	ELENA MAKSIMOVA	{"email": "maksimova_elena.30081969@postgrespro.ru", "phone": "+70829986526"}
0005432693114	7FAF93	7913 541356	GALINA KUZNECOVA	{"email": "gkuznecova16031980@postgrespro.ru", "phone": "+70462048433"}
0005432693115	7FAF93	0536 714547	SERGEY PETROV	{"phone": "+70922893028"}
0005432693116	7FAF93	2192 069260	ZOYA SMIRNOVA	{"email": "zoya_smirnova_08101975@postgrespro.ru", "phone": "+70860568223"}
0005432693117	4B0D46	3434 748291	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila_121966@postgrespro.ru", "phone": "+70114485826"}
0005432693118	4B0D46	7167 672485	ALEKSANDR BORISOV	{"email": "borisovaleksandr-031978@postgrespro.ru", "phone": "+70458184179"}
0005432693119	73F1B6	0092 251720	ANDREY SERGEEV	{"phone": "+70907023596"}
0005432693120	73F1B6	3233 210890	TATYANA ANDREEVA	{"email": "t-andreeva-011972@postgrespro.ru", "phone": "+70516621468"}
0005432693121	F3E166	6598 547450	ALEKSANDR BORISOV	{"email": "borisov_aleksandr071976@postgrespro.ru", "phone": "+70621594477"}
0005432693122	F3E166	1850 280039	TAISA NAZAROVA	{"phone": "+70955338834"}
0005432693123	4097DC	2282 515284	OKSANA KUZNECOVA	{"phone": "+70745580532"}
0005432693124	6DC1EE	1430 799179	EVGENIY KUZMIN	{"phone": "+70357750578"}
0005432693125	6DC1EE	2772 995432	STANISLAV IVANOV	{"phone": "+70252802121"}
0005432693126	6DC1EE	6652 325592	EKATERINA NAUMOVA	{"email": "naumova-ekaterina1975@postgrespro.ru", "phone": "+70877320456"}
0005432693127	1CF1F8	5264 500279	TATYANA DAVYDOVA	{"email": "t_davydova19121986@postgrespro.ru", "phone": "+70785333404"}
0005432693128	1CF1F8	5771 965912	LIDIYA ZAKHAROVA	{"email": "lidiya-zakharova_011972@postgrespro.ru", "phone": "+70301827072"}
0005432693129	7AC666	8362 911122	SERGEY KRASNOV	{"phone": "+70386034698"}
0005432693130	375BFF	5767 751793	VALERIY GRIGOREV	{"phone": "+70603634995"}
0005432693131	3F877D	7893 805509	ALEKSANDR MARTYNOV	{"email": "a-martynov.26071972@postgrespro.ru", "phone": "+70362030347"}
0005432693132	3F877D	6819 919580	ARTUR GAVRILOV	{"email": "gavrilova-1972@postgrespro.ru", "phone": "+70065339467"}
0005432693133	C5B3DA	9627 706637	OLEG KOROLEV	{"email": "korolevo-1962@postgrespro.ru", "phone": "+70111326648"}
0005432693134	71039A	8037 380227	ALEKSEY PETROV	{"email": "petrov_a_16111963@postgrespro.ru", "phone": "+70474022681"}
0005432693135	65F181	3976 507977	IRINA ZHUKOVA	{"phone": "+70547637192"}
0005432693137	65F181	4199 449149	YULIYA ANDREEVA	{"phone": "+70636979368"}
0005432693138	37C4A7	4540 058837	YURIY KUZNECOV	{"phone": "+70588790571"}
0005432693139	37C4A7	0584 287915	MARINA LUKYANOVA	{"email": "lukyanova.marina_16021986@postgrespro.ru", "phone": "+70370146313"}
0005432693140	1A06F6	0494 691693	ALEKSANDR STEPANOV	{"phone": "+70861671569"}
0005432693141	1A06F6	2407 647646	TATYANA PETROVA	{"email": "petrova.t-09111973@postgrespro.ru", "phone": "+70501716388"}
0005432693142	235A34	4047 653914	IRINA FILIPPOVA	{"email": "filippova_irina.10121961@postgrespro.ru", "phone": "+70003637098"}
0005432693143	7F2F63	9094 300858	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila_041984@postgrespro.ru", "phone": "+70060464508"}
0005432693144	0FC4B6	7676 052824	ELENA KULIKOVA	{"email": "e.kulikova_19051977@postgrespro.ru", "phone": "+70649280110"}
0005432693145	298176	4932 405202	OLEG SAVELEV	{"email": "savelev-oleg_26061972@postgrespro.ru", "phone": "+70712404075"}
0005432693146	298176	3406 791590	VALERIYA VLASOVA	{"phone": "+70208858219"}
0005432693147	F1BE4B	8788 708826	ALEKSEY TARASOV	{"email": "alekseytarasov-031973@postgrespro.ru", "phone": "+70309751773"}
0005432693148	90AC98	6422 156048	EKATERINA GERASIMOVA	{"phone": "+70363760770"}
0005432693149	90AC98	4870 585300	ANASTASIYA ORLOVA	{"email": "orlova_a.111972@postgrespro.ru", "phone": "+70998219336"}
0005432693150	DCB10D	0676 139932	OLGA RYABOVA	{"email": "ryabova_olga-1981@postgrespro.ru", "phone": "+70982332098"}
0005432693151	DCB10D	8592 674179	IVAN SOLOVEV	{"email": "solovev.ivan1972@postgrespro.ru", "phone": "+70184174268"}
0005432693152	C019B1	7264 968953	VIOLETTA ZAYCEVA	{"phone": "+70240998315"}
0005432693153	C019B1	8528 137146	ELENA GORBUNOVA	{"phone": "+70097846486"}
0005432693154	7D54B3	4693 255486	LYUBOV MIRONOVA	{"email": "l_mironova_01011995@postgrespro.ru", "phone": "+70655113708"}
0005432693155	E625E0	6509 475325	SERGEY NOVIKOV	{"email": "novikov.s-1966@postgrespro.ru", "phone": "+70692348117"}
0005432693156	F88C0B	7052 592096	VLADIMIR NAZAROV	{"email": "nazarov.vladimir-081982@postgrespro.ru", "phone": "+70062463997"}
0005432693157	9EB057	0811 228407	ALEKSANDR NIKITIN	{"phone": "+70146216994"}
0005432693158	9EB057	0130 948164	GALINA DANILOVA	{"phone": "+70399073119"}
0005432693159	1F92D5	9699 027893	ANTON NIKITIN	{"email": "anton.nikitin.061969@postgrespro.ru", "phone": "+70677153360"}
0005432693160	1F92D5	5829 148085	NINA KUZNECOVA	{"phone": "+70936440586"}
0005432693161	48E137	7920 608629	VLADISLAV FEDOROV	{"email": "vladislav_fedorov-18101981@postgrespro.ru", "phone": "+70991053478"}
0005432693162	ADD220	8700 083254	NIKOLAY DENISOV	{"phone": "+70737178908"}
0005432693163	8ADC7D	3231 830229	IVAN KOROLEV	{"email": "korolev.i.091974@postgrespro.ru", "phone": "+70849047603"}
0005432693164	57F02B	7179 106573	NIKOLAY SOLOVEV	{"email": "nsolovev.1968@postgrespro.ru", "phone": "+70662882169"}
0005432693165	57F02B	0924 206887	TAMARA ALEKSANDROVA	{"phone": "+70126095920"}
0005432693166	EE06A7	1408 127441	LYUBOV KOROLEVA	{"email": "lyubov-koroleva13121978@postgrespro.ru", "phone": "+70543787179"}
0005432693167	EE06A7	8804 615695	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov_1967@postgrespro.ru", "phone": "+70359114331"}
0005432693168	F6F950	0125 414705	ALEKSANDR PETROV	{"email": "petrov.a_1967@postgrespro.ru", "phone": "+70371386360"}
0005432693169	36B88B	1940 050308	YURIY GORBUNOV	{"email": "yuriy_gorbunov1970@postgrespro.ru", "phone": "+70168448912"}
0005432693170	36B88B	2526 827559	VLADIMIR ZHUKOV	{"email": "v-zhukov-1983@postgrespro.ru", "phone": "+70811622989"}
0005432693171	5B325B	6802 421377	TIGRAN ZAKHAROV	{"email": "tigran.zakharov-17031969@postgrespro.ru", "phone": "+70221756036"}
0005432693172	61C933	0627 616193	TAMARA PETROVA	{"phone": "+70360982428"}
0005432693173	61C933	3232 858741	ALEKSANDR IVANOV	{"phone": "+70913935855"}
0005432693174	F0E297	1618 567124	SERGEY SOROKIN	{"email": "sorokin.s-101964@postgrespro.ru", "phone": "+70809797030"}
0005432693175	AC362F	7127 790974	LYUBOV NAZAROVA	{"phone": "+70220013321"}
0005432693176	583171	0126 157264	VLADIMIR MATVEEV	{"phone": "+70643328305"}
0005432693177	583171	9786 066809	DMITRIY SMIRNOV	{"email": "dmitriy-smirnov.031966@postgrespro.ru", "phone": "+70158251539"}
0005432693178	BF13AC	4229 184882	SERGEY BORISOV	{"email": "s_borisov-1967@postgrespro.ru", "phone": "+70014146520"}
0005432693179	BF13AC	3805 163941	ALENA GAVRILOVA	{"email": "alena_gavrilova.01081971@postgrespro.ru", "phone": "+70031300919"}
0005432693180	BF13AC	4672 995070	VLADIMIR GUSEV	{"phone": "+70932061814"}
0005432693181	84A8A0	9125 653177	SERGEY SEMENOV	{"email": "semenovs.121970@postgrespro.ru", "phone": "+70443262760"}
0005432693182	BD180B	1251 553845	ELENA PAVLOVA	{"email": "pavlova-e08091980@postgrespro.ru", "phone": "+70030081047"}
0005432693183	BD180B	7204 366466	SERGEY DMITRIEV	{"email": "dmitrievsergey1982@postgrespro.ru", "phone": "+70452524231"}
0005432693184	A1CD7B	4139 573450	DMITRIY MAKAROV	{"phone": "+70787567786"}
0005432693185	D8392E	5281 593740	ANDREY KARPOV	{"email": "karpov.andrey_20111973@postgrespro.ru", "phone": "+70349726034"}
0005432693186	ABC682	0964 226570	ANDREY MELNIKOV	{"phone": "+70363553851"}
0005432693187	C6088D	6347 991190	PAVEL SCHERBAKOV	{"phone": "+70918124025"}
0005432693188	C6088D	9014 341663	VYACHESLAV ANTONOV	{"email": "vyacheslav-antonov121977@postgrespro.ru", "phone": "+70241917289"}
0005432693189	073481	0201 658394	TATYANA TROFIMOVA	{"email": "trofimova-t.071974@postgrespro.ru", "phone": "+70116742021"}
0005432693190	BA75AE	2581 699867	VIKTOR POPOV	{"email": "popov_v.1970@postgrespro.ru", "phone": "+70814013541"}
0005432693191	F8D086	7950 280513	PAVEL GRIGOREV	{"email": "grigorevpavel07061969@postgrespro.ru", "phone": "+70350028521"}
0005432693192	F8D086	8146 665422	NINA VOLKOVA	{"phone": "+70266216357"}
0005432693193	67CB4C	7084 417509	NIKITA ANTONOV	{"phone": "+70188005731"}
0005432693194	A2E6EA	4743 256295	MILANA AKIMOVA	{"phone": "+70389733833"}
0005432693195	A2FA34	3155 415575	ELINA MIKHAYLOVA	{"email": "mikhaylova.elina-1972@postgrespro.ru", "phone": "+70798429619"}
0005432693196	9BF320	2111 602371	KSENIYA IVANOVA	{"email": "k.ivanova_01021975@postgrespro.ru", "phone": "+70168880417"}
0005432693197	06089B	9067 595163	VLADIMIR SCHERBAKOV	{"phone": "+70275930017"}
0005432693198	35906B	3721 341274	NADEZHDA MOISEEVA	{"phone": "+70454232703"}
0005432693199	E3DA4F	7752 753243	ALEKSANDR KOROLEV	{"email": "aleksandr_korolev_1979@postgrespro.ru", "phone": "+70712146941"}
0005432693200	E3DA4F	3783 564717	ELIZAVETA BOGDANOVA	{"phone": "+70280141019"}
0005432693201	306BAF	6213 435431	ALEKSANDR KAZAKOV	{"phone": "+70499341406"}
0005432693202	7B8426	7235 083120	LYUDMILA PETROVA	{"email": "lpetrova_011960@postgrespro.ru", "phone": "+70951233719"}
0005432693203	7B8426	7983 287430	TAGIR KOZLOV	{"email": "kozlov.t-021973@postgrespro.ru", "phone": "+70425982502"}
0005432693204	7EB41C	2327 002670	EKATERINA ZOTOVA	{"email": "zotova-e-041990@postgrespro.ru", "phone": "+70274673167"}
0005432693205	642BB6	2199 171874	IGOR FEDOROV	{"phone": "+70377367384"}
0005432693206	BBF3D5	1703 774243	SANIYA STEPANOVA	{"phone": "+70664000113"}
0005432693207	BBF3D5	5051 509073	ROMAN ZAYCEV	{"email": "zaycevr_04031983@postgrespro.ru", "phone": "+70135405455"}
0005432693208	C48EED	7502 173177	SAMIR BARANOV	{"email": "s_baranov_011980@postgrespro.ru", "phone": "+70776677984"}
0005432693209	C48EED	6792 277098	NIKITA SERGEEV	{"email": "nikita-sergeev.1961@postgrespro.ru", "phone": "+70170699094"}
0005432693210	C48EED	7833 212833	OLGA POLYAKOVA	{"email": "polyakova-olga.021980@postgrespro.ru", "phone": "+70466168833"}
0005432693211	40C1D2	0357 569334	OLGA IVANOVA	{"email": "ivanova-olga-1965@postgrespro.ru", "phone": "+70890174207"}
0005432693212	D87E9E	0012 370104	OLGA VOROBEVA	{"email": "vorobeva.olga_1971@postgrespro.ru", "phone": "+70582872335"}
0005432693213	D87E9E	4700 851744	SERGEY NAZAROV	{"phone": "+70817231643"}
0005432693214	BDFCEF	1174 111123	NATALYA CHERNOVA	{"email": "n.chernova011966@postgrespro.ru", "phone": "+70632593170"}
0005432693215	589E44	3380 998769	MARGARITA FROLOVA	{"email": "margarita_frolova-1970@postgrespro.ru", "phone": "+70146148943"}
0005432693216	F90D88	0966 494952	VLADIMIR ZAKHAROV	{"email": "v-zakharov-1971@postgrespro.ru", "phone": "+70373823829"}
0005432693217	6D2715	1466 859828	IGOR ZAYCEV	{"email": "izaycev1966@postgrespro.ru", "phone": "+70524675345"}
0005432693218	1487D9	3543 870957	VLADIMIR IVANOV	{"phone": "+70771258959"}
0005432693219	7508D0	0265 911046	RAVIL NIKITIN	{"email": "r-nikitin_1985@postgrespro.ru", "phone": "+70112986657"}
0005432693220	E047DD	2950 791635	SERGEY SCHERBAKOV	{"email": "s-scherbakov-031973@postgrespro.ru", "phone": "+70857802672"}
0005432693221	153E30	8071 118481	ELENA TARASOVA	{"email": "e-tarasova_121976@postgrespro.ru", "phone": "+70090101125"}
0005432693222	153E30	6744 042221	ANDREY PETROV	{"phone": "+70744444329"}
0005432693223	6E930C	3998 727376	SERGEY KUZNECOV	{"email": "kuznecov-s_1972@postgrespro.ru", "phone": "+70231329580"}
0005432693224	F8F4E2	4253 991823	ALEKSEY SMIRNOV	{"phone": "+70546060939"}
0005432693225	05AC33	2687 474098	NATALYA KALININA	{"email": "kalininan-101971@postgrespro.ru", "phone": "+70347073837"}
0005432693226	C153AC	2338 042496	NATALYA NAZAROVA	{"phone": "+70367618540"}
0005432693227	910AF3	7121 558851	LILIYA KUZNECOVA	{"email": "kuznecoval121975@postgrespro.ru", "phone": "+70526040215"}
0005432693228	910AF3	1449 760357	MIKHAIL GUSEV	{"phone": "+70399483390"}
0005432693229	DBF4BF	6350 124722	ALEKSANDR ISAEV	{"email": "isaev.aleksandr-011979@postgrespro.ru", "phone": "+70827406915"}
0005432693230	1441A0	7710 503223	OLGA KARPOVA	{"email": "karpova-o08081964@postgrespro.ru", "phone": "+70867488350"}
0005432693231	77B635	1534 021412	EKATERINA ZAYCEVA	{"phone": "+70363589298"}
0005432693232	77B635	1380 812871	KRISTINA ISAEVA	{"phone": "+70063665617"}
0005432693233	77B635	0742 227886	ANNA BOGDANOVA	{"email": "a-bogdanova_12111974@postgrespro.ru", "phone": "+70371931018"}
0005432693234	9175A6	3596 900223	NIKOLAY ZHURAVLEV	{"email": "nzhuravlev_031963@postgrespro.ru", "phone": "+70660943191"}
0005432693235	9175A6	1433 037604	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr021972@postgrespro.ru", "phone": "+70962899554"}
0005432693236	C1015A	2968 857618	OLGA BARANOVA	{"phone": "+70494930255"}
0005432693237	0B0BDE	6765 928689	KLAVDIYA ALEKSANDROVA	{"email": "aleksandrovak_1980@postgrespro.ru", "phone": "+70138641568"}
0005432693238	E6DCF7	4705 100836	ALLA POPOVA	{"email": "a-popova021976@postgrespro.ru", "phone": "+70720787458"}
0005432693239	14E841	4910 887634	PETR FROLOV	{"phone": "+70212844110"}
0005432693240	14E841	1716 495648	LYUBOV MEDVEDEVA	{"email": "lyubov.medvedeva1970@postgrespro.ru", "phone": "+70039365523"}
0005432693241	55FDA1	3555 337857	YULIYA MOISEEVA	{"email": "moiseeva.y101975@postgrespro.ru", "phone": "+70713280914"}
0005432693242	55FDA1	4886 415072	LARISA IVANOVA	{"email": "ivanova_larisa-1971@postgrespro.ru", "phone": "+70383972602"}
0005432693243	60535E	6703 512765	VIKTOR TIKHONOV	{"phone": "+70152285160"}
0005432693244	644E0C	9638 946702	GALINA EFREMOVA	{"phone": "+70495776615"}
0005432693245	644E0C	1965 808686	ALEKSEY KOROLEV	{"email": "a.korolev-25081981@postgrespro.ru", "phone": "+70277598420"}
0005432693246	EDE30C	2713 594921	MARIYA VOLKOVA	{"phone": "+70015886213"}
0005432693247	F254FA	2945 113256	EVGENIY NIKITIN	{"phone": "+70952971780"}
0005432693248	DA5029	9690 054159	LILIYA DMITRIEVA	{"email": "dmitrieva.l_06021972@postgrespro.ru", "phone": "+70137032252"}
0005432693249	DA5029	5314 717776	ALEKSANDR VLASOV	{"email": "aleksandrvlasov_1974@postgrespro.ru", "phone": "+70201557838"}
0005432693250	D924A0	3024 533004	TATYANA SOKOLOVA	{"email": "t.sokolova_101969@postgrespro.ru", "phone": "+70560841201"}
0005432693251	02FBCE	4703 397474	OLEG KULIKOV	{"email": "kulikovoleg_29011968@postgrespro.ru", "phone": "+70865541979"}
0005432693252	02FBCE	7816 333153	OLGA BORISOVA	{"email": "borisova.o.01071964@postgrespro.ru", "phone": "+70033900420"}
0005432693253	E5DDED	7869 404431	EVGENIY TARASOV	{"phone": "+70130226396"}
0005432693254	6A8E3E	9056 825698	ALEKSANDRA EFIMOVA	{"email": "efimova_aleksandra.1978@postgrespro.ru", "phone": "+70126985496"}
0005432693255	6A8E3E	1292 880506	ARINA SOKOLOVA	{"phone": "+70303115440"}
0005432693256	3E1E1C	7664 463397	VYACHESLAV ANTONOV	{"email": "vyacheslav.antonov.031983@postgrespro.ru", "phone": "+70086202849"}
0005432693257	E6D00A	6643 686835	LYUDMILA SOROKINA	{"email": "l_sorokina_041975@postgrespro.ru", "phone": "+70086216333"}
0005432693258	2B1DB4	8471 866486	DENIS KUDRYASHOV	{"phone": "+70271480694"}
0005432693259	40EDB0	8602 017099	IRINA MATVEEVA	{"email": "irina_matveeva-30041973@postgrespro.ru", "phone": "+70429119173"}
0005432693260	12C63A	2622 034762	OLGA ERMAKOVA	{"phone": "+70224712130"}
0005432693261	33A858	4599 662990	VALENTIN MATVEEV	{"phone": "+70617091871"}
0005432693262	19C9EC	7881 939802	GALINA ZOTOVA	{"email": "g-zotova14051977@postgrespro.ru", "phone": "+70261104149"}
0005432693263	D1DA83	5102 349686	MAKAR GERASIMOV	{"email": "gerasimov_makar-1965@postgrespro.ru", "phone": "+70462794236"}
0005432693264	0F0D45	6535 611027	ALEKSEY ALEKSEEV	{"email": "a_alekseev.02061968@postgrespro.ru", "phone": "+70829812847"}
0005432693265	0F0D45	1800 335213	VALERIY ZAKHAROV	{"phone": "+70948757056"}
0005432693266	B0D0ED	6098 166168	VLADIMIR PETROV	{"email": "petrovv15081960@postgrespro.ru", "phone": "+70624866203"}
0005432693267	16D92E	8529 201224	ALEKSANDR SOKOLOV	{"phone": "+70531410073"}
0005432693268	16D92E	9160 652665	OLGA DAVYDOVA	{"phone": "+70940072097"}
0005432693269	09EF19	2615 494293	ANASTASIYA MAKSIMOVA	{"email": "maksimova-anastasiya071972@postgrespro.ru", "phone": "+70570056102"}
0005432693270	36ECE1	0196 477130	ALEKSEY MAKAROV	{"phone": "+70094153523"}
0005432693271	B41ABC	3497 327856	ANASTASIYA OVCHINNIKOVA	{"email": "anastasiya-ovchinnikova.071975@postgrespro.ru", "phone": "+70062220911"}
0005432693272	B41ABC	1127 903197	EVGENIY DENISOV	{"email": "denisov.e061970@postgrespro.ru", "phone": "+70314258583"}
0005432693273	03627E	1120 431119	POLINA GAVRILOVA	{"email": "gavrilova_polina.011970@postgrespro.ru", "phone": "+70527832103"}
0005432693274	382BE1	0091 910325	LYUDMILA KONDRATEVA	{"email": "lyudmila-kondrateva-1969@postgrespro.ru", "phone": "+70917159385"}
0005432693275	382BE1	4414 801661	ANDREY NAUMOV	{"phone": "+70376856020"}
0005432693276	382BE1	0773 253808	TATYANA YAKOVLEVA	{"phone": "+70239717166"}
0005432693277	A4F3A6	7995 462109	GRIGORIY GUSEV	{"email": "g-gusev26111971@postgrespro.ru", "phone": "+70172236018"}
0005432693278	283D41	4040 145471	MIKHAIL MARTYNOV	{"phone": "+70827038739"}
0005432693279	283D41	8928 316438	GEVORG FROLOV	{"email": "frolov.g_22091971@postgrespro.ru", "phone": "+70527940691"}
0005432693280	DE362C	0158 287472	TATYANA ZAYCEVA	{"email": "tatyana_zayceva-29011978@postgrespro.ru", "phone": "+70279364529"}
0005432693281	01E153	8633 286188	ALEKSANDR NOVIKOV	{"phone": "+70408060355"}
0005432693282	41AA37	5757 218036	IGOR IVANOV	{"phone": "+70169914491"}
0005432693283	41AA37	2780 082362	NIKOLAY PETROV	{"email": "petrov.n_23051977@postgrespro.ru", "phone": "+70465587091"}
0005432693284	8A9544	3903 769343	ANNA OVCHINNIKOVA	{"phone": "+70784844597"}
0005432693285	D8D0E7	6732 129889	OLEG SOROKIN	{"email": "o_sorokin-071978@postgrespro.ru", "phone": "+70352254845"}
0005432693286	D8D0E7	7079 879102	MILANA IVANOVA	{"email": "ivanova-milana-111968@postgrespro.ru", "phone": "+70485939316"}
0005432693287	BBA639	1132 948078	VADIM PETROV	{"phone": "+70274826859"}
0005432693288	980EA0	7368 496555	ELENA BORISOVA	{"phone": "+70502674520"}
0005432693289	980EA0	1553 719643	YURIY IVANOV	{"phone": "+70290785319"}
0005432693290	8D1A7E	7162 566020	MARIYA ANDREEVA	{"email": "andreeva_m_03101976@postgrespro.ru", "phone": "+70957087625"}
0005432693291	608045	4380 927688	IGOR KAZAKOV	{"email": "igor.kazakov_09041967@postgrespro.ru", "phone": "+70776089038"}
0005432693292	682F58	5462 764278	VYACHESLAV SEMENOV	{"email": "semenov.vyacheslav1969@postgrespro.ru", "phone": "+70635353704"}
0005432693293	CD78E1	7578 854693	MARIYA NAUMOVA	{"email": "mnaumova.15031970@postgrespro.ru", "phone": "+70413501047"}
0005432693294	CD78E1	3397 406169	INNA SEMENOVA	{"email": "isemenova.1965@postgrespro.ru", "phone": "+70857226598"}
0005432693295	8A26A9	3852 501196	VYACHESLAV TIMOFEEV	{"email": "timofeev-v.1977@postgrespro.ru", "phone": "+70747144717"}
0005432693296	8A26A9	5268 138007	ROMAN PAVLOV	{"email": "roman-pavlov1971@postgrespro.ru", "phone": "+70790389848"}
0005432693297	175BB2	3474 143303	IVAN FROLOV	{"email": "ivan-frolov_1973@postgrespro.ru", "phone": "+70751643753"}
0005432693298	175BB2	6792 873077	VALENTINA GUSEVA	{"email": "vguseva021969@postgrespro.ru", "phone": "+70424342056"}
0005432693299	427F64	1669 013938	ANNA KONDRATEVA	{"phone": "+70348582448"}
0005432693300	DD3B41	3664 300174	MARGARITA FILIPPOVA	{"email": "m-filippova_21011966@postgrespro.ru", "phone": "+70754942682"}
0005432693301	A37FC5	2559 040911	ROMAN BARANOV	{"phone": "+70020379263"}
0005432693302	D01272	0830 307875	ANDREY ILIN	{"phone": "+70810445083"}
0005432693303	D01272	7569 251509	LYUBOV ERMAKOVA	{"email": "ermakova.l_061968@postgrespro.ru", "phone": "+70466193902"}
0005432693304	73461F	3060 659161	OLGA IVANOVA	{"email": "oivanova.25051981@postgrespro.ru", "phone": "+70950586146"}
0005432693305	73461F	0783 793018	LIDIYA FILIPPOVA	{"phone": "+70037713679"}
0005432693306	3BC779	9319 181496	ALEKSANDR IVANOV	{"phone": "+70045549840"}
0005432693307	1EA58D	2643 775369	OKSANA KOZLOVA	{"email": "oksana.kozlova.05061972@postgrespro.ru", "phone": "+70088662652"}
0005432693308	1EA58D	9293 923463	GENNADIY PETROV	{"email": "petrov.g_1973@postgrespro.ru", "phone": "+70987103607"}
0005432693309	6D170F	8685 336642	ANGELINA TROFIMOVA	{"phone": "+70071610270"}
0005432693310	38393E	5289 954384	EGOR DENISOV	{"email": "egordenisov1966@postgrespro.ru", "phone": "+70992584143"}
0005432693311	79B337	8494 254091	EGOR BARANOV	{"phone": "+70977521236"}
0005432693312	79B337	0446 734928	ALEKSEY BORISOV	{"email": "aleksey_borisov.051959@postgrespro.ru", "phone": "+70921681768"}
0005432693313	209BBC	0147 303846	NIKITA SEMENOV	{"email": "semenovn_29021976@postgrespro.ru", "phone": "+70470773534"}
0005432693314	9BFBC9	0473 154591	ALEKSEY SERGEEV	{"email": "aleksey-sergeev021972@postgrespro.ru", "phone": "+70429794468"}
0005432693315	9BFBC9	3632 521929	SERGEY ABRAMOV	{"email": "sergeyabramov_1974@postgrespro.ru", "phone": "+70240305775"}
0005432693316	BF508B	3775 585312	NATALYA EGOROVA	{"email": "egorova_n22081970@postgrespro.ru", "phone": "+70106271837"}
0005432693317	FCB913	1893 095913	ANNA LAZAREVA	{"email": "lazareva_anna-29071968@postgrespro.ru", "phone": "+70468310172"}
0005432693318	FCB913	8581 903400	YURIY SEMENOV	{"email": "semenov_yuriy.081966@postgrespro.ru", "phone": "+70624283528"}
0005432693319	478A32	3275 692744	YULIYA ANTONOVA	{"email": "antonova-yuliya-29121975@postgrespro.ru", "phone": "+70508538675"}
0005432693320	478A32	6307 799344	TATYANA BARANOVA	{"phone": "+70945680594"}
0005432693321	3F5F73	2015 032861	NINA DANILOVA	{"phone": "+70725891480"}
0005432693322	3F5F73	8886 417898	NATALYA DAVYDOVA	{"email": "n_davydova-24101974@postgrespro.ru", "phone": "+70156141732"}
0005432693323	C3C818	9705 683373	TATYANA YAKOVLEVA	{"email": "t_yakovleva-18021980@postgrespro.ru", "phone": "+70461060096"}
0005432693324	C3C818	7674 977916	DMITRIY MEDVEDEV	{"email": "d-medvedev-07011966@postgrespro.ru", "phone": "+70087813580"}
0005432693325	57BA5C	1207 382912	ALEKSEY MARTYNOV	{"email": "martynov.aleksey021973@postgrespro.ru", "phone": "+70411507151"}
0005432693326	71047D	9779 812913	ELISEY KUDRYASHOV	{"email": "kudryashovelisey.1970@postgrespro.ru", "phone": "+70617725592"}
0005432693327	62E217	7113 629567	NIKITA ILIN	{"phone": "+70793286431"}
0005432693328	CA0F21	5614 125212	ALINA SERGEEVA	{"email": "a_sergeeva-26121972@postgrespro.ru", "phone": "+70299868898"}
0005432693329	6A0127	0583 768796	YULIYA LUKYANOVA	{"email": "lukyanova.yuliya-1980@postgrespro.ru", "phone": "+70125657806"}
0005432693330	6A0127	8740 754561	YURIY PETROV	{"email": "yuriypetrov15101961@postgrespro.ru", "phone": "+70197590821"}
0005432693331	7155C1	2336 602584	LILIYA DMITRIEVA	{"email": "dmitrieva.l-101973@postgrespro.ru", "phone": "+70821790627"}
0005432693332	7155C1	4818 194026	VYACHESLAV ANDREEV	{"email": "andreev_v-05061978@postgrespro.ru", "phone": "+70301773479"}
0005432693333	2721D6	2591 497270	VLADIMIR BORISOV	{"phone": "+70930313140"}
0005432693334	98608E	9089 058236	MAKSIM NIKITIN	{"phone": "+70880823319"}
0005432693335	2AA942	3402 646930	ELENA VOLKOVA	{"phone": "+70019123027"}
0005432693336	387FB5	8279 903429	OLGA ABRAMOVA	{"email": "abramova-o.1973@postgrespro.ru", "phone": "+70070837092"}
0005432693337	387FB5	6276 383245	ALEKSEY MOROZOV	{"email": "morozova.24061965@postgrespro.ru", "phone": "+70600879076"}
0005432693338	19C243	8057 847470	YURIY POPOV	{"email": "popov_y-05051959@postgrespro.ru", "phone": "+70793079030"}
0005432693339	B6CEB6	5850 579065	NATALYA ANTONOVA	{"phone": "+70954250803"}
0005432693340	E18E07	7322 139228	MIKHAIL POPOV	{"email": "popovmikhail_101967@postgrespro.ru", "phone": "+70425877339"}
0005432693341	DE0088	3512 613516	EVGENIY ROMANOV	{"email": "evgeniy.romanov1974@postgrespro.ru", "phone": "+70368483235"}
0005432693342	DE0088	1477 899504	NADEZHDA MELNIKOVA	{"email": "n-melnikova05031972@postgrespro.ru", "phone": "+70168543390"}
0005432693343	09CE89	4321 314813	EVGENIY PAVLOV	{"phone": "+70648762799"}
0005432693344	70C7D8	5713 590419	TAMARA KULIKOVA	{"email": "kulikova_tamara1973@postgrespro.ru", "phone": "+70738398178"}
0005432693345	AD1D08	4495 503015	VARVARA POPOVA	{"email": "varvarapopova.23051972@postgrespro.ru", "phone": "+70688588092"}
0005432693346	B1E904	3281 048763	ANNA MIRONOVA	{"email": "a_mironova041977@postgrespro.ru", "phone": "+70472694097"}
0005432693347	B1E904	2300 878022	ILYA DAVYDOV	{"phone": "+70428799480"}
0005432693348	6BC98A	4628 323784	LYUDMILA SCHERBAKOVA	{"email": "scherbakovalyudmila-121970@postgrespro.ru", "phone": "+70257887764"}
0005432693349	62099F	4271 398093	ELENA POTAPOVA	{"email": "elena.potapova101966@postgrespro.ru", "phone": "+70898554355"}
0005432693350	9A4EC2	0292 856337	NIKITA DENISOV	{"email": "nikita_denisov.1979@postgrespro.ru", "phone": "+70570075314"}
0005432693351	91BF1C	2131 819830	VIKTOR GUSEV	{"email": "viktorgusev.25061967@postgrespro.ru", "phone": "+70793458923"}
0005432693352	91BF1C	2555 495780	VALENTINA RODIONOVA	{"phone": "+70463242395"}
0005432693353	02510F	9807 865598	RAISA FILIPPOVA	{"phone": "+70581905460"}
0005432693354	77E758	3297 205073	VALENTINA GERASIMOVA	{"phone": "+70458068506"}
0005432693355	DCB97C	6206 539753	IVAN ABRAMOV	{"email": "ivan_abramov_1967@postgrespro.ru", "phone": "+70347636553"}
0005432693356	4C6345	5194 202683	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr-19101979@postgrespro.ru", "phone": "+70902455062"}
0005432693357	4CDFC2	8786 509937	KONSTANTIN BONDARENKO	{"phone": "+70884895319"}
0005432693358	4CDFC2	7513 686263	YURIY VASILEV	{"email": "vasilevy.041984@postgrespro.ru", "phone": "+70939854706"}
0005432693359	1A199E	5984 971126	ILYA VOLKOV	{"email": "volkov-ilya101978@postgrespro.ru", "phone": "+70466830739"}
0005432693360	1A199E	6017 292533	ELENA SOKOLOVA	{"email": "sokolova_e-081975@postgrespro.ru", "phone": "+70088162570"}
0005432693361	EF674C	8328 660766	KARINA NAUMOVA	{"phone": "+70065124810"}
0005432693362	C3278E	2282 037831	ANTONIDA KONOVALOVA	{"phone": "+70639608134"}
0005432693363	D7C375	6469 979498	GALINA MOROZOVA	{"phone": "+70241406312"}
0005432693364	FA291A	0450 667420	VLADIMIR TARASOV	{"email": "v-tarasov.1965@postgrespro.ru", "phone": "+70185858438"}
0005432693365	DC84BA	2790 053030	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_1959@postgrespro.ru", "phone": "+70637051634"}
0005432693366	AC99BC	6006 735884	TATYANA POPOVA	{"email": "tpopova.1959@postgrespro.ru", "phone": "+70600256687"}
0005432693367	AC99BC	1102 014715	EDUARD SCHERBAKOV	{"phone": "+70693507097"}
0005432693368	4D2D11	3003 314303	IRINA SIDOROVA	{"email": "i_sidorova_1966@postgrespro.ru", "phone": "+70292755575"}
0005432693369	4D2D11	6025 524389	ALEKSANDR MATVEEV	{"phone": "+70531594445"}
0005432693370	16E967	7091 977646	VLADIMIR VOROBEV	{"phone": "+70941749498"}
0005432693371	1DEF3D	5064 667751	LYUDMILA SOROKINA	{"phone": "+70387939355"}
0005432693372	AD8C51	4747 682826	ALEKSEY KULIKOV	{"phone": "+70082328047"}
0005432693373	EE3B35	2874 924424	PAVEL ZHUKOV	{"phone": "+70212358855"}
0005432693374	423CD9	5387 580177	ALEKSANDRA MOROZOVA	{"email": "aleksandra-morozova.23061968@postgrespro.ru", "phone": "+70076573682"}
0005432693375	9829A9	1718 410992	VIKTOR ZAKHAROV	{"email": "zakharov_v26041971@postgrespro.ru", "phone": "+70432042085"}
0005432693376	379ABF	6421 018765	IVAN IVANOV	{"email": "ivanov_ivan-1968@postgrespro.ru", "phone": "+70475014743"}
0005432693377	588D07	7834 893792	LARISA KISELEVA	{"email": "kiseleva_l1983@postgrespro.ru", "phone": "+70403994017"}
0005432693378	5BB715	1942 573476	ALEKSANDR MATVEEV	{"email": "a_matveev1978@postgrespro.ru", "phone": "+70495957520"}
0005432693379	32D7A6	6570 758228	KIRILL KONOVALOV	{"phone": "+70975379549"}
0005432693380	B575AB	8237 606206	MARIYA KOVALEVA	{"phone": "+70615649762"}
0005432693381	19C313	0682 916095	RAISA STEPANOVA	{"email": "raisastepanova-1966@postgrespro.ru", "phone": "+70675734032"}
0005432693382	19C313	2336 013076	PETR SCHERBAKOV	{"email": "petr.scherbakov.011967@postgrespro.ru", "phone": "+70954908969"}
0005432693383	5E0273	9516 072905	TAMARA KONOVALOVA	{"phone": "+70009622902"}
0005432693384	CE211E	0352 509172	VALENTINA MAKAROVA	{"email": "v.makarova1961@postgrespro.ru", "phone": "+70442509101"}
0005432693385	CE211E	7209 853308	TAISIYA KRASNOVA	{"email": "tkrasnova-121966@postgrespro.ru", "phone": "+70474211039"}
0005432693386	C2010D	2679 274443	NADEZHDA TITOVA	{"email": "titova-n.1955@postgrespro.ru", "phone": "+70238812609"}
0005432693387	C2010D	0643 836167	EVGENIY STEPANOV	{"email": "e.stepanov_071979@postgrespro.ru", "phone": "+70110032575"}
0005432693388	4EEC92	6098 660093	TATYANA FROLOVA	{"phone": "+70392164481"}
0005432693389	764D1C	3966 384698	ALINA ZAKHAROVA	{"phone": "+70703714392"}
0005432693390	02E091	5833 936467	VALENTINA SOROKINA	{"phone": "+70854209690"}
0005432693391	E69F03	0204 346345	LYUBOV FROLOVA	{"email": "frolova_lyubov02121965@postgrespro.ru", "phone": "+70215027185"}
0005432693392	B566D3	8021 700721	SERGEY KUZNECOV	{"email": "kuznecovsergey_17011971@postgrespro.ru", "phone": "+70274795149"}
0005432693393	0F11D9	6207 753994	VALENTINA POLYAKOVA	{"email": "v-polyakova.081971@postgrespro.ru", "phone": "+70739650295"}
0005432693394	480C61	1473 913610	POLINA ILINA	{"email": "ilina-p-06121973@postgrespro.ru", "phone": "+70859497378"}
0005432693395	DCFBED	1511 418853	GALINA KULIKOVA	{"phone": "+70102314559"}
0005432693396	74FB51	2614 759233	GENNADIY ORLOV	{"email": "orlov_g.081975@postgrespro.ru", "phone": "+70384224149"}
0005432693397	93DC7C	0703 906865	TATYANA TIKHONOVA	{"phone": "+70764393652"}
0005432693398	F21FAD	8812 379572	GALINA KRASNOVA	{"email": "krasnova_galina-10081971@postgrespro.ru", "phone": "+70472495633"}
0005432693399	F21FAD	5485 034554	TATYANA SEMENOVA	{"phone": "+70661913025"}
0005432693400	C8CD43	1116 153378	DMITRIY SOKOLOV	{"phone": "+70729089568"}
0005432693401	C43E23	2476 060694	SERGEY NAUMOV	{"phone": "+70537256489"}
0005432693402	C43E23	8924 501588	TATYANA PAVLOVA	{"phone": "+70365423557"}
0005432693403	385661	6153 128060	ANATOLIY MOROZOV	{"email": "morozov-anatoliy.1971@postgrespro.ru", "phone": "+70011174053"}
0005432693404	385661	7501 418311	OKSANA SMIRNOVA	{"phone": "+70564085524"}
0005432693405	385661	3993 059051	NATALYA TROFIMOVA	{"email": "n_trofimova011958@postgrespro.ru", "phone": "+70353135385"}
0005432693406	3009D3	9720 110057	ALEKSANDRA TIKHONOVA	{"email": "tikhonova.aleksandra_14051974@postgrespro.ru", "phone": "+70743159537"}
0005432693407	5D4049	8750 801012	NELLYA MELNIKOVA	{"phone": "+70403593417"}
0005432693408	5D4049	1982 214033	IRINA ZOTOVA	{"email": "i.zotova_1978@postgrespro.ru", "phone": "+70766102354"}
0005432693409	4C70D7	5574 230053	ALEKSEY KOZLOV	{"email": "a-kozlov.07111970@postgrespro.ru", "phone": "+70834408631"}
0005432693410	4C70D7	4720 054000	IGOR MAKAROV	{"email": "i.makarov-1962@postgrespro.ru", "phone": "+70850872341"}
0005432693411	16C118	4420 890858	GEORGIY KUDRYASHOV	{"email": "kudryashovg_27081978@postgrespro.ru", "phone": "+70339057747"}
0005432693412	FF87B1	2994 727676	VALENTINA KARPOVA	{"phone": "+70723085932"}
0005432693413	C99AFF	7556 546245	OLEG SCHERBAKOV	{"email": "oscherbakov.1963@postgrespro.ru", "phone": "+70541085896"}
0005432693414	007247	7627 669670	ELENA VASILEVA	{"phone": "+70234482513"}
0005432693415	26F4B8	8325 352819	NATALIYA MIRONOVA	{"phone": "+70296930977"}
0005432693416	8C6D90	5759 946810	EVGENIY SOROKIN	{"email": "e_sorokin_16101984@postgrespro.ru", "phone": "+70703435493"}
0005432693417	ECEB4E	8388 346508	ALEKSANDR SMIRNOV	{"phone": "+70851187474"}
0005432693418	BBF190	3703 659444	VLADIMIR BONDARENKO	{"phone": "+70875496719"}
0005432693419	BBF190	9097 709766	VALERIYA KUZNECOVA	{"phone": "+70120455822"}
0005432693420	F124AE	4798 170240	VLADIMIR VLASOV	{"email": "vvlasov-18051966@postgrespro.ru", "phone": "+70755877847"}
0005432693421	A2085F	4856 139842	ANNA ERMAKOVA	{"phone": "+70839413136"}
0005432693422	773216	2560 386913	LYUBOV IVANOVA	{"phone": "+70744243915"}
0005432693423	56FEFB	2504 768270	SERGEY KULIKOV	{"phone": "+70885281413"}
0005432693424	466D12	6641 972270	ANNA FROLOVA	{"phone": "+70483586111"}
0005432693425	DE4409	1951 000093	SERGEY SEMENOV	{"phone": "+70745731418"}
0005432693426	3C9EC6	7868 670436	KLAVDIYA ALEKSANDROVA	{"email": "k-aleksandrova_20091972@postgrespro.ru", "phone": "+70410104618"}
0005432693427	C9000D	4266 881187	VALERIY NAUMOV	{"email": "naumovvaleriy.051987@postgrespro.ru", "phone": "+70110929905"}
0005432693428	2D500C	6469 680013	VASILIY IVANOV	{"email": "v-ivanov_18101964@postgrespro.ru", "phone": "+70900602713"}
0005432693429	B8D795	2469 753430	VLADIMIR MIRONOV	{"phone": "+70831800890"}
0005432693430	ACE3CE	2530 422296	VIKTOR KUZMIN	{"phone": "+70535122776"}
0005432693431	ACE3CE	6677 706066	SERGEY KUDRYASHOV	{"email": "kudryashov_s-1970@postgrespro.ru", "phone": "+70002532562"}
0005432693432	37E1CB	1210 310772	VALENTINA NOVIKOVA	{"email": "valentinanovikova121967@postgrespro.ru", "phone": "+70615307693"}
0005432693433	4CA2C6	9716 810915	SERGEY ABRAMOV	{"email": "s-abramov1975@postgrespro.ru", "phone": "+70924794208"}
0005432693434	4CA2C6	2980 950154	TAMARA ANDREEVA	{"email": "andreeva.t_03111963@postgrespro.ru", "phone": "+70828981381"}
0005432693435	96049E	9440 504805	OKSANA DMITRIEVA	{"email": "dmitrieva_o-31121974@postgrespro.ru", "phone": "+70531590975"}
0005432693436	86BD23	8579 621746	ANDREY IVANOV	{"email": "aivanov10071970@postgrespro.ru", "phone": "+70324084024"}
0005432693437	A21B03	8008 888489	VIKTORIYA MIKHAYLOVA	{"phone": "+70947454449"}
0005432693438	A21B03	7876 282265	SVETLANA POTAPOVA	{"email": "potapova.s-1976@postgrespro.ru", "phone": "+70720642631"}
0005432693439	BE70F7	9175 516353	LYUBOV TARASOVA	{"email": "lyubov-tarasova_1974@postgrespro.ru", "phone": "+70032971834"}
0005432693440	DB1EA4	8856 599501	NIKOLAY ZAKHAROV	{"email": "zakharovn_1984@postgrespro.ru", "phone": "+70814070283"}
0005432693441	E83E91	6414 053935	ALEKSEY TIKHONOV	{"email": "tikhonovaleksey.01091968@postgrespro.ru", "phone": "+70137693478"}
0005432693442	98B3D0	9991 811162	NATALYA SOROKINA	{"phone": "+70926075188"}
0005432693443	98B3D0	9132 130951	ALEKSANDR KUZNECOV	{"phone": "+70505067606"}
0005432693444	67571C	9344 041046	ELENA AFANASEVA	{"phone": "+70290499068"}
0005432693445	67571C	5400 957923	GULNAZ POPOVA	{"email": "popova_gulnaz.1977@postgrespro.ru", "phone": "+70959373948"}
0005432693446	67571C	2056 385295	ELENA KUZNECOVA	{"email": "elena_kuznecova_1966@postgrespro.ru", "phone": "+70371812749"}
0005432693447	09EA78	3184 330191	ALEKSANDR TARASOV	{"phone": "+70799112346"}
0005432693448	09EA78	0901 123950	POLINA KOLESNIKOVA	{"phone": "+70182825833"}
0005432693449	09EA78	3180 445086	LYUBOV PAVLOVA	{"phone": "+70724818810"}
0005432693450	10DD30	4231 800634	ALEVTINA BELYAEVA	{"phone": "+70933867147"}
0005432693451	BAABBD	7444 866183	SERGEY BELOV	{"phone": "+70770642372"}
0005432693452	E145CE	9711 692478	MIKHAIL SOKOLOV	{"phone": "+70371719297"}
0005432693453	E145CE	8346 435929	RINAT NAZAROV	{"email": "nazarovr_1977@postgrespro.ru", "phone": "+70019906505"}
0005432693454	4CD156	6778 585173	IGOR ALEKSEEV	{"email": "igor_alekseev071969@postgrespro.ru", "phone": "+70067172474"}
0005432693455	4CD156	2270 314454	ELENA ZHURAVLEVA	{"phone": "+70478865211"}
0005432693456	335FA5	0089 715269	EDUARD KUZMIN	{"email": "e.kuzmin_051961@postgrespro.ru", "phone": "+70179528491"}
0005432693457	335FA5	7286 942391	ELENA RODIONOVA	{"phone": "+70051123542"}
0005432693458	9F79F8	5972 178858	IRINA NAZAROVA	{"phone": "+70481468246"}
0005432693459	6BA62E	8052 990536	LYUDMILA POPOVA	{"phone": "+70431757115"}
0005432693460	EDD58F	2138 016891	NIKITA ABRAMOV	{"phone": "+70679351885"}
0005432693461	EDD58F	0372 092810	RAUF MAKAROV	{"phone": "+70775995583"}
0005432693462	EDD58F	5506 636430	KONSTANTIN SERGEEV	{"email": "sergeev-konstantin_23051974@postgrespro.ru", "phone": "+70899444224"}
0005432693463	2142C9	1596 732382	SVETLANA GRISHINA	{"email": "grishinas-1968@postgrespro.ru", "phone": "+70873383594"}
0005432693464	3E7A61	1611 056151	ELENA NAZAROVA	{"phone": "+70074428603"}
0005432693465	3E7A61	3931 469295	LYUDMILA KUZMINA	{"phone": "+70972919830"}
0005432693466	5698BC	8453 656045	SVETLANA OVCHINNIKOVA	{"email": "sovchinnikova_1969@postgrespro.ru", "phone": "+70454693893"}
0005432693467	200CE8	3578 493508	SVETLANA ZOTOVA	{"phone": "+70004482652"}
0005432693468	200CE8	7262 351779	VYACHESLAV MARTYNOV	{"email": "martynov_v.1966@postgrespro.ru", "phone": "+70276469978"}
0005432693469	9E1FD1	9543 254290	RIMMA KUZNECOVA	{"phone": "+70801714474"}
0005432693470	F6B794	8573 083306	ALEKSANDR NOVIKOV	{"email": "a.novikov_101964@postgrespro.ru", "phone": "+70068442254"}
0005432693471	E6C136	7325 273322	ALEKSEY ZHUKOV	{"phone": "+70167172813"}
0005432693472	E6C136	5922 082920	DMITRIY FILIPPOV	{"phone": "+70480832330"}
0005432693473	E768A4	1139 048234	TATYANA TARASOVA	{"email": "ttarasova_04071965@postgrespro.ru", "phone": "+70044313123"}
0005432693474	27D25C	6322 473968	VERA IVANOVA	{"phone": "+70142563805"}
0005432693475	4DE1D4	2177 204137	ALEKSEY KISELEV	{"phone": "+70975489273"}
0005432693476	CAF7E6	9227 846759	SERGEY MAKSIMOV	{"phone": "+70033166256"}
0005432693477	DD8125	9317 844816	NATALYA NIKITINA	{"email": "natalya-nikitina_091964@postgrespro.ru", "phone": "+70219117489"}
0005432693478	7E6D63	9118 266809	SERGEY BORISOV	{"phone": "+70326094557"}
0005432693479	5AB065	5243 882286	VADIM MEDVEDEV	{"phone": "+70668404360"}
0005432693480	5AB065	4999 361235	KIRILL KUZNECOV	{"phone": "+70908008267"}
0005432693481	1839B3	5188 327704	ANDREY POPOV	{"email": "a-popov_081992@postgrespro.ru", "phone": "+70419169220"}
0005432693482	EA43A0	4995 318788	VALERIYA KISELEVA	{"email": "v_kiseleva04111974@postgrespro.ru", "phone": "+70376408278"}
0005432693483	FE5D09	0858 279252	OLGA ANDREEVA	{"email": "andreeva-olga-1961@postgrespro.ru", "phone": "+70093660850"}
0005432693484	FE5D09	5491 449813	VLADIMIR POPOV	{"email": "popov-vladimir1971@postgrespro.ru", "phone": "+70951354088"}
0005432693485	FE5D09	1618 527726	ALBERT EGOROV	{"phone": "+70441361271"}
0005432693486	62F1C9	2254 180973	LYUDMILA KRASNOVA	{"phone": "+70590391725"}
0005432693487	B90E60	3312 658067	NIKOLAY ROMANOV	{"email": "romanov_nikolay_29111978@postgrespro.ru", "phone": "+70387823171"}
0005432693488	B90E60	4743 297306	ALEKSEY ILIN	{"email": "aleksey.ilin_31121972@postgrespro.ru", "phone": "+70111959774"}
0005432693489	602ECC	7331 120584	ANNA KUZNECOVA	{"email": "kuznecova.anna_1988@postgrespro.ru", "phone": "+70789137008"}
0005432693490	602ECC	7003 747569	MAKSIM SOROKIN	{"email": "sorokinmaksim_051982@postgrespro.ru", "phone": "+70274615213"}
0005432693491	DC8C53	3054 742268	TATYANA GUSEVA	{"email": "guseva_t-121962@postgrespro.ru", "phone": "+70007298142"}
0005432693492	A19521	7611 191315	SERGEY NAUMOV	{"email": "sergey_naumov.1970@postgrespro.ru", "phone": "+70435462380"}
0005432693493	2423F7	0172 099131	EVGENIY GUSEV	{"email": "e_gusev-14061978@postgrespro.ru", "phone": "+70248356296"}
0005432693494	D47CDE	5556 050844	TAMARA EFREMOVA	{"email": "efremova_t-12111977@postgrespro.ru", "phone": "+70287070849"}
0005432693495	D0D1A3	3444 234160	SERGEY SOROKIN	{"email": "sorokin.sergey_011972@postgrespro.ru", "phone": "+70210908121"}
0005432693496	2C647D	0847 923093	ANNA KALININA	{"email": "annakalinina-071985@postgrespro.ru", "phone": "+70020705564"}
0005432693497	99F52F	6219 113799	ALEKSANDR TARASOV	{"phone": "+70923082414"}
0005432693498	99F52F	2590 465618	EKATERINA YAKOVLEVA	{"email": "yakovleva-ekaterina.011972@postgrespro.ru", "phone": "+70149894034"}
0005432693499	99F52F	3307 905219	SVETLANA GRISHINA	{"email": "svetlanagrishina011968@postgrespro.ru", "phone": "+70071417536"}
0005432693500	997E0A	9557 763020	SERGEY IVANOV	{"phone": "+70500323798"}
0005432693501	21C659	3645 482928	BOGDAN DENISOV	{"email": "denisov-b.1976@postgrespro.ru", "phone": "+70402456310"}
0005432693502	DB23D8	3967 221578	MARIYA POPOVA	{"email": "popova-mariya1962@postgrespro.ru", "phone": "+70233728695"}
0005432693503	894A18	0595 342860	VLADIMIR PAVLOV	{"phone": "+70971776452"}
0005432693504	BA98C3	8394 210365	NIKOLAY GAVRILOV	{"email": "gavrilovnikolay.091967@postgrespro.ru", "phone": "+70299653977"}
0005432693505	408FAB	3227 881871	GALINA DENISOVA	{"email": "galinadenisova-081963@postgrespro.ru", "phone": "+70061780435"}
0005432693506	408FAB	0180 085098	LEONID SCHERBAKOV	{"phone": "+70243849142"}
0005432693507	BB5DC1	5262 461658	GALINA ANDREEVA	{"email": "andreeva-galina_101970@postgrespro.ru", "phone": "+70177798114"}
0005432693508	BB5DC1	4339 285915	DARYA MASLOVA	{"email": "maslova_d_1984@postgrespro.ru", "phone": "+70286133615"}
0005432693509	DB121D	1351 207396	SERGEY KAZAKOV	{"phone": "+70680573729"}
0005432693510	DB121D	5726 813104	KRISTINA NIKITINA	{"phone": "+70468873664"}
0005432693511	5852E3	9168 536924	MATVEY TARASOV	{"phone": "+70445503204"}
0005432693512	3771CC	1614 265700	MIKHAIL RODIONOV	{"email": "mrodionov-031964@postgrespro.ru", "phone": "+70131286797"}
0005432693513	940CA2	1018 723040	SERGEY KUDRYASHOV	{"phone": "+70974953990"}
0005432693514	B7D1D4	9290 939687	ANASTASIYA KUZMINA	{"phone": "+70169374863"}
0005432693515	DE5989	1500 466359	ILYA FILIPPOV	{"email": "filippov_i18041973@postgrespro.ru", "phone": "+70848751224"}
0005432693516	C3722A	8162 788861	ELENA MIKHAYLOVA	{"email": "elenamikhaylova.25071981@postgrespro.ru", "phone": "+70673851772"}
0005432693517	841FB3	5580 449252	DMITRIY KUZMIN	{"email": "dmitriykuzmin-121974@postgrespro.ru", "phone": "+70294752222"}
0005432693518	841FB3	9141 824547	MATVEY ZHURAVLEV	{"email": "zhuravlev_m-07011970@postgrespro.ru", "phone": "+70038781571"}
0005432693519	ABA31C	4720 705184	NELLI KONDRATEVA	{"email": "nellikondrateva.25111966@postgrespro.ru", "phone": "+70765888054"}
0005432693520	5E7E27	9694 285907	VERA NAUMOVA	{"phone": "+70882170579"}
0005432693521	06D615	5237 591288	ROMAN SOKOLOV	{"phone": "+70564720456"}
0005432693522	06D615	6117 078613	SERGEY BARANOV	{"phone": "+70345709776"}
0005432693523	4B38EF	7762 254405	LYUDMILA MELNIKOVA	{"email": "lmelnikova-16081974@postgrespro.ru", "phone": "+70284385625"}
0005432693524	7D8E88	9286 607314	ELENA VASILEVA	{"email": "vasileva.elena-1975@postgrespro.ru", "phone": "+70669990840"}
0005432693525	7D8E88	1434 902162	SERGEY PETROV	{"email": "s.petrov-1971@postgrespro.ru", "phone": "+70176244383"}
0005432693526	50AB74	5820 883176	MARINA IVANOVA	{"phone": "+70022587217"}
0005432693527	767554	3853 826162	ANDREY KOZLOV	{"phone": "+70088580998"}
0005432693528	767554	6779 006585	ANASTASIYA PETROVA	{"phone": "+70813365541"}
0005432693529	16DEA6	0600 078964	SERGEY EGOROV	{"email": "sergey.egorov1979@postgrespro.ru", "phone": "+70498543040"}
0005432693530	F22583	1578 079416	ANTONINA TIMOFEEVA	{"email": "timofeeva_antonina-09091974@postgrespro.ru", "phone": "+70744954028"}
0005432693531	743C3D	5619 980197	ELIZAVETA DAVYDOVA	{"phone": "+70242346467"}
0005432693532	3F987D	0912 293150	MAKSIM MAKAROV	{"phone": "+70134037315"}
0005432693533	3F987D	2565 029012	EKATERINA YAKOVLEVA	{"phone": "+70127498776"}
0005432693534	D20521	8114 244719	RAISA CHERNOVA	{"phone": "+70684421770"}
0005432693535	D20521	1869 418557	RAISA KOZLOVA	{"phone": "+70323326396"}
0005432693536	D7A137	2550 848139	LYUDMILA TARASOVA	{"email": "ltarasova_1983@postgrespro.ru", "phone": "+70596983067"}
0005432693537	D7A137	0179 180227	ANNA SOROKINA	{"email": "anna-sorokina23081973@postgrespro.ru", "phone": "+70728998144"}
0005432693538	C38971	5681 324390	MIKHAIL VOLKOV	{"phone": "+70596915726"}
0005432693539	22B7AE	6780 776414	DANILA KOROLEV	{"email": "d_korolev1965@postgrespro.ru", "phone": "+70183868023"}
0005432693540	22B7AE	2771 810106	ALEKSEY MEDVEDEV	{"email": "medvedeva.18101968@postgrespro.ru", "phone": "+70916551618"}
0005432693541	22B7AE	7293 375402	OLEG KUZNECOV	{"email": "kuznecov-oleg-1988@postgrespro.ru", "phone": "+70260237608"}
0005432693542	02A128	4244 934076	ANNA ALEKSEEVA	{"email": "alekseeva_a.111974@postgrespro.ru", "phone": "+70847954893"}
0005432693543	45940B	1182 115734	KIRA AKIMOVA	{"email": "kakimova011978@postgrespro.ru", "phone": "+70382945425"}
0005432693544	357BA1	6760 500558	TATYANA MAKAROVA	{"phone": "+70078286404"}
0005432693545	7E49E9	6441 574446	OLGA MAKAROVA	{"email": "makarovaolga.22081974@postgrespro.ru", "phone": "+70149770934"}
0005432693546	7E49E9	1628 783031	ANNA NIKITINA	{"email": "nikitinaa.111978@postgrespro.ru", "phone": "+70958452631"}
0005432693547	09184E	6317 344154	TATYANA POPOVA	{"phone": "+70035570432"}
0005432693548	09184E	5683 143897	SERGEY SCHERBAKOV	{"phone": "+70463572513"}
0005432693549	6E3087	4888 623247	ALENA ALEKSEEVA	{"email": "alekseeva_alena.091979@postgrespro.ru", "phone": "+70855392035"}
0005432693550	6E3087	0247 062732	MARINA IVANOVA	{"email": "m_ivanova091970@postgrespro.ru", "phone": "+70523838738"}
0005432693551	D50B84	7556 073921	AZAT KISELEV	{"phone": "+70588779108"}
0005432693552	D50B84	5210 992177	SOFIYA MIKHAYLOVA	{"email": "mikhaylova_s.06051989@postgrespro.ru", "phone": "+70912614649"}
0005432693553	D50B84	3182 742637	OLGA SCHERBAKOVA	{"phone": "+70767597231"}
0005432693554	070084	8035 351356	PAVEL OSIPOV	{"phone": "+70157085822"}
0005432693555	FCCBB7	7773 590853	TATYANA ALEKSANDROVA	{"email": "t.aleksandrova-101979@postgrespro.ru", "phone": "+70614731983"}
0005432693556	0D8260	0078 694666	ILYA VOLKOV	{"email": "volkov_i02081971@postgrespro.ru", "phone": "+70298503761"}
0005432693557	8764F3	0273 543661	YULIYA NIKITINA	{"email": "nikitina_yuliya111969@postgrespro.ru", "phone": "+70723916694"}
0005432693558	8764F3	4898 155912	NIKOLAY KOZLOV	{"phone": "+70656581714"}
0005432693559	8764F3	3590 803339	LYUDMILA FEDOROVA	{"email": "fedorova_lyudmila-03031970@postgrespro.ru", "phone": "+70412217201"}
0005432693560	8764F3	1490 255576	DANIIL SOROKIN	{"email": "d_sorokin22111975@postgrespro.ru", "phone": "+70480686348"}
0005432693561	0357F4	2494 206057	LYUCIYA ERMAKOVA	{"phone": "+70844180750"}
0005432693562	6D8E09	9098 410177	LARISA MOISEEVA	{"email": "l.moiseeva_09041981@postgrespro.ru", "phone": "+70696651123"}
0005432693563	6D8E09	6734 831028	MIKHAIL SAVELEV	{"email": "msavelev.25031968@postgrespro.ru", "phone": "+70614334811"}
0005432693564	52F557	3439 108993	DANIIL SMIRNOV	{"email": "smirnov.d.1970@postgrespro.ru", "phone": "+70197980032"}
0005432693565	52F557	4010 314594	KRISTINA IVANOVA	{"phone": "+70647568701"}
0005432693566	3EA29E	4158 142957	SVETLANA IVANOVA	{"phone": "+70157782788"}
0005432693567	D4DEE3	5071 050837	ELENA SIDOROVA	{"email": "sidorova-elena-1971@postgrespro.ru", "phone": "+70979893439"}
0005432693568	D4DEE3	1402 713495	NINA IVANOVA	{"email": "n-ivanova-25091976@postgrespro.ru", "phone": "+70934359411"}
0005432693569	14F752	0983 392755	TATYANA YUDINA	{"email": "tyudina011967@postgrespro.ru", "phone": "+70154452839"}
0005432693570	C9D9B0	0940 763264	BORIS BORISOV	{"email": "borisov-b_26031969@postgrespro.ru", "phone": "+70620332465"}
0005432693571	C9D9B0	3332 132720	NATALYA KUZNECOVA	{"email": "kuznecova-natalya-1971@postgrespro.ru", "phone": "+70668944050"}
0005432693572	F5D066	0329 338798	EDUARD ABRAMOV	{"phone": "+70591666135"}
0005432693573	12A16E	1580 190284	TAISIYA ANTONOVA	{"email": "tantonova-081965@postgrespro.ru", "phone": "+70290273418"}
0005432693574	C50D55	5014 560419	KLAVDIYA PETROVA	{"email": "petrova_k-021970@postgrespro.ru", "phone": "+70393964646"}
0005432693575	C50D55	9376 614767	VLADIMIR POPOV	{"email": "vpopov01121964@postgrespro.ru", "phone": "+70450561378"}
0005432693576	3DC64A	7673 556721	NATALIYA KISELEVA	{"phone": "+70055490695"}
0005432693577	7761AA	7423 419277	ALEKSEY POPOV	{"email": "popov-a.17051980@postgrespro.ru", "phone": "+70459661657"}
0005432693578	64F058	8967 337488	TATYANA SERGEEVA	{"phone": "+70197903674"}
0005432693579	64F058	9375 265367	DMITRIY GRIGOREV	{"phone": "+70343865226"}
0005432693580	3E9D71	0287 397981	DARYA FEDOROVA	{"phone": "+70441388690"}
0005432693581	3E9D71	6286 990671	ANDREY VLASOV	{"phone": "+70959506333"}
0005432693582	6B46C5	0636 519618	GALINA GRISHINA	{"phone": "+70514657648"}
0005432693583	73CB61	5692 534346	DANIIL YAKOVLEV	{"email": "daniil-yakovlev-1975@postgrespro.ru", "phone": "+70505480841"}
0005432693584	68406D	2176 409917	ELENA IVANOVA	{"email": "elena-ivanova1980@postgrespro.ru", "phone": "+70161299457"}
0005432693585	D9848E	7894 620976	SERGEY VOROBEV	{"email": "s.vorobev021976@postgrespro.ru", "phone": "+70053251815"}
0005432693586	FFCA9B	1653 247845	EVGENIYA NIKIFOROVA	{"email": "evgeniya.nikiforova.24091972@postgrespro.ru", "phone": "+70033534318"}
0005432693587	2470BB	2211 232412	VALENTINA PETROVA	{"email": "petrovav-101970@postgrespro.ru", "phone": "+70447997724"}
0005432693588	532010	1652 176970	YURIY PAVLOV	{"phone": "+70014980694"}
0005432693589	532010	2977 639535	GALINA DANILOVA	{"phone": "+70437404854"}
0005432693590	CE95DB	2828 111441	ANASTASIYA GAVRILOVA	{"email": "anastasiya.gavrilova_25071970@postgrespro.ru", "phone": "+70704954453"}
0005432693591	33CD57	3771 627470	VLADIMIR GORBUNOV	{"phone": "+70257177748"}
0005432693592	570B55	7874 848889	ELENA BORISOVA	{"email": "borisova_elena.1971@postgrespro.ru", "phone": "+70560901102"}
0005432693593	570B55	7113 736046	ZUKHRA SOKOLOVA	{"phone": "+70226266897"}
0005432693594	9E9232	0978 959215	ALEKSEY ALEKSEEV	{"email": "a.alekseev_111969@postgrespro.ru", "phone": "+70863900473"}
0005432693595	D7930A	4851 349624	IRINA VOLKOVA	{"email": "volkovai-09061984@postgrespro.ru", "phone": "+70612846734"}
0005432693596	54A675	6571 214093	SERGEY MOROZOV	{"email": "morozov.s-1970@postgrespro.ru", "phone": "+70039345485"}
0005432693597	20CBD2	9110 884155	DANIIL SERGEEV	{"email": "sergeev.daniil22081970@postgrespro.ru", "phone": "+70185889151"}
0005432693598	5C696C	1115 670229	MIKHAIL POPOV	{"phone": "+70781109396"}
0005432693599	610646	5642 957892	VLADIMIR FEDOROV	{"phone": "+70050944651"}
0005432693600	147F7F	7439 785179	LEV FEDOTOV	{"email": "lfedotov-121971@postgrespro.ru", "phone": "+70852895833"}
0005432693601	884B4B	1314 155998	YULIYA OVCHINNIKOVA	{"phone": "+70339793259"}
0005432693602	884B4B	3143 823642	IGOR MATVEEV	{"email": "matveev-igor-18071969@postgrespro.ru", "phone": "+70034376730"}
0005432693603	F0A8A6	8666 108689	GALINA DMITRIEVA	{"phone": "+70008949303"}
0005432693604	E5B04D	8176 830205	ARINA SOKOLOVA	{"phone": "+70998211183"}
0005432693605	DA4865	7288 839020	ILDAR STEPANOV	{"email": "stepanovildar_31081966@postgrespro.ru", "phone": "+70378091690"}
0005432693606	DA4865	9182 008000	SERGEY VASILEV	{"email": "svasilev16041968@postgrespro.ru", "phone": "+70401214783"}
0005432693607	1DE941	2976 494699	EKATERINA MIRONOVA	{"phone": "+70768727737"}
0005432693608	1DE941	0085 367258	DANILA RODIONOV	{"email": "rodionovd12021973@postgrespro.ru", "phone": "+70406890774"}
0005432693609	284D2D	8267 543310	VLADIMIR TARASOV	{"phone": "+70425512477"}
0005432693610	284D2D	8731 195293	DMITRIY EGOROV	{"email": "dmitriyegorov_12071975@postgrespro.ru", "phone": "+70639875207"}
0005432693611	2459F7	5457 506859	EVGENIY PAVLOV	{"phone": "+70121305337"}
0005432693612	2459F7	2616 209163	ALENA MIKHAYLOVA	{"phone": "+70400736065"}
0005432693613	70E620	0482 480609	IGOR SCHERBAKOV	{"phone": "+70500820877"}
0005432693614	70E620	8792 763602	EKATERINA SMIRNOVA	{"email": "smirnova.e.091964@postgrespro.ru", "phone": "+70216247620"}
0005432693615	151A42	2250 698597	YULIYA LUKYANOVA	{"phone": "+70796247297"}
0005432693616	2DB47F	9129 846524	MARINA ROMANOVA	{"phone": "+70432231998"}
0005432693617	1987BF	6885 946150	ANNA EGOROVA	{"phone": "+70489730950"}
0005432693618	ED8276	0604 802932	NATALYA KRASNOVA	{"phone": "+70575744110"}
0005432693619	F428CD	3141 370967	ELIZAVETA DMITRIEVA	{"email": "dmitrieva.elizaveta-1981@postgrespro.ru", "phone": "+70640825204"}
0005432693620	13C181	3743 643259	VALENTINA SOROKINA	{"phone": "+70201947410"}
0005432693621	13C181	8723 211784	NIKOLAY MOROZOV	{"email": "nmorozov.15031972@postgrespro.ru", "phone": "+70740877028"}
0005432693622	DB8976	3815 196958	RUSHANIYA BOGDANOVA	{"phone": "+70005992958"}
0005432693623	B183A9	7194 394422	VIKTORIYA ZAKHAROVA	{"email": "viktoriyazakharova1971@postgrespro.ru", "phone": "+70182972861"}
0005432693624	F12A9D	6023 541250	ALEKSANDR NIKITIN	{"email": "a-nikitin-021973@postgrespro.ru", "phone": "+70941624258"}
0005432693625	B97D75	8208 148239	ALEKSEY ZAYCEV	{"email": "zaycev.a.1968@postgrespro.ru", "phone": "+70429183036"}
0005432693626	481FDC	1014 755978	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-24061969@postgrespro.ru", "phone": "+70159357360"}
0005432693627	4753F2	1651 982507	RUSTEM GAVRILOV	{"email": "gavrilovr_081988@postgrespro.ru", "phone": "+70164398977"}
0005432693628	4753F2	6984 814421	ANTON SEMENOV	{"phone": "+70713136324"}
0005432693629	3F79F8	6078 431930	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov1976@postgrespro.ru", "phone": "+70185872010"}
0005432693630	3F79F8	8765 126665	EVGENIY KOROLEV	{"phone": "+70813177177"}
0005432693631	B0581E	0096 357453	MAKSIM ZAKHAROV	{"phone": "+70779557154"}
0005432693632	B0581E	4038 293550	RAVIL VASILEV	{"email": "vasilevr101972@postgrespro.ru", "phone": "+70241137192"}
0005432693633	2E7E60	6752 903729	VLADIMIR ZAYCEV	{"email": "zaycev.v1957@postgrespro.ru", "phone": "+70089802841"}
0005432693634	2E7E60	1034 379319	NINA IVANOVA	{"email": "n_ivanova.1970@postgrespro.ru", "phone": "+70977167877"}
0005432693635	9C924C	6629 263048	ALEKSANDR KOROLEV	{"phone": "+70583386814"}
0005432693636	B565DE	4077 678704	LILIYA KRASNOVA	{"email": "l_krasnova_1967@postgrespro.ru", "phone": "+70961131970"}
0005432693637	894F8B	5404 650598	ELENA RYABOVA	{"phone": "+70969274054"}
0005432693638	21C272	7971 391351	LYUBOV ANTONOVA	{"phone": "+70895389225"}
0005432693639	24904F	7210 212082	DMITRIY TIMOFEEV	{"email": "timofeevd_111962@postgrespro.ru", "phone": "+70994242332"}
0005432693640	24904F	5849 917900	YAROSLAV TIKHONOV	{"email": "yaroslav.tikhonov_1978@postgrespro.ru", "phone": "+70657702585"}
0005432693641	6F919D	3179 559752	ANDREY RODIONOV	{"phone": "+70173146767"}
0005432693642	C9752B	6261 451097	MARFA MELNIKOVA	{"phone": "+70107316884"}
0005432693643	98B3DD	0086 327482	ANNA FILATOVA	{"email": "a-filatova081972@postgrespro.ru", "phone": "+70112088371"}
0005432693644	98B3DD	6431 890244	DANILA NIKITIN	{"email": "d-nikitin-1967@postgrespro.ru", "phone": "+70472923504"}
0005432693645	0D7599	9672 615567	SVETLANA ANDREEVA	{"email": "andreeva_svetlana_1963@postgrespro.ru", "phone": "+70608352883"}
0005432693646	82FB4F	3179 916316	OLEG FEDOTOV	{"phone": "+70278114267"}
0005432693647	E32839	1729 628049	NIKOLAY KUZNECOV	{"email": "kuznecov-n_31081962@postgrespro.ru", "phone": "+70140607679"}
0005432693648	CA7CDB	6940 554162	NIKITA MIRONOV	{"email": "mironov-nikita.1964@postgrespro.ru", "phone": "+70528652247"}
0005432693649	CA7CDB	6777 972860	LILIYA YUDINA	{"email": "l-yudina_1971@postgrespro.ru", "phone": "+70192943521"}
0005432693650	E8CFBA	4196 242969	LILIYA SIDOROVA	{"email": "sidoroval_1962@postgrespro.ru", "phone": "+70546528104"}
0005432693651	E8CFBA	2020 587822	ALEKSEY POPOV	{"email": "a-popov091978@postgrespro.ru", "phone": "+70918986404"}
0005432693652	6679EA	8659 590297	TAKHIR KISELEV	{"phone": "+70175529493"}
0005432693653	593948	4224 454923	VIKTOR VOLKOV	{"email": "volkov.viktor-19011964@postgrespro.ru", "phone": "+70543602984"}
0005432693654	79B831	4701 938657	DMITRIY MELNIKOV	{"email": "dmelnikov.10051971@postgrespro.ru", "phone": "+70722388315"}
0005432693655	1FA6F9	2235 171811	ELENA PAVLOVA	{"email": "pavlova_elena_091977@postgrespro.ru", "phone": "+70744562804"}
0005432693656	1FA6F9	5723 271065	VERA ABRAMOVA	{"email": "abramova.v-1966@postgrespro.ru", "phone": "+70800149587"}
0005432693657	0999B0	5865 406161	MARINA KAZAKOVA	{"email": "marina.kazakova031974@postgrespro.ru", "phone": "+70495632003"}
0005432693658	AB1779	0077 466032	ALEKSANDR FEDOTOV	{"phone": "+70178851642"}
0005432693659	A07CAC	6525 958458	TATYANA GRISHINA	{"email": "grishinat_091968@postgrespro.ru", "phone": "+70393592903"}
0005432693660	A07CAC	0321 428980	VIKTOR FEDOTOV	{"phone": "+70963934816"}
0005432693661	834266	4329 591031	ALEKSANDR ANTONOV	{"phone": "+70560092564"}
0005432693662	D8F92E	4256 025547	TAMARA KULIKOVA	{"phone": "+70067875660"}
0005432693663	118F09	5263 794646	EKATERINA DMITRIEVA	{"phone": "+70536195347"}
0005432693664	118F09	6935 952719	SERGEY ZAKHAROV	{"phone": "+70579195794"}
0005432693665	F159F8	3124 869921	VIKTOR GORBUNOV	{"phone": "+70689231153"}
0005432693666	D43FB1	4164 397094	VITALIY FEDOROV	{"phone": "+70477559679"}
0005432693667	4A9365	0619 673386	NATALYA LUKYANOVA	{"email": "n-lukyanova041964@postgrespro.ru", "phone": "+70973827882"}
0005432693668	C355DA	2319 431197	NATALIYA LUKYANOVA	{"email": "nataliya-lukyanova_27091970@postgrespro.ru", "phone": "+70579260309"}
0005432693669	F8F18A	2956 777381	VLADIMIR POPOV	{"phone": "+70717767953"}
0005432693670	BA84AD	3209 677227	EVGENIYA YUDINA	{"phone": "+70480375678"}
0005432693671	BA84AD	5903 189915	SVETLANA NIKITINA	{"email": "nikitina.svetlana1968@postgrespro.ru", "phone": "+70275509394"}
0005432693672	BA84AD	5735 990739	IVAN BARANOV	{"phone": "+70954722171"}
0005432693673	940ABB	5883 506352	EKATERINA MATVEEVA	{"phone": "+70951787256"}
0005432693674	940ABB	0858 325234	DMITRIY GAVRILOV	{"phone": "+70132609065"}
0005432693675	34F84C	1869 204440	ALEKSANDR VOLKOV	{"phone": "+70639323889"}
0005432693676	793AAE	7002 902219	IVAN SAVELEV	{"phone": "+70130089650"}
0005432693677	793AAE	5809 322628	NIKOLAY MIRONOV	{"phone": "+70033467769"}
0005432693678	BD5C8C	2044 181584	VIKTOR AFANASEV	{"phone": "+70724156569"}
0005432693679	BD5C8C	1713 742983	DMITRIY ABRAMOV	{"phone": "+70953369783"}
0005432693680	4D7D95	1674 587852	MIKHAIL ZAKHAROV	{"email": "mikhail-zakharov.071970@postgrespro.ru", "phone": "+70004823774"}
0005432693681	919D02	3507 893414	MARIYA KUZMINA	{"phone": "+70625291083"}
0005432693682	8B8850	2546 199825	ULYANA SEMENOVA	{"phone": "+70376955376"}
0005432693683	E47008	0060 078833	LYUDMILA GORBUNOVA	{"phone": "+70433844430"}
0005432693684	1317DF	2464 787025	VLADIMIR VOLKOV	{"phone": "+70434253194"}
0005432693685	47CDB5	2228 443872	TATYANA NAZAROVA	{"phone": "+70183382929"}
0005432693686	F6D438	1074 337146	GENNADIY VOLKOV	{"email": "volkov-gennadiy_07111982@postgrespro.ru", "phone": "+70336539943"}
0005432693687	DFC5B0	9788 578510	SERGEY SOROKIN	{"email": "sorokin.s-18041994@postgrespro.ru", "phone": "+70195629750"}
0005432693688	0A671A	5241 222993	VERA VASILEVA	{"phone": "+70116349492"}
0005432693689	A71827	5416 283524	ARINA KUZMINA	{"email": "kuzmina-arina-02061965@postgrespro.ru", "phone": "+70779492299"}
0005432693690	329308	2100 824468	PETR ORLOV	{"email": "petr-orlov07011982@postgrespro.ru", "phone": "+70180223612"}
0005432693691	D9F612	3399 584993	GALINA MASLOVA	{"phone": "+70441800340"}
0005432693692	D9F612	5001 284262	VALERIY EGOROV	{"phone": "+70398686738"}
0005432693693	8D7FF3	0948 393246	NATALYA ORLOVA	{"phone": "+70582377285"}
0005432693694	8D7FF3	1399 125676	ILDAR IVANOV	{"email": "ivanov.ildar.101968@postgrespro.ru", "phone": "+70784456703"}
0005432693695	6E8CC2	4927 031749	DMITRIY MARTYNOV	{"email": "d-martynov-1976@postgrespro.ru", "phone": "+70982314265"}
0005432693696	6E8CC2	3668 880455	VERA SOLOVEVA	{"phone": "+70844361430"}
0005432693697	6E8CC2	1500 223619	ELENA GRISHINA	{"phone": "+70999505915"}
0005432693698	C1F4F0	2597 519400	NATALYA BELOVA	{"email": "nbelova081966@postgrespro.ru", "phone": "+70128180158"}
0005432693699	C1F4F0	6121 228067	VLADIMIR ANTONOV	{"phone": "+70879443486"}
0005432693700	EADDA6	7036 504271	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov04091973@postgrespro.ru", "phone": "+70261054836"}
0005432693701	EADDA6	4922 494464	MARINA BOGDANOVA	{"email": "bogdanova-m031970@postgrespro.ru", "phone": "+70842183053"}
0005432693702	348854	3867 234399	ALEKSANDRA MAKAROVA	{"email": "aleksandra.makarova.1970@postgrespro.ru", "phone": "+70329629310"}
0005432693703	348854	2680 003907	ANDREY KAZAKOV	{"phone": "+70489247633"}
0005432693704	127D94	8461 557575	IRINA YAKOVLEVA	{"phone": "+70595492892"}
0005432693705	DBF017	3881 450072	MAKSIM ILIN	{"email": "ilin-maksim.1981@postgrespro.ru", "phone": "+70054428441"}
0005432693706	49BDA0	1655 878103	VLADIMIR KULIKOV	{"email": "vladimir.kulikov-1966@postgrespro.ru", "phone": "+70323463001"}
0005432693707	49BDA0	6797 911576	IRINA KARPOVA	{"phone": "+70890453550"}
0005432693708	49BDA0	7035 978247	ANDREY POPOV	{"phone": "+70256941739"}
0005432693709	49BDA0	8127 349600	ROMAN MATVEEV	{"email": "roman-matveev.15081973@postgrespro.ru", "phone": "+70114346115"}
0005432693710	3ABCC4	5747 237357	NATALYA BOGDANOVA	{"email": "natalya-bogdanova.071979@postgrespro.ru", "phone": "+70372916382"}
0005432693711	EF1F4D	8290 756354	SERGEY DMITRIEV	{"email": "dmitriev.sergey-1958@postgrespro.ru", "phone": "+70949982797"}
0005432693712	0F1B72	6652 018901	VALENTINA KONOVALOVA	{"phone": "+70441285056"}
0005432693713	CBF191	8871 090297	ARTUR SMIRNOV	{"phone": "+70321114719"}
0005432693714	CBF191	7343 677595	MIKHAIL MIRONOV	{"phone": "+70104688745"}
0005432693715	7E5DF6	2372 705933	GALINA KUZMINA	{"phone": "+70209817064"}
0005432693716	352865	5559 285061	ANASTASIYA ISAEVA	{"phone": "+70254091510"}
0005432693717	352865	9943 833436	OLEG ZAYCEV	{"phone": "+70094363242"}
0005432693718	3CC79F	9183 118812	ELENA KUZNECOVA	{"email": "elena.kuznecova.011976@postgrespro.ru", "phone": "+70881352754"}
0005432693719	830651	6389 769035	ALFIYA GAVRILOVA	{"email": "alfiyagavrilova_09121982@postgrespro.ru", "phone": "+70607867869"}
0005432693720	AF2354	3335 296930	ELENA KOLESNIKOVA	{"email": "elena-kolesnikova-1971@postgrespro.ru", "phone": "+70044220725"}
0005432693721	76FDFD	2024 776920	VLADIMIR ANTONOV	{"email": "antonov-v.30051967@postgrespro.ru", "phone": "+70133534750"}
0005432693722	B62EBD	0773 279595	ALEKSANDRA VOLKOVA	{"email": "aleksandra_volkova.12041971@postgrespro.ru", "phone": "+70795955628"}
0005432693723	9D0F8F	0962 970600	EKATERINA GAVRILOVA	{"email": "ekaterina-gavrilova041986@postgrespro.ru", "phone": "+70846818585"}
0005432693724	04E3B2	2486 882564	RAISA SERGEEVA	{"email": "raisa-sergeeva_05061962@postgrespro.ru", "phone": "+70809983456"}
0005432693725	DE73AC	5516 867657	NADIYA VASILEVA	{"phone": "+70778511920"}
0005432693726	E4AB77	0026 876487	VIKTOR NIKITIN	{"email": "nikitin_v021975@postgrespro.ru", "phone": "+70853383515"}
0005432693727	CEF834	2519 196426	MARIYA PAVLOVA	{"email": "pavlova-mariya-09011975@postgrespro.ru", "phone": "+70740860481"}
0005432693728	CEF834	4219 737535	IRINA ANDREEVA	{"phone": "+70052156406"}
0005432693729	C899C8	5195 229572	SERGEY KOZLOV	{"email": "kozlov_s.1969@postgrespro.ru", "phone": "+70147229090"}
0005432693730	C899C8	6110 200879	MAKSIM KUZNECOV	{"email": "mkuznecov_1973@postgrespro.ru", "phone": "+70435281943"}
0005432693731	BFC66D	5175 508371	ANATOLIY GORBUNOV	{"email": "anatoliy-gorbunov1974@postgrespro.ru", "phone": "+70539181123"}
0005432693732	BFC66D	9935 512862	VIKTOR MELNIKOV	{"phone": "+70909431737"}
0005432693733	314B2A	0624 526802	ALEKSANDR POPOV	{"phone": "+70715225369"}
0005432693734	314B2A	1736 791155	SERGEY SERGEEV	{"email": "s.sergeev-28011981@postgrespro.ru", "phone": "+70477041963"}
0005432693735	454B43	2713 990916	YULIYA POPOVA	{"email": "popova.yuliya-041974@postgrespro.ru", "phone": "+70229525426"}
0005432693736	454B43	1743 036616	ALINA OSIPOVA	{"email": "a.osipova.1971@postgrespro.ru", "phone": "+70866079483"}
0005432693737	949DDA	5988 724613	ARTEM STEPANOV	{"email": "a.stepanov-1959@postgrespro.ru", "phone": "+70454682585"}
0005432693738	6F0740	8627 412529	ALEKSEY KONOVALOV	{"phone": "+70235573144"}
0005432693739	A8C15C	5476 802712	VERA ISAEVA	{"phone": "+70284535710"}
0005432693740	A8C15C	8945 791479	NATALYA IVANOVA	{"email": "natalya.ivanova-23051968@postgrespro.ru", "phone": "+70622431952"}
0005432693741	699501	8568 141811	ALSU CHERNOVA	{"email": "alsuchernova_1971@postgrespro.ru", "phone": "+70862162571"}
0005432693742	699501	5910 987144	EVGENIY EGOROV	{"phone": "+70914313692"}
0005432693743	441412	9239 865803	IRINA NOVIKOVA	{"email": "novikovairina111963@postgrespro.ru", "phone": "+70381118085"}
0005432693744	74358C	8413 121838	ANTON BORISOV	{"phone": "+70447195207"}
0005432693745	1DF5D7	2034 499568	VITALIY FEDOTOV	{"email": "vfedotov26051975@postgrespro.ru", "phone": "+70170144938"}
0005432693746	16B293	2440 919042	LIDIYA ZAYCEVA	{"phone": "+70351719903"}
0005432693747	16B293	5277 998812	VALENTINA DAVYDOVA	{"phone": "+70313932983"}
0005432693748	1F5C38	5640 117576	VLADIMIR SMIRNOV	{"phone": "+70325809879"}
0005432693916	D9AFAB	4308 292355	IRINA FEDOROVA	{"phone": "+70935558115"}
0005432693749	1F5C38	5425 392944	VLADIMIR DAVYDOV	{"email": "v.davydov-1959@postgrespro.ru", "phone": "+70141560381"}
0005432693750	326814	7697 098492	ANGELINA KOMAROVA	{"email": "akomarova.1969@postgrespro.ru", "phone": "+70427146471"}
0005432693751	43017F	7825 009413	ANDREY TARASOV	{"phone": "+70931294153"}
0005432693752	2A9956	6678 840941	KSENIYA SOROKINA	{"email": "sorokinakseniya_03111978@postgrespro.ru", "phone": "+70834256658"}
0005432693753	5390CF	3781 269007	ANDREY EGOROV	{"phone": "+70873644589"}
0005432693754	5390CF	2812 133693	ANNA KUDRYASHOVA	{"email": "kudryashovaa1973@postgrespro.ru", "phone": "+70754543485"}
0005432693755	9912B9	9193 015879	OLGA SAVELEVA	{"email": "saveleva.olga_021971@postgrespro.ru", "phone": "+70374618404"}
0005432693756	B092C6	5652 635327	DANIYA POTAPOVA	{"phone": "+70357770555"}
0005432693757	B092C6	0301 320747	IRINA NESTEROVA	{"phone": "+70970960689"}
0005432693758	337C7D	0393 548752	ANNA KUZNECOVA	{"email": "a.kuznecova-11041981@postgrespro.ru", "phone": "+70389524481"}
0005432693759	7AF6B5	7805 315110	VALERIY SIDOROV	{"email": "sidorovv.041972@postgrespro.ru", "phone": "+70262459749"}
0005432693760	0A28A9	4777 682590	TATYANA ZAKHAROVA	{"email": "t_zakharova.22011967@postgrespro.ru", "phone": "+70916345485"}
0005432693761	9B71BE	7871 425122	ANATOLIY ZAKHAROV	{"phone": "+70133210548"}
0005432693762	6DBF38	6922 192873	DENIS PETROV	{"phone": "+70822703456"}
0005432693763	AD3498	5946 971384	RASIM EGOROV	{"phone": "+70192363009"}
0005432693764	D373FD	8362 440218	ALEKSANDR SIDOROV	{"phone": "+70651022923"}
0005432693765	D373FD	7360 146307	RODION MELNIKOV	{"email": "melnikov.r06091974@postgrespro.ru", "phone": "+70458420238"}
0005432693766	2C0064	6522 653267	SVETLANA NIKITINA	{"phone": "+70135236028"}
0005432693767	A428B5	6873 296394	PAVEL SMIRNOV	{"phone": "+70838465953"}
0005432693768	7CC4D6	8626 820646	LYUDMILA EFREMOVA	{"email": "l-efremova1973@postgrespro.ru", "phone": "+70127100797"}
0005432693769	EB74A2	2077 768444	VIKTOR VOLKOV	{"email": "vvolkov_101972@postgrespro.ru", "phone": "+70152737395"}
0005432693770	EB74A2	3679 800323	PETR BORISOV	{"phone": "+70932775854"}
0005432693771	75C5AF	5865 419637	VYACHESLAV KARPOV	{"email": "karpov_vyacheslav1970@postgrespro.ru", "phone": "+70702741058"}
0005432693772	C04B8D	6711 819875	SVETLANA YAKOVLEVA	{"phone": "+70166166987"}
0005432693773	EA23F6	4056 700435	ANZHELIKA MOISEEVA	{"phone": "+70068950941"}
0005432693774	8FE1F8	4488 088188	ELVIRA NIKOLAEVA	{"email": "elvira_nikolaeva_1970@postgrespro.ru", "phone": "+70899199854"}
0005432693775	4E37F2	1910 095846	LYUBOV TROFIMOVA	{"phone": "+70742955489"}
0005432693776	7EE414	2621 900534	NATALYA PAVLOVA	{"email": "n_pavlova-25021970@postgrespro.ru", "phone": "+70432749460"}
0005432693777	C9CDDA	0629 884526	VIKTOR SEMENOV	{"phone": "+70692623211"}
0005432693778	ECBF4A	3576 640670	NIKOLAY BARANOV	{"email": "n_baranov_1976@postgrespro.ru", "phone": "+70370751475"}
0005432693779	2F7F4C	2729 470448	DARYA SMIRNOVA	{"email": "dsmirnova061986@postgrespro.ru", "phone": "+70709391990"}
0005432693780	672C91	4307 632893	SERGEY EGOROV	{"phone": "+70652382480"}
0005432693781	672C91	4028 225637	ANASTASIYA TIMOFEEVA	{"phone": "+70476970624"}
0005432693782	BDF150	9272 342896	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr-1963@postgrespro.ru", "phone": "+70404918006"}
0005432693783	9E9DFA	1261 674733	MARINA KUZMINA	{"phone": "+70612163461"}
0005432693784	35F6CF	8727 598686	SVETLANA KONOVALOVA	{"email": "konovalova.s-101970@postgrespro.ru", "phone": "+70720248174"}
0005432693785	F757A9	6990 575454	OLGA KOROLEVA	{"email": "korolevao_061973@postgrespro.ru", "phone": "+70860677371"}
0005432693786	6696C5	2013 688669	SERGEY NIKITIN	{"phone": "+70687563979"}
0005432693904	7FD297	8253 998611	SVETLANA KAZAKOVA	{"phone": "+70905525742"}
0005432693787	6114CE	9123 970964	LYUDMILA KUZNECOVA	{"email": "kuznecova-l-20101977@postgrespro.ru", "phone": "+70668200343"}
0005432693788	74A1FC	3076 754973	NATALYA KRASNOVA	{"phone": "+70092966211"}
0005432693789	74A1FC	8651 273719	MARIYA GAVRILOVA	{"phone": "+70310965138"}
0005432693790	4FE473	4296 976310	MAKSIM BELOV	{"phone": "+70560983566"}
0005432693791	4FE473	9308 788934	VALENTINA NESTEROVA	{"email": "nesterova-v-1974@postgrespro.ru", "phone": "+70600570848"}
0005432693792	0BE81E	2804 924723	ALEKSANDRA AKIMOVA	{"phone": "+70189450414"}
0005432693793	0BE81E	5552 238244	ZINAIDA OSIPOVA	{"email": "z_osipova-1965@postgrespro.ru", "phone": "+70924846474"}
0005432693794	3227BA	3656 108332	MARINA DENISOVA	{"phone": "+70687322520"}
0005432693795	3227BA	7144 641393	VLADIMIR AFANASEV	{"email": "vafanasev-1975@postgrespro.ru", "phone": "+70244791700"}
0005432693796	3227BA	1699 650085	NIKOLAY VLASOV	{"phone": "+70289159935"}
0005432693797	603DE7	7411 915050	GRIGORIY NAZAROV	{"email": "nazarovgrigoriy-19091967@postgrespro.ru", "phone": "+70975405841"}
0005432693798	5AF024	5635 204060	VLADISLAV POPOV	{"phone": "+70078226069"}
0005432693799	5AF024	1694 543101	ALEKSEY BARANOV	{"phone": "+70097189282"}
0005432693800	682643	9224 563560	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov_23031968@postgrespro.ru", "phone": "+70767512651"}
0005432693801	400736	0328 792679	VLADISLAV BORISOV	{"email": "vladislav-borisov1969@postgrespro.ru", "phone": "+70036479325"}
0005432693802	13CDB7	7434 886607	IVAN IVANOV	{"email": "i.ivanov12071973@postgrespro.ru", "phone": "+70961757387"}
0005432693803	996783	0225 199794	ALEKSEY DAVYDOV	{"phone": "+70167158673"}
0005432693804	996783	6137 551153	EKATERINA ALEKSEEVA	{"email": "ekaterina-alekseeva_16021982@postgrespro.ru", "phone": "+70833002891"}
0005432693805	1B1F20	0592 633185	VERA PAVLOVA	{"email": "pavlovavera071982@postgrespro.ru", "phone": "+70120553865"}
0005432693806	E89510	6636 547846	LYUBOV KOROLEVA	{"phone": "+70931967071"}
0005432693807	E89510	7550 736795	DARYA ANTONOVA	{"email": "d-antonova1964@postgrespro.ru", "phone": "+70668813699"}
0005432693808	F391F2	4172 616589	NADEZHDA SIDOROVA	{"email": "sidorova.nadezhda_06071976@postgrespro.ru", "phone": "+70293877250"}
0005432693809	0086F0	9555 510571	TATYANA OVCHINNIKOVA	{"phone": "+70756241564"}
0005432693810	0086F0	8871 013032	LYUBOV KOZLOVA	{"phone": "+70713232186"}
0005432693811	96F889	4754 833701	OLGA POPOVA	{"email": "popova-o19041966@postgrespro.ru", "phone": "+70886425472"}
0005432693812	96F889	2110 696570	ELENA BELYAEVA	{"email": "belyaeva-elena_021968@postgrespro.ru", "phone": "+70470611742"}
0005432693813	39AD4C	3403 920178	IRINA TARASOVA	{"email": "irinatarasova.061974@postgrespro.ru", "phone": "+70831358074"}
0005432693814	39AD4C	6417 212788	NIKITA KUZNECOV	{"email": "nikita-kuznecov_1971@postgrespro.ru", "phone": "+70794212180"}
0005432693815	39AD4C	0153 907276	OLGA MAKAROVA	{"email": "olga.makarova.061975@postgrespro.ru", "phone": "+70566557862"}
0005432693816	C9C647	0103 194044	ALEKSANDR MIKHAYLOV	{"phone": "+70557321621"}
0005432693817	026928	9529 397429	ALEKSEY ANDREEV	{"email": "andreeva-24011969@postgrespro.ru", "phone": "+70333627622"}
0005432693818	28C31E	2131 391782	SERGEY ZAKHAROV	{"email": "zakharov.s-1974@postgrespro.ru", "phone": "+70780179244"}
0005432693819	58729C	2634 520412	EGOR MAKAROV	{"phone": "+70330750542"}
0005432693820	1400A7	5948 162777	BORIS KOZLOV	{"phone": "+70327483197"}
0005432693821	B5C1CB	9908 006967	ANDREY MATVEEV	{"phone": "+70862530806"}
0005432693822	B5C1CB	5924 542582	VIKTORIYA YAKOVLEVA	{"email": "yakovlevaviktoriya.011967@postgrespro.ru", "phone": "+70275398800"}
0005432693823	169334	1228 075845	VLADIMIR NIKOLAEV	{"phone": "+70154075253"}
0005432693824	169334	8040 268476	MAKSIM ZAYCEV	{"phone": "+70728643150"}
0005432693825	2BEF52	9502 796447	RUSLAN NIKOLAEV	{"email": "ruslan_nikolaev12121975@postgrespro.ru", "phone": "+70219868615"}
0005432693826	2BEF52	4660 783098	VLADIMIR KAZAKOV	{"email": "vladimir.kazakov.29111971@postgrespro.ru", "phone": "+70257283143"}
0005432693827	C15B17	3618 850499	OLGA MELNIKOVA	{"email": "melnikova-o31071972@postgrespro.ru", "phone": "+70248096073"}
0005432693828	B56882	5808 018906	EVGENIYA SEMENOVA	{"email": "semenova-e_061973@postgrespro.ru", "phone": "+70946544860"}
0005432693829	AD70E5	6505 635190	SERGEY VASILEV	{"email": "s_vasilev_1985@postgrespro.ru", "phone": "+70270860779"}
0005432693830	C64B19	1598 234686	MIKHAIL SHEVCHENKO	{"email": "mikhailshevchenko-1970@postgrespro.ru", "phone": "+70580289864"}
0005432693831	D6F63A	6636 584913	SOFYA POLYAKOVA	{"phone": "+70676298668"}
0005432693832	26EF28	8552 869243	OLGA ZHUKOVA	{"phone": "+70849837388"}
0005432693833	0967AF	0894 087872	OKSANA FILIPPOVA	{"email": "oksana_filippova.06111971@postgrespro.ru", "phone": "+70429176145"}
0005432693834	0967AF	9235 965416	ALEKSANDR KUZNECOV	{"email": "a_kuznecov031975@postgrespro.ru", "phone": "+70700450461"}
0005432693835	9CF695	7681 312044	MIKHAIL SMIRNOV	{"phone": "+70805354633"}
0005432693836	5A059E	2007 586105	FEDOR GAVRILOV	{"email": "gavrilov-fedor.1966@postgrespro.ru", "phone": "+70656378720"}
0005432693837	231E34	0966 826112	GALINA ZAKHAROVA	{"email": "zakharova.g.21061983@postgrespro.ru", "phone": "+70936098127"}
0005432693838	231E34	7871 103959	MARINA BARANOVA	{"email": "m-baranova_02041978@postgrespro.ru", "phone": "+70765399335"}
0005432693839	231E34	7625 707043	LYUDMILA KUZNECOVA	{"phone": "+70656670742"}
0005432693840	8688F6	8039 160620	OLEG KONOVALOV	{"email": "konovalov.oleg-1975@postgrespro.ru", "phone": "+70034393415"}
0005432693841	8688F6	2461 742486	SERGEY SMIRNOV	{"email": "sergeysmirnov_1972@postgrespro.ru", "phone": "+70808973403"}
0005432693842	5C2C64	5430 466847	NATALYA VOROBEVA	{"email": "vorobevanatalya_121986@postgrespro.ru", "phone": "+70686140384"}
0005432693843	5C2C64	6844 757233	VYACHESLAV KOZLOV	{"email": "vyacheslav.kozlov-071975@postgrespro.ru", "phone": "+70511102131"}
0005432693844	B8CE58	4667 299687	ANNA PAVLOVA	{"email": "pavlova-anna-061973@postgrespro.ru", "phone": "+70751981775"}
0005432693845	B8CE58	4116 662001	ELIZAVETA GERASIMOVA	{"email": "gerasimova-e.1969@postgrespro.ru", "phone": "+70976862084"}
0005432693846	3A18FC	5909 745834	ANNA GUSEVA	{"email": "a-guseva_111974@postgrespro.ru", "phone": "+70272725313"}
0005432693847	3A18FC	9074 039176	NATALYA DANILOVA	{"phone": "+70627652179"}
0005432693848	A2E124	8085 132334	NINA POPOVA	{"phone": "+70706065280"}
0005432693849	81FCF5	9888 305267	NATALYA GRISHINA	{"email": "n_grishina.11031979@postgrespro.ru", "phone": "+70960483533"}
0005432693850	81FCF5	6138 204947	ELENA MATVEEVA	{"email": "matveeva.elena-101982@postgrespro.ru", "phone": "+70882805403"}
0005432693851	B34F5A	3901 600796	OLGA FOMINA	{"email": "o.fomina25011976@postgrespro.ru", "phone": "+70618364574"}
0005432693852	DCE24C	2968 188542	KSENIYA SMIRNOVA	{"phone": "+70279233108"}
0005432693853	F3B4A5	2984 455323	ILYA KUZMIN	{"email": "kuzmin-ilya-111972@postgrespro.ru", "phone": "+70615362001"}
0005432693854	09420F	0599 113669	LYUDMILA MAKAROVA	{"phone": "+70356384657"}
0005432693855	FE8373	6269 786060	MARINA EFREMOVA	{"email": "mefremova.1970@postgrespro.ru", "phone": "+70240229299"}
0005432693856	9A36B3	2622 667134	IVAN KUZMIN	{"email": "kuzmini12091973@postgrespro.ru", "phone": "+70786306173"}
0005432693857	9A36B3	6025 602106	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana_051979@postgrespro.ru", "phone": "+70286037298"}
0005432693858	E95D6F	3513 896169	YULIYA NIKITINA	{"email": "nikitina_y-051972@postgrespro.ru", "phone": "+70906445828"}
0005432693859	E95D6F	3379 493452	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova.1971@postgrespro.ru", "phone": "+70898221106"}
0005432693860	06F9B2	1019 841475	ANATOLIY BELOV	{"email": "anatoliy_belov_1964@postgrespro.ru", "phone": "+70492955740"}
0005432693861	5B2E38	6563 538173	NATALYA EGOROVA	{"phone": "+70206618208"}
0005432693862	ED012C	8214 483753	SERGEY DENISOV	{"phone": "+70026766102"}
0005432693863	EACFF6	1937 535278	ELENA ANTONOVA	{"email": "eantonova.1965@postgrespro.ru", "phone": "+70246366066"}
0005432693864	EACFF6	3807 292585	MIKHAIL KAZAKOV	{"email": "kazakov-mikhail.06071974@postgrespro.ru", "phone": "+70618691119"}
0005432693865	C0C691	4608 134875	GALINA POPOVA	{"email": "popova-g.021975@postgrespro.ru", "phone": "+70038075395"}
0005432693866	659840	2658 416661	ALEKSANDR DMITRIEV	{"email": "admitriev-15111964@postgrespro.ru", "phone": "+70035416092"}
0005432693867	659840	3241 074092	MARINA MARTYNOVA	{"email": "martynova_marina-021976@postgrespro.ru", "phone": "+70308009199"}
0005432693868	88B5A3	1744 954372	SERGEY SEMENOV	{"phone": "+70121128129"}
0005432693869	88B5A3	1660 208325	ROMAN NAUMOV	{"email": "r_naumov-18031975@postgrespro.ru", "phone": "+70716014400"}
0005432693870	3C421C	2031 288532	OLGA DAVYDOVA	{"phone": "+70703115973"}
0005432693871	863FE1	7777 620128	MARINA SOROKINA	{"email": "marina.sorokina_1977@postgrespro.ru", "phone": "+70611739722"}
0005432693872	863FE1	2982 743100	ILYA DENISOV	{"email": "idenisov_1974@postgrespro.ru", "phone": "+70262478845"}
0005432693873	863FE1	5544 411034	ELLA KONOVALOVA	{"email": "e.konovalova.1961@postgrespro.ru", "phone": "+70636291867"}
0005432693874	0E13E0	5837 909256	TATYANA FOMINA	{"email": "t-fomina12041971@postgrespro.ru", "phone": "+70612593551"}
0005432693875	0E13E0	0904 262156	ELENA FILIPPOVA	{"email": "filippova.elena12111974@postgrespro.ru", "phone": "+70705314991"}
0005432693876	BF80A4	8089 307691	EMMA SIDOROVA	{"email": "sidorova_e-1972@postgrespro.ru", "phone": "+70726289432"}
0005432693877	C4AD35	0456 632088	IRINA YAKOVLEVA	{"email": "yakovleva_i111972@postgrespro.ru", "phone": "+70543796983"}
0005432693878	C4AD35	0090 749749	MIKHAIL MOROZOV	{"email": "morozov_mikhail1974@postgrespro.ru", "phone": "+70212577299"}
0005432693879	FDF157	9932 721583	RAISA EFREMOVA	{"phone": "+70748452355"}
0005432693880	84048A	4165 459615	PAVEL IVANOV	{"phone": "+70758615907"}
0005432693881	84048A	8225 781603	VLADIMIR ILIN	{"email": "vilin11031970@postgrespro.ru", "phone": "+70625727143"}
0005432693882	F735AC	0561 626383	ALEKSANDR IVANOV	{"phone": "+70846899991"}
0005432693883	0A8DDE	8581 639853	ALEKSANDR BONDARENKO	{"phone": "+70317266051"}
0005432693884	0A8DDE	3771 552054	NADEZHDA PAVLOVA	{"phone": "+70744261582"}
0005432693885	3F7204	6778 043322	GALINA RYABOVA	{"email": "gryabova-1972@postgrespro.ru", "phone": "+70076867504"}
0005432693886	31B98C	3219 998816	EGOR MAKAROV	{"email": "e.makarov_1982@postgrespro.ru", "phone": "+70865548115"}
0005432693887	BFC9DE	3403 231158	EVGENIY MAKSIMOV	{"phone": "+70522294522"}
0005432693888	BFC9DE	7721 278035	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana.031964@postgrespro.ru", "phone": "+70414960953"}
0005432693889	2AEE68	8213 379845	YULIYA SOKOLOVA	{"email": "sokolova.yuliya18101970@postgrespro.ru", "phone": "+70548923069"}
0005432693890	927321	1610 934044	ANTON BORISOV	{"phone": "+70165825576"}
0005432693891	B1E78B	3518 586513	ELENA SOROKINA	{"phone": "+70249713084"}
0005432693892	772CDE	4128 373057	NATALYA TARASOVA	{"phone": "+70698902811"}
0005432693893	6B2276	0850 848122	VARVARA ANTONOVA	{"phone": "+70682199792"}
0005432693894	BBA97B	2362 574155	NELLYA MIKHAYLOVA	{"email": "n_mikhaylova1962@postgrespro.ru", "phone": "+70213583249"}
0005432693895	C5C189	8965 743484	IGOR VASILEV	{"phone": "+70243421605"}
0005432693896	C5C189	6935 050386	ROMAN CHERNOV	{"phone": "+70698302234"}
0005432693897	7EDCD6	4107 611063	YANA MAKSIMOVA	{"email": "yana-maksimova_08041973@postgrespro.ru", "phone": "+70316270786"}
0005432693898	1C0DFA	2229 418718	MARINA IVANOVA	{"phone": "+70731168596"}
0005432693899	1C0DFA	5203 629485	ANASTASIYA GRISHINA	{"phone": "+70196669511"}
0005432693900	0D48C9	1747 353053	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov_121965@postgrespro.ru", "phone": "+70006918817"}
0005432693901	0D48C9	5844 239512	ALEKSANDR FOMIN	{"email": "aleksandr_fomin19021966@postgrespro.ru", "phone": "+70070903626"}
0005432693902	5F8779	0206 367673	ANASTASIYA ABRAMOVA	{"email": "aabramova.071976@postgrespro.ru", "phone": "+70194245864"}
0005432693903	0F8DFE	4940 150467	MARGARITA KULIKOVA	{"phone": "+70561880774"}
0005432693905	FB39E4	1767 105111	VLADISLAV OSIPOV	{"email": "osipov.vladislav.1976@postgrespro.ru", "phone": "+70207657496"}
0005432693906	FB39E4	9861 022064	GALINA ORLOVA	{"email": "orlova.g23041983@postgrespro.ru", "phone": "+70608207713"}
0005432693907	0F44FE	8418 754524	NINA OVCHINNIKOVA	{"phone": "+70576814393"}
0005432693908	0F44FE	9087 526656	NATALYA GUSEVA	{"phone": "+70329731748"}
0005432693909	542ED3	0003 882482	EVGENIYA TIMOFEEVA	{"phone": "+70157274155"}
0005432693910	CBC0AB	5105 746479	ANTONINA SMIRNOVA	{"phone": "+70950580778"}
0005432693911	37223E	8698 154998	VASILIY TIKHONOV	{"phone": "+70541848762"}
0005432693912	37223E	1560 421204	VYACHESLAV MEDVEDEV	{"email": "medvedev_vyacheslav26011980@postgrespro.ru", "phone": "+70625398931"}
0005432693913	0399AA	7596 768244	VALENTINA DAVYDOVA	{"phone": "+70423374208"}
0005432693914	E589A1	2116 946739	DMITRIY POPOV	{"phone": "+70793610106"}
0005432693915	4D99F6	2817 128185	ZOYA AFANASEVA	{"email": "afanaseva-zoya-031983@postgrespro.ru", "phone": "+70527618398"}
0005432693917	C0F402	7784 278032	YURIY SMIRNOV	{"phone": "+70959174317"}
0005432693918	DC145A	9849 555972	ALEKSEY NIKITIN	{"email": "a_nikitin-011977@postgrespro.ru", "phone": "+70183011544"}
0005432693919	625E20	0577 361746	VALENTINA KOZLOVA	{"phone": "+70841084077"}
0005432693920	E206F0	1500 523965	VIKTOR MIKHAYLOV	{"email": "mikhaylov-v_1977@postgrespro.ru", "phone": "+70950525916"}
0005432693921	B34A10	0430 731203	YULIYA SIDOROVA	{"email": "sidorovay.091969@postgrespro.ru", "phone": "+70656859291"}
0005432693922	371395	1837 988175	GALINA KOVALEVA	{"phone": "+70835711415"}
0005432693923	664CB7	1167 022909	ALEVTINA FROLOVA	{"phone": "+70472047083"}
0005432693924	E02F3A	7779 101487	GENNADIY PETROV	{"phone": "+70167445477"}
0005432693925	5079D8	1757 144862	ANNA MARTYNOVA	{"email": "martynova.anna-051973@postgrespro.ru", "phone": "+70047116024"}
0005432693926	D4DE18	9587 674027	ANNA MAKAROVA	{"email": "amakarova.1972@postgrespro.ru", "phone": "+70083127656"}
0005432693927	197A5D	2658 653909	GALINA SIDOROVA	{"email": "sidorovag12081974@postgrespro.ru", "phone": "+70476635636"}
0005432693928	F2702E	7518 332940	VALENTINA EFIMOVA	{"email": "efimova_v.1978@postgrespro.ru", "phone": "+70806911014"}
0005432693929	5B63A4	9557 830658	VALENTINA GERASIMOVA	{"email": "valentina-gerasimova_061976@postgrespro.ru", "phone": "+70020191477"}
0005432693930	5B63A4	7601 186910	TATYANA MALYSHEVA	{"email": "malysheva-tatyana-20121966@postgrespro.ru", "phone": "+70437924149"}
0005432693931	2056F2	4469 392643	OLGA GORBUNOVA	{"email": "o-gorbunova_1982@postgrespro.ru", "phone": "+70438607827"}
0005432693932	BDB26B	2016 582843	ALEKSANDR OSIPOV	{"email": "osipov-aleksandr_111978@postgrespro.ru", "phone": "+70824330493"}
0005432693933	AB69B4	2411 910916	OLGA KONOVALOVA	{"phone": "+70462820296"}
0005432693934	512707	6304 765107	GENNADIY KISELEV	{"phone": "+70018525173"}
0005432693935	C23C5F	6302 417996	ELENA CHERNOVA	{"email": "chernovaelena23101970@postgrespro.ru", "phone": "+70053020384"}
0005432693936	C23C5F	4199 790582	VADIM OSIPOV	{"email": "osipov-vadim.1974@postgrespro.ru", "phone": "+70933409244"}
0005432693937	F632FA	9690 618922	ALEKSANDR MATVEEV	{"email": "a.matveev041973@postgrespro.ru", "phone": "+70791386078"}
0005432693938	BE1BE4	9897 322682	TATYANA ARKHIPOVA	{"phone": "+70077387050"}
0005432693939	E73F15	2169 972089	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov.1966@postgrespro.ru", "phone": "+70100903658"}
0005432693940	645B59	1141 274973	LYUDMILA ROMANOVA	{"phone": "+70213226059"}
0005432693941	46C901	8112 391457	ELIZAVETA STEPANOVA	{"email": "e-stepanova.1976@postgrespro.ru", "phone": "+70709868418"}
0005432693942	EB0FBD	4327 734666	LYUBOV KONOVALOVA	{"phone": "+70605243540"}
0005432693943	4E85E2	5851 238649	IRINA KAZAKOVA	{"phone": "+70577044059"}
0005432693944	767193	0775 760347	VIKTOR BELOV	{"email": "belov_viktor_29061973@postgrespro.ru", "phone": "+70295322394"}
0005432693945	442803	2608 503268	MARIYA KONDRATEVA	{"phone": "+70279700340"}
0005432693946	F9A767	3624 570616	ALEKSANDRA MATVEEVA	{"email": "matveeva_a_18041968@postgrespro.ru", "phone": "+70768341053"}
0005432693947	8F1E5D	3567 534053	VIKTOR BELOV	{"email": "v-belov.041981@postgrespro.ru", "phone": "+70200266236"}
0005432693948	8F1E5D	4146 064236	MARIYA ZAYCEVA	{"email": "mzayceva-19091973@postgrespro.ru", "phone": "+70703422728"}
0005432693949	365919	6875 577256	KAMIL BORISOV	{"email": "k_borisov061978@postgrespro.ru", "phone": "+70222282766"}
0005432693950	365919	0178 912654	PAVEL SMIRNOV	{"email": "p.smirnov-1973@postgrespro.ru", "phone": "+70499803680"}
0005432693951	5234D7	2664 131193	MARGARITA ROMANOVA	{"email": "romanova_m.08071970@postgrespro.ru", "phone": "+70367952333"}
0005432693952	433713	1516 898539	VLADIMIR VOROBEV	{"email": "vorobev_vladimir_061975@postgrespro.ru", "phone": "+70857562541"}
0005432693953	433713	4667 953316	NIKOLAY SMIRNOV	{"phone": "+70680262493"}
0005432693954	573459	7419 331413	VIKTOR KUDRYASHOV	{"email": "viktor-kudryashov-111966@postgrespro.ru", "phone": "+70455845906"}
0005432693955	1F690E	2533 384936	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.n011976@postgrespro.ru", "phone": "+70523294362"}
0005432693956	1F690E	0626 352440	OLGA POTAPOVA	{"email": "o.potapova031974@postgrespro.ru", "phone": "+70446042768"}
0005432693957	DF9C22	1726 677800	ALENA ZAKHAROVA	{"phone": "+70426743392"}
0005432693958	DF9C22	8792 660588	ELENA KRASNOVA	{"phone": "+70050160387"}
0005432693959	F04E4E	6661 048536	ZLATA VASILEVA	{"email": "vasileva.zlata_1974@postgrespro.ru", "phone": "+70972481931"}
0005432693960	F04E4E	5303 765990	GALINA FILIPPOVA	{"email": "g-filippova_071971@postgrespro.ru", "phone": "+70545597931"}
0005432693961	2E7370	3473 456441	VLADIMIR RODIONOV	{"email": "rodionov_v-08051964@postgrespro.ru", "phone": "+70797489532"}
0005432693962	2E7370	1555 321076	NATALYA GUSEVA	{"email": "natalya-guseva.121972@postgrespro.ru", "phone": "+70853041746"}
0005432693963	D9B1FC	5835 894277	ELENA MIKHAYLOVA	{"email": "mikhaylovaelena1957@postgrespro.ru", "phone": "+70616815657"}
0005432693964	F07CF1	6850 329952	MAKSIM MIRONOV	{"phone": "+70055113677"}
0005432693965	306BD9	9304 485545	SERGEY FROLOV	{"phone": "+70329864713"}
0005432693966	9ED117	6611 047368	PETR IVANOV	{"phone": "+70927022040"}
0005432693967	9ED117	8808 472975	ANASTASIYA KISELEVA	{"email": "kiselevaanastasiya1980@postgrespro.ru", "phone": "+70784578293"}
0005432693968	5ECA84	2330 221374	VLADIMIR ZHURAVLEV	{"phone": "+70663723055"}
0005432693969	5ECA84	2053 567235	ELENA MARTYNOVA	{"phone": "+70145362344"}
0005432693970	916D1E	7890 413534	NINA EGOROVA	{"phone": "+70188256982"}
0005432693971	A4053E	4602 149483	ANATOLIY BARANOV	{"phone": "+70910692789"}
0005432693972	33947E	9242 745924	GALINA KOROLEVA	{"phone": "+70818319206"}
0005432693973	33947E	7318 833749	VALENTIN KULIKOV	{"email": "kulikov_valentin09101971@postgrespro.ru", "phone": "+70688966814"}
0005432706416	EE5D99	6324 412127	VLADIMIR FOMIN	{"phone": "+70802385272"}
0005432706473	A50C04	5150 138974	TATYANA PETROVA	{"phone": "+70219673438"}
0005432706343	B932E1	7729 483497	VALENTIN ZAKHAROV	{"phone": "+70205136741"}
0005432706307	BE9C9A	7608 545379	MIKHAIL KRASNOV	{"phone": "+70617019262"}
0005432706308	FA0128	7325 407303	EVGENIYA FILATOVA	{"email": "filatova-evgeniya_051968@postgrespro.ru", "phone": "+70439816478"}
0005432706309	418343	1654 633607	MARIYA IVANOVA	{"phone": "+70051583676"}
0005432706310	B4F6E4	1583 090318	OKSANA SEMENOVA	{"email": "oksanasemenova121977@postgrespro.ru", "phone": "+70054656082"}
0005432706311	EEF9A4	1627 654878	MAKSIM FILIPPOV	{"email": "filippov-maksim-14051974@postgrespro.ru", "phone": "+70290473030"}
0005432706312	EEF9A4	4838 557706	ALEKSEY MARTYNOV	{"email": "aleksey_martynov.05011979@postgrespro.ru", "phone": "+70397704306"}
0005432706313	E8BCFC	0698 650678	ANATOLIY ANTONOV	{"email": "antonovanatoliy1976@postgrespro.ru", "phone": "+70995657623"}
0005432706314	16AEDC	6892 217359	SERGEY VLASOV	{"phone": "+70352963701"}
0005432706315	16AEDC	0348 755834	YULIYA POPOVA	{"email": "y-popova.031979@postgrespro.ru", "phone": "+70804584350"}
0005432706316	16AEDC	1672 324334	KONSTANTIN DENISOV	{"email": "denisovk-1978@postgrespro.ru", "phone": "+70739405845"}
0005432706317	8CD195	3652 454217	ALEKSEY POPOV	{"email": "popov-a-1966@postgrespro.ru", "phone": "+70415016501"}
0005432706318	3E1488	8743 329496	PAVEL KUZNECOV	{"email": "p_kuznecov1961@postgrespro.ru", "phone": "+70160222197"}
0005432706319	3E1488	3614 407231	NADEZHDA PAVLOVA	{"email": "n-pavlova_1961@postgrespro.ru", "phone": "+70048458431"}
0005432706320	C5ADB2	3553 883560	LYUBOV ABRAMOVA	{"email": "abramova.l.031977@postgrespro.ru", "phone": "+70005173988"}
0005432706321	AD5CB8	9274 571530	LARISA EFIMOVA	{"phone": "+70212686790"}
0005432706322	AD5CB8	8706 673058	NADEZHDA NIKOLAEVA	{"email": "n_nikolaeva19031969@postgrespro.ru", "phone": "+70590594263"}
0005432706323	9EAE1E	6455 615321	DARYA IVANOVA	{"email": "ivanova-d_06041975@postgrespro.ru", "phone": "+70263456205"}
0005432706324	893BD9	3731 279734	SERGEY KULIKOV	{"email": "s.kulikov-02091970@postgrespro.ru", "phone": "+70404244502"}
0005432706325	893BD9	0981 939654	NADEZHDA SMIRNOVA	{"email": "n-smirnova_1963@postgrespro.ru", "phone": "+70296873912"}
0005432706326	2A9F0D	2796 890586	OLESYA PAVLOVA	{"email": "pavlova-olesya-1979@postgrespro.ru", "phone": "+70515215553"}
0005432706327	9AB1E8	6122 747155	DMITRIY KUZNECOV	{"phone": "+70649252463"}
0005432706328	382CE9	6807 812784	SERGEY SERGEEV	{"phone": "+70950568693"}
0005432706329	ACD808	6265 541148	DZHAMILYA DMITRIEVA	{"email": "dmitrieva.dzhamilya.1973@postgrespro.ru", "phone": "+70142884264"}
0005432706330	ACD808	6242 180577	NAIL ROMANOV	{"phone": "+70255689801"}
0005432706331	B42A68	0433 518204	ELENA KUZNECOVA	{"email": "elena.kuznecova041966@postgrespro.ru", "phone": "+70050755334"}
0005432706332	B42A68	9884 560575	VITALIY ILIN	{"email": "vitaliyilin-1960@postgrespro.ru", "phone": "+70724029047"}
0005432706333	3675DC	3349 125066	ELENA ALEKSANDROVA	{"email": "aleksandrovae-1968@postgrespro.ru", "phone": "+70089637563"}
0005432706334	3675DC	3986 356814	TATYANA IVANOVA	{"email": "tatyana.ivanova061968@postgrespro.ru", "phone": "+70367127976"}
0005432706335	9003F4	0535 778693	ZOYA KAZAKOVA	{"phone": "+70635149329"}
0005432706336	4C9E10	8233 456155	ELENA POTAPOVA	{"phone": "+70052454808"}
0005432706337	1F1A56	4220 155132	ROMAN SHEVCHENKO	{"email": "r.shevchenko.13061967@postgrespro.ru", "phone": "+70642600786"}
0005432706338	258C39	3037 895091	VITALIY MATVEEV	{"email": "vitaliy-matveev1976@postgrespro.ru", "phone": "+70830592081"}
0005432706339	3A6A45	7765 268600	IGOR SIDOROV	{"email": "igor_sidorov.1968@postgrespro.ru", "phone": "+70849615218"}
0005432706340	3A6A45	4664 528730	MARIYA TIKHONOVA	{"email": "m.tikhonova_1960@postgrespro.ru", "phone": "+70224293550"}
0005432706341	43DA65	6429 808065	ANATOLIY SMIRNOV	{"phone": "+70032360498"}
0005432706342	B932E1	2370 076237	NATALYA MASLOVA	{"phone": "+70038565941"}
0005432706344	FFC7F9	3082 299532	PETR SOROKIN	{"email": "sorokin_petr.111976@postgrespro.ru", "phone": "+70797914321"}
0005432706345	6BF1D8	4118 922346	NIKOLAY MAKSIMOV	{"email": "nikolay_maksimov-1972@postgrespro.ru", "phone": "+70095395329"}
0005432706346	093472	4307 925976	TATYANA MIKHAYLOVA	{"phone": "+70617525036"}
0005432706347	3B7396	1925 664832	MIKHAIL ALEKSEEV	{"phone": "+70362424788"}
0005432706348	D9AA00	0261 601496	EKATERINA TROFIMOVA	{"email": "trofimova-ekaterina1965@postgrespro.ru", "phone": "+70957075026"}
0005432706349	D9AA00	8988 257626	OLGA CHERNOVA	{"email": "o-chernova_1967@postgrespro.ru", "phone": "+70556049798"}
0005432706350	D9AA00	5439 391354	ELENA ZAKHAROVA	{"email": "zakharova.e_1966@postgrespro.ru", "phone": "+70368433796"}
0005432706351	ACD254	0039 119069	VLADIMIR DMITRIEV	{"email": "dmitriev.vladimir-1972@postgrespro.ru", "phone": "+70223141898"}
0005432706352	D2D96A	7271 917955	SERGEY PETROV	{"email": "petrov-sergey_021974@postgrespro.ru", "phone": "+70372077664"}
0005432706353	D13553	9147 215823	GENNADIY NIKITIN	{"email": "g_nikitin-1990@postgrespro.ru", "phone": "+70214436751"}
0005432706354	37D865	2096 239037	SERGEY KUDRYASHOV	{"phone": "+70512065055"}
0005432706355	37D865	5838 787771	IGOR NIKOLAEV	{"phone": "+70978881409"}
0005432706356	78A9B6	5284 424931	YURIY GRIGOREV	{"email": "grigorev_y_1980@postgrespro.ru", "phone": "+70261269582"}
0005432706357	9BD14A	3594 649566	ELENA VOROBEVA	{"email": "elena-vorobeva_111968@postgrespro.ru", "phone": "+70766641437"}
0005432706358	45AD84	9808 196527	VALERIYA PAVLOVA	{"email": "pavlova.valeriya1977@postgrespro.ru", "phone": "+70663828080"}
0005432706359	45AD84	0906 560928	IGOR YAKOVLEV	{"email": "iyakovlev021980@postgrespro.ru", "phone": "+70200776795"}
0005432706360	A9429F	8025 052157	OKSANA KAZAKOVA	{"email": "kazakovao021966@postgrespro.ru", "phone": "+70079072402"}
0005432706361	DDB495	1097 817755	MARIYA KALININA	{"phone": "+70728045395"}
0005432706362	45AA40	2297 146078	MARINA POPOVA	{"phone": "+70921301856"}
0005432706363	45AA40	0577 041653	NINA ZHUKOVA	{"phone": "+70380621647"}
0005432706364	32ABA8	6946 600971	IRINA VASILEVA	{"email": "i_vasileva.09111973@postgrespro.ru", "phone": "+70237645925"}
0005432706365	5DA7B8	1093 236293	IVAN BORISOV	{"phone": "+70967031771"}
0005432706366	E6878B	3560 169782	TATYANA BORISOVA	{"email": "borisova_t1973@postgrespro.ru", "phone": "+70293840570"}
0005432706367	804BD8	1329 159127	EKATERINA BORISOVA	{"phone": "+70502479016"}
0005432706368	804BD8	5184 888101	ELENA MAKSIMOVA	{"email": "elena_maksimova.011964@postgrespro.ru", "phone": "+70740449260"}
0005432706369	5BC514	6158 774343	ELENA POLYAKOVA	{"phone": "+70064243628"}
0005432706370	416537	3120 162450	NIKOLAY EGOROV	{"email": "egorov_nikolay.1984@postgrespro.ru", "phone": "+70277080425"}
0005432706371	416537	2905 264405	IGOR AFANASEV	{"email": "afanasev.i_021987@postgrespro.ru", "phone": "+70844292661"}
0005432706372	2CD169	9909 970784	VASILIY MAKSIMOV	{"email": "maksimov.v12051961@postgrespro.ru", "phone": "+70883743259"}
0005432706373	AF5A2F	4443 100313	IRINA FROLOVA	{"email": "frolova-i09021969@postgrespro.ru", "phone": "+70476530504"}
0005432706374	AF5A2F	5546 077779	NIKITA ROMANOV	{"email": "n-romanov1971@postgrespro.ru", "phone": "+70892015658"}
0005432706375	946A8C	6136 794907	NIKOLAY SIDOROV	{"phone": "+70620997869"}
0005432706376	DEE736	8200 081398	EVGENIY KUZNECOV	{"phone": "+70871194749"}
0005432706377	DEE736	8727 367126	VALERIY FEDOTOV	{"phone": "+70065467649"}
0005432706378	30F9F7	7596 151613	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova-121962@postgrespro.ru", "phone": "+70220422247"}
0005432706379	660713	3287 825079	IGOR SHEVCHENKO	{"email": "igor-shevchenko_1979@postgrespro.ru", "phone": "+70312129133"}
0005432706380	AA78D0	6131 316637	VLADIMIR SERGEEV	{"email": "sergeev.vladimir_1969@postgrespro.ru", "phone": "+70559672963"}
0005432706381	AA78D0	3899 554188	ALEKSANDRA NESTEROVA	{"email": "nesterova.aleksandra_1971@postgrespro.ru", "phone": "+70225767592"}
0005432706382	E99D6F	4311 462160	ALINA DMITRIEVA	{"phone": "+70846899389"}
0005432706383	D75300	4833 934037	NIKOLAY FEDOROV	{"phone": "+70852769682"}
0005432706384	F1A754	6222 806301	ALISA KUZMINA	{"phone": "+70510298285"}
0005432706385	F1A754	1697 765838	LEV CHERNOV	{"phone": "+70338852294"}
0005432706386	5CCE30	2463 706597	FILIPP IVANOV	{"phone": "+70228686282"}
0005432706387	642388	4472 297981	ALEKSANDR ANTONOV	{"phone": "+70674219093"}
0005432706388	1AE6CD	9774 224630	YURIY ORLOV	{"phone": "+70057980920"}
0005432706389	700F0E	2841 095677	ALEKSANDR ANTONOV	{"phone": "+70841499601"}
0005432706390	99B34B	0225 435495	NIKOLAY VOLKOV	{"phone": "+70200882471"}
0005432706391	21D78A	2901 506415	ELIZAVETA ARKHIPOVA	{"phone": "+70941482621"}
0005432706392	21D78A	3312 406311	MARGARITA ZHURAVLEVA	{"email": "m-zhuravleva-011971@postgrespro.ru", "phone": "+70543906434"}
0005432706393	6C5136	6521 184465	ALEKSANDRA MIKHAYLOVA	{"phone": "+70043521264"}
0005432706394	D96E8C	0196 544097	ISLAM FROLOV	{"phone": "+70146987952"}
0005432706395	41752F	1300 199682	MARIYA ANTONOVA	{"email": "antonova_m_1980@postgrespro.ru", "phone": "+70677998684"}
0005432706396	4ACD86	1115 270391	VERA IVANOVA	{"email": "ivanova.v.04091967@postgrespro.ru", "phone": "+70590159347"}
0005432706397	7EC827	5968 204779	EVGENIY DMITRIEV	{"email": "dmitrieve.29121968@postgrespro.ru", "phone": "+70406828578"}
0005432706398	687213	4850 132025	ELIZAVETA MOROZOVA	{"phone": "+70711935546"}
0005432706399	687213	6962 564754	ALEKSANDRA LUKYANOVA	{"phone": "+70168756831"}
0005432706400	8F1739	9805 551692	NINA MOISEEVA	{"phone": "+70693067615"}
0005432706401	8F1739	1246 985104	IGOR IVANOV	{"phone": "+70068044547"}
0005432706402	3504D3	4343 322864	ILYA SCHERBAKOV	{"phone": "+70164809667"}
0005432706403	12297F	7340 616098	GENNADIY MEDVEDEV	{"email": "gmedvedev04101973@postgrespro.ru", "phone": "+70349209864"}
0005432706404	28587D	0373 915503	LIDIYA VASILEVA	{"email": "l_vasileva07081979@postgrespro.ru", "phone": "+70433628959"}
0005432706405	A24832	3615 479586	TIMUR NIKOLAEV	{"email": "nikolaev_t-1964@postgrespro.ru", "phone": "+70687872127"}
0005432706406	A24832	1960 120224	MAKSIM GUSEV	{"email": "m_gusev.101972@postgrespro.ru", "phone": "+70323890615"}
0005432706407	99D3E3	5505 394175	VLADIMIR KARPOV	{"phone": "+70551531706"}
0005432706408	55C73F	7625 307930	EVGENIY DENISOV	{"email": "denisov.e.121978@postgrespro.ru", "phone": "+70918298380"}
0005432706409	7AB59B	8131 636114	VALENTINA ROMANOVA	{"email": "romanova-valentina-07091963@postgrespro.ru", "phone": "+70741245539"}
0005432706410	406FF4	2046 579052	VERA AFANASEVA	{"phone": "+70523256881"}
0005432706411	AC5C11	5591 469971	LIDIYA KONDRATEVA	{"phone": "+70284895718"}
0005432706412	1A126E	5742 482503	SOFIYA ZAKHAROVA	{"email": "zakharova-sofiya_011973@postgrespro.ru", "phone": "+70567020806"}
0005432706413	6E1118	4617 170143	ALEKSANDR FOMIN	{"phone": "+70008093926"}
0005432706414	416D28	1306 176109	GLEB POPOV	{"email": "g.popov1971@postgrespro.ru", "phone": "+70832923980"}
0005432706415	121142	1084 003287	ALEKSANDRA ANTONOVA	{"phone": "+70429616976"}
0005432706417	B55D2A	1577 985224	NIKOLAY ANTONOV	{"email": "antonov.n.051963@postgrespro.ru", "phone": "+70926605169"}
0005432706418	B55D2A	9916 631418	OKSANA IVANOVA	{"phone": "+70955367166"}
0005432706419	A0F9FC	0877 385964	SERGEY VASILEV	{"phone": "+70813590665"}
0005432706420	A0F9FC	1633 547127	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov_061976@postgrespro.ru", "phone": "+70910436076"}
0005432706421	24F8AA	3860 284241	LYUDMILA KUZNECOVA	{"phone": "+70757164359"}
0005432706422	8DED55	7964 627313	IGOR CHERNOV	{"email": "chernov.igor.081971@postgrespro.ru", "phone": "+70928254068"}
0005432706423	6C513F	2379 163643	ALEKSEY POPOV	{"email": "popov.a.061975@postgrespro.ru", "phone": "+70692513481"}
0005432706424	6C513F	9513 576597	ELENA FILATOVA	{"email": "efilatova.1962@postgrespro.ru", "phone": "+70788391685"}
0005432706425	EE8754	0574 631450	OLGA SEMENOVA	{"email": "olga-semenova101974@postgrespro.ru", "phone": "+70395697745"}
0005432706426	F7C423	1490 287154	ALENA MATVEEVA	{"email": "matveeva_a.1973@postgrespro.ru", "phone": "+70339333154"}
0005432706427	F7C423	1620 675237	ANDREY MIKHAYLOV	{"email": "amikhaylov061973@postgrespro.ru", "phone": "+70619877382"}
0005432706428	468413	4885 742619	ROZA SIDOROVA	{"phone": "+70593898836"}
0005432706429	ABD4BC	8915 296727	RUSLAN MAKSIMOV	{"email": "maksimov-ruslan_1972@postgrespro.ru", "phone": "+70709238802"}
0005432706430	BFBA4A	8396 859012	DMITRIY KOZLOV	{"phone": "+70309158213"}
0005432706431	AF9F93	5276 592531	ELENA SAVELEVA	{"phone": "+70613128991"}
0005432706432	AF9F93	0524 107547	SVETLANA SOROKINA	{"email": "sorokina-svetlana1966@postgrespro.ru", "phone": "+70895957588"}
0005432706433	45261E	8186 160488	IRINA OSIPOVA	{"email": "osipova-i_1974@postgrespro.ru", "phone": "+70908900056"}
0005432706434	B6CBCA	8296 306385	SERGEY GRIGOREV	{"email": "grigorevsergey_1977@postgrespro.ru", "phone": "+70257742975"}
0005432706435	B6CBCA	6844 127172	ZOYA NAZAROVA	{"phone": "+70339232953"}
0005432706436	35173D	6548 531730	SERGEY SEMENOV	{"email": "sergey-semenov1982@postgrespro.ru", "phone": "+70294784546"}
0005432706437	A216AD	8757 465124	NATALYA ALEKSANDROVA	{"email": "aleksandrovanatalya_091973@postgrespro.ru", "phone": "+70024067905"}
0005432706438	5995AF	8359 585578	VERA KOROLEVA	{"phone": "+70936012119"}
0005432706439	6DFBBB	3696 023813	MARIYA AFANASEVA	{"phone": "+70773588626"}
0005432706440	6DFBBB	3091 485006	VIKTOR SIDOROV	{"phone": "+70059052588"}
0005432706441	DBA904	9079 045278	ELENA AFANASEVA	{"email": "afanaseva-elena-11051970@postgrespro.ru", "phone": "+70917219966"}
0005432706442	AAAB13	7534 904546	YULIYA RODIONOVA	{"email": "rodionova.yuliya121961@postgrespro.ru", "phone": "+70399272456"}
0005432706443	AEA04D	7391 075038	NATALIYA ROMANOVA	{"email": "romanova.n-16021975@postgrespro.ru", "phone": "+70780679192"}
0005432706444	FA4A36	9842 165282	ARTEM SIDOROV	{"phone": "+70514498469"}
0005432706445	AEF536	1894 961079	ARTEM OSIPOV	{"email": "artem.osipov_09071977@postgrespro.ru", "phone": "+70899299340"}
0005432706446	B64F8C	6263 010995	EKATERINA FADEEVA	{"phone": "+70158173779"}
0005432706447	6F0B83	8229 440152	ANATOLIY MIKHAYLOV	{"email": "mikhaylov.anatoliy071970@postgrespro.ru", "phone": "+70031322686"}
0005432706448	3BC507	3050 340165	ANASTASIYA NIKITINA	{"email": "a_nikitina.19051960@postgrespro.ru", "phone": "+70322181835"}
0005432706449	0009ED	7478 666965	VYACHESLAV IVANOV	{"email": "v_ivanov-1968@postgrespro.ru", "phone": "+70033317400"}
0005432706450	0009ED	0734 272387	LYUDMILA PAVLOVA	{"email": "lyudmila-pavlova_1963@postgrespro.ru", "phone": "+70968910881"}
0005432706451	6FBE1B	9321 225745	DARYA SOKOLOVA	{"phone": "+70472958282"}
0005432706452	94EEB8	4541 244631	GENNADIY PETROV	{"phone": "+70385047383"}
0005432706453	94EEB8	7832 780609	ANDREY BORISOV	{"phone": "+70466760499"}
0005432706454	7714BC	9670 854504	NIKOLAY ANDREEV	{"phone": "+70896099376"}
0005432706455	2DD355	0992 713588	VERA SOROKINA	{"phone": "+70256869585"}
0005432706456	C8699F	3113 695953	LIDIYA FEDOROVA	{"email": "lidiya-fedorova_13071977@postgrespro.ru", "phone": "+70917857175"}
0005432706457	C8699F	3692 288580	ANNA IVANOVA	{"phone": "+70929006076"}
0005432706458	D8F3B1	9502 955720	NATALYA FEDOROVA	{"phone": "+70320663403"}
0005432706459	84BD8F	7030 296683	MIKHAIL VLASOV	{"phone": "+70168993692"}
0005432706460	D582FF	2249 683587	VLADISLAV FILIPPOV	{"phone": "+70627183067"}
0005432706461	766366	7621 306450	DARYA FADEEVA	{"phone": "+70005231423"}
0005432706462	766366	3826 183473	VALENTIN SHEVCHENKO	{"email": "v-shevchenko1975@postgrespro.ru", "phone": "+70890702070"}
0005432706463	8B8B7C	2388 730560	OLGA KOVALEVA	{"email": "olga.kovaleva-04091964@postgrespro.ru", "phone": "+70461207710"}
0005432706464	8B8B7C	4786 003795	TATYANA TIKHONOVA	{"email": "t-tikhonova-01091969@postgrespro.ru", "phone": "+70628341810"}
0005432706465	AB674E	3343 851042	NINA LEBEDEVA	{"phone": "+70619252820"}
0005432706466	34DD27	5637 911429	GALINA ZHUKOVA	{"email": "zhukovag.071973@postgrespro.ru", "phone": "+70439501660"}
0005432706467	C34450	3796 041014	NINA POPOVA	{"phone": "+70829381500"}
0005432706468	F64BB6	6979 843511	TATYANA FADEEVA	{"email": "t-fadeeva.07091979@postgrespro.ru", "phone": "+70573513513"}
0005432706469	154D45	5972 145874	VLADIMIR IVANOV	{"email": "v.ivanov1959@postgrespro.ru", "phone": "+70718280826"}
0005432706470	16C763	5106 174269	ELIZAVETA GRISHINA	{"email": "e-grishina-1976@postgrespro.ru", "phone": "+70477531382"}
0005432706471	16C763	8071 214327	GENNADIY IVANOV	{"phone": "+70619252935"}
0005432706472	A50C04	9247 016250	OLGA ILINA	{"email": "o_ilina20081971@postgrespro.ru", "phone": "+70269798679"}
0005432706474	87B50B	3132 269933	MIKHAIL KONOVALOV	{"email": "konovalov_m-21021974@postgrespro.ru", "phone": "+70180796277"}
0005432706475	96B785	9869 779075	ALENA BORISOVA	{"email": "borisova_alena_1969@postgrespro.ru", "phone": "+70779276805"}
0005432706476	C57D14	6713 508884	NIKOLAY POPOV	{"phone": "+70975667850"}
0005432706477	8E5225	9993 900024	KONSTANTIN AFANASEV	{"email": "afanasev_k.19071975@postgrespro.ru", "phone": "+70978500204"}
0005432706478	A5CF53	8412 587267	DARYA RODIONOVA	{"email": "rodionova.darya_1971@postgrespro.ru", "phone": "+70888382687"}
0005432706479	A5CF53	7733 349905	MARINA POPOVA	{"phone": "+70353082267"}
0005432706480	257B58	8024 080453	MARINA PETROVA	{"email": "petrova_m.031972@postgrespro.ru", "phone": "+70724542599"}
0005432706481	3B4EAF	8419 314350	LILIYA ARKHIPOVA	{"email": "arkhipova.liliya.1978@postgrespro.ru", "phone": "+70186388698"}
0005432706482	D0CC9B	3193 641155	VENERA SOLOVEVA	{"phone": "+70938451245"}
0005432706483	AB57C9	3540 482055	SERGEY GRIGOREV	{"email": "sergey-grigorev_1959@postgrespro.ru", "phone": "+70429424072"}
0005432706484	5F7C95	3064 496158	VLADIMIR ABRAMOV	{"email": "abramov.vladimir.15051969@postgrespro.ru", "phone": "+70252583268"}
0005432706485	569311	7271 995826	DENIS GAVRILOV	{"phone": "+70866077280"}
0005432706486	3FE3AA	6632 560745	KONSTANTIN ALEKSEEV	{"email": "konstantin-alekseev30041972@postgrespro.ru", "phone": "+70817682690"}
0005432706487	3FE3AA	2538 153119	OLGA KRASNOVA	{"phone": "+70228526809"}
0005432706488	D24967	4549 883000	VITALIY MARTYNOV	{"email": "martynov_v.1975@postgrespro.ru", "phone": "+70312771362"}
0005432706489	D24967	3646 635402	ANATOLIY ZAYCEV	{"email": "anatoliy-zaycev17061976@postgrespro.ru", "phone": "+70205245379"}
0005432706490	FBA75B	2355 308782	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov_1970@postgrespro.ru", "phone": "+70893994403"}
0005432706491	B7A638	2001 656784	YURIY SMIRNOV	{"email": "smirnov.y_1971@postgrespro.ru", "phone": "+70296732982"}
0005432706492	B7A638	1251 823897	RAISA FROLOVA	{"email": "rfrolova.24051955@postgrespro.ru", "phone": "+70580914978"}
0005432706493	1828AB	3657 118110	ELENA ROMANOVA	{"phone": "+70911725280"}
0005432706494	B6494A	7053 137044	SERGEY KUZNECOV	{"email": "s_kuznecov.16051984@postgrespro.ru", "phone": "+70904584699"}
0005432706495	9E2082	8840 514388	PELAGEYA SERGEEVA	{"phone": "+70271656194"}
0005432706496	F5850F	6195 751321	TATYANA SIDOROVA	{"email": "sidorovatatyana_27101966@postgrespro.ru", "phone": "+70046167979"}
0005432706497	C46B94	3147 374921	MAKSIM VOROBEV	{"email": "m.vorobev08021972@postgrespro.ru", "phone": "+70065069899"}
0005432706498	C46B94	9928 763701	ALEKSANDR DAVYDOV	{"phone": "+70140303472"}
0005432706499	E562F8	2363 739039	NADEZHDA SIDOROVA	{"email": "sidorova.n-06121955@postgrespro.ru", "phone": "+70220361169"}
0005432706500	FCC18D	0516 580454	VLADISLAV FEDOROV	{"email": "fedorov-vladislav_04031977@postgrespro.ru", "phone": "+70989337036"}
0005432706501	FCC18D	3685 588270	ANTON FILIPPOV	{"phone": "+70353865022"}
0005432706502	238D3E	6091 932422	NIKOLAY VASILEV	{"email": "vasilev-nikolay.1966@postgrespro.ru", "phone": "+70101127088"}
0005432706503	238D3E	0296 508158	VERONIKA KOVALEVA	{"email": "v-kovaleva-081973@postgrespro.ru", "phone": "+70718070989"}
0005432706504	95B193	2652 966838	IVAN MEDVEDEV	{"phone": "+70355176518"}
0005432706505	C7DBBE	1790 093013	VALENTINA OSIPOVA	{"phone": "+70868963010"}
0005432706506	ECB090	4283 622135	VALENTINA BORISOVA	{"phone": "+70171080147"}
0005432706507	352A6C	4560 967909	ARINA MIRONOVA	{"phone": "+70513378167"}
0005432706508	65096E	2989 520964	EGOR GERASIMOV	{"phone": "+70543015932"}
0005432706509	EB90BB	1631 069667	IVAN SCHERBAKOV	{"email": "i.scherbakov081966@postgrespro.ru", "phone": "+70645919490"}
0005432706510	43F089	5759 935156	VERA SOLOVEVA	{"phone": "+70289405790"}
0005432706511	DB53FC	6034 360326	TATYANA NESTEROVA	{"email": "nesterova-tatyana_061973@postgrespro.ru", "phone": "+70309158611"}
0005432706512	DB53FC	8803 539073	IRINA SOROKINA	{"phone": "+70300790846"}
0005432706513	CE3487	9776 782734	ELENA PETROVA	{"phone": "+70782487264"}
0005432706514	CE3487	9717 320953	VALENTINA ILINA	{"email": "ilina_valentina_1967@postgrespro.ru", "phone": "+70699616946"}
0005432706515	0F6CBD	2318 360258	ANDREY BONDARENKO	{"phone": "+70064171597"}
0005432706516	EE538C	0117 908016	DANIIL KUZNECOV	{"email": "kuznecovdaniil-09041968@postgrespro.ru", "phone": "+70772691660"}
0005432706517	EE538C	5350 172608	VIKTOR KUZNECOV	{"phone": "+70472103346"}
0005432706518	F68B8C	7342 074833	ELENA SOROKINA	{"email": "esorokina-051966@postgrespro.ru", "phone": "+70520125206"}
0005432706519	F68B8C	2412 139764	ANASTASIYA MELNIKOVA	{"email": "amelnikova-071967@postgrespro.ru", "phone": "+70277889601"}
0005432706520	D4796F	2819 349855	ANNA ZHUKOVA	{"phone": "+70610489452"}
0005432706521	02FF3E	8076 079580	VLADIMIR SMIRNOV	{"phone": "+70722122336"}
0005432706522	18D0F2	1153 199061	GALINA ANTONOVA	{"email": "antonova.g.01061972@postgrespro.ru", "phone": "+70708090109"}
0005432706523	B9EAB1	9005 165811	EKATERINA MAKAROVA	{"email": "makarovaekaterina_14101983@postgrespro.ru", "phone": "+70198805460"}
0005432706524	B9EAB1	1747 941457	TATYANA KISELEVA	{"email": "kiselevat-121976@postgrespro.ru", "phone": "+70826415097"}
0005432706525	701849	2038 109188	NADEZHDA AFANASEVA	{"email": "n.afanaseva_28071973@postgrespro.ru", "phone": "+70206319417"}
0005432706526	4A6412	8468 369662	ALEKSANDR GERASIMOV	{"phone": "+70198098341"}
0005432706527	25AA8A	5763 686964	RENAT ANDREEV	{"phone": "+70373907903"}
0005432706528	25AA8A	7312 766172	DARYA IVANOVA	{"phone": "+70699433772"}
0005432706529	25AA8A	7399 246915	ANATOLIY SCHERBAKOV	{"email": "scherbakov_anatoliy1976@postgrespro.ru", "phone": "+70151442463"}
0005432706530	294079	6994 535796	SVETLANA MAKSIMOVA	{"phone": "+70557000002"}
0005432706531	294079	4730 543976	OKSANA ZHUKOVA	{"email": "oksanazhukova.101961@postgrespro.ru", "phone": "+70758254144"}
0005432706532	44B71F	1757 942431	GENNADIY SAVELEV	{"email": "savelev.gennadiy081981@postgrespro.ru", "phone": "+70480166605"}
0005432706533	75D4B0	0290 044986	TATYANA BARANOVA	{"email": "baranovat06041966@postgrespro.ru", "phone": "+70577167133"}
0005432706534	75D4B0	9481 235978	SERGEY KUZNECOV	{"email": "kuznecov.sergey02061963@postgrespro.ru", "phone": "+70063322556"}
0005432706535	E7EF62	5557 367614	VALERIYA ZAKHAROVA	{"email": "zakharova.v.1975@postgrespro.ru", "phone": "+70336902214"}
0005432706536	1B8D31	8739 819218	RUSTEM ALEKSEEV	{"phone": "+70870713364"}
0005432706537	1B8D31	4273 470653	ELENA SIDOROVA	{"email": "sidorova.e-031976@postgrespro.ru", "phone": "+70337388065"}
0005432706538	D2743A	1156 956584	ANDREY ANTONOV	{"email": "antonov_a.26011980@postgrespro.ru", "phone": "+70017303868"}
0005432706539	D2743A	3437 104600	TAMARA SOKOLOVA	{"email": "sokolova.tamara1970@postgrespro.ru", "phone": "+70676182688"}
0005432706540	D416C3	8403 091038	DENIS PETROV	{"phone": "+70343669975"}
0005432706541	D416C3	1182 924826	OKSANA MAKSIMOVA	{"phone": "+70308404436"}
0005432706542	153078	9867 163954	MARIYA PETROVA	{"email": "petrova.m.30011974@postgrespro.ru", "phone": "+70137870342"}
0005432706543	87C2EF	5605 151608	ALEKSANDRA RODIONOVA	{"phone": "+70128171360"}
0005432706544	87C2EF	9365 308597	VERONIKA FOMINA	{"phone": "+70394622830"}
0005432706545	7D25CD	8862 675112	OLEG MEDVEDEV	{"email": "o.medvedev_24021956@postgrespro.ru", "phone": "+70542126489"}
0005432706546	717E97	3915 019040	MARIYA ISAEVA	{"phone": "+70634742868"}
0005432706547	B74CC3	0197 368773	IRINA FROLOVA	{"email": "frolova_irina-17041975@postgrespro.ru", "phone": "+70603944633"}
0005432706548	FAB52D	4984 689302	OLESYA KARPOVA	{"phone": "+70516392906"}
0005432706549	905FE3	7601 260157	ANTON TIKHONOV	{"email": "tikhonov.a_29011990@postgrespro.ru", "phone": "+70248960079"}
0005432706550	C5A4C5	2465 221113	IRINA FROLOVA	{"email": "frolova-i.16081963@postgrespro.ru", "phone": "+70730472038"}
0005432706551	924ADC	8011 851754	ALEKSEY POPOV	{"phone": "+70099588108"}
0005432706552	DFEC8E	5135 476275	MARINA ZAKHAROVA	{"phone": "+70320275895"}
0005432706553	DFEC8E	1658 677850	YURIY DENISOV	{"email": "yuriy-denisov_03041976@postgrespro.ru", "phone": "+70889626572"}
0005432706554	EA6B32	6145 674326	YULIYA MEDVEDEVA	{"phone": "+70587537120"}
0005432706555	35054E	6895 508630	TATYANA OSIPOVA	{"phone": "+70782100293"}
0005432706556	F23A25	7626 275797	PAVEL KARPOV	{"email": "p.karpov071968@postgrespro.ru", "phone": "+70598765327"}
0005432706557	8966AD	7988 193425	EVGENIY EGOROV	{"email": "egorov_e-1975@postgrespro.ru", "phone": "+70089859266"}
0005432706558	D96AA3	8777 255611	DARYA BORISOVA	{"phone": "+70394654637"}
0005432706559	D96AA3	5840 536296	ANNA ANTONOVA	{"email": "a_antonova-081968@postgrespro.ru", "phone": "+70553367170"}
0005432706560	043013	0667 160682	YURIY ZHURAVLEV	{"email": "yzhuravlev_121969@postgrespro.ru", "phone": "+70048437121"}
0005432706561	043013	9424 398581	SVETLANA SOKOLOVA	{"phone": "+70812365794"}
0005432706562	CB416B	3336 300492	ALEKSANDR MAKAROV	{"phone": "+70174375171"}
0005432706563	748032	7924 006956	VASILIY SHEVCHENKO	{"phone": "+70198382609"}
0005432706564	5C07AD	5332 200526	NINA KUDRYASHOVA	{"phone": "+70424074899"}
0005432706565	5C07AD	8212 176424	NIKOLAY TARASOV	{"phone": "+70848205012"}
0005432706566	DB9D3B	4671 421601	TATYANA FEDOROVA	{"phone": "+70621346792"}
0005432706567	DB9D3B	7912 638955	ANDREY MIKHAYLOV	{"email": "a-mikhaylov-051976@postgrespro.ru", "phone": "+70151296887"}
0005432706568	BDB8FA	6997 616170	IVAN SEMENOV	{"phone": "+70989111021"}
0005432706569	A94E12	2182 988686	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov-19061970@postgrespro.ru", "phone": "+70244378736"}
0005432706570	A1789C	2091 715937	OLGA KOZLOVA	{"phone": "+70954860994"}
0005432706571	AFA3E2	2262 228105	IRINA RODIONOVA	{"email": "rodionova-i06071977@postgrespro.ru", "phone": "+70176224468"}
0005432706572	AFA3E2	3498 206165	VLADIMIR MAKAROV	{"phone": "+70711724490"}
0005432706573	AFA3E2	1262 543449	ALEKSANDR MELNIKOV	{"email": "a-melnikov031966@postgrespro.ru", "phone": "+70290741173"}
0005432706574	19D027	2408 860150	KSENIYA DMITRIEVA	{"phone": "+70990322783"}
0005432706575	82C424	6916 988874	MIKHAIL TIKHONOV	{"phone": "+70119493952"}
0005432706576	F58148	6515 114081	MARIYA FROLOVA	{"email": "frolovam.1969@postgrespro.ru", "phone": "+70640291086"}
0005432706577	63A4CF	6650 619806	LARISA SIDOROVA	{"email": "sidorova_l_051963@postgrespro.ru", "phone": "+70675724487"}
0005432706578	1CF1C4	3861 198460	VLADIMIR KAZAKOV	{"phone": "+70543835940"}
0005432706579	0129DF	4916 126462	SVETLANA MAKAROVA	{"email": "s-makarova051981@postgrespro.ru", "phone": "+70897196667"}
0005432706580	866D5A	6461 419126	ANNA PETROVA	{"phone": "+70063489119"}
0005432706581	5FD01D	5001 623855	STEPAN NAUMOV	{"email": "naumovstepan.1983@postgrespro.ru", "phone": "+70497758728"}
0005432706582	7A4CE4	9827 688867	VITALIY KUZNECOV	{"email": "kuznecov_vitaliy-01111980@postgrespro.ru", "phone": "+70331351587"}
0005432706583	7A4CE4	3919 308736	ALEKSANDR FEDOROV	{"phone": "+70804390000"}
0005432706584	3A0789	6025 651138	LIDIYA KONOVALOVA	{"email": "l.konovalova_1970@postgrespro.ru", "phone": "+70731288053"}
0005432706585	4C408D	6103 418938	ANASTASIYA STEPANOVA	{"phone": "+70802211930"}
0005432706586	4C408D	9168 654656	ILYA MIKHAYLOV	{"phone": "+70273029729"}
0005432706587	4C408D	4143 844309	IGOR SMIRNOV	{"email": "igor.smirnov011974@postgrespro.ru", "phone": "+70513543305"}
0005432706588	CCE1BA	6177 880966	GALINA GORBUNOVA	{"email": "gorbunova_g-11051981@postgrespro.ru", "phone": "+70285546003"}
0005432706589	CCE1BA	0982 908863	YAKOV GAVRILOV	{"phone": "+70314441697"}
0005432706590	6750D9	7581 847803	VALENTINA KOVALEVA	{"phone": "+70429077609"}
0005432706591	6315EA	3403 715088	POLINA VOROBEVA	{"phone": "+70876333797"}
0005432706592	6315EA	5469 470431	TATYANA ANISIMOVA	{"phone": "+70372478187"}
0005432706593	3917C5	7244 352040	ZINAIDA NIKOLAEVA	{"email": "nikolaevaz-04121970@postgrespro.ru", "phone": "+70595858632"}
0005432706594	3917C5	6508 940346	GALINA ZAYCEVA	{"phone": "+70826047951"}
0005432706595	02941C	8647 411291	VYACHESLAV KOZLOV	{"phone": "+70941272177"}
0005432706596	9FE81B	0220 208947	ANATOLIY KAZAKOV	{"email": "anatoliy.kazakov1968@postgrespro.ru", "phone": "+70303232439"}
0005432706597	7F7984	3515 054831	ANATOLIY SOLOVEV	{"phone": "+70261598010"}
0005432706598	7F7984	4168 753937	ALEKSANDR ANTONOV	{"phone": "+70876805928"}
0005432706599	CAB1A3	7669 901506	NATALYA ISAEVA	{"phone": "+70726286485"}
0005432706600	1925B7	5287 933124	GENNADIY DMITRIEV	{"phone": "+70936831316"}
0005432706601	1925B7	5357 966219	VIKTORIYA ANDREEVA	{"phone": "+70902950004"}
0005432706602	1925B7	8929 987204	TATYANA EFREMOVA	{"phone": "+70338656242"}
0005432706603	979FC4	9560 835367	VALERIY GUSEV	{"phone": "+70303154917"}
0005432706604	B355CE	8668 890865	VALERIY ROMANOV	{"phone": "+70352778608"}
0005432706605	A285E9	0488 381727	NINEL NESTEROVA	{"email": "n-nesterova_031970@postgrespro.ru", "phone": "+70483308690"}
0005432706606	A285E9	3357 426909	DMITRIY IVANOV	{"email": "d-ivanov20101981@postgrespro.ru", "phone": "+70838238641"}
0005432706607	A285E9	0746 995325	VERONIKA ROMANOVA	{"phone": "+70671276163"}
0005432706608	CAF624	6489 425611	RAMILYA NIKOLAEVA	{"email": "nikolaeva.r.1970@postgrespro.ru", "phone": "+70609860171"}
0005432706609	A764C2	5051 720007	MAKSIM YAKOVLEV	{"email": "yakovlevm_071962@postgrespro.ru", "phone": "+70026961063"}
0005432706610	A764C2	5545 450823	VLADIMIR SERGEEV	{"email": "vladimir-sergeev-121973@postgrespro.ru", "phone": "+70803386087"}
0005432706611	694CB0	1553 846741	IGOR BELOV	{"phone": "+70343410539"}
0005432706612	694CB0	7131 597981	ALEKSANDR KOROLEV	{"phone": "+70616296387"}
0005432706613	9C922F	3773 858364	SERGEY VASILEV	{"phone": "+70467125875"}
0005432706614	9C922F	0042 542529	NIKOLAY BORISOV	{"email": "n_borisov_22121967@postgrespro.ru", "phone": "+70380187594"}
0005432706615	9C922F	3341 381116	TATYANA ANTONOVA	{"phone": "+70536699246"}
0005432706616	56BE33	0143 722631	ILYA NAUMOV	{"phone": "+70182162707"}
0005432706617	C45B30	6638 325701	ALEKSANDR ZAYCEV	{"email": "a.zaycev.03051975@postgrespro.ru", "phone": "+70361461027"}
0005432706618	35F3B6	0517 489508	ELENA PAVLOVA	{"email": "pavlova_elena-021976@postgrespro.ru", "phone": "+70476828751"}
0005432706619	35F3B6	8525 781505	KONSTANTIN MOROZOV	{"email": "konstantin_morozov30051980@postgrespro.ru", "phone": "+70115029572"}
0005432706620	49BA37	0723 790971	LEONID TARASOV	{"email": "tarasovleonid.041967@postgrespro.ru", "phone": "+70735710551"}
0005432706621	68A52A	6315 374101	ELENA PAVLOVA	{"phone": "+70547441994"}
0005432706622	68A52A	2492 604349	ANTON KOROLEV	{"email": "a_korolev_041975@postgrespro.ru", "phone": "+70210435304"}
0005432706623	474898	3257 075791	GULNARA SOROKINA	{"email": "sorokina-gulnara.20121973@postgrespro.ru", "phone": "+70032267506"}
0005432706624	125356	6379 399605	MAKSIM TIMOFEEV	{"email": "m_timofeev_1966@postgrespro.ru", "phone": "+70616004823"}
0005432706625	F718B2	1686 992717	OLEG ORLOV	{"email": "orlovo.021975@postgrespro.ru", "phone": "+70876659895"}
0005432706626	BC2178	9306 449064	DMITRIY ILIN	{"email": "d_ilin.081980@postgrespro.ru", "phone": "+70812542150"}
0005432706627	E86DAC	4060 011343	SERGEY ANDREEV	{"email": "andreev_s_041977@postgrespro.ru", "phone": "+70847550286"}
0005432706628	28D7EC	8528 826182	OLEG NIKITIN	{"phone": "+70891503571"}
0005432706629	28D7EC	2304 803387	ALINA EGOROVA	{"email": "alina-egorova_121963@postgrespro.ru", "phone": "+70053670672"}
0005432706630	B86CD4	5058 405157	YURIY NIKITIN	{"phone": "+70250815879"}
0005432706631	B86CD4	4212 942017	ANNA KISELEVA	{"phone": "+70573402694"}
0005432706632	D564CC	9432 542379	SERGEY SAVELEV	{"email": "savelev.s021962@postgrespro.ru", "phone": "+70915281693"}
0005432706633	D564CC	5791 330127	ELENA TROFIMOVA	{"email": "trofimova-e11081985@postgrespro.ru", "phone": "+70982447703"}
0005432706634	0328E3	1439 966451	VERA ZAKHAROVA	{"phone": "+70902763183"}
0005432706635	0328E3	7051 578758	SERGEY SHEVCHENKO	{"email": "shevchenkosergey-02101975@postgrespro.ru", "phone": "+70096962091"}
0005432706636	3C98A2	4241 601728	VALERIY SIDOROV	{"email": "sidorov-valeriy.03041968@postgrespro.ru", "phone": "+70241359558"}
0005432706637	D43FDB	2914 831269	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov.1974@postgrespro.ru", "phone": "+70120589716"}
0005432706638	5A58AF	6773 583242	ALEKSANDR ALEKSEEV	{"email": "alekseev-a_1973@postgrespro.ru", "phone": "+70151464207"}
0005432706639	5A58AF	8338 927453	SVETLANA VOLKOVA	{"email": "volkova-s.1985@postgrespro.ru", "phone": "+70638329724"}
0005432706640	D8B333	8341 860177	NIKOLAY KUZMIN	{"email": "kuzminn_1960@postgrespro.ru", "phone": "+70188314379"}
0005432706641	5DDB36	0971 190692	ANDREY ABRAMOV	{"email": "a-abramov-12011968@postgrespro.ru", "phone": "+70352153009"}
0005432706642	2FC41C	5038 645105	KARINA STEPANOVA	{"email": "stepanovakarina011977@postgrespro.ru", "phone": "+70812340958"}
0005432706643	D47219	5981 708311	ALEKSANDR BORISOV	{"phone": "+70746164049"}
0005432706644	3E8719	3874 803186	ELENA ORLOVA	{"email": "orlova_elena-17011982@postgrespro.ru", "phone": "+70885359492"}
0005432706645	9EA754	3934 205846	MARINA MAKSIMOVA	{"email": "maksimova.marina02081976@postgrespro.ru", "phone": "+70543087148"}
0005432706646	ABCE17	5360 236504	ANTON ANDREEV	{"phone": "+70475516127"}
0005432706647	863C9B	8343 380840	OKSANA TARASOVA	{"email": "tarasovaoksana1973@postgrespro.ru", "phone": "+70942655920"}
0005432706648	723707	2687 734239	DMITRIY ANTONOV	{"email": "dmitriy.antonov_061967@postgrespro.ru", "phone": "+70795008698"}
0005432706649	B1BB5B	8008 381882	LEYLA KAZAKOVA	{"phone": "+70578464329"}
0005432706650	F736EA	8437 556934	LYUBOV LEBEDEVA	{"email": "lyubovlebedeva051976@postgrespro.ru", "phone": "+70131099617"}
0005432706651	CE03F2	9177 737713	VERA MAKSIMOVA	{"phone": "+70427982244"}
0005432706652	CE03F2	0892 829690	KIRILL KUZMIN	{"email": "kirill_kuzmin.1968@postgrespro.ru", "phone": "+70647136905"}
0005432706653	CE03F2	7274 541034	VALENTINA ANTONOVA	{"email": "valentina_antonova-01011972@postgrespro.ru", "phone": "+70175798040"}
0005432706654	FDECC4	2743 802320	KRISTINA MELNIKOVA	{"phone": "+70717837520"}
0005432706655	FDECC4	7437 451424	EVGENIY GAVRILOV	{"email": "e.gavrilov01121966@postgrespro.ru", "phone": "+70106202142"}
0005432706656	778ACF	6453 867163	NINA DANILOVA	{"email": "ninadanilova-031973@postgrespro.ru", "phone": "+70849549216"}
0005432706657	71C0CF	6233 329515	VALENTINA BOGDANOVA	{"phone": "+70974839558"}
0005432706658	71C0CF	5383 063367	IVAN SCHERBAKOV	{"email": "ischerbakov1954@postgrespro.ru", "phone": "+70845583655"}
0005432706659	6D5E17	0207 580658	OKSANA KUZNECOVA	{"email": "okuznecova_16091970@postgrespro.ru", "phone": "+70227237901"}
0005432706660	38A066	0443 751585	YULIYA DAVYDOVA	{"phone": "+70212179595"}
0005432706661	1FEFA0	2924 299954	ALEKSEY ZAKHAROV	{"email": "aleksey.zakharov071976@postgrespro.ru", "phone": "+70905762784"}
0005432706662	4DD0BA	3400 699453	ALEKSANDR GUSEV	{"email": "a-gusev051972@postgrespro.ru", "phone": "+70556246696"}
0005432706663	4DD0BA	6967 432052	VALENTINA KULIKOVA	{"email": "kulikovavalentina121966@postgrespro.ru", "phone": "+70610321001"}
0005432706664	F3435D	2348 542923	VASILIY ALEKSEEV	{"email": "alekseev-v_1970@postgrespro.ru", "phone": "+70546113555"}
0005432706665	D38E3E	4927 850807	NIKOLAY BELOV	{"phone": "+70152921873"}
0005432706666	D38E3E	3780 575642	VYACHESLAV DMITRIEV	{"phone": "+70653075427"}
0005432706667	D38E3E	4223 935527	POLINA SERGEEVA	{"email": "sergeeva.polina-18041967@postgrespro.ru", "phone": "+70622958345"}
0005432706668	287972	5200 944825	VLADIMIR NAZAROV	{"phone": "+70255508484"}
0005432706669	287972	3528 955338	VALENTINA BARANOVA	{"phone": "+70299369781"}
0005432706670	BEFEE8	5103 300424	VLADIMIR SCHERBAKOV	{"email": "vladimir.scherbakov.1978@postgrespro.ru", "phone": "+70065850325"}
0005432706671	BEFEE8	9822 488126	DMITRIY GRIGOREV	{"phone": "+70288115677"}
0005432706672	062596	0167 348608	ARTEM SOROKIN	{"phone": "+70048311039"}
0005432706673	EE78CE	2853 636682	SVETLANA ALEKSANDROVA	{"email": "aleksandrovas_1972@postgrespro.ru", "phone": "+70567645459"}
0005432706674	EE78CE	3404 241541	VALERIY POPOV	{"email": "vpopov101970@postgrespro.ru", "phone": "+70258592747"}
0005432706675	44E398	2094 196548	GEORGIY ROMANOV	{"phone": "+70433601284"}
0005432706676	D99B73	1351 740053	TATYANA ANDREEVA	{"email": "andreevat1971@postgrespro.ru", "phone": "+70847097993"}
0005432706677	7685A8	4641 091955	SANIYA SCHERBAKOVA	{"email": "saniya.scherbakova_03021985@postgrespro.ru", "phone": "+70893876559"}
0005432706678	7685A8	3679 324006	DARYA GRISHINA	{"phone": "+70223301151"}
0005432706679	83139B	7202 284821	DZHAMILYA NIKIFOROVA	{"phone": "+70829562776"}
0005432706680	83139B	4669 695718	PRASKOVYA IVANOVA	{"email": "p.ivanova031964@postgrespro.ru", "phone": "+70607046400"}
0005432706681	FBF099	0559 872338	KARINA RYABOVA	{"email": "ryabova-karina.091974@postgrespro.ru", "phone": "+70830997742"}
0005432706682	FBF099	9629 322144	TATYANA ZHUKOVA	{"phone": "+70104587107"}
0005432706683	07C17A	2296 218006	DMITRIY MATVEEV	{"email": "matveev-dmitriy-27091976@postgrespro.ru", "phone": "+70347312747"}
0005432706684	10C479	1166 835381	ELENA EFREMOVA	{"email": "efremovaelena.1963@postgrespro.ru", "phone": "+70372008467"}
0005432706685	3C7E01	1676 412610	MARIYA KRASNOVA	{"email": "krasnovam-06051969@postgrespro.ru", "phone": "+70189476099"}
0005432706686	3C7E01	1035 623395	VALENTINA PETROVA	{"email": "petrovavalentina.031965@postgrespro.ru", "phone": "+70501160577"}
0005432706687	414B1B	5238 051903	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin.101969@postgrespro.ru", "phone": "+70391248977"}
0005432706688	AF04A4	4682 634681	IGOR GERASIMOV	{"email": "igor.gerasimov08031968@postgrespro.ru", "phone": "+70572624714"}
0005432706689	CDDD31	2933 762070	VLADIMIR ISAEV	{"email": "v.isaev_1963@postgrespro.ru", "phone": "+70231432034"}
0005432706690	6B694B	6185 948277	ANNA KOROLEVA	{"email": "korolevaa_061976@postgrespro.ru", "phone": "+70481033983"}
0005432706691	6B694B	3945 604347	ANTONINA SCHERBAKOVA	{"email": "ascherbakova-1962@postgrespro.ru", "phone": "+70314538195"}
0005432706692	CF0382	9452 868423	NIKOLAY VASILEV	{"email": "nikolay-vasilev11091967@postgrespro.ru", "phone": "+70241445852"}
0005432706693	CF0382	6861 549478	ALEKSANDR GRIGOREV	{"phone": "+70152160029"}
0005432706694	C8F5A6	1551 020951	NIKOLAY SOKOLOV	{"email": "nikolay_sokolov-02121977@postgrespro.ru", "phone": "+70175618518"}
0005432706695	1B18A7	8888 241588	ALEKSEY IVANOV	{"email": "ivanova-111972@postgrespro.ru", "phone": "+70006357350"}
0005432706696	A66CED	9741 580866	MAKSIM ANTONOV	{"email": "antonov-maksim.051973@postgrespro.ru", "phone": "+70425265677"}
0005432706697	37AA13	1677 367462	NATALIYA BELOVA	{"email": "belova-nataliya.021971@postgrespro.ru", "phone": "+70471651790"}
0005432706698	B978EB	6519 528336	YANA FILATOVA	{"phone": "+70555248553"}
0005432706699	607922	5803 754382	ALEKSEY KOZLOV	{"phone": "+70258764541"}
0005432706700	FAA675	5374 470257	DMITRIY VOROBEV	{"email": "dmitriy.vorobev_1967@postgrespro.ru", "phone": "+70079387322"}
0005432706701	FAA675	0055 789245	SERGEY MAKSIMOV	{"email": "maksimov.sergey121968@postgrespro.ru", "phone": "+70008189744"}
0005432706702	F487FE	2094 757765	NURLAN ANDREEV	{"email": "andreev_n-1973@postgrespro.ru", "phone": "+70655385542"}
0005432706703	F487FE	4804 416893	NIKOLAY KUZMIN	{"phone": "+70336856405"}
0005432706704	78D49F	9823 310115	MARINA GAVRILOVA	{"email": "gavrilova_m-061968@postgrespro.ru", "phone": "+70590945605"}
0005432706705	9DF25F	4227 888621	VLADIMIR ANDREEV	{"email": "andreev-vladimir081961@postgrespro.ru", "phone": "+70361706948"}
0005432706706	D7E5AF	4902 967020	NIKITA MATVEEV	{"email": "matveev.nikita_21061977@postgrespro.ru", "phone": "+70871918494"}
0005432706707	D7E5AF	1184 893889	OLEG GRIGOREV	{"email": "grigorev_o061977@postgrespro.ru", "phone": "+70047602493"}
0005432706708	17CE48	2843 790790	SVETLANA BELYAEVA	{"phone": "+70305614669"}
0005432706709	17CE48	2845 091622	VENERA GORBUNOVA	{"phone": "+70216391826"}
0005432706710	D8C176	4589 079885	DMITRIY FEDOTOV	{"email": "fedotov.dmitriy.011967@postgrespro.ru", "phone": "+70619783546"}
0005432706711	62ABF7	1221 106289	NINA PETROVA	{"phone": "+70468751328"}
0005432706712	62ABF7	4309 285459	MAKSIM PAVLOV	{"phone": "+70303772245"}
0005432706713	297E38	0465 357496	VIKTOR RODIONOV	{"email": "v.rodionov.1968@postgrespro.ru", "phone": "+70941873827"}
0005432706714	297E38	3550 722752	VITALIY ABRAMOV	{"phone": "+70044443942"}
0005432706715	AEEACB	5683 835758	MARIYA GAVRILOVA	{"email": "gavrilova.m.01121978@postgrespro.ru", "phone": "+70001167510"}
0005432706716	AEEACB	8568 601651	MIKHAIL KUZMIN	{"email": "kuzmin-mikhail.1973@postgrespro.ru", "phone": "+70715542419"}
0005432706717	90D22A	3816 286534	EVGENIYA ZHUKOVA	{"email": "zhukova.evgeniya061978@postgrespro.ru", "phone": "+70711987145"}
0005432706718	295CE3	0873 489036	GALINA ARKHIPOVA	{"email": "arkhipova.galina-1966@postgrespro.ru", "phone": "+70839865313"}
0005432706719	295CE3	2761 999693	LYUBOV AFANASEVA	{"email": "lyubov_afanaseva-1973@postgrespro.ru", "phone": "+70940294354"}
0005432706720	68EE5D	8500 536010	GALINA PAVLOVA	{"phone": "+70444516042"}
0005432706721	E30B7D	0935 133434	OLGA MOROZOVA	{"email": "morozovaolga_081970@postgrespro.ru", "phone": "+70809681409"}
0005432706722	898E7C	7927 229036	OLGA SAVELEVA	{"phone": "+70777347630"}
0005432706723	898E7C	6943 912257	KONSTANTIN MAKAROV	{"phone": "+70174387156"}
0005432706724	BBD925	9504 123461	MARIYA KOVALEVA	{"email": "mariyakovaleva-051974@postgrespro.ru", "phone": "+70784958254"}
0005432706725	F318B5	4796 026980	ALEKSANDR FILIPPOV	{"phone": "+70167597923"}
0005432706726	F318B5	3323 458996	OLGA DENISOVA	{"phone": "+70969779907"}
0005432706727	B21072	4508 509818	NIKITA VOROBEV	{"phone": "+70748165135"}
0005432706728	BF7AFE	6926 793624	NATALYA STEPANOVA	{"email": "stepanova-n041963@postgrespro.ru", "phone": "+70862720199"}
0005432706729	F26CC9	5878 151632	LARISA DANILOVA	{"phone": "+70396861259"}
0005432706730	F26CC9	5256 575745	OLGA MOROZOVA	{"phone": "+70919732694"}
0005432706731	271CC0	4800 752377	ALEKSANDR SMIRNOV	{"phone": "+70263426137"}
0005432706732	2A7945	7604 043782	NINA ALEKSEEVA	{"email": "alekseeva_nina1977@postgrespro.ru", "phone": "+70150488490"}
0005432706733	2A7945	8192 056064	IVAN NOVIKOV	{"phone": "+70422064931"}
0005432706734	E669B8	2911 248808	ALEKSANDR ALEKSANDROV	{"phone": "+70772227527"}
0005432706735	B56982	1966 756601	NIKOLAY NAZAROV	{"email": "nazarov.nikolay111968@postgrespro.ru", "phone": "+70603182268"}
0005432706736	B56982	2097 986846	VALENTINA MAKAROVA	{"email": "v.makarova.081965@postgrespro.ru", "phone": "+70442303609"}
0005432706737	D46E8D	4543 065797	OLGA KUDRYASHOVA	{"email": "olga-kudryashova07101968@postgrespro.ru", "phone": "+70864578333"}
0005432706738	D46E8D	0647 212733	NATALIYA EGOROVA	{"email": "egorova.n-031976@postgrespro.ru", "phone": "+70006078871"}
0005432706739	4CC8AF	1392 139322	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov071980@postgrespro.ru", "phone": "+70686613474"}
0005432706740	81C595	8770 178026	ILONA ZHUKOVA	{"phone": "+70110101951"}
0005432706741	5BFEA4	9967 342166	SERGEY ISAEV	{"email": "isaev.sergey.1971@postgrespro.ru", "phone": "+70792039575"}
0005432706742	8AAAF1	8903 759223	LIDIYA MAKAROVA	{"email": "makarova.lidiya-29091973@postgrespro.ru", "phone": "+70495954441"}
0005432706743	8AAAF1	9792 139283	VIKTOR FROLOV	{"phone": "+70145047636"}
0005432706744	A9056C	0406 228293	ELIZAVETA SIDOROVA	{"email": "sidorovaelizaveta-021970@postgrespro.ru", "phone": "+70630562561"}
0005432706745	A9056C	3610 436856	GALINA NESTEROVA	{"email": "gnesterova02101977@postgrespro.ru", "phone": "+70437656774"}
0005432706746	F5F9C1	9238 724000	ALEKSANDR ZHURAVLEV	{"email": "a_zhuravlev_05031980@postgrespro.ru", "phone": "+70789199310"}
0005432706747	7CA6FD	7794 925406	NONNA KOMAROVA	{"phone": "+70564337589"}
0005432706748	ED34A0	9028 964859	TAISIYA NIKOLAEVA	{"email": "t-nikolaeva.071973@postgrespro.ru", "phone": "+70400030230"}
0005432706749	E2466B	9561 616120	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina041982@postgrespro.ru", "phone": "+70601228591"}
0005432706750	75567B	1117 802919	ALEKSEY SHEVCHENKO	{"email": "aleksey-shevchenko041974@postgrespro.ru", "phone": "+70826217951"}
0005432706751	C65401	2225 672566	VADIM RODIONOV	{"phone": "+70717273405"}
0005432706752	BAD001	0637 300203	VIKTOR ILIN	{"phone": "+70474218392"}
0005432706753	2C7963	6288 010639	IGOR KUZNECOV	{"email": "i.kuznecov14111971@postgrespro.ru", "phone": "+70411860289"}
0005432706754	D9A1FF	2064 855711	NIKITA SHEVCHENKO	{"email": "shevchenko_n.1986@postgrespro.ru", "phone": "+70111205618"}
0005432706755	2F57E2	3121 317918	ALEKSANDR ZHURAVLEV	{"phone": "+70683793835"}
0005432706756	6E7685	5357 129828	VALENTINA ARKHIPOVA	{"phone": "+70357146643"}
0005432706757	11D5F0	4345 753853	ELENA ANISIMOVA	{"phone": "+70684156530"}
0005432706758	D563F0	0078 815042	OLGA BORISOVA	{"phone": "+70081428040"}
0005432706759	5928E1	5011 308988	VIKTOR BELOV	{"email": "belov_v-1974@postgrespro.ru", "phone": "+70427407846"}
0005432706760	5EA26B	1381 735667	VLADISLAV ZAKHAROV	{"email": "v_zakharov041972@postgrespro.ru", "phone": "+70486866636"}
0005432706761	BAF3F9	4425 125430	GALINA BORISOVA	{"phone": "+70620357808"}
0005432706762	78B53B	1631 348856	LYUDMILA ALEKSANDROVA	{"phone": "+70809077090"}
0005432706763	5CB04A	8105 032972	PAVEL IVANOV	{"email": "ivanov.pavel03091962@postgrespro.ru", "phone": "+70399485184"}
0005432706764	734012	6844 918643	ALEKSANDRA MAKAROVA	{"email": "makarovaaleksandra031975@postgrespro.ru", "phone": "+70015270530"}
0005432706765	8C7D10	2473 332923	SERGEY PAVLOV	{"email": "spavlov.22091975@postgrespro.ru", "phone": "+70610647724"}
0005432706766	8C7D10	1262 870249	DMITRIY ORLOV	{"email": "d-orlov_16091974@postgrespro.ru", "phone": "+70873274722"}
0005432706767	69B15D	1548 077572	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e-27101967@postgrespro.ru", "phone": "+70187422001"}
0005432706768	8592BF	2903 007279	YURIY ANTONOV	{"email": "y-antonov-1972@postgrespro.ru", "phone": "+70996115979"}
0005432706769	FC660A	5216 635443	IVAN KOZLOV	{"email": "i-kozlov-24041961@postgrespro.ru", "phone": "+70486012107"}
0005432706770	EB9F4E	2999 056642	SERGEY MAKSIMOV	{"email": "maksimov.s061967@postgrespro.ru", "phone": "+70451366598"}
0005432706771	B48119	2302 646624	ANATOLIY GAVRILOV	{"email": "agavrilov08091975@postgrespro.ru", "phone": "+70360783057"}
0005432706772	26CF5C	9198 370913	ALEKSANDR FILIPPOV	{"phone": "+70986607241"}
0005432706773	26CF5C	6470 823118	ELENA CHERNOVA	{"phone": "+70592516297"}
0005432706774	9FA8F6	9518 173205	GALINA MELNIKOVA	{"phone": "+70372363094"}
0005432706775	23F26D	7633 584442	SVETLANA ANISIMOVA	{"email": "s_anisimova1968@postgrespro.ru", "phone": "+70666759211"}
0005432706776	161781	1476 213468	IVAN VLASOV	{"email": "ivlasov061966@postgrespro.ru", "phone": "+70787563811"}
0005432706777	96CA60	8197 735743	LEONID SHEVCHENKO	{"phone": "+70977534912"}
0005432706778	1E300A	1347 618709	DIANA EGOROVA	{"phone": "+70728674222"}
0005432706779	B24D18	2107 068102	ANASTASIYA NOVIKOVA	{"email": "anastasiyanovikova_26041976@postgrespro.ru", "phone": "+70441255420"}
0005432706780	B24D18	1566 487003	LEONTIY KARPOV	{"email": "l-karpov-29051985@postgrespro.ru", "phone": "+70660937629"}
0005432706781	77C92F	6535 717006	IVAN SMIRNOV	{"phone": "+70892166580"}
0005432706782	F248CB	3070 130068	IGOR MAKSIMOV	{"phone": "+70058613829"}
0005432706783	1169B1	6342 519176	ANTONINA MATVEEVA	{"email": "matveeva.a_29101971@postgrespro.ru", "phone": "+70636614451"}
0005432706784	1169B1	0760 775107	LIDIYA MAKSIMOVA	{"email": "lmaksimova_02101965@postgrespro.ru", "phone": "+70928100564"}
0005432706785	9575BC	9678 193067	ANNA MATVEEVA	{"phone": "+70551448225"}
0005432706786	9575BC	7695 200765	NINA LOGINOVA	{"phone": "+70731176825"}
0005432706787	CCBD86	7336 344931	VERA PETROVA	{"email": "petrova-v_121964@postgrespro.ru", "phone": "+70366663768"}
0005432706788	8B0246	9009 657577	ALEKSEY KUZMIN	{"phone": "+70171864882"}
0005432706789	C6CD20	7205 434885	ALEKSEY MIKHAYLOV	{"email": "aleksey.mikhaylov.23041963@postgrespro.ru", "phone": "+70199266492"}
0005432706790	B58852	4956 863344	NIKOLAY IVANOV	{"phone": "+70354088202"}
0005432706791	B58852	0853 709302	SOFYA ROMANOVA	{"email": "sofya-romanova17051979@postgrespro.ru", "phone": "+70940346939"}
0005432706792	501141	4302 269281	NATALYA KONOVALOVA	{"email": "n-konovalova.1983@postgrespro.ru", "phone": "+70270063025"}
0005432706793	7324DA	2361 301731	VIKTOR GERASIMOV	{"email": "gerasimov_viktor-121981@postgrespro.ru", "phone": "+70214529520"}
0005432706794	110F77	6348 707842	OLEG KISELEV	{"phone": "+70080026886"}
0005432706795	38F3D6	9353 243985	IRINA KUZMINA	{"phone": "+70798664810"}
0005432706796	950841	8727 293744	ANTONINA OSIPOVA	{"phone": "+70745966813"}
0005432706797	9E562F	0146 033078	ALEKSANDR KRASNOV	{"phone": "+70946236246"}
0005432706798	58EEBB	3541 812591	ALEKSANDR ZHUKOV	{"email": "aleksandr_zhukov1969@postgrespro.ru", "phone": "+70708647727"}
0005432706799	51E041	7370 498675	ALEKSANDR SIDOROV	{"phone": "+70556923871"}
0005432706800	B8EBB7	7985 326787	VARVARA DAVYDOVA	{"phone": "+70482689277"}
0005432706801	018954	4000 358581	VALENTINA DAVYDOVA	{"email": "davydova_valentina-02051964@postgrespro.ru", "phone": "+70253922252"}
0005432706802	23E509	4758 980446	SERGEY IVANOV	{"phone": "+70713078641"}
0005432706803	87CC37	4068 301248	OLGA SOLOVEVA	{"email": "solovevaolga.06101970@postgrespro.ru", "phone": "+70276887476"}
0005432706804	9007D5	2995 048566	DAMIR NIKITIN	{"email": "nikitin_d_011965@postgrespro.ru", "phone": "+70394248354"}
0005432706805	AD7553	0985 568089	NIKOLAY OSIPOV	{"phone": "+70169606482"}
0005432706806	AD7553	3556 518538	VALERIY NIKOLAEV	{"email": "nikolaevvaleriy.26031972@postgrespro.ru", "phone": "+70735243090"}
0005432706807	1C7192	8972 382624	SERGEY ILIN	{"email": "ilin.sergey-1966@postgrespro.ru", "phone": "+70464738726"}
0005432706808	15B492	8308 677043	ILYA KRASNOV	{"email": "krasnovilya-051964@postgrespro.ru", "phone": "+70329288536"}
0005432706809	AA1A33	9149 694523	ANZHELIKA MAKSIMOVA	{"email": "maksimova.anzhelika051963@postgrespro.ru", "phone": "+70795102944"}
0005432706810	8DEF9B	8838 762712	SVETLANA DAVYDOVA	{"email": "s.davydova26111971@postgrespro.ru", "phone": "+70111407755"}
0005432706811	8DEF9B	3355 637925	VALERIY ABRAMOV	{"phone": "+70632767037"}
0005432706812	802554	0489 823119	SOFYA GUSEVA	{"email": "guseva_sofya.11081987@postgrespro.ru", "phone": "+70388564917"}
0005432706813	802554	9495 464539	DANIYA SOKOLOVA	{"phone": "+70528929381"}
0005432706814	6A6B70	7839 529036	EVGENIY ANDREEV	{"email": "andreev_evgeniy_1969@postgrespro.ru", "phone": "+70260734393"}
0005432706815	DBDC72	8727 757714	DENIS MATVEEV	{"phone": "+70374553629"}
0005432706816	D78853	8458 197898	NADEZHDA MOROZOVA	{"phone": "+70646363052"}
0005432706817	143EFB	9047 446261	LYUBOV IVANOVA	{"phone": "+70425463792"}
0005432706818	6F4497	7358 588150	IGOR GUSEV	{"phone": "+70716938126"}
0005432706819	9F93E2	1201 322851	ANDREY CHERNOV	{"email": "chernov-a03021967@postgrespro.ru", "phone": "+70472228435"}
0005432706820	595DC7	4533 130499	VLADIMIR DENISOV	{"email": "denisov-vladimir101977@postgrespro.ru", "phone": "+70594229983"}
0005432706821	7145C6	4814 099392	GALINA ALEKSANDROVA	{"phone": "+70970916251"}
0005432706822	0B823A	9588 420518	NATALYA IVANOVA	{"phone": "+70596670705"}
0005432706823	221CC8	9925 042617	SERGEY SHEVCHENKO	{"email": "shevchenko_s30091967@postgrespro.ru", "phone": "+70615813277"}
0005432706824	095664	4056 367956	YURIY KUDRYASHOV	{"email": "kudryashov-yuriy-24081964@postgrespro.ru", "phone": "+70043734130"}
0005432706825	EA9BF6	1573 541827	ALENA CHERNOVA	{"email": "chernovaa-16091975@postgrespro.ru", "phone": "+70547651159"}
0005432706826	0770E3	7738 197631	ALEKSANDR DMITRIEV	{"email": "admitriev_1970@postgrespro.ru", "phone": "+70799503892"}
0005432706827	1D6013	9613 369166	EDUARD SAVELEV	{"email": "savelev_e.1967@postgrespro.ru", "phone": "+70216228188"}
0005432706828	1D6013	6297 620376	NATALYA NIKITINA	{"phone": "+70846069380"}
0005432706829	1D6013	9768 557340	TAMARA PETROVA	{"phone": "+70369208267"}
0005432706830	071CD5	7897 596139	VLADIMIR GORBUNOV	{"phone": "+70078973840"}
0005432706831	141DB0	5091 147277	ARTEM PETROV	{"phone": "+70348737290"}
0005432706832	F18457	3015 863396	ALEKSANDR NIKOLAEV	{"phone": "+70739343356"}
0005432706833	92CF57	0406 116503	MARGARITA MAKSIMOVA	{"email": "m.maksimova_12041971@postgrespro.ru", "phone": "+70198976476"}
0005432706834	92CF57	9282 677079	ANASTASIYA DENISOVA	{"phone": "+70864560743"}
0005432706835	C21027	6364 180186	TATYANA ISAEVA	{"phone": "+70887941307"}
0005432706836	7A952B	1760 539614	ALEKSANDRA BARANOVA	{"email": "aleksandra_baranova-07121975@postgrespro.ru", "phone": "+70349683517"}
0005432706837	5258F2	7766 105147	OLGA SEMENOVA	{"email": "olgasemenova_1967@postgrespro.ru", "phone": "+70831678629"}
0005432706838	F411AF	5028 324507	BORIS ALEKSEEV	{"phone": "+70144427994"}
0005432706839	BCE456	8930 978545	LARISA POLYAKOVA	{"email": "l_polyakova-14121955@postgrespro.ru", "phone": "+70873957779"}
0005432706840	264931	2465 959683	YULIYA MOROZOVA	{"email": "morozova.yuliya-29121977@postgrespro.ru", "phone": "+70638222617"}
0005432706841	09D934	3310 447186	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya-08101967@postgrespro.ru", "phone": "+70551951581"}
0005432706842	587D6B	9351 047124	ELENA POTAPOVA	{"phone": "+70805583420"}
0005432706843	587D6B	3517 021110	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya-mikhaylova1974@postgrespro.ru", "phone": "+70586910824"}
0005432707010	925B9D	2226 461159	MARIYA NAUMOVA	{"phone": "+70467981237"}
0005432706844	24233F	6351 693248	VLADIMIR VOLKOV	{"email": "v-volkov.29031975@postgrespro.ru", "phone": "+70588380740"}
0005432706845	F55212	7748 480916	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev-11111962@postgrespro.ru", "phone": "+70460269328"}
0005432706846	9D3BEF	9254 693329	ELIZAVETA FADEEVA	{"email": "elizaveta_fadeeva-1960@postgrespro.ru", "phone": "+70057543844"}
0005432706847	9D3BEF	9826 297593	GENNADIY KUZNECOV	{"email": "kuznecov.gennadiy20011966@postgrespro.ru", "phone": "+70526892980"}
0005432706848	DCB0D7	4843 339330	TAMARA FROLOVA	{"email": "t-frolova1976@postgrespro.ru", "phone": "+70413340683"}
0005432706849	32FB9E	3921 897739	ZOYA BELOVA	{"email": "belova.z_1979@postgrespro.ru", "phone": "+70667495896"}
0005432706850	F75F3C	8735 608170	SERGEY IVANOV	{"phone": "+70607532349"}
0005432706851	52E36A	0967 101892	IRINA MOROZOVA	{"email": "irina_morozova.1979@postgrespro.ru", "phone": "+70724718666"}
0005432706852	52E36A	8734 974012	EVGENIYA KUZNECOVA	{"email": "e.kuznecova.1973@postgrespro.ru", "phone": "+70307004004"}
0005432706853	5E84A7	2318 073440	LYUDMILA ANDREEVA	{"email": "lyudmila_andreeva1968@postgrespro.ru", "phone": "+70972799398"}
0005432706854	607651	1123 883907	TATYANA TIKHONOVA	{"email": "t-tikhonova20021964@postgrespro.ru", "phone": "+70012490767"}
0005432706855	252F57	0061 507067	GENNADIY VOLKOV	{"phone": "+70271990001"}
0005432706856	252F57	6635 769581	EVGENIY DENISOV	{"email": "denisov_evgeniy051970@postgrespro.ru", "phone": "+70703615539"}
0005432706857	AA186F	9927 318632	LYUDMILA NIKOLAEVA	{"email": "l.nikolaeva.16121977@postgrespro.ru", "phone": "+70805536676"}
0005432706858	AA186F	0152 518465	ANTONINA SERGEEVA	{"email": "sergeevaa.071979@postgrespro.ru", "phone": "+70859237529"}
0005432706859	B02830	7784 441779	VIKTOR AFANASEV	{"phone": "+70443213060"}
0005432706860	A43B73	9989 748193	ANNA MAKAROVA	{"email": "amakarova_1972@postgrespro.ru", "phone": "+70337768067"}
0005432706861	020D43	7454 737123	VIKTOR GRIGOREV	{"email": "grigorev.v.1972@postgrespro.ru", "phone": "+70511298871"}
0005432706862	020D43	0233 376070	YAROSLAV GUSEV	{"phone": "+70370662843"}
0005432706863	3C1F99	0069 236391	VALENTINA POPOVA	{"email": "popova.v.031973@postgrespro.ru", "phone": "+70374636922"}
0005432706864	3C1F99	9395 969236	EDUARD MAKAROV	{"email": "makarov.e-061972@postgrespro.ru", "phone": "+70696708680"}
0005432706865	F75E7E	8808 471457	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova.02081975@postgrespro.ru", "phone": "+70727920982"}
0005432706866	11606F	0614 317095	SVETLANA MASLOVA	{"email": "s-maslova_22011968@postgrespro.ru", "phone": "+70327481400"}
0005432706867	11606F	5783 809664	KSENIYA ZOTOVA	{"phone": "+70920607671"}
0005432706868	BADC85	7228 845716	VIKTOR NIKITIN	{"phone": "+70495245534"}
0005432706869	75812F	4235 039182	SERGEY SOKOLOV	{"email": "sokolovs.06011973@postgrespro.ru", "phone": "+70146260743"}
0005432706870	9CE248	9604 564344	ANDREY MIKHAYLOV	{"phone": "+70731289084"}
0005432706871	9CE248	0707 347177	VERA PETROVA	{"email": "petrova_v.071977@postgrespro.ru", "phone": "+70370683983"}
0005432706872	474074	3579 670266	TATYANA CHERNOVA	{"phone": "+70859811781"}
0005432706873	474074	0244 474469	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.041973@postgrespro.ru", "phone": "+70324831038"}
0005432706874	A4AF66	8499 864204	NATALYA NESTEROVA	{"email": "natalyanesterova_1968@postgrespro.ru", "phone": "+70281717568"}
0005432706875	29D1C5	1702 411645	VERA NESTEROVA	{"phone": "+70211408786"}
0005432706876	E096D4	6405 825613	ALEKSANDRA GAVRILOVA	{"phone": "+70515032170"}
0005432706877	E096D4	5471 659369	IRINA IVANOVA	{"phone": "+70619254838"}
0005432706878	500440	6260 744651	NATALYA DAVYDOVA	{"phone": "+70570265398"}
0005432706879	500440	2312 495322	ALEKSEY ANDREEV	{"phone": "+70852083889"}
0005432706880	9BEA24	9112 676094	ALSU IVANOVA	{"phone": "+70126532199"}
0005432706881	270564	9539 609533	NINA POPOVA	{"phone": "+70980359794"}
0005432706882	270564	0259 208615	ELENA NIKOLAEVA	{"email": "elenanikolaeva_011971@postgrespro.ru", "phone": "+70977840482"}
0005432706883	2A7DEC	1317 258176	EKATERINA KOMAROVA	{"email": "ekaterinakomarova.1979@postgrespro.ru", "phone": "+70755535554"}
0005432706884	24C311	9928 090142	VASILIY DMITRIEV	{"email": "dmitriev-vasiliy.1980@postgrespro.ru", "phone": "+70880239603"}
0005432706885	24C311	6851 646891	PAVEL FROLOV	{"phone": "+70635249508"}
0005432706886	5D31CA	5051 969367	MARIYA VOROBEVA	{"email": "mvorobeva.1982@postgrespro.ru", "phone": "+70146564118"}
0005432706887	029B90	4729 666801	MARINA KOZLOVA	{"email": "kozlova.m_1982@postgrespro.ru", "phone": "+70018640060"}
0005432706888	029B90	5020 880526	ANNA MELNIKOVA	{"email": "a.melnikova-22031977@postgrespro.ru", "phone": "+70114096937"}
0005432706889	C4EE3B	8180 474165	ELIZAVETA EGOROVA	{"email": "elizavetaegorova_1975@postgrespro.ru", "phone": "+70754101861"}
0005432706890	C4EE3B	3922 724743	RUSLAN SIDOROV	{"email": "ruslansidorov-21091970@postgrespro.ru", "phone": "+70819930046"}
0005432706891	EE250B	4610 581833	NATALIYA IVANOVA	{"phone": "+70579760086"}
0005432706892	8BCB2B	8049 783067	LARISA KOZLOVA	{"email": "kozlova-l-1969@postgrespro.ru", "phone": "+70859354099"}
0005432706893	8BCB2B	1682 178557	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova_101973@postgrespro.ru", "phone": "+70017532778"}
0005432706894	D159E8	9344 872779	MIKHAIL MEDVEDEV	{"email": "medvedev-m.1988@postgrespro.ru", "phone": "+70822567324"}
0005432706895	79645E	0548 452363	RADIK PETROV	{"phone": "+70541999745"}
0005432706896	C5B78A	9100 516051	PETR NIKITIN	{"phone": "+70628158899"}
0005432706897	D4BEC5	1273 409372	ALEKSANDR KISELEV	{"phone": "+70105267749"}
0005432706898	2BB44B	7363 175663	TAMARA BELOVA	{"email": "belova.tamara.021970@postgrespro.ru", "phone": "+70128207458"}
0005432706899	2BB44B	5460 744612	KIRILL GERASIMOV	{"email": "k-gerasimov.25011967@postgrespro.ru", "phone": "+70221927695"}
0005432706900	92FFE0	4777 038749	OLEG BORISOV	{"phone": "+70304599175"}
0005432706901	C8EE8D	8831 711671	MAKSIM SAVELEV	{"email": "m_savelev.26061973@postgrespro.ru", "phone": "+70755849702"}
0005432706902	C8EE8D	6573 556278	SERGEY GUSEV	{"email": "gusevs-15061964@postgrespro.ru", "phone": "+70799074362"}
0005432706903	5F2231	4915 103332	TATYANA PETROVA	{"phone": "+70227237168"}
0005432706904	5F2231	2229 572369	VALERIYA EGOROVA	{"phone": "+70042148144"}
0005432706905	CE3937	7775 888144	ANTON POPOV	{"phone": "+70184746165"}
0005432706906	0A2DF7	9184 208025	ALEKSEY SAVELEV	{"phone": "+70719227708"}
0005432706907	137E1C	7479 270965	SVETLANA BELOVA	{"email": "belovas_05041967@postgrespro.ru", "phone": "+70047647776"}
0005432706908	F73CCF	0109 485301	ANASTASIYA VOLKOVA	{"phone": "+70670710579"}
0005432706909	98159A	8257 941659	EGOR OSIPOV	{"email": "osipov-egor-28011964@postgrespro.ru", "phone": "+70724778809"}
0005432706910	D390C2	4862 377236	NINEL SOROKINA	{"email": "n_sorokina_011960@postgrespro.ru", "phone": "+70966190574"}
0005432706911	042A92	3341 210026	TAISIYA IVANOVA	{"phone": "+70222846758"}
0005432706912	1EB717	4736 168837	IGOR SOROKIN	{"phone": "+70549171837"}
0005432706913	FCF878	1299 432443	ALEKSANDR ABRAMOV	{"phone": "+70944415948"}
0005432706914	FCF878	4107 640354	TATYANA FILATOVA	{"phone": "+70301852371"}
0005432706915	E7757F	3221 844621	NIKITA OSIPOV	{"email": "nikita_osipov-1973@postgrespro.ru", "phone": "+70377581304"}
0005432706916	E7757F	8176 552890	ANNA VOLKOVA	{"phone": "+70221970829"}
0005432706917	489B57	2218 985812	VALENTINA KOMAROVA	{"email": "v.komarova-1968@postgrespro.ru", "phone": "+70586083363"}
0005432706918	11250D	3811 106952	NATALYA GRISHINA	{"phone": "+70905520415"}
0005432706919	E89C05	3585 681273	NATALYA ALEKSEEVA	{"email": "natalyaalekseeva_1967@postgrespro.ru", "phone": "+70662925470"}
0005432706920	E89C05	9484 223751	ANASTASIYA MELNIKOVA	{"email": "melnikova.a-061969@postgrespro.ru", "phone": "+70119574509"}
0005432706921	E89C05	7007 380215	TATYANA ZAKHAROVA	{"phone": "+70438926255"}
0005432706922	015E11	8479 580839	ARTUR DENISOV	{"email": "arturdenisov-1965@postgrespro.ru", "phone": "+70376993716"}
0005432706923	9688B6	8899 989949	SERAFIMA POPOVA	{"phone": "+70523380065"}
0005432706924	AC54BA	9545 561786	NADEZHDA SEMENOVA	{"email": "semenova_nadezhda.1960@postgrespro.ru", "phone": "+70993000915"}
0005432706925	AA1843	2673 549598	OKSANA KONDRATEVA	{"phone": "+70136245135"}
0005432706926	88A746	4862 539917	FEDOR SCHERBAKOV	{"email": "scherbakov.fedor031965@postgrespro.ru", "phone": "+70318105911"}
0005432706927	B3EB19	5394 764000	TATYANA MAKAROVA	{"email": "t-makarova_1958@postgrespro.ru", "phone": "+70541527765"}
0005432706928	A88709	9066 070074	NIKOLAY ORLOV	{"phone": "+70589789003"}
0005432706929	FBDBE8	2450 185501	SVETLANA SOKOLOVA	{"email": "s-sokolova.18041973@postgrespro.ru", "phone": "+70156040898"}
0005432706930	F229DB	0719 369559	KRISTINA RYABOVA	{"email": "kristina.ryabova111970@postgrespro.ru", "phone": "+70848038812"}
0005432706931	4C09C6	5207 234709	GULFIYA POPOVA	{"phone": "+70981675285"}
0005432706932	4C09C6	2550 986578	OLGA ERMAKOVA	{"email": "ermakova.olga-28061967@postgrespro.ru", "phone": "+70589659982"}
0005432706933	727B97	8488 564964	NATALYA NOVIKOVA	{"email": "natalyanovikova-16081976@postgrespro.ru", "phone": "+70187725322"}
0005432706934	B7A0E8	1981 433996	ANASTASIYA ZHURAVLEVA	{"phone": "+70179844486"}
0005432706935	49C75B	3900 300271	ROZALIYA ZAYCEVA	{"phone": "+70671674059"}
0005432706936	BF6BFA	2006 257209	ALEKSANDR POPOV	{"phone": "+70469057844"}
0005432706937	BF6BFA	0211 566430	SERGEY MIKHAYLOV	{"phone": "+70590217228"}
0005432706938	A9C813	5493 499405	ALEKSANDR TARASOV	{"email": "tarasov.a_1979@postgrespro.ru", "phone": "+70105665064"}
0005432706939	A9C813	9387 567843	ALEKSANDR TIKHONOV	{"email": "a-tikhonov.1991@postgrespro.ru", "phone": "+70545315024"}
0005432706940	4781FC	7062 692739	VLADIMIR PAVLOV	{"phone": "+70036418218"}
0005432706941	4781FC	5556 441682	VLADIMIR ZAKHAROV	{"email": "v_zakharov-31101969@postgrespro.ru", "phone": "+70713325539"}
0005432706942	C2B6A7	4791 399809	IRINA DANILOVA	{"email": "danilova.i1978@postgrespro.ru", "phone": "+70868872948"}
0005432706943	26F252	6402 807334	LYUDMILA MATVEEVA	{"email": "l_matveeva-05051973@postgrespro.ru", "phone": "+70252690883"}
0005432706944	1E042D	6527 585876	ALEKSEY SEMENOV	{"email": "semenov_a-19041978@postgrespro.ru", "phone": "+70105691118"}
0005432706945	51F9E3	0103 110876	SVETLANA BARANOVA	{"email": "svetlana.baranova.08051965@postgrespro.ru", "phone": "+70403270483"}
0005432706946	F05143	8397 302372	SERGEY GAVRILOV	{"email": "gavrilov.s121977@postgrespro.ru", "phone": "+70334747225"}
0005432706947	80D1C0	9738 389247	LILIYA MIKHAYLOVA	{"phone": "+70375212312"}
0005432707064	8DFB56	9319 843215	ANNA SEMENOVA	{"phone": "+70625767878"}
0005432706948	80D1C0	5134 269565	EVGENIYA KISELEVA	{"email": "kiseleva-evgeniya_18121986@postgrespro.ru", "phone": "+70502444848"}
0005432706949	E7D463	8512 508023	SERGEY ANDREEV	{"phone": "+70860079325"}
0005432706950	B85AF9	8878 248231	ILFAT MOROZOV	{"phone": "+70884461467"}
0005432706951	B85AF9	0709 456217	SERGEY ANDREEV	{"phone": "+70137293436"}
0005432706952	FD9D47	7267 563380	ANNA DANILOVA	{"phone": "+70173923632"}
0005432706953	FD9D47	4696 166955	ALEKSANDR AFANASEV	{"email": "afanaseva1969@postgrespro.ru", "phone": "+70217963137"}
0005432706954	0FD491	2904 928659	TAMARA SMIRNOVA	{"email": "tamarasmirnova_1978@postgrespro.ru", "phone": "+70704463768"}
0005432706955	BF6B81	5996 497471	VLADIMIR DENISOV	{"email": "vladimir-denisov.1971@postgrespro.ru", "phone": "+70562168716"}
0005432706956	E0580E	8647 470350	NINA KAZAKOVA	{"phone": "+70171670141"}
0005432706957	0F79AC	8178 387697	NIKOLAY NIKITIN	{"email": "nikitinnikolay.28071979@postgrespro.ru", "phone": "+70611996496"}
0005432706958	E25550	1816 549245	VLADISLAV KUDRYASHOV	{"email": "v-kudryashov_11031968@postgrespro.ru", "phone": "+70385959677"}
0005432706959	E25550	4743 355436	OLGA KARPOVA	{"email": "olgakarpova-011975@postgrespro.ru", "phone": "+70397687056"}
0005432706960	029624	9728 642824	VERA KONOVALOVA	{"phone": "+70466721484"}
0005432706961	8E4C60	5058 273529	VALERIY RODIONOV	{"email": "rodionov.valeriy_121976@postgrespro.ru", "phone": "+70260041021"}
0005432706962	8E4C60	8901 185147	EDUARD KUZMIN	{"email": "kuzmin-eduard_111977@postgrespro.ru", "phone": "+70724362514"}
0005432706963	AE43CE	0595 189763	YURIY SCHERBAKOV	{"email": "scherbakov.y_1975@postgrespro.ru", "phone": "+70687483665"}
0005432706964	9EEAFE	4702 241100	MARINA VLASOVA	{"email": "vlasova-marina-14101971@postgrespro.ru", "phone": "+70512331007"}
0005432706965	A29C1D	8634 515414	YURIY SMIRNOV	{"phone": "+70495285415"}
0005432706966	84F9CF	4913 980050	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr_071973@postgrespro.ru", "phone": "+70905584853"}
0005432706967	A33BF6	7859 296075	VALERIY KONOVALOV	{"phone": "+70438732970"}
0005432706968	75E429	5438 021677	STANISLAV IVANOV	{"email": "s.ivanov.071974@postgrespro.ru", "phone": "+70539955011"}
0005432706969	E3F2B8	3776 936506	MARIYA SOROKINA	{"phone": "+70172167409"}
0005432706970	853062	7441 456964	ANASTASIYA STEPANOVA	{"email": "stepanova.anastasiya_26121977@postgrespro.ru", "phone": "+70856210826"}
0005432707473	FDC56C	2658 825254	SERGEY DAVYDOV	{"phone": "+70782283777"}
0005432706971	D7BE7E	5128 260408	PETR MAKSIMOV	{"email": "p.maksimov_041970@postgrespro.ru", "phone": "+70853634142"}
0005432706972	F0DC1B	5440 872400	IVAN BARANOV	{"email": "i-baranov1978@postgrespro.ru", "phone": "+70151529994"}
0005432706973	24AE57	4599 735123	ELIZAVETA BARANOVA	{"email": "elizaveta_baranova-1972@postgrespro.ru", "phone": "+70786857277"}
0005432706974	ABA1EB	5777 516018	ALEKSANDR YAKOVLEV	{"phone": "+70970760869"}
0005432706975	5CBD6D	9352 227164	DMITRIY MIKHAYLOV	{"phone": "+70804905716"}
0005432706976	5CBD6D	6492 404837	MARIYA SMIRNOVA	{"email": "mariya_smirnova.27091978@postgrespro.ru", "phone": "+70134926123"}
0005432706977	DDA0C6	7255 262711	VLADIMIR SMIRNOV	{"phone": "+70732437315"}
0005432706978	DDA0C6	3076 362975	DARYA VLASOVA	{"email": "darya.vlasova_19101971@postgrespro.ru", "phone": "+70013833166"}
0005432706979	1C9EE6	0056 044826	ANASTASIYA DANILOVA	{"email": "anastasiya.danilova.1973@postgrespro.ru", "phone": "+70361816502"}
0005432706980	CC69B8	8364 693645	ANNA OSIPOVA	{"phone": "+70718376450"}
0005432706981	CC69B8	4164 824638	ARTEM DMITRIEV	{"phone": "+70629338624"}
0005432706982	5F2D2F	0065 602770	NIKOLAY VOROBEV	{"email": "vorobev.n.111979@postgrespro.ru", "phone": "+70428936305"}
0005432706983	5F2D2F	3504 396005	DANIIL ZHUKOV	{"email": "d-zhukov-1965@postgrespro.ru", "phone": "+70997126797"}
0005432706984	8AF8AA	1617 991778	MARIYA MELNIKOVA	{"phone": "+70985913875"}
0005432706985	8AF8AA	6920 271956	OKSANA ZAYCEVA	{"email": "zaycevao-021967@postgrespro.ru", "phone": "+70160742077"}
0005432706986	52FB4E	8286 214543	ALEKSEY VOROBEV	{"email": "aleksey-vorobev-15041980@postgrespro.ru", "phone": "+70658250466"}
0005432706987	D3C2D8	5225 033049	NIKOLAY NAZAROV	{"phone": "+70348133318"}
0005432706988	BA9AA9	0703 138133	RINAT MATVEEV	{"email": "matveev.rinat_07101968@postgrespro.ru", "phone": "+70613378952"}
0005432706989	7BF208	8705 520300	ANNA STEPANOVA	{"email": "astepanova-1966@postgrespro.ru", "phone": "+70767724550"}
0005432706990	8CB848	8312 577827	KIRA MIRONOVA	{"email": "k.mironova_121972@postgrespro.ru", "phone": "+70506434709"}
0005432706991	8CB848	7830 132802	ALEKSANDR NAUMOV	{"phone": "+70267325909"}
0005432706992	8CB848	7270 340688	NADEZHDA ORLOVA	{"email": "orlova-nadezhda.031976@postgrespro.ru", "phone": "+70007636843"}
0005432706993	BFA6F9	2402 950499	NATALYA MOROZOVA	{"phone": "+70353766678"}
0005432706994	7F7DBA	7972 444363	DINA SAVELEVA	{"email": "dsaveleva.071973@postgrespro.ru", "phone": "+70332399951"}
0005432706995	7F7DBA	0397 385700	NIKOLAY BARANOV	{"email": "nikolay_baranov-1976@postgrespro.ru", "phone": "+70068929414"}
0005432706996	C5376B	5469 044599	YURIY KRASNOV	{"phone": "+70248149149"}
0005432706997	C5376B	9896 147572	NIKOLAY KUZNECOV	{"phone": "+70509137196"}
0005432706998	D6E9B2	3394 230612	VALERIYA SOKOLOVA	{"email": "v.sokolova1975@postgrespro.ru", "phone": "+70169003133"}
0005432706999	F0BC3D	9533 309000	RAISA MEDVEDEVA	{"phone": "+70359092388"}
0005432707000	54B01A	4960 378937	MIKHAIL DAVYDOV	{"email": "davydov_mikhail121965@postgrespro.ru", "phone": "+70779375270"}
0005432707001	E8DF42	0654 077128	STANISLAV MARTYNOV	{"phone": "+70850346448"}
0005432707002	9C20D6	0417 118598	VERA MOROZOVA	{"email": "v-morozova_021984@postgrespro.ru", "phone": "+70551643360"}
0005432707003	7564F8	1444 418025	ALEKSANDR FROLOV	{"phone": "+70749730450"}
0005432707004	7564F8	8672 527301	MARINA CHERNOVA	{"email": "marina.chernova19041973@postgrespro.ru", "phone": "+70784771788"}
0005432707187	BF1A89	5732 295422	ANDREY MARTYNOV	{"phone": "+70167744666"}
0005432707005	4CB3D7	0584 844550	GENNADIY KULIKOV	{"email": "g.kulikov-1973@postgrespro.ru", "phone": "+70878457311"}
0005432707006	0CDF37	4108 865649	TATYANA MAKAROVA	{"email": "makarovat-1969@postgrespro.ru", "phone": "+70838141770"}
0005432707007	7A483B	2955 923105	SVETLANA ILINA	{"phone": "+70937655514"}
0005432707008	E2A000	3977 974416	VITALIY NAZAROV	{"phone": "+70095843826"}
0005432707009	E2A000	3334 365610	VARVARA KOROLEVA	{"email": "varvara-koroleva-15051967@postgrespro.ru", "phone": "+70295552064"}
0005432707011	925B9D	3408 276936	DAVID GORBUNOV	{"email": "gorbunovdavid_15051973@postgrespro.ru", "phone": "+70913109804"}
0005432707012	3A106A	8806 482810	RAISA ORLOVA	{"email": "r-orlova061976@postgrespro.ru", "phone": "+70334213429"}
0005432707013	1BFBFA	6569 074216	NADEZHDA SAVELEVA	{"email": "saveleva.nadezhda.1976@postgrespro.ru", "phone": "+70733423652"}
0005432707014	1BFBFA	5909 301609	ALENA BOGDANOVA	{"email": "bogdanova_a.08011975@postgrespro.ru", "phone": "+70424881178"}
0005432707015	F2F0F8	5114 006667	EKATERINA BOGDANOVA	{"phone": "+70342386913"}
0005432707016	30E267	4947 540312	LYUBOV YAKOVLEVA	{"email": "yakovleva-lyubov.1976@postgrespro.ru", "phone": "+70414060581"}
0005432707017	30E267	3100 933331	SVETLANA CHERNOVA	{"phone": "+70927507390"}
0005432707018	30E267	5642 090941	TATYANA VLASOVA	{"email": "t.vlasova-15071971@postgrespro.ru", "phone": "+70801213632"}
0005432707019	06F808	2349 510556	EKATERINA ANTONOVA	{"phone": "+70265153483"}
0005432707020	082D4F	6565 712494	RUSLAN DAVYDOV	{"email": "davydov_r.25071972@postgrespro.ru", "phone": "+70215956721"}
0005432707021	E112BC	4138 161363	VERONIKA BOGDANOVA	{"phone": "+70155254228"}
0005432707022	E112BC	0695 752750	VLADIMIR KUZNECOV	{"phone": "+70377094058"}
0005432707023	E112BC	8659 770944	DENIS KAZAKOV	{"email": "d.kazakov1963@postgrespro.ru", "phone": "+70159590898"}
0005432707024	ACBCC9	1027 571069	NATALYA KUZNECOVA	{"email": "natalya-kuznecova.07021967@postgrespro.ru", "phone": "+70633100403"}
0005432707025	ACBCC9	7934 149555	KAROLINA ABRAMOVA	{"phone": "+70261496260"}
0005432707026	7B2663	0264 210129	NINA GUSEVA	{"phone": "+70904257375"}
0005432707474	9FA176	6961 421072	RAFAIL ANTONOV	{"phone": "+70127865715"}
0005432707027	7B2663	7296 500069	EVGENIY TIMOFEEV	{"email": "timofeev_e.05081970@postgrespro.ru", "phone": "+70702510448"}
0005432707028	F7104D	1630 195351	ALEKSANDR IVANOV	{"phone": "+70063830723"}
0005432707029	F7104D	5735 391007	MARIYA GERASIMOVA	{"phone": "+70801815880"}
0005432707030	749089	1426 175288	OLEG NIKITIN	{"phone": "+70344020769"}
0005432707031	4CC777	6821 916122	VALERIY MAKSIMOV	{"email": "maksimov.v.19021986@postgrespro.ru", "phone": "+70754467617"}
0005432707032	4CC777	1110 949421	GALINA KOMAROVA	{"phone": "+70962255312"}
0005432707033	8B5924	8091 707015	SERGEY MELNIKOV	{"email": "melnikov-sergey071967@postgrespro.ru", "phone": "+70925401512"}
0005432707034	8B5924	4048 767545	ELENA KOZLOVA	{"email": "elena_kozlova-1966@postgrespro.ru", "phone": "+70751471566"}
0005432707035	CBD761	7930 903489	OLGA FADEEVA	{"phone": "+70986366758"}
0005432707036	2B62B4	0213 997508	DMITRIY GUSEV	{"email": "gusev_dmitriy_101968@postgrespro.ru", "phone": "+70854793621"}
0005432707037	2B62B4	1995 435808	SVETLANA NIKIFOROVA	{"email": "svetlana-nikiforova-051975@postgrespro.ru", "phone": "+70990746419"}
0005432707038	35C6D0	4404 890705	SERGEY IVANOV	{"email": "sergey_ivanov20031975@postgrespro.ru", "phone": "+70866787277"}
0005432707039	C1044D	2012 243677	ALEKSANDR KOZLOV	{"phone": "+70702835211"}
0005432707040	FA16CE	0249 095334	EGOR TIKHONOV	{"email": "egor-tikhonov-051976@postgrespro.ru", "phone": "+70659878103"}
0005432707041	39564D	7832 827638	DARYA MAKSIMOVA	{"email": "dmaksimova_1967@postgrespro.ru", "phone": "+70020509164"}
0005432707042	09C459	3966 674591	YULIYA TIKHONOVA	{"phone": "+70640431693"}
0005432707043	04A3DE	5925 643229	OLGA TARASOVA	{"email": "o-tarasova_051972@postgrespro.ru", "phone": "+70343471436"}
0005432707044	186286	4333 107973	ZULFIYA LUKYANOVA	{"phone": "+70807263469"}
0005432707045	EC154F	3678 315657	VERA YAKOVLEVA	{"email": "yakovlevavera.061978@postgrespro.ru", "phone": "+70803577280"}
0005432707046	265103	6966 274469	VIKTOR BORISOV	{"email": "borisov_v.071959@postgrespro.ru", "phone": "+70135396075"}
0005432707047	296AC8	3494 670624	NIKOLAY IVANOV	{"phone": "+70304499371"}
0005432707048	296AC8	9272 330300	DMITRIY ANTONOV	{"phone": "+70663665230"}
0005432707049	296AC8	9874 030302	SERGEY NAZAROV	{"email": "s.nazarov_1969@postgrespro.ru", "phone": "+70482629568"}
0005432707050	B7F271	4778 878412	OLEG ALEKSANDROV	{"email": "oaleksandrov-19061973@postgrespro.ru", "phone": "+70170039351"}
0005432707051	B7F271	3617 338466	DENIS RODIONOV	{"phone": "+70357343133"}
0005432707052	14ADB3	7197 498123	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin-27111974@postgrespro.ru", "phone": "+70705135580"}
0005432707053	14ADB3	2774 874083	NADEZHDA IVANOVA	{"phone": "+70979295907"}
0005432707054	FF401A	5848 266247	VLADIMIR SERGEEV	{"email": "sergeev-vladimir1972@postgrespro.ru", "phone": "+70685723647"}
0005432707055	FF401A	2407 799529	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikova_v021976@postgrespro.ru", "phone": "+70701908730"}
0005432707056	A226E5	1943 020077	NIKOLAY FEDOROV	{"phone": "+70433525691"}
0005432707057	9FD7A6	0984 206889	VLADIMIR MAKSIMOV	{"email": "maksimov_vladimir.091968@postgrespro.ru", "phone": "+70066292998"}
0005432707058	93D14E	0334 997902	VALENTINA NAUMOVA	{"phone": "+70125060884"}
0005432707059	5D246A	7539 738195	SERGEY NAZAROV	{"email": "sergey.nazarov-17101970@postgrespro.ru", "phone": "+70145655066"}
0005432707060	474677	3767 100591	SERGEY ANDREEV	{"phone": "+70620328942"}
0005432707061	5A95B7	6578 997770	LYUDMILA KARPOVA	{"email": "karpoval_01031965@postgrespro.ru", "phone": "+70462149782"}
0005432707062	184506	0404 132553	SVETLANA LAZAREVA	{"email": "lazareva.s_1972@postgrespro.ru", "phone": "+70396016127"}
0005432707063	9776FE	5436 765235	SERGEY DENISOV	{"email": "sergey-denisov-091972@postgrespro.ru", "phone": "+70618748205"}
0005432707065	8DFB56	4908 285575	YURIY VOLKOV	{"email": "volkovyuriy-22011974@postgrespro.ru", "phone": "+70660718705"}
0005432707066	2A72D7	5930 405593	IRINA MASLOVA	{"phone": "+70606696878"}
0005432707067	4B3861	2555 016091	OLGA VOLKOVA	{"phone": "+70293302988"}
0005432707068	7605F3	2279 772939	EVGENIYA IVANOVA	{"email": "ivanova-e17111970@postgrespro.ru", "phone": "+70898555501"}
0005432707069	A0028B	9050 688196	ANTONINA PETROVA	{"email": "antoninapetrova.1975@postgrespro.ru", "phone": "+70362353823"}
0005432707070	A0028B	2252 030923	OLGA KULIKOVA	{"email": "o-kulikova_031967@postgrespro.ru", "phone": "+70038200493"}
0005432707071	972FF4	8802 780406	SERGEY STEPANOV	{"email": "stepanov-s_31121977@postgrespro.ru", "phone": "+70871850312"}
0005432707072	972FF4	5280 183317	ALEKSEY MOROZOV	{"phone": "+70957589079"}
0005432707073	972FF4	8671 480394	NATALYA LOGINOVA	{"phone": "+70837590278"}
0005432707074	22485B	7783 713310	ELENA IVANOVA	{"phone": "+70376961958"}
0005432707075	B567CD	4131 605374	LYUBOV KARPOVA	{"phone": "+70818794163"}
0005432707076	FCF97C	5712 044955	VALENTINA NIKOLAEVA	{"email": "valentina.nikolaeva_1966@postgrespro.ru", "phone": "+70175624820"}
0005432707077	D05BB4	1597 214870	DANIL PAVLOV	{"email": "dpavlov_18111986@postgrespro.ru", "phone": "+70981060277"}
0005432707078	D05BB4	1333 304867	LARISA POPOVA	{"phone": "+70202772411"}
0005432707079	46E703	0956 040787	VALENTINA YUDINA	{"phone": "+70234671138"}
0005432707080	46E703	0899 239992	EGOR VOROBEV	{"phone": "+70296501615"}
0005432707081	46E703	7502 104221	EKATERINA ILINA	{"phone": "+70426117312"}
0005432707082	8228A5	4447 038592	LILIYA KULIKOVA	{"email": "kulikova.l.021965@postgrespro.ru", "phone": "+70582195064"}
0005432707083	8228A5	2875 298778	YULIYA YUDINA	{"email": "yudinayuliya-1968@postgrespro.ru", "phone": "+70159396739"}
0005432707084	33C9F5	9042 846916	VIKTOR KUZMIN	{"phone": "+70401010923"}
0005432707085	33C9F5	3525 086651	SERGEY DAVYDOV	{"phone": "+70840642640"}
0005432707086	D792F0	2602 840766	SVETLANA BELOVA	{"phone": "+70814230387"}
0005432707087	B94450	3338 991559	PETR SOKOLOV	{"email": "sokolov_petr-1969@postgrespro.ru", "phone": "+70850559403"}
0005432707088	9DD8A9	6487 546670	VLADIMIR IVANOV	{"email": "ivanov-vladimir02031975@postgrespro.ru", "phone": "+70001612994"}
0005432707089	9DD8A9	6433 033996	YURIY STEPANOV	{"phone": "+70657992081"}
0005432707090	9DD8A9	3688 343818	ANTON NIKITIN	{"email": "a.nikitin-061976@postgrespro.ru", "phone": "+70389325756"}
0005432707091	EDC82C	1643 084191	EVGENIYA KOROLEVA	{"email": "korolevaevgeniya.121974@postgrespro.ru", "phone": "+70481668815"}
0005432707092	B8DA8D	0353 025076	ELENA ANISIMOVA	{"email": "anisimova.elena_031972@postgrespro.ru", "phone": "+70652709182"}
0005432707093	C2A462	1147 901706	SVETLANA KUZNECOVA	{"email": "svetlana.kuznecova1966@postgrespro.ru", "phone": "+70732016029"}
0005432707094	09C6FE	3919 255031	OLGA POLYAKOVA	{"phone": "+70215057333"}
0005432707095	CA4F79	4555 516413	GALINA ROMANOVA	{"email": "romanova-galina1967@postgrespro.ru", "phone": "+70142857186"}
0005432707096	32A91E	1529 799684	KARINA GERASIMOVA	{"phone": "+70671675941"}
0005432707097	136C4D	8122 570126	ILYA SAVELEV	{"phone": "+70872755153"}
0005432707098	21784B	9471 344684	BORIS YAKOVLEV	{"phone": "+70182992944"}
0005432707099	2E6153	4361 752999	IRINA ZHUKOVA	{"phone": "+70603344054"}
0005432707100	43FBAE	8767 336135	NINA SOKOLOVA	{"email": "nina_sokolova-26041975@postgrespro.ru", "phone": "+70523398210"}
0005432707101	B71640	9831 914269	IGOR SEMENOV	{"email": "semenov-i_121966@postgrespro.ru", "phone": "+70615240661"}
0005432707102	A6196E	3171 156963	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr1975@postgrespro.ru", "phone": "+70284978747"}
0005432707103	A6196E	3632 852770	GALINA ZAKHAROVA	{"phone": "+70862488858"}
0005432707104	6DD778	3039 623747	RINAT EGOROV	{"email": "egorov.r.1978@postgrespro.ru", "phone": "+70947055028"}
0005432707105	6DD778	5155 302158	PAVEL IVANOV	{"phone": "+70190793838"}
0005432707106	6DFADD	1290 800014	ALEKSEY FEDOTOV	{"email": "fedotov-aleksey_1970@postgrespro.ru", "phone": "+70122610252"}
0005432707107	6DFADD	9304 847101	ELENA ZOTOVA	{"email": "zotovae_05041966@postgrespro.ru", "phone": "+70338918904"}
0005432707108	BE1AA0	5938 587963	NATALYA STEPANOVA	{"email": "n_stepanova-011967@postgrespro.ru", "phone": "+70840860945"}
0005432707109	2FC5CF	8012 968734	PAVEL BELOV	{"email": "belovp1972@postgrespro.ru", "phone": "+70007143344"}
0005432707110	1857A4	9488 320190	SERGEY ZHURAVLEV	{"email": "s.zhuravlev.091977@postgrespro.ru", "phone": "+70369737708"}
0005432707111	9A9AA2	0621 776434	SERGEY TIKHONOV	{"phone": "+70978302989"}
0005432707112	6225E3	4951 396702	ANDREY IVANOV	{"email": "ivanov.a1963@postgrespro.ru", "phone": "+70623530831"}
0005432707113	551436	6219 262235	MIKHAIL NOVIKOV	{"phone": "+70745240311"}
0005432707114	D87E6B	1102 664541	ZULFIYA KOMAROVA	{"phone": "+70975970843"}
0005432707115	D87E6B	7632 523226	VLADIMIR FOMIN	{"phone": "+70449332004"}
0005432707116	63858D	1564 239724	ZINAIDA MAKAROVA	{"email": "makarova-zinaida-16031981@postgrespro.ru", "phone": "+70897878916"}
0005432707117	0978D8	1530 025205	LYUDMILA SOROKINA	{"email": "sorokinalyudmila_03081978@postgrespro.ru", "phone": "+70340842600"}
0005432707118	0978D8	6713 194749	REGINA MAKAROVA	{"email": "makarovaregina071963@postgrespro.ru", "phone": "+70039324912"}
0005432707119	569C0A	2479 255646	ALBERT KOROLEV	{"email": "korolev_a24091970@postgrespro.ru", "phone": "+70103825791"}
0005432707120	569C0A	4772 976611	ILMIRA DENISOVA	{"phone": "+70300489480"}
0005432707121	569C0A	2287 343580	ARTEM FEDOROV	{"phone": "+70822205972"}
0005432707122	3D410E	3002 926129	NIKOLAY MOROZOV	{"email": "morozovnikolay_1971@postgrespro.ru", "phone": "+70057150096"}
0005432707123	4D503E	1137 928492	FEDOR MOROZOV	{"email": "fedor-morozov_1975@postgrespro.ru", "phone": "+70097263326"}
0005432707124	6BEB80	0650 263769	DENIS SHEVCHENKO	{"phone": "+70715492894"}
0005432707364	2B6613	5877 904530	OLGA PAVLOVA	{"phone": "+70899752284"}
0005432707125	6BEB80	9948 419786	NIKOLAY POPOV	{"email": "popov-n-101976@postgrespro.ru", "phone": "+70715136867"}
0005432707126	6BEB80	4056 595640	ANASTASIYA GAVRILOVA	{"phone": "+70599439136"}
0005432707127	D52FD8	8921 276147	DMITRIY ROMANOV	{"email": "romanov-d-121969@postgrespro.ru", "phone": "+70294674240"}
0005432707128	59070F	0840 449774	VLADIMIR KISELEV	{"phone": "+70210861630"}
0005432707129	0F3DEA	9517 362032	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova_071975@postgrespro.ru", "phone": "+70613514284"}
0005432707130	0F3DEA	5591 270655	ILYA TIMOFEEV	{"phone": "+70324517314"}
0005432707131	3A2B3D	9788 238000	OLGA POPOVA	{"email": "o.popova-091967@postgrespro.ru", "phone": "+70812567988"}
0005432707132	8B5838	7429 734157	VLADIMIR SIDOROV	{"phone": "+70813617386"}
0005432707133	ECF0FE	8172 583570	MARINA ABRAMOVA	{"email": "abramova-marina-061968@postgrespro.ru", "phone": "+70251065218"}
0005432707134	82E5B9	8783 534720	ALEKSEY KARPOV	{"phone": "+70015882417"}
0005432707135	F60E5A	3884 532673	NATALYA RYABOVA	{"phone": "+70198144167"}
0005432707136	A7E82F	8286 680785	MIKHAIL RODIONOV	{"phone": "+70046759722"}
0005432707137	A7E82F	6539 870310	ALEKSEY BONDARENKO	{"email": "a.bondarenko.081967@postgrespro.ru", "phone": "+70466083378"}
0005432707138	20318B	9603 192233	OKSANA TROFIMOVA	{"phone": "+70019158681"}
0005432707139	2A1581	0652 309141	MAKSIM ANTONOV	{"email": "m-antonov-021959@postgrespro.ru", "phone": "+70439548006"}
0005432707140	7CFA55	8734 552131	MARINA FEDOROVA	{"email": "fedorova.m.26011973@postgrespro.ru", "phone": "+70555242457"}
0005432707141	BE8B28	5933 233449	NADEZHDA MEDVEDEVA	{"email": "medvedeva_nadezhda091971@postgrespro.ru", "phone": "+70434991827"}
0005432707142	5E0D76	5402 566862	VARVARA TITOVA	{"email": "vtitova.1964@postgrespro.ru", "phone": "+70696088615"}
0005432707143	5E0D76	9414 261331	LYUBOV BORISOVA	{"email": "lyubov_borisova1978@postgrespro.ru", "phone": "+70769555927"}
0005432707144	5E0D76	5472 401883	ALEKSANDR IVANOV	{"phone": "+70245209913"}
0005432707145	8FCF7E	1554 507277	ALINA VASILEVA	{"phone": "+70242140763"}
0005432707146	A3983A	2733 682234	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir20091974@postgrespro.ru", "phone": "+70394328637"}
0005432707147	A3983A	1970 157526	EKATERINA FILATOVA	{"phone": "+70743828592"}
0005432707148	02270F	1785 841208	VITALIY POPOV	{"phone": "+70300936513"}
0005432707149	E68307	5652 947828	TATYANA POPOVA	{"email": "tatyana-popova.1967@postgrespro.ru", "phone": "+70998326579"}
0005432707150	E68307	6464 994163	MAKSIM GAVRILOV	{"phone": "+70264247813"}
0005432707151	E68307	3807 978576	ALEKSEY SHEVCHENKO	{"email": "shevchenko-a.10091967@postgrespro.ru", "phone": "+70644433656"}
0005432707152	A0A8A6	5326 383237	ELENA ZOTOVA	{"email": "zotova_e_011969@postgrespro.ru", "phone": "+70731652891"}
0005432707153	A0A8A6	5367 800932	TATYANA MELNIKOVA	{"phone": "+70532873423"}
0005432707154	64D011	7368 097064	ALEKSANDRA IVANOVA	{"email": "ivanova.aleksandra_091968@postgrespro.ru", "phone": "+70604236068"}
0005432707155	64D011	0846 929420	VALERIYA ANTONOVA	{"email": "antonova-valeriya.14091980@postgrespro.ru", "phone": "+70817229965"}
0005432707156	E985EF	3279 359684	MAKSIM POPOV	{"phone": "+70629671083"}
0005432707157	E985EF	1468 267984	PETR ROMANOV	{"phone": "+70118011724"}
0005432707158	1939B6	4853 349559	ALEKSEY MARTYNOV	{"email": "alekseymartynov.1974@postgrespro.ru", "phone": "+70353794547"}
0005432707159	E78293	5855 788393	MIKHAIL TARASOV	{"email": "tarasov.mikhail1968@postgrespro.ru", "phone": "+70890934291"}
0005432707160	A86D79	0745 761192	MARIYA ROMANOVA	{"phone": "+70279503238"}
0005432707161	BB436A	9362 484939	SERGEY POPOV	{"phone": "+70659526100"}
0005432707162	F13B4C	0672 769219	ELENA KOLESNIKOVA	{"email": "kolesnikova-elena.101967@postgrespro.ru", "phone": "+70720703990"}
0005432707163	F13B4C	0508 378463	VALERIYA BELOVA	{"phone": "+70577538542"}
0005432707164	6216E6	8974 423422	ALEKSANDR ZAYCEV	{"phone": "+70932192304"}
0005432707165	B67C4B	8649 976168	ANDREY MIRONOV	{"phone": "+70649241484"}
0005432707166	BA9FD2	2122 433136	ELIZAVETA EGOROVA	{"email": "egorovae-1966@postgrespro.ru", "phone": "+70832242361"}
0005432707167	A529C1	8585 413369	NADEZHDA FROLOVA	{"phone": "+70496257475"}
0005432707168	F6AC87	2921 175876	SOFYA NIKIFOROVA	{"phone": "+70097293223"}
0005432707169	09401F	7192 028334	IVAN OSIPOV	{"email": "osipov_i_1974@postgrespro.ru", "phone": "+70353499450"}
0005432707170	5607B9	2015 662950	NIKOLAY ZHUKOV	{"phone": "+70937017984"}
0005432707171	5607B9	2631 417751	MIKHAIL ZAKHAROV	{"phone": "+70000456903"}
0005432707172	104CEE	0675 808936	LIDIYA VLASOVA	{"phone": "+70194987270"}
0005432707173	90C195	7359 814050	YURIY KAZAKOV	{"email": "y_kazakov.1973@postgrespro.ru", "phone": "+70244627336"}
0005432707174	90C195	1456 360201	YURIY ZAKHAROV	{"phone": "+70079246482"}
0005432707175	7C732D	6334 162669	VLADIMIR CHERNOV	{"email": "vladimirchernov_1957@postgrespro.ru", "phone": "+70575136584"}
0005432707176	D009F6	6464 875892	ARTEM MEDVEDEV	{"phone": "+70031814582"}
0005432707177	D009F6	4126 516708	ALEKSEY BORISOV	{"email": "borisov-a1965@postgrespro.ru", "phone": "+70046129052"}
0005432707178	BE344B	9684 605247	VALENTINA KUZMINA	{"phone": "+70455385346"}
0005432707179	BE344B	5102 140672	ANASTASIYA EGOROVA	{"phone": "+70470145774"}
0005432707180	227451	4298 742288	SVETLANA STEPANOVA	{"phone": "+70388639344"}
0005432707181	D56E90	1794 573840	KRISTINA CHERNOVA	{"phone": "+70991080956"}
0005432707182	D56E90	6423 729539	DENIS SOROKIN	{"phone": "+70677639879"}
0005432707183	D07697	8866 296273	IRINA KONDRATEVA	{"email": "irinakondrateva_19101979@postgrespro.ru", "phone": "+70860638491"}
0005432707184	D07697	6762 881080	NIKOLAY STEPANOV	{"email": "n-stepanov.1968@postgrespro.ru", "phone": "+70221147761"}
0005432707185	A49D8C	7553 495802	GENNADIY KUZMIN	{"phone": "+70600863641"}
0005432707186	32E359	2709 915457	EKATERINA LAZAREVA	{"phone": "+70959958521"}
0005432707188	078771	6214 057759	MIKHAIL ALEKSEEV	{"email": "mikhail.alekseev111971@postgrespro.ru", "phone": "+70300541973"}
0005432707189	078771	1062 580561	ALINA IVANOVA	{"email": "ivanova.a.011974@postgrespro.ru", "phone": "+70780532332"}
0005432707190	85A958	0548 510410	GALINA TROFIMOVA	{"phone": "+70889323161"}
0005432707191	D4711D	2666 640649	ALEKSEY VLASOV	{"email": "avlasov1978@postgrespro.ru", "phone": "+70678268406"}
0005432707192	2675CB	0426 123880	ALEKSANDR ANTONOV	{"email": "antonov_aleksandr.05071966@postgrespro.ru", "phone": "+70123298783"}
0005432707193	043E81	1714 734467	EVGENIYA BELOVA	{"email": "belova-evgeniya21021973@postgrespro.ru", "phone": "+70124553550"}
0005432707194	603171	5689 782390	ELIZAVETA SOROKINA	{"email": "elizaveta_sorokina.111964@postgrespro.ru", "phone": "+70603898749"}
0005432707195	97CB89	2588 040476	VLADIMIR ZAYCEV	{"email": "zaycevvladimir061974@postgrespro.ru", "phone": "+70269252873"}
0005432707196	9F29FE	4541 638043	NINA ARKHIPOVA	{"phone": "+70060725814"}
0005432707197	9F29FE	6835 852101	TATYANA MEDVEDEVA	{"email": "medvedeva-t_121970@postgrespro.ru", "phone": "+70041591762"}
0005432707198	2E52F1	4110 845333	MARIYA FOMINA	{"phone": "+70776633516"}
0005432707199	2E52F1	1852 015600	GALINA ANTONOVA	{"phone": "+70167861695"}
0005432707200	A8CCC4	2339 533957	SERGEY GORBUNOV	{"email": "gorbunov_sergey-02081970@postgrespro.ru", "phone": "+70215135277"}
0005432707201	A8CCC4	1241 277462	MARIYA PETROVA	{"email": "m-petrova-08071976@postgrespro.ru", "phone": "+70152900714"}
0005432707202	7BC0BE	5775 114286	ALEKSANDR SCHERBAKOV	{"phone": "+70881591732"}
0005432707203	7BC0BE	5117 597241	DMITRIY BORISOV	{"email": "d.borisov14011983@postgrespro.ru", "phone": "+70140970842"}
0005432707204	FE401B	1798 517907	MARIYA IVANOVA	{"email": "m_ivanova_031970@postgrespro.ru", "phone": "+70920091204"}
0005432707205	6B1B31	0707 026997	YULIYA OSIPOVA	{"phone": "+70338973194"}
0005432707206	6B1B31	5236 991243	SERGEY POPOV	{"phone": "+70013268167"}
0005432707207	EF2631	2363 683913	YURIY ANTONOV	{"phone": "+70175898181"}
0005432707208	F64188	6944 267456	LEONID EGOROV	{"phone": "+70194187848"}
0005432707209	F64188	2734 899809	OLGA KUZNECOVA	{"email": "olgakuznecova-1979@postgrespro.ru", "phone": "+70378728640"}
0005432707210	A1C7E1	5685 618354	ALEKSEY KOROLEV	{"email": "aleksey.korolev-1980@postgrespro.ru", "phone": "+70895411413"}
0005432707211	767534	7968 394153	TATYANA POPOVA	{"email": "t.popova_011964@postgrespro.ru", "phone": "+70123292172"}
0005432707212	100247	3740 423115	GRIGORIY ZAKHAROV	{"phone": "+70859752383"}
0005432707213	7119AE	4983 839536	YURIY ALEKSEEV	{"email": "alekseev-yuriy.1975@postgrespro.ru", "phone": "+70916652623"}
0005432707214	7119AE	3741 972657	IGOR MAKSIMOV	{"phone": "+70130249619"}
0005432707215	C1E3E0	4013 940396	TATYANA SAVELEVA	{"email": "tatyana-saveleva-18071979@postgrespro.ru", "phone": "+70093516497"}
0005432707216	C1E3E0	9045 341355	GALINA ZAYCEVA	{"email": "galina.zayceva.1977@postgrespro.ru", "phone": "+70046225996"}
0005432707217	C1E3E0	7797 999423	LYUBOV EGOROVA	{"email": "egorova.lyubov-1976@postgrespro.ru", "phone": "+70142023993"}
0005432707218	AFCCA6	2148 040943	STEPAN MAKAROV	{"email": "s.makarov-30061978@postgrespro.ru", "phone": "+70279603002"}
0005432707219	AFCCA6	1562 275688	LILIYA GRISHINA	{"email": "liliya_grishina09031962@postgrespro.ru", "phone": "+70569021957"}
0005432707220	7712C3	4687 629473	VLADIMIR ALEKSEEV	{"phone": "+70856647575"}
0005432707221	EA6E70	8990 344108	NINA VOLKOVA	{"email": "volkova-n06111968@postgrespro.ru", "phone": "+70188301307"}
0005432707222	EA6E70	3259 576152	SVETLANA TROFIMOVA	{"phone": "+70765248328"}
0005432707223	237F53	5462 501935	OLEG SCHERBAKOV	{"email": "oleg.scherbakov-1964@postgrespro.ru", "phone": "+70327973337"}
0005432707224	FDF825	5033 114900	ANTON KUZNECOV	{"email": "kuznecov-a_081980@postgrespro.ru", "phone": "+70881124158"}
0005432707225	EBA145	8267 489709	DMITRIY TIMOFEEV	{"email": "timofeev.dmitriy.1970@postgrespro.ru", "phone": "+70949398837"}
0005432707226	3DBDDC	9498 512137	SVETLANA ZAKHAROVA	{"phone": "+70005832787"}
0005432707227	EC8110	5455 915639	EGOR VASILEV	{"email": "egor-vasilev1959@postgrespro.ru", "phone": "+70037669904"}
0005432707228	EC8110	3554 253349	ELENA NIKITINA	{"phone": "+70190558116"}
0005432707229	F5E5A6	7920 611946	KRISTINA VOLKOVA	{"email": "volkova_kristina.26081969@postgrespro.ru", "phone": "+70039150638"}
0005432707230	F5E5A6	6568 928090	EKATERINA KOLESNIKOVA	{"phone": "+70762597872"}
0005432707231	6F4050	6393 297992	SVETLANA KONOVALOVA	{"phone": "+70968843312"}
0005432707232	9E95E5	5884 778740	NIKITA KUZNECOV	{"email": "kuznecov_n-1987@postgrespro.ru", "phone": "+70978473082"}
0005432707233	E646FA	0377 529234	VALERIY ALEKSANDROV	{"email": "aleksandrov-v.14011965@postgrespro.ru", "phone": "+70647613310"}
0005432707234	632F07	3500 213321	OLGA BARANOVA	{"email": "baranova-olga-061973@postgrespro.ru", "phone": "+70259018683"}
0005432707235	632F07	6533 374724	LARISA MAKAROVA	{"email": "makarova-l-07121970@postgrespro.ru", "phone": "+70338745858"}
0005432707236	781016	6577 546424	ALEKSANDR NIKOLAEV	{"phone": "+70191875538"}
0005432707237	2CE879	2174 723419	GULFIYA KUZMINA	{"phone": "+70462914259"}
0005432707238	2CE879	1455 759575	VALENTINA KRASNOVA	{"phone": "+70798168812"}
0005432707239	D6A181	3390 987391	VIKTOR MEDVEDEV	{"phone": "+70327150140"}
0005432707240	3AF6A3	6502 650398	SERGEY KAZAKOV	{"email": "sergey_kazakov.061989@postgrespro.ru", "phone": "+70432760912"}
0005432707241	3AF6A3	9282 399365	LYUBOV SOKOLOVA	{"phone": "+70684955859"}
0005432707242	19D192	2682 467487	YULIYA NOVIKOVA	{"phone": "+70816635638"}
0005432707243	48A6F8	0897 858661	RUDOLF NIKOLAEV	{"phone": "+70213731063"}
0005432707244	48A6F8	1080 173514	ALEKSEY MOROZOV	{"email": "morozov.aleksey-04121973@postgrespro.ru", "phone": "+70336414957"}
0005432707245	C39500	6649 185266	ALEKSEY DENISOV	{"phone": "+70461423627"}
0005432707246	C39500	2862 864505	VIKTOR KONOVALOV	{"email": "viktor-konovalov.24041966@postgrespro.ru", "phone": "+70026193543"}
0005432707247	6CB6EA	5221 627344	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov.011968@postgrespro.ru", "phone": "+70484325640"}
0005432707248	6CB6EA	6539 387450	GALINA SERGEEVA	{"email": "sergeeva_g.02051982@postgrespro.ru", "phone": "+70189692865"}
0005432707249	5FE620	7167 178741	NIKITA BARANOV	{"email": "n_baranov071952@postgrespro.ru", "phone": "+70087319840"}
0005432707250	28AA0D	6826 258042	MARIYA ORLOVA	{"email": "mariya_orlova-011973@postgrespro.ru", "phone": "+70312356201"}
0005432707251	A64EB0	4280 965634	ELENA ROMANOVA	{"phone": "+70240048900"}
0005432707252	A64EB0	3612 929046	IVAN GAVRILOV	{"phone": "+70583402844"}
0005432707253	31896B	2344 771508	MARINA ANTONOVA	{"phone": "+70157858843"}
0005432707254	F678D6	9750 732463	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr111969@postgrespro.ru", "phone": "+70301975299"}
0005432707255	175B6D	7901 437314	LARISA DENISOVA	{"email": "l-denisova.1965@postgrespro.ru", "phone": "+70278896315"}
0005432707256	175B6D	4618 350818	VALENTINA ZHUKOVA	{"email": "valentina_zhukova-041980@postgrespro.ru", "phone": "+70370493661"}
0005432707257	A3C0AC	2418 497077	VALENTINA KOROLEVA	{"email": "koroleva-valentina-1957@postgrespro.ru", "phone": "+70700365972"}
0005432707258	FE7042	4158 357022	SERGEY MIRONOV	{"email": "s_mironov_051973@postgrespro.ru", "phone": "+70892016028"}
0005432707259	D29F3F	7587 307384	ALEKSANDR IVANOV	{"email": "a_ivanov071983@postgrespro.ru", "phone": "+70244123691"}
0005432707260	D29F3F	0783 168083	VYACHESLAV SOROKIN	{"email": "vyacheslav_sorokin.1972@postgrespro.ru", "phone": "+70933696261"}
0005432707261	5FE967	0160 845666	ANDREY KUZNECOV	{"phone": "+70114676183"}
0005432707262	48C706	2173 831817	ELIZAVETA MEDVEDEVA	{"email": "e_medvedeva_21021981@postgrespro.ru", "phone": "+70466719659"}
0005432707263	0888B1	8457 885781	ANTON GUSEV	{"email": "anton_gusev-09101967@postgrespro.ru", "phone": "+70949747728"}
0005432707264	81667B	0166 439474	YURIY TIKHONOV	{"email": "y_tikhonov.081976@postgrespro.ru", "phone": "+70229543799"}
0005432707265	85BD79	3129 964909	ALEKSANDR FILIPPOV	{"phone": "+70118445506"}
0005432707266	5D654A	7496 198768	OLEG ROMANOV	{"phone": "+70256816361"}
0005432707267	D1B5C0	4520 411648	ALEKSANDR PETROV	{"phone": "+70685072500"}
0005432707268	2D7042	3395 122988	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_1982@postgrespro.ru", "phone": "+70392771135"}
0005432707269	2D7042	1506 489984	ELENA NIKIFOROVA	{"phone": "+70620103880"}
0005432707270	1E9690	0708 217052	FEDOR ZHUKOV	{"phone": "+70846275114"}
0005432707271	6295A7	7657 315750	ELENA MASLOVA	{"phone": "+70379083302"}
0005432707272	6295A7	5347 412047	NIKOLAY SOROKIN	{"phone": "+70235831305"}
0005432707273	CE169F	7894 783700	EVGENIY FEDOROV	{"email": "fedorovevgeniy.061974@postgrespro.ru", "phone": "+70885715516"}
0005432707274	CE169F	8720 204809	ALEKSEY FILIPPOV	{"phone": "+70792841546"}
0005432707275	CE169F	1034 858243	LADA YUDINA	{"email": "yudina_l1978@postgrespro.ru", "phone": "+70112024224"}
0005432707276	B92D0F	9742 584533	MARINA LUKYANOVA	{"phone": "+70023812145"}
0005432707277	B92D0F	7858 059619	KSENIYA ZAYCEVA	{"email": "kseniya_zayceva1966@postgrespro.ru", "phone": "+70660709185"}
0005432707278	EADCED	6233 971905	VERA VLASOVA	{"email": "vera-vlasova_1971@postgrespro.ru", "phone": "+70825242523"}
0005432707279	6E84B3	1784 592495	YANA POLYAKOVA	{"email": "yanapolyakova-091980@postgrespro.ru", "phone": "+70518826149"}
0005432707280	976105	9945 150520	NINA OSIPOVA	{"phone": "+70522905860"}
0005432707281	976105	6949 907468	SVETLANA SOLOVEVA	{"phone": "+70461993682"}
0005432707282	14E326	8873 540343	TATYANA KOMAROVA	{"email": "komarova-tatyana-07051976@postgrespro.ru", "phone": "+70893463863"}
0005432707283	14E326	8640 064987	MAKSIM MOROZOV	{"email": "morozov-m.26031973@postgrespro.ru", "phone": "+70859120615"}
0005432707284	14E326	9532 757722	VASILIY NIKITIN	{"email": "nikitin_v041979@postgrespro.ru", "phone": "+70871633096"}
0005432707285	83EAF4	2342 709513	NADEZHDA AFANASEVA	{"email": "afanaseva_n-05111968@postgrespro.ru", "phone": "+70842984020"}
0005432707286	55E66E	1537 790997	EVGENIYA IVANOVA	{"email": "evgeniya.ivanova081973@postgrespro.ru", "phone": "+70830621214"}
0005432707287	55E66E	9911 579997	DIANA ROMANOVA	{"email": "romanova.diana.071980@postgrespro.ru", "phone": "+70349261323"}
0005432707288	AF4009	8365 901977	VYACHESLAV KOZLOV	{"email": "kozlov.vyacheslav-081975@postgrespro.ru", "phone": "+70741357223"}
0005432707289	F66B88	9739 096349	EKATERINA YUDINA	{"phone": "+70108406595"}
0005432707290	A7FD40	2827 627669	SEMEN MOROZOV	{"phone": "+70861278547"}
0005432707291	A7FD40	0372 893653	ALEKSANDR GUSEV	{"phone": "+70485502158"}
0005432707292	77C0AA	7006 561993	DMITRIY MAKAROV	{"phone": "+70587167977"}
0005432707293	77C0AA	3600 246863	TATYANA ZHURAVLEVA	{"phone": "+70968229075"}
0005432707294	9E6122	7480 141538	MAKSIM SAVELEV	{"phone": "+70108358771"}
0005432707295	C7EB2A	6690 655097	OLGA KUZNECOVA	{"email": "kuznecova_o-1969@postgrespro.ru", "phone": "+70954493713"}
0005432707296	877AAB	2612 829241	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-28081977@postgrespro.ru", "phone": "+70005612837"}
0005432707297	A20626	8390 036903	LYUDMILA GUSEVA	{"email": "lyudmila-guseva_07101969@postgrespro.ru", "phone": "+70365233055"}
0005432707298	A20626	7851 193840	ARTEM AFANASEV	{"email": "afanasevartem.1968@postgrespro.ru", "phone": "+70932390976"}
0005432707299	A20626	0051 617163	EKATERINA DAVYDOVA	{"phone": "+70778605151"}
0005432707300	B2669B	0586 173458	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov-31081976@postgrespro.ru", "phone": "+70946571923"}
0005432707301	431B5F	9375 486304	VERA MAKSIMOVA	{"email": "v_maksimova_1970@postgrespro.ru", "phone": "+70006851482"}
0005432707302	431B5F	4508 694314	RAMIL EGOROV	{"email": "regorov_1978@postgrespro.ru", "phone": "+70639985081"}
0005432707303	A2191F	9065 856981	ARTEM ZHUKOV	{"email": "zhukov-a-081980@postgrespro.ru", "phone": "+70367059988"}
0005432707304	932370	9990 667275	VALERIY KUZNECOV	{"phone": "+70675538655"}
0005432707305	813C88	9226 221787	INNA SMIRNOVA	{"email": "smirnova_inna081982@postgrespro.ru", "phone": "+70346417587"}
0005432707306	97D60A	4766 719748	LIDIYA AKIMOVA	{"email": "l.akimova_091980@postgrespro.ru", "phone": "+70763023837"}
0005432707307	9FD35C	3758 334445	VASILIY TIKHONOV	{"email": "vtikhonov-1979@postgrespro.ru", "phone": "+70741524739"}
0005432707308	9FD35C	1481 849225	MAKSIM DENISOV	{"email": "denisov_m-1979@postgrespro.ru", "phone": "+70300013461"}
0005432707309	9FD35C	7165 758753	SERGEY KUZNECOV	{"email": "kuznecov-s-30041974@postgrespro.ru", "phone": "+70631276795"}
0005432707310	D531A7	1774 050108	EKATERINA BORISOVA	{"email": "e-borisova.1973@postgrespro.ru", "phone": "+70958307188"}
0005432707311	56431A	8043 499678	TATYANA LEBEDEVA	{"email": "lebedeva.tatyana.08081972@postgrespro.ru", "phone": "+70414161733"}
0005432707312	E5CB7D	9211 734564	MIKHAIL ORLOV	{"email": "m-orlov-11121966@postgrespro.ru", "phone": "+70554161451"}
0005432707313	78A6FF	4872 946592	ALEKSEY KARPOV	{"phone": "+70140981158"}
0005432707314	02C703	0964 912194	MARINA TARASOVA	{"phone": "+70055175803"}
0005432707315	AFE7A0	6146 331510	OLGA KUZMINA	{"phone": "+70858141745"}
0005432707316	6E0652	3481 453903	SERGEY OSIPOV	{"email": "sergey_osipov_1981@postgrespro.ru", "phone": "+70852994218"}
0005432707317	6E0652	5125 150986	MARIYA TIKHONOVA	{"phone": "+70949818855"}
0005432707318	554253	6011 484741	SERGEY TIKHONOV	{"phone": "+70725844918"}
0005432707319	D11459	0868 868849	MIKHAIL IVANOV	{"phone": "+70305407606"}
0005432707320	39FD6D	4446 563984	ALEKSEY MAKSIMOV	{"phone": "+70722211760"}
0005432707321	352D7A	4311 274465	NATALYA KUZNECOVA	{"email": "kuznecova-n_27051968@postgrespro.ru", "phone": "+70873979632"}
0005432707322	FF39BB	0854 851020	VLADIMIR ANDREEV	{"email": "v.andreev-1979@postgrespro.ru", "phone": "+70111086327"}
0005432707323	FF39BB	4736 734699	NATALYA OVCHINNIKOVA	{"email": "natalya-ovchinnikova1971@postgrespro.ru", "phone": "+70306595046"}
0005432707324	095321	2418 073571	IRINA GUSEVA	{"phone": "+70257678672"}
0005432707325	6C15E5	3821 325477	ALEKSANDR NIKITIN	{"email": "nikitin_a071972@postgrespro.ru", "phone": "+70243100431"}
0005432707326	DBF5E4	4827 790190	ELENA BARANOVA	{"phone": "+70648719280"}
0005432707327	038D10	2320 440162	VALERIYA POLYAKOVA	{"phone": "+70469309262"}
0005432707328	038D10	2320 487986	NATALYA SCHERBAKOVA	{"email": "natalya-scherbakova_20101959@postgrespro.ru", "phone": "+70811557558"}
0005432707329	27C412	6185 596976	VLADIMIR TARASOV	{"phone": "+70157172892"}
0005432707330	339F85	1169 758193	NIKOLAY KRASNOV	{"email": "krasnov_nikolay_1964@postgrespro.ru", "phone": "+70609221895"}
0005432707331	339F85	3084 572251	VALERIY SOLOVEV	{"email": "solovev-valeriy.081977@postgrespro.ru", "phone": "+70880489445"}
0005432707332	251C7C	3525 032315	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev1958@postgrespro.ru", "phone": "+70915511216"}
0005432707333	7D4783	7811 201867	VYACHESLAV ANDREEV	{"email": "vyacheslav.andreev111980@postgrespro.ru", "phone": "+70891902983"}
0005432707334	6F6808	8225 757886	IVAN ABRAMOV	{"phone": "+70403460145"}
0005432707335	4F7DA4	3919 896429	VIKTORIYA NIKIFOROVA	{"email": "nikiforovav-041969@postgrespro.ru", "phone": "+70049965159"}
0005432707336	BA5343	0135 073692	VLADIMIR KUZMIN	{"phone": "+70095642726"}
0005432707337	BA5343	4495 539468	SVETLANA SOLOVEVA	{"email": "s.soloveva-04081981@postgrespro.ru", "phone": "+70507348393"}
0005432707338	ADEE1D	2423 173619	MIKHAIL SOKOLOV	{"phone": "+70483463516"}
0005432707339	8EAF9B	5798 234706	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir-091973@postgrespro.ru", "phone": "+70991424325"}
0005432707340	2EE73A	7039 223872	ULYANA DMITRIEVA	{"email": "u.dmitrieva.04091979@postgrespro.ru", "phone": "+70265187806"}
0005432707341	66FCC8	5195 054142	ANNA VLASOVA	{"email": "a_vlasova.1975@postgrespro.ru", "phone": "+70191195262"}
0005432707342	66FCC8	2893 932137	MARIYA BELYAEVA	{"email": "mbelyaeva021975@postgrespro.ru", "phone": "+70225751127"}
0005432707343	DB937C	2764 477937	OKSANA DANILOVA	{"email": "oksana.danilova061984@postgrespro.ru", "phone": "+70537575199"}
0005432707344	DB937C	4427 105569	DANILA SIDOROV	{"email": "sidorov_danila.1968@postgrespro.ru", "phone": "+70203732116"}
0005432707345	D43B85	5718 733798	OLEG ORLOV	{"phone": "+70726129200"}
0005432707346	D43B85	8473 160448	OLGA MELNIKOVA	{"phone": "+70528596846"}
0005432707347	9B7CBF	2452 505601	NATALYA OSIPOVA	{"email": "n_osipova_25041976@postgrespro.ru", "phone": "+70420560490"}
0005432707348	E41B96	5345 228355	MARGARITA STEPANOVA	{"phone": "+70666034277"}
0005432707349	0BF8B9	2346 133387	MARINA KRASNOVA	{"phone": "+70656544918"}
0005432707350	474F58	2821 157420	YURIY TIKHONOV	{"phone": "+70202277175"}
0005432707351	DB4B2F	2178 570785	KONSTANTIN IVANOV	{"email": "ivanov_k.111968@postgrespro.ru", "phone": "+70436825316"}
0005432707352	083E7D	7345 383601	KONSTANTIN GAVRILOV	{"phone": "+70037261265"}
0005432707353	CF31E3	6566 914479	SERGEY SOROKIN	{"phone": "+70926471629"}
0005432707354	CF31E3	1533 042587	IVAN YAKOVLEV	{"phone": "+70518305550"}
0005432707355	CF31E3	0648 782623	VLADIMIR RODIONOV	{"phone": "+70116977727"}
0005432707356	066245	2236 327375	DMITRIY KRASNOV	{"email": "krasnov_d1979@postgrespro.ru", "phone": "+70242599577"}
0005432707357	066245	4187 979032	VLADIMIR MOISEEV	{"phone": "+70247897160"}
0005432707358	25D8CE	2627 634222	MARIYA VASILEVA	{"email": "m.vasileva.071960@postgrespro.ru", "phone": "+70046807380"}
0005432707359	F5E593	8689 238865	NATALIYA KUZNECOVA	{"email": "kuznecova-nataliya.111972@postgrespro.ru", "phone": "+70690040637"}
0005432707360	322667	1267 700854	MAKSIM NAZAROV	{"phone": "+70433977899"}
0005432707361	6A3E71	2200 296824	ALEKSANDR KARPOV	{"email": "karpov.aleksandr.1968@postgrespro.ru", "phone": "+70100978228"}
0005432707362	712BAB	1404 735234	EVGENIY GUSEV	{"email": "evgeniy.gusev.14111963@postgrespro.ru", "phone": "+70176480649"}
0005432707363	3871B2	7488 432515	ANTONINA ILINA	{"email": "ilina_a_081975@postgrespro.ru", "phone": "+70174354779"}
0005432707365	7D3020	0852 477226	GALINA MOROZOVA	{"email": "galina.morozova.051972@postgrespro.ru", "phone": "+70397822360"}
0005432707366	AEC74C	6652 732242	DMITRIY IVANOV	{"email": "ivanov_dmitriy_02121968@postgrespro.ru", "phone": "+70481881385"}
0005432707367	AEC74C	2840 671836	SERGEY SOROKIN	{"phone": "+70582332940"}
0005432707368	A66C4F	5190 229059	SVETLANA ANTONOVA	{"email": "antonova-svetlana_041956@postgrespro.ru", "phone": "+70457371095"}
0005432707369	D95EA0	6626 453382	MARIYA KOZLOVA	{"email": "m-kozlova-29111968@postgrespro.ru", "phone": "+70601401383"}
0005432707370	6226B0	4429 672195	ROMAN KUZNECOV	{"phone": "+70965532794"}
0005432707371	6CE28C	7982 415303	VYACHESLAV FOMIN	{"phone": "+70271022881"}
0005432707372	6CE28C	5166 107952	PAVEL MIKHAYLOV	{"email": "mikhaylov-pavel-03031976@postgrespro.ru", "phone": "+70370033624"}
0005432707373	714B17	6409 469595	ANASTASIYA ABRAMOVA	{"phone": "+70280957365"}
0005432707374	B83A6B	8111 774355	VIKTOR SIDOROV	{"phone": "+70174374447"}
0005432707375	B83A6B	6225 211160	VLADIMIR BARANOV	{"email": "baranovvladimir-1969@postgrespro.ru", "phone": "+70470794886"}
0005432707376	911A48	3017 153233	DANIL TIMOFEEV	{"phone": "+70367934341"}
0005432707377	493303	3948 477423	DMITRIY RODIONOV	{"email": "dmitriy.rodionov_1962@postgrespro.ru", "phone": "+70554469262"}
0005432707378	493303	0720 560704	ALEKSEY SOROKIN	{"phone": "+70561046599"}
0005432707379	75B9CC	5431 308295	ANASTASIYA IVANOVA	{"email": "ivanova.a-05111970@postgrespro.ru", "phone": "+70865143042"}
0005432707380	1E3A8E	3067 928248	GEORGIY GRIGOREV	{"email": "ggrigorev_1960@postgrespro.ru", "phone": "+70361801186"}
0005432707381	645F29	2189 770879	ANNA PETROVA	{"phone": "+70860651203"}
0005432707382	645F29	3943 001468	NINA STEPANOVA	{"phone": "+70198522919"}
0005432707383	BE6363	1532 726151	TATYANA ORLOVA	{"phone": "+70443482981"}
0005432707384	69614E	0701 932091	VADIM MAKSIMOV	{"email": "vadim-maksimov.1973@postgrespro.ru", "phone": "+70843473839"}
0005432707385	636E9D	8633 210158	ANDREY ANTONOV	{"phone": "+70868580518"}
0005432707386	8BB912	7250 838398	OLGA SOROKINA	{"email": "sorokina.olga-061971@postgrespro.ru", "phone": "+70536301085"}
0005432707387	FA82BA	3627 270440	MARIYA YUDINA	{"phone": "+70347825409"}
0005432707388	7EBD24	7212 314167	IRINA FOMINA	{"email": "irina_fomina.19121967@postgrespro.ru", "phone": "+70212360578"}
0005432707389	C8D856	9135 791275	DMITRIY GAVRILOV	{"phone": "+70740006062"}
0005432707390	C8D856	5382 918624	MARINA TIKHONOVA	{"phone": "+70711097839"}
0005432707391	9C7E61	2987 792212	DMITRIY NAZAROV	{"phone": "+70079197640"}
0005432707392	9C7E61	2034 261697	MARIYA SOLOVEVA	{"email": "m.soloveva.1988@postgrespro.ru", "phone": "+70121758437"}
0005432707393	360951	4658 608319	LIDIYA GUSEVA	{"phone": "+70687623957"}
0005432707394	87F78A	4101 215039	NIKOLAY ZAKHAROV	{"phone": "+70979770305"}
0005432707395	9F8E77	5883 238471	ALINA KUZNECOVA	{"phone": "+70034027207"}
0005432707396	9F8E77	6219 728785	VALERIY NAUMOV	{"email": "naumovvaleriy-051979@postgrespro.ru", "phone": "+70668389541"}
0005432707397	9F8E77	2962 399403	EKATERINA GRISHINA	{"email": "ekaterinagrishina-1975@postgrespro.ru", "phone": "+70458675659"}
0005432707398	B8AB08	5890 281329	NINA PAVLOVA	{"email": "npavlova1962@postgrespro.ru", "phone": "+70180993128"}
0005432707399	5C9ED7	5614 816002	TATYANA ROMANOVA	{"email": "tromanova12021980@postgrespro.ru", "phone": "+70514347655"}
0005432707400	0C4DD4	6404 444265	KONSTANTIN ALEKSEEV	{"email": "konstantin_alekseev.1972@postgrespro.ru", "phone": "+70853238314"}
0005432707457	A5200B	2580 544209	TATYANA GORBUNOVA	{"phone": "+70266547443"}
0005432707401	6465E6	4373 051802	VALERIY KUDRYASHOV	{"email": "kudryashov.valeriy.1977@postgrespro.ru", "phone": "+70498887933"}
0005432707402	6465E6	3509 359004	LUIZA ERMAKOVA	{"phone": "+70718722845"}
0005432707403	28BC01	3774 532059	KSENIYA KOROLEVA	{"phone": "+70731912669"}
0005432707404	EBF6F5	5875 373716	NATALYA OVCHINNIKOVA	{"phone": "+70150888107"}
0005432707405	EBF6F5	2852 447773	ELENA KAZAKOVA	{"phone": "+70095969176"}
0005432707406	F88FD7	7764 984014	VALENTINA ZAYCEVA	{"email": "zaycevavalentina-1971@postgrespro.ru", "phone": "+70604674232"}
0005432707407	F88FD7	2632 122362	NINA VOROBEVA	{"phone": "+70705221504"}
0005432707408	9894F6	7412 055860	NATALYA EFREMOVA	{"email": "natalya.efremova.121975@postgrespro.ru", "phone": "+70470638194"}
0005432707409	87C4FB	0100 208615	ILYA ILIN	{"email": "ilin.i.081976@postgrespro.ru", "phone": "+70894699519"}
0005432707410	176E5E	3983 198544	KLAVDIYA ABRAMOVA	{"phone": "+70456009001"}
0005432707411	176E5E	8454 613448	VALENTINA ALEKSEEVA	{"phone": "+70657414705"}
0005432707412	E143EA	2348 675563	OLEG ROMANOV	{"phone": "+70637780158"}
0005432707413	81A9EA	7794 229436	LEONID ROMANOV	{"email": "romanov-l.1973@postgrespro.ru", "phone": "+70574860892"}
0005432707414	81A9EA	0007 215862	ALEKSANDR PAVLOV	{"email": "pavlov_a-021983@postgrespro.ru", "phone": "+70493717558"}
0005432707415	81A9EA	1393 010392	VYACHESLAV STEPANOV	{"phone": "+70238692585"}
0005432707416	1183DF	6463 184417	ALEKSANDR IVANOV	{"email": "aleksandrivanov.1975@postgrespro.ru", "phone": "+70199912941"}
0005432707417	073018	4213 926752	VIKTOR VASILEV	{"phone": "+70278370075"}
0005432707418	073018	1129 871376	VALERIY POPOV	{"email": "popovv.1980@postgrespro.ru", "phone": "+70883640843"}
0005432707419	073018	2626 833019	ALEKSEY VASILEV	{"email": "a.vasilev011980@postgrespro.ru", "phone": "+70905249417"}
0005432707420	580DBC	2108 898505	NIKOLAY FILIPPOV	{"phone": "+70887946231"}
0005432707421	181AC4	0445 142995	TATYANA KOROLEVA	{"phone": "+70305816647"}
0005432707422	181AC4	2941 470593	LARISA MOROZOVA	{"email": "larisamorozova.101976@postgrespro.ru", "phone": "+70318894014"}
0005432707423	50356D	5186 471688	GENNADIY FILIPPOV	{"email": "gfilippov-12061969@postgrespro.ru", "phone": "+70152930726"}
0005432707424	FF3333	6067 359129	GALINA KUZMINA	{"phone": "+70069473584"}
0005432707425	FF3333	5093 076483	MARIYA MOISEEVA	{"phone": "+70297217734"}
0005432707426	CE669E	1608 393394	YURIY VOROBEV	{"email": "vorobevyuriy.1979@postgrespro.ru", "phone": "+70473073306"}
0005432707427	210275	8263 457745	GALINA ZHURAVLEVA	{"email": "zhuravlevagalina_091958@postgrespro.ru", "phone": "+70250355504"}
0005432707428	210275	5139 582018	MARINA MOISEEVA	{"phone": "+70428199793"}
0005432707429	11940E	5739 848652	ANATOLIY NIKITIN	{"phone": "+70705986645"}
0005432707430	11940E	5256 995328	GALINA MELNIKOVA	{"email": "melnikovag_041980@postgrespro.ru", "phone": "+70581818536"}
0005432707431	4836F7	7552 939696	EGOR ZAYCEV	{"email": "zaycev-e-1980@postgrespro.ru", "phone": "+70012548845"}
0005432707432	90BD9E	5518 682496	ALEKSEY MIRONOV	{"phone": "+70153140599"}
0005432707433	B5DDC3	4833 719089	DMITRIY ALEKSEEV	{"email": "dmitriy.alekseev-21111981@postgrespro.ru", "phone": "+70922277014"}
0005432707434	B5DDC3	6920 152021	NATALYA IVANOVA	{"email": "natalyaivanova-1971@postgrespro.ru", "phone": "+70784143587"}
0005432707435	50F2BA	9001 125112	SERGEY MATVEEV	{"email": "matveevsergey.1962@postgrespro.ru", "phone": "+70773017556"}
0005432707436	FA267E	8488 131997	LARISA KRASNOVA	{"phone": "+70430144469"}
0005432707437	90C017	7131 349181	NIKOLAY BELOV	{"phone": "+70799498208"}
0005432707438	F49CBD	9794 448059	NATALYA SCHERBAKOVA	{"email": "scherbakovan05121979@postgrespro.ru", "phone": "+70374245777"}
0005432707439	997D91	7198 593665	ALFIYA YUDINA	{"phone": "+70149183384"}
0005432707440	997D91	9955 446350	NADEZHDA BARANOVA	{"email": "nadezhda-baranova021978@postgrespro.ru", "phone": "+70195078869"}
0005432707441	997D91	8907 683546	SERGEY ABRAMOV	{"email": "sergey-abramov_011978@postgrespro.ru", "phone": "+70687174660"}
0005432707442	BA61F4	1064 158343	ALEKSANDR BORISOV	{"phone": "+70279206675"}
0005432707443	A471CD	2971 237300	ELENA FILIPPOVA	{"phone": "+70977258086"}
0005432707444	DDF6A5	7217 331802	NATALYA ARKHIPOVA	{"email": "n.arkhipova21121968@postgrespro.ru", "phone": "+70914639481"}
0005432707445	DDF6A5	5437 197053	OKSANA FEDOROVA	{"email": "fedorova_o.03121977@postgrespro.ru", "phone": "+70737277243"}
0005432707446	54BB2F	0144 617454	KLAVDIYA NIKITINA	{"phone": "+70758525379"}
0005432707447	54BB2F	1954 666880	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir_041987@postgrespro.ru", "phone": "+70030418942"}
0005432707448	A58236	6224 637203	VALENTINA ALEKSEEVA	{"email": "alekseeva_v.1972@postgrespro.ru", "phone": "+70016102594"}
0005432707449	A58236	8158 439936	MARAT PETROV	{"email": "petrov.marat-1980@postgrespro.ru", "phone": "+70228427615"}
0005432707450	422068	9956 233140	ANNA VOROBEVA	{"email": "vorobeva_a-20081962@postgrespro.ru", "phone": "+70615508698"}
0005432707451	422068	6623 075588	OLGA NIKOLAEVA	{"email": "o_nikolaeva_101989@postgrespro.ru", "phone": "+70250907396"}
0005432707452	6EA4F8	1126 524251	ANNA MELNIKOVA	{"phone": "+70521416696"}
0005432707453	564605	5168 337818	ANGELINA ANDREEVA	{"email": "a_andreeva1963@postgrespro.ru", "phone": "+70973734826"}
0005432707454	564605	2755 847095	LIDIYA RODIONOVA	{"phone": "+70708353934"}
0005432707455	A5200B	9309 183535	ALEKSANDR POPOV	{"phone": "+70882506174"}
0005432707456	A5200B	0896 259146	NIKITA SOKOLOV	{"phone": "+70935464303"}
0005432707458	F7F55F	5820 708498	KIRILL FILIPPOV	{"email": "filippov_k.031964@postgrespro.ru", "phone": "+70770152583"}
0005432707459	D9E81F	6483 336440	ALEKSEY MOROZOV	{"email": "a_morozov-1987@postgrespro.ru", "phone": "+70917271205"}
0005432707460	D9E81F	7420 570335	LYUBOV EGOROVA	{"phone": "+70165653692"}
0005432707461	E3566C	0436 395599	SERGEY FILIPPOV	{"phone": "+70696852071"}
0005432707462	E3566C	1521 748813	VLADIMIR TIKHONOV	{"phone": "+70523065810"}
0005432707463	83052C	0320 058090	VERA DMITRIEVA	{"email": "dmitrieva-v1968@postgrespro.ru", "phone": "+70314633586"}
0005432707464	481870	1371 198782	ANDREY DAVYDOV	{"phone": "+70855123971"}
0005432707465	E6F9CA	4802 357969	NIKOLAY FOMIN	{"phone": "+70891528613"}
0005432707466	8D2B52	0544 225566	ALEKSANDR FILIPPOV	{"phone": "+70931931453"}
0005432707467	917989	2929 856825	TAMARA VOLKOVA	{"phone": "+70711258205"}
0005432707468	00B347	1252 341312	VADIM IVANOV	{"phone": "+70860176163"}
0005432707469	C9464A	4554 160574	EGOR KONOVALOV	{"email": "ekonovalov-051967@postgrespro.ru", "phone": "+70100538956"}
0005432707470	214B11	4308 027150	LYUDMILA KOVALEVA	{"email": "l.kovaleva-1970@postgrespro.ru", "phone": "+70358916260"}
0005432707471	214B11	2976 232201	VLADISLAV VOROBEV	{"phone": "+70772829519"}
0005432707472	FDC56C	2640 998900	ELVIRA IVANOVA	{"phone": "+70973236480"}
0005432707475	68D972	0337 929872	ROMAN KONOVALOV	{"email": "konovalovr10061969@postgrespro.ru", "phone": "+70105316307"}
0005432707476	68D972	4857 134258	ELENA DMITRIEVA	{"phone": "+70993392408"}
0005432707477	1752EF	7078 039877	YULIYA NAZAROVA	{"phone": "+70770982387"}
0005432707478	E705C7	5456 206273	ALENA PETROVA	{"phone": "+70293240261"}
0005432707479	E705C7	2584 627818	ALEKSEY POPOV	{"email": "popova_1978@postgrespro.ru", "phone": "+70147236251"}
0005432707480	98861F	8830 391151	NADEZHDA NIKOLAEVA	{"email": "nikolaeva-n23091975@postgrespro.ru", "phone": "+70256764907"}
0005432707481	730AE0	1581 269553	ALEVTINA SOROKINA	{"email": "alevtina-sorokina.121973@postgrespro.ru", "phone": "+70066631714"}
0005432707482	730AE0	5022 086902	VALERIYA NIKOLAEVA	{"phone": "+70938969658"}
0005432707483	9E69E3	0108 673955	PAVEL MOISEEV	{"email": "moiseev.p-19051964@postgrespro.ru", "phone": "+70460891340"}
0005432707484	C20B20	4724 557486	ELENA LOGINOVA	{"phone": "+70441327723"}
0005432707485	89760E	8128 348516	NATALYA ZAYCEVA	{"email": "n-zayceva_011971@postgrespro.ru", "phone": "+70361853924"}
0005432707486	BE1508	1042 248226	ANNA ZHURAVLEVA	{"phone": "+70230052772"}
0005432707487	BBF292	8026 892764	VLADIMIR DENISOV	{"email": "denisov.v_091978@postgrespro.ru", "phone": "+70703279505"}
0005432707488	BBF292	8603 101840	SVETLANA KOLESNIKOVA	{"phone": "+70068336415"}
0005432707489	BBF292	6243 966844	OLGA NIKOLAEVA	{"phone": "+70071852068"}
0005432707490	2F1379	8633 556696	VALENTINA SOLOVEVA	{"phone": "+70201915568"}
0005432707491	2F1379	3461 111530	ALEKSANDR VOROBEV	{"email": "a_vorobev15071973@postgrespro.ru", "phone": "+70658175849"}
0005432707492	2F1379	6962 083193	VYACHESLAV KUZNECOV	{"email": "v_kuznecov.11071975@postgrespro.ru", "phone": "+70846267331"}
0005432707493	9B0F78	1210 253086	ANATOLIY NAUMOV	{"phone": "+70327351440"}
0005432707494	49AA60	3078 163238	ALENA KOMAROVA	{"email": "a_komarova_121971@postgrespro.ru", "phone": "+70206707297"}
0005432707495	8C6E88	0375 562518	VIKTOR KUZMIN	{"phone": "+70056548114"}
0005432707496	E130F7	9188 189579	DARYA ANDREEVA	{"email": "andreeva-darya_041968@postgrespro.ru", "phone": "+70172748942"}
0005432707497	5876B3	7582 042912	DARYA RODIONOVA	{"phone": "+70357582092"}
0005432707498	DD1D66	2953 403172	NINA KOVALEVA	{"email": "kovalevan.11081971@postgrespro.ru", "phone": "+70262358123"}
0005432707499	F939D7	3789 901020	ELENA NIKITINA	{"phone": "+70703908841"}
0005432707500	7B1A8C	3816 591564	YULIYA GERASIMOVA	{"email": "gerasimova-y071960@postgrespro.ru", "phone": "+70217984514"}
0005432707501	7E6551	4195 881303	ALEKSEY VASILEV	{"email": "a.vasilev_031975@postgrespro.ru", "phone": "+70619763635"}
0005432707502	2076EA	1036 540622	ALIYA TARASOVA	{"email": "tarasova_a091972@postgrespro.ru", "phone": "+70284248859"}
0005432707503	6221A3	6164 731439	ALEKSANDR VLASOV	{"phone": "+70834434920"}
0005432707504	6221A3	6441 857733	ANASTASIYA DENISOVA	{"email": "denisovaa.031981@postgrespro.ru", "phone": "+70318264506"}
0005432707505	6221A3	0954 939936	ANDREY ALEKSEEV	{"email": "a_alekseev-01061968@postgrespro.ru", "phone": "+70354323047"}
0005432707506	453D81	4311 719859	IVAN NIKITIN	{"phone": "+70077388083"}
0005432707507	7FAE12	0180 022404	SVETLANA LUKYANOVA	{"phone": "+70387948184"}
0005432707508	E81019	0958 032035	NIKOLAY KULIKOV	{"email": "nikolaykulikov_30101981@postgrespro.ru", "phone": "+70188870939"}
0005432707509	E81019	2555 665004	ALEKSANDR KUZNECOV	{"phone": "+70171623062"}
0005432707510	018505	4511 786594	IVAN KARPOV	{"email": "i.karpov-011976@postgrespro.ru", "phone": "+70009788329"}
0005432720428	47500C	2980 441669	TATYANA SOROKINA	{"email": "sorokina-t101968@postgrespro.ru", "phone": "+70413998243"}
0005432720429	30BE1F	5756 671098	OLESYA LAZAREVA	{"email": "lazarevaolesya_1975@postgrespro.ru", "phone": "+70367966243"}
0005432720430	1B1B67	6529 149085	VITALIY KISELEV	{"email": "vitaliy_kiselev051975@postgrespro.ru", "phone": "+70285325657"}
0005432720431	1B1B67	1266 171910	OLESYA ABRAMOVA	{"phone": "+70594759312"}
0005432720432	4E7E42	6392 429478	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev27051982@postgrespro.ru", "phone": "+70546397137"}
0005432720433	E2BCE2	3974 110061	VIKTOR GORBUNOV	{"phone": "+70788990200"}
0005432720434	E2BCE2	9397 940973	AMIR KUZNECOV	{"email": "kuznecov-amir-021964@postgrespro.ru", "phone": "+70096128890"}
0005432720435	F90435	2856 769134	ANTON MAKAROV	{"phone": "+70209429555"}
0005432720436	F90435	8959 503041	TATYANA SERGEEVA	{"email": "t_sergeeva_081972@postgrespro.ru", "phone": "+70838439084"}
0005432720437	4BA187	6704 482696	ANTONINA NIKOLAEVA	{"email": "a-nikolaeva.071984@postgrespro.ru", "phone": "+70545189077"}
0005432720438	5536AB	2173 563667	ANASTASIYA KONOVALOVA	{"phone": "+70662463767"}
0005432720439	5536AB	5332 001529	LYUDMILA NESTEROVA	{"email": "nesterova.lyudmila_24011965@postgrespro.ru", "phone": "+70881915666"}
0005432720440	DDFDEE	7903 190843	ARTEM TARASOV	{"email": "artem-tarasov_12031975@postgrespro.ru", "phone": "+70183115830"}
0005432720441	DDFDEE	2130 533119	MARAT FEDOTOV	{"email": "mfedotov_031975@postgrespro.ru", "phone": "+70999476306"}
0005432720442	A95A51	7174 625193	DARYA TIKHONOVA	{"email": "darya.tikhonova041985@postgrespro.ru", "phone": "+70834373398"}
0005432720443	C18A4A	1374 867279	ALEKSEY FOMIN	{"email": "a.fomin.1970@postgrespro.ru", "phone": "+70657315964"}
0005432720444	C18A4A	8101 327822	EKATERINA KISELEVA	{"email": "kiseleva.e23051976@postgrespro.ru", "phone": "+70613130358"}
0005432720445	C18A4A	2974 628426	ANNA MELNIKOVA	{"email": "melnikova-a_081967@postgrespro.ru", "phone": "+70491840101"}
0005432720446	D12629	5250 601696	NATALYA LEBEDEVA	{"phone": "+70793961467"}
0005432720447	84BDC7	7992 967884	EVGENIYA KUZNECOVA	{"email": "e.kuznecova26081980@postgrespro.ru", "phone": "+70660875443"}
0005432720448	ECC187	6616 521834	ANATOLIY KUZNECOV	{"phone": "+70109749476"}
0005432720449	ECC187	9551 372181	ANASTASIYA POPOVA	{"email": "popova_a-111972@postgrespro.ru", "phone": "+70888618540"}
0005432720450	4AAD23	5613 980260	NATALYA PETROVA	{"phone": "+70457797791"}
0005432720451	9AC0F8	1637 950429	SERGEY KISELEV	{"email": "kiselevs_03011973@postgrespro.ru", "phone": "+70576953720"}
0005432720452	0B4B45	6074 369873	RAISA FEDOROVA	{"email": "fedorovaraisa_1953@postgrespro.ru", "phone": "+70016143180"}
0005432720453	D48DB3	0322 474591	NADEZHDA FOMINA	{"email": "n-fomina-041972@postgrespro.ru", "phone": "+70310150878"}
0005432720454	D48DB3	7969 548505	SERGEY YAKOVLEV	{"phone": "+70124934965"}
0005432720455	D48DB3	8468 938804	LYUDMILA BELOVA	{"email": "lbelova-02071974@postgrespro.ru", "phone": "+70929093646"}
0005432720456	C5D560	3789 649592	ALEKSEY SOKOLOV	{"phone": "+70222157892"}
0005432720457	4D973D	5057 127961	SERGEY KARPOV	{"phone": "+70649421697"}
0005432720458	27ED50	8948 087153	ELENA IVANOVA	{"phone": "+70362100206"}
0005432720459	27ED50	3925 204227	LYUDMILA NESTEROVA	{"phone": "+70827863846"}
0005432720460	DB9C8D	8918 460136	DMITRIY KUZNECOV	{"phone": "+70952724127"}
0005432720461	DB9C8D	6004 337340	OLGA GUSEVA	{"phone": "+70441961811"}
0005432720462	DB9C8D	4415 328605	RAIL BORISOV	{"phone": "+70938482939"}
0005432720463	A33929	3773 676528	ALEKSANDR IVANOV	{"phone": "+70173703996"}
0005432720464	495F7F	3580 693603	ANASTASIYA STEPANOVA	{"phone": "+70606873891"}
0005432720465	E91D33	6678 777678	LARISA KOZLOVA	{"phone": "+70712818327"}
0005432720466	E91D33	8157 838027	KRISTINA ILINA	{"email": "ilina.kristina.101977@postgrespro.ru", "phone": "+70463171736"}
0005432720467	7F9D73	6782 978311	LYUDMILA IVANOVA	{"phone": "+70693382221"}
0005432720468	EAE1E8	3399 893798	ELENA VASILEVA	{"email": "vasilevaelena_26081968@postgrespro.ru", "phone": "+70573765309"}
0005432720469	EAE1E8	3952 229629	ARTEM PAVLOV	{"phone": "+70764381410"}
0005432720470	B11C6E	4274 172969	OLEG SOKOLOV	{"email": "sokolov_o.1967@postgrespro.ru", "phone": "+70297644604"}
0005432720471	8A6500	7992 399688	ARTUR SERGEEV	{"email": "sergeev.artur_29021972@postgrespro.ru", "phone": "+70587468769"}
0005432720472	9E3067	6424 120979	LYUDMILA VASILEVA	{"phone": "+70698632359"}
0005432720473	1D9F9E	4113 308051	ARTEM TIKHONOV	{"phone": "+70741546792"}
0005432720474	BFC714	5681 094783	IRINA SAVELEVA	{"email": "saveleva_i.21081962@postgrespro.ru", "phone": "+70934065738"}
0005432720475	563FB3	3296 179114	RAFAEL BARANOV	{"email": "rafael_baranov.1984@postgrespro.ru", "phone": "+70839527333"}
0005432720476	1D02E9	4030 894601	NINA MATVEEVA	{"email": "matveeva.n1966@postgrespro.ru", "phone": "+70820288351"}
0005432720477	33D9F5	7715 000065	ANATOLIY PAVLOV	{"phone": "+70672329146"}
0005432720478	E162EC	0823 167683	EKATERINA KUZMINA	{"email": "ekaterina.kuzmina-111967@postgrespro.ru", "phone": "+70755966990"}
0005432720479	05F682	7716 547179	ARSENIY ALEKSEEV	{"phone": "+70777122385"}
0005432720480	B50058	0967 991039	EVGENIYA ANTONOVA	{"phone": "+70909375234"}
0005432720481	B9FAEA	8405 833603	TATYANA OSIPOVA	{"email": "t-osipova.031972@postgrespro.ru", "phone": "+70664020636"}
0005432720482	3A28A4	4349 602493	ALINA NAZAROVA	{"email": "nazarovaa.13081982@postgrespro.ru", "phone": "+70666325582"}
0005432720483	71D239	4806 049863	ANDREY STEPANOV	{"email": "stepanov_a.21011968@postgrespro.ru", "phone": "+70184356197"}
0005432720484	E54F3D	7152 862820	ALEKSEY BARANOV	{"phone": "+70423825062"}
0005432720485	E54F3D	0793 280868	OLEG ORLOV	{"phone": "+70494519153"}
0005432720486	F8121C	3152 044400	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov.25031969@postgrespro.ru", "phone": "+70478466023"}
0005432720487	CF24F4	8361 621950	ELIZAVETA TARASOVA	{"email": "tarasova-elizaveta.091965@postgrespro.ru", "phone": "+70528631287"}
0005432720488	CF24F4	5671 428315	DMITRIY VOLKOV	{"email": "volkov.dmitriy-1965@postgrespro.ru", "phone": "+70110975027"}
0005432720489	A2ABB4	6744 449676	SVETLANA NIKOLAEVA	{"email": "nikolaevas1982@postgrespro.ru", "phone": "+70612243065"}
0005432720490	A2ABB4	1515 646444	GALINA FROLOVA	{"email": "frolova.g1973@postgrespro.ru", "phone": "+70501780447"}
0005432720491	A2ABB4	0559 965660	VLADIMIR NIKITIN	{"email": "nikitin-v1970@postgrespro.ru", "phone": "+70114125252"}
0005432720492	EA05BF	5458 973469	LIDIYA KISELEVA	{"email": "kiseleva_l-1967@postgrespro.ru", "phone": "+70828137391"}
0005432720493	EA05BF	7398 361261	PAVEL ILIN	{"phone": "+70304054499"}
0005432720494	92C169	7784 471547	VYACHESLAV FEDOTOV	{"phone": "+70372086975"}
0005432720495	556294	0857 986412	SVETLANA ZHUKOVA	{"phone": "+70790686216"}
0005432720496	556294	0688 387551	EKATERINA STEPANOVA	{"email": "stepanovaekaterina-1963@postgrespro.ru", "phone": "+70647961061"}
0005432720497	66C251	4621 938519	OLESYA BOGDANOVA	{"email": "bogdanova.olesya.061977@postgrespro.ru", "phone": "+70602586144"}
0005432720498	7E35B1	2663 679716	ALEKSANDR ZAKHAROV	{"phone": "+70100510883"}
0005432720499	27D9B1	2558 068285	PAVEL STEPANOV	{"email": "pstepanov.1968@postgrespro.ru", "phone": "+70804565087"}
0005432720500	FAB73F	5858 363793	SEMEN KULIKOV	{"email": "kulikov_semen1971@postgrespro.ru", "phone": "+70681118642"}
0005432720501	FAB73F	4872 947821	DANIL VASILEV	{"phone": "+70020697016"}
0005432720502	F0C6A0	2472 137532	VALENTINA MARTYNOVA	{"email": "martynova.valentina-17071981@postgrespro.ru", "phone": "+70813349649"}
0005432720503	F0C6A0	7312 109745	PAVEL MOROZOV	{"phone": "+70041244638"}
0005432720504	D77DAA	8719 767574	VASILIY BONDARENKO	{"phone": "+70585932479"}
0005432720505	3C9712	2083 172060	VITALIY DAVYDOV	{"phone": "+70276087841"}
0005432720506	924DE4	3546 557420	VIKTOR GAVRILOV	{"phone": "+70942341816"}
0005432720507	A59259	4678 186071	SVETLANA BORISOVA	{"email": "s.borisova_24041982@postgrespro.ru", "phone": "+70775595960"}
0005432720508	A59259	4851 536566	ANNA MEDVEDEVA	{"email": "medvedeva.anna1977@postgrespro.ru", "phone": "+70713115169"}
0005432720509	48B38D	9044 326868	POLINA SAVELEVA	{"email": "p_saveleva26011967@postgrespro.ru", "phone": "+70859182155"}
0005432720510	065659	0927 496295	ILYAS KOZLOV	{"phone": "+70017407464"}
0005432720511	64EDE9	9680 957989	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr.13021969@postgrespro.ru", "phone": "+70799178412"}
0005432720512	64EDE9	8162 350360	ALEKSANDR NOVIKOV	{"phone": "+70617691857"}
0005432720513	4FED4E	0841 572173	ALEKSEY MAKAROV	{"phone": "+70815975379"}
0005432720514	DFD630	1463 512085	LYUBOV ABRAMOVA	{"email": "abramova_lyubov-09101975@postgrespro.ru", "phone": "+70536759465"}
0005432720515	BCB4C2	5750 617862	ALENA LEBEDEVA	{"phone": "+70087467542"}
0005432720516	D08C49	3740 059382	ANNA TROFIMOVA	{"email": "a.trofimova17101964@postgrespro.ru", "phone": "+70589120361"}
0005432720517	D08C49	2469 506702	DMITRIY TARASOV	{"email": "dmitriy.tarasov-22041965@postgrespro.ru", "phone": "+70219588399"}
0005432720518	D08C49	8974 014304	IGOR IVANOV	{"phone": "+70649144827"}
0005432720519	E5EA2D	5936 091381	NIKOLAY IVANOV	{"email": "ivanovn_1986@postgrespro.ru", "phone": "+70703698491"}
0005432720520	51852D	1338 288108	ALEKSANDR PAVLOV	{"phone": "+70305292387"}
0005432720521	51852D	2579 449682	ELENA SOROKINA	{"phone": "+70484690170"}
0005432720522	51852D	2565 405074	ANTONINA SOROKINA	{"email": "sorokina_antonina111969@postgrespro.ru", "phone": "+70603116541"}
0005432720523	10BF6F	6718 371847	MAKAR SEMENOV	{"phone": "+70783738541"}
0005432720524	478C96	1918 785654	LYUBOV ZAYCEVA	{"email": "l_zayceva_22021963@postgrespro.ru", "phone": "+70479445618"}
0005432720525	478C96	2240 443623	ALEKSANDRA MOISEEVA	{"phone": "+70670275211"}
0005432720526	AD6DD4	5739 070604	NINA SCHERBAKOVA	{"phone": "+70817588620"}
0005432720527	3F5492	7843 781739	DARYA KUZNECOVA	{"email": "kuznecova_darya.1974@postgrespro.ru", "phone": "+70112263400"}
0005432720528	641403	6465 357229	SERGEY SAVELEV	{"email": "savelev.s-06031978@postgrespro.ru", "phone": "+70100668732"}
0005432720529	641403	0445 174216	OLGA NIKOLAEVA	{"phone": "+70389374227"}
0005432720530	EF9EDE	3027 114610	SERGEY MOROZOV	{"phone": "+70129407120"}
0005432720531	08C023	5038 721604	KONSTANTIN ROMANOV	{"phone": "+70775476927"}
0005432720532	56A71B	9794 488411	LEV SOLOVEV	{"phone": "+70444260328"}
0005432720533	AF33EF	1209 947583	PAVEL MATVEEV	{"phone": "+70644154803"}
0005432720534	26CCFC	1333 821999	SERGEY MIKHAYLOV	{"phone": "+70316077976"}
0005432720535	26CCFC	8785 567503	SERGEY NAZAROV	{"phone": "+70582634594"}
0005432720536	51BABB	9677 365001	ANASTASIYA SIDOROVA	{"phone": "+70240606366"}
0005432720537	51BABB	7548 170551	OKSANA NAUMOVA	{"phone": "+70035615657"}
0005432720538	63C395	4475 130994	DMITRIY FOMIN	{"email": "fomin.dmitriy_1975@postgrespro.ru", "phone": "+70252183862"}
0005432720539	687944	1826 546059	LYUDMILA VASILEVA	{"email": "lyudmilavasileva-26081963@postgrespro.ru", "phone": "+70090698656"}
0005432720540	F0AE9E	0174 750018	VARVARA SEMENOVA	{"email": "v.semenova.1970@postgrespro.ru", "phone": "+70303107511"}
0005432720541	851DA2	1014 774836	ANTON TIMOFEEV	{"phone": "+70592579312"}
0005432720542	A81298	3577 259421	VERA MARTYNOVA	{"email": "martynova-vera-17011974@postgrespro.ru", "phone": "+70145478603"}
0005432720543	A81298	2924 193969	ANASTASIYA EGOROVA	{"email": "egorova_anastasiya_20051979@postgrespro.ru", "phone": "+70474873697"}
0005432720544	902DAE	6774 212270	BORIS ZHURAVLEV	{"phone": "+70852410818"}
0005432720545	902DAE	5208 635601	RAISA DENISOVA	{"phone": "+70375591906"}
0005432720546	3F1BEE	0897 016311	IRINA GERASIMOVA	{"email": "irinagerasimova-1964@postgrespro.ru", "phone": "+70109700458"}
0005432720547	AEABFB	7521 632993	VENERA VOROBEVA	{"phone": "+70573262171"}
0005432720548	0C45E6	7524 512086	NATALYA MIKHAYLOVA	{"phone": "+70051699184"}
0005432720549	27A525	1129 194050	ROMAN EGOROV	{"phone": "+70364170620"}
0005432720550	27A525	4677 677783	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay_111983@postgrespro.ru", "phone": "+70154189639"}
0005432720551	6019A0	0723 586757	ANNA POPOVA	{"email": "a.popova_20061971@postgrespro.ru", "phone": "+70953025819"}
0005432720552	782E23	3513 712575	EKATERINA POPOVA	{"phone": "+70246592133"}
0005432720553	782E23	1758 250897	MARIYA GERASIMOVA	{"phone": "+70912969571"}
0005432720554	430E14	0253 886033	DMITRIY SOLOVEV	{"phone": "+70745013088"}
0005432720555	49F582	2533 689052	GENNADIY ALEKSEEV	{"email": "alekseev_g_1985@postgrespro.ru", "phone": "+70355747244"}
0005432720556	49F582	1993 950560	MAKSIM FEDOTOV	{"phone": "+70164634222"}
0005432720557	C2F0B6	7825 413645	VLADIMIR SERGEEV	{"email": "v.sergeev-081979@postgrespro.ru", "phone": "+70874424075"}
0005432720558	FA4464	1158 801613	ALEKSANDR SEMENOV	{"phone": "+70779432477"}
0005432720559	FA4464	5120 323507	GALINA RODIONOVA	{"email": "rodionova.galina-041963@postgrespro.ru", "phone": "+70742077414"}
0005432720560	FA4464	9337 212189	YULIYA KUZNECOVA	{"email": "y.kuznecova_05031968@postgrespro.ru", "phone": "+70442395937"}
0005432720561	F8117F	6462 304880	VLADIMIR ROMANOV	{"email": "romanov.v1964@postgrespro.ru", "phone": "+70107151643"}
0005432720562	F8117F	5762 833045	ALEKSANDR MIRONOV	{"email": "a-mironov17051973@postgrespro.ru", "phone": "+70818715242"}
0005432720563	F8117F	8346 754244	EVGENIY BONDARENKO	{"phone": "+70106628827"}
0005432720564	7B53BB	1831 250180	GEORGIY GAVRILOV	{"email": "gavrilov_g1971@postgrespro.ru", "phone": "+70886514619"}
0005432720565	2F2281	8578 023481	IVAN KRASNOV	{"email": "ivankrasnov.24111966@postgrespro.ru", "phone": "+70909555215"}
0005432720566	2F2281	0970 494859	ANZHELA ILINA	{"email": "ilina-a_1963@postgrespro.ru", "phone": "+70319239937"}
0005432720567	8DFD4B	1962 048174	VASILIY VOROBEV	{"email": "vasiliy.vorobev1966@postgrespro.ru", "phone": "+70191775685"}
0005432720568	69B048	1116 971177	ELENA MARTYNOVA	{"email": "elena-martynova_1978@postgrespro.ru", "phone": "+70872451083"}
0005432720569	51F467	4689 657808	ANNA VLASOVA	{"email": "vlasovaa-051979@postgrespro.ru", "phone": "+70467193497"}
0005432720570	44B23C	7746 444329	OLGA NAZAROVA	{"email": "o.nazarova_1985@postgrespro.ru", "phone": "+70336963285"}
0005432720571	542BA0	6945 794717	OLGA IVANOVA	{"email": "o.ivanova10031976@postgrespro.ru", "phone": "+70322884060"}
0005432720572	542BA0	7108 094427	FELIKS MARTYNOV	{"email": "f-martynov_051980@postgrespro.ru", "phone": "+70313368237"}
0005432720573	688EAB	3036 529258	ANDREY MARTYNOV	{"email": "martynovandrey-1977@postgrespro.ru", "phone": "+70838880120"}
0005432720574	688EAB	3137 707621	KIRILL IVANOV	{"phone": "+70994513603"}
0005432720575	9658B3	8564 427446	MARIYA STEPANOVA	{"phone": "+70561341127"}
0005432720576	732CFE	7827 414569	VLADISLAV EGOROV	{"email": "egorovv-031980@postgrespro.ru", "phone": "+70264250804"}
0005432720577	FDD5FD	3452 039613	NATALYA ALEKSANDROVA	{"email": "aleksandrova.n-101971@postgrespro.ru", "phone": "+70888971796"}
0005432720578	E950F6	3418 871315	ELENA POPOVA	{"email": "popovaelena.061973@postgrespro.ru", "phone": "+70081853721"}
0005432720579	5C42D9	5800 154954	ANDREY KUZMIN	{"phone": "+70804672673"}
0005432720580	EB947A	7796 446818	SVETLANA NIKIFOROVA	{"phone": "+70140548724"}
0005432720581	EB947A	3109 849518	VALENTINA POPOVA	{"phone": "+70851143872"}
0005432720582	F4214C	3646 914594	SERGEY KISELEV	{"phone": "+70404545132"}
0005432720583	3203D7	6255 286989	LYUDMILA NESTEROVA	{"email": "lyudmila-nesterova-1971@postgrespro.ru", "phone": "+70313507963"}
0005432720584	3203D7	3810 877524	IRINA TARASOVA	{"email": "tarasova.irina111967@postgrespro.ru", "phone": "+70666167098"}
0005432720585	9953B7	8296 501014	VITALIY NIKOLAEV	{"email": "nikolaev-v.041969@postgrespro.ru", "phone": "+70936788284"}
0005432720586	8C2ADB	7498 425654	SERGEY IVANOV	{"email": "ivanov_sergey-081973@postgrespro.ru", "phone": "+70452454027"}
0005432720587	8C2ADB	8202 349870	NATALYA NOVIKOVA	{"phone": "+70206986768"}
0005432720588	8C2ADB	9135 448053	ILYA SOLOVEV	{"phone": "+70477102189"}
0005432720589	A9ACBF	0874 510877	LEV MAKSIMOV	{"email": "l_maksimov-061976@postgrespro.ru", "phone": "+70168610569"}
0005432720590	1F1AA7	5485 893912	ALLA DENISOVA	{"phone": "+70157921053"}
0005432720591	21A6B0	0132 455169	VIKTOR PAVLOV	{"email": "viktor.pavlov-021979@postgrespro.ru", "phone": "+70866626067"}
0005432720592	55357B	2056 756954	KIRILL NAUMOV	{"email": "naumovkirill-1971@postgrespro.ru", "phone": "+70484083243"}
0005432720593	51F11D	0538 999779	TATYANA GUSEVA	{"phone": "+70988345397"}
0005432720594	51F11D	7218 963938	IGOR MOROZOV	{"email": "morozov.i091973@postgrespro.ru", "phone": "+70047928665"}
0005432720595	1F81CC	8735 095797	ALINA IVANOVA	{"phone": "+70924117247"}
0005432720596	E35DDF	3892 419532	LIDIYA EFIMOVA	{"phone": "+70500718959"}
0005432720597	E35DDF	8798 440841	NATALYA GORBUNOVA	{"phone": "+70105471443"}
0005432720598	F48554	8236 034947	VIKTORIYA TIKHONOVA	{"phone": "+70161357523"}
0005432720599	0F9917	6902 785250	NADEZHDA NOVIKOVA	{"email": "nadezhda_novikova.11051970@postgrespro.ru", "phone": "+70399359304"}
0005432720600	0F9917	0797 898943	LILIYA SEMENOVA	{"phone": "+70722144143"}
0005432720601	A934DA	3950 106762	IGOR ORLOV	{"email": "igororlov.1971@postgrespro.ru", "phone": "+70795235512"}
0005432720602	4004E1	4277 194671	OLGA GERASIMOVA	{"phone": "+70390907297"}
0005432720603	C5EC21	0814 868839	YAROSLAV SEMENOV	{"phone": "+70776291192"}
0005432720604	C5EC21	9808 319519	ANDREY GUSEV	{"email": "a-gusev.11121976@postgrespro.ru", "phone": "+70034424571"}
0005432720605	E7B04A	6573 956227	NINA VOROBEVA	{"email": "n_vorobeva.24031963@postgrespro.ru", "phone": "+70241184025"}
0005432720606	0EC844	1081 120580	VLADIMIR BORISOV	{"email": "borisov_v101969@postgrespro.ru", "phone": "+70137975889"}
0005432720607	0EC844	1802 903783	VALERIY SCHERBAKOV	{"phone": "+70246109274"}
0005432720608	11C5A7	9420 758021	KSENIYA EGOROVA	{"email": "egorova.k.27091963@postgrespro.ru", "phone": "+70894190678"}
0005432720609	11C5A7	6315 438175	ALEKSEY MOISEEV	{"email": "aleksey.moiseev121981@postgrespro.ru", "phone": "+70576400876"}
0005432720610	879455	1365 026105	VALENTINA KONOVALOVA	{"email": "konovalova-v.121971@postgrespro.ru", "phone": "+70846897430"}
0005432720611	BEE09D	2377 262692	ELENA MIKHAYLOVA	{"email": "elena_mikhaylova-1982@postgrespro.ru", "phone": "+70077666517"}
0005432720612	BEE09D	4132 423735	VYACHESLAV KRASNOV	{"email": "v.krasnov21121966@postgrespro.ru", "phone": "+70903477436"}
0005432720613	BEE09D	4696 857608	NADEZHDA MOISEEVA	{"phone": "+70856780276"}
0005432720614	558AF2	8517 211773	OLEG NOVIKOV	{"email": "onovikov_101968@postgrespro.ru", "phone": "+70326003540"}
0005432720615	0B23DC	6002 802228	SVETLANA GRISHINA	{"phone": "+70598042711"}
0005432720616	0B23DC	8266 354936	VALENTIN SOKOLOV	{"phone": "+70798422345"}
0005432720617	CB3FD2	9324 028142	LIDIYA KOROLEVA	{"email": "koroleva-lidiya_021968@postgrespro.ru", "phone": "+70495657127"}
0005432720618	F14D9E	8593 249204	OKSANA SOROKINA	{"phone": "+70735160739"}
0005432720619	F14D9E	6097 011086	ELIZAVETA KULIKOVA	{"email": "e_kulikova.031976@postgrespro.ru", "phone": "+70636001398"}
0005432720620	E4FB44	9500 192816	MAKSIM VOLKOV	{"phone": "+70604457626"}
0005432720621	E4FB44	5717 882802	SOFYA KULIKOVA	{"email": "kulikova-sofya_1968@postgrespro.ru", "phone": "+70475598551"}
0005432720622	50F5DA	2543 820590	OKSANA NESTEROVA	{"email": "nesterova-oksana_051970@postgrespro.ru", "phone": "+70003239495"}
0005432720623	D460D9	1102 227996	ALBINA KARPOVA	{"email": "albina.karpova-16121979@postgrespro.ru", "phone": "+70036411881"}
0005432720624	D460D9	2596 388182	IRINA MAKSIMOVA	{"email": "maksimovairina.08051976@postgrespro.ru", "phone": "+70699245290"}
0005432720625	4473F9	6858 924112	NIKOLAY MOISEEV	{"email": "moiseev_nikolay-011977@postgrespro.ru", "phone": "+70816996567"}
0005432720626	6AC35B	4915 732421	ELENA MELNIKOVA	{"phone": "+70475752558"}
0005432720627	6AC35B	6975 910608	EVGENIYA FROLOVA	{"email": "efrolova.071977@postgrespro.ru", "phone": "+70323809062"}
0005432720628	6AC35B	4084 797187	NATALYA BELOVA	{"phone": "+70238042188"}
0005432720629	6AF670	8472 667633	OLGA NAUMOVA	{"phone": "+70752426032"}
0005432720630	E2245E	2161 741396	ELEONORA LOGINOVA	{"email": "loginova.eleonora_28111959@postgrespro.ru", "phone": "+70709444912"}
0005432720631	9DA6F1	1269 654408	GALINA ZHUKOVA	{"email": "zhukova.g091979@postgrespro.ru", "phone": "+70500464087"}
0005432720632	FE3941	1418 331077	ELENA KULIKOVA	{"email": "kulikova.elena13091965@postgrespro.ru", "phone": "+70051199397"}
0005432720633	36B4B9	4256 130723	DAMIR DAVYDOV	{"phone": "+70005475118"}
0005432720634	36B4B9	8512 903471	ALEKSEY KOROLEV	{"email": "korolev-aleksey_041970@postgrespro.ru", "phone": "+70795633374"}
0005432720635	75B573	6745 009816	MARIYA PETROVA	{"phone": "+70275569480"}
0005432720636	75B573	6445 052825	EKATERINA LUKYANOVA	{"email": "lukyanovae-10031969@postgrespro.ru", "phone": "+70347086860"}
0005432720637	7D362D	1094 122388	MARK MAKSIMOV	{"email": "maksimov_mark-111969@postgrespro.ru", "phone": "+70997201440"}
0005432720638	51BA8F	0176 343997	LYUDMILA KUZNECOVA	{"email": "kuznecova-l27051963@postgrespro.ru", "phone": "+70932059932"}
0005432720639	4CDF09	9971 835632	EKATERINA IVANOVA	{"phone": "+70448136241"}
0005432720640	CFBBE2	2177 730734	NADEZHDA SERGEEVA	{"email": "nadezhda_sergeeva-16031984@postgrespro.ru", "phone": "+70766634885"}
0005432720641	8E0E2D	5355 873320	ANFISA STEPANOVA	{"phone": "+70557963095"}
0005432720642	8E0E2D	3900 944507	ANNA TIMOFEEVA	{"email": "timofeeva-anna1972@postgrespro.ru", "phone": "+70792016906"}
0005432720643	8E0E2D	2172 032928	OLGA POLYAKOVA	{"phone": "+70801022677"}
0005432720644	7F8093	4448 926097	VIKTORIYA POPOVA	{"phone": "+70773233631"}
0005432720645	7F8093	6266 213642	TAMARA KOROLEVA	{"phone": "+70775874948"}
0005432720646	7931AD	2392 550687	NADEZHDA MOISEEVA	{"email": "nadezhda_moiseeva24091972@postgrespro.ru", "phone": "+70436525676"}
0005432720647	20DA83	3035 177826	OLEG IVANOV	{"email": "ivanov.oleg-11091963@postgrespro.ru", "phone": "+70119796989"}
0005432720648	20DA83	6950 012578	NIKOLAY SOLOVEV	{"email": "nikolay.solovev1976@postgrespro.ru", "phone": "+70771066353"}
0005432720649	91E57C	3873 476954	NATALYA TIKHONOVA	{"phone": "+70179100795"}
0005432720650	BD3DFA	0429 769213	EKATERINA KRASNOVA	{"email": "e_krasnova-011972@postgrespro.ru", "phone": "+70208456033"}
0005432720651	DCFBA6	2724 704279	ANASTASIYA LAZAREVA	{"email": "lazareva.anastasiya.18121967@postgrespro.ru", "phone": "+70511990143"}
0005432720652	7392EA	0619 543356	ALBINA IVANOVA	{"phone": "+70005884431"}
0005432720653	527A3D	0105 097511	OLGA MIRONOVA	{"phone": "+70890521504"}
0005432720654	D52F03	9853 791998	MARIYA IVANOVA	{"phone": "+70079471374"}
0005432720655	2B256B	6753 416514	OKSANA FADEEVA	{"phone": "+70352471402"}
0005432720656	2B256B	1654 391836	VALERIY ZHUKOV	{"phone": "+70382825213"}
0005432720657	7BACCB	6463 450322	EKATERINA BORISOVA	{"phone": "+70465668101"}
0005432720658	7BACCB	9586 137734	NINA KUZMINA	{"phone": "+70468239390"}
0005432720659	483F9F	6928 778213	GALINA TIKHONOVA	{"phone": "+70610194415"}
0005432720660	22C5C2	3296 863509	EVGENIY SEMENOV	{"email": "semenov-evgeniy_07011969@postgrespro.ru", "phone": "+70210086868"}
0005432720661	DB4127	6904 987860	MARIYA STEPANOVA	{"email": "mstepanova-29011980@postgrespro.ru", "phone": "+70483434873"}
0005432720662	E02F7A	4280 965670	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya.031981@postgrespro.ru", "phone": "+70018780706"}
0005432720663	E02F7A	4736 714441	YULIYA KISELEVA	{"phone": "+70113573802"}
0005432720664	108CE1	1502 848735	KIRILL ANDREEV	{"phone": "+70705443508"}
0005432720665	3BFE32	8283 852658	NIKOLAY PAVLOV	{"email": "n.pavlov011965@postgrespro.ru", "phone": "+70210816040"}
0005432720666	46C6F2	7586 640490	NIKITA FEDOROV	{"email": "nikita_fedorov-111978@postgrespro.ru", "phone": "+70909762847"}
0005432720667	E2562E	8332 637047	NIKITA NIKOLAEV	{"phone": "+70804265225"}
0005432720668	9F3045	3889 157049	NADEZHDA KALININA	{"phone": "+70352835306"}
0005432720669	BEBDBA	4884 668972	NATALYA BORISOVA	{"phone": "+70140752809"}
0005432720670	BEBDBA	6929 034461	ZINAIDA ZHUKOVA	{"email": "zhukova-zinaida25041972@postgrespro.ru", "phone": "+70209763818"}
0005432720671	791218	7943 655824	ROMAN ANDREEV	{"email": "r-andreev-1975@postgrespro.ru", "phone": "+70191953957"}
0005432720672	F4FAFD	2936 481852	SERGEY KULIKOV	{"email": "sergey-kulikov-06051971@postgrespro.ru", "phone": "+70780355097"}
0005432720673	F4FAFD	0176 806160	NURLAN MIRONOV	{"email": "mironov.nurlan-1967@postgrespro.ru", "phone": "+70837954561"}
0005432720674	AD77E9	0770 173505	VALENTINA SOROKINA	{"phone": "+70100285084"}
0005432720675	AD77E9	8658 708460	GENNADIY KUZMIN	{"email": "gennadiy-kuzmin_1971@postgrespro.ru", "phone": "+70064788457"}
0005432720676	00B168	1516 504000	OLGA SAVELEVA	{"email": "saveleva_olga_091975@postgrespro.ru", "phone": "+70432483653"}
0005432720677	93589C	7941 872147	RAMIL SERGEEV	{"phone": "+70325285636"}
0005432720678	4D7B56	5981 367466	RAISA ILINA	{"email": "ilinaraisa-011966@postgrespro.ru", "phone": "+70864460887"}
0005432720679	C4AF43	1421 029188	ALEKSANDR ORLOV	{"email": "orlovaleksandr05121976@postgrespro.ru", "phone": "+70465563906"}
0005432720680	50E622	4853 008877	ANATOLIY SOLOVEV	{"phone": "+70412699477"}
0005432720681	4AC17B	0465 130527	MAKSIM ZAYCEV	{"email": "zaycev_maksim.1974@postgrespro.ru", "phone": "+70367439199"}
0005432720682	86C89A	2691 272867	ELENA GORBUNOVA	{"email": "gorbunova_e.071964@postgrespro.ru", "phone": "+70308542695"}
0005432720683	7353D1	8080 615723	NATALYA ARKHIPOVA	{"email": "arkhipova.n-28091959@postgrespro.ru", "phone": "+70561489826"}
0005432720739	A11DEB	3260 764431	VADIM MIKHAYLOV	{"phone": "+70161499524"}
0005432720684	11DC3D	5826 687870	ALEKSANDR ANDREEV	{"email": "andreevaleksandr1972@postgrespro.ru", "phone": "+70412497007"}
0005432720685	11DC3D	4717 370846	TATYANA AFANASEVA	{"email": "t_afanaseva10021968@postgrespro.ru", "phone": "+70565140091"}
0005432720686	A4E915	3098 758351	ELENA MASLOVA	{"phone": "+70173333986"}
0005432720687	55E3CB	8819 841006	SERGEY KUZNECOV	{"phone": "+70513064923"}
0005432720688	55E3CB	6880 696687	ANNA ARKHIPOVA	{"phone": "+70104112571"}
0005432720689	55E3CB	0779 604316	OLGA GAVRILOVA	{"email": "gavrilova.o_091972@postgrespro.ru", "phone": "+70581772641"}
0005432720690	4F7E95	7888 391733	MARIYA ALEKSANDROVA	{"email": "maleksandrova18061967@postgrespro.ru", "phone": "+70328456736"}
0005432720691	4F7E95	8660 593972	ELENA MARTYNOVA	{"phone": "+70979414578"}
0005432720692	F156CA	3654 105315	ALEKSEY SEMENOV	{"phone": "+70847105269"}
0005432720693	AADFE9	5932 413968	ANNA SEMENOVA	{"email": "semenovaa.1966@postgrespro.ru", "phone": "+70623968503"}
0005432720694	CEC2E9	9715 131356	ANFISA ISAEVA	{"email": "a_isaeva15121977@postgrespro.ru", "phone": "+70379892077"}
0005432720695	3635DB	0568 265097	ALEKSANDR BORISOV	{"email": "borisova-1968@postgrespro.ru", "phone": "+70675543863"}
0005432720696	55BB4B	5387 851088	LIDIYA PAVLOVA	{"email": "lidiya-pavlova29041969@postgrespro.ru", "phone": "+70351507926"}
0005432720697	55BB4B	3343 330187	ANASTASIYA FILATOVA	{"phone": "+70363661428"}
0005432720698	55BB4B	6793 694378	ALEKSANDR EGOROV	{"phone": "+70472718722"}
0005432720699	1FD834	4587 747871	GEORGIY POPOV	{"email": "gpopov14121973@postgrespro.ru", "phone": "+70823338931"}
0005432720700	48F452	8621 091371	ALEKSANDRA NIKITINA	{"email": "nikitina-aleksandra_1978@postgrespro.ru", "phone": "+70478986762"}
0005432720758	9F0DB5	6819 021700	VLADIMIR SEMENOV	{"phone": "+70940985176"}
0005432720701	48F452	2805 664381	NADEZHDA KUZNECOVA	{"email": "kuznecovan011978@postgrespro.ru", "phone": "+70202751631"}
0005432720702	48F452	5213 786896	LYUDMILA KRASNOVA	{"phone": "+70944190662"}
0005432720703	FBFB28	8528 323354	PAVEL STEPANOV	{"email": "stepanovpavel-021984@postgrespro.ru", "phone": "+70042298381"}
0005432720704	FBFB28	0367 952605	KONSTANTIN CHERNOV	{"phone": "+70521932514"}
0005432720705	251008	8995 428409	EVGENIY NOVIKOV	{"phone": "+70829426424"}
0005432720706	5B7852	1463 500220	ANASTASIYA SEMENOVA	{"email": "anastasiya.semenova.1978@postgrespro.ru", "phone": "+70969168613"}
0005432720707	5B7852	0874 178415	LYUBOV SIDOROVA	{"phone": "+70622758147"}
0005432720708	8768D2	6775 941194	RUDOLF MOROZOV	{"email": "morozovr-1967@postgrespro.ru", "phone": "+70028065959"}
0005432720709	E60EB3	3157 869896	GALINA KARPOVA	{"email": "g-karpova_021976@postgrespro.ru", "phone": "+70698986359"}
0005432720710	CA455C	3564 216933	EVGENIY MAKSIMOV	{"phone": "+70164629616"}
0005432720711	78BEEE	7750 076575	GENNADIY BARANOV	{"phone": "+70174441624"}
0005432720712	37B872	1440 020546	MARIYA ALEKSEEVA	{"phone": "+70701653201"}
0005432720713	D73135	3966 734713	NATALYA NESTEROVA	{"phone": "+70761405748"}
0005432720714	0FF9D2	9382 099169	LARISA MIRONOVA	{"email": "mironova-l.121970@postgrespro.ru", "phone": "+70324111428"}
0005432720715	B8F301	5430 564667	IGOR ZAYCEV	{"phone": "+70268034205"}
0005432720716	79FDE8	3408 196762	EGOR SCHERBAKOV	{"email": "e-scherbakov-041978@postgrespro.ru", "phone": "+70957975981"}
0005432720717	8FA579	9817 318152	SVETLANA STEPANOVA	{"email": "svetlana_stepanova-1970@postgrespro.ru", "phone": "+70782033155"}
0005432720718	8FA579	2537 531940	IVAN SCHERBAKOV	{"email": "scherbakovivan021975@postgrespro.ru", "phone": "+70507637073"}
0005432720719	8FA579	6632 045411	VALERIYA FILIPPOVA	{"email": "filippova.valeriya_1969@postgrespro.ru", "phone": "+70069044562"}
0005432720720	AC257B	7102 614773	YULIYA KUZNECOVA	{"phone": "+70368725271"}
0005432720721	9812FC	5429 679669	IRINA KOZLOVA	{"email": "kozlovai_03101982@postgrespro.ru", "phone": "+70285235424"}
0005432720722	583E99	8917 430689	SERGEY SIDOROV	{"phone": "+70481265330"}
0005432720723	3C9CFC	1303 275822	ELIZAVETA ILINA	{"email": "ilinaelizaveta-081978@postgrespro.ru", "phone": "+70495471041"}
0005432720724	4A19F6	4628 245354	ELMIRA ALEKSEEVA	{"email": "alekseeva.e.091971@postgrespro.ru", "phone": "+70286601368"}
0005432720725	4E7837	3551 881259	RAISA SEMENOVA	{"email": "rsemenova_29121972@postgrespro.ru", "phone": "+70756907784"}
0005432720726	4E7837	6250 128449	PAVEL DAVYDOV	{"email": "davydovp.071980@postgrespro.ru", "phone": "+70647454554"}
0005432720727	0A2DCD	4480 690841	KARINA MELNIKOVA	{"email": "k.melnikova.1972@postgrespro.ru", "phone": "+70724059892"}
0005432720728	2DCA55	5141 182651	VIKTORIYA ANDREEVA	{"email": "andreeva.v1973@postgrespro.ru", "phone": "+70558591081"}
0005432720729	6B26D5	0081 136349	NADEZHDA GAVRILOVA	{"email": "gavrilova_n.21031979@postgrespro.ru", "phone": "+70548824788"}
0005432720730	5F28E5	4859 706940	ALEKSANDR KRASNOV	{"phone": "+70714485430"}
0005432720731	5F28E5	3771 902205	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy011966@postgrespro.ru", "phone": "+70587675399"}
0005432720732	E7F770	9046 011231	VIKTOR IVANOV	{"phone": "+70703765850"}
0005432720733	E7F770	5951 226855	GLEB SIDOROV	{"email": "g_sidorov-10021962@postgrespro.ru", "phone": "+70235825154"}
0005432720734	010562	1044 981430	VLADIMIR MAKSIMOV	{"email": "v-maksimov.27111984@postgrespro.ru", "phone": "+70016106377"}
0005432720735	280E19	8643 169604	SVETLANA FEDOROVA	{"phone": "+70953131478"}
0005432720736	68A314	1793 240198	ANATOLIY DENISOV	{"email": "denisov-anatoliy.011977@postgrespro.ru", "phone": "+70940143133"}
0005432720737	3EC6D4	0687 633762	IVAN ZHUKOV	{"email": "zhukov-ivan061972@postgrespro.ru", "phone": "+70320598345"}
0005432720738	3EC6D4	7926 775926	RENATA TROFIMOVA	{"phone": "+70430379297"}
0005432720740	D29EBE	2035 156544	VIKTOR VOLKOV	{"phone": "+70557420727"}
0005432720741	7B07A9	1892 746048	NIKOLAY MEDVEDEV	{"email": "n_medvedev_1975@postgrespro.ru", "phone": "+70950764301"}
0005432720742	7B07A9	0102 940018	ALEKSANDR KUZNECOV	{"email": "a_kuznecov101974@postgrespro.ru", "phone": "+70304031579"}
0005432720743	07F14E	1083 140238	ALEKSEY TIMOFEEV	{"phone": "+70956804348"}
0005432720744	4D414D	5419 203270	ILNAR TARASOV	{"email": "ilnar-tarasov1986@postgrespro.ru", "phone": "+70466506398"}
0005432720745	4D414D	5257 400022	ANDREY SHEVCHENKO	{"phone": "+70603541276"}
0005432720746	CF55B3	8734 070170	NIKOLAY SOKOLOV	{"email": "n_sokolov1976@postgrespro.ru", "phone": "+70186267275"}
0005432720747	13444A	9476 650950	ELENA MOROZOVA	{"phone": "+70708555263"}
0005432720748	560114	0023 630224	DMITRIY STEPANOV	{"email": "stepanovdmitriy.031980@postgrespro.ru", "phone": "+70861700833"}
0005432720749	8A9868	6821 419787	YULIYA KAZAKOVA	{"phone": "+70162885656"}
0005432720750	7BC162	0255 291561	YULIYA VOLKOVA	{"phone": "+70504576514"}
0005432720751	8F16D2	6087 539083	IRINA KOZLOVA	{"email": "i.kozlova_1992@postgrespro.ru", "phone": "+70071727896"}
0005432720752	25FF1A	6340 595563	ALEKSANDRA TARASOVA	{"phone": "+70526855405"}
0005432720753	25FF1A	5514 824393	MIKHAIL DMITRIEV	{"email": "m-dmitriev_26041979@postgrespro.ru", "phone": "+70581106299"}
0005432720754	6D9434	4623 407446	IRINA KISELEVA	{"email": "i_kiseleva.1971@postgrespro.ru", "phone": "+70092440888"}
0005432720755	383810	5598 570107	VLADIMIR NAZAROV	{"email": "nazarovvladimir_1964@postgrespro.ru", "phone": "+70013467773"}
0005432720756	19CA08	7229 143816	MARIYA DAVYDOVA	{"phone": "+70686862628"}
0005432720757	19CA08	7396 181260	ANASTASIYA FROLOVA	{"phone": "+70556694077"}
0005432720759	9F0DB5	8079 427575	OLGA FILATOVA	{"email": "o.filatova_23091973@postgrespro.ru", "phone": "+70705361875"}
0005432720760	F60BBA	8625 957961	DENIS BORISOV	{"email": "borisovdenis_1963@postgrespro.ru", "phone": "+70174497216"}
0005432720761	0DAC68	2499 392330	ELENA KUZMINA	{"email": "kuzmina.e_1965@postgrespro.ru", "phone": "+70586381428"}
0005432720762	0DAC68	6849 157163	VALERIY ANDREEV	{"email": "andreev.v.1978@postgrespro.ru", "phone": "+70952280782"}
0005432720823	FB2D05	5072 778758	ALEKSANDR DENISOV	{"phone": "+70408359491"}
0005432720763	BF16DC	9619 799524	VALENTINA CHERNOVA	{"email": "valentina-chernova021973@postgrespro.ru", "phone": "+70739982784"}
0005432720764	BF16DC	7738 282304	IVAN ALEKSEEV	{"email": "alekseev-i.16111974@postgrespro.ru", "phone": "+70593709147"}
0005432720765	125713	5909 914169	OKSANA SOROKINA	{"phone": "+70959738525"}
0005432720766	2D6F7D	8276 488304	ELIZAVETA MIKHAYLOVA	{"phone": "+70610778382"}
0005432720767	E36BA7	2430 371388	KONSTANTIN MIRONOV	{"email": "mironovkonstantin.051979@postgrespro.ru", "phone": "+70387818367"}
0005432720768	E36BA7	0596 798504	DMITRIY PETROV	{"phone": "+70501390474"}
0005432720769	2865B8	9904 742508	ANNA PETROVA	{"phone": "+70889081991"}
0005432720770	2865B8	0187 865230	DMITRIY SOROKIN	{"email": "d_sorokin.1966@postgrespro.ru", "phone": "+70422419973"}
0005432720771	2E9BCD	2223 357828	ILYA PAVLOV	{"phone": "+70968970998"}
0005432720772	45FFF9	1134 232848	VALERIYA IVANOVA	{"email": "ivanovav021967@postgrespro.ru", "phone": "+70394759200"}
0005432720773	EFFC7A	0427 949496	ANDREY SHEVCHENKO	{"phone": "+70725544991"}
0005432720774	4DCBC9	6700 246886	NATALYA LAZAREVA	{"email": "lazareva-natalya_1969@postgrespro.ru", "phone": "+70132101783"}
0005432720775	4DCBC9	4322 743761	TIMUR CHERNOV	{"email": "t-chernov.1983@postgrespro.ru", "phone": "+70829884330"}
0005432720776	8566C1	1199 361301	RAISA PETROVA	{"phone": "+70693283915"}
0005432720777	45BF94	8268 845458	IRINA NESTEROVA	{"email": "i-nesterova011965@postgrespro.ru", "phone": "+70933000382"}
0005432720778	218457	0293 800050	RAMIL KUZNECOV	{"email": "kuznecovramil.111970@postgrespro.ru", "phone": "+70300925376"}
0005432720779	9F07E5	5900 963723	DMITRIY GORBUNOV	{"phone": "+70135668720"}
0005432720780	2E4AB3	3165 374347	TAMARA TROFIMOVA	{"email": "tamara-trofimova_031966@postgrespro.ru", "phone": "+70492034596"}
0005432720781	2E4AB3	9002 782541	ARTEM GUSEV	{"email": "artem_gusev.10041976@postgrespro.ru", "phone": "+70824397194"}
0005432720782	C46C3D	9949 465048	ALENA NOVIKOVA	{"email": "alena-novikova.1979@postgrespro.ru", "phone": "+70214699103"}
0005432720783	21407B	7221 200752	VIKTOR KUZNECOV	{"email": "kuznecovv.031979@postgrespro.ru", "phone": "+70133983598"}
0005432720784	5C7472	2982 630222	ZOYA EGOROVA	{"phone": "+70633138716"}
0005432720785	D1BCFC	7375 510286	VIOLETTA SOLOVEVA	{"email": "violettasoloveva.1974@postgrespro.ru", "phone": "+70577237711"}
0005432720786	D1BCFC	2001 058712	PAVEL POPOV	{"phone": "+70426014884"}
0005432720787	D1BCFC	3842 725586	ARTEM PAVLOV	{"email": "artem_pavlov.061970@postgrespro.ru", "phone": "+70004780491"}
0005432720788	AE6F4C	4731 101269	VLADISLAV DMITRIEV	{"email": "dmitriev_v_1981@postgrespro.ru", "phone": "+70303555988"}
0005432720789	4A891C	5108 147492	ANDREY TIMOFEEV	{"phone": "+70765965428"}
0005432720790	B68B61	1698 068600	FEDOR ISAEV	{"phone": "+70531539707"}
0005432720791	E2EEC9	0076 566992	DAMIR CHERNOV	{"email": "d-chernov-27091967@postgrespro.ru", "phone": "+70324176535"}
0005432720792	E2EEC9	1350 667551	SVETLANA MASLOVA	{"email": "s-maslova_1966@postgrespro.ru", "phone": "+70496082815"}
0005432720793	6C3F5A	1808 859926	ALBINA ALEKSEEVA	{"email": "alekseeva-albina_1981@postgrespro.ru", "phone": "+70860782704"}
0005432720794	9AF7CA	8569 989607	ALEKSANDR GAVRILOV	{"phone": "+70854846166"}
0005432720795	CB7ABB	7129 962205	ROMAN VASILEV	{"email": "vasilevroman_031974@postgrespro.ru", "phone": "+70887964792"}
0005432720796	C3FABC	3386 856821	ULYANA DAVYDOVA	{"phone": "+70373018098"}
0005432720797	C3FABC	3950 197073	MARIYA IVANOVA	{"phone": "+70384979915"}
0005432720798	533B5A	6798 804667	TATYANA LOGINOVA	{"phone": "+70455266302"}
0005432720799	56908D	6696 255877	ELENA KISELEVA	{"email": "e.kiseleva.1969@postgrespro.ru", "phone": "+70912950472"}
0005432720800	9A7D4D	6534 846803	EVGENIY ROMANOV	{"phone": "+70367952896"}
0005432720801	FD3F68	4205 455242	YULIYA ZOTOVA	{"phone": "+70029130869"}
0005432720802	F91959	2124 443704	NINA FEDOROVA	{"email": "nina.fedorova.051961@postgrespro.ru", "phone": "+70282864670"}
0005432720803	F91959	6103 977632	SERGEY KRASNOV	{"email": "skrasnov-24051964@postgrespro.ru", "phone": "+70705759035"}
0005432720804	530872	0718 162035	IRINA STEPANOVA	{"phone": "+70559478142"}
0005432720805	5ADBB7	9744 282206	DMITRIY ABRAMOV	{"phone": "+70709358420"}
0005432720806	C7A46C	8013 324423	TATYANA ANISIMOVA	{"email": "t-anisimova-16031963@postgrespro.ru", "phone": "+70394068627"}
0005432720807	8BD50D	7894 753554	NADEZHDA DMITRIEVA	{"phone": "+70925946229"}
0005432720808	E55F10	9402 076625	ALEKSEY IVANOV	{"email": "a_ivanov-07061963@postgrespro.ru", "phone": "+70979657749"}
0005432720809	CD7468	0601 038257	NATALYA FEDOROVA	{"email": "nfedorova.11011971@postgrespro.ru", "phone": "+70560998887"}
0005432720810	B9B7A6	7024 854617	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr1976@postgrespro.ru", "phone": "+70919585004"}
0005432720811	BA1893	3994 119841	ELINA MOROZOVA	{"phone": "+70290548136"}
0005432720812	E952C9	8498 014954	LIDIYA KUZNECOVA	{"phone": "+70050454398"}
0005432720813	8BAE84	3880 726023	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.081972@postgrespro.ru", "phone": "+70576893226"}
0005432720814	C0F60C	7488 647122	ANDREY ANDREEV	{"email": "a_andreev1965@postgrespro.ru", "phone": "+70578481727"}
0005432720815	67CA94	8341 119852	VLADIMIR SHEVCHENKO	{"phone": "+70733376430"}
0005432720816	F67FBE	1402 138957	RUDOLF SIDOROV	{"email": "r-sidorov011974@postgrespro.ru", "phone": "+70401799623"}
0005432720817	8598ED	0854 549343	TATYANA ZAKHAROVA	{"phone": "+70789104261"}
0005432720818	DCBD79	5943 795500	RIMMA KULIKOVA	{"phone": "+70076425162"}
0005432720819	DCBD79	0471 182626	DENIS FILIPPOV	{"email": "denisfilippov1981@postgrespro.ru", "phone": "+70581348236"}
0005432720820	80F7E0	0792 500569	SAMVEL EGOROV	{"phone": "+70482383635"}
0005432720821	35B72B	5700 423667	GEORGIY DAVYDOV	{"phone": "+70591896331"}
0005432720822	FB2D05	1285 418783	ALEKSANDR FOMIN	{"email": "fomin-a_041970@postgrespro.ru", "phone": "+70343585809"}
0005432720824	173EF1	2072 047697	KONSTANTIN KONOVALOV	{"phone": "+70857215518"}
0005432720825	173EF1	0452 174282	YULIYA MOISEEVA	{"email": "moiseeva_yuliya_1961@postgrespro.ru", "phone": "+70824676632"}
0005432720826	AA6FBD	7327 773380	LARISA VOROBEVA	{"phone": "+70919303621"}
0005432720827	1C7A54	1527 062114	SERGEY SEMENOV	{"phone": "+70853414727"}
0005432720828	A319E6	6794 755575	TATYANA DAVYDOVA	{"email": "tatyana-davydova1967@postgrespro.ru", "phone": "+70102548629"}
0005432720829	AB36AC	8689 343481	LYUDMILA KOMAROVA	{"email": "komarova.lyudmila-1970@postgrespro.ru", "phone": "+70582507083"}
0005432720830	AB36AC	5753 314011	VALENTINA NIKOLAEVA	{"email": "nikolaeva_v081975@postgrespro.ru", "phone": "+70334361737"}
0005432720831	AB36AC	7413 770098	ROMAN SOKOLOV	{"phone": "+70907625411"}
0005432720832	77A298	0523 894072	SVETLANA ORLOVA	{"phone": "+70077971149"}
0005432720833	6500BD	2726 645936	VIKTORIYA VLASOVA	{"email": "v-vlasova-101968@postgrespro.ru", "phone": "+70975988183"}
0005432720834	A95133	2925 545248	NADEZHDA ISAEVA	{"email": "n_isaeva_071981@postgrespro.ru", "phone": "+70180399269"}
0005432720835	A95133	9373 544951	VADIM FILIPPOV	{"email": "v_filippov.10071979@postgrespro.ru", "phone": "+70271028403"}
0005432720836	87A047	2828 020195	IVAN BORISOV	{"email": "iborisov.09071975@postgrespro.ru", "phone": "+70460020367"}
0005432720837	87A047	3349 973266	TIMOFEY MIKHAYLOV	{"email": "mikhaylov_t.051966@postgrespro.ru", "phone": "+70683745725"}
0005432720838	D7DA1D	1412 690125	SERGEY SHEVCHENKO	{"phone": "+70403329672"}
0005432720839	D7DA1D	3179 835474	LYUDMILA ZHUKOVA	{"email": "lyudmila-zhukova-1973@postgrespro.ru", "phone": "+70896659101"}
0005432720840	3FE77C	3361 562398	OLGA ALEKSEEVA	{"email": "o_alekseeva_1978@postgrespro.ru", "phone": "+70810205680"}
0005432720841	429C25	6219 730441	GALINA KUZNECOVA	{"email": "kuznecovagalina-02011964@postgrespro.ru", "phone": "+70415310665"}
0005432720842	429C25	6598 848144	ANDREY FROLOV	{"phone": "+70513983359"}
0005432720843	6A13C9	3404 736526	VLADIMIR KUZNECOV	{"email": "kuznecov-v_14111963@postgrespro.ru", "phone": "+70593470442"}
0005432720844	64054F	7368 098913	IVAN KOROLEV	{"email": "ivan-korolev.17101972@postgrespro.ru", "phone": "+70453205577"}
0005432720845	A7BA0C	3529 408530	TATYANA ALEKSEEVA	{"email": "alekseevatatyana091989@postgrespro.ru", "phone": "+70422846142"}
0005432720846	A7BA0C	6459 464983	IVAN ILIN	{"email": "ivan_ilin.09091973@postgrespro.ru", "phone": "+70728904620"}
0005432720847	87CF2B	3921 691705	KIRILL ZHUKOV	{"email": "k.zhukov-031971@postgrespro.ru", "phone": "+70335619205"}
0005432720848	560304	4576 536742	SERGEY IVANOV	{"email": "sergey-ivanov-011970@postgrespro.ru", "phone": "+70544525173"}
0005432720849	560304	7266 700378	NAIL NIKOLAEV	{"phone": "+70500086455"}
0005432720850	560304	6297 015935	SERGEY ALEKSANDROV	{"email": "aleksandrov.sergey.051968@postgrespro.ru", "phone": "+70568513915"}
0005432720851	6389EF	3066 405291	MARIYA ZHUKOVA	{"phone": "+70654119995"}
0005432720852	AC4271	7568 651427	GENNADIY FILIPPOV	{"phone": "+70898101979"}
0005432720853	F8ADAE	1777 196276	YURIY GRIGOREV	{"email": "yuriy.grigorev-19051969@postgrespro.ru", "phone": "+70826356176"}
0005432720854	CF02F0	9857 026090	ARTEM SEMENOV	{"email": "semenov_artem_021976@postgrespro.ru", "phone": "+70698638445"}
0005432720855	708CAF	0107 813929	OLGA NIKOLAEVA	{"email": "nikolaevaolga20011964@postgrespro.ru", "phone": "+70720332330"}
0005432720856	708CAF	6766 050622	NINA NIKOLAEVA	{"email": "n-nikolaeva_30101962@postgrespro.ru", "phone": "+70061687914"}
0005432720857	B2B069	3585 121728	SVETLANA AFANASEVA	{"phone": "+70114183320"}
0005432720858	37E5B8	2595 061387	MAKSIM KUZMIN	{"phone": "+70762715448"}
0005432720859	0859A9	0234 087091	VLADIMIR MATVEEV	{"email": "matveev-v031971@postgrespro.ru", "phone": "+70101842433"}
0005432720860	234C4D	3136 954543	ROMAN MAKAROV	{"phone": "+70027894736"}
0005432720861	234C4D	0862 085274	ANTON FILIPPOV	{"phone": "+70900812993"}
0005432720862	455E43	0749 343372	VERA MAKSIMOVA	{"phone": "+70967987819"}
0005432720863	455E43	1239 745244	NIKOLAY ISAEV	{"email": "isaev_n-111966@postgrespro.ru", "phone": "+70599950798"}
0005432720864	5FCDE0	2584 172832	DMITRIY IVANOV	{"email": "ivanov-dmitriy_1967@postgrespro.ru", "phone": "+70728830115"}
0005432720865	C29307	4695 993590	VALENTINA NOVIKOVA	{"email": "valentina-novikova-11021961@postgrespro.ru", "phone": "+70827418736"}
0005432720866	C29307	5714 402026	VITALIY SIDOROV	{"phone": "+70150780988"}
0005432720867	BB4E05	9553 726461	VLADIMIR KISELEV	{"phone": "+70108198774"}
0005432720868	23AFD3	9240 709471	ALEKSEY MAKSIMOV	{"phone": "+70963129175"}
0005432720869	23AFD3	3651 951583	PETR GORBUNOV	{"phone": "+70383117935"}
0005432720870	EB8A8C	7613 350067	OKSANA KUZNECOVA	{"phone": "+70393367883"}
0005432720871	4EDD11	0642 475663	ALFIYA SMIRNOVA	{"email": "smirnovaa.07091979@postgrespro.ru", "phone": "+70550163104"}
0005432720872	C81152	0752 015997	NADEZHDA VASILEVA	{"email": "vasileva.n24041964@postgrespro.ru", "phone": "+70830690292"}
0005432720873	EC6336	9907 977227	LYUDMILA YAKOVLEVA	{"email": "yakovlevalyudmila25081962@postgrespro.ru", "phone": "+70256237051"}
0005432720874	A9DAF8	4242 637109	GALINA TIKHONOVA	{"phone": "+70337056174"}
0005432720875	4CBD21	9457 922043	ANDREY IVANOV	{"phone": "+70684037763"}
0005432720876	8D9115	9104 723123	MIKHAIL MEDVEDEV	{"email": "mikhail.medvedev_1973@postgrespro.ru", "phone": "+70880943067"}
0005432720877	5C985E	2517 040468	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_27101967@postgrespro.ru", "phone": "+70537869497"}
0005432720878	8618A2	1867 884084	OLEG ORLOV	{"email": "o-orlov071984@postgrespro.ru", "phone": "+70972214780"}
0005432720879	295ABB	9361 502008	TATYANA PETROVA	{"phone": "+70111893481"}
0005432720880	295ABB	3746 336391	IGOR SOLOVEV	{"email": "solovev-i_29091965@postgrespro.ru", "phone": "+70241358823"}
0005432720881	EDB225	8608 821593	OKSANA TARASOVA	{"email": "o-tarasova101967@postgrespro.ru", "phone": "+70482087951"}
0005432720941	59FE22	3159 063451	SERGEY KUZMIN	{"phone": "+70714600390"}
0005432720882	658095	8051 144090	MAKSIM SMIRNOV	{"email": "smirnov_m.1983@postgrespro.ru", "phone": "+70766063400"}
0005432720883	658095	1416 125671	VLADIMIR KULIKOV	{"phone": "+70976137102"}
0005432720884	96BF80	5829 088513	ANNA DANILOVA	{"email": "a.danilova-091969@postgrespro.ru", "phone": "+70412569240"}
0005432720885	96BF80	9918 805946	ALENA KOMAROVA	{"phone": "+70194707914"}
0005432720886	26D71C	6584 477432	ANDREY VOROBEV	{"email": "a_vorobev_051967@postgrespro.ru", "phone": "+70227995745"}
0005432720887	CBF71B	4075 215904	VYACHESLAV ISAEV	{"email": "isaev.vyacheslav1981@postgrespro.ru", "phone": "+70776216623"}
0005432720888	B39690	9082 287908	LYUDMILA ZOTOVA	{"phone": "+70627711200"}
0005432720889	A8D422	1243 011671	SERGEY SMIRNOV	{"email": "s.smirnov-061976@postgrespro.ru", "phone": "+70425664658"}
0005432720890	A8D422	0594 016635	EKATERINA NAZAROVA	{"phone": "+70623611413"}
0005432720891	8E66A4	2297 644336	ALEKSANDR MIRONOV	{"email": "a-mironov24031970@postgrespro.ru", "phone": "+70966838047"}
0005432720892	FF36C6	9697 194980	ANATOLIY KUZNECOV	{"email": "kuznecova.03011982@postgrespro.ru", "phone": "+70284626163"}
0005432720893	FF36C6	9317 725742	VERA KOLESNIKOVA	{"email": "vera_kolesnikova041973@postgrespro.ru", "phone": "+70601001716"}
0005432720894	C8729A	7357 116119	OLGA DENISOVA	{"email": "denisovaolga-18111962@postgrespro.ru", "phone": "+70488002403"}
0005432720895	48950B	2452 066105	IRINA YAKOVLEVA	{"email": "irina-yakovleva1972@postgrespro.ru", "phone": "+70305795126"}
0005432720896	E82405	9401 854473	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoaleksandr-041977@postgrespro.ru", "phone": "+70114436674"}
0005432720897	E82405	0341 571720	YURIY BELOV	{"email": "belovy.18121978@postgrespro.ru", "phone": "+70327832177"}
0005432720898	3778A1	2571 274623	VALENTINA NIKOLAEVA	{"email": "valentinanikolaeva.1975@postgrespro.ru", "phone": "+70338514265"}
0005432720899	3778A1	7452 248649	SERGEY IVANOV	{"email": "ivanovsergey.1981@postgrespro.ru", "phone": "+70211982674"}
0005432720900	7FC87F	1676 698202	VYACHESLAV KULIKOV	{"phone": "+70446372961"}
0005432720901	1A6FDA	9843 157347	VIKTOR ZHUKOV	{"email": "v-zhukov_13121970@postgrespro.ru", "phone": "+70192557443"}
0005432720902	61A038	5867 825731	OLEG GORBUNOV	{"email": "gorbunovoleg_1968@postgrespro.ru", "phone": "+70509713024"}
0005432720903	E93DE1	4303 011339	OLEG MATVEEV	{"phone": "+70025361357"}
0005432720904	C50458	3221 019026	DMITRIY SHEVCHENKO	{"email": "dmitriy-shevchenko111976@postgrespro.ru", "phone": "+70091909692"}
0005432720905	6E3A5D	2315 129213	KIRA SIDOROVA	{"email": "sidorova_kira-1963@postgrespro.ru", "phone": "+70216546136"}
0005432720906	6E3A5D	9331 082283	EKATERINA POPOVA	{"phone": "+70548300988"}
0005432720907	6E3A5D	5356 598650	SERGEY SOROKIN	{"email": "sorokin.sergey_091968@postgrespro.ru", "phone": "+70041635664"}
0005432720908	C9FA34	7631 166505	OLGA KUZNECOVA	{"email": "okuznecova091979@postgrespro.ru", "phone": "+70801927740"}
0005432720909	4FB8BC	0517 426951	MARIYA MAKAROVA	{"email": "makarovam-1961@postgrespro.ru", "phone": "+70896417948"}
0005432720910	D798D7	6250 225233	VALERIY DENISOV	{"email": "denisov_v1964@postgrespro.ru", "phone": "+70461898146"}
0005432720911	D798D7	0614 525167	DENIS ANTONOV	{"email": "antonovdenis1975@postgrespro.ru", "phone": "+70471427229"}
0005432720912	2C5F1F	2492 550877	ANNA MASLOVA	{"email": "maslova_a_1963@postgrespro.ru", "phone": "+70929715835"}
0005432720913	CEF2FC	9368 038081	ILYA EGOROV	{"phone": "+70976712957"}
0005432720914	EF221C	3920 537475	SVETLANA KUZMINA	{"phone": "+70046829477"}
0005432720915	4E1C65	8908 460276	SVETLANA KOMAROVA	{"phone": "+70363064259"}
0005432720916	B0FF6A	9419 255998	ROMAN ABRAMOV	{"email": "roman-abramov.091969@postgrespro.ru", "phone": "+70311578978"}
0005432720917	582A35	3346 495295	GALINA VASILEVA	{"email": "vasileva-galina.1979@postgrespro.ru", "phone": "+70330920154"}
0005432720918	582A35	2030 601751	MARIYA YUDINA	{"email": "m.yudina-16091963@postgrespro.ru", "phone": "+70659259805"}
0005432720919	10A717	9158 570011	ANNA EGOROVA	{"email": "egorova.a_1965@postgrespro.ru", "phone": "+70238702354"}
0005432720920	10A717	4223 270434	ELENA ANTONOVA	{"email": "antonova_e01081963@postgrespro.ru", "phone": "+70065872391"}
0005432720921	10A717	3582 527280	IGOR SOKOLOV	{"phone": "+70615584686"}
0005432720922	AF7BBC	9334 228088	TATYANA LOGINOVA	{"phone": "+70204836911"}
0005432720923	5BCD33	2353 116426	SERGEY SERGEEV	{"email": "ssergeev1982@postgrespro.ru", "phone": "+70184565221"}
0005432720924	5BCD33	3387 953753	KARIM VLASOV	{"phone": "+70470458831"}
0005432720925	7889F2	5504 717867	OLGA KOROLEVA	{"email": "o_koroleva.121979@postgrespro.ru", "phone": "+70264282679"}
0005432720926	BCDE5F	1839 445211	YULIYA AKIMOVA	{"email": "yakimova.1966@postgrespro.ru", "phone": "+70921355757"}
0005432720927	9CF9A2	5130 147509	LYUDMILA FADEEVA	{"email": "fadeeva_l1973@postgrespro.ru", "phone": "+70598333216"}
0005432720928	471181	3157 980443	EDUARD MATVEEV	{"phone": "+70799925657"}
0005432720929	89132B	1754 455942	GALINA KUZNECOVA	{"phone": "+70227996389"}
0005432720930	89132B	0148 030497	NATALYA BARANOVA	{"email": "natalya.baranova_081984@postgrespro.ru", "phone": "+70759498872"}
0005432720931	632001	3441 837696	TATYANA YUDINA	{"phone": "+70483897856"}
0005432720932	EAA9F2	1589 455995	ANDREY OSIPOV	{"phone": "+70507691681"}
0005432720933	696B05	1471 692097	ELIZAVETA NAZAROVA	{"email": "elizaveta.nazarova_26041970@postgrespro.ru", "phone": "+70622261428"}
0005432720934	232C75	5240 585775	IRINA AFANASEVA	{"phone": "+70851708415"}
0005432720935	232C75	6337 648629	DANILA NOVIKOV	{"phone": "+70292752310"}
0005432720936	6FB283	7053 703883	VYACHESLAV IVANOV	{"phone": "+70943908864"}
0005432720937	938583	1252 214528	ELIZAVETA KUZNECOVA	{"phone": "+70690215465"}
0005432720938	938583	5024 880837	VALERIY GRIGOREV	{"phone": "+70246661923"}
0005432720939	E0E216	7392 261066	DMITRIY TIKHONOV	{"phone": "+70555689586"}
0005432720940	59FE22	2396 651648	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr_10111971@postgrespro.ru", "phone": "+70526581283"}
0005432720942	59FE22	2563 031923	MARINA FROLOVA	{"email": "marinafrolova.051972@postgrespro.ru", "phone": "+70375444041"}
0005432720943	999B2B	7409 596917	TATYANA VASILEVA	{"email": "tatyanavasileva.021968@postgrespro.ru", "phone": "+70906446675"}
0005432720944	B223F5	3642 941810	DMITRIY PAVLOV	{"email": "d.pavlov27091977@postgrespro.ru", "phone": "+70680058155"}
0005432720945	B223F5	4004 434382	ANDREY GERASIMOV	{"phone": "+70529316671"}
0005432720946	7456BB	8733 218663	VALENTIN FOMIN	{"phone": "+70219305896"}
0005432720947	6B3E69	0596 179210	IRINA BARANOVA	{"phone": "+70229390549"}
0005432720948	DC2F96	6099 585533	ELISEY SMIRNOV	{"email": "eliseysmirnov.1968@postgrespro.ru", "phone": "+70185266215"}
0005432720949	89D2D0	7346 432322	EVGENIY KARPOV	{"phone": "+70239820485"}
0005432720950	BAA512	5777 168501	RAISA CHERNOVA	{"email": "raisa_chernova.07011970@postgrespro.ru", "phone": "+70491866944"}
0005432720951	42747B	8941 024730	NINA MIKHAYLOVA	{"email": "mikhaylova-nina.07071966@postgrespro.ru", "phone": "+70047175426"}
0005432720952	61A495	4856 131565	VLADIMIR KULIKOV	{"phone": "+70753329876"}
0005432720953	9B8DBF	7224 400996	RIFAT GAVRILOV	{"phone": "+70762963673"}
0005432720954	2BBF85	9574 317616	SVETLANA ALEKSANDROVA	{"phone": "+70629349066"}
0005432720955	2BBF85	5885 007623	ELENA SCHERBAKOVA	{"email": "scherbakova-elena_1969@postgrespro.ru", "phone": "+70526623229"}
0005432720956	FD823F	9906 245023	ALEKSANDR MAKSIMOV	{"phone": "+70982879581"}
0005432720957	FD823F	0304 096854	ALEKSEY SOROKIN	{"email": "sorokinaleksey.051972@postgrespro.ru", "phone": "+70439883498"}
0005432720958	329C2A	0835 053780	IVAN ISAEV	{"phone": "+70751120259"}
0005432720959	8C9A56	2736 077487	TAMARA IVANOVA	{"email": "ivanova_t1967@postgrespro.ru", "phone": "+70545189995"}
0005432720960	8C9A56	7491 178464	ANASTASIYA GRISHINA	{"phone": "+70275510737"}
0005432720961	F8DF53	2798 148411	NIKOLAY KUDRYASHOV	{"email": "kudryashov-n-011971@postgrespro.ru", "phone": "+70071740200"}
0005432720962	F8DF53	6345 220546	ALEKSANDR PETROV	{"phone": "+70044538840"}
0005432720963	FCFBB0	1865 218106	EVGENIY MEDVEDEV	{"phone": "+70699135656"}
0005432720964	0A45DB	0978 834443	YURIY DENISOV	{"phone": "+70165346958"}
0005432720965	32601A	6741 654155	ALINA DANILOVA	{"phone": "+70011781835"}
0005432720966	32601A	6607 894179	DMITRIY NIKOLAEV	{"phone": "+70703033979"}
0005432720967	771B4D	0944 345852	ALEKSANDR SERGEEV	{"email": "sergeeva_1974@postgrespro.ru", "phone": "+70241403577"}
0005432720968	771B4D	5137 983325	EVGENIYA MATVEEVA	{"email": "e_matveeva_1974@postgrespro.ru", "phone": "+70422870518"}
0005432720969	D8BC83	2631 326395	EVGENIY ZHURAVLEV	{"email": "e-zhuravlev_19061968@postgrespro.ru", "phone": "+70237811575"}
0005432720970	D8BC83	5166 950578	SVETLANA KARPOVA	{"phone": "+70431425419"}
0005432720971	20CE32	2839 074060	DMITRIY VLASOV	{"phone": "+70403381771"}
0005432720972	6D1678	4624 619566	NIKOLAY FROLOV	{"phone": "+70779080020"}
0005432720973	609C89	1677 227384	ZHANNA ERMAKOVA	{"email": "ermakova-zhanna071968@postgrespro.ru", "phone": "+70714923841"}
0005432720974	A731E8	8924 119360	EDUARD MIKHAYLOV	{"email": "mikhaylov_e-1963@postgrespro.ru", "phone": "+70464783035"}
0005432720975	77A4AD	4653 020210	ALEKSANDR IVANOV	{"phone": "+70856864509"}
0005432720976	F925EE	4217 523089	NATALYA SAVELEVA	{"email": "natalya_saveleva05081976@postgrespro.ru", "phone": "+70934084185"}
0005432720977	F925EE	4256 730876	TAMARA POTAPOVA	{"email": "tpotapova_1974@postgrespro.ru", "phone": "+70171915675"}
0005432720978	6BBD34	6654 715622	IVAN VOLKOV	{"phone": "+70824746634"}
0005432720979	40EFAF	4583 014979	NADEZHDA KISELEVA	{"phone": "+70752557521"}
0005432720980	1903D9	4649 589440	ALEKSANDR KUZNECOV	{"phone": "+70488457176"}
0005432720981	1903D9	0167 332745	ARTEM ALEKSEEV	{"email": "alekseev-a-06111980@postgrespro.ru", "phone": "+70660667448"}
0005432720982	0C0DC1	7333 888881	ALEKSEY ALEKSEEV	{"phone": "+70153051161"}
0005432720983	ED4784	0789 720986	VALERIYA KUZNECOVA	{"email": "v_kuznecova_10051980@postgrespro.ru", "phone": "+70775365664"}
0005432720984	74F702	5364 629576	EVGENIY NAUMOV	{"email": "e_naumov.12061972@postgrespro.ru", "phone": "+70018169445"}
0005432720985	576F4D	1235 092670	VERA SOROKINA	{"email": "sorokina-v_111975@postgrespro.ru", "phone": "+70010834756"}
0005432720986	576F4D	2002 292122	ANDREY SERGEEV	{"email": "sergeev.a_30111978@postgrespro.ru", "phone": "+70741298812"}
0005432720987	2586F5	6923 857929	OLGA ANTONOVA	{"phone": "+70105354853"}
0005432720988	FEB55A	9043 195134	ZINAIDA KOLESNIKOVA	{"phone": "+70067370394"}
0005432720989	8E0B7B	2644 994324	MARIYA SERGEEVA	{"phone": "+70913056927"}
0005432720990	C1F627	7574 398975	YULIYA TIMOFEEVA	{"email": "timofeeva-y.12081972@postgrespro.ru", "phone": "+70152790024"}
0005432720991	696173	1138 662193	IVAN ZAYCEV	{"email": "ivanzaycev12091981@postgrespro.ru", "phone": "+70008431299"}
0005432720992	696173	9822 254300	DARYA BORISOVA	{"phone": "+70494078468"}
0005432720993	1234A8	4372 501174	LYUDMILA ZAKHAROVA	{"phone": "+70835605230"}
0005432720994	E32BB6	9485 985590	MARIYA MIRONOVA	{"phone": "+70093347401"}
0005432720995	84454D	0820 748803	ALEKSANDR ZAKHAROV	{"phone": "+70949451673"}
0005432720996	EB5B61	4572 764530	YANA KUZNECOVA	{"email": "yana.kuznecova.101971@postgrespro.ru", "phone": "+70785366159"}
0005432720997	AE5216	5566 317335	MADINA KARPOVA	{"phone": "+70782745366"}
0005432720998	C3579C	1268 088476	NINA EFREMOVA	{"email": "n_efremova.081977@postgrespro.ru", "phone": "+70867266126"}
0005432720999	C78851	5133 114531	ANATOLIY SOROKIN	{"email": "anatoliy.sorokin.04021976@postgrespro.ru", "phone": "+70888881348"}
0005432721000	2715FD	1573 074458	DENIS KARPOV	{"phone": "+70243829630"}
0005432721001	CA5132	7291 162807	IRINA ORLOVA	{"phone": "+70519002102"}
0005432721002	5F9AD1	8373 837650	VALENTINA KOLESNIKOVA	{"phone": "+70845289650"}
0005432721003	5F9AD1	7247 988508	IVAN TIKHONOV	{"phone": "+70836632644"}
0005432721004	4E9042	5976 200956	RAISA BORISOVA	{"phone": "+70477107387"}
0005432721005	4E9042	7514 252964	SOFYA POPOVA	{"phone": "+70699286769"}
0005432721006	7AE06D	8349 637246	KSENIYA ZAKHAROVA	{"email": "zakharova.kseniya-1977@postgrespro.ru", "phone": "+70899035261"}
0005432721007	7AE06D	8915 018135	ELENA SEMENOVA	{"email": "semenovae_17041975@postgrespro.ru", "phone": "+70100830142"}
0005432721008	7AE06D	1433 510548	NATALYA SOROKINA	{"email": "natalyasorokina09111968@postgrespro.ru", "phone": "+70220738624"}
0005432721009	4EF685	2273 807885	NIKOLAY BELOV	{"email": "nikolay.belov.1976@postgrespro.ru", "phone": "+70774625600"}
0005432721010	82D2B2	5127 907391	ZINAIDA DANILOVA	{"email": "danilovazinaida_30051969@postgrespro.ru", "phone": "+70912406832"}
0005432721011	82D2B2	8067 246487	TIMOFEY IVANOV	{"phone": "+70381510022"}
0005432721012	ADE52A	5595 469750	ALEKSEY CHERNOV	{"phone": "+70068259859"}
0005432721013	ADE52A	4250 912841	NADEZHDA KUDRYASHOVA	{"phone": "+70103649053"}
0005432721014	99DC7E	3763 129425	KONSTANTIN KUZNECOV	{"email": "kkuznecov1975@postgrespro.ru", "phone": "+70122800531"}
0005432721015	34C66D	4877 948177	OKSANA VOROBEVA	{"email": "vorobevao.09041980@postgrespro.ru", "phone": "+70583779589"}
0005432721016	2DE57C	0350 492955	ALEVTINA PETROVA	{"email": "petrova-a-081976@postgrespro.ru", "phone": "+70314436097"}
0005432721017	F83AAD	3946 409370	ANDREY MARTYNOV	{"email": "andrey_martynov1970@postgrespro.ru", "phone": "+70921630893"}
0005432721018	F83AAD	7992 421610	TATYANA KOROLEVA	{"phone": "+70382602746"}
0005432721019	F83AAD	6728 472754	OLGA PETROVA	{"phone": "+70932648271"}
0005432721020	C48869	6137 127443	INNA SEMENOVA	{"phone": "+70112818880"}
0005432721021	1FDE3E	2297 896407	VLADIMIR IVANOV	{"phone": "+70091855216"}
0005432721022	E8C1F1	3601 248482	YURIY ORLOV	{"email": "yuriy.orlov.1973@postgrespro.ru", "phone": "+70574043835"}
0005432721023	E8C1F1	4876 498897	SVETLANA FILIPPOVA	{"email": "filippova-s_09121980@postgrespro.ru", "phone": "+70750069176"}
0005432721024	62AE2F	5449 198155	PAVEL SHEVCHENKO	{"phone": "+70838531168"}
0005432721025	61C445	9470 365874	SVETLANA ALEKSEEVA	{"phone": "+70067688326"}
0005432721026	61C445	2181 261939	ELENA NOVIKOVA	{"email": "e-novikova1976@postgrespro.ru", "phone": "+70273508815"}
0005432721027	DFFF3E	5088 507941	ALLA NIKOLAEVA	{"phone": "+70891322417"}
0005432721028	43E261	7547 305164	ALEKSEY MAKAROV	{"email": "makarov.aleksey_22041971@postgrespro.ru", "phone": "+70682001364"}
0005432721029	21C3DB	0923 468121	ALEKSEY MOROZOV	{"phone": "+70977220393"}
0005432721030	77F4E4	4294 184508	KONSTANTIN KUZMIN	{"email": "kuzmin.konstantin.26081962@postgrespro.ru", "phone": "+70327008677"}
0005432721031	39B9AD	1570 738473	NADEZHDA GORBUNOVA	{"email": "gorbunova_n.22101979@postgrespro.ru", "phone": "+70031337949"}
0005432721032	39B9AD	3176 866458	SERGEY VLASOV	{"email": "sergeyvlasov1974@postgrespro.ru", "phone": "+70482783010"}
0005432721033	04ED12	2678 460740	ALEKSANDRA NAZAROVA	{"phone": "+70344243201"}
0005432721034	04ED12	7920 419481	SERGEY IVANOV	{"phone": "+70639917157"}
0005432721035	4600E1	8762 291489	MARINA NIKIFOROVA	{"email": "nikiforova.m.111968@postgrespro.ru", "phone": "+70800920594"}
0005432721036	5C9E6F	5062 015965	NATALIYA VASILEVA	{"phone": "+70021393350"}
0005432721037	5C9E6F	9133 691916	ALEKSANDR SOLOVEV	{"email": "a_solovev.25091970@postgrespro.ru", "phone": "+70400122511"}
0005432721038	927B51	8706 828909	ARTEM MIRONOV	{"email": "a_mironov-1967@postgrespro.ru", "phone": "+70813855054"}
0005432721039	5C9B54	1526 613151	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey.051975@postgrespro.ru", "phone": "+70692722058"}
0005432721040	F1D403	1661 025528	SERGEY KOZLOV	{"email": "kozlov-s1982@postgrespro.ru", "phone": "+70156799287"}
0005432721041	F1D403	0732 959361	VIKTOR EGOROV	{"phone": "+70802175037"}
0005432721042	F1D403	4595 191104	VLADIMIR MIKHAYLOV	{"phone": "+70415858964"}
0005432721043	5EFC8F	4966 034193	NIKOLAY VASILEV	{"email": "nikolay_vasilev-1983@postgrespro.ru", "phone": "+70588425007"}
0005432721044	5EFC8F	8517 773355	ALEKSANDRA FOMINA	{"phone": "+70897639048"}
0005432721045	E9D88A	7321 652280	ELENA KONOVALOVA	{"phone": "+70880432180"}
0005432721046	F333DD	9751 446515	ARTUR GUSEV	{"email": "gusev.a-1983@postgrespro.ru", "phone": "+70234950496"}
0005432721047	F333DD	8031 610612	NIKITA FEDOROV	{"email": "n.fedorov-051973@postgrespro.ru", "phone": "+70466557911"}
0005432721048	59504E	0468 639153	OLGA SIDOROVA	{"phone": "+70660596863"}
0005432721049	7EF892	9159 433988	NATALYA MALYSHEVA	{"email": "malysheva_natalya_1957@postgrespro.ru", "phone": "+70521507916"}
0005432721050	7EF892	9093 544805	KSENIYA GORBUNOVA	{"phone": "+70154747468"}
0005432721051	3DA163	9693 254230	EKATERINA ZAKHAROVA	{"email": "zakharova-e.1976@postgrespro.ru", "phone": "+70862768617"}
0005432721052	58B424	3572 771971	DMITRIY MATVEEV	{"email": "dmitriy.matveev_1974@postgrespro.ru", "phone": "+70346321608"}
0005432721053	959FE8	6208 995327	ANATOLIY MIRONOV	{"phone": "+70923586190"}
0005432721054	E2C916	3941 672445	GALINA KOZLOVA	{"phone": "+70847341003"}
0005432721055	0EDB8F	4710 111844	ALEKSANDR EGOROV	{"email": "aleksandr.egorov061977@postgrespro.ru", "phone": "+70777600819"}
0005432721056	0EDB8F	4009 152141	YULIYA MARTYNOVA	{"email": "y_martynova-1969@postgrespro.ru", "phone": "+70797829676"}
0005432721057	0EDB8F	8491 946640	YURIY BARANOV	{"email": "baranovyuriy.1967@postgrespro.ru", "phone": "+70472665535"}
0005432721058	A0EB29	0595 603683	NINA ISAEVA	{"email": "n-isaeva.011956@postgrespro.ru", "phone": "+70202739011"}
0005432721059	A0EB29	8460 488860	VLADIMIR ROMANOV	{"phone": "+70632515718"}
0005432721060	679951	2664 598682	DENIS MIRONOV	{"email": "d-mironov_1980@postgrespro.ru", "phone": "+70583298502"}
0005432721061	ECB1A9	7529 145107	ELENA SERGEEVA	{"email": "elena-sergeeva.1979@postgrespro.ru", "phone": "+70590165973"}
0005432721062	22A5B7	9885 143248	GEVORG BORISOV	{"email": "g-borisov-20011968@postgrespro.ru", "phone": "+70875835650"}
0005432721063	1C8024	3199 765975	MARIYA GERASIMOVA	{"phone": "+70011880779"}
0005432721064	C5BEBE	6795 898445	NATALIYA ISAEVA	{"email": "nataliyaisaeva.18111964@postgrespro.ru", "phone": "+70393990067"}
0005432721065	E12C7B	3690 245903	PETR IVANOV	{"phone": "+70895381588"}
0005432721066	E12C7B	1232 771044	TATYANA ERMAKOVA	{"phone": "+70651049169"}
0005432721067	B3555B	8364 043722	FEDOR SCHERBAKOV	{"phone": "+70064178885"}
0005432721068	80F8D1	8967 226388	MAKSIM KAZAKOV	{"email": "maksimkazakov11101971@postgrespro.ru", "phone": "+70852532029"}
0005432721069	08E642	9352 918308	ALEKSANDR SEMENOV	{"phone": "+70253063078"}
0005432721070	54CBAB	4871 497224	TATYANA SOROKINA	{"email": "sorokina-t.061984@postgrespro.ru", "phone": "+70272007523"}
0005432721071	365BC0	5733 459496	POLINA FEDOROVA	{"email": "fedorova-polina.091979@postgrespro.ru", "phone": "+70544534639"}
0005432721072	F76D72	1387 769800	DMITRIY KUZNECOV	{"phone": "+70288761039"}
0005432721073	C3AA2F	0152 340154	VYACHESLAV MEDVEDEV	{"email": "medvedev-vyacheslav1980@postgrespro.ru", "phone": "+70055374180"}
0005432721074	7426A4	1895 931880	DMITRIY SAVELEV	{"phone": "+70238123069"}
0005432721075	7426A4	2698 436400	ALEKSANDRA IVANOVA	{"phone": "+70661049211"}
0005432721076	142064	7145 761477	MIKHAIL ZAKHAROV	{"email": "m-zakharov-1970@postgrespro.ru", "phone": "+70620881406"}
0005432721077	C9DFE5	2204 883033	EKATERINA EFREMOVA	{"email": "efremovaekaterina-12021973@postgrespro.ru", "phone": "+70586275492"}
0005432721078	C9DFE5	4170 027380	MARINA ABRAMOVA	{"phone": "+70319625315"}
0005432721079	C9DFE5	9912 994149	OLGA POPOVA	{"phone": "+70821536864"}
0005432721080	4D3309	8970 003020	ELIZAVETA GORBUNOVA	{"email": "gorbunovaelizaveta16021974@postgrespro.ru", "phone": "+70011738666"}
0005432721081	4D3309	1122 822801	DMITRIY ABRAMOV	{"email": "dabramov-16061975@postgrespro.ru", "phone": "+70900626244"}
0005432721082	C63DE2	5498 348430	ELENA KONOVALOVA	{"phone": "+70459457665"}
0005432721083	C63DE2	5125 065906	LARISA PETROVA	{"phone": "+70790494150"}
0005432721084	D079D6	3638 403148	MIKHAIL NAZAROV	{"email": "mnazarov_28101980@postgrespro.ru", "phone": "+70593393292"}
0005432721085	2968C8	6516 631240	GALINA ALEKSEEVA	{"phone": "+70370570643"}
0005432721086	E6C191	6722 065880	VERONIKA MIRONOVA	{"email": "mironova.veronika-1985@postgrespro.ru", "phone": "+70286522047"}
0005432721087	99FE84	2875 090700	VALERIY BORISOV	{"email": "borisovvaleriy-1981@postgrespro.ru", "phone": "+70476083515"}
0005432721088	9020D1	3218 973236	PRASKOVYA MOISEEVA	{"phone": "+70311483738"}
0005432721089	11A062	9035 500446	SERGEY ZAYCEV	{"email": "sergey.zaycev.101958@postgrespro.ru", "phone": "+70838326362"}
0005432721090	2D5B66	6753 972001	MIKHAIL SHEVCHENKO	{"email": "shevchenko-mikhail1966@postgrespro.ru", "phone": "+70728324034"}
0005432721091	2D5B66	2373 597703	SVETLANA FROLOVA	{"email": "frolova-s021967@postgrespro.ru", "phone": "+70809930379"}
0005432721092	03E842	5301 473003	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n1977@postgrespro.ru", "phone": "+70186838583"}
0005432721093	03E842	2660 813428	BORIS GUSEV	{"email": "boris-gusev_1972@postgrespro.ru", "phone": "+70579071541"}
0005432721094	D16AF5	6755 528367	TATYANA IVANOVA	{"phone": "+70991252111"}
0005432721095	D16AF5	5872 211123	SVETLANA IVANOVA	{"email": "ivanova_svetlana051973@postgrespro.ru", "phone": "+70364817320"}
0005432721096	16F5B9	1544 866518	LARISA IVANOVA	{"email": "ivanoval1979@postgrespro.ru", "phone": "+70519524789"}
0005432721097	524586	1002 306442	YULIYA SOLOVEVA	{"email": "soloveva.yuliya_071969@postgrespro.ru", "phone": "+70519522418"}
0005432721098	D5E239	2905 299214	DMITRIY SHEVCHENKO	{"email": "dmitriy-shevchenko.1972@postgrespro.ru", "phone": "+70435006281"}
0005432721099	A0437C	5265 339097	ANATOLIY ROMANOV	{"phone": "+70239086564"}
0005432721100	F3BE9D	6592 711912	VLADISLAV MOISEEV	{"phone": "+70567403483"}
0005432721101	5DC22B	4244 512808	IRINA POTAPOVA	{"email": "potapovairina.1977@postgrespro.ru", "phone": "+70168115274"}
0005432721102	8B571F	0865 233058	ANASTASIYA ROMANOVA	{"email": "romanova_a_071974@postgrespro.ru", "phone": "+70655280388"}
0005432721103	860570	4458 053895	LEONID FROLOV	{"email": "frolovl.1979@postgrespro.ru", "phone": "+70622560385"}
0005432721104	860570	7454 384571	EGOR AFANASEV	{"email": "afanasev-e-22031970@postgrespro.ru", "phone": "+70297768275"}
0005432721105	FB26D2	8479 354988	OLGA SOROKINA	{"email": "sorokina-o.1974@postgrespro.ru", "phone": "+70904672255"}
0005432721106	6F6C6F	8269 088674	SVETLANA YUDINA	{"email": "yudina-s.12011969@postgrespro.ru", "phone": "+70349845755"}
0005432721107	6F6C6F	2751 363086	YURIY PAVLOV	{"email": "ypavlov021976@postgrespro.ru", "phone": "+70513936393"}
0005432721108	16DF5F	7484 683247	SERGEY SEMENOV	{"email": "sergey.semenov-09061969@postgrespro.ru", "phone": "+70852254738"}
0005432721109	3EEEEE	0963 220620	EVGENIYA BORISOVA	{"email": "e.borisova_22121968@postgrespro.ru", "phone": "+70947082684"}
0005432721110	3EEEEE	9616 583972	SVETLANA KOZLOVA	{"phone": "+70317298999"}
0005432721111	380A1D	2821 607886	VALENTINA ZHUKOVA	{"email": "valentina-zhukova25041976@postgrespro.ru", "phone": "+70555922073"}
0005432721112	380A1D	5671 930425	NAZAR VASILEV	{"email": "vasilevnazar.051978@postgrespro.ru", "phone": "+70134657744"}
0005432721113	D1D4FC	2355 583247	GALINA MIKHAYLOVA	{"email": "mikhaylova-galina_1973@postgrespro.ru", "phone": "+70301830168"}
0005432721114	2B84DA	3528 921992	MIKHAIL PETROV	{"phone": "+70355964149"}
0005432721115	2B84DA	3603 445992	EKATERINA DMITRIEVA	{"phone": "+70416377182"}
0005432721116	6101F7	3919 476159	OKSANA KOROLEVA	{"email": "koroleva-oksana.081966@postgrespro.ru", "phone": "+70205652462"}
0005432721117	6101F7	1481 945183	VALENTINA SERGEEVA	{"phone": "+70481659765"}
0005432721118	DEF424	5482 099539	ALISA MATVEEVA	{"phone": "+70764969456"}
0005432721119	5692D8	7703 087523	VERA KOZLOVA	{"phone": "+70465729709"}
0005432721120	1F523C	2207 056859	YULIYA RYABOVA	{"email": "ryabovay-1975@postgrespro.ru", "phone": "+70908530883"}
0005432721121	331BF8	9969 424593	TATYANA ROMANOVA	{"email": "romanovat-23031968@postgrespro.ru", "phone": "+70128635516"}
0005432721122	5AA228	8881 559200	VALENTINA NIKIFOROVA	{"phone": "+70336356136"}
0005432721123	569AD4	7633 817263	VLADIMIR MATVEEV	{"email": "vladimir-matveev.1963@postgrespro.ru", "phone": "+70422031320"}
0005432721124	DED20A	4457 513997	ELENA VOLKOVA	{"email": "elena-volkova-24011965@postgrespro.ru", "phone": "+70233860066"}
0005432721125	EFA5A6	0487 706199	ALEKSANDR VASILEV	{"phone": "+70944038727"}
0005432721126	EFA5A6	8356 783717	OKSANA SOKOLOVA	{"phone": "+70524267130"}
0005432721127	F6DF6E	3805 590573	MARAT ZAYCEV	{"email": "zaycevmarat.121971@postgrespro.ru", "phone": "+70845451742"}
0005432721128	D24B18	3246 744690	LYUBOV KOZLOVA	{"phone": "+70319715497"}
0005432721129	D24A81	6591 035202	LILIYA NIKOLAEVA	{"phone": "+70496506218"}
0005432721130	D24A81	0947 333172	VALENTINA MAKAROVA	{"phone": "+70705979771"}
0005432721131	2678C7	5616 825515	IVAN NAZAROV	{"email": "ivan-nazarov.1979@postgrespro.ru", "phone": "+70732396510"}
0005432721132	2678C7	5723 121796	KONSTANTIN FOMIN	{"email": "k.fomin.051981@postgrespro.ru", "phone": "+70830588785"}
0005432721133	5D1C12	6859 299123	ELVIRA ILINA	{"email": "ilina-e_1980@postgrespro.ru", "phone": "+70737964559"}
0005432721134	C8FB72	8961 445542	RUSLAN ZAKHAROV	{"email": "ruslan-zakharov.13081968@postgrespro.ru", "phone": "+70879507669"}
0005432721135	C567FF	0012 602707	MARINA MOISEEVA	{"email": "m-moiseeva_121961@postgrespro.ru", "phone": "+70910719271"}
0005432721136	C8C79C	5228 891318	LYUBOV CHERNOVA	{"email": "chernova_lyubov.011983@postgrespro.ru", "phone": "+70992295406"}
0005432721137	C8C79C	9469 012270	VIKTOR MAKAROV	{"email": "makarov-viktor011972@postgrespro.ru", "phone": "+70014226303"}
0005432721138	4B2EB4	4845 605688	EVGENIY MIKHAYLOV	{"phone": "+70930722343"}
0005432721139	628D00	7257 573496	VALENTINA DANILOVA	{"email": "valentinadanilova.091972@postgrespro.ru", "phone": "+70695316985"}
0005432721140	B20EB7	1912 556610	ALEKSEY MIKHAYLOV	{"phone": "+70856910224"}
0005432721141	8B771C	2773 138170	ALEKSANDRA BELYAEVA	{"email": "aleksandra-belyaeva.011967@postgrespro.ru", "phone": "+70983340378"}
0005432721142	8B771C	6984 279902	ALEKSEY ALEKSEEV	{"phone": "+70768793994"}
0005432721143	7916FA	1792 837190	EKATERINA ROMANOVA	{"email": "eromanova19081973@postgrespro.ru", "phone": "+70522673452"}
0005432721144	5467D1	6415 132985	VIKTOR ABRAMOV	{"email": "v.abramov1968@postgrespro.ru", "phone": "+70206548593"}
0005432721145	B740B0	9271 188740	YANA SERGEEVA	{"phone": "+70006248963"}
0005432721146	811D0D	0573 027492	MARINA KOMAROVA	{"phone": "+70232638813"}
0005432721147	7CBBBF	2649 006673	TATYANA KOROLEVA	{"email": "korolevat1968@postgrespro.ru", "phone": "+70781558691"}
0005432721148	C25D79	4234 289849	VLADIMIR IVANOV	{"email": "ivanov_vladimir_31011985@postgrespro.ru", "phone": "+70012686637"}
0005432721149	8C2FFF	9435 410257	LEONID KOZLOV	{"phone": "+70148746379"}
0005432721150	8C2FFF	8859 357733	DMITRIY ALEKSANDROV	{"email": "aleksandrov.d.061969@postgrespro.ru", "phone": "+70391757376"}
0005432721151	DCC6A8	3664 312861	EVGENIY GUSEV	{"phone": "+70523359455"}
0005432721152	FEBAE4	4441 370133	EGOR VOROBEV	{"email": "vorobev.egor031954@postgrespro.ru", "phone": "+70748266356"}
0005432721153	9FC231	9468 825748	PAVEL ILIN	{"phone": "+70112927414"}
0005432721154	D27A07	9202 554980	MARIYA STEPANOVA	{"email": "stepanova.mariya-13011967@postgrespro.ru", "phone": "+70668296747"}
0005432721155	D27A07	9705 430259	ANDREY SMIRNOV	{"phone": "+70104664922"}
0005432721156	60F276	1878 426225	MARGARITA SOKOLOVA	{"email": "m_sokolova.051957@postgrespro.ru", "phone": "+70762916994"}
0005432721157	60F276	4889 522710	ARTEM KUZNECOV	{"email": "akuznecov07041971@postgrespro.ru", "phone": "+70847857051"}
0005432721158	20F4A8	5050 488007	PETR SOKOLOV	{"email": "petr.sokolov021987@postgrespro.ru", "phone": "+70141128950"}
0005432721159	20F4A8	5707 032081	OLGA YUDINA	{"phone": "+70133401268"}
0005432721160	44FBA7	3553 505139	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey_19051973@postgrespro.ru", "phone": "+70786866083"}
0005432721161	85D5EA	2494 593291	LUIZA YUDINA	{"email": "yudinal-1978@postgrespro.ru", "phone": "+70239415063"}
0005432721162	85D5EA	4395 530810	ALEKSANDRA SMIRNOVA	{"phone": "+70170550640"}
0005432721163	91B57A	5438 472245	OKSANA FROLOVA	{"email": "o-frolova_23061979@postgrespro.ru", "phone": "+70348214264"}
0005432721164	91B57A	9370 922080	SVETLANA TROFIMOVA	{"phone": "+70801338445"}
0005432721165	7BD407	0019 221315	KLAVDIYA FEDOROVA	{"email": "fedorova.klavdiya-091977@postgrespro.ru", "phone": "+70014134215"}
0005432721166	238EF9	8316 090633	STANISLAV KUZMIN	{"email": "skuzmin011969@postgrespro.ru", "phone": "+70056672365"}
0005432721167	BA7803	0061 542948	MAKSIM MIKHAYLOV	{"phone": "+70543742515"}
0005432721168	BA7803	3903 941111	KRISTINA BELOVA	{"email": "belova.k_1972@postgrespro.ru", "phone": "+70194512700"}
0005432721169	03EA98	9900 705040	STANISLAV ZAYCEV	{"phone": "+70799979782"}
0005432721170	538B4E	0553 486190	ANDREY EGOROV	{"email": "a_egorov-05021960@postgrespro.ru", "phone": "+70322497566"}
0005432721171	538B4E	7359 676993	ANDREY IVANOV	{"phone": "+70691824163"}
0005432721172	81C2E8	4204 362629	DARYA NESTEROVA	{"email": "nesterova.darya.25051969@postgrespro.ru", "phone": "+70638357410"}
0005432721173	B5DBF6	8983 092429	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.17021987@postgrespro.ru", "phone": "+70472823810"}
0005432721174	C72CD1	7428 292333	TATYANA BELOVA	{"email": "tatyana_belova1971@postgrespro.ru", "phone": "+70603929121"}
0005432721175	91D1A0	2500 090420	ALEKSANDR FOMIN	{"email": "aleksandr.fomin.1964@postgrespro.ru", "phone": "+70476870631"}
0005432721176	AA08F8	3289 530849	VALENTINA NIKIFOROVA	{"email": "nikiforova_valentina.071971@postgrespro.ru", "phone": "+70464835726"}
0005432721177	AA08F8	5078 434811	NIKOLAY ZAKHAROV	{"phone": "+70181140112"}
0005432721178	C88DD9	6507 347242	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina_1979@postgrespro.ru", "phone": "+70279655793"}
0005432721179	C88DD9	8627 683390	DINA KUZNECOVA	{"email": "kuznecova-dina.01061979@postgrespro.ru", "phone": "+70680809601"}
0005432721180	C88DD9	5789 190988	ANTONINA ALEKSEEVA	{"email": "antoninaalekseeva011977@postgrespro.ru", "phone": "+70544907829"}
0005432721181	1177AC	2708 508505	ALEKSANDR FOMIN	{"email": "fomina.041967@postgrespro.ru", "phone": "+70646783197"}
0005432721182	6FC213	5879 409931	OLGA KULIKOVA	{"phone": "+70574308014"}
0005432721183	8E2300	0398 537412	LYUBOV YUDINA	{"email": "lyubovyudina-1978@postgrespro.ru", "phone": "+70340697770"}
0005432721184	8E2300	6992 575961	VLADIMIR VASILEV	{"email": "vladimir.vasilev_011966@postgrespro.ru", "phone": "+70490377735"}
0005432721185	9DB24F	1126 296857	NIKOLAY ROMANOV	{"email": "nromanov111970@postgrespro.ru", "phone": "+70587051461"}
0005432721186	D6D02E	4199 663728	NIKOLAY VASILEV	{"email": "vasilev.nikolay-1961@postgrespro.ru", "phone": "+70773546731"}
0005432721187	5B5E4A	1124 936303	NATALYA TIKHONOVA	{"email": "tikhonova_natalya.1985@postgrespro.ru", "phone": "+70823782881"}
0005432721188	265EE8	8620 191630	SERGEY SOROKIN	{"email": "sorokinsergey-1964@postgrespro.ru", "phone": "+70776435905"}
0005432721189	ED0D1E	9088 146781	ANDREY ZAYCEV	{"email": "zaycev_a1960@postgrespro.ru", "phone": "+70033840751"}
0005432721190	7535BA	4261 943066	NIKOLAY KOZLOV	{"phone": "+70084556847"}
0005432721191	E25336	4375 918803	RUMIYA BORISOVA	{"email": "rumiya_borisova_14021987@postgrespro.ru", "phone": "+70293370335"}
0005432721192	E25336	3628 101655	ANTONINA KUZNECOVA	{"phone": "+70156754765"}
0005432721193	0D1B34	4992 940099	EGOR SCHERBAKOV	{"email": "scherbakovegor.061957@postgrespro.ru", "phone": "+70024583472"}
0005432721194	81CEA5	1998 357321	ROBERT MOISEEV	{"email": "moiseev_robert031974@postgrespro.ru", "phone": "+70275546774"}
0005432721195	81CEA5	1753 536227	VIKTOR VOLKOV	{"phone": "+70035235679"}
0005432721196	A07DA3	1527 125716	ELIZAVETA SAVELEVA	{"phone": "+70354078609"}
0005432721197	A07DA3	2786 205820	ANATOLIY SEMENOV	{"email": "semenovanatoliy.121972@postgrespro.ru", "phone": "+70755350314"}
0005432721198	D9B368	2222 795940	NINA RYABOVA	{"email": "nina.ryabova_1964@postgrespro.ru", "phone": "+70448249728"}
0005432721199	F87422	9998 115200	YURIY EGOROV	{"email": "yuriy.egorov-111971@postgrespro.ru", "phone": "+70087475817"}
0005432721200	6120A1	7567 890712	SERGEY KUZNECOV	{"phone": "+70663166182"}
0005432721201	BCF20F	4076 409860	NIKITA KUZNECOV	{"phone": "+70617542896"}
0005432721202	BCF20F	8475 787982	VLADIMIR TARASOV	{"email": "tarasov.vladimir021979@postgrespro.ru", "phone": "+70693143007"}
0005432721203	B81B10	1639 060415	BOGDAN KUZNECOV	{"email": "kuznecov.b1969@postgrespro.ru", "phone": "+70480968346"}
0005432721204	1E16CE	7788 731541	OLGA DMITRIEVA	{"phone": "+70885406313"}
0005432721205	007CA7	2853 764847	EGOR GORBUNOV	{"phone": "+70800463578"}
0005432721206	8BDBF9	9937 070357	EKATERINA DAVYDOVA	{"email": "davydova-ekaterina1966@postgrespro.ru", "phone": "+70985437707"}
0005432721207	8BDBF9	5428 510164	ALENA KAZAKOVA	{"email": "kazakova.a_011983@postgrespro.ru", "phone": "+70228842408"}
0005432721208	0FE332	8778 870189	DILYARA ABRAMOVA	{"email": "d_abramova.121968@postgrespro.ru", "phone": "+70879919643"}
0005432721209	61EE9F	4611 518344	DENIS ROMANOV	{"email": "d-romanov_19021970@postgrespro.ru", "phone": "+70974849515"}
0005432721210	866744	9426 361581	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.tatyana.30081963@postgrespro.ru", "phone": "+70298407323"}
0005432721211	1CB659	1750 809321	VALENTINA SERGEEVA	{"email": "sergeeva-valentina-30011966@postgrespro.ru", "phone": "+70812192410"}
0005432721212	1CB659	4936 613830	ANDREY STEPANOV	{"phone": "+70678736710"}
0005432721213	01E148	8924 623375	ANASTASIYA LEBEDEVA	{"phone": "+70295890697"}
0005432721214	AC1820	8468 901313	ALEKSEY GAVRILOV	{"phone": "+70930069314"}
0005432721215	20B5B3	6165 905072	SERGEY NIKOLAEV	{"phone": "+70415197605"}
0005432721216	7AC82E	9945 900003	IVAN DAVYDOV	{"email": "davydov-i_091978@postgrespro.ru", "phone": "+70553231392"}
0005432721217	7AC82E	6241 212816	IRINA VOLKOVA	{"email": "irina_volkova-02111972@postgrespro.ru", "phone": "+70464303092"}
0005432721218	6D9E0E	2508 123996	VASILIY KUZNECOV	{"email": "v.kuznecov_1974@postgrespro.ru", "phone": "+70128192674"}
0005432721219	8F471B	4255 160980	SERGEY IVANOV	{"phone": "+70533574377"}
0005432721220	8F471B	0794 838860	VLADA ZAYCEVA	{"email": "vlada.zayceva.101971@postgrespro.ru", "phone": "+70083166412"}
0005432721221	37CDC2	4241 644850	VYACHESLAV RODIONOV	{"phone": "+70888931988"}
0005432721222	D85E58	6475 107934	OLGA FOMINA	{"phone": "+70701121386"}
0005432721223	95EFF6	9957 428168	LIDIYA ERMAKOVA	{"email": "ermakoval.12101972@postgrespro.ru", "phone": "+70023165142"}
0005432721224	B11E23	4466 669017	YURIY ABRAMOV	{"phone": "+70538999487"}
0005432721225	B11E23	6739 425898	MIKHAIL CHERNOV	{"email": "chernovm-27121968@postgrespro.ru", "phone": "+70986667911"}
0005432721226	9329DB	3595 406596	PAVEL PETROV	{"email": "petrov_pavel_1974@postgrespro.ru", "phone": "+70140369975"}
0005432721227	9329DB	2704 722271	YANA ZAKHAROVA	{"phone": "+70747735218"}
0005432721228	9329DB	7047 478666	MARIYA MAKAROVA	{"email": "m.makarova031960@postgrespro.ru", "phone": "+70950317341"}
0005432721229	77864E	0686 601867	ANTON GERASIMOV	{"phone": "+70527746266"}
0005432721230	77864E	5078 967332	LILIYA PETROVA	{"email": "l-petrova-13111960@postgrespro.ru", "phone": "+70082946805"}
0005432721231	7736C2	2972 609457	YULIYA KUDRYASHOVA	{"email": "kudryashova_y011982@postgrespro.ru", "phone": "+70402578106"}
0005432721232	751C63	8529 262980	NIKOLAY PETROV	{"email": "petrov-n061983@postgrespro.ru", "phone": "+70011885054"}
0005432721233	F3A081	9919 760145	ALEKSANDR TARASOV	{"phone": "+70972336882"}
0005432721234	F3A081	6730 561911	ALEKSANDRA VASILEVA	{"email": "vasilevaaleksandra_14041983@postgrespro.ru", "phone": "+70840362871"}
0005432721235	79B122	6979 895699	GENNADIY VOLKOV	{"phone": "+70170192250"}
0005432721236	3CE9A3	0038 650622	VIKTOR NIKOLAEV	{"phone": "+70777465102"}
0005432721237	F0192F	2938 562987	VALENTINA MAKAROVA	{"phone": "+70726625621"}
0005432721238	D5CFB5	4619 490661	ALEKSANDR SERGEEV	{"email": "sergeev.a_21011980@postgrespro.ru", "phone": "+70536461196"}
0005432721239	554DFD	7252 667257	EVGENIY OSIPOV	{"phone": "+70515853662"}
0005432721240	BCBAAF	3496 816847	ELENA KUZNECOVA	{"phone": "+70301319807"}
0005432721241	BCBAAF	6883 697491	MIKHAIL VOLKOV	{"email": "volkov.m021981@postgrespro.ru", "phone": "+70522517853"}
0005432721242	E79FBF	0753 150997	VASILIY MATVEEV	{"email": "vasiliy-matveev_011974@postgrespro.ru", "phone": "+70192712826"}
0005432721243	CC4FD5	7183 198208	ANDREY MELNIKOV	{"email": "melnikov-a_031981@postgrespro.ru", "phone": "+70501060364"}
0005432721244	9476EA	3113 293974	LYUBOV LOGINOVA	{"email": "lyubovloginova_1974@postgrespro.ru", "phone": "+70215483587"}
0005432721245	9476EA	7035 987290	IVAN MIKHAYLOV	{"phone": "+70269210602"}
0005432721246	97491B	1225 280182	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov.101973@postgrespro.ru", "phone": "+70234844988"}
0005432721247	03A33C	6447 885211	TAMARA FEDOROVA	{"phone": "+70089034278"}
0005432721248	96E46C	6402 111773	TATYANA LUKYANOVA	{"phone": "+70354529401"}
0005432721249	96E46C	7482 918995	ALEKSEY GUSEV	{"email": "gusev-aleksey.1961@postgrespro.ru", "phone": "+70120934701"}
0005432721250	B0C120	2756 022314	OLEG KUZNECOV	{"phone": "+70564767233"}
0005432721251	E7CC0A	9779 491996	VALENTINA ISAEVA	{"phone": "+70213619045"}
0005432721252	FFF0D0	0827 916034	DARYA SAVELEVA	{"phone": "+70627186740"}
0005432721253	104ADB	9091 970508	LEONID DENISOV	{"phone": "+70696569684"}
0005432721254	104ADB	8419 942506	LYUBOV SAVELEVA	{"phone": "+70453340621"}
0005432721255	631B1D	8857 464979	IVAN IVANOV	{"email": "i-ivanov-1970@postgrespro.ru", "phone": "+70375110432"}
0005432721256	631B1D	8093 173214	EKATERINA KOROLEVA	{"email": "ekaterina.koroleva.03021977@postgrespro.ru", "phone": "+70838325943"}
0005432721257	166844	9398 315930	ALEKSEY KUZNECOV	{"phone": "+70076710630"}
0005432721258	E6AC6C	4167 335431	IRINA TIMOFEEVA	{"phone": "+70850300150"}
0005432721259	E6AC6C	9265 776430	MARIYA SAVELEVA	{"email": "saveleva_m-031970@postgrespro.ru", "phone": "+70013329161"}
0005432721260	C80836	4169 515546	ANASTASIYA KOLESNIKOVA	{"phone": "+70067574798"}
0005432721261	C80836	8779 325006	TATYANA BORISOVA	{"phone": "+70977597758"}
0005432721262	70D808	0825 613649	PETR BONDARENKO	{"phone": "+70103147450"}
0005432721263	43F60B	2359 524317	YAROSLAV CHERNOV	{"phone": "+70101304489"}
0005432721264	BDFC08	8435 595114	KRISTINA FADEEVA	{"email": "fadeevak01041970@postgrespro.ru", "phone": "+70711196995"}
0005432721265	1EF2DC	6559 317143	TATYANA ZAYCEVA	{"phone": "+70377332446"}
0005432721266	1EF2DC	0444 591883	VALERIY KUZNECOV	{"phone": "+70570434344"}
0005432721267	B6757B	7250 537334	TATYANA PETROVA	{"email": "t-petrova.071971@postgrespro.ru", "phone": "+70741560216"}
0005432721268	B6757B	7210 053229	ALEKSANDR KAZAKOV	{"phone": "+70109081997"}
0005432721269	671C1B	1975 291381	TATYANA KARPOVA	{"phone": "+70382510020"}
0005432721270	671C1B	9080 063207	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov-071973@postgrespro.ru", "phone": "+70704256384"}
0005432721271	2D152E	9080 224341	ALEKSANDR IVANOV	{"phone": "+70990489599"}
0005432721272	655C13	1431 458425	PETR KOZLOV	{"phone": "+70746940578"}
0005432721273	655C13	9651 280700	ANASTASIYA DANILOVA	{"email": "anastasiya_danilova12101975@postgrespro.ru", "phone": "+70705232353"}
0005432721274	E1BB22	3788 133741	GENNADIY AFANASEV	{"phone": "+70359488698"}
0005432721275	0A98FF	1670 532088	VALENTINA ANDREEVA	{"email": "andreeva-v_04081975@postgrespro.ru", "phone": "+70318551455"}
0005432721276	8567E7	0975 672106	MARINA NIKIFOROVA	{"phone": "+70731269282"}
0005432721277	8567E7	4409 141164	SVETLANA KOLESNIKOVA	{"email": "svetlanakolesnikova071972@postgrespro.ru", "phone": "+70987703167"}
0005432721278	3100B1	6361 814267	NATALYA SMIRNOVA	{"email": "n.smirnova.12101979@postgrespro.ru", "phone": "+70793815471"}
0005432721279	3100B1	5556 857608	EKATERINA KOZLOVA	{"phone": "+70414855646"}
0005432721280	2BCDDA	5085 541829	NINA MAKSIMOVA	{"phone": "+70063899174"}
0005432721281	2BCDDA	6966 121002	ALEKSANDR SHEVCHENKO	{"phone": "+70275709038"}
0005432721282	5E473B	3006 769321	ELIZAVETA NIKOLAEVA	{"email": "elizaveta-nikolaeva021971@postgrespro.ru", "phone": "+70215878580"}
0005432721283	9E2BF1	9408 403910	YURIY NIKITIN	{"email": "nikitiny_1973@postgrespro.ru", "phone": "+70857258630"}
0005432721284	9E2BF1	4621 230938	TATYANA VASILEVA	{"phone": "+70931780788"}
0005432721285	DC9906	8369 838614	ALLA KONOVALOVA	{"email": "allakonovalova_1984@postgrespro.ru", "phone": "+70237846630"}
0005432721286	9167B6	8841 228751	VIKTOR POPOV	{"email": "popov_viktor05061972@postgrespro.ru", "phone": "+70356305807"}
0005432721287	248CA9	6825 229151	OLESYA PETROVA	{"email": "olesyapetrova12031965@postgrespro.ru", "phone": "+70393439814"}
0005432721288	248CA9	2341 167265	EKATERINA SOKOLOVA	{"email": "ekaterina_sokolova.1966@postgrespro.ru", "phone": "+70288349671"}
0005432721289	E5B0B8	9926 177266	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov-05051966@postgrespro.ru", "phone": "+70996232843"}
0005432721290	D92C42	0362 807651	TAMARA SOLOVEVA	{"phone": "+70573477087"}
0005432721291	D92C42	0303 590455	NATALIYA BELYAEVA	{"email": "belyaeva-n.15021979@postgrespro.ru", "phone": "+70828106113"}
0005432721292	D92C42	3265 670904	SOFYA GAVRILOVA	{"phone": "+70265394088"}
0005432721293	983945	1035 729000	MARIYA MASLOVA	{"email": "maslova.mariya.1968@postgrespro.ru", "phone": "+70272269324"}
0005432721294	EB9988	3933 229620	ALEKSANDR CHERNOV	{"phone": "+70091071853"}
0005432721295	EB9988	4095 731486	RAVIL KOROLEV	{"phone": "+70566069746"}
0005432721296	A50E9F	2898 022159	LYUDMILA MOROZOVA	{"phone": "+70827629212"}
0005432721297	28D60C	1173 734152	ANTON NAUMOV	{"phone": "+70342630928"}
0005432721298	6145B0	0931 552544	RUSTAM CHERNOV	{"phone": "+70146123185"}
0005432721299	6145B0	3515 372545	VALENTINA SOROKINA	{"email": "sorokinavalentina_031978@postgrespro.ru", "phone": "+70085665558"}
0005432721300	7114EA	7231 712690	VALENTINA ISAEVA	{"email": "isaeva-valentina.10021970@postgrespro.ru", "phone": "+70730561745"}
0005432721301	2FCB2A	9148 367180	ANASTASIYA SAVELEVA	{"email": "savelevaanastasiya_25021979@postgrespro.ru", "phone": "+70014956764"}
0005432721302	4D3685	5383 447705	ELENA DAVYDOVA	{"email": "elenadavydova_1962@postgrespro.ru", "phone": "+70726194118"}
0005432721303	D5A417	3398 828832	RAIL VASILEV	{"phone": "+70910385540"}
0005432721304	D5A417	1905 465497	ELENA ILINA	{"phone": "+70015365329"}
0005432721305	D5A417	2947 564881	VIKTORIYA FEDOROVA	{"phone": "+70378575874"}
0005432721306	1E46B9	2222 839644	SERGEY FOMIN	{"phone": "+70497338544"}
0005432721307	1E46B9	4692 535106	VLADIMIR KUZNECOV	{"phone": "+70347559348"}
0005432721308	BD970D	2765 344079	TATYANA KAZAKOVA	{"email": "kazakova-tatyana.1978@postgrespro.ru", "phone": "+70043170771"}
0005432721309	26F8F9	5438 609622	NADEZHDA ANTONOVA	{"email": "antonova-n101980@postgrespro.ru", "phone": "+70710767568"}
0005432721310	26F8F9	0977 392576	NIKITA KOZLOV	{"email": "nikita.kozlov_1972@postgrespro.ru", "phone": "+70112537824"}
0005432721311	DF7BAF	7744 746813	VLADIMIR MOROZOV	{"phone": "+70204805084"}
0005432721312	904D03	0099 230801	NATALIYA BOGDANOVA	{"phone": "+70539544449"}
0005432721313	A5BCD6	6330 206593	ELENA MOROZOVA	{"email": "morozova_elena1976@postgrespro.ru", "phone": "+70018680159"}
0005432721314	A5BCD6	5633 201582	GALINA FOMINA	{"email": "fominag-1966@postgrespro.ru", "phone": "+70152014847"}
0005432721315	A5BCD6	2894 685396	ELENA GORBUNOVA	{"phone": "+70058995847"}
0005432721316	ED9222	7677 691895	VIKTOR KOROLEV	{"email": "viktor-korolev091980@postgrespro.ru", "phone": "+70355805485"}
0005432721317	9486F3	0208 153920	TIGRAN POPOV	{"phone": "+70976913186"}
0005432721318	04F631	7794 366554	VLADISLAV SOLOVEV	{"email": "vladislav-solovev1967@postgrespro.ru", "phone": "+70398627928"}
0005432721319	F5CF5B	9935 404325	YANA IVANOVA	{"email": "ivanova-y-31011979@postgrespro.ru", "phone": "+70487838290"}
0005432721320	08B2E4	5975 655094	ANVAR ANDREEV	{"phone": "+70874117323"}
0005432721321	C27A27	8014 300216	OLGA ANDREEVA	{"email": "o.andreeva-041976@postgrespro.ru", "phone": "+70826572094"}
0005432721322	D47E97	7764 826189	NIKITA KISELEV	{"email": "kiselev-nikita1988@postgrespro.ru", "phone": "+70995948789"}
0005432721323	5CFDAE	3028 299684	VASILIY STEPANOV	{"phone": "+70491021032"}
0005432721324	82C2FB	3391 005763	MARIYA VASILEVA	{"email": "vasilevamariya-26051965@postgrespro.ru", "phone": "+70388975883"}
0005432721325	C69E24	7726 613766	OLEG KUZNECOV	{"phone": "+70881321294"}
0005432721326	C69E24	5004 105210	ALEKSEY ANTONOV	{"phone": "+70917805124"}
0005432721327	6E5BAC	4953 087451	SVETLANA ANTONOVA	{"email": "antonova_s-071977@postgrespro.ru", "phone": "+70382630064"}
0005432721328	6E5BAC	4541 783353	PETR TIKHONOV	{"email": "tikhonovpetr-1969@postgrespro.ru", "phone": "+70275701484"}
0005432721329	1AE3CB	7126 285906	VALENTINA ILINA	{"email": "v-ilina-041965@postgrespro.ru", "phone": "+70791145728"}
0005432721330	1AE3CB	8356 975796	RAISA ZHUKOVA	{"email": "zhukova.raisa29041969@postgrespro.ru", "phone": "+70524698329"}
0005432721331	8F6FBC	4949 108606	GLEB DAVYDOV	{"phone": "+70398348770"}
0005432721332	9C8DB7	2608 356563	VYACHESLAV MEDVEDEV	{"email": "vyacheslavmedvedev_1980@postgrespro.ru", "phone": "+70176312412"}
0005432721333	9C8DB7	3388 850000	VIKTOR KUZMIN	{"phone": "+70902521301"}
0005432721334	0893C5	7670 978327	ANTONINA KOROLEVA	{"phone": "+70259110636"}
0005432721335	C09A35	0633 244194	NIKOLAY MOROZOV	{"email": "morozovnikolay-1978@postgrespro.ru", "phone": "+70399671007"}
0005432721336	C09A35	5126 294022	ANDREY MAKSIMOV	{"phone": "+70936994441"}
0005432721337	CBC092	1503 597437	DMITRIY IVANOV	{"email": "dmitriy_ivanov_121972@postgrespro.ru", "phone": "+70084732859"}
0005432721338	C83814	6479 186525	PAVEL MOROZOV	{"phone": "+70485857838"}
0005432721339	D57815	1287 750785	ALENA IVANOVA	{"email": "a-ivanova.15021974@postgrespro.ru", "phone": "+70156281886"}
0005432721340	B3E139	5606 944338	NATALIYA OVCHINNIKOVA	{"phone": "+70358656303"}
0005432721341	B3E139	7196 437067	ELENA MELNIKOVA	{"email": "melnikova_elena_28081966@postgrespro.ru", "phone": "+70459532668"}
0005432721342	B3E139	6597 876459	LYUDMILA TARASOVA	{"phone": "+70807081472"}
0005432721343	58268A	2220 700042	VYACHESLAV MATVEEV	{"email": "matveevvyacheslav11121972@postgrespro.ru", "phone": "+70240412367"}
0005432721344	0CFE4D	9551 713975	TATYANA NAUMOVA	{"email": "tatyana-naumova.12081970@postgrespro.ru", "phone": "+70004753999"}
0005432721345	0CFE4D	2548 413302	NIKITA MELNIKOV	{"email": "n-melnikov_061974@postgrespro.ru", "phone": "+70251302481"}
0005432721346	0AC935	8151 578966	DINA IVANOVA	{"phone": "+70991691691"}
0005432721347	A4DE51	8505 111487	ANASTASIYA SOROKINA	{"phone": "+70695340600"}
0005432721348	A4DE51	1698 660810	VITALIY GORBUNOV	{"email": "gorbunovvitaliy_061968@postgrespro.ru", "phone": "+70388160097"}
0005432721349	6F77DC	0065 857951	DMITRIY PETROV	{"email": "dmitriy_petrov-18101962@postgrespro.ru", "phone": "+70418155939"}
0005432721350	16EBA4	1084 249308	SERGEY MAKSIMOV	{"email": "s_maksimov01101978@postgrespro.ru", "phone": "+70072190158"}
0005432721351	16EBA4	9007 512303	VYACHESLAV BARANOV	{"phone": "+70507124135"}
0005432721352	16EBA4	6321 582319	ELENA MELNIKOVA	{"phone": "+70791712103"}
0005432721353	82EE5E	4079 988405	VALENTIN SIDOROV	{"email": "sidorov.v_1974@postgrespro.ru", "phone": "+70359346204"}
0005432721354	955675	8573 315233	PAVEL IVANOV	{"email": "pavel-ivanov_071969@postgrespro.ru", "phone": "+70744147113"}
0005432721355	B4D2D7	0219 669599	ALEKSEY MARTYNOV	{"email": "aleksey_martynov1969@postgrespro.ru", "phone": "+70703263680"}
0005432721356	B4D2D7	4427 440746	POLINA SERGEEVA	{"phone": "+70400909730"}
0005432721357	ED9275	6935 407243	VERA IVANOVA	{"phone": "+70391184494"}
0005432721358	ED9275	3760 639698	EVA DENISOVA	{"phone": "+70195448937"}
0005432721359	85A7CE	6295 469756	GALINA MOROZOVA	{"email": "morozovag25101970@postgrespro.ru", "phone": "+70765735785"}
0005432721360	85A7CE	0522 947485	IRINA ZAYCEVA	{"phone": "+70771694624"}
0005432721361	B14601	0754 983450	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr1979@postgrespro.ru", "phone": "+70664956459"}
0005432721362	B14601	8371 545784	SVETLANA BORISOVA	{"email": "borisova-s1968@postgrespro.ru", "phone": "+70373499945"}
0005432721363	70BB92	5980 876722	NINA KOZLOVA	{"phone": "+70135801387"}
0005432721364	70BB92	3299 627794	VITALIY SERGEEV	{"phone": "+70569354714"}
0005432721365	A53A02	1786 086460	GRIGORIY GAVRILOV	{"email": "grigoriy-gavrilov.051961@postgrespro.ru", "phone": "+70600843926"}
0005432721366	A53A02	9918 245731	MARINA ANDREEVA	{"phone": "+70681933756"}
0005432721367	DF5FF9	6974 422120	OLGA AKIMOVA	{"phone": "+70331047883"}
0005432721368	CD8FB2	1380 134318	ELEONORA KONDRATEVA	{"email": "eleonora.kondrateva.06061987@postgrespro.ru", "phone": "+70853816971"}
0005432721369	07F86E	4308 207575	ELENA MARTYNOVA	{"email": "elenamartynova_1963@postgrespro.ru", "phone": "+70953023657"}
0005432721370	07F86E	4081 611518	SVETLANA ERMAKOVA	{"phone": "+70475768151"}
0005432721371	07F86E	6200 350694	IRINA STEPANOVA	{"email": "irinastepanova.04031968@postgrespro.ru", "phone": "+70048551472"}
0005432721372	07F86E	2660 614417	ANZHELIKA KOZLOVA	{"phone": "+70030738651"}
0005432721373	FDA8B8	7782 635908	SULTAN SOKOLOV	{"email": "sokolov.sultan.11121966@postgrespro.ru", "phone": "+70494025850"}
0005432721374	EA05E5	6070 630542	ILNUR ABRAMOV	{"email": "abramov-i_1965@postgrespro.ru", "phone": "+70310590688"}
0005432721375	F3132E	9494 872893	VLADISLAV NOVIKOV	{"phone": "+70096747260"}
0005432721376	791EC4	8870 223282	TAMARA CHERNOVA	{"phone": "+70165459430"}
0005432721377	C00CDA	1724 761383	ROMAN SIDOROV	{"phone": "+70214683035"}
0005432721378	A675D1	2731 363107	MILENA ALEKSANDROVA	{"email": "aleksandrova.milena071967@postgrespro.ru", "phone": "+70043329426"}
0005432721379	DA0D2B	0705 279219	SERGEY ANDREEV	{"email": "s-andreev.15041976@postgrespro.ru", "phone": "+70723353251"}
0005432721380	DA0D2B	4559 097992	ARTEM ZHURAVLEV	{"phone": "+70822808784"}
0005432721381	3CCE38	1785 993724	KRISTINA SERGEEVA	{"email": "sergeeva_k-17091976@postgrespro.ru", "phone": "+70420720569"}
0005432721382	3CCE38	0382 547351	VALENTINA SEMENOVA	{"phone": "+70423229093"}
0005432721383	1AE9BA	9284 214401	TATYANA KOZLOVA	{"email": "tatyana.kozlova-1968@postgrespro.ru", "phone": "+70553555353"}
0005432721384	0492CE	7421 398452	SERGEY IVANOV	{"phone": "+70591963080"}
0005432721385	3DF0A0	7188 958364	VIKTORIYA SMIRNOVA	{"email": "smirnova_v21041974@postgrespro.ru", "phone": "+70174584853"}
0005432721386	3DF0A0	1062 584716	ELENA ZHURAVLEVA	{"phone": "+70597545479"}
0005432721387	3253F0	6045 942564	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev.1971@postgrespro.ru", "phone": "+70180911914"}
0005432721388	36C3EE	8519 314419	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov061973@postgrespro.ru", "phone": "+70207725473"}
0005432721389	36C3EE	5086 820830	VIKTOR ANTONOV	{"email": "vantonov.1976@postgrespro.ru", "phone": "+70217086502"}
0005432721390	4B4598	8671 032591	GALINA AKIMOVA	{"phone": "+70188395812"}
0005432721391	3C54A7	8040 388803	TATYANA MATVEEVA	{"email": "matveeva-t_04011967@postgrespro.ru", "phone": "+70567244912"}
0005432721392	14DBAD	5928 528841	ELENA MIRONOVA	{"email": "e_mironova_081977@postgrespro.ru", "phone": "+70269672984"}
0005432721393	A33E88	7645 974038	NIKOLAY SOLOVEV	{"email": "solovev_n-04071967@postgrespro.ru", "phone": "+70162264471"}
0005432721394	A33E88	7534 059852	ELENA KARPOVA	{"phone": "+70455128795"}
0005432721395	A33E88	7582 882288	NIKITA ORLOV	{"email": "nikitaorlov_091975@postgrespro.ru", "phone": "+70840652141"}
0005432721396	CBF42F	6772 646936	RAISA SMIRNOVA	{"phone": "+70426866528"}
0005432721397	B1BF8C	0683 802012	YULIYA PAVLOVA	{"phone": "+70701454126"}
0005432721398	A3DEC2	9827 965161	VIKTOR ROMANOV	{"email": "romanovviktor_23061978@postgrespro.ru", "phone": "+70141744833"}
0005432721399	23C77D	3282 764541	SERGEY KUZNECOV	{"email": "sergeykuznecov.031983@postgrespro.ru", "phone": "+70900300962"}
0005432721400	E2C05D	0224 896075	GALINA ZAKHAROVA	{"phone": "+70917880570"}
0005432721401	9A712B	0272 539483	NATALYA MEDVEDEVA	{"phone": "+70034947970"}
0005432721402	7B5988	0381 624021	VERA MOISEEVA	{"phone": "+70087668561"}
0005432721403	ADED43	1492 906599	ANASTASIYA SCHERBAKOVA	{"phone": "+70154298676"}
0005432721404	7B9FAA	6695 879730	GALINA KOVALEVA	{"phone": "+70556653566"}
0005432721405	11E375	9401 918571	IGOR KULIKOV	{"phone": "+70693535898"}
0005432721406	7D14C4	3152 100630	RENAT PETROV	{"phone": "+70951810026"}
0005432721407	7D14C4	7626 978533	GALINA AKIMOVA	{"phone": "+70301900262"}
0005432721465	1CBA1E	9280 306627	DMITRIY ROMANOV	{"phone": "+70974184231"}
0005432721408	7D14C4	7577 555922	LIDIYA KULIKOVA	{"email": "kulikovalidiya-1962@postgrespro.ru", "phone": "+70610069672"}
0005432721409	006B99	8001 422541	VIKTOR ISAEV	{"phone": "+70326934253"}
0005432721410	006B99	2316 531342	ELENA OSIPOVA	{"email": "elenaosipova091978@postgrespro.ru", "phone": "+70979016567"}
0005432721411	93CBDD	0834 726444	GALINA AKIMOVA	{"phone": "+70546325640"}
0005432721412	B79D07	1009 388858	VIKTOR GERASIMOV	{"phone": "+70154783455"}
0005432721413	B79D07	8018 619209	VLADIMIR SMIRNOV	{"phone": "+70821769086"}
0005432721414	C6DD95	4151 310255	YULIYA ISAEVA	{"email": "yuliya_isaeva.24051973@postgrespro.ru", "phone": "+70009898340"}
0005432721415	F6760A	9199 375748	ALEKSANDR ISAEV	{"phone": "+70698540809"}
0005432721416	3D7A1E	4610 316201	VIKTORIYA ISAEVA	{"phone": "+70039542413"}
0005432721417	3D7A1E	1416 823718	POLINA FEDOROVA	{"phone": "+70990660370"}
0005432721418	5E2DC3	8525 953841	PAVEL IVANOV	{"phone": "+70039881533"}
0005432721419	5E2DC3	2154 275253	SERGEY KONOVALOV	{"phone": "+70818684344"}
0005432721420	B7F689	2221 280279	SERGEY KOROLEV	{"phone": "+70138598642"}
0005432721421	B7F689	3112 577512	EVGENIY ILIN	{"phone": "+70725869393"}
0005432721422	80EC72	8098 068261	GENNADIY KUZNECOV	{"email": "kuznecov_gennadiy-021978@postgrespro.ru", "phone": "+70850309085"}
0005432721423	80EC72	9301 275403	ARTEMIY DAVYDOV	{"phone": "+70957505549"}
0005432721424	CE04AB	4786 104301	VARVARA ALEKSANDROVA	{"email": "valeksandrova.091977@postgrespro.ru", "phone": "+70166494300"}
0005432721425	AC7343	2928 968954	IRINA SOKOLOVA	{"email": "i.sokolova-15061971@postgrespro.ru", "phone": "+70040060010"}
0005432721426	DF5C20	8246 523812	VYACHESLAV MATVEEV	{"phone": "+70044720842"}
0005432721427	352D92	9789 808595	ELENA ZAKHAROVA	{"email": "zakharovae17011982@postgrespro.ru", "phone": "+70390820321"}
0005432721428	352D92	2595 727803	ANDREY SHEVCHENKO	{"email": "shevchenko-andrey.101964@postgrespro.ru", "phone": "+70948204866"}
0005432721429	9F57F1	5654 158098	IRINA DAVYDOVA	{"email": "davydova_irina_03101976@postgrespro.ru", "phone": "+70170676970"}
0005432721430	760FB9	2348 553462	LIDIYA KAZAKOVA	{"email": "l.kazakova.06031972@postgrespro.ru", "phone": "+70292529879"}
0005432721431	4EF800	8806 882627	VALERIY PAVLOV	{"phone": "+70315599248"}
0005432721432	C4DC2E	1120 216606	EKATERINA ALEKSANDROVA	{"phone": "+70060515946"}
0005432721433	C4DC2E	0521 347679	VLADIMIR SCHERBAKOV	{"phone": "+70591257770"}
0005432721434	CA6C3D	3390 930031	ALINA VOLKOVA	{"email": "volkova.a091970@postgrespro.ru", "phone": "+70044505756"}
0005432721435	025297	3045 202737	ELENA KOZLOVA	{"email": "kozlova.elena-1964@postgrespro.ru", "phone": "+70584292905"}
0005432721436	6BABF1	3044 660698	NIKOLAY VASILEV	{"email": "vasilev.nikolay-1980@postgrespro.ru", "phone": "+70326940807"}
0005432721437	9C23FB	2893 906113	ALEKSEY MAKAROV	{"phone": "+70603082869"}
0005432721438	9C23FB	4157 994530	NATALYA ROMANOVA	{"phone": "+70452046285"}
0005432721439	B36B84	6946 478665	ANDREY IVANOV	{"email": "a_ivanov.061970@postgrespro.ru", "phone": "+70162116237"}
0005432721440	E58070	5147 813325	YURIY VOROBEV	{"phone": "+70509645949"}
0005432721441	E58070	5760 358288	DMITRIY KONOVALOV	{"phone": "+70818953982"}
0005432721442	590521	9722 394292	ARTEM KUDRYASHOV	{"email": "akudryashov1976@postgrespro.ru", "phone": "+70051724046"}
0005432721443	590521	7249 073345	VALENTINA EGOROVA	{"email": "valentinaegorova.10081986@postgrespro.ru", "phone": "+70495800739"}
0005432721444	A75872	7528 992579	TATYANA ANISIMOVA	{"phone": "+70911898711"}
0005432721445	A75872	5963 695724	SERGEY ZAKHAROV	{"phone": "+70861216967"}
0005432721446	7B693D	4903 192488	RUSLAN FEDOROV	{"phone": "+70315790291"}
0005432721447	F634B1	3796 341129	VALENTINA MARTYNOVA	{"phone": "+70586718222"}
0005432721448	696E13	2588 123400	ALEKSEY VLASOV	{"phone": "+70525770910"}
0005432721449	E0082C	9937 798861	ANDREY ANTONOV	{"email": "antonov.a_30071964@postgrespro.ru", "phone": "+70308888768"}
0005432721450	41DC6D	6489 849617	LIDIYA KUZNECOVA	{"phone": "+70710092321"}
0005432721451	41DC6D	5564 374199	VIKTOR IVANOV	{"phone": "+70951923024"}
0005432721452	5A743B	9395 500475	ANNA TIKHONOVA	{"phone": "+70528468363"}
0005432721453	5A743B	4720 833196	ANNA DMITRIEVA	{"phone": "+70182299759"}
0005432721454	FFD44F	1761 369600	VLADIMIR ANDREEV	{"email": "v.andreev-20101974@postgrespro.ru", "phone": "+70002511157"}
0005432721455	D80852	6672 229417	ANNA SERGEEVA	{"email": "sergeeva_a_16021979@postgrespro.ru", "phone": "+70176034685"}
0005432721456	CF7110	1129 413725	SERGEY FILIPPOV	{"phone": "+70335756218"}
0005432721457	A72E67	6917 029167	ALEKSANDR SIDOROV	{"email": "a.sidorov-02051980@postgrespro.ru", "phone": "+70425581273"}
0005432721458	59EAC2	9348 788668	LYUBOV NIKOLAEVA	{"phone": "+70379313357"}
0005432721459	59EAC2	7017 946538	ALEKSANDRA ISAEVA	{"phone": "+70387946439"}
0005432721460	330455	2560 362703	LYUDMILA FROLOVA	{"phone": "+70113380434"}
0005432721461	7B8BB8	5616 164778	LYUDMILA VOLKOVA	{"phone": "+70105005740"}
0005432721462	7B8BB8	3210 619066	SERGEY ZAYCEV	{"phone": "+70912162083"}
0005432721463	871C20	2396 323373	ANTONINA PETROVA	{"phone": "+70063313722"}
0005432721464	45FA45	1335 426620	OKSANA FEDOROVA	{"email": "fedorova_oksana-11071973@postgrespro.ru", "phone": "+70863455506"}
0005432721466	F61993	7645 751025	ARTUR MOROZOV	{"email": "morozov.a.04101960@postgrespro.ru", "phone": "+70651300524"}
0005432721467	C568A0	9321 209986	ALEKSANDR IVANOV	{"phone": "+70402769992"}
0005432721468	57ED68	8624 904788	NADEZHDA MIRONOVA	{"phone": "+70932678191"}
0005432721469	1440B9	9308 547794	MARINA GAVRILOVA	{"email": "marina.gavrilova.06071975@postgrespro.ru", "phone": "+70837219685"}
0005432721470	1440B9	0383 062544	ELENA SOKOLOVA	{"email": "e-sokolova_1965@postgrespro.ru", "phone": "+70572296013"}
0005432721471	1440B9	4930 784328	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov031976@postgrespro.ru", "phone": "+70538836151"}
0005432721472	F4F8D4	2104 855448	VIKTORIYA IVANOVA	{"phone": "+70817865760"}
0005432721473	3E1BE0	9154 068315	MIKHAIL PAVLOV	{"phone": "+70250923220"}
0005432721474	C86604	6404 479748	NATALYA NOVIKOVA	{"email": "novikova_n.101964@postgrespro.ru", "phone": "+70354242043"}
0005432721475	FC46EA	7237 335766	ALLA ZHUKOVA	{"phone": "+70538671182"}
0005432721476	395293	4657 177927	OLGA POTAPOVA	{"email": "o.potapova.04101972@postgrespro.ru", "phone": "+70797899546"}
0005432721477	7C4AEF	9910 590170	ALEKSEY RODIONOV	{"phone": "+70229457661"}
0005432721478	2ED230	0204 451473	ALEKSEY GRIGOREV	{"phone": "+70668199883"}
0005432721479	9578F9	2719 516364	VALENTINA ERMAKOVA	{"email": "ermakova_v-17061971@postgrespro.ru", "phone": "+70097397826"}
0005432721480	5B7A1F	8961 653901	VALERIY MAKAROV	{"phone": "+70858358876"}
0005432721481	5B7A1F	7941 019220	POLINA ANDREEVA	{"phone": "+70643415367"}
0005432721482	73FABD	9867 856221	DENIS KARPOV	{"email": "karpov_denis.121982@postgrespro.ru", "phone": "+70249255066"}
0005432721483	B317B6	9560 312689	EVGENIY KRASNOV	{"phone": "+70973153849"}
0005432721484	06DCE4	9652 377050	GUZEL KUZMINA	{"email": "kuzmina.g_1972@postgrespro.ru", "phone": "+70450913640"}
0005432721485	06DCE4	3370 223135	NINA KISELEVA	{"phone": "+70907710975"}
0005432721486	6702F6	2878 508747	VENIAMIN ABRAMOV	{"email": "veniamin-abramov_1981@postgrespro.ru", "phone": "+70792271991"}
0005432721487	48C2F2	8508 327876	VLADIMIR KULIKOV	{"phone": "+70962620622"}
0005432721488	48C2F2	7914 927468	LYUDMILA FILIPPOVA	{"email": "lyudmila_filippova_1983@postgrespro.ru", "phone": "+70222035049"}
0005432721489	035FBA	5548 972728	TATYANA NIKOLAEVA	{"email": "t.nikolaeva-1975@postgrespro.ru", "phone": "+70658388936"}
0005432721490	495E53	1939 034206	SERGEY ABRAMOV	{"email": "abramov_sergey_1973@postgrespro.ru", "phone": "+70796212087"}
0005432721491	6E7E87	6757 208983	ALEKSANDR ZAKHAROV	{"phone": "+70655801621"}
0005432721492	40456D	6110 010658	GALINA CHERNOVA	{"email": "chernovagalina.091972@postgrespro.ru", "phone": "+70419897098"}
0005432721493	40456D	9636 820424	ALINA FILATOVA	{"email": "filatova_alina081975@postgrespro.ru", "phone": "+70988770624"}
0005432721494	3E821A	5680 890066	VYACHESLAV ROMANOV	{"email": "romanovv-071981@postgrespro.ru", "phone": "+70277235709"}
0005432721495	3E821A	9581 909681	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov_1972@postgrespro.ru", "phone": "+70947064692"}
0005432721496	3E821A	0941 292462	YULIYA KISELEVA	{"email": "kiseleva_yuliya.1973@postgrespro.ru", "phone": "+70726733992"}
0005432721497	66A874	1872 492621	TATYANA DAVYDOVA	{"phone": "+70539391522"}
0005432721498	2D8D73	4451 891661	ALEKSEY TARASOV	{"email": "tarasova.041975@postgrespro.ru", "phone": "+70744005570"}
0005432721499	F92B1C	8647 550029	MAKSIM ZHUKOV	{"phone": "+70095330729"}
0005432721500	123DB3	8253 873170	ANNA ZAYCEVA	{"email": "zayceva-anna.071980@postgrespro.ru", "phone": "+70312470149"}
0005432721501	DC2FBA	0211 225286	FAINA SERGEEVA	{"phone": "+70116235684"}
0005432721502	DC2FBA	9684 931868	DIANA KRASNOVA	{"email": "krasnovadiana-07111974@postgrespro.ru", "phone": "+70355457058"}
0005432721503	F2A120	3258 461382	SERGEY MOROZOV	{"phone": "+70089885596"}
0005432721504	774334	6399 328429	VALERIY SERGEEV	{"phone": "+70896377600"}
0005432721505	32C1DE	1302 231744	NIKOLAY KOZLOV	{"email": "n.kozlov.1975@postgrespro.ru", "phone": "+70696455923"}
0005432721506	782EFF	0796 656859	ARTEM FOMIN	{"email": "a_fomin_051963@postgrespro.ru", "phone": "+70018060207"}
0005432721507	782EFF	1395 162540	NINA PETROVA	{"email": "petrova-nina_081972@postgrespro.ru", "phone": "+70905859395"}
0005432721508	4724CB	6213 964874	GENNADIY PAVLOV	{"email": "gennadiy-pavlov-1957@postgrespro.ru", "phone": "+70882344323"}
0005432721509	4724CB	4334 996012	NIKITA ABRAMOV	{"email": "abramov.nikita-12121970@postgrespro.ru", "phone": "+70413426081"}
0005432721510	07BE72	8040 459934	LILIYA ZAKHAROVA	{"phone": "+70567464429"}
0005432721511	59F1EF	4850 720578	DENIS BONDARENKO	{"phone": "+70885501652"}
0005432721512	D619DA	6895 250120	EVGENIYA KUDRYASHOVA	{"email": "kudryashova_evgeniya.101968@postgrespro.ru", "phone": "+70501306438"}
0005432721513	B37788	1718 757945	TATYANA BOGDANOVA	{"email": "bogdanova-t_10061967@postgrespro.ru", "phone": "+70241604761"}
0005432721514	B37788	8480 329460	SERGEY VOLKOV	{"phone": "+70633237365"}
0005432721515	AA8F01	9917 250404	LYUDMILA MEDVEDEVA	{"email": "medvedeva-lyudmila-25021975@postgrespro.ru", "phone": "+70817537635"}
0005432721516	AA8F01	9215 773274	PAVEL DMITRIEV	{"email": "dmitriev_pavel_1979@postgrespro.ru", "phone": "+70269974441"}
0005432721517	384615	0493 152711	SERGEY MAKSIMOV	{"email": "maksimovs-071960@postgrespro.ru", "phone": "+70166623395"}
0005432721518	575143	6032 085486	IRINA EGOROVA	{"email": "egorova_irina24061965@postgrespro.ru", "phone": "+70275871413"}
0005432721519	4E6B18	5656 269030	MIKHAIL KOZLOV	{"email": "kozlov.mikhail041977@postgrespro.ru", "phone": "+70953494619"}
0005432721520	4E6B18	8820 670101	SERGEY EGOROV	{"phone": "+70444155504"}
0005432721521	5AB494	5470 631657	GALIYA NIKOLAEVA	{"email": "gnikolaeva-021964@postgrespro.ru", "phone": "+70838086473"}
0005432721522	70D331	9118 821646	VLADIMIR TARASOV	{"phone": "+70967548332"}
0005432721523	BC3EBD	3188 605933	ANDREY KUZNECOV	{"email": "a.kuznecov071974@postgrespro.ru", "phone": "+70416938706"}
0005432721524	CF02DE	0426 281183	VALERIY POPOV	{"phone": "+70507296770"}
0005432721525	2E2B81	3332 806836	MARINA MALYSHEVA	{"phone": "+70820517489"}
0005432721526	0B92B8	2643 601071	MARIYA EGOROVA	{"phone": "+70067241514"}
0005432721527	D47C59	4898 360665	TATYANA ANDREEVA	{"phone": "+70314942352"}
0005432721528	3343E6	6912 101803	EVGENIYA GORBUNOVA	{"email": "evgeniya.gorbunova1966@postgrespro.ru", "phone": "+70888294012"}
0005432721529	3F84A1	1455 007259	GENNADIY ZAKHAROV	{"email": "gennadiyzakharov_071950@postgrespro.ru", "phone": "+70519743286"}
0005432721530	B02832	4502 006471	VLADIMIR FEDOROV	{"phone": "+70316592848"}
0005432721531	17B154	6997 410503	SERGEY GORBUNOV	{"email": "sgorbunov-09051978@postgrespro.ru", "phone": "+70886765146"}
0005432721532	17B154	9112 410504	VLADIMIR CHERNOV	{"email": "chernov_v_22031960@postgrespro.ru", "phone": "+70514911183"}
0005432721533	2C9204	1202 006638	YULIYA MAKSIMOVA	{"email": "y.maksimova-1977@postgrespro.ru", "phone": "+70302648593"}
0005432721534	90ADAD	1711 751797	SERGEY SEMENOV	{"email": "semenov-s1969@postgrespro.ru", "phone": "+70487749879"}
0005432721535	90ADAD	9604 692823	OLEG KUZNECOV	{"phone": "+70014514261"}
0005432721536	C45EA1	0645 533684	SVETLANA NIKOLAEVA	{"email": "nikolaeva.svetlana_23011968@postgrespro.ru", "phone": "+70540876391"}
0005432721537	145E9B	4552 577873	MARIYA IVANOVA	{"phone": "+70082829751"}
0005432721538	145E9B	3183 285812	MARINA KISELEVA	{"phone": "+70468701864"}
0005432721539	4DE586	6112 866893	ZOYA KULIKOVA	{"email": "kulikova.zoya-1971@postgrespro.ru", "phone": "+70699211274"}
0005432721540	4DE586	7308 297457	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev-1980@postgrespro.ru", "phone": "+70933377198"}
0005432721596	367F18	0920 327544	TATYANA LUKYANOVA	{"phone": "+70203270167"}
0005432721541	98D6F1	1613 750854	EVGENIY VOROBEV	{"email": "e.vorobev.1966@postgrespro.ru", "phone": "+70132393711"}
0005432721542	F95EC3	3854 775435	SERGEY MOISEEV	{"phone": "+70047511838"}
0005432721543	F95EC3	1759 242414	IGOR FROLOV	{"phone": "+70000635361"}
0005432721544	FDF63B	7981 906970	VIKTOR SCHERBAKOV	{"email": "v_scherbakov-061972@postgrespro.ru", "phone": "+70856177622"}
0005432721545	56B198	7892 616743	ANASTASIYA YAKOVLEVA	{"email": "ayakovleva_041959@postgrespro.ru", "phone": "+70750721762"}
0005432721546	2C259D	1541 122217	GALINA BELOVA	{"phone": "+70324753289"}
0005432721547	2C259D	3158 918826	EVGENIY IVANOV	{"email": "e-ivanov071968@postgrespro.ru", "phone": "+70549084104"}
0005432721548	3D14DF	6640 034704	ARTEM STEPANOV	{"phone": "+70769097977"}
0005432721549	3D14DF	5074 324725	LYUBOV DAVYDOVA	{"email": "davydoval.17111979@postgrespro.ru", "phone": "+70382959048"}
0005432721550	785A6A	3150 655249	NINA ZHUKOVA	{"phone": "+70742435365"}
0005432721551	B085FD	8183 929747	GALINA FILIPPOVA	{"phone": "+70928286587"}
0005432721552	9E7C37	5058 077914	NATALYA MIKHAYLOVA	{"phone": "+70322927041"}
0005432721553	52C274	8493 313631	VLADIMIR NIKITIN	{"phone": "+70994954989"}
0005432721554	17DA2A	7348 853470	VLADIMIR POPOV	{"phone": "+70036652184"}
0005432721555	4EE7BA	2523 055304	ANATOLIY IVANOV	{"phone": "+70547213884"}
0005432721556	8E8575	5901 402139	GRIGORIY ORLOV	{"email": "grigoriy-orlov_10061967@postgrespro.ru", "phone": "+70550787899"}
0005432721557	7C9CAC	3579 649426	LIDIYA MOISEEVA	{"phone": "+70732293132"}
0005432721558	7C9CAC	6003 094094	LYUDMILA SCHERBAKOVA	{"phone": "+70149166875"}
0005432721559	4A3A61	3426 269486	NINA ERMAKOVA	{"email": "n.ermakova-1979@postgrespro.ru", "phone": "+70791383975"}
0005432721560	4A3A61	1448 256191	SERGEY ROMANOV	{"email": "sergey_romanov.091970@postgrespro.ru", "phone": "+70002296997"}
0005432721561	A1C128	7405 205748	ANTON NIKITIN	{"email": "nikitinanton091961@postgrespro.ru", "phone": "+70869569205"}
0005432721562	A1C128	8487 776853	MARIYA NOVIKOVA	{"email": "novikovam-29031975@postgrespro.ru", "phone": "+70635992267"}
0005432721563	04ED0E	9379 373654	ZOYA IVANOVA	{"email": "ivanova-z1969@postgrespro.ru", "phone": "+70639635489"}
0005432721564	AC20B7	7954 515628	ELENA LAZAREVA	{"email": "lazareva-elena.1962@postgrespro.ru", "phone": "+70665579752"}
0005432721565	8FE24D	6905 170770	ZOYA FROLOVA	{"email": "zoyafrolova_1970@postgrespro.ru", "phone": "+70237340735"}
0005432721566	E6A36E	4779 617021	ALEKSANDR IVANOV	{"email": "ivanova-22021968@postgrespro.ru", "phone": "+70287307125"}
0005432721567	C11D57	3120 803111	BORIS SHEVCHENKO	{"email": "shevchenkob-081980@postgrespro.ru", "phone": "+70697885436"}
0005432721568	C11D57	1921 723169	YANA FILIPPOVA	{"email": "filippova_y16101960@postgrespro.ru", "phone": "+70243822786"}
0005432721569	6A6852	6080 849627	MARIYA KUZNECOVA	{"email": "m.kuznecova-1980@postgrespro.ru", "phone": "+70102241318"}
0005432721570	678D38	1485 030710	IRINA CHERNOVA	{"email": "chernova.irina_1955@postgrespro.ru", "phone": "+70086593020"}
0005432721571	F9D4C6	7430 354658	SALAVAT SIDOROV	{"email": "s_sidorov08081974@postgrespro.ru", "phone": "+70741261993"}
0005432721572	A40F65	3194 777379	VERA SERGEEVA	{"phone": "+70623867038"}
0005432721573	A40F65	3433 970027	OLGA KULIKOVA	{"email": "o.kulikova_29071973@postgrespro.ru", "phone": "+70185770329"}
0005432721574	DDB6CC	8728 546306	VIKTOR MAKAROV	{"phone": "+70494415177"}
0005432721575	DDB6CC	1966 590982	OLGA KUZNECOVA	{"email": "kuznecova_o_1969@postgrespro.ru", "phone": "+70546209011"}
0005432721632	023A92	9932 561504	MARIYA KOZLOVA	{"phone": "+70462505781"}
0005432721576	B0E6DF	5579 354389	YULIYA TIKHONOVA	{"email": "tikhonova-yuliya1984@postgrespro.ru", "phone": "+70530738904"}
0005432721577	0F1EFE	3099 717310	ALEKSANDR KUZMIN	{"email": "a_kuzmin.1967@postgrespro.ru", "phone": "+70524341001"}
0005432721578	BEBF39	8949 556227	YURIY ALEKSEEV	{"email": "alekseev-yuriy_26081969@postgrespro.ru", "phone": "+70970225764"}
0005432721579	BEBF39	9408 693254	TAMARA KARPOVA	{"phone": "+70665923651"}
0005432721580	63AFE8	0462 674910	ANNA NIKIFOROVA	{"email": "anna.nikiforova_1968@postgrespro.ru", "phone": "+70775660797"}
0005432721581	63AFE8	0610 363055	VASILIY KAZAKOV	{"phone": "+70128564764"}
0005432721582	63AFE8	2179 374956	VITALIY VOLKOV	{"phone": "+70124805054"}
0005432721583	64C7D2	3717 678529	ANDREY PETROV	{"phone": "+70476397929"}
0005432721584	2D85C4	9556 404778	TATYANA SOROKINA	{"email": "sorokinatatyana_1964@postgrespro.ru", "phone": "+70260143080"}
0005432721585	2D85C4	1372 379532	NATALYA SIDOROVA	{"email": "sidorova-natalya-011977@postgrespro.ru", "phone": "+70486073191"}
0005432721586	2CC428	7582 139410	IGOR SEMENOV	{"phone": "+70006128686"}
0005432721587	98C661	8119 687613	ANASTASIYA ERMAKOVA	{"email": "a_ermakova.101966@postgrespro.ru", "phone": "+70135853664"}
0005432721588	98C661	2983 456413	EVGENIY CHERNOV	{"email": "e-chernov051970@postgrespro.ru", "phone": "+70858516927"}
0005432721589	C4FF1E	8825 356987	AYRAT SAVELEV	{"email": "savelev.ayrat.31121964@postgrespro.ru", "phone": "+70288376706"}
0005432721590	EE9E23	1484 586480	VIKTOR KUZMIN	{"phone": "+70427977644"}
0005432721591	FDCB3D	3387 689916	NIKITA GUSEV	{"email": "nikita-gusev-1961@postgrespro.ru", "phone": "+70992037735"}
0005432721592	EEB605	2673 726656	DIANA KRASNOVA	{"phone": "+70150979607"}
0005432721593	EEB605	0989 958132	MARGARITA MOROZOVA	{"email": "m_morozova-1976@postgrespro.ru", "phone": "+70267161887"}
0005432721594	E9C6A3	7924 082658	IVAN SMIRNOV	{"phone": "+70947482644"}
0005432721595	E9C6A3	1143 919945	VIKTOR IVANOV	{"phone": "+70524522166"}
0005432721597	EB5879	3714 686468	TATYANA VLASOVA	{"email": "vlasova.t091972@postgrespro.ru", "phone": "+70857590707"}
0005432721598	37D45A	4882 381959	EKATERINA DENISOVA	{"email": "e.denisova_1970@postgrespro.ru", "phone": "+70247659961"}
0005432721599	37D45A	6302 868984	OLGA KUZNECOVA	{"phone": "+70882139307"}
0005432721600	036A1D	7657 637654	YULIYA ISAEVA	{"phone": "+70094416185"}
0005432721601	036A1D	8021 746062	EKATERINA KUZNECOVA	{"phone": "+70537913254"}
0005432721602	3E6C5C	8395 181772	NATALYA IVANOVA	{"email": "natalya_ivanova-1975@postgrespro.ru", "phone": "+70354303219"}
0005432721603	B0F288	2572 387176	KSENIYA ANDREEVA	{"email": "andreeva_k.1962@postgrespro.ru", "phone": "+70442467701"}
0005432721604	B0F288	5118 579181	VIKTORIYA ABRAMOVA	{"email": "v.abramova02061970@postgrespro.ru", "phone": "+70900466177"}
0005432721605	F44489	9328 349975	IRINA DENISOVA	{"phone": "+70569391647"}
0005432721606	CFB155	7158 016957	YURIY SOROKIN	{"email": "sorokin_y.061975@postgrespro.ru", "phone": "+70689544240"}
0005432721607	A5B92E	2939 051637	VIKTORIYA ALEKSEEVA	{"email": "viktoriya.alekseeva-121969@postgrespro.ru", "phone": "+70505281982"}
0005432721608	DEB0B8	4611 603697	ALSU TARASOVA	{"phone": "+70887241761"}
0005432721609	3CED9F	0508 302376	VALENTINA KOROLEVA	{"email": "vkoroleva_071969@postgrespro.ru", "phone": "+70898334417"}
0005432721610	E9833C	4375 330276	VALENTIN ANTONOV	{"phone": "+70954315549"}
0005432721611	C2A9C2	1879 204073	ANASTASIYA NIKOLAEVA	{"phone": "+70937257571"}
0005432721612	5AA9E4	2109 933985	MARIYA KULIKOVA	{"email": "mkulikova.30011983@postgrespro.ru", "phone": "+70362628980"}
0005432721613	91540E	6080 236889	MARIYA BARANOVA	{"email": "mbaranova.17111979@postgrespro.ru", "phone": "+70417995639"}
0005432721614	C570E3	4316 056693	MIKHAIL SOKOLOV	{"email": "sokolovm_1968@postgrespro.ru", "phone": "+70836517807"}
0005432721615	C570E3	3534 014106	VALENTINA POLYAKOVA	{"email": "vpolyakova_071976@postgrespro.ru", "phone": "+70283560544"}
0005432721616	824528	2200 805274	KRISTINA KOLESNIKOVA	{"email": "kolesnikovak.101977@postgrespro.ru", "phone": "+70085731019"}
0005432721617	3907BE	6231 119800	ALEKSEY ABRAMOV	{"email": "a-abramov_111978@postgrespro.ru", "phone": "+70769755805"}
0005432721618	870317	0468 693568	KSENIYA KOROLEVA	{"email": "kseniyakoroleva.1979@postgrespro.ru", "phone": "+70257829683"}
0005432721619	4E02DA	9394 563898	KSENIYA IVANOVA	{"phone": "+70740756641"}
0005432721620	A787AF	8145 203960	VITALIY FROLOV	{"phone": "+70846782144"}
0005432721621	A787AF	8110 555020	ALEKSEY ABRAMOV	{"email": "abramovaleksey.1966@postgrespro.ru", "phone": "+70260579927"}
0005432721622	846D46	3832 295345	LEV KAZAKOV	{"email": "l-kazakov_111969@postgrespro.ru", "phone": "+70599069898"}
0005432721623	846D46	1875 299692	OLGA FEDOROVA	{"phone": "+70206762397"}
0005432721624	B1E6B0	5310 486830	MARIYA MIRONOVA	{"email": "mmironova-101967@postgrespro.ru", "phone": "+70134562894"}
0005432721625	1EA548	5125 303097	SERGEY SHEVCHENKO	{"email": "sergeyshevchenko-19101968@postgrespro.ru", "phone": "+70154192974"}
0005432721626	5D7ACC	1795 236340	MARIYA FROLOVA	{"email": "m-frolova1967@postgrespro.ru", "phone": "+70707288597"}
0005432721627	B1AC53	2991 305823	ALEKSEY PETROV	{"phone": "+70798476528"}
0005432721628	A51747	9163 685215	EVGENIY KOZLOV	{"phone": "+70477991054"}
0005432721629	91574C	3012 425945	OLGA NOVIKOVA	{"email": "novikova.olga_07111985@postgrespro.ru", "phone": "+70340470278"}
0005432721630	91574C	7533 757244	SERGEY KRASNOV	{"phone": "+70094357723"}
0005432721631	023A92	3078 299326	MIKHAIL POPOV	{"phone": "+70170927184"}
0005432721633	D306A1	5823 588672	LEONID MOISEEV	{"phone": "+70350715221"}
0005432721634	9DBEAE	9988 984699	IGOR SOLOVEV	{"email": "solovevi.111968@postgrespro.ru", "phone": "+70749644184"}
0005432721635	B17C24	3775 095323	ANDREY GORBUNOV	{"email": "andrey_gorbunov_1978@postgrespro.ru", "phone": "+70041613312"}
0005432721636	EB2C96	6147 880203	IVAN STEPANOV	{"phone": "+70881751565"}
0005432721637	D02780	9140 459860	KONSTANTIN GORBUNOV	{"email": "k_gorbunov-26121975@postgrespro.ru", "phone": "+70701970797"}
0005432721638	178A44	6519 837105	LYUDMILA AFANASEVA	{"email": "afanaseva_l26071976@postgrespro.ru", "phone": "+70991574356"}
0005432721639	C28F43	8987 252942	OLGA BORISOVA	{"phone": "+70335556011"}
0005432721640	C28F43	5614 384236	KLAVDIYA TITOVA	{"phone": "+70054127846"}
0005432721641	C28F43	2554 562765	VERA FOMINA	{"email": "vera-fomina.21051974@postgrespro.ru", "phone": "+70960618806"}
0005432721642	3B023D	0604 670219	IRINA POPOVA	{"phone": "+70656938580"}
0005432721643	72685D	2534 510421	ELENA KUZNECOVA	{"email": "elena_kuznecova-101967@postgrespro.ru", "phone": "+70171275043"}
0005432721644	72685D	9252 594435	LARISA YAKOVLEVA	{"email": "yakovleva-l.13061967@postgrespro.ru", "phone": "+70514391120"}
0005432721645	63A264	3656 490298	ZOYA PAVLOVA	{"phone": "+70393540137"}
0005432721646	2BAB0C	6463 615722	ALEKSEY ANTONOV	{"email": "antonov-aleksey.13021970@postgrespro.ru", "phone": "+70098160720"}
0005432721647	BC1D71	2142 973118	ALLA BELOVA	{"phone": "+70702458988"}
0005432721648	B1FA8A	0067 335262	MIKHAIL MAKAROV	{"phone": "+70365664779"}
0005432721649	052D11	5876 361782	ALBINA YUDINA	{"phone": "+70431557495"}
0005432721650	51B411	9718 227763	SERGEY IVANOV	{"email": "sergey-ivanov.091965@postgrespro.ru", "phone": "+70880720590"}
0005432721651	EF05D3	7066 110997	IVAN FROLOV	{"phone": "+70065207897"}
0005432721652	EF05D3	3904 978341	SERGEY ZAYCEV	{"email": "s-zaycev_021957@postgrespro.ru", "phone": "+70974895710"}
0005432721653	53B35B	7471 348481	OLGA AFANASEVA	{"phone": "+70714582903"}
0005432721654	114840	1232 015060	GENNADIY POPOV	{"email": "popovgennadiy-25031964@postgrespro.ru", "phone": "+70335355881"}
0005432721655	CB65B7	2930 716613	SERGEY ZHUKOV	{"phone": "+70213756969"}
0005432721656	A63E72	8323 815130	MAKSIM KOZLOV	{"phone": "+70186313591"}
0005432721657	98363C	1570 656919	OLGA KOLESNIKOVA	{"email": "olgakolesnikova.1973@postgrespro.ru", "phone": "+70775288820"}
0005432721658	C8BD4F	4156 991225	EKATERINA IVANOVA	{"phone": "+70331058709"}
0005432721659	5C2F43	1352 340700	RUMIYA IVANOVA	{"phone": "+70957749935"}
0005432721660	08CEBA	6823 835909	NINA VOLKOVA	{"phone": "+70755848930"}
0005432721661	52C63D	6278 311186	ANDREY ZAYCEV	{"phone": "+70899021802"}
0005432721662	52C63D	4914 952261	TIMUR MEDVEDEV	{"phone": "+70301893200"}
0005432721663	9D5D96	7171 164887	ANATOLIY PETROV	{"phone": "+70520672119"}
0005432721664	F2EC6C	2801 870948	ALEKSANDRA IVANOVA	{"phone": "+70978993590"}
0005432721665	BD870D	6092 831066	ANDREY BORISOV	{"email": "andrey-borisov.1973@postgrespro.ru", "phone": "+70446990644"}
0005432721666	63A827	6234 327600	LIDIYA SAVELEVA	{"phone": "+70452179904"}
0005432721667	63A827	4363 590339	SVETLANA SCHERBAKOVA	{"email": "svetlanascherbakova21111968@postgrespro.ru", "phone": "+70753385965"}
0005432721668	2616EB	8510 867603	ELIZAVETA BELOVA	{"phone": "+70526487094"}
0005432721669	2ADCFD	4462 958207	ALEKSEY KUZMIN	{"email": "kuzmin-aleksey.021971@postgrespro.ru", "phone": "+70619535718"}
0005432721670	530EF3	8761 679853	STEPAN MOROZOV	{"email": "s_morozov.051983@postgrespro.ru", "phone": "+70142062454"}
0005432721671	7D470E	7144 022222	ALEKSANDR SEMENOV	{"phone": "+70576074273"}
0005432721672	F4D385	0725 568531	MARIYA KOVALEVA	{"email": "m-kovaleva1974@postgrespro.ru", "phone": "+70908052853"}
0005432721673	F4D385	8734 410316	ANATOLIY PAVLOV	{"email": "anatoliy.pavlov_1968@postgrespro.ru", "phone": "+70524857172"}
0005432721674	F4D385	8566 271842	VERONIKA RYABOVA	{"phone": "+70199853855"}
0005432721675	121A4E	8863 592359	NATALYA BORISOVA	{"email": "n.borisova_111964@postgrespro.ru", "phone": "+70665842119"}
0005432721676	5F39CD	7464 057677	EVGENIY BORISOV	{"email": "borisov_evgeniy.1977@postgrespro.ru", "phone": "+70005915229"}
0005432721677	0A3226	8135 983276	OLGA DANILOVA	{"phone": "+70007061805"}
0005432721678	E0668E	4106 730676	YURIY TARASOV	{"email": "tarasovy1971@postgrespro.ru", "phone": "+70179777793"}
0005432721679	B58F99	3977 759784	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev111977@postgrespro.ru", "phone": "+70340604607"}
0005432721680	6014FD	8050 995666	TATYANA EGOROVA	{"phone": "+70581397822"}
0005432721681	696B03	4548 111130	ANATOLIY POPOV	{"phone": "+70402848179"}
0005432721682	696B03	9746 758911	SVETLANA LEBEDEVA	{"email": "lebedeva_s1978@postgrespro.ru", "phone": "+70173137061"}
0005432721683	EC11B0	5701 328243	VLADIMIR SOKOLOV	{"email": "vsokolov06051955@postgrespro.ru", "phone": "+70720508375"}
0005432721684	7AEC61	2289 481145	ALEKSANDRA POPOVA	{"email": "popova.a.011972@postgrespro.ru", "phone": "+70504324982"}
0005432721685	B0B38D	0075 076339	EVGENIY ABRAMOV	{"phone": "+70152799170"}
0005432721686	A0C969	8594 416219	ELENA STEPANOVA	{"email": "stepanova_elena-02101974@postgrespro.ru", "phone": "+70444031142"}
0005432721687	A0C969	7205 388693	NINA BOGDANOVA	{"phone": "+70111377270"}
0005432721688	81338C	4594 275291	IRINA BELOVA	{"phone": "+70608758411"}
0005432721689	81338C	3830 764138	YURIY KUZNECOV	{"phone": "+70231887528"}
0005432721690	B4CAB1	5674 409945	VIKTOR MATVEEV	{"phone": "+70112244725"}
0005432721691	D3B067	2180 633350	ELENA KUZNECOVA	{"phone": "+70313438025"}
0005432727754	AEB3CE	7097 994043	SERGEY BORISOV	{"phone": "+70486433939"}
0005432727716	202A4F	7713 691244	IRINA SIDOROVA	{"phone": "+70413412457"}
0005432727717	1CEA6D	7731 300271	MARIYA BELYAEVA	{"phone": "+70868124848"}
0005432727718	DF91EF	1716 631575	MARGARITA KUZNECOVA	{"phone": "+70252778419"}
0005432727719	AB0372	1134 343939	VLADISLAV KUZNECOV	{"email": "vladislav-kuznecov.041978@postgrespro.ru", "phone": "+70401156388"}
0005432727720	2C9DEF	5884 729701	IREK CHERNOV	{"email": "chernov_irek.21011969@postgrespro.ru", "phone": "+70790293135"}
0005432727721	5CD840	6197 179918	DANIL GUSEV	{"phone": "+70031630713"}
0005432727722	5CD840	1880 682837	ALEKSANDR IVANOV	{"phone": "+70061290558"}
0005432727723	8FEC44	1039 366919	DARYA BARANOVA	{"phone": "+70451229695"}
0005432727724	CF0549	6764 049718	VALENTINA YAKOVLEVA	{"email": "yakovlevavalentina_031996@postgrespro.ru", "phone": "+70427860602"}
0005432727725	81F0A5	2926 706615	IRINA AFANASEVA	{"email": "afanaseva.irina1963@postgrespro.ru", "phone": "+70581435473"}
0005432727726	2B439F	2833 138240	DMITRIY KULIKOV	{"email": "kulikov-dmitriy1982@postgrespro.ru", "phone": "+70625967172"}
0005432727727	2B439F	8407 587776	MARIYA KUDRYASHOVA	{"email": "kudryashova_m-05011973@postgrespro.ru", "phone": "+70348887776"}
0005432727728	221218	3062 842886	GALINA KOLESNIKOVA	{"email": "g_kolesnikova.071966@postgrespro.ru", "phone": "+70749051032"}
0005432727729	221218	0760 720513	LIDIYA MIRONOVA	{"phone": "+70171564605"}
0005432727730	719EA5	1747 227468	VIKTOR YAKOVLEV	{"phone": "+70326719809"}
0005432727731	719EA5	2380 930176	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v_10121982@postgrespro.ru", "phone": "+70784492553"}
0005432727788	F80299	2708 458748	VALENTINA VOROBEVA	{"phone": "+70308908256"}
0005432727732	2AE0A0	1587 947204	ELEONORA SERGEEVA	{"email": "eleonora_sergeeva_1967@postgrespro.ru", "phone": "+70527182260"}
0005432727733	2AE0A0	9463 582573	GALINA TITOVA	{"phone": "+70848592947"}
0005432727734	5EA09C	1304 474518	OLGA POTAPOVA	{"email": "o-potapova_041974@postgrespro.ru", "phone": "+70811066962"}
0005432727735	5EA09C	7946 312254	OLGA MELNIKOVA	{"phone": "+70914012956"}
0005432727736	5EA09C	2380 088176	LARISA KAZAKOVA	{"email": "kazakova-larisa.1970@postgrespro.ru", "phone": "+70983450714"}
0005432727737	C4DF1E	9944 226103	VALERIY BARANOV	{"phone": "+70829315404"}
0005432727738	B35BC3	4253 416364	YURIY VLASOV	{"phone": "+70292135339"}
0005432727739	09C43F	2021 590594	GRIGORIY CHERNOV	{"email": "grigoriy.chernov.23021964@postgrespro.ru", "phone": "+70267942536"}
0005432727740	06965F	7811 369913	SANIYA BELOVA	{"phone": "+70833337899"}
0005432727741	67376C	5189 056508	EKATERINA SCHERBAKOVA	{"email": "ekaterina.scherbakova.1964@postgrespro.ru", "phone": "+70269644540"}
0005432727742	21637C	7617 398097	VIKTORIYA IVANOVA	{"phone": "+70025400556"}
0005432727743	21637C	6213 073329	RUZALIYA LUKYANOVA	{"email": "r_lukyanova_081963@postgrespro.ru", "phone": "+70821907479"}
0005432727744	127EB3	0019 899798	SERGEY NOVIKOV	{"phone": "+70700317181"}
0005432727745	D25615	3001 618457	YULIYA DAVYDOVA	{"phone": "+70425313069"}
0005432727746	1DF0A7	2870 903131	ALEKSANDR ROMANOV	{"phone": "+70496677613"}
0005432727747	1DF0A7	4414 815625	VLADISLAV BELOV	{"phone": "+70884093321"}
0005432727748	182830	0614 087776	MARIYA NAZAROVA	{"email": "m-nazarova-13111975@postgrespro.ru", "phone": "+70780308918"}
0005432727749	182830	8034 366156	MARIYA SAVELEVA	{"phone": "+70377284786"}
0005432727750	89AC03	2111 804607	SVETLANA MALYSHEVA	{"email": "s_malysheva.061971@postgrespro.ru", "phone": "+70498895246"}
0005432727751	ADCA07	4125 663300	ELENA IVANOVA	{"phone": "+70561955393"}
0005432727752	DE0694	6615 721852	ANDREY OSIPOV	{"phone": "+70418248522"}
0005432727753	AEB3CE	6151 434543	TATYANA KONDRATEVA	{"email": "tatyana_kondrateva-121970@postgrespro.ru", "phone": "+70916833586"}
0005432727755	E5A82D	3469 977629	NATALYA KOVALEVA	{"email": "n-kovaleva_1966@postgrespro.ru", "phone": "+70555100715"}
0005432727756	2A6278	7215 128647	EGOR VOLKOV	{"email": "egor_volkov-1968@postgrespro.ru", "phone": "+70435961849"}
0005432727757	2481E3	5061 486165	LYUBOV IVANOVA	{"phone": "+70139199097"}
0005432727758	2481E3	8396 838342	VALENTIN VOLKOV	{"email": "vvolkov.031964@postgrespro.ru", "phone": "+70120398399"}
0005432727759	BBC700	7308 262112	NATALYA KISELEVA	{"email": "n_kiseleva-101973@postgrespro.ru", "phone": "+70268246408"}
0005432727760	2985DB	4835 375544	KONSTANTIN NAZAROV	{"email": "nazarovk11091978@postgrespro.ru", "phone": "+70532690067"}
0005432727761	467DCD	1941 368226	KIRILL KUZNECOV	{"email": "k.kuznecov_1971@postgrespro.ru", "phone": "+70408696575"}
0005432727762	467DCD	8410 960121	IRINA VLASOVA	{"email": "vlasovairina_031976@postgrespro.ru", "phone": "+70233153917"}
0005432727763	1DF4B7	7773 326194	ALEKSEY IVANOV	{"email": "ivanov_aleksey22021970@postgrespro.ru", "phone": "+70256869429"}
0005432727764	D1748A	6778 033184	MAKSIM MIRONOV	{"email": "mironovmaksim.1977@postgrespro.ru", "phone": "+70195834560"}
0005432727765	D52A89	1502 154052	ELENA DMITRIEVA	{"phone": "+70371339391"}
0005432727766	D52A89	9436 672286	ANASTASIYA KARPOVA	{"email": "karpovaa1979@postgrespro.ru", "phone": "+70763419065"}
0005432727767	5D75E0	5410 781575	STANISLAV EGOROV	{"phone": "+70362318283"}
0005432727768	9B1E08	0921 597409	SVETLANA NIKITINA	{"email": "svetlananikitina.1984@postgrespro.ru", "phone": "+70368919074"}
0005432727769	2E5D36	3163 227112	LEONID AFANASEV	{"email": "afanasevl27121972@postgrespro.ru", "phone": "+70426294347"}
0005432727770	EDF79D	4931 700031	ARTEM NIKITIN	{"phone": "+70606137002"}
0005432727771	856573	6651 430041	YURIY KONOVALOV	{"email": "konovalov.yuriy-081973@postgrespro.ru", "phone": "+70596749731"}
0005432727772	856573	3091 549844	ANTON OSIPOV	{"phone": "+70620982497"}
0005432727773	856573	9918 920803	ANATOLIY MAKAROV	{"email": "makarovanatoliy15121972@postgrespro.ru", "phone": "+70165541921"}
0005432727774	F698BC	4277 177192	ELENA ALEKSANDROVA	{"phone": "+70767369338"}
0005432727775	F698BC	8001 924966	SERGEY DMITRIEV	{"phone": "+70068273778"}
0005432727776	892F22	1917 448650	TAISIYA VOROBEVA	{"email": "t.vorobeva_1979@postgrespro.ru", "phone": "+70578957370"}
0005432727777	B9330F	5359 076699	ANNA MOROZOVA	{"email": "anna.morozova_1969@postgrespro.ru", "phone": "+70153622769"}
0005432727778	B9330F	4027 056264	YANA KUZNECOVA	{"email": "kuznecova_yana-1969@postgrespro.ru", "phone": "+70142905747"}
0005432727779	205AE2	8156 195773	MIKHAIL NAZAROV	{"phone": "+70655958466"}
0005432727780	1B7231	7439 081261	MIKHAIL MIRONOV	{"phone": "+70821611355"}
0005432727781	360CF4	0169 104179	BORIS GORBUNOV	{"phone": "+70912150737"}
0005432727782	360CF4	5037 655795	ANNA PETROVA	{"email": "petrova-a121968@postgrespro.ru", "phone": "+70841854421"}
0005432727783	54A6CB	9818 250570	MARIYA SMIRNOVA	{"phone": "+70692748057"}
0005432727784	3D3D55	7381 446016	PAVEL GUSEV	{"phone": "+70058854397"}
0005432727785	6F7B1A	7717 445006	PETR KUZNECOV	{"email": "kuznecov.p.18061968@postgrespro.ru", "phone": "+70973260413"}
0005432727786	6F7B1A	1258 885773	EKATERINA ZAKHAROVA	{"email": "zakharova.e-1982@postgrespro.ru", "phone": "+70610957165"}
0005432727787	6F7B1A	6514 719362	VLADIMIR NIKITIN	{"email": "nikitin_vladimir071974@postgrespro.ru", "phone": "+70449141777"}
0005432727789	43EFB9	3303 376662	OLEG ROMANOV	{"phone": "+70773398053"}
0005432727790	43EFB9	5025 777794	ALEKSANDR ISAEV	{"email": "isaev-a1965@postgrespro.ru", "phone": "+70073466861"}
0005432727791	643026	9916 754950	SERGEY ZAKHAROV	{"email": "szakharov_19081970@postgrespro.ru", "phone": "+70801519661"}
0005432727792	76FC93	4966 608172	RUSLAN MEDVEDEV	{"phone": "+70101917549"}
0005432727793	1C5CF4	8020 706017	YURIY IVANOV	{"phone": "+70553048002"}
0005432727794	1C5CF4	6526 930150	LEONID SOLOVEV	{"email": "leonid_solovev04031975@postgrespro.ru", "phone": "+70779952785"}
0005432727795	7C256E	4244 857465	ALINA VASILEVA	{"phone": "+70551257383"}
0005432727796	7C256E	0205 735836	LYUDMILA KISELEVA	{"email": "kiseleva-l.091971@postgrespro.ru", "phone": "+70805679830"}
0005432727797	A5BB39	7011 749970	ALEKSEY SERGEEV	{"phone": "+70877834588"}
0005432727798	3651C9	6366 374057	VALENTINA GERASIMOVA	{"phone": "+70342396326"}
0005432727799	3E72AE	5670 124121	SERGEY PAVLOV	{"email": "pavlov_s.1975@postgrespro.ru", "phone": "+70734142593"}
0005432727800	3D3E45	1020 968620	NADEZHDA SAVELEVA	{"email": "saveleva_nadezhda_081973@postgrespro.ru", "phone": "+70666158303"}
0005432727801	B468CC	8277 017236	IVAN ANTONOV	{"phone": "+70451642181"}
0005432727802	B468CC	6066 376591	VALENTINA FADEEVA	{"email": "v.fadeeva_1979@postgrespro.ru", "phone": "+70888104522"}
0005432727803	351D57	3272 326216	BORIS SOROKIN	{"email": "boris_sorokin_04011974@postgrespro.ru", "phone": "+70302633347"}
0005432727804	8B9AEA	3649 296241	TATYANA YAKOVLEVA	{"phone": "+70240039570"}
0005432727805	D1D931	0915 831378	OLGA IVANOVA	{"email": "ivanova_o-10041965@postgrespro.ru", "phone": "+70337097693"}
0005432727806	EED720	1443 161056	IRINA PETROVA	{"phone": "+70151810578"}
0005432727807	63F8D6	6518 041379	KIRILL EGOROV	{"phone": "+70043802544"}
0005432727808	9AE0CC	3944 609708	VALERIY SOKOLOV	{"phone": "+70707253740"}
0005432727809	9AE0CC	7705 686331	OLGA ABRAMOVA	{"phone": "+70513822952"}
0005432727810	6EC937	5408 881214	RAISA IVANOVA	{"email": "ivanova-r.1976@postgrespro.ru", "phone": "+70503283819"}
0005432727811	AE6666	3347 067371	ANATOLIY SOROKIN	{"email": "sorokin_a-23031965@postgrespro.ru", "phone": "+70737572251"}
0005432727812	7058B0	5000 566659	MARIYA BOGDANOVA	{"email": "bogdanova_m031972@postgrespro.ru", "phone": "+70020831865"}
0005432727813	6773B7	9017 338913	ANATOLIY SHEVCHENKO	{"phone": "+70001303830"}
0005432727814	6773B7	8544 807061	KLAVDIYA VASILEVA	{"email": "vasilevaklavdiya.011976@postgrespro.ru", "phone": "+70775706310"}
0005432727815	313CCF	0058 252813	OLGA ALEKSEEVA	{"phone": "+70103770829"}
0005432727816	84424A	4534 654333	OLEG ILIN	{"phone": "+70773696218"}
0005432727817	84424A	6138 903532	VLADIMIR ANTONOV	{"phone": "+70061877348"}
0005432727818	DA706B	6341 026639	TATYANA VOROBEVA	{"email": "vorobeva_tatyana101968@postgrespro.ru", "phone": "+70640040773"}
0005432727819	A411F8	7693 220913	TATYANA SOROKINA	{"phone": "+70689475286"}
0005432727820	7F5B2B	4585 588723	VLADIMIR FOMIN	{"phone": "+70321819189"}
0005432727821	BCEFFA	0075 798742	NINA ALEKSANDROVA	{"email": "n_aleksandrova_09081956@postgrespro.ru", "phone": "+70322628531"}
0005432727822	F3407E	8965 241498	VYACHESLAV FEDOROV	{"email": "v.fedorov_041970@postgrespro.ru", "phone": "+70314900494"}
0005432727823	DBFD87	1175 653106	OLGA PAVLOVA	{"phone": "+70641574273"}
0005432727824	F91C54	2848 815716	MIKHAIL PETROV	{"phone": "+70239791302"}
0005432727825	F91C54	9370 531576	VLADIMIR DAVYDOV	{"phone": "+70068779762"}
0005432727826	5E4C4F	1705 771426	YURIY NAUMOV	{"phone": "+70651179878"}
0005432727827	5E4C4F	6867 130648	ALEKSEY MOROZOV	{"phone": "+70849589019"}
0005432727828	2E31C6	3083 524874	ALEKSEY AFANASEV	{"email": "afanasev_aleksey30091979@postgrespro.ru", "phone": "+70341225694"}
0005432727829	54261C	0080 600959	ANDREY ILIN	{"email": "ilin_andrey.041975@postgrespro.ru", "phone": "+70475195227"}
0005432727830	54261C	7958 951947	PAVEL MARTYNOV	{"email": "martynov-pavel_1978@postgrespro.ru", "phone": "+70412052681"}
0005432727831	50C785	0602 869909	RIMMA FILIPPOVA	{"phone": "+70570710820"}
0005432727832	45842A	2651 217329	KONSTANTIN NOVIKOV	{"email": "novikov_konstantin_26031976@postgrespro.ru", "phone": "+70323091134"}
0005432727833	EF1BAC	1240 795565	SVETLANA KUDRYASHOVA	{"phone": "+70734485536"}
0005432727834	2D6AEA	3136 418921	NIKOLAY VOROBEV	{"email": "nikolayvorobev-14061971@postgrespro.ru", "phone": "+70633346886"}
0005432727835	7F1B6C	2640 422735	ROMAN SOKOLOV	{"phone": "+70177612796"}
0005432727836	D446ED	3289 010911	VIKTOR KUZNECOV	{"email": "kuznecovviktor04031982@postgrespro.ru", "phone": "+70421063510"}
0005432727837	D446ED	6877 068030	YULIYA POPOVA	{"phone": "+70805514077"}
0005432727838	044BCA	5116 846393	STANISLAV SOROKIN	{"email": "sorokin_s1961@postgrespro.ru", "phone": "+70094227791"}
0005432727839	F20EBD	2158 708463	ROMAN ZAYCEV	{"phone": "+70647351345"}
0005432727840	F20EBD	2623 362080	MIKHAIL ISAEV	{"phone": "+70939449793"}
0005432727841	14EFA3	8646 871816	ALBERT GRIGOREV	{"email": "grigorevalbert_24091961@postgrespro.ru", "phone": "+70835379719"}
0005432727842	6905B1	7514 156794	VLADIMIR ROMANOV	{"phone": "+70311129762"}
0005432727843	D57033	8132 573194	ROMAN BELOV	{"phone": "+70952883755"}
0005432727844	A4D5D4	9652 258988	ALEKSANDR GUSEV	{"email": "gusev_aleksandr061972@postgrespro.ru", "phone": "+70263002187"}
0005432727845	A4D5D4	9983 698032	ALEKSEY POPOV	{"email": "aleksey.popov-1980@postgrespro.ru", "phone": "+70196389885"}
0005432727846	4F4ED4	5248 887567	VYACHESLAV AFANASEV	{"email": "afanasev-vyacheslav1981@postgrespro.ru", "phone": "+70925627192"}
0005432727847	4F4ED4	6643 596198	NATALYA IVANOVA	{"email": "n.ivanova021964@postgrespro.ru", "phone": "+70778000003"}
0005432727848	0BC64C	0014 823657	EVDOKIYA POTAPOVA	{"email": "potapova_e_1977@postgrespro.ru", "phone": "+70005906916"}
0005432727849	C3F357	3760 962842	GALINA CHERNOVA	{"phone": "+70294222708"}
0005432727850	362A38	0269 299052	ANTON ZAKHAROV	{"phone": "+70850001436"}
0005432727851	D3DD00	7386 116046	VERA PAVLOVA	{"email": "vera_pavlova041978@postgrespro.ru", "phone": "+70553885627"}
0005432727852	D3DD00	2566 828916	ALEKSANDR ORLOV	{"email": "orlovaleksandr.29061974@postgrespro.ru", "phone": "+70997016509"}
0005432727853	8F966B	6673 741423	TAMARA MEDVEDEVA	{"phone": "+70008406293"}
0005432727854	06E897	8086 860855	ZOYA SAVELEVA	{"phone": "+70150628076"}
0005432727855	41990B	7425 535986	VYACHESLAV ANTONOV	{"email": "antonov_vyacheslav-081965@postgrespro.ru", "phone": "+70531664728"}
0005432727856	0DAE9F	3314 017418	ANASTASIYA ZHURAVLEVA	{"email": "anastasiya_zhuravleva_09061974@postgrespro.ru", "phone": "+70678163117"}
0005432727857	BB2B4D	6539 057808	VALERIY SOKOLOV	{"email": "vsokolov1971@postgrespro.ru", "phone": "+70319054607"}
0005432727858	BDD39D	2787 010314	ANTONINA DMITRIEVA	{"phone": "+70678878156"}
0005432727859	6AA26E	0231 359332	GEORGIY VASILEV	{"email": "georgiy_vasilev-1964@postgrespro.ru", "phone": "+70467580303"}
0005432727860	6AA26E	7935 741522	ANDREY NIKOLAEV	{"email": "nikolaev-a-091975@postgrespro.ru", "phone": "+70293824123"}
0005432727861	E4C138	6142 699966	EGOR VASILEV	{"email": "vasilev.egor_051963@postgrespro.ru", "phone": "+70675845900"}
0005432727862	E4C138	8974 806176	VASILIY KOROLEV	{"phone": "+70200576281"}
0005432727863	83EAE3	8005 485789	VLADIMIR SMIRNOV	{"phone": "+70625838859"}
0005432727864	83EAE3	6070 546306	OLEG VASILEV	{"phone": "+70179475913"}
0005432727865	83EAE3	3895 215081	IRINA ABRAMOVA	{"email": "i-abramova_02101978@postgrespro.ru", "phone": "+70318837876"}
0005432727866	A1B974	7668 086912	MIKHAIL BORISOV	{"phone": "+70128457991"}
0005432727867	A1B974	8722 582684	VIKTORIYA SEMENOVA	{"email": "v.semenova-031976@postgrespro.ru", "phone": "+70420591665"}
0005432727868	8E2113	0293 795372	PAVEL VASILEV	{"email": "pavel.vasilev-1966@postgrespro.ru", "phone": "+70929473457"}
0005432727869	14D931	3402 943407	LYUDMILA MEDVEDEVA	{"phone": "+70079721071"}
0005432727870	281638	0382 218843	SVETLANA MOROZOVA	{"phone": "+70579972521"}
0005432727871	8B91F4	8657 893643	ELENA KUZNECOVA	{"phone": "+70636120326"}
0005432727872	43E29B	1553 400324	IVAN KISELEV	{"email": "ivan-kiselev_061977@postgrespro.ru", "phone": "+70847648903"}
0005432727873	879783	8850 737661	SERGEY IVANOV	{"email": "ivanov-s031985@postgrespro.ru", "phone": "+70790422158"}
0005432727874	879783	9051 985734	VLADIMIR SHEVCHENKO	{"phone": "+70836169618"}
0005432727875	DBA1B6	6084 384752	VERA SEMENOVA	{"phone": "+70419434010"}
0005432727876	F2058E	3390 555519	MARINA ANDREEVA	{"phone": "+70079083697"}
0005432727877	0F6F97	8435 278734	RAISA ANISIMOVA	{"email": "raisa_anisimova-1981@postgrespro.ru", "phone": "+70992120515"}
0005432727878	0F6F97	6162 413752	IRINA BELOVA	{"phone": "+70504488653"}
0005432727879	4D1B38	9926 137556	OLEG EGOROV	{"email": "egorov.oleg.101967@postgrespro.ru", "phone": "+70033500059"}
0005432727880	4D1B38	0634 705234	DARYA IVANOVA	{"phone": "+70536700618"}
0005432727881	CF8110	8444 431309	GENNADIY FEDOROV	{"email": "fedorov_g-1980@postgrespro.ru", "phone": "+70583898372"}
0005432727882	CF8110	8022 694640	GLEB ZHURAVLEV	{"phone": "+70682748926"}
0005432727883	87580D	1430 355774	OLGA POPOVA	{"email": "o-popova1976@postgrespro.ru", "phone": "+70554672146"}
0005432727884	87580D	7293 038405	ALEKSANDR PETROV	{"email": "a-petrov.051969@postgrespro.ru", "phone": "+70453218002"}
0005432727885	08F35D	7956 719832	VALERIY ILIN	{"phone": "+70579316361"}
0005432727886	5BF699	3534 452428	LYUDMILA ANISIMOVA	{"email": "anisimoval051966@postgrespro.ru", "phone": "+70603666507"}
0005432727887	D054E4	9548 726067	ANDREY SOKOLOV	{"phone": "+70087657221"}
0005432727888	D054E4	5099 593460	VERONIKA KONDRATEVA	{"phone": "+70365598132"}
0005432727889	D054E4	5570 329989	TATYANA SERGEEVA	{"phone": "+70742053066"}
0005432727890	6C7CD8	6383 454932	ZINAIDA VASILEVA	{"email": "vasileva.zinaida-18011978@postgrespro.ru", "phone": "+70502449472"}
0005432727891	AA29F4	3780 664868	VIKTOR ANTONOV	{"phone": "+70019751793"}
0005432727892	4EBA72	8841 203962	VALENTINA FROLOVA	{"email": "valentina_frolova-13031969@postgrespro.ru", "phone": "+70337691073"}
0005432727893	EA11EB	4771 504526	TAMARA STEPANOVA	{"phone": "+70696563256"}
0005432727894	EA11EB	6149 123367	OLGA PAVLOVA	{"phone": "+70408952211"}
0005432727895	200D55	2366 896027	IRINA KUDRYASHOVA	{"phone": "+70273774056"}
0005432727896	C2D891	5733 924541	TAMARA MALYSHEVA	{"phone": "+70777583984"}
0005432727897	2D0E50	7887 390882	VASILIY PETROV	{"email": "v_petrov101975@postgrespro.ru", "phone": "+70776721191"}
0005432727898	2D0E50	0681 057523	NIKOLAY KOZLOV	{"email": "nikolay_kozlov_101972@postgrespro.ru", "phone": "+70987644697"}
0005432727899	0239DA	5664 457041	ANATOLIY MATVEEV	{"phone": "+70661954639"}
0005432727900	0239DA	3758 989510	VLADIMIR GERASIMOV	{"email": "vladimir.gerasimov_09091968@postgrespro.ru", "phone": "+70375749860"}
0005432727901	85B18D	9346 375889	ALEKSANDR ALEKSEEV	{"phone": "+70385025087"}
0005432727958	A1DDF8	9662 783466	EVDOKIYA KOROLEVA	{"phone": "+70296594743"}
0005432727902	85B18D	3467 362340	VALENTINA IVANOVA	{"email": "valentina_ivanova_061963@postgrespro.ru", "phone": "+70789541082"}
0005432727903	CEF18F	4033 583832	NATALYA TITOVA	{"phone": "+70083161175"}
0005432727904	E84B52	9132 055505	NATALYA SOKOLOVA	{"phone": "+70033111866"}
0005432727905	C9981F	5659 232940	VLADIMIR VASILEV	{"phone": "+70883551888"}
0005432727906	18D672	4324 605534	NIKOLAY STEPANOV	{"phone": "+70119138774"}
0005432727907	D6A3BC	0016 210820	LYUDMILA POLYAKOVA	{"email": "polyakova.l19041976@postgrespro.ru", "phone": "+70366260600"}
0005432727908	897F59	1670 534910	ANATOLIY POPOV	{"email": "popov-anatoliy_1969@postgrespro.ru", "phone": "+70007509822"}
0005432727909	897F59	6883 574556	ELENA ARKHIPOVA	{"email": "elena_arkhipova.13041971@postgrespro.ru", "phone": "+70572832275"}
0005432727910	EBA6D1	3228 378281	IRINA CHERNOVA	{"phone": "+70216792498"}
0005432727911	F610AA	9532 570633	MARAT NAZAROV	{"phone": "+70116676981"}
0005432727912	F610AA	5261 270309	ALEKSEY VOLKOV	{"phone": "+70360381003"}
0005432727913	4149AC	7364 430551	IVAN SCHERBAKOV	{"email": "scherbakovi1968@postgrespro.ru", "phone": "+70106410743"}
0005432727914	4149AC	3419 358652	EKATERINA FEDOROVA	{"email": "e.fedorova-25081981@postgrespro.ru", "phone": "+70643492298"}
0005432727915	4C2A2B	8219 110943	ANASTASIYA GUSEVA	{"phone": "+70091575734"}
0005432727916	F7D232	6049 258634	SERGEY BONDARENKO	{"email": "sergey_bondarenko_03121978@postgrespro.ru", "phone": "+70623437893"}
0005432727917	87C128	7905 586182	ZARINA BORISOVA	{"email": "zarina_borisova-1970@postgrespro.ru", "phone": "+70424037186"}
0005432727918	87C128	1077 789417	LYUDMILA ZAKHAROVA	{"phone": "+70801639519"}
0005432727919	D1BF07	6087 432706	ALEKSEY KAZAKOV	{"email": "kazakov-aleksey.15061967@postgrespro.ru", "phone": "+70424173669"}
0005432727920	D1BF07	4587 217617	TAMARA ZHURAVLEVA	{"phone": "+70757113323"}
0005432727921	D1BF07	9445 334231	ANASTASIYA NIKOLAEVA	{"email": "a.nikolaeva_1978@postgrespro.ru", "phone": "+70551239065"}
0005432727922	024963	3195 642833	EKATERINA GAVRILOVA	{"email": "ekaterina_gavrilova041980@postgrespro.ru", "phone": "+70505521976"}
0005432727980	68B766	9651 486969	ANATOLIY NAZAROV	{"phone": "+70548458850"}
0005432727923	AC622E	8560 396061	ARTEM ANDREEV	{"email": "andreev_a.19041966@postgrespro.ru", "phone": "+70457948120"}
0005432727924	AC622E	6040 475090	KIRILL SCHERBAKOV	{"phone": "+70156352505"}
0005432727925	5B74F6	3500 933592	ALEKSANDR TIMOFEEV	{"email": "timofeev_a-14111968@postgrespro.ru", "phone": "+70297764083"}
0005432727926	5B74F6	0461 116484	STANISLAV POPOV	{"email": "popov.s_111967@postgrespro.ru", "phone": "+70069323214"}
0005432727927	1C0E14	8645 914470	GALINA POPOVA	{"email": "g.popova_041971@postgrespro.ru", "phone": "+70899715430"}
0005432727928	4FF5DC	1414 006737	LYUDMILA FILIPPOVA	{"email": "lyudmila_filippova.1968@postgrespro.ru", "phone": "+70286295592"}
0005432727929	4FF5DC	4191 813601	DANILA YAKOVLEV	{"phone": "+70788151937"}
0005432727930	1CA65C	4776 861747	EGOR KUZNECOV	{"phone": "+70402930867"}
0005432727931	04289A	8418 020750	VYACHESLAV RODIONOV	{"phone": "+70740800152"}
0005432727932	0AB2DA	0956 701391	GLEB GUSEV	{"email": "gusevg01011984@postgrespro.ru", "phone": "+70288263895"}
0005432727933	18757B	8361 301446	YULIYA EGOROVA	{"phone": "+70714872134"}
0005432727934	09A4AE	6355 187491	MARINA DENISOVA	{"email": "denisovam_03011976@postgrespro.ru", "phone": "+70481625966"}
0005432727935	D0F7A7	4270 902958	RUSTAM MIKHAYLOV	{"email": "rustam.mikhaylov_1962@postgrespro.ru", "phone": "+70605386909"}
0005432727936	D0F7A7	9408 448947	VALENTINA VOLKOVA	{"email": "v-volkova.1968@postgrespro.ru", "phone": "+70812311332"}
0005432727937	E15169	7741 228648	TATYANA ZHURAVLEVA	{"email": "zhuravleva_tatyana-041971@postgrespro.ru", "phone": "+70805634826"}
0005432727938	E15169	8095 906437	SVETLANA ZAYCEVA	{"email": "svetlana_zayceva-1981@postgrespro.ru", "phone": "+70965157047"}
0005432727939	E15169	3245 621606	ANDREY ORLOV	{"phone": "+70153557655"}
0005432727940	34F65D	1673 159297	NIKOLAY MELNIKOV	{"email": "n.melnikov-10031978@postgrespro.ru", "phone": "+70588533277"}
0005432727941	5F35EE	6564 972194	EVGENIY MIRONOV	{"phone": "+70388837977"}
0005432727942	5D5575	7851 024264	FEDOR NIKOLAEV	{"email": "fedornikolaev-011977@postgrespro.ru", "phone": "+70279974891"}
0005432727943	AE7495	0267 681014	SEMEN NIKOLAEV	{"phone": "+70934363039"}
0005432727944	B16798	1610 144335	ILDAR TIMOFEEV	{"email": "itimofeev.051970@postgrespro.ru", "phone": "+70327975972"}
0005432727945	CD73B1	4489 211885	NATALYA VOROBEVA	{"phone": "+70465482468"}
0005432727946	019C59	6727 254722	OLGA NOVIKOVA	{"phone": "+70227167666"}
0005432727947	ABD829	0210 050485	LYUBOV AFANASEVA	{"phone": "+70602168852"}
0005432727948	ABD829	5266 243715	YURIY STEPANOV	{"email": "y-stepanov-1966@postgrespro.ru", "phone": "+70009426147"}
0005432727949	CBAE5B	3071 083276	ANDREY FILIPPOV	{"email": "andrey-filippov1965@postgrespro.ru", "phone": "+70983283095"}
0005432727950	CBAE5B	5498 831132	EKATERINA NIKITINA	{"phone": "+70508790618"}
0005432727951	85D5D7	0431 062599	NINA DMITRIEVA	{"phone": "+70723824811"}
0005432727952	85D5D7	4363 910602	EKATERINA EFREMOVA	{"phone": "+70448295043"}
0005432727953	85D5D7	6557 150092	LYUDMILA EGOROVA	{"phone": "+70160999166"}
0005432727954	059D5E	2518 472037	VLADIMIR FOMIN	{"email": "v-fomin_13011964@postgrespro.ru", "phone": "+70108119877"}
0005432727955	059D5E	4857 419139	LIDIYA KUZNECOVA	{"phone": "+70596027270"}
0005432727956	380ED5	6067 920167	VLADIMIR SHEVCHENKO	{"phone": "+70190811559"}
0005432727957	D5B9B5	4195 533082	RAMIL SOROKIN	{"phone": "+70846695128"}
0005432727959	40BA04	2297 899801	IRINA NAUMOVA	{"email": "naumova_irina-11121975@postgrespro.ru", "phone": "+70298542119"}
0005432727960	38F013	5726 534060	SVETLANA TARASOVA	{"email": "svetlana.tarasova_1967@postgrespro.ru", "phone": "+70170727990"}
0005432727961	38F013	6570 525193	NIKOLAY SEMENOV	{"phone": "+70759013692"}
0005432727962	D24A91	2207 856656	IGOR SOROKIN	{"email": "sorokin_i_1976@postgrespro.ru", "phone": "+70344303648"}
0005432727963	83A56A	0127 193573	SERGEY TIKHONOV	{"email": "tikhonov.s-1972@postgrespro.ru", "phone": "+70437696837"}
0005432727964	39C6A4	3586 030786	RAVZA POPOVA	{"phone": "+70813497930"}
0005432727965	BA0A41	6027 147520	VYACHESLAV ANDREEV	{"phone": "+70802692824"}
0005432727966	49A084	9697 953290	ALEKSANDR KARPOV	{"phone": "+70749386674"}
0005432727967	49A084	0942 868416	ANNA ARKHIPOVA	{"email": "annaarkhipova_13091979@postgrespro.ru", "phone": "+70668747526"}
0005432727968	7FFE93	5211 675412	ALEKSANDRA KOROLEVA	{"email": "a-koroleva041976@postgrespro.ru", "phone": "+70776336696"}
0005432727969	71774A	5442 789624	LEONID SMIRNOV	{"phone": "+70697507843"}
0005432727970	DFDF96	8285 995260	LIDIYA ALEKSEEVA	{"email": "l-alekseeva-14121967@postgrespro.ru", "phone": "+70929655359"}
0005432727971	B30B50	0249 882532	SERGEY MAKAROV	{"email": "makarov-sergey.011979@postgrespro.ru", "phone": "+70256289985"}
0005432727972	3A7017	8897 019404	NIKITA KUZNECOV	{"email": "nikita-kuznecov.01031971@postgrespro.ru", "phone": "+70191358300"}
0005432727973	3A7017	3547 563048	YANA OSIPOVA	{"email": "yana_osipova.16051969@postgrespro.ru", "phone": "+70841220918"}
0005432727974	565994	5000 579246	TAISIYA SOKOLOVA	{"email": "sokolova.taisiya_021969@postgrespro.ru", "phone": "+70602949749"}
0005432727975	E6D525	8305 599289	IRINA PETROVA	{"email": "irina.petrova1972@postgrespro.ru", "phone": "+70564755985"}
0005432727976	CEB8C9	4545 613416	PAVEL KOROLEV	{"phone": "+70118873860"}
0005432727977	CEB8C9	0773 573709	MARGARITA BELOVA	{"email": "belovamargarita-28071968@postgrespro.ru", "phone": "+70566458186"}
0005432727978	CEB8C9	5979 176381	VIKTOR KULIKOV	{"email": "v-kulikov.25031964@postgrespro.ru", "phone": "+70010245139"}
0005432727979	68B766	5045 359438	VALENTINA POPOVA	{"phone": "+70058256618"}
0005432727981	68B766	3110 268206	ELENA NIKITINA	{"phone": "+70513612779"}
0005432727982	E9C551	0563 110228	EMIL GRIGOREV	{"email": "emil.grigorev.051970@postgrespro.ru", "phone": "+70600741401"}
0005432727983	603E45	9986 722224	ALEKSANDR SOKOLOV	{"phone": "+70342679283"}
0005432727984	E86100	9898 493297	ALEKSANDR SOROKIN	{"phone": "+70816008571"}
0005432727985	94B254	9653 701789	PAVEL KISELEV	{"email": "pavel_kiselev.041973@postgrespro.ru", "phone": "+70121343170"}
0005432727986	210875	4009 633419	BORIS KOROLEV	{"email": "bkorolev111972@postgrespro.ru", "phone": "+70127790524"}
0005432727987	A4C879	5299 218690	SVETLANA GUSEVA	{"phone": "+70258131690"}
0005432727988	CA9CDE	8625 942229	VALENTINA GORBUNOVA	{"phone": "+70958367891"}
0005432727989	ED3A06	2316 100811	YURIY FILIPPOV	{"phone": "+70158548231"}
0005432727990	ED3A06	6169 858188	VLADIMIR DMITRIEV	{"phone": "+70342758617"}
0005432727991	FDCB0D	9998 913474	LYUBOV MASLOVA	{"email": "maslova.l.22021971@postgrespro.ru", "phone": "+70972292276"}
0005432727992	201D1C	1756 344617	ARTEM TIMOFEEV	{"email": "artem_timofeev.061959@postgrespro.ru", "phone": "+70815944080"}
0005432727993	E7FE85	7303 703113	ANTON SOROKIN	{"email": "sorokin_a-011979@postgrespro.ru", "phone": "+70701367041"}
0005432727994	925D68	9229 853875	VIKTOR ROMANOV	{"phone": "+70516837025"}
0005432727995	925D68	6510 084100	NATALIYA MIRONOVA	{"email": "mironovan1971@postgrespro.ru", "phone": "+70588025886"}
0005432727996	D674AF	0758 055252	ANNA MATVEEVA	{"email": "a-matveeva-1973@postgrespro.ru", "phone": "+70130073715"}
0005432727997	F3C6A1	1474 034523	ALEKSANDR TIKHONOV	{"email": "tikhonov_a.091977@postgrespro.ru", "phone": "+70384882067"}
0005432727998	305DC2	3821 565746	IRINA KONOVALOVA	{"phone": "+70487823860"}
0005432727999	A08E3F	4587 330121	SERGEY NOVIKOV	{"email": "novikovs1971@postgrespro.ru", "phone": "+70987217915"}
0005432728000	A0EA31	2899 519831	OLGA SEMENOVA	{"phone": "+70732129182"}
0005432728001	33D5A1	5929 142864	ANGELINA ANDREEVA	{"email": "andreeva_angelina_1977@postgrespro.ru", "phone": "+70588728701"}
0005432728002	33D5A1	1441 065120	NATALYA NAZAROVA	{"email": "natalya-nazarova-25101972@postgrespro.ru", "phone": "+70977902200"}
0005432728003	E052D5	0384 036670	ALEKSANDR ISAEV	{"phone": "+70445183002"}
0005432728004	6AF3D5	3311 879246	INNA VOLKOVA	{"email": "volkovai101972@postgrespro.ru", "phone": "+70817505832"}
0005432728005	EF66CC	2654 723113	SERGEY MATVEEV	{"phone": "+70042436945"}
0005432728006	1B9EE9	5549 614898	YURIY GERASIMOV	{"phone": "+70353660930"}
0005432728007	C72BC5	1586 086475	IRINA GERASIMOVA	{"phone": "+70745105655"}
0005432728008	C72BC5	1035 890157	NATALYA PAVLOVA	{"phone": "+70628410658"}
0005432728009	1F4883	1568 489481	ALEKSANDR EGOROV	{"email": "egorov-a_021976@postgrespro.ru", "phone": "+70933192485"}
0005432728010	1F4883	6969 940724	SERGEY STEPANOV	{"email": "stepanov-s.101983@postgrespro.ru", "phone": "+70499016139"}
0005432728011	901F3F	2229 724414	SERGEY POPOV	{"phone": "+70567702835"}
0005432728012	901F3F	6992 532684	ANNA LUKYANOVA	{"email": "annalukyanova-1982@postgrespro.ru", "phone": "+70541834849"}
0005432728013	577781	3211 054759	LEONID ORLOV	{"phone": "+70338603553"}
0005432728014	FB22A1	2274 277191	TATYANA NAZAROVA	{"phone": "+70741792667"}
0005432728015	FB22A1	7968 855985	GALINA ZHUKOVA	{"phone": "+70702093899"}
0005432728016	BAF240	0607 081115	EVGENIY GERASIMOV	{"phone": "+70758760117"}
0005432728017	BAF240	3982 921808	SERGEY BONDARENKO	{"phone": "+70730732264"}
0005432728018	C89AE3	5812 932922	TATYANA FROLOVA	{"email": "frolova-t1974@postgrespro.ru", "phone": "+70467630974"}
0005432728019	FC623C	5102 550303	ELENA KUDRYASHOVA	{"phone": "+70992160847"}
0005432728020	71B621	2254 035727	SERAFIMA MOISEEVA	{"email": "s-moiseeva.061972@postgrespro.ru", "phone": "+70777292605"}
0005432728021	71B621	0683 819437	ALLA POLYAKOVA	{"email": "alla-polyakova_101974@postgrespro.ru", "phone": "+70380638491"}
0005432728022	7389FA	1906 797687	OLGA TIMOFEEVA	{"phone": "+70100816124"}
0005432728023	7389FA	5388 420830	NATALYA TIMOFEEVA	{"phone": "+70359033970"}
0005432728024	59709F	8017 229234	ELIZAVETA MELNIKOVA	{"email": "melnikova_elizaveta.1968@postgrespro.ru", "phone": "+70885377721"}
0005432728025	89A9C4	3407 019150	PETR KISELEV	{"email": "petrkiselev-121995@postgrespro.ru", "phone": "+70757217856"}
0005432728026	89A9C4	1037 543278	LYUDMILA MELNIKOVA	{"email": "lyudmila.melnikova1978@postgrespro.ru", "phone": "+70744441877"}
0005432728027	F400C0	3390 130245	YURIY FEDOROV	{"email": "fedorov_yuriy-091968@postgrespro.ru", "phone": "+70782405086"}
0005432728028	C8C816	6490 723781	GALINA MOISEEVA	{"phone": "+70623543729"}
0005432728029	389592	8093 245363	DMITRIY TIKHONOV	{"phone": "+70675781215"}
0005432728030	2ACA6A	7912 196230	VALENTINA KOLESNIKOVA	{"email": "v.kolesnikova_091978@postgrespro.ru", "phone": "+70566143379"}
0005432728031	2ACA6A	8651 111874	VALERIY VASILEV	{"email": "valeriy.vasilev04031967@postgrespro.ru", "phone": "+70496988812"}
0005432728032	191264	8305 018895	OKSANA LEBEDEVA	{"phone": "+70227965746"}
0005432728033	75846B	3329 954233	SERGEY KUZNECOV	{"email": "kuznecovsergey.1971@postgrespro.ru", "phone": "+70104597826"}
0005432728034	2D2121	5554 184415	VALERIY VOLKOV	{"email": "valeriy_volkov_22121966@postgrespro.ru", "phone": "+70161719765"}
0005432728035	2D2121	8126 510792	VALENTIN KOZLOV	{"phone": "+70690635702"}
0005432728036	2D2121	8600 836282	SERGEY CHERNOV	{"phone": "+70117901818"}
0005432728037	8ED8C4	6335 592874	VLADIMIR IVANOV	{"phone": "+70144289189"}
0005432728038	3D9DBD	3278 913170	SERGEY FOMIN	{"email": "sergey_fomin_10111975@postgrespro.ru", "phone": "+70369361695"}
0005432728039	A64913	2469 509211	ANNA YUDINA	{"email": "yudina.a.17101969@postgrespro.ru", "phone": "+70856512658"}
0005432728040	CBAB51	3507 135046	ALEKSANDR ANTONOV	{"email": "antonovaleksandr-20081966@postgrespro.ru", "phone": "+70802679714"}
0005432728041	A30EE2	7469 281411	VLADIMIR ORLOV	{"email": "vladimir-orlov.01011969@postgrespro.ru", "phone": "+70036436875"}
0005432728042	99D7D4	2794 748596	NIKOLAY NAUMOV	{"phone": "+70394823015"}
0005432728043	99D7D4	6259 376314	NATALIYA LOGINOVA	{"phone": "+70394822673"}
0005432728044	1917A8	2039 874283	YURIY KUZMIN	{"email": "kuzmin_y31051982@postgrespro.ru", "phone": "+70066623423"}
0005432728045	051101	7217 129028	ALINA KUZMINA	{"email": "alinakuzmina_1976@postgrespro.ru", "phone": "+70705954571"}
0005432728046	051101	2413 204230	ANASTASIYA ZAYCEVA	{"email": "zayceva-a1971@postgrespro.ru", "phone": "+70004873097"}
0005432728047	051101	4033 738680	TATYANA SEMENOVA	{"email": "semenovatatyana.1974@postgrespro.ru", "phone": "+70016832313"}
0005432728048	561EF2	8053 821828	ANNA GAVRILOVA	{"email": "anna_gavrilova031975@postgrespro.ru", "phone": "+70585389241"}
0005432728049	9D84AD	0141 497018	KSENIYA ABRAMOVA	{"phone": "+70091985043"}
0005432728050	9D84AD	9288 261361	MARINA GUSEVA	{"phone": "+70943312913"}
0005432728051	B38956	6908 141791	NIKITA GRIGOREV	{"phone": "+70527380427"}
0005432728052	4159F0	0183 929216	VALERIY SIDOROV	{"phone": "+70993869085"}
0005432728053	7A34A0	0293 692056	SVETLANA BORISOVA	{"phone": "+70766605583"}
0005432728054	7A34A0	9550 773047	MARGARITA PETROVA	{"phone": "+70347208454"}
0005432728055	D21C77	9845 803837	ALEKSEY KULIKOV	{"phone": "+70439280822"}
0005432728056	D21C77	4723 916128	LYUBOV BELOVA	{"phone": "+70752843253"}
0005432728057	D21C77	1166 363669	LYUBOV GUSEVA	{"email": "guseva-lyubov.15041968@postgrespro.ru", "phone": "+70406961283"}
0005432728058	1CA9B4	8788 699650	SOFIYA KONOVALOVA	{"phone": "+70637627176"}
0005432728059	1CA9B4	6589 177783	ELENA KISELEVA	{"email": "kiselevaelena_1970@postgrespro.ru", "phone": "+70680295606"}
0005432728060	417AC2	5129 382299	VYACHESLAV KUZNECOV	{"phone": "+70043854213"}
0005432728061	417AC2	1733 743581	NATALYA KUZMINA	{"phone": "+70331787745"}
0005432728062	1107E0	1901 547481	VIKTORIYA SOKOLOVA	{"phone": "+70472591566"}
0005432728063	1107E0	7876 686065	NATALYA KULIKOVA	{"email": "kulikova-natalya1966@postgrespro.ru", "phone": "+70178296416"}
0005432728064	2DC1A9	9466 675478	EGOR SIDOROV	{"phone": "+70586657316"}
0005432728065	1BED34	7871 792991	VALENTINA ROMANOVA	{"email": "v_romanova_061975@postgrespro.ru", "phone": "+70558807757"}
0005432728066	1BED34	4307 096158	ELENA SERGEEVA	{"email": "sergeeva-e_011980@postgrespro.ru", "phone": "+70578808622"}
0005432728067	F7AE69	0191 732387	RAISA KARPOVA	{"email": "raisakarpova22121968@postgrespro.ru", "phone": "+70069840081"}
0005432728068	F7AE69	3969 215131	VALENTINA ILINA	{"email": "ilina.v_16011967@postgrespro.ru", "phone": "+70537445544"}
0005432728069	769E3D	7348 428525	OLGA TROFIMOVA	{"email": "trofimovaolga12051989@postgrespro.ru", "phone": "+70258601578"}
0005432728070	381CBC	5356 649874	ANASTASIYA GAVRILOVA	{"phone": "+70237969762"}
0005432728071	834EFA	7078 914496	NATALYA ILINA	{"email": "ilina.n-111971@postgrespro.ru", "phone": "+70057704329"}
0005432728072	834EFA	0094 697435	DANIIL NIKITIN	{"phone": "+70375969182"}
0005432728073	5D26B7	5216 296915	ELENA FOMINA	{"phone": "+70087338138"}
0005432728074	018B94	0256 242117	IRINA ZHUKOVA	{"email": "i_zhukova1973@postgrespro.ru", "phone": "+70778185567"}
0005432728075	D1D706	1662 615212	NATALYA POPOVA	{"email": "natalyapopova_1994@postgrespro.ru", "phone": "+70136138093"}
0005432728076	8A25EE	5031 638337	MARYAM NIKITINA	{"phone": "+70617975676"}
0005432728077	B87255	8307 934105	OLEG FEDOTOV	{"phone": "+70006271477"}
0005432728078	B87255	6349 066960	TATYANA SOKOLOVA	{"phone": "+70072027515"}
0005432728079	CEA779	6650 807887	IGOR FEDOTOV	{"email": "igorfedotov.1978@postgrespro.ru", "phone": "+70768251259"}
0005432728080	CEA779	3722 531477	TATYANA ISAEVA	{"email": "tatyana-isaeva.31081986@postgrespro.ru", "phone": "+70153860602"}
0005432728081	8A678F	0428 260416	VALENTIN GRIGOREV	{"phone": "+70397752799"}
0005432728082	983DBF	3999 293194	DENIS BELOV	{"email": "belov_denis081975@postgrespro.ru", "phone": "+70026616963"}
0005432728083	1B724F	6373 083108	GALINA BOGDANOVA	{"email": "g_bogdanova011973@postgrespro.ru", "phone": "+70507082237"}
0005432728084	20A544	3219 948265	GALINA SERGEEVA	{"email": "sergeeva-galina_25091981@postgrespro.ru", "phone": "+70546454366"}
0005432728085	2B3B78	0997 601167	SVETLANA TITOVA	{"phone": "+70783455449"}
0005432728086	D0A18E	7596 193636	MARINA KUDRYASHOVA	{"email": "kudryashova_marina_21121974@postgrespro.ru", "phone": "+70534130992"}
0005432728087	0AE697	7031 677419	EKATERINA LAZAREVA	{"email": "e.lazareva-1978@postgrespro.ru", "phone": "+70600447832"}
0005432728088	0AE697	1374 151320	NINA FROLOVA	{"phone": "+70399828147"}
0005432728089	B052F8	1063 204290	MAKSIM STEPANOV	{"email": "maksim.stepanov-061976@postgrespro.ru", "phone": "+70150439984"}
0005432728090	F406D2	9530 804433	SVETLANA MELNIKOVA	{"email": "melnikova_s_071972@postgrespro.ru", "phone": "+70824117930"}
0005432728091	F406D2	4526 633006	LIDIYA TIKHONOVA	{"email": "tikhonova_l_101975@postgrespro.ru", "phone": "+70524682245"}
0005432728092	F406D2	0524 480308	RINAT STEPANOV	{"email": "stepanov.rinat-081982@postgrespro.ru", "phone": "+70528794213"}
0005432728093	15EDCA	6829 667467	MAKSIM KISELEV	{"email": "kiselev_m_07111973@postgrespro.ru", "phone": "+70218874380"}
0005432728094	5BE7AA	6080 180143	LYUDMILA FROLOVA	{"email": "l.frolova-1975@postgrespro.ru", "phone": "+70120911340"}
0005432728095	40172E	5425 835008	NIKITA BORISOV	{"email": "nikita_borisov.08041970@postgrespro.ru", "phone": "+70154227136"}
0005432728096	47BBAA	9808 431744	TAMARA EGOROVA	{"email": "t-egorova.1966@postgrespro.ru", "phone": "+70470678360"}
0005432728097	47BBAA	0605 987023	YAN RODIONOV	{"phone": "+70982141842"}
0005432728098	72AF33	0007 994676	ANNA SMIRNOVA	{"email": "anna.smirnova_02091971@postgrespro.ru", "phone": "+70816358789"}
0005432728099	72AF33	3381 895387	ALISHER KULIKOV	{"email": "a_kulikov-18031977@postgrespro.ru", "phone": "+70799324594"}
0005432728100	DADEEC	9846 595509	OKSANA IVANOVA	{"email": "ivanova_oksana.03121966@postgrespro.ru", "phone": "+70672397785"}
0005432728101	DADEEC	9247 452413	SERGEY IVANOV	{"phone": "+70116319096"}
0005432728102	DADEEC	1253 028698	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina10061971@postgrespro.ru", "phone": "+70992416734"}
0005432728103	0B80A4	8940 357240	NIKOLAY POPOV	{"email": "popovn_1972@postgrespro.ru", "phone": "+70557180092"}
0005432728104	0B80A4	6467 000941	NIKITA OSIPOV	{"phone": "+70871911794"}
0005432728105	0B80A4	7709 103035	SERGEY KISELEV	{"email": "s.kiselev_1964@postgrespro.ru", "phone": "+70216336186"}
0005432728106	49720D	9276 341752	VALENTINA ISAEVA	{"phone": "+70414733940"}
0005432728107	784A22	3345 006817	ALEKSANDR AFANASEV	{"phone": "+70081068879"}
0005432728108	784A22	9901 888521	IGOR ILIN	{"phone": "+70870034003"}
0005432728109	784A22	6851 241104	EKATERINA LEBEDEVA	{"email": "ekaterina_lebedeva_021963@postgrespro.ru", "phone": "+70319100164"}
0005432728110	0B649C	5417 203339	SVYATOSLAV KULIKOV	{"phone": "+70615728855"}
0005432728111	0B649C	3236 072294	VALERIY FROLOV	{"email": "v.frolov_28101973@postgrespro.ru", "phone": "+70832765492"}
0005432728112	0B649C	0709 677994	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey.05041977@postgrespro.ru", "phone": "+70472794652"}
0005432728113	EC9F57	8031 617047	IGOR BONDARENKO	{"email": "i_bondarenko.021977@postgrespro.ru", "phone": "+70978453338"}
0005432728114	C8116C	4656 589632	ANNA NAZAROVA	{"phone": "+70826877553"}
0005432728115	A91A97	2775 275969	TATYANA DAVYDOVA	{"phone": "+70379844303"}
0005432728116	8AC0F7	6804 516910	RAISA VASILEVA	{"email": "r-vasileva1978@postgrespro.ru", "phone": "+70989105079"}
0005432728117	4192DB	2477 022341	VASILIY KUZNECOV	{"phone": "+70715448356"}
0005432728118	9B5EFB	9225 921456	YAROSLAVA NIKITINA	{"email": "nikitina-yaroslava-011975@postgrespro.ru", "phone": "+70774040375"}
0005432728119	9B5EFB	6674 395238	GALINA ABRAMOVA	{"phone": "+70444447114"}
0005432728120	3CAC4E	5296 226381	OLGA KOVALEVA	{"phone": "+70755692718"}
0005432728121	3CAC4E	8334 100518	VADIM KUZNECOV	{"phone": "+70589143621"}
0005432728122	3CAC4E	5305 203303	NADEZHDA FADEEVA	{"email": "n_fadeeva_031966@postgrespro.ru", "phone": "+70538832280"}
0005432728123	75FCF7	4949 761136	PELAGEYA MIRONOVA	{"phone": "+70782511244"}
0005432728124	75FCF7	8963 879470	DARYA ILINA	{"email": "ilinadarya-101969@postgrespro.ru", "phone": "+70675122814"}
0005432728125	75FCF7	0620 038465	ULYANA TITOVA	{"email": "titovau.13061970@postgrespro.ru", "phone": "+70542603655"}
0005432728182	484175	8806 862440	TATYANA FEDOROVA	{"phone": "+70546619139"}
0005432728126	47DAEF	5396 666518	MARIYA SERGEEVA	{"email": "sergeeva_m_21071971@postgrespro.ru", "phone": "+70714917967"}
0005432728127	47DAEF	3026 194715	SNEZHANA LOGINOVA	{"email": "snezhana.loginova.1979@postgrespro.ru", "phone": "+70135708531"}
0005432728128	EC5526	3852 385576	VERA MAKAROVA	{"phone": "+70840096413"}
0005432728129	0DD15B	9034 910893	OLGA POPOVA	{"phone": "+70795950703"}
0005432728130	0DD15B	7461 944283	DARYA SOLOVEVA	{"email": "darya-soloveva-06031966@postgrespro.ru", "phone": "+70805935555"}
0005432728131	919FAA	9920 619249	SVETLANA LAZAREVA	{"phone": "+70026183003"}
0005432728132	919FAA	2343 309368	TATYANA KRASNOVA	{"phone": "+70711847719"}
0005432728133	8B8F39	3502 912365	AYRAT IVANOV	{"phone": "+70893450760"}
0005432728134	D82DBE	0048 407480	NIKOLAY RODIONOV	{"email": "nikolay.rodionov_091972@postgrespro.ru", "phone": "+70161941891"}
0005432728135	D82DBE	9533 019936	VALENTINA KUZNECOVA	{"email": "v-kuznecova.021968@postgrespro.ru", "phone": "+70468305652"}
0005432728136	A0F476	9934 687294	VIKTORIYA LOGINOVA	{"email": "viktoriya.loginova_13041969@postgrespro.ru", "phone": "+70848728629"}
0005432728137	9DCBCD	0344 418184	EKATERINA AKIMOVA	{"phone": "+70503626275"}
0005432728138	BBC7D1	2161 001363	IRINA NESTEROVA	{"email": "irina_nesterova.31101974@postgrespro.ru", "phone": "+70566864799"}
0005432728139	5B8111	7190 798088	TATYANA ZAYCEVA	{"phone": "+70316335158"}
0005432728140	5B8111	9650 355696	SERGEY VOLKOV	{"email": "volkovsergey-101972@postgrespro.ru", "phone": "+70061725490"}
0005432728141	9D3E5D	2516 600521	ILYA MAKAROV	{"email": "i_makarov05031969@postgrespro.ru", "phone": "+70302176594"}
0005432728142	7E144C	3822 701134	NINA MOISEEVA	{"email": "n.moiseeva_17091974@postgrespro.ru", "phone": "+70735175170"}
0005432728143	7E144C	5932 945469	YURIY DAVYDOV	{"email": "davydov-y.1967@postgrespro.ru", "phone": "+70697798659"}
0005432728144	432529	4953 277929	AMIR IVANOV	{"phone": "+70897561627"}
0005432728145	98BE59	4337 331170	NATALIYA SCHERBAKOVA	{"phone": "+70508690378"}
0005432728146	40A764	7456 800050	ANASTASIYA IVANOVA	{"email": "ivanovaa-1972@postgrespro.ru", "phone": "+70501715337"}
0005432728147	73477A	4312 341223	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-1964@postgrespro.ru", "phone": "+70031181817"}
0005432728148	73477A	5033 921104	GALINA ABRAMOVA	{"email": "abramova_g_20041973@postgrespro.ru", "phone": "+70171246676"}
0005432728149	E5F5FA	6512 757744	KRISTINA BELOVA	{"phone": "+70321758984"}
0005432728150	E5F5FA	4928 750801	ANGELINA MELNIKOVA	{"email": "melnikovaangelina.1968@postgrespro.ru", "phone": "+70545679334"}
0005432728151	4DE34D	8935 981619	ALEKSANDR ZHUKOV	{"phone": "+70585213015"}
0005432728152	997DFC	5096 717259	FEDOR SCHERBAKOV	{"email": "f-scherbakov1963@postgrespro.ru", "phone": "+70350066592"}
0005432728153	997DFC	3489 409422	VLADIMIR TARASOV	{"phone": "+70296255253"}
0005432728154	6CC89E	8073 565325	ANNA FROLOVA	{"phone": "+70493627887"}
0005432728155	6CC89E	7145 708418	ELENA NAUMOVA	{"email": "e-naumova021970@postgrespro.ru", "phone": "+70695460300"}
0005432728156	94AED1	8357 462733	ALEKSANDRA BELOVA	{"email": "aleksandra_belova_1984@postgrespro.ru", "phone": "+70271318838"}
0005432728157	94AED1	6287 465500	VLADISLAV BARANOV	{"email": "v-baranov_1971@postgrespro.ru", "phone": "+70758632944"}
0005432728158	94AED1	8471 886587	ALEKSEY VOLKOV	{"phone": "+70059892571"}
0005432728159	714019	0110 544313	ANNA EGOROVA	{"phone": "+70942681303"}
0005432728160	714019	3315 092196	VALENTINA ANDREEVA	{"email": "valentina-andreeva-27061965@postgrespro.ru", "phone": "+70877335682"}
0005432728161	B8431D	6337 321893	VERA NESTEROVA	{"phone": "+70907977510"}
0005432728162	FA8AEB	1032 333758	YURIY PAVLOV	{"phone": "+70035629243"}
0005432728163	B7EBF5	0464 021204	RAISA ORLOVA	{"phone": "+70299218682"}
0005432728164	B7EBF5	5522 277240	TATYANA SMIRNOVA	{"email": "smirnova.tatyana-051970@postgrespro.ru", "phone": "+70648762196"}
0005432728165	8906B1	0504 071851	VALERIY VASILEV	{"phone": "+70052369070"}
0005432728166	8906B1	8506 982240	YULIYA VOROBEVA	{"email": "yuliyavorobeva28021978@postgrespro.ru", "phone": "+70529075261"}
0005432728167	2BDA53	0266 610372	IVAN SIDOROV	{"email": "i-sidorov.04051978@postgrespro.ru", "phone": "+70846818630"}
0005432728168	B8BED7	5813 448381	YURIY NIKITIN	{"phone": "+70573373271"}
0005432728169	B8BED7	5913 245066	KRISTINA SMIRNOVA	{"phone": "+70566539868"}
0005432728170	021B62	3157 743997	SERGEY MIKHAYLOV	{"email": "mikhaylovs_1982@postgrespro.ru", "phone": "+70476000997"}
0005432728171	6BC9BA	8918 781208	NINA VOLKOVA	{"phone": "+70635668945"}
0005432728172	6BC9BA	8893 591901	LARISA SOROKINA	{"phone": "+70034334211"}
0005432728173	F90467	2185 785899	VLADIMIR PAVLOV	{"phone": "+70591907936"}
0005432728174	F90467	3440 432189	DMITRIY KOZLOV	{"phone": "+70542593426"}
0005432728175	42A4DA	0400 035980	TATYANA ILINA	{"email": "t_ilina-1969@postgrespro.ru", "phone": "+70738637795"}
0005432728176	42A4DA	9631 406638	ANNA ABRAMOVA	{"email": "abramovaanna-1975@postgrespro.ru", "phone": "+70622748277"}
0005432728177	42A4DA	4862 696484	GALINA NOVIKOVA	{"email": "g_novikova1969@postgrespro.ru", "phone": "+70653615623"}
0005432728178	83BADB	0952 149383	ROMAN PAVLOV	{"phone": "+70188142630"}
0005432728179	06BE6F	2828 979566	PETR FROLOV	{"email": "p.frolov.1986@postgrespro.ru", "phone": "+70774777190"}
0005432728180	06BE6F	2430 319277	OLGA MASLOVA	{"phone": "+70497051561"}
0005432728181	C934D0	0211 960534	ANASTASIYA RODIONOVA	{"email": "rodionovaanastasiya.07081986@postgrespro.ru", "phone": "+70480475382"}
0005432728183	560B03	0847 054291	GENNADIY NIKITIN	{"phone": "+70004659013"}
0005432728184	560B03	2477 093472	MARGARITA NOVIKOVA	{"phone": "+70126330805"}
0005432728185	DBE95F	5473 369364	OKSANA ROMANOVA	{"email": "oksana.romanova_041971@postgrespro.ru", "phone": "+70811168946"}
0005432728186	41D102	2774 929485	NIKOLAY TIMOFEEV	{"phone": "+70832968318"}
0005432728187	41D102	0970 268168	VIKTOR GUSEV	{"phone": "+70152014165"}
0005432728188	1532B0	3308 510159	IVAN MIKHAYLOV	{"phone": "+70994000940"}
0005432728189	1532B0	0269 140916	VASILIY ANDREEV	{"email": "vasiliy.andreev-1970@postgrespro.ru", "phone": "+70861023835"}
0005432728190	1532B0	0006 555442	ANNA NIKITINA	{"email": "a.nikitina-24061962@postgrespro.ru", "phone": "+70980031602"}
0005432728191	13ED9B	8489 888282	SOFYA SMIRNOVA	{"phone": "+70869550834"}
0005432728192	46A7BC	0160 576984	GALINA DAVYDOVA	{"email": "g-davydova.1982@postgrespro.ru", "phone": "+70898777022"}
0005432728193	643D0E	0275 589755	ANDREY ISAEV	{"phone": "+70633246101"}
0005432728194	71C9F3	5364 819206	ALLA FEDOROVA	{"email": "fedorova.a.031973@postgrespro.ru", "phone": "+70945732969"}
0005432728195	9D9B6C	5392 266435	LYUBOV KUZNECOVA	{"phone": "+70108892749"}
0005432728196	EB8C19	3572 096950	ANZHELA MOISEEVA	{"phone": "+70790918596"}
0005432728197	AB2C17	0178 198811	EVGENIY KUZNECOV	{"phone": "+70336319067"}
0005432728198	AB2C17	5631 357677	DENIS MOROZOV	{"email": "morozovd01101977@postgrespro.ru", "phone": "+70067772658"}
0005432728199	C12422	9859 094303	SERGEY FROLOV	{"email": "s-frolov041970@postgrespro.ru", "phone": "+70456834918"}
0005432728200	FBFD67	7680 246461	YURIY OSIPOV	{"email": "yuriy_osipov.111979@postgrespro.ru", "phone": "+70350508989"}
0005432728201	FBFD67	7238 454074	SERGEY FROLOV	{"phone": "+70238454192"}
0005432728202	54644E	2025 652414	VLADIMIR VASILEV	{"phone": "+70075705626"}
0005432728203	4EE2BA	1912 104512	YULIYA SCHERBAKOVA	{"phone": "+70767165467"}
0005432728204	4EE2BA	1532 819917	NATALYA BORISOVA	{"email": "borisova_natalya.041985@postgrespro.ru", "phone": "+70035097245"}
0005432728205	395EAF	5121 558074	ANGELINA KOVALEVA	{"phone": "+70301834484"}
0005432728206	6F0E2A	5928 657628	KLAVDIYA MELNIKOVA	{"phone": "+70148296641"}
0005432728207	F309DB	7819 276595	TATYANA ANDREEVA	{"phone": "+70756253250"}
0005432728208	3C514A	0324 354338	VLADIMIR IVANOV	{"email": "ivanovv.1963@postgrespro.ru", "phone": "+70145322327"}
0005432728209	3C514A	9564 608884	KONSTANTIN IVANOV	{"phone": "+70845828339"}
0005432728210	A9C492	2866 945559	VIKTOR GAVRILOV	{"phone": "+70027277629"}
0005432728211	A9C492	1649 567533	VERA ILINA	{"email": "vera-ilina-24021977@postgrespro.ru", "phone": "+70237104327"}
0005432728212	63D71E	2569 640584	NATALYA SMIRNOVA	{"email": "smirnova.natalya-071971@postgrespro.ru", "phone": "+70394066805"}
0005432728213	6E2773	3458 890239	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov_031966@postgrespro.ru", "phone": "+70210856733"}
0005432728214	6E2773	0966 011061	ALEKSANDRA FILIPPOVA	{"phone": "+70575304759"}
0005432728215	6E2773	7816 327267	ANTONINA PAVLOVA	{"email": "a_pavlova_17041975@postgrespro.ru", "phone": "+70547218574"}
0005432728216	6FE425	0944 226444	MATVEY ZAKHAROV	{"phone": "+70772345101"}
0005432728217	647BB5	5683 074220	KONSTANTIN TIKHONOV	{"email": "konstantin_tikhonov_1978@postgrespro.ru", "phone": "+70211508290"}
0005432728218	059FB3	3017 061607	MIKHAIL KUDRYASHOV	{"email": "kudryashov.mikhail.081970@postgrespro.ru", "phone": "+70351230050"}
0005432728219	3DC3EF	1331 296762	VARVARA IVANOVA	{"email": "ivanovav1968@postgrespro.ru", "phone": "+70722708521"}
0005432728220	B58FC9	1270 157671	DMITRIY KUDRYASHOV	{"phone": "+70859833632"}
0005432728221	D57946	3398 316986	ALEKSEY SOKOLOV	{"phone": "+70939655407"}
0005432728222	D57946	1483 738993	GALINA VLASOVA	{"email": "vlasova-g-051978@postgrespro.ru", "phone": "+70928400341"}
0005432728223	4DEA26	8843 386331	IVAN MEDVEDEV	{"email": "i.medvedev_111968@postgrespro.ru", "phone": "+70882992884"}
0005432728224	C62DF7	6460 940157	ALEKSANDR PAVLOV	{"email": "a-pavlov_1983@postgrespro.ru", "phone": "+70798684400"}
0005432728225	033E39	9032 237109	ALEKSANDRA SOKOLOVA	{"phone": "+70351496708"}
0005432728226	D54F3F	1269 813997	SVETLANA KUZNECOVA	{"email": "kuznecovas.031973@postgrespro.ru", "phone": "+70312868515"}
0005432728227	4D6E3A	8178 579404	ANDREY NOVIKOV	{"email": "andreynovikov-021970@postgrespro.ru", "phone": "+70977566247"}
0005432728228	9EBB92	4535 495930	MARIYA YAKOVLEVA	{"phone": "+70898233194"}
0005432728229	670F42	7915 549087	ANNA NIKOLAEVA	{"email": "a.nikolaeva-07021977@postgrespro.ru", "phone": "+70790809853"}
0005432728230	52F133	3816 352460	ALINA KOZLOVA	{"email": "kozlovaalina_101970@postgrespro.ru", "phone": "+70832116454"}
0005432728231	30F773	3479 468497	SERGEY ABRAMOV	{"email": "sergey_abramov26071966@postgrespro.ru", "phone": "+70676686652"}
0005432728232	30F773	8302 333194	LIDIYA NOVIKOVA	{"email": "l_novikova.1971@postgrespro.ru", "phone": "+70951517104"}
0005432728233	DA85FC	7140 018616	ROZALIYA YUDINA	{"email": "ryudina.27091979@postgrespro.ru", "phone": "+70676867829"}
0005432728234	D29ABE	2422 677700	ANTON KRASNOV	{"email": "krasnovanton-06061969@postgrespro.ru", "phone": "+70136649135"}
0005432728235	76969E	9705 440379	IVAN IVANOV	{"phone": "+70636971670"}
0005432728236	76969E	2994 727498	VIKTOR SHEVCHENKO	{"email": "v_shevchenko-1971@postgrespro.ru", "phone": "+70413193945"}
0005432728237	EBCE3F	0177 369558	GENNADIY SAVELEV	{"email": "savelevg.031975@postgrespro.ru", "phone": "+70666310137"}
0005432728238	CA67DC	9744 887209	NINA KOMAROVA	{"email": "n.komarova1986@postgrespro.ru", "phone": "+70919137404"}
0005432728239	CA67DC	1973 150064	LYUBOV MAKSIMOVA	{"email": "lyubovmaksimova-25031980@postgrespro.ru", "phone": "+70183518977"}
0005432728240	7999D6	9752 429238	VASILIY SCHERBAKOV	{"phone": "+70803267291"}
0005432728241	2F0E9B	5054 423022	ALEKSANDR KULIKOV	{"phone": "+70074080813"}
0005432728242	A80439	6600 440077	IVAN ROMANOV	{"phone": "+70443357052"}
0005432728243	015AEA	5830 153824	SERGEY MEDVEDEV	{"email": "sergey_medvedev.18071979@postgrespro.ru", "phone": "+70307834488"}
0005432728244	015AEA	7560 372634	SVETLANA BELOVA	{"email": "belova-s1979@postgrespro.ru", "phone": "+70733435852"}
0005432728245	115389	3378 347113	VLADIMIR NOVIKOV	{"email": "vnovikov1973@postgrespro.ru", "phone": "+70760814232"}
0005432728246	21B4CE	4657 758043	PETR ZHURAVLEV	{"phone": "+70949230638"}
0005432728247	36AC43	3895 697235	NIKITA FEDOROV	{"email": "nikitafedorov.1968@postgrespro.ru", "phone": "+70617658101"}
0005432728248	36AC43	3246 026141	VITALIY KUZNECOV	{"email": "v_kuznecov.1962@postgrespro.ru", "phone": "+70450426976"}
0005432728249	9230CB	3590 755257	ALEKSANDR MIKHAYLOV	{"phone": "+70365991339"}
0005432728250	9230CB	0221 769807	GALINA PETROVA	{"phone": "+70147552237"}
0005432728251	9230CB	4918 050732	GENNADIY TIKHONOV	{"email": "gennadiy.tikhonov1984@postgrespro.ru", "phone": "+70669461526"}
0005432728252	A5944D	7459 861405	VERA SOKOLOVA	{"email": "sokolovav-1961@postgrespro.ru", "phone": "+70101986506"}
0005432728253	5A6E7F	1639 946938	DARYA DANILOVA	{"email": "d_danilova041963@postgrespro.ru", "phone": "+70459193624"}
0005432728254	CCE9B5	0504 429050	NINA MARTYNOVA	{"email": "martynova.n-081973@postgrespro.ru", "phone": "+70202125669"}
0005432728255	CCE9B5	2986 264710	SVETLANA KOROLEVA	{"email": "svetlana-koroleva-031978@postgrespro.ru", "phone": "+70298502516"}
0005432728256	3CEF0F	7633 818261	IGOR NOVIKOV	{"email": "i_novikov_081975@postgrespro.ru", "phone": "+70765313605"}
0005432728257	E6EF1B	9684 052740	TAISIYA POLYAKOVA	{"email": "polyakovataisiya.081979@postgrespro.ru", "phone": "+70753813811"}
0005432728258	D198B3	4405 388878	MARIYA PETROVA	{"email": "petrovam-31071963@postgrespro.ru", "phone": "+70623672918"}
0005432728259	08E643	1673 362540	NATALYA KOZLOVA	{"phone": "+70395679011"}
0005432728260	08E643	8902 459525	MARINA GERASIMOVA	{"phone": "+70383590979"}
0005432728261	023814	6287 198449	ANNA MIKHAYLOVA	{"email": "annamikhaylova.031978@postgrespro.ru", "phone": "+70354170384"}
0005432728262	023814	4332 566795	OLGA AKIMOVA	{"email": "o-akimova.1974@postgrespro.ru", "phone": "+70262249048"}
0005432728263	226BAA	0052 766427	GALINA SOROKINA	{"phone": "+70139827269"}
0005432728264	226BAA	4898 754647	YURIY KISELEV	{"phone": "+70526861113"}
0005432728265	FF98D8	0411 420595	MARSEL ROMANOV	{"email": "romanov.m.051975@postgrespro.ru", "phone": "+70358103493"}
0005432728266	1EFE91	7928 022384	LARISA BORISOVA	{"email": "l.borisova-1973@postgrespro.ru", "phone": "+70360653592"}
0005432728267	1EFE91	2581 465562	ELENA ZAKHAROVA	{"phone": "+70909431514"}
0005432728268	719B33	5616 665580	PRASKOVYA ABRAMOVA	{"email": "praskovya-abramova.011980@postgrespro.ru", "phone": "+70962217918"}
0005432728269	719B33	6262 120769	MIKHAIL SHEVCHENKO	{"phone": "+70027761150"}
0005432728270	719B33	5942 897319	ALEKSEY SOKOLOV	{"email": "aleksey_sokolov-31101972@postgrespro.ru", "phone": "+70865549742"}
0005432728271	D6EF88	6770 399150	ROSTISLAV GUSEV	{"email": "gusev_rostislav.111974@postgrespro.ru", "phone": "+70441699111"}
0005432728272	D6EF88	1840 656690	ALEKSEY FROLOV	{"email": "frolov.a1970@postgrespro.ru", "phone": "+70065657378"}
0005432728273	D6EF88	1719 138044	OLGA TROFIMOVA	{"email": "olga-trofimova_1975@postgrespro.ru", "phone": "+70462943306"}
0005432728274	C4AC23	5556 118850	OKSANA IVANOVA	{"phone": "+70933004562"}
0005432728275	C4AC23	0499 473343	MARIYA BARANOVA	{"email": "mariya-baranova-081963@postgrespro.ru", "phone": "+70477848001"}
0005432728276	FD3903	0615 925663	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir1972@postgrespro.ru", "phone": "+70930431619"}
0005432728277	D3C276	2470 100176	YURIY BELOV	{"phone": "+70059438535"}
0005432728278	D3C276	6394 157178	ELENA DAVYDOVA	{"phone": "+70502157909"}
0005432728279	8E0FD3	4999 071165	EVGENIY MARTYNOV	{"email": "martynovevgeniy06101979@postgrespro.ru", "phone": "+70978864453"}
0005432728280	8E0FD3	4658 357474	NADEZHDA KUZNECOVA	{"phone": "+70149234318"}
0005432728281	A0A3CC	2816 436805	SVETLANA MATVEEVA	{"email": "matveeva_svetlana.1963@postgrespro.ru", "phone": "+70557344855"}
0005432728282	5539EF	3230 267164	TATYANA GORBUNOVA	{"phone": "+70009739633"}
0005432728283	DB0900	0771 927388	VALENTINA ANDREEVA	{"phone": "+70903698838"}
0005432728284	DB0900	5569 289055	NIKOLAY POPOV	{"phone": "+70050188744"}
0005432728285	F0421C	3209 133268	EKATERINA SAVELEVA	{"email": "saveleva.ekaterina1977@postgrespro.ru", "phone": "+70814944993"}
0005432728286	27C129	3813 437145	ILSHAT POPOV	{"email": "ipopov_1969@postgrespro.ru", "phone": "+70613983254"}
0005432747011	3E1EA2	7687 574738	VIKTORIYA MATVEEVA	{"phone": "+70623374099"}
0005432728287	27C129	1016 818605	ELENA ALEKSEEVA	{"email": "alekseeva_elena-1971@postgrespro.ru", "phone": "+70497098695"}
0005432728288	27C129	3829 890562	ALEKSANDR IVANOV	{"phone": "+70505665276"}
0005432728289	8187EC	1541 427018	ANNA NIKIFOROVA	{"email": "nikiforova_a-21091975@postgrespro.ru", "phone": "+70270473859"}
0005432728290	8187EC	1257 715407	ALEKSANDR MATVEEV	{"phone": "+70735330397"}
0005432728291	8187EC	0762 158552	ALEKSEY ALEKSEEV	{"phone": "+70111914239"}
0005432728292	ED5D25	9370 562747	ARTUR KARPOV	{"email": "arturkarpov.01021964@postgrespro.ru", "phone": "+70817274401"}
0005432728293	7DEF36	9680 296270	TAMARA VASILEVA	{"email": "vasileva_t-18051985@postgrespro.ru", "phone": "+70369789120"}
0005432728294	7DEF36	5114 897892	VITALIY KOZLOV	{"email": "kozlovv-041976@postgrespro.ru", "phone": "+70960483706"}
0005432728295	0D7026	1502 976598	MARIYA BOGDANOVA	{"phone": "+70009446368"}
0005432728296	A13873	7935 117383	ALEKSEY ALEKSANDROV	{"phone": "+70230254549"}
0005432728297	4ED709	5373 385686	SOFYA IVANOVA	{"email": "ivanova.s_111989@postgrespro.ru", "phone": "+70918279443"}
0005432728298	DDF937	1364 068879	VALENTINA MIKHAYLOVA	{"phone": "+70415832490"}
0005432728299	DDF937	4950 857150	RUZALIYA KAZAKOVA	{"email": "kazakova.ruzaliya.021985@postgrespro.ru", "phone": "+70555876633"}
0005432728300	DDF937	8611 200748	VIKTOR SAVELEV	{"email": "savelev_v_061979@postgrespro.ru", "phone": "+70021006538"}
0005432728301	61777D	4579 893388	RAFAIL MAKAROV	{"phone": "+70395711927"}
0005432728302	61777D	9038 158353	GALINA KONOVALOVA	{"email": "konovalova-galina.111965@postgrespro.ru", "phone": "+70356957271"}
0005432728303	3F155E	3234 838150	SVETLANA MATVEEVA	{"phone": "+70966650462"}
0005432728304	00535D	5983 036632	ARTUR KUZMIN	{"phone": "+70877659218"}
0005432728305	00535D	6140 981666	IRINA ALEKSEEVA	{"phone": "+70391141455"}
0005432728306	B57D6C	5063 323829	TATYANA ALEKSEEVA	{"phone": "+70020260266"}
0005432728307	230DAC	2665 545266	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr.14051959@postgrespro.ru", "phone": "+70595970282"}
0005432728308	15B191	9776 062362	TAMARA TITOVA	{"email": "t-titova_08101971@postgrespro.ru", "phone": "+70454664705"}
0005432728309	BB3C93	8862 246069	ANATOLIY GORBUNOV	{"email": "anatoliygorbunov_1972@postgrespro.ru", "phone": "+70979883215"}
0005432728310	BB3C93	9167 550099	NIKOLAY NAZAROV	{"email": "nazarov_nikolay.14081963@postgrespro.ru", "phone": "+70571160336"}
0005432728311	4138AC	1874 006343	ALEKSANDR SAVELEV	{"phone": "+70128743911"}
0005432728312	F900F8	4748 254844	GLEB MAKSIMOV	{"email": "g-maksimov041978@postgrespro.ru", "phone": "+70695466860"}
0005432728313	FF4B63	2936 482425	NINA KULIKOVA	{"email": "nina-kulikova_111969@postgrespro.ru", "phone": "+70283022029"}
0005432748018	C95921	3353 361636	ALEKSANDR YAKOVLEV	{"phone": "+70409123220"}
0005432746864	A5E925	4275 816091	KONSTANTIN KOZLOV	{"email": "kozlov_k14061974@postgrespro.ru", "phone": "+70707092230"}
0005432746865	8F5954	4587 736546	GALINA ANDREEVA	{"phone": "+70891024100"}
0005432746866	1D5053	8011 017946	ELENA BELYAEVA	{"email": "belyaevae1966@postgrespro.ru", "phone": "+70306576867"}
0005432746867	461D8B	4258 701880	VLADIMIR VOLKOV	{"email": "v-volkov-051968@postgrespro.ru", "phone": "+70507131258"}
0005432746868	461D8B	7590 484262	VIKTOR RODIONOV	{"phone": "+70688134814"}
0005432746869	70B9DE	6863 377823	SERGEY PAVLOV	{"email": "s_pavlov_1966@postgrespro.ru", "phone": "+70596748802"}
0005432746870	E21B69	8852 101320	TATYANA STEPANOVA	{"email": "tatyana_stepanova-1979@postgrespro.ru", "phone": "+70503321517"}
0005432746871	91BCE6	1841 593144	EVGENIYA SEMENOVA	{"email": "semenova-e.1970@postgrespro.ru", "phone": "+70128718413"}
0005432746872	746997	4428 478412	NATALYA FOMINA	{"phone": "+70646621312"}
0005432746873	746997	8191 433255	EKATERINA ALEKSEEVA	{"email": "alekseeva.e.08051968@postgrespro.ru", "phone": "+70988662344"}
0005432746874	D1E268	3626 548434	VYACHESLAV ZAYCEV	{"phone": "+70234088621"}
0005432746875	DC4304	7971 890804	KONSTANTIN SMIRNOV	{"email": "smirnov-konstantin02071978@postgrespro.ru", "phone": "+70493743899"}
0005432746876	DC4304	5395 941742	ALEKSEY BORISOV	{"phone": "+70019080855"}
0005432746877	91A8BE	2839 587549	VLADIMIR VLASOV	{"phone": "+70916454567"}
0005432746878	91A8BE	0194 215821	ANNA KOZLOVA	{"email": "kozlova-anna_1970@postgrespro.ru", "phone": "+70902654006"}
0005432746879	87CB68	4557 073713	SVETLANA VASILEVA	{"phone": "+70939971963"}
0005432746880	44ACA9	2300 503487	GALINA KOMAROVA	{"phone": "+70446524068"}
0005432746881	44ACA9	8202 275899	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a-011979@postgrespro.ru", "phone": "+70134474943"}
0005432746882	B83ED2	7070 402541	ALEKSANDR NIKITIN	{"email": "a-nikitin_1967@postgrespro.ru", "phone": "+70217807944"}
0005432746883	C6B814	1188 388648	NIKOLAY SMIRNOV	{"phone": "+70567811155"}
0005432746884	4BC871	8272 420029	NINA MAKAROVA	{"phone": "+70810376892"}
0005432746885	2567B7	7998 866395	SVYATOSLAV VASILEV	{"email": "vasilev.s.1972@postgrespro.ru", "phone": "+70510879310"}
0005432746886	EBD13F	0411 438761	ZINAIDA FEDOROVA	{"phone": "+70140748477"}
0005432746887	E3540D	8054 501947	VLADIMIR SMIRNOV	{"phone": "+70843632805"}
0005432746888	052060	3705 478798	NINA VASILEVA	{"email": "nvasileva_1961@postgrespro.ru", "phone": "+70155163218"}
0005432746889	87C239	7219 964878	VLADIMIR BELOV	{"email": "belov-vladimir.18061966@postgrespro.ru", "phone": "+70377110530"}
0005432746890	422ADC	8295 572482	SVETLANA MATVEEVA	{"phone": "+70208390379"}
0005432746891	7ED034	9066 485643	ROMAN PETROV	{"email": "romanpetrov051981@postgrespro.ru", "phone": "+70659245951"}
0005432746892	27D10B	5578 269425	ALEKSEY MOROZOV	{"email": "morozov.a101973@postgrespro.ru", "phone": "+70949292309"}
0005432746893	C93124	8878 835152	IRINA KUZNECOVA	{"phone": "+70923368471"}
0005432746894	E4D3E9	7905 149780	ANVAR MAKSIMOV	{"phone": "+70518989904"}
0005432746895	F9F5AC	8371 615556	TIMOFEY MIRONOV	{"phone": "+70159178392"}
0005432746896	F9F5AC	4050 249980	ELENA MALYSHEVA	{"email": "emalysheva.31081976@postgrespro.ru", "phone": "+70368561945"}
0005432746897	C94991	6726 914765	ALEKSANDR ROMANOV	{"phone": "+70374742963"}
0005432746898	C94991	0792 456281	ELENA ROMANOVA	{"email": "romanova.e.091974@postgrespro.ru", "phone": "+70057564935"}
0005432746899	BC330C	1196 531616	VADIM KUZMIN	{"email": "vadimkuzmin-24071964@postgrespro.ru", "phone": "+70773234792"}
0005432746900	CA918B	0390 662024	VLADIMIR GORBUNOV	{"email": "vladimir-gorbunov.1965@postgrespro.ru", "phone": "+70588004790"}
0005432746901	59EE8D	9476 954584	VARVARA NOVIKOVA	{"email": "varvara.novikova.1966@postgrespro.ru", "phone": "+70838306119"}
0005432746902	59A871	8874 748001	TATYANA FADEEVA	{"phone": "+70705596937"}
0005432746903	ECF712	2304 535012	ANTONINA MOROZOVA	{"phone": "+70393630158"}
0005432746904	5B0DEF	9751 879071	NATALYA AFANASEVA	{"phone": "+70610586518"}
0005432746905	5891A5	8777 721591	EVGENIY ZHURAVLEV	{"email": "evgeniy.zhuravlev.21011977@postgrespro.ru", "phone": "+70494166054"}
0005432746906	5891A5	9712 375399	ANDREY ISAEV	{"phone": "+70058146981"}
0005432746907	5A34FB	7657 210443	KLAVDIYA SAVELEVA	{"email": "saveleva.klavdiya.021984@postgrespro.ru", "phone": "+70275703329"}
0005432746908	08CFB0	5640 689793	MARINA TROFIMOVA	{"email": "m_trofimova101967@postgrespro.ru", "phone": "+70520114806"}
0005432746909	640852	5944 488861	KIRILL TARASOV	{"phone": "+70388990382"}
0005432746910	DCFEE8	9390 896351	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir1968@postgrespro.ru", "phone": "+70699213665"}
0005432746911	2DC539	6850 186727	MIKHAIL NOVIKOV	{"email": "novikov.mikhail.1983@postgrespro.ru", "phone": "+70802778403"}
0005432746912	2DC539	5328 995951	ARTEM FROLOV	{"phone": "+70741818898"}
0005432746913	DCB1CB	2835 900427	VIKTOR ZAKHAROV	{"phone": "+70341959681"}
0005432746914	DCB1CB	5457 494626	TATYANA VOROBEVA	{"phone": "+70540525544"}
0005432746915	56BC04	6139 874532	ALEKSANDR BORISOV	{"email": "borisovaleksandr-1979@postgrespro.ru", "phone": "+70610917971"}
0005432746916	8C8C9C	5690 463776	IVAN FILIPPOV	{"phone": "+70296036244"}
0005432746917	8C8C9C	6377 117174	VIKTOR SOROKIN	{"email": "sorokin_v.091964@postgrespro.ru", "phone": "+70492881150"}
0005432746918	8C8C9C	8610 583590	VERA EFIMOVA	{"email": "efimova-v-07071969@postgrespro.ru", "phone": "+70877100810"}
0005432746919	CE54D8	5119 497879	ELENA KARPOVA	{"email": "elena_karpova1973@postgrespro.ru", "phone": "+70864228832"}
0005432746920	C84B90	1885 244571	TATYANA DAVYDOVA	{"phone": "+70388206384"}
0005432746921	FA7CBF	9409 977174	ALFIYA LEBEDEVA	{"email": "a-lebedeva.07051968@postgrespro.ru", "phone": "+70623509523"}
0005432746922	FA7CBF	7562 151610	ANNA CHERNOVA	{"email": "chernovaanna_1966@postgrespro.ru", "phone": "+70843904511"}
0005432746923	B03218	1400 383368	OLGA KOZLOVA	{"phone": "+70444667610"}
0005432746924	97CBC9	6722 751261	OLESYA KARPOVA	{"email": "okarpova_1975@postgrespro.ru", "phone": "+70613534483"}
0005432746925	9C4881	3951 293561	VALENTINA SERGEEVA	{"email": "sergeeva.valentina.041969@postgrespro.ru", "phone": "+70063093241"}
0005432746926	9C4881	2082 564619	OLEG VASILEV	{"email": "oleg_vasilev_1973@postgrespro.ru", "phone": "+70899609006"}
0005432746927	B46517	4516 748591	DANILA VOLKOV	{"email": "danila.volkov.1984@postgrespro.ru", "phone": "+70122678743"}
0005432746928	1798F3	5006 142666	ANASTASIYA ROMANOVA	{"phone": "+70824683849"}
0005432746929	58D9DC	9853 360229	OLEG SERGEEV	{"phone": "+70380244401"}
0005432746930	2BF99A	0499 300446	ALENA SOLOVEVA	{"phone": "+70967236393"}
0005432746931	03309C	2951 147883	VLADIMIR MEDVEDEV	{"email": "vladimir.medvedev11021989@postgrespro.ru", "phone": "+70352891297"}
0005432746932	4EDDE3	9064 334984	SEMEN NIKOLAEV	{"phone": "+70094361164"}
0005432746933	43E1FF	9142 075379	ANDREY MIKHAYLOV	{"phone": "+70196851869"}
0005432746934	F1F108	4383 282203	MAKSIM ROMANOV	{"phone": "+70358658929"}
0005432746935	1554A8	7306 646195	PAVEL MAKSIMOV	{"phone": "+70733893696"}
0005432746936	092828	5536 614575	OLGA VASILEVA	{"email": "vasileva.olga1984@postgrespro.ru", "phone": "+70700318110"}
0005432746937	D93458	5251 955746	OLGA ZHURAVLEVA	{"email": "zhuravlevao-1972@postgrespro.ru", "phone": "+70668282267"}
0005432746938	6397AB	0630 799815	MAKSIM NAZAROV	{"email": "m_nazarov111965@postgrespro.ru", "phone": "+70699125662"}
0005432746939	F89330	9184 934826	GENNADIY IVANOV	{"phone": "+70367475032"}
0005432746940	A0A6E6	9983 497388	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova-n051972@postgrespro.ru", "phone": "+70040869755"}
0005432746941	A0A6E6	7570 327077	LYUBOV FILIPPOVA	{"email": "lyubov_filippova-05041975@postgrespro.ru", "phone": "+70783457831"}
0005432746942	898C00	3852 115288	IVAN ZAKHAROV	{"phone": "+70533265386"}
0005432746943	898C00	7302 970914	VLADIMIR TARASOV	{"email": "tarasov-v.101975@postgrespro.ru", "phone": "+70215704863"}
0005432746944	898C00	1977 997680	ALEKSANDR MAKAROV	{"phone": "+70244151966"}
0005432746945	CFEF24	8797 061922	OLEG ORLOV	{"email": "orlov.oleg1959@postgrespro.ru", "phone": "+70670929772"}
0005432746946	CFEF24	1574 166911	VYACHESLAV KOROLEV	{"phone": "+70298695185"}
0005432746947	B377DE	7949 291003	ANASTASIYA VOROBEVA	{"email": "vorobevaa_121966@postgrespro.ru", "phone": "+70645608009"}
0005432746948	B377DE	8267 081581	SERGEY SMIRNOV	{"email": "ssmirnov_31101979@postgrespro.ru", "phone": "+70917083818"}
0005432746949	13C20C	2476 293545	SERGEY KONOVALOV	{"email": "konovalov.sergey_16041979@postgrespro.ru", "phone": "+70528294948"}
0005432746950	D7B13F	2046 092399	GENNADIY SOKOLOV	{"email": "gennadiy_sokolov_1971@postgrespro.ru", "phone": "+70261283389"}
0005432746951	D7B13F	9326 072403	ELENA FEDOROVA	{"email": "e-fedorova-09091983@postgrespro.ru", "phone": "+70211652505"}
0005432746952	427DE7	4899 902333	ALEKSANDR DMITRIEV	{"phone": "+70691826980"}
0005432746953	2142F5	8524 805047	IRINA KUZNECOVA	{"email": "irina_kuznecova_1980@postgrespro.ru", "phone": "+70160636984"}
0005432747012	F8B482	5955 274681	ELIZAVETA MOROZOVA	{"phone": "+70593955535"}
0005432746954	3BA8EA	7103 192531	OLGA TITOVA	{"email": "olga_titova12051981@postgrespro.ru", "phone": "+70002515051"}
0005432746955	D740C8	1902 578450	TATYANA VOROBEVA	{"phone": "+70307871225"}
0005432746956	D740C8	6902 502393	DIANA ZAKHAROVA	{"email": "d-zakharova13111964@postgrespro.ru", "phone": "+70481127157"}
0005432746957	1AD78B	8128 128177	ANTONINA TARASOVA	{"email": "antonina-tarasova21051980@postgrespro.ru", "phone": "+70346009926"}
0005432746958	1AD78B	3358 779868	NIKOLAY ZAKHAROV	{"phone": "+70653600434"}
0005432746959	87B10E	0814 797963	VALERIY PAVLOV	{"phone": "+70393706339"}
0005432746960	87B10E	2001 697776	ANASTASIYA ZHUKOVA	{"email": "zhukova.anastasiya-081966@postgrespro.ru", "phone": "+70977962232"}
0005432746961	3DFD02	7406 847918	DMITRIY STEPANOV	{"phone": "+70861815125"}
0005432746962	E5E0E1	1764 700043	DMITRIY SOLOVEV	{"email": "d-solovev_071985@postgrespro.ru", "phone": "+70512234490"}
0005432748075	79E964	9640 476046	MIKHAIL IVANOV	{"phone": "+70804851580"}
0005432746963	5A7312	3821 669890	FANIL SIDOROV	{"email": "sidorov-f_051972@postgrespro.ru", "phone": "+70102999529"}
0005432746964	9B8470	8087 801574	NIKOLAY ZHUKOV	{"phone": "+70178341717"}
0005432746965	9B8470	7682 745806	SERGEY SEMENOV	{"phone": "+70227716757"}
0005432746966	6AF789	7854 242621	INNA POTAPOVA	{"phone": "+70924638306"}
0005432746967	6AF789	1671 853748	YURIY MIRONOV	{"email": "mironov.yuriy-071980@postgrespro.ru", "phone": "+70572990276"}
0005432746968	1D6154	9964 034489	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov-1975@postgrespro.ru", "phone": "+70878529340"}
0005432746969	1D6154	6552 854688	VLADIMIR EGOROV	{"phone": "+70069263896"}
0005432746970	F60BF6	2298 400743	NADEZHDA POPOVA	{"phone": "+70401865691"}
0005432746971	F60BF6	9026 685321	RINAT ANTONOV	{"email": "antonov_r-021974@postgrespro.ru", "phone": "+70402598576"}
0005432746972	1FD216	4516 809736	IRINA TITOVA	{"phone": "+70881373483"}
0005432746973	1FD216	1411 849765	ALEKSEY ZHURAVLEV	{"phone": "+70348033468"}
0005432746974	4EC5F3	3959 188109	NINA KUZNECOVA	{"email": "nina.kuznecova.1972@postgrespro.ru", "phone": "+70775907969"}
0005432746975	1D4F9F	0278 809955	LYUDMILA IVANOVA	{"phone": "+70862116484"}
0005432746976	E52E3E	3135 198116	MARIYA PAVLOVA	{"email": "pavlova_mariya.061971@postgrespro.ru", "phone": "+70257021293"}
0005432746977	E52E3E	2259 975696	VALERIY STEPANOV	{"phone": "+70987026803"}
0005432746978	7A6F8C	4449 530119	LYUBOV TIMOFEEVA	{"email": "timofeeval041978@postgrespro.ru", "phone": "+70520713345"}
0005432746979	365A80	4698 900605	VIKTOR KUZNECOV	{"phone": "+70096896582"}
0005432746980	365A80	1387 020932	OLEG KOZLOV	{"phone": "+70867195481"}
0005432746981	8F2C36	3715 550937	SERGEY SEMENOV	{"email": "sergey-semenov.1964@postgrespro.ru", "phone": "+70562156831"}
0005432746982	145A8A	4141 551323	LIYA OVCHINNIKOVA	{"email": "liyaovchinnikova.08061974@postgrespro.ru", "phone": "+70768739757"}
0005432746983	BD6D73	2793 024574	ALEKSANDR ANDREEV	{"email": "andreeva-1961@postgrespro.ru", "phone": "+70973615507"}
0005432746984	1C625F	6373 591725	NATALYA ANDREEVA	{"email": "natalya.andreeva_20051966@postgrespro.ru", "phone": "+70175488192"}
0005432747040	81295E	5563 209870	VLADISLAV STEPANOV	{"phone": "+70639703093"}
0005432746985	38B4A1	7202 278289	NINA KOROLEVA	{"email": "nina-koroleva1971@postgrespro.ru", "phone": "+70994298316"}
0005432746986	38B4A1	7379 472221	ELENA MARTYNOVA	{"email": "emartynova_021975@postgrespro.ru", "phone": "+70831061373"}
0005432746987	7D7BD3	2006 439365	NATALYA VOLKOVA	{"phone": "+70718011595"}
0005432746988	B84D73	8518 156785	NIKOLAY NAZAROV	{"email": "nazarov-n.031971@postgrespro.ru", "phone": "+70085024182"}
0005432746989	B84D73	5641 666536	IRINA RODIONOVA	{"email": "rodionova.i.26061968@postgrespro.ru", "phone": "+70301898005"}
0005432746990	0C6AA3	8816 802005	NIKOLAY VOLKOV	{"phone": "+70375297925"}
0005432746991	658628	2322 212483	MARINA CHERNOVA	{"email": "marina.chernova.051975@postgrespro.ru", "phone": "+70966518233"}
0005432746992	23472B	7193 706640	SERGEY ALEKSANDROV	{"phone": "+70830669447"}
0005432746993	23472B	2187 195340	MARINA MAKAROVA	{"phone": "+70841991035"}
0005432746994	729291	1514 770693	RUMIYA KONOVALOVA	{"email": "konovalova_r.1976@postgrespro.ru", "phone": "+70144472023"}
0005432746995	729291	5325 702506	SERGEY BELOV	{"email": "s_belov-03091983@postgrespro.ru", "phone": "+70423117815"}
0005432746996	729291	8962 431935	ANDREY NAZAROV	{"email": "nazarova111970@postgrespro.ru", "phone": "+70287071544"}
0005432746997	74E653	2360 627919	MARINA ROMANOVA	{"phone": "+70797531844"}
0005432746998	FE4D30	2690 153463	SERGEY SERGEEV	{"email": "sergeev_sergey1975@postgrespro.ru", "phone": "+70251655830"}
0005432746999	7D0B21	4236 706619	DENIS DENISOV	{"email": "denis.denisov_1970@postgrespro.ru", "phone": "+70550593909"}
0005432747000	392122	3777 957623	LYUBOV LEBEDEVA	{"phone": "+70686031267"}
0005432747001	392122	4164 028650	ANATOLIY ISAEV	{"email": "a_isaev061985@postgrespro.ru", "phone": "+70591156907"}
0005432747002	189E28	9132 451037	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr-03111980@postgrespro.ru", "phone": "+70231255370"}
0005432747003	BFB786	4607 653727	EVGENIYA SAVELEVA	{"phone": "+70237769994"}
0005432747004	BFB786	0353 733614	EKATERINA EFREMOVA	{"email": "e-efremova-111960@postgrespro.ru", "phone": "+70823779297"}
0005432747005	84289E	2459 128316	TAISIYA GERASIMOVA	{"email": "taisiya.gerasimova-091981@postgrespro.ru", "phone": "+70055644228"}
0005432747006	6CC28D	0639 189957	MARIYA ROMANOVA	{"email": "m-romanova_1964@postgrespro.ru", "phone": "+70154133486"}
0005432747007	6CC28D	9122 892406	NATALYA SAVELEVA	{"phone": "+70648516457"}
0005432747008	3AFD47	1158 402460	VALERIY ZAYCEV	{"email": "zaycevv_21051985@postgrespro.ru", "phone": "+70715137559"}
0005432747009	5F6578	1337 457726	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr.1969@postgrespro.ru", "phone": "+70103007254"}
0005432747010	3E1EA2	9771 857854	VLADIMIR ROMANOV	{"email": "vladimir-romanov1957@postgrespro.ru", "phone": "+70188642071"}
0005432747013	30C56D	0382 471132	POLINA AFANASEVA	{"phone": "+70405908739"}
0005432747014	30C56D	8774 222371	VALENTINA DENISOVA	{"phone": "+70453597597"}
0005432747015	1A045A	3619 072115	DANILA BARANOV	{"phone": "+70926817262"}
0005432747016	1A045A	9528 531757	KONSTANTIN CHERNOV	{"email": "chernov.k_1976@postgrespro.ru", "phone": "+70591863197"}
0005432747017	E9AACA	3951 244114	GALINA PETROVA	{"phone": "+70719669768"}
0005432747018	3487BF	3246 586111	SERGEY VOROBEV	{"phone": "+70586704560"}
0005432747019	30B09C	3824 920478	VALENTINA BORISOVA	{"email": "borisova.v-101978@postgrespro.ru", "phone": "+70590484788"}
0005432747020	30B09C	9887 977272	ELENA NIKOLAEVA	{"email": "e.nikolaeva_17121966@postgrespro.ru", "phone": "+70243689615"}
0005432747021	30B09C	1720 416953	SVETLANA FILATOVA	{"phone": "+70033038347"}
0005432747022	31E730	4823 381016	LYUBOV SOLOVEVA	{"email": "lyubov-soloveva061963@postgrespro.ru", "phone": "+70011771202"}
0005432747023	BEAFF7	5349 191559	LIDIYA ANTONOVA	{"phone": "+70884449883"}
0005432747024	9D3163	2950 426599	SERGEY VOROBEV	{"phone": "+70306676736"}
0005432747025	9D3163	4140 770534	ANTONIDA NIKOLAEVA	{"email": "nikolaeva.antonida.18101971@postgrespro.ru", "phone": "+70374770910"}
0005432747026	1C6E57	5677 777909	SVETLANA TIMOFEEVA	{"phone": "+70116621045"}
0005432747027	D66CF3	9442 442925	MARGARITA TARASOVA	{"email": "margarita_tarasova_1976@postgrespro.ru", "phone": "+70236421637"}
0005432747028	47B073	1029 855446	LIDIYA LUKYANOVA	{"email": "lukyanova_l-08081966@postgrespro.ru", "phone": "+70364875694"}
0005432747029	B7E1DC	3840 273190	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev.14111967@postgrespro.ru", "phone": "+70328479025"}
0005432747030	1B971B	7855 185806	GALINA BELOVA	{"email": "belovagalina_1982@postgrespro.ru", "phone": "+70218154762"}
0005432747031	1B971B	4123 392844	ANNA KISELEVA	{"email": "kiselevaanna_051976@postgrespro.ru", "phone": "+70358258324"}
0005432747032	1B971B	9738 636828	TATYANA GRISHINA	{"phone": "+70852064919"}
0005432747033	1B971B	4726 158683	VALENTINA MIRONOVA	{"phone": "+70074129168"}
0005432747034	30BC67	2569 408023	ALEKSEY VASILEV	{"email": "vasilevaleksey.071972@postgrespro.ru", "phone": "+70513256354"}
0005432747035	30BC67	9335 717631	MIKHAIL MAKAROV	{"email": "makarov-m_1970@postgrespro.ru", "phone": "+70309496766"}
0005432747036	BF8521	4371 418620	LYUBOV ERMAKOVA	{"phone": "+70466212142"}
0005432747037	9F6826	0323 883416	VALENTINA ANTONOVA	{"phone": "+70309623540"}
0005432747038	B19C26	5713 059997	OLGA PETROVA	{"email": "petrovaolga.1971@postgrespro.ru", "phone": "+70799156462"}
0005432747039	B19C26	3976 356729	VIKTOR SOLOVEV	{"email": "solovev_v061970@postgrespro.ru", "phone": "+70986683070"}
0005432747041	81295E	6829 042358	LYUDMILA NESTEROVA	{"phone": "+70991130642"}
0005432747042	62D9C9	2626 657664	VALENTINA ABRAMOVA	{"email": "valentina-abramova.1970@postgrespro.ru", "phone": "+70111415042"}
0005432747043	1A98DC	2746 650859	NINA FROLOVA	{"phone": "+70478345136"}
0005432747044	6E6152	4502 651513	YURIY KUZMIN	{"email": "kuzminy.06021968@postgrespro.ru", "phone": "+70319344566"}
0005432747045	149DA6	8527 346901	VADIM ANDREEV	{"email": "v-andreev-011980@postgrespro.ru", "phone": "+70993634752"}
0005432747046	7ADBC7	6569 937408	VALERIY VOLKOV	{"email": "volkov.valeriy.1965@postgrespro.ru", "phone": "+70486839845"}
0005432747047	7B6160	9931 301534	ALEKSANDR FROLOV	{"email": "frolov_aleksandr_1967@postgrespro.ru", "phone": "+70449496039"}
0005432747048	7B6160	0162 350207	VALERIY FILIPPOV	{"phone": "+70698712583"}
0005432747049	7B6160	9691 113384	MARIYA DMITRIEVA	{"email": "mdmitrieva.11041980@postgrespro.ru", "phone": "+70408450495"}
0005432747050	413218	8459 444594	ANTON PETROV	{"phone": "+70477453231"}
0005432747051	66C918	5426 147251	RAISA MIRONOVA	{"email": "mironova_r.111971@postgrespro.ru", "phone": "+70805463436"}
0005432747052	CFF455	7614 455899	TAISIYA SOKOLOVA	{"phone": "+70578298540"}
0005432747053	979D81	6747 374191	DMITRIY CHERNOV	{"email": "dmitriychernov.111969@postgrespro.ru", "phone": "+70886369876"}
0005432747054	979D81	7065 640863	VLADIMIR KOROLEV	{"phone": "+70470265339"}
0005432747055	A50DE6	9732 995384	YAROSLAV SMIRNOV	{"email": "yaroslav-smirnov-16031962@postgrespro.ru", "phone": "+70245731150"}
0005432747056	A50DE6	0795 995659	ELENA KUZMINA	{"email": "e.kuzmina23011976@postgrespro.ru", "phone": "+70090279957"}
0005432747057	09CF4B	8880 970791	ELENA GAVRILOVA	{"email": "elena.gavrilova031971@postgrespro.ru", "phone": "+70991620162"}
0005432747058	09CF4B	5589 981915	GALINA MELNIKOVA	{"phone": "+70156989683"}
0005432747059	0DD69D	3315 434047	VALENTINA MAKSIMOVA	{"email": "maksimova-valentina-1968@postgrespro.ru", "phone": "+70468875746"}
0005432747060	A5BD94	8831 630297	OLGA FROLOVA	{"phone": "+70934087365"}
0005432747061	A5BD94	0648 128388	ANDREY NIKITIN	{"phone": "+70240186662"}
0005432747062	3B9610	6356 761403	MAKSIM KONOVALOV	{"phone": "+70157676484"}
0005432747063	8FE8B8	2418 207711	ELENA KONOVALOVA	{"email": "konovalova_elena01051970@postgrespro.ru", "phone": "+70648574962"}
0005432747064	E5FDCA	5295 280016	MARTA KONOVALOVA	{"phone": "+70512614577"}
0005432747065	523402	0117 125561	NATALYA KISELEVA	{"email": "nkiseleva081968@postgrespro.ru", "phone": "+70261614429"}
0005432747066	055CAB	9492 372248	VIKTOR KAZAKOV	{"email": "v.kazakov_011964@postgrespro.ru", "phone": "+70213447724"}
0005432747067	6CC50B	0933 906469	SERGEY KUZNECOV	{"phone": "+70891538233"}
0005432747068	B454D4	1025 788857	OLGA IVANOVA	{"phone": "+70226578543"}
0005432747069	11F53F	2627 476003	ANATOLIY DAVYDOV	{"email": "davydova_17031984@postgrespro.ru", "phone": "+70867295192"}
0005432747070	11F53F	8787 561373	VALENTINA SMIRNOVA	{"email": "v-smirnova_101976@postgrespro.ru", "phone": "+70302551343"}
0005432747071	741F11	7892 152484	ALEKSANDR KULIKOV	{"email": "kulikov_a-031976@postgrespro.ru", "phone": "+70562251274"}
0005432747072	07CF4E	5291 665834	RAISA IVANOVA	{"phone": "+70560820470"}
0005432747073	07CF4E	8041 212642	ALEKSANDR KAZAKOV	{"email": "kazakova-19101970@postgrespro.ru", "phone": "+70374812803"}
0005432747074	07CF4E	9868 677204	ALEKSANDR ILIN	{"phone": "+70363759007"}
0005432747075	D38F13	3325 562759	YURIY POPOV	{"email": "popov_yuriy07041979@postgrespro.ru", "phone": "+70628024201"}
0005432747076	D38F13	9157 505048	IRINA DENISOVA	{"email": "denisovairina12091983@postgrespro.ru", "phone": "+70510474448"}
0005432747077	B23F7C	2789 626012	NIKITA FILIPPOV	{"phone": "+70448949806"}
0005432747078	B23F7C	1580 712561	MAKSIM ALEKSEEV	{"phone": "+70512220006"}
0005432747079	600CF9	1954 639573	DMITRIY ANDREEV	{"email": "d_andreev-1968@postgrespro.ru", "phone": "+70671087591"}
0005432747080	C08F7E	2064 000782	NIKOLAY KUZNECOV	{"email": "kuznecov.n_23091969@postgrespro.ru", "phone": "+70000922393"}
0005432747081	A4C1E3	3285 391355	ANNA DANILOVA	{"email": "a-danilova.061979@postgrespro.ru", "phone": "+70191979032"}
0005432747082	827D58	7746 907437	NIKOLAY SMIRNOV	{"email": "n_smirnov-1976@postgrespro.ru", "phone": "+70706854422"}
0005432747083	827D58	1991 719862	ELENA TROFIMOVA	{"phone": "+70390880664"}
0005432747084	827D58	9698 169644	YULIYA KUZNECOVA	{"email": "kuznecovayuliya_11091965@postgrespro.ru", "phone": "+70424565020"}
0005432747085	EFCC58	0317 172609	SVETLANA SIDOROVA	{"phone": "+70001466064"}
0005432747086	D74A74	6558 547108	MARIYA ZHUKOVA	{"phone": "+70596159672"}
0005432747087	D74A74	5890 249869	DIANA EFIMOVA	{"email": "dianaefimova-1964@postgrespro.ru", "phone": "+70598590158"}
0005432747088	4FAA25	2220 370357	RADIK FEDOROV	{"email": "r.fedorov-1968@postgrespro.ru", "phone": "+70103159617"}
0005432747089	4FAA25	9924 323382	NINA MOROZOVA	{"email": "morozova.n-11021968@postgrespro.ru", "phone": "+70020571581"}
0005432747090	03DADD	9752 348544	ELENA SOKOLOVA	{"phone": "+70431373112"}
0005432747091	03DADD	9987 675147	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev.041985@postgrespro.ru", "phone": "+70931126238"}
0005432747092	34A19E	7258 579330	DMITRIY GORBUNOV	{"email": "gorbunov_dmitriy-041973@postgrespro.ru", "phone": "+70442068480"}
0005432747093	34A19E	9087 944617	YURIY VASILEV	{"phone": "+70276054550"}
0005432747094	34A19E	1099 615646	LYUDMILA TARASOVA	{"phone": "+70320792258"}
0005432747095	7FF32F	2990 063781	EKATERINA KAZAKOVA	{"email": "kazakovae-08021970@postgrespro.ru", "phone": "+70656825606"}
0005432747152	D13059	8951 900521	LYUBOV MIKHAYLOVA	{"phone": "+70722134380"}
0005432747096	7FF32F	4996 709393	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov081968@postgrespro.ru", "phone": "+70207090313"}
0005432747097	8AF01B	9196 323853	ANATOLIY VASILEV	{"phone": "+70317061936"}
0005432747098	026782	5189 883871	ANTONINA PETROVA	{"phone": "+70096986362"}
0005432747099	026782	6139 646658	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_20091976@postgrespro.ru", "phone": "+70995446314"}
0005432747100	3FB625	2111 670625	DMITRIY FEDOTOV	{"email": "dmitriy.fedotov_031974@postgrespro.ru", "phone": "+70429558229"}
0005432747101	C89666	7280 248513	ANNA EFIMOVA	{"phone": "+70601402479"}
0005432747102	4166DA	4162 006099	ANASTASIYA KOZLOVA	{"phone": "+70971625237"}
0005432747103	4166DA	9526 668150	LYUDMILA AFANASEVA	{"phone": "+70024103462"}
0005432747104	1F22E5	0663 426404	DANIIL KUZNECOV	{"email": "kuznecov-daniil.1967@postgrespro.ru", "phone": "+70697089796"}
0005432747105	9F8EE3	2352 587145	MIKHAIL KISELEV	{"phone": "+70177604959"}
0005432747106	9F8EE3	4348 573413	VYACHESLAV ANDREEV	{"email": "andreev_v-1968@postgrespro.ru", "phone": "+70862293239"}
0005432747107	22558A	1779 326789	SVETLANA DANILOVA	{"phone": "+70699147944"}
0005432747108	CA2309	2102 582750	GALINA BELYAEVA	{"phone": "+70825301442"}
0005432747109	FFCAA9	8964 133832	LYUBOV SOLOVEVA	{"email": "l-soloveva_02051969@postgrespro.ru", "phone": "+70556108701"}
0005432747110	D1DFE7	1735 175802	RINAT NOVIKOV	{"phone": "+70081679934"}
0005432747111	D1DFE7	9580 957074	ZLATA SOKOLOVA	{"email": "z_sokolova-27091984@postgrespro.ru", "phone": "+70710420427"}
0005432747112	D1DFE7	2234 286354	EVGENIY ISAEV	{"phone": "+70731263640"}
0005432747113	698875	7005 106044	YULIYA KOLESNIKOVA	{"email": "y-kolesnikova-08121966@postgrespro.ru", "phone": "+70779572266"}
0005432747114	C83281	5622 303090	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov.30111968@postgrespro.ru", "phone": "+70171159967"}
0005432747115	0EB6C0	4727 601428	ARTUR ISAEV	{"phone": "+70780497735"}
0005432747116	F8BFD3	2479 658230	ANDREY NAUMOV	{"email": "naumov.a021974@postgrespro.ru", "phone": "+70020504280"}
0005432747117	F8BFD3	0104 421729	ALEKSANDRA KARPOVA	{"email": "a.karpova.011977@postgrespro.ru", "phone": "+70374344823"}
0005432747118	618D53	3191 696546	DARYA RODIONOVA	{"email": "darya-rodionova.11111970@postgrespro.ru", "phone": "+70862475707"}
0005432747119	F9D4AA	9198 281287	LIDIYA DAVYDOVA	{"email": "davydova_l04101977@postgrespro.ru", "phone": "+70276800453"}
0005432747120	F9D4AA	5324 520591	KIRILL ZAKHAROV	{"phone": "+70154519988"}
0005432747121	F9D4AA	6561 546177	SERGEY TIKHONOV	{"phone": "+70068957019"}
0005432747122	8E5689	7584 224868	NADEZHDA ORLOVA	{"phone": "+70340319839"}
0005432747123	8E5689	6941 145629	OLEG VOROBEV	{"email": "ovorobev-121972@postgrespro.ru", "phone": "+70614855586"}
0005432747124	FB5793	1254 301643	IVAN KUZMIN	{"phone": "+70008769816"}
0005432747125	D108EC	8095 794239	TATYANA DAVYDOVA	{"phone": "+70557376500"}
0005432747126	9F7D69	5220 376025	VERA ZAYCEVA	{"email": "vera.zayceva-27071957@postgrespro.ru", "phone": "+70006482483"}
0005432747127	D7448C	4312 605563	VIKTOR DAVYDOV	{"phone": "+70166649383"}
0005432747128	D7448C	4402 210250	SVETLANA KUZNECOVA	{"phone": "+70710163306"}
0005432747129	E143C1	3857 197862	LARISA TROFIMOVA	{"email": "l.trofimova.121969@postgrespro.ru", "phone": "+70123017936"}
0005432747130	E143C1	2603 649627	VLADISLAV NOVIKOV	{"email": "vnovikov.091988@postgrespro.ru", "phone": "+70631243884"}
0005432747131	2EC774	8211 631704	VIKTORIYA YAKOVLEVA	{"email": "viktoriya.yakovleva.1972@postgrespro.ru", "phone": "+70243358490"}
0005432747132	2EC774	7886 073534	GULFIYA STEPANOVA	{"phone": "+70816485404"}
0005432747133	3D0B02	5193 440615	TATYANA ZHURAVLEVA	{"email": "tatyanazhuravleva1981@postgrespro.ru", "phone": "+70190850753"}
0005432747134	3D0B02	3834 560669	ELENA KISELEVA	{"phone": "+70891931340"}
0005432747135	39B315	7939 732544	DMITRIY MIKHAYLOV	{"phone": "+70648580158"}
0005432747136	9ACB36	8158 203673	ELENA SERGEEVA	{"phone": "+70272393296"}
0005432747137	9ACB36	2883 194526	MARAT KISELEV	{"email": "kiselev.marat081976@postgrespro.ru", "phone": "+70864146619"}
0005432747138	9B5DAB	9920 043617	VLADIMIR MATVEEV	{"email": "vladimir-matveev.1973@postgrespro.ru", "phone": "+70839788897"}
0005432747139	E5C78B	6816 203387	GALINA ANDREEVA	{"email": "g_andreeva_1979@postgrespro.ru", "phone": "+70417538618"}
0005432747140	223DCC	0472 385708	SVETLANA TROFIMOVA	{"email": "s_trofimova_1978@postgrespro.ru", "phone": "+70327068580"}
0005432747141	20B6D4	4679 660668	ELENA KUZMINA	{"phone": "+70972884106"}
0005432747142	B7AB7E	8762 230317	RAUZA KUZMINA	{"email": "kuzminar_26061969@postgrespro.ru", "phone": "+70885412059"}
0005432747143	B002E2	5596 334675	NAILYA DAVYDOVA	{"phone": "+70127006455"}
0005432747144	B002E2	0870 635035	VLADIMIR IVANOV	{"email": "ivanovv_1976@postgrespro.ru", "phone": "+70357282383"}
0005432747145	939589	1093 641578	EKATERINA DAVYDOVA	{"email": "ekaterina.davydova_25031961@postgrespro.ru", "phone": "+70242335529"}
0005432747146	939589	8946 476310	ANASTASIYA KOLESNIKOVA	{"phone": "+70387743346"}
0005432747147	F32BEC	5075 984525	ALEKSANDR KUZNECOV	{"phone": "+70674256400"}
0005432747148	1F0152	8424 739207	IVAN KUZMIN	{"phone": "+70634067122"}
0005432747149	BD43DF	9536 295645	PETR ILIN	{"phone": "+70015631717"}
0005432747150	1D0E70	7456 386386	TAMARA SMIRNOVA	{"phone": "+70151934579"}
0005432747151	5DC530	6347 139391	EVGENIY PETROV	{"email": "evgeniy_petrov-1975@postgrespro.ru", "phone": "+70173794632"}
0005432747153	D13059	7012 799007	ANATOLIY NAZAROV	{"email": "anatoliy.nazarov1980@postgrespro.ru", "phone": "+70022413742"}
0005432747154	2A7CD2	7049 544102	SERGEY KAZAKOV	{"phone": "+70302932501"}
0005432747155	2A7CD2	2301 043010	ARTEM MATVEEV	{"phone": "+70358979936"}
0005432747156	B46814	8467 471361	VALERIY MAKAROV	{"email": "vmakarov-1966@postgrespro.ru", "phone": "+70319718745"}
0005432747157	7AC869	8822 896915	MARGARITA FEDOROVA	{"phone": "+70729781759"}
0005432747158	439669	1759 320148	ARINA SEMENOVA	{"phone": "+70456091829"}
0005432747159	439669	1520 636880	IRINA CHERNOVA	{"phone": "+70728305965"}
0005432747160	31991C	7092 709374	ALEVTINA NIKOLAEVA	{"phone": "+70379505475"}
0005432747161	2EAA35	8606 336713	DMITRIY ALEKSEEV	{"phone": "+70418131904"}
0005432747162	2BDDF7	5243 515825	ELENA MAKAROVA	{"email": "elena-makarova-021968@postgrespro.ru", "phone": "+70230396810"}
0005432747163	19B895	6077 621308	GENNADIY IVANOV	{"phone": "+70080280010"}
0005432747164	ECF87F	6675 910235	VALERIY SOROKIN	{"phone": "+70506943182"}
0005432747165	EF7F90	5670 636968	FEDOR BORISOV	{"email": "borisovfedor-011968@postgrespro.ru", "phone": "+70096920460"}
0005432747166	951460	6325 533318	SERGEY GAVRILOV	{"phone": "+70026012599"}
0005432747167	4B4381	8351 819950	ELENA SMIRNOVA	{"email": "smirnova.e-1986@postgrespro.ru", "phone": "+70165303953"}
0005432747168	F811ED	9470 537558	VALENTINA POLYAKOVA	{"email": "polyakova.v-1985@postgrespro.ru", "phone": "+70991249193"}
0005432747169	F811ED	6629 221822	KARINA ZAKHAROVA	{"email": "karinazakharova1971@postgrespro.ru", "phone": "+70598864913"}
0005432747170	F811ED	8943 692926	ARTUR KAZAKOV	{"phone": "+70740179530"}
0005432747171	0E5E8B	5816 268734	LYUDMILA PETROVA	{"email": "lyudmila.petrova.27101977@postgrespro.ru", "phone": "+70208457375"}
0005432747172	0E5E8B	7842 067880	DENIS YAKOVLEV	{"email": "denis_yakovlev_1968@postgrespro.ru", "phone": "+70442087949"}
0005432747173	6F5E1F	8869 230670	ANDREY SOLOVEV	{"email": "soloveva29091973@postgrespro.ru", "phone": "+70647618151"}
0005432747174	E22E20	0688 508547	VERA TROFIMOVA	{"email": "vera-trofimova1969@postgrespro.ru", "phone": "+70220881278"}
0005432747175	75BE29	0160 670828	VLADIMIR KOZLOV	{"email": "vladimir_kozlov1969@postgrespro.ru", "phone": "+70646833974"}
0005432747176	75BE29	6870 172206	OLGA SOKOLOVA	{"phone": "+70100484674"}
0005432747177	16B91F	5791 561197	KSENIYA MAKSIMOVA	{"phone": "+70689358904"}
0005432747178	11395C	4387 918010	YULIYA VASILEVA	{"email": "yuliya_vasileva-24081971@postgrespro.ru", "phone": "+70880520894"}
0005432747179	ECF0D2	4199 506044	TIMOFEY MIRONOV	{"email": "mironov.t.27041969@postgrespro.ru", "phone": "+70149637386"}
0005432747180	ECF0D2	2500 747157	OKSANA ALEKSANDROVA	{"phone": "+70027058084"}
0005432747181	DCF099	0130 839139	EVGENIY MAKAROV	{"email": "e.makarov_1958@postgrespro.ru", "phone": "+70878990462"}
0005432747182	268882	2330 216097	IVAN OSIPOV	{"phone": "+70106175325"}
0005432747183	B1038B	2772 857843	VLADIMIR IVANOV	{"email": "ivanov_vladimir021974@postgrespro.ru", "phone": "+70030856059"}
0005432747184	B1038B	8452 495747	ROBERT TARASOV	{"email": "tarasovrobert_12051970@postgrespro.ru", "phone": "+70616426936"}
0005432747185	01574D	8143 332039	OLESYA FROLOVA	{"email": "frolovaolesya-101970@postgrespro.ru", "phone": "+70051400304"}
0005432747186	01574D	9745 523210	ALEKSEY CHERNOV	{"phone": "+70455523570"}
0005432747187	84B817	8711 006443	YULIYA ANDREEVA	{"email": "andreeva-yuliya-26101971@postgrespro.ru", "phone": "+70274534412"}
0005432747188	84B817	9030 801698	TATYANA LOGINOVA	{"phone": "+70992794400"}
0005432747189	CFBC02	3228 749995	OLEG KUZNECOV	{"phone": "+70986403714"}
0005432747190	C84F23	4445 381597	VLADIMIR ZHURAVLEV	{"phone": "+70649994482"}
0005432747191	C35E24	7101 252845	SVETLANA ABRAMOVA	{"email": "svetlana-abramova1968@postgrespro.ru", "phone": "+70006703629"}
0005432747192	5AE094	7833 506396	YULIYA NIKIFOROVA	{"email": "y-nikiforova-1976@postgrespro.ru", "phone": "+70380203225"}
0005432747193	5AE094	4408 918848	NATALYA MARTYNOVA	{"email": "natalya_martynova051988@postgrespro.ru", "phone": "+70705071228"}
0005432747194	2164E3	6607 604164	ALEKSANDR STEPANOV	{"phone": "+70823714459"}
0005432747195	2164E3	5619 223491	VALERIY DAVYDOV	{"email": "davydovvaleriy_1976@postgrespro.ru", "phone": "+70188344658"}
0005432747196	73B371	3978 777894	TAMARA NAUMOVA	{"email": "tamara.naumova_1987@postgrespro.ru", "phone": "+70991768736"}
0005432747197	73B371	6525 853273	TATYANA KRASNOVA	{"email": "krasnova_tatyana.021961@postgrespro.ru", "phone": "+70225265545"}
0005432747198	55C053	5364 331832	VASILIY SEMENOV	{"email": "semenov-vasiliy-071974@postgrespro.ru", "phone": "+70166701636"}
0005432747199	D10CAA	4191 612427	SERGEY PETROV	{"phone": "+70950383272"}
0005432747200	D10CAA	3991 575742	ANTON FROLOV	{"email": "frolov.a1973@postgrespro.ru", "phone": "+70582899461"}
0005432747201	6FB938	0954 759488	MAKSIM ISAEV	{"email": "maksim-isaev_121971@postgrespro.ru", "phone": "+70227774193"}
0005432747202	C26F2B	5555 564791	ANATOLIY ABRAMOV	{"email": "anatoliy-abramov-1972@postgrespro.ru", "phone": "+70169946878"}
0005432747203	067044	4169 509158	MARINA MIKHAYLOVA	{"email": "mikhaylova.marina.05101971@postgrespro.ru", "phone": "+70415553566"}
0005432747204	7BEDD4	6262 139158	VASILIY SCHERBAKOV	{"email": "vscherbakov_1974@postgrespro.ru", "phone": "+70568279510"}
0005432747205	7BEDD4	9348 031334	LARISA GORBUNOVA	{"phone": "+70716437779"}
0005432747206	7BEDD4	3274 038554	MARINA KRASNOVA	{"email": "marina_krasnova-011982@postgrespro.ru", "phone": "+70463429124"}
0005432747207	BEA0DE	1416 192478	SVETLANA KOVALEVA	{"email": "kovalevas1971@postgrespro.ru", "phone": "+70032723794"}
0005432747208	BEA0DE	6130 764832	ALLA ZHUKOVA	{"phone": "+70435597687"}
0005432747209	EB5D0F	5330 148942	IRINA BOGDANOVA	{"phone": "+70950607200"}
0005432747210	17548A	2817 660374	NATALYA KISELEVA	{"email": "kiseleva_natalya.17081974@postgrespro.ru", "phone": "+70513717072"}
0005432747211	EDF985	5838 916912	SVETLANA KRASNOVA	{"email": "krasnova.svetlana-051975@postgrespro.ru", "phone": "+70719194894"}
0005432747212	8F12EB	1247 852692	ANASTASIYA SMIRNOVA	{"email": "a_smirnova_29011978@postgrespro.ru", "phone": "+70579333615"}
0005432747213	8F12EB	7347 215072	EKATERINA IVANOVA	{"email": "e_ivanova.041969@postgrespro.ru", "phone": "+70340862922"}
0005432747214	0ED4AB	1306 652348	SERGEY ALEKSANDROV	{"email": "aleksandrov.sergey_1965@postgrespro.ru", "phone": "+70849295455"}
0005432747215	D13064	4438 432144	ANDREY GRIGOREV	{"email": "andrey.grigorev.1964@postgrespro.ru", "phone": "+70693147233"}
0005432747216	130203	8944 814617	SERGEY IVANOV	{"email": "ivanov.sergey.08091969@postgrespro.ru", "phone": "+70687201965"}
0005432747217	130203	8194 558785	DMITRIY SOROKIN	{"phone": "+70113236596"}
0005432747218	130203	4536 048755	NINA SAVELEVA	{"email": "nina_saveleva-1959@postgrespro.ru", "phone": "+70444866823"}
0005432747219	508847	6909 987325	LYUBOV ANDREEVA	{"phone": "+70103852139"}
0005432747220	144333	6294 240191	STANISLAV ISAEV	{"email": "s_isaev-1973@postgrespro.ru", "phone": "+70894181911"}
0005432747221	144333	3893 760636	OLGA VLASOVA	{"email": "olga.vlasova_101961@postgrespro.ru", "phone": "+70376310374"}
0005432747222	17CCB8	2769 488518	SVETLANA NIKIFOROVA	{"phone": "+70623321323"}
0005432747223	9B6958	2333 496062	GRIGORIY SOLOVEV	{"email": "g_solovev-1956@postgrespro.ru", "phone": "+70485083082"}
0005432747224	CBAE1C	9067 730171	OLGA ANDREEVA	{"phone": "+70523765835"}
0005432747225	1D8EA2	2741 287036	SERGEY SAVELEV	{"email": "sergey.savelev_18011967@postgrespro.ru", "phone": "+70247851104"}
0005432747226	1D8EA2	3297 007176	VASILIY CHERNOV	{"email": "vchernov-18081965@postgrespro.ru", "phone": "+70246762939"}
0005432747227	5D0CE1	8417 542909	KLAVDIYA MASLOVA	{"phone": "+70263748015"}
0005432747228	56AEB8	6406 176974	ELENA DAVYDOVA	{"phone": "+70225122544"}
0005432747229	130470	3385 583416	NINA GORBUNOVA	{"phone": "+70651625274"}
0005432747230	06B276	2175 029798	INNA NIKIFOROVA	{"email": "i-nikiforova_021978@postgrespro.ru", "phone": "+70154106493"}
0005432747231	189F0E	7993 018776	RUSLAN BELOV	{"phone": "+70432774694"}
0005432747232	9D3077	8966 294835	ANDREY PAVLOV	{"email": "pavlovandrey-25091978@postgrespro.ru", "phone": "+70256155995"}
0005432747233	8E6FDB	5046 069614	NIKOLAY TARASOV	{"email": "nikolaytarasov16041974@postgrespro.ru", "phone": "+70604446088"}
0005432747234	94A501	5660 841140	IRINA KUZNECOVA	{"phone": "+70949313247"}
0005432747235	2FA1B9	0782 265264	KIRILL TIKHONOV	{"email": "tikhonovk-031964@postgrespro.ru", "phone": "+70694767424"}
0005432747236	02EA32	1406 810194	MAKSIM SEMENOV	{"email": "semenovm_031977@postgrespro.ru", "phone": "+70671504685"}
0005432747237	FBFA4F	6762 746221	SOFYA TIKHONOVA	{"email": "sofyatikhonova-081985@postgrespro.ru", "phone": "+70601697257"}
0005432747238	49C540	7938 135158	KLAVDIYA IVANOVA	{"email": "ivanovaklavdiya.1957@postgrespro.ru", "phone": "+70312681303"}
0005432747239	D3A9D2	1498 674178	KIRILL IVANOV	{"phone": "+70997429195"}
0005432747240	F3C8D3	0250 781365	ANATOLIY VOLKOV	{"email": "volkov_anatoliy-041976@postgrespro.ru", "phone": "+70617628763"}
0005432748076	7D38E5	9717 776504	SERGEY ROMANOV	{"phone": "+70097115375"}
0005432747241	1FBC67	5717 424826	VALERIY ROMANOV	{"email": "valeriy_romanov_1972@postgrespro.ru", "phone": "+70683643531"}
0005432747242	B5EED8	2226 229712	NINA LEBEDEVA	{"email": "lebedeva_nina_1971@postgrespro.ru", "phone": "+70133528518"}
0005432747243	7F65BB	6204 709568	VALENTIN KONOVALOV	{"email": "valentin-konovalov1969@postgrespro.ru", "phone": "+70137893342"}
0005432747244	E1677F	9515 051348	GENNADIY NIKITIN	{"phone": "+70823529489"}
0005432747245	E1677F	3248 182983	EKATERINA ILINA	{"phone": "+70610553083"}
0005432747246	4CEBFC	9858 294358	NIKITA TIMOFEEV	{"phone": "+70163360037"}
0005432747247	39E221	7280 458764	MARK DAVYDOV	{"email": "davydov-mark-08101975@postgrespro.ru", "phone": "+70508551636"}
0005432747248	39E221	4751 583570	VALENTINA TIMOFEEVA	{"email": "timofeeva.valentina_08061992@postgrespro.ru", "phone": "+70633417985"}
0005432747249	0A0041	7847 304864	LYUDMILA POPOVA	{"email": "lpopova071973@postgrespro.ru", "phone": "+70570674698"}
0005432747250	4BF521	2131 568772	OLEG MAKAROV	{"phone": "+70099615302"}
0005432747251	4BF521	4688 540853	GALINA MELNIKOVA	{"phone": "+70332870397"}
0005432747252	92CFAB	0381 888768	ROMAN YAKOVLEV	{"email": "r.yakovlev_111971@postgrespro.ru", "phone": "+70448745303"}
0005432747253	8862C5	6820 881596	VALENTINA ALEKSEEVA	{"phone": "+70585001996"}
0005432747254	9B1541	8792 184641	SVETLANA ANDREEVA	{"email": "svetlana_andreeva_1964@postgrespro.ru", "phone": "+70261149246"}
0005432747255	83E3E6	3302 386060	YULIYA VLASOVA	{"email": "vlasovay-1972@postgrespro.ru", "phone": "+70349117818"}
0005432747256	83E3E6	6991 715740	SVETLANA ZAYCEVA	{"phone": "+70839841041"}
0005432747257	25DAF8	9175 184368	ALEKSEY ROMANOV	{"email": "alekseyromanov1964@postgrespro.ru", "phone": "+70279946530"}
0005432747258	0A6D3D	0422 985763	VALENTINA MOISEEVA	{"phone": "+70003347764"}
0005432747259	74A81E	7482 549615	OLGA EGOROVA	{"phone": "+70368310081"}
0005432747260	74A81E	6648 674765	VERA FILIPPOVA	{"email": "verafilippova-041966@postgrespro.ru", "phone": "+70670522693"}
0005432747261	6B6B62	2100 852145	NIKOLAY DAVYDOV	{"phone": "+70027458463"}
0005432747262	28E7FF	9173 439670	DANIL FEDOROV	{"phone": "+70984360185"}
0005432747263	28E7FF	2297 517368	MIKHAIL KOZLOV	{"email": "mikhail-kozlov-02071973@postgrespro.ru", "phone": "+70272594585"}
0005432747264	F56698	8720 569971	NINA KUZNECOVA	{"phone": "+70138869748"}
0005432747265	F56698	2058 280102	LARISA IVANOVA	{"phone": "+70764838692"}
0005432747266	46CDBB	4141 946364	ALEKSEY ABRAMOV	{"phone": "+70444573863"}
0005432747267	35E16F	7963 191987	SVETLANA KARPOVA	{"email": "karpova.s_021955@postgrespro.ru", "phone": "+70195799297"}
0005432747268	35E16F	1707 739515	VLADIMIR IVANOV	{"phone": "+70188908211"}
0005432747269	C65707	2309 232601	OLGA KUDRYASHOVA	{"phone": "+70926102941"}
0005432747270	1CB7FF	5924 939875	DENIS FEDOROV	{"email": "fedorov-denis-021976@postgrespro.ru", "phone": "+70317243681"}
0005432747271	0850ED	5846 903067	LYUDMILA GUSEVA	{"email": "l.guseva031976@postgrespro.ru", "phone": "+70830140730"}
0005432747272	189458	3856 700779	SVETLANA SERGEEVA	{"phone": "+70100174618"}
0005432747273	64A2DB	4390 011402	SERGEY MAKAROV	{"email": "makarov-sergey_04011978@postgrespro.ru", "phone": "+70610605955"}
0005432747274	775FA0	3031 334846	SVETLANA SOKOLOVA	{"email": "sokolovasvetlana-31121963@postgrespro.ru", "phone": "+70671749598"}
0005432747275	0A5330	6636 561825	NADEZHDA SOKOLOVA	{"phone": "+70120477170"}
0005432747276	F544FB	1451 236524	MAKSIM FILIPPOV	{"email": "maksim.filippov.27021977@postgrespro.ru", "phone": "+70979903046"}
0005432747277	A05E53	4238 007575	EGOR STEPANOV	{"phone": "+70755934108"}
0005432747278	835B9B	7584 604878	SVETLANA KOZLOVA	{"email": "s.kozlova-1971@postgrespro.ru", "phone": "+70610464259"}
0005432747279	4C534C	4465 875726	YULIYA KONDRATEVA	{"phone": "+70869834677"}
0005432747280	4C534C	4053 003277	ZINAIDA BORISOVA	{"email": "borisovaz081968@postgrespro.ru", "phone": "+70214158981"}
0005432747281	AA45B5	9517 927080	RUSTAM ROMANOV	{"email": "romanovr_17041978@postgrespro.ru", "phone": "+70813226487"}
0005432747282	AA45B5	0070 504704	YULIYA TROFIMOVA	{"phone": "+70477805993"}
0005432747283	C7D420	1100 042601	EVGENIY SCHERBAKOV	{"phone": "+70461870538"}
0005432747284	C7D420	3426 444249	LYUDMILA MEDVEDEVA	{"phone": "+70063352983"}
0005432747285	2A6B54	3329 640266	LIDIYA FILIPPOVA	{"email": "filippoval.061972@postgrespro.ru", "phone": "+70114616846"}
0005432747286	2A6B54	1898 864838	NIKITA EGOROV	{"email": "egorov-n-20021988@postgrespro.ru", "phone": "+70470489766"}
0005432747287	885D2E	4171 393103	DMITRIY KUZNECOV	{"phone": "+70067313807"}
0005432747288	2B9C87	8550 776834	LYUDMILA KONDRATEVA	{"phone": "+70026279700"}
0005432747289	5419D6	0483 411644	SERGEY BONDARENKO	{"email": "sergey-bondarenko_30081964@postgrespro.ru", "phone": "+70483190063"}
0005432747290	5419D6	6699 600496	KRISTINA DAVYDOVA	{"email": "k-davydova.1978@postgrespro.ru", "phone": "+70400787674"}
0005432747291	1C937B	3677 814922	ALEKSANDR MOISEEV	{"phone": "+70764727907"}
0005432747292	1C937B	3603 894819	VASILIY ABRAMOV	{"phone": "+70869984543"}
0005432747293	1C937B	5223 136799	ANNA PETROVA	{"phone": "+70862067806"}
0005432747294	F36CEA	7100 376068	ANDREY VOROBEV	{"email": "andrey.vorobev_041964@postgrespro.ru", "phone": "+70003432581"}
0005432747295	F36CEA	2170 511656	NELLI POPOVA	{"phone": "+70298736929"}
0005432747296	EFD873	7574 308700	DMITRIY SIDOROV	{"email": "d-sidorov_13071958@postgrespro.ru", "phone": "+70345609155"}
0005432747297	EFD873	7396 406821	VALENTINA KUZMINA	{"email": "kuzmina_v.28031964@postgrespro.ru", "phone": "+70488772602"}
0005432747298	761CC4	2511 072531	LYUDMILA KUZNECOVA	{"phone": "+70933269765"}
0005432747299	761CC4	2310 786054	ALEKSANDRA LAZAREVA	{"phone": "+70328340514"}
0005432747300	A95D1C	3028 287638	IRINA NIKITINA	{"phone": "+70602930327"}
0005432747301	A95D1C	4220 562747	SERGEY TIKHONOV	{"email": "sergeytikhonov_13011972@postgrespro.ru", "phone": "+70240798317"}
0005432747302	F91137	0187 652301	VYACHESLAV FILIPPOV	{"email": "vfilippov081964@postgrespro.ru", "phone": "+70977402563"}
0005432747303	3C344D	3996 182011	ELENA GAVRILOVA	{"phone": "+70751340813"}
0005432747304	3F6C7E	7244 902286	TATYANA AFANASEVA	{"phone": "+70207001522"}
0005432747305	B3E605	9989 478855	LEONID DMITRIEV	{"email": "l_dmitriev_051984@postgrespro.ru", "phone": "+70487247981"}
0005432747306	DCF3F5	2138 314140	IVAN KONOVALOV	{"phone": "+70987138262"}
0005432747307	DCF3F5	5774 182672	VALENTINA ZAYCEVA	{"email": "zaycevav-1975@postgrespro.ru", "phone": "+70704760515"}
0005432747308	FDF764	8938 381394	ANDREY VASILEV	{"email": "a-vasilev-24111965@postgrespro.ru", "phone": "+70564716331"}
0005432747309	116169	9746 741246	ANASTASIYA SCHERBAKOVA	{"email": "scherbakova-anastasiya-03111956@postgrespro.ru", "phone": "+70232811397"}
0005432747310	A88EAE	8132 345466	VLADIMIR PAVLOV	{"phone": "+70271296858"}
0005432747311	33F421	9485 774111	OLGA KUZMINA	{"phone": "+70490742612"}
0005432747312	19AE09	1224 567385	VALERIY VASILEV	{"phone": "+70646920475"}
0005432747313	19AE09	1914 839014	ALEKSANDR SAVELEV	{"phone": "+70191724277"}
0005432747314	19AE09	3002 422274	KLAVDIYA NAZAROVA	{"email": "klavdiya_nazarova1981@postgrespro.ru", "phone": "+70370744129"}
0005432747315	CDE1A9	2740 791987	ANASTASIYA MEDVEDEVA	{"email": "amedvedeva1959@postgrespro.ru", "phone": "+70592575463"}
0005432747316	CDE1A9	2108 787000	EDUARD VLASOV	{"phone": "+70484459586"}
0005432747317	CDE1A9	3327 223854	VIKTOR KUZNECOV	{"phone": "+70947181111"}
0005432747318	87A11B	5439 015223	ANZHELIKA KUZNECOVA	{"email": "kuznecova-a_1965@postgrespro.ru", "phone": "+70083414502"}
0005432747319	C2A11D	9825 003456	EKATERINA VASILEVA	{"phone": "+70473680124"}
0005432747320	B61EA0	8801 612276	ELENA EGOROVA	{"phone": "+70660112240"}
0005432747321	975AD4	4018 552697	MARINA KUZMINA	{"email": "marina-kuzmina.031966@postgrespro.ru", "phone": "+70095238981"}
0005432747322	37F272	3174 400706	ELENA OVCHINNIKOVA	{"phone": "+70234981726"}
0005432747323	37F272	8371 629442	ZULFIYA NIKITINA	{"email": "z-nikitina-1986@postgrespro.ru", "phone": "+70512529704"}
0005432747324	820510	5971 640286	ELENA KRASNOVA	{"email": "e-krasnova071977@postgrespro.ru", "phone": "+70359564503"}
0005432747325	820510	4240 858315	KSENIYA BOGDANOVA	{"phone": "+70026948886"}
0005432747326	820510	3270 043559	LIDIYA KULIKOVA	{"email": "kulikova-lidiya-041978@postgrespro.ru", "phone": "+70603905281"}
0005432747327	D11749	4443 611145	ANNA ZHUKOVA	{"phone": "+70448695454"}
0005432747328	D11749	1209 213912	VLADISLAV SIDOROV	{"phone": "+70825730639"}
0005432747329	1A6D79	0931 857329	MARIYA EGOROVA	{"email": "m_egorova_21011971@postgrespro.ru", "phone": "+70411333638"}
0005432747330	1B0E3D	4711 301086	VLADIMIR STEPANOV	{"phone": "+70723093821"}
0005432747331	968558	7116 516908	NIKOLAY TARASOV	{"email": "ntarasov_12031987@postgrespro.ru", "phone": "+70399918031"}
0005432747332	B30FD4	9879 316132	GALINA ZAKHAROVA	{"phone": "+70762685269"}
0005432747333	B30FD4	5463 400936	MARGARITA SAVELEVA	{"email": "m-saveleva.011971@postgrespro.ru", "phone": "+70807919146"}
0005432747334	58F4A3	9867 303497	VALENTINA NIKOLAEVA	{"email": "nikolaeva-valentina-071967@postgrespro.ru", "phone": "+70044863423"}
0005432747335	C93198	0302 793825	VLADIMIR FROLOV	{"phone": "+70353191219"}
0005432747336	B02C35	0016 891564	PETR GAVRILOV	{"email": "gavrilov_p30071952@postgrespro.ru", "phone": "+70074008835"}
0005432747337	51E863	2513 557625	ILYA YAKOVLEV	{"email": "yakovlev_i09021970@postgrespro.ru", "phone": "+70996258863"}
0005432747338	51E863	2919 180162	SERGEY PETROV	{"email": "sergey-petrov-07101976@postgrespro.ru", "phone": "+70179364294"}
0005432747339	982AE9	1235 928888	TATYANA ANTONOVA	{"email": "tatyana_antonova.021976@postgrespro.ru", "phone": "+70679465632"}
0005432747340	EC25DD	0050 645578	VARVARA MALYSHEVA	{"phone": "+70352360939"}
0005432747341	D72C78	1652 602252	ANNA VASILEVA	{"phone": "+70359582346"}
0005432747342	FE6200	0182 781280	VLADIMIR KISELEV	{"email": "kiselevvladimir10011974@postgrespro.ru", "phone": "+70363085633"}
0005432747343	DFA488	5825 702437	OLGA BARANOVA	{"phone": "+70616629591"}
0005432747344	DFA488	9373 931066	GALINA SERGEEVA	{"phone": "+70072767555"}
0005432747345	E31654	1045 948716	ELENA PETROVA	{"phone": "+70986764152"}
0005432747346	9007CC	4708 196444	OLGA ANDREEVA	{"phone": "+70994429374"}
0005432747347	DE14E4	3605 845315	ROMAN YAKOVLEV	{"phone": "+70781211310"}
0005432747348	B06159	8136 439235	VALENTINA KUDRYASHOVA	{"phone": "+70337125351"}
0005432747349	8D4F8E	4022 050967	NIKOLAY IVANOV	{"email": "ivanovn_1977@postgrespro.ru", "phone": "+70586402650"}
0005432747350	7F1964	6436 580763	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a_1967@postgrespro.ru", "phone": "+70146381061"}
0005432747351	7F1964	1958 815125	LYUDMILA SIDOROVA	{"phone": "+70411331421"}
0005432747352	44E39B	8331 915896	VIKTOR VASILEV	{"email": "vasilev-v.1988@postgrespro.ru", "phone": "+70484041884"}
0005432747353	1EA35D	2133 400076	ANATOLIY BORISOV	{"email": "a_borisov.1963@postgrespro.ru", "phone": "+70848578558"}
0005432747354	D6AC56	2181 537404	DANIIL PAVLOV	{"phone": "+70705920951"}
0005432747355	D6AC56	7664 342976	ELENA ZAKHAROVA	{"phone": "+70409553760"}
0005432747356	5230B9	1834 574113	GALINA SOROKINA	{"email": "gsorokina_12041972@postgrespro.ru", "phone": "+70489865068"}
0005432747357	5230B9	9170 039287	OLGA PETROVA	{"phone": "+70976126003"}
0005432747358	FCF039	9776 050893	ANNA KOZLOVA	{"email": "kozlova.a.021985@postgrespro.ru", "phone": "+70839578493"}
0005432747359	FCF039	5984 217539	ALEKSANDR GRIGOREV	{"phone": "+70755332186"}
0005432747360	A8EDB1	6758 978946	IVAN GRIGOREV	{"email": "ivangrigorev-22081983@postgrespro.ru", "phone": "+70501885435"}
0005432747361	A8EDB1	3184 397745	OLGA SMIRNOVA	{"phone": "+70519612922"}
0005432747362	C30587	5583 765947	POLINA KISELEVA	{"phone": "+70776511230"}
0005432747363	81348C	3726 925664	TATYANA POPOVA	{"phone": "+70066607203"}
0005432747364	FF2500	2414 628879	KONSTANTIN VASILEV	{"email": "vasilevk.1975@postgrespro.ru", "phone": "+70754577886"}
0005432747365	FF2500	1624 781629	LYUDMILA ANISIMOVA	{"email": "anisimova-lyudmila-061977@postgrespro.ru", "phone": "+70124989268"}
0005432747366	FF1013	0020 656178	ALEKSANDR VASILEV	{"email": "vasilev.a.1976@postgrespro.ru", "phone": "+70899335371"}
0005432747367	E1FFC9	7153 024392	VASILIY KUZNECOV	{"phone": "+70154377269"}
0005432747368	9325A9	5207 703171	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov1965@postgrespro.ru", "phone": "+70202177136"}
0005432747369	DE5B8B	6658 967769	LILIYA PAVLOVA	{"phone": "+70312978193"}
0005432747370	DE5B8B	4226 478740	LIDIYA NAUMOVA	{"email": "naumova-l.16081973@postgrespro.ru", "phone": "+70537481245"}
0005432747371	DE5B8B	5431 464778	GRIGORIY MIRONOV	{"phone": "+70238786155"}
0005432747372	DE5B8B	9766 011985	SERGEY BORISOV	{"phone": "+70868829126"}
0005432747373	2FE9AA	1411 962818	IVAN ZAYCEV	{"email": "ivan.zaycev-071969@postgrespro.ru", "phone": "+70573323242"}
0005432747374	2C439D	4960 168597	IGOR DENISOV	{"phone": "+70426226079"}
0005432747375	3A0219	4822 695548	ALINA YUDINA	{"phone": "+70798590694"}
0005432747376	6722CF	7752 360074	TATYANA MEDVEDEVA	{"phone": "+70184171897"}
0005432747377	6722CF	5943 180330	DARYA GORBUNOVA	{"email": "d-gorbunova1977@postgrespro.ru", "phone": "+70687433902"}
0005432747378	71ACC8	3203 562645	ELIZAVETA BOGDANOVA	{"email": "elizaveta.bogdanova1981@postgrespro.ru", "phone": "+70327843075"}
0005432747379	F92818	1800 127717	TATYANA KRASNOVA	{"phone": "+70536630628"}
0005432747380	AAFBE0	1842 764405	VALENTINA KOMAROVA	{"email": "komarovavalentina.01041968@postgrespro.ru", "phone": "+70598073579"}
0005432747381	77B835	1844 456483	DENIS STEPANOV	{"phone": "+70796875786"}
0005432747382	77B835	4578 076278	ARTUR MOROZOV	{"phone": "+70065049870"}
0005432747383	C2BB97	9555 634611	ANATOLIY GRIGOREV	{"email": "agrigorev_1972@postgrespro.ru", "phone": "+70940931592"}
0005432747384	76AE4E	2227 451079	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr16051970@postgrespro.ru", "phone": "+70502233774"}
0005432747385	128F5A	1380 037782	VLADIMIR MOISEEV	{"email": "v_moiseev1963@postgrespro.ru", "phone": "+70087114949"}
0005432747386	124093	6078 179576	GALINA VOROBEVA	{"phone": "+70951266491"}
0005432747387	DBA45B	1323 539821	SVETLANA DAVYDOVA	{"email": "davydova_svetlana-1968@postgrespro.ru", "phone": "+70685972047"}
0005432747388	DA7CCD	2052 156349	MIKHAIL ANDREEV	{"phone": "+70124490922"}
0005432747389	DA7CCD	3963 871817	RAISA ORLOVA	{"email": "raisa.orlova041973@postgrespro.ru", "phone": "+70770985257"}
0005432747390	AC9886	4923 934878	SERGEY SOROKIN	{"phone": "+70382428202"}
0005432747391	AC9886	3267 424886	NADEZHDA LEBEDEVA	{"phone": "+70220195427"}
0005432747392	703744	6329 508122	FARIDA OVCHINNIKOVA	{"phone": "+70118975767"}
0005432747393	B2060E	3310 101945	NINA BELYAEVA	{"phone": "+70608319088"}
0005432747394	306C96	8346 992897	NAIL OSIPOV	{"email": "nosipov-23061965@postgrespro.ru", "phone": "+70773642810"}
0005432747395	2001A4	6117 623387	ALEKSANDR GUSEV	{"email": "a_gusev-051974@postgrespro.ru", "phone": "+70527595116"}
0005432747396	C7FF67	1116 783324	VALENTINA OVCHINNIKOVA	{"phone": "+70477359162"}
0005432747397	95BA91	3275 353766	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr_1961@postgrespro.ru", "phone": "+70444440161"}
0005432747398	461F11	9348 636453	RAVILYA ROMANOVA	{"phone": "+70153955085"}
0005432747399	461F11	5622 047731	LIDIYA ZHURAVLEVA	{"email": "lidiya-zhuravleva1971@postgrespro.ru", "phone": "+70697563268"}
0005432747400	DAAD1B	8854 660971	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov041971@postgrespro.ru", "phone": "+70023197227"}
0005432747401	DAAD1B	4283 563465	GENNADIY SMIRNOV	{"email": "smirnov.g-26031975@postgrespro.ru", "phone": "+70009160167"}
0005432747402	622516	9758 215822	KSENIYA SERGEEVA	{"phone": "+70332027159"}
0005432747403	A16868	4856 069255	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev1979@postgrespro.ru", "phone": "+70307639160"}
0005432747404	32CB2E	2024 441559	SVETLANA VASILEVA	{"phone": "+70233456750"}
0005432747405	32CB2E	2439 322495	EVGENIY KUZNECOV	{"phone": "+70556546629"}
0005432747406	2E2756	0761 026287	YULIYA MOISEEVA	{"email": "y_moiseeva_21021969@postgrespro.ru", "phone": "+70880175939"}
0005432747407	048B5C	8748 105357	TATYANA CHERNOVA	{"phone": "+70343705760"}
0005432747408	ACAE4A	7567 505342	ALEKSEY DAVYDOV	{"email": "aleksey-davydov27081974@postgrespro.ru", "phone": "+70299922376"}
0005432747409	ACAE4A	7395 997108	LYUDMILA KOZLOVA	{"email": "lyudmila.kozlova20111983@postgrespro.ru", "phone": "+70425792727"}
0005432747410	61213D	0287 812175	YURIY ZHURAVLEV	{"email": "yuriy_zhuravlev.04051971@postgrespro.ru", "phone": "+70650574888"}
0005432747411	4BFFF6	9998 496323	EVGENIYA IVANOVA	{"phone": "+70480635540"}
0005432747412	4BFFF6	5675 498795	LYUBOV GAVRILOVA	{"phone": "+70623355148"}
0005432747413	4BFFF6	8130 103562	ALEKSEY IVANOV	{"phone": "+70336376947"}
0005432747414	92D8DD	5531 141783	OLGA MIRONOVA	{"email": "o.mironova.26011978@postgrespro.ru", "phone": "+70143135666"}
0005432747415	92D8DD	0751 211800	VLADIMIR KUZNECOV	{"email": "v-kuznecov031973@postgrespro.ru", "phone": "+70344486553"}
0005432747416	307C4D	3729 251758	NADEZHDA ZHURAVLEVA	{"phone": "+70449926002"}
0005432747417	307C4D	0635 450985	ANASTASIYA MATVEEVA	{"phone": "+70529310236"}
0005432747418	BED47D	4160 685980	SVETLANA MELNIKOVA	{"email": "s.melnikova_071967@postgrespro.ru", "phone": "+70034922667"}
0005432747419	BED47D	6610 467073	MARGARITA DENISOVA	{"email": "denisova-m.061968@postgrespro.ru", "phone": "+70363111052"}
0005432747420	BED47D	6694 757253	SVETLANA KUZNECOVA	{"email": "skuznecova-101986@postgrespro.ru", "phone": "+70121353066"}
0005432747421	DDABD7	9734 727156	NATALYA TROFIMOVA	{"email": "trofimovan_21111972@postgrespro.ru", "phone": "+70735020562"}
0005432747422	732DFC	8156 607435	GALINA GERASIMOVA	{"email": "gerasimovag1982@postgrespro.ru", "phone": "+70772764967"}
0005432747423	8391EE	9454 406645	IVAN KUZNECOV	{"email": "kuznecov.ivan1987@postgrespro.ru", "phone": "+70235667666"}
0005432747424	486FFE	6963 975851	GEVORG ANTONOV	{"email": "gevorg_antonov_10121963@postgrespro.ru", "phone": "+70167755564"}
0005432747425	486FFE	3858 405548	VLADISLAV PAVLOV	{"phone": "+70464071086"}
0005432747426	D705C5	0833 384380	MARIYA FADEEVA	{"phone": "+70964526590"}
0005432747427	D705C5	9017 739524	ARTEM YAKOVLEV	{"phone": "+70181330046"}
0005432747428	62134A	1265 191820	RUSLAN VOLKOV	{"email": "ruslan.volkov_111971@postgrespro.ru", "phone": "+70375028165"}
0005432747429	70FCA4	6422 802526	VLADIMIR SERGEEV	{"email": "sergeev_vladimir.24021977@postgrespro.ru", "phone": "+70216389094"}
0005432747430	721D82	0172 076358	MAKSIM OSIPOV	{"phone": "+70869085041"}
0005432747431	0F83F5	4572 674110	VIKTOR PAVLOV	{"email": "pavlov-viktor1969@postgrespro.ru", "phone": "+70871329019"}
0005432747432	0F83F5	0382 912857	GALINA NAUMOVA	{"email": "galinanaumova.1964@postgrespro.ru", "phone": "+70077838011"}
0005432747433	6E71B9	7994 378760	VALENTINA STEPANOVA	{"email": "stepanova-v-26111967@postgrespro.ru", "phone": "+70926314194"}
0005432747434	FB7CE7	0867 354197	VALENTINA GERASIMOVA	{"email": "valentina-gerasimova-081976@postgrespro.ru", "phone": "+70318017164"}
0005432747435	FB7CE7	7620 892864	NINA KOVALEVA	{"email": "nina_kovaleva.111971@postgrespro.ru", "phone": "+70093721497"}
0005432747436	13451C	9084 616559	ANTONINA ZOTOVA	{"email": "antonina.zotova24051977@postgrespro.ru", "phone": "+70525384758"}
0005432747437	E24FCB	2811 372273	YULIYA PETROVA	{"phone": "+70614625801"}
0005432747438	E24FCB	8570 835129	SVETLANA OSIPOVA	{"email": "svetlana-osipova21071956@postgrespro.ru", "phone": "+70607444232"}
0005432747439	55BC59	3979 976975	ALEKSANDR TIMOFEEV	{"phone": "+70064099024"}
0005432747440	4E3BF3	8856 722426	OLGA ISAEVA	{"email": "olga.isaeva1966@postgrespro.ru", "phone": "+70973052363"}
0005432747441	5105A3	8192 708053	VIKTOR PETROV	{"phone": "+70671031640"}
0005432747442	4C834F	1825 696520	DARYA IVANOVA	{"email": "darya-ivanova08081960@postgrespro.ru", "phone": "+70406416247"}
0005432747443	E2232B	2196 874110	ALEVTINA TIMOFEEVA	{"email": "a-timofeeva091972@postgrespro.ru", "phone": "+70280658233"}
0005432747444	15E7A9	0477 516632	TATYANA TIKHONOVA	{"email": "tatyana-tikhonova.28011966@postgrespro.ru", "phone": "+70333880209"}
0005432747445	15E7A9	3754 760915	OKSANA MATVEEVA	{"email": "omatveeva.04101970@postgrespro.ru", "phone": "+70545235240"}
0005432747446	EC1D60	8010 407887	ANDREY ANTONOV	{"email": "antonov.a_081970@postgrespro.ru", "phone": "+70369140143"}
0005432747447	EC1D60	5665 157352	VALERIYA LOGINOVA	{"phone": "+70786600139"}
0005432747448	895F88	1209 041604	ELENA ROMANOVA	{"email": "elenaromanova.011984@postgrespro.ru", "phone": "+70081276779"}
0005432747449	4C8F6F	6658 441685	MIKHAIL MAKAROV	{"phone": "+70961894100"}
0005432747450	4C8F6F	4732 679456	VASILIY TARASOV	{"email": "tarasovvasiliy1969@postgrespro.ru", "phone": "+70382395601"}
0005432747451	F25C18	3734 759168	GALINA TIMOFEEVA	{"email": "timofeeva.g_1968@postgrespro.ru", "phone": "+70026640198"}
0005432747452	EFA125	1283 247997	MARIYA MAKAROVA	{"email": "makarova_m.121977@postgrespro.ru", "phone": "+70779784601"}
0005432747453	EFA125	8313 039131	MIKHAIL ISAEV	{"phone": "+70664639392"}
0005432747454	BED473	2904 457137	VLADIMIR SIDOROV	{"phone": "+70476845533"}
0005432747455	6DE261	7735 217198	TATYANA DENISOVA	{"phone": "+70666442705"}
0005432747456	AA9C3B	1709 139633	NIKOLAY KISELEV	{"phone": "+70869044788"}
0005432747457	677C2D	8022 784080	OLEG BONDARENKO	{"phone": "+70498069982"}
0005432747458	7E5E8B	9162 692686	SVETLANA ISAEVA	{"email": "isaeva_s.18101972@postgrespro.ru", "phone": "+70913728101"}
0005432747459	7E5E8B	2193 330031	LYUBOV PETROVA	{"email": "petrova_lyubov.13031966@postgrespro.ru", "phone": "+70358003942"}
0005432747460	D06D07	8386 118431	ANDREY MELNIKOV	{"phone": "+70204982074"}
0005432747461	C643DF	8453 188471	ANASTASIYA FADEEVA	{"email": "fadeeva-a_24061973@postgrespro.ru", "phone": "+70695936612"}
0005432747462	BB635F	5987 659104	VERA KONDRATEVA	{"email": "verakondrateva_101970@postgrespro.ru", "phone": "+70192322374"}
0005432748077	D047D8	5855 164009	NINA ROMANOVA	{"phone": "+70072510410"}
0005432747463	908CF6	2698 878320	OLGA EFIMOVA	{"email": "o_efimova_071969@postgrespro.ru", "phone": "+70926775500"}
0005432747464	5E37B0	9094 956227	LILIYA NIKITINA	{"phone": "+70353136371"}
0005432747465	5596AB	7299 726527	ELENA FOMINA	{"email": "fomina_elena_1971@postgrespro.ru", "phone": "+70396413074"}
0005432747466	5596AB	9476 017552	TATYANA CHERNOVA	{"email": "chernova-t.1980@postgrespro.ru", "phone": "+70676355209"}
0005432747467	FAA7ED	4161 455382	ANNA VOLKOVA	{"phone": "+70729096749"}
0005432747468	1F2BAC	2392 976024	ELMIRA SAVELEVA	{"email": "e_saveleva1973@postgrespro.ru", "phone": "+70816120267"}
0005432747469	158DCC	7965 764094	DINARA POPOVA	{"email": "popovad.031984@postgrespro.ru", "phone": "+70370690495"}
0005432747470	D5490B	5299 798613	ANASTASIYA POPOVA	{"phone": "+70552278458"}
0005432747471	C5B490	2811 672398	ANNA SCHERBAKOVA	{"email": "a.scherbakova.03011974@postgrespro.ru", "phone": "+70755814383"}
0005432747472	791DAD	9649 823102	NATALIYA SIDOROVA	{"phone": "+70903713226"}
0005432747473	0B4206	7893 000278	MARINA SCHERBAKOVA	{"phone": "+70747093388"}
0005432747474	6AF423	5636 645033	MARINA FEDOROVA	{"email": "fedorova_m-021984@postgrespro.ru", "phone": "+70600570562"}
0005432747475	6AF423	8024 348899	VLADIMIR BELOV	{"phone": "+70092031355"}
0005432747476	A5CA3D	8408 862368	ALEKSANDR SOROKIN	{"phone": "+70231107454"}
0005432747477	F79EDE	9514 611637	ELIZAVETA KAZAKOVA	{"phone": "+70036013004"}
0005432747478	2DC6A4	9704 402997	ALENA ANDREEVA	{"email": "aandreeva.23111972@postgrespro.ru", "phone": "+70602432730"}
0005432747479	2DC6A4	3879 076427	DIANA KUZNECOVA	{"phone": "+70719782955"}
0005432747480	3B746B	7344 291212	VLADIMIR VOLKOV	{"email": "vladimir-volkov.111956@postgrespro.ru", "phone": "+70152071999"}
0005432747481	74000D	3599 100046	ELENA ALEKSANDROVA	{"email": "aleksandrovae-1964@postgrespro.ru", "phone": "+70091631771"}
0005432747482	EE14C5	4705 458273	VALERIYA ALEKSANDROVA	{"email": "aleksandrova-valeriya051973@postgrespro.ru", "phone": "+70722727641"}
0005432747483	3639CA	7098 444224	ALEKSANDR NOVIKOV	{"email": "anovikov_011963@postgrespro.ru", "phone": "+70080594283"}
0005432747484	F4F869	5492 012466	ALEKSANDR VOLKOV	{"email": "volkova13081968@postgrespro.ru", "phone": "+70055010265"}
0005432747485	1937E8	0258 600018	ALEKSANDR SOLOVEV	{"phone": "+70725317988"}
0005432747486	3E13BB	2591 590908	TATYANA RODIONOVA	{"phone": "+70635460514"}
0005432747487	491AA9	6919 133317	TATYANA IVANOVA	{"email": "tatyanaivanova_24021965@postgrespro.ru", "phone": "+70273248691"}
0005432747488	494433	9636 792688	VALENTINA ANDREEVA	{"phone": "+70650256044"}
0005432747489	494433	1453 281204	ALLA BOGDANOVA	{"email": "a_bogdanova_021968@postgrespro.ru", "phone": "+70312200146"}
0005432747490	6B1895	7501 929829	VIKTOR KUDRYASHOV	{"email": "v.kudryashov091975@postgrespro.ru", "phone": "+70169684558"}
0005432747491	6B1895	6800 891741	SERGEY BELOV	{"phone": "+70741811814"}
0005432747492	FD54A2	2308 977834	NATALYA KUZNECOVA	{"phone": "+70983768290"}
0005432747493	FD54A2	9615 898979	ALEKSANDR KARPOV	{"email": "a_karpov-24051972@postgrespro.ru", "phone": "+70477573447"}
0005432747494	5C07CA	6385 690965	MATVEY GUSEV	{"email": "m_gusev-061968@postgrespro.ru", "phone": "+70252373215"}
0005432747495	5C07CA	7936 823468	PETR SOLOVEV	{"email": "solovev_petr1974@postgrespro.ru", "phone": "+70866280315"}
0005432747496	5C07CA	9531 827067	NIKOLAY VOLKOV	{"phone": "+70189337953"}
0005432747497	D4F9F0	8608 334122	TATYANA KUZMINA	{"phone": "+70297520566"}
0005432747498	97F172	7484 853396	FARIDA OSIPOVA	{"email": "faridaosipova06111963@postgrespro.ru", "phone": "+70322894383"}
0005432747499	8351A3	4765 443591	IVAN SCHERBAKOV	{"email": "scherbakov.ivan.071975@postgrespro.ru", "phone": "+70207143190"}
0005432747500	8351A3	8427 428798	NINA SIDOROVA	{"email": "nina_sidorova.29101979@postgrespro.ru", "phone": "+70688022370"}
0005432747501	8351A3	8001 456363	INNA KOROLEVA	{"email": "korolevai-26081982@postgrespro.ru", "phone": "+70785611941"}
0005432747502	B59D0C	9294 853382	ELENA ANTONOVA	{"phone": "+70197308931"}
0005432747503	B59D0C	8052 346553	ALEKSEY STEPANOV	{"phone": "+70277286214"}
0005432747504	2326B6	4676 920710	TATYANA ZAYCEVA	{"phone": "+70125033329"}
0005432747505	B814F9	8745 370541	VLADIMIR SHEVCHENKO	{"phone": "+70449804437"}
0005432747506	951269	5683 562805	OKSANA ZAKHAROVA	{"email": "zakharova_o_12041978@postgrespro.ru", "phone": "+70755192763"}
0005432747507	9FDDE6	0555 250587	KARINA SEMENOVA	{"email": "semenova.karina.1967@postgrespro.ru", "phone": "+70314378993"}
0005432747508	8803E1	4583 601133	POLINA KUZNECOVA	{"email": "kuznecova_polina1969@postgrespro.ru", "phone": "+70039006495"}
0005432747509	8803E1	3920 473744	MARAT KUZNECOV	{"email": "kuznecov_m-1982@postgrespro.ru", "phone": "+70413742664"}
0005432747510	62C8E0	8923 841139	LYUDMILA IVANOVA	{"phone": "+70386046905"}
0005432747511	B89718	3892 545420	LYUDMILA DAVYDOVA	{"email": "l-davydova-10031970@postgrespro.ru", "phone": "+70924182492"}
0005432747512	B89718	0105 300793	NATALYA GRISHINA	{"email": "grishina-n_111980@postgrespro.ru", "phone": "+70851770207"}
0005432747513	D9A4DB	2207 694786	VLADISLAV SMIRNOV	{"email": "v_smirnov1976@postgrespro.ru", "phone": "+70215651101"}
0005432747514	C222DF	1669 573441	ILNAR ISAEV	{"phone": "+70887572236"}
0005432747515	C222DF	3180 529128	IVAN RODIONOV	{"phone": "+70960935910"}
0005432747516	83F092	4287 228330	LILIYA SOKOLOVA	{"phone": "+70078522275"}
0005432747517	8205AC	6214 002787	RAISA MELNIKOVA	{"phone": "+70903051313"}
0005432747518	8EB1D8	3698 721802	YURIY KAZAKOV	{"email": "kazakovy-081970@postgrespro.ru", "phone": "+70288016095"}
0005432747519	26D98E	5918 059084	SVETLANA KULIKOVA	{"email": "s-kulikova_071972@postgrespro.ru", "phone": "+70490452750"}
0005432747520	B82C8C	5045 855214	ASKHAT KOZLOV	{"phone": "+70553792608"}
0005432747521	C2E245	2625 203197	ROMAN NOVIKOV	{"email": "roman_novikov_16061978@postgrespro.ru", "phone": "+70802918656"}
0005432747522	CB6D9C	4527 583805	KONSTANTIN KUZNECOV	{"phone": "+70837966296"}
0005432747523	C2DE78	2697 343979	VALENTINA IVANOVA	{"phone": "+70490483142"}
0005432747524	685E2F	1478 167024	GRIGORIY KAZAKOV	{"email": "grigoriykazakov03091974@postgrespro.ru", "phone": "+70313885300"}
0005432747525	7187B9	9572 629735	VASILIY PAVLOV	{"phone": "+70444992182"}
0005432747526	986116	1198 974983	ANNA NIKIFOROVA	{"phone": "+70620478758"}
0005432747527	E359A2	3669 071161	PETR IVANOV	{"email": "petr.ivanov_1979@postgrespro.ru", "phone": "+70220113846"}
0005432747528	9BDE4E	5495 384698	SERGEY ILIN	{"phone": "+70911121488"}
0005432747529	9BDE4E	1046 578616	ALEKSEY IVANOV	{"email": "alekseyivanov.071970@postgrespro.ru", "phone": "+70042169332"}
0005432747530	826FDF	8332 526289	PAVEL BELOV	{"email": "pbelov-12021975@postgrespro.ru", "phone": "+70748762067"}
0005432747531	B7B99C	2254 916530	VADIM NAUMOV	{"email": "v-naumov-061981@postgrespro.ru", "phone": "+70811754190"}
0005432747532	5305E0	3526 743350	MAYYA OSIPOVA	{"email": "m_osipova_31121970@postgrespro.ru", "phone": "+70917727015"}
0005432747533	5305E0	6170 150635	ANATOLIY DENISOV	{"email": "a_denisov_1965@postgrespro.ru", "phone": "+70922025048"}
0005432747534	287F21	1772 742110	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr.121986@postgrespro.ru", "phone": "+70388853280"}
0005432747535	A4835B	3675 033071	YAROSLAV ISAEV	{"phone": "+70419921466"}
0005432747536	C09F3B	7118 531419	ANDREY FILIPPOV	{"email": "andrey.filippov27051963@postgrespro.ru", "phone": "+70611106359"}
0005432747537	1562F1	5103 343351	VALENTINA AKIMOVA	{"phone": "+70359229253"}
0005432747538	7B8960	9949 477083	ALEKSANDR DAVYDOV	{"email": "aleksandr_davydov-1972@postgrespro.ru", "phone": "+70362849133"}
0005432747539	7B8960	6886 552078	KSENIYA CHERNOVA	{"phone": "+70261601570"}
0005432747540	7B8960	2748 069426	ALEKSEY POPOV	{"phone": "+70781094144"}
0005432747541	AC73AF	5859 188401	IGOR MATVEEV	{"email": "matveevi.041977@postgrespro.ru", "phone": "+70078491181"}
0005432747542	172054	6858 721601	VIKTOR KUZNECOV	{"email": "kuznecov_v-1968@postgrespro.ru", "phone": "+70813592620"}
0005432747543	172054	7968 895645	NINA ALEKSEEVA	{"phone": "+70910445072"}
0005432747544	023FF1	6563 252185	ALEKSANDR KUZNECOV	{"phone": "+70572288275"}
0005432747545	1C814A	7834 467419	VERA KOZLOVA	{"email": "kozlova.v.071973@postgrespro.ru", "phone": "+70250906513"}
0005432747546	1C814A	5499 786540	ELENA KULIKOVA	{"phone": "+70054801559"}
0005432747547	B93F7E	6745 570525	PETR NIKITIN	{"email": "nikitin-petr.1967@postgrespro.ru", "phone": "+70467657701"}
0005432747548	F8C40B	8794 494120	IRINA KISELEVA	{"email": "i-kiseleva_1978@postgrespro.ru", "phone": "+70247920508"}
0005432747549	6FE177	2545 978179	ANATOLIY SOKOLOV	{"phone": "+70308473624"}
0005432747550	74552D	4614 573725	NINA NIKITINA	{"email": "nikitina-n1968@postgrespro.ru", "phone": "+70536095536"}
0005432747551	74552D	1605 895118	ALEKSANDR ZAKHAROV	{"phone": "+70206592824"}
0005432747552	0C2FB6	6166 554444	ALEKSANDR MATVEEV	{"phone": "+70312194979"}
0005432747553	0C2FB6	4809 633330	VALENTINA STEPANOVA	{"phone": "+70565960610"}
0005432747554	6C21BC	0561 292938	IRINA KULIKOVA	{"email": "ikulikova.17071973@postgrespro.ru", "phone": "+70138568081"}
0005432747555	CFCE14	9520 049031	VALENTINA PAVLOVA	{"email": "pavlova-valentina_111979@postgrespro.ru", "phone": "+70750455648"}
0005432747556	CFCE14	4020 120106	RAIS ALEKSEEV	{"phone": "+70061499191"}
0005432747557	CFCE14	5277 296757	ZOYA DANILOVA	{"phone": "+70232323412"}
0005432747558	7911EE	7162 234813	MARINA AKIMOVA	{"email": "akimovamarina08061972@postgrespro.ru", "phone": "+70839577887"}
0005432747559	659983	1746 381350	GULNARA KUZNECOVA	{"email": "kuznecova-g_1981@postgrespro.ru", "phone": "+70142609227"}
0005432747560	659983	3026 393447	EKATERINA ABRAMOVA	{"phone": "+70445336678"}
0005432747561	185308	0328 899356	DMITRIY MELNIKOV	{"phone": "+70854548098"}
0005432747562	3F02A0	7876 725326	PETR YAKOVLEV	{"phone": "+70546222203"}
0005432747563	71FE9D	2609 399750	VALERIY ANDREEV	{"phone": "+70098238597"}
0005432747564	3BD84B	4279 083587	ALEKSEY IVANOV	{"phone": "+70055573272"}
0005432747565	17E6C3	8328 722445	NIKOLAY KISELEV	{"email": "nkiselev.1973@postgrespro.ru", "phone": "+70932275942"}
0005432747566	96D0BB	6282 544686	LIDIYA POPOVA	{"phone": "+70578861803"}
0005432747567	96D0BB	1239 804535	MARIYA VLASOVA	{"email": "vlasovam11051973@postgrespro.ru", "phone": "+70088061735"}
0005432747568	629B47	4779 252129	ANGELINA PETROVA	{"phone": "+70360014717"}
0005432747569	91DFA5	2900 604934	ALEKSANDR KISELEV	{"email": "kiselev-a.1965@postgrespro.ru", "phone": "+70458922506"}
0005432747570	91DFA5	3140 205954	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova.03051972@postgrespro.ru", "phone": "+70148824943"}
0005432747571	0016BD	4670 079390	GENNADIY MAKAROV	{"email": "gmakarov-011968@postgrespro.ru", "phone": "+70605127843"}
0005432747572	3B498C	7801 759742	VASILIY SERGEEV	{"email": "sergeev_vasiliy.05091962@postgrespro.ru", "phone": "+70182284691"}
0005432747573	8F47AF	6038 426302	GLEB ZAYCEV	{"phone": "+70335107846"}
0005432747574	5DE2F4	0744 124400	LYUBOV EGOROVA	{"phone": "+70147407409"}
0005432748301	B49A89	9945 499508	GENNADIY ROMANOV	{"phone": "+70314609480"}
0005432747575	B3F0B7	0924 252658	NADEZHDA MAKAROVA	{"email": "makarova.n101966@postgrespro.ru", "phone": "+70652047145"}
0005432747576	B3F0B7	0587 190343	ZHANNA POPOVA	{"phone": "+70448850025"}
0005432747577	254CCF	2231 073624	RAVILYA MELNIKOVA	{"email": "melnikovar_1973@postgrespro.ru", "phone": "+70869005813"}
0005432747578	254CCF	8401 352741	NIKOLAY KOZLOV	{"phone": "+70437675461"}
0005432747579	254CCF	0899 050364	SVETLANA SOROKINA	{"email": "ssorokina.1963@postgrespro.ru", "phone": "+70602781085"}
0005432747580	F0F5BD	8571 173674	KSENIYA PETROVA	{"email": "kseniyapetrova-1963@postgrespro.ru", "phone": "+70347147998"}
0005432747581	1D74D5	1691 058959	NATALYA MAKAROVA	{"email": "makarova_n-121956@postgrespro.ru", "phone": "+70963867443"}
0005432747582	1D74D5	7164 714262	VLADIMIR KUDRYASHOV	{"phone": "+70851449686"}
0005432747583	1D74D5	0430 266213	DENIS ZAKHAROV	{"phone": "+70896251724"}
0005432747584	7E8353	0104 583078	DANIIL MAKSIMOV	{"email": "d_maksimov.1963@postgrespro.ru", "phone": "+70225583873"}
0005432747585	6EB1FB	4867 126948	VLADIMIR VLASOV	{"phone": "+70198409875"}
0005432747586	6EB1FB	5201 913583	VALERIY GORBUNOV	{"phone": "+70123005742"}
0005432747587	3DE40F	6557 183035	SERGEY VOLKOV	{"phone": "+70164319172"}
0005432747588	AC2D3D	5947 881557	EVGENIY MELNIKOV	{"email": "e_melnikov.11041961@postgrespro.ru", "phone": "+70780270533"}
0005432747589	AC2D3D	0577 503931	IVAN GRIGOREV	{"phone": "+70783835781"}
0005432747590	AC2D3D	8195 878959	YURIY NOVIKOV	{"email": "y_novikov021968@postgrespro.ru", "phone": "+70938905496"}
0005432747591	61B2C7	8124 515810	ANNA GUSEVA	{"phone": "+70875424972"}
0005432747592	61B2C7	0744 509821	ALEKSANDR MIKHAYLOV	{"phone": "+70956219314"}
0005432747593	61B2C7	4985 645887	ANASTASIYA ALEKSEEVA	{"phone": "+70098537987"}
0005432747594	ED4F42	2457 482401	ALEKSEY GERASIMOV	{"phone": "+70186935312"}
0005432747595	ED4F42	7525 112248	ALEKSANDR VOROBEV	{"email": "vorobev.aleksandr-041977@postgrespro.ru", "phone": "+70550161687"}
0005432747596	586D7E	8099 779326	TAISIYA EFIMOVA	{"phone": "+70577580930"}
0005432747597	B4F256	3157 951913	LYUDMILA KONOVALOVA	{"email": "konovalovalyudmila_1970@postgrespro.ru", "phone": "+70704783372"}
0005432747598	4ADDA9	8137 872848	MARINA POPOVA	{"email": "m.popova-111973@postgrespro.ru", "phone": "+70686345478"}
0005432747599	B24F9D	2298 946039	OLGA SMIRNOVA	{"phone": "+70635603772"}
0005432747600	873B9C	2811 487684	ANASTASIYA SOROKINA	{"phone": "+70001047150"}
0005432747601	873B9C	4941 283577	GULFIYA LOGINOVA	{"email": "loginova_g_25091976@postgrespro.ru", "phone": "+70809094699"}
0005432747602	3AD2F7	8358 848739	NATALYA SIDOROVA	{"email": "sidorova-n.031966@postgrespro.ru", "phone": "+70630659540"}
0005432747603	1CC0B5	8349 045262	VALENTIN KUZNECOV	{"email": "kuznecovvalentin-10091962@postgrespro.ru", "phone": "+70559110724"}
0005432747604	1CC0B5	7083 757438	MARIYA MIKHAYLOVA	{"phone": "+70922139993"}
0005432747605	DD0DCF	3138 812815	VLADIMIR SEMENOV	{"phone": "+70907276481"}
0005432747606	042E24	3725 120011	KLAVDIYA PETROVA	{"phone": "+70278816793"}
0005432747607	042E24	1457 422030	ELENA ZHURAVLEVA	{"phone": "+70651088844"}
0005432747608	FCEAB7	8351 937775	ANNA OSIPOVA	{"email": "a.osipova.1978@postgrespro.ru", "phone": "+70930935727"}
0005432747609	FCEAB7	3926 292571	LYUBOV MOROZOVA	{"phone": "+70185749812"}
0005432747666	533D96	0040 114366	VLADIMIR ABRAMOV	{"phone": "+70896988893"}
0005432747610	7F887D	6280 758563	MAYYA AKIMOVA	{"email": "m_akimova1969@postgrespro.ru", "phone": "+70281479712"}
0005432747611	B3AAE1	9798 756037	INNA KUZMINA	{"email": "kuzmina.inna1976@postgrespro.ru", "phone": "+70492600147"}
0005432747612	3DAB35	1026 251070	EMIL KUZNECOV	{"phone": "+70623021542"}
0005432747613	3DAB35	1459 721970	GENNADIY SCHERBAKOV	{"email": "gennadiy-scherbakov19071965@postgrespro.ru", "phone": "+70006179024"}
0005432747614	F18DEB	1075 407020	DAMIR BARANOV	{"phone": "+70455689149"}
0005432747615	F2D0A0	8876 214303	NINA ROMANOVA	{"phone": "+70411248276"}
0005432747616	2A873B	6464 941370	STANISLAV KUZNECOV	{"email": "skuznecov26111971@postgrespro.ru", "phone": "+70075008282"}
0005432747617	409236	9621 998805	ELENA ILINA	{"email": "e_ilina.20091979@postgrespro.ru", "phone": "+70553040722"}
0005432747618	D92F20	0849 442575	ILYA ROMANOV	{"phone": "+70792632272"}
0005432747619	174902	1462 115184	VYACHESLAV RODIONOV	{"email": "v_rodionov.1973@postgrespro.ru", "phone": "+70750814093"}
0005432747620	EC860C	2434 564541	TATYANA SMIRNOVA	{"phone": "+70711906911"}
0005432747621	BE1884	3108 807804	ALEKSANDR EGOROV	{"email": "a_egorov21061980@postgrespro.ru", "phone": "+70855079943"}
0005432747622	BE1884	9310 099327	KRISTINA KUZMINA	{"email": "kuzmina-k_021966@postgrespro.ru", "phone": "+70011939655"}
0005432747623	5C21C7	1766 851713	VALERIY SMIRNOV	{"email": "smirnov_valeriy04061961@postgrespro.ru", "phone": "+70542195944"}
0005432747624	5C21C7	7207 204033	ALEKSEY FEDOROV	{"phone": "+70056261056"}
0005432747625	5C21C7	6323 664737	ELENA ZHUKOVA	{"email": "ezhukova-1969@postgrespro.ru", "phone": "+70996476766"}
0005432747626	FC960A	3333 268975	VADIM ANDREEV	{"email": "andreev.v.101959@postgrespro.ru", "phone": "+70401024176"}
0005432747627	E4F183	6356 955032	MARINA IVANOVA	{"email": "ivanova-marina.18081980@postgrespro.ru", "phone": "+70769681819"}
0005432747628	F74B77	6567 323469	ELENA VOROBEVA	{"email": "elena_vorobeva-081974@postgrespro.ru", "phone": "+70522259377"}
0005432747629	F74B77	9054 707460	IVAN KUZNECOV	{"phone": "+70880632076"}
0005432747630	93BB9F	4650 206711	ILYA ROMANOV	{"email": "romanovi.031966@postgrespro.ru", "phone": "+70816231772"}
0005432747631	9CEF57	9772 859519	SVETLANA KOZLOVA	{"email": "kozlova-s.101972@postgrespro.ru", "phone": "+70941583362"}
0005432747632	1AE222	5567 898899	SHAMIL KUZNECOV	{"email": "shamil-kuznecov11041970@postgrespro.ru", "phone": "+70438460940"}
0005432747633	1AE222	2581 960361	VALERIYA ANISIMOVA	{"email": "anisimova_valeriya-31101976@postgrespro.ru", "phone": "+70980592293"}
0005432747634	F446B0	3138 608586	ANATOLIY ANTONOV	{"email": "antonov-anatoliy.31071973@postgrespro.ru", "phone": "+70559453692"}
0005432747635	35D69F	4988 383360	MARINA BELOVA	{"phone": "+70465859662"}
0005432747636	35D69F	1499 315557	VALENTIN ISAEV	{"email": "isaev-v_05101975@postgrespro.ru", "phone": "+70605632291"}
0005432747637	6E90FF	7032 696668	YULIYA NAUMOVA	{"email": "naumova.y_071963@postgrespro.ru", "phone": "+70296062465"}
0005432747638	6E90FF	7947 750705	VALENTINA DAVYDOVA	{"email": "valentina.davydova.111969@postgrespro.ru", "phone": "+70799122489"}
0005432747639	2BD615	1387 115043	PAVEL DENISOV	{"email": "p_denisov.07011965@postgrespro.ru", "phone": "+70189893944"}
0005432747640	8D55BD	1128 732535	MARINA BARANOVA	{"email": "m_baranova_021978@postgrespro.ru", "phone": "+70931336352"}
0005432747641	8D55BD	3594 276344	VYACHESLAV MIRONOV	{"email": "mironov-v1983@postgrespro.ru", "phone": "+70134845262"}
0005432747642	C18221	1300 172694	PAVEL IVANOV	{"email": "ivanov-p29111979@postgrespro.ru", "phone": "+70052160023"}
0005432747643	6A60BA	0013 663077	ANTON VOLKOV	{"email": "volkov_a-15061965@postgrespro.ru", "phone": "+70065216693"}
0005432747644	6A60BA	0906 160268	OLEG POPOV	{"email": "o-popov-1971@postgrespro.ru", "phone": "+70214625251"}
0005432747645	6E4B95	0376 713316	SERGEY SIDOROV	{"phone": "+70719414900"}
0005432747646	6E4B95	1479 215465	SERGEY GORBUNOV	{"phone": "+70211606271"}
0005432747647	6E4B95	0949 456093	PETR MIKHAYLOV	{"email": "petr_mikhaylov-19041990@postgrespro.ru", "phone": "+70430098407"}
0005432747648	961B2A	1975 681405	YURIY POPOV	{"email": "popov.y.021952@postgrespro.ru", "phone": "+70176288502"}
0005432747649	504545	8677 226209	MATVEY MAKAROV	{"email": "makarov.matvey-25101975@postgrespro.ru", "phone": "+70134953171"}
0005432747650	F9B04A	9133 498904	ELENA MEDVEDEVA	{"email": "e_medvedeva14031980@postgrespro.ru", "phone": "+70300932789"}
0005432747815	D39110	8044 760310	GRIGORIY KARPOV	{"phone": "+70367339830"}
0005432747651	C6B4A8	6459 048833	MARINA TIMOFEEVA	{"email": "timofeevamarina_091982@postgrespro.ru", "phone": "+70184675120"}
0005432747652	3C67F9	6508 855879	TAGIR NOVIKOV	{"phone": "+70943123336"}
0005432747653	8D571A	2910 742460	BORIS GERASIMOV	{"email": "gerasimovboris-01101961@postgrespro.ru", "phone": "+70418937689"}
0005432747654	C26C09	6321 970780	NATALYA IVANOVA	{"email": "nivanova_16111969@postgrespro.ru", "phone": "+70314215827"}
0005432747655	C26C09	2610 486162	MAKSIM MIRONOV	{"email": "mironov.maksim-111992@postgrespro.ru", "phone": "+70197730426"}
0005432747656	4BFDA5	8069 321133	SERGEY TARASOV	{"email": "starasov091967@postgrespro.ru", "phone": "+70681845209"}
0005432747657	4BFDA5	4386 621784	ARTEM SIDOROV	{"phone": "+70187366528"}
0005432747658	BEF8E6	0894 697431	PETR POPOV	{"email": "petrpopov.27051967@postgrespro.ru", "phone": "+70898433991"}
0005432747659	A16BEC	0052 023327	GALINA IVANOVA	{"phone": "+70356282607"}
0005432747660	AF3B31	8610 040845	ALEKSANDR ZAKHAROV	{"email": "a_zakharov_031974@postgrespro.ru", "phone": "+70534086980"}
0005432747661	AF3B31	5644 948873	ARTEM ANTONOV	{"phone": "+70482728557"}
0005432747662	501431	5343 029193	EVGENIY ILIN	{"email": "ilin_evgeniy011971@postgrespro.ru", "phone": "+70410664232"}
0005432747663	F0592C	9446 731547	ANATOLIY VASILEV	{"phone": "+70169703036"}
0005432747664	5C8E68	4723 950949	ELENA KOLESNIKOVA	{"phone": "+70404676467"}
0005432747665	EDE4A1	9205 569564	MARGARITA BORISOVA	{"phone": "+70965353076"}
0005432747667	FD0BD3	6631 330514	NADEZHDA PAVLOVA	{"email": "pavlova_nadezhda-07041980@postgrespro.ru", "phone": "+70964651051"}
0005432747668	0B9C7A	5437 978766	VALERIY STEPANOV	{"phone": "+70276419008"}
0005432747669	0B9C7A	4621 121166	DENIS MARTYNOV	{"email": "martynov.denis-06051981@postgrespro.ru", "phone": "+70252718746"}
0005432747670	7DAE1C	6178 686915	ALLA RODIONOVA	{"phone": "+70046193191"}
0005432747671	28AA27	1507 928733	ALEKSANDR PETROV	{"phone": "+70917743318"}
0005432747672	A18ED9	7949 720908	IRINA GAVRILOVA	{"phone": "+70932186338"}
0005432747673	A18ED9	9117 363326	DARYA ORLOVA	{"email": "darya_orlova-041975@postgrespro.ru", "phone": "+70742901845"}
0005432747674	C2D5B3	3254 240329	OLEG SMIRNOV	{"phone": "+70924903532"}
0005432747675	C1B02F	2115 640884	ZHANNA KUZNECOVA	{"phone": "+70345522871"}
0005432747676	F48BF4	0524 812967	YURIY MIRONOV	{"phone": "+70286865965"}
0005432747677	F03F4D	9426 025971	EVGENIYA ILINA	{"email": "ilina_e-011962@postgrespro.ru", "phone": "+70701084543"}
0005432747678	F03F4D	0631 136430	LYUDMILA TARASOVA	{"email": "lyudmila.tarasova.1980@postgrespro.ru", "phone": "+70470596086"}
0005432747679	F03F4D	4289 744530	IRAIDA GAVRILOVA	{"phone": "+70807393351"}
0005432747680	9A5B35	5068 138176	ZINAIDA FEDOROVA	{"phone": "+70965081977"}
0005432747681	60F600	9864 404113	NIKOLAY SOROKIN	{"email": "nikolay-sorokin_23091958@postgrespro.ru", "phone": "+70178891452"}
0005432747682	9FE20C	5602 874853	SERGEY SCHERBAKOV	{"phone": "+70733178670"}
0005432747683	9FE20C	4088 062925	NIKOLAY VOROBEV	{"email": "nvorobev_1969@postgrespro.ru", "phone": "+70171653564"}
0005432747684	E07AC3	8388 788687	ANDREY YAKOVLEV	{"email": "a.yakovlev061974@postgrespro.ru", "phone": "+70012315730"}
0005432747685	A39C6A	4894 005294	VADIM YAKOVLEV	{"phone": "+70855357639"}
0005432747686	A39C6A	5751 460622	OLEG IVANOV	{"email": "ivanov.oleg_1965@postgrespro.ru", "phone": "+70039179581"}
0005432747687	9C145E	6603 629370	NIKOLAY ZAYCEV	{"phone": "+70203623802"}
0005432747688	9C145E	9146 490343	LYUDMILA CHERNOVA	{"phone": "+70494603234"}
0005432747689	48F414	7201 450164	VLADIMIR MAKAROV	{"phone": "+70254824004"}
0005432747690	48F414	1310 565622	ELENA ANDREEVA	{"email": "e-andreeva-29061980@postgrespro.ru", "phone": "+70900802909"}
0005432747691	A7C80F	6228 224025	IGOR NOVIKOV	{"email": "igornovikov.101977@postgrespro.ru", "phone": "+70261441463"}
0005432747692	5AD0D6	1002 926668	EKATERINA KONDRATEVA	{"email": "kondrateva.ekaterina04051965@postgrespro.ru", "phone": "+70793938699"}
0005432747693	5AD0D6	2837 398327	NINA MASLOVA	{"email": "maslovan02111974@postgrespro.ru", "phone": "+70490887178"}
0005432747694	F37C04	4480 746666	TATYANA YAKOVLEVA	{"email": "t-yakovleva_021976@postgrespro.ru", "phone": "+70780616840"}
0005432747695	5E6EE4	0264 633810	ELENA KUZNECOVA	{"email": "elena.kuznecova-081980@postgrespro.ru", "phone": "+70353831770"}
0005432747696	28BC0A	3738 794079	SERGEY KULIKOV	{"email": "s.kulikov-15011968@postgrespro.ru", "phone": "+70346547254"}
0005432747697	3D99B5	5759 514980	NIKOLAY SAVELEV	{"phone": "+70480051734"}
0005432747698	D20B20	8851 962408	ELENA BELOVA	{"phone": "+70134011965"}
0005432747699	D20B20	6182 194130	ANDREY RODIONOV	{"email": "rodionov.andrey.15011976@postgrespro.ru", "phone": "+70328166213"}
0005432747700	28DFE9	3766 897339	GALINA SCHERBAKOVA	{"email": "scherbakovag-02091970@postgrespro.ru", "phone": "+70859987043"}
0005432747701	E0573A	0380 953313	ANATOLIY VASILEV	{"email": "avasilev_19021982@postgrespro.ru", "phone": "+70380266706"}
0005432747702	89011B	7863 456895	ALEKSANDR PETROV	{"email": "a-petrov.1968@postgrespro.ru", "phone": "+70533364896"}
0005432747703	3267D7	5601 780420	DMITRIY ZAYCEV	{"phone": "+70749833275"}
0005432747704	3267D7	2194 186354	DENIS FOMIN	{"email": "fomin_d1977@postgrespro.ru", "phone": "+70659641266"}
0005432747705	3267D7	1910 193622	OLEG MIKHAYLOV	{"phone": "+70662359992"}
0005432747706	882A21	5274 257659	ALINA VASILEVA	{"phone": "+70293250737"}
0005432747707	4BF818	9500 263681	IVAN DENISOV	{"email": "ivan-denisov.14111990@postgrespro.ru", "phone": "+70546058663"}
0005432747708	4BF818	5674 444115	RUSLAN BELOV	{"email": "belovr021970@postgrespro.ru", "phone": "+70408748109"}
0005432747709	E29382	7194 568958	ANNA POTAPOVA	{"phone": "+70610810665"}
0005432747710	7BBF21	4436 255226	EVGENIYA GRISHINA	{"email": "grishina.evgeniya-1970@postgrespro.ru", "phone": "+70603229534"}
0005432747711	7BBF21	5591 015584	NIKOLAY PETROV	{"email": "petrov.nikolay_1968@postgrespro.ru", "phone": "+70835417299"}
0005432747712	D975A8	1840 879485	GALINA PAVLOVA	{"email": "g.pavlova-1972@postgrespro.ru", "phone": "+70432472580"}
0005432747713	D975A8	4645 591341	OLESYA POPOVA	{"phone": "+70039518669"}
0005432747714	49B684	3320 079678	ALEKSEY BORISOV	{"email": "aleksey-borisov_1974@postgrespro.ru", "phone": "+70801971457"}
0005432747715	96F64B	1986 576702	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina-1973@postgrespro.ru", "phone": "+70420254576"}
0005432747716	0772B1	5450 860712	EGOR MELNIKOV	{"email": "melnikov_egor.1972@postgrespro.ru", "phone": "+70014526982"}
0005432747717	87F457	6282 461069	TATYANA RYABOVA	{"email": "ryabova_tatyana12071966@postgrespro.ru", "phone": "+70321586849"}
0005432747718	3A6736	4750 279906	NATALYA KONDRATEVA	{"phone": "+70738323797"}
0005432747719	B7E5FF	4263 481158	KONSTANTIN EGOROV	{"email": "konstantin-egorov_1964@postgrespro.ru", "phone": "+70181669723"}
0005432747720	B7E5FF	6824 695256	IVAN KOZLOV	{"phone": "+70424235435"}
0005432747721	BCCE34	0505 405357	KSENIYA KUZMINA	{"email": "kuzmina.kseniya_071970@postgrespro.ru", "phone": "+70763008490"}
0005432747722	BCCE34	2003 955173	ARTEMIY MAKAROV	{"email": "makarov-a_1957@postgrespro.ru", "phone": "+70135902070"}
0005432747723	2C9917	9198 293919	GENNADIY SIDOROV	{"email": "g_sidorov.011965@postgrespro.ru", "phone": "+70842668702"}
0005432747724	32A677	5485 280969	ALEKSANDR MIKHAYLOV	{"phone": "+70251949295"}
0005432747725	32A677	7283 675629	VIKTORIYA TARASOVA	{"phone": "+70167563037"}
0005432747726	F54487	6329 139352	NATALYA ANTONOVA	{"email": "antonova-n_111965@postgrespro.ru", "phone": "+70684493554"}
0005432747727	5874CB	0459 728296	YULIYA ZAKHAROVA	{"phone": "+70217936822"}
0005432747728	5874CB	1121 055953	LARISA MATVEEVA	{"email": "larisa_matveeva.1969@postgrespro.ru", "phone": "+70563307893"}
0005432747729	000999	3242 847651	TATYANA SOROKINA	{"email": "sorokina_tatyana_1975@postgrespro.ru", "phone": "+70890210861"}
0005432747730	BE8F69	5380 205680	IRINA ZAKHAROVA	{"email": "irina.zakharova_07041974@postgrespro.ru", "phone": "+70052119087"}
0005432747731	508300	1809 575722	VIKTOR KUZNECOV	{"phone": "+70349804931"}
0005432747732	316514	7561 975613	VALERIY AFANASEV	{"phone": "+70765814438"}
0005432747733	9553CD	9735 845807	MARIYA ABRAMOVA	{"email": "m.abramova25031975@postgrespro.ru", "phone": "+70087341474"}
0005432747734	9553CD	0615 387303	BORIS KUZMIN	{"phone": "+70668164368"}
0005432747735	73496F	2019 661518	LEV VLASOV	{"email": "vlasov_l07111960@postgrespro.ru", "phone": "+70246464342"}
0005432747736	73496F	6093 078106	NATALYA MIRONOVA	{"email": "mironova.natalya021978@postgrespro.ru", "phone": "+70097066704"}
0005432747737	3296AF	3254 625372	LYUDMILA NIKITINA	{"phone": "+70428141531"}
0005432747738	3296AF	3844 904076	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila_30031971@postgrespro.ru", "phone": "+70813840217"}
0005432747739	9B5A67	7947 246876	VYACHESLAV MEDVEDEV	{"email": "v-medvedev111984@postgrespro.ru", "phone": "+70951117430"}
0005432747740	9B5A67	3188 504884	RAISA KUZNECOVA	{"phone": "+70120087332"}
0005432747741	6BDBC8	6562 811374	VALERIY MAKAROV	{"email": "v.makarov.051968@postgrespro.ru", "phone": "+70980593459"}
0005432747742	6BDBC8	2504 435064	NIKOLAY PETROV	{"email": "petrov.n20081974@postgrespro.ru", "phone": "+70986369849"}
0005432747743	5D64C1	4310 966432	IRINA KISELEVA	{"email": "irina-kiseleva.1970@postgrespro.ru", "phone": "+70316549732"}
0005432747744	35A3A8	7329 579356	ELENA AKIMOVA	{"email": "elena-akimova08121958@postgrespro.ru", "phone": "+70329139418"}
0005432747745	5B7EC3	4849 068962	ANASTASIYA EGOROVA	{"email": "anastasiya.egorova081972@postgrespro.ru", "phone": "+70637171644"}
0005432747746	5DC1AF	2811 400191	PAVEL MIRONOV	{"email": "p-mironov.25111963@postgrespro.ru", "phone": "+70666169504"}
0005432747747	057FDD	6235 853237	VIKTOR POPOV	{"email": "popovv.1965@postgrespro.ru", "phone": "+70361338019"}
0005432747748	1B3EB9	5047 071914	NATALYA MAKAROVA	{"email": "makarova.n.11041977@postgrespro.ru", "phone": "+70794432101"}
0005432747749	787888	5214 265970	ALEKSEY TARASOV	{"email": "tarasov-a_03071972@postgrespro.ru", "phone": "+70640916124"}
0005432747750	787888	2155 330421	ANTON SEMENOV	{"email": "semenov_a1976@postgrespro.ru", "phone": "+70829534427"}
0005432747751	99DDF6	2186 181690	OLGA MIRONOVA	{"email": "mironova-olga-1971@postgrespro.ru", "phone": "+70608134674"}
0005432747752	99DDF6	0534 645190	ANASTASIYA IVANOVA	{"email": "aivanova24031969@postgrespro.ru", "phone": "+70614433915"}
0005432747753	4CF6F9	9680 997904	ANATOLIY KOZLOV	{"email": "akozlov-071987@postgrespro.ru", "phone": "+70436099245"}
0005432747754	581A22	4875 796655	ANASTASIYA ZAKHAROVA	{"email": "zakharovaa.121968@postgrespro.ru", "phone": "+70624541087"}
0005432747755	6C3874	6483 698723	ALEKSEY SOLOVEV	{"phone": "+70731621147"}
0005432747756	1F750C	3606 406708	ELENA KOVALEVA	{"phone": "+70223018603"}
0005432747757	72D0EA	7607 885403	SVETLANA EGOROVA	{"email": "svetlana_egorova08041960@postgrespro.ru", "phone": "+70535168492"}
0005432747758	84FC64	0877 499801	DMITRIY POPOV	{"email": "popov.d1976@postgrespro.ru", "phone": "+70038698087"}
0005432747759	AFE09F	9907 753293	ELENA OSIPOVA	{"phone": "+70994595713"}
0005432747760	AFE09F	9550 933540	ELIZAVETA SMIRNOVA	{"email": "e-smirnova-091974@postgrespro.ru", "phone": "+70051248014"}
0005432747761	AFE09F	5273 491445	NADEZHDA MOROZOVA	{"email": "n.morozova_1968@postgrespro.ru", "phone": "+70321986531"}
0005432747762	AFE09F	2526 272544	ALEKSANDRA GAVRILOVA	{"email": "gavrilova.a.1971@postgrespro.ru", "phone": "+70542256164"}
0005432747763	402F55	7164 982133	ALEKSANDR AFANASEV	{"email": "afanasev-aleksandr_081970@postgrespro.ru", "phone": "+70854613138"}
0005432747764	59828C	4517 334024	VADIM AFANASEV	{"email": "afanasev-v.01041976@postgrespro.ru", "phone": "+70086727128"}
0005432747765	3AEA0F	1448 097888	SVETLANA NIKITINA	{"phone": "+70385582656"}
0005432747766	0572B0	6915 366207	SOFIYA MOROZOVA	{"phone": "+70607661745"}
0005432747767	0572B0	4629 601457	VIKTOR POPOV	{"email": "v.popov_1967@postgrespro.ru", "phone": "+70343237491"}
0005432747768	840024	7104 271509	ZINAIDA MIKHAYLOVA	{"email": "mikhaylovazinaida_1978@postgrespro.ru", "phone": "+70532741545"}
0005432747769	C61213	7678 616409	NINA MAKSIMOVA	{"email": "maksimova_nina-1970@postgrespro.ru", "phone": "+70158152745"}
0005432747770	C61213	2702 125231	EVGENIY IVANOV	{"email": "evgeniyivanov.1969@postgrespro.ru", "phone": "+70410870924"}
0005432747771	4A57DC	3734 116375	MIKHAIL NOVIKOV	{"phone": "+70346060063"}
0005432747772	F93E11	2830 542970	TATYANA FILIPPOVA	{"email": "filippova.t-01021977@postgrespro.ru", "phone": "+70772790007"}
0005432747773	F93E11	1750 560056	DMITRIY ORLOV	{"email": "orlov.dmitriy.05101965@postgrespro.ru", "phone": "+70658002037"}
0005432747774	6E147F	1406 012848	ALINA PAVLOVA	{"phone": "+70729093371"}
0005432747775	EC4A79	5390 177924	ELENA ZAKHAROVA	{"email": "zakharova-e071980@postgrespro.ru", "phone": "+70491649069"}
0005432747776	4128BC	5412 603160	IRINA MIKHAYLOVA	{"phone": "+70327557430"}
0005432747777	4128BC	6377 660132	EVGENIY TIKHONOV	{"phone": "+70255146985"}
0005432747778	4128BC	1646 893997	RODION FILIPPOV	{"email": "r-filippov_15021960@postgrespro.ru", "phone": "+70336475468"}
0005432747779	C3A2D9	1235 826148	ELIZAVETA KOZLOVA	{"phone": "+70025785057"}
0005432747780	C3A2D9	8895 608512	VALENTIN ANDREEV	{"email": "andreevvalentin_1975@postgrespro.ru", "phone": "+70045862196"}
0005432747781	519FBF	9910 067552	ALEKSEY EGOROV	{"phone": "+70923282066"}
0005432747782	519FBF	9983 841137	ELENA POPOVA	{"email": "popova-e_1970@postgrespro.ru", "phone": "+70203745866"}
0005432747783	E43EB0	1735 806278	ELENA ZHURAVLEVA	{"email": "elenazhuravleva17051980@postgrespro.ru", "phone": "+70266280667"}
0005432747784	E43EB0	2817 511580	SERGEY DENISOV	{"email": "s-denisov.1973@postgrespro.ru", "phone": "+70028177576"}
0005432747785	B539B6	1515 125888	DARYA SAVELEVA	{"email": "savelevad.031970@postgrespro.ru", "phone": "+70804252552"}
0005432747786	B539B6	2213 888607	NATALYA KULIKOVA	{"phone": "+70608060538"}
0005432747787	E77B2A	7869 324852	ALEKSANDR MOROZOV	{"phone": "+70149718228"}
0005432747788	E77B2A	0307 422167	PAVEL KONOVALOV	{"phone": "+70051692561"}
0005432747789	B99A82	6223 443003	OLGA MOROZOVA	{"phone": "+70120651654"}
0005432747790	D40B8A	8139 984571	VALERIY SOKOLOV	{"email": "valeriy_sokolov111970@postgrespro.ru", "phone": "+70761655956"}
0005432747791	6A7269	3158 969169	MARIYA MARTYNOVA	{"email": "m_martynova_011985@postgrespro.ru", "phone": "+70640472105"}
0005432747792	B6FC2F	1236 963341	ELENA NESTEROVA	{"email": "nesterovae.021979@postgrespro.ru", "phone": "+70331880137"}
0005432747793	57FE08	1035 468223	ELIZAVETA RYABOVA	{"phone": "+70370658674"}
0005432747794	57FE08	5547 040365	ALEKSEY YAKOVLEV	{"email": "aleksey-yakovlev-1974@postgrespro.ru", "phone": "+70079241471"}
0005432748471	ECB733	0815 174928	AZAT CHERNOV	{"phone": "+70259286262"}
0005432747795	B85156	3210 689365	VIKTOR AFANASEV	{"email": "viktor_afanasev031973@postgrespro.ru", "phone": "+70225828341"}
0005432747796	4D1FC7	7241 814791	ANDREY EGOROV	{"email": "egorov.a041983@postgrespro.ru", "phone": "+70266475895"}
0005432747797	02AEF6	0744 817799	IRINA MIRONOVA	{"email": "mironova.irina1976@postgrespro.ru", "phone": "+70498877812"}
0005432747798	6A446E	1430 720433	IRINA ANTONOVA	{"phone": "+70999398728"}
0005432747799	6A446E	7456 840364	VIKTORIYA VOLKOVA	{"phone": "+70560264684"}
0005432747800	DDBC82	0692 430315	IGOR MEDVEDEV	{"email": "medvedev_i.021971@postgrespro.ru", "phone": "+70159909734"}
0005432747801	05405D	6619 720681	DARYA ANISIMOVA	{"email": "anisimovad-1982@postgrespro.ru", "phone": "+70690238562"}
0005432747802	0C6E02	2650 864234	LIDIYA ARKHIPOVA	{"email": "lidiya_arkhipova_23101965@postgrespro.ru", "phone": "+70584016547"}
0005432747803	1054F2	4479 144555	ANGELINA GORBUNOVA	{"email": "gorbunova-angelina29051971@postgrespro.ru", "phone": "+70487687320"}
0005432747804	F3A8E6	2534 809318	KARINA PAVLOVA	{"email": "k_pavlova.1971@postgrespro.ru", "phone": "+70546336247"}
0005432747805	5DD829	0348 572145	IVAN ABRAMOV	{"email": "ivan.abramov.19021967@postgrespro.ru", "phone": "+70129135584"}
0005432747806	9D22F2	0096 661242	NIKOLAY DAVYDOV	{"phone": "+70402162365"}
0005432747807	9D22F2	1292 726770	OLGA KUZNECOVA	{"email": "kuznecova-olga-1961@postgrespro.ru", "phone": "+70028798648"}
0005432747808	DF537A	7075 782406	TATYANA VOROBEVA	{"phone": "+70221788840"}
0005432747809	C89B3D	2519 343785	IVAN ZHURAVLEV	{"phone": "+70613111349"}
0005432747810	C89B3D	8305 116445	FEDOR FEDOROV	{"phone": "+70120324744"}
0005432747811	D79BC9	2133 299021	OLGA NAUMOVA	{"email": "naumova-o.1976@postgrespro.ru", "phone": "+70200295521"}
0005432747812	2E948A	0519 110475	MIKHAIL MAKAROV	{"phone": "+70260882493"}
0005432747813	75190A	6511 735434	EKATERINA KOROLEVA	{"email": "ekaterina.koroleva-101968@postgrespro.ru", "phone": "+70615573796"}
0005432747814	8B679D	7266 113044	YULIYA LEBEDEVA	{"email": "yuliya-lebedeva_041970@postgrespro.ru", "phone": "+70475621862"}
0005432747816	8DAFD7	8672 072105	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr.26081984@postgrespro.ru", "phone": "+70851259590"}
0005432747817	8DAFD7	2367 130504	MARIYA VOLKOVA	{"phone": "+70323016708"}
0005432747818	97B060	4409 191955	OLESYA SCHERBAKOVA	{"email": "o-scherbakova_1973@postgrespro.ru", "phone": "+70648558835"}
0005432747819	8D8AA1	6471 238099	EVGENIYA AFANASEVA	{"email": "afanaseva_evgeniya_051967@postgrespro.ru", "phone": "+70939683397"}
0005432747820	8D8AA1	9019 633719	NINA IVANOVA	{"email": "ivanova_n.16101964@postgrespro.ru", "phone": "+70583187361"}
0005432747821	5AA1C5	7550 952669	YURIY KOZLOV	{"email": "yuriy.kozlov.1972@postgrespro.ru", "phone": "+70304241395"}
0005432747822	92F227	8874 397300	IVAN SERGEEV	{"phone": "+70499996839"}
0005432747823	92F227	6359 051188	RUMIYA NIKIFOROVA	{"email": "rumiya-nikiforova_1984@postgrespro.ru", "phone": "+70061512882"}
0005432747824	84B850	7004 569884	RUZALIYA ALEKSEEVA	{"phone": "+70040361112"}
0005432747825	2DCA5E	5638 476091	NATALIYA DMITRIEVA	{"phone": "+70083307443"}
0005432747826	C904FC	9524 209496	ARTEM MIKHAYLOV	{"email": "artemmikhaylov_22071976@postgrespro.ru", "phone": "+70146591632"}
0005432747827	3B1707	9784 886731	PAVEL POPOV	{"email": "popov-pavel-1983@postgrespro.ru", "phone": "+70435528828"}
0005432747828	9981FF	5009 541632	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr.1963@postgrespro.ru", "phone": "+70580501213"}
0005432747829	9981FF	7320 340144	LILIYA NESTEROVA	{"email": "nesterovaliliya021959@postgrespro.ru", "phone": "+70365548920"}
0005432747830	D94238	8322 733960	OLGA VOLKOVA	{"email": "olga-volkova_111961@postgrespro.ru", "phone": "+70234457332"}
0005432747831	866A25	6325 827543	BORIS SAVELEV	{"email": "bsavelev.1974@postgrespro.ru", "phone": "+70045432396"}
0005432747832	A2DE1D	9014 985565	ALEKSANDR ZHUKOV	{"phone": "+70690432329"}
0005432747833	A2DE1D	0598 356685	KONSTANTIN KUZNECOV	{"email": "k.kuznecov-04081977@postgrespro.ru", "phone": "+70168484322"}
0005432747834	A2DE1D	1820 478925	MARINA MASLOVA	{"phone": "+70875778602"}
0005432747835	661B2E	5751 726908	ILYA KOROLEV	{"email": "i.korolev06061964@postgrespro.ru", "phone": "+70019915451"}
0005432747836	299193	1386 438913	MARIYA SMIRNOVA	{"phone": "+70349352411"}
0005432747837	E20BA0	9675 995342	VALERIY EGOROV	{"email": "egorovv1977@postgrespro.ru", "phone": "+70406722266"}
0005432747838	E20BA0	4652 385203	YAKOV ZHURAVLEV	{"phone": "+70447866827"}
0005432747839	0D6C97	9717 912378	VIKTOR KUDRYASHOV	{"email": "viktorkudryashov1978@postgrespro.ru", "phone": "+70911747238"}
0005432747840	0D6C97	7771 549484	ALEKSANDR KULIKOV	{"phone": "+70166987676"}
0005432747841	0B5685	6415 424155	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov31101978@postgrespro.ru", "phone": "+70249000740"}
0005432747842	97F97B	6450 832215	OLGA FILIPPOVA	{"email": "o_filippova1972@postgrespro.ru", "phone": "+70117160166"}
0005432747843	0F9D41	2113 122371	ALEKSEY KRASNOV	{"email": "krasnov.aleksey.02051970@postgrespro.ru", "phone": "+70489473084"}
0005432747844	0F9D41	3915 410422	NINA NIKITINA	{"phone": "+70765724995"}
0005432747845	0F9D41	5167 703454	LYUBOV ANISIMOVA	{"phone": "+70942975082"}
0005432747846	8A1CBA	3512 022275	TATYANA TIMOFEEVA	{"email": "timofeeva.tatyana_1970@postgrespro.ru", "phone": "+70181408557"}
0005432747847	8A1CBA	1314 753221	TATYANA NESTEROVA	{"email": "tatyana_nesterova-041974@postgrespro.ru", "phone": "+70450947098"}
0005432747848	32FEC2	4495 507441	MARIYA MATVEEVA	{"phone": "+70157811455"}
0005432747849	32FEC2	7345 658937	ANDREY ANDREEV	{"email": "andreev_andrey_01091969@postgrespro.ru", "phone": "+70476998707"}
0005432747850	32D718	9595 278990	MAKSIM KAZAKOV	{"email": "m_kazakov-1972@postgrespro.ru", "phone": "+70973541667"}
0005432747851	D53A6B	3359 219304	RAIL FROLOV	{"phone": "+70484973896"}
0005432747852	E621EF	3691 216492	ANATOLIY SOKOLOV	{"phone": "+70570577560"}
0005432747853	E621EF	1943 288821	ALEKSEY MELNIKOV	{"email": "melnikov.a.011972@postgrespro.ru", "phone": "+70274279254"}
0005432747854	76F582	8813 808011	VERA DAVYDOVA	{"phone": "+70312430718"}
0005432747855	2E699A	8783 665988	MARIYA NIKITINA	{"email": "mariya_nikitina_1970@postgrespro.ru", "phone": "+70370200835"}
0005432747856	9C970C	4230 953686	ELENA ALEKSEEVA	{"phone": "+70017154706"}
0005432747857	9C970C	7825 409775	NIKOLAY OSIPOV	{"phone": "+70383570813"}
0005432747858	AFB6A9	0742 522046	ALEKSEY ANTONOV	{"phone": "+70206629803"}
0005432747859	C71C98	7335 127528	OLGA TITOVA	{"email": "titova-olga_1979@postgrespro.ru", "phone": "+70708745757"}
0005432747860	330038	6250 784267	IGOR AFANASEV	{"email": "afanasev_igor1971@postgrespro.ru", "phone": "+70847639328"}
0005432747861	BA3F3C	5718 372430	ALEKSANDR MOROZOV	{"email": "a-morozov_101979@postgrespro.ru", "phone": "+70636938020"}
0005432747862	BA3F3C	1398 084151	ALEKSANDRA KONOVALOVA	{"phone": "+70451187937"}
0005432747863	BA3F3C	0686 021905	VLADIMIR GRIGOREV	{"email": "grigorev.vladimir.101976@postgrespro.ru", "phone": "+70406924289"}
0005432747864	22D2CB	3260 690072	MARIYA ZHUKOVA	{"phone": "+70452591907"}
0005432747865	4EB1A5	3538 443170	SERGEY GRIGOREV	{"email": "sgrigorev_09011961@postgrespro.ru", "phone": "+70554799205"}
0005432747866	7E0FE3	4955 592012	ZAKHAR SEMENOV	{"phone": "+70562261718"}
0005432747867	3BF8DA	8854 265049	TAISIYA MOROZOVA	{"email": "taisiya-morozova-1973@postgrespro.ru", "phone": "+70617891801"}
0005432747868	DDEA93	1313 497887	LYUBOV KUZMINA	{"phone": "+70970158423"}
0005432747869	B27916	2329 432641	BORIS SHEVCHENKO	{"email": "bshevchenko071970@postgrespro.ru", "phone": "+70691837024"}
0005432747870	B27916	2177 532259	TATYANA RODIONOVA	{"email": "trodionova.29071977@postgrespro.ru", "phone": "+70516788134"}
0005432747871	C28DF2	5527 929951	VITALIY BONDARENKO	{"email": "vitaliybondarenko1971@postgrespro.ru", "phone": "+70134625234"}
0005432747872	C28DF2	8631 483443	ZHANNA NESTEROVA	{"phone": "+70265724083"}
0005432747873	D50583	3965 477158	VALERIY IVANOV	{"email": "ivanov_valeriy_1984@postgrespro.ru", "phone": "+70534562674"}
0005432747874	5FBB74	4649 427573	VLADIMIR GAVRILOV	{"email": "v.gavrilov-1980@postgrespro.ru", "phone": "+70406725741"}
0005432747875	698337	0144 745082	TAISIYA MELNIKOVA	{"phone": "+70346183095"}
0005432747876	07DB1A	2713 772229	SERGEY FILIPPOV	{"phone": "+70244815878"}
0005432747877	A69CDF	3017 954524	ALEKSANDR NIKITIN	{"phone": "+70656334048"}
0005432747878	9B1E5E	0661 904144	OLGA ILINA	{"email": "ilina.o111974@postgrespro.ru", "phone": "+70882028621"}
0005432747879	25F188	3153 666306	ROMAN FILIPPOV	{"phone": "+70051119531"}
0005432747880	25F188	5941 219871	VERA NAZAROVA	{"email": "nazarova-v.101969@postgrespro.ru", "phone": "+70315038027"}
0005432747881	B0F248	6594 510717	ANFISA SOKOLOVA	{"phone": "+70393454465"}
0005432747882	81C18E	0764 130194	VYACHESLAV IVANOV	{"phone": "+70707405109"}
0005432747883	9D5D79	4900 658409	ILYA BORISOV	{"email": "iborisov1974@postgrespro.ru", "phone": "+70999544077"}
0005432747884	4DD14D	1648 490633	LYUDMILA MAKAROVA	{"phone": "+70888864006"}
0005432747885	4DD14D	7708 507501	ARTEM ILIN	{"email": "ilin.a_28021968@postgrespro.ru", "phone": "+70968419653"}
0005432747886	CF49C3	0510 118500	OLGA NIKITINA	{"email": "olga-nikitina-1970@postgrespro.ru", "phone": "+70897702535"}
0005432747887	CF49C3	3449 780837	IGOR SOROKIN	{"phone": "+70002806020"}
0005432747888	2348DF	8383 478998	YULIYA LUKYANOVA	{"email": "lukyanova-y091980@postgrespro.ru", "phone": "+70459501527"}
0005432747889	56CF19	8719 670457	KRISTINA SOKOLOVA	{"email": "k-sokolova1978@postgrespro.ru", "phone": "+70985352218"}
0005432747890	61CD0B	4359 661378	GENNADIY CHERNOV	{"phone": "+70826704053"}
0005432747891	250ED8	2374 517749	SERGEY ANDREEV	{"email": "sergey.andreev1972@postgrespro.ru", "phone": "+70027651177"}
0005432747892	4BAD8D	5629 401695	IGOR TIKHONOV	{"email": "tikhonov.igor_031976@postgrespro.ru", "phone": "+70919940934"}
0005432747893	5443B2	4495 605510	ANATOLIY KUZNECOV	{"phone": "+70706242327"}
0005432747894	5443B2	7608 085500	KLAVDIYA ABRAMOVA	{"phone": "+70279806335"}
0005432747895	F0BA13	2407 585709	IRINA KULIKOVA	{"phone": "+70109051502"}
0005432747896	F0BA13	2480 578729	ALEKSANDRA NOVIKOVA	{"email": "a_novikova101975@postgrespro.ru", "phone": "+70129739666"}
0005432747897	CEAB23	2622 224758	ALEKSEY KONOVALOV	{"phone": "+70938278171"}
0005432747898	CEAB23	1547 889966	ELENA POPOVA	{"phone": "+70692396443"}
0005432747899	CEAB23	1293 687313	DINARA SOKOLOVA	{"email": "dinara-sokolova.27091975@postgrespro.ru", "phone": "+70067429786"}
0005432747900	DE4312	9176 096557	MARINA ZAYCEVA	{"email": "mzayceva_29061974@postgrespro.ru", "phone": "+70690070111"}
0005432747901	DD5739	9000 181722	VYACHESLAV KISELEV	{"phone": "+70534255303"}
0005432747902	B6D051	4216 585885	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov_20121980@postgrespro.ru", "phone": "+70001018976"}
0005432747903	8C7D27	3063 892926	LYUBOV GRISHINA	{"phone": "+70090569520"}
0005432747904	A4BA59	6134 630905	IVAN FEDOROV	{"email": "fedorov.ivan05091976@postgrespro.ru", "phone": "+70999645667"}
0005432747905	2236E8	3798 388247	NIKOLAY PETROV	{"email": "n-petrov.01041984@postgrespro.ru", "phone": "+70053395797"}
0005432747906	06C8CF	7469 036406	SERGEY KOZLOV	{"email": "skozlov-1973@postgrespro.ru", "phone": "+70428785278"}
0005432747907	9264B9	3671 653838	VERONIKA ERMAKOVA	{"phone": "+70271373854"}
0005432747908	7DB8CF	3990 200193	OLGA NIKIFOROVA	{"email": "nikiforova_o.16111974@postgrespro.ru", "phone": "+70399287906"}
0005432747909	85776F	5146 622707	LYUBOV NAUMOVA	{"email": "naumova_l-22091981@postgrespro.ru", "phone": "+70237016912"}
0005432747910	6C371D	7239 177091	MIKHAIL EGOROV	{"phone": "+70778443795"}
0005432747911	80D88A	8367 716712	VITALIY GORBUNOV	{"email": "vitaliy.gorbunov-011976@postgrespro.ru", "phone": "+70324374315"}
0005432747912	80D88A	0770 719793	ILNUR FEDOROV	{"phone": "+70927630017"}
0005432747913	E71858	2170 363686	ALEKSANDR IVANOV	{"phone": "+70076337798"}
0005432747914	413255	6830 202316	MIKHAIL FOMIN	{"email": "fomin_m041966@postgrespro.ru", "phone": "+70629194266"}
0005432747915	413255	7620 715526	SOFIYA GAVRILOVA	{"email": "s_gavrilova-1980@postgrespro.ru", "phone": "+70999839734"}
0005432747916	1CC6B0	0537 155003	ANNA PAVLOVA	{"phone": "+70972237772"}
0005432747917	763818	8736 549536	GENNADIY PETROV	{"phone": "+70565384159"}
0005432747918	5D845F	6282 625310	YULIYA FADEEVA	{"email": "fadeevay011984@postgrespro.ru", "phone": "+70005372707"}
0005432747919	47BE7D	4472 778659	MARINA KARPOVA	{"email": "marina.karpova-31071971@postgrespro.ru", "phone": "+70908266205"}
0005432747920	9F873F	9656 053752	EVGENIY FILIPPOV	{"phone": "+70161527678"}
0005432747921	9F873F	4246 979100	NINA ANISIMOVA	{"email": "anisimova-n-011976@postgrespro.ru", "phone": "+70759450008"}
0005432747922	D7F7C2	5509 370601	VIKTOR FEDOTOV	{"phone": "+70031428090"}
0005432747923	D7F7C2	2754 990977	SVETLANA IVANOVA	{"email": "s_ivanova_25111977@postgrespro.ru", "phone": "+70844136528"}
0005432747924	D73B32	2810 258663	VERA ROMANOVA	{"phone": "+70565729603"}
0005432747925	D73B32	9957 895384	OLGA SERGEEVA	{"phone": "+70535622982"}
0005432747926	2722EA	4291 195993	ANDREY FROLOV	{"phone": "+70473805200"}
0005432747927	89945D	1634 009375	KSENIYA PETROVA	{"phone": "+70914586116"}
0005432747928	D8244C	6791 456770	VALENTIN KOZLOV	{"phone": "+70181076558"}
0005432747929	3D29E9	0802 392457	ALENA BORISOVA	{"email": "alena.borisova.1973@postgrespro.ru", "phone": "+70966244835"}
0005432747930	3D29E9	6436 901021	VITALIY DMITRIEV	{"phone": "+70276853333"}
0005432747931	3D29E9	6849 323911	DANIIL ALEKSEEV	{"phone": "+70985257892"}
0005432747932	BFDEF7	5537 286019	NINA NIKITINA	{"phone": "+70125940947"}
0005432747933	8A0A5E	2739 498371	VALERIYA SOROKINA	{"email": "sorokina.v071970@postgrespro.ru", "phone": "+70853918357"}
0005432747934	2A3B07	5757 535027	DMITRIY GORBUNOV	{"email": "dgorbunov.1969@postgrespro.ru", "phone": "+70239952917"}
0005432747935	128EC5	9217 160320	MARIYA NAZAROVA	{"email": "m_nazarova.1969@postgrespro.ru", "phone": "+70884318876"}
0005432747936	5E98B5	2156 587188	NINA NIKITINA	{"email": "nnikitina_1969@postgrespro.ru", "phone": "+70120363072"}
0005432747937	5E98B5	1587 701924	PELAGEYA IVANOVA	{"email": "ivanova-p-13111963@postgrespro.ru", "phone": "+70779669172"}
0005432747938	5E98B5	2665 788925	IVAN GRIGOREV	{"email": "i-grigorev_08041964@postgrespro.ru", "phone": "+70575568112"}
0005432747939	A2BE8E	1863 744157	ALEKSANDR AFANASEV	{"phone": "+70586594938"}
0005432747940	C2D19C	5015 258213	KONSTANTIN ANDREEV	{"email": "andreev_k_111975@postgrespro.ru", "phone": "+70364429961"}
0005432747941	91F2AE	3899 343228	LYUBOV LEBEDEVA	{"email": "l_lebedeva041980@postgrespro.ru", "phone": "+70759071346"}
0005432747942	E085B9	7515 040661	ALEKSEY KRASNOV	{"email": "krasnovaleksey1961@postgrespro.ru", "phone": "+70531008629"}
0005432747943	DCEB12	8937 932894	SOFYA IVANOVA	{"email": "ivanova-sofya1965@postgrespro.ru", "phone": "+70548483706"}
0005432747944	EE6AFE	7951 561673	DMITRIY KUZMIN	{"phone": "+70811392711"}
0005432747945	7B745B	8675 050578	OLEG VOROBEV	{"email": "o_vorobev-1968@postgrespro.ru", "phone": "+70721557216"}
0005432747946	D15DFE	5389 908321	ANASTASIYA ZAYCEVA	{"email": "anastasiya-zayceva.06061976@postgrespro.ru", "phone": "+70402011387"}
0005432747947	D15DFE	6832 573611	ARINA NAZAROVA	{"phone": "+70707961445"}
0005432747948	DB72B9	7232 192268	TATYANA GAVRILOVA	{"email": "gavrilovat.011971@postgrespro.ru", "phone": "+70610354670"}
0005432747949	D1FC7D	8598 703226	MAKSIM KOZLOV	{"phone": "+70178152502"}
0005432747950	EAC894	3449 698436	EKATERINA GAVRILOVA	{"phone": "+70529429843"}
0005432747951	40038D	2343 737863	VALERIY SOROKIN	{"phone": "+70383078327"}
0005432747952	092EA7	0707 492525	EKATERINA KISELEVA	{"email": "e.kiseleva-041971@postgrespro.ru", "phone": "+70973466523"}
0005432747953	A0D7D6	1632 622569	MAKSIM KOZLOV	{"email": "m.kozlov.081984@postgrespro.ru", "phone": "+70113032404"}
0005432747954	A0D7D6	0381 685725	YULIYA ROMANOVA	{"email": "yromanova.18041964@postgrespro.ru", "phone": "+70613624028"}
0005432747955	9C7ABF	1033 346255	NATALYA DAVYDOVA	{"email": "natalya.davydova.25051971@postgrespro.ru", "phone": "+70659806024"}
0005432747956	4891A8	5641 618587	OLGA VASILEVA	{"phone": "+70768906427"}
0005432747957	4891A8	9749 824207	GALINA ALEKSEEVA	{"phone": "+70476622389"}
0005432747958	57537E	6008 868305	LYUDMILA EGOROVA	{"phone": "+70915192295"}
0005432747959	D2BCBF	7725 241209	BULAT PETROV	{"email": "petrov_bulat.051966@postgrespro.ru", "phone": "+70677757824"}
0005432747960	D177D8	9572 175042	ALIYA OSIPOVA	{"phone": "+70714996015"}
0005432747961	D177D8	0071 866496	RUSLAN IVANOV	{"email": "ivanov-ruslan30081974@postgrespro.ru", "phone": "+70989116019"}
0005432747962	CAE0D5	7456 654875	MAKSIM MOROZOV	{"email": "morozov-maksim_051966@postgrespro.ru", "phone": "+70175865809"}
0005432747963	CAE0D5	9062 781802	VIKTOR IVANOV	{"phone": "+70775032568"}
0005432747964	C7F3BD	3747 876077	MARINA MOROZOVA	{"phone": "+70351029209"}
0005432747965	1C3672	3205 818727	OLGA BORISOVA	{"phone": "+70340672589"}
0005432747966	7858AB	4040 153694	EKATERINA PETROVA	{"email": "petrova.ekaterina.11021982@postgrespro.ru", "phone": "+70242702407"}
0005432747967	7C6834	6320 772472	ANNA NIKOLAEVA	{"phone": "+70065712174"}
0005432747968	95112E	3046 015137	ARTUR PAVLOV	{"email": "a.pavlov-11041983@postgrespro.ru", "phone": "+70113231572"}
0005432747969	95112E	3361 120475	OLEG NIKITIN	{"email": "oleg-nikitin.18101962@postgrespro.ru", "phone": "+70114225669"}
0005432747970	95112E	2993 441649	SERGEY GORBUNOV	{"phone": "+70871636269"}
0005432747971	D76568	8850 211594	ELENA BELOVA	{"phone": "+70608872177"}
0005432747972	D76568	2226 949533	VYACHESLAV KOZLOV	{"phone": "+70472591896"}
0005432747973	51C703	8101 070306	IRINA KISELEVA	{"phone": "+70339759420"}
0005432747974	956B21	7076 804055	EKATERINA KULIKOVA	{"email": "kulikovae.18051972@postgrespro.ru", "phone": "+70254904838"}
0005432747975	641AAE	0449 785414	YURIY MIRONOV	{"email": "mironov-yuriy.071972@postgrespro.ru", "phone": "+70416469983"}
0005432747976	641AAE	5899 913298	YURIY KOZLOV	{"phone": "+70301941543"}
0005432747977	A0CB0A	7751 147091	VERA NESTEROVA	{"email": "nesterova.vera.061969@postgrespro.ru", "phone": "+70093256732"}
0005432747978	474A96	2765 625238	YURIY ZHUKOV	{"email": "yuriy_zhukov_1967@postgrespro.ru", "phone": "+70533953975"}
0005432747979	6E07A6	9739 009090	NATALYA MIKHAYLOVA	{"phone": "+70239016985"}
0005432747980	43A42E	0365 823207	SERGEY NOVIKOV	{"phone": "+70707895750"}
0005432747981	43A42E	3755 295474	NIKOLAY GORBUNOV	{"phone": "+70638634957"}
0005432747982	E4F3C8	5929 302321	LYUBOV ZAYCEVA	{"email": "lzayceva-17101970@postgrespro.ru", "phone": "+70253414347"}
0005432747983	F30BF3	3701 893903	IGOR ABRAMOV	{"email": "abramovigor1965@postgrespro.ru", "phone": "+70947567085"}
0005432747984	F30BF3	4656 351231	ELIZAVETA FILATOVA	{"phone": "+70754246997"}
0005432747985	8A8771	4853 150013	ANDREY SOLOVEV	{"phone": "+70538442221"}
0005432747986	4B94C2	5147 604708	VADIM IVANOV	{"email": "v_ivanov_071978@postgrespro.ru", "phone": "+70337879427"}
0005432747987	4B94C2	9233 456974	ELIZAVETA NOVIKOVA	{"email": "elizaveta.novikova_031972@postgrespro.ru", "phone": "+70749942300"}
0005432747988	4B94C2	1164 734345	EKATERINA ABRAMOVA	{"phone": "+70218226073"}
0005432747989	F8ABC5	8595 466482	EVGENIY MIKHAYLOV	{"phone": "+70442308705"}
0005432747990	15174A	6626 341817	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova-1975@postgrespro.ru", "phone": "+70943678128"}
0005432747991	AB7F30	0664 495650	NINA IVANOVA	{"email": "ivanova-n_1975@postgrespro.ru", "phone": "+70644042892"}
0005432747992	AB7F30	7705 955116	ALEKSANDR OSIPOV	{"email": "a-osipov.1961@postgrespro.ru", "phone": "+70299072034"}
0005432747993	D8AB71	8477 902950	RUSLAN POPOV	{"phone": "+70747701876"}
0005432747994	FFCDE8	3324 453339	ELENA GORBUNOVA	{"phone": "+70681710962"}
0005432747995	C130DC	5892 742038	ALEKSEY STEPANOV	{"email": "aleksey_stepanov_19051981@postgrespro.ru", "phone": "+70682843579"}
0005432747996	DF68AF	3481 351667	TATYANA DMITRIEVA	{"email": "dmitrieva-t-021977@postgrespro.ru", "phone": "+70922421450"}
0005432747997	4FBAE9	9585 335671	VARVARA LEBEDEVA	{"email": "v.lebedeva.091976@postgrespro.ru", "phone": "+70286470439"}
0005432747998	E03315	5412 191800	EKATERINA GERASIMOVA	{"email": "e-gerasimova_061982@postgrespro.ru", "phone": "+70844066182"}
0005432747999	F77E70	9662 063382	ALEKSEY KULIKOV	{"email": "aleksey-kulikov-1961@postgrespro.ru", "phone": "+70109951234"}
0005432748000	F77E70	9804 650113	NIKOLAY ROMANOV	{"phone": "+70105048251"}
0005432748001	F77E70	2222 652502	KSENIYA KUZNECOVA	{"email": "kkuznecova011987@postgrespro.ru", "phone": "+70768891843"}
0005432748002	F77E70	2885 916827	DANIL SAVELEV	{"email": "savelev_danil22091968@postgrespro.ru", "phone": "+70103380013"}
0005432748003	BD6F04	0251 250402	VLADIMIR DAVYDOV	{"email": "vdavydov.1972@postgrespro.ru", "phone": "+70659752498"}
0005432748004	3DDC85	2616 156644	OLEG TIKHONOV	{"email": "tikhonovo031971@postgrespro.ru", "phone": "+70156282931"}
0005432748005	3DDC85	4834 867491	IRINA TARASOVA	{"phone": "+70843293215"}
0005432748006	195D36	5089 835499	EVGENIYA BOGDANOVA	{"phone": "+70490118921"}
0005432748007	03B2D7	3474 847989	GALINA VOROBEVA	{"email": "g.vorobeva.1959@postgrespro.ru", "phone": "+70989613016"}
0005432748008	03B2D7	0790 287901	IRINA MAKAROVA	{"email": "makarovairina-1970@postgrespro.ru", "phone": "+70119304830"}
0005432748009	8A868B	4208 399572	VLADIMIR ROMANOV	{"email": "romanovv29071966@postgrespro.ru", "phone": "+70520857148"}
0005432748010	AFE538	5340 264607	TATYANA SOKOLOVA	{"phone": "+70181064811"}
0005432748011	FD6A85	2020 687546	VIKTORIYA ALEKSEEVA	{"phone": "+70125657146"}
0005432748012	6A8D0F	5637 377225	RAISA ALEKSEEVA	{"phone": "+70579342838"}
0005432748013	6A8D0F	3649 896649	ALEKSEY KONOVALOV	{"email": "a.konovalov.101967@postgrespro.ru", "phone": "+70368846242"}
0005432748014	6A8D0F	9745 323121	IGOR SEMENOV	{"email": "semenov-igor.1960@postgrespro.ru", "phone": "+70930974143"}
0005432748015	F84247	1325 172479	SERGEY GAVRILOV	{"email": "gavrilovs29011969@postgrespro.ru", "phone": "+70801818942"}
0005432748016	BC3266	3270 696664	DMITRIY GRIGOREV	{"phone": "+70725571862"}
0005432748017	BC3266	9794 608893	SERGEY YAKOVLEV	{"email": "yakovlev_sergey10101976@postgrespro.ru", "phone": "+70059079217"}
0005432748019	5A1CE9	0621 755005	ELENA VOLKOVA	{"email": "volkova-elena1956@postgrespro.ru", "phone": "+70975121612"}
0005432748020	1C7A32	7010 949770	ALEKSANDR SCHERBAKOV	{"phone": "+70428917244"}
0005432748021	C02492	7982 351434	YURIY VOLKOV	{"phone": "+70250295404"}
0005432748022	E8BE5A	8948 061151	GALINA EFIMOVA	{"phone": "+70791335469"}
0005432748023	82606E	8518 065643	NATALIYA KUZNECOVA	{"phone": "+70365877807"}
0005432748024	DDB314	6890 403308	VALERIY BORISOV	{"phone": "+70606420279"}
0005432748025	9F95D2	6118 954968	VLADIMIR MAKSIMOV	{"email": "maksimovvladimir.1976@postgrespro.ru", "phone": "+70893620932"}
0005432748026	9F95D2	3913 454507	VERA KOZLOVA	{"email": "vkozlova-1975@postgrespro.ru", "phone": "+70819519674"}
0005432748027	525F1D	5180 069927	ALINA TIMOFEEVA	{"email": "timofeeva.alina_1967@postgrespro.ru", "phone": "+70450325690"}
0005432748028	FB63D1	0670 813213	ANDREY ABRAMOV	{"email": "andrey_abramov30081970@postgrespro.ru", "phone": "+70362000674"}
0005432748029	CD1A70	1026 112978	ELENA POPOVA	{"phone": "+70279014650"}
0005432748030	7D141B	2875 482703	GALINA TIKHONOVA	{"email": "g_tikhonova-1980@postgrespro.ru", "phone": "+70572414361"}
0005432748031	FAAB71	1132 187833	RAISA KUZMINA	{"phone": "+70980812797"}
0005432748032	CA222B	0873 291571	ALEKSEY NAZAROV	{"email": "aleksey.nazarov.1979@postgrespro.ru", "phone": "+70881744922"}
0005432748033	CA222B	7818 950579	VLADIMIR ROMANOV	{"phone": "+70239790597"}
0005432748034	7BF0FE	7676 362470	NINA NIKITINA	{"email": "nina.nikitina_031970@postgrespro.ru", "phone": "+70076302915"}
0005432748035	D47BCC	7190 033628	IVAN KUZNECOV	{"phone": "+70084003599"}
0005432748036	91EC0A	4191 315118	MIKHAIL SAVELEV	{"phone": "+70121955794"}
0005432748037	91EC0A	6900 264339	OLGA SMIRNOVA	{"email": "smirnova-o-051967@postgrespro.ru", "phone": "+70659636023"}
0005432748038	91EC0A	8311 650538	NIKITA ANDREEV	{"email": "nikita_andreev-1981@postgrespro.ru", "phone": "+70137829448"}
0005432748039	7DDA97	2748 561572	LARISA KOMAROVA	{"phone": "+70379195204"}
0005432748040	1A1D2F	7884 740800	MARIYA SOROKINA	{"email": "m_sorokina1970@postgrespro.ru", "phone": "+70003599603"}
0005432748041	6D48D4	6365 987151	INGA MEDVEDEVA	{"phone": "+70575000340"}
0005432748042	6D48D4	0271 646191	ALEKSANDR KUZNECOV	{"email": "kuznecova_01061981@postgrespro.ru", "phone": "+70331442586"}
0005432748043	61EE95	1761 904379	DMITRIY SMIRNOV	{"email": "dmitriysmirnov_101989@postgrespro.ru", "phone": "+70261759013"}
0005432748044	AAC000	4889 587458	MAKSIM BARANOV	{"email": "maksim.baranov-06031968@postgrespro.ru", "phone": "+70194480750"}
0005432748045	412D67	3886 050736	DANIIL CHERNOV	{"phone": "+70882793000"}
0005432748046	412D67	3842 573585	GALINA KALININA	{"phone": "+70481735579"}
0005432748047	3666B4	7590 622078	SERGEY ZAYCEV	{"phone": "+70506391333"}
0005432748048	2C47E8	7884 845614	NADEZHDA ZAKHAROVA	{"email": "zakharova-nadezhda.1968@postgrespro.ru", "phone": "+70276335592"}
0005432748049	2C47E8	3191 512699	EVGENIY NAZAROV	{"phone": "+70985016070"}
0005432748050	E61D92	6422 555227	TATYANA LAZAREVA	{"phone": "+70701869261"}
0005432748051	E61D92	7790 518057	IRINA DENISOVA	{"email": "i-denisova051979@postgrespro.ru", "phone": "+70166558788"}
0005432748052	619AD2	1484 460495	ALEKSANDR ZHURAVLEV	{"phone": "+70215260485"}
0005432748053	8F04A5	0662 442385	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr-121976@postgrespro.ru", "phone": "+70132602233"}
0005432748054	251424	8001 940603	VLADIMIR FROLOV	{"phone": "+70996699757"}
0005432748055	4DDCFF	7817 260339	ARINA ALEKSEEVA	{"phone": "+70584146700"}
0005432748056	086244	4501 133788	ANDREY VASILEV	{"email": "andrey-vasilev021983@postgrespro.ru", "phone": "+70561827048"}
0005432748057	C8C71E	2417 645128	VLADIMIR BARANOV	{"phone": "+70557201322"}
0005432748058	261665	8853 265699	GALINA MIRONOVA	{"email": "mironovagalina-06021978@postgrespro.ru", "phone": "+70601423894"}
0005432748059	261665	0493 813468	SERGEY POPOV	{"phone": "+70828270298"}
0005432748060	261665	2402 343206	YULIYA KOMAROVA	{"email": "y.komarova_1975@postgrespro.ru", "phone": "+70132351985"}
0005432748061	A21C3E	2684 520997	GALINA YAKOVLEVA	{"phone": "+70010940290"}
0005432748062	DDFD85	7361 539080	YULIYA KOROLEVA	{"email": "yuliyakoroleva.101975@postgrespro.ru", "phone": "+70527183982"}
0005432748063	DDFD85	4297 307251	MIKHAIL ANTONOV	{"phone": "+70219734387"}
0005432748064	E29929	9788 078207	DMITRIY NAZAROV	{"email": "nazarov.dmitriy_10081983@postgrespro.ru", "phone": "+70359894588"}
0005432748065	64444C	3835 051420	ANASTASIYA POPOVA	{"phone": "+70639904231"}
0005432748066	64444C	7269 727885	DMITRIY YAKOVLEV	{"phone": "+70740112012"}
0005432748067	2B878D	0983 055582	ANTON ISAEV	{"email": "a.isaev20121974@postgrespro.ru", "phone": "+70356767702"}
0005432748068	3E6B16	0424 109112	EVGENIYA MAKSIMOVA	{"email": "e.maksimova-1971@postgrespro.ru", "phone": "+70677037367"}
0005432748069	3E6B16	7442 825701	NADEZHDA ROMANOVA	{"email": "nadezhda-romanova-1979@postgrespro.ru", "phone": "+70855268826"}
0005432748070	6C8417	2259 879961	MARIYA NAZAROVA	{"email": "m_nazarova.1964@postgrespro.ru", "phone": "+70832784959"}
0005432748071	FE8075	0658 393675	IVAN ALEKSEEV	{"phone": "+70642661691"}
0005432748072	0039D4	0878 926697	MAYA DAVYDOVA	{"phone": "+70403973744"}
0005432748073	583C34	6734 679138	VALENTINA EGOROVA	{"email": "valentina-egorova051967@postgrespro.ru", "phone": "+70049776920"}
0005432748074	79E964	2913 493229	ALEKSANDR KISELEV	{"email": "akiselev-1976@postgrespro.ru", "phone": "+70416860897"}
0005432748078	D23403	4076 299667	YULIYA POPOVA	{"email": "yuliya-popova_11021984@postgrespro.ru", "phone": "+70331896526"}
0005432748079	D23403	4407 095218	EKATERINA RODIONOVA	{"email": "rodionova.e031964@postgrespro.ru", "phone": "+70706618887"}
0005432748080	A30166	4875 366389	VLADIMIR FOMIN	{"phone": "+70701523664"}
0005432748081	09187C	9767 942793	ANDREY ABRAMOV	{"phone": "+70288163396"}
0005432748082	09187C	9665 223583	OKSANA DMITRIEVA	{"email": "oksana-dmitrieva-1969@postgrespro.ru", "phone": "+70095806949"}
0005432748083	5C650A	7259 894378	ARTEMIY BELOV	{"email": "a.belov.1963@postgrespro.ru", "phone": "+70091247654"}
0005432748084	CAE5C8	4770 271711	IRINA SCHERBAKOVA	{"phone": "+70866258799"}
0005432748085	93691E	7434 408112	IRINA KUZMINA	{"phone": "+70944486896"}
0005432748086	93691E	1009 730187	LYUDMILA KOVALEVA	{"email": "lyudmila_kovaleva-28101972@postgrespro.ru", "phone": "+70610744506"}
0005432748087	075381	9926 107020	VALENTINA CHERNOVA	{"phone": "+70659388689"}
0005432748088	075381	5944 013820	NINA FILIPPOVA	{"email": "filippova-n27081975@postgrespro.ru", "phone": "+70573236490"}
0005432748089	F4D6FA	7038 078562	NATALYA KULIKOVA	{"email": "kulikovanatalya-01111977@postgrespro.ru", "phone": "+70860508710"}
0005432748090	3828ED	7608 948731	OLEG DENISOV	{"email": "o-denisov091975@postgrespro.ru", "phone": "+70359143304"}
0005432748091	6CCA25	2646 571962	EVGENIYA LEBEDEVA	{"email": "lebedeva_evgeniya-1973@postgrespro.ru", "phone": "+70860596349"}
0005432748092	5975D1	9468 582990	IGOR MAKSIMOV	{"phone": "+70912422746"}
0005432748093	FFAC26	4139 958452	ALEKSANDR ALEKSEEV	{"phone": "+70891827072"}
0005432748094	4715E7	6831 312232	OLGA IVANOVA	{"email": "olga.ivanova031970@postgrespro.ru", "phone": "+70249542831"}
0005432748095	1D9435	8262 771335	OLGA SMIRNOVA	{"email": "smirnova_o021962@postgrespro.ru", "phone": "+70063952746"}
0005432748096	B59BE5	5615 377638	YURIY NIKITIN	{"email": "yuriynikitin26061968@postgrespro.ru", "phone": "+70697341520"}
0005432748097	45FE73	3375 657638	ULYANA KUZNECOVA	{"phone": "+70831177649"}
0005432748098	743B65	5880 913112	ARTEM PAVLOV	{"email": "apavlov_121975@postgrespro.ru", "phone": "+70182429202"}
0005432748099	98ABE4	6867 659925	VASILIY ROMANOV	{"phone": "+70570508046"}
0005432748100	953AB1	1786 669907	TATYANA NAUMOVA	{"email": "tnaumova-18111972@postgrespro.ru", "phone": "+70116684340"}
0005432748101	7A336B	1228 492362	MAKSIM MAKAROV	{"phone": "+70900174179"}
0005432748102	7A336B	7749 892594	TAMARA SEMENOVA	{"phone": "+70744989783"}
0005432748103	7B19E8	6485 908185	LYUBOV ARKHIPOVA	{"phone": "+70135204520"}
0005432748104	112861	6677 735923	ALEKSANDR STEPANOV	{"email": "a.stepanov-091966@postgrespro.ru", "phone": "+70618697612"}
0005432748105	544E65	2202 575134	VADIM MEDVEDEV	{"email": "v_medvedev041974@postgrespro.ru", "phone": "+70295678121"}
0005432748106	973002	1923 225343	DMITRIY ILIN	{"email": "dmitriyilin.04051975@postgrespro.ru", "phone": "+70552260672"}
0005432748107	92DB19	1375 623786	VALENTINA CHERNOVA	{"email": "vchernova1972@postgrespro.ru", "phone": "+70400400870"}
0005432748108	C934FF	2099 720735	OLGA IVANOVA	{"phone": "+70524131611"}
0005432748109	C934FF	8161 376946	ALIYA KISELEVA	{"email": "kiseleva-a_20111978@postgrespro.ru", "phone": "+70121020580"}
0005432748110	0BB816	4745 364721	OLGA ANISIMOVA	{"email": "anisimova_o_1986@postgrespro.ru", "phone": "+70157778130"}
0005432748111	0BB816	9860 076078	SERGEY PETROV	{"phone": "+70259314744"}
0005432748112	0BB816	5743 807422	SVETLANA IVANOVA	{"email": "ivanova-svetlana-03071969@postgrespro.ru", "phone": "+70492210575"}
0005432748113	AE80C5	1198 727071	EKATERINA MEDVEDEVA	{"email": "medvedeva_e1968@postgrespro.ru", "phone": "+70831933469"}
0005432748114	FCC3DB	6416 915189	GALINA NIKOLAEVA	{"email": "nikolaevag21051972@postgrespro.ru", "phone": "+70765982006"}
0005432748115	4281BF	7685 983849	ALEKSANDR MOROZOV	{"phone": "+70749191582"}
0005432748116	EAE53C	7715 859004	NATALYA LUKYANOVA	{"email": "natalya_lukyanova.061981@postgrespro.ru", "phone": "+70048884824"}
0005432748117	74CD7A	1620 828267	ELENA MAKSIMOVA	{"email": "maksimova_e-01051974@postgrespro.ru", "phone": "+70028236553"}
0005432748118	10598D	6219 779958	ALEKSEY ANDREEV	{"phone": "+70007426030"}
0005432748119	E94F24	9010 921949	OLGA ILINA	{"email": "oilina-071978@postgrespro.ru", "phone": "+70709318954"}
0005432748120	920269	9400 763032	VERONIKA KOMAROVA	{"email": "komarova_veronika_30121964@postgrespro.ru", "phone": "+70894925147"}
0005432748121	920269	2639 169752	DMITRIY OSIPOV	{"email": "d.osipov-14091968@postgrespro.ru", "phone": "+70143420233"}
0005432748122	F9188F	9756 990813	TAMARA LEBEDEVA	{"email": "lebedeva-tamara1974@postgrespro.ru", "phone": "+70802270308"}
0005432748123	7D6DC5	2002 698080	ELIZAVETA NAUMOVA	{"email": "naumovaelizaveta_111982@postgrespro.ru", "phone": "+70435118110"}
0005432748124	961600	2886 389020	NAILYA ARKHIPOVA	{"phone": "+70418455852"}
0005432748125	961600	4341 307544	ANATOLIY DENISOV	{"email": "a-denisov_20021960@postgrespro.ru", "phone": "+70211493194"}
0005432748126	CD3721	6521 427585	EVELINA VASILEVA	{"email": "evelina.vasileva-101977@postgrespro.ru", "phone": "+70227549623"}
0005432748127	CD3721	7259 234763	OKSANA CHERNOVA	{"email": "o-chernova091980@postgrespro.ru", "phone": "+70804556706"}
0005432748128	9D99EB	9435 969276	OLGA YAKOVLEVA	{"email": "olga.yakovleva-1967@postgrespro.ru", "phone": "+70175110689"}
0005432748129	A52D47	4158 554088	TATYANA NESTEROVA	{"phone": "+70797215639"}
0005432748130	A52D47	2926 460266	SERGEY KUDRYASHOV	{"email": "kudryashov_s-1975@postgrespro.ru", "phone": "+70048176522"}
0005432748131	FF8B7B	9315 643877	GALINA SIDOROVA	{"email": "gsidorova.22061969@postgrespro.ru", "phone": "+70300587441"}
0005432748132	45C9AE	6997 093174	RUSTAM VOROBEV	{"phone": "+70413439893"}
0005432748133	0A462A	3331 992330	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin_1965@postgrespro.ru", "phone": "+70441436473"}
0005432748134	98438B	9614 926753	VIKTOR SEMENOV	{"phone": "+70325675833"}
0005432748135	D27599	7173 020199	ALEKSANDR DENISOV	{"phone": "+70112308987"}
0005432748136	223D8E	3776 853030	VALENTINA FILIPPOVA	{"email": "vfilippova_29101982@postgrespro.ru", "phone": "+70751357908"}
0005432748137	A60F9D	5772 053208	ANNA ZHURAVLEVA	{"email": "anna.zhuravleva_1970@postgrespro.ru", "phone": "+70097335712"}
0005432748138	A60F9D	9403 603485	DANIIL BARANOV	{"phone": "+70024819243"}
0005432748139	A60F9D	5114 416523	VITALIY IVANOV	{"email": "ivanov.v.14111976@postgrespro.ru", "phone": "+70186994906"}
0005432748140	65BB47	1010 766003	NIKITA SEMENOV	{"phone": "+70888510090"}
0005432748141	65BB47	6812 777450	MARINA ILINA	{"phone": "+70792087827"}
0005432748142	C5D7D3	4132 809166	VLADISLAV ALEKSEEV	{"email": "vladislav.alekseev.071973@postgrespro.ru", "phone": "+70800135101"}
0005432748143	C5D7D3	8025 799457	TATYANA DMITRIEVA	{"phone": "+70343724704"}
0005432748144	1055D7	0123 045498	ARTEM KISELEV	{"phone": "+70037714468"}
0005432748145	8A32C9	3733 299959	YULIYA ORLOVA	{"email": "orlova_yuliya_25111971@postgrespro.ru", "phone": "+70277973053"}
0005432748146	B1EB5A	7024 301844	KONSTANTIN MELNIKOV	{"phone": "+70090055240"}
0005432748147	0035B5	5048 450226	IRINA KUDRYASHOVA	{"email": "irina.kudryashova.081964@postgrespro.ru", "phone": "+70150011367"}
0005432748148	8EBE01	1283 469176	TATYANA ALEKSEEVA	{"email": "alekseevatatyana05061981@postgrespro.ru", "phone": "+70786166078"}
0005432748149	177370	4294 816951	ELENA GORBUNOVA	{"phone": "+70310404309"}
0005432748150	177370	6792 646707	ALEKSANDRA KAZAKOVA	{"phone": "+70543625353"}
0005432748151	BC573C	4569 459266	IVAN PETROV	{"phone": "+70690128698"}
0005432748152	DD9112	1901 936164	EKATERINA NAUMOVA	{"email": "naumovae.23081978@postgrespro.ru", "phone": "+70508076234"}
0005432748153	EFB234	6122 521397	OLGA NESTEROVA	{"phone": "+70581268618"}
0005432748154	EFB234	9367 946282	ALEKSANDR SMIRNOV	{"phone": "+70862849819"}
0005432748155	AEAA2B	0266 956472	PAVEL TARASOV	{"phone": "+70219572900"}
0005432748156	479588	3208 621890	NIKOLAY EGOROV	{"phone": "+70072875242"}
0005432748157	3D8140	9953 827705	NIKITA MOISEEV	{"phone": "+70041458002"}
0005432748158	6DEA38	5850 418278	SERGEY FROLOV	{"email": "frolov_s1978@postgrespro.ru", "phone": "+70468641006"}
0005432748159	7DCF6D	5252 430032	KIRILL TIKHONOV	{"email": "k-tikhonov-1978@postgrespro.ru", "phone": "+70666676128"}
0005432748160	A044A3	7194 934493	VLADIMIR VASILEV	{"email": "v-vasilev.041986@postgrespro.ru", "phone": "+70342294136"}
0005432748161	45F644	1440 870728	GULNAZ OSIPOVA	{"phone": "+70346796917"}
0005432748162	3F5D87	0613 887955	ELENA ORLOVA	{"email": "orlova-e_1973@postgrespro.ru", "phone": "+70036125829"}
0005432748163	6E4FD4	1551 326729	SAMIR PAVLOV	{"phone": "+70644817224"}
0005432748164	4EC6D9	9151 987693	YURIY FEDOTOV	{"phone": "+70684854938"}
0005432748165	23706D	2782 141805	EKATERINA FOMINA	{"email": "ekaterinafomina_24081972@postgrespro.ru", "phone": "+70013862134"}
0005432748166	9CF3BD	8185 562219	SVETLANA VOROBEVA	{"phone": "+70917140479"}
0005432748167	03E5D0	2887 594474	VLADIMIR VOROBEV	{"email": "vorobev_v.1980@postgrespro.ru", "phone": "+70182848725"}
0005432748168	03E5D0	1436 650870	VLADIMIR BARANOV	{"email": "vladimir.baranov03021969@postgrespro.ru", "phone": "+70363325300"}
0005432748169	DC5B31	2282 909146	MARIYA KUZNECOVA	{"phone": "+70627785554"}
0005432748170	DC5B31	0392 212797	VALENTINA SOLOVEVA	{"phone": "+70122833801"}
0005432748171	129FF8	2266 990558	YULIYA MAKAROVA	{"phone": "+70861272653"}
0005432748172	129FF8	9009 788624	MAKSIM IVANOV	{"email": "m_ivanov01051985@postgrespro.ru", "phone": "+70415847182"}
0005432748173	A48BD9	5768 723126	GERMAN AFANASEV	{"email": "g_afanasev17041981@postgrespro.ru", "phone": "+70424021688"}
0005432748174	E17AB9	0400 839447	DMITRIY BELOV	{"phone": "+70930215139"}
0005432748175	E17AB9	1687 863688	VALERIY KOROLEV	{"phone": "+70083701455"}
0005432748176	4DCBB0	5996 519303	ALEKSANDR MARTYNOV	{"phone": "+70594252072"}
0005432748177	F02358	8998 925754	IRINA MASLOVA	{"email": "maslova_irina.22041968@postgrespro.ru", "phone": "+70117052602"}
0005432748178	F02358	8629 755619	EKATERINA PETROVA	{"phone": "+70742852898"}
0005432748179	F02358	6522 984251	ANASTASIYA BELOVA	{"phone": "+70896091803"}
0005432748180	5D646C	5311 024493	DMITRIY FEDOTOV	{"email": "d-fedotov051966@postgrespro.ru", "phone": "+70317903691"}
0005432748181	A21906	0844 947899	VALENTINA ROMANOVA	{"email": "romanova-v.1970@postgrespro.ru", "phone": "+70411590441"}
0005432748182	EE4A83	2848 845029	ANTON KONOVALOV	{"email": "konovalov.a_011980@postgrespro.ru", "phone": "+70716900390"}
0005432748183	EE4A83	7710 183018	VALENTINA ALEKSEEVA	{"email": "alekseevavalentina30041976@postgrespro.ru", "phone": "+70091588397"}
0005432748184	C4270D	5055 642578	ULYANA SERGEEVA	{"email": "sergeeva_u1982@postgrespro.ru", "phone": "+70833374833"}
0005432748185	C4270D	4203 427481	VLADIMIR ROMANOV	{"phone": "+70406210359"}
0005432748186	AD767F	5384 232413	VASILIY TIMOFEEV	{"phone": "+70586029333"}
0005432748187	AD767F	3768 781418	ANNA KUZNECOVA	{"email": "a-kuznecova_1971@postgrespro.ru", "phone": "+70609478071"}
0005432748188	B5D58B	8797 478913	NATALIYA TARASOVA	{"phone": "+70723719498"}
0005432748189	9187FD	5485 613157	NINA GERASIMOVA	{"phone": "+70579772514"}
0005432748190	65EE74	7284 082307	OLGA IVANOVA	{"email": "olgaivanova.021972@postgrespro.ru", "phone": "+70918380711"}
0005432748191	65EE74	6141 229955	TATYANA DENISOVA	{"email": "denisova-tatyana1970@postgrespro.ru", "phone": "+70988898574"}
0005432748192	65E58D	6589 361882	PAVEL ZAKHAROV	{"email": "zakharovp.1968@postgrespro.ru", "phone": "+70632003474"}
0005432748193	05A081	7236 153623	MIKHAIL ZAKHAROV	{"phone": "+70534258640"}
0005432748194	244568	4866 506699	YULIYA BELOVA	{"phone": "+70872084969"}
0005432748195	B75880	0883 076324	ALEKSANDR SOROKIN	{"phone": "+70971356328"}
0005432748196	6916AA	7033 678269	ANDREY NOVIKOV	{"phone": "+70023088919"}
0005432748197	6916AA	5159 454336	VYACHESLAV NAUMOV	{"phone": "+70967916448"}
0005432748198	738044	1931 096156	NATALIYA POLYAKOVA	{"email": "polyakova-n1963@postgrespro.ru", "phone": "+70202464371"}
0005432748199	81B611	7869 871421	EVGENIY STEPANOV	{"email": "stepanov-evgeniy-101974@postgrespro.ru", "phone": "+70112980243"}
0005432748200	81B611	3727 744776	LYUDMILA FILATOVA	{"phone": "+70557609459"}
0005432748201	CE21D5	0209 879101	ALEKSANDR MOISEEV	{"email": "aleksandrmoiseev.121963@postgrespro.ru", "phone": "+70137303122"}
0005432748202	913789	5350 427157	EVGENIY SERGEEV	{"email": "sergeev_evgeniy.111978@postgrespro.ru", "phone": "+70990456220"}
0005432748203	913789	3074 891123	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov10021976@postgrespro.ru", "phone": "+70870653485"}
0005432748204	B36017	8721 378389	EKATERINA EGOROVA	{"phone": "+70844986285"}
0005432748205	B142B8	7430 449939	SERGEY KARPOV	{"email": "karpov.sergey1970@postgrespro.ru", "phone": "+70620667693"}
0005432748206	1E3056	2538 410059	NATALYA SMIRNOVA	{"phone": "+70580720232"}
0005432748207	1E3056	6030 407242	IRINA ANDREEVA	{"phone": "+70335827983"}
0005432748208	9F4917	0979 192260	NIKOLAY MELNIKOV	{"email": "nmelnikov-12071978@postgrespro.ru", "phone": "+70987245830"}
0005432748209	9F4917	8736 043096	NIKOLAY MIKHAYLOV	{"phone": "+70744261128"}
0005432748210	25795F	9340 558901	ARTEM KOZLOV	{"email": "a-kozlov-15041981@postgrespro.ru", "phone": "+70899062015"}
0005432748211	5251FD	2162 035876	VYACHESLAV EGOROV	{"email": "egorovvyacheslav.101967@postgrespro.ru", "phone": "+70160439969"}
0005432748212	5251FD	0046 677734	ROMAN MELNIKOV	{"email": "melnikov-roman-26021969@postgrespro.ru", "phone": "+70385859733"}
0005432748213	A3F9FE	2344 521680	SERGEY SAVELEV	{"email": "ssavelev_13071970@postgrespro.ru", "phone": "+70300024437"}
0005432748214	A3F9FE	8001 225209	IVAN KISELEV	{"email": "i-kiselev_1971@postgrespro.ru", "phone": "+70228069180"}
0005432748215	44124C	8806 718088	ZOYA VASILEVA	{"email": "z-vasileva_1974@postgrespro.ru", "phone": "+70484062777"}
0005432748216	8E0715	7603 783960	YURIY MAKAROV	{"phone": "+70829553734"}
0005432748217	8E0715	9579 234872	ANDREY MELNIKOV	{"phone": "+70824451293"}
0005432748218	DCA376	5533 110459	SVETLANA POPOVA	{"email": "s.popova-091970@postgrespro.ru", "phone": "+70875405955"}
0005432748219	73A651	3135 070256	ZOYA KOVALEVA	{"email": "z.kovaleva091967@postgrespro.ru", "phone": "+70346308313"}
0005432748220	519E0E	6782 783018	VIKTORIYA KUDRYASHOVA	{"phone": "+70220846064"}
0005432748221	366787	7571 620467	ANDREY ANTONOV	{"email": "antonova-101974@postgrespro.ru", "phone": "+70987195374"}
0005432748222	73DFAE	8046 169222	GALINA FILATOVA	{"phone": "+70387277881"}
0005432748223	583BBA	2783 925063	SVETLANA YAKOVLEVA	{"email": "yakovleva.s1971@postgrespro.ru", "phone": "+70304275182"}
0005432748224	F49258	2348 005085	SERGEY VASILEV	{"email": "sergeyvasilev.031981@postgrespro.ru", "phone": "+70279635461"}
0005432748225	8E863C	5421 726121	ANATOLIY BONDARENKO	{"phone": "+70446961152"}
0005432748226	C1D0BE	9696 204758	ANDREY VLASOV	{"phone": "+70352029359"}
0005432748227	66EE6E	1296 233381	SVETLANA ZAKHAROVA	{"phone": "+70413508071"}
0005432748228	95085C	3338 136181	NIKOLAY NIKITIN	{"email": "n.nikitin_121968@postgrespro.ru", "phone": "+70511929911"}
0005432748229	AD9097	8302 237945	MARIYA GUSEVA	{"email": "mguseva071964@postgrespro.ru", "phone": "+70755154348"}
0005432748230	AD9097	1837 986245	NATALYA IVANOVA	{"phone": "+70653289829"}
0005432748231	AD9097	1677 307648	SERGEY IVANOV	{"phone": "+70034718568"}
0005432748232	4293FD	9494 354132	ANATOLIY MAKSIMOV	{"phone": "+70780626456"}
0005432748233	613652	4921 380592	ELENA KOLESNIKOVA	{"email": "kolesnikova_e_07121971@postgrespro.ru", "phone": "+70195309456"}
0005432748234	613652	3263 714764	NATALYA ZHUKOVA	{"email": "nzhukova_02081980@postgrespro.ru", "phone": "+70143771922"}
0005432748235	754C08	8175 859921	ELENA VLASOVA	{"email": "vlasova_elena1969@postgrespro.ru", "phone": "+70360977551"}
0005432748236	C5C3E5	8510 291223	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov.1979@postgrespro.ru", "phone": "+70960942208"}
0005432748237	EC4A85	1387 001842	VALERIY SOLOVEV	{"phone": "+70187377243"}
0005432748238	2CBEEB	9955 854178	OLGA FOMINA	{"email": "fomina.olga_27071985@postgrespro.ru", "phone": "+70157132094"}
0005432748239	1B66F2	5228 413559	ELENA VOROBEVA	{"email": "e_vorobeva_1958@postgrespro.ru", "phone": "+70510409815"}
0005432748240	863610	8884 272358	ANTON MATVEEV	{"email": "matveev.anton.23051963@postgrespro.ru", "phone": "+70273166050"}
0005432748241	CC2FF2	7888 905254	VADIM NIKOLAEV	{"phone": "+70386420383"}
0005432748242	2D47D0	2561 666912	DARYA AKIMOVA	{"email": "akimova.d-14031964@postgrespro.ru", "phone": "+70491894737"}
0005432748243	2D47D0	9597 033361	LYUDMILA EGOROVA	{"email": "l.egorova-20071976@postgrespro.ru", "phone": "+70285422859"}
0005432748244	408CC5	7535 721714	NINA MELNIKOVA	{"phone": "+70469625307"}
0005432748245	408CC5	7714 703970	TATYANA NIKIFOROVA	{"email": "t.nikiforova-051973@postgrespro.ru", "phone": "+70294388523"}
0005432748246	E3C61A	1348 237801	PAVEL ZAKHAROV	{"email": "zakharov-pavel_1970@postgrespro.ru", "phone": "+70865774418"}
0005432748247	E3C61A	0695 528998	SERGEY FROLOV	{"email": "frolov.s09091969@postgrespro.ru", "phone": "+70751160604"}
0005432748248	7E97B5	7822 927480	SVETLANA DENISOVA	{"email": "denisova_s_16011991@postgrespro.ru", "phone": "+70878240218"}
0005432748249	DAC8BA	9167 339925	TAMARA VOROBEVA	{"phone": "+70513478403"}
0005432748250	74DAD8	6589 298784	VLADIMIR IVANOV	{"phone": "+70996147197"}
0005432748251	AE455A	0437 626204	TATYANA ZOTOVA	{"phone": "+70654711611"}
0005432748252	D6A7BC	8999 316591	SNEZHANA SIDOROVA	{"phone": "+70395461545"}
0005432748253	D6A7BC	7315 676017	ALEKSANDRA POLYAKOVA	{"email": "polyakovaaleksandra08041972@postgrespro.ru", "phone": "+70012696949"}
0005432748254	43647C	7142 729947	ELENA MAKSIMOVA	{"phone": "+70715179861"}
0005432748255	7E84BF	8136 011945	ZINAIDA ILINA	{"phone": "+70974651349"}
0005432748256	555096	5844 322316	IRINA BORISOVA	{"phone": "+70576974807"}
0005432748257	9F9176	5876 829827	VLADIMIR KARPOV	{"phone": "+70115033824"}
0005432748258	3AC4C7	7276 623128	ANTONINA ALEKSANDROVA	{"phone": "+70801987933"}
0005432748259	753241	9131 529264	NINA LEBEDEVA	{"email": "lebedevanina_101967@postgrespro.ru", "phone": "+70940487046"}
0005432748260	065B00	4907 863889	RAISA GUSEVA	{"email": "guseva-raisa21021974@postgrespro.ru", "phone": "+70503343960"}
0005432748261	065B00	4676 978890	NIKITA ANTONOV	{"email": "antonov.nikita-011975@postgrespro.ru", "phone": "+70061508626"}
0005432748262	E6CC15	5355 651993	ALEKSEY GERASIMOV	{"email": "gerasimovaleksey30061967@postgrespro.ru", "phone": "+70161911224"}
0005432748263	E6CC15	9195 850973	DARYA KUZNECOVA	{"email": "kuznecovad07011976@postgrespro.ru", "phone": "+70177187361"}
0005432748264	E6CC15	4544 869029	KONSTANTIN EGOROV	{"email": "egorov_k-051974@postgrespro.ru", "phone": "+70816764729"}
0005432748265	467C60	5476 357170	NINA EGOROVA	{"phone": "+70436212051"}
0005432748266	064884	5452 537378	TIMOFEY POPOV	{"phone": "+70919860857"}
0005432748267	064884	8177 188626	VLADIMIR AFANASEV	{"email": "v.afanasev16011958@postgrespro.ru", "phone": "+70576618811"}
0005432748268	142C65	7614 144653	MAKSIM ANDREEV	{"phone": "+70164668369"}
0005432748269	9BEEE5	9479 429729	VIKTORIYA SOROKINA	{"phone": "+70625584519"}
0005432748270	1D1D81	8095 415404	TATYANA MARTYNOVA	{"phone": "+70434260774"}
0005432748271	1D1D81	0582 230915	ANDREY MIKHAYLOV	{"email": "mikhaylov.andrey_10071978@postgrespro.ru", "phone": "+70467322470"}
0005432748272	F2F3D8	1283 048754	YURIY ZHURAVLEV	{"email": "yuriyzhuravlev-1978@postgrespro.ru", "phone": "+70026488004"}
0005432748273	564BDB	3092 773525	ZINAIDA CHERNOVA	{"phone": "+70716312813"}
0005432748274	9981AA	1120 531174	EGOR ANTONOV	{"email": "antonov_egor-23031968@postgrespro.ru", "phone": "+70866546930"}
0005432748275	9981AA	8217 103054	EKATERINA NIKOLAEVA	{"email": "nikolaeva_e_24051967@postgrespro.ru", "phone": "+70979039583"}
0005432748276	D1ED45	6708 464114	IGOR MARTYNOV	{"email": "i.martynov1975@postgrespro.ru", "phone": "+70351834135"}
0005432748277	9407E1	3927 391383	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-13101967@postgrespro.ru", "phone": "+70569422721"}
0005432748278	9407E1	2158 079120	YULIYA KALININA	{"email": "kalinina_yuliya.1962@postgrespro.ru", "phone": "+70407442608"}
0005432748279	C9EFD4	8239 486827	TATYANA KOROLEVA	{"email": "koroleva-t14091981@postgrespro.ru", "phone": "+70690311527"}
0005432748280	40A56A	2246 586562	SERGEY NIKOLAEV	{"phone": "+70600751162"}
0005432748281	B92B92	3243 216138	IRINA NOVIKOVA	{"phone": "+70180468229"}
0005432748282	B92B92	2037 270588	VLADIMIR BELOV	{"phone": "+70541729857"}
0005432748283	DC9AFB	1607 796610	ANATOLIY BARANOV	{"email": "baranov.a_15101976@postgrespro.ru", "phone": "+70579917549"}
0005432748284	3D553A	0275 954229	OLGA POPOVA	{"phone": "+70106636953"}
0005432748285	3D553A	9818 413437	ALEKSEY SEMENOV	{"phone": "+70593830312"}
0005432748286	2573E3	7675 760450	PAVEL VOROBEV	{"email": "vorobev_pavel03091981@postgrespro.ru", "phone": "+70054738217"}
0005432748287	44749E	9671 268963	ALEKSANDRA KONOVALOVA	{"phone": "+70880328741"}
0005432748288	4E9CF2	1368 854807	LYUBOV SEMENOVA	{"email": "semenova_lyubov_26101964@postgrespro.ru", "phone": "+70311480797"}
0005432748289	4E9CF2	7911 250313	NADEZHDA YUDINA	{"phone": "+70051932466"}
0005432748290	FEF0B7	4428 586905	ALINA TIKHONOVA	{"email": "tikhonovaalina-1974@postgrespro.ru", "phone": "+70505150930"}
0005432748291	F53A0A	6613 694350	VALERIY POPOV	{"email": "popov.v.061967@postgrespro.ru", "phone": "+70349900725"}
0005432748292	67BF81	3171 985870	LYUDMILA SEMENOVA	{"phone": "+70540629706"}
0005432748293	A5CCFE	3583 965942	VITALIY NIKITIN	{"phone": "+70296919584"}
0005432748294	A51305	7536 084511	ELENA TROFIMOVA	{"phone": "+70476262354"}
0005432748295	A55353	7738 912973	ALEKSANDR MOROZOV	{"phone": "+70594360300"}
0005432748296	A55353	0305 611463	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr_051970@postgrespro.ru", "phone": "+70252699798"}
0005432748297	4BCBDC	8626 331044	VERA KUZMINA	{"email": "kuzminavera111975@postgrespro.ru", "phone": "+70530550514"}
0005432748298	F99CA3	0120 320267	MIKHAIL NIKOLAEV	{"phone": "+70287077974"}
0005432748299	ED3642	1939 382019	NATALYA CHERNOVA	{"email": "n-chernova_30061973@postgrespro.ru", "phone": "+70973381514"}
0005432748300	ED3642	4588 968133	RUMIYA ROMANOVA	{"phone": "+70018311927"}
0005432748302	7E33A8	7719 922081	VLADIMIR VASILEV	{"email": "vladimir_vasilev-01061971@postgrespro.ru", "phone": "+70226609404"}
0005432748303	7E33A8	4423 699101	ELENA NESTEROVA	{"phone": "+70701151501"}
0005432748304	6EF6EA	8619 996074	ALEKSANDR FROLOV	{"email": "frolov.aleksandr021975@postgrespro.ru", "phone": "+70338349385"}
0005432748305	AD6236	0606 676071	ILDAR KAZAKOV	{"phone": "+70562293131"}
0005432748306	F31764	8351 285291	VLADIMIR EGOROV	{"email": "vladimir_egorov_1960@postgrespro.ru", "phone": "+70702833068"}
0005432748307	7836DE	3967 878147	MARINA FILIPPOVA	{"phone": "+70231647651"}
0005432748308	7836DE	1193 802654	NATALYA POTAPOVA	{"email": "npotapova021970@postgrespro.ru", "phone": "+70115724924"}
0005432748309	7836DE	6598 072154	TATYANA DENISOVA	{"email": "denisova-tatyana_1967@postgrespro.ru", "phone": "+70037009061"}
0005432748310	6C3A16	7636 999353	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova_111977@postgrespro.ru", "phone": "+70658553011"}
0005432748311	E63611	5883 251823	PAVEL SIDOROV	{"phone": "+70219373294"}
0005432748312	5448A3	4304 676918	SERGEY KUZMIN	{"email": "kuzmin_sergey.011976@postgrespro.ru", "phone": "+70719286634"}
0005432748313	3105C9	5784 782932	ALEKSEY MAKSIMOV	{"phone": "+70262437261"}
0005432748314	703884	3368 029427	ANDREY KONOVALOV	{"email": "a_konovalov091972@postgrespro.ru", "phone": "+70161503715"}
0005432748315	703884	0320 671645	ANDREY KRASNOV	{"phone": "+70373595072"}
0005432748316	40DCA2	3400 043646	VALENTINA ANDREEVA	{"email": "valentina-andreeva-031988@postgrespro.ru", "phone": "+70784441484"}
0005432748317	2B924F	0127 422586	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.061964@postgrespro.ru", "phone": "+70626680040"}
0005432748318	053926	8008 820899	NIKOLAY KAZAKOV	{"phone": "+70484203155"}
0005432748319	7266E1	2101 130079	TIMOFEY EGOROV	{"email": "timofey.egorov.19051969@postgrespro.ru", "phone": "+70254293469"}
0005432748320	7266E1	4279 147111	VLADIMIR PAVLOV	{"email": "pavlov-v_1975@postgrespro.ru", "phone": "+70439824446"}
0005432748321	7266E1	4701 768491	MAKSIM SOLOVEV	{"email": "solovev.m_091978@postgrespro.ru", "phone": "+70556074197"}
0005432748434	E7A27E	0832 093608	VALENTINA NIKITINA	{"phone": "+70757068092"}
0005432748322	61627D	4887 735001	DMITRIY SOROKIN	{"email": "sorokin.dmitriy-01061970@postgrespro.ru", "phone": "+70300622172"}
0005432748323	D2711C	6187 610175	ANZHELIKA KOMAROVA	{"phone": "+70146047123"}
0005432748324	FF2379	6764 817664	OLGA POPOVA	{"phone": "+70315080064"}
0005432748325	FF2379	3793 246955	IRINA PAVLOVA	{"email": "pavlova_i_091976@postgrespro.ru", "phone": "+70407826538"}
0005432748326	673AEF	6486 830104	LARISA ABRAMOVA	{"phone": "+70555829333"}
0005432748327	673AEF	0884 274500	ARTEM IVANOV	{"phone": "+70074298775"}
0005432748328	B49CD8	3954 043754	SERGEY PAVLOV	{"phone": "+70464170699"}
0005432748329	89B519	6721 761523	SERGEY RODIONOV	{"phone": "+70612627019"}
0005432748330	89B519	3346 089290	EVGENIY NAZAROV	{"email": "nazarov-e_011970@postgrespro.ru", "phone": "+70762316071"}
0005432748331	74FD30	6835 970071	ELENA ZAKHAROVA	{"email": "elena_zakharova1970@postgrespro.ru", "phone": "+70866840854"}
0005432748332	784C9A	1970 695772	DMITRIY IVANOV	{"email": "ivanov-d_121966@postgrespro.ru", "phone": "+70363617513"}
0005432748333	DDFE93	2401 552738	RIMMA SIDOROVA	{"email": "r_sidorova.111977@postgrespro.ru", "phone": "+70869327312"}
0005432748334	EA11C3	3489 224441	LUIZA IVANOVA	{"phone": "+70023781237"}
0005432748335	DA2A31	8649 784431	MAKSIM EGOROV	{"phone": "+70223681842"}
0005432748336	9D4994	1652 933094	ALEKSEY SERGEEV	{"email": "sergeev.a_041958@postgrespro.ru", "phone": "+70282455290"}
0005432748337	9D4994	8406 402002	OLGA ROMANOVA	{"email": "o-romanova_111966@postgrespro.ru", "phone": "+70837458377"}
0005432748338	941572	2501 169085	EKATERINA TROFIMOVA	{"email": "trofimova-e_18031982@postgrespro.ru", "phone": "+70007785214"}
0005432748339	941572	2851 679138	TATYANA BELOVA	{"phone": "+70838071441"}
0005432748340	034A52	1310 693611	SERGEY ZAKHAROV	{"phone": "+70255400906"}
0005432748341	034A52	9589 849372	VIKTOR IVANOV	{"email": "ivanovviktor_28081973@postgrespro.ru", "phone": "+70582263250"}
0005432748342	A8366D	7213 664350	ALEKSANDR PETROV	{"phone": "+70837872743"}
0005432748343	8C1E52	6186 304415	IVAN RODIONOV	{"email": "rodionov_i.22101965@postgrespro.ru", "phone": "+70312989991"}
0005432748344	37EB68	9277 205698	IRINA BELYAEVA	{"phone": "+70415393833"}
0005432748345	BB974F	4148 912250	ANATOLIY IVANOV	{"email": "a-ivanov.27081977@postgrespro.ru", "phone": "+70813183964"}
0005432748346	BB974F	6465 378955	POLINA OVCHINNIKOVA	{"email": "p-ovchinnikova-1981@postgrespro.ru", "phone": "+70903004225"}
0005432748347	F351CE	0070 597632	VITALIY ORLOV	{"phone": "+70966474389"}
0005432748348	2F5158	8831 372669	ALEKSANDR ANDREEV	{"phone": "+70290902850"}
0005432748349	A8925C	4007 677532	VLADISLAV STEPANOV	{"phone": "+70421780330"}
0005432748350	F99828	8820 669631	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov-1960@postgrespro.ru", "phone": "+70307843304"}
0005432748351	001F1D	3684 079418	MARINA KARPOVA	{"phone": "+70327027391"}
0005432748352	3023D3	8702 783846	EKATERINA BELYAEVA	{"email": "e.belyaeva1967@postgrespro.ru", "phone": "+70491449602"}
0005432748353	4DA4C7	8649 511560	SVETLANA DENISOVA	{"email": "denisovasvetlana091959@postgrespro.ru", "phone": "+70289902317"}
0005432748354	4DA4C7	1300 263929	ALBINA IVANOVA	{"email": "aivanova.1959@postgrespro.ru", "phone": "+70395703438"}
0005432748355	CC68B8	1375 513439	LYUBOV NAUMOVA	{"phone": "+70646346623"}
0005432748356	6F87E8	0275 216770	OLGA NAZAROVA	{"phone": "+70917371470"}
0005432748357	FD5F71	4325 688398	ALEKSEY VOLKOV	{"phone": "+70797525854"}
0005432748358	A649A5	6296 040191	OLGA NESTEROVA	{"email": "olga_nesterova.24081969@postgrespro.ru", "phone": "+70959871917"}
0005432748359	1663A0	1297 476002	VLADIMIR DMITRIEV	{"email": "vladimirdmitriev.27061970@postgrespro.ru", "phone": "+70746311568"}
0005432748360	AA2DFE	9211 717380	NIKOLAY KAZAKOV	{"email": "kazakov_nikolay101957@postgrespro.ru", "phone": "+70781251927"}
0005432748361	AA2DFE	2567 788250	ELENA SAVELEVA	{"email": "saveleva.e.101971@postgrespro.ru", "phone": "+70677639274"}
0005432748362	677FAD	7010 642964	KAMILLA CHERNOVA	{"phone": "+70727990207"}
0005432748363	84A837	1528 252555	YULIYA MEDVEDEVA	{"email": "medvedeva_y-27091968@postgrespro.ru", "phone": "+70001437727"}
0005432748364	4CA7F2	6435 834807	VALENTINA KUZMINA	{"email": "kuzminavalentina-1973@postgrespro.ru", "phone": "+70469799609"}
0005432748365	4CA7F2	9401 518623	GALINA ROMANOVA	{"phone": "+70497915880"}
0005432748366	57EE4E	3440 586519	MARIYA SOKOLOVA	{"phone": "+70869996116"}
0005432748367	D15D6B	3701 058098	LIDIYA ILINA	{"phone": "+70851054875"}
0005432748368	D15D6B	8463 726835	IRINA RYABOVA	{"email": "irina.ryabova_30071974@postgrespro.ru", "phone": "+70781703755"}
0005432748369	5FFE06	8732 949168	TATYANA MIKHAYLOVA	{"email": "tmikhaylova.05031977@postgrespro.ru", "phone": "+70642660392"}
0005432748370	5FFE06	8682 182918	RAISA BORISOVA	{"phone": "+70339845373"}
0005432748371	09172C	5679 667516	LYUDMILA TARASOVA	{"phone": "+70481522166"}
0005432748372	09172C	0716 628327	INNA ALEKSANDROVA	{"phone": "+70944072019"}
0005432748373	896DD2	7387 621040	SERGEY NOVIKOV	{"email": "sergey.novikov-1982@postgrespro.ru", "phone": "+70906869834"}
0005432748374	D0D0AD	7330 975106	NADEZHDA SERGEEVA	{"email": "n_sergeeva1974@postgrespro.ru", "phone": "+70348424553"}
0005432748375	82E716	2449 085987	ANDREY FOMIN	{"email": "a_fomin_071974@postgrespro.ru", "phone": "+70158134587"}
0005432748376	F699AC	5853 375699	ROSTISLAV NIKOLAEV	{"phone": "+70643594129"}
0005432748377	4E24D6	3814 201462	MARIYA KUZNECOVA	{"phone": "+70664737000"}
0005432748378	8D719F	9467 030799	SERGEY NAZAROV	{"email": "s_nazarov_15031988@postgrespro.ru", "phone": "+70466276104"}
0005432748379	008130	5763 381650	ANTONINA NAZAROVA	{"phone": "+70347479985"}
0005432748380	008130	6070 712476	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov.081960@postgrespro.ru", "phone": "+70854594483"}
0005432748381	008130	3027 237357	VITALIY VOLKOV	{"phone": "+70859768190"}
0005432748382	B96D96	1378 697970	SVETLANA BELOVA	{"email": "belova.svetlana011970@postgrespro.ru", "phone": "+70981681072"}
0005432748383	D94CDE	9581 951611	ILYA SEMENOV	{"email": "semenov.i_031967@postgrespro.ru", "phone": "+70442009604"}
0005432748384	A2C771	6791 996634	OLGA TARASOVA	{"phone": "+70858377710"}
0005432748385	A2C771	0972 444800	NINA KONOVALOVA	{"email": "konovalovan.011971@postgrespro.ru", "phone": "+70502716995"}
0005432748386	45409E	2915 017116	VIKTOR SOKOLOV	{"phone": "+70682241067"}
0005432748387	FD4032	3691 324341	SEMEN MAKAROV	{"email": "makarov-s.101972@postgrespro.ru", "phone": "+70054369305"}
0005432748388	FD4032	8700 273091	ALEKSEY MATVEEV	{"phone": "+70042016621"}
0005432748389	64F000	7135 376711	VALENTINA ALEKSANDROVA	{"email": "aleksandrovav_1983@postgrespro.ru", "phone": "+70776356021"}
0005432748390	64F000	9968 542782	SEMEN BELOV	{"phone": "+70992702881"}
0005432748391	4932F7	6980 477963	NIKOLAY KUZNECOV	{"phone": "+70219734810"}
0005432748392	5091F5	7163 310815	KIRA ANDREEVA	{"email": "andreevak.25051980@postgrespro.ru", "phone": "+70551612415"}
0005432748393	5091F5	1600 847197	KRISTINA POTAPOVA	{"email": "potapovak.1981@postgrespro.ru", "phone": "+70983247843"}
0005432748394	5091F5	6940 575403	LIDIYA LEBEDEVA	{"phone": "+70721446208"}
0005432748395	77BAC4	7961 654903	LYUDMILA NIKOLAEVA	{"email": "l_nikolaeva_06081978@postgrespro.ru", "phone": "+70336782133"}
0005432748396	FB3747	4756 626712	OLGA IVANOVA	{"phone": "+70210087023"}
0005432748397	72CA0C	3479 692004	YULIYA POPOVA	{"phone": "+70500180606"}
0005432748398	72CA0C	3343 033745	TATYANA NIKITINA	{"phone": "+70106011360"}
0005432748399	EA52C3	1693 947374	EVGENIY ALEKSEEV	{"email": "alekseevevgeniy.1984@postgrespro.ru", "phone": "+70620012984"}
0005432748400	EA52C3	9109 311092	NIKOLAY KUZNECOV	{"email": "n_kuznecov1967@postgrespro.ru", "phone": "+70639446220"}
0005432748401	E7DFFC	8952 652610	MIKHAIL PETROV	{"phone": "+70480736677"}
0005432748402	E7DFFC	4061 970559	IRINA ALEKSEEVA	{"email": "alekseevairina-111966@postgrespro.ru", "phone": "+70357674101"}
0005432748403	8B8FF6	9687 114856	VIKTOR NIKITIN	{"email": "v-nikitin03091973@postgrespro.ru", "phone": "+70173573076"}
0005432748404	8B8FF6	7835 442889	MARINA TITOVA	{"email": "m.titova.1976@postgrespro.ru", "phone": "+70037012640"}
0005432748405	C1F628	9428 423722	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov-1962@postgrespro.ru", "phone": "+70459274626"}
0005432748406	C1F628	7929 254719	ANATOLIY TIKHONOV	{"phone": "+70581911688"}
0005432748407	C884B1	4766 704865	IRINA FROLOVA	{"email": "irina-frolova_121973@postgrespro.ru", "phone": "+70115220639"}
0005432748408	C884B1	2914 455487	VALENTINA IVANOVA	{"phone": "+70571230514"}
0005432748409	6617BD	8242 198435	MIKHAIL MAKSIMOV	{"phone": "+70140295974"}
0005432748410	6617BD	6703 596932	GUZEL KONDRATEVA	{"phone": "+70194283517"}
0005432748411	6617BD	3912 307345	ALINA STEPANOVA	{"phone": "+70871727757"}
0005432748412	17CA06	2530 861986	VALENTINA KALININA	{"phone": "+70830537506"}
0005432748413	4AED6E	1268 921936	TIMOFEY ISAEV	{"email": "timofey_isaev.061970@postgrespro.ru", "phone": "+70813302953"}
0005432748414	36D60B	8150 664034	EVGENIY CHERNOV	{"email": "chernov-evgeniy25111973@postgrespro.ru", "phone": "+70370832251"}
0005432748415	A5703B	9277 946026	ALEKSEY MIKHAYLOV	{"phone": "+70815129347"}
0005432748416	A5703B	4814 678960	VALENTINA MATVEEVA	{"phone": "+70779131569"}
0005432748417	A5703B	2186 234247	VLADIMIR VOLKOV	{"phone": "+70366237541"}
0005432748418	C31375	3925 802531	OKSANA MAKAROVA	{"phone": "+70870557514"}
0005432748419	C31375	7661 365917	VLADIMIR PAVLOV	{"phone": "+70312071520"}
0005432748420	182031	8838 528297	ZINAIDA GERASIMOVA	{"phone": "+70348904612"}
0005432748421	93C84E	1924 491113	SERGEY MATVEEV	{"phone": "+70629213675"}
0005432748422	2EF857	8042 461229	IGOR DENISOV	{"email": "igordenisov_13091973@postgrespro.ru", "phone": "+70710901735"}
0005432748423	E3012C	3689 653139	OLGA LAZAREVA	{"phone": "+70858961614"}
0005432748424	EAB2F2	8974 923928	VLADIMIR SEMENOV	{"email": "vladimir.semenov-05091977@postgrespro.ru", "phone": "+70412568106"}
0005432748425	B0FBE8	2877 029974	BORIS KISELEV	{"email": "b_kiselev-091986@postgrespro.ru", "phone": "+70587836181"}
0005432748426	78595D	3925 486471	ALEKSANDR VLASOV	{"phone": "+70583561703"}
0005432748427	78595D	2674 827626	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr19041971@postgrespro.ru", "phone": "+70042044548"}
0005432748428	43C65A	1216 566411	ANTONINA BELOVA	{"email": "antoninabelova-17051981@postgrespro.ru", "phone": "+70213543971"}
0005432748429	43C65A	5859 725420	IGOR TARASOV	{"phone": "+70453551270"}
0005432748430	E4E6AE	0918 451182	IRINA VASILEVA	{"email": "vasileva.irina_08091964@postgrespro.ru", "phone": "+70919193168"}
0005432748431	E4E6AE	5893 385083	VYACHESLAV GUSEV	{"email": "gusev.vyacheslav-1972@postgrespro.ru", "phone": "+70000808966"}
0005432748432	F69106	3404 065098	EKATERINA GORBUNOVA	{"email": "gorbunova_ekaterina_051979@postgrespro.ru", "phone": "+70974085634"}
0005432748433	FFBB19	0943 485533	VITALIY NAUMOV	{"email": "v_naumov_081980@postgrespro.ru", "phone": "+70892283283"}
0005432748435	E7A27E	2137 451484	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-28061972@postgrespro.ru", "phone": "+70436058693"}
0005432748436	47F01A	0070 936143	TATYANA ISAEVA	{"phone": "+70263068118"}
0005432748437	D8807B	3379 446748	EKATERINA KUZNECOVA	{"email": "kuznecova-e061979@postgrespro.ru", "phone": "+70717690068"}
0005432748438	D8807B	6782 137985	SERGEY SOLOVEV	{"email": "solovev_s-041957@postgrespro.ru", "phone": "+70062700301"}
0005432748439	9ABE62	9291 684068	LIDIYA DAVYDOVA	{"phone": "+70926553349"}
0005432748440	9ABE62	0934 034036	VIKTOR TIMOFEEV	{"phone": "+70765442407"}
0005432748441	4CF04E	4419 805267	GALINA EGOROVA	{"email": "egorovag-071967@postgrespro.ru", "phone": "+70139664445"}
0005432748442	BE2939	5826 533145	VASILIY DENISOV	{"phone": "+70627995681"}
0005432748443	0C9560	6100 246293	ALEKSEY FILIPPOV	{"email": "a.filippov011985@postgrespro.ru", "phone": "+70079396464"}
0005432748444	76701E	3977 613359	EKATERINA VOLKOVA	{"phone": "+70037913139"}
0005432748445	76701E	7358 396416	VLADISLAV FEDOTOV	{"phone": "+70060225794"}
0005432748446	76701E	3292 904462	OKSANA ILINA	{"phone": "+70727829882"}
0005432748447	A00D7F	7042 997647	RAISA BELYAEVA	{"email": "belyaeva.r11011971@postgrespro.ru", "phone": "+70925956515"}
0005432748448	A00D7F	1752 496258	MARIYA BOGDANOVA	{"phone": "+70152778544"}
0005432748449	0EF59D	1731 086787	TATYANA POLYAKOVA	{"phone": "+70943701531"}
0005432748450	AEB3A9	8792 428414	TATYANA KOMAROVA	{"phone": "+70589073560"}
0005432748451	7D3FC8	1750 731187	TATYANA PETROVA	{"phone": "+70551327798"}
0005432748452	22CD61	6748 139413	TIGRAN KRASNOV	{"phone": "+70969540549"}
0005432748453	8CC604	4246 893554	ARINA IVANOVA	{"phone": "+70279510763"}
0005432748454	06205A	5676 607625	DMITRIY ZAKHAROV	{"phone": "+70977917045"}
0005432748455	7CCC98	5587 491347	LARISA KAZAKOVA	{"email": "kazakova_l_111984@postgrespro.ru", "phone": "+70459004645"}
0005432748456	7CCC98	3068 623358	MIKHAIL KUZMIN	{"phone": "+70782857233"}
0005432748457	2D3F80	3376 744304	ANDREY ZHUKOV	{"phone": "+70320856300"}
0005432748458	2D3F80	5989 196930	YULIYA ZHUKOVA	{"email": "zhukova.y.011971@postgrespro.ru", "phone": "+70579313554"}
0005432748459	36E37A	3192 630506	NADEZHDA KOVALEVA	{"email": "n_kovaleva1964@postgrespro.ru", "phone": "+70755437168"}
0005432748460	2CFA58	3198 866959	NATALYA VOROBEVA	{"phone": "+70263584609"}
0005432748461	A0AFE3	3014 026810	OKSANA SEMENOVA	{"email": "o-semenova_121979@postgrespro.ru", "phone": "+70533837724"}
0005432748462	746129	9560 074008	VALENTINA KUZNECOVA	{"phone": "+70074787503"}
0005432748463	5CC51E	2876 498759	NIKOLAY KISELEV	{"phone": "+70174616243"}
0005432748464	C2C837	8435 292443	YULIYA MASLOVA	{"email": "maslova_y_27081974@postgrespro.ru", "phone": "+70918153875"}
0005432748465	C2C837	1179 881093	IRINA VOLKOVA	{"phone": "+70269941193"}
0005432748466	85DDCB	5859 917984	GALINA SIDOROVA	{"email": "sidorova.galina-09041967@postgrespro.ru", "phone": "+70826988211"}
0005432748467	E2882D	0796 451148	NIKITA DAVYDOV	{"email": "n_davydov.111972@postgrespro.ru", "phone": "+70459022021"}
0005432748468	12021F	6139 790329	IGOR POPOV	{"phone": "+70201516277"}
0005432748469	C4DAE3	6688 965794	DMITRIY KUZNECOV	{"phone": "+70030625726"}
0005432748470	ECB733	9552 174112	ALEKSEY IVANOV	{"email": "ivanov.aleksey30081970@postgrespro.ru", "phone": "+70582711566"}
0005432748472	B275C2	7954 585197	SAVELIY KISELEV	{"phone": "+70319980256"}
0005432748473	BEE1DF	6476 893603	SERGEY ISAEV	{"phone": "+70648336313"}
0005432748474	914CB2	8024 008573	SERGEY POPOV	{"phone": "+70662886054"}
0005432748475	839A73	9890 837370	NATALYA TITOVA	{"email": "n.titova-121980@postgrespro.ru", "phone": "+70777701117"}
0005432748476	4758A3	7736 119378	MARGARITA PETROVA	{"email": "m_petrova_091971@postgrespro.ru", "phone": "+70208348508"}
0005432748477	4758A3	7450 306764	VLADIMIR POPOV	{"email": "v.popov-1977@postgrespro.ru", "phone": "+70327362321"}
0005432748478	300F1F	2390 034222	EKATERINA KULIKOVA	{"phone": "+70267138512"}
0005432748479	300F1F	1670 053333	ARTEM TIMOFEEV	{"phone": "+70499660639"}
0005432748480	A72396	3534 091469	OLGA ROMANOVA	{"phone": "+70962630087"}
0005432748481	AC2A91	6802 157671	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-1962@postgrespro.ru", "phone": "+70911634772"}
0005432748482	072986	1986 259144	EKATERINA NIKOLAEVA	{"phone": "+70805720535"}
0005432748483	C2EDDA	7785 386042	ARTEM KULIKOV	{"phone": "+70877824274"}
0005432748484	D958F6	3543 340599	IVAN BELOV	{"email": "i.belov24011962@postgrespro.ru", "phone": "+70049385592"}
0005432748485	1ECAA9	8771 786896	ALEKSANDR STEPANOV	{"email": "stepanov.a_24051970@postgrespro.ru", "phone": "+70138741627"}
0005432748486	E69F10	0831 165936	NADEZHDA NAUMOVA	{"email": "nadezhda.naumova_081977@postgrespro.ru", "phone": "+70814769576"}
0005432748487	E69F10	9127 149047	ANATOLIY SOLOVEV	{"email": "anatoliy_solovev.1971@postgrespro.ru", "phone": "+70275284905"}
0005432748488	A5FD73	3450 229904	ROMAN MATVEEV	{"email": "matveev-roman08111971@postgrespro.ru", "phone": "+70412670059"}
0005432748489	90276E	2702 615001	ALEKSANDR BONDARENKO	{"email": "bondarenko_a-31101978@postgrespro.ru", "phone": "+70298210653"}
0005432748490	60D60B	4251 499006	NIKITA KOROLEV	{"email": "korolev_n_28051970@postgrespro.ru", "phone": "+70156236008"}
0005432748491	60D60B	6321 248431	ALEKSEY MARTYNOV	{"phone": "+70409626718"}
0005432748492	60D60B	5065 645664	SERGEY MAKSIMOV	{"email": "maksimov_s1966@postgrespro.ru", "phone": "+70488030153"}
0005432748493	39B46A	9360 236358	EVGENIY VOROBEV	{"email": "vorobev.evgeniy18111971@postgrespro.ru", "phone": "+70211055185"}
0005432748494	D27117	1231 677626	ARTUR CHERNOV	{"phone": "+70725757644"}
0005432748495	5BE7F6	7566 746620	ARTEM BARANOV	{"phone": "+70241019705"}
0005432748496	B2575B	0778 837409	IGOR KOROLEV	{"phone": "+70763018620"}
0005432748497	ABFE9A	8085 343642	YURIY BONDARENKO	{"phone": "+70096096873"}
0005432748498	A5B6B0	8069 387254	NATALYA OVCHINNIKOVA	{"phone": "+70457659230"}
0005432748499	5571EF	0752 059483	SERGEY GUSEV	{"phone": "+70646154531"}
0005432748500	5571EF	0405 403542	ANTON IVANOV	{"phone": "+70958549456"}
0005432748501	9F3931	3306 365995	DMITRIY GORBUNOV	{"email": "gorbunov_dmitriy.24111980@postgrespro.ru", "phone": "+70145746650"}
0005432748502	5E1365	0645 484036	ZINAIDA MAKAROVA	{"phone": "+70867159372"}
0005432748503	5E1365	5393 606629	NAIL KUZNECOV	{"email": "kuznecov_nail-1974@postgrespro.ru", "phone": "+70327938120"}
0005432748504	5E1365	1617 509809	IGOR GORBUNOV	{"phone": "+70792014224"}
0005432748505	FB8C9A	1561 342709	TAISIYA POLYAKOVA	{"email": "taisiya-polyakova_1975@postgrespro.ru", "phone": "+70409332254"}
0005432748506	357DC0	7883 196527	ALEKSANDR FROLOV	{"phone": "+70681138906"}
0005432748507	7D8C1A	8582 450180	VIKTOR MOROZOV	{"phone": "+70104550496"}
0005432748508	86FFB6	0517 481232	ALEKSEY ILIN	{"phone": "+70378865577"}
0005432748509	84F419	1046 030811	NIKITA IVANOV	{"phone": "+70248948884"}
0005432748510	BC3E32	4417 235080	ROMAN IVANOV	{"phone": "+70372896128"}
0005432748511	B96737	6255 452041	VALENTINA MOROZOVA	{"email": "morozovav_111972@postgrespro.ru", "phone": "+70400989270"}
0005432748512	B96737	2607 636586	VLADIMIR EGOROV	{"phone": "+70962385077"}
0005432748513	4F996D	2918 522066	ALEKSEY GAVRILOV	{"email": "gavrilov-a.22031972@postgrespro.ru", "phone": "+70458418973"}
0005432748514	4F996D	8506 987690	ELENA FADEEVA	{"email": "e_fadeeva091962@postgrespro.ru", "phone": "+70115546759"}
0005432748515	891233	6857 139836	NIKOLAY VASILEV	{"phone": "+70841280903"}
0005432748516	891233	3902 088578	ALEKSANDR ZAKHAROV	{"phone": "+70941672815"}
0005432748517	9A2039	1430 483108	IGOR SAVELEV	{"email": "igor.savelev1975@postgrespro.ru", "phone": "+70939729679"}
0005432748518	D1D12C	4872 479644	LYUDMILA GAVRILOVA	{"email": "l_gavrilova31031979@postgrespro.ru", "phone": "+70908177827"}
0005432748519	97BFAA	4800 057513	DMITRIY SOROKIN	{"email": "dmitriy.sorokin_071970@postgrespro.ru", "phone": "+70915414608"}
0005432748520	97BFAA	6552 095910	OLGA ZAKHAROVA	{"phone": "+70607685371"}
0005432748521	1A080F	2953 910657	VYACHESLAV BONDARENKO	{"email": "bondarenkovyacheslav-061973@postgrespro.ru", "phone": "+70182769318"}
0005432748522	1A080F	3106 076831	ALEKSANDR SOLOVEV	{"email": "asolovev-1969@postgrespro.ru", "phone": "+70785282562"}
0005432748523	ECF7C6	7726 601920	DIANA ANTONOVA	{"phone": "+70302707655"}
0005432748524	D31C57	3294 558465	VERONIKA ROMANOVA	{"phone": "+70885273740"}
0005432748525	B4B493	1055 527316	NIKOLAY ANTONOV	{"email": "nikolay.antonov-08091973@postgrespro.ru", "phone": "+70368257070"}
0005432748526	2C7746	3914 473406	ALLA IVANOVA	{"phone": "+70467495553"}
0005432748527	DE3566	4520 684212	SERGEY KOZLOV	{"email": "kozlov_s_15101966@postgrespro.ru", "phone": "+70267866477"}
0005432748528	E8B1BE	1493 127469	DMITRIY SCHERBAKOV	{"email": "d_scherbakov.06031970@postgrespro.ru", "phone": "+70149169207"}
0005432748529	E87B8C	6770 231383	KRISTINA MAKAROVA	{"email": "k.makarova.121971@postgrespro.ru", "phone": "+70774049848"}
0005432748530	E87B8C	5787 064894	NIKITA NAZAROV	{"email": "nazarov.n.14021970@postgrespro.ru", "phone": "+70683532321"}
0005432748531	9938ED	7103 776825	TATYANA DAVYDOVA	{"email": "davydova.t.19061970@postgrespro.ru", "phone": "+70686301279"}
0005432748532	F32292	3417 552117	SERGEY IVANOV	{"email": "ivanov-s_031983@postgrespro.ru", "phone": "+70975568576"}
0005432748533	757266	2192 233417	TATYANA SOROKINA	{"phone": "+70526559837"}
0005432748534	757266	8729 822048	IRINA BELYAEVA	{"email": "belyaeva-irina1974@postgrespro.ru", "phone": "+70297726893"}
0005432748535	BEB9FC	0063 385884	VALERIY MIRONOV	{"email": "v.mironov.19061969@postgrespro.ru", "phone": "+70340566229"}
0005432748536	F1226D	9307 556607	NIKITA KOROLEV	{"phone": "+70685022134"}
0005432748537	8DF5B1	4181 464583	NATALYA NOVIKOVA	{"phone": "+70466116058"}
0005432748538	B9AA26	8588 701940	ZOYA MOROZOVA	{"email": "zoyamorozova-19051979@postgrespro.ru", "phone": "+70202435714"}
0005432748539	B9AA26	5364 939241	ALENA POLYAKOVA	{"email": "polyakovaalena18061979@postgrespro.ru", "phone": "+70477662202"}
0005432748540	B9AA26	4165 121463	MARIYA KUZMINA	{"email": "mariya_kuzmina1972@postgrespro.ru", "phone": "+70284559281"}
0005432748541	DE02D9	3583 874828	TATYANA SOROKINA	{"phone": "+70334501893"}
0005432748542	AC2EF7	8288 111974	ELENA GAVRILOVA	{"phone": "+70077469615"}
0005432748543	66F521	1600 397578	ALEKSANDR SIDOROV	{"phone": "+70312366698"}
0005432748544	66F521	7914 692115	DANIIL TIKHONOV	{"email": "daniil_tikhonov021968@postgrespro.ru", "phone": "+70334415677"}
0005432748545	B9AEF8	8954 585134	IRINA ANTONOVA	{"email": "i-antonova_111963@postgrespro.ru", "phone": "+70782074764"}
0005432748546	30468A	9992 798252	MIKHAIL NOVIKOV	{"email": "novikov-m1970@postgrespro.ru", "phone": "+70007837138"}
0005432748547	30468A	5383 080143	IVAN ILIN	{"email": "ilin.ivan01041978@postgrespro.ru", "phone": "+70181954997"}
0005432748548	7D0313	0520 074635	NIKOLAY ABRAMOV	{"phone": "+70076549517"}
0005432748549	7D0313	8888 411325	NATALYA DANILOVA	{"email": "n_danilova.091967@postgrespro.ru", "phone": "+70727720949"}
0005432748550	175359	3922 748683	OLGA CHERNOVA	{"email": "ochernova_1969@postgrespro.ru", "phone": "+70238240358"}
0005432748551	A6EBD1	8154 399766	AMINA LOGINOVA	{"phone": "+70517401109"}
0005432748552	CADB8F	3757 415191	NADEZHDA BELOVA	{"email": "belova-n-041975@postgrespro.ru", "phone": "+70845915030"}
0005432748553	670EA4	3922 464572	VERA KONOVALOVA	{"phone": "+70425829262"}
0005432748554	670EA4	4549 188186	OLESYA KALININA	{"email": "okalinina_10121970@postgrespro.ru", "phone": "+70654905103"}
0005432748555	670EA4	1292 614535	MILENA EGOROVA	{"phone": "+70232032165"}
0005432748556	B23C33	4228 646989	NATALYA LUKYANOVA	{"phone": "+70362997186"}
0005432748557	B23C33	0529 982089	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov.1974@postgrespro.ru", "phone": "+70239554117"}
0005432748558	1A799C	1089 475662	VITALIY RODIONOV	{"email": "v-rodionov-1977@postgrespro.ru", "phone": "+70389412019"}
0005432748559	B838E4	9893 334382	MAKSIM TIMOFEEV	{"phone": "+70285982039"}
0005432748560	C26BD3	8913 438186	VERONIKA KULIKOVA	{"phone": "+70671777856"}
0005432748561	5B9A97	0212 636906	ALLA SAVELEVA	{"phone": "+70141422637"}
0005432748562	61C2DE	0451 143654	ROMAN MOROZOV	{"email": "morozov-roman-06101971@postgrespro.ru", "phone": "+70561694148"}
0005432748563	8234AD	0889 937956	RAISA IVANOVA	{"email": "ivanova.r_1976@postgrespro.ru", "phone": "+70584999909"}
0005432748564	8234AD	5054 437996	NADEZHDA KOROLEVA	{"email": "n_koroleva1976@postgrespro.ru", "phone": "+70454674722"}
0005432748565	6018FC	7763 466283	OKSANA ISAEVA	{"email": "o_isaeva06081981@postgrespro.ru", "phone": "+70378279246"}
0005432748566	53C29D	3049 196391	VALERIYA ZAKHAROVA	{"phone": "+70695710196"}
0005432748567	8940F5	2284 017916	ARTEM IVANOV	{"email": "ivanov_artem1981@postgrespro.ru", "phone": "+70746297655"}
0005432748568	8940F5	7217 065033	MARINA KALININA	{"phone": "+70491722026"}
0005432748569	99DDFE	8282 666601	ELENA ZAYCEVA	{"email": "zaycevaelena.1959@postgrespro.ru", "phone": "+70675451172"}
0005432748570	D3A9EB	8110 699045	IGOR ZHUKOV	{"phone": "+70322342392"}
0005432748571	D3A9EB	3321 664226	ANDREY KONOVALOV	{"phone": "+70214817561"}
0005432748572	82CFBA	9044 498601	VLADIMIR NAUMOV	{"email": "naumovv_071974@postgrespro.ru", "phone": "+70192005999"}
0005432748573	82CFBA	8428 456530	ANNA MIKHAYLOVA	{"email": "mikhaylova-a_041983@postgrespro.ru", "phone": "+70713665317"}
0005432748574	867998	3740 956287	SVETLANA VASILEVA	{"email": "s-vasileva.1971@postgrespro.ru", "phone": "+70295957068"}
0005432748575	104DBC	2019 095560	NIKOLAY NIKOLAEV	{"email": "nikolaev-nikolay-1973@postgrespro.ru", "phone": "+70165245985"}
0005432748576	754841	1847 212602	VIKTOR MIKHAYLOV	{"phone": "+70837864984"}
0005432748577	526082	0979 376428	SVETLANA MALYSHEVA	{"email": "malysheva_svetlana_23031970@postgrespro.ru", "phone": "+70577495723"}
0005432748578	A15926	0359 389474	GALINA KUDRYASHOVA	{"phone": "+70420460613"}
0005432748579	A15926	6247 374622	NATALYA MAKSIMOVA	{"email": "maksimova-n-12121965@postgrespro.ru", "phone": "+70074460783"}
0005432748580	06C1BC	6015 652723	VYACHESLAV SMIRNOV	{"phone": "+70508819663"}
0005432748581	06C1BC	6966 438608	VLADIMIR MELNIKOV	{"email": "vmelnikov071969@postgrespro.ru", "phone": "+70114006752"}
0005432748582	FBBA1E	8790 035704	ALEKSEY GAVRILOV	{"phone": "+70160779742"}
0005432748583	96DFAF	2754 350579	NATALIYA LAZAREVA	{"email": "lazarevanataliya-1977@postgrespro.ru", "phone": "+70788996913"}
0005432748584	B0FB87	7944 130393	TATYANA FOMINA	{"phone": "+70297630868"}
0005432748585	780CA4	8749 213384	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov.021973@postgrespro.ru", "phone": "+70954768955"}
0005432748586	ED2BD2	1093 115614	PAVEL ZAYCEV	{"email": "pavel_zaycev1978@postgrespro.ru", "phone": "+70705744358"}
0005432748587	ED2BD2	6786 041664	MAKSIM GERASIMOV	{"phone": "+70163043396"}
0005432748588	6993F6	5502 667165	SERGEY BELOV	{"phone": "+70860639425"}
0005432748589	6993F6	8985 724185	ILYA SOKOLOV	{"email": "ilyasokolov-1978@postgrespro.ru", "phone": "+70446403253"}
0005432748590	07B30A	5949 188183	ALFIYA DAVYDOVA	{"email": "davydova_alfiya11101976@postgrespro.ru", "phone": "+70673631742"}
0005432748591	07B30A	9149 226458	ANNA OSIPOVA	{"phone": "+70724017948"}
0005432748592	3629ED	9104 348920	DMITRIY VOROBEV	{"email": "vorobevdmitriy-25091973@postgrespro.ru", "phone": "+70981110078"}
0005432748593	3629ED	5293 032891	KARINA KUZNECOVA	{"email": "kkuznecova-01091971@postgrespro.ru", "phone": "+70039288502"}
0005432748594	B64981	8496 209977	LYUBOV MOROZOVA	{"phone": "+70293412761"}
0005432748595	8608DD	3177 571913	LIDIYA FILIPPOVA	{"email": "filippova_l.121977@postgrespro.ru", "phone": "+70096809301"}
0005432748596	F4446A	8351 443121	TATYANA FROLOVA	{"email": "frolovatatyana1982@postgrespro.ru", "phone": "+70373736762"}
0005432748597	F4446A	9757 034410	MADINA ORLOVA	{"phone": "+70711125827"}
0005432748598	F47B02	9060 319480	YULIYA ANISIMOVA	{"email": "yuliya.anisimova_14021965@postgrespro.ru", "phone": "+70924770845"}
0005432748599	8D9192	4426 098563	DMITRIY BELOV	{"email": "dbelov.011967@postgrespro.ru", "phone": "+70833673434"}
0005432748600	B5F424	2676 160703	NINA KOZLOVA	{"email": "nina_kozlova1978@postgrespro.ru", "phone": "+70253922847"}
0005432748601	9EBEF1	1886 895414	VIKTORIYA KONOVALOVA	{"phone": "+70409431551"}
0005432748602	8EC56D	9346 135985	EVGENIYA DENISOVA	{"email": "denisova-evgeniya_091979@postgrespro.ru", "phone": "+70864459537"}
0005432748603	EFA7C8	3221 058022	TATYANA YUDINA	{"email": "yudina-t_16111974@postgrespro.ru", "phone": "+70037199814"}
0005432748604	F94C46	5596 905872	MARIYA POTAPOVA	{"email": "m_potapova031974@postgrespro.ru", "phone": "+70974712021"}
0005432748605	F94C46	8999 588939	KSENIYA NESTEROVA	{"phone": "+70262180226"}
0005432748606	734729	0909 517251	ALEKSEY ISAEV	{"email": "isaev-a1975@postgrespro.ru", "phone": "+70082195572"}
0005432748607	734729	7188 775543	OLEG SOKOLOV	{"phone": "+70551340814"}
0005432748608	B10C54	9157 540857	VLADIMIR FROLOV	{"email": "vladimir.frolov-021970@postgrespro.ru", "phone": "+70806242068"}
0005432748609	6924D1	0749 975959	NIKOLAY SHEVCHENKO	{"email": "nikolay-shevchenko-1977@postgrespro.ru", "phone": "+70025550883"}
0005432748610	84D279	6111 896938	ELENA IVANOVA	{"email": "ivanova_e-10011971@postgrespro.ru", "phone": "+70986829520"}
0005432748611	73CE81	3262 172152	NAIL NIKOLAEV	{"email": "nikolaevn.1973@postgrespro.ru", "phone": "+70649378705"}
0005432748612	F62EAF	3320 689123	SERGEY OSIPOV	{"email": "osipov-sergey.1981@postgrespro.ru", "phone": "+70701018563"}
0005432748613	F62EAF	7601 545645	DANILA SHEVCHENKO	{"phone": "+70060587203"}
0005432748614	D27E1E	8942 552158	MAKSIM FOMIN	{"phone": "+70457576754"}
0005432748615	D27E1E	0514 628937	IVAN BELOV	{"email": "ivanbelov03091976@postgrespro.ru", "phone": "+70518108864"}
0005432748616	9A773B	1857 872563	ANDREY PAVLOV	{"phone": "+70301600585"}
0005432748617	9A773B	3821 252397	ALEKSANDRA VASILEVA	{"email": "a-vasileva1968@postgrespro.ru", "phone": "+70368498166"}
0005432748618	C88F28	6642 964563	IRINA KULIKOVA	{"phone": "+70044901178"}
0005432748619	C88F28	4602 034538	IRINA KUDRYASHOVA	{"phone": "+70760324055"}
0005432748620	F09997	4200 517099	SVETLANA MIKHAYLOVA	{"email": "s.mikhaylova.081970@postgrespro.ru", "phone": "+70425616442"}
0005432748621	DFE9E6	2671 956598	ALEKSEY KUDRYASHOV	{"email": "akudryashov.14111978@postgrespro.ru", "phone": "+70711963550"}
0005432748622	D3EE19	4793 219726	MARINA POPOVA	{"phone": "+70797639036"}
0005432748623	51691B	0730 520541	ANDREY TIMOFEEV	{"phone": "+70896521340"}
0005432748624	20B104	9057 315989	OLEG FOMIN	{"email": "fomino_09041979@postgrespro.ru", "phone": "+70427470627"}
0005432748625	20B104	8666 646421	NIKITA ZAKHAROV	{"email": "n.zakharov071973@postgrespro.ru", "phone": "+70881458578"}
0005432748626	1211A3	1399 387514	MARINA GUSEVA	{"phone": "+70487636990"}
0005432748627	1211A3	4619 028134	ANDREY VASILEV	{"email": "andrey_vasilev-121971@postgrespro.ru", "phone": "+70422938925"}
0005432748628	1211A3	0837 458725	NATALYA KALININA	{"email": "n-kalinina_071978@postgrespro.ru", "phone": "+70165485378"}
0005432748629	3D822D	2262 689904	LIDIYA POPOVA	{"email": "popova.lidiya.17101977@postgrespro.ru", "phone": "+70227361297"}
0005432748630	923A21	0984 311196	MARINA SIDOROVA	{"email": "sidorova-marina071972@postgrespro.ru", "phone": "+70225042577"}
0005432748631	0FBE85	5230 174068	ALEKSEY ZAKHAROV	{"email": "zakharov.a1985@postgrespro.ru", "phone": "+70409312857"}
0005432748632	33ED31	3711 895883	LYUBOV MASLOVA	{"email": "l.maslova-1970@postgrespro.ru", "phone": "+70934552234"}
0005432748633	D30164	9721 992066	DANIIL SOLOVEV	{"email": "d.solovev_051981@postgrespro.ru", "phone": "+70465165962"}
0005432748634	8DD7DE	2909 396707	SEMEN ZAKHAROV	{"email": "s.zakharov_08061975@postgrespro.ru", "phone": "+70029930913"}
0005432748635	8DD7DE	8580 467823	LYUBOV FOMINA	{"phone": "+70498239734"}
0005432748636	F45469	2515 409207	SOFYA VOLKOVA	{"phone": "+70447226399"}
0005432748637	F45469	9095 506010	NIKOLAY ZHUKOV	{"email": "nikolay-zhukov041975@postgrespro.ru", "phone": "+70383531889"}
0005432748638	C85F47	8214 706103	RASHID DAVYDOV	{"email": "davydov-r1971@postgrespro.ru", "phone": "+70987975748"}
0005432748639	4E4B1E	6760 350751	PAVEL ZAYCEV	{"email": "p_zaycev.1974@postgrespro.ru", "phone": "+70383551371"}
0005432748640	4E4B1E	0872 603056	YURIY TARASOV	{"email": "tarasov-y_1978@postgrespro.ru", "phone": "+70552997793"}
0005432748641	4A3EDA	4088 083904	ANDREY SCHERBAKOV	{"phone": "+70409666585"}
0005432748642	65D93B	1484 612453	LARISA SMIRNOVA	{"phone": "+70853249669"}
0005432748643	19FC47	5088 829395	GALINA ANDREEVA	{"email": "g.andreeva.1972@postgrespro.ru", "phone": "+70631929618"}
0005432748644	19FC47	6828 126712	YULIYA FILIPPOVA	{"phone": "+70375074892"}
0005432748645	0569E6	4207 377068	IVAN POPOV	{"email": "popovi-031975@postgrespro.ru", "phone": "+70546145234"}
0005432748646	D88593	3745 953872	MARIYA IVANOVA	{"phone": "+70440374137"}
0005432748647	A393CF	4358 453420	VLADIMIR MAKSIMOV	{"phone": "+70535812270"}
0005432748648	71673B	0307 641843	PAVEL VOLKOV	{"email": "p.volkov_04021961@postgrespro.ru", "phone": "+70772753784"}
0005432748649	B48826	6348 874095	STEPAN ORLOV	{"email": "sorlov_111965@postgrespro.ru", "phone": "+70293499609"}
0005432748650	F76487	1195 909639	AMIR SOROKIN	{"email": "amir-sorokin16021968@postgrespro.ru", "phone": "+70263591604"}
0005432748651	F3375A	9529 484991	PAVEL MAKAROV	{"email": "makarov_pavel-1972@postgrespro.ru", "phone": "+70600758551"}
0005432748652	B839EE	6143 695917	DMITRIY VASILEV	{"phone": "+70777786725"}
0005432748653	60B196	4791 968226	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-1969@postgrespro.ru", "phone": "+70898430825"}
0005432748654	554DAD	5124 476535	SERGEY PETROV	{"phone": "+70627081355"}
0005432748655	E7A160	8179 183356	TATYANA ZAKHAROVA	{"email": "tatyana_zakharova_071967@postgrespro.ru", "phone": "+70315556691"}
0005432748656	E7A160	2468 153425	SERGEY STEPANOV	{"email": "sergeystepanov-1978@postgrespro.ru", "phone": "+70251371187"}
0005432748657	7CBBD9	8420 885728	ILYA BORISOV	{"phone": "+70430071963"}
0005432748658	3551B2	7788 064449	ALINA PETROVA	{"email": "a_petrova.081969@postgrespro.ru", "phone": "+70427013280"}
0005432748659	EBC7BD	6875 767752	MAGOMED SOROKIN	{"email": "magomed.sorokin_1964@postgrespro.ru", "phone": "+70108846067"}
0005432748660	700037	9733 900888	ANASTASIYA PETROVA	{"phone": "+70941847378"}
0005432748661	700037	0464 354552	SVETLANA PETROVA	{"email": "petrova.svetlana.04031981@postgrespro.ru", "phone": "+70597949829"}
0005432748662	6F7DAD	7782 201138	GENNADIY GORBUNOV	{"phone": "+70957225167"}
0005432748663	77330B	0572 414196	IRINA YUDINA	{"phone": "+70419452267"}
0005432748664	2BA7A1	8242 941018	FATIMA KOROLEVA	{"email": "korolevaf1973@postgrespro.ru", "phone": "+70255463874"}
0005432748665	86DF04	1219 250515	MARIANNA FILIPPOVA	{"phone": "+70203220984"}
0005432748666	86DF04	2645 516825	VALENTINA ALEKSANDROVA	{"phone": "+70151947649"}
0005432748667	CFD316	2934 498102	MARIYA KULIKOVA	{"phone": "+70342954971"}
0005432748668	3CCDFF	7096 649055	RAISA VOROBEVA	{"email": "vorobeva-r.19021985@postgrespro.ru", "phone": "+70524008025"}
0005432748669	91556A	6098 492752	YURIY ABRAMOV	{"phone": "+70092974425"}
0005432748670	91556A	6451 097113	NINA ILINA	{"email": "ilina_nina1977@postgrespro.ru", "phone": "+70705396687"}
0005432748671	30329E	6244 662223	DMITRIY ZAYCEV	{"email": "d_zaycev051971@postgrespro.ru", "phone": "+70368687607"}
0005432748672	30329E	0877 812344	LARISA IVANOVA	{"phone": "+70748761041"}
0005432748673	2A84FB	5948 368360	VASILIY IVANOV	{"email": "ivanov.vasiliy-1981@postgrespro.ru", "phone": "+70841537880"}
0005432748674	A5EECF	2259 241651	MARINA KAZAKOVA	{"email": "kazakova.m-061966@postgrespro.ru", "phone": "+70314195622"}
0005432748675	FC4DEB	9174 989557	KARINA POPOVA	{"email": "karina.popova.03071971@postgrespro.ru", "phone": "+70805143212"}
0005432748676	1033A9	1802 489122	EVGENIY SEMENOV	{"phone": "+70268596586"}
0005432748677	9DB78B	5136 388800	ALEKSANDR KUZNECOV	{"phone": "+70094109262"}
0005432748678	9DB78B	9067 316429	MAKSIM FOMIN	{"phone": "+70433833000"}
0005432748679	9D5CEE	8125 840602	ALEKSANDR KUZNECOV	{"phone": "+70662013638"}
0005432748680	9D5CEE	7009 404782	SERGEY GORBUNOV	{"email": "gorbunov.sergey_121968@postgrespro.ru", "phone": "+70899746945"}
0005432748681	C7836B	3002 952906	NIKOLAY PETROV	{"email": "petrov-nikolay_23041977@postgrespro.ru", "phone": "+70057434674"}
0005432748682	927B22	8304 779718	VIKTOR VASILEV	{"email": "vasilev.v051975@postgrespro.ru", "phone": "+70073982068"}
0005432748683	D90238	9016 839273	IVAN KOROLEV	{"phone": "+70534803733"}
0005432748684	16E977	1379 289269	NINA GRISHINA	{"phone": "+70500397050"}
0005432749747	D68146	0497 139207	TAMARA IVANOVA	{"email": "tamara-ivanova_29091957@postgrespro.ru", "phone": "+70684542301"}
0005432749748	D68146	8023 591662	DENIS MOISEEV	{"email": "moiseev.denis.28061975@postgrespro.ru", "phone": "+70758573583"}
0005432749749	3A0A76	7290 587034	IGOR GUSEV	{"phone": "+70530055220"}
0005432749750	3A0A76	1842 513963	ELENA VOROBEVA	{"phone": "+70927765067"}
0005432749751	A764C8	0675 891198	NATALYA YAKOVLEVA	{"email": "natalya.yakovleva26061967@postgrespro.ru", "phone": "+70577897680"}
0005432749752	B004EE	8081 254656	ALEKSANDR MELNIKOV	{"phone": "+70085717999"}
0005432749753	AAAAB4	1024 044878	YULIYA ROMANOVA	{"email": "y_romanova-031979@postgrespro.ru", "phone": "+70677657725"}
0005432749754	9B415C	7054 301527	VIKTORIYA DAVYDOVA	{"email": "viktoriya.davydova051960@postgrespro.ru", "phone": "+70441150786"}
0005432749755	11B94A	0766 882499	VIKTOR TIMOFEEV	{"phone": "+70316101785"}
0005432749756	11B94A	8669 680414	NIKITA BORISOV	{"phone": "+70196157737"}
0005432749757	798DDB	6826 732620	VLADIMIR MIKHAYLOV	{"phone": "+70553917718"}
0005432749758	244A73	8400 722476	IGOR SHEVCHENKO	{"phone": "+70485532912"}
0005432749759	B2EAC2	2262 730088	NIKOLAY VOROBEV	{"phone": "+70347287803"}
0005432749760	74D816	5829 447713	SERGEY VASILEV	{"phone": "+70235106976"}
0005432749761	74D816	0439 595535	YURIY SOKOLOV	{"email": "sokolov-yuriy-1985@postgrespro.ru", "phone": "+70759578445"}
0005432749762	F25592	5423 978606	ANNA RODIONOVA	{"phone": "+70137583908"}
0005432749763	EA15DB	8295 254905	TATYANA STEPANOVA	{"phone": "+70648438505"}
0005432749764	BAB16D	2493 011450	LYUBOV SOKOLOVA	{"phone": "+70958721501"}
0005432749765	02D854	5998 348717	ANDREY VASILEV	{"email": "vasilev_andrey_09091975@postgrespro.ru", "phone": "+70807235526"}
0005432749766	02D854	1915 149979	IVAN MATVEEV	{"phone": "+70877349516"}
0005432749767	CDF3E5	4285 575419	TIMOFEY BONDARENKO	{"phone": "+70016033745"}
0005432749768	649143	4719 541226	SERGEY ANDREEV	{"phone": "+70620563581"}
0005432749769	725A3B	2762 638924	VALENTINA DENISOVA	{"email": "valentina-denisova16051980@postgrespro.ru", "phone": "+70446263829"}
0005432749770	DDEBB3	3189 201649	NADEZHDA KUZNECOVA	{"email": "kuznecova-n051972@postgrespro.ru", "phone": "+70286940105"}
0005432749771	D51D96	0867 308321	LARISA FILIPPOVA	{"email": "filippova.l.13011969@postgrespro.ru", "phone": "+70036737492"}
0005432749772	7AA8AD	8564 647996	LIDIYA KOLESNIKOVA	{"email": "lidiya.kolesnikova071980@postgrespro.ru", "phone": "+70326018358"}
0005432749773	7AA8AD	9012 476475	YURIY GRIGOREV	{"phone": "+70385135432"}
0005432749774	7AA8AD	8212 927470	ALEKSANDR BARANOV	{"phone": "+70531956689"}
0005432749775	2205C9	6020 546873	OLGA PETROVA	{"email": "o.petrova_1968@postgrespro.ru", "phone": "+70922606732"}
0005432749776	3778FE	9562 859987	IVAN FEDOROV	{"phone": "+70356452454"}
0005432749777	3778FE	5795 435944	SERGEY ILIN	{"email": "ilinsergey.08011985@postgrespro.ru", "phone": "+70318439923"}
0005432749778	3884A7	7977 992523	LYUDMILA SERGEEVA	{"phone": "+70450790132"}
0005432749779	47DF70	6026 567906	YULIYA MOISEEVA	{"email": "moiseeva-y1970@postgrespro.ru", "phone": "+70764097184"}
0005432749780	47DF70	9823 023222	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir.091975@postgrespro.ru", "phone": "+70589894049"}
0005432749781	DAE03F	6325 632276	PAVEL AFANASEV	{"email": "afanasev.pavel041973@postgrespro.ru", "phone": "+70020471851"}
0005432749782	DD0719	5471 110118	EKATERINA SIDOROVA	{"email": "sidorovaekaterina.1981@postgrespro.ru", "phone": "+70120866023"}
0005432749783	DD0719	5531 776070	ALEKSANDRA POPOVA	{"phone": "+70168951543"}
0005432749784	E344A6	6072 186598	VLADISLAV RODIONOV	{"email": "vrodionov.121964@postgrespro.ru", "phone": "+70622267783"}
0005432749785	5B75E8	3564 466322	ANATOLIY MELNIKOV	{"email": "melnikov-a-031978@postgrespro.ru", "phone": "+70354420397"}
0005432749786	5B75E8	3427 391828	GENNADIY BONDARENKO	{"phone": "+70788405654"}
0005432749787	AA6E16	7788 751198	ANDREY DAVYDOV	{"phone": "+70281020802"}
0005432749788	F07FFD	2154 951602	ALEKSANDR TARASOV	{"phone": "+70545253487"}
0005432749789	75D8B4	3131 895182	TATYANA ALEKSEEVA	{"email": "alekseeva.t-051982@postgrespro.ru", "phone": "+70800022424"}
0005432749790	8DC73A	7770 314355	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev1965@postgrespro.ru", "phone": "+70928208156"}
0005432749791	8DC73A	3370 889075	VALERIY FILIPPOV	{"phone": "+70571809054"}
0005432749792	AC63A8	7885 697941	ELENA MAKAROVA	{"email": "emakarova_07051982@postgrespro.ru", "phone": "+70847529542"}
0005432749793	A71F83	6242 697280	VIKTORIYA SCHERBAKOVA	{"phone": "+70361735802"}
0005432749794	09F927	5779 218606	SERGEY VLASOV	{"phone": "+70007418748"}
0005432749795	09F927	2379 105065	DARYA ANDREEVA	{"phone": "+70108646037"}
0005432749796	6D215F	0778 768196	ANATOLIY TARASOV	{"phone": "+70010191702"}
0005432749797	CC433C	2913 693180	NADEZHDA EGOROVA	{"email": "nadezhda_egorova031985@postgrespro.ru", "phone": "+70621204913"}
0005432749798	CC433C	7912 108220	ANATOLIY DMITRIEV	{"phone": "+70722366630"}
0005432749799	659442	5449 839863	GALINA ORLOVA	{"email": "g.orlova-04011980@postgrespro.ru", "phone": "+70433403175"}
0005432749800	02A001	8731 021079	VALENTIN FEDOROV	{"email": "fedorovvalentin081965@postgrespro.ru", "phone": "+70318695948"}
0005432749801	0B06B7	8464 886234	NATALYA TARASOVA	{"phone": "+70342070378"}
0005432749802	287323	1247 293440	EVGENIY POPOV	{"email": "popov_e.17081968@postgrespro.ru", "phone": "+70679971128"}
0005432749803	48A9D7	8186 274780	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina_121963@postgrespro.ru", "phone": "+70234884774"}
0005432749804	C5A3A1	3447 800074	ARKADIY TIKHONOV	{"email": "tikhonov.arkadiy.021971@postgrespro.ru", "phone": "+70677101251"}
0005432749805	AD8CF4	8891 813209	GALINA KULIKOVA	{"email": "kulikova.galina.1967@postgrespro.ru", "phone": "+70998410711"}
0005432749806	AD8CF4	4677 893417	NINA STEPANOVA	{"phone": "+70888068314"}
0005432749807	B80012	2140 186839	MAKSIM AFANASEV	{"phone": "+70347522697"}
0005432749808	B80012	2687 568033	ANTON TIMOFEEV	{"email": "a_timofeev1975@postgrespro.ru", "phone": "+70424743150"}
0005432749809	B80012	5802 769414	RUSLAN OSIPOV	{"phone": "+70038021800"}
0005432749810	486AC5	6047 343236	ILSHAT KRASNOV	{"email": "i-krasnov-19111963@postgrespro.ru", "phone": "+70540410397"}
0005432749811	B67C3D	4942 250013	LIDIYA AKIMOVA	{"phone": "+70711776487"}
0005432749812	41E9D9	1675 155595	EKATERINA RYABOVA	{"email": "ryabova.ekaterina_051959@postgrespro.ru", "phone": "+70242821720"}
0005432749813	41E9D9	7906 226852	VITALIY FEDOROV	{"email": "vitaliy.fedorov-29021972@postgrespro.ru", "phone": "+70144930883"}
0005432749814	41E9D9	0495 698773	YULIYA ANDREEVA	{"phone": "+70536297296"}
0005432749815	B2C4EC	9562 346560	SVETLANA SOLOVEVA	{"phone": "+70532257319"}
0005432749816	AA20E2	6647 746551	VALERIY VOLKOV	{"phone": "+70752570186"}
0005432749817	C69A85	0408 741594	OLEG ANTONOV	{"phone": "+70698706053"}
0005432749818	77D422	9953 936681	IGOR SEMENOV	{"phone": "+70988492423"}
0005432749819	AE71C0	1401 071473	ANATOLIY PETROV	{"email": "a-petrov-23121973@postgrespro.ru", "phone": "+70401432524"}
0005432749820	51A101	2252 449183	YULIYA KUDRYASHOVA	{"phone": "+70711988752"}
0005432749821	6CC872	8808 246322	TATYANA KISELEVA	{"email": "kiseleva_t08031976@postgrespro.ru", "phone": "+70554350027"}
0005432749822	6CC872	7849 070107	VLADIMIR TARASOV	{"email": "vladimir.tarasov.16071971@postgrespro.ru", "phone": "+70921081498"}
0005432749823	1E4BDF	5683 907435	ANDREY VLASOV	{"email": "andrey_vlasov_1961@postgrespro.ru", "phone": "+70021143131"}
0005432749824	1E4BDF	0965 432493	YULIYA IVANOVA	{"phone": "+70643228779"}
0005432749825	23F26A	6470 065589	DARYA ANTONOVA	{"email": "darya.antonova.111970@postgrespro.ru", "phone": "+70404502705"}
0005432749826	23F26A	3929 585601	DMITRIY MAKSIMOV	{"email": "maksimov-dmitriy051971@postgrespro.ru", "phone": "+70159507025"}
0005432749827	7AC0EA	8042 221169	TATYANA NIKITINA	{"email": "t.nikitina16111968@postgrespro.ru", "phone": "+70870812696"}
0005432749828	F17E7D	5916 054186	EKATERINA MIKHAYLOVA	{"email": "mikhaylova_e-101969@postgrespro.ru", "phone": "+70666568653"}
0005432749829	F17E7D	7032 775155	MIKHAIL ANTONOV	{"email": "mikhail.antonov1959@postgrespro.ru", "phone": "+70815282343"}
0005432749830	AD89CF	6641 936474	MIKHAIL ANDREEV	{"phone": "+70916814279"}
0005432749831	AD89CF	3080 149778	ANTONINA PAVLOVA	{"email": "antonina-pavlova.061974@postgrespro.ru", "phone": "+70738079851"}
0005432749832	5FF43F	6158 698828	IVAN MATVEEV	{"phone": "+70962837307"}
0005432749833	F3AE04	9753 438896	ZINAIDA DAVYDOVA	{"phone": "+70326560914"}
0005432749834	72795B	0968 509855	VERA IVANOVA	{"phone": "+70176988739"}
0005432749835	72795B	0113 833711	IRINA MATVEEVA	{"email": "matveeva-i-28091979@postgrespro.ru", "phone": "+70632842490"}
0005432749836	8A7C12	8105 216710	VASILIY BORISOV	{"phone": "+70899493222"}
0005432749837	8A7C12	2426 232071	ALEKSANDR POPOV	{"email": "popov_a1967@postgrespro.ru", "phone": "+70873794273"}
0005432749838	A14CB5	6260 681509	NIKOLAY EGOROV	{"email": "egorovnikolay_1965@postgrespro.ru", "phone": "+70950572706"}
0005432749839	43E722	1612 327418	NINA VOLKOVA	{"email": "n-volkova.061974@postgrespro.ru", "phone": "+70083548965"}
0005432749840	BBD084	1695 811484	OLGA POTAPOVA	{"phone": "+70187867631"}
0005432749841	BBD084	1009 024936	NATALYA MOISEEVA	{"phone": "+70843023339"}
0005432749842	179D8A	3196 178447	NAILYA MAKSIMOVA	{"phone": "+70722531962"}
0005432749843	179D8A	9567 531056	NATALIYA BOGDANOVA	{"phone": "+70363437985"}
0005432749844	E18B0F	1053 567168	NINA SEMENOVA	{"phone": "+70463112651"}
0005432749845	E18B0F	7472 202689	DANIYA MIRONOVA	{"email": "d.mironova-1977@postgrespro.ru", "phone": "+70887405962"}
0005432749846	09D9DB	7120 888017	YULIYA NIKITINA	{"phone": "+70628102328"}
0005432749847	E9E924	3713 374569	DMITRIY KUZNECOV	{"phone": "+70925053095"}
0005432749848	E9E924	4316 442624	GALINA FILIPPOVA	{"email": "filippova-galina1976@postgrespro.ru", "phone": "+70181543090"}
0005432749849	E9E924	9058 940148	EKATERINA SIDOROVA	{"email": "ekaterina.sidorova_1974@postgrespro.ru", "phone": "+70340084797"}
0005432749850	13B6B3	8309 392880	ALEKSANDR SMIRNOV	{"email": "smirnova_081973@postgrespro.ru", "phone": "+70961081380"}
0005432749851	17A6DA	1572 110105	VLADIMIR MEDVEDEV	{"phone": "+70200922337"}
0005432749852	FEA0A3	7074 999700	VIKTOR PETROV	{"email": "viktorpetrov-061963@postgrespro.ru", "phone": "+70606113255"}
0005432749853	D19762	3191 909935	LEONTIY KOROLEV	{"phone": "+70790987568"}
0005432751468	E0047B	3917 026313	ALENA GORBUNOVA	{"email": "a_gorbunova_081979@postgrespro.ru", "phone": "+70791534198"}
0005432751469	E0047B	2843 365279	OLGA SERGEEVA	{"email": "olgasergeeva.05121976@postgrespro.ru", "phone": "+70427363774"}
0005432751470	7D46AB	9463 639086	PAVEL VASILEV	{"phone": "+70704684895"}
0005432751471	7D46AB	0542 301071	VASILIY PAVLOV	{"email": "pavlov.v.011978@postgrespro.ru", "phone": "+70268039351"}
0005432751472	A7B60A	2484 158924	BORIS EGOROV	{"email": "egorov-boris_25101971@postgrespro.ru", "phone": "+70482247733"}
0005432751473	A7B60A	9092 530218	VYACHESLAV RODIONOV	{"phone": "+70475624422"}
0005432751474	94F44C	9965 278905	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev121967@postgrespro.ru", "phone": "+70670791129"}
0005432751475	DEE3FD	0189 945432	SERGEY MATVEEV	{"phone": "+70285694994"}
0005432751476	DEE3FD	5412 428194	PAVEL MIKHAYLOV	{"email": "p.mikhaylov_20121977@postgrespro.ru", "phone": "+70198775225"}
0005432751477	ED922A	9893 559358	ANNA POTAPOVA	{"email": "potapova_anna061985@postgrespro.ru", "phone": "+70382987071"}
0005432751478	E65A87	0192 870754	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-aleksandr.11061976@postgrespro.ru", "phone": "+70320906890"}
0005432751479	38DFA0	8139 597833	ANASTASIYA YAKOVLEVA	{"phone": "+70607857347"}
0005432751480	38DFA0	4313 361720	ALEKSANDR ROMANOV	{"email": "a_romanov-30091981@postgrespro.ru", "phone": "+70628656226"}
0005432751481	74B0AD	5665 841077	LIDIYA CHERNOVA	{"email": "chernova-lidiya.1967@postgrespro.ru", "phone": "+70344729483"}
0005432751542	D775A6	2774 361901	NATALYA MOROZOVA	{"phone": "+70584116326"}
0005432751482	E3175F	9187 837878	NATALYA SIDOROVA	{"email": "natalya.sidorova_061980@postgrespro.ru", "phone": "+70072158234"}
0005432751483	B18770	4106 732912	OLESYA CHERNOVA	{"phone": "+70856800215"}
0005432751484	1D88EE	3345 155185	ALEKSANDR OSIPOV	{"email": "a-osipov1969@postgrespro.ru", "phone": "+70941116166"}
0005432751485	1C6928	9408 386705	SERGEY ZAKHAROV	{"email": "sergey_zakharov.15091967@postgrespro.ru", "phone": "+70812084410"}
0005432751486	07F1C1	1420 572777	ANDREY IVANOV	{"email": "andrey_ivanov.041979@postgrespro.ru", "phone": "+70679308321"}
0005432751487	07F1C1	2316 635639	NIKOLAY FEDOTOV	{"phone": "+70694620986"}
0005432751488	350647	6792 868742	STANISLAV FROLOV	{"email": "s.frolov_26121976@postgrespro.ru", "phone": "+70302863112"}
0005432751489	45809D	8155 255804	VASILIY FEDOROV	{"phone": "+70383212777"}
0005432751490	45809D	4599 481901	PAVEL MIRONOV	{"phone": "+70849232952"}
0005432751491	45809D	6354 759338	GALINA EGOROVA	{"email": "egorova.g.18011977@postgrespro.ru", "phone": "+70644423350"}
0005432751492	D1FC07	3395 524079	NATALIYA ARKHIPOVA	{"email": "arkhipova_nataliya.1975@postgrespro.ru", "phone": "+70157432498"}
0005432751493	4199CA	9860 879725	ZHANNA KARPOVA	{"phone": "+70806917138"}
0005432751494	90DED7	5282 274433	VIKTOR PETROV	{"email": "vpetrov.101978@postgrespro.ru", "phone": "+70187053296"}
0005432751495	90DED7	2685 029665	DENIS KUZMIN	{"email": "denis_kuzmin_1992@postgrespro.ru", "phone": "+70674885162"}
0005432751496	23AAD5	2338 359735	NIKOLAY ZAYCEV	{"email": "nzaycev.24091975@postgrespro.ru", "phone": "+70838697631"}
0005432751497	AC06C6	1722 186164	VALENTINA LUKYANOVA	{"phone": "+70640254913"}
0005432751498	208C6E	8481 560181	SVETLANA KOLESNIKOVA	{"email": "skolesnikova08111970@postgrespro.ru", "phone": "+70036517990"}
0005432751499	9CFBC1	4425 638187	NIKOLAY IVANOV	{"phone": "+70487480896"}
0005432751500	6A9E32	8883 053354	VLADIMIR MELNIKOV	{"phone": "+70057610177"}
0005432751501	6A9E32	4392 453584	ELENA MIKHAYLOVA	{"phone": "+70616201361"}
0005432751502	6411AA	6693 333271	ALEKSANDR KUZNECOV	{"email": "kuznecova-11081975@postgrespro.ru", "phone": "+70894067031"}
0005432751503	D677AF	6350 539686	ALEKSANDR ANDREEV	{"email": "andreev-a-1976@postgrespro.ru", "phone": "+70890398055"}
0005432751504	D677AF	8817 681299	ALEKSANDRA DENISOVA	{"phone": "+70639415251"}
0005432751505	4E0802	4745 386138	YURIY EGOROV	{"phone": "+70579130439"}
0005432751506	4E0802	7992 619699	SERGEY PAVLOV	{"phone": "+70510974013"}
0005432751507	1EBE43	6549 300289	ELMIRA IVANOVA	{"phone": "+70189226805"}
0005432751508	1EBE43	0837 937528	NINA BORISOVA	{"email": "borisova-nina.10061965@postgrespro.ru", "phone": "+70119311506"}
0005432751509	DE0F9C	4286 151907	ALEKSANDR ORLOV	{"phone": "+70904052859"}
0005432751510	5B9D12	7575 290742	VARVARA FEDOROVA	{"phone": "+70097179886"}
0005432751511	78ADF9	1431 224835	ANNA FOMINA	{"phone": "+70249033859"}
0005432751512	716F79	6209 592038	ANASTASIYA LEBEDEVA	{"email": "lebedeva.anastasiya-02051971@postgrespro.ru", "phone": "+70163089466"}
0005432751513	716F79	2213 050043	ILYA PAVLOV	{"phone": "+70946466752"}
0005432751514	716F79	8219 249069	SVETLANA YAKOVLEVA	{"phone": "+70171665122"}
0005432751515	5DA7DA	9988 133500	NIKOLAY KUDRYASHOV	{"email": "kudryashovn-12011976@postgrespro.ru", "phone": "+70337258434"}
0005432751516	F7F042	9964 627703	ANDREY GORBUNOV	{"email": "gorbunov-a_1973@postgrespro.ru", "phone": "+70106802393"}
0005432751517	1F4CE9	0746 033747	ANNA KUZNECOVA	{"email": "kuznecova.anna.041978@postgrespro.ru", "phone": "+70875221877"}
0005432751518	A33360	0777 250045	ALEKSANDR DMITRIEV	{"phone": "+70250802246"}
0005432751519	7F72FB	7471 790824	GULNARA LUKYANOVA	{"email": "g_lukyanova.021968@postgrespro.ru", "phone": "+70645603884"}
0005432751520	14BB44	6119 614153	LYUDMILA SEMENOVA	{"phone": "+70657285390"}
0005432751521	3BE237	0637 673161	EKATERINA KONDRATEVA	{"phone": "+70536458578"}
0005432751522	3BE237	8715 440523	SVETLANA ZOTOVA	{"email": "zotova_svetlana1971@postgrespro.ru", "phone": "+70743138384"}
0005432751523	15BBD7	7907 112386	EKATERINA BORISOVA	{"email": "borisova-e_081975@postgrespro.ru", "phone": "+70992728144"}
0005432751524	DD741A	5227 716884	VLADIMIR KISELEV	{"email": "kiselev-vladimir-051969@postgrespro.ru", "phone": "+70845234387"}
0005432751525	B615E1	8046 953785	LYUDMILA KULIKOVA	{"email": "kulikova_lyudmila.1994@postgrespro.ru", "phone": "+70072139238"}
0005432751526	74E430	5934 280689	OLGA ANDREEVA	{"phone": "+70208225066"}
0005432751527	B9A767	4234 550254	KONSTANTIN VASILEV	{"phone": "+70154045288"}
0005432751528	318376	1389 553784	ZINAIDA PAVLOVA	{"email": "zpavlova.041972@postgrespro.ru", "phone": "+70894345998"}
0005432751529	318376	6314 890568	YANA SOLOVEVA	{"phone": "+70377640382"}
0005432751530	318376	9482 225936	ELENA SOROKINA	{"phone": "+70795449144"}
0005432751531	125D6C	4100 070150	TATYANA STEPANOVA	{"phone": "+70698885178"}
0005432751532	9EF33F	1293 776592	ANDREY MIRONOV	{"phone": "+70149493328"}
0005432751533	4C1B8D	3597 425731	NINA KUDRYASHOVA	{"email": "kudryashova-nina.1961@postgrespro.ru", "phone": "+70714246184"}
0005432751534	75481B	4822 971135	IRINA PETROVA	{"phone": "+70605728763"}
0005432751535	75481B	4776 923624	ALEKSANDRA KUDRYASHOVA	{"email": "a.kudryashova-1982@postgrespro.ru", "phone": "+70751545066"}
0005432751536	75481B	1483 239428	MIKHAIL MIKHAYLOV	{"email": "mikhaylovmikhail25101975@postgrespro.ru", "phone": "+70905235960"}
0005432751537	55AC2A	6529 026734	KARINA FROLOVA	{"phone": "+70395290220"}
0005432751538	CE50BC	8282 151722	LYUBOV KISELEVA	{"phone": "+70559876910"}
0005432751539	5013E1	8942 791128	ANNA KOROLEVA	{"email": "korolevaanna-19021974@postgrespro.ru", "phone": "+70973014664"}
0005432751540	FB4C0E	6103 540815	KRISTINA NAZAROVA	{"email": "nazarova.k_1969@postgrespro.ru", "phone": "+70424266409"}
0005432751541	E216CC	5519 780731	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov-06051977@postgrespro.ru", "phone": "+70998019567"}
0005432751543	D775A6	5712 053104	GALINA KOZLOVA	{"phone": "+70351804461"}
0005432751544	1AB4E8	3692 327851	SERGEY ZAKHAROV	{"email": "s-zakharov.051964@postgrespro.ru", "phone": "+70551440420"}
0005432751545	99CADB	6184 400030	YURIY SOKOLOV	{"email": "ysokolov29031970@postgrespro.ru", "phone": "+70208624290"}
0005432751546	5DCFBC	3350 063845	NIKOLAY SAVELEV	{"email": "nsavelev_1993@postgrespro.ru", "phone": "+70692060548"}
0005432751547	5DCFBC	5247 233884	LYUBOV STEPANOVA	{"email": "l-stepanova111977@postgrespro.ru", "phone": "+70615546362"}
0005432751548	9CF377	1363 837365	OLESYA OVCHINNIKOVA	{"email": "ovchinnikova_o.30111975@postgrespro.ru", "phone": "+70304452367"}
0005432751549	3C6256	5612 369526	VLADIMIR ILIN	{"phone": "+70412773908"}
0005432751550	3C6256	9737 526071	SERGEY MIKHAYLOV	{"phone": "+70427302062"}
0005432751551	9D5F4B	3577 148416	VITALIY SEMENOV	{"phone": "+70631424041"}
0005432751552	63CC17	5372 968054	VLADIMIR NOVIKOV	{"email": "vladimir_novikov-071971@postgrespro.ru", "phone": "+70158718586"}
0005432751553	0B3948	6275 195995	NIKOLAY IVANOV	{"email": "n-ivanov-22031976@postgrespro.ru", "phone": "+70054415699"}
0005432751554	B2C62A	8729 770160	VITALIY KUDRYASHOV	{"email": "v.kudryashov_1963@postgrespro.ru", "phone": "+70233813741"}
0005432751555	AA042C	3816 165617	IVAN KUZNECOV	{"email": "ivan_kuznecov_1975@postgrespro.ru", "phone": "+70534642533"}
0005432751556	5481BC	9216 808418	ROMAN ALEKSEEV	{"phone": "+70934126311"}
0005432751557	458294	2012 696622	IGOR KUZNECOV	{"phone": "+70149051097"}
0005432751558	CFA03F	3418 529221	VIKTOR DMITRIEV	{"email": "dmitrievv101972@postgrespro.ru", "phone": "+70447040425"}
0005432751559	BEE894	0279 569859	EGOR ZAKHAROV	{"email": "e.zakharov_1968@postgrespro.ru", "phone": "+70870267460"}
0005432751560	81C0AB	2203 617213	LEONID MEDVEDEV	{"email": "leonid-medvedev09071968@postgrespro.ru", "phone": "+70611242408"}
0005432751561	DB8BBE	3136 051346	EKATERINA VLASOVA	{"phone": "+70023676050"}
0005432751562	DB8BBE	3096 493622	VLADIMIR POPOV	{"phone": "+70943415077"}
0005432751563	EF02BC	2806 854723	NIKOLAY VOLKOV	{"email": "volkov.n-1978@postgrespro.ru", "phone": "+70895109778"}
0005432751564	BA3A1F	0739 164293	GALINA PAVLOVA	{"phone": "+70422952539"}
0005432751565	BA3A1F	4372 438916	SERGEY NIKOLAEV	{"email": "nikolaev-s1971@postgrespro.ru", "phone": "+70714067857"}
0005432751566	BA3A1F	8247 735281	ELENA NESTEROVA	{"email": "nesterovaelena.11031973@postgrespro.ru", "phone": "+70883803442"}
0005432751567	2D8FBC	8651 287103	SVETLANA FILIPPOVA	{"phone": "+70843961176"}
0005432751568	2D8FBC	9169 936299	IGOR SCHERBAKOV	{"email": "igor.scherbakov-061979@postgrespro.ru", "phone": "+70850996993"}
0005432751569	2D8FBC	9060 308877	NATALIYA DANILOVA	{"phone": "+70852523344"}
0005432751570	CE0447	6613 681457	KRISTINA FOMINA	{"email": "k_fomina-091973@postgrespro.ru", "phone": "+70626918640"}
0005432751571	CE0447	4551 916668	SERGEY KRASNOV	{"email": "krasnov.s_111964@postgrespro.ru", "phone": "+70672191416"}
0005432751572	F6FD99	7156 251316	LILIYA KONDRATEVA	{"phone": "+70597468806"}
0005432751573	F6FD99	9003 356019	VALENTINA ANDREEVA	{"phone": "+70720507414"}
0005432751574	88228B	7153 135249	IRINA KUZNECOVA	{"phone": "+70503437926"}
0005432751575	4F3203	8828 165658	SERGEY FROLOV	{"email": "frolov_s-30111962@postgrespro.ru", "phone": "+70735541818"}
0005432751576	E2C1B5	1544 783733	VYACHESLAV STEPANOV	{"phone": "+70432559223"}
0005432751577	E2C1B5	8856 919361	VLADIMIR MEDVEDEV	{"email": "vladimir-medvedev1970@postgrespro.ru", "phone": "+70364358394"}
0005432751578	B87063	7477 093500	MIKHAIL DENISOV	{"email": "denisov_mikhail_041961@postgrespro.ru", "phone": "+70442161849"}
0005432751579	96EFFB	9629 296590	SERGEY SOLOVEV	{"email": "solovev-sergey.1978@postgrespro.ru", "phone": "+70977293552"}
0005432751580	52F824	4604 702135	DMITRIY MIRONOV	{"phone": "+70043759876"}
0005432751581	F5D06C	9721 634476	OKSANA ORLOVA	{"email": "oksana_orlova-19111987@postgrespro.ru", "phone": "+70099413990"}
0005432751582	F5D06C	1358 972611	SERGEY SOROKIN	{"email": "s.sorokin_011985@postgrespro.ru", "phone": "+70606373578"}
0005432751583	5A75EF	9730 113893	OLGA FOMINA	{"email": "fominaolga-03051980@postgrespro.ru", "phone": "+70327934443"}
0005432751584	5A75EF	3587 886415	ALENA FROLOVA	{"phone": "+70757549440"}
0005432751585	5A75EF	7763 874530	VERA KUZNECOVA	{"email": "vera-kuznecova1969@postgrespro.ru", "phone": "+70536893584"}
0005432751586	D66030	7831 562654	NIKOLAY FROLOV	{"email": "nikolayfrolov111984@postgrespro.ru", "phone": "+70849268627"}
0005432751587	D8F2C6	4176 122509	DARYA FROLOVA	{"email": "d.frolova061984@postgrespro.ru", "phone": "+70347877694"}
0005432751588	D8F2C6	9389 655360	OLGA KOMAROVA	{"phone": "+70877117190"}
0005432751589	0E104F	8853 550275	KSENIYA FILIPPOVA	{"email": "kseniya.filippova1961@postgrespro.ru", "phone": "+70151422859"}
0005432751590	39A049	3628 020897	MAKSIM TIMOFEEV	{"email": "timofeev_maksim.28061964@postgrespro.ru", "phone": "+70782970832"}
0005432751591	E28159	2526 086408	MAKSIM ZHUKOV	{"email": "zhukov_m16051968@postgrespro.ru", "phone": "+70205085702"}
0005432751592	E28159	3240 595833	SVETLANA ERMAKOVA	{"email": "ermakova-svetlana101951@postgrespro.ru", "phone": "+70234680420"}
0005432751593	A66615	3823 577552	IRINA VASILEVA	{"phone": "+70328734638"}
0005432751594	A66615	7257 589471	ANATOLIY SCHERBAKOV	{"phone": "+70393706342"}
0005432751595	0CCD69	9390 673518	MATRENA CHERNOVA	{"email": "chernova.matrena15071958@postgrespro.ru", "phone": "+70383951180"}
0005432751596	0CCD69	5570 067857	SERGEY KOROLEV	{"email": "korolev_sergey_061981@postgrespro.ru", "phone": "+70014912965"}
0005432751597	5BEE03	7752 241689	ILYA RODIONOV	{"phone": "+70911303096"}
0005432751598	0E81FB	9426 810878	SERGEY ZHUKOV	{"email": "zhukov-sergey_24121983@postgrespro.ru", "phone": "+70656671572"}
0005432751599	2C4F61	7955 308085	SOFYA FADEEVA	{"email": "fadeeva_s.021985@postgrespro.ru", "phone": "+70787128780"}
0005432751600	418D0A	1933 388094	ELENA ANDREEVA	{"email": "elenaandreeva24081958@postgrespro.ru", "phone": "+70025616772"}
0005432751601	B051BA	0738 282257	NIKOLAY MATVEEV	{"email": "nikolay-matveev1975@postgrespro.ru", "phone": "+70055620866"}
0005432751602	A8C95F	7359 223369	TATYANA NESTEROVA	{"email": "nesterova.t.1970@postgrespro.ru", "phone": "+70020133149"}
0005432751603	541F41	0678 662919	NATALYA TARASOVA	{"phone": "+70588560383"}
0005432751604	F8D22A	7863 610588	ALEKSANDR SOKOLOV	{"email": "sokolova.08061972@postgrespro.ru", "phone": "+70346729420"}
0005432751605	F8D22A	4949 041003	ANTON STEPANOV	{"phone": "+70622137176"}
0005432751606	F8D22A	6221 193894	MARFA MOROZOVA	{"email": "morozovam-19021965@postgrespro.ru", "phone": "+70708923824"}
0005432751607	4B3744	8871 028829	MAKSIM VOLKOV	{"email": "volkov_maksim.111972@postgrespro.ru", "phone": "+70389446702"}
0005432751608	5BD413	8785 948287	EVGENIY IVANOV	{"phone": "+70322395337"}
0005432751609	5BD413	8451 992060	TATYANA BARANOVA	{"email": "baranova-tatyana-10041981@postgrespro.ru", "phone": "+70354376683"}
0005432751610	D285A4	6471 043946	ALEKSANDR BORISOV	{"email": "borisov-a-13041981@postgrespro.ru", "phone": "+70451615817"}
0005432751611	2BB59C	0145 611518	VLADIMIR ROMANOV	{"phone": "+70761400009"}
0005432751612	32B8B0	1860 834959	EVGENIY FROLOV	{"phone": "+70908327467"}
0005432751613	7FCF2C	6998 548836	VIKTOR ILIN	{"email": "ilin-v12021974@postgrespro.ru", "phone": "+70611333315"}
0005432751614	85DF16	1888 767369	ALEKSANDR BORISOV	{"email": "borisova_1971@postgrespro.ru", "phone": "+70134840397"}
0005432751615	85DF16	8426 084888	OLGA ORLOVA	{"phone": "+70435430048"}
0005432751616	EA556D	0571 445125	NINA LAZAREVA	{"email": "lazareva-n.10031965@postgrespro.ru", "phone": "+70483154061"}
0005432751617	89F2E7	3817 414414	ANASTASIYA BORISOVA	{"email": "aborisova1979@postgrespro.ru", "phone": "+70109111198"}
0005432751618	B0FEE4	0661 546842	TATYANA SMIRNOVA	{"phone": "+70484868675"}
0005432751619	B74D6C	0953 162842	KIRILL ISAEV	{"phone": "+70863074505"}
0005432751620	B994EA	5394 667900	VLADISLAV KUZMIN	{"phone": "+70378511618"}
0005432751621	B994EA	0127 467538	VLADIMIR ZAYCEV	{"phone": "+70402600274"}
0005432751622	A4A771	1276 752523	ALEKSANDRA ABRAMOVA	{"email": "abramovaaleksandra_28121976@postgrespro.ru", "phone": "+70489771096"}
0005432751623	A4A771	5759 486062	NATALIYA NESTEROVA	{"phone": "+70226841635"}
0005432751624	57CAB1	6015 418151	SERGEY MIRONOV	{"email": "sergey_mironov_041968@postgrespro.ru", "phone": "+70098351331"}
0005432751625	57CAB1	7490 115936	NAILYA NAZAROVA	{"email": "nazarova-n_22071976@postgrespro.ru", "phone": "+70432191395"}
0005432751626	25FD7C	4281 871832	EVGENIY SOKOLOV	{"email": "e_sokolov.051983@postgrespro.ru", "phone": "+70976513406"}
0005432751627	25FD7C	6424 953728	OLEG YAKOVLEV	{"phone": "+70207599588"}
0005432751628	25FD7C	6079 697150	VASILIY VOLKOV	{"email": "v_volkov1972@postgrespro.ru", "phone": "+70149851012"}
0005432753242	AE1F70	5623 001761	YULIYA BELOVA	{"phone": "+70789378147"}
0005432753243	AE1F70	7024 064783	NIKITA ZHUKOV	{"email": "nikitazhukov-01081973@postgrespro.ru", "phone": "+70269288268"}
0005432753244	823A23	9969 816043	ALEKSANDR POPOV	{"email": "popov_aleksandr.06051975@postgrespro.ru", "phone": "+70345790106"}
0005432753245	1E84E2	1296 680722	KONSTANTIN GERASIMOV	{"email": "k.gerasimov1971@postgrespro.ru", "phone": "+70974092108"}
0005432753246	6424F6	6147 441865	YURIY TIMOFEEV	{"email": "timofeev.yuriy1984@postgrespro.ru", "phone": "+70448150760"}
0005432753247	6424F6	2108 391224	SVETLANA SEMENOVA	{"phone": "+70266794609"}
0005432753248	652AB3	1788 749567	NATALYA KALININA	{"phone": "+70227069951"}
0005432753249	652AB3	6103 852929	SERGEY FROLOV	{"email": "s-frolov-071976@postgrespro.ru", "phone": "+70624083421"}
0005432753250	1BAFDB	7149 596101	LYUDMILA GUSEVA	{"email": "guseva.l091976@postgrespro.ru", "phone": "+70422412911"}
0005432753251	7E5B58	3906 269933	ANATOLIY ALEKSEEV	{"email": "alekseev.anatoliy-041973@postgrespro.ru", "phone": "+70380077859"}
0005432753252	3BDDBF	5479 997848	SERGEY KUZNECOV	{"email": "kuznecov_s-1962@postgrespro.ru", "phone": "+70955347934"}
0005432753253	DE0CA0	0977 513517	IGOR BARANOV	{"phone": "+70127078580"}
0005432753254	DE0CA0	4576 528155	TATYANA FEDOROVA	{"phone": "+70576665155"}
0005432753255	8FDE91	8441 064979	LYUBOV MIRONOVA	{"phone": "+70370368433"}
0005432753256	69F4EE	0369 847165	SERGEY GAVRILOV	{"email": "s-gavrilov-091976@postgrespro.ru", "phone": "+70258571146"}
0005432753257	3C04DD	6121 518678	ELENA ABRAMOVA	{"phone": "+70075108460"}
0005432753258	E2FB9C	4006 387050	TATYANA KOROLEVA	{"phone": "+70538531093"}
0005432753259	32B687	7591 256809	ANNA SMIRNOVA	{"email": "anna_smirnova09101968@postgrespro.ru", "phone": "+70368765297"}
0005432753260	32B687	3138 378562	SERGEY GERASIMOV	{"phone": "+70099871426"}
0005432753261	A9FF36	8066 136390	ANDREY DENISOV	{"email": "denisov-andrey.1970@postgrespro.ru", "phone": "+70253472240"}
0005432753262	FB5860	0619 512523	TATYANA SMIRNOVA	{"phone": "+70139555039"}
0005432753263	E8BB69	3261 552223	SERGEY ANDREEV	{"phone": "+70115440620"}
0005432753264	EA4F1F	2533 461378	VLADIMIR YAKOVLEV	{"email": "vladimiryakovlev-051983@postgrespro.ru", "phone": "+70287229180"}
0005432753265	79CFAB	9342 580830	ANASTASIYA POLYAKOVA	{"email": "anastasiya_polyakova.26101958@postgrespro.ru", "phone": "+70841966628"}
0005432753266	866387	9726 104544	GALINA TARASOVA	{"email": "tarasovagalina-101986@postgrespro.ru", "phone": "+70088962227"}
0005432753267	866387	1611 414395	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana_1964@postgrespro.ru", "phone": "+70485517235"}
0005432753268	866387	0922 881303	TATYANA LAZAREVA	{"phone": "+70900627140"}
0005432753269	3381AE	0154 189051	VALENTIN MELNIKOV	{"phone": "+70824054966"}
0005432753270	8D3F43	9441 151174	NATALYA ALEKSEEVA	{"phone": "+70978366353"}
0005432753271	3C62B8	3385 666187	SVETLANA FILIPPOVA	{"email": "svetlana-filippova.121971@postgrespro.ru", "phone": "+70497855875"}
0005432753272	3C62B8	3608 272265	KIRILL AFANASEV	{"phone": "+70187984839"}
0005432753273	7DFD34	9483 324892	ELENA KULIKOVA	{"email": "e-kulikova-17101965@postgrespro.ru", "phone": "+70884140585"}
0005432753274	3A9F7D	9602 844740	ALI VOLKOV	{"phone": "+70320336086"}
0005432753275	FBA7ED	5542 993868	EVGENIY KRASNOV	{"email": "e.krasnov12031971@postgrespro.ru", "phone": "+70565134505"}
0005432753276	5261A1	5476 516241	OLGA RYABOVA	{"email": "olga_ryabova-1965@postgrespro.ru", "phone": "+70522416481"}
0005432753277	1CD035	4625 579546	IVAN KUZNECOV	{"email": "ivan_kuznecov_061972@postgrespro.ru", "phone": "+70029829418"}
0005432753278	8978AB	1355 029136	VLADIMIR FEDOROV	{"phone": "+70773429644"}
0005432753279	918105	1936 196324	NIKOLAY SEMENOV	{"email": "nikolay_semenov_30061969@postgrespro.ru", "phone": "+70243831378"}
0005432753280	119EDE	1775 510555	TATYANA EFIMOVA	{"phone": "+70977007929"}
0005432753281	119EDE	6315 288983	ALEKSANDR KULIKOV	{"email": "kulikov_a-22051981@postgrespro.ru", "phone": "+70449095732"}
0005432753282	119EDE	9401 231682	LYUBOV POPOVA	{"phone": "+70948741686"}
0005432753283	119EDE	9265 319617	DAVID IVANOV	{"email": "david-ivanov.061968@postgrespro.ru", "phone": "+70008674812"}
0005432753284	469F32	0825 653950	SERGEY ANDREEV	{"email": "s-andreev081985@postgrespro.ru", "phone": "+70722665617"}
0005432753285	7633D5	6943 533686	NATALYA KONOVALOVA	{"phone": "+70217314596"}
0005432753286	C9BBE2	1579 071796	NAIL GORBUNOV	{"phone": "+70349531524"}
0005432753287	C9BBE2	8991 541413	GALINA POTAPOVA	{"phone": "+70920753801"}
0005432753288	A2DF22	8887 164535	LYUDMILA GRISHINA	{"email": "grishinalyudmila_121958@postgrespro.ru", "phone": "+70477845455"}
0005432753289	F5A23D	0009 777251	ALEKSANDR VASILEV	{"email": "vasileva-08101976@postgrespro.ru", "phone": "+70443235207"}
0005432753290	B5E94B	3602 533760	YURIY POPOV	{"phone": "+70102988120"}
0005432753291	3068A0	2815 268071	LIDIYA AFANASEVA	{"phone": "+70150942718"}
0005432753292	3068A0	3090 400240	ARINA TARASOVA	{"phone": "+70649271275"}
0005432753293	E25CF5	6794 148358	VLADIMIR SHEVCHENKO	{"email": "vladimirshevchenko_1965@postgrespro.ru", "phone": "+70031547515"}
0005432753294	BFE1B1	9222 176591	OLGA MEDVEDEVA	{"email": "medvedeva.olga-071979@postgrespro.ru", "phone": "+70243566234"}
0005432753295	59F0CD	1806 376852	EKATERINA LAZAREVA	{"email": "lazareva.ekaterina-1982@postgrespro.ru", "phone": "+70357637737"}
0005432753296	6CCF93	0648 059472	IRINA MAKAROVA	{"email": "makarovai1977@postgrespro.ru", "phone": "+70395813006"}
0005432753297	201C5C	5992 262501	TATYANA DANILOVA	{"email": "danilova-tatyana-1970@postgrespro.ru", "phone": "+70241576022"}
0005432753298	5555A8	0850 917414	OLEG SOROKIN	{"phone": "+70857260934"}
0005432753299	36D379	0213 160508	YULIYA LOGINOVA	{"email": "loginovayuliya_1980@postgrespro.ru", "phone": "+70938527355"}
0005432753300	36D379	3630 118622	YULIYA TARASOVA	{"phone": "+70398867619"}
0005432753301	CEA4FD	2863 859957	NIKOLAY ABRAMOV	{"email": "abramov_nikolay.18071986@postgrespro.ru", "phone": "+70695345972"}
0005432753302	CEA4FD	3434 502503	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina_27061986@postgrespro.ru", "phone": "+70612642500"}
0005432753303	F13C2F	8903 207111	MAKSIM KAZAKOV	{"email": "kazakovm.051977@postgrespro.ru", "phone": "+70920590245"}
0005432753304	F13C2F	7328 983214	YURIY MELNIKOV	{"email": "melnikovyuriy-1979@postgrespro.ru", "phone": "+70630815447"}
0005432753305	C6BB57	2845 731557	ALENA KARPOVA	{"phone": "+70840696612"}
0005432753306	B80CAF	4733 436114	VLADIMIR SEMENOV	{"phone": "+70749753599"}
0005432753307	634F4F	5043 165103	NIKOLAY SCHERBAKOV	{"email": "scherbakovn-1964@postgrespro.ru", "phone": "+70100348194"}
0005432753308	F659FB	6256 102952	NIKOLAY DAVYDOV	{"email": "davydov-n.121981@postgrespro.ru", "phone": "+70158822759"}
0005432753309	083E59	5090 925690	LYUDMILA OSIPOVA	{"phone": "+70426705313"}
0005432753310	083E59	6856 178357	TATYANA LOGINOVA	{"email": "t.loginova-071970@postgrespro.ru", "phone": "+70303742913"}
0005432753311	FABA87	7645 201011	ANDREY GERASIMOV	{"email": "gerasimov_andrey_1958@postgrespro.ru", "phone": "+70729338960"}
0005432753312	9D4ABD	2444 929131	ANDREY SCHERBAKOV	{"email": "andrey-scherbakov.02021960@postgrespro.ru", "phone": "+70872512078"}
0005432753313	53133E	8025 549305	ALEKSANDR MAKAROV	{"phone": "+70787203089"}
0005432753314	53133E	5310 777973	EMIL BORISOV	{"phone": "+70520860222"}
0005432753315	02F3E3	1517 215793	IGOR BARANOV	{"phone": "+70917487811"}
0005432753316	4C5266	0448 651176	OLGA MAKAROVA	{"email": "makarovaolga.041954@postgrespro.ru", "phone": "+70667868547"}
0005432753317	A3C951	8383 249846	VALENTINA SMIRNOVA	{"phone": "+70342173360"}
0005432753318	FE5974	4688 740871	ANGELINA VOROBEVA	{"phone": "+70622208108"}
0005432753319	FE5974	9651 862707	ANATOLIY SCHERBAKOV	{"phone": "+70298842041"}
0005432753320	3D3433	0633 888124	ELENA ZAKHAROVA	{"email": "zakharovae.031971@postgrespro.ru", "phone": "+70042463096"}
0005432753321	F23C20	6678 067948	ANNA ALEKSANDROVA	{"phone": "+70198740599"}
0005432753322	342827	3109 788186	SVETLANA DANILOVA	{"email": "danilova_svetlana.20061971@postgrespro.ru", "phone": "+70485831793"}
0005432753323	24128B	2410 534040	ALEKSANDR VOLKOV	{"email": "volkovaleksandr_061950@postgrespro.ru", "phone": "+70429432492"}
0005432753324	4F0712	1708 689163	NATALYA SOROKINA	{"email": "sorokina.natalya_27041969@postgrespro.ru", "phone": "+70372571013"}
0005432753325	4F0712	4571 854963	KONSTANTIN SIDOROV	{"phone": "+70615729154"}
0005432753326	A4538C	6334 008865	DMITRIY MAKAROV	{"email": "makarovd.05121969@postgrespro.ru", "phone": "+70427886001"}
0005432753327	94FA04	2749 148454	OLGA SERGEEVA	{"phone": "+70573617908"}
0005432753328	861A9E	7236 855664	YURIY ORLOV	{"phone": "+70990115054"}
0005432753329	861A9E	3154 458607	IRINA KONOVALOVA	{"email": "i_konovalova_1969@postgrespro.ru", "phone": "+70625350107"}
0005432753330	86443A	5421 452706	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr.091977@postgrespro.ru", "phone": "+70710718233"}
0005432753331	86443A	0832 484034	MIKHAIL NOVIKOV	{"email": "novikov.mikhail_1973@postgrespro.ru", "phone": "+70160650213"}
0005432755123	44E52C	7202 431263	NINA OSIPOVA	{"phone": "+70081075334"}
0005432753332	311E3C	0069 148461	GALINA KUZNECOVA	{"email": "galina.kuznecova_1980@postgrespro.ru", "phone": "+70603562232"}
0005432753333	963DEA	6453 639388	MARINA ZAYCEVA	{"phone": "+70555104222"}
0005432753334	A15818	7649 214418	NATALYA FILATOVA	{"phone": "+70271138186"}
0005432753335	A15818	9206 789081	ALEKSANDR KOZLOV	{"email": "kozlov_a-1980@postgrespro.ru", "phone": "+70651831524"}
0005432753336	DA3C66	5177 103861	OLGA SOLOVEVA	{"email": "soloveva_o28111977@postgrespro.ru", "phone": "+70999548983"}
0005432753337	78D77B	7176 929009	TATYANA SERGEEVA	{"phone": "+70136902191"}
0005432753338	3395DD	2269 135090	GALINA ISAEVA	{"phone": "+70930897806"}
0005432753339	34CEE6	0529 436406	ALEKSANDR GRIGOREV	{"phone": "+70597152517"}
0005432753340	724AB7	8517 786489	TAISIYA GRISHINA	{"phone": "+70062205065"}
0005432753341	349D2D	8693 933334	TATYANA VOLKOVA	{"email": "tatyana-volkova.041969@postgrespro.ru", "phone": "+70709157076"}
0005432753342	4B081F	2919 066642	VLADIMIR GERASIMOV	{"email": "v_gerasimov.1960@postgrespro.ru", "phone": "+70901743280"}
0005432753343	4B081F	7333 481223	ALEKSANDR EGOROV	{"email": "egorov.a_1973@postgrespro.ru", "phone": "+70438202932"}
0005432753344	5F22D9	5511 015400	VITALIY DAVYDOV	{"email": "davydov.v_1967@postgrespro.ru", "phone": "+70721403553"}
0005432753345	5F22D9	7666 816774	KSENIYA KUZNECOVA	{"email": "k-kuznecova30091966@postgrespro.ru", "phone": "+70086088609"}
0005432753346	4F2EFB	5664 001779	MARINA GORBUNOVA	{"email": "m_gorbunova_071980@postgrespro.ru", "phone": "+70450527526"}
0005432753347	05DE53	9695 439982	ANDREY MEDVEDEV	{"phone": "+70343285972"}
0005432753348	05DE53	3258 975978	YULIYA IVANOVA	{"email": "yuliya-ivanova_29121976@postgrespro.ru", "phone": "+70544548588"}
0005432753349	234F5D	8979 518473	MARINA EGOROVA	{"email": "egorova-marina_18101971@postgrespro.ru", "phone": "+70779393249"}
0005432753350	34FD61	7746 817963	ELENA GAVRILOVA	{"phone": "+70494443797"}
0005432753351	712204	6860 493604	ANDREY STEPANOV	{"phone": "+70272907354"}
0005432753352	712204	6578 884936	IVAN EGOROV	{"phone": "+70054633570"}
0005432753353	712204	7594 516722	NINA GAVRILOVA	{"phone": "+70749539368"}
0005432753354	AA3EA4	0748 297856	KONSTANTIN KOZLOV	{"email": "konstantin.kozlov1975@postgrespro.ru", "phone": "+70614213586"}
0005432753355	0283F6	6034 594481	DMITRIY FOMIN	{"email": "fomindmitriy.07091974@postgrespro.ru", "phone": "+70175996495"}
0005432753356	185631	5984 477951	ANASTASIYA PETROVA	{"email": "anastasiya-petrova.041972@postgrespro.ru", "phone": "+70663365797"}
0005432753357	E05A68	8443 494900	ALEKSEY KUZNECOV	{"phone": "+70157926310"}
0005432753358	E05A68	2325 718656	VALERIY DMITRIEV	{"phone": "+70353802195"}
0005432753359	D8E8F1	5651 159105	VALENTINA PAVLOVA	{"email": "pavlovav.26111971@postgrespro.ru", "phone": "+70665815139"}
0005432753360	784485	5689 096152	ANNA DANILOVA	{"email": "danilova.a.1966@postgrespro.ru", "phone": "+70719203912"}
0005432753361	784485	0555 147127	DMITRIY RODIONOV	{"phone": "+70853371867"}
0005432753362	313480	6057 499519	DARYA IVANOVA	{"phone": "+70164292010"}
0005432753363	BC2FAD	3516 245995	NURIYA NIKITINA	{"email": "nnikitina-14091969@postgrespro.ru", "phone": "+70203192365"}
0005432753364	E11B26	8711 099267	ALEKSEY FEDOROV	{"email": "aleksey_fedorov31051965@postgrespro.ru", "phone": "+70110377980"}
0005432753365	E11B26	4672 952715	VITALIY MEDVEDEV	{"email": "vmedvedev-051975@postgrespro.ru", "phone": "+70604375162"}
0005432753366	E11B26	8244 348725	VALERIY KOZLOV	{"email": "kozlovv1972@postgrespro.ru", "phone": "+70474898021"}
0005432753367	16E865	3083 639442	VALENTINA VASILEVA	{"email": "vasileva.v-1970@postgrespro.ru", "phone": "+70173448469"}
0005432753368	70D2BF	6454 498359	KRISTINA ORLOVA	{"phone": "+70909616948"}
0005432753369	70D2BF	3917 703787	MAKSIM AFANASEV	{"phone": "+70352279071"}
0005432753370	FBD9FB	0944 192640	YURIY VLASOV	{"phone": "+70147437946"}
0005432753371	E12CE6	1503 812244	ILYA VASILEV	{"email": "vasilevi-1976@postgrespro.ru", "phone": "+70011808898"}
0005432753372	B04DD0	4800 628384	FARIDA IVANOVA	{"email": "ivanova_farida-26071976@postgrespro.ru", "phone": "+70495444102"}
0005432753373	B04DD0	9243 852981	RAIS NIKOLAEV	{"phone": "+70700373827"}
0005432753374	9B6E65	7210 553549	ALBINA ANDREEVA	{"phone": "+70065512723"}
0005432753375	9B6E65	3962 687373	EVGENIYA NIKITINA	{"email": "nikitina_evgeniya.1966@postgrespro.ru", "phone": "+70804131921"}
0005432753376	F295FA	8400 397832	TAISIYA ANDREEVA	{"phone": "+70633652221"}
0005432753377	F295FA	0175 700648	ALEKSANDR ZAKHAROV	{"phone": "+70020707461"}
0005432753378	F295FA	0091 946162	ANTON ZHURAVLEV	{"phone": "+70744437545"}
0005432753379	30892B	6381 027000	SNEZHANA ISAEVA	{"phone": "+70186601505"}
0005432753380	30892B	7767 322021	RUFINA OVCHINNIKOVA	{"email": "rufina_ovchinnikova.111970@postgrespro.ru", "phone": "+70440225610"}
0005432753381	670C75	6299 032212	EVGENIY NIKITIN	{"email": "nikitin_evgeniy_1967@postgrespro.ru", "phone": "+70759461841"}
0005432753382	03DEF8	5525 638878	ALEKSANDR ZAYCEV	{"email": "zaycev_aleksandr_081973@postgrespro.ru", "phone": "+70864036312"}
0005432753383	B33377	6037 287836	ALINA CHERNOVA	{"phone": "+70157618183"}
0005432753384	B99BC7	6591 385688	ELENA SEMENOVA	{"email": "semenova-e1977@postgrespro.ru", "phone": "+70984549742"}
0005432753385	B99BC7	9454 966373	ALEKSANDR TIKHONOV	{"email": "aleksandr-tikhonov.1976@postgrespro.ru", "phone": "+70677483559"}
0005432753386	2D231B	9847 919776	MARIYA ROMANOVA	{"email": "romanova_mariya_1974@postgrespro.ru", "phone": "+70805877776"}
0005432753387	54B5A6	7113 655520	ANGELINA KUZNECOVA	{"email": "kuznecova.a_1983@postgrespro.ru", "phone": "+70717533941"}
0005432753388	61413D	0052 804611	TATYANA KAZAKOVA	{"email": "t_kazakova101981@postgrespro.ru", "phone": "+70818059404"}
0005432753389	257725	2215 372703	OLEG MELNIKOV	{"email": "melnikov_oleg_101972@postgrespro.ru", "phone": "+70660427251"}
0005432753390	BCBBDB	4535 856250	NATALYA MIKHAYLOVA	{"phone": "+70856316059"}
0005432753391	960D6A	6981 456305	LYUDMILA GERASIMOVA	{"phone": "+70755094238"}
0005432753392	960D6A	3746 156209	ANATOLIY SOKOLOV	{"email": "anatoliy_sokolov_1971@postgrespro.ru", "phone": "+70583291469"}
0005432753393	F6D349	5744 750715	NATALIYA POTAPOVA	{"email": "nataliya_potapova.27011973@postgrespro.ru", "phone": "+70713351887"}
0005432753394	D1725F	8558 865294	LYUDMILA BORISOVA	{"email": "borisova_lyudmila_1975@postgrespro.ru", "phone": "+70469476838"}
0005432753395	709DD5	0809 993771	ALEKSEY ILIN	{"phone": "+70112651498"}
0005432753396	C22AC3	7321 597374	EVGENIY FEDOROV	{"phone": "+70466373780"}
0005432753397	C22AC3	8433 400026	TAMARA POPOVA	{"email": "tamara_popova-21101958@postgrespro.ru", "phone": "+70079784292"}
0005432753398	63D2CF	7345 801158	OLEG KAZAKOV	{"phone": "+70079325170"}
0005432753399	1FB33B	9224 493030	DIANA VASILEVA	{"email": "dvasileva.06051974@postgrespro.ru", "phone": "+70335140295"}
0005432753400	78EC85	7558 552954	RENAT DMITRIEV	{"email": "r-dmitriev.081973@postgrespro.ru", "phone": "+70612894847"}
0005432753401	DB4586	7876 486929	VLADISLAV GUSEV	{"phone": "+70565116640"}
0005432755024	BCC390	1577 870855	ELENA KUZNECOVA	{"phone": "+70252791562"}
0005432755015	A2B801	4056 913996	ANDREY ROMANOV	{"phone": "+70841903111"}
0005432755016	6BAAF2	9289 905222	NATALYA PAVLOVA	{"email": "natalyapavlova-24111961@postgrespro.ru", "phone": "+70347655578"}
0005432755017	6BAAF2	9578 349831	VLADIMIR ZHUKOV	{"phone": "+70153787544"}
0005432755018	691A49	6404 798996	VIKTOR MAKAROV	{"email": "makarovviktor.02071977@postgrespro.ru", "phone": "+70945574444"}
0005432755019	691A49	0683 908843	VLADIMIR PETROV	{"phone": "+70342569025"}
0005432755020	D5363A	5196 693356	ANTONINA KOMAROVA	{"email": "antoninakomarova.23021964@postgrespro.ru", "phone": "+70829387387"}
0005432755021	C741CE	2236 889833	ALEKSANDR PETROV	{"phone": "+70638211159"}
0005432755022	C741CE	7373 134020	DMITRIY AFANASEV	{"phone": "+70445479745"}
0005432755023	BCC390	2423 814506	NATALYA MOISEEVA	{"email": "moiseevan1969@postgrespro.ru", "phone": "+70515762118"}
0005432755025	BCC390	9133 974227	OLESYA ILINA	{"email": "ilina-olesya_1974@postgrespro.ru", "phone": "+70869271706"}
0005432755026	DFD2F6	4039 969489	NATALYA NAZAROVA	{"phone": "+70917128249"}
0005432755027	15176B	4036 208982	VIKTOR ORLOV	{"email": "orlovviktor_23111973@postgrespro.ru", "phone": "+70778871647"}
0005432755028	15176B	7073 733360	IVAN KRASNOV	{"email": "krasnov-ivan-1974@postgrespro.ru", "phone": "+70761408203"}
0005432755029	B03DB9	7345 033828	VERA ROMANOVA	{"email": "romanova_vera1972@postgrespro.ru", "phone": "+70380621090"}
0005432755030	091C35	4616 949198	TAMARA FROLOVA	{"email": "frolovatamara.031968@postgrespro.ru", "phone": "+70209828140"}
0005432755031	6F3E18	2750 014280	EVGENIY KISELEV	{"phone": "+70279249277"}
0005432755032	4AEE1F	6604 100123	LYUDMILA VOROBEVA	{"email": "lvorobeva-02091978@postgrespro.ru", "phone": "+70376318214"}
0005432755033	962E99	9198 567369	LYUBOV VOROBEVA	{"email": "vorobeva.l_1968@postgrespro.ru", "phone": "+70359394262"}
0005432755034	962E99	9395 521661	ELENA MATVEEVA	{"phone": "+70863011259"}
0005432755035	473B06	1571 382006	ANDREY VASILEV	{"email": "andrey-vasilev-1960@postgrespro.ru", "phone": "+70949226435"}
0005432755036	473B06	8459 685483	IRINA ZOTOVA	{"phone": "+70201821907"}
0005432755037	258FC1	4268 085690	NATALYA VASILEVA	{"phone": "+70237768317"}
0005432755038	CECA49	2412 140020	GALINA VOLKOVA	{"phone": "+70838255543"}
0005432755039	545D8C	1810 206518	NIKOLAY SOKOLOV	{"email": "n-sokolov_12071977@postgrespro.ru", "phone": "+70094987136"}
0005432755040	545D8C	3578 027438	ELMIRA POTAPOVA	{"phone": "+70923896684"}
0005432755041	12F4DD	5793 785535	INNA POPOVA	{"email": "popova-inna.011979@postgrespro.ru", "phone": "+70289983789"}
0005432755042	12F4DD	9926 516801	VADIM FROLOV	{"phone": "+70485191115"}
0005432755043	844DCF	6741 443503	ANNA VOROBEVA	{"email": "annavorobeva1969@postgrespro.ru", "phone": "+70444404571"}
0005432755044	844DCF	1308 669714	VYACHESLAV NIKITIN	{"phone": "+70103934332"}
0005432755045	CC6003	0563 928187	VALENTINA NIKITINA	{"phone": "+70568909602"}
0005432755046	5BD029	3537 962996	RUSLAN PAVLOV	{"email": "pavlov.r-1973@postgrespro.ru", "phone": "+70865743646"}
0005432755047	9F61B3	3870 559234	ILGIZ FROLOV	{"email": "frolov.i011977@postgrespro.ru", "phone": "+70880537340"}
0005432755048	B5AA3C	3563 745851	VALENTINA GUSEVA	{"email": "guseva_valentina-1968@postgrespro.ru", "phone": "+70740943772"}
0005432755049	DAB018	7974 478435	LIYA MOROZOVA	{"email": "morozova-l.1963@postgrespro.ru", "phone": "+70098938390"}
0005432755050	F8FE2D	7290 717447	VYACHESLAV FROLOV	{"phone": "+70360408753"}
0005432755051	5362E0	5424 583829	DARYA BELOVA	{"email": "belovad.1980@postgrespro.ru", "phone": "+70847158463"}
0005432755052	ECEB5F	3784 299943	YURIY BARANOV	{"phone": "+70664492014"}
0005432755053	2B68C2	2887 500981	NIKITA SOLOVEV	{"phone": "+70398599282"}
0005432755054	8E9A52	6886 107206	DMITRIY EGOROV	{"email": "d_egorov111973@postgrespro.ru", "phone": "+70309218682"}
0005432755055	4C63CA	7333 915706	ALEKSEY ZAYCEV	{"phone": "+70872326869"}
0005432755056	E8C5FF	3882 392526	SVETLANA ERMAKOVA	{"email": "ermakovas.1968@postgrespro.ru", "phone": "+70465355594"}
0005432755057	E34F88	3602 071775	VIKTOR GAVRILOV	{"email": "v.gavrilov.04091974@postgrespro.ru", "phone": "+70223978778"}
0005432755058	ABF5E9	9476 628095	LEONID NOVIKOV	{"email": "leonidnovikov.101980@postgrespro.ru", "phone": "+70454780351"}
0005432755059	832A55	4365 783317	LIDIYA KOROLEVA	{"phone": "+70686773953"}
0005432755060	832A55	1673 320854	OKSANA EFIMOVA	{"email": "o-efimova_04011967@postgrespro.ru", "phone": "+70403057192"}
0005432755061	C058C3	9054 189015	DIANA ANDREEVA	{"email": "d_andreeva_1969@postgrespro.ru", "phone": "+70901458157"}
0005432755062	3B7AC0	6345 018942	ALEKSANDR ILIN	{"email": "a-ilin051972@postgrespro.ru", "phone": "+70852913013"}
0005432755063	3B7AC0	6695 402128	ALEKSANDR ZAYCEV	{"phone": "+70498279864"}
0005432755064	BA3F0E	8693 795526	ANNA IVANOVA	{"phone": "+70463109318"}
0005432755065	BA3F0E	3636 334387	NATALYA FILIPPOVA	{"email": "filippova_n.22011959@postgrespro.ru", "phone": "+70921620612"}
0005432755066	E3A99E	4792 459842	ANATOLIY NAUMOV	{"email": "anaumov.071965@postgrespro.ru", "phone": "+70143831147"}
0005432755067	E3A99E	3348 123353	MAKSIM ZAYCEV	{"email": "zaycev_m_09121964@postgrespro.ru", "phone": "+70063044460"}
0005432755068	791938	5848 769067	ANTONINA BARANOVA	{"phone": "+70283704526"}
0005432755069	4F0052	9136 982941	DARYA SMIRNOVA	{"phone": "+70254361122"}
0005432755070	4F0052	8497 159764	NATALYA KOLESNIKOVA	{"email": "nkolesnikova.04041965@postgrespro.ru", "phone": "+70274420733"}
0005432755071	B22926	8733 646577	SVETLANA EGOROVA	{"email": "egorovas1980@postgrespro.ru", "phone": "+70195274897"}
0005432755072	49CE3F	1971 946789	DANILA NIKOLAEV	{"phone": "+70093572912"}
0005432755073	9EF133	2712 645614	VIKTORIYA LEBEDEVA	{"email": "lebedeva_viktoriya-121979@postgrespro.ru", "phone": "+70283126388"}
0005432755074	9EF133	6062 865129	TAMARA YAKOVLEVA	{"email": "yakovlevat.05081969@postgrespro.ru", "phone": "+70112047485"}
0005432755075	E70B79	4192 245886	SVETLANA MAKAROVA	{"phone": "+70275364511"}
0005432755076	B849FB	3756 949360	ALEKSEY SEMENOV	{"phone": "+70088913996"}
0005432755077	1B23AE	9513 030279	OLGA KONOVALOVA	{"phone": "+70135890886"}
0005432755078	995B94	7188 896277	VALENTINA OSIPOVA	{"phone": "+70871457924"}
0005432755079	995B94	8860 267776	ANNA IVANOVA	{"email": "ivanova-a081972@postgrespro.ru", "phone": "+70896194213"}
0005432755080	95E743	8831 993400	ELENA NIKITINA	{"email": "nikitinaelena-021969@postgrespro.ru", "phone": "+70657471442"}
0005432755081	330B56	7905 951963	GALINA BOGDANOVA	{"phone": "+70065074430"}
0005432755082	662605	2038 824765	TATYANA SIDOROVA	{"email": "t-sidorova.091972@postgrespro.ru", "phone": "+70808980513"}
0005432755083	662605	8360 176087	IRINA BARANOVA	{"email": "irina.baranova.1965@postgrespro.ru", "phone": "+70101405590"}
0005432755084	662605	0544 802590	NATALYA KARPOVA	{"phone": "+70999813171"}
0005432755085	F87378	0337 961334	RAFAIL TARASOV	{"email": "rtarasov081970@postgrespro.ru", "phone": "+70763511501"}
0005432755086	DEBA24	6528 856216	YAROSLAV GRIGOREV	{"email": "yaroslav_grigorev-041975@postgrespro.ru", "phone": "+70752932131"}
0005432755087	524C76	6051 075207	OLGA KRASNOVA	{"email": "krasnova-o23031977@postgrespro.ru", "phone": "+70272891600"}
0005432755088	524C76	4964 948705	NATALIYA ALEKSEEVA	{"email": "n_alekseeva1960@postgrespro.ru", "phone": "+70092270727"}
0005432755089	60D22D	5102 046493	ALBINA DANILOVA	{"phone": "+70443477348"}
0005432755090	BA9736	2718 026040	LARISA MATVEEVA	{"phone": "+70780898653"}
0005432755091	BA9736	6747 950529	YULIYA OVCHINNIKOVA	{"email": "ovchinnikovayuliya-1978@postgrespro.ru", "phone": "+70758156317"}
0005432755092	8CCFEF	3685 847155	OLGA KOZLOVA	{"email": "kozlova_o091971@postgrespro.ru", "phone": "+70542721349"}
0005432755093	8CCFEF	0348 528559	VYACHESLAV AFANASEV	{"email": "afanasev.vyacheslav1977@postgrespro.ru", "phone": "+70850607201"}
0005432755094	C17A60	0021 807554	GALINA TIMOFEEVA	{"email": "galina.timofeeva-041981@postgrespro.ru", "phone": "+70300113430"}
0005432755095	C17A60	4557 611430	ALEKSEY KUZNECOV	{"phone": "+70607329903"}
0005432755096	0DF198	4260 587372	YULIYA NIKOLAEVA	{"email": "y_nikolaeva_05021978@postgrespro.ru", "phone": "+70552443473"}
0005432755097	E925DB	5822 870502	LARISA TARASOVA	{"phone": "+70337100918"}
0005432755098	5DB189	4087 985256	TATYANA EFIMOVA	{"email": "t.efimova13091975@postgrespro.ru", "phone": "+70632376915"}
0005432755099	A0FDC7	0314 823117	IRINA NIKOLAEVA	{"phone": "+70722450760"}
0005432755100	4D6323	4953 735792	LILIYA ERMAKOVA	{"email": "l-ermakova-28011984@postgrespro.ru", "phone": "+70596320071"}
0005432755101	44CAAE	0919 030383	OLEG MAKAROV	{"email": "o_makarov-12051973@postgrespro.ru", "phone": "+70010886946"}
0005432755102	CB162E	2327 250885	NIKOLAY NIKITIN	{"email": "nikitin.n.04091978@postgrespro.ru", "phone": "+70752467422"}
0005432755103	A21350	6291 290022	ELENA SOKOLOVA	{"phone": "+70549775369"}
0005432755104	A21350	3977 900482	ALEKSANDR NIKOLAEV	{"phone": "+70296902967"}
0005432755105	ACE5F0	6277 339570	DMITRIY IVANOV	{"phone": "+70529758628"}
0005432755106	DC4B6D	2276 491871	VIKTORIYA RODIONOVA	{"email": "viktoriya.rodionova_17011977@postgrespro.ru", "phone": "+70867553853"}
0005432755107	AE569A	7400 229626	TATYANA POTAPOVA	{"email": "potapova_tatyana121965@postgrespro.ru", "phone": "+70266668505"}
0005432755108	743443	0107 621366	KONSTANTIN SIDOROV	{"email": "k.sidorov_071971@postgrespro.ru", "phone": "+70573736476"}
0005432755109	743443	8806 338709	NATALYA LEBEDEVA	{"phone": "+70590509319"}
0005432755110	3F58F6	1029 569106	MARIYA ILINA	{"phone": "+70745000175"}
0005432755111	3F58F6	7129 923029	GALINA ANDREEVA	{"email": "andreeva-galina_101965@postgrespro.ru", "phone": "+70505180123"}
0005432755112	71A7F3	2077 827880	MARIYA TIMOFEEVA	{"email": "m.timofeeva-29061963@postgrespro.ru", "phone": "+70686480601"}
0005432755113	1A6A02	5298 769925	ANASTASIYA KOMAROVA	{"email": "komarova_anastasiya081975@postgrespro.ru", "phone": "+70059227083"}
0005432755114	1A6A02	1667 890946	ROMAN SIDOROV	{"email": "sidorov-roman-1982@postgrespro.ru", "phone": "+70688776404"}
0005432755115	BE2BD0	9097 223735	ALEKSEY IVANOV	{"email": "ivanov.aleksey1973@postgrespro.ru", "phone": "+70697750562"}
0005432755116	85F24C	0188 867806	VERA LUKYANOVA	{"phone": "+70709740762"}
0005432755117	A2DC66	0267 395256	LYUCIYA FILIPPOVA	{"email": "filippova_lyuciya01031975@postgrespro.ru", "phone": "+70714338084"}
0005432755118	A2DC66	4266 542535	NATALYA FROLOVA	{"email": "n.frolova_16061966@postgrespro.ru", "phone": "+70569490498"}
0005432755119	F67B5C	2112 002590	ELENA MEDVEDEVA	{"email": "elena_medvedeva.031964@postgrespro.ru", "phone": "+70070156205"}
0005432755120	F67B5C	5886 260523	ELENA YUDINA	{"phone": "+70293277343"}
0005432755121	36C0BA	3865 287552	NATALYA MATVEEVA	{"email": "matveeva.natalya.10101961@postgrespro.ru", "phone": "+70270685331"}
0005432755122	36C0BA	2424 652623	GALINA KUZNECOVA	{"phone": "+70326867837"}
0005432755124	44E52C	3660 480398	DMITRIY GERASIMOV	{"email": "gerasimovdmitriy.17011963@postgrespro.ru", "phone": "+70878551485"}
0005432755125	EA326D	7297 757655	GALINA EFREMOVA	{"email": "efremova-galina041976@postgrespro.ru", "phone": "+70327392871"}
0005432755126	90B708	3292 192515	GALIYA ZAKHAROVA	{"email": "zakharova.galiya.1968@postgrespro.ru", "phone": "+70914003026"}
0005432755127	90B708	9793 323471	IGOR VOROBEV	{"phone": "+70596364381"}
0005432755128	4D38C8	2272 364928	NIKITA GAVRILOV	{"phone": "+70300327005"}
0005432755129	014ADB	5974 320247	ELENA KOLESNIKOVA	{"email": "e-kolesnikova081976@postgrespro.ru", "phone": "+70269748283"}
0005432755130	014ADB	5463 269513	ELENA SOLOVEVA	{"phone": "+70231548995"}
0005432755131	F76BB8	6780 028809	EVGENIYA SEMENOVA	{"email": "esemenova.1975@postgrespro.ru", "phone": "+70866607420"}
0005432755132	6D7687	4271 738181	IRINA LOGINOVA	{"email": "irina.loginova041964@postgrespro.ru", "phone": "+70704727254"}
0005432755133	F1655F	9752 062698	VALERIY KULIKOV	{"email": "valeriy-kulikov_14011970@postgrespro.ru", "phone": "+70382343941"}
0005432755134	3733A5	4282 933651	TATYANA KUZNECOVA	{"email": "tatyanakuznecova_121969@postgrespro.ru", "phone": "+70507021239"}
0005432755135	3733A5	8509 228425	ARTEM FEDOROV	{"phone": "+70256254761"}
0005432755136	0EDF79	5878 280554	DZHAMILYA MEDVEDEVA	{"email": "medvedeva_d051983@postgrespro.ru", "phone": "+70817251731"}
0005432755137	4D6306	3547 074156	TAMARA ZOTOVA	{"email": "zotovatamara_121967@postgrespro.ru", "phone": "+70139419956"}
0005432755138	C8B0E8	9970 389799	ALEKSANDR VOLKOV	{"email": "volkov_a1970@postgrespro.ru", "phone": "+70665588307"}
0005432755139	C8B0E8	0356 090228	ALEKSANDR IVANOV	{"email": "ivanov-a.1962@postgrespro.ru", "phone": "+70903126720"}
0005432755140	A8949C	1361 008631	TATYANA ZAYCEVA	{"phone": "+70016483558"}
0005432755141	BC5899	1193 085110	ANNA GRISHINA	{"phone": "+70125032593"}
0005432755142	1A0B17	4026 794333	ALEKSEY CHERNOV	{"email": "chernov_aleksey19011973@postgrespro.ru", "phone": "+70398223629"}
0005432755143	D461D8	3233 430332	ALEKSANDRA BARANOVA	{"email": "a-baranova_17031980@postgrespro.ru", "phone": "+70924346637"}
0005432755144	5481D3	4247 625115	EVGENIY ANTONOV	{"email": "antonov_evgeniy_03111977@postgrespro.ru", "phone": "+70533895933"}
0005432755145	26AA10	0157 956481	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_aleksandr.1974@postgrespro.ru", "phone": "+70402611097"}
0005432755146	26AA10	1010 796299	GALINA OSIPOVA	{"email": "galina-osipova-06101972@postgrespro.ru", "phone": "+70550525309"}
0005432755147	26AA10	8187 269123	ALIYA PAVLOVA	{"email": "pavlova_aliya.1973@postgrespro.ru", "phone": "+70590594460"}
0005432755148	C4F52A	9293 423946	ANNA KUDRYASHOVA	{"phone": "+70366323258"}
0005432755149	D7E505	1729 861291	ALEKSANDRA KUZMINA	{"email": "kuzmina_a.19091970@postgrespro.ru", "phone": "+70527180831"}
0005432755150	024E02	4391 728581	ELENA PETROVA	{"email": "petrova.e.30041972@postgrespro.ru", "phone": "+70591856577"}
0005432755151	338848	0372 857766	ELENA NESTEROVA	{"email": "elena-nesterova_19011965@postgrespro.ru", "phone": "+70090773945"}
0005432755152	338848	4895 615960	MARIYA GERASIMOVA	{"phone": "+70171981247"}
0005432755153	338848	1008 047411	SVETLANA LAZAREVA	{"phone": "+70870806853"}
0005432755154	C03B25	8107 129844	VERA ZAYCEVA	{"phone": "+70712574999"}
0005432755155	F17793	1916 566725	ANNA CHERNOVA	{"phone": "+70640301743"}
0005432755156	F17793	6836 859459	LYUDMILA ANISIMOVA	{"email": "l-anisimova-01091965@postgrespro.ru", "phone": "+70148375059"}
0005432755157	4EB40A	3676 034394	SAVELIY KRASNOV	{"phone": "+70155829033"}
0005432755158	4EB40A	1166 634835	ALEKSEY RODIONOV	{"email": "a_rodionov_061975@postgrespro.ru", "phone": "+70520743384"}
0005432755159	4EB40A	3986 981509	YURIY ZHURAVLEV	{"phone": "+70018638683"}
0005432755160	4E2EC6	3030 785717	ALEVTINA BOGDANOVA	{"phone": "+70195068333"}
0005432755161	B46F11	7247 366568	ANNA KUZNECOVA	{"email": "a-kuznecova.1981@postgrespro.ru", "phone": "+70907376189"}
0005432755162	E852D1	1307 614589	LYUDMILA IVANOVA	{"email": "l_ivanova.07101964@postgrespro.ru", "phone": "+70152603403"}
0005432755163	B1A65D	2663 575120	OLEG ZAYCEV	{"email": "ozaycev031973@postgrespro.ru", "phone": "+70852435935"}
0005432755164	B1A65D	9205 071915	NIKITA BORISOV	{"phone": "+70943611361"}
0005432755165	585397	4683 516315	ANATOLIY VLASOV	{"email": "vlasov_anatoliy_11111966@postgrespro.ru", "phone": "+70982917136"}
0005432755166	585397	9996 387862	ANDREY EGOROV	{"phone": "+70725394155"}
0005432755167	B8863B	6422 905509	OLEG NOVIKOV	{"email": "novikov-oleg17021972@postgrespro.ru", "phone": "+70921241095"}
0005432755168	A01D4B	1297 506842	IRINA ISAEVA	{"email": "i-isaeva071961@postgrespro.ru", "phone": "+70873177413"}
0005432755169	A01D4B	3143 250320	YURIY OSIPOV	{"email": "y.osipov29011982@postgrespro.ru", "phone": "+70741306410"}
0005432755170	90934D	6318 983107	MARINA KOROLEVA	{"email": "m-koroleva_041977@postgrespro.ru", "phone": "+70052616714"}
0005432755171	737C92	7891 913027	VALENTINA ANISIMOVA	{"phone": "+70941438110"}
0005432755172	C422F3	3195 921720	YULIYA MALYSHEVA	{"phone": "+70451329011"}
0005432755173	C422F3	6888 718836	EVGENIY TIMOFEEV	{"email": "e_timofeev1964@postgrespro.ru", "phone": "+70428410452"}
0005432756927	D3D103	0527 988175	YULIYA MOROZOVA	{"phone": "+70808359350"}
0005432756787	9F20C6	4686 997548	MARIYA MOROZOVA	{"email": "m.morozova-17031954@postgrespro.ru", "phone": "+70071219594"}
0005432756788	9FB918	2164 850657	DANILA KOZLOV	{"email": "kozlov-danila-1970@postgrespro.ru", "phone": "+70294745130"}
0005432756789	9FB918	4692 192336	VIKTOR TIKHONOV	{"email": "tikhonov.v121972@postgrespro.ru", "phone": "+70725890955"}
0005432756790	C8CF07	5109 222109	MARIYA NIKIFOROVA	{"phone": "+70008744882"}
0005432756791	C8CF07	1938 362972	SVETLANA NIKITINA	{"email": "nikitina_svetlana-061969@postgrespro.ru", "phone": "+70017063534"}
0005432756792	31E345	2342 361370	EKATERINA SERGEEVA	{"email": "esergeeva13111973@postgrespro.ru", "phone": "+70327267111"}
0005432756793	E2E063	4999 935838	VIOLETTA KOZLOVA	{"email": "kozlova.v1970@postgrespro.ru", "phone": "+70740480240"}
0005432756794	CD20C8	0660 873984	MAKSIM FILIPPOV	{"email": "filippovm_081975@postgrespro.ru", "phone": "+70636824285"}
0005432756795	CD20C8	1166 251632	DMITRIY FOMIN	{"phone": "+70530281349"}
0005432756796	E272D7	9660 294010	ANNA AFANASEVA	{"email": "anna_afanaseva.1965@postgrespro.ru", "phone": "+70618508332"}
0005432756797	2EE1B4	1912 405410	ALEKSANDR ROMANOV	{"email": "aromanov_011973@postgrespro.ru", "phone": "+70214984100"}
0005432756798	EF0A90	6537 217153	ALEKSANDR FOMIN	{"email": "aleksandrfomin_1963@postgrespro.ru", "phone": "+70572421032"}
0005432756799	EF0A90	1339 086677	SVETLANA MIKHAYLOVA	{"email": "mikhaylova-svetlana-101973@postgrespro.ru", "phone": "+70890024440"}
0005432756800	E4B6F3	1157 652193	ARTEM MAKAROV	{"phone": "+70998229383"}
0005432756801	5F9131	9675 131201	ANDREY ALEKSEEV	{"email": "a.alekseev111973@postgrespro.ru", "phone": "+70752826253"}
0005432756802	A54E63	0568 762298	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir_1978@postgrespro.ru", "phone": "+70936178394"}
0005432756803	A54E63	1418 507477	MADINA BELOVA	{"email": "belova-m111979@postgrespro.ru", "phone": "+70480170572"}
0005432756804	4EA98B	2523 464352	OLGA MIRONOVA	{"email": "mironova-o.081972@postgrespro.ru", "phone": "+70738842697"}
0005432756805	3F9334	9841 388143	SVETLANA OSIPOVA	{"phone": "+70368494045"}
0005432756806	3F9334	4468 727673	KLAVDIYA PETROVA	{"email": "klavdiyapetrova.071972@postgrespro.ru", "phone": "+70618979692"}
0005432756807	E32B92	8865 208948	SERGEY PETROV	{"email": "petrovsergey-021981@postgrespro.ru", "phone": "+70859927245"}
0005432756808	FFF1F9	9793 346487	ANNA EFIMOVA	{"phone": "+70891465752"}
0005432756809	800BE5	7166 780421	LIDIYA OSIPOVA	{"email": "osipovalidiya.1960@postgrespro.ru", "phone": "+70255174417"}
0005432756810	1D6C64	1568 391252	MARIYA BARANOVA	{"phone": "+70388620471"}
0005432756811	CB5582	9207 747282	GENNADIY FROLOV	{"phone": "+70419223884"}
0005432756812	CB5582	4230 414142	VALENTIN KOZLOV	{"phone": "+70087171731"}
0005432756813	098A2D	8791 429072	SVETLANA TITOVA	{"email": "stitova-07071970@postgrespro.ru", "phone": "+70270841883"}
0005432756814	909260	9779 798496	IGOR IVANOV	{"email": "igor-ivanov021976@postgrespro.ru", "phone": "+70047178007"}
0005432756815	ECD34C	2366 637479	SERGEY MEDVEDEV	{"email": "medvedev_sergey.1973@postgrespro.ru", "phone": "+70750959030"}
0005432756816	ACF7C0	9242 905047	SERGEY GERASIMOV	{"email": "sergeygerasimov051977@postgrespro.ru", "phone": "+70929287954"}
0005432756817	ACF7C0	9725 695403	IRINA VASILEVA	{"phone": "+70454137348"}
0005432756818	BAB0E1	7679 637268	ALEKSEY PETROV	{"email": "petrov-a-011972@postgrespro.ru", "phone": "+70687671013"}
0005432756819	BAB0E1	0006 291957	ELENA KUZNECOVA	{"email": "e-kuznecova12081971@postgrespro.ru", "phone": "+70988355785"}
0005432756820	8A42EE	8043 507422	ALEKSANDR SOLOVEV	{"phone": "+70736030368"}
0005432756821	48532C	0311 409577	LEV TARASOV	{"email": "ltarasov-18041970@postgrespro.ru", "phone": "+70273443454"}
0005432756822	56ECE3	3705 091459	SERGEY NAZAROV	{"email": "sergey-nazarov-20081971@postgrespro.ru", "phone": "+70057376319"}
0005432756823	56ECE3	7022 998565	OLGA ORLOVA	{"email": "orlova-olga.1978@postgrespro.ru", "phone": "+70738778858"}
0005432756824	56ECE3	9863 441452	OLGA KOMAROVA	{"email": "komarova.olga_01081967@postgrespro.ru", "phone": "+70543213510"}
0005432756825	BA715B	3111 013051	VIKTOR KISELEV	{"phone": "+70913536522"}
0005432756826	6452F5	2691 549637	PAVEL YAKOVLEV	{"phone": "+70537372939"}
0005432756827	D00EDA	9550 699489	ALEKSANDR ANDREEV	{"email": "andreev_a.09091959@postgrespro.ru", "phone": "+70516686618"}
0005432756828	979C8E	4053 140131	OLEG BARANOV	{"email": "baranov.oleg_1971@postgrespro.ru", "phone": "+70242113345"}
0005432756829	5130B1	2550 453906	ARTEM MIKHAYLOV	{"email": "artem_mikhaylov_1957@postgrespro.ru", "phone": "+70497567681"}
0005432756830	1644B9	0050 084180	KIRILL EGOROV	{"email": "k.egorov-1995@postgrespro.ru", "phone": "+70673832501"}
0005432756831	C73F6D	2417 545500	ILYA CHERNOV	{"phone": "+70296884673"}
0005432756832	C73F6D	8811 255053	NATALYA KAZAKOVA	{"email": "n.kazakova-23011972@postgrespro.ru", "phone": "+70663658471"}
0005432756833	28B9A6	1568 650512	DMITRIY POPOV	{"email": "popov-d.17071963@postgrespro.ru", "phone": "+70940375398"}
0005432756834	C2F9CB	7159 871463	EGOR TIKHONOV	{"phone": "+70997840222"}
0005432756835	279D87	1270 316833	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva-021972@postgrespro.ru", "phone": "+70409235043"}
0005432756836	5FFAD5	4860 930950	ALEKSANDR MIRONOV	{"email": "aleksandrmironov061972@postgrespro.ru", "phone": "+70585225819"}
0005432756837	5FFAD5	1965 616158	PETR GUSEV	{"email": "petr.gusev-1979@postgrespro.ru", "phone": "+70485631097"}
0005432756838	FAB48F	9801 031938	SERGEY MOISEEV	{"email": "sergey-moiseev.03081980@postgrespro.ru", "phone": "+70513311758"}
0005432756839	FAB48F	5712 947192	YURIY KUZNECOV	{"phone": "+70066621247"}
0005432756840	A4C3FC	2382 360911	ANNA ANDREEVA	{"email": "andreevaanna1976@postgrespro.ru", "phone": "+70360042615"}
0005432756841	95276F	8539 179332	SVETLANA VOROBEVA	{"phone": "+70678847303"}
0005432756842	ED9B88	4945 056967	YULIYA LAZAREVA	{"phone": "+70747322881"}
0005432756843	ED9B88	6622 290943	EKATERINA VOLKOVA	{"phone": "+70117902028"}
0005432756844	0F4592	6497 194285	ALEKSANDR SEMENOV	{"phone": "+70345775817"}
0005432756845	1AFA33	6336 459121	SERGEY DAVYDOV	{"phone": "+70952319158"}
0005432756846	41E0DE	8727 599861	DARYA ZOTOVA	{"email": "zotovad-051983@postgrespro.ru", "phone": "+70251530955"}
0005432756847	41E0DE	0989 669630	SVETLANA VLASOVA	{"phone": "+70293802125"}
0005432756848	90A4F4	0823 352139	OLEG MOISEEV	{"email": "moiseev.oleg.091967@postgrespro.ru", "phone": "+70040215872"}
0005432756849	9D3363	6425 984208	GALINA ZOTOVA	{"phone": "+70801347485"}
0005432756850	9D3363	7058 301457	EVGENIY MIRONOV	{"phone": "+70253355953"}
0005432756851	49F8A3	6367 555921	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr-1974@postgrespro.ru", "phone": "+70344251483"}
0005432756852	49F8A3	9332 580926	KSENIYA PETROVA	{"email": "petrova.k_1974@postgrespro.ru", "phone": "+70633860574"}
0005432756853	637341	1522 730900	VALERIY ANDREEV	{"email": "v-andreev.12091965@postgrespro.ru", "phone": "+70097193329"}
0005432756854	637341	8867 091354	LYUDMILA ANTONOVA	{"phone": "+70151805744"}
0005432756855	637341	1126 253331	GEORGIY TARASOV	{"email": "tarasov_georgiy.1968@postgrespro.ru", "phone": "+70737164479"}
0005432756856	637341	6748 502561	IGOR ZHURAVLEV	{"phone": "+70005687287"}
0005432756857	703FDD	2763 588862	DMITRIY GERASIMOV	{"phone": "+70202134272"}
0005432756858	D290FC	9808 258780	EVGENIY PETROV	{"email": "petrovevgeniy_12081973@postgrespro.ru", "phone": "+70536257306"}
0005432756859	D290FC	1750 038451	ALEKSANDRA MELNIKOVA	{"phone": "+70830847123"}
0005432756860	D290FC	3917 119912	OLEG KRASNOV	{"email": "olegkrasnov-17101968@postgrespro.ru", "phone": "+70575347428"}
0005432756861	1D0DCB	9018 246159	OLEG SAVELEV	{"phone": "+70798753572"}
0005432756862	1D0DCB	4357 392034	GALINA POLYAKOVA	{"email": "galina.polyakova15091966@postgrespro.ru", "phone": "+70510235362"}
0005432756863	72C2C4	8602 510373	NIKOLAY KUZMIN	{"phone": "+70650478847"}
0005432756864	C9E1F4	6381 627383	TATYANA SIDOROVA	{"phone": "+70404211091"}
0005432756865	B54598	3066 495216	VIKTOR FILIPPOV	{"phone": "+70075955929"}
0005432756866	38470E	4861 008825	NIKOLAY SCHERBAKOV	{"email": "nscherbakov-09111983@postgrespro.ru", "phone": "+70370810335"}
0005432756867	38470E	6983 470043	ALEKSANDR DMITRIEV	{"email": "a_dmitriev-15121977@postgrespro.ru", "phone": "+70974855350"}
0005432756868	8AED1A	9082 354247	KONSTANTIN ZAKHAROV	{"email": "zakharov_konstantin-1974@postgrespro.ru", "phone": "+70865112316"}
0005432756869	599127	2277 668709	PETR NIKOLAEV	{"phone": "+70971272368"}
0005432756870	738557	2294 753840	OLGA FADEEVA	{"email": "fadeevao-07091970@postgrespro.ru", "phone": "+70951983146"}
0005432756871	F025E5	9009 970135	NIKOLAY MOISEEV	{"email": "moiseev_n1968@postgrespro.ru", "phone": "+70399093285"}
0005432756872	F025E5	9945 277932	NAIL EGOROV	{"phone": "+70049887892"}
0005432756873	1ABE84	8807 213472	KSENIYA GERASIMOVA	{"email": "kseniya-gerasimova_071973@postgrespro.ru", "phone": "+70345538366"}
0005432756874	1ABE84	1963 064413	LILIYA GRISHINA	{"phone": "+70260907632"}
0005432756875	FC2801	5761 051082	ELENA GUSEVA	{"email": "elenaguseva-29121973@postgrespro.ru", "phone": "+70752923533"}
0005432756876	FC2801	0188 510133	MARK STEPANOV	{"email": "stepanovmark28031975@postgrespro.ru", "phone": "+70165418016"}
0005432756877	F7F533	7789 870345	IGOR SOKOLOV	{"phone": "+70290654943"}
0005432756878	F7F533	8059 601712	DARYA FOMINA	{"email": "fomina-darya1982@postgrespro.ru", "phone": "+70907099363"}
0005432756879	2F18E8	5810 800041	SVETLANA KONDRATEVA	{"email": "s-kondrateva.1969@postgrespro.ru", "phone": "+70895984665"}
0005432756880	0DEC7B	2414 037359	IRINA KUZNECOVA	{"email": "i_kuznecova_01091975@postgrespro.ru", "phone": "+70564215557"}
0005432756881	0DEC7B	3763 203770	NINA KULIKOVA	{"email": "kulikovan011980@postgrespro.ru", "phone": "+70355472581"}
0005432756882	26FD8C	7418 411579	ELENA GAVRILOVA	{"email": "gavrilova-elena1971@postgrespro.ru", "phone": "+70174632531"}
0005432756883	1BE9DA	8486 746920	ROMAN MAKSIMOV	{"phone": "+70375416703"}
0005432756884	BBFE9D	4969 394205	OLGA EGOROVA	{"email": "egorovao-23041972@postgrespro.ru", "phone": "+70186213409"}
0005432756885	BBFE9D	0435 031026	NIKOLAY SAVELEV	{"email": "savelev.nikolay.1980@postgrespro.ru", "phone": "+70055642774"}
0005432756886	A7FA1C	0127 693988	OKSANA GUSEVA	{"email": "guseva.o-061980@postgrespro.ru", "phone": "+70194312074"}
0005432756887	16DCAD	2294 308723	TATYANA STEPANOVA	{"phone": "+70269983048"}
0005432756888	10DA1C	5483 792772	ANDREY KRASNOV	{"email": "andrey.krasnov071974@postgrespro.ru", "phone": "+70409455305"}
0005432756889	10DA1C	7530 497933	SERGEY SOKOLOV	{"email": "sokolovs05111971@postgrespro.ru", "phone": "+70495113034"}
0005432756890	5846A2	7569 625748	PAVEL IVANOV	{"email": "ivanovp041980@postgrespro.ru", "phone": "+70488405753"}
0005432756891	5846A2	1070 469053	YULIYA SOROKINA	{"email": "sorokina.y05051969@postgrespro.ru", "phone": "+70718798485"}
0005432756892	D19B9A	6871 530349	ANATOLIY VASILEV	{"phone": "+70778840400"}
0005432756893	D19B9A	7417 010209	KIRILL IVANOV	{"email": "kirill.ivanov_1963@postgrespro.ru", "phone": "+70789521910"}
0005432756894	9D67B1	4132 781636	VIKTOR MAKAROV	{"email": "v.makarov.071977@postgrespro.ru", "phone": "+70973583250"}
0005432756895	467BBF	5388 912018	LILIYA ZAYCEVA	{"phone": "+70179073185"}
0005432756896	FCB3C1	1686 845094	SERGEY SMIRNOV	{"phone": "+70985650129"}
0005432756897	FCB3C1	4653 959486	TAMARA YAKOVLEVA	{"email": "tamara.yakovleva.1969@postgrespro.ru", "phone": "+70879294556"}
0005432756898	A0EC99	5150 673701	YURIY SMIRNOV	{"phone": "+70001633565"}
0005432756899	A0EC99	2365 770305	NIKOLAY SEMENOV	{"email": "semenov.n21101974@postgrespro.ru", "phone": "+70815850855"}
0005432756900	B622B1	6243 068674	MILENA NOVIKOVA	{"phone": "+70906987516"}
0005432756901	EEFB21	4657 848191	KRISTINA LEBEDEVA	{"email": "lebedeva-kristina-29071967@postgrespro.ru", "phone": "+70915098969"}
0005432756902	4D624C	0001 989070	VERA ORLOVA	{"email": "orlovavera.1961@postgrespro.ru", "phone": "+70552834923"}
0005432756903	F2E558	1972 859820	ANNA ROMANOVA	{"phone": "+70394240923"}
0005432756904	F557D4	2002 697879	RUSLAN SERGEEV	{"phone": "+70365315826"}
0005432756905	F557D4	1345 419358	EKATERINA SOLOVEVA	{"email": "soloveva.ekaterina_27011970@postgrespro.ru", "phone": "+70411171642"}
0005432756906	12C2A0	6295 778286	VLADIMIR ZAYCEV	{"phone": "+70841602549"}
0005432756907	12C2A0	0878 738633	ANATOLIY ZAKHAROV	{"phone": "+70638929839"}
0005432756908	4BBB38	2105 781702	YURIY ROMANOV	{"phone": "+70865600754"}
0005432756909	4BBB38	3396 674023	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev_26021979@postgrespro.ru", "phone": "+70047828617"}
0005432756910	2ED546	9405 056033	GALINA KOZLOVA	{"email": "g_kozlova21041954@postgrespro.ru", "phone": "+70559526209"}
0005432756911	6B7BCE	8034 607505	MARINA KONDRATEVA	{"phone": "+70263703399"}
0005432756912	318D70	6880 360204	MARAT FROLOV	{"email": "frolovmarat_1961@postgrespro.ru", "phone": "+70196014586"}
0005432756913	8D153B	7371 689370	ANDREY STEPANOV	{"email": "stepanov_a.1977@postgrespro.ru", "phone": "+70603831252"}
0005432756914	194744	5919 112875	DAMIR IVANOV	{"email": "ivanov.d-031974@postgrespro.ru", "phone": "+70422349504"}
0005432756915	DDEED5	5427 322646	VALERIY KOROLEV	{"phone": "+70589729753"}
0005432756916	3E2F87	5674 969890	OLEG STEPANOV	{"phone": "+70184548024"}
0005432756917	F46646	0958 835520	PETR SOROKIN	{"phone": "+70329678891"}
0005432756918	25D0F4	9411 320802	ALEKSEY FEDOROV	{"email": "a.fedorov-02111971@postgrespro.ru", "phone": "+70652576721"}
0005432756919	38B6C2	9384 996999	NATALYA KOZLOVA	{"email": "kozlova-natalya.1967@postgrespro.ru", "phone": "+70485241483"}
0005432756920	118FB3	6648 908228	OLGA SAVELEVA	{"email": "saveleva.o_011980@postgrespro.ru", "phone": "+70397853983"}
0005432756921	FDBCB1	3109 211703	YURIY KULIKOV	{"email": "kulikovy_1960@postgrespro.ru", "phone": "+70364276501"}
0005432756922	DA7E16	4522 592866	VLADIMIR BORISOV	{"phone": "+70921710183"}
0005432756923	9CAD52	7526 708487	ALEKSEY KUZNECOV	{"phone": "+70874299065"}
0005432756924	9034CD	3781 077602	IRINA VOLKOVA	{"email": "i_volkova-1972@postgrespro.ru", "phone": "+70178856361"}
0005432756925	9034CD	3079 308673	ANNA ZAYCEVA	{"phone": "+70383672430"}
0005432756926	C7E7B5	5055 297566	NIKOLAY ZHURAVLEV	{"email": "zhuravlev_n.051978@postgrespro.ru", "phone": "+70010038619"}
0005432756928	D3D103	7387 929614	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr.031969@postgrespro.ru", "phone": "+70986774612"}
0005432756929	B093D9	1898 490940	ANDREY ILIN	{"email": "andrey_ilin_1969@postgrespro.ru", "phone": "+70276802180"}
0005432756930	B093D9	9210 558823	OLEG IVANOV	{"phone": "+70220698201"}
0005432756931	B093D9	1073 193644	ALEKSANDR ZAKHAROV	{"phone": "+70512920480"}
0005432756932	E4CAEA	4091 987856	ELENA LUKYANOVA	{"email": "elenalukyanova.1979@postgrespro.ru", "phone": "+70381795357"}
0005432756933	E4CAEA	3104 135224	ELIZAVETA BARANOVA	{"email": "baranovaelizaveta.01091970@postgrespro.ru", "phone": "+70214791949"}
0005432756934	2B7F2D	9226 643214	GALINA MOROZOVA	{"email": "morozova.galina121966@postgrespro.ru", "phone": "+70230064242"}
0005432756935	A4AED1	9560 250485	RAUZA NIKOLAEVA	{"email": "nikolaeva.rauza_28061965@postgrespro.ru", "phone": "+70803131511"}
0005432756936	FD68BB	4163 837167	VYACHESLAV KOZLOV	{"phone": "+70842200299"}
0005432756937	B057CF	2599 373571	ALEKSANDR BORISOV	{"phone": "+70047546095"}
0005432756938	B057CF	4170 232329	ALSU GORBUNOVA	{"email": "alsu.gorbunova-111966@postgrespro.ru", "phone": "+70526415675"}
0005432756939	2A7312	5103 175368	NATALYA LUKYANOVA	{"phone": "+70272956561"}
0005432756940	A9920C	7752 828829	NADEZHDA SOKOLOVA	{"phone": "+70755052116"}
0005432756941	A9920C	3741 899911	GALINA SOROKINA	{"phone": "+70272475143"}
0005432756942	834FD7	4136 673250	VALENTINA POLYAKOVA	{"email": "v-polyakova.031964@postgrespro.ru", "phone": "+70160419336"}
0005432782838	D5CEF2	1873 248489	IVAN POPOV	{"phone": "+70362231621"}
0005432782839	5AB856	7171 300889	EGOR TARASOV	{"phone": "+70408805218"}
0005432782840	6CEFA5	6697 918256	ANTON FOMIN	{"phone": "+70182484146"}
0005432782841	FF9B3F	9613 801830	ANDREY ANDREEV	{"email": "andreev.andrey_021967@postgrespro.ru", "phone": "+70619481677"}
0005432782842	3A8F1D	2468 096702	MIKHAIL SHEVCHENKO	{"phone": "+70292130396"}
0005432782843	0127E1	5097 173158	DANIIL SAVELEV	{"email": "savelev_daniil_1967@postgrespro.ru", "phone": "+70457892616"}
0005432782844	A1567B	2527 479723	SERGEY OSIPOV	{"email": "sosipov_1966@postgrespro.ru", "phone": "+70556185229"}
0005432782845	139C0D	9743 852803	TAMARA NESTEROVA	{"phone": "+70347459002"}
0005432782846	B32091	2854 806047	NIKOLAY KRASNOV	{"phone": "+70291863222"}
0005432782847	A66F88	6134 050474	ALEKSANDR VASILEV	{"email": "vasilevaleksandr_16111973@postgrespro.ru", "phone": "+70753445948"}
0005432782848	6619AD	4282 522774	VALERIY VOROBEV	{"phone": "+70236692461"}
0005432782849	6619AD	5117 289699	VLADISLAV ISAEV	{"email": "isaev-v_12061974@postgrespro.ru", "phone": "+70679299446"}
0005432782850	DE2D7C	6171 130456	NADEZHDA LOGINOVA	{"phone": "+70201110486"}
0005432782851	DE2D7C	1091 464657	TAMARA MAKAROVA	{"email": "makarova_tamara1981@postgrespro.ru", "phone": "+70627777082"}
0005432782852	59F100	1872 807338	IRINA IVANOVA	{"phone": "+70697143300"}
0005432782853	92044B	0737 255572	SVETLANA ILINA	{"phone": "+70475760400"}
0005432782854	92044B	9418 036794	NIKOLAY BARANOV	{"email": "n_baranov22071958@postgrespro.ru", "phone": "+70741099274"}
0005432782855	5097C0	5433 796863	SOFYA SCHERBAKOVA	{"phone": "+70604093831"}
0005432782856	5097C0	2797 817318	MAKSIM NIKITIN	{"email": "nikitin-m1967@postgrespro.ru", "phone": "+70733175655"}
0005432782857	152F28	6196 699894	LYUDMILA NAZAROVA	{"phone": "+70448293073"}
0005432782858	5AF572	2935 037557	LILIYA ZHURAVLEVA	{"phone": "+70507947957"}
0005432782859	5AF572	2663 604061	EVGENIY SERGEEV	{"email": "evgeniy.sergeev.1973@postgrespro.ru", "phone": "+70346394123"}
0005432782860	9C222A	1904 230475	MIKHAIL SCHERBAKOV	{"phone": "+70996850898"}
0005432782861	118E56	1400 154852	YANINA SOKOLOVA	{"phone": "+70595913702"}
0005432782862	118E56	6171 766621	ALENA SOKOLOVA	{"phone": "+70722075694"}
0005432782863	928C0F	8811 710325	VALENTINA FROLOVA	{"phone": "+70778894981"}
0005432782864	66FF0F	6135 299173	GALINA TIKHONOVA	{"phone": "+70683426671"}
0005432782865	66FF0F	0709 974767	EVGENIY ZHURAVLEV	{"phone": "+70967319663"}
0005432782866	1B2AE5	7585 190898	IVAN MAKAROV	{"email": "i.makarov_1977@postgrespro.ru", "phone": "+70301975223"}
0005432782867	1B2AE5	8593 501249	KSENIYA MIRONOVA	{"phone": "+70557585300"}
0005432782868	4246F0	7291 430685	EKATERINA GERASIMOVA	{"phone": "+70560618965"}
0005432782869	A10242	1259 162685	SERGEY FEDOROV	{"email": "fedorov.s_10021976@postgrespro.ru", "phone": "+70059966058"}
0005432782870	A10242	7039 581534	VLADIMIR STEPANOV	{"email": "v_stepanov031965@postgrespro.ru", "phone": "+70138322858"}
0005432782871	8D093F	5253 057558	YULIYA KOROLEVA	{"email": "koroleva-yuliya-041973@postgrespro.ru", "phone": "+70495058378"}
0005432782872	80BFBE	7018 254412	TATYANA POLYAKOVA	{"email": "tatyana-polyakova.091974@postgrespro.ru", "phone": "+70946515940"}
0005432782873	62B0C2	0676 566091	EVGENIY SERGEEV	{"email": "evgeniysergeev1973@postgrespro.ru", "phone": "+70040436078"}
0005432782874	C9F5B6	5234 075812	RUSLAN ABRAMOV	{"email": "r_abramov-1974@postgrespro.ru", "phone": "+70418152148"}
0005432782875	0D8D08	8066 218607	OLGA SOLOVEVA	{"phone": "+70118907305"}
0005432782876	0D8D08	6628 888494	ANNA FOMINA	{"phone": "+70125155070"}
0005432782877	DF51EE	8510 183515	NINA VOROBEVA	{"phone": "+70106057150"}
0005432782878	499547	1584 374544	NADEZHDA ZHUKOVA	{"phone": "+70565654149"}
0005432782879	A99B63	8400 559912	ELENA PETROVA	{"phone": "+70255517154"}
0005432782880	A99B63	9960 923624	ZINAIDA FROLOVA	{"phone": "+70356155974"}
0005432782881	9A0999	5903 118045	STANISLAV FOMIN	{"phone": "+70873373417"}
0005432782882	9A0999	1616 457620	MARAT MAKAROV	{"phone": "+70510607454"}
0005432782883	C0341C	3705 215335	ELIZAVETA ILINA	{"phone": "+70031689003"}
0005432782884	D61009	1711 457374	OLGA RYABOVA	{"phone": "+70754421113"}
0005432782885	18A8D7	2879 636592	GRIGORIY AFANASEV	{"phone": "+70382419284"}
0005432782886	4F8918	3049 351593	SERGEY BARANOV	{"email": "baranov_s.27031979@postgrespro.ru", "phone": "+70021965081"}
0005432782887	EEA612	9706 322770	RUSLAN POPOV	{"email": "popov-ruslan.111967@postgrespro.ru", "phone": "+70391347315"}
0005432782888	F8E9BF	8854 794792	MAYA ROMANOVA	{"phone": "+70480315182"}
0005432782889	F8E9BF	5282 659764	NINA NIKOLAEVA	{"phone": "+70676266260"}
0005432782890	3B7399	0856 549296	ANATOLIY DAVYDOV	{"email": "a_davydov_18041966@postgrespro.ru", "phone": "+70096019102"}
0005432782891	E8ACB4	3954 264121	VIKTOR BONDARENKO	{"email": "v_bondarenko.051976@postgrespro.ru", "phone": "+70112737485"}
0005432782892	E8ACB4	1854 119215	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr.1976@postgrespro.ru", "phone": "+70030763180"}
0005432782893	1DBE9B	6545 211829	VLADIMIR TARASOV	{"phone": "+70818556761"}
0005432782894	13510D	3458 318944	VALENTINA BOGDANOVA	{"phone": "+70668727912"}
0005432782895	13510D	6061 401931	LYUDMILA VOROBEVA	{"phone": "+70028785320"}
0005432782896	50C987	1311 614108	SERGEY POPOV	{"email": "s-popov_011978@postgrespro.ru", "phone": "+70494991048"}
0005432782897	50C987	1154 481502	ANATOLIY KUDRYASHOV	{"email": "kudryashovanatoliy_06091978@postgrespro.ru", "phone": "+70003229544"}
0005432782898	C89CF9	9152 058297	VERA KAZAKOVA	{"email": "vera-kazakova-1969@postgrespro.ru", "phone": "+70927883206"}
0005432782899	CC19A2	7125 527837	ARINA GUSEVA	{"phone": "+70410835942"}
0005432782900	A86E01	7086 980756	LYUBOV KUDRYASHOVA	{"email": "kudryashovalyubov-1969@postgrespro.ru", "phone": "+70970113029"}
0005432782901	A86E01	3196 334050	ANDREY KULIKOV	{"email": "andrey-kulikov_1969@postgrespro.ru", "phone": "+70929904529"}
0005432782902	AA1BA6	3839 149544	NATALYA KISELEVA	{"phone": "+70447538760"}
0005432782903	17A551	1646 190310	VLADIMIR KULIKOV	{"phone": "+70602789655"}
0005432782904	DED8F2	1930 055503	VLADIMIR NAZAROV	{"email": "v_nazarov-18091976@postgrespro.ru", "phone": "+70905126159"}
0005432782905	DA94EB	6357 680422	SVETLANA KOROLEVA	{"phone": "+70033969846"}
0005432782906	4506ED	4018 038605	LIDIYA SOKOLOVA	{"email": "lsokolova-05101969@postgrespro.ru", "phone": "+70591553333"}
0005432782907	D01D80	7774 228444	IRINA MOROZOVA	{"email": "imorozova_101984@postgrespro.ru", "phone": "+70830432235"}
0005432782908	FD6069	8571 397408	MARINA NIKOLAEVA	{"email": "m-nikolaeva-061973@postgrespro.ru", "phone": "+70337442847"}
0005432782909	35BB1D	9826 356193	IVAN KUZNECOV	{"email": "ivan_kuznecov09011971@postgrespro.ru", "phone": "+70572628785"}
0005432782910	5628DA	1213 463270	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr_1976@postgrespro.ru", "phone": "+70602802827"}
0005432782911	B26051	2898 519577	MIKHAIL FEDOTOV	{"phone": "+70530144388"}
0005432782912	57E8EA	5067 533390	IRINA OSIPOVA	{"phone": "+70744476510"}
0005432782913	57E8EA	1548 545144	SAMIR NIKITIN	{"phone": "+70357854359"}
0005432782914	57E8EA	5917 985606	LEONID ROMANOV	{"phone": "+70696288723"}
0005432782915	57E8EA	4262 288765	NATALYA MAKAROVA	{"email": "natalya-makarova1962@postgrespro.ru", "phone": "+70893085776"}
0005432782916	56A9AD	9100 578235	STEPAN PAVLOV	{"phone": "+70007252771"}
0005432782917	F7FB71	2795 620988	SVETLANA KOVALEVA	{"email": "skovaleva-1974@postgrespro.ru", "phone": "+70170170395"}
0005432782918	57F499	6564 940943	VIKTOR FILIPPOV	{"email": "filippov_viktor_1989@postgrespro.ru", "phone": "+70085007402"}
0005432782919	8D0134	6277 102005	VALENTIN NIKITIN	{"phone": "+70822836041"}
0005432782920	5D8FDB	0374 993338	LYUDMILA VASILEVA	{"phone": "+70228938495"}
0005432782921	1B87DD	9578 751832	SHAMIL MARTYNOV	{"email": "martynov_shamil-12071978@postgrespro.ru", "phone": "+70465015127"}
0005432782922	B731F0	3668 174533	RAMIL ORLOV	{"phone": "+70754944018"}
0005432782923	802990	6749 484628	YULIYA MIKHAYLOVA	{"email": "mikhaylovayuliya051975@postgrespro.ru", "phone": "+70462858447"}
0005432782924	802990	3398 171308	ANNA ORLOVA	{"email": "orlovaa_1971@postgrespro.ru", "phone": "+70073770790"}
0005432782925	6ED027	5243 378531	YANA SOLOVEVA	{"email": "soloveva_y-031971@postgrespro.ru", "phone": "+70705679573"}
0005432782926	6ED027	6540 121279	EKATERINA ISAEVA	{"email": "isaevaekaterina.1976@postgrespro.ru", "phone": "+70785825070"}
0005432782927	6ED027	4630 485804	VADIM PETROV	{"email": "vadim_petrov-17011962@postgrespro.ru", "phone": "+70968292200"}
0005432782928	154307	5122 231940	OLGA POPOVA	{"phone": "+70576512916"}
0005432782929	E0D321	9027 309121	ANDREY ZHUKOV	{"phone": "+70586282188"}
0005432782930	E0D321	5217 553674	DENIS NIKOLAEV	{"phone": "+70797766678"}
0005432782931	D8DDBC	9215 201333	MIKHAIL BORISOV	{"phone": "+70182277296"}
0005432782932	770544	0089 121672	VALENTIN KISELEV	{"email": "kiselev-valentin1969@postgrespro.ru", "phone": "+70858617394"}
0005432782933	770544	1906 800835	VALENTINA YUDINA	{"phone": "+70845273215"}
0005432782934	0AEC8F	5590 216799	EKATERINA BORISOVA	{"email": "borisovae.12071979@postgrespro.ru", "phone": "+70357060927"}
0005432782935	90C8B2	2803 937605	SERGEY DENISOV	{"phone": "+70419132024"}
0005432782936	008822	5633 536625	VLADIMIR KUDRYASHOV	{"phone": "+70314544097"}
0005432782937	6D2567	7825 052046	NATALYA AKIMOVA	{"email": "natalya.akimova_031968@postgrespro.ru", "phone": "+70187615662"}
0005432782938	043481	4771 701315	GALINA NESTEROVA	{"phone": "+70738750858"}
0005432782939	715647	7560 401871	NAILYA SIDOROVA	{"email": "sidorovanailya_081973@postgrespro.ru", "phone": "+70242889346"}
0005432782940	F03384	6981 188840	NIKOLAY ALEKSANDROV	{"email": "nikolay.aleksandrov.1960@postgrespro.ru", "phone": "+70006935623"}
0005432782941	F03384	9236 572970	SVETLANA NAZAROVA	{"phone": "+70484663970"}
0005432782942	79BF04	9947 737088	PETR MELNIKOV	{"email": "pmelnikov_1970@postgrespro.ru", "phone": "+70777575027"}
0005432782943	A9F025	8137 939414	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey-1975@postgrespro.ru", "phone": "+70748397275"}
0005432782944	A9F025	6805 888237	TAMARA POPOVA	{"email": "popova_tamara-101972@postgrespro.ru", "phone": "+70890666299"}
0005432782945	7047E5	3208 424413	INNA DAVYDOVA	{"email": "i.davydova.1974@postgrespro.ru", "phone": "+70618299973"}
0005432782946	1B38FC	5757 393925	DMITRIY SOROKIN	{"phone": "+70714967350"}
0005432782947	1B38FC	5388 144474	ELENA MOROZOVA	{"email": "elena.morozova.1971@postgrespro.ru", "phone": "+70074110961"}
0005432782948	1B38FC	3211 748941	PAVEL RODIONOV	{"phone": "+70954665072"}
0005432782949	BBE912	7137 107602	ALEKSANDR KOZLOV	{"email": "kozlov_a-091969@postgrespro.ru", "phone": "+70362958483"}
0005432782950	BBE912	3188 318171	NADEZHDA NIKIFOROVA	{"email": "n-nikiforova_1967@postgrespro.ru", "phone": "+70213875925"}
0005432782951	BBE912	6689 374855	IVAN DAVYDOV	{"email": "ivandavydov.1971@postgrespro.ru", "phone": "+70667764771"}
0005432782952	98D337	7412 001884	YANA GORBUNOVA	{"phone": "+70654153756"}
0005432782953	98D337	0683 850585	OLGA SERGEEVA	{"email": "o_sergeeva-08061969@postgrespro.ru", "phone": "+70477259673"}
0005432782954	42B499	6603 196726	YULIYA FILIPPOVA	{"email": "yfilippova.14041972@postgrespro.ru", "phone": "+70924407965"}
0005432782955	24CA5B	7816 674270	NIKITA SCHERBAKOV	{"email": "scherbakov_n091972@postgrespro.ru", "phone": "+70606867634"}
0005432782956	5E34F6	7009 503138	GALINA ZAKHAROVA	{"email": "gzakharova08061981@postgrespro.ru", "phone": "+70557074942"}
0005432782957	5D7E83	3057 146851	ANDREY KOZLOV	{"email": "andrey-kozlov-24071984@postgrespro.ru", "phone": "+70087438340"}
0005432782958	600631	3561 685771	NINA MIKHAYLOVA	{"phone": "+70980027402"}
0005432782959	FB461C	8597 580915	GALINA SMIRNOVA	{"email": "galina_smirnova_14061977@postgrespro.ru", "phone": "+70024194916"}
0005432782960	E2756A	1713 240264	MATVEY VOLKOV	{"email": "volkov-m.22111968@postgrespro.ru", "phone": "+70591995133"}
0005432782961	E2756A	4515 525017	OLGA VASILEVA	{"phone": "+70537181476"}
0005432782962	3E4E5C	9561 389530	TATYANA NIKITINA	{"email": "t.nikitina22041977@postgrespro.ru", "phone": "+70825191335"}
0005432782963	D964E9	5428 413645	SERGEY MOROZOV	{"email": "morozov-s051980@postgrespro.ru", "phone": "+70309474405"}
0005432782964	B4D776	4469 365041	NIKITA KUZNECOV	{"phone": "+70400279005"}
0005432782965	A71DEC	9072 437751	NATALYA MAKAROVA	{"email": "makarova.natalya-031982@postgrespro.ru", "phone": "+70617775562"}
0005432782966	A71DEC	4167 299832	ELENA KRASNOVA	{"phone": "+70567797676"}
0005432783022	76A99E	9681 674075	DARYA KISELEVA	{"phone": "+70779654547"}
0005432782967	FBA237	9078 886626	DMITRIY KUDRYASHOV	{"email": "dkudryashov111968@postgrespro.ru", "phone": "+70444097076"}
0005432782968	FBA237	0762 746444	SERGEY BORISOV	{"email": "sergey_borisov.021984@postgrespro.ru", "phone": "+70446232997"}
0005432782969	D06CF4	0750 551428	SERGEY BORISOV	{"phone": "+70643295224"}
0005432782970	AE35A1	9633 503650	NIKOLAY ANDREEV	{"email": "n_andreev_1969@postgrespro.ru", "phone": "+70626361383"}
0005432782971	F2A0A5	3653 323647	MARINA ABRAMOVA	{"phone": "+70683843516"}
0005432782972	E4EE9A	8883 318805	SERGEY GERASIMOV	{"phone": "+70586538767"}
0005432782973	E4EE9A	6040 428835	SHAVKAT POPOV	{"email": "shavkat-popov_1977@postgrespro.ru", "phone": "+70731071590"}
0005432782974	E4EE9A	5579 070912	VLADIMIR NAZAROV	{"email": "vnazarov.09121966@postgrespro.ru", "phone": "+70553950035"}
0005432782975	E4EE9A	2867 766586	ELENA NESTEROVA	{"phone": "+70166517613"}
0005432782976	E4EE9A	5923 420006	ALEKSANDR EGOROV	{"email": "egorovaleksandr.1966@postgrespro.ru", "phone": "+70965078877"}
0005432782977	F871DE	0331 949697	OLESYA SMIRNOVA	{"phone": "+70187617316"}
0005432782978	0779BE	9544 934280	ANATOLIY IVANOV	{"email": "anatoliy.ivanov19041980@postgrespro.ru", "phone": "+70421866063"}
0005432782979	0779BE	0510 696783	ILGIZ CHERNOV	{"email": "chernovi1967@postgrespro.ru", "phone": "+70672022254"}
0005432782980	0779BE	5502 210815	ANASTASIYA KOROLEVA	{"email": "anastasiyakoroleva28021979@postgrespro.ru", "phone": "+70258462742"}
0005432782981	3EC233	2689 565965	NATALYA MALYSHEVA	{"phone": "+70514900507"}
0005432782982	0C880F	1628 166054	IRINA LAZAREVA	{"phone": "+70895713129"}
0005432782983	8007FA	2185 393049	FEDOR FROLOV	{"phone": "+70614059357"}
0005432782984	C58199	5975 891900	ROMAN ZHUKOV	{"phone": "+70627018171"}
0005432782985	88527F	6993 987892	SERGEY ZHURAVLEV	{"email": "s_zhuravlev061975@postgrespro.ru", "phone": "+70827474036"}
0005432782986	7876DE	8327 054726	ROMAN ALEKSEEV	{"email": "r_alekseev_1972@postgrespro.ru", "phone": "+70493438184"}
0005432782987	345BFB	9206 870109	ALINA BOGDANOVA	{"phone": "+70179565464"}
0005432782988	345BFB	3265 773986	ALISA LUKYANOVA	{"email": "alisa_lukyanova-041975@postgrespro.ru", "phone": "+70230469225"}
0005432782989	5C3E24	0654 580134	OLGA KUZNECOVA	{"email": "kuznecova-olga_101971@postgrespro.ru", "phone": "+70408900266"}
0005432782990	515486	5891 067406	GALINA NIKOLAEVA	{"email": "nikolaevag-28041975@postgrespro.ru", "phone": "+70529703014"}
0005432782991	15DDE9	8147 743498	NIKITA GRIGOREV	{"email": "n.grigorev_1964@postgrespro.ru", "phone": "+70682747537"}
0005432782992	15DDE9	7691 150532	ANTON EGOROV	{"phone": "+70566854207"}
0005432782993	C1AFF0	9171 158416	DARYA BELYAEVA	{"email": "d_belyaeva-1974@postgrespro.ru", "phone": "+70365270201"}
0005432782994	0FDFAC	0876 171128	LYUDMILA POPOVA	{"email": "lpopova1970@postgrespro.ru", "phone": "+70422592458"}
0005432782995	AC9B07	8441 236029	TAMARA GAVRILOVA	{"email": "gavrilova-t.071980@postgrespro.ru", "phone": "+70316469298"}
0005432782996	35EA61	7295 656703	YURIY MELNIKOV	{"phone": "+70569151392"}
0005432782997	6DCBFC	4024 581379	SVETLANA FILATOVA	{"email": "s_filatova_1953@postgrespro.ru", "phone": "+70269313083"}
0005432782998	6DCBFC	4341 137827	VIKTOR MAKAROV	{"phone": "+70229673194"}
0005432782999	3310C1	7446 230702	DMITRIY SOLOVEV	{"email": "d_solovev.28051967@postgrespro.ru", "phone": "+70108328354"}
0005432783000	3310C1	5149 771032	VALENTIN GORBUNOV	{"email": "gorbunov.v1963@postgrespro.ru", "phone": "+70037075064"}
0005432783001	E1E2D2	3718 143197	SVETLANA BELOVA	{"email": "svetlana_belova-28021967@postgrespro.ru", "phone": "+70398273636"}
0005432783002	E1E2D2	0689 959263	ELENA KOROLEVA	{"phone": "+70449496614"}
0005432783003	445C08	0584 201604	MIKHAIL MEDVEDEV	{"email": "m_medvedev11011969@postgrespro.ru", "phone": "+70843139102"}
0005432783004	445C08	8372 465697	DMITRIY MIKHAYLOV	{"email": "mikhaylovdmitriy_14101972@postgrespro.ru", "phone": "+70309822437"}
0005432783005	AA7D71	3000 420424	TAMARA IVANOVA	{"phone": "+70361240699"}
0005432783006	AA7D71	4254 231612	ILYA IVANOV	{"email": "i.ivanov1974@postgrespro.ru", "phone": "+70661082492"}
0005432783007	685751	2770 841754	NATALYA IVANOVA	{"phone": "+70859929861"}
0005432783008	52B31D	6647 780431	ALEKSEY MELNIKOV	{"phone": "+70796526208"}
0005432783009	1FDB65	0654 098039	YURIY KISELEV	{"phone": "+70091886495"}
0005432783010	1FDB65	7906 492274	NADEZHDA SEMENOVA	{"email": "n_semenova-031975@postgrespro.ru", "phone": "+70212825846"}
0005432783011	1FDB65	6673 917611	MARIYA NESTEROVA	{"email": "nesterova.m-121968@postgrespro.ru", "phone": "+70701479459"}
0005432783012	47E749	5606 929366	PETR KARPOV	{"phone": "+70809403871"}
0005432783013	07465F	3401 216078	ANGELINA KUZNECOVA	{"email": "angelinakuznecova-1976@postgrespro.ru", "phone": "+70723472079"}
0005432783014	2553EF	5313 435163	NIKOLAY SMIRNOV	{"phone": "+70910214293"}
0005432783015	2553EF	3651 204614	NATALIYA BOGDANOVA	{"email": "n.bogdanova1978@postgrespro.ru", "phone": "+70196144481"}
0005432783016	350FCB	3849 710272	ALEVTINA SAVELEVA	{"email": "alevtina.saveleva-1973@postgrespro.ru", "phone": "+70893981069"}
0005432783017	8997DB	7737 657833	NINA CHERNOVA	{"email": "chernova_n23101966@postgrespro.ru", "phone": "+70968330176"}
0005432783018	67E558	5037 204765	PAVEL EGOROV	{"phone": "+70136614816"}
0005432783019	FFD8C8	9253 867945	EVGENIYA SIDOROVA	{"email": "sidorova-evgeniya20011976@postgrespro.ru", "phone": "+70514832563"}
0005432783020	11017B	7103 599448	SVETLANA NIKOLAEVA	{"email": "svetlananikolaeva-011978@postgrespro.ru", "phone": "+70866249047"}
0005432783021	6E7299	8025 714273	MARIYA GAVRILOVA	{"email": "gavrilova-mariya-071968@postgrespro.ru", "phone": "+70781199848"}
0005432783023	3393BF	1311 930562	IRINA NAZAROVA	{"email": "irina-nazarova_021977@postgrespro.ru", "phone": "+70618815451"}
0005432783024	312B0A	8922 628024	ALBINA VOROBEVA	{"email": "vorobeva.albina.23061977@postgrespro.ru", "phone": "+70485158816"}
0005432783025	47660B	4618 967462	SVETLANA ZAYCEVA	{"phone": "+70832939463"}
0005432783026	20C10C	5217 469035	VIKTOR BELOV	{"email": "viktor.belov061973@postgrespro.ru", "phone": "+70441105792"}
0005432783027	38E9BF	0929 801976	ULYANA TIKHONOVA	{"phone": "+70223644744"}
0005432783028	2A97B6	9131 844587	GALINA GUSEVA	{"phone": "+70385689545"}
0005432783029	2A97B6	3702 128453	NADEZHDA PETROVA	{"phone": "+70060090649"}
0005432783030	2A97B6	4398 605043	TATYANA FEDOROVA	{"email": "tatyana.fedorova_1969@postgrespro.ru", "phone": "+70400778722"}
0005432783031	980128	2416 642996	IRINA NIKIFOROVA	{"email": "inikiforova_041973@postgrespro.ru", "phone": "+70371407351"}
0005432783032	8567F7	1515 335178	MARIYA OVCHINNIKOVA	{"phone": "+70890126983"}
0005432783033	8567F7	1516 555789	SVETLANA LUKYANOVA	{"email": "svetlana-lukyanova.101959@postgrespro.ru", "phone": "+70553373912"}
0005432783034	B74C70	2764 480123	VLADISLAV TARASOV	{"phone": "+70462501855"}
0005432783035	E487AA	0399 047800	IRINA MIRONOVA	{"phone": "+70717891979"}
0005432783036	E487AA	8889 132871	ANNA NESTEROVA	{"phone": "+70550924348"}
0005432783037	961A5C	6473 156446	IRAIDA KULIKOVA	{"phone": "+70875058620"}
0005432783038	961A5C	8253 148655	LYUDMILA VOLKOVA	{"phone": "+70206126733"}
0005432783039	ED9FA9	9697 198466	RAMIL ZAKHAROV	{"email": "r_zakharov_1970@postgrespro.ru", "phone": "+70829378942"}
0005432783040	BFB7B0	3509 920406	NIKOLAY GORBUNOV	{"phone": "+70507314450"}
0005432783041	9CA3FD	5546 856272	ALEKSANDR GUSEV	{"email": "gusevaleksandr03041978@postgrespro.ru", "phone": "+70128226893"}
0005432783042	5237DA	3740 886324	GRIGORIY SHEVCHENKO	{"phone": "+70157441641"}
0005432783043	4AE908	4367 344192	MARIANNA MATVEEVA	{"phone": "+70421374600"}
0005432783044	C933BF	0054 595074	VASILIY ILIN	{"email": "v_ilin-011977@postgrespro.ru", "phone": "+70786599036"}
0005432783045	C933BF	7532 194665	VALENTINA MOROZOVA	{"email": "morozova-v.081969@postgrespro.ru", "phone": "+70888635654"}
0005432783046	043C72	2766 294526	IVAN SMIRNOV	{"email": "smirnov_ivan-24081967@postgrespro.ru", "phone": "+70274357296"}
0005432783047	043C72	3554 163719	ALEKSANDR SOKOLOV	{"phone": "+70417744193"}
0005432783048	D369C2	9324 558913	PAVEL SOLOVEV	{"email": "solovev.p_1979@postgrespro.ru", "phone": "+70943860935"}
0005432783049	B21F08	8436 240158	MAKSIM ORLOV	{"email": "morlov-061979@postgrespro.ru", "phone": "+70577401103"}
0005432783050	B21F08	0050 837679	ALEKSANDR FEDOROV	{"phone": "+70909179064"}
0005432783051	06611F	0314 429963	ARINA FOMINA	{"email": "a_fomina.14041965@postgrespro.ru", "phone": "+70436450252"}
0005432783052	B61796	9551 320775	VALENTIN KUZNECOV	{"email": "v.kuznecov.22121971@postgrespro.ru", "phone": "+70480283514"}
0005432783053	95710C	2252 236792	IRINA MIRONOVA	{"email": "irina_mironova_26071976@postgrespro.ru", "phone": "+70266838562"}
0005432783054	95710C	6317 769686	VALENTIN NIKITIN	{"email": "nikitin.v121974@postgrespro.ru", "phone": "+70815927892"}
0005432783055	DCEC25	4533 492709	VALERIY KISELEV	{"phone": "+70566071042"}
0005432783056	DD51CF	2048 549783	GLEB TARASOV	{"phone": "+70956469007"}
0005432783057	FE5DC6	8091 897017	LYUBOV POPOVA	{"phone": "+70955675864"}
0005432783058	2B34C1	5597 821317	NATALYA MELNIKOVA	{"email": "melnikova_natalya.051972@postgrespro.ru", "phone": "+70509938687"}
0005432783059	925A49	1765 788106	ANNA SERGEEVA	{"email": "a_sergeeva-07121969@postgrespro.ru", "phone": "+70639290429"}
0005432783060	930887	8860 875533	IGOR PETROV	{"email": "igor-petrov1984@postgrespro.ru", "phone": "+70318306637"}
0005432783061	1AA5D6	6959 950817	LILIYA ANDREEVA	{"phone": "+70777603573"}
0005432783062	A66E14	0419 670733	OLGA KUZNECOVA	{"email": "okuznecova1971@postgrespro.ru", "phone": "+70921665469"}
0005432783063	A66E14	5228 379530	VYACHESLAV ABRAMOV	{"phone": "+70262408176"}
0005432783064	6B6453	1493 957931	TATYANA ZOTOVA	{"phone": "+70679774073"}
0005432783065	2F80F1	7862 144471	ANNA NIKOLAEVA	{"phone": "+70893990988"}
0005432783066	74F039	8068 212193	SERGEY KUZMIN	{"phone": "+70220167064"}
0005432783067	163DE4	0207 507148	NADEZHDA KONDRATEVA	{"email": "nadezhda-kondrateva031979@postgrespro.ru", "phone": "+70363158843"}
0005432783068	893F2C	5117 969140	ILYAS FOMIN	{"phone": "+70035084763"}
0005432783069	893F2C	5973 780131	RAUZA TIKHONOVA	{"phone": "+70504808252"}
0005432783070	FFA737	2357 502752	GALINA SERGEEVA	{"phone": "+70091508747"}
0005432783071	CDF990	8389 285291	OLEG ILIN	{"phone": "+70773610189"}
0005432783072	E69620	9647 530860	DMITRIY CHERNOV	{"email": "dchernov_1969@postgrespro.ru", "phone": "+70931078493"}
0005432783073	D63B62	7717 326530	KAMIL IVANOV	{"email": "k.ivanov.1983@postgrespro.ru", "phone": "+70963521614"}
0005432783074	163FE7	0318 982680	NIKOLAY IVANOV	{"phone": "+70867968882"}
0005432783075	E86580	9341 941152	NIKOLAY POPOV	{"email": "popovnikolay.031965@postgrespro.ru", "phone": "+70942871531"}
0005432783076	E86580	9866 317124	ANASTASIYA VASILEVA	{"phone": "+70335342208"}
0005432783077	FCD3E2	2110 976797	YULIYA ISAEVA	{"email": "isaeva-y_011977@postgrespro.ru", "phone": "+70036746366"}
0005432783078	327C4A	7191 415383	ANTON ANDREEV	{"email": "aandreev-19061976@postgrespro.ru", "phone": "+70096949048"}
0005432783079	264746	5150 621296	ANNA ZAKHAROVA	{"phone": "+70415470604"}
0005432783080	264746	9470 441242	TATYANA AKIMOVA	{"email": "tatyanaakimova-071977@postgrespro.ru", "phone": "+70676912596"}
0005432783081	4B6FF9	2687 458247	PAVEL PAVLOV	{"email": "p-pavlov-27071970@postgrespro.ru", "phone": "+70326951805"}
0005432783082	4B6FF9	7068 648843	YURIY MARTYNOV	{"email": "martynov_yuriy.1985@postgrespro.ru", "phone": "+70701644028"}
0005432783083	4B6FF9	5001 911881	NIKOLAY PAVLOV	{"phone": "+70649806052"}
0005432783084	4B6FF9	7121 405674	NINA MIKHAYLOVA	{"phone": "+70797378868"}
0005432783085	DA53D1	0847 144179	NADEZHDA SMIRNOVA	{"email": "smirnova-nadezhda12111962@postgrespro.ru", "phone": "+70999934261"}
0005432783086	DA53D1	0996 860602	LIDIYA MIKHAYLOVA	{"email": "lidiya-mikhaylova03011970@postgrespro.ru", "phone": "+70216268500"}
0005432783087	7E2196	6030 827672	ALEKSEY BELOV	{"email": "belova-16091973@postgrespro.ru", "phone": "+70727782825"}
0005432783088	F61078	3538 828045	ANDREY KOZLOV	{"email": "andrey-kozlov-14061968@postgrespro.ru", "phone": "+70993964625"}
0005432783089	5B4E59	4009 056348	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.1975@postgrespro.ru", "phone": "+70828321424"}
0005432783090	B1985C	5233 328224	VALENTINA FILATOVA	{"email": "v-filatova1972@postgrespro.ru", "phone": "+70977272162"}
0005432783091	B1985C	1078 837020	KLARA ISAEVA	{"phone": "+70438437129"}
0005432783092	B1985C	8020 933973	ELENA ZHURAVLEVA	{"email": "elena-zhuravleva.1977@postgrespro.ru", "phone": "+70740493828"}
0005432783093	07A989	1772 914429	MARIYA GRISHINA	{"phone": "+70630815782"}
0005432783094	07A989	6043 714334	ELENA KUZMINA	{"email": "elenakuzmina-04011966@postgrespro.ru", "phone": "+70483886765"}
0005432783095	B849F2	1003 717551	SVETLANA TITOVA	{"email": "s_titova1962@postgrespro.ru", "phone": "+70543228559"}
0005432783096	B849F2	6835 240689	LYUDMILA KOLESNIKOVA	{"phone": "+70172272145"}
0005432783097	B849F2	8480 974654	MARK ANTONOV	{"email": "antonov_m1973@postgrespro.ru", "phone": "+70593630559"}
0005432783098	21AEBC	4097 177727	DMITRIY ZAKHAROV	{"email": "zakharov-d-1978@postgrespro.ru", "phone": "+70016786290"}
0005432783099	21AEBC	4115 210069	NADEZHDA MAKSIMOVA	{"email": "maksimova_nadezhda-12061966@postgrespro.ru", "phone": "+70977973224"}
0005432783100	13EA5B	4505 594159	OLEG MEDVEDEV	{"email": "omedvedev.121979@postgrespro.ru", "phone": "+70604430121"}
0005432783101	13EA5B	4814 620412	EKATERINA ISAEVA	{"email": "isaevaekaterina.021976@postgrespro.ru", "phone": "+70219153011"}
0005432783102	996F9A	7536 122430	VLADIMIR KRASNOV	{"email": "v-krasnov_011975@postgrespro.ru", "phone": "+70673774353"}
0005432783103	996F9A	4659 343868	ALEKSANDR NOVIKOV	{"phone": "+70862080212"}
0005432783104	29F137	4448 237747	SERGEY CHERNOV	{"email": "s.chernov1976@postgrespro.ru", "phone": "+70728749327"}
0005432783105	29F137	0489 386120	MARIYA TROFIMOVA	{"phone": "+70791541337"}
0005432783106	CF1E8B	5988 903363	EVDOKIYA SOROKINA	{"email": "esorokina1970@postgrespro.ru", "phone": "+70184432464"}
0005432783107	417DE6	8033 300976	SERGEY EGOROV	{"phone": "+70808340568"}
0005432783108	D236CE	7307 069311	SERGEY CHERNOV	{"phone": "+70714540611"}
0005432783109	826A84	7792 412075	ALEKSANDR KOROLEV	{"phone": "+70240012859"}
0005432783110	A9AF6B	8932 397178	IVAN SCHERBAKOV	{"phone": "+70592148743"}
0005432783111	2318D3	5112 824800	SERGEY SCHERBAKOV	{"phone": "+70095908847"}
0005432783112	72D631	0711 847216	ALEKSANDR KARPOV	{"email": "karpovaleksandr15021983@postgrespro.ru", "phone": "+70062435455"}
0005432783113	325C71	5954 242374	OLGA GUSEVA	{"phone": "+70631383829"}
0005432783114	325C71	1883 379051	ALEKSANDRA LAZAREVA	{"phone": "+70301778735"}
0005432783115	037831	4485 480727	TAISIYA YUDINA	{"email": "t.yudina06101977@postgrespro.ru", "phone": "+70589658084"}
0005432783116	266045	2488 965902	ELENA FADEEVA	{"phone": "+70804922087"}
0005432783117	42AE59	1043 274420	DMITRIY BORISOV	{"email": "d-borisov.1970@postgrespro.ru", "phone": "+70180637939"}
0005432783118	42AE59	3129 625473	VLADIMIR PETROV	{"phone": "+70156270921"}
0005432783119	B16810	6711 699481	IRINA GUSEVA	{"email": "guseva.irina10091979@postgrespro.ru", "phone": "+70760902224"}
0005432783120	6BBFE2	2244 278306	ROZA NESTEROVA	{"phone": "+70340747695"}
0005432783121	C643FF	4624 887203	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva-091982@postgrespro.ru", "phone": "+70499766708"}
0005432783122	CD0716	0523 074456	NINA IVANOVA	{"email": "ivanova-n071969@postgrespro.ru", "phone": "+70894869177"}
0005432783123	CD0716	9871 100586	GALINA ANISIMOVA	{"email": "anisimovagalina06061985@postgrespro.ru", "phone": "+70361003272"}
0005432783124	CD0716	7104 658476	TATYANA FEDOROVA	{"phone": "+70820389980"}
0005432783125	0F77A1	8731 026794	ANNA ZHURAVLEVA	{"email": "zhuravlevaa_051985@postgrespro.ru", "phone": "+70929187571"}
0005432783126	632B36	0769 602608	ANNA KISELEVA	{"phone": "+70945687381"}
0005432783127	874171	6182 311568	VIKTOR KUZMIN	{"email": "vkuzmin.101979@postgrespro.ru", "phone": "+70397349314"}
0005432783128	179A89	9369 790660	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov.071977@postgrespro.ru", "phone": "+70673055827"}
0005432783129	654E27	7010 020063	ALEKSANDR IVANOV	{"email": "a-ivanov-1979@postgrespro.ru", "phone": "+70403890954"}
0005432783130	FE529C	1669 685594	PETR MAKAROV	{"email": "makarov-p_071963@postgrespro.ru", "phone": "+70748215927"}
0005432783131	B864EE	8121 481971	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr1974@postgrespro.ru", "phone": "+70816312688"}
0005432783132	B864EE	7985 783907	VLADIMIR ZHUKOV	{"email": "vladimirzhukov1967@postgrespro.ru", "phone": "+70231405484"}
0005432783133	B864EE	5981 443368	NATALYA SEMENOVA	{"email": "semenova-natalya.021966@postgrespro.ru", "phone": "+70099924719"}
0005432783134	D180A5	9463 210804	LYUBOV KOLESNIKOVA	{"email": "l-kolesnikova.031966@postgrespro.ru", "phone": "+70231604186"}
0005432783135	71FB3F	2170 758059	NADEZHDA KARPOVA	{"phone": "+70155362671"}
0005432783136	71FB3F	0344 936394	RAFIK ZHUKOV	{"phone": "+70842710336"}
0005432783137	71FB3F	3707 491690	KONSTANTIN TARASOV	{"email": "konstantin.tarasov_031975@postgrespro.ru", "phone": "+70144148271"}
0005432783138	C1A572	9418 120188	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-101970@postgrespro.ru", "phone": "+70603420205"}
0005432783139	DE72EF	8416 822343	RIMMA GORBUNOVA	{"email": "gorbunova-rimma-051976@postgrespro.ru", "phone": "+70452098203"}
0005432783140	03F5C6	8653 496718	DANIL ZAYCEV	{"email": "d_zaycev_08091976@postgrespro.ru", "phone": "+70556504876"}
0005432783141	79587B	4087 188576	ALEKSEY SAVELEV	{"email": "aleksey.savelev_02091974@postgrespro.ru", "phone": "+70341538656"}
0005432783142	79587B	3251 776696	MAKSIM BELOV	{"email": "m.belov_071983@postgrespro.ru", "phone": "+70140891760"}
0005432783143	55876A	6346 319715	LYUDMILA NESTEROVA	{"phone": "+70209932939"}
0005432783144	13EEB6	7479 125849	NINA YAKOVLEVA	{"phone": "+70530391355"}
0005432783145	13EEB6	7397 629413	ANNA LOGINOVA	{"phone": "+70209927078"}
0005432783146	743194	7541 536447	RAMIS SEMENOV	{"phone": "+70902204450"}
0005432783147	743194	5487 967117	STANISLAV SOROKIN	{"phone": "+70216296004"}
0005432783148	743194	5877 470048	ALEKSEY PAVLOV	{"phone": "+70263501523"}
0005432783149	3B06E2	6396 566449	SERGEY IVANOV	{"phone": "+70513637942"}
0005432783150	3B06E2	5685 421862	LYUBOV NOVIKOVA	{"email": "novikovalyubov.08061969@postgrespro.ru", "phone": "+70241196728"}
0005432783151	64D52E	0252 579045	OKSANA BARANOVA	{"phone": "+70592201252"}
0005432783152	0CE7B0	3175 998204	NINA KUZNECOVA	{"email": "kuznecova_n_011974@postgrespro.ru", "phone": "+70377330740"}
0005432783153	0CE7B0	3938 449702	LYUBOV KOZLOVA	{"phone": "+70085262243"}
0005432783154	919985	8415 020402	DMITRIY FEDOROV	{"phone": "+70720096742"}
0005432783155	919985	9587 579701	OLESYA GUSEVA	{"phone": "+70175497634"}
0005432783156	8595F1	9887 102717	ALEKSEY BELOV	{"email": "a-belov1966@postgrespro.ru", "phone": "+70708018678"}
0005432783157	F9528A	8901 983835	VALENTINA ANTONOVA	{"phone": "+70785546229"}
0005432783158	F9528A	8490 258656	OKSANA MOROZOVA	{"email": "oksana.morozova_1970@postgrespro.ru", "phone": "+70347629179"}
0005432783159	F9528A	2897 415769	SERGEY PAVLOV	{"phone": "+70087452086"}
0005432783160	A25C4B	3491 943554	IRINA MARTYNOVA	{"email": "martynova_i_1976@postgrespro.ru", "phone": "+70729583295"}
0005432783161	644346	4408 824573	GALINA KOROLEVA	{"phone": "+70074243650"}
0005432783162	136BEE	1156 134700	MATVEY TARASOV	{"phone": "+70172512876"}
0005432783163	46B936	7365 876061	MAKSIM MAKSIMOV	{"phone": "+70628956889"}
0005432783164	02D4AE	4604 790417	ALEKSEY SOLOVEV	{"email": "solovev_a-16061974@postgrespro.ru", "phone": "+70347887910"}
0005432783165	A20FF3	3198 249792	MIKHAIL IVANOV	{"email": "ivanovmikhail.17081978@postgrespro.ru", "phone": "+70565068075"}
0005432783579	2EBD68	6115 957437	NATALYA KUZNECOVA	{"phone": "+70657846703"}
0005432783166	9E4E91	3077 674867	NATALIYA YAKOVLEVA	{"email": "n_yakovleva_13041970@postgrespro.ru", "phone": "+70215068741"}
0005432783167	0DFF94	1502 681118	GALINA MIKHAYLOVA	{"email": "galinamikhaylova-081964@postgrespro.ru", "phone": "+70361745200"}
0005432783168	0DFF94	1209 878639	TATYANA ILINA	{"phone": "+70582857410"}
0005432783169	EBA0DC	0603 912619	LEONID POPOV	{"phone": "+70232646648"}
0005432783170	EBA0DC	3180 275102	SERGEY MAKAROV	{"email": "makarovs-101977@postgrespro.ru", "phone": "+70047385214"}
0005432783171	A180DE	1262 177581	STANISLAV MAKAROV	{"phone": "+70305723299"}
0005432783172	A180DE	5313 605972	STANISLAV ILIN	{"email": "silin_17121972@postgrespro.ru", "phone": "+70611622942"}
0005432783173	0A898E	3750 300494	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov_26081966@postgrespro.ru", "phone": "+70482024938"}
0005432783174	3BD04C	6562 047592	NINA MIRONOVA	{"email": "mironova.nina-1981@postgrespro.ru", "phone": "+70510765090"}
0005432783175	B55D23	0292 112493	ELENA EGOROVA	{"phone": "+70733897386"}
0005432783176	B55D23	1050 278146	RAISA BORISOVA	{"email": "borisovaraisa1963@postgrespro.ru", "phone": "+70087316973"}
0005432783177	834F82	1543 577626	TAMARA ALEKSANDROVA	{"phone": "+70425391435"}
0005432783178	74FCB9	7746 819136	RAFAIL YAKOVLEV	{"email": "r.yakovlev-1990@postgrespro.ru", "phone": "+70523379597"}
0005432783179	38BA2C	3368 097282	ALEKSEY DENISOV	{"email": "denisov.a111974@postgrespro.ru", "phone": "+70816798695"}
0005432783180	D82D62	0776 618739	NATALYA MOROZOVA	{"phone": "+70842947424"}
0005432783181	D82D62	8753 172762	ELENA ROMANOVA	{"email": "e.romanova_18071968@postgrespro.ru", "phone": "+70193423167"}
0005432783182	EE58FC	7254 129107	GENNADIY IVANOV	{"email": "g_ivanov-1976@postgrespro.ru", "phone": "+70711585957"}
0005432783183	6160C3	3811 257266	MAKSIM SOLOVEV	{"email": "solovev.maksim10031983@postgrespro.ru", "phone": "+70385550395"}
0005432783184	6160C3	2912 197450	ANASTASIYA KOVALEVA	{"email": "kovaleva.anastasiya1966@postgrespro.ru", "phone": "+70471288660"}
0005432783185	3B5E88	7041 782088	ANNA NAUMOVA	{"phone": "+70408982911"}
0005432783186	45C2D2	3546 433913	PETR DENISOV	{"email": "p.denisov051956@postgrespro.ru", "phone": "+70959549787"}
0005432783187	83ED4A	2443 333230	ALEKSANDR NAZAROV	{"email": "nazarov_aleksandr-1960@postgrespro.ru", "phone": "+70978124286"}
0005432783188	828DB0	6345 542926	RUSLAN SMIRNOV	{"phone": "+70180704446"}
0005432783189	828DB0	8109 279569	EKATERINA SEMENOVA	{"phone": "+70512640284"}
0005432783190	708683	3181 621547	EKATERINA ZAYCEVA	{"email": "zaycevaekaterina.1970@postgrespro.ru", "phone": "+70399017437"}
0005432783191	50C4E6	3549 155224	SVETLANA ZAKHAROVA	{"email": "zakharova.s.11071981@postgrespro.ru", "phone": "+70341016841"}
0005432783192	16292D	9541 639435	ALEKSEY FILIPPOV	{"phone": "+70630478078"}
0005432783193	16292D	9533 069698	OKSANA ALEKSANDROVA	{"email": "oksana_aleksandrova1971@postgrespro.ru", "phone": "+70225564647"}
0005432783194	2E1EA4	6324 488402	SERGEY IVANOV	{"phone": "+70441866736"}
0005432783195	073ADB	0780 435886	NADEZHDA ZAKHAROVA	{"phone": "+70178179351"}
0005432783196	073ADB	1145 576643	ANNA MAKSIMOVA	{"email": "maksimova-anna18071978@postgrespro.ru", "phone": "+70535954035"}
0005432783197	073ADB	6903 773304	VIKTOR KULIKOV	{"email": "v-kulikov.1961@postgrespro.ru", "phone": "+70677709786"}
0005432783198	CABD41	3731 331212	VLADISLAV KOZLOV	{"phone": "+70217092797"}
0005432783199	F122F9	3329 003500	VITALIY BORISOV	{"phone": "+70235529509"}
0005432783200	332EC7	3125 617751	TIMUR VOROBEV	{"phone": "+70374367085"}
0005432783201	91923B	7616 767966	RAISA ANDREEVA	{"phone": "+70754840955"}
0005432783202	F66815	9559 379783	LYUBOV KULIKOVA	{"email": "l_kulikova.30071974@postgrespro.ru", "phone": "+70045945495"}
0005432783203	2FCAE4	3610 611129	VALERIY IVANOV	{"email": "ivanov.v-14051957@postgrespro.ru", "phone": "+70188590675"}
0005432783204	47E243	8343 644332	GEORGIY MAKAROV	{"phone": "+70108877089"}
0005432783205	47E243	6385 785287	VLADISLAV SOROKIN	{"email": "sorokin.vladislav011982@postgrespro.ru", "phone": "+70412317984"}
0005432783206	47E243	4831 464471	PLATON OSIPOV	{"phone": "+70606266034"}
0005432783207	932513	6287 802432	LIDIYA DAVYDOVA	{"phone": "+70996316931"}
0005432783208	D12C46	9262 388333	NATALYA EFREMOVA	{"phone": "+70813059939"}
0005432783209	D12C46	7921 179697	SOFYA KOLESNIKOVA	{"email": "kolesnikovas091963@postgrespro.ru", "phone": "+70696897705"}
0005432783210	F7475F	9174 342780	LYUDMILA BORISOVA	{"phone": "+70307003178"}
0005432783211	F7475F	6998 426250	SERGEY ALEKSEEV	{"email": "s.alekseev1969@postgrespro.ru", "phone": "+70130020394"}
0005432783212	28FC64	8853 673013	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana.01051976@postgrespro.ru", "phone": "+70972183170"}
0005432783213	28FC64	4088 454879	LYUDMILA IVANOVA	{"phone": "+70362619046"}
0005432783214	22D50B	5595 045439	SERGEY ISAEV	{"phone": "+70966871649"}
0005432783215	402BA7	2841 014195	VLADIMIR KUZMIN	{"phone": "+70143530879"}
0005432783216	647BBC	8579 650931	NATALIYA SOROKINA	{"email": "sorokina_nataliya_1967@postgrespro.ru", "phone": "+70245222861"}
0005432783217	127DA7	5931 495255	VALENTIN ZAKHAROV	{"phone": "+70807361774"}
0005432783218	BA9F27	8628 257419	ALEKSANDR FEDOROV	{"phone": "+70735288099"}
0005432783219	BA9F27	8318 877369	SVETLANA ILINA	{"email": "s-ilina-121968@postgrespro.ru", "phone": "+70147130671"}
0005432783220	9BBEFB	5022 310974	PETR SHEVCHENKO	{"email": "p-shevchenko_1967@postgrespro.ru", "phone": "+70730472429"}
0005432783221	0D083B	2868 326094	TATYANA TIKHONOVA	{"email": "tatyana.tikhonova-1972@postgrespro.ru", "phone": "+70908176255"}
0005432783222	0D083B	4055 293549	ANNA AKIMOVA	{"email": "a_akimova_1963@postgrespro.ru", "phone": "+70310323533"}
0005432783223	0D083B	0966 661892	SERGEY GUSEV	{"email": "s.gusev.22081968@postgrespro.ru", "phone": "+70377463474"}
0005432783224	0D083B	8362 872094	LIDIYA SEMENOVA	{"phone": "+70466240587"}
0005432783819	A18045	4544 099329	ALEKSEY GAVRILOV	{"phone": "+70640326309"}
0005432783225	C6A6A0	6112 651146	ANASTASIYA VOLKOVA	{"email": "anastasiya-volkova.041980@postgrespro.ru", "phone": "+70373833515"}
0005432783226	FF3B6B	7109 399835	REGINA KULIKOVA	{"phone": "+70594113226"}
0005432783227	065050	3606 152581	DENIS GRIGOREV	{"email": "d.grigorev_15101969@postgrespro.ru", "phone": "+70079725640"}
0005432783228	D27438	8898 683524	ALEKSANDR ZAYCEV	{"phone": "+70369796733"}
0005432783229	915B35	5889 143075	VYACHESLAV FILIPPOV	{"phone": "+70910581786"}
0005432783230	9BCCA0	3843 985039	TATYANA FEDOROVA	{"email": "fedorova-tatyana.1960@postgrespro.ru", "phone": "+70807256497"}
0005432783231	EE5221	2028 912346	NIKITA GERASIMOV	{"email": "gerasimovnikita.1976@postgrespro.ru", "phone": "+70236390740"}
0005432783232	EE5221	3670 497391	ANASTASIYA MIKHAYLOVA	{"email": "a.mikhaylova-1963@postgrespro.ru", "phone": "+70112309862"}
0005432783233	E32B18	8726 322259	MAKSIM GRIGOREV	{"email": "grigorevm-1971@postgrespro.ru", "phone": "+70115812634"}
0005432783234	FC5109	6154 687165	VLADIMIR TARASOV	{"phone": "+70328796965"}
0005432783235	05F620	1716 286950	TATYANA NAUMOVA	{"email": "tatyana_naumova1982@postgrespro.ru", "phone": "+70363509065"}
0005432783236	05F620	8858 258173	STANISLAV KUZNECOV	{"email": "kuznecov-s-1966@postgrespro.ru", "phone": "+70573875078"}
0005432783237	1DD666	0243 896008	VLADIMIR SMIRNOV	{"phone": "+70721423946"}
0005432783238	1DD666	6769 154417	SERAFIM ROMANOV	{"email": "romanovserafim-1978@postgrespro.ru", "phone": "+70567779161"}
0005432783239	18CAA6	3592 413238	MIKHAIL STEPANOV	{"phone": "+70838598706"}
0005432783240	E1CB8C	3348 040708	STEPAN TIMOFEEV	{"email": "timofeev.stepan-23051985@postgrespro.ru", "phone": "+70207804388"}
0005432783241	E1CB8C	5601 075229	YURIY ZHUKOV	{"email": "zhukov-yuriy-1977@postgrespro.ru", "phone": "+70430555481"}
0005432783242	D5256B	0745 088796	YURIY TIMOFEEV	{"email": "timofeev.yuriy_1979@postgrespro.ru", "phone": "+70308105822"}
0005432783243	D5256B	4733 454374	ROMAN ANTONOV	{"email": "rantonov_1981@postgrespro.ru", "phone": "+70896169254"}
0005432783244	73DB92	3977 865042	RUSLAN MIKHAYLOV	{"email": "mikhaylovruslan.1971@postgrespro.ru", "phone": "+70794221468"}
0005432783245	56AA8D	7451 807600	RAFAEL ZHURAVLEV	{"phone": "+70339256311"}
0005432783246	56AA8D	9529 938765	LYUDMILA ZAKHAROVA	{"email": "l_zakharova.03031960@postgrespro.ru", "phone": "+70181575168"}
0005432783247	6A5790	4425 039429	YULIYA ANTONOVA	{"email": "antonova.yuliya061984@postgrespro.ru", "phone": "+70126188343"}
0005432783248	7F0C2D	4744 148041	VIKTORIYA GAVRILOVA	{"email": "gavrilova_viktoriya_1966@postgrespro.ru", "phone": "+70193925073"}
0005432783249	7F0C2D	6444 626598	VLADIMIR FEDOTOV	{"email": "fedotovv-101964@postgrespro.ru", "phone": "+70189167550"}
0005432783250	BEA09D	2078 760645	MARIYA MASLOVA	{"email": "maslova.m-081976@postgrespro.ru", "phone": "+70420576219"}
0005432783251	777D1B	8742 216023	EVGENIYA ZAYCEVA	{"email": "zaycevae14071970@postgrespro.ru", "phone": "+70011426876"}
0005432783252	777D1B	7982 443424	ALEKSANDR SOLOVEV	{"phone": "+70631162089"}
0005432783253	E59A6B	5516 122056	VLADIMIR MIRONOV	{"email": "vladimir_mironov.031966@postgrespro.ru", "phone": "+70541343442"}
0005432783254	4F8836	9074 958397	ALLA IVANOVA	{"phone": "+70926721114"}
0005432783255	E08A5B	3122 836531	NINA CHERNOVA	{"email": "chernova.n_07021986@postgrespro.ru", "phone": "+70470567079"}
0005432783256	0D0BF4	1605 398983	NINA MALYSHEVA	{"phone": "+70397712961"}
0005432783257	AD32FD	3658 783200	KONSTANTIN ILIN	{"phone": "+70408926046"}
0005432783258	0FDEC1	4792 719140	DARYA BELYAEVA	{"phone": "+70996946852"}
0005432783259	033E10	6667 490613	NATALYA MAKAROVA	{"phone": "+70332109468"}
0005432783260	033E10	3568 612140	ASKHAT MELNIKOV	{"email": "askhatmelnikov_061965@postgrespro.ru", "phone": "+70244164482"}
0005432783261	DB5E55	2512 048184	NURIYA NIKOLAEVA	{"phone": "+70785864639"}
0005432783262	05DC83	1921 134698	SERGEY MAKAROV	{"phone": "+70211723016"}
0005432783263	05DC83	5411 251983	FARID IVANOV	{"email": "ivanovf_01111978@postgrespro.ru", "phone": "+70797120014"}
0005432783264	75CE90	0395 414560	TATYANA SERGEEVA	{"phone": "+70801175281"}
0005432783265	75CE90	7700 141800	PAVEL SEMENOV	{"email": "pavel.semenov_15021985@postgrespro.ru", "phone": "+70148829779"}
0005432783266	E38FCC	8868 122571	EVGENIY POPOV	{"email": "popov.e.1969@postgrespro.ru", "phone": "+70469608216"}
0005432783267	7FA72B	8725 887280	ELENA FROLOVA	{"email": "e_frolova_021963@postgrespro.ru", "phone": "+70206978821"}
0005432783268	7FA72B	0076 830007	MARIYA MAKAROVA	{"phone": "+70064709723"}
0005432783269	A24F85	4080 773079	OKSANA EGOROVA	{"email": "egorovaoksana.1969@postgrespro.ru", "phone": "+70444112050"}
0005432783270	3EFBA6	5661 339195	ALEKSEY SHEVCHENKO	{"phone": "+70233563886"}
0005432783271	FF0327	2437 297601	NINA ZHURAVLEVA	{"email": "zhuravleva_n-031978@postgrespro.ru", "phone": "+70886286759"}
0005432783272	F16B9C	5612 336817	VALERIY MAKAROV	{"email": "v-makarov.031970@postgrespro.ru", "phone": "+70190536697"}
0005432783273	F16B9C	4540 310758	VASILIY KOROLEV	{"email": "vasiliy_korolev_11021974@postgrespro.ru", "phone": "+70445081399"}
0005432783274	F16B9C	7339 561947	VYACHESLAV ZAKHAROV	{"email": "zakharov-v-13101978@postgrespro.ru", "phone": "+70932180027"}
0005432783275	760A4B	8787 454927	ALEKSANDR KOROLEV	{"phone": "+70249999429"}
0005432783276	79539E	3603 296861	ALEKSEY SCHERBAKOV	{"phone": "+70463292422"}
0005432783277	79539E	0205 275745	NIKOLAY BONDARENKO	{"email": "nikolay_bondarenko_011972@postgrespro.ru", "phone": "+70410003677"}
0005432783278	8F21A6	0387 230243	VIKTOR VOLKOV	{"email": "viktorvolkov111969@postgrespro.ru", "phone": "+70255950264"}
0005432783279	4CC2DE	6925 163456	SVETLANA ROMANOVA	{"email": "s_romanova_1968@postgrespro.ru", "phone": "+70141140525"}
0005432783280	297709	3607 564321	NIKITA SEMENOV	{"email": "nikita.semenov-121980@postgrespro.ru", "phone": "+70524638680"}
0005432783281	297709	9395 544537	ANASTASIYA EGOROVA	{"email": "egorova-anastasiya1979@postgrespro.ru", "phone": "+70855499445"}
0005432783820	A18045	4543 894698	TATYANA FILATOVA	{"phone": "+70937826634"}
0005432783282	0C5F96	6493 790840	ANDREY FOMIN	{"email": "a_fomin-061980@postgrespro.ru", "phone": "+70431193004"}
0005432783283	0C5F96	0738 583742	DMITRIY ZAYCEV	{"phone": "+70644809342"}
0005432783284	CBFDA7	4074 440226	NATALIYA NIKOLAEVA	{"phone": "+70258233075"}
0005432783285	0F8AAA	1667 168369	VIKTORIYA KRASNOVA	{"phone": "+70475570864"}
0005432783286	DB365C	9265 696535	GENNADIY KOROLEV	{"email": "gkorolev.071970@postgrespro.ru", "phone": "+70661280332"}
0005432783287	DB365C	6850 211858	EVGENIYA MOISEEVA	{"phone": "+70656201942"}
0005432783288	EA4FF3	0289 759432	OLGA MAKAROVA	{"email": "olga.makarova.13091975@postgrespro.ru", "phone": "+70874715894"}
0005432783289	A9BAEB	2736 996954	SERGEY ZHUKOV	{"email": "sergeyzhukov_26071963@postgrespro.ru", "phone": "+70559720497"}
0005432783290	A9BAEB	3305 023539	GALINA PAVLOVA	{"email": "g.pavlova_1965@postgrespro.ru", "phone": "+70995149319"}
0005432783291	CE2EB4	0113 054497	NIKOLAY MARTYNOV	{"email": "martynov-n_111964@postgrespro.ru", "phone": "+70899185467"}
0005432783292	CE2EB4	6463 826374	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda_021974@postgrespro.ru", "phone": "+70557720222"}
0005432783293	CE2EB4	2881 843325	ANDREY MIRONOV	{"email": "mironov.andrey091974@postgrespro.ru", "phone": "+70834880635"}
0005432783294	F5E31C	0465 930296	SERGEY GUSEV	{"email": "sergeygusev.11011969@postgrespro.ru", "phone": "+70283657508"}
0005432783295	C8CAC9	2067 364162	ALEKSANDR VOLKOV	{"phone": "+70077263145"}
0005432783296	F37F4E	1347 770257	KLAVDIYA GERASIMOVA	{"phone": "+70109024176"}
0005432783297	903321	7750 994947	NINA IVANOVA	{"phone": "+70272914123"}
0005432783298	304622	6922 799144	YURIY IVANOV	{"email": "yuriy_ivanov-17091974@postgrespro.ru", "phone": "+70595393124"}
0005432783299	D9A8AB	2714 374687	ANATOLIY AFANASEV	{"email": "afanasev_anatoliy-011966@postgrespro.ru", "phone": "+70298000043"}
0005432783300	5C75A7	7905 373545	VLADISLAV GAVRILOV	{"email": "gavrilovv1975@postgrespro.ru", "phone": "+70687611158"}
0005432783301	5C75A7	0953 909071	LYUBOV ORLOVA	{"phone": "+70636523071"}
0005432783302	5C75A7	9841 034697	ALEKSANDR SAVELEV	{"email": "savelev.aleksandr_1967@postgrespro.ru", "phone": "+70311932544"}
0005432783303	B3A926	2729 118735	VLADIMIR MIRONOV	{"email": "v_mironov_061976@postgrespro.ru", "phone": "+70695749608"}
0005432783304	B3A926	1062 010839	PAVEL POPOV	{"phone": "+70026088946"}
0005432783305	40160E	9921 174049	MARIYA ISAEVA	{"email": "misaeva_111967@postgrespro.ru", "phone": "+70442746205"}
0005432783306	C21A84	8801 243380	ANTON MAKAROV	{"email": "makarov-anton_1963@postgrespro.ru", "phone": "+70417767115"}
0005432783307	1DB0FF	3013 300080	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir03091969@postgrespro.ru", "phone": "+70237914101"}
0005432783308	D61FEB	5687 523687	SERGEY ILIN	{"phone": "+70457327849"}
0005432783309	D61FEB	1957 751490	VALERIYA YAKOVLEVA	{"email": "yakovleva-v-1967@postgrespro.ru", "phone": "+70796468312"}
0005432783310	3041A2	8757 425285	ELIZAVETA KUZNECOVA	{"email": "kuznecova_elizaveta_031975@postgrespro.ru", "phone": "+70741622019"}
0005432783311	38048D	2429 821211	EGOR SOKOLOV	{"phone": "+70373185268"}
0005432783312	38048D	6231 027752	ANNA ILINA	{"email": "ilina.a24031971@postgrespro.ru", "phone": "+70067394882"}
0005432783313	9A2044	5201 211124	ILYA ZAKHAROV	{"phone": "+70488037367"}
0005432783314	E9A3BD	9951 914403	ELENA DAVYDOVA	{"email": "elena-davydova.1966@postgrespro.ru", "phone": "+70461528139"}
0005432783315	451124	1184 492562	DARYA POPOVA	{"phone": "+70671273656"}
0005432783316	D8B478	2787 814991	SERGEY FEDOTOV	{"email": "fedotov-sergey_1969@postgrespro.ru", "phone": "+70400937019"}
0005432783317	76367C	9970 757296	STEPAN NIKOLAEV	{"email": "stepan_nikolaev_09051977@postgrespro.ru", "phone": "+70831793359"}
0005432783318	B6288C	4199 059756	VLADIMIR BORISOV	{"phone": "+70777207109"}
0005432783319	3E6080	0445 543868	IRINA IVANOVA	{"email": "irina_ivanova12031967@postgrespro.ru", "phone": "+70793763741"}
0005432783320	3E6080	1531 919692	GALINA VOLKOVA	{"phone": "+70952913656"}
0005432783321	01933E	0750 001833	DMITRIY OSIPOV	{"phone": "+70018106607"}
0005432783322	0FC806	3447 360699	IRINA ZHUKOVA	{"email": "zhukova_i-1971@postgrespro.ru", "phone": "+70696361721"}
0005432783323	0FC806	7324 092868	MIKHAIL SOROKIN	{"phone": "+70332031555"}
0005432783324	0FC806	1544 385017	GENNADIY ZHUKOV	{"phone": "+70236672060"}
0005432783325	985769	2017 579130	VLADIMIR DENISOV	{"phone": "+70455316796"}
0005432783326	44A958	1290 089093	NIKOLAY IVANOV	{"phone": "+70984614975"}
0005432783327	2B5BED	7764 777620	LEYLA KOROLEVA	{"phone": "+70693444165"}
0005432783328	E0C802	3390 341726	FEDOR ANTONOV	{"email": "fedorantonov071974@postgrespro.ru", "phone": "+70341446627"}
0005432783329	E0C802	6304 405000	ALEKSANDR FEDOROV	{"phone": "+70052980195"}
0005432783330	E0C802	3959 949854	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a-081977@postgrespro.ru", "phone": "+70804120280"}
0005432783331	DA6318	8607 042633	RAISA VASILEVA	{"phone": "+70420528948"}
0005432783332	B0B5F8	9185 988234	ALEKSEY KUZNECOV	{"phone": "+70934202151"}
0005432783333	BDAF59	6500 031250	DIANA FILATOVA	{"phone": "+70027270687"}
0005432783334	BDAF59	6486 512513	EKATERINA SOKOLOVA	{"phone": "+70403566234"}
0005432783335	D0B7AC	1367 515028	ALEKSANDR VOLKOV	{"email": "volkova-1977@postgrespro.ru", "phone": "+70599056831"}
0005432783336	7EA4EB	7756 164445	DANIL MIKHAYLOV	{"email": "danil.mikhaylov.051964@postgrespro.ru", "phone": "+70816707338"}
0005432783337	C53129	2274 960173	SVETLANA AFANASEVA	{"phone": "+70823045406"}
0005432783338	25FD41	4222 246945	ANATOLIY MAKAROV	{"email": "makarov.a_1967@postgrespro.ru", "phone": "+70597992746"}
0005432783339	25FD41	7670 080521	SERGEY PAVLOV	{"email": "s-pavlov-121970@postgrespro.ru", "phone": "+70261048557"}
0005432783340	E2E241	1790 865692	VASILIY TARASOV	{"email": "v_tarasov07111969@postgrespro.ru", "phone": "+70647939309"}
0005432783341	E2E241	0939 092533	ALEKSANDR IVANOV	{"phone": "+70321557966"}
0005432783342	E2E241	5020 905497	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov101973@postgrespro.ru", "phone": "+70323707394"}
0005432783343	E2E241	0884 127198	GALINA IVANOVA	{"phone": "+70605476770"}
0005432783344	4DB7BB	7270 816673	VLADISLAV ALEKSEEV	{"phone": "+70834914831"}
0005432783345	4DB7BB	5911 891569	MAKSIM SOLOVEV	{"phone": "+70452492174"}
0005432783346	015593	8146 410153	SVETLANA ROMANOVA	{"phone": "+70968034556"}
0005432783347	AFCB25	6597 981022	NATALYA ZAKHAROVA	{"email": "n.zakharova.25101968@postgrespro.ru", "phone": "+70545396556"}
0005432783348	1C1F35	5148 364108	MARINA KRASNOVA	{"phone": "+70940625183"}
0005432783349	9E5279	7503 514188	RAFAIL NIKOLAEV	{"phone": "+70462842980"}
0005432783350	F1B451	8279 791529	DENIS SOLOVEV	{"phone": "+70030500019"}
0005432783351	D25D9E	5115 962515	VALENTINA NAUMOVA	{"email": "v.naumova021971@postgrespro.ru", "phone": "+70182705198"}
0005432783352	D25D9E	1823 616540	SERGEY KUZNECOV	{"email": "sergey_kuznecov.1973@postgrespro.ru", "phone": "+70575075059"}
0005432783353	C09A7E	4672 376748	DENIS SAVELEV	{"phone": "+70864386874"}
0005432783354	E0CE51	1408 469871	IVAN PAVLOV	{"phone": "+70952040516"}
0005432783355	3DA30C	6060 622942	EGOR CHERNOV	{"phone": "+70104572256"}
0005432783356	EED35E	5825 682166	ARTEM GERASIMOV	{"email": "gerasimov_a-1975@postgrespro.ru", "phone": "+70287112038"}
0005432783357	3595D5	0708 758455	LYUBOV NIKOLAEVA	{"email": "lyubov-nikolaeva.111966@postgrespro.ru", "phone": "+70099429007"}
0005432783358	497C29	1636 619010	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov1956@postgrespro.ru", "phone": "+70032360195"}
0005432783359	497C29	0221 551848	DMITRIY ABRAMOV	{"phone": "+70486678011"}
0005432783360	167F59	1439 045367	YULIYA MARTYNOVA	{"phone": "+70592096460"}
0005432783361	DB60BE	9201 316304	VYACHESLAV FEDOTOV	{"email": "fedotov-vyacheslav_1978@postgrespro.ru", "phone": "+70288432290"}
0005432783362	B493E9	5599 898275	VALENTINA IVANOVA	{"phone": "+70689452981"}
0005432783363	FAB2BB	2961 610532	NATALYA EFREMOVA	{"email": "n_efremova_12011981@postgrespro.ru", "phone": "+70768382262"}
0005432783364	FAA0BF	3406 839008	GALINA ANDREEVA	{"email": "g-andreeva.1968@postgrespro.ru", "phone": "+70523125982"}
0005432783365	BE5F71	1253 875862	ANDREY GORBUNOV	{"email": "andrey.gorbunov_1962@postgrespro.ru", "phone": "+70573400222"}
0005432783366	D500D0	7145 261550	MAKSIM PETROV	{"email": "petrov.maksim021969@postgrespro.ru", "phone": "+70196928235"}
0005432783367	35C164	6371 182296	PAVEL NIKOLAEV	{"email": "nikolaevp-1980@postgrespro.ru", "phone": "+70692427186"}
0005432783368	197E23	9627 017324	LARISA BORISOVA	{"email": "borisova.l.13031967@postgrespro.ru", "phone": "+70019427684"}
0005432783369	197E23	1050 244660	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov-04101973@postgrespro.ru", "phone": "+70606036067"}
0005432783370	F90652	3790 442398	NADEZHDA MIRONOVA	{"phone": "+70586655304"}
0005432783371	7A49D7	0472 821054	MIKHAIL NAZAROV	{"email": "m_nazarov.22051968@postgrespro.ru", "phone": "+70710668510"}
0005432783372	7618C0	0683 675117	ALEKSANDR MIKHAYLOV	{"phone": "+70274189256"}
0005432783373	E9EFCB	2407 648638	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov1970@postgrespro.ru", "phone": "+70795464294"}
0005432783374	3B1748	4676 285420	MIKHAIL SIDOROV	{"phone": "+70692665066"}
0005432783375	C65B8E	8570 183628	VALENTINA POPOVA	{"phone": "+70472438871"}
0005432783376	9B1BD1	8401 237830	IVAN ZHUKOV	{"phone": "+70054818647"}
0005432783377	99F804	8425 168059	TATYANA CHERNOVA	{"phone": "+70706597488"}
0005432783378	ADD41D	0310 071746	MARIYA KOZLOVA	{"email": "kozlovam11031971@postgrespro.ru", "phone": "+70210692386"}
0005432783379	0C4864	1661 419673	GALINA YUDINA	{"email": "yudinag-1966@postgrespro.ru", "phone": "+70230308267"}
0005432783380	21B039	1872 879095	VADIM BONDARENKO	{"email": "bondarenko-v05011964@postgrespro.ru", "phone": "+70621610126"}
0005432783381	21B039	5651 996016	SERGEY SHEVCHENKO	{"email": "s-shevchenko-021979@postgrespro.ru", "phone": "+70990112220"}
0005432783382	21B039	6070 458162	OLGA ILINA	{"phone": "+70274859736"}
0005432783383	21B039	5807 231767	SERGEY BORISOV	{"phone": "+70266239397"}
0005432783384	58E475	8795 571762	VERA KARPOVA	{"phone": "+70239766323"}
0005432783385	58E475	0186 585306	ALEKSEY SERGEEV	{"email": "asergeev_26021971@postgrespro.ru", "phone": "+70223191377"}
0005432783386	58E475	4051 459638	ANGELINA POTAPOVA	{"phone": "+70235564119"}
0005432783387	EDB8A7	7630 970573	MARINA OSIPOVA	{"phone": "+70235977828"}
0005432783388	1607D7	2827 769403	OLEG KOZLOV	{"phone": "+70784815448"}
0005432783389	1607D7	0092 194809	STEPAN NAZAROV	{"email": "stepannazarov_1976@postgrespro.ru", "phone": "+70782878520"}
0005432783390	1607D7	5587 445000	IGOR MIRONOV	{"email": "i_mironov-1961@postgrespro.ru", "phone": "+70816466576"}
0005432783391	599055	4191 761129	SERGEY AFANASEV	{"email": "afanasev-sergey_091974@postgrespro.ru", "phone": "+70018392973"}
0005432783392	599055	4588 902333	YULIYA FILATOVA	{"email": "yuliya-filatova.1977@postgrespro.ru", "phone": "+70673665869"}
0005432783393	21CDCF	6697 095657	TATYANA NIKITINA	{"phone": "+70245879075"}
0005432783394	F0AC5A	6123 273746	ALEKSANDR GRIGOREV	{"email": "grigorev-a_23061976@postgrespro.ru", "phone": "+70142103326"}
0005432783395	F0AC5A	0260 371132	SERAFIMA EFIMOVA	{"phone": "+70695161354"}
0005432783396	F0AC5A	5988 597816	MIROSLAV FEDOROV	{"phone": "+70365862870"}
0005432783397	7518A4	0049 551531	SVETLANA MARTYNOVA	{"phone": "+70744746509"}
0005432783398	E49192	6534 230864	OLGA KUDRYASHOVA	{"email": "kudryashovaolga_29081976@postgrespro.ru", "phone": "+70205560750"}
0005432783399	6F0DA1	4482 178643	KSENIYA SOLOVEVA	{"email": "k-soloveva-1981@postgrespro.ru", "phone": "+70169908756"}
0005432783400	1C78FD	4738 371315	MIKHAIL POPOV	{"email": "popov.mikhail_27011978@postgrespro.ru", "phone": "+70716506108"}
0005432783401	E063BF	1245 392360	SAMIR VLASOV	{"phone": "+70941740274"}
0005432783402	8C8202	7305 326879	TATYANA STEPANOVA	{"phone": "+70742801341"}
0005432783403	8C8202	2047 984268	LILIYA KAZAKOVA	{"email": "kazakova_l03051975@postgrespro.ru", "phone": "+70255232274"}
0005432783404	327EAB	3427 362603	DANIIL KULIKOV	{"email": "kulikov-daniil_051982@postgrespro.ru", "phone": "+70089088384"}
0005432783405	080A68	3720 053024	RAVIL RODIONOV	{"email": "rodionov-ravil27091979@postgrespro.ru", "phone": "+70499311510"}
0005432783406	080A68	9400 911779	VALENTINA POPOVA	{"phone": "+70806363950"}
0005432783407	DB4826	7248 430924	FEDOR ZAKHAROV	{"email": "zakharovfedor-101974@postgrespro.ru", "phone": "+70915939794"}
0005432783408	B8F1AC	3992 386821	STANISLAV PAVLOV	{"phone": "+70949492835"}
0005432783409	EA2690	4490 803792	ALEKSANDRA ANISIMOVA	{"phone": "+70139497992"}
0005432783410	87EDB9	0265 060914	DARYA EGOROVA	{"email": "egorova_darya.1963@postgrespro.ru", "phone": "+70088188668"}
0005432783411	87EDB9	3785 280652	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov1965@postgrespro.ru", "phone": "+70172657526"}
0005432783412	21D84A	8826 462308	OLGA KARPOVA	{"email": "karpova_olga_061980@postgrespro.ru", "phone": "+70214372592"}
0005432783413	DEB695	6646 456171	VALENTIN KUZNECOV	{"email": "kuznecov-v.02121978@postgrespro.ru", "phone": "+70244371739"}
0005432783414	3BE9D4	8189 746782	RINAT TARASOV	{"phone": "+70862701031"}
0005432783415	D38105	3616 816921	ALEKSANDRA BORISOVA	{"phone": "+70979926391"}
0005432783416	34F45D	9082 105041	ALEKSANDR SIDOROV	{"phone": "+70336329780"}
0005432783417	B5BFB8	4407 032076	MARSEL ISAEV	{"email": "isaevm_06091974@postgrespro.ru", "phone": "+70218818812"}
0005432783418	CB6386	4236 573309	ALEKSANDR KAZAKOV	{"phone": "+70032266786"}
0005432783419	D21D6D	7335 211278	DENIS MAKSIMOV	{"email": "denismaksimov.021973@postgrespro.ru", "phone": "+70171329216"}
0005432783420	A338D2	7992 371461	EGOR DAVYDOV	{"phone": "+70793474815"}
0005432783421	708C15	4101 457216	MARIYA VLASOVA	{"email": "mariyavlasova1968@postgrespro.ru", "phone": "+70498301747"}
0005432783422	034ED0	8355 330756	DMITRIY PAVLOV	{"phone": "+70567890498"}
0005432783423	415286	3511 065451	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev_1975@postgrespro.ru", "phone": "+70771494097"}
0005432783424	415286	0506 777195	ANDREY NAZAROV	{"email": "nazarov.andrey04041975@postgrespro.ru", "phone": "+70953190750"}
0005432783425	0CC77B	6894 589755	ANDREY FEDOROV	{"phone": "+70949396631"}
0005432783426	DB1C86	9175 322702	OLGA KUZNECOVA	{"phone": "+70003127930"}
0005432783427	DB1C86	7723 959723	LIDIYA GORBUNOVA	{"email": "gorbunova_lidiya-051974@postgrespro.ru", "phone": "+70951313162"}
0005432783428	95F960	4408 407719	GALINA AKIMOVA	{"email": "galina_akimova_1978@postgrespro.ru", "phone": "+70989983024"}
0005432783429	BDF66E	4507 141701	VLADIMIR KULIKOV	{"email": "v.kulikov.101983@postgrespro.ru", "phone": "+70366909352"}
0005432783430	BDF66E	0769 473232	IVAN ALEKSANDROV	{"phone": "+70034033030"}
0005432783431	BF1746	3800 521709	TATYANA MIKHAYLOVA	{"email": "t-mikhaylova.101970@postgrespro.ru", "phone": "+70208995642"}
0005432783432	EBD5F4	6679 901589	ELIZAVETA SCHERBAKOVA	{"email": "scherbakova.elizaveta.30051973@postgrespro.ru", "phone": "+70821095113"}
0005432783433	EB4DB8	4023 229622	IRINA MAKAROVA	{"email": "imakarova28121965@postgrespro.ru", "phone": "+70960430125"}
0005432783434	7C05B7	8472 237067	GENNADIY KUZNECOV	{"email": "gkuznecov.031973@postgrespro.ru", "phone": "+70098861117"}
0005432783435	35D670	1957 580795	ELENA IVANOVA	{"phone": "+70463016543"}
0005432783436	35D670	6020 508369	IRINA VOROBEVA	{"email": "irina.vorobeva23071983@postgrespro.ru", "phone": "+70566330745"}
0005432783437	FC942B	2351 105723	PETR GRIGOREV	{"email": "petr.grigorev_1979@postgrespro.ru", "phone": "+70681765895"}
0005432783438	EF97C7	5651 241887	ALEKSANDR SCHERBAKOV	{"phone": "+70515556652"}
0005432783439	D9F131	7051 359129	NATALYA KONDRATEVA	{"phone": "+70180042128"}
0005432783440	362BF2	8666 070891	YULIYA NIKOLAEVA	{"email": "nikolaeva-yuliya_1966@postgrespro.ru", "phone": "+70835367499"}
0005432783441	6AD336	0057 938897	NIKOLAY POPOV	{"phone": "+70911489378"}
0005432783442	BF5463	4454 465270	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr-19081988@postgrespro.ru", "phone": "+70927282512"}
0005432783443	BC84FC	5543 056300	LYUBOV MIKHAYLOVA	{"email": "lmikhaylova.1960@postgrespro.ru", "phone": "+70902596957"}
0005432783444	089B82	7390 127796	LYUDMILA KOMAROVA	{"email": "komarova.lyudmila.111972@postgrespro.ru", "phone": "+70685021900"}
0005432783445	089B82	2788 239405	ANASTASIYA TITOVA	{"email": "titova-a-021957@postgrespro.ru", "phone": "+70683262781"}
0005432783446	DF41DC	9430 192329	LYUBOV MAKSIMOVA	{"email": "maksimova_l-14081972@postgrespro.ru", "phone": "+70450268493"}
0005432783447	5ED6FB	8803 748717	EKATERINA MIKHAYLOVA	{"phone": "+70367769398"}
0005432783448	8251D9	7255 467919	TATYANA VOROBEVA	{"phone": "+70024026204"}
0005432783449	8251D9	7713 390559	ELENA AFANASEVA	{"email": "afanaseva-elena.041982@postgrespro.ru", "phone": "+70577058348"}
0005432783450	8A56D3	6580 625644	ALLA DENISOVA	{"email": "denisova.a1972@postgrespro.ru", "phone": "+70467066992"}
0005432783451	645AB9	1299 624454	ALEKSANDR YAKOVLEV	{"phone": "+70855481210"}
0005432783452	645AB9	7865 332882	ARTEM KULIKOV	{"email": "artem.kulikov-091963@postgrespro.ru", "phone": "+70627940876"}
0005432783453	C5B70F	5701 516355	VLADIMIR VOLKOV	{"phone": "+70961970186"}
0005432783454	A7A147	9072 759972	VIKTORIYA ALEKSANDROVA	{"email": "aleksandrovaviktoriya08111974@postgrespro.ru", "phone": "+70439249085"}
0005432783455	4FEBDF	6736 925866	TATYANA PETROVA	{"phone": "+70209476500"}
0005432783456	C7B01A	6635 562073	SERGEY ABRAMOV	{"email": "sergey.abramov121982@postgrespro.ru", "phone": "+70901505815"}
0005432783457	295A45	8602 869733	OLGA PETROVA	{"email": "o.petrova_121971@postgrespro.ru", "phone": "+70968784082"}
0005432783458	75591A	6637 783786	ELENA ANISIMOVA	{"phone": "+70195463356"}
0005432783459	5325B4	5969 763352	VERA NOVIKOVA	{"email": "veranovikova_10111966@postgrespro.ru", "phone": "+70882051437"}
0005432783460	6B4044	9187 674307	VALENTINA NIKIFOROVA	{"phone": "+70577964939"}
0005432783461	6B4044	7748 937808	DMITRIY MELNIKOV	{"email": "d_melnikov-111963@postgrespro.ru", "phone": "+70908741987"}
0005432783462	5C01DD	9009 673380	LIDIYA OSIPOVA	{"phone": "+70309130973"}
0005432783463	A1FD0E	2583 227340	OLGA POPOVA	{"phone": "+70453206020"}
0005432783464	A1FD0E	8957 343947	VIKTOR KARPOV	{"email": "v.karpov101977@postgrespro.ru", "phone": "+70969072145"}
0005432783465	FC1004	1384 144682	VALENTINA MAKAROVA	{"email": "valentinamakarova27031972@postgrespro.ru", "phone": "+70686880399"}
0005432783466	FC1004	4582 929053	ANDREY NOVIKOV	{"email": "novikov-a21041977@postgrespro.ru", "phone": "+70035460175"}
0005432783467	0802E5	0284 579337	VLADIMIR FILIPPOV	{"email": "vladimirfilippov.1984@postgrespro.ru", "phone": "+70444766467"}
0005432783468	2D15E6	3461 011124	ALMIRA SEMENOVA	{"email": "a_semenova_1962@postgrespro.ru", "phone": "+70550380343"}
0005432783469	15973D	2761 584460	NAILYA BORISOVA	{"email": "borisovan-1973@postgrespro.ru", "phone": "+70960732315"}
0005432783470	15973D	4354 857820	DANIIL YAKOVLEV	{"phone": "+70894485724"}
0005432783471	C1351D	1990 775593	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov-31101973@postgrespro.ru", "phone": "+70286315458"}
0005432783472	52E3D2	8271 827508	NINA KUZNECOVA	{"email": "n_kuznecova.1975@postgrespro.ru", "phone": "+70977785526"}
0005432783473	E39FD3	0573 954156	DMITRIY YAKOVLEV	{"email": "yakovlev.dmitriy_081977@postgrespro.ru", "phone": "+70759006976"}
0005432783474	4FA214	1329 891143	OLGA KOROLEVA	{"phone": "+70068398299"}
0005432783475	3C14DA	9692 753945	ALEKSANDR KAZAKOV	{"email": "kazakov_a-051972@postgrespro.ru", "phone": "+70327734976"}
0005432783476	904036	5645 260839	LYUBOV BORISOVA	{"phone": "+70904630668"}
0005432783477	904036	7512 390257	ARINA TIKHONOVA	{"email": "tikhonova-arina_1970@postgrespro.ru", "phone": "+70564572712"}
0005432783478	AE1BF1	4557 856932	VIKTORIYA MIRONOVA	{"email": "v.mironova-1980@postgrespro.ru", "phone": "+70825364372"}
0005432783479	9C7BBC	2506 072047	OLGA PAVLOVA	{"phone": "+70655769369"}
0005432783480	D28922	5536 725551	ALEKSEY VOLKOV	{"email": "alekseyvolkov_30051983@postgrespro.ru", "phone": "+70182067560"}
0005432783481	D28922	4419 012434	NIKOLAY FEDOROV	{"phone": "+70158576984"}
0005432783482	D28922	6735 832767	ALEKSEY GRIGOREV	{"phone": "+70844687751"}
0005432783483	319B9A	3642 868190	TATYANA SMIRNOVA	{"phone": "+70053629288"}
0005432783484	185239	9253 793236	ROMAN KARPOV	{"email": "karpov_roman101958@postgrespro.ru", "phone": "+70353397730"}
0005432783485	0AC545	7210 554430	VIKTOR MOROZOV	{"email": "morozov-v17121978@postgrespro.ru", "phone": "+70169196237"}
0005432783486	0AC545	4635 663033	SERGEY STEPANOV	{"email": "s.stepanov-07021972@postgrespro.ru", "phone": "+70043081197"}
0005432783487	B68434	3365 438992	VLADIMIR ZAKHAROV	{"phone": "+70086435730"}
0005432783488	B68434	8452 097322	OLGA NESTEROVA	{"phone": "+70773097079"}
0005432783489	692840	7978 075601	YULIYA NESTEROVA	{"email": "yuliyanesterova1967@postgrespro.ru", "phone": "+70383383631"}
0005432783490	6D7357	4264 634513	LYUBOV ZAYCEVA	{"email": "lyubovzayceva17121975@postgrespro.ru", "phone": "+70458277807"}
0005432783491	D6FAC1	7464 722595	ELIZAVETA STEPANOVA	{"phone": "+70569678491"}
0005432783492	D6FAC1	3874 956684	VIKTOR FEDOTOV	{"phone": "+70378401140"}
0005432783493	6F42A8	1455 242262	SERGEY BONDARENKO	{"phone": "+70405083395"}
0005432783494	6F42A8	7488 480554	BORIS FEDOTOV	{"phone": "+70638450153"}
0005432783495	6F42A8	4866 613930	IRINA MIKHAYLOVA	{"email": "mikhaylova.i.071979@postgrespro.ru", "phone": "+70220580478"}
0005432783496	57F8D3	1890 846270	IRINA BELYAEVA	{"email": "i.belyaeva1984@postgrespro.ru", "phone": "+70813097524"}
0005432783497	57F8D3	4592 867281	VASILISA NIKITINA	{"email": "nikitina_vasilisa_14041970@postgrespro.ru", "phone": "+70030403537"}
0005432783498	E3DA0A	2989 557363	SVETLANA ILINA	{"phone": "+70618976971"}
0005432783499	8FA45C	5846 213599	SVETLANA DENISOVA	{"email": "denisova_s-1979@postgrespro.ru", "phone": "+70174006948"}
0005432783500	8FA45C	5424 831686	TATYANA POPOVA	{"email": "popova_tatyana101973@postgrespro.ru", "phone": "+70933883739"}
0005432783501	19D7DF	7281 941899	ALEKSANDR ILIN	{"phone": "+70350823874"}
0005432783502	4FC75A	9772 780427	DMITRIY KAZAKOV	{"email": "kazakov_d-021977@postgrespro.ru", "phone": "+70559161639"}
0005432783503	4FC75A	1796 561099	ALEKSANDR ABRAMOV	{"phone": "+70238083907"}
0005432783504	58AF32	4904 856817	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva_03071967@postgrespro.ru", "phone": "+70505058721"}
0005432783505	58AF32	9352 359236	ZOYA GORBUNOVA	{"email": "gorbunova.zoya-1969@postgrespro.ru", "phone": "+70734114578"}
0005432783506	50CADF	7115 811009	EKATERINA MOISEEVA	{"phone": "+70329920942"}
0005432783507	5FCC4E	9748 607290	DMITRIY CHERNOV	{"phone": "+70421695611"}
0005432783508	C86709	2919 309749	OLEG MOROZOV	{"email": "o.morozov111976@postgrespro.ru", "phone": "+70095422404"}
0005432783509	C86709	2383 707705	EKATERINA KONDRATEVA	{"phone": "+70022648992"}
0005432783510	935D04	0764 002581	SVETLANA MOROZOVA	{"phone": "+70310905092"}
0005432783511	935D04	0974 472237	YAROSLAV OSIPOV	{"phone": "+70895132807"}
0005432783512	9F34F8	0105 871174	MIKHAIL NIKOLAEV	{"email": "m-nikolaev.1971@postgrespro.ru", "phone": "+70634816130"}
0005432783513	9F34F8	3544 761667	ALINA ALEKSANDROVA	{"email": "aleksandrova.a-1985@postgrespro.ru", "phone": "+70799071434"}
0005432783514	BFBBD9	0063 265333	VADIM VLASOV	{"email": "v_vlasov.06021969@postgrespro.ru", "phone": "+70071402392"}
0005432783515	C43826	7868 652656	YURIY FEDOTOV	{"phone": "+70678384191"}
0005432783516	384CED	5329 185611	MARIYA KALININA	{"phone": "+70599602627"}
0005432783517	384CED	1109 226657	IRINA NAZAROVA	{"phone": "+70252665083"}
0005432783518	CB64A8	7731 178313	ANNA KUZNECOVA	{"email": "a.kuznecova.26061978@postgrespro.ru", "phone": "+70391994515"}
0005432783519	CB64A8	8627 480373	LYUDMILA SOKOLOVA	{"email": "lsokolova-1977@postgrespro.ru", "phone": "+70252243227"}
0005432783520	CB64A8	9716 125502	IRINA VOLKOVA	{"email": "volkova-i.21031968@postgrespro.ru", "phone": "+70350566653"}
0005432783521	2A922B	6199 199599	GENNADIY DMITRIEV	{"email": "dmitriev.g_09021976@postgrespro.ru", "phone": "+70334691593"}
0005432783522	9AEDAD	7048 084644	ARINA MIKHAYLOVA	{"email": "mikhaylova_a-1972@postgrespro.ru", "phone": "+70114261137"}
0005432783523	9AEDAD	5454 579763	DANIIL ALEKSANDROV	{"phone": "+70954406648"}
0005432783524	C5148A	7656 660268	EVGENIYA VOLKOVA	{"email": "evgeniyavolkova021977@postgrespro.ru", "phone": "+70318407936"}
0005432783525	C5148A	7144 055139	ALEKSANDR MAKAROV	{"phone": "+70493079827"}
0005432783526	866674	6932 722232	OLEG MIKHAYLOV	{"phone": "+70498310499"}
0005432783527	866674	4752 111676	ARTEM MOROZOV	{"phone": "+70776553435"}
0005432783528	866674	2519 404223	BORIS KUZNECOV	{"phone": "+70685904393"}
0005432783529	99A78D	3620 948452	VIKTOR ZAYCEV	{"email": "viktor_zaycev-06041981@postgrespro.ru", "phone": "+70250088710"}
0005432783530	9A7D41	1206 927859	TATYANA POLYAKOVA	{"email": "polyakova.tatyana_01091970@postgrespro.ru", "phone": "+70092831080"}
0005432783531	B8A2ED	5054 109870	TAMARA ANTONOVA	{"email": "tamara_antonova_01021971@postgrespro.ru", "phone": "+70745343073"}
0005432783532	F631ED	7171 963765	ALEKSANDR DENISOV	{"phone": "+70849892754"}
0005432783533	CC4F61	9703 822003	LYUDMILA ROMANOVA	{"email": "romanova_l.101994@postgrespro.ru", "phone": "+70327734337"}
0005432783534	E2D0A9	3614 491409	SERGEY MELNIKOV	{"phone": "+70055666042"}
0005432783535	70BFCD	3809 746958	ALEKSANDRA MATVEEVA	{"phone": "+70408026508"}
0005432783536	70BFCD	2218 285077	VENERA MAKAROVA	{"phone": "+70655472762"}
0005432783537	70BFCD	8104 258091	LYUBOV RODIONOVA	{"email": "rodionoval-1972@postgrespro.ru", "phone": "+70894164952"}
0005432783538	301A34	8148 171382	SERGEY NIKOLAEV	{"email": "nikolaev.s.101974@postgrespro.ru", "phone": "+70038778960"}
0005432783539	976015	4925 568373	IVAN ALEKSANDROV	{"email": "aleksandrov-i.1981@postgrespro.ru", "phone": "+70753283438"}
0005432783540	C46459	6252 935097	VALENTINA SMIRNOVA	{"email": "valentina_smirnova06061975@postgrespro.ru", "phone": "+70127899525"}
0005432783541	C46459	7760 861134	ANASTASIYA ILINA	{"phone": "+70361691922"}
0005432783542	A3E78A	7201 285946	ANDREY KOZLOV	{"phone": "+70906296679"}
0005432783543	B11176	9856 918949	ALLA FOMINA	{"email": "a.fomina.03111984@postgrespro.ru", "phone": "+70136383989"}
0005432783544	FC949B	3449 660158	ELENA FADEEVA	{"email": "efadeeva011973@postgrespro.ru", "phone": "+70132539599"}
0005432783545	95627F	0422 587382	TATYANA KULIKOVA	{"phone": "+70601254963"}
0005432783546	E5251B	2244 484334	MAKSIM KUDRYASHOV	{"email": "kudryashov-m-031965@postgrespro.ru", "phone": "+70084774855"}
0005432783547	E5251B	9311 961817	SERGEY FEDOROV	{"email": "sergey.fedorov14021980@postgrespro.ru", "phone": "+70706982759"}
0005432783548	6E3B8F	9109 526152	SVETLANA KRASNOVA	{"email": "s-krasnova.21041965@postgrespro.ru", "phone": "+70308097961"}
0005432783549	36D6E9	9117 814117	ANZHELA LEBEDEVA	{"phone": "+70887393914"}
0005432783550	EE5040	5979 715205	ANASTASIYA NAZAROVA	{"phone": "+70412817556"}
0005432783551	FB67A2	2112 462824	YULIYA KONDRATEVA	{"email": "kondrateva_y1968@postgrespro.ru", "phone": "+70128637343"}
0005432783552	FB67A2	3704 893463	TATYANA KUZNECOVA	{"phone": "+70614994534"}
0005432783553	095725	4189 886382	SERGEY MAKSIMOV	{"phone": "+70028385442"}
0005432783554	7CCE24	9326 949330	OLGA IVANOVA	{"email": "olga_ivanova_081964@postgrespro.ru", "phone": "+70338195530"}
0005432783555	B01EE2	1595 107589	GALINA KUDRYASHOVA	{"phone": "+70269102883"}
0005432783556	982527	7445 915334	ELVIRA FILIPPOVA	{"phone": "+70760818323"}
0005432783557	982527	0450 483421	NIKOLAY GERASIMOV	{"phone": "+70069581788"}
0005432783558	D6B5E0	5556 134624	ARTEM STEPANOV	{"phone": "+70975047956"}
0005432783559	B9A645	3214 970987	STANISLAV VOROBEV	{"email": "s-vorobev.1977@postgrespro.ru", "phone": "+70228650243"}
0005432783560	B9A645	5769 491804	TAMARA DENISOVA	{"phone": "+70650657480"}
0005432783561	82719B	7820 188486	VLADIMIR NIKITIN	{"phone": "+70416628986"}
0005432783562	82719B	5907 427918	ANASTASIYA SOROKINA	{"email": "sorokina-anastasiya.12061980@postgrespro.ru", "phone": "+70074375044"}
0005432783563	1B0F53	7811 948478	IGOR KUDRYASHOV	{"email": "kudryashovigor.20071983@postgrespro.ru", "phone": "+70341273343"}
0005432783564	1B0F53	6684 279029	ANNA ZHURAVLEVA	{"email": "anna.zhuravleva.08071969@postgrespro.ru", "phone": "+70686146638"}
0005432783565	6C2C27	7632 703639	ILDAR FROLOV	{"phone": "+70923926185"}
0005432783566	6C2C27	1773 919129	ALIYA KOROLEVA	{"email": "aliyakoroleva-031982@postgrespro.ru", "phone": "+70821931443"}
0005432783567	9A96A4	0282 878795	ANTON VOLKOV	{"email": "volkov_anton.01031964@postgrespro.ru", "phone": "+70953284819"}
0005432783568	1FF51F	9734 180515	ROMAN KOZLOV	{"email": "roman_kozlov-111974@postgrespro.ru", "phone": "+70000033098"}
0005432783569	C84D4E	9221 825151	OKSANA SOROKINA	{"email": "oksanasorokina-01111968@postgrespro.ru", "phone": "+70791967594"}
0005432783570	C84D4E	3536 407125	ARKADIY TIKHONOV	{"phone": "+70430375306"}
0005432783571	9B7C13	5848 555553	SERGEY MEDVEDEV	{"phone": "+70472221418"}
0005432783740	24EB77	9138 818143	TATYANA KARPOVA	{"phone": "+70438131634"}
0005432783572	9B7C13	6668 608523	BORIS MATVEEV	{"email": "matveev.boris041964@postgrespro.ru", "phone": "+70733970634"}
0005432783573	808E1D	1867 086900	MARINA EFIMOVA	{"email": "m.efimova.071965@postgrespro.ru", "phone": "+70286111242"}
0005432783574	808E1D	6021 311465	VALENTINA MOISEEVA	{"phone": "+70644864530"}
0005432783575	AF39A3	4519 620699	VLADIMIR ISAEV	{"phone": "+70008800659"}
0005432783576	092378	7755 437586	YANA NIKITINA	{"email": "yana.nikitina_1984@postgrespro.ru", "phone": "+70332124369"}
0005432783577	1614F8	3066 674725	ANNA LAZAREVA	{"email": "a-lazareva-101953@postgrespro.ru", "phone": "+70006624244"}
0005432783578	1614F8	7797 795202	OLGA MELNIKOVA	{"email": "o-melnikova-1987@postgrespro.ru", "phone": "+70011525851"}
0005432783580	2EBD68	8358 791446	ANASTASIYA KISELEVA	{"email": "kiseleva_anastasiya-17021983@postgrespro.ru", "phone": "+70448329782"}
0005432783581	58FEED	8436 727845	DMITRIY YAKOVLEV	{"phone": "+70271053684"}
0005432783582	58FEED	7720 277635	ANATOLIY FILIPPOV	{"email": "anatoliy-filippov-101977@postgrespro.ru", "phone": "+70134806197"}
0005432783583	2BB258	2148 627191	ALEKSANDR MIKHAYLOV	{"phone": "+70208670374"}
0005432783584	4952B8	6678 583528	NIKITA ABRAMOV	{"phone": "+70248846207"}
0005432783585	04817D	1723 845701	MILENA KOZLOVA	{"email": "m_kozlova_28111977@postgrespro.ru", "phone": "+70465403108"}
0005432783586	04817D	6965 969630	NATALYA DAVYDOVA	{"email": "davydovan081976@postgrespro.ru", "phone": "+70706813701"}
0005432783587	B7AF68	4587 793828	MAKSIM POPOV	{"phone": "+70628302116"}
0005432783588	B7AF68	2758 925098	ALINA ZOTOVA	{"email": "alina_zotova.1975@postgrespro.ru", "phone": "+70688039158"}
0005432783589	336E43	5355 860333	VALENTINA MIKHAYLOVA	{"email": "v-mikhaylova-07011975@postgrespro.ru", "phone": "+70026069272"}
0005432783590	6016DF	1769 819239	LYUDMILA KISELEVA	{"email": "lyudmila.kiseleva-28031968@postgrespro.ru", "phone": "+70542466467"}
0005432783591	6016DF	6637 255309	GALINA MASLOVA	{"email": "maslova_galina-1974@postgrespro.ru", "phone": "+70716660589"}
0005432783592	A78610	7100 412437	ALEKSEY BELOV	{"email": "belov.a_1964@postgrespro.ru", "phone": "+70232610149"}
0005432783593	8D58CB	7573 922788	NIKOLAY SOROKIN	{"email": "sorokin.nikolay-021975@postgrespro.ru", "phone": "+70393353352"}
0005432783594	8D58CB	5988 273620	VLADIMIR FOMIN	{"email": "fomin_vladimir.1968@postgrespro.ru", "phone": "+70194795765"}
0005432783595	03BE05	7233 679055	OLGA VOROBEVA	{"phone": "+70922611653"}
0005432783596	03BE05	1850 262015	SOFYA ZHURAVLEVA	{"phone": "+70323969859"}
0005432783597	190711	6643 053501	ALEKSANDR ANDREEV	{"phone": "+70007751017"}
0005432783598	190711	3138 704524	ALEKSEY SCHERBAKOV	{"phone": "+70986431490"}
0005432783599	09F1B9	8835 887015	GALINA DAVYDOVA	{"email": "galina_davydova.1963@postgrespro.ru", "phone": "+70709424030"}
0005432783600	68A538	0764 997839	SERGEY KAZAKOV	{"phone": "+70944739745"}
0005432783601	68A538	4222 042084	GULNARA NIKOLAEVA	{"email": "gnikolaeva-1963@postgrespro.ru", "phone": "+70555096231"}
0005432783602	68A538	6708 132957	ANDREY FEDOROV	{"phone": "+70375901111"}
0005432783603	3EACFA	3876 559723	DANIIL ALEKSANDROV	{"phone": "+70408218435"}
0005432783604	7CE630	0829 683415	GALINA GRISHINA	{"phone": "+70589841085"}
0005432783605	C0FAB4	2167 070648	ALEKSEY FROLOV	{"phone": "+70391065873"}
0005432783606	C0FAB4	0206 781209	GALINA BARANOVA	{"email": "baranova_galina17041973@postgrespro.ru", "phone": "+70390325564"}
0005432783607	943045	5662 917211	ALEKSANDR ZAYCEV	{"phone": "+70130064891"}
0005432783608	C956BA	4841 401091	IVAN TARASOV	{"email": "tarasov_i-22051979@postgrespro.ru", "phone": "+70080972087"}
0005432783609	05DB9B	6875 733993	MATVEY VASILEV	{"email": "vasilevm_03051974@postgrespro.ru", "phone": "+70159267828"}
0005432783610	30103C	4791 975089	NINA VOROBEVA	{"email": "vorobeva-nina031977@postgrespro.ru", "phone": "+70495456670"}
0005432783611	30103C	7576 188984	NATALYA KONDRATEVA	{"phone": "+70314819363"}
0005432783612	29357D	1504 828841	ANASTASIYA ROMANOVA	{"email": "romanova.anastasiya_071986@postgrespro.ru", "phone": "+70445163654"}
0005432783613	C45911	5157 227486	ANDREY GERASIMOV	{"email": "a-gerasimov-17051965@postgrespro.ru", "phone": "+70745967730"}
0005432783614	F51C17	3096 980984	ALEKSANDR FEDOROV	{"phone": "+70679178285"}
0005432783615	BCA6BF	6116 000539	EVGENIY SOLOVEV	{"email": "solovev.e-051967@postgrespro.ru", "phone": "+70794936479"}
0005432783616	5A88F9	8485 072294	VLADIMIR KUZNECOV	{"phone": "+70456307615"}
0005432783617	5A88F9	6713 768225	IRINA ABRAMOVA	{"email": "abramova_irina-1978@postgrespro.ru", "phone": "+70782072769"}
0005432783618	E6E901	6367 301206	TATYANA BELYAEVA	{"email": "tatyanabelyaeva.03011965@postgrespro.ru", "phone": "+70303386604"}
0005432783619	6776D0	0637 220136	LYUBOV PAVLOVA	{"phone": "+70541271128"}
0005432783620	E4D158	4889 874529	NELLI DENISOVA	{"email": "denisova.n-23101969@postgrespro.ru", "phone": "+70781151706"}
0005432783621	66B80D	1132 555837	IGOR SEMENOV	{"email": "semenov-igor.1970@postgrespro.ru", "phone": "+70695283450"}
0005432783622	D96C86	7444 518710	EKATERINA FEDOROVA	{"phone": "+70022605611"}
0005432783623	E48208	0080 242147	SERGEY MAKSIMOV	{"email": "s-maksimov-1976@postgrespro.ru", "phone": "+70733686521"}
0005432783624	E48208	8644 040117	MARIYA ZHUKOVA	{"phone": "+70558126815"}
0005432783625	356B6B	9349 333636	ARTEM MIKHAYLOV	{"phone": "+70684033704"}
0005432783626	6EA983	2498 552728	ARTEM KRASNOV	{"email": "a-krasnov-1974@postgrespro.ru", "phone": "+70340189942"}
0005432783627	6EA983	5241 082726	ELIZAVETA FILIPPOVA	{"phone": "+70536635242"}
0005432783628	6EA983	5240 478152	MARIYA MEDVEDEVA	{"email": "mariya-medvedeva1986@postgrespro.ru", "phone": "+70162542994"}
0005432783629	4948D3	9662 208091	ANASTASIYA SEMENOVA	{"email": "semenovaa.1964@postgrespro.ru", "phone": "+70756549147"}
0005432783630	4948D3	6865 698541	KONSTANTIN DENISOV	{"phone": "+70173115775"}
0005432783631	7C3410	1848 332589	IVAN KUZMIN	{"email": "kuzmin_i.1965@postgrespro.ru", "phone": "+70994206870"}
0005432783632	DDEE56	1252 378088	OLGA IVANOVA	{"phone": "+70947644472"}
0005432783633	DDEE56	7781 572644	VITALIY TIKHONOV	{"email": "tikhonov_vitaliy.1976@postgrespro.ru", "phone": "+70877442834"}
0005432783634	951BBD	1492 373096	MIKHAIL GERASIMOV	{"phone": "+70264774140"}
0005432783635	5688BB	7616 690047	DARYA BORISOVA	{"email": "darya.borisova1976@postgrespro.ru", "phone": "+70056946050"}
0005432783636	AD1684	0797 852110	GALINA FEDOROVA	{"phone": "+70643247414"}
0005432783637	AD1684	3917 977885	ALEKSANDR VLASOV	{"phone": "+70280198899"}
0005432783638	70B5A2	0756 820897	OLEG SMIRNOV	{"email": "oleg_smirnov-1957@postgrespro.ru", "phone": "+70734733648"}
0005432783639	70B5A2	7204 577596	ELENA NIKOLAEVA	{"email": "enikolaeva_1966@postgrespro.ru", "phone": "+70448861765"}
0005432783640	65EDC3	2308 763700	NATALYA VLASOVA	{"phone": "+70753600924"}
0005432783641	CF92DB	9097 329182	VASILIY FEDOTOV	{"phone": "+70607070887"}
0005432783642	CF92DB	4576 372980	ANTONINA MAKAROVA	{"phone": "+70301060661"}
0005432783643	B1D5C6	2808 826220	VALENTINA POPOVA	{"email": "vpopova-121967@postgrespro.ru", "phone": "+70594977404"}
0005432783644	EA96FF	6203 156548	VYACHESLAV NOVIKOV	{"email": "vnovikov_02021989@postgrespro.ru", "phone": "+70903706873"}
0005432783645	EA96FF	5674 150066	SERGEY KARPOV	{"email": "karpov_sergey17031968@postgrespro.ru", "phone": "+70864391526"}
0005432783646	23D0FD	2384 973939	MIKHAIL MAKAROV	{"email": "m-makarov16101971@postgrespro.ru", "phone": "+70353437250"}
0005432783647	ED336A	3492 398966	VLADIMIR POPOV	{"phone": "+70836234350"}
0005432783648	92A54E	9912 126068	EVGENIY ANTONOV	{"email": "antonov-evgeniy_1974@postgrespro.ru", "phone": "+70323506697"}
0005432783649	92A54E	5236 128947	DMITRIY BELOV	{"email": "d-belov_13101963@postgrespro.ru", "phone": "+70364083755"}
0005432783650	92A54E	2754 995974	VYACHESLAV KUZNECOV	{"phone": "+70006246935"}
0005432783651	18A138	4413 337999	NIKOLAY VASILEV	{"phone": "+70886143396"}
0005432783652	310E1C	2841 676064	ELEONORA SERGEEVA	{"phone": "+70400223357"}
0005432783653	DE23B5	5638 226580	SERGEY KUZNECOV	{"phone": "+70787063676"}
0005432783654	DE23B5	8870 279660	NIKOLAY BARANOV	{"email": "n.baranov.1967@postgrespro.ru", "phone": "+70207266831"}
0005432783655	AC0A03	4891 521943	GENNADIY AFANASEV	{"phone": "+70570885478"}
0005432783656	9DBB92	6100 571017	EDGAR ZAYCEV	{"email": "zaycev.e.09051965@postgrespro.ru", "phone": "+70665478341"}
0005432783657	DD9F60	9242 795745	DENIS ANDREEV	{"phone": "+70964588655"}
0005432783658	DD9F60	2004 297579	DMITRIY PETROV	{"email": "dmitriy_petrov081969@postgrespro.ru", "phone": "+70670756801"}
0005432783659	20DE3B	4596 165563	VALENTINA FEDOROVA	{"phone": "+70358472334"}
0005432783660	72C418	2962 004811	EGOR KUZNECOV	{"phone": "+70242671987"}
0005432783661	879365	5137 511325	TATYANA NIKITINA	{"phone": "+70464755175"}
0005432783662	28C2E8	7947 434279	LILIYA SOKOLOVA	{"phone": "+70302300291"}
0005432783663	866629	0654 234772	ILDAR BARANOV	{"phone": "+70847267505"}
0005432783664	866629	3385 905023	SERGEY ZAKHAROV	{"phone": "+70123213339"}
0005432783665	615F97	7839 743930	FEDOR TIKHONOV	{"email": "tikhonovf.03041974@postgrespro.ru", "phone": "+70948731362"}
0005432783666	615F97	2370 909945	EGOR PETROV	{"phone": "+70262429324"}
0005432783667	879FD8	9598 332741	ALEKSANDR PETROV	{"phone": "+70986827158"}
0005432783668	879FD8	0584 985764	GALINA ALEKSANDROVA	{"email": "aleksandrovag.27031978@postgrespro.ru", "phone": "+70155886400"}
0005432783669	859992	2842 685470	STEPAN PETROV	{"email": "petrov.stepan_1969@postgrespro.ru", "phone": "+70744273936"}
0005432783670	C69AEE	1673 436255	VERONIKA ZAYCEVA	{"phone": "+70372347494"}
0005432783671	8C5DDC	5353 279248	ANDREY VOLKOV	{"phone": "+70565769909"}
0005432783672	BC1998	3802 531119	SVETLANA KUZMINA	{"email": "kuzmina_s-29091971@postgrespro.ru", "phone": "+70458668518"}
0005432783673	BC1998	0979 656168	MIKHAIL ZAYCEV	{"phone": "+70071698663"}
0005432783674	D6ACCF	8027 689909	ANASTASIYA SAVELEVA	{"email": "saveleva_a-23051971@postgrespro.ru", "phone": "+70821151117"}
0005432783675	5BEA0E	2049 367461	DARYA KRASNOVA	{"email": "d.krasnova-1970@postgrespro.ru", "phone": "+70865671895"}
0005432783676	5BEA0E	5288 226066	VLADIMIR VASILEV	{"phone": "+70735427593"}
0005432783677	76B4CF	7328 767294	OLGA DAVYDOVA	{"email": "davydova_olga_1976@postgrespro.ru", "phone": "+70330078115"}
0005432783678	39F9BD	4175 372163	VLADIMIR OSIPOV	{"phone": "+70751765094"}
0005432783679	8D0A3B	4318 783027	NATALYA ABRAMOVA	{"email": "abramovan-19111973@postgrespro.ru", "phone": "+70339966225"}
0005432783680	B5C589	8651 596555	VLADIMIR ZHUKOV	{"email": "zhukovvladimir_01021975@postgrespro.ru", "phone": "+70421721596"}
0005432783681	C39709	0121 206822	GALINA ANISIMOVA	{"phone": "+70094694119"}
0005432783682	C39709	5088 623506	MARIYA KUZNECOVA	{"phone": "+70988630200"}
0005432783683	EC110B	1532 241566	YURIY STEPANOV	{"email": "stepanov_y111975@postgrespro.ru", "phone": "+70397199896"}
0005432783684	E81C58	0988 766275	PAVEL SOROKIN	{"phone": "+70823248331"}
0005432783685	BBE633	3752 620492	ANDREY PETROV	{"email": "petrov_andrey_15021960@postgrespro.ru", "phone": "+70984011655"}
0005432783686	BBE633	3103 117213	ANASTASIYA IVANOVA	{"email": "ivanova.anastasiya_101969@postgrespro.ru", "phone": "+70151787959"}
0005432783687	D47426	5211 859760	SERGEY FEDOROV	{"email": "sergey-fedorov-111960@postgrespro.ru", "phone": "+70949722772"}
0005432783688	C6669C	4594 349127	IGOR TIKHONOV	{"phone": "+70896350066"}
0005432783689	C6669C	1447 206393	TATYANA LAZAREVA	{"email": "lazarevat-13081962@postgrespro.ru", "phone": "+70235797384"}
0005432783690	C2AA89	7547 933190	ANDREY MAKSIMOV	{"phone": "+70582192625"}
0005432783691	DC896D	5537 486544	ELIZAVETA TIKHONOVA	{"email": "tikhonova.e-26061979@postgrespro.ru", "phone": "+70287489916"}
0005432783692	44522B	6110 200316	MIKHAIL FEDOTOV	{"email": "mfedotov-051975@postgrespro.ru", "phone": "+70901349912"}
0005432783693	0FE692	0613 057138	MARINA MATVEEVA	{"email": "matveeva.m.021980@postgrespro.ru", "phone": "+70506072120"}
0005432783694	0FE692	8871 490429	ARTEM KUZMIN	{"phone": "+70778552977"}
0005432783695	5F67E6	7507 072746	ALEKSEY YAKOVLEV	{"phone": "+70768184962"}
0005432783696	5F67E6	7617 444882	NINA YUDINA	{"email": "nina-yudina16051978@postgrespro.ru", "phone": "+70990955258"}
0005432783697	546D9D	8472 416555	MIKHAIL ZHURAVLEV	{"phone": "+70990649043"}
0005432783698	546D9D	9770 077426	ALEKSANDR ZAYCEV	{"email": "zayceva-09061970@postgrespro.ru", "phone": "+70033667119"}
0005432783699	71F3B1	3797 589496	YULIYA ANISIMOVA	{"email": "yuliyaanisimova-071989@postgrespro.ru", "phone": "+70731371907"}
0005432783700	4856BD	3703 668524	YULIYA TROFIMOVA	{"email": "y_trofimova.1970@postgrespro.ru", "phone": "+70694051853"}
0005432783701	46076B	5183 922068	EKATERINA VOROBEVA	{"email": "vorobeva.ekaterina22011962@postgrespro.ru", "phone": "+70542318686"}
0005432783702	4DBD09	9288 488637	VLADIMIR KONOVALOV	{"email": "konovalovvladimir-061976@postgrespro.ru", "phone": "+70001650600"}
0005432783703	E25E2E	3168 469220	OLGA GUSEVA	{"email": "o-guseva-1969@postgrespro.ru", "phone": "+70643395885"}
0005432783704	E25E2E	2681 033647	ARTEMIY RODIONOV	{"email": "a.rodionov-1972@postgrespro.ru", "phone": "+70100301846"}
0005432783705	E25E2E	1995 676500	NIKOLAY MAKAROV	{"email": "nmakarov101979@postgrespro.ru", "phone": "+70353165385"}
0005432783706	C11FE4	3154 614950	NATALYA VLASOVA	{"phone": "+70348834351"}
0005432783707	BBA231	0849 276972	VALENTINA KAZAKOVA	{"phone": "+70416979131"}
0005432783708	BBA231	9565 087959	ROMAN BONDARENKO	{"phone": "+70158459203"}
0005432783709	0CC2F4	2935 359365	VIKTOR SMIRNOV	{"email": "smirnov_viktor.09031973@postgrespro.ru", "phone": "+70448184352"}
0005432783710	0CC2F4	6219 202629	LIDIYA NAUMOVA	{"phone": "+70467188988"}
0005432783711	D4660E	7747 091070	ALEKSEY NAZAROV	{"phone": "+70539150078"}
0005432783712	1E098D	8727 705398	VALENTINA MAKAROVA	{"email": "v-makarova-1961@postgrespro.ru", "phone": "+70888201027"}
0005432783713	C33F8E	0231 632403	ALEKSANDR BORISOV	{"phone": "+70886480152"}
0005432783714	C33F8E	7890 914732	OKSANA SCHERBAKOVA	{"email": "o_scherbakova_1967@postgrespro.ru", "phone": "+70676944099"}
0005432783715	F44045	6027 676745	IRINA KUDRYASHOVA	{"email": "kudryashova.irina021976@postgrespro.ru", "phone": "+70709583226"}
0005432783716	F44045	6956 398878	VALERIYA TROFIMOVA	{"phone": "+70607975970"}
0005432783717	CB29FD	7755 472636	ANATOLIY FROLOV	{"phone": "+70029315339"}
0005432783718	36E6D7	4089 942064	VIKTOR VASILEV	{"email": "vasilevv11101966@postgrespro.ru", "phone": "+70427865451"}
0005432783719	36E6D7	0419 946428	EVGENIY IVANOV	{"email": "evgeniy-ivanov_1968@postgrespro.ru", "phone": "+70436749480"}
0005432783720	3E8D5E	6678 880560	VLADISLAV PETROV	{"email": "v-petrov-081973@postgrespro.ru", "phone": "+70476007515"}
0005432783721	A4C25E	6443 997509	ALEKSANDR IVANOV	{"email": "a.ivanov1965@postgrespro.ru", "phone": "+70954122716"}
0005432783722	825FA6	1054 042172	YULIYA TARASOVA	{"email": "y-tarasova_1980@postgrespro.ru", "phone": "+70378663601"}
0005432783723	9A81DA	6505 425209	NIKOLAY VOROBEV	{"phone": "+70786073724"}
0005432783724	9A81DA	5097 702937	ANATOLIY BONDARENKO	{"email": "anatoliy-bondarenko.1962@postgrespro.ru", "phone": "+70199000333"}
0005432783725	C1AC65	6585 943205	EKATERINA EFREMOVA	{"email": "e_efremova_071969@postgrespro.ru", "phone": "+70702985821"}
0005432783726	0E7C1F	4573 567524	VIKTOR NOVIKOV	{"email": "viktor.novikov_1967@postgrespro.ru", "phone": "+70057118468"}
0005432783727	0E7C1F	9411 080939	KLAVDIYA MIKHAYLOVA	{"phone": "+70428334273"}
0005432783728	0E7C1F	6865 925401	TATYANA BOGDANOVA	{"phone": "+70369161838"}
0005432783729	AA041A	1628 551781	SERGEY BONDARENKO	{"email": "bondarenko-s_29061979@postgrespro.ru", "phone": "+70480363435"}
0005432783730	906DE2	4479 035332	NINA POPOVA	{"email": "popova-nina_23121979@postgrespro.ru", "phone": "+70818250534"}
0005432783731	906DE2	5553 988962	VITALIY SIDOROV	{"phone": "+70827151571"}
0005432783732	906DE2	1702 095029	VALERIYA ZHUKOVA	{"email": "vzhukova1970@postgrespro.ru", "phone": "+70627941542"}
0005432783733	8894FF	1749 391752	MARIYA DMITRIEVA	{"phone": "+70682754623"}
0005432783734	919E16	5141 722000	DARYA MOISEEVA	{"phone": "+70485208933"}
0005432783735	57C209	3539 753871	TATYANA MAKSIMOVA	{"email": "t.maksimova.27081976@postgrespro.ru", "phone": "+70670453727"}
0005432783736	F5E33F	9431 214700	YULIYA FROLOVA	{"email": "y-frolova-28111968@postgrespro.ru", "phone": "+70990860188"}
0005432783737	F5E33F	4442 565780	ALEKSANDR DMITRIEV	{"email": "dmitriev_a.01041971@postgrespro.ru", "phone": "+70216044625"}
0005432783738	F5E33F	4733 523158	ALEKSEY TARASOV	{"email": "tarasov.aleksey121982@postgrespro.ru", "phone": "+70576801559"}
0005432783739	6A4ED3	5696 045638	KSENIYA TROFIMOVA	{"phone": "+70686267786"}
0005432783741	24EB77	7652 926741	YURIY RODIONOV	{"phone": "+70580860073"}
0005432783742	24EB77	7394 176912	ALEKSANDR KUZMIN	{"email": "kuzmin.a_16041973@postgrespro.ru", "phone": "+70514728997"}
0005432783743	0B6FB3	9939 253101	GEORGIY SOROKIN	{"phone": "+70159913620"}
0005432783744	CAEDE2	9485 110895	ROMAN KUZNECOV	{"email": "roman.kuznecov-05061986@postgrespro.ru", "phone": "+70210869305"}
0005432783745	CAEDE2	9990 564963	NINA POPOVA	{"email": "n_popova_13091971@postgrespro.ru", "phone": "+70053245705"}
0005432783746	AC34CF	4077 903572	ALEKSEY MAKSIMOV	{"email": "maksimov-a20121963@postgrespro.ru", "phone": "+70916395170"}
0005432783747	232ADB	5884 530966	ALEKSANDR FEDOTOV	{"email": "fedotov_a_1960@postgrespro.ru", "phone": "+70059053408"}
0005432783748	94D7BA	2888 796421	OLEG GAVRILOV	{"email": "oleg_gavrilov.1969@postgrespro.ru", "phone": "+70426227942"}
0005432783749	94D7BA	7138 226093	TAISIYA NESTEROVA	{"email": "nesterova_taisiya.1982@postgrespro.ru", "phone": "+70336771363"}
0005432783750	397FB0	9760 937410	MARINA NESTEROVA	{"phone": "+70656211957"}
0005432783751	397FB0	1926 468573	NELLI ANISIMOVA	{"phone": "+70284562244"}
0005432783752	84C643	1436 944911	SVETLANA GRISHINA	{"phone": "+70703053312"}
0005432783753	B2285A	9803 434702	OLGA KOROLEVA	{"email": "okoroleva_041969@postgrespro.ru", "phone": "+70455100522"}
0005432783754	B2285A	8291 233891	NATALYA MIKHAYLOVA	{"phone": "+70226528191"}
0005432783755	5335F3	8206 270573	ROMAN IVANOV	{"phone": "+70914606219"}
0005432783756	5335F3	8796 279763	NATALYA IVANOVA	{"email": "ivanova_natalya.24121980@postgrespro.ru", "phone": "+70302645251"}
0005432783757	A2167B	4720 613116	VALENTIN GORBUNOV	{"email": "valentin.gorbunov_25011970@postgrespro.ru", "phone": "+70659939669"}
0005432783758	A2167B	3515 501405	SERGEY MAKSIMOV	{"phone": "+70786621198"}
0005432783759	BD73E6	7162 519000	ANDREY NIKITIN	{"email": "nikitina051978@postgrespro.ru", "phone": "+70221108056"}
0005432783760	A00435	6324 488626	ANDREY AFANASEV	{"phone": "+70981164996"}
0005432783761	E1DFC9	9239 821015	SERGEY FILIPPOV	{"email": "sergey.filippov1973@postgrespro.ru", "phone": "+70214765628"}
0005432783762	522E03	8959 672059	NIKOLAY POPOV	{"email": "n.popov_071972@postgrespro.ru", "phone": "+70558730540"}
0005432783763	522E03	4721 249267	ALIYA SERGEEVA	{"phone": "+70549675434"}
0005432783764	A9A4E1	7747 741960	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr1972@postgrespro.ru", "phone": "+70829537903"}
0005432783765	CEE068	3381 770927	ALEKSANDR MAKSIMOV	{"phone": "+70110264708"}
0005432783766	8F77FA	5095 981870	VYACHESLAV GAVRILOV	{"email": "vyacheslav_gavrilov_1967@postgrespro.ru", "phone": "+70291074993"}
0005432783767	8F77FA	7905 894540	VALENTINA MOISEEVA	{"phone": "+70215012739"}
0005432783768	F8C65A	0283 877109	NADEZHDA KOZLOVA	{"email": "nadezhda-kozlova1970@postgrespro.ru", "phone": "+70057290574"}
0005432783769	F8C65A	5240 082200	VIKTOR EGOROV	{"email": "egorovv-22081973@postgrespro.ru", "phone": "+70877021533"}
0005432783770	525FB1	9173 076947	OLESYA FEDOROVA	{"phone": "+70901474265"}
0005432783771	38D573	7036 573579	VADIM SAVELEV	{"phone": "+70779524641"}
0005432783772	94BC10	6085 742044	IGOR ZHURAVLEV	{"phone": "+70781283589"}
0005432783773	50C1B2	3810 112930	DMITRIY GRIGOREV	{"email": "grigorevdmitriy.28111977@postgrespro.ru", "phone": "+70195168037"}
0005432783774	CD3C5B	6340 641664	ALEKSEY ALEKSEEV	{"phone": "+70731232892"}
0005432783775	CD3C5B	2911 081896	VALERIY ISAEV	{"phone": "+70529464116"}
0005432783776	AB3E7D	2111 490159	ELENA GUSEVA	{"email": "guseva.elena-28111974@postgrespro.ru", "phone": "+70665788923"}
0005432783777	4DEA6A	8586 359243	ELENA KRASNOVA	{"email": "krasnova_elena_03071971@postgrespro.ru", "phone": "+70786582927"}
0005432783778	BA2243	0027 261713	MARINA ZAKHAROVA	{"email": "zakharova-m_13071971@postgrespro.ru", "phone": "+70750952461"}
0005432783779	BA2243	6471 490762	TATYANA NIKITINA	{"phone": "+70178566189"}
0005432783780	BA2243	4085 536461	NATALYA EFIMOVA	{"email": "natalya_efimova_1981@postgrespro.ru", "phone": "+70690422170"}
0005432783781	E5B24F	0708 892359	YULIYA KAZAKOVA	{"email": "kazakova_y-091957@postgrespro.ru", "phone": "+70749879732"}
0005432783782	88260D	8831 470685	YULIYA KONOVALOVA	{"phone": "+70931857247"}
0005432783783	FFAF9B	2773 152735	DMITRIY ZAYCEV	{"phone": "+70160543094"}
0005432783784	FFAF9B	5744 836435	VITALIY KUZNECOV	{"phone": "+70267913861"}
0005432783785	7DA968	7513 914193	NIKOLAY SERGEEV	{"email": "sergeevn.19081976@postgrespro.ru", "phone": "+70036023650"}
0005432783786	57BF7A	0834 151874	ANTONINA NIKOLAEVA	{"email": "nikolaeva-antonina_1973@postgrespro.ru", "phone": "+70361587123"}
0005432783787	57BF7A	4155 556803	PAVEL ANTONOV	{"phone": "+70423554179"}
0005432783788	AACF48	0816 261289	ZINAIDA LUKYANOVA	{"email": "lukyanovaz-091971@postgrespro.ru", "phone": "+70132710094"}
0005432783789	771836	6659 605916	ANATOLIY KUDRYASHOV	{"phone": "+70090759646"}
0005432783790	6349CA	9127 396222	VIKTOR MIKHAYLOV	{"phone": "+70217048310"}
0005432783791	54663E	0114 188910	DMITRIY TIMOFEEV	{"email": "timofeevd.1973@postgrespro.ru", "phone": "+70412869894"}
0005432783792	026C73	1596 119389	EKATERINA SERGEEVA	{"phone": "+70522178720"}
0005432783793	386940	2163 155627	ALEKSEY BARANOV	{"email": "alekseybaranov-05121971@postgrespro.ru", "phone": "+70368700304"}
0005432783794	D47846	6621 932629	EVGENIY BARANOV	{"phone": "+70446797770"}
0005432783795	C1C447	6113 665456	EKATERINA ZAYCEVA	{"phone": "+70833476755"}
0005432783796	577475	7541 243064	ALEKSANDR FOMIN	{"email": "fomin.aleksandr_041954@postgrespro.ru", "phone": "+70451579089"}
0005432783797	BE6E9B	9022 506661	OLEG DENISOV	{"phone": "+70106558896"}
0005432783798	F99FEF	0352 515643	ALLA EFREMOVA	{"email": "a.efremova-20061976@postgrespro.ru", "phone": "+70567874615"}
0005432783799	BA3802	0652 080904	SERGEY NOVIKOV	{"phone": "+70155296458"}
0005432783800	BA3802	0346 143724	IVAN KUZMIN	{"phone": "+70658913737"}
0005432783801	ECA203	2684 405436	NINA ORLOVA	{"phone": "+70193265311"}
0005432783802	D8634E	5649 850259	LIDIYA DAVYDOVA	{"phone": "+70983756487"}
0005432783803	FBBC2A	1688 168773	NADEZHDA ERMAKOVA	{"email": "nadezhda-ermakova021972@postgrespro.ru", "phone": "+70184778230"}
0005432783804	53648C	0278 794819	ANTON MOROZOV	{"email": "morozov_anton-061961@postgrespro.ru", "phone": "+70339169062"}
0005432783805	53648C	7485 195372	NATALYA ZHUKOVA	{"phone": "+70029642184"}
0005432783806	099A4C	4766 220812	OLGA NESTEROVA	{"phone": "+70487596185"}
0005432783807	3CCA0B	7967 768280	EVDOKIYA KUZMINA	{"email": "kuzminae20101964@postgrespro.ru", "phone": "+70136687264"}
0005432783808	B9A5BC	7784 244166	RADIK POPOV	{"email": "radikpopov-24061987@postgrespro.ru", "phone": "+70061051556"}
0005432783809	77C08A	0326 625895	SVETLANA KOROLEVA	{"phone": "+70828535036"}
0005432783810	77C08A	7889 179594	LILIYA NAUMOVA	{"phone": "+70180210424"}
0005432783811	7D4622	2103 556758	EKATERINA MIRONOVA	{"email": "ekaterina_mironova.26051971@postgrespro.ru", "phone": "+70740179033"}
0005432783812	7D4622	9258 508960	ELIZAVETA NIKITINA	{"email": "nikitinae_071971@postgrespro.ru", "phone": "+70113598167"}
0005432783813	D85785	0591 821732	SVETLANA LOGINOVA	{"email": "svetlana.loginova_13051969@postgrespro.ru", "phone": "+70614609116"}
0005432783814	EFD9E4	9839 804790	VERONIKA NOVIKOVA	{"email": "novikova_v-021984@postgrespro.ru", "phone": "+70871963611"}
0005432783815	3A0695	6998 397718	ANASTASIYA SOLOVEVA	{"email": "a.soloveva08021977@postgrespro.ru", "phone": "+70330118451"}
0005432783816	54F33F	5173 306664	EGOR KULIKOV	{"email": "kulikov_e-29011976@postgrespro.ru", "phone": "+70320027838"}
0005432783817	C8B035	3157 205423	SVETLANA GERASIMOVA	{"email": "gerasimova_s_091970@postgrespro.ru", "phone": "+70500555425"}
0005432783818	C8B035	9630 662011	OLEG IVANOV	{"email": "ivanovoleg-061975@postgrespro.ru", "phone": "+70146557765"}
0005432783821	1DDAA6	2844 956046	YURIY PAVLOV	{"email": "yuriy.pavlov1971@postgrespro.ru", "phone": "+70089835460"}
0005432783822	1DDAA6	2551 777560	ELENA KOROLEVA	{"phone": "+70853546783"}
0005432783823	683165	8244 629507	VLADIMIR VASILEV	{"email": "vladimirvasilev_1976@postgrespro.ru", "phone": "+70348236607"}
0005432783824	0AC028	2344 841524	SERGEY PAVLOV	{"email": "pavlov-s-03011970@postgrespro.ru", "phone": "+70775898353"}
0005432783825	25F51B	5277 501605	SERGEY MOROZOV	{"email": "s.morozov-121977@postgrespro.ru", "phone": "+70671921793"}
0005432783826	D2805B	5533 580286	FEDOR IVANOV	{"phone": "+70348524769"}
0005432783827	D2805B	9879 691297	ELENA ERMAKOVA	{"phone": "+70851979584"}
0005432783828	2242F0	5926 537918	ANTONINA VASILEVA	{"email": "vasileva.antonina-1965@postgrespro.ru", "phone": "+70055272353"}
0005432783829	2242F0	2883 961831	SERGEY ZHUKOV	{"email": "zhukov_sergey.28121978@postgrespro.ru", "phone": "+70578739946"}
0005432783830	02A88D	7405 339326	ARTEM KISELEV	{"email": "kiselev_a-051968@postgrespro.ru", "phone": "+70743014281"}
0005432783831	02A88D	4240 056892	RAISA POTAPOVA	{"email": "potapova-r.19051974@postgrespro.ru", "phone": "+70239590514"}
0005432783832	95ADB2	5745 516721	NINA STEPANOVA	{"email": "stepanova-nina_21091970@postgrespro.ru", "phone": "+70523079167"}
0005432783833	435B67	7604 758455	ELENA SEMENOVA	{"phone": "+70331385508"}
0005432783834	9B47FB	1354 390724	DMITRIY GERASIMOV	{"email": "dmitriy-gerasimov_101967@postgrespro.ru", "phone": "+70207715155"}
0005432783835	6131D5	0590 753548	LYUDMILA FILIPPOVA	{"email": "lyudmila-filippova-30111970@postgrespro.ru", "phone": "+70521850977"}
0005432783836	47BEAA	7712 916633	EVGENIY TARASOV	{"phone": "+70676688640"}
0005432783837	6DF0C3	6756 487173	VADIM ZHUKOV	{"email": "v-zhukov_031974@postgrespro.ru", "phone": "+70032528680"}
0005432783838	76D68D	7624 233316	NINA ZAYCEVA	{"email": "zaycevan-1969@postgrespro.ru", "phone": "+70328008800"}
0005432783839	76D68D	9817 077754	MARINA FROLOVA	{"email": "frolovamarina051975@postgrespro.ru", "phone": "+70403733688"}
0005432783840	34CEB3	1957 396343	OLGA GUSEVA	{"phone": "+70631694272"}
0005432783841	34CEB3	0574 430239	ANNA FILIPPOVA	{"email": "filippovaa_06101967@postgrespro.ru", "phone": "+70130136633"}
0005432783842	D7B2C6	7569 781066	ALEKSANDR ZAKHAROV	{"phone": "+70738085238"}
0005432783843	637372	3505 534445	MAKSIM PAVLOV	{"email": "pavlov.m041969@postgrespro.ru", "phone": "+70228775513"}
0005432783844	83F179	9482 694836	VIKTOR ANTONOV	{"phone": "+70840946027"}
0005432783845	83F179	6223 366893	EVGENIY GERASIMOV	{"email": "gerasimov.e-17051968@postgrespro.ru", "phone": "+70546894986"}
0005432783846	75C62A	0978 836653	VLADIMIR NAZAROV	{"email": "vladimir-nazarov.1968@postgrespro.ru", "phone": "+70905284862"}
0005432783847	1EAE50	4700 633826	RUSLAN KOZLOV	{"phone": "+70016650236"}
0005432783848	9042F0	4399 540554	IVAN VASILEV	{"phone": "+70747469512"}
0005432783849	E00D81	9606 189558	TATYANA ISAEVA	{"phone": "+70065015805"}
0005432783850	CAC057	1908 457079	KRISTINA NAZAROVA	{"email": "nazarova-k_29041976@postgrespro.ru", "phone": "+70981539145"}
0005432783851	4935B5	5689 654621	POLINA KOVALEVA	{"email": "kovaleva.polina-23111983@postgrespro.ru", "phone": "+70620364752"}
0005432783852	4935B5	1400 229668	OLGA NIKITINA	{"phone": "+70440296780"}
0005432783853	7C8495	9381 811092	EKATERINA KOZLOVA	{"email": "kozlova_e.1970@postgrespro.ru", "phone": "+70686226339"}
0005432783854	D6792A	6773 392914	KSENIYA ZAKHAROVA	{"email": "k_zakharova.1975@postgrespro.ru", "phone": "+70704675185"}
0005432783855	BBAC11	5497 001693	GULFIYA MOROZOVA	{"phone": "+70749536509"}
0005432783856	950D0A	1758 837383	ZHANNA DMITRIEVA	{"email": "dmitrievazhanna.1983@postgrespro.ru", "phone": "+70368939258"}
0005432783857	AFD6C5	6154 079005	VERA VASILEVA	{"phone": "+70120318826"}
0005432783858	AFD6C5	3862 858280	EVGENIY KUZNECOV	{"email": "e_kuznecov.06071981@postgrespro.ru", "phone": "+70660552452"}
0005432783859	850932	9185 012538	ANATOLIY KRASNOV	{"phone": "+70934168519"}
0005432783860	CF2EC6	3405 036196	SEMEN KUZNECOV	{"phone": "+70171163692"}
0005432783861	F89114	1422 661408	ANTONINA ABRAMOVA	{"email": "abramova.a-03031972@postgrespro.ru", "phone": "+70808175484"}
0005432783862	05F1E7	6146 063532	VLADISLAV MIKHAYLOV	{"phone": "+70557105806"}
0005432783863	05F1E7	5419 346631	ALEKSANDR GUSEV	{"phone": "+70111022406"}
0005432783864	3A08E2	5685 609945	VLADA NIKOLAEVA	{"email": "nikolaeva.vlada_1971@postgrespro.ru", "phone": "+70658546128"}
0005432783865	3A08E2	1202 411691	VYACHESLAV PETROV	{"email": "petrovv.10121980@postgrespro.ru", "phone": "+70528639065"}
0005432783866	CFDEC8	6804 411384	MARINA EGOROVA	{"phone": "+70849957802"}
0005432783867	0DED05	1952 265354	ALEKSANDRA KONOVALOVA	{"email": "konovalova.aleksandra1971@postgrespro.ru", "phone": "+70519497037"}
0005432783868	0DED05	3439 628219	VLADIMIR ZAYCEV	{"phone": "+70609563053"}
0005432783869	8D1417	0005 369105	OLGA MAKAROVA	{"email": "makarova.o-1961@postgrespro.ru", "phone": "+70890340731"}
0005432783870	C32C04	4363 864970	DMITRIY VASILEV	{"phone": "+70134883947"}
0005432783871	C32C04	3325 447423	EKATERINA DAVYDOVA	{"email": "davydovae1981@postgrespro.ru", "phone": "+70567891216"}
0005432783872	87AB12	0273 897805	TAISIYA GORBUNOVA	{"phone": "+70050225469"}
0005432783873	11E066	6150 584873	VALENTINA GERASIMOVA	{"phone": "+70499642011"}
0005432783874	11E066	0452 992515	NADEZHDA SOKOLOVA	{"email": "nadezhda.sokolova021971@postgrespro.ru", "phone": "+70937965355"}
0005432783875	0F04A7	5634 223649	OLGA KARPOVA	{"email": "karpova_o-1973@postgrespro.ru", "phone": "+70193539731"}
0005432783876	95FE0F	7230 271508	ANZHELIKA FROLOVA	{"email": "frolova-a_1973@postgrespro.ru", "phone": "+70800918907"}
0005432783877	0FC1B8	1300 780052	NATALYA PETROVA	{"email": "petrova-natalya-02101968@postgrespro.ru", "phone": "+70663675424"}
0005432783878	74029F	7317 648960	VERA MIKHAYLOVA	{"phone": "+70921064750"}
0005432783879	116002	6793 821620	TATYANA IVANOVA	{"phone": "+70515154041"}
0005432783880	4CEF8C	1259 635358	ALEKSEY ABRAMOV	{"email": "abramov.a1984@postgrespro.ru", "phone": "+70925603783"}
0005432783881	E8C8ED	6006 753835	IRINA ORLOVA	{"phone": "+70713663039"}
0005432783882	E8C8ED	5726 828886	DENIS BARANOV	{"email": "d-baranov1973@postgrespro.ru", "phone": "+70148374334"}
0005432783883	E8C8ED	8655 880107	VALERIYA LEBEDEVA	{"email": "v-lebedeva-1975@postgrespro.ru", "phone": "+70540527790"}
0005432783884	D8DBB4	4259 273179	GENNADIY MIKHAYLOV	{"email": "gennadiymikhaylov.011970@postgrespro.ru", "phone": "+70703591250"}
0005432783885	01EC90	8889 579307	SEMEN EGOROV	{"email": "egorovsemen091976@postgrespro.ru", "phone": "+70816541821"}
0005432783886	01EC90	7781 308382	ELENA BORISOVA	{"email": "borisova.elena.20031976@postgrespro.ru", "phone": "+70980026925"}
0005432783887	69EE57	1770 840051	OLGA SOKOLOVA	{"phone": "+70837085653"}
0005432783888	69EE57	4383 065203	MAKSIM ZAYCEV	{"email": "maksim.zaycev_15121957@postgrespro.ru", "phone": "+70364025439"}
0005432783889	F3E947	1327 703592	VALENTINA MATVEEVA	{"email": "vmatveeva.091974@postgrespro.ru", "phone": "+70109479819"}
0005432783890	F3E947	0842 538728	SERGEY SMIRNOV	{"email": "smirnov_s091959@postgrespro.ru", "phone": "+70102185245"}
0005432783891	2C857C	3304 934269	GEORGIY NAZAROV	{"phone": "+70309157796"}
0005432783892	2C857C	0897 843126	ELENA VASILEVA	{"phone": "+70759764514"}
0005432783893	149271	2962 458058	EKATERINA DAVYDOVA	{"phone": "+70828181332"}
0005432783894	A62074	3901 984899	ANASTASIYA OSIPOVA	{"phone": "+70657041374"}
0005432783895	A62074	1417 615526	GENNADIY ISAEV	{"email": "isaev-gennadiy_1978@postgrespro.ru", "phone": "+70529757086"}
0005432783896	A62074	8392 970892	ELENA MAKSIMOVA	{"email": "maksimova_e_29051965@postgrespro.ru", "phone": "+70767881770"}
0005432783897	76D7AF	0359 206573	ROMAN SCHERBAKOV	{"email": "scherbakov.r1968@postgrespro.ru", "phone": "+70067062548"}
0005432783898	76D7AF	3142 275367	VALENTIN ZAYCEV	{"email": "zaycev-valentin.111979@postgrespro.ru", "phone": "+70438743544"}
0005432783899	172507	7980 232218	TATYANA BELYAEVA	{"phone": "+70190451270"}
0005432783900	0CD21F	6861 127489	NADEZHDA OVCHINNIKOVA	{"email": "novchinnikova.1967@postgrespro.ru", "phone": "+70132310652"}
0005432783901	70856E	3209 856588	ANNA TIKHONOVA	{"phone": "+70726102677"}
0005432783902	ACD72F	3720 002657	NIKITA GORBUNOV	{"phone": "+70883307186"}
0005432783903	44BD0F	8244 545205	KIRILL KONOVALOV	{"email": "konovalov.kirill-16041977@postgrespro.ru", "phone": "+70333470851"}
0005432783904	44BD0F	7214 970009	DMITRIY SMIRNOV	{"phone": "+70330414501"}
0005432783905	9B2E28	9619 254309	OLEG ZAKHAROV	{"phone": "+70993368556"}
0005432783906	3512A6	8337 951137	KSENIYA MOROZOVA	{"email": "kseniya.morozova.1963@postgrespro.ru", "phone": "+70810807477"}
0005432783907	80FBE2	4209 716649	IGOR SOLOVEV	{"email": "solovevigor.051966@postgrespro.ru", "phone": "+70858938834"}
0005432783908	80FBE2	7825 619270	NINA BORISOVA	{"phone": "+70782750809"}
0005432783909	905836	6151 949273	ROMAN ROMANOV	{"email": "roman_romanov_071976@postgrespro.ru", "phone": "+70952466343"}
0005432783910	F3D9B2	0557 240218	ALEKSANDRA BELOVA	{"email": "a-belova05091975@postgrespro.ru", "phone": "+70195084683"}
0005432783911	DA71F4	7620 093432	POLINA ZOTOVA	{"email": "zotovapolina.14021970@postgrespro.ru", "phone": "+70287033832"}
0005432783912	5DE944	5168 311457	GALINA ANDREEVA	{"email": "galina.andreeva22031974@postgrespro.ru", "phone": "+70285835254"}
0005432783913	5DE944	0630 015015	ANNA DANILOVA	{"email": "danilovaa.051972@postgrespro.ru", "phone": "+70396714883"}
0005432783914	99975F	2669 462650	OLGA MOISEEVA	{"email": "moiseeva_o.07091961@postgrespro.ru", "phone": "+70506507842"}
0005432783915	6AA647	3599 220069	LYUBOV SAVELEVA	{"email": "lyubov.saveleva-041976@postgrespro.ru", "phone": "+70704312433"}
0005432783916	E1FA94	2960 507501	VIKTOR ZAKHAROV	{"phone": "+70567649535"}
0005432783917	D22C64	7155 051294	IGOR SEMENOV	{"email": "semenov_i10061977@postgrespro.ru", "phone": "+70014558482"}
0005432783918	052A48	2977 936994	ALEKSANDR EGOROV	{"phone": "+70108231134"}
0005432783919	50221B	1684 795118	SERGEY MAKAROV	{"phone": "+70023654691"}
0005432783920	50221B	9917 166374	NADEZHDA CHERNOVA	{"email": "chernovanadezhda1980@postgrespro.ru", "phone": "+70197035851"}
0005432783921	053951	6857 002993	VITALIY NAZAROV	{"phone": "+70102920549"}
0005432783922	E536F6	3341 339782	ALEKSEY ZAKHAROV	{"email": "zakharov_a.071972@postgrespro.ru", "phone": "+70903367283"}
0005432783923	BE0E32	4607 298920	ARTEM KUZNECOV	{"phone": "+70571722482"}
0005432783924	4D4949	4374 368819	DMITRIY OSIPOV	{"phone": "+70841431431"}
0005432783925	4D4949	1436 465983	MARIYA ALEKSEEVA	{"email": "malekseeva19071969@postgrespro.ru", "phone": "+70975005809"}
0005432783926	CBFEF2	8097 082957	OLEG OSIPOV	{"email": "osipov-o21031975@postgrespro.ru", "phone": "+70382497221"}
0005432783927	CBFEF2	0131 330137	ALBERT SIDOROV	{"phone": "+70180172459"}
0005432783928	B393C0	8001 861228	MARINA ROMANOVA	{"phone": "+70872170159"}
0005432783929	B393C0	2649 643989	FARID FILIPPOV	{"email": "farid_filippov-09031978@postgrespro.ru", "phone": "+70652324631"}
0005432783930	74E50B	8261 090022	OLEG BORISOV	{"email": "borisovoleg1966@postgrespro.ru", "phone": "+70037426949"}
0005432783931	74E50B	7716 673752	IRINA BELOVA	{"phone": "+70403094029"}
0005432783932	A80B41	7029 525263	NINA KONOVALOVA	{"email": "konovalova_nina24021966@postgrespro.ru", "phone": "+70977854989"}
0005432783933	A80B41	5535 510862	ARTEM FEDOTOV	{"email": "fedotov_a.1973@postgrespro.ru", "phone": "+70430997918"}
0005432783934	A80B41	7771 913053	YURIY IVANOV	{"email": "ivanov_yuriy.021960@postgrespro.ru", "phone": "+70214415646"}
0005432783935	E215DD	7285 801157	ILYA AFANASEV	{"email": "ilyaafanasev.20071978@postgrespro.ru", "phone": "+70047434492"}
0005432783936	E215DD	1971 761329	ANTONINA MEDVEDEVA	{"phone": "+70799944511"}
0005432783937	B6FADB	2388 286434	ALEKSANDR BELOV	{"phone": "+70340863502"}
0005432783938	C6E05D	9993 556525	EVGENIYA KOVALEVA	{"phone": "+70858334104"}
0005432783939	C6E05D	7959 882800	MIKHAIL TIMOFEEV	{"email": "mikhailtimofeev.10121971@postgrespro.ru", "phone": "+70996304396"}
0005432783940	BCD913	2615 252209	EKATERINA TIKHONOVA	{"phone": "+70416169517"}
0005432783941	459422	9096 778211	DMITRIY CHERNOV	{"email": "chernov_d.031987@postgrespro.ru", "phone": "+70745995565"}
0005432783942	459422	1582 204289	OLGA VOLKOVA	{"email": "volkovao_1975@postgrespro.ru", "phone": "+70970263742"}
0005432783943	5BEFF9	8433 588524	DARYA RODIONOVA	{"phone": "+70679920853"}
0005432783944	468A8B	4300 193659	ELENA ANDREEVA	{"phone": "+70009154250"}
0005432783945	DC8E60	9917 453668	MAKSIM MIRONOV	{"phone": "+70329245191"}
0005432783946	D5CE5F	4393 480746	ALBINA ILINA	{"email": "ilinaa.081967@postgrespro.ru", "phone": "+70637484900"}
0005432783947	D5CE5F	9120 345476	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev1965@postgrespro.ru", "phone": "+70538656326"}
0005432783948	45473D	9574 209276	VERA MOISEEVA	{"phone": "+70769317736"}
0005432783949	45473D	5270 906103	VALENTINA IVANOVA	{"email": "valentinaivanova_091977@postgrespro.ru", "phone": "+70169932395"}
0005432783950	D731B4	8793 901134	ELENA MOROZOVA	{"phone": "+70577998896"}
0005432783951	EC9DE0	7992 834972	BORIS ABRAMOV	{"phone": "+70920934627"}
0005432783952	CE6775	5119 919672	ALEKSANDRA MASLOVA	{"email": "maslovaa-041971@postgrespro.ru", "phone": "+70027284127"}
0005432783953	8B7394	8421 046954	YURIY ALEKSEEV	{"phone": "+70278218111"}
0005432783954	A6507F	6974 792950	NIKOLAY IVANOV	{"phone": "+70447440307"}
0005432783955	A6507F	5323 783057	LYUBOV KUZMINA	{"email": "lyubovkuzmina-091984@postgrespro.ru", "phone": "+70946295246"}
0005432783956	A6507F	3311 024307	EVGENIY GUSEV	{"phone": "+70046892438"}
0005432783957	D112EF	4914 220455	LYUCIYA ALEKSANDROVA	{"phone": "+70825176975"}
0005432783958	309145	8418 827112	VALENTINA KUZNECOVA	{"phone": "+70171885623"}
0005432783959	309145	5268 497857	MIKHAIL VASILEV	{"email": "vasilevm-29031972@postgrespro.ru", "phone": "+70164990353"}
0005432783960	309145	1611 698165	VALENTINA IVANOVA	{"email": "ivanova_v_17111973@postgrespro.ru", "phone": "+70199488716"}
0005432783961	4BFADC	5510 354776	IVAN SCHERBAKOV	{"phone": "+70825904745"}
0005432783962	615642	0698 960581	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana.091976@postgrespro.ru", "phone": "+70960395753"}
0005432783963	6FC7F1	3780 683634	EVGENIY ZAKHAROV	{"email": "zakharov.e1962@postgrespro.ru", "phone": "+70321177663"}
0005432783964	6FC7F1	9311 132818	OLGA PETROVA	{"phone": "+70010888456"}
0005432783965	BCC70E	3096 848556	NIKITA ALEKSEEV	{"phone": "+70343099575"}
0005432783966	BCC70E	7693 262428	VIKTOR MAKAROV	{"phone": "+70169670179"}
0005432783967	99A42C	0105 173118	ELENA POPOVA	{"email": "e.popova-1980@postgrespro.ru", "phone": "+70249206673"}
0005432783968	25E382	9090 108600	NATALIYA GUSEVA	{"email": "guseva_nataliya_041969@postgrespro.ru", "phone": "+70241147731"}
0005432783969	315D23	1073 620642	EVGENIY KUZNECOV	{"phone": "+70565428959"}
0005432783970	53E4A9	2402 745572	ELENA IVANOVA	{"email": "e.ivanova111963@postgrespro.ru", "phone": "+70672485069"}
0005432783971	447277	4749 363047	OLEG KOZLOV	{"email": "o_kozlov_1968@postgrespro.ru", "phone": "+70719478447"}
0005432783972	EFA00A	6044 807728	STEPAN KAZAKOV	{"phone": "+70567322416"}
0005432783973	EFA00A	4060 552290	ANNA IVANOVA	{"phone": "+70573347013"}
0005432783974	E69B2E	5621 123026	NIKOLAY FROLOV	{"email": "nfrolov-1973@postgrespro.ru", "phone": "+70090727932"}
0005432783975	DF4A01	5156 463783	ALEKSANDR KARPOV	{"phone": "+70999924618"}
0005432783976	D6C691	8575 154668	ALEKSANDR MIKHAYLOV	{"phone": "+70530964632"}
0005432783977	D6C691	1036 441467	RUSTAM DAVYDOV	{"phone": "+70421645303"}
0005432783978	D4206D	8580 317139	NIKITA DMITRIEV	{"phone": "+70787167209"}
0005432783979	D4206D	8696 982862	EKATERINA KUZMINA	{"email": "kuzmina_ekaterina_1972@postgrespro.ru", "phone": "+70223408580"}
0005432783980	D4206D	2380 287727	EKATERINA NIKIFOROVA	{"phone": "+70892925426"}
0005432783981	4BDC4C	5223 864471	MARIYA GERASIMOVA	{"email": "gerasimova_mariya1963@postgrespro.ru", "phone": "+70522936217"}
0005432783982	4BDC4C	7343 569081	ANATOLIY VOROBEV	{"phone": "+70538869395"}
0005432783983	16EB12	7778 379237	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr_1980@postgrespro.ru", "phone": "+70082347357"}
0005432783984	16EB12	0692 901322	KONSTANTIN ALEKSEEV	{"email": "konstantin_alekseev-1966@postgrespro.ru", "phone": "+70013805043"}
0005432783985	3FDB96	3771 995802	VLADIMIR SHEVCHENKO	{"email": "shevchenkovladimir_08061969@postgrespro.ru", "phone": "+70218427596"}
0005432783986	E7D143	5027 495493	GENNADIY BONDARENKO	{"phone": "+70422282820"}
0005432783987	67C57A	7865 524770	VLADIMIR ROMANOV	{"phone": "+70560096041"}
0005432783988	CB84C7	8371 351930	SERGEY DENISOV	{"phone": "+70375959912"}
0005432783989	6E7CF7	1628 762259	TATYANA STEPANOVA	{"email": "stepanova.t03091969@postgrespro.ru", "phone": "+70634420582"}
0005432783990	6E7CF7	8977 140628	ANDREY MIKHAYLOV	{"email": "mikhaylovandrey011970@postgrespro.ru", "phone": "+70402049309"}
0005432783991	83F44D	3739 940491	LARISA POPOVA	{"phone": "+70778599293"}
0005432783992	D0490B	7755 989783	DARYA POTAPOVA	{"email": "potapova_darya26051981@postgrespro.ru", "phone": "+70330813499"}
0005432783993	312EA7	7709 029314	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila.011977@postgrespro.ru", "phone": "+70913734686"}
0005432783994	6CB324	8444 873234	PAVEL SEMENOV	{"phone": "+70096089832"}
0005432783995	6CB324	1081 572995	ANATOLIY SOROKIN	{"email": "a-sorokin-061971@postgrespro.ru", "phone": "+70523210273"}
0005432783996	B3EAEA	6679 710533	ANGELINA GUSEVA	{"email": "guseva.a-1966@postgrespro.ru", "phone": "+70940603509"}
0005432783997	9EF59F	9625 671634	NATALYA GUSEVA	{"email": "nguseva121981@postgrespro.ru", "phone": "+70808847689"}
0005432783998	9EF59F	4402 126268	LARISA KONOVALOVA	{"email": "konovalova-l_121977@postgrespro.ru", "phone": "+70451736309"}
0005432783999	DAF910	5625 497350	TATYANA NIKITINA	{"email": "nikitinat.121968@postgrespro.ru", "phone": "+70537942846"}
0005432784000	DAF910	9514 052092	ANTONINA VOLKOVA	{"email": "volkova-antonina-1974@postgrespro.ru", "phone": "+70616724265"}
0005432784001	793631	5784 421331	GALINA KOZLOVA	{"email": "kozlova_galina_081972@postgrespro.ru", "phone": "+70851608371"}
0005432784002	793631	4586 798652	NATALYA KOZLOVA	{"email": "kozlovanatalya-1968@postgrespro.ru", "phone": "+70843816396"}
0005432784003	1AA9E1	7269 061585	EVGENIY SERGEEV	{"phone": "+70484038450"}
0005432784004	282B3D	1051 167482	ALEKSANDR ZAYCEV	{"phone": "+70095330464"}
0005432784005	282B3D	4476 202325	MAKSIM PAVLOV	{"email": "pavlov.maksim_1967@postgrespro.ru", "phone": "+70116073830"}
0005432784006	4745FC	7061 920756	VYACHESLAV NIKITIN	{"phone": "+70346847201"}
0005432784007	F6651F	2010 200282	LYUBOV MARTYNOVA	{"phone": "+70512356548"}
0005432784008	26C355	0871 266357	NINA YAKOVLEVA	{"email": "n.yakovleva.111973@postgrespro.ru", "phone": "+70258185464"}
0005432784009	C944CA	9938 716284	ALEKSEY IVANOV	{"phone": "+70509581853"}
0005432784010	A7C9A8	7508 316876	VALERIY DENISOV	{"email": "denisovvaleriy_02051976@postgrespro.ru", "phone": "+70123955332"}
0005432784011	49F215	3254 644168	ALEKSANDR ABRAMOV	{"phone": "+70829755865"}
0005432784012	49F215	0958 493400	VYACHESLAV MAKAROV	{"email": "makarovvyacheslav.1979@postgrespro.ru", "phone": "+70954744852"}
0005432784013	ECCCD4	4670 035604	VLADIMIR POPOV	{"email": "vladimir_popov1965@postgrespro.ru", "phone": "+70353348299"}
0005432784014	ECCCD4	1331 607666	DMITRIY BORISOV	{"phone": "+70515758221"}
0005432784015	2A1CAA	1334 875423	GALINA SAVELEVA	{"phone": "+70961311875"}
0005432784016	2A1CAA	1447 877221	VLADIMIR ALEKSANDROV	{"email": "vladimir.aleksandrov.031970@postgrespro.ru", "phone": "+70370389982"}
0005432784017	2A1CAA	5297 195581	VASILIY GORBUNOV	{"phone": "+70789587980"}
0005432784018	D87158	3792 715671	ILGIZ SOLOVEV	{"phone": "+70194801316"}
0005432784019	57F4E1	4948 919047	MARIYA IVANOVA	{"phone": "+70291139455"}
0005432784020	57F4E1	3533 402041	VLADISLAV DMITRIEV	{"email": "dmitrievvladislav1964@postgrespro.ru", "phone": "+70879571606"}
0005432784021	16BF8F	7952 616142	RASHIT SAVELEV	{"phone": "+70643034048"}
0005432784022	16BF8F	8194 030915	ILYA STEPANOV	{"phone": "+70637734289"}
0005432784023	1230C9	9601 620583	ELENA GAVRILOVA	{"phone": "+70322434227"}
0005432784024	6814C0	7148 309990	LYUBOV TIKHONOVA	{"phone": "+70519992578"}
0005432784025	F6516A	1834 188665	SERGEY OSIPOV	{"email": "sosipov.24071971@postgrespro.ru", "phone": "+70364605772"}
0005432784026	F6516A	2188 056756	ALENA EGOROVA	{"email": "egorovaalena1962@postgrespro.ru", "phone": "+70739513798"}
0005432784027	F970F9	9399 694058	IRINA DAVYDOVA	{"phone": "+70510143897"}
0005432784028	AB5447	6053 200883	LIDIYA KULIKOVA	{"email": "lkulikova061984@postgrespro.ru", "phone": "+70064999258"}
0005432784029	205E5E	2805 543681	GENNADIY FEDOROV	{"phone": "+70441303357"}
0005432784030	205E5E	2715 161235	ALEKSEY NIKOLAEV	{"phone": "+70991314908"}
0005432784031	570489	3581 195482	PAVEL YAKOVLEV	{"phone": "+70597081400"}
0005432784032	A46CB9	4455 544202	ALEKSANDR KULIKOV	{"phone": "+70263526047"}
0005432784033	A46CB9	1357 970608	TAGIR KUDRYASHOV	{"email": "tkudryashov101963@postgrespro.ru", "phone": "+70690038859"}
0005432784034	DFDD89	4036 623810	VLADISLAV MAKSIMOV	{"email": "vladislav-maksimov_18031968@postgrespro.ru", "phone": "+70985205420"}
0005432784035	DFDD89	4004 875751	DMITRIY DMITRIEV	{"phone": "+70743286583"}
0005432784036	DFDD89	0677 488548	ALEKSANDR IVANOV	{"email": "a_ivanov-05061975@postgrespro.ru", "phone": "+70867690348"}
0005432784037	0FF5A9	3122 837346	ALENA IVANOVA	{"email": "a-ivanova.1980@postgrespro.ru", "phone": "+70438928681"}
0005432784038	0FF5A9	3767 530186	DARYA PETROVA	{"phone": "+70066175656"}
0005432784039	471574	4511 574351	MIKHAIL ORLOV	{"phone": "+70538770551"}
0005432784040	471574	2515 910171	VLADIMIR VASILEV	{"phone": "+70693583688"}
0005432784041	F6232D	9596 604988	VALENTINA FOMINA	{"phone": "+70228041139"}
0005432784042	F6232D	4168 304944	VITALIY ALEKSEEV	{"email": "vitaliy-alekseev.091958@postgrespro.ru", "phone": "+70857617920"}
0005432784043	A21D43	0632 081895	MIKHAIL IVANOV	{"phone": "+70750567361"}
0005432784044	A21D43	9947 687704	VALERIY POPOV	{"email": "vpopov.30051976@postgrespro.ru", "phone": "+70937136401"}
0005432784045	DD8402	8283 917470	ANATOLIY SEMENOV	{"email": "a-semenov.30061973@postgrespro.ru", "phone": "+70075828178"}
0005432784046	5E1515	0953 288050	ALEKSANDR OSIPOV	{"email": "aleksandr.osipov121972@postgrespro.ru", "phone": "+70349757047"}
0005432784047	0D621E	0594 030643	GALINA LUKYANOVA	{"phone": "+70004556665"}
0005432784048	0D621E	4740 018460	EKATERINA IVANOVA	{"phone": "+70385548030"}
0005432784049	59EA02	6444 483361	ALEKSANDR STEPANOV	{"phone": "+70026137888"}
0005432784050	48355E	4261 368056	ALLA IVANOVA	{"phone": "+70300928491"}
0005432784051	48355E	1451 712720	NATALYA SOROKINA	{"email": "natalya_sorokina.121964@postgrespro.ru", "phone": "+70231841822"}
0005432784052	78F7A4	0404 448732	OLGA BORISOVA	{"email": "o.borisova.1977@postgrespro.ru", "phone": "+70285403055"}
0005432784053	78F7A4	0418 303634	SERGEY ILIN	{"email": "sergey.ilin.30011981@postgrespro.ru", "phone": "+70109622055"}
0005432784054	294816	1234 130546	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov-1973@postgrespro.ru", "phone": "+70497870798"}
0005432784055	D82166	0120 166877	VASILIY MOISEEV	{"email": "moiseev.vasiliy_061980@postgrespro.ru", "phone": "+70123709271"}
0005432784056	4D6EEB	0735 201338	MARIYA VLASOVA	{"phone": "+70070931185"}
0005432784057	023703	3210 581277	MARGARITA BELYAEVA	{"email": "margaritabelyaeva1981@postgrespro.ru", "phone": "+70784596119"}
0005432784058	A4C55E	0685 089924	IGOR ZAYCEV	{"phone": "+70689589941"}
0005432784059	2E4750	4512 951136	IVAN MIRONOV	{"email": "i-mironov_13041956@postgrespro.ru", "phone": "+70872999575"}
0005432784060	3FF962	6528 573533	SVETLANA ALEKSEEVA	{"phone": "+70894711132"}
0005432784061	3FF962	5180 953021	DENIS TIKHONOV	{"phone": "+70306050689"}
0005432784062	EBE569	7384 829695	VLADIMIR PETROV	{"phone": "+70516059957"}
0005432784063	EBE569	9118 669118	MARINA GRISHINA	{"phone": "+70415849554"}
0005432784064	A67E91	7699 381159	MARINA IVANOVA	{"email": "m_ivanova-1974@postgrespro.ru", "phone": "+70646788665"}
0005432784065	76843F	1753 561241	GALINA TARASOVA	{"phone": "+70625279442"}
0005432784066	76843F	0338 680281	VLADIMIR KAZAKOV	{"email": "v.kazakov07011981@postgrespro.ru", "phone": "+70913985237"}
0005432784067	76843F	0881 796621	VENERA TROFIMOVA	{"phone": "+70754972442"}
0005432784068	65C238	9983 302232	VLADIMIR IVANOV	{"phone": "+70382193642"}
0005432784069	63404A	8549 921714	YULIYA MAKAROVA	{"email": "ymakarova.071970@postgrespro.ru", "phone": "+70159778072"}
0005432784070	63404A	6638 278282	ANDREY KUZMIN	{"phone": "+70928599121"}
0005432784071	0F7A21	9929 521596	SERGEY BONDARENKO	{"email": "bondarenko_sergey061973@postgrespro.ru", "phone": "+70507489327"}
0005432784072	10C200	5875 493864	ELENA KALININA	{"phone": "+70808292796"}
0005432784073	D64F81	3907 341260	ANNA LAZAREVA	{"email": "anna-lazareva1958@postgrespro.ru", "phone": "+70694851565"}
0005432784074	D64F81	5992 886525	NIKITA ANDREEV	{"email": "andreev.nikita_07061967@postgrespro.ru", "phone": "+70541713192"}
0005432784075	D06362	6691 932300	SVETLANA NESTEROVA	{"phone": "+70543879955"}
0005432784187	CED2E6	3669 738843	SERGEY PETROV	{"phone": "+70167016473"}
0005432784076	5412B4	0111 090078	ALEKSANDR EGOROV	{"email": "aleksandr-egorov1969@postgrespro.ru", "phone": "+70348541397"}
0005432784077	BCE98E	5074 383130	VLADISLAV PAVLOV	{"phone": "+70195133971"}
0005432784078	8E2942	7135 003527	ZHANNA KOROLEVA	{"phone": "+70148556141"}
0005432784079	22DCE8	6752 465553	EKATERINA ROMANOVA	{"phone": "+70308113019"}
0005432784080	22DCE8	6859 980872	MAKSIM EGOROV	{"phone": "+70924122560"}
0005432784081	CA88DE	9190 902957	VIKTOR SCHERBAKOV	{"email": "v.scherbakov1976@postgrespro.ru", "phone": "+70186621786"}
0005432784082	7B56C9	8891 902573	NADEZHDA SOKOLOVA	{"email": "sokolovanadezhda-1979@postgrespro.ru", "phone": "+70352839507"}
0005432784083	7B56C9	8510 802149	PAVEL FOMIN	{"phone": "+70884679080"}
0005432784084	56FED2	5633 287741	MARIYA GORBUNOVA	{"email": "gorbunova_mariya_1974@postgrespro.ru", "phone": "+70273526521"}
0005432784085	620775	7798 010348	NATALYA ANISIMOVA	{"email": "n_anisimova-21101971@postgrespro.ru", "phone": "+70192244089"}
0005432784086	898181	2771 269694	ANASTASIYA POPOVA	{"phone": "+70706960635"}
0005432784087	C5B325	6357 339716	KSENIYA VASILEVA	{"phone": "+70235547020"}
0005432784088	C5B325	9080 344781	MAKSIM BARANOV	{"email": "maksim-baranov1977@postgrespro.ru", "phone": "+70643339062"}
0005432784089	282DAB	6624 541351	VLADIMIR SIDOROV	{"email": "vladimir.sidorov1988@postgrespro.ru", "phone": "+70044032446"}
0005432784090	282DAB	7198 232877	GALINA VOROBEVA	{"email": "galina_vorobeva_1982@postgrespro.ru", "phone": "+70322841911"}
0005432784091	282DAB	4587 271223	RAISA MASLOVA	{"phone": "+70602397496"}
0005432784092	60A4CC	6865 369569	NIKOLAY SCHERBAKOV	{"email": "scherbakovn121965@postgrespro.ru", "phone": "+70989121955"}
0005432784093	51A877	2954 884881	DARYA ROMANOVA	{"email": "darya.romanova08091981@postgrespro.ru", "phone": "+70643113983"}
0005432784094	F933E3	6787 049283	RADIK KRASNOV	{"email": "radik-krasnov.1976@postgrespro.ru", "phone": "+70817184215"}
0005432784095	DBEEC7	7953 042800	MARIYA DAVYDOVA	{"email": "mariyadavydova.07121964@postgrespro.ru", "phone": "+70742399286"}
0005432784096	72A6F3	1043 287767	ELENA VOROBEVA	{"phone": "+70607275416"}
0005432784097	72A6F3	5370 823261	DIANA MATVEEVA	{"email": "matveeva-diana.071972@postgrespro.ru", "phone": "+70762282779"}
0005432784098	B45895	9091 495453	ILYA IVANOV	{"email": "ivanov-ilya-061966@postgrespro.ru", "phone": "+70104970095"}
0005432784099	652C5B	2954 527013	VALENTINA OSIPOVA	{"email": "osipovavalentina_1969@postgrespro.ru", "phone": "+70702957363"}
0005432784100	652C5B	3965 659472	VASILIY POPOV	{"phone": "+70753799291"}
0005432784101	552CDF	4192 344098	ELENA KUZMINA	{"phone": "+70863461038"}
0005432784102	552CDF	5325 942899	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey.061967@postgrespro.ru", "phone": "+70168503230"}
0005432784103	552CDF	9299 115016	ELENA KALININA	{"email": "kalinina-elena_081965@postgrespro.ru", "phone": "+70403660465"}
0005432784104	D655FA	3489 198359	NIKITA SOROKIN	{"phone": "+70663667398"}
0005432784105	D655FA	0986 567734	LYUBOV CHERNOVA	{"email": "lyubov.chernova031969@postgrespro.ru", "phone": "+70453652501"}
0005432784106	00E0B4	5003 660920	MIKHAIL VOLKOV	{"phone": "+70040618650"}
0005432784107	7B35A7	4118 526042	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr09091968@postgrespro.ru", "phone": "+70959488926"}
0005432784108	571352	9473 876041	LEV SIDOROV	{"phone": "+70156586737"}
0005432784109	F35397	8429 785478	SVETLANA PETROVA	{"phone": "+70722196004"}
0005432784110	4CF71F	0077 085582	ILYA IVANOV	{"email": "ilya.ivanov1966@postgrespro.ru", "phone": "+70321746132"}
0005432784111	F428CB	4047 689439	EVGENIY VLASOV	{"email": "vlasov.evgeniy19111976@postgrespro.ru", "phone": "+70318924505"}
0005432784112	CB41AF	3166 377929	SVETLANA LUKYANOVA	{"phone": "+70370172084"}
0005432784113	CB41AF	3393 006726	MARIYA LEBEDEVA	{"phone": "+70064166014"}
0005432784114	31E8AA	4230 227245	SERGEY NAUMOV	{"phone": "+70421838449"}
0005432784115	31E8AA	9174 735816	LUIZA PETROVA	{"phone": "+70413870247"}
0005432784116	381FB4	1033 131931	RAIL ORLOV	{"email": "orlov-rail18101979@postgrespro.ru", "phone": "+70193620007"}
0005432784117	39B12B	4955 725653	VITALIY CHERNOV	{"email": "chernov-v_121979@postgrespro.ru", "phone": "+70825050165"}
0005432784118	9A1F34	9319 671685	NATALYA SEMENOVA	{"phone": "+70838910021"}
0005432784119	9A1F34	5019 085714	PAVEL GUSEV	{"email": "gusev_pavel.041986@postgrespro.ru", "phone": "+70608976643"}
0005432784120	DC1D88	2338 836013	LYUDMILA ILINA	{"email": "l.ilina121981@postgrespro.ru", "phone": "+70030415709"}
0005432784121	881EBF	7158 463641	SERGEY MOROZOV	{"email": "morozov_s_1977@postgrespro.ru", "phone": "+70885703070"}
0005432784122	7FFAA1	9705 010064	NIKOLAY KRASNOV	{"phone": "+70071110106"}
0005432784123	60EB7F	6416 443232	NATALYA POPOVA	{"phone": "+70973376892"}
0005432784124	D3AC3D	0140 645909	ANNA TIKHONOVA	{"phone": "+70331921014"}
0005432784125	D3AC3D	9740 705704	EVGENIYA PAVLOVA	{"email": "evgeniya-pavlova-061965@postgrespro.ru", "phone": "+70732629320"}
0005432784126	9F82CF	1655 555176	RINAT EGOROV	{"email": "r_egorov1978@postgrespro.ru", "phone": "+70083460703"}
0005432784127	31C414	6976 563824	ANATOLIY DENISOV	{"email": "denisova_1979@postgrespro.ru", "phone": "+70581237206"}
0005432784128	18B5BD	2221 152834	MAKSIM BORISOV	{"email": "m-borisov_1964@postgrespro.ru", "phone": "+70275221430"}
0005432784129	BB841F	0388 364553	ALEKSEY KARPOV	{"email": "aleksey.karpov-23111974@postgrespro.ru", "phone": "+70525181995"}
0005432784130	BB841F	7417 113084	ALEVTINA SOROKINA	{"email": "sorokina_alevtina-1971@postgrespro.ru", "phone": "+70012905230"}
0005432784244	474649	9208 069760	SVETLANA NAZAROVA	{"phone": "+70786399274"}
0005432784131	5CD1BA	9084 213683	YULIYA GUSEVA	{"email": "y.guseva11061969@postgrespro.ru", "phone": "+70179079864"}
0005432784132	5CD1BA	4640 728802	NINA BOGDANOVA	{"email": "nbogdanova.091973@postgrespro.ru", "phone": "+70984934043"}
0005432784133	FDDA87	6223 825089	DENIS VOLKOV	{"email": "volkov-d-081973@postgrespro.ru", "phone": "+70914236130"}
0005432784134	8F1955	6978 153378	SERGEY GERASIMOV	{"phone": "+70688242640"}
0005432784135	FBD7BC	2640 593297	SVETLANA POPOVA	{"email": "popova-svetlana.011980@postgrespro.ru", "phone": "+70068530208"}
0005432784136	8FA8F5	7895 168925	NINA KUZNECOVA	{"email": "nina.kuznecova12041982@postgrespro.ru", "phone": "+70969686842"}
0005432784137	5533CB	0687 836724	VLADIMIR CHERNOV	{"email": "vladimirchernov.111960@postgrespro.ru", "phone": "+70730259679"}
0005432784138	5533CB	4716 035391	TATYANA GERASIMOVA	{"email": "t_gerasimova081964@postgrespro.ru", "phone": "+70377799637"}
0005432784139	5533CB	9630 469383	NADEZHDA FILATOVA	{"phone": "+70465136213"}
0005432784140	64CEC2	5129 370715	OLGA NESTEROVA	{"email": "nesterovaolga.011973@postgrespro.ru", "phone": "+70968881684"}
0005432784141	367767	5267 746543	DMITRIY VLASOV	{"phone": "+70305824183"}
0005432784142	A2983B	7553 639477	DMITRIY SMIRNOV	{"email": "d-smirnov_14121977@postgrespro.ru", "phone": "+70639412788"}
0005432784143	A2983B	8819 307195	VIKTOR ABRAMOV	{"email": "viktor-abramov-1955@postgrespro.ru", "phone": "+70171340172"}
0005432784144	7A4332	3053 835708	DIANA STEPANOVA	{"email": "stepanova.d-1973@postgrespro.ru", "phone": "+70048359593"}
0005432784145	8E06B1	2372 440966	VLADA ANISIMOVA	{"email": "v-anisimova1971@postgrespro.ru", "phone": "+70551859260"}
0005432784146	CE30CA	1828 400799	ELENA SAVELEVA	{"phone": "+70099613587"}
0005432784147	840D2D	6399 889426	YULIYA NOVIKOVA	{"phone": "+70786757371"}
0005432784148	64BB69	6719 978117	IGOR PAVLOV	{"phone": "+70586460657"}
0005432784149	64BB69	9040 135541	TAMARA ANTONOVA	{"phone": "+70334679373"}
0005432784150	3C6CA5	5093 840763	ANATOLIY ZAKHAROV	{"email": "anatoliyzakharov.1970@postgrespro.ru", "phone": "+70201847351"}
0005432784151	EA8060	3866 468937	NIKOLAY IVANOV	{"email": "n.ivanov-27071979@postgrespro.ru", "phone": "+70096162148"}
0005432784152	20B493	4024 663007	LARISA MELNIKOVA	{"email": "melnikovalarisa09071971@postgrespro.ru", "phone": "+70587337707"}
0005432784153	173EA5	2473 065416	SERGEY KOZLOV	{"email": "s-kozlov_1971@postgrespro.ru", "phone": "+70162638498"}
0005432784154	ECBF37	6092 824553	KONSTANTIN KUZNECOV	{"email": "kuznecov_konstantin-14051987@postgrespro.ru", "phone": "+70345458624"}
0005432784155	991625	1203 915184	ALINA RYABOVA	{"email": "aryabova051958@postgrespro.ru", "phone": "+70763821450"}
0005432784156	39AA82	0466 728895	NADEZHDA ANTONOVA	{"phone": "+70117828306"}
0005432784157	39AA82	4356 447479	MARINA DENISOVA	{"phone": "+70946878806"}
0005432784158	0170C3	9869 076320	GALINA FILATOVA	{"email": "filatova.g.101975@postgrespro.ru", "phone": "+70641658783"}
0005432784159	761E10	8394 571807	ALEKSEY SOROKIN	{"phone": "+70020552298"}
0005432784160	A8EE6C	1088 785634	LYUBOV ANTONOVA	{"email": "antonova_lyubov.1966@postgrespro.ru", "phone": "+70665548865"}
0005432784161	123FED	1614 473326	VIKTOR KULIKOV	{"phone": "+70646262927"}
0005432784162	B4CD56	0795 864967	ANNA OVCHINNIKOVA	{"phone": "+70410363252"}
0005432784163	C6C111	0847 410811	ALEKSEY KULIKOV	{"email": "kulikov.aleksey.12121964@postgrespro.ru", "phone": "+70139611821"}
0005432784164	6276B3	8343 476733	VLADISLAV FILIPPOV	{"email": "filippovv011970@postgrespro.ru", "phone": "+70068389387"}
0005432784165	6276B3	2111 677389	SVETLANA RODIONOVA	{"phone": "+70598497446"}
0005432784166	CB656B	4108 652272	GRIGORIY NOVIKOV	{"email": "g.novikov-1966@postgrespro.ru", "phone": "+70930895474"}
0005432784167	CCA168	0350 122233	OLGA OSIPOVA	{"email": "osipova-olga-1965@postgrespro.ru", "phone": "+70846006767"}
0005432784168	090458	0559 690946	VASILIY IVANOV	{"email": "ivanov.vasiliy051977@postgrespro.ru", "phone": "+70282014596"}
0005432784169	E655B7	2895 007099	SERGEY KUZMIN	{"phone": "+70977031655"}
0005432784170	35EF92	6731 662653	VLADIMIR EGOROV	{"email": "v_egorov_021967@postgrespro.ru", "phone": "+70931871842"}
0005432784171	6EB7F3	2822 584871	INNA GORBUNOVA	{"phone": "+70088583543"}
0005432784172	6EB7F3	6269 644443	ARTEM MAKAROV	{"phone": "+70857887441"}
0005432784173	6EB7F3	6527 960566	ALEKSANDRA KUZNECOVA	{"phone": "+70329231337"}
0005432784174	C039AC	6993 094746	DANILA BONDARENKO	{"email": "bondarenkod-051966@postgrespro.ru", "phone": "+70373689800"}
0005432784175	C039AC	6384 660349	LEONID KULIKOV	{"email": "kulikovleonid_1963@postgrespro.ru", "phone": "+70279042002"}
0005432784176	7F10CA	3674 791635	GLEB IVANOV	{"phone": "+70094187608"}
0005432784177	7F10CA	5444 352399	LIDIYA VASILEVA	{"email": "l.vasileva-1976@postgrespro.ru", "phone": "+70797712078"}
0005432784178	028C5D	6040 257908	ANTONINA MELNIKOVA	{"email": "antonina_melnikova_1973@postgrespro.ru", "phone": "+70252017962"}
0005432784179	FF837B	4113 346143	ANASTASIYA DENISOVA	{"phone": "+70712734355"}
0005432784180	94F2C2	6214 337224	ASKHAT MIRONOV	{"email": "amironov07031975@postgrespro.ru", "phone": "+70135694829"}
0005432784181	1AE502	3825 164095	OLGA STEPANOVA	{"phone": "+70893984389"}
0005432784182	1AE502	1888 101142	MAKSIM MATVEEV	{"email": "m_matveev-27051968@postgrespro.ru", "phone": "+70732753964"}
0005432784183	976AA2	1608 422662	ALLA PAVLOVA	{"phone": "+70949470110"}
0005432784184	976AA2	6804 732409	VIKTORIYA OSIPOVA	{"phone": "+70009373696"}
0005432784185	9E21A7	2952 735591	RAMIL ROMANOV	{"phone": "+70988072093"}
0005432784186	B94CCE	1583 888785	SULTAN KISELEV	{"email": "sultankiselev.21121970@postgrespro.ru", "phone": "+70729478208"}
0005432784188	CED2E6	1356 788267	VERA KOVALEVA	{"email": "vera-kovaleva-1971@postgrespro.ru", "phone": "+70571639903"}
0005432784189	560E5E	4850 180729	KRISTINA POLYAKOVA	{"email": "polyakova-k-1984@postgrespro.ru", "phone": "+70448423435"}
0005432784190	1A1145	0108 680903	DMITRIY KUZNECOV	{"email": "kuznecov_d.30101959@postgrespro.ru", "phone": "+70735032437"}
0005432784191	1A1145	8847 470811	YURIY SOLOVEV	{"email": "y_solovev-1965@postgrespro.ru", "phone": "+70989200621"}
0005432784192	5F671C	1900 285137	MARINA ROMANOVA	{"email": "marina-romanova1983@postgrespro.ru", "phone": "+70270572982"}
0005432784193	5F671C	8501 181638	OLGA POPOVA	{"email": "olga_popova.041971@postgrespro.ru", "phone": "+70298216480"}
0005432784194	5998A4	3995 777736	ARTEM STEPANOV	{"phone": "+70457138284"}
0005432784195	87AE58	4851 696058	MAKSIM KRASNOV	{"email": "krasnov_maksim-1971@postgrespro.ru", "phone": "+70401994150"}
0005432784196	BDDE81	0843 731212	DANIIL VASILEV	{"phone": "+70088199920"}
0005432784197	2EFA2B	8896 380059	VALENTINA MAKAROVA	{"email": "makarova-v19101972@postgrespro.ru", "phone": "+70791846710"}
0005432784198	2EFA2B	0494 708461	TATYANA SCHERBAKOVA	{"email": "scherbakova_t_061972@postgrespro.ru", "phone": "+70994378892"}
0005432784199	3A25A6	7265 424715	ALEKSEY ALEKSEEV	{"email": "alekseev-a.111975@postgrespro.ru", "phone": "+70534862476"}
0005432784200	B0C938	3083 423239	EKATERINA VASILEVA	{"phone": "+70374845517"}
0005432784201	B0C938	0719 156734	GENNADIY MAKSIMOV	{"email": "maksimov.gennadiy1976@postgrespro.ru", "phone": "+70508479197"}
0005432784202	77F0B2	4725 149826	EVGENIY MIKHAYLOV	{"email": "mikhaylove031965@postgrespro.ru", "phone": "+70036682655"}
0005432784203	4B5930	5612 631514	OLGA KUZMINA	{"phone": "+70553271188"}
0005432784204	4B5930	1868 026628	VALERIYA ZAYCEVA	{"phone": "+70290082516"}
0005432784205	030A63	7307 023129	DARYA MOISEEVA	{"email": "moiseeva_d-15031964@postgrespro.ru", "phone": "+70375972059"}
0005432784206	6C0161	3781 671582	NURIYA KUDRYASHOVA	{"phone": "+70491220362"}
0005432784207	9C93C0	2742 782607	ALEKSANDR ANTONOV	{"phone": "+70036633595"}
0005432784208	9C93C0	3927 617263	TATYANA ZHUKOVA	{"email": "zhukova_t.1965@postgrespro.ru", "phone": "+70234671801"}
0005432784209	7A11D4	0816 635271	KONSTANTIN KUZMIN	{"email": "kuzmin-k_1955@postgrespro.ru", "phone": "+70853956327"}
0005432784210	7A11D4	1654 359976	VLADIMIR MOROZOV	{"email": "vladimirmorozov1977@postgrespro.ru", "phone": "+70969952007"}
0005432784211	00A7BA	0360 334639	ANDREY STEPANOV	{"email": "andrey_stepanov.29091966@postgrespro.ru", "phone": "+70254417097"}
0005432784212	00A7BA	8631 186531	ELENA VASILEVA	{"phone": "+70028588221"}
0005432784213	6C73D0	3970 652003	IRINA PETROVA	{"phone": "+70095951015"}
0005432784214	9F1E82	9528 663662	SVETLANA MIRONOVA	{"email": "mironova.s-011973@postgrespro.ru", "phone": "+70064489515"}
0005432784215	9F1E82	9406 582330	GALINA ISAEVA	{"email": "g.isaeva-041977@postgrespro.ru", "phone": "+70688266164"}
0005432784216	9F1E82	5015 534005	SVETLANA RYABOVA	{"email": "s_ryabova-081970@postgrespro.ru", "phone": "+70587829592"}
0005432784217	D3BF14	5160 539133	GALINA ROMANOVA	{"phone": "+70593199482"}
0005432784218	92E74F	1446 988901	ILMIR EGOROV	{"email": "egorov.i-01021968@postgrespro.ru", "phone": "+70894810090"}
0005432784219	4B6254	6020 561193	SERGEY ZAYCEV	{"phone": "+70232998175"}
0005432784220	314E14	7736 038783	NATALYA BORISOVA	{"email": "borisovan15061961@postgrespro.ru", "phone": "+70152422563"}
0005432784221	125D10	4550 303090	ELENA ALEKSEEVA	{"email": "alekseevaelena-1992@postgrespro.ru", "phone": "+70603298656"}
0005432784222	42C0F6	8741 171950	ALEKSANDR ZAKHAROV	{"email": "azakharov1967@postgrespro.ru", "phone": "+70927305128"}
0005432784223	42C0F6	1375 248250	EVGENIY ZAKHAROV	{"email": "evgeniy.zakharov1982@postgrespro.ru", "phone": "+70059920663"}
0005432784224	FE20AA	2089 018818	NIKOLAY SOLOVEV	{"phone": "+70715483604"}
0005432784225	FE20AA	4972 166263	TATYANA KUZNECOVA	{"phone": "+70336645504"}
0005432784226	FE20AA	7515 869547	YURIY IVANOV	{"email": "y-ivanov_011970@postgrespro.ru", "phone": "+70700184849"}
0005432784227	48F229	5415 388456	SERGEY SOROKIN	{"email": "ssorokin.091979@postgrespro.ru", "phone": "+70299171881"}
0005432784228	788320	9692 920443	VIKTORIYA KUZNECOVA	{"email": "kuznecova-v111980@postgrespro.ru", "phone": "+70169220318"}
0005432784229	5D54E0	3036 012379	SERGEY TARASOV	{"email": "tarasov_s.1971@postgrespro.ru", "phone": "+70471039170"}
0005432784230	596E0A	0482 921472	VERA FILATOVA	{"phone": "+70954583766"}
0005432784231	6A98C4	8986 518678	MARINA GAVRILOVA	{"email": "marina.gavrilova14081976@postgrespro.ru", "phone": "+70552220743"}
0005432784232	516516	5051 904461	LARISA FILIPPOVA	{"phone": "+70986912946"}
0005432784233	FF52A9	4628 226552	SVETLANA MELNIKOVA	{"email": "melnikova_s-1967@postgrespro.ru", "phone": "+70709067753"}
0005432784234	FF52A9	7768 424536	SERGEY EGOROV	{"email": "s_egorov1978@postgrespro.ru", "phone": "+70732863575"}
0005432784235	70EB98	7004 797211	VALENTINA KUZNECOVA	{"phone": "+70586699714"}
0005432784236	70EB98	4471 306049	AZAT FEDOROV	{"phone": "+70515211694"}
0005432784237	87DFCC	6897 820344	EVGENIY SEMENOV	{"phone": "+70176614755"}
0005432784238	8D7CBA	5533 631727	ALINA SMIRNOVA	{"phone": "+70888324320"}
0005432784239	BA68AE	6376 053381	IGOR BONDARENKO	{"email": "bondarenko_i1976@postgrespro.ru", "phone": "+70608297002"}
0005432784240	BA68AE	9840 496052	MIKHAIL VASILEV	{"phone": "+70736666133"}
0005432784241	BA68AE	9353 391019	SVETLANA NOVIKOVA	{"phone": "+70276747885"}
0005432784242	9627E2	4917 433196	ELENA POPOVA	{"phone": "+70121194823"}
0005432784243	474649	5292 611210	VLADIMIR MAKAROV	{"phone": "+70625412343"}
0005432784245	CCE6ED	9586 527673	OLGA NAZAROVA	{"phone": "+70423620023"}
0005432784246	D27E47	5410 978198	LARISA POPOVA	{"email": "popova_larisa15111970@postgrespro.ru", "phone": "+70947570366"}
0005432784247	D27E47	5455 721164	LYUBOV POLYAKOVA	{"phone": "+70358708120"}
0005432784248	471066	8467 638314	IVAN KRASNOV	{"email": "ikrasnov101973@postgrespro.ru", "phone": "+70661795217"}
0005432784249	4F460F	1076 927021	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey101968@postgrespro.ru", "phone": "+70058165555"}
0005432784250	4F460F	1659 566091	VALERIYA NAZAROVA	{"email": "valeriya-nazarova-07011974@postgrespro.ru", "phone": "+70559635462"}
0005432784251	09C401	7367 503720	PETR POPOV	{"email": "p-popov-101969@postgrespro.ru", "phone": "+70392138341"}
0005432784252	791C96	3413 204593	ELENA VOLKOVA	{"phone": "+70420421315"}
0005432784253	98BF72	4406 700004	NINA LOGINOVA	{"phone": "+70483971021"}
0005432784254	1FE604	1062 808734	VLADIMIR SEMENOV	{"email": "semenovvladimir.05021972@postgrespro.ru", "phone": "+70581118787"}
0005432784255	FF4AEC	6659 375980	DANILA FOMIN	{"phone": "+70334144135"}
0005432784256	DC4CD1	1961 795727	MIKHAIL YAKOVLEV	{"email": "yakovlevm.101978@postgrespro.ru", "phone": "+70031796339"}
0005432784257	66A7E4	1714 033889	DANILA BARANOV	{"email": "danilabaranov_12111959@postgrespro.ru", "phone": "+70840186194"}
0005432784258	05283A	7081 585428	VYACHESLAV ZAYCEV	{"email": "vyacheslavzaycev1964@postgrespro.ru", "phone": "+70383415139"}
0005432784259	4A9B16	3112 913922	SERGEY MAKSIMOV	{"email": "maksimovsergey.031980@postgrespro.ru", "phone": "+70746775613"}
0005432784260	15E1DE	5750 309867	ALINA ZHURAVLEVA	{"email": "zhuravlevaa1967@postgrespro.ru", "phone": "+70605232740"}
0005432784261	C69571	1854 646023	NADEZHDA TARASOVA	{"phone": "+70331769444"}
0005432784262	01BE7A	6164 857996	ANDREY CHERNOV	{"phone": "+70626501535"}
0005432784263	D5A2D5	8967 179724	ARTEM SHEVCHENKO	{"phone": "+70342505565"}
0005432784264	5ADDD8	2025 730421	DIANA SIDOROVA	{"phone": "+70632653412"}
0005432784265	E7A4C1	5481 569285	VIKTORIYA PETROVA	{"email": "petrovaviktoriya-1975@postgrespro.ru", "phone": "+70958289752"}
0005432784266	5993B2	1093 698674	ZINAIDA MAKAROVA	{"phone": "+70237340444"}
0005432784267	5993B2	3897 711971	OLGA MALYSHEVA	{"email": "malysheva.o.011976@postgrespro.ru", "phone": "+70243783714"}
0005432784268	76CDEF	7054 108399	GENNADIY IVANOV	{"email": "g.ivanov.051983@postgrespro.ru", "phone": "+70904840515"}
0005432784269	43D7B2	6151 839743	ALEKSANDRA SOLOVEVA	{"phone": "+70455148697"}
0005432784270	DE7E09	5990 068910	DMITRIY IVANOV	{"email": "ivanov.dmitriy.071976@postgrespro.ru", "phone": "+70127085960"}
0005432784271	9F1E3B	9656 846751	NADEZHDA SOKOLOVA	{"email": "sokolova.n-1960@postgrespro.ru", "phone": "+70466317642"}
0005432784272	26A59C	7332 261254	VITALIY BORISOV	{"email": "v_borisov_13061967@postgrespro.ru", "phone": "+70338262064"}
0005432784273	26A59C	5147 704795	ANTONINA STEPANOVA	{"phone": "+70791830624"}
0005432784274	E33F75	3101 843729	TATYANA VOLKOVA	{"phone": "+70212119949"}
0005432784275	D0BC7C	1115 413146	SVETLANA MAKSIMOVA	{"phone": "+70684102613"}
0005432784276	EF7188	4335 576079	ROZALIYA SCHERBAKOVA	{"phone": "+70068093693"}
0005432784277	57CA8F	5476 720663	SVYATOSLAV FILIPPOV	{"phone": "+70412404993"}
0005432784278	AC22CB	3535 003657	SVETLANA KUZNECOVA	{"email": "s-kuznecova-041982@postgrespro.ru", "phone": "+70818122218"}
0005432784279	693E60	9119 757627	TATYANA MAKAROVA	{"phone": "+70426261623"}
0005432784280	581905	1991 484740	NINA ANTONOVA	{"email": "antonova-nina1978@postgrespro.ru", "phone": "+70548552104"}
0005432784281	581905	9833 415512	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev.20081977@postgrespro.ru", "phone": "+70788229826"}
0005432784282	1E936A	3674 185493	DMITRIY PETROV	{"email": "dmitriypetrov031975@postgrespro.ru", "phone": "+70518217222"}
0005432784283	2729C6	0490 998016	GALINA KARPOVA	{"email": "karpovag-1975@postgrespro.ru", "phone": "+70014190780"}
0005432784284	A46AF2	2396 373891	NATALIYA KAZAKOVA	{"email": "n-kazakova-1975@postgrespro.ru", "phone": "+70006757604"}
0005432784285	A46AF2	1107 282330	ANNA POTAPOVA	{"email": "potapova.a1969@postgrespro.ru", "phone": "+70445786679"}
0005432784286	7B7DFC	1390 761058	DARYA ANDREEVA	{"email": "d.andreeva_1974@postgrespro.ru", "phone": "+70894871757"}
0005432784287	7B7DFC	1408 446001	LYUDMILA MELNIKOVA	{"phone": "+70330066700"}
0005432784288	652BA1	6894 147751	EVGENIY KUZNECOV	{"phone": "+70923671128"}
0005432784289	5FEB67	2882 793096	MARIYA SEMENOVA	{"phone": "+70663122833"}
0005432784290	532C56	8889 777070	GALINA MAKAROVA	{"phone": "+70639705847"}
0005432784291	E467B4	1853 332539	LEV PAVLOV	{"email": "pavlov-l1970@postgrespro.ru", "phone": "+70649598180"}
0005432784292	D6A0DF	6799 808449	DENIS KAZAKOV	{"phone": "+70736648088"}
0005432784293	81415B	5023 399623	NINA DANILOVA	{"phone": "+70686291367"}
0005432784294	3BFBCA	1623 887760	VIKTOR DAVYDOV	{"email": "davydov.viktor.24031962@postgrespro.ru", "phone": "+70733058261"}
0005432784295	6E799B	2236 339183	SERGEY KOZLOV	{"phone": "+70063696451"}
0005432784296	6E799B	4688 740267	TATYANA GORBUNOVA	{"email": "gorbunova-tatyana-1974@postgrespro.ru", "phone": "+70112682817"}
0005432784297	6E799B	7561 084034	VARVARA KOZLOVA	{"phone": "+70311860208"}
0005432784298	010A78	5181 633874	VALENTINA MIRONOVA	{"email": "valentina-mironova121981@postgrespro.ru", "phone": "+70182040992"}
0005432784299	010A78	6203 598682	MARINA MELNIKOVA	{"phone": "+70815350685"}
0005432784300	548401	6486 578990	VLADIMIR PETROV	{"phone": "+70081628942"}
0005432784301	FD8C91	4545 219107	IOSIF SOLOVEV	{"phone": "+70724246447"}
0005432784302	FD8C91	0393 075339	ALEKSANDR SOROKIN	{"email": "sorokin_a_03021970@postgrespro.ru", "phone": "+70457883210"}
0005432784303	7725C7	5883 171861	PAVEL SOKOLOV	{"email": "sokolov.pavel.051965@postgrespro.ru", "phone": "+70191330882"}
0005432784304	7725C7	5595 845673	ANGELINA VOLKOVA	{"email": "a_volkova.091972@postgrespro.ru", "phone": "+70805294425"}
0005432784305	AFCC5C	7335 552364	ZARINA SOKOLOVA	{"phone": "+70962034515"}
0005432784306	E0D201	0624 699759	NADEZHDA ZHUKOVA	{"email": "nadezhda-zhukova1975@postgrespro.ru", "phone": "+70396146681"}
0005432784307	C4EE00	3483 121033	LIDIYA ERMAKOVA	{"phone": "+70644776833"}
0005432784308	C4EE00	8195 345666	NIKOLAY FROLOV	{"phone": "+70065535317"}
0005432784309	93BB78	3755 300982	VERA IVANOVA	{"phone": "+70945092747"}
0005432784310	93BB78	1577 609992	VLADIMIR SOLOVEV	{"email": "vladimir_solovev_061965@postgrespro.ru", "phone": "+70120920072"}
0005432784311	93BB78	1561 916608	MIKHAIL MAKAROV	{"phone": "+70939042366"}
0005432784312	BF6E47	7512 579666	TATYANA EFREMOVA	{"email": "efremovat_111974@postgrespro.ru", "phone": "+70546403082"}
0005432784313	BF6E47	1475 346083	ILDAR PETROV	{"phone": "+70567636685"}
0005432784314	17ED5C	8323 496756	TATYANA EGOROVA	{"phone": "+70481369067"}
0005432784315	DAFFE0	9752 977162	LARISA BELYAEVA	{"email": "belyaeva-larisa.1961@postgrespro.ru", "phone": "+70996033587"}
0005432784316	5E9882	7958 221438	IGOR FROLOV	{"email": "frolov.igor.051964@postgrespro.ru", "phone": "+70024404844"}
0005432784317	6EB292	7717 521754	EKATERINA BOGDANOVA	{"phone": "+70544961894"}
0005432784318	618FC0	1843 452756	YULIYA CHERNOVA	{"email": "y_chernova_1975@postgrespro.ru", "phone": "+70704584399"}
0005432784319	2430B3	6353 071978	RAISA BORISOVA	{"email": "r_borisova.1984@postgrespro.ru", "phone": "+70614329381"}
0005432784320	2430B3	3742 224450	SERGEY KUZNECOV	{"email": "kuznecov.s_011974@postgrespro.ru", "phone": "+70459992544"}
0005432784321	0FBEAE	6478 626485	LYUBOV CHERNOVA	{"phone": "+70699901899"}
0005432784322	A2077E	1692 989873	ANASTASIYA KUZNECOVA	{"phone": "+70996510406"}
0005432784323	BDBE05	1037 693115	NINA STEPANOVA	{"phone": "+70273164781"}
0005432784324	757473	6929 049307	MIKHAIL MOROZOV	{"phone": "+70401275149"}
0005432784325	7BA8CA	3732 934745	SERGEY VOLKOV	{"phone": "+70768500549"}
0005432784326	7BEBFD	8070 056972	VERA MIRONOVA	{"phone": "+70955800498"}
0005432784327	5DCFF8	7895 016820	VIKTOR BORISOV	{"email": "viktor-borisov1975@postgrespro.ru", "phone": "+70329007377"}
0005432784328	5DCFF8	0781 334374	LYUBOV RYABOVA	{"phone": "+70052004130"}
0005432784329	90B1ED	5734 979147	YULIYA SAVELEVA	{"phone": "+70350494390"}
0005432784330	1C7517	8235 665136	RUMIYA GAVRILOVA	{"phone": "+70395686205"}
0005432784331	769156	7780 719489	SOFYA MAKSIMOVA	{"email": "maksimova.sofya.1972@postgrespro.ru", "phone": "+70211697432"}
0005432784332	65C89D	2442 764413	SVETLANA DANILOVA	{"email": "danilovas1973@postgrespro.ru", "phone": "+70441619378"}
0005432784333	9819D9	0341 386825	ELENA VASILEVA	{"email": "evasileva111975@postgrespro.ru", "phone": "+70601084877"}
0005432784334	9819D9	9254 309913	ALEKSANDR SEMENOV	{"phone": "+70063809081"}
0005432784335	9819D9	6295 669968	ALEKSEY MAKAROV	{"phone": "+70505929441"}
0005432784336	C3514A	1180 055586	EVGENIY BORISOV	{"email": "borisovevgeniy.16091975@postgrespro.ru", "phone": "+70423008820"}
0005432784337	EDCD1D	1280 182365	LIDIYA KAZAKOVA	{"email": "kazakova-lidiya-1974@postgrespro.ru", "phone": "+70320461916"}
0005432784338	EDCD1D	2818 323007	ANTON AFANASEV	{"email": "a_afanasev1969@postgrespro.ru", "phone": "+70132834260"}
0005432784339	14F93A	4456 035149	EVGENIYA KULIKOVA	{"phone": "+70905130019"}
0005432784340	14F93A	8826 993351	SERGEY VOLKOV	{"phone": "+70766473844"}
0005432784341	85DD23	3264 231816	NADEZHDA TIKHONOVA	{"email": "n_tikhonova.25011973@postgrespro.ru", "phone": "+70665218882"}
0005432784342	654B78	4721 386530	ALEKSANDR KONOVALOV	{"phone": "+70424094126"}
0005432784343	0402E2	4221 757848	EDUARD SHEVCHENKO	{"email": "shevchenko_eduard_1975@postgrespro.ru", "phone": "+70652381875"}
0005432784344	0402E2	6392 678783	YULIYA VOROBEVA	{"phone": "+70015972672"}
0005432784345	5B5688	6414 001509	VALERIY SOKOLOV	{"email": "valeriy-sokolov_10061975@postgrespro.ru", "phone": "+70135553852"}
0005432784346	5B5688	7652 875268	ALEKSEY SAVELEV	{"email": "savelev_a121973@postgrespro.ru", "phone": "+70494214219"}
0005432784347	35DD75	6009 797099	SERGEY MOISEEV	{"phone": "+70159488274"}
0005432784348	35DD75	3529 032467	SAVELIY FROLOV	{"email": "frolovs.1967@postgrespro.ru", "phone": "+70838531296"}
0005432784349	484084	7214 455163	NIKOLAY POPOV	{"phone": "+70403444166"}
0005432784350	86D348	3785 678660	GALINA MEDVEDEVA	{"phone": "+70882249398"}
0005432784351	83CE55	7204 289266	MIKHAIL VLASOV	{"phone": "+70346638400"}
0005432784352	83CE55	8840 295104	GALINA KRASNOVA	{"phone": "+70793415541"}
0005432784353	83CE55	6101 668458	OLGA SOKOLOVA	{"phone": "+70150984883"}
0005432784354	E03151	5405 869386	VYACHESLAV ZAKHAROV	{"phone": "+70850718607"}
0005432784355	E03151	1225 204886	EKATERINA NESTEROVA	{"email": "nesterovae.1965@postgrespro.ru", "phone": "+70615140195"}
0005432784356	55F72C	6347 278486	VYACHESLAV ZAYCEV	{"phone": "+70719291512"}
0005432784357	C80D5B	2962 138854	TATYANA IVANOVA	{"email": "ivanovat-1985@postgrespro.ru", "phone": "+70821604017"}
0005432784358	CBD22D	4594 971417	IGOR POPOV	{"email": "i.popov.17071980@postgrespro.ru", "phone": "+70464295501"}
0005432784359	CBD22D	1399 906801	ALLA TROFIMOVA	{"email": "alla-trofimova_021966@postgrespro.ru", "phone": "+70243903817"}
0005432784360	CBD22D	7669 613946	ANTON KOZLOV	{"email": "kozlov_anton_071977@postgrespro.ru", "phone": "+70928877925"}
0005432784361	4A965D	7106 031166	DMITRIY EGOROV	{"email": "egorovdmitriy061975@postgrespro.ru", "phone": "+70167431919"}
0005432784362	8E63F2	9850 781299	ELENA AKIMOVA	{"phone": "+70018445471"}
0005432784363	B1FA4C	2084 489409	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova.08091973@postgrespro.ru", "phone": "+70715512905"}
0005432784364	C6C24E	9005 749016	DANIIL IVANOV	{"email": "daniil-ivanov-1966@postgrespro.ru", "phone": "+70653414393"}
0005432784365	3A8664	4506 915635	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova.02071979@postgrespro.ru", "phone": "+70761674566"}
0005432784366	3A8664	9868 272519	IVAN VOROBEV	{"phone": "+70537702303"}
0005432784367	7F3F83	8458 419719	VLADISLAV DMITRIEV	{"phone": "+70503438150"}
0005432784368	54D5D1	9391 984224	VALENTINA ZAYCEVA	{"email": "zayceva-v1977@postgrespro.ru", "phone": "+70847019363"}
0005432784369	019BDC	1333 860887	SERGEY MOROZOV	{"phone": "+70110843584"}
0005432784370	5E6DF9	0177 554715	VALERIY KOZLOV	{"phone": "+70123224847"}
0005432784371	67BAC8	1591 721785	EVGENIY TARASOV	{"email": "evgeniy_tarasov_09121957@postgrespro.ru", "phone": "+70538161309"}
0005432784372	724E5A	3997 498036	NIKOLAY TIMOFEEV	{"email": "timofeev.nikolay30121973@postgrespro.ru", "phone": "+70892085923"}
0005432784373	CC3E9E	1507 126854	ALEKSEY FILIPPOV	{"email": "filippov_aleksey.121974@postgrespro.ru", "phone": "+70962506530"}
0005432784374	553765	7714 262646	SERGEY SERGEEV	{"phone": "+70867286257"}
0005432784375	81F86D	4481 616002	DENIS STEPANOV	{"email": "stepanov-denis-03021974@postgrespro.ru", "phone": "+70032209372"}
0005432784376	7114E5	8537 204358	ALEKSANDR MARTYNOV	{"email": "martynov-a-02111983@postgrespro.ru", "phone": "+70647910248"}
0005432784377	7114E5	3116 750413	ARSEN KUZMIN	{"email": "arsenkuzmin05011970@postgrespro.ru", "phone": "+70814611757"}
0005432784378	92F31D	1802 239048	VLADIMIR GERASIMOV	{"email": "gerasimov_vladimir_24101962@postgrespro.ru", "phone": "+70323735317"}
0005432784379	FF5552	6026 498271	OLGA STEPANOVA	{"phone": "+70327471141"}
0005432784380	72DEC5	4569 813771	GALINA FILIPPOVA	{"phone": "+70145617260"}
0005432784381	72DEC5	9780 753376	SERGEY DAVYDOV	{"phone": "+70903523213"}
0005432784382	4374EF	8923 629965	IRINA NAUMOVA	{"phone": "+70029914237"}
0005432784383	8C3DE4	5212 501700	VIKTOR IVANOV	{"phone": "+70046581665"}
0005432784384	8C3DE4	3573 961524	DMITRIY KUDRYASHOV	{"email": "dmitriy.kudryashov_101967@postgrespro.ru", "phone": "+70985096046"}
0005432784385	8C3DE4	1679 294852	MARIYA EGOROVA	{"phone": "+70708392688"}
0005432784386	94819A	0044 090544	IRINA ZAKHAROVA	{"phone": "+70485228383"}
0005432784387	94819A	3525 816659	ELENA NESTEROVA	{"phone": "+70594524750"}
0005432784388	D6A573	0357 939552	ANATOLIY ANDREEV	{"email": "anatoliy-andreev1981@postgrespro.ru", "phone": "+70585558084"}
0005432784389	ED54A3	5972 632481	ALEKSANDR GRIGOREV	{"phone": "+70596112913"}
0005432784390	D8437C	0738 861957	VADIM SOLOVEV	{"email": "solovev.vadim-021966@postgrespro.ru", "phone": "+70116821498"}
0005432784391	D8437C	4740 893925	NATALYA ANTONOVA	{"email": "antonova_n-1963@postgrespro.ru", "phone": "+70662939359"}
0005432784392	5A8C52	6752 977590	GEORGIY MAKAROV	{"email": "g_makarov_1982@postgrespro.ru", "phone": "+70521447099"}
0005432784393	E94F26	7512 661055	ANTONINA PAVLOVA	{"phone": "+70776904218"}
0005432784394	E94F26	7175 587165	EKATERINA POPOVA	{"phone": "+70929006002"}
0005432784395	E94F26	4594 970161	DARYA BELYAEVA	{"email": "dbelyaeva_17071972@postgrespro.ru", "phone": "+70897790137"}
0005432784396	3F48F8	2566 741708	OLEG KARPOV	{"email": "oleg.karpov_041974@postgrespro.ru", "phone": "+70375755431"}
0005432784397	3F48F8	0824 630988	VIKTOR POPOV	{"email": "viktor.popov_111977@postgrespro.ru", "phone": "+70940460822"}
0005432784398	9A2F0C	6510 913405	DENIS BELOV	{"phone": "+70253445996"}
0005432784399	9A2F0C	9864 337821	REGINA NAZAROVA	{"phone": "+70367759557"}
0005432784400	9A9EE4	4472 460488	TATYANA PETROVA	{"phone": "+70107100086"}
0005432784401	53D565	7515 165777	SOFYA TIKHONOVA	{"email": "tikhonovasofya081970@postgrespro.ru", "phone": "+70513431111"}
0005432784402	9CB7CB	3522 166429	ALEKSANDR KARPOV	{"phone": "+70828385552"}
0005432784403	9CB7CB	8809 431120	ALEKSEY ANDREEV	{"email": "aleksey.andreev28041966@postgrespro.ru", "phone": "+70372914972"}
0005432784404	78C2C5	2248 132434	ANATOLIY SOKOLOV	{"email": "sokolov.a1964@postgrespro.ru", "phone": "+70593507916"}
0005432784405	3D04AE	9125 018295	EKATERINA NOVIKOVA	{"phone": "+70138638273"}
0005432784406	52C09A	4654 186132	INESSA SAVELEVA	{"email": "inessasaveleva.21011971@postgrespro.ru", "phone": "+70350064792"}
0005432784407	4ADAA8	0418 404921	VLADISLAV ZHURAVLEV	{"email": "zhuravlev_v091978@postgrespro.ru", "phone": "+70001178969"}
0005432784408	BFFDD8	9014 677852	MIROSLAV PETROV	{"email": "miroslavpetrov.1974@postgrespro.ru", "phone": "+70213540612"}
0005432784409	A69E32	4033 459357	OLESYA VLASOVA	{"phone": "+70411125806"}
0005432784410	A999D5	5696 487014	NINA BORISOVA	{"email": "borisova-nina.051961@postgrespro.ru", "phone": "+70622318594"}
0005432784411	A5834E	8645 107766	NADEZHDA SMIRNOVA	{"email": "smirnovan-08051974@postgrespro.ru", "phone": "+70816840833"}
0005432784412	A5834E	2617 374466	EKATERINA KALININA	{"email": "ekaterina.kalinina_1989@postgrespro.ru", "phone": "+70801041109"}
0005432784413	B2B504	3434 495019	NIKOLAY BORISOV	{"email": "nikolay.borisov.1973@postgrespro.ru", "phone": "+70634962740"}
0005432784414	08D093	0561 048826	GENNADIY KUZNECOV	{"email": "kuznecov_g-1964@postgrespro.ru", "phone": "+70780256757"}
0005432784415	060A12	7787 839845	IGOR GORBUNOV	{"email": "gorbunov.i-1965@postgrespro.ru", "phone": "+70499573227"}
0005432784416	B45DB6	8726 497841	ULYANA ZAKHAROVA	{"phone": "+70448402212"}
0005432784417	B45DB6	6885 896622	ANNA FADEEVA	{"email": "fadeeva.a.1967@postgrespro.ru", "phone": "+70059566055"}
0005432784418	9156B2	1395 117530	VITALIY BARANOV	{"email": "baranovv-1975@postgrespro.ru", "phone": "+70277212758"}
0005432784419	7475B3	2558 298163	DENIS MARTYNOV	{"email": "denismartynov-1970@postgrespro.ru", "phone": "+70546511456"}
0005432784420	7475B3	8708 814206	YURIY KISELEV	{"phone": "+70944534675"}
0005432784421	DAAC54	7357 237857	LYUDMILA OSIPOVA	{"email": "lyudmila-osipova-09021982@postgrespro.ru", "phone": "+70221430512"}
0005432784422	DAAC54	7378 973771	EKATERINA ROMANOVA	{"email": "e_romanova-23121970@postgrespro.ru", "phone": "+70008412936"}
0005432784423	87E251	2041 062826	ALEKSANDR SCHERBAKOV	{"phone": "+70321885799"}
0005432784424	87E251	0857 545009	SERGEY VOLKOV	{"email": "s_volkov031976@postgrespro.ru", "phone": "+70363056186"}
0005432784425	164BD5	7766 028887	SVETLANA MEDVEDEVA	{"phone": "+70171795675"}
0005432784426	164BD5	8685 680458	VENERA KAZAKOVA	{"phone": "+70769375926"}
0005432784427	2F8C4B	1414 572059	IRINA SOROKINA	{"email": "irina.sorokina_121972@postgrespro.ru", "phone": "+70924514365"}
0005432784428	180B0C	6788 882981	EKATERINA AFANASEVA	{"email": "afanaseva-e.1970@postgrespro.ru", "phone": "+70543237362"}
0005432784429	681548	6816 096772	DARYA ZHURAVLEVA	{"email": "zhuravlevadarya-1980@postgrespro.ru", "phone": "+70951843505"}
0005432784430	F8AFA1	5948 175679	ELENA ISAEVA	{"phone": "+70494525701"}
0005432784431	D356FE	7947 669660	VASILIY VOROBEV	{"email": "v_vorobev_08021972@postgrespro.ru", "phone": "+70303899406"}
0005432784432	B2301C	2149 540662	OLGA KRASNOVA	{"phone": "+70363606100"}
0005432784433	228E21	4864 031077	GRIGORIY KISELEV	{"phone": "+70050414869"}
0005432784434	228E21	6283 168834	VIKTOR KUDRYASHOV	{"email": "v_kudryashov.051963@postgrespro.ru", "phone": "+70335456094"}
0005432784435	3E7250	7819 956504	DENIS NIKOLAEV	{"phone": "+70237372280"}
0005432784436	D5CC4C	1999 273728	YULIYA PAVLOVA	{"phone": "+70723768784"}
0005432784437	A5A26F	7139 419436	EVGENIYA MOROZOVA	{"email": "e-morozova02061979@postgrespro.ru", "phone": "+70163960695"}
0005432784438	A5A26F	1343 069646	SEMEN NIKITIN	{"phone": "+70714284324"}
0005432784439	D05D0A	7985 957415	NADEZHDA SERGEEVA	{"email": "sergeevan_05091975@postgrespro.ru", "phone": "+70008542694"}
0005432784440	D05D0A	0086 422993	ANTON VOLKOV	{"phone": "+70988329681"}
0005432784441	79B473	2739 649003	TATYANA VLASOVA	{"email": "vlasova-t-051973@postgrespro.ru", "phone": "+70018374200"}
0005432784442	79B473	5001 618756	LARISA ABRAMOVA	{"email": "larisa.abramova_1967@postgrespro.ru", "phone": "+70897359029"}
0005432784443	357322	0472 869364	ELENA MOISEEVA	{"email": "elenamoiseeva_1977@postgrespro.ru", "phone": "+70599308022"}
0005432784444	CC3C2C	4589 304300	ELENA FROLOVA	{"email": "frolovae.1968@postgrespro.ru", "phone": "+70808042483"}
0005432784445	29B0E2	3878 248523	VALERIY BELOV	{"email": "belov.v1975@postgrespro.ru", "phone": "+70209623810"}
0005432784446	156BE2	9957 303144	DENIS IVANOV	{"email": "denis-ivanov_011972@postgrespro.ru", "phone": "+70397766311"}
0005432784447	E306B0	0121 886442	ALEKSANDR KISELEV	{"email": "kiselev-a-1977@postgrespro.ru", "phone": "+70658890406"}
0005432784448	0879FF	8088 960938	DANIIL TIMOFEEV	{"phone": "+70965008175"}
0005432784449	0879FF	8241 625351	SERGEY DENISOV	{"phone": "+70945767370"}
0005432784450	A7778D	8820 584417	ULYANA KOLESNIKOVA	{"phone": "+70287385188"}
0005432784451	A7778D	6607 188939	MARINA GRISHINA	{"phone": "+70383030115"}
0005432784452	EB4B5B	9586 543783	MARGARITA VOROBEVA	{"email": "m_vorobeva.12061985@postgrespro.ru", "phone": "+70710491578"}
0005432784453	F6E6E2	8651 292767	TATYANA SEMENOVA	{"phone": "+70943368674"}
0005432784454	F6E6E2	2418 308204	YULIYA NAZAROVA	{"email": "yuliyanazarova.1976@postgrespro.ru", "phone": "+70257693866"}
0005432784455	BDA066	3291 386460	ANASTASIYA VOROBEVA	{"phone": "+70042048364"}
0005432784456	5B212E	2805 931442	VERA NIKIFOROVA	{"phone": "+70781565156"}
0005432784457	21A1CF	4814 273893	NAILYA ANTONOVA	{"phone": "+70048301033"}
0005432784458	21A1CF	0467 921671	NINA ZAKHAROVA	{"phone": "+70595171510"}
0005432784459	0586AE	9241 538887	SULTAN IVANOV	{"email": "ivanov.sultan_1973@postgrespro.ru", "phone": "+70992842241"}
0005432784460	0586AE	5019 884408	TATYANA FILIPPOVA	{"phone": "+70964957327"}
0005432784461	10D2DD	2612 652016	OLGA ZHUKOVA	{"email": "zhukovao-12011976@postgrespro.ru", "phone": "+70368231076"}
0005432784462	868F03	3270 364118	ANDREY VOLKOV	{"phone": "+70990808579"}
0005432784463	334568	7333 905629	TATYANA PETROVA	{"phone": "+70633186418"}
0005432784464	4E954C	6193 947825	VERA IVANOVA	{"email": "vivanova-1974@postgrespro.ru", "phone": "+70071655054"}
0005432784465	4E954C	2728 675934	LYUBOV IVANOVA	{"phone": "+70469059370"}
0005432784466	1F51F0	3876 203981	ELENA DANILOVA	{"phone": "+70864655290"}
0005432784467	138B71	0090 785811	ALEKSANDR GRIGOREV	{"phone": "+70571395199"}
0005432784468	138B71	6621 376345	MARINA DAVYDOVA	{"email": "davydovamarina-1958@postgrespro.ru", "phone": "+70061942922"}
0005432784469	A44031	3159 453073	VALENTINA MOROZOVA	{"phone": "+70319535046"}
0005432784470	A44031	9406 396759	NIKOLAY NIKITIN	{"email": "nikolay_nikitin_011967@postgrespro.ru", "phone": "+70910509826"}
0005432784471	478AD2	7235 867968	NINA TIKHONOVA	{"email": "n_tikhonova071972@postgrespro.ru", "phone": "+70912133853"}
0005432784472	A0B9D9	6523 404619	ANASTASIYA SCHERBAKOVA	{"email": "anastasiyascherbakova_1971@postgrespro.ru", "phone": "+70293576216"}
0005432784473	A0B9D9	6942 182881	TATYANA DAVYDOVA	{"phone": "+70458528568"}
0005432784474	652E12	3532 368569	SERGEY NAUMOV	{"email": "naumov.sergey111966@postgrespro.ru", "phone": "+70126649478"}
0005432784475	0AF9F5	3221 986755	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr.121974@postgrespro.ru", "phone": "+70936812698"}
0005432784476	BC0F44	2407 349772	VLADIMIR ROMANOV	{"email": "romanov.v15041964@postgrespro.ru", "phone": "+70998717183"}
0005432784477	68584B	3085 828658	ELENA NOVIKOVA	{"email": "novikova_e1977@postgrespro.ru", "phone": "+70508633189"}
0005432784478	68584B	2597 450798	NADEZHDA PETROVA	{"phone": "+70216665502"}
0005432784479	C5906A	1376 108324	NADEZHDA FEDOROVA	{"email": "fedorova-n_1971@postgrespro.ru", "phone": "+70240729926"}
0005432784480	B14C9F	0027 003090	VERA CHERNOVA	{"phone": "+70096435593"}
0005432784481	37AA4E	9198 976213	IRINA DAVYDOVA	{"phone": "+70654098437"}
0005432784482	7A6F91	2879 619946	ALEKSEY ILIN	{"phone": "+70316547980"}
0005432784483	48FBC4	2789 559318	ALEKSEY FROLOV	{"phone": "+70558151040"}
0005432784484	BF851A	2968 482236	NADEZHDA MAKAROVA	{"email": "makarovanadezhda.011969@postgrespro.ru", "phone": "+70560948707"}
0005432784485	BF851A	1655 989378	MARINA ALEKSEEVA	{"email": "alekseevam071965@postgrespro.ru", "phone": "+70179768572"}
0005432784486	9F9664	2897 966424	ELENA KUDRYASHOVA	{"email": "kudryashova.e22041962@postgrespro.ru", "phone": "+70939925574"}
0005432784487	CBEB4E	0908 468183	VASILIY ZHUKOV	{"phone": "+70304430237"}
0005432784488	9D69FA	9868 579664	VALENTINA NAUMOVA	{"email": "naumova-valentina061971@postgrespro.ru", "phone": "+70125619545"}
0005432784489	75DDE5	3185 925742	IRINA DENISOVA	{"phone": "+70234840524"}
0005432784490	479DC8	8896 868202	ANNA ROMANOVA	{"email": "anna_romanova_1972@postgrespro.ru", "phone": "+70628699129"}
0005432784491	F02068	3455 736269	KLAVDIYA MELNIKOVA	{"email": "melnikovaklavdiya1972@postgrespro.ru", "phone": "+70568874782"}
0005432784492	9191A7	0358 708601	TATYANA KOLESNIKOVA	{"email": "tkolesnikova.021970@postgrespro.ru", "phone": "+70816159404"}
0005432784493	9191A7	4730 821392	KONSTANTIN MIKHAYLOV	{"email": "mikhaylovkonstantin-061971@postgrespro.ru", "phone": "+70477156817"}
0005432784494	965BF5	4627 767417	MIKHAIL VASILEV	{"phone": "+70732556208"}
0005432784495	90535F	6321 261335	NINA DAVYDOVA	{"email": "ndavydova-06091977@postgrespro.ru", "phone": "+70673912545"}
0005432784496	77D356	9708 535506	IGOR ALEKSEEV	{"email": "alekseevigor081975@postgrespro.ru", "phone": "+70688902689"}
0005432784497	570C53	7673 490288	FANIYA KONOVALOVA	{"email": "konovalova_faniya-21111974@postgrespro.ru", "phone": "+70856903418"}
0005432784498	570C53	9391 362876	PAVEL MOISEEV	{"email": "moiseevp-071972@postgrespro.ru", "phone": "+70399669564"}
0005432784499	EBB3B4	4530 822923	SERGEY SEMENOV	{"phone": "+70056768319"}
0005432784500	EBB3B4	5045 500917	SOFYA VOLKOVA	{"email": "sofya-volkova-30061980@postgrespro.ru", "phone": "+70645393717"}
0005432784501	ADE09E	7521 304748	VLADIMIR KUDRYASHOV	{"phone": "+70622334750"}
0005432784502	ADE09E	6406 901318	ALEKSANDR FOMIN	{"email": "a.fomin1964@postgrespro.ru", "phone": "+70893726997"}
0005432784503	E1C7BF	0251 039279	DMITRIY IVANOV	{"email": "ivanov-d-20061973@postgrespro.ru", "phone": "+70198920533"}
0005432784504	BD4679	4917 100453	ANNA SOROKINA	{"phone": "+70631534746"}
0005432784505	BD4679	5288 949832	DIANA POPOVA	{"email": "diana.popova1962@postgrespro.ru", "phone": "+70970197645"}
0005432784506	DDE9D7	6736 346082	SERGEY IVANOV	{"email": "ivanov.s-16101977@postgrespro.ru", "phone": "+70082163948"}
0005432784507	274A1B	8933 639481	TATYANA VASILEVA	{"email": "tatyana_vasileva.1968@postgrespro.ru", "phone": "+70119350053"}
0005432784508	9F50E8	0919 060501	VALERIY ZAKHAROV	{"email": "valeriy_zakharov-1964@postgrespro.ru", "phone": "+70071104238"}
0005432784509	9F50E8	0864 874241	DIANA KARPOVA	{"phone": "+70511412933"}
0005432784510	822301	6981 459369	MARIYA GAVRILOVA	{"email": "m-gavrilova_041969@postgrespro.ru", "phone": "+70633313835"}
0005432784511	A0B394	0004 959184	TATYANA SERGEEVA	{"email": "tatyana-sergeeva071970@postgrespro.ru", "phone": "+70553855607"}
0005432784512	9E25E8	1953 514594	YULIYA VASILEVA	{"phone": "+70810189025"}
0005432784513	4AB693	3767 467791	ARINA FILATOVA	{"phone": "+70426868733"}
0005432784514	5A0541	4525 090798	PRASKOVYA IVANOVA	{"phone": "+70482628541"}
0005432784515	5A0541	4071 899531	VYACHESLAV TARASOV	{"email": "v_tarasov.20091973@postgrespro.ru", "phone": "+70701158567"}
0005432784516	B6A503	8318 911686	NINA NIKOLAEVA	{"phone": "+70894904906"}
0005432784517	80BB6B	4864 205786	VASILIY CHERNOV	{"email": "vasiliychernov.081969@postgrespro.ru", "phone": "+70360636805"}
0005432784518	80BB6B	4262 154580	RIMMA FADEEVA	{"phone": "+70891413791"}
0005432784519	80BB6B	3561 402426	ALBINA KUZNECOVA	{"email": "albinakuznecova_1970@postgrespro.ru", "phone": "+70618810357"}
0005432784520	80BB6B	6520 006491	DANIL CHERNOV	{"email": "danil.chernov011966@postgrespro.ru", "phone": "+70691598841"}
0005432784521	368250	3494 418735	ALFIYA DMITRIEVA	{"phone": "+70066610185"}
0005432784522	368250	7911 688786	ALEKSEY MIKHAYLOV	{"phone": "+70802744393"}
0005432784523	368250	2854 071896	ELENA VOROBEVA	{"phone": "+70706624761"}
0005432784524	EEAEF1	7413 039789	NADEZHDA EFIMOVA	{"email": "efimova-n_1972@postgrespro.ru", "phone": "+70695009103"}
0005432784525	E5319C	7634 900614	OLGA EGOROVA	{"phone": "+70513211668"}
0005432784526	57BF03	9614 213725	DARYA NAZAROVA	{"email": "nazarovadarya_1963@postgrespro.ru", "phone": "+70134711452"}
0005432784527	051A35	8900 967416	TATYANA ABRAMOVA	{"phone": "+70834836778"}
0005432784528	051A35	5662 770759	YURIY DAVYDOV	{"phone": "+70679149895"}
0005432784529	6041D5	8951 832876	NATALYA YAKOVLEVA	{"phone": "+70079981145"}
0005432784530	6041D5	0337 509475	VLADIMIR SCHERBAKOV	{"phone": "+70186776395"}
0005432784531	99AF17	5914 971451	ALEKSANDR ZAKHAROV	{"email": "zakharov-a.121991@postgrespro.ru", "phone": "+70804596148"}
0005432784532	9A0DFC	7482 841024	RIMA YAKOVLEVA	{"phone": "+70134652238"}
0005432784533	7C3A90	6906 225917	SERGEY ALEKSEEV	{"phone": "+70333616176"}
0005432784534	7C3A90	6114 863408	DANIIL KUDRYASHOV	{"phone": "+70265982570"}
0005432784535	7C3A90	9800 423544	MIKHAIL ISAEV	{"email": "mikhail_isaev.19091974@postgrespro.ru", "phone": "+70397024612"}
0005432784536	B7B156	4232 866375	LARISA GRISHINA	{"phone": "+70262302625"}
0005432784537	C623CF	3933 825548	VASILIY IVANOV	{"phone": "+70272474460"}
0005432784538	ACAD45	6056 999023	ANNA MIKHAYLOVA	{"phone": "+70033672030"}
0005432784539	663589	6474 585098	NADEZHDA KAZAKOVA	{"email": "kazakova.nadezhda_101990@postgrespro.ru", "phone": "+70166933196"}
0005432784540	CEF74B	6634 478884	ILONA MAKSIMOVA	{"email": "i_maksimova.071967@postgrespro.ru", "phone": "+70075658609"}
0005432784541	A1737B	2895 766411	RAFAEL MIKHAYLOV	{"phone": "+70111931613"}
0005432784542	F9653E	2206 166977	YURIY NIKITIN	{"phone": "+70781008008"}
0005432784543	852D7E	2365 250305	OLEG VOLKOV	{"phone": "+70776346121"}
0005432784544	3FE669	5038 602824	MIKHAIL KRASNOV	{"phone": "+70315677910"}
0005432784545	3A3862	0399 411625	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr111979@postgrespro.ru", "phone": "+70197169068"}
0005432784546	3A3862	6168 855357	VADIM KRASNOV	{"email": "krasnov_vadim08061967@postgrespro.ru", "phone": "+70284403928"}
0005432784547	D389F9	8894 620201	VALERIY SEMENOV	{"phone": "+70794590114"}
0005432784548	D389F9	2001 796099	SERGEY KARPOV	{"phone": "+70496754994"}
0005432784549	D389F9	3043 787239	ANDREY FROLOV	{"email": "a-frolov_1974@postgrespro.ru", "phone": "+70008112107"}
0005432784550	08E614	0754 275573	YURIY VOROBEV	{"email": "vorobev.y.091975@postgrespro.ru", "phone": "+70203693877"}
0005432784551	F84E31	3276 482104	ALEKSEY ALEKSEEV	{"phone": "+70510078394"}
0005432784552	E5BF17	2864 664378	SERGEY ZAKHAROV	{"email": "zakharov.s_1969@postgrespro.ru", "phone": "+70428386921"}
0005432784553	A2F8B9	6070 881028	PAVEL ZHURAVLEV	{"phone": "+70956054451"}
0005432784554	275C93	0626 024503	SERGEY AFANASEV	{"email": "sergey.afanasev-1978@postgrespro.ru", "phone": "+70732916591"}
0005432784555	275C93	4066 869923	GALINA KOVALEVA	{"email": "kovaleva-g111971@postgrespro.ru", "phone": "+70745704700"}
0005432784556	69740B	3804 525102	DZHAMILYA KOROLEVA	{"phone": "+70560662103"}
0005432784557	E801B5	2528 928122	OLGA FEDOROVA	{"phone": "+70799515892"}
0005432784558	B6EE3C	0495 454831	MAKSIM TIKHONOV	{"email": "maksim-tikhonov_011975@postgrespro.ru", "phone": "+70047612225"}
0005432784559	649A78	7232 455086	VLADIMIR MELNIKOV	{"phone": "+70043816321"}
0005432784560	CAE199	5172 415455	MARIYA NESTEROVA	{"email": "nesterovam.021974@postgrespro.ru", "phone": "+70844320160"}
0005432784561	CAE199	0080 773700	DMITRIY NIKITIN	{"email": "nikitin-dmitriy_111968@postgrespro.ru", "phone": "+70942408273"}
0005432784562	02B6C7	5923 230192	VLADIMIR KOROLEV	{"phone": "+70716081045"}
0005432784563	02B6C7	5887 042222	ELENA EFREMOVA	{"email": "efremovaelena17031975@postgrespro.ru", "phone": "+70390069611"}
0005432784564	02B6C7	4211 391014	VYACHESLAV MAKAROV	{"phone": "+70869143646"}
0005432784565	D26EDD	4284 787600	ELIZAVETA ABRAMOVA	{"phone": "+70305499165"}
0005432784566	3C4A61	2155 993205	RUMIYA KARPOVA	{"email": "r.karpova1971@postgrespro.ru", "phone": "+70112180878"}
0005432784567	E4DBFF	9186 072429	YULIYA NIKOLAEVA	{"phone": "+70799648935"}
0005432784568	2EC209	3489 637653	NIKOLAY ISAEV	{"email": "isaev_n061964@postgrespro.ru", "phone": "+70151174552"}
0005432784569	2EC209	7560 961789	SERGEY FILIPPOV	{"email": "filippovsergey-1962@postgrespro.ru", "phone": "+70848348984"}
0005432784570	2EC209	5407 716771	ILMIRA GORBUNOVA	{"phone": "+70361701717"}
0005432784571	49A11E	8518 948050	GLEB ALEKSANDROV	{"email": "aleksandrovg_081975@postgrespro.ru", "phone": "+70308235606"}
0005432784572	326D10	7425 534601	ALEKSANDR KUDRYASHOV	{"email": "a_kudryashov.051968@postgrespro.ru", "phone": "+70332545367"}
0005432784573	326D10	2571 845206	VLADIMIR DENISOV	{"email": "vladimir.denisov.1971@postgrespro.ru", "phone": "+70991104467"}
0005432784574	544452	3897 880974	ANASTASIYA KARPOVA	{"email": "anastasiyakarpova-101971@postgrespro.ru", "phone": "+70976859654"}
0005432784575	544452	1878 614628	DARYA FOMINA	{"email": "d.fomina.15051967@postgrespro.ru", "phone": "+70132792223"}
0005432784576	911D03	2085 242815	NADEZHDA AFANASEVA	{"email": "afanasevanadezhda-091974@postgrespro.ru", "phone": "+70128253699"}
0005432784577	911D03	0532 578258	EKATERINA VOLKOVA	{"phone": "+70396348204"}
0005432784578	FE3D6A	6252 548228	VIOLETTA ISAEVA	{"email": "isaevavioletta-071972@postgrespro.ru", "phone": "+70112442042"}
0005432784579	FE3D6A	5142 348267	SERGEY IVANOV	{"email": "ivanov-sergey_1978@postgrespro.ru", "phone": "+70291623622"}
0005432784580	98F9C8	9205 589731	NIKOLAY SMIRNOV	{"phone": "+70967615955"}
0005432784581	71AFC4	5741 412066	DANIIL MOROZOV	{"email": "daniil.morozov.071958@postgrespro.ru", "phone": "+70895324468"}
0005432784582	71AFC4	3517 798918	VIKTOR MOROZOV	{"email": "morozov_v031982@postgrespro.ru", "phone": "+70110494056"}
0005432784583	2C6560	0539 554306	DMITRIY STEPANOV	{"phone": "+70181738490"}
0005432784584	2C6560	7785 890626	SERGEY GUSEV	{"phone": "+70186096864"}
0005432784585	1E3D12	2192 635821	EVGENIY ABRAMOV	{"email": "abramov.evgeniy.101976@postgrespro.ru", "phone": "+70289863956"}
0005432784586	1E3D12	2483 859176	RAISA KOLESNIKOVA	{"phone": "+70049622904"}
0005432784587	344092	1748 627617	LIDIYA POPOVA	{"email": "l_popova-111984@postgrespro.ru", "phone": "+70101351289"}
0005432784588	2B9B80	4661 513998	ELENA PAVLOVA	{"email": "e-pavlova1962@postgrespro.ru", "phone": "+70200575012"}
0005432784589	2B9B80	8498 565388	YULIYA KUZMINA	{"phone": "+70394956444"}
0005432784590	2B9B80	1084 657416	NATALIYA NIKITINA	{"email": "nataliya-nikitina071971@postgrespro.ru", "phone": "+70575633965"}
0005432784591	AADD08	3476 811513	RUSTEM KUZNECOV	{"phone": "+70350106225"}
0005432784592	AADD08	7782 050481	ALEKSANDR SEMENOV	{"email": "semenov-a_1986@postgrespro.ru", "phone": "+70014235860"}
0005432784593	057D8F	0182 471611	ALENA KUZNECOVA	{"phone": "+70539401420"}
0005432784594	A90FFF	2703 704216	OLGA SCHERBAKOVA	{"phone": "+70286060578"}
0005432784595	A90FFF	0528 926408	ALEKSANDR DENISOV	{"email": "aleksandrdenisov-16091968@postgrespro.ru", "phone": "+70392387423"}
0005432784596	A90FFF	4163 534540	VITALIY SCHERBAKOV	{"email": "v_scherbakov_1979@postgrespro.ru", "phone": "+70168603236"}
0005432784597	094622	4509 292572	EVGENIY KISELEV	{"email": "e_kiselev_30111972@postgrespro.ru", "phone": "+70239270991"}
0005432784598	D3DFC8	2533 206395	VIKTOR DMITRIEV	{"email": "viktor-dmitriev-05121967@postgrespro.ru", "phone": "+70796649812"}
0005432784599	6B5047	5844 368565	ANATOLIY ANDREEV	{"phone": "+70872543708"}
0005432784600	6B5047	9934 123041	EVGENIY EGOROV	{"phone": "+70177376383"}
0005432784601	87F364	4629 201579	EKATERINA MAKAROVA	{"email": "makarova-ekaterina.1974@postgrespro.ru", "phone": "+70807977678"}
0005432784602	87F364	2137 335925	NAZAR ORLOV	{"email": "orlov_nazar.1982@postgrespro.ru", "phone": "+70729936454"}
0005432784603	2C541F	9298 826586	DMITRIY AFANASEV	{"email": "dmitriy.afanasev.1963@postgrespro.ru", "phone": "+70377335338"}
0005432784604	2C541F	1374 105915	LARISA SEMENOVA	{"phone": "+70104385203"}
0005432784605	5B0508	8604 191710	IRINA RODIONOVA	{"phone": "+70965987260"}
0005432784606	013682	8584 818855	VLADIMIR SEMENOV	{"email": "semenovv.1976@postgrespro.ru", "phone": "+70700198156"}
0005432784607	013682	4788 208325	VLADIMIR EGOROV	{"phone": "+70958658603"}
0005432784608	013682	7672 387623	YURIY POPOV	{"phone": "+70564882835"}
0005432784609	CEEAE7	4899 687974	NADEZHDA SAVELEVA	{"phone": "+70833213556"}
0005432784610	E39114	0479 337348	POLINA IVANOVA	{"phone": "+70269771700"}
0005432784611	87EBE9	5276 237100	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov.041972@postgrespro.ru", "phone": "+70925991162"}
0005432784612	7B131E	7241 479005	GALINA FILIPPOVA	{"email": "filippova_galina_23121972@postgrespro.ru", "phone": "+70506079147"}
0005432784613	7B131E	0863 031615	DENIS SOKOLOV	{"phone": "+70501756934"}
0005432784614	45070F	6928 434660	ZINAIDA ORLOVA	{"email": "orlovazinaida071976@postgrespro.ru", "phone": "+70073106885"}
0005432784615	7A21D6	9500 013460	VIKTOR KUZMIN	{"phone": "+70522032696"}
0005432784616	AC91A0	9707 040130	EVGENIY PAVLOV	{"email": "pavlovevgeniy1977@postgrespro.ru", "phone": "+70745389328"}
0005432784617	ECC237	9693 684260	ANATOLIY IVANOV	{"phone": "+70682989695"}
0005432784618	E51963	3237 470083	GALINA KARPOVA	{"phone": "+70737396076"}
0005432784619	5C0FD9	9858 485432	BORIS GAVRILOV	{"email": "bgavrilov-101973@postgrespro.ru", "phone": "+70433821318"}
0005432784620	5C0FD9	2046 020677	LYUBOV IVANOVA	{"email": "ivanova.l_071984@postgrespro.ru", "phone": "+70990288305"}
0005432784621	FF5ADD	3651 673574	NINA IVANOVA	{"email": "ivanova.nina_06051971@postgrespro.ru", "phone": "+70689114565"}
0005432784622	FF5ADD	1642 671161	ELENA KUDRYASHOVA	{"phone": "+70469198114"}
0005432784623	1B2A7F	3272 717357	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev-1968@postgrespro.ru", "phone": "+70733491999"}
0005432784624	1B2A7F	3527 096123	VIKTORIYA MAKAROVA	{"phone": "+70173400209"}
0005432784625	916AFA	6434 350215	LILIYA FROLOVA	{"phone": "+70509757585"}
0005432784626	916AFA	9913 057627	VIKTOR ANDREEV	{"phone": "+70555694093"}
0005432784627	10AB12	6682 619831	LYUDMILA MIKHAYLOVA	{"phone": "+70580524703"}
0005432784628	9160C1	9849 891897	VLADIMIR IVANOV	{"email": "ivanov_v-051980@postgrespro.ru", "phone": "+70214778159"}
0005432784629	D21433	7445 086961	VALENTINA LAZAREVA	{"email": "valentina_lazareva091975@postgrespro.ru", "phone": "+70442152730"}
0005432784630	658299	1313 697947	VALENTINA SOLOVEVA	{"phone": "+70797444315"}
0005432784631	1B2E6D	4447 282540	ALEKSANDRA KUZMINA	{"phone": "+70084103484"}
0005432784632	9F0E69	9849 242315	MIKHAIL ZAKHAROV	{"phone": "+70698768215"}
0005432784633	9F0E69	3201 160950	POLINA KONOVALOVA	{"phone": "+70049068253"}
0005432784634	B7B9BB	6275 942768	OLEG TIKHONOV	{"email": "oleg_tikhonov06101966@postgrespro.ru", "phone": "+70087806299"}
0005432784635	6973F4	7231 727161	IVAN MELNIKOV	{"phone": "+70378234437"}
0005432784636	F1C631	3794 539651	VYACHESLAV SOLOVEV	{"email": "solovev-vyacheslav-041974@postgrespro.ru", "phone": "+70199778005"}
0005432784637	276F14	9613 395725	SVETLANA SOLOVEVA	{"phone": "+70665191602"}
0005432784638	276F14	3011 644889	EKATERINA ZOTOVA	{"phone": "+70665330198"}
0005432784639	CECE6D	1303 086837	NIKOLAY ZAKHAROV	{"phone": "+70611729234"}
0005432784640	CECE6D	4423 154079	ALINA YUDINA	{"phone": "+70660943170"}
0005432784641	CECE6D	8347 094624	ALEKSEY FOMIN	{"phone": "+70180205974"}
0005432784642	6F3008	0131 829537	VASILIY VASILEV	{"email": "vvasilev-111974@postgrespro.ru", "phone": "+70698858794"}
0005432784643	6F3008	9466 760437	SERGEY YAKOVLEV	{"email": "yakovlev.s.1970@postgrespro.ru", "phone": "+70114526198"}
0005432784755	FC3E40	7509 473116	SERGEY SEMENOV	{"phone": "+70961668279"}
0005432784644	C43293	6743 057663	ELENA KOZLOVA	{"email": "e.kozlova.1967@postgrespro.ru", "phone": "+70046226133"}
0005432784645	1D5C7C	6874 765895	TATYANA ZHURAVLEVA	{"phone": "+70810965818"}
0005432784646	956B03	1044 502156	TAISIYA SERGEEVA	{"email": "taisiyasergeeva.20121977@postgrespro.ru", "phone": "+70851434719"}
0005432784647	3F3678	2536 677115	NONNA KULIKOVA	{"email": "kulikovan101972@postgrespro.ru", "phone": "+70817692018"}
0005432784648	407118	1607 622060	EGOR MARTYNOV	{"email": "martynov.e12021971@postgrespro.ru", "phone": "+70519731423"}
0005432784649	407118	5688 167902	NAIL EGOROV	{"phone": "+70918181781"}
0005432784650	158B94	0428 925422	NATALYA POTAPOVA	{"phone": "+70067231294"}
0005432784651	649CE3	6568 185762	VERA LOGINOVA	{"email": "loginova_vera1964@postgrespro.ru", "phone": "+70962649697"}
0005432784652	649CE3	8477 118201	MIKHAIL SCHERBAKOV	{"phone": "+70006741647"}
0005432784653	EAAAB7	4420 167824	IVAN AFANASEV	{"phone": "+70102264919"}
0005432784654	0E770D	0251 052707	KONSTANTIN ILIN	{"phone": "+70915965593"}
0005432784655	D326A2	1307 580857	IVAN BELOV	{"phone": "+70734353566"}
0005432784656	D4D492	7903 377760	EVGENIY SERGEEV	{"email": "evgeniy.sergeev-11051978@postgrespro.ru", "phone": "+70936275294"}
0005432784657	D4D492	0639 124629	PAVEL SCHERBAKOV	{"email": "scherbakov-p-17051957@postgrespro.ru", "phone": "+70459209139"}
0005432784658	25F8BC	6685 944620	RUSTAM SOLOVEV	{"phone": "+70159887024"}
0005432784659	25F8BC	3431 842754	ANASTASIYA FOMINA	{"phone": "+70236480868"}
0005432784660	199732	2787 981281	YURIY ANTONOV	{"phone": "+70199845724"}
0005432784661	635341	3612 861651	LIDIYA KISELEVA	{"phone": "+70194618446"}
0005432784662	635341	3688 339565	ALEKSANDR VOLKOV	{"phone": "+70991970216"}
0005432784663	38E315	3197 824087	VALENTINA FOMINA	{"email": "valentina.fomina_1980@postgrespro.ru", "phone": "+70180358926"}
0005432784664	5518AF	0595 077187	ELENA ANISIMOVA	{"email": "anisimova_elena_18041975@postgrespro.ru", "phone": "+70355867284"}
0005432784665	AFCDC8	4255 541186	SERGEY TARASOV	{"phone": "+70220544166"}
0005432784666	AFCDC8	5658 054757	ARTEM SAVELEV	{"email": "savelev-a1980@postgrespro.ru", "phone": "+70027621933"}
0005432784667	832110	9119 558327	VLADIMIR GUSEV	{"email": "gusev-v.081964@postgrespro.ru", "phone": "+70674463692"}
0005432784668	DD03AD	9077 259931	BORIS SHEVCHENKO	{"email": "shevchenko_b.101963@postgrespro.ru", "phone": "+70691239386"}
0005432784669	DD03AD	9686 827650	ROSTISLAV ZAYCEV	{"phone": "+70916880750"}
0005432784670	7B902E	7625 848627	IRINA PAVLOVA	{"email": "pavlova-irina_15071972@postgrespro.ru", "phone": "+70348934351"}
0005432784671	06531E	9770 552505	YULIYA KUZNECOVA	{"email": "kuznecovay19021975@postgrespro.ru", "phone": "+70030190215"}
0005432784672	75BC11	1334 337171	VALENTINA VLASOVA	{"phone": "+70345107372"}
0005432784673	75BC11	6367 941592	EKATERINA SMIRNOVA	{"email": "e_smirnova_121981@postgrespro.ru", "phone": "+70642082275"}
0005432784674	13B578	0924 297936	LIDIYA TIMOFEEVA	{"email": "ltimofeeva041975@postgrespro.ru", "phone": "+70841987607"}
0005432784675	13B578	8737 820905	OLESYA STEPANOVA	{"email": "stepanova.olesya.28021984@postgrespro.ru", "phone": "+70187608441"}
0005432784676	13B578	1252 490615	OKSANA POPOVA	{"email": "o-popova.1970@postgrespro.ru", "phone": "+70390918342"}
0005432784677	812A0F	2784 104450	MIKHAIL SIDOROV	{"email": "sidorov_m11071971@postgrespro.ru", "phone": "+70236276838"}
0005432784678	812A0F	1898 314797	OLESYA AKIMOVA	{"email": "akimova_olesya-27101969@postgrespro.ru", "phone": "+70185123403"}
0005432784679	2D2153	1496 140990	OLGA YUDINA	{"phone": "+70691193685"}
0005432784680	2D2153	9965 707401	MAKSIM PETROV	{"email": "m-petrov_1980@postgrespro.ru", "phone": "+70606256867"}
0005432784681	4AAF8C	4462 773749	NADEZHDA FEDOROVA	{"email": "n_fedorova15091988@postgrespro.ru", "phone": "+70707571156"}
0005432784682	D7D5F0	3480 497595	ANDREY VOLKOV	{"phone": "+70501825572"}
0005432784683	E38A2E	0609 001402	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov.1987@postgrespro.ru", "phone": "+70245327002"}
0005432784684	879F6C	5415 525426	ALEKSEY SAVELEV	{"email": "savelev.a041978@postgrespro.ru", "phone": "+70028901514"}
0005432784685	589BFE	0543 462680	ROMAN SCHERBAKOV	{"email": "r.scherbakov-081967@postgrespro.ru", "phone": "+70482443097"}
0005432784686	3DD161	7026 251001	SERGEY PAVLOV	{"email": "pavlovsergey02081956@postgrespro.ru", "phone": "+70708425023"}
0005432784687	CE7AE1	3091 870088	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov25111978@postgrespro.ru", "phone": "+70813846329"}
0005432784688	9E01C0	7131 114515	OLEG MAKAROV	{"email": "makarov_o.1970@postgrespro.ru", "phone": "+70410502345"}
0005432784689	9E01C0	2164 902926	ALEKSANDR ZAKHAROV	{"phone": "+70597897807"}
0005432784690	9E01C0	1152 277355	OLGA MASLOVA	{"email": "maslovaolga-17111972@postgrespro.ru", "phone": "+70676691622"}
0005432784691	6EC900	8038 523807	RAMIL ZAKHAROV	{"email": "ramilzakharov-1963@postgrespro.ru", "phone": "+70695773701"}
0005432784692	E1B36D	3926 327312	IVAN BONDARENKO	{"phone": "+70315396040"}
0005432784693	756EF5	3675 765952	ELENA SMIRNOVA	{"phone": "+70002865346"}
0005432784694	73A4D7	7220 157557	NURLAN IVANOV	{"email": "nurlanivanov-1979@postgrespro.ru", "phone": "+70085948997"}
0005432784695	AF8112	2063 236842	NATALYA NIKOLAEVA	{"phone": "+70018753825"}
0005432784696	92F062	1693 535800	ANNA ILINA	{"email": "anna_ilina-011981@postgrespro.ru", "phone": "+70371164348"}
0005432784697	DD0682	6643 990746	GRIGORIY TIKHONOV	{"email": "tikhonovg.06021972@postgrespro.ru", "phone": "+70981286972"}
0005432784698	DD0682	0379 637828	SVETLANA KOZLOVA	{"email": "svetlana.kozlova1978@postgrespro.ru", "phone": "+70767784463"}
0005432784699	599423	6646 570650	VIKTOR ALEKSEEV	{"email": "v-alekseev09091971@postgrespro.ru", "phone": "+70905057522"}
0005432784700	599423	6640 109572	ELENA MAKAROVA	{"email": "makarovae_091958@postgrespro.ru", "phone": "+70076977569"}
0005432784701	6DD426	5342 588598	VERONIKA ERMAKOVA	{"email": "ermakova_v1972@postgrespro.ru", "phone": "+70929841277"}
0005432784702	1D27FE	4671 461440	STEPAN SEMENOV	{"email": "semenov_stepan1967@postgrespro.ru", "phone": "+70791273232"}
0005432784703	F0E5F0	7122 702858	LYUBOV FROLOVA	{"email": "l_frolova-121975@postgrespro.ru", "phone": "+70162810767"}
0005432784704	9B1135	5317 793662	PAVEL OSIPOV	{"email": "osipov_p.091973@postgrespro.ru", "phone": "+70320890937"}
0005432784705	F63D04	4117 824137	LARISA KOVALEVA	{"phone": "+70114033429"}
0005432784706	37FAEF	0168 113939	ALEKSANDR BORISOV	{"email": "borisov.a.08091983@postgrespro.ru", "phone": "+70552955258"}
0005432784707	54676A	2996 947944	ALEKSEY ZAYCEV	{"phone": "+70567815777"}
0005432784708	E48887	9751 365591	OLGA MAKAROVA	{"email": "o.makarova051969@postgrespro.ru", "phone": "+70521236084"}
0005432784709	DADD76	7560 541433	MARIYA KALININA	{"phone": "+70718251531"}
0005432784710	DADD76	1133 729689	MARIYA RYABOVA	{"phone": "+70310120555"}
0005432784711	68CD61	2734 357572	EVGENIY KAZAKOV	{"email": "evgeniy.kazakov-1968@postgrespro.ru", "phone": "+70275799534"}
0005432784712	9A9465	5815 542646	BULAT MELNIKOV	{"email": "b-melnikov29051978@postgrespro.ru", "phone": "+70810239723"}
0005432784713	964532	8008 599545	VITALIY NAZAROV	{"phone": "+70544978972"}
0005432784714	460C6A	0910 778468	MARINA NIKITINA	{"email": "nikitina.marina_06061981@postgrespro.ru", "phone": "+70277712257"}
0005432784715	460C6A	4382 314295	EVGENIY ABRAMOV	{"email": "abramov-e_1973@postgrespro.ru", "phone": "+70354141288"}
0005432784716	460C6A	9875 591283	ANDREY KISELEV	{"phone": "+70508481550"}
0005432784717	5020C3	0108 284350	MARIYA VLASOVA	{"email": "vlasovam1977@postgrespro.ru", "phone": "+70352630742"}
0005432784718	A00687	1592 087647	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_10061967@postgrespro.ru", "phone": "+70264995620"}
0005432784719	A00687	9746 631790	VALENTINA KUZMINA	{"email": "kuzmina_v1968@postgrespro.ru", "phone": "+70621170855"}
0005432784720	B10B9E	3474 678612	NATALYA ZAKHAROVA	{"phone": "+70510583828"}
0005432784721	B10B9E	5510 242731	OLEG ANTONOV	{"email": "oleg-antonov.21031977@postgrespro.ru", "phone": "+70918868289"}
0005432784722	8BF4E1	8682 278234	VIKTORIYA KOMAROVA	{"phone": "+70041949799"}
0005432784723	B9356C	8409 709995	ANNA POPOVA	{"phone": "+70829476855"}
0005432784724	B9356C	3009 015132	ALEKSANDR VLASOV	{"phone": "+70994427683"}
0005432784725	B9356C	6132 970555	ALEKSEY POPOV	{"email": "popovaleksey27061979@postgrespro.ru", "phone": "+70176931088"}
0005432784726	11438A	0550 185062	ALEKSEY KUZMIN	{"phone": "+70427875618"}
0005432784727	3CDA2F	2278 924274	EKATERINA BARANOVA	{"phone": "+70029952651"}
0005432784728	9B4BD2	5145 068013	VALENTINA MALYSHEVA	{"email": "malysheva_valentina-121989@postgrespro.ru", "phone": "+70134150745"}
0005432784729	FA2B34	2090 334931	LIDIYA ERMAKOVA	{"phone": "+70154925076"}
0005432784730	67C405	3859 065199	DMITRIY GORBUNOV	{"phone": "+70677609150"}
0005432784731	7A2512	1971 047846	ALEKSANDR ABRAMOV	{"phone": "+70484600342"}
0005432784732	7A2512	7465 078074	VLADIMIR ANTONOV	{"phone": "+70099508383"}
0005432784733	1CF69D	7910 254849	ANATOLIY VOLKOV	{"phone": "+70757857185"}
0005432784734	FBCA2A	2844 005866	NIKOLAY NAZAROV	{"email": "nazarov_n1960@postgrespro.ru", "phone": "+70705444328"}
0005432784735	09F070	2076 567546	IGOR PAVLOV	{"phone": "+70843073908"}
0005432784736	F9929C	1086 055700	EKATERINA MAKSIMOVA	{"phone": "+70601454614"}
0005432784737	B8F0FD	8293 180929	ALEKSANDR PETROV	{"email": "petrovaleksandr-1979@postgrespro.ru", "phone": "+70469169874"}
0005432784738	A340D7	7679 085714	LYUDMILA BELOVA	{"email": "belova_lyudmila-121967@postgrespro.ru", "phone": "+70738717473"}
0005432784739	A340D7	8013 793027	VIKTORIYA MAKAROVA	{"phone": "+70966834427"}
0005432784740	78C6A1	1950 025616	SERGEY STEPANOV	{"email": "stepanovsergey.22011975@postgrespro.ru", "phone": "+70643460364"}
0005432784741	78C6A1	9941 367508	DMITRIY FEDOTOV	{"phone": "+70289905366"}
0005432784742	8473F1	4434 586415	NIKOLAY ZHURAVLEV	{"phone": "+70753519319"}
0005432784743	8473F1	0218 224722	PAVEL KONOVALOV	{"phone": "+70450220657"}
0005432784744	8473F1	9801 244817	ANASTASIYA IVANOVA	{"phone": "+70256920043"}
0005432784745	AE0BCD	4102 362422	VIKTOR ZAKHAROV	{"email": "zakharov-v-061968@postgrespro.ru", "phone": "+70159584606"}
0005432784746	AE0BCD	2034 938290	ALEKSANDR EGOROV	{"email": "a.egorov_121969@postgrespro.ru", "phone": "+70941161934"}
0005432784747	057A41	8190 408659	ANNA PAVLOVA	{"email": "pavlova_anna13031960@postgrespro.ru", "phone": "+70996933562"}
0005432784748	057A41	5750 723769	SERGEY IVANOV	{"phone": "+70767394370"}
0005432784749	031428	7491 423859	OLGA POPOVA	{"email": "o-popova081980@postgrespro.ru", "phone": "+70015416628"}
0005432784750	36B685	5129 847505	OLGA POPOVA	{"email": "olga-popova.1989@postgrespro.ru", "phone": "+70977261041"}
0005432784751	36B685	7514 088748	POLINA MOISEEVA	{"email": "moiseeva_p-1978@postgrespro.ru", "phone": "+70331606820"}
0005432784752	36B685	3967 422958	VLADIMIR SMIRNOV	{"email": "vladimirsmirnov_1972@postgrespro.ru", "phone": "+70907663664"}
0005432784753	FC3E40	6652 273587	TATYANA TARASOVA	{"email": "tarasova_tatyana_1968@postgrespro.ru", "phone": "+70523194739"}
0005432784754	FC3E40	3566 435132	IRINA SOROKINA	{"phone": "+70035815319"}
0005432784756	094C01	6980 125444	YURIY TARASOV	{"phone": "+70585991514"}
0005432784757	094C01	9666 534689	DANILA ZAYCEV	{"phone": "+70534429344"}
0005432784758	E26FC4	4598 136200	ALEKSANDR MAKSIMOV	{"phone": "+70389235563"}
0005432784759	0B546C	2844 621275	VALENTIN KUZMIN	{"phone": "+70926963538"}
0005432784760	0B546C	6464 813024	ANNA BARANOVA	{"phone": "+70840403998"}
0005432784761	8E852B	0372 766525	IRINA POTAPOVA	{"email": "potapova.i.101962@postgrespro.ru", "phone": "+70300594059"}
0005432784762	49D6E6	6307 859734	VALERIY SIDOROV	{"email": "sidorov_valeriy.051970@postgrespro.ru", "phone": "+70549334091"}
0005432784763	BD0A58	2743 828727	EDUARD KISELEV	{"phone": "+70793793287"}
0005432784764	BD0A58	1238 810852	OLGA ZHURAVLEVA	{"phone": "+70089596704"}
0005432784765	BD0A58	9215 192574	ALEKSANDRA LEBEDEVA	{"phone": "+70701025374"}
0005432784766	86B0DF	7036 613552	VALERIYA AFANASEVA	{"phone": "+70339100096"}
0005432784767	CCA3C3	9153 356831	ELENA KUZNECOVA	{"email": "e-kuznecova-1976@postgrespro.ru", "phone": "+70239985740"}
0005432784768	3A73BB	6647 072534	VERA KAZAKOVA	{"email": "kazakova_v.1968@postgrespro.ru", "phone": "+70947427223"}
0005432784769	3A73BB	1011 261038	EVDOKIYA MOROZOVA	{"phone": "+70459799232"}
0005432784770	3A73BB	1086 372272	MAKSIM PAVLOV	{"phone": "+70957226644"}
0005432784771	AD3E0B	7188 180501	ALEKSEY FEDOTOV	{"email": "aleksey.fedotov-051959@postgrespro.ru", "phone": "+70154838358"}
0005432784772	C3BA3B	8038 659554	LYUDMILA ILINA	{"email": "ilina_lyudmila_071960@postgrespro.ru", "phone": "+70852993849"}
0005432784773	0ABF30	2767 809767	SVETLANA AKIMOVA	{"phone": "+70814127648"}
0005432784774	16D0DD	9151 980677	ELENA MELNIKOVA	{"email": "melnikova-elena-1979@postgrespro.ru", "phone": "+70552535809"}
0005432784775	16D0DD	8299 212991	NADIYA MAKAROVA	{"phone": "+70886709681"}
0005432784776	269DDC	1536 839640	NIKITA VASILEV	{"email": "vasilev-n01041978@postgrespro.ru", "phone": "+70457688174"}
0005432784777	9AFCB1	8509 962337	OLGA GRISHINA	{"email": "o.grishina-27121965@postgrespro.ru", "phone": "+70702422121"}
0005432784778	3EF464	4676 077502	ELVIRA BORISOVA	{"email": "borisova-elvira.04121968@postgrespro.ru", "phone": "+70925104201"}
0005432784779	3EF464	9671 433866	MARINA FROLOVA	{"phone": "+70580265073"}
0005432784780	7AB75B	4687 938412	ALEKSANDR OSIPOV	{"phone": "+70239734205"}
0005432784781	FF3234	1904 515640	VLADIMIR KARPOV	{"phone": "+70661992852"}
0005432784782	D7A720	4201 813203	LYUDMILA MOISEEVA	{"phone": "+70635313748"}
0005432784783	4C1059	7349 122404	TATYANA SEMENOVA	{"phone": "+70224274231"}
0005432784784	56F2C3	0668 999044	ALEKSEY MAKAROV	{"email": "makarov.a-1976@postgrespro.ru", "phone": "+70803639181"}
0005432784785	56F2C3	9045 204123	VLADIMIR TIKHONOV	{"phone": "+70952967221"}
0005432784786	56F2C3	6488 825195	MIKHAIL NOVIKOV	{"email": "m_novikov_101959@postgrespro.ru", "phone": "+70085768301"}
0005432784787	FE6729	7022 794426	GALINA KOLESNIKOVA	{"phone": "+70209713989"}
0005432784788	0AA439	5807 868891	LEONID KUZNECOV	{"email": "kuznecovleonid-1972@postgrespro.ru", "phone": "+70046681678"}
0005432784789	57E0E6	4499 873207	EKATERINA FROLOVA	{"email": "frolova-e-19071968@postgrespro.ru", "phone": "+70822831662"}
0005432784790	7332E6	6042 190744	VYACHESLAV ANDREEV	{"phone": "+70248737834"}
0005432784791	7332E6	0143 388244	DMITRIY ZAYCEV	{"email": "dmitriy-zaycev.091974@postgrespro.ru", "phone": "+70657255311"}
0005432784792	87CED3	9627 468489	VALENTINA STEPANOVA	{"phone": "+70733071201"}
0005432784793	C6CB26	4219 421730	SERGEY MATVEEV	{"phone": "+70524587426"}
0005432784794	18F544	0093 895386	LIDIYA ANDREEVA	{"email": "andreeva_lidiya011977@postgrespro.ru", "phone": "+70586098579"}
0005432784795	BD5FFC	8625 630437	ELENA FOMINA	{"email": "fomina-elena-041973@postgrespro.ru", "phone": "+70171053152"}
0005432784796	BD5FFC	7469 589023	ALEKSEY VLASOV	{"phone": "+70572830125"}
0005432784797	42AB43	9790 635483	VLADIMIR DAVYDOV	{"email": "vladimir-davydov.121975@postgrespro.ru", "phone": "+70276356220"}
0005432784798	B30996	6600 433865	IRINA EGOROVA	{"phone": "+70611054004"}
0005432784799	B30996	9336 006358	LYUDMILA SOKOLOVA	{"phone": "+70269421926"}
0005432784800	937B74	7202 588422	VERA PETROVA	{"email": "petrova-vera.1974@postgrespro.ru", "phone": "+70926111589"}
0005432784801	7A86D5	3503 442422	VLADIMIR FILIPPOV	{"email": "filippov.v-1975@postgrespro.ru", "phone": "+70355429074"}
0005432784802	F37AD4	7803 406961	ZOYA NOVIKOVA	{"email": "novikova-z071975@postgrespro.ru", "phone": "+70628965321"}
0005432784803	C5B6B8	6441 499352	GENNADIY FEDOROV	{"email": "fedorov.g_101982@postgrespro.ru", "phone": "+70619200370"}
0005432784860	38A9D6	2080 942745	ELENA FILIPPOVA	{"phone": "+70175275885"}
0005432784804	3BB6CC	5803 347948	POLINA BOGDANOVA	{"email": "bogdanova_p-20021972@postgrespro.ru", "phone": "+70199262634"}
0005432784805	FC1DF6	7597 360051	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana21031968@postgrespro.ru", "phone": "+70715499886"}
0005432784806	285770	6078 573092	ARTEM SMIRNOV	{"phone": "+70994346048"}
0005432784807	1CB99C	4890 043468	LYUDMILA VASILEVA	{"email": "lyudmila.vasileva-011979@postgrespro.ru", "phone": "+70948496107"}
0005432784808	22F3D6	0280 967537	KIRILL SOKOLOV	{"email": "sokolov_kirill_30011965@postgrespro.ru", "phone": "+70140779087"}
0005432784809	E81A35	3428 897934	ALEKSANDR SOKOLOV	{"phone": "+70408478852"}
0005432784810	E81A35	9883 287222	NATALYA PAVLOVA	{"phone": "+70796477485"}
0005432784811	7B323C	6725 263600	VALENTINA KUDRYASHOVA	{"email": "valentina.kudryashova.1980@postgrespro.ru", "phone": "+70342571201"}
0005432784812	923DD0	7379 548813	MARINA IVANOVA	{"email": "ivanova_marina.19011965@postgrespro.ru", "phone": "+70696504497"}
0005432784813	3C88A4	9259 797388	EDUARD SMIRNOV	{"phone": "+70124151501"}
0005432784814	7DBB26	1178 764508	TATYANA SEMENOVA	{"phone": "+70530473564"}
0005432784815	B63624	5463 211170	OLGA EFREMOVA	{"phone": "+70472092636"}
0005432784816	C506B3	7469 930803	KRISTINA ABRAMOVA	{"email": "k_abramova.051967@postgrespro.ru", "phone": "+70002623187"}
0005432784817	08A256	6213 060572	MAKSIM KOROLEV	{"phone": "+70024391825"}
0005432784818	76F515	0093 198896	KSENIYA SMIRNOVA	{"phone": "+70863267718"}
0005432784819	76F515	7932 221109	LEONID VLASOV	{"phone": "+70785137263"}
0005432784820	4607EF	2495 553661	BOGDAN PAVLOV	{"phone": "+70930625925"}
0005432784821	344FBF	6881 421939	ALEKSANDR MIRONOV	{"email": "aleksandr_mironov-31031977@postgrespro.ru", "phone": "+70418472354"}
0005432784822	A7FDF1	6033 153424	VLADIMIR SERGEEV	{"phone": "+70345111551"}
0005432784823	A7FDF1	8996 542786	VLADIMIR POPOV	{"phone": "+70184513863"}
0005432784824	58F095	2621 900083	NATALYA VOROBEVA	{"phone": "+70040428738"}
0005432784825	81EE9B	5158 776347	SERGEY KUDRYASHOV	{"phone": "+70171565122"}
0005432784826	EA6F55	6827 527882	ALEKSANDR GRIGOREV	{"phone": "+70621378038"}
0005432784827	EA6F55	1106 556946	SERGEY KARPOV	{"email": "sergey-karpov.1981@postgrespro.ru", "phone": "+70298816471"}
0005432784828	A30CA1	5344 477057	LYUDMILA BELYAEVA	{"phone": "+70765264794"}
0005432784829	A30CA1	9079 212779	MIKHAIL FROLOV	{"phone": "+70309952669"}
0005432784830	F71A84	7670 846405	EKATERINA NOVIKOVA	{"phone": "+70545379486"}
0005432784831	F71A84	5417 165823	ELIZAVETA ARKHIPOVA	{"email": "elizaveta.arkhipova10051969@postgrespro.ru", "phone": "+70687095077"}
0005432784832	9C6B8A	2502 872631	VALENTINA KOLESNIKOVA	{"email": "valentina_kolesnikova_1954@postgrespro.ru", "phone": "+70804566096"}
0005432784833	15EDAE	0804 084385	DMITRIY POPOV	{"phone": "+70601748648"}
0005432784834	CA9C45	6743 454328	TATYANA POPOVA	{"phone": "+70292551915"}
0005432784835	CA9C45	6399 945249	MAKSIM SERGEEV	{"email": "sergeev-m.22021970@postgrespro.ru", "phone": "+70226250524"}
0005432784836	79A986	6880 473844	SERGEY ANDREEV	{"phone": "+70549255142"}
0005432784837	79A986	2998 922810	YULIYA KUZNECOVA	{"phone": "+70359539838"}
0005432784838	79A986	9461 086897	TATYANA KUZNECOVA	{"email": "tkuznecova-091980@postgrespro.ru", "phone": "+70224187127"}
0005432784839	93598B	7628 909961	MIKHAIL OSIPOV	{"phone": "+70954007913"}
0005432784840	BC4BDD	1694 688479	ARTEM GERASIMOV	{"email": "a-gerasimov29061977@postgrespro.ru", "phone": "+70746825805"}
0005432784841	548B36	1516 590956	LIDIYA ERMAKOVA	{"phone": "+70007702902"}
0005432784842	0DE656	5415 955405	IGOR BELOV	{"email": "belov-i13021966@postgrespro.ru", "phone": "+70320048345"}
0005432784843	EF2BA0	0977 525190	OLGA YUDINA	{"phone": "+70426387199"}
0005432784844	EF2BA0	1511 129809	TATYANA EGOROVA	{"phone": "+70675855310"}
0005432784845	88F090	1836 837235	LYUDMILA SAVELEVA	{"email": "l_saveleva.24121977@postgrespro.ru", "phone": "+70339576162"}
0005432784846	88F090	2651 877497	YULIYA SOROKINA	{"email": "yuliya_sorokina111960@postgrespro.ru", "phone": "+70292154748"}
0005432784847	6850E3	6545 171322	TAMARA NIKOLAEVA	{"email": "nikolaeva_t_1960@postgrespro.ru", "phone": "+70194603578"}
0005432784848	6850E3	2319 832252	YAROSLAV MARTYNOV	{"phone": "+70563593482"}
0005432784849	6850E3	7775 927590	LILIYA ORLOVA	{"phone": "+70690530841"}
0005432784850	B346A0	8677 386095	DENIS GORBUNOV	{"phone": "+70267903482"}
0005432784851	4C539C	5444 196744	MAKSIM FOMIN	{"email": "fominm-01071976@postgrespro.ru", "phone": "+70969183506"}
0005432784852	8EEFFF	5514 089708	RAMIL DENISOV	{"email": "denisov.r17071964@postgrespro.ru", "phone": "+70296438320"}
0005432784853	8EEFFF	1088 106266	GULNARA PETROVA	{"phone": "+70355856617"}
0005432784854	6E3703	4044 115177	OLGA KOROLEVA	{"email": "o_koroleva.041975@postgrespro.ru", "phone": "+70687904656"}
0005432784855	6E3703	1680 483495	VYACHESLAV ZHURAVLEV	{"email": "vyacheslav-zhuravlev-1969@postgrespro.ru", "phone": "+70577415924"}
0005432784856	410BA7	0966 197682	GALINA IVANOVA	{"phone": "+70100474790"}
0005432784857	2488C9	1800 286593	ALEKSANDRA PETROVA	{"email": "aleksandra-petrova_051978@postgrespro.ru", "phone": "+70664900266"}
0005432784858	738A82	6479 747513	SERGEY TIKHONOV	{"email": "s.tikhonov09061980@postgrespro.ru", "phone": "+70431242805"}
0005432784859	38A9D6	2510 519857	TATYANA ANDREEVA	{"email": "tatyana.andreeva_1976@postgrespro.ru", "phone": "+70336102385"}
0005432784861	BDF2B5	8861 226169	VALERIY NOVIKOV	{"phone": "+70611332174"}
0005432784862	E9600E	9742 225394	LARISA VASILEVA	{"email": "vasileva_larisa-051971@postgrespro.ru", "phone": "+70015344585"}
0005432784863	1F63AC	8841 398688	PETR SIDOROV	{"phone": "+70858203516"}
0005432784864	EB2542	9235 663319	ANATOLIY KUZMIN	{"email": "a_kuzmin-1979@postgrespro.ru", "phone": "+70788313078"}
0005432784865	EB2542	5684 516175	NATALYA KUZNECOVA	{"phone": "+70771907139"}
0005432784866	0DE30D	0519 262025	TATYANA ANDREEVA	{"phone": "+70599818587"}
0005432784867	421C54	3483 124724	IRINA KUZMINA	{"phone": "+70051244318"}
0005432784868	66DEF5	3935 798610	ROZA VASILEVA	{"email": "vasileva_r_05011977@postgrespro.ru", "phone": "+70456224949"}
0005432784869	53125C	9904 581779	VENIAMIN ILIN	{"email": "ilinv061969@postgrespro.ru", "phone": "+70872475593"}
0005432784870	9BC995	5533 288919	ZINAIDA POPOVA	{"phone": "+70896188691"}
0005432784871	0CD5D6	1613 764350	ELENA ZAYCEVA	{"email": "zayceva.elena.09031988@postgrespro.ru", "phone": "+70945729119"}
0005432784872	67EFE5	2296 085787	MARIYA KOROLEVA	{"email": "koroleva-m_1974@postgrespro.ru", "phone": "+70064854419"}
0005432784873	67EFE5	4666 062611	RIMMA MAKAROVA	{"email": "makarova.r_1979@postgrespro.ru", "phone": "+70900052192"}
0005432784874	0C9B1C	9228 804716	ALEKSANDR ZAKHAROV	{"phone": "+70151972594"}
0005432784875	0C9B1C	8215 935569	ELIZAVETA SMIRNOVA	{"phone": "+70044951122"}
0005432784876	EF4220	4001 030907	MARIYA OSIPOVA	{"email": "mariya_osipova.051987@postgrespro.ru", "phone": "+70000012684"}
0005432784877	7DC44D	1872 239885	PETR BONDARENKO	{"email": "bondarenko_petr_1965@postgrespro.ru", "phone": "+70160565330"}
0005432784878	F10327	6188 813761	ALLA SOROKINA	{"email": "sorokina_alla_091969@postgrespro.ru", "phone": "+70194942622"}
0005432784879	F10327	6891 377760	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev-29091986@postgrespro.ru", "phone": "+70098756061"}
0005432784880	20F423	2415 780745	ELENA GORBUNOVA	{"email": "e-gorbunova-091981@postgrespro.ru", "phone": "+70805112320"}
0005432784881	4524F0	9928 346570	ILYA BONDARENKO	{"email": "bondarenkoilya-1983@postgrespro.ru", "phone": "+70652935101"}
0005432784882	9A9EED	0255 756422	NATALYA YAKOVLEVA	{"phone": "+70515923222"}
0005432784883	9A9EED	5602 553872	NINA BELYAEVA	{"email": "n-belyaeva-081965@postgrespro.ru", "phone": "+70647957335"}
0005432784884	E6CCFE	4945 718256	NIKITA MOROZOV	{"email": "morozov_n051982@postgrespro.ru", "phone": "+70202966162"}
0005432784885	E6CCFE	0979 152124	NATALYA GORBUNOVA	{"phone": "+70947883529"}
0005432784886	020E98	3872 543639	SERGEY ROMANOV	{"email": "sergey_romanov.051977@postgrespro.ru", "phone": "+70455370826"}
0005432784887	020E98	9392 516830	MARGARITA KARPOVA	{"phone": "+70488743691"}
0005432784888	8BF1CC	2508 736832	OLEG MAKAROV	{"email": "makarov-o08071968@postgrespro.ru", "phone": "+70198779336"}
0005432784889	5C8C42	6350 932492	IVAN ZAYCEV	{"email": "zaycevivan_27031958@postgrespro.ru", "phone": "+70708391163"}
0005432784890	9788E9	1573 283097	LYUBOV MEDVEDEVA	{"phone": "+70035434283"}
0005432784891	436E29	9433 136361	VERA GORBUNOVA	{"email": "gorbunovavera_081988@postgrespro.ru", "phone": "+70511106688"}
0005432784892	436E29	9720 693007	EVGENIY TIMOFEEV	{"email": "timofeev.evgeniy-1972@postgrespro.ru", "phone": "+70521566931"}
0005432784893	F8B525	1365 863320	LYUBOV ERMAKOVA	{"phone": "+70918615780"}
0005432784894	91DC16	3035 093401	GALINA ANDREEVA	{"phone": "+70052533615"}
0005432784895	91DC16	7258 204371	TATYANA GAVRILOVA	{"email": "gavrilova_tatyana_27031958@postgrespro.ru", "phone": "+70190175076"}
0005432784896	A6F7E1	3484 263905	LYUDMILA VLASOVA	{"phone": "+70823963859"}
0005432784897	0D9AD2	8400 799659	ALSU VASILEVA	{"email": "vasilevaalsu_10091974@postgrespro.ru", "phone": "+70485078951"}
0005432784898	0D9AD2	0249 357373	LARISA DMITRIEVA	{"email": "dmitrievalarisa.22051979@postgrespro.ru", "phone": "+70067169290"}
0005432784899	0D9AD2	2315 940768	LYUDMILA FROLOVA	{"email": "frolova-lyudmila1979@postgrespro.ru", "phone": "+70100254895"}
0005432784900	5B3FD5	2041 940385	VALERIY VASILEV	{"email": "vasilevv-29041977@postgrespro.ru", "phone": "+70404001082"}
0005432784901	F33993	8258 792609	NADEZHDA MAKAROVA	{"email": "makarova_nadezhda_25091978@postgrespro.ru", "phone": "+70992608830"}
0005432784902	5665A5	1523 302555	LYUDMILA LEBEDEVA	{"email": "l-lebedeva-111973@postgrespro.ru", "phone": "+70487697239"}
0005432784903	0C8484	8686 861408	ANASTASIYA ALEKSEEVA	{"phone": "+70034052942"}
0005432784904	55CA5D	4637 781466	IVAN BORISOV	{"phone": "+70701375607"}
0005432784905	768E5B	1163 557363	OLGA MELNIKOVA	{"email": "melnikova-o-031969@postgrespro.ru", "phone": "+70157222318"}
0005432784906	A1B665	1759 923756	KIRILL STEPANOV	{"phone": "+70926125623"}
0005432784907	FC17C2	7977 233431	OLGA IVANOVA	{"phone": "+70663448796"}
0005432784908	9BE12A	7005 295736	RAILYA KUZNECOVA	{"phone": "+70966599971"}
0005432784909	AD3FF1	8799 700032	KLAVDIYA KUZNECOVA	{"email": "kuznecova_k-041964@postgrespro.ru", "phone": "+70663051723"}
0005432784910	86C460	1612 638094	RAISA NIKOLAEVA	{"email": "rnikolaeva-011974@postgrespro.ru", "phone": "+70587173380"}
0005432784911	86C460	7329 766697	MAKSIM YAKOVLEV	{"phone": "+70880299813"}
0005432784912	03CFA4	7586 425589	VYACHESLAV MATVEEV	{"phone": "+70336980440"}
0005432784913	6BEF5D	2548 715374	ALEKSEY STEPANOV	{"phone": "+70338452164"}
0005432784914	E2692E	4116 119018	LEONID TARASOV	{"email": "l-tarasov.1974@postgrespro.ru", "phone": "+70389757647"}
0005432784915	CC7C63	5148 492241	ALEKSANDR SOROKIN	{"email": "a_sorokin061968@postgrespro.ru", "phone": "+70875225731"}
0005432784916	50DC31	2097 395484	MAKSIM AFANASEV	{"email": "maksim_afanasev1961@postgrespro.ru", "phone": "+70384972163"}
0005432784917	50DC31	6779 417491	MARINA PAVLOVA	{"email": "pavlova_marina01011963@postgrespro.ru", "phone": "+70315008769"}
0005432784918	CCC148	5738 816138	ANTONINA NESTEROVA	{"email": "nesterovaa-18121964@postgrespro.ru", "phone": "+70574284146"}
0005432784919	768AD0	5127 681579	NATALYA ORLOVA	{"email": "natalya_orlova.061965@postgrespro.ru", "phone": "+70507160418"}
0005432784920	1C2427	4955 142734	OLEG SMIRNOV	{"email": "smirnov-o_07051967@postgrespro.ru", "phone": "+70219133997"}
0005432784921	525663	4008 731316	DMITRIY KUZMIN	{"phone": "+70211442046"}
0005432784922	525663	1469 762277	TATYANA YUDINA	{"email": "yudina.tatyana-021971@postgrespro.ru", "phone": "+70971354462"}
0005432784923	A89DE3	4268 906275	ARTEM ALEKSEEV	{"phone": "+70987978012"}
0005432784924	E73399	8819 807446	VIKTOR VASILEV	{"phone": "+70401219343"}
0005432784925	E73399	2231 646214	ALEKSEY POPOV	{"phone": "+70520950339"}
0005432784926	447AEA	2036 041218	ALEKSEY MAKSIMOV	{"email": "aleksey.maksimov19121963@postgrespro.ru", "phone": "+70601424039"}
0005432784927	B01B23	0691 157843	ALEKSANDR IVANOV	{"email": "ivanov-a.111964@postgrespro.ru", "phone": "+70612165037"}
0005432784928	B01B23	4728 652786	VITALIY SHEVCHENKO	{"email": "shevchenko_v.1963@postgrespro.ru", "phone": "+70034805232"}
0005432784929	CFD2B7	7581 972270	MARINA KOZLOVA	{"phone": "+70292601480"}
0005432784930	CFD2B7	6305 027366	ARTEM OSIPOV	{"email": "artem.osipov_03091969@postgrespro.ru", "phone": "+70882309313"}
0005432784931	CFD2B7	9513 388483	RUSLAN FEDOROV	{"phone": "+70602478490"}
0005432784932	32FB80	4182 753238	YURIY ORLOV	{"email": "orlov_yuriy.03011974@postgrespro.ru", "phone": "+70813464052"}
0005432784933	8DBA29	4159 203509	TATYANA POPOVA	{"phone": "+70325907791"}
0005432784934	8DBA29	8556 568134	SVETLANA MAKSIMOVA	{"phone": "+70810293229"}
0005432784935	8DBA29	0319 511281	ALINA VASILEVA	{"phone": "+70516947370"}
0005432784936	CCFB56	7593 044779	LYUDMILA SEMENOVA	{"phone": "+70063611418"}
0005432784937	CCFB56	9501 186143	DENIS KUZNECOV	{"email": "kuznecovdenis_13101984@postgrespro.ru", "phone": "+70330704721"}
0005432784938	6AC5BE	1332 339355	VLADIMIR TIMOFEEV	{"phone": "+70300965536"}
0005432784939	2363A9	6851 461473	SVETLANA ILINA	{"email": "silina1963@postgrespro.ru", "phone": "+70569510303"}
0005432784940	F2FB1C	6468 526836	VLADIMIR ZHURAVLEV	{"email": "zhuravlev.v1964@postgrespro.ru", "phone": "+70834698369"}
0005432784941	D627E7	4019 707659	ALEKSANDR NAZAROV	{"email": "nazarova17081967@postgrespro.ru", "phone": "+70025461758"}
0005432784942	5A1CC3	9838 242772	EGOR BELOV	{"email": "belov_e.1970@postgrespro.ru", "phone": "+70027668246"}
0005432784943	1C1890	2953 046760	NINA SOROKINA	{"email": "nina_sorokina.051967@postgrespro.ru", "phone": "+70038605847"}
0005432784944	C413AB	3585 684798	SVETLANA SOROKINA	{"phone": "+70707460512"}
0005432784945	2FEB82	5260 644841	ZHANNA MALYSHEVA	{"email": "z_malysheva-121980@postgrespro.ru", "phone": "+70055491948"}
0005432784946	39988F	0828 091266	MARGARITA KISELEVA	{"email": "kiseleva-margarita-1969@postgrespro.ru", "phone": "+70493493407"}
0005432784947	39988F	4310 552523	YULIYA KOZLOVA	{"phone": "+70969064501"}
0005432784948	607111	7744 726080	ELENA STEPANOVA	{"email": "stepanova_elena101970@postgrespro.ru", "phone": "+70359481692"}
0005432784949	607111	8753 229344	OKSANA NAUMOVA	{"phone": "+70815551030"}
0005432784950	B71DDD	9336 283875	STANISLAV NIKOLAEV	{"email": "nikolaev-stanislav1960@postgrespro.ru", "phone": "+70134639443"}
0005432784951	B71DDD	5841 271676	LIDIYA NIKITINA	{"phone": "+70813079542"}
0005432784952	97BEA2	5089 882640	MARIYA GAVRILOVA	{"phone": "+70042672338"}
0005432784953	41D358	9448 540713	ROMAN MAKSIMOV	{"phone": "+70207913465"}
0005432784954	A814A9	9480 928457	VIKTOR STEPANOV	{"email": "stepanov-v101989@postgrespro.ru", "phone": "+70343085849"}
0005432784955	6800AF	5442 715437	YURIY ZAYCEV	{"email": "zaycev.y031974@postgrespro.ru", "phone": "+70897454968"}
0005432784956	6800AF	8361 486098	IVAN POPOV	{"phone": "+70903733797"}
0005432784957	6800AF	6244 645144	VALENTINA KUDRYASHOVA	{"phone": "+70112911078"}
0005432784958	240267	8257 286116	VYACHESLAV TIMOFEEV	{"email": "vyacheslav-timofeev071966@postgrespro.ru", "phone": "+70820296345"}
0005432784959	240267	4852 206037	VLADIMIR VOLKOV	{"email": "volkov.v.01041967@postgrespro.ru", "phone": "+70072162665"}
0005432784960	14D5F5	9651 457844	NIKITA SMIRNOV	{"email": "smirnov-n_041976@postgrespro.ru", "phone": "+70530302698"}
0005432784961	B74D92	1200 696033	VERA POPOVA	{"email": "popovavera-041972@postgrespro.ru", "phone": "+70367815638"}
0005432784962	824075	6476 041016	ULYANA MARTYNOVA	{"email": "martynova-u101967@postgrespro.ru", "phone": "+70080183637"}
0005432784963	94F71D	5803 327784	ALINA SEMENOVA	{"phone": "+70204974726"}
0005432784964	22F0D0	0849 764915	NIKOLAY YAKOVLEV	{"email": "yakovlev-n011969@postgrespro.ru", "phone": "+70710295692"}
0005432784965	22F0D0	3693 328521	ANTON MAKAROV	{"email": "anton.makarov-19091983@postgrespro.ru", "phone": "+70743690411"}
0005432784966	3CBBEF	7573 335669	EKATERINA PETROVA	{"email": "petrova.ekaterina_1980@postgrespro.ru", "phone": "+70237642361"}
0005432784967	3CBBEF	4571 212484	DMITRIY BARANOV	{"email": "baranov.dmitriy-1974@postgrespro.ru", "phone": "+70843463822"}
0005432784968	04994F	7873 024593	ANASTASIYA KONDRATEVA	{"email": "a_kondrateva_011974@postgrespro.ru", "phone": "+70266499057"}
0005432784969	AAE50E	2689 199481	ALEKSEY KUZNECOV	{"phone": "+70745276598"}
0005432784970	70765B	7647 039350	VALENTINA SAVELEVA	{"email": "saveleva-valentina.111959@postgrespro.ru", "phone": "+70010780607"}
0005432784971	3E1B2E	2750 223381	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov_091968@postgrespro.ru", "phone": "+70304195551"}
0005432784972	C0BF20	8594 635749	ILYA KOZLOV	{"phone": "+70872136963"}
0005432784973	C0BF20	3281 356857	MARIYA ILINA	{"email": "ilinamariya28051970@postgrespro.ru", "phone": "+70386126240"}
0005432784974	9BA600	5978 331272	LIDIYA DENISOVA	{"phone": "+70800355919"}
0005432784975	DA616F	8884 779500	OKSANA ZAKHAROVA	{"email": "zakharova_oksana.101964@postgrespro.ru", "phone": "+70694434997"}
0005432784976	36AD9F	0864 315756	STEPAN SEMENOV	{"email": "semenov-stepan081969@postgrespro.ru", "phone": "+70774289117"}
0005432784977	623EA6	2810 993210	DMITRIY SOROKIN	{"email": "d_sorokin.111979@postgrespro.ru", "phone": "+70974985046"}
0005432784978	EFD405	6167 291156	OLGA MARTYNOVA	{"phone": "+70206464679"}
0005432784979	5DB6B3	8070 071688	VLADISLAV SAVELEV	{"phone": "+70577002162"}
0005432784980	5DB6B3	7516 925190	KONSTANTIN EGOROV	{"phone": "+70296477639"}
0005432784981	A4A839	8600 217176	EDUARD SERGEEV	{"phone": "+70256884739"}
0005432784982	A4A839	9618 972681	ARSENIY KONOVALOV	{"phone": "+70166116504"}
0005432784983	C6222C	0691 581538	LIDIYA GORBUNOVA	{"email": "gorbunova_lidiya-25061972@postgrespro.ru", "phone": "+70825981017"}
0005432784984	C6222C	9809 737981	LIDIYA MAKAROVA	{"email": "makarovalidiya1976@postgrespro.ru", "phone": "+70765896716"}
0005432784985	C6222C	7453 644996	TATYANA NAUMOVA	{"phone": "+70577922384"}
0005432784986	E2C190	5391 602096	PETR MAKAROV	{"phone": "+70376124901"}
0005432784987	E269B5	0130 392666	ANATOLIY ZHUKOV	{"phone": "+70146507413"}
0005432784988	DD1903	2647 447213	OLGA NOVIKOVA	{"phone": "+70075894056"}
0005432784989	55F4AC	2649 555554	MARIYA STEPANOVA	{"phone": "+70621244963"}
0005432784990	EC416A	6165 465686	VLADIMIR AFANASEV	{"phone": "+70617588706"}
0005432784991	EC416A	5959 576456	GENNADIY KUDRYASHOV	{"phone": "+70312901091"}
0005432784992	28B44B	0034 951612	NINA VASILEVA	{"email": "n-vasileva17021985@postgrespro.ru", "phone": "+70680948235"}
0005432784993	9FD656	7534 432940	LYUDMILA SOROKINA	{"email": "sorokina-lyudmila_1977@postgrespro.ru", "phone": "+70745005155"}
0005432784994	F9ED84	3730 497109	VLADIMIR GUSEV	{"phone": "+70494550308"}
0005432784995	200E8C	6922 421289	VLADIMIR SERGEEV	{"phone": "+70326963764"}
0005432784996	17E4C3	3398 486418	LEV MIKHAYLOV	{"phone": "+70477967023"}
0005432784997	BF883A	4544 614030	VASILIY IVANOV	{"email": "v-ivanov1968@postgrespro.ru", "phone": "+70247693279"}
0005432784998	BF883A	7678 105113	MARIYA SOKOLOVA	{"email": "m.sokolova07011977@postgrespro.ru", "phone": "+70348610209"}
0005432784999	BF883A	4087 755576	NATALYA MIKHAYLOVA	{"email": "mikhaylova-n_1979@postgrespro.ru", "phone": "+70300508646"}
0005432785000	838955	3182 030199	VLADIMIR BELOV	{"phone": "+70261126750"}
0005432785001	543AA7	4597 174370	ALEKSANDR ORLOV	{"email": "a.orlov-101972@postgrespro.ru", "phone": "+70877574268"}
0005432785002	D046A8	0563 976965	ANDREY MATVEEV	{"phone": "+70322731451"}
0005432785003	04E99D	6627 175128	OLGA ZHUKOVA	{"phone": "+70370477966"}
0005432785004	27EB28	1840 008728	SVETLANA PETROVA	{"phone": "+70829287330"}
0005432785005	27EB28	7556 312980	VENERA SOLOVEVA	{"email": "soloveva.v121961@postgrespro.ru", "phone": "+70070852749"}
0005432785006	4ED4B5	5918 539984	OLGA MATVEEVA	{"email": "o-matveeva-30081982@postgrespro.ru", "phone": "+70220588074"}
0005432785007	DEA5ED	5743 557767	ANDREY SOKOLOV	{"phone": "+70806319916"}
0005432785008	DEA5ED	0540 683161	VLADIMIR AFANASEV	{"email": "v_afanasev-28021960@postgrespro.ru", "phone": "+70377766669"}
0005432785009	4A7E3F	6409 206603	ELENA ZAKHAROVA	{"phone": "+70573803411"}
0005432785010	57AD7D	4988 228476	ILYA ZHURAVLEV	{"phone": "+70454157072"}
0005432785011	57AD7D	6710 006618	MIKHAIL SEMENOV	{"phone": "+70452249063"}
0005432785012	1DA7A2	8040 896037	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov.17081972@postgrespro.ru", "phone": "+70944297124"}
0005432785013	354EEC	5425 332093	MARIYA GAVRILOVA	{"email": "gavrilovam.091964@postgrespro.ru", "phone": "+70747779401"}
0005432785014	354EEC	1486 215209	ALEKSEY VOLKOV	{"phone": "+70416319664"}
0005432785015	D61E18	8921 337204	VALENTINA SEMENOVA	{"phone": "+70058465151"}
0005432785016	D61E18	2028 915219	VALENTINA KAZAKOVA	{"email": "kazakovavalentina-1977@postgrespro.ru", "phone": "+70450587831"}
0005432785017	909B85	1466 209521	DMITRIY BARANOV	{"email": "baranovd-011959@postgrespro.ru", "phone": "+70364100624"}
0005432785018	584EFF	1856 287764	LIDIYA MARTYNOVA	{"email": "lidiya-martynova.021963@postgrespro.ru", "phone": "+70243568632"}
0005432785019	6C339A	0056 688527	NIKOLAY SIDOROV	{"email": "sidorovn.21051965@postgrespro.ru", "phone": "+70039615612"}
0005432785020	F4CCCE	9358 442521	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova.091974@postgrespro.ru", "phone": "+70417308177"}
0005432785021	F4CCCE	6621 021655	ELENA BORISOVA	{"email": "borisova.e.1973@postgrespro.ru", "phone": "+70019227343"}
0005432785022	F4CCCE	0470 799302	ILYA KULIKOV	{"phone": "+70866116345"}
0005432785023	F4CCCE	5167 254873	NATALYA ANTONOVA	{"email": "natalya.antonova.1964@postgrespro.ru", "phone": "+70334802397"}
0005432785024	1A23F7	0830 903010	ALISA DANILOVA	{"email": "danilovaa_1970@postgrespro.ru", "phone": "+70293661918"}
0005432785025	220EEC	8271 868360	NAIL TIKHONOV	{"phone": "+70353697850"}
0005432785026	584CEB	8421 628140	OKSANA DENISOVA	{"email": "oksanadenisova.03021971@postgrespro.ru", "phone": "+70523837254"}
0005432785027	BF8C7B	4232 475055	IVAN VASILEV	{"email": "vasilev_ivan.23111979@postgrespro.ru", "phone": "+70620096858"}
0005432785028	85CF8B	6897 629164	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov_05041978@postgrespro.ru", "phone": "+70194868539"}
0005432785029	85CF8B	3107 117224	MARIYA ZAKHAROVA	{"email": "zakharova_m041974@postgrespro.ru", "phone": "+70069998506"}
0005432785030	85CF8B	0658 860127	VALENTINA ZAYCEVA	{"email": "valentinazayceva_08101979@postgrespro.ru", "phone": "+70179409981"}
0005432785031	827416	6050 259208	SVETLANA SOKOLOVA	{"phone": "+70947715625"}
0005432785032	D5C1B5	1633 107930	VALENTINA KARPOVA	{"phone": "+70996760126"}
0005432785033	D5C1B5	6078 931993	NATALYA KUDRYASHOVA	{"email": "kudryashova-n-30061983@postgrespro.ru", "phone": "+70934224896"}
0005432785034	158781	2261 358604	TATYANA EGOROVA	{"phone": "+70933442449"}
0005432785035	E68B74	7440 546566	DMITRIY MELNIKOV	{"phone": "+70183608111"}
0005432785036	E68B74	6212 259883	LIDIYA IVANOVA	{"phone": "+70980807194"}
0005432785037	CB6662	6006 844784	DARINA SOLOVEVA	{"email": "soloveva.d-11031978@postgrespro.ru", "phone": "+70752474127"}
0005432785038	599D83	7640 540402	NATALYA MAKSIMOVA	{"phone": "+70542283558"}
0005432785039	E2A4A9	3745 021616	VERA KOROLEVA	{"email": "koroleva_vera1967@postgrespro.ru", "phone": "+70777037732"}
0005432785040	E2A4A9	1787 224146	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva-1978@postgrespro.ru", "phone": "+70170430698"}
0005432785041	30A3A6	2232 195066	NATALYA YAKOVLEVA	{"email": "yakovleva.n1976@postgrespro.ru", "phone": "+70825541585"}
0005432785042	725579	6548 294115	VLADIMIR NIKITIN	{"email": "nikitin-v-10111962@postgrespro.ru", "phone": "+70119572451"}
0005432785043	725579	2337 272665	ALEKSEY SMIRNOV	{"email": "smirnovaleksey_101975@postgrespro.ru", "phone": "+70045399624"}
0005432785044	725579	5275 123386	YURIY SERGEEV	{"email": "sergeev.y.16111975@postgrespro.ru", "phone": "+70465963735"}
0005432785045	82D4D0	1670 060243	GALINA NOVIKOVA	{"email": "g_novikova_1970@postgrespro.ru", "phone": "+70826853952"}
0005432785046	82D4D0	4705 953487	LARISA ANDREEVA	{"email": "larisa-andreeva031970@postgrespro.ru", "phone": "+70311156153"}
0005432785047	90E55F	9760 089070	VALENTINA AKIMOVA	{"email": "akimova.v.20061962@postgrespro.ru", "phone": "+70221839475"}
0005432785048	90E55F	2322 467934	VERA ZOTOVA	{"email": "zotovav-20101965@postgrespro.ru", "phone": "+70272224169"}
0005432785049	5DA452	6683 282060	LYUDMILA DAVYDOVA	{"email": "l.davydova-15021975@postgrespro.ru", "phone": "+70307903953"}
0005432785050	D886F9	7555 919070	ANNA VLASOVA	{"email": "vlasova.a_07061968@postgrespro.ru", "phone": "+70667698856"}
0005432785051	0204DF	3396 330560	NIKITA SCHERBAKOV	{"phone": "+70458698389"}
0005432785052	0204DF	7330 423220	RINAT VOLKOV	{"email": "volkovr_09061978@postgrespro.ru", "phone": "+70974889725"}
0005432785053	50BF03	0347 378844	ALEKSEY KUZMIN	{"phone": "+70045833169"}
0005432785054	463445	8522 682758	LYUBOV POLYAKOVA	{"email": "lyubovpolyakova_13051979@postgrespro.ru", "phone": "+70258428666"}
0005432785055	4C72C5	5187 209043	ANDREY PAVLOV	{"phone": "+70511644484"}
0005432785056	39543A	8941 111937	EVGENIY ALEKSEEV	{"email": "ealekseev_06101968@postgrespro.ru", "phone": "+70998385694"}
0005432785057	6BB793	0641 352984	LYUBOV VOLKOVA	{"email": "lyubov.volkova05081972@postgrespro.ru", "phone": "+70479743351"}
0005432785058	1B6734	8838 754198	ANNA YUDINA	{"email": "a.yudina-011972@postgrespro.ru", "phone": "+70865030769"}
0005432785059	3F033B	6370 205200	ELENA STEPANOVA	{"phone": "+70143785371"}
0005432785060	61FB4B	9527 994228	SERGEY BELOV	{"email": "sergeybelov.011974@postgrespro.ru", "phone": "+70678034761"}
0005432785061	61FB4B	3292 608582	ILYA YAKOVLEV	{"phone": "+70945676194"}
0005432785062	61FB4B	3090 451086	MIKHAIL YAKOVLEV	{"phone": "+70980377662"}
0005432785063	3B0D7C	2837 169183	IVAN OSIPOV	{"phone": "+70562432127"}
0005432785064	F2CABB	0338 442713	VLADIMIR MELNIKOV	{"phone": "+70117201425"}
0005432785065	DA52A2	6275 307668	NIKOLAY MIKHAYLOV	{"phone": "+70996449596"}
0005432785066	560E17	0896 185446	PELAGEYA ZAKHAROVA	{"phone": "+70906068915"}
0005432785067	560E17	8274 545116	NINA ZOTOVA	{"email": "n_zotova_08071968@postgrespro.ru", "phone": "+70515644791"}
0005432785068	76F983	7610 303495	SVETLANA KUZMINA	{"phone": "+70451850853"}
0005432785069	76F983	6089 712608	POLINA GRISHINA	{"email": "polina_grishina_1975@postgrespro.ru", "phone": "+70601890122"}
0005432785070	3DB456	4610 192961	NINA FADEEVA	{"email": "nfadeeva.01061975@postgrespro.ru", "phone": "+70150664538"}
0005432785071	E113D1	6380 113597	VERA ILINA	{"phone": "+70509010833"}
0005432785072	E113D1	8060 276871	MARIYA DMITRIEVA	{"phone": "+70851167248"}
0005432785073	7FF686	2759 348891	MAKSIM FROLOV	{"phone": "+70415288796"}
0005432785074	7FF686	5693 858016	ANDREY BORISOV	{"phone": "+70210806781"}
0005432785075	BE9D89	8967 755111	MARINA VOLKOVA	{"phone": "+70941868323"}
0005432785076	3137C8	5289 798436	PETR KUDRYASHOV	{"email": "kudryashov_p28011981@postgrespro.ru", "phone": "+70525633028"}
0005432785077	3137C8	3092 228866	ALBERT KAZAKOV	{"email": "kazakov_a-1972@postgrespro.ru", "phone": "+70048199520"}
0005432785078	024B85	2351 938019	ELENA SOLOVEVA	{"email": "esoloveva.1972@postgrespro.ru", "phone": "+70918340388"}
0005432785079	EA47F7	5699 406689	YURIY TIKHONOV	{"email": "tikhonovy-071976@postgrespro.ru", "phone": "+70697747735"}
0005432785080	EA47F7	8116 847166	VIKTOR MAKAROV	{"email": "makarov_v_08061980@postgrespro.ru", "phone": "+70727374556"}
0005432785081	B71BEF	9257 722542	IVAN MEDVEDEV	{"email": "medvedevivan.1972@postgrespro.ru", "phone": "+70151149671"}
0005432785082	B71BEF	8171 485493	FANIL ALEKSANDROV	{"email": "aleksandrov-fanil.101985@postgrespro.ru", "phone": "+70677312555"}
0005432785138	5741BA	8529 578234	MARIYA KOMAROVA	{"phone": "+70744580114"}
0005432785083	3CCFFF	3749 181287	OLGA ALEKSANDROVA	{"email": "olga-aleksandrova_06111973@postgrespro.ru", "phone": "+70259738420"}
0005432785084	3CCFFF	8746 735644	IGOR SHEVCHENKO	{"phone": "+70919922217"}
0005432785085	3CCFFF	4061 840500	TATYANA CHERNOVA	{"phone": "+70739598882"}
0005432785086	4BEA82	2234 132769	ARSENIY GUSEV	{"email": "arseniygusev-1975@postgrespro.ru", "phone": "+70459376184"}
0005432785087	619715	2691 756050	VADIM IVANOV	{"email": "ivanov-vadim-071972@postgrespro.ru", "phone": "+70435815663"}
0005432785088	11F6E6	8913 929330	EVA KUZNECOVA	{"phone": "+70704790842"}
0005432785089	6FAF77	9806 193679	TATYANA MOROZOVA	{"email": "tatyana-morozova-30121970@postgrespro.ru", "phone": "+70232256064"}
0005432785090	6FAF77	2272 641974	ALEKSANDR KULIKOV	{"phone": "+70212319079"}
0005432785091	D358DA	6914 613387	EDUARD GUSEV	{"email": "eduard.gusev-1977@postgrespro.ru", "phone": "+70359334891"}
0005432785092	8DE1B3	6650 942114	IVAN MIKHAYLOV	{"phone": "+70068880878"}
0005432785093	8DE1B3	4280 393710	POLINA EFIMOVA	{"email": "pefimova071959@postgrespro.ru", "phone": "+70464225268"}
0005432785094	B0B66D	5852 601587	OLEG POPOV	{"email": "o_popov-1966@postgrespro.ru", "phone": "+70652233926"}
0005432785095	BD8506	0138 236619	ANDREY FEDOROV	{"email": "fedorov-andrey101977@postgrespro.ru", "phone": "+70129940955"}
0005432785096	BD8506	1281 465311	ANTONINA MELNIKOVA	{"phone": "+70702864624"}
0005432785097	4363CA	8426 484792	SEMEN VOLKOV	{"email": "volkov-s_1973@postgrespro.ru", "phone": "+70496800785"}
0005432785098	4363CA	6298 845356	ANASTASIYA SERGEEVA	{"email": "anastasiya.sergeeva-24101974@postgrespro.ru", "phone": "+70733987320"}
0005432785099	8263FC	9613 601581	ALEKSANDRA MEDVEDEVA	{"email": "a_medvedeva.20091963@postgrespro.ru", "phone": "+70757526305"}
0005432785100	8263FC	2159 416528	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e.11091980@postgrespro.ru", "phone": "+70782312070"}
0005432785101	5458D9	0482 320862	NADEZHDA ILINA	{"phone": "+70083947511"}
0005432785102	5458D9	1910 002999	LILIYA TIKHONOVA	{"phone": "+70779401448"}
0005432785103	445131	3585 787232	GENNADIY MOROZOV	{"phone": "+70711479390"}
0005432785104	A09990	5223 178202	VIKTOR GERASIMOV	{"email": "gerasimov.v081961@postgrespro.ru", "phone": "+70125411378"}
0005432785105	670C0B	7347 095979	KIRILL BORISOV	{"email": "borisov_k-1975@postgrespro.ru", "phone": "+70107427584"}
0005432785106	670C0B	8832 443433	KONSTANTIN TIKHONOV	{"phone": "+70922695302"}
0005432785107	137B75	5769 303906	SVETLANA POPOVA	{"email": "s_popova-091976@postgrespro.ru", "phone": "+70356375442"}
0005432785108	B05156	0632 644658	MARIYA LEBEDEVA	{"email": "mariya.lebedeva011965@postgrespro.ru", "phone": "+70929911207"}
0005432785109	B05156	7729 555356	EVGENIYA KUDRYASHOVA	{"email": "kudryashovaevgeniya1979@postgrespro.ru", "phone": "+70975383272"}
0005432785110	302771	1109 442865	TAISIYA POLYAKOVA	{"email": "t.polyakova.1976@postgrespro.ru", "phone": "+70370130615"}
0005432785111	FF48EB	2209 487103	PAVEL SMIRNOV	{"phone": "+70712646640"}
0005432785112	F82DB2	1711 750453	LYUBOV FADEEVA	{"email": "lyubov.fadeeva1977@postgrespro.ru", "phone": "+70635272954"}
0005432785113	F82DB2	6278 848990	OKSANA POPOVA	{"phone": "+70589280489"}
0005432785114	9D1C75	8722 165592	ANNA SOLOVEVA	{"phone": "+70636140178"}
0005432785115	9F88B0	6202 876767	YURIY YAKOVLEV	{"phone": "+70815890136"}
0005432785116	9F88B0	6081 661755	SERGEY SEMENOV	{"email": "s-semenov.02101976@postgrespro.ru", "phone": "+70514964163"}
0005432785117	984511	4300 773484	OLGA KOROLEVA	{"email": "o-koroleva_071984@postgrespro.ru", "phone": "+70804956853"}
0005432785118	984511	6672 403850	ANASTASIYA EFREMOVA	{"phone": "+70790037490"}
0005432785119	240F1A	0365 384091	ALEKSANDR KOROLEV	{"email": "a_korolev.021982@postgrespro.ru", "phone": "+70029650650"}
0005432785120	240F1A	4818 862518	MARIYA IVANOVA	{"email": "ivanova.mariya071987@postgrespro.ru", "phone": "+70562255077"}
0005432785121	3AFEE4	6071 421849	VALENTINA MIKHAYLOVA	{"email": "v-mikhaylova_24111964@postgrespro.ru", "phone": "+70387668794"}
0005432785122	B2A12C	8609 017898	VLADIMIR FROLOV	{"phone": "+70533368463"}
0005432785123	B2A12C	3558 135057	DANIIL BORISOV	{"email": "borisovd25111987@postgrespro.ru", "phone": "+70910127241"}
0005432785124	20C4F3	0379 582382	MAKSIM ABRAMOV	{"phone": "+70949094132"}
0005432785125	079814	0324 628568	LYUDMILA POPOVA	{"email": "lpopova121970@postgrespro.ru", "phone": "+70964285867"}
0005432785126	518CD7	6251 469643	ALEKSANDR IVANOV	{"phone": "+70568358449"}
0005432785127	518CD7	4422 016487	ELENA IVANOVA	{"email": "elena_ivanova_1977@postgrespro.ru", "phone": "+70553054356"}
0005432785128	518CD7	5617 168248	VADIM VOROBEV	{"email": "vadim.vorobev.04011967@postgrespro.ru", "phone": "+70581243509"}
0005432785129	0CDB88	3046 064815	NIKITA IVANOV	{"email": "nikitaivanov-20061975@postgrespro.ru", "phone": "+70627587768"}
0005432785130	CDB877	3939 083596	TATYANA ZHUKOVA	{"email": "tatyanazhukova_061983@postgrespro.ru", "phone": "+70525528270"}
0005432785131	ED0881	4200 183065	PAVEL BORISOV	{"email": "borisov-pavel.29011960@postgrespro.ru", "phone": "+70879116645"}
0005432785132	353BAD	1254 575927	ALEKSANDRA LOGINOVA	{"phone": "+70856661146"}
0005432785133	C2542F	9891 598561	LYUDMILA BORISOVA	{"phone": "+70934495445"}
0005432785134	40C213	1696 738253	SERGEY KISELEV	{"email": "kiselev.s.1994@postgrespro.ru", "phone": "+70872863388"}
0005432785135	40C213	2666 284643	GENNADIY GRIGOREV	{"phone": "+70809756813"}
0005432785136	40C213	8391 834554	ALEKSANDR ZAKHAROV	{"phone": "+70328565626"}
0005432785137	F6A847	6869 180039	ILYA MIKHAYLOV	{"email": "i-mikhaylov_16061966@postgrespro.ru", "phone": "+70522048046"}
0005432785139	63AB67	3746 139037	VLADIMIR VASILEV	{"phone": "+70933571088"}
0005432785140	B89C4A	6811 249450	ALEKSANDR MOROZOV	{"email": "morozov-a-28031969@postgrespro.ru", "phone": "+70826459977"}
0005432785141	1D3F0C	7760 024930	EVGENIY STEPANOV	{"email": "stepanov.evgeniy25081973@postgrespro.ru", "phone": "+70287549634"}
0005432785142	AD08BA	1692 511791	OLGA NAZAROVA	{"phone": "+70836881989"}
0005432785143	AD08BA	0158 011908	MAKSIM GUSEV	{"phone": "+70027052037"}
0005432785144	B50CE8	2786 390955	NADEZHDA GAVRILOVA	{"phone": "+70510661854"}
0005432785145	52E533	8588 316715	VIKTOR ISAEV	{"email": "viktor.isaev_1974@postgrespro.ru", "phone": "+70143285546"}
0005432785146	52E533	7305 088256	VIKTOR DENISOV	{"email": "denisovviktor11091972@postgrespro.ru", "phone": "+70081802065"}
0005432785147	8C5C72	5318 334672	YULIYA BARANOVA	{"phone": "+70475249419"}
0005432785148	8C5C72	9590 588052	DMITRIY ALEKSEEV	{"email": "dmitriyalekseev-16061982@postgrespro.ru", "phone": "+70751000400"}
0005432785149	8C5C72	2098 671047	ZOYA TARASOVA	{"phone": "+70368556932"}
0005432785150	3B5948	6127 219152	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr_061965@postgrespro.ru", "phone": "+70593173104"}
0005432785151	EABB49	7269 805274	VLADIMIR MIRONOV	{"phone": "+70943074210"}
0005432785152	EABB49	3964 192806	EVGENIY EGOROV	{"phone": "+70870264320"}
0005432785153	EABB49	7584 395076	ANDREY ZHURAVLEV	{"phone": "+70891441603"}
0005432785154	A1593F	1329 456625	PRASKOVYA EGOROVA	{"email": "p-egorova_25061979@postgrespro.ru", "phone": "+70729859177"}
0005432785155	C47085	7578 851867	ASIYA MIKHAYLOVA	{"email": "mikhaylova.a_111969@postgrespro.ru", "phone": "+70066384116"}
0005432785156	C47085	8528 121197	OLESYA VASILEVA	{"email": "olesya-vasileva_1962@postgrespro.ru", "phone": "+70988422714"}
0005432785157	E38106	7612 214898	ALEKSANDR ZHURAVLEV	{"phone": "+70450441874"}
0005432785158	BBB1AF	2106 436892	VLADIMIR ORLOV	{"phone": "+70579443623"}
0005432785159	B82BAB	0584 507390	SERGEY SOROKIN	{"phone": "+70401772037"}
0005432785160	1C7AAD	6190 730831	IRINA IVANOVA	{"email": "irina.ivanova_1970@postgrespro.ru", "phone": "+70377551671"}
0005432785161	1C7AAD	1566 949474	NATALYA ABRAMOVA	{"phone": "+70447249114"}
0005432785162	3E43B1	1270 661291	IGOR MOISEEV	{"phone": "+70267614934"}
0005432785163	3E43B1	5978 733122	VALENTINA ANDREEVA	{"phone": "+70661244710"}
0005432785164	F64411	7507 235201	ALEKSEY FEDOTOV	{"email": "alekseyfedotov_04021973@postgrespro.ru", "phone": "+70071737933"}
0005432785165	2672C5	1322 261127	ALEVTINA TIKHONOVA	{"email": "a-tikhonova031974@postgrespro.ru", "phone": "+70492423261"}
0005432785166	04752F	7870 523015	ELENA SIDOROVA	{"email": "sidorovaelena1975@postgrespro.ru", "phone": "+70396552009"}
0005432785167	4C2CB8	2048 675133	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya_101979@postgrespro.ru", "phone": "+70547995947"}
0005432785168	6E6034	8264 218909	RAISA OSIPOVA	{"email": "osipovar_1968@postgrespro.ru", "phone": "+70567361179"}
0005432785169	6E6034	7382 007664	ANASTASIYA NIKOLAEVA	{"email": "anikolaeva-1974@postgrespro.ru", "phone": "+70243339219"}
0005432785170	E96E44	1744 671192	LILIYA ANISIMOVA	{"email": "liliya_anisimova-031973@postgrespro.ru", "phone": "+70629196395"}
0005432785171	C90A41	4549 310129	DANIIL NAZAROV	{"phone": "+70318430658"}
0005432785172	C90A41	7983 621171	GALINA NIKITINA	{"email": "nikitinagalina.1977@postgrespro.ru", "phone": "+70510340036"}
0005432785173	6880D5	2080 648434	VALENTINA ANISIMOVA	{"phone": "+70207482694"}
0005432785174	302B78	4732 169297	NATALYA ZAKHAROVA	{"email": "natalya_zakharova1990@postgrespro.ru", "phone": "+70490504968"}
0005432785175	302B78	4355 893843	ALEKSANDR SMIRNOV	{"phone": "+70799218738"}
0005432785176	ADA4C3	2012 079001	DENIS MEDVEDEV	{"email": "d_medvedev.041971@postgrespro.ru", "phone": "+70876266792"}
0005432785177	ADA4C3	6758 368845	ARTEM FOMIN	{"phone": "+70392293820"}
0005432785178	3D620C	1552 965720	NATALYA RYABOVA	{"email": "ryabovan-25121964@postgrespro.ru", "phone": "+70199667231"}
0005432785179	3D620C	0924 943334	NATALYA MALYSHEVA	{"phone": "+70238229628"}
0005432785180	3D620C	8667 517348	TATYANA BORISOVA	{"phone": "+70443019675"}
0005432785181	50848A	8928 437426	VASILIY TARASOV	{"email": "tarasov.v1957@postgrespro.ru", "phone": "+70511120891"}
0005432785182	CE289D	8402 152246	KARINA MAKAROVA	{"phone": "+70443474325"}
0005432785183	B49FCE	0143 699832	LARISA KUZNECOVA	{"phone": "+70022785918"}
0005432785184	CB946E	5846 211750	PAVEL BORISOV	{"phone": "+70057359476"}
0005432785185	3F1517	5928 582685	SERGEY GAVRILOV	{"email": "gavrilovs-081965@postgrespro.ru", "phone": "+70742998760"}
0005432785186	723702	6374 436723	NADEZHDA KAZAKOVA	{"phone": "+70778221354"}
0005432785187	0A89D6	8949 955802	SERGEY MOROZOV	{"email": "s-morozov.12051971@postgrespro.ru", "phone": "+70096252448"}
0005432785188	0A89D6	5368 188172	SVETLANA NIKOLAEVA	{"email": "nikolaeva-s-021972@postgrespro.ru", "phone": "+70951132014"}
0005432785189	7B30B5	3890 485856	IGOR SEMENOV	{"email": "semenov-i-1969@postgrespro.ru", "phone": "+70594199675"}
0005432785190	BEE89C	6973 832757	LYUBOV ZAYCEVA	{"email": "l-zayceva011972@postgrespro.ru", "phone": "+70293185541"}
0005432785191	DCC3AF	8082 422944	VALENTINA VOROBEVA	{"phone": "+70033566261"}
0005432785192	7B7C37	8221 306929	DARYA KUZNECOVA	{"email": "darya-kuznecova1974@postgrespro.ru", "phone": "+70826130866"}
0005432785193	7B7C37	0006 878447	ALEKSANDRA KUZNECOVA	{"email": "aleksandra-kuznecova.1976@postgrespro.ru", "phone": "+70601465689"}
0005432785194	D1EF15	2522 390562	ANDREY FROLOV	{"email": "afrolov1976@postgrespro.ru", "phone": "+70564080637"}
0005432785195	2CEC94	7361 173406	TATYANA SOROKINA	{"email": "tsorokina_061968@postgrespro.ru", "phone": "+70175867051"}
0005432785196	82B683	0168 032027	MARINA ALEKSEEVA	{"phone": "+70779084849"}
0005432785197	181164	0948 235939	ALISA VOLKOVA	{"email": "alisa_volkova101978@postgrespro.ru", "phone": "+70998030224"}
0005432785198	181164	0151 044393	VIKTORIYA IVANOVA	{"email": "vivanova-1962@postgrespro.ru", "phone": "+70909234330"}
0005432785199	810A3A	2253 986261	LYUDMILA GORBUNOVA	{"phone": "+70895635832"}
0005432785200	3798C9	4186 146947	NATALYA MOISEEVA	{"phone": "+70169348269"}
0005432785201	3798C9	4269 563368	DMITRIY KOZLOV	{"email": "dmitriy_kozlov-16071967@postgrespro.ru", "phone": "+70707775416"}
0005432785202	91ED3A	8286 317567	ROMAN BELOV	{"phone": "+70223869432"}
0005432785203	91ED3A	4027 573234	ALEKSANDR EGOROV	{"phone": "+70788339039"}
0005432785204	E7AE85	0215 351412	NADEZHDA SEMENOVA	{"email": "semenova.n.20111986@postgrespro.ru", "phone": "+70782444193"}
0005432785205	E7AE85	2429 553647	LYUBOV KOZLOVA	{"phone": "+70924787202"}
0005432785206	49004E	9141 909045	NADEZHDA POPOVA	{"email": "n.popova1970@postgrespro.ru", "phone": "+70806230741"}
0005432785207	154BD6	8782 533098	ALEKSEY ZHURAVLEV	{"phone": "+70089114011"}
0005432785208	17E0A2	3561 449696	ALEKSANDR MARTYNOV	{"phone": "+70189491031"}
0005432785209	E663AE	8546 363242	EVGENIYA KOLESNIKOVA	{"phone": "+70068982373"}
0005432785210	DF8487	9167 843141	SERGEY KUDRYASHOV	{"email": "s-kudryashov26081970@postgrespro.ru", "phone": "+70969294144"}
0005432785211	DF8487	8415 774208	VERA SOROKINA	{"email": "verasorokina-1978@postgrespro.ru", "phone": "+70755659810"}
0005432785212	E155B5	9282 995635	VIKTOR BARANOV	{"email": "vbaranov_051985@postgrespro.ru", "phone": "+70534096086"}
0005432785213	DEA7C6	7563 471608	TAMARA IVANOVA	{"phone": "+70721221735"}
0005432785214	DEA7C6	5227 347097	VLADIMIR OSIPOV	{"email": "osipovv1980@postgrespro.ru", "phone": "+70742893707"}
0005432785215	DEA7C6	0522 810517	MAKSIM ZAKHAROV	{"email": "m.zakharov_061971@postgrespro.ru", "phone": "+70650451310"}
0005432785216	C4A2B5	4795 048761	LYUDMILA MARTYNOVA	{"email": "lyudmila.martynova-031977@postgrespro.ru", "phone": "+70523049113"}
0005432785217	60DBCD	6467 048047	VIKTORIYA SOKOLOVA	{"phone": "+70998590486"}
0005432785218	D8D0E8	8543 861751	DENIS ILIN	{"email": "ilind-1972@postgrespro.ru", "phone": "+70554517441"}
0005432785219	0513BE	1446 962834	NIKOLAY SOKOLOV	{"phone": "+70915169379"}
0005432785220	DA5EDF	1802 920920	ANNA POPOVA	{"email": "popova_a-24111966@postgrespro.ru", "phone": "+70595327965"}
0005432785221	C227EB	2992 909761	ANNA KULIKOVA	{"email": "akulikova-1975@postgrespro.ru", "phone": "+70999652082"}
0005432785222	C227EB	1292 931522	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey_1967@postgrespro.ru", "phone": "+70753069918"}
0005432785223	8F1136	1117 585015	ALEKSANDR SHEVCHENKO	{"phone": "+70289105609"}
0005432785224	8E236F	3830 264955	SERGEY ILIN	{"email": "sergey_ilin.011968@postgrespro.ru", "phone": "+70432014470"}
0005432785225	AED454	3917 391688	STEPAN GUSEV	{"email": "stepan.gusev101973@postgrespro.ru", "phone": "+70809659490"}
0005432785226	F5B2CF	3416 569261	KLAVDIYA POLYAKOVA	{"phone": "+70461446208"}
0005432785227	7952E6	4372 808166	OKSANA VOROBEVA	{"phone": "+70527625222"}
0005432785228	995F86	3279 832722	ILYA ILIN	{"phone": "+70736206325"}
0005432785229	E6F542	3434 849412	NIKOLAY KOZLOV	{"email": "n_kozlov-1976@postgrespro.ru", "phone": "+70759912783"}
0005432785230	A3116B	1715 987329	OLGA IVANOVA	{"email": "o_ivanova_1952@postgrespro.ru", "phone": "+70022523120"}
0005432785231	A3116B	9977 986229	ANTON KUDRYASHOV	{"phone": "+70649158390"}
0005432785232	EA2101	0253 370325	NATALYA PAVLOVA	{"phone": "+70912231736"}
0005432785233	2805E1	4924 661028	NATALYA STEPANOVA	{"email": "stepanova.n-051969@postgrespro.ru", "phone": "+70108288164"}
0005432785234	660377	4463 247054	ANTONINA FEDOROVA	{"phone": "+70384335541"}
0005432785235	2A3CC6	4379 497826	VLADIMIR ABRAMOV	{"email": "abramov-vladimir1978@postgrespro.ru", "phone": "+70110663501"}
0005432785236	A43F29	2361 790652	TATYANA KONDRATEVA	{"phone": "+70151254991"}
0005432785237	12CA0E	6482 299586	SAVELIY POPOV	{"email": "spopov111976@postgrespro.ru", "phone": "+70037332503"}
0005432785238	5FDEFB	8166 187490	ANTONINA RODIONOVA	{"phone": "+70880085196"}
0005432785239	5FDEFB	7596 277286	GALINA MOROZOVA	{"email": "morozova_galina-16121954@postgrespro.ru", "phone": "+70373693705"}
0005432785240	A5FC1E	8474 642101	TAMARA FEDOROVA	{"email": "fedorova-t.24101973@postgrespro.ru", "phone": "+70397178579"}
0005432785241	AA99CE	9133 873016	ALEKSANDRA DENISOVA	{"phone": "+70116385149"}
0005432785242	AA99CE	3904 669000	BULAT MOROZOV	{"email": "morozov_bulat.22121966@postgrespro.ru", "phone": "+70484486750"}
0005432785243	6EF96D	2409 035058	YURIY IVANOV	{"phone": "+70498325987"}
0005432785244	03D0D2	2811 787073	VASILIY PETROV	{"email": "petrov_vasiliy03081968@postgrespro.ru", "phone": "+70117219929"}
0005432785245	03D0D2	9535 021380	VLADIMIR BELOV	{"email": "vladimirbelov-1975@postgrespro.ru", "phone": "+70187557664"}
0005432785246	C11037	5378 624739	VIKTORIYA MIKHAYLOVA	{"email": "viktoriyamikhaylova_031987@postgrespro.ru", "phone": "+70440654871"}
0005432785247	51E83C	8922 870411	ANDREY MARTYNOV	{"phone": "+70935291412"}
0005432785248	512085	7342 291693	OLGA DENISOVA	{"email": "o-denisova.021973@postgrespro.ru", "phone": "+70142974289"}
0005432785249	67B668	6797 829009	EVGENIY BORISOV	{"email": "e_borisov-1978@postgrespro.ru", "phone": "+70880934236"}
0005432785250	D553E4	3206 976321	VLADIMIR FEDOTOV	{"phone": "+70249351447"}
0005432785251	D553E4	6653 224618	ANATOLIY ABRAMOV	{"phone": "+70336084527"}
0005432785252	58ADC9	7002 094463	LYAYSAN KUZNECOVA	{"email": "lyaysan-kuznecova-071963@postgrespro.ru", "phone": "+70917011893"}
0005432785253	58ADC9	6067 509553	NATALYA SCHERBAKOVA	{"email": "nscherbakova.1978@postgrespro.ru", "phone": "+70546161861"}
0005432785254	D78929	0526 862514	RUSLAN KUZNECOV	{"phone": "+70578127504"}
0005432785255	ACC007	5530 710147	EVA ANDREEVA	{"phone": "+70453437131"}
0005432785256	ACC007	6174 600303	OKSANA EGOROVA	{"phone": "+70733025918"}
0005432785257	0A9092	9079 548108	DMITRIY MOISEEV	{"email": "moiseev.d_061967@postgrespro.ru", "phone": "+70406762869"}
0005432785258	4D6DBD	8945 405223	ANDREY MOROZOV	{"phone": "+70219772605"}
0005432785259	7D8731	2114 583532	OLEG ANDREEV	{"email": "oleg_andreev_1976@postgrespro.ru", "phone": "+70990016751"}
0005432785260	7D8731	8886 343913	TATYANA KOROLEVA	{"phone": "+70446704585"}
0005432785261	7D8731	1006 960066	EKATERINA KUZNECOVA	{"email": "ekaterina_kuznecova.091972@postgrespro.ru", "phone": "+70442038829"}
0005432785262	345BA6	8491 319836	YURIY MELNIKOV	{"phone": "+70050935236"}
0005432785263	345BA6	1695 630254	TATYANA NIKITINA	{"email": "t_nikitina_091981@postgrespro.ru", "phone": "+70662203258"}
0005432785264	EF3473	0909 402963	RUSLAN FEDOROV	{"phone": "+70936386125"}
0005432785265	EF3473	5510 895637	DARYA FILIPPOVA	{"phone": "+70789935845"}
0005432785266	4A79E7	6918 496016	OLGA VOLKOVA	{"email": "volkovao-1970@postgrespro.ru", "phone": "+70924924283"}
0005432785267	DF4A3E	3194 292214	SVETLANA BELOVA	{"phone": "+70291605438"}
0005432785268	0BB148	3513 130407	VLADIMIR CHERNOV	{"email": "chernov.v_05091979@postgrespro.ru", "phone": "+70359734854"}
0005432785269	0BB148	7152 978476	DMITRIY NAUMOV	{"email": "naumov_d-081966@postgrespro.ru", "phone": "+70446437477"}
0005432785270	0BB148	1895 839194	VASILIY TIKHONOV	{"email": "vasiliy_tikhonov_1972@postgrespro.ru", "phone": "+70011643266"}
0005432785271	B7D46B	5468 732161	IRINA CHERNOVA	{"email": "chernova-irina-27091968@postgrespro.ru", "phone": "+70783601330"}
0005432785272	B7D46B	0796 008221	OKSANA POPOVA	{"phone": "+70812614016"}
0005432785273	7F8550	4397 602218	ALEKSEY KULIKOV	{"email": "a-kulikov.1964@postgrespro.ru", "phone": "+70453434792"}
0005432785274	EBA4FA	0101 322516	ANDREY SEMENOV	{"phone": "+70400423970"}
0005432785275	EBA4FA	7516 295143	VALERIY SOLOVEV	{"email": "valeriy_solovev_061973@postgrespro.ru", "phone": "+70982812552"}
0005432785276	EBA4FA	4241 455053	OLGA TITOVA	{"email": "olga.titova-041972@postgrespro.ru", "phone": "+70699467387"}
0005432785277	B75E6D	1250 379539	PAVEL VASILEV	{"email": "vasilev_pavel.1973@postgrespro.ru", "phone": "+70622698863"}
0005432785278	B75E6D	7363 430468	OLEG EGOROV	{"email": "oegorov_061971@postgrespro.ru", "phone": "+70000385774"}
0005432785279	D81CAC	7897 260911	KLAVDIYA YAKOVLEVA	{"phone": "+70137554144"}
0005432785280	6E4975	2593 157697	NIKOLAY ILIN	{"email": "nikolayilin1980@postgrespro.ru", "phone": "+70166976141"}
0005432785281	01FF81	4631 350080	DIANA AFANASEVA	{"phone": "+70595999495"}
0005432785282	C07E0E	2623 096724	SERGEY ORLOV	{"phone": "+70391730100"}
0005432785283	C07E0E	7830 304857	MARIYA LEBEDEVA	{"phone": "+70261785454"}
0005432785284	C07E0E	8341 218976	KSENIYA ZHURAVLEVA	{"email": "kzhuravleva_011969@postgrespro.ru", "phone": "+70757714737"}
0005432785285	93F6F6	5993 877280	ALEKSANDR BELOV	{"email": "belova-1986@postgrespro.ru", "phone": "+70393836099"}
0005432785286	BD0BCF	8952 886036	DENIS SMIRNOV	{"phone": "+70943742362"}
0005432785287	902D01	2942 913029	NIKOLAY KUZMIN	{"email": "kuzmin_nikolay-1984@postgrespro.ru", "phone": "+70030292333"}
0005432785288	902D01	5130 204043	VALENTINA NOVIKOVA	{"email": "v_novikova-15081966@postgrespro.ru", "phone": "+70311131701"}
0005432785289	56F817	7023 526350	MIKHAIL MIKHAYLOV	{"phone": "+70464478059"}
0005432785290	BA7DE3	0881 299496	ANASTASIYA LUKYANOVA	{"email": "lukyanovaanastasiya20111977@postgrespro.ru", "phone": "+70928942901"}
0005432785291	934DB3	5052 778634	DMITRIY GERASIMOV	{"phone": "+70220381071"}
0005432785292	934DB3	8066 801366	VLADIMIR KOZLOV	{"email": "kozlov.vladimir.091972@postgrespro.ru", "phone": "+70522070036"}
0005432785293	3DE8B3	5573 166500	ALEKSANDR IVANOV	{"phone": "+70467293393"}
0005432785294	3DE8B3	4154 809711	ALEKSANDRA KOLESNIKOVA	{"phone": "+70873671322"}
0005432785295	80F4AA	8647 502518	TATYANA LUKYANOVA	{"email": "tlukyanova-071977@postgrespro.ru", "phone": "+70999446553"}
0005432785296	80F4AA	2685 720522	GALINA TROFIMOVA	{"phone": "+70559930231"}
0005432785297	164EB8	3218 151895	SERGEY ILIN	{"phone": "+70011849265"}
0005432785298	BF78A3	4397 859732	ARTEM POPOV	{"phone": "+70329714773"}
0005432785299	BF78A3	7252 171234	DMITRIY ANDREEV	{"email": "dmitriy_andreev-1978@postgrespro.ru", "phone": "+70901540216"}
0005432785300	98D12D	4483 657328	NIKOLAY YAKOVLEV	{"email": "nyakovlev1964@postgrespro.ru", "phone": "+70979244054"}
0005432785301	061B0A	9871 423362	ALEKSEY ZAKHAROV	{"phone": "+70696029348"}
0005432785302	CE8DB0	5612 993284	SERGEY GUSEV	{"email": "s.gusev_01071965@postgrespro.ru", "phone": "+70192082062"}
0005432785303	856EEC	1170 209864	SERGEY ANTONOV	{"email": "antonov_s-111985@postgrespro.ru", "phone": "+70606563645"}
0005432785304	219751	3905 723046	ANDREY DMITRIEV	{"phone": "+70754515731"}
0005432785305	4A75FC	4138 217642	GALINA KUZNECOVA	{"email": "kuznecova-galina.1977@postgrespro.ru", "phone": "+70312197682"}
0005432785306	4A75FC	8107 279172	MARIYA KARPOVA	{"email": "karpova_m.06111968@postgrespro.ru", "phone": "+70883433313"}
0005432785307	29E19D	2376 392977	KLAVDIYA KONDRATEVA	{"phone": "+70345443160"}
0005432785308	9B07C8	2832 862579	YANA KRASNOVA	{"email": "krasnova.yana.1984@postgrespro.ru", "phone": "+70811151336"}
0005432785309	19DFE6	7949 324962	ALEKSANDR BARANOV	{"email": "aleksandr.baranov.21111967@postgrespro.ru", "phone": "+70191276561"}
0005432785310	19DFE6	3266 878812	EKATERINA LEBEDEVA	{"phone": "+70593238468"}
0005432785311	CF2B34	1636 373961	ALEKSANDR GERASIMOV	{"phone": "+70286470998"}
0005432785312	CF2B34	0365 909619	LYUDMILA IVANOVA	{"phone": "+70843519105"}
0005432785313	CF2B34	5442 548323	LYUBOV STEPANOVA	{"email": "stepanova-l30111972@postgrespro.ru", "phone": "+70366895822"}
0005432785314	CF2B34	4691 088812	ALENA GERASIMOVA	{"email": "gerasimovaalena021973@postgrespro.ru", "phone": "+70924429418"}
0005432785315	13FC5E	6934 119716	ALEKSANDR KUDRYASHOV	{"phone": "+70572757289"}
0005432785316	13FC5E	6156 815976	EVGENIYA ROMANOVA	{"email": "romanovaevgeniya18021970@postgrespro.ru", "phone": "+70731787234"}
0005432785317	BF0B1A	9684 507554	VALENTIN ILIN	{"email": "ilin-valentin-1975@postgrespro.ru", "phone": "+70599857766"}
0005432785318	BF0B1A	4748 592225	NADEZHDA MELNIKOVA	{"phone": "+70857740514"}
0005432785319	D701FD	7737 408859	SVETLANA NESTEROVA	{"email": "nesterova_svetlana091956@postgrespro.ru", "phone": "+70420251533"}
0005432785320	D701FD	6782 188741	VLADIMIR ZAKHAROV	{"email": "zakharov.v-051977@postgrespro.ru", "phone": "+70413236712"}
0005432785321	E1D2E6	9207 189618	YULIYA MIKHAYLOVA	{"email": "mikhaylova.y_05071965@postgrespro.ru", "phone": "+70883747336"}
0005432785322	E1D2E6	7615 444325	NIKOLAY DENISOV	{"email": "denisov-nikolay.17021961@postgrespro.ru", "phone": "+70760643348"}
0005432785323	A9234B	3302 829955	ANNA KUZNECOVA	{"phone": "+70903918502"}
0005432785324	A9234B	6404 353710	GALINA IVANOVA	{"phone": "+70413220924"}
0005432785325	9B3B12	3167 192850	TAMARA MEDVEDEVA	{"email": "medvedevatamara.17091961@postgrespro.ru", "phone": "+70616830755"}
0005432785326	89877A	0868 493167	YURIY BONDARENKO	{"phone": "+70418208843"}
0005432785327	F492B8	0071 544522	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir1969@postgrespro.ru", "phone": "+70354668385"}
0005432785328	6BA416	3775 229047	NATALYA PETROVA	{"phone": "+70115553786"}
0005432785329	4A726F	4277 541195	NATALYA MIKHAYLOVA	{"phone": "+70855296481"}
0005432785330	4A726F	5701 291520	VALERIYA SOROKINA	{"phone": "+70432901630"}
0005432785331	366775	7777 270011	ALEKSANDR ROMANOV	{"email": "romanov_a_1970@postgrespro.ru", "phone": "+70958767750"}
0005432785332	366775	1974 032055	LYUDMILA MAKAROVA	{"phone": "+70649733623"}
0005432785333	9D874C	6216 541660	ALEKSANDR VOLKOV	{"email": "volkov.a_10071985@postgrespro.ru", "phone": "+70967184650"}
0005432785334	2ADAD7	1887 668860	NIKITA STEPANOV	{"phone": "+70783117494"}
0005432785335	E59D7C	1845 348271	YAN AFANASEV	{"phone": "+70627386394"}
0005432785336	A3E68A	6148 672162	ILDAR IVANOV	{"phone": "+70692819453"}
0005432785337	0669FA	0913 918481	EVGENIY RODIONOV	{"email": "rodionov.e1967@postgrespro.ru", "phone": "+70663999980"}
0005432785338	0669FA	7317 517369	ROMAN KUZMIN	{"phone": "+70550410589"}
0005432785339	B40FCD	4913 194215	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey_21091967@postgrespro.ru", "phone": "+70092259074"}
0005432785340	B40FCD	6351 080468	ANDREY ALEKSANDROV	{"phone": "+70032604170"}
0005432785341	E9E69A	5478 532885	TATYANA MASLOVA	{"email": "tatyana_maslova.16111966@postgrespro.ru", "phone": "+70331786482"}
0005432785342	E9E69A	3217 106301	NATALYA MEDVEDEVA	{"phone": "+70848707233"}
0005432785343	ADB651	2031 186198	GENNADIY RODIONOV	{"email": "g.rodionov_091967@postgrespro.ru", "phone": "+70944498354"}
0005432785344	ADB651	0624 805207	EVGENIY FROLOV	{"email": "efrolov091976@postgrespro.ru", "phone": "+70537686786"}
0005432785345	555BF7	7393 163424	ANDREY GORBUNOV	{"phone": "+70965364413"}
0005432785346	0FA4B1	4770 181516	VALENTINA ZHURAVLEVA	{"phone": "+70303732125"}
0005432785347	7DFD8B	1878 928792	VITALIY SIDOROV	{"email": "v_sidorov_1975@postgrespro.ru", "phone": "+70176563793"}
0005432785348	456871	1504 561768	MIKHAIL YAKOVLEV	{"phone": "+70336908672"}
0005432785349	DDAD41	3295 413058	NADEZHDA TIMOFEEVA	{"email": "nadezhda_timofeeva_29101968@postgrespro.ru", "phone": "+70890939072"}
0005432785350	4FD10C	1265 951268	VALENTINA ZAKHAROVA	{"phone": "+70044739460"}
0005432785351	4FD10C	8831 781947	ALEKSEY VASILEV	{"email": "aleksey.vasilev.03061972@postgrespro.ru", "phone": "+70602279665"}
0005432785352	994E58	5503 483391	ILDAR KONOVALOV	{"phone": "+70186145804"}
0005432785353	994E58	7601 367230	VIKTOR CHERNOV	{"email": "chernovviktor_1980@postgrespro.ru", "phone": "+70750720801"}
0005432785354	AA8241	1060 188143	ANASTASIYA MAKAROVA	{"phone": "+70514708647"}
0005432785355	5AD7A5	3832 340637	ELENA PAVLOVA	{"phone": "+70493032309"}
0005432785356	D06B75	4384 674272	DMITRIY MELNIKOV	{"phone": "+70662256216"}
0005432785357	79D4C9	2049 232919	GALINA MOROZOVA	{"email": "g_morozova_12071965@postgrespro.ru", "phone": "+70121360448"}
0005432785358	225CDB	7917 523938	ALEKSANDR KUZMIN	{"phone": "+70637988984"}
0005432785359	492463	1991 596298	ALEKSEY MAKAROV	{"email": "makarovaleksey111971@postgrespro.ru", "phone": "+70358890995"}
0005432785360	DE367D	0637 864998	NIKOLAY VOLKOV	{"phone": "+70052220407"}
0005432785361	DE367D	2132 024463	EVGENIY MARTYNOV	{"phone": "+70378063201"}
0005432785362	1BB503	7029 547053	TAMARA IVANOVA	{"phone": "+70902137742"}
0005432785363	1BB503	4057 987875	VIKTORIYA NESTEROVA	{"email": "nesterova-v_101964@postgrespro.ru", "phone": "+70922652610"}
0005432785364	362C5A	3117 993715	OLGA POPOVA	{"email": "popova-o051965@postgrespro.ru", "phone": "+70609395836"}
0005432785365	6D380B	1278 548597	ALEKSANDR MAKAROV	{"phone": "+70149218124"}
0005432785366	270B3E	5432 042390	SERGEY FROLOV	{"email": "s_frolov_1956@postgrespro.ru", "phone": "+70945288632"}
0005432785367	0B2CEF	7224 934382	ALEKSANDR KARPOV	{"phone": "+70977665172"}
0005432785368	0B2CEF	7402 249117	ALEKSEY FROLOV	{"phone": "+70599710843"}
0005432785369	E654C6	8797 097584	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva-1962@postgrespro.ru", "phone": "+70773945242"}
0005432785370	1E6842	0366 841738	NAILYA KUZNECOVA	{"phone": "+70156291870"}
0005432798953	D3636A	7578 004402	NIKOLAY MATVEEV	{"email": "matveev.nikolay_041978@postgrespro.ru", "phone": "+70832785891"}
0005432798954	D3636A	1218 373639	ELENA MAKSIMOVA	{"phone": "+70081707634"}
0005432798955	A4FA27	8918 590388	SVETLANA BARANOVA	{"email": "baranova-svetlana.051964@postgrespro.ru", "phone": "+70914454837"}
0005432798956	A4FA27	1923 735039	DARYA MEDVEDEVA	{"email": "medvedeva_darya-1979@postgrespro.ru", "phone": "+70297118966"}
0005432798957	FA4B5B	1469 771720	EKATERINA SIDOROVA	{"phone": "+70673997010"}
0005432798958	FA4B5B	1019 941515	LEYLA KAZAKOVA	{"phone": "+70590750589"}
0005432798959	66266A	8313 004503	LYUDMILA IVANOVA	{"phone": "+70839359410"}
0005432798960	66266A	2177 529515	ANDREY PAVLOV	{"phone": "+70382378540"}
0005432798961	66266A	5507 632993	VIKTOR SIDOROV	{"email": "sidorovviktor061981@postgrespro.ru", "phone": "+70067560757"}
0005432798962	1B0293	7339 495515	YURIY SIDOROV	{"email": "sidorov_yuriy-11111982@postgrespro.ru", "phone": "+70967025823"}
0005432798963	86D07D	2474 982595	VADIM SOKOLOV	{"phone": "+70431883254"}
0005432798964	6B7755	9042 967958	KONSTANTIN DENISOV	{"email": "konstantin.denisov1982@postgrespro.ru", "phone": "+70457311903"}
0005432798965	6B7755	7667 987500	VIKTOR FROLOV	{"email": "frolov.viktor1968@postgrespro.ru", "phone": "+70494318912"}
0005432798966	6114FE	3856 742806	EVGENIYA KAZAKOVA	{"email": "kazakova_evgeniya.1973@postgrespro.ru", "phone": "+70040967177"}
0005432798967	9644D3	2141 542712	OLGA KARPOVA	{"email": "o_karpova_021986@postgrespro.ru", "phone": "+70676179387"}
0005432798968	5027DA	7043 370678	SERGEY NIKITIN	{"email": "nikitin_sergey-041983@postgrespro.ru", "phone": "+70988762227"}
0005432798969	955682	1120 839044	ANNA MIRONOVA	{"phone": "+70622111491"}
0005432798970	57CD5E	3655 311524	GALIYA KUZNECOVA	{"phone": "+70745507979"}
0005432798971	5A34B7	1254 431198	IRINA STEPANOVA	{"email": "stepanova.irina_1972@postgrespro.ru", "phone": "+70870853623"}
0005432798972	DAE727	9434 356481	VALENTINA SERGEEVA	{"phone": "+70214501163"}
0005432798973	DAE727	7087 674563	ALEKSANDRA TIKHONOVA	{"email": "atikhonova_17101976@postgrespro.ru", "phone": "+70412325981"}
0005432798974	E145DD	3019 406981	NIKOLAY CHERNOV	{"email": "nikolaychernov.07091986@postgrespro.ru", "phone": "+70943229464"}
0005432798975	E145DD	1498 196544	EKATERINA OSIPOVA	{"phone": "+70281987920"}
0005432798976	A535CF	3732 856646	SVETLANA BORISOVA	{"phone": "+70373822148"}
0005432798977	2F3D18	0163 334032	VLADIMIR BONDARENKO	{"phone": "+70353222010"}
0005432798978	2F3D18	1005 028382	OLGA PETROVA	{"email": "o-petrova.021964@postgrespro.ru", "phone": "+70871511489"}
0005432798979	1460F2	1376 861095	DMITRIY IVANOV	{"phone": "+70123124048"}
0005432798980	7B91FE	9639 167049	ALEKSANDRA SIDOROVA	{"email": "sidorova.aleksandra.18061966@postgrespro.ru", "phone": "+70760807149"}
0005432798981	024C54	6324 997091	OLGA MIRONOVA	{"phone": "+70131554517"}
0005432798982	024C54	7312 601553	PETR SEMENOV	{"email": "p_semenov_1963@postgrespro.ru", "phone": "+70432365079"}
0005432798983	297788	1139 752269	ALEKSEY MIKHAYLOV	{"email": "alekseymikhaylov.23091980@postgrespro.ru", "phone": "+70749335032"}
0005432798984	5990B0	5192 599207	OLGA MEDVEDEVA	{"phone": "+70862892730"}
0005432798985	C6F7DA	9645 783735	ALEKSANDR SEMENOV	{"phone": "+70257023801"}
0005432798986	C6F7DA	1651 051082	IRINA ISAEVA	{"phone": "+70112853835"}
0005432798987	C6F7DA	3791 455509	PETR BARANOV	{"phone": "+70930189879"}
0005432798988	4E73A4	8387 538490	SERGEY VLASOV	{"phone": "+70570671085"}
0005432798989	4E73A4	0633 817484	MARIYA VOLKOVA	{"email": "mariya.volkova.04071981@postgrespro.ru", "phone": "+70657093925"}
0005432798990	B6D011	7917 470655	NINA FEDOROVA	{"phone": "+70657345176"}
0005432798991	6F1019	6843 835879	VLADIMIR ROMANOV	{"email": "v-romanov.1987@postgrespro.ru", "phone": "+70460146407"}
0005432798992	6F1019	5384 230789	ALBINA KOROLEVA	{"email": "koroleva-a071974@postgrespro.ru", "phone": "+70191558115"}
0005432798993	6F1019	6747 669785	EKATERINA SERGEEVA	{"phone": "+70989673601"}
0005432798994	39C89B	7735 770846	MARIYA SERGEEVA	{"email": "sergeeva.m_01061974@postgrespro.ru", "phone": "+70596688971"}
0005432799050	FDA27A	8215 873640	VIKTORIYA POTAPOVA	{"phone": "+70605256636"}
0005432798995	6C29D2	7027 841391	OLGA NIKOLAEVA	{"email": "olga-nikolaeva.1962@postgrespro.ru", "phone": "+70437677097"}
0005432798996	8EC0A7	5803 060236	OLEG POPOV	{"phone": "+70289338599"}
0005432798997	08BB84	7078 944089	GENNADIY MAKAROV	{"email": "makarov.gennadiy_051988@postgrespro.ru", "phone": "+70867302287"}
0005432798998	08BB84	9381 176699	ELENA NOVIKOVA	{"phone": "+70549301905"}
0005432798999	222395	7163 573758	NADEZHDA NAZAROVA	{"email": "nazarova-nadezhda-24121974@postgrespro.ru", "phone": "+70907496575"}
0005432799000	A03912	6082 039657	NIKOLAY FEDOTOV	{"email": "nikolayfedotov-1967@postgrespro.ru", "phone": "+70983064585"}
0005432799001	FAED3B	1962 467627	MARIYA ILINA	{"email": "ilina.m.071967@postgrespro.ru", "phone": "+70754946990"}
0005432799002	FAED3B	6770 311980	ANTON FROLOV	{"phone": "+70127737795"}
0005432799003	2F4726	0080 905998	ROMAN KONOVALOV	{"email": "konovalov-r04051980@postgrespro.ru", "phone": "+70416330450"}
0005432799004	3B5B79	1642 651344	TATYANA IVANOVA	{"email": "t.ivanova_081966@postgrespro.ru", "phone": "+70018101385"}
0005432799005	C56983	8156 759294	ELENA PETROVA	{"email": "petrova_elena_25121967@postgrespro.ru", "phone": "+70928868218"}
0005432799006	1B9923	2994 331645	VLADIMIR STEPANOV	{"email": "stepanov-vladimir14091978@postgrespro.ru", "phone": "+70409069117"}
0005432799007	A2642B	6087 474200	ILYA VOLKOV	{"email": "volkov_ilya.081962@postgrespro.ru", "phone": "+70651230496"}
0005432799008	A2642B	5498 095305	NATALYA DANILOVA	{"email": "natalyadanilova10031974@postgrespro.ru", "phone": "+70251155484"}
0005432799009	4A6B43	2564 975659	EVGENIY KOZLOV	{"email": "evgeniykozlov_08031965@postgrespro.ru", "phone": "+70091383755"}
0005432799010	7EC9A4	1540 419086	ALEKSANDR SOLOVEV	{"email": "soloveva1969@postgrespro.ru", "phone": "+70861610568"}
0005432799011	B98681	3375 080565	ELENA BARANOVA	{"email": "baranova_elena-101975@postgrespro.ru", "phone": "+70829781038"}
0005432799012	41ED53	0526 070874	ILDAR PETROV	{"email": "ildarpetrov28071964@postgrespro.ru", "phone": "+70919152661"}
0005432799013	05143C	2237 036845	SERGEY GAVRILOV	{"email": "sgavrilov061975@postgrespro.ru", "phone": "+70696614834"}
0005432799014	9FC937	0948 822862	SERGEY MATVEEV	{"phone": "+70777943619"}
0005432799015	9DCCEB	9391 164045	VYACHESLAV ROMANOV	{"email": "romanov_vyacheslav-06081978@postgrespro.ru", "phone": "+70661024793"}
0005432799016	72E5BA	5636 637946	TAMARA ROMANOVA	{"email": "tamara.romanova25091975@postgrespro.ru", "phone": "+70451605453"}
0005432799017	FC9F13	8849 511235	NINA FROLOVA	{"phone": "+70574028442"}
0005432799018	FC9F13	1428 907047	NIKOLAY BELOV	{"phone": "+70580325534"}
0005432799019	FC9F13	7361 159402	YULIYA TROFIMOVA	{"email": "y_trofimova-28061956@postgrespro.ru", "phone": "+70407505691"}
0005432799020	FC9F13	0775 065576	LYUDMILA ANTONOVA	{"phone": "+70030182774"}
0005432799021	9FB948	1070 987699	ALEKSANDRA KUDRYASHOVA	{"phone": "+70084202578"}
0005432799022	1FFF81	7427 384351	ALEKSANDR MAKSIMOV	{"email": "aleksandrmaksimov.04071975@postgrespro.ru", "phone": "+70885256797"}
0005432799023	1FFF81	8571 645255	ANATOLIY MELNIKOV	{"email": "anatoliy_melnikov-20101971@postgrespro.ru", "phone": "+70292440763"}
0005432799024	21AF82	6500 113072	LYUBOV FILATOVA	{"email": "filatova_l-031985@postgrespro.ru", "phone": "+70372493761"}
0005432799025	C09E07	1458 557354	ANASTASIYA PETROVA	{"email": "petrova_a1963@postgrespro.ru", "phone": "+70707043566"}
0005432799026	98EE19	5797 654853	SERGEY ILIN	{"phone": "+70002544075"}
0005432799027	5C2627	2317 752498	ALEKSEY VOLKOV	{"email": "volkov.aleksey_1973@postgrespro.ru", "phone": "+70521974866"}
0005432799028	7D9174	4723 083451	VLADIMIR SOROKIN	{"phone": "+70205551655"}
0005432799029	7D9174	9583 846648	VALERIY NIKOLAEV	{"phone": "+70065960099"}
0005432799030	DCE8BC	5786 444643	ALEKSANDR ZHURAVLEV	{"phone": "+70130427414"}
0005432799031	DCE8BC	4120 230525	POLINA PAVLOVA	{"phone": "+70753495331"}
0005432799032	6AB736	0117 222674	EVGENIY ANTONOV	{"email": "antonove30121967@postgrespro.ru", "phone": "+70266060473"}
0005432799033	6AB736	5385 426313	EVGENIY YAKOVLEV	{"phone": "+70171194261"}
0005432799034	FEC8F8	4482 569648	SERGEY ANTONOV	{"email": "s.antonov-01091969@postgrespro.ru", "phone": "+70046587570"}
0005432799035	FEC8F8	0508 618070	LEONID SCHERBAKOV	{"email": "leonid.scherbakov28071989@postgrespro.ru", "phone": "+70760406942"}
0005432799036	5C5BCC	8810 266391	LYUDMILA DANILOVA	{"email": "danilova-lyudmila1965@postgrespro.ru", "phone": "+70816206509"}
0005432799037	4AA389	2479 835491	LYUDMILA EGOROVA	{"email": "lyudmilaegorova15051966@postgrespro.ru", "phone": "+70435052700"}
0005432799038	203A9A	4874 273281	ELENA ABRAMOVA	{"phone": "+70059936104"}
0005432799039	2E19CF	4251 535219	DENIS PETROV	{"phone": "+70704705637"}
0005432799040	F63D3C	5945 040887	YULIYA BORISOVA	{"phone": "+70603120695"}
0005432799041	55161B	5918 247783	EKATERINA PAVLOVA	{"phone": "+70695321006"}
0005432799042	35734C	3734 997208	YURIY VASILEV	{"email": "yuriy.vasilev_25051973@postgrespro.ru", "phone": "+70099127746"}
0005432799043	4271D2	4271 221454	ALENA MASLOVA	{"email": "a.maslova.05071966@postgrespro.ru", "phone": "+70806590622"}
0005432799044	4271D2	8891 509339	SVETLANA IVANOVA	{"email": "s.ivanova_081977@postgrespro.ru", "phone": "+70137768530"}
0005432799045	9818CF	9517 573798	VERONIKA ORLOVA	{"phone": "+70148797944"}
0005432799046	462346	6103 322184	VITALIY MELNIKOV	{"email": "vitaliy_melnikov28071980@postgrespro.ru", "phone": "+70542029396"}
0005432799047	462346	3020 904842	BORIS GERASIMOV	{"email": "gerasimov_boris-1974@postgrespro.ru", "phone": "+70796729127"}
0005432799048	9489B4	6984 534931	SVETLANA ZAYCEVA	{"phone": "+70437921642"}
0005432799049	BD328B	7055 415037	LYUBOV VOROBEVA	{"phone": "+70572982480"}
0005432799051	40CEE4	8630 265040	VIKTOR KARPOV	{"email": "v.karpov.021957@postgrespro.ru", "phone": "+70569479423"}
0005432799052	40CEE4	7011 860755	SVETLANA MIRONOVA	{"email": "s-mironova-091974@postgrespro.ru", "phone": "+70796203557"}
0005432799053	8B308A	4857 642096	MAKSIM ALEKSEEV	{"phone": "+70779285544"}
0005432799054	3908A6	2211 935134	ALEKSEY YAKOVLEV	{"email": "alekseyyakovlev-1978@postgrespro.ru", "phone": "+70311967879"}
0005432799055	56ED1A	4001 012665	SERGEY POPOV	{"phone": "+70377830598"}
0005432799056	1FFBA2	4643 387691	ALEKSANDR SEMENOV	{"email": "a_semenov_30031977@postgrespro.ru", "phone": "+70955620913"}
0005432799057	9C3BFE	9957 711344	SVETLANA NOVIKOVA	{"email": "novikova_svetlana_26111969@postgrespro.ru", "phone": "+70111870355"}
0005432799058	9C3BFE	1149 674189	NIKITA BELOV	{"phone": "+70060792631"}
0005432799059	F517A1	7215 348768	TATYANA SOKOLOVA	{"email": "sokolova.t061983@postgrespro.ru", "phone": "+70165645042"}
0005432799060	F517A1	8277 414410	NINA ZAKHAROVA	{"phone": "+70730999639"}
0005432799061	35C0F6	5189 740140	ANASTASIYA TIMOFEEVA	{"email": "timofeeva-anastasiya_1977@postgrespro.ru", "phone": "+70270706621"}
0005432799062	35C0F6	8513 237372	SERGEY DMITRIEV	{"phone": "+70398720257"}
0005432799063	04E03A	7433 656848	DARYA SAVELEVA	{"email": "saveleva-d.1964@postgrespro.ru", "phone": "+70506352975"}
0005432799064	313D1D	2976 553940	IVAN DENISOV	{"phone": "+70162030732"}
0005432799065	313D1D	6102 251409	VLADIMIR KAZAKOV	{"email": "kazakovvladimir.17051966@postgrespro.ru", "phone": "+70908017388"}
0005432799066	E425E5	1531 600401	MIKHAIL KAZAKOV	{"email": "m-kazakov1973@postgrespro.ru", "phone": "+70045721077"}
0005432799067	E425E5	6425 688795	DMITRIY VASILEV	{"email": "dmitriy.vasilev-1972@postgrespro.ru", "phone": "+70075348026"}
0005432799068	CECDEF	2258 883217	ELENA NIKIFOROVA	{"email": "e.nikiforova-08041974@postgrespro.ru", "phone": "+70996408308"}
0005432799069	BAAE2E	4691 338448	VALERIY TARASOV	{"email": "tarasovv30061962@postgrespro.ru", "phone": "+70742846526"}
0005432799070	BAAE2E	8715 321212	ALEKSANDR IVANOV	{"phone": "+70361253595"}
0005432799071	E53E29	2049 937738	DMITRIY SEMENOV	{"email": "dmitriy.semenov.05051960@postgrespro.ru", "phone": "+70970319957"}
0005432799072	C1041C	0141 159602	SERGEY MARTYNOV	{"email": "martynov_s17011973@postgrespro.ru", "phone": "+70436958778"}
0005432799073	CAF722	5589 734197	MARIYA NOVIKOVA	{"phone": "+70328083761"}
0005432799074	937303	2837 880308	ALEKSANDRA ILINA	{"email": "ilina-a27021978@postgrespro.ru", "phone": "+70868621082"}
0005432799075	937303	2749 430765	NINA STEPANOVA	{"phone": "+70807562351"}
0005432799076	1EF56F	9772 671108	VIKTOR KUZMIN	{"email": "kuzminv_1972@postgrespro.ru", "phone": "+70793674762"}
0005432799077	6F16FE	9623 215894	MIKHAIL PETROV	{"phone": "+70225341313"}
0005432799078	6F16FE	3238 265076	VALERIY KUZNECOV	{"phone": "+70281577395"}
0005432799079	D661B7	1536 567060	SERGEY AFANASEV	{"phone": "+70580903397"}
0005432799080	D661B7	8045 122319	GALINA SOROKINA	{"phone": "+70775992808"}
0005432799081	B5D57B	5258 491454	LYUDMILA BELOVA	{"phone": "+70263927911"}
0005432799082	363F84	3934 520183	SERGEY ZAKHAROV	{"email": "sergey_zakharov.011977@postgrespro.ru", "phone": "+70730151502"}
0005432799083	363F84	6164 372456	RAMIL OSIPOV	{"email": "osipov-ramil-1983@postgrespro.ru", "phone": "+70364546041"}
0005432799084	77F5AB	0972 968143	VIKTORIYA ZAYCEVA	{"phone": "+70195983670"}
0005432799085	516A7B	4355 252183	VALERIY TARASOV	{"email": "v.tarasov-14041970@postgrespro.ru", "phone": "+70840351860"}
0005432799086	5405DC	3612 197365	EVGENIY SIDOROV	{"phone": "+70019297153"}
0005432799087	AD39B2	2743 125823	TAISIYA MAKAROVA	{"email": "t-makarova23061978@postgrespro.ru", "phone": "+70737859703"}
0005432799088	D1FD93	4570 198783	NATALYA PETROVA	{"email": "n-petrova.18071970@postgrespro.ru", "phone": "+70684739948"}
0005432799089	D1FD93	1276 698803	MIKHAIL TIKHONOV	{"phone": "+70421806199"}
0005432799090	DE2F65	2092 679490	NIKOLAY VOLKOV	{"email": "volkovnikolay.031963@postgrespro.ru", "phone": "+70314016120"}
0005432799091	56D6A9	3540 076564	GALINA PETROVA	{"phone": "+70731508591"}
0005432799092	3EEBD4	6127 003442	OLGA IVANOVA	{"phone": "+70287088703"}
0005432799093	AA1B44	9841 859110	ALEVTINA ZAKHAROVA	{"phone": "+70906258550"}
0005432799094	620EE4	1508 087408	VALENTINA OVCHINNIKOVA	{"phone": "+70510810602"}
0005432799095	06943D	6474 193794	LIDIYA MIKHAYLOVA	{"email": "mikhaylova-l_051972@postgrespro.ru", "phone": "+70169335578"}
0005432799096	06943D	2041 867206	VIKTORIYA SOROKINA	{"phone": "+70512997288"}
0005432799097	065531	0694 812892	OLGA FILATOVA	{"phone": "+70950203087"}
0005432799098	2FBA02	6845 736882	ALEKSANDR ILIN	{"email": "ilin_aleksandr-1969@postgrespro.ru", "phone": "+70524429778"}
0005432799099	A87D91	7697 555663	MIKHAIL SEMENOV	{"phone": "+70666514838"}
0005432799100	FF21D6	3898 375146	ALEKSANDR MAKAROV	{"phone": "+70932189381"}
0005432799101	2E29DC	8643 261640	ANTON MAKAROV	{"phone": "+70534157165"}
0005432799102	5B1B0E	2256 724688	MARIYA STEPANOVA	{"email": "stepanova_mariya-1966@postgrespro.ru", "phone": "+70883588174"}
0005432799103	5B1B0E	8116 077348	OKSANA MIKHAYLOVA	{"email": "omikhaylova_08101971@postgrespro.ru", "phone": "+70433358850"}
0005432799104	C4181A	3053 778262	ALEKSANDR KUZNECOV	{"phone": "+70558197381"}
0005432799105	C4181A	6984 947747	GALINA NESTEROVA	{"phone": "+70919688121"}
0005432799106	F50A2D	0762 955814	ANTON BELOV	{"email": "a_belov_26111970@postgrespro.ru", "phone": "+70048313940"}
0005432799107	A60907	2122 226656	TATYANA KOLESNIKOVA	{"phone": "+70965013234"}
0005432799108	07E87F	4764 851730	TAISIYA AKIMOVA	{"email": "akimovataisiya091972@postgrespro.ru", "phone": "+70314341980"}
0005432799109	737AB3	1924 521519	VIKTOR EGOROV	{"phone": "+70101916683"}
0005432799110	308E5C	8549 915648	ANDREY MOROZOV	{"phone": "+70809609973"}
0005432799111	308E5C	3747 818481	ANGELINA KOROLEVA	{"phone": "+70974993786"}
0005432799112	214660	9532 172520	KONSTANTIN YAKOVLEV	{"email": "yakovlev_konstantin.1983@postgrespro.ru", "phone": "+70003376107"}
0005432799113	214660	3732 873815	PAVEL KUZNECOV	{"email": "pavel_kuznecov_081976@postgrespro.ru", "phone": "+70797614408"}
0005432799114	A1F8C1	9341 374526	MIKHAIL MIKHAYLOV	{"email": "mmikhaylov.101980@postgrespro.ru", "phone": "+70424419965"}
0005432799115	1290B3	1718 276175	NIKOLAY OSIPOV	{"email": "nosipov-12071969@postgrespro.ru", "phone": "+70904742503"}
0005432799116	31F632	7344 451170	OLGA ANISIMOVA	{"phone": "+70644686754"}
0005432799117	95A135	2638 190951	NATALYA KOROLEVA	{"phone": "+70711774436"}
0005432799118	293A76	5870 675354	LYUDMILA FROLOVA	{"phone": "+70706719980"}
0005432799119	A0DC23	4103 250381	SVETLANA KUZNECOVA	{"email": "svetlana_kuznecova_1979@postgrespro.ru", "phone": "+70513395625"}
0005432799120	1F8266	8214 537505	SERGEY GORBUNOV	{"phone": "+70173617434"}
0005432799121	46AB28	0028 242144	KONSTANTIN POPOV	{"phone": "+70825722257"}
0005432799122	6D11DC	0668 547314	ANASTASIYA ROMANOVA	{"phone": "+70895980183"}
0005432799123	2DBF0B	0949 252180	MIKHAIL NOVIKOV	{"email": "mikhail_novikov_30081978@postgrespro.ru", "phone": "+70332623771"}
0005432799124	4579D7	5524 674859	VLADIMIR SAVELEV	{"email": "vladimir.savelev_081976@postgrespro.ru", "phone": "+70664089212"}
0005432799125	4579D7	1731 146587	LYUDMILA PETROVA	{"email": "petrova-l27081971@postgrespro.ru", "phone": "+70058806742"}
0005432799126	57CAD0	8858 489234	KSENIYA LEBEDEVA	{"email": "k-lebedeva1974@postgrespro.ru", "phone": "+70677348844"}
0005432799127	05A3F9	2640 016111	IRINA POLYAKOVA	{"email": "irina_polyakova.12061976@postgrespro.ru", "phone": "+70888445270"}
0005432799128	05A3F9	3793 263690	ANNA MIKHAYLOVA	{"email": "a-mikhaylova.011981@postgrespro.ru", "phone": "+70371982807"}
0005432799129	05A3F9	9263 737741	ALFIYA EFIMOVA	{"email": "efimovaa-04081971@postgrespro.ru", "phone": "+70479318142"}
0005432799130	9B19E1	3645 190114	ALEVTINA ANISIMOVA	{"email": "anisimova_a02111981@postgrespro.ru", "phone": "+70504465583"}
0005432799131	B5F5E9	6328 424543	NATALYA VASILEVA	{"phone": "+70947491920"}
0005432799132	B5F5E9	8750 063344	TATYANA SEMENOVA	{"email": "semenova_tatyana_23031979@postgrespro.ru", "phone": "+70962588558"}
0005432799133	75DA89	3945 818228	EVGENIY NAZAROV	{"email": "e.nazarov_05011966@postgrespro.ru", "phone": "+70614168353"}
0005432799134	B2EC4F	2836 251987	ALEKSANDR FEDOTOV	{"email": "fedotov_a-17081977@postgrespro.ru", "phone": "+70378523441"}
0005432799135	ADF22A	1727 905436	VALENTINA KOROLEVA	{"email": "koroleva.valentina-091970@postgrespro.ru", "phone": "+70681243503"}
0005432799136	ADF22A	7135 588344	KSENIYA KUZMINA	{"email": "k_kuzmina-1958@postgrespro.ru", "phone": "+70885247193"}
0005432799137	2997AE	1726 410649	NIKOLAY MAKSIMOV	{"email": "nikolay.maksimov-011979@postgrespro.ru", "phone": "+70115787152"}
0005432799138	A77B94	0802 264733	VLADIMIR NOVIKOV	{"email": "v-novikov_1961@postgrespro.ru", "phone": "+70556447092"}
0005432799139	B13E21	2781 275638	IVAN MOROZOV	{"email": "ivan_morozov_10041970@postgrespro.ru", "phone": "+70105467544"}
0005432799140	CB0A9B	5502 245575	RAISA BELYAEVA	{"email": "belyaeva-raisa_1972@postgrespro.ru", "phone": "+70544304648"}
0005432799141	CB0A9B	1329 807293	GENNADIY KOROLEV	{"email": "korolev-gennadiy_04121977@postgrespro.ru", "phone": "+70831723324"}
0005432799142	CB0A9B	4626 993683	NATALYA KALININA	{"phone": "+70443497642"}
0005432799143	5E30BF	1188 346974	SVETLANA PETROVA	{"phone": "+70182667925"}
0005432799144	5E30BF	2482 140182	ILYA IVANOV	{"email": "ivanovilya_1972@postgrespro.ru", "phone": "+70799929548"}
0005432799145	5E30BF	8106 358563	VASILIY ROMANOV	{"email": "vromanov_061965@postgrespro.ru", "phone": "+70055192437"}
0005432799146	C6C858	3125 586930	EKATERINA GAVRILOVA	{"email": "gavrilovaekaterina12051970@postgrespro.ru", "phone": "+70333027543"}
0005432799147	C6C858	6198 748538	NATALYA ANISIMOVA	{"phone": "+70938557765"}
0005432799148	9CD6D8	4209 025165	OLEG MAKSIMOV	{"phone": "+70659336291"}
0005432799149	9CD6D8	6207 120449	TIMUR KUZNECOV	{"email": "kuznecovt10061968@postgrespro.ru", "phone": "+70188848833"}
0005432799150	9CD6D8	9185 625575	ANDREY BELOV	{"phone": "+70864380769"}
0005432799151	01C2F3	6672 890360	DMITRIY KRASNOV	{"phone": "+70143765804"}
0005432799152	01C2F3	1881 227920	OKSANA LAZAREVA	{"phone": "+70356446823"}
0005432799153	AB9986	2309 494571	GALINA KOZLOVA	{"email": "gkozlova_061982@postgrespro.ru", "phone": "+70575004441"}
0005432799154	B106D9	2315 026765	PETR IVANOV	{"phone": "+70834665328"}
0005432799155	119A4A	8334 043744	VERA BARANOVA	{"phone": "+70254105176"}
0005432799156	4039D9	5716 865922	EVGENIYA VASILEVA	{"email": "vasileva.e-071983@postgrespro.ru", "phone": "+70995361633"}
0005432799157	B6C581	0002 747556	SVETLANA SMIRNOVA	{"phone": "+70338943374"}
0005432799158	2CCE3D	6004 942094	ANNA SOKOLOVA	{"phone": "+70403855501"}
0005432799159	2CCE3D	4870 013823	LEONID NIKITIN	{"email": "lnikitin.031970@postgrespro.ru", "phone": "+70845430831"}
0005432799160	CD2BED	9248 899426	SERGEY OSIPOV	{"email": "sergeyosipov_111971@postgrespro.ru", "phone": "+70290949111"}
0005432799161	1ED70A	0281 622258	DARYA KOMAROVA	{"email": "komarova_d-15031969@postgrespro.ru", "phone": "+70597407449"}
0005432799162	66EC52	9760 107976	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov-1976@postgrespro.ru", "phone": "+70606262378"}
0005432799163	D42CC5	7179 115477	YULIYA AKIMOVA	{"email": "yuliyaakimova_11111971@postgrespro.ru", "phone": "+70184181083"}
0005432799164	318D4A	6415 606932	KONSTANTIN MARTYNOV	{"phone": "+70637461446"}
0005432799165	6FEF5F	0225 047078	NATALYA NAZAROVA	{"phone": "+70591582742"}
0005432799166	3B73AF	3290 467750	SERGEY KAZAKOV	{"email": "kazakov-sergey1970@postgrespro.ru", "phone": "+70478962052"}
0005432799167	3B73AF	2441 505123	SERGEY BELOV	{"email": "belov_s.16051979@postgrespro.ru", "phone": "+70982388466"}
0005432799168	9A2678	8583 290578	NINA GUSEVA	{"phone": "+70378010512"}
0005432799169	9A2678	9999 103329	SERGEY ISAEV	{"phone": "+70647529335"}
0005432799170	0FB29D	7005 411591	ANGELINA SMIRNOVA	{"email": "smirnova-angelina-121966@postgrespro.ru", "phone": "+70769619399"}
0005432799171	E2F2BA	0056 837960	DENIS PAVLOV	{"email": "denis_pavlov.041975@postgrespro.ru", "phone": "+70078276168"}
0005432799172	AFB597	4491 380970	ANATOLIY SOKOLOV	{"email": "anatoliy.sokolov011988@postgrespro.ru", "phone": "+70681731198"}
0005432799173	AFB597	5321 698012	IGOR MOROZOV	{"email": "morozov.i-05041967@postgrespro.ru", "phone": "+70693923126"}
0005432799174	2611CC	4017 388159	ANTONINA KARPOVA	{"email": "antonina.karpova-1974@postgrespro.ru", "phone": "+70939041038"}
0005432799175	2E559E	5536 150639	PETR VASILEV	{"email": "vasilev.petr-081977@postgrespro.ru", "phone": "+70926859056"}
0005432799176	2E559E	2438 566640	MARIYA PAVLOVA	{"phone": "+70280048649"}
0005432799177	AFCCF5	7736 159517	IRINA NOVIKOVA	{"email": "novikova.irina.1964@postgrespro.ru", "phone": "+70301993231"}
0005432799178	31B267	8920 373938	PAVEL GORBUNOV	{"email": "gorbunov-pavel20091987@postgrespro.ru", "phone": "+70516622517"}
0005432799179	1BF738	9645 334633	LYUDMILA SEMENOVA	{"email": "l_semenova.1978@postgrespro.ru", "phone": "+70213460079"}
0005432799180	1BF738	3081 626822	YULIYA KUZNECOVA	{"email": "kuznecova-y.041984@postgrespro.ru", "phone": "+70682620448"}
0005432799181	CEDFC3	4465 561755	ANDREY SEMENOV	{"phone": "+70953840475"}
0005432799182	CEDFC3	0014 263696	NIKOLAY KULIKOV	{"email": "n-kulikov_24051976@postgrespro.ru", "phone": "+70006112346"}
0005432799183	771DAB	0670 890904	GENNADIY KONOVALOV	{"phone": "+70264456252"}
0005432799184	C0C8E2	2204 025644	TATYANA DENISOVA	{"phone": "+70705905014"}
0005432799185	6B9F17	4209 748480	VLADIMIR BORISOV	{"email": "vborisov021966@postgrespro.ru", "phone": "+70275964085"}
0005432799186	C5EC81	1325 026812	SERGEY VASILEV	{"email": "vasilevs-13111964@postgrespro.ru", "phone": "+70612404800"}
0005432799187	0074DE	0754 863170	ARTEM CHERNOV	{"email": "a-chernov10111966@postgrespro.ru", "phone": "+70445163361"}
0005432799188	9D3E8B	4686 492022	VIKTOR GRIGOREV	{"phone": "+70351406047"}
0005432799189	4E330B	7922 447784	MIKHAIL SCHERBAKOV	{"email": "scherbakovmikhail061969@postgrespro.ru", "phone": "+70668396861"}
0005432799190	B72970	5551 305300	VALENTINA GRISHINA	{"phone": "+70794870431"}
0005432799191	B72970	3777 389071	LIDIYA POPOVA	{"phone": "+70322197138"}
0005432799192	916D6A	7995 971615	VERA ILINA	{"phone": "+70218887028"}
0005432799193	916D6A	3736 978124	ANNA MALYSHEVA	{"phone": "+70960857936"}
0005432799194	A9B940	6362 090557	NIKOLAY ANTONOV	{"email": "nikolay_antonov_061972@postgrespro.ru", "phone": "+70905477901"}
0005432799195	A9B940	7809 993965	OKSANA TIKHONOVA	{"phone": "+70013305533"}
0005432799196	A9B940	2373 780903	MADINA CHERNOVA	{"phone": "+70365349548"}
0005432799197	DEB201	1682 420814	NIKOLAY TIKHONOV	{"phone": "+70077562781"}
0005432799198	9A11A3	7102 349901	NATALYA KONOVALOVA	{"phone": "+70567993016"}
0005432799199	B4E9C0	5090 790956	ALEKSEY VOLKOV	{"phone": "+70371633381"}
0005432799200	3E41E0	0430 331783	ALEKSANDR KRASNOV	{"email": "krasnov-a-011984@postgrespro.ru", "phone": "+70197495125"}
0005432799201	3E41E0	9027 545782	LYUDMILA NESTEROVA	{"phone": "+70821554095"}
0005432799202	C310F2	1521 767021	VALENTINA KARPOVA	{"email": "v_karpova1973@postgrespro.ru", "phone": "+70455401646"}
0005432799203	C310F2	1220 016669	RAISA FILATOVA	{"email": "raisa-filatova1967@postgrespro.ru", "phone": "+70685337338"}
0005432799204	8E0685	5788 816720	ZOYA NIKIFOROVA	{"email": "zoya_nikiforova1964@postgrespro.ru", "phone": "+70665604531"}
0005432799205	BBC4B8	9006 068944	LEV MIRONOV	{"phone": "+70947177286"}
0005432799206	22F262	1304 896276	ALEKSANDR TIMOFEEV	{"phone": "+70853964096"}
0005432799207	E84F2A	1756 127314	RODION EGOROV	{"email": "egorovr_15061975@postgrespro.ru", "phone": "+70591559468"}
0005432799208	055C99	8536 924845	IVAN NIKITIN	{"phone": "+70349914146"}
0005432799209	EB21FB	7230 944814	ANATOLIY MOROZOV	{"email": "morozovanatoliy-16111980@postgrespro.ru", "phone": "+70152836851"}
0005432799210	EB21FB	2352 090524	SERGEY TARASOV	{"email": "tarasov_sergey_1972@postgrespro.ru", "phone": "+70168693553"}
0005432799211	AEC623	4388 770756	SERGEY SERGEEV	{"phone": "+70657325624"}
0005432799212	52EC59	1765 378708	RAFIK DMITRIEV	{"phone": "+70554827342"}
0005432799213	131268	5078 211139	NATALYA FEDOROVA	{"email": "fedorova-natalya-081973@postgrespro.ru", "phone": "+70049118368"}
0005432799214	2C2E33	1506 817938	MARGARITA KOVALEVA	{"email": "m_kovaleva-11051962@postgrespro.ru", "phone": "+70418033686"}
0005432799215	2C2E33	4833 301868	ELENA ISAEVA	{"phone": "+70254240738"}
0005432799216	1A6BB3	5027 850254	ELENA NOVIKOVA	{"phone": "+70662622205"}
0005432799217	1B5233	0805 265933	NATALYA FADEEVA	{"email": "n-fadeeva101963@postgrespro.ru", "phone": "+70524143207"}
0005432799218	361708	7216 619815	ANATOLIY ALEKSEEV	{"phone": "+70376516339"}
0005432799219	B5EBF6	4022 348781	SERGEY VLASOV	{"email": "s.vlasov.05061960@postgrespro.ru", "phone": "+70174779175"}
0005432799220	25C303	4185 041888	ALEKSEY FOMIN	{"email": "aleksey.fomin-1965@postgrespro.ru", "phone": "+70156188546"}
0005432799221	A5FE32	5439 608707	MIKHAIL SAVELEV	{"phone": "+70348531790"}
0005432799222	A5FE32	0775 293932	ANDREY MIRONOV	{"email": "a_mironov091966@postgrespro.ru", "phone": "+70112565231"}
0005432799223	AA4F5B	5858 245718	ELENA CHERNOVA	{"email": "chernova.elena031976@postgrespro.ru", "phone": "+70372153750"}
0005432799224	AA4F5B	5689 927059	NATALYA MATVEEVA	{"phone": "+70848838743"}
0005432799225	119C35	1971 257156	LYUDMILA ORLOVA	{"email": "orlova_lyudmila.121960@postgrespro.ru", "phone": "+70689099666"}
0005432799226	B59C6D	2305 008625	OLEG BELOV	{"email": "oleg_belov.121973@postgrespro.ru", "phone": "+70698155259"}
0005432799227	B59C6D	6530 485866	EVGENIY NIKOLAEV	{"email": "nikolaevevgeniy1971@postgrespro.ru", "phone": "+70282307824"}
0005432799228	4D4B3E	7360 265256	ALEKSANDR KUZNECOV	{"email": "akuznecov_15091982@postgrespro.ru", "phone": "+70036005870"}
0005432799229	6F5034	4074 800846	DENIS SOROKIN	{"email": "sorokin_d.1982@postgrespro.ru", "phone": "+70461874153"}
0005432799230	8FE177	6397 057040	ELENA ALEKSANDROVA	{"email": "aleksandrova_elena-041964@postgrespro.ru", "phone": "+70873026400"}
0005432799231	046EC4	2020 475723	ARTEM MARTYNOV	{"email": "artemmartynov1971@postgrespro.ru", "phone": "+70067077336"}
0005432799232	046EC4	4698 715285	ROMAN ISAEV	{"phone": "+70070562384"}
0005432799233	018346	9572 009647	VASILIY SAVELEV	{"phone": "+70455266226"}
0005432799234	2300E8	1299 234582	ALEKSANDR TIMOFEEV	{"phone": "+70412454005"}
0005432799235	6053D2	8407 525940	LYUDMILA FILATOVA	{"email": "lyudmilafilatova_1973@postgrespro.ru", "phone": "+70410327867"}
0005432799236	6053D2	1642 532228	MAKSIM IVANOV	{"email": "ivanov-m-1975@postgrespro.ru", "phone": "+70978326289"}
0005432799237	70ABFD	9648 183035	RAISA NAZAROVA	{"email": "raisa_nazarova1974@postgrespro.ru", "phone": "+70110648405"}
0005432799238	32BCDD	8166 394647	NATALYA MIRONOVA	{"email": "nmironova_071966@postgrespro.ru", "phone": "+70218442376"}
0005432799239	FB940C	4304 369616	KSENIYA RODIONOVA	{"phone": "+70241466440"}
0005432799240	FB940C	1060 440937	VIKTOR KULIKOV	{"phone": "+70947622592"}
0005432799241	2DFA9A	3404 745938	ALEKSANDR KUZMIN	{"email": "kuzmin-a081963@postgrespro.ru", "phone": "+70619779213"}
0005432799242	2DFA9A	9255 302616	PAVEL YAKOVLEV	{"email": "p-yakovlev_1976@postgrespro.ru", "phone": "+70989328996"}
0005432799243	E78A9E	0086 406129	YULIYA KALININA	{"email": "y_kalinina.23031975@postgrespro.ru", "phone": "+70069854966"}
0005432799244	47EB6A	5525 625056	NATALYA NOVIKOVA	{"phone": "+70697638611"}
0005432799245	1C1498	0112 216830	VALENTINA IVANOVA	{"phone": "+70833347263"}
0005432799246	1C1498	7817 214248	IVAN KISELEV	{"email": "i.kiselev1969@postgrespro.ru", "phone": "+70611496951"}
0005432799247	E89278	4781 097070	ALEKSANDR VOLKOV	{"phone": "+70123857397"}
0005432799248	A576B1	2009 407816	ANNA TIMOFEEVA	{"phone": "+70712142504"}
0005432799249	3164A2	7220 167440	ILYA VOROBEV	{"phone": "+70083160013"}
0005432799250	75790A	3562 037962	VYACHESLAV ALEKSEEV	{"phone": "+70925277317"}
0005432799251	805899	5192 004834	SOFYA FROLOVA	{"phone": "+70801162160"}
0005432799252	719434	7161 694108	NATALYA KONOVALOVA	{"email": "konovalova-natalya_1976@postgrespro.ru", "phone": "+70987854077"}
0005432799253	6A2C8E	6492 071757	EKATERINA SIDOROVA	{"email": "sidorovae011962@postgrespro.ru", "phone": "+70681911665"}
0005432799254	6A2C8E	0645 293499	OLGA MEDVEDEVA	{"phone": "+70578133251"}
0005432799255	DAFDFF	0805 984830	NATALYA KULIKOVA	{"email": "kulikova_natalya-1978@postgrespro.ru", "phone": "+70493307107"}
0005432799256	A13C02	0714 703400	ALEKSEY SERGEEV	{"phone": "+70494648681"}
0005432799257	A13C02	6491 651161	ANASTASIYA CHERNOVA	{"phone": "+70611871482"}
0005432799258	36A777	0556 533057	POLINA ANDREEVA	{"phone": "+70791731462"}
0005432799259	F20F9B	3533 957114	VERA MIKHAYLOVA	{"phone": "+70663607695"}
0005432799260	19A669	3348 288244	VIKTORIYA NIKITINA	{"email": "v_nikitina1977@postgrespro.ru", "phone": "+70318574893"}
0005432799261	F2375A	0801 591605	SERGEY KUZNECOV	{"phone": "+70395822639"}
0005432799262	3E239F	2762 070095	INNA MOISEEVA	{"phone": "+70947175306"}
0005432799263	8056E4	3745 002848	ALEKSEY SEMENOV	{"email": "semenov-a111972@postgrespro.ru", "phone": "+70267252465"}
0005432799264	662AF8	5951 362556	SERGEY SIDOROV	{"phone": "+70150741139"}
0005432799265	DBAA58	7115 665205	YURIY FEDOTOV	{"phone": "+70891434630"}
0005432799266	17289F	5126 634085	TATYANA NIKOLAEVA	{"email": "t_nikolaeva.1964@postgrespro.ru", "phone": "+70323535083"}
0005432799267	17289F	9521 287837	DARYA KUZMINA	{"phone": "+70683453057"}
0005432799268	FB1588	1063 441438	ELENA VOLKOVA	{"email": "volkovaelena-041966@postgrespro.ru", "phone": "+70086976808"}
0005432799269	FB1588	7018 773076	SVETLANA KOMAROVA	{"phone": "+70424251808"}
0005432799270	EE6CDB	9045 700746	NAIL MARTYNOV	{"email": "n_martynov-27021962@postgrespro.ru", "phone": "+70911594673"}
0005432799271	6AF69A	3390 797994	ANATOLIY FROLOV	{"phone": "+70785550646"}
0005432799272	BC3BB6	5301 678711	LYUBOV MIRONOVA	{"email": "mironova.l-021978@postgrespro.ru", "phone": "+70668960941"}
0005432799273	4C67AA	4646 942614	SERGEY ALEKSANDROV	{"phone": "+70316935096"}
0005432799442	36CD82	8967 155711	ELENA TARASOVA	{"phone": "+70244244395"}
0005432799274	783314	1875 265952	GULSHAT YUDINA	{"email": "yudina_gulshat1967@postgrespro.ru", "phone": "+70777584227"}
0005432799275	753E4C	4634 371983	MARINA ZAKHAROVA	{"email": "marina_zakharova_1982@postgrespro.ru", "phone": "+70376559278"}
0005432799276	753E4C	7885 144880	ALEKSANDR TIMOFEEV	{"email": "timofeevaleksandr.22081974@postgrespro.ru", "phone": "+70957522805"}
0005432799277	175240	4448 789129	EKATERINA KARPOVA	{"email": "karpovaekaterina_18011974@postgrespro.ru", "phone": "+70781718631"}
0005432799278	175240	8351 421321	SERGEY PETROV	{"phone": "+70526405832"}
0005432799279	CAAA6D	8696 626308	EGOR ISAEV	{"phone": "+70382370779"}
0005432799280	753C8D	0133 408127	EVGENIY SAVELEV	{"phone": "+70696830076"}
0005432799281	017CBF	5338 400286	VIKTOR PETROV	{"email": "vpetrov_121969@postgrespro.ru", "phone": "+70560237359"}
0005432799282	EABB81	2470 762680	GALINA ZAKHAROVA	{"phone": "+70867115253"}
0005432799283	EABB81	9443 411170	MIKHAIL MAKAROV	{"email": "makarov-mikhail-22051974@postgrespro.ru", "phone": "+70733172783"}
0005432799284	84D346	6204 219175	OLGA TIKHONOVA	{"phone": "+70076049048"}
0005432799285	84D346	3087 117915	ALEKSEY VASILEV	{"email": "vasilev-aleksey_12051974@postgrespro.ru", "phone": "+70181507063"}
0005432799286	4EFF92	9106 780557	MARIYA ABRAMOVA	{"email": "m.abramova_1979@postgrespro.ru", "phone": "+70618561385"}
0005432799287	215364	2559 319479	NINA ZOTOVA	{"email": "zotova_n031974@postgrespro.ru", "phone": "+70016587073"}
0005432799288	215364	9573 809240	KIRILL RODIONOV	{"phone": "+70897563071"}
0005432799289	BB3346	4636 621515	TATYANA ARKHIPOVA	{"email": "tatyana_arkhipova-17081979@postgrespro.ru", "phone": "+70465294641"}
0005432799290	94A8B7	1043 105241	ELVIRA IVANOVA	{"phone": "+70006297629"}
0005432799291	94A8B7	7221 530067	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya_14031966@postgrespro.ru", "phone": "+70467871102"}
0005432799292	8AC6C7	4271 553351	NINA KOROLEVA	{"email": "nina_koroleva.111974@postgrespro.ru", "phone": "+70079002121"}
0005432799293	8AC6C7	5430 180626	MIKHAIL NIKOLAEV	{"phone": "+70459200426"}
0005432799294	64FB9E	6056 393819	IRINA ROMANOVA	{"email": "romanova.irina-061972@postgrespro.ru", "phone": "+70001642260"}
0005432799295	545396	6395 968427	YAROSLAV GUSEV	{"email": "gusev_y.091982@postgrespro.ru", "phone": "+70241856017"}
0005432799296	B120C8	5562 333148	NINA GUSEVA	{"phone": "+70724613309"}
0005432799297	B120C8	4691 928694	SVETLANA ROMANOVA	{"phone": "+70341715310"}
0005432799298	1FFDB7	5672 626915	YULIYA LUKYANOVA	{"email": "lukyanova.yuliya061975@postgrespro.ru", "phone": "+70067853374"}
0005432799299	59FFF3	5710 734416	ANATOLIY GUSEV	{"phone": "+70405768190"}
0005432799300	59FFF3	1831 105821	VALENTINA KOMAROVA	{"phone": "+70684763889"}
0005432799301	59FFF3	4366 829457	ALEKSANDR EGOROV	{"email": "aleksandr.egorov-1959@postgrespro.ru", "phone": "+70370654355"}
0005432799302	A2674B	3103 366086	YAROSLAV GRIGOREV	{"phone": "+70923249967"}
0005432799303	826102	3245 045302	VIKTOR MEDVEDEV	{"phone": "+70398282366"}
0005432799304	826102	9256 286234	ANDREY GAVRILOV	{"email": "a_gavrilov.20031979@postgrespro.ru", "phone": "+70060894899"}
0005432799305	195F6D	0314 148220	VITALIY ZAYCEV	{"email": "zaycev-v.121970@postgrespro.ru", "phone": "+70997549192"}
0005432799306	5504AC	7938 496804	OKSANA KOZLOVA	{"phone": "+70714186769"}
0005432799307	5504AC	7520 711938	ARKADIY ZAYCEV	{"email": "zaycev_a_1974@postgrespro.ru", "phone": "+70189825067"}
0005432799308	60CDD8	3290 971863	RAISA DMITRIEVA	{"email": "r.dmitrieva.1973@postgrespro.ru", "phone": "+70543505363"}
0005432799309	CA910E	3817 807006	GRIGORIY DMITRIEV	{"phone": "+70052654705"}
0005432799310	CA910E	8190 505385	YURIY IVANOV	{"phone": "+70320847031"}
0005432799311	802664	7072 240246	DMITRIY FEDOTOV	{"phone": "+70227319524"}
0005432799312	802664	6858 791532	ANASTASIYA GORBUNOVA	{"phone": "+70404747447"}
0005432799313	B25980	7217 384366	VALERIY FROLOV	{"email": "frolovvaleriy.1977@postgrespro.ru", "phone": "+70567078436"}
0005432799314	00A036	3014 857932	IRINA MAKAROVA	{"phone": "+70436679547"}
0005432799315	00A036	2188 299033	ALESYA SERGEEVA	{"phone": "+70596574834"}
0005432799316	CF8B19	0604 868673	ALEKSANDRA VOLKOVA	{"email": "a-volkova1972@postgrespro.ru", "phone": "+70015509264"}
0005432799317	26C4F5	0697 012352	TATYANA KOMAROVA	{"email": "komarovat061976@postgrespro.ru", "phone": "+70808352632"}
0005432799318	26C4F5	3674 250764	ALEKSANDRA NIKOLAEVA	{"phone": "+70192844424"}
0005432799319	26C4F5	0047 485402	ANNA NIKIFOROVA	{"email": "a-nikiforova.101973@postgrespro.ru", "phone": "+70477839543"}
0005432799320	5613B1	3742 582941	MARGARITA ANISIMOVA	{"email": "anisimovam-13041980@postgrespro.ru", "phone": "+70765224899"}
0005432799321	5613B1	2373 074748	EKATERINA FILIPPOVA	{"email": "filippova_ekaterina-1970@postgrespro.ru", "phone": "+70069783249"}
0005432799322	879F16	2632 295137	VIKTOR ANDREEV	{"email": "andreev.v02031976@postgrespro.ru", "phone": "+70922848415"}
0005432799323	773575	1723 641787	ELENA TIMOFEEVA	{"phone": "+70217895161"}
0005432799324	2451D7	2790 435616	TATYANA TITOVA	{"phone": "+70142731262"}
0005432799325	2451D7	8514 387845	ILYA MEDVEDEV	{"phone": "+70654013648"}
0005432799326	5190E7	2439 252156	TATYANA SOKOLOVA	{"email": "sokolova_t051988@postgrespro.ru", "phone": "+70851284452"}
0005432799327	FC70A3	2634 592205	NELLI MALYSHEVA	{"email": "malysheva-n.1979@postgrespro.ru", "phone": "+70439597105"}
0005432799328	A51EDD	6646 679249	DENIS ALEKSEEV	{"phone": "+70431079526"}
0005432799329	949F2D	5462 491829	SERGEY ANDREEV	{"email": "andreev_s-22101981@postgrespro.ru", "phone": "+70447094044"}
0005432799330	ADC3AE	9011 242933	PAVEL KULIKOV	{"email": "pavel-kulikov.12071982@postgrespro.ru", "phone": "+70404859615"}
0005432799331	F04C20	9241 834591	ARSENIY KISELEV	{"email": "kiselev-arseniy-04121972@postgrespro.ru", "phone": "+70284857053"}
0005432799332	F04C20	3699 093520	ANATOLIY PETROV	{"email": "petrov.anatoliy051973@postgrespro.ru", "phone": "+70198024161"}
0005432799333	F04C20	7596 676325	VIKTORIYA POPOVA	{"email": "v.popova_1976@postgrespro.ru", "phone": "+70691368605"}
0005432799334	F04C20	6947 251243	LYUDMILA SOKOLOVA	{"email": "lyudmila_sokolova.061970@postgrespro.ru", "phone": "+70209203310"}
0005432799335	B26A2C	0522 124279	VALENTINA IVANOVA	{"email": "valentina.ivanova22091965@postgrespro.ru", "phone": "+70583361599"}
0005432799336	7939A8	2150 913269	NIKITA AFANASEV	{"email": "afanasevn_12101962@postgrespro.ru", "phone": "+70051824118"}
0005432799337	7939A8	9245 074850	ELENA SOROKINA	{"email": "sorokina.elena-1977@postgrespro.ru", "phone": "+70025136464"}
0005432799338	0F524B	3680 688061	ALINA NESTEROVA	{"phone": "+70471891355"}
0005432799339	BD4D6E	6614 756787	EVGENIY ZAKHAROV	{"phone": "+70710870134"}
0005432799340	BD4D6E	4677 710044	ANTON NAZAROV	{"email": "nazarov-a17051985@postgrespro.ru", "phone": "+70643363947"}
0005432799341	70AA0F	1440 017275	ALEVTINA SOKOLOVA	{"email": "sokolovaalevtina.041976@postgrespro.ru", "phone": "+70199400021"}
0005432799342	8E407D	2740 016585	GULNARA KUZNECOVA	{"phone": "+70546894907"}
0005432799343	8E407D	0936 918731	SVETLANA AKIMOVA	{"phone": "+70796573088"}
0005432799344	ACE1DB	8056 724711	SERGEY ZHURAVLEV	{"email": "szhuravlev.1965@postgrespro.ru", "phone": "+70310749241"}
0005432799345	AA0A88	8652 404387	VYACHESLAV OSIPOV	{"phone": "+70042193893"}
0005432799346	AA0A88	5966 355651	VERA SMIRNOVA	{"phone": "+70229587746"}
0005432799347	F1970E	7329 866420	ALEKSANDR PETROV	{"email": "petrov-a111973@postgrespro.ru", "phone": "+70910832992"}
0005432799348	898C82	4096 152017	NATALIYA POLYAKOVA	{"email": "polyakova-n.13061972@postgrespro.ru", "phone": "+70392769945"}
0005432799349	632230	4223 607693	ELENA SIDOROVA	{"email": "elena.sidorova_071970@postgrespro.ru", "phone": "+70496513175"}
0005432799350	632230	1015 325897	ELENA MOROZOVA	{"email": "morozova.elena.1966@postgrespro.ru", "phone": "+70573838790"}
0005432799351	F53A04	2997 284262	SERGEY MIRONOV	{"email": "mironov.sergey_031973@postgrespro.ru", "phone": "+70266080974"}
0005432799352	3DD279	0918 309806	ZULFIYA BORISOVA	{"phone": "+70206085397"}
0005432799353	E4CC22	3888 490424	DMITRIY NAZAROV	{"email": "nazarov.dmitriy.1976@postgrespro.ru", "phone": "+70837913238"}
0005432799354	E4CC22	8995 606214	ALEKSEY KARPOV	{"email": "a.karpov23121960@postgrespro.ru", "phone": "+70133236665"}
0005432799355	144807	4327 012118	MARIYA MIKHAYLOVA	{"phone": "+70624165266"}
0005432799356	144807	1539 735061	ALEKSEY DENISOV	{"email": "denisov.a.031981@postgrespro.ru", "phone": "+70666712664"}
0005432799357	144807	2723 619330	MAKSIM KUZMIN	{"phone": "+70975266331"}
0005432799358	4203E4	4125 754326	MARIYA POTAPOVA	{"phone": "+70932532738"}
0005432799359	6ACCD9	3128 031450	ANASTASIYA DAVYDOVA	{"email": "a.davydova_20021974@postgrespro.ru", "phone": "+70788273806"}
0005432799360	ADB549	1665 613214	DMITRIY VOROBEV	{"phone": "+70357360388"}
0005432799361	82FF01	7931 315788	MARIYA DAVYDOVA	{"phone": "+70284215940"}
0005432799362	3896AB	8097 868047	ALEKSEY VOROBEV	{"phone": "+70797799524"}
0005432799363	3896AB	1916 075806	ANTON ABRAMOV	{"phone": "+70513166490"}
0005432799364	E68F04	2669 587564	SANIYA ZAKHAROVA	{"email": "s.zakharova.09091976@postgrespro.ru", "phone": "+70793114108"}
0005432799365	E68F04	3746 422312	ALEKSANDR ABRAMOV	{"email": "a.abramov.19081977@postgrespro.ru", "phone": "+70513974029"}
0005432799366	E68F04	7075 378628	ANNA GUSEVA	{"phone": "+70113045893"}
0005432799367	E68F04	1282 550396	DARYA FROLOVA	{"phone": "+70574061997"}
0005432799368	4BE534	4305 216601	VLADIMIR SOKOLOV	{"phone": "+70334185676"}
0005432799369	EE900E	2275 728224	ALEKSEY KUZNECOV	{"phone": "+70028239821"}
0005432799370	201224	7197 174220	EKATERINA GAVRILOVA	{"email": "e-gavrilova.07051973@postgrespro.ru", "phone": "+70040774958"}
0005432799371	C6D357	8240 644689	DMITRIY ANTONOV	{"email": "d-antonov031977@postgrespro.ru", "phone": "+70020640863"}
0005432799372	FC8E5E	6731 489946	LILIYA SOROKINA	{"email": "l-sorokina-25121964@postgrespro.ru", "phone": "+70771690447"}
0005432799373	171C9C	8676 871666	MARK EGOROV	{"email": "mark_egorov121980@postgrespro.ru", "phone": "+70040465491"}
0005432799374	AD50AC	3393 956227	NIKITA ISAEV	{"phone": "+70289769824"}
0005432799375	C0B960	4402 126031	MARIYA SCHERBAKOVA	{"phone": "+70488606203"}
0005432799376	A200BE	6639 981516	VALENTIN MOISEEV	{"email": "valentin-moiseev.011967@postgrespro.ru", "phone": "+70627554898"}
0005432799377	9290A7	1363 046518	OLGA ROMANOVA	{"phone": "+70926986620"}
0005432799378	9290A7	9294 125782	YURIY ABRAMOV	{"email": "yuriyabramov_1967@postgrespro.ru", "phone": "+70142471926"}
0005432799379	9290A7	9841 525013	YAROSLAV ALEKSEEV	{"phone": "+70093076904"}
0005432799380	EA5307	7121 949534	SERGEY SOKOLOV	{"phone": "+70431969321"}
0005432799381	EA5307	9885 583868	VERONIKA OSIPOVA	{"phone": "+70228733222"}
0005432799382	9F26DE	7913 649886	MAKSIM ZHUKOV	{"phone": "+70205102257"}
0005432799383	562553	8316 828101	VLADIMIR VASILEV	{"phone": "+70734936132"}
0005432799384	106023	9981 077755	SERGEY ZHURAVLEV	{"phone": "+70080571807"}
0005432799385	106023	0092 670223	VASILIY SOROKIN	{"phone": "+70874670047"}
0005432799386	69353A	5768 944533	POLINA FADEEVA	{"email": "fadeeva_p_121976@postgrespro.ru", "phone": "+70118829634"}
0005432799387	478A19	7276 419208	GENNADIY MELNIKOV	{"phone": "+70929816313"}
0005432799388	FF49D9	9410 892262	IGOR EGOROV	{"email": "i-egorov-051975@postgrespro.ru", "phone": "+70805702975"}
0005432799389	4142B3	0591 587455	OLGA NESTEROVA	{"email": "olganesterova-071987@postgrespro.ru", "phone": "+70803991373"}
0005432799390	BA55BD	3281 088738	TATYANA SMIRNOVA	{"email": "smirnova_t12071985@postgrespro.ru", "phone": "+70147948032"}
0005432799391	1E95AF	5023 622552	VLADISLAV IVANOV	{"email": "ivanovvladislav14071967@postgrespro.ru", "phone": "+70117883883"}
0005432799392	1E95AF	2978 053858	GALINA VLASOVA	{"email": "galinavlasova.1971@postgrespro.ru", "phone": "+70143056111"}
0005432799393	6D76A8	6333 847879	NIKOLAY BARANOV	{"email": "baranov-n041987@postgrespro.ru", "phone": "+70003971091"}
0005432799394	6D76A8	2870 150992	KONSTANTIN KOZLOV	{"email": "kozlov-k-051975@postgrespro.ru", "phone": "+70050771074"}
0005432799395	6D76A8	8735 495444	STANISLAV CHERNOV	{"phone": "+70861025765"}
0005432799396	240F38	3555 508025	SHAMIL FEDOROV	{"phone": "+70918695176"}
0005432799397	F95839	6513 003194	DANIL IVANOV	{"email": "ivanov_d-1964@postgrespro.ru", "phone": "+70686777731"}
0005432799398	F95839	3329 796203	VERA GERASIMOVA	{"phone": "+70179111693"}
0005432799399	D7E75F	7207 613645	VIKTORIYA ORLOVA	{"phone": "+70892991824"}
0005432799400	4E1C7F	0846 407187	MARINA GERASIMOVA	{"email": "m.gerasimova091977@postgrespro.ru", "phone": "+70178152405"}
0005432799401	7EE4C2	9868 100939	DENIS ZAKHAROV	{"email": "zakharov_denis-12121977@postgrespro.ru", "phone": "+70764526295"}
0005432799402	BECB6A	8251 300076	OLEG NAUMOV	{"phone": "+70215129053"}
0005432799403	F07E4E	9336 646906	GENNADIY PETROV	{"phone": "+70701299082"}
0005432799404	C58F13	5153 461683	VLADIMIR SIDOROV	{"phone": "+70490351538"}
0005432799405	C58F13	5543 550510	VALENTINA SCHERBAKOVA	{"phone": "+70635497550"}
0005432799406	A0F9CF	5641 874035	NINA POPOVA	{"email": "n.popova_1972@postgrespro.ru", "phone": "+70494107608"}
0005432799407	29085D	4451 433317	NADEZHDA KUZMINA	{"email": "nadezhdakuzmina.041964@postgrespro.ru", "phone": "+70175592071"}
0005432799408	29085D	5726 916430	ELENA FEDOROVA	{"email": "e.fedorova061981@postgrespro.ru", "phone": "+70415850240"}
0005432799409	ADEB82	7091 669886	NINA KUZMINA	{"phone": "+70686457803"}
0005432799410	ADEB82	7449 654255	LYUBOV VLASOVA	{"phone": "+70213698893"}
0005432799411	38F879	9188 077794	ALEKSANDR IVANOV	{"phone": "+70624978891"}
0005432799412	38F879	5943 829689	GEORGIY ANDREEV	{"email": "georgiy_andreev-021969@postgrespro.ru", "phone": "+70584625948"}
0005432799413	38F879	7433 645224	ARKADIY KUZMIN	{"phone": "+70651115984"}
0005432799414	86FC9F	4222 222255	ANDREY ZAKHAROV	{"phone": "+70390565117"}
0005432799415	B504A3	4445 306961	ALEKSEY GERASIMOV	{"phone": "+70552899565"}
0005432799416	C5501B	3462 932962	OLEG MOROZOV	{"phone": "+70840836758"}
0005432799417	C5501B	1006 481742	ZULFIYA LOGINOVA	{"email": "z_loginova.27061972@postgrespro.ru", "phone": "+70054245181"}
0005432799418	879E89	7552 302019	DMITRIY MOROZOV	{"phone": "+70562744520"}
0005432799419	A8AB0C	5318 072729	VLADIMIR ALEKSANDROV	{"phone": "+70840317795"}
0005432799420	A8AB0C	4778 120772	IRINA ALEKSEEVA	{"phone": "+70136387649"}
0005432799421	6AEB02	2125 353584	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.13011975@postgrespro.ru", "phone": "+70594864634"}
0005432799422	25BF56	5718 196274	EVGENIY DENISOV	{"phone": "+70701264519"}
0005432799423	AB7F66	7592 813337	IRINA ILINA	{"email": "ilinai1978@postgrespro.ru", "phone": "+70927173927"}
0005432799424	1A0219	6297 831962	SERGEY KONOVALOV	{"email": "konovalov_s-111970@postgrespro.ru", "phone": "+70188676561"}
0005432799425	1A0219	2081 278834	NATALYA MIRONOVA	{"email": "mironovan_12061972@postgrespro.ru", "phone": "+70517151016"}
0005432799426	FF346E	5967 515599	PAVEL ANDREEV	{"email": "andreevp.1973@postgrespro.ru", "phone": "+70884681771"}
0005432799427	655175	4424 940152	EVGENIY KOROLEV	{"email": "korolev_evgeniy-091983@postgrespro.ru", "phone": "+70417521903"}
0005432799428	E95350	3288 634434	VLADISLAV PAVLOV	{"phone": "+70337715219"}
0005432799429	0E14CC	7373 858489	DARYA LAZAREVA	{"phone": "+70699498180"}
0005432799430	20DF69	0238 767548	TAISIYA KUZMINA	{"email": "kuzmina.taisiya_09031977@postgrespro.ru", "phone": "+70186522863"}
0005432799431	20DF69	4299 340684	VERONIKA NESTEROVA	{"phone": "+70141279078"}
0005432799432	6068E7	6542 701646	VLADIMIR SERGEEV	{"email": "sergeev_vladimir_01121964@postgrespro.ru", "phone": "+70980429896"}
0005432799433	6068E7	5523 542240	MARIYA FROLOVA	{"email": "frolova.mariya.071965@postgrespro.ru", "phone": "+70531964949"}
0005432799434	7CC4A6	3231 330100	ELENA MEDVEDEVA	{"email": "e.medvedeva1986@postgrespro.ru", "phone": "+70678876826"}
0005432799435	31134A	9572 992473	IVAN SEMENOV	{"email": "semenovi.1972@postgrespro.ru", "phone": "+70449679771"}
0005432799436	B6CFD2	6494 022801	MARINA ANDREEVA	{"email": "andreeva.m.22121966@postgrespro.ru", "phone": "+70690143208"}
0005432799437	9D29FB	9463 996187	VALENTINA IVANOVA	{"phone": "+70031808404"}
0005432799438	732521	7152 195066	NIKOLAY MAKAROV	{"email": "nikolaymakarov_1961@postgrespro.ru", "phone": "+70778865272"}
0005432799439	18EA99	4640 877929	LYUDMILA POPOVA	{"email": "popovalyudmila_011959@postgrespro.ru", "phone": "+70595870473"}
0005432799440	EAFA3F	3881 714245	MARIYA ANTONOVA	{"phone": "+70993523946"}
0005432799441	EAFA3F	6828 848112	OLGA GAVRILOVA	{"phone": "+70354361867"}
0005432799443	36CD82	0088 583061	ARTEM MAKSIMOV	{"phone": "+70036317184"}
0005432799444	A9BF32	2330 534462	ANNA VOROBEVA	{"phone": "+70532007376"}
0005432799445	305D21	4627 273044	ERIK SOLOVEV	{"phone": "+70372495589"}
0005432799446	305D21	8903 004401	DENIS KONOVALOV	{"phone": "+70992879430"}
0005432799447	4A15B4	3004 725527	PAVEL SEMENOV	{"email": "semenovpavel-1962@postgrespro.ru", "phone": "+70925142880"}
0005432799448	F9F9A6	7454 516681	OLGA MIRONOVA	{"phone": "+70255579129"}
0005432799449	B51C92	7747 484751	ALEKSANDR ALEKSEEV	{"phone": "+70768006918"}
0005432799450	29733D	7270 993647	SERGEY VLASOV	{"email": "s-vlasov.121978@postgrespro.ru", "phone": "+70792640618"}
0005432799451	29733D	1217 971573	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr_061978@postgrespro.ru", "phone": "+70419213962"}
0005432799452	443C07	0846 487011	VYACHESLAV ZAKHAROV	{"phone": "+70750961151"}
0005432799453	D5FD4C	4897 036632	OLGA SOKOLOVA	{"phone": "+70326977495"}
0005432799454	FBD60A	2611 035710	OKSANA EGOROVA	{"email": "oksana-egorova01081974@postgrespro.ru", "phone": "+70818634895"}
0005432799455	2EE56F	4150 217205	MATVEY KUZNECOV	{"email": "kuznecov_m.1971@postgrespro.ru", "phone": "+70095975553"}
0005432799456	ECBED5	0181 817607	IGOR MEDVEDEV	{"phone": "+70551443010"}
0005432799457	ECBED5	2651 173749	YURIY BONDARENKO	{"phone": "+70264393185"}
0005432799458	98CB41	0233 667125	GALINA DAVYDOVA	{"email": "davydova.galina.1964@postgrespro.ru", "phone": "+70536529323"}
0005432799459	17D60E	7655 405281	DARYA BORISOVA	{"email": "daryaborisova.22061969@postgrespro.ru", "phone": "+70568402350"}
0005432799460	2F8B17	6600 618082	LYUBOV EFREMOVA	{"phone": "+70598815928"}
0005432799461	8633F5	4403 081766	ELENA SIDOROVA	{"email": "sidorova.e_1969@postgrespro.ru", "phone": "+70691288055"}
0005432799462	1803E9	3194 673911	VASILIY KUZNECOV	{"phone": "+70565202203"}
0005432799463	C6E524	1039 757887	ALEKSANDR PETROV	{"email": "aleksandr_petrov.24061980@postgrespro.ru", "phone": "+70298062678"}
0005432799464	9A6065	9543 953077	NADEZHDA TIMOFEEVA	{"email": "timofeeva.nadezhda_08071970@postgrespro.ru", "phone": "+70239560984"}
0005432799465	673A65	3418 449677	LYUBOV BELOVA	{"phone": "+70346629140"}
0005432799466	63DF17	4416 599107	SERGEY SAVELEV	{"email": "ssavelev_101974@postgrespro.ru", "phone": "+70410877256"}
0005432799467	63DF17	2259 951258	NINA NIKITINA	{"phone": "+70490668747"}
0005432799468	71C206	8508 393189	ZOYA SMIRNOVA	{"email": "z.smirnova.071972@postgrespro.ru", "phone": "+70511482639"}
0005432799469	209C98	2575 773330	AYRAT PAVLOV	{"email": "pavlova.02051978@postgrespro.ru", "phone": "+70093278672"}
0005432799470	6B4200	7602 037548	SERGEY MIRONOV	{"phone": "+70016658565"}
0005432799471	CC73C1	8854 937953	TATYANA VOLKOVA	{"phone": "+70292180812"}
0005432799472	CC73C1	8068 163431	ALEKSANDR PAVLOV	{"phone": "+70392740971"}
0005432799473	4AFB60	7126 009050	IVAN MOISEEV	{"email": "moiseev_i-031967@postgrespro.ru", "phone": "+70244442243"}
0005432799474	B84606	9044 589970	VYACHESLAV MAKAROV	{"email": "vyacheslav_makarov-081973@postgrespro.ru", "phone": "+70019908573"}
0005432799475	021137	9632 076335	KIRILL TARASOV	{"phone": "+70445651275"}
0005432799476	B9827D	7790 907751	VERA KOZLOVA	{"email": "v.kozlova.11041975@postgrespro.ru", "phone": "+70003111120"}
0005432799477	A38E15	6821 705318	ANASTASIYA MATVEEVA	{"phone": "+70748298608"}
0005432799478	A38E15	8423 503520	VALENTINA SIDOROVA	{"phone": "+70718656461"}
0005432799479	D6892D	9662 115851	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova.081980@postgrespro.ru", "phone": "+70935347961"}
0005432799480	D6892D	4327 750858	LYUBOV BORISOVA	{"email": "borisova_lyubov.20091964@postgrespro.ru", "phone": "+70205831022"}
0005432799481	2CE953	8753 705152	DANILA FILIPPOV	{"phone": "+70730231252"}
0005432799482	EE5739	4475 836948	KIRILL GUSEV	{"phone": "+70663451401"}
0005432799483	EE5739	3825 385922	MARIYA KOZLOVA	{"email": "mariya_kozlova_091971@postgrespro.ru", "phone": "+70588788336"}
0005432799484	E32DA7	9783 730892	SVETLANA ZAKHAROVA	{"phone": "+70452804373"}
0005432799485	E32DA7	9066 610852	AYRAT ILIN	{"email": "ilin.a1973@postgrespro.ru", "phone": "+70823113976"}
0005432799486	4C5426	3588 097463	LIDIYA TIMOFEEVA	{"email": "timofeeva-lidiya25101974@postgrespro.ru", "phone": "+70728891236"}
0005432799487	4C5426	8388 691394	GALINA NAZAROVA	{"phone": "+70784392589"}
0005432799488	D39BD1	0760 283202	ZINAIDA ANDREEVA	{"email": "andreeva-z.18071972@postgrespro.ru", "phone": "+70132196363"}
0005432799489	D39BD1	1127 354229	ANNA AFANASEVA	{"phone": "+70910490858"}
0005432799490	36506C	6142 404893	PAVEL NAZAROV	{"email": "nazarov-p_1975@postgrespro.ru", "phone": "+70635895184"}
0005432799491	36506C	2748 779352	EKATERINA TIKHONOVA	{"email": "tikhonova.e1969@postgrespro.ru", "phone": "+70485071745"}
0005432799492	793CA1	3903 515020	MARIYA SEMENOVA	{"phone": "+70902256522"}
0005432799493	FAE35D	9414 577520	OLESYA FILATOVA	{"phone": "+70557586794"}
0005432799494	337B2C	5333 859677	DMITRIY VASILEV	{"email": "vasilev-dmitriy-021976@postgrespro.ru", "phone": "+70782244853"}
0005432799495	DCCBBB	7995 381227	NIKOLAY NAZAROV	{"email": "nazarov.n_071975@postgrespro.ru", "phone": "+70267612369"}
0005432799496	DCCBBB	2736 999181	IVAN ANTONOV	{"email": "i_antonov_041972@postgrespro.ru", "phone": "+70059485547"}
0005432799497	0FAC96	8027 006566	TATYANA GORBUNOVA	{"email": "gorbunova_tatyana051977@postgrespro.ru", "phone": "+70137509966"}
0005432799498	3BB9CF	1980 838852	MARIYA RODIONOVA	{"email": "rodionova-mariya1977@postgrespro.ru", "phone": "+70566484474"}
0005432799499	08AD9C	4971 826601	ILYA NIKOLAEV	{"email": "inikolaev-10061968@postgrespro.ru", "phone": "+70023288910"}
0005432799500	3C53F4	7071 108345	NIKOLAY SCHERBAKOV	{"email": "nikolay.scherbakov-17101968@postgrespro.ru", "phone": "+70912109750"}
0005432799501	7E0560	8137 168706	ARSENIY CHERNOV	{"phone": "+70670647544"}
0005432799502	BC5AFE	2648 584324	TAMARA NOVIKOVA	{"phone": "+70529468068"}
0005432799503	BCF049	1077 932998	EVGENIY STEPANOV	{"email": "stepanov_e.05051975@postgrespro.ru", "phone": "+70805134405"}
0005432799504	E2882A	9679 096376	ALEKSANDR VASILEV	{"email": "a.vasilev-011983@postgrespro.ru", "phone": "+70044084863"}
0005432799505	E2882A	3667 251914	NINA PAVLOVA	{"email": "nina_pavlova_1965@postgrespro.ru", "phone": "+70142661576"}
0005432799506	8AE3E2	7261 033605	TAMARA GAVRILOVA	{"email": "gavrilova-tamara-1960@postgrespro.ru", "phone": "+70063262053"}
0005432799507	FF4550	2905 020141	VLADIMIR FEDOTOV	{"phone": "+70658927563"}
0005432799508	F8413A	0189 542476	EVGENIY STEPANOV	{"email": "evgeniy_stepanov.03121965@postgrespro.ru", "phone": "+70321346268"}
0005432799509	F8413A	1062 535013	ANTONINA DENISOVA	{"phone": "+70734648386"}
0005432799510	35897E	5473 043125	ANASTASIYA MOISEEVA	{"phone": "+70259107757"}
0005432799511	43C0D5	5139 760133	GENNADIY POPOV	{"email": "gennadiy.popov_1974@postgrespro.ru", "phone": "+70015530183"}
0005432799512	58B3E5	8763 928131	VLADIMIR KUZMIN	{"phone": "+70828819216"}
0005432799513	716E1C	5855 264374	GALINA DANILOVA	{"phone": "+70678296571"}
0005432799514	716E1C	9673 314375	SAMIR SOLOVEV	{"email": "solovev_s-20011973@postgrespro.ru", "phone": "+70211609963"}
0005432799515	89C615	6484 109608	VYACHESLAV MELNIKOV	{"email": "vmelnikov-1974@postgrespro.ru", "phone": "+70893810433"}
0005432799516	6DB3F1	0172 692836	MAKSIM MOROZOV	{"phone": "+70113285221"}
0005432799517	ED1470	1406 169443	SVETLANA ZAKHAROVA	{"email": "s_zakharova.1963@postgrespro.ru", "phone": "+70702804871"}
0005432799518	ED1470	7548 044868	OLESYA ZHUKOVA	{"phone": "+70094364353"}
0005432799519	047D98	2762 724393	NINA PAVLOVA	{"phone": "+70564518812"}
0005432799520	047D98	3181 100203	ANDREY KOZLOV	{"phone": "+70418822706"}
0005432799521	D95ED8	3816 296639	TATYANA FOMINA	{"phone": "+70497178153"}
0005432799522	B290A2	7127 242126	ANATOLIY IVANOV	{"email": "a-ivanov1974@postgrespro.ru", "phone": "+70106681410"}
0005432799523	56A51F	4878 152974	ALENA SOLOVEVA	{"email": "solovevaalena_101974@postgrespro.ru", "phone": "+70098476915"}
0005432799524	AF0855	8066 072501	LYUBOV LUKYANOVA	{"phone": "+70354572793"}
0005432799525	AF0855	0836 760940	IRINA KUZNECOVA	{"email": "kuznecova.i-021979@postgrespro.ru", "phone": "+70624794923"}
0005432799526	F50C9B	5920 976369	SERGEY VASILEV	{"phone": "+70605219364"}
0005432799527	F50C9B	6183 394930	ANNA TIKHONOVA	{"phone": "+70031329017"}
0005432799528	1F98AE	6273 368330	GALINA VOLKOVA	{"email": "volkova-galina-011980@postgrespro.ru", "phone": "+70889694678"}
0005432799529	1393B9	2053 208204	SERGEY MAKAROV	{"phone": "+70875912701"}
0005432799530	89660E	6515 298718	LARISA FEDOROVA	{"phone": "+70047914390"}
0005432799531	FE3648	2143 610787	ROZA SIDOROVA	{"email": "rozasidorova071977@postgrespro.ru", "phone": "+70186864467"}
0005432799532	FE3648	7616 579515	ILGIZ VOLKOV	{"phone": "+70786481137"}
0005432799533	01AF94	6050 468483	ARTEM ANTONOV	{"phone": "+70788051470"}
0005432799534	8ECBB5	1664 988211	ANASTASIYA EGOROVA	{"email": "anastasiya-egorova-05031981@postgrespro.ru", "phone": "+70049589882"}
0005432799535	8ECBB5	4182 342673	ALEKSEY ISAEV	{"email": "isaev.aleksey.051967@postgrespro.ru", "phone": "+70924156645"}
0005432799536	902F6C	3084 260387	ANASTASIYA SAVELEVA	{"email": "a.saveleva-04061971@postgrespro.ru", "phone": "+70094654779"}
0005432799537	A1A532	2711 931327	OKSANA PAVLOVA	{"phone": "+70511665467"}
0005432799538	458FE6	3498 879257	ALINA KULIKOVA	{"email": "alina.kulikova_1978@postgrespro.ru", "phone": "+70622440687"}
0005432799539	764D41	9904 698028	MARIYA EGOROVA	{"phone": "+70359096358"}
0005432799540	9CF95E	2971 283612	VALERIYA LUKYANOVA	{"email": "lukyanovavaleriya_21011979@postgrespro.ru", "phone": "+70825859621"}
0005432799541	9CF95E	7966 110405	VLADIMIR NIKOLAEV	{"email": "v.nikolaev12071976@postgrespro.ru", "phone": "+70993390491"}
0005432799542	654440	1594 813737	VERA CHERNOVA	{"email": "v_chernova.1970@postgrespro.ru", "phone": "+70511236341"}
0005432799543	654440	5695 844815	OLGA ZHURAVLEVA	{"email": "olga.zhuravleva_011976@postgrespro.ru", "phone": "+70048414664"}
0005432799544	7C48FD	7172 264519	ALEKSANDR MIKHAYLOV	{"phone": "+70104704347"}
0005432799545	7C48FD	4641 642205	MIKHAIL IVANOV	{"email": "ivanov_mikhail.1965@postgrespro.ru", "phone": "+70345306119"}
0005432799546	DF2AD5	3665 606974	MARIYA MALYSHEVA	{"email": "malyshevam.23051982@postgrespro.ru", "phone": "+70071718150"}
0005432799547	DF2AD5	6605 150304	OLESYA TITOVA	{"phone": "+70765762121"}
0005432799548	57C9B7	1410 357710	SERGEY NOVIKOV	{"email": "sergey_novikov-071972@postgrespro.ru", "phone": "+70288861685"}
0005432799549	345EC1	5877 401438	DARYA POPOVA	{"phone": "+70163786955"}
0005432799550	345EC1	6938 872926	ALEKSANDRA GAVRILOVA	{"phone": "+70336176225"}
0005432799551	357A27	2427 919883	YULIYA YAKOVLEVA	{"phone": "+70356966541"}
0005432799552	7669C8	8539 326989	INNA ILINA	{"phone": "+70836724304"}
0005432799553	E07315	2805 765436	ANTON SOLOVEV	{"phone": "+70606666017"}
0005432799554	2E9459	4537 528254	LYUBOV NAZAROVA	{"email": "lyubovnazarova-07041977@postgrespro.ru", "phone": "+70324961487"}
0005432799555	FCCC0E	4167 274753	SVETLANA OVCHINNIKOVA	{"email": "s_ovchinnikova.1956@postgrespro.ru", "phone": "+70542468095"}
0005432799556	9DAB04	2565 909106	EVGENIY SEMENOV	{"email": "esemenov.081970@postgrespro.ru", "phone": "+70458685512"}
0005432799557	9DAB04	0444 385574	MAKSIM EGOROV	{"email": "egorov_m_1963@postgrespro.ru", "phone": "+70968968287"}
0005432799558	E58622	0724 991395	DMITRIY GERASIMOV	{"email": "d_gerasimov-081973@postgrespro.ru", "phone": "+70730800345"}
0005432799559	F8113E	3072 525152	VALERIY OSIPOV	{"email": "v_osipov.031983@postgrespro.ru", "phone": "+70483522871"}
0005432799560	F8113E	9304 449261	KLAVDIYA PAVLOVA	{"email": "klavdiya.pavlova02091972@postgrespro.ru", "phone": "+70378625448"}
0005432799561	F8113E	0434 521662	OKSANA YAKOVLEVA	{"email": "yakovleva_o-1965@postgrespro.ru", "phone": "+70785448085"}
0005432799562	040E23	4796 449938	OKSANA MELNIKOVA	{"phone": "+70530968959"}
0005432799563	040E23	3033 829775	DARYA YAKOVLEVA	{"email": "d-yakovleva-22081974@postgrespro.ru", "phone": "+70287752931"}
0005432799564	03BB5B	8007 376029	VERONIKA SIDOROVA	{"email": "sidorovav-1973@postgrespro.ru", "phone": "+70811614689"}
0005432799565	03BB5B	0139 806550	IVAN VOROBEV	{"email": "i_vorobev061972@postgrespro.ru", "phone": "+70506955954"}
0005432799566	99C176	2889 092073	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva041968@postgrespro.ru", "phone": "+70297880536"}
0005432799567	A16120	8189 840430	MARIYA IVANOVA	{"phone": "+70201194353"}
0005432799568	A16120	4214 044231	LYUDMILA KOVALEVA	{"phone": "+70256687713"}
0005432799569	A16120	1434 552066	VIKTOR GRIGOREV	{"phone": "+70062552762"}
0005432799570	2EAB8B	4942 662292	TATYANA SERGEEVA	{"email": "tatyana.sergeeva-26091969@postgrespro.ru", "phone": "+70167663958"}
0005432799571	2EAB8B	4592 683152	NADEZHDA KUZNECOVA	{"email": "kuznecovan-22021968@postgrespro.ru", "phone": "+70453668587"}
0005432799572	289834	3786 462267	EKATERINA ALEKSEEVA	{"phone": "+70966423247"}
0005432799573	F9B93A	8165 700304	NADEZHDA KONOVALOVA	{"phone": "+70459084455"}
0005432799574	08599D	6651 116827	VITALIY VASILEV	{"email": "vasilev.v1985@postgrespro.ru", "phone": "+70139463484"}
0005432799575	08599D	6320 226729	VYACHESLAV GUSEV	{"email": "v_gusev_061978@postgrespro.ru", "phone": "+70979434916"}
0005432799576	92DB58	5796 423252	VALERIY BELOV	{"email": "belov_valeriy.031973@postgrespro.ru", "phone": "+70770396925"}
0005432799577	E1EC8E	0325 295831	VIKTOR PAVLOV	{"email": "pavlov.viktor_23071966@postgrespro.ru", "phone": "+70911502465"}
0005432799578	E1EC8E	0435 584859	ANATOLIY KUDRYASHOV	{"email": "anatoliykudryashov.011981@postgrespro.ru", "phone": "+70001748203"}
0005432799579	1B8202	9482 542542	ALEKSANDR EGOROV	{"phone": "+70508838558"}
0005432799580	411FC9	0593 982006	TATYANA SERGEEVA	{"phone": "+70975219495"}
0005432799581	411FC9	6836 701048	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova-14121969@postgrespro.ru", "phone": "+70821681469"}
0005432799582	D4BEC4	9484 555915	ALEKSEY IVANOV	{"email": "aivanov.1967@postgrespro.ru", "phone": "+70890618290"}
0005432799583	1DB2B7	6376 018501	ALEKSEY KUZNECOV	{"phone": "+70843744367"}
0005432799584	1DB2B7	3829 623180	TATYANA NESTEROVA	{"email": "nesterova.tatyana.1965@postgrespro.ru", "phone": "+70804156297"}
0005432799585	1D22F3	8779 223557	DENIS SEMENOV	{"phone": "+70542999964"}
0005432799586	1D22F3	4530 429853	SVETLANA MIRONOVA	{"email": "s.mironova1973@postgrespro.ru", "phone": "+70248023256"}
0005432799587	1D22F3	6707 004012	OLGA KAZAKOVA	{"email": "olga-kazakova.11021976@postgrespro.ru", "phone": "+70235248860"}
0005432799588	9BF4B9	1349 443414	GALINA BORISOVA	{"phone": "+70830968426"}
0005432799589	1841AE	8130 790822	ALENA ZAYCEVA	{"email": "a.zayceva.1968@postgrespro.ru", "phone": "+70265690573"}
0005432799590	4D8FCD	1879 672272	VIKTOR ALEKSEEV	{"email": "viktoralekseev-14111965@postgrespro.ru", "phone": "+70965288192"}
0005432799591	C9F489	9329 257854	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr.011968@postgrespro.ru", "phone": "+70441815493"}
0005432799592	C9F489	1863 935786	MARIYA PETROVA	{"email": "m_petrova.1982@postgrespro.ru", "phone": "+70129444330"}
0005432799593	A10095	1196 335859	MARINA KUZNECOVA	{"phone": "+70263006166"}
0005432799594	6A3138	9926 053519	ELVIRA MEDVEDEVA	{"phone": "+70591133821"}
0005432799595	6A3138	8086 621177	GRIGORIY BONDARENKO	{"email": "bondarenko.grigoriy.1964@postgrespro.ru", "phone": "+70395172069"}
0005432799596	6A3138	0766 635387	DARYA IVANOVA	{"phone": "+70527505030"}
0005432799597	1B8529	4682 260723	MAKSIM GORBUNOV	{"email": "gorbunov-maksim.17031960@postgrespro.ru", "phone": "+70612425630"}
0005432799598	7E6D24	7626 532723	EVGENIYA KOVALEVA	{"phone": "+70133160545"}
0005432799599	13311B	9280 045860	NATALYA ROMANOVA	{"email": "nromanova.20021972@postgrespro.ru", "phone": "+70121618477"}
0005432799600	0862AE	4248 888738	ALEKSANDR BORISOV	{"phone": "+70849235673"}
0005432799601	B9A648	6174 305331	LIDIYA SIDOROVA	{"email": "lidiya-sidorova_1977@postgrespro.ru", "phone": "+70990486982"}
0005432799602	531233	4057 642657	TAMARA KUDRYASHOVA	{"email": "tamara-kudryashova-1970@postgrespro.ru", "phone": "+70063555731"}
0005432799603	396D1B	4180 579857	VALENTINA KISELEVA	{"phone": "+70967265177"}
0005432799604	BDF368	0961 725665	TATYANA NIKOLAEVA	{"phone": "+70580745318"}
0005432799605	F736B9	6941 654766	ALEKSEY GERASIMOV	{"phone": "+70279188280"}
0005432799606	76BD85	6020 719527	RUSLAN FEDOTOV	{"phone": "+70685318254"}
0005432799607	76BD85	1892 007034	GALINA POTAPOVA	{"email": "galina.potapova-1974@postgrespro.ru", "phone": "+70912163912"}
0005432799608	91D535	1015 288326	TATYANA LOGINOVA	{"email": "t_loginova.051972@postgrespro.ru", "phone": "+70327123156"}
0005432799609	91D535	0649 179424	DENIS VASILEV	{"phone": "+70991678041"}
0005432799610	1419DB	3223 050398	SERGEY KAZAKOV	{"email": "s.kazakov.1963@postgrespro.ru", "phone": "+70009170911"}
0005432799611	5A4CBD	0697 806010	ANTONINA EFIMOVA	{"email": "a_efimova.1967@postgrespro.ru", "phone": "+70630706941"}
0005432799612	78413D	4386 591786	MARIYA VOROBEVA	{"phone": "+70349000425"}
0005432799613	76B0F2	8370 395379	SERGEY FROLOV	{"email": "s-frolov_081966@postgrespro.ru", "phone": "+70018679962"}
0005432799614	76B0F2	2004 804686	ARTEM SEMENOV	{"email": "artem-semenov_091984@postgrespro.ru", "phone": "+70211400994"}
0005432799615	CFB39B	5377 973506	NATALYA GERASIMOVA	{"email": "gerasimova-n-1979@postgrespro.ru", "phone": "+70150728668"}
0005432799616	1AF70C	6582 220453	LYUDMILA VASILEVA	{"email": "l.vasileva_101971@postgrespro.ru", "phone": "+70296294571"}
0005432799617	1AF70C	3060 337246	TATYANA ZHURAVLEVA	{"email": "t-zhuravleva-15021979@postgrespro.ru", "phone": "+70791307145"}
0005432799618	50EB67	7850 090933	VYACHESLAV SERGEEV	{"phone": "+70599657243"}
0005432799619	50EB67	1170 812620	VALENTINA LUKYANOVA	{"phone": "+70572464018"}
0005432799620	50EB67	6511 336382	DENIS MAKAROV	{"phone": "+70920255867"}
0005432799621	3E7B68	9800 020645	YURIY PETROV	{"phone": "+70732739537"}
0005432799622	01AA0F	5353 882828	ANDREY VOLKOV	{"phone": "+70837118723"}
0005432799623	C9DDBB	5434 827564	MARIYA YAKOVLEVA	{"email": "mariya_yakovleva_1974@postgrespro.ru", "phone": "+70175201146"}
0005432799624	BCA967	0738 408755	MAKSIM CHERNOV	{"email": "m_chernov021976@postgrespro.ru", "phone": "+70689467680"}
0005432799625	BCA967	0611 565480	NINA ZHURAVLEVA	{"phone": "+70709938187"}
0005432799626	1CD1C2	9248 266608	VYACHESLAV SERGEEV	{"phone": "+70788510732"}
0005432799627	1CD1C2	8717 488042	NIKOLAY ZHURAVLEV	{"email": "nikolay-zhuravlev_26011971@postgrespro.ru", "phone": "+70883218855"}
0005432799628	6C2FF6	0904 435103	ALEKSEY SOLOVEV	{"phone": "+70674879845"}
0005432799629	8585AA	8297 130360	ANDREY SOKOLOV	{"email": "asokolov.061969@postgrespro.ru", "phone": "+70184556906"}
0005432799630	8585AA	7924 179214	ANDREY ORLOV	{"phone": "+70145225467"}
0005432799631	5E15FE	5128 340840	FEDOR KUZNECOV	{"email": "kuznecov_fedor011967@postgrespro.ru", "phone": "+70857240867"}
0005432799632	D3208B	4750 951638	IGOR SMIRNOV	{"email": "smirnov_i_1964@postgrespro.ru", "phone": "+70778466009"}
0005432799633	4D44C8	1591 563059	GALINA KALININA	{"phone": "+70507111853"}
0005432799634	EF3347	2076 698099	OLGA MAKAROVA	{"phone": "+70014539720"}
0005432799635	213C1E	2855 317199	ANATOLIY SEMENOV	{"email": "anatoliy-semenov_10031969@postgrespro.ru", "phone": "+70765495401"}
0005432799636	910C15	2768 863180	VLADIMIR NAZAROV	{"phone": "+70972026448"}
0005432799637	7DCE94	2197 018059	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev-1971@postgrespro.ru", "phone": "+70081352724"}
0005432799638	7DCE94	9368 013079	KONSTANTIN MIKHAYLOV	{"email": "kmikhaylov27031968@postgrespro.ru", "phone": "+70166962476"}
0005432799639	0F6DEF	4898 271421	SERGEY KAZAKOV	{"phone": "+70059017911"}
0005432799640	C58A3F	5463 539933	VLADIMIR OSIPOV	{"email": "vosipov28011976@postgrespro.ru", "phone": "+70946731550"}
0005432799641	11F7E6	1043 284728	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov_11081963@postgrespro.ru", "phone": "+70936256274"}
0005432799642	B5D0BF	7804 819780	GENNADIY KUZNECOV	{"phone": "+70106885500"}
0005432799643	B5D0BF	6118 302748	LIDIYA TARASOVA	{"phone": "+70019481126"}
0005432799644	B5D0BF	7839 507743	EVGENIY PETROV	{"phone": "+70771686720"}
0005432799645	80F57A	0798 391771	ALEKSANDR DMITRIEV	{"phone": "+70610582772"}
0005432799646	80F57A	2859 213049	VALENTINA FOMINA	{"email": "vfomina22121969@postgrespro.ru", "phone": "+70607406521"}
0005432799647	E9020D	0570 831525	ELENA GORBUNOVA	{"phone": "+70817706481"}
0005432799648	4A7859	3665 509562	ANNA FILIPPOVA	{"email": "filippova-anna-30091974@postgrespro.ru", "phone": "+70675637145"}
0005432799649	3F0F54	1808 797658	OLEG VASILEV	{"email": "o-vasilev_10051967@postgrespro.ru", "phone": "+70371746159"}
0005432799650	CA1AEA	5238 436474	ANTON IVANOV	{"phone": "+70068462107"}
0005432799651	A6BC95	2916 228433	ELENA KULIKOVA	{"email": "kulikova-elena27051974@postgrespro.ru", "phone": "+70663519839"}
0005432799652	165050	0139 073304	NATALYA CHERNOVA	{"phone": "+70454741243"}
0005432799653	85FF47	8681 084037	EKATERINA ZAYCEVA	{"email": "zaycevae_15021976@postgrespro.ru", "phone": "+70847061373"}
0005432799654	DC20BC	9191 994965	VIKTOR KUDRYASHOV	{"phone": "+70984410513"}
0005432799655	8C1E20	6700 816920	VIKTOR ZAYCEV	{"phone": "+70324814667"}
0005432799656	02F758	9545 477980	PAVEL TARASOV	{"phone": "+70492290364"}
0005432799657	02F758	0372 030085	IRINA LOGINOVA	{"email": "loginova.irina.101966@postgrespro.ru", "phone": "+70815730085"}
0005432799658	75D6D4	0555 268488	ARKADIY KUZNECOV	{"phone": "+70527201337"}
0005432799659	75D6D4	7029 346322	YANA YUDINA	{"phone": "+70304755483"}
0005432799660	21497A	8919 086078	MARINA VASILEVA	{"email": "vasileva.m_26071974@postgrespro.ru", "phone": "+70039161374"}
0005432799661	7530DC	5330 171197	VALENTINA MASLOVA	{"phone": "+70460547029"}
0005432799662	7530DC	7056 550791	PETR EGOROV	{"phone": "+70651883359"}
0005432799663	6C5459	2202 437873	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova.1968@postgrespro.ru", "phone": "+70694091752"}
0005432799664	6C5459	7446 935823	ALEKSEY MAKSIMOV	{"email": "maksimov.aleksey.28071985@postgrespro.ru", "phone": "+70155110601"}
0005432799665	5C4F48	0090 143789	LYUBOV SOKOLOVA	{"phone": "+70920422571"}
0005432799666	5C4F48	1670 870792	OKSANA LOGINOVA	{"phone": "+70123927902"}
0005432799667	5C4F48	5525 096477	NIKITA KUZNECOV	{"email": "kuznecovnikita_081970@postgrespro.ru", "phone": "+70247433088"}
0005432799668	85A8CE	8951 464727	TAISIYA SERGEEVA	{"email": "sergeeva.taisiya_081977@postgrespro.ru", "phone": "+70425118959"}
0005432799669	DAF358	3004 031860	EKATERINA BARANOVA	{"email": "baranova-ekaterina_03051983@postgrespro.ru", "phone": "+70040357428"}
0005432799670	CB0FB1	2891 490387	NIKOLAY KOZLOV	{"email": "kozlov.nikolay-1972@postgrespro.ru", "phone": "+70590704640"}
0005432799671	00BF0F	4690 604306	LYUDMILA KRASNOVA	{"phone": "+70306174220"}
0005432799672	6BAC16	8975 953277	ALEKSANDR GERASIMOV	{"email": "gerasimov.a1965@postgrespro.ru", "phone": "+70015158575"}
0005432799673	0A9356	2605 061534	ALEKSANDR KRASNOV	{"phone": "+70961981945"}
0005432799674	00C64D	0931 614672	ZINAIDA IVANOVA	{"email": "ivanova_zinaida03091964@postgrespro.ru", "phone": "+70033658640"}
0005432799675	50425B	7221 985266	EVGENIYA ZAKHAROVA	{"phone": "+70169555077"}
0005432799676	CCD3B1	7923 736984	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaa.1974@postgrespro.ru", "phone": "+70438880676"}
0005432799677	1C1120	5729 398684	ANATOLIY SMIRNOV	{"email": "smirnov_a_051963@postgrespro.ru", "phone": "+70363786537"}
0005432799678	0363D1	9183 137169	RUSTAM TIMOFEEV	{"email": "timofeev-r1961@postgrespro.ru", "phone": "+70344882611"}
0005432799679	368915	5274 243659	DMITRIY MEDVEDEV	{"email": "medvedev-dmitriy_1969@postgrespro.ru", "phone": "+70679776355"}
0005432799680	368915	4350 127976	MARIYA KUZNECOVA	{"email": "kuznecova.m.07091968@postgrespro.ru", "phone": "+70209206474"}
0005432799681	E60214	3770 523532	YAKOV DMITRIEV	{"email": "yakov_dmitriev-051969@postgrespro.ru", "phone": "+70997001104"}
0005432799682	18550D	7881 122793	ANASTASIYA SERGEEVA	{"email": "anastasiyasergeeva.1971@postgrespro.ru", "phone": "+70068410344"}
0005432799683	28CCF3	8088 616843	VIKTOR GORBUNOV	{"email": "v_gorbunov.011975@postgrespro.ru", "phone": "+70678860777"}
0005432799684	6083C1	4553 636177	ELIZAVETA ALEKSEEVA	{"email": "elizaveta-alekseeva.1970@postgrespro.ru", "phone": "+70842386667"}
0005432799685	FF48FA	7833 811525	ROMAN POPOV	{"email": "popov_r_25051965@postgrespro.ru", "phone": "+70008536148"}
0005432799686	FF48FA	3253 024455	SERGEY BARANOV	{"email": "s-baranov1964@postgrespro.ru", "phone": "+70567093102"}
0005432799687	CF1F41	1925 328530	YURIY FILIPPOV	{"email": "y_filippov.1963@postgrespro.ru", "phone": "+70544798474"}
0005432799688	93123F	8434 960026	ALEKSANDR VLASOV	{"email": "a_vlasov011974@postgrespro.ru", "phone": "+70635584332"}
0005432799689	8FDE0F	2374 287537	YURIY SEMENOV	{"email": "semenov_y_1957@postgrespro.ru", "phone": "+70090170183"}
0005432799690	35BA1C	3996 800221	PAVEL VASILEV	{"email": "vasilev-pavel091973@postgrespro.ru", "phone": "+70959143667"}
0005432799691	3298CC	2575 204883	EVGENIY IVANOV	{"phone": "+70857852315"}
0005432799692	401D61	3131 824282	VALENTINA KALININA	{"phone": "+70985805743"}
0005432799693	B9415F	7530 836478	ZOYA MOISEEVA	{"email": "moiseeva.z_031974@postgrespro.ru", "phone": "+70326232008"}
0005432799694	168C79	3318 404962	SERGEY TIMOFEEV	{"email": "timofeev.sergey_061979@postgrespro.ru", "phone": "+70270526406"}
0005432799695	A8D43F	0559 990441	ANATOLIY YAKOVLEV	{"email": "anatoliy-yakovlev-1971@postgrespro.ru", "phone": "+70375193741"}
0005432799696	A8D43F	2567 676416	IRINA VASILEVA	{"email": "vasilevai_101983@postgrespro.ru", "phone": "+70280377979"}
0005432799697	7FCDAE	4631 948981	ALEKSANDRA KUZNECOVA	{"phone": "+70896349313"}
0005432799698	9EA43E	8331 099747	ALEKSANDRA KISELEVA	{"phone": "+70625996380"}
0005432799699	1D2FED	6663 648589	TATYANA ARKHIPOVA	{"phone": "+70024277797"}
0005432799700	1D2FED	1754 288161	NURLAN ALEKSEEV	{"phone": "+70828941489"}
0005432799701	277363	0952 225066	SAMIRA ANTONOVA	{"email": "antonovas.1980@postgrespro.ru", "phone": "+70396287596"}
0005432799702	277363	6310 527713	OLGA KOROLEVA	{"phone": "+70643787033"}
0005432799703	277363	8774 139571	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov_06121964@postgrespro.ru", "phone": "+70111480148"}
0005432799704	F3DBB0	2165 882615	DMITRIY SIDOROV	{"email": "dmitriy.sidorov-1984@postgrespro.ru", "phone": "+70567976030"}
0005432799705	F3DBB0	8665 927892	IRINA KUZMINA	{"email": "kuzmina-irina_22051959@postgrespro.ru", "phone": "+70057885229"}
0005432799706	F3DBB0	3513 367116	EGOR MELNIKOV	{"email": "egor-melnikov-27021970@postgrespro.ru", "phone": "+70723347521"}
0005432799707	16850D	0782 626324	OKSANA MASLOVA	{"phone": "+70321703315"}
0005432799708	80D9E9	1189 214327	ROMAN KUDRYASHOV	{"email": "roman-kudryashov_1979@postgrespro.ru", "phone": "+70741155999"}
0005432799709	80D9E9	1283 128170	YULIYA KUZNECOVA	{"phone": "+70738316429"}
0005432799710	10809F	3285 476313	ELENA LUKYANOVA	{"email": "elena.lukyanova.31101961@postgrespro.ru", "phone": "+70477200711"}
0005432799711	13D146	4723 801659	SVETLANA AKIMOVA	{"email": "akimova.svetlana-11021978@postgrespro.ru", "phone": "+70860756469"}
0005432799712	16E1E3	2162 856523	NINA ANTONOVA	{"phone": "+70529433890"}
0005432799713	16E1E3	0872 470176	LYUBOV SOROKINA	{"phone": "+70066074959"}
0005432799714	16E1E3	0684 116009	IRINA KUDRYASHOVA	{"email": "ikudryashova-24021968@postgrespro.ru", "phone": "+70189579765"}
0005432799715	666828	2562 350016	NIKOLAY KUZNECOV	{"phone": "+70333521322"}
0005432799716	666828	2209 995961	ELENA MAKAROVA	{"phone": "+70621137311"}
0005432799717	FE3BB1	7974 019422	IVAN MAKSIMOV	{"phone": "+70066143128"}
0005432799718	063880	4958 496116	SVETLANA LUKYANOVA	{"phone": "+70230197854"}
0005432799719	630C0D	3866 888956	EVGENIY GUSEV	{"phone": "+70661521606"}
0005432799720	10A06B	2904 416459	ELENA NIKITINA	{"phone": "+70619416471"}
0005432799721	6A4980	8904 074126	VALENTINA VASILEVA	{"phone": "+70570000527"}
0005432799722	6A4980	9673 496605	GLEB PAVLOV	{"email": "gleb_pavlov_27051973@postgrespro.ru", "phone": "+70107120490"}
0005432799723	733127	6623 868349	NATALYA OSIPOVA	{"phone": "+70432916501"}
0005432799724	81FDBB	8046 385055	NADEZHDA YAKOVLEVA	{"email": "yakovlevan.051981@postgrespro.ru", "phone": "+70546836714"}
0005432799725	274438	2038 646461	ALEKSANDR SHEVCHENKO	{"phone": "+70174155628"}
0005432799726	274438	3952 626726	OLEG KUZNECOV	{"phone": "+70578757274"}
0005432799727	FBAA0C	0548 150322	ALEKSEY SERGEEV	{"email": "a_sergeev_011964@postgrespro.ru", "phone": "+70713405825"}
0005432799728	324DDE	4529 176372	ANNA EGOROVA	{"phone": "+70879333670"}
0005432799729	7806F9	0200 838481	ROMAN MAKAROV	{"phone": "+70912422545"}
0005432799730	2E3416	2221 349701	PAVEL VOROBEV	{"email": "vorobev-p_06021972@postgrespro.ru", "phone": "+70847891563"}
0005432799731	2E3416	0951 830058	ALFIYA KUZNECOVA	{"email": "alfiya.kuznecova.091973@postgrespro.ru", "phone": "+70266753884"}
0005432799732	335DE5	5616 795087	VERA LEBEDEVA	{"phone": "+70275141287"}
0005432799733	335DE5	2063 972846	TATYANA GRISHINA	{"phone": "+70033888959"}
0005432799734	4B2BF7	0178 798795	VALENTINA KALININA	{"email": "kalinina.v031967@postgrespro.ru", "phone": "+70218496338"}
0005432799735	4B2BF7	3391 325608	ANATOLIY KOZLOV	{"phone": "+70048894513"}
0005432799736	5A9D02	4033 384481	SVETLANA ABRAMOVA	{"email": "abramova-svetlana-1959@postgrespro.ru", "phone": "+70905858216"}
0005432799737	5A9D02	3512 042398	IRAIDA KISELEVA	{"phone": "+70388651959"}
0005432799738	38F4B4	7787 267426	NINA KAZAKOVA	{"phone": "+70019636379"}
0005432799739	8BF3CF	1615 763937	ANNA SIDOROVA	{"phone": "+70589537630"}
0005432799740	3D3166	0908 798190	NATALYA KARPOVA	{"email": "natalya-karpova081963@postgrespro.ru", "phone": "+70442036505"}
0005432799741	3D3166	9390 275659	ANNA ANDREEVA	{"email": "a_andreeva_1963@postgrespro.ru", "phone": "+70026458895"}
0005432799742	940A6A	2405 127386	DMITRIY SOLOVEV	{"email": "solovevd.04111979@postgrespro.ru", "phone": "+70030481687"}
0005432799743	940A6A	7539 163725	ANNA ZOTOVA	{"phone": "+70225383663"}
0005432799744	ACC30B	1607 577520	VERA MELNIKOVA	{"email": "melnikova-vera_1968@postgrespro.ru", "phone": "+70541080321"}
0005432799745	F337C3	5046 812398	SVETLANA IVANOVA	{"email": "ivanova-s.121970@postgrespro.ru", "phone": "+70701623387"}
0005432799746	F337C3	9358 238405	EVGENIY ZAKHAROV	{"email": "evgeniy_zakharov041973@postgrespro.ru", "phone": "+70070696386"}
0005432799747	E42507	9624 822155	ELENA SEMENOVA	{"email": "e_semenova-08011965@postgrespro.ru", "phone": "+70316024639"}
0005432799748	152FEC	7098 016689	TATYANA MIKHAYLOVA	{"phone": "+70080605865"}
0005432799749	1F9BC4	5458 577966	SERGEY NAZAROV	{"email": "nazarov_sergey_1970@postgrespro.ru", "phone": "+70245922905"}
0005432799750	1F9BC4	6694 558035	YURIY NOVIKOV	{"email": "yuriy_novikov-22061974@postgrespro.ru", "phone": "+70309536996"}
0005432799751	B3D3D2	7910 748090	DAMIR SAVELEV	{"phone": "+70202914077"}
0005432799752	4B2D1A	0606 065215	VALERIY OSIPOV	{"phone": "+70488820141"}
0005432799753	AC58AE	5671 258435	VERA POPOVA	{"email": "v_popova.26061975@postgrespro.ru", "phone": "+70265980390"}
0005432799754	E97002	0197 522748	ALEKSANDR KUZNECOV	{"phone": "+70752653490"}
0005432799755	904A49	4406 217171	YURIY KARPOV	{"phone": "+70891020962"}
0005432799756	E5017A	2914 600102	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.12071978@postgrespro.ru", "phone": "+70601588628"}
0005432799757	E5017A	1628 133402	IRINA NIKITINA	{"email": "nikitina-i.15101968@postgrespro.ru", "phone": "+70062034843"}
0005432799758	98B7CE	4857 419884	VLADISLAV MOROZOV	{"phone": "+70644841333"}
0005432799759	C1CD91	2751 443404	IRINA LUKYANOVA	{"email": "lukyanova_irina.071977@postgrespro.ru", "phone": "+70348214892"}
0005432799760	70EF3E	1291 365992	ALEKSANDR CHERNOV	{"phone": "+70886051814"}
0005432799761	70EF3E	7251 332124	FLYURA MALYSHEVA	{"email": "f-malysheva_15101972@postgrespro.ru", "phone": "+70191549430"}
0005432799762	69C1E6	3967 629651	DARYA ANDREEVA	{"email": "andreevadarya29111969@postgrespro.ru", "phone": "+70923272895"}
0005432799763	FCA9F9	7270 756741	RADIK ROMANOV	{"phone": "+70032221605"}
0005432799764	841705	3113 866585	ELIZAVETA KUZNECOVA	{"email": "kuznecova-e061981@postgrespro.ru", "phone": "+70618773641"}
0005432799765	BCAC4B	4600 497003	NATALYA GORBUNOVA	{"phone": "+70927704717"}
0005432799766	294189	6284 798612	ARTEM BELOV	{"phone": "+70863979831"}
0005432799767	294189	6512 085546	DMITRIY FOMIN	{"email": "d.fomin1968@postgrespro.ru", "phone": "+70660889675"}
0005432799768	806345	8123 481313	ARSEN KUZNECOV	{"phone": "+70084663777"}
0005432799769	806345	0489 323290	ALEKSEY DAVYDOV	{"phone": "+70239032125"}
0005432799770	806345	0724 216627	KONSTANTIN MIRONOV	{"phone": "+70929666441"}
0005432799771	806345	4849 709692	DANILA MARTYNOV	{"phone": "+70891673623"}
0005432799772	C3A637	9448 574561	KSENIYA LOGINOVA	{"email": "loginovakseniya.07041983@postgrespro.ru", "phone": "+70524146506"}
0005432799773	C3A637	2038 326644	VASILIY SAVELEV	{"phone": "+70375068130"}
0005432799774	CC6224	2543 552787	ALEKSEY KUZNECOV	{"phone": "+70402870765"}
0005432799775	B83794	3620 449354	ARTEM STEPANOV	{"email": "artemstepanov14021976@postgrespro.ru", "phone": "+70617400501"}
0005432799776	E7008A	9725 772035	KSENIYA SMIRNOVA	{"phone": "+70014031773"}
0005432799777	E7008A	6972 463112	SERGEY BELOV	{"email": "sergey.belov-12061958@postgrespro.ru", "phone": "+70817470516"}
0005432799778	E457E7	1706 257058	YULIYA IVANOVA	{"phone": "+70508020771"}
0005432799779	FDC7E7	2964 498565	ALEKSEY VLASOV	{"phone": "+70760819834"}
0005432799780	3C12A3	1219 641004	SEMEN PETROV	{"email": "semen.petrov_28031969@postgrespro.ru", "phone": "+70598774813"}
0005432799781	3C12A3	5538 858629	MARINA VASILEVA	{"phone": "+70729254231"}
0005432799782	3667B9	3584 271350	MARIYA PETROVA	{"email": "petrova_mariya_1966@postgrespro.ru", "phone": "+70492768333"}
0005432799783	75B87E	9234 966002	TAMARA NOVIKOVA	{"email": "novikova_tamara1969@postgrespro.ru", "phone": "+70477968775"}
0005432799784	75B87E	8421 969084	ALEKSANDR SERGEEV	{"phone": "+70614424573"}
0005432799785	CA65D6	0861 328250	ANATOLIY ROMANOV	{"email": "aromanov.1965@postgrespro.ru", "phone": "+70099512777"}
0005432799786	A2C0FC	7595 705746	ANTONINA VOLKOVA	{"phone": "+70009696643"}
0005432799787	A2C0FC	5006 650943	ZINAIDA VLASOVA	{"email": "vlasova.zinaida28011973@postgrespro.ru", "phone": "+70063471803"}
0005432799788	A2C0FC	9518 094783	ALEKSANDR SIDOROV	{"phone": "+70631017849"}
0005432799789	46BC93	1201 556662	EKATERINA SEMENOVA	{"email": "semenova-e.1973@postgrespro.ru", "phone": "+70208133915"}
0005432799790	CE1A3B	0440 961116	VALENTINA GRISHINA	{"email": "v_grishina.04011985@postgrespro.ru", "phone": "+70086847763"}
0005432799791	CE1A3B	5481 716791	OLEG ANDREEV	{"phone": "+70595405886"}
0005432799792	C1C257	0187 017994	SERGEY TIMOFEEV	{"phone": "+70999266187"}
0005432799793	C1C257	6684 734933	ANTONINA MALYSHEVA	{"email": "malysheva.antonina-051962@postgrespro.ru", "phone": "+70007885087"}
0005432799794	2700C6	5919 484407	SERGEY MELNIKOV	{"phone": "+70763636910"}
0005432799795	7C3FC6	6089 213140	GALINA ANTONOVA	{"phone": "+70838182696"}
0005432799796	7C3FC6	7373 687808	OLEG KUZNECOV	{"email": "kuznecov-oleg.10091973@postgrespro.ru", "phone": "+70137092565"}
0005432799797	D44C33	9397 756814	ANATOLIY MAKSIMOV	{"phone": "+70255400840"}
0005432799798	F711B4	3892 760730	VLADIMIR SOLOVEV	{"email": "solovev-v-031973@postgrespro.ru", "phone": "+70806289075"}
0005432799799	5CB837	3493 943505	ARTEM SMIRNOV	{"phone": "+70174103824"}
0005432799800	F8CD97	3213 312223	MARIYA KUZNECOVA	{"phone": "+70723473215"}
0005432799801	7176DE	3792 992289	VLADIMIR PETROV	{"email": "petrov_v.121976@postgrespro.ru", "phone": "+70538522910"}
0005432799802	7176DE	9373 214444	ANASTASIYA MOROZOVA	{"email": "morozova.anastasiya.1973@postgrespro.ru", "phone": "+70870667137"}
0005432799803	85EB73	1848 629128	ELENA ABRAMOVA	{"phone": "+70244652606"}
0005432799804	85EB73	8840 524464	EVGENIY MELNIKOV	{"email": "melnikov-e_03071971@postgrespro.ru", "phone": "+70785997965"}
0005432799805	85EB73	6853 480064	SERGEY SEMENOV	{"email": "s_semenov-1971@postgrespro.ru", "phone": "+70142375422"}
0005432799806	60F098	6180 416089	NINA TITOVA	{"email": "n-titova_22021967@postgrespro.ru", "phone": "+70532607507"}
0005432799807	8525F3	7979 987626	LYUBOV GAVRILOVA	{"phone": "+70500293536"}
0005432799808	68BAF7	0631 291553	VADIM MIKHAYLOV	{"email": "vadimmikhaylov_1979@postgrespro.ru", "phone": "+70271938146"}
0005432799809	110A87	1281 427542	YURIY KUZNECOV	{"email": "kuznecovyuriy_071957@postgrespro.ru", "phone": "+70160664152"}
0005432799810	5C2142	0294 671008	ANASTASIYA ZAKHAROVA	{"email": "zakharova-a031978@postgrespro.ru", "phone": "+70606812010"}
0005432799811	5F51A5	8050 236096	ARTEM MIRONOV	{"email": "mironova_1966@postgrespro.ru", "phone": "+70991715956"}
0005432799812	447BE8	3690 460498	ANATOLIY SOKOLOV	{"email": "sokolova-04021971@postgrespro.ru", "phone": "+70563803071"}
0005432799813	447BE8	1325 880217	ALEKSANDR IVANOV	{"phone": "+70079006972"}
0005432799814	0B6004	6515 666390	MARINA KUDRYASHOVA	{"phone": "+70850404101"}
0005432799815	986FDF	5566 235050	VIKTOR KUZMIN	{"email": "viktor_kuzmin-121978@postgrespro.ru", "phone": "+70297566487"}
0005432799816	64E9DD	2819 623416	NINA IVANOVA	{"email": "nina.ivanova-1970@postgrespro.ru", "phone": "+70546875212"}
0005432799817	7B0CF7	4733 624745	TAMARA KUZMINA	{"email": "kuzminat051973@postgrespro.ru", "phone": "+70065763231"}
0005432799818	7B0CF7	9963 313474	LIDIYA MATVEEVA	{"email": "matveevalidiya.28091971@postgrespro.ru", "phone": "+70038656487"}
0005432799819	1E48A9	4058 203826	EKATERINA EGOROVA	{"phone": "+70735649118"}
0005432799820	1E48A9	6808 138620	GALINA ZAKHAROVA	{"email": "galinazakharova.081966@postgrespro.ru", "phone": "+70085412994"}
0005432799821	1E48A9	8046 433209	TAISA MATVEEVA	{"email": "matveeva.t-14061980@postgrespro.ru", "phone": "+70600347701"}
0005432799822	B221F2	9079 087066	KONSTANTIN SEMENOV	{"email": "semenovk.1975@postgrespro.ru", "phone": "+70228245896"}
0005432799823	39A4A4	8933 599496	EVGENIY BELOV	{"email": "ebelov1977@postgrespro.ru", "phone": "+70833353234"}
0005432799824	B31E8D	7820 654887	SVETLANA ROMANOVA	{"email": "romanova-s.1982@postgrespro.ru", "phone": "+70846266226"}
0005432799825	3AB5BF	7209 461914	OLGA VOROBEVA	{"phone": "+70566786624"}
0005432799826	3AB5BF	4543 734937	ALEKSEY IVANOV	{"email": "ivanov.a_21021969@postgrespro.ru", "phone": "+70716393848"}
0005432799827	BC69EE	0165 045908	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr031979@postgrespro.ru", "phone": "+70930007570"}
0005432799828	BC69EE	8781 708210	IRINA SOLOVEVA	{"email": "solovevairina15051969@postgrespro.ru", "phone": "+70253676487"}
0005432799829	96E2BB	8670 496797	MARIYA VASILEVA	{"email": "mariya.vasileva-1975@postgrespro.ru", "phone": "+70485317551"}
0005432799830	00FCA9	0543 687765	EVGENIY KUZMIN	{"email": "kuzmin.e.101971@postgrespro.ru", "phone": "+70807930140"}
0005432799831	F2687C	8694 788820	NINA FOMINA	{"phone": "+70929467122"}
0005432799832	6F911E	7750 935217	GALINA MOROZOVA	{"email": "morozova-g_1956@postgrespro.ru", "phone": "+70369076309"}
0005432799833	35122B	2513 557143	YANA TARASOVA	{"email": "tarasova-yana.071982@postgrespro.ru", "phone": "+70502477216"}
0005432799834	35122B	4523 280818	MIKHAIL ALEKSEEV	{"email": "alekseev-mikhail071973@postgrespro.ru", "phone": "+70508112679"}
0005432799835	B15193	2276 690798	PAVEL IVANOV	{"phone": "+70437821557"}
0005432799836	B15193	6439 854702	DMITRIY ANDREEV	{"phone": "+70087071208"}
0005432799837	50D1B6	3838 203028	NIKOLAY STEPANOV	{"phone": "+70715402250"}
0005432799838	50D1B6	1895 766730	ANDREY OSIPOV	{"email": "andrey-osipov_15031984@postgrespro.ru", "phone": "+70530132456"}
0005432799839	D1F4F7	6482 137579	LYUBOV VLASOVA	{"email": "l.vlasova-07101965@postgrespro.ru", "phone": "+70175548279"}
0005432799840	13E956	9028 776181	TATYANA MAKAROVA	{"phone": "+70585136900"}
0005432799841	13E956	0850 318533	ANDREY STEPANOV	{"email": "andrey_stepanov-1981@postgrespro.ru", "phone": "+70303130184"}
0005432799842	E1F249	2996 709338	ZINAIDA IVANOVA	{"phone": "+70535812974"}
0005432799843	A4FA69	3771 338918	SOFYA OVCHINNIKOVA	{"phone": "+70346988571"}
0005432799844	A4FA69	5081 076943	PAVEL SOKOLOV	{"email": "p.sokolov1972@postgrespro.ru", "phone": "+70445158360"}
0005432799845	F10030	6683 082232	SOFYA GAVRILOVA	{"phone": "+70381622607"}
0005432799846	878B55	2563 170247	NIKOLAY IVANOV	{"email": "ivanovn-051974@postgrespro.ru", "phone": "+70686040295"}
0005432799847	878B55	6532 089848	ANATOLIY SERGEEV	{"phone": "+70776933135"}
0005432799848	CEC349	6067 015951	EVGENIY KUZNECOV	{"phone": "+70415052762"}
0005432799849	CEC349	8821 081223	MIKHAIL SAVELEV	{"email": "savelev-mikhail-051963@postgrespro.ru", "phone": "+70259525240"}
0005432799850	BC26BE	0378 988846	NADEZHDA NIKITINA	{"email": "nikitina-nadezhda-071962@postgrespro.ru", "phone": "+70225831156"}
0005432799851	BC26BE	2473 005273	NIKOLAY ISAEV	{"email": "isaev.nikolay-021969@postgrespro.ru", "phone": "+70755652785"}
0005432799852	456212	9037 128175	TATYANA POPOVA	{"email": "popova.t.1982@postgrespro.ru", "phone": "+70010187182"}
0005432799853	2D9F5C	4522 671201	NIKITA NAZAROV	{"phone": "+70454562136"}
0005432799854	2D9F5C	3806 140253	EGOR DMITRIEV	{"phone": "+70225498135"}
0005432799855	C56B5A	0696 567730	VALERIY TIKHONOV	{"email": "tikhonovvaleriy031977@postgrespro.ru", "phone": "+70439278896"}
0005432799856	4DC00A	3933 116679	ANASTASIYA VLASOVA	{"phone": "+70585260538"}
0005432799857	4DC00A	5262 450881	ELIZAVETA DAVYDOVA	{"email": "davydova.elizaveta-1976@postgrespro.ru", "phone": "+70755732502"}
0005432799858	CE4E44	7460 119869	LYUCIYA KOLESNIKOVA	{"email": "kolesnikovalyuciya_071974@postgrespro.ru", "phone": "+70592979072"}
0005432799859	CE4E44	0881 059072	VITALIY KISELEV	{"phone": "+70161843591"}
0005432799860	CE4E44	6450 636913	ALEKSANDR FROLOV	{"email": "frolov.a-1969@postgrespro.ru", "phone": "+70471637963"}
0005432799861	D3A43B	4874 192864	KIRILL KULIKOV	{"phone": "+70003509402"}
0005432799862	D5C687	0093 363040	RIMMA ERMAKOVA	{"phone": "+70726496832"}
0005432799863	542000	5852 388897	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-1968@postgrespro.ru", "phone": "+70148082793"}
0005432799864	D36F1C	9402 238369	OLGA NIKITINA	{"email": "olga.nikitina-071971@postgrespro.ru", "phone": "+70764041658"}
0005432799865	E9B7C7	3727 388700	SERGEY ZAYCEV	{"email": "s_zaycev.081968@postgrespro.ru", "phone": "+70335740696"}
0005432799866	DF6E4A	6454 606414	ZINAIDA NIKITINA	{"phone": "+70481321755"}
0005432799867	14EE55	4598 526777	OLEG MIKHAYLOV	{"email": "mikhaylov.oleg_10031972@postgrespro.ru", "phone": "+70992201878"}
0005432799868	66E7B2	0269 053817	IGOR MAKAROV	{"email": "makarov_igor-111973@postgrespro.ru", "phone": "+70373426458"}
0005432799869	AF4470	0740 024945	KIRILL VASILEV	{"phone": "+70561273430"}
0005432799870	A127B2	7812 729669	ANDREY MEDVEDEV	{"phone": "+70802827660"}
0005432799871	A127B2	8538 216495	NIKOLAY MEDVEDEV	{"phone": "+70778274256"}
0005432799872	C18E4F	7631 542039	VIKTOR FROLOV	{"phone": "+70460644817"}
0005432799873	C18E4F	0339 077407	TATYANA SMIRNOVA	{"email": "t-smirnova031972@postgrespro.ru", "phone": "+70297738967"}
0005432799874	D5B33E	0826 921817	GALINA ZAYCEVA	{"phone": "+70301368552"}
0005432799875	D5B33E	1053 938526	YURIY KUZNECOV	{"email": "kuznecov_yuriy.1963@postgrespro.ru", "phone": "+70798988901"}
0005432799876	53EC38	1232 060127	ANASTASIYA TARASOVA	{"phone": "+70476321417"}
0005432799877	72B1FC	1116 145235	YULIYA SOLOVEVA	{"phone": "+70283258738"}
0005432799878	F8EF58	6797 321287	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev.22101969@postgrespro.ru", "phone": "+70906543343"}
0005432799879	F8EF58	7550 919445	ILYA YAKOVLEV	{"email": "ilya_yakovlev.061978@postgrespro.ru", "phone": "+70804785699"}
0005432799880	96C2B6	3665 684862	ELENA KAZAKOVA	{"phone": "+70390631103"}
0005432799881	96C2B6	7195 433217	ARMEN SMIRNOV	{"phone": "+70860216006"}
0005432799882	7CD965	8353 973469	ALEKSANDR KOROLEV	{"phone": "+70312192206"}
0005432799883	74F3CC	1652 279015	GALINA ANISIMOVA	{"email": "anisimova_galina_22021983@postgrespro.ru", "phone": "+70910414072"}
0005432799884	E785F5	6328 477097	MAKSIM DMITRIEV	{"email": "mdmitriev.011969@postgrespro.ru", "phone": "+70785052185"}
0005432799885	25AB9F	7275 229674	EVGENIY KUZMIN	{"email": "evgeniykuzmin1983@postgrespro.ru", "phone": "+70064474162"}
0005432799886	410DB8	9120 751835	ANATOLIY OSIPOV	{"email": "osipov.a.051979@postgrespro.ru", "phone": "+70111818002"}
0005432799887	01BAFF	9669 628997	KSENIYA YAKOVLEVA	{"phone": "+70902411734"}
0005432799888	88B8CB	5462 643527	TATYANA ANTONOVA	{"email": "tatyana.antonova.021980@postgrespro.ru", "phone": "+70917780013"}
0005432799889	770205	8543 639308	LARISA NIKITINA	{"email": "nikitina-l.01011970@postgrespro.ru", "phone": "+70114486442"}
0005432799890	DAC7D8	2742 209177	LYUDMILA FEDOROVA	{"email": "lyudmila_fedorova.071972@postgrespro.ru", "phone": "+70031041961"}
0005432799891	BD176E	0029 642653	ALEKSEY MIRONOV	{"email": "a_mironov1982@postgrespro.ru", "phone": "+70295726603"}
0005432799892	BD176E	4128 403103	MARIYA BARANOVA	{"phone": "+70348539174"}
0005432799893	BD176E	3127 042034	ULYANA SOROKINA	{"phone": "+70678962232"}
0005432799894	545B76	5632 136831	EVGENIY BORISOV	{"phone": "+70457882596"}
0005432799895	D46D54	1272 061446	TATYANA FROLOVA	{"phone": "+70173471287"}
0005432799896	4B98FC	4517 784897	SERGEY NOVIKOV	{"email": "novikov.sergey-011980@postgrespro.ru", "phone": "+70475657224"}
0005432799897	E89E3E	4403 066275	OLGA ARKHIPOVA	{"phone": "+70746008014"}
0005432799898	E89E3E	8016 083611	PAVEL MAKSIMOV	{"email": "p-maksimov1980@postgrespro.ru", "phone": "+70207446838"}
0005432799899	685482	8463 247109	NINA POPOVA	{"email": "popova.nina1973@postgrespro.ru", "phone": "+70237653911"}
0005432799900	7B578A	5495 400045	IRINA SEMENOVA	{"email": "semenova.i.081982@postgrespro.ru", "phone": "+70598596222"}
0005432799901	8D2560	3326 044326	ALEKSANDR BARANOV	{"phone": "+70407830664"}
0005432799902	98372B	7059 358095	YULIYA RYABOVA	{"email": "y.ryabova-03041960@postgrespro.ru", "phone": "+70556917821"}
0005432799903	DCEB0D	6980 296927	RAMILYA ZAKHAROVA	{"phone": "+70650288690"}
0005432799904	7B41F5	8372 083016	MIKHAIL NAZAROV	{"email": "nazarov-m-051968@postgrespro.ru", "phone": "+70034800637"}
0005432799905	3732B6	9702 718741	ANATOLIY KUZNECOV	{"phone": "+70878570533"}
0005432799906	09CEC7	3165 263138	ALEKSANDR GERASIMOV	{"phone": "+70517132772"}
0005432799907	09CEC7	1658 057978	DMITRIY DAVYDOV	{"phone": "+70661282352"}
0005432799908	C37708	6024 383824	YULIYA MOROZOVA	{"email": "morozova-y.051961@postgrespro.ru", "phone": "+70412551885"}
0005432799909	E1C376	2688 367837	GENNADIY SMIRNOV	{"email": "smirnov.gennadiy011974@postgrespro.ru", "phone": "+70998475065"}
0005432799910	29E9E0	5987 667204	IRINA LEBEDEVA	{"phone": "+70692768668"}
0005432799911	88A917	5568 441862	MARINA MIKHAYLOVA	{"email": "mikhaylovamarina041975@postgrespro.ru", "phone": "+70743901162"}
0005432799912	FF96C7	0382 826632	ANNA SOLOVEVA	{"email": "soloveva.a091967@postgrespro.ru", "phone": "+70384671190"}
0005432799913	1F44B7	5528 450950	VALERIYA KOLESNIKOVA	{"email": "kolesnikova.v_30071968@postgrespro.ru", "phone": "+70898639166"}
0005432799914	ADF437	5799 340253	ELENA POTAPOVA	{"email": "potapova-elena091968@postgrespro.ru", "phone": "+70302622105"}
0005432799915	4DB2C3	9315 994365	ELMIRA MALYSHEVA	{"phone": "+70449350585"}
0005432799916	0950E4	3352 301287	TATYANA ANDREEVA	{"email": "andreevatatyana_061957@postgrespro.ru", "phone": "+70235151978"}
0005432800093	889C3F	2980 259579	RAFAIL SERGEEV	{"phone": "+70947417395"}
0005432799917	D2BA36	8379 260913	MAKSIM PETROV	{"email": "petrov.m20031974@postgrespro.ru", "phone": "+70981445254"}
0005432799918	D2BA36	1073 954339	MARIYA SEMENOVA	{"email": "m-semenova.071966@postgrespro.ru", "phone": "+70569439720"}
0005432799919	6C41C4	4343 023962	RINAT MATVEEV	{"phone": "+70838971739"}
0005432799920	1CFF4D	2209 764464	SERGEY STEPANOV	{"phone": "+70716817834"}
0005432799921	E0112D	4993 235022	GALINA ZAKHAROVA	{"email": "gzakharova.1964@postgrespro.ru", "phone": "+70880466231"}
0005432799922	7224FE	2685 586939	ALEKSANDR DENISOV	{"email": "aleksandrdenisov-1970@postgrespro.ru", "phone": "+70936152182"}
0005432799923	6B5014	1484 313766	ALEKSEY RODIONOV	{"phone": "+70815977858"}
0005432799924	C83BEF	1667 320855	NIKOLAY MAKAROV	{"phone": "+70528129387"}
0005432799925	518F85	6516 826832	OLGA ZAKHAROVA	{"phone": "+70738208336"}
0005432799926	68FAAF	5565 787412	MIKHAIL IVANOV	{"phone": "+70632701284"}
0005432799927	A1D0C0	6054 623483	PETR EGOROV	{"email": "egorov_petr1966@postgrespro.ru", "phone": "+70456805107"}
0005432799928	C28056	6957 566477	TATYANA SOLOVEVA	{"phone": "+70605153984"}
0005432799929	C28056	4917 218279	IRINA MAKAROVA	{"phone": "+70593439876"}
0005432799930	68D820	4560 459033	NIKOLAY ALEKSEEV	{"email": "n-alekseev_1984@postgrespro.ru", "phone": "+70702130988"}
0005432799931	68D820	1398 048671	OLGA YUDINA	{"email": "o-yudina-19041982@postgrespro.ru", "phone": "+70913797417"}
0005432799932	9F6846	5006 869621	OLGA LOGINOVA	{"phone": "+70293009108"}
0005432799933	BB1AAD	6594 835226	ANDREY EGOROV	{"email": "egorovandrey_081988@postgrespro.ru", "phone": "+70789553070"}
0005432799934	CCCA18	0804 178041	LYUDMILA ZAYCEVA	{"phone": "+70308708835"}
0005432799935	514AAD	6769 915991	ELENA TITOVA	{"email": "etitova.051978@postgrespro.ru", "phone": "+70088299476"}
0005432799936	514AAD	0084 343095	MARIYA OSIPOVA	{"email": "osipovam-21021978@postgrespro.ru", "phone": "+70333133374"}
0005432799937	13B4BA	6533 749749	IRINA EGOROVA	{"email": "i-egorova-061980@postgrespro.ru", "phone": "+70077326138"}
0005432799938	4DEDAA	0295 011084	SERGEY VOLKOV	{"email": "s-volkov.1972@postgrespro.ru", "phone": "+70001773831"}
0005432799939	6180B3	4119 693486	ZHANNA NIKITINA	{"email": "z.nikitina.1969@postgrespro.ru", "phone": "+70041294703"}
0005432799940	8E70F5	1556 573153	SERGEY SHEVCHENKO	{"email": "sergey_shevchenko-111976@postgrespro.ru", "phone": "+70058759201"}
0005432799941	D60327	9733 812103	ANTON GUSEV	{"phone": "+70935744056"}
0005432799942	D60327	9949 053272	VASILIY MEDVEDEV	{"phone": "+70901423567"}
0005432799943	A2B11E	9869 260031	NIKOLAY IVANOV	{"phone": "+70511153263"}
0005432799944	A32E87	8084 970353	VIKTOR IVANOV	{"phone": "+70334799314"}
0005432799945	A32E87	6148 657615	ALEKSEY MELNIKOV	{"email": "a.melnikov28091975@postgrespro.ru", "phone": "+70666410134"}
0005432799946	88B2DE	4148 662890	OLGA KOROLEVA	{"email": "olgakoroleva_1982@postgrespro.ru", "phone": "+70900809261"}
0005432799947	152B55	5586 261403	VERONIKA POPOVA	{"phone": "+70647403215"}
0005432799948	152B55	7407 417708	PETR STEPANOV	{"email": "stepanovp12031971@postgrespro.ru", "phone": "+70110234147"}
0005432799949	831D50	2544 240689	TATYANA NESTEROVA	{"phone": "+70321235593"}
0005432799950	A13A9C	4928 851213	VIKTORIYA SMIRNOVA	{"phone": "+70432318341"}
0005432799951	A13A9C	1340 227582	SOFYA TIMOFEEVA	{"phone": "+70610101119"}
0005432799952	DECEF6	0087 046524	ALEKSEY IVANOV	{"phone": "+70655109945"}
0005432799953	DECEF6	6503 112958	SERGEY EGOROV	{"email": "egorov-sergey-011963@postgrespro.ru", "phone": "+70003564720"}
0005432799954	38C8C1	1520 219927	ANATOLIY KOZLOV	{"phone": "+70444963997"}
0005432799955	73E0C8	5173 691298	DMITRIY FILIPPOV	{"email": "filippovdmitriy_111965@postgrespro.ru", "phone": "+70654227053"}
0005432799956	A5D9D0	5881 847584	STANISLAV VASILEV	{"phone": "+70964725869"}
0005432799957	DC5045	7392 430424	ANNA YAKOVLEVA	{"email": "ayakovleva_27111965@postgrespro.ru", "phone": "+70714777231"}
0005432799958	DC5045	1984 850948	NADEZHDA ANISIMOVA	{"email": "anisimovanadezhda-07051970@postgrespro.ru", "phone": "+70000291028"}
0005432799959	74A8E0	4656 115097	SERGEY TARASOV	{"email": "s-tarasov_1970@postgrespro.ru", "phone": "+70028971353"}
0005432799960	74A8E0	0580 870533	VLADIMIR GERASIMOV	{"email": "gerasimovvladimir.1985@postgrespro.ru", "phone": "+70870033429"}
0005432799961	59C2A4	3658 351473	IRINA DMITRIEVA	{"phone": "+70887083900"}
0005432799962	642864	5784 977209	MATVEY DAVYDOV	{"email": "m_davydov.021974@postgrespro.ru", "phone": "+70127659802"}
0005432799963	642864	3023 777007	NINA SERGEEVA	{"email": "sergeeva.nina07011967@postgrespro.ru", "phone": "+70285368855"}
0005432799964	71DE5B	7310 376888	NINA KUZNECOVA	{"phone": "+70795961002"}
0005432799965	8EDABE	3468 592410	ELENA EFREMOVA	{"phone": "+70151246706"}
0005432799966	8EDABE	0089 110515	LIDIYA ALEKSANDROVA	{"phone": "+70203278086"}
0005432799967	9D3D7E	1085 089944	EDUARD PAVLOV	{"phone": "+70926470614"}
0005432799968	9D3D7E	7985 741803	OLGA ROMANOVA	{"email": "olga.romanova051969@postgrespro.ru", "phone": "+70446985570"}
0005432799969	F3D06A	9491 014851	VALENTINA VASILEVA	{"phone": "+70202933292"}
0005432799970	F3D06A	2172 849635	IRINA ZOTOVA	{"phone": "+70409051548"}
0005432799971	57DDD4	8461 440579	SVETLANA KALININA	{"phone": "+70778314563"}
0005432799972	57DDD4	4671 442563	IGNAT MATVEEV	{"phone": "+70492091089"}
0005432799973	092F50	6166 672495	TATYANA KUZMINA	{"email": "kuzmina-t_061963@postgrespro.ru", "phone": "+70454055499"}
0005432799974	092F50	4248 946106	NADEZHDA IVANOVA	{"phone": "+70322929188"}
0005432799975	092F50	9208 074198	MARAT PETROV	{"email": "petrov-m.16081980@postgrespro.ru", "phone": "+70727538874"}
0005432799976	86B19E	2555 342446	ANTON IVANOV	{"email": "ivanov.anton11071957@postgrespro.ru", "phone": "+70914895927"}
0005432799977	2C326A	3828 671748	NIKOLAY VASILEV	{"phone": "+70513104688"}
0005432800094	AE62F0	9750 558926	MAKSIM SEMENOV	{"phone": "+70878243030"}
0005432799978	5F5DF2	5824 449886	LYUBOV LOGINOVA	{"email": "l_loginova_1986@postgrespro.ru", "phone": "+70524155271"}
0005432799979	5F5DF2	1813 418981	VALERIY OSIPOV	{"email": "osipovv-1962@postgrespro.ru", "phone": "+70651347811"}
0005432799980	5F5DF2	8614 181187	NATALYA GAVRILOVA	{"email": "natalya_gavrilova-06011966@postgrespro.ru", "phone": "+70813567672"}
0005432799981	0C3909	6304 551859	NADEZHDA SOROKINA	{"phone": "+70612508604"}
0005432799982	0C3909	5794 258690	ALISA ZAKHAROVA	{"email": "zakharova-a.1966@postgrespro.ru", "phone": "+70894144530"}
0005432799983	FBD549	6411 441515	SVETLANA BARANOVA	{"phone": "+70848873096"}
0005432799984	D0E1E6	1700 060179	ALEKSANDRA POLYAKOVA	{"email": "a_polyakova_061962@postgrespro.ru", "phone": "+70213232761"}
0005432799985	D0E1E6	2040 143698	NATALYA GERASIMOVA	{"email": "gerasimova-natalya.051983@postgrespro.ru", "phone": "+70719474727"}
0005432799986	BF907D	5297 792839	DANILA GERASIMOV	{"phone": "+70623015228"}
0005432799987	BF907D	4857 829639	LARISA TIMOFEEVA	{"email": "l_timofeeva.031974@postgrespro.ru", "phone": "+70537740955"}
0005432799988	94BEED	3897 609040	NIKOLAY NAZAROV	{"phone": "+70107088936"}
0005432799989	94BEED	4020 460355	KLAVDIYA ERMAKOVA	{"email": "ermakovaklavdiya-27091965@postgrespro.ru", "phone": "+70458740078"}
0005432799990	25026F	2286 729290	TATYANA EGOROVA	{"email": "egorova-tatyana-051978@postgrespro.ru", "phone": "+70051329458"}
0005432799991	25026F	6641 102927	IVAN EGOROV	{"email": "i_egorov.1966@postgrespro.ru", "phone": "+70708744406"}
0005432799992	E8608B	1929 594832	EVGENIY SCHERBAKOV	{"email": "escherbakov.101968@postgrespro.ru", "phone": "+70365817360"}
0005432799993	A31577	0709 471566	NATALYA IVANOVA	{"email": "ivanovanatalya18121965@postgrespro.ru", "phone": "+70134593395"}
0005432799994	32F670	9363 382649	MARTA FOMINA	{"email": "fomina.m_06091967@postgrespro.ru", "phone": "+70071971986"}
0005432799995	32F670	8096 425876	OLGA SAVELEVA	{"phone": "+70359783755"}
0005432799996	82D937	5699 705766	ELENA SOROKINA	{"phone": "+70218346521"}
0005432799997	82D937	5513 162298	SVETLANA IVANOVA	{"phone": "+70608089826"}
0005432799998	755D5C	3543 134580	VALERIY ILIN	{"email": "ilin-valeriy1970@postgrespro.ru", "phone": "+70978212808"}
0005432799999	755D5C	1940 115211	NATALYA KUZNECOVA	{"email": "nkuznecova_061974@postgrespro.ru", "phone": "+70059338562"}
0005432800000	8AA937	3031 073860	KSENIYA DAVYDOVA	{"phone": "+70711555605"}
0005432800001	E08FB3	3162 528924	IRINA KULIKOVA	{"email": "kulikova_irina101968@postgrespro.ru", "phone": "+70316649661"}
0005432800002	AC511F	4588 706637	NADEZHDA SAVELEVA	{"phone": "+70300554094"}
0005432800003	E724FF	2902 216640	NIKOLAY FEDOROV	{"email": "fedorovnikolay-13021983@postgrespro.ru", "phone": "+70816992069"}
0005432800004	C5A3A0	5701 245163	ALEKSANDR KONOVALOV	{"email": "akonovalov021978@postgrespro.ru", "phone": "+70182476052"}
0005432800005	F1BF85	2382 265833	VIKTOR FEDOTOV	{"email": "fedotovv1976@postgrespro.ru", "phone": "+70248030028"}
0005432800006	EF8511	9898 612978	NIKOLAY NIKOLAEV	{"email": "nikolay_nikolaev-031967@postgrespro.ru", "phone": "+70048708289"}
0005432800007	A6638B	5503 055555	FARID NIKOLAEV	{"email": "farid-nikolaev-081973@postgrespro.ru", "phone": "+70812616707"}
0005432800008	A6638B	9315 976666	ALEVTINA ARKHIPOVA	{"email": "alevtina.arkhipova-1982@postgrespro.ru", "phone": "+70981109273"}
0005432800009	B43C6D	8748 910002	TATYANA NIKOLAEVA	{"phone": "+70385489990"}
0005432800010	A9E9E8	6039 758822	ZOYA BELOVA	{"email": "zoya_belova1965@postgrespro.ru", "phone": "+70693476089"}
0005432800011	615341	2606 609056	ELVINA ALEKSANDROVA	{"email": "aleksandrovae_30091970@postgrespro.ru", "phone": "+70482519494"}
0005432800012	615341	1069 291197	TATYANA ANDREEVA	{"phone": "+70686736635"}
0005432800013	404444	4971 241690	VALENTINA MAKSIMOVA	{"email": "valentina-maksimova.20031977@postgrespro.ru", "phone": "+70867365299"}
0005432800014	404444	7073 383534	REGINA RYABOVA	{"phone": "+70236964869"}
0005432800015	404444	3680 901093	LYUDMILA KOROLEVA	{"email": "lyudmila.koroleva.081975@postgrespro.ru", "phone": "+70770149151"}
0005432800016	3D70E4	1787 403038	VITALIY ALEKSANDROV	{"email": "v.aleksandrov1972@postgrespro.ru", "phone": "+70074700661"}
0005432800017	5B0882	9923 819562	ANTONINA IVANOVA	{"email": "ivanovaantonina_011974@postgrespro.ru", "phone": "+70450018938"}
0005432800018	5B0882	2050 269262	ANASTASIYA MOROZOVA	{"email": "morozova-a_021976@postgrespro.ru", "phone": "+70094745621"}
0005432800019	C56434	0238 809996	DMITRIY FEDOTOV	{"email": "dmitriy-fedotov-07031989@postgrespro.ru", "phone": "+70810723840"}
0005432800020	B6FAAC	8347 014468	EDUARD SERGEEV	{"email": "sergeev_e_1972@postgrespro.ru", "phone": "+70132779781"}
0005432800021	B6FAAC	6835 807622	VALENTINA SMIRNOVA	{"email": "vsmirnova.081966@postgrespro.ru", "phone": "+70236437928"}
0005432800022	7101BA	3491 322156	IRINA ABRAMOVA	{"email": "abramova_irina_15091962@postgrespro.ru", "phone": "+70325099493"}
0005432800023	7101BA	6976 178209	NADEZHDA MAKAROVA	{"email": "nadezhdamakarova.31081964@postgrespro.ru", "phone": "+70011191427"}
0005432800024	66787E	0210 951779	YURIY MOROZOV	{"email": "morozovyuriy.061977@postgrespro.ru", "phone": "+70108117811"}
0005432800025	66787E	4353 029693	MARIYA GAVRILOVA	{"phone": "+70336139482"}
0005432800026	77A05D	0547 126106	VLADIMIR KUZMIN	{"phone": "+70528876417"}
0005432800027	77A05D	7515 473328	NATALYA NESTEROVA	{"email": "n-nesterova-1961@postgrespro.ru", "phone": "+70850306543"}
0005432800028	18A944	7133 326108	SERGEY TIKHONOV	{"email": "sergeytikhonov_011965@postgrespro.ru", "phone": "+70726944105"}
0005432800029	18A944	0128 151842	OLGA IVANOVA	{"email": "ivanova_olga.24021967@postgrespro.ru", "phone": "+70407042525"}
0005432800030	9970F7	3467 050680	KIRILL STEPANOV	{"phone": "+70338529109"}
0005432800031	D71478	1109 227814	POLINA PETROVA	{"email": "polinapetrova_081973@postgrespro.ru", "phone": "+70018348459"}
0005432800032	8CE24B	4975 142055	NINA KUZMINA	{"email": "nina_kuzmina051974@postgrespro.ru", "phone": "+70146625326"}
0005432800033	1CCD84	2752 994247	SERGEY DENISOV	{"phone": "+70888730925"}
0005432800034	BA3F7D	3872 254697	ANNA POPOVA	{"email": "a-popova-24121977@postgrespro.ru", "phone": "+70549821321"}
0005432800035	3D9804	1464 051068	SVETLANA ALEKSANDROVA	{"phone": "+70171366541"}
0005432800036	8FE5C8	3898 661315	LARISA MAKAROVA	{"phone": "+70734216515"}
0005432800037	8FE5C8	9428 875555	EKATERINA AKIMOVA	{"phone": "+70977781605"}
0005432800038	00A7CA	1072 224727	VLADIMIR IVANOV	{"phone": "+70079309450"}
0005432800039	00A7CA	0152 404853	ELENA SOROKINA	{"phone": "+70016283366"}
0005432800040	5CA64B	0520 590707	NADEZHDA NESTEROVA	{"email": "nadezhda-nesterova-061978@postgrespro.ru", "phone": "+70053795043"}
0005432800041	5CA64B	8182 667782	YURIY KUZNECOV	{"email": "y_kuznecov1985@postgrespro.ru", "phone": "+70076140699"}
0005432800042	973C34	8906 096259	LEONID SIDOROV	{"email": "sidorov_leonid_1978@postgrespro.ru", "phone": "+70041508114"}
0005432800043	973C34	8641 864942	MARINA RODIONOVA	{"phone": "+70044143433"}
0005432800044	CF53F8	1222 297685	EVGENIY MOISEEV	{"phone": "+70423378574"}
0005432800045	CF53F8	8607 469192	EVGENIY DENISOV	{"phone": "+70322289765"}
0005432800046	A680AD	8550 385276	SVETLANA MAKSIMOVA	{"email": "s-maksimova10111972@postgrespro.ru", "phone": "+70527503832"}
0005432800047	41A107	7718 753381	STANISLAV YAKOVLEV	{"phone": "+70177302964"}
0005432800048	AD1AC5	6450 255325	ALBINA DENISOVA	{"email": "denisova.a_1970@postgrespro.ru", "phone": "+70986508998"}
0005432800049	AD1AC5	7123 189211	IRINA ZAYCEVA	{"phone": "+70446217507"}
0005432800050	8C1F5D	1908 186736	ELENA POLYAKOVA	{"phone": "+70701240234"}
0005432800051	533092	2028 305209	VALERIY YAKOVLEV	{"phone": "+70204660539"}
0005432800052	4BA858	2943 577144	ANASTASIYA STEPANOVA	{"email": "stepanova.a031982@postgrespro.ru", "phone": "+70868504704"}
0005432800053	D3DDA9	8240 949474	TATYANA MAKSIMOVA	{"email": "tatyanamaksimova041966@postgrespro.ru", "phone": "+70527978401"}
0005432800054	D3DDA9	3088 142857	VLADIMIR MAKSIMOV	{"email": "v_maksimov-22011967@postgrespro.ru", "phone": "+70428116751"}
0005432800055	2206DC	7605 281791	ELENA NIKOLAEVA	{"email": "nikolaeva-e24091976@postgrespro.ru", "phone": "+70287072410"}
0005432800167	B011A0	0672 705114	ALEKSANDR ABRAMOV	{"phone": "+70245676805"}
0005432800056	2206DC	0885 148415	VIKTORIYA KUZNECOVA	{"email": "kuznecova-viktoriya_1969@postgrespro.ru", "phone": "+70935200142"}
0005432800057	B9E3A6	4498 906712	MARINA KOLESNIKOVA	{"email": "kolesnikovam1984@postgrespro.ru", "phone": "+70900863445"}
0005432800058	B9E3A6	9864 886065	VALENTINA ZAKHAROVA	{"phone": "+70598331348"}
0005432800059	B9E3A6	9534 148721	EVGENIYA NOVIKOVA	{"phone": "+70983869384"}
0005432800060	774561	2477 446356	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov.1974@postgrespro.ru", "phone": "+70580807866"}
0005432800061	BA7222	2324 413019	RUSLAN GAVRILOV	{"email": "gavrilovr02111981@postgrespro.ru", "phone": "+70027434495"}
0005432800062	3AC386	6417 676813	ARTEM SAVELEV	{"phone": "+70794911357"}
0005432800063	B20F83	9141 447559	PAVEL SEMENOV	{"phone": "+70602833480"}
0005432800064	B20F83	5959 576170	ANASTASIYA MAKAROVA	{"email": "anastasiya_makarova_071982@postgrespro.ru", "phone": "+70837795940"}
0005432800065	129C8C	9995 359321	VIKTORIYA BORISOVA	{"email": "borisova-v-22081976@postgrespro.ru", "phone": "+70723732088"}
0005432800066	0441E3	0163 369456	YURIY VOROBEV	{"email": "vorobev.yuriy1973@postgrespro.ru", "phone": "+70773182484"}
0005432800067	1414F3	2991 821750	ELENA POPOVA	{"email": "elena.popova.1972@postgrespro.ru", "phone": "+70826559666"}
0005432800068	2A04B9	4239 917174	IGOR SCHERBAKOV	{"phone": "+70023440029"}
0005432800069	4DCC07	9323 910129	ANASTASIYA TROFIMOVA	{"phone": "+70985276300"}
0005432800070	D7352E	0517 004094	MARIYA GRISHINA	{"email": "grishina.mariya121968@postgrespro.ru", "phone": "+70755845169"}
0005432800071	26C609	4434 090044	SERGEY SOLOVEV	{"phone": "+70081542397"}
0005432800072	26C609	4716 248136	ANTONINA KAZAKOVA	{"phone": "+70247987891"}
0005432800073	26C609	5322 089104	VALENTINA ANDREEVA	{"phone": "+70357360286"}
0005432800074	1EF9FE	5432 855752	ANDREY ROMANOV	{"email": "romanov_andrey-1974@postgrespro.ru", "phone": "+70837112180"}
0005432800075	C32626	1918 293967	ELENA ZAKHAROVA	{"email": "zakharova_elena1971@postgrespro.ru", "phone": "+70256583627"}
0005432800076	C32626	1924 978357	EVGENIY CHERNOV	{"email": "chernov-evgeniy1977@postgrespro.ru", "phone": "+70433603239"}
0005432800077	C32626	3936 364412	IRINA ANISIMOVA	{"email": "anisimova_irina1971@postgrespro.ru", "phone": "+70978404160"}
0005432800078	4CBCA6	8223 891736	NATALIYA VASILEVA	{"phone": "+70043770168"}
0005432800079	46BE16	4906 379577	VASILIY SIDOROV	{"phone": "+70533651007"}
0005432800080	20F784	6616 206043	OLEG MELNIKOV	{"phone": "+70576187728"}
0005432800081	62FB47	2178 016874	NIKITA ILIN	{"email": "ilin_nikita_1977@postgrespro.ru", "phone": "+70950316199"}
0005432800082	AA671F	2956 626287	SERAFIMA POLYAKOVA	{"phone": "+70828846735"}
0005432800083	AA671F	6795 848273	IVAN OSIPOV	{"email": "osipovivan_041968@postgrespro.ru", "phone": "+70267619656"}
0005432800084	A57DAC	8662 302975	NINA NIKIFOROVA	{"email": "n-nikiforova.081978@postgrespro.ru", "phone": "+70415881170"}
0005432800085	6E6C06	7768 303147	SERGEY SEMENOV	{"email": "semenov-sergey-091965@postgrespro.ru", "phone": "+70498007475"}
0005432800086	6E6C06	5899 205987	ANATOLIY GORBUNOV	{"email": "agorbunov_021974@postgrespro.ru", "phone": "+70322585842"}
0005432800087	49B27E	9539 352129	VYACHESLAV STEPANOV	{"email": "stepanovv-011973@postgrespro.ru", "phone": "+70540799933"}
0005432800088	F57F5E	1392 224374	GALINA POPOVA	{"email": "popova_g-1974@postgrespro.ru", "phone": "+70472081506"}
0005432800089	F57F5E	6727 539055	MARIYA SOROKINA	{"phone": "+70556600280"}
0005432800090	BBFA2E	9507 694151	TATYANA ABRAMOVA	{"email": "tatyanaabramova_11091974@postgrespro.ru", "phone": "+70761771112"}
0005432800091	BBFA2E	9521 592338	ALEKSEY KULIKOV	{"phone": "+70382356120"}
0005432800092	84E69A	6895 898044	ANTONINA ROMANOVA	{"email": "antonina.romanova.011986@postgrespro.ru", "phone": "+70743581441"}
0005432800095	AE62F0	2435 482550	IRINA ZHUKOVA	{"email": "zhukova_i1961@postgrespro.ru", "phone": "+70121515259"}
0005432800096	5EA6DA	4149 272197	KSENIYA BARANOVA	{"phone": "+70557161622"}
0005432800097	5EA6DA	0620 285672	TATYANA POPOVA	{"email": "popovatatyana27071959@postgrespro.ru", "phone": "+70132210664"}
0005432800098	5EA6DA	8636 690825	VLADIMIR KULIKOV	{"email": "kulikov_vladimir_111969@postgrespro.ru", "phone": "+70979840779"}
0005432800099	5EA6DA	1524 101870	RAISA POPOVA	{"email": "raisapopova.1981@postgrespro.ru", "phone": "+70033327139"}
0005432800100	D7D461	0592 929639	ALEKSANDR ALEKSANDROV	{"phone": "+70068780819"}
0005432800101	31C3C9	3253 077532	SERAFIMA SAVELEVA	{"phone": "+70977476487"}
0005432800102	31C3C9	4833 725744	ELENA ERMAKOVA	{"phone": "+70861009627"}
0005432800103	5BF2C1	4740 562652	OLGA DENISOVA	{"email": "odenisova.031957@postgrespro.ru", "phone": "+70999119943"}
0005432800104	5BF2C1	8751 271886	STANISLAV MELNIKOV	{"phone": "+70053724943"}
0005432800105	5BFD3E	3417 698681	YULIYA PAVLOVA	{"phone": "+70581623166"}
0005432800106	5BFD3E	7835 000300	VERA PETROVA	{"phone": "+70146970730"}
0005432800107	DBCF46	9510 619888	ALEKSANDRA ZAYCEVA	{"email": "zaycevaaleksandra-071960@postgrespro.ru", "phone": "+70233976521"}
0005432800108	A414F8	3228 718835	SERGEY MATVEEV	{"email": "sergey_matveev031974@postgrespro.ru", "phone": "+70027486791"}
0005432800109	A414F8	9046 343071	IGOR SOROKIN	{"email": "i.sorokin19051969@postgrespro.ru", "phone": "+70395529467"}
0005432800110	48B5A7	8548 538230	NINA ZOTOVA	{"email": "zotova.n-24011963@postgrespro.ru", "phone": "+70214984904"}
0005432800111	F430FC	7667 778557	ALLA LEBEDEVA	{"email": "lebedeva_a18071973@postgrespro.ru", "phone": "+70874855475"}
0005432800112	F430FC	6044 839480	ANGELINA MALYSHEVA	{"email": "malyshevaa.1958@postgrespro.ru", "phone": "+70629305023"}
0005432800113	F430FC	6053 309588	OLEG ZAKHAROV	{"phone": "+70481062735"}
0005432800114	2EA9D6	6818 711021	DENIS ZAKHAROV	{"phone": "+70582315248"}
0005432800115	42D605	7927 785052	LYUBOV BOGDANOVA	{"email": "l-bogdanova.051966@postgrespro.ru", "phone": "+70558181958"}
0005432800116	42D605	4959 342915	NATALYA DAVYDOVA	{"email": "davydova_natalya.10031978@postgrespro.ru", "phone": "+70403385979"}
0005432800117	72C160	9274 939845	VALERIY ZHUKOV	{"email": "zhukov-v121979@postgrespro.ru", "phone": "+70149323257"}
0005432800118	4332DC	9998 471983	OKSANA SERGEEVA	{"email": "sergeevaoksana_14071973@postgrespro.ru", "phone": "+70976377656"}
0005432800119	4332DC	8811 601328	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov_1982@postgrespro.ru", "phone": "+70676738476"}
0005432800120	4332DC	9783 154608	ALEVTINA FOMINA	{"email": "a.fomina.1971@postgrespro.ru", "phone": "+70150441131"}
0005432800121	901E4A	6228 589262	ALEKSEY KUZNECOV	{"email": "kuznecov.a.1968@postgrespro.ru", "phone": "+70703613897"}
0005432800122	2126EE	7978 074703	ELIZAVETA ZAKHAROVA	{"phone": "+70316855505"}
0005432800123	2126EE	6619 318917	NATALYA NIKIFOROVA	{"phone": "+70721723816"}
0005432800124	2126EE	5657 301521	EVGENIY DENISOV	{"phone": "+70445578480"}
0005432800125	AEF465	6061 379520	ANASTASIYA KUZNECOVA	{"phone": "+70114213982"}
0005432800126	F5B882	4496 663359	VALENTINA KOVALEVA	{"email": "v.kovaleva.10091971@postgrespro.ru", "phone": "+70523974716"}
0005432800127	5F6A82	7604 564902	ALEKSEY FEDOROV	{"email": "aleksey.fedorov1977@postgrespro.ru", "phone": "+70524205776"}
0005432800128	D17D19	1342 043111	ZINAIDA MOROZOVA	{"email": "zinaidamorozova-1958@postgrespro.ru", "phone": "+70596917761"}
0005432800129	A6C51F	3348 576148	SOFYA POPOVA	{"phone": "+70816124033"}
0005432800130	A6C51F	5810 384002	MIKHAIL ROMANOV	{"email": "romanov.mikhail-1966@postgrespro.ru", "phone": "+70922465675"}
0005432800131	A6C51F	2203 092563	EKATERINA IVANOVA	{"email": "ivanova_e101977@postgrespro.ru", "phone": "+70897968577"}
0005432800132	9BC58E	8413 741132	MARINA FILIPPOVA	{"email": "filippova-m_29011968@postgrespro.ru", "phone": "+70339200673"}
0005432800133	9BC58E	8490 489955	ANDREY NIKOLAEV	{"email": "andrey_nikolaev.041973@postgrespro.ru", "phone": "+70607836553"}
0005432800134	9BC58E	2600 500936	VALERIYA FOMINA	{"phone": "+70654486839"}
0005432800135	04701A	0188 138946	EVGENIYA GRISHINA	{"email": "e.grishina.1967@postgrespro.ru", "phone": "+70337595578"}
0005432800136	04701A	6244 089332	ANASTASIYA NOVIKOVA	{"email": "novikova.anastasiya.1972@postgrespro.ru", "phone": "+70884455188"}
0005432800137	04701A	6696 747751	VITALIY POPOV	{"phone": "+70725672677"}
0005432800138	EA0445	5362 152683	IRINA FILATOVA	{"email": "filatova_i16101973@postgrespro.ru", "phone": "+70529012873"}
0005432800139	03E090	1750 560112	ALEKSEY NAZAROV	{"phone": "+70995986001"}
0005432800140	41E63B	3945 483738	NADEZHDA KUZMINA	{"phone": "+70355933948"}
0005432800141	41E63B	5465 793958	INNA TROFIMOVA	{"email": "trofimova-i021973@postgrespro.ru", "phone": "+70059621375"}
0005432800142	7BBCB7	6809 576186	TAISIYA KAZAKOVA	{"email": "t-kazakova.1965@postgrespro.ru", "phone": "+70310092717"}
0005432800143	7BBCB7	1323 988009	NADEZHDA BOGDANOVA	{"phone": "+70444989330"}
0005432800144	401BDF	8074 548558	EVGENIYA KUZNECOVA	{"email": "e-kuznecova_1967@postgrespro.ru", "phone": "+70500978648"}
0005432800145	F344F2	1743 235787	SVETLANA BELYAEVA	{"email": "svetlana_belyaeva.31011963@postgrespro.ru", "phone": "+70798685169"}
0005432800146	C533C1	4822 516976	ANTON TARASOV	{"email": "tarasov.a.17061964@postgrespro.ru", "phone": "+70706612055"}
0005432800147	C533C1	5990 203840	VIKTORIYA POPOVA	{"phone": "+70385479873"}
0005432800148	C7A1F0	2473 341433	MARIYA FROLOVA	{"email": "mariya_frolova10011963@postgrespro.ru", "phone": "+70130895482"}
0005432800149	FCB59B	7964 349699	VIKTOR OSIPOV	{"phone": "+70804269177"}
0005432800150	0AA847	9131 294163	IGOR KOZLOV	{"phone": "+70200415508"}
0005432800151	79A18C	7921 472993	IRINA STEPANOVA	{"phone": "+70905986919"}
0005432800152	9F430F	2226 375688	EVGENIY MAKAROV	{"email": "evgeniymakarov-081960@postgrespro.ru", "phone": "+70343270189"}
0005432800153	8F9D5E	7436 582947	MARINA ROMANOVA	{"phone": "+70305875646"}
0005432800154	8F9D5E	0310 196450	NIKITA IVANOV	{"phone": "+70273265576"}
0005432800155	B99250	9184 565035	VIKTOR VOLKOV	{"email": "volkovviktor-23051976@postgrespro.ru", "phone": "+70581498110"}
0005432800156	B99250	3676 920946	VALENTINA KOLESNIKOVA	{"email": "kolesnikovav_1976@postgrespro.ru", "phone": "+70966034554"}
0005432800157	B31A70	3967 624928	EVGENIY GAVRILOV	{"email": "gavrilov-evgeniy_23121972@postgrespro.ru", "phone": "+70701293944"}
0005432800158	98E645	5261 587252	ELENA SOKOLOVA	{"email": "elena-sokolova.091976@postgrespro.ru", "phone": "+70712408233"}
0005432800159	160CDF	6481 645942	YURIY FEDOTOV	{"email": "y.fedotov.23081979@postgrespro.ru", "phone": "+70958654655"}
0005432800160	730D17	3661 869051	ANTON ZHURAVLEV	{"phone": "+70348767835"}
0005432800161	730D17	9979 227556	NATALYA NIKITINA	{"phone": "+70400094947"}
0005432800162	32F9F8	7491 876355	IRINA EGOROVA	{"email": "egorova.i.1974@postgrespro.ru", "phone": "+70172599787"}
0005432800163	0CA1AC	1398 568716	EVGENIY EGOROV	{"email": "egorov.e.111974@postgrespro.ru", "phone": "+70448491640"}
0005432800164	F818A0	7694 954959	NINA TARASOVA	{"email": "tarasova-n_081976@postgrespro.ru", "phone": "+70206438006"}
0005432800165	24E8B0	2087 234932	ANNA KOROLEVA	{"phone": "+70099831862"}
0005432800166	24E8B0	7151 108550	YURIY MAKAROV	{"phone": "+70726163812"}
0005432800168	B011A0	7871 577474	VALENTINA SEMENOVA	{"phone": "+70368432507"}
0005432800169	63658C	5312 724434	OLGA POPOVA	{"email": "popovaolga-1981@postgrespro.ru", "phone": "+70005929115"}
0005432800170	63658C	5626 717717	MAKSIM MAKSIMOV	{"phone": "+70707981863"}
0005432800171	63658C	0869 602013	ALENA STEPANOVA	{"email": "stepanova.a-081972@postgrespro.ru", "phone": "+70464929219"}
0005432800172	72293B	3056 384024	LARISA KUZNECOVA	{"email": "l_kuznecova121970@postgrespro.ru", "phone": "+70087388940"}
0005432800173	693041	5372 056622	LIDIYA TROFIMOVA	{"phone": "+70722691405"}
0005432800174	693041	3082 848849	ROMAN SERGEEV	{"email": "r_sergeev081976@postgrespro.ru", "phone": "+70542652271"}
0005432800175	95F616	0904 260188	VALERIY BARANOV	{"email": "v.baranov28071973@postgrespro.ru", "phone": "+70153365553"}
0005432800176	69BA88	7625 256861	NADEZHDA ANTONOVA	{"phone": "+70949784332"}
0005432800177	69BA88	1057 025762	ISLAM KUZNECOV	{"phone": "+70389169656"}
0005432800178	7BFF5B	4175 208556	PAVEL DENISOV	{"phone": "+70283787667"}
0005432800179	1B1303	4676 588574	OLGA MIRONOVA	{"email": "mironova.olga-1973@postgrespro.ru", "phone": "+70827830447"}
0005432800180	7DD526	5139 341631	ANDREY ORLOV	{"email": "orlov_andrey-14091966@postgrespro.ru", "phone": "+70139479426"}
0005432800181	C0F0FD	7104 664948	NIKOLAY MOROZOV	{"email": "morozov.n-051964@postgrespro.ru", "phone": "+70677225084"}
0005432800182	C0F0FD	1769 517355	IVAN ZAKHAROV	{"email": "zakharovivan-15081977@postgrespro.ru", "phone": "+70559343548"}
0005432800183	D18A0D	1800 033447	ALEKSANDR BELOV	{"email": "aleksandr_belov.1962@postgrespro.ru", "phone": "+70326000828"}
0005432800184	931516	7033 237239	IRINA ANDREEVA	{"email": "andreeva-irina-051981@postgrespro.ru", "phone": "+70062324315"}
0005432800185	4601EA	1295 714923	ALLA NAZAROVA	{"phone": "+70534165090"}
0005432800186	4601EA	4486 866604	ANASTASIYA ANISIMOVA	{"email": "anisimova.a.051968@postgrespro.ru", "phone": "+70644791219"}
0005432800187	F62D0F	4509 318491	ALEKSEY VASILEV	{"phone": "+70241627340"}
0005432800188	F62D0F	9207 743678	EGOR SOROKIN	{"phone": "+70642415907"}
0005432800189	C2A731	3308 840855	EVGENIY OSIPOV	{"email": "e.osipov-1976@postgrespro.ru", "phone": "+70679381037"}
0005432800190	C2A731	9774 747376	LARISA PAVLOVA	{"email": "pavlova.larisa-1969@postgrespro.ru", "phone": "+70247961108"}
0005432800191	E3E46B	3696 632182	VLADIMIR ZAYCEV	{"phone": "+70551165089"}
0005432800192	E3E46B	8427 357381	OLGA ALEKSEEVA	{"phone": "+70509612874"}
0005432800193	E3E46B	6560 687599	FEDOR NOVIKOV	{"email": "fedornovikov_111986@postgrespro.ru", "phone": "+70612621507"}
0005432800194	A1BD7C	8312 215503	ANNA SOROKINA	{"email": "sorokina.anna.11041969@postgrespro.ru", "phone": "+70891919240"}
0005432800195	58C4EB	2687 620283	KRISTINA EFREMOVA	{"phone": "+70967567145"}
0005432800196	8E2887	5716 119889	OLEG ISAEV	{"phone": "+70628702348"}
0005432800197	8E2887	9483 580036	ALEKSANDR GRIGOREV	{"email": "grigorev-a_01101979@postgrespro.ru", "phone": "+70594400659"}
0005432800198	83D988	1690 312395	ZOYA ZAKHAROVA	{"email": "zoya.zakharova_081971@postgrespro.ru", "phone": "+70148569078"}
0005432800199	BEE203	1806 209617	OLGA SOKOLOVA	{"email": "sokolova_o-071975@postgrespro.ru", "phone": "+70487901386"}
0005432800200	BEE203	1251 947654	VYACHESLAV PAVLOV	{"email": "vyacheslav.pavlov26101971@postgrespro.ru", "phone": "+70474703926"}
0005432800201	03C446	7864 602362	EVGENIY ROMANOV	{"email": "romanov-evgeniy.071980@postgrespro.ru", "phone": "+70787185110"}
0005432800202	5BF300	4173 100867	GALINA KUZNECOVA	{"email": "kuznecovag-1965@postgrespro.ru", "phone": "+70971083235"}
0005432800203	01A848	1459 720270	OLGA DENISOVA	{"phone": "+70056256162"}
0005432800204	D63B87	6328 005415	MARGARITA SERGEEVA	{"phone": "+70890544273"}
0005432800205	0AB634	4191 059291	OLGA STEPANOVA	{"phone": "+70260096999"}
0005432800206	FD29BE	1714 015381	SVETLANA ILINA	{"email": "ilina_s.101978@postgrespro.ru", "phone": "+70738639252"}
0005432800207	785DB7	6296 509716	NIKOLAY SERGEEV	{"email": "sergeevn_1965@postgrespro.ru", "phone": "+70113782391"}
0005432800208	785DB7	4670 847958	GALINA SOKOLOVA	{"phone": "+70673514260"}
0005432800209	68D8C5	4829 068095	NIKOLAY POPOV	{"phone": "+70426939485"}
0005432800210	3863E9	4589 170459	NIKOLAY KUZMIN	{"email": "n-kuzmin.061978@postgrespro.ru", "phone": "+70939724146"}
0005432800211	765A76	2926 851185	DMITRIY SOLOVEV	{"phone": "+70009663441"}
0005432800212	765A76	5272 397748	SVETLANA SAVELEVA	{"phone": "+70687468327"}
0005432800213	CBDA5C	1810 651638	IRINA TARASOVA	{"email": "irina-tarasova_20101958@postgrespro.ru", "phone": "+70089632878"}
0005432800214	3B5693	2485 419426	TATYANA IVANOVA	{"phone": "+70072112230"}
0005432800215	3B5693	8346 481310	EGOR SOKOLOV	{"email": "egorsokolov.1972@postgrespro.ru", "phone": "+70083399224"}
0005432800216	3B5693	8267 188709	EKATERINA EGOROVA	{"email": "e_egorova.1960@postgrespro.ru", "phone": "+70229296371"}
0005432800217	045CBF	2009 725840	VIKTOR MAKAROV	{"email": "makarovv.17041971@postgrespro.ru", "phone": "+70165127100"}
0005432800218	EEE496	2280 418902	ELENA NIKIFOROVA	{"email": "nikiforova-e-01081979@postgrespro.ru", "phone": "+70417237397"}
0005432800219	74A020	8679 456072	TATYANA KOROLEVA	{"phone": "+70251466490"}
0005432800220	4FE180	7151 278627	VYACHESLAV PETROV	{"email": "petrov.v20041966@postgrespro.ru", "phone": "+70793734234"}
0005432800221	724780	2047 721861	YURIY TIKHONOV	{"email": "tikhonov-yuriy06041982@postgrespro.ru", "phone": "+70327678148"}
0005432800222	724780	4648 223980	ANDREY ORLOV	{"email": "aorlov-061977@postgrespro.ru", "phone": "+70503826525"}
0005432800223	A766BB	7155 161259	IVAN KUZNECOV	{"email": "ivan.kuznecov061956@postgrespro.ru", "phone": "+70957429700"}
0005432800224	A766BB	1101 491871	YURIY ANDREEV	{"phone": "+70029964996"}
0005432800225	A766BB	4416 769346	LILIYA KUZNECOVA	{"phone": "+70165859502"}
0005432800226	BB0822	9421 757392	NIKITA ROMANOV	{"email": "romanov_n.1972@postgrespro.ru", "phone": "+70606525454"}
0005432800227	BB0822	8158 395538	LARISA ROMANOVA	{"email": "larisa.romanova.031982@postgrespro.ru", "phone": "+70434311465"}
0005432800228	C7BA87	0138 847450	TATYANA KOROLEVA	{"email": "koroleva_t1958@postgrespro.ru", "phone": "+70905820571"}
0005432800229	D76A2A	2313 169320	ALEKSANDR EGOROV	{"email": "aleksandregorov011975@postgrespro.ru", "phone": "+70354036754"}
0005432800230	D76A2A	8257 501473	RAISA RODIONOVA	{"email": "rodionova-raisa10041963@postgrespro.ru", "phone": "+70481000527"}
0005432800231	D21A67	0215 373976	IGOR SAVELEV	{"phone": "+70801177639"}
0005432800232	8D6EC3	9637 912124	YURIY CHERNOV	{"email": "y_chernov09041987@postgrespro.ru", "phone": "+70817185355"}
0005432800233	8D6EC3	2419 269758	OLGA ISAEVA	{"phone": "+70637722080"}
0005432800234	4EF0F7	7963 580056	NINA ILINA	{"phone": "+70966674101"}
0005432800235	DBCBEF	1638 114471	ARTEM KRASNOV	{"phone": "+70407015440"}
0005432800236	772179	6510 833231	DARYA VASILEVA	{"phone": "+70598937111"}
0005432800237	CDBDDF	4039 479095	TATYANA MOROZOVA	{"email": "morozovatatyana.10101968@postgrespro.ru", "phone": "+70689130843"}
0005432800238	3B7BDA	9481 215748	MAKSIM KUZNECOV	{"email": "maksim_kuznecov_021972@postgrespro.ru", "phone": "+70892547672"}
0005432800239	3B7BDA	0833 054871	VLADIMIR ISAEV	{"email": "isaev.vladimir_05111974@postgrespro.ru", "phone": "+70654882733"}
0005432800240	2CEAEE	2594 695263	ANATOLIY KUDRYASHOV	{"email": "kudryashov.anatoliy1972@postgrespro.ru", "phone": "+70742953186"}
0005432800241	2CEAEE	0410 474036	OLGA SIDOROVA	{"phone": "+70395234882"}
0005432800242	13C599	1636 008187	VALENTINA TARASOVA	{"email": "valentina-tarasova_1974@postgrespro.ru", "phone": "+70184342471"}
0005432800243	93C7A3	1245 193627	ALEKSANDR DAVYDOV	{"email": "davydov.a1978@postgrespro.ru", "phone": "+70979132759"}
0005432800244	77AB2F	8883 784875	ALEVTINA FILIPPOVA	{"email": "a-filippova-1965@postgrespro.ru", "phone": "+70622549788"}
0005432800245	77AB2F	3500 082523	MIKHAIL DENISOV	{"email": "mikhail-denisov-1973@postgrespro.ru", "phone": "+70954150736"}
0005432800246	7AF17C	6551 547142	LYUBOV KULIKOVA	{"phone": "+70659814109"}
0005432800247	7AF17C	5924 681278	ALEKSANDR ZHUKOV	{"phone": "+70104057234"}
0005432800248	24817B	9603 959692	SERGEY SIDOROV	{"phone": "+70480642968"}
0005432800249	356E48	3704 423493	ALEKSEY ZAKHAROV	{"phone": "+70653485962"}
0005432800250	8282DA	9249 456924	VALENTINA RODIONOVA	{"email": "rodionova_valentina-03071958@postgrespro.ru", "phone": "+70603397478"}
0005432800251	882091	8917 646541	VITALIY ANDREEV	{"phone": "+70975168864"}
0005432800252	364F91	8702 029507	DANILA ANDREEV	{"email": "andreev.danila.01041971@postgrespro.ru", "phone": "+70827219907"}
0005432800253	364F91	6565 061335	ALEKSANDR PETROV	{"phone": "+70401894398"}
0005432800254	B1CB3A	9823 699199	VASILIY SMIRNOV	{"email": "smirnov_v-16121968@postgrespro.ru", "phone": "+70149906616"}
0005432800255	B1CB3A	3355 104623	ANGELINA FROLOVA	{"email": "a_frolova081967@postgrespro.ru", "phone": "+70282543619"}
0005432800256	30C38C	5311 265230	ALEKSEY ALEKSEEV	{"email": "a_alekseev1978@postgrespro.ru", "phone": "+70288532163"}
0005432800257	6EF910	7301 554137	LIDIYA DANILOVA	{"phone": "+70185410331"}
0005432800258	EA49C3	9033 758564	ALEKSANDR MOISEEV	{"phone": "+70221894128"}
0005432800259	21D07C	4442 232680	ANNA VOLKOVA	{"phone": "+70981651830"}
0005432800260	21D07C	9355 493359	IGOR TARASOV	{"phone": "+70070548619"}
0005432800261	C8F43A	1663 907789	LIDIYA TIKHONOVA	{"email": "tikhonova-lidiya-1984@postgrespro.ru", "phone": "+70452261104"}
0005432800262	C8F43A	1386 298118	VALERIY KUZNECOV	{"email": "kuznecovvaleriy.27031981@postgrespro.ru", "phone": "+70764761824"}
0005432800263	C8F43A	2773 617124	NINA RYABOVA	{"phone": "+70459298035"}
0005432800264	A7D01C	9251 142129	EKATERINA SIDOROVA	{"phone": "+70200505100"}
0005432800265	29CB83	2565 348660	RAISA SEMENOVA	{"phone": "+70480579785"}
0005432800266	79D0F7	2726 608992	NIKOLAY KULIKOV	{"phone": "+70455149555"}
0005432800267	C01DFA	4047 055060	KHALIDA ALEKSANDROVA	{"phone": "+70239263080"}
0005432800268	638740	0061 858777	YURIY BORISOV	{"email": "borisov-yuriy.29111981@postgrespro.ru", "phone": "+70587430045"}
0005432800269	52B294	3709 674653	MAKSIM KRASNOV	{"email": "krasnovmaksim.18091979@postgrespro.ru", "phone": "+70487971057"}
0005432800270	52B294	9531 801516	MARIYA MOISEEVA	{"phone": "+70791699851"}
0005432800271	3EE7E8	8733 448935	ELENA NAZAROVA	{"email": "elena-nazarova14081964@postgrespro.ru", "phone": "+70137174504"}
0005432800272	317931	8275 425494	VALENTINA RODIONOVA	{"phone": "+70218962720"}
0005432800273	1B8498	5801 028083	SVETLANA SERGEEVA	{"email": "s_sergeeva_09101964@postgrespro.ru", "phone": "+70501323322"}
0005432800274	7509A2	9343 479049	TATYANA NESTEROVA	{"phone": "+70234860235"}
0005432800275	B88517	3303 565293	ANNA GERASIMOVA	{"phone": "+70500155081"}
0005432800276	B88517	3747 757159	ALEKSANDR ZAKHAROV	{"email": "zakharova-23091980@postgrespro.ru", "phone": "+70375716479"}
0005432800277	3AD34E	1889 236032	DMITRIY KUZMIN	{"email": "kuzmind1966@postgrespro.ru", "phone": "+70229354226"}
0005432800278	38D773	4945 105530	ALEKSEY KUZNECOV	{"email": "kuznecov_a03101970@postgrespro.ru", "phone": "+70730718817"}
0005432800279	7B80E9	3373 513190	VALENTIN SIDOROV	{"phone": "+70723671672"}
0005432800280	993CFA	2466 796295	ROMAN SHEVCHENKO	{"email": "shevchenko.roman.19101977@postgrespro.ru", "phone": "+70966779262"}
0005432800281	993CFA	2657 849536	ALEKSANDR SOROKIN	{"email": "aleksandr.sorokin-1974@postgrespro.ru", "phone": "+70067665143"}
0005432800282	728EE8	2376 889410	OLEG SERGEEV	{"email": "osergeev_041979@postgrespro.ru", "phone": "+70643025188"}
0005432800283	728EE8	2766 338611	DANIIL YAKOVLEV	{"email": "d.yakovlev_1971@postgrespro.ru", "phone": "+70463720247"}
0005432800284	6B77DB	9801 758469	RAISA BELYAEVA	{"phone": "+70654403005"}
0005432800285	07079D	6236 690943	DARYA ALEKSANDROVA	{"phone": "+70998517647"}
0005432800286	F39AC9	1283 095815	EKATERINA NESTEROVA	{"phone": "+70077471469"}
0005432800287	F39AC9	8710 495506	NIKOLAY ZHUKOV	{"email": "n_zhukov-041965@postgrespro.ru", "phone": "+70036472011"}
0005432800288	B27374	5501 048563	VERA DANILOVA	{"phone": "+70556305201"}
0005432800289	194675	6712 841000	SERGEY AFANASEV	{"email": "afanasev-s13011970@postgrespro.ru", "phone": "+70244370732"}
0005432800290	194675	6624 202268	EKATERINA MIRONOVA	{"email": "mironova.e10031977@postgrespro.ru", "phone": "+70798223656"}
0005432802429	717F79	5115 949554	ELENA MAKSIMOVA	{"phone": "+70863214180"}
0005432802430	717F79	6350 754329	MARIYA POTAPOVA	{"email": "mariya_potapova1981@postgrespro.ru", "phone": "+70421644433"}
0005432802431	717F79	3920 953431	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr27091971@postgrespro.ru", "phone": "+70585727500"}
0005432802432	B5ECFB	5460 831312	OKSANA VOROBEVA	{"phone": "+70196605992"}
0005432802433	B5ECFB	0120 656434	OKSANA ANDREEVA	{"phone": "+70809966918"}
0005432802434	238FA7	0070 819237	DMITRIY SAVELEV	{"email": "dsavelev021976@postgrespro.ru", "phone": "+70994722925"}
0005432802435	087568	3528 089600	EVGENIY PETROV	{"email": "petrov-e.091964@postgrespro.ru", "phone": "+70997241620"}
0005432802436	3C2D05	7610 889922	EKATERINA IVANOVA	{"email": "ivanova-e-20111976@postgrespro.ru", "phone": "+70203033173"}
0005432802437	3C2D05	0249 382090	NATALIYA PETROVA	{"phone": "+70481171456"}
0005432802438	D399CC	9418 331220	ALEKSEY ANDREEV	{"phone": "+70026962485"}
0005432802439	D399CC	5707 303013	IRINA LUKYANOVA	{"phone": "+70740435655"}
0005432802440	DA9FAE	3897 243687	SERGEY VOROBEV	{"email": "vorobevsergey091968@postgrespro.ru", "phone": "+70319188706"}
0005432802441	E0A132	6499 426942	SEMEN POPOV	{"phone": "+70381981276"}
0005432802442	96D312	7916 349693	OLEG OSIPOV	{"phone": "+70102584681"}
0005432802443	96D312	3620 237692	ZINAIDA IVANOVA	{"email": "ivanova-zinaida_011971@postgrespro.ru", "phone": "+70336553365"}
0005432802444	61EEBE	8609 449763	VIKTOR KUZMIN	{"email": "kuzminviktor_021966@postgrespro.ru", "phone": "+70659955247"}
0005432802445	125FF8	5873 576403	YANA POPOVA	{"email": "ypopova.121972@postgrespro.ru", "phone": "+70214308720"}
0005432802446	125FF8	8201 158777	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir.051957@postgrespro.ru", "phone": "+70294429123"}
0005432802447	125FF8	3674 679792	VLADISLAV EGOROV	{"phone": "+70017592744"}
0005432802448	C6EE71	1161 563520	TATYANA AFANASEVA	{"phone": "+70735947050"}
0005432802449	3901AE	2879 949166	NINA BELOVA	{"phone": "+70479002081"}
0005432802450	061546	1202 989381	MAKSIM MIRONOV	{"phone": "+70623605570"}
0005432802451	1F8D27	6568 603048	SVETLANA AKIMOVA	{"email": "akimova.s_01011971@postgrespro.ru", "phone": "+70718075883"}
0005432802452	BC20A3	9859 626605	TATYANA FEDOROVA	{"email": "fedorova_tatyana_101965@postgrespro.ru", "phone": "+70268035913"}
0005432802453	BC20A3	2501 792143	IRINA MAKSIMOVA	{"email": "irina-maksimova_041974@postgrespro.ru", "phone": "+70133641686"}
0005432802454	2FE309	9302 902472	OLGA FILATOVA	{"phone": "+70910911491"}
0005432802455	DC866E	3868 193864	NATALYA FEDOROVA	{"phone": "+70153085157"}
0005432802456	0A3B0F	1315 366416	VERA ROMANOVA	{"email": "vera_romanova_021978@postgrespro.ru", "phone": "+70959152049"}
0005432802457	0A3B0F	4685 350128	VERA BORISOVA	{"email": "v_borisova-1972@postgrespro.ru", "phone": "+70717632586"}
0005432802458	0A3B0F	2744 473708	ANDREY KAZAKOV	{"email": "kazakov.andrey_1982@postgrespro.ru", "phone": "+70345135012"}
0005432802459	B14BD7	6193 986427	VIKTORIYA ZHUKOVA	{"phone": "+70076800242"}
0005432802460	725BF9	0932 621428	ELENA BELOVA	{"email": "elenabelova.011977@postgrespro.ru", "phone": "+70265685320"}
0005432802461	49FB91	6571 580234	LIDIYA ANISIMOVA	{"email": "lidiyaanisimova_101977@postgrespro.ru", "phone": "+70278281241"}
0005432802462	45184B	2567 303765	VASILIY FROLOV	{"email": "frolov-vasiliy.19051984@postgrespro.ru", "phone": "+70393603843"}
0005432802463	45184B	1524 754231	ALEKSANDR AFANASEV	{"email": "a.afanasev-24111978@postgrespro.ru", "phone": "+70100140862"}
0005432802464	45184B	1212 720115	ELENA NIKOLAEVA	{"phone": "+70751755930"}
0005432802465	836A44	2098 088349	GALINA MIKHAYLOVA	{"phone": "+70567876083"}
0005432802466	836A44	3374 420265	ANDREY KUZNECOV	{"email": "kuznecov_a.1978@postgrespro.ru", "phone": "+70502866078"}
0005432802467	4865C7	5025 442006	DENIS ILIN	{"phone": "+70120593360"}
0005432802468	F05FD1	2872 026514	LYUBOV AKIMOVA	{"email": "lakimova_091967@postgrespro.ru", "phone": "+70257890882"}
0005432802469	A7198E	4971 081391	SERGEY PETROV	{"phone": "+70289903703"}
0005432802470	44017F	6576 488238	MARINA MIKHAYLOVA	{"email": "marinamikhaylova051976@postgrespro.ru", "phone": "+70004715578"}
0005432802471	44017F	8770 918594	IRINA ZAKHAROVA	{"phone": "+70252063244"}
0005432802472	3CE1A5	5983 888403	EKATERINA SOKOLOVA	{"email": "sokolova_e-1983@postgrespro.ru", "phone": "+70411409177"}
0005432802473	3CE1A5	5882 068344	ALEKSANDR MOROZOV	{"phone": "+70141799103"}
0005432802474	5CBBE7	0442 203575	GALINA SIDOROVA	{"email": "sidorovag_1970@postgrespro.ru", "phone": "+70607051503"}
0005432802475	7C19AB	9969 195574	DANIL ZHURAVLEV	{"phone": "+70303681824"}
0005432802476	7C19AB	6837 076274	VYACHESLAV ANTONOV	{"email": "vyacheslavantonov.15071966@postgrespro.ru", "phone": "+70766502358"}
0005432802477	FB674F	9861 289441	DANIIL NAZAROV	{"phone": "+70578278181"}
0005432802478	B02D04	1172 547950	ANDREY ZAKHAROV	{"phone": "+70131095881"}
0005432802479	C38815	7498 522276	ARKADIY MELNIKOV	{"phone": "+70630063920"}
0005432802480	608963	0745 910569	IRINA KOZLOVA	{"phone": "+70036523338"}
0005432802481	22FC1A	8542 819144	MIKHAIL NIKOLAEV	{"email": "m_nikolaev061967@postgrespro.ru", "phone": "+70705911285"}
0005432802482	B7BFEE	0579 932642	ANDREY VASILEV	{"email": "a.vasilev1971@postgrespro.ru", "phone": "+70728053526"}
0005432802483	B7BFEE	8806 143206	DMITRIY MAKSIMOV	{"email": "maksimov_dmitriy.041967@postgrespro.ru", "phone": "+70773648797"}
0005432802484	27C6CF	7548 972565	TAMARA KOZLOVA	{"email": "t_kozlova_091968@postgrespro.ru", "phone": "+70841296351"}
0005432802485	27C6CF	4366 286808	LIDIYA OVCHINNIKOVA	{"email": "lovchinnikova1961@postgrespro.ru", "phone": "+70400804907"}
0005432802486	27C6CF	5159 319070	PETR TARASOV	{"email": "tarasov_petr-24051974@postgrespro.ru", "phone": "+70560041372"}
0005432802487	956FBD	2587 561723	MARIYA NESTEROVA	{"phone": "+70129972624"}
0005432802488	956FBD	0227 764730	SVETLANA POPOVA	{"phone": "+70994669914"}
0005432802489	956FBD	5977 444515	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov_031976@postgrespro.ru", "phone": "+70604879636"}
0005432802490	8EFF55	0032 868227	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr041978@postgrespro.ru", "phone": "+70794732251"}
0005432802491	48CAEC	9257 454637	MARIYA DAVYDOVA	{"phone": "+70771978000"}
0005432802492	DBA792	7310 012852	MAKSIM ANDREEV	{"phone": "+70068749634"}
0005432802493	FE15B0	8917 020358	VALERIY KUZNECOV	{"email": "vkuznecov.02041966@postgrespro.ru", "phone": "+70399953308"}
0005432802494	179CEB	6189 238765	SERGEY NIKOLAEV	{"email": "snikolaev21061974@postgrespro.ru", "phone": "+70509133637"}
0005432802495	C6311B	2184 176162	VLADIMIR GAVRILOV	{"email": "gavrilov-v_22091973@postgrespro.ru", "phone": "+70050267631"}
0005432802496	A34A4C	5047 057292	ANATOLIY MIKHAYLOV	{"phone": "+70438985617"}
0005432802497	524F77	4010 194465	VALERIY MATVEEV	{"phone": "+70382582400"}
0005432802498	FE7FFD	2041 486156	OLGA GORBUNOVA	{"phone": "+70626565493"}
0005432802499	5B48B4	3990 053770	GENNADIY SOROKIN	{"email": "sorokingennadiy.1983@postgrespro.ru", "phone": "+70546505396"}
0005432802500	5B48B4	9469 212971	GALINA BORISOVA	{"email": "g-borisova.18031965@postgrespro.ru", "phone": "+70152783377"}
0005432802501	E32247	9537 330046	TATYANA GERASIMOVA	{"email": "gerasimovat1977@postgrespro.ru", "phone": "+70935248566"}
0005432802502	C671B3	8559 137651	ANZHELA ZAYCEVA	{"email": "zaycevaa.1972@postgrespro.ru", "phone": "+70191889841"}
0005432802503	950306	2490 897967	YURIY POPOV	{"email": "popov-yuriy_091981@postgrespro.ru", "phone": "+70314277993"}
0005432802504	A7B094	5990 148120	VYACHESLAV PAVLOV	{"email": "pavlovv-081987@postgrespro.ru", "phone": "+70672936173"}
0005432802505	60BA5C	0433 690445	GENNADIY ABRAMOV	{"email": "abramov_gennadiy_18111970@postgrespro.ru", "phone": "+70585528304"}
0005432802506	60BA5C	2234 048291	SVETLANA ANDREEVA	{"email": "s_andreeva.121979@postgrespro.ru", "phone": "+70232850261"}
0005432802507	86DB90	8597 127875	VLADIMIR KUZNECOV	{"phone": "+70749597575"}
0005432802508	86DB90	2848 476331	EKATERINA CHERNOVA	{"email": "chernova_e1968@postgrespro.ru", "phone": "+70717975967"}
0005432802509	C27005	7834 501514	ANATOLIY MIKHAYLOV	{"phone": "+70714577046"}
0005432802510	BA54FA	3883 250386	MARIYA KONOVALOVA	{"phone": "+70083485026"}
0005432802511	BA54FA	3391 641444	IRINA NIKOLAEVA	{"email": "nikolaeva-i-1977@postgrespro.ru", "phone": "+70147375045"}
0005432802512	7E7C68	9483 456622	ALEKSEY MIRONOV	{"phone": "+70088802095"}
0005432802513	82E055	4192 877160	ROMAN SEMENOV	{"phone": "+70056218050"}
0005432802514	D1AB22	3639 358303	NATALYA ANTONOVA	{"email": "antonovan_1966@postgrespro.ru", "phone": "+70028296618"}
0005432802515	5DAC5B	4476 887353	VALENTINA GUSEVA	{"email": "v.guseva1974@postgrespro.ru", "phone": "+70265177177"}
0005432802516	4D557F	4163 630910	SVETLANA KULIKOVA	{"email": "kulikovasvetlana_11101965@postgrespro.ru", "phone": "+70430404347"}
0005432802517	7BF116	3866 725676	ALSU ARKHIPOVA	{"phone": "+70079735179"}
0005432802518	7BF116	8329 753546	VLADIMIR KUZNECOV	{"email": "v_kuznecov111983@postgrespro.ru", "phone": "+70785845311"}
0005432802519	18078A	7653 503007	RADIK DAVYDOV	{"phone": "+70770059974"}
0005432802520	18078A	4329 433914	IRINA LUKYANOVA	{"phone": "+70710274170"}
0005432802521	86383C	5638 590066	EVGENIYA IVANOVA	{"email": "ivanova_e.27051970@postgrespro.ru", "phone": "+70116669223"}
0005432802522	57B965	3429 730087	SERGEY SCHERBAKOV	{"phone": "+70695234540"}
0005432802523	B73889	0960 418563	ELENA VASILEVA	{"email": "vasileva.e-1971@postgrespro.ru", "phone": "+70022726157"}
0005432802524	B73889	0464 950552	ROMAN SOKOLOV	{"email": "sokolovr101982@postgrespro.ru", "phone": "+70322493368"}
0005432802525	59AA0A	4364 583312	ALEKSEY MARTYNOV	{"phone": "+70127943826"}
0005432802526	065330	1231 644226	VIKTORIYA SEMENOVA	{"email": "v-semenova-14091972@postgrespro.ru", "phone": "+70396958297"}
0005432802527	065330	6201 126316	LARISA POPOVA	{"email": "popova_larisa-20121962@postgrespro.ru", "phone": "+70100790682"}
0005432802528	20A909	6754 540591	ALEKSEY IVANOV	{"email": "ivanov-aleksey011982@postgrespro.ru", "phone": "+70411012490"}
0005432802529	20A909	8735 978721	ELENA KOZLOVA	{"email": "kozlova-elena-02061966@postgrespro.ru", "phone": "+70350172015"}
0005432802530	20A909	8152 906735	NADEZHDA ISAEVA	{"phone": "+70160995825"}
0005432802531	F9501A	0809 142332	VLADIMIR ISAEV	{"phone": "+70342028138"}
0005432802532	68EE45	9475 604248	ARTEM BARANOV	{"phone": "+70939479895"}
0005432802533	68EE45	5723 132294	LYUBOV OSIPOVA	{"email": "l-osipova24101970@postgrespro.ru", "phone": "+70315224490"}
0005432802534	8D9954	3795 632323	RINAT MIRONOV	{"phone": "+70091565881"}
0005432802535	6BEF22	2186 573600	ANASTASIYA BOGDANOVA	{"email": "anastasiya.bogdanova.051968@postgrespro.ru", "phone": "+70537180568"}
0005432802536	6BEF22	4482 443491	SERGEY GRIGOREV	{"email": "s.grigorev15071973@postgrespro.ru", "phone": "+70918135240"}
0005432802537	12A08E	7685 476769	EGOR PETROV	{"phone": "+70878135826"}
0005432802538	82B73D	7325 029202	IRINA VLASOVA	{"phone": "+70151059658"}
0005432802539	A49CFD	2576 848172	NADEZHDA DAVYDOVA	{"email": "nadezhda_davydova.1966@postgrespro.ru", "phone": "+70771698682"}
0005432802540	A49CFD	3763 847242	DANILA KUDRYASHOV	{"phone": "+70505173116"}
0005432802541	76A981	0914 308419	ANASTASIYA KALININA	{"phone": "+70196661609"}
0005432802542	BC4EA6	5709 541383	OLGA POPOVA	{"phone": "+70343955685"}
0005432802543	129803	4366 329510	GLEB MIKHAYLOV	{"email": "mikhaylovgleb.031966@postgrespro.ru", "phone": "+70154204664"}
0005432802544	FF0510	9758 123606	DARYA LUKYANOVA	{"email": "daryalukyanova121977@postgrespro.ru", "phone": "+70195245631"}
0005432802545	C3BE8B	7156 896642	DMITRIY MAKSIMOV	{"phone": "+70457540427"}
0005432802546	DF9066	6876 521301	VIKTOR DENISOV	{"email": "viktordenisov_28081975@postgrespro.ru", "phone": "+70376211739"}
0005432802547	4441A3	0559 621808	ANASTASIYA FILIPPOVA	{"phone": "+70322912466"}
0005432802548	4441A3	4242 798380	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko.13021966@postgrespro.ru", "phone": "+70985875361"}
0005432802549	898849	5279 792459	MARAT ZHUKOV	{"email": "m_zhukov-1970@postgrespro.ru", "phone": "+70331400388"}
0005432802550	8C7AB5	0023 230336	ANDREY GERASIMOV	{"email": "a-gerasimov.011974@postgrespro.ru", "phone": "+70139891951"}
0005432802551	854D7F	2788 578775	ALEKSANDR SHEVCHENKO	{"phone": "+70053334873"}
0005432802552	55DAC7	1866 184573	SERGEY IVANOV	{"phone": "+70632598953"}
0005432802553	E8CC60	4967 058841	ANATOLIY NOVIKOV	{"phone": "+70665727589"}
0005432802554	E8CC60	5452 943122	ALEKSANDR KISELEV	{"email": "a_kiselev16011975@postgrespro.ru", "phone": "+70669634969"}
0005432802555	96AF5C	7868 421251	STANISLAV BELOV	{"phone": "+70604858848"}
0005432802556	EE47AB	3572 428381	OLGA LUKYANOVA	{"phone": "+70908069729"}
0005432802557	614CD4	7244 165615	RUSLAN TIMOFEEV	{"phone": "+70227855342"}
0005432802558	D31F48	6553 958997	YAKOV ISAEV	{"phone": "+70176367246"}
0005432802559	B7DD8C	9450 642132	TATYANA KUDRYASHOVA	{"phone": "+70288887228"}
0005432802560	C993BD	1110 170015	LYUBOV AFANASEVA	{"email": "lyubov-afanaseva12121982@postgrespro.ru", "phone": "+70445731577"}
0005432802561	C993BD	6827 283186	GALINA VOROBEVA	{"email": "g.vorobeva-1969@postgrespro.ru", "phone": "+70141719770"}
0005432802562	A6AF8E	3514 857842	NATALYA VOLKOVA	{"phone": "+70742190561"}
0005432802563	EB79BC	0750 335740	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr11081981@postgrespro.ru", "phone": "+70258855858"}
0005432802564	06ABF1	1575 959774	ELENA FROLOVA	{"phone": "+70532633993"}
0005432802565	06ABF1	2805 615787	NIKOLAY DAVYDOV	{"email": "n.davydov_1975@postgrespro.ru", "phone": "+70964510640"}
0005432802566	84258B	1377 977145	TAMARA SOLOVEVA	{"phone": "+70256045393"}
0005432802567	078624	3577 373790	NADEZHDA MALYSHEVA	{"phone": "+70806938852"}
0005432802568	C43156	6447 532897	MAKAR KUZNECOV	{"phone": "+70491818813"}
0005432802569	C43156	9300 631898	DIANA AFANASEVA	{"phone": "+70493321412"}
0005432802570	906F44	1648 872250	ELIZAVETA OSIPOVA	{"phone": "+70519850381"}
0005432802571	906F44	8050 295776	VYACHESLAV FEDOROV	{"phone": "+70657872183"}
0005432802572	D19B07	5032 624851	ELENA BOGDANOVA	{"phone": "+70694267766"}
0005432802573	CAD54D	6432 217421	ANDREY SEMENOV	{"email": "semenov_a-051966@postgrespro.ru", "phone": "+70857275322"}
0005432802574	CAD54D	2877 121272	DMITRIY KAZAKOV	{"email": "kazakov-d.1978@postgrespro.ru", "phone": "+70950015523"}
0005432802575	9C27F9	1550 107671	ALEKSANDR YAKOVLEV	{"phone": "+70467511936"}
0005432802576	0900B0	9108 309710	ALEKSANDR GRIGOREV	{"phone": "+70442234622"}
0005432802577	930D06	0056 874835	EVGENIY TARASOV	{"email": "tarasovevgeniy-26011968@postgrespro.ru", "phone": "+70552683125"}
0005432802578	6B13D8	0664 389347	YURIY MOROZOV	{"email": "yuriy.morozov1978@postgrespro.ru", "phone": "+70508754255"}
0005432802579	039801	2975 794334	VALENTINA ERMAKOVA	{"phone": "+70782768570"}
0005432802580	9ECCBE	9735 369731	OKSANA KISELEVA	{"email": "o-kiseleva_19081968@postgrespro.ru", "phone": "+70835794529"}
0005432802581	9ECCBE	7316 658240	VALENTINA SCHERBAKOVA	{"phone": "+70256067900"}
0005432802582	9C72F3	4782 804133	RINAT VOROBEV	{"email": "vorobev.r-1974@postgrespro.ru", "phone": "+70753975271"}
0005432802583	9C72F3	3015 250527	VITALIY KONOVALOV	{"email": "vitaliy.konovalov_1983@postgrespro.ru", "phone": "+70149655916"}
0005432802584	9C72F3	5063 325888	DENIS ZHUKOV	{"phone": "+70840086788"}
0005432802585	26312B	5084 336868	YULIYA TROFIMOVA	{"email": "trofimova_yuliya_13031974@postgrespro.ru", "phone": "+70456628188"}
0005432802586	A4DF8C	9624 001979	ELENA PETROVA	{"email": "e_petrova-1975@postgrespro.ru", "phone": "+70395262795"}
0005432802587	A4DF8C	8386 659426	LYUBOV ANTONOVA	{"email": "lyubov.antonova-03111978@postgrespro.ru", "phone": "+70768630898"}
0005432802588	1FF0A9	6911 278247	VITALIY KUZMIN	{"phone": "+70501881204"}
0005432802589	1FF0A9	7081 662932	ALEKSEY BORISOV	{"phone": "+70560689960"}
0005432802590	8BB6EE	6068 604116	ALFIYA FADEEVA	{"email": "a.fadeeva-22081967@postgrespro.ru", "phone": "+70913714816"}
0005432802591	8BB6EE	5183 428023	ZOYA FILIPPOVA	{"email": "z_filippova081968@postgrespro.ru", "phone": "+70596436309"}
0005432817126	F8A65B	0780 902458	TAISIYA BELYAEVA	{"phone": "+70170924137"}
0005432802592	47FE95	5176 770491	KRISTINA NAUMOVA	{"email": "k.naumova_101972@postgrespro.ru", "phone": "+70160522852"}
0005432802593	8600BB	8276 294862	ALISA NESTEROVA	{"email": "nesterova-a-071971@postgrespro.ru", "phone": "+70776402369"}
0005432802594	BD987C	7291 317037	DMITRIY IVANOV	{"phone": "+70661235335"}
0005432802595	5B8528	4418 298358	SERGEY BORISOV	{"phone": "+70650048336"}
0005432802596	5B8528	1423 105699	VIKTORIYA GORBUNOVA	{"email": "gorbunova_v_121980@postgrespro.ru", "phone": "+70635731676"}
0005432802597	AA4DC7	3929 833309	ANDREY ROMANOV	{"phone": "+70161918113"}
0005432802598	51B5FF	2229 941877	LARISA KOMAROVA	{"phone": "+70512503576"}
0005432802599	51B5FF	9175 081403	SERGEY FEDOTOV	{"email": "fedotov-sergey_1961@postgrespro.ru", "phone": "+70704675786"}
0005432802600	B785F6	6435 546102	SHAMIL MIRONOV	{"phone": "+70394251719"}
0005432802601	0CF74E	0871 785445	SERGEY KUDRYASHOV	{"email": "kudryashov_sergey.02111971@postgrespro.ru", "phone": "+70796742956"}
0005432802602	111EE7	4711 250638	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.aleksandra-1980@postgrespro.ru", "phone": "+70708972658"}
0005432802603	7208BF	4892 194051	DARYA BORISOVA	{"phone": "+70693455600"}
0005432802604	7208BF	6282 985591	LYUDMILA KOROLEVA	{"email": "koroleva-lyudmila_30101987@postgrespro.ru", "phone": "+70049017244"}
0005432802605	223214	7163 934199	ALEKSEY PAVLOV	{"email": "pavlova.071962@postgrespro.ru", "phone": "+70919536933"}
0005432802606	3358E6	3476 977556	VIKTOR NAZAROV	{"email": "vnazarov-14011972@postgrespro.ru", "phone": "+70345418815"}
0005432802607	B9C5D2	9626 274707	SEMEN NAUMOV	{"email": "semen_naumov-051984@postgrespro.ru", "phone": "+70559774283"}
0005432802608	90C4C0	6666 306201	TATYANA ROMANOVA	{"phone": "+70772888650"}
0005432802609	F1A5EC	6307 368150	LILIYA CHERNOVA	{"phone": "+70358760271"}
0005432802610	F1A5EC	2381 008325	VIKTOR SOROKIN	{"email": "sorokin-viktor-15061971@postgrespro.ru", "phone": "+70400564403"}
0005432802611	B34B49	5948 022956	VALENTIN KRASNOV	{"phone": "+70972772573"}
0005432802612	A73E50	0811 419705	NATALYA SMIRNOVA	{"email": "smirnovan-23091976@postgrespro.ru", "phone": "+70714046039"}
0005432802613	A73E50	0253 513988	POLINA ERMAKOVA	{"email": "p_ermakova-05121979@postgrespro.ru", "phone": "+70785859813"}
0005432802614	5AC45F	2915 725091	NIKOLAY PETROV	{"phone": "+70643576722"}
0005432802615	E41819	9444 768720	ILYA VLASOV	{"email": "vlasov-ilya_1975@postgrespro.ru", "phone": "+70435897159"}
0005432802616	FF1E01	0031 228769	RIMMA KOROLEVA	{"email": "koroleva_rimma_1979@postgrespro.ru", "phone": "+70349570249"}
0005432802617	2262EA	9411 257272	VLADIMIR ISAEV	{"email": "v_isaev.01111984@postgrespro.ru", "phone": "+70527191943"}
0005432802618	CA42A0	1253 936527	VASILIY ISAEV	{"phone": "+70936076871"}
0005432802619	CA42A0	1748 025775	ULYANA KRASNOVA	{"email": "krasnovaulyana1968@postgrespro.ru", "phone": "+70096904099"}
0005432802620	821125	4368 553104	LYUDMILA ABRAMOVA	{"email": "l-abramova-021979@postgrespro.ru", "phone": "+70975772337"}
0005432802621	821125	1997 330779	NIKOLAY SOROKIN	{"email": "sorokinn.1979@postgrespro.ru", "phone": "+70157368773"}
0005432802622	411F96	8644 513849	VIKTOR GORBUNOV	{"phone": "+70074759816"}
0005432802623	411F96	0894 815794	ALEKSANDR NAZAROV	{"phone": "+70306589264"}
0005432802624	B3C102	5297 790116	MARIYA NIKITINA	{"email": "m-nikitina.121990@postgrespro.ru", "phone": "+70828999768"}
0005432802625	E1D5B3	4759 717104	OKSANA BELOVA	{"email": "o_belova.1969@postgrespro.ru", "phone": "+70270946094"}
0005432802626	E1D5B3	7091 138425	ELENA POPOVA	{"email": "popova_e_1977@postgrespro.ru", "phone": "+70124425894"}
0005432802627	46D57F	3220 683247	VLADIMIR GRIGOREV	{"email": "vgrigorev.021978@postgrespro.ru", "phone": "+70200288751"}
0005432802628	46D57F	5278 491560	ANATOLIY BARANOV	{"email": "anatoliy_baranov1976@postgrespro.ru", "phone": "+70785290857"}
0005432802629	741D7D	8927 124398	NIKOLAY MAKAROV	{"email": "nikolaymakarov.011975@postgrespro.ru", "phone": "+70808478155"}
0005432802630	741D7D	3130 573148	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov1965@postgrespro.ru", "phone": "+70047628326"}
0005432802631	741D7D	7624 931808	VLADIMIR ZHURAVLEV	{"email": "vladimir_zhuravlev_03091972@postgrespro.ru", "phone": "+70082933959"}
0005432802632	BF875A	4078 095570	VIKTOR YAKOVLEV	{"phone": "+70297574407"}
0005432802633	BF875A	9540 447841	TATYANA FROLOVA	{"email": "frolova-t_18041973@postgrespro.ru", "phone": "+70488996174"}
0005432802634	2720B7	2387 587351	LYUBOV FILATOVA	{"email": "filatovalyubov.071978@postgrespro.ru", "phone": "+70860979386"}
0005432802635	6CB653	6698 013952	NADEZHDA ANDREEVA	{"phone": "+70059246097"}
0005432802636	1ADC3D	7260 551739	PAVEL KUZNECOV	{"phone": "+70368850957"}
0005432802637	1ADC3D	8869 300170	SOFYA TROFIMOVA	{"phone": "+70947552641"}
0005432802638	8A21F5	7675 054413	NIKITA VASILEV	{"phone": "+70382643300"}
0005432802639	8A21F5	5584 028068	NAILYA NIKITINA	{"phone": "+70304130250"}
0005432802640	8A21F5	3839 552165	VALERIY BARANOV	{"phone": "+70722678971"}
0005432802641	56F697	6055 882645	GALINA SIDOROVA	{"phone": "+70604008129"}
0005432802642	A1D36B	5828 963208	NIKOLAY NOVIKOV	{"phone": "+70992234749"}
0005432802643	A1D36B	9912 634392	NADEZHDA FROLOVA	{"phone": "+70251518695"}
0005432816938	ECA0D7	0995 065689	DMITRIY KUZMIN	{"email": "kuzmin_d1965@postgrespro.ru", "phone": "+70710233387"}
0005432816939	F51D2C	2901 492158	NATALYA OSIPOVA	{"phone": "+70957864115"}
0005432816940	F51D2C	9049 720967	VALENTINA MARTYNOVA	{"email": "valentina-martynova.1971@postgrespro.ru", "phone": "+70694320679"}
0005432816941	606590	2351 742965	NATALYA FILIPPOVA	{"email": "filippova_n-27021970@postgrespro.ru", "phone": "+70269012572"}
0005432816942	606590	0378 335807	EKATERINA GAVRILOVA	{"email": "gavrilova_ekaterina.061967@postgrespro.ru", "phone": "+70804069200"}
0005432816943	AAA629	5966 265875	YURIY VASILEV	{"email": "vasilev.y-021981@postgrespro.ru", "phone": "+70417032761"}
0005432816944	AAA629	7844 124181	NIKOLAY DAVYDOV	{"email": "davydov.n.101974@postgrespro.ru", "phone": "+70084469463"}
0005432816945	7F0E21	8841 094140	EVGENIY MATVEEV	{"email": "matveev-evgeniy12081962@postgrespro.ru", "phone": "+70499680033"}
0005432816946	554340	6137 327628	VALENTINA KOLESNIKOVA	{"email": "kolesnikova.v21121973@postgrespro.ru", "phone": "+70548507053"}
0005432816947	81D8AF	2991 969910	ANDREY FILIPPOV	{"email": "andreyfilippov.01121963@postgrespro.ru", "phone": "+70080556739"}
0005432816948	5FE259	9881 136816	MARINA KUDRYASHOVA	{"email": "kudryashova_m.1974@postgrespro.ru", "phone": "+70528724576"}
0005432816949	E372E0	8422 497078	YULIYA VASILEVA	{"phone": "+70346720194"}
0005432816950	7FA26D	8639 093673	DENIS ALEKSEEV	{"phone": "+70956097995"}
0005432816951	7FA26D	8638 068676	TATYANA LOGINOVA	{"phone": "+70806262610"}
0005432816952	656C7C	1552 009423	ELENA DAVYDOVA	{"email": "davydova_e_1980@postgrespro.ru", "phone": "+70162361226"}
0005432816953	656C7C	0751 696544	EKATERINA IVANOVA	{"email": "ivanova_e-22071971@postgrespro.ru", "phone": "+70422390165"}
0005432816954	2AFE83	7061 316947	DMITRIY MELNIKOV	{"email": "d_melnikov1981@postgrespro.ru", "phone": "+70167717077"}
0005432816955	2AFE83	9237 588537	ILYA KUZMIN	{"email": "i_kuzmin-22101969@postgrespro.ru", "phone": "+70516167756"}
0005432816956	F7FFBA	5871 450036	ELVIRA NIKOLAEVA	{"email": "e-nikolaeva1976@postgrespro.ru", "phone": "+70742214034"}
0005432816957	DFF1DB	2827 223646	MAKSIM BORISOV	{"phone": "+70298697969"}
0005432816958	C25AAA	4348 133241	ANASTASIYA KARPOVA	{"email": "a-karpova_1976@postgrespro.ru", "phone": "+70857900445"}
0005432816959	C25AAA	2620 264521	OLGA KOZLOVA	{"phone": "+70646612197"}
0005432816960	30E270	2158 334952	OLEG PAVLOV	{"email": "pavlovoleg1982@postgrespro.ru", "phone": "+70115126548"}
0005432816961	30E270	5755 022384	MATVEY KUZNECOV	{"phone": "+70368495908"}
0005432816962	7FE22B	2731 638397	ALEKSANDRA MASLOVA	{"phone": "+70307857397"}
0005432816963	1061DD	2862 755273	KIRILL YAKOVLEV	{"email": "kirill-yakovlev17021979@postgrespro.ru", "phone": "+70040612586"}
0005432816964	A60039	6011 694032	TAISA KOROLEVA	{"email": "t_koroleva.1964@postgrespro.ru", "phone": "+70509482807"}
0005432816965	A7EBD4	4064 758761	OLGA SAVELEVA	{"email": "savelevao_1967@postgrespro.ru", "phone": "+70478739301"}
0005432816966	1F26A0	8602 133861	ALEKSANDR ISAEV	{"phone": "+70915708399"}
0005432816967	5A4F43	1341 716538	EKATERINA GERASIMOVA	{"email": "egerasimova.1968@postgrespro.ru", "phone": "+70375376906"}
0005432816968	89E185	7743 346322	RADIK PAVLOV	{"phone": "+70189966114"}
0005432816969	89E185	5578 489882	MARIYA ARKHIPOVA	{"phone": "+70187352905"}
0005432816970	EFAFEA	7523 217373	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-05121975@postgrespro.ru", "phone": "+70260729083"}
0005432816971	EFAFEA	3270 171934	YURIY SHEVCHENKO	{"phone": "+70435301052"}
0005432816972	90FA0D	3425 120911	VERA OVCHINNIKOVA	{"phone": "+70041640095"}
0005432816973	E07F87	6683 113958	PAVEL CHERNOV	{"email": "p-chernov-09061970@postgrespro.ru", "phone": "+70592058012"}
0005432816974	71F5C0	4964 965169	EVGENIY SCHERBAKOV	{"phone": "+70867324551"}
0005432816975	0503C1	4170 956446	ELENA KUDRYASHOVA	{"email": "e_kudryashova-18061973@postgrespro.ru", "phone": "+70104721446"}
0005432816976	0503C1	4812 641017	VALERIY VOROBEV	{"phone": "+70058278895"}
0005432816977	EAAF64	4826 316718	MILANA DMITRIEVA	{"phone": "+70136027635"}
0005432816978	F1C518	9286 722816	ARKADIY DAVYDOV	{"phone": "+70759281045"}
0005432816979	A89165	3534 545785	ARTEM ZAYCEV	{"phone": "+70062958815"}
0005432816980	E9E38E	7184 393459	OLGA POLYAKOVA	{"phone": "+70919706607"}
0005432816981	7E11D1	9721 010096	GENNADIY MOISEEV	{"email": "gennadiymoiseev-08051984@postgrespro.ru", "phone": "+70089725329"}
0005432816982	83CD5A	9776 519761	VALENTINA MAKAROVA	{"phone": "+70074632502"}
0005432816983	6AD116	8342 267103	NATALYA EGOROVA	{"phone": "+70560451570"}
0005432816984	6AD116	9647 787560	OLGA KOROLEVA	{"phone": "+70933132472"}
0005432816985	511938	3633 820025	ALEKSANDR POPOV	{"email": "popov_a04101975@postgrespro.ru", "phone": "+70840306388"}
0005432816986	511938	1163 274056	DMITRIY SEMENOV	{"phone": "+70035173818"}
0005432816987	8388FF	1622 226327	MIKHAIL IVANOV	{"email": "ivanovm.1970@postgrespro.ru", "phone": "+70272502177"}
0005432816988	8388FF	3333 725751	EVGENIY MAKSIMOV	{"phone": "+70203000616"}
0005432816989	5DBEB4	0534 581225	SERGEY KOZLOV	{"email": "kozlov_sergey_031970@postgrespro.ru", "phone": "+70338100874"}
0005432816990	5DBEB4	1973 067592	VALERIYA VASILEVA	{"phone": "+70344161010"}
0005432816991	130F0D	9890 636004	DMITRIY KUZNECOV	{"phone": "+70054297657"}
0005432816992	130F0D	2360 449229	GALINA KRASNOVA	{"phone": "+70898547768"}
0005432816993	6DA2D9	5651 522234	ELENA NAUMOVA	{"phone": "+70322756136"}
0005432816994	6DA2D9	3764 428930	EGOR KUZNECOV	{"email": "egor-kuznecov_1975@postgrespro.ru", "phone": "+70431761488"}
0005432816995	CAF345	5945 525067	ELENA MELNIKOVA	{"email": "melnikova-elena-13101976@postgrespro.ru", "phone": "+70067042050"}
0005432816996	B38AE7	0038 022190	VLADIMIR ZAKHAROV	{"email": "zakharov_v_1974@postgrespro.ru", "phone": "+70642009575"}
0005432816997	B38AE7	2522 875251	TAMARA KULIKOVA	{"phone": "+70960280897"}
0005432816998	A43EF5	0940 874682	MARINA MAKAROVA	{"phone": "+70879693344"}
0005432816999	A43EF5	5076 073455	SERGEY KUZMIN	{"email": "s-kuzmin26121981@postgrespro.ru", "phone": "+70459365504"}
0005432817000	A3FDF3	9873 259238	TAMARA STEPANOVA	{"email": "t_stepanova.1970@postgrespro.ru", "phone": "+70363190111"}
0005432817001	5B349A	0210 111669	SERGEY KUZNECOV	{"phone": "+70483312683"}
0005432817002	445415	2375 206446	VLADIMIR IVANOV	{"phone": "+70540110393"}
0005432817003	3B3C03	0986 067030	VLADIMIR MEDVEDEV	{"phone": "+70988109457"}
0005432817004	A5BB51	3509 028417	YULIYA KONDRATEVA	{"email": "y.kondrateva.1971@postgrespro.ru", "phone": "+70008729648"}
0005432817005	A5BB51	5094 663700	GALINA ANDREEVA	{"email": "andreeva_g_1964@postgrespro.ru", "phone": "+70512481497"}
0005432817006	6AA8F3	9821 846867	VIKTOR KUZNECOV	{"email": "kuznecovv_041976@postgrespro.ru", "phone": "+70868715465"}
0005432817007	5F7C6B	7469 302146	TATYANA ANTONOVA	{"phone": "+70794545871"}
0005432817008	9F1138	3111 409259	YURIY EGOROV	{"phone": "+70454714415"}
0005432817009	8CB6BA	4725 857762	LILIYA NIKOLAEVA	{"email": "nikolaeva_l_1963@postgrespro.ru", "phone": "+70036302906"}
0005432817010	D52CFC	8795 113905	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov041966@postgrespro.ru", "phone": "+70606471306"}
0005432817011	672DDB	9157 662778	VALERIYA VLASOVA	{"email": "valeriya_vlasova1969@postgrespro.ru", "phone": "+70191496379"}
0005432817012	A73008	6253 845013	NADEZHDA KUZNECOVA	{"email": "n.kuznecova.1964@postgrespro.ru", "phone": "+70275525959"}
0005432817013	A73008	1399 069128	LYUBOV IVANOVA	{"email": "l-ivanova-18071960@postgrespro.ru", "phone": "+70043597617"}
0005432817014	DFF06F	2632 091582	EVGENIY MOROZOV	{"email": "morozov-e_081983@postgrespro.ru", "phone": "+70468234709"}
0005432817015	12C4C0	4191 637394	ARTUR SCHERBAKOV	{"phone": "+70491169246"}
0005432817016	EEAF43	9374 082049	EKATERINA MIKHAYLOVA	{"email": "e_mikhaylova1966@postgrespro.ru", "phone": "+70578892025"}
0005432817074	433A5E	6118 231804	ARTUR NIKOLAEV	{"phone": "+70553489107"}
0005432817017	1EC516	5392 332770	ANASTASIYA EGOROVA	{"email": "egorova-anastasiya-1963@postgrespro.ru", "phone": "+70801072398"}
0005432817018	F16E86	0837 193945	DMITRIY SAVELEV	{"email": "savelevd-24021960@postgrespro.ru", "phone": "+70251870739"}
0005432817019	B046C7	2389 452516	NATALYA KOVALEVA	{"phone": "+70916026800"}
0005432817020	3F6CEC	7605 839759	ALEKSEY KARPOV	{"phone": "+70231907566"}
0005432817021	3F6CEC	9665 332876	MARINA MAKAROVA	{"email": "marinamakarova111970@postgrespro.ru", "phone": "+70530514548"}
0005432817022	32FE68	2131 709705	EVGENIY NAZAROV	{"email": "nazarov.evgeniy121972@postgrespro.ru", "phone": "+70867394997"}
0005432817023	B97961	1591 080562	ELENA ZOTOVA	{"email": "zotova-e_26111979@postgrespro.ru", "phone": "+70114209051"}
0005432817024	F6D236	8908 342076	ILYA MEDVEDEV	{"email": "medvedev_i_071981@postgrespro.ru", "phone": "+70120669634"}
0005432817025	EFCAF9	0845 750799	ELENA STEPANOVA	{"phone": "+70590213998"}
0005432817026	A3D79E	1605 351977	NINA KALININA	{"phone": "+70286113045"}
0005432817027	A3D79E	3902 696669	ROSTISLAV MOROZOV	{"phone": "+70917301995"}
0005432817028	8763CC	2831 649713	IGOR NAZAROV	{"email": "inazarov18041971@postgrespro.ru", "phone": "+70554210449"}
0005432817029	C41A81	6644 019739	GERMAN ALEKSEEV	{"email": "g_alekseev-1977@postgrespro.ru", "phone": "+70085332811"}
0005432817030	847279	8038 721108	VYACHESLAV TARASOV	{"email": "tarasov-vyacheslav1971@postgrespro.ru", "phone": "+70438530386"}
0005432817031	847279	5600 814740	EVGENIY FEDOTOV	{"phone": "+70156357850"}
0005432817032	847279	0202 217654	VALERIY KUZNECOV	{"email": "valeriy-kuznecov_1963@postgrespro.ru", "phone": "+70228731289"}
0005432817033	334C56	6160 953853	EVGENIY FEDOROV	{"phone": "+70335120658"}
0005432817034	E86590	1094 950343	NIKITA POPOV	{"phone": "+70353091973"}
0005432817035	5998EA	0481 756991	DANILA DMITRIEV	{"phone": "+70734891624"}
0005432817036	4E18D1	3295 426215	MARINA NIKOLAEVA	{"phone": "+70816728358"}
0005432817037	967A9E	5812 759148	BORIS ABRAMOV	{"email": "abramovb081967@postgrespro.ru", "phone": "+70644586505"}
0005432817038	8AEE7D	6116 286502	NURIYA ABRAMOVA	{"phone": "+70094493812"}
0005432817039	8AEE7D	5919 813252	VALENTINA NAZAROVA	{"phone": "+70081555429"}
0005432817040	D05B83	0472 707043	MIKHAIL AFANASEV	{"email": "mikhail_afanasev-1972@postgrespro.ru", "phone": "+70127183391"}
0005432817041	9A5202	8383 395915	ALBINA MOROZOVA	{"phone": "+70944989524"}
0005432817042	9A5202	7545 382900	TATYANA VLASOVA	{"phone": "+70668171307"}
0005432817043	D8A752	3412 604490	ANNA IVANOVA	{"email": "a_ivanova_1969@postgrespro.ru", "phone": "+70896657738"}
0005432817044	C74387	6907 867819	TATYANA MOROZOVA	{"email": "morozova_t051968@postgrespro.ru", "phone": "+70573634304"}
0005432817045	AC9353	9539 946628	KIRILL GORBUNOV	{"email": "gorbunov-kirill.031973@postgrespro.ru", "phone": "+70600308020"}
0005432817046	AC9353	2777 086122	ILYA POPOV	{"email": "popov-i1978@postgrespro.ru", "phone": "+70397732927"}
0005432817047	2B918F	8111 357484	EKATERINA VOLKOVA	{"phone": "+70400910750"}
0005432817048	5E4A20	6708 719640	SERGEY MOROZOV	{"phone": "+70069426674"}
0005432817049	5E4A20	7951 817619	SERGEY GERASIMOV	{"phone": "+70551729374"}
0005432817050	29FFE7	0359 294660	MARINA NIKITINA	{"phone": "+70251355157"}
0005432817051	29FFE7	8570 507891	KSENIYA KUDRYASHOVA	{"phone": "+70368488542"}
0005432817052	77EF17	7926 367919	ELIZAVETA IVANOVA	{"email": "ivanova.e.081964@postgrespro.ru", "phone": "+70479682503"}
0005432817053	B58675	2657 379282	VALERIYA MARTYNOVA	{"email": "valeriya-martynova.031981@postgrespro.ru", "phone": "+70955884059"}
0005432817054	B58675	3735 443899	MAKSIM OSIPOV	{"email": "osipov_m-1962@postgrespro.ru", "phone": "+70658164089"}
0005432817055	49D70A	6906 907349	SVETLANA ANISIMOVA	{"phone": "+70646581306"}
0005432817056	6A82C9	8028 716478	EDUARD SERGEEV	{"phone": "+70041216751"}
0005432817057	6A82C9	7284 565072	MARIYA NIKOLAEVA	{"phone": "+70460829280"}
0005432817058	31B5E8	2220 594543	ALEKSANDRA ANDREEVA	{"phone": "+70282975284"}
0005432817059	A45954	1761 206853	ANASTASIYA IVANOVA	{"phone": "+70838840970"}
0005432817060	A45954	0308 100093	SERGEY NIKOLAEV	{"email": "sergeynikolaev_22061976@postgrespro.ru", "phone": "+70208276350"}
0005432817061	140E80	1864 464756	OLGA KONDRATEVA	{"phone": "+70341551452"}
0005432817062	70072E	5292 261241	MARINA TARASOVA	{"email": "marina_tarasova_26111973@postgrespro.ru", "phone": "+70620884955"}
0005432817063	70072E	6421 487798	NADEZHDA LEBEDEVA	{"email": "n-lebedeva_1975@postgrespro.ru", "phone": "+70220691899"}
0005432817064	2864B6	4234 638481	VALENTIN FILIPPOV	{"phone": "+70107354092"}
0005432817065	B02AE5	0964 509902	GUZEL STEPANOVA	{"phone": "+70292900467"}
0005432817066	E43B53	6652 130524	ALLA NIKOLAEVA	{"email": "allanikolaeva_05021978@postgrespro.ru", "phone": "+70831808100"}
0005432817067	650F54	8901 612952	IRINA VOLKOVA	{"email": "volkova-i081963@postgrespro.ru", "phone": "+70391410958"}
0005432817068	508230	0949 050009	ALEKSANDR POPOV	{"email": "popov_a.15091979@postgrespro.ru", "phone": "+70388151960"}
0005432817069	17AEF5	9943 551930	ELENA VOROBEVA	{"phone": "+70388227264"}
0005432817070	17AEF5	9600 764473	LIDIYA IVANOVA	{"email": "livanova.1966@postgrespro.ru", "phone": "+70858882592"}
0005432817071	556E0B	8987 482694	VLADIMIR POPOV	{"email": "vladimir-popov.06091976@postgrespro.ru", "phone": "+70239184926"}
0005432817072	85A5DA	3833 369221	INNA MIRONOVA	{"phone": "+70409349182"}
0005432817073	B793ED	2611 022639	ALEKSANDR MAKAROV	{"phone": "+70350219702"}
0005432817075	433A5E	3041 677932	MIKHAIL MIRONOV	{"email": "mironovmikhail-1961@postgrespro.ru", "phone": "+70298708507"}
0005432817076	433A5E	7496 937544	EGOR SMIRNOV	{"email": "smirnov_e041970@postgrespro.ru", "phone": "+70198312470"}
0005432817077	E65B9F	4940 155049	TAMARA NIKOLAEVA	{"email": "tamaranikolaeva.1973@postgrespro.ru", "phone": "+70915789813"}
0005432817078	E65B9F	4331 731061	TATYANA SOKOLOVA	{"email": "tatyana_sokolova-10091970@postgrespro.ru", "phone": "+70981879202"}
0005432817079	E65B9F	2031 383310	VERA NOVIKOVA	{"phone": "+70882164099"}
0005432817080	E65B9F	8313 000892	ALEKSANDR KAZAKOV	{"email": "a.kazakov.011974@postgrespro.ru", "phone": "+70709878953"}
0005432817081	FF1EFC	7440 308907	ZINAIDA NAZAROVA	{"phone": "+70100570675"}
0005432817082	A80353	0127 837057	MARK FEDOTOV	{"phone": "+70007270306"}
0005432817083	A80353	4252 957988	NADEZHDA FILIPPOVA	{"phone": "+70829664949"}
0005432817084	EECA67	8543 726376	KSENIYA DENISOVA	{"email": "denisovak.081970@postgrespro.ru", "phone": "+70289232159"}
0005432817085	66D862	6539 598475	YURIY GRIGOREV	{"phone": "+70146281886"}
0005432817086	C66941	8542 396860	IRINA NIKITINA	{"phone": "+70859105343"}
0005432817087	2DCAD8	1738 685405	SERGEY GERASIMOV	{"email": "sergey-gerasimov-1974@postgrespro.ru", "phone": "+70308815708"}
0005432817088	2DCAD8	9047 891729	VERONIKA MAKAROVA	{"email": "veronika.makarova-1959@postgrespro.ru", "phone": "+70476991305"}
0005432817089	36AC60	9094 765121	ANASTASIYA ERMAKOVA	{"email": "a.ermakova_1959@postgrespro.ru", "phone": "+70597120203"}
0005432817090	20B164	9800 134384	VALENTINA MEDVEDEVA	{"email": "v.medvedeva28081966@postgrespro.ru", "phone": "+70222082060"}
0005432817091	4E3CC2	2626 297463	YULIYA SIDOROVA	{"email": "sidorova_y_021980@postgrespro.ru", "phone": "+70389655808"}
0005432817092	79EB88	6024 121785	ARTUR DMITRIEV	{"phone": "+70143002048"}
0005432817093	79EB88	2745 657460	LYUDMILA KUDRYASHOVA	{"email": "kudryashova-lyudmila_18051967@postgrespro.ru", "phone": "+70295285485"}
0005432817094	69309E	8847 348185	VALERIY NIKOLAEV	{"email": "nikolaev.valeriy081971@postgrespro.ru", "phone": "+70047721556"}
0005432817095	69309E	2748 521431	VALENTINA POPOVA	{"email": "valentinapopova_1991@postgrespro.ru", "phone": "+70928112924"}
0005432817096	1BD1E3	0150 933061	IVAN NAUMOV	{"email": "ivan.naumov_011979@postgrespro.ru", "phone": "+70157956414"}
0005432817097	4674BF	5610 186972	ALEKSEY NIKOLAEV	{"phone": "+70916224687"}
0005432817098	0D1EA2	4610 198944	IRINA LOGINOVA	{"phone": "+70194768549"}
0005432817099	0D1EA2	8460 518648	VADIM VOLKOV	{"email": "v-volkov_23031969@postgrespro.ru", "phone": "+70426245442"}
0005432817100	347544	6945 350024	VLADIMIR KRASNOV	{"email": "vladimir_krasnov-15011966@postgrespro.ru", "phone": "+70286579590"}
0005432817101	4383D4	2062 517610	ALEKSANDR ROMANOV	{"phone": "+70674218367"}
0005432817102	8D6630	1953 448209	NADEZHDA KOMAROVA	{"email": "komarova.nadezhda121981@postgrespro.ru", "phone": "+70850413900"}
0005432817103	8D6630	5759 314840	ANDREY ZHURAVLEV	{"phone": "+70360156649"}
0005432817104	BD9EA1	2887 906080	VALERIY VASILEV	{"phone": "+70898142235"}
0005432817105	885F43	7936 926230	MARGARITA SOKOLOVA	{"email": "msokolova14061965@postgrespro.ru", "phone": "+70845455634"}
0005432817106	885F43	9425 715042	ELENA ZAYCEVA	{"email": "elena_zayceva.061976@postgrespro.ru", "phone": "+70213565637"}
0005432817107	81DDE3	0567 010365	IGOR SIDOROV	{"email": "igor_sidorov_091966@postgrespro.ru", "phone": "+70211673637"}
0005432817108	81DDE3	4539 519642	VLADIMIR ORLOV	{"phone": "+70579876772"}
0005432817109	643E8F	7775 443288	VALENTINA KONOVALOVA	{"email": "konovalova_valentina_011965@postgrespro.ru", "phone": "+70829412766"}
0005432817110	DC8637	1581 977874	ZINAIDA IVANOVA	{"email": "ivanova.z.071971@postgrespro.ru", "phone": "+70977189962"}
0005432817111	69BE66	5672 530345	EKATERINA NOVIKOVA	{"email": "novikova.ekaterina.021975@postgrespro.ru", "phone": "+70753244730"}
0005432817112	628BB5	6742 023117	VIKTOR KUZNECOV	{"phone": "+70864801163"}
0005432817113	7EC2BF	8830 465165	IRINA IVANOVA	{"phone": "+70088390883"}
0005432817114	255966	5674 856822	GEORGIY NIKOLAEV	{"email": "g-nikolaev21091966@postgrespro.ru", "phone": "+70429076813"}
0005432817115	F6E52B	7808 406653	ANDREY SOROKIN	{"email": "asorokin_1968@postgrespro.ru", "phone": "+70397580557"}
0005432817116	E59D95	1449 493099	DARYA SOLOVEVA	{"phone": "+70926773090"}
0005432817117	C7DF14	3183 880477	TAMARA ZAKHAROVA	{"phone": "+70941883622"}
0005432817118	BB3B25	1750 196041	DMITRIY SMIRNOV	{"phone": "+70943702268"}
0005432817119	688A41	7305 242797	ANASTASIYA SOLOVEVA	{"email": "anastasiya.soloveva_26121974@postgrespro.ru", "phone": "+70705654534"}
0005432817120	A95477	6008 905257	SERGEY BORISOV	{"email": "borisov.s.05011976@postgrespro.ru", "phone": "+70535122187"}
0005432817121	BC25BE	5627 977741	VALERIY KULIKOV	{"phone": "+70091013015"}
0005432817122	BC25BE	5973 899096	ALEKSANDR CHERNOV	{"phone": "+70965286262"}
0005432817123	B22115	2668 381131	SERGEY FILIPPOV	{"phone": "+70556500108"}
0005432817124	7577F4	9866 723940	ALEKSANDR PETROV	{"email": "apetrov-1973@postgrespro.ru", "phone": "+70160055226"}
0005432817125	F8A65B	8004 691552	VYACHESLAV ZAYCEV	{"phone": "+70319461566"}
0005432817127	F8A65B	0595 715271	DMITRIY KRASNOV	{"email": "dmitriykrasnov-1962@postgrespro.ru", "phone": "+70418325467"}
0005432817128	4B51A6	4370 935834	IVAN KAZAKOV	{"email": "ikazakov_04091985@postgrespro.ru", "phone": "+70035239498"}
0005432817129	3E57AC	9251 566215	LYUDMILA BELYAEVA	{"email": "belyaevalyudmila.071978@postgrespro.ru", "phone": "+70509724423"}
0005432817130	3E57AC	7579 061357	GULNARA ZHURAVLEVA	{"phone": "+70620749040"}
0005432817131	EB62DC	2798 742810	GALINA FROLOVA	{"email": "gfrolova15071966@postgrespro.ru", "phone": "+70658338624"}
0005432817132	EB62DC	5173 453581	OLGA OSIPOVA	{"phone": "+70211059944"}
0005432817133	54A22C	7185 607705	DMITRIY SERGEEV	{"phone": "+70414706650"}
0005432817134	E2770A	6686 187604	ALEKSEY KUDRYASHOV	{"phone": "+70289771628"}
0005432817135	E2770A	9771 199449	NAILYA VASILEVA	{"email": "vasileva-nailya-28081978@postgrespro.ru", "phone": "+70682644937"}
0005432817136	7BFB19	7765 912175	GENNADIY SIDOROV	{"phone": "+70976623588"}
0005432817137	BF56A8	4111 487862	NADEZHDA KONOVALOVA	{"phone": "+70280738836"}
0005432817138	C281F9	1611 031036	ALEKSANDRA KISELEVA	{"phone": "+70109670854"}
0005432817139	BF0CDE	4095 672423	ANASTASIYA SMIRNOVA	{"phone": "+70893929493"}
0005432817140	BDEA9E	9696 290001	NATALIYA PETROVA	{"email": "petrova_nataliya12111972@postgrespro.ru", "phone": "+70874427282"}
0005432817141	BDEA9E	6080 881212	VASILIY FOMIN	{"phone": "+70136425495"}
0005432817142	1FA7F1	6830 691405	IRINA SEMENOVA	{"email": "i_semenova.121971@postgrespro.ru", "phone": "+70245562915"}
0005432817143	1FA7F1	4417 010549	IRINA NESTEROVA	{"email": "nesterova_i_1970@postgrespro.ru", "phone": "+70822634489"}
0005432817144	1FA7F1	0503 412959	NIKOLAY SOKOLOV	{"email": "nikolaysokolov1984@postgrespro.ru", "phone": "+70729056302"}
0005432817145	1FA7F1	1994 927069	ALINA KUZNECOVA	{"phone": "+70489578019"}
0005432817146	A40D87	4676 132072	SERGEY FROLOV	{"email": "s_frolov14051983@postgrespro.ru", "phone": "+70204450802"}
0005432817147	00E4FD	1912 313726	ALEKSANDR IVANOV	{"phone": "+70388572715"}
0005432817148	00E4FD	4267 751061	IRINA KUZNECOVA	{"email": "kuznecovairina1963@postgrespro.ru", "phone": "+70611088814"}
0005432817149	00E4FD	8238 042666	NIKOLAY SEMENOV	{"phone": "+70144123339"}
0005432817150	C6EA53	0681 407237	RAZIYA MOROZOVA	{"phone": "+70997950590"}
0005432817151	7F00A6	3903 997236	MIKHAIL KOZLOV	{"email": "kozlov-m.1965@postgrespro.ru", "phone": "+70778426256"}
0005432817152	5AA290	4404 360736	SERGEY NAUMOV	{"phone": "+70196399225"}
0005432817153	2A35D8	7888 468477	DARYA ANDREEVA	{"phone": "+70902789513"}
0005432817154	2A35D8	0648 051234	ALEKSANDR VOROBEV	{"phone": "+70812347275"}
0005432817155	0531F0	5157 481841	ANASTASIYA VASILEVA	{"email": "vasileva_anastasiya.31051979@postgrespro.ru", "phone": "+70046039302"}
0005432817156	422397	3943 465207	ALEKSANDR DENISOV	{"phone": "+70225046629"}
0005432817157	422397	4747 302328	SVETLANA ARKHIPOVA	{"email": "svetlanaarkhipova1972@postgrespro.ru", "phone": "+70427212166"}
0005432817158	50FEB8	3179 064152	SERGEY NAZAROV	{"phone": "+70090226550"}
0005432817159	50FEB8	4701 342792	VLADIMIR KOZLOV	{"email": "vkozlov_20011974@postgrespro.ru", "phone": "+70281547370"}
0005432817160	50FEB8	9349 749350	NIKOLAY ZHUKOV	{"phone": "+70302676084"}
0005432817161	FF3614	9731 457395	ELENA EGOROVA	{"email": "elena.egorova1967@postgrespro.ru", "phone": "+70703655404"}
0005432817162	FF3614	5662 733945	VLADIMIR MIRONOV	{"phone": "+70794665322"}
0005432817163	A4F057	8536 196792	GALINA KOZLOVA	{"email": "g-kozlova25121969@postgrespro.ru", "phone": "+70775670452"}
0005432817164	A4F057	0385 077592	TAMARA NOVIKOVA	{"email": "novikova_t_041976@postgrespro.ru", "phone": "+70171688132"}
0005432817165	E37B9A	8235 282968	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov.09031974@postgrespro.ru", "phone": "+70427402525"}
0005432817166	680299	5852 675116	VERA KAZAKOVA	{"phone": "+70634810460"}
0005432817167	9A195A	7012 679287	ELENA RYABOVA	{"phone": "+70034682953"}
0005432817168	9A195A	3512 952300	NATALYA GUSEVA	{"email": "n_guseva031965@postgrespro.ru", "phone": "+70110811210"}
0005432817169	51CFC4	7914 419869	EKATERINA VASILEVA	{"email": "evasileva1966@postgrespro.ru", "phone": "+70369264457"}
0005432817170	A20B06	4542 086206	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov_1975@postgrespro.ru", "phone": "+70931640049"}
0005432817171	A20B06	1058 864876	VIKTOR KUZMIN	{"email": "viktor-kuzmin.1973@postgrespro.ru", "phone": "+70903010288"}
0005432817172	3751E9	2710 347767	ZOYA ZOTOVA	{"email": "zotovazoya.061969@postgrespro.ru", "phone": "+70890330474"}
0005432817173	6F0B4C	5186 922607	VALERIYA DANILOVA	{"phone": "+70810190096"}
0005432817174	6F0B4C	5577 728016	IRINA FILIPPOVA	{"email": "ifilippova.1975@postgrespro.ru", "phone": "+70620485729"}
0005432817175	0AA229	6300 782030	SERGEY SIDOROV	{"phone": "+70560059072"}
0005432817176	0AA229	7138 350041	EVGENIY DAVYDOV	{"email": "e_davydov_071973@postgrespro.ru", "phone": "+70899238795"}
0005432817177	ED46E3	4004 340345	SERGEY TIMOFEEV	{"email": "s-timofeev_1974@postgrespro.ru", "phone": "+70489173783"}
0005432817178	A3F9C7	2513 582271	IRINA EFIMOVA	{"phone": "+70612221794"}
0005432817179	59EFCF	7270 803669	DENIS ILIN	{"email": "denis-ilin-15081973@postgrespro.ru", "phone": "+70461766279"}
0005432817180	756099	7527 831537	VALENTINA ANISIMOVA	{"phone": "+70750160131"}
0005432817181	D32EFD	3599 470291	NATALYA ARKHIPOVA	{"email": "natalya_arkhipova_081970@postgrespro.ru", "phone": "+70492244990"}
0005432817182	C4C4DA	6158 223819	ANASTASIYA SOLOVEVA	{"email": "anastasiyasoloveva.121973@postgrespro.ru", "phone": "+70847853915"}
0005432817183	C4C4DA	4892 310456	ANATOLIY ABRAMOV	{"email": "a-abramov.1971@postgrespro.ru", "phone": "+70958838103"}
0005432817184	ABB309	4451 319123	NINA SERGEEVA	{"phone": "+70703118170"}
0005432817185	E60F8A	9563 203762	EVGENIY SOROKIN	{"phone": "+70317251211"}
0005432817186	06F201	4616 643718	SVETLANA DMITRIEVA	{"email": "svetlana.dmitrieva.031969@postgrespro.ru", "phone": "+70356834318"}
0005432817187	D8D680	3972 496630	SVETLANA KOROLEVA	{"email": "s.koroleva.24051971@postgrespro.ru", "phone": "+70986700395"}
0005432817188	9F2139	4782 096458	ZHANNA KOZLOVA	{"email": "kozlova-zhanna-061965@postgrespro.ru", "phone": "+70634127936"}
0005432817189	6A7237	0089 611510	TATYANA ANISIMOVA	{"email": "anisimovatatyana-24081974@postgrespro.ru", "phone": "+70791806132"}
0005432817190	2E7B0C	4236 399335	ANNA BORISOVA	{"phone": "+70024970012"}
0005432817191	2E7B0C	2813 954628	MARIYA MATVEEVA	{"email": "matveevam1983@postgrespro.ru", "phone": "+70859073769"}
0005432817192	9F2D01	6227 773127	VLADIMIR IVANOV	{"email": "vladimir_ivanov_1979@postgrespro.ru", "phone": "+70541747772"}
0005432817193	4CE782	9213 570464	VLADIMIR KUZNECOV	{"email": "v-kuznecov_111975@postgrespro.ru", "phone": "+70252664759"}
0005432817194	97CBB1	6637 337095	RAISA VASILEVA	{"phone": "+70135224459"}
0005432817195	EDD64C	4934 483126	ALBINA MIRONOVA	{"email": "albina-mironova_021957@postgrespro.ru", "phone": "+70935945234"}
0005432817196	3B45F0	7719 514436	VALENTIN SMIRNOV	{"email": "valentinsmirnov_041977@postgrespro.ru", "phone": "+70086875224"}
0005432817197	36E25B	8286 311778	TATYANA ZHURAVLEVA	{"email": "t.zhuravleva-1968@postgrespro.ru", "phone": "+70819171396"}
0005432817198	36E25B	2010 716302	ALEKSANDRA YAKOVLEVA	{"phone": "+70943433217"}
0005432817199	11AD6D	1585 053059	VIKTOR MATVEEV	{"email": "matveev.viktor_14031973@postgrespro.ru", "phone": "+70818257205"}
0005432817200	7E921B	3149 920488	OLGA RYABOVA	{"phone": "+70401197586"}
0005432817201	7E921B	7124 790993	VIKTOR KISELEV	{"email": "viktor_kiselev021972@postgrespro.ru", "phone": "+70130251416"}
0005432817202	DB2A06	2136 656538	ALEKSANDR NIKITIN	{"phone": "+70656672643"}
0005432817203	71BF0F	1055 485946	ANDREY IVANOV	{"email": "ivanov-andrey-01031979@postgrespro.ru", "phone": "+70702391608"}
0005432817204	71BF0F	0981 229295	IRINA IVANOVA	{"email": "i_ivanova1976@postgrespro.ru", "phone": "+70686440025"}
0005432817205	FC887A	0000 692930	IVAN SEMENOV	{"phone": "+70581284747"}
0005432817206	6F4F4A	9603 668428	ANNA NIKIFOROVA	{"phone": "+70648386171"}
0005432817207	6AF9D5	4656 986145	MAYYA ZAYCEVA	{"email": "zayceva.m-1975@postgrespro.ru", "phone": "+70727306818"}
0005432817208	3059D2	8765 938194	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov071977@postgrespro.ru", "phone": "+70891684624"}
0005432817209	3059D2	0519 236392	IVAN SCHERBAKOV	{"phone": "+70598847337"}
0005432817210	7C7B92	2622 573483	ALEKSEY ILIN	{"phone": "+70235849528"}
0005432817211	7C7B92	3704 151486	OKSANA KOLESNIKOVA	{"phone": "+70327296903"}
0005432817212	3E8C72	8405 760514	VLADIMIR NIKITIN	{"phone": "+70878276508"}
0005432817213	94373E	5403 248329	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy01071971@postgrespro.ru", "phone": "+70987809508"}
0005432817214	94373E	9314 206621	OLEG POPOV	{"phone": "+70220499178"}
0005432817215	94373E	0971 957589	VALERIY ZAKHAROV	{"email": "v_zakharov1975@postgrespro.ru", "phone": "+70302777076"}
0005432817216	9F99E0	8785 951252	VALENTINA STEPANOVA	{"email": "stepanovav19121982@postgrespro.ru", "phone": "+70126820376"}
0005432817217	14E3BF	2661 152794	SERGEY KRASNOV	{"email": "krasnovsergey1964@postgrespro.ru", "phone": "+70539981538"}
0005432817218	992E92	6219 524949	YURIY BORISOV	{"phone": "+70926987381"}
0005432817219	D765F9	0984 165878	VERA ORLOVA	{"phone": "+70862469549"}
0005432817220	B2563D	2319 200556	ALEKSANDR BELOV	{"email": "belov-aleksandr.091972@postgrespro.ru", "phone": "+70156310935"}
0005432817221	7B32AB	9199 635700	OLGA MIRONOVA	{"email": "olga_mironova_22031973@postgrespro.ru", "phone": "+70472382062"}
0005432817222	A463B8	0043 790947	EKATERINA KONOVALOVA	{"email": "ekaterinakonovalova-22091975@postgrespro.ru", "phone": "+70556592102"}
0005432817223	A463B8	5500 286350	VIKTOR KULIKOV	{"email": "vkulikov1973@postgrespro.ru", "phone": "+70369917178"}
0005432817224	C4AA6E	6208 594360	ELENA KUZNECOVA	{"phone": "+70594411267"}
0005432817225	6D00A6	1206 885887	MARINA FEDOROVA	{"phone": "+70006802372"}
0005432817226	3946E9	0372 943543	TATYANA BELOVA	{"phone": "+70810751922"}
0005432817227	4BF1C9	2478 286097	VALERIY STEPANOV	{"phone": "+70059944313"}
0005432817228	7F0454	2800 695259	VITALIY DMITRIEV	{"email": "vitaliy_dmitriev29101981@postgrespro.ru", "phone": "+70493467730"}
0005432817229	7F0454	0184 993370	VLADIMIR KUZNECOV	{"phone": "+70382065142"}
0005432817230	BE40F1	7180 864582	ALEKSANDR FILIPPOV	{"phone": "+70045134740"}
0005432817231	84CF8D	9420 627287	YULIYA RYABOVA	{"phone": "+70869247492"}
0005432817232	1E1500	6717 045313	ELVIRA NIKITINA	{"email": "nikitina_elvira.10031978@postgrespro.ru", "phone": "+70460773586"}
0005432817233	1E1500	2753 948954	ALEKSANDR PETROV	{"email": "aleksandr_petrov111973@postgrespro.ru", "phone": "+70890084742"}
0005432817234	DCC253	4362 187317	VITALIY KAZAKOV	{"email": "vkazakov.091975@postgrespro.ru", "phone": "+70516893627"}
0005432817235	DCC253	9676 888240	ANDREY IVANOV	{"phone": "+70614519277"}
0005432817236	CDCE36	5841 668346	MARINA MEDVEDEVA	{"phone": "+70833086019"}
0005432817237	45A9AF	2776 311389	YULIYA KISELEVA	{"phone": "+70955647513"}
0005432817238	45A9AF	3453 383186	TATYANA MAKAROVA	{"phone": "+70415794896"}
0005432817239	DC48C3	8765 424561	NAIL SERGEEV	{"phone": "+70848693674"}
0005432817240	1C7252	3116 370537	DMITRIY NIKOLAEV	{"email": "nikolaev_dmitriy.1975@postgrespro.ru", "phone": "+70095883544"}
0005432817241	30CDFB	2108 177311	NINA IVANOVA	{"phone": "+70622202945"}
0005432817242	4239CD	8098 387189	IRINA MAKSIMOVA	{"email": "maksimovai.1983@postgrespro.ru", "phone": "+70660648231"}
0005432817243	20879C	3893 185365	ANASTASIYA KOZLOVA	{"email": "akozlova_1970@postgrespro.ru", "phone": "+70035482194"}
0005432817244	EC49A2	0853 253687	GALINA KONDRATEVA	{"email": "galina_kondrateva.1976@postgrespro.ru", "phone": "+70442944432"}
0005432817245	EC49A2	2186 453805	NINA STEPANOVA	{"email": "stepanova-nina-011977@postgrespro.ru", "phone": "+70065020445"}
0005432817363	CBB799	3857 440602	EKATERINA KISELEVA	{"phone": "+70042334195"}
0005432817246	EC49A2	9077 886176	YURIY FEDOROV	{"email": "fedorov_y_30081963@postgrespro.ru", "phone": "+70809232558"}
0005432817247	9ECC72	7354 874136	ALEKSANDR GRIGOREV	{"phone": "+70650085864"}
0005432817248	CE5007	5828 487111	ELENA SOKOLOVA	{"phone": "+70703947223"}
0005432817249	18E4E5	8419 961701	DANIIL MATVEEV	{"email": "d_matveev-1961@postgrespro.ru", "phone": "+70976933002"}
0005432817250	353689	2059 334355	VLADISLAV ORLOV	{"phone": "+70045994417"}
0005432817251	353689	8161 582586	ANATOLIY ZAYCEV	{"email": "a-zaycev.051978@postgrespro.ru", "phone": "+70785834015"}
0005432817252	7BAD7B	6502 277531	ALEKSEY MELNIKOV	{"phone": "+70182987988"}
0005432817253	1E3AAE	6750 245388	VLADIMIR GORBUNOV	{"phone": "+70716770066"}
0005432817254	F65664	8842 120346	TATYANA RYABOVA	{"phone": "+70603264092"}
0005432817255	B91AF4	2839 307879	ALEKSANDRA IVANOVA	{"email": "aleksandra-ivanova-1981@postgrespro.ru", "phone": "+70654492299"}
0005432817256	23BC48	3257 507489	ELIZAVETA ZHUKOVA	{"phone": "+70464315984"}
0005432817257	23BC48	4963 039155	DENIS GRIGOREV	{"email": "d.grigorev1980@postgrespro.ru", "phone": "+70855546493"}
0005432817258	9382AE	7112 886283	NIKITA KUZMIN	{"phone": "+70887015473"}
0005432817259	399860	9405 195234	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay1960@postgrespro.ru", "phone": "+70963874593"}
0005432817260	2996C4	7757 021761	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr_1954@postgrespro.ru", "phone": "+70325455247"}
0005432817261	D8ABAF	7293 628783	ANNA FOMINA	{"phone": "+70684887384"}
0005432817262	F80FFE	2156 587780	LYUDMILA ZHURAVLEVA	{"phone": "+70014868792"}
0005432817263	D78BB3	1927 279285	ILYA VASILEV	{"phone": "+70575100447"}
0005432817264	D78BB3	6057 872368	ILYA IVANOV	{"phone": "+70189222755"}
0005432817265	285E8D	2833 596118	ZINAIDA SEMENOVA	{"phone": "+70381818095"}
0005432817266	285E8D	0598 166687	TATYANA SIDOROVA	{"phone": "+70975082561"}
0005432817267	4B336C	1328 658983	TATYANA MOISEEVA	{"phone": "+70051245051"}
0005432817268	4B336C	1517 506424	ARSENIY NOVIKOV	{"phone": "+70733245429"}
0005432817269	EF10F2	7801 657149	ELVIRA ALEKSEEVA	{"email": "elviraalekseeva-1968@postgrespro.ru", "phone": "+70861187395"}
0005432817270	F7901F	3437 389446	ANASTASIYA BOGDANOVA	{"phone": "+70836574587"}
0005432817271	EDCF53	2722 808575	KARINA FEDOROVA	{"email": "k-fedorova.08081973@postgrespro.ru", "phone": "+70445602469"}
0005432817272	EDCF53	6134 301160	YULIYA OSIPOVA	{"phone": "+70858001774"}
0005432817273	A98820	6513 592219	VADIM ZAYCEV	{"phone": "+70560250407"}
0005432817274	A98820	5262 993462	ANDREY VASILEV	{"email": "vasilevandrey-041966@postgrespro.ru", "phone": "+70254419425"}
0005432817275	C216C1	5646 747564	EKATERINA MAKSIMOVA	{"phone": "+70223542570"}
0005432817276	6168DE	2391 402930	NIKOLAY KUZMIN	{"email": "nkuzmin_101975@postgrespro.ru", "phone": "+70553023106"}
0005432817277	B899D4	0608 593730	VALENTIN OSIPOV	{"email": "osipov_valentin.1979@postgrespro.ru", "phone": "+70503798820"}
0005432817278	B899D4	6223 884728	NIKOLAY KULIKOV	{"email": "n-kulikov-071974@postgrespro.ru", "phone": "+70642117190"}
0005432817279	B899D4	8581 179686	STEPAN CHERNOV	{"email": "s_chernov_11101966@postgrespro.ru", "phone": "+70115622025"}
0005432817280	2AD672	9499 340577	EKATERINA MOROZOVA	{"email": "ekaterina-morozova101968@postgrespro.ru", "phone": "+70711443288"}
0005432817281	2AD672	0604 958346	NIKOLAY SOKOLOV	{"phone": "+70107832937"}
0005432817282	B771FA	2233 440012	ANATOLIY VOLKOV	{"phone": "+70707847206"}
0005432817283	BC33DF	0628 616761	ANATOLIY KUZNECOV	{"phone": "+70369915879"}
0005432817284	BC33DF	2971 351869	TAKHIR FILIPPOV	{"email": "takhir-filippov.011973@postgrespro.ru", "phone": "+70380643371"}
0005432817285	B537FF	1815 084202	NIKOLAY KOZLOV	{"phone": "+70125121106"}
0005432817286	B537FF	6566 070725	OLESYA SERGEEVA	{"phone": "+70737198910"}
0005432817287	C781C9	9433 835948	FATIMA SAVELEVA	{"phone": "+70454709635"}
0005432817288	116213	1822 048500	TATYANA STEPANOVA	{"email": "stepanova-t.121963@postgrespro.ru", "phone": "+70861125417"}
0005432817289	7CE43B	3759 067919	ZINAIDA KONOVALOVA	{"email": "zinaida_konovalova-041972@postgrespro.ru", "phone": "+70726252992"}
0005432817290	9A977A	8903 381007	VIKTOR NOVIKOV	{"email": "novikovviktor_1974@postgrespro.ru", "phone": "+70827308322"}
0005432817291	9A977A	9092 648863	NATALYA IVANOVA	{"phone": "+70138210915"}
0005432817292	F313FF	0145 943238	NIKOLAY FOMIN	{"phone": "+70212090807"}
0005432817293	2C8785	4200 440892	SEMEN VLASOV	{"email": "semenvlasov-061978@postgrespro.ru", "phone": "+70520797624"}
0005432817294	775A46	4771 463057	EVGENIY SCHERBAKOV	{"email": "e_scherbakov26011972@postgrespro.ru", "phone": "+70758407685"}
0005432817295	BBECA8	2127 181532	VLADIMIR VLASOV	{"email": "vlasov.vladimir.21031996@postgrespro.ru", "phone": "+70763247213"}
0005432817296	997423	1051 990452	KIRILL STEPANOV	{"email": "kirill_stepanov.31121966@postgrespro.ru", "phone": "+70486138557"}
0005432817297	1A3A8C	9711 403207	NATALIYA KOZLOVA	{"email": "nataliya-kozlova.1954@postgrespro.ru", "phone": "+70633718592"}
0005432817298	16E8CA	1504 894727	OLGA BELOVA	{"email": "olga.belova_1959@postgrespro.ru", "phone": "+70783239246"}
0005432817299	AC6587	9376 863469	OLGA MELNIKOVA	{"phone": "+70894823580"}
0005432817300	C0C2CF	0738 198110	IVAN SMIRNOV	{"email": "ismirnov.01081964@postgrespro.ru", "phone": "+70056063053"}
0005432817301	503354	9750 735263	BORIS SERGEEV	{"email": "sergeev-boris10031961@postgrespro.ru", "phone": "+70636305015"}
0005432817302	BC3087	8444 587709	DMITRIY VOROBEV	{"phone": "+70516794285"}
0005432817303	DC0013	1471 305344	TIMUR IVANOV	{"email": "t_ivanov-29051965@postgrespro.ru", "phone": "+70741359211"}
0005432817304	C4AF42	5319 631690	VERA KUZMINA	{"phone": "+70791411117"}
0005432817305	C4AF42	9314 192030	GALINA MOROZOVA	{"phone": "+70329020695"}
0005432817306	D7F884	1565 830304	NADEZHDA PAVLOVA	{"email": "pavlova_n_11111970@postgrespro.ru", "phone": "+70536753304"}
0005432817307	D7F884	3902 709430	VERA FILIPPOVA	{"email": "verafilippova_1966@postgrespro.ru", "phone": "+70512037990"}
0005432817308	BC0779	1914 089176	NATALYA YAKOVLEVA	{"phone": "+70933044438"}
0005432817309	BC0779	3431 038012	EKATERINA NOVIKOVA	{"email": "ekaterina-novikova28031971@postgrespro.ru", "phone": "+70841807713"}
0005432817310	321D58	8640 884694	BORIS EGOROV	{"email": "begorov25121965@postgrespro.ru", "phone": "+70806796025"}
0005432817311	321D58	8225 904741	ALEKSANDR STEPANOV	{"email": "stepanova_061976@postgrespro.ru", "phone": "+70568444635"}
0005432817312	1475F5	6172 028172	GALINA KUZNECOVA	{"phone": "+70164245356"}
0005432817313	47AA3D	1281 977080	OLGA IVANOVA	{"email": "ivanova-o-101976@postgrespro.ru", "phone": "+70037158835"}
0005432817314	52CAE4	7268 421186	ELENA MAKAROVA	{"email": "elena_makarova081964@postgrespro.ru", "phone": "+70045804666"}
0005432817315	DA9614	8915 130009	VARVARA NESTEROVA	{"email": "nesterova-varvara.051967@postgrespro.ru", "phone": "+70000904669"}
0005432817316	BFF55A	0598 005546	RAISA DAVYDOVA	{"email": "davydovar1977@postgrespro.ru", "phone": "+70272488288"}
0005432817317	BFF55A	9573 369724	ELENA VASILEVA	{"phone": "+70478923516"}
0005432817318	7EDDB2	0833 129370	VLADIMIR PAVLOV	{"email": "pavlov.v-021970@postgrespro.ru", "phone": "+70882171749"}
0005432817319	7EDDB2	4912 706251	GENNADIY NAUMOV	{"email": "gnaumov.111972@postgrespro.ru", "phone": "+70810890394"}
0005432817320	7460E1	3931 203263	SERGEY ABRAMOV	{"phone": "+70929535529"}
0005432817321	479800	9844 461180	ANNA BOGDANOVA	{"phone": "+70375251374"}
0005432817322	479800	1358 664516	ALEKSEY KARPOV	{"email": "a.karpov_1975@postgrespro.ru", "phone": "+70286839240"}
0005432817323	70DD6E	7818 840515	VLADIMIR OSIPOV	{"email": "v_osipov.061973@postgrespro.ru", "phone": "+70319316035"}
0005432817324	70DD6E	2753 523894	ALLA ALEKSEEVA	{"email": "a-alekseeva.1967@postgrespro.ru", "phone": "+70132321438"}
0005432817325	D7C0BA	7315 816729	TIKHON EGOROV	{"phone": "+70033187259"}
0005432817326	E4FA9C	1398 197581	DARYA NIKOLAEVA	{"phone": "+70752803674"}
0005432817327	B10518	6954 044939	AYRAT VASILEV	{"email": "vasileva_051967@postgrespro.ru", "phone": "+70842295827"}
0005432817328	1976FC	6905 883756	ANASTASIYA MIRONOVA	{"email": "a_mironova-031971@postgrespro.ru", "phone": "+70505476829"}
0005432817329	8267A7	6952 034848	DMITRIY RODIONOV	{"email": "d.rodionov1971@postgrespro.ru", "phone": "+70318776925"}
0005432817330	CCAC3F	6101 423790	ANATOLIY VOLKOV	{"email": "volkov.a-08041968@postgrespro.ru", "phone": "+70120968016"}
0005432817331	F9F341	4278 103469	MARINA TIKHONOVA	{"phone": "+70537785896"}
0005432817332	84575D	9765 365852	NIKOLAY VASILEV	{"email": "nikolay-vasilev_1973@postgrespro.ru", "phone": "+70263659570"}
0005432817333	84575D	7736 701740	LYUBOV ARKHIPOVA	{"phone": "+70208040131"}
0005432817334	836920	6095 728795	DMITRIY FILIPPOV	{"email": "filippov-dmitriy.1985@postgrespro.ru", "phone": "+70860295588"}
0005432817335	836920	4368 337963	LEONID IVANOV	{"email": "leonid.ivanov11091975@postgrespro.ru", "phone": "+70316109379"}
0005432817336	44874C	0918 423782	NATALYA ARKHIPOVA	{"email": "arkhipova-n061968@postgrespro.ru", "phone": "+70816831928"}
0005432817337	44874C	5082 582599	GALINA PETROVA	{"phone": "+70149334895"}
0005432817338	EACF0A	8054 538415	VITALIY KAZAKOV	{"email": "vitaliy_kazakov_01031962@postgrespro.ru", "phone": "+70061303555"}
0005432817339	EACF0A	8450 221518	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr18121966@postgrespro.ru", "phone": "+70321422978"}
0005432817340	EACF0A	4638 504261	VERA POPOVA	{"email": "popova.v.1974@postgrespro.ru", "phone": "+70551090866"}
0005432817341	015897	4799 449699	YULIYA BORISOVA	{"email": "yuliya.borisova091987@postgrespro.ru", "phone": "+70716669032"}
0005432817342	6D8F18	6007 268715	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr_031975@postgrespro.ru", "phone": "+70138784528"}
0005432817399	F8777B	9362 161335	LYUBOV MAKAROVA	{"phone": "+70121063174"}
0005432817343	6D8F18	7296 114493	KONSTANTIN SCHERBAKOV	{"email": "scherbakov.k.20101965@postgrespro.ru", "phone": "+70638649544"}
0005432817344	1DC5B0	3286 744961	IRINA ILINA	{"email": "ilina-i.081976@postgrespro.ru", "phone": "+70147969466"}
0005432817345	1DC5B0	2709 587112	ALINA GRISHINA	{"email": "grishina-alina.081972@postgrespro.ru", "phone": "+70278623898"}
0005432817346	0282DE	3567 142545	VENERA LEBEDEVA	{"email": "lebedeva_venera_1972@postgrespro.ru", "phone": "+70201077500"}
0005432817347	0282DE	5023 723167	SERGEY POPOV	{"email": "sergey.popov.26041972@postgrespro.ru", "phone": "+70591579134"}
0005432817348	0282DE	7056 275438	IRINA OSIPOVA	{"phone": "+70678558855"}
0005432817349	C15DA7	3232 704661	ALEKSANDRA SOKOLOVA	{"email": "aleksandrasokolova1982@postgrespro.ru", "phone": "+70637660110"}
0005432817350	8E33F9	9206 012208	ELENA ISAEVA	{"email": "isaeva.elena24081976@postgrespro.ru", "phone": "+70540321808"}
0005432817351	8E33F9	1724 912515	MARIYA DMITRIEVA	{"email": "dmitrievam24081968@postgrespro.ru", "phone": "+70099145626"}
0005432817352	9BE31C	3235 483882	NIKITA KRASNOV	{"phone": "+70771279072"}
0005432817353	D1BD41	5337 965560	ZOYA MAKSIMOVA	{"email": "z_maksimova_081982@postgrespro.ru", "phone": "+70055716195"}
0005432817354	BFC1E0	6366 440754	EKATERINA KRASNOVA	{"email": "ekrasnova30051982@postgrespro.ru", "phone": "+70122317564"}
0005432817355	FE14EE	4351 355915	LYUBOV DMITRIEVA	{"phone": "+70618850030"}
0005432817356	6B1C9B	1249 063924	ELENA FEDOROVA	{"email": "fedorova-elena_01021963@postgrespro.ru", "phone": "+70632418256"}
0005432817357	6B1C9B	2308 110758	YULIYA NIKOLAEVA	{"email": "yuliya.nikolaeva051978@postgrespro.ru", "phone": "+70072954345"}
0005432817358	0B12E6	5066 844388	YANINA ZHUKOVA	{"phone": "+70716365141"}
0005432817359	F30AF2	4176 000309	SVETLANA MELNIKOVA	{"phone": "+70862662419"}
0005432817360	DB17DB	9042 121962	MIKHAIL FOMIN	{"email": "mikhailfomin_1986@postgrespro.ru", "phone": "+70591612517"}
0005432817361	A53BEA	9335 043281	MARIYA VLASOVA	{"email": "vlasova_mariya_12021974@postgrespro.ru", "phone": "+70815913489"}
0005432817362	A53BEA	5612 586353	ALEKSEY ROMANOV	{"phone": "+70647972250"}
0005432817364	C21589	8013 921796	MARIYA ORLOVA	{"email": "mariya-orlova.011976@postgrespro.ru", "phone": "+70074817645"}
0005432817365	F0A7E0	6945 994491	IRINA SERGEEVA	{"phone": "+70788591396"}
0005432817366	B52F6E	7339 841375	MIKHAIL CHERNOV	{"phone": "+70421179655"}
0005432817367	8239B4	8054 798635	ANNA ROMANOVA	{"phone": "+70729114886"}
0005432817368	799A10	2114 924130	OLEG MEDVEDEV	{"phone": "+70887067378"}
0005432817369	1AF832	1693 494167	VLADIMIR VLASOV	{"phone": "+70574988472"}
0005432817370	BB8933	8275 867032	EVGENIY TIMOFEEV	{"email": "timofeev-evgeniy021977@postgrespro.ru", "phone": "+70753545056"}
0005432817371	ADE4A2	9904 281463	MARGARITA ANTONOVA	{"phone": "+70572776932"}
0005432817372	ADE4A2	0417 436856	VLADISLAV KUZMIN	{"email": "kuzmin.vladislav.061973@postgrespro.ru", "phone": "+70609298733"}
0005432817373	927971	0393 180871	VLADIMIR BONDARENKO	{"email": "bondarenko.v-1979@postgrespro.ru", "phone": "+70107321596"}
0005432817374	922910	9536 907760	TATYANA KONDRATEVA	{"phone": "+70865874191"}
0005432817375	922910	2626 881128	ALEKSANDR SOROKIN	{"email": "sorokina-16011980@postgrespro.ru", "phone": "+70766959953"}
0005432817376	922910	8112 730752	OLEG MAKAROV	{"email": "o-makarov_09041976@postgrespro.ru", "phone": "+70829167659"}
0005432817377	09C400	6245 912979	TAMARA FEDOROVA	{"phone": "+70990765048"}
0005432817378	850CB8	1846 527288	IVAN KAZAKOV	{"email": "kazakovivan.071975@postgrespro.ru", "phone": "+70577647003"}
0005432817379	007BE6	9032 960747	EKATERINA MEDVEDEVA	{"phone": "+70045759510"}
0005432817380	C2A611	8653 520574	NATALYA NIKITINA	{"email": "nnikitina_061973@postgrespro.ru", "phone": "+70995413339"}
0005432817381	4EE4CE	1066 546593	VITALIY BELOV	{"email": "belov_vitaliy.011975@postgrespro.ru", "phone": "+70494555983"}
0005432817382	07EE48	9697 430828	ANDREY YAKOVLEV	{"phone": "+70565779473"}
0005432817383	8069CB	2753 468825	DENIS RODIONOV	{"email": "d_rodionov-031969@postgrespro.ru", "phone": "+70928493498"}
0005432817384	2897B7	1654 541089	SNEZHANA YAKOVLEVA	{"phone": "+70651879680"}
0005432817385	88D136	8757 418474	LYUDMILA BELOVA	{"phone": "+70441686988"}
0005432817386	0F9642	7687 894177	DARYA SEMENOVA	{"phone": "+70359835063"}
0005432817387	0F9642	6036 727633	YULIYA KAZAKOVA	{"phone": "+70560329566"}
0005432817388	F3E72C	0537 093813	ALEKSEY PETROV	{"phone": "+70211759590"}
0005432817389	B660C6	3026 511492	VLADIMIR KULIKOV	{"phone": "+70740971043"}
0005432817390	B660C6	4642 770740	NATALYA MOROZOVA	{"email": "morozova_n_031976@postgrespro.ru", "phone": "+70194000601"}
0005432817391	26483B	9415 151245	VASILIY SAVELEV	{"phone": "+70832077698"}
0005432817392	26483B	2070 490981	DENIS OSIPOV	{"email": "osipov_denis021982@postgrespro.ru", "phone": "+70754127739"}
0005432817393	26483B	8394 334808	EKATERINA MELNIKOVA	{"email": "e-melnikova-1966@postgrespro.ru", "phone": "+70132642577"}
0005432817394	31AF43	5267 730976	VLADIMIR TIMOFEEV	{"phone": "+70129626441"}
0005432817395	17966F	4437 405711	GENNADIY KUZNECOV	{"phone": "+70836347526"}
0005432817396	17966F	2900 697325	NATALYA ORLOVA	{"phone": "+70380519327"}
0005432817397	EFCA9C	7605 597468	NINA SEMENOVA	{"phone": "+70075799800"}
0005432817398	F8777B	9372 808696	TAMARA GERASIMOVA	{"email": "t-gerasimova.30061973@postgrespro.ru", "phone": "+70361233581"}
0005432817400	0B2BF2	9089 877867	EKATERINA EGOROVA	{"phone": "+70458248442"}
0005432817401	6A67E2	5682 534955	POLINA RYABOVA	{"email": "polinaryabova09121973@postgrespro.ru", "phone": "+70768569676"}
0005432817402	F3B7CE	7821 773955	SVETLANA SIDOROVA	{"phone": "+70624322021"}
0005432817403	F3B7CE	3503 091630	VIKTOR ZHUKOV	{"email": "zhukov-v-09021978@postgrespro.ru", "phone": "+70857320197"}
0005432817404	6928E2	5105 011313	PAVEL BONDARENKO	{"email": "p-bondarenko.1972@postgrespro.ru", "phone": "+70940386973"}
0005432817405	6928E2	7071 102015	SERGEY IVANOV	{"email": "ivanov-sergey.071980@postgrespro.ru", "phone": "+70757073883"}
0005432817406	68D4A1	0497 965374	SANIYA KOMAROVA	{"email": "komarova.saniya-31121969@postgrespro.ru", "phone": "+70459744812"}
0005432817407	7DFD22	5385 405215	VYACHESLAV DENISOV	{"phone": "+70600055681"}
0005432817408	076888	1229 663926	VIKTOR ORLOV	{"email": "orlov_viktor-1969@postgrespro.ru", "phone": "+70658494266"}
0005432817409	5439E4	4351 405961	ZINAIDA SMIRNOVA	{"phone": "+70504879441"}
0005432817410	6D94A7	4739 303937	IVAN ANTONOV	{"email": "antonov_i.29101974@postgrespro.ru", "phone": "+70384527024"}
0005432817411	6D94A7	5823 290413	YULIYA VASILEVA	{"email": "vasileva.y.101977@postgrespro.ru", "phone": "+70836880432"}
0005432817412	17C2AC	5023 107043	ELENA YUDINA	{"email": "elena-yudina.071987@postgrespro.ru", "phone": "+70633042165"}
0005432817413	4082A4	4927 613384	ANNA SEMENOVA	{"email": "semenova_a_031980@postgrespro.ru", "phone": "+70033547776"}
0005432817414	77CEDA	0360 904968	OLGA FROLOVA	{"phone": "+70404950302"}
0005432817415	77CEDA	0783 805319	VIKTORIYA STEPANOVA	{"phone": "+70643949271"}
0005432817416	98370D	4070 109296	ELENA FROLOVA	{"email": "frolovaelena10011971@postgrespro.ru", "phone": "+70393578006"}
0005432817417	05DF83	8886 236245	KONSTANTIN VOROBEV	{"phone": "+70848120829"}
0005432817418	496FDC	3362 870374	EVGENIY ANTONOV	{"phone": "+70149801735"}
0005432817419	496FDC	4492 812291	SVETLANA ANTONOVA	{"email": "antonova_svetlana.27111976@postgrespro.ru", "phone": "+70945641609"}
0005432817420	6C8748	2982 204185	RASHIT SHEVCHENKO	{"phone": "+70437127006"}
0005432817421	149ACA	5012 084323	ZHANNA KARPOVA	{"email": "zhannakarpova01081970@postgrespro.ru", "phone": "+70597496077"}
0005432817422	76490D	1254 686965	SERGEY KUZMIN	{"email": "kuzmin.s.1963@postgrespro.ru", "phone": "+70970120658"}
0005432817423	76490D	4067 868548	SERGEY OSIPOV	{"email": "osipov.s.1968@postgrespro.ru", "phone": "+70832825641"}
0005432817424	76490D	5717 113326	AMINA MELNIKOVA	{"email": "melnikova.a021974@postgrespro.ru", "phone": "+70989869160"}
0005432817425	109AAD	1143 847737	ANNA EGOROVA	{"email": "egorova-a.08091962@postgrespro.ru", "phone": "+70443465373"}
0005432817426	391108	6970 268569	LYUBOV KUZMINA	{"phone": "+70693474647"}
0005432817427	C2D4BD	0592 062626	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov111969@postgrespro.ru", "phone": "+70027321108"}
0005432817428	A455AB	7520 633456	VALENTINA RYABOVA	{"phone": "+70497975844"}
0005432817429	4F73BA	7494 869185	ANTON NIKITIN	{"email": "nikitina-1971@postgrespro.ru", "phone": "+70965301270"}
0005432817430	915A03	1819 870301	ALEVTINA ANDREEVA	{"phone": "+70818707962"}
0005432817431	12FD5C	3303 061346	TATYANA TROFIMOVA	{"phone": "+70554508454"}
0005432817432	9ADD5E	7949 882248	IRINA PETROVA	{"phone": "+70644904072"}
0005432817433	9ADD5E	2992 073142	ANTONINA GORBUNOVA	{"phone": "+70890381129"}
0005432817434	71B9F6	9188 359245	TAMARA PAVLOVA	{"email": "pavlova.t_1972@postgrespro.ru", "phone": "+70746056182"}
0005432817435	887A5F	6146 816544	EVDOKIYA GUSEVA	{"phone": "+70381889414"}
0005432817436	887A5F	3178 761342	LYUDMILA TITOVA	{"phone": "+70468362682"}
0005432817437	1EBBB1	8813 513816	DENIS SOLOVEV	{"phone": "+70364653924"}
0005432817438	945282	7452 503701	ELENA POPOVA	{"email": "e.popova_02031970@postgrespro.ru", "phone": "+70425254943"}
0005432817439	945282	4656 261662	ALEKSEY DAVYDOV	{"email": "davydov.aleksey-1986@postgrespro.ru", "phone": "+70394043150"}
0005432817440	C425B6	3409 359337	EVGENIY PAVLOV	{"phone": "+70619489993"}
0005432817441	822A83	2947 111142	DARYA AKIMOVA	{"email": "akimovadarya_29071973@postgrespro.ru", "phone": "+70228343452"}
0005432817442	822A83	9285 225618	SVETLANA KONDRATEVA	{"email": "kondrateva.svetlana091972@postgrespro.ru", "phone": "+70549946527"}
0005432817443	822A83	6972 812816	ZULFIYA PAVLOVA	{"phone": "+70512613219"}
0005432817444	59E658	2478 035777	KONSTANTIN NIKITIN	{"email": "nikitinkonstantin061968@postgrespro.ru", "phone": "+70647267487"}
0005432817445	59E658	6335 259857	IVAN TIMOFEEV	{"email": "ivan_timofeev.061956@postgrespro.ru", "phone": "+70843362490"}
0005432817446	8C3417	2839 928228	ELENA SIDOROVA	{"phone": "+70685173050"}
0005432817447	97BCD7	3445 572120	KRISTINA KULIKOVA	{"phone": "+70930848654"}
0005432817448	6687E0	4503 832468	ALIK SMIRNOV	{"email": "smirnov_alik_1971@postgrespro.ru", "phone": "+70205040327"}
0005432817449	6687E0	9194 910666	TATYANA KUZMINA	{"email": "t-kuzmina-04071978@postgrespro.ru", "phone": "+70786658339"}
0005432817450	9BACD3	5498 948749	VITALIY MOISEEV	{"email": "vitaliy.moiseev1966@postgrespro.ru", "phone": "+70494284313"}
0005432817451	93B253	6426 530893	ARKADIY IVANOV	{"email": "ivanov_arkadiy021983@postgrespro.ru", "phone": "+70618161377"}
0005432817452	CBFE9A	3813 148705	SERGEY KUZNECOV	{"phone": "+70593062822"}
0005432817453	3250A6	7795 237573	VALENTINA SMIRNOVA	{"email": "smirnova-valentina.111974@postgrespro.ru", "phone": "+70345433842"}
0005432817454	636A30	9131 298548	SVETLANA NESTEROVA	{"email": "nesterova.svetlana.10051971@postgrespro.ru", "phone": "+70746709594"}
0005432817681	067765	6086 524560	MAKSIM KRASNOV	{"phone": "+70337465540"}
0005432817455	99A973	1705 976181	TAMARA NOVIKOVA	{"email": "tamara.novikova.01081975@postgrespro.ru", "phone": "+70196306426"}
0005432817456	E6195B	6236 077016	IGOR KUZNECOV	{"email": "kuznecov.i-1970@postgrespro.ru", "phone": "+70160730775"}
0005432817457	A7FDF9	8433 878227	VALENTINA LEBEDEVA	{"email": "lebedevavalentina031974@postgrespro.ru", "phone": "+70709543013"}
0005432817458	744E5D	9267 609087	NATALYA PAVLOVA	{"phone": "+70989368337"}
0005432817459	132A0E	9360 594618	EVGENIY GRIGOREV	{"email": "evgeniy.grigorev_1974@postgrespro.ru", "phone": "+70647394792"}
0005432817460	132A0E	2285 692468	DENIS VOROBEV	{"email": "vorobev.d111979@postgrespro.ru", "phone": "+70751028085"}
0005432817461	5E7E8A	0128 997361	ALBERT ANTONOV	{"phone": "+70419755703"}
0005432817462	6FFEFD	2641 684345	VALENTINA TITOVA	{"email": "titovavalentina1967@postgrespro.ru", "phone": "+70447086540"}
0005432817463	9996DC	3974 123126	ANNA NOVIKOVA	{"email": "a_novikova.101968@postgrespro.ru", "phone": "+70443375359"}
0005432817464	840CA7	8010 105973	VALERIY ORLOV	{"email": "valeriyorlov.091971@postgrespro.ru", "phone": "+70848146087"}
0005432817465	3E572A	1491 610857	YURIY PAVLOV	{"phone": "+70219103651"}
0005432817466	3E572A	6213 932938	SERGEY KONOVALOV	{"email": "konovalovs_1966@postgrespro.ru", "phone": "+70100212379"}
0005432817467	E09F78	4875 816954	LILIYA BARANOVA	{"phone": "+70222825470"}
0005432817468	082A3B	0677 259827	MIKHAIL STEPANOV	{"phone": "+70689745422"}
0005432817469	082A3B	0736 478393	ALEKSANDR MAKSIMOV	{"phone": "+70266579156"}
0005432817470	082A3B	9422 378459	ANDREY STEPANOV	{"email": "andrey-stepanov.1970@postgrespro.ru", "phone": "+70343340190"}
0005432817471	00F07F	1849 630615	MAKSIM NAUMOV	{"phone": "+70678405607"}
0005432817472	7043CA	8787 196353	ELENA KUZNECOVA	{"phone": "+70812569879"}
0005432817473	7043CA	7135 165537	DMITRIY KRASNOV	{"phone": "+70868529539"}
0005432817474	BED292	4027 013679	POLINA ZHUKOVA	{"email": "zhukova-p_051972@postgrespro.ru", "phone": "+70071758219"}
0005432817475	BED292	4152 017141	TATYANA VOLKOVA	{"email": "volkovatatyana_02121977@postgrespro.ru", "phone": "+70718598627"}
0005432817476	257494	8468 545823	BORIS SMIRNOV	{"phone": "+70141748785"}
0005432817477	257494	3862 471091	VLADIMIR MAKAROV	{"phone": "+70974785697"}
0005432817478	951D95	9326 883116	MARIYA BARANOVA	{"email": "baranova_m-051970@postgrespro.ru", "phone": "+70998506070"}
0005432817479	706CB8	5401 673798	DANIIL MAKSIMOV	{"email": "maksimov.d.10091961@postgrespro.ru", "phone": "+70004614449"}
0005432817480	677C75	4012 437682	ANASTASIYA SIDOROVA	{"phone": "+70504134352"}
0005432817481	7ED1BA	5302 286620	TIMUR KOZLOV	{"phone": "+70473113769"}
0005432817482	CF6E41	6093 857308	VALERIY IVANOV	{"phone": "+70127835206"}
0005432817483	5F6203	8316 504922	GERMAN ANTONOV	{"phone": "+70105357955"}
0005432817544	76E79E	9234 475102	SHAMIL MIRONOV	{"phone": "+70238601493"}
0005432817484	EFDF94	6297 647286	VALENTINA SMIRNOVA	{"email": "valentina_smirnova_1961@postgrespro.ru", "phone": "+70270116827"}
0005432817485	EFDF94	8509 994101	IRINA VASILEVA	{"email": "irina-vasileva_121976@postgrespro.ru", "phone": "+70861771897"}
0005432817486	EFDF94	6861 263122	PAVEL RODIONOV	{"phone": "+70647204223"}
0005432817487	EFDF94	0669 773412	ALEKSANDR KISELEV	{"email": "a.kiselev091970@postgrespro.ru", "phone": "+70771540274"}
0005432817488	E1A3B8	2688 474003	OKSANA IVANOVA	{"email": "ivanovaoksana.1975@postgrespro.ru", "phone": "+70371321138"}
0005432817489	E12AD6	8389 119058	ANTON KOZLOV	{"phone": "+70384628588"}
0005432817490	AF29CB	3971 331120	ZINAIDA KOVALEVA	{"phone": "+70852945022"}
0005432817491	B9971C	1442 875056	OLESYA MIKHAYLOVA	{"email": "mikhaylova-o05021971@postgrespro.ru", "phone": "+70031414127"}
0005432817492	FA10EE	7913 563763	OKSANA FEDOROVA	{"email": "oksana-fedorova-14111972@postgrespro.ru", "phone": "+70437271220"}
0005432817493	AC96BD	1921 748404	ROZA GAVRILOVA	{"phone": "+70601992535"}
0005432817494	AC96BD	5376 450716	ANDREY ZAKHAROV	{"email": "a-zakharov.091974@postgrespro.ru", "phone": "+70165575103"}
0005432817495	7BD516	4815 217106	RUMIYA BARANOVA	{"email": "baranova_r_14051971@postgrespro.ru", "phone": "+70754319747"}
0005432817496	A8A41D	7905 989279	IVAN GRIGOREV	{"phone": "+70455965012"}
0005432817497	CE80F0	1575 794079	RUSLAN ZHUKOV	{"email": "zhukovr.22011963@postgrespro.ru", "phone": "+70382249233"}
0005432817498	EB6B48	3052 775661	SERGEY FROLOV	{"phone": "+70155971528"}
0005432817499	EB6B48	3724 606289	OLEG KISELEV	{"email": "okiselev_1968@postgrespro.ru", "phone": "+70679178971"}
0005432817500	9504A9	4902 692007	EVGENIYA ZAKHAROVA	{"email": "zakharova_evgeniya18111969@postgrespro.ru", "phone": "+70103595457"}
0005432817501	7CDE27	2128 436671	YURIY MAKSIMOV	{"email": "y_maksimov_24031977@postgrespro.ru", "phone": "+70061400817"}
0005432817502	559D7F	5612 911073	SERGEY GERASIMOV	{"phone": "+70429605894"}
0005432817503	315709	4279 965294	MARIYA DMITRIEVA	{"phone": "+70114299240"}
0005432817504	972CD3	3891 519436	TATYANA DMITRIEVA	{"phone": "+70781812837"}
0005432817505	972CD3	8549 458958	EVGENIY PETROV	{"phone": "+70899489236"}
0005432817506	4ECD68	2536 783512	ILDAR ZAKHAROV	{"phone": "+70351224871"}
0005432817507	6579A6	4908 307954	MARIYA IVANOVA	{"phone": "+70629726077"}
0005432817508	08A208	3606 265581	NADEZHDA PETROVA	{"phone": "+70402791351"}
0005432817509	E90948	2984 001796	IVAN SIDOROV	{"phone": "+70916733417"}
0005432817510	539D2B	6751 474217	DARYA BORISOVA	{"phone": "+70988701618"}
0005432817511	44558E	7073 444545	ELVIRA GORBUNOVA	{"phone": "+70084659536"}
0005432817512	A9E6F8	1335 704371	PAVEL BELOV	{"email": "belovpavel_21061972@postgrespro.ru", "phone": "+70401995798"}
0005432817513	5640C6	3623 859380	NATALYA GERASIMOVA	{"email": "n-gerasimova-1990@postgrespro.ru", "phone": "+70439864700"}
0005432817514	8390C3	1065 070203	EVGENIY MEDVEDEV	{"email": "evgeniy.medvedev091968@postgrespro.ru", "phone": "+70567472896"}
0005432817515	8390C3	8285 841367	VALENTINA GAVRILOVA	{"phone": "+70283134432"}
0005432817516	9964E8	7097 013748	ANATOLIY MEDVEDEV	{"phone": "+70265483901"}
0005432817517	9964E8	9613 216309	DMITRIY ISAEV	{"phone": "+70760586915"}
0005432817518	6F3277	1637 701049	VIKTOR VASILEV	{"phone": "+70877872155"}
0005432817519	AE0B60	0326 779100	DENIS CHERNOV	{"email": "denis.chernov061974@postgrespro.ru", "phone": "+70065250131"}
0005432817520	CB84DE	4988 098311	VALENTINA GUSEVA	{"email": "v_guseva_1962@postgrespro.ru", "phone": "+70538062964"}
0005432817521	CB84DE	8345 273802	NIKOLAY KRASNOV	{"email": "krasnov-n.1971@postgrespro.ru", "phone": "+70247178174"}
0005432817522	751378	3464 453242	MIKHAIL ALEKSEEV	{"email": "m-alekseev_1967@postgrespro.ru", "phone": "+70959844390"}
0005432817523	751378	8515 510670	EKATERINA KUDRYASHOVA	{"phone": "+70677234059"}
0005432817524	E68E3E	8524 054954	NIKOLAY POPOV	{"phone": "+70072040147"}
0005432817525	83D756	9167 451734	MARGARITA MARTYNOVA	{"email": "margarita-martynova071980@postgrespro.ru", "phone": "+70964236351"}
0005432817526	9950EB	4172 815373	SERGEY ALEKSANDROV	{"email": "sergeyaleksandrov.121965@postgrespro.ru", "phone": "+70187385551"}
0005432817527	4C53FF	0053 186627	LYUBOV ZAYCEVA	{"email": "lyubov_zayceva111975@postgrespro.ru", "phone": "+70263321948"}
0005432817528	4C53FF	8380 323530	ANDREY RODIONOV	{"email": "arodionov-051975@postgrespro.ru", "phone": "+70907817378"}
0005432817529	7428BD	7017 867220	EKATERINA KISELEVA	{"email": "kiselevae-091975@postgrespro.ru", "phone": "+70867722404"}
0005432817530	C5C463	0350 100340	DIANA SCHERBAKOVA	{"phone": "+70269868635"}
0005432817531	C5C463	1913 036238	RUSLAN FOMIN	{"email": "fominruslan07021968@postgrespro.ru", "phone": "+70755389991"}
0005432817532	863EEF	2646 515238	LIDIYA SOKOLOVA	{"email": "lsokolova031986@postgrespro.ru", "phone": "+70355698222"}
0005432817533	863EEF	8393 597642	ELENA GERASIMOVA	{"phone": "+70406529977"}
0005432817534	681DBE	1692 780788	ALEKSEY ANTONOV	{"phone": "+70354668456"}
0005432817535	4E35B0	4259 641492	ALSU MIKHAYLOVA	{"email": "mikhaylova-a_1967@postgrespro.ru", "phone": "+70005551574"}
0005432817536	4E35B0	6849 415807	NADEZHDA NAZAROVA	{"phone": "+70823136819"}
0005432817537	0FB5D9	0850 330889	DENIS MOISEEV	{"email": "d.moiseev1980@postgrespro.ru", "phone": "+70686125266"}
0005432817538	CF1152	0683 038555	OLEG FROLOV	{"email": "frolovoleg-19091961@postgrespro.ru", "phone": "+70514727725"}
0005432817539	C53E65	7362 237881	FAINA FILATOVA	{"email": "f_filatova30111968@postgrespro.ru", "phone": "+70157174095"}
0005432817540	08C319	2649 371931	MIKHAIL EGOROV	{"phone": "+70309612139"}
0005432817541	08C319	8035 132650	LYUDMILA ANDREEVA	{"email": "l.andreeva1980@postgrespro.ru", "phone": "+70006578426"}
0005432817542	6AF993	6894 083690	EVGENIY VOROBEV	{"phone": "+70292213477"}
0005432817543	415930	1978 794834	NIKOLAY POPOV	{"email": "nikolay-popov01071980@postgrespro.ru", "phone": "+70653737210"}
0005432817545	76E79E	4656 498703	IRINA NIKOLAEVA	{"email": "i_nikolaeva1968@postgrespro.ru", "phone": "+70585665934"}
0005432817546	B61B10	1891 584512	VALENTINA SMIRNOVA	{"email": "smirnova-valentina_061985@postgrespro.ru", "phone": "+70725577542"}
0005432817547	B61B10	8640 739731	OLGA ORLOVA	{"phone": "+70274161378"}
0005432817548	1CF080	6621 440926	TAMARA PETROVA	{"email": "t.petrova1969@postgrespro.ru", "phone": "+70697074740"}
0005432817549	1CF080	6788 597791	VADIM VASILEV	{"phone": "+70305888060"}
0005432817550	BEDE3F	8955 546829	ROMAN FEDOROV	{"phone": "+70635267180"}
0005432817551	BEDE3F	2338 482789	ARKADIY YAKOVLEV	{"phone": "+70290507931"}
0005432817552	10D693	0534 467845	MARINA FILIPPOVA	{"phone": "+70600092460"}
0005432817553	4A364A	7789 630708	VARVARA SCHERBAKOVA	{"email": "vscherbakova-1961@postgrespro.ru", "phone": "+70736957467"}
0005432817554	01ADBE	9286 051116	VIKTORIYA SOKOLOVA	{"phone": "+70592215194"}
0005432817555	6FCB15	8912 374342	MAKSIM KOROLEV	{"phone": "+70676170222"}
0005432817556	6FCB15	9491 018442	VALENTINA MALYSHEVA	{"phone": "+70060240313"}
0005432817557	B5F2F5	1050 596568	NIKOLAY SCHERBAKOV	{"email": "scherbakov-n_091972@postgrespro.ru", "phone": "+70775903032"}
0005432817558	B5F2F5	4994 665674	DMITRIY PETROV	{"email": "petrov_d-15121977@postgrespro.ru", "phone": "+70261393912"}
0005432817559	DBD021	8325 362799	NATALYA SOLOVEVA	{"email": "soloveva-n-1964@postgrespro.ru", "phone": "+70255810390"}
0005432817560	DBD021	4140 292151	ILYA GUSEV	{"email": "ilya-gusev_09091966@postgrespro.ru", "phone": "+70794653612"}
0005432817561	B01299	8823 032616	SERGEY MAKSIMOV	{"phone": "+70200646788"}
0005432817562	B01299	9814 312161	VADIM ILIN	{"phone": "+70404525318"}
0005432817563	9567AF	2571 103533	IRINA KULIKOVA	{"email": "kulikova_i30091963@postgrespro.ru", "phone": "+70249793260"}
0005432817564	38C655	2180 005713	SERGEY ZAKHAROV	{"phone": "+70009417021"}
0005432817565	1344F4	8247 286576	EVGENIY VOLKOV	{"email": "evgeniy_volkov_011970@postgrespro.ru", "phone": "+70177800178"}
0005432817566	1344F4	4973 434385	MARINA BORISOVA	{"phone": "+70853343361"}
0005432817567	1344F4	8535 750578	ANNA ILINA	{"email": "ilina.anna071984@postgrespro.ru", "phone": "+70220824276"}
0005432817568	3A4F26	2119 719570	VASILIY RODIONOV	{"email": "rodionov.vasiliy111970@postgrespro.ru", "phone": "+70379031788"}
0005432817569	76FD5D	3589 749642	TATYANA ISAEVA	{"phone": "+70891742136"}
0005432817570	215D65	4541 439692	STEPAN FOMIN	{"email": "s_fomin-22081964@postgrespro.ru", "phone": "+70347977686"}
0005432817571	215D65	9030 996194	YURIY KUZNECOV	{"phone": "+70719303497"}
0005432817572	707B8F	9057 860051	ELENA ZAKHAROVA	{"email": "zakharovaelena-06111960@postgrespro.ru", "phone": "+70676202402"}
0005432817573	E062BD	3240 653479	NADEZHDA SOKOLOVA	{"phone": "+70723920306"}
0005432817574	43FDC2	9551 223666	IRINA MASLOVA	{"phone": "+70379958369"}
0005432817575	43FDC2	7114 513723	EVGENIY ZAKHAROV	{"email": "e.zakharov.081973@postgrespro.ru", "phone": "+70849374647"}
0005432817576	F7CDCC	5838 275630	EVGENIY RODIONOV	{"email": "erodionov.061975@postgrespro.ru", "phone": "+70908599270"}
0005432817577	675F1B	6442 547451	VALENTINA BORISOVA	{"phone": "+70835689369"}
0005432817578	CB5BA1	2094 688134	ARTEM SEMENOV	{"email": "semenov_artem_25071973@postgrespro.ru", "phone": "+70074610429"}
0005432817579	A8F43E	8529 008897	YULIYA FILATOVA	{"email": "y-filatova27011962@postgrespro.ru", "phone": "+70303937281"}
0005432817580	743513	1361 994614	ANDREY NAZAROV	{"email": "a-nazarov_20101968@postgrespro.ru", "phone": "+70997774117"}
0005432817581	D8F962	8962 157576	IRINA ANTONOVA	{"email": "i_antonova-1979@postgrespro.ru", "phone": "+70309586731"}
0005432817582	DD2C95	4295 148282	ELENA KRASNOVA	{"phone": "+70050364950"}
0005432817583	443004	3174 973175	ANNA SERGEEVA	{"phone": "+70477144578"}
0005432817584	0673A2	7726 610714	VLADIMIR MAKAROV	{"email": "vmakarov.1967@postgrespro.ru", "phone": "+70898402312"}
0005432817585	D32EEB	8989 893714	TATYANA KOROLEVA	{"phone": "+70233523768"}
0005432817586	D826AA	7310 660988	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy_111980@postgrespro.ru", "phone": "+70668090960"}
0005432817587	D826AA	3086 106228	ELENA ZHURAVLEVA	{"phone": "+70001201747"}
0005432817588	E1795E	4439 085361	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva-lyudmila111980@postgrespro.ru", "phone": "+70281840089"}
0005432817589	C9DCA2	1850 438460	KONSTANTIN MAKSIMOV	{"email": "maksimov-konstantin_1965@postgrespro.ru", "phone": "+70202028962"}
0005432817590	9DF1CC	2594 989712	ALEKSANDR MATVEEV	{"phone": "+70173344411"}
0005432817591	9DF1CC	5356 696604	ROMAN DMITRIEV	{"email": "dmitriev-roman_1978@postgrespro.ru", "phone": "+70408122041"}
0005432817592	9DF1CC	7868 152297	YURIY FEDOROV	{"phone": "+70816647897"}
0005432817593	CCF8F1	6003 344475	LYUBOV LAZAREVA	{"phone": "+70537509001"}
0005432817594	CCF8F1	0290 245861	KSENIYA EGOROVA	{"phone": "+70973654861"}
0005432817595	AFF2CE	1433 051021	ALEKSANDRA IVANOVA	{"email": "a-ivanova-1980@postgrespro.ru", "phone": "+70120538613"}
0005432817596	7AE8D4	1490 405284	ALESYA KOZLOVA	{"phone": "+70383173802"}
0005432817597	8DE36F	8005 294768	NARIMAN FROLOV	{"email": "n-frolov-051971@postgrespro.ru", "phone": "+70836548971"}
0005432817598	460D7C	4690 628455	NATALYA ILINA	{"email": "natalya_ilina.24021967@postgrespro.ru", "phone": "+70848943670"}
0005432817599	F31F85	2713 328185	ALEKSEY IVANOV	{"phone": "+70404891527"}
0005432817600	F31F85	1385 116573	ZINAIDA POTAPOVA	{"email": "potapova_zinaida_1961@postgrespro.ru", "phone": "+70716237649"}
0005432817601	9CAD3B	2688 867854	ALEKSANDRA FILATOVA	{"phone": "+70113344510"}
0005432817602	173D3A	3751 016455	VLADIMIR KISELEV	{"phone": "+70900089058"}
0005432817603	610CB9	3359 641037	VLADIMIR NIKOLAEV	{"email": "nikolaev.v_14031981@postgrespro.ru", "phone": "+70793876372"}
0005432817604	24900D	2718 006595	AMINA DAVYDOVA	{"phone": "+70796149903"}
0005432817605	24900D	8042 434985	KARIM TARASOV	{"phone": "+70698399871"}
0005432817606	17262E	6404 651169	ELENA VASILEVA	{"phone": "+70784919594"}
0005432817607	17262E	0174 153010	TATYANA KULIKOVA	{"email": "kulikova-tatyana_1982@postgrespro.ru", "phone": "+70887525347"}
0005432817608	17262E	4376 940546	MARINA BARANOVA	{"email": "baranova-m_1979@postgrespro.ru", "phone": "+70918725916"}
0005432817609	A6492C	3359 181878	DANILA ROMANOV	{"phone": "+70169663613"}
0005432817610	0BFBB6	0834 770524	ALEKSANDR SEMENOV	{"email": "asemenov-021970@postgrespro.ru", "phone": "+70562648787"}
0005432817611	0BFBB6	1392 693151	BORIS IVANOV	{"phone": "+70726840619"}
0005432817612	5C6653	4050 619575	LYUBOV ZAKHAROVA	{"email": "zakharovalyubov1968@postgrespro.ru", "phone": "+70351087458"}
0005432817613	5C6653	4773 947116	SERGEY DAVYDOV	{"phone": "+70974597366"}
0005432817614	34160D	4491 057877	ROMAN OSIPOV	{"email": "osipov.r20121977@postgrespro.ru", "phone": "+70692965868"}
0005432817615	E3768D	1563 509047	STANISLAV GAVRILOV	{"email": "stanislav-gavrilov-1981@postgrespro.ru", "phone": "+70749563051"}
0005432817616	E3768D	6497 371307	VYACHESLAV KAZAKOV	{"email": "vyacheslav-kazakov-051970@postgrespro.ru", "phone": "+70929926084"}
0005432817617	7E84C3	0557 629480	MARINA ANISIMOVA	{"phone": "+70470758271"}
0005432817618	7E84C3	3446 009503	RIMMA BOGDANOVA	{"email": "bogdanova-rimma23051978@postgrespro.ru", "phone": "+70494851551"}
0005432817619	BC272A	7017 535178	PAVEL MOROZOV	{"phone": "+70317869226"}
0005432817620	480CBC	8003 840051	OLGA FEDOROVA	{"phone": "+70776872093"}
0005432817621	E9680E	3632 578975	MILENA TITOVA	{"email": "titova-m-24041972@postgrespro.ru", "phone": "+70278005232"}
0005432817622	C09670	7836 754665	ANASTASIYA KOMAROVA	{"email": "a_komarova.23121978@postgrespro.ru", "phone": "+70060368938"}
0005432817623	C9A6F3	1577 195149	KONSTANTIN ROMANOV	{"phone": "+70565072411"}
0005432817624	C9A6F3	6447 842819	LYUDMILA EGOROVA	{"email": "lyudmila_egorova.031963@postgrespro.ru", "phone": "+70639452262"}
0005432817625	F9EE2D	3233 679784	KIRA KONDRATEVA	{"phone": "+70911571694"}
0005432817626	2EF5F4	5569 547094	SEMEN DENISOV	{"phone": "+70327587178"}
0005432817627	4EF18F	9325 983929	VASILISA KONDRATEVA	{"phone": "+70606802675"}
0005432817628	AD85C7	3883 524751	NATALYA ZHURAVLEVA	{"phone": "+70206830598"}
0005432817629	80A276	2454 606449	VIKTOR SOKOLOV	{"email": "v.sokolov_031958@postgrespro.ru", "phone": "+70048219277"}
0005432817630	80A276	6060 992500	VIKTOR OSIPOV	{"phone": "+70811007372"}
0005432817631	918892	4131 632181	ALEKSANDR POPOV	{"email": "a-popov.1974@postgrespro.ru", "phone": "+70145239627"}
0005432817632	FE3369	2265 076618	KSENIYA FROLOVA	{"email": "frolova_kseniya26101979@postgrespro.ru", "phone": "+70678731426"}
0005432817633	FE3369	1885 073899	ANDREY BORISOV	{"phone": "+70667353656"}
0005432817634	61F273	0655 934546	TATYANA PETROVA	{"email": "tatyana_petrova1967@postgrespro.ru", "phone": "+70681091195"}
0005432817635	CCAEC9	2886 632232	ANNA BELOVA	{"phone": "+70883958399"}
0005432817636	290A6D	8457 588900	TAISIYA PETROVA	{"phone": "+70673337736"}
0005432817637	BF196C	2535 801368	LYUDMILA TIKHONOVA	{"phone": "+70452412675"}
0005432817638	6C3395	5825 419928	ELIZAVETA FEDOROVA	{"email": "e-fedorova-26101975@postgrespro.ru", "phone": "+70121596368"}
0005432817639	6C3395	6728 149415	LIDIYA KRASNOVA	{"phone": "+70702678947"}
0005432817640	F83CA6	2846 379596	IRINA POTAPOVA	{"email": "irina_potapova_10111959@postgrespro.ru", "phone": "+70751690415"}
0005432817641	13978B	9157 217503	TATYANA SOKOLOVA	{"email": "tatyanasokolova-01091975@postgrespro.ru", "phone": "+70780169981"}
0005432817642	13978B	9184 697751	ELENA SMIRNOVA	{"email": "esmirnova-111976@postgrespro.ru", "phone": "+70416403778"}
0005432817643	75FC53	4585 879913	IVAN GUSEV	{"email": "i.gusev-111969@postgrespro.ru", "phone": "+70981384925"}
0005432817644	75FC53	4244 404668	SVYATOSLAV KISELEV	{"email": "s_kiselev_15111970@postgrespro.ru", "phone": "+70260420887"}
0005432817645	1D959F	7400 725787	MIKHAIL NIKITIN	{"phone": "+70264378201"}
0005432817646	1D959F	0269 883838	OKSANA MOROZOVA	{"phone": "+70316243854"}
0005432817647	04684D	4228 405711	NIKOLAY NOVIKOV	{"email": "n-novikov.1967@postgrespro.ru", "phone": "+70710161058"}
0005432817648	1FBA17	7720 949704	LARISA ILINA	{"email": "ilina-l1975@postgrespro.ru", "phone": "+70329700172"}
0005432817649	1FBA17	7051 881214	ANATOLIY VOLKOV	{"phone": "+70834852968"}
0005432817650	1FBA17	4945 986072	YURIY VOLKOV	{"email": "yvolkov_22061970@postgrespro.ru", "phone": "+70034436408"}
0005432817651	0A0CA5	9150 753298	YURIY ALEKSANDROV	{"email": "aleksandrov_y_1972@postgrespro.ru", "phone": "+70261962862"}
0005432817652	0A0CA5	1423 264546	OKSANA MELNIKOVA	{"email": "melnikova.o_1978@postgrespro.ru", "phone": "+70593894996"}
0005432817653	CC2BCB	4355 416793	IVAN DENISOV	{"phone": "+70666113336"}
0005432817654	CC2BCB	4222 109735	VALERIY FOMIN	{"phone": "+70545232929"}
0005432817655	CC2BCB	1356 527532	ALENA ALEKSANDROVA	{"phone": "+70218025028"}
0005432817656	22D896	0635 057140	ELIZAVETA ILINA	{"email": "elizaveta.ilina20071960@postgrespro.ru", "phone": "+70628375281"}
0005432817657	6713B3	3886 113383	VYACHESLAV VLASOV	{"phone": "+70731104132"}
0005432817658	5FFD53	8922 779772	NATALYA PAVLOVA	{"phone": "+70600636795"}
0005432817659	188C13	1834 021855	ANASTASIYA FILIPPOVA	{"email": "filippova.a_081966@postgrespro.ru", "phone": "+70329096440"}
0005432817660	B8F334	0786 638670	TATYANA SMIRNOVA	{"phone": "+70575888707"}
0005432817661	6FD09A	4201 749784	OLGA TITOVA	{"phone": "+70671685733"}
0005432817662	34FDFF	9985 286669	SOFIYA ANISIMOVA	{"email": "sanisimova_31081967@postgrespro.ru", "phone": "+70873443366"}
0005432817663	34FDFF	9520 177451	SVETLANA KUZMINA	{"email": "svetlana_kuzmina.081971@postgrespro.ru", "phone": "+70736518403"}
0005432817664	874840	6761 780135	ALEKSEY FILIPPOV	{"email": "afilippov.111980@postgrespro.ru", "phone": "+70785805880"}
0005432817665	B1C2A6	1884 612993	SERGEY AFANASEV	{"phone": "+70763022650"}
0005432817666	6CA0F9	6782 455942	OLGA PETROVA	{"phone": "+70871811215"}
0005432817667	6CA0F9	5066 049649	MIKHAIL FEDOTOV	{"phone": "+70599120812"}
0005432817668	6CA0F9	3528 136087	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev-091964@postgrespro.ru", "phone": "+70946932968"}
0005432817669	B2C721	1219 385421	STANISLAV EGOROV	{"phone": "+70605551476"}
0005432817670	B2C721	0434 632461	DARYA AKIMOVA	{"email": "d-akimova-13031975@postgrespro.ru", "phone": "+70933049838"}
0005432817671	B2C721	8094 531085	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov-25101975@postgrespro.ru", "phone": "+70975662936"}
0005432817672	A9C80F	7650 926189	VIKTOR BELOV	{"phone": "+70884383140"}
0005432817673	25F2FE	4608 349292	YULIYA TROFIMOVA	{"phone": "+70478050220"}
0005432817674	138B92	3764 664441	NINA PAVLOVA	{"phone": "+70826711456"}
0005432817675	138B92	0949 277391	MARIYA SERGEEVA	{"email": "sergeeva.mariya_051969@postgrespro.ru", "phone": "+70514675168"}
0005432817676	6CB448	3199 597004	ALEKSANDR IVANOV	{"email": "ivanov-a.1969@postgrespro.ru", "phone": "+70456279823"}
0005432817677	1B230C	4639 796417	ALEKSANDR FOMIN	{"phone": "+70409977118"}
0005432817678	6B6E4B	7570 978883	OKSANA KOZLOVA	{"phone": "+70981302595"}
0005432817679	067765	0278 698041	EKATERINA OSIPOVA	{"email": "osipovaekaterina_081977@postgrespro.ru", "phone": "+70602648171"}
0005432817680	067765	8083 346770	GENNADIY SIDOROV	{"phone": "+70003758063"}
0005432817682	F0F017	7762 948643	VALENTIN ZAKHAROV	{"email": "valentinzakharov.101979@postgrespro.ru", "phone": "+70384898028"}
0005432817683	F0F017	1533 654998	OLGA EGOROVA	{"email": "olga_egorova121980@postgrespro.ru", "phone": "+70904448161"}
0005432817684	EBCCE7	7568 261081	PAVEL ABRAMOV	{"email": "pavel-abramov.1985@postgrespro.ru", "phone": "+70486770907"}
0005432817685	EBCCE7	3967 803021	VIKTOR KUZNECOV	{"email": "v_kuznecov-121970@postgrespro.ru", "phone": "+70644177412"}
0005432817686	E9D62F	9843 137088	VLADIMIR VOLKOV	{"phone": "+70515174387"}
0005432817687	CA15E9	6972 620249	VASILIY MOISEEV	{"email": "vmoiseev_26101987@postgrespro.ru", "phone": "+70202206745"}
0005432817688	CA15E9	3584 307306	LILIYA SOKOLOVA	{"phone": "+70589555280"}
0005432817689	12FB97	3804 752041	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr.111958@postgrespro.ru", "phone": "+70061106017"}
0005432817690	B58832	4963 373248	ANZHELA GUSEVA	{"email": "anzhela-guseva.20061973@postgrespro.ru", "phone": "+70026145244"}
0005432817691	7F2346	3927 096929	VLADIMIR GUSEV	{"email": "gusev_vladimir.071974@postgrespro.ru", "phone": "+70718252415"}
0005432817692	7F2346	2419 164094	YULIYA NOVIKOVA	{"email": "novikovay.19091965@postgrespro.ru", "phone": "+70664021183"}
0005432817693	9AF43A	3668 991952	IGOR ABRAMOV	{"email": "abramov_i-23071971@postgrespro.ru", "phone": "+70417145398"}
0005432817694	5E6FCB	6494 182328	ANGELINA DAVYDOVA	{"email": "davydovaa23121969@postgrespro.ru", "phone": "+70403173353"}
0005432817695	766664	6950 102168	YULIYA IVANOVA	{"email": "yuliya_ivanova1975@postgrespro.ru", "phone": "+70737954908"}
0005432817696	079700	8808 488402	TATYANA MELNIKOVA	{"phone": "+70833534531"}
0005432817697	079700	6739 828287	KRISTINA TITOVA	{"email": "titova_kristina1963@postgrespro.ru", "phone": "+70369314215"}
0005432817698	B27BEE	0593 549109	NIKITA SERGEEV	{"phone": "+70191480560"}
0005432817699	134EDC	2726 434497	EKATERINA VASILEVA	{"email": "vasileva_e.01071977@postgrespro.ru", "phone": "+70986795591"}
0005432817700	BEEB43	4968 514785	ELIZAVETA IVANOVA	{"email": "ivanova-elizaveta_101970@postgrespro.ru", "phone": "+70850661624"}
0005432817701	BEEB43	9335 796617	ALEKSANDR GAVRILOV	{"phone": "+70529469571"}
0005432817702	0CF6B0	6625 993576	EKATERINA YUDINA	{"email": "ekaterina-yudina.21121980@postgrespro.ru", "phone": "+70805674227"}
0005432817703	5BABA0	0711 980762	EKATERINA GAVRILOVA	{"phone": "+70330129386"}
0005432817704	B818F8	5160 432154	VERA KOMAROVA	{"phone": "+70384832788"}
0005432817705	B818F8	8482 493244	OLGA FROLOVA	{"phone": "+70126264929"}
0005432817706	B818F8	7587 385743	GENNADIY DENISOV	{"phone": "+70881904498"}
0005432817707	589549	6290 599761	ELENA DENISOVA	{"phone": "+70501889428"}
0005432817708	2BC62B	2125 660237	FEDOR ISAEV	{"email": "isaev-fedor-1973@postgrespro.ru", "phone": "+70097810678"}
0005432817709	2D8C22	8141 587258	VIKTOR KOZLOV	{"phone": "+70519188180"}
0005432817710	2D8C22	0148 079187	TATYANA ROMANOVA	{"phone": "+70474396072"}
0005432817711	7B2710	3931 477378	ANASTASIYA EGOROVA	{"email": "a.egorova-081975@postgrespro.ru", "phone": "+70289734171"}
0005432817712	7B2710	6963 548041	DANIIL MOROZOV	{"email": "morozov_d16071973@postgrespro.ru", "phone": "+70851134489"}
0005432817713	7B2710	7090 102589	IRINA ZHURAVLEVA	{"email": "i-zhuravleva_071977@postgrespro.ru", "phone": "+70120700501"}
0005432817714	A63010	4411 137604	VIKTOR ILIN	{"email": "viktor_ilin20011960@postgrespro.ru", "phone": "+70443629227"}
0005432817715	9794ED	5931 201618	MARGARITA MIRONOVA	{"email": "mironova_m_1957@postgrespro.ru", "phone": "+70298182868"}
0005432817716	88670B	1430 292540	ELENA EFREMOVA	{"email": "elenaefremova_1959@postgrespro.ru", "phone": "+70383230829"}
0005432817717	92AED6	1482 442747	OLGA ABRAMOVA	{"email": "o_abramova_1958@postgrespro.ru", "phone": "+70841360132"}
0005432817718	06A128	6305 430800	GALINA MATVEEVA	{"phone": "+70280180279"}
0005432817719	06A128	8892 717333	EKATERINA MOROZOVA	{"email": "morozova-ekaterina_1974@postgrespro.ru", "phone": "+70276375076"}
0005432817720	E620AE	6641 324091	OLEG TIMOFEEV	{"phone": "+70893535023"}
0005432817721	E620AE	7730 232102	ALEKSEY MIRONOV	{"email": "mironov.aleksey-031979@postgrespro.ru", "phone": "+70803637943"}
0005432817722	E620AE	8593 757726	ANDREY VLASOV	{"email": "avlasov_18031973@postgrespro.ru", "phone": "+70152581845"}
0005432817723	0747CC	2738 281493	LYUBOV PETROVA	{"email": "l.petrova.28091969@postgrespro.ru", "phone": "+70501593622"}
0005432817724	0747CC	9372 024049	TATYANA NIKITINA	{"email": "tatyana-nikitina-041979@postgrespro.ru", "phone": "+70161033981"}
0005432817725	EFA247	6008 866391	DMITRIY DENISOV	{"phone": "+70591422936"}
0005432817726	35FC4A	7672 449629	ELENA MIKHAYLOVA	{"email": "mikhaylova_elena1975@postgrespro.ru", "phone": "+70410126915"}
0005432817727	35FC4A	4816 711797	MIKHAIL DMITRIEV	{"phone": "+70029278014"}
0005432817728	CB8D9D	1762 347027	EVGENIY ISAEV	{"email": "e.isaev-061969@postgrespro.ru", "phone": "+70125164641"}
0005432817729	CB8D9D	3352 022904	MIKHAIL ANTONOV	{"phone": "+70463792506"}
0005432817730	CB8D9D	0683 013137	NIKITA SEMENOV	{"phone": "+70301325247"}
0005432817731	3AC9AB	2530 999742	ANASTASIYA MIRONOVA	{"email": "mironovaanastasiya-12041980@postgrespro.ru", "phone": "+70582390506"}
0005432817732	87A756	8396 780797	GALINA KOZLOVA	{"phone": "+70033511060"}
0005432817733	5E7A53	2439 522668	NIKOLAY RODIONOV	{"phone": "+70349110674"}
0005432817734	B257BF	4857 262893	ALEKSANDR RODIONOV	{"email": "rodionov.a-041979@postgrespro.ru", "phone": "+70394527370"}
0005432817735	B257BF	4373 779055	KONSTANTIN TIKHONOV	{"phone": "+70087450473"}
0005432817736	866C71	7540 219977	NATALYA SERGEEVA	{"email": "sergeevanatalya_23101971@postgrespro.ru", "phone": "+70655163447"}
0005432817737	B9599A	7620 129758	ANTONINA LAZAREVA	{"phone": "+70605197564"}
0005432817738	B9599A	1235 151336	LYUDMILA IVANOVA	{"email": "l.ivanova101974@postgrespro.ru", "phone": "+70820871683"}
0005432817739	464460	3899 949218	SERGEY ANDREEV	{"email": "sergey_andreev1981@postgrespro.ru", "phone": "+70515469340"}
0005432817740	B9BAB3	0907 017390	MAKSIM KUDRYASHOV	{"email": "maksim-kudryashov.1971@postgrespro.ru", "phone": "+70891753053"}
0005432817741	30D2BD	6297 824210	VLADIMIR BARANOV	{"phone": "+70433193502"}
0005432817742	30D2BD	2141 403846	NIKOLAY SEMENOV	{"phone": "+70506252713"}
0005432817743	D7C6C5	6212 428454	EKATERINA ZHUKOVA	{"phone": "+70106117739"}
0005432817744	D7C6C5	3934 157646	ALEKSANDR SERGEEV	{"email": "a-sergeev25051990@postgrespro.ru", "phone": "+70885734824"}
0005432817745	E27C2C	6083 493928	VERA ANTONOVA	{"email": "antonova_v.20051969@postgrespro.ru", "phone": "+70885715002"}
0005432817746	E27C2C	3444 459465	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr_1966@postgrespro.ru", "phone": "+70184981594"}
0005432817747	F8296F	5649 752662	KIRILL ZAYCEV	{"email": "zaycev-kirill011967@postgrespro.ru", "phone": "+70483298056"}
0005432817748	EB4DCF	0483 394104	EKATERINA SIDOROVA	{"email": "e.sidorova21041966@postgrespro.ru", "phone": "+70046769371"}
0005432817749	EB9E1F	6184 058231	ALEKSANDR GORBUNOV	{"phone": "+70494420199"}
0005432817750	EB9E1F	8241 435396	SOFYA ABRAMOVA	{"phone": "+70882800193"}
0005432817751	9FDC70	3906 396110	DMITRIY PAVLOV	{"phone": "+70354836326"}
0005432817752	9FDC70	9128 032368	OLGA PAVLOVA	{"email": "pavlovao.17121968@postgrespro.ru", "phone": "+70834491913"}
0005432817753	0315C2	7850 237305	TATYANA GERASIMOVA	{"email": "gerasimovat.011965@postgrespro.ru", "phone": "+70514925755"}
0005432817754	BA5D77	8025 112881	NINA KOROLEVA	{"email": "ninakoroleva.1966@postgrespro.ru", "phone": "+70202893866"}
0005432817755	BA5D77	7382 753590	GENNADIY GAVRILOV	{"phone": "+70967362912"}
0005432817756	D888FF	9898 199778	LYUDMILA BELOVA	{"phone": "+70848909198"}
0005432817757	F2CBEB	3429 825935	MARIYA SCHERBAKOVA	{"email": "scherbakova-m_01011981@postgrespro.ru", "phone": "+70027361808"}
0005432817758	751F50	9314 882504	SVETLANA ILINA	{"email": "ilinasvetlana02101980@postgrespro.ru", "phone": "+70552693748"}
0005432817759	751F50	0757 529866	NAIL FILIPPOV	{"phone": "+70180251266"}
0005432817760	78D084	5507 021480	OLGA IVANOVA	{"email": "olga-ivanova.041985@postgrespro.ru", "phone": "+70805831370"}
0005432817761	69E7C3	8785 938622	EGOR PETROV	{"phone": "+70590512980"}
0005432817762	73A658	7141 864863	VLADIMIR MAKAROV	{"phone": "+70890989863"}
0005432817763	68A0E1	3472 969492	ANDREY ANTONOV	{"phone": "+70501486549"}
0005432817764	68A0E1	3326 361533	DMITRIY GUSEV	{"phone": "+70482078508"}
0005432817765	EE8FD7	1188 740282	MARINA KONDRATEVA	{"email": "m-kondrateva011968@postgrespro.ru", "phone": "+70022341610"}
0005432817766	EE8FD7	6347 869211	VERA ERMAKOVA	{"phone": "+70589035763"}
0005432817767	5EAF59	1118 033175	ALEKSANDR KOZLOV	{"phone": "+70011498733"}
0005432817768	5EAF59	1264 579732	MIKHAIL MATVEEV	{"phone": "+70959596747"}
0005432817769	0A62C8	5563 828255	LIYA SERGEEVA	{"email": "sergeeva_l-13061971@postgrespro.ru", "phone": "+70195983087"}
0005432817770	CBDCB8	8895 901995	EVGENIY ANDREEV	{"email": "andreev-evgeniy.1970@postgrespro.ru", "phone": "+70989000480"}
0005432817771	CBDCB8	3844 998899	MAKSIM KOZLOV	{"email": "kozlov_m_1969@postgrespro.ru", "phone": "+70445559554"}
0005432817772	E1D160	4176 964289	ANNA YAKOVLEVA	{"phone": "+70075103261"}
0005432817773	6C76C2	9974 493610	ALEVTINA DANILOVA	{"email": "alevtinadanilova_1975@postgrespro.ru", "phone": "+70702622699"}
0005432817774	6C76C2	5049 846973	DMITRIY ALEKSEEV	{"email": "d.alekseev11041976@postgrespro.ru", "phone": "+70503347571"}
0005432817775	7D5221	2475 157380	KRISTINA SMIRNOVA	{"phone": "+70531350616"}
0005432817776	72CB08	5055 857496	DANIIL IVANOV	{"email": "daniil.ivanov_1965@postgrespro.ru", "phone": "+70526482045"}
0005432817777	72CB08	2136 672705	SERGEY ALEKSANDROV	{"email": "sergey.aleksandrov.29111979@postgrespro.ru", "phone": "+70910893439"}
0005432817778	B4C211	1090 724175	ALESYA FILIPPOVA	{"phone": "+70215430452"}
0005432817779	284D8A	5110 072516	NADEZHDA KOROLEVA	{"email": "n_koroleva_26061978@postgrespro.ru", "phone": "+70200539760"}
0005432817780	8368C7	7707 911155	MAKSIM ANTONOV	{"phone": "+70684811454"}
0005432817781	071C9A	9306 562440	MARINA PAVLOVA	{"email": "pavlova-m26011973@postgrespro.ru", "phone": "+70446030141"}
0005432817782	99C9D8	8781 746506	EKATERINA YAKOVLEVA	{"email": "yakovleva_e29021980@postgrespro.ru", "phone": "+70320783954"}
0005432817783	99C9D8	9126 733761	IRINA SAVELEVA	{"email": "isaveleva.121976@postgrespro.ru", "phone": "+70695922602"}
0005432817784	F09A39	9207 119274	VITALIY VASILEV	{"phone": "+70245564114"}
0005432817785	02C994	2444 658910	VALERIY FILIPPOV	{"phone": "+70561728227"}
0005432817786	6ACCFD	9141 966928	EKATERINA FADEEVA	{"phone": "+70301863973"}
0005432817787	4DDE76	7961 815555	NADEZHDA SOLOVEVA	{"email": "nsoloveva_1972@postgrespro.ru", "phone": "+70896787615"}
0005432817788	67832A	4990 302062	OLGA NAUMOVA	{"email": "olga_naumova1975@postgrespro.ru", "phone": "+70874548527"}
0005432817789	B17F26	3257 618419	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov1973@postgrespro.ru", "phone": "+70828003395"}
0005432817790	B17F26	3311 771527	EVA VASILEVA	{"phone": "+70279032763"}
0005432817791	B76737	0639 959956	MIKHAIL VASILEV	{"email": "mikhail-vasilev_1965@postgrespro.ru", "phone": "+70372948980"}
0005432817792	53E9F5	5769 880021	VALENTINA MELNIKOVA	{"phone": "+70757223988"}
0005432817793	53E9F5	2800 666805	VLADIMIR KUZNECOV	{"phone": "+70850778289"}
0005432817794	5C615D	7863 015788	ILYA KUDRYASHOV	{"phone": "+70019093906"}
0005432817795	F31BEB	9400 840558	IRINA MASLOVA	{"email": "irina-maslova_081973@postgrespro.ru", "phone": "+70092443046"}
0005432817796	292B9A	6297 068166	VERONIKA KRASNOVA	{"email": "krasnova.veronika_24081977@postgrespro.ru", "phone": "+70068943197"}
0005432817797	292B9A	5033 346931	ELENA ALEKSANDROVA	{"email": "e-aleksandrova_071974@postgrespro.ru", "phone": "+70400156991"}
0005432817798	F30DB9	2168 813892	ALEKSEY ILIN	{"phone": "+70187873246"}
0005432817799	F30DB9	5344 688932	VLADIMIR NIKITIN	{"phone": "+70420984687"}
0005432817800	A93A2F	0762 748044	ANATOLIY DMITRIEV	{"email": "dmitriev_a1968@postgrespro.ru", "phone": "+70297567644"}
0005432817801	A93A2F	0361 690217	OLGA IVANOVA	{"phone": "+70855363577"}
0005432817802	1DF75E	0013 744073	KSENIYA NIKOLAEVA	{"phone": "+70897296428"}
0005432817803	1DF75E	2849 536481	YURIY KOZLOV	{"email": "yuriy-kozlov-1971@postgrespro.ru", "phone": "+70357899492"}
0005432817804	7F05A1	1314 544477	IGOR NAUMOV	{"email": "naumov-igor.1970@postgrespro.ru", "phone": "+70159561036"}
0005432817805	EB91D9	7835 028776	NAZAR GAVRILOV	{"phone": "+70592850799"}
0005432817806	972A89	9047 056880	DMITRIY MIKHAYLOV	{"phone": "+70044944314"}
0005432817807	EB5FCE	0707 813556	TATYANA KOVALEVA	{"phone": "+70638617547"}
0005432817808	0BF94E	3150 787706	GENNADIY TIMOFEEV	{"phone": "+70008114996"}
0005432817809	BE6774	1974 657671	VERA BORISOVA	{"email": "borisova_vera_081969@postgrespro.ru", "phone": "+70753399730"}
0005432817810	CDCEA6	5233 996916	NATALYA MIRONOVA	{"phone": "+70231919445"}
0005432817811	CDCEA6	8673 217224	OLGA KOZLOVA	{"email": "kozlova_o-1982@postgrespro.ru", "phone": "+70054385456"}
0005432817812	568385	3443 038099	ZHANNA STEPANOVA	{"phone": "+70667692087"}
0005432817813	568385	2759 370037	MAKSIM GUSEV	{"email": "m_gusev_041969@postgrespro.ru", "phone": "+70159144442"}
0005432817814	57C60F	5523 552182	OKSANA ANTONOVA	{"email": "antonova_o-1969@postgrespro.ru", "phone": "+70883896279"}
0005432817815	E5508A	1438 792763	GALINA VOLKOVA	{"phone": "+70009176925"}
0005432817816	E2FD69	9958 686948	GENNADIY IVANOV	{"email": "gennadiy.ivanov_051966@postgrespro.ru", "phone": "+70418327485"}
0005432817817	FFA8B3	8641 853360	MARIYA SOLOVEVA	{"email": "m_soloveva_051980@postgrespro.ru", "phone": "+70759726780"}
0005432817818	BF0045	4039 634504	IVAN SERGEEV	{"phone": "+70638457637"}
0005432817819	47ABBA	5400 257813	TATYANA BOGDANOVA	{"email": "t.bogdanova.1974@postgrespro.ru", "phone": "+70234622392"}
0005432817820	76D1D7	6973 976529	IVAN SCHERBAKOV	{"phone": "+70139918404"}
0005432817821	671BF7	8510 283535	MIKHAIL FEDOROV	{"phone": "+70826324687"}
0005432817822	3D8356	7258 234444	MARIYA IVANOVA	{"phone": "+70048869784"}
0005432817823	3D8356	2020 552780	LYUBOV VASILEVA	{"phone": "+70047620532"}
0005432817824	7EDECF	1294 094056	VERA KONDRATEVA	{"phone": "+70744664643"}
0005432817825	0EC6CC	7677 864521	DARYA BELOVA	{"phone": "+70919732639"}
0005432817826	0EC6CC	3673 332778	NATALYA SOKOLOVA	{"email": "sokolova.n1973@postgrespro.ru", "phone": "+70138145883"}
0005432817827	15D527	1881 320277	KSENIYA KUZNECOVA	{"phone": "+70782000679"}
0005432817828	89111F	1869 972933	ANDREY PAVLOV	{"email": "pavlov-a1975@postgrespro.ru", "phone": "+70643777544"}
0005432817829	66B6E0	9505 386339	ANNA KOLESNIKOVA	{"email": "anna-kolesnikova.10071977@postgrespro.ru", "phone": "+70184668068"}
0005432817830	7FFB7D	0919 693344	ANDREY VOLKOV	{"email": "volkov-andrey_021969@postgrespro.ru", "phone": "+70502147969"}
0005432817831	A0DD2A	4899 422507	VIKTOR IVANOV	{"email": "viktor.ivanov-1971@postgrespro.ru", "phone": "+70607894645"}
0005432817832	0A10FA	0616 275898	YURIY KUZNECOV	{"email": "yuriy-kuznecov1984@postgrespro.ru", "phone": "+70736197973"}
0005432817833	FFA974	5019 972293	LYUDMILA DENISOVA	{"phone": "+70487048584"}
0005432817834	FFA974	1277 165951	NATALYA MALYSHEVA	{"email": "n.malysheva22031970@postgrespro.ru", "phone": "+70893965252"}
0005432817835	74689E	6547 123019	ALEKSANDR ISAEV	{"phone": "+70415224825"}
0005432817836	A6AA22	2685 637969	IRINA NAUMOVA	{"email": "naumova_irina_1979@postgrespro.ru", "phone": "+70489735775"}
0005432817837	A6AA22	3706 496599	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail21051957@postgrespro.ru", "phone": "+70633836732"}
0005432817838	77ABCF	4580 578816	SOFYA DAVYDOVA	{"email": "davydova-sofya-21081967@postgrespro.ru", "phone": "+70315713325"}
0005432817839	77ABCF	7624 619129	ALEKSANDR DAVYDOV	{"phone": "+70246064703"}
0005432817840	77ABCF	8015 329298	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e-121968@postgrespro.ru", "phone": "+70121097205"}
0005432817841	AA6C00	6512 883407	DMITRIY NOVIKOV	{"email": "novikovd09101965@postgrespro.ru", "phone": "+70752526534"}
0005432817842	3E825D	5860 248232	DMITRIY CHERNOV	{"email": "dmitriychernov-29091967@postgrespro.ru", "phone": "+70447304875"}
0005432817843	DF5957	2794 898460	MAKSIM FEDOTOV	{"email": "fedotov-m.1972@postgrespro.ru", "phone": "+70241034968"}
0005432817844	2BB1D2	2714 806902	SVETLANA KONDRATEVA	{"email": "svetlana_kondrateva-16061972@postgrespro.ru", "phone": "+70742999333"}
0005432817845	27B07B	3089 228085	MAKSIM FEDOROV	{"email": "maksimfedorov_28101966@postgrespro.ru", "phone": "+70663481594"}
0005432817846	D7800D	7470 680972	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova.31011976@postgrespro.ru", "phone": "+70778302182"}
0005432817847	126DD3	1739 172109	TATYANA EGOROVA	{"email": "egorova.tatyana.071978@postgrespro.ru", "phone": "+70866421623"}
0005432817848	9CE0DE	2939 998019	GALINA DMITRIEVA	{"email": "dmitrieva.g091963@postgrespro.ru", "phone": "+70253923360"}
0005432817849	9CE0DE	8621 601105	NATALYA ROMANOVA	{"email": "n.romanova_19071968@postgrespro.ru", "phone": "+70739672835"}
0005432817850	ACCFE0	4812 226409	RUSLAN CHERNOV	{"email": "ruslan-chernov_111974@postgrespro.ru", "phone": "+70154104053"}
0005432817851	ACCFE0	0087 857799	IRINA LOGINOVA	{"phone": "+70994073345"}
0005432817852	895AD3	0542 313727	SERGEY POPOV	{"email": "popov-sergey111977@postgrespro.ru", "phone": "+70902984181"}
0005432817853	28F2FB	9584 059254	DANILA IVANOV	{"phone": "+70651273019"}
0005432817854	39B4C3	2082 443912	YURIY KARPOV	{"phone": "+70650605492"}
0005432817855	5DF3EB	6231 955569	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov_101965@postgrespro.ru", "phone": "+70565110530"}
0005432817856	5DF3EB	4957 777711	ALEKSEY MARTYNOV	{"email": "martynov.aleksey_1978@postgrespro.ru", "phone": "+70702207374"}
0005432817857	EAFFDF	0709 326582	MARINA MELNIKOVA	{"email": "mmelnikova-27021979@postgrespro.ru", "phone": "+70708977557"}
0005432817858	08FC60	3352 565841	LADA POTAPOVA	{"phone": "+70077193355"}
0005432817859	820E96	1601 837456	ANNA SIDOROVA	{"email": "asidorova-071973@postgrespro.ru", "phone": "+70572035114"}
0005432817860	62872E	4817 377005	ALEVTINA ARKHIPOVA	{"phone": "+70324360477"}
0005432817861	1970ED	1350 144888	ELENA KOMAROVA	{"email": "komarova_e-07031979@postgrespro.ru", "phone": "+70661444419"}
0005432817862	1970ED	5710 443693	OLGA KOROLEVA	{"email": "koroleva.olga.121963@postgrespro.ru", "phone": "+70961314957"}
0005432817863	9B33F9	7901 740795	ARTEM STEPANOV	{"phone": "+70609085497"}
0005432817864	083952	8484 439074	MAKSIM GUSEV	{"phone": "+70337677390"}
0005432817865	083952	6205 582885	VLADIMIR VASILEV	{"email": "vasilevvladimir1973@postgrespro.ru", "phone": "+70944160678"}
0005432817866	B91E6C	1352 650068	ALEKSEY MOROZOV	{"email": "aleksey-morozov1972@postgrespro.ru", "phone": "+70871534123"}
0005432817867	B91E6C	6675 307218	DMITRIY GAVRILOV	{"phone": "+70685805990"}
0005432817868	1E566F	3966 559494	MIKHAIL DENISOV	{"phone": "+70733439628"}
0005432817869	0A9327	9146 496995	SVETLANA SERGEEVA	{"phone": "+70079597305"}
0005432817870	4EFCD8	3257 225595	GALINA TITOVA	{"phone": "+70063052688"}
0005432817871	BF9DAB	3528 328907	SERGEY EGOROV	{"email": "egorov.s.061967@postgrespro.ru", "phone": "+70302278511"}
0005432817872	08FE69	7678 485971	ALINA KRASNOVA	{"email": "krasnovaalina051968@postgrespro.ru", "phone": "+70005198146"}
0005432817873	9A0E78	5701 973684	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr-1972@postgrespro.ru", "phone": "+70622272481"}
0005432817874	485BD3	3393 771010	IVAN PAVLOV	{"email": "pavlov_i.091977@postgrespro.ru", "phone": "+70004253301"}
0005432817875	7F2AC0	0832 093055	ELVIRA PAVLOVA	{"email": "pavlova-e.011981@postgrespro.ru", "phone": "+70526813574"}
0005432817876	15DF0D	8160 305143	GALINA GUSEVA	{"email": "galinaguseva_23101966@postgrespro.ru", "phone": "+70966127378"}
0005432817877	512559	1617 630426	VLADIMIR CHERNOV	{"phone": "+70543140779"}
0005432817878	512559	9456 006711	LARISA IVANOVA	{"email": "ivanova-larisa011977@postgrespro.ru", "phone": "+70862736670"}
0005432817879	0D1297	4864 532799	OLGA MALYSHEVA	{"phone": "+70844314389"}
0005432817880	F8E158	1764 956006	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.1962@postgrespro.ru", "phone": "+70983440394"}
0005432817881	F8E158	5298 336928	NINA KUZMINA	{"email": "kuzminanina20011971@postgrespro.ru", "phone": "+70275410720"}
0005432817882	F8E158	0085 040189	ALEKSEY BORISOV	{"email": "borisovaleksey091975@postgrespro.ru", "phone": "+70866861092"}
0005432817883	49E95E	6103 891797	VLADISLAV KARPOV	{"email": "vladislavkarpov1978@postgrespro.ru", "phone": "+70364426389"}
0005432817884	5A85DD	2155 937854	IVAN MATVEEV	{"email": "i-matveev_1978@postgrespro.ru", "phone": "+70294306842"}
0005432817885	5A85DD	4359 657937	VALENTINA DENISOVA	{"phone": "+70873553751"}
0005432817886	ADB24F	9654 770025	MARINA SERGEEVA	{"phone": "+70160838795"}
0005432817887	FE8955	4852 648295	MAKSIM KUDRYASHOV	{"phone": "+70580621870"}
0005432817888	FE8955	4244 754019	ROMAN KARPOV	{"phone": "+70310627697"}
0005432817889	2F89AB	4531 600855	YAKOV MIRONOV	{"phone": "+70631898341"}
0005432817890	2F89AB	5256 447549	VADIM NIKOLAEV	{"email": "nikolaev.v_16031972@postgrespro.ru", "phone": "+70264487609"}
0005432817891	F4FDDF	4633 448849	VALENTINA KOMAROVA	{"phone": "+70849344353"}
0005432817892	482F00	4487 463643	IGOR GORBUNOV	{"email": "gorbunov_i_1981@postgrespro.ru", "phone": "+70947949130"}
0005432817893	056E07	2883 818629	ELENA DENISOVA	{"phone": "+70801282709"}
0005432817894	55E5F9	9861 817929	DMITRIY SOLOVEV	{"email": "dmitriy.solovev-021958@postgrespro.ru", "phone": "+70029041798"}
0005432817895	55E5F9	9513 364493	SERGEY TIMOFEEV	{"phone": "+70820173377"}
0005432817896	D77EF4	0965 029768	ALEKSANDR CHERNOV	{"phone": "+70996308997"}
0005432817897	A752BE	1870 993330	VIKTORIYA PETROVA	{"phone": "+70643152664"}
0005432817898	47EFB5	5966 013891	ANNA POLYAKOVA	{"phone": "+70024507231"}
0005432817899	8763E0	5253 416759	ALEKSEY SCHERBAKOV	{"phone": "+70200477253"}
0005432817900	E07CD2	1702 660162	KSENIYA MARTYNOVA	{"email": "martynovakseniya.031969@postgrespro.ru", "phone": "+70162327034"}
0005432817901	E07CD2	3296 943931	VLADISLAV FROLOV	{"phone": "+70889047673"}
0005432817902	C149EA	7981 300357	OLEG FROLOV	{"phone": "+70264743554"}
0005432817903	89BC61	7343 760479	TATYANA VOROBEVA	{"email": "vorobeva-tatyana16081979@postgrespro.ru", "phone": "+70936351762"}
0005432817904	89BC61	3519 535741	ELENA TITOVA	{"phone": "+70894378404"}
0005432817905	89BC61	4803 595102	YURIY ILIN	{"email": "y-ilin_07071969@postgrespro.ru", "phone": "+70463650227"}
0005432817906	5F303D	2345 805313	DMITRIY MIKHAYLOV	{"email": "d.mikhaylov-27031966@postgrespro.ru", "phone": "+70374100626"}
0005432817907	EA085E	2765 375973	MIKHAIL POPOV	{"phone": "+70899217826"}
0005432817908	EA085E	1281 225408	GALINA ZAKHAROVA	{"email": "g.zakharova.031981@postgrespro.ru", "phone": "+70333596734"}
0005432817909	C3C00E	3692 159059	MAKSIM POPOV	{"email": "popov.m-1977@postgrespro.ru", "phone": "+70249240177"}
0005432817910	32CCB7	4139 046585	PAVEL FOMIN	{"phone": "+70074166843"}
0005432817911	695815	8829 504920	VERA BELOVA	{"email": "belova.v051968@postgrespro.ru", "phone": "+70591167800"}
0005432817912	449ED6	5511 015066	ARKADIY KONOVALOV	{"phone": "+70827484891"}
0005432817913	449ED6	4990 398698	VERA LAZAREVA	{"phone": "+70864299261"}
0005432817914	FCE90E	7151 564536	ALEKSANDR BARANOV	{"phone": "+70395034002"}
0005432817915	1E63F5	3791 067522	NATALYA KOROLEVA	{"email": "natalya.koroleva_111967@postgrespro.ru", "phone": "+70243511262"}
0005432817916	1E63F5	7988 210158	EGOR SIDOROV	{"email": "e.sidorov_1974@postgrespro.ru", "phone": "+70687363638"}
0005432817917	02AD70	2910 454782	ROMAN KUZNECOV	{"phone": "+70074245378"}
0005432817918	F7035F	6338 327270	GALIYA YAKOVLEVA	{"phone": "+70666557271"}
0005432817919	373E59	8318 448923	ALEKSANDR AFANASEV	{"phone": "+70228374761"}
0005432817920	DE705E	7348 811183	ALEKSEY KRASNOV	{"phone": "+70527933068"}
0005432817921	9C254A	1111 660113	NIKOLAY BELOV	{"email": "belovnikolay101973@postgrespro.ru", "phone": "+70023179644"}
0005432817922	9C254A	2092 618965	ALEKSEY ALEKSANDROV	{"phone": "+70037174923"}
0005432817923	6E7A45	3715 987509	DARYA KUZNECOVA	{"phone": "+70474812020"}
0005432817924	D50ED8	4850 756905	TATYANA NIKITINA	{"email": "nikitina-t03071966@postgrespro.ru", "phone": "+70098255429"}
0005432817925	8C4CC3	6417 729078	KRISTINA ANTONOVA	{"phone": "+70506617736"}
0005432817926	8C4CC3	2068 987980	TATYANA LAZAREVA	{"phone": "+70537904726"}
0005432817927	5BBA43	4809 634617	VALERIY VASILEV	{"email": "v_vasilev091970@postgrespro.ru", "phone": "+70776121566"}
0005432817928	5BBA43	3298 685036	EKATERINA FILATOVA	{"phone": "+70280772542"}
0005432817929	9E8BAE	2942 113933	ALEKSEY GERASIMOV	{"email": "aleksey-gerasimov.101977@postgrespro.ru", "phone": "+70556106533"}
0005432817930	9E8BAE	7152 862601	NATALYA KARPOVA	{"phone": "+70731773686"}
0005432817931	47AD53	4452 575510	OLGA KUZMINA	{"phone": "+70366645725"}
0005432817932	A568D1	6669 076623	LARISA NOVIKOVA	{"phone": "+70627603403"}
0005432817933	A568D1	7913 213188	OLGA IVANOVA	{"email": "ivanova-olga-13071966@postgrespro.ru", "phone": "+70023044669"}
0005432817934	93D32C	0839 083502	ALEKSANDRA PAVLOVA	{"phone": "+70462770346"}
0005432817935	CD5752	5802 506427	TAISIYA MELNIKOVA	{"email": "tmelnikova121973@postgrespro.ru", "phone": "+70200863417"}
0005432817936	644D28	9881 729087	VERA NAZAROVA	{"email": "v_nazarova.041973@postgrespro.ru", "phone": "+70451571771"}
0005432817937	846CF1	8570 677633	ANDREY KAZAKOV	{"email": "akazakov-01031965@postgrespro.ru", "phone": "+70791570633"}
0005432817938	70F6C0	3542 601178	NADEZHDA MEDVEDEVA	{"phone": "+70966751251"}
0005432817939	6523BF	8109 045997	VLADIMIR GRIGOREV	{"phone": "+70695160794"}
0005432817940	C1EEBF	4219 654273	IGOR SHEVCHENKO	{"email": "i-shevchenko1969@postgrespro.ru", "phone": "+70351095821"}
0005432817941	C1EEBF	5337 786131	ALINA ZAKHAROVA	{"phone": "+70273669029"}
0005432817942	602D5C	2694 655530	EKATERINA AKIMOVA	{"phone": "+70062039454"}
0005432817943	602D5C	6065 299363	SERGEY SMIRNOV	{"phone": "+70986925866"}
0005432817944	174B1A	7148 887510	VALERIY TIKHONOV	{"phone": "+70356353120"}
0005432817945	26B3CC	1540 888859	RAVIL KUZNECOV	{"phone": "+70611028202"}
0005432817946	4F5AF3	8327 049802	IGOR SHEVCHENKO	{"email": "shevchenko-i.14091972@postgrespro.ru", "phone": "+70443035749"}
0005432817947	6390FA	2802 893101	SERGEY PAVLOV	{"email": "sergey-pavlov_17031976@postgrespro.ru", "phone": "+70367734556"}
0005432817948	6390FA	6884 677788	MIKHAIL TARASOV	{"email": "mikhail-tarasov.01101973@postgrespro.ru", "phone": "+70848900715"}
0005432817949	E72ACE	9297 324717	POLINA GRISHINA	{"email": "pgrishina-10011968@postgrespro.ru", "phone": "+70045176699"}
0005432817950	C3A647	6663 078865	SERAFIMA VOLKOVA	{"phone": "+70398745821"}
0005432817951	C3A647	7552 823932	EKATERINA DAVYDOVA	{"email": "davydova_e_1977@postgrespro.ru", "phone": "+70596937008"}
0005432817952	46565E	0477 345213	SVETLANA TITOVA	{"email": "titova.svetlana-13061968@postgrespro.ru", "phone": "+70566932057"}
0005432817953	ADE7FD	0065 520578	VLADISLAV STEPANOV	{"phone": "+70670460983"}
0005432817954	ADE7FD	9119 368235	YURIY TIKHONOV	{"email": "tikhonov_yuriy061973@postgrespro.ru", "phone": "+70674886470"}
0005432817955	1E7276	8029 927292	SVETLANA IVANOVA	{"email": "svetlana.ivanova_1961@postgrespro.ru", "phone": "+70150486162"}
0005432817956	E37C6C	1923 485611	EKATERINA BORISOVA	{"email": "ekaterina.borisova_25111973@postgrespro.ru", "phone": "+70571740215"}
0005432817957	E37C6C	8645 698829	VLADIMIR PAVLOV	{"phone": "+70899151100"}
0005432817958	EF4D32	3739 542211	ANDREY MAKAROV	{"email": "andrey-makarov_18051957@postgrespro.ru", "phone": "+70838068152"}
0005432817959	4703C8	4483 587815	DMITRIY KUZMIN	{"phone": "+70775182345"}
0005432817960	0E2BAA	9064 866944	VIKTORIYA DENISOVA	{"email": "denisova.viktoriya-1967@postgrespro.ru", "phone": "+70266547837"}
0005432817961	0E2BAA	8777 096366	PAVEL EGOROV	{"email": "pavel-egorov-1975@postgrespro.ru", "phone": "+70448932041"}
0005432817962	0E2BAA	2428 358098	ANDREY MIKHAYLOV	{"phone": "+70458203940"}
0005432817963	67822F	9981 622728	ANNA ORLOVA	{"phone": "+70649296827"}
0005432817964	67822F	0329 652467	IRINA KOLESNIKOVA	{"phone": "+70622399116"}
0005432817965	FF0DEE	4773 472010	ANATOLIY BORISOV	{"email": "a-borisov_101968@postgrespro.ru", "phone": "+70228490476"}
0005432817966	4CFC05	8890 708176	GALINA NIKOLAEVA	{"phone": "+70604311927"}
0005432817967	4CFC05	9729 736624	DMITRIY ROMANOV	{"phone": "+70072402755"}
0005432817968	6B4F4E	9362 344435	ZAKHAR DAVYDOV	{"email": "zakhardavydov.1980@postgrespro.ru", "phone": "+70883758108"}
0005432817969	3833A7	1283 559684	VALERIY ZAYCEV	{"email": "zaycev-v-1964@postgrespro.ru", "phone": "+70983507658"}
0005432817970	E9EB4A	0111 776926	VALENTINA STEPANOVA	{"email": "valentina_stepanova_29071976@postgrespro.ru", "phone": "+70756959698"}
0005432817971	58CAB9	8354 368131	EVGENIY CHERNOV	{"email": "chernov_evgeniy011970@postgrespro.ru", "phone": "+70235110345"}
0005432817972	2D6525	2696 032083	MARINA CHERNOVA	{"email": "chernova_m21101978@postgrespro.ru", "phone": "+70021014428"}
0005432817973	37BC1A	1526 622942	NINA KOZLOVA	{"phone": "+70552846486"}
0005432817974	E88DDE	5261 370887	YURIY FOMIN	{"email": "fomin_y_06111978@postgrespro.ru", "phone": "+70798186089"}
0005432817975	2CA30F	1971 180901	VIKTOR STEPANOV	{"phone": "+70134601250"}
0005432817976	371092	4881 766698	VALENTINA KONDRATEVA	{"phone": "+70587278288"}
0005432817977	1AF438	4264 276793	KONSTANTIN POPOV	{"email": "k.popov_1976@postgrespro.ru", "phone": "+70530180322"}
0005432817978	49C17D	2101 312001	ANNA OVCHINNIKOVA	{"email": "a_ovchinnikova_1970@postgrespro.ru", "phone": "+70957232835"}
0005432817979	7A97C2	1933 300761	DMITRIY MATVEEV	{"email": "matveev-dmitriy-1970@postgrespro.ru", "phone": "+70871530923"}
0005432817980	F24907	8899 822302	DMITRIY ISAEV	{"phone": "+70615527290"}
0005432817981	924581	8075 374102	EVGENIY KOZLOV	{"phone": "+70422739419"}
0005432817982	A13E36	1796 688668	ALLA SEMENOVA	{"phone": "+70055368305"}
0005432817983	A13E36	9529 656144	VIKTOR SAVELEV	{"email": "savelevv.1961@postgrespro.ru", "phone": "+70105639435"}
0005432817984	58CECA	6395 143513	VYACHESLAV ALEKSEEV	{"phone": "+70333430896"}
0005432817985	CC9E42	4286 683571	DARYA ANISIMOVA	{"email": "anisimova-d-1965@postgrespro.ru", "phone": "+70939348123"}
0005432817986	017DA9	6916 057666	EKATERINA ROMANOVA	{"email": "romanova.e101966@postgrespro.ru", "phone": "+70196318202"}
0005432817987	06BB41	3835 679241	TATYANA BORISOVA	{"email": "tborisova_1983@postgrespro.ru", "phone": "+70233904295"}
0005432817988	22F1F3	1615 631805	ZINAIDA POPOVA	{"phone": "+70231061737"}
0005432817989	A3CFB7	9947 530356	SOFYA KALININA	{"email": "kalinina.sofya1982@postgrespro.ru", "phone": "+70833922192"}
0005432817990	A3CFB7	7572 860302	DAVID ZAYCEV	{"phone": "+70685616738"}
0005432817991	2193D7	8992 292076	SERGEY ANDREEV	{"email": "s-andreev_111965@postgrespro.ru", "phone": "+70228813453"}
0005432817992	E7545E	3233 221294	NIKOLAY MAKSIMOV	{"email": "n_maksimov_021979@postgrespro.ru", "phone": "+70693470573"}
0005432817993	0C632D	7209 472607	ALEKSANDR KAZAKOV	{"email": "aleksandr-kazakov1978@postgrespro.ru", "phone": "+70540826703"}
0005432817994	15257C	5181 392552	VERA FEDOROVA	{"phone": "+70413286332"}
0005432817995	E5F147	9430 530562	MARIYA SIDOROVA	{"phone": "+70912429672"}
0005432817996	E5F147	3336 323542	DARINA DENISOVA	{"phone": "+70027348014"}
0005432817997	696E6E	9048 210779	ZLATA CHERNOVA	{"phone": "+70694358805"}
0005432817998	6E013A	7737 361752	MIKHAIL VOROBEV	{"email": "vorobev_mikhail-12101974@postgrespro.ru", "phone": "+70153820277"}
0005432817999	6E013A	5830 845036	ROMAN SERGEEV	{"email": "roman_sergeev.20101974@postgrespro.ru", "phone": "+70262471679"}
0005432818000	144D01	9272 232212	NADEZHDA MELNIKOVA	{"email": "nadezhda-melnikova.021967@postgrespro.ru", "phone": "+70552153311"}
0005432818001	144D01	3501 748206	VLADIMIR SOROKIN	{"email": "v-sorokin1969@postgrespro.ru", "phone": "+70803402480"}
0005432818002	A4A90A	8276 289888	DANIIL FEDOROV	{"phone": "+70366535918"}
0005432818003	8381A3	3097 849968	RAISA SIDOROVA	{"phone": "+70347560794"}
0005432818004	8381A3	2726 601595	NELYA GERASIMOVA	{"phone": "+70212157658"}
0005432818005	E89F28	0511 794309	ZHANNA ANDREEVA	{"email": "zhannaandreeva_1972@postgrespro.ru", "phone": "+70908833929"}
0005432818006	E89F28	4194 443702	ALEKSANDR AFANASEV	{"email": "a-afanasev.28101977@postgrespro.ru", "phone": "+70136451153"}
0005432818007	E89F28	3747 467873	VASILIY SOKOLOV	{"phone": "+70411848136"}
0005432818008	ABE705	9644 997023	ANASTASIYA IVANOVA	{"phone": "+70779716397"}
0005432818009	ABE705	1282 458301	VASILIY VLASOV	{"phone": "+70201338687"}
0005432818010	518815	9983 595510	ZHANNA BELOVA	{"phone": "+70614298509"}
0005432818011	00DE40	5670 798326	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov.03081976@postgrespro.ru", "phone": "+70835681286"}
0005432818012	00DE40	9895 392376	ARTEM PETROV	{"phone": "+70968097882"}
0005432818013	811FAC	7945 740248	ANNA SOKOLOVA	{"email": "sokolova-a1982@postgrespro.ru", "phone": "+70879004839"}
0005432818014	811FAC	2600 257549	SERGEY VASILEV	{"phone": "+70459235291"}
0005432818015	51A360	6194 138990	VADIM NIKITIN	{"phone": "+70846453834"}
0005432818016	AD947D	3290 014204	ELLA SMIRNOVA	{"email": "smirnova_ella22061965@postgrespro.ru", "phone": "+70754081323"}
0005432818017	AD947D	4097 716525	STANISLAV SAVELEV	{"phone": "+70732298257"}
0005432818018	E0F8D3	9836 290135	ALEKSEY GRIGOREV	{"email": "grigorev-a-031986@postgrespro.ru", "phone": "+70884691481"}
0005432818019	E0F8D3	5164 502110	MARIYA ZOTOVA	{"phone": "+70788044954"}
0005432818020	98F24E	4768 553102	KSENIYA ANDREEVA	{"email": "andreeva.k-011973@postgrespro.ru", "phone": "+70320406517"}
0005432818021	ED76DD	5699 247334	OLGA IVANOVA	{"email": "ivanova-o-1981@postgrespro.ru", "phone": "+70148998100"}
0005432818022	ED76DD	5720 440975	EMILIYA TITOVA	{"email": "e_titova-1970@postgrespro.ru", "phone": "+70514897691"}
0005432818023	829D5B	7656 601400	IRINA VASILEVA	{"email": "vasileva_i.30031968@postgrespro.ru", "phone": "+70037896574"}
0005432818024	829D5B	3916 795203	MARIYA PETROVA	{"email": "mariya_petrova_1972@postgrespro.ru", "phone": "+70220975415"}
0005432818025	2B5106	8698 193443	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-v041970@postgrespro.ru", "phone": "+70427817394"}
0005432818026	AFFC8D	4859 465508	ARINA VOROBEVA	{"email": "vorobeva.a_11031965@postgrespro.ru", "phone": "+70072962296"}
0005432818027	AFFC8D	5880 370504	YURIY SMIRNOV	{"email": "yuriysmirnov.1965@postgrespro.ru", "phone": "+70728458023"}
0005432818028	86EB0C	0035 658001	MIKHAIL IVANOV	{"email": "ivanov_mikhail.1972@postgrespro.ru", "phone": "+70365342836"}
0005432818029	6FCE91	1403 770484	ALEKSEY MAKSIMOV	{"phone": "+70184359218"}
0005432818030	6FCE91	6642 185340	ANASTASIYA BOGDANOVA	{"email": "anastasiyabogdanova.1986@postgrespro.ru", "phone": "+70285652341"}
0005432818031	6BEFB6	0321 144386	OLGA AFANASEVA	{"phone": "+70843573654"}
0005432818032	F6166C	0483 547428	TAMARA FEDOROVA	{"phone": "+70377345085"}
0005432818033	3FB390	5018 964479	GALINA PAVLOVA	{"phone": "+70751640508"}
0005432818034	3FB390	3448 735140	YULIYA IVANOVA	{"phone": "+70702368462"}
0005432818035	009A5B	2121 344044	ILYA CHERNOV	{"email": "ilya_chernov.1968@postgrespro.ru", "phone": "+70295712143"}
0005432818036	5F7DC0	2896 360404	ALEKSEY KOROLEV	{"phone": "+70970560423"}
0005432818037	7A48BA	0017 727021	DMITRIY EGOROV	{"phone": "+70065064852"}
0005432818038	2AF768	3243 721432	SVETLANA KISELEVA	{"email": "kiseleva_s_011970@postgrespro.ru", "phone": "+70399238762"}
0005432818039	2657A4	0504 772710	FELIKS IVANOV	{"email": "feliks-ivanov_081979@postgrespro.ru", "phone": "+70092811480"}
0005432818040	2657A4	4959 307380	TATYANA VOLKOVA	{"email": "volkova_t-29091963@postgrespro.ru", "phone": "+70942746631"}
0005432818041	53AB5B	5118 765883	MIKHAIL ANDREEV	{"phone": "+70864895461"}
0005432818042	99CA60	6696 541174	ELENA VLASOVA	{"phone": "+70514899645"}
0005432818043	1E6494	6573 718743	ALEKSANDR EGOROV	{"phone": "+70893426323"}
0005432818044	62107D	0994 236203	SERGEY NIKITIN	{"email": "s-nikitin121959@postgrespro.ru", "phone": "+70726794401"}
0005432818045	97539A	1748 133360	ANDREY KUZMIN	{"email": "kuzmin_a_25061976@postgrespro.ru", "phone": "+70410207646"}
0005432818046	6DB0EC	0636 170163	LYUBOV NOVIKOVA	{"email": "novikova_l1967@postgrespro.ru", "phone": "+70588025770"}
0005432818047	C6F543	6697 215098	ELENA BORISOVA	{"email": "borisovaelena-02091965@postgrespro.ru", "phone": "+70188885897"}
0005432818048	83FAA5	9948 091952	NATALYA MARTYNOVA	{"email": "martynova_n1982@postgrespro.ru", "phone": "+70024027017"}
0005432818049	CE3FCA	4719 517639	ELENA ZAYCEVA	{"email": "zaycevaelena.1963@postgrespro.ru", "phone": "+70841114812"}
0005432818050	0374DA	1777 992894	ANDREY KOZLOV	{"email": "kozlov.a.031977@postgrespro.ru", "phone": "+70995948821"}
0005432818051	3CC47C	8843 870566	ARTEM KOZLOV	{"email": "kozlov.artem-111974@postgrespro.ru", "phone": "+70390855758"}
0005432818052	3CC47C	8230 946426	ILYA GRIGOREV	{"email": "i_grigorev101962@postgrespro.ru", "phone": "+70761915532"}
0005432818053	1DF74E	3937 185816	ANDREY KRASNOV	{"phone": "+70309688920"}
0005432818054	1A9061	9949 784537	ANATOLIY EGOROV	{"email": "egorov.anatoliy1968@postgrespro.ru", "phone": "+70554006955"}
0005432818055	1A9061	2918 475914	EKATERINA FROLOVA	{"email": "ekaterinafrolova011966@postgrespro.ru", "phone": "+70160204282"}
0005432818056	BC66AB	2819 076846	NATALYA MAKAROVA	{"phone": "+70083554219"}
0005432818057	BA08D3	6007 962456	ANDREY FROLOV	{"phone": "+70863800300"}
0005432818058	70633E	4757 721894	DMITRIY NIKITIN	{"email": "nikitin_dmitriy111985@postgrespro.ru", "phone": "+70218750537"}
0005432818059	70633E	6313 679208	ALEKSANDR SCHERBAKOV	{"phone": "+70046684262"}
0005432818060	70633E	2166 232374	ELENA SOKOLOVA	{"phone": "+70627753379"}
0005432818061	70633E	8473 378004	MARINA YAKOVLEVA	{"phone": "+70677631716"}
0005432818062	5136B9	8836 666887	ANNA BARANOVA	{"phone": "+70131556768"}
0005432818063	5136B9	0215 815012	VALENTINA KOZLOVA	{"email": "vkozlova_1969@postgrespro.ru", "phone": "+70829826529"}
0005432818064	D336B2	9911 636194	VIKTOR ZAKHAROV	{"email": "viktor-zakharov061971@postgrespro.ru", "phone": "+70179654429"}
0005432818065	44FE9E	9914 410051	SERGEY NAUMOV	{"phone": "+70386882425"}
0005432818066	5EEAD9	3735 521012	VIKTORIYA POPOVA	{"email": "viktoriya-popova031968@postgrespro.ru", "phone": "+70898650336"}
0005432818067	6808E0	7136 133721	NINA OSIPOVA	{"email": "osipovan-03011967@postgrespro.ru", "phone": "+70532834741"}
0005432818068	D053D8	8517 365586	LYUBOV IVANOVA	{"email": "livanova051976@postgrespro.ru", "phone": "+70992610501"}
0005432818069	D053D8	1378 343252	ELENA PAVLOVA	{"phone": "+70624353475"}
0005432818070	EB3F7F	5591 095583	VALERIYA VOLKOVA	{"phone": "+70024560962"}
0005432818071	9DA07D	0239 340914	ANASTASIYA ILINA	{"phone": "+70866198139"}
0005432818072	B233E3	4801 553214	ALEKSANDR MOISEEV	{"phone": "+70415791708"}
0005432818073	32C971	3195 270419	ALEKSANDRA ZHURAVLEVA	{"email": "zhuravleva.a_27031975@postgrespro.ru", "phone": "+70873472237"}
0005432818074	35EF7D	1957 597553	ANDREY VOLKOV	{"phone": "+70041439477"}
0005432818075	E22674	8090 037273	OLGA SIDOROVA	{"email": "olgasidorova.071965@postgrespro.ru", "phone": "+70801488958"}
0005432818076	BA4AB5	9234 104977	VALENTINA VASILEVA	{"phone": "+70964565239"}
0005432818077	BA4AB5	0479 832117	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr_1969@postgrespro.ru", "phone": "+70283461682"}
0005432818078	48A44B	9428 931515	DANILA KUZMIN	{"email": "kuzmin-danila.07011977@postgrespro.ru", "phone": "+70531554561"}
0005432818079	48A44B	0171 716641	YULIYA NESTEROVA	{"email": "yuliya-nesterova-18121979@postgrespro.ru", "phone": "+70564426203"}
0005432818080	233BEE	6768 581897	SEMEN NIKOLAEV	{"email": "nikolaevs021980@postgrespro.ru", "phone": "+70680038897"}
0005432818081	233BEE	5730 044488	SEMEN VLASOV	{"email": "semen.vlasov_1967@postgrespro.ru", "phone": "+70026281813"}
0005432818082	D1F3AD	5036 790898	ANTONINA ANTONOVA	{"phone": "+70119073612"}
0005432818083	EE0C1E	6629 206228	ELENA POPOVA	{"phone": "+70367384309"}
0005432818084	089F0A	9808 018318	LYUBOV MEDVEDEVA	{"email": "medvedeval_1974@postgrespro.ru", "phone": "+70775790294"}
0005432818085	247F8C	7735 752473	LEONID ANTONOV	{"phone": "+70324210376"}
0005432818086	28F660	5561 284955	LYUBOV AFANASEVA	{"phone": "+70851571059"}
0005432818087	865E6E	7845 840218	NATALYA OVCHINNIKOVA	{"phone": "+70759547092"}
0005432818088	124AF9	9407 272243	LYUDMILA YAKOVLEVA	{"email": "lyudmila-yakovleva.07121976@postgrespro.ru", "phone": "+70498840495"}
0005432818089	6EBE1B	5224 120019	GALINA DMITRIEVA	{"email": "galina_dmitrieva_1961@postgrespro.ru", "phone": "+70014660087"}
0005432818090	829E7F	5376 600789	NATALYA SERGEEVA	{"email": "n.sergeeva031973@postgrespro.ru", "phone": "+70662829730"}
0005432818091	F5959F	1003 355849	LYUBOV FEDOROVA	{"email": "l-fedorova.041971@postgrespro.ru", "phone": "+70833760305"}
0005432818092	F5959F	3835 623487	ANTONINA ANISIMOVA	{"email": "antonina_anisimova_081971@postgrespro.ru", "phone": "+70088809548"}
0005432818093	DB1EA2	0664 462086	ALEKSANDR KUZMIN	{"email": "a-kuzmin-1966@postgrespro.ru", "phone": "+70367317261"}
0005432818094	DB1EA2	1129 261386	SERGEY GRIGOREV	{"phone": "+70878929774"}
0005432818095	036ED7	9989 766055	TATYANA STEPANOVA	{"phone": "+70034707705"}
0005432818096	9EF9AE	4334 228765	VALENTINA SOROKINA	{"email": "sorokina-v-1969@postgrespro.ru", "phone": "+70183184079"}
0005432818097	9EF9AE	0111 134151	MARIYA NIKOLAEVA	{"phone": "+70821998289"}
0005432818098	5712B7	0667 080178	NIKOLAY KUZNECOV	{"phone": "+70973665022"}
0005432818099	616B05	1008 950073	SOFYA ANTONOVA	{"email": "antonova.s.1986@postgrespro.ru", "phone": "+70689844724"}
0005432818100	616B05	9422 997112	EVA ANDREEVA	{"email": "andreeva.e04121969@postgrespro.ru", "phone": "+70387062607"}
0005432818101	09A767	6788 923377	LIDIYA ROMANOVA	{"email": "romanova.l-031974@postgrespro.ru", "phone": "+70820028974"}
0005432818102	C16711	2921 596580	ALEKSEY MIKHAYLOV	{"phone": "+70650766907"}
0005432818103	2EEC4B	0300 432201	NADEZHDA GORBUNOVA	{"phone": "+70102977213"}
0005432818104	E4F120	6129 961867	ANATOLIY MATVEEV	{"phone": "+70567384618"}
0005432818105	4B2254	1711 715401	VLADIMIR ORLOV	{"phone": "+70424023351"}
0005432818106	70C51C	8343 724898	ALEKSANDR OSIPOV	{"phone": "+70119323365"}
0005432818107	70C51C	8670 078043	ALEKSANDRA PETROVA	{"email": "petrova-aleksandra121977@postgrespro.ru", "phone": "+70798802063"}
0005432818108	077BA7	0772 261395	ELENA VOLKOVA	{"phone": "+70443689728"}
0005432818109	DFABA1	4389 920517	LIDIYA ANISIMOVA	{"email": "lidiyaanisimova-061980@postgrespro.ru", "phone": "+70864029616"}
0005432818110	DFABA1	3858 105151	VLADIMIR VASILEV	{"email": "vasilevvladimir.01071973@postgrespro.ru", "phone": "+70056779558"}
0005432818111	EF6AE3	4413 726482	ANASTASIYA NIKIFOROVA	{"phone": "+70282744973"}
0005432818112	EF6AE3	7646 423791	NIKOLAY GUSEV	{"email": "n_gusev051981@postgrespro.ru", "phone": "+70719554757"}
0005432818113	7C828E	1368 128789	ELENA KAZAKOVA	{"phone": "+70941379968"}
0005432818114	707F35	2134 935732	DMITRIY SHEVCHENKO	{"email": "shevchenko.dmitriy.051955@postgrespro.ru", "phone": "+70027281407"}
0005432818115	2F8017	0397 256007	VIKTOR MAKAROV	{"phone": "+70124918789"}
0005432818116	D74460	7428 936071	ANDREY ILIN	{"email": "ilinandrey-1969@postgrespro.ru", "phone": "+70107641022"}
0005432818117	98947D	7274 156928	SERGEY VASILEV	{"phone": "+70619301466"}
0005432818118	98947D	7364 902389	NIKOLAY ALEKSEEV	{"phone": "+70340917963"}
0005432818119	5F5557	9056 934280	NATALYA KUZNECOVA	{"email": "kuznecova-natalya.091975@postgrespro.ru", "phone": "+70826913914"}
0005432818120	9956D3	3903 567298	TATYANA ZOTOVA	{"email": "t_zotova10041975@postgrespro.ru", "phone": "+70645663099"}
0005432818121	D84940	1830 016116	VLADIMIR GAVRILOV	{"phone": "+70226801225"}
0005432818122	D84940	6058 876866	ALEKSANDR FROLOV	{"phone": "+70761018881"}
0005432818123	53FB67	8617 037866	YULIYA LAZAREVA	{"email": "yuliya_lazareva-1983@postgrespro.ru", "phone": "+70226761107"}
0005432818124	A921B7	7672 616835	ANNA KISELEVA	{"phone": "+70791260385"}
0005432818125	A921B7	5301 176309	AMINA ALEKSANDROVA	{"phone": "+70861847960"}
0005432818126	645954	3017 971759	MARIYA MAKSIMOVA	{"phone": "+70891784647"}
0005432818127	7895CA	9343 787213	DENIS PAVLOV	{"phone": "+70010579950"}
0005432818128	06BB54	3914 854081	ANGELINA MOISEEVA	{"phone": "+70329417435"}
0005432818129	06BB54	0591 650219	TATYANA FADEEVA	{"phone": "+70342566255"}
0005432818130	F9F6C8	1108 189934	ZINAIDA AFANASEVA	{"phone": "+70511002491"}
0005432818131	58971A	4288 190664	ANNA CHERNOVA	{"phone": "+70079030505"}
0005432818132	109AFB	1753 117002	KIRILL ZAYCEV	{"email": "zaycev.k24121989@postgrespro.ru", "phone": "+70911978048"}
0005432818133	B7122A	7300 104821	ELENA DANILOVA	{"email": "danilova_elena1967@postgrespro.ru", "phone": "+70530071395"}
0005432818134	DCAE07	8782 421537	NIKOLAY SMIRNOV	{"email": "smirnov_nikolay-1984@postgrespro.ru", "phone": "+70245613092"}
0005432818135	EB9084	8602 565368	DMITRIY VASILEV	{"phone": "+70831508146"}
0005432818136	C23F6B	8306 911406	OLEG FOMIN	{"email": "oleg.fomin_18051961@postgrespro.ru", "phone": "+70230534558"}
0005432818137	C23F6B	2851 208539	MARINA STEPANOVA	{"phone": "+70359418897"}
0005432818138	52CED5	2192 230162	SVETLANA EFREMOVA	{"email": "efremova-svetlana.18021980@postgrespro.ru", "phone": "+70544809241"}
0005432818139	553617	0239 764165	ELENA BORISOVA	{"phone": "+70385093677"}
0005432818140	DD9168	3969 896086	ALEKSANDR ILIN	{"phone": "+70554093546"}
0005432818141	664EC5	1284 261952	DMITRIY BORISOV	{"phone": "+70390332148"}
0005432818142	602947	8253 628143	NIKOLAY KULIKOV	{"phone": "+70600487092"}
0005432818143	602947	6991 657512	MIKHAIL GORBUNOV	{"phone": "+70269895580"}
0005432818144	974B14	7214 118481	YULIYA ROMANOVA	{"email": "romanova_y-1986@postgrespro.ru", "phone": "+70997771549"}
0005432818145	974B14	7045 735181	POLINA ZHUKOVA	{"phone": "+70440765790"}
0005432818146	A7B7C8	6164 746121	ANDREY GRIGOREV	{"email": "grigorev-andrey_1977@postgrespro.ru", "phone": "+70059025762"}
0005432818147	E50516	2923 987500	ELENA NIKITINA	{"phone": "+70852443175"}
0005432818148	237CB4	6023 796861	ALEKSANDRA KOLESNIKOVA	{"email": "kolesnikova_aleksandra-091972@postgrespro.ru", "phone": "+70809596974"}
0005432818149	0773AE	1796 887218	LYUBOV MEDVEDEVA	{"phone": "+70529763946"}
0005432818150	0773AE	9821 334184	VIKTOR VOLKOV	{"email": "viktorvolkov.30031976@postgrespro.ru", "phone": "+70169872356"}
0005432818151	A6109F	6399 580363	ARINA POTAPOVA	{"email": "arina_potapova_111987@postgrespro.ru", "phone": "+70603529660"}
0005432818152	A68E62	5064 902497	ALEKSANDRA BOGDANOVA	{"phone": "+70112502021"}
0005432818153	E91821	9718 854870	GENNADIY KUZNECOV	{"email": "g.kuznecov-03011972@postgrespro.ru", "phone": "+70594431170"}
0005432818154	E91821	5283 238503	VLADIMIR ZAYCEV	{"phone": "+70113494940"}
0005432818155	4404D0	7428 733152	NIKITA GAVRILOV	{"phone": "+70056500473"}
0005432818156	4404D0	6436 695774	GALINA NESTEROVA	{"phone": "+70827266990"}
0005432818157	69CB77	2454 748631	ILYA PETROV	{"email": "petrov_i.29081972@postgrespro.ru", "phone": "+70223045103"}
0005432818158	CB7160	8536 482384	ELENA NAZAROVA	{"email": "elena-nazarova.1970@postgrespro.ru", "phone": "+70175642308"}
0005432818159	D1E9C0	0513 404212	ALEKSANDR KRASNOV	{"phone": "+70862437087"}
0005432818160	7D5CF2	3390 151805	PETR NAZAROV	{"phone": "+70624630478"}
0005432818161	3A92CB	7258 431169	OLESYA LOGINOVA	{"email": "loginova_o111970@postgrespro.ru", "phone": "+70420474089"}
0005432818162	3A92CB	2116 719672	SERGEY POPOV	{"phone": "+70883686406"}
0005432818163	1AEE7D	5049 742484	ALEKSANDR SOROKIN	{"phone": "+70629013967"}
0005432818164	1AEE7D	1339 006522	TAMARA SOKOLOVA	{"email": "sokolova-tamara.16071980@postgrespro.ru", "phone": "+70493654155"}
0005432818165	170779	3030 890284	MARIYA GERASIMOVA	{"phone": "+70395738975"}
0005432818166	2ECF94	2188 710398	GENNADIY KUZNECOV	{"email": "g_kuznecov_10051981@postgrespro.ru", "phone": "+70102786378"}
0005432818167	E16F62	1984 317440	PAVEL NOVIKOV	{"email": "p_novikov_081976@postgrespro.ru", "phone": "+70273523179"}
0005432818168	238CA3	5074 156682	NIKOLAY GRIGOREV	{"email": "grigorev-nikolay1970@postgrespro.ru", "phone": "+70937604364"}
0005432818169	A6C89B	3016 207588	NATALYA KUZNECOVA	{"email": "n_kuznecova_1967@postgrespro.ru", "phone": "+70000507919"}
0005432818170	4AFBDF	8718 264694	NIKOLAY ZHUKOV	{"email": "n_zhukov101979@postgrespro.ru", "phone": "+70756064451"}
0005432818171	4AFBDF	3101 507504	VERA ALEKSANDROVA	{"email": "vera.aleksandrova.04121972@postgrespro.ru", "phone": "+70203075745"}
0005432818172	050782	8373 971871	ALEKSANDR MAKSIMOV	{"email": "maksimov.a_031976@postgrespro.ru", "phone": "+70462848842"}
0005432818173	B75D23	1534 161290	TATYANA TIKHONOVA	{"email": "tikhonova.t31101965@postgrespro.ru", "phone": "+70936736885"}
0005432818174	B75D23	9078 337830	IRINA NOVIKOVA	{"phone": "+70501288867"}
0005432818175	2B7E25	9567 773166	SANIYA KUZNECOVA	{"email": "kuznecova_saniya-081962@postgrespro.ru", "phone": "+70364470012"}
0005432818176	36137E	5345 492192	GALINA VASILEVA	{"phone": "+70868319074"}
0005432818177	8C8E8D	5269 912481	VLADIMIR GAVRILOV	{"phone": "+70446788546"}
0005432818178	647A21	9789 078431	NADEZHDA RYABOVA	{"phone": "+70530757359"}
0005432818179	E79F69	9841 459808	VALENTINA TIMOFEEVA	{"phone": "+70926146671"}
0005432818180	E79F69	5662 284510	ALEKSANDR PETROV	{"email": "petrov.aleksandr_121965@postgrespro.ru", "phone": "+70754316504"}
0005432818181	67255C	5653 480463	IRINA NIKIFOROVA	{"email": "i.nikiforova18011959@postgrespro.ru", "phone": "+70422115092"}
0005432818182	67255C	2274 780984	ELENA KUZNECOVA	{"phone": "+70434424881"}
0005432818183	149A5D	9412 945926	YANA TARASOVA	{"email": "tarasova-y.021983@postgrespro.ru", "phone": "+70731384053"}
0005432818184	6CAABC	5580 281256	KRISTINA NIKITINA	{"email": "nikitinak_101972@postgrespro.ru", "phone": "+70331466361"}
0005432818185	6CAABC	5289 796943	ARTEM ROMANOV	{"phone": "+70091816470"}
0005432818186	5ECD34	4828 805730	ELENA FOMINA	{"phone": "+70120593163"}
0005432818187	D0EA37	0794 696676	GENNADIY MIRONOV	{"phone": "+70185774033"}
0005432818188	25E83F	8463 306809	ELENA STEPANOVA	{"email": "e_stepanova-27081981@postgrespro.ru", "phone": "+70779823196"}
0005432818189	25E83F	1741 780912	SERGEY PAVLOV	{"email": "pavlov_s_1985@postgrespro.ru", "phone": "+70104511597"}
0005432818190	5FEA77	4235 600733	NATALYA MAKSIMOVA	{"phone": "+70755602606"}
0005432818191	544D24	9358 955066	NIKITA KUZNECOV	{"phone": "+70255392317"}
0005432818192	F56DEC	8064 717692	ALEKSANDR VASILEV	{"phone": "+70474586772"}
0005432818193	F56DEC	6480 493178	ANDREY BARANOV	{"email": "andreybaranov21061977@postgrespro.ru", "phone": "+70063155935"}
0005432818194	1EDA37	3836 608559	OLGA AFANASEVA	{"phone": "+70795802306"}
0005432818195	1EDA37	1077 664146	DAVID EGOROV	{"email": "david-egorov1981@postgrespro.ru", "phone": "+70034998102"}
0005432818196	E2F2DB	9919 177700	OLGA GRISHINA	{"email": "olgagrishina_091967@postgrespro.ru", "phone": "+70852547075"}
0005432818197	764BAF	7318 372073	EVGENIY KARPOV	{"email": "karpov.e.22081979@postgrespro.ru", "phone": "+70316547171"}
0005432818198	E24EE9	6894 451495	ANNA KRASNOVA	{"phone": "+70453830721"}
0005432818199	E24EE9	1284 716417	ANASTASIYA AKIMOVA	{"phone": "+70901448413"}
0005432818200	A2C8FD	1482 890598	ELENA KULIKOVA	{"email": "kulikovaelena101973@postgrespro.ru", "phone": "+70193935777"}
0005432818201	89E2F8	9670 522683	ANASTASIYA MELNIKOVA	{"email": "amelnikova.1970@postgrespro.ru", "phone": "+70425411276"}
0005432818202	730DB7	2375 254981	ANDREY TIKHONOV	{"email": "tikhonov_andrey1975@postgrespro.ru", "phone": "+70167379219"}
0005432818203	681C0C	7219 920385	YURIY GERASIMOV	{"phone": "+70474531795"}
0005432818204	D85935	8630 865885	ANTONINA ISAEVA	{"phone": "+70519955413"}
0005432818205	D85935	9398 469394	ANNA MEDVEDEVA	{"phone": "+70379482300"}
0005432818206	2BD712	3280 012969	YULIYA VASILEVA	{"phone": "+70298607053"}
0005432818207	2BD712	6019 000612	DENIS NIKITIN	{"email": "nikitin.denis.26041976@postgrespro.ru", "phone": "+70137809081"}
0005432818208	2BD712	4198 489054	TATYANA KALININA	{"email": "kalininat-01101977@postgrespro.ru", "phone": "+70394278274"}
0005432818209	6E2CBC	5588 387453	LIDIYA VOLKOVA	{"phone": "+70784581145"}
0005432818210	086E15	9008 269303	TATYANA FOMINA	{"email": "fomina_tatyana1982@postgrespro.ru", "phone": "+70199900637"}
0005432818211	51E32A	6584 563025	VALENTINA FOMINA	{"phone": "+70789078740"}
0005432818212	51E32A	2832 573826	MARIYA AFANASEVA	{"email": "afanaseva-mariya1977@postgrespro.ru", "phone": "+70236356123"}
0005432818213	2C22D6	7174 673966	ALEKSANDR ZAKHAROV	{"email": "zakharov.a.071972@postgrespro.ru", "phone": "+70408536458"}
0005432818214	2C22D6	0414 754602	ALEKSANDRA TIKHONOVA	{"email": "tikhonova_a1968@postgrespro.ru", "phone": "+70474990574"}
0005432818215	E1CA52	7913 079542	ALEKSEY BONDARENKO	{"email": "alekseybondarenko.1971@postgrespro.ru", "phone": "+70494480440"}
0005432818216	02FE49	6425 589966	NINA MAKAROVA	{"phone": "+70514952435"}
0005432818217	A8F833	8044 695388	TATYANA BELYAEVA	{"phone": "+70058304159"}
0005432818218	6B6522	8418 729915	SVETLANA ISAEVA	{"email": "s.isaeva_041962@postgrespro.ru", "phone": "+70519636127"}
0005432818219	75F58A	8580 416225	ROMAN VOLKOV	{"email": "roman_volkov-1967@postgrespro.ru", "phone": "+70088535121"}
0005432818220	E10879	4320 589088	GALINA BORISOVA	{"phone": "+70354699787"}
0005432818221	E10879	2582 819041	SERGEY ISAEV	{"email": "sergey.isaev.011965@postgrespro.ru", "phone": "+70965298129"}
0005432818222	4213E5	2903 300220	NATALYA STEPANOVA	{"email": "stepanovan-1972@postgrespro.ru", "phone": "+70591574747"}
0005432818223	6E15A1	8436 810329	LILIYA GAVRILOVA	{"email": "gavrilova_l_061973@postgrespro.ru", "phone": "+70550892068"}
0005432818224	6E15A1	5869 886211	PETR YAKOVLEV	{"phone": "+70597510483"}
0005432818225	2A531E	6617 290490	VALENTINA BELOVA	{"phone": "+70971092571"}
0005432818226	194305	9348 583968	IRINA KISELEVA	{"email": "kiseleva.irina1976@postgrespro.ru", "phone": "+70951757301"}
0005432818227	194305	9068 118438	SERGEY MOROZOV	{"phone": "+70646589084"}
0005432818228	2F8240	5197 626713	MARGARITA VOROBEVA	{"email": "m.vorobeva_30011972@postgrespro.ru", "phone": "+70158576654"}
0005432818229	2F8240	0548 798124	ALEKSEY DENISOV	{"phone": "+70795099786"}
0005432818230	7660E7	6579 922607	IRINA MELNIKOVA	{"email": "irina-melnikova-051975@postgrespro.ru", "phone": "+70421166685"}
0005432818231	30C535	9379 099113	ALEKSEY SHEVCHENKO	{"phone": "+70581274711"}
0005432818232	93EEFA	9575 735595	ROMAN ZAYCEV	{"email": "zaycev.r.021970@postgrespro.ru", "phone": "+70617432477"}
0005432818233	93EEFA	4046 831718	MIKHAIL KUZNECOV	{"phone": "+70927254144"}
0005432818234	A0B66C	0044 667705	YURIY SIDOROV	{"phone": "+70722181259"}
0005432818235	10E444	9811 987678	EKATERINA KONDRATEVA	{"email": "kondrateva-ekaterina-031985@postgrespro.ru", "phone": "+70543710448"}
0005432818236	6AF9AC	8470 590203	SERGEY ZHURAVLEV	{"email": "zhuravlev.s-05091956@postgrespro.ru", "phone": "+70373600565"}
0005432818237	26FE3A	8259 656825	VLADIMIR PAVLOV	{"phone": "+70660885834"}
0005432818238	79F314	8749 256759	ARINA VLASOVA	{"email": "vlasova-arina.1978@postgrespro.ru", "phone": "+70364918176"}
0005432818239	79F314	1024 793017	MARINA FOMINA	{"email": "marina.fomina-1975@postgrespro.ru", "phone": "+70980118488"}
0005432818240	630F92	9154 000358	VALENTINA SERGEEVA	{"email": "sergeeva_v101986@postgrespro.ru", "phone": "+70666004608"}
0005432818241	B410D4	3212 148335	ALEKSANDR KRASNOV	{"phone": "+70049665560"}
0005432818242	897480	4885 560793	YURIY SEMENOV	{"email": "y.semenov.1970@postgrespro.ru", "phone": "+70906592497"}
0005432818243	897480	9334 064215	VLADIMIR KUZNECOV	{"phone": "+70754722235"}
0005432818244	44815A	7039 616086	NIKOLAY DAVYDOV	{"email": "n.davydov_1983@postgrespro.ru", "phone": "+70000381380"}
0005432818245	44815A	8769 359405	SERGEY ANDREEV	{"phone": "+70578561471"}
0005432818246	9DA797	5639 282073	VALENTINA NESTEROVA	{"phone": "+70616655146"}
0005432818247	9DA797	4222 063985	IRINA PETROVA	{"email": "petrovai1966@postgrespro.ru", "phone": "+70881146146"}
0005432818248	70CE7D	9903 848081	TATYANA AFANASEVA	{"email": "afanaseva-t.1976@postgrespro.ru", "phone": "+70286021382"}
0005432818249	F14B45	1983 738916	VIKTOR FROLOV	{"email": "frolov-v_14111967@postgrespro.ru", "phone": "+70629995104"}
0005432818250	F14B45	3469 190952	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev.10091972@postgrespro.ru", "phone": "+70200695727"}
0005432818251	06DBAC	9771 572636	ALEKSEY IVANOV	{"email": "ivanov-a1964@postgrespro.ru", "phone": "+70373269420"}
0005432818252	06DBAC	2388 173449	LYUDMILA YUDINA	{"email": "yudina.l.121967@postgrespro.ru", "phone": "+70258978434"}
0005432818253	C3638A	6249 127228	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_05111977@postgrespro.ru", "phone": "+70069662881"}
0005432818254	CBB4D5	7368 234980	IRINA MELNIKOVA	{"email": "imelnikova.101981@postgrespro.ru", "phone": "+70108879163"}
0005432818255	CBB4D5	5743 733636	VYACHESLAV NAZAROV	{"email": "nazarov_vyacheslav.091980@postgrespro.ru", "phone": "+70739187059"}
0005432818256	BB04EE	2486 183443	MIKHAIL MIRONOV	{"email": "mironov-mikhail-081973@postgrespro.ru", "phone": "+70445445612"}
0005432818257	B271B6	8991 861853	STANISLAV IVANOV	{"phone": "+70288278146"}
0005432818258	B271B6	0407 474413	RAISA ABRAMOVA	{"email": "abramova.r.081978@postgrespro.ru", "phone": "+70594248758"}
0005432818259	E142B2	6637 202431	ALEKSEY IVANOV	{"phone": "+70360599002"}
0005432818260	113AA2	5702 558360	EVGENIY KAZAKOV	{"phone": "+70541646833"}
0005432818261	88317C	5450 055465	ALEKSANDR FEDOROV	{"phone": "+70643414659"}
0005432818262	43901C	1216 190699	VIKTOR POPOV	{"phone": "+70031641639"}
0005432818263	ECED25	2730 875672	TATYANA KUZMINA	{"email": "kuzmina-tatyana_101960@postgrespro.ru", "phone": "+70515335587"}
0005432818264	ECED25	7981 582959	SVETLANA SOLOVEVA	{"email": "ssoloveva_02051978@postgrespro.ru", "phone": "+70602292330"}
0005432818265	BB8D4D	9472 970592	TIMUR ANTONOV	{"phone": "+70695706169"}
0005432818266	BB8D4D	0314 775668	VALENTINA MAKSIMOVA	{"phone": "+70414675818"}
0005432818267	A654FF	5844 026128	ALBINA KUZNECOVA	{"email": "albinakuznecova-1982@postgrespro.ru", "phone": "+70137880238"}
0005432818268	FDB8FC	4395 905262	NADEZHDA YUDINA	{"phone": "+70798186184"}
0005432818269	4F244B	4752 615596	ELENA AKIMOVA	{"email": "elenaakimova_1961@postgrespro.ru", "phone": "+70211834548"}
0005432818270	B544C4	8733 637819	VLADIMIR EGOROV	{"phone": "+70282377132"}
0005432818271	DD0453	6607 105885	LYUBOV FOMINA	{"phone": "+70062387286"}
0005432818272	DD0453	6822 629411	LARISA KUZNECOVA	{"phone": "+70586695567"}
0005432818273	56C9DE	2828 783750	TATYANA YUDINA	{"email": "t_yudina-1979@postgrespro.ru", "phone": "+70912435782"}
0005432818274	0977E9	3064 879237	MIKHAIL ALEKSANDROV	{"email": "aleksandrov.m-1971@postgrespro.ru", "phone": "+70947842003"}
0005432818275	E8607B	4765 101640	OLEG KUZMIN	{"phone": "+70226273550"}
0005432818276	4C1605	4026 186489	OKSANA EFIMOVA	{"phone": "+70565442158"}
0005432818277	4C1605	5721 151816	VLADIMIR NAUMOV	{"phone": "+70157614353"}
0005432818278	F06B01	4230 382549	LYUDMILA KOZLOVA	{"phone": "+70907869490"}
0005432818279	2F1642	7963 344799	ANATOLIY NIKITIN	{"phone": "+70347925144"}
0005432818280	083584	4271 249422	TATYANA ISAEVA	{"email": "tatyana.isaeva101968@postgrespro.ru", "phone": "+70815104802"}
0005432818281	D069E6	0413 765918	LIDIYA SERGEEVA	{"email": "lidiya-sergeeva28121970@postgrespro.ru", "phone": "+70151190566"}
0005432818282	11EC33	2304 039276	VIKTORIYA IVANOVA	{"email": "ivanova.viktoriya-1973@postgrespro.ru", "phone": "+70936400716"}
0005432818283	11EC33	2459 196294	ANATOLIY ZHURAVLEV	{"phone": "+70155523352"}
0005432818284	11EC33	2980 798709	EVGENIY VLASOV	{"email": "evlasov1978@postgrespro.ru", "phone": "+70374654918"}
0005432818285	A849A3	0775 147369	SERAFIMA ZHUKOVA	{"phone": "+70643190566"}
0005432818286	A849A3	5287 466382	NINA ANTONOVA	{"email": "n_antonova1980@postgrespro.ru", "phone": "+70581649856"}
0005432818287	9CAA39	9535 632974	NATALIYA SMIRNOVA	{"phone": "+70149922048"}
0005432818288	9CAA39	9504 225224	ZHANNA ANTONOVA	{"email": "antonovazhanna-101980@postgrespro.ru", "phone": "+70723236088"}
0005432818289	CB3805	3709 950838	DMITRIY AFANASEV	{"phone": "+70953731429"}
0005432818290	CB3805	4316 692696	OLGA BORISOVA	{"email": "borisovaolga.031963@postgrespro.ru", "phone": "+70363401346"}
0005432818291	9D6CC7	8321 260230	KSENIYA MOISEEVA	{"email": "k.moiseeva081973@postgrespro.ru", "phone": "+70039842890"}
0005432818292	02E4FA	2411 547487	DMITRIY NOVIKOV	{"email": "d.novikov1975@postgrespro.ru", "phone": "+70250527124"}
0005432818293	49C10A	3114 276040	NATALIYA RYABOVA	{"email": "nryabova.1966@postgrespro.ru", "phone": "+70339919085"}
0005432818294	C620F9	6695 648378	SERGEY VASILEV	{"email": "s-vasilev.1974@postgrespro.ru", "phone": "+70489975253"}
0005432818295	2905E6	5646 812179	VYACHESLAV IVANOV	{"phone": "+70770253686"}
0005432818296	7A52A6	2172 644300	EVGENIY FILIPPOV	{"phone": "+70790601309"}
0005432818297	B678BA	7284 516527	ZINAIDA IVANOVA	{"phone": "+70182690963"}
0005432818298	731F18	7112 520748	VLADIMIR POPOV	{"phone": "+70683243100"}
0005432818299	731F18	6678 112949	EVGENIY NIKITIN	{"phone": "+70893261606"}
0005432818300	A09288	1001 126923	TAMARA ZAYCEVA	{"email": "zayceva-tamara051976@postgrespro.ru", "phone": "+70750083819"}
0005432818301	4AB5B4	1021 683624	DARYA CHERNOVA	{"email": "chernova_darya.31051983@postgrespro.ru", "phone": "+70078031808"}
0005432818302	4AB5B4	9713 641140	DMITRIY IVANOV	{"email": "dmitriyivanov1972@postgrespro.ru", "phone": "+70543882388"}
0005432818303	0D17E5	2095 493963	VLADIMIR OSIPOV	{"email": "osipov-v-20061972@postgrespro.ru", "phone": "+70398643120"}
0005432818304	BC6B33	8773 938501	ANASTASIYA MIRONOVA	{"email": "amironova-101981@postgrespro.ru", "phone": "+70969575945"}
0005432818305	BC6B33	1384 759037	ALEKSANDRA ISAEVA	{"email": "a-isaeva-1966@postgrespro.ru", "phone": "+70546607596"}
0005432818306	BC6B33	4193 614088	ANASTASIYA DMITRIEVA	{"email": "anastasiya.dmitrieva.18081970@postgrespro.ru", "phone": "+70733693212"}
0005432818307	AF25E3	2903 102466	SERGEY NIKITIN	{"email": "s-nikitin-30051954@postgrespro.ru", "phone": "+70430146840"}
0005432818308	190A96	5679 301415	LEONID SERGEEV	{"phone": "+70820951524"}
0005432818309	3F4C78	2908 061351	NIKOLAY YAKOVLEV	{"phone": "+70453537402"}
0005432818310	3F4C78	1492 119118	ANATOLIY GRIGOREV	{"email": "anatoliy_grigorev_1981@postgrespro.ru", "phone": "+70388869313"}
0005432818311	2E6831	6881 569754	VLADISLAV BELOV	{"phone": "+70577284119"}
0005432818312	3E67BD	4402 439875	IVAN BARANOV	{"email": "ibaranov05101966@postgrespro.ru", "phone": "+70547154049"}
0005432818313	29EC39	8395 993152	SERGEY KUZMIN	{"email": "s.kuzmin_1977@postgrespro.ru", "phone": "+70214276587"}
0005432818314	F0B7CD	2286 696620	EKATERINA YAKOVLEVA	{"phone": "+70250479710"}
0005432818315	F9E856	5320 783429	MARINA NESTEROVA	{"email": "marina_nesterova.1973@postgrespro.ru", "phone": "+70241191671"}
0005432818316	82B8C1	1817 825150	EVGENIY KUZNECOV	{"phone": "+70125899085"}
0005432818317	82B8C1	9043 419807	OLGA KISELEVA	{"phone": "+70639828947"}
0005432818318	9D6C5C	8656 679538	DARYA NAZAROVA	{"email": "darya_nazarova_1977@postgrespro.ru", "phone": "+70975592197"}
0005432818319	864106	8269 067580	SERGEY IVANOV	{"email": "s.ivanov_1974@postgrespro.ru", "phone": "+70691983289"}
0005432818320	864106	8314 664517	INNA ISAEVA	{"email": "i.isaeva1982@postgrespro.ru", "phone": "+70790607308"}
0005432818321	08F965	3205 458980	YURIY BONDARENKO	{"phone": "+70631728793"}
0005432818322	003EB8	0154 574798	ANASTASIYA IVANOVA	{"phone": "+70300835057"}
0005432818323	5335DB	0081 261922	VALERIYA NIKIFOROVA	{"phone": "+70965523962"}
0005432818324	AA63EC	8845 883072	ELENA KUZMINA	{"phone": "+70565376083"}
0005432818325	9D7E25	5677 590896	EVGENIY GUSEV	{"email": "evgeniy_gusev.13111974@postgrespro.ru", "phone": "+70217006109"}
0005432818326	9D7E25	3714 317185	ANATOLIY PAVLOV	{"phone": "+70771079384"}
0005432818327	010B25	2727 123865	MIKHAIL ANDREEV	{"email": "mandreev_081973@postgrespro.ru", "phone": "+70840972214"}
0005432818328	01E50A	8252 470320	ALEKSANDR MOISEEV	{"phone": "+70367954575"}
0005432818329	01E50A	0350 455507	NINA ZAYCEVA	{"email": "n.zayceva081968@postgrespro.ru", "phone": "+70710354147"}
0005432818330	0D82C9	7375 472811	RINAT DAVYDOV	{"email": "davydov-r1973@postgrespro.ru", "phone": "+70671038617"}
0005432818331	0D82C9	4455 864809	LARISA MAKSIMOVA	{"phone": "+70419594604"}
0005432818332	732BC0	1614 050351	VIKTORIYA ANISIMOVA	{"email": "viktoriyaanisimova_1975@postgrespro.ru", "phone": "+70679042628"}
0005432818333	92A58E	3571 203090	VLADIMIR EGOROV	{"email": "vladimir-egorov-20121975@postgrespro.ru", "phone": "+70915312258"}
0005432818334	0DFAF0	5029 967692	NIKOLAY NIKITIN	{"phone": "+70803242879"}
0005432818335	45E958	6936 824592	KRISTINA GORBUNOVA	{"email": "gorbunovak1989@postgrespro.ru", "phone": "+70158332310"}
0005432818336	74954E	2748 754988	DMITRIY PETROV	{"email": "dmitriy_petrov-20121973@postgrespro.ru", "phone": "+70059872732"}
0005432822064	6C2C76	2277 001535	NIKOLAY ROMANOV	{"email": "nikolay_romanov_07121966@postgrespro.ru", "phone": "+70477876595"}
0005432822065	6CD666	6340 725636	VERA ZAKHAROVA	{"phone": "+70647794370"}
0005432822066	6CD666	5420 029272	MIKHAIL KUDRYASHOV	{"email": "kudryashov_mikhail_031974@postgrespro.ru", "phone": "+70320853140"}
0005432822067	435D29	2525 974429	LIDIYA IVANOVA	{"email": "ivanova-l-1970@postgrespro.ru", "phone": "+70969747665"}
0005432822068	88B15F	4203 159384	MAKSIM FILIPPOV	{"phone": "+70616776107"}
0005432822069	D4D108	5755 059805	IRINA FEDOROVA	{"phone": "+70722787183"}
0005432822070	9B326E	6192 889578	SERGEY IVANOV	{"phone": "+70839090649"}
0005432822071	890859	3064 290674	ANDREY FROLOV	{"phone": "+70871967719"}
0005432822072	890859	0089 993672	ALEKSANDRA KUZNECOVA	{"email": "kuznecova-aleksandra.1971@postgrespro.ru", "phone": "+70408488147"}
0005432822073	824533	1938 188476	NATALYA ALEKSEEVA	{"phone": "+70553071346"}
0005432822074	302282	7352 043543	VALENTINA TARASOVA	{"email": "tarasova-v031979@postgrespro.ru", "phone": "+70913858324"}
0005432822075	302282	3985 671381	KONSTANTIN NIKOLAEV	{"phone": "+70392778343"}
0005432822076	590938	3440 422619	ANNA SOKOLOVA	{"phone": "+70910024082"}
0005432822077	575052	5356 855747	ANATOLIY VASILEV	{"email": "anatoliy.vasilev.21111976@postgrespro.ru", "phone": "+70418968857"}
0005432822078	273D1D	6299 567599	PAVEL YAKOVLEV	{"phone": "+70146435729"}
0005432822079	273D1D	0624 059607	LYUDMILA PETROVA	{"email": "petrova-lyudmila-091973@postgrespro.ru", "phone": "+70093011709"}
0005432822080	79A618	1224 344846	LYUBOV KUZMINA	{"email": "lyubov.kuzmina_061978@postgrespro.ru", "phone": "+70425986528"}
0005432822081	E2A263	2752 509677	SERGEY IVANOV	{"phone": "+70449852579"}
0005432822082	BC0FC5	3166 267216	SERGEY KUZNECOV	{"phone": "+70550255264"}
0005432822083	E96452	1108 351634	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir18021968@postgrespro.ru", "phone": "+70293295628"}
0005432822084	E96452	2807 120229	ALEKSANDR ANDREEV	{"email": "aandreev091966@postgrespro.ru", "phone": "+70264698111"}
0005432822085	918255	5977 378318	MARIYA ZHUKOVA	{"email": "m-zhukova-1963@postgrespro.ru", "phone": "+70268813456"}
0005432822086	918255	8896 151718	LIDIYA KAZAKOVA	{"phone": "+70875849953"}
0005432822087	F19D85	4073 655292	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila.25051975@postgrespro.ru", "phone": "+70323335592"}
0005432822088	A0E5D4	9313 715295	ZINAIDA DMITRIEVA	{"email": "zinaida_dmitrieva.071974@postgrespro.ru", "phone": "+70576337763"}
0005432822089	A0E5D4	3188 472461	GALINA IVANOVA	{"phone": "+70069471936"}
0005432822090	E8ACEC	3286 019376	RAMIL ANTONOV	{"email": "r-antonov18051967@postgrespro.ru", "phone": "+70820858713"}
0005432822091	4EEC71	7608 756960	VALERIY KULIKOV	{"email": "valeriy-kulikov1966@postgrespro.ru", "phone": "+70636200842"}
0005432822148	A63B76	2766 396776	YULIYA POPOVA	{"phone": "+70633483083"}
0005432822092	4EEC71	4411 192477	LIDIYA KOROLEVA	{"email": "l_koroleva.01121965@postgrespro.ru", "phone": "+70861454521"}
0005432822093	D1A876	4121 865230	ALEKSANDR EGOROV	{"email": "egorov_a-1963@postgrespro.ru", "phone": "+70105894371"}
0005432822094	D1A876	1060 780358	ALEKSANDR IVANOV	{"phone": "+70337694043"}
0005432822095	E32678	0499 257446	IRINA BELYAEVA	{"email": "i-belyaeva.101976@postgrespro.ru", "phone": "+70464464971"}
0005432822096	E32678	5229 775648	SVETLANA ALEKSEEVA	{"phone": "+70816875818"}
0005432822097	E32678	8614 272510	TAMARA BARANOVA	{"phone": "+70183297330"}
0005432822098	75CB68	9475 048002	OLGA KUZNECOVA	{"phone": "+70722749510"}
0005432822099	A47CBF	8121 720484	SVETLANA NIKIFOROVA	{"email": "snikiforova12011974@postgrespro.ru", "phone": "+70692421197"}
0005432822100	F801C5	6219 984866	OLGA GERASIMOVA	{"email": "gerasimovao_1969@postgrespro.ru", "phone": "+70931602621"}
0005432822101	F801C5	5945 825234	DMITRIY KAZAKOV	{"email": "dmitriykazakov-111979@postgrespro.ru", "phone": "+70012963460"}
0005432822102	D1830C	8978 113073	ALEKSEY ANTONOV	{"email": "alekseyantonov-29101961@postgrespro.ru", "phone": "+70409402560"}
0005432822103	733D1A	1383 202062	ALEKSEY NAUMOV	{"email": "naumova.011971@postgrespro.ru", "phone": "+70687465245"}
0005432822104	733D1A	5869 864512	EVGENIY STEPANOV	{"email": "stepanov.e101970@postgrespro.ru", "phone": "+70969588965"}
0005432822105	733D1A	5273 852482	VLADIMIR ILIN	{"phone": "+70569188030"}
0005432822106	2EEE50	6747 138629	NIKOLAY MOROZOV	{"phone": "+70173116340"}
0005432822107	2EEE50	9353 457099	SERGEY MEDVEDEV	{"phone": "+70371891441"}
0005432822108	FFF86A	6861 634239	ALEKSANDR ZAKHAROV	{"email": "zakharov.a-061972@postgrespro.ru", "phone": "+70654304495"}
0005432822109	CA9AE3	3372 168641	ALEKSANDR ZHURAVLEV	{"phone": "+70445031189"}
0005432822110	CA9AE3	2696 226010	IVAN IVANOV	{"email": "iivanov.111976@postgrespro.ru", "phone": "+70480010065"}
0005432822111	5223C4	6942 893622	OLEG ANDREEV	{"phone": "+70768822163"}
0005432822112	5223C4	1419 037633	ANNA KUZMINA	{"phone": "+70040586587"}
0005432822113	9A6F7E	1999 175149	TIMOFEY OSIPOV	{"phone": "+70653815737"}
0005432822114	9A6F7E	4826 107407	ALEKSANDR NIKITIN	{"phone": "+70417168036"}
0005432822115	E431F6	8968 701927	IGOR VASILEV	{"email": "vasilevigor.13121957@postgrespro.ru", "phone": "+70553535115"}
0005432822116	E431F6	3101 198030	LIDIYA LOGINOVA	{"email": "lidiya_loginova1970@postgrespro.ru", "phone": "+70514797045"}
0005432822117	DA6ED0	8738 758376	MARIYA YAKOVLEVA	{"phone": "+70861579529"}
0005432822118	DA6ED0	2767 870223	ALEKSANDR OSIPOV	{"phone": "+70590723375"}
0005432822119	11A47C	1946 436782	DMITRIY ROMANOV	{"email": "romanovd08101969@postgrespro.ru", "phone": "+70295389937"}
0005432822120	11A47C	7615 166098	SERGEY EGOROV	{"phone": "+70755140989"}
0005432822121	9EF8D7	3666 928620	VALERIY ALEKSANDROV	{"email": "aleksandrovv1969@postgrespro.ru", "phone": "+70389498725"}
0005432822122	D4412E	5471 990659	VLADIMIR ANDREEV	{"phone": "+70193492097"}
0005432822123	FC2580	5195 877345	ALEKSEY MEDVEDEV	{"phone": "+70804751529"}
0005432822124	474ECE	0442 654111	DMITRIY MOISEEV	{"phone": "+70656717497"}
0005432822125	474ECE	4965 913104	LYUDMILA TARASOVA	{"phone": "+70801176907"}
0005432822126	474ECE	3733 023705	OLGA PETROVA	{"email": "petrova.olga30041972@postgrespro.ru", "phone": "+70506360194"}
0005432822127	383375	6532 903866	SERGEY FILIPPOV	{"email": "filippov_s_071968@postgrespro.ru", "phone": "+70446816451"}
0005432822128	383375	3753 080902	ALEKSANDR ANDREEV	{"phone": "+70704040095"}
0005432822129	383375	0364 806750	NIKOLAY KAZAKOV	{"phone": "+70024507343"}
0005432822130	4BCA91	8675 603371	YAKOV KOROLEV	{"phone": "+70231887966"}
0005432822131	06E9E6	4560 863746	VYACHESLAV SCHERBAKOV	{"email": "scherbakovv091981@postgrespro.ru", "phone": "+70480093721"}
0005432822132	5BBFFB	2022 046708	PETR MATVEEV	{"email": "matveev-petr.06021961@postgrespro.ru", "phone": "+70891302847"}
0005432822133	5BBFFB	3368 808355	VLADISLAV MELNIKOV	{"phone": "+70716274556"}
0005432822134	5BBFFB	7740 787658	EKATERINA IVANOVA	{"email": "ivanova_ekaterina081971@postgrespro.ru", "phone": "+70143370637"}
0005432822135	D3A1B0	7605 755256	ALEKSANDR KOZLOV	{"phone": "+70040666128"}
0005432822136	D3A1B0	4993 692531	ANDREY GUSEV	{"email": "andrey_gusev121963@postgrespro.ru", "phone": "+70376599060"}
0005432822137	936D83	8872 672412	MARIYA SAVELEVA	{"email": "saveleva-mariya011973@postgrespro.ru", "phone": "+70035671688"}
0005432822138	936D83	8877 728640	ALEKSEY GRIGOREV	{"phone": "+70220612163"}
0005432822139	C0E726	0781 001838	ANTONINA MIRONOVA	{"email": "mironova_antonina1977@postgrespro.ru", "phone": "+70655304953"}
0005432822140	315500	2444 860840	IVAN SERGEEV	{"email": "sergeevivan_071977@postgrespro.ru", "phone": "+70633763564"}
0005432822141	F69B70	4077 873748	TATYANA VASILEVA	{"email": "tatyana_vasileva.031972@postgrespro.ru", "phone": "+70796516504"}
0005432822142	229CB5	9662 224011	ALBINA SOROKINA	{"email": "a_sorokina.1983@postgrespro.ru", "phone": "+70977032615"}
0005432822143	56A533	0945 527954	ANASTASIYA MAKSIMOVA	{"email": "anastasiya_maksimova-091970@postgrespro.ru", "phone": "+70121968236"}
0005432822144	96D995	1587 422801	ALEKSEY BELOV	{"email": "alekseybelov.071975@postgrespro.ru", "phone": "+70456679397"}
0005432822145	96D995	7305 884472	DARYA BELOVA	{"email": "belova_darya-27121982@postgrespro.ru", "phone": "+70783738121"}
0005432822146	A63B76	8519 907591	VALENTINA KRASNOVA	{"phone": "+70019226443"}
0005432822147	A63B76	5933 347211	VLADIMIR FILIPPOV	{"phone": "+70810944550"}
0005432822149	053A91	6460 223636	ILYA IVANOV	{"phone": "+70475290756"}
0005432822150	4F422A	9712 298179	NATALYA BARANOVA	{"email": "nbaranova1980@postgrespro.ru", "phone": "+70428844848"}
0005432822151	24414A	0462 698622	OKSANA FROLOVA	{"email": "frolova.oksana_111966@postgrespro.ru", "phone": "+70065308639"}
0005432822152	24414A	3182 571268	ALEKSANDR MARTYNOV	{"email": "a_martynov-04081969@postgrespro.ru", "phone": "+70808901465"}
0005432822153	527C5E	8888 066237	RAFAIL SAVELEV	{"phone": "+70330629138"}
0005432822154	527C5E	0973 065633	OLGA NESTEROVA	{"phone": "+70047714475"}
0005432822155	5EDC23	0992 320907	DARYA ZHUKOVA	{"phone": "+70752101379"}
0005432822156	28F01F	5272 653707	IVAN BELOV	{"phone": "+70572994218"}
0005432822157	28F01F	0043 100842	VYACHESLAV GRIGOREV	{"phone": "+70003535955"}
0005432822158	60E308	5487 172289	ALEKSEY FILIPPOV	{"email": "filippov.aleksey.25091970@postgrespro.ru", "phone": "+70074893139"}
0005432822159	827407	0852 416749	YURIY KOZLOV	{"phone": "+70182906479"}
0005432822160	689D74	7393 821942	OLGA EFREMOVA	{"phone": "+70486612328"}
0005432822161	47086C	9850 102358	RAVIL ANTONOV	{"phone": "+70299746346"}
0005432822162	A68301	9612 157807	ELENA STEPANOVA	{"email": "e-stepanova16021973@postgrespro.ru", "phone": "+70071128701"}
0005432822163	A68301	3263 756820	SVETLANA KUZNECOVA	{"phone": "+70859236909"}
0005432822164	164EC4	6763 902911	MAKSIM NIKITIN	{"phone": "+70790339266"}
0005432822165	ACF807	0017 033930	ELENA MAKAROVA	{"email": "makarova_elena31031973@postgrespro.ru", "phone": "+70330345665"}
0005432822166	497FEA	4441 220381	ANTON BORISOV	{"phone": "+70187698810"}
0005432822167	2785BA	3670 597031	NATALYA DMITRIEVA	{"email": "dmitrieva-natalya-021972@postgrespro.ru", "phone": "+70711628507"}
0005432822168	D185E3	5636 547455	ANASTASIYA ANDREEVA	{"email": "aandreeva_1969@postgrespro.ru", "phone": "+70722709734"}
0005432822169	6959E4	9513 003017	ELENA KOZLOVA	{"phone": "+70636449637"}
0005432822170	8A7ECD	5046 350977	ALEKSANDR EGOROV	{"phone": "+70294821279"}
0005432822171	E3CE68	3566 810496	OLGA NOVIKOVA	{"email": "olga-novikova_31031979@postgrespro.ru", "phone": "+70600565187"}
0005432822172	1666D9	5244 124938	NINA POLYAKOVA	{"email": "npolyakova-111975@postgrespro.ru", "phone": "+70289202154"}
0005432822173	23A7F7	9959 822073	MIKHAIL KUZNECOV	{"phone": "+70460570733"}
0005432822174	D05416	7306 770668	NADEZHDA ALEKSEEVA	{"phone": "+70729573630"}
0005432822175	D05416	5962 644859	YULIYA NESTEROVA	{"email": "nesterova-yuliya_021974@postgrespro.ru", "phone": "+70256956748"}
0005432822176	D63276	6267 640969	LYUDMILA MIRONOVA	{"phone": "+70302713674"}
0005432822177	5B134B	1949 439480	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko-17101963@postgrespro.ru", "phone": "+70098216460"}
0005432822178	0FEFF3	2124 097032	FAINA DENISOVA	{"phone": "+70655961774"}
0005432822179	B65432	4171 807887	MARINA YUDINA	{"email": "m-yudina_031983@postgrespro.ru", "phone": "+70135735077"}
0005432822180	B65432	4325 643122	NINA AKIMOVA	{"phone": "+70378683606"}
0005432822181	22D9E3	2249 849554	IRINA MAKAROVA	{"phone": "+70800774264"}
0005432822182	2ECEE7	5762 267723	MARINA EGOROVA	{"phone": "+70927095295"}
0005432822183	764772	3195 499216	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir-051963@postgrespro.ru", "phone": "+70592339324"}
0005432822184	271107	9306 966911	VIKTOR BORISOV	{"email": "viktor.borisov_091976@postgrespro.ru", "phone": "+70943085720"}
0005432822185	271107	0695 459347	LYUBOV ZAKHAROVA	{"phone": "+70139569436"}
0005432822186	80B439	9038 835601	IRINA BELYAEVA	{"email": "irina_belyaeva-14061963@postgrespro.ru", "phone": "+70109552116"}
0005432822187	80B439	6182 262483	VLADIMIR ROMANOV	{"email": "romanovv.17081981@postgrespro.ru", "phone": "+70794205824"}
0005432822188	80B439	4255 931764	NIKOLAY MELNIKOV	{"email": "nmelnikov.031973@postgrespro.ru", "phone": "+70027563296"}
0005432822189	4F2676	2978 453092	VALENTINA VASILEVA	{"email": "valentina.vasileva.011973@postgrespro.ru", "phone": "+70835563330"}
0005432822190	7B1444	9808 011099	ALEKSEY MOISEEV	{"phone": "+70411264693"}
0005432822191	7B1444	2578 649804	YURIY SOROKIN	{"email": "sorokin.y1973@postgrespro.ru", "phone": "+70777290040"}
0005432822192	CCEF02	9578 521486	MAKSIM KUZNECOV	{"email": "maksim-kuznecov-21011976@postgrespro.ru", "phone": "+70855849014"}
0005432822193	45BAE9	5340 239032	SERGEY PETROV	{"phone": "+70670930741"}
0005432822194	BA9297	5341 331134	VIKTOR MATVEEV	{"phone": "+70393546104"}
0005432822195	BA9297	2835 627155	ANATOLIY MAKSIMOV	{"email": "amaksimov.041966@postgrespro.ru", "phone": "+70678171988"}
0005432822196	847EC7	8680 337463	VLADIMIR FEDOROV	{"email": "vladimir_fedorov-1974@postgrespro.ru", "phone": "+70792585241"}
0005432822197	A0B375	3727 169943	IRINA SMIRNOVA	{"email": "irinasmirnova011980@postgrespro.ru", "phone": "+70929314361"}
0005432822198	CA303F	1554 574180	VALERIY PAVLOV	{"email": "v.pavlov_17071969@postgrespro.ru", "phone": "+70802339205"}
0005432822199	CC4B95	8816 220258	IRINA KUZNECOVA	{"email": "kuznecova_i.1981@postgrespro.ru", "phone": "+70845938165"}
0005432822200	E4EE62	2993 680037	DMITRIY SCHERBAKOV	{"email": "dmitriy_scherbakov_04051972@postgrespro.ru", "phone": "+70524182844"}
0005432822201	E4EE62	2742 652057	SERGEY SMIRNOV	{"phone": "+70776700800"}
0005432822202	EFC836	0055 927281	KLAVDIYA GUSEVA	{"phone": "+70868370497"}
0005432822203	EFC836	2526 126848	ANASTASIYA SEMENOVA	{"email": "a_semenova-101976@postgrespro.ru", "phone": "+70601050809"}
0005432822204	524968	5853 748656	VIKTORIYA SCHERBAKOVA	{"email": "v-scherbakova041981@postgrespro.ru", "phone": "+70586535499"}
0005432822205	524968	7602 755505	ANDREY FROLOV	{"phone": "+70928247701"}
0005432822206	F1F0EB	9306 501951	NADEZHDA FROLOVA	{"phone": "+70247941979"}
0005432822207	3EAF8A	0511 277469	LYUBOV MALYSHEVA	{"phone": "+70739894470"}
0005432822208	758E6F	4388 390190	PAVEL FEDOROV	{"phone": "+70622141736"}
0005432822209	758E6F	3163 026149	LYUDMILA NAZAROVA	{"email": "nazaroval-071964@postgrespro.ru", "phone": "+70098027257"}
0005432822210	758E6F	8849 936862	VIKTOR VASILEV	{"phone": "+70949691006"}
0005432822211	B0F57B	0544 810712	TATYANA KUZNECOVA	{"email": "kuznecovat.10081969@postgrespro.ru", "phone": "+70434637416"}
0005432822212	F447DC	9814 489582	VIKTOR ANTONOV	{"phone": "+70529772806"}
0005432822213	F583B4	9335 176949	SVETLANA KISELEVA	{"email": "s_kiseleva-011982@postgrespro.ru", "phone": "+70702085786"}
0005432822214	729973	0978 420426	ALEKSANDRA ZAYCEVA	{"phone": "+70008061644"}
0005432822215	C207B7	9360 613860	ANDREY GRIGOREV	{"email": "grigorev-andrey_28091974@postgrespro.ru", "phone": "+70240177672"}
0005432822216	C207B7	9828 319399	TATYANA BELOVA	{"phone": "+70902743894"}
0005432822272	2EA9E6	7727 750471	SERGEY DMITRIEV	{"phone": "+70070438444"}
0005432822217	20F9CA	1463 488765	IRINA MOROZOVA	{"email": "irina-morozova.1962@postgrespro.ru", "phone": "+70677346768"}
0005432822218	0A3500	6455 718169	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr.20061969@postgrespro.ru", "phone": "+70334637662"}
0005432822219	ABCBCB	1152 156956	LYUDMILA KONOVALOVA	{"email": "konovaloval051982@postgrespro.ru", "phone": "+70012348555"}
0005432822220	0B3FE0	1768 681998	SVETLANA KUZMINA	{"email": "svetlana.kuzmina-081981@postgrespro.ru", "phone": "+70030414711"}
0005432822221	EFADF1	2826 234571	ANDREY MOISEEV	{"email": "andrey-moiseev.121977@postgrespro.ru", "phone": "+70116016703"}
0005432822222	EFADF1	1372 782338	SERGEY BELOV	{"phone": "+70020300060"}
0005432822223	F21532	6940 106037	GRIGORIY ANTONOV	{"email": "grigoriy.antonov05041968@postgrespro.ru", "phone": "+70876823145"}
0005432822224	F21532	4447 148315	TAMARA GORBUNOVA	{"email": "gorbunova_tamara16121974@postgrespro.ru", "phone": "+70117303825"}
0005432822225	7D41AB	6445 110273	GALINA KUZNECOVA	{"email": "kuznecovag-021973@postgrespro.ru", "phone": "+70415004555"}
0005432822226	7D41AB	6765 284278	VALENTINA KUZNECOVA	{"email": "valentinakuznecova-29071969@postgrespro.ru", "phone": "+70838673475"}
0005432822227	800003	4138 391821	IVAN POPOV	{"phone": "+70748402357"}
0005432822228	93E922	6122 909281	VALENTINA PAVLOVA	{"email": "valentina.pavlova1973@postgrespro.ru", "phone": "+70961549242"}
0005432822229	07AE99	1161 735302	ALEKSEY KUZMIN	{"email": "aleksey_kuzmin_1964@postgrespro.ru", "phone": "+70824785016"}
0005432822230	07AE99	2594 554777	ANASTASIYA SAVELEVA	{"email": "saveleva_a-14111971@postgrespro.ru", "phone": "+70560241412"}
0005432822231	89BC77	0699 021315	TATYANA ABRAMOVA	{"phone": "+70790802597"}
0005432822232	B7076F	3492 471058	DMITRIY KUZNECOV	{"email": "kuznecov_d1979@postgrespro.ru", "phone": "+70120168321"}
0005432822233	B7076F	1121 398466	ANDREY MEDVEDEV	{"email": "andrey_medvedev-31101975@postgrespro.ru", "phone": "+70069060573"}
0005432822234	B7076F	8007 362718	ALLA KOZLOVA	{"email": "a_kozlova101981@postgrespro.ru", "phone": "+70012164775"}
0005432822235	5D5C9B	9704 749456	LYUDMILA ARKHIPOVA	{"phone": "+70636087668"}
0005432822236	C5A8EA	8524 127369	ZINAIDA SMIRNOVA	{"email": "z-smirnova-041971@postgrespro.ru", "phone": "+70342393441"}
0005432822237	761E81	7134 355731	ALEKSANDR ISAEV	{"phone": "+70294541119"}
0005432822238	B71D03	3931 953673	OLEG IVANOV	{"phone": "+70788050709"}
0005432822239	59E201	8277 658674	NINA MALYSHEVA	{"phone": "+70350759619"}
0005432822240	59E201	2062 447914	SERGEY PETROV	{"email": "sergeypetrov_101981@postgrespro.ru", "phone": "+70129379692"}
0005432822241	59E201	9771 063004	SERGEY SIDOROV	{"email": "sidorovsergey_1972@postgrespro.ru", "phone": "+70992368710"}
0005432822242	495859	6576 154187	EKATERINA KUZMINA	{"email": "kuzmina.e-041967@postgrespro.ru", "phone": "+70946105971"}
0005432822243	495859	5625 833503	MARINA AFANASEVA	{"email": "marina-afanaseva.1969@postgrespro.ru", "phone": "+70853249071"}
0005432822244	780454	2224 617779	OKSANA ALEKSEEVA	{"phone": "+70961833744"}
0005432822245	780454	5656 397818	NATALYA RYABOVA	{"phone": "+70051295300"}
0005432822246	6A29BA	9742 454237	MIKHAIL BARANOV	{"email": "baranov_m.24111973@postgrespro.ru", "phone": "+70176058955"}
0005432822247	8F39D8	0299 266449	YULIYA RODIONOVA	{"email": "y_rodionova.05011971@postgrespro.ru", "phone": "+70214098231"}
0005432822248	8F39D8	0396 789268	VIKTORIYA ZAYCEVA	{"email": "zayceva_v_1973@postgrespro.ru", "phone": "+70781819587"}
0005432822249	8EAE6B	3640 897030	SERGEY KUZNECOV	{"phone": "+70860214137"}
0005432822250	919292	0886 020675	SVETLANA NIKITINA	{"email": "nikitina-s_091975@postgrespro.ru", "phone": "+70848177294"}
0005432822251	66646A	2911 432679	VLADISLAV CHERNOV	{"email": "chernov_v_011979@postgrespro.ru", "phone": "+70477935121"}
0005432822252	78D6A0	5844 169693	VERA MELNIKOVA	{"phone": "+70143815303"}
0005432822253	78D6A0	9442 055363	ALEKSANDR ZHUKOV	{"email": "azhukov.021984@postgrespro.ru", "phone": "+70144928882"}
0005432822254	4F4EE6	3523 718585	NIKOLAY FROLOV	{"email": "frolov.n.31101972@postgrespro.ru", "phone": "+70392895372"}
0005432822255	D9C3CC	3630 461756	NATALYA VASILEVA	{"email": "natalya_vasileva_051978@postgrespro.ru", "phone": "+70519378425"}
0005432822256	C4E83E	3672 149118	ALEKSANDRA MIKHAYLOVA	{"phone": "+70566249435"}
0005432822257	C4E83E	9216 800544	ALEKSANDRA KOVALEVA	{"phone": "+70936723449"}
0005432822258	5EE684	6743 150306	SERGEY SAVELEV	{"email": "s.savelev1976@postgrespro.ru", "phone": "+70543796825"}
0005432822259	C458E1	3821 270982	KONSTANTIN ABRAMOV	{"phone": "+70223758822"}
0005432822260	1CBC34	1655 152466	NADEZHDA TROFIMOVA	{"email": "nadezhdatrofimova-041965@postgrespro.ru", "phone": "+70502959417"}
0005432822261	D61231	9795 386802	EVGENIY MAKAROV	{"email": "emakarov-16111969@postgrespro.ru", "phone": "+70693096929"}
0005432822262	D61231	8779 255929	NATALYA ZAYCEVA	{"email": "zayceva_n1971@postgrespro.ru", "phone": "+70092816914"}
0005432822263	D61231	7972 787493	DMITRIY SOKOLOV	{"phone": "+70803056933"}
0005432822264	C7E7DC	8123 284444	INNA STEPANOVA	{"phone": "+70195539048"}
0005432822265	26813D	2426 178651	VASILIY FROLOV	{"email": "vasiliy_frolov.05031969@postgrespro.ru", "phone": "+70052988375"}
0005432822266	71E6DB	4315 131412	VALENTINA SAVELEVA	{"phone": "+70460650177"}
0005432822267	71E6DB	9873 909233	ELENA KUZNECOVA	{"email": "elena_kuznecova_17101974@postgrespro.ru", "phone": "+70615510371"}
0005432822268	71E6DB	8950 313102	PETR SHEVCHENKO	{"phone": "+70965808300"}
0005432822269	E4A6F7	6866 987038	EGOR SEMENOV	{"email": "egor_semenov.1978@postgrespro.ru", "phone": "+70054587276"}
0005432822270	164614	9995 525976	PETR KUZNECOV	{"email": "kuznecov_petr21061968@postgrespro.ru", "phone": "+70564636421"}
0005432822271	C569ED	8031 468923	TATYANA EGOROVA	{"phone": "+70439501572"}
0005432822273	B6C5A3	5893 804753	ALEKSEY VASILEV	{"email": "vasilevaleksey10041971@postgrespro.ru", "phone": "+70869028089"}
0005432822274	8B4BA5	3877 357534	ANDREY KISELEV	{"email": "kiselev-andrey_1971@postgrespro.ru", "phone": "+70801279503"}
0005432822275	8B4BA5	5541 115952	LYUBOV SMIRNOVA	{"phone": "+70919356820"}
0005432822276	A6D2D2	4351 290510	VALERIYA PAVLOVA	{"email": "pavlova-v-1984@postgrespro.ru", "phone": "+70088365072"}
0005432822277	66EA33	6886 325783	GALINA SEMENOVA	{"phone": "+70311328458"}
0005432822278	007638	4293 794276	TATYANA KOROLEVA	{"email": "t.koroleva1969@postgrespro.ru", "phone": "+70453397677"}
0005432822279	286B92	4097 335311	ALEKSANDR ZAKHAROV	{"email": "a-zakharov.08061974@postgrespro.ru", "phone": "+70303849211"}
0005432822280	01C549	2882 130514	LYUDMILA MIRONOVA	{"phone": "+70670027185"}
0005432822281	25B328	3072 108420	OLEG MIRONOV	{"email": "mironov_o-15091970@postgrespro.ru", "phone": "+70271742298"}
0005432822282	505E0B	5190 313155	MIKHAIL CHERNOV	{"email": "chernov_m061969@postgrespro.ru", "phone": "+70976560681"}
0005432822283	F47588	9042 421657	ALEKSANDR KISELEV	{"phone": "+70904531453"}
0005432822284	F47588	7715 836259	YURIY EGOROV	{"phone": "+70189410776"}
0005432822285	0D1D21	8138 239242	ARINA ORLOVA	{"phone": "+70771890490"}
0005432822286	F2BD3A	4563 751246	VADIM KUDRYASHOV	{"phone": "+70840282717"}
0005432822287	ACE298	7652 169003	YURIY ZAKHAROV	{"phone": "+70396486415"}
0005432822288	FCA1A0	5144 662310	ALEKSEY ILIN	{"email": "ilin.a_26031977@postgrespro.ru", "phone": "+70844726885"}
0005432822289	FCA1A0	8393 199959	VIKTORIYA OSIPOVA	{"email": "osipovaviktoriya_1965@postgrespro.ru", "phone": "+70599344461"}
0005432822290	63A096	8252 859939	TAISIYA KOROLEVA	{"phone": "+70349355546"}
0005432822291	63A096	7110 851603	PAVEL IVANOV	{"phone": "+70700324225"}
0005432822292	63A096	2438 626893	ELINA MIKHAYLOVA	{"phone": "+70576918611"}
0005432822293	7648F1	2358 783806	KLAVDIYA KONOVALOVA	{"phone": "+70189524474"}
0005432822294	39CEC8	9318 043204	IGOR ALEKSANDROV	{"phone": "+70800357844"}
0005432822295	39CEC8	4179 065558	NURIYA KOZLOVA	{"email": "nkozlova_1960@postgrespro.ru", "phone": "+70942687832"}
0005432822296	E25632	1750 182316	ALEKSANDR EGOROV	{"email": "egorov.aleksandr051975@postgrespro.ru", "phone": "+70402616597"}
0005432822297	3CDA4C	8591 455310	YANA SOROKINA	{"email": "sorokinay.1970@postgrespro.ru", "phone": "+70030449835"}
0005432822298	582491	1174 417656	LIDIYA PAVLOVA	{"email": "l_pavlova-051973@postgrespro.ru", "phone": "+70439023299"}
0005432822299	5EE192	4579 224011	VIKTOR KULIKOV	{"phone": "+70186270791"}
0005432822300	5EE192	6651 582338	IRAIDA IVANOVA	{"phone": "+70330929236"}
0005432822301	83386B	8785 207209	GALINA KRASNOVA	{"email": "galina.krasnova_1980@postgrespro.ru", "phone": "+70839493222"}
0005432822302	C51173	8090 896495	RINAT VOLKOV	{"phone": "+70409632159"}
0005432822303	654434	6241 255973	VIKTOR IVANOV	{"phone": "+70828147966"}
0005432822304	64EDC6	0131 731767	ANATOLIY MOROZOV	{"phone": "+70536728415"}
0005432822305	64EDC6	8509 295156	ANTONINA KUZNECOVA	{"email": "kuznecova_antonina_11011967@postgrespro.ru", "phone": "+70290319641"}
0005432822306	64EDC6	8412 819299	MAKSIM NAZAROV	{"email": "m-nazarov.091982@postgrespro.ru", "phone": "+70112166247"}
0005432822307	BAF228	7049 412330	ALEKSANDR OSIPOV	{"email": "osipov_a28051975@postgrespro.ru", "phone": "+70598443429"}
0005432822308	CCA9B1	4505 025630	DARYA FEDOROVA	{"email": "d_fedorova_121976@postgrespro.ru", "phone": "+70270983378"}
0005432822309	CCA9B1	1884 313525	ALEKSANDR KOZLOV	{"phone": "+70386301879"}
0005432822310	58B387	1973 466600	SERGEY SMIRNOV	{"email": "smirnovsergey_21081972@postgrespro.ru", "phone": "+70416148833"}
0005432822311	EE3A99	3663 367674	TATYANA NESTEROVA	{"email": "tatyana.nesterova1970@postgrespro.ru", "phone": "+70824970631"}
0005432822312	C8057E	6237 078502	EKATERINA EFREMOVA	{"email": "ekaterina.efremova1956@postgrespro.ru", "phone": "+70889019883"}
0005432822313	17120F	5275 298002	KONSTANTIN TIMOFEEV	{"phone": "+70939725109"}
0005432822314	3CB72D	9742 367099	SARIYA VOLKOVA	{"email": "volkova.s.1968@postgrespro.ru", "phone": "+70167799775"}
0005432822315	158F77	6698 648293	IVAN ZAYCEV	{"phone": "+70611681468"}
0005432822316	B17C2A	1281 609661	TATYANA FILATOVA	{"email": "tatyana_filatova061970@postgrespro.ru", "phone": "+70830776603"}
0005432822317	B17C2A	5440 845543	KSENIYA MAKAROVA	{"email": "makarova-kseniya-1971@postgrespro.ru", "phone": "+70274172167"}
0005432822318	1650E7	9509 679819	ANASTASIYA FOMINA	{"phone": "+70435413796"}
0005432822319	17EFBE	3281 876046	BORIS SHEVCHENKO	{"phone": "+70982758378"}
0005432822320	17EFBE	2223 972968	MARIYA DAVYDOVA	{"phone": "+70865878902"}
0005432822321	B68749	2150 488288	TATYANA NIKITINA	{"phone": "+70534002079"}
0005432822322	B68749	4008 841147	VERA FILATOVA	{"email": "vera.filatova1984@postgrespro.ru", "phone": "+70512749800"}
0005432822323	7ADC1F	8422 119906	NINA MAKAROVA	{"phone": "+70446460905"}
0005432822324	F72C38	2930 819880	IGOR IVANOV	{"phone": "+70696906410"}
0005432822325	F72C38	5255 800401	SVETLANA BOGDANOVA	{"email": "s.bogdanova_051966@postgrespro.ru", "phone": "+70632901852"}
0005432822326	F72C38	8251 508671	MAKSIM SOKOLOV	{"phone": "+70835927452"}
0005432822327	EA3984	4047 418262	NATALYA ROMANOVA	{"email": "romanova_natalya1970@postgrespro.ru", "phone": "+70248542158"}
0005432822328	E1C838	5285 466614	SERGEY MATVEEV	{"phone": "+70975042689"}
0005432822329	E1C838	2342 076829	LEV BONDARENKO	{"phone": "+70056423440"}
0005432822330	6B6044	6830 077444	MARINA MOROZOVA	{"email": "morozovam07011968@postgrespro.ru", "phone": "+70790195815"}
0005432822331	BC4D72	7061 466883	NADEZHDA KAZAKOVA	{"email": "kazakova_nadezhda_1974@postgrespro.ru", "phone": "+70615604506"}
0005432822332	CBA31C	3210 340392	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov_18041978@postgrespro.ru", "phone": "+70657886382"}
0005432822333	CBA31C	0257 745123	SERGEY MELNIKOV	{"email": "melnikov_s.071976@postgrespro.ru", "phone": "+70034510916"}
0005432822334	6E642D	3388 224019	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr_08031979@postgrespro.ru", "phone": "+70906108829"}
0005432822335	8DBCFD	7423 753244	ANTONINA IVANOVA	{"phone": "+70832399147"}
0005432822336	C2E55F	1804 827811	ALEKSANDR GRIGOREV	{"phone": "+70275362529"}
0005432822337	37472C	3632 993321	VLADIMIR DAVYDOV	{"email": "vladimirdavydov_12041973@postgrespro.ru", "phone": "+70273994350"}
0005432822338	CE9BB4	0775 783533	NADEZHDA MAKAROVA	{"phone": "+70057411293"}
0005432822339	83E7A5	0556 314599	EKATERINA MAKAROVA	{"email": "makarova_e.081969@postgrespro.ru", "phone": "+70652763267"}
0005432822340	A6D2D5	1341 473562	OLGA TROFIMOVA	{"phone": "+70275314682"}
0005432822341	B57B32	8872 266207	YULIYA KULIKOVA	{"phone": "+70375916738"}
0005432822342	975CBC	5393 721151	ROMAN NIKOLAEV	{"phone": "+70146008966"}
0005432822343	5685A5	7925 089156	ARTEM KULIKOV	{"email": "a.kulikov061965@postgrespro.ru", "phone": "+70123786031"}
0005432822344	5685A5	6064 564615	VLADIMIR GORBUNOV	{"email": "v-gorbunov-09101965@postgrespro.ru", "phone": "+70009495667"}
0005432822345	15A047	7610 581908	DIANA VOROBEVA	{"email": "vorobeva_d-1968@postgrespro.ru", "phone": "+70782072889"}
0005432822346	15A047	2906 457669	ILYAS TIKHONOV	{"email": "tikhonov_ilyas_1984@postgrespro.ru", "phone": "+70850323151"}
0005432822347	C93FEF	9289 989258	NIKITA VOLKOV	{"phone": "+70229924759"}
0005432822348	2C6E03	3604 596204	LIDIYA SEMENOVA	{"email": "lsemenova.021977@postgrespro.ru", "phone": "+70025760133"}
0005432822349	4A6C5B	2117 271813	EVGENIY SERGEEV	{"email": "e-sergeev.061971@postgrespro.ru", "phone": "+70422676823"}
0005432822350	E186DF	9783 804227	VIKTOR OSIPOV	{"phone": "+70445486691"}
0005432822351	F836CA	9130 215589	GENNADIY SOKOLOV	{"email": "sokolovg_1974@postgrespro.ru", "phone": "+70494440362"}
0005432822352	A4926A	5791 541118	KSENIYA MIRONOVA	{"phone": "+70902183899"}
0005432822353	FAECD3	7060 736324	VALENTINA KOZLOVA	{"phone": "+70521971662"}
0005432822354	01889A	7048 320845	ELENA VLASOVA	{"phone": "+70145142908"}
0005432822355	0F87C4	9226 993840	LYUDMILA KUDRYASHOVA	{"phone": "+70565263673"}
0005432822356	62865F	6151 791565	VASILIY SAVELEV	{"phone": "+70906521513"}
0005432822357	5B00D4	8920 462812	DARYA ALEKSEEVA	{"email": "darya.alekseeva_051984@postgrespro.ru", "phone": "+70894045886"}
0005432822358	5B00D4	2780 083270	ALEKSEY KUDRYASHOV	{"email": "kudryashov-a-1970@postgrespro.ru", "phone": "+70894053527"}
0005432822359	190126	1824 037317	ALEKSEY KOZLOV	{"email": "kozlovaleksey.1969@postgrespro.ru", "phone": "+70146169662"}
0005432822360	3DC360	9539 688702	TATYANA DENISOVA	{"phone": "+70418894646"}
0005432822361	3DC360	4983 792449	LILIYA VOLKOVA	{"email": "liliya_volkova-25011973@postgrespro.ru", "phone": "+70016547662"}
0005432822362	241112	3869 285383	VASILIY TARASOV	{"phone": "+70736774064"}
0005432822363	241112	8737 888216	DENIS SOROKIN	{"email": "denis_sorokin-09031969@postgrespro.ru", "phone": "+70399203121"}
0005432822364	2B5594	7244 242717	OLEG BELOV	{"email": "obelov_1973@postgrespro.ru", "phone": "+70366668628"}
0005432822365	122A4E	7635 990758	NELYA VASILEVA	{"email": "nelya.vasileva02081974@postgrespro.ru", "phone": "+70948828776"}
0005432822366	3567CC	6401 132283	IVAN DMITRIEV	{"email": "i-dmitriev_09081962@postgrespro.ru", "phone": "+70191343605"}
0005432822367	6AB657	2807 568533	EVGENIY DMITRIEV	{"phone": "+70804936664"}
0005432822368	A63363	6280 893913	EKATERINA SOROKINA	{"phone": "+70364489877"}
0005432822369	E83383	5100 558478	TATYANA IVANOVA	{"email": "t.ivanova_1970@postgrespro.ru", "phone": "+70164181299"}
0005432822370	FE970C	5772 000695	TATYANA LEBEDEVA	{"email": "lebedevat1962@postgrespro.ru", "phone": "+70555525347"}
0005432822371	FE970C	1673 590383	NATALIYA SMIRNOVA	{"email": "n.smirnova.27071978@postgrespro.ru", "phone": "+70083268538"}
0005432822372	FE970C	8978 025255	ALINA SAVELEVA	{"email": "alina.saveleva-041973@postgrespro.ru", "phone": "+70446827629"}
0005432822373	C57231	6403 754198	YURIY KULIKOV	{"phone": "+70585694625"}
0005432822374	C57231	3264 245293	VALERIY KUZNECOV	{"email": "kuznecov_v1977@postgrespro.ru", "phone": "+70004461942"}
0005432822375	C25D58	0891 108966	EKATERINA POPOVA	{"email": "popova-ekaterina.25061960@postgrespro.ru", "phone": "+70278824201"}
0005432822376	1A60A0	3823 983022	ALEKSANDR KUZNECOV	{"phone": "+70659179250"}
0005432822377	1A60A0	6496 805129	MARIYA KOLESNIKOVA	{"email": "kolesnikova-m1967@postgrespro.ru", "phone": "+70877899850"}
0005432822378	1A60A0	8545 844904	LIDIYA KUZNECOVA	{"phone": "+70900354466"}
0005432822379	C432AC	4064 554184	ALEKSANDR FOMIN	{"phone": "+70327922222"}
0005432822380	A51D63	1260 389001	ANTONINA ZHURAVLEVA	{"phone": "+70217512016"}
0005432822381	A51D63	6067 299276	VALENTINA CHERNOVA	{"phone": "+70446716805"}
0005432822382	29D094	7997 337185	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr_1973@postgrespro.ru", "phone": "+70933036288"}
0005432822383	B8A979	1869 031186	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay.031976@postgrespro.ru", "phone": "+70530651341"}
0005432822384	E41A42	9411 654217	VLADIMIR FROLOV	{"email": "vladimir_frolov-01081967@postgrespro.ru", "phone": "+70856908863"}
0005432822385	BF4EAC	6346 930261	VIKTOR VLASOV	{"email": "viktor.vlasov-021980@postgrespro.ru", "phone": "+70569768131"}
0005432822386	BF4EAC	0649 054962	MARGARITA KOVALEVA	{"phone": "+70979287888"}
0005432822387	674788	0343 338062	VALERIY ZAYCEV	{"phone": "+70201895539"}
0005432822388	6676D9	6831 922931	FAINA TARASOVA	{"email": "ftarasova-1963@postgrespro.ru", "phone": "+70811370723"}
0005432822389	BBF33E	4636 260402	VIKTOR KONOVALOV	{"email": "v.konovalov-061978@postgrespro.ru", "phone": "+70070549123"}
0005432822390	BBF33E	8279 815372	LYUDMILA BOGDANOVA	{"email": "l-bogdanova.041963@postgrespro.ru", "phone": "+70968375041"}
0005432822391	011BC6	4277 776141	NIKITA FROLOV	{"phone": "+70762933528"}
0005432822392	8CA303	9460 523177	MARIYA FILIPPOVA	{"email": "m-filippova_061973@postgrespro.ru", "phone": "+70480336497"}
0005432822393	978233	5494 973604	OKSANA VOROBEVA	{"email": "vorobeva_o-25011974@postgrespro.ru", "phone": "+70473880484"}
0005432822394	B39CF8	4396 389117	EVGENIY OSIPOV	{"email": "evgeniy-osipov-1972@postgrespro.ru", "phone": "+70440187579"}
0005432822395	7CBF3E	7230 876881	VALERIY FILIPPOV	{"phone": "+70328475783"}
0005432822396	7CBF3E	4613 053445	NIKITA BORISOV	{"phone": "+70064799843"}
0005432822397	DA867D	8356 849584	ANDREY KAZAKOV	{"phone": "+70396057443"}
0005432822398	190AF1	3050 046858	NATALIYA IVANOVA	{"email": "n.ivanova_021993@postgrespro.ru", "phone": "+70999799287"}
0005432822399	4EB03F	6141 688945	ALENA NIKIFOROVA	{"email": "alena-nikiforova.1969@postgrespro.ru", "phone": "+70330375907"}
0005432822400	4EB03F	6064 018055	ROMAN FROLOV	{"email": "r_frolov.17021969@postgrespro.ru", "phone": "+70711832963"}
0005432822401	4EB03F	5887 162970	VADIM NOVIKOV	{"phone": "+70544663266"}
0005432822402	BB73BE	5617 633576	KIRILL DAVYDOV	{"phone": "+70008594327"}
0005432822403	46DA60	1258 624024	ALEKSANDR TARASOV	{"phone": "+70119079391"}
0005432822404	539A03	8476 754251	ANGELINA NIKITINA	{"email": "nikitina_a-12091976@postgrespro.ru", "phone": "+70596650534"}
0005432822405	539A03	6504 592729	ELENA TIKHONOVA	{"email": "tikhonova-elena_051972@postgrespro.ru", "phone": "+70006665796"}
0005432822406	539A03	4248 999121	SVETLANA ANDREEVA	{"phone": "+70152859707"}
0005432822407	D34134	3786 186719	GLEB BELOV	{"email": "gbelov1971@postgrespro.ru", "phone": "+70774744864"}
0005432822408	580A7C	4779 471148	MARGARITA KOZLOVA	{"email": "m.kozlova04011977@postgrespro.ru", "phone": "+70715745395"}
0005432822409	580A7C	7976 939087	TATYANA AFANASEVA	{"email": "tatyana_afanaseva_26061974@postgrespro.ru", "phone": "+70567303022"}
0005432822410	BBD061	8025 176839	NIKOLAY GRIGOREV	{"email": "nikolay_grigorev_02031980@postgrespro.ru", "phone": "+70693631305"}
0005432822411	DD64E3	8929 144313	OLGA KOLESNIKOVA	{"phone": "+70344003002"}
0005432823450	511389	9948 421093	ALEKSANDR SHEVCHENKO	{"phone": "+70873067899"}
0005432822412	DD64E3	8829 902809	LYUDMILA ANDREEVA	{"email": "andreeva-lyudmila_21091974@postgrespro.ru", "phone": "+70991879267"}
0005432822413	357F46	3435 067170	YURIY SOROKIN	{"email": "yuriysorokin-18061976@postgrespro.ru", "phone": "+70904876899"}
0005432822414	357F46	3046 361707	NATALIYA KULIKOVA	{"email": "n-kulikova-071972@postgrespro.ru", "phone": "+70520428560"}
0005432822415	357F46	1774 190435	SERGEY ZHUKOV	{"email": "zhukovs1977@postgrespro.ru", "phone": "+70352162249"}
0005432822416	46928A	9904 748119	KLAVDIYA POPOVA	{"phone": "+70066898462"}
0005432822417	46928A	3768 749191	ALEKSEY MARTYNOV	{"email": "amartynov.1972@postgrespro.ru", "phone": "+70538160145"}
0005432822418	40C306	7982 212085	TAMARA ERMAKOVA	{"phone": "+70050436255"}
0005432822419	C6C3FA	1757 810564	ALEKSEY FEDOTOV	{"email": "fedotov.a1966@postgrespro.ru", "phone": "+70152118915"}
0005432822420	E7FE1D	1764 208732	EVGENIY PETROV	{"phone": "+70177577018"}
0005432822421	E7FE1D	4401 323765	YULIYA FROLOVA	{"phone": "+70302478149"}
0005432822422	62D87F	2692 644875	LYUDMILA ROMANOVA	{"phone": "+70553033773"}
0005432822423	62D87F	7592 961331	PAVEL KUDRYASHOV	{"phone": "+70784662850"}
0005432822424	1D752E	8181 850541	DMITRIY SERGEEV	{"email": "sergeev.dmitriy-26041967@postgrespro.ru", "phone": "+70418975110"}
0005432822425	3F67BA	0687 294645	SVETLANA NOVIKOVA	{"phone": "+70400957613"}
0005432822426	3F67BA	2222 205756	SERGEY SOLOVEV	{"email": "solovevsergey061973@postgrespro.ru", "phone": "+70524018780"}
0005432822427	3F67BA	9413 850802	GULNARA SCHERBAKOVA	{"phone": "+70224172086"}
0005432822428	32044E	4607 997709	OLGA SOLOVEVA	{"email": "soloveva.o.1966@postgrespro.ru", "phone": "+70792215162"}
0005432822429	32044E	1720 508586	ARINA KUZNECOVA	{"email": "kuznecovaa_081964@postgrespro.ru", "phone": "+70093290536"}
0005432822430	9EA55D	7849 194135	SERGEY KOZLOV	{"phone": "+70973466756"}
0005432822431	B9E0BF	6200 098545	EKATERINA DENISOVA	{"phone": "+70155292376"}
0005432822432	4AC6CA	2358 911066	ANTONINA ORLOVA	{"email": "orlova-a.1968@postgrespro.ru", "phone": "+70465270292"}
0005432822433	4AC6CA	3992 855415	SERGEY BARANOV	{"phone": "+70392205995"}
0005432822434	4AC6CA	3799 979066	LYUDMILA ZOTOVA	{"email": "l-zotova_1979@postgrespro.ru", "phone": "+70845146672"}
0005432822435	90DA8A	8916 145519	VLADIMIR IVANOV	{"email": "vladimir-ivanov_09021972@postgrespro.ru", "phone": "+70358015002"}
0005432823415	6DAD83	4352 305549	ELENA DAVYDOVA	{"phone": "+70359477201"}
0005432823416	97AB72	1831 993008	ANNA KOROLEVA	{"email": "akoroleva-1965@postgrespro.ru", "phone": "+70621599210"}
0005432823417	936C77	3370 370512	NATALYA MOISEEVA	{"phone": "+70281749717"}
0005432823418	B5D25B	7915 605390	ANATOLIY NIKITIN	{"email": "anatoliy-nikitin.20011981@postgrespro.ru", "phone": "+70615534475"}
0005432823419	8A388A	9176 399290	RASHIT ROMANOV	{"phone": "+70021935427"}
0005432823420	8A388A	4088 949718	TATYANA TIMOFEEVA	{"email": "timofeeva-t_1973@postgrespro.ru", "phone": "+70968711688"}
0005432823421	8A388A	8767 419709	TATYANA PAVLOVA	{"phone": "+70837246901"}
0005432823422	EBD26A	0584 429659	MARINA OVCHINNIKOVA	{"email": "marinaovchinnikova.041972@postgrespro.ru", "phone": "+70275824997"}
0005432823423	EBD26A	2509 451746	VITALIY FROLOV	{"email": "vitaliy.frolov.03121959@postgrespro.ru", "phone": "+70988449395"}
0005432823424	D610A9	1643 507301	VALERIYA MOROZOVA	{"phone": "+70961782218"}
0005432823425	2BC069	9578 312829	VIKTOR VLASOV	{"phone": "+70209614445"}
0005432823426	7EB1DF	7337 130726	SERGEY KAZAKOV	{"phone": "+70012739451"}
0005432823427	6380B6	2657 033595	ELIZAVETA MOISEEVA	{"email": "elizaveta.moiseeva051985@postgrespro.ru", "phone": "+70710342973"}
0005432823428	D484CE	3856 247537	PETR KONOVALOV	{"email": "konovalov_petr26091976@postgrespro.ru", "phone": "+70238901022"}
0005432823429	C8EA29	8502 255014	DENIS MAKAROV	{"phone": "+70188103925"}
0005432823430	C8EA29	8083 245779	LYUDMILA MELNIKOVA	{"email": "lyudmila_melnikova101971@postgrespro.ru", "phone": "+70283449353"}
0005432823431	D51EA6	0850 379520	VALENTINA SCHERBAKOVA	{"email": "valentinascherbakova.26061973@postgrespro.ru", "phone": "+70747582188"}
0005432823432	D51EA6	9777 229167	IRINA FROLOVA	{"email": "irina_frolova.20061986@postgrespro.ru", "phone": "+70724788089"}
0005432823433	1BDB86	4759 137734	YULIYA AKIMOVA	{"email": "akimova-y.1971@postgrespro.ru", "phone": "+70124740164"}
0005432823434	B7C7F5	1211 446264	MIKHAIL STEPANOV	{"email": "stepanov.m_1965@postgrespro.ru", "phone": "+70461726768"}
0005432823435	642F22	6512 023207	TATYANA NESTEROVA	{"phone": "+70541021365"}
0005432823436	AD5453	9042 227208	VERA POPOVA	{"email": "v.popova-28121980@postgrespro.ru", "phone": "+70493582278"}
0005432823437	23CB7D	7731 605024	ANASTASIYA IVANOVA	{"phone": "+70150195927"}
0005432823438	23CB7D	0395 330610	ARTEM NOVIKOV	{"phone": "+70971745308"}
0005432823439	91EBFB	4868 623994	ALEKSANDR ZHUKOV	{"email": "azhukov-101977@postgrespro.ru", "phone": "+70291043891"}
0005432823440	232FFA	4841 903451	TATYANA SOLOVEVA	{"email": "t.soloveva.07011978@postgrespro.ru", "phone": "+70356102075"}
0005432823441	3B2DC4	2800 431595	NATALIYA SERGEEVA	{"email": "sergeeva_nataliya-041972@postgrespro.ru", "phone": "+70276429211"}
0005432823442	ABBE35	1480 447936	MAKSIM ALEKSEEV	{"phone": "+70967095426"}
0005432823443	ABBE35	2071 937768	NIKOLAY VASILEV	{"phone": "+70766906074"}
0005432823444	ABBE35	3032 041802	FARIT TIMOFEEV	{"email": "f_timofeev.16101974@postgrespro.ru", "phone": "+70384552214"}
0005432823445	6C877A	7979 657600	TAMARA KALININA	{"phone": "+70961259943"}
0005432823446	6C877A	0132 371804	TATYANA IVANOVA	{"email": "tatyana_ivanova1974@postgrespro.ru", "phone": "+70335958347"}
0005432823447	6C877A	7607 942266	ANNA MEDVEDEVA	{"email": "anna_medvedeva-1984@postgrespro.ru", "phone": "+70616901977"}
0005432823448	5FD34C	5467 013892	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey.17011973@postgrespro.ru", "phone": "+70338549519"}
0005432823449	B826F3	0733 092811	OLGA MEDVEDEVA	{"email": "o_medvedeva.101974@postgrespro.ru", "phone": "+70188443486"}
0005432823451	4138B6	9900 779937	EVGENIY MELNIKOV	{"email": "evgeniy.melnikov-011976@postgrespro.ru", "phone": "+70537233394"}
0005432823452	4138B6	2661 242786	VLADIMIR IVANOV	{"phone": "+70447567830"}
0005432823453	78ADE5	7733 268646	ANASTASIYA BELOVA	{"email": "belova_anastasiya.061976@postgrespro.ru", "phone": "+70352749300"}
0005432823454	78ADE5	8556 322997	ANDREY VASILEV	{"email": "vasilev.andrey.101974@postgrespro.ru", "phone": "+70609575533"}
0005432823455	17624B	2024 441279	LARISA POPOVA	{"email": "popova_larisa-06071980@postgrespro.ru", "phone": "+70665786709"}
0005432823456	58C9C7	7226 939284	ALEKSANDRA KULIKOVA	{"phone": "+70221263754"}
0005432823457	58C9C7	8308 555502	EKATERINA SOKOLOVA	{"email": "sokolovaekaterina-20091960@postgrespro.ru", "phone": "+70626347186"}
0005432823458	D3FEF1	9459 295906	LYUBOV TIMOFEEVA	{"email": "timofeeva-lyubov.1969@postgrespro.ru", "phone": "+70027707419"}
0005432823459	45A42A	7002 305829	DENIS SCHERBAKOV	{"email": "d.scherbakov06111975@postgrespro.ru", "phone": "+70478780390"}
0005432823460	45A42A	6258 335705	NAIL ILIN	{"email": "n_ilin111968@postgrespro.ru", "phone": "+70299829532"}
0005432823461	565CEE	2599 213750	RAIL KUZNECOV	{"email": "rkuznecov_061955@postgrespro.ru", "phone": "+70787229266"}
0005432823462	A3DF9C	8017 179783	SAMIR MELNIKOV	{"email": "melnikov_s071978@postgrespro.ru", "phone": "+70856311534"}
0005432823463	E58B79	8535 004864	SERGEY STEPANOV	{"email": "stepanov-s-1971@postgrespro.ru", "phone": "+70270808051"}
0005432823464	03E061	7345 722517	VALENTINA SIDOROVA	{"phone": "+70945653003"}
0005432823465	01413E	7973 327464	SERGEY IVANOV	{"phone": "+70684005426"}
0005432823466	01413E	0716 287622	ALEKSANDR DENISOV	{"email": "denisov-a.071980@postgrespro.ru", "phone": "+70169381530"}
0005432823467	994D7A	4677 612602	VLADIMIR KAZAKOV	{"phone": "+70780770231"}
0005432823468	06B8C0	8087 686044	OKSANA NOVIKOVA	{"email": "o.novikova-05021969@postgrespro.ru", "phone": "+70001199314"}
0005432823469	DF30B0	7679 117068	SNEZHANA IVANOVA	{"phone": "+70043839028"}
0005432823470	55148E	3620 657715	IRINA KOROLEVA	{"email": "i.koroleva-17021981@postgrespro.ru", "phone": "+70533085146"}
0005432823471	9B22C6	8020 805097	ALEKSEY KOZLOV	{"phone": "+70829865754"}
0005432823472	9B22C6	8714 942941	ROMAN FILIPPOV	{"phone": "+70635426679"}
0005432823473	8263EC	1120 880479	ARTEM YAKOVLEV	{"phone": "+70849456534"}
0005432823474	19018D	2596 141645	ALEKSANDRA FILIPPOVA	{"phone": "+70110753380"}
0005432823475	29A6B3	0101 504042	NATALYA DMITRIEVA	{"phone": "+70634207129"}
0005432823476	E42F38	2200 961959	OLGA ISAEVA	{"email": "isaeva_o_1979@postgrespro.ru", "phone": "+70847166045"}
0005432823477	7E88B0	3063 368105	ALEKSANDR MARTYNOV	{"phone": "+70067766649"}
0005432823478	C42D43	5379 771175	VLADIMIR SOROKIN	{"email": "sorokin_vladimir1973@postgrespro.ru", "phone": "+70346989800"}
0005432823479	C42D43	3119 582764	OLESYA KRASNOVA	{"email": "o.krasnova.101979@postgrespro.ru", "phone": "+70777946806"}
0005432823480	4604EA	8962 063436	SOFIYA LAZAREVA	{"email": "lazarevas-29121962@postgrespro.ru", "phone": "+70524092782"}
0005432823481	A691C1	5316 321115	IVAN ANDREEV	{"email": "andreev-i-081977@postgrespro.ru", "phone": "+70002016762"}
0005432823482	FD0FB2	3352 800165	YURIY KUZNECOV	{"phone": "+70900026942"}
0005432823483	BD556B	6361 426610	IGOR NAUMOV	{"phone": "+70857017176"}
0005432823484	BD556B	4109 551048	ELENA SMIRNOVA	{"email": "smirnova.elena.1954@postgrespro.ru", "phone": "+70111751101"}
0005432823485	6E593F	3455 620543	VALERIY SOKOLOV	{"phone": "+70913876936"}
0005432823486	52ED1A	3757 744991	VERA KUZNECOVA	{"email": "kuznecova.vera.1970@postgrespro.ru", "phone": "+70194767839"}
0005432823487	52ED1A	2995 773610	BORIS KUZNECOV	{"phone": "+70277006968"}
0005432823488	7FFB77	0992 068435	SVETLANA MAKAROVA	{"phone": "+70981079998"}
0005432823489	7FFB77	7598 586412	MIKHAIL NAUMOV	{"email": "mnaumov-30041974@postgrespro.ru", "phone": "+70325199164"}
0005432823490	EB4E70	4365 784007	RASHIT VOLKOV	{"email": "volkovr_1961@postgrespro.ru", "phone": "+70892588630"}
0005432823491	2B3F9A	7511 918155	MARIYA KOLESNIKOVA	{"email": "mariya-kolesnikova.1962@postgrespro.ru", "phone": "+70903460562"}
0005432823492	87192C	7261 674241	SERGEY MELNIKOV	{"phone": "+70237307606"}
0005432823493	87192C	0137 732538	VERA BOGDANOVA	{"email": "v_bogdanova.02081970@postgrespro.ru", "phone": "+70348694441"}
0005432823494	87192C	7780 279428	VIKTORIYA ABRAMOVA	{"email": "abramova.v-23091968@postgrespro.ru", "phone": "+70762743101"}
0005432823495	F5761F	1057 596898	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_valentina.121979@postgrespro.ru", "phone": "+70581014321"}
0005432823496	DF65D6	9918 092681	IGOR VOLKOV	{"phone": "+70310916850"}
0005432823497	DF65D6	2551 489732	ALEKSANDR KRASNOV	{"phone": "+70073054189"}
0005432823498	4C7494	4451 470400	MARIYA STEPANOVA	{"email": "mariyastepanova_1972@postgrespro.ru", "phone": "+70991585364"}
0005432823499	DCAE64	8806 177194	VLADIMIR ALEKSEEV	{"phone": "+70288431024"}
0005432823500	AF803A	8194 320294	NADEZHDA SMIRNOVA	{"email": "nsmirnova.06061992@postgrespro.ru", "phone": "+70159367025"}
0005432823501	603471	6697 033259	OKSANA DANILOVA	{"phone": "+70119904802"}
0005432823502	BA00E2	7561 458959	STANISLAV SOROKIN	{"email": "sorokinstanislav.071983@postgrespro.ru", "phone": "+70362831538"}
0005432823503	FFE3D1	8302 330589	ELENA SMIRNOVA	{"phone": "+70041054052"}
0005432823504	20A729	8014 641099	SVETLANA DAVYDOVA	{"phone": "+70069321473"}
0005432823505	A90BF9	9008 693296	FEDOR MOROZOV	{"phone": "+70880160966"}
0005432823506	A90BF9	3193 087850	ELENA ZHUKOVA	{"email": "zhukova-e-051972@postgrespro.ru", "phone": "+70642465656"}
0005432823507	D1839D	3414 286410	VYACHESLAV KRASNOV	{"email": "vyacheslav_krasnov-22051970@postgrespro.ru", "phone": "+70727628306"}
0005432823508	07ABF5	1692 466680	ANDREY ALEKSANDROV	{"phone": "+70888892838"}
0005432823509	07ABF5	7167 200662	DANIIL ANTONOV	{"email": "daniil_antonov22121972@postgrespro.ru", "phone": "+70897744214"}
0005432838516	7F51AF	1206 158527	VLADIMIR DAVYDOV	{"phone": "+70790019892"}
0005432838684	AF611B	6449 270788	MIKHAIL POPOV	{"phone": "+70819956724"}
0005432838480	F3E99F	7166 000174	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail-23091966@postgrespro.ru", "phone": "+70490120222"}
0005432838481	00B798	8196 762733	NATALYA CHERNOVA	{"phone": "+70814844467"}
0005432838482	8F3CD0	4164 679732	DMITRIY RODIONOV	{"phone": "+70111409074"}
0005432838483	572997	8813 638416	ILYA MATVEEV	{"phone": "+70849656425"}
0005432838484	572997	4144 258710	VLADIMIR KUZNECOV	{"phone": "+70435644513"}
0005432838485	5E2AF7	1020 942705	NATALYA KUZNECOVA	{"email": "natalya_kuznecova16121977@postgrespro.ru", "phone": "+70529203876"}
0005432838486	41D571	8705 582425	SERGEY NIKOLAEV	{"phone": "+70714269455"}
0005432838487	41D571	6138 495576	GENNADIY GUSEV	{"phone": "+70071088106"}
0005432838488	1D205A	3872 212794	NIKOLAY IVANOV	{"email": "nikolay-ivanov-1966@postgrespro.ru", "phone": "+70433551974"}
0005432838489	B7F531	3618 191080	DMITRIY MEDVEDEV	{"email": "dmitriy-medvedev21111954@postgrespro.ru", "phone": "+70913602644"}
0005432838490	B7F531	8637 033566	ELENA SERGEEVA	{"phone": "+70413002218"}
0005432838491	4787D7	1004 732434	VIKTORIYA DAVYDOVA	{"phone": "+70580948499"}
0005432838492	4787D7	9488 381659	ELENA MELNIKOVA	{"email": "melnikovae31011975@postgrespro.ru", "phone": "+70008180843"}
0005432838493	968CA0	7617 886403	PAVEL VOLKOV	{"phone": "+70641848752"}
0005432838494	D67D64	2986 687725	LYUBOV BARANOVA	{"email": "baranova.l-071974@postgrespro.ru", "phone": "+70498065443"}
0005432838495	D67D64	4769 245095	ALEKSANDR EGOROV	{"email": "aegorov111967@postgrespro.ru", "phone": "+70369416270"}
0005432838496	F6CA88	3524 753688	VERA DENISOVA	{"email": "denisova-v.1971@postgrespro.ru", "phone": "+70457793038"}
0005432838497	F6CA88	7531 681432	VALENTINA NIKOLAEVA	{"phone": "+70200980644"}
0005432838498	77D3FA	4858 574974	FILIPP SAVELEV	{"email": "savelevf.101977@postgrespro.ru", "phone": "+70022654472"}
0005432838499	00F703	8536 205917	VIKTOR BONDARENKO	{"email": "bondarenko_viktor_101970@postgrespro.ru", "phone": "+70399299220"}
0005432838500	3D3B09	2828 050639	SERGEY MARTYNOV	{"email": "s_martynov1977@postgrespro.ru", "phone": "+70125312172"}
0005432838501	B44534	0732 188693	SERGEY VLASOV	{"email": "vlasov-s.1983@postgrespro.ru", "phone": "+70491201773"}
0005432838502	B44534	2551 458628	ANNA SOLOVEVA	{"phone": "+70425433536"}
0005432838503	B44534	1738 489617	KSENIYA TROFIMOVA	{"email": "trofimova.kseniya_05081976@postgrespro.ru", "phone": "+70800522748"}
0005432838504	35FD83	6847 520127	SERGEY ANDREEV	{"email": "sergey-andreev_28071970@postgrespro.ru", "phone": "+70148512277"}
0005432838505	455E19	5699 614811	OLGA YAKOVLEVA	{"email": "olga-yakovleva-1964@postgrespro.ru", "phone": "+70446384432"}
0005432838506	F1722B	7894 501457	KSENIYA KUZNECOVA	{"phone": "+70813185328"}
0005432838507	5279ED	9454 638343	VALENTIN NIKITIN	{"phone": "+70196839752"}
0005432838508	8B43A2	6156 398180	MILANA ROMANOVA	{"phone": "+70284805076"}
0005432838509	26B650	3577 012349	ELENA SMIRNOVA	{"email": "smirnova_e-1978@postgrespro.ru", "phone": "+70810370256"}
0005432838510	559171	2055 957044	IRINA MEDVEDEVA	{"email": "medvedevairina081976@postgrespro.ru", "phone": "+70030705644"}
0005432838511	559171	8928 220856	OLGA PAVLOVA	{"email": "o-pavlova.1982@postgrespro.ru", "phone": "+70866591950"}
0005432838512	D8C192	9837 574780	NINA PETROVA	{"email": "ninapetrova.071970@postgrespro.ru", "phone": "+70365160169"}
0005432838513	13D20E	6978 661197	OLEG SOLOVEV	{"phone": "+70761988923"}
0005432838514	593603	3661 323521	ALEKSEY ZHURAVLEV	{"email": "aleksey-zhuravlev.10091965@postgrespro.ru", "phone": "+70237438762"}
0005432838515	593603	5790 962311	IRINA VOROBEVA	{"email": "vorobeva-irina061963@postgrespro.ru", "phone": "+70048698217"}
0005432838517	7F51AF	7094 353232	VERONIKA BORISOVA	{"email": "veronika-borisova.011969@postgrespro.ru", "phone": "+70282861756"}
0005432838518	CB794F	0042 668541	YURIY VOROBEV	{"phone": "+70291547494"}
0005432838519	58B8D6	6359 493095	LYUDMILA SAVELEVA	{"phone": "+70202443774"}
0005432838520	00C242	8536 646820	SVETLANA SMIRNOVA	{"email": "svetlanasmirnova_22061979@postgrespro.ru", "phone": "+70230121830"}
0005432838521	1BB793	0923 575248	VALERIY NOVIKOV	{"phone": "+70224983327"}
0005432838522	64F89A	5925 850839	VERA BARANOVA	{"phone": "+70623385169"}
0005432838523	2C29E2	6155 601373	VIKTORIYA FROLOVA	{"phone": "+70695452534"}
0005432838524	2C29E2	0472 126106	ANASTASIYA SIDOROVA	{"phone": "+70036215202"}
0005432838525	085A42	0919 200794	TATYANA SMIRNOVA	{"email": "smirnovatatyana.021970@postgrespro.ru", "phone": "+70605744541"}
0005432838526	00380F	6961 826241	OLGA YAKOVLEVA	{"email": "olgayakovleva_021977@postgrespro.ru", "phone": "+70343617073"}
0005432838527	00380F	5701 294375	TATYANA IVANOVA	{"email": "tatyana_ivanova_10031967@postgrespro.ru", "phone": "+70205924880"}
0005432838528	00380F	5666 728399	BORIS ANDREEV	{"phone": "+70977956803"}
0005432838529	174EBB	6684 373759	ANASTASIYA NIKITINA	{"email": "anastasiyanikitina111970@postgrespro.ru", "phone": "+70378615818"}
0005432838530	174EBB	8963 804271	NINA ANTONOVA	{"email": "antonova_nina17121964@postgrespro.ru", "phone": "+70190578124"}
0005432838531	A3D683	9041 963682	IGOR SOLOVEV	{"email": "i-solovev_1965@postgrespro.ru", "phone": "+70297049725"}
0005432838532	797E99	7078 182404	NIKOLAY KARPOV	{"email": "karpov-n.14081972@postgrespro.ru", "phone": "+70408200088"}
0005432838533	797E99	4562 779994	VLADIMIR SOKOLOV	{"phone": "+70558773989"}
0005432838534	077018	9109 873498	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.071984@postgrespro.ru", "phone": "+70275185667"}
0005432838535	4837B9	5926 310792	ALEKSEY SOLOVEV	{"phone": "+70432142367"}
0005432838536	9F682C	3430 885409	NADEZHDA OVCHINNIKOVA	{"email": "n-ovchinnikova.04101971@postgrespro.ru", "phone": "+70361676634"}
0005432838537	D3422E	4514 434572	LYUDMILA TITOVA	{"phone": "+70225933518"}
0005432838538	D3422E	9250 157697	ALEKSANDR NOVIKOV	{"phone": "+70990460587"}
0005432838539	92826A	0475 064808	SERGEY MAKSIMOV	{"phone": "+70109451078"}
0005432838540	92826A	3247 640054	ELENA FROLOVA	{"email": "elena-frolova.071991@postgrespro.ru", "phone": "+70181137670"}
0005432838541	F8BD54	4533 416073	ALINA DANILOVA	{"email": "a_danilova_29061976@postgrespro.ru", "phone": "+70819470113"}
0005432838542	8DDCD7	2044 815850	ALEKSEY ORLOV	{"phone": "+70499159032"}
0005432838543	3D9126	4552 754877	ANATOLIY DMITRIEV	{"email": "dmitrievanatoliy_25061979@postgrespro.ru", "phone": "+70336176358"}
0005432838544	3D9126	8711 844754	VYACHESLAV SMIRNOV	{"phone": "+70088512171"}
0005432838545	1CE3AF	4782 008538	ZINAIDA TIMOFEEVA	{"phone": "+70059189481"}
0005432838546	1CE3AF	6622 398104	OLEG ORLOV	{"email": "orlov.o_1965@postgrespro.ru", "phone": "+70690018289"}
0005432838547	111249	5956 040165	KRISTINA NIKITINA	{"email": "k_nikitina.1977@postgrespro.ru", "phone": "+70561924594"}
0005432838548	111249	0904 099890	VALERIY KUZNECOV	{"phone": "+70883767993"}
0005432838549	3D1F4A	9590 790199	ANATOLIY PAVLOV	{"phone": "+70118047635"}
0005432838550	1399FA	1698 565040	LYUBOV MATVEEVA	{"email": "matveeva.l24071973@postgrespro.ru", "phone": "+70328955736"}
0005432838551	694B32	8393 218090	SERGEY SMIRNOV	{"phone": "+70611942168"}
0005432838552	41DB9C	5076 166995	GALINA FILATOVA	{"email": "filatova.g_1970@postgrespro.ru", "phone": "+70767669091"}
0005432838553	41DB9C	9729 608615	ANATOLIY OSIPOV	{"phone": "+70041720309"}
0005432838554	655443	7733 222615	EKATERINA MAKSIMOVA	{"email": "ekaterina.maksimova_071973@postgrespro.ru", "phone": "+70821388448"}
0005432838555	1A7699	9151 555137	NIKOLAY GERASIMOV	{"email": "gerasimov.nikolay28071977@postgrespro.ru", "phone": "+70692061358"}
0005432838556	1A7699	5553 650460	ULYANA KAZAKOVA	{"email": "ukazakova.1967@postgrespro.ru", "phone": "+70878821292"}
0005432838557	77969C	3329 281582	ELENA FILATOVA	{"email": "e_filatova30041976@postgrespro.ru", "phone": "+70365664629"}
0005432838558	F3DEC5	8991 546511	ARTEM GAVRILOV	{"email": "gavrilovartem-29061965@postgrespro.ru", "phone": "+70447959337"}
0005432838559	7A9577	2065 434682	EVGENIY KUZNECOV	{"phone": "+70318672055"}
0005432838560	7A9577	4671 554863	SVETLANA AKIMOVA	{"email": "s_akimova_031978@postgrespro.ru", "phone": "+70995203392"}
0005432838561	EBC3AD	0114 795148	MARIYA ILINA	{"phone": "+70040059398"}
0005432838562	EBC3AD	7022 690646	POLINA DENISOVA	{"email": "denisova.polina1975@postgrespro.ru", "phone": "+70209490292"}
0005432838563	7006A9	6551 957691	EKATERINA SOROKINA	{"phone": "+70781457757"}
0005432838564	533508	9095 697810	EGOR EGOROV	{"email": "egorov_egor1962@postgrespro.ru", "phone": "+70290558881"}
0005432838565	533508	1980 754470	TATYANA DANILOVA	{"email": "danilova-tatyana-031968@postgrespro.ru", "phone": "+70518852614"}
0005432838566	800A19	7321 209859	MARIANNA NIKITINA	{"phone": "+70302994169"}
0005432838567	800A19	8309 986954	YURIY MAKAROV	{"phone": "+70767639377"}
0005432838568	DDF6D1	4273 063160	INNA IVANOVA	{"email": "inna-ivanova.27121972@postgrespro.ru", "phone": "+70575992847"}
0005432838569	DDF6D1	5483 274713	VALENTINA ARKHIPOVA	{"phone": "+70405516359"}
0005432838570	E0216A	9066 471728	MARIYA NIKOLAEVA	{"email": "mariyanikolaeva1962@postgrespro.ru", "phone": "+70496288068"}
0005432838571	E0216A	5610 259633	ALEKSEY DMITRIEV	{"email": "alekseydmitriev-1970@postgrespro.ru", "phone": "+70937589941"}
0005432838572	E0216A	7045 770931	IRINA OVCHINNIKOVA	{"phone": "+70861677229"}
0005432838573	9FB430	8717 965294	ANTON STEPANOV	{"email": "a.stepanov101977@postgrespro.ru", "phone": "+70429907748"}
0005432838574	4E4809	1046 802596	ALEKSANDR FEDOROV	{"email": "afedorov_051975@postgrespro.ru", "phone": "+70763416904"}
0005432838575	4E4809	7489 623323	MAKSIM KOZLOV	{"phone": "+70942272316"}
0005432838576	8462CD	9653 401053	NATALYA IVANOVA	{"phone": "+70776345345"}
0005432838577	427AF9	5709 301944	MARINA ROMANOVA	{"phone": "+70865072638"}
0005432838578	427AF9	5993 225264	IGOR DAVYDOV	{"email": "davydovigor_1966@postgrespro.ru", "phone": "+70472603351"}
0005432838579	427AF9	7774 036543	MARGARITA PETROVA	{"phone": "+70527940784"}
0005432838580	5C94B1	5361 299650	STANISLAV SCHERBAKOV	{"email": "scherbakov-s.1969@postgrespro.ru", "phone": "+70034680722"}
0005432838581	BD0EFF	4970 274872	ALEKSANDR TARASOV	{"phone": "+70361654516"}
0005432838582	E140A7	2276 158384	NIKOLAY VLASOV	{"email": "vlasov-n11021967@postgrespro.ru", "phone": "+70093808410"}
0005432838583	4ADEAF	2985 062494	MAYYA TARASOVA	{"phone": "+70410904966"}
0005432838584	4ADEAF	7512 641414	EVGENIYA BORISOVA	{"phone": "+70914756399"}
0005432838585	B51C7E	5693 048873	ALEKSANDR PAVLOV	{"phone": "+70596525779"}
0005432838586	B51C7E	6214 726142	RIFAT SERGEEV	{"email": "rifatsergeev-101974@postgrespro.ru", "phone": "+70673059071"}
0005432838587	6389FB	7242 883388	EKATERINA KOVALEVA	{"email": "e.kovaleva-011975@postgrespro.ru", "phone": "+70232953395"}
0005432838588	8D97FD	1408 368650	NIKOLAY ORLOV	{"phone": "+70426670606"}
0005432838589	8D97FD	2485 077805	PAVEL SEMENOV	{"email": "semenov_pavel.19091980@postgrespro.ru", "phone": "+70945821770"}
0005432838590	8D97FD	8102 059421	NATALIYA KUDRYASHOVA	{"phone": "+70968611867"}
0005432838591	460B57	4665 590716	IGOR BARANOV	{"email": "igor_baranov_07081969@postgrespro.ru", "phone": "+70878211019"}
0005432838592	AE35C2	1961 482193	RAISA GORBUNOVA	{"phone": "+70993322375"}
0005432838593	AE35C2	7059 298877	POLINA TARASOVA	{"phone": "+70646203747"}
0005432838594	E97167	9588 919045	SERGEY CHERNOV	{"phone": "+70305565204"}
0005432838595	7353AF	9335 256574	MARIYA SOKOLOVA	{"email": "sokolova-m-1970@postgrespro.ru", "phone": "+70810784094"}
0005432838596	7353AF	2727 002107	LYUDMILA KULIKOVA	{"email": "lkulikova071974@postgrespro.ru", "phone": "+70513159030"}
0005432838597	F3C74A	8042 877412	RAISA FROLOVA	{"email": "frolova_raisa_1966@postgrespro.ru", "phone": "+70940135491"}
0005432838598	273654	5481 967234	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_v.1968@postgrespro.ru", "phone": "+70692781786"}
0005432838599	913433	7988 352670	VIKTOR KOZLOV	{"email": "kozlovviktor1970@postgrespro.ru", "phone": "+70544665364"}
0005432838600	913433	6403 362841	ARTEM MIRONOV	{"phone": "+70819344202"}
0005432838601	C19607	8642 605514	YULIYA FOMINA	{"email": "fomina-y_1979@postgrespro.ru", "phone": "+70822034253"}
0005432838602	19AD06	1617 538909	ANDREY KUZNECOV	{"email": "andreykuznecov081964@postgrespro.ru", "phone": "+70171752798"}
0005432838603	19AD06	4229 367977	NADEZHDA EGOROVA	{"phone": "+70440001212"}
0005432838604	6586EF	6238 994964	ANDREY FROLOV	{"phone": "+70899410512"}
0005432838605	6586EF	3279 436008	ANATOLIY MAKAROV	{"phone": "+70886770068"}
0005432838606	6586EF	8133 098886	DMITRIY PAVLOV	{"email": "pavlov-d_16081971@postgrespro.ru", "phone": "+70670459886"}
0005432838607	F9C0D2	8527 997791	RAISA SOROKINA	{"email": "raisa-sorokina-021975@postgrespro.ru", "phone": "+70055134109"}
0005432838608	23336C	8133 336741	KONSTANTIN SEMENOV	{"phone": "+70528180143"}
0005432838609	5F14B7	6337 125717	VLADISLAV TIMOFEEV	{"phone": "+70897407535"}
0005432838610	5F14B7	8362 383387	LYUBOV KOZLOVA	{"email": "lyubov_kozlova071966@postgrespro.ru", "phone": "+70069449859"}
0005432838611	5F14B7	6316 723538	PAVEL ANDREEV	{"email": "pavel.andreev-1975@postgrespro.ru", "phone": "+70983134753"}
0005432838612	30F8D7	8944 646980	ANASTASIYA MAKAROVA	{"phone": "+70556496561"}
0005432838613	861DD6	4984 084859	DARYA DANILOVA	{"email": "danilovadarya-111976@postgrespro.ru", "phone": "+70350616609"}
0005432838614	861DD6	4031 140252	ANNA IVANOVA	{"phone": "+70246869292"}
0005432838615	85D94C	8675 757627	TATYANA KISELEVA	{"phone": "+70670117345"}
0005432838616	85D94C	3558 781375	MIKHAIL KUZNECOV	{"email": "kuznecov.m26011973@postgrespro.ru", "phone": "+70243746783"}
0005432838617	2DB8BC	8386 638185	TATYANA ROMANOVA	{"phone": "+70316944409"}
0005432838618	F17AF4	5426 536593	GEORGIY KARPOV	{"email": "karpov_g.061962@postgrespro.ru", "phone": "+70717548597"}
0005432838619	A8AAB4	0791 755653	TATYANA MEDVEDEVA	{"phone": "+70529170445"}
0005432838620	A8AAB4	0228 906537	DMITRIY VOLKOV	{"email": "d.volkov1980@postgrespro.ru", "phone": "+70258128218"}
0005432838621	BB6EDD	5002 969358	VIKTOR ALEKSEEV	{"phone": "+70698542296"}
0005432838622	DAC64D	4200 918872	MARINA NIKOLAEVA	{"email": "nikolaeva.marina_1967@postgrespro.ru", "phone": "+70209344102"}
0005432838623	556214	0053 762754	SERGEY NIKITIN	{"phone": "+70798079069"}
0005432838624	556214	4708 683296	ALFIYA GORBUNOVA	{"email": "gorbunovaa07111977@postgrespro.ru", "phone": "+70544657360"}
0005432838625	53EC13	8236 451048	RAMAZAN SCHERBAKOV	{"phone": "+70787149187"}
0005432838626	EE5F5D	4585 878840	NADEZHDA EFREMOVA	{"phone": "+70709776370"}
0005432838627	6388A1	3435 811585	TAMARA FEDOROVA	{"email": "tamara-fedorova_22021974@postgrespro.ru", "phone": "+70000149608"}
0005432838628	C1A25B	0190 045719	VITALIY MIKHAYLOV	{"phone": "+70046173466"}
0005432838685	1781D6	1915 175927	ANTON MOROZOV	{"phone": "+70297475476"}
0005432838629	863D94	8007 374961	GALINA YAKOVLEVA	{"email": "yakovleva.g.081975@postgrespro.ru", "phone": "+70737436497"}
0005432838630	D9CDAB	5541 097621	NINA AFANASEVA	{"phone": "+70502638949"}
0005432838631	D9CDAB	1361 239442	EKATERINA POTAPOVA	{"email": "ekaterina-potapova1962@postgrespro.ru", "phone": "+70856982177"}
0005432838632	3B7371	6885 413474	YULIYA KOMAROVA	{"email": "yuliyakomarova.07021972@postgrespro.ru", "phone": "+70074972006"}
0005432838633	79225D	0359 951702	ALEKSANDR TARASOV	{"phone": "+70972629970"}
0005432838634	79225D	4443 030235	VALENTINA KONOVALOVA	{"email": "konovalova.v.101970@postgrespro.ru", "phone": "+70537657503"}
0005432838635	62EA44	1834 370167	VLADIMIR KUZNECOV	{"phone": "+70630108794"}
0005432838636	C5DF82	6002 699439	MARIYA ORLOVA	{"phone": "+70540920726"}
0005432838637	08E219	0553 478074	EVDOKIYA ISAEVA	{"phone": "+70255348752"}
0005432838638	1D9419	2359 302058	NATALYA VASILEVA	{"email": "n.vasileva.1979@postgrespro.ru", "phone": "+70359716000"}
0005432838639	1D9419	8701 247287	DANILA NAZAROV	{"email": "danilanazarov1974@postgrespro.ru", "phone": "+70986959915"}
0005432838640	1D9419	8149 314881	ANTONINA ZAKHAROVA	{"email": "zakharovaa-071977@postgrespro.ru", "phone": "+70075737544"}
0005432838641	D0DF9D	5171 574450	EVGENIYA NIKOLAEVA	{"email": "enikolaeva20111967@postgrespro.ru", "phone": "+70701743038"}
0005432838642	D86E39	2355 635619	EGOR BORISOV	{"email": "borisov-egor.011972@postgrespro.ru", "phone": "+70821995710"}
0005432838643	50C198	2979 567173	NADEZHDA FILATOVA	{"email": "filatova-n-041978@postgrespro.ru", "phone": "+70051411887"}
0005432838644	50C198	8726 767447	OLEG SMIRNOV	{"email": "smirnov-o-18041980@postgrespro.ru", "phone": "+70531559849"}
0005432838645	50C198	5601 730488	EKATERINA KAZAKOVA	{"phone": "+70435527520"}
0005432838646	124C62	6474 261296	ALEKSEY ORLOV	{"email": "orlov_aleksey-111965@postgrespro.ru", "phone": "+70390701253"}
0005432838647	92634A	3601 123433	ALINA KONOVALOVA	{"email": "konovalova-alina_071972@postgrespro.ru", "phone": "+70814095498"}
0005432838648	92634A	3972 478999	EVGENIY ILIN	{"email": "ilinevgeniy_24121967@postgrespro.ru", "phone": "+70839429528"}
0005432838649	AC36BB	2624 311423	ALEKSANDR VASILEV	{"email": "vasilev.a.101965@postgrespro.ru", "phone": "+70958121227"}
0005432838650	FC1265	8250 923801	VALERIY TIKHONOV	{"email": "v-tikhonov_20031979@postgrespro.ru", "phone": "+70717692233"}
0005432838651	FC1265	4534 224772	EKATERINA LUKYANOVA	{"email": "e-lukyanova041976@postgrespro.ru", "phone": "+70287686809"}
0005432838652	ECED6F	1600 179942	MARIYA GUSEVA	{"email": "m-guseva_1965@postgrespro.ru", "phone": "+70353041019"}
0005432838653	ECED6F	5963 208435	DANIIL ZAKHAROV	{"email": "zakharov_daniil081986@postgrespro.ru", "phone": "+70753949687"}
0005432838654	6292DB	8195 295990	SERGEY SIDOROV	{"phone": "+70131942116"}
0005432838655	6292DB	0173 213661	RAISA ROMANOVA	{"phone": "+70608252860"}
0005432838656	2AB368	1039 655854	TATYANA IVANOVA	{"email": "ivanova-tatyana121970@postgrespro.ru", "phone": "+70922818115"}
0005432838657	0684ED	2994 439179	OLGA BORISOVA	{"email": "borisova_olga101989@postgrespro.ru", "phone": "+70615568880"}
0005432838658	7837D7	2440 036016	SERGEY MIKHAYLOV	{"phone": "+70929457104"}
0005432838659	7837D7	8758 351809	ELENA TITOVA	{"email": "elena.titova_081976@postgrespro.ru", "phone": "+70653179893"}
0005432838660	7837D7	1286 892929	MIKHAIL GORBUNOV	{"email": "gorbunovmikhail1969@postgrespro.ru", "phone": "+70300794778"}
0005432838661	2B1849	1075 294726	ANTON ANDREEV	{"phone": "+70288163454"}
0005432838662	89CA95	3690 211139	ELENA KISELEVA	{"phone": "+70138242929"}
0005432838663	89CA95	3386 686570	MIKHAIL VASILEV	{"email": "vasilevm-121969@postgrespro.ru", "phone": "+70705952838"}
0005432838664	F1BA76	1223 853040	YULIYA ZAKHAROVA	{"email": "y.zakharova_31121976@postgrespro.ru", "phone": "+70849973628"}
0005432838665	CE2763	2960 657669	NINA BORISOVA	{"email": "borisova_nina.011977@postgrespro.ru", "phone": "+70311651862"}
0005432838666	B9E1F2	0364 626161	MAKSIM SOLOVEV	{"phone": "+70501914117"}
0005432838667	B9E1F2	2338 678917	ALEKSANDR KUZNECOV	{"phone": "+70020553613"}
0005432838668	907539	9240 331928	ANNA MAKAROVA	{"phone": "+70828692816"}
0005432838669	25C42C	2188 097960	ANGELINA MEDVEDEVA	{"email": "medvedeva-angelina.20021969@postgrespro.ru", "phone": "+70079664684"}
0005432838670	FA48FF	4168 577068	VALENTINA MIRONOVA	{"email": "mironova_valentina23101981@postgrespro.ru", "phone": "+70246214848"}
0005432838671	FA48FF	9896 151340	VYACHESLAV FEDOTOV	{"email": "vfedotov_1971@postgrespro.ru", "phone": "+70933779313"}
0005432838672	DE642B	5434 512449	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr1976@postgrespro.ru", "phone": "+70091715977"}
0005432838673	DE642B	6187 152611	LYUDMILA SOLOVEVA	{"phone": "+70164753983"}
0005432838674	5E82FE	2742 828500	LYUBOV ZOTOVA	{"email": "zotova-l_11091975@postgrespro.ru", "phone": "+70228568936"}
0005432838675	4CDE00	9178 659084	TATYANA IVANOVA	{"email": "ivanovat_02011970@postgrespro.ru", "phone": "+70518788251"}
0005432838676	272246	0765 517502	VALENTINA DANILOVA	{"email": "danilova-v.11101973@postgrespro.ru", "phone": "+70249802958"}
0005432838677	272246	3847 314715	EKATERINA TARASOVA	{"email": "e-tarasova-091975@postgrespro.ru", "phone": "+70390150140"}
0005432838678	9EF6BA	9622 419346	GALINA IVANOVA	{"phone": "+70348528157"}
0005432838679	705034	6125 956035	EKATERINA AKIMOVA	{"email": "e-akimova.28051968@postgrespro.ru", "phone": "+70536732569"}
0005432838680	705034	4346 222489	YULIYA EGOROVA	{"phone": "+70245151410"}
0005432838681	DAC86B	4596 650625	IRINA KUZNECOVA	{"phone": "+70557418018"}
0005432838682	DAC86B	8848 255732	VERA VOROBEVA	{"phone": "+70584859064"}
0005432838683	A53946	3039 957962	NIKITA EGOROV	{"phone": "+70524481326"}
0005432838686	3BEA0D	0260 492731	LARISA ZAYCEVA	{"email": "l.zayceva02011979@postgrespro.ru", "phone": "+70187571069"}
0005432838687	5E0FBF	0376 645167	ANNA FEDOROVA	{"email": "a.fedorova-081975@postgrespro.ru", "phone": "+70734328501"}
0005432838688	438012	4612 086597	VALENTINA BORISOVA	{"email": "valentina-borisova.1969@postgrespro.ru", "phone": "+70069319774"}
0005432838689	438012	9419 370190	DENIS SOROKIN	{"phone": "+70339980974"}
0005432838690	E51D97	5186 174316	SERGEY MOISEEV	{"email": "sergeymoiseev.1970@postgrespro.ru", "phone": "+70692171661"}
0005432838691	281F73	8317 506681	MIKHAIL SERGEEV	{"phone": "+70991386312"}
0005432838692	ADD4F6	8569 003120	YURIY IVANOV	{"email": "ivanov_yuriy.04091972@postgrespro.ru", "phone": "+70950526241"}
0005432838693	A78B4A	6400 285948	NINA RODIONOVA	{"phone": "+70285796850"}
0005432838694	0C98F2	3439 221745	DMITRIY MAKAROV	{"phone": "+70234708811"}
0005432838695	0C98F2	1873 695125	KRISTINA TIMOFEEVA	{"phone": "+70950596724"}
0005432838696	7C5519	6984 287610	MAKSIM ANTONOV	{"email": "maksim.antonov_1969@postgrespro.ru", "phone": "+70269978804"}
0005432838697	7A9482	0008 464315	TATYANA PAVLOVA	{"email": "pavlova-tatyana081970@postgrespro.ru", "phone": "+70314009649"}
0005432838698	9954A3	1594 279234	IRAIDA ROMANOVA	{"email": "iraida.romanova-25011972@postgrespro.ru", "phone": "+70045853049"}
0005432838699	C7E6CF	3160 595819	MAKSIM KAZAKOV	{"email": "maksim.kazakov_041965@postgrespro.ru", "phone": "+70475269891"}
0005432838700	C7E6CF	6504 478446	ALEKSEY SCHERBAKOV	{"phone": "+70317364673"}
0005432838701	9AFB49	8329 952553	NIKOLAY CHERNOV	{"phone": "+70593680601"}
0005432838702	9AFB49	8773 199230	NINA NIKOLAEVA	{"email": "nikolaeva.n1972@postgrespro.ru", "phone": "+70158609647"}
0005432838703	D923CC	9934 634978	ALEKSANDR ZAKHAROV	{"phone": "+70115640311"}
0005432838704	31AD7E	4544 870089	VYACHESLAV FOMIN	{"phone": "+70436625243"}
0005432838705	4414F3	0447 714189	KONSTANTIN AFANASEV	{"email": "konstantinafanasev.021981@postgrespro.ru", "phone": "+70500497212"}
0005432838706	94F987	2304 976641	ANATOLIY KUZNECOV	{"phone": "+70799967387"}
0005432838707	9DF426	8460 546927	RUMIYA BORISOVA	{"email": "borisovar1972@postgrespro.ru", "phone": "+70320185408"}
0005432838708	4EA7AA	4747 062751	VIKTOR MARTYNOV	{"email": "martynovv_1966@postgrespro.ru", "phone": "+70506890922"}
0005432838709	7891FD	5699 807210	OLGA SIDOROVA	{"email": "olga_sidorova.1973@postgrespro.ru", "phone": "+70961446165"}
0005432838710	0FD1EA	4366 660464	GALINA SMIRNOVA	{"phone": "+70181487596"}
0005432838711	0FD1EA	2223 156505	GALINA ROMANOVA	{"email": "g.romanova051970@postgrespro.ru", "phone": "+70891377073"}
0005432838712	0FD1EA	5997 930452	GULFIYA KAZAKOVA	{"phone": "+70787632561"}
0005432838713	CE8A21	1022 484591	IGOR GERASIMOV	{"phone": "+70340195264"}
0005432838714	802A9B	3397 799982	YULIYA DENISOVA	{"email": "y_denisova_1976@postgrespro.ru", "phone": "+70353013342"}
0005432838715	3EC393	4095 287177	EVGENIYA ZHUKOVA	{"email": "zhukova.e.30081980@postgrespro.ru", "phone": "+70554481861"}
0005432838716	9F9579	6552 446510	RAMIL KAZAKOV	{"email": "r-kazakov-06101962@postgrespro.ru", "phone": "+70104075786"}
0005432838717	5897F7	9831 433373	VLADIMIR ALEKSEEV	{"phone": "+70022988961"}
0005432838718	5897F7	7462 900144	LYUDMILA ANDREEVA	{"phone": "+70335784939"}
0005432838719	9E8E05	3171 029057	VALENTINA FILIPPOVA	{"phone": "+70243398865"}
0005432838720	9E8E05	4507 963568	EKATERINA TIMOFEEVA	{"email": "e_timofeeva-101965@postgrespro.ru", "phone": "+70985164328"}
0005432838721	6A98DF	7457 710076	VIKTOR SOROKIN	{"email": "viktor-sorokin_1966@postgrespro.ru", "phone": "+70379562384"}
0005432838722	4CFD2C	8253 916341	SABINA KOZLOVA	{"email": "kozlova.sabina-1966@postgrespro.ru", "phone": "+70199685755"}
0005432838723	D2CE1A	9463 906227	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev.17061972@postgrespro.ru", "phone": "+70637411112"}
0005432838724	F27D30	3582 373950	OLGA MAKSIMOVA	{"phone": "+70406536375"}
0005432838725	C67F95	2281 264176	LYUDMILA KOROLEVA	{"email": "lyudmilakoroleva-19081967@postgrespro.ru", "phone": "+70580525477"}
0005432838726	C67F95	4187 574566	ERIK MATVEEV	{"phone": "+70130466447"}
0005432838727	6E47C8	3181 826850	ALEKSANDRA SMIRNOVA	{"phone": "+70466782885"}
0005432838728	6E47C8	9302 230273	IVAN SIDOROV	{"email": "sidorov.ivan_121971@postgrespro.ru", "phone": "+70422076715"}
0005432838729	852F23	7692 995904	MIKHAIL NOVIKOV	{"phone": "+70649696847"}
0005432838730	1EDDDD	3425 708404	SERGEY GORBUNOV	{"phone": "+70172154640"}
0005432838731	F8319B	3151 873872	VLADIMIR MIRONOV	{"phone": "+70358881869"}
0005432838732	F8319B	8507 168558	MATVEY PETROV	{"email": "m_petrov-1973@postgrespro.ru", "phone": "+70397053987"}
0005432838733	5157EE	0195 231214	VLADIMIR PETROV	{"email": "v-petrov-031965@postgrespro.ru", "phone": "+70386541735"}
0005432838734	754748	8717 631342	OLEG ISAEV	{"email": "o_isaev.051977@postgrespro.ru", "phone": "+70787419238"}
0005432838735	988F12	6310 793069	ALEKSANDR IVANOV	{"phone": "+70772902514"}
0005432838736	66126A	9815 466020	ANASTASIYA VASILEVA	{"phone": "+70569056689"}
0005432838737	80FDC4	5942 506316	FARIT PETROV	{"email": "petrov_farit-071964@postgrespro.ru", "phone": "+70905926012"}
0005432838738	1CE01B	9421 471395	EGOR SEMENOV	{"phone": "+70361977937"}
0005432838739	1CE01B	7505 753944	VLADIMIR SOROKIN	{"email": "sorokin.vladimir111973@postgrespro.ru", "phone": "+70769504778"}
0005432838740	17B642	6984 208233	ANATOLIY ANDREEV	{"email": "anatoliy.andreev1969@postgrespro.ru", "phone": "+70368919807"}
0005432838741	9E579C	9785 336400	MARINA ERMAKOVA	{"email": "m-ermakova_1975@postgrespro.ru", "phone": "+70580990255"}
0005432838742	C78E0B	0549 708665	MIKHAIL VASILEV	{"email": "vasilev_m.1980@postgrespro.ru", "phone": "+70691443546"}
0005432838743	6732D7	6756 025999	ALEKSANDRA FOMINA	{"email": "fomina.a.19031964@postgrespro.ru", "phone": "+70172432590"}
0005432838744	6732D7	1363 585253	ALEKSANDR IVANOV	{"phone": "+70536055100"}
0005432838745	18B148	6376 045685	VALENTINA MAKAROVA	{"email": "v-makarova1961@postgrespro.ru", "phone": "+70979906334"}
0005432838746	CD4DFD	4077 659250	TATYANA ANTONOVA	{"phone": "+70666641130"}
0005432838747	9902AE	5320 283369	ALEKSANDR SERGEEV	{"email": "a.sergeev.011975@postgrespro.ru", "phone": "+70298766831"}
0005432838748	9902AE	8000 619940	MIKHAIL PAVLOV	{"phone": "+70125576438"}
0005432838749	266A2E	3683 218410	NIKOLAY SOLOVEV	{"email": "nikolaysolovev1970@postgrespro.ru", "phone": "+70674382682"}
0005432838750	266A2E	8763 098128	LIDIYA EGOROVA	{"phone": "+70374564642"}
0005432838751	767019	8671 559669	EKATERINA ZAKHAROVA	{"phone": "+70679601578"}
0005432838752	5D05F3	9689 795120	TAMARA FILIPPOVA	{"email": "tamarafilippova_01091976@postgrespro.ru", "phone": "+70482051861"}
0005432838753	5D05F3	7847 729888	ANASTASIYA MELNIKOVA	{"email": "anastasiyamelnikova.121980@postgrespro.ru", "phone": "+70271119550"}
0005432838754	08E12C	8810 631344	OKSANA NIKITINA	{"email": "nikitina-oksana.1981@postgrespro.ru", "phone": "+70667316062"}
0005432838755	9CAD09	3195 308597	MIKHAIL GERASIMOV	{"email": "gerasimov-mikhail25051971@postgrespro.ru", "phone": "+70527384785"}
0005432838756	9CAD09	6578 380507	GLEB KUZNECOV	{"email": "gleb.kuznecov.16031968@postgrespro.ru", "phone": "+70497058494"}
0005432838757	DB5C1C	5990 497997	ROMAN MAKAROV	{"email": "romanmakarov_06021971@postgrespro.ru", "phone": "+70177060024"}
0005432838758	DB5C1C	0751 866720	EVGENIY KUZMIN	{"phone": "+70521874467"}
0005432838759	ECE013	3313 710452	BORIS MEDVEDEV	{"email": "boris_medvedev_041973@postgrespro.ru", "phone": "+70009620079"}
0005432838760	ECE013	3087 933902	LYUBOV VOLKOVA	{"phone": "+70231736447"}
0005432838761	B3A0D3	1938 990931	SERGEY NAUMOV	{"email": "naumov_s.071980@postgrespro.ru", "phone": "+70165683667"}
0005432838762	DD0908	9381 147403	OLGA ANDREEVA	{"phone": "+70103911561"}
0005432838763	828834	3296 187830	AYRAT KULIKOV	{"phone": "+70615223046"}
0005432838764	BB25B3	3427 260487	EVGENIY TIKHONOV	{"email": "tikhonov-evgeniy1972@postgrespro.ru", "phone": "+70628821334"}
0005432838765	465115	1169 321790	VLADIMIR ANDREEV	{"email": "v.andreev-1975@postgrespro.ru", "phone": "+70404855260"}
0005432838766	8D2C96	5259 174218	YULIYA MIKHAYLOVA	{"phone": "+70830120685"}
0005432838767	33FEB8	2851 666552	PETR MOROZOV	{"email": "petrmorozov-021965@postgrespro.ru", "phone": "+70009841574"}
0005432838768	F8B13F	7781 603320	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda23081972@postgrespro.ru", "phone": "+70590892561"}
0005432838769	9AF29F	1781 342573	SERGEY KOROLEV	{"email": "s.korolev-101977@postgrespro.ru", "phone": "+70265920966"}
0005432838770	9AF29F	7518 260503	ANDREY BORISOV	{"phone": "+70481620786"}
0005432838771	632721	2655 845514	YAROSLAV TARASOV	{"phone": "+70249241888"}
0005432838772	6E4147	1950 765525	MARIYA FILIPPOVA	{"phone": "+70189169320"}
0005432838773	6E4147	8613 429038	NATALYA BORISOVA	{"email": "borisovanatalya.16011977@postgrespro.ru", "phone": "+70672861289"}
0005432838774	4DC8C6	4711 908893	IVAN KAZAKOV	{"phone": "+70558412949"}
0005432838775	B0B844	9888 176406	LILIYA PAVLOVA	{"email": "l-pavlova.031965@postgrespro.ru", "phone": "+70163913155"}
0005432838776	768B7F	9555 732555	NATALYA MAKSIMOVA	{"phone": "+70949348049"}
0005432838777	768B7F	2892 001491	NATALYA LAZAREVA	{"phone": "+70637115310"}
0005432838778	C88DFB	1933 902362	KRISTINA FOMINA	{"email": "k_fomina061956@postgrespro.ru", "phone": "+70428267541"}
0005432838779	B8EB4F	5162 189286	ALEKSANDR GRIGOREV	{"email": "agrigorev_25021971@postgrespro.ru", "phone": "+70002647276"}
0005432838780	B8EB4F	1148 524188	SERGEY GORBUNOV	{"phone": "+70332416172"}
0005432838781	B8EB4F	0530 443954	ALIYA SIDOROVA	{"email": "aliya_sidorova-041969@postgrespro.ru", "phone": "+70790408836"}
0005432838782	DA4310	4805 948224	PAVEL BORISOV	{"phone": "+70662781829"}
0005432838783	DE2306	5980 688159	OLGA SIDOROVA	{"email": "sidorova.o_1980@postgrespro.ru", "phone": "+70139403275"}
0005432838784	DE2306	2625 846694	DENIS SAVELEV	{"phone": "+70337129500"}
0005432838785	0A527A	9915 072340	ELENA FILATOVA	{"email": "filatovae1974@postgrespro.ru", "phone": "+70510205121"}
0005432838786	0A527A	7697 426248	OLGA KRASNOVA	{"phone": "+70710290506"}
0005432838787	45893F	5919 742933	LILIYA BORISOVA	{"email": "borisova_l1966@postgrespro.ru", "phone": "+70615783531"}
0005432838788	DFF87C	7999 630011	POLINA MARTYNOVA	{"phone": "+70170901922"}
0005432838789	2DF58B	1959 457394	TIKHON SEMENOV	{"phone": "+70246198494"}
0005432838790	2DF58B	5523 586784	EKATERINA NIKOLAEVA	{"phone": "+70411049486"}
0005432838791	FA4ECE	6646 471068	LYUDMILA CHERNOVA	{"email": "chernova_l-08121959@postgrespro.ru", "phone": "+70677192182"}
0005432838792	02791D	3140 392583	IRINA SOLOVEVA	{"email": "solovevairina031974@postgrespro.ru", "phone": "+70075585590"}
0005432838793	A9C5E7	6490 520553	ANASTASIYA NESTEROVA	{"phone": "+70170624740"}
0005432838794	7DC313	3332 209137	SOFIYA NIKITINA	{"email": "s_nikitina_19021971@postgrespro.ru", "phone": "+70963897545"}
0005432838795	7EE60C	6328 694480	SOFIYA FILATOVA	{"email": "filatova-sofiya101967@postgrespro.ru", "phone": "+70248846345"}
0005432838796	7EE60C	2650 607846	ROMAN MAKAROV	{"phone": "+70271527465"}
0005432838797	61492E	5412 879522	ANDREY DENISOV	{"phone": "+70542433389"}
0005432838798	9A66ED	6821 816633	VERA NIKOLAEVA	{"email": "nikolaevav-071972@postgrespro.ru", "phone": "+70471110004"}
0005432838799	F5D53B	0500 393609	ANNA SIDOROVA	{"email": "sidorovaanna-1980@postgrespro.ru", "phone": "+70502506986"}
0005432838800	CACD73	1122 433762	ANDREY KUDRYASHOV	{"email": "andrey.kudryashov_18051977@postgrespro.ru", "phone": "+70750390677"}
0005432838801	FAD54A	1025 713496	NATALYA PAVLOVA	{"phone": "+70663159240"}
0005432838802	24E6E8	9408 391822	FAIL VOROBEV	{"email": "fail_vorobev18081967@postgrespro.ru", "phone": "+70453840532"}
0005432838803	8B16D3	0260 297075	ALINA KOROLEVA	{"phone": "+70989836546"}
0005432838804	CE167E	1065 408859	TATYANA MIKHAYLOVA	{"phone": "+70021853508"}
0005432838805	9ECA6C	1968 859785	GALINA KOROLEVA	{"email": "korolevag121964@postgrespro.ru", "phone": "+70122189358"}
0005432838806	DE4B30	1684 884979	ALEKSANDR KOROLEV	{"email": "a-korolev25091974@postgrespro.ru", "phone": "+70866765371"}
0005432838920	F28E85	2742 397177	STANISLAV SOKOLOV	{"phone": "+70121830642"}
0005432838807	85A63E	2840 226507	RUSTYAM SCHERBAKOV	{"email": "rustyamscherbakov-071973@postgrespro.ru", "phone": "+70021242901"}
0005432838808	EABB97	6549 015236	VITALIY IVANOV	{"phone": "+70840910517"}
0005432838809	402650	9129 144315	KSENIYA MAKAROVA	{"phone": "+70022470380"}
0005432838810	BB0EB7	2218 285564	ANGELINA VOLKOVA	{"phone": "+70248959590"}
0005432838811	6CD4EB	1959 276459	ANNA POPOVA	{"phone": "+70445138443"}
0005432838812	DCB215	4640 400481	VYACHESLAV KISELEV	{"email": "vyacheslav_kiselev-091971@postgrespro.ru", "phone": "+70483187491"}
0005432838813	4E7B9C	9022 520231	ANDREY FROLOV	{"email": "andrey.frolov-1973@postgrespro.ru", "phone": "+70090370788"}
0005432838814	54ABFE	9151 955632	SOFYA SOROKINA	{"email": "s.sorokina.121972@postgrespro.ru", "phone": "+70495800173"}
0005432838815	84E284	9654 952705	IRINA POPOVA	{"email": "ipopova-1960@postgrespro.ru", "phone": "+70057408509"}
0005432838816	84E284	7900 600217	VALENTINA MOISEEVA	{"email": "valentinamoiseeva.1967@postgrespro.ru", "phone": "+70682297729"}
0005432838817	84E284	8164 180090	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova-mariya.011973@postgrespro.ru", "phone": "+70216581102"}
0005432838818	84E284	7332 467221	ALEKSANDRA ANTONOVA	{"phone": "+70679494670"}
0005432838819	8CEE5F	9562 762378	TIMUR ZAYCEV	{"email": "zaycevtimur1974@postgrespro.ru", "phone": "+70472503302"}
0005432838820	F029A4	9517 496064	LARISA ROMANOVA	{"phone": "+70996942554"}
0005432838821	B7C173	2026 605236	MIKHAIL MEDVEDEV	{"phone": "+70079789788"}
0005432838822	B7C173	4414 351594	LIDIYA SOROKINA	{"phone": "+70198271406"}
0005432838823	2A0D09	1505 104738	MARIYA FILIPPOVA	{"phone": "+70155871644"}
0005432838824	C4D691	4357 663107	LYUBOV FILIPPOVA	{"phone": "+70464370032"}
0005432838825	C4D691	6546 208364	RAISA GERASIMOVA	{"phone": "+70256383619"}
0005432838826	8115D1	0125 937740	ROMAN SOKOLOV	{"email": "sokolovr_1979@postgrespro.ru", "phone": "+70932704791"}
0005432838827	8115D1	6529 132778	SERGEY BELOV	{"email": "belov_sergey-10011972@postgrespro.ru", "phone": "+70822497955"}
0005432838828	D3A48B	3546 514262	VIKTORIYA FADEEVA	{"email": "viktoriya_fadeeva_25061978@postgrespro.ru", "phone": "+70501454054"}
0005432838829	1CA587	9917 264095	TIGRAN MAKAROV	{"phone": "+70766587510"}
0005432838830	1CA587	5826 477525	MARIYA KARPOVA	{"email": "m.karpova_1981@postgrespro.ru", "phone": "+70967220539"}
0005432838831	0DC935	4591 276701	DMITRIY MOROZOV	{"phone": "+70614790980"}
0005432838832	C522C2	6174 161870	SVETLANA OSIPOVA	{"phone": "+70700628230"}
0005432838833	816AB9	9675 449604	NADEZHDA SOKOLOVA	{"phone": "+70169483472"}
0005432838834	0668CD	1396 796812	NIKOLAY BORISOV	{"email": "borisov.n.05111976@postgrespro.ru", "phone": "+70332599684"}
0005432838835	60E839	8479 283610	OLGA FROLOVA	{"phone": "+70926999316"}
0005432838836	60E839	9404 164606	ANASTASIYA PETROVA	{"phone": "+70524480294"}
0005432838837	109060	8191 650105	VALENTINA GERASIMOVA	{"phone": "+70883512078"}
0005432838838	6C891A	5272 569593	VIKTOR VOROBEV	{"email": "vorobevv-1975@postgrespro.ru", "phone": "+70443434789"}
0005432838839	A3507D	9870 510787	OLGA ANISIMOVA	{"email": "o-anisimova-15071974@postgrespro.ru", "phone": "+70151379843"}
0005432838840	661E37	2771 128397	ANDREY MOROZOV	{"phone": "+70330884649"}
0005432838841	C944F7	2704 851508	VALENTINA KRASNOVA	{"email": "valentina-krasnova_25031960@postgrespro.ru", "phone": "+70751803963"}
0005432838842	AF716E	2404 973373	YAROSLAV SMIRNOV	{"phone": "+70260594771"}
0005432838843	AF716E	2685 863698	ANATOLIY MATVEEV	{"email": "a-matveev_1967@postgrespro.ru", "phone": "+70863385179"}
0005432838844	5AC6E1	1063 780441	NINA MOROZOVA	{"phone": "+70780444754"}
0005432838845	D8C388	2701 088576	SNEZHANA KONDRATEVA	{"email": "skondrateva.1982@postgrespro.ru", "phone": "+70563549624"}
0005432838846	89882D	7623 201281	NINA VOROBEVA	{"email": "nvorobeva_121990@postgrespro.ru", "phone": "+70890892096"}
0005432838847	89882D	7799 098357	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a-051988@postgrespro.ru", "phone": "+70824569161"}
0005432838848	DA779F	3648 812418	VLADIMIR GUSEV	{"email": "v.gusev-06031968@postgrespro.ru", "phone": "+70056383216"}
0005432838849	DD0315	3187 140852	VALENTINA DANILOVA	{"phone": "+70595367013"}
0005432838850	F7B9A7	8322 329982	YURIY KOZLOV	{"phone": "+70697672606"}
0005432838851	71968A	5746 835118	TATYANA IVANOVA	{"phone": "+70588969632"}
0005432838852	71968A	2736 482277	ALEKSEY MIKHAYLOV	{"phone": "+70363475134"}
0005432838853	52D9BD	7414 488454	EVGENIY ORLOV	{"email": "orlov.e.1978@postgrespro.ru", "phone": "+70316646461"}
0005432838854	E8FD9E	3389 714585	VALERIYA NIKOLAEVA	{"phone": "+70206866831"}
0005432838855	E8FD9E	8283 030083	NIKITA SERGEEV	{"phone": "+70049666744"}
0005432838856	5D9B81	3168 194846	IRINA ZAKHAROVA	{"phone": "+70883721273"}
0005432838857	4B8D20	1434 961693	ANATOLIY BELOV	{"email": "anatoliy.belov121958@postgrespro.ru", "phone": "+70626005605"}
0005432838858	74FACB	7041 720579	NATALYA KOROLEVA	{"email": "nkoroleva_10011957@postgrespro.ru", "phone": "+70557140292"}
0005432838859	28B553	2221 740525	ANNA NOVIKOVA	{"phone": "+70591560984"}
0005432838860	733021	8895 155384	ELENA MELNIKOVA	{"email": "e-melnikova011977@postgrespro.ru", "phone": "+70098946467"}
0005432838861	9C44D4	5783 980428	ANNA SAVELEVA	{"email": "saveleva-anna.13091975@postgrespro.ru", "phone": "+70842582446"}
0005432838862	C2321F	7879 052361	EDUARD PETROV	{"phone": "+70161706305"}
0005432838863	7ECB2F	7363 509725	OLGA RODIONOVA	{"email": "olgarodionova1958@postgrespro.ru", "phone": "+70476474059"}
0005432838864	7ECB2F	3139 138094	LARISA SOLOVEVA	{"email": "soloveva-l-1973@postgrespro.ru", "phone": "+70248242723"}
0005432838865	203BC6	8291 092592	MARIYA GAVRILOVA	{"email": "mariya_gavrilova.14051969@postgrespro.ru", "phone": "+70913188211"}
0005432838866	5EBE65	5252 493935	EKATERINA SOKOLOVA	{"phone": "+70459729391"}
0005432838867	C1D291	1967 135801	TATYANA ANISIMOVA	{"phone": "+70737808831"}
0005432838868	67D958	5904 811567	ELENA KAZAKOVA	{"phone": "+70355296768"}
0005432838869	67D958	4675 048739	ALEKSANDR ZAKHAROV	{"phone": "+70857758674"}
0005432838870	730941	0755 259739	NIKITA TIKHONOV	{"email": "tikhonov_n.051985@postgrespro.ru", "phone": "+70051601617"}
0005432838871	549D40	6958 902699	DAMIR STEPANOV	{"email": "dstepanov-1955@postgrespro.ru", "phone": "+70964942975"}
0005432838872	549D40	7784 388406	IGOR FEDOROV	{"email": "fedorovi1983@postgrespro.ru", "phone": "+70313814462"}
0005432838873	549D40	5071 826893	MARINA KOMAROVA	{"phone": "+70133023262"}
0005432838874	DE29DE	8917 393036	NATALYA MELNIKOVA	{"email": "natalyamelnikova_061963@postgrespro.ru", "phone": "+70777401906"}
0005432838875	DE29DE	9283 367006	YURIY EGOROV	{"phone": "+70064863847"}
0005432838876	DE29DE	2448 055798	DANIIL MELNIKOV	{"phone": "+70316694843"}
0005432838877	C7ABFF	9388 698365	SERGEY NOVIKOV	{"email": "novikov-sergey101974@postgrespro.ru", "phone": "+70743887263"}
0005432838878	AEB519	8434 969826	SERGEY ANDREEV	{"phone": "+70437860731"}
0005432838879	9D1DF0	4501 953993	ANDREY TIKHONOV	{"email": "tikhonov.andrey031982@postgrespro.ru", "phone": "+70111962730"}
0005432838880	9D1DF0	3502 939945	LIDIYA TARASOVA	{"email": "tarasova.lidiya101973@postgrespro.ru", "phone": "+70201799424"}
0005432838881	9D1DF0	6569 857156	NIKITA MOROZOV	{"phone": "+70856577169"}
0005432838882	472B56	1904 020982	VLADIMIR ALEKSEEV	{"phone": "+70785896707"}
0005432838883	472B56	9541 282472	PELAGEYA BOGDANOVA	{"email": "pelageya_bogdanova.081968@postgrespro.ru", "phone": "+70701815697"}
0005432838884	510775	2708 204581	IRINA TARASOVA	{"email": "irinatarasova.1970@postgrespro.ru", "phone": "+70662698896"}
0005432838885	510775	4835 994249	IGOR DENISOV	{"phone": "+70845235526"}
0005432838886	BB8778	0372 466638	VLADIMIR MIRONOV	{"email": "vladimir_mironov-1977@postgrespro.ru", "phone": "+70951627462"}
0005432838887	F8E4E0	2260 793311	ANNA SMIRNOVA	{"email": "anna_smirnova101972@postgrespro.ru", "phone": "+70236541814"}
0005432838888	8E0DB4	2425 385787	DMITRIY ALEKSANDROV	{"phone": "+70345718227"}
0005432838889	8E0DB4	0534 243527	YULIYA BELOVA	{"email": "yuliya.belova-1970@postgrespro.ru", "phone": "+70497429241"}
0005432838890	400A69	3705 168310	DMITRIY FEDOTOV	{"phone": "+70596822889"}
0005432838891	400A69	3566 636810	MIKHAIL IVANOV	{"phone": "+70105051746"}
0005432838892	AD38E0	2448 249612	SVETLANA ZAKHAROVA	{"phone": "+70078423742"}
0005432838893	AD38E0	9958 322372	VYACHESLAV ZAKHAROV	{"phone": "+70396756019"}
0005432838894	42340A	0581 387361	ROMAN YAKOVLEV	{"email": "roman-yakovlev_18091976@postgrespro.ru", "phone": "+70385420156"}
0005432838895	42340A	7032 016507	NATALYA OSIPOVA	{"phone": "+70300819532"}
0005432838896	240542	0554 375658	ANNA MOROZOVA	{"email": "a.morozova.071977@postgrespro.ru", "phone": "+70497293486"}
0005432838897	80DD3A	6520 315938	SERGEY YAKOVLEV	{"email": "yakovlev-s.011976@postgrespro.ru", "phone": "+70123667872"}
0005432838898	80DD3A	5674 529095	VLADIMIR SAVELEV	{"email": "vladimir.savelev.02091963@postgrespro.ru", "phone": "+70618395807"}
0005432838899	80DD3A	7033 429338	ANDREY TARASOV	{"email": "a-tarasov_1964@postgrespro.ru", "phone": "+70262161761"}
0005432838900	44C1C1	6257 768033	ANASTASIYA KOZLOVA	{"phone": "+70200256875"}
0005432838901	2DCA64	8361 521684	VLADIMIR ROMANOV	{"email": "v.romanov.30061971@postgrespro.ru", "phone": "+70629280785"}
0005432838902	3E568F	2037 211930	GENNADIY GERASIMOV	{"email": "g_gerasimov-1969@postgrespro.ru", "phone": "+70207429838"}
0005432838903	3F9FBC	4217 771568	OLGA PETROVA	{"phone": "+70276902772"}
0005432838904	3F9FBC	5167 488439	LEONID KULIKOV	{"email": "leonidkulikov.061971@postgrespro.ru", "phone": "+70742899133"}
0005432838905	69A98C	4538 732913	NIKOLAY NIKITIN	{"phone": "+70830085142"}
0005432838906	87C7B9	7838 068131	VARVARA KOROLEVA	{"email": "v-koroleva1977@postgrespro.ru", "phone": "+70538986642"}
0005432838907	87C7B9	0106 405561	NATALYA KOROLEVA	{"phone": "+70803249000"}
0005432838908	FE559E	9469 288530	ELENA KUZNECOVA	{"email": "e.kuznecova.1976@postgrespro.ru", "phone": "+70199740686"}
0005432838909	FE559E	6124 941199	VLADIMIR NIKITIN	{"email": "vnikitin.1962@postgrespro.ru", "phone": "+70531267817"}
0005432838910	D0B7EE	1852 772713	DMITRIY KISELEV	{"phone": "+70828187450"}
0005432838911	D0B7EE	4529 462317	ALEKSANDR VASILEV	{"phone": "+70520256677"}
0005432838912	7E3BA7	9326 333390	INESSA MALYSHEVA	{"phone": "+70703284876"}
0005432838913	7E3BA7	2694 760340	EVGENIY KONOVALOV	{"email": "ekonovalov_15101984@postgrespro.ru", "phone": "+70695275468"}
0005432838914	A6EA3D	7569 577338	DANIL SOKOLOV	{"phone": "+70091351207"}
0005432838915	A6EA3D	7685 751403	VALENTINA ALEKSEEVA	{"phone": "+70025150765"}
0005432838916	BF8378	3331 823089	SOFYA EGOROVA	{"email": "egorova_s_041966@postgrespro.ru", "phone": "+70068488789"}
0005432838917	98DD8A	1966 173897	NATALYA MAKSIMOVA	{"email": "nmaksimova_1965@postgrespro.ru", "phone": "+70552773677"}
0005432838918	98DD8A	2723 423664	SVETLANA GORBUNOVA	{"email": "gorbunova_svetlana1976@postgrespro.ru", "phone": "+70097808372"}
0005432838919	E914F7	9158 900046	KSENIYA FEDOROVA	{"email": "fedorova-kseniya20061972@postgrespro.ru", "phone": "+70707377970"}
0005432838921	3750B5	1797 306302	TAISIYA ABRAMOVA	{"phone": "+70049930820"}
0005432838922	C6FA29	5215 677103	ALEKSEY POPOV	{"email": "popov_a_1970@postgrespro.ru", "phone": "+70829537626"}
0005432838923	C6FA29	2304 779442	VLADIMIR BONDARENKO	{"email": "bondarenko.v20071982@postgrespro.ru", "phone": "+70386541316"}
0005432838924	C6FA29	2481 569585	OLGA ORLOVA	{"phone": "+70046419179"}
0005432838925	1D743E	7704 192539	YURIY SCHERBAKOV	{"email": "scherbakov-yuriy.101973@postgrespro.ru", "phone": "+70419867717"}
0005432838926	FD65EC	9799 445287	ELENA KAZAKOVA	{"email": "kazakova-elena_111976@postgrespro.ru", "phone": "+70308001781"}
0005432838927	E268CC	5852 650798	LYUBOV EFREMOVA	{"email": "lyubov_efremova-1970@postgrespro.ru", "phone": "+70232321677"}
0005432838928	E268CC	3653 381734	IVAN MAKAROV	{"email": "makarov-i_1962@postgrespro.ru", "phone": "+70126989001"}
0005432838929	E268CC	1084 772581	KSENIYA VASILEVA	{"email": "vasilevakseniya_31011967@postgrespro.ru", "phone": "+70184104716"}
0005432838930	6D65CD	0489 497882	ARINA SAVELEVA	{"email": "arinasaveleva041975@postgrespro.ru", "phone": "+70131935628"}
0005432838931	6D65CD	7832 391790	VERONIKA KISELEVA	{"email": "kiseleva-v-1975@postgrespro.ru", "phone": "+70282659946"}
0005432838932	6C4581	4770 127915	MARIYA IVANOVA	{"email": "ivanova_mariya_081976@postgrespro.ru", "phone": "+70556528874"}
0005432838933	6C4581	3638 948172	ALEKSANDR IVANOV	{"email": "ivanov-a.1975@postgrespro.ru", "phone": "+70907666071"}
0005432838934	6C4581	3166 388154	MARIYA SERGEEVA	{"email": "msergeeva05061969@postgrespro.ru", "phone": "+70979931043"}
0005432838935	A277D7	0836 685622	VYACHESLAV TARASOV	{"phone": "+70355106248"}
0005432838936	A277D7	7922 293006	VIKTOR ABRAMOV	{"phone": "+70246169303"}
0005432838937	811D13	6537 437752	VALENTINA SERGEEVA	{"phone": "+70476420507"}
0005432838938	9E103A	1828 068564	VALERIY SMIRNOV	{"phone": "+70987442046"}
0005432838939	766FEC	5602 788348	FEDOR KUZNECOV	{"phone": "+70993201462"}
0005432838940	EE71B6	6347 188911	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov1973@postgrespro.ru", "phone": "+70534413137"}
0005432838941	2A3EC0	8965 110584	VALENTIN BELOV	{"phone": "+70383406210"}
0005432838942	2A3EC0	1271 231855	ANATOLIY PETROV	{"email": "petrov_anatoliy17081981@postgrespro.ru", "phone": "+70351669980"}
0005432838943	F62F0E	7379 806841	ALEKSANDR FROLOV	{"email": "aleksandr_frolov_031970@postgrespro.ru", "phone": "+70349430679"}
0005432838944	F62F0E	8192 244096	MIKHAIL MIKHAYLOV	{"email": "m-mikhaylov031983@postgrespro.ru", "phone": "+70115656481"}
0005432838945	C04764	2556 348407	ALEKSANDR KULIKOV	{"phone": "+70613066278"}
0005432838946	89AA85	1595 303373	RASHIT KUZNECOV	{"phone": "+70365621065"}
0005432838947	3A7AA8	6947 750428	DENIS MEDVEDEV	{"phone": "+70476918763"}
0005432838948	3A7AA8	1676 116069	TATYANA ZAYCEVA	{"phone": "+70680659169"}
0005432838949	D6D6A2	9466 959906	VALENTINA BARANOVA	{"email": "v.baranova-071958@postgrespro.ru", "phone": "+70547489253"}
0005432838950	C46E93	7080 915998	ALEKSANDR DAVYDOV	{"email": "davydov_aleksandr-061974@postgrespro.ru", "phone": "+70575931494"}
0005432838951	F701D0	1449 907459	VLADIMIR DMITRIEV	{"phone": "+70962834653"}
0005432838952	71597E	4462 800676	SHAMIL BARANOV	{"phone": "+70952857147"}
0005432838953	E72D91	8970 983304	EVGENIY GORBUNOV	{"phone": "+70378259715"}
0005432838954	D19887	4982 476115	VALERIY KISELEV	{"email": "kiselevv08011966@postgrespro.ru", "phone": "+70333403308"}
0005432838955	D68A99	7349 308153	RAISA KOROLEVA	{"email": "koroleva_r_021972@postgrespro.ru", "phone": "+70480244142"}
0005432838956	D68A99	2620 853932	MARIYA POPOVA	{"phone": "+70359361569"}
0005432838957	8D819C	7565 560614	KSENIYA LAZAREVA	{"email": "lazareva.kseniya06031978@postgrespro.ru", "phone": "+70319321115"}
0005432838958	8D819C	1904 307061	OLEG ZAKHAROV	{"email": "zakharov.o.1972@postgrespro.ru", "phone": "+70372651145"}
0005432838959	815B29	7101 982720	POLINA SOROKINA	{"phone": "+70942795461"}
0005432838960	815B29	0580 011605	NADEZHDA KOROLEVA	{"phone": "+70242389901"}
0005432838961	ABC4E5	4089 411664	GRIGORIY KUZMIN	{"email": "kuzming.031982@postgrespro.ru", "phone": "+70371276242"}
0005432838962	12FE1C	1125 639513	ELENA VOLKOVA	{"email": "evolkova_1977@postgrespro.ru", "phone": "+70484711677"}
0005432838963	AA9AE1	6384 377826	MARIYA TARASOVA	{"email": "mariya_tarasova02041960@postgrespro.ru", "phone": "+70969525217"}
0005432838964	E256FD	5939 398981	SERGEY ZHURAVLEV	{"email": "s-zhuravlev_24031976@postgrespro.ru", "phone": "+70283077836"}
0005432838965	D75D1F	9116 987231	ALISHER IVANOV	{"phone": "+70349776409"}
0005432838966	D75D1F	6171 428129	ALEKSANDRA TIKHONOVA	{"email": "tikhonova.aleksandra.1976@postgrespro.ru", "phone": "+70920313764"}
0005432838967	66C3B4	8690 237608	ALEKSANDR SOKOLOV	{"email": "a_sokolov.031975@postgrespro.ru", "phone": "+70396664058"}
0005432838968	E1A120	3136 989029	GENNADIY GUSEV	{"email": "gennadiy.gusev-1973@postgrespro.ru", "phone": "+70371391415"}
0005432838969	422E3A	0282 256560	ANATOLIY MIRONOV	{"phone": "+70387841198"}
0005432838970	940230	5826 122320	ROMAN MIRONOV	{"phone": "+70841486419"}
0005432838971	CDF9B4	9193 301441	PAVEL NIKITIN	{"phone": "+70235708344"}
0005432838972	CDF9B4	8453 156484	SVETLANA SOROKINA	{"email": "sorokinas.24011971@postgrespro.ru", "phone": "+70137341763"}
0005432838973	C988A7	1528 125058	VALENTINA KUZMINA	{"phone": "+70614624007"}
0005432838974	2D6894	8662 639047	IRINA STEPANOVA	{"email": "irinastepanova061983@postgrespro.ru", "phone": "+70280153225"}
0005432838975	2D6894	5793 736318	ALEKSEY IVANOV	{"phone": "+70648446391"}
0005432839032	F117BF	1852 315098	ALEKSANDR IVANOV	{"phone": "+70969157962"}
0005432838976	3B51FE	8404 121385	NADEZHDA OSIPOVA	{"email": "osipova.nadezhda_09011979@postgrespro.ru", "phone": "+70792008470"}
0005432838977	8321E3	3574 447840	MARAT ZHURAVLEV	{"phone": "+70759570614"}
0005432838978	E8CA2F	1772 121278	ELENA EGOROVA	{"email": "elena.egorova_21061980@postgrespro.ru", "phone": "+70072177705"}
0005432838979	32F8FD	1987 323065	GALINA KISELEVA	{"phone": "+70502356540"}
0005432838980	32F8FD	6129 388822	SVETLANA NAZAROVA	{"email": "s_nazarova1976@postgrespro.ru", "phone": "+70900255145"}
0005432838981	F5A10D	7648 997443	ALEKSEY SEMENOV	{"phone": "+70544388871"}
0005432838982	F5A10D	3445 420772	DMITRIY BORISOV	{"phone": "+70898580949"}
0005432838983	4B463C	0878 193538	LIDIYA OSIPOVA	{"email": "osipova.lidiya-1962@postgrespro.ru", "phone": "+70604820580"}
0005432838984	0D20AE	3595 559737	ANNA KONDRATEVA	{"phone": "+70738192825"}
0005432838985	0D20AE	9111 184667	LYUBOV VASILEVA	{"email": "vasilevalyubov031968@postgrespro.ru", "phone": "+70037354084"}
0005432838986	D37747	8387 170127	SERGEY KUZNECOV	{"email": "sergey-kuznecov.121972@postgrespro.ru", "phone": "+70923130949"}
0005432838987	8C2EB8	3438 713966	MAKSIM NIKITIN	{"phone": "+70803866129"}
0005432838988	791F28	3976 039497	ELENA CHERNOVA	{"email": "elena.chernova01051980@postgrespro.ru", "phone": "+70357793896"}
0005432838989	791F28	5160 441756	NADEZHDA ISAEVA	{"phone": "+70515053614"}
0005432838990	D54438	7957 624406	SERGEY MAKAROV	{"phone": "+70051783913"}
0005432838991	D54438	5591 679192	GENNADIY DAVYDOV	{"email": "g.davydov021975@postgrespro.ru", "phone": "+70541695550"}
0005432838992	DB36DC	9915 888148	VLADIMIR ZAYCEV	{"email": "v_zaycev_07011974@postgrespro.ru", "phone": "+70929902180"}
0005432838993	DB36DC	6124 520778	DANILA NAZAROV	{"phone": "+70966255343"}
0005432838994	DB36DC	4121 960116	TATYANA KOMAROVA	{"email": "komarovat-101972@postgrespro.ru", "phone": "+70278496011"}
0005432838995	9E000F	6623 880708	VALERIY DENISOV	{"email": "denisov-v-041979@postgrespro.ru", "phone": "+70298861869"}
0005432838996	9E000F	1683 687913	EKATERINA MOISEEVA	{"email": "e_moiseeva.11011967@postgrespro.ru", "phone": "+70089192896"}
0005432838997	A69EC3	7679 571272	ALEKSANDR BORISOV	{"email": "a-borisov-121963@postgrespro.ru", "phone": "+70728984318"}
0005432838998	DB8A08	7872 709284	EVGENIY RODIONOV	{"email": "evgeniyrodionov.1970@postgrespro.ru", "phone": "+70857067926"}
0005432838999	887191	3073 093790	ALEKSEY ANDREEV	{"email": "andreev_a-08051971@postgrespro.ru", "phone": "+70594868606"}
0005432839000	A52AF2	7031 659976	EVDOKIYA MIKHAYLOVA	{"email": "mikhaylovaevdokiya_041959@postgrespro.ru", "phone": "+70168309675"}
0005432839001	1F7C29	6004 950686	MARINA TARASOVA	{"email": "tarasova-marina-011984@postgrespro.ru", "phone": "+70976413236"}
0005432839002	3AFA3C	4465 600169	TATYANA KOZLOVA	{"email": "kozlova-tatyana.27121965@postgrespro.ru", "phone": "+70166402795"}
0005432839003	D89742	3900 048352	VALENTINA ORLOVA	{"phone": "+70356474068"}
0005432839004	69397D	7294 762610	LYUDMILA KOZLOVA	{"phone": "+70979104822"}
0005432839005	69397D	3067 658931	MIKHAIL DAVYDOV	{"email": "mikhail_davydov021974@postgrespro.ru", "phone": "+70867287169"}
0005432839006	F48ABF	0348 752387	LIDIYA DENISOVA	{"email": "denisova-l.1968@postgrespro.ru", "phone": "+70396098248"}
0005432839007	E60891	1001 378738	SERGEY DAVYDOV	{"phone": "+70077210185"}
0005432839008	E60891	7410 902007	GALINA RODIONOVA	{"phone": "+70705572881"}
0005432839009	F68CD7	7768 751517	LIDIYA YUDINA	{"email": "lyudina111977@postgrespro.ru", "phone": "+70651436782"}
0005432839010	8462D1	5304 037758	YANA KAZAKOVA	{"email": "kazakova_y.1976@postgrespro.ru", "phone": "+70871187599"}
0005432839011	67115F	2622 769387	NIKOLAY BONDARENKO	{"phone": "+70993135661"}
0005432839012	D1EAF3	9945 173189	SVETLANA DMITRIEVA	{"email": "svetlana_dmitrieva.09011974@postgrespro.ru", "phone": "+70138039314"}
0005432839013	D4F444	4770 273267	ALEKSEY KISELEV	{"phone": "+70500275722"}
0005432839014	D4F444	3610 104800	ELINA GAVRILOVA	{"phone": "+70846156686"}
0005432839015	476869	3326 544734	OLGA KAZAKOVA	{"phone": "+70665934679"}
0005432839016	476869	1883 437389	RAISA POPOVA	{"phone": "+70346758721"}
0005432839017	7A812A	4688 060603	NATALYA KOROLEVA	{"phone": "+70751756603"}
0005432839018	474179	3550 980238	IVAN BELOV	{"phone": "+70373015961"}
0005432839019	414C0D	0795 275673	IRINA MIKHAYLOVA	{"phone": "+70168696811"}
0005432839020	BAF711	2401 359582	TATYANA NESTEROVA	{"phone": "+70354313964"}
0005432839021	BAF711	8955 073282	OKSANA SOROKINA	{"email": "sorokina_o_19031974@postgrespro.ru", "phone": "+70716149415"}
0005432839022	BDDCB9	5210 942196	GALINA ANISIMOVA	{"phone": "+70752126459"}
0005432839023	294C8F	8405 010130	ALEKSANDR BORISOV	{"email": "borisovaleksandr1984@postgrespro.ru", "phone": "+70743462499"}
0005432839024	6A8FA1	0021 552582	ALEKSEY MATVEEV	{"email": "matveev-aleksey_1971@postgrespro.ru", "phone": "+70162215220"}
0005432839025	6A8FA1	5872 196238	ANTONINA ZAYCEVA	{"phone": "+70610559904"}
0005432839026	F8A0BE	8763 508166	RUSLAN FOMIN	{"email": "rfomin.111979@postgrespro.ru", "phone": "+70337584989"}
0005432839027	F8A0BE	8088 612827	LYUDMILA SOROKINA	{"phone": "+70038293357"}
0005432839028	0809FA	6331 222509	MAKSIM SIDOROV	{"phone": "+70031758871"}
0005432839029	819760	1302 139800	LIDIYA LAZAREVA	{"phone": "+70527852677"}
0005432839030	9E94A1	7709 010973	IGOR KUZNECOV	{"email": "kuznecov-igor.07071975@postgrespro.ru", "phone": "+70203535304"}
0005432839031	9E94A1	4563 804386	NIKITA KUZNECOV	{"phone": "+70014011027"}
0005432839033	C72CB5	1302 632226	EDUARD NAZAROV	{"email": "eduardnazarov_071983@postgrespro.ru", "phone": "+70743031733"}
0005432839034	C72CB5	3504 518422	KAMILLA IVANOVA	{"email": "ivanovak.081977@postgrespro.ru", "phone": "+70876075178"}
0005432839035	8F640F	0901 654683	INNA KOZLOVA	{"phone": "+70528324784"}
0005432839036	6244DD	4244 488061	NADEZHDA SCHERBAKOVA	{"email": "scherbakova.nadezhda-19071960@postgrespro.ru", "phone": "+70149802961"}
0005432839037	B038CC	9460 105289	PETR MAKAROV	{"phone": "+70312328294"}
0005432839038	C3F10B	4209 765058	OKSANA IVANOVA	{"phone": "+70514457641"}
0005432839039	F553E7	3410 322549	YULIYA SOROKINA	{"email": "yuliyasorokina_26071963@postgrespro.ru", "phone": "+70449922178"}
0005432839040	F553E7	6480 242162	IRINA ILINA	{"email": "irina_ilina_1980@postgrespro.ru", "phone": "+70834390504"}
0005432839041	CA237C	8513 640127	VLADIMIR MAKAROV	{"phone": "+70292384707"}
0005432839042	CA237C	4421 157652	ELENA AKIMOVA	{"email": "e.akimova-30111969@postgrespro.ru", "phone": "+70085906370"}
0005432839043	40A3C5	7175 212876	VIKTOR GAVRILOV	{"email": "viktor.gavrilov1969@postgrespro.ru", "phone": "+70502191265"}
0005432839044	40A3C5	9193 754723	ELVIRA ABRAMOVA	{"email": "e.abramova_1968@postgrespro.ru", "phone": "+70311453022"}
0005432839045	44C4D2	9528 347837	EKATERINA MOROZOVA	{"phone": "+70630090304"}
0005432839046	D05E3A	1000 133739	ELENA NIKIFOROVA	{"phone": "+70801037538"}
0005432839047	F94F1B	0842 012757	LYUDMILA KARPOVA	{"phone": "+70828391268"}
0005432839048	F94F1B	3696 095982	DANIL FEDOTOV	{"email": "danil-fedotov14011975@postgrespro.ru", "phone": "+70870040474"}
0005432839049	1212FC	1304 862161	ARTEM ROMANOV	{"email": "artem_romanov.1966@postgrespro.ru", "phone": "+70634069632"}
0005432839050	218B04	4892 964339	ZINAIDA ORLOVA	{"email": "orlova.zinaida021978@postgrespro.ru", "phone": "+70319943822"}
0005432839051	2C28C8	7446 448741	VLADISLAV KOZLOV	{"email": "vladislav.kozlov1973@postgrespro.ru", "phone": "+70503999591"}
0005432839052	2C28C8	4960 128325	TATYANA ANTONOVA	{"email": "antonovat_061967@postgrespro.ru", "phone": "+70632668041"}
0005432839053	3648C8	0737 081126	PAVEL SMIRNOV	{"phone": "+70337912640"}
0005432839054	3648C8	7609 327071	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a-1976@postgrespro.ru", "phone": "+70989118171"}
0005432839055	0E9B1A	2021 426797	MURAT MOROZOV	{"email": "morozov_m23081977@postgrespro.ru", "phone": "+70866549819"}
0005432839056	0E9B1A	2351 422538	IVAN POPOV	{"email": "ivanpopov.1970@postgrespro.ru", "phone": "+70561844069"}
0005432839057	0E9B1A	5365 514393	SERGEY ZHUKOV	{"phone": "+70570738802"}
0005432839058	79D76B	1526 212950	KONSTANTIN AFANASEV	{"email": "konstantin.afanasev.22061972@postgrespro.ru", "phone": "+70561438967"}
0005432839059	4A57F3	0373 572143	ANATOLIY EGOROV	{"phone": "+70655755618"}
0005432839060	9ECAFB	9065 370544	NIKOLAY BORISOV	{"phone": "+70479836131"}
0005432839061	9ECAFB	6406 118234	OLGA SAVELEVA	{"email": "saveleva_o1974@postgrespro.ru", "phone": "+70925908544"}
0005432839062	3E8C82	7991 894011	ANTONINA POTAPOVA	{"email": "apotapova_051967@postgrespro.ru", "phone": "+70237383586"}
0005432839063	3E8C82	6124 201383	IRINA KONDRATEVA	{"phone": "+70565816103"}
0005432839064	AC2C7E	2384 182130	ANDREY ABRAMOV	{"email": "abramov-andrey_1978@postgrespro.ru", "phone": "+70083664229"}
0005432839065	66561A	0288 261719	OLESYA ZAKHAROVA	{"email": "o.zakharova_09061971@postgrespro.ru", "phone": "+70046249073"}
0005432839066	66561A	0278 871680	ALINA STEPANOVA	{"phone": "+70632199276"}
0005432839067	23497A	3143 248117	ALEKSANDR DAVYDOV	{"phone": "+70134648331"}
0005432839068	23497A	3780 353198	EVGENIYA SIDOROVA	{"email": "e.sidorova_19051977@postgrespro.ru", "phone": "+70482401007"}
0005432839069	E29196	4954 495359	IRINA ZHUKOVA	{"email": "irinazhukova.08011970@postgrespro.ru", "phone": "+70672687307"}
0005432839070	01976C	7787 105281	NADEZHDA BELOVA	{"phone": "+70729303832"}
0005432839071	CB7FFD	6702 527808	IRINA ISAEVA	{"phone": "+70252789913"}
0005432839072	CB7FFD	4977 204883	ANATOLIY KRASNOV	{"phone": "+70320742309"}
0005432839073	AA91A1	2091 975420	ANATOLIY RODIONOV	{"phone": "+70691640413"}
0005432839074	A456A2	9624 710574	TATYANA KRASNOVA	{"email": "t-krasnova-1974@postgrespro.ru", "phone": "+70776585750"}
0005432839075	8B3864	7702 475746	OLGA GUSEVA	{"phone": "+70716881441"}
0005432839076	C80653	7877 756642	INNA SEMENOVA	{"email": "innasemenova1958@postgrespro.ru", "phone": "+70325785930"}
0005432839077	C80653	2646 327846	VYACHESLAV YAKOVLEV	{"phone": "+70936986891"}
0005432839078	AB2C35	0554 199319	MARK IVANOV	{"email": "m-ivanov-08021969@postgrespro.ru", "phone": "+70052637032"}
0005432839079	7D6BC9	2136 625960	OLEG VLASOV	{"email": "vlasovo_1980@postgrespro.ru", "phone": "+70883210391"}
0005432839080	0B9081	1440 013796	DMITRIY PETROV	{"email": "petrov_dmitriy_101978@postgrespro.ru", "phone": "+70956795020"}
0005432839081	78688A	3580 948569	NIKOLAY SOLOVEV	{"phone": "+70735557192"}
0005432839082	78688A	6599 221206	GALINA NIKIFOROVA	{"phone": "+70346158220"}
0005432839083	36DFD2	2727 968244	GENNADIY VASILEV	{"phone": "+70456183731"}
0005432839084	E85B63	3435 837784	ANNA KOROLEVA	{"phone": "+70257089092"}
0005432839085	BD51F2	8865 270402	SVETLANA STEPANOVA	{"email": "svetlana-stepanova_09041977@postgrespro.ru", "phone": "+70693425009"}
0005432839086	BD51F2	3532 156081	NATALYA SAVELEVA	{"phone": "+70857865025"}
0005432839087	973696	5708 553785	ELVIRA RODIONOVA	{"phone": "+70477052934"}
0005432839088	4B1DCE	3787 312502	EGOR SIDOROV	{"email": "sidorov_e.19081970@postgrespro.ru", "phone": "+70413746301"}
0005432839089	8E2448	3939 768948	LYUDMILA IVANOVA	{"phone": "+70742812459"}
0005432839090	8E2448	0461 164232	VIKTORIYA SEMENOVA	{"email": "semenovav-29021984@postgrespro.ru", "phone": "+70434472524"}
0005432839091	B332E8	4456 798760	PAVEL FEDOROV	{"email": "p-fedorov_121966@postgrespro.ru", "phone": "+70365029352"}
0005432839092	D7F47B	1234 398507	VLADIMIR SMIRNOV	{"email": "vsmirnov31081964@postgrespro.ru", "phone": "+70351700937"}
0005432839093	BB771F	8594 611600	VIKTOR KAZAKOV	{"phone": "+70168861918"}
0005432839094	5D3479	3327 100343	TAMARA VASILEVA	{"phone": "+70549672944"}
0005432839095	5D3479	4642 726781	NIKITA ZAKHAROV	{"phone": "+70811187899"}
0005432839096	0BD69B	0540 009831	ELENA MAKSIMOVA	{"phone": "+70327456981"}
0005432839097	0BD69B	8842 621228	ALEKSANDR KOZLOV	{"phone": "+70912970213"}
0005432839098	0BD69B	8215 728832	EVGENIYA BORISOVA	{"phone": "+70260045078"}
0005432839099	AF2C5D	8906 504157	KSENIYA NAUMOVA	{"email": "k_naumova_29091975@postgrespro.ru", "phone": "+70455038042"}
0005432839100	AF2C5D	5481 606651	IVAN SCHERBAKOV	{"email": "i_scherbakov08021967@postgrespro.ru", "phone": "+70167585693"}
0005432839101	20AE7E	4583 245395	EKATERINA MAKAROVA	{"email": "e-makarova12121977@postgrespro.ru", "phone": "+70640091085"}
0005432839102	4588C5	3781 329821	NADEZHDA GORBUNOVA	{"email": "gorbunovan_1968@postgrespro.ru", "phone": "+70253185026"}
0005432839103	27A1E6	1063 591881	DMITRIY VLASOV	{"phone": "+70784014112"}
0005432839104	27A1E6	5522 330049	TATYANA ZOTOVA	{"email": "zotovat_061969@postgrespro.ru", "phone": "+70909757635"}
0005432839105	69022E	0229 947486	SERGEY TIKHONOV	{"phone": "+70414694051"}
0005432839106	AA14C9	7435 690202	VIKTORIYA VOLKOVA	{"phone": "+70586339943"}
0005432839107	C75B08	9025 344374	ALEKSANDR ZHUKOV	{"email": "zhukov-a_1961@postgrespro.ru", "phone": "+70575153232"}
0005432839108	89AD12	2594 273024	GALINA IVANOVA	{"email": "g_ivanova_01031971@postgrespro.ru", "phone": "+70951477442"}
0005432839109	89AD12	9642 806734	ANATOLIY NAZAROV	{"phone": "+70909724729"}
0005432839110	8890B7	9326 680301	OKSANA BELYAEVA	{"email": "oksanabelyaeva101970@postgrespro.ru", "phone": "+70457754272"}
0005432839111	082677	4957 103085	ALEKSANDR IVANOV	{"phone": "+70314426894"}
0005432839112	EBB9C7	5285 044548	NATALYA POTAPOVA	{"email": "potapova.natalya-13021970@postgrespro.ru", "phone": "+70114475940"}
0005432839113	EBB9C7	8038 985882	VIKTORIYA MAKAROVA	{"phone": "+70170173097"}
0005432839114	A590AB	8808 418588	ANTONINA KOROLEVA	{"email": "korolevaantonina_1977@postgrespro.ru", "phone": "+70376715517"}
0005432839115	F77DCD	8849 490866	ANNA KUZMINA	{"email": "a.kuzmina-1969@postgrespro.ru", "phone": "+70474063657"}
0005432839116	F77DCD	9978 741086	SVETLANA ZAYCEVA	{"email": "szayceva-041976@postgrespro.ru", "phone": "+70985787838"}
0005432839117	6C17D8	2353 111435	ALEKSEY ZAKHAROV	{"email": "zakharova-1984@postgrespro.ru", "phone": "+70221751271"}
0005432839118	7C74B7	1759 711285	SVETLANA SOKOLOVA	{"phone": "+70717044530"}
0005432839119	D2A76B	4346 402544	DENIS BONDARENKO	{"email": "bondarenko_denis.031967@postgrespro.ru", "phone": "+70886884651"}
0005432839120	0EC5FB	3977 785779	EVGENIY SOROKIN	{"phone": "+70659315569"}
0005432839121	FEA0FD	1516 688413	NATALYA PETROVA	{"phone": "+70577205208"}
0005432839122	FEA0FD	8859 381652	LARISA VOROBEVA	{"phone": "+70647953273"}
0005432839123	4CBD12	7217 041003	VIKTOR ANDREEV	{"phone": "+70541390265"}
0005432839124	84664B	5111 616762	NATALYA EGOROVA	{"email": "egorova-natalya1980@postgrespro.ru", "phone": "+70009405944"}
0005432839125	AF0912	0667 512147	SERGEY ANDREEV	{"phone": "+70753935824"}
0005432839126	AF0912	3464 801759	ANNA AKIMOVA	{"email": "a-akimova1968@postgrespro.ru", "phone": "+70514079934"}
0005432839127	C3CB57	2428 976408	ELENA FOMINA	{"email": "fomina.elena08021972@postgrespro.ru", "phone": "+70327353452"}
0005432839128	A12F0F	7642 740030	OLGA KOROLEVA	{"phone": "+70393878140"}
0005432839129	A12F0F	8034 681410	ELENA DAVYDOVA	{"phone": "+70942401871"}
0005432839130	D76651	0587 351762	ANNA LEBEDEVA	{"phone": "+70517570693"}
0005432839131	D76651	5073 532139	EVGENIYA TARASOVA	{"email": "evgeniya-tarasova021973@postgrespro.ru", "phone": "+70430985659"}
0005432839132	FEE58E	5059 637087	LIDIYA IVANOVA	{"email": "ivanova_lidiya-101965@postgrespro.ru", "phone": "+70427793888"}
0005432839189	8BB49E	8848 350552	ALEKSANDRA KUZNECOVA	{"phone": "+70587574859"}
0005432839133	8EA1E2	0559 962631	SERGEY KUZNECOV	{"email": "sergey-kuznecov031977@postgrespro.ru", "phone": "+70452557493"}
0005432839134	8EA1E2	2647 017746	ARMAN CHERNOV	{"phone": "+70514346600"}
0005432839135	BFAC74	3676 341311	ILYA NIKITIN	{"email": "ilyanikitin-071964@postgrespro.ru", "phone": "+70395470242"}
0005432839136	FCFBC0	6312 475972	VLADIMIR BELOV	{"email": "belov.vladimir.1973@postgrespro.ru", "phone": "+70955820318"}
0005432839137	C1CF1C	6803 253456	OLGA KUDRYASHOVA	{"email": "okudryashova.081972@postgrespro.ru", "phone": "+70882594781"}
0005432839138	C1CF1C	4196 177435	NATALYA ZAKHAROVA	{"phone": "+70547678751"}
0005432839139	4D2B90	9974 745089	ARTEM VLASOV	{"phone": "+70615233385"}
0005432839140	F6A1EA	1498 200380	SERGEY MELNIKOV	{"phone": "+70242551502"}
0005432839141	F6A1EA	0083 233603	ANGELINA EGOROVA	{"email": "egorova_a_021972@postgrespro.ru", "phone": "+70984949286"}
0005432839142	C55EEF	7600 297404	IRINA ABRAMOVA	{"email": "abramova_irina-1976@postgrespro.ru", "phone": "+70639282350"}
0005432839143	1AD4E9	1928 862772	IRINA BORISOVA	{"phone": "+70856645766"}
0005432839144	1AD4E9	7325 291173	OKSANA LUKYANOVA	{"email": "o.lukyanova-091972@postgrespro.ru", "phone": "+70069129869"}
0005432839145	739832	0702 524249	OLEG NAZAROV	{"phone": "+70507925446"}
0005432839146	5D4167	4066 393484	TATYANA SOLOVEVA	{"email": "tatyanasoloveva-23121977@postgrespro.ru", "phone": "+70036592209"}
0005432839147	5D4167	2390 661343	ALEKSANDR MATVEEV	{"phone": "+70892066423"}
0005432839148	61F679	0649 938099	VALENTINA ROMANOVA	{"email": "v-romanova.1970@postgrespro.ru", "phone": "+70805251452"}
0005432839149	61F679	8941 247237	SERGEY ALEKSEEV	{"phone": "+70572508458"}
0005432839150	D3298C	7533 656373	ALEKSANDR IVANOV	{"email": "ivanov.a22081970@postgrespro.ru", "phone": "+70972506854"}
0005432839151	D3298C	8091 548351	IGOR KUZNECOV	{"phone": "+70001456576"}
0005432839152	277B17	8229 918826	GENNADIY SIDOROV	{"email": "sidorov_g08091971@postgrespro.ru", "phone": "+70115846812"}
0005432839153	0A087A	5261 035323	NATALYA ALEKSEEVA	{"phone": "+70297622078"}
0005432839154	A404AB	0296 913378	VERA SOROKINA	{"phone": "+70943493498"}
0005432839155	A404AB	8318 396901	LYUBOV KUZNECOVA	{"phone": "+70641850845"}
0005432839156	AFC963	7622 751226	NIKOLAY KUDRYASHOV	{"email": "n_kudryashov1966@postgrespro.ru", "phone": "+70229382888"}
0005432839157	AFC963	2411 723043	TATYANA SOROKINA	{"email": "sorokina.t1980@postgrespro.ru", "phone": "+70539118905"}
0005432839158	F16A26	4506 297596	SVETLANA SOKOLOVA	{"email": "sokolova_s1984@postgrespro.ru", "phone": "+70066766751"}
0005432839159	F16A26	3900 959379	SOFYA OSIPOVA	{"email": "sofya-osipova09051969@postgrespro.ru", "phone": "+70716284690"}
0005432839160	B6C60B	3991 327547	OKSANA FROLOVA	{"email": "oksana-frolova.011973@postgrespro.ru", "phone": "+70873035314"}
0005432839161	B6C60B	0145 801791	VITALIY TARASOV	{"email": "vitaliy.tarasov071976@postgrespro.ru", "phone": "+70419527641"}
0005432839162	B5AF38	6615 331412	ANTONINA KOROLEVA	{"phone": "+70930983965"}
0005432839163	5FCE21	0925 644458	IRINA SEMENOVA	{"phone": "+70717898373"}
0005432839164	5FCE21	7935 398811	VIKTOR MAKAROV	{"phone": "+70888591357"}
0005432839165	CD0CD6	4571 090674	EVGENIY ZHURAVLEV	{"phone": "+70661977768"}
0005432839166	6D5F05	7321 956715	IRINA BELYAEVA	{"email": "ibelyaeva_09041967@postgrespro.ru", "phone": "+70937664901"}
0005432839167	9B7143	6173 133043	IRINA GORBUNOVA	{"email": "irinagorbunova.121966@postgrespro.ru", "phone": "+70568331015"}
0005432839168	9B7143	5175 085198	ELIZAVETA SMIRNOVA	{"email": "e.smirnova1972@postgrespro.ru", "phone": "+70351024503"}
0005432839169	CB2121	7443 535513	ANDREY KUDRYASHOV	{"phone": "+70739554727"}
0005432839170	6C0D7D	0423 822687	KAMIL KUZMIN	{"email": "kuzminkamil_1969@postgrespro.ru", "phone": "+70727726627"}
0005432839171	84A358	8651 333615	NIKOLAY CHERNOV	{"email": "chernov.nikolay_031982@postgrespro.ru", "phone": "+70724048397"}
0005432839172	84A358	8900 443961	MAKSIM SEMENOV	{"phone": "+70566396819"}
0005432839173	EC6E15	7386 302801	ANASTASIYA KOMAROVA	{"phone": "+70898937161"}
0005432839174	EC6E15	7092 791158	KONSTANTIN VOROBEV	{"phone": "+70237505022"}
0005432839175	EC6E15	3571 154102	YURIY VOLKOV	{"phone": "+70260299680"}
0005432839176	B2DC6E	3515 541149	VYACHESLAV BELOV	{"email": "belovv.22091971@postgrespro.ru", "phone": "+70801937635"}
0005432839177	B2DC6E	1307 790384	VLADIMIR SEMENOV	{"phone": "+70284682429"}
0005432839178	AF14F7	0352 744582	DARYA ZHURAVLEVA	{"phone": "+70557116794"}
0005432839179	79E7D2	0620 880903	EVGENIYA KALININA	{"email": "evgeniyakalinina_21051970@postgrespro.ru", "phone": "+70909468702"}
0005432839180	736DEC	6122 083038	ANDREY ISAEV	{"email": "isaev-a_031976@postgrespro.ru", "phone": "+70827966103"}
0005432839181	736DEC	7891 047714	NIKOLAY POPOV	{"email": "popov-nikolay11111975@postgrespro.ru", "phone": "+70597131084"}
0005432839182	F3AADC	7410 759965	ANTON BORISOV	{"email": "a-borisov041981@postgrespro.ru", "phone": "+70707757480"}
0005432839183	A40318	7370 043912	MARIYA KONDRATEVA	{"phone": "+70251972613"}
0005432839184	A40318	5140 273685	ALSU NIKITINA	{"email": "a_nikitina_28101968@postgrespro.ru", "phone": "+70360282922"}
0005432839185	8EC3C2	4140 959203	SOFYA LOGINOVA	{"phone": "+70610468262"}
0005432839186	8EC3C2	7346 129074	VLADISLAV KONOVALOV	{"phone": "+70094270970"}
0005432839187	53E624	7467 651762	ELENA ANDREEVA	{"phone": "+70681046621"}
0005432839188	53E624	3761 760696	VALENTINA ABRAMOVA	{"email": "abramovav061962@postgrespro.ru", "phone": "+70343678882"}
0005432839190	36856F	3423 662810	ILONA SOROKINA	{"phone": "+70333126763"}
0005432839191	EF0879	9408 992504	ALSU ARKHIPOVA	{"email": "arkhipova.alsu05041970@postgrespro.ru", "phone": "+70615783454"}
0005432839192	646620	0408 351099	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir-111980@postgrespro.ru", "phone": "+70257373236"}
0005432839193	93F3F5	5411 584213	YULIYA SMIRNOVA	{"phone": "+70673019489"}
0005432839194	93F3F5	9322 885365	IVAN SAVELEV	{"email": "ivan-savelev.071972@postgrespro.ru", "phone": "+70846730735"}
0005432839195	11EDCF	2878 089991	SERGEY PETROV	{"email": "petrov.s011979@postgrespro.ru", "phone": "+70341785065"}
0005432839196	11EDCF	5285 343390	FEDOR STEPANOV	{"phone": "+70310105042"}
0005432839197	200641	5509 458594	ANNA ZOTOVA	{"email": "azotova_22091985@postgrespro.ru", "phone": "+70876901173"}
0005432839198	200641	0198 398780	RAVIL AFANASEV	{"phone": "+70759223978"}
0005432839199	87DED2	7729 449819	VALENTINA DANILOVA	{"email": "valentina-danilova_1966@postgrespro.ru", "phone": "+70994495850"}
0005432839200	6CE23B	3378 179930	ANASTASIYA FOMINA	{"phone": "+70518148194"}
0005432839201	EE5681	3648 929759	TIMOFEY NIKITIN	{"email": "nikitint021969@postgrespro.ru", "phone": "+70701670002"}
0005432839202	1FDE87	3996 646533	NAZAR IVANOV	{"phone": "+70146635441"}
0005432839203	7120EF	7149 021427	GEORGIY TIKHONOV	{"email": "g_tikhonov081969@postgrespro.ru", "phone": "+70424236719"}
0005432839204	8DB0BD	9450 156981	ANASTASIYA FOMINA	{"phone": "+70282630276"}
0005432839205	8DB0BD	1164 900699	OLEG KUZNECOV	{"phone": "+70000664908"}
0005432839206	9A6F71	0785 673992	VLADISLAV TIKHONOV	{"phone": "+70034949327"}
0005432839207	84FE31	1376 960360	BORIS MAKAROV	{"email": "boris.makarov21111977@postgrespro.ru", "phone": "+70013823705"}
0005432839208	41AE10	5624 992456	ELENA ZHURAVLEVA	{"phone": "+70423752501"}
0005432839209	41AE10	1726 904350	TATYANA BORISOVA	{"email": "borisova_t101970@postgrespro.ru", "phone": "+70227278779"}
0005432839210	3D6762	7043 684541	DARYA ISAEVA	{"phone": "+70304816944"}
0005432839211	4C7941	5041 674189	ALEKSEY GUSEV	{"email": "aleksey_gusev011983@postgrespro.ru", "phone": "+70944275220"}
0005432839212	9F81FD	9688 448086	ANASTASIYA IVANOVA	{"email": "ivanova-a.1974@postgrespro.ru", "phone": "+70053315164"}
0005432839213	0F4D07	7993 459853	SEMEN DAVYDOV	{"email": "davydov.semen1982@postgrespro.ru", "phone": "+70950067851"}
0005432839214	20701B	6291 352225	LYUBOV ORLOVA	{"email": "lyubov_orlova.101974@postgrespro.ru", "phone": "+70384068532"}
0005432839215	72C142	4399 365500	VALENTINA KRASNOVA	{"phone": "+70566862997"}
0005432839216	3069F3	9992 955578	SVETLANA ALEKSEEVA	{"email": "s-alekseeva.12121979@postgrespro.ru", "phone": "+70549890317"}
0005432839217	3B171D	2574 893987	NINA ROMANOVA	{"phone": "+70208999686"}
0005432839218	6509A4	2657 960180	YULIYA RYABOVA	{"email": "yuliya.ryabova-121971@postgrespro.ru", "phone": "+70762000033"}
0005432839219	72919F	8855 369956	SVETLANA KAZAKOVA	{"email": "kazakova-svetlana-1968@postgrespro.ru", "phone": "+70671749121"}
0005432839220	72919F	3104 729819	VALERIY TIKHONOV	{"email": "tikhonov.valeriy_041972@postgrespro.ru", "phone": "+70836371586"}
0005432839221	6E11A7	4315 737659	NATALYA SCHERBAKOVA	{"email": "natalya_scherbakova_111973@postgrespro.ru", "phone": "+70854924656"}
0005432839222	6E11A7	4160 895367	YULIYA VOLKOVA	{"phone": "+70582170285"}
0005432839223	CDBE15	7805 813917	NIKOLAY IVANOV	{"phone": "+70550994800"}
0005432839224	844493	3654 557826	VIKTORIYA NOVIKOVA	{"phone": "+70158609436"}
0005432839225	EA75FD	6875 290686	ALEKSANDR NIKOLAEV	{"phone": "+70579080081"}
0005432839226	8288D3	6603 182266	TATYANA ZAKHAROVA	{"email": "t.zakharova1973@postgrespro.ru", "phone": "+70237693207"}
0005432839227	770419	8737 763039	ALBERT POPOV	{"phone": "+70017212510"}
0005432839228	770419	4615 723549	ARTEM MELNIKOV	{"phone": "+70873780313"}
0005432839229	21BD85	2551 746482	VASILIY GORBUNOV	{"email": "vasiliy_gorbunov-091962@postgrespro.ru", "phone": "+70664508274"}
0005432839230	9B2D2D	2685 338480	VIKTORIYA NIKOLAEVA	{"phone": "+70759902955"}
0005432839231	2B9525	3230 014797	NIKITA KUZNECOV	{"email": "n-kuznecov1981@postgrespro.ru", "phone": "+70224336180"}
0005432839232	2B9525	3672 425167	VERA KONOVALOVA	{"phone": "+70150510331"}
0005432839233	DA8468	8028 867284	GENNADIY MIRONOV	{"phone": "+70544434816"}
0005432839234	DA8468	5870 674526	IRINA SAVELEVA	{"phone": "+70550785315"}
0005432839235	532113	7909 262785	MIKHAIL MIRONOV	{"email": "mikhail-mironov.031971@postgrespro.ru", "phone": "+70878246519"}
0005432839236	51CEDF	3063 107522	LYUDMILA MIKHAYLOVA	{"email": "lyudmila_mikhaylova-10071962@postgrespro.ru", "phone": "+70756859969"}
0005432839237	51CEDF	6595 931082	VASILIY ZAKHAROV	{"email": "zakharov.v_1970@postgrespro.ru", "phone": "+70141371148"}
0005432839238	831A79	0658 290067	TATYANA KONOVALOVA	{"email": "konovalovatatyana.111977@postgrespro.ru", "phone": "+70987188013"}
0005432839239	D45724	0735 843664	OLGA KUZNECOVA	{"email": "o_kuznecova.06111976@postgrespro.ru", "phone": "+70180005315"}
0005432839240	350BDD	0992 944496	YULIYA KONOVALOVA	{"phone": "+70873636275"}
0005432839241	6234EC	1592 649733	NADEZHDA DAVYDOVA	{"email": "davydova_nadezhda-051970@postgrespro.ru", "phone": "+70305325131"}
0005432839242	6234EC	8052 778122	KONSTANTIN TARASOV	{"email": "konstantin_tarasov_16061973@postgrespro.ru", "phone": "+70271803692"}
0005432839243	62C216	1896 502882	ALEKSANDR BORISOV	{"email": "aborisov-15011979@postgrespro.ru", "phone": "+70342066028"}
0005432839244	62C216	6265 599995	TATYANA ILINA	{"phone": "+70792568115"}
0005432839245	FF574D	5943 938497	VERA ROMANOVA	{"phone": "+70281499847"}
0005432839246	B2C8FB	6866 363026	NIKOLAY MOROZOV	{"email": "morozov.n.091978@postgrespro.ru", "phone": "+70593475109"}
0005432839247	A4F4E4	9693 046023	TATYANA NIKITINA	{"email": "nikitina-t-1969@postgrespro.ru", "phone": "+70350249632"}
0005432839248	A4F4E4	5675 161409	INNA BARANOVA	{"email": "ibaranova-1979@postgrespro.ru", "phone": "+70447703039"}
0005432839249	46CAB1	0574 434133	VIKTOR TIMOFEEV	{"email": "timofeev.v111976@postgrespro.ru", "phone": "+70468572803"}
0005432839250	46CAB1	8355 547825	DANILA SCHERBAKOV	{"email": "dscherbakov-111982@postgrespro.ru", "phone": "+70985297536"}
0005432839251	93FC65	3944 967212	KIRILL ALEKSEEV	{"email": "alekseevk07041960@postgrespro.ru", "phone": "+70906025316"}
0005432839252	93FC65	0604 130956	ALEKSANDR SIDOROV	{"email": "sidorov.a.1971@postgrespro.ru", "phone": "+70438222100"}
0005432839253	5157D7	5025 802599	NATALYA BELOVA	{"phone": "+70761704918"}
0005432839254	759DED	6816 046091	NATALYA NAUMOVA	{"email": "natalya_naumova101975@postgrespro.ru", "phone": "+70136946630"}
0005432839255	653772	5783 482256	LILIYA KUZNECOVA	{"email": "l-kuznecova-1964@postgrespro.ru", "phone": "+70313594165"}
0005432839256	50D2A9	2659 599191	MARIYA DANILOVA	{"phone": "+70912744200"}
0005432839257	50D2A9	1424 880472	VALERIY FEDOTOV	{"email": "fedotov_v_061974@postgrespro.ru", "phone": "+70926619053"}
0005432839258	9A7F03	8013 862076	VALENTINA KUZMINA	{"phone": "+70632055244"}
0005432839259	9A7F03	1925 069690	EKATERINA ZHUKOVA	{"phone": "+70405038335"}
0005432839260	A56D34	2246 728917	ANNA YAKOVLEVA	{"phone": "+70781045086"}
0005432839261	76B016	0632 556301	NATALYA IVANOVA	{"email": "n.ivanova041975@postgrespro.ru", "phone": "+70265743156"}
0005432839262	76B016	6670 636776	MARIYA KUDRYASHOVA	{"email": "kudryashovamariya_1972@postgrespro.ru", "phone": "+70127336920"}
0005432839263	01D92B	3659 094103	TATYANA KOZLOVA	{"email": "kozlova_t-011979@postgrespro.ru", "phone": "+70032115433"}
0005432839264	01D92B	0131 432687	MIKHAIL GUSEV	{"phone": "+70765625708"}
0005432839265	064515	2665 949230	NATALYA ZHUKOVA	{"email": "zhukova.natalya-121970@postgrespro.ru", "phone": "+70904751923"}
0005432839266	05483D	1920 971786	VLADIMIR SOKOLOV	{"email": "vladimir.sokolov-1988@postgrespro.ru", "phone": "+70341266765"}
0005432839267	F2EE1F	2726 910119	YULIYA SEMENOVA	{"email": "semenova-yuliya-1964@postgrespro.ru", "phone": "+70642975670"}
0005432839268	F2EE1F	6035 825823	ARINA OSIPOVA	{"phone": "+70634153292"}
0005432839269	F2EE1F	7988 668979	VERA VOLKOVA	{"phone": "+70296258434"}
0005432839270	298B2E	1909 785724	OLGA DANILOVA	{"phone": "+70555593164"}
0005432839271	298B2E	5760 675860	ALEKSEY KOROLEV	{"phone": "+70073525439"}
0005432839272	D46DFB	0513 783667	DARYA VOROBEVA	{"phone": "+70760563241"}
0005432839273	D46DFB	4403 959767	ANDREY BORISOV	{"phone": "+70087775698"}
0005432839274	198EA2	3033 610415	SVETLANA NOVIKOVA	{"phone": "+70432639412"}
0005432839275	198EA2	3999 748598	VERA SAVELEVA	{"email": "saveleva.vera_011976@postgrespro.ru", "phone": "+70690612365"}
0005432839276	D047DA	3490 514391	VLADISLAV POPOV	{"phone": "+70257975553"}
0005432839277	D047DA	7890 502295	LYUDMILA GUSEVA	{"email": "lyudmila-guseva071970@postgrespro.ru", "phone": "+70756029848"}
0005432839278	A94B7D	8555 545172	FARIT KUZMIN	{"email": "fkuzmin.071978@postgrespro.ru", "phone": "+70625818830"}
0005432839279	02BFFD	1484 077258	KONSTANTIN ALEKSEEV	{"email": "alekseev-k-1960@postgrespro.ru", "phone": "+70288984090"}
0005432839280	CDA6E3	5697 946334	LILIYA IVANOVA	{"email": "ivanova-l.1961@postgrespro.ru", "phone": "+70097484678"}
0005432839281	CDA6E3	8802 051221	TATYANA IVANOVA	{"email": "t_ivanova_041965@postgrespro.ru", "phone": "+70902288090"}
0005432839282	CDA6E3	6012 976201	NATALIYA TROFIMOVA	{"phone": "+70785609181"}
0005432839283	751DCB	1870 008952	LIDIYA KUZNECOVA	{"phone": "+70122147117"}
0005432839284	F6CD05	2123 147099	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey-01101978@postgrespro.ru", "phone": "+70542774014"}
0005432839285	B55E5D	1671 193820	VALENTINA PAVLOVA	{"phone": "+70239124706"}
0005432839286	1D1B55	5919 926401	IRINA VASILEVA	{"phone": "+70345613180"}
0005432839287	8EC914	7081 792510	TATYANA TIKHONOVA	{"phone": "+70558854259"}
0005432839288	8EC914	4398 060491	NINA RODIONOVA	{"email": "nina-rodionova-091966@postgrespro.ru", "phone": "+70016309564"}
0005432839289	8EC914	5741 676309	ANNA ZAYCEVA	{"phone": "+70266132378"}
0005432839290	E042D1	4568 213014	VLADIMIR IVANOV	{"phone": "+70969076963"}
0005432839291	F2D4A0	9258 312468	VLADISLAV NOVIKOV	{"email": "vladislav-novikov_27081985@postgrespro.ru", "phone": "+70984549213"}
0005432839292	F2D4A0	1424 638480	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev_081963@postgrespro.ru", "phone": "+70739321820"}
0005432839293	23225D	1051 125731	OLEG STEPANOV	{"email": "o_stepanov.071977@postgrespro.ru", "phone": "+70193220635"}
0005432839294	4B31FD	0202 159110	ALEKSANDR BARANOV	{"phone": "+70016616872"}
0005432839295	0FFDAC	0047 069736	SERGEY ZAYCEV	{"phone": "+70414638224"}
0005432839296	F1292B	9627 289926	VALENTINA GUSEVA	{"phone": "+70754760939"}
0005432839297	F1292B	8834 327850	NADEZHDA DANILOVA	{"email": "nadezhda_danilova_1974@postgrespro.ru", "phone": "+70304430290"}
0005432839298	C32A83	8073 014682	GALINA BELOVA	{"phone": "+70882992442"}
0005432839299	BFE41E	1768 576584	MARIYA SMIRNOVA	{"phone": "+70358253159"}
0005432839300	BFE41E	6930 821391	ANTONINA MIKHAYLOVA	{"email": "mikhaylova_a12111976@postgrespro.ru", "phone": "+70193387010"}
0005432839301	1A37B1	1223 624609	ANDREY SIDOROV	{"phone": "+70876511246"}
0005432839302	1A37B1	7391 982063	VENERA DENISOVA	{"email": "venera_denisova.021958@postgrespro.ru", "phone": "+70646863083"}
0005432839303	18187D	6684 002153	VLADIMIR ALEKSANDROV	{"phone": "+70484537282"}
0005432839304	D49839	1526 175234	IGOR KARPOV	{"email": "karpovigor.061973@postgrespro.ru", "phone": "+70759079542"}
0005432839305	207881	7308 848378	ANDREY BELOV	{"phone": "+70347956294"}
0005432839306	9759A7	4606 274673	YURIY FILIPPOV	{"phone": "+70328000531"}
0005432839307	9759A7	0223 620824	SVETLANA BARANOVA	{"email": "baranova.s-21101974@postgrespro.ru", "phone": "+70983794403"}
0005432839308	626772	1102 524328	NAZAR KOZLOV	{"email": "n.kozlov.1959@postgrespro.ru", "phone": "+70528121573"}
0005432839309	626772	5049 376011	DARYA FILATOVA	{"phone": "+70352356894"}
0005432839310	A2486A	7108 676333	LILIYA VOLKOVA	{"phone": "+70683930178"}
0005432839311	A2486A	5771 590628	MARIYA FROLOVA	{"email": "m.frolova_041973@postgrespro.ru", "phone": "+70490437324"}
0005432839312	D6E204	7768 646277	DARINA ZAYCEVA	{"phone": "+70153386969"}
0005432839313	D074CB	2159 453893	VASILIY NAUMOV	{"email": "v_naumov-101970@postgrespro.ru", "phone": "+70247579312"}
0005432839314	E526B2	2720 708073	VALENTINA MALYSHEVA	{"email": "v_malysheva.091968@postgrespro.ru", "phone": "+70412569550"}
0005432839315	626BAE	2155 066192	ALEKSANDR BELOV	{"phone": "+70851834120"}
0005432839316	91F54D	7584 482884	ALEKSANDR ALEKSEEV	{"phone": "+70133195786"}
0005432839317	FA73A5	5775 970716	ANDREY KUZNECOV	{"email": "andrey_kuznecov-1966@postgrespro.ru", "phone": "+70462122248"}
0005432839318	C2BF8E	9780 276769	TIMOFEY NAUMOV	{"phone": "+70746362052"}
0005432839319	C2BF8E	9648 748203	LYUBOV VASILEVA	{"phone": "+70146750454"}
0005432839320	169554	9937 000537	EKATERINA NESTEROVA	{"phone": "+70772573702"}
0005432839321	169554	0935 903139	VALERIY BELOV	{"phone": "+70921231547"}
0005432839322	CFFC02	2336 264011	OLESYA MELNIKOVA	{"phone": "+70292574518"}
0005432839323	CFFC02	9300 393764	TATYANA STEPANOVA	{"phone": "+70407608809"}
0005432839324	C6EF60	5548 722693	MARINA KRASNOVA	{"email": "m_krasnova10101978@postgrespro.ru", "phone": "+70622512055"}
0005432839325	C6EF60	6381 805409	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.24031981@postgrespro.ru", "phone": "+70131767043"}
0005432839326	F3A3DF	6840 876413	NINA KUZNECOVA	{"email": "kuznecovanina-1963@postgrespro.ru", "phone": "+70720060648"}
0005432839327	67D579	9314 630419	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev.091973@postgrespro.ru", "phone": "+70055823367"}
0005432839328	0D62BF	3874 112466	VERONIKA POLYAKOVA	{"phone": "+70880384515"}
0005432839329	0D62BF	4945 548656	ALEKSANDRA SIDOROVA	{"phone": "+70421464484"}
0005432839330	34C466	6742 240980	NADEZHDA BARANOVA	{"phone": "+70950518050"}
0005432839331	A55C12	9682 496645	OKSANA ALEKSEEVA	{"phone": "+70236286587"}
0005432839332	DBC81F	4148 676778	ZAKHAR ROMANOV	{"email": "z_romanov081974@postgrespro.ru", "phone": "+70615094334"}
0005432839333	3843F5	4616 506549	BORIS AFANASEV	{"email": "afanasev_boris.22041971@postgrespro.ru", "phone": "+70882278168"}
0005432839334	C6D426	1678 095872	LYUDMILA SERGEEVA	{"email": "lyudmilasergeeva-25121973@postgrespro.ru", "phone": "+70681705097"}
0005432839335	C6D426	6241 545827	ALEKSANDR DMITRIEV	{"email": "aleksandrdmitriev_05011970@postgrespro.ru", "phone": "+70088263256"}
0005432839336	C6D426	7872 239877	GALINA ALEKSEEVA	{"phone": "+70072978894"}
0005432839337	8BC145	7981 038198	LYUBOV ANTONOVA	{"phone": "+70176341990"}
0005432839338	8BC145	3043 537433	NATALYA STEPANOVA	{"email": "n-stepanova121971@postgrespro.ru", "phone": "+70729094922"}
0005432839339	8BC145	8785 059771	ELENA BORISOVA	{"phone": "+70423816245"}
0005432839340	E79C46	0116 294380	EVGENIYA BORISOVA	{"email": "e.borisova1970@postgrespro.ru", "phone": "+70751023656"}
0005432839341	9AB364	6644 251760	VALERIY VOROBEV	{"phone": "+70870673374"}
0005432839342	9AB364	9986 608994	MAKSIM PAVLOV	{"phone": "+70903816885"}
0005432839343	BEBD92	0013 501418	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov.1974@postgrespro.ru", "phone": "+70328115919"}
0005432839344	7DB89D	1552 852356	ROMAN EGOROV	{"email": "regorov.111975@postgrespro.ru", "phone": "+70040515455"}
0005432839345	71C2B3	7051 382223	ELENA MAKAROVA	{"email": "makarovae_1983@postgrespro.ru", "phone": "+70382280223"}
0005432839346	71C2B3	1750 000249	RAISA FILATOVA	{"email": "rfilatova-1972@postgrespro.ru", "phone": "+70842474147"}
0005432839347	CAF671	7851 734866	GENNADIY OSIPOV	{"email": "gennadiy_osipov.1966@postgrespro.ru", "phone": "+70009200767"}
0005432839348	CAF671	1980 091301	ROMAN SAVELEV	{"phone": "+70993605205"}
0005432839349	45D06F	9670 830215	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova111969@postgrespro.ru", "phone": "+70052691638"}
0005432839350	6D728E	1570 815318	ALEKSANDR PAVLOV	{"email": "apavlov.111963@postgrespro.ru", "phone": "+70070292371"}
0005432839351	6D728E	5049 852204	ARTEM VOROBEV	{"phone": "+70882962448"}
0005432839352	8C522D	1317 229660	OLGA MASLOVA	{"email": "o_maslova.1970@postgrespro.ru", "phone": "+70206773697"}
0005432839353	8C522D	7706 329720	IGOR ABRAMOV	{"email": "igorabramov.26011977@postgrespro.ru", "phone": "+70476232772"}
0005432839354	76D742	8159 313972	VYACHESLAV MIKHAYLOV	{"phone": "+70474367519"}
0005432839355	483A54	2748 382135	TAMARA RODIONOVA	{"email": "tamara.rodionova.1984@postgrespro.ru", "phone": "+70783634751"}
0005432839356	FA6DA4	6093 472601	VLADIMIR AFANASEV	{"email": "vladimir-afanasev.31101967@postgrespro.ru", "phone": "+70670198078"}
0005432839357	46D20C	9153 289128	PAVEL NOVIKOV	{"email": "novikov.p_1965@postgrespro.ru", "phone": "+70010729463"}
0005432839358	07EBC5	7783 044308	OKSANA ANDREEVA	{"phone": "+70439157249"}
0005432839359	B85721	5236 375975	OLGA SCHERBAKOVA	{"phone": "+70600100799"}
0005432839360	B85721	5089 135970	TATYANA NIKITINA	{"email": "tnikitina-051973@postgrespro.ru", "phone": "+70825967810"}
0005432839361	F7FEF4	5803 530001	LEV FILIPPOV	{"phone": "+70181395905"}
0005432839362	AED7BF	4949 019003	ELENA NIKITINA	{"email": "elena.nikitina_27101966@postgrespro.ru", "phone": "+70425823321"}
0005432839363	954A8B	1470 469177	ELENA KUZNECOVA	{"email": "e-kuznecova.041978@postgrespro.ru", "phone": "+70322384745"}
0005432839364	954A8B	8117 964111	MIKHAIL GRIGOREV	{"email": "grigorev.mikhail.10051983@postgrespro.ru", "phone": "+70468601094"}
0005432839365	575D26	5414 201620	TATYANA OVCHINNIKOVA	{"email": "t-ovchinnikova-30081978@postgrespro.ru", "phone": "+70381271684"}
0005432839366	9C5C0D	8885 326478	PETR IVANOV	{"phone": "+70730361699"}
0005432839367	9C5C0D	1951 715258	VLADIMIR KISELEV	{"phone": "+70649231250"}
0005432839368	9C5C0D	7744 219083	VADIM ABRAMOV	{"email": "abramov_v08031973@postgrespro.ru", "phone": "+70367445643"}
0005432839369	BF112F	0903 060243	VLADIMIR POPOV	{"email": "popov-v-18031970@postgrespro.ru", "phone": "+70152695131"}
0005432839370	BF112F	6940 721265	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov_22071961@postgrespro.ru", "phone": "+70941449331"}
0005432839371	714C1E	1005 193269	ALEKSANDRA EGOROVA	{"email": "aleksandraegorova_1971@postgrespro.ru", "phone": "+70104223609"}
0005432839372	714C1E	3275 465604	PAVEL FOMIN	{"email": "p.fomin-12101973@postgrespro.ru", "phone": "+70772263431"}
0005432839373	B1E857	8094 120309	MARIYA VOROBEVA	{"phone": "+70016832368"}
0005432839374	B1E857	7872 196578	EKATERINA GUSEVA	{"email": "guseva-ekaterina_031971@postgrespro.ru", "phone": "+70370822145"}
0005432839375	B1E857	6853 565501	TAMARA MELNIKOVA	{"email": "t.melnikova11111972@postgrespro.ru", "phone": "+70376523538"}
0005432839376	4F10A5	7386 095867	MAKSIM ALEKSEEV	{"email": "maksim.alekseev-041967@postgrespro.ru", "phone": "+70731515345"}
0005432839377	A71244	3653 381738	TATYANA SEMENOVA	{"email": "t_semenova-1961@postgrespro.ru", "phone": "+70146536114"}
0005432839378	A71244	2639 268034	VLADIMIR ISAEV	{"phone": "+70145383703"}
0005432839379	2B171E	8132 716486	NATALYA STEPANOVA	{"email": "n_stepanova1971@postgrespro.ru", "phone": "+70066085299"}
0005432839380	2B171E	3530 178506	VASILIY GERASIMOV	{"email": "vasiliygerasimov091981@postgrespro.ru", "phone": "+70644345664"}
0005432839381	1920BC	1818 200502	YURIY MELNIKOV	{"phone": "+70222913148"}
0005432839382	2C9CB0	9167 402012	NIKOLAY MOROZOV	{"phone": "+70565074040"}
0005432839383	2C9CB0	6443 553404	NINA DANILOVA	{"phone": "+70900972880"}
0005432839384	44FF7D	1367 454910	EDUARD VASILEV	{"phone": "+70272984997"}
0005432839385	44FF7D	2615 246013	DMITRIY NIKOLAEV	{"phone": "+70321635233"}
0005432839386	44FF7D	9426 472667	ARTEM VASILEV	{"email": "artemvasilev1980@postgrespro.ru", "phone": "+70821508540"}
0005432839387	6A5C8B	9627 419675	ROZA MAKAROVA	{"email": "rmakarova.031965@postgrespro.ru", "phone": "+70796766577"}
0005432839388	83B562	4087 152077	GALINA ALEKSANDROVA	{"phone": "+70204436457"}
0005432839389	245B0D	1552 967505	SERGEY RODIONOV	{"phone": "+70081377432"}
0005432839390	8E6053	5601 639847	DANIIL NOVIKOV	{"email": "novikov-d03101970@postgrespro.ru", "phone": "+70620971653"}
0005432839391	8E6053	2191 705633	LIDIYA KONOVALOVA	{"email": "konovalova_lidiya1968@postgrespro.ru", "phone": "+70609781683"}
0005432839392	8E6053	8428 915780	DMITRIY NIKOLAEV	{"phone": "+70352330759"}
0005432839393	B3C42F	2457 496682	ALEKSANDR MOROZOV	{"phone": "+70077977767"}
0005432839394	B3C42F	6672 190549	OLGA SEMENOVA	{"phone": "+70161997901"}
0005432839395	89CE91	9908 722258	ZINAIDA SMIRNOVA	{"phone": "+70875187274"}
0005432839396	D2E0BA	7991 481761	DMITRIY KUDRYASHOV	{"phone": "+70237116113"}
0005432839397	549371	3697 638477	RUSLAN MATVEEV	{"email": "ruslan_matveev1964@postgrespro.ru", "phone": "+70147827282"}
0005432839398	7B4613	7671 401602	ALEKSANDRA KOVALEVA	{"phone": "+70407847321"}
0005432839399	63E4B3	1387 556682	ALEKSEY BONDARENKO	{"email": "a-bondarenko.22011967@postgrespro.ru", "phone": "+70609961023"}
0005432839400	63E4B3	7550 141007	MARINA DAVYDOVA	{"email": "mdavydova.1970@postgrespro.ru", "phone": "+70761672461"}
0005432839401	3B5371	8167 402759	VALENTINA NIKOLAEVA	{"email": "vnikolaeva_121981@postgrespro.ru", "phone": "+70263424355"}
0005432839402	CBD3CE	9714 795839	ZOYA EGOROVA	{"phone": "+70368576500"}
0005432839403	0B76F3	9728 354379	NINA SOLOVEVA	{"phone": "+70535991684"}
0005432839404	B775F7	9219 395146	ANTONINA ANISIMOVA	{"phone": "+70988185551"}
0005432839405	4A1E4D	9719 631422	ALEKSANDR BONDARENKO	{"phone": "+70653535184"}
0005432839406	4A1E4D	1988 367617	VALERIYA SOKOLOVA	{"phone": "+70396512706"}
0005432839407	1B62E9	7098 482079	VASILIY KULIKOV	{"email": "kulikov_v_111967@postgrespro.ru", "phone": "+70711981091"}
0005432839408	1B62E9	2994 607741	ANTONIDA ORLOVA	{"email": "orlova-a_22091966@postgrespro.ru", "phone": "+70543850283"}
0005432839409	B339DC	8937 517440	ANTON KUZNECOV	{"phone": "+70684748116"}
0005432839410	B339DC	4926 143012	IRINA PAVLOVA	{"email": "pavlova-irina01051967@postgrespro.ru", "phone": "+70792999925"}
0005432839411	CC5C3A	2648 442757	VALENTINA GAVRILOVA	{"phone": "+70484168701"}
0005432839412	D33A25	9670 550426	TAISIYA MIKHAYLOVA	{"phone": "+70502994664"}
0005432839413	2AE1A4	1822 474790	MARIYA AKIMOVA	{"email": "mariya.akimova.29111970@postgrespro.ru", "phone": "+70172966240"}
0005432839414	04C76C	6071 398570	VLADIMIR SIDOROV	{"phone": "+70758546517"}
0005432839415	E96CEF	4926 742653	SERGEY FOMIN	{"email": "fomin-s.1981@postgrespro.ru", "phone": "+70251601788"}
0005432839416	E96CEF	8980 924545	ELENA CHERNOVA	{"email": "chernova.elena.17021976@postgrespro.ru", "phone": "+70291402362"}
0005432839417	A0FB1B	9738 120875	ZHANNA NIKOLAEVA	{"email": "nikolaeva-z28111981@postgrespro.ru", "phone": "+70623097788"}
0005432839418	A0FB1B	8860 370081	ALEKSANDR MELNIKOV	{"email": "melnikova27071973@postgrespro.ru", "phone": "+70688980729"}
0005432839419	A49336	3557 354298	NIKITA FROLOV	{"email": "frolovnikita.041969@postgrespro.ru", "phone": "+70642621451"}
0005432839420	A49336	7062 759304	OLGA SEMENOVA	{"email": "olga_semenova.061977@postgrespro.ru", "phone": "+70875299861"}
0005432839421	A49336	6138 145910	NATALYA KOROLEVA	{"phone": "+70794131764"}
0005432839422	E27D7D	1631 839293	MIKHAIL KULIKOV	{"email": "m-kulikov01041971@postgrespro.ru", "phone": "+70435311816"}
0005432839423	E27D7D	4607 812548	ALENA GAVRILOVA	{"email": "alena_gavrilova-111968@postgrespro.ru", "phone": "+70643976326"}
0005432839424	2B9FC9	2613 505678	TATYANA FROLOVA	{"phone": "+70343855298"}
0005432839425	EB29E8	4906 549980	EVGENIY MEDVEDEV	{"phone": "+70235501951"}
0005432839426	D59B45	2494 363986	ROZA EGOROVA	{"phone": "+70616343513"}
0005432839427	E24F5C	2417 541856	DENIS ANDREEV	{"phone": "+70315167065"}
0005432839428	E24F5C	4387 515340	SERGEY PETROV	{"email": "s-petrov-011981@postgrespro.ru", "phone": "+70021047173"}
0005432839429	FCE215	0243 005702	VALENTINA FEDOROVA	{"phone": "+70072632955"}
0005432839430	FCE215	3438 872047	YANINA VASILEVA	{"email": "y-vasileva-11021975@postgrespro.ru", "phone": "+70187208041"}
0005432839431	D533E4	2283 366896	ROBERT IVANOV	{"phone": "+70275075836"}
0005432839432	E60015	7695 062997	SERGEY NAZAROV	{"phone": "+70026438168"}
0005432839433	037DE1	0174 659864	TATYANA POLYAKOVA	{"phone": "+70962103968"}
0005432839434	BF20F6	5401 381428	OKSANA KALININA	{"phone": "+70155193366"}
0005432839435	06CCB3	7678 543660	VERA FILATOVA	{"phone": "+70773222291"}
0005432839436	06CCB3	3661 772246	VLADIMIR KOROLEV	{"phone": "+70757413455"}
0005432839437	C54976	9663 987420	NADEZHDA ILINA	{"phone": "+70445924155"}
0005432839438	C54976	4976 775251	MARINA KUZNECOVA	{"phone": "+70391063740"}
0005432839439	DD5C17	9362 443115	OLGA KOLESNIKOVA	{"email": "kolesnikova-o-01091970@postgrespro.ru", "phone": "+70041973726"}
0005432839440	FA9320	5836 133495	NINA KULIKOVA	{"email": "kulikova-nina_1970@postgrespro.ru", "phone": "+70066651235"}
0005432839441	FA9320	7393 808216	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr_1969@postgrespro.ru", "phone": "+70879725862"}
0005432839442	FA9320	6615 069973	OLGA IVANOVA	{"email": "o_ivanova031968@postgrespro.ru", "phone": "+70489368949"}
0005432839443	F5312F	3085 635240	MARIYA FOMINA	{"email": "fominam1965@postgrespro.ru", "phone": "+70894726612"}
0005432839444	F5312F	3845 092474	OLGA ILINA	{"email": "ilina_olga_1956@postgrespro.ru", "phone": "+70433269993"}
0005432839445	26E33B	0148 582769	MIROSLAV ALEKSEEV	{"phone": "+70278973554"}
0005432839446	141C76	8813 675425	ANNA GERASIMOVA	{"phone": "+70242811290"}
0005432839447	77B09E	9564 850464	SVETLANA BARANOVA	{"phone": "+70841685803"}
0005432839448	77B09E	3969 716148	NADEZHDA ANTONOVA	{"phone": "+70707017178"}
0005432839449	D8B022	8159 777782	PAVEL ALEKSEEV	{"phone": "+70895229175"}
0005432839450	D8B022	0829 206475	VIKTOR GRIGOREV	{"phone": "+70984599208"}
0005432839451	263BC3	7828 362999	DIANA MALYSHEVA	{"email": "dianamalysheva.03011969@postgrespro.ru", "phone": "+70074776747"}
0005432839452	DD01E0	4699 556008	IVAN BARANOV	{"email": "ibaranov_27031965@postgrespro.ru", "phone": "+70737151100"}
0005432839453	5C4939	9246 966620	RENATA ILINA	{"email": "renata.ilina-081967@postgrespro.ru", "phone": "+70180830533"}
0005432839454	5C4939	3587 789739	ELENA MIKHAYLOVA	{"phone": "+70316158690"}
0005432839455	5C6EB0	6436 585401	DENIS GUSEV	{"phone": "+70468835552"}
0005432839456	5C6EB0	8247 949654	VALERIY MIKHAYLOV	{"email": "v_mikhaylov.121968@postgrespro.ru", "phone": "+70066014365"}
0005432839457	08CF2D	3473 508116	NADEZHDA BORISOVA	{"phone": "+70923205489"}
0005432839458	6438CE	5101 414793	NINA KOMAROVA	{"email": "komarova.nina031971@postgrespro.ru", "phone": "+70598003236"}
0005432839459	6438CE	2371 132342	VALENTINA SEMENOVA	{"phone": "+70421910331"}
0005432839460	2EF039	3708 912119	VLADIMIR POPOV	{"phone": "+70899461064"}
0005432839461	2EF039	4439 875846	OLEG SIDOROV	{"email": "sidorov_o_25081964@postgrespro.ru", "phone": "+70441097460"}
0005432839462	B38AA7	5545 538545	VLADIMIR ALEKSANDROV	{"phone": "+70913386815"}
0005432839463	270340	7720 552100	OLGA SAVELEVA	{"email": "osaveleva_061965@postgrespro.ru", "phone": "+70590142688"}
0005432839464	5B42F4	7047 159997	OLEG SEMENOV	{"phone": "+70358762645"}
0005432839465	5533D5	0528 152054	OLEG FEDOROV	{"email": "oleg.fedorov.1983@postgrespro.ru", "phone": "+70108062451"}
0005432839466	5533D5	2786 919833	ELENA KULIKOVA	{"email": "e.kulikova.121970@postgrespro.ru", "phone": "+70212647226"}
0005432839467	25AF99	9311 152570	VLADISLAV FOMIN	{"phone": "+70485721723"}
0005432839468	25AF99	7215 871586	ANNA SERGEEVA	{"phone": "+70416844687"}
0005432839469	9CD532	7058 782968	ANATOLIY KUDRYASHOV	{"email": "a.kudryashov-1965@postgrespro.ru", "phone": "+70283383686"}
0005432839470	9CD532	3907 602709	IVAN AFANASEV	{"email": "afanasev-i-08071973@postgrespro.ru", "phone": "+70386484599"}
0005432839471	9CD532	4314 268009	DMITRIY KUZMIN	{"phone": "+70368987271"}
0005432839472	F4B953	6896 969290	VALENTIN MAKSIMOV	{"email": "valentinmaksimov.24091973@postgrespro.ru", "phone": "+70367570662"}
0005432839473	B19A31	3019 542160	EVGENIY SMIRNOV	{"email": "evgeniysmirnov.17051971@postgrespro.ru", "phone": "+70851187657"}
0005432839474	11AC24	9577 050967	ALBINA BARANOVA	{"email": "baranova-a-041970@postgrespro.ru", "phone": "+70364372631"}
0005432839475	31250D	5491 637318	KONSTANTIN YAKOVLEV	{"email": "yakovlev.k-011972@postgrespro.ru", "phone": "+70339950475"}
0005432839476	31250D	3917 491000	LYUDMILA KUZNECOVA	{"phone": "+70539186377"}
0005432839477	B11197	6220 371400	NELLI OSIPOVA	{"email": "osipovanelli_081969@postgrespro.ru", "phone": "+70946928358"}
0005432839478	AB8ACC	7173 586865	VLADIMIR KOROLEV	{"email": "vkorolev-1980@postgrespro.ru", "phone": "+70630765765"}
0005432839479	AB8ACC	0818 071873	VIKTOR TARASOV	{"email": "v-tarasov_28021977@postgrespro.ru", "phone": "+70444619803"}
0005432839480	81F456	6785 709421	IRINA BELYAEVA	{"email": "i-belyaeva1979@postgrespro.ru", "phone": "+70093858639"}
0005432839481	E03BB5	5662 617643	VASILIY BELOV	{"email": "belovv.101977@postgrespro.ru", "phone": "+70921036750"}
0005432839482	7A9ADA	4527 045736	EGOR NIKOLAEV	{"email": "e_nikolaev-03091969@postgrespro.ru", "phone": "+70027981030"}
0005432839483	92D166	7326 055444	ALENA FEDOROVA	{"email": "alena.fedorova.1982@postgrespro.ru", "phone": "+70480819213"}
0005432839484	427DAA	1043 857855	VLADIMIR KRASNOV	{"phone": "+70407920282"}
0005432839485	427DAA	0299 202369	MIKHAIL SMIRNOV	{"email": "smirnov_mikhail_10081976@postgrespro.ru", "phone": "+70167456928"}
0005432839486	300C09	3272 823838	OLGA LUKYANOVA	{"phone": "+70169710888"}
0005432839487	3DDDBB	2076 879887	VLADIMIR BARANOV	{"phone": "+70362973649"}
0005432839488	3DDDBB	9432 372104	ELENA SCHERBAKOVA	{"phone": "+70395677375"}
0005432839489	C24682	8646 408955	SERGEY PETROV	{"phone": "+70089965733"}
0005432839490	B57342	0775 343737	ALINA VOLKOVA	{"phone": "+70135041152"}
0005432839491	7E888A	6992 628238	LIDIYA KOVALEVA	{"phone": "+70687074777"}
0005432839492	5BC4B0	1495 890428	MARIYA TIMOFEEVA	{"phone": "+70026813153"}
0005432839493	5BC4B0	4990 517549	ALEKSANDR MEDVEDEV	{"email": "medvedev_a1977@postgrespro.ru", "phone": "+70139903326"}
0005432839494	60395F	8105 735514	ELENA LEBEDEVA	{"email": "lebedevae-23051966@postgrespro.ru", "phone": "+70580498647"}
0005432839495	04BCE1	6179 528542	LEONID FROLOV	{"phone": "+70022233326"}
0005432839496	04BCE1	6558 591703	ANDREY RODIONOV	{"phone": "+70324010811"}
0005432839497	7D8E3E	7948 410307	IRINA PETROVA	{"email": "petrovai.031980@postgrespro.ru", "phone": "+70441690579"}
0005432839498	69BD54	3321 616407	SVETLANA EFIMOVA	{"email": "efimova_svetlana-1983@postgrespro.ru", "phone": "+70921437330"}
0005432839499	564054	8044 414630	VLADIMIR FROLOV	{"phone": "+70612394855"}
0005432839500	564054	1417 664676	KAMIL MIKHAYLOV	{"email": "mikhaylov.k_20101975@postgrespro.ru", "phone": "+70481150423"}
0005432839501	2E8D2F	0410 395480	NATALYA FADEEVA	{"email": "natalya-fadeeva.1966@postgrespro.ru", "phone": "+70682112178"}
0005432839502	2E8D2F	4479 151079	VLADISLAV AFANASEV	{"email": "afanasev.vladislav.121962@postgrespro.ru", "phone": "+70569995901"}
0005432839503	DD885A	8949 276744	MARIYA MIKHAYLOVA	{"phone": "+70796028282"}
0005432839504	57485D	6656 544064	GALINA ANISIMOVA	{"email": "anisimova.galina-1967@postgrespro.ru", "phone": "+70548339957"}
0005432839505	57485D	4596 883474	MAKSIM MAKAROV	{"email": "makarov_maksim011971@postgrespro.ru", "phone": "+70234787682"}
0005432839506	1A77D1	0659 545314	ARTEM GRIGOREV	{"phone": "+70877804443"}
0005432839507	33E237	2156 590828	DMITRIY ALEKSEEV	{"email": "alekseev_d.10031970@postgrespro.ru", "phone": "+70999150106"}
0005432839508	33E237	3275 832040	MARIYA BORISOVA	{"email": "borisova-m031984@postgrespro.ru", "phone": "+70054437295"}
0005432839509	33E237	5223 370200	DMITRIY NIKITIN	{"phone": "+70156219485"}
0005432839510	63F41C	6154 234021	LYUDMILA EFREMOVA	{"phone": "+70745778445"}
0005432839511	F5AEA5	8340 740536	NIKOLAY BONDARENKO	{"email": "bondarenkonikolay1972@postgrespro.ru", "phone": "+70282078753"}
0005432839512	F36ADB	2836 698334	TATYANA MOROZOVA	{"phone": "+70690210146"}
0005432839513	B27EC7	2827 414377	SABINA FEDOROVA	{"phone": "+70296191624"}
0005432839514	B27EC7	0495 313492	IGOR FILIPPOV	{"phone": "+70161310881"}
0005432839515	73CF60	0876 499519	ALENA MALYSHEVA	{"phone": "+70218421143"}
0005432839516	73CF60	9986 771456	SERGEY DAVYDOV	{"phone": "+70481494690"}
0005432839517	73CF60	7172 201283	EVGENIY MIKHAYLOV	{"phone": "+70157035843"}
0005432839518	E4A06B	1103 821389	DANIIL KONOVALOV	{"phone": "+70466473770"}
0005432839519	E4A06B	0977 023841	RUSLAN GERASIMOV	{"email": "ruslan-gerasimov011971@postgrespro.ru", "phone": "+70766810707"}
0005432839520	49574C	6247 295864	ALEKSANDR BELOV	{"email": "belov_a-20061969@postgrespro.ru", "phone": "+70332266855"}
0005432839521	C2C56E	7561 075809	YURIY ALEKSANDROV	{"email": "aleksandrov.y.20031966@postgrespro.ru", "phone": "+70972346244"}
0005432839522	B8F15C	9292 490480	NATALYA BORISOVA	{"phone": "+70861208397"}
0005432839523	B8F15C	3181 529052	OKSANA KOROLEVA	{"phone": "+70757264861"}
0005432839524	B7AF77	2947 560944	ALENA ZAYCEVA	{"email": "zayceva_a_1963@postgrespro.ru", "phone": "+70693988266"}
0005432839525	B7AF77	4809 253021	NIKOLAY ZHUKOV	{"phone": "+70089288289"}
0005432839526	A25057	0397 532566	ANTON ZAYCEV	{"phone": "+70095525722"}
0005432839527	ADDBA7	5426 428068	ELENA KOZLOVA	{"email": "ekozlova22101964@postgrespro.ru", "phone": "+70392637337"}
0005432839528	ADDBA7	2307 617928	ELENA OVCHINNIKOVA	{"email": "e_ovchinnikova.1985@postgrespro.ru", "phone": "+70088313855"}
0005432839529	ADDBA7	1014 572891	MIKHAIL MARTYNOV	{"email": "mikhailmartynov.1970@postgrespro.ru", "phone": "+70404797408"}
0005432839530	EEB616	1834 121408	ALEKSANDR DMITRIEV	{"phone": "+70468564747"}
0005432839531	33C3F3	0608 496275	DARYA SOKOLOVA	{"email": "sokolova-d_1985@postgrespro.ru", "phone": "+70482349407"}
0005432839532	33C3F3	7935 732922	NATALYA NOVIKOVA	{"phone": "+70888776174"}
0005432839533	37212C	7197 986161	VALERIY KULIKOV	{"phone": "+70970458171"}
0005432839534	775527	5602 394737	VALERIY IVANOV	{"phone": "+70179206607"}
0005432839535	775527	6743 523976	ALINA SEMENOVA	{"email": "alina.semenova-30081982@postgrespro.ru", "phone": "+70730216891"}
0005432839536	B35CDE	5711 976730	TATYANA ZOTOVA	{"phone": "+70443083590"}
0005432839537	39E268	5644 294696	STANISLAV NOVIKOV	{"phone": "+70181018638"}
0005432839538	34B498	2666 964046	FAINA SIDOROVA	{"phone": "+70015141133"}
0005432839539	34B498	5309 447956	VIKTOR AFANASEV	{"phone": "+70879430888"}
0005432839540	A9B1F1	6718 586701	LIDIYA KAZAKOVA	{"phone": "+70553368540"}
0005432839541	A9B1F1	5259 015924	IRINA SMIRNOVA	{"email": "smirnovai111965@postgrespro.ru", "phone": "+70518821166"}
0005432839542	99E4C7	0850 769407	NIKOLAY POPOV	{"phone": "+70577005188"}
0005432839543	1EFCEB	0080 387652	ELIZAVETA PETROVA	{"email": "petrovaelizaveta-121971@postgrespro.ru", "phone": "+70238553657"}
0005432839544	040C69	3740 709507	VADIM ALEKSEEV	{"phone": "+70759815196"}
0005432839545	184443	3789 726920	LYUBOV MASLOVA	{"phone": "+70378657897"}
0005432839546	184443	2729 035229	DARYA VOLKOVA	{"email": "daryavolkova_21041968@postgrespro.ru", "phone": "+70341688500"}
0005432839547	8183B1	7892 465645	NATALYA TIKHONOVA	{"phone": "+70598578289"}
0005432839548	D00200	7899 873365	YURIY DMITRIEV	{"phone": "+70818277655"}
0005432839549	0E10B0	8298 094180	OLGA SCHERBAKOVA	{"email": "scherbakova-olga.29071975@postgrespro.ru", "phone": "+70292445641"}
0005432839550	135284	5814 021468	OLGA EFIMOVA	{"email": "o-efimova13071977@postgrespro.ru", "phone": "+70493884340"}
0005432839551	B4DC74	4087 052687	KSENIYA GAVRILOVA	{"email": "kseniya_gavrilova_23111975@postgrespro.ru", "phone": "+70420123982"}
0005432839552	F199D8	0567 037598	ALEVTINA EFIMOVA	{"email": "alevtina_efimova-101974@postgrespro.ru", "phone": "+70199345800"}
0005432839553	F199D8	8219 667390	VLADIMIR SEMENOV	{"phone": "+70871469473"}
0005432839554	DD9248	3949 434079	MAKSIM PETROV	{"email": "m_petrov_1965@postgrespro.ru", "phone": "+70250331040"}
0005432839555	DD9248	8570 961145	ALEVTINA YAKOVLEVA	{"email": "yakovleva_alevtina_021963@postgrespro.ru", "phone": "+70094904680"}
0005432839556	51E160	3811 267108	RUSLAN TIKHONOV	{"email": "r-tikhonov.021981@postgrespro.ru", "phone": "+70873699033"}
0005432839557	E43B57	7399 003582	EVGENIY GAVRILOV	{"email": "gavrilov.evgeniy041972@postgrespro.ru", "phone": "+70146274282"}
0005432839558	29DE16	3632 801884	ELENA IVANOVA	{"email": "ivanova_elena26021967@postgrespro.ru", "phone": "+70427757281"}
0005432839559	29DE16	8444 456114	LARISA ZAKHAROVA	{"email": "zakharoval.1976@postgrespro.ru", "phone": "+70869740596"}
0005432839560	29DE16	8479 528619	ANTON MOISEEV	{"phone": "+70485234190"}
0005432839561	7D7AAB	0719 247223	ELENA KONOVALOVA	{"phone": "+70009188033"}
0005432839562	7D7AAB	5231 409525	NINA KOROLEVA	{"phone": "+70782573066"}
0005432839563	6BCA56	1924 369638	TATYANA PETROVA	{"phone": "+70432966166"}
0005432839564	70443E	5683 416150	MIKHAIL DENISOV	{"email": "denisov-m081965@postgrespro.ru", "phone": "+70655615159"}
0005432839565	8C1FDE	4075 600590	SERGEY GERASIMOV	{"phone": "+70292610451"}
0005432839566	C97DD1	6941 959643	VIKTOR OSIPOV	{"email": "v-osipov_1977@postgrespro.ru", "phone": "+70216969356"}
0005432839567	6C172E	0692 054629	OLESYA ALEKSANDROVA	{"phone": "+70859561493"}
0005432839568	EE1D12	2646 295689	ANDREY SEMENOV	{"email": "semenov.andrey1971@postgrespro.ru", "phone": "+70881125537"}
0005432839569	EE1D12	0688 507404	ALEKSANDR STEPANOV	{"phone": "+70176214271"}
0005432839570	CDD310	8780 799301	ANATOLIY ANTONOV	{"email": "antonova_091962@postgrespro.ru", "phone": "+70947298485"}
0005432839571	CDD310	7870 929495	RENAT IVANOV	{"phone": "+70109317357"}
0005432839572	1B3769	9692 920217	EKATERINA ALEKSEEVA	{"email": "alekseeva_ekaterina-02101962@postgrespro.ru", "phone": "+70228342320"}
0005432839573	C9D22F	6895 313975	IRINA NIKOLAEVA	{"phone": "+70334237854"}
0005432839574	7B5CEF	4443 745760	NINA SAVELEVA	{"email": "ninasaveleva-1970@postgrespro.ru", "phone": "+70258883812"}
0005432839575	7B5CEF	5780 778846	IVAN SMIRNOV	{"phone": "+70426905460"}
0005432839576	7B5CEF	8461 630651	DANILA DENISOV	{"email": "denisov_d-1968@postgrespro.ru", "phone": "+70247520147"}
0005432839577	206B1E	1149 257680	ALEKSEY MOROZOV	{"email": "morozov-aleksey_1974@postgrespro.ru", "phone": "+70491729835"}
0005432839578	F8C088	5968 857326	MIKHAIL VASILEV	{"phone": "+70017042847"}
0005432839579	F8C088	3679 453212	ELENA NIKITINA	{"email": "e.nikitina-10111967@postgrespro.ru", "phone": "+70843818545"}
0005432839580	98F6CF	9426 972943	BORIS KUZNECOV	{"phone": "+70269424007"}
0005432839581	9920CF	3764 619114	OLGA NAZAROVA	{"email": "nazarova.olga03021972@postgrespro.ru", "phone": "+70235285383"}
0005432839582	6C163A	0570 907507	VERONIKA YAKOVLEVA	{"email": "v-yakovleva-31081960@postgrespro.ru", "phone": "+70100510348"}
0005432839583	12A70E	9495 315879	SOFYA IVANOVA	{"email": "ivanovas19061974@postgrespro.ru", "phone": "+70158729081"}
0005432839584	11319E	7309 083200	KONSTANTIN SMIRNOV	{"email": "konstantin.smirnov-1971@postgrespro.ru", "phone": "+70022490001"}
0005432839585	01B3DB	8422 065917	MARINA NAZAROVA	{"email": "nazarovamarina-25051968@postgrespro.ru", "phone": "+70202902254"}
0005432839586	DDC276	8482 333165	ANTON SEMENOV	{"phone": "+70178901809"}
0005432839587	5248DA	7279 450578	SERGEY ZAYCEV	{"email": "s-zaycev_011968@postgrespro.ru", "phone": "+70163393780"}
0005432839588	64E9E5	4937 942176	MIKHAIL KULIKOV	{"phone": "+70052137028"}
0005432839589	64E9E5	3230 596906	SERGEY SIDOROV	{"phone": "+70076589594"}
0005432839590	E80A46	7219 219048	OLGA POLYAKOVA	{"phone": "+70803232578"}
0005432839591	C998E8	7489 028152	SVETLANA POPOVA	{"email": "popovasvetlana_21071969@postgrespro.ru", "phone": "+70107572646"}
0005432839592	F7C944	1598 018953	YURIY KULIKOV	{"email": "kulikovy07121990@postgrespro.ru", "phone": "+70907366937"}
0005432839593	F7C944	4501 951667	ALSU ROMANOVA	{"email": "a.romanova.1963@postgrespro.ru", "phone": "+70201429500"}
0005432839594	A9AB5D	4388 231105	DMITRIY MOROZOV	{"email": "morozov.d.1972@postgrespro.ru", "phone": "+70075315593"}
0005432839595	D11BB2	7958 370969	NADEZHDA SERGEEVA	{"email": "nadezhda_sergeeva-041972@postgrespro.ru", "phone": "+70926269305"}
0005432839596	D33DDC	2630 934772	NIKITA ANDREEV	{"email": "nikita_andreev-1972@postgrespro.ru", "phone": "+70492794441"}
0005432839597	D33DDC	2997 723411	SVETLANA STEPANOVA	{"phone": "+70926036932"}
0005432839598	D33DDC	8896 566250	VIKTOR SMIRNOV	{"email": "smirnov_v_20111974@postgrespro.ru", "phone": "+70832969535"}
0005432839599	C5C332	0422 669007	VYACHESLAV KAZAKOV	{"email": "kazakovv1972@postgrespro.ru", "phone": "+70995770499"}
0005432839600	30D09D	3658 646895	IRINA MALYSHEVA	{"email": "i_malysheva-061972@postgrespro.ru", "phone": "+70754878497"}
0005432839601	B289EC	9390 914024	VLADIMIR ABRAMOV	{"phone": "+70408016535"}
0005432839602	075D2A	7134 702880	VALENTINA MASLOVA	{"phone": "+70638305884"}
0005432839603	77E022	1138 546316	DARYA KARPOVA	{"email": "karpova_darya.29111980@postgrespro.ru", "phone": "+70051387747"}
0005432839604	6F504B	9416 023223	KONSTANTIN EGOROV	{"email": "konstantinegorov-121980@postgrespro.ru", "phone": "+70950555435"}
0005432839605	B48CCD	0605 975962	IRINA YAKOVLEVA	{"email": "irina_yakovleva.1974@postgrespro.ru", "phone": "+70317701500"}
0005432839606	B48CCD	7779 234579	ILYA VLASOV	{"phone": "+70518551424"}
0005432839607	BAB370	0450 610773	VERA IVANOVA	{"email": "ivanova_v.081971@postgrespro.ru", "phone": "+70630704745"}
0005432839608	BAB370	3568 383818	ALEKSEY KOROLEV	{"phone": "+70242424891"}
0005432839609	42F891	6387 471291	IVAN ISAEV	{"phone": "+70140712229"}
0005432839610	53B127	2423 300986	IRINA KUZMINA	{"phone": "+70927200754"}
0005432839611	53B127	4192 984380	NATALYA NESTEROVA	{"phone": "+70620579529"}
0005432839612	875262	6948 410823	VLADISLAV FEDOROV	{"email": "fedorovvladislav_041972@postgrespro.ru", "phone": "+70773244164"}
0005432839613	591A2C	0028 621302	ROMAN DAVYDOV	{"phone": "+70563638497"}
0005432839614	7DB061	2608 568533	MIKHAIL MELNIKOV	{"email": "melnikov_mikhail.101966@postgrespro.ru", "phone": "+70508495258"}
0005432839615	6C6D50	2931 579176	NADEZHDA VLASOVA	{"email": "nadezhda-vlasova_101975@postgrespro.ru", "phone": "+70957986435"}
0005432839616	6C6D50	3418 480678	PETR KOZLOV	{"phone": "+70594123711"}
0005432839617	9ACF5C	9896 393294	ELENA OVCHINNIKOVA	{"phone": "+70991783911"}
0005432839618	FA6458	5725 539187	LYUDMILA POPOVA	{"phone": "+70998534076"}
0005432839619	F3B29B	7894 703805	DMITRIY DAVYDOV	{"phone": "+70362261705"}
0005432839620	A4DA29	2317 837735	ALEKSEY SCHERBAKOV	{"phone": "+70847196433"}
0005432839621	296ECB	7894 861540	ANATOLIY GAVRILOV	{"phone": "+70549670482"}
0005432839622	E72A7A	5459 638504	ALEKSEY FOMIN	{"email": "afomin1966@postgrespro.ru", "phone": "+70514106064"}
0005432839623	E72A7A	9579 275524	ALEKSANDR SERGEEV	{"email": "a_sergeev041973@postgrespro.ru", "phone": "+70026782451"}
0005432839624	727267	5815 452984	EKATERINA SIDOROVA	{"email": "ekaterina.sidorova05021965@postgrespro.ru", "phone": "+70461923328"}
0005432839625	056664	4234 772544	EVGENIYA FOMINA	{"phone": "+70992501319"}
0005432839626	C939F7	3441 655662	VYACHESLAV IVANOV	{"phone": "+70451656370"}
0005432839627	3F0BB3	1275 858731	YURIY ROMANOV	{"email": "yuriyromanov031967@postgrespro.ru", "phone": "+70979264665"}
0005432839628	DA3D76	1126 336104	OKSANA BELYAEVA	{"email": "oksana-belyaeva-16111971@postgrespro.ru", "phone": "+70532027100"}
0005432839629	1EB983	7306 272631	ILYA PAVLOV	{"email": "pavlov-i.19041972@postgrespro.ru", "phone": "+70141709506"}
0005432839630	106988	8248 354214	ARTEM SOKOLOV	{"phone": "+70843516525"}
0005432839631	106988	5609 011451	MARAT MIRONOV	{"email": "mironovm_1977@postgrespro.ru", "phone": "+70206346768"}
0005432839632	E02419	2659 461207	ANASTASIYA MATVEEVA	{"phone": "+70815521203"}
0005432839633	425AF5	6894 463994	MARIYA STEPANOVA	{"email": "stepanova-m-25101973@postgrespro.ru", "phone": "+70581964496"}
0005432839634	287D00	6986 978697	ALEKSANDRA ORLOVA	{"phone": "+70666788613"}
0005432839635	96D011	5788 928473	ARSENIY IVANOV	{"email": "ivanov_arseniy1976@postgrespro.ru", "phone": "+70261846186"}
0005432839636	C436A9	3359 741315	MARIYA ALEKSEEVA	{"phone": "+70630131731"}
0005432839637	1DDFF4	6323 405836	OLEG TARASOV	{"email": "tarasov_oleg_26121980@postgrespro.ru", "phone": "+70445818484"}
0005432839638	14A836	9545 175770	NATALYA KONDRATEVA	{"email": "kondrateva_n_1959@postgrespro.ru", "phone": "+70887185224"}
0005432839639	3B116D	4437 979387	EVGENIY MAKAROV	{"email": "emakarov_1970@postgrespro.ru", "phone": "+70340004659"}
0005432839640	65590D	9858 784056	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov1967@postgrespro.ru", "phone": "+70827835498"}
0005432839641	FEDCF4	6041 166317	DMITRIY FEDOROV	{"phone": "+70760814064"}
0005432839642	A9F1BA	8147 746502	ALSU POPOVA	{"email": "a.popova111982@postgrespro.ru", "phone": "+70478441231"}
0005432839643	3D3685	9220 606304	RAMIL STEPANOV	{"phone": "+70848247969"}
0005432839644	3D3685	7762 717426	PETR ZAYCEV	{"phone": "+70693661555"}
0005432839645	4F1B24	6754 378451	ANNA KUZNECOVA	{"phone": "+70921099128"}
0005432839646	147C8D	0565 559918	OLEG GRIGOREV	{"phone": "+70631853293"}
0005432839647	B927F4	6238 466880	RIMMA ALEKSANDROVA	{"phone": "+70697555490"}
0005432839648	E3D154	7851 288071	VASILIY SMIRNOV	{"email": "vasiliy-smirnov28071986@postgrespro.ru", "phone": "+70611945821"}
0005432839649	1452FE	7506 462171	GLEB STEPANOV	{"email": "stepanov_g101964@postgrespro.ru", "phone": "+70305630195"}
0005432839650	1452FE	4245 700485	MIKHAIL VLASOV	{"email": "m-vlasov.1982@postgrespro.ru", "phone": "+70122436752"}
0005432839651	F82D5C	0195 676554	OLGA SIDOROVA	{"phone": "+70056212270"}
0005432839652	BD45DE	4362 853718	NATALYA PETROVA	{"email": "natalya.petrova_1968@postgrespro.ru", "phone": "+70925752174"}
0005432839653	37F35D	8347 981111	ALBINA LEBEDEVA	{"phone": "+70961199088"}
0005432839654	4C7374	5205 202952	ALEKSEY KUZNECOV	{"email": "kuznecova.011972@postgrespro.ru", "phone": "+70766470634"}
0005432839655	4C7374	2649 739116	VERA POPOVA	{"email": "popova_vera1975@postgrespro.ru", "phone": "+70338829615"}
0005432839656	4C7374	1509 301021	ALEKSEY SOROKIN	{"email": "aleksey_sorokin.081980@postgrespro.ru", "phone": "+70784896665"}
0005432839657	4C7374	4816 679307	NADEZHDA SOKOLOVA	{"phone": "+70417599036"}
0005432839658	317CBF	2486 716794	EKATERINA OSIPOVA	{"email": "osipovae-031969@postgrespro.ru", "phone": "+70883744313"}
0005432839659	7CD64F	9860 833057	VLADIMIR KUZMIN	{"phone": "+70349893602"}
0005432839660	7CD64F	0845 873089	EVDOKIYA POPOVA	{"email": "popova-e-101970@postgrespro.ru", "phone": "+70675002438"}
0005432839661	7CD64F	0153 420701	MARAT BELOV	{"email": "m_belov-1968@postgrespro.ru", "phone": "+70763446449"}
0005432839662	DB4CA1	8415 853068	NIKOLAY TIKHONOV	{"phone": "+70763440796"}
0005432839663	118838	7696 412067	VITALIY KISELEV	{"phone": "+70447061902"}
0005432839664	04589D	3611 290435	OKSANA SOKOLOVA	{"email": "sokolova-o-22081972@postgrespro.ru", "phone": "+70209492064"}
0005432839665	FA0A20	8275 990664	STANISLAV ANTONOV	{"email": "antonov.s.12081970@postgrespro.ru", "phone": "+70019446723"}
0005432839666	3453BF	2649 873432	GALINA IVANOVA	{"email": "ivanova-galina.1977@postgrespro.ru", "phone": "+70239861948"}
0005432839667	3453BF	5914 754523	INNA SIDOROVA	{"email": "sidorova_inna_05121964@postgrespro.ru", "phone": "+70322577036"}
0005432839668	B6A459	8336 178669	ANNA KUZNECOVA	{"email": "kuznecova.a_101978@postgrespro.ru", "phone": "+70237927385"}
0005432839669	B6A459	1470 088510	ALEKSANDR PETROV	{"email": "petrovaleksandr-15061969@postgrespro.ru", "phone": "+70493155059"}
0005432839670	CE1D82	9445 451187	EVGENIY MEDVEDEV	{"phone": "+70617841304"}
0005432839671	CE1D82	5457 118651	EVGENIY MOISEEV	{"phone": "+70804306963"}
0005432839672	16BD90	1555 556537	EGOR MAKAROV	{"email": "egor_makarov1978@postgrespro.ru", "phone": "+70930553847"}
0005432839673	2B20AE	4328 393498	OLGA ABRAMOVA	{"phone": "+70585907608"}
0005432839674	23C92B	5039 002076	SHAMIL KULIKOV	{"email": "s-kulikov_26111979@postgrespro.ru", "phone": "+70146614783"}
0005432839675	064DDF	1581 294577	ELENA BORISOVA	{"email": "e-borisova.1991@postgrespro.ru", "phone": "+70856653890"}
0005432839676	064DDF	0912 289288	NATALYA KRASNOVA	{"email": "krasnova-natalya-1973@postgrespro.ru", "phone": "+70789455901"}
0005432839677	9DB739	7196 340351	ZOYA GORBUNOVA	{"email": "z_gorbunova.30071981@postgrespro.ru", "phone": "+70822594914"}
0005432839678	DE3DA5	4175 390867	EKATERINA KOVALEVA	{"phone": "+70445921091"}
0005432839679	499A5C	2189 614351	OKSANA MIKHAYLOVA	{"email": "mikhaylovaoksana_16071980@postgrespro.ru", "phone": "+70456343849"}
0005432839739	D1E765	6119 278225	VITALIY BONDARENKO	{"phone": "+70056740489"}
0005432839680	499A5C	1790 416353	ANASTASIYA ZAKHAROVA	{"email": "anastasiyazakharova_1979@postgrespro.ru", "phone": "+70914827509"}
0005432839681	D2B038	3047 406509	ELIZAVETA ROMANOVA	{"phone": "+70673886531"}
0005432839682	57395F	6608 039045	LYUBOV MOROZOVA	{"phone": "+70551956781"}
0005432839683	A3DE03	6432 201816	ALEKSANDR NIKITIN	{"phone": "+70401871747"}
0005432839684	38B56A	3154 301685	ANDREY POPOV	{"email": "a.popov1976@postgrespro.ru", "phone": "+70268700167"}
0005432839685	FD7962	4799 310043	ANNA FILIPPOVA	{"email": "filippovaa-01051972@postgrespro.ru", "phone": "+70626062547"}
0005432839686	2FBD0A	0317 381251	LIDIYA GRISHINA	{"phone": "+70065902136"}
0005432839687	E802CC	3785 900736	VLADIMIR IVANOV	{"email": "vladimirivanov-11081969@postgrespro.ru", "phone": "+70646362843"}
0005432839688	A892D5	7120 631404	ILDAR BONDARENKO	{"email": "bondarenko.i-041973@postgrespro.ru", "phone": "+70474856066"}
0005432839689	DAB078	9519 515778	ELENA GAVRILOVA	{"phone": "+70135263183"}
0005432839690	DAB078	0612 350264	ALEKSANDR BORISOV	{"email": "borisov-a_16021968@postgrespro.ru", "phone": "+70792035176"}
0005432839691	6922F0	2160 408808	TATYANA STEPANOVA	{"email": "stepanova.tatyana.051965@postgrespro.ru", "phone": "+70232266283"}
0005432839692	B9E08E	6934 141797	FANIYA MIRONOVA	{"email": "mironova_f.1976@postgrespro.ru", "phone": "+70088091623"}
0005432839693	AA7E82	3866 780448	VALERIY VASILEV	{"email": "valeriyvasilev-1974@postgrespro.ru", "phone": "+70234862201"}
0005432839694	33A38B	1441 272458	YURIY KOROLEV	{"phone": "+70597966732"}
0005432839695	7A3BC8	2381 509990	DMITRIY KUDRYASHOV	{"email": "dmitriy.kudryashov11021977@postgrespro.ru", "phone": "+70024683075"}
0005432839696	209980	4099 727513	TATYANA NIKOLAEVA	{"email": "nikolaeva_tatyana.27011964@postgrespro.ru", "phone": "+70931568846"}
0005432839697	209980	3480 643043	ALEVTINA ZAKHAROVA	{"email": "zakharovaalevtina_081968@postgrespro.ru", "phone": "+70783056883"}
0005432839698	DDB3B3	4128 231971	EVGENIY KUZMIN	{"phone": "+70939468018"}
0005432839699	456906	2488 453027	SERGEY MATVEEV	{"email": "smatveev071975@postgrespro.ru", "phone": "+70611707612"}
0005432839700	CCA8CC	1202 109266	EVGENIY MIRONOV	{"phone": "+70332591203"}
0005432839701	CCA8CC	3896 172569	GENNADIY ABRAMOV	{"email": "g.abramov-051962@postgrespro.ru", "phone": "+70373631863"}
0005432839702	D690DC	3173 376958	TATYANA SCHERBAKOVA	{"email": "scherbakovat_03061968@postgrespro.ru", "phone": "+70819159572"}
0005432839703	CA4521	1907 523457	DENIS ZAKHAROV	{"phone": "+70136212775"}
0005432839704	BC3FB3	2888 863497	VLADIMIR POPOV	{"email": "popov.v-09051966@postgrespro.ru", "phone": "+70821336402"}
0005432839705	BC3FB3	9548 454649	PETR TIKHONOV	{"email": "tikhonov-petr.1987@postgrespro.ru", "phone": "+70596639780"}
0005432839706	C03CBE	5950 380911	LILIYA FROLOVA	{"phone": "+70304095475"}
0005432839707	EBC096	7012 644333	MAKSIM ZHUKOV	{"email": "zhukov.m-091974@postgrespro.ru", "phone": "+70986995319"}
0005432839708	BA505E	1832 061868	NATALYA ARKHIPOVA	{"email": "narkhipova.091961@postgrespro.ru", "phone": "+70339561315"}
0005432839709	AF39D7	4088 080668	OLGA KUZMINA	{"phone": "+70378181211"}
0005432839710	C0A0CE	8371 532761	EKATERINA IVANOVA	{"email": "ivanovaekaterina101973@postgrespro.ru", "phone": "+70119101758"}
0005432839711	275F0C	5760 787384	EVGENIY AFANASEV	{"phone": "+70515656894"}
0005432839712	9E7467	4840 704090	SVETLANA RODIONOVA	{"email": "svetlana-rodionova1960@postgrespro.ru", "phone": "+70687574736"}
0005432839713	31B6ED	9607 718885	ANNA VLASOVA	{"email": "a.vlasova.1961@postgrespro.ru", "phone": "+70134327887"}
0005432839714	1D902D	5624 751860	MIKHAIL MAKAROV	{"email": "makarovm14031962@postgrespro.ru", "phone": "+70499207915"}
0005432839715	1D902D	7958 722768	ELIZAVETA EFIMOVA	{"phone": "+70731354028"}
0005432839716	1D902D	6796 257694	VALERIYA SOLOVEVA	{"email": "soloveva.v.1960@postgrespro.ru", "phone": "+70398531370"}
0005432839717	7D3326	7384 943821	VLADIMIR SERGEEV	{"phone": "+70861109666"}
0005432839718	877A54	3805 067108	SERGEY ABRAMOV	{"email": "abramov-s_28071970@postgrespro.ru", "phone": "+70820698739"}
0005432839719	947CC8	5038 571103	VALENTINA BORISOVA	{"phone": "+70006728944"}
0005432839720	B13C6B	3737 993961	NINA NESTEROVA	{"email": "ninanesterova-22061977@postgrespro.ru", "phone": "+70220377521"}
0005432839721	E490A1	5135 312397	PETR ZAKHAROV	{"phone": "+70976956533"}
0005432839722	3D54EF	2003 137853	SVETLANA MAKAROVA	{"phone": "+70653314343"}
0005432839723	872F55	1732 669391	VLADIMIR KAZAKOV	{"phone": "+70713954961"}
0005432839724	FF1D7E	9354 012908	ALEKSEY VOROBEV	{"phone": "+70496697880"}
0005432839725	C63C2A	2737 393043	EKATERINA KUZNECOVA	{"email": "kuznecova_e081970@postgrespro.ru", "phone": "+70191459880"}
0005432839726	C56D27	3814 009944	VLADISLAV GORBUNOV	{"email": "gorbunov_v_051976@postgrespro.ru", "phone": "+70342318853"}
0005432839727	CCDB8A	5713 963867	SERGEY YAKOVLEV	{"phone": "+70690690884"}
0005432839728	A64488	5589 703026	EKATERINA KUZNECOVA	{"phone": "+70775001545"}
0005432839729	A64488	5660 420170	VITALIY SCHERBAKOV	{"email": "scherbakovv081970@postgrespro.ru", "phone": "+70828520117"}
0005432839730	A64488	5241 641205	OLEG SOKOLOV	{"email": "sokolov.oleg1984@postgrespro.ru", "phone": "+70401943288"}
0005432839731	311158	9532 787121	NATALYA ANISIMOVA	{"email": "n_anisimova1970@postgrespro.ru", "phone": "+70226012373"}
0005432839732	311158	0054 252291	OLGA NIKOLAEVA	{"email": "nikolaeva_o-1976@postgrespro.ru", "phone": "+70722296113"}
0005432839733	311158	1372 660691	ANDREY ALEKSEEV	{"phone": "+70707880132"}
0005432839734	1BD907	1988 400118	ELIZAVETA FROLOVA	{"email": "frolova-elizaveta_25031971@postgrespro.ru", "phone": "+70160619106"}
0005432839735	B0920F	1441 032582	VALERIY DENISOV	{"email": "valeriy_denisov.1974@postgrespro.ru", "phone": "+70249085502"}
0005432839736	B0920F	4492 778639	DMITRIY ILIN	{"phone": "+70767488413"}
0005432839737	6E0018	4763 491936	SVETLANA ANISIMOVA	{"email": "anisimova-svetlana-11021982@postgrespro.ru", "phone": "+70053913662"}
0005432839738	DE571D	4556 576154	MARINA KOMAROVA	{"phone": "+70825549480"}
0005432839740	FCEFAA	4614 083637	ILYA ZAKHAROV	{"phone": "+70415771982"}
0005432839741	FCEFAA	5700 424836	NIKOLAY IVANOV	{"phone": "+70241132447"}
0005432839742	A8D215	3553 014537	NATALYA MIKHAYLOVA	{"email": "natalya-mikhaylova-081974@postgrespro.ru", "phone": "+70681962635"}
0005432839743	3055A7	4335 368608	OLGA VOLKOVA	{"email": "volkovaolga_1981@postgrespro.ru", "phone": "+70375284610"}
0005432839744	3055A7	5851 870279	ALEKSANDR TARASOV	{"email": "a_tarasov111984@postgrespro.ru", "phone": "+70516359303"}
0005432839745	7ECDEF	7878 884735	ALEKSANDR KONOVALOV	{"email": "akonovalov_22071982@postgrespro.ru", "phone": "+70453700346"}
0005432839746	7ECDEF	9107 431850	ANASTASIYA ISAEVA	{"email": "isaevaanastasiya_1981@postgrespro.ru", "phone": "+70849158770"}
0005432839747	643F30	2084 416101	NADEZHDA ZAKHAROVA	{"phone": "+70628731004"}
0005432839748	643F30	3715 466575	ALBINA NAZAROVA	{"phone": "+70553449785"}
0005432839749	928137	2033 711695	VLADIMIR BELOV	{"email": "vladimirbelov.06031966@postgrespro.ru", "phone": "+70867392912"}
0005432839750	6D1057	5123 479974	KIRILL NAZAROV	{"phone": "+70338842652"}
0005432839751	6D1057	2406 747107	VALENTINA KISELEVA	{"email": "v_kiseleva_1971@postgrespro.ru", "phone": "+70002067096"}
0005432839752	F60ED2	2971 762580	VLADIMIR IVANOV	{"email": "v.ivanov.14081976@postgrespro.ru", "phone": "+70872352483"}
0005432839753	A7FE2E	2616 184313	ANATOLIY SCHERBAKOV	{"phone": "+70944133126"}
0005432839754	A7FE2E	9004 351358	SVETLANA MIKHAYLOVA	{"phone": "+70602405531"}
0005432839755	9337BF	7492 725574	FARID KUZNECOV	{"phone": "+70707979436"}
0005432839756	DBB736	0426 561689	NATALYA KISELEVA	{"email": "n.kiseleva1963@postgrespro.ru", "phone": "+70429706247"}
0005432839757	44B9D3	8760 097132	ALINA KOLESNIKOVA	{"phone": "+70290746562"}
0005432839758	A95348	2956 358403	ALEKSANDR CHERNOV	{"phone": "+70981393677"}
0005432839759	A95348	1409 428324	DARYA TIMOFEEVA	{"phone": "+70328460912"}
0005432839760	B2BF5F	6048 008514	MIKHAIL ZAYCEV	{"email": "mikhail_zaycev-17071979@postgrespro.ru", "phone": "+70137466156"}
0005432839761	F31823	0538 338617	ALEKSEY STEPANOV	{"email": "stepanov.aleksey1967@postgrespro.ru", "phone": "+70219795702"}
0005432839762	BCA1BE	7009 625888	OLGA KUZNECOVA	{"phone": "+70029672408"}
0005432839763	4250C4	6559 743009	YURIY MIRONOV	{"email": "mironov-yuriy091977@postgrespro.ru", "phone": "+70098946713"}
0005432839764	A16B13	4196 544647	ALEKSANDR POPOV	{"email": "popov.aleksandr_091980@postgrespro.ru", "phone": "+70057670653"}
0005432839765	A16B13	9912 263763	KLAVDIYA AKIMOVA	{"email": "klavdiyaakimova.26061974@postgrespro.ru", "phone": "+70602255581"}
0005432839766	2708C0	6714 834743	VLADISLAV POPOV	{"phone": "+70412318783"}
0005432839767	2708C0	9032 780116	OLGA MEDVEDEVA	{"email": "medvedeva_o.051967@postgrespro.ru", "phone": "+70533872422"}
0005432839768	00C143	0328 687986	ANTON VASILEV	{"phone": "+70786617437"}
0005432839769	00C143	4750 403935	ARSENIY FROLOV	{"phone": "+70123834915"}
0005432839770	26EA07	8360 888443	INNA FILATOVA	{"email": "inna-filatova1975@postgrespro.ru", "phone": "+70297370858"}
0005432839771	AB56AC	6657 129301	OLGA NOVIKOVA	{"email": "novikova_o021977@postgrespro.ru", "phone": "+70497708480"}
0005432839772	AB56AC	0958 447909	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov061966@postgrespro.ru", "phone": "+70488069082"}
0005432839773	F4E094	9738 872221	MARIYA ZAKHAROVA	{"phone": "+70982564571"}
0005432839774	7C7A65	6788 686044	NAILYA ANDREEVA	{"email": "andreeva_n.041965@postgrespro.ru", "phone": "+70938918053"}
0005432839775	7C7A65	1118 146576	EVGENIY SIDOROV	{"phone": "+70307503220"}
0005432839776	7DC8EA	7434 540504	NIKOLAY MOROZOV	{"phone": "+70779464651"}
0005432839777	2D1FBC	0876 362255	VIKTOR RODIONOV	{"email": "viktor.rodionov1975@postgrespro.ru", "phone": "+70741674793"}
0005432839778	2D1FBC	3469 052917	LYUDMILA STEPANOVA	{"email": "stepanova-lyudmila_031973@postgrespro.ru", "phone": "+70351768177"}
0005432839779	37575A	8493 213263	SERGEY SOKOLOV	{"email": "sergey.sokolov_111981@postgrespro.ru", "phone": "+70099008763"}
0005432839780	DF0E86	0840 401643	OLGA PETROVA	{"email": "olga.petrova_22021972@postgrespro.ru", "phone": "+70051929249"}
0005432839781	DF0E86	7134 673795	ZOYA ANTONOVA	{"phone": "+70949532978"}
0005432839782	DBEB72	6343 087610	NIKOLAY EGOROV	{"phone": "+70180572676"}
0005432839783	AF4611	5890 951274	VIKTORIYA POTAPOVA	{"email": "potapova.v1971@postgrespro.ru", "phone": "+70720801029"}
0005432839784	48AB68	2290 222477	YURIY MIKHAYLOV	{"phone": "+70135367398"}
0005432839785	2C0BA3	3212 451081	KLAVDIYA SOKOLOVA	{"phone": "+70372448144"}
0005432839786	82DB62	7031 524621	VASILIY KUZNECOV	{"phone": "+70311986748"}
0005432839787	82DB62	3448 428930	VLADIMIR PAVLOV	{"phone": "+70199007680"}
0005432839788	82DB62	9779 693458	RUSLAN ZAYCEV	{"email": "zaycevruslan.03051974@postgrespro.ru", "phone": "+70854364016"}
0005432839789	82DB62	3553 499787	TATYANA SOROKINA	{"email": "sorokinatatyana_1977@postgrespro.ru", "phone": "+70695840493"}
0005432839790	A1B85A	4482 498968	IGOR NAUMOV	{"phone": "+70521724459"}
0005432839791	A1B85A	2821 067395	VITALIY KRASNOV	{"phone": "+70475869390"}
0005432839792	A1B85A	0582 461282	NIKOLAY SMIRNOV	{"email": "nsmirnov.20041972@postgrespro.ru", "phone": "+70628629989"}
0005432839793	52A4E9	7033 800253	ELENA CHERNOVA	{"phone": "+70102979619"}
0005432839794	089BE1	7683 165820	VERA SAVELEVA	{"email": "v-saveleva.14111980@postgrespro.ru", "phone": "+70381549527"}
0005432839795	F0A2F1	8423 157399	DANIIL YAKOVLEV	{"phone": "+70681497274"}
0005432839796	E09172	3362 990831	VALERIYA MASLOVA	{"phone": "+70881248559"}
0005432839797	A63922	3329 041734	MIKHAIL ALEKSEEV	{"phone": "+70378973582"}
0005432839798	ED830B	5239 132748	PAVEL DAVYDOV	{"email": "davydov_p-011965@postgrespro.ru", "phone": "+70299706639"}
0005432839799	8C1719	1971 772832	VLADIMIR PAVLOV	{"phone": "+70204618947"}
0005432839800	8E3E97	4591 075292	GEORGIY FOMIN	{"phone": "+70216573458"}
0005432839801	8E3E97	8894 711670	NAILYA KUZNECOVA	{"email": "kuznecova-nailya_021976@postgrespro.ru", "phone": "+70044305661"}
0005432839802	D601F1	1253 152538	SERGEY MOISEEV	{"phone": "+70202732339"}
0005432839803	562B16	5445 296665	TATYANA POTAPOVA	{"phone": "+70400353145"}
0005432839804	562B16	2842 435018	ARINA SIDOROVA	{"phone": "+70951897745"}
0005432839917	469BBF	5042 110546	NINA OVCHINNIKOVA	{"phone": "+70414000945"}
0005432839805	50F120	1481 231417	LIDIYA VASILEVA	{"email": "l_vasileva16031977@postgrespro.ru", "phone": "+70105149298"}
0005432839806	0984CD	4367 743284	ANATOLIY YAKOVLEV	{"phone": "+70498140842"}
0005432839807	864FC4	3392 069724	VERA KALININA	{"phone": "+70193515385"}
0005432839808	1A2C45	1911 123191	VIKTOR MELNIKOV	{"email": "v-melnikov-021967@postgrespro.ru", "phone": "+70412583520"}
0005432839809	1A2C45	4352 940601	VIKTORIYA KOLESNIKOVA	{"phone": "+70802829792"}
0005432839810	F7EFCC	4230 076676	VLADIMIR GERASIMOV	{"phone": "+70386596391"}
0005432839811	F7EFCC	1433 845878	EVGENIY OSIPOV	{"email": "osipovevgeniy101964@postgrespro.ru", "phone": "+70480527924"}
0005432839812	8812ED	1902 041277	MIKHAIL TARASOV	{"email": "mikhail-tarasov-03101974@postgrespro.ru", "phone": "+70833681569"}
0005432839813	18EECF	0722 993841	ELENA TITOVA	{"phone": "+70854134503"}
0005432839814	0BE57D	7155 673528	MARYAM SEMENOVA	{"email": "maryam_semenova-17101969@postgrespro.ru", "phone": "+70978797638"}
0005432839815	0BE57D	6424 821689	TAMARA BOGDANOVA	{"email": "t_bogdanova.28011974@postgrespro.ru", "phone": "+70375949024"}
0005432839816	A3AB70	0773 491889	IVAN SAVELEV	{"email": "savelevivan.091967@postgrespro.ru", "phone": "+70773852307"}
0005432839817	B0BB1E	3925 837291	ALINA SEMENOVA	{"email": "a.semenova_1970@postgrespro.ru", "phone": "+70195095761"}
0005432839818	386300	8566 686123	IRINA OSIPOVA	{"phone": "+70604252660"}
0005432839819	386300	7376 483734	YULIYA SOKOLOVA	{"email": "sokolovay111975@postgrespro.ru", "phone": "+70684153089"}
0005432839820	386300	9001 185616	ROMAN GAVRILOV	{"phone": "+70715913205"}
0005432839821	D538DE	4416 130472	ARTEM KUZNECOV	{"email": "kuznecov.artem.1980@postgrespro.ru", "phone": "+70967519595"}
0005432839822	D12E3E	7438 441398	ALEKSANDR SERGEEV	{"phone": "+70196271768"}
0005432839823	757686	9096 527012	EVGENIY BORISOV	{"email": "e.borisov-061964@postgrespro.ru", "phone": "+70564213740"}
0005432839824	757686	1514 433672	DMITRIY ALEKSEEV	{"email": "alekseev.dmitriy121977@postgrespro.ru", "phone": "+70828129831"}
0005432839825	757686	7506 983398	TAMARA ABRAMOVA	{"email": "abramova-t-071969@postgrespro.ru", "phone": "+70078498144"}
0005432839826	32DB6A	4445 501720	PETR FROLOV	{"phone": "+70359801022"}
0005432839827	BC1A8E	4697 509481	GALINA NIKITINA	{"email": "nikitina_g111975@postgrespro.ru", "phone": "+70103955221"}
0005432839828	907A8F	3435 477962	DARYA SAVELEVA	{"email": "darya_saveleva_1976@postgrespro.ru", "phone": "+70666069794"}
0005432839829	EE101E	8052 362793	ANTONINA ORLOVA	{"email": "aorlova_1970@postgrespro.ru", "phone": "+70686922354"}
0005432839830	C39D67	3070 408151	VERONIKA EGOROVA	{"phone": "+70644220948"}
0005432839831	85324C	4983 757286	YURIY KRASNOV	{"phone": "+70460118851"}
0005432839832	4022DC	6954 458767	DMITRIY PAVLOV	{"phone": "+70419878502"}
0005432839833	0ACC01	6896 245885	ANNA ZHUKOVA	{"phone": "+70931730154"}
0005432839834	0ACC01	8581 534710	ALEKSANDR VASILEV	{"phone": "+70033697299"}
0005432839835	0ACC01	8956 859033	VALERIY DENISOV	{"email": "valeriydenisov-1972@postgrespro.ru", "phone": "+70910732927"}
0005432839836	823797	0322 380949	OLGA KOVALEVA	{"phone": "+70535718505"}
0005432839837	A75DD9	3506 399920	ANNA ABRAMOVA	{"phone": "+70471000473"}
0005432839838	A75DD9	1438 197981	NIKOLAY MATVEEV	{"phone": "+70117679279"}
0005432839839	03F896	1206 478526	VERA MOROZOVA	{"email": "v.morozova-1980@postgrespro.ru", "phone": "+70873228868"}
0005432839840	187346	5129 984038	OLGA EGOROVA	{"phone": "+70803829883"}
0005432839841	187346	3843 448424	ANATOLIY MATVEEV	{"phone": "+70145629251"}
0005432839842	CA7ED6	2959 511892	ALEKSANDR NIKITIN	{"phone": "+70411552477"}
0005432839843	0FBCA4	7980 218375	ZINAIDA NIKOLAEVA	{"phone": "+70726805987"}
0005432839844	BE853D	6137 827804	ELENA MIRONOVA	{"email": "mironovaelena_1974@postgrespro.ru", "phone": "+70507788712"}
0005432839845	BE853D	5861 945440	LYUDMILA PAVLOVA	{"email": "pavlova-l.1968@postgrespro.ru", "phone": "+70263747219"}
0005432839846	BE853D	1127 928806	SVETLANA VLASOVA	{"email": "svlasova-121966@postgrespro.ru", "phone": "+70973074154"}
0005432839847	364334	2727 766667	EKATERINA PETROVA	{"email": "petrova-e121983@postgrespro.ru", "phone": "+70187502832"}
0005432839848	B4392B	7492 460044	EVDOKIYA MAKSIMOVA	{"email": "maksimovae-31101966@postgrespro.ru", "phone": "+70340400880"}
0005432839849	B4392B	8170 864157	ANTONINA RYABOVA	{"email": "ryabova-a.021976@postgrespro.ru", "phone": "+70164874896"}
0005432839850	2E0A1D	5444 414235	IRINA FADEEVA	{"phone": "+70444166599"}
0005432839851	C4107D	5899 227234	ALEKSEY VOLKOV	{"phone": "+70800386240"}
0005432839852	C4107D	7265 151139	MIKHAIL KONOVALOV	{"phone": "+70678456681"}
0005432839853	54B2C0	4606 886468	NINA LOGINOVA	{"email": "n-loginova.081967@postgrespro.ru", "phone": "+70349158748"}
0005432839854	54B2C0	1009 383566	NATALYA BORISOVA	{"phone": "+70644490996"}
0005432839855	999463	5852 530149	DANILA KISELEV	{"email": "kiselevdanila021981@postgrespro.ru", "phone": "+70271526514"}
0005432839856	F47AB4	0294 127332	LYUBOV SIDOROVA	{"email": "l.sidorova10051967@postgrespro.ru", "phone": "+70735865674"}
0005432839857	F47AB4	4364 004858	EKATERINA MEDVEDEVA	{"email": "e_medvedeva1970@postgrespro.ru", "phone": "+70417756570"}
0005432839858	F47AB4	4222 187178	IGOR ZAKHAROV	{"email": "izakharov.30071968@postgrespro.ru", "phone": "+70150620383"}
0005432839859	180180	6916 674311	IGOR POPOV	{"phone": "+70237436204"}
0005432839860	9B0311	4358 636275	MARGARITA POTAPOVA	{"phone": "+70807127905"}
0005432839861	9B0311	5381 737181	SVETLANA VASILEVA	{"email": "vasileva_s_04061973@postgrespro.ru", "phone": "+70976466764"}
0005432839862	FBB71E	0646 843273	OLEG KUZNECOV	{"phone": "+70736700067"}
0005432839863	EAC069	4643 041529	IRINA VOLKOVA	{"email": "volkova_i.121973@postgrespro.ru", "phone": "+70167057222"}
0005432839864	EAC069	3572 512184	VENERA VOLKOVA	{"phone": "+70956461160"}
0005432839865	80D96D	8056 143071	LILIYA GRISHINA	{"phone": "+70362308735"}
0005432839866	83BF2B	5892 548103	RAISA KUZMINA	{"email": "kuzminaraisa-06021983@postgrespro.ru", "phone": "+70016192575"}
0005432839867	89672E	3779 744452	ANASTASIYA IVANOVA	{"phone": "+70650587340"}
0005432839868	56683C	8609 247706	MARINA SCHERBAKOVA	{"phone": "+70808527786"}
0005432839869	56683C	7589 177486	VLADISLAV PAVLOV	{"email": "pavlov.vladislav_24121969@postgrespro.ru", "phone": "+70407122567"}
0005432839870	556B4D	5875 659742	ALLA OSIPOVA	{"email": "osipova-a22121970@postgrespro.ru", "phone": "+70246310808"}
0005432839871	556B4D	1227 199779	NATALYA KUZNECOVA	{"email": "kuznecova_n.1965@postgrespro.ru", "phone": "+70165547463"}
0005432839872	53B284	6959 335771	VIKTOR SOLOVEV	{"email": "vsolovev_1964@postgrespro.ru", "phone": "+70360878327"}
0005432839873	53B284	7247 431592	EVGENIY ZAYCEV	{"email": "evgeniy_zaycev1963@postgrespro.ru", "phone": "+70216473233"}
0005432839874	B4F9AE	7123 262466	ELENA KONOVALOVA	{"email": "ekonovalova_27101973@postgrespro.ru", "phone": "+70336183699"}
0005432839875	B4F9AE	6601 417767	RAISA KOMAROVA	{"phone": "+70694094943"}
0005432839876	87FD49	9344 732660	LIDIYA KOMAROVA	{"email": "lidiya-komarova.1978@postgrespro.ru", "phone": "+70355545607"}
0005432839877	969353	7295 728547	OLGA BELOVA	{"phone": "+70710175968"}
0005432839878	228B0C	5441 533193	TATYANA KAZAKOVA	{"email": "tatyana_kazakova-061979@postgrespro.ru", "phone": "+70195434167"}
0005432839879	163660	3838 612596	NADEZHDA KONOVALOVA	{"phone": "+70384895200"}
0005432839880	33B506	4455 195663	IRINA MASLOVA	{"phone": "+70067884331"}
0005432839881	8DC7D4	8084 570896	ANASTASIYA POPOVA	{"email": "popova-anastasiya011962@postgrespro.ru", "phone": "+70169642564"}
0005432839882	E949F0	8234 496605	DENIS SOKOLOV	{"phone": "+70131823104"}
0005432839883	1E3F5C	5978 064673	ANATOLIY FOMIN	{"email": "fomin-anatoliy-121978@postgrespro.ru", "phone": "+70147006595"}
0005432839884	B8AC61	6563 178792	DMITRIY DMITRIEV	{"phone": "+70684138780"}
0005432839885	B8AC61	2084 373861	IRINA MAKAROVA	{"email": "makarova_i.091982@postgrespro.ru", "phone": "+70612905155"}
0005432839886	D8E67D	0906 561705	IRINA CHERNOVA	{"phone": "+70769819213"}
0005432839887	D8E67D	4263 613048	KRISTINA GORBUNOVA	{"phone": "+70569795593"}
0005432839888	FC4F70	1206 999524	VIKTOR NIKITIN	{"phone": "+70619156693"}
0005432839889	99B970	9065 136119	ZINAIDA POPOVA	{"phone": "+70049225837"}
0005432839890	99B970	7411 579990	VIKTOR SEMENOV	{"email": "semenov-viktor_02051982@postgrespro.ru", "phone": "+70150727207"}
0005432839891	0C2FF3	1949 703951	GALINA KUZNECOVA	{"email": "kuznecovagalina101971@postgrespro.ru", "phone": "+70233396283"}
0005432839892	0C2FF3	1102 008994	DMITRIY SOLOVEV	{"phone": "+70267915348"}
0005432839893	68B8BB	6828 988808	SVETLANA FROLOVA	{"phone": "+70662235401"}
0005432839894	68B8BB	6759 123648	OLGA POPOVA	{"phone": "+70699479379"}
0005432839895	68B8BB	4614 649136	YAROSLAV SMIRNOV	{"phone": "+70533355377"}
0005432839896	F68A55	3778 159051	STANISLAV MEDVEDEV	{"email": "stanislav_medvedev19121976@postgrespro.ru", "phone": "+70477601962"}
0005432839897	F68A55	2897 044255	ANDREY KONOVALOV	{"email": "konovalov-a_1987@postgrespro.ru", "phone": "+70541357211"}
0005432839898	AF5453	2634 856585	OLGA ZOTOVA	{"email": "o_zotova.31031971@postgrespro.ru", "phone": "+70102096076"}
0005432839899	0CC8FE	8330 639840	ALEKSANDRA KOZLOVA	{"phone": "+70435622096"}
0005432839900	0CC8FE	6904 544275	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov071968@postgrespro.ru", "phone": "+70193259343"}
0005432839901	774D34	0371 363818	SVETLANA KOZLOVA	{"email": "svetlana.kozlova_021981@postgrespro.ru", "phone": "+70067084542"}
0005432839902	D6512C	7490 207377	NIKOLAY GERASIMOV	{"email": "n-gerasimov-1964@postgrespro.ru", "phone": "+70043716378"}
0005432839903	D6512C	6729 771100	KLAVDIYA MATVEEVA	{"phone": "+70791672675"}
0005432839904	19D514	3870 451281	ALEKSANDR DAVYDOV	{"phone": "+70725321124"}
0005432839905	33C7DF	2830 976084	OLEG MOROZOV	{"phone": "+70757416917"}
0005432839906	DB8DD5	6123 879090	VLADIMIR NAZAROV	{"phone": "+70205429222"}
0005432839907	7F486C	7976 394426	DENIS ABRAMOV	{"email": "d-abramov_01081971@postgrespro.ru", "phone": "+70009854134"}
0005432839908	7F486C	6383 616736	ELENA AFANASEVA	{"email": "e_afanaseva.22031970@postgrespro.ru", "phone": "+70716000106"}
0005432839909	975B3E	5447 117344	OLGA MELNIKOVA	{"email": "melnikova_o.05101968@postgrespro.ru", "phone": "+70318453047"}
0005432839910	4B0E71	9581 446946	YULIYA FOMINA	{"phone": "+70090330688"}
0005432839911	3C4B9C	3901 673247	YURIY NOVIKOV	{"phone": "+70115372017"}
0005432839912	D18EC7	1186 826666	YURIY GERASIMOV	{"email": "yuriy-gerasimov.30041964@postgrespro.ru", "phone": "+70107011558"}
0005432839913	3FA56B	0617 254778	ELIZAVETA KUZMINA	{"phone": "+70449562732"}
0005432839914	3FA56B	2599 807656	SHAVKAT SOLOVEV	{"email": "s_solovev_091983@postgrespro.ru", "phone": "+70832397374"}
0005432839915	9E042F	7122 253540	EVGENIY DENISOV	{"email": "evgeniydenisov-30041976@postgrespro.ru", "phone": "+70927631435"}
0005432839916	469BBF	3512 621196	LIDIYA POTAPOVA	{"email": "l.potapova_1970@postgrespro.ru", "phone": "+70361437547"}
0005432839918	A7EA32	5675 363063	TATYANA LEBEDEVA	{"phone": "+70740828502"}
0005432839919	4E6AE5	0231 727734	RUSLAN RODIONOV	{"email": "rodionov-ruslan041974@postgrespro.ru", "phone": "+70492685813"}
0005432839920	5D0B5B	0630 855842	LILIYA KUZNECOVA	{"email": "lkuznecova08031978@postgrespro.ru", "phone": "+70477523901"}
0005432839921	493702	8651 530067	SVETLANA SOROKINA	{"phone": "+70501988132"}
0005432839922	493702	0080 965997	MARINA BELOVA	{"email": "marina-belova-041969@postgrespro.ru", "phone": "+70212896918"}
0005432839923	C938DF	3337 143697	TATYANA EGOROVA	{"phone": "+70945559604"}
0005432839924	25CCDD	0044 604348	NATALYA MAKAROVA	{"email": "nmakarova.07091961@postgrespro.ru", "phone": "+70511481457"}
0005432839925	0DDE12	2930 113670	VALENTINA VASILEVA	{"phone": "+70872328825"}
0005432839926	0DDE12	2724 422707	MIKHAIL GERASIMOV	{"email": "mikhail-gerasimov.28071963@postgrespro.ru", "phone": "+70163174613"}
0005432839927	CCF605	4580 600809	NIKOLAY ROMANOV	{"email": "romanov_n-15041980@postgrespro.ru", "phone": "+70365247412"}
0005432839928	CCF605	2631 070504	ALEKSEY RODIONOV	{"email": "alekseyrodionov-07121967@postgrespro.ru", "phone": "+70138038658"}
0005432839929	D54CB1	5491 157656	ELENA KONDRATEVA	{"email": "kondrateva-elena.081978@postgrespro.ru", "phone": "+70692437478"}
0005432839930	D54CB1	2084 560426	ELENA TIKHONOVA	{"email": "elena.tikhonova_27021969@postgrespro.ru", "phone": "+70290230399"}
0005432839931	3A6038	4069 055402	NATALYA KOLESNIKOVA	{"email": "n_kolesnikova_111976@postgrespro.ru", "phone": "+70504912803"}
0005432839932	3632FC	9808 035714	ELENA KUZNECOVA	{"email": "e-kuznecova_1966@postgrespro.ru", "phone": "+70822275321"}
0005432839933	3632FC	9290 388745	NATALYA VASILEVA	{"email": "vasileva_natalya-1965@postgrespro.ru", "phone": "+70731744110"}
0005432839934	3632FC	3639 450844	MARINA ABRAMOVA	{"phone": "+70663219665"}
0005432839935	EF57E1	4778 881654	TATYANA POTAPOVA	{"email": "potapova.tatyana121962@postgrespro.ru", "phone": "+70635762747"}
0005432839936	EF57E1	2110 717739	DENIS MOROZOV	{"phone": "+70286424851"}
0005432839937	3F71EB	0563 878218	ELENA EGOROVA	{"email": "egorova-e-1972@postgrespro.ru", "phone": "+70705586155"}
0005432839938	3F71EB	9084 801959	TATYANA ISAEVA	{"phone": "+70029128541"}
0005432839939	CA9CF5	1827 103687	SERGEY EGOROV	{"phone": "+70793689810"}
0005432839940	CA9CF5	8819 588181	MAKSIM VOROBEV	{"phone": "+70194685839"}
0005432839941	25DFF5	6816 513623	VLADIMIR SCHERBAKOV	{"phone": "+70429729440"}
0005432840987	30DF55	7962 483708	ANNA KUZNECOVA	{"phone": "+70645160860"}
0005432840976	228F25	5798 039416	VALENTINA NIKIFOROVA	{"phone": "+70558615852"}
0005432840977	FF5B31	3859 622971	NATALYA IVANOVA	{"email": "ivanova.n.1962@postgrespro.ru", "phone": "+70011882754"}
0005432840978	FF5B31	7898 020327	TAMARA SIDOROVA	{"phone": "+70773845499"}
0005432840979	E0B17D	8000 926988	NIKOLAY KUDRYASHOV	{"phone": "+70940105034"}
0005432840980	03EC81	3542 038939	MIKHAIL KISELEV	{"email": "mikhail-kiselev_07051976@postgrespro.ru", "phone": "+70266394743"}
0005432840981	03EC81	7787 623803	VERA ZOTOVA	{"phone": "+70619114103"}
0005432840982	03EC81	6068 815886	SERGEY ANTONOV	{"phone": "+70094551663"}
0005432840983	55F6B4	8288 091376	NINA NIKOLAEVA	{"phone": "+70711666248"}
0005432840984	55F6B4	6319 965081	DANILA VASILEV	{"email": "vasilevd_27031983@postgrespro.ru", "phone": "+70549388123"}
0005432840985	48CCEE	8404 795727	ALEKSEY MIRONOV	{"email": "a_mironov111971@postgrespro.ru", "phone": "+70988354694"}
0005432840986	48CCEE	0846 122455	SERGEY SHEVCHENKO	{"email": "s-shevchenko_18041968@postgrespro.ru", "phone": "+70493973118"}
0005432840988	30DF55	4394 168033	ALEKSANDR DAVYDOV	{"email": "adavydov_1981@postgrespro.ru", "phone": "+70529212265"}
0005432840989	1D08A4	3402 084856	TAMARA BELYAEVA	{"email": "tamara.belyaeva-1973@postgrespro.ru", "phone": "+70800006372"}
0005432840990	1D08A4	3447 520492	VYACHESLAV YAKOVLEV	{"phone": "+70088163438"}
0005432840991	130960	1105 342559	IVAN ZAKHAROV	{"email": "zakharovi-011973@postgrespro.ru", "phone": "+70257700546"}
0005432840992	E1A102	3469 945749	MARIYA RYABOVA	{"phone": "+70523064095"}
0005432840993	C6DD98	7093 789410	KONSTANTIN ANTONOV	{"phone": "+70017905864"}
0005432840994	C6DD98	0648 227643	NIKOLAY TARASOV	{"email": "tarasov.nikolay.1971@postgrespro.ru", "phone": "+70567649281"}
0005432840995	C68FEE	8883 825282	VIKTOR MIKHAYLOV	{"email": "mikhaylov_viktor011978@postgrespro.ru", "phone": "+70916600537"}
0005432840996	14AD43	9721 114727	VLADIMIR GERASIMOV	{"phone": "+70043610805"}
0005432840997	32835B	9453 961753	EKATERINA ORLOVA	{"email": "orlova_ekaterina_27091964@postgrespro.ru", "phone": "+70436290259"}
0005432840998	32835B	2963 839655	ILYA NIKOLAEV	{"email": "nikolaev.ilya1981@postgrespro.ru", "phone": "+70170046822"}
0005432840999	A00DCD	9641 406383	TATYANA ABRAMOVA	{"email": "t-abramova1970@postgrespro.ru", "phone": "+70463921503"}
0005432841000	27D4CE	6658 153002	EKATERINA SERGEEVA	{"email": "e.sergeeva-071966@postgrespro.ru", "phone": "+70856525221"}
0005432841001	27D4CE	7354 287445	EVGENIY TIKHONOV	{"phone": "+70320147012"}
0005432841002	BD5F4C	7224 865658	LIDIYA SCHERBAKOVA	{"email": "scherbakovalidiya041981@postgrespro.ru", "phone": "+70752597010"}
0005432841003	067908	5316 652481	VASILIY MEDVEDEV	{"email": "medvedev-v_1969@postgrespro.ru", "phone": "+70666528817"}
0005432841004	F3A8B5	2817 616204	ARSEN FEDOTOV	{"email": "arsen.fedotov.021972@postgrespro.ru", "phone": "+70897649844"}
0005432841005	F3A8B5	2199 247093	VLADIMIR SERGEEV	{"phone": "+70714243486"}
0005432841006	84CF99	4319 956523	IRINA FROLOVA	{"email": "frolova-i_1959@postgrespro.ru", "phone": "+70312902548"}
0005432841007	44E6CA	4731 082597	ULYANA BOGDANOVA	{"phone": "+70512801162"}
0005432841008	44E6CA	3347 899477	LYUDMILA ROMANOVA	{"phone": "+70165940526"}
0005432841009	BB24F3	5211 183221	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr.12031978@postgrespro.ru", "phone": "+70719966625"}
0005432841010	BB24F3	2256 091128	ALEVTINA IVANOVA	{"phone": "+70045324396"}
0005432841011	62F855	8006 274665	MARIYA VASILEVA	{"email": "mariya.vasileva071968@postgrespro.ru", "phone": "+70484443376"}
0005432841012	9DEEAE	3359 416965	ANTON ABRAMOV	{"email": "abramov_a111970@postgrespro.ru", "phone": "+70454070030"}
0005432841013	97C266	6322 475215	ALEKSANDR FOMIN	{"phone": "+70674493694"}
0005432841014	C56B60	0057 121141	KIRILL SEMENOV	{"email": "ksemenov.26061965@postgrespro.ru", "phone": "+70591315431"}
0005432841015	A081CC	0303 989746	ALEKSEY ANTONOV	{"email": "antonov.a_13041970@postgrespro.ru", "phone": "+70184970919"}
0005432841016	7ABC7A	9132 183240	ALENA VOLKOVA	{"email": "a.volkova-041974@postgrespro.ru", "phone": "+70177450062"}
0005432841017	D91B7C	2440 995623	SEMEN NIKOLAEV	{"phone": "+70962484020"}
0005432841018	E934A2	7086 454119	DMITRIY SCHERBAKOV	{"email": "scherbakovdmitriy.1955@postgrespro.ru", "phone": "+70042385129"}
0005432841019	53222E	5612 883665	NADEZHDA TARASOVA	{"email": "ntarasova-1974@postgrespro.ru", "phone": "+70338677160"}
0005432841020	53222E	0999 831699	LIDIYA PAVLOVA	{"phone": "+70123598229"}
0005432841021	B8FCFF	3329 532191	GALINA FROLOVA	{"email": "g.frolova-04021968@postgrespro.ru", "phone": "+70266229829"}
0005432841022	8C30C1	6295 128409	ANNA TARASOVA	{"email": "tarasova-a_29091961@postgrespro.ru", "phone": "+70763786911"}
0005432841023	734367	6838 051268	GENNADIY VASILEV	{"phone": "+70182753472"}
0005432841024	77D6C7	3185 958494	OLGA SIDOROVA	{"phone": "+70573638368"}
0005432841025	4DB880	9948 746820	YULIYA TIKHONOVA	{"email": "tikhonova-yuliya_061969@postgrespro.ru", "phone": "+70237771506"}
0005432841026	D0AD3C	8513 220950	NINA SMIRNOVA	{"email": "nsmirnova.1981@postgrespro.ru", "phone": "+70158721144"}
0005432841027	E51A60	3332 595800	LYUDMILA SIDOROVA	{"email": "lyudmila-sidorova-1972@postgrespro.ru", "phone": "+70607794060"}
0005432841028	0D2D5B	3559 579762	VLADIMIR CHERNOV	{"email": "vchernov1965@postgrespro.ru", "phone": "+70729055764"}
0005432841029	0D2D5B	5154 883583	MARIYA SMIRNOVA	{"phone": "+70071125104"}
0005432841030	0D2D5B	8758 267503	ALEKSANDR MEDVEDEV	{"email": "aleksandr-medvedev.10111982@postgrespro.ru", "phone": "+70363845863"}
0005432841031	47FA46	4287 374482	ALEKSANDRA EFREMOVA	{"email": "efremova-a.23051975@postgrespro.ru", "phone": "+70890771216"}
0005432841032	A1F61E	8660 531971	DMITRIY CHERNOV	{"email": "dmitriy-chernov041962@postgrespro.ru", "phone": "+70659800281"}
0005432841033	A1F61E	7847 995519	ALEKSANDR MOROZOV	{"phone": "+70568614251"}
0005432841034	688A83	4630 536396	VITALIY PETROV	{"email": "petrov-vitaliy_28091968@postgrespro.ru", "phone": "+70022274001"}
0005432841035	F6AD78	6482 994741	KIRILL SMIRNOV	{"email": "k.smirnov-1960@postgrespro.ru", "phone": "+70286978513"}
0005432841036	97CC92	9995 524692	MARINA DMITRIEVA	{"phone": "+70677866806"}
0005432841037	0B7FC3	1379 808346	ALEKSANDR YAKOVLEV	{"phone": "+70956286837"}
0005432841038	0B7FC3	8696 987438	NINA BELYAEVA	{"phone": "+70729732500"}
0005432841039	3C6D7D	5390 616926	LYUDMILA SMIRNOVA	{"email": "smirnova_l_1977@postgrespro.ru", "phone": "+70612283690"}
0005432841040	1FD74F	6742 581963	IRINA ZAYCEVA	{"email": "zayceva_i_1970@postgrespro.ru", "phone": "+70114798749"}
0005432841041	A48C88	0241 262138	EKATERINA TIKHONOVA	{"phone": "+70500169468"}
0005432841042	C14215	5564 448296	LYUDMILA MAKAROVA	{"email": "lmakarova_27071965@postgrespro.ru", "phone": "+70869130806"}
0005432841043	5386B3	4236 729184	DENIS KUZNECOV	{"email": "kuznecov_d_1968@postgrespro.ru", "phone": "+70325333898"}
0005432841044	5386B3	1445 090694	LYUDMILA ROMANOVA	{"email": "romanova_lyudmila.1967@postgrespro.ru", "phone": "+70051184747"}
0005432841045	76CA4C	4613 218222	ANDREY KUZNECOV	{"email": "a-kuznecov121987@postgrespro.ru", "phone": "+70798852249"}
0005432841046	6AC704	1588 054044	YANA LOGINOVA	{"phone": "+70901580604"}
0005432841047	5DF8F6	1504 430965	MIKHAIL CHERNOV	{"email": "mikhailchernov1982@postgrespro.ru", "phone": "+70584795345"}
0005432841048	260A57	6120 122262	OLEG MOROZOV	{"phone": "+70963706253"}
0005432841049	F14C34	9068 771093	ALEKSANDR ILIN	{"email": "a_ilin.12021979@postgrespro.ru", "phone": "+70294624045"}
0005432841050	AC4A9F	5988 059225	TAMARA ZOTOVA	{"phone": "+70191260596"}
0005432841051	83BF71	5167 199631	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko_1973@postgrespro.ru", "phone": "+70355795533"}
0005432841052	83BF71	6567 102613	MARINA MIKHAYLOVA	{"phone": "+70815640115"}
0005432841053	D90F09	3799 247486	VALERIY KAZAKOV	{"email": "kazakovvaleriy_1988@postgrespro.ru", "phone": "+70426667387"}
0005432841054	74F2A1	7182 633207	VALENTINA FEDOROVA	{"email": "fedorova_valentina.1980@postgrespro.ru", "phone": "+70553976812"}
0005432841055	74F2A1	8230 587731	BORIS KOROLEV	{"phone": "+70205180632"}
0005432841056	72A6DF	0394 467694	LYUDMILA TIMOFEEVA	{"phone": "+70172895229"}
0005432841057	F66460	1092 468618	YULIYA SERGEEVA	{"email": "sergeeva_y_041979@postgrespro.ru", "phone": "+70177576229"}
0005432841058	2D0A9C	4234 352288	LYUDMILA MATVEEVA	{"email": "lmatveeva10121975@postgrespro.ru", "phone": "+70989558292"}
0005432841059	CB2299	4375 784854	VERA NIKITINA	{"email": "vera_nikitina_03111956@postgrespro.ru", "phone": "+70674701958"}
0005432841060	D960A9	7922 549621	TATYANA MAKSIMOVA	{"phone": "+70034186382"}
0005432841061	F29CD3	0036 978196	ELENA AFANASEVA	{"phone": "+70505864280"}
0005432841062	8CBF29	8844 154483	ALSU BARANOVA	{"email": "alsu-baranova.111973@postgrespro.ru", "phone": "+70695589467"}
0005432841063	8CBF29	8189 342692	ANDREY POPOV	{"phone": "+70017838366"}
0005432841064	7B118E	3715 644631	NADEZHDA KUDRYASHOVA	{"email": "nadezhda-kudryashova1983@postgrespro.ru", "phone": "+70186730496"}
0005432841065	7B118E	9294 181706	LYUDMILA FEDOROVA	{"phone": "+70477814383"}
0005432841066	E814D7	8853 699432	IRINA BELOVA	{"email": "belova_irina1971@postgrespro.ru", "phone": "+70420662766"}
0005432841067	7CBA04	7531 460556	KONSTANTIN ANTONOV	{"email": "konstantin.antonov111981@postgrespro.ru", "phone": "+70360493255"}
0005432841068	7CBA04	8849 740453	ELENA NIKOLAEVA	{"email": "e.nikolaeva-15091970@postgrespro.ru", "phone": "+70853185848"}
0005432841069	FC02CF	6238 286510	LIDIYA CHERNOVA	{"email": "lchernova.1968@postgrespro.ru", "phone": "+70536783651"}
0005432841070	C91E6B	5975 850513	ANNA MEDVEDEVA	{"phone": "+70963681156"}
0005432841071	4AF53C	2081 136921	VIKTOR KOZLOV	{"email": "kozlovviktor.21011967@postgrespro.ru", "phone": "+70029557100"}
0005432841072	4AF53C	6747 765617	ANTON GORBUNOV	{"email": "anton.gorbunov011977@postgrespro.ru", "phone": "+70613556616"}
0005432841073	B4F969	3732 907246	ANDREY VOROBEV	{"email": "vorobevandrey_09061972@postgrespro.ru", "phone": "+70648013957"}
0005432848055	572294	6039 038931	DMITRIY ROMANOV	{"email": "romanov-dmitriy_1969@postgrespro.ru", "phone": "+70659984079"}
0005432848056	572294	9847 447091	ANNA MAKAROVA	{"email": "makarova.a-04111976@postgrespro.ru", "phone": "+70150008684"}
0005432848057	572294	5673 349865	MARGARITA CHERNOVA	{"phone": "+70747647276"}
0005432848058	039029	3179 265776	ALEKSANDR SERGEEV	{"phone": "+70006185207"}
0005432848059	CD1CBF	3161 965405	EVGENIYA VASILEVA	{"phone": "+70984626390"}
0005432848060	E7BC1B	3259 274198	ANNA MELNIKOVA	{"phone": "+70702674836"}
0005432848061	73F06B	6972 949067	IRINA EFIMOVA	{"phone": "+70636550685"}
0005432848062	75849B	9558 998956	VIKTORIYA IVANOVA	{"phone": "+70805197886"}
0005432848063	4AF2C0	1179 284728	TATYANA ZAKHAROVA	{"phone": "+70662987461"}
0005432848064	4AF2C0	9307 657560	LYUBOV IVANOVA	{"email": "lyubovivanova.1969@postgrespro.ru", "phone": "+70730628896"}
0005432848065	697CA8	6107 300538	EVGENIY ILIN	{"phone": "+70949701252"}
0005432848066	9AF46F	8630 719482	NADEZHDA KUZNECOVA	{"email": "kuznecova.n041976@postgrespro.ru", "phone": "+70294422950"}
0005432848067	C97BA4	6794 063526	ALEKSANDR VLASOV	{"email": "a_vlasov.24111977@postgrespro.ru", "phone": "+70736228157"}
0005432848068	B6CC1E	3781 503773	VALERIY KUZNECOV	{"phone": "+70646644874"}
0005432848069	E9E0FD	7884 034925	YULIYA MAKAROVA	{"email": "ymakarova-24051970@postgrespro.ru", "phone": "+70503418859"}
0005432848070	E9E0FD	4461 853095	VALERIY KUZNECOV	{"email": "kuznecovv061977@postgrespro.ru", "phone": "+70165238713"}
0005432848071	294C52	5044 949473	ALEKSANDRA KOLESNIKOVA	{"email": "a-kolesnikova-051975@postgrespro.ru", "phone": "+70167719828"}
0005432848072	294C52	1135 138593	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_aleksandr.1978@postgrespro.ru", "phone": "+70690950351"}
0005432848073	02C55D	8172 353053	VITALIY MAKAROV	{"email": "makarov-vitaliy-1973@postgrespro.ru", "phone": "+70547281662"}
0005432848074	02C55D	7410 329176	ALBINA SOKOLOVA	{"email": "sokolova.a-26071966@postgrespro.ru", "phone": "+70381828097"}
0005432848075	0302C8	5553 602625	ZAKHAR ZAKHAROV	{"phone": "+70785751061"}
0005432848076	0D274F	8947 981727	ANTONINA EGOROVA	{"phone": "+70375027587"}
0005432848077	0D274F	2723 130147	ALEKSANDR MARTYNOV	{"email": "martynov_a_17051967@postgrespro.ru", "phone": "+70521949449"}
0005432848078	1BC4FF	8839 771388	VLADIMIR BORISOV	{"email": "vladimir_borisov-041982@postgrespro.ru", "phone": "+70942652790"}
0005432848527	65413F	6767 897251	VALENTINA FILIPPOVA	{"phone": "+70174527498"}
0005432848079	4EED8C	6626 299618	MARINA DMITRIEVA	{"email": "marina.dmitrieva-081972@postgrespro.ru", "phone": "+70028600700"}
0005432848080	509129	7778 879314	ALEKSANDR KUDRYASHOV	{"phone": "+70238330205"}
0005432848081	509129	1880 441461	EVGENIYA PAVLOVA	{"phone": "+70971972797"}
0005432848082	509129	4462 725692	VADIM IVANOV	{"email": "vivanov_14081978@postgrespro.ru", "phone": "+70556023768"}
0005432848083	60BB09	9222 169499	SERGEY ANDREEV	{"phone": "+70313763086"}
0005432848084	60BB09	4441 774831	OLEG OSIPOV	{"phone": "+70898683255"}
0005432848085	05848E	7478 313251	SERGEY SCHERBAKOV	{"email": "scherbakovsergey1976@postgrespro.ru", "phone": "+70483829189"}
0005432848086	05848E	3288 383533	OLGA IVANOVA	{"phone": "+70599634511"}
0005432848087	FDEAF1	3810 765122	KSENIYA RYABOVA	{"phone": "+70166087305"}
0005432848088	C4DA35	5378 950769	ROMAN NOVIKOV	{"email": "r_novikov.1960@postgrespro.ru", "phone": "+70768593361"}
0005432848089	142A0D	8999 163243	MIKHAIL FEDOROV	{"phone": "+70981826270"}
0005432848090	142A0D	3428 322939	OLEG ORLOV	{"phone": "+70457687452"}
0005432848091	C53C19	4231 725095	ALEKSANDR KRASNOV	{"phone": "+70486263269"}
0005432848092	C53C19	1998 789239	ROZA RODIONOVA	{"email": "roza.rodionova.19071956@postgrespro.ru", "phone": "+70454151732"}
0005432848093	C1F6A0	2195 412545	DARYA ARKHIPOVA	{"email": "arkhipova_d.22051962@postgrespro.ru", "phone": "+70572876330"}
0005432848094	67DD98	2869 417072	IVAN MAKAROV	{"email": "makarov-i101979@postgrespro.ru", "phone": "+70218801637"}
0005432848095	67DD98	2132 792620	ALEKSANDR KUZNECOV	{"phone": "+70574870209"}
0005432848096	5B2E82	0807 396781	VITALIY KONOVALOV	{"phone": "+70423649370"}
0005432848097	8D2CF7	4240 238503	MARINA PETROVA	{"email": "marina-petrova.101973@postgrespro.ru", "phone": "+70988943298"}
0005432848098	8D2CF7	8842 692547	TATYANA MIKHAYLOVA	{"email": "mikhaylova_tatyana.081966@postgrespro.ru", "phone": "+70427839418"}
0005432848099	C67C48	9385 300945	DENIS MOISEEV	{"phone": "+70872342372"}
0005432848100	E0902C	6643 655301	ANTONINA GORBUNOVA	{"phone": "+70543008025"}
0005432848101	1E131C	5508 884239	RAISA VOLKOVA	{"phone": "+70274471984"}
0005432848102	682ABC	5898 173829	OKSANA KOROLEVA	{"email": "koroleva.oksana.16121970@postgrespro.ru", "phone": "+70231187917"}
0005432848103	682ABC	5653 663504	ELENA DAVYDOVA	{"email": "edavydova-24091965@postgrespro.ru", "phone": "+70592242321"}
0005432848104	682ABC	5311 875729	EVGENIY ANTONOV	{"email": "antonov.evgeniy1976@postgrespro.ru", "phone": "+70287805904"}
0005432848105	86AA59	4350 266196	PETR ORLOV	{"phone": "+70325742930"}
0005432848106	86AA59	3081 123880	VIKTOR FEDOTOV	{"phone": "+70349115979"}
0005432848107	3593A2	5818 182051	LILIYA EGOROVA	{"phone": "+70163438297"}
0005432848108	3593A2	8362 444557	VYACHESLAV KONOVALOV	{"email": "vyacheslav-konovalov.20041975@postgrespro.ru", "phone": "+70006338731"}
0005432848109	3593A2	6234 020556	LIDIYA DENISOVA	{"phone": "+70625063997"}
0005432848110	AF41EA	4772 280145	GERMAN MIRONOV	{"email": "mironovg_01011962@postgrespro.ru", "phone": "+70366789853"}
0005432848111	E56A44	8512 899639	VLADIMIR ZAYCEV	{"email": "zaycevv041979@postgrespro.ru", "phone": "+70359645902"}
0005432848112	E56A44	6016 670005	ZINAIDA AFANASEVA	{"phone": "+70686419693"}
0005432848350	800EB3	1345 062223	EKATERINA ZHUKOVA	{"phone": "+70679308150"}
0005432848113	7526AA	3286 745198	DMITRIY PAVLOV	{"email": "dmitriy-pavlov1971@postgrespro.ru", "phone": "+70811330538"}
0005432848114	7F016F	9344 848876	ALIYA ABRAMOVA	{"email": "aliya_abramova-051971@postgrespro.ru", "phone": "+70176858398"}
0005432848115	5C5500	9163 202109	VALERIY VASILEV	{"email": "vasilev-v-1975@postgrespro.ru", "phone": "+70678450257"}
0005432848116	5C5500	6260 523989	ANTONINA SOKOLOVA	{"phone": "+70073623939"}
0005432848117	1BD342	9812 593343	ARSENIY NIKITIN	{"email": "nikitin-a-051969@postgrespro.ru", "phone": "+70747223249"}
0005432848118	1BD342	9440 018369	EKATERINA TIKHONOVA	{"phone": "+70778667343"}
0005432848119	1BD342	7233 370105	ELIZAVETA ALEKSEEVA	{"phone": "+70766339530"}
0005432848120	1BD342	2163 404424	LIDIYA BORISOVA	{"email": "borisova.lidiya031976@postgrespro.ru", "phone": "+70801367001"}
0005432848121	686175	0342 604621	NATALYA KUZNECOVA	{"phone": "+70153476093"}
0005432848122	686175	8563 228342	YULIYA MOROZOVA	{"phone": "+70837019452"}
0005432848123	B6F8E8	1381 487266	NATALYA KRASNOVA	{"phone": "+70034744000"}
0005432848124	B6F8E8	4929 529668	ANATOLIY SHEVCHENKO	{"phone": "+70495575291"}
0005432848125	703F8E	2256 266160	PAVEL IVANOV	{"email": "ivanov-p061977@postgrespro.ru", "phone": "+70251344279"}
0005432848126	2847A3	5662 430880	ANDREY KOROLEV	{"email": "korolevandrey-1973@postgrespro.ru", "phone": "+70281316924"}
0005432848127	F61136	2334 327132	ELENA ANISIMOVA	{"email": "elena-anisimova-16101970@postgrespro.ru", "phone": "+70101415393"}
0005432848128	ED6519	0703 823273	ANTONINA KUZNECOVA	{"email": "a.kuznecova24051974@postgrespro.ru", "phone": "+70255036689"}
0005432848129	4D1745	2195 386382	ELENA EFIMOVA	{"phone": "+70150010395"}
0005432848130	C037D2	0848 272530	MIKHAIL VOLKOV	{"phone": "+70177270496"}
0005432848131	D137EC	6458 532847	YULIYA KOZLOVA	{"email": "y.kozlova.31081972@postgrespro.ru", "phone": "+70292417992"}
0005432848132	05C42D	3538 938076	MIKHAIL MATVEEV	{"email": "matveev-mikhail-1962@postgrespro.ru", "phone": "+70211688388"}
0005432848133	512D5B	3414 994482	ANTON PAVLOV	{"email": "pavlova_021973@postgrespro.ru", "phone": "+70958085237"}
0005432848134	96950D	4063 664151	NINA SOLOVEVA	{"phone": "+70316642941"}
0005432848695	C6CFAE	3397 690381	OLGA SOROKINA	{"phone": "+70316805154"}
0005432848135	5B1420	9551 533291	TATYANA ILINA	{"email": "tatyana-ilina1970@postgrespro.ru", "phone": "+70813084555"}
0005432848136	064893	4956 420040	EKATERINA BORISOVA	{"email": "borisova-ekaterina1976@postgrespro.ru", "phone": "+70281754246"}
0005432848137	AF1075	0454 086642	VALERIY ANDREEV	{"email": "andreevv_1983@postgrespro.ru", "phone": "+70131987528"}
0005432848138	05E866	3789 186587	EGOR GERASIMOV	{"phone": "+70694092640"}
0005432848139	26EC09	5769 596037	TATYANA LAZAREVA	{"email": "lazareva.t_10071976@postgrespro.ru", "phone": "+70856392123"}
0005432848140	37499B	5622 878102	NIKOLAY DENISOV	{"phone": "+70676529254"}
0005432848141	37499B	5652 509643	VLADIMIR ABRAMOV	{"phone": "+70453604638"}
0005432848142	D9800C	6062 581841	OLEG IVANOV	{"phone": "+70721137766"}
0005432848143	CB9CF4	6061 352307	SVETLANA KUZNECOVA	{"phone": "+70793929816"}
0005432848144	E7192B	4402 799705	NATALYA POPOVA	{"email": "n-popova_051970@postgrespro.ru", "phone": "+70483579135"}
0005432848145	E7192B	8625 302745	EVGENIYA LUKYANOVA	{"email": "elukyanova.12051966@postgrespro.ru", "phone": "+70345443465"}
0005432848146	6B369C	2053 710164	ALINA ZAKHAROVA	{"email": "a-zakharova_1966@postgrespro.ru", "phone": "+70266201790"}
0005432848147	199E99	0892 679646	ALEKSEY ALEKSEEV	{"email": "aleksey-alekseev.1959@postgrespro.ru", "phone": "+70810610535"}
0005432848148	ACE299	8762 569242	YURIY KONOVALOV	{"email": "yuriy_konovalov-12111968@postgrespro.ru", "phone": "+70367405732"}
0005432848149	ACE299	8936 661783	TATYANA EGOROVA	{"phone": "+70577528740"}
0005432848150	ACE299	3168 345970	ANNA LAZAREVA	{"email": "lazareva-anna-07101964@postgrespro.ru", "phone": "+70826616064"}
0005432848151	32BF75	3359 875576	VERA LEBEDEVA	{"phone": "+70845563827"}
0005432848152	32BF75	1953 045244	SOFIYA POTAPOVA	{"email": "s.potapova_111978@postgrespro.ru", "phone": "+70673197391"}
0005432848153	9C41BC	4752 382460	VIKTOR ANDREEV	{"phone": "+70208402814"}
0005432848154	9C41BC	5540 427379	AYRAT RODIONOV	{"phone": "+70181946095"}
0005432848155	985214	0248 937959	SERGEY MEDVEDEV	{"phone": "+70422505642"}
0005432848156	14FD28	7683 072500	TATYANA VOROBEVA	{"phone": "+70934447454"}
0005432848157	14FD28	3227 477354	MAKSIM BORISOV	{"email": "maksim_borisov_081968@postgrespro.ru", "phone": "+70376123256"}
0005432848158	3CC67E	6002 460054	KIRILL FROLOV	{"phone": "+70072335285"}
0005432848159	ADF1CB	6961 990591	YULIANA FOMINA	{"phone": "+70339524571"}
0005432848160	BE2355	9281 082193	VIKTOR SOKOLOV	{"email": "sokolov.v.25051979@postgrespro.ru", "phone": "+70421127962"}
0005432848161	4B4AAC	7752 969943	NIKITA MIKHAYLOV	{"phone": "+70744517582"}
0005432848162	746C71	6057 538745	NATALYA ORLOVA	{"email": "natalya.orlova-27051973@postgrespro.ru", "phone": "+70731204996"}
0005432848163	746C71	8494 599774	RAISA GERASIMOVA	{"phone": "+70082329621"}
0005432848164	966443	6143 762559	GENNADIY KULIKOV	{"email": "kulikov_g.1971@postgrespro.ru", "phone": "+70353361143"}
0005432848165	9A9A3B	2122 290695	STEPAN NAUMOV	{"phone": "+70990879496"}
0005432848166	B76B46	8052 428210	SERGEY ROMANOV	{"phone": "+70117769366"}
0005432848167	3F9608	4336 061956	MIKHAIL YAKOVLEV	{"phone": "+70440750542"}
0005432848168	CCE6CD	7334 140496	ANDREY GORBUNOV	{"email": "gorbunov_andrey.011975@postgrespro.ru", "phone": "+70007518876"}
0005432848169	9AD666	8033 519823	VALENTIN ANTONOV	{"email": "v.antonov-081972@postgrespro.ru", "phone": "+70960604708"}
0005432848170	9AD666	4854 124201	NURIYA MOROZOVA	{"email": "nuriya_morozova_1973@postgrespro.ru", "phone": "+70390249944"}
0005432848171	8D02C9	5754 413524	GEORGIY SCHERBAKOV	{"phone": "+70898788735"}
0005432848172	BEBC4F	3501 662280	ANDREY ILIN	{"phone": "+70926690194"}
0005432848173	7A96D3	8090 065127	ANNA GRISHINA	{"email": "annagrishina.25071979@postgrespro.ru", "phone": "+70924317219"}
0005432848174	7A96D3	6755 564564	ANDREY BORISOV	{"phone": "+70791184439"}
0005432848175	64A0B7	2671 461397	ANASTASIYA FROLOVA	{"phone": "+70305977491"}
0005432848176	50AF75	1591 118932	EVGENIY EGOROV	{"email": "egorov_evgeniy.1972@postgrespro.ru", "phone": "+70314998998"}
0005432848177	E80068	1034 804407	ELENA SMIRNOVA	{"phone": "+70642387564"}
0005432848178	E80068	8395 364476	YANA CHERNOVA	{"email": "ychernova-09071962@postgrespro.ru", "phone": "+70777959766"}
0005432848179	48C927	0354 346702	IVAN GORBUNOV	{"email": "gorbunovi-19051972@postgrespro.ru", "phone": "+70196326045"}
0005432848180	825F09	6141 316313	NIKOLAY PAVLOV	{"email": "pavlov.nikolay03111975@postgrespro.ru", "phone": "+70474337269"}
0005432848181	825F09	4171 744839	ARTEM KARPOV	{"phone": "+70222816562"}
0005432848182	8893BA	5686 499694	GENNADIY POPOV	{"email": "g.popov_031976@postgrespro.ru", "phone": "+70681202960"}
0005432848183	3A729E	9257 616434	SERGEY SOROKIN	{"phone": "+70871115671"}
0005432848184	F430A4	5957 322493	LYUDMILA ERMAKOVA	{"phone": "+70826714198"}
0005432848185	331F99	4000 672116	ANASTASIYA YAKOVLEVA	{"phone": "+70056784256"}
0005432848186	331F99	1972 109977	STANISLAV BARANOV	{"email": "sbaranov_29121979@postgrespro.ru", "phone": "+70189651467"}
0005432848187	331F99	1010 121290	IGOR BORISOV	{"phone": "+70939200559"}
0005432848188	B68F2A	0995 910020	ILSHAT VASILEV	{"phone": "+70234632355"}
0005432848189	BA1462	6526 802547	VALERIY GERASIMOV	{"phone": "+70107607024"}
0005432848190	BA1462	7707 388178	IGOR VASILEV	{"phone": "+70282626939"}
0005432848191	95C993	4791 498955	DANILA MARTYNOV	{"email": "d_martynov1979@postgrespro.ru", "phone": "+70393210710"}
0005432848192	691C48	1575 843290	MARGARITA EGOROVA	{"email": "m_egorova-111969@postgrespro.ru", "phone": "+70997300033"}
0005432848193	0B30B8	2582 342210	IVAN SEMENOV	{"phone": "+70119022926"}
0005432848194	401C7C	9443 213477	NATALIYA ZAKHAROVA	{"phone": "+70376212789"}
0005432848195	401C7C	5955 774662	SVETLANA KOZLOVA	{"email": "kozlova_s26101971@postgrespro.ru", "phone": "+70070967717"}
0005432848196	D3294D	9247 882543	NATALYA POPOVA	{"phone": "+70682637680"}
0005432848197	D3294D	8462 113522	SVETLANA OSIPOVA	{"phone": "+70653802491"}
0005432848198	73149D	5241 599836	LARISA KUZNECOVA	{"phone": "+70671886101"}
0005432848199	77403A	7860 882036	NATALYA PETROVA	{"email": "n_petrova_1971@postgrespro.ru", "phone": "+70467165691"}
0005432848200	BE299E	2397 838433	DMITRIY KUDRYASHOV	{"phone": "+70878044111"}
0005432848201	BE299E	7804 703334	MARINA MELNIKOVA	{"phone": "+70502080957"}
0005432848202	6C2FB2	0406 551516	RAISA YAKOVLEVA	{"phone": "+70973784676"}
0005432848203	6C2FB2	9633 859936	IVAN ZHURAVLEV	{"email": "zhuravlev-i_101967@postgrespro.ru", "phone": "+70386560335"}
0005432848204	568F43	8226 356797	GALINA KOROLEVA	{"phone": "+70313406462"}
0005432848205	568F43	1248 434828	VALERIY PETROV	{"email": "petrov_valeriy11081966@postgrespro.ru", "phone": "+70857907047"}
0005432848206	16AF30	0959 203769	MAKSIM YAKOVLEV	{"email": "yakovlevmaksim-12021986@postgrespro.ru", "phone": "+70059877279"}
0005432848207	F94E36	7834 202535	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya.121951@postgrespro.ru", "phone": "+70072576835"}
0005432848208	F94E36	0636 764022	GALINA PAVLOVA	{"email": "pavlova.galina.071963@postgrespro.ru", "phone": "+70157273755"}
0005432848209	D26423	9279 555833	RUSTAM VOLKOV	{"phone": "+70868352468"}
0005432848210	6C3C28	0565 644516	ILDAR GAVRILOV	{"email": "i_gavrilov-041980@postgrespro.ru", "phone": "+70482497736"}
0005432848211	6C1FA1	3427 380370	EKATERINA VLASOVA	{"phone": "+70650871219"}
0005432848212	6C1FA1	1629 983818	ANDREY KUZMIN	{"email": "a-kuzmin02031973@postgrespro.ru", "phone": "+70738264954"}
0005432848213	0A56D4	9235 781007	MARINA MAKSIMOVA	{"email": "m-maksimova-1965@postgrespro.ru", "phone": "+70493451069"}
0005432848214	0A56D4	0951 749326	TATYANA POTAPOVA	{"email": "t_potapova_1982@postgrespro.ru", "phone": "+70861511365"}
0005432848215	7D2881	1037 086764	ADELINA AKIMOVA	{"phone": "+70960116066"}
0005432848216	7D2881	6819 569370	ANNA ROMANOVA	{"email": "a_romanova_1970@postgrespro.ru", "phone": "+70455720461"}
0005432848217	2706ED	2515 932378	EVDOKIYA EFIMOVA	{"email": "efimovaevdokiya.10021980@postgrespro.ru", "phone": "+70757314759"}
0005432848218	203713	6177 746406	LARISA YUDINA	{"phone": "+70066855523"}
0005432848219	81FAF4	0452 807670	LYUDMILA IVANOVA	{"phone": "+70726024350"}
0005432848220	81FAF4	8524 162764	ANNA KULIKOVA	{"email": "anna_kulikova-061964@postgrespro.ru", "phone": "+70182743205"}
0005432848221	9BCFB9	3290 294999	MARIYA FADEEVA	{"phone": "+70925083543"}
0005432848222	9BCFB9	8876 292767	MAKSIM ZAKHAROV	{"email": "zakharov_maksim-24021978@postgrespro.ru", "phone": "+70001311651"}
0005432848223	979A99	9508 111555	TATYANA POPOVA	{"phone": "+70763286783"}
0005432848224	ED7C7F	0288 179346	EKATERINA NIKITINA	{"phone": "+70351332081"}
0005432848225	ED7C7F	5026 543043	NATALYA KOROLEVA	{"email": "natalyakoroleva_031973@postgrespro.ru", "phone": "+70907360746"}
0005432848226	FC61F7	2275 960661	DMITRIY NIKOLAEV	{"email": "nikolaev.d_061962@postgrespro.ru", "phone": "+70289570563"}
0005432848227	7B40B9	3851 778683	ALEKSANDR VASILEV	{"email": "a-vasilev.091970@postgrespro.ru", "phone": "+70694154996"}
0005432848228	7B40B9	7528 561200	VLADISLAV EGOROV	{"email": "v-egorov_121970@postgrespro.ru", "phone": "+70334544949"}
0005432848229	651E2D	4310 586053	ANNA TITOVA	{"phone": "+70202108761"}
0005432848230	8CB08B	6365 226174	MARGARITA DMITRIEVA	{"email": "dmitrievam_1973@postgrespro.ru", "phone": "+70436908009"}
0005432848231	44D1E7	4908 190333	SVETLANA VLASOVA	{"phone": "+70977063221"}
0005432848232	63D2E6	6576 432287	IGOR SMIRNOV	{"email": "smirnovigor-27011975@postgrespro.ru", "phone": "+70844137687"}
0005432848351	E4F042	6303 186731	MARINA KALININA	{"phone": "+70460960424"}
0005432848233	4C316D	8201 728801	TAMARA NIKITINA	{"email": "nikitina_tamara16021975@postgrespro.ru", "phone": "+70654656913"}
0005432848234	ED79CF	4568 300175	DMITRIY SOLOVEV	{"email": "solovev-dmitriy_16011977@postgrespro.ru", "phone": "+70644709620"}
0005432848235	ED79CF	2446 762810	ELENA VOLKOVA	{"email": "e_volkova-01101969@postgrespro.ru", "phone": "+70945271798"}
0005432848236	DD5854	4582 833912	ANTONINA IVANOVA	{"phone": "+70378634738"}
0005432848237	CB3230	9221 704559	VIKTORIYA KAZAKOVA	{"email": "kazakova-v_1978@postgrespro.ru", "phone": "+70449188765"}
0005432848238	0D0621	7599 937150	IGOR DMITRIEV	{"phone": "+70605797449"}
0005432848239	8E59B1	3589 989121	NIKITA MEDVEDEV	{"email": "n.medvedev-21061976@postgrespro.ru", "phone": "+70825669702"}
0005432848240	8E59B1	1824 185064	SERGEY TIKHONOV	{"email": "sergey_tikhonov.1983@postgrespro.ru", "phone": "+70193833064"}
0005432848241	6EE8FF	8590 546628	VALENTINA ORLOVA	{"phone": "+70185784095"}
0005432848242	28F65C	4240 925351	LIDIYA KONDRATEVA	{"phone": "+70138057616"}
0005432848243	28F65C	0942 986964	ALEKSANDR KRASNOV	{"phone": "+70705323062"}
0005432848244	28F65C	4024 109266	SERGEY ZAKHAROV	{"email": "s.zakharov26041972@postgrespro.ru", "phone": "+70250468285"}
0005432848245	206390	1574 473569	VALERIY SOLOVEV	{"phone": "+70471355413"}
0005432848246	206390	2351 450617	ANDREY KOROLEV	{"email": "korolev-a_08051978@postgrespro.ru", "phone": "+70493772792"}
0005432848247	4F20E2	1001 550675	GALINA MOROZOVA	{"phone": "+70514778026"}
0005432848248	FE3776	4373 106672	MARIYA KUZNECOVA	{"email": "kuznecova-m_081970@postgrespro.ru", "phone": "+70727662644"}
0005432848249	FE3776	8712 037819	VYACHESLAV KAZAKOV	{"email": "vyacheslav-kazakov_101964@postgrespro.ru", "phone": "+70560321756"}
0005432848250	FE3776	1378 796271	GALINA KALININA	{"email": "kalinina-galina061975@postgrespro.ru", "phone": "+70790744534"}
0005432848251	130897	9393 561488	ELENA PETROVA	{"email": "elena.petrova091971@postgrespro.ru", "phone": "+70694591541"}
0005432848252	817B31	8435 584229	TATYANA ANDREEVA	{"phone": "+70447386356"}
0005432848253	74F838	7823 104048	LYUBOV BOGDANOVA	{"email": "bogdanova-l.011965@postgrespro.ru", "phone": "+70773072678"}
0005432848254	42CFFD	2720 868002	IRINA LUKYANOVA	{"phone": "+70455687793"}
0005432848255	FFB47E	9637 177844	ELENA PETROVA	{"email": "e_petrova1974@postgrespro.ru", "phone": "+70786905745"}
0005432848256	6FC52D	0430 077145	RAISA GUSEVA	{"phone": "+70935420043"}
0005432848257	CF1324	1616 965635	KSENIYA KONOVALOVA	{"phone": "+70270758031"}
0005432848258	CF1324	9296 701584	TAMARA KISELEVA	{"email": "kiselevat051969@postgrespro.ru", "phone": "+70093410620"}
0005432848259	DCCE95	3253 691877	ALEKSANDR GERASIMOV	{"phone": "+70307904064"}
0005432848260	1AB2F8	9919 410495	ARTEM SCHERBAKOV	{"email": "a.scherbakov.1957@postgrespro.ru", "phone": "+70014003629"}
0005432848261	1AB2F8	6254 712202	ZAKHAR SEMENOV	{"email": "zakharsemenov081969@postgrespro.ru", "phone": "+70770724452"}
0005432848262	6F30ED	5793 562811	OLGA BOGDANOVA	{"phone": "+70618119470"}
0005432848263	6F30ED	8965 431866	RAISA EGOROVA	{"phone": "+70612554386"}
0005432848264	E8B996	5817 926137	TAMARA POPOVA	{"email": "t_popova_111957@postgrespro.ru", "phone": "+70511122875"}
0005432848265	042524	0476 501532	MARINA KUZNECOVA	{"phone": "+70002504769"}
0005432848266	CB55DB	7640 341318	VLADIMIR NOVIKOV	{"email": "novikovvladimir-08041979@postgrespro.ru", "phone": "+70984383470"}
0005432848267	6A4F33	9803 308343	OLGA SOROKINA	{"email": "osorokina14041968@postgrespro.ru", "phone": "+70985933713"}
0005432848268	6A4F33	6414 800324	YURIY MAKSIMOV	{"email": "maksimovyuriy.1976@postgrespro.ru", "phone": "+70072503995"}
0005432848269	04DB6F	0394 260769	DMITRIY ANDREEV	{"email": "dmitriy.andreev-021975@postgrespro.ru", "phone": "+70336055143"}
0005432848270	04DB6F	8344 305490	ADELINA ZAYCEVA	{"email": "a.zayceva-041974@postgrespro.ru", "phone": "+70660886829"}
0005432848271	219116	2423 592737	VLADISLAV FROLOV	{"email": "frolov.vladislav-1976@postgrespro.ru", "phone": "+70555121015"}
0005432848272	B9194C	7631 623863	GALINA NIKITINA	{"email": "nikitina-galina-071978@postgrespro.ru", "phone": "+70782814280"}
0005432848273	ED147E	2874 267792	TAMARA VOLKOVA	{"phone": "+70028384715"}
0005432848274	ED147E	9988 687851	ALEKSANDRA FOMINA	{"phone": "+70485188812"}
0005432848275	ED147E	4976 392060	NADEZHDA ANISIMOVA	{"email": "nadezhda.anisimova_17041969@postgrespro.ru", "phone": "+70000887568"}
0005432848276	5A9812	6016 784629	ALEKSANDR NOVIKOV	{"email": "a_novikov-19111966@postgrespro.ru", "phone": "+70409917766"}
0005432848277	AA34AA	7267 400797	ANNA ABRAMOVA	{"phone": "+70130309706"}
0005432848278	54D108	8449 013043	SVETLANA POPOVA	{"phone": "+70457002743"}
0005432848279	54D108	7824 098426	ANTON MAKAROV	{"phone": "+70481167715"}
0005432848280	FA0A1A	6806 018760	NADEZHDA MEDVEDEVA	{"email": "nadezhda_medvedeva_091962@postgrespro.ru", "phone": "+70111738889"}
0005432848281	FA0A1A	3440 509217	VASILIY FOMIN	{"phone": "+70638239913"}
0005432848282	0C92E0	8514 835734	ROZALIYA KULIKOVA	{"email": "rozaliya-kulikova-051972@postgrespro.ru", "phone": "+70550921750"}
0005432848283	069246	9842 905421	IRAIDA KUZMINA	{"phone": "+70725838223"}
0005432848284	25789A	7200 428115	EGOR MOROZOV	{"phone": "+70025319572"}
0005432848285	DE3E1A	6534 343843	NADEZHDA SOLOVEVA	{"email": "nadezhda_soloveva1965@postgrespro.ru", "phone": "+70089065287"}
0005432848286	DE3E1A	3349 367767	DIANA LEBEDEVA	{"phone": "+70658142626"}
0005432848287	3B3346	9177 850676	TATYANA PETROVA	{"email": "petrova-t-1968@postgrespro.ru", "phone": "+70548781943"}
0005432848288	3B3346	3493 970498	VALENTINA KUZNECOVA	{"email": "kuznecovav-031984@postgrespro.ru", "phone": "+70565958729"}
0005432848289	081787	5979 901350	MARIYA KUZMINA	{"phone": "+70981424074"}
0005432848290	081787	6893 802388	MARINA FOMINA	{"email": "fomina-marina-1976@postgrespro.ru", "phone": "+70839347622"}
0005432848291	9D72D8	2338 394787	RADIK FROLOV	{"phone": "+70491743631"}
0005432848292	8D82A6	7266 576181	VERA ABRAMOVA	{"email": "abramova.v_1969@postgrespro.ru", "phone": "+70308929201"}
0005432848293	46D86E	3515 711552	ALEVTINA GAVRILOVA	{"email": "gavrilova.a081966@postgrespro.ru", "phone": "+70075769303"}
0005432848294	C249A4	6732 510763	DARYA AKIMOVA	{"phone": "+70279778538"}
0005432848295	C249A4	9997 660569	NATALYA POPOVA	{"phone": "+70349689271"}
0005432848296	C249A4	2315 796850	NIKOLAY ALEKSEEV	{"phone": "+70701121953"}
0005432848297	7D1943	8734 649938	ALEKSANDRA KOZLOVA	{"email": "aleksandrakozlova_1965@postgrespro.ru", "phone": "+70973068280"}
0005432848298	1AA06C	8898 184815	IGOR BORISOV	{"phone": "+70384334624"}
0005432848299	680FCA	8021 320287	GERMAN ZAKHAROV	{"email": "g-zakharov09021984@postgrespro.ru", "phone": "+70018227464"}
0005432848300	5F10FA	2345 846476	ZHANNA POTAPOVA	{"email": "potapova_z031961@postgrespro.ru", "phone": "+70167309120"}
0005432848301	484791	0372 244022	DMITRIY VOLKOV	{"phone": "+70544186363"}
0005432848302	9DF0F2	1211 549840	NATALYA ARKHIPOVA	{"email": "n_arkhipova-1969@postgrespro.ru", "phone": "+70430390491"}
0005432848303	B59F24	0457 879612	SVETLANA FOMINA	{"phone": "+70154862500"}
0005432848304	C8ABA6	7768 821478	VLADIMIR SMIRNOV	{"email": "vladimirsmirnov_27081969@postgrespro.ru", "phone": "+70392647988"}
0005432848305	E2E734	3370 451002	VASILIY FROLOV	{"email": "frolov-vasiliy.1971@postgrespro.ru", "phone": "+70107285057"}
0005432848306	576718	4797 918079	IGOR FROLOV	{"email": "frolov-igor.23061975@postgrespro.ru", "phone": "+70663980950"}
0005432848307	576718	5354 196220	SERGEY BARANOV	{"phone": "+70311559084"}
0005432848308	3C39FB	8533 073131	ILMIRA MARTYNOVA	{"email": "martynova-ilmira091968@postgrespro.ru", "phone": "+70676489492"}
0005432848309	25E5AF	7105 563324	VLADIMIR DMITRIEV	{"email": "v-dmitriev_091970@postgrespro.ru", "phone": "+70408880816"}
0005432848310	D86CF0	6739 846354	BORIS FEDOTOV	{"email": "boris.fedotov091974@postgrespro.ru", "phone": "+70997733735"}
0005432848311	3F96BD	8932 034728	IVAN KUDRYASHOV	{"email": "kudryashovi-22091965@postgrespro.ru", "phone": "+70328343240"}
0005432848312	853D92	3917 520704	ROMAN FEDOROV	{"email": "fedorov_r15091962@postgrespro.ru", "phone": "+70841817412"}
0005432848313	159AB7	0458 166213	ALEKSANDR NAUMOV	{"email": "naumov.a-061981@postgrespro.ru", "phone": "+70767971756"}
0005432848314	65E217	5390 324039	TATYANA MAKAROVA	{"phone": "+70653069532"}
0005432848315	65E217	8248 301342	ALEKSEY TIMOFEEV	{"email": "timofeeva-1970@postgrespro.ru", "phone": "+70806045557"}
0005432848316	E16DD9	1983 580870	VALENTIN SAVELEV	{"email": "savelev_v_1969@postgrespro.ru", "phone": "+70284320944"}
0005432848317	E16DD9	8343 462288	VASILIY GRIGOREV	{"email": "vgrigorev.031969@postgrespro.ru", "phone": "+70630704710"}
0005432848318	18B961	8749 086893	ALEKSANDR NAZAROV	{"phone": "+70882305729"}
0005432848319	18B961	6077 549570	ZINAIDA AKIMOVA	{"email": "zakimova-091980@postgrespro.ru", "phone": "+70947307619"}
0005432848320	ECE30F	9423 178587	ALEKSEY SCHERBAKOV	{"phone": "+70941768048"}
0005432848321	7055DE	0828 758668	LIDIYA BELYAEVA	{"email": "belyaeva-lidiya-21081967@postgrespro.ru", "phone": "+70928604368"}
0005432848322	6EECBC	6051 503376	DIANA STEPANOVA	{"phone": "+70322577562"}
0005432848323	DFCEC7	1726 945836	OLGA PAVLOVA	{"email": "pavlova.olga_1966@postgrespro.ru", "phone": "+70851651347"}
0005432848324	7C29F6	9035 343402	NIKOLAY MAKSIMOV	{"email": "maksimov_nikolay_07111961@postgrespro.ru", "phone": "+70849090262"}
0005432848325	702A02	4861 984993	VIKTOR STEPANOV	{"email": "stepanovv_011977@postgrespro.ru", "phone": "+70905501666"}
0005432848326	1EA9C7	1154 626670	KRISTINA MOISEEVA	{"phone": "+70729812271"}
0005432848327	212DE7	1093 731355	ULYANA SIDOROVA	{"email": "sidorova_ulyana-09081967@postgrespro.ru", "phone": "+70866279039"}
0005432848328	E23206	5383 596971	ELENA IVANOVA	{"phone": "+70175396142"}
0005432848329	8F36E8	1114 148111	SERGEY KUZNECOV	{"phone": "+70981942798"}
0005432848330	8F36E8	3752 723366	VLADIMIR ANDREEV	{"phone": "+70025258347"}
0005432848331	0A7480	1483 283596	VALENTINA SIDOROVA	{"email": "sidorovavalentina.18091968@postgrespro.ru", "phone": "+70602822053"}
0005432848332	5805C7	9678 828122	MARINA LAZAREVA	{"phone": "+70082025122"}
0005432848333	9AD838	5786 162391	DENIS GERASIMOV	{"email": "gerasimov.denis.1974@postgrespro.ru", "phone": "+70090169673"}
0005432848334	B36D90	6888 007144	ALEKSANDR KOROLEV	{"phone": "+70920387708"}
0005432848335	B36D90	1272 745387	SERGEY KUZNECOV	{"email": "s.kuznecov-021978@postgrespro.ru", "phone": "+70793429285"}
0005432848336	B36D90	0608 815353	IVAN KULIKOV	{"email": "kulikov_i111969@postgrespro.ru", "phone": "+70824900622"}
0005432848337	4E40D2	9854 896097	IVAN STEPANOV	{"phone": "+70762179462"}
0005432848338	44EB71	1636 587121	NIKITA ZHURAVLEV	{"phone": "+70815776376"}
0005432848339	44EB71	9654 421148	ANNA DANILOVA	{"phone": "+70937613404"}
0005432848340	F97950	9142 094514	LYUDMILA ROMANOVA	{"email": "romanoval_091969@postgrespro.ru", "phone": "+70103284935"}
0005432848341	73F83B	4957 942816	VALENTINA FADEEVA	{"email": "v-fadeeva.021978@postgrespro.ru", "phone": "+70452168467"}
0005432848342	60DAF5	2874 183720	NIKOLAY IVANOV	{"phone": "+70267652531"}
0005432848343	D2606C	2474 876121	ALEKSANDR NIKOLAEV	{"phone": "+70415351600"}
0005432848344	6158A9	1519 763046	OLGA ISAEVA	{"email": "olga_isaeva_071961@postgrespro.ru", "phone": "+70245498748"}
0005432848345	48E37E	5384 772901	ELENA OSIPOVA	{"phone": "+70233923915"}
0005432848346	48E37E	3989 652843	EVGENIY KARPOV	{"email": "e_karpov-1979@postgrespro.ru", "phone": "+70168678823"}
0005432848347	A81BF8	5932 598427	RUSLAN MAKSIMOV	{"email": "maksimov_r-07101972@postgrespro.ru", "phone": "+70227096313"}
0005432848573	71CEDC	2148 565193	DENIS KUZNECOV	{"phone": "+70510935657"}
0005432848348	05D2A0	2949 263563	GENNADIY YAKOVLEV	{"email": "gennadiy.yakovlev01081966@postgrespro.ru", "phone": "+70863828285"}
0005432848349	05D2A0	0005 867653	LYUDMILA POPOVA	{"phone": "+70031415317"}
0005432848352	717F16	1825 845679	ANATOLIY KULIKOV	{"email": "kulikov.anatoliy.12121958@postgrespro.ru", "phone": "+70724008478"}
0005432848353	B76AAF	3516 888926	POLINA MAKAROVA	{"phone": "+70791762097"}
0005432848354	9699C9	8925 244152	ANDREY SOKOLOV	{"email": "sokolov.andrey.15071976@postgrespro.ru", "phone": "+70921473302"}
0005432848355	FF9AE0	9330 526155	FATIMA ALEKSANDROVA	{"phone": "+70060471683"}
0005432848356	FF9AE0	2300 822718	ELIZAVETA MOISEEVA	{"email": "moiseevae-051965@postgrespro.ru", "phone": "+70177130495"}
0005432848357	9B50EB	0297 512989	KAMILLA LEBEDEVA	{"phone": "+70500300008"}
0005432848358	E5EEB4	2230 634079	ALEKSANDRA YUDINA	{"phone": "+70426360694"}
0005432848359	E5EEB4	9401 109879	VALERIY STEPANOV	{"email": "v.stepanov_061964@postgrespro.ru", "phone": "+70203800421"}
0005432848360	E5EEB4	9351 997730	OLGA TARASOVA	{"email": "olga-tarasova-1964@postgrespro.ru", "phone": "+70369174239"}
0005432848361	902522	3312 005892	ALEKSANDR AFANASEV	{"phone": "+70208763389"}
0005432848362	902522	5368 914999	ILDAR VLASOV	{"phone": "+70826488377"}
0005432848363	902522	0814 652284	TATYANA ISAEVA	{"email": "isaevatatyana.1974@postgrespro.ru", "phone": "+70575501703"}
0005432848364	F2BB4B	8662 394747	ANDREY NOVIKOV	{"email": "novikov_andrey-1969@postgrespro.ru", "phone": "+70582094109"}
0005432848365	527B64	0446 098565	NIKOLAY DMITRIEV	{"email": "dmitriev_nikolay1966@postgrespro.ru", "phone": "+70117649474"}
0005432848366	527B64	5949 825642	SOFYA SOROKINA	{"email": "s-sorokina-101970@postgrespro.ru", "phone": "+70603068247"}
0005432848367	7D42CD	4953 101148	VALENTINA KULIKOVA	{"email": "kulikovav-071980@postgrespro.ru", "phone": "+70818046761"}
0005432848368	5788AB	2065 821589	VIKTOR POPOV	{"email": "v_popov-17081975@postgrespro.ru", "phone": "+70221144961"}
0005432848369	32D965	8602 845350	IGOR SCHERBAKOV	{"phone": "+70351321212"}
0005432848370	32D965	1742 501200	IGOR MIRONOV	{"phone": "+70866122247"}
0005432848371	73B07E	5850 175486	VLADISLAV BORISOV	{"phone": "+70500714696"}
0005432848372	3100B5	3240 018766	ALEKSANDR CHERNOV	{"email": "aleksandrchernov-22111969@postgrespro.ru", "phone": "+70787963353"}
0005432848373	5DDC3F	6626 628800	EKATERINA VOROBEVA	{"phone": "+70077339206"}
0005432848374	5DDC3F	4370 968982	ALEKSANDR KRASNOV	{"email": "aleksandrkrasnov041973@postgrespro.ru", "phone": "+70317855429"}
0005432848375	C16A70	4484 957265	VLADIMIR SHEVCHENKO	{"phone": "+70601211218"}
0005432848376	C16A70	7982 241613	EKATERINA STEPANOVA	{"email": "e_stepanova.111973@postgrespro.ru", "phone": "+70268131487"}
0005432848377	72D482	7057 809162	VALENTINA BORISOVA	{"phone": "+70057120746"}
0005432848378	D6BC33	4087 549907	VYACHESLAV DAVYDOV	{"email": "davydov.v.011973@postgrespro.ru", "phone": "+70191251247"}
0005432848379	D6BC33	9819 418647	NIKOLAY ZAYCEV	{"email": "nikolay-zaycev071978@postgrespro.ru", "phone": "+70138786340"}
0005432848380	92CC13	6527 477383	MAKSIM ZAYCEV	{"email": "zaycev-m13061968@postgrespro.ru", "phone": "+70065509569"}
0005432848381	92CC13	3841 907701	MARIYA TARASOVA	{"phone": "+70927180681"}
0005432848382	92CC13	4819 736282	ALEKSANDR ZHURAVLEV	{"phone": "+70205875745"}
0005432848383	27EF2D	3627 109329	ALINA SERGEEVA	{"email": "alina.sergeeva-121973@postgrespro.ru", "phone": "+70680475932"}
0005432848384	27EF2D	9511 575759	TATYANA MASLOVA	{"phone": "+70459103556"}
0005432848385	53F4F8	2244 904493	ILYA ORLOV	{"phone": "+70243284920"}
0005432848386	B44F8C	1981 307155	GALINA MAKAROVA	{"phone": "+70200738379"}
0005432848387	13F50E	4442 383938	SVETLANA VASILEVA	{"phone": "+70266601849"}
0005432848388	13F50E	3880 735986	MARIYA DAVYDOVA	{"email": "mariya-davydova-041967@postgrespro.ru", "phone": "+70728171650"}
0005432848389	E10BB0	0649 342828	MIKHAIL STEPANOV	{"email": "mstepanov.30101987@postgrespro.ru", "phone": "+70981083339"}
0005432848390	E10BB0	5285 378885	SVETLANA KOZLOVA	{"email": "s.kozlova.17011981@postgrespro.ru", "phone": "+70281024810"}
0005432848391	E10BB0	7815 402479	ELENA MAKSIMOVA	{"email": "maksimova_elena.1977@postgrespro.ru", "phone": "+70589473698"}
0005432848392	0A014E	4289 947872	DMITRIY ILIN	{"phone": "+70419005881"}
0005432848393	5C6CD3	6680 529717	DIANA DANILOVA	{"phone": "+70053170369"}
0005432848394	9DC8DB	3973 286313	ELENA YAKOVLEVA	{"phone": "+70022776081"}
0005432848395	1D22A4	9362 025990	MARIYA NIKIFOROVA	{"phone": "+70599999625"}
0005432848396	73B9DB	8340 810947	EKATERINA GERASIMOVA	{"phone": "+70611688045"}
0005432848397	D9385E	3707 397941	VASILIY RODIONOV	{"email": "v.rodionov_021965@postgrespro.ru", "phone": "+70816964863"}
0005432848398	D9385E	2738 923380	VADIM DENISOV	{"email": "denisovv.06051974@postgrespro.ru", "phone": "+70112985915"}
0005432848399	9F5A98	7675 566935	TAMARA KISELEVA	{"phone": "+70836501817"}
0005432848400	9F5A98	2551 319122	VIKTOR BONDARENKO	{"phone": "+70811401572"}
0005432848401	36AAFD	2360 880612	ALEKSANDR KAZAKOV	{"phone": "+70141915506"}
0005432848402	7D0174	6425 607603	NATALYA OVCHINNIKOVA	{"phone": "+70985697082"}
0005432848403	7D0174	3567 656386	TATYANA NIKIFOROVA	{"phone": "+70382527136"}
0005432848404	313B26	4818 308184	MARGARITA KONOVALOVA	{"email": "m_konovalova1967@postgrespro.ru", "phone": "+70249884763"}
0005432848405	627A0F	3164 501804	ANNA GAVRILOVA	{"email": "a_gavrilova.12111963@postgrespro.ru", "phone": "+70467744111"}
0005432848406	627A0F	5300 651081	IVAN ALEKSEEV	{"phone": "+70166579519"}
0005432848407	613C82	4955 932118	DARYA IVANOVA	{"phone": "+70614958669"}
0005432848408	2E0C67	2902 768243	IGOR GAVRILOV	{"phone": "+70339671639"}
0005432848409	14F0F5	7911 951245	MAKSIM VASILEV	{"email": "vasilev-m_18031970@postgrespro.ru", "phone": "+70573241050"}
0005432848410	14F0F5	4271 377628	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov.10041967@postgrespro.ru", "phone": "+70127352205"}
0005432848411	FC4E8A	6064 987851	ALEKSANDR BORISOV	{"phone": "+70047791263"}
0005432848412	71858B	5063 805101	YURIY MAKAROV	{"email": "yuriy-makarov13021968@postgrespro.ru", "phone": "+70101353062"}
0005432848413	1A3CD9	6636 073936	ALEKSEY MIKHAYLOV	{"phone": "+70348441778"}
0005432848414	1A3CD9	2885 033807	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov19081967@postgrespro.ru", "phone": "+70356551651"}
0005432848415	999E77	6516 330006	EVGENIYA KUZNECOVA	{"email": "kuznecova-evgeniya_011995@postgrespro.ru", "phone": "+70741723784"}
0005432848416	999E77	3291 014703	OLGA ORLOVA	{"phone": "+70891185663"}
0005432848417	498236	6790 503794	IVAN ROMANOV	{"phone": "+70192946894"}
0005432848418	498236	5715 774107	PAVEL ROMANOV	{"phone": "+70177819463"}
0005432848419	4C52D6	0296 709580	LYUBOV TITOVA	{"email": "titoval071966@postgrespro.ru", "phone": "+70446736600"}
0005432848420	D9B166	4825 158205	MARINA LAZAREVA	{"email": "marina_lazareva-31081966@postgrespro.ru", "phone": "+70589986520"}
0005432848421	D9B166	4417 780513	VLADIMIR SEMENOV	{"phone": "+70752083876"}
0005432848422	8BA501	5265 713526	KONSTANTIN IVANOV	{"phone": "+70389950105"}
0005432848423	BF6B67	1818 463897	VIKTORIYA ILINA	{"email": "v_ilina.1974@postgrespro.ru", "phone": "+70514698650"}
0005432848424	BF6B67	1448 354910	YURIY SCHERBAKOV	{"email": "y-scherbakov_1970@postgrespro.ru", "phone": "+70800626199"}
0005432848425	8B62E4	0342 377261	SERGEY SERGEEV	{"phone": "+70193789913"}
0005432848426	AAE643	6601 050065	IVAN FOMIN	{"phone": "+70983123667"}
0005432848427	AAE643	9405 655268	ELENA GERASIMOVA	{"email": "gerasimova_e081978@postgrespro.ru", "phone": "+70201281478"}
0005432848428	2AD353	9229 848948	VLADIMIR KOZLOV	{"email": "kozlov-vladimir.19021976@postgrespro.ru", "phone": "+70145038662"}
0005432848429	2AD353	6897 206986	YULIYA KALININA	{"email": "kalinina_y-041973@postgrespro.ru", "phone": "+70543261251"}
0005432848430	2AD353	6470 834338	ZINAIDA SEMENOVA	{"phone": "+70900873090"}
0005432848431	1E30F3	2660 862337	VALERIY DENISOV	{"email": "v_denisov1977@postgrespro.ru", "phone": "+70444501988"}
0005432848432	FE3EF1	4148 396251	TAMARA ANDREEVA	{"phone": "+70996648406"}
0005432848433	FE3EF1	2116 067143	SERGEY VLASOV	{"email": "s-vlasov1980@postgrespro.ru", "phone": "+70103429672"}
0005432848434	097764	2845 746782	ANTON GERASIMOV	{"email": "gerasimov_a-1973@postgrespro.ru", "phone": "+70399474696"}
0005432848435	8611E2	8113 588338	ANDREY NIKOLAEV	{"email": "a_nikolaev_021967@postgrespro.ru", "phone": "+70877842662"}
0005432848436	D91D28	6253 080715	VLADIMIR PETROV	{"email": "petrov_v.071966@postgrespro.ru", "phone": "+70850541491"}
0005432848437	D91D28	3064 879439	NATALYA NAZAROVA	{"phone": "+70066429653"}
0005432848438	3DC295	3872 639346	LEONID POPOV	{"email": "l_popov_031968@postgrespro.ru", "phone": "+70736517683"}
0005432848439	E0C36B	7206 558963	KIRILL SEMENOV	{"email": "k_semenov.05021968@postgrespro.ru", "phone": "+70233689855"}
0005432848440	E0C36B	0287 002503	ALEKSANDR DAVYDOV	{"phone": "+70617226590"}
0005432848441	E0C36B	4206 979999	ALEKSANDR KOROLEV	{"phone": "+70435010816"}
0005432848442	3C6D23	4011 919987	ELENA VOLKOVA	{"email": "evolkova-05081973@postgrespro.ru", "phone": "+70141553901"}
0005432848443	3C6D23	5043 864104	ANATOLIY VOROBEV	{"phone": "+70008498309"}
0005432848444	774C4A	4928 918796	INNA MEDVEDEVA	{"phone": "+70912765491"}
0005432848445	59CDAD	9100 043001	IRINA IVANOVA	{"phone": "+70045756089"}
0005432848446	59CDAD	6632 167581	NINA NIKOLAEVA	{"email": "nikolaevan091958@postgrespro.ru", "phone": "+70664832743"}
0005432848447	3F285A	6077 726427	ANASTASIYA DENISOVA	{"email": "anastasiyadenisova.15121959@postgrespro.ru", "phone": "+70386827021"}
0005432848448	35E3FD	2897 709208	LYUDMILA SEMENOVA	{"phone": "+70042106760"}
0005432848449	7046AE	4925 319255	TAMARA PAVLOVA	{"email": "t-pavlova_1972@postgrespro.ru", "phone": "+70122052381"}
0005432848450	4C0A57	0633 254361	MARIYA MOROZOVA	{"phone": "+70027009499"}
0005432848451	4C0A57	1575 047242	NATALIYA EFREMOVA	{"email": "n_efremova.041966@postgrespro.ru", "phone": "+70837968174"}
0005432848452	4C92C2	4443 170910	GALINA PAVLOVA	{"phone": "+70438250225"}
0005432848453	4C92C2	2637 411053	YULIYA ANISIMOVA	{"email": "yuliya_anisimova19111972@postgrespro.ru", "phone": "+70408527714"}
0005432848454	A239FC	5386 859461	ANASTASIYA ABRAMOVA	{"phone": "+70655977596"}
0005432848455	89FE68	7020 992734	OLGA DMITRIEVA	{"phone": "+70899918093"}
0005432848456	89FE68	3739 665728	ALBINA SEMENOVA	{"phone": "+70921305225"}
0005432848457	AE3FC6	5847 797582	YAN VOLKOV	{"phone": "+70575624234"}
0005432848458	AE3FC6	8577 120576	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov.121970@postgrespro.ru", "phone": "+70721884220"}
0005432848459	AE3FC6	0465 056801	MARIYA KONDRATEVA	{"email": "m_kondrateva13071964@postgrespro.ru", "phone": "+70335777654"}
0005432848460	2E7A6D	3760 781922	EVGENIY FOMIN	{"email": "evgeniyfomin_1968@postgrespro.ru", "phone": "+70922553493"}
0005432848461	2E7A6D	3538 165434	OLGA VOLKOVA	{"email": "olga-volkova-30071960@postgrespro.ru", "phone": "+70111971425"}
0005432848462	1EC291	0430 296293	PAVEL KOZLOV	{"email": "kozlov-pavel-1967@postgrespro.ru", "phone": "+70922156497"}
0005432848463	1EC291	8553 639368	VIKTORIYA ROMANOVA	{"email": "romanovav051967@postgrespro.ru", "phone": "+70385652615"}
0005432848464	811D2E	9269 458269	MARIYA FEDOROVA	{"phone": "+70466274297"}
0005432848465	4671CD	9296 901180	LEONID VOLKOV	{"email": "l-volkov1985@postgrespro.ru", "phone": "+70212781795"}
0005432848466	4671CD	4889 705045	NATALYA PETROVA	{"email": "petrova_natalya.25091971@postgrespro.ru", "phone": "+70070365162"}
0005432848467	A2E3E8	2980 588647	VLADIMIR MARTYNOV	{"phone": "+70659724619"}
0005432848468	5EB47B	8939 665823	SALAVAT RODIONOV	{"phone": "+70763803660"}
0005432848469	542340	4338 449783	NADEZHDA ISAEVA	{"phone": "+70793831947"}
0005432848470	542340	6381 111360	YULIYA YUDINA	{"email": "yuliyayudina.25071977@postgrespro.ru", "phone": "+70236817995"}
0005432848471	067102	9570 752791	ELENA SEMENOVA	{"email": "esemenova.101966@postgrespro.ru", "phone": "+70598351457"}
0005432848472	0673A7	0912 072670	ANASTASIYA TIKHONOVA	{"email": "tikhonova.a-081977@postgrespro.ru", "phone": "+70436531120"}
0005432848473	0673A7	3933 065432	ANASTASIYA SIDOROVA	{"phone": "+70109951569"}
0005432848474	A460D7	9810 671836	VERA KUZNECOVA	{"phone": "+70284523514"}
0005432848475	07DC73	9734 791311	YURIY MATVEEV	{"phone": "+70282164027"}
0005432848476	2BEE96	6229 200450	ALBINA SIDOROVA	{"email": "sidorovaa-21021970@postgrespro.ru", "phone": "+70454642199"}
0005432848477	2BEE96	5488 941596	LYUDMILA ALEKSANDROVA	{"email": "aleksandrova-lyudmila-03041980@postgrespro.ru", "phone": "+70727370256"}
0005432848478	9C084B	5056 969122	OLGA GERASIMOVA	{"email": "olga.gerasimova.1967@postgrespro.ru", "phone": "+70844831725"}
0005432848479	E5EADD	0348 235801	VASILIY ORLOV	{"phone": "+70528217821"}
0005432848480	E5EADD	2521 715321	PETR DMITRIEV	{"phone": "+70415338034"}
0005432848481	4D5C8D	9982 010047	ALINA DANILOVA	{"phone": "+70744065274"}
0005432848482	7F676F	1140 027190	RAFAIL MAKSIMOV	{"email": "r.maksimov-21101977@postgrespro.ru", "phone": "+70995422062"}
0005432848483	E3EA12	1798 280164	VIKTOR IVANOV	{"phone": "+70922466326"}
0005432848484	E3EA12	0529 218326	ANATOLIY TIMOFEEV	{"phone": "+70316262595"}
0005432848485	EDE1B9	1007 830623	NINA SOLOVEVA	{"phone": "+70967354479"}
0005432848486	EDE1B9	8478 951039	NIKOLAY NIKITIN	{"phone": "+70775873400"}
0005432848487	523211	3745 977649	RAIS NIKOLAEV	{"phone": "+70923367429"}
0005432848488	B76546	5177 104374	NIKITA KOZLOV	{"email": "kozlov-n121979@postgrespro.ru", "phone": "+70001662957"}
0005432848489	B11C29	0946 124308	NATALYA KUZMINA	{"email": "natalya.kuzmina-121973@postgrespro.ru", "phone": "+70141194985"}
0005432848490	11D5CE	5652 733072	EVGENIY CHERNOV	{"phone": "+70837655938"}
0005432848491	249F79	9964 658111	NATALYA ERMAKOVA	{"email": "ermakovan.071965@postgrespro.ru", "phone": "+70435542396"}
0005432848492	87D895	7203 353327	LYUDMILA SOLOVEVA	{"phone": "+70600153394"}
0005432848493	650E80	3237 076114	VALENTINA POPOVA	{"email": "valentina.popova_021979@postgrespro.ru", "phone": "+70970173029"}
0005432848494	690897	7958 280519	PETR MAKAROV	{"email": "petrmakarov_11011977@postgrespro.ru", "phone": "+70902851176"}
0005432848495	C394F7	0196 324068	ALEKSEY SMIRNOV	{"email": "aleksey-smirnov111976@postgrespro.ru", "phone": "+70815414465"}
0005432848496	C394F7	1285 540657	IRAIDA AKIMOVA	{"email": "akimova.i1973@postgrespro.ru", "phone": "+70658952524"}
0005432848497	1A292E	8316 246241	ALEKSEY GORBUNOV	{"email": "aleksey.gorbunov081976@postgrespro.ru", "phone": "+70225149622"}
0005432848498	3253C9	0208 556933	KSENIYA FILATOVA	{"phone": "+70428308024"}
0005432848499	4A86FB	8327 914713	TATYANA ISAEVA	{"phone": "+70359579289"}
0005432848500	4A86FB	9981 348462	TATYANA VOROBEVA	{"phone": "+70016882043"}
0005432848501	4A86FB	0426 794657	ANTON KONOVALOV	{"phone": "+70355302554"}
0005432848502	AF1D86	6707 483340	OLGA IVANOVA	{"phone": "+70488432364"}
0005432848503	AF1D86	6840 829875	NATALYA MAKAROVA	{"email": "natalyamakarova.1964@postgrespro.ru", "phone": "+70670343650"}
0005432848504	8A80B3	8365 820987	ALBERT NAUMOV	{"email": "a.naumov_1978@postgrespro.ru", "phone": "+70831379967"}
0005432848505	8A80B3	7155 307943	VIKTOR PETROV	{"phone": "+70011951835"}
0005432848506	D171A2	2422 369226	TATYANA BARANOVA	{"phone": "+70367820499"}
0005432848507	16D8B9	7570 117210	MAYA MAKAROVA	{"email": "makarova_maya-1969@postgrespro.ru", "phone": "+70931099240"}
0005432848508	CB1960	7121 968396	YAROSLAV ANDREEV	{"phone": "+70760729147"}
0005432848509	CB1960	5943 894375	RUSLAN MIKHAYLOV	{"email": "mikhaylov_ruslan_021971@postgrespro.ru", "phone": "+70005560568"}
0005432848510	5EDCB5	7985 701786	OLGA FILATOVA	{"phone": "+70052572127"}
0005432848511	775207	6473 635124	DARYA KRASNOVA	{"email": "krasnova_d061975@postgrespro.ru", "phone": "+70837453147"}
0005432848512	775207	6593 293265	ANNA IVANOVA	{"email": "a.ivanova_1964@postgrespro.ru", "phone": "+70812199280"}
0005432848513	31B2CB	4968 977878	TATYANA PAVLOVA	{"phone": "+70116005648"}
0005432848514	A4E3E2	8108 183654	NIKOLAY MAKSIMOV	{"phone": "+70208688098"}
0005432848515	7D69DE	8863 046218	VIKTORIYA KISELEVA	{"email": "viktoriya-kiseleva03021975@postgrespro.ru", "phone": "+70013308297"}
0005432848516	7D69DE	1586 093434	ILYA KUZNECOV	{"email": "kuznecovilya-031963@postgrespro.ru", "phone": "+70224922859"}
0005432848517	0100FE	3523 327608	NATALYA KONDRATEVA	{"email": "kondrateva_natalya091967@postgrespro.ru", "phone": "+70448153846"}
0005432848518	0100FE	0379 665089	SERGEY KUZNECOV	{"email": "kuznecov-s-021968@postgrespro.ru", "phone": "+70369953547"}
0005432848519	F1EE35	4033 888280	LYUBOV OVCHINNIKOVA	{"email": "lyubovovchinnikova-101981@postgrespro.ru", "phone": "+70027089382"}
0005432848520	B1BA89	8964 534538	ROMAN POPOV	{"phone": "+70495499780"}
0005432848521	0F8DCF	5451 837949	VALENTINA PETROVA	{"email": "petrovavalentina1965@postgrespro.ru", "phone": "+70620920595"}
0005432848522	0B9500	8372 794957	LYUDMILA VOLKOVA	{"phone": "+70248826979"}
0005432848523	263D8A	1736 049941	DMITRIY ZAKHAROV	{"email": "d_zakharov.25031973@postgrespro.ru", "phone": "+70838688363"}
0005432848524	263D8A	8698 542815	MARINA ISAEVA	{"email": "marina_isaeva31031979@postgrespro.ru", "phone": "+70132464541"}
0005432848525	B30B53	7220 871948	ANATOLIY VASILEV	{"email": "anatoliy_vasilev-16031963@postgrespro.ru", "phone": "+70692207178"}
0005432848526	B30B53	8027 980878	SERGEY NOVIKOV	{"email": "sergey.novikov1974@postgrespro.ru", "phone": "+70119730592"}
0005432848528	2854D7	5429 702968	ELENA MATVEEVA	{"email": "matveeva_e-07081974@postgrespro.ru", "phone": "+70863564854"}
0005432848529	CECBC8	6247 349779	VIKTOR MAKAROV	{"phone": "+70898442889"}
0005432848530	CECBC8	0156 252815	SERGEY MELNIKOV	{"phone": "+70542251366"}
0005432848531	B3467D	2803 267504	ELDAR MAKAROV	{"phone": "+70275327179"}
0005432848532	B3467D	8399 625374	IRINA ANDREEVA	{"email": "i-andreeva.25121974@postgrespro.ru", "phone": "+70596663772"}
0005432848533	CFBCA1	7947 708855	VITALIY ANDREEV	{"email": "andreev-v-10081963@postgrespro.ru", "phone": "+70113481904"}
0005432848534	8A096B	0526 995986	EKATERINA VOROBEVA	{"phone": "+70151011736"}
0005432848535	8A096B	6382 487020	YULIYA KOLESNIKOVA	{"email": "kolesnikova-yuliya_1978@postgrespro.ru", "phone": "+70795984130"}
0005432848536	6ABEEA	4934 949489	NADEZHDA SMIRNOVA	{"phone": "+70556963812"}
0005432848537	0788DF	3396 352340	ELENA ANISIMOVA	{"phone": "+70025680723"}
0005432848538	0788DF	2360 558775	KONSTANTIN FROLOV	{"phone": "+70375071857"}
0005432848539	48A1A6	2433 732851	OLGA DENISOVA	{"email": "denisova_o_061958@postgrespro.ru", "phone": "+70234034560"}
0005432848540	48A1A6	2669 609050	ELENA POLYAKOVA	{"email": "polyakova_elena_1972@postgrespro.ru", "phone": "+70064025031"}
0005432848541	1EE62F	9349 440962	NIKITA ZAYCEV	{"email": "n_zaycev-22021966@postgrespro.ru", "phone": "+70194433995"}
0005432848542	3CE20E	6086 781209	NADEZHDA MOISEEVA	{"phone": "+70515084083"}
0005432848543	142C0C	1257 032999	NIKOLAY KUZNECOV	{"email": "kuznecov-n24111971@postgrespro.ru", "phone": "+70503028167"}
0005432848544	6DCF3A	3145 514642	NINA VASILEVA	{"phone": "+70308428985"}
0005432848545	6DCF3A	4784 637472	TATYANA ISAEVA	{"phone": "+70810458193"}
0005432848546	D311A3	1399 442629	ANNA BOGDANOVA	{"phone": "+70500950723"}
0005432848547	2C31D2	5594 557128	ANASTASIYA KUZMINA	{"phone": "+70247063317"}
0005432848548	795C1C	5120 064263	GALINA VASILEVA	{"phone": "+70360980748"}
0005432848549	795C1C	0089 959689	OLGA MELNIKOVA	{"phone": "+70119630629"}
0005432848550	9DF4D1	1341 683834	ALEKSANDR ROMANOV	{"phone": "+70465519323"}
0005432848551	9DF4D1	7457 910005	SERGEY STEPANOV	{"email": "sergey-stepanov1966@postgrespro.ru", "phone": "+70392008949"}
0005432848552	F90B66	6814 462587	ELENA SAVELEVA	{"email": "saveleva_elena.21111966@postgrespro.ru", "phone": "+70701815284"}
0005432848553	31457C	9422 030848	ALEKSEY NIKOLAEV	{"phone": "+70281156513"}
0005432848554	31457C	3397 277395	ALEKSANDR DENISOV	{"email": "a.denisov-101968@postgrespro.ru", "phone": "+70933183534"}
0005432848555	8E7C75	3335 258014	SVYATOSLAV FEDOROV	{"phone": "+70516590704"}
0005432848556	E761CF	9454 792846	YURIY OSIPOV	{"email": "y.osipov-051969@postgrespro.ru", "phone": "+70240615917"}
0005432848557	E761CF	3574 786551	SERGEY KUZNECOV	{"phone": "+70172748403"}
0005432848558	8B8129	2307 169250	ALEKSANDR NIKOLAEV	{"phone": "+70768747452"}
0005432848559	27F201	2138 641233	IGOR SOKOLOV	{"email": "sokolovigor.11071967@postgrespro.ru", "phone": "+70646758987"}
0005432848560	A20D69	0281 428267	YURIY VOLKOV	{"phone": "+70864407365"}
0005432848561	15D0D5	4737 257265	FANIYA KOROLEVA	{"email": "koroleva_faniya-1972@postgrespro.ru", "phone": "+70333070542"}
0005432848562	62A267	7756 481084	ALEKSANDRA ERMAKOVA	{"phone": "+70914613667"}
0005432848563	62A267	9661 942954	ANNA VOLKOVA	{"phone": "+70723092911"}
0005432848564	B1E584	4379 570952	VLADIMIR ALEKSEEV	{"phone": "+70267670330"}
0005432848565	EC0B1D	5151 610787	GALINA KALININA	{"email": "kalinina.g051977@postgrespro.ru", "phone": "+70663887125"}
0005432848566	EC0B1D	9294 509491	ALEKSEY SOKOLOV	{"phone": "+70934970958"}
0005432848567	3881D5	3068 033596	INESSA MIKHAYLOVA	{"email": "mikhaylova-i.091972@postgrespro.ru", "phone": "+70640574802"}
0005432848568	D68DCE	2614 770511	IRINA MATVEEVA	{"email": "matveeva.i-20091966@postgrespro.ru", "phone": "+70096127657"}
0005432848569	D68DCE	6698 607608	IGOR FEDOROV	{"email": "igorfedorov.021972@postgrespro.ru", "phone": "+70309627338"}
0005432848570	3B985B	1623 391239	YULIYA GUSEVA	{"phone": "+70046537321"}
0005432848571	3B985B	8350 290228	SOFYA YAKOVLEVA	{"email": "yakovleva_sofya1973@postgrespro.ru", "phone": "+70677480984"}
0005432848572	D15808	0972 644568	DMITRIY MOROZOV	{"email": "dmitriy_morozov_061968@postgrespro.ru", "phone": "+70250704751"}
0005432848574	DE9EE1	8929 730962	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova_anastasiya.1972@postgrespro.ru", "phone": "+70023512564"}
0005432848575	AFAF2A	5921 908141	ALEKSEY FILIPPOV	{"email": "a-filippov_1965@postgrespro.ru", "phone": "+70985020866"}
0005432848576	AFAF2A	9655 613178	ALEKSANDR GRIGOREV	{"email": "aleksandrgrigorev-20111975@postgrespro.ru", "phone": "+70008260729"}
0005432848577	48E3F3	0016 171561	VLADIMIR ORLOV	{"email": "orlov.v011980@postgrespro.ru", "phone": "+70153900502"}
0005432848578	48E3F3	1958 646122	SAMIRA ZAYCEVA	{"email": "samira_zayceva24021972@postgrespro.ru", "phone": "+70859692366"}
0005432848579	48E3F3	4657 705694	VLADISLAV TIKHONOV	{"email": "tikhonov.vladislav.1967@postgrespro.ru", "phone": "+70952457444"}
0005432848580	6BE78B	2239 036761	SAMVEL ISAEV	{"email": "sisaev_041975@postgrespro.ru", "phone": "+70517712303"}
0005432848581	6BE78B	9272 173310	ALEKSANDRA POTAPOVA	{"phone": "+70185258176"}
0005432848582	88E48F	5810 379502	PAVEL SCHERBAKOV	{"phone": "+70604517762"}
0005432848583	E563D7	9328 302442	DMITRIY DENISOV	{"email": "dmitriy.denisov_051968@postgrespro.ru", "phone": "+70694352979"}
0005432848584	7C876D	6170 802992	NIKOLAY YAKOVLEV	{"phone": "+70209735574"}
0005432848585	E6FA4E	0775 260923	DENIS EGOROV	{"email": "denis-egorov-10101986@postgrespro.ru", "phone": "+70388781146"}
0005432848586	81AB38	5381 876554	TATYANA MEDVEDEVA	{"phone": "+70237034462"}
0005432848587	81AB38	2937 305351	MARIYA MAKAROVA	{"email": "makarovamariya021972@postgrespro.ru", "phone": "+70592618864"}
0005432848588	8C2121	3475 293742	SERGEY ZHURAVLEV	{"phone": "+70172190000"}
0005432848589	3F6CC6	4845 592156	VLADISLAV OSIPOV	{"phone": "+70251351831"}
0005432848590	3F6CC6	1839 902197	NIKOLAY SOKOLOV	{"phone": "+70507452143"}
0005432848591	D99C53	5181 092456	ALEKSEY AFANASEV	{"email": "afanasev.aleksey.12051972@postgrespro.ru", "phone": "+70900647799"}
0005432848592	D99C53	9638 514632	ALEKSEY KRASNOV	{"email": "akrasnov1965@postgrespro.ru", "phone": "+70026984913"}
0005432848593	0A6019	9852 627052	DMITRIY KUZNECOV	{"email": "kuznecov.d081977@postgrespro.ru", "phone": "+70105033840"}
0005432848594	0A6019	9652 328258	IRINA ZHUKOVA	{"phone": "+70366850268"}
0005432848595	9D8B5C	8568 617999	VASILIY STEPANOV	{"email": "v-stepanov1976@postgrespro.ru", "phone": "+70731880532"}
0005432848596	8FA9B0	5391 214237	NINA IVANOVA	{"email": "ivanovan27051978@postgrespro.ru", "phone": "+70152989190"}
0005432848597	8FA9B0	0956 183153	MARIYA OSIPOVA	{"phone": "+70394546577"}
0005432848598	12E005	8383 429920	VLADISLAV MIRONOV	{"email": "mironovvladislav.051969@postgrespro.ru", "phone": "+70432042594"}
0005432848599	52532D	3354 687758	STEPAN MIKHAYLOV	{"phone": "+70480012435"}
0005432848600	52532D	7406 280350	ELENA ALEKSANDROVA	{"email": "elena.aleksandrova.1974@postgrespro.ru", "phone": "+70287314649"}
0005432848601	24D1F0	2479 517315	ELENA MARTYNOVA	{"email": "martynova_e_051973@postgrespro.ru", "phone": "+70924391956"}
0005432848602	1460CD	4679 214266	ALEKSANDR FOMIN	{"phone": "+70306950373"}
0005432848603	1460CD	8369 010224	OLEG EGOROV	{"email": "egorov-oleg_04061971@postgrespro.ru", "phone": "+70824541434"}
0005432848604	1460CD	2751 547027	LIDIYA KONOVALOVA	{"email": "l.konovalova-051975@postgrespro.ru", "phone": "+70970087430"}
0005432848605	1E84DD	9080 027173	VIKTORIYA FILIPPOVA	{"phone": "+70190358918"}
0005432848606	D591F2	7149 077173	SERGEY NIKOLAEV	{"phone": "+70062292006"}
0005432848607	D591F2	1584 015973	RUSLAN MOROZOV	{"email": "ruslan-morozov30111978@postgrespro.ru", "phone": "+70891826457"}
0005432848608	3B297B	8659 425337	SERGEY YAKOVLEV	{"email": "yakovlev_sergey1968@postgrespro.ru", "phone": "+70671800955"}
0005432848609	3B297B	8833 468352	VLADIMIR MOROZOV	{"email": "vladimir.morozov-1985@postgrespro.ru", "phone": "+70306349364"}
0005432848610	62570B	0503 977573	KIRILL MAKAROV	{"email": "kirillmakarov-22111970@postgrespro.ru", "phone": "+70118073394"}
0005432848611	62570B	4930 079068	ELENA PAVLOVA	{"email": "pavlovaelena091974@postgrespro.ru", "phone": "+70192185297"}
0005432848612	02EABE	7032 707778	MIKHAIL PETROV	{"email": "petrov.m.1972@postgrespro.ru", "phone": "+70655487385"}
0005432848613	215146	0869 618266	ANNA VASILEVA	{"email": "anna.vasileva.1976@postgrespro.ru", "phone": "+70127129238"}
0005432848614	215146	0352 389834	SERGEY SOKOLOV	{"phone": "+70685417671"}
0005432848615	BC6881	9478 456593	IRINA IVANOVA	{"email": "ivanova.i_22031968@postgrespro.ru", "phone": "+70186960571"}
0005432848616	BC6881	0206 780079	RAMIL IVANOV	{"phone": "+70981464181"}
0005432848617	0A496D	1822 865793	EVGENIY MAKAROV	{"phone": "+70821040126"}
0005432848618	66496A	0937 613428	VALERIYA TARASOVA	{"phone": "+70689343700"}
0005432848619	A2C3BF	5272 506427	DENIS TARASOV	{"phone": "+70482454225"}
0005432848620	A2C3BF	6600 530974	KLAVDIYA SIDOROVA	{"email": "sidorovak-21051980@postgrespro.ru", "phone": "+70349525848"}
0005432848621	1101A8	5444 105857	YURIY KISELEV	{"email": "kiselev.yuriy.1976@postgrespro.ru", "phone": "+70597730755"}
0005432848622	CE5B97	6719 911912	IRINA LUKYANOVA	{"email": "lukyanova.irina-13071980@postgrespro.ru", "phone": "+70093278092"}
0005432848623	5523AA	6437 452743	YURIY ALEKSEEV	{"phone": "+70420348496"}
0005432848624	B52B6D	1128 960608	NADEZHDA ILINA	{"email": "ilina.nadezhda-101984@postgrespro.ru", "phone": "+70815639409"}
0005432848625	B52B6D	6525 683053	ANNA GRISHINA	{"phone": "+70141767361"}
0005432848626	B52B6D	8956 807765	IRINA MELNIKOVA	{"email": "melnikova_irina_1970@postgrespro.ru", "phone": "+70780600105"}
0005432848627	D46D0B	9852 424942	TAMARA ANISIMOVA	{"email": "t-anisimova1970@postgrespro.ru", "phone": "+70226287999"}
0005432848628	776ECF	1947 037845	ALEKSANDR VLASOV	{"phone": "+70147655553"}
0005432848629	248392	7262 009294	VALENTINA EGOROVA	{"phone": "+70784290686"}
0005432848630	248392	2306 818429	NATALYA SERGEEVA	{"email": "natalya_sergeeva-1982@postgrespro.ru", "phone": "+70489595096"}
0005432848631	248392	6223 275275	ANDREY VOROBEV	{"phone": "+70072537200"}
0005432848632	C84BD2	3089 441986	KSENIYA OVCHINNIKOVA	{"email": "kseniyaovchinnikova_13081966@postgrespro.ru", "phone": "+70110076490"}
0005432848633	C84BD2	8090 996352	TATYANA MOROZOVA	{"phone": "+70741976555"}
0005432848634	4A451A	2827 500249	EKATERINA DMITRIEVA	{"email": "ekaterina-dmitrieva.021982@postgrespro.ru", "phone": "+70539344612"}
0005432848635	4A451A	8847 291642	DANILA ALEKSANDROV	{"phone": "+70292840457"}
0005432848636	D8E35C	8697 075463	SERGEY FILIPPOV	{"email": "sergey_filippov.051979@postgrespro.ru", "phone": "+70142968099"}
0005432848637	E56467	6741 073474	DMITRIY MIKHAYLOV	{"email": "dmitriymikhaylov.31071971@postgrespro.ru", "phone": "+70991809972"}
0005432848638	E56467	5716 253691	SVETLANA ISAEVA	{"email": "svetlana.isaeva.30051974@postgrespro.ru", "phone": "+70388238263"}
0005432848639	E645A9	1146 320638	VLADIMIR SOLOVEV	{"phone": "+70844114401"}
0005432848640	E645A9	8056 147651	ANAIT FILATOVA	{"email": "afilatova-14091964@postgrespro.ru", "phone": "+70870450117"}
0005432848641	E645A9	7967 361486	NAIL NIKOLAEV	{"email": "n.nikolaev_051965@postgrespro.ru", "phone": "+70691501203"}
0005432848642	9C8325	1209 499694	VALENTINA IVANOVA	{"phone": "+70075435975"}
0005432848643	9C8325	4892 822010	ALEKSEY SOKOLOV	{"email": "sokolov-a_091967@postgrespro.ru", "phone": "+70063737173"}
0005432848644	9C8325	5945 460694	ZINAIDA MIRONOVA	{"email": "mironova.z.1976@postgrespro.ru", "phone": "+70437806914"}
0005432848645	0BBA27	6132 191398	TATYANA SOLOVEVA	{"email": "soloveva-tatyana121977@postgrespro.ru", "phone": "+70700058368"}
0005432848646	0BBA27	7039 271869	LIDIYA POPOVA	{"email": "popova_lidiya15041967@postgrespro.ru", "phone": "+70677477764"}
0005432848647	F33BA9	4631 910225	TATYANA FILIPPOVA	{"email": "filippova_t.29031976@postgrespro.ru", "phone": "+70296866700"}
0005432848648	F33BA9	7016 098667	DARYA KUZNECOVA	{"email": "kuznecova-d.041971@postgrespro.ru", "phone": "+70399269751"}
0005432848649	EC617D	8315 970403	MARIYA POPOVA	{"email": "popova_mariya_1959@postgrespro.ru", "phone": "+70090465190"}
0005432848650	2F5F07	1055 121171	NIKOLAY KUDRYASHOV	{"phone": "+70923717048"}
0005432848651	747AA4	3511 758658	VENIAMIN ANDREEV	{"email": "andreevveniamin.27121977@postgrespro.ru", "phone": "+70351588278"}
0005432848652	747AA4	2838 241711	NIKITA SMIRNOV	{"phone": "+70249175494"}
0005432848715	709578	8005 660703	RAFAIL PAVLOV	{"phone": "+70130205806"}
0005432848653	09DD57	4449 173008	ANATOLIY GORBUNOV	{"email": "gorbunova1973@postgrespro.ru", "phone": "+70248229660"}
0005432848654	09DD57	7906 385738	NINA VASILEVA	{"email": "vasileva.nina-1975@postgrespro.ru", "phone": "+70107040706"}
0005432848655	16A121	2776 765876	SERGEY NIKOLAEV	{"email": "nikolaev.s.1980@postgrespro.ru", "phone": "+70750115750"}
0005432848656	16A121	8168 403527	NIKOLAY ZHUKOV	{"email": "n.zhukov21121967@postgrespro.ru", "phone": "+70617608331"}
0005432848657	B53D17	1189 727351	VLADIMIR ZHUKOV	{"phone": "+70445425877"}
0005432848658	91A524	6427 639023	ALEKSANDR IVANOV	{"phone": "+70892115289"}
0005432848659	06DAD2	4372 600874	ANDREY BORISOV	{"phone": "+70773349855"}
0005432848660	06DAD2	8303 701300	DARYA VLASOVA	{"phone": "+70587041546"}
0005432848661	8C32CA	5489 351673	ALEKSANDR FILIPPOV	{"phone": "+70708691307"}
0005432848662	8C32CA	0145 852735	DANIL SMIRNOV	{"phone": "+70418285587"}
0005432848663	FD598E	3678 044103	ALEKSEY BORISOV	{"phone": "+70212791795"}
0005432848664	9B59D6	5811 530148	IRINA KARPOVA	{"phone": "+70022213950"}
0005432848665	5809B0	5584 949463	VALERIY MOROZOV	{"email": "morozov.v_1972@postgrespro.ru", "phone": "+70523825160"}
0005432848666	3542FC	3193 469058	LYUDMILA SEMENOVA	{"email": "semenova.lyudmila-06041986@postgrespro.ru", "phone": "+70318961030"}
0005432848667	3D5D31	5689 575657	LILIYA MARTYNOVA	{"email": "liliya.martynova_011974@postgrespro.ru", "phone": "+70016422562"}
0005432848668	4D4FB5	5124 292348	SVETLANA ALEKSEEVA	{"email": "salekseeva13061971@postgrespro.ru", "phone": "+70970057455"}
0005432848669	34B43E	0662 545160	VYACHESLAV YAKOVLEV	{"email": "yakovlev.vyacheslav_111976@postgrespro.ru", "phone": "+70973156553"}
0005432848670	34B43E	3767 377622	NATALYA KISELEVA	{"email": "kiselevan_1971@postgrespro.ru", "phone": "+70867567637"}
0005432848671	E2D0B9	1728 309877	ZHANNA NOVIKOVA	{"email": "zhanna-novikova_21041973@postgrespro.ru", "phone": "+70411217518"}
0005432848672	E2D0B9	5763 943798	TATYANA BARANOVA	{"email": "baranovatatyana.04041965@postgrespro.ru", "phone": "+70893339420"}
0005432848673	E2D0B9	0390 383183	ELIZAVETA NAUMOVA	{"email": "naumova_elizaveta11101982@postgrespro.ru", "phone": "+70639531918"}
0005432848674	934B22	9237 632353	SVETLANA POPOVA	{"email": "popova_s_101965@postgrespro.ru", "phone": "+70265478773"}
0005432848675	C6DD57	9916 664971	ALEKSEY NIKITIN	{"phone": "+70807525790"}
0005432848676	12F16D	2463 222845	MARIYA TARASOVA	{"phone": "+70993742058"}
0005432848677	6B05DD	4632 431664	ELENA NIKOLAEVA	{"phone": "+70754704028"}
0005432848678	6B05DD	7572 378754	ARSENIY ORLOV	{"email": "orlov_arseniy_041974@postgrespro.ru", "phone": "+70500333674"}
0005432848679	F2DD60	8820 539150	SERGEY EGOROV	{"phone": "+70414646243"}
0005432848680	F2DD60	0076 600386	ANTON VOLKOV	{"phone": "+70856004756"}
0005432848681	480F8B	1941 804566	SERGEY CHERNOV	{"email": "s.chernov021974@postgrespro.ru", "phone": "+70437238015"}
0005432848682	81830C	2693 791271	ROMAN RODIONOV	{"email": "r.rodionov25011981@postgrespro.ru", "phone": "+70069975046"}
0005432848683	81830C	1239 975406	YURIY GRIGOREV	{"phone": "+70425810350"}
0005432848684	D9C873	3715 321934	ROMAN FOMIN	{"email": "fomin-roman_22061969@postgrespro.ru", "phone": "+70219649261"}
0005432848685	89B393	2497 786053	VIKTOR KISELEV	{"phone": "+70162789588"}
0005432848686	B788E6	5410 467714	MARIYA MARTYNOVA	{"email": "mariya.martynova_17121977@postgrespro.ru", "phone": "+70645474908"}
0005432848687	2740EF	3531 035139	ANDREY KUZMIN	{"phone": "+70061822147"}
0005432848688	6D0047	1978 082708	SERGEY IVANOV	{"email": "ivanov.s.061977@postgrespro.ru", "phone": "+70742964380"}
0005432848689	E8C355	2311 494193	SERGEY SEMENOV	{"phone": "+70896099116"}
0005432848690	6EFC3E	6618 768955	STEPAN VASILEV	{"email": "vasilevstepan-1978@postgrespro.ru", "phone": "+70780394677"}
0005432848691	6EFC3E	9387 061154	MAKSIM MOROZOV	{"phone": "+70569649075"}
0005432848692	78BC2C	6327 764739	ANNA IVANOVA	{"email": "ivanova.anna1960@postgrespro.ru", "phone": "+70995779183"}
0005432848693	A85527	5787 028194	MARIYA KARPOVA	{"email": "mkarpova_13081979@postgrespro.ru", "phone": "+70322823191"}
0005432848694	757BAD	2759 556684	VLADIMIR MOROZOV	{"phone": "+70927322290"}
0005432848696	2F27B5	0061 331259	KONSTANTIN SOLOVEV	{"email": "solovev_k.101968@postgrespro.ru", "phone": "+70426857308"}
0005432848697	F36A3C	4118 053207	EKATERINA ZHUKOVA	{"phone": "+70821321011"}
0005432848698	E3A042	0509 110044	TATYANA PETROVA	{"phone": "+70075349831"}
0005432848699	24BCBC	8406 437409	KONSTANTIN FEDOROV	{"email": "konstantin.fedorov20031968@postgrespro.ru", "phone": "+70727415839"}
0005432848700	6031B7	0999 373268	LIDIYA KUDRYASHOVA	{"phone": "+70463763924"}
0005432848701	6031B7	2598 619983	ANDREY KOROLEV	{"email": "korolev.a-04031967@postgrespro.ru", "phone": "+70678777978"}
0005432848702	B92A3B	9925 125081	DMITRIY SMIRNOV	{"phone": "+70987212459"}
0005432848703	B8F575	4506 144075	SERGEY MAKAROV	{"phone": "+70983733943"}
0005432848704	965299	0056 804172	MAKSIM GORBUNOV	{"email": "maksim_gorbunov_15011964@postgrespro.ru", "phone": "+70011178555"}
0005432848705	965299	5348 788300	VLADIMIR VOLKOV	{"phone": "+70923611711"}
0005432848706	52E72F	9198 176786	TATYANA MELNIKOVA	{"phone": "+70896219665"}
0005432848707	D1F9FC	8355 631295	TATYANA RODIONOVA	{"phone": "+70736716848"}
0005432848708	D1F9FC	4112 632484	VALERIYA YUDINA	{"email": "valeriya-yudina_1976@postgrespro.ru", "phone": "+70090454821"}
0005432848709	379299	4955 199569	LYUDMILA MATVEEVA	{"email": "matveeva_l-1975@postgrespro.ru", "phone": "+70755976700"}
0005432848710	D49C3E	1533 275975	NIKOLAY ZHUKOV	{"phone": "+70867650870"}
0005432848711	D49C3E	4118 552114	SEMEN GUSEV	{"phone": "+70437000540"}
0005432848712	0C3EB0	4438 705353	GENNADIY SOROKIN	{"email": "sorokin_g_121971@postgrespro.ru", "phone": "+70449618795"}
0005432848713	0C3EB0	9977 762500	NATALYA IVANOVA	{"phone": "+70827778081"}
0005432848714	C5538E	0576 655508	ALEKSEY NIKOLAEV	{"phone": "+70794100041"}
0005432848716	29A6A5	8665 500194	ALEKSANDR BARANOV	{"email": "aleksandr-baranov-11041970@postgrespro.ru", "phone": "+70507128153"}
0005432848717	54BE47	7964 091379	YURIY KUZMIN	{"phone": "+70490444498"}
0005432848718	46655E	1813 457158	ANASTASIYA MAKAROVA	{"email": "makarova-anastasiya111977@postgrespro.ru", "phone": "+70928656759"}
0005432848719	80D763	1227 560359	GALINA FADEEVA	{"phone": "+70690354418"}
0005432848720	80D763	3733 687531	DMITRIY MEDVEDEV	{"email": "medvedev.dmitriy.051976@postgrespro.ru", "phone": "+70612174861"}
0005432848721	7DE840	6856 718279	SVETLANA ZAKHAROVA	{"phone": "+70486507118"}
0005432848722	6FBA64	0298 373061	ELENA IVANOVA	{"email": "ivanova_e.031968@postgrespro.ru", "phone": "+70817092890"}
0005432848723	1FD6AC	9563 372488	IRINA RODIONOVA	{"email": "irina_rodionova_1974@postgrespro.ru", "phone": "+70348901864"}
0005432848724	E19202	8560 986159	SERGEY SHEVCHENKO	{"email": "shevchenkos_02041978@postgrespro.ru", "phone": "+70956297031"}
0005432848725	AA0D4B	5370 520768	NADEZHDA MOROZOVA	{"phone": "+70660209953"}
0005432848836	E11C30	0041 646564	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov1984@postgrespro.ru", "phone": "+70347936612"}
0005432848837	960B51	0810 305683	OLGA SEMENOVA	{"phone": "+70010940902"}
0005432848838	5DC75D	3863 430067	ZOYA NIKIFOROVA	{"email": "z-nikiforova_1967@postgrespro.ru", "phone": "+70684005921"}
0005432848839	5DC75D	4509 042158	VARVARA KISELEVA	{"phone": "+70590490354"}
0005432848840	B30754	5772 771719	OLEG MIRONOV	{"phone": "+70279042555"}
0005432848841	4CBCDD	5868 083182	ALEKSEY EGOROV	{"phone": "+70668140538"}
0005432848842	15BC66	8522 555136	ROMAN PAVLOV	{"phone": "+70656323824"}
0005432848843	9C8F9A	4689 044065	VADIM VASILEV	{"email": "vasilev_vadim.1987@postgrespro.ru", "phone": "+70581356535"}
0005432848844	60FB47	8439 693748	DMITRIY BORISOV	{"email": "borisov-dmitriy041978@postgrespro.ru", "phone": "+70882325785"}
0005432848845	D5C005	8569 060134	SERGEY VOLKOV	{"phone": "+70593987029"}
0005432848846	17F610	6375 634609	IRINA KOZLOVA	{"phone": "+70967221841"}
0005432848847	7E6A4A	7580 916030	KONSTANTIN KISELEV	{"email": "konstantin_kiselev.06061977@postgrespro.ru", "phone": "+70466203243"}
0005432848848	7E6A4A	2065 923037	ANDREY NOVIKOV	{"phone": "+70139309071"}
0005432848849	E610E0	3191 624996	ILDAR VASILEV	{"phone": "+70002573180"}
0005432848850	3A0ECD	9772 638860	EVGENIYA PAVLOVA	{"phone": "+70487275769"}
0005432848851	3D0329	3272 947925	NINA KULIKOVA	{"email": "kulikovanina.19111977@postgrespro.ru", "phone": "+70383597779"}
0005432848852	A6D149	1480 235183	VIKTORIYA TROFIMOVA	{"email": "v_trofimova_061980@postgrespro.ru", "phone": "+70044365236"}
0005432848853	A6D149	4789 236513	ALEKSANDR ZAYCEV	{"phone": "+70342761441"}
0005432848854	1626CA	5632 101609	ZOYA KOROLEVA	{"email": "korolevaz.1968@postgrespro.ru", "phone": "+70095390700"}
0005432848855	1626CA	3997 322550	VLADIMIR NAZAROV	{"email": "nazarov.v_011967@postgrespro.ru", "phone": "+70797572868"}
0005432848856	1626CA	0779 316590	OLGA IVANOVA	{"phone": "+70724337653"}
0005432848857	61307D	5822 670069	MARIYA NIKITINA	{"email": "mariyanikitina-051972@postgrespro.ru", "phone": "+70028312164"}
0005432848858	C0843B	5408 864618	SERGEY BORISOV	{"email": "borisovs.081962@postgrespro.ru", "phone": "+70673184408"}
0005432848859	C0843B	3403 313438	OLESYA TARASOVA	{"phone": "+70731323636"}
0005432848860	6C2E92	5641 549522	RAMIL SEMENOV	{"phone": "+70886337829"}
0005432848861	6C2E92	2027 676879	ARINA ALEKSEEVA	{"email": "alekseeva-a06031974@postgrespro.ru", "phone": "+70766942744"}
0005432848862	4C803B	2093 897091	VLADIMIR POPOV	{"email": "vladimir-popov-041977@postgrespro.ru", "phone": "+70110594428"}
0005432848863	4C803B	6665 930302	MILANA IVANOVA	{"email": "ivanovam22121960@postgrespro.ru", "phone": "+70172356176"}
0005432848864	86B531	6365 746396	SERGEY ANDREEV	{"phone": "+70630948934"}
0005432848865	86B531	7606 492885	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir071966@postgrespro.ru", "phone": "+70001820019"}
0005432848866	AA4B13	2824 757213	NATALYA SERGEEVA	{"email": "n.sergeeva_1968@postgrespro.ru", "phone": "+70177790681"}
0005432848867	35E05A	9153 234061	ANTON YAKOVLEV	{"email": "yakovlev-anton1983@postgrespro.ru", "phone": "+70019284373"}
0005432848868	90D124	5199 747709	LYUDMILA ANDREEVA	{"phone": "+70088487586"}
0005432848869	24B31D	8563 166442	GALINA ROMANOVA	{"phone": "+70744469586"}
0005432848870	9CF31A	8607 880978	YURIY SMIRNOV	{"phone": "+70385592558"}
0005432848871	9CF31A	0157 750639	VIKTORIYA ZHUKOVA	{"phone": "+70877282786"}
0005432848872	D21AE2	3366 247546	SERGEY PETROV	{"phone": "+70395958435"}
0005432848873	25EDE1	0551 374703	VIKTOR SOKOLOV	{"email": "v.sokolov.24031982@postgrespro.ru", "phone": "+70518877993"}
0005432848874	F89522	4616 103834	ARTEM FOMIN	{"email": "a_fomin1979@postgrespro.ru", "phone": "+70407605425"}
0005432848875	736F32	8815 326051	SERGEY IVANOV	{"email": "ivanov-s_081980@postgrespro.ru", "phone": "+70273285523"}
0005432848876	736F32	8239 471963	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_v.1980@postgrespro.ru", "phone": "+70017105738"}
0005432848877	56EAFD	7584 877322	OLGA KRASNOVA	{"phone": "+70990977249"}
0005432848878	E67B89	9576 495747	TATYANA KOVALEVA	{"email": "kovaleva-tatyana26101973@postgrespro.ru", "phone": "+70665376293"}
0005432848879	9E6AA2	5601 971264	IGOR ANDREEV	{"email": "igor.andreev_1963@postgrespro.ru", "phone": "+70543145057"}
0005432848880	EBA471	5146 561239	OLGA TITOVA	{"email": "titovao.081966@postgrespro.ru", "phone": "+70718047035"}
0005432848881	EBA471	3912 737180	ELENA KAZAKOVA	{"email": "elena_kazakova.061962@postgrespro.ru", "phone": "+70424656336"}
0005432848882	ED6B1E	7884 109548	VALENTINA POLYAKOVA	{"email": "v.polyakova-121966@postgrespro.ru", "phone": "+70118832390"}
0005432848883	ED6B1E	5518 110723	ELENA KRASNOVA	{"email": "krasnova.elena-25021969@postgrespro.ru", "phone": "+70180407153"}
0005432848884	0E261B	2039 435580	YURIY KULIKOV	{"phone": "+70645798061"}
0005432848885	0E261B	8356 069435	EGOR EGOROV	{"phone": "+70625755657"}
0005432848886	DD0207	1168 582241	SERGEY MIRONOV	{"email": "mironov-s091969@postgrespro.ru", "phone": "+70776823847"}
0005432848887	DCF281	1433 297606	VALERIYA IVANOVA	{"email": "v.ivanova.27091976@postgrespro.ru", "phone": "+70696943839"}
0005432848888	DCF281	7818 577558	DMITRIY GERASIMOV	{"phone": "+70547260739"}
0005432848889	85AA0B	1981 462944	VLADISLAV ALEKSANDROV	{"email": "vladislav.aleksandrov-051974@postgrespro.ru", "phone": "+70491817006"}
0005432848890	85AA0B	9363 611416	MAKSIM ILIN	{"email": "ilin.m_081979@postgrespro.ru", "phone": "+70412218435"}
0005432848891	A9D8CF	6670 370275	MARIYA BARANOVA	{"email": "m_baranova-121977@postgrespro.ru", "phone": "+70487907301"}
0005432848892	62D1C3	7236 992390	YURIY SOROKIN	{"email": "y-sorokin.24121989@postgrespro.ru", "phone": "+70059028173"}
0005432848893	62D1C3	7232 977285	LYUBOV POPOVA	{"phone": "+70318411014"}
0005432848894	C5F871	2093 133385	VLADIMIR KARPOV	{"phone": "+70403000560"}
0005432848895	B0B427	8366 115531	MIKHAIL FOMIN	{"phone": "+70209225025"}
0005432848896	B0B427	3512 747229	MARINA TARASOVA	{"phone": "+70026508741"}
0005432848897	020E58	2545 157911	IGOR KUZNECOV	{"phone": "+70947269367"}
0005432848898	020E58	3027 221846	VITALIY KARPOV	{"email": "karpov.vitaliy1967@postgrespro.ru", "phone": "+70069781481"}
0005432848899	A631D0	7498 695196	ALEKSANDR EGOROV	{"email": "egorov.a021974@postgrespro.ru", "phone": "+70969492000"}
0005432848900	3244A8	2211 355244	ELENA IVANOVA	{"phone": "+70282076363"}
0005432848901	3244A8	6505 233815	ALEVTINA NIKITINA	{"email": "nikitina_a-091979@postgrespro.ru", "phone": "+70288692018"}
0005432848902	0CBEF3	2481 611391	ANATOLIY TIKHONOV	{"email": "anatoliytikhonov1974@postgrespro.ru", "phone": "+70616918728"}
0005432848903	4C3103	3893 155017	EDUARD SIDOROV	{"email": "sidorov-e_1971@postgrespro.ru", "phone": "+70503561761"}
0005432848904	BCCD16	9150 499862	ANATOLIY AFANASEV	{"email": "anatoliy-afanasev.061973@postgrespro.ru", "phone": "+70250023227"}
0005432848905	BCCD16	4345 624147	TIMUR ALEKSANDROV	{"phone": "+70235587076"}
0005432848906	D03A7B	1568 229508	GALINA ANDREEVA	{"phone": "+70005250390"}
0005432848907	7E1E05	2621 494690	NATALYA NIKIFOROVA	{"phone": "+70232192019"}
0005432848908	AE3BD9	0683 777927	MAKSIM NAZAROV	{"email": "nazarov_m_31121977@postgrespro.ru", "phone": "+70067817738"}
0005432848909	AE3BD9	2488 187429	NATALYA ZOTOVA	{"email": "zotovan-15061978@postgrespro.ru", "phone": "+70919410032"}
0005432848910	5E3B81	9460 636217	ELENA KOLESNIKOVA	{"phone": "+70569540654"}
0005432848911	87F914	0802 467305	DMITRIY GERASIMOV	{"phone": "+70332355872"}
0005432848912	E4114B	2672 899577	NIKOLAY VOLKOV	{"email": "volkov_nikolay1961@postgrespro.ru", "phone": "+70986054245"}
0005432848913	6AE32D	8501 090766	LYUDMILA ANDREEVA	{"phone": "+70627930956"}
0005432848914	6AE32D	4543 919115	NADEZHDA MARTYNOVA	{"email": "martynova_n_19031968@postgrespro.ru", "phone": "+70010466267"}
0005432848915	B9E26B	4860 095527	IGOR KUZNECOV	{"email": "kuznecovigor1965@postgrespro.ru", "phone": "+70326056447"}
0005432848916	4574FE	3463 089844	OLGA GERASIMOVA	{"email": "olga-gerasimova.06111980@postgrespro.ru", "phone": "+70638425922"}
0005432848917	BC1725	9698 811850	TATYANA KOROLEVA	{"phone": "+70323244765"}
0005432848918	6A6EF7	0391 794358	ANNA NESTEROVA	{"phone": "+70343075130"}
0005432848919	6A6EF7	1481 439008	ALEKSEY SIDOROV	{"email": "a_sidorov071958@postgrespro.ru", "phone": "+70730679902"}
0005432848920	1F4074	1896 785885	VALENTINA ANISIMOVA	{"phone": "+70429484226"}
0005432848921	EC4973	3561 878464	IVAN KUZNECOV	{"email": "kuznecov.ivan071970@postgrespro.ru", "phone": "+70907482721"}
0005432848922	EC4973	8354 405033	PAVEL NOVIKOV	{"phone": "+70400634953"}
0005432848923	ADF31F	9033 669330	VITALIY SOKOLOV	{"phone": "+70740033724"}
0005432848924	ADF31F	9251 452814	DANILA POPOV	{"phone": "+70405866349"}
0005432848925	ADF31F	9918 615264	SEMEN MIKHAYLOV	{"phone": "+70808967826"}
0005432851815	B28E7B	9966 362772	EVELINA FROLOVA	{"email": "frolova.e.03101973@postgrespro.ru", "phone": "+70005533535"}
0005432851816	6AE7FD	5399 930892	NATALYA ARKHIPOVA	{"phone": "+70888427159"}
0005432851817	803275	7601 911127	IGOR ANDREEV	{"email": "iandreev.1979@postgrespro.ru", "phone": "+70187122054"}
0005432851818	803275	3992 690124	SERGEY PAVLOV	{"email": "sergey_pavlov.011983@postgrespro.ru", "phone": "+70599422752"}
0005432851931	E21710	1489 960609	YURIY FEDOTOV	{"phone": "+70164973311"}
0005432851819	F6E208	4662 241848	ALEKSEY NIKOLAEV	{"email": "aleksey.nikolaev_13081974@postgrespro.ru", "phone": "+70489166275"}
0005432851820	4CE02E	1449 375584	ANTONINA BARANOVA	{"email": "antoninabaranova_1971@postgrespro.ru", "phone": "+70978157996"}
0005432851821	4ABCB4	1125 497217	MARINA LAZAREVA	{"email": "lazareva-m-15051982@postgrespro.ru", "phone": "+70038127420"}
0005432851822	086706	2283 930774	MIKHAIL VASILEV	{"phone": "+70426052784"}
0005432851823	88733C	9339 609806	ALEKSANDR NIKITIN	{"email": "a_nikitin-11061966@postgrespro.ru", "phone": "+70411826583"}
0005432851824	4A038E	9960 332908	MARINA POLYAKOVA	{"phone": "+70725809971"}
0005432851825	A74BAE	0487 304662	KIRILL SHEVCHENKO	{"phone": "+70700833590"}
0005432851826	A74BAE	7865 492019	NADEZHDA IVANOVA	{"email": "nadezhda_ivanova-21021973@postgrespro.ru", "phone": "+70821559127"}
0005432851827	D7A795	2393 333479	YURIY KOROLEV	{"phone": "+70641366577"}
0005432851828	660925	5784 958338	NADEZHDA FOMINA	{"email": "fomina-nadezhda1965@postgrespro.ru", "phone": "+70856624558"}
0005432851829	660925	1790 551649	IRINA VASILEVA	{"phone": "+70661243500"}
0005432851830	3E8C96	5652 375716	ANDREY ZAYCEV	{"phone": "+70029629826"}
0005432851831	CB2A31	9730 427414	EKATERINA NESTEROVA	{"phone": "+70160473696"}
0005432851832	A8AEDE	0351 990631	MAKSIM POPOV	{"phone": "+70810274760"}
0005432851833	A8AEDE	8755 871060	ANATOLIY POPOV	{"email": "anatoliy-popov.1977@postgrespro.ru", "phone": "+70304223663"}
0005432851834	A8AEDE	1527 650809	KSENIYA POPOVA	{"phone": "+70704362751"}
0005432851835	7CC4E6	1488 697502	ANASTASIYA SMIRNOVA	{"email": "anastasiyasmirnova.071968@postgrespro.ru", "phone": "+70781816105"}
0005432851836	7CC4E6	7882 576498	YULIYA SOKOLOVA	{"email": "sokolovayuliya_1968@postgrespro.ru", "phone": "+70657015458"}
0005432851837	ECFEAB	4380 788576	ALEKSANDR KONOVALOV	{"phone": "+70637575086"}
0005432851838	4D1BDF	1235 039542	TAMARA FROLOVA	{"email": "frolova-t031977@postgrespro.ru", "phone": "+70874185606"}
0005432851839	FEB388	6153 688518	TATYANA ANDREEVA	{"phone": "+70794977858"}
0005432851840	FEB388	4766 710951	LIDIYA POLYAKOVA	{"email": "lidiya_polyakova30051972@postgrespro.ru", "phone": "+70682352595"}
0005432851841	612E28	3150 598946	ALEKSANDRA CHERNOVA	{"email": "aleksandra_chernova-1964@postgrespro.ru", "phone": "+70591861739"}
0005432851842	E05D29	7542 631221	EVGENIY SOLOVEV	{"email": "e-solovev_051964@postgrespro.ru", "phone": "+70110061432"}
0005432851843	39E5D3	4705 935429	VLADISLAV MAKAROV	{"email": "v_makarov1973@postgrespro.ru", "phone": "+70774879591"}
0005432851844	CF1A19	8994 887975	SVETLANA MAKAROVA	{"phone": "+70138188657"}
0005432851845	76D218	4578 923601	IRINA NESTEROVA	{"email": "nesterova_i-28051966@postgrespro.ru", "phone": "+70332512609"}
0005432851846	76D218	9812 048256	VALENTINA NOVIKOVA	{"phone": "+70955730143"}
0005432851847	16450C	2938 567833	NATALYA MALYSHEVA	{"email": "nmalysheva.21121988@postgrespro.ru", "phone": "+70548852328"}
0005432851848	16450C	7287 382584	VADIM SCHERBAKOV	{"phone": "+70156051132"}
0005432851849	D316B6	5706 299642	IGOR TARASOV	{"email": "i-tarasov-24111972@postgrespro.ru", "phone": "+70202019367"}
0005432851850	D316B6	6044 677766	EVGENIYA FOMINA	{"email": "fomina.evgeniya-1973@postgrespro.ru", "phone": "+70154009194"}
0005432851851	D316B6	2709 514857	ANATOLIY KARPOV	{"phone": "+70946013664"}
0005432851852	CE4D9D	4993 488511	VALENTIN BARANOV	{"email": "valentin-baranov_1975@postgrespro.ru", "phone": "+70165067376"}
0005432851853	E02FE4	2497 922784	VALENTINA TARASOVA	{"email": "tarasova-v.1978@postgrespro.ru", "phone": "+70362321150"}
0005432851854	E02FE4	4512 126644	SERGEY KUZNECOV	{"email": "kuznecov-sergey-1972@postgrespro.ru", "phone": "+70620500580"}
0005432851855	DAC024	8477 284673	NIKOLAY FEDOROV	{"email": "fedorov.n.22061976@postgrespro.ru", "phone": "+70030183461"}
0005432851856	564D60	7834 425353	VALENTINA MOROZOVA	{"email": "vmorozova051970@postgrespro.ru", "phone": "+70973546616"}
0005432851857	3D0982	6708 138416	ANATOLIY STEPANOV	{"email": "stepanov-anatoliy_1981@postgrespro.ru", "phone": "+70294255195"}
0005432851858	BE24C5	6922 698781	ANNA FOMINA	{"email": "fomina-anna_011969@postgrespro.ru", "phone": "+70915105677"}
0005432851859	B6B145	4235 012939	VLADISLAV GORBUNOV	{"phone": "+70308476902"}
0005432851860	B6B145	3697 827585	VALERIY ZAKHAROV	{"email": "v_zakharov.1971@postgrespro.ru", "phone": "+70495569523"}
0005432851861	72FE3E	6370 680209	SVETLANA MIKHAYLOVA	{"email": "svetlanamikhaylova_1970@postgrespro.ru", "phone": "+70802390589"}
0005432851862	2D4228	3200 525432	MARIYA ANDREEVA	{"email": "mariya.andreeva_1957@postgrespro.ru", "phone": "+70150931632"}
0005432851863	2D4228	9333 524967	ROMAN GAVRILOV	{"email": "r_gavrilov-1973@postgrespro.ru", "phone": "+70108247402"}
0005432851864	3CC86B	9157 128819	OKSANA GUSEVA	{"email": "o_guseva-1964@postgrespro.ru", "phone": "+70205640885"}
0005432851865	EEFF12	1009 339811	LYUBOV ISAEVA	{"email": "lyubov-isaeva-1966@postgrespro.ru", "phone": "+70404542226"}
0005432851866	EEFF12	7313 586065	VLADIMIR NIKITIN	{"phone": "+70227090746"}
0005432851867	EEFF12	5636 180320	IRINA GRISHINA	{"phone": "+70729387073"}
0005432851868	792C97	2036 144990	VALENTINA SOKOLOVA	{"phone": "+70915240936"}
0005432851869	792C97	3966 744021	SERGEY VOROBEV	{"email": "s.vorobev-041971@postgrespro.ru", "phone": "+70015001986"}
0005432851870	D8353C	0820 818945	RAISA KOROLEVA	{"phone": "+70214442630"}
0005432851871	D8353C	1930 872623	SERGEY KUZNECOV	{"email": "kuznecov_s031976@postgrespro.ru", "phone": "+70231030813"}
0005432851872	60F659	6766 653843	MAKSIM STEPANOV	{"phone": "+70647246225"}
0005432851873	60F659	5554 670644	ALEKSEY VOLKOV	{"email": "a-volkov.081968@postgrespro.ru", "phone": "+70712275676"}
0005432851874	AD695D	2787 568004	OLGA POPOVA	{"email": "o-popova-1965@postgrespro.ru", "phone": "+70914198947"}
0005432851875	B6B73C	6625 699467	YANA IVANOVA	{"phone": "+70236541013"}
0005432851876	1A3826	1227 872598	SERGEY KONOVALOV	{"phone": "+70959477912"}
0005432851877	1A3826	0770 947700	MARIYA TIMOFEEVA	{"phone": "+70673217868"}
0005432851878	78DDB5	0828 843152	YULIYA KRASNOVA	{"phone": "+70186076086"}
0005432851879	9F0ED8	1396 726889	LIDIYA MARTYNOVA	{"phone": "+70602599438"}
0005432851880	9F0ED8	0556 106526	MIKHAIL ZHUKOV	{"phone": "+70195154919"}
0005432851881	EEA9CE	3189 164284	NATALYA OSIPOVA	{"phone": "+70858975589"}
0005432851882	A36908	8377 993192	SERGEY ZHUKOV	{"email": "zhukov.s.11031960@postgrespro.ru", "phone": "+70860199160"}
0005432851883	0DAF4F	8191 056204	MARGARITA TROFIMOVA	{"phone": "+70583588226"}
0005432851884	D570EF	9438 997865	ROZALIYA ARKHIPOVA	{"email": "rarkhipova_071971@postgrespro.ru", "phone": "+70886105051"}
0005432851885	C5F737	6223 388752	MIKHAIL KUDRYASHOV	{"email": "mikhail.kudryashov-1979@postgrespro.ru", "phone": "+70106879068"}
0005432851886	CBF5B6	7828 407871	VALENTINA BOGDANOVA	{"phone": "+70466393104"}
0005432851887	CBF5B6	7982 340585	SVETLANA KOROLEVA	{"phone": "+70414597481"}
0005432851888	F52E4A	4968 827406	ANATOLIY MOISEEV	{"phone": "+70805576379"}
0005432851889	96E0E3	0998 958407	SERGEY KUZMIN	{"email": "kuzmins.011979@postgrespro.ru", "phone": "+70326146674"}
0005432851890	EDF1BF	8533 464513	TATYANA KRASNOVA	{"phone": "+70635679956"}
0005432851891	46C2B5	8925 013899	NINA ARKHIPOVA	{"phone": "+70321388610"}
0005432851892	DAB0C4	4141 696540	YULIYA ZAYCEVA	{"phone": "+70849629341"}
0005432851893	DAB0C4	0381 629390	TATYANA TARASOVA	{"email": "t_tarasova_071957@postgrespro.ru", "phone": "+70222466570"}
0005432851894	A419C9	3622 428699	NATALYA TARASOVA	{"email": "tarasova-natalya041970@postgrespro.ru", "phone": "+70463754266"}
0005432851895	A419C9	4824 025709	NINA PAVLOVA	{"email": "npavlova.061981@postgrespro.ru", "phone": "+70685017565"}
0005432851896	840DC5	6584 177986	ANNA SOKOLOVA	{"email": "anna_sokolova.071964@postgrespro.ru", "phone": "+70733198772"}
0005432851897	D90C1D	2087 504540	ELENA NESTEROVA	{"phone": "+70504123037"}
0005432851898	1C0676	0976 496036	ALEKSANDRA PAVLOVA	{"phone": "+70184165963"}
0005432851899	BB04A7	0031 869401	LYUBOV KAZAKOVA	{"email": "lkazakova_071969@postgrespro.ru", "phone": "+70419570350"}
0005432851900	AFAC73	6990 213345	ELENA MELNIKOVA	{"phone": "+70878033635"}
0005432851901	AFAC73	1301 695378	IRINA MAKAROVA	{"phone": "+70423542605"}
0005432851902	AFAC73	9285 198259	EVGENIY IVANOV	{"email": "ivanovevgeniy-11051975@postgrespro.ru", "phone": "+70680923948"}
0005432851903	9C342B	5781 152305	ALEKSANDR MATVEEV	{"email": "a-matveev.111962@postgrespro.ru", "phone": "+70675248043"}
0005432851904	394BD8	7859 299935	ELENA ROMANOVA	{"phone": "+70375968532"}
0005432851905	144A96	1638 098788	KIRILL SAVELEV	{"email": "ksavelev.07081963@postgrespro.ru", "phone": "+70493991896"}
0005432851906	31F587	1438 168030	DMITRIY IVANOV	{"email": "divanov.121974@postgrespro.ru", "phone": "+70778533005"}
0005432851907	9D2DF0	5848 305379	SERGEY FOMIN	{"email": "fomin_s.1971@postgrespro.ru", "phone": "+70143426003"}
0005432851908	9D2DF0	3709 105993	DMITRIY SIDOROV	{"email": "sidorov_d1973@postgrespro.ru", "phone": "+70964140814"}
0005432851909	9D2DF0	8511 390003	ALEKSANDR SOROKIN	{"phone": "+70800464110"}
0005432851910	CA8F33	0890 536114	EKATERINA NESTEROVA	{"phone": "+70576359011"}
0005432851911	CA8F33	5476 388854	ALEKSANDR NIKITIN	{"phone": "+70261149949"}
0005432851912	F6293E	3011 634454	VALENTINA SCHERBAKOVA	{"email": "v-scherbakova-1975@postgrespro.ru", "phone": "+70785390047"}
0005432851913	F6293E	2591 022468	ANNA ANDREEVA	{"phone": "+70331429462"}
0005432851914	038259	2590 283125	SERGEY ZAYCEV	{"email": "zaycevsergey1987@postgrespro.ru", "phone": "+70021260549"}
0005432851915	18A1D6	3045 122056	VALERIYA IVANOVA	{"phone": "+70978764134"}
0005432851916	645203	3293 935238	DMITRIY CHERNOV	{"phone": "+70412954304"}
0005432851917	354109	7193 428366	MAKSIM IVANOV	{"phone": "+70199086855"}
0005432851918	CAF4F2	3110 552494	NATALIYA KRASNOVA	{"email": "krasnova-nataliya111960@postgrespro.ru", "phone": "+70241369215"}
0005432851919	115B11	9851 722635	VYACHESLAV EGOROV	{"email": "v_egorov_051980@postgrespro.ru", "phone": "+70117645978"}
0005432851920	115B11	8535 378166	ALEKSEY OSIPOV	{"email": "osipov_aleksey091969@postgrespro.ru", "phone": "+70499654563"}
0005432851921	115B11	9080 418500	VIKTOR KUZNECOV	{"email": "v-kuznecov061982@postgrespro.ru", "phone": "+70506499727"}
0005432851922	B1EFFA	5013 171901	NATALYA NOVIKOVA	{"email": "novikovanatalya1968@postgrespro.ru", "phone": "+70720775527"}
0005432851923	FDC3D3	2240 573586	ALEKSANDR FROLOV	{"phone": "+70056960872"}
0005432851924	FDC3D3	3544 822960	VLADIMIR GUSEV	{"email": "gusevv.051983@postgrespro.ru", "phone": "+70324998323"}
0005432851925	EF6C11	5108 901258	POLINA MAKAROVA	{"email": "makarova_polina091973@postgrespro.ru", "phone": "+70269327211"}
0005432851926	F43524	1639 660340	IRINA STEPANOVA	{"phone": "+70309834764"}
0005432851927	46A0E3	8845 132300	MIKHAIL NAUMOV	{"phone": "+70734832298"}
0005432851928	FBD24B	2581 908074	PAVEL MAKSIMOV	{"email": "p_maksimov-22101975@postgrespro.ru", "phone": "+70384336369"}
0005432851929	1F872D	0308 124075	EVGENIY KOZLOV	{"email": "e_kozlov-21051976@postgrespro.ru", "phone": "+70323597082"}
0005432851930	1F872D	7651 226064	ALEKSEY MAKAROV	{"email": "makarov-aleksey_071980@postgrespro.ru", "phone": "+70419531857"}
0005432851932	A7D883	6165 153921	MARTA NAUMOVA	{"email": "naumovamarta1965@postgrespro.ru", "phone": "+70163982803"}
0005432851933	A7D883	7543 809363	MAKSIM SCHERBAKOV	{"email": "scherbakovm_02091971@postgrespro.ru", "phone": "+70000303740"}
0005432851934	91D3E6	3414 937548	ELVINA KUZNECOVA	{"phone": "+70321686851"}
0005432851935	91D3E6	5290 417358	YURIY STEPANOV	{"email": "yuriy.stepanov.101983@postgrespro.ru", "phone": "+70692696333"}
0005432851936	7D8D0F	9860 315164	KRISTINA YUDINA	{"email": "yudina_kristina.02031973@postgrespro.ru", "phone": "+70146726950"}
0005432851937	391315	4563 163925	SEMEN FOMIN	{"email": "sfomin.1981@postgrespro.ru", "phone": "+70637567515"}
0005432851938	048842	4861 350700	DARYA BOGDANOVA	{"email": "darya_bogdanova-101962@postgrespro.ru", "phone": "+70672421053"}
0005432851939	D0BBBF	8642 229209	ELIZAVETA KOZLOVA	{"phone": "+70473494198"}
0005432851940	57EA37	7832 970752	MIKHAIL ZAYCEV	{"phone": "+70794558946"}
0005432851941	646B3C	7861 956277	NIKOLAY FROLOV	{"phone": "+70270342993"}
0005432851942	646B3C	9810 921937	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a-05051965@postgrespro.ru", "phone": "+70977752066"}
0005432851943	D3F00E	8323 498101	ANASTASIYA FEDOROVA	{"email": "anastasiya_fedorova.101988@postgrespro.ru", "phone": "+70918849557"}
0005432851944	D3F00E	0637 734592	IRINA VLASOVA	{"phone": "+70756545469"}
0005432851945	371937	4713 220918	OKSANA PAVLOVA	{"email": "pavlova-oksana-111968@postgrespro.ru", "phone": "+70755046290"}
0005432851946	2A444A	6740 333674	KONSTANTIN IVANOV	{"phone": "+70041427741"}
0005432851947	5B6A93	0585 526361	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov-1976@postgrespro.ru", "phone": "+70661729594"}
0005432851948	5B6A93	5603 121782	ELENA ALEKSEEVA	{"phone": "+70453417705"}
0005432851949	C150F6	8980 152842	VITALIY SOROKIN	{"email": "v-sorokin_111969@postgrespro.ru", "phone": "+70525600268"}
0005432851950	03F855	0703 490749	VALENTINA NIKOLAEVA	{"email": "nikolaeva.valentina1974@postgrespro.ru", "phone": "+70440155966"}
0005432851951	4C3FC2	5915 632281	ANASTASIYA KALININA	{"email": "kalinina-anastasiya-1969@postgrespro.ru", "phone": "+70739180437"}
0005432851952	4C3FC2	5130 949391	PAVEL FEDOTOV	{"phone": "+70003535210"}
0005432851953	F79D15	4040 110204	ANNA EFREMOVA	{"email": "annaefremova-1971@postgrespro.ru", "phone": "+70077584852"}
0005432851954	F79D15	0906 705582	MARIYA YAKOVLEVA	{"email": "m_yakovleva25101969@postgrespro.ru", "phone": "+70710805263"}
0005432851955	42637D	3672 307419	RADIK NIKITIN	{"email": "r.nikitin_17041969@postgrespro.ru", "phone": "+70901103849"}
0005432851956	D7C3C2	1508 910166	ALINA MALYSHEVA	{"phone": "+70818517512"}
0005432851957	63A991	7329 820020	LARISA MIKHAYLOVA	{"email": "larisa_mikhaylova_1974@postgrespro.ru", "phone": "+70929848538"}
0005432851958	4F0714	0845 086340	NIKOLAY KUZNECOV	{"phone": "+70019870738"}
0005432851959	7FC6FF	6843 968287	VLADIMIR SEMENOV	{"email": "vladimir.semenov.091964@postgrespro.ru", "phone": "+70983888153"}
0005432851960	7FC6FF	6016 679839	VALENTINA POPOVA	{"email": "valentina_popova_071960@postgrespro.ru", "phone": "+70722947274"}
0005432851961	60F7E7	2407 638315	YULIYA PAVLOVA	{"phone": "+70953694030"}
0005432851962	2315D2	6289 893654	OLGA KISELEVA	{"email": "kiseleva-olga-1982@postgrespro.ru", "phone": "+70439979658"}
0005432851963	0AAE5B	2456 961854	VALENTINA KUDRYASHOVA	{"email": "kudryashova_valentina-1973@postgrespro.ru", "phone": "+70763757935"}
0005432851964	0AAE5B	5244 696163	VLADIMIR ZAYCEV	{"phone": "+70062257228"}
0005432851965	ADDB73	1317 111983	VYACHESLAV DMITRIEV	{"email": "dmitrievv_02011967@postgrespro.ru", "phone": "+70046414656"}
0005432851966	FE1C83	6475 008358	NIKOLAY KUZNECOV	{"phone": "+70311205633"}
0005432851967	9ABD5B	0442 900508	MAKAR IVANOV	{"phone": "+70254092926"}
0005432851968	52ADFF	5628 926052	LEV SOLOVEV	{"email": "lev_solovev22081975@postgrespro.ru", "phone": "+70318773448"}
0005432851969	5B7B0A	6417 355170	GERMAN TARASOV	{"email": "tarasov_g1979@postgrespro.ru", "phone": "+70398018851"}
0005432851970	FBC877	7547 403293	ANDREY PETROV	{"email": "andreypetrov.12091979@postgrespro.ru", "phone": "+70848919445"}
0005432851971	FBC877	1222 226421	ELENA GAVRILOVA	{"email": "gavrilova_elena1972@postgrespro.ru", "phone": "+70582991742"}
0005432851972	8F8F84	4012 026399	MARIYA TARASOVA	{"phone": "+70274219766"}
0005432851973	8F8F84	0417 595900	ELENA SMIRNOVA	{"phone": "+70391215935"}
0005432851974	6D38A6	2744 249663	EKATERINA TIKHONOVA	{"phone": "+70984243774"}
0005432851975	6D38A6	0364 436752	GENNADIY FEDOROV	{"email": "fedorov_gennadiy_11031972@postgrespro.ru", "phone": "+70034932485"}
0005432851976	0A443F	4771 042177	ALEKSEY MAKSIMOV	{"phone": "+70710908150"}
0005432851977	FC8931	3058 116990	ANTON GUSEV	{"email": "antongusev.051966@postgrespro.ru", "phone": "+70599858647"}
0005432851978	C1A5D3	5714 120560	NATALYA ZAKHAROVA	{"email": "natalya-zakharova-1964@postgrespro.ru", "phone": "+70824993083"}
0005432851979	68E408	9449 833804	EVGENIY ZAKHAROV	{"email": "zakharove_11111972@postgrespro.ru", "phone": "+70628590243"}
0005432851980	68E408	2426 324743	NIKOLAY NIKOLAEV	{"email": "nikolaev.n_1986@postgrespro.ru", "phone": "+70755016220"}
0005432851981	33EEC0	4066 234529	MARINA DENISOVA	{"phone": "+70289687097"}
0005432851982	65653B	9504 002407	ELENA TITOVA	{"email": "e.titova-031966@postgrespro.ru", "phone": "+70094765963"}
0005432851983	11B054	1027 753456	EKATERINA ZOTOVA	{"phone": "+70291998541"}
0005432851984	987352	6094 650409	STEPAN GUSEV	{"email": "s_gusev081964@postgrespro.ru", "phone": "+70312429563"}
0005432851985	DD3241	6028 648308	MIKHAIL KISELEV	{"email": "m_kiselev051965@postgrespro.ru", "phone": "+70587299493"}
0005432851986	345351	7640 623699	YURIY SIDOROV	{"phone": "+70017943335"}
0005432851987	345351	1028 431945	LYUDMILA EGOROVA	{"phone": "+70933666325"}
0005432851988	345351	6013 204240	ALEKSANDR BORISOV	{"phone": "+70776257078"}
0005432851989	2A6686	4495 188688	RAFAEL BORISOV	{"phone": "+70420458476"}
0005432851990	4212FA	0550 854527	GRIGORIY KUZMIN	{"phone": "+70750127938"}
0005432851991	E290B2	7066 719964	NADEZHDA EFIMOVA	{"phone": "+70111984073"}
0005432851992	E290B2	0924 681607	DANIL MOISEEV	{"email": "d_moiseev-03091976@postgrespro.ru", "phone": "+70234743710"}
0005432851993	366C4B	4558 572153	EVGENIY GORBUNOV	{"email": "evgeniy-gorbunov-1980@postgrespro.ru", "phone": "+70113979188"}
0005432851994	D58F89	9135 564730	TATYANA MAKSIMOVA	{"phone": "+70472299733"}
0005432851995	D58F89	4450 814401	LYUBOV KOMAROVA	{"email": "komarova_lyubov_24041966@postgrespro.ru", "phone": "+70148267029"}
0005432851996	77153A	3601 028450	MARIYA IVANOVA	{"email": "ivanovamariya-101971@postgrespro.ru", "phone": "+70600081877"}
0005432851997	77153A	7724 024184	SERGEY ROMANOV	{"phone": "+70525737006"}
0005432851998	B53D01	8473 744063	YURIY PAVLOV	{"email": "pavlov.yuriy_011980@postgrespro.ru", "phone": "+70738305650"}
0005432851999	B53D01	0552 136395	PAVEL GERASIMOV	{"email": "gerasimov_pavel-1978@postgrespro.ru", "phone": "+70547529916"}
0005432852000	FCF561	2104 566001	YAN DAVYDOV	{"email": "davydov-yan_121971@postgrespro.ru", "phone": "+70717618117"}
0005432852001	FCC7AB	8478 396720	YULIYA AKIMOVA	{"phone": "+70349189082"}
0005432852002	E85F08	3532 298064	ANDREY NAZAROV	{"phone": "+70398710183"}
0005432852003	E85F08	4968 648504	ALEKSANDR ROMANOV	{"email": "romanov-a_011967@postgrespro.ru", "phone": "+70167840469"}
0005432852004	76E9D5	7281 173780	DMITRIY MEDVEDEV	{"email": "dmitriy-medvedev.1982@postgrespro.ru", "phone": "+70733276552"}
0005432852005	76E9D5	9616 955138	GALINA MATVEEVA	{"email": "matveeva-galina-071973@postgrespro.ru", "phone": "+70981202832"}
0005432852006	76E9D5	8019 086825	EKATERINA FEDOROVA	{"phone": "+70362205040"}
0005432852007	D23568	7750 777518	MARIYA TIMOFEEVA	{"email": "timofeevam-17021973@postgrespro.ru", "phone": "+70467929547"}
0005432852008	5D962F	8429 279199	LEONID KUZNECOV	{"email": "kuznecov_leonid1977@postgrespro.ru", "phone": "+70244307755"}
0005432852009	84F8E3	9840 764416	PAVEL SAVELEV	{"email": "savelev-p.1972@postgrespro.ru", "phone": "+70987413299"}
0005432852010	F5785A	4950 030481	ANZHELIKA ARKHIPOVA	{"email": "arkhipovaa1982@postgrespro.ru", "phone": "+70182928789"}
0005432852011	F5785A	5434 551513	NATALYA SEMENOVA	{"phone": "+70567661104"}
0005432852012	F5785A	7918 932899	LIDIYA NIKOLAEVA	{"phone": "+70695415201"}
0005432852013	F5785A	6524 665499	MAKSIM MEDVEDEV	{"email": "m-medvedev_20071959@postgrespro.ru", "phone": "+70457695052"}
0005432852014	2CC40F	2388 868222	RAISA POPOVA	{"email": "popova-r_1972@postgrespro.ru", "phone": "+70672644129"}
0005432852015	2CC40F	8249 415176	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey_1975@postgrespro.ru", "phone": "+70760493484"}
0005432852016	371A4E	1379 178062	OLGA VASILEVA	{"phone": "+70935259805"}
0005432852017	F2288F	7861 055693	SERGEY ALEKSANDROV	{"email": "aleksandrov.s1969@postgrespro.ru", "phone": "+70445636969"}
0005432852018	1F7EC4	5069 738131	OKSANA ZAKHAROVA	{"email": "ozakharova_1980@postgrespro.ru", "phone": "+70729439084"}
0005432852019	1F7EC4	6537 957640	IRINA BELYAEVA	{"email": "belyaeva-irina.10121968@postgrespro.ru", "phone": "+70171086956"}
0005432852020	365F9F	1335 631054	VERA MARTYNOVA	{"phone": "+70120135485"}
0005432852021	5068A6	7709 373880	OKSANA NAZAROVA	{"email": "o_nazarova25121973@postgrespro.ru", "phone": "+70289555786"}
0005432852022	92D53A	2971 056482	ELENA KOROLEVA	{"phone": "+70760925456"}
0005432852023	A1F2B6	8231 578885	GALINA NIKOLAEVA	{"email": "nikolaeva.galina-06081979@postgrespro.ru", "phone": "+70145457390"}
0005432852024	652F5A	8281 587786	STANISLAV SOROKIN	{"phone": "+70289875594"}
0005432852025	652F5A	5927 739153	YURIY ANTONOV	{"email": "antonov-yuriy1982@postgrespro.ru", "phone": "+70349627846"}
0005432852026	681708	6897 350909	IRINA BORISOVA	{"email": "irina.borisova1970@postgrespro.ru", "phone": "+70560277872"}
0005432852027	681708	6356 585025	ALEKSANDR SMIRNOV	{"phone": "+70992705105"}
0005432852028	972495	2661 955871	NATALYA BORISOVA	{"phone": "+70925023009"}
0005432852029	B1DA1A	1605 596367	DARYA MARTYNOVA	{"email": "darya_martynova-011970@postgrespro.ru", "phone": "+70394778024"}
0005432852030	B1DA1A	6644 141454	DMITRIY ANDREEV	{"phone": "+70633333524"}
0005432852031	58EA24	1148 947976	SVETLANA KUZMINA	{"email": "svetlana-kuzmina.21091971@postgrespro.ru", "phone": "+70478853546"}
0005432852032	8042C1	8804 937477	NATALYA LEBEDEVA	{"phone": "+70791045641"}
0005432852033	7BE22F	1010 338869	ILYA IVANOV	{"phone": "+70390841994"}
0005432852034	63090F	0913 629231	NATALYA KULIKOVA	{"email": "n_kulikova-1982@postgrespro.ru", "phone": "+70766778461"}
0005432852035	1F84F2	5680 265492	VASILIY MAKSIMOV	{"email": "vmaksimov.1975@postgrespro.ru", "phone": "+70347635388"}
0005432852036	1F47AF	9379 831656	NADEZHDA ALEKSANDROVA	{"phone": "+70742051318"}
0005432852037	9B0332	1614 776056	VLADIMIR EGOROV	{"phone": "+70131731535"}
0005432852038	CD2803	0427 208440	DINARA VOROBEVA	{"phone": "+70165807177"}
0005432852039	C2C83B	9498 867221	ALEKSANDR BONDARENKO	{"email": "a_bondarenko-1972@postgrespro.ru", "phone": "+70039015758"}
0005432852040	49C44F	6363 885077	ELENA ALEKSEEVA	{"email": "elenaalekseeva011967@postgrespro.ru", "phone": "+70491255194"}
0005432852041	C2E671	0217 411699	SVETLANA POLYAKOVA	{"email": "s_polyakova_1986@postgrespro.ru", "phone": "+70467414890"}
0005432852042	FC409C	4065 987662	STEPAN GUSEV	{"phone": "+70355537394"}
0005432852043	F1CFFA	8144 675966	EVGENIYA SERGEEVA	{"email": "evgeniya_sergeeva.031964@postgrespro.ru", "phone": "+70330706451"}
0005432852044	614391	9367 005234	VALENTINA MAKAROVA	{"email": "v.makarova.20041980@postgrespro.ru", "phone": "+70724807080"}
0005432852045	E73E75	3042 145368	IRINA FEDOROVA	{"email": "ifedorova061958@postgrespro.ru", "phone": "+70364966977"}
0005432852046	E73E75	3608 818741	ALEKSANDRA MAKAROVA	{"phone": "+70889855719"}
0005432852047	3B7220	7192 162599	EKATERINA NIKIFOROVA	{"phone": "+70538037419"}
0005432852048	A4C6BF	9002 776944	IRINA PETROVA	{"email": "irina-petrova-071975@postgrespro.ru", "phone": "+70980350703"}
0005432852049	A4C6BF	0758 524683	NATALYA CHERNOVA	{"phone": "+70480256740"}
0005432852050	166C0F	1071 098233	DANIL BELOV	{"email": "danil.belov1969@postgrespro.ru", "phone": "+70183646186"}
0005432852051	7C0221	5970 718421	ANDREY DENISOV	{"phone": "+70240373588"}
0005432852052	7C0221	9747 132900	ARTEM ANDREEV	{"phone": "+70411200652"}
0005432852053	8B0970	4190 002953	EVGENIY ANTONOV	{"email": "evgeniy-antonov-071982@postgrespro.ru", "phone": "+70886839065"}
0005432852054	D6D304	5657 293162	VLADISLAV NAZAROV	{"email": "vladislav-nazarov-1977@postgrespro.ru", "phone": "+70315848462"}
0005432852055	3E821E	0554 717982	SERGEY MEDVEDEV	{"phone": "+70703385153"}
0005432852056	3E821E	4071 390484	ELEONORA BARANOVA	{"email": "eleonora.baranova1972@postgrespro.ru", "phone": "+70803420283"}
0005432852057	434FE9	5725 952622	SERGEY YAKOVLEV	{"email": "s-yakovlev-011966@postgrespro.ru", "phone": "+70993199475"}
0005432852058	434FE9	6578 147864	ALEKSEY KULIKOV	{"email": "kulikov-a1960@postgrespro.ru", "phone": "+70745207610"}
0005432852059	14ACA4	2936 963248	TAMARA CHERNOVA	{"phone": "+70304740160"}
0005432852060	14ACA4	3455 767789	MARK KUZMIN	{"email": "kuzmin.m_1953@postgrespro.ru", "phone": "+70615474028"}
0005432852061	13C298	1196 325939	TIMUR VASILEV	{"email": "vasilev_t.16071982@postgrespro.ru", "phone": "+70754044496"}
0005432852062	358C20	4886 098667	ELENA KUZNECOVA	{"email": "kuznecova-elena.1971@postgrespro.ru", "phone": "+70755113365"}
0005432852063	358C20	1847 270356	TATYANA VOLKOVA	{"email": "tatyana_volkova-101976@postgrespro.ru", "phone": "+70157535388"}
0005432852064	A04D9C	3095 258849	MARINA LEBEDEVA	{"phone": "+70978144033"}
0005432852065	71BB8A	7988 291819	VIKTOR STEPANOV	{"phone": "+70532953067"}
0005432852066	71BB8A	4627 514974	ELENA MALYSHEVA	{"phone": "+70934030830"}
0005432852067	91E2C6	0703 992272	VALERIY ZAYCEV	{"phone": "+70477119359"}
0005432852068	EC6A43	1408 161352	ELENA ANDREEVA	{"email": "andreeva-e_05041970@postgrespro.ru", "phone": "+70222717279"}
0005432852069	B0580E	7621 082454	OLGA DENISOVA	{"email": "denisova_olga_051978@postgrespro.ru", "phone": "+70392977976"}
0005432852070	B0580E	1416 748029	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov.08071959@postgrespro.ru", "phone": "+70601260905"}
0005432852071	51B989	1684 300253	NIKOLAY MAKAROV	{"email": "makarovnikolay-26041970@postgrespro.ru", "phone": "+70530622228"}
0005432852072	463E4C	9775 932965	STANISLAV VASILEV	{"phone": "+70797031465"}
0005432852073	463E4C	7191 696520	VALERIYA BORISOVA	{"phone": "+70693207204"}
0005432852074	463E4C	1256 901208	VALENTINA BELOVA	{"email": "belovav1967@postgrespro.ru", "phone": "+70195937007"}
0005432852075	576444	9723 844966	ANATOLIY VASILEV	{"email": "anatoliy.vasilev-1966@postgrespro.ru", "phone": "+70136858926"}
0005432852076	6B2092	4331 313925	SERGEY ZAYCEV	{"phone": "+70509762443"}
0005432852077	BC6AFE	2791 565541	OLGA ROMANOVA	{"email": "olga_romanova-14081969@postgrespro.ru", "phone": "+70848009705"}
0005432852078	5EBDF8	0182 180253	LYUBOV NIKITINA	{"email": "nikitinal_121980@postgrespro.ru", "phone": "+70266761210"}
0005432852079	494E33	2193 043251	MARIYA KAZAKOVA	{"phone": "+70764516405"}
0005432852080	289AA1	6851 386989	IGOR GORBUNOV	{"email": "gorbunovigor.041974@postgrespro.ru", "phone": "+70276022492"}
0005432852081	289AA1	4942 596912	NIKOLAY POPOV	{"phone": "+70522250009"}
0005432852082	289AA1	8831 867165	VERA MELNIKOVA	{"phone": "+70580253790"}
0005432852083	CA4C4E	3069 175619	MIKHAIL KUZNECOV	{"email": "kuznecov.mikhail.25051966@postgrespro.ru", "phone": "+70340868849"}
0005432852084	CA4C4E	7026 580656	ALEKSANDR SERGEEV	{"phone": "+70172655837"}
0005432852085	2D6FBB	5822 576991	KONSTANTIN TIMOFEEV	{"email": "k.timofeev-1966@postgrespro.ru", "phone": "+70896314937"}
0005432852086	2D6FBB	8752 823749	OLEG KISELEV	{"phone": "+70004852597"}
0005432852087	2D6FBB	7436 893090	PETR ROMANOV	{"email": "romanov-petr-1973@postgrespro.ru", "phone": "+70294113690"}
0005432852088	2DDDA3	7219 161929	NADEZHDA STEPANOVA	{"email": "stepanova-nadezhda01071965@postgrespro.ru", "phone": "+70378538120"}
0005432852089	2DDDA3	0666 377448	MARIYA BOGDANOVA	{"phone": "+70823186396"}
0005432852090	2DDDA3	8650 123699	VYACHESLAV SOKOLOV	{"phone": "+70269754194"}
0005432852091	96CA83	1854 013741	MIKHAIL SAVELEV	{"phone": "+70137109355"}
0005432852092	A93026	1056 883417	FEDOR GAVRILOV	{"email": "gavrilovf06071978@postgrespro.ru", "phone": "+70311713866"}
0005432852093	7685CD	9015 424611	MARIYA BORISOVA	{"email": "mariya_borisova_081973@postgrespro.ru", "phone": "+70422357744"}
0005432852094	30DD18	2891 124685	MIKHAIL BONDARENKO	{"email": "bondarenko-m-071973@postgrespro.ru", "phone": "+70017736964"}
0005432852095	30DD18	5725 539750	YURIY FILIPPOV	{"email": "yfilippov-10031966@postgrespro.ru", "phone": "+70639044768"}
0005432852096	2178F3	4039 356581	ARTEM FROLOV	{"phone": "+70062548184"}
0005432852097	2178F3	8382 013951	MIKHAIL RODIONOV	{"email": "m.rodionov_1968@postgrespro.ru", "phone": "+70088001342"}
0005432852098	2178F3	8367 684906	ANATOLIY BORISOV	{"email": "borisov.a_041965@postgrespro.ru", "phone": "+70738730720"}
0005432852099	7ADFF0	1687 313334	LYUDMILA KISELEVA	{"email": "l.kiseleva_1984@postgrespro.ru", "phone": "+70476468933"}
0005432852100	401257	4090 742262	MARINA BELOVA	{"phone": "+70900646894"}
0005432852101	401257	0123 985043	SERGEY ALEKSANDROV	{"phone": "+70616248820"}
0005432852102	A3EC38	2617 812421	EVGENIY KOZLOV	{"email": "kozlov_e-08101987@postgrespro.ru", "phone": "+70499939445"}
0005432852103	A3EC38	5970 962846	ALEKSEY TARASOV	{"email": "a_tarasov09061967@postgrespro.ru", "phone": "+70462152479"}
0005432857852	C15A6F	2692 844410	NINA KARPOVA	{"email": "nina.karpova_29091981@postgrespro.ru", "phone": "+70409357013"}
0005432857853	4F35F9	8011 264068	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey-03081974@postgrespro.ru", "phone": "+70377337584"}
0005432857854	4F35F9	2227 560891	ANNA VLASOVA	{"email": "vlasova_a-1968@postgrespro.ru", "phone": "+70299321518"}
0005432857855	C462E9	1772 785158	ELENA PETROVA	{"email": "e.petrova.1973@postgrespro.ru", "phone": "+70107048825"}
0005432857856	92D14B	9084 432008	IGOR TIKHONOV	{"email": "igor-tikhonov051972@postgrespro.ru", "phone": "+70655505524"}
0005432857857	92D14B	0892 103118	LYUBOV VOROBEVA	{"phone": "+70924562505"}
0005432857858	29F8B9	5474 069088	LIDIYA MAKAROVA	{"email": "l.makarova_021972@postgrespro.ru", "phone": "+70516568983"}
0005432857859	964561	2950 865070	KRISTINA KISELEVA	{"phone": "+70405262716"}
0005432857860	25A0EC	2471 891872	NIKOLAY ALEKSANDROV	{"phone": "+70709113266"}
0005432857861	25A0EC	1027 941158	ALEKSEY CHERNOV	{"email": "chernov_aleksey-12031973@postgrespro.ru", "phone": "+70446661707"}
0005432857862	7FA548	6197 437297	LYUDMILA YAKOVLEVA	{"phone": "+70889705514"}
0005432857863	C7C423	4407 637977	ALEKSANDR TIMOFEEV	{"phone": "+70760845826"}
0005432857864	D64FD4	4438 368948	TATYANA BARANOVA	{"email": "t.baranova091976@postgrespro.ru", "phone": "+70628972982"}
0005432857865	97C157	6458 953312	BORIS PETROV	{"email": "boris.petrov_071975@postgrespro.ru", "phone": "+70861318388"}
0005432857866	97C157	3802 223069	SVETLANA KOMAROVA	{"phone": "+70041638790"}
0005432857867	1E7478	8784 742185	VENIAMIN NAUMOV	{"phone": "+70619188066"}
0005432857868	6020F4	3231 599916	ANDREY PAVLOV	{"phone": "+70217183870"}
0005432857869	6020F4	3243 557008	KONSTANTIN BELOV	{"phone": "+70011111399"}
0005432857870	2858DC	4183 315437	IVAN SMIRNOV	{"phone": "+70752989532"}
0005432857871	2858DC	9769 275083	EVGENIY DAVYDOV	{"phone": "+70408637278"}
0005432857872	DBA559	4454 901433	MARIYA ABRAMOVA	{"phone": "+70575909439"}
0005432857873	DBA559	0315 308275	ANGELINA FROLOVA	{"phone": "+70888268366"}
0005432857874	4CD560	4456 660202	OLGA ZAYCEVA	{"phone": "+70682549559"}
0005432857875	4CD560	4189 502845	YURIY ZAKHAROV	{"email": "zakharovy1976@postgrespro.ru", "phone": "+70050438207"}
0005432857876	C45E45	0202 098224	KAMIL IVANOV	{"email": "kamil-ivanov1969@postgrespro.ru", "phone": "+70791839107"}
0005432857877	E5D2D1	9109 937003	EVGENIY MAKAROV	{"phone": "+70515989709"}
0005432857878	E5D2D1	1251 934057	IRINA ANISIMOVA	{"email": "anisimova_irina1967@postgrespro.ru", "phone": "+70953214448"}
0005432857879	82A7FA	9906 871723	MIKHAIL NAZAROV	{"email": "nazarov_m.071983@postgrespro.ru", "phone": "+70001248701"}
0005432857880	82A7FA	5332 981171	VALERIY KISELEV	{"phone": "+70853235970"}
0005432857881	263ECE	2634 372601	OLGA FEDOROVA	{"phone": "+70768516590"}
0005432857882	208EEB	0315 634202	SVETLANA RODIONOVA	{"email": "s-rodionova-1983@postgrespro.ru", "phone": "+70052928535"}
0005432857883	F54B50	7747 182944	IRINA POPOVA	{"email": "i.popova-1981@postgrespro.ru", "phone": "+70558796439"}
0005432857884	3C69BD	0127 139401	NIKOLAY DAVYDOV	{"email": "n-davydov.25021966@postgrespro.ru", "phone": "+70156783936"}
0005432857885	290F4C	7746 360576	IGOR PETROV	{"email": "petrovigor_021968@postgrespro.ru", "phone": "+70588605654"}
0005432857886	5E2586	1662 615377	ANNA MIRONOVA	{"phone": "+70606663439"}
0005432857887	491D18	3906 539237	TAMARA KOLESNIKOVA	{"phone": "+70863370810"}
0005432857888	D47F6E	4726 041434	SEMEN CHERNOV	{"email": "s.chernov-25021976@postgrespro.ru", "phone": "+70554828213"}
0005432857889	D47F6E	1607 143291	IVAN PAVLOV	{"phone": "+70679364620"}
0005432857890	FAF930	6772 715649	ALEKSEY NOVIKOV	{"email": "aleksey.novikov1960@postgrespro.ru", "phone": "+70200003433"}
0005432857891	2D8B24	9130 618512	NIKITA SOKOLOV	{"email": "sokolov.nikita02111974@postgrespro.ru", "phone": "+70800685666"}
0005432857892	2D8B24	5562 879057	MIKHAIL VASILEV	{"phone": "+70811279678"}
0005432857893	3DF18D	1284 539077	KIRILL PETROV	{"phone": "+70931309157"}
0005432857894	F49E39	7407 027932	ANNA KUZNECOVA	{"email": "a-kuznecova1970@postgrespro.ru", "phone": "+70143826612"}
0005432857895	F49E39	7823 722422	YURIY KAZAKOV	{"email": "y.kazakov061967@postgrespro.ru", "phone": "+70793083475"}
0005432857896	AAAF55	3385 241140	VYACHESLAV KUZNECOV	{"phone": "+70504451614"}
0005432857897	2CA657	2285 281833	ELENA SMIRNOVA	{"phone": "+70778109079"}
0005432857898	7A6CC7	4571 615733	VALERIY EGOROV	{"email": "egorovvaleriy.1978@postgrespro.ru", "phone": "+70040450462"}
0005432857899	7BCF68	0188 139051	LYUDMILA KUZNECOVA	{"email": "kuznecova.l-1966@postgrespro.ru", "phone": "+70733588703"}
0005432857900	CBDD08	9994 532820	TATYANA KUZNECOVA	{"phone": "+70079965828"}
0005432857901	CBDD08	0702 218429	VALERIYA KONOVALOVA	{"phone": "+70953439727"}
0005432857902	D21167	4857 860564	VLADIMIR KISELEV	{"email": "vladimir-kiselev.1959@postgrespro.ru", "phone": "+70903676528"}
0005432857903	5B84FC	7282 770677	PAVEL BORISOV	{"email": "borisovp-15091973@postgrespro.ru", "phone": "+70556302092"}
0005432857904	4D7A56	6953 534441	SERGEY ILIN	{"phone": "+70047849803"}
0005432857905	3FB9EC	7937 128377	TATYANA TARASOVA	{"email": "tarasova_t_14011965@postgrespro.ru", "phone": "+70475723851"}
0005432857906	7BD16B	9622 214408	NINA FADEEVA	{"email": "fadeevanina21061966@postgrespro.ru", "phone": "+70882878645"}
0005432857907	09A822	4400 567285	NATALIYA VASILEVA	{"email": "nataliyavasileva.021982@postgrespro.ru", "phone": "+70776273920"}
0005432857908	F4CCA7	8213 772567	EVGENIY ZAYCEV	{"email": "zaycevevgeniy-081974@postgrespro.ru", "phone": "+70814309416"}
0005432857909	B63F2A	7801 115891	VLADIMIR MEDVEDEV	{"email": "vladimir.medvedev.1965@postgrespro.ru", "phone": "+70675217159"}
0005432857910	760D07	3245 579228	VALENTINA MAKAROVA	{"email": "vmakarova23051971@postgrespro.ru", "phone": "+70755693502"}
0005432857911	2196E0	2770 694516	ANDREY NIKOLAEV	{"phone": "+70912584374"}
0005432857912	FC3A7D	7281 419963	NADEZHDA KONOVALOVA	{"phone": "+70194809531"}
0005432857913	FC3A7D	4941 013059	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr.021969@postgrespro.ru", "phone": "+70159161262"}
0005432857914	3CBAC4	8610 057752	YURIY FROLOV	{"phone": "+70008467060"}
0005432857915	B50880	8510 823391	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov111976@postgrespro.ru", "phone": "+70015896642"}
0005432857916	FCFADD	3202 773828	OLEG TARASOV	{"email": "tarasov.oleg.17121973@postgrespro.ru", "phone": "+70145449425"}
0005432857917	711D96	7767 145148	VALENTINA KUZNECOVA	{"email": "kuznecova-v_1966@postgrespro.ru", "phone": "+70606119291"}
0005432857918	EF5C91	4335 402207	ARTUR BORISOV	{"phone": "+70373894224"}
0005432857919	0D84FA	3791 223290	NAILYA MAKSIMOVA	{"email": "maksimovanailya_081976@postgrespro.ru", "phone": "+70201322648"}
0005432857920	930011	1140 896859	RAMIL NIKITIN	{"phone": "+70067326878"}
0005432857921	930011	9501 683627	VIKTORIYA NIKITINA	{"email": "v.nikitina-071966@postgrespro.ru", "phone": "+70534173966"}
0005432857922	6E4825	0711 495695	ALEKSANDR KISELEV	{"email": "kiselev-a-051979@postgrespro.ru", "phone": "+70927175945"}
0005432857923	0B6517	1831 357094	YURIY SEMENOV	{"email": "semenov_yuriy_101980@postgrespro.ru", "phone": "+70400226631"}
0005432857924	281D74	4368 899629	NIKOLAY VOLKOV	{"email": "volkovnikolay021979@postgrespro.ru", "phone": "+70825682749"}
0005432857925	D53B4C	5778 220031	IRINA DANILOVA	{"email": "i_danilova-29051972@postgrespro.ru", "phone": "+70518628680"}
0005432857926	FD91A3	1869 797638	RAISA VLASOVA	{"email": "raisa_vlasova_031976@postgrespro.ru", "phone": "+70736304770"}
0005432857927	1A9D75	5692 117383	ALEFTINA BORISOVA	{"phone": "+70535375034"}
0005432857928	22A9EE	7423 254548	SERGEY GORBUNOV	{"email": "gorbunovsergey1971@postgrespro.ru", "phone": "+70082991537"}
0005432857929	A57ED1	1135 032280	EKATERINA FADEEVA	{"email": "fadeeva-ekaterina.26071982@postgrespro.ru", "phone": "+70710212863"}
0005432857930	BBB93C	2549 083126	ANASTASIYA TROFIMOVA	{"phone": "+70591572521"}
0005432857931	3A2127	6508 464380	KIRA KOLESNIKOVA	{"email": "k-kolesnikova_16021974@postgrespro.ru", "phone": "+70372374057"}
0005432857932	572384	5511 544467	ARTEM STEPANOV	{"phone": "+70253757340"}
0005432857933	554F4D	4243 538335	SERGEY AFANASEV	{"email": "afanasev-sergey-1966@postgrespro.ru", "phone": "+70130497663"}
0005432857934	F27F45	9264 142780	DENIS FROLOV	{"phone": "+70358051068"}
0005432857935	F27F45	0753 163652	VALERIYA KUZNECOVA	{"phone": "+70216689396"}
0005432857936	0B5383	7527 920330	ALEKSEY ZAKHAROV	{"phone": "+70603041798"}
0005432857937	C17DF9	2426 004308	SOFYA MAKSIMOVA	{"email": "maksimova_s24061976@postgrespro.ru", "phone": "+70074470542"}
0005432857938	C17DF9	3948 357655	FATIMA AKIMOVA	{"email": "f.akimova.12101972@postgrespro.ru", "phone": "+70832950208"}
0005432857939	C17DF9	3917 245379	EKATERINA VOROBEVA	{"email": "vorobeva.e.1966@postgrespro.ru", "phone": "+70657496364"}
0005432857940	DBC943	4141 158940	MIKHAIL FOMIN	{"phone": "+70194670438"}
0005432857941	DBC943	6174 339193	VIKTOR ZHUKOV	{"email": "viktor_zhukov091962@postgrespro.ru", "phone": "+70957243775"}
0005432857942	0FA3D1	6462 190099	ANFISA PAVLOVA	{"phone": "+70351736097"}
0005432857943	B30810	5872 521182	OKSANA DENISOVA	{"phone": "+70876414369"}
0005432857944	B30810	5430 886925	IGOR PAVLOV	{"email": "pavlovi.1969@postgrespro.ru", "phone": "+70266823283"}
0005432857945	48191F	5076 654403	VLADIMIR BONDARENKO	{"email": "bondarenko-v_1988@postgrespro.ru", "phone": "+70555918433"}
0005432857946	48191F	6637 427412	OLEG KOZLOV	{"email": "olegkozlov_26051965@postgrespro.ru", "phone": "+70338827368"}
0005432857947	59E854	3100 992295	VLADIMIR BORISOV	{"phone": "+70152568214"}
0005432857948	7ACD8A	6171 944677	ALEKSANDR RODIONOV	{"phone": "+70294253387"}
0005432857949	B7FAF8	3941 465374	RINAT MOROZOV	{"phone": "+70764650207"}
0005432857950	B7FAF8	1002 691878	VLADIMIR VASILEV	{"email": "vasilev-vladimir-021977@postgrespro.ru", "phone": "+70389200495"}
0005432857951	67A7F5	8790 271152	BORIS MIKHAYLOV	{"phone": "+70624940105"}
0005432857952	8AEADE	5975 373031	TATYANA ANTONOVA	{"email": "antonova-t16041976@postgrespro.ru", "phone": "+70641785437"}
0005432857953	8AEADE	9682 273464	PETR KULIKOV	{"email": "petr.kulikov1982@postgrespro.ru", "phone": "+70416370613"}
0005432857954	581D56	1932 306660	NATALYA TITOVA	{"email": "titova-n.041973@postgrespro.ru", "phone": "+70704464377"}
0005432857955	48306C	5601 524170	NADIYA POPOVA	{"phone": "+70554181816"}
0005432857956	48306C	5687 962457	EVGENIY ALEKSEEV	{"email": "alekseeve-071965@postgrespro.ru", "phone": "+70753110802"}
0005432857957	8961D3	6750 255748	ALEKSANDR POPOV	{"email": "aleksandr-popov.011974@postgrespro.ru", "phone": "+70019721375"}
0005432857958	81AC2C	2947 530849	IRINA IVANOVA	{"phone": "+70964301624"}
0005432857959	CEDA05	8018 768405	TATYANA MAKAROVA	{"email": "makarova.tatyana.1964@postgrespro.ru", "phone": "+70043392653"}
0005432857960	E41439	5949 612676	DMITRIY SHEVCHENKO	{"phone": "+70187161999"}
0005432857961	43450A	2199 276831	SERGEY RODIONOV	{"phone": "+70212787240"}
0005432857962	43450A	8708 133289	ALEKSANDR BARANOV	{"email": "aleksandr.baranov1978@postgrespro.ru", "phone": "+70876207718"}
0005432857963	E13BF6	6916 570543	KRISTINA ILINA	{"email": "kristina.ilina_02011978@postgrespro.ru", "phone": "+70454174790"}
0005432857964	E13BF6	6494 217934	MARIYA MIKHAYLOVA	{"email": "mariya.mikhaylova.06031962@postgrespro.ru", "phone": "+70093655699"}
0005432857965	411F62	9619 549295	OKSANA DENISOVA	{"email": "odenisova24081964@postgrespro.ru", "phone": "+70857053827"}
0005432857966	29B66D	1896 537769	TATYANA EGOROVA	{"email": "tatyana-egorova-1959@postgrespro.ru", "phone": "+70880642044"}
0005432857967	FB4939	3305 291452	SERGEY FEDOROV	{"email": "sergey_fedorov.1961@postgrespro.ru", "phone": "+70327207825"}
0005432857968	7BD74A	2639 746060	VYACHESLAV GERASIMOV	{"phone": "+70551855637"}
0005432857969	7BD74A	0010 795047	VLADIMIR FEDOROV	{"phone": "+70012214942"}
0005432857970	00CDD6	4062 167040	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr_101968@postgrespro.ru", "phone": "+70075630754"}
0005432857971	00CDD6	9328 824221	IVAN ISAEV	{"phone": "+70200581422"}
0005432857972	D0DB16	1197 971104	TATYANA LOGINOVA	{"email": "t.loginova-20081977@postgrespro.ru", "phone": "+70404037601"}
0005432857973	7D0F6C	1658 202046	MARIYA MOROZOVA	{"phone": "+70035452816"}
0005432857974	B51BDD	5281 848784	PAVEL GORBUNOV	{"phone": "+70391553500"}
0005432857975	9A0426	1276 086647	ALEKSEY GRIGOREV	{"email": "grigorev.a-061971@postgrespro.ru", "phone": "+70359789433"}
0005432857976	84879E	9707 924601	IVAN ZAKHAROV	{"phone": "+70356458174"}
0005432857977	E4EF3B	4276 783285	NATALYA BOGDANOVA	{"phone": "+70233605585"}
0005432857978	E4EF3B	6954 040087	NATALYA KARPOVA	{"phone": "+70529679049"}
0005432857979	FAA955	3636 007244	LYUBOV KUZMINA	{"phone": "+70037115861"}
0005432857980	FAA955	4159 556579	ANATOLIY SCHERBAKOV	{"phone": "+70126313882"}
0005432857981	214776	9631 477011	VIKTOR IVANOV	{"phone": "+70780209576"}
0005432857982	1AF9FE	3023 438626	VALENTINA SOROKINA	{"email": "vsorokina_1982@postgrespro.ru", "phone": "+70077669337"}
0005432857983	5B6BC6	5637 282788	VIKTOR SOROKIN	{"email": "viktor_sorokin1965@postgrespro.ru", "phone": "+70759947246"}
0005432857984	237E4D	2578 186697	ALEKSANDR ALEKSANDROV	{"email": "a_aleksandrov_1974@postgrespro.ru", "phone": "+70205629114"}
0005432857985	237E4D	9761 669445	NIKOLAY SAVELEV	{"email": "savelev_nikolay_1966@postgrespro.ru", "phone": "+70546513225"}
0005432857986	C395B3	2109 583251	NIKOLAY FEDOTOV	{"phone": "+70229045545"}
0005432857987	C395B3	4407 008823	ALEKSANDR KOZLOV	{"email": "a-kozlov.121962@postgrespro.ru", "phone": "+70816492246"}
0005432857988	014468	6957 750736	NIKOLAY CHERNOV	{"phone": "+70165596137"}
0005432857989	014468	9240 433928	DMITRIY ZHUKOV	{"email": "zhukov-dmitriy.111972@postgrespro.ru", "phone": "+70784106329"}
0005432857990	5E36BD	2226 020692	YULIYA CHERNOVA	{"email": "yuliya-chernova_1971@postgrespro.ru", "phone": "+70533178566"}
0005432857991	D08F29	3271 179060	SERGEY PETROV	{"phone": "+70327523320"}
0005432857992	3D4A74	8028 111516	YURIY VOROBEV	{"email": "y_vorobev_1975@postgrespro.ru", "phone": "+70035596326"}
0005432857993	A972FA	7242 593149	TATYANA ALEKSEEVA	{"email": "alekseeva.t1974@postgrespro.ru", "phone": "+70676922952"}
0005432857994	A972FA	9264 268922	LYUDMILA KISELEVA	{"email": "kiseleva.lyudmila.081974@postgrespro.ru", "phone": "+70465975710"}
0005432857995	A972FA	5228 947789	IVAN ZAKHAROV	{"email": "ivan_zakharov_061972@postgrespro.ru", "phone": "+70220850028"}
0005432857996	059702	4331 708270	ELENA ZAKHAROVA	{"email": "zakharova_elena_1974@postgrespro.ru", "phone": "+70783873163"}
0005432857997	059702	0169 895507	KIRILL KUZNECOV	{"email": "kuznecov-kirill-11071964@postgrespro.ru", "phone": "+70373595119"}
0005432857998	E519F6	3016 798316	VLADIMIR POPOV	{"phone": "+70365793930"}
0005432857999	AAC215	4600 277134	ALEKSANDR BARANOV	{"email": "baranov-aleksandr061976@postgrespro.ru", "phone": "+70918942497"}
0005432858000	F01A71	4443 216645	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-aleksandr-1968@postgrespro.ru", "phone": "+70638078922"}
0005432858001	2F964D	4789 455223	DANIIL ROMANOV	{"email": "romanov.d-22061961@postgrespro.ru", "phone": "+70990202258"}
0005432858002	2F964D	5985 178447	VLADISLAV EGOROV	{"email": "egorov.v.101955@postgrespro.ru", "phone": "+70738157565"}
0005432858003	FFE456	2575 516662	NATALYA SEMENOVA	{"phone": "+70212905325"}
0005432858004	2D9780	9158 365059	VLADISLAV ANDREEV	{"email": "v_andreev.04101974@postgrespro.ru", "phone": "+70578284319"}
0005432858005	2D9780	0072 742755	NATALYA BARANOVA	{"email": "natalya-baranova1975@postgrespro.ru", "phone": "+70549933379"}
0005432858006	2D9780	1375 530283	MIKHAIL KRASNOV	{"phone": "+70610278965"}
0005432858007	2D10CC	3264 475453	NADEZHDA ERMAKOVA	{"phone": "+70026030607"}
0005432858008	D20B8D	7239 263227	ANNA ANDREEVA	{"phone": "+70163432866"}
0005432858009	188406	5207 992565	FEDOR SOKOLOV	{"email": "fedor.sokolov_031971@postgrespro.ru", "phone": "+70856943253"}
0005432858010	030A89	7931 469055	SERGEY KOZLOV	{"email": "sergeykozlov_1977@postgrespro.ru", "phone": "+70103652560"}
0005432858011	59AF6D	2558 953148	ILYA SERGEEV	{"email": "i.sergeev28081967@postgrespro.ru", "phone": "+70430536910"}
0005432858012	59AF6D	6831 002867	MARIYA GAVRILOVA	{"email": "mgavrilova_11051963@postgrespro.ru", "phone": "+70207151873"}
0005432858013	3A0C1C	7294 135783	IRINA NIKITINA	{"email": "irina-nikitina.031973@postgrespro.ru", "phone": "+70870930038"}
0005432858014	25F666	6985 895363	VALERIY KUZMIN	{"email": "valeriy-kuzmin121976@postgrespro.ru", "phone": "+70710632140"}
0005432858015	25F666	4275 237414	GALINA ORLOVA	{"email": "galina_orlova_1965@postgrespro.ru", "phone": "+70193518921"}
0005432858016	71E2CC	6314 777661	YULIYA MOROZOVA	{"phone": "+70130809151"}
0005432858017	D06778	8165 134285	NATALYA LAZAREVA	{"phone": "+70848837328"}
0005432858018	545B05	9671 921514	YURIY KUZNECOV	{"email": "y.kuznecov_031974@postgrespro.ru", "phone": "+70236635532"}
0005432858019	935543	1587 558309	VIKTOR TIKHONOV	{"phone": "+70423765252"}
0005432858020	5EA721	9582 890350	DMITRIY VOLKOV	{"phone": "+70225613652"}
0005432858021	B96CEA	7865 608016	SERGEY IVANOV	{"email": "ivanovsergey.24031971@postgrespro.ru", "phone": "+70249933977"}
0005432858022	B96CEA	4932 347238	DMITRIY MAKAROV	{"phone": "+70624001038"}
0005432858023	FC561E	0557 730915	ANDREY FOMIN	{"email": "fomin-a-31101970@postgrespro.ru", "phone": "+70751036136"}
0005432858024	503366	9121 418095	DANILA MIRONOV	{"phone": "+70912682968"}
0005432858025	3DFE03	6922 448727	TAMARA VOROBEVA	{"phone": "+70933301303"}
0005432858026	07F7D4	8837 688377	ELENA PETROVA	{"email": "elenapetrova1967@postgrespro.ru", "phone": "+70609106800"}
0005432858027	07F7D4	3372 545920	DARYA MIKHAYLOVA	{"email": "darya_mikhaylova071971@postgrespro.ru", "phone": "+70095799412"}
0005432858028	07F7D4	9666 938405	VIKTORIYA MASLOVA	{"email": "viktoriyamaslova-111971@postgrespro.ru", "phone": "+70058130384"}
0005432858029	07F7D4	2428 197857	EKATERINA STEPANOVA	{"phone": "+70865821457"}
0005432858030	CE3ADD	6911 715276	ARTEM SERGEEV	{"email": "sergeev_a_1966@postgrespro.ru", "phone": "+70571251688"}
0005432858031	ECAAFD	8120 620567	MARGARITA KULIKOVA	{"email": "m_kulikova_091977@postgrespro.ru", "phone": "+70404252544"}
0005432858032	149085	8250 343519	EKATERINA BORISOVA	{"phone": "+70650713682"}
0005432858033	E00E8D	7645 712319	VYACHESLAV PAVLOV	{"email": "pavlov-vyacheslav.29111964@postgrespro.ru", "phone": "+70269529973"}
0005432858034	94D00F	0081 322196	ELENA TARASOVA	{"phone": "+70629897279"}
0005432858035	C2918E	6109 880473	SERGEY KRASNOV	{"email": "skrasnov_111983@postgrespro.ru", "phone": "+70074228276"}
0005432858036	88C87C	3884 403296	DENIS SOROKIN	{"phone": "+70234740410"}
0005432858037	88C87C	4950 989565	ELENA SAVELEVA	{"phone": "+70009835009"}
0005432858038	69E2E0	5912 360522	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova.24041982@postgrespro.ru", "phone": "+70969756921"}
0005432858039	E8781F	8477 340837	ANDREY ZAKHAROV	{"phone": "+70974917108"}
0005432858040	855F32	4001 501392	SVETLANA ABRAMOVA	{"email": "sabramova-23071976@postgrespro.ru", "phone": "+70224914749"}
0005432858041	73FC5F	9403 440065	ROMAN SIDOROV	{"phone": "+70833908284"}
0005432858042	C5A462	4963 439027	SERGEY PAVLOV	{"email": "pavlov.s-16091971@postgrespro.ru", "phone": "+70102533055"}
0005432858043	C5A462	4310 982083	ALEKSANDRA RODIONOVA	{"email": "a_rodionova_1975@postgrespro.ru", "phone": "+70469677382"}
0005432858044	5BAF0C	4146 597472	ANASTASIYA GRISHINA	{"email": "a-grishina.031974@postgrespro.ru", "phone": "+70105246543"}
0005432858045	5BAF0C	5541 361804	VIKTOR ROMANOV	{"email": "viktor-romanov111982@postgrespro.ru", "phone": "+70569252894"}
0005432858046	BFAB9A	1553 170973	SHAVKAT NOVIKOV	{"email": "shavkatnovikov_1966@postgrespro.ru", "phone": "+70204188744"}
0005432858047	C7A6E7	8833 199800	VALERIYA KUZNECOVA	{"email": "valeriyakuznecova031969@postgrespro.ru", "phone": "+70646758608"}
0005432858048	610C2A	4523 008071	MARIYA KALININA	{"email": "m-kalinina_25011978@postgrespro.ru", "phone": "+70857929755"}
0005432858049	610C2A	9544 087977	NATALYA GAVRILOVA	{"phone": "+70904952936"}
0005432858050	21DB62	6031 488818	MIKHAIL MEDVEDEV	{"phone": "+70482361182"}
0005432858051	CB4601	6334 011117	MARINA BARANOVA	{"email": "marina-baranova.29051971@postgrespro.ru", "phone": "+70038208529"}
0005432858052	C3E11A	3993 905716	ALEKSANDR GUSEV	{"phone": "+70278236999"}
0005432858053	C3E11A	1128 840838	PETR MAKAROV	{"email": "makarovp.09041977@postgrespro.ru", "phone": "+70705243967"}
0005432858054	4EEDF1	4577 913366	VLADIMIR ABRAMOV	{"phone": "+70968114323"}
0005432858055	32C9FB	4832 371176	KONSTANTIN ORLOV	{"phone": "+70866892752"}
0005432858056	F12D4D	7935 906937	NINA POPOVA	{"phone": "+70227878894"}
0005432858057	63A7CA	6198 430351	NIKITA PAVLOV	{"phone": "+70971719751"}
0005432858058	63A7CA	9986 856333	TATYANA MATVEEVA	{"phone": "+70378670687"}
0005432858059	EE8535	4740 021045	VIKTORIYA ROMANOVA	{"email": "romanovav.081967@postgrespro.ru", "phone": "+70224345502"}
0005432858060	27F3B5	4940 440930	NATALYA AFANASEVA	{"email": "afanaseva_n-1968@postgrespro.ru", "phone": "+70161759183"}
0005432858061	9EB49F	2859 045519	ANDREY VASILEV	{"phone": "+70578200297"}
0005432858062	C84C32	0717 531754	ALEKSANDR MATVEEV	{"email": "matveev.a-1976@postgrespro.ru", "phone": "+70451362850"}
0005432858063	A52BEE	1385 506893	VYACHESLAV SOKOLOV	{"email": "sokolov-vyacheslav19041969@postgrespro.ru", "phone": "+70625873386"}
0005432858064	6FFD74	0269 066881	ELDAR FROLOV	{"email": "e.frolov1965@postgrespro.ru", "phone": "+70379318560"}
0005432858065	440949	3622 509252	TAMARA KOROLEVA	{"phone": "+70233623079"}
0005432858066	CCBBCA	3104 058319	ANDREY MAKSIMOV	{"phone": "+70424283549"}
0005432858067	CCBBCA	6117 225347	VASILIY KUDRYASHOV	{"phone": "+70065526918"}
0005432858068	1A23D7	6487 055020	TATYANA VLASOVA	{"phone": "+70691937738"}
0005432858069	BD5187	2761 719192	DANA ZAKHAROVA	{"email": "d.zakharova_081971@postgrespro.ru", "phone": "+70404292547"}
0005432858070	01A568	2386 257163	ROMAN VOROBEV	{"email": "roman.vorobev1979@postgrespro.ru", "phone": "+70929033440"}
0005432858071	76DC60	7402 387205	ELENA MATVEEVA	{"email": "matveeva-elena-071971@postgrespro.ru", "phone": "+70112847039"}
0005432858072	76DC60	1545 329148	NIKOLAY POPOV	{"phone": "+70468888725"}
0005432858073	AE0F38	0229 207501	VALENTIN MEDVEDEV	{"email": "valentin.medvedev-05091970@postgrespro.ru", "phone": "+70893725696"}
0005432858074	837206	4391 914015	VLADIMIR MELNIKOV	{"phone": "+70351503812"}
0005432858075	C905DA	0952 691215	YURIY MOROZOV	{"email": "morozovyuriy_1977@postgrespro.ru", "phone": "+70105955158"}
0005432858076	31AF1E	1615 894896	IVAN PETROV	{"phone": "+70917649631"}
0005432858077	A05301	5402 141784	ARTUR KOROLEV	{"phone": "+70454058075"}
0005432858078	A05301	5241 274727	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov-071977@postgrespro.ru", "phone": "+70195864513"}
0005432858079	77A588	1225 185552	NINA VASILEVA	{"email": "nvasileva-051966@postgrespro.ru", "phone": "+70531008988"}
0005432858080	68AD52	0031 485444	TATYANA KAZAKOVA	{"email": "kazakovatatyana_1970@postgrespro.ru", "phone": "+70961625369"}
0005432858081	CDD198	1605 846419	ANDREY SCHERBAKOV	{"phone": "+70721071340"}
0005432858082	68933A	0260 735015	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov081958@postgrespro.ru", "phone": "+70713795839"}
0005432858083	C73951	1693 701730	GENNADIY ROMANOV	{"phone": "+70857583481"}
0005432858084	C73951	4017 661953	YULIYA ISAEVA	{"email": "isaeva.yuliya-1980@postgrespro.ru", "phone": "+70737203912"}
0005432858085	8709EB	5708 971756	SERGEY ABRAMOV	{"phone": "+70988035654"}
0005432858086	8629C0	9394 224744	VALENTIN NOVIKOV	{"email": "valentinnovikov-12051963@postgrespro.ru", "phone": "+70955499350"}
0005432858087	B1BA68	5041 456886	NADEZHDA MIKHAYLOVA	{"phone": "+70182259957"}
0005432858088	B1BA68	4997 535574	MARINA NESTEROVA	{"email": "nesterova_marina-01051971@postgrespro.ru", "phone": "+70001085284"}
0005432858089	B1BA68	7323 874688	IGOR KRASNOV	{"phone": "+70226842837"}
0005432858090	3C7B6A	3608 123948	MAKSIM KAZAKOV	{"phone": "+70015348764"}
0005432858091	DB6A7D	4374 158689	ARINA AKIMOVA	{"email": "arina.akimova10091976@postgrespro.ru", "phone": "+70167221609"}
0005432858092	6E3A25	9981 681010	KRISTINA MIKHAYLOVA	{"phone": "+70328274712"}
0005432858093	AA474E	3230 423854	ANDREY KUZNECOV	{"email": "kuznecov_a.081982@postgrespro.ru", "phone": "+70316519664"}
0005432858094	82AFB9	3742 575164	TATYANA MASLOVA	{"phone": "+70417550722"}
0005432858095	82AFB9	1155 564871	ANDREY NOVIKOV	{"email": "novikov-andrey1975@postgrespro.ru", "phone": "+70625332577"}
0005432858096	5B7F4E	0385 843981	MARIYA YUDINA	{"phone": "+70788180909"}
0005432858097	5B7F4E	2496 297819	ALEKSEY GRIGOREV	{"email": "grigorev_aleksey-031977@postgrespro.ru", "phone": "+70714131663"}
0005432858098	BB41FF	0828 159293	SVETLANA DAVYDOVA	{"phone": "+70118529070"}
0005432858099	BB41FF	6810 933946	ALINA IVANOVA	{"phone": "+70699444718"}
0005432858100	07CDA3	8942 369071	EDUARD IVANOV	{"email": "ivanov-e.011976@postgrespro.ru", "phone": "+70875866233"}
0005432858101	344956	2191 402823	KLAVDIYA KONDRATEVA	{"phone": "+70920313167"}
0005432858102	344956	2194 723832	ELENA NIKIFOROVA	{"phone": "+70769857323"}
0005432858103	1C0231	4180 151110	ANDREY SMIRNOV	{"phone": "+70711568592"}
0005432858104	7972EB	7609 532571	VERA KOROLEVA	{"email": "v-koroleva_071974@postgrespro.ru", "phone": "+70365204329"}
0005432858105	7972EB	4135 712074	IRINA GAVRILOVA	{"email": "gavrilovairina.011971@postgrespro.ru", "phone": "+70733138546"}
0005432858106	8E0118	4980 333957	YULIYA IVANOVA	{"phone": "+70601374294"}
0005432858107	7FBFFF	7496 140681	VITALIY FILIPPOV	{"email": "vitaliy.filippov071970@postgrespro.ru", "phone": "+70425462035"}
0005432858108	7FBFFF	8010 686028	YULIYA LAZAREVA	{"email": "lazareva_yuliya_08071972@postgrespro.ru", "phone": "+70543388680"}
0005432858109	B1DFD7	4346 688550	GENNADIY PETROV	{"email": "gennadiypetrov_051973@postgrespro.ru", "phone": "+70936497445"}
0005432858110	F3235F	8799 970304	ALEKSEY ALEKSEEV	{"phone": "+70162366896"}
0005432858111	F3235F	8528 797248	ALEKSEY SAVELEV	{"email": "aleksey-savelev1969@postgrespro.ru", "phone": "+70192271891"}
0005432858112	9F03DD	6213 773022	DENIS BELOV	{"email": "belovdenis_07091970@postgrespro.ru", "phone": "+70807665724"}
0005432858113	2C84E6	6815 067589	ANTONINA FILIPPOVA	{"email": "antoninafilippova-31081969@postgrespro.ru", "phone": "+70214176448"}
0005432858114	2C84E6	1336 119982	LIDIYA KISELEVA	{"phone": "+70491236509"}
0005432858115	335F5F	0836 769365	PAVEL ILIN	{"email": "pavel.ilin_011965@postgrespro.ru", "phone": "+70758937203"}
0005432858116	41D158	6938 890478	ALEKSEY ROMANOV	{"phone": "+70840760412"}
0005432858117	A87DE5	7914 257085	ILYA SOROKIN	{"phone": "+70417828306"}
0005432858118	599209	3569 306797	VLADIMIR NIKITIN	{"email": "nikitin_vladimir-111972@postgrespro.ru", "phone": "+70958136303"}
0005432858119	599209	4708 616292	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v-1968@postgrespro.ru", "phone": "+70833084391"}
0005432858120	09F435	0900 672567	PETR GUSEV	{"email": "gusevpetr1968@postgrespro.ru", "phone": "+70311107912"}
0005432858121	09F435	8019 918199	ANNA MIRONOVA	{"phone": "+70443522025"}
0005432858122	142864	6869 173632	TAMARA BELOVA	{"phone": "+70899902754"}
0005432858123	A88244	3119 571703	GENNADIY FEDOTOV	{"phone": "+70705170665"}
0005432858124	263D9E	8835 321155	MARINA ZHURAVLEVA	{"email": "marina_zhuravleva-1968@postgrespro.ru", "phone": "+70209779596"}
0005432858125	D7F79E	1487 071564	SVETLANA MAKSIMOVA	{"email": "maksimova.s_071971@postgrespro.ru", "phone": "+70557232022"}
0005432858126	C71B4C	3670 770773	ELENA YUDINA	{"email": "yudinaelena_1982@postgrespro.ru", "phone": "+70417717851"}
0005432858127	C71B4C	9550 552185	VALENTINA POPOVA	{"email": "valentina.popova.1989@postgrespro.ru", "phone": "+70861969080"}
0005432858128	4E123F	9731 294177	ELENA SMIRNOVA	{"email": "esmirnova-101973@postgrespro.ru", "phone": "+70268304503"}
0005432858129	696F53	4210 657001	DMITRIY AFANASEV	{"phone": "+70704862830"}
0005432858130	DFC128	2487 627539	NATALYA KOROLEVA	{"email": "natalya-koroleva_01041972@postgrespro.ru", "phone": "+70872704439"}
0005432858131	F469BE	5800 895690	EKATERINA KUZNECOVA	{"phone": "+70672823422"}
0005432858132	B26F35	5715 909562	NATALYA KOZLOVA	{"phone": "+70552858867"}
0005432858133	A7F4CC	2409 727273	VALERIY VOROBEV	{"email": "v_vorobev_1977@postgrespro.ru", "phone": "+70392080910"}
0005432858134	9EDE94	4345 105884	LYUDMILA ABRAMOVA	{"email": "lyudmila_abramova_091977@postgrespro.ru", "phone": "+70781946050"}
0005432858135	6F0C40	3436 022470	TATYANA ALEKSEEVA	{"phone": "+70222058934"}
0005432858136	F9EA0F	4315 206617	SERGEY PETROV	{"email": "petrovs1967@postgrespro.ru", "phone": "+70872918477"}
0005432858137	F9EA0F	5527 339269	IVAN ILIN	{"email": "ilinivan031976@postgrespro.ru", "phone": "+70311408694"}
0005432858138	40BACA	9386 951776	VLADIMIR ANDREEV	{"phone": "+70872105581"}
0005432858139	0467EE	3944 668178	NINA IVANOVA	{"phone": "+70341250786"}
0005432858140	0467EE	9027 942621	NIKOLAY TARASOV	{"email": "nikolay_tarasov1964@postgrespro.ru", "phone": "+70359528915"}
0005432858141	0467EE	2044 121465	ALEKSEY KARPOV	{"email": "a.karpov-26081975@postgrespro.ru", "phone": "+70663004170"}
0005432858142	6F68B9	7092 644939	ZOYA SMIRNOVA	{"phone": "+70744523143"}
0005432858143	6F02D4	6663 693852	TATYANA SIDOROVA	{"phone": "+70867357070"}
0005432858144	DEAD5E	9481 385600	ALEKSANDR CHERNOV	{"email": "aleksandrchernov_16041973@postgrespro.ru", "phone": "+70501239572"}
0005432858145	969622	1258 892095	TAMARA NIKOLAEVA	{"email": "tamara-nikolaeva-03021966@postgrespro.ru", "phone": "+70651886250"}
0005432858146	969622	1392 243486	LEONID MARTYNOV	{"email": "martynov.leonid11061964@postgrespro.ru", "phone": "+70295996703"}
0005432858147	366185	3014 853249	VLADIMIR OSIPOV	{"email": "v.osipov05041972@postgrespro.ru", "phone": "+70718725843"}
0005432858148	753FD3	8504 741797	TATYANA SOKOLOVA	{"email": "tsokolova_27101964@postgrespro.ru", "phone": "+70751225357"}
0005432858149	22AD8B	9514 023831	STANISLAV ORLOV	{"email": "orlovs-28041968@postgrespro.ru", "phone": "+70473956334"}
0005432858150	BCDAAC	4037 954702	SERGEY BORISOV	{"email": "s-borisov111973@postgrespro.ru", "phone": "+70987201452"}
0005432858151	BCDAAC	7780 389661	ALEKSANDR NIKOLAEV	{"phone": "+70938845398"}
0005432858152	761BAE	4734 883428	MARIYA SOKOLOVA	{"phone": "+70224431025"}
0005432858153	761BAE	8882 416845	TAISIYA FILATOVA	{"phone": "+70969080079"}
0005432858154	3E3F86	0694 396231	SERGEY FOMIN	{"phone": "+70618217125"}
0005432858155	14A9B2	1091 629431	ALEKSANDR BORISOV	{"email": "borisova-031967@postgrespro.ru", "phone": "+70151741790"}
0005432858156	DBB37B	5661 266679	MAKSIM KULIKOV	{"email": "m-kulikov_111974@postgrespro.ru", "phone": "+70406944516"}
0005432858157	AC45B1	5841 145675	ZINAIDA TIKHONOVA	{"email": "z_tikhonova_25121974@postgrespro.ru", "phone": "+70033179203"}
0005432858158	7D778D	5053 393374	VIKTOR PAVLOV	{"phone": "+70829011144"}
0005432858159	5CD342	7408 569680	NADEZHDA BORISOVA	{"email": "n-borisova.1970@postgrespro.ru", "phone": "+70258319865"}
0005432858160	E8E11F	5288 367241	VIKTOR MOROZOV	{"phone": "+70463099234"}
0005432858161	27D83B	4534 625677	VALERIY TIMOFEEV	{"phone": "+70924672557"}
0005432858162	444C00	8265 093124	SVETLANA SCHERBAKOVA	{"email": "s.scherbakova051969@postgrespro.ru", "phone": "+70807594165"}
0005432858163	A13C17	7026 266031	NADEZHDA AFANASEVA	{"email": "n.afanaseva_1983@postgrespro.ru", "phone": "+70230169652"}
0005432858164	A13C17	0255 137394	YURIY NAUMOV	{"email": "y_naumov_1974@postgrespro.ru", "phone": "+70072697713"}
0005432858165	DAA135	6570 943272	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev16081979@postgrespro.ru", "phone": "+70006413378"}
0005432858166	0D0793	8237 657283	SERGEY NOVIKOV	{"phone": "+70639378034"}
0005432858167	C5DF7D	5446 286209	ANDREY TARASOV	{"email": "atarasov_1966@postgrespro.ru", "phone": "+70291950378"}
0005432858168	E59AC1	0257 992579	KSENIYA KOLESNIKOVA	{"email": "kolesnikova.kseniya-1971@postgrespro.ru", "phone": "+70438010707"}
0005432858169	00AEA8	3628 123026	SERGEY ALEKSANDROV	{"email": "aleksandrov-s12051963@postgrespro.ru", "phone": "+70984227542"}
0005432858170	00AEA8	6106 961126	VASILIY PAVLOV	{"email": "pavlovvasiliy_011972@postgrespro.ru", "phone": "+70937092927"}
0005432858171	636CAF	9243 181255	EVGENIY SOROKIN	{"email": "evgeniy_sorokin.081977@postgrespro.ru", "phone": "+70815144797"}
0005432858172	636CAF	1336 773930	NATALYA GORBUNOVA	{"email": "natalyagorbunova_021975@postgrespro.ru", "phone": "+70167261944"}
0005432858173	643D9F	1241 000235	IGOR NIKITIN	{"phone": "+70071356711"}
0005432858174	DD05F9	6702 229296	VERA YAKOVLEVA	{"phone": "+70873171555"}
0005432858175	B3DBD7	4175 934777	ANNA ARKHIPOVA	{"email": "anna_arkhipova.1984@postgrespro.ru", "phone": "+70981334993"}
0005432858176	B3DBD7	2949 384711	YURIY IVANOV	{"phone": "+70866309268"}
0005432858177	0439C4	3778 294904	ALEKSEY MEDVEDEV	{"phone": "+70125542548"}
0005432858178	6FE00F	7226 944388	OLGA LEBEDEVA	{"phone": "+70913613688"}
0005432858179	6FE00F	2159 001874	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr-1967@postgrespro.ru", "phone": "+70707611567"}
0005432858180	6FE00F	1606 173313	ALEKSEY PETROV	{"phone": "+70961698877"}
0005432858181	6D8127	1421 572915	YANA NIKIFOROVA	{"phone": "+70864045247"}
0005432858182	0200C3	8956 405338	TATYANA MEDVEDEVA	{"email": "tatyana-medvedeva_10101968@postgrespro.ru", "phone": "+70206657580"}
0005432858183	0200C3	3469 073432	VLADIMIR KONOVALOV	{"email": "v_konovalov121962@postgrespro.ru", "phone": "+70681278332"}
0005432858184	892B5D	8611 967293	ALEKSANDR SAVELEV	{"phone": "+70071898659"}
0005432858185	C33053	3972 488648	SVETLANA GAVRILOVA	{"phone": "+70832896630"}
0005432858186	BBF89D	1821 025007	TATYANA RODIONOVA	{"email": "rodionovatatyana-1975@postgrespro.ru", "phone": "+70393825425"}
0005432858187	EAE468	7180 073013	ANTONINA YAKOVLEVA	{"phone": "+70722016438"}
0005432858188	EAE468	7982 465363	LYUDMILA KULIKOVA	{"email": "kulikova_lyudmila021965@postgrespro.ru", "phone": "+70088131011"}
0005432858189	5F572F	9621 633982	DANIIL VOROBEV	{"email": "d_vorobev_04081977@postgrespro.ru", "phone": "+70563056862"}
0005432858190	1DB483	6470 429974	IGOR ZAKHAROV	{"phone": "+70053147649"}
0005432858191	A6B693	5223 647922	NINA AKIMOVA	{"phone": "+70708559288"}
0005432858192	08AC35	7886 975298	DMITRIY MELNIKOV	{"phone": "+70326799579"}
0005432858193	BC6E6D	5040 877474	TATYANA BELOVA	{"phone": "+70928574566"}
0005432858194	BC6E6D	7478 717385	MIKHAIL VOLKOV	{"phone": "+70569366672"}
0005432858195	CDCAFD	7706 142034	DANIL IVANOV	{"email": "ivanov.d.1965@postgrespro.ru", "phone": "+70741606731"}
0005432858252	3C2FD8	6385 177446	VIKTOR DENISOV	{"phone": "+70079840246"}
0005432858196	CDCAFD	8793 335668	ELIZAVETA ROMANOVA	{"email": "romanova_elizaveta_1962@postgrespro.ru", "phone": "+70427730765"}
0005432858197	28003B	9261 557890	VALERIY SEMENOV	{"phone": "+70781228365"}
0005432858198	28003B	4690 330347	IGOR PETROV	{"email": "petrov.igor_1972@postgrespro.ru", "phone": "+70113493500"}
0005432858199	DA1A66	6881 408718	ALEKSEY IVANOV	{"phone": "+70603004908"}
0005432858200	BF0548	0449 004363	VALERIY NIKOLAEV	{"phone": "+70065390900"}
0005432858201	E6356F	5832 287499	VALENTINA SIDOROVA	{"phone": "+70200185538"}
0005432858202	FA0571	2828 214010	EVGENIYA VASILEVA	{"phone": "+70538741502"}
0005432858203	2A9483	0860 101240	VITALIY ALEKSANDROV	{"phone": "+70242775391"}
0005432858204	1C123A	0486 733072	NIKOLAY TIMOFEEV	{"email": "n.timofeev-081964@postgrespro.ru", "phone": "+70148567081"}
0005432858205	1C123A	5915 041069	LYUDMILA CHERNOVA	{"phone": "+70330527960"}
0005432858206	525E67	6941 367286	VLADIMIR TARASOV	{"email": "v-tarasov_121976@postgrespro.ru", "phone": "+70769649415"}
0005432858207	525E67	5533 333632	IRAIDA MARTYNOVA	{"email": "martynova-iraida19071972@postgrespro.ru", "phone": "+70323297437"}
0005432858208	ECD4EF	9393 739072	YULIYA CHERNOVA	{"phone": "+70110789041"}
0005432858209	ECD4EF	8767 131762	ALEKSEY VASILEV	{"email": "alekseyvasilev.061967@postgrespro.ru", "phone": "+70949027302"}
0005432858210	5DDB02	1135 083206	ALEKSANDR KRASNOV	{"phone": "+70929356247"}
0005432858211	5DDB02	1571 778403	GALINA KUZNECOVA	{"email": "g.kuznecova_05031979@postgrespro.ru", "phone": "+70200816473"}
0005432858212	46155D	6567 564141	LYUBOV KUZMINA	{"email": "l-kuzmina.21011980@postgrespro.ru", "phone": "+70258859778"}
0005432858213	1F2612	2928 858604	ARSENIY SIDOROV	{"email": "arseniy-sidorov051972@postgrespro.ru", "phone": "+70071983094"}
0005432858214	6DF82D	1522 450454	NIKOLAY MIKHAYLOV	{"phone": "+70633308116"}
0005432858215	6DF82D	2521 689453	POLINA NESTEROVA	{"email": "polina.nesterova.1972@postgrespro.ru", "phone": "+70496623931"}
0005432858216	00EF4D	1655 061733	VLADIMIR NAUMOV	{"phone": "+70610937812"}
0005432858217	00EF4D	6229 041723	GEVORG DAVYDOV	{"email": "davydovgevorg-081976@postgrespro.ru", "phone": "+70356631850"}
0005432858218	A2DAF2	3777 404290	NIKOLAY FEDOROV	{"email": "nikolay_fedorov_1961@postgrespro.ru", "phone": "+70396195150"}
0005432858219	01BE2B	0053 747863	ANDREY TIKHONOV	{"email": "tikhonovandrey07091974@postgrespro.ru", "phone": "+70129170824"}
0005432858220	01BE2B	8867 394156	VALENTINA ZHUKOVA	{"email": "valentina-zhukova_1972@postgrespro.ru", "phone": "+70011136627"}
0005432858221	E9C158	5956 043151	ANATOLIY SMIRNOV	{"email": "anatoliysmirnov_11041960@postgrespro.ru", "phone": "+70035321239"}
0005432858222	AC2433	0311 654533	RAVIL POPOV	{"email": "r.popov_1958@postgrespro.ru", "phone": "+70760549657"}
0005432858223	98B4AA	2291 570173	LYUBOV BORISOVA	{"phone": "+70974025451"}
0005432858224	98B4AA	7574 489378	ALEKSANDRA MELNIKOVA	{"phone": "+70989077247"}
0005432858225	7AC8C6	6837 765274	SVETLANA PETROVA	{"phone": "+70452552473"}
0005432858226	7AC8C6	7065 647374	SERGEY VLASOV	{"email": "sergey_vlasov05061974@postgrespro.ru", "phone": "+70201082469"}
0005432858227	7AC8C6	5324 407075	VALENTINA EGOROVA	{"phone": "+70497434250"}
0005432858228	342D33	1186 192637	NIKOLAY KUZNECOV	{"phone": "+70398618240"}
0005432858229	BD4E8A	8017 354626	ALEKSANDR SOLOVEV	{"phone": "+70467928006"}
0005432858230	BD4E8A	6359 696799	NATALYA MAKAROVA	{"email": "n.makarova_06041975@postgrespro.ru", "phone": "+70162841839"}
0005432858231	561457	7693 616183	OLGA KONOVALOVA	{"phone": "+70761125995"}
0005432858232	360250	5559 236329	MARIYA GUSEVA	{"email": "guseva_m_26051968@postgrespro.ru", "phone": "+70954803411"}
0005432858356	7206BB	8692 393925	OLGA ZOTOVA	{"phone": "+70630744722"}
0005432858233	D0AA54	6948 418748	ELENA POPOVA	{"email": "popova-elena-16021969@postgrespro.ru", "phone": "+70302926099"}
0005432858234	D0AA54	8992 361240	IRINA KAZAKOVA	{"email": "kazakova_irina-091975@postgrespro.ru", "phone": "+70806013847"}
0005432858235	7E782C	6484 968961	ROMAN GRIGOREV	{"email": "grigorev-r-111969@postgrespro.ru", "phone": "+70908756335"}
0005432858236	7E782C	0814 416288	SERGEY VOLKOV	{"phone": "+70577297975"}
0005432858237	7E782C	5801 018279	TIMOFEY BORISOV	{"email": "borisovtimofey_031971@postgrespro.ru", "phone": "+70402997973"}
0005432858238	A4CF9E	0162 041393	EGOR RODIONOV	{"email": "rodionov.e1966@postgrespro.ru", "phone": "+70065349380"}
0005432858239	BF99AA	8601 454618	LYUDMILA MELNIKOVA	{"phone": "+70879517082"}
0005432858240	BF99AA	3228 525669	ALEKSEY VOLKOV	{"email": "aleksey_volkov-25031959@postgrespro.ru", "phone": "+70782397720"}
0005432858241	BF99AA	5082 505336	LYUBOV IVANOVA	{"phone": "+70281994292"}
0005432858242	74D334	0989 564117	ALEKSANDR ZAKHAROV	{"phone": "+70662693331"}
0005432858243	74D334	0089 100341	ANDREY SERGEEV	{"phone": "+70464671558"}
0005432858244	7B46D2	1444 036078	KSENIYA FEDOROVA	{"email": "kseniya-fedorova25071982@postgrespro.ru", "phone": "+70286886625"}
0005432858245	F31979	4240 200735	ALEKSANDR GUSEV	{"phone": "+70321273886"}
0005432858246	F31979	3679 760794	ALEKSANDR FOMIN	{"email": "a-fomin.1971@postgrespro.ru", "phone": "+70129837708"}
0005432858247	F31979	3762 524823	MIKHAIL BELOV	{"email": "mikhailbelov_16041983@postgrespro.ru", "phone": "+70244156041"}
0005432858248	F31979	2418 498924	VALERIY KONOVALOV	{"phone": "+70134995647"}
0005432858249	82599F	8690 382873	OLGA KISELEVA	{"email": "o.kiseleva-15111963@postgrespro.ru", "phone": "+70598669351"}
0005432858250	7D58CF	7675 987155	ANASTASIYA KULIKOVA	{"phone": "+70040128395"}
0005432858251	FBBBF4	1725 316157	VASILIY FEDOROV	{"email": "fedorov-vasiliy111986@postgrespro.ru", "phone": "+70157819135"}
0005432858253	F76904	3264 682935	NATALYA MOISEEVA	{"phone": "+70798353881"}
0005432858254	C6C5B3	2770 265273	ARTUR KAZAKOV	{"phone": "+70748038247"}
0005432858255	3363D8	0404 729362	EVGENIY FROLOV	{"email": "evgeniy-frolov_29031975@postgrespro.ru", "phone": "+70917510403"}
0005432858256	1645B0	0722 914885	VENERA TROFIMOVA	{"phone": "+70560040654"}
0005432858257	8785B3	0742 905644	OLESYA DENISOVA	{"email": "denisova.olesya-21011975@postgrespro.ru", "phone": "+70269920848"}
0005432858258	1E179D	4677 648219	IRINA GORBUNOVA	{"email": "irina_gorbunova031984@postgrespro.ru", "phone": "+70641444779"}
0005432858259	1E179D	4150 615199	MAKSIM SOROKIN	{"phone": "+70704300057"}
0005432858260	2AA7CA	3352 409946	KRISTINA DMITRIEVA	{"phone": "+70114360064"}
0005432858261	A36C35	4236 549726	LARISA BORISOVA	{"email": "l-borisova.07111968@postgrespro.ru", "phone": "+70937003956"}
0005432858262	946C84	5933 768633	ANASTASIYA ILINA	{"phone": "+70304421127"}
0005432858263	946C84	0933 720325	VALENTIN MAKAROV	{"phone": "+70013360692"}
0005432858264	21524A	8959 894062	ALEKSEY ISAEV	{"phone": "+70178855898"}
0005432858265	70E85E	8852 699754	VALERIY NAZAROV	{"email": "valeriynazarov-051961@postgrespro.ru", "phone": "+70106883523"}
0005432858266	70E85E	2815 257934	ANNA KUDRYASHOVA	{"phone": "+70443127182"}
0005432858267	CB2768	3701 132562	OLEG ILIN	{"email": "ilin.oleg_09021966@postgrespro.ru", "phone": "+70476728433"}
0005432858268	CB2768	7053 091349	VIKTOR FOMIN	{"phone": "+70956830086"}
0005432858269	169E9D	4450 833187	SERGEY IVANOV	{"email": "ivanov_s.1975@postgrespro.ru", "phone": "+70161471042"}
0005432858270	169E9D	9305 777508	ANTON YAKOVLEV	{"email": "a_yakovlev.17041982@postgrespro.ru", "phone": "+70597017701"}
0005432858271	5CA55E	0864 961437	ALEKSANDR KUZNECOV	{"email": "kuznecov-a-28031976@postgrespro.ru", "phone": "+70510987768"}
0005432858272	C2BA9F	8304 464821	TAMARA KOVALEVA	{"phone": "+70538717887"}
0005432858273	8F03A6	9382 183268	LARISA NIKOLAEVA	{"email": "nikolaeva_l-041969@postgrespro.ru", "phone": "+70633524898"}
0005432858274	033844	4651 666885	KRISTINA ANTONOVA	{"phone": "+70555915556"}
0005432858275	033844	7443 525430	IVAN BORISOV	{"phone": "+70399102198"}
0005432858276	B9F53F	0413 176074	EKATERINA FOMINA	{"phone": "+70783771692"}
0005432858277	B9F53F	2306 875903	ALEKSANDR FROLOV	{"email": "frolov.a11061969@postgrespro.ru", "phone": "+70414584400"}
0005432858278	848181	7976 265756	ALEKSANDR MAKSIMOV	{"phone": "+70924426732"}
0005432858279	848181	9122 541928	ANNA EFREMOVA	{"email": "efremovaanna.02121978@postgrespro.ru", "phone": "+70904248511"}
0005432858280	AA96D7	5515 727793	GEORGIY PAVLOV	{"email": "pavlovg-1973@postgrespro.ru", "phone": "+70968795428"}
0005432858281	B7D85C	7628 146519	ELENA FOMINA	{"phone": "+70238064704"}
0005432858282	BB33D2	8355 718496	LIDIYA KOMAROVA	{"email": "lidiya-komarova-061977@postgrespro.ru", "phone": "+70994911749"}
0005432858283	BB33D2	5208 202616	LYUDMILA BORISOVA	{"email": "lyudmila.borisova.021969@postgrespro.ru", "phone": "+70970406880"}
0005432858284	F6EFC3	9349 587686	RUSLAN KISELEV	{"phone": "+70029493422"}
0005432858285	7A82E1	8486 552307	ARTEMIY KRASNOV	{"email": "a_krasnov_24111969@postgrespro.ru", "phone": "+70850846174"}
0005432858286	548888	4998 120119	VLADIMIR TARASOV	{"phone": "+70903039425"}
0005432858287	2C2F40	6950 252999	RAMIL SMIRNOV	{"phone": "+70948507647"}
0005432858288	693A9D	8246 261763	OLGA IVANOVA	{"email": "o.ivanova.31031980@postgrespro.ru", "phone": "+70321073037"}
0005432858289	40D0A1	3299 537231	ALINA DAVYDOVA	{"phone": "+70840779350"}
0005432858290	40D0A1	2663 248238	VERA GRISHINA	{"phone": "+70426202829"}
0005432858291	E15030	6325 862667	PAVEL STEPANOV	{"phone": "+70741803615"}
0005432858292	E15030	4136 939154	EVGENIY PETROV	{"phone": "+70608717298"}
0005432858293	F6114D	0435 698744	ELENA KOZLOVA	{"phone": "+70811557749"}
0005432858294	AB2EE5	8636 686168	NINA NIKITINA	{"email": "n-nikitina.1973@postgrespro.ru", "phone": "+70051970218"}
0005432858295	4EBA6B	0037 507322	ALEVTINA POTAPOVA	{"phone": "+70712646336"}
0005432858296	503F08	8466 899582	KSENIYA KOZLOVA	{"email": "kozlova.kseniya15071983@postgrespro.ru", "phone": "+70708597188"}
0005432858297	503F08	8029 521459	KSENIYA MOROZOVA	{"phone": "+70405201547"}
0005432858298	B8EDD1	1054 868789	PAVEL KUZNECOV	{"email": "pavel_kuznecov_1974@postgrespro.ru", "phone": "+70075421322"}
0005432858299	D6ECA2	5871 153420	ZOYA NESTEROVA	{"phone": "+70638371329"}
0005432858300	9AF05D	4153 785656	DMITRIY ZHURAVLEV	{"email": "dmitriyzhuravlev1971@postgrespro.ru", "phone": "+70853185962"}
0005432858301	24E06D	6066 672580	VITALIY NAZAROV	{"phone": "+70217569583"}
0005432858302	24E06D	8448 044284	VALERIY BELOV	{"phone": "+70334824623"}
0005432858303	1F48EE	5449 433847	SERGEY TIKHONOV	{"phone": "+70570923848"}
0005432858304	CB9CEA	6107 108636	SERGEY POPOV	{"email": "popov_s-101972@postgrespro.ru", "phone": "+70731762342"}
0005432858305	CB9CEA	1567 063933	OLGA ZAYCEVA	{"phone": "+70971781077"}
0005432858306	D0B95E	4877 903979	ANDREY DENISOV	{"email": "denisov_andrey-01021983@postgrespro.ru", "phone": "+70957669545"}
0005432858307	939E9D	8440 188212	ELENA KUZNECOVA	{"phone": "+70043795699"}
0005432858308	9285DF	3586 730532	MARIYA KARPOVA	{"email": "karpova_mariya.041976@postgrespro.ru", "phone": "+70111703873"}
0005432858309	F4D7CC	6538 315073	TATYANA ROMANOVA	{"phone": "+70974064859"}
0005432858310	21C7F1	7089 323472	MIKHAIL NOVIKOV	{"phone": "+70938724855"}
0005432858311	A451C4	8564 868710	PAVEL ISAEV	{"phone": "+70360827617"}
0005432858312	A451C4	3764 390978	IRINA IVANOVA	{"email": "ivanova_irina_111957@postgrespro.ru", "phone": "+70736525945"}
0005432858313	A2FDC1	7554 893503	EGOR DMITRIEV	{"phone": "+70812913375"}
0005432858314	A8C000	0358 923338	DMITRIY MAKSIMOV	{"email": "maksimov.dmitriy.13101973@postgrespro.ru", "phone": "+70276066553"}
0005432858315	A8C000	9577 203788	EKATERINA MARTYNOVA	{"phone": "+70681630687"}
0005432858316	FCB923	1635 318193	DANIIL POPOV	{"phone": "+70727305794"}
0005432858317	FCB923	4032 652447	VIKTOR SIDOROV	{"email": "v-sidorov-1961@postgrespro.ru", "phone": "+70959249006"}
0005432858318	D6D1D6	6230 280066	LYUBOV ALEKSEEVA	{"phone": "+70707128855"}
0005432858319	2E302C	9106 891105	ALEKSEY ILIN	{"email": "a_ilin011984@postgrespro.ru", "phone": "+70911569252"}
0005432858320	12E332	5744 953398	POLINA BOGDANOVA	{"email": "bogdanova-polina16101981@postgrespro.ru", "phone": "+70535491985"}
0005432858321	12E332	8014 843829	ALEKSANDRA PETROVA	{"email": "aleksandra-petrova021979@postgrespro.ru", "phone": "+70181738532"}
0005432858322	12E332	9130 957057	GULNARA KUZNECOVA	{"email": "g.kuznecova101980@postgrespro.ru", "phone": "+70046162771"}
0005432858323	26BE2F	8872 729380	TATYANA KUZMINA	{"phone": "+70921632732"}
0005432858324	DF2806	9555 279315	ELENA NAZAROVA	{"email": "nazarova-elena1959@postgrespro.ru", "phone": "+70787793447"}
0005432858325	DF2806	7591 071757	SERGEY KOZLOV	{"email": "kozlov-sergey-1975@postgrespro.ru", "phone": "+70359053155"}
0005432858326	DF3438	6250 569274	VALENTINA VOROBEVA	{"email": "valentinavorobeva_31031978@postgrespro.ru", "phone": "+70160297936"}
0005432858327	5CA83A	8627 309602	VIKTOR KUZNECOV	{"email": "vkuznecov_31121985@postgrespro.ru", "phone": "+70860820854"}
0005432858328	5CA83A	0016 458692	VADIM DENISOV	{"phone": "+70567534339"}
0005432858329	DEE6D6	4453 416419	LIDIYA POPOVA	{"phone": "+70482221861"}
0005432858330	3FA867	8682 847512	LYUDMILA ANTONOVA	{"email": "antonova_lyudmila_1973@postgrespro.ru", "phone": "+70050455140"}
0005432858331	397D11	4560 162365	IRINA LEBEDEVA	{"email": "i.lebedeva10051966@postgrespro.ru", "phone": "+70691416340"}
0005432858332	0D5C5B	9512 711666	ZINAIDA PETROVA	{"phone": "+70842236217"}
0005432858333	442E34	4698 534698	VALERIY PAVLOV	{"email": "pavlov-valeriy-18071976@postgrespro.ru", "phone": "+70318444904"}
0005432858334	70B271	6790 460348	ANASTASIYA YAKOVLEVA	{"phone": "+70557455156"}
0005432858335	2459C4	4752 229207	TATYANA ABRAMOVA	{"email": "tatyana-abramova.1972@postgrespro.ru", "phone": "+70666326356"}
0005432858336	2459C4	8304 691414	NADEZHDA GORBUNOVA	{"phone": "+70176455914"}
0005432858337	9396CE	2469 401275	ANTON GUSEV	{"email": "gusev.anton.1977@postgrespro.ru", "phone": "+70074654143"}
0005432858338	A69E23	5758 357293	DMITRIY PETROV	{"email": "dmitriypetrov-031971@postgrespro.ru", "phone": "+70154659124"}
0005432858339	BB3DCC	4382 073443	LARISA NAZAROVA	{"phone": "+70089725085"}
0005432858340	7A36F3	8078 409233	ANASTASIYA SERGEEVA	{"phone": "+70943044253"}
0005432858341	A3AE41	7643 136210	TIMOFEY GUSEV	{"email": "timofey.gusev-121969@postgrespro.ru", "phone": "+70325126904"}
0005432858342	A3AE41	4141 535023	DMITRIY MELNIKOV	{"phone": "+70232499375"}
0005432858343	A3AE41	2621 800922	ANASTASIYA POPOVA	{"email": "apopova.121963@postgrespro.ru", "phone": "+70286790855"}
0005432858344	3625AE	1495 450022	OLEG NOVIKOV	{"email": "novikov_oleg-09091960@postgrespro.ru", "phone": "+70971425998"}
0005432858345	B6F5DC	7654 156242	ANDREY BARANOV	{"email": "a-baranov.1975@postgrespro.ru", "phone": "+70898538231"}
0005432858346	240FA9	4936 049445	ELENA KOROLEVA	{"phone": "+70898617382"}
0005432858347	240FA9	5866 825221	NATALYA PETROVA	{"email": "petrovanatalya.091979@postgrespro.ru", "phone": "+70860986075"}
0005432858348	240FA9	4509 038425	EKATERINA KRASNOVA	{"email": "ekaterinakrasnova_1969@postgrespro.ru", "phone": "+70685534089"}
0005432858349	958340	0360 929625	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.1970@postgrespro.ru", "phone": "+70346486267"}
0005432858350	73FFAD	4316 571409	VIKTOR PETROV	{"phone": "+70121878834"}
0005432858351	73FFAD	8313 589058	ZINAIDA STEPANOVA	{"email": "stepanovaz_1974@postgrespro.ru", "phone": "+70157746217"}
0005432858352	88100C	1144 194145	ELENA FROLOVA	{"phone": "+70509442967"}
0005432858353	9045A3	2593 021999	IVAN PETROV	{"phone": "+70852919664"}
0005432858354	9045A3	6954 000250	VALENTINA ANDREEVA	{"email": "andreeva_valentina_28111958@postgrespro.ru", "phone": "+70795285297"}
0005432858355	7206BB	0357 576761	NIKOLAY VOLKOV	{"phone": "+70946691238"}
0005432858357	299148	6679 107262	ALEKSEY STEPANOV	{"email": "stepanov_a-13081969@postgrespro.ru", "phone": "+70545697248"}
0005432858358	299148	0548 022490	LYUDMILA VASILEVA	{"email": "lyudmila.vasileva_05091974@postgrespro.ru", "phone": "+70569561937"}
0005432858359	377793	7323 450822	MARIYA KOLESNIKOVA	{"email": "m_kolesnikova-22011969@postgrespro.ru", "phone": "+70781550289"}
0005432858360	377793	6762 442474	ANDREY VOLKOV	{"email": "andrey_volkov03121963@postgrespro.ru", "phone": "+70381260094"}
0005432858361	ED445A	8489 967157	TATYANA ROMANOVA	{"email": "t_romanova-16031970@postgrespro.ru", "phone": "+70237675639"}
0005432858362	7252D2	0964 049002	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.011977@postgrespro.ru", "phone": "+70373276223"}
0005432858363	7252D2	6471 503355	LEONID PETROV	{"email": "l_petrov_1969@postgrespro.ru", "phone": "+70653244643"}
0005432858364	885250	4235 075453	TAMARA AKIMOVA	{"phone": "+70976516764"}
0005432858365	5F7105	2616 057829	LYUDMILA KISELEVA	{"email": "kiseleva.l-1974@postgrespro.ru", "phone": "+70095882866"}
0005432858366	713806	5395 436665	IVAN TARASOV	{"phone": "+70420431385"}
0005432858367	8196B0	8115 899198	RINAT SOKOLOV	{"email": "sokolov.rinat.081974@postgrespro.ru", "phone": "+70672526979"}
0005432858368	92BF3D	0234 812385	LEONID MIRONOV	{"phone": "+70983861774"}
0005432858369	C6A5EF	0927 142033	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr_13111983@postgrespro.ru", "phone": "+70165820788"}
0005432858370	C6A5EF	5949 533128	VADIM NAUMOV	{"email": "vadim-naumov_1972@postgrespro.ru", "phone": "+70762184835"}
0005432858371	DC4A53	6564 564876	OKSANA YAKOVLEVA	{"email": "yakovleva.oksana1977@postgrespro.ru", "phone": "+70923380490"}
0005432858372	DC4A53	2003 833775	ELENA STEPANOVA	{"email": "stepanova.elena101969@postgrespro.ru", "phone": "+70525000030"}
0005432858373	2AA1C6	1948 547342	EVGENIYA PAVLOVA	{"phone": "+70891130511"}
0005432858374	AF8212	1094 617194	NADEZHDA MOISEEVA	{"phone": "+70313255629"}
0005432858375	B33FC4	5046 647666	ALEKSANDR IVANOV	{"email": "ivanov_a.021983@postgrespro.ru", "phone": "+70196927227"}
0005432858376	CEB0A8	3700 612155	ANATOLIY TIKHONOV	{"email": "a_tikhonov_1975@postgrespro.ru", "phone": "+70475161521"}
0005432858377	EBE1DE	1347 161083	ARTEM DENISOV	{"phone": "+70654323474"}
0005432858378	4A94B7	8222 760149	DENIS YAKOVLEV	{"phone": "+70410574548"}
0005432858379	754FD6	3973 611627	VERA KUZMINA	{"phone": "+70065649080"}
0005432858380	F38F19	3098 807500	VLADIMIR DENISOV	{"phone": "+70118210937"}
0005432858381	DD642C	5857 246670	ALEKSANDR ZAKHAROV	{"phone": "+70717736210"}
0005432858382	186380	0732 037374	NADEZHDA DMITRIEVA	{"phone": "+70968223542"}
0005432858383	186380	9082 737831	IGOR BARANOV	{"phone": "+70424286419"}
0005432858384	577E12	9911 062744	ALEKSANDR AFANASEV	{"email": "afanasev-a.1978@postgrespro.ru", "phone": "+70476745598"}
0005432858385	812C99	5323 940683	ALEKSEY KISELEV	{"phone": "+70856996784"}
0005432858386	812C99	3403 388278	RUSLAN TIKHONOV	{"phone": "+70327890661"}
0005432858387	A0ED65	3967 645903	TATYANA KISELEVA	{"email": "kiselevat-121974@postgrespro.ru", "phone": "+70794177693"}
0005432858388	A0ED65	8364 281214	EVGENIY VOLKOV	{"email": "evgeniy.volkov-1981@postgrespro.ru", "phone": "+70933997670"}
0005432858389	220210	8030 355871	IRINA GRISHINA	{"phone": "+70430480435"}
0005432858390	220210	4221 697880	RINAT VASILEV	{"email": "rinat_vasilev_16101980@postgrespro.ru", "phone": "+70894112912"}
0005432858391	D9F43E	1330 458104	DMITRIY CHERNOV	{"phone": "+70306108165"}
0005432858392	79BFE8	1969 393530	EVGENIY MAKSIMOV	{"email": "maksimov-e09111970@postgrespro.ru", "phone": "+70983857892"}
0005432858393	32992C	7813 177122	TALGAT CHERNOV	{"phone": "+70564889046"}
0005432858394	32992C	1479 438917	VIKTOR FEDOROV	{"email": "viktor_fedorov.25101955@postgrespro.ru", "phone": "+70134257185"}
0005432858395	D1D8C1	7649 459448	ELENA KARPOVA	{"phone": "+70496818981"}
0005432858396	9B29D3	4215 602851	DINARA BARANOVA	{"phone": "+70792661398"}
0005432858397	7C4FAC	0610 347774	MARIYA KUZMINA	{"email": "mkuzmina.031977@postgrespro.ru", "phone": "+70814019254"}
0005432858398	7C4FAC	6180 582138	NATALYA SOROKINA	{"phone": "+70379843202"}
0005432858399	814C78	2268 310826	IRINA LOGINOVA	{"phone": "+70128434502"}
0005432858400	814C78	8788 840699	TALGAT CHERNOV	{"email": "chernov-t.071968@postgrespro.ru", "phone": "+70403620362"}
0005432858401	126AAE	0494 877374	SOFYA POPOVA	{"phone": "+70031326928"}
0005432858402	25CE41	5723 674910	EKATERINA KOLESNIKOVA	{"email": "ekaterinakolesnikova_051979@postgrespro.ru", "phone": "+70319640036"}
0005432858403	29A03B	4169 669732	ARTEM PETROV	{"email": "petrov_artem041966@postgrespro.ru", "phone": "+70283354597"}
0005432858404	29A03B	1988 641729	VITALIY GRIGOREV	{"email": "v_grigorev_031984@postgrespro.ru", "phone": "+70065376415"}
0005432858405	72900C	1993 186244	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.23081974@postgrespro.ru", "phone": "+70484094107"}
0005432858406	4D4D33	8074 435452	NIKOLAY SEMENOV	{"email": "semenov-n061984@postgrespro.ru", "phone": "+70388630673"}
0005432858407	0B3363	9031 929749	VLADIMIR SOKOLOV	{"email": "sokolovv1970@postgrespro.ru", "phone": "+70732532762"}
0005432858408	243314	3866 988027	GALINA NAZAROVA	{"phone": "+70189959473"}
0005432858409	DED7C1	8281 583341	ANNA GAVRILOVA	{"phone": "+70714700021"}
0005432858410	DED7C1	7589 140281	LARISA RODIONOVA	{"phone": "+70930971149"}
0005432858411	3C7605	6278 640756	KAMIL FROLOV	{"phone": "+70252018237"}
0005432858412	3C7605	6506 944030	TATYANA MALYSHEVA	{"phone": "+70707877818"}
0005432858413	C3EA22	5734 528408	NADEZHDA IVANOVA	{"phone": "+70512891027"}
0005432862162	8859AD	5227 380064	SERGEY ROMANOV	{"email": "romanov-s.031973@postgrespro.ru", "phone": "+70729111271"}
0005432862163	3027C9	6248 708800	MARIYA KULIKOVA	{"phone": "+70167940979"}
0005432862164	A805A3	1288 554798	ALEKSANDR EGOROV	{"phone": "+70653114372"}
0005432862165	6CF401	5526 536840	LARISA SERGEEVA	{"email": "larisa.sergeeva.12061971@postgrespro.ru", "phone": "+70995137462"}
0005432862166	82F9AA	0889 745535	VALENTINA IVANOVA	{"phone": "+70081130756"}
0005432862167	66EFA1	9512 888758	EVGENIY VOLKOV	{"email": "e-volkov_1987@postgrespro.ru", "phone": "+70236053294"}
0005432862168	3231D0	2628 652384	TATYANA TARASOVA	{"email": "tarasova_tatyana.27031969@postgrespro.ru", "phone": "+70689496897"}
0005432862169	9FA589	0210 294298	KIRILL ANTONOV	{"email": "antonov-k.04091962@postgrespro.ru", "phone": "+70343625899"}
0005432862170	CDB3A6	4085 549575	MIKHAIL BELOV	{"email": "mikhail-belov.101981@postgrespro.ru", "phone": "+70281209120"}
0005432862171	CDB3A6	8984 696121	VALENTINA BELOVA	{"phone": "+70671022136"}
0005432862172	0C79B6	5971 340046	OLGA BELYAEVA	{"email": "belyaeva.olga.111970@postgrespro.ru", "phone": "+70568597211"}
0005432862173	B0BBF6	5374 752851	SVETLANA KUDRYASHOVA	{"phone": "+70498407683"}
0005432862174	AA3D0D	4454 254543	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev.10051975@postgrespro.ru", "phone": "+70091214451"}
0005432862175	4ADC33	5590 059702	EVGENIY STEPANOV	{"email": "evgeniy-stepanov1968@postgrespro.ru", "phone": "+70957334118"}
0005432862176	4ADC33	3962 303456	ANDREY GUSEV	{"email": "andreygusev09071975@postgrespro.ru", "phone": "+70856821104"}
0005432862177	2266B6	5801 362711	SVETLANA ZAKHAROVA	{"email": "zakharova-s1965@postgrespro.ru", "phone": "+70806453802"}
0005432862178	2266B6	6196 296263	NADEZHDA ALEKSANDROVA	{"phone": "+70453853441"}
0005432862179	BC218A	2196 375598	MARGARITA KAZAKOVA	{"phone": "+70739561630"}
0005432862180	BC218A	9031 042154	DMITRIY FILIPPOV	{"email": "filippov-dmitriy_021972@postgrespro.ru", "phone": "+70859227306"}
0005432862181	7D9EC1	3766 822125	DENIS ZHUKOV	{"email": "zhukovdenis_1968@postgrespro.ru", "phone": "+70770568778"}
0005432862182	2CAA68	1551 250743	ANTONINA ZHURAVLEVA	{"phone": "+70340748127"}
0005432862183	9F8904	6271 825896	ALBERT PAVLOV	{"email": "pavlov-albert.25051973@postgrespro.ru", "phone": "+70186739410"}
0005432862184	9F8904	5173 916363	VASILIY KUZNECOV	{"phone": "+70909315607"}
0005432862185	11A6A0	9668 264868	ELENA YAKOVLEVA	{"email": "elena-yakovleva.1975@postgrespro.ru", "phone": "+70335710074"}
0005432862186	600257	1722 286471	ILYA KONOVALOV	{"phone": "+70303469805"}
0005432862187	FB7FB8	3744 920908	DMITRIY ZHUKOV	{"phone": "+70693619571"}
0005432862188	DD9B60	9729 734433	SERGEY ZAYCEV	{"phone": "+70446325947"}
0005432862189	DD9B60	6616 322285	ALEKSEY ZHUKOV	{"email": "zhukovaleksey-081970@postgrespro.ru", "phone": "+70719134093"}
0005432862190	BD04E4	0391 972485	KONSTANTIN SCHERBAKOV	{"email": "scherbakov.konstantin-29071977@postgrespro.ru", "phone": "+70237761901"}
0005432862191	6DCE35	4774 325437	RUSTAM SERGEEV	{"email": "rsergeev_23011966@postgrespro.ru", "phone": "+70667618941"}
0005432862192	6DCE35	1072 613777	VIKTOR FILIPPOV	{"email": "v-filippov_031973@postgrespro.ru", "phone": "+70577464308"}
0005432862193	4F765C	1636 198099	DARYA KULIKOVA	{"email": "kulikova_darya29041966@postgrespro.ru", "phone": "+70729186554"}
0005432862194	4F765C	9905 225248	ANATOLIY VOROBEV	{"phone": "+70119797729"}
0005432862195	D54825	4084 961926	LYUBOV MASLOVA	{"email": "lmaslova-1967@postgrespro.ru", "phone": "+70800491587"}
0005432862196	D52E1A	9738 966443	ANATOLIY VOROBEV	{"phone": "+70172934765"}
0005432862197	9F8087	4547 765348	NIKITA KRASNOV	{"phone": "+70279180775"}
0005432862198	F7C7F6	2151 841724	ELENA BELOVA	{"phone": "+70617320641"}
0005432862199	ADBEF3	9985 139786	NIKOLAY MOROZOV	{"phone": "+70168556266"}
0005432862200	FFBD71	4844 670896	VALERIY SERGEEV	{"phone": "+70216476579"}
0005432862201	4A1A57	8380 731234	MARAT RODIONOV	{"email": "rodionov_marat_26011982@postgrespro.ru", "phone": "+70516845107"}
0005432862202	40C50D	1353 087299	ANNA VOLKOVA	{"phone": "+70182355658"}
0005432862203	40C50D	1585 655488	EVGENIYA IVANOVA	{"phone": "+70679365950"}
0005432862204	9CD2CC	1184 233034	GENNADIY STEPANOV	{"email": "stepanovg-1975@postgrespro.ru", "phone": "+70720474884"}
0005432862205	6C4BF9	5572 137665	ALEKSANDR DAVYDOV	{"phone": "+70162313033"}
0005432862206	8ABF5F	6631 633113	VIKTOR SERGEEV	{"phone": "+70731824575"}
0005432862207	8ABF5F	1878 155618	NADEZHDA SOROKINA	{"email": "nsorokina_031974@postgrespro.ru", "phone": "+70031845233"}
0005432862208	96830C	3058 978212	GALINA NIKOLAEVA	{"email": "gnikolaeva081977@postgrespro.ru", "phone": "+70411824047"}
0005432862209	3C6D14	5118 282339	EKATERINA KOROLEVA	{"email": "e-koroleva-031972@postgrespro.ru", "phone": "+70566927169"}
0005432862210	6A444A	0445 860529	ANDREY MAKAROV	{"phone": "+70559961616"}
0005432862211	A1A4F2	9167 914801	LYUDMILA TIKHONOVA	{"phone": "+70559463481"}
0005432862212	A1A4F2	9732 891428	DENIS BELOV	{"email": "denis.belov04101967@postgrespro.ru", "phone": "+70467361261"}
0005432862213	A1A4F2	5784 632599	VALENTINA OVCHINNIKOVA	{"email": "valentina_ovchinnikova_1970@postgrespro.ru", "phone": "+70403582916"}
0005432862214	48022B	5285 708464	ALEKSANDR FROLOV	{"phone": "+70519611485"}
0005432862215	178146	9911 440107	LYUBOV RODIONOVA	{"phone": "+70364072186"}
0005432862216	67CAC7	9157 737217	TAMARA EFREMOVA	{"phone": "+70631462137"}
0005432862217	67CAC7	2189 868230	NIKITA KONOVALOV	{"phone": "+70337262105"}
0005432862218	90D7D8	7959 154816	DMITRIY TARASOV	{"phone": "+70160028119"}
0005432862219	120412	9250 386030	ALIYA VOLKOVA	{"email": "aliya.volkova06111956@postgrespro.ru", "phone": "+70476748412"}
0005432862220	E9BE17	3966 105297	ANTON MIRONOV	{"phone": "+70195503001"}
0005432862221	B0D983	9280 095627	MARIYA GORBUNOVA	{"email": "mgorbunova-27031965@postgrespro.ru", "phone": "+70631848354"}
0005432862222	ADA555	7361 554893	ALEKSANDR VOROBEV	{"email": "a-vorobev.12051980@postgrespro.ru", "phone": "+70799369019"}
0005432862223	13D2E5	7552 276299	EVGENIY BORISOV	{"phone": "+70044712340"}
0005432862224	8BD12D	4920 135896	VASILIY SOKOLOV	{"email": "vsokolov.071979@postgrespro.ru", "phone": "+70890432110"}
0005432862225	8BD12D	0300 612778	TATYANA TROFIMOVA	{"email": "trofimovatatyana-1978@postgrespro.ru", "phone": "+70741123092"}
0005432862226	8BD12D	0825 103486	VALERIYA NIKIFOROVA	{"phone": "+70610100549"}
0005432862227	4FEAA4	4581 231934	TATYANA DMITRIEVA	{"phone": "+70224577279"}
0005432862228	43127B	3968 417856	VITALIY KUZNECOV	{"email": "vitaliy.kuznecov08111974@postgrespro.ru", "phone": "+70483527238"}
0005432862229	03D915	5328 838734	ELENA MOISEEVA	{"phone": "+70789464708"}
0005432862230	4B6945	2527 511834	MARIYA ERMAKOVA	{"email": "mariya.ermakova1977@postgrespro.ru", "phone": "+70564215853"}
0005432862231	4B6945	7465 769446	NINEL NIKOLAEVA	{"email": "n.nikolaeva1969@postgrespro.ru", "phone": "+70552497318"}
0005432862232	BC5275	3061 948512	VLADIMIR EGOROV	{"phone": "+70040360972"}
0005432862233	6D6E06	1240 758159	PAVEL ZHURAVLEV	{"phone": "+70945608650"}
0005432862234	7C290D	8270 492258	ANATOLIY SAVELEV	{"phone": "+70192754444"}
0005432862235	7C290D	0683 546484	NINA KALININA	{"email": "kalinina.n26121969@postgrespro.ru", "phone": "+70245205735"}
0005432862236	A3E10C	8174 618511	ALEKSANDR KULIKOV	{"phone": "+70723593215"}
0005432862237	775955	9380 687481	EVGENIY MOROZOV	{"phone": "+70165838288"}
0005432862238	775955	7560 531177	OKSANA MAKAROVA	{"email": "makarova_oksana-081974@postgrespro.ru", "phone": "+70972938292"}
0005432862239	51EAD4	1571 211248	SEMEN POPOV	{"email": "popov-semen.1955@postgrespro.ru", "phone": "+70513631240"}
0005432862240	9CA315	0206 719867	RUSLAN SOKOLOV	{"phone": "+70818727180"}
0005432862241	9CA315	6620 486034	EVGENIY NIKITIN	{"email": "evgeniy-nikitin-011973@postgrespro.ru", "phone": "+70582025195"}
0005432862242	3BE6C9	7153 591339	ANDREY NIKITIN	{"email": "nikitin-andrey041977@postgrespro.ru", "phone": "+70100919911"}
0005432862243	80AD0B	9841 926320	MARIYA ANTONOVA	{"email": "mariya.antonova_1962@postgrespro.ru", "phone": "+70202441515"}
0005432862244	29C015	0771 860254	ARTEM IVANOV	{"email": "artem_ivanov_011957@postgrespro.ru", "phone": "+70143384425"}
0005432862245	6B27A8	1518 691534	EVDOKIYA KARPOVA	{"phone": "+70420504043"}
0005432862246	EA74F6	2820 732020	VLADIMIR GERASIMOV	{"email": "gerasimov-v-26081963@postgrespro.ru", "phone": "+70871232092"}
0005432862247	ABA871	0110 771534	YURIY MAKAROV	{"phone": "+70085159322"}
0005432862248	D83463	7034 533242	ELISEY YAKOVLEV	{"email": "elisey-yakovlev091976@postgrespro.ru", "phone": "+70801284243"}
0005432862249	D83463	8930 844688	IVAN PETROV	{"phone": "+70079253579"}
0005432862250	5E2035	8482 871014	OLEG MOISEEV	{"phone": "+70747539457"}
0005432862251	084083	2177 620262	ALLA EGOROVA	{"email": "alla_egorova19121974@postgrespro.ru", "phone": "+70286397605"}
0005432862252	084083	0481 785559	NAIL KUZNECOV	{"email": "n-kuznecov_1971@postgrespro.ru", "phone": "+70041533552"}
0005432862253	2F6D1B	0598 497915	KLAVDIYA KAZAKOVA	{"email": "kazakovak-121969@postgrespro.ru", "phone": "+70284113837"}
0005432862254	9917DD	7458 855280	SERGEY MIKHAYLOV	{"email": "sergeymikhaylov_1976@postgrespro.ru", "phone": "+70809110756"}
0005432862255	239337	7065 698895	ANGELINA ORLOVA	{"phone": "+70633557223"}
0005432862256	B9C70F	5340 329552	VALERIY IVANOV	{"phone": "+70457148850"}
0005432862257	B9C70F	9424 410271	OLGA IVANOVA	{"phone": "+70181040978"}
0005432862258	B9C70F	4654 745955	STEPAN ZHUKOV	{"phone": "+70036944023"}
0005432862259	80FAF4	5822 248742	ALEKSANDR MAKAROV	{"phone": "+70713642265"}
0005432862260	393CEE	3517 764826	NIKOLAY GAVRILOV	{"email": "gavrilov_n-1971@postgrespro.ru", "phone": "+70828343996"}
0005432862261	393CEE	9411 479996	OLGA FILIPPOVA	{"phone": "+70741732646"}
0005432862262	CD50C9	1997 066419	KRISTINA SIDOROVA	{"phone": "+70819729149"}
0005432862263	CD50C9	9463 728183	NATALIYA SIDOROVA	{"phone": "+70018179559"}
0005432862264	3AF822	9347 587941	ALEKSANDR ZHURAVLEV	{"phone": "+70390582702"}
0005432862265	691A40	9165 417651	SERGEY VASILEV	{"email": "vasilev.s101966@postgrespro.ru", "phone": "+70620762458"}
0005432862266	691A40	6108 039295	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a.15061977@postgrespro.ru", "phone": "+70126939603"}
0005432862267	691A40	9501 818510	ELENA VASILEVA	{"phone": "+70905047793"}
0005432862268	9CEBEB	1225 984292	ANNA IVANOVA	{"email": "ivanova_a-051973@postgrespro.ru", "phone": "+70299566902"}
0005432862269	9CEBEB	8586 540421	ALEKSANDR EGOROV	{"phone": "+70389207329"}
0005432862270	66D94F	8617 979282	ALEKSEY POPOV	{"phone": "+70859958291"}
0005432862271	66D94F	3502 621364	ALEKSEY ANDREEV	{"email": "alekseyandreev.1965@postgrespro.ru", "phone": "+70017102630"}
0005432862272	9929AC	2029 792186	SERGEY SOKOLOV	{"email": "sokolov.sergey_121973@postgrespro.ru", "phone": "+70887151745"}
0005432862273	E71760	4427 211358	IVAN ZAKHAROV	{"email": "zakharov.i-021981@postgrespro.ru", "phone": "+70527780169"}
0005432862274	D12A73	2747 962911	OLGA MELNIKOVA	{"phone": "+70757537132"}
0005432862275	EDA2A5	1516 099765	ANASTASIYA FOMINA	{"email": "fominaanastasiya.1971@postgrespro.ru", "phone": "+70280902468"}
0005432862276	E3D4AB	3488 917870	YURIY STEPANOV	{"email": "yuriy_stepanov081973@postgrespro.ru", "phone": "+70658248882"}
0005432862277	372F45	5180 294708	ILYA YAKOVLEV	{"phone": "+70144737055"}
0005432862278	3BE773	6568 620389	MARINA NIKITINA	{"phone": "+70034231048"}
0005432862279	3BE773	8714 856105	NIKOLAY SAVELEV	{"email": "nikolay.savelev.14021983@postgrespro.ru", "phone": "+70415583498"}
0005432862280	EF0EBB	0201 285532	ALEKSEY NIKOLAEV	{"phone": "+70087535496"}
0005432862281	0E0D10	2203 122970	MAKSIM KUZNECOV	{"phone": "+70406614829"}
0005432862282	0E0D10	2371 382787	PAVEL TARASOV	{"email": "tarasov-p-121967@postgrespro.ru", "phone": "+70617976127"}
0005432862283	0E0D10	4817 647581	MARINA GRISHINA	{"phone": "+70130460039"}
0005432862284	FE2AB8	7079 249049	IRINA BOGDANOVA	{"email": "bogdanova.irina-1969@postgrespro.ru", "phone": "+70370605840"}
0005432862285	DA835F	2691 177977	SERGEY DMITRIEV	{"phone": "+70121480441"}
0005432862286	AA65E1	0153 010868	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-011971@postgrespro.ru", "phone": "+70943346305"}
0005432862287	AA65E1	6130 337841	VALENTINA KOZLOVA	{"email": "kozlova.valentina.25121976@postgrespro.ru", "phone": "+70945679844"}
0005432862288	B68B66	7417 257829	PETR ANDREEV	{"phone": "+70271673291"}
0005432862289	2A85F4	2189 579597	NATALYA ROMANOVA	{"email": "natalya-romanova-31011976@postgrespro.ru", "phone": "+70242708102"}
0005432862290	A8633A	4846 150910	VIKTOR FILIPPOV	{"email": "viktor.filippov-23061980@postgrespro.ru", "phone": "+70424406493"}
0005432862291	E900ED	0914 080223	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr.02101963@postgrespro.ru", "phone": "+70061811819"}
0005432862292	E900ED	8743 898678	OLGA KRASNOVA	{"phone": "+70412392375"}
0005432862293	933187	8220 103382	LYUDMILA MELNIKOVA	{"phone": "+70308413731"}
0005432862294	933187	9120 979006	IVAN GAVRILOV	{"phone": "+70170372457"}
0005432862295	B906C2	2247 750274	ELENA IVANOVA	{"phone": "+70873433390"}
0005432862296	18B221	7498 174242	ALEKSANDR POPOV	{"phone": "+70352051934"}
0005432862297	9FCACF	9709 640992	ANNA KUZNECOVA	{"email": "kuznecova-a10101984@postgrespro.ru", "phone": "+70727105048"}
0005432862298	970A16	8883 796552	MARAT NOVIKOV	{"phone": "+70006807925"}
0005432862299	972D49	8311 570909	EVGENIY ILIN	{"phone": "+70091002481"}
0005432862300	972D49	4299 894290	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova-30081972@postgrespro.ru", "phone": "+70032139011"}
0005432862301	1646ED	7087 882269	SOFIYA GRISHINA	{"email": "grishinas.011984@postgrespro.ru", "phone": "+70558444071"}
0005432862302	1646ED	0267 464920	IVAN MATVEEV	{"phone": "+70725621775"}
0005432862303	522DE8	8093 496555	DENIS NIKOLAEV	{"phone": "+70336616771"}
0005432862304	FC90C3	4618 295005	MARIYA KOMAROVA	{"email": "komarovamariya071974@postgrespro.ru", "phone": "+70810979774"}
0005432862305	BCE6E9	5542 961192	OLGA VLASOVA	{"phone": "+70994956343"}
0005432862306	DC45F5	9976 732638	OLESYA KOZLOVA	{"email": "olesya_kozlova-20081985@postgrespro.ru", "phone": "+70627659529"}
0005432862307	1D9746	7041 936775	PAVEL VASILEV	{"email": "pvasilev.20101975@postgrespro.ru", "phone": "+70647898155"}
0005432862308	1D9746	7167 028454	SERGEY IVANOV	{"email": "sergeyivanov.1976@postgrespro.ru", "phone": "+70678284543"}
0005432862309	6DB452	5442 405522	SERGEY NIKOLAEV	{"email": "sergey_nikolaev_15081968@postgrespro.ru", "phone": "+70705213023"}
0005432862310	6DB452	7665 607330	NIKOLAY KUZNECOV	{"email": "kuznecovn_11121960@postgrespro.ru", "phone": "+70893213029"}
0005432862311	F7208D	3615 746605	ANNA ZAKHAROVA	{"phone": "+70202324966"}
0005432862312	B7AAC5	2485 701385	NATALYA LUKYANOVA	{"email": "lukyanova.n011969@postgrespro.ru", "phone": "+70795118116"}
0005432862313	DEA110	4493 504491	IRINA DAVYDOVA	{"email": "i-davydova_1976@postgrespro.ru", "phone": "+70053397063"}
0005432862314	A59712	7513 915777	ALEKSANDR VOROBEV	{"phone": "+70667795247"}
0005432862315	1875E9	6161 344867	YULIYA MASLOVA	{"email": "yuliyamaslova_12051968@postgrespro.ru", "phone": "+70272267602"}
0005432862316	1875E9	9310 198147	EVDOKIYA KUZNECOVA	{"email": "evdokiyakuznecova-1965@postgrespro.ru", "phone": "+70955921693"}
0005432862317	80FBDE	8813 374683	MARINA BELOVA	{"phone": "+70489495480"}
0005432862318	80FBDE	8678 859249	IVAN EGOROV	{"email": "egorov_i.1978@postgrespro.ru", "phone": "+70919187690"}
0005432862319	FEBEB2	5056 493075	SERGEY ISAEV	{"email": "s_isaev_1986@postgrespro.ru", "phone": "+70951434185"}
0005432862320	5CC5E9	4464 515652	IGOR ZAYCEV	{"email": "igor_zaycev-08101967@postgrespro.ru", "phone": "+70642276196"}
0005432862321	C192F6	4546 267675	ARTUR KRASNOV	{"email": "krasnov.artur_19011972@postgrespro.ru", "phone": "+70760268745"}
0005432862322	C192F6	2324 296189	ANASTASIYA TROFIMOVA	{"email": "trofimova.anastasiya.121975@postgrespro.ru", "phone": "+70840454624"}
0005432862323	C192F6	6715 209629	OLGA MIKHAYLOVA	{"phone": "+70755837303"}
0005432862324	F8EAD0	0637 121758	DANILA DAVYDOV	{"email": "davydov.d091965@postgrespro.ru", "phone": "+70796374334"}
0005432862325	F8EAD0	1057 815994	YULIYA KOROLEVA	{"email": "koroleva.y01061979@postgrespro.ru", "phone": "+70230356651"}
0005432862326	37D1A7	1124 134657	GALINA LOGINOVA	{"email": "loginova-galina_021982@postgrespro.ru", "phone": "+70166570614"}
0005432862327	E16777	2769 653655	TATYANA SOLOVEVA	{"email": "solovevat-17041978@postgrespro.ru", "phone": "+70542007073"}
0005432862328	E16777	1254 667364	POLINA KUZMINA	{"email": "polina.kuzmina02071968@postgrespro.ru", "phone": "+70268839415"}
0005432862329	0A1144	5117 325158	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr_051982@postgrespro.ru", "phone": "+70350070809"}
0005432862330	262081	7812 893243	SVETLANA PETROVA	{"phone": "+70769795584"}
0005432862331	A8914F	3123 461387	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey-081974@postgrespro.ru", "phone": "+70756555029"}
0005432862332	A8914F	7592 555176	TATYANA EFREMOVA	{"phone": "+70495453526"}
0005432862333	D9FC44	2685 490742	NADEZHDA LEBEDEVA	{"phone": "+70884824424"}
0005432862334	D9FC44	5285 302621	GALINA KUZMINA	{"email": "g_kuzmina_021978@postgrespro.ru", "phone": "+70644826560"}
0005432862335	D9FC44	0920 652637	LYUBOV ANDREEVA	{"email": "andreeva.l-12021968@postgrespro.ru", "phone": "+70410045815"}
0005432862336	05F912	0323 519033	TAMARA SIDOROVA	{"phone": "+70999265728"}
0005432862337	05F912	1186 637146	MIKHAIL POPOV	{"phone": "+70480363079"}
0005432862338	8E01D6	2419 756205	TATYANA BORISOVA	{"phone": "+70832880788"}
0005432862339	73295D	2328 354067	EVGENIY KRASNOV	{"phone": "+70325416493"}
0005432862340	D1B5FB	7046 274379	MARINA STEPANOVA	{"phone": "+70158218631"}
0005432862341	D1B5FB	4300 454270	YURIY SHEVCHENKO	{"email": "yuriy-shevchenko-1969@postgrespro.ru", "phone": "+70213092436"}
0005432862342	4314F5	9634 130480	DMITRIY NIKOLAEV	{"phone": "+70870959016"}
0005432862343	DA4D8B	7227 224089	MARINA MELNIKOVA	{"phone": "+70714254462"}
0005432862344	A8E94D	6565 893866	PAVEL MIKHAYLOV	{"email": "mikhaylovp_071982@postgrespro.ru", "phone": "+70613728320"}
0005432862345	A8E94D	9080 145011	MARIANNA LAZAREVA	{"phone": "+70715694703"}
0005432862346	554023	5389 041354	LYUDMILA ALEKSANDROVA	{"email": "l-aleksandrova_1977@postgrespro.ru", "phone": "+70454591718"}
0005432862347	E2B100	3848 575768	EVGENIY BORISOV	{"email": "borisov.e-01071986@postgrespro.ru", "phone": "+70007279687"}
0005432862348	E2B100	2899 215796	NATALYA KONOVALOVA	{"phone": "+70518717094"}
0005432862349	6BDD8A	2009 437210	NATALYA STEPANOVA	{"email": "natalya-stepanova051979@postgrespro.ru", "phone": "+70777958955"}
0005432862350	F2D62E	2651 337376	VLADIMIR NIKOLAEV	{"phone": "+70461473856"}
0005432862351	F2D62E	5011 148436	NADEZHDA BORISOVA	{"phone": "+70489295848"}
0005432862352	B33562	8432 312663	YANA MEDVEDEVA	{"phone": "+70964771896"}
0005432862353	1F2EF5	1593 006245	SERGEY NAUMOV	{"email": "sergeynaumov_24021983@postgrespro.ru", "phone": "+70743117717"}
0005432862354	15B4C2	9897 696814	RADIK STEPANOV	{"email": "radikstepanov_04061968@postgrespro.ru", "phone": "+70553287481"}
0005432862355	178233	4454 384366	GALINA KUDRYASHOVA	{"email": "gkudryashova23021970@postgrespro.ru", "phone": "+70223632767"}
0005432862356	2AB258	8135 112907	GALINA DAVYDOVA	{"phone": "+70121982547"}
0005432862357	2AB258	7796 735929	KONSTANTIN SOKOLOV	{"email": "konstantin-sokolov.29061970@postgrespro.ru", "phone": "+70527749459"}
0005432862358	0994E9	4103 313601	TATYANA KONOVALOVA	{"phone": "+70828000387"}
0005432862359	06B229	5153 909181	EKATERINA KISELEVA	{"email": "e_kiseleva-1976@postgrespro.ru", "phone": "+70410563727"}
0005432862360	06B229	5641 789868	DMITRIY ROMANOV	{"email": "dromanov1963@postgrespro.ru", "phone": "+70419478229"}
0005432862361	DFB864	9134 943373	GUZEL PAVLOVA	{"phone": "+70424414600"}
0005432862362	DFB864	3686 602512	NATALYA POPOVA	{"phone": "+70640841497"}
0005432862363	54891F	4251 983583	VIKTOR PAVLOV	{"email": "pavlovviktor08031979@postgrespro.ru", "phone": "+70918448516"}
0005432862364	D8CFB4	0219 827915	SVETLANA KOZLOVA	{"phone": "+70782063843"}
0005432862365	D8CFB4	7684 895210	NATALYA ALEKSANDROVA	{"phone": "+70084575331"}
0005432862366	90924D	0947 327806	RAISA NIKITINA	{"email": "nikitinar-091979@postgrespro.ru", "phone": "+70331458929"}
0005432862367	0029AE	7830 262533	SERGEY IVANOV	{"phone": "+70009235667"}
0005432862368	FF5FC3	0005 635488	SERGEY POPOV	{"email": "sergey-popov-15021961@postgrespro.ru", "phone": "+70309929827"}
0005432862369	08EBA8	1070 378401	EVGENIYA AFANASEVA	{"phone": "+70111120523"}
0005432862370	43D03F	9006 165456	TATYANA RYABOVA	{"phone": "+70259403914"}
0005432862371	50D41D	7745 239714	SERGEY RODIONOV	{"phone": "+70284312557"}
0005432862372	0285FA	7983 001580	ANDREY ANTONOV	{"email": "antonov.andrey.1964@postgrespro.ru", "phone": "+70876718853"}
0005432862373	7B754A	5052 580061	ELENA FROLOVA	{"phone": "+70343194651"}
0005432862374	6A35E3	7992 693025	DANA POPOVA	{"email": "d_popova_101967@postgrespro.ru", "phone": "+70024222363"}
0005432862375	CA2C0B	2103 848132	SERGEY MIKHAYLOV	{"phone": "+70799071791"}
0005432862376	CA2C0B	1468 847288	OLEG SHEVCHENKO	{"email": "o-shevchenko.081980@postgrespro.ru", "phone": "+70927864739"}
0005432862377	4EDA8E	7593 994678	ELENA PETROVA	{"phone": "+70405296176"}
0005432862378	BA7671	5926 127192	NINA NAUMOVA	{"phone": "+70355767295"}
0005432862379	BCD1C6	5463 001663	SERGEY POPOV	{"phone": "+70504531476"}
0005432862380	BCD1C6	6786 975815	LYUBOV NIKITINA	{"phone": "+70651279005"}
0005432862381	A87C47	6318 739929	SERAFIMA TARASOVA	{"phone": "+70836226231"}
0005432862382	A87C47	9360 939945	MARIYA KUZNECOVA	{"phone": "+70691304470"}
0005432862383	032BB4	9045 691712	GRIGORIY KUZNECOV	{"email": "gkuznecov-05101972@postgrespro.ru", "phone": "+70897618189"}
0005432862384	032BB4	4555 888601	NIKOLAY MAKAROV	{"email": "nmakarov061983@postgrespro.ru", "phone": "+70959019432"}
0005432862385	032BB4	9542 083838	SVETLANA LAZAREVA	{"phone": "+70176065792"}
0005432862386	DC08FD	8766 548136	TAMARA ROMANOVA	{"phone": "+70025733766"}
0005432862387	6C8D49	2156 271352	VIKTORIYA GUSEVA	{"phone": "+70737895793"}
0005432862388	2A48B5	5270 755585	MIKHAIL POPOV	{"phone": "+70806207844"}
0005432862389	2A48B5	2040 405365	EDUARD FROLOV	{"phone": "+70520988134"}
0005432862390	D24D0D	1466 755903	LYUDMILA KOROLEVA	{"email": "lyudmila-koroleva_14011978@postgrespro.ru", "phone": "+70543010419"}
0005432862391	D24D0D	1674 552962	LARISA NIKOLAEVA	{"phone": "+70710563359"}
0005432862392	338BFE	6404 022999	GULSINA MIRONOVA	{"phone": "+70874374951"}
0005432862393	F0692F	0455 654690	ELENA KOZLOVA	{"email": "e-kozlova_011970@postgrespro.ru", "phone": "+70266631952"}
0005432862394	F0692F	8816 499516	VLADIMIR PETROV	{"phone": "+70010092093"}
0005432862395	0DB978	2815 788383	IGOR VLASOV	{"phone": "+70466325587"}
0005432862396	678A57	3732 140817	VALERIYA KUZMINA	{"email": "kuzmina_v.1968@postgrespro.ru", "phone": "+70542194469"}
0005432862397	678A57	3340 375850	ALEKSANDR SAVELEV	{"email": "asavelev-04021987@postgrespro.ru", "phone": "+70462952985"}
0005432862398	6C1235	4195 510341	NATALYA NOVIKOVA	{"email": "natalya.novikova041973@postgrespro.ru", "phone": "+70295216112"}
0005432862399	6C1235	6507 908753	EKATERINA PETROVA	{"email": "petrovaekaterina111983@postgrespro.ru", "phone": "+70277501033"}
0005432862400	0220E7	3858 489660	ANDREY PETROV	{"phone": "+70289832068"}
0005432862401	0220E7	9448 803936	GALINA ILINA	{"phone": "+70900498556"}
0005432862402	60F42C	3486 824632	VIKTORIYA POPOVA	{"email": "vpopova.1972@postgrespro.ru", "phone": "+70836666592"}
0005432862403	60F42C	7525 232592	ALINA NESTEROVA	{"phone": "+70756987871"}
0005432862404	1D481B	3974 927333	POLINA KUZNECOVA	{"email": "kuznecova_p-04051969@postgrespro.ru", "phone": "+70698403077"}
0005432862405	F770E2	5996 411518	EKATERINA TIKHONOVA	{"phone": "+70046465611"}
0005432862406	239D71	5355 165570	ANNA KULIKOVA	{"email": "akulikova09101978@postgrespro.ru", "phone": "+70797334478"}
0005432862407	239D71	4853 298635	YURIY PETROV	{"phone": "+70128108635"}
0005432862408	3F09AD	9210 210195	VIKTOR SEMENOV	{"phone": "+70732749729"}
0005432862409	3F09AD	0320 139276	SERGEY MATVEEV	{"email": "sergey-matveev-051968@postgrespro.ru", "phone": "+70423314893"}
0005432862410	972ED6	1336 462489	NATALYA KOZLOVA	{"email": "kozlova.natalya-101962@postgrespro.ru", "phone": "+70516711185"}
0005432862411	972ED6	3494 521227	ANDREY KISELEV	{"email": "kiselev.a-25111968@postgrespro.ru", "phone": "+70316166563"}
0005432862412	800F52	8362 835991	GEORGIY DAVYDOV	{"phone": "+70672093160"}
0005432862413	5C0A85	4296 525208	ARSENIY VASILEV	{"email": "arseniy.vasilev02121970@postgrespro.ru", "phone": "+70310233670"}
0005432862414	7BFB8C	6421 023928	FARID SERGEEV	{"email": "sergeevf101974@postgrespro.ru", "phone": "+70650129013"}
0005432862415	7BFB8C	9271 598510	LIDIYA PETROVA	{"email": "petrova.lidiya.1966@postgrespro.ru", "phone": "+70166360481"}
0005432862416	7BFB8C	9402 613940	TATYANA POPOVA	{"email": "popova-tatyana-071981@postgrespro.ru", "phone": "+70976072861"}
0005432862417	22B241	8957 110548	SVETLANA ALEKSANDROVA	{"phone": "+70188739158"}
0005432862418	4A2A78	4118 648829	ALLA ANTONOVA	{"email": "antonova.alla-27021964@postgrespro.ru", "phone": "+70242618725"}
0005432862419	508625	9846 396352	ALEKSANDR MOISEEV	{"phone": "+70113301877"}
0005432862420	1154BD	2898 563507	VALERIY SAVELEV	{"email": "savelev-v.091982@postgrespro.ru", "phone": "+70064988815"}
0005432862421	D2508D	0032 543374	ARTEM SCHERBAKOV	{"email": "artemscherbakov.071968@postgrespro.ru", "phone": "+70499464109"}
0005432862422	AF9865	1583 399289	ALEKSEY BORISOV	{"email": "aleksey_borisov_121969@postgrespro.ru", "phone": "+70107949179"}
0005432862423	AF9865	4966 376231	OKSANA SIDOROVA	{"email": "oksana.sidorova_16041960@postgrespro.ru", "phone": "+70377401461"}
0005432862424	308CFC	5829 173954	EKATERINA KOZLOVA	{"email": "ekozlova.22071962@postgrespro.ru", "phone": "+70016057971"}
0005432862425	80354C	2769 455329	ELENA KUZMINA	{"phone": "+70741900917"}
0005432862426	80354C	7255 079330	GRIGORIY SHEVCHENKO	{"phone": "+70906877610"}
0005432862427	7AC939	1909 323210	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov.19111968@postgrespro.ru", "phone": "+70328657397"}
0005432862428	F01DF4	0565 317101	VADIM MOROZOV	{"phone": "+70427160841"}
0005432862429	5C5F08	4558 827610	ELENA GERASIMOVA	{"phone": "+70175916168"}
0005432862430	848778	1702 370324	ZINAIDA OSIPOVA	{"email": "osipova_z1982@postgrespro.ru", "phone": "+70435789339"}
0005432862431	E79F85	4692 629576	OLGA RODIONOVA	{"phone": "+70140710604"}
0005432862432	732492	3706 267804	EGOR GERASIMOV	{"email": "egerasimov_1967@postgrespro.ru", "phone": "+70795205056"}
0005432862433	732492	9406 529070	YURIY EGOROV	{"phone": "+70457255666"}
0005432862434	EA1472	2333 396117	VALERIY ZHUKOV	{"email": "v_zhukov_1976@postgrespro.ru", "phone": "+70190143463"}
0005432862435	EA1472	3011 730619	LYUDMILA PAVLOVA	{"phone": "+70141062338"}
0005432862436	59A8E3	2425 471332	IRAIDA KUZMINA	{"email": "kuzminai.081972@postgrespro.ru", "phone": "+70506090030"}
0005432862437	59A8E3	0617 052615	ANGELINA POPOVA	{"email": "popovaa-1967@postgrespro.ru", "phone": "+70949261454"}
0005432862438	6C827B	2960 589081	TATYANA KUZNECOVA	{"phone": "+70929605520"}
0005432862439	6C827B	3502 937101	IRINA ISAEVA	{"email": "i_isaeva.27111971@postgrespro.ru", "phone": "+70010368322"}
0005432862440	54FD1A	7080 589265	ZINAIDA TIKHONOVA	{"phone": "+70001265694"}
0005432862441	E32477	7349 542232	SERGEY VOLKOV	{"email": "s_volkov.11071967@postgrespro.ru", "phone": "+70500922250"}
0005432862442	1227C8	7048 931619	KARINA ZHURAVLEVA	{"email": "k_zhuravleva_041970@postgrespro.ru", "phone": "+70852442978"}
0005432862443	AB1BB0	3275 209602	YURIY GRIGOREV	{"email": "grigorev_yuriy_1972@postgrespro.ru", "phone": "+70479890512"}
0005432862444	AB1BB0	0067 953426	OLGA ANDREEVA	{"phone": "+70247091065"}
0005432862445	74569E	3123 853275	ALEKSANDR PETROV	{"phone": "+70095798576"}
0005432862446	8C5AB9	4191 640574	ELENA BELOVA	{"email": "belova.e1968@postgrespro.ru", "phone": "+70586452263"}
0005432862447	8C5AB9	9855 153590	NINA KALININA	{"phone": "+70250336766"}
0005432862448	CDF9CF	8888 846099	DMITRIY NAUMOV	{"phone": "+70306815171"}
0005432862449	CDF9CF	2229 275832	NIKOLAY VOROBEV	{"phone": "+70165132524"}
0005432862450	CDF9CF	5910 752585	NIKOLAY NOVIKOV	{"phone": "+70769038371"}
0005432862451	FF1263	6285 425832	ALEKSEY KUZNECOV	{"phone": "+70530074244"}
0005432862452	FF1263	0361 336406	KONSTANTIN ROMANOV	{"email": "romanov_k.041974@postgrespro.ru", "phone": "+70242621701"}
0005432862453	A478DA	4106 129126	ELENA VOLKOVA	{"phone": "+70709095688"}
0005432862454	EBF158	8582 816278	DANIIL VOLKOV	{"email": "volkov_daniil_051969@postgrespro.ru", "phone": "+70230686829"}
0005432862455	EBF158	2349 928928	ALEFTINA KULIKOVA	{"phone": "+70762271841"}
0005432862456	AD720F	8367 567412	VLADIMIR ANDREEV	{"phone": "+70856838906"}
0005432862457	AD720F	3985 546714	ANDREY MAKAROV	{"email": "makarov.a1961@postgrespro.ru", "phone": "+70661243801"}
0005432862458	BB80AD	6198 358644	LYUDMILA NIKOLAEVA	{"phone": "+70623291566"}
0005432862459	692499	3150 718755	VITALIY RODIONOV	{"phone": "+70179630552"}
0005432862460	1C2E0F	8760 928375	ANDREY KUZNECOV	{"email": "kuznecov-andrey.111972@postgrespro.ru", "phone": "+70929954910"}
0005432862461	5947A8	4362 687423	SERGEY VOROBEV	{"email": "s_vorobev061956@postgrespro.ru", "phone": "+70941656551"}
0005432862462	43D996	5949 767356	ANDREY NIKITIN	{"email": "nikitin.a_1969@postgrespro.ru", "phone": "+70895066692"}
0005432862463	43D996	9338 639991	YURIY SEMENOV	{"phone": "+70204321682"}
0005432862464	E2CF40	0554 520168	NIKOLAY TIMOFEEV	{"phone": "+70555860153"}
0005432862465	E2CF40	0036 411685	DENIS MATVEEV	{"email": "denismatveev1968@postgrespro.ru", "phone": "+70114900571"}
0005432862466	B9D060	7240 352136	ALEVTINA KOLESNIKOVA	{"email": "kolesnikova.a.31081967@postgrespro.ru", "phone": "+70760969582"}
0005432862467	1EB78C	9224 867564	LYUDMILA ZAKHAROVA	{"phone": "+70727016463"}
0005432862468	1EB78C	1797 919546	MAKSIM ZHUKOV	{"email": "maksimzhukov.121965@postgrespro.ru", "phone": "+70754410534"}
0005432862469	04E431	8410 216102	PAVEL MAKSIMOV	{"phone": "+70375965707"}
0005432862470	04E431	3289 259019	VERA ZOTOVA	{"phone": "+70698959703"}
0005432862471	7641DF	5761 457182	DMITRIY KUZNECOV	{"phone": "+70898971489"}
0005432862472	7641DF	4193 697387	ALIK ZAKHAROV	{"phone": "+70853853683"}
0005432862473	00CDD3	4409 177272	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev28071976@postgrespro.ru", "phone": "+70846211997"}
0005432862474	00CDD3	2759 024522	ANASTASIYA MOROZOVA	{"email": "morozova-a051975@postgrespro.ru", "phone": "+70468658008"}
0005432862475	041AAA	6256 690646	LYUBOV ILINA	{"email": "ilina-lyubov.25071971@postgrespro.ru", "phone": "+70818042454"}
0005432862476	21F30D	1040 550488	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov-18111975@postgrespro.ru", "phone": "+70671675237"}
0005432862477	EA4AB2	7334 043932	ALEKSEY SOLOVEV	{"email": "solovev.a_1977@postgrespro.ru", "phone": "+70543430943"}
0005432862478	EA4AB2	7662 400625	VLADIMIR KISELEV	{"phone": "+70138700449"}
0005432862479	548D27	4604 544624	OKSANA KARPOVA	{"phone": "+70795135112"}
0005432862480	3FDD5B	0577 229576	ARTEM VLASOV	{"email": "artem_vlasov.28011969@postgrespro.ru", "phone": "+70165541364"}
0005432862481	FF4C51	8197 825281	VLADIMIR FROLOV	{"email": "v.frolov-1972@postgrespro.ru", "phone": "+70403768789"}
0005432862482	408C20	8024 458761	TATYANA RODIONOVA	{"email": "rodionova_t1970@postgrespro.ru", "phone": "+70401006341"}
0005432862483	408C20	1169 380744	YURIY ANDREEV	{"email": "yandreev_091977@postgrespro.ru", "phone": "+70568874318"}
0005432862484	2A72FC	2791 999068	VLADIMIR MATVEEV	{"phone": "+70191718926"}
0005432862485	1115C6	9241 840109	OLGA IVANOVA	{"phone": "+70917839119"}
0005432862486	1115C6	2103 202182	NATALYA VOLKOVA	{"email": "natalya-volkova081969@postgrespro.ru", "phone": "+70865193076"}
0005432862487	388F7F	3737 505421	LEONID GORBUNOV	{"email": "gorbunov-leonid_121976@postgrespro.ru", "phone": "+70286980011"}
0005432862488	388F7F	2483 652884	VLADIMIR ANDREEV	{"email": "vladimirandreev.011979@postgrespro.ru", "phone": "+70446179440"}
0005432862489	FF138D	8676 852495	IRINA BOGDANOVA	{"phone": "+70479455328"}
0005432862490	2283FC	4436 790813	VLADIMIR SOKOLOV	{"phone": "+70133606224"}
0005432862491	2283FC	3332 581745	EVGENIY SCHERBAKOV	{"email": "e.scherbakov_21031966@postgrespro.ru", "phone": "+70680819587"}
0005432862492	E32BFD	6316 808254	ALENA VASILEVA	{"phone": "+70310216514"}
0005432862493	2462F8	7483 472652	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov.011964@postgrespro.ru", "phone": "+70399073937"}
0005432862494	DF8C3B	7605 192536	SVETLANA ILINA	{"phone": "+70175631831"}
0005432862495	DF8C3B	4627 131909	OLGA VLASOVA	{"email": "vlasovaolga.06111965@postgrespro.ru", "phone": "+70292453341"}
0005432862496	8E349F	0503 899262	ALEKSANDR MOROZOV	{"phone": "+70871328094"}
0005432862497	386E3F	6069 768210	ALEKSANDRA ALEKSANDROVA	{"phone": "+70588278315"}
0005432862498	386E3F	7161 983336	MAKSIM SAVELEV	{"phone": "+70988815446"}
0005432862499	386E3F	2491 511506	VASILIY BONDARENKO	{"phone": "+70461510237"}
0005432862500	A31C6B	8839 869757	YANA IVANOVA	{"phone": "+70807453015"}
0005432862501	22D627	4908 829858	EGOR KOZLOV	{"email": "egorkozlov-1976@postgrespro.ru", "phone": "+70602769659"}
0005432862502	22D627	3834 457305	VALENTINA VLASOVA	{"phone": "+70467664613"}
0005432862503	F98D8B	7039 287109	NATALYA ZAYCEVA	{"phone": "+70503920502"}
0005432862504	349461	5203 417372	VLADIMIR SIDOROV	{"phone": "+70459710508"}
0005432862505	4836B1	4259 306462	SERGEY IVANOV	{"email": "sergey-ivanov-1967@postgrespro.ru", "phone": "+70732083005"}
0005432862506	59EDBB	0501 863875	VIKTOR TIMOFEEV	{"phone": "+70323258831"}
0005432862507	719AAA	2364 276836	INNA MOROZOVA	{"phone": "+70316212182"}
0005432862508	719AAA	0659 096382	DMITRIY KULIKOV	{"email": "d.kulikov19061979@postgrespro.ru", "phone": "+70993983116"}
0005432862509	719AAA	3749 589833	ELENA MASLOVA	{"email": "maslova.elena_1972@postgrespro.ru", "phone": "+70514471412"}
0005432862510	719AAA	5808 567966	DARYA NESTEROVA	{"email": "nesterovadarya.19111963@postgrespro.ru", "phone": "+70502432991"}
0005432862511	FEC2B6	2946 388223	MIKHAIL VASILEV	{"email": "vasilevm_121972@postgrespro.ru", "phone": "+70019560745"}
0005432862512	FEC2B6	0689 159346	NATALYA EGOROVA	{"email": "natalya_egorova_24021978@postgrespro.ru", "phone": "+70573140225"}
0005432862513	FA2410	7595 721412	VIKTOR EGOROV	{"email": "v_egorov.011976@postgrespro.ru", "phone": "+70425058530"}
0005432862514	93FE80	5038 990711	GALINA MARTYNOVA	{"phone": "+70922112165"}
0005432862515	93FE80	1056 053587	ANTON ANDREEV	{"email": "andreeva_1970@postgrespro.ru", "phone": "+70476969611"}
0005432862516	CA97EE	8511 294167	VASILIY AFANASEV	{"email": "vasiliy.afanasev_1970@postgrespro.ru", "phone": "+70103667020"}
0005432862517	3F78EA	8190 230627	ANASTASIYA ANDREEVA	{"email": "a_andreeva.1967@postgrespro.ru", "phone": "+70045250718"}
0005432862518	3F78EA	8863 566920	NATALYA YAKOVLEVA	{"email": "natalya.yakovleva.06081968@postgrespro.ru", "phone": "+70719074640"}
0005432862519	140412	0771 937890	ANNA SIDOROVA	{"phone": "+70115687051"}
0005432862520	140412	9875 738175	DMITRIY ANDREEV	{"phone": "+70246904993"}
0005432862521	7A1495	6501 602388	YULIYA KONDRATEVA	{"phone": "+70605683757"}
0005432862522	CBC543	1225 681602	SVETLANA NESTEROVA	{"phone": "+70887842427"}
0005432862523	1F70CF	3860 093509	BORIS STEPANOV	{"email": "stepanov.b_11111973@postgrespro.ru", "phone": "+70590858196"}
0005432862524	1F70CF	2892 799216	ANDREY AFANASEV	{"email": "afanasev-a_1954@postgrespro.ru", "phone": "+70487324045"}
0005432862525	A1D4B9	1404 804028	IVAN SCHERBAKOV	{"email": "i_scherbakov_111967@postgrespro.ru", "phone": "+70410284907"}
0005432862526	E7D149	5846 528422	ANASTASIYA PAVLOVA	{"email": "pavlova_a.25011962@postgrespro.ru", "phone": "+70238993254"}
0005432862527	D292CC	4837 379180	VITALIY NIKOLAEV	{"email": "nikolaev-vitaliy.27091976@postgrespro.ru", "phone": "+70733462740"}
0005432865952	E5FB91	3620 398748	SERGEY FROLOV	{"phone": "+70311772914"}
0005432862528	D292CC	0683 187632	NIKOLAY KUZMIN	{"email": "nikolay.kuzmin-13101967@postgrespro.ru", "phone": "+70936697183"}
0005432865894	A54EB3	1186 306551	RAISA KOMAROVA	{"phone": "+70112458792"}
0005432865895	265C11	1677 253054	ALEKSANDR BELOV	{"phone": "+70540331932"}
0005432865896	265C11	0498 167106	ANTONINA SOKOLOVA	{"phone": "+70932439782"}
0005432865897	265C11	8193 967518	PAVEL SIDOROV	{"email": "sidorov_pavel101960@postgrespro.ru", "phone": "+70003998970"}
0005432865898	0DFCD1	2578 373595	PETR ZHUKOV	{"phone": "+70350919291"}
0005432865899	05928F	8748 881005	ALEKSANDR CHERNOV	{"email": "chernovaleksandr.10021967@postgrespro.ru", "phone": "+70111845752"}
0005432865900	05928F	7813 732139	SVETLANA POPOVA	{"phone": "+70096675860"}
0005432865901	8095AE	8973 110698	NATALYA VOLKOVA	{"email": "volkova-n_091968@postgrespro.ru", "phone": "+70922593837"}
0005432865902	8095AE	1251 956541	OLEG FEDOTOV	{"phone": "+70282724093"}
0005432865903	56C5F0	0289 453511	ELENA ANISIMOVA	{"email": "e.anisimova.071973@postgrespro.ru", "phone": "+70196904288"}
0005432865904	1BDC7B	0525 457187	ANDREY SEMENOV	{"email": "semenov.a.081974@postgrespro.ru", "phone": "+70185875272"}
0005432865905	6D3416	5326 279558	NIKOLAY PAVLOV	{"phone": "+70160268371"}
0005432865906	301A55	7600 923385	MIKHAIL KRASNOV	{"email": "m.krasnov1972@postgrespro.ru", "phone": "+70215071386"}
0005432865907	40F6B4	5955 658522	PETR POPOV	{"email": "popov.p10121977@postgrespro.ru", "phone": "+70072288406"}
0005432865908	40F6B4	5972 288972	MARIYA BELYAEVA	{"email": "mariya-belyaeva.1973@postgrespro.ru", "phone": "+70528119071"}
0005432865909	56C610	5726 069938	ROMAN TIKHONOV	{"email": "roman-tikhonov09021977@postgrespro.ru", "phone": "+70472654227"}
0005432865910	56C610	7699 749570	TAISIYA KUZNECOVA	{"email": "kuznecova-t_111977@postgrespro.ru", "phone": "+70156155572"}
0005432865911	64D7FF	4301 382327	LIDIYA KOLESNIKOVA	{"email": "kolesnikova.lidiya1978@postgrespro.ru", "phone": "+70807800272"}
0005432865912	C9C8E0	6692 308078	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey101982@postgrespro.ru", "phone": "+70539730790"}
0005432865913	C9C8E0	8736 117779	OLEG ORLOV	{"email": "orlov_oleg_121972@postgrespro.ru", "phone": "+70681391243"}
0005432865914	C81DF6	6079 268377	VLADISLAV FROLOV	{"email": "frolovvladislav_22121973@postgrespro.ru", "phone": "+70597075712"}
0005432865915	3B9009	7045 769954	VALENTINA ZAYCEVA	{"phone": "+70246355239"}
0005432865916	3B9009	8947 863528	VALENTINA FROLOVA	{"email": "vfrolova.1977@postgrespro.ru", "phone": "+70223003426"}
0005432865917	D5C8D0	7223 607642	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov-13061964@postgrespro.ru", "phone": "+70495586940"}
0005432865918	D54AAC	2451 382207	ALEKSEY KUZNECOV	{"email": "kuznecova.10081973@postgrespro.ru", "phone": "+70489585277"}
0005432865919	D54AAC	1075 164116	RAMIL POPOV	{"phone": "+70403635299"}
0005432865920	D54AAC	7544 620856	ELENA MAKSIMOVA	{"email": "elena.maksimova.1970@postgrespro.ru", "phone": "+70011674610"}
0005432865921	145E9C	6508 658780	TATYANA DAVYDOVA	{"email": "tatyana_davydova021967@postgrespro.ru", "phone": "+70560672487"}
0005432865922	145E9C	6456 091936	DMITRIY IVANOV	{"phone": "+70016904262"}
0005432865923	145E9C	3287 361034	ILYA MIRONOV	{"phone": "+70873971649"}
0005432865924	043D2D	6503 916666	VIKTOR KULIKOV	{"email": "viktor_kulikov29011983@postgrespro.ru", "phone": "+70339324026"}
0005432865925	C04D26	3124 510171	DENIS BONDARENKO	{"email": "d.bondarenko-1974@postgrespro.ru", "phone": "+70140463708"}
0005432865926	CB7781	5422 474042	DMITRIY FROLOV	{"email": "frolovd1967@postgrespro.ru", "phone": "+70682580967"}
0005432865927	CB7781	9737 479070	SVETLANA POPOVA	{"phone": "+70168241073"}
0005432865928	6649ED	1544 158298	KSENIYA PAVLOVA	{"phone": "+70404697550"}
0005432865929	9E70C5	4281 167826	MARIYA BELOVA	{"phone": "+70198413227"}
0005432865930	B11ABF	8629 551130	SNEZHANA VOROBEVA	{"email": "vorobeva.s-1972@postgrespro.ru", "phone": "+70219998000"}
0005432865931	B11ABF	5517 702549	KIRILL KUZNECOV	{"phone": "+70164466407"}
0005432865932	B11ABF	2555 409469	DANIIL GRIGOREV	{"phone": "+70024956923"}
0005432865933	06F718	2365 120230	ALENA AFANASEVA	{"email": "alena_afanaseva-091978@postgrespro.ru", "phone": "+70982199516"}
0005432865934	FCEBFA	1530 437838	SERGEY FEDOTOV	{"phone": "+70622759772"}
0005432865935	A6F5FD	1453 850834	DMITRIY MAKAROV	{"email": "dmakarov.1967@postgrespro.ru", "phone": "+70588934225"}
0005432865936	8F450D	4799 901237	ANASTASIYA GRISHINA	{"email": "agrishina-11121987@postgrespro.ru", "phone": "+70917318819"}
0005432865937	91EBEC	5693 450237	POLINA NIKITINA	{"email": "nikitina_p-091980@postgrespro.ru", "phone": "+70307314333"}
0005432865938	11EEFB	0310 275197	VLADIMIR MAKSIMOV	{"email": "maksimovvladimir.061977@postgrespro.ru", "phone": "+70796621249"}
0005432865939	997BFC	1695 685204	ALEKSEY GAVRILOV	{"phone": "+70263285202"}
0005432865940	765EE0	4773 432391	NADEZHDA NIKOLAEVA	{"phone": "+70402255232"}
0005432865941	970D23	4208 181915	ALINA ALEKSEEVA	{"phone": "+70711975265"}
0005432865942	970D23	3733 911330	ULYANA LOGINOVA	{"email": "u.loginova-1972@postgrespro.ru", "phone": "+70743173193"}
0005432865943	2438E6	5358 205992	SERGEY OSIPOV	{"email": "osipovsergey-1976@postgrespro.ru", "phone": "+70591411898"}
0005432865944	9B471C	5707 371179	ANASTASIYA SERGEEVA	{"phone": "+70367810417"}
0005432865945	706AA2	6823 631432	ANASTASIYA AFANASEVA	{"phone": "+70117761031"}
0005432865946	B3E72A	0555 666798	DMITRIY YAKOVLEV	{"phone": "+70633526401"}
0005432865947	A45AD2	2031 283903	ANTONINA POPOVA	{"email": "antonina-popova-16081981@postgrespro.ru", "phone": "+70845766698"}
0005432865948	969E67	4449 343587	MARIYA NIKOLAEVA	{"phone": "+70990154574"}
0005432865949	69C0BA	5484 373985	VLADISLAV MOROZOV	{"email": "morozov_vladislav-30041968@postgrespro.ru", "phone": "+70790988995"}
0005432865950	69C0BA	0892 687009	LYUBOV AKIMOVA	{"email": "lakimova27121984@postgrespro.ru", "phone": "+70671565704"}
0005432865951	3F3093	6442 364728	NADEZHDA DENISOVA	{"phone": "+70812308880"}
0005432865953	26974D	5153 992832	EVGENIY SEMENOV	{"email": "e-semenov-29051977@postgrespro.ru", "phone": "+70279823149"}
0005432865954	26974D	8889 709994	BORIS KUZMIN	{"phone": "+70110452726"}
0005432865955	E33CF8	4929 287331	ELENA GORBUNOVA	{"email": "e_gorbunova-01091974@postgrespro.ru", "phone": "+70603466510"}
0005432865956	26D603	0017 200396	MARINA NIKITINA	{"phone": "+70687796210"}
0005432865957	5E022F	0511 922218	ANDREY FEDOTOV	{"email": "afedotov.041973@postgrespro.ru", "phone": "+70831068430"}
0005432865958	6B4542	1465 352737	OLESYA IVANOVA	{"phone": "+70945299577"}
0005432865959	6B4542	5588 436983	SERGEY VOROBEV	{"phone": "+70515165339"}
0005432865960	8C5C42	7251 538934	GALINA LAZAREVA	{"email": "lazarevag-1966@postgrespro.ru", "phone": "+70191111307"}
0005432865961	D3FE8C	2690 908667	NADEZHDA KARPOVA	{"phone": "+70272456719"}
0005432865962	EA7464	1301 890070	ARTUR MAKAROV	{"phone": "+70686554056"}
0005432865963	409AC9	4030 776865	ALFIYA FEDOROVA	{"phone": "+70485928135"}
0005432865964	880FB4	7248 894519	SVETLANA DAVYDOVA	{"phone": "+70629860943"}
0005432865965	4A3F2A	1297 305366	YULIYA OSIPOVA	{"email": "y_osipova_1975@postgrespro.ru", "phone": "+70170628705"}
0005432865966	569AB3	1396 190917	ARINA FADEEVA	{"email": "arina_fadeeva1967@postgrespro.ru", "phone": "+70793656661"}
0005432865967	04A073	5786 720186	TAMARA YAKOVLEVA	{"phone": "+70594501376"}
0005432865968	04A073	2769 333388	LYUDMILA IVANOVA	{"phone": "+70062438235"}
0005432865969	7E0CD8	1340 823853	VIKTOR KULIKOV	{"email": "kulikov.v.121970@postgrespro.ru", "phone": "+70761202629"}
0005432865970	857FEA	4141 647406	ALEKSEY ABRAMOV	{"email": "a.abramov-1980@postgrespro.ru", "phone": "+70262269452"}
0005432866027	0F1809	4048 605161	VASILIY ANDREEV	{"phone": "+70161619618"}
0005432865971	857FEA	6436 621672	NAILYA NAZAROVA	{"email": "nazarova-n-081973@postgrespro.ru", "phone": "+70488043517"}
0005432865972	DF1E06	7475 664718	ALEKSANDR SIDOROV	{"phone": "+70252376758"}
0005432865973	DF1E06	7298 808539	ANDREY MOROZOV	{"email": "morozov.andrey-08081967@postgrespro.ru", "phone": "+70639540509"}
0005432865974	C11AC3	2836 058817	SERGEY KRASNOV	{"email": "sergey-krasnov19111967@postgrespro.ru", "phone": "+70537910891"}
0005432865975	0965A0	4485 899402	YURIY STEPANOV	{"email": "y.stepanov-051969@postgrespro.ru", "phone": "+70901918769"}
0005432865976	DE4711	6503 566331	SEMEN MAKAROV	{"phone": "+70285975185"}
0005432865977	DE4711	4956 764460	ANASTASIYA MIRONOVA	{"email": "a_mironova-08111973@postgrespro.ru", "phone": "+70811524041"}
0005432865978	1F9254	0386 373555	MARIYA IVANOVA	{"email": "ivanova.mariya-1983@postgrespro.ru", "phone": "+70399397986"}
0005432865979	1F9254	2974 405162	VLADIMIR ZAYCEV	{"phone": "+70792999854"}
0005432865980	1F9254	0563 340202	ANNA DMITRIEVA	{"email": "anna_dmitrieva1958@postgrespro.ru", "phone": "+70347952387"}
0005432865981	2623C8	5618 093593	MARAT SEMENOV	{"phone": "+70567031101"}
0005432865982	2623C8	8824 573409	VYACHESLAV KAZAKOV	{"email": "v_kazakov-1979@postgrespro.ru", "phone": "+70113172116"}
0005432865983	5E63C1	1129 057962	NIKOLAY BORISOV	{"email": "nikolay_borisov_1972@postgrespro.ru", "phone": "+70214863158"}
0005432865984	7CEA52	9086 339796	IRINA SOROKINA	{"phone": "+70457574974"}
0005432865985	AF8E24	3310 207708	ANDREY PETROV	{"phone": "+70589656257"}
0005432865986	065839	4125 809457	IRINA IVANOVA	{"email": "irina-ivanova.1978@postgrespro.ru", "phone": "+70099188644"}
0005432865987	065839	3620 617307	ANATOLIY KOZLOV	{"email": "akozlov_1974@postgrespro.ru", "phone": "+70723630007"}
0005432865988	065839	6517 447855	ZHANNA FROLOVA	{"phone": "+70031540840"}
0005432865989	EA8E67	6591 956103	DMITRIY NAZAROV	{"email": "d-nazarov-061965@postgrespro.ru", "phone": "+70247040774"}
0005432865990	EA8E67	1532 249351	MARIYA FADEEVA	{"phone": "+70191542701"}
0005432865991	9E608C	8869 204880	ANNA FROLOVA	{"phone": "+70328566456"}
0005432865992	9E608C	0906 769205	TATYANA TIKHONOVA	{"phone": "+70294391174"}
0005432865993	7FA73D	9186 609877	GALINA ANDREEVA	{"email": "andreevagalina1971@postgrespro.ru", "phone": "+70458347261"}
0005432865994	C67FEA	3263 886795	YULIYA AFANASEVA	{"email": "yuliya-afanaseva011975@postgrespro.ru", "phone": "+70475732692"}
0005432865995	7B7680	4452 927983	MARIYA EGOROVA	{"phone": "+70845135235"}
0005432865996	7B7680	3862 990080	TATYANA KULIKOVA	{"phone": "+70968659106"}
0005432865997	06A0AB	3338 334398	ALBERT KAZAKOV	{"phone": "+70698056912"}
0005432865998	5A1FC0	2732 472210	SVETLANA ANDREEVA	{"phone": "+70025557050"}
0005432865999	3416BE	2547 564700	TIMUR TARASOV	{"phone": "+70170162337"}
0005432866000	614482	1245 166245	LIDIYA GAVRILOVA	{"email": "lidiya_gavrilova-071970@postgrespro.ru", "phone": "+70830117769"}
0005432866001	1DD467	0414 400483	LYUDMILA NOVIKOVA	{"email": "l.novikova_091975@postgrespro.ru", "phone": "+70624603524"}
0005432866002	1DD467	5170 865774	RAMILYA TARASOVA	{"phone": "+70748458134"}
0005432866003	743B18	1887 715620	MIKHAIL STEPANOV	{"email": "stepanov.mikhail.111963@postgrespro.ru", "phone": "+70085979616"}
0005432866004	743B18	2461 563339	OLEG GRIGOREV	{"phone": "+70057633216"}
0005432866005	743B18	3177 105305	ZOYA KUZNECOVA	{"phone": "+70179849412"}
0005432866006	72905D	6657 881018	ALENA PETROVA	{"email": "apetrova.101967@postgrespro.ru", "phone": "+70268006372"}
0005432866007	00D1B1	3347 370965	SVETLANA ZHURAVLEVA	{"email": "zhuravleva_s_061964@postgrespro.ru", "phone": "+70420575907"}
0005432866008	00D1B1	9542 568272	MIKHAIL KARPOV	{"phone": "+70601035441"}
0005432866009	418241	3223 490485	NINA FEDOROVA	{"email": "fedorova.n-091962@postgrespro.ru", "phone": "+70258129886"}
0005432866010	F695A0	9142 795284	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov.10071972@postgrespro.ru", "phone": "+70727544517"}
0005432866011	6C5D7D	0256 176100	OLGA BELOVA	{"email": "belova.o.1973@postgrespro.ru", "phone": "+70931919488"}
0005432866012	E966FF	4244 151543	MARIYA FEDOROVA	{"phone": "+70795207615"}
0005432866013	57B310	5077 292588	ALEKSANDR GRIGOREV	{"phone": "+70161908532"}
0005432866014	586570	9152 279406	OLGA POPOVA	{"phone": "+70190071198"}
0005432866015	CD9E63	2635 802975	MIKHAIL ZHUKOV	{"phone": "+70268759739"}
0005432866016	A4FA8C	7785 257595	LYUDMILA DAVYDOVA	{"phone": "+70190814667"}
0005432866017	A4FA8C	8824 478537	OLESYA SOKOLOVA	{"phone": "+70340273881"}
0005432866018	A72F9B	2895 227256	LIDIYA DAVYDOVA	{"phone": "+70175765739"}
0005432866019	269FEF	6883 697489	SOFYA KRASNOVA	{"email": "krasnova.s1973@postgrespro.ru", "phone": "+70578700353"}
0005432866020	269FEF	5746 180894	NATALYA KOROLEVA	{"phone": "+70879746407"}
0005432866021	269FEF	8189 273878	MAKSIM MIKHAYLOV	{"email": "maksim.mikhaylov_1976@postgrespro.ru", "phone": "+70789562854"}
0005432866022	8FB879	3467 722255	EVGENIY MELNIKOV	{"phone": "+70748953415"}
0005432866023	67C66A	6563 838174	SERGEY MAKAROV	{"email": "smakarov-071970@postgrespro.ru", "phone": "+70884711787"}
0005432866024	D2A2A3	1938 655240	DMITRIY NIKOLAEV	{"email": "nikolaev.dmitriy.12071978@postgrespro.ru", "phone": "+70682830872"}
0005432866025	A4F9E1	8921 665439	VALENTINA GORBUNOVA	{"email": "v-gorbunova.1970@postgrespro.ru", "phone": "+70006043442"}
0005432866026	A4F9E1	0973 644999	ALEKSEY PAVLOV	{"email": "pavlova1959@postgrespro.ru", "phone": "+70454120966"}
0005432866028	9F5B96	1782 164120	NATALYA EFIMOVA	{"phone": "+70512088659"}
0005432866029	A7499A	6324 072014	VLADIMIR KOZLOV	{"phone": "+70345819375"}
0005432866030	2A87DC	4749 590220	ELENA TIKHONOVA	{"email": "e.tikhonova10061974@postgrespro.ru", "phone": "+70218416964"}
0005432866031	2A87DC	8482 595105	EVGENIYA ANISIMOVA	{"phone": "+70819358915"}
0005432866032	2A87DC	1939 377415	LYUDMILA KOVALEVA	{"email": "kovaleva.lyudmila_091980@postgrespro.ru", "phone": "+70168732656"}
0005432866033	2A87DC	6419 361392	VITALIY STEPANOV	{"phone": "+70011483769"}
0005432866034	36AD9D	9955 900960	MARIYA ANDREEVA	{"phone": "+70550223950"}
0005432866035	B37CCE	0337 870356	LIDIYA MAKSIMOVA	{"phone": "+70249216558"}
0005432866036	5D286D	4422 122349	MIKHAIL ALEKSANDROV	{"email": "mikhailaleksandrov-111978@postgrespro.ru", "phone": "+70781012049"}
0005432866037	6DA817	8231 349898	RUSTAM SOROKIN	{"phone": "+70915187045"}
0005432866038	1ADF9A	6627 673531	VLADIMIR NIKITIN	{"phone": "+70035617986"}
0005432866039	6FF40A	1840 923940	ALEKSANDR EGOROV	{"email": "egorov_aleksandr-24121978@postgrespro.ru", "phone": "+70974050123"}
0005432866040	52DB80	3782 018175	RAISA FEDOROVA	{"email": "fedorova.raisa_071984@postgrespro.ru", "phone": "+70418387215"}
0005432866041	52DB80	4884 320861	ANASTASIYA MELNIKOVA	{"phone": "+70455953531"}
0005432866042	061ED7	8769 748660	TATYANA NIKITINA	{"phone": "+70119763816"}
0005432866043	061ED7	0280 516284	MARIYA MALYSHEVA	{"phone": "+70091415172"}
0005432866044	B9CFA1	9392 291278	VYACHESLAV FEDOROV	{"email": "fedorovv.101971@postgrespro.ru", "phone": "+70137902486"}
0005432866045	25745C	7121 509438	VLADISLAV NIKITIN	{"email": "vladislav-nikitin-1968@postgrespro.ru", "phone": "+70383275602"}
0005432866046	25745C	1737 191748	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov.081972@postgrespro.ru", "phone": "+70466178203"}
0005432866047	946D09	0711 244313	NIKOLAY SERGEEV	{"email": "sergeevnikolay.25061969@postgrespro.ru", "phone": "+70173876473"}
0005432866048	B5B474	3765 352182	VLADIMIR SEMENOV	{"email": "semenov.v1966@postgrespro.ru", "phone": "+70172602198"}
0005432866049	B5B474	0132 014088	GALINA NOVIKOVA	{"phone": "+70947937208"}
0005432866050	B5B474	0164 961500	ANASTASIYA DANILOVA	{"phone": "+70203924341"}
0005432866051	519149	5865 015038	ALEKSEY MOROZOV	{"email": "aleksey-morozov1987@postgrespro.ru", "phone": "+70818173294"}
0005432866052	99B515	4821 917541	VASILISA ILINA	{"phone": "+70486745625"}
0005432866053	506D2D	4198 977542	SVETLANA EFIMOVA	{"email": "sefimova.061974@postgrespro.ru", "phone": "+70059938427"}
0005432866054	E34EAF	5922 893823	LIDIYA KAZAKOVA	{"phone": "+70543008440"}
0005432866055	E34EAF	4174 576026	ANNA ORLOVA	{"email": "a_orlova_23051976@postgrespro.ru", "phone": "+70092264156"}
0005432866056	F62422	0220 405475	RAISA ANDREEVA	{"email": "raisaandreeva-15031985@postgrespro.ru", "phone": "+70203191100"}
0005432866057	F62422	8265 934178	ALEKSANDRA SOKOLOVA	{"email": "sokolova-aleksandra-101958@postgrespro.ru", "phone": "+70513529974"}
0005432866058	C6C1B6	1755 518734	VLADISLAV SEMENOV	{"email": "v_semenov_111973@postgrespro.ru", "phone": "+70881925706"}
0005432866059	DAB5E4	6321 254347	OLEG MOROZOV	{"email": "morozovoleg_16031979@postgrespro.ru", "phone": "+70321635103"}
0005432866060	DAB5E4	9812 815216	IGOR BELOV	{"email": "igor.belov011985@postgrespro.ru", "phone": "+70184934365"}
0005432866061	CF8F4A	6968 648432	MIKHAIL DENISOV	{"phone": "+70710880206"}
0005432866062	CF8F4A	8747 383912	VIKTOR MAKSIMOV	{"email": "maksimov-viktor-05101963@postgrespro.ru", "phone": "+70390402022"}
0005432866063	A6A0A9	0135 626081	GLEB PETROV	{"phone": "+70078013801"}
0005432866064	F1B633	2790 070572	ALENA IVANOVA	{"phone": "+70496635734"}
0005432866065	542613	4148 405780	NINA ZAKHAROVA	{"email": "zakharovan17061970@postgrespro.ru", "phone": "+70557896641"}
0005432866066	542613	7002 319812	VLADIMIR KAZAKOV	{"email": "kazakovv.1965@postgrespro.ru", "phone": "+70972258062"}
0005432866067	D8E339	7882 614299	YULIYA IVANOVA	{"phone": "+70199485734"}
0005432866068	D8E339	8041 859836	VALENTINA MALYSHEVA	{"email": "malysheva.v051968@postgrespro.ru", "phone": "+70145123638"}
0005432866069	47F8D7	0680 214497	ALEKSANDR SIDOROV	{"phone": "+70861269639"}
0005432866070	47F8D7	4404 050997	OLGA ERMAKOVA	{"phone": "+70827513458"}
0005432866071	2154B0	8877 809958	LIDIYA RYABOVA	{"email": "ryabova_lidiya-04011971@postgrespro.ru", "phone": "+70304788787"}
0005432866072	270CC5	5053 743452	YURIY ORLOV	{"phone": "+70275526304"}
0005432866073	6566CE	8122 686299	TATYANA NOVIKOVA	{"email": "novikovat_1973@postgrespro.ru", "phone": "+70664852091"}
0005432866074	65630C	6871 872457	ANNA NIKOLAEVA	{"phone": "+70129360350"}
0005432866075	89B331	4571 541122	PAVEL PETROV	{"email": "pavelpetrov02121965@postgrespro.ru", "phone": "+70388174242"}
0005432866076	EBF639	4968 113113	NIKOLAY IVANOV	{"email": "ivanov_n-1960@postgrespro.ru", "phone": "+70301752450"}
0005432866077	E82648	7528 471590	NIKITA KISELEV	{"email": "kiselev_nikita.30111980@postgrespro.ru", "phone": "+70686605764"}
0005432866078	D81BC7	3017 887444	NATALIYA MARTYNOVA	{"email": "nmartynova.061981@postgrespro.ru", "phone": "+70596574715"}
0005432866079	D81BC7	5941 553700	ALEKSEY IVANOV	{"email": "a.ivanov-19111959@postgrespro.ru", "phone": "+70694435703"}
0005432866080	D81BC7	3045 131343	EVGENIYA KOROLEVA	{"email": "korolevaevgeniya-1973@postgrespro.ru", "phone": "+70452416606"}
0005432866081	ED5CC2	0578 306567	ANATOLIY SOROKIN	{"email": "anatoliy-sorokin24061974@postgrespro.ru", "phone": "+70039803940"}
0005432866082	9151DA	7817 301987	NIKITA ALEKSEEV	{"email": "alekseev-n-061980@postgrespro.ru", "phone": "+70996569480"}
0005432866083	5AE88A	3594 813505	TATYANA KONOVALOVA	{"phone": "+70759935745"}
0005432866084	5AE88A	5700 064743	LILIYA LEBEDEVA	{"phone": "+70429813736"}
0005432866085	5AE88A	7453 096282	ALEKSANDR MIRONOV	{"email": "aleksandr-mironov.11021974@postgrespro.ru", "phone": "+70632845146"}
0005432866086	447DD4	1741 765498	MARIYA KOMAROVA	{"phone": "+70709042465"}
0005432866087	63EDAE	3190 041652	TATYANA SCHERBAKOVA	{"email": "scherbakovatatyana.1972@postgrespro.ru", "phone": "+70190705694"}
0005432866088	0B7A1E	2634 051084	TATYANA ARKHIPOVA	{"email": "arkhipova_tatyana_21091977@postgrespro.ru", "phone": "+70641934672"}
0005432866089	0B7A1E	8716 292623	ALEKSEY EGOROV	{"phone": "+70979232688"}
0005432866090	F3B139	1497 089548	ANASTASIYA MARTYNOVA	{"phone": "+70026398207"}
0005432866091	628B50	0793 617675	KLAVDIYA FEDOROVA	{"phone": "+70098181973"}
0005432866092	628B50	6004 150090	SVETLANA MATVEEVA	{"email": "s.matveeva_041960@postgrespro.ru", "phone": "+70185929044"}
0005432866093	628B50	4486 457602	SERGEY ORLOV	{"email": "sergey.orlov_1970@postgrespro.ru", "phone": "+70121898066"}
0005432866094	E0DE58	3914 411078	ALEKSANDR EGOROV	{"email": "aleksandregorov-1967@postgrespro.ru", "phone": "+70811191596"}
0005432866095	2DB10B	0599 518729	BORIS MAKAROV	{"email": "bmakarov-1981@postgrespro.ru", "phone": "+70072228452"}
0005432866096	46F7E3	2401 020928	ALEKSANDR BONDARENKO	{"email": "bondarenko.a.1964@postgrespro.ru", "phone": "+70627131791"}
0005432866097	A349FE	1500 119664	ROZA POPOVA	{"email": "roza.popova1974@postgrespro.ru", "phone": "+70051244062"}
0005432866098	1C1419	0772 561039	OLGA KOROLEVA	{"phone": "+70324539727"}
0005432866099	72245A	4665 669863	LIDIYA FEDOROVA	{"email": "lfedorova.091964@postgrespro.ru", "phone": "+70483931433"}
0005432866100	39B5E8	8975 560043	NINA KRASNOVA	{"email": "krasnova-nina.04111965@postgrespro.ru", "phone": "+70364481205"}
0005432866101	11F302	2467 617734	VIKTOR VASILEV	{"phone": "+70159960352"}
0005432866102	11F302	9294 591938	ALEKSANDRA SIDOROVA	{"email": "sidorova_aleksandra_081975@postgrespro.ru", "phone": "+70244811255"}
0005432866103	704993	4038 347445	YULIYA PAVLOVA	{"email": "y.pavlova1968@postgrespro.ru", "phone": "+70835844965"}
0005432866104	704993	9455 612498	NATALIYA DMITRIEVA	{"phone": "+70684023321"}
0005432866105	4AF03F	6865 889357	VLADIMIR VASILEV	{"email": "vvasilev031972@postgrespro.ru", "phone": "+70306289894"}
0005432866106	A7F347	4022 283791	NINA TIKHONOVA	{"email": "tikhonova-n_20111968@postgrespro.ru", "phone": "+70400724756"}
0005432866107	E0AE52	8032 560901	IRINA EFREMOVA	{"phone": "+70917405189"}
0005432866108	E0AE52	8702 404321	DENIS EGOROV	{"phone": "+70006551892"}
0005432866109	DCA505	9549 563656	ALEKSANDR ABRAMOV	{"email": "aabramov1965@postgrespro.ru", "phone": "+70217346816"}
0005432866110	E8AD6A	5342 551160	YULIYA MEDVEDEVA	{"phone": "+70759776349"}
0005432866111	E8AD6A	5754 823257	KRISTINA ALEKSEEVA	{"email": "alekseeva-k-061975@postgrespro.ru", "phone": "+70556968933"}
0005432866112	D2A26D	9428 901629	TAMARA MELNIKOVA	{"phone": "+70626920159"}
0005432866113	0CC919	7537 760129	ALEKSANDR FEDOROV	{"phone": "+70412842494"}
0005432866114	AABD56	9158 512573	TATYANA KUDRYASHOVA	{"email": "t.kudryashova-30011974@postgrespro.ru", "phone": "+70032558207"}
0005432866115	AABD56	4595 344850	VITALIY FEDOTOV	{"email": "fedotov.v081979@postgrespro.ru", "phone": "+70341527074"}
0005432866116	844375	4225 376224	TATYANA PETROVA	{"phone": "+70418907765"}
0005432866117	844375	6279 906061	ANDREY DMITRIEV	{"phone": "+70884708505"}
0005432866118	EFA95A	2892 449796	OLGA ILINA	{"phone": "+70921707107"}
0005432866119	EFA95A	1528 137983	NIKOLAY KONOVALOV	{"phone": "+70710634381"}
0005432866120	D4CE8E	5336 569606	VLADISLAV SCHERBAKOV	{"phone": "+70940539749"}
0005432866121	B65569	3545 065487	ANNA NESTEROVA	{"email": "nesterova.anna-1975@postgrespro.ru", "phone": "+70774437352"}
0005432866122	00E5DC	4374 265717	MARIYA KUZNECOVA	{"phone": "+70710068934"}
0005432866123	139240	1272 518167	DINA VOLKOVA	{"phone": "+70193869112"}
0005432866124	F4772B	9236 421730	IRINA KOROLEVA	{"email": "koroleva.irina-1956@postgrespro.ru", "phone": "+70249491752"}
0005432866125	F20689	0704 144159	DMITRIY PETROV	{"phone": "+70753902108"}
0005432866126	F20689	6365 443276	SERGEY DMITRIEV	{"email": "dmitriev-s.1970@postgrespro.ru", "phone": "+70492429050"}
0005432866127	F20689	8863 373404	OLEG GUSEV	{"email": "gusev.o.03051977@postgrespro.ru", "phone": "+70490558341"}
0005432866128	D5A532	5599 324939	ANATOLIY BONDARENKO	{"phone": "+70150372727"}
0005432866129	0FCF3E	8082 499283	ANASTASIYA OSIPOVA	{"phone": "+70222512154"}
0005432866130	48F527	4562 596422	IRINA STEPANOVA	{"email": "stepanova_irina.1973@postgrespro.ru", "phone": "+70566343894"}
0005432866131	48F527	1625 985909	VLADISLAV EGOROV	{"phone": "+70621915050"}
0005432866132	48F527	0969 710716	MIKHAIL MOROZOV	{"phone": "+70593104871"}
0005432866133	53611A	4894 053369	DENIS MAKSIMOV	{"phone": "+70383019129"}
0005432869443	69640E	7106 826143	ALEKSANDR POPOV	{"phone": "+70146937335"}
0005432866134	53611A	6616 336912	ARSENIY SMIRNOV	{"email": "smirnov_a-14011966@postgrespro.ru", "phone": "+70742040871"}
0005432866135	45B251	4704 950688	VALENTINA MOISEEVA	{"phone": "+70656279939"}
0005432866136	2187ED	4486 930528	RUSLAN MOROZOV	{"email": "morozov.r1970@postgrespro.ru", "phone": "+70727887470"}
0005432866137	2187ED	9772 456351	ANDREY AFANASEV	{"email": "afanasev_a.061982@postgrespro.ru", "phone": "+70240322831"}
0005432866138	FF041B	5823 004129	VLADIMIR EGOROV	{"email": "vladimiregorov-1971@postgrespro.ru", "phone": "+70554910972"}
0005432866139	FF041B	8892 691586	ELENA PAVLOVA	{"phone": "+70711641274"}
0005432866140	7A7B41	5935 097523	GENNADIY POPOV	{"email": "g_popov091967@postgrespro.ru", "phone": "+70242973356"}
0005432866141	284D58	6249 696987	ELIZAVETA KOROLEVA	{"phone": "+70204250792"}
0005432866142	284D58	3997 673597	VALERIY RODIONOV	{"email": "v.rodionov_101965@postgrespro.ru", "phone": "+70129491580"}
0005432866143	B31898	2654 774644	FEDOR KONOVALOV	{"email": "konovalov_fedor031963@postgrespro.ru", "phone": "+70320539070"}
0005432866144	FB183A	0515 588579	EKATERINA ANISIMOVA	{"email": "eanisimova.1967@postgrespro.ru", "phone": "+70186219650"}
0005432866145	6A5DC6	3416 629742	ELENA VLASOVA	{"phone": "+70362317066"}
0005432866146	6A5DC6	2349 744331	GENNADIY SOROKIN	{"email": "sorokin_gennadiy_1980@postgrespro.ru", "phone": "+70652026450"}
0005432866147	EDAA7D	4981 331930	OLGA VLASOVA	{"phone": "+70230647121"}
0005432866148	DBCEA8	9050 083922	VIKTORIYA ROMANOVA	{"email": "v.romanova.071960@postgrespro.ru", "phone": "+70581905551"}
0005432866149	DBCEA8	7020 638243	NIKOLAY MELNIKOV	{"email": "nmelnikov-1971@postgrespro.ru", "phone": "+70579420024"}
0005432866150	D53114	7203 053348	PELAGEYA FEDOROVA	{"email": "fedorova_p.1974@postgrespro.ru", "phone": "+70209507726"}
0005432866151	073657	9444 775243	SVETLANA MATVEEVA	{"phone": "+70333947971"}
0005432866152	148733	4006 851709	LYUBOV KOROLEVA	{"email": "lyubov_koroleva-031978@postgrespro.ru", "phone": "+70213722364"}
0005432866153	38EB42	9974 440714	NINA ZHUKOVA	{"email": "zhukova_nina.04041965@postgrespro.ru", "phone": "+70046711968"}
0005432866154	93984B	5301 307823	MAKSIM KOROLEV	{"email": "m.korolev_14061970@postgrespro.ru", "phone": "+70905617873"}
0005432866155	FD07C2	1342 605582	ELENA DMITRIEVA	{"email": "elena.dmitrieva_1955@postgrespro.ru", "phone": "+70609515508"}
0005432866156	2F68AD	3527 644833	VASILIY EGOROV	{"email": "v-egorov.1971@postgrespro.ru", "phone": "+70111786186"}
0005432866157	36A9EC	2042 098699	ANDREY GAVRILOV	{"email": "agavrilov05021981@postgrespro.ru", "phone": "+70961660657"}
0005432866158	58F7A6	9337 441906	NATALYA SMIRNOVA	{"phone": "+70089099482"}
0005432866159	A4EBBB	3088 295914	LYUDMILA KUZNECOVA	{"phone": "+70797805567"}
0005432866160	3F47D9	9559 957180	VLADIMIR KAZAKOV	{"email": "vladimir_kazakov-121969@postgrespro.ru", "phone": "+70273623535"}
0005432866161	1464AA	8471 361802	VYACHESLAV FROLOV	{"phone": "+70057196666"}
0005432866162	441010	7125 909200	VALERIYA ILINA	{"phone": "+70406774681"}
0005432866163	58E66B	9381 543229	RENAT SHEVCHENKO	{"email": "renat.shevchenko1976@postgrespro.ru", "phone": "+70938373368"}
0005432866164	997EFA	6032 279717	DMITRIY NAZAROV	{"email": "nazarov_d_1972@postgrespro.ru", "phone": "+70214355633"}
0005432866165	997EFA	7046 859768	YURIY MAKAROV	{"phone": "+70924104630"}
0005432866166	997EFA	5034 999308	VLADIMIR ANTONOV	{"email": "vladimir_antonov.091963@postgrespro.ru", "phone": "+70075734989"}
0005432866167	24E701	5680 083936	NATALYA BELYAEVA	{"email": "belyaeva-n_1971@postgrespro.ru", "phone": "+70215494826"}
0005432866168	24E701	8653 006048	KRISTINA VASILEVA	{"email": "vasilevak1972@postgrespro.ru", "phone": "+70806413207"}
0005432866169	DEFB18	0680 908801	ALINA YAKOVLEVA	{"email": "yakovlevaa_1956@postgrespro.ru", "phone": "+70343479233"}
0005432866170	3556E0	3686 345987	ALEKSANDR ANDREEV	{"phone": "+70486935551"}
0005432866171	3556E0	9911 261948	VLADISLAV MAKAROV	{"phone": "+70744262089"}
0005432866172	4217A0	7390 382666	VLADIMIR MAKAROV	{"email": "vladimir-makarov.071979@postgrespro.ru", "phone": "+70569913888"}
0005432866173	4217A0	4906 243475	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr_15051967@postgrespro.ru", "phone": "+70242759748"}
0005432866174	10810C	4432 186932	IGOR NAZAROV	{"email": "nazarov_i_1970@postgrespro.ru", "phone": "+70448836128"}
0005432866175	10810C	0751 871714	ANDREY EGOROV	{"phone": "+70388130936"}
0005432866176	E0E3C0	2450 871080	ANASTASIYA MELNIKOVA	{"phone": "+70290495438"}
0005432866177	74DC60	0213 783429	KRISTINA TARASOVA	{"email": "tarasova.k_08081978@postgrespro.ru", "phone": "+70512336988"}
0005432866178	543DC6	0638 002764	DMITRIY VASILEV	{"phone": "+70951344727"}
0005432866179	543DC6	4850 212524	SERGEY ISAEV	{"email": "sergey_isaev.091969@postgrespro.ru", "phone": "+70955699474"}
0005432866180	D2310A	9923 818486	ZINAIDA KALININA	{"phone": "+70680054007"}
0005432866181	D2310A	9413 117802	ANDREY BELOV	{"email": "a_belov-101974@postgrespro.ru", "phone": "+70901402646"}
0005432866182	D2310A	9093 913050	EVGENIY AFANASEV	{"email": "evgeniy_afanasev101974@postgrespro.ru", "phone": "+70905700455"}
0005432866183	5ED842	0550 240620	VERA KUZNECOVA	{"email": "v-kuznecova.21101962@postgrespro.ru", "phone": "+70392450861"}
0005432866184	95206B	6511 218789	NATALYA POPOVA	{"email": "popova.n.05091974@postgrespro.ru", "phone": "+70233478179"}
0005432866185	95206B	6661 814068	VYACHESLAV SEMENOV	{"email": "semenov.v_1972@postgrespro.ru", "phone": "+70774790189"}
0005432866186	6C0222	9648 831279	ZARINA ALEKSEEVA	{"email": "alekseeva-z_021971@postgrespro.ru", "phone": "+70182486399"}
0005432866187	6C0222	4600 469515	ULYANA IVANOVA	{"phone": "+70808319700"}
0005432866188	6C0222	8549 599328	MARINA KONDRATEVA	{"email": "marina_kondrateva1968@postgrespro.ru", "phone": "+70340229309"}
0005432866189	D8E89E	6089 557695	VALERIYA POPOVA	{"email": "valeriyapopova.021983@postgrespro.ru", "phone": "+70516312445"}
0005432866190	8F1ECE	4681 116092	ALEKSANDRA ILINA	{"email": "ilina.a_20021962@postgrespro.ru", "phone": "+70266045874"}
0005432866191	CF0F9D	2865 870203	NATALYA SERGEEVA	{"email": "natalya_sergeeva_061970@postgrespro.ru", "phone": "+70262879653"}
0005432866192	CF0F9D	6522 719041	YAROSLAV ALEKSEEV	{"phone": "+70515346455"}
0005432866193	809A10	8578 357102	LYUBOV SOROKINA	{"phone": "+70060184643"}
0005432866194	D67D77	3196 721626	EVGENIYA TIKHONOVA	{"phone": "+70444105981"}
0005432866195	D67D77	1503 257686	ALEKSANDR POPOV	{"email": "popov_aleksandr.1981@postgrespro.ru", "phone": "+70559586721"}
0005432866196	D65F62	7859 592553	YURIY MIKHAYLOV	{"phone": "+70187457876"}
0005432866197	D65F62	0186 075823	VLADIMIR SEMENOV	{"phone": "+70231900595"}
0005432866198	4ED4DF	5063 066180	SERGEY SOKOLOV	{"phone": "+70449999545"}
0005432866199	DBD70D	8222 889147	ALEKSANDR GRIGOREV	{"email": "grigorev.a.1969@postgrespro.ru", "phone": "+70387598528"}
0005432866200	DBD70D	6484 642898	LYUBOV CHERNOVA	{"phone": "+70754184979"}
0005432866201	DBD70D	1985 072360	IRINA TIMOFEEVA	{"phone": "+70430251989"}
0005432866202	4CE235	7340 197534	NADIYA POTAPOVA	{"phone": "+70150512762"}
0005432866203	179A40	7174 328626	ALEKSANDR KARPOV	{"email": "a.karpov-121975@postgrespro.ru", "phone": "+70055927456"}
0005432866204	D7A0D5	8324 905894	ANASTASIYA ZAYCEVA	{"email": "zayceva.a1977@postgrespro.ru", "phone": "+70561678530"}
0005432866205	B44124	1696 136087	MARIYA KISELEVA	{"phone": "+70533256402"}
0005432866206	1D6295	8455 696945	TAMARA MEDVEDEVA	{"email": "t.medvedeva-041977@postgrespro.ru", "phone": "+70528608643"}
0005432866207	D2BB91	2847 959428	VALERIY FROLOV	{"email": "frolov_v1974@postgrespro.ru", "phone": "+70753661935"}
0005432866208	137EAC	0854 932564	RUSLAN AFANASEV	{"email": "afanasev-ruslan-1967@postgrespro.ru", "phone": "+70086414828"}
0005432866209	8E2D1B	4671 474026	ALEKSANDR RODIONOV	{"phone": "+70186505851"}
0005432866210	6A06EA	8917 541261	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana101972@postgrespro.ru", "phone": "+70736976036"}
0005432866211	6A06EA	1291 289950	TATYANA KULIKOVA	{"phone": "+70732927658"}
0005432866212	F80019	0783 557122	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey-15051959@postgrespro.ru", "phone": "+70451207109"}
0005432866213	F80019	5713 612165	GUZEL CHERNOVA	{"phone": "+70212690850"}
0005432866214	46B0BC	3488 789364	VLADIMIR POPOV	{"phone": "+70667280449"}
0005432866215	46B0BC	4983 257986	VALENTINA NIKIFOROVA	{"email": "nikiforova-v1969@postgrespro.ru", "phone": "+70477796352"}
0005432866216	5ADE14	8678 220772	MARIYA BELYAEVA	{"email": "mariya-belyaeva_1962@postgrespro.ru", "phone": "+70325541352"}
0005432866217	D07F4B	7598 208678	VLADIMIR IVANOV	{"email": "ivanov_vladimir_1971@postgrespro.ru", "phone": "+70712395726"}
0005432866218	D07F4B	9815 281146	MAYA GORBUNOVA	{"email": "gorbunova-maya_1973@postgrespro.ru", "phone": "+70413271670"}
0005432866219	316AFC	8504 252565	VASILIY NIKITIN	{"phone": "+70499788183"}
0005432866220	6A5A5C	8744 761973	NIKOLAY TIMOFEEV	{"phone": "+70444135928"}
0005432869412	286B9A	5881 276775	MAKSIM ORLOV	{"phone": "+70274150570"}
0005432869413	64B02B	5722 142396	VLADIMIR GRIGOREV	{"phone": "+70881638461"}
0005432869414	8013E6	1006 224479	MIKHAIL KISELEV	{"phone": "+70121335588"}
0005432869415	59E2C1	9530 000979	ANTONINA BELOVA	{"email": "belova-a-1979@postgrespro.ru", "phone": "+70414936008"}
0005432869416	59E2C1	2053 739408	ELENA POPOVA	{"email": "e.popova101960@postgrespro.ru", "phone": "+70838300410"}
0005432869417	07A3B0	8019 770276	LIDIYA MATVEEVA	{"phone": "+70817183319"}
0005432869418	5D8AB8	7761 941236	IRINA IVANOVA	{"email": "i_ivanova101977@postgrespro.ru", "phone": "+70509499116"}
0005432869419	B338F4	9239 754962	LYUBOV EGOROVA	{"email": "egorova-lyubov.061976@postgrespro.ru", "phone": "+70473536416"}
0005432869420	B338F4	2030 227835	MARINA SCHERBAKOVA	{"email": "marina_scherbakova.19011977@postgrespro.ru", "phone": "+70458408876"}
0005432869421	06E92E	6804 009977	ALEKSANDR KUZNECOV	{"phone": "+70358974454"}
0005432869422	E5E229	8179 023952	MARIYA DAVYDOVA	{"phone": "+70770470854"}
0005432869423	E5E229	9399 472686	MIKHAIL KONOVALOV	{"email": "konovalov_m-021967@postgrespro.ru", "phone": "+70649962189"}
0005432869424	48A348	3147 777428	VALERIYA POPOVA	{"email": "v-popova121971@postgrespro.ru", "phone": "+70613721367"}
0005432869425	A6D487	3618 776935	TIMUR PETROV	{"phone": "+70719947985"}
0005432869426	CB9FDC	8493 975068	LYUDMILA FROLOVA	{"phone": "+70040439995"}
0005432869427	11E863	7056 555195	EVGENIYA BELYAEVA	{"email": "e-belyaeva-121970@postgrespro.ru", "phone": "+70982029222"}
0005432869428	AEF40B	7414 208375	TATYANA NESTEROVA	{"phone": "+70470985997"}
0005432869429	F60D13	4678 499986	NADEZHDA MEDVEDEVA	{"phone": "+70418775153"}
0005432869430	380244	8850 179335	YULIYA MARTYNOVA	{"email": "martynova_yuliya_101965@postgrespro.ru", "phone": "+70773423827"}
0005432869431	01CD1F	2286 917931	IGOR ISAEV	{"email": "isaevi-021992@postgrespro.ru", "phone": "+70791016812"}
0005432869432	9A1A53	3756 106863	SVETLANA KALININA	{"email": "kalininas1984@postgrespro.ru", "phone": "+70224682764"}
0005432869433	6F1960	9491 249248	IVAN VASILEV	{"email": "i_vasilev-121963@postgrespro.ru", "phone": "+70022289873"}
0005432869434	C423F1	3645 788419	MARINA PETROVA	{"phone": "+70415618527"}
0005432869435	853B28	4581 686641	TATYANA ERMAKOVA	{"email": "t.ermakova1977@postgrespro.ru", "phone": "+70838081944"}
0005432869436	A133B6	9554 139546	LYUDMILA ALEKSEEVA	{"phone": "+70249475018"}
0005432869437	A133B6	7594 807727	EVGENIYA YAKOVLEVA	{"email": "yakovleva-evgeniya1967@postgrespro.ru", "phone": "+70492577270"}
0005432869438	00B76F	0745 143966	ALEKSANDR SEMENOV	{"phone": "+70097664238"}
0005432869439	00B76F	0308 790886	IRINA NAZAROVA	{"phone": "+70641628807"}
0005432869440	00B76F	7453 847573	VYACHESLAV RODIONOV	{"email": "vyacheslav_rodionov.1970@postgrespro.ru", "phone": "+70820917667"}
0005432869441	B2F9D8	6782 015020	ZOYA VLASOVA	{"email": "vlasova-zoya111969@postgrespro.ru", "phone": "+70737944772"}
0005432869442	69640E	1814 582825	ANDREY BARANOV	{"email": "baranov_a_21051961@postgrespro.ru", "phone": "+70833815368"}
0005432869444	5429E3	0500 553051	VALENTINA ZHUKOVA	{"phone": "+70817053991"}
0005432869445	5429E3	6350 804529	IGOR IVANOV	{"phone": "+70878377176"}
0005432869446	7E15D6	0210 058224	RAISA AFANASEVA	{"phone": "+70343497728"}
0005432869447	F3B954	6678 524052	ALLA KUZNECOVA	{"email": "akuznecova09051971@postgrespro.ru", "phone": "+70479099478"}
0005432869448	F3B954	6229 873716	MIKHAIL KONOVALOV	{"email": "konovalov_m-1963@postgrespro.ru", "phone": "+70448067682"}
0005432869449	93200F	7394 169961	MIKHAIL KISELEV	{"phone": "+70701187232"}
0005432869450	93200F	3121 335792	ANATOLIY VASILEV	{"email": "anatoliyvasilev_121973@postgrespro.ru", "phone": "+70072109604"}
0005432869451	B58EAC	7615 378612	RENAT MARTYNOV	{"phone": "+70585161961"}
0005432869452	506CB5	8434 718728	TAMARA ANDREEVA	{"phone": "+70501292918"}
0005432869453	76278D	6473 173783	KIRILL POPOV	{"phone": "+70680470571"}
0005432869454	DF22DD	9324 973247	ILYA KUZNECOV	{"phone": "+70881584260"}
0005432869455	7CEA63	6370 987947	NATALYA TARASOVA	{"email": "tarasova-natalya-1964@postgrespro.ru", "phone": "+70142761138"}
0005432869456	109635	7798 650065	PAVEL MIKHAYLOV	{"email": "mikhaylov.pavel121972@postgrespro.ru", "phone": "+70697888151"}
0005432869457	98B069	6954 270641	ANATOLIY MOROZOV	{"phone": "+70270233775"}
0005432869458	98B069	7999 405313	YAROSLAV SIDOROV	{"phone": "+70815679898"}
0005432869459	825E24	3059 726444	VASILIY ZHURAVLEV	{"email": "v.zhuravlev.1973@postgrespro.ru", "phone": "+70499149404"}
0005432869460	825E24	3023 813578	VERA KUDRYASHOVA	{"email": "kudryashova.v.1978@postgrespro.ru", "phone": "+70910457732"}
0005432869461	E32D33	0778 184680	LYUBOV KOROLEVA	{"phone": "+70396503585"}
0005432869462	E32D33	8726 502041	NATALYA CHERNOVA	{"phone": "+70360784854"}
0005432869463	E32D33	6566 460237	IVAN VOLKOV	{"email": "volkov-i_1984@postgrespro.ru", "phone": "+70244682524"}
0005432869464	0FFFFE	5520 444444	NIKITA NIKOLAEV	{"phone": "+70872989603"}
0005432869465	6BBEE6	2670 599745	GALINA ZHURAVLEVA	{"email": "galina.zhuravleva.1977@postgrespro.ru", "phone": "+70974213166"}
0005432869466	6BBEE6	9318 702160	LYUDMILA FROLOVA	{"email": "frolova.l_13101961@postgrespro.ru", "phone": "+70950858252"}
0005432869467	6BBEE6	2066 487540	ELENA KARPOVA	{"email": "karpova.elena_1973@postgrespro.ru", "phone": "+70637791623"}
0005432869468	77F0F7	0486 918834	ALEKSEY PAVLOV	{"phone": "+70666642679"}
0005432869469	DD501E	6894 012095	VALENTINA RYABOVA	{"phone": "+70239818962"}
0005432869470	DD501E	3832 030770	TATYANA KARPOVA	{"email": "tatyana_karpova1977@postgrespro.ru", "phone": "+70020159969"}
0005432869471	FAC630	0934 687909	ARTUR ALEKSANDROV	{"email": "aaleksandrov011974@postgrespro.ru", "phone": "+70388645868"}
0005432869472	FAC630	0002 655460	OLGA IVANOVA	{"email": "ivanova.o_28091977@postgrespro.ru", "phone": "+70278462371"}
0005432869473	9721DD	8965 322187	ZOYA KALININA	{"phone": "+70224848683"}
0005432869474	321C32	3106 072870	VALERIYA GERASIMOVA	{"phone": "+70029082228"}
0005432869475	425AC5	9252 323574	VYACHESLAV KUDRYASHOV	{"phone": "+70459272018"}
0005432869476	CD9ECA	6349 613798	SERGEY KULIKOV	{"email": "kulikov_sergey-101969@postgrespro.ru", "phone": "+70447839380"}
0005432869477	F86BD4	3022 152509	STEPAN KUDRYASHOV	{"phone": "+70156329834"}
0005432869478	F86BD4	0985 217638	LILIYA KOMAROVA	{"email": "liliya-komarova091978@postgrespro.ru", "phone": "+70269774908"}
0005432869479	924FF7	2613 520695	VALERIY NOVIKOV	{"email": "novikovv-101977@postgrespro.ru", "phone": "+70716938584"}
0005432869480	924FF7	8996 015998	SERGEY KUZNECOV	{"phone": "+70911412326"}
0005432869481	74954F	6214 269865	ANASTASIYA OSIPOVA	{"email": "osipova_anastasiya.051975@postgrespro.ru", "phone": "+70283625045"}
0005432869482	69C27B	0711 905076	LYUDMILA ISAEVA	{"phone": "+70000274841"}
0005432869483	D601E7	3610 984721	ALBINA MOROZOVA	{"email": "morozova-a061963@postgrespro.ru", "phone": "+70714334913"}
0005432869484	D278FF	0062 557188	IGOR KUZNECOV	{"email": "kuznecovigor.091965@postgrespro.ru", "phone": "+70653464544"}
0005432869485	D278FF	0798 275211	GENNADIY BONDARENKO	{"email": "bondarenko_g.04091974@postgrespro.ru", "phone": "+70808051285"}
0005432869486	5FD238	5772 732264	EKATERINA NIKITINA	{"phone": "+70517876886"}
0005432869487	AD702F	0244 314650	VLADIMIR DENISOV	{"phone": "+70488033173"}
0005432869488	ACC931	5101 328351	IGOR GUSEV	{"email": "igor-gusev_101969@postgrespro.ru", "phone": "+70648945667"}
0005432869489	DAF4A7	9560 707463	YURIY KUZNECOV	{"email": "yuriy.kuznecov_1969@postgrespro.ru", "phone": "+70392697264"}
0005432869490	D2C982	2533 457589	VLADIMIR KUZNECOV	{"phone": "+70422989480"}
0005432869491	225DBC	7676 270709	OLGA ISAEVA	{"email": "isaevao.011979@postgrespro.ru", "phone": "+70355744427"}
0005432869492	6DA72C	0184 275991	ANASTASIYA KARPOVA	{"email": "karpovaa24121964@postgrespro.ru", "phone": "+70359462022"}
0005432869493	D0F1B5	3194 267722	VALENTIN MOISEEV	{"email": "moiseev.valentin1972@postgrespro.ru", "phone": "+70228767216"}
0005432869494	383758	9077 147315	RUSTAM IVANOV	{"email": "ivanov.rustam.1978@postgrespro.ru", "phone": "+70124031570"}
0005432869495	32D10C	9338 135106	NIKOLAY SCHERBAKOV	{"phone": "+70818835553"}
0005432869496	32D10C	0214 808706	VLADIMIR MELNIKOV	{"email": "vladimir_melnikov.1973@postgrespro.ru", "phone": "+70907237442"}
0005432869497	26A69B	2274 344068	VALENTINA ORLOVA	{"email": "valentinaorlova-081977@postgrespro.ru", "phone": "+70206112390"}
0005432869498	9B56B3	1567 829529	NIKITA IVANOV	{"phone": "+70931478963"}
0005432869499	676CB9	0110 491662	ANNA SEMENOVA	{"phone": "+70888214794"}
0005432869500	676CB9	1479 465940	SERGEY NIKOLAEV	{"email": "nikolaev_s-111980@postgrespro.ru", "phone": "+70267514404"}
0005432869501	86E7C4	9300 849867	YURIY SIDOROV	{"email": "y.sidorov.1965@postgrespro.ru", "phone": "+70697696533"}
0005432869502	86E7C4	6669 370315	TATYANA POPOVA	{"email": "tatyana.popova_1981@postgrespro.ru", "phone": "+70222183125"}
0005432869503	CCC45C	7430 424940	OLEG IVANOV	{"phone": "+70490407793"}
0005432869504	15A0D9	2816 913989	SERGEY ILIN	{"email": "sergeyilin_22101992@postgrespro.ru", "phone": "+70993190275"}
0005432869505	FB2E92	3840 443383	SERGEY SOLOVEV	{"phone": "+70468486204"}
0005432869506	FB2E92	3866 825734	IGOR GRIGOREV	{"email": "i_grigorev_1978@postgrespro.ru", "phone": "+70929363830"}
0005432869507	0DAF63	9921 248942	LYUDMILA NIKITINA	{"phone": "+70271918052"}
0005432869508	0A4CB4	1567 575794	ALEKSANDRA ZAKHAROVA	{"email": "a-zakharova_27011977@postgrespro.ru", "phone": "+70340274031"}
0005432869509	0A4CB4	8403 183280	ANTON VASILEV	{"email": "anton.vasilev_051970@postgrespro.ru", "phone": "+70933537482"}
0005432869510	9CEDDC	3805 951440	GALINA VLASOVA	{"email": "vlasova-galina-24091966@postgrespro.ru", "phone": "+70985752718"}
0005432869511	9CEDDC	3497 157205	TATYANA IVANOVA	{"phone": "+70318924064"}
0005432869512	ADBC47	4445 898898	MIKHAIL BELOV	{"phone": "+70327373788"}
0005432869513	7642CD	5074 428482	GUZEL MOISEEVA	{"email": "guzelmoiseeva-1981@postgrespro.ru", "phone": "+70593244900"}
0005432869514	017D35	4538 352173	VYACHESLAV ANTONOV	{"phone": "+70656166014"}
0005432869515	04FEFB	7740 037135	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a-1974@postgrespro.ru", "phone": "+70822926611"}
0005432869516	3934A6	7097 182734	NATALYA MASLOVA	{"phone": "+70562132337"}
0005432869517	264070	9751 680548	VLADIMIR SCHERBAKOV	{"phone": "+70933124533"}
0005432869518	58A147	4449 731864	ALENA SIDOROVA	{"phone": "+70724704775"}
0005432869519	B7B069	1149 493494	ALEKSEY POPOV	{"email": "aleksey-popov12071970@postgrespro.ru", "phone": "+70782816445"}
0005432869520	B7B069	4242 922743	VLADIMIR IVANOV	{"email": "ivanovv-021981@postgrespro.ru", "phone": "+70740100614"}
0005432869521	856B46	8480 330484	VALERIY KAZAKOV	{"phone": "+70864928875"}
0005432869522	856B46	5534 892027	ALEKSEY PAVLOV	{"phone": "+70923023399"}
0005432869523	69D25A	7160 991501	ALEKSEY MAKSIMOV	{"phone": "+70613639523"}
0005432869524	93C9E2	3386 983323	VLADISLAV VASILEV	{"phone": "+70130355190"}
0005432869525	637856	3858 774887	DARYA FADEEVA	{"phone": "+70221693905"}
0005432869526	4AFEA9	4308 387331	ANASTASIYA MALYSHEVA	{"phone": "+70670196874"}
0005432869527	4AFEA9	5401 543221	MARINA SIDOROVA	{"email": "marina.sidorova_081970@postgrespro.ru", "phone": "+70176633675"}
0005432869528	5EDA1D	2345 355043	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir.1976@postgrespro.ru", "phone": "+70281323178"}
0005432869529	5EDA1D	7325 945225	VYACHESLAV KARPOV	{"phone": "+70404821798"}
0005432869530	FE3EB4	3915 113485	TAMARA ANISIMOVA	{"email": "anisimova.t071966@postgrespro.ru", "phone": "+70981089741"}
0005432869531	A360CE	2124 058513	MARIYA SEMENOVA	{"phone": "+70576768487"}
0005432869532	B5E13D	2164 178575	SERAFIMA ARKHIPOVA	{"phone": "+70959125342"}
0005432869533	497143	1903 241783	SVETLANA ISAEVA	{"email": "isaevasvetlana.1975@postgrespro.ru", "phone": "+70644580907"}
0005432869534	497143	1698 069841	VERA DANILOVA	{"phone": "+70153513448"}
0005432869535	497143	2056 057193	VIKTOR SERGEEV	{"phone": "+70597813708"}
0005432869536	46968F	7548 986213	LYUDMILA IVANOVA	{"phone": "+70842652521"}
0005432869537	4B0C5C	8308 841397	OLGA DAVYDOVA	{"phone": "+70670092655"}
0005432869538	4B0C5C	4793 107762	TAMARA BORISOVA	{"email": "borisova.t16041976@postgrespro.ru", "phone": "+70908853715"}
0005432869539	A0E4F8	7383 481634	VALENTINA DENISOVA	{"phone": "+70024673716"}
0005432869540	A0E4F8	1844 748094	ALFIYA IVANOVA	{"email": "ivanovaalfiya_011974@postgrespro.ru", "phone": "+70404473731"}
0005432869541	6F0B7D	0952 793858	LYUDMILA BELOVA	{"email": "belova-lyudmila.10101962@postgrespro.ru", "phone": "+70425399332"}
0005432869542	3137B0	0951 635529	ANASTASIYA MIKHAYLOVA	{"email": "anastasiyamikhaylova1973@postgrespro.ru", "phone": "+70458057578"}
0005432869543	CC732C	1012 321369	VASILIY SERGEEV	{"email": "vasiliy-sergeev_1970@postgrespro.ru", "phone": "+70226960421"}
0005432869544	CC732C	4073 687027	EDUARD NIKITIN	{"phone": "+70595225399"}
0005432869545	148FD9	4024 534210	ANDREY ZHURAVLEV	{"email": "zhuravlev.a19051971@postgrespro.ru", "phone": "+70972476913"}
0005432869546	E22F9B	5862 958776	ZOYA YAKOVLEVA	{"phone": "+70350486299"}
0005432869547	D7EE9D	4927 806913	ALEKSANDRA AFANASEVA	{"email": "aleksandra-afanaseva.22071971@postgrespro.ru", "phone": "+70849428125"}
0005432869548	BD08B5	6092 122473	ARMEN MOROZOV	{"email": "morozova071971@postgrespro.ru", "phone": "+70967743307"}
0005432869549	BD08B5	5457 527099	ALINA MOROZOVA	{"phone": "+70026246841"}
0005432869550	39AFB4	5079 097249	GALINA MIRONOVA	{"email": "galinamironova.05111974@postgrespro.ru", "phone": "+70385891370"}
0005432869551	39AFB4	5519 446023	DMITRIY BORISOV	{"email": "d.borisov-1973@postgrespro.ru", "phone": "+70364030896"}
0005432869552	6A6887	3910 275839	IRINA SEMENOVA	{"email": "isemenova12121972@postgrespro.ru", "phone": "+70760594834"}
0005432869553	70CE11	0406 326484	NINA SOROKINA	{"phone": "+70790160649"}
0005432869554	242ED0	5621 107819	ANNA MAKAROVA	{"email": "makarova-a-19071978@postgrespro.ru", "phone": "+70307924749"}
0005432869555	242ED0	5699 255814	OLESYA ABRAMOVA	{"phone": "+70869211282"}
0005432869556	CE0CDF	8599 851799	VIKTORIYA KONOVALOVA	{"phone": "+70707208392"}
0005432869557	56BD07	7643 427379	LIDIYA ZHUKOVA	{"email": "lidiyazhukova_051976@postgrespro.ru", "phone": "+70599344180"}
0005432869558	56BD07	4606 642816	DENIS ANTONOV	{"phone": "+70244243433"}
0005432869559	4211FA	3605 619577	SVETLANA BARANOVA	{"phone": "+70584449260"}
0005432869560	3A60AC	4598 759294	ANATOLIY FROLOV	{"email": "anatoliy_frolov-1977@postgrespro.ru", "phone": "+70406028148"}
0005432869561	3A60AC	4867 113230	ELENA KUDRYASHOVA	{"email": "kudryashova-elena_09091968@postgrespro.ru", "phone": "+70767589637"}
0005432869562	A9B425	6692 630282	MAKSIM SCHERBAKOV	{"phone": "+70177529332"}
0005432869563	A9B425	7694 803040	DMITRIY GUSEV	{"phone": "+70660766500"}
0005432869564	19F516	1314 702642	GENNADIY ALEKSANDROV	{"phone": "+70381116995"}
0005432869565	19F516	0357 380785	ELENA TIKHONOVA	{"phone": "+70865431326"}
0005432869566	C16AD1	0123 380815	NATALYA ZOTOVA	{"phone": "+70817958952"}
0005432869567	C16AD1	1434 648906	YURIY DENISOV	{"email": "denisov_y1963@postgrespro.ru", "phone": "+70886170733"}
0005432869568	E4242F	2183 367911	TATYANA MAKAROVA	{"phone": "+70356648772"}
0005432869569	2DF999	6235 581129	MARINA MELNIKOVA	{"phone": "+70817420117"}
0005432869570	2DF999	3703 508957	ALEKSANDRA ZAYCEVA	{"email": "aleksandrazayceva.041969@postgrespro.ru", "phone": "+70875677143"}
0005432869571	6B3434	9523 993377	EKATERINA ALEKSEEVA	{"email": "alekseeva_e_1974@postgrespro.ru", "phone": "+70427359995"}
0005432869572	E18FA3	6036 846066	ALEKSEY TIMOFEEV	{"phone": "+70475782963"}
0005432869573	B80DE2	8707 010282	EKATERINA GUSEVA	{"email": "ekaterina_guseva1964@postgrespro.ru", "phone": "+70397354690"}
0005432869574	B80DE2	5764 381496	MIKHAIL MAKAROV	{"email": "makarovmikhail_18121973@postgrespro.ru", "phone": "+70343461464"}
0005432869575	3A4044	0763 628180	NATALYA FOMINA	{"phone": "+70752065254"}
0005432869576	3A4044	6722 415233	ANASTASIYA GUSEVA	{"email": "anastasiya.guseva21121985@postgrespro.ru", "phone": "+70831753369"}
0005432869577	5337A1	3715 492747	NINA YAKOVLEVA	{"email": "yakovleva.nina.22101967@postgrespro.ru", "phone": "+70121721343"}
0005432869578	5337A1	8372 237791	EKATERINA GORBUNOVA	{"phone": "+70601747386"}
0005432869579	9583FF	4844 640668	VLADIMIR MARTYNOV	{"email": "martynovv_13091969@postgrespro.ru", "phone": "+70128677337"}
0005432869580	CEF273	2303 242660	LYUDMILA FROLOVA	{"phone": "+70829743803"}
0005432869581	CEF273	4181 050178	VADIM SMIRNOV	{"email": "smirnov.vadim_13061968@postgrespro.ru", "phone": "+70039697420"}
0005432869582	A12892	1158 894441	YURIY SOROKIN	{"email": "yuriysorokin.051972@postgrespro.ru", "phone": "+70659823410"}
0005432869583	EA9778	5748 133676	ELENA SOKOLOVA	{"phone": "+70719325291"}
0005432869584	4EC770	6097 965215	ALEKSEY SHEVCHENKO	{"phone": "+70465389479"}
0005432869585	4EC770	9986 765696	VALERIYA POPOVA	{"email": "popova_valeriya_051984@postgrespro.ru", "phone": "+70806193553"}
0005432869586	EAAFC4	7204 770838	VIKTOR ILIN	{"phone": "+70070313255"}
0005432869587	EAAFC4	2809 569779	NINA BARANOVA	{"phone": "+70470635679"}
0005432869588	EAAFC4	9467 100451	NIKITA SHEVCHENKO	{"email": "nikita.shevchenko_041982@postgrespro.ru", "phone": "+70506818937"}
0005432869589	15326F	1958 195554	NINA KUZNECOVA	{"email": "kuznecova.n.16041980@postgrespro.ru", "phone": "+70913274125"}
0005432869590	537B84	7685 710138	SERGEY BARANOV	{"phone": "+70763476646"}
0005432869591	3CF9FA	4841 402860	TATYANA ORLOVA	{"phone": "+70227004784"}
0005432869592	2FFF0F	1878 154923	GALINA YAKOVLEVA	{"phone": "+70290368554"}
0005432869593	2FFF0F	3931 451276	DANIL MOISEEV	{"email": "dmoiseev08051972@postgrespro.ru", "phone": "+70688136268"}
0005432869594	D462D0	8694 300017	YURIY NOVIKOV	{"email": "y_novikov-031979@postgrespro.ru", "phone": "+70809228067"}
0005432869595	34C4AE	8666 385528	ALEKSANDR SCHERBAKOV	{"phone": "+70995930877"}
0005432869596	CEA76F	2948 608557	SOFYA NAUMOVA	{"phone": "+70960833204"}
0005432869597	CEA76F	3074 648317	SVETLANA KUZMINA	{"email": "kuzminasvetlana_27101972@postgrespro.ru", "phone": "+70040987705"}
0005432869598	50CE3A	6065 539308	MARIYA KONOVALOVA	{"email": "konovalova.mariya_1970@postgrespro.ru", "phone": "+70519842945"}
0005432869599	EF115C	7065 553623	NIKITA NIKITIN	{"email": "nikitin_nikita_27031977@postgrespro.ru", "phone": "+70242496559"}
0005432869600	EF115C	3575 590799	ILYA DAVYDOV	{"phone": "+70987103799"}
0005432869601	DF5D39	2883 404957	ANDREY DMITRIEV	{"email": "dmitriev.a_10121971@postgrespro.ru", "phone": "+70873077273"}
0005432869602	DF5D39	8122 028172	VIKTOR TIMOFEEV	{"phone": "+70422518101"}
0005432869603	DF5D39	9485 169175	LYUDMILA SOKOLOVA	{"phone": "+70419748920"}
0005432869604	2A9F22	0989 141220	DMITRIY NAZAROV	{"email": "nazarov-dmitriy.1966@postgrespro.ru", "phone": "+70385275443"}
0005432869605	636CB2	5812 182300	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev.071975@postgrespro.ru", "phone": "+70021418104"}
0005432869606	636CB2	6349 352982	STANISLAV ZHUKOV	{"email": "szhukov_101975@postgrespro.ru", "phone": "+70254777141"}
0005432869607	097F23	1183 464388	VERA IVANOVA	{"email": "ivanovavera1971@postgrespro.ru", "phone": "+70883231730"}
0005432869608	097F23	2607 000376	IRINA VOLKOVA	{"email": "irina_volkova_19051969@postgrespro.ru", "phone": "+70369228604"}
0005432869609	097F23	6577 757157	ILNUR FILIPPOV	{"email": "ilnur.filippov1969@postgrespro.ru", "phone": "+70639037466"}
0005432869610	718434	7172 754514	STEPAN EGOROV	{"email": "egorovs1971@postgrespro.ru", "phone": "+70494223030"}
0005432869611	718434	5562 955662	VIKTOR STEPANOV	{"email": "viktor_stepanov_011965@postgrespro.ru", "phone": "+70291314158"}
0005432869612	0BBE56	4313 642253	VYACHESLAV SMIRNOV	{"phone": "+70210188293"}
0005432869613	9FCA99	1735 702634	DARYA VLASOVA	{"email": "darya-vlasova.12091961@postgrespro.ru", "phone": "+70772140074"}
0005432869614	9FCA99	3864 043526	ANNA KUZNECOVA	{"email": "anna_kuznecova.081985@postgrespro.ru", "phone": "+70405422664"}
0005432869615	9FCA99	8821 147036	PAVEL BORISOV	{"email": "pborisov051976@postgrespro.ru", "phone": "+70970613871"}
0005432869616	F69377	2172 484387	TATYANA NIKITINA	{"email": "tatyana-nikitina1968@postgrespro.ru", "phone": "+70093754856"}
0005432869617	F69377	6688 345970	VIKTOR NIKITIN	{"email": "nikitin-v-101984@postgrespro.ru", "phone": "+70464902679"}
0005432869618	708982	9832 534631	IVAN NIKITIN	{"email": "ivan_nikitin071970@postgrespro.ru", "phone": "+70315121821"}
0005432869619	6DAC4A	9243 167853	EKATERINA ZAYCEVA	{"email": "zaycevae.041988@postgrespro.ru", "phone": "+70531700023"}
0005432869620	6DAC4A	4705 769214	SVETLANA KUZNECOVA	{"phone": "+70776683569"}
0005432869621	AB4526	7406 714209	VERA SOLOVEVA	{"email": "vsoloveva.1972@postgrespro.ru", "phone": "+70133297442"}
0005432869622	775608	4821 388370	SVETLANA KUZMINA	{"phone": "+70726547089"}
0005432869623	6A1207	5143 487293	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr_1968@postgrespro.ru", "phone": "+70249748878"}
0005432869624	6A1207	4064 493942	GALINA ROMANOVA	{"email": "galina.romanova.20081970@postgrespro.ru", "phone": "+70786443508"}
0005432869625	6A1207	8234 266709	NADEZHDA FOMINA	{"phone": "+70159509089"}
0005432869626	4CC464	4514 830308	VITALIY VASILEV	{"phone": "+70145672984"}
0005432869627	D07A2D	4844 049228	MIKHAIL MAKSIMOV	{"phone": "+70822128550"}
0005432869628	D07A2D	6530 607009	ALEKSANDR TARASOV	{"phone": "+70817324622"}
0005432869629	1E1F98	9055 267025	VYACHESLAV FILIPPOV	{"phone": "+70814423943"}
0005432869630	1E1F98	0357 291976	DANIIL ZAKHAROV	{"email": "daniilzakharov_1974@postgrespro.ru", "phone": "+70809247733"}
0005432869631	720470	8468 263806	ARTEM ANDREEV	{"phone": "+70299884642"}
0005432869632	E6A226	7092 512859	LEONID TIKHONOV	{"phone": "+70003480304"}
0005432869633	E6A226	4771 554160	LYUDMILA ALEKSEEVA	{"phone": "+70340281916"}
0005432869634	628449	3771 070228	VALENTINA GUSEVA	{"phone": "+70220473716"}
0005432869635	4F1BC0	6940 446292	ANASTASIYA SAVELEVA	{"email": "saveleva-a-26011980@postgrespro.ru", "phone": "+70733993795"}
0005432869636	4F1BC0	6305 377725	ANDREY OSIPOV	{"email": "a.osipov-1964@postgrespro.ru", "phone": "+70339583927"}
0005432869637	C44888	1412 241290	VLADIMIR IVANOV	{"email": "ivanov-v.23111974@postgrespro.ru", "phone": "+70267085129"}
0005432869638	CA4000	4859 323878	IRINA NAZAROVA	{"phone": "+70690116161"}
0005432869639	696128	2828 974319	OLGA IVANOVA	{"phone": "+70152192073"}
0005432869640	AFC302	6154 628219	IRINA FADEEVA	{"email": "fadeeva_irina-1982@postgrespro.ru", "phone": "+70264511788"}
0005432869641	F24B0F	2305 937051	NIKOLAY OSIPOV	{"phone": "+70957198178"}
0005432869642	7CFCF5	9192 567540	YURIY SOROKIN	{"email": "y.sorokin-081977@postgrespro.ru", "phone": "+70081891841"}
0005432869643	7CFCF5	9992 286279	TATYANA KOROLEVA	{"email": "tkoroleva.06031976@postgrespro.ru", "phone": "+70879158117"}
0005432869644	3FB897	1051 475161	ANNA BELOVA	{"email": "belova_anna-1971@postgrespro.ru", "phone": "+70624473201"}
0005432869645	3FB897	6768 107834	EVGENIY SEMENOV	{"email": "evgeniy-semenov.1983@postgrespro.ru", "phone": "+70104263938"}
0005432869646	7EF1E4	3626 514810	DMITRIY POPOV	{"email": "dpopov.101975@postgrespro.ru", "phone": "+70402484899"}
0005432869647	992601	1098 069005	ALEKSANDR KUZMIN	{"phone": "+70390092469"}
0005432869648	4A1DA6	8755 278757	VALERIY GAVRILOV	{"email": "v-gavrilov_1974@postgrespro.ru", "phone": "+70362395940"}
0005432869649	4A1DA6	4023 149952	NINA ANTONOVA	{"phone": "+70461029536"}
0005432869650	4A1DA6	1342 158284	EVGENIY ALEKSANDROV	{"email": "evgeniyaleksandrov_1978@postgrespro.ru", "phone": "+70184726994"}
0005432869651	01177B	5814 226384	ELENA KARPOVA	{"email": "ekarpova.19061973@postgrespro.ru", "phone": "+70895108101"}
0005432869652	9F4F5D	4852 738837	EVGENIYA AFANASEVA	{"phone": "+70893192515"}
0005432869653	862A74	1519 370735	NADEZHDA CHERNOVA	{"email": "nadezhda_chernova.071973@postgrespro.ru", "phone": "+70149517048"}
0005432869654	D23A2B	2147 564596	TATYANA YAKOVLEVA	{"phone": "+70556812555"}
0005432869655	E45EBC	7657 440247	ANNA NOVIKOVA	{"phone": "+70480855039"}
0005432869656	E45EBC	9952 811154	RAISA GUSEVA	{"email": "rguseva1968@postgrespro.ru", "phone": "+70191065146"}
0005432869657	741E49	3074 026190	ANZHELA KUZNECOVA	{"email": "kuznecovaa.12111972@postgrespro.ru", "phone": "+70972117205"}
0005432869658	2001B3	1375 719404	ANNA KALININA	{"email": "a-kalinina.121972@postgrespro.ru", "phone": "+70727155257"}
0005432869659	CF07C7	6352 887053	NIKOLAY YAKOVLEV	{"email": "nikolay_yakovlev.1981@postgrespro.ru", "phone": "+70576361862"}
0005432869660	826E07	4616 509858	NINA SMIRNOVA	{"email": "n_smirnova_1980@postgrespro.ru", "phone": "+70371858338"}
0005432869661	153DE2	7495 505170	ALINA PAVLOVA	{"email": "alinapavlova_1964@postgrespro.ru", "phone": "+70847702118"}
0005432869662	153DE2	2993 367119	TAMARA KOZLOVA	{"email": "tamara-kozlova_1972@postgrespro.ru", "phone": "+70467378918"}
0005432869663	50B70D	0048 266146	SERGEY GRIGOREV	{"email": "grigorevsergey_17091969@postgrespro.ru", "phone": "+70516945210"}
0005432869664	CA1322	9875 413186	TATYANA RODIONOVA	{"email": "trodionova101977@postgrespro.ru", "phone": "+70114342724"}
0005432869665	CA1322	0013 202595	ANDREY KRASNOV	{"phone": "+70190758772"}
0005432869666	466173	7562 405338	INNA VOLKOVA	{"email": "volkova_i-03051972@postgrespro.ru", "phone": "+70087793082"}
0005432869667	466173	9856 279065	VASILIY YAKOVLEV	{"phone": "+70972345960"}
0005432869668	971564	5643 757361	ANATOLIY CHERNOV	{"email": "anatoliy_chernov_1980@postgrespro.ru", "phone": "+70975771471"}
0005432869669	2199DB	7899 737609	VIKTOR ABRAMOV	{"email": "viktorabramov081967@postgrespro.ru", "phone": "+70229229034"}
0005432869670	7106EF	2442 315014	EKATERINA STEPANOVA	{"email": "stepanovae-04071970@postgrespro.ru", "phone": "+70754707928"}
0005432869671	7106EF	9862 093891	NATALYA ARKHIPOVA	{"phone": "+70309947979"}
0005432869672	7106EF	7758 700590	GALINA TARASOVA	{"email": "tarasovag_011975@postgrespro.ru", "phone": "+70434708398"}
0005432869673	22D3E6	1036 214210	ANASTASIYA SIDOROVA	{"email": "anastasiya_sidorova.051970@postgrespro.ru", "phone": "+70176691678"}
0005432869674	A8023E	4142 210357	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy-18021981@postgrespro.ru", "phone": "+70430443580"}
0005432869675	A8023E	2987 444239	ANDREY KOZLOV	{"email": "kozlov-andrey-1975@postgrespro.ru", "phone": "+70007560893"}
0005432869676	1F583C	8012 471888	ANTONIDA IVANOVA	{"phone": "+70132136614"}
0005432869677	0FB1BB	4765 910623	ROMAN PETROV	{"phone": "+70137418979"}
0005432869678	0FB1BB	9533 035151	KRISTINA POLYAKOVA	{"phone": "+70803851783"}
0005432869679	0FB1BB	5387 955758	SVETLANA AFANASEVA	{"phone": "+70158302934"}
0005432869680	76680E	1638 068318	PAVEL YAKOVLEV	{"phone": "+70594085859"}
0005432869681	87659D	8282 602112	DANIIL NAZAROV	{"email": "nazarov_d_1975@postgrespro.ru", "phone": "+70649105878"}
0005432869682	2F391C	9248 358740	VALERIYA NIKITINA	{"email": "v.nikitina071966@postgrespro.ru", "phone": "+70658320940"}
0005432869683	2F391C	4363 591009	LYUBOV NAZAROVA	{"email": "l_nazarova081981@postgrespro.ru", "phone": "+70760158416"}
0005432869684	2F391C	1632 897613	LIDIYA ABRAMOVA	{"phone": "+70979699335"}
0005432869685	54D644	1772 617693	NATALYA SMIRNOVA	{"email": "natalya_smirnova.1986@postgrespro.ru", "phone": "+70296315394"}
0005432869686	54D644	8652 686147	MAKSIM MOROZOV	{"email": "morozov_m.29041974@postgrespro.ru", "phone": "+70783218281"}
0005432869687	F52638	5767 705445	SERGEY SERGEEV	{"phone": "+70562257388"}
0005432869688	F52638	7549 501194	TAMARA VOROBEVA	{"phone": "+70683190230"}
0005432869689	5E5A61	9064 572882	IGOR IVANOV	{"email": "igor_ivanov_10061960@postgrespro.ru", "phone": "+70644614105"}
0005432869690	5E5A61	9534 228332	STANISLAV ANDREEV	{"email": "andreev-stanislav_13021978@postgrespro.ru", "phone": "+70063056004"}
0005432869691	E83A02	3331 586966	ANDREY MAKAROV	{"phone": "+70682140765"}
0005432869692	C2478D	6551 104455	ALEKSEY FROLOV	{"phone": "+70232039012"}
0005432869693	D8129B	3151 101274	OLEG OSIPOV	{"email": "oleg-osipov.1977@postgrespro.ru", "phone": "+70196727037"}
0005432869694	D8129B	8812 838608	ANNA BORISOVA	{"phone": "+70252464666"}
0005432869695	F5C997	3492 040895	ELIZAVETA NESTEROVA	{"phone": "+70435522729"}
0005432869696	BAC29F	0156 640015	MARAT FILIPPOV	{"email": "filippov-m.121965@postgrespro.ru", "phone": "+70327958770"}
0005432869697	6FCA13	8915 657802	ALEKSANDR PAVLOV	{"phone": "+70524445666"}
0005432869698	6FCA13	3686 615055	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova_a-1965@postgrespro.ru", "phone": "+70051675838"}
0005432869699	F693A7	6977 345583	MARIYA KUZMINA	{"email": "mariya_kuzmina_1989@postgrespro.ru", "phone": "+70756535637"}
0005432869700	F693A7	0614 121615	SERGEY PETROV	{"email": "petrov_sergey.071970@postgrespro.ru", "phone": "+70758647486"}
0005432869701	E70442	8431 947661	ANATOLIY FOMIN	{"email": "anatoliyfomin041973@postgrespro.ru", "phone": "+70241605129"}
0005432869702	E70442	7703 306866	ANNA PETROVA	{"email": "petrova.anna_101967@postgrespro.ru", "phone": "+70242738970"}
0005432869703	21EF81	9654 119996	LYUDMILA ANTONOVA	{"phone": "+70749685322"}
0005432869704	E37605	8163 193352	ILYA ALEKSEEV	{"email": "ilya.alekseev-051976@postgrespro.ru", "phone": "+70424370137"}
0005432869705	C5EC4A	0580 102188	VLADIMIR SOROKIN	{"email": "vsorokin-14021969@postgrespro.ru", "phone": "+70864807359"}
0005432869706	C5EC4A	9922 347622	ALEKSANDR NOVIKOV	{"email": "aleksandrnovikov.11011974@postgrespro.ru", "phone": "+70533541626"}
0005432869707	E1CA58	6152 760005	ELENA KUDRYASHOVA	{"phone": "+70707527468"}
0005432869708	E1CA58	2053 658262	DMITRIY VASILEV	{"email": "vasilev-d.121964@postgrespro.ru", "phone": "+70660440876"}
0005432869709	F49146	8621 058312	LEONID IVANOV	{"email": "ivanov.leonid1977@postgrespro.ru", "phone": "+70922864597"}
0005432869710	EF14C5	8742 689322	ALEKSANDR ZHUKOV	{"phone": "+70499618128"}
0005432869711	146637	4131 008617	VALERIYA AFANASEVA	{"email": "v-afanaseva-30061977@postgrespro.ru", "phone": "+70036866218"}
0005432869712	75F4D2	4114 969243	NIKOLAY SOROKIN	{"email": "nikolay.sorokin081988@postgrespro.ru", "phone": "+70125968856"}
0005432869713	90957E	8288 121106	RENATA LUKYANOVA	{"email": "renata_lukyanova-22091967@postgrespro.ru", "phone": "+70700405201"}
0005432869714	90957E	7016 859808	MAKSIM RODIONOV	{"phone": "+70444890530"}
0005432869715	AB40D2	8103 470528	SERGEY KOZLOV	{"phone": "+70086669299"}
0005432869716	AB40D2	1203 681102	VLADIMIR MAKSIMOV	{"phone": "+70762208482"}
0005432869717	3AEE0E	9372 585782	ANDREY NAZAROV	{"email": "andrey_nazarov.1977@postgrespro.ru", "phone": "+70880228093"}
0005432869718	3AEE0E	0575 751809	OLGA VASILEVA	{"email": "olga.vasileva.18061979@postgrespro.ru", "phone": "+70038146259"}
0005432869719	AA778E	7037 666229	ELENA NIKITINA	{"phone": "+70728094200"}
0005432869720	937738	7930 335796	OLGA VOROBEVA	{"phone": "+70969054104"}
0005432869721	965B93	6403 995149	ALEKSEY ZHURAVLEV	{"phone": "+70170868175"}
0005432869722	965B93	8758 055445	RUSLAN SCHERBAKOV	{"email": "scherbakov-r041972@postgrespro.ru", "phone": "+70358443251"}
0005432869723	AF4103	2160 750447	VALENTINA ZAKHAROVA	{"email": "zakharovav1965@postgrespro.ru", "phone": "+70164221092"}
0005432869724	AF4103	7778 007048	NINA KUZNECOVA	{"phone": "+70138253521"}
0005432869725	6FE18E	3198 419271	SERGEY PAVLOV	{"email": "pavlov-sergey.10051973@postgrespro.ru", "phone": "+70018175318"}
0005432869726	E0545C	5217 255363	YULIYA BORISOVA	{"email": "borisova-yuliya-051985@postgrespro.ru", "phone": "+70191828906"}
0005432873165	6B954B	3021 529104	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-a-31101968@postgrespro.ru", "phone": "+70020715485"}
0005432873166	6B954B	4139 769795	SERGEY STEPANOV	{"phone": "+70762725558"}
0005432873167	3A6CD9	1535 516734	MARINA EFIMOVA	{"email": "m-efimova_13021978@postgrespro.ru", "phone": "+70213601095"}
0005432873168	3A6CD9	5739 861832	DMITRIY IVANOV	{"email": "d-ivanov.1975@postgrespro.ru", "phone": "+70020193183"}
0005432873169	B3F63D	7419 740749	PAVEL TARASOV	{"phone": "+70585028361"}
0005432873170	595E9A	4956 768509	MIKHAIL ALEKSANDROV	{"email": "mikhail_aleksandrov_05121985@postgrespro.ru", "phone": "+70210643876"}
0005432873171	3C810A	9743 182935	IRINA POPOVA	{"email": "popova_irina_091969@postgrespro.ru", "phone": "+70677461820"}
0005432873172	418E67	2457 394308	IGOR FOMIN	{"email": "ifomin1969@postgrespro.ru", "phone": "+70895430785"}
0005432873173	418E67	5437 148721	NELLI SEMENOVA	{"email": "semenova_nelli.121977@postgrespro.ru", "phone": "+70177089184"}
0005432873174	F562A8	5396 759598	TATYANA IVANOVA	{"email": "ivanova-t.1968@postgrespro.ru", "phone": "+70518946196"}
0005432873175	BF5486	4436 724899	YULIYA MOROZOVA	{"phone": "+70185595202"}
0005432873176	BF5486	0910 148633	TATYANA KAZAKOVA	{"email": "kazakova-tatyana.121972@postgrespro.ru", "phone": "+70811702486"}
0005432873177	530AFE	0496 868938	LYUBOV STEPANOVA	{"phone": "+70137284885"}
0005432873178	530AFE	6455 356303	IGOR STEPANOV	{"phone": "+70935306122"}
0005432873179	355F69	1623 579955	TATYANA BELOVA	{"email": "tatyana.belova_23071963@postgrespro.ru", "phone": "+70150427795"}
0005432873180	1A2B36	3873 286706	DMITRIY ALEKSANDROV	{"phone": "+70652439284"}
0005432873181	5C6A57	0280 934329	IRINA ZAYCEVA	{"phone": "+70434966936"}
0005432873182	5C6A57	3413 834480	ALEKSEY SMIRNOV	{"phone": "+70913664031"}
0005432873183	3CB673	2981 105998	BORIS SCHERBAKOV	{"email": "scherbakov-b-03071967@postgrespro.ru", "phone": "+70717501806"}
0005432873184	E59405	1583 089165	NATALYA KRASNOVA	{"phone": "+70413191346"}
0005432873185	DE6684	8839 541341	TATYANA KOZLOVA	{"email": "kozlova_t_031962@postgrespro.ru", "phone": "+70486066175"}
0005432873186	9DF801	6440 365678	ANATOLIY KOZLOV	{"email": "kozlovanatoliy.08121971@postgrespro.ru", "phone": "+70047140817"}
0005432873187	13B5A4	3294 972165	ALINA FROLOVA	{"email": "frolova-alina_26031965@postgrespro.ru", "phone": "+70086186836"}
0005432873188	904B0B	7677 627666	LYUBOV RYABOVA	{"email": "lyubovryabova-021978@postgrespro.ru", "phone": "+70983901728"}
0005432873189	A48747	9247 752155	ALEKSEY KRASNOV	{"phone": "+70428008421"}
0005432873190	69963E	1513 866035	INNA MIRONOVA	{"email": "i-mironova-041969@postgrespro.ru", "phone": "+70657828704"}
0005432873191	F785E2	5370 821875	NATALYA KOROLEVA	{"email": "korolevan-01011966@postgrespro.ru", "phone": "+70122268733"}
0005432873192	167001	4151 851710	ALEKSANDR NOVIKOV	{"phone": "+70710476899"}
0005432873193	167001	4686 840191	VALENTINA SERGEEVA	{"phone": "+70479241358"}
0005432873194	72B695	9880 109334	DMITRIY AFANASEV	{"email": "afanasev-dmitriy-031972@postgrespro.ru", "phone": "+70113752943"}
0005432873195	72B695	7525 374712	SVETLANA KOMAROVA	{"email": "komarova_s_1966@postgrespro.ru", "phone": "+70729350153"}
0005432873196	FCA561	8125 437738	OLGA BORISOVA	{"phone": "+70548384233"}
0005432873197	9C5AD9	2948 302083	VALENTINA SIDOROVA	{"phone": "+70951917215"}
0005432873198	FB5F0C	2428 501745	RINAT DMITRIEV	{"phone": "+70247344585"}
0005432873199	061BCE	8205 563536	TATYANA IVANOVA	{"email": "tatyana.ivanova_12061976@postgrespro.ru", "phone": "+70755045988"}
0005432873200	1CECC1	1029 878381	LYUDMILA KISELEVA	{"email": "l_kiseleva-101959@postgrespro.ru", "phone": "+70638021846"}
0005432873201	CBEBCB	8114 223743	OKSANA POPOVA	{"email": "popovaoksana091983@postgrespro.ru", "phone": "+70067378625"}
0005432873202	D92349	3229 721958	KARINA YAKOVLEVA	{"phone": "+70616861257"}
0005432873203	D92349	2489 960162	RIMMA MAKAROVA	{"phone": "+70844803671"}
0005432873204	F8DB45	1807 753388	TATYANA RODIONOVA	{"email": "rodionova_tatyana.021974@postgrespro.ru", "phone": "+70154182128"}
0005432873205	92F391	9941 093540	EKATERINA KUZMINA	{"phone": "+70861070249"}
0005432873206	04A4B9	2876 162718	VALERIY KRASNOV	{"phone": "+70918252050"}
0005432873207	A4C4FA	1684 825140	VERA KOMAROVA	{"email": "komarova_v.1963@postgrespro.ru", "phone": "+70839151078"}
0005432873208	A4C4FA	9437 853264	VALERIYA CHERNOVA	{"email": "valeriyachernova111974@postgrespro.ru", "phone": "+70540094881"}
0005432873209	4415B3	0495 093353	ALEKSEY OSIPOV	{"email": "aleksey-osipov_1974@postgrespro.ru", "phone": "+70559049002"}
0005432873210	1AF887	3152 762794	NADEZHDA KARPOVA	{"phone": "+70015829339"}
0005432873211	1AF887	6917 284665	NIKOLAY KUDRYASHOV	{"phone": "+70883742876"}
0005432873212	80399D	8697 688649	MARIYA LUKYANOVA	{"phone": "+70647657787"}
0005432873213	B0D4D2	2055 732068	ANDREY NAZAROV	{"email": "andrey-nazarov_1985@postgrespro.ru", "phone": "+70309000186"}
0005432873214	B0D4D2	3267 025066	ANDREY ANDREEV	{"email": "andreev.andrey.11021970@postgrespro.ru", "phone": "+70886191159"}
0005432873215	814BC8	9924 142848	TATYANA BELYAEVA	{"email": "t_belyaeva.1979@postgrespro.ru", "phone": "+70932556665"}
0005432873216	5971CD	0997 077221	ELENA OVCHINNIKOVA	{"phone": "+70802362241"}
0005432873217	DE8C6C	4964 476049	TATYANA MELNIKOVA	{"phone": "+70220785585"}
0005432873218	8FD1F3	4722 236285	VITALIY ZAKHAROV	{"phone": "+70642568004"}
0005432873219	AF67CD	3136 904113	VALENTINA ZHURAVLEVA	{"phone": "+70578356487"}
0005432873220	E07FEC	4472 950329	DMITRIY MIRONOV	{"email": "mironovdmitriy_28091958@postgrespro.ru", "phone": "+70458346563"}
0005432873221	E07FEC	5331 839106	DIANA ZOTOVA	{"phone": "+70497425734"}
0005432873222	059EF0	7011 039122	INNA GAVRILOVA	{"email": "gavrilova.inna.081971@postgrespro.ru", "phone": "+70144303271"}
0005432873223	C580A6	6549 240758	OLGA CHERNOVA	{"email": "o_chernova_1962@postgrespro.ru", "phone": "+70139167745"}
0005432873224	35FE7B	3735 101663	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov-1974@postgrespro.ru", "phone": "+70056900230"}
0005432873225	35FE7B	1061 363821	MARIYA MARTYNOVA	{"email": "m_martynova-02011976@postgrespro.ru", "phone": "+70707108264"}
0005432873226	3EF9AE	1279 535352	ALEKSANDR DENISOV	{"phone": "+70169528291"}
0005432873227	3EF9AE	0532 244179	NIKITA CHERNOV	{"email": "chernov-nikita_07111959@postgrespro.ru", "phone": "+70053416330"}
0005432873228	7D8116	8021 558840	BORIS STEPANOV	{"email": "b_stepanov_021980@postgrespro.ru", "phone": "+70605389996"}
0005432873229	7EDB61	7502 247217	ILYA SOROKIN	{"email": "sorokin_ilya_12081977@postgrespro.ru", "phone": "+70192496128"}
0005432873230	33525E	0457 932838	PAVEL SOKOLOV	{"phone": "+70260926281"}
0005432873231	5E9890	4034 126910	LIDIYA MOISEEVA	{"email": "lmoiseeva-051963@postgrespro.ru", "phone": "+70621628626"}
0005432873232	CAAF7A	4477 304323	DANIIL SERGEEV	{"email": "sergeev_d031973@postgrespro.ru", "phone": "+70577557854"}
0005432873233	CAAF7A	4862 469685	ILYA KAZAKOV	{"phone": "+70116012057"}
0005432873234	43E0CE	4503 884101	OLEG TIKHONOV	{"phone": "+70312928980"}
0005432873235	3405AA	2468 247885	DARYA ZHUKOVA	{"email": "zhukovadarya.111964@postgrespro.ru", "phone": "+70743913745"}
0005432873236	28A2AC	2491 834682	VERA PETROVA	{"phone": "+70482128058"}
0005432873237	C0F304	7436 012495	ANASTASIYA MIRONOVA	{"phone": "+70745871475"}
0005432873238	94E51B	9793 254745	STANISLAV SHEVCHENKO	{"phone": "+70817943477"}
0005432873239	89AD0D	6611 326884	VYACHESLAV ZAKHAROV	{"email": "vyacheslav.zakharov-021983@postgrespro.ru", "phone": "+70795542611"}
0005432873240	89AD0D	8263 205886	VALENTINA EFREMOVA	{"phone": "+70419046428"}
0005432873241	6ADBC1	6314 081062	VLADIMIR IVANOV	{"email": "vladimir-ivanov.26091959@postgrespro.ru", "phone": "+70753149398"}
0005432873242	6ADBC1	9238 472235	MIKHAIL SIDOROV	{"phone": "+70564519260"}
0005432873243	AD9E20	3071 689975	EVGENIYA KOLESNIKOVA	{"phone": "+70736438751"}
0005432873244	AD9E20	3473 050897	ALEKSANDR ZAYCEV	{"phone": "+70134865184"}
0005432873245	A20AF9	9629 134092	YURIY SIDOROV	{"phone": "+70210327303"}
0005432873246	9F48B3	0959 331710	DMITRIY NAZAROV	{"email": "dmitriy_nazarov111968@postgrespro.ru", "phone": "+70023331234"}
0005432873247	720CCA	4686 203962	MARINA KULIKOVA	{"phone": "+70509962493"}
0005432873248	720CCA	8121 860287	TATYANA DENISOVA	{"email": "denisova.tatyana.1977@postgrespro.ru", "phone": "+70991838414"}
0005432873249	441CC0	4316 348039	DMITRIY ALEKSANDROV	{"phone": "+70346002828"}
0005432873250	441CC0	8909 408295	NINA MAKAROVA	{"phone": "+70220205359"}
0005432873251	9C0133	4506 317934	GALINA MATVEEVA	{"phone": "+70458526514"}
0005432873252	E234BC	6638 224094	IRINA EGOROVA	{"phone": "+70365988161"}
0005432873253	B7EB73	7749 715579	ARTEM NIKOLAEV	{"email": "a.nikolaev-1977@postgrespro.ru", "phone": "+70824721524"}
0005432873254	71D057	8784 655748	SERGEY CHERNOV	{"phone": "+70638922790"}
0005432873255	681BF4	5319 617822	YULIYA RODIONOVA	{"email": "rodionova.yuliya1976@postgrespro.ru", "phone": "+70683385429"}
0005432873256	E50F21	5353 683185	BULAT DAVYDOV	{"email": "davydov_b17051969@postgrespro.ru", "phone": "+70723950890"}
0005432873257	E50F21	1248 899660	ARTEM SOROKIN	{"email": "asorokin1967@postgrespro.ru", "phone": "+70317802738"}
0005432873258	9A2A75	7611 532812	VLADISLAV ALEKSANDROV	{"email": "vladislav-aleksandrov.021973@postgrespro.ru", "phone": "+70307062814"}
0005432873259	9A2A75	0779 780128	EVGENIYA ORLOVA	{"phone": "+70655052151"}
0005432873260	AD0BEC	4231 168644	ALEKSANDRA OVCHINNIKOVA	{"phone": "+70250700787"}
0005432873261	D38D9A	6593 283249	DENIS KUDRYASHOV	{"email": "kudryashov_denis_071971@postgrespro.ru", "phone": "+70663403769"}
0005432873262	D38D9A	9167 964987	NATALYA CHERNOVA	{"phone": "+70609608575"}
0005432873263	A14BD0	1760 871372	LYUDMILA POPOVA	{"phone": "+70864920298"}
0005432873264	A14BD0	6501 635976	ELENA YAKOVLEVA	{"email": "yakovleva-elena13031966@postgrespro.ru", "phone": "+70943483618"}
0005432873265	7384AB	3275 018474	YANA POPOVA	{"email": "ypopova-11051978@postgrespro.ru", "phone": "+70624011449"}
0005432873266	7384AB	6223 276568	VLADIMIR IVANOV	{"phone": "+70184530233"}
0005432873267	2D1D74	1405 740679	ALEKSANDR SOLOVEV	{"phone": "+70822909149"}
0005432873268	47B85B	7269 574745	YURIY KRASNOV	{"email": "krasnov_y_111973@postgrespro.ru", "phone": "+70819255149"}
0005432873269	47B85B	1482 910244	ELIZAVETA IVANOVA	{"email": "ivanova-elizaveta_02061972@postgrespro.ru", "phone": "+70006306069"}
0005432873270	47B85B	2867 581444	NIKOLAY MIRONOV	{"phone": "+70854814602"}
0005432873271	4E8656	1050 405497	ANDREY KUZNECOV	{"email": "andrey_kuznecov-101977@postgrespro.ru", "phone": "+70436990231"}
0005432873272	4E8656	4599 311858	OLGA SEMENOVA	{"email": "semenovaolga051974@postgrespro.ru", "phone": "+70953767895"}
0005432873273	4E8656	6416 904455	SVETLANA ZHURAVLEVA	{"email": "szhuravleva24061973@postgrespro.ru", "phone": "+70198214264"}
0005432873274	B12818	2799 318056	NIKOLAY IVANOV	{"email": "n-ivanov1967@postgrespro.ru", "phone": "+70081404416"}
0005432873275	A0165E	0584 115039	DMITRIY MAKAROV	{"email": "dmitriy.makarov29121971@postgrespro.ru", "phone": "+70591693186"}
0005432873276	A0165E	5054 409788	OLGA KRASNOVA	{"email": "o-krasnova_1965@postgrespro.ru", "phone": "+70428432103"}
0005432873277	232E9D	9277 568020	ALEKSEY SCHERBAKOV	{"phone": "+70557220414"}
0005432873278	232E9D	9602 561804	ZINAIDA NIKOLAEVA	{"email": "z-nikolaeva081980@postgrespro.ru", "phone": "+70329314447"}
0005432873279	974771	1796 074289	TATYANA ANISIMOVA	{"email": "anisimova.tatyana-1966@postgrespro.ru", "phone": "+70525937496"}
0005432873280	974771	7368 523813	ALEKSEY PAVLOV	{"email": "alekseypavlov101989@postgrespro.ru", "phone": "+70560079419"}
0005432873281	2C8C4F	6720 286228	TATYANA EFIMOVA	{"phone": "+70105011774"}
0005432873282	0B448E	1939 144317	ANATOLIY SOROKIN	{"email": "a-sorokin.1976@postgrespro.ru", "phone": "+70331417838"}
0005432873283	0B448E	2595 715148	ALEKSANDR GUSEV	{"phone": "+70639610648"}
0005432873284	0B448E	9328 930043	ELENA BELOVA	{"email": "elena-belova.1979@postgrespro.ru", "phone": "+70425765834"}
0005432873285	2842AF	9648 229779	VALENTIN MOROZOV	{"email": "morozovvalentin-041967@postgrespro.ru", "phone": "+70510707031"}
0005432873286	2842AF	6069 473766	TATYANA BELOVA	{"email": "belovatatyana.23051976@postgrespro.ru", "phone": "+70348653308"}
0005432873287	8F66D3	7301 992534	INNA SERGEEVA	{"email": "sergeevainna-111972@postgrespro.ru", "phone": "+70025976731"}
0005432873288	30E76E	5493 518611	OLGA NIKITINA	{"email": "nikitina-olga-101984@postgrespro.ru", "phone": "+70912126351"}
0005432873289	35228D	2265 241150	ALEKSEY FROLOV	{"phone": "+70517333680"}
0005432873290	35228D	2045 603311	EKATERINA OSIPOVA	{"email": "osipova.ekaterina_1972@postgrespro.ru", "phone": "+70229414897"}
0005432873291	744674	7985 092716	ILYA GAVRILOV	{"email": "gavrilovi_1960@postgrespro.ru", "phone": "+70245726704"}
0005432873292	744674	1476 629574	ROMAN GERASIMOV	{"email": "r_gerasimov16041985@postgrespro.ru", "phone": "+70424056027"}
0005432873293	633EED	8304 712823	EGOR ANDREEV	{"email": "egor-andreev_1958@postgrespro.ru", "phone": "+70439194113"}
0005432873294	633EED	2882 058295	ALEKSANDR BORISOV	{"email": "borisov_a_1972@postgrespro.ru", "phone": "+70040621954"}
0005432873295	BEA802	6646 017492	VALERIY KUZNECOV	{"phone": "+70672043337"}
0005432873296	C95477	6410 809916	SERGEY ANDREEV	{"phone": "+70154951198"}
0005432873297	B2EE75	6667 324555	ALEKSEY POPOV	{"email": "popov-aleksey04051965@postgrespro.ru", "phone": "+70187006021"}
0005432873298	083C77	7548 095138	YURIY ANDREEV	{"phone": "+70178792182"}
0005432873299	083C77	1544 372977	LILIYA MASLOVA	{"email": "lmaslova_1972@postgrespro.ru", "phone": "+70778256162"}
0005432873300	1CC4D4	7907 716995	YURIY KARPOV	{"email": "karpovyuriy-28071981@postgrespro.ru", "phone": "+70172986537"}
0005432873301	FA9A85	7116 446828	GALINA MAKAROVA	{"email": "galina.makarova.1977@postgrespro.ru", "phone": "+70293943099"}
0005432873302	67C706	8701 116667	KARINA CHERNOVA	{"email": "chernovakarina20091974@postgrespro.ru", "phone": "+70322289557"}
0005432873303	67C706	7435 287893	MARAT TIKHONOV	{"email": "m.tikhonov_1981@postgrespro.ru", "phone": "+70573585867"}
0005432873304	788E3B	3237 580698	NATALYA AKIMOVA	{"phone": "+70711231428"}
0005432873305	788E3B	2912 500623	VALENTIN SERGEEV	{"phone": "+70819403426"}
0005432873306	0B549B	7310 948320	ELIZAVETA MAKAROVA	{"email": "makarova.elizaveta-1974@postgrespro.ru", "phone": "+70904817743"}
0005432873307	0B549B	4756 379717	LYUDMILA NESTEROVA	{"email": "lnesterova.21021972@postgrespro.ru", "phone": "+70875135886"}
0005432873308	B6A5C4	9011 764421	EVGENIY ZHURAVLEV	{"email": "ezhuravlev_1967@postgrespro.ru", "phone": "+70675621575"}
0005432873309	D79605	5140 219451	ANDREY KUDRYASHOV	{"email": "kudryashovandrey.04011965@postgrespro.ru", "phone": "+70744611420"}
0005432873310	F594F8	2887 459056	MAKSIM ZAYCEV	{"email": "m-zaycev.041978@postgrespro.ru", "phone": "+70072587207"}
0005432873311	563C2A	4826 889080	IGOR FOMIN	{"email": "fomin-igor.07081969@postgrespro.ru", "phone": "+70966507259"}
0005432873312	563C2A	1131 699512	MARINA ALEKSANDROVA	{"phone": "+70913637377"}
0005432873313	563C2A	2283 134947	DENIS PETROV	{"phone": "+70193530147"}
0005432873314	09DE3D	8580 523457	ELENA IVANOVA	{"email": "elena_ivanova-16121972@postgrespro.ru", "phone": "+70804977188"}
0005432873315	1C6E30	4576 184121	IRINA BARANOVA	{"phone": "+70304325884"}
0005432873316	1C6E30	7224 865235	YURIY ZAKHAROV	{"email": "yuriyzakharov_1975@postgrespro.ru", "phone": "+70877975824"}
0005432873317	1C6E30	5625 546371	NIKOLAY ABRAMOV	{"email": "nikolay.abramov_1975@postgrespro.ru", "phone": "+70249556804"}
0005432873318	68E837	3075 991695	NADEZHDA TARASOVA	{"phone": "+70263135158"}
0005432873319	DEFF1F	4214 732693	OLGA ANDREEVA	{"phone": "+70465079108"}
0005432873320	DEFF1F	2786 178383	TATYANA MASLOVA	{"email": "tmaslova-1979@postgrespro.ru", "phone": "+70140297816"}
0005432873321	B0936D	0754 472835	DMITRIY SOLOVEV	{"email": "solovev_dmitriy_30071969@postgrespro.ru", "phone": "+70095407470"}
0005432873322	A5A93B	6537 302437	ALEKSANDR FEDOROV	{"email": "fedorov-a30081962@postgrespro.ru", "phone": "+70021133659"}
0005432873323	2B79AA	1441 673326	ALEKSEY NIKITIN	{"phone": "+70597808376"}
0005432873324	2B79AA	4078 827306	NINA VOLKOVA	{"email": "nina.volkova1974@postgrespro.ru", "phone": "+70861196841"}
0005432873325	E7B4A2	8942 116681	ILYA GERASIMOV	{"phone": "+70517578512"}
0005432873326	B6AEB9	2618 311681	ELENA SEMENOVA	{"email": "semenovaelena_03121972@postgrespro.ru", "phone": "+70541200868"}
0005432873327	B6AEB9	5596 029541	NATALYA TIMOFEEVA	{"email": "n_timofeeva091976@postgrespro.ru", "phone": "+70485794982"}
0005432873328	B6AEB9	3855 988745	ALEKSANDR ABRAMOV	{"phone": "+70724609100"}
0005432873329	5D7014	5026 680608	KSENIYA ZAKHAROVA	{"phone": "+70248365102"}
0005432873330	50307C	7339 542708	ANTONINA MARTYNOVA	{"email": "antonina-martynova.22081982@postgrespro.ru", "phone": "+70009855371"}
0005432873331	50307C	3996 079930	DMITRIY TIMOFEEV	{"phone": "+70580020708"}
0005432873332	9F57A1	1656 894766	VALENTINA TROFIMOVA	{"email": "valentina-trofimova.021980@postgrespro.ru", "phone": "+70663980150"}
0005432873333	DDDEE7	8385 048111	VITALIY EGOROV	{"phone": "+70234819420"}
0005432873334	A91126	2438 043452	VYACHESLAV SOROKIN	{"phone": "+70033121768"}
0005432873335	A91126	6564 218806	DENIS SERGEEV	{"email": "sergeevd-1967@postgrespro.ru", "phone": "+70778598463"}
0005432873336	5ED440	3560 416894	ANVAR SCHERBAKOV	{"email": "scherbakov-a.24051979@postgrespro.ru", "phone": "+70917302078"}
0005432873337	D812C3	5104 529368	ANDREY GORBUNOV	{"email": "a_gorbunov.1961@postgrespro.ru", "phone": "+70422443717"}
0005432873338	B1A824	0614 049144	VLADIMIR FILIPPOV	{"email": "filippov_vladimir101977@postgrespro.ru", "phone": "+70696574493"}
0005432873339	B1A824	5486 883288	ELIZAVETA TITOVA	{"phone": "+70496827257"}
0005432873340	E83B47	0517 877211	OLESYA MATVEEVA	{"email": "matveevao.061968@postgrespro.ru", "phone": "+70547477412"}
0005432873341	DEA047	1551 333848	LYUDMILA SIDOROVA	{"email": "l_sidorova_1974@postgrespro.ru", "phone": "+70074508812"}
0005432873342	AF8239	0037 280575	SERGEY KONOVALOV	{"email": "skonovalov1961@postgrespro.ru", "phone": "+70223715089"}
0005432873343	8EAA81	1630 003572	YULIYA KUZMINA	{"phone": "+70844507116"}
0005432873344	8EAA81	0434 254409	LEONID POPOV	{"email": "popovleonid.04091972@postgrespro.ru", "phone": "+70336885482"}
0005432873345	437F5A	8241 818847	IGOR SMIRNOV	{"email": "i_smirnov1985@postgrespro.ru", "phone": "+70522789211"}
0005432873346	437F5A	2660 793339	VIKTOR ROMANOV	{"phone": "+70748341827"}
0005432873347	E2A46F	1438 089239	NIKOLAY DMITRIEV	{"email": "n-dmitriev.051971@postgrespro.ru", "phone": "+70338002009"}
0005432873348	15B6E4	3715 621985	ALENA MAKAROVA	{"phone": "+70770362792"}
0005432873349	47F8E5	2580 032754	ANTONINA KOLESNIKOVA	{"phone": "+70469953404"}
0005432873350	47F8E5	0737 984262	NATALYA FILIPPOVA	{"phone": "+70586242037"}
0005432873351	46A3BD	2224 718716	GALINA NESTEROVA	{"phone": "+70343841561"}
0005432873352	862A39	6265 539425	EVGENIY MIKHAYLOV	{"phone": "+70878011851"}
0005432873353	ACBD7C	5684 152051	NINA ZAYCEVA	{"email": "nzayceva.111968@postgrespro.ru", "phone": "+70875264241"}
0005432873354	ACBD7C	9055 229831	LEV KOZLOV	{"phone": "+70344144611"}
0005432873355	E54CA7	6483 467408	VADIM STEPANOV	{"phone": "+70211209654"}
0005432873356	14F964	1102 781386	NATALYA ANTONOVA	{"email": "antonova.n-03081975@postgrespro.ru", "phone": "+70134043178"}
0005432873357	FB6C0E	5093 082159	ANTONINA VOROBEVA	{"email": "antoninavorobeva.121963@postgrespro.ru", "phone": "+70439790993"}
0005432873358	FFA426	2205 362072	VIKTOR DENISOV	{"email": "denisov.v-011984@postgrespro.ru", "phone": "+70166127066"}
0005432873359	FFA426	3733 535757	NATALYA VLASOVA	{"phone": "+70343232961"}
0005432873360	DE57CA	9988 317099	NINA EGOROVA	{"phone": "+70709007759"}
0005432873361	123D16	9636 177344	ELENA KRASNOVA	{"phone": "+70034753679"}
0005432873362	123D16	5885 615479	DAMIR CHERNOV	{"email": "damir_chernov_051965@postgrespro.ru", "phone": "+70419967436"}
0005432873363	7C9282	7746 273006	DMITRIY VASILEV	{"phone": "+70837917116"}
0005432873364	C1D126	1681 427380	NATALIYA MASLOVA	{"email": "maslova-nataliya.08011976@postgrespro.ru", "phone": "+70548757208"}
0005432873365	C1D126	8676 639992	SVETLANA VOROBEVA	{"email": "vorobevasvetlana-011977@postgrespro.ru", "phone": "+70802024774"}
0005432873366	8E9BF3	7697 213921	MIKHAIL PETROV	{"email": "petrov.m_1967@postgrespro.ru", "phone": "+70040053876"}
0005432873367	8E9BF3	5623 255681	ALESYA KOROLEVA	{"email": "alesya-koroleva_30081965@postgrespro.ru", "phone": "+70388216876"}
0005432873368	5E8AC3	9599 859109	IRINA KUZNECOVA	{"email": "i.kuznecova07101975@postgrespro.ru", "phone": "+70087280795"}
0005432873369	5E8AC3	2554 748081	ALEKSANDR DENISOV	{"phone": "+70183102568"}
0005432873370	07EA30	6792 187667	NIKOLAY FOMIN	{"phone": "+70993514932"}
0005432873371	07EA30	6838 512722	ANDREY VLASOV	{"email": "vlasov-a_1974@postgrespro.ru", "phone": "+70709864138"}
0005432873372	8203BE	7463 763394	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov.02091982@postgrespro.ru", "phone": "+70224778898"}
0005432873373	8203BE	4998 483803	MAKSIM IVANOV	{"phone": "+70820403952"}
0005432873374	198A74	1725 299348	YULIYA KUZNECOVA	{"phone": "+70829803109"}
0005432873375	198A74	4442 515809	ALEKSEY KUZNECOV	{"phone": "+70276350040"}
0005432873376	8998C3	6640 128439	SVETLANA NESTEROVA	{"email": "svetlana.nesterova-071968@postgrespro.ru", "phone": "+70252144408"}
0005432873377	D9E767	8362 416887	LYUDMILA KULIKOVA	{"email": "kulikova.lyudmila_23051967@postgrespro.ru", "phone": "+70754786228"}
0005432873378	D9E767	8599 402311	SERGEY STEPANOV	{"phone": "+70731250323"}
0005432873379	C1B452	3429 404321	ALEKSANDR EGOROV	{"phone": "+70000018093"}
0005432873380	45E242	2032 067214	TATYANA IVANOVA	{"email": "ivanova-t-1970@postgrespro.ru", "phone": "+70867970424"}
0005432873381	45E242	0736 289377	ALEKSEY STEPANOV	{"phone": "+70386284070"}
0005432873382	647A25	9377 537087	GENNADIY KUZMIN	{"phone": "+70360382760"}
0005432873383	242006	0544 457049	TAMARA ISAEVA	{"phone": "+70096151937"}
0005432873384	242006	8997 006802	OLEG NIKITIN	{"email": "nikitino_091967@postgrespro.ru", "phone": "+70404111824"}
0005432873385	796E0C	9056 374501	ANDREY SEMENOV	{"email": "semenovandrey-1975@postgrespro.ru", "phone": "+70903971946"}
0005432873386	B17F7F	6777 658144	POLINA ZHUKOVA	{"email": "polina_zhukova.1972@postgrespro.ru", "phone": "+70755551633"}
0005432873387	B17F7F	9717 238332	NIKOLAY ROMANOV	{"email": "n_romanov-101975@postgrespro.ru", "phone": "+70335487743"}
0005432873388	C71558	0212 527096	YURIY MELNIKOV	{"email": "melnikovy-10041978@postgrespro.ru", "phone": "+70842227537"}
0005432873389	97CCC1	0816 505216	ALBERT ZAYCEV	{"email": "zaycev-albert.13031970@postgrespro.ru", "phone": "+70533724153"}
0005432873390	97CCC1	4995 132592	ANASTASIYA POPOVA	{"phone": "+70642806738"}
0005432873391	2A3D8B	7569 084370	ANNA NIKITINA	{"phone": "+70578964194"}
0005432873392	4BB47A	7823 486530	ANTON KAZAKOV	{"email": "a.kazakov_091969@postgrespro.ru", "phone": "+70228706304"}
0005432873393	0948AA	4877 510188	VALENTINA SAVELEVA	{"phone": "+70462246421"}
0005432873394	0948AA	4171 689008	ALEKSANDR MATVEEV	{"email": "a-matveev11091975@postgrespro.ru", "phone": "+70156818071"}
0005432873395	2C61D9	9167 620478	NIKITA ZAKHAROV	{"phone": "+70249336182"}
0005432873396	AE2618	6844 292353	VLADIMIR MIKHAYLOV	{"email": "vladimir.mikhaylov-021973@postgrespro.ru", "phone": "+70649129931"}
0005432873397	4C3B0B	8288 436592	EVDOKIYA SOKOLOVA	{"email": "sokolova-e_27071970@postgrespro.ru", "phone": "+70438231431"}
0005432873398	4C3B0B	4944 664524	ANNA ZAYCEVA	{"email": "azayceva.15101969@postgrespro.ru", "phone": "+70981822073"}
0005432873399	0322E0	0850 271416	STANISLAV KONOVALOV	{"phone": "+70445342049"}
0005432873400	F9276C	2471 906369	TATYANA KUZMINA	{"phone": "+70323352543"}
0005432873401	F9276C	5704 300530	ALEKSANDR ANDREEV	{"phone": "+70508230923"}
0005432873402	F9276C	8583 476422	ZAKHAR MIKHAYLOV	{"phone": "+70501141931"}
0005432873403	ACC7A3	4123 263308	TAMARA EFIMOVA	{"email": "t_efimova_25021972@postgrespro.ru", "phone": "+70016007488"}
0005432873404	ACC7A3	6548 266984	VIKTORIYA TARASOVA	{"phone": "+70299737276"}
0005432873405	E3A010	1582 452836	LYUBOV MAKAROVA	{"email": "lyubov_makarova_12101976@postgrespro.ru", "phone": "+70376488413"}
0005432873406	0D82A2	0165 020785	ANTONINA NIKOLAEVA	{"email": "a.nikolaeva.03111975@postgrespro.ru", "phone": "+70516373397"}
0005432873407	AEC172	0501 769005	ELENA SOKOLOVA	{"email": "elenasokolova_1973@postgrespro.ru", "phone": "+70100582841"}
0005432873408	AEC172	0742 015036	ELIZAVETA FADEEVA	{"email": "fadeevaelizaveta_1970@postgrespro.ru", "phone": "+70331061160"}
0005432873409	9F5F91	5058 725699	BORIS ANDREEV	{"email": "andreev.boris.1980@postgrespro.ru", "phone": "+70901474905"}
0005432873410	95D96D	0521 642644	ANTONINA NIKIFOROVA	{"email": "nikiforovaantonina_031977@postgrespro.ru", "phone": "+70332922237"}
0005432873411	95D96D	6161 228099	NIKOLAY ANTONOV	{"phone": "+70417288103"}
0005432873412	EC7D10	6464 413706	ILYA YAKOVLEV	{"phone": "+70374253982"}
0005432873413	EC7D10	0058 170146	MARINA ZAKHAROVA	{"email": "zakharova-marina_15041970@postgrespro.ru", "phone": "+70387470191"}
0005432873414	97B815	2743 233653	ALEKSANDR ALEKSANDROV	{"email": "aaleksandrov.04061978@postgrespro.ru", "phone": "+70806389104"}
0005432873415	97B815	9009 204914	TATYANA FROLOVA	{"phone": "+70939585931"}
0005432873416	5BD52B	7569 218778	ANZHELIKA SEMENOVA	{"phone": "+70135574717"}
0005432873417	DA2D4F	6547 295152	IVAN SAVELEV	{"email": "savelev-i1983@postgrespro.ru", "phone": "+70478405787"}
0005432873418	DA2D4F	9944 392407	SVETLANA PAVLOVA	{"email": "pavlovas-1972@postgrespro.ru", "phone": "+70194774434"}
0005432873419	BD295B	1960 091371	ELMIRA KOROLEVA	{"phone": "+70435170790"}
0005432873420	62F887	5379 837244	MARIYA EGOROVA	{"email": "egorova_mariya.041980@postgrespro.ru", "phone": "+70979131516"}
0005432873421	62F887	4629 623753	VALERIYA ERMAKOVA	{"email": "valeriya_ermakova_101984@postgrespro.ru", "phone": "+70104706911"}
0005432873422	33851B	3099 271413	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova_25011982@postgrespro.ru", "phone": "+70169740959"}
0005432873423	B2B722	9471 188341	GALINA AFANASEVA	{"email": "galina-afanaseva-14121981@postgrespro.ru", "phone": "+70520765442"}
0005432873424	3046BF	7281 797686	VLADIMIR BELOV	{"phone": "+70800738117"}
0005432873425	8A8C95	6943 966518	VYACHESLAV CHERNOV	{"email": "v_chernov.101971@postgrespro.ru", "phone": "+70918918266"}
0005432873426	227D1F	6851 695278	ILMIRA GUSEVA	{"email": "ilmira-guseva_1971@postgrespro.ru", "phone": "+70863019851"}
0005432873427	CE4ECE	2170 072161	DANIIL GAVRILOV	{"email": "gavrilovdaniil.12091977@postgrespro.ru", "phone": "+70567999643"}
0005432873428	96AD54	4013 245549	VIKTOR MOROZOV	{"phone": "+70172069467"}
0005432873429	96AD54	0752 264075	VIKTORIYA MOROZOVA	{"email": "vmorozova_14091974@postgrespro.ru", "phone": "+70588340776"}
0005432873430	DC4909	4747 301710	OLEG FROLOV	{"email": "frolov-o.14031971@postgrespro.ru", "phone": "+70424701239"}
0005432873431	DC4909	6197 466799	SERGEY KAZAKOV	{"phone": "+70529277927"}
0005432873432	76C1C4	1036 674415	MAKSIM SEMENOV	{"phone": "+70049107343"}
0005432873433	76C1C4	9120 844767	ANDREY ILIN	{"email": "ilinandrey-1960@postgrespro.ru", "phone": "+70117646345"}
0005432873434	8D6BC6	2923 787367	TIMUR BARANOV	{"phone": "+70995050664"}
0005432873435	8D6BC6	2992 985425	DANIIL ANDREEV	{"phone": "+70657406845"}
0005432873436	411F5B	8898 007444	IRINA FILIPPOVA	{"email": "filippovairina.1965@postgrespro.ru", "phone": "+70384696739"}
0005432873437	411F5B	6344 964447	KSENIYA ABRAMOVA	{"email": "abramova.kseniya.061978@postgrespro.ru", "phone": "+70979223761"}
0005432873438	185086	3639 647474	DMITRIY ANTONOV	{"email": "dmitriy.antonov-1964@postgrespro.ru", "phone": "+70558210267"}
0005432873439	96F3D3	7444 949880	VERA YUDINA	{"phone": "+70080838576"}
0005432873440	FF633C	2091 147670	MAKSIM BORISOV	{"email": "borisov.maksim_1967@postgrespro.ru", "phone": "+70327685221"}
0005432873441	1F5B20	6432 297273	TATYANA PETROVA	{"email": "petrova.t_1987@postgrespro.ru", "phone": "+70340334717"}
0005432873442	721890	6579 016029	NATALYA KUZMINA	{"phone": "+70129548284"}
0005432873443	A8D821	6744 511853	TATYANA NIKOLAEVA	{"email": "nikolaeva.tatyana.031984@postgrespro.ru", "phone": "+70256378990"}
0005432873444	A8D821	0693 892132	EVGENIY SOKOLOV	{"phone": "+70621772920"}
0005432873445	A8D821	4146 793643	ANASTASIYA KOLESNIKOVA	{"email": "akolesnikova.1955@postgrespro.ru", "phone": "+70152368309"}
0005432873446	88E269	9388 018936	VLADIMIR MAKAROV	{"phone": "+70129385478"}
0005432873447	88E269	4869 032637	ANTON KARPOV	{"phone": "+70873241821"}
0005432873448	FC5833	1596 656870	GALINA KONOVALOVA	{"email": "galina_konovalova_081973@postgrespro.ru", "phone": "+70651195858"}
0005432873449	F4C50A	8885 861184	YURIY ANDREEV	{"phone": "+70783102678"}
0005432873450	5CE2F1	7068 034477	SVETLANA OVCHINNIKOVA	{"phone": "+70669662351"}
0005432873451	99A3BF	9023 802166	IRINA ORLOVA	{"phone": "+70158473644"}
0005432873452	0ECC58	1793 543158	ANATOLIY MAKAROV	{"email": "a-makarov-051969@postgrespro.ru", "phone": "+70651767443"}
0005432873453	0ECC58	4625 313591	ZINAIDA ZHUKOVA	{"email": "z-zhukova-051976@postgrespro.ru", "phone": "+70039912589"}
0005432873454	0ECC58	8603 707036	OLEG KUZMIN	{"phone": "+70529831407"}
0005432873455	FD4AE9	8742 145550	TAMARA MIKHAYLOVA	{"email": "t.mikhaylova.051988@postgrespro.ru", "phone": "+70737422409"}
0005432873456	FD4AE9	4293 736804	LIDIYA PETROVA	{"phone": "+70750045308"}
0005432873457	6DFE92	7179 421605	TIMOFEY VASILEV	{"email": "vasilev.timofey.081974@postgrespro.ru", "phone": "+70277898464"}
0005432873458	127171	1749 210306	ALENA PAVLOVA	{"email": "pavlovaalena-1968@postgrespro.ru", "phone": "+70305791894"}
0005432873459	16391A	6451 541124	SERGEY VASILEV	{"email": "vasilev.sergey_05091977@postgrespro.ru", "phone": "+70821541161"}
0005432873460	16391A	5007 204670	ALEKSEY MAKAROV	{"phone": "+70139055866"}
0005432873461	8A213F	6204 145331	GALINA EFIMOVA	{"phone": "+70562581374"}
0005432873462	657D7E	9425 829167	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr30101964@postgrespro.ru", "phone": "+70605867021"}
0005432873463	66D053	4881 923935	ALEKSEY GRIGOREV	{"phone": "+70504771938"}
0005432873464	5AD781	9628 485764	EVGENIYA FEDOROVA	{"phone": "+70942101462"}
0005432873465	3707D2	5524 688228	VIKTOR KUZNECOV	{"email": "kuznecov.viktor_071975@postgrespro.ru", "phone": "+70820991721"}
0005432873466	5FE1D1	2157 092894	VITALIY VOLKOV	{"phone": "+70747965135"}
0005432873467	1C6655	8053 985699	GALINA IVANOVA	{"email": "g.ivanova_101965@postgrespro.ru", "phone": "+70885402240"}
0005432873468	8F4D05	5273 814580	VIKTOR KOZLOV	{"email": "vkozlov.1964@postgrespro.ru", "phone": "+70012216960"}
0005432873469	E13C50	3481 074496	EKATERINA SEMENOVA	{"phone": "+70263767072"}
0005432873470	2F60A4	6478 738998	SERGEY SIDOROV	{"email": "sidorov_s_1967@postgrespro.ru", "phone": "+70945535350"}
0005432873471	2F60A4	4287 652462	MARTA SOLOVEVA	{"email": "msoloveva-21061975@postgrespro.ru", "phone": "+70361136589"}
0005432873472	29AAF3	4313 731389	ARTEM PETROV	{"phone": "+70081946475"}
0005432873473	D40D10	6984 633045	VLADIMIR BONDARENKO	{"email": "bondarenko_vladimir.071971@postgrespro.ru", "phone": "+70264713394"}
0005432873474	D40D10	2143 131714	VLADISLAV FOMIN	{"phone": "+70565165273"}
0005432873475	D40D10	1087 580230	VIKTOR KUZNECOV	{"email": "kuznecov-v_1976@postgrespro.ru", "phone": "+70880079350"}
0005432873476	FCD02F	8370 694324	VERA ZHURAVLEVA	{"phone": "+70124961918"}
0005432873477	FCD02F	8557 555501	TATYANA ABRAMOVA	{"email": "abramovat.121973@postgrespro.ru", "phone": "+70609033944"}
0005432873478	FCD02F	8863 919173	ALEKSEY ROMANOV	{"email": "alekseyromanov.16111961@postgrespro.ru", "phone": "+70681643896"}
0005432873479	DE0573	0894 209869	GALINA NESTEROVA	{"phone": "+70352458709"}
0005432873480	1D7A5A	5734 178985	DARYA BORISOVA	{"email": "daryaborisova_1969@postgrespro.ru", "phone": "+70354712926"}
0005432873481	537E3B	7163 344333	ANDREY CHERNOV	{"email": "chernova_03061971@postgrespro.ru", "phone": "+70328393597"}
0005432873482	615D82	6012 259599	ALEKSANDR ZHURAVLEV	{"phone": "+70683478566"}
0005432873483	615D82	8846 716693	SOFYA FILIPPOVA	{"phone": "+70177052583"}
0005432873484	A8F3B8	0818 339170	VERONIKA VOROBEVA	{"email": "veronika-vorobeva.18111962@postgrespro.ru", "phone": "+70619812931"}
0005432873485	A8F3B8	4400 040425	VYACHESLAV SHEVCHENKO	{"phone": "+70670116020"}
0005432873486	BF4F73	0738 506207	RAISA ANISIMOVA	{"email": "r.anisimova-1970@postgrespro.ru", "phone": "+70515367015"}
0005432873487	362D8E	2542 181864	KSENIYA NIKOLAEVA	{"email": "knikolaeva_071981@postgrespro.ru", "phone": "+70382967946"}
0005432873488	910D2F	1481 193849	TAISIYA ALEKSEEVA	{"phone": "+70126039887"}
0005432873489	F1F0BE	4922 779621	VLADIMIR MARTYNOV	{"phone": "+70722505674"}
0005432873490	F1F0BE	2098 920492	ANDREY TIKHONOV	{"email": "andrey_tikhonov1973@postgrespro.ru", "phone": "+70319602841"}
0005432873491	6167D2	5588 965218	TATYANA MAKSIMOVA	{"email": "tatyana-maksimova111959@postgrespro.ru", "phone": "+70375146923"}
0005432873492	5DCF63	9056 198131	ALEKSEY KUZNECOV	{"phone": "+70980357865"}
0005432873493	DDD27A	6876 459727	ALEKSANDR DENISOV	{"email": "aleksandr-denisov061974@postgrespro.ru", "phone": "+70197255720"}
0005432873494	DDD27A	8330 557805	DMITRIY EGOROV	{"phone": "+70655883919"}
0005432873495	5BE38B	8892 220363	LIDIYA KOLESNIKOVA	{"phone": "+70535133614"}
0005432873496	5BE38B	3047 103119	VLADIMIR SOLOVEV	{"phone": "+70613103301"}
0005432873497	956E78	2536 105053	MARINA STEPANOVA	{"email": "stepanova.marina09031972@postgrespro.ru", "phone": "+70279924771"}
0005432873498	89CC77	2395 510502	SERGEY PETROV	{"phone": "+70704419740"}
0005432873499	89CC77	2898 412031	ANDREY AFANASEV	{"email": "andreyafanasev.041972@postgrespro.ru", "phone": "+70932193492"}
0005432873500	3E0193	0515 625935	ALEKSANDR TARASOV	{"phone": "+70898805757"}
0005432873501	3E0193	0463 183821	IVAN BELOV	{"email": "i-belov1975@postgrespro.ru", "phone": "+70959552747"}
0005432873502	F6C33B	3894 270203	VLADIMIR CHERNOV	{"phone": "+70884611913"}
0005432873503	F6C33B	4405 149528	TAGIR KONOVALOV	{"phone": "+70311934071"}
0005432873504	69E2C8	7660 759855	ALEKSANDR MAKSIMOV	{"email": "a_maksimov111981@postgrespro.ru", "phone": "+70452128708"}
0005432880848	8165F2	8051 448288	ZAKHAR NAZAROV	{"phone": "+70193462734"}
0005432880551	2194AB	7785 129525	NIKOLAY MAKAROV	{"email": "makarovn20111981@postgrespro.ru", "phone": "+70388709216"}
0005432880552	2194AB	7748 068241	EVGENIY BELOV	{"phone": "+70760321841"}
0005432880553	54DB1D	6112 966403	ANASTASIYA SIDOROVA	{"email": "sidorova-anastasiya-061983@postgrespro.ru", "phone": "+70170514013"}
0005432880554	120B90	1534 868479	LARISA ZAYCEVA	{"email": "zayceva_larisa091981@postgrespro.ru", "phone": "+70220680326"}
0005432880555	6414C8	3470 981604	IGOR MAKSIMOV	{"email": "i_maksimov-15041971@postgrespro.ru", "phone": "+70374946452"}
0005432880556	2D3FC6	3534 259862	ALEKSEY GORBUNOV	{"email": "gorbunov-aleksey.1978@postgrespro.ru", "phone": "+70109126185"}
0005432880557	51F334	2850 756983	IVAN KRASNOV	{"email": "ivankrasnov_101975@postgrespro.ru", "phone": "+70297789381"}
0005432880558	CE0A7D	3744 254745	SERGEY BONDARENKO	{"email": "bondarenkosergey.31011967@postgrespro.ru", "phone": "+70472343478"}
0005432880559	CE0A7D	8399 310428	TIMOFEY SCHERBAKOV	{"phone": "+70023430236"}
0005432880560	5720F8	5544 108721	VITALIY NOVIKOV	{"email": "vitaliynovikov.10121979@postgrespro.ru", "phone": "+70548284033"}
0005432880561	99A7AD	4078 018524	ALEKSANDR KOZLOV	{"phone": "+70291446094"}
0005432880562	99A7AD	4170 308030	VYACHESLAV KAZAKOV	{"email": "v_kazakov.1971@postgrespro.ru", "phone": "+70630053896"}
0005432880563	99A7AD	1879 893017	VIKTOR PETROV	{"phone": "+70742949415"}
0005432880564	0DBF36	2541 485684	DARYA NOVIKOVA	{"email": "daryanovikova_06041969@postgrespro.ru", "phone": "+70486048243"}
0005432880565	0DBF36	3131 135972	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey-18101969@postgrespro.ru", "phone": "+70289202883"}
0005432880566	3B92F3	4543 735719	DMITRIY VASILEV	{"email": "vasilev_dmitriy.1989@postgrespro.ru", "phone": "+70480860924"}
0005432880567	860CD0	5745 340478	IRINA SERGEEVA	{"email": "sergeeva.i_23021972@postgrespro.ru", "phone": "+70029395430"}
0005432880568	CAD320	8166 440422	ANATOLIY ALEKSANDROV	{"email": "aleksandrova_03071969@postgrespro.ru", "phone": "+70868404894"}
0005432881126	4479C0	8033 357553	MARGARITA PETROVA	{"phone": "+70643004512"}
0005432880569	CCCA30	2964 490876	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a1969@postgrespro.ru", "phone": "+70419713508"}
0005432880570	3FEFF4	9933 859143	SERGEY NOVIKOV	{"email": "s-novikov_051977@postgrespro.ru", "phone": "+70546851176"}
0005432880571	A19F1C	9342 730278	VIKTOR NAZAROV	{"email": "v-nazarov_031982@postgrespro.ru", "phone": "+70748112878"}
0005432880572	AFC8A5	9141 587508	NINA KARPOVA	{"phone": "+70599922189"}
0005432880573	FB07DD	8972 644800	LYUBOV VASILEVA	{"phone": "+70869027534"}
0005432880574	295DAA	5781 313651	TAMARA FILATOVA	{"email": "filatova_t_061967@postgrespro.ru", "phone": "+70886598195"}
0005432880575	D7570D	7943 344321	LYUBOV ILINA	{"phone": "+70478433714"}
0005432880576	FA0C24	8569 872048	OLESYA ZAYCEVA	{"phone": "+70743434683"}
0005432880577	B2B2E1	3617 111432	VLADIMIR TARASOV	{"phone": "+70603430846"}
0005432880578	B2B2E1	9097 524683	MAKSIM SERGEEV	{"email": "sergeev_m-18021973@postgrespro.ru", "phone": "+70811467389"}
0005432880579	F3A607	8567 337918	EVGENIY ZHUKOV	{"email": "evgeniy_zhukov-28091975@postgrespro.ru", "phone": "+70950658465"}
0005432880580	F3A607	7665 197597	MAKSIM FEDOROV	{"phone": "+70281750018"}
0005432880581	07834C	6727 713471	ANDREY ALEKSANDROV	{"email": "aleksandrov.a.061968@postgrespro.ru", "phone": "+70218707477"}
0005432880582	07834C	4692 057926	ALEKSANDR GERASIMOV	{"phone": "+70332996013"}
0005432880583	07834C	8922 117133	SERGEY ALEKSEEV	{"email": "alekseev-sergey_1969@postgrespro.ru", "phone": "+70534659735"}
0005432880584	07834C	8039 102061	SVETLANA PETROVA	{"email": "petrova_s.31071973@postgrespro.ru", "phone": "+70904153320"}
0005432880585	6B7F1D	2551 016673	ALEKSEY VLASOV	{"email": "a.vlasov_1981@postgrespro.ru", "phone": "+70985901695"}
0005432880586	CA63A4	4600 693293	ALEKSEY MOISEEV	{"email": "aleksey_moiseev1976@postgrespro.ru", "phone": "+70886034536"}
0005432880587	5378D6	4624 557061	NINA VASILEVA	{"phone": "+70304348557"}
0005432880588	DF14D1	0986 591919	OKSANA ANDREEVA	{"email": "andreeva.o1973@postgrespro.ru", "phone": "+70598787744"}
0005432880589	DF14D1	0084 697257	ANTON ZAKHAROV	{"email": "anton_zakharov-20101972@postgrespro.ru", "phone": "+70531048109"}
0005432880590	DF14D1	4886 561132	SERGEY NIKITIN	{"phone": "+70464172691"}
0005432880591	63CC26	3146 956388	IRINA NAUMOVA	{"email": "naumovai27091963@postgrespro.ru", "phone": "+70126363647"}
0005432880592	63CC26	2320 169218	NADEZHDA KAZAKOVA	{"email": "n_kazakova1978@postgrespro.ru", "phone": "+70551190983"}
0005432880593	353D9D	4502 446147	PETR PAVLOV	{"email": "petrpavlov.1962@postgrespro.ru", "phone": "+70132773608"}
0005432880594	B72EA0	8948 459067	VITALIY KOZLOV	{"phone": "+70227925239"}
0005432880595	41A647	9158 332576	DMITRIY SEMENOV	{"email": "semenovdmitriy.25101976@postgrespro.ru", "phone": "+70344662145"}
0005432880596	4FB0FC	6406 431642	OLEG GORBUNOV	{"email": "gorbunov.oleg-101983@postgrespro.ru", "phone": "+70613753525"}
0005432880597	773663	8728 908901	TATYANA TIKHONOVA	{"email": "tikhonovatatyana.1985@postgrespro.ru", "phone": "+70993304750"}
0005432880598	FA5BDD	2316 546790	SERGEY VASILEV	{"email": "vasilev-sergey_061972@postgrespro.ru", "phone": "+70904318702"}
0005432880599	FA5BDD	9168 341293	OLGA ZAYCEVA	{"email": "zayceva.o.071981@postgrespro.ru", "phone": "+70468590265"}
0005432880600	7751D4	9892 841334	SERGEY NOVIKOV	{"email": "sergeynovikov_1968@postgrespro.ru", "phone": "+70607503694"}
0005432880601	57E03D	7398 029987	ANDREY PETROV	{"phone": "+70110650518"}
0005432880602	57E03D	0612 223385	ELENA GAVRILOVA	{"email": "e_gavrilova.18071972@postgrespro.ru", "phone": "+70461397228"}
0005432880603	57E03D	8504 805329	VERA ZAKHAROVA	{"email": "zakharovavera031968@postgrespro.ru", "phone": "+70278264360"}
0005432880604	197FFC	0330 936517	KIRILL PETROV	{"email": "petrovkirill_1976@postgrespro.ru", "phone": "+70876061123"}
0005432880605	197FFC	7768 323929	NINA IVANOVA	{"email": "n_ivanova-021971@postgrespro.ru", "phone": "+70903099063"}
0005432880606	13E32A	0138 278134	ANATOLIY ALEKSANDROV	{"email": "a-aleksandrov1959@postgrespro.ru", "phone": "+70444175632"}
0005432880607	22936E	1252 719091	DAMIR PAVLOV	{"phone": "+70949439163"}
0005432880608	5CC0A6	2602 628721	IRINA MASLOVA	{"phone": "+70781700284"}
0005432880609	9DA67D	2962 592422	MAKSIM KAZAKOV	{"email": "m_kazakov1984@postgrespro.ru", "phone": "+70409205579"}
0005432880610	9DA67D	6203 895481	ALEKSANDR GERASIMOV	{"email": "a-gerasimov_29091978@postgrespro.ru", "phone": "+70811155669"}
0005432880611	AED2E6	5484 039462	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova_1971@postgrespro.ru", "phone": "+70748977373"}
0005432880612	FAD003	0982 471066	NIKITA IVANOV	{"email": "n-ivanov-1964@postgrespro.ru", "phone": "+70850184340"}
0005432880613	FAD003	0764 254908	ALEKSANDR SOLOVEV	{"phone": "+70765408839"}
0005432880614	FAD003	1637 967915	SERGEY IVANOV	{"phone": "+70984927222"}
0005432880615	278CBB	8157 052345	STANISLAV IVANOV	{"phone": "+70966916647"}
0005432880616	9DB0F5	9503 004872	RINAT OSIPOV	{"email": "osipov_r-061968@postgrespro.ru", "phone": "+70928234628"}
0005432880617	9DB0F5	6632 193354	ANNA SOKOLOVA	{"phone": "+70376911706"}
0005432880618	9AE5B5	6267 967974	NADEZHDA MOISEEVA	{"email": "moiseeva_n_12031978@postgrespro.ru", "phone": "+70076295196"}
0005432880619	9AE5B5	8287 548908	KRISTINA GAVRILOVA	{"phone": "+70951739834"}
0005432880620	B36DF9	2720 113365	VYACHESLAV ZAKHAROV	{"email": "zakharov.v20041975@postgrespro.ru", "phone": "+70907860450"}
0005432880621	BC8494	3628 985659	MIKHAIL AFANASEV	{"email": "afanasev-mikhail-1983@postgrespro.ru", "phone": "+70667642108"}
0005432880622	E676DD	8527 290078	IGOR ANDREEV	{"phone": "+70425833272"}
0005432880623	5CBAC5	4758 867615	YULIYA ZAKHAROVA	{"email": "zakharova_yuliya.011976@postgrespro.ru", "phone": "+70171318692"}
0005432880624	5CBAC5	5252 309317	LIDIYA ROMANOVA	{"email": "romanova.lidiya.25051968@postgrespro.ru", "phone": "+70667957355"}
0005432880625	1D796E	2112 471016	DARYA EFIMOVA	{"phone": "+70994259461"}
0005432880626	6E82F5	8338 679956	EGOR GRIGOREV	{"phone": "+70341758502"}
0005432880627	6E82F5	3939 087630	ALFIYA SERGEEVA	{"phone": "+70393130913"}
0005432880628	4788D6	9386 431298	LYUDMILA YAKOVLEVA	{"phone": "+70225635073"}
0005432880629	4788D6	0856 008426	NADEZHDA TIKHONOVA	{"phone": "+70512734827"}
0005432880630	0D673F	7835 588759	LEONID KUZMIN	{"email": "leonid-kuzmin-02061983@postgrespro.ru", "phone": "+70154846387"}
0005432880631	0D673F	7171 195080	DMITRIY GUSEV	{"phone": "+70789348517"}
0005432880632	0D673F	8049 451747	NATALYA KUZMINA	{"phone": "+70756325339"}
0005432880633	558348	8407 058580	RAISA MEDVEDEVA	{"email": "medvedeva.raisa.20031980@postgrespro.ru", "phone": "+70106688479"}
0005432880634	C0F552	3337 877056	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov1972@postgrespro.ru", "phone": "+70417631926"}
0005432880635	E05355	0063 442300	LYUBOV FOMINA	{"email": "fominalyubov30121972@postgrespro.ru", "phone": "+70604625191"}
0005432880636	5E3EE3	0818 093949	ALEKSANDR KULIKOV	{"phone": "+70763874792"}
0005432880637	EE12A2	1373 302063	SERGEY IVANOV	{"email": "sergey-ivanov.021964@postgrespro.ru", "phone": "+70987892763"}
0005432880638	A874D1	2304 683328	TAISIYA NIKITINA	{"phone": "+70970835358"}
0005432880639	8C8307	6794 600675	GALINA BELOVA	{"email": "gbelova.18011968@postgrespro.ru", "phone": "+70702632134"}
0005432880640	CCCE0C	9618 261168	DMITRIY SEMENOV	{"phone": "+70137422577"}
0005432880641	97F2DC	3641 402546	SERGEY KUZNECOV	{"email": "sergey-kuznecov-15031967@postgrespro.ru", "phone": "+70964258078"}
0005432880642	97F2DC	8929 121577	ELIZAVETA ISAEVA	{"phone": "+70359626170"}
0005432880643	AF6034	6063 516048	NINA FROLOVA	{"email": "ninafrolova26041971@postgrespro.ru", "phone": "+70593769683"}
0005432880644	AF6034	0736 685333	LYUDMILA SEMENOVA	{"phone": "+70618448231"}
0005432880645	F89B2B	0322 720030	ARTEM DENISOV	{"phone": "+70349735918"}
0005432880813	03E86A	9007 045804	VLADIMIR ILIN	{"phone": "+70596500767"}
0005432880646	117D40	6533 109774	IVAN PAVLOV	{"email": "ivanpavlov1974@postgrespro.ru", "phone": "+70702103341"}
0005432880647	A20E97	1328 463772	ELENA RYABOVA	{"email": "e_ryabova1959@postgrespro.ru", "phone": "+70580764014"}
0005432880648	63BAF8	7891 045371	YURIY ROMANOV	{"phone": "+70391870406"}
0005432880649	63BAF8	3808 546013	LYUDMILA MATVEEVA	{"phone": "+70204307540"}
0005432880650	914F7E	4016 037287	LYUDMILA SOROKINA	{"email": "sorokina-l-28081972@postgrespro.ru", "phone": "+70741377573"}
0005432880651	FA26D6	2079 094957	DENIS KUZNECOV	{"phone": "+70886204259"}
0005432880652	8256A2	9765 374667	ALEKSANDR VASILEV	{"phone": "+70953320802"}
0005432880653	E83138	0664 667685	TATYANA TIMOFEEVA	{"phone": "+70779015217"}
0005432880654	E83138	0150 487460	ALFIYA GUSEVA	{"phone": "+70279290780"}
0005432880655	E83138	7171 238796	VITALIY SHEVCHENKO	{"phone": "+70121326488"}
0005432880656	A83B25	9243 752416	ANDREY BELOV	{"email": "andreybelov-1964@postgrespro.ru", "phone": "+70610094498"}
0005432880657	ACAA93	2388 563932	POLINA EFREMOVA	{"email": "p-efremova_16021966@postgrespro.ru", "phone": "+70418919469"}
0005432880658	ACAA93	0028 005517	LYUDMILA KALININA	{"phone": "+70859078211"}
0005432880659	780375	6647 737462	SERGEY SIDOROV	{"email": "sidorov-s-1970@postgrespro.ru", "phone": "+70730786185"}
0005432880660	E3DF6E	5728 486253	IGOR MELNIKOV	{"phone": "+70388760330"}
0005432880661	C0448B	5178 504213	MARIYA SAVELEVA	{"phone": "+70875103466"}
0005432880662	D5E76C	9491 976089	SVETLANA IVANOVA	{"phone": "+70912582654"}
0005432880663	8D178F	5070 688111	ROMAN FROLOV	{"phone": "+70115670848"}
0005432880664	8D178F	6949 747896	VLADIMIR SAVELEV	{"phone": "+70402662007"}
0005432880665	DDBD83	0579 090499	ELENA EFIMOVA	{"email": "efimovaelena121964@postgrespro.ru", "phone": "+70268521731"}
0005432880666	DD2FA8	7809 731640	ALEKSANDR MELNIKOV	{"email": "melnikov_a.30041965@postgrespro.ru", "phone": "+70833545984"}
0005432880667	DD2FA8	0299 501329	ALINA KUZNECOVA	{"email": "a_kuznecova.051974@postgrespro.ru", "phone": "+70351937183"}
0005432880668	F6C25C	7319 154640	ANDREY KUDRYASHOV	{"email": "kudryashov.a_17031969@postgrespro.ru", "phone": "+70053403329"}
0005432880669	BEAF0B	1424 842003	GEORGIY KUZNECOV	{"email": "georgiy.kuznecov_12041974@postgrespro.ru", "phone": "+70814278103"}
0005432880670	BEAF0B	2781 133238	VIKTORIYA KUZNECOVA	{"phone": "+70402558578"}
0005432880671	42BACD	5766 002882	ANDREY SEMENOV	{"email": "a_semenov_091961@postgrespro.ru", "phone": "+70131445558"}
0005432880672	D9A12F	0466 903885	LYUBOV STEPANOVA	{"phone": "+70508508093"}
0005432880673	489A4D	4217 206916	SVETLANA PAVLOVA	{"email": "s-pavlova_03041981@postgrespro.ru", "phone": "+70446556641"}
0005432880674	489A4D	3553 024797	DENIS NAUMOV	{"phone": "+70355287895"}
0005432880675	118F98	5931 329265	VYACHESLAV ISAEV	{"phone": "+70129490333"}
0005432880676	1085F5	3986 388232	ALEKSANDR YAKOVLEV	{"email": "yakovleva19101967@postgrespro.ru", "phone": "+70123804388"}
0005432880677	632B69	2258 804122	GENNADIY POPOV	{"email": "g-popov1966@postgrespro.ru", "phone": "+70127867914"}
0005432880678	3BEBB9	4761 189080	TAMARA AKIMOVA	{"email": "akimova_t_11081973@postgrespro.ru", "phone": "+70794154652"}
0005432880679	135FDB	5708 709259	EVGENIY KOZLOV	{"phone": "+70486785708"}
0005432880680	FA80A3	2465 033492	IRINA AKIMOVA	{"email": "akimova.i1980@postgrespro.ru", "phone": "+70664443689"}
0005432880681	184D16	8715 257844	NIKOLAY KRASNOV	{"email": "krasnov-nikolay.101976@postgrespro.ru", "phone": "+70683415816"}
0005432880682	184D16	0021 900407	YURIY NOVIKOV	{"phone": "+70651305288"}
0005432880683	3ADF03	7477 958319	SERGEY SCHERBAKOV	{"email": "scherbakovs_03111971@postgrespro.ru", "phone": "+70008336389"}
0005432880684	509834	6812 646687	IGOR EGOROV	{"phone": "+70083728340"}
0005432880685	952B45	4435 120952	ARTEM GERASIMOV	{"phone": "+70139755016"}
0005432880686	BDD9D8	7203 044542	DENIS ALEKSANDROV	{"email": "denis.aleksandrov_15011963@postgrespro.ru", "phone": "+70193023870"}
0005432880687	BDD9D8	2945 283802	TAMARA IVANOVA	{"email": "t_ivanova_10051982@postgrespro.ru", "phone": "+70315251957"}
0005432880688	543947	9985 460260	PAVEL KUZMIN	{"phone": "+70734879206"}
0005432880689	841C51	6836 899480	ALEFTINA FOMINA	{"phone": "+70426286199"}
0005432880690	AA3557	9149 948103	TATYANA ANTONOVA	{"phone": "+70204677400"}
0005432880691	BF09AE	3262 545138	RUSLAN VASILEV	{"email": "vasilevruslan_121968@postgrespro.ru", "phone": "+70548522076"}
0005432880692	BF09AE	7152 774749	ANASTASIYA ANTONOVA	{"phone": "+70330888744"}
0005432880693	9202B6	6932 315090	ALEKSANDR ROMANOV	{"email": "a_romanov_19071958@postgrespro.ru", "phone": "+70477862075"}
0005432880694	6E8FC9	3876 780890	MIKHAIL IVANOV	{"phone": "+70278567935"}
0005432880695	53AB27	8377 876497	EVGENIY MOROZOV	{"phone": "+70940666171"}
0005432880696	A52BAF	5153 809795	EGOR BORISOV	{"email": "eborisov1976@postgrespro.ru", "phone": "+70309993365"}
0005432880697	A52BAF	1429 754709	VADIM NIKITIN	{"phone": "+70040964076"}
0005432880698	F32D0D	1217 780554	ALEKSANDRA TROFIMOVA	{"phone": "+70129417975"}
0005432880699	01F36F	8014 317718	VALENTINA MASLOVA	{"phone": "+70548478641"}
0005432880700	01F36F	9769 099963	NIKOLAY SCHERBAKOV	{"phone": "+70882591811"}
0005432880701	363AF2	3432 469943	EVGENIYA DANILOVA	{"email": "danilova-e-1971@postgrespro.ru", "phone": "+70174437528"}
0005432880702	363AF2	6732 475868	OKSANA SERGEEVA	{"phone": "+70791510928"}
0005432880703	BC528E	5642 740766	SVETLANA DMITRIEVA	{"email": "svetlana-dmitrieva.071968@postgrespro.ru", "phone": "+70349575135"}
0005432880704	4C878F	9399 508894	PETR SAVELEV	{"phone": "+70245254279"}
0005432880705	05250A	1461 810410	VASILIY KOZLOV	{"phone": "+70730036382"}
0005432880706	05250A	8132 411508	VLADISLAV POPOV	{"phone": "+70819607153"}
0005432880707	F758C1	8688 953153	EVGENIY KAZAKOV	{"email": "evgeniy.kazakov-061977@postgrespro.ru", "phone": "+70184658783"}
0005432880708	A76D47	5402 848460	ANDREY VOLKOV	{"email": "volkov.a1976@postgrespro.ru", "phone": "+70884688193"}
0005432880709	A76D47	9970 135599	ALEKSANDRA NIKOLAEVA	{"email": "nikolaeva.aleksandra.1972@postgrespro.ru", "phone": "+70263264133"}
0005432880710	F18AA7	5076 471575	VLADIMIR BORISOV	{"email": "borisov_v25041960@postgrespro.ru", "phone": "+70183261513"}
0005432880711	F18AA7	0960 316818	KSENIYA ANDREEVA	{"phone": "+70314453219"}
0005432880712	6A122A	1006 189719	NATALYA ABRAMOVA	{"phone": "+70468354406"}
0005432880713	9E1BFF	8024 965142	VASILIY VASILEV	{"email": "v.vasilev_08121965@postgrespro.ru", "phone": "+70227140721"}
0005432880714	F966A8	7528 353346	NATALYA DAVYDOVA	{"email": "davydova.natalya1970@postgrespro.ru", "phone": "+70035665740"}
0005432880715	F966A8	9241 044527	VALENTINA MOISEEVA	{"phone": "+70249680656"}
0005432880716	FEFD60	4013 225280	PAVEL VOROBEV	{"phone": "+70770000815"}
0005432880717	3D34C2	4356 883184	GALINA ALEKSEEVA	{"email": "g-alekseeva.21111977@postgrespro.ru", "phone": "+70707177220"}
0005432880718	3D34C2	5174 085429	TATYANA FILATOVA	{"email": "tatyana.filatova-021976@postgrespro.ru", "phone": "+70323305729"}
0005432880719	6CC1A7	3917 391142	NATALYA NIKITINA	{"email": "natalya_nikitina-1966@postgrespro.ru", "phone": "+70955072414"}
0005432880720	9D074E	4961 402431	SERGEY ISAEV	{"phone": "+70882011658"}
0005432880721	F7A4A6	3503 568023	VALENTINA MATVEEVA	{"email": "matveeva_v13011986@postgrespro.ru", "phone": "+70221680189"}
0005432880722	ADCBEC	3010 197420	IVAN YAKOVLEV	{"email": "yakovlevi_051966@postgrespro.ru", "phone": "+70031908519"}
0005432880723	6A44A0	7262 687250	ALEKSANDR KOROLEV	{"phone": "+70722971284"}
0005432880724	041B10	9563 289280	ANTON FEDOTOV	{"phone": "+70449179002"}
0005432880725	041B10	2121 094479	NIKOLAY SIDOROV	{"email": "sidorov-nikolay06081973@postgrespro.ru", "phone": "+70611816483"}
0005432880726	DCB826	2012 170616	VYACHESLAV SOLOVEV	{"phone": "+70140322367"}
0005432880727	C1464A	1848 606919	YURIY SOROKIN	{"email": "yuriysorokin-01121980@postgrespro.ru", "phone": "+70080089576"}
0005432880728	C1464A	0878 706309	LILIYA GERASIMOVA	{"email": "liliya.gerasimova121969@postgrespro.ru", "phone": "+70720982347"}
0005432880729	C1464A	9225 840713	IRINA POPOVA	{"phone": "+70657589432"}
0005432880730	A39889	7838 449298	ALEKSANDRA DENISOVA	{"phone": "+70027162844"}
0005432880731	A39889	6608 067859	VALENTINA SMIRNOVA	{"email": "valentinasmirnova-041976@postgrespro.ru", "phone": "+70627522029"}
0005432880732	00635C	6693 435392	MARIYA MIKHAYLOVA	{"phone": "+70711506093"}
0005432880733	00635C	1109 644445	LYUDMILA MIRONOVA	{"phone": "+70893063063"}
0005432880734	5380E4	5160 111539	YULIYA ARKHIPOVA	{"phone": "+70508449434"}
0005432880735	D43247	2154 561921	IRINA LAZAREVA	{"email": "i_lazareva.03021964@postgrespro.ru", "phone": "+70279472602"}
0005432880736	F1E594	3447 915129	TATYANA NESTEROVA	{"email": "t_nesterova.031983@postgrespro.ru", "phone": "+70802840975"}
0005432881183	8D56A2	2022 636423	GALINA ANTONOVA	{"phone": "+70026022609"}
0005432880737	F1E594	7781 205840	ANTON ZAKHAROV	{"email": "zakharov_anton_111976@postgrespro.ru", "phone": "+70994331079"}
0005432880738	8EEFB6	3251 614851	ALEKSEY OSIPOV	{"phone": "+70940418571"}
0005432880739	D6AEF8	2956 367152	TAMARA KUDRYASHOVA	{"phone": "+70530708522"}
0005432880740	9519B0	7406 386572	VALENTINA FADEEVA	{"email": "valentina_fadeeva011981@postgrespro.ru", "phone": "+70874443672"}
0005432880741	D8E382	7602 465157	EGOR FROLOV	{"phone": "+70088637037"}
0005432880742	1B757D	4194 089355	VIKTOR ALEKSEEV	{"email": "v-alekseev16011968@postgrespro.ru", "phone": "+70646007417"}
0005432880743	76B21D	0290 030840	OLGA KUZNECOVA	{"phone": "+70164654226"}
0005432880744	95F210	6559 236100	EKATERINA VOROBEVA	{"email": "evorobeva-24071968@postgrespro.ru", "phone": "+70318642591"}
0005432880745	95F210	4282 146653	GEORGIY ZHURAVLEV	{"phone": "+70098996258"}
0005432880746	7B68A5	5161 551042	ANASTASIYA SAVELEVA	{"email": "saveleva.a_1970@postgrespro.ru", "phone": "+70428913359"}
0005432880747	7B68A5	7875 796110	DMITRIY MIRONOV	{"email": "mironovdmitriy.16011971@postgrespro.ru", "phone": "+70959285164"}
0005432880748	7B68A5	1145 688573	TATYANA LEBEDEVA	{"email": "lebedevatatyana1979@postgrespro.ru", "phone": "+70823859236"}
0005432880749	7200CA	4886 417502	VLADIMIR ROMANOV	{"email": "romanovv.041975@postgrespro.ru", "phone": "+70528063885"}
0005432880750	99ACEB	0339 841654	YURIY STEPANOV	{"email": "ystepanov_26031972@postgrespro.ru", "phone": "+70722864513"}
0005432880751	FFA6C4	2077 131272	VYACHESLAV EGOROV	{"email": "egorov_vyacheslav1978@postgrespro.ru", "phone": "+70427823056"}
0005432880752	FFA6C4	5591 398048	NINA KUZMINA	{"email": "kuzminanina121974@postgrespro.ru", "phone": "+70424859574"}
0005432880753	ACEB28	5657 112305	GEORGIY ANTONOV	{"phone": "+70635570124"}
0005432880754	ACEB28	3794 187402	OLGA NIKOLAEVA	{"phone": "+70783076975"}
0005432880755	6C33EF	0240 989861	MIKHAIL SCHERBAKOV	{"email": "m.scherbakov-14091967@postgrespro.ru", "phone": "+70461743124"}
0005432880756	B4F484	6006 164710	ALEKSANDR SOKOLOV	{"email": "a.sokolov021964@postgrespro.ru", "phone": "+70793336974"}
0005432880757	389A5C	8773 570837	EKATERINA BORISOVA	{"phone": "+70549542929"}
0005432880758	389A5C	4162 990412	ELENA ILINA	{"email": "e.ilina-031966@postgrespro.ru", "phone": "+70494594843"}
0005432880759	F4ADA6	7839 765738	VIKTOR MAKSIMOV	{"email": "v-maksimov.03061974@postgrespro.ru", "phone": "+70060106742"}
0005432880760	BDDC58	6641 592404	DMITRIY KARPOV	{"email": "karpov-dmitriy111963@postgrespro.ru", "phone": "+70163826044"}
0005432880761	615438	9599 183556	VALENTINA GAVRILOVA	{"email": "gavrilova-valentina.08081965@postgrespro.ru", "phone": "+70054750555"}
0005432880762	13FE96	6657 076747	INNA MEDVEDEVA	{"email": "medvedeva_inna1975@postgrespro.ru", "phone": "+70412533116"}
0005432880763	13FE96	0385 932499	MARGARITA PAVLOVA	{"email": "mpavlova1978@postgrespro.ru", "phone": "+70770692703"}
0005432880764	1E5A13	7913 005565	DANIIL VOLKOV	{"email": "volkov.d041983@postgrespro.ru", "phone": "+70157727579"}
0005432880765	459310	7564 815556	ILYA KUZMIN	{"email": "i-kuzmin-101977@postgrespro.ru", "phone": "+70779750471"}
0005432880766	73D347	3724 291050	PAVEL NIKITIN	{"email": "pavel_nikitin-1971@postgrespro.ru", "phone": "+70494485254"}
0005432880767	73D347	5107 641944	LIDIYA BELOVA	{"phone": "+70880956214"}
0005432880768	73D347	2992 700564	TATYANA SEMENOVA	{"phone": "+70913594876"}
0005432880769	AF0E2C	3265 825196	ALEKSANDRA MIRONOVA	{"phone": "+70553704327"}
0005432880770	AF0E2C	6730 547283	NIKOLAY TIMOFEEV	{"email": "timofeevn081974@postgrespro.ru", "phone": "+70631882861"}
0005432880771	3AB30C	0867 287006	ANDREY PAVLOV	{"email": "andrey_pavlov-1961@postgrespro.ru", "phone": "+70796882413"}
0005432880772	857039	2711 410351	SERGEY BARANOV	{"email": "baranov-s111970@postgrespro.ru", "phone": "+70734626587"}
0005432880773	14F018	1135 175660	SVETLANA SERGEEVA	{"email": "sergeevasvetlana.011978@postgrespro.ru", "phone": "+70569237607"}
0005432880774	14F018	5625 475321	MARIYA CHERNOVA	{"email": "mchernova031985@postgrespro.ru", "phone": "+70018112085"}
0005432880775	D283D8	9389 473244	DMITRIY SEMENOV	{"email": "dmitriysemenov03091966@postgrespro.ru", "phone": "+70487432913"}
0005432880776	56DEB9	6992 546896	ELENA MAKAROVA	{"email": "makarovae.1964@postgrespro.ru", "phone": "+70989172654"}
0005432880777	56DEB9	0985 823165	SVETLANA KOROLEVA	{"email": "koroleva_svetlana-031976@postgrespro.ru", "phone": "+70881963918"}
0005432880778	035391	7092 501580	NIKOLAY EGOROV	{"email": "egorov_nikolay.1970@postgrespro.ru", "phone": "+70806603312"}
0005432880779	C28223	4318 781518	OKSANA ZHURAVLEVA	{"phone": "+70681254968"}
0005432880780	C28223	7800 119560	RAFAIL IVANOV	{"phone": "+70458019043"}
0005432880781	6143F2	6480 512139	KIRILL ZAYCEV	{"phone": "+70987340830"}
0005432880782	6143F2	4106 799413	ANNA KUZNECOVA	{"email": "anna.kuznecova-031986@postgrespro.ru", "phone": "+70285266529"}
0005432880783	68C552	6454 015812	TATYANA YAKOVLEVA	{"email": "tatyana_yakovleva1979@postgrespro.ru", "phone": "+70485840604"}
0005432880784	390C5A	2394 942052	RUSTEM VOLKOV	{"email": "volkov.r.25021966@postgrespro.ru", "phone": "+70532920653"}
0005432880785	4857EE	3815 132048	DMITRIY MIRONOV	{"phone": "+70562594809"}
0005432880786	107BC9	0587 979624	MARIYA YUDINA	{"phone": "+70261664569"}
0005432880787	15E580	6517 924390	MIKHAIL ZHUKOV	{"phone": "+70051164154"}
0005432880788	4FB225	8981 457255	DMITRIY FROLOV	{"phone": "+70071932719"}
0005432880789	B60C73	2675 647727	DMITRIY RODIONOV	{"phone": "+70588845727"}
0005432880790	8EF6AF	4984 610633	ANDREY VASILEV	{"phone": "+70583896611"}
0005432880791	962A6B	1914 302294	GALINA MIKHAYLOVA	{"phone": "+70681352028"}
0005432880792	D99B19	1342 074822	IVAN MOISEEV	{"email": "moiseev-ivan031977@postgrespro.ru", "phone": "+70464267054"}
0005432880793	5D17B7	1202 329693	ALEKSANDR EGOROV	{"phone": "+70180892927"}
0005432880794	24DEF1	5034 597349	ALEKSANDR KULIKOV	{"phone": "+70097422162"}
0005432880795	24DEF1	8779 889299	ALEKSEY SHEVCHENKO	{"email": "aleksey_shevchenko_14041968@postgrespro.ru", "phone": "+70460128032"}
0005432880796	CECB4B	6596 285859	VLADIMIR STEPANOV	{"phone": "+70425281397"}
0005432880797	9C22DE	0433 999624	EKATERINA IVANOVA	{"email": "ekaterina-ivanova13091975@postgrespro.ru", "phone": "+70400341822"}
0005432880798	9C22DE	7123 381743	VALENTINA KULIKOVA	{"email": "kulikova.valentina.15031965@postgrespro.ru", "phone": "+70673939376"}
0005432880799	A04AC1	5074 495670	ANASTASIYA OSIPOVA	{"email": "osipova_a_1976@postgrespro.ru", "phone": "+70458044433"}
0005432880800	FDD0F1	0306 116063	IRINA FEDOROVA	{"email": "i-fedorova_081975@postgrespro.ru", "phone": "+70403538236"}
0005432880801	FDD0F1	2384 465686	VALERIYA KRASNOVA	{"phone": "+70955704494"}
0005432880802	7A6617	6116 179478	YURIY KUZNECOV	{"email": "yuriykuznecov1982@postgrespro.ru", "phone": "+70544973193"}
0005432880803	4AC05D	9593 890871	RAVILYA FROLOVA	{"phone": "+70425782785"}
0005432880804	9EA999	8571 971783	ELENA RODIONOVA	{"phone": "+70793788539"}
0005432880805	7E8A16	8290 769884	ANNA CHERNOVA	{"phone": "+70787708517"}
0005432880806	18DCF0	5529 891023	SERGEY BORISOV	{"phone": "+70247962432"}
0005432880807	DF65C9	5425 213542	YULIYA KOLESNIKOVA	{"phone": "+70351817751"}
0005432880808	A5A18A	3306 738823	VALERIYA MELNIKOVA	{"email": "valeriya.melnikova23111978@postgrespro.ru", "phone": "+70909070772"}
0005432880809	6A25A3	7534 840062	VERONIKA KULIKOVA	{"phone": "+70652431168"}
0005432880810	E90876	8323 225294	ALEKSANDR IVANOV	{"email": "aleksandrivanov.071989@postgrespro.ru", "phone": "+70318849058"}
0005432880811	E90876	4483 697208	MARINA ROMANOVA	{"email": "romanova.marina_03101959@postgrespro.ru", "phone": "+70855703811"}
0005432880812	E90876	7600 068659	MARINA VASILEVA	{"email": "m_vasileva_121976@postgrespro.ru", "phone": "+70236375389"}
0005432880814	24230D	8611 316653	ANTONINA MAKAROVA	{"email": "makarova_antonina_08121965@postgrespro.ru", "phone": "+70059125706"}
0005432880815	5931E9	5592 721278	ANASTASIYA SIDOROVA	{"phone": "+70819971339"}
0005432880816	7FC00A	8256 825542	NATALYA KOROLEVA	{"email": "n.koroleva-1964@postgrespro.ru", "phone": "+70780471571"}
0005432880817	A28EF1	6002 588959	VYACHESLAV EGOROV	{"phone": "+70370345838"}
0005432880818	773C96	4477 664985	SVETLANA KOVALEVA	{"phone": "+70226053964"}
0005432880819	773C96	1614 891751	GALINA MEDVEDEVA	{"phone": "+70713432555"}
0005432880820	F6D0FA	6412 612162	OLESYA SOKOLOVA	{"email": "o_sokolova.041982@postgrespro.ru", "phone": "+70014894906"}
0005432880821	787510	5131 133872	EKATERINA VASILEVA	{"phone": "+70859284689"}
0005432880822	86CDBA	7718 449049	VLADIMIR BORISOV	{"phone": "+70849787787"}
0005432880823	A06D6E	4412 421396	YULIYA EGOROVA	{"email": "egorova_yuliya-041976@postgrespro.ru", "phone": "+70688558761"}
0005432880824	DE4AF8	5152 767087	ALEKSANDR NIKOLAEV	{"phone": "+70115304869"}
0005432880825	B74651	1399 081417	YURIY EGOROV	{"email": "egorov.yuriy-1971@postgrespro.ru", "phone": "+70910874930"}
0005432880826	B74651	1835 506104	SVETLANA VLASOVA	{"email": "vlasovas011984@postgrespro.ru", "phone": "+70690514567"}
0005432880827	B74651	7695 972903	VALENTINA ROMANOVA	{"phone": "+70518623613"}
0005432880828	A40342	2400 437837	SVETLANA DENISOVA	{"email": "denisova_svetlana_26071967@postgrespro.ru", "phone": "+70147301582"}
0005432880829	360E2E	6532 369953	ELENA VASILEVA	{"email": "vasilevaelena-061977@postgrespro.ru", "phone": "+70948492307"}
0005432880830	F1F54B	0946 932814	EKATERINA KOROLEVA	{"phone": "+70696447515"}
0005432880831	83DC97	4897 259612	MIKHAIL SERGEEV	{"phone": "+70259877135"}
0005432880832	F99D25	4569 769596	AMIR ROMANOV	{"phone": "+70333618255"}
0005432880833	AF8515	1744 576896	NINA NAZAROVA	{"phone": "+70481511007"}
0005432880834	7DC408	5247 364376	TATYANA BELOVA	{"email": "belovatatyana-22051965@postgrespro.ru", "phone": "+70872188812"}
0005432880835	7DC408	3406 704297	SVETLANA MATVEEVA	{"phone": "+70580254090"}
0005432880836	73DE38	8565 026926	ILDAR SEMENOV	{"email": "i-semenov121961@postgrespro.ru", "phone": "+70713018096"}
0005432880837	417AB8	1003 862887	NIKOLAY SERGEEV	{"email": "sergeev.n.041983@postgrespro.ru", "phone": "+70748964718"}
0005432880838	8E8C36	9666 960268	VALENTINA STEPANOVA	{"phone": "+70104707734"}
0005432880839	CE8473	6297 662593	SVETLANA ISAEVA	{"phone": "+70666713107"}
0005432880840	3F7F59	7241 451220	VERA ISAEVA	{"email": "vera-isaeva_1970@postgrespro.ru", "phone": "+70817005537"}
0005432880841	E4FE9B	6358 688239	ALEKSEY GUSEV	{"phone": "+70289313095"}
0005432880842	E4FE9B	4278 836424	ANNA TITOVA	{"email": "anna-titova_1977@postgrespro.ru", "phone": "+70627287680"}
0005432880843	26D237	6784 126434	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.22021967@postgrespro.ru", "phone": "+70847855804"}
0005432880844	26D237	0292 956930	ALINA LAZAREVA	{"email": "alazareva30031964@postgrespro.ru", "phone": "+70935601150"}
0005432880845	8468C1	2424 745280	ANNA FILIPPOVA	{"phone": "+70063608071"}
0005432880846	F1CC02	1733 127751	DIANA ALEKSEEVA	{"phone": "+70911959964"}
0005432880847	8165F2	6990 840404	ANATOLIY MARTYNOV	{"email": "martynov-a1979@postgrespro.ru", "phone": "+70150788415"}
0005432880849	E0533B	5603 838666	ANDREY SOKOLOV	{"email": "sokolovandrey-091959@postgrespro.ru", "phone": "+70959519653"}
0005432880850	E0533B	1714 726566	DMITRIY MELNIKOV	{"email": "melnikov-dmitriy.19011965@postgrespro.ru", "phone": "+70014108246"}
0005432880851	E0533B	3768 797810	SERGEY YAKOVLEV	{"phone": "+70237847672"}
0005432880852	BAB377	4890 107653	PETR BORISOV	{"phone": "+70444443664"}
0005432880853	4A7156	1752 148189	ALEKSANDR NIKOLAEV	{"email": "anikolaev1974@postgrespro.ru", "phone": "+70777056515"}
0005432880854	70DEAE	2171 135319	VYACHESLAV KOZLOV	{"phone": "+70699650664"}
0005432880855	E7F82C	6019 285463	NADEZHDA NIKITINA	{"phone": "+70532968642"}
0005432880856	0D0501	9143 236866	LARISA OSIPOVA	{"phone": "+70109782676"}
0005432880857	99CC15	4318 667503	VASILIY MELNIKOV	{"email": "melnikov_v.22121959@postgrespro.ru", "phone": "+70459618198"}
0005432880858	0FECB9	1374 096959	ANDREY FEDOTOV	{"email": "a-fedotov20011974@postgrespro.ru", "phone": "+70110537460"}
0005432880859	0FECB9	3207 399109	ALEKSANDR DENISOV	{"email": "denisov_aleksandr1961@postgrespro.ru", "phone": "+70400283511"}
0005432880860	B11DF2	1993 549406	NATALYA NAUMOVA	{"email": "naumovan-051976@postgrespro.ru", "phone": "+70419096220"}
0005432880861	BF0851	4532 123952	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr.1977@postgrespro.ru", "phone": "+70792186678"}
0005432880862	BF0851	2161 830834	MARIYA CHERNOVA	{"email": "mariya.chernova.15091974@postgrespro.ru", "phone": "+70060603143"}
0005432880863	BF0851	1432 800106	VIKTOR SHEVCHENKO	{"phone": "+70136459253"}
0005432880864	6C4961	7481 951973	ALEKSEY MEDVEDEV	{"email": "alekseymedvedev.031969@postgrespro.ru", "phone": "+70389311245"}
0005432880865	598D0D	9083 398364	VLADISLAV TARASOV	{"phone": "+70250612521"}
0005432880866	598D0D	5826 161916	VITALIY PETROV	{"email": "v_petrov-1957@postgrespro.ru", "phone": "+70019576343"}
0005432880867	DF3F3A	9891 384614	ELENA KOZLOVA	{"email": "kozlova.elena-1962@postgrespro.ru", "phone": "+70420610458"}
0005432880868	DF3F3A	0323 039393	VIKTOR ALEKSANDROV	{"email": "v.aleksandrov-091981@postgrespro.ru", "phone": "+70455052515"}
0005432880869	C94134	0871 174652	NATALYA ERMAKOVA	{"email": "nermakova-1977@postgrespro.ru", "phone": "+70182102887"}
0005432880870	A7D709	1219 783354	SERGEY FEDOROV	{"phone": "+70752984541"}
0005432880871	5054C9	9492 351479	VALERIY ZAKHAROV	{"email": "valeriy_zakharov.061971@postgrespro.ru", "phone": "+70956622766"}
0005432880872	450A8C	1358 776376	EKATERINA KOMAROVA	{"email": "komarova-e.24031975@postgrespro.ru", "phone": "+70107454241"}
0005432880873	75CCF4	6921 238851	OLESYA KALININA	{"phone": "+70280680020"}
0005432880874	01528B	6644 931307	VLADIMIR GUSEV	{"phone": "+70660382662"}
0005432880934	439745	0034 084148	LYUDMILA FOMINA	{"phone": "+70410318540"}
0005432880875	EE81B8	3351 736290	NATALYA SEMENOVA	{"email": "natalya.semenova.1966@postgrespro.ru", "phone": "+70855662041"}
0005432880876	DBCE30	8557 518213	OLGA MIKHAYLOVA	{"phone": "+70569616907"}
0005432880877	773E18	1489 571071	VLADIMIR BONDARENKO	{"phone": "+70304746521"}
0005432880878	773E18	0508 192055	VERA KUZNECOVA	{"phone": "+70113992449"}
0005432880879	296A61	4142 072066	ALLA PETROVA	{"email": "petrova.a-14091966@postgrespro.ru", "phone": "+70329510060"}
0005432880880	073012	1156 319955	NIKOLAY ZAKHAROV	{"phone": "+70164976002"}
0005432880881	073012	6530 860195	ALEKSEY NOVIKOV	{"phone": "+70960843413"}
0005432880882	2AA1B8	5932 507909	SVETLANA VASILEVA	{"phone": "+70335673051"}
0005432880883	49FB01	7299 855333	PAVEL OSIPOV	{"phone": "+70064000118"}
0005432880884	D8571E	8568 768462	VLADIMIR SEMENOV	{"phone": "+70117616361"}
0005432880885	3C7D41	6271 364686	VLADIMIR SCHERBAKOV	{"email": "vladimir.scherbakov.04071986@postgrespro.ru", "phone": "+70770781471"}
0005432880886	2D8374	0793 520473	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev021978@postgrespro.ru", "phone": "+70961418103"}
0005432880887	961EE1	3551 374322	SERGEY IVANOV	{"phone": "+70784638962"}
0005432880888	256CD0	7622 568521	VERA SEMENOVA	{"email": "v.semenova1967@postgrespro.ru", "phone": "+70423356239"}
0005432880889	C67A80	9365 741176	ALEKSANDR RODIONOV	{"phone": "+70756563675"}
0005432880890	C67A80	5665 480027	IVAN GUSEV	{"email": "ivan-gusev_1978@postgrespro.ru", "phone": "+70025404991"}
0005432880891	43C725	6525 723489	SERGEY ILIN	{"email": "s.ilin011977@postgrespro.ru", "phone": "+70198369614"}
0005432880892	43C725	0432 154954	SVETLANA ANTONOVA	{"email": "antonova_svetlana_1970@postgrespro.ru", "phone": "+70587305865"}
0005432880893	DE2FC5	3603 042174	MARIYA NAZAROVA	{"email": "m-nazarova.04081971@postgrespro.ru", "phone": "+70387676161"}
0005432880894	CDD45D	9011 118668	VIKTOR ISAEV	{"phone": "+70070807480"}
0005432880895	CDD45D	7352 465754	VITALIY KARPOV	{"email": "karpov-v.06081967@postgrespro.ru", "phone": "+70408217294"}
0005432880896	CDD45D	3751 884989	VLADIMIR MAKSIMOV	{"email": "maksimov.vladimir.16091975@postgrespro.ru", "phone": "+70988235840"}
0005432880897	08DCAD	0943 610106	VALENTINA SOLOVEVA	{"email": "solovevav_12101961@postgrespro.ru", "phone": "+70440155695"}
0005432880898	08DCAD	4253 373448	ALEKSANDR ALEKSEEV	{"phone": "+70433594256"}
0005432880899	B7A9B5	1003 349868	IRINA SAVELEVA	{"email": "saveleva.irina.061969@postgrespro.ru", "phone": "+70116955460"}
0005432880900	031CB5	5787 987901	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov-05051962@postgrespro.ru", "phone": "+70445871455"}
0005432880901	38FB8A	2731 151274	KSENIYA GRISHINA	{"phone": "+70703193709"}
0005432880902	4314A3	5102 274121	ALEKSANDR SCHERBAKOV	{"phone": "+70685862341"}
0005432880903	4B29BF	3978 257902	ELENA NIKITINA	{"email": "nikitina-e_081961@postgrespro.ru", "phone": "+70017466734"}
0005432880904	046FC3	0806 768283	NATALYA PETROVA	{"email": "petrova.n.08091956@postgrespro.ru", "phone": "+70068851645"}
0005432880905	4365B1	0008 039774	SVETLANA MOROZOVA	{"email": "s.morozova.1978@postgrespro.ru", "phone": "+70801039258"}
0005432880906	4365B1	2407 736702	ALEKSANDR MELNIKOV	{"phone": "+70850460276"}
0005432880907	0CB4AB	5592 058053	IVAN ZAKHAROV	{"email": "zakharovivan1966@postgrespro.ru", "phone": "+70994472072"}
0005432880908	598224	2685 507315	TATYANA PAVLOVA	{"email": "tatyana_pavlova-1970@postgrespro.ru", "phone": "+70530431580"}
0005432880909	092C39	1398 703578	ALINA EFIMOVA	{"phone": "+70556908081"}
0005432880910	541D74	3401 311656	VALENTINA OVCHINNIKOVA	{"phone": "+70808068522"}
0005432880911	218D12	8436 217860	RUSLAN ANDREEV	{"email": "ruslanandreev-071961@postgrespro.ru", "phone": "+70082007917"}
0005432880912	97DB6E	5987 483664	LYUBOV EGOROVA	{"email": "lyubovegorova-14091961@postgrespro.ru", "phone": "+70416175194"}
0005432880913	97DB6E	4054 552058	ILYA GERASIMOV	{"email": "gerasimov.ilya-091971@postgrespro.ru", "phone": "+70702811595"}
0005432880914	59C9C7	5043 535670	EKATERINA MAKAROVA	{"email": "e.makarova.1970@postgrespro.ru", "phone": "+70939187391"}
0005432880915	8C3300	5480 863357	YANA ZHUKOVA	{"email": "zhukova_yana-1970@postgrespro.ru", "phone": "+70458074554"}
0005432880916	08274A	1894 594248	NINA ZHUKOVA	{"email": "zhukova.n.18091976@postgrespro.ru", "phone": "+70083876169"}
0005432880917	F403FB	8557 067201	TAMARA YUDINA	{"phone": "+70517379861"}
0005432880918	35FD0E	3331 017994	ANNA CHERNOVA	{"phone": "+70818697679"}
0005432880919	CF25F5	2226 496015	VLADIMIR MOROZOV	{"phone": "+70633852569"}
0005432880920	CF25F5	5410 056813	IRINA SEMENOVA	{"phone": "+70201741023"}
0005432880921	0E2512	6626 257850	VERA KOZLOVA	{"email": "v-kozlova.051975@postgrespro.ru", "phone": "+70921101003"}
0005432880922	0E2512	2185 144735	ARTEM SERGEEV	{"email": "sergeeva091981@postgrespro.ru", "phone": "+70343964100"}
0005432880923	F49EC1	1720 361512	SVETLANA POPOVA	{"email": "popova_s-1971@postgrespro.ru", "phone": "+70233819925"}
0005432880924	F49EC1	3694 478416	ILYA IVANOV	{"email": "ilya_ivanov-121977@postgrespro.ru", "phone": "+70255397326"}
0005432880925	B26739	9166 013964	ANASTASIYA SIDOROVA	{"phone": "+70645807329"}
0005432880926	B8D5EE	6478 005821	ALISA ILINA	{"email": "ilina.alisa031956@postgrespro.ru", "phone": "+70037461507"}
0005432880927	B8D5EE	7635 317383	ANNA KOROLEVA	{"phone": "+70767775187"}
0005432880928	029C7D	7978 960518	TATYANA SMIRNOVA	{"email": "tsmirnova_1959@postgrespro.ru", "phone": "+70512623035"}
0005432880929	029C7D	2505 350738	RODION TARASOV	{"phone": "+70919815989"}
0005432880930	774E47	6644 136395	YULIYA KRASNOVA	{"email": "krasnova_yuliya.15051983@postgrespro.ru", "phone": "+70697132297"}
0005432880931	FFBCD8	3390 679757	ANNA GERASIMOVA	{"email": "gerasimovaa_1965@postgrespro.ru", "phone": "+70012065230"}
0005432880932	13EEFA	6671 148462	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.011979@postgrespro.ru", "phone": "+70486648102"}
0005432880933	005E40	2399 169288	VASILIY TIMOFEEV	{"email": "vtimofeev-051975@postgrespro.ru", "phone": "+70832838625"}
0005432880935	439745	2000 038393	DENIS KUZMIN	{"email": "kuzmin.denis30091974@postgrespro.ru", "phone": "+70513090486"}
0005432880936	3A5030	9793 277369	VALERIY NIKITIN	{"email": "valeriynikitin_101966@postgrespro.ru", "phone": "+70818761753"}
0005432880937	3A5030	6883 098895	YULIYA KONOVALOVA	{"phone": "+70898900667"}
0005432880938	87DE86	7437 771342	KIRILL PAVLOV	{"email": "pavlovkirill_1962@postgrespro.ru", "phone": "+70839627907"}
0005432880939	87DE86	0982 537761	BORIS IVANOV	{"phone": "+70337369311"}
0005432880940	3815CF	8678 729979	ZINAIDA BELOVA	{"email": "belova-zinaida091976@postgrespro.ru", "phone": "+70934351691"}
0005432880941	3815CF	7533 342481	BORIS RODIONOV	{"email": "b.rodionov_091976@postgrespro.ru", "phone": "+70787430245"}
0005432880942	2B0E5D	9020 056111	ALEKSEY MELNIKOV	{"email": "melnikov.aleksey-31011957@postgrespro.ru", "phone": "+70186324155"}
0005432880943	2B0E5D	7218 773404	ROMAN IVANOV	{"phone": "+70029708395"}
0005432880944	5B5AFF	6233 860570	KONSTANTIN ILIN	{"phone": "+70208414890"}
0005432880945	9935FA	8345 463220	TATYANA ZOTOVA	{"email": "zotovat-081971@postgrespro.ru", "phone": "+70534636789"}
0005432880946	9935FA	1909 188555	RAMIL KUZMIN	{"email": "ramil-kuzmin.071982@postgrespro.ru", "phone": "+70196143493"}
0005432880947	2A120C	6826 245307	LIDIYA DANILOVA	{"phone": "+70418525059"}
0005432880948	9C98DF	0442 838926	EKATERINA FILATOVA	{"phone": "+70958249979"}
0005432880949	F0FC7D	6207 851015	ELENA KARPOVA	{"email": "karpova-elena.21021973@postgrespro.ru", "phone": "+70244406595"}
0005432880950	AF605A	0662 521841	SVETLANA ZAKHAROVA	{"phone": "+70478555174"}
0005432880951	EA1B5A	3519 540390	OKSANA GAVRILOVA	{"email": "oksana_gavrilova091977@postgrespro.ru", "phone": "+70059725290"}
0005432880952	926963	8523 108828	ALEKSEY KONOVALOV	{"email": "konovalov.a071968@postgrespro.ru", "phone": "+70947446682"}
0005432880953	434DDB	2198 398994	DARYA KRASNOVA	{"email": "darya-krasnova1969@postgrespro.ru", "phone": "+70058314420"}
0005432880954	6CBAD6	6635 246549	VITALIY POPOV	{"email": "popov_v1963@postgrespro.ru", "phone": "+70135391719"}
0005432880955	B11286	4149 851864	MAKSIM MARTYNOV	{"email": "martynov-m-19101968@postgrespro.ru", "phone": "+70825772123"}
0005432880956	A92986	3263 098842	ALEKSANDR KOZLOV	{"email": "a_kozlov1959@postgrespro.ru", "phone": "+70430570897"}
0005432880957	A92986	4225 900074	OLGA ZAKHAROVA	{"email": "o-zakharova081972@postgrespro.ru", "phone": "+70486894388"}
0005432880958	92C06E	1407 069543	OLEG BARANOV	{"email": "o.baranov.081978@postgrespro.ru", "phone": "+70747777633"}
0005432880959	92C06E	0111 911558	ANDREY ILIN	{"email": "ilin_andrey091975@postgrespro.ru", "phone": "+70480544308"}
0005432880960	B05FAC	9815 950509	ALEKSANDR GERASIMOV	{"phone": "+70806879669"}
0005432880961	34A35D	4320 151194	NADEZHDA IVANOVA	{"email": "ivanova-n1968@postgrespro.ru", "phone": "+70505472115"}
0005432880962	34A35D	3333 412626	GALINA MIKHAYLOVA	{"phone": "+70434221010"}
0005432880963	E6B8ED	2649 175986	MIKHAIL VOLKOV	{"email": "volkov_m-18041966@postgrespro.ru", "phone": "+70749503198"}
0005432880964	E6B8ED	0904 605351	GALINA GUSEVA	{"phone": "+70375026742"}
0005432880965	47591E	7198 677138	ARTUR NAZAROV	{"email": "a_nazarov_051985@postgrespro.ru", "phone": "+70901601315"}
0005432880966	6C6E1A	3143 233390	ANATOLIY FROLOV	{"email": "frolov.a31101964@postgrespro.ru", "phone": "+70226898911"}
0005432880967	357288	7599 422120	NINA SOKOLOVA	{"email": "sokolova_n.091968@postgrespro.ru", "phone": "+70703708572"}
0005432880968	357288	6571 596720	ANDREY IVANOV	{"email": "a_ivanov_1963@postgrespro.ru", "phone": "+70288142642"}
0005432880969	7C86BE	2533 576917	LARISA EGOROVA	{"phone": "+70529859932"}
0005432880970	7C86BE	7048 803033	IRINA POTAPOVA	{"email": "i-potapova_1988@postgrespro.ru", "phone": "+70833211596"}
0005432880971	7C86BE	2305 051533	MARIYA ANISIMOVA	{"email": "mariya.anisimova031971@postgrespro.ru", "phone": "+70892229729"}
0005432880972	9C8B8C	4246 020167	ALFIYA ANISIMOVA	{"phone": "+70318845755"}
0005432880973	3D0691	3264 433442	LYUDMILA FROLOVA	{"email": "l_frolova-19011985@postgrespro.ru", "phone": "+70337681895"}
0005432880974	3D0691	2660 573002	NINA DANILOVA	{"phone": "+70466543401"}
0005432880975	CA8531	3103 400420	ANDREY IVANOV	{"email": "a-ivanov23041969@postgrespro.ru", "phone": "+70963258075"}
0005432880976	372747	0693 925339	VYACHESLAV RODIONOV	{"email": "vyacheslav.rodionov-19051973@postgrespro.ru", "phone": "+70778740948"}
0005432880977	1CA0CE	3057 655264	GALINA ILINA	{"phone": "+70596204590"}
0005432880978	5C4C51	5783 860399	NINA ISAEVA	{"email": "ninaisaeva-111982@postgrespro.ru", "phone": "+70769640443"}
0005432880979	13C5AC	5092 990946	VLADISLAV DAVYDOV	{"phone": "+70804844270"}
0005432880980	13C5AC	8803 959866	ELVIRA GORBUNOVA	{"email": "gorbunova.e-11111971@postgrespro.ru", "phone": "+70683744129"}
0005432880981	A7F114	2918 336612	EVGENIY SOKOLOV	{"phone": "+70859099323"}
0005432880982	962042	2509 060665	OLGA MARTYNOVA	{"email": "martynovao-11031980@postgrespro.ru", "phone": "+70631015980"}
0005432880983	69F011	5954 290746	ALEKSANDRA NIKITINA	{"phone": "+70615875542"}
0005432880984	E1E3A3	4633 627680	ALEKSANDR ZAKHAROV	{"phone": "+70521254903"}
0005432880985	E1E3A3	4383 518214	NINA TIMOFEEVA	{"phone": "+70762503677"}
0005432880986	C8DDAC	8817 668379	VERA KOZLOVA	{"phone": "+70524227062"}
0005432880987	158EBF	2069 200662	ALEKSANDR ALEKSANDROV	{"email": "a.aleksandrov_101966@postgrespro.ru", "phone": "+70734480184"}
0005432880988	865562	0650 293614	DIANA VASILEVA	{"email": "vasileva.d_091980@postgrespro.ru", "phone": "+70057932384"}
0005432880989	ED3A34	8189 447862	ALEKSEY FEDOROV	{"email": "a_fedorov-1975@postgrespro.ru", "phone": "+70379238597"}
0005432880990	ED3A34	5258 546457	VYACHESLAV GRIGOREV	{"phone": "+70453702047"}
0005432880991	E4630E	9134 898339	SERGEY TIMOFEEV	{"phone": "+70974676873"}
0005432880992	E4630E	6538 708024	LYUBOV KUZMINA	{"phone": "+70618943304"}
0005432881051	FB7BAB	8730 672150	ALLA DAVYDOVA	{"phone": "+70948829696"}
0005432880993	7981FA	8230 558917	ALEKSANDR NAZAROV	{"email": "nazarov.aleksandr-071971@postgrespro.ru", "phone": "+70033487360"}
0005432880994	0B3440	3065 773573	RUSLAN SMIRNOV	{"phone": "+70548204654"}
0005432880995	E244A8	6032 868125	OKSANA BORISOVA	{"email": "borisovao.1963@postgrespro.ru", "phone": "+70912973570"}
0005432880996	474359	5407 656719	YULIYA GORBUNOVA	{"email": "gorbunova.yuliya-031979@postgrespro.ru", "phone": "+70972748432"}
0005432880997	E03571	2918 514162	ALEKSANDRA IVANOVA	{"email": "a-ivanova_11021968@postgrespro.ru", "phone": "+70911851445"}
0005432880998	28DAD1	8194 297529	OLGA DENISOVA	{"email": "olgadenisova_061971@postgrespro.ru", "phone": "+70758401617"}
0005432880999	CBC3AD	9390 024996	VLADIMIR NIKOLAEV	{"email": "nikolaev_vladimir_121971@postgrespro.ru", "phone": "+70736532112"}
0005432881000	35C792	8003 771338	TAMARA ANTONOVA	{"phone": "+70270965712"}
0005432881001	35C792	5048 189670	MIKHAIL SEMENOV	{"email": "semenov.mikhail051969@postgrespro.ru", "phone": "+70431860138"}
0005432881002	0D3BD3	3042 265831	VIKTOR TIMOFEEV	{"email": "timofeevviktor_1971@postgrespro.ru", "phone": "+70160131014"}
0005432881003	A77EE0	8276 352979	ALEKSEY MOROZOV	{"email": "aleksey-morozov_1969@postgrespro.ru", "phone": "+70760579543"}
0005432881004	DC7C3F	8564 837128	ALEKSEY KOZLOV	{"email": "kozlov.aleksey-111974@postgrespro.ru", "phone": "+70835052935"}
0005432881005	F32283	5981 289747	VITALIY ALEKSEEV	{"phone": "+70469986211"}
0005432881006	7000A1	6830 046723	MARAT VASILEV	{"email": "marat-vasilev.19051984@postgrespro.ru", "phone": "+70548452576"}
0005432881007	856024	7049 954627	ALEKSANDR VOROBEV	{"phone": "+70954462373"}
0005432881008	856024	7880 282637	ANTONINA FROLOVA	{"email": "antonina-frolova-061980@postgrespro.ru", "phone": "+70430673533"}
0005432881009	89A5A3	2047 525715	VLADIMIR MAKSIMOV	{"phone": "+70285296053"}
0005432881010	BCAB12	3611 916944	SVETLANA KARPOVA	{"email": "s_karpova_051971@postgrespro.ru", "phone": "+70747421125"}
0005432881011	4A2782	5745 339823	LEONID SEMENOV	{"email": "l.semenov1974@postgrespro.ru", "phone": "+70048859794"}
0005432881012	CB8711	5965 049878	DMITRIY SIDOROV	{"email": "sidorov-d_1987@postgrespro.ru", "phone": "+70695927149"}
0005432881013	B6414C	1973 439048	LIDIYA PAVLOVA	{"email": "lpavlova.1964@postgrespro.ru", "phone": "+70278935925"}
0005432881014	B6414C	1372 673640	SVETLANA FADEEVA	{"email": "fadeeva-svetlana_29011975@postgrespro.ru", "phone": "+70053178112"}
0005432881015	B6414C	2135 687296	MIKHAIL KOZLOV	{"phone": "+70686339125"}
0005432881016	CCBA7D	2862 602374	ANASTASIYA MAKAROVA	{"email": "a-makarova-111961@postgrespro.ru", "phone": "+70146152857"}
0005432881017	97CDE7	9612 532156	VIKTORIYA FILIPPOVA	{"phone": "+70737829930"}
0005432881018	40DBFE	1838 542473	ALEKSANDR POPOV	{"email": "popov-aleksandr_1973@postgrespro.ru", "phone": "+70222963599"}
0005432881019	40DBFE	5838 531332	VYACHESLAV GAVRILOV	{"phone": "+70277498483"}
0005432881020	904730	6871 930407	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr_1965@postgrespro.ru", "phone": "+70028098217"}
0005432881021	39232C	7659 715482	PAVEL SOKOLOV	{"email": "p-sokolov.1967@postgrespro.ru", "phone": "+70965352837"}
0005432881022	A05A70	3162 211577	ELENA VOROBEVA	{"email": "e.vorobeva-1983@postgrespro.ru", "phone": "+70175870962"}
0005432881023	A05A70	9972 869963	ALEKSANDR BELOV	{"phone": "+70108824813"}
0005432881024	A05A70	0965 036304	TAMARA FROLOVA	{"phone": "+70674383865"}
0005432881025	B172D7	2135 752356	VLADIMIR ANTONOV	{"phone": "+70492292457"}
0005432881026	37B572	8112 482610	ELENA POPOVA	{"email": "epopova1978@postgrespro.ru", "phone": "+70489861268"}
0005432881027	FFD49B	5952 577410	OLGA VOROBEVA	{"phone": "+70653344150"}
0005432881028	B3ED86	3833 766499	GENNADIY SOROKIN	{"email": "gennadiysorokin1981@postgrespro.ru", "phone": "+70832358978"}
0005432881029	BBEF83	8562 400220	NIKOLAY KUDRYASHOV	{"email": "kudryashov.nikolay-1975@postgrespro.ru", "phone": "+70019916917"}
0005432881030	BBEF83	1345 124938	LILIYA PETROVA	{"email": "petrova_liliya-1974@postgrespro.ru", "phone": "+70749580441"}
0005432881031	BBEF83	5323 829415	ALEKSANDR ALEKSEEV	{"phone": "+70979665264"}
0005432881032	F327E7	0301 613861	ANASTASIYA SAVELEVA	{"phone": "+70376916165"}
0005432881033	BC0412	9791 694751	EKATERINA POPOVA	{"phone": "+70977968167"}
0005432881034	FD3C1C	0908 486256	ILMIR POPOV	{"email": "popovilmir_1983@postgrespro.ru", "phone": "+70463721565"}
0005432881035	3EF275	2559 772085	FEDOR SEMENOV	{"email": "fedor_semenov1972@postgrespro.ru", "phone": "+70855576250"}
0005432881148	78947F	0257 906306	IRINA POTAPOVA	{"phone": "+70911835537"}
0005432881036	508DA4	5553 980945	EVGENIY FOMIN	{"email": "evgeniy_fomin.1970@postgrespro.ru", "phone": "+70899936659"}
0005432881037	508DA4	7542 657283	ALEKSANDR SAVELEV	{"email": "asavelev021976@postgrespro.ru", "phone": "+70408125289"}
0005432881038	8E24BA	9257 765163	ELENA POPOVA	{"phone": "+70207942201"}
0005432881039	15EA85	5719 532298	SVETLANA ILINA	{"email": "ilina_s.081975@postgrespro.ru", "phone": "+70898863520"}
0005432881040	15EA85	7278 176585	MARIYA AFANASEVA	{"phone": "+70145078498"}
0005432881041	E732D1	2064 225357	MARIYA TIMOFEEVA	{"phone": "+70989914864"}
0005432881042	E732D1	5836 098484	VITALIY STEPANOV	{"phone": "+70439994731"}
0005432881043	546EF3	4287 382740	NINA POPOVA	{"phone": "+70656254635"}
0005432881044	DF2135	6199 546573	ANZHELIKA FEDOROVA	{"phone": "+70340281499"}
0005432881045	E313EC	4360 605078	ELENA KRASNOVA	{"email": "krasnova-elena_11061971@postgrespro.ru", "phone": "+70023607977"}
0005432881046	E313EC	3702 871232	PETR ILIN	{"phone": "+70689912937"}
0005432881047	B1EF8F	7124 227806	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin.05111977@postgrespro.ru", "phone": "+70864000447"}
0005432881048	B1EF8F	9158 351981	KIRA ZHURAVLEVA	{"phone": "+70363564971"}
0005432881049	17BD15	7761 290208	ALEKSANDR BELOV	{"phone": "+70347563152"}
0005432881050	FB7BAB	0721 750252	KSENIYA VOROBEVA	{"email": "kvorobeva.09071985@postgrespro.ru", "phone": "+70954971730"}
0005432881052	298348	4637 477369	DANIIL KRASNOV	{"email": "d.krasnov1974@postgrespro.ru", "phone": "+70355727720"}
0005432881053	298348	3824 101425	NATALYA SCHERBAKOVA	{"email": "n-scherbakova.1978@postgrespro.ru", "phone": "+70889707302"}
0005432881054	298348	3556 736848	VLADIMIR SOROKIN	{"email": "vsorokin-011978@postgrespro.ru", "phone": "+70304986730"}
0005432881055	7D8189	2570 969415	MAKSIM DMITRIEV	{"phone": "+70924203172"}
0005432881056	1988D2	9831 976313	IRINA SOLOVEVA	{"phone": "+70464956615"}
0005432881057	BAE5C3	3663 394866	VITALIY NIKITIN	{"phone": "+70458223188"}
0005432881058	BAE5C3	1054 349252	VLADIMIR VLASOV	{"phone": "+70970241124"}
0005432881059	A54BC4	6671 514415	LIDIYA ROMANOVA	{"email": "l.romanova-30031988@postgrespro.ru", "phone": "+70713030638"}
0005432881060	214671	3580 930332	RUSLAN GAVRILOV	{"email": "ruslan_gavrilov_1970@postgrespro.ru", "phone": "+70581407004"}
0005432881061	5B920C	7317 980023	OLGA FROLOVA	{"email": "frolova-olga_031980@postgrespro.ru", "phone": "+70926512059"}
0005432881062	9F4DF3	9202 115987	KONSTANTIN KOZLOV	{"phone": "+70757288427"}
0005432881063	094A8B	7092 254624	MARINA MIKHAYLOVA	{"phone": "+70838871808"}
0005432881064	094A8B	6511 574341	ELIZAVETA KOLESNIKOVA	{"email": "elizaveta-kolesnikova1964@postgrespro.ru", "phone": "+70075130661"}
0005432881065	3669EE	5938 332171	IRINA ZHUKOVA	{"phone": "+70687957635"}
0005432881066	3669EE	6569 238243	VITALIY CHERNOV	{"email": "vchernov-1975@postgrespro.ru", "phone": "+70076392457"}
0005432881067	FE0778	9444 196908	IRINA SMIRNOVA	{"email": "i.smirnova1967@postgrespro.ru", "phone": "+70776700827"}
0005432881068	FD4BBA	1630 399113	IRINA NAZAROVA	{"phone": "+70747212417"}
0005432881069	FD4BBA	2356 806825	VLADIMIR SERGEEV	{"phone": "+70052527880"}
0005432881070	380DF5	1113 063280	RUSLAN KAZAKOV	{"email": "ruslankazakov_1975@postgrespro.ru", "phone": "+70773301429"}
0005432881071	380DF5	0663 343609	VYACHESLAV GORBUNOV	{"email": "gorbunov-vyacheslav-26071975@postgrespro.ru", "phone": "+70788650603"}
0005432881072	79CD69	0199 182256	MIKHAIL KUZMIN	{"email": "kuzmin-m_01101961@postgrespro.ru", "phone": "+70072145993"}
0005432881073	79CD69	8350 214226	ARTEM IVANOV	{"email": "ivanovartem-13011967@postgrespro.ru", "phone": "+70140196012"}
0005432881074	2BE21B	6054 169900	POLINA GUSEVA	{"email": "p_guseva021970@postgrespro.ru", "phone": "+70142152150"}
0005432881075	4959C2	6216 194531	GALINA SOKOLOVA	{"email": "sokolova-galina-041976@postgrespro.ru", "phone": "+70357664168"}
0005432881076	A61076	1769 111593	VALENTINA EFREMOVA	{"phone": "+70713680441"}
0005432881077	4F1E2B	5866 618574	OLGA KUZNECOVA	{"email": "kuznecovaolga-1983@postgrespro.ru", "phone": "+70425935421"}
0005432881078	14EAA2	0663 488940	MARINA KOROLEVA	{"email": "koroleva_m.071972@postgrespro.ru", "phone": "+70123493918"}
0005432881079	4071E0	2570 654738	ANTONINA STEPANOVA	{"phone": "+70066457008"}
0005432881080	4071E0	5783 173858	ALEKSANDR VOLKOV	{"phone": "+70814046400"}
0005432881081	4071E0	5239 104933	TATYANA KOZLOVA	{"phone": "+70621749898"}
0005432881082	3389C1	1294 559857	VALERIY CHERNOV	{"phone": "+70304349270"}
0005432881083	B7B012	7152 619199	ANTONINA MATVEEVA	{"phone": "+70040384306"}
0005432881084	58DF45	7218 814713	ANDREY NOVIKOV	{"phone": "+70291812485"}
0005432881085	F421F6	8803 161425	ANTON NAZAROV	{"phone": "+70034666121"}
0005432881086	181DC8	9460 028695	ALEKSEY ILIN	{"email": "ilinaleksey_111977@postgrespro.ru", "phone": "+70814433982"}
0005432881087	A19909	4528 165247	ALEKSANDR GORBUNOV	{"phone": "+70714797994"}
0005432881088	B129C7	3016 006328	ALEKSANDR MARTYNOV	{"email": "amartynov-101966@postgrespro.ru", "phone": "+70223635643"}
0005432881089	01F807	8773 854836	ELENA POTAPOVA	{"email": "potapova_e-27041971@postgrespro.ru", "phone": "+70215501901"}
0005432881090	16FAF8	8482 102836	KONSTANTIN CHERNOV	{"email": "chernov-konstantin.1970@postgrespro.ru", "phone": "+70803748899"}
0005432881149	59A1BA	0083 658667	ALEKSANDR KUZNECOV	{"phone": "+70034285201"}
0005432881091	16FAF8	3709 366294	NADEZHDA NIKOLAEVA	{"email": "n.nikolaeva1972@postgrespro.ru", "phone": "+70486562005"}
0005432881092	F7C261	8089 023760	DMITRIY DENISOV	{"email": "dmitriy-denisov_1972@postgrespro.ru", "phone": "+70174122322"}
0005432881093	F7C261	5482 546543	ELENA MAKAROVA	{"phone": "+70174170905"}
0005432881094	F7C261	5815 934937	NINA IVANOVA	{"email": "ivanovanina-28061980@postgrespro.ru", "phone": "+70501587521"}
0005432881095	1FE1F8	2912 652504	NATALYA POLYAKOVA	{"phone": "+70236696694"}
0005432881096	64A407	2199 392608	OKSANA SMIRNOVA	{"email": "osmirnova_17021975@postgrespro.ru", "phone": "+70424503964"}
0005432881097	264577	1534 539091	LYUDMILA GUSEVA	{"email": "l-guseva_091977@postgrespro.ru", "phone": "+70238922593"}
0005432881098	4E76C0	0856 834841	SERGEY FROLOV	{"phone": "+70612568047"}
0005432881099	53DF2C	9974 068032	ALEKSANDR KUZNECOV	{"phone": "+70595532166"}
0005432881100	53DF2C	6134 019038	LYUDMILA ZAKHAROVA	{"email": "zakharova-l-03011971@postgrespro.ru", "phone": "+70678127241"}
0005432881101	D0C26C	5666 940918	YURIY KAZAKOV	{"phone": "+70315290054"}
0005432881102	F19FF9	9001 132284	EKATERINA SOKOLOVA	{"email": "ekaterinasokolova_1968@postgrespro.ru", "phone": "+70128807656"}
0005432881103	1F7670	8146 486466	YULIYA ORLOVA	{"email": "y_orlova-12041968@postgrespro.ru", "phone": "+70817880184"}
0005432881104	644361	5988 777580	ALEKSANDRA KUZMINA	{"email": "kuzminaaleksandra.111971@postgrespro.ru", "phone": "+70873892829"}
0005432881105	1606FA	0400 373307	LYUDMILA SCHERBAKOVA	{"email": "lyudmila-scherbakova-24111976@postgrespro.ru", "phone": "+70553899496"}
0005432881106	A56BA0	0464 819668	ALEKSEY BORISOV	{"email": "a.borisov_18111958@postgrespro.ru", "phone": "+70225795222"}
0005432881107	A56BA0	0269 265867	ILMIR FROLOV	{"email": "i.frolov.09101988@postgrespro.ru", "phone": "+70225640924"}
0005432881108	A56BA0	2968 647424	VLADIMIR CHERNOV	{"email": "vladimir-chernov-1969@postgrespro.ru", "phone": "+70298096583"}
0005432881109	63DCF4	7084 771199	TATYANA MAKSIMOVA	{"phone": "+70830085279"}
0005432881110	688933	2596 214983	ROZALIYA TROFIMOVA	{"email": "rozaliya.trofimova.26071975@postgrespro.ru", "phone": "+70501158721"}
0005432881111	D8D5FA	6332 207984	OLEG ANTONOV	{"phone": "+70936901028"}
0005432881112	C9DCF5	0625 087609	VLADIMIR PAVLOV	{"phone": "+70590787131"}
0005432881113	307233	0959 464812	DANILA SCHERBAKOV	{"phone": "+70317722354"}
0005432881114	307233	2850 545943	SVETLANA EFIMOVA	{"phone": "+70873191420"}
0005432881115	807AF9	9058 346475	KRISTINA NIKOLAEVA	{"phone": "+70252023598"}
0005432881116	807AF9	4067 751683	VYACHESLAV FROLOV	{"phone": "+70656165298"}
0005432881117	9CDCD8	0261 582202	NADEZHDA BORISOVA	{"email": "n.borisova_1979@postgrespro.ru", "phone": "+70293037467"}
0005432881118	D93C27	2186 796720	RUSLAN NIKITIN	{"phone": "+70397686092"}
0005432881119	412A32	7753 274541	VIKTOR MELNIKOV	{"email": "melnikov-v-1962@postgrespro.ru", "phone": "+70248172829"}
0005432881120	2397BB	6926 114161	MARIYA GUSEVA	{"phone": "+70351278409"}
0005432881121	2397BB	3429 070992	ANNA GERASIMOVA	{"phone": "+70528134610"}
0005432881122	6BD9A7	2895 858852	MARIYA SOROKINA	{"phone": "+70552148731"}
0005432881123	9BAB2D	9525 598415	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir.29121967@postgrespro.ru", "phone": "+70900980533"}
0005432881124	F3C653	1225 704581	LYUBOV SEMENOVA	{"phone": "+70551748127"}
0005432881125	F3C653	3299 406024	FAIL ZHUKOV	{"phone": "+70895914499"}
0005432881127	AEE4DC	9099 160812	NADEZHDA MOROZOVA	{"email": "morozovan.04101979@postgrespro.ru", "phone": "+70039839493"}
0005432881128	AEE4DC	2672 234573	YULIYA KUZNECOVA	{"email": "y.kuznecova-18011975@postgrespro.ru", "phone": "+70805418677"}
0005432881129	A6A514	6050 253178	ALEKSEY FEDOROV	{"email": "aleksey_fedorov_17011976@postgrespro.ru", "phone": "+70347259571"}
0005432881130	1A6DAC	2233 354082	LILIYA NIKITINA	{"email": "nikitina-liliya_011972@postgrespro.ru", "phone": "+70089276941"}
0005432881131	D9AB48	4758 574889	IGOR AFANASEV	{"phone": "+70689293511"}
0005432881132	70858A	1083 435765	TATYANA IVANOVA	{"phone": "+70751169581"}
0005432881133	916553	5075 628003	LEONID VOROBEV	{"email": "l-vorobev_061961@postgrespro.ru", "phone": "+70356016717"}
0005432881134	CD4BA0	4747 178367	VLADIMIR SOKOLOV	{"email": "sokolov-vladimir_1960@postgrespro.ru", "phone": "+70192414251"}
0005432881135	5397BD	6036 349293	VALENTINA IVANOVA	{"email": "valentina_ivanova-1975@postgrespro.ru", "phone": "+70042648623"}
0005432881136	5397BD	6957 555479	OLGA YAKOVLEVA	{"phone": "+70553109360"}
0005432881137	B0A67D	5387 848317	ALEKSEY SOKOLOV	{"email": "asokolov071969@postgrespro.ru", "phone": "+70586753306"}
0005432881138	745D7E	2815 255894	ALEKSANDRA FROLOVA	{"phone": "+70947875961"}
0005432881139	523F67	9081 597143	OLGA PAVLOVA	{"phone": "+70779014733"}
0005432881140	F2D0FF	5290 028278	TATYANA ERMAKOVA	{"email": "tatyana.ermakova1978@postgrespro.ru", "phone": "+70558292273"}
0005432881141	F2D0FF	7589 980162	ZOYA SOKOLOVA	{"email": "sokolova-z-111980@postgrespro.ru", "phone": "+70519392999"}
0005432881142	9BA0C1	6966 086891	EVGENIY MAKAROV	{"phone": "+70550978097"}
0005432881143	D69FCC	1217 373682	EKATERINA VOLKOVA	{"email": "ekaterinavolkova.081967@postgrespro.ru", "phone": "+70343121787"}
0005432881144	D69FCC	5465 496502	VLADIMIR FEDOROV	{"phone": "+70960475966"}
0005432881145	40974E	5188 913120	VALENTIN SHEVCHENKO	{"phone": "+70815028617"}
0005432881146	44278F	6211 385722	ALEKSEY SHEVCHENKO	{"phone": "+70510746971"}
0005432881147	78947F	4691 610995	OLEG IVANOV	{"phone": "+70028846981"}
0005432881150	D0F0B9	5992 261166	VLADISLAV VOLKOV	{"phone": "+70791945679"}
0005432881151	27FEF8	1254 112550	ANTONINA DANILOVA	{"phone": "+70632425869"}
0005432881152	1BF896	7063 677852	ALEKSANDRA YUDINA	{"email": "a-yudina071971@postgrespro.ru", "phone": "+70862801555"}
0005432881153	AED7ED	6015 784277	NIKOLAY MAKSIMOV	{"email": "n-maksimov_011969@postgrespro.ru", "phone": "+70337581533"}
0005432881154	F973BB	7182 316592	ANDREY SOLOVEV	{"email": "asolovev_1968@postgrespro.ru", "phone": "+70832937808"}
0005432881155	A81B0F	1741 205628	OLGA GUSEVA	{"phone": "+70234663245"}
0005432881156	5F2F0E	3417 073869	LILIYA KOLESNIKOVA	{"email": "liliya.kolesnikova071962@postgrespro.ru", "phone": "+70516607563"}
0005432881157	68D066	8753 488180	SOFYA NIKOLAEVA	{"email": "sofyanikolaeva-14021973@postgrespro.ru", "phone": "+70016626878"}
0005432881158	AA77C8	8122 854414	ANNA TIMOFEEVA	{"phone": "+70510317093"}
0005432881159	CCCF23	4555 275980	NIKOLAY DENISOV	{"email": "denisovn.091970@postgrespro.ru", "phone": "+70614734672"}
0005432881160	2C5570	4472 623874	INNA KUZNECOVA	{"email": "kuznecova_i_1970@postgrespro.ru", "phone": "+70592352458"}
0005432881161	80DB8C	0018 883410	VITALIY ZAYCEV	{"email": "v-zaycev_08031966@postgrespro.ru", "phone": "+70428446302"}
0005432881162	80DB8C	3368 458465	NATALYA ANISIMOVA	{"email": "natalya-anisimova-30121970@postgrespro.ru", "phone": "+70013915792"}
0005432881163	BCF12A	2786 703857	EKATERINA KRASNOVA	{"phone": "+70709059942"}
0005432881164	D0458E	0369 182962	IGOR MARTYNOV	{"phone": "+70100446054"}
0005432881165	A03A70	4127 995960	NINA SERGEEVA	{"phone": "+70258596597"}
0005432881166	37E464	8703 267145	SERGEY IVANOV	{"email": "sergeyivanov-041963@postgrespro.ru", "phone": "+70985868687"}
0005432881167	433403	7597 113870	ANASTASIYA MELNIKOVA	{"phone": "+70875396720"}
0005432881168	01B78F	8470 781147	SERGEY MIRONOV	{"email": "s.mironov-1969@postgrespro.ru", "phone": "+70225363697"}
0005432881169	01B78F	0003 727094	NIKOLAY FEDOROV	{"email": "fedorov_nikolay11081958@postgrespro.ru", "phone": "+70690082696"}
0005432881170	43E1DA	0998 292085	OLGA MELNIKOVA	{"phone": "+70440653790"}
0005432881171	A4DF58	1265 356235	EVGENIY KOZLOV	{"phone": "+70658278715"}
0005432881172	845D44	3815 838700	VALENTINA VOLKOVA	{"email": "volkova_valentina071973@postgrespro.ru", "phone": "+70883106452"}
0005432881173	511290	0255 169735	NAIL KUZNECOV	{"phone": "+70555588995"}
0005432881174	45D575	3858 596137	IVAN KUDRYASHOV	{"phone": "+70757369447"}
0005432881175	B21B13	7475 723865	NIKOLAY SOLOVEV	{"phone": "+70683014965"}
0005432881176	AF5C49	2866 997046	NINA KISELEVA	{"email": "n.kiseleva_03091969@postgrespro.ru", "phone": "+70052936142"}
0005432881177	AF5C49	2947 963156	LEONID PETROV	{"email": "leonid-petrov101963@postgrespro.ru", "phone": "+70215773589"}
0005432881178	3B3DAA	1484 313119	RAIL VASILEV	{"email": "rail_vasilev04021967@postgrespro.ru", "phone": "+70020828006"}
0005432881179	2A8331	6948 019686	ALEKSEY BONDARENKO	{"phone": "+70729205640"}
0005432881180	2BE5F1	2910 676635	ELENA ZHUKOVA	{"email": "elena-zhukova26011980@postgrespro.ru", "phone": "+70825616415"}
0005432881181	2BE5F1	7810 912166	IVAN ALEKSANDROV	{"email": "ivanaleksandrov.1986@postgrespro.ru", "phone": "+70792475571"}
0005432881182	72B065	9780 108571	ANDREY NIKITIN	{"email": "nikitin-a-08091966@postgrespro.ru", "phone": "+70281738411"}
0005432881184	8D56A2	5452 333602	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr18021972@postgrespro.ru", "phone": "+70729298150"}
0005432881185	8D56A2	9228 720133	VALENTINA BARANOVA	{"email": "v-baranova041982@postgrespro.ru", "phone": "+70601104711"}
0005432881186	91F8A5	2490 350609	SERGEY KULIKOV	{"phone": "+70806053434"}
0005432881187	91F8A5	9466 389638	PAVEL AFANASEV	{"email": "p.afanasev-28061969@postgrespro.ru", "phone": "+70185621137"}
0005432881188	F63871	3991 560667	NATALYA SOROKINA	{"phone": "+70950945477"}
0005432881189	F63871	3374 780340	DARYA MASLOVA	{"phone": "+70568770723"}
0005432881190	F63871	5844 721147	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir_071978@postgrespro.ru", "phone": "+70585016977"}
0005432881191	3D1437	5974 869132	VERONIKA SAVELEVA	{"phone": "+70811851536"}
0005432881192	D050E6	1706 038549	EVGENIY RODIONOV	{"email": "e-rodionov.1973@postgrespro.ru", "phone": "+70259912819"}
0005432881193	D050E6	1066 205957	VALENTINA TARASOVA	{"phone": "+70894945360"}
0005432881194	8435FD	0950 031373	RUSTAM PETROV	{"phone": "+70505263654"}
0005432881195	8EC6AE	1971 285405	NATALYA MIRONOVA	{"phone": "+70940713418"}
0005432881196	8EC6AE	5224 020762	MAKAR KULIKOV	{"email": "kulikov-makar.031987@postgrespro.ru", "phone": "+70441224568"}
0005432881197	CEC8E8	0984 922965	ANTONINA FROLOVA	{"email": "a.frolova-1966@postgrespro.ru", "phone": "+70592752514"}
0005432881198	599FCF	4331 415893	VYACHESLAV KRASNOV	{"email": "vkrasnov071975@postgrespro.ru", "phone": "+70897567125"}
0005432881199	94E5FB	6705 376528	GALINA SMIRNOVA	{"phone": "+70287386981"}
0005432881200	A6BBBF	1961 722975	SVETLANA MAKAROVA	{"email": "makarova-s1964@postgrespro.ru", "phone": "+70412675840"}
0005432881201	D8D0E4	4765 018201	MARIYA ZAKHAROVA	{"email": "zakharova.m1973@postgrespro.ru", "phone": "+70276120397"}
0005432881202	AD531F	7972 345805	ALEKSEY KARPOV	{"phone": "+70188977717"}
0005432881203	29D782	5231 216539	OLGA POPOVA	{"email": "olgapopova1969@postgrespro.ru", "phone": "+70389878750"}
0005432881204	7B3BBD	8275 189315	EVGENIYA FILATOVA	{"email": "efilatova_061965@postgrespro.ru", "phone": "+70111091996"}
0005432881205	7B3BBD	0111 507160	MARYAM KONDRATEVA	{"email": "kondrateva_m.1976@postgrespro.ru", "phone": "+70984001752"}
0005432881206	2E0B65	8129 944640	NIKOLAY MOROZOV	{"email": "morozov-n-1972@postgrespro.ru", "phone": "+70117860703"}
0005432881207	2E0B65	4527 346017	NADEZHDA KUZNECOVA	{"email": "kuznecovan1973@postgrespro.ru", "phone": "+70724372478"}
0005432881208	3CE8F7	8261 306399	YURIY PETROV	{"phone": "+70332816492"}
0005432881209	349C29	1319 773523	VALENTINA BOGDANOVA	{"email": "bogdanovav_1972@postgrespro.ru", "phone": "+70441449107"}
0005432881210	BCF953	1629 923469	ALEKSANDR DMITRIEV	{"email": "a-dmitriev081960@postgrespro.ru", "phone": "+70377331605"}
0005432881211	4FACFE	2251 824558	TATYANA ILINA	{"email": "t_ilina-07011966@postgrespro.ru", "phone": "+70251315581"}
0005432881212	7B06CC	3834 451261	VLADIMIR BELOV	{"email": "vladimirbelov.28071973@postgrespro.ru", "phone": "+70249260859"}
0005432881213	64E5AB	1593 490906	IGOR FEDOTOV	{"phone": "+70265697065"}
0005432881214	6CBAFE	8772 291387	MARGARITA KOZLOVA	{"email": "mkozlova.1963@postgrespro.ru", "phone": "+70774722552"}
0005432881215	86652E	5857 547647	ALEKSANDR NOVIKOV	{"email": "a-novikov-1971@postgrespro.ru", "phone": "+70731805730"}
0005432881216	CB0E3D	7211 196260	ALEKSEY GAVRILOV	{"phone": "+70314629651"}
0005432881217	E77624	2230 170836	TAMARA RODIONOVA	{"email": "rodionova-t-081975@postgrespro.ru", "phone": "+70612140860"}
0005432881218	F550E1	1154 533172	GALINA GORBUNOVA	{"phone": "+70281361617"}
0005432881219	78C0EB	3289 439355	OLEG KISELEV	{"phone": "+70186279110"}
0005432881220	78C0EB	9799 572279	NATALYA DANILOVA	{"email": "danilova-natalya_1966@postgrespro.ru", "phone": "+70072055570"}
0005432881221	9802D5	5649 736641	DMITRIY KRASNOV	{"email": "krasnov-dmitriy.1972@postgrespro.ru", "phone": "+70081940875"}
0005432881222	ACE153	6912 616868	RAISA DAVYDOVA	{"email": "r-davydova.15101974@postgrespro.ru", "phone": "+70632761154"}
0005432881223	BF60FD	1800 113320	OLGA IVANOVA	{"email": "ivanovao071978@postgrespro.ru", "phone": "+70549386665"}
0005432881224	1EB68A	4067 854728	VALERIY VLASOV	{"email": "v_vlasov.061976@postgrespro.ru", "phone": "+70160082652"}
0005432881225	1EB68A	9999 057974	PAVEL SCHERBAKOV	{"email": "pavel_scherbakov25121973@postgrespro.ru", "phone": "+70878384485"}
0005432881226	DD8AF0	6096 095212	VIKTOR NIKITIN	{"phone": "+70686760836"}
0005432881227	9B7033	5427 596619	OLGA ABRAMOVA	{"phone": "+70708793934"}
0005432881228	9B7033	2973 800658	MARIYA BELOVA	{"email": "mariya.belova-02061972@postgrespro.ru", "phone": "+70952791226"}
0005432881229	575490	6155 537838	ALEKSANDR ABRAMOV	{"phone": "+70352272748"}
0005432881230	9E6D51	0708 980152	LIDIYA POTAPOVA	{"email": "potapova_l_1972@postgrespro.ru", "phone": "+70708461773"}
0005432881231	9E6D51	5996 372498	SVETLANA IVANOVA	{"email": "svetlana-ivanova.15121974@postgrespro.ru", "phone": "+70839152083"}
0005432881232	256955	8216 757265	RUSLAN VASILEV	{"email": "r-vasilev.051968@postgrespro.ru", "phone": "+70611882156"}
0005432881233	256955	9644 675898	SVETLANA YUDINA	{"email": "yudinas-1961@postgrespro.ru", "phone": "+70075361992"}
0005432881234	256955	1160 208633	DENIS KAZAKOV	{"email": "deniskazakov-1971@postgrespro.ru", "phone": "+70140727548"}
0005432881235	CFE710	1582 143787	VIKTOR CHERNOV	{"email": "v_chernov.1962@postgrespro.ru", "phone": "+70234664018"}
0005432881236	CFE710	3872 864883	GULNARA GAVRILOVA	{"email": "g.gavrilova.1969@postgrespro.ru", "phone": "+70741903142"}
0005432881237	CE2647	3257 166289	SERGEY MAKAROV	{"email": "s.makarov_30071965@postgrespro.ru", "phone": "+70001056462"}
0005432881238	D0CE97	2756 969146	TATYANA FADEEVA	{"email": "t_fadeeva-061976@postgrespro.ru", "phone": "+70587005683"}
0005432881239	D0CE97	9967 229135	FARIDA MAKAROVA	{"email": "makarovafarida04121966@postgrespro.ru", "phone": "+70900239720"}
0005432881240	7C796B	3771 323495	GENNADIY SMIRNOV	{"phone": "+70047944663"}
0005432881241	2060DC	1798 843846	SERGEY GUSEV	{"phone": "+70817587426"}
0005432881242	2060DC	7200 889584	LYUBOV VOLKOVA	{"email": "volkova-l26061975@postgrespro.ru", "phone": "+70162826558"}
0005432881243	00CBA0	3292 545243	RAISA DMITRIEVA	{"email": "rdmitrieva-1979@postgrespro.ru", "phone": "+70260032270"}
0005432881244	00CBA0	1285 465732	NATALYA LAZAREVA	{"phone": "+70890259953"}
0005432881245	707FD3	4941 011644	OLEG MAKSIMOV	{"email": "maksimov-oleg1986@postgrespro.ru", "phone": "+70553825398"}
0005432881246	53E188	1644 127515	ZHANNA ROMANOVA	{"phone": "+70115538937"}
0005432881247	53E188	9018 615176	EKATERINA MIRONOVA	{"phone": "+70673446441"}
0005432881248	53E188	5177 921263	SVETLANA NESTEROVA	{"email": "svetlananesterova.111971@postgrespro.ru", "phone": "+70721881500"}
0005432881249	6C9E85	4909 147989	LYUBOV DMITRIEVA	{"email": "lyubov.dmitrieva_041980@postgrespro.ru", "phone": "+70787095209"}
0005432890709	23E08E	2330 674086	RUSLAN NIKITIN	{"phone": "+70161794142"}
0005432890669	6B245A	4268 065558	VERA DMITRIEVA	{"email": "veradmitrieva1967@postgrespro.ru", "phone": "+70644437266"}
0005432890670	C3502E	5822 826008	TATYANA ROMANOVA	{"phone": "+70294239592"}
0005432890671	C3502E	3117 897080	ALEKSANDR KUZNECOV	{"phone": "+70836997229"}
0005432890672	A27474	7243 152420	DMITRIY DENISOV	{"phone": "+70386553297"}
0005432890673	D11C26	5267 126473	ANNA BORISOVA	{"phone": "+70871085104"}
0005432890674	008C12	8093 262052	SERGEY POPOV	{"email": "s-popov_1974@postgrespro.ru", "phone": "+70261709286"}
0005432890675	008C12	9072 919306	IGOR SOROKIN	{"email": "igorsorokin-12061982@postgrespro.ru", "phone": "+70461516492"}
0005432890676	9B926D	0755 723876	TATYANA PETROVA	{"phone": "+70912326020"}
0005432890677	9B926D	3965 506932	KSENIYA LOGINOVA	{"email": "loginova_k.18111976@postgrespro.ru", "phone": "+70527737949"}
0005432890678	9B926D	5769 250685	GRIGORIY SOROKIN	{"phone": "+70523140714"}
0005432890679	A91EA2	7698 039608	NATALYA KONOVALOVA	{"phone": "+70535561174"}
0005432890680	A91EA2	5971 520036	YURIY POPOV	{"email": "y_popov_1970@postgrespro.ru", "phone": "+70818965923"}
0005432890681	3E7CC7	9262 844381	LILIYA SOKOLOVA	{"phone": "+70837252699"}
0005432890682	13E5F4	4310 602571	ALBINA KAZAKOVA	{"phone": "+70717407904"}
0005432890683	13E5F4	5675 610270	TATYANA KUZNECOVA	{"phone": "+70561438193"}
0005432890684	847285	9910 512667	ELENA NAUMOVA	{"email": "e-naumova1965@postgrespro.ru", "phone": "+70008330270"}
0005432890685	E7BBE6	4917 240282	ANTON NOVIKOV	{"email": "novikov.a_071978@postgrespro.ru", "phone": "+70302809720"}
0005432890686	E26778	6484 537135	ELENA NIKOLAEVA	{"email": "nikolaeva_e-07111968@postgrespro.ru", "phone": "+70548980742"}
0005432890687	85027D	3708 952910	ANTON BARANOV	{"email": "a.baranov_061976@postgrespro.ru", "phone": "+70464707574"}
0005432890688	CFCE12	0780 560006	RAVILYA NESTEROVA	{"phone": "+70915537643"}
0005432890689	CFCE12	2505 592218	YURIY ILIN	{"phone": "+70687508991"}
0005432890690	9C261A	5947 617001	SVETLANA EFREMOVA	{"phone": "+70099283797"}
0005432890691	9C261A	7868 147190	SERGEY GRIGOREV	{"email": "grigorev.s.18071969@postgrespro.ru", "phone": "+70067899310"}
0005432890692	D78C5D	2058 166194	VASILIY MEDVEDEV	{"phone": "+70776063144"}
0005432890693	D78C5D	1067 737223	NATALYA MAKAROVA	{"email": "natalyamakarova_1968@postgrespro.ru", "phone": "+70845890983"}
0005432890694	6DB53E	4387 564248	VYACHESLAV PETROV	{"phone": "+70703137684"}
0005432890695	6D1E69	7738 749437	NATALYA TARASOVA	{"email": "n-tarasova111978@postgrespro.ru", "phone": "+70500091202"}
0005432890696	6D1E69	2329 684174	KLAVDIYA KARPOVA	{"email": "k.karpova-01111963@postgrespro.ru", "phone": "+70097372941"}
0005432890697	7FB141	3681 763418	VLADIMIR FEDOROV	{"phone": "+70945766735"}
0005432890698	A1AD0C	9439 668153	ANNA PETROVA	{"phone": "+70552202639"}
0005432890699	A1AD0C	2978 651785	GENNADIY KAZAKOV	{"phone": "+70843377002"}
0005432890700	135441	2182 549512	VERA NESTEROVA	{"email": "vera-nesterova031969@postgrespro.ru", "phone": "+70455904894"}
0005432890701	FDF629	7575 676099	YULIYA BELOVA	{"phone": "+70319499243"}
0005432890702	F9B291	6662 405131	IRINA KONOVALOVA	{"email": "konovalova.irina.1975@postgrespro.ru", "phone": "+70221394671"}
0005432890703	026565	0391 086684	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova.n24101979@postgrespro.ru", "phone": "+70555449192"}
0005432890704	5E0EDA	3638 650813	VALERIY IVANOV	{"email": "valeriy-ivanov-09111980@postgrespro.ru", "phone": "+70050332663"}
0005432890705	B78257	1084 792661	VLADIMIR BONDARENKO	{"email": "vladimir_bondarenko-14021971@postgrespro.ru", "phone": "+70946632760"}
0005432890706	B78257	7610 413312	ANASTASIYA POTAPOVA	{"email": "potapova-anastasiya.08051982@postgrespro.ru", "phone": "+70127656715"}
0005432890707	BE282F	0870 735286	ALEKSANDR YAKOVLEV	{"email": "aleksandryakovlev.031978@postgrespro.ru", "phone": "+70628730511"}
0005432890708	23E08E	6110 690966	NIKITA VASILEV	{"phone": "+70923342113"}
0005432890710	3DA783	6679 040517	VLADIMIR SOLOVEV	{"phone": "+70640318411"}
0005432890711	EC6E0F	7063 932036	DARYA KISELEVA	{"phone": "+70321844116"}
0005432890712	5D617E	5919 965212	RAISA KAZAKOVA	{"email": "raisa-kazakova-041979@postgrespro.ru", "phone": "+70733599900"}
0005432890713	80D6AA	7283 889751	NADEZHDA OSIPOVA	{"email": "osipova.n-1971@postgrespro.ru", "phone": "+70519056206"}
0005432890714	CFA1F3	6067 637451	OLGA MIKHAYLOVA	{"email": "mikhaylova-o.31121967@postgrespro.ru", "phone": "+70604591407"}
0005432890715	FF912B	3280 584950	EKATERINA GORBUNOVA	{"email": "e-gorbunova_081977@postgrespro.ru", "phone": "+70850177330"}
0005432890716	FA0A02	4942 443420	NATALYA NIKIFOROVA	{"email": "nikiforova-natalya-1969@postgrespro.ru", "phone": "+70834004132"}
0005432890717	7A8DAF	1392 009779	VALENTINA FILATOVA	{"email": "v.filatova-1976@postgrespro.ru", "phone": "+70685933575"}
0005432890718	7A8DAF	4370 339305	YURIY IVANOV	{"phone": "+70309751186"}
0005432890719	57D93D	4403 844808	YULIYA BORISOVA	{"email": "y.borisova_30091973@postgrespro.ru", "phone": "+70726354599"}
0005432890720	F25D2E	6954 546529	ELENA MALYSHEVA	{"email": "e_malysheva_1974@postgrespro.ru", "phone": "+70432268563"}
0005432890721	F25D2E	3803 093749	VLADIMIR TIKHONOV	{"email": "tikhonov.v09111964@postgrespro.ru", "phone": "+70209660050"}
0005432890722	F25D2E	6945 923473	NAILYA NAUMOVA	{"phone": "+70347401475"}
0005432890723	17A4B8	6779 773288	ELIZAVETA POPOVA	{"phone": "+70420506262"}
0005432890724	17A4B8	7614 487607	EKATERINA POTAPOVA	{"phone": "+70602016415"}
0005432890725	A4EB63	3846 783783	VLADIMIR BELOV	{"email": "v-belov-1966@postgrespro.ru", "phone": "+70244654424"}
0005432890726	A4EB63	3318 307635	LYUDMILA EGOROVA	{"phone": "+70199082163"}
0005432890727	A4EB63	1773 972966	NADEZHDA ARKHIPOVA	{"phone": "+70460683730"}
0005432890728	51214B	8450 645309	INESSA TROFIMOVA	{"phone": "+70386114926"}
0005432890729	EC3528	6500 941533	KONSTANTIN TIKHONOV	{"email": "ktikhonov-021976@postgrespro.ru", "phone": "+70424793776"}
0005432890730	639FDD	0580 233157	DMITRIY SMIRNOV	{"phone": "+70626090619"}
0005432890731	5E420A	8178 057129	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay-111976@postgrespro.ru", "phone": "+70711726951"}
0005432890732	679FB4	6613 766987	ELENA ORLOVA	{"phone": "+70162856438"}
0005432890733	E26888	9785 519696	ANATOLIY FEDOROV	{"phone": "+70950934398"}
0005432890734	5A513A	9987 057626	YURIY GORBUNOV	{"email": "gorbunov-y.11101966@postgrespro.ru", "phone": "+70517640719"}
0005432890735	4F9634	9582 119446	VLADIMIR SERGEEV	{"phone": "+70611314610"}
0005432890736	4F9634	8283 289078	ANDREY MIKHAYLOV	{"email": "mikhaylovandrey_021974@postgrespro.ru", "phone": "+70362075047"}
0005432890737	187782	9803 577264	LYUBOV NESTEROVA	{"phone": "+70854933745"}
0005432890738	013B57	3896 560789	EKATERINA GAVRILOVA	{"email": "gavrilovaekaterina.31101975@postgrespro.ru", "phone": "+70940881518"}
0005432890739	013B57	1500 328199	MARIYA GERASIMOVA	{"email": "m.gerasimova1977@postgrespro.ru", "phone": "+70837718883"}
0005432890740	599D26	6120 478293	ALEKSANDR FROLOV	{"email": "aleksandr_frolov19041959@postgrespro.ru", "phone": "+70555450858"}
0005432890741	2D63A2	7724 058939	VALERIY KUDRYASHOV	{"email": "kudryashov_v.1989@postgrespro.ru", "phone": "+70902091737"}
0005432890742	2D63A2	0803 188695	ILYA ALEKSEEV	{"email": "ilyaalekseev_16071961@postgrespro.ru", "phone": "+70577464344"}
0005432890855	CE045C	0023 370948	ALENA SCHERBAKOVA	{"phone": "+70958658734"}
0005432890743	55D47D	8859 148099	OKSANA NIKITINA	{"email": "nikitina-o_24061962@postgrespro.ru", "phone": "+70371546869"}
0005432890744	0379BD	7262 751922	IRINA IVANOVA	{"phone": "+70672344728"}
0005432890745	0379BD	9415 379716	OLGA MIKHAYLOVA	{"email": "mikhaylovao.03011981@postgrespro.ru", "phone": "+70005063974"}
0005432890746	87DCC0	2943 212022	EGOR SOROKIN	{"email": "sorokin_egor.22021971@postgrespro.ru", "phone": "+70078300091"}
0005432890747	AF3817	3275 447822	ROMAN ZAKHAROV	{"phone": "+70501860239"}
0005432890748	A15469	4978 800775	TATYANA CHERNOVA	{"email": "chernova-t_011970@postgrespro.ru", "phone": "+70221072861"}
0005432890749	B27DC3	9810 780785	ANNA OSIPOVA	{"email": "anna_osipova_06121983@postgrespro.ru", "phone": "+70593489080"}
0005432890750	B27DC3	5701 569415	SERGEY SERGEEV	{"email": "s.sergeev.041979@postgrespro.ru", "phone": "+70690780546"}
0005432890751	AD1509	7382 576422	ALEKSEY KUZNECOV	{"email": "a_kuznecov1961@postgrespro.ru", "phone": "+70896933611"}
0005432890752	AD1509	6871 564876	ELZA NIKOLAEVA	{"phone": "+70901398660"}
0005432890753	B28566	1447 090797	PETR DENISOV	{"email": "denisovp_1974@postgrespro.ru", "phone": "+70137086393"}
0005432890754	B28566	5055 648418	ANDREY KONOVALOV	{"email": "andrey.konovalov-071973@postgrespro.ru", "phone": "+70315193805"}
0005432890755	0D21A9	0089 892292	DARYA GERASIMOVA	{"email": "d_gerasimova.1969@postgrespro.ru", "phone": "+70743885493"}
0005432890756	0D21A9	4330 033728	ELENA POPOVA	{"email": "popova.e_051960@postgrespro.ru", "phone": "+70521992758"}
0005432890757	1CBC9E	4783 227417	NATALYA ZAYCEVA	{"email": "nzayceva_1969@postgrespro.ru", "phone": "+70748152912"}
0005432890758	1CBC9E	7296 693436	YURIY KUZMIN	{"phone": "+70849022844"}
0005432890759	E63EB3	7603 044563	ANDREY KUZNECOV	{"email": "andrey_kuznecov-24061983@postgrespro.ru", "phone": "+70459422837"}
0005432890760	5AAD74	2687 494808	GENNADIY EGOROV	{"phone": "+70798580761"}
0005432890761	5AAD74	7569 113757	SERAFIMA MATVEEVA	{"email": "serafima_matveeva_1968@postgrespro.ru", "phone": "+70495081750"}
0005432890762	180CF6	2993 502642	GALINA MASLOVA	{"phone": "+70870949319"}
0005432890763	A424EF	0207 265692	LYUBOV SEMENOVA	{"email": "semenovalyubov.1976@postgrespro.ru", "phone": "+70865385271"}
0005432890764	1985C2	3162 202047	RAISA ZHUKOVA	{"phone": "+70069241558"}
0005432890765	F50746	8776 131594	NIKOLAY ROMANOV	{"phone": "+70967699431"}
0005432890766	7E6054	0252 320675	ALEKSEY ABRAMOV	{"phone": "+70240246605"}
0005432890767	7E6054	6083 178275	VLADISLAV OSIPOV	{"email": "vladislavosipov-021977@postgrespro.ru", "phone": "+70614945830"}
0005432890768	CCDF54	5045 203037	MIKHAIL PAVLOV	{"phone": "+70931208593"}
0005432890831	80EB96	5865 724862	TATYANA RODIONOVA	{"phone": "+70073600849"}
0005432890769	DD7B96	4707 862439	NIKOLAY ZHURAVLEV	{"email": "nikolay_zhuravlev.1974@postgrespro.ru", "phone": "+70175498759"}
0005432890770	B3AB69	5607 235168	GALINA GORBUNOVA	{"phone": "+70299339609"}
0005432890771	91FEBB	6037 550575	ELENA KONOVALOVA	{"phone": "+70864041495"}
0005432890772	91FEBB	5634 715533	IGOR ALEKSANDROV	{"phone": "+70065457738"}
0005432890773	A84D00	7407 574295	NATALIYA TARASOVA	{"phone": "+70197164052"}
0005432890774	A84D00	0053 824284	YURIY OSIPOV	{"email": "osipov-y_19101978@postgrespro.ru", "phone": "+70622137281"}
0005432890775	94779D	9660 068674	NATALYA ANDREEVA	{"phone": "+70352914959"}
0005432890776	FA6984	4831 126907	DMITRIY BONDARENKO	{"email": "bondarenko.dmitriy-061977@postgrespro.ru", "phone": "+70235530417"}
0005432890777	9A1F02	2833 381233	TATYANA ANTONOVA	{"phone": "+70611392851"}
0005432890778	9A1F02	5018 832969	DMITRIY PETROV	{"phone": "+70715526359"}
0005432890779	395B5A	4100 336852	IRINA KOROLEVA	{"email": "i.koroleva111979@postgrespro.ru", "phone": "+70102381330"}
0005432890780	395B5A	2919 665279	VERA ROMANOVA	{"phone": "+70778486456"}
0005432890781	32362C	3193 923482	GALINA DANILOVA	{"phone": "+70715454454"}
0005432890782	32362C	8081 819895	INNA KISELEVA	{"email": "innakiseleva.011969@postgrespro.ru", "phone": "+70164120734"}
0005432890783	32362C	8979 715517	IGOR ANDREEV	{"phone": "+70311702867"}
0005432890784	229F58	3852 004049	NADEZHDA KOROLEVA	{"phone": "+70551120016"}
0005432890785	229F58	6030 194535	ANDREY IVANOV	{"phone": "+70844203015"}
0005432890786	182107	7242 402242	DENIS NOVIKOV	{"phone": "+70505802045"}
0005432890787	820DEB	0735 462400	SERGEY IVANOV	{"phone": "+70074300221"}
0005432890788	1CB645	2004 189723	SERGEY KOZLOV	{"email": "s.kozlov_14091974@postgrespro.ru", "phone": "+70587207291"}
0005432890789	84CDDB	8213 072430	SERGEY KUZNECOV	{"phone": "+70115605756"}
0005432890790	84CDDB	2892 097583	SVETLANA KAZAKOVA	{"email": "kazakova.s1970@postgrespro.ru", "phone": "+70312858813"}
0005432890791	63F25F	0961 136084	GEORGIY KONOVALOV	{"email": "georgiy.konovalov11081979@postgrespro.ru", "phone": "+70186640272"}
0005432890792	384965	8096 052709	ANATOLIY VOLKOV	{"phone": "+70186967628"}
0005432890793	E18193	5954 467157	IGOR MAKAROV	{"email": "makarovi_27101968@postgrespro.ru", "phone": "+70702031967"}
0005432890794	E18193	2978 851873	ANDREY POPOV	{"email": "andreypopov.1970@postgrespro.ru", "phone": "+70955581919"}
0005432890795	C20242	1691 723316	ANGELINA BORISOVA	{"email": "a-borisova.061972@postgrespro.ru", "phone": "+70446703812"}
0005432890796	82B2D6	1742 472083	ALEKSANDR ILIN	{"phone": "+70502877137"}
0005432890797	DB0EBB	5049 285998	VERA ANTONOVA	{"email": "vera-antonova1973@postgrespro.ru", "phone": "+70044906539"}
0005432890798	0F8136	1813 451499	OKSANA NIKOLAEVA	{"email": "nikolaeva-o061958@postgrespro.ru", "phone": "+70503268245"}
0005432890799	9C2ECA	6656 573228	ROBERT MATVEEV	{"email": "robert.matveev_1967@postgrespro.ru", "phone": "+70060635240"}
0005432890800	4EF09F	7963 354989	IRINA DMITRIEVA	{"email": "dmitrieva_i061973@postgrespro.ru", "phone": "+70171577535"}
0005432890801	3B3BE1	7021 261315	LYUDMILA FEDOROVA	{"phone": "+70596298869"}
0005432890802	3B3BE1	3209 658890	KONSTANTIN BORISOV	{"email": "borisov_konstantin1985@postgrespro.ru", "phone": "+70184968660"}
0005432890803	84C710	2138 543957	ANASTASIYA SERGEEVA	{"phone": "+70908413103"}
0005432890804	84C710	4298 150801	TIMOFEY MAKSIMOV	{"phone": "+70190301919"}
0005432890805	52A146	9839 022633	OLEG PETROV	{"phone": "+70453629150"}
0005432890806	C07003	7577 946055	PAVEL KISELEV	{"phone": "+70505051630"}
0005432890807	C07003	8278 326141	IVAN ANDREEV	{"phone": "+70985958879"}
0005432890808	37F2DA	8021 210093	KONSTANTIN KOZLOV	{"email": "konstantin-kozlov_1973@postgrespro.ru", "phone": "+70961252000"}
0005432890809	E64E2E	3875 812574	ELENA FADEEVA	{"email": "e.fadeeva_1974@postgrespro.ru", "phone": "+70973054175"}
0005432890810	AD1D04	4585 031460	EVGENIYA ABRAMOVA	{"phone": "+70221530205"}
0005432890811	4D849D	5483 961063	TAMARA DMITRIEVA	{"email": "tamaradmitrieva1980@postgrespro.ru", "phone": "+70628392098"}
0005432890812	4D849D	2798 124193	RUSLAN BARANOV	{"phone": "+70677028425"}
0005432890813	96D39B	5270 650009	ARINA VOROBEVA	{"phone": "+70402945375"}
0005432890814	EC24E6	1775 215364	LYUDMILA SOLOVEVA	{"phone": "+70161759678"}
0005432890815	EC24E6	3194 630167	NATALYA BORISOVA	{"phone": "+70277096250"}
0005432890816	53C35A	5355 092542	SVETLANA DENISOVA	{"phone": "+70812587241"}
0005432890817	06E332	4376 048347	DENIS SOROKIN	{"phone": "+70044510077"}
0005432890818	6F9F8F	9749 444156	ALEKSANDR TIKHONOV	{"email": "a.tikhonov_021978@postgrespro.ru", "phone": "+70682418103"}
0005432890819	A14E69	1277 849461	OLGA EFIMOVA	{"email": "olgaefimova20011975@postgrespro.ru", "phone": "+70393565042"}
0005432890820	A14E69	4501 652267	EGOR KUDRYASHOV	{"email": "kudryashove121973@postgrespro.ru", "phone": "+70010979911"}
0005432890821	A14E69	0815 995789	SERGEY GRIGOREV	{"email": "s-grigorev041966@postgrespro.ru", "phone": "+70200050504"}
0005432890822	140509	0247 793074	SERGEY DAVYDOV	{"email": "davydov-s1969@postgrespro.ru", "phone": "+70702928381"}
0005432890823	140509	8739 404812	ZINAIDA VASILEVA	{"email": "vasilevazinaida081974@postgrespro.ru", "phone": "+70222495022"}
0005432890824	5B1C8E	1684 248156	VASILIY DAVYDOV	{"phone": "+70892964079"}
0005432890825	5B1C8E	5896 396508	ALEKSEY POPOV	{"email": "popov.aleksey.1981@postgrespro.ru", "phone": "+70176199483"}
0005432890826	92F194	6554 313904	EVGENIY IVANOV	{"phone": "+70714527396"}
0005432890827	9EEA72	3273 085532	EVGENIY MEDVEDEV	{"phone": "+70464535602"}
0005432890828	381423	3184 471811	SERGEY MIRONOV	{"phone": "+70917740976"}
0005432890829	C413E5	0115 982806	MIKHAIL NOVIKOV	{"phone": "+70666445991"}
0005432890830	98ED12	1836 850507	ILMIR BELOV	{"email": "i_belov.121988@postgrespro.ru", "phone": "+70970487201"}
0005432890832	80EB96	5098 767564	ALENA KONOVALOVA	{"phone": "+70877029451"}
0005432890833	3223EE	5779 035973	IGOR SMIRNOV	{"phone": "+70357294058"}
0005432890834	7E6737	7632 382728	ANTONINA NOVIKOVA	{"email": "a-novikova.061971@postgrespro.ru", "phone": "+70980270933"}
0005432890835	D6FCBA	3997 073804	OLGA FADEEVA	{"email": "fadeeva-olga.20021973@postgrespro.ru", "phone": "+70394604831"}
0005432890836	15F055	1555 869412	VERA KOVALEVA	{"email": "v-kovaleva_051981@postgrespro.ru", "phone": "+70102915016"}
0005432890837	C1CE00	4320 209242	ALEKSANDR IVANOV	{"phone": "+70803367902"}
0005432890838	C1CE00	2903 989701	ZOYA VOROBEVA	{"phone": "+70501421144"}
0005432890839	C1CE00	7489 845691	ANDREY IVANOV	{"email": "ivanova.10061969@postgrespro.ru", "phone": "+70412070575"}
0005432890840	671ED3	1957 907607	VERA RYABOVA	{"phone": "+70618112172"}
0005432890841	671ED3	1078 610942	VALERIY POPOV	{"email": "popov_v_1978@postgrespro.ru", "phone": "+70867896068"}
0005432890842	07FF3D	5248 452882	ANNA CHERNOVA	{"phone": "+70217519071"}
0005432890843	A4500C	3042 564619	VLADIMIR IVANOV	{"email": "ivanov.vladimir.101975@postgrespro.ru", "phone": "+70664154832"}
0005432890844	A4500C	0835 759698	ANATOLIY KISELEV	{"email": "kiselev-anatoliy-091978@postgrespro.ru", "phone": "+70430836522"}
0005432890845	A4500C	9495 783868	VASILIY ALEKSEEV	{"email": "alekseev-vasiliy02111971@postgrespro.ru", "phone": "+70479365519"}
0005432890846	DE4521	0332 212004	VLADIMIR KUZNECOV	{"email": "v.kuznecov-01081974@postgrespro.ru", "phone": "+70121997428"}
0005432890847	DE4521	5802 293489	SERGEY STEPANOV	{"email": "stepanovs-051971@postgrespro.ru", "phone": "+70343514636"}
0005432890848	C9326D	8356 492734	NIKOLAY POPOV	{"email": "nikolay_popov091974@postgrespro.ru", "phone": "+70515503430"}
0005432890849	F4DCF4	6884 182429	ALFIYA MELNIKOVA	{"phone": "+70170845575"}
0005432890850	44AD03	8332 108117	NINA MAKAROVA	{"email": "makarova.n1976@postgrespro.ru", "phone": "+70219253968"}
0005432890851	BECE04	2783 591313	ANTON VASILEV	{"email": "vasilevanton.021972@postgrespro.ru", "phone": "+70499223390"}
0005432890852	BECE04	5630 811807	SNEZHANA EGOROVA	{"email": "egorovas_101973@postgrespro.ru", "phone": "+70186335652"}
0005432890853	ED34D2	8715 775483	GALINA ERMAKOVA	{"email": "galinaermakova.1983@postgrespro.ru", "phone": "+70016093858"}
0005432890854	C331B5	8089 220815	DANIIL MATVEEV	{"phone": "+70652873388"}
0005432890856	8D6CC9	8798 945374	ELENA GRISHINA	{"email": "e.grishina_051965@postgrespro.ru", "phone": "+70773055311"}
0005432890857	8D6CC9	7604 493006	EKATERINA TIKHONOVA	{"phone": "+70460867709"}
0005432890858	F46248	9487 354546	DMITRIY MOISEEV	{"phone": "+70197213240"}
0005432890859	F46248	4722 492856	MARIYA KUZNECOVA	{"email": "kuznecova-mariya-1979@postgrespro.ru", "phone": "+70411100888"}
0005432890860	7DA7C8	8587 069891	DMITRIY VASILEV	{"phone": "+70256986105"}
0005432890861	94B755	8559 971864	OLGA NOVIKOVA	{"phone": "+70521073731"}
0005432890862	FE495B	7377 887707	VASILIY PETROV	{"email": "petrov.v_28051968@postgrespro.ru", "phone": "+70619303942"}
0005432890863	852CA4	2954 078562	OLGA MAKSIMOVA	{"email": "maksimova_olga021961@postgrespro.ru", "phone": "+70458768520"}
0005432890864	C81B7B	4437 932524	NIKOLAY NOVIKOV	{"email": "n-novikov-1968@postgrespro.ru", "phone": "+70933847417"}
0005432890865	C81B7B	8110 721917	DMITRIY KUZNECOV	{"phone": "+70420720820"}
0005432890866	97777D	1855 816055	MARIYA SOLOVEVA	{"phone": "+70813544366"}
0005432890867	97777D	4173 892386	SERGEY PETROV	{"email": "sergey-petrov.1991@postgrespro.ru", "phone": "+70441311699"}
0005432890868	A02961	0506 392288	YULIYA FILIPPOVA	{"email": "filippova-yuliya1960@postgrespro.ru", "phone": "+70144794190"}
0005432890869	A02961	7497 800359	EVGENIY FEDOROV	{"phone": "+70389827788"}
0005432890870	98F963	9836 079851	YURIY ANDREEV	{"phone": "+70057212781"}
0005432890871	842A15	1997 002331	VIKTOR FEDOROV	{"email": "viktor-fedorov_1958@postgrespro.ru", "phone": "+70899003455"}
0005432890872	842A15	5089 006771	NINA MOISEEVA	{"phone": "+70257740903"}
0005432890873	B6357C	3710 683502	VITALIY SHEVCHENKO	{"phone": "+70086743878"}
0005432890874	FE513F	7357 833815	VALERIY VOLKOV	{"phone": "+70434763356"}
0005432890875	9E6F2E	4754 688240	MAKSIM MELNIKOV	{"email": "m_melnikov.051965@postgrespro.ru", "phone": "+70438589838"}
0005432890876	9E6F2E	2350 583911	KSENIYA LOGINOVA	{"phone": "+70002489456"}
0005432890877	80195D	0681 958945	SVETLANA PAVLOVA	{"phone": "+70298252695"}
0005432890878	897C25	7449 474328	ZARINA FADEEVA	{"phone": "+70135493166"}
0005432890879	897C25	9115 555006	ELENA STEPANOVA	{"email": "stepanova.e-071981@postgrespro.ru", "phone": "+70319356513"}
0005432890880	1AB099	2903 219245	NINA MAKAROVA	{"phone": "+70189996421"}
0005432890881	ECEA42	5419 979248	VLADIMIR FEDOROV	{"email": "fedorov-v-21121955@postgrespro.ru", "phone": "+70310664902"}
0005432890882	85B741	3949 898654	GALINA POPOVA	{"phone": "+70006375044"}
0005432890883	7F7B99	6820 233334	ANASTASIYA MELNIKOVA	{"email": "a_melnikova.22071978@postgrespro.ru", "phone": "+70409676927"}
0005432890884	3203CD	8500 915840	ALENA MATVEEVA	{"email": "matveevaalena_09041967@postgrespro.ru", "phone": "+70845943344"}
0005432890885	49D891	9458 252372	VALENTINA IVANOVA	{"email": "ivanova-v-12051965@postgrespro.ru", "phone": "+70571242379"}
0005432890886	49D891	4809 864313	SERGEY PETROV	{"email": "spetrov-091977@postgrespro.ru", "phone": "+70017049537"}
0005432890887	85DDEA	0928 319439	LYUBOV IVANOVA	{"phone": "+70379359895"}
0005432890888	85DDEA	2835 824266	MAKSIM NOVIKOV	{"email": "m_novikov121974@postgrespro.ru", "phone": "+70127946418"}
0005432890889	A9E013	1613 568301	ANNA POPOVA	{"email": "anna.popova1969@postgrespro.ru", "phone": "+70178759273"}
0005432890890	5C4752	8880 833449	RUSLAN MOISEEV	{"email": "r-moiseev.1976@postgrespro.ru", "phone": "+70472849667"}
0005432890891	5C4752	6232 623194	LYUBOV NIKITINA	{"email": "nikitina.lyubov-011974@postgrespro.ru", "phone": "+70444979796"}
0005432890952	85B7A4	3444 557577	EVDOKIYA PAVLOVA	{"phone": "+70101103228"}
0005432890892	C68081	3991 254591	DARYA POTAPOVA	{"email": "potapovad_071976@postgrespro.ru", "phone": "+70367277659"}
0005432890893	6BA3B4	6978 203436	ALEKSANDR GERASIMOV	{"phone": "+70583494063"}
0005432890894	A43154	2552 370514	SERGEY KONOVALOV	{"email": "skonovalov1970@postgrespro.ru", "phone": "+70052374077"}
0005432890895	172B0D	5605 521456	PETR ANDREEV	{"phone": "+70628487107"}
0005432890896	172B0D	3930 036301	NINA GERASIMOVA	{"phone": "+70078768022"}
0005432890897	E95A32	1973 630570	ALEKSANDR BELOV	{"phone": "+70412736446"}
0005432890898	41F5FA	1703 157726	SERGEY STEPANOV	{"phone": "+70404352008"}
0005432890899	1D716E	3705 219925	ANDREY FILIPPOV	{"phone": "+70539700488"}
0005432890900	1D716E	1918 839114	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr1960@postgrespro.ru", "phone": "+70791180058"}
0005432890901	61485F	9785 144252	ALENA KUZMINA	{"email": "kuzmina.alena.1973@postgrespro.ru", "phone": "+70494242976"}
0005432890902	61485F	3941 734673	ROMAN EGOROV	{"email": "egorovroman19051980@postgrespro.ru", "phone": "+70744892627"}
0005432890903	C0690F	1216 198542	YULIYA SEMENOVA	{"phone": "+70523824433"}
0005432890904	9257F0	7375 968466	ALEKSANDR VLASOV	{"email": "a-vlasov_09071962@postgrespro.ru", "phone": "+70050127330"}
0005432890905	3A690B	4181 315445	LIDIYA SOROKINA	{"email": "lidiya.sorokina-1976@postgrespro.ru", "phone": "+70932680144"}
0005432890906	3A690B	1148 003414	MARINA ANISIMOVA	{"email": "anisimova-m_1964@postgrespro.ru", "phone": "+70263874114"}
0005432890907	3A690B	0798 944687	ANDREY PAVLOV	{"phone": "+70525101294"}
0005432890908	BDAFC7	6740 833239	VLADIMIR SIDOROV	{"phone": "+70701460565"}
0005432890909	D98516	6381 292984	ALEKSANDR RODIONOV	{"phone": "+70212009313"}
0005432890910	49327F	3164 681689	EKATERINA MELNIKOVA	{"phone": "+70507296851"}
0005432890911	B16C5A	6524 028871	ANTONINA VASILEVA	{"phone": "+70926988269"}
0005432890912	B8EBBC	8696 893683	VLADIMIR SEMENOV	{"phone": "+70079394093"}
0005432890913	12C674	9214 046579	NINA MARTYNOVA	{"phone": "+70739836297"}
0005432890914	12C674	0457 396032	IVAN TIKHONOV	{"email": "ivan_tikhonov-021961@postgrespro.ru", "phone": "+70743421496"}
0005432890915	EC9630	6434 401124	KONSTANTIN KAZAKOV	{"phone": "+70250499238"}
0005432890916	8A24D4	3015 039993	VLADIMIR MATVEEV	{"email": "v.matveev.18041970@postgrespro.ru", "phone": "+70170724997"}
0005432890917	8A24D4	1523 426525	SVETLANA ROMANOVA	{"email": "romanova.svetlana_1965@postgrespro.ru", "phone": "+70809722465"}
0005432890918	AFFAE1	8161 696655	RAISA MOROZOVA	{"phone": "+70393670641"}
0005432890919	AFFAE1	3412 489530	KLAVDIYA NIKIFOROVA	{"phone": "+70373260253"}
0005432890920	593651	9633 830681	ANATOLIY GUSEV	{"email": "gusev-a1975@postgrespro.ru", "phone": "+70844903244"}
0005432890921	593651	4930 145567	KONSTANTIN ZHURAVLEV	{"phone": "+70811839193"}
0005432890922	593651	2830 432453	VASILIY ISAEV	{"phone": "+70749944597"}
0005432890923	B14E83	6812 699437	VIKTOR ZHUKOV	{"email": "zhukov_viktor101971@postgrespro.ru", "phone": "+70596804284"}
0005432890924	4CF9B8	0109 071006	MAKSIM ANDREEV	{"phone": "+70909090749"}
0005432890925	4CF9B8	8897 116193	MAKSIM MAKSIMOV	{"phone": "+70434649921"}
0005432890926	DC7311	7190 564024	TAISIYA FILIPPOVA	{"email": "taisiya.filippova26121988@postgrespro.ru", "phone": "+70987314823"}
0005432890927	0E17EA	6283 531069	NINA KARPOVA	{"email": "karpova-n-1974@postgrespro.ru", "phone": "+70615518531"}
0005432890928	5C0E53	2843 778618	OLGA KUZMINA	{"email": "o_kuzmina-1967@postgrespro.ru", "phone": "+70215826486"}
0005432890929	5C0E53	1822 442133	ALEKSEY STEPANOV	{"email": "stepanov-aleksey-1968@postgrespro.ru", "phone": "+70533341814"}
0005432890930	5C0E53	0829 082107	TATYANA ANTONOVA	{"email": "tatyanaantonova-111980@postgrespro.ru", "phone": "+70791749797"}
0005432890931	CFAF65	1085 177703	RUSLAN BORISOV	{"phone": "+70922950595"}
0005432890932	4059DC	6665 813116	VASILIY MOROZOV	{"email": "v.morozov1971@postgrespro.ru", "phone": "+70313413443"}
0005432890933	BF6F16	7268 904327	LIDIYA SOROKINA	{"email": "l.sorokina_1977@postgrespro.ru", "phone": "+70317701769"}
0005432890934	BF6F16	0327 626376	VERA ROMANOVA	{"phone": "+70956112283"}
0005432890935	EA8416	7016 788430	YULIYA ALEKSANDROVA	{"phone": "+70352731200"}
0005432890936	94F31A	8355 412877	DARINA EFREMOVA	{"phone": "+70234144281"}
0005432890937	94F31A	6745 369010	FAINA YUDINA	{"email": "faina.yudina011969@postgrespro.ru", "phone": "+70940679111"}
0005432890938	8A5964	4224 945907	YURIY OSIPOV	{"email": "osipov.y_111981@postgrespro.ru", "phone": "+70938392929"}
0005432890939	8A5964	1691 439692	VALENTINA SEMENOVA	{"phone": "+70194322452"}
0005432890940	802CE9	4659 488379	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-111978@postgrespro.ru", "phone": "+70087340111"}
0005432890941	802CE9	2437 729711	FARIT TARASOV	{"email": "farit-tarasov-31081971@postgrespro.ru", "phone": "+70597290144"}
0005432890942	ABCAA6	7076 886223	NINA IVANOVA	{"phone": "+70425607503"}
0005432890943	ABCAA6	4371 208468	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev_1969@postgrespro.ru", "phone": "+70703933224"}
0005432890944	282BD4	3978 276684	LYUDMILA AFANASEVA	{"email": "lyudmila_afanaseva.1973@postgrespro.ru", "phone": "+70830411237"}
0005432890945	282BD4	8460 782557	DANILA NAZAROV	{"phone": "+70347922726"}
0005432890946	752247	5766 116637	OLEG TIMOFEEV	{"email": "olegtimofeev_12011982@postgrespro.ru", "phone": "+70798082831"}
0005432890947	752247	4174 875470	ILYA FILIPPOV	{"email": "ilyafilippov_1967@postgrespro.ru", "phone": "+70429745942"}
0005432890948	752247	1683 986752	YULIYA KOROLEVA	{"email": "y_koroleva_25101967@postgrespro.ru", "phone": "+70411782180"}
0005432890949	6767A2	5226 695345	NIKOLAY NOVIKOV	{"email": "n_novikov.1976@postgrespro.ru", "phone": "+70270831833"}
0005432890950	DE3D86	4383 516775	EKATERINA ILINA	{"phone": "+70226612151"}
0005432890951	06615E	6818 100156	NATALYA KONDRATEVA	{"email": "kondrateva-n-111977@postgrespro.ru", "phone": "+70557251259"}
0005432890953	427E50	8784 334722	SERGEY SAVELEV	{"email": "savelev-sergey1976@postgrespro.ru", "phone": "+70235439480"}
0005432890954	FE3C61	9414 010654	ANDREY ZAKHAROV	{"phone": "+70904193683"}
0005432890955	FE3C61	3670 930386	VIKTOR SAVELEV	{"phone": "+70245338395"}
0005432890956	ECB8A5	4571 689052	MIKHAIL SOROKIN	{"email": "sorokin.m.1970@postgrespro.ru", "phone": "+70440854986"}
0005432890957	ECB8A5	9677 058400	NAIL FEDOROV	{"phone": "+70284996960"}
0005432890958	E3E603	5323 901355	ELENA BELYAEVA	{"phone": "+70407777854"}
0005432890959	3A3FB3	9525 554031	ARTUR VOROBEV	{"phone": "+70442942668"}
0005432890960	27DF81	4263 848563	EVGENIYA KISELEVA	{"phone": "+70851593486"}
0005432890961	C8F326	0360 468382	ALEKSANDR KONOVALOV	{"phone": "+70933710721"}
0005432890962	C8F326	4510 822208	ANTON KOROLEV	{"phone": "+70866162911"}
0005432890963	04B909	7399 043610	NATALIYA ZAYCEVA	{"email": "zaycevanataliya.01111976@postgrespro.ru", "phone": "+70610125961"}
0005432890964	DBF4A2	9578 552034	YULIYA KOZLOVA	{"phone": "+70390201281"}
0005432890965	350BE4	9662 681508	VLADIMIR PAVLOV	{"phone": "+70109938782"}
0005432890966	350BE4	3849 176715	SERGEY CHERNOV	{"phone": "+70430782546"}
0005432890967	119FCE	7027 855139	ANNA NIKITINA	{"phone": "+70899300559"}
0005432890968	CABA43	1677 258947	VERA BOGDANOVA	{"phone": "+70294054685"}
0005432890969	985446	1560 373715	MIKHAIL ALEKSANDROV	{"email": "aleksandrov_mikhail.1978@postgrespro.ru", "phone": "+70988647065"}
0005432890970	985446	6172 193627	EVGENIY KULIKOV	{"phone": "+70010314332"}
0005432890971	6538C7	6068 438560	OLGA NOVIKOVA	{"email": "o_novikova01021971@postgrespro.ru", "phone": "+70578986981"}
0005432890972	943912	9693 356054	EVGENIY KUZNECOV	{"email": "kuznecov-e_051971@postgrespro.ru", "phone": "+70328653221"}
0005432890973	A91994	6769 037588	LARISA SOLOVEVA	{"email": "soloveva-l.011974@postgrespro.ru", "phone": "+70988399926"}
0005432890974	9C8C9A	2219 724792	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr_1975@postgrespro.ru", "phone": "+70752175409"}
0005432890975	6D085D	8980 991781	MARIYA MASLOVA	{"phone": "+70315839298"}
0005432890976	521C54	9244 697525	VALERIYA POLYAKOVA	{"phone": "+70892337403"}
0005432890977	521C54	0655 171564	EKATERINA NESTEROVA	{"email": "nesterova-e-1954@postgrespro.ru", "phone": "+70912077029"}
0005432890978	C0F7D6	0094 939845	ILYA MAKAROV	{"phone": "+70499173944"}
0005432890979	C0F7D6	8386 159729	ANATOLIY FILIPPOV	{"phone": "+70987411350"}
0005432890980	F8FD1F	2569 808756	YURIY MOROZOV	{"email": "yuriymorozov.1976@postgrespro.ru", "phone": "+70517064952"}
0005432890981	F8FD1F	8270 515818	TATYANA KRASNOVA	{"phone": "+70184777669"}
0005432890982	F8FD1F	8647 547539	VITALIY OSIPOV	{"email": "osipovv.121983@postgrespro.ru", "phone": "+70840575994"}
0005432890983	46BA58	0674 039172	ARTEM POPOV	{"phone": "+70913626717"}
0005432890984	D5C685	0897 868405	IGOR ANDREEV	{"email": "andreev-igor1964@postgrespro.ru", "phone": "+70248927276"}
0005432890985	7D20D8	2891 912614	KRISTINA TARASOVA	{"email": "tarasovakristina.06051970@postgrespro.ru", "phone": "+70992073174"}
0005432890986	F5DAB4	9789 909545	ELENA FADEEVA	{"phone": "+70811649706"}
0005432890987	9DEAFB	1698 186816	TALGAT TIMOFEEV	{"phone": "+70680722736"}
0005432890988	9DEAFB	9369 671227	SERGEY SMIRNOV	{"email": "smirnov_s19071978@postgrespro.ru", "phone": "+70806451182"}
0005432890989	982B62	1390 640527	ELENA PAVLOVA	{"phone": "+70886327411"}
0005432890990	B61F08	9852 760379	OLEG SOROKIN	{"email": "o.sorokin1975@postgrespro.ru", "phone": "+70777164183"}
0005432890991	56C3CF	8425 054078	NIKOLAY ALEKSANDROV	{"email": "n_aleksandrov_1966@postgrespro.ru", "phone": "+70565040253"}
0005432890992	9EF410	0693 396705	VALERIY KAZAKOV	{"phone": "+70411550202"}
0005432890993	9EF410	9434 713410	NATALYA MIKHAYLOVA	{"phone": "+70717701923"}
0005432890994	CEEA9C	2757 338662	SERGEY FILIPPOV	{"phone": "+70315700267"}
0005432890995	CEEA9C	5316 850381	VALENTINA KONOVALOVA	{"email": "konovalova-v-081985@postgrespro.ru", "phone": "+70781691174"}
0005432890996	2A2F2E	6447 389824	ANTONINA KOROLEVA	{"phone": "+70462359305"}
0005432890997	1BD93F	8702 422320	INNA POTAPOVA	{"email": "potapovainna-1982@postgrespro.ru", "phone": "+70045131048"}
0005432890998	D78D29	9861 780802	ALEKSEY TIKHONOV	{"phone": "+70399458403"}
0005432890999	249C0E	2072 998421	VLADIMIR FILIPPOV	{"email": "v-filippov-08111975@postgrespro.ru", "phone": "+70573152375"}
0005432891000	3BAEFE	2835 003769	ARTEM ROMANOV	{"email": "romanovartem031974@postgrespro.ru", "phone": "+70661742866"}
0005432891001	3BAEFE	1103 726048	LYUBOV KOZLOVA	{"email": "kozlovalyubov.13071973@postgrespro.ru", "phone": "+70519388444"}
0005432891002	27F66D	2599 759079	ALEKSANDR BARANOV	{"email": "aleksandr-baranov_011974@postgrespro.ru", "phone": "+70475889585"}
0005432891003	509313	3052 162572	SVETLANA KISELEVA	{"email": "svetlana_kiseleva-101965@postgrespro.ru", "phone": "+70052404350"}
0005432891004	509313	3645 888591	ELENA BELOVA	{"phone": "+70904833726"}
0005432891005	509313	4623 567932	EVGENIY OSIPOV	{"phone": "+70329058210"}
0005432891006	27B21B	2371 960828	EKATERINA OSIPOVA	{"phone": "+70588629261"}
0005432891007	2909DB	8324 702503	ELENA KUZNECOVA	{"phone": "+70632398239"}
0005432891008	C64E11	4825 738204	GENNADIY MAKAROV	{"email": "makarovgennadiy-121961@postgrespro.ru", "phone": "+70204319539"}
0005432891009	5F2E0E	4841 360346	ANASTASIYA ZAKHAROVA	{"phone": "+70123390522"}
0005432891010	20D0CB	6720 409821	EKATERINA ILINA	{"email": "eilina-1969@postgrespro.ru", "phone": "+70551308748"}
0005432891011	B429CA	5869 889246	ALEKSEY PETROV	{"phone": "+70640850067"}
0005432891012	6B221D	6004 957197	ALEKSANDR MIRONOV	{"email": "aleksandr_mironov.1977@postgrespro.ru", "phone": "+70501475427"}
0005432891013	74DFF2	1569 075656	SERGEY YAKOVLEV	{"email": "yakovlev.s.1966@postgrespro.ru", "phone": "+70186187708"}
0005432891014	315AA4	6797 721850	ANNA BELOVA	{"phone": "+70120380215"}
0005432891015	0009D5	3748 081465	MAKSIM SOKOLOV	{"phone": "+70650801843"}
0005432891016	0009D5	5702 744060	FATIMA TIKHONOVA	{"phone": "+70200988488"}
0005432891017	57D37C	7598 824395	ALEKSANDR VLASOV	{"phone": "+70334112620"}
0005432891018	921044	7999 940146	NIKOLAY BELOV	{"phone": "+70689083066"}
0005432891019	921044	0209 611658	ALEKSANDR POPOV	{"email": "a.popov.30061968@postgrespro.ru", "phone": "+70330152253"}
0005432891020	921044	7178 632234	VALENTINA NIKOLAEVA	{"phone": "+70834165980"}
0005432891021	E5978B	3493 645160	ALEKSEY FILIPPOV	{"email": "a.filippov.1982@postgrespro.ru", "phone": "+70620332585"}
0005432891022	E5978B	1221 704464	OLGA IVANOVA	{"email": "ivanova.o-1972@postgrespro.ru", "phone": "+70338860209"}
0005432891023	5DF1BE	4871 286345	BORIS BELOV	{"email": "boris_belov-1969@postgrespro.ru", "phone": "+70937217353"}
0005432891024	AA2647	1896 233477	NADEZHDA GERASIMOVA	{"phone": "+70117684853"}
0005432891025	AA2647	5705 781529	OLGA NIKOLAEVA	{"email": "nikolaeva_olga1972@postgrespro.ru", "phone": "+70172362229"}
0005432891026	46BCBD	3071 752057	ANDREY MAKAROV	{"phone": "+70447185374"}
0005432891027	46BCBD	6135 518612	ANDREY SOLOVEV	{"phone": "+70738303997"}
0005432891028	D47B93	1339 237778	ALENA SOLOVEVA	{"phone": "+70647928945"}
0005432891029	195FAE	4923 923204	NADEZHDA KAZAKOVA	{"email": "n-kazakova_011971@postgrespro.ru", "phone": "+70982720543"}
0005432891030	195FAE	0921 481865	ANTONINA PAVLOVA	{"phone": "+70268583997"}
0005432891031	846567	6337 888048	MARIYA MARTYNOVA	{"phone": "+70478111702"}
0005432891032	C57915	4121 357195	YULIYA SEMENOVA	{"phone": "+70026568568"}
0005432891033	CAA8EF	6384 622839	EKATERINA GERASIMOVA	{"email": "gerasimova-ekaterina_26081969@postgrespro.ru", "phone": "+70494987887"}
0005432891034	CAA8EF	0789 145858	EKATERINA ZAKHAROVA	{"phone": "+70722009504"}
0005432891035	1CA72D	7360 018896	VERA NAZAROVA	{"email": "nazarova.v.07031971@postgrespro.ru", "phone": "+70009288857"}
0005432891036	1CA72D	0151 925120	YANA FADEEVA	{"email": "fadeevay.101968@postgrespro.ru", "phone": "+70587916769"}
0005432891037	18F139	0412 221921	IGOR ZHUKOV	{"phone": "+70483169358"}
0005432891038	8EA8DD	7264 119341	VALERIY KUZNECOV	{"email": "kuznecov_v101975@postgrespro.ru", "phone": "+70995979595"}
0005432891039	8EA8DD	4258 032578	OKSANA ALEKSEEVA	{"email": "o_alekseeva-02071986@postgrespro.ru", "phone": "+70073112801"}
0005432891040	132A0D	0184 670305	ALINA GORBUNOVA	{"phone": "+70941267823"}
0005432891041	C985DA	9829 847331	NIKITA KRASNOV	{"email": "krasnovnikita.101962@postgrespro.ru", "phone": "+70579703810"}
0005432891042	C985DA	1770 211960	ALLA KUDRYASHOVA	{"phone": "+70203736148"}
0005432891043	C5F3A8	3062 825752	DMITRIY ZAKHAROV	{"phone": "+70873316846"}
0005432891044	C5F3A8	1631 245527	ANDREY GAVRILOV	{"phone": "+70721868476"}
0005432891045	4C65CA	8650 075630	ANDREY SOKOLOV	{"phone": "+70897917594"}
0005432891046	4C65CA	7092 157158	TATYANA MAKAROVA	{"email": "makarova_t_111985@postgrespro.ru", "phone": "+70622918988"}
0005432891047	61915D	5504 003437	SHAMIL STEPANOV	{"phone": "+70215181946"}
0005432891048	61915D	1524 642214	VYACHESLAV ISAEV	{"phone": "+70755882819"}
0005432891049	F377C5	8109 414559	LYUBOV FILIPPOVA	{"phone": "+70038447313"}
0005432891050	D9FF87	5894 620651	TATYANA MALYSHEVA	{"email": "tatyana-malysheva.021968@postgrespro.ru", "phone": "+70071674148"}
0005432891051	60A430	2888 938137	MARINA KUZNECOVA	{"email": "m.kuznecova.1974@postgrespro.ru", "phone": "+70477094470"}
0005432891052	60A430	7717 369685	ALEKSANDRA TIMOFEEVA	{"email": "aleksandra_timofeeva-27031983@postgrespro.ru", "phone": "+70198594544"}
0005432891053	B1A136	5911 490778	MARINA SERGEEVA	{"email": "marinasergeeva-111979@postgrespro.ru", "phone": "+70756198174"}
0005432891054	B1A136	0158 805148	IRINA MIKHAYLOVA	{"phone": "+70974196743"}
0005432891055	28C26A	5832 742772	NINA TIKHONOVA	{"phone": "+70708455395"}
0005432891056	43A446	6296 965594	SERGEY IVANOV	{"email": "ivanov.s_1988@postgrespro.ru", "phone": "+70541676487"}
0005432891057	6788F1	7293 970584	ALEKSEY MIRONOV	{"email": "mironov-a_081974@postgrespro.ru", "phone": "+70962566648"}
0005432891058	9C0617	9536 522761	EVGENIY KOZLOV	{"email": "e_kozlov_091967@postgrespro.ru", "phone": "+70890807412"}
0005432891059	6B2C06	1951 236859	ALENA KUZNECOVA	{"phone": "+70501169479"}
0005432891060	4DCBD7	7317 842979	ELIZAVETA BARANOVA	{"email": "elizaveta-baranova051981@postgrespro.ru", "phone": "+70050818784"}
0005432891061	8E251C	7265 252267	KONSTANTIN AFANASEV	{"phone": "+70130858968"}
0005432891062	B858E1	4948 354350	IRINA MAKSIMOVA	{"phone": "+70278555536"}
0005432891063	B858E1	3207 626066	ALINA EGOROVA	{"email": "a_egorova_101960@postgrespro.ru", "phone": "+70254682386"}
0005432891064	AAA979	6457 438844	ELENA MATVEEVA	{"email": "matveeva.e.031973@postgrespro.ru", "phone": "+70330734624"}
0005432891065	EC866A	5188 542838	LYUDMILA RYABOVA	{"email": "lyudmila_ryabova1971@postgrespro.ru", "phone": "+70228294621"}
0005432891066	CA2A74	9684 851451	SERGEY PETROV	{"email": "sergey_petrov-1977@postgrespro.ru", "phone": "+70201558809"}
0005432891067	191E4B	8521 998886	NATALYA KONDRATEVA	{"email": "natalya-kondrateva.111973@postgrespro.ru", "phone": "+70489887411"}
0005432891068	029976	1634 168647	ELENA EFREMOVA	{"email": "elena_efremova-18041959@postgrespro.ru", "phone": "+70201334515"}
0005432891069	CB99A1	1946 156066	MARINA FROLOVA	{"phone": "+70782296667"}
0005432891070	8AA236	5186 198389	PETR KAZAKOV	{"phone": "+70022841089"}
0005432891071	8AA236	8077 484859	MARINA MOISEEVA	{"email": "moiseeva.m1974@postgrespro.ru", "phone": "+70627770162"}
0005432891072	695E59	1850 753031	TAISIYA ZAKHAROVA	{"email": "taisiyazakharova.03041958@postgrespro.ru", "phone": "+70923115820"}
0005432891073	695E59	4539 062634	VIKTORIYA NIKITINA	{"phone": "+70258263860"}
0005432891074	A29A13	0732 707307	MARIYA GUSEVA	{"email": "guseva-mariya-09121972@postgrespro.ru", "phone": "+70304985419"}
0005432891075	102C56	0307 192719	MARGARITA ROMANOVA	{"phone": "+70141227080"}
0005432891076	2AAA3A	0011 603512	NATALIYA TARASOVA	{"email": "nataliya_tarasova-12051963@postgrespro.ru", "phone": "+70465951354"}
0005432891077	2AAA3A	1084 800230	EVGENIYA OSIPOVA	{"email": "osipova.e.05071975@postgrespro.ru", "phone": "+70635451997"}
0005432891078	133BBF	2983 099681	DENIS MOROZOV	{"phone": "+70097201747"}
0005432891079	A40845	3358 104438	RAISA KUZNECOVA	{"email": "kuznecova_r1975@postgrespro.ru", "phone": "+70854817650"}
0005432891080	A40845	0957 215262	GALINA SIDOROVA	{"phone": "+70627411906"}
0005432891081	86A698	7916 865197	ELMIRA SOROKINA	{"phone": "+70902761065"}
0005432891082	479841	9262 511548	TATYANA EFREMOVA	{"phone": "+70971505837"}
0005432891083	A5607D	1081 192418	OLGA GUSEVA	{"email": "guseva_olga-031973@postgrespro.ru", "phone": "+70091538637"}
0005432891084	F1C858	7639 942925	EVGENIY EGOROV	{"email": "egorov_evgeniy-1970@postgrespro.ru", "phone": "+70795492034"}
0005432891085	F1C858	8920 504325	GALINA MOROZOVA	{"email": "g.morozova-07101977@postgrespro.ru", "phone": "+70397133795"}
0005432891086	2CF7DB	3606 188218	VADIM PAVLOV	{"email": "v_pavlov-28111972@postgrespro.ru", "phone": "+70429183133"}
0005432891087	DA9709	6115 265405	MIKHAIL POPOV	{"email": "mikhail_popov.20111957@postgrespro.ru", "phone": "+70378300488"}
0005432891088	DA9709	5282 101480	ALEKSEY NIKITIN	{"email": "nikitinaleksey_28041961@postgrespro.ru", "phone": "+70741233981"}
0005432891089	AEC253	9007 684779	POLINA MALYSHEVA	{"phone": "+70075207660"}
0005432891090	316535	8968 098106	GENNADIY ANTONOV	{"email": "gennadiyantonov-1973@postgrespro.ru", "phone": "+70162881649"}
0005432891091	316535	2692 948397	ILYA FROLOV	{"phone": "+70777098920"}
0005432891092	480EBC	9085 675237	OKSANA BORISOVA	{"email": "borisovaoksana19081979@postgrespro.ru", "phone": "+70164759482"}
0005432891093	480EBC	1846 599378	DANILA SEMENOV	{"phone": "+70725069835"}
0005432891094	47BECE	3426 649876	TAISIYA AFANASEVA	{"email": "t-afanaseva1972@postgrespro.ru", "phone": "+70274262611"}
0005432891095	63CD33	2227 056383	OLGA ANTONOVA	{"phone": "+70278024079"}
0005432891096	8681C9	0709 070831	YANA IVANOVA	{"email": "yana-ivanova.101981@postgrespro.ru", "phone": "+70745131269"}
0005432891097	DB391E	9771 197110	VALENTINA NAUMOVA	{"phone": "+70690716297"}
0005432891098	DB391E	5704 558386	IRINA KULIKOVA	{"phone": "+70180607942"}
0005432891099	93EAB0	7925 892289	DMITRIY DAVYDOV	{"phone": "+70451231872"}
0005432891100	93EAB0	9511 720624	NIKOLAY PETROV	{"email": "petrov.n-30111975@postgrespro.ru", "phone": "+70743751296"}
0005432891101	9ACE10	7493 059753	TATYANA MAKSIMOVA	{"email": "t.maksimova_081972@postgrespro.ru", "phone": "+70385204212"}
0005432891102	235CDA	6157 799114	IVAN PETROV	{"email": "petrov.ivan-011974@postgrespro.ru", "phone": "+70223814287"}
0005432891103	235CDA	9574 818329	SVETLANA PETROVA	{"phone": "+70674544074"}
0005432891104	CFC278	7966 531603	SERGEY STEPANOV	{"email": "sergey_stepanov1976@postgrespro.ru", "phone": "+70674350354"}
0005432891105	A379C4	2167 686438	LIDIYA BORISOVA	{"phone": "+70535714026"}
0005432891106	A7703E	2646 817355	EDUARD MATVEEV	{"email": "e.matveev_30101970@postgrespro.ru", "phone": "+70315467279"}
0005432891107	5801C5	1287 693699	ALEKSANDR MOROZOV	{"phone": "+70349044329"}
0005432891108	D06D6F	2734 790663	RUSTAM POPOV	{"phone": "+70051662254"}
0005432891109	1022B0	4188 081991	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey-27101958@postgrespro.ru", "phone": "+70216243001"}
0005432891110	1022B0	5022 691120	ANDREY GUSEV	{"email": "a_gusev111962@postgrespro.ru", "phone": "+70903973741"}
0005432891111	08F040	4798 986441	DMITRIY VASILEV	{"email": "dvasilev.08011969@postgrespro.ru", "phone": "+70568544302"}
0005432891112	9B64C4	8360 381418	VIKTOR SHEVCHENKO	{"email": "shevchenkoviktor-1962@postgrespro.ru", "phone": "+70930248331"}
0005432891113	3A7E4A	3283 279595	KLAVDIYA FOMINA	{"phone": "+70346092653"}
0005432891114	F4840B	8076 465897	IVAN SERGEEV	{"email": "sergeev-i03051968@postgrespro.ru", "phone": "+70936806741"}
0005432891115	F4840B	2063 620264	DMITRIY ALEKSANDROV	{"email": "dmitriy_aleksandrov13081970@postgrespro.ru", "phone": "+70271153849"}
0005432891116	522364	5905 026761	MARINA FILATOVA	{"email": "filatova_marina_01091969@postgrespro.ru", "phone": "+70821457513"}
0005432891117	164F4D	6648 745347	NATALYA LOGINOVA	{"email": "natalya-loginova-1979@postgrespro.ru", "phone": "+70280115891"}
0005432891118	AC086B	3177 833155	VALERIY GORBUNOV	{"email": "valeriygorbunov-18041975@postgrespro.ru", "phone": "+70739712197"}
0005432891119	7F6B29	0428 458048	MIKHAIL TIMOFEEV	{"phone": "+70797312976"}
0005432891120	034802	8636 800268	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev_051973@postgrespro.ru", "phone": "+70211885804"}
0005432891121	A9EF06	7687 819190	LARISA DENISOVA	{"email": "larisa_denisova.1978@postgrespro.ru", "phone": "+70075019150"}
0005432891122	A9EF06	1259 403285	EVGENIY ILIN	{"email": "evgeniy-ilin.1976@postgrespro.ru", "phone": "+70834018721"}
0005432891123	6AE315	0074 121410	DMITRIY FOMIN	{"email": "fomind_1963@postgrespro.ru", "phone": "+70173852033"}
0005432891124	169231	7722 519626	YULIYA KISELEVA	{"phone": "+70392204078"}
0005432891125	D1DD9E	3276 684820	MAKSIM KISELEV	{"email": "mkiselev_071967@postgrespro.ru", "phone": "+70014314893"}
0005432891126	7D0D54	6655 801858	NIKOLAY ZAKHAROV	{"email": "n.zakharov-1977@postgrespro.ru", "phone": "+70733874491"}
0005432891127	FAEC39	9495 741826	ELENA KRASNOVA	{"email": "e_krasnova_1955@postgrespro.ru", "phone": "+70889741823"}
0005432891128	557905	1510 234642	ELVIRA POTAPOVA	{"phone": "+70038335300"}
0005432891129	557905	5171 385175	DMITRIY MIKHAYLOV	{"email": "mikhaylovd.021984@postgrespro.ru", "phone": "+70958284080"}
0005432891130	557905	6564 987998	IRINA SOROKINA	{"phone": "+70879159331"}
0005432891131	A3698F	1945 985161	LIDIYA AKIMOVA	{"email": "akimova-lidiya1968@postgrespro.ru", "phone": "+70137634980"}
0005432891132	7296D3	6174 887739	ANATOLIY KUZMIN	{"email": "anatoliy_kuzmin26031967@postgrespro.ru", "phone": "+70465610940"}
0005432891312	CA4A51	4067 507908	STANISLAV ZAKHAROV	{"phone": "+70452447498"}
0005432891133	CD86BD	3618 059551	KSENIYA GORBUNOVA	{"email": "gorbunova-kseniya1964@postgrespro.ru", "phone": "+70839661058"}
0005432891134	DD56C3	4529 335488	VALERIY KUZMIN	{"phone": "+70175874237"}
0005432891135	1ECB0B	1865 938428	LEONID NIKOLAEV	{"email": "nikolaevl-1962@postgrespro.ru", "phone": "+70490754184"}
0005432891136	08958F	8020 146386	EVGENIY IVANOV	{"email": "e_ivanov_1985@postgrespro.ru", "phone": "+70203097978"}
0005432891137	08958F	3138 041137	LYUDMILA SOLOVEVA	{"email": "l_soloveva_30111973@postgrespro.ru", "phone": "+70850436473"}
0005432891138	08958F	1465 083161	ANASTASIYA ZAKHAROVA	{"email": "zakharova_anastasiya1975@postgrespro.ru", "phone": "+70286252670"}
0005432891139	F80BDE	4192 226207	SERGEY DAVYDOV	{"email": "davydov_sergey.041981@postgrespro.ru", "phone": "+70917218975"}
0005432891140	F80BDE	7937 854140	IGOR ISAEV	{"email": "iisaev1983@postgrespro.ru", "phone": "+70706066825"}
0005432891141	B33FB0	0118 407330	YURIY GORBUNOV	{"email": "yuriygorbunov031975@postgrespro.ru", "phone": "+70983783546"}
0005432891142	B33FB0	1651 678610	SERGEY NOVIKOV	{"phone": "+70885669753"}
0005432891143	BD8CA2	3298 501367	LILIYA PETROVA	{"phone": "+70889145124"}
0005432891144	4F6156	7054 764077	DMITRIY POPOV	{"email": "dmitriy_popov-03021978@postgrespro.ru", "phone": "+70364065838"}
0005432891145	4F6156	1962 705049	LYUDMILA KUZNECOVA	{"email": "lyudmila.kuznecova041972@postgrespro.ru", "phone": "+70604087892"}
0005432891146	EBC100	0912 186964	ANDREY KUZMIN	{"email": "kuzmin.a.041979@postgrespro.ru", "phone": "+70489485429"}
0005432891147	6E2C03	8699 670030	DENIS BELOV	{"email": "belov.d-1980@postgrespro.ru", "phone": "+70478565311"}
0005432891148	6E2C03	2065 035417	OLGA ALEKSANDROVA	{"email": "olga.aleksandrova_111971@postgrespro.ru", "phone": "+70943169404"}
0005432891149	9A1F10	5747 481266	ALINA KUZMINA	{"email": "kuzmina_alina-1969@postgrespro.ru", "phone": "+70616065469"}
0005432891150	67567A	6947 866616	ANNA KONOVALOVA	{"email": "a.konovalova-1971@postgrespro.ru", "phone": "+70664603265"}
0005432891151	D68F30	9122 924947	DMITRIY KRASNOV	{"phone": "+70352238148"}
0005432891152	D68F30	8954 718620	ARTEM KAZAKOV	{"email": "a.kazakov.1956@postgrespro.ru", "phone": "+70314953857"}
0005432891153	5CBA06	2622 207267	NIKITA STEPANOV	{"phone": "+70908333948"}
0005432891154	188CAA	5471 522801	EVGENIYA MATVEEVA	{"phone": "+70167786036"}
0005432891155	388FB1	4934 826279	ILYA ZAYCEV	{"email": "zaycev-ilya_08071969@postgrespro.ru", "phone": "+70654377757"}
0005432891156	D5CF37	2699 091560	ALEKSEY ALEKSANDROV	{"phone": "+70787958087"}
0005432891157	98E780	1500 261230	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_1961@postgrespro.ru", "phone": "+70735981372"}
0005432891158	B1B5AB	9177 437661	STANISLAV GRIGOREV	{"email": "sgrigorev-021974@postgrespro.ru", "phone": "+70357589458"}
0005432891159	B1B5AB	6723 007651	ALEKSANDR KARPOV	{"phone": "+70856890316"}
0005432891160	A0915C	7480 609567	KONSTANTIN STEPANOV	{"phone": "+70379065400"}
0005432891161	020108	9200 166932	RAMIL VOROBEV	{"email": "vorobev_r-011974@postgrespro.ru", "phone": "+70416829092"}
0005432891162	92D724	1792 168496	YULIYA KRASNOVA	{"email": "ykrasnova_1976@postgrespro.ru", "phone": "+70553003743"}
0005432891163	92D724	2827 106118	SERGEY DAVYDOV	{"phone": "+70949133220"}
0005432891164	7C05E7	0366 376731	YURIY CHERNOV	{"email": "chernovy_17121972@postgrespro.ru", "phone": "+70079140917"}
0005432891165	4281FB	4882 470637	GALINA SERGEEVA	{"email": "g_sergeeva061977@postgrespro.ru", "phone": "+70587445779"}
0005432891166	74A914	2754 977899	VLADIMIR KARPOV	{"phone": "+70038799357"}
0005432891167	7E7711	8167 414891	VLADA EFIMOVA	{"phone": "+70107081221"}
0005432891168	69D3B1	3751 165669	TATYANA OSIPOVA	{"email": "t.osipova_071974@postgrespro.ru", "phone": "+70772135656"}
0005432891169	40DC1B	6466 047809	NATALYA BELOVA	{"phone": "+70338984013"}
0005432891170	48315D	2616 350998	EVDOKIYA DAVYDOVA	{"phone": "+70135415108"}
0005432891171	3D6305	7980 142026	YURIY KUZNECOV	{"phone": "+70492903356"}
0005432891172	73CF77	6606 203769	ALEKSANDR FEDOROV	{"phone": "+70485447100"}
0005432891173	A7593A	8743 130563	EVGENIY ZAYCEV	{"email": "ezaycev_16051977@postgrespro.ru", "phone": "+70218022693"}
0005432891174	51CAD6	4875 782693	TATYANA IVANOVA	{"phone": "+70235507751"}
0005432891175	CDD836	2751 609427	VERONIKA ARKHIPOVA	{"email": "arkhipova_veronika-061967@postgrespro.ru", "phone": "+70806006826"}
0005432891176	CDD836	9514 839935	DANIIL ALEKSEEV	{"phone": "+70507713937"}
0005432891177	CDD836	2495 738060	NADEZHDA PAVLOVA	{"email": "pavlova.n-26011965@postgrespro.ru", "phone": "+70471293075"}
0005432891178	D600FB	3078 047294	VLADIMIR OSIPOV	{"email": "osipov-v_1968@postgrespro.ru", "phone": "+70521418732"}
0005432891179	A9B86C	3196 575327	TATYANA MARTYNOVA	{"email": "martynova-tatyana13051962@postgrespro.ru", "phone": "+70324608397"}
0005432891180	F324E3	5102 173843	ELENA KISELEVA	{"phone": "+70864201815"}
0005432891181	010C66	5787 867323	NATALYA EGOROVA	{"phone": "+70405079678"}
0005432891182	010C66	6545 901138	LEONID SEMENOV	{"email": "l-semenov.21111980@postgrespro.ru", "phone": "+70156148722"}
0005432891183	6D4577	9803 481130	ANDREY GERASIMOV	{"phone": "+70655948127"}
0005432891184	C924BA	9174 825862	ALEKSANDR ZAKHAROV	{"phone": "+70059437442"}
0005432891185	B77155	1976 494133	EKATERINA ALEKSEEVA	{"phone": "+70800450164"}
0005432891186	B77155	4205 778368	GALINA KUZNECOVA	{"email": "galina_kuznecova.1965@postgrespro.ru", "phone": "+70786025377"}
0005432891187	174E4A	2398 613477	EGOR SEMENOV	{"email": "semenov-egor.051974@postgrespro.ru", "phone": "+70001229206"}
0005432891188	9B2294	9077 110039	GENNADIY KRASNOV	{"phone": "+70689935676"}
0005432891189	9B2294	2163 885522	RUSLAN ORLOV	{"phone": "+70126404492"}
0005432891190	E4E4E8	6727 536796	ALEKSANDRA TIKHONOVA	{"phone": "+70076828986"}
0005432891191	4F6078	0863 686034	NIKOLAY IVANOV	{"phone": "+70915686906"}
0005432891192	C17BBA	8556 954170	ANDREY KISELEV	{"email": "kiselev_a.24041989@postgrespro.ru", "phone": "+70737028873"}
0005432891193	C17BBA	6576 869349	NATALYA KISELEVA	{"email": "n-kiseleva051979@postgrespro.ru", "phone": "+70941525965"}
0005432891194	C17BBA	6764 640847	ANDREY IVANOV	{"phone": "+70783297456"}
0005432891195	C3F7C5	7399 375333	ALEKSANDR POPOV	{"email": "a-popov1970@postgrespro.ru", "phone": "+70131027215"}
0005432891196	74FAB4	7894 493554	NADEZHDA LAZAREVA	{"phone": "+70510165050"}
0005432891197	E02259	4136 491717	ANASTASIYA KRASNOVA	{"phone": "+70589805295"}
0005432891198	4B64C0	1109 008435	ANASTASIYA FOMINA	{"email": "a-fomina111957@postgrespro.ru", "phone": "+70814679888"}
0005432891199	4B64C0	8198 692652	LYUDMILA MIKHAYLOVA	{"phone": "+70256878235"}
0005432891200	4B64C0	0018 677710	IRINA ANDREEVA	{"email": "andreeva_irina-1978@postgrespro.ru", "phone": "+70181846901"}
0005432891201	A9DBDC	7611 366605	TATYANA SOKOLOVA	{"email": "tatyana-sokolova.1960@postgrespro.ru", "phone": "+70917629967"}
0005432891202	792934	3385 359863	ROMAN MEDVEDEV	{"phone": "+70353688001"}
0005432891203	B6E6DC	3937 733112	ELMIRA TIKHONOVA	{"email": "tikhonovaelmira-06071970@postgrespro.ru", "phone": "+70125266977"}
0005432891204	479BD5	7999 775281	VALENTINA NOVIKOVA	{"phone": "+70623253768"}
0005432891205	7B74C1	0605 906884	ANTONINA RYABOVA	{"phone": "+70747544568"}
0005432891206	7B74C1	2624 577953	OLGA ANDREEVA	{"phone": "+70760207760"}
0005432891207	039AAB	0691 434936	VERA MOROZOVA	{"email": "morozovav08041977@postgrespro.ru", "phone": "+70639250624"}
0005432891208	039AAB	4851 689564	ALEKSANDR NAZAROV	{"phone": "+70363979213"}
0005432891209	8D96AD	0400 808677	ANNA KALININA	{"email": "a_kalinina-03011971@postgrespro.ru", "phone": "+70796833754"}
0005432891210	7DA32B	2211 394640	VERA ORLOVA	{"email": "v.orlova-02091962@postgrespro.ru", "phone": "+70948748041"}
0005432891211	7DA32B	7643 319145	IVAN KUZNECOV	{"phone": "+70334624577"}
0005432891212	7DA32B	2701 106280	TAISIYA ZAKHAROVA	{"phone": "+70705688386"}
0005432891213	E3707E	3252 920487	VLADIMIR NAZAROV	{"phone": "+70984039743"}
0005432891214	B0A94F	1937 168935	MARGARITA FROLOVA	{"email": "m-frolova12021982@postgrespro.ru", "phone": "+70404392301"}
0005432891215	21AAAD	4015 647433	ZOYA KOROLEVA	{"email": "koroleva_zoya.10091970@postgrespro.ru", "phone": "+70906670770"}
0005432891216	095221	1768 789947	ANDREY ANDREEV	{"email": "andreyandreev.12071961@postgrespro.ru", "phone": "+70599944379"}
0005432891217	BB105A	5860 980363	MAKSIM KUZNECOV	{"email": "kuznecovm-11051975@postgrespro.ru", "phone": "+70527662050"}
0005432891218	EF575C	0281 724990	PETR VOROBEV	{"phone": "+70563304658"}
0005432891219	977EAA	3051 809784	EVA ZHUKOVA	{"phone": "+70940417735"}
0005432891220	51F206	1548 571310	OLGA GAVRILOVA	{"email": "o.gavrilova_101972@postgrespro.ru", "phone": "+70780511256"}
0005432891221	C3A3D0	2512 927574	VALENTINA IVANOVA	{"email": "v_ivanova-1968@postgrespro.ru", "phone": "+70739950855"}
0005432891222	C3A3D0	9500 497389	GALINA PETROVA	{"phone": "+70344296187"}
0005432891223	99282A	3376 689487	ANDREY NIKITIN	{"email": "nikitinandrey.101976@postgrespro.ru", "phone": "+70695757842"}
0005432891224	E212C0	1936 321513	OKSANA PAVLOVA	{"phone": "+70891409973"}
0005432891225	E212C0	4398 076006	IGOR KRASNOV	{"phone": "+70116494486"}
0005432891226	7F5ADC	7844 949296	GALINA MIKHAYLOVA	{"phone": "+70179894237"}
0005432891227	4F13AD	4108 636351	NINA BELYAEVA	{"phone": "+70546562308"}
0005432891228	4F13AD	7003 556545	GLEB FEDOROV	{"email": "g.fedorov_01061985@postgrespro.ru", "phone": "+70314837981"}
0005432891229	AE9A05	2496 569632	MARINA RYABOVA	{"phone": "+70169413253"}
0005432891230	AE9A05	2571 075216	VALENTINA SMIRNOVA	{"phone": "+70404831069"}
0005432891231	AE9A05	3206 437216	MARIYA KUZNECOVA	{"phone": "+70530526047"}
0005432891232	C06E51	7270 187379	DENIS TARASOV	{"email": "d.tarasov.1983@postgrespro.ru", "phone": "+70076576439"}
0005432891233	266698	0329 711710	MARIYA ANTONOVA	{"email": "antonovamariya_1979@postgrespro.ru", "phone": "+70655419229"}
0005432891234	266698	6764 034644	NAIL MARTYNOV	{"phone": "+70301097336"}
0005432891235	A4F76D	9584 508768	ANNA OSIPOVA	{"phone": "+70437199371"}
0005432891236	2E552D	5745 914234	YURIY PETROV	{"phone": "+70719595072"}
0005432891237	56E043	5956 872719	TAMARA DAVYDOVA	{"phone": "+70195828741"}
0005432891238	56E043	5064 558977	KLAVDIYA KOZLOVA	{"phone": "+70605599676"}
0005432891239	56E043	0464 754250	NINA ROMANOVA	{"phone": "+70308764811"}
0005432891240	31C476	7284 389829	ELENA ZAKHAROVA	{"phone": "+70125221131"}
0005432891241	0A8097	5021 825967	ANASTASIYA NIKITINA	{"phone": "+70814856248"}
0005432891242	39834C	6714 575632	ANDREY EGOROV	{"email": "aegorov_08021977@postgrespro.ru", "phone": "+70528731833"}
0005432891243	062D04	6643 226805	NADEZHDA MIRONOVA	{"phone": "+70972886794"}
0005432891244	062D04	1940 751855	OLGA PAVLOVA	{"phone": "+70910254559"}
0005432891245	9B505C	7540 961195	IRINA PAVLOVA	{"email": "pavlova.i031958@postgrespro.ru", "phone": "+70093856403"}
0005432891246	9B505C	1194 281692	GALINA EFIMOVA	{"phone": "+70099587116"}
0005432891247	52A9A8	8261 084671	IVAN ISAEV	{"email": "ivan_isaev1980@postgrespro.ru", "phone": "+70228926681"}
0005432891248	43E578	3313 465362	MARIYA LEBEDEVA	{"email": "lebedeva_mariya_1964@postgrespro.ru", "phone": "+70185494476"}
0005432891249	BE35BA	6948 758824	VIKTOR CHERNOV	{"phone": "+70924963271"}
0005432891250	E1F024	5580 857229	VERA GORBUNOVA	{"phone": "+70762788486"}
0005432891251	DED9F0	1667 967362	ZOYA TARASOVA	{"email": "tarasova.z.041973@postgrespro.ru", "phone": "+70774154774"}
0005432891252	4932AB	4421 090710	VLADIMIR GORBUNOV	{"email": "vladimir_gorbunov-031969@postgrespro.ru", "phone": "+70030086902"}
0005432891253	4932AB	7151 425905	SERGEY MAKSIMOV	{"phone": "+70256522834"}
0005432891254	9D120C	3395 890175	EVGENIYA NIKOLAEVA	{"email": "nikolaeva.evgeniya-06091973@postgrespro.ru", "phone": "+70292310776"}
0005432891491	41C128	8924 708379	ALEKSANDR VOROBEV	{"phone": "+70833341658"}
0005432891255	3669F4	5672 335444	SERGEY MIRONOV	{"email": "s.mironov-30081969@postgrespro.ru", "phone": "+70583331301"}
0005432891256	3669F4	6195 369972	SVETLANA VOROBEVA	{"email": "vorobeva.s19051978@postgrespro.ru", "phone": "+70039843395"}
0005432891257	8A2CB6	0711 945219	SVETLANA MOROZOVA	{"email": "morozova-svetlana.1976@postgrespro.ru", "phone": "+70372684621"}
0005432891258	8A2CB6	2917 605829	MIKHAIL KRASNOV	{"phone": "+70984700377"}
0005432891259	1D76ED	6316 915752	ALEKSANDR SEMENOV	{"phone": "+70907812083"}
0005432891260	3A31A0	0510 538005	MIKHAIL VOROBEV	{"email": "mikhail.vorobev021979@postgrespro.ru", "phone": "+70337208707"}
0005432891261	0E4280	8326 344909	DANILA FROLOV	{"phone": "+70502497429"}
0005432891262	95B544	4610 199502	VITALIY ISAEV	{"email": "v.isaev_17111970@postgrespro.ru", "phone": "+70466039554"}
0005432891263	83883B	2686 697413	VALENTIN VOROBEV	{"email": "valentin-vorobev121966@postgrespro.ru", "phone": "+70039038746"}
0005432891264	83883B	1129 222061	ALEKSANDR POPOV	{"email": "popov_a.25121965@postgrespro.ru", "phone": "+70174290575"}
0005432891265	275479	2910 618841	IGOR MIKHAYLOV	{"email": "mikhaylov-igor_1948@postgrespro.ru", "phone": "+70635845866"}
0005432891266	3384F1	2418 784416	KIRILL PAVLOV	{"email": "kirill.pavlov.121975@postgrespro.ru", "phone": "+70673145231"}
0005432891267	3384F1	2282 612822	SERGEY STEPANOV	{"phone": "+70324988299"}
0005432891268	9742D1	9970 040363	ALEKSANDR MEDVEDEV	{"email": "aleksandr-medvedev-23031975@postgrespro.ru", "phone": "+70285052902"}
0005432891269	BD0F54	0017 825968	MARSEL SMIRNOV	{"phone": "+70091576199"}
0005432891326	D027C7	6531 096662	FARID MOROZOV	{"phone": "+70274579959"}
0005432891270	35C933	8685 615085	SERGEY SEMENOV	{"email": "semenovsergey_1971@postgrespro.ru", "phone": "+70645903250"}
0005432891271	35C933	3024 078481	DMITRIY PETROV	{"email": "petrov_dmitriy.1965@postgrespro.ru", "phone": "+70141301877"}
0005432891272	1B7ACF	1110 619396	ELENA ANTONOVA	{"email": "antonova_e031975@postgrespro.ru", "phone": "+70087791582"}
0005432891273	1B7ACF	8041 996274	DANIIL ZAKHAROV	{"email": "zakharov.daniil_22091973@postgrespro.ru", "phone": "+70812508262"}
0005432891274	01A8F8	6103 638270	OKSANA IVANOVA	{"phone": "+70833485492"}
0005432891275	2178CE	6270 640035	MARIYA ANISIMOVA	{"email": "mariya-anisimova-14091984@postgrespro.ru", "phone": "+70895753421"}
0005432891276	012CA7	3505 662548	YULIYA ILINA	{"phone": "+70601142253"}
0005432891277	772BF0	5952 360138	ALEKSANDR SHEVCHENKO	{"phone": "+70052185904"}
0005432891278	CCB396	3587 003733	MARINA PETROVA	{"phone": "+70077788423"}
0005432891279	D0CB08	5357 327773	EVGENIY MAKAROV	{"phone": "+70978768802"}
0005432891280	D8B422	6028 681642	NINA BORISOVA	{"email": "n.borisova_041972@postgrespro.ru", "phone": "+70607920951"}
0005432891281	EC1B05	4553 340112	ANTONINA POPOVA	{"phone": "+70010909752"}
0005432891282	E91967	8989 078441	IRINA FILIPPOVA	{"email": "irina-filippova-09031977@postgrespro.ru", "phone": "+70864388061"}
0005432891283	E91967	9904 263180	ELENA KUZNECOVA	{"phone": "+70225663474"}
0005432891284	F39254	9838 660290	VALERIY FEDOROV	{"email": "fedorov_valeriy02111978@postgrespro.ru", "phone": "+70188574931"}
0005432891285	9184DB	3126 711535	LYUDMILA NAUMOVA	{"email": "lyudmila.naumova.1977@postgrespro.ru", "phone": "+70658397190"}
0005432891286	7F11C0	3801 076548	TATYANA NAZAROVA	{"email": "nazarovat1972@postgrespro.ru", "phone": "+70091172639"}
0005432891287	7F11C0	1500 247340	NIKITA KRASNOV	{"email": "nikitakrasnov_031973@postgrespro.ru", "phone": "+70938647439"}
0005432891288	F51671	2718 811226	ILYA MEDVEDEV	{"email": "ilya_medvedev_01111970@postgrespro.ru", "phone": "+70432860265"}
0005432891289	8421CC	3389 787069	ANNA OSIPOVA	{"email": "annaosipova1973@postgrespro.ru", "phone": "+70634507157"}
0005432891290	8211F6	6254 452872	OLGA FOMINA	{"email": "fomina_olga.05111971@postgrespro.ru", "phone": "+70182927619"}
0005432891291	62663B	1576 255931	MARIYA KISELEVA	{"email": "kiseleva-m-1974@postgrespro.ru", "phone": "+70559397541"}
0005432891292	62663B	2818 669778	NATALYA EGOROVA	{"phone": "+70563960401"}
0005432891293	BE5BF5	6309 946890	GALINA PETROVA	{"phone": "+70837684615"}
0005432891294	BE5BF5	5937 630064	ANTON IVANOV	{"email": "anton-ivanov.121974@postgrespro.ru", "phone": "+70214489415"}
0005432891295	D71484	7786 526435	NADEZHDA KUDRYASHOVA	{"phone": "+70626793462"}
0005432891296	D71484	3180 731431	ELENA GRISHINA	{"email": "e_grishina_29051966@postgrespro.ru", "phone": "+70972252893"}
0005432891297	C6FC3D	5491 090861	LYUBOV LAZAREVA	{"email": "lyubov.lazareva.071977@postgrespro.ru", "phone": "+70954154693"}
0005432891298	71E830	1530 880698	ANNA POPOVA	{"phone": "+70564813197"}
0005432891299	71E830	1810 226464	YULIYA RYABOVA	{"phone": "+70740988376"}
0005432891300	76C4B6	9894 254890	ALEKSANDR ABRAMOV	{"phone": "+70726124755"}
0005432891301	76C4B6	2914 169123	GALINA NIKOLAEVA	{"email": "g.nikolaeva-1966@postgrespro.ru", "phone": "+70012022674"}
0005432891302	213B93	8153 541710	EKATERINA FEDOROVA	{"phone": "+70658678304"}
0005432891303	E1182F	9499 635555	YURIY KRASNOV	{"email": "yuriy-krasnov-02091973@postgrespro.ru", "phone": "+70825721827"}
0005432891304	B6B5A5	2886 145130	LYUDMILA SEMENOVA	{"email": "l.semenova.24101969@postgrespro.ru", "phone": "+70507517503"}
0005432891305	5AE4D4	4140 379906	VALENTINA ZAKHAROVA	{"email": "zakharova.v-10061972@postgrespro.ru", "phone": "+70435744884"}
0005432891306	9A1D02	3199 951439	TIMUR MATVEEV	{"email": "timur.matveev101971@postgrespro.ru", "phone": "+70543433819"}
0005432891307	2AB0B6	2554 660094	NIKOLAY PETROV	{"email": "petrovnikolay.121974@postgrespro.ru", "phone": "+70450646297"}
0005432891308	A3DCC5	3370 709093	NIKITA TARASOV	{"phone": "+70205263849"}
0005432891309	0DA972	6193 453675	LYUBOV IVANOVA	{"email": "ivanova-l.061979@postgrespro.ru", "phone": "+70572425731"}
0005432891310	0DA972	4769 728363	ANNA FEDOROVA	{"email": "anna_fedorova.1974@postgrespro.ru", "phone": "+70865467193"}
0005432891311	CA4A51	0495 394609	GENNADIY PAVLOV	{"phone": "+70777971079"}
0005432891313	CA4A51	5781 683094	ELVIRA KONOVALOVA	{"email": "konovalova-e-061971@postgrespro.ru", "phone": "+70033392661"}
0005432891314	4DF41C	7118 567552	ALEKSEY FEDOROV	{"email": "a.fedorov-1973@postgrespro.ru", "phone": "+70736523842"}
0005432891315	F2F744	3299 560196	SERGEY SOROKIN	{"email": "sergey_sorokin_24041963@postgrespro.ru", "phone": "+70294922417"}
0005432891316	A8CB4E	9917 229735	EKATERINA TROFIMOVA	{"phone": "+70205134654"}
0005432891317	189D9E	3007 074406	MIKHAIL KUDRYASHOV	{"phone": "+70589429836"}
0005432891318	189D9E	9135 832924	DIANA FEDOROVA	{"phone": "+70290388003"}
0005432891319	C25FDA	7595 620912	LIDIYA NAZAROVA	{"email": "l.nazarova_071970@postgrespro.ru", "phone": "+70572976629"}
0005432891320	FD142D	4715 704328	SERGEY BELOV	{"phone": "+70227429305"}
0005432891321	A2E4F8	4491 689732	GALINA ROMANOVA	{"phone": "+70069247293"}
0005432891322	DE3172	2267 338870	IGOR GUSEV	{"phone": "+70457165753"}
0005432891323	85F65A	7680 777393	PETR POPOV	{"email": "popov-p-27121977@postgrespro.ru", "phone": "+70751614233"}
0005432891324	85F65A	2831 862153	ALEKSEY ZAKHAROV	{"phone": "+70149799063"}
0005432891325	85F65A	4506 979247	ALEKSEY KUZMIN	{"email": "aleksey.kuzmin-111967@postgrespro.ru", "phone": "+70816094015"}
0005432891327	4285EC	1462 011523	VALENTINA ZOTOVA	{"phone": "+70353847354"}
0005432891328	BDAB3B	8447 920903	GEORGIY SIDOROV	{"phone": "+70786478895"}
0005432891329	BDAB3B	6874 494985	TAMARA DENISOVA	{"email": "denisovatamara_11071972@postgrespro.ru", "phone": "+70735211031"}
0005432891330	2D45C6	4742 389691	ALEKSANDR KUZMIN	{"phone": "+70744193414"}
0005432891331	F5E2E0	5935 013560	VERA LEBEDEVA	{"email": "lebedeva.v1974@postgrespro.ru", "phone": "+70764806025"}
0005432891332	351A81	7926 755236	IRINA PETROVA	{"phone": "+70082890253"}
0005432891333	AA1105	1827 034741	ALEKSANDR PETROV	{"email": "apetrov1982@postgrespro.ru", "phone": "+70873502732"}
0005432891334	28386D	8144 916343	VLADISLAV KUZNECOV	{"phone": "+70790753770"}
0005432891335	28386D	2575 842117	ANNA ANDREEVA	{"phone": "+70230009301"}
0005432891336	049EDA	7178 355014	ALEKSANDR VOLKOV	{"phone": "+70540843204"}
0005432891337	049EDA	0132 859965	DMITRIY IVANOV	{"email": "ivanovdmitriy081967@postgrespro.ru", "phone": "+70336272661"}
0005432891338	E170D5	1001 162722	VALERIYA SIDOROVA	{"phone": "+70078422433"}
0005432891339	A872F8	4959 817106	LYUBOV MEDVEDEVA	{"phone": "+70200707635"}
0005432891340	2067FA	8779 353076	EKATERINA TITOVA	{"phone": "+70707258256"}
0005432891341	2067FA	1014 271641	SERGEY KONOVALOV	{"email": "sergey.konovalov-1968@postgrespro.ru", "phone": "+70178967161"}
0005432891342	A59471	2464 175499	TATYANA BELYAEVA	{"email": "belyaeva.tatyana-031974@postgrespro.ru", "phone": "+70854361841"}
0005432891343	7784E7	5514 739607	ARINA SERGEEVA	{"phone": "+70632445605"}
0005432891344	7784E7	7411 497608	NATALYA DMITRIEVA	{"phone": "+70332795243"}
0005432891345	EEAEF9	4118 243401	FEDOR ZAYCEV	{"email": "zaycevfedor1970@postgrespro.ru", "phone": "+70603404939"}
0005432891346	53D002	8061 776049	ANNA TIKHONOVA	{"phone": "+70531355725"}
0005432891347	F0A394	9616 155067	FARIDA ALEKSEEVA	{"email": "alekseevaf_1977@postgrespro.ru", "phone": "+70478466921"}
0005432891348	C42ABF	2429 488032	MARAT ROMANOV	{"phone": "+70470377506"}
0005432891349	C42ABF	9080 860928	MIKHAIL EGOROV	{"phone": "+70637290605"}
0005432891350	EE07F9	2424 779748	YURIY CHERNOV	{"email": "y_chernov041975@postgrespro.ru", "phone": "+70519685522"}
0005432891351	1DA61D	9214 888595	ARTEM POPOV	{"email": "a-popov1965@postgrespro.ru", "phone": "+70198893061"}
0005432891352	1DA61D	5901 448673	IVAN FEDOROV	{"email": "fedorov_i1984@postgrespro.ru", "phone": "+70209251721"}
0005432891353	DDD1DB	0109 866060	NINA FILATOVA	{"email": "nina.filatova-1974@postgrespro.ru", "phone": "+70946400759"}
0005432891354	C9BCA6	5790 566313	ZINAIDA SERGEEVA	{"phone": "+70973726416"}
0005432891355	25EBD3	7891 188418	VIKTOR POPOV	{"email": "v-popov_04101964@postgrespro.ru", "phone": "+70143360424"}
0005432891356	AEAC04	6237 600732	VLADIMIR BELOV	{"email": "belov-v081965@postgrespro.ru", "phone": "+70941494010"}
0005432891357	980BCC	3276 795504	LIDIYA KAZAKOVA	{"email": "l-kazakova-111972@postgrespro.ru", "phone": "+70661000910"}
0005432891358	980BCC	7753 448171	TATYANA NESTEROVA	{"phone": "+70325723029"}
0005432891359	FA3B7C	4868 190364	ANASTASIYA PAVLOVA	{"email": "anastasiya_pavlova-29081973@postgrespro.ru", "phone": "+70713974143"}
0005432891360	FA3B7C	2336 994513	NATALYA EFREMOVA	{"phone": "+70823088269"}
0005432891361	4BFF50	9053 784825	ROMAN SEMENOV	{"email": "roman_semenov_02011974@postgrespro.ru", "phone": "+70391387244"}
0005432891362	4BFF50	8671 635582	YURIY TARASOV	{"email": "tarasov-yuriy.15121973@postgrespro.ru", "phone": "+70198168642"}
0005432891363	C42769	8374 439191	GERMAN MOROZOV	{"phone": "+70534287728"}
0005432891364	C42769	6096 950631	MAKSIM BELOV	{"phone": "+70400171018"}
0005432891365	A80786	2357 890999	OLGA VOLKOVA	{"phone": "+70947364327"}
0005432891366	A80786	5509 894687	NINA FILATOVA	{"phone": "+70059894546"}
0005432891367	A323EE	6569 696495	YURIY STEPANOV	{"email": "yuriy_stepanov04071973@postgrespro.ru", "phone": "+70088855629"}
0005432891368	A323EE	3965 494007	TATYANA GERASIMOVA	{"email": "gerasimova-tatyana_1964@postgrespro.ru", "phone": "+70136811261"}
0005432891369	57A2CF	1989 032489	ROMAN KULIKOV	{"phone": "+70372738445"}
0005432891370	AC9AC9	7669 370593	GENNADIY KOZLOV	{"email": "kozlov-g_1985@postgrespro.ru", "phone": "+70065110341"}
0005432891371	167130	4528 503045	KRISTINA ZHUKOVA	{"email": "k_zhukova-1965@postgrespro.ru", "phone": "+70188733773"}
0005432891372	167130	0897 291725	EGOR ROMANOV	{"email": "romanov-e_1974@postgrespro.ru", "phone": "+70521846767"}
0005432891373	167130	5798 754484	TATYANA BORISOVA	{"email": "borisova.tatyana.011975@postgrespro.ru", "phone": "+70301535340"}
0005432891374	0D7EE6	8808 206683	SERGEY KUZMIN	{"email": "skuzmin_061984@postgrespro.ru", "phone": "+70113722399"}
0005432891375	0D7EE6	4843 675158	VALENTINA ABRAMOVA	{"email": "abramova_valentina-1973@postgrespro.ru", "phone": "+70090658801"}
0005432891376	DAD9CC	8149 768302	EMMA MAKSIMOVA	{"phone": "+70881349504"}
0005432891377	24DCDB	3298 493466	ELENA KUZNECOVA	{"email": "elena-kuznecova-011964@postgrespro.ru", "phone": "+70106112734"}
0005432891378	A28331	3805 573272	ANDREY KOZLOV	{"email": "kozlov.a-1970@postgrespro.ru", "phone": "+70380431510"}
0005432891379	2025A5	4205 986796	ANATOLIY KUZNECOV	{"phone": "+70617262684"}
0005432891380	F40802	4230 296488	SERGEY SOLOVEV	{"phone": "+70256031433"}
0005432891381	F40802	1195 913965	MIKHAIL KUZMIN	{"email": "kuzmin-mikhail.1990@postgrespro.ru", "phone": "+70095625754"}
0005432891382	F05396	9788 585281	MARIYA GRISHINA	{"phone": "+70542788252"}
0005432891493	071C9D	7517 183950	DENIS KOZLOV	{"phone": "+70948968389"}
0005432891383	F05396	4616 740092	ANDREY KUDRYASHOV	{"email": "kudryashov_andrey101973@postgrespro.ru", "phone": "+70183727446"}
0005432891384	53685D	6546 119279	RUSLAN FEDOTOV	{"email": "r.fedotov_1973@postgrespro.ru", "phone": "+70842776614"}
0005432891385	53685D	3149 723358	EKATERINA KUZNECOVA	{"email": "e.kuznecova.1970@postgrespro.ru", "phone": "+70266924414"}
0005432891386	4DAF3C	8515 601841	ANDREY ROMANOV	{"phone": "+70944447362"}
0005432891387	FB646F	5884 733336	OLGA LEBEDEVA	{"email": "lebedeva_o.27081967@postgrespro.ru", "phone": "+70475408735"}
0005432891388	1594BD	9490 649659	MIKHAIL SOKOLOV	{"email": "mikhail.sokolov.111967@postgrespro.ru", "phone": "+70724459006"}
0005432891389	8B645B	4969 416738	PAVEL KUZNECOV	{"email": "pavelkuznecov.061966@postgrespro.ru", "phone": "+70827548356"}
0005432891390	5C4285	3373 212733	VLADIMIR PETROV	{"email": "petrov.v17051964@postgrespro.ru", "phone": "+70265190531"}
0005432891391	5C4285	9512 655953	MARIYA LAZAREVA	{"phone": "+70154087582"}
0005432891392	5C4285	9386 337280	ALEKSANDR CHERNOV	{"phone": "+70561242399"}
0005432891393	8BD7F5	4140 659717	DMITRIY NOVIKOV	{"email": "d.novikov-01091963@postgrespro.ru", "phone": "+70543686837"}
0005432891394	8BD7F5	8417 360816	KONSTANTIN POPOV	{"phone": "+70879206068"}
0005432891395	5FE27F	2970 238316	SERGEY ZHURAVLEV	{"phone": "+70423156857"}
0005432891396	7E2FED	1185 331843	GALINA SOROKINA	{"phone": "+70315339121"}
0005432891397	410BAF	2478 410892	ANNA MAKAROVA	{"phone": "+70923589525"}
0005432891398	F40391	8975 440670	IRINA SERGEEVA	{"email": "irina-sergeeva_1978@postgrespro.ru", "phone": "+70529739448"}
0005432891399	F40391	7841 742510	VLADIMIR KOZLOV	{"email": "kozlovv1976@postgrespro.ru", "phone": "+70733836083"}
0005432891400	2EA07E	1300 712684	LEYLA ROMANOVA	{"phone": "+70836789937"}
0005432891401	B1A0BA	8608 008682	ALEKSEY SAVELEV	{"email": "aleksey-savelev23121970@postgrespro.ru", "phone": "+70743602175"}
0005432891402	B1A0BA	6466 932094	LEONTIY ORLOV	{"email": "leontiy-orlov.011974@postgrespro.ru", "phone": "+70459419885"}
0005432891403	C4C7F4	4179 980951	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov_1978@postgrespro.ru", "phone": "+70126944468"}
0005432891404	0DAC31	2806 132476	YULIYA FOMINA	{"email": "fominay111976@postgrespro.ru", "phone": "+70488283628"}
0005432891405	EC00BA	6055 774646	ELENA PETROVA	{"email": "petrova-elena.01071971@postgrespro.ru", "phone": "+70350441147"}
0005432891406	EC00BA	1275 252647	ANDREY IVANOV	{"email": "ivanova26121965@postgrespro.ru", "phone": "+70498666467"}
0005432891407	7B1AE5	9546 766246	SERGEY MATVEEV	{"email": "matveevsergey_111981@postgrespro.ru", "phone": "+70744515187"}
0005432891408	7B1AE5	0414 458339	LIDIYA NESTEROVA	{"email": "nesterova-lidiya1965@postgrespro.ru", "phone": "+70338073146"}
0005432891409	6289DD	9611 523883	LYUBOV BELOVA	{"phone": "+70811049794"}
0005432891410	6289DD	0169 244046	ELENA ROMANOVA	{"phone": "+70430664101"}
0005432891411	B5C4D6	7477 410468	ANNA LUKYANOVA	{"phone": "+70361040006"}
0005432891412	A41204	7535 579268	YANA MIKHAYLOVA	{"email": "mikhaylovayana-16071969@postgrespro.ru", "phone": "+70619128574"}
0005432891413	5B6FB0	3302 198688	YURIY FEDOTOV	{"email": "yuriyfedotov.101966@postgrespro.ru", "phone": "+70949654724"}
0005432891414	3F3754	2834 678228	EVGENIYA KISELEVA	{"email": "kiseleva.e.1966@postgrespro.ru", "phone": "+70928025307"}
0005432891415	A9988C	4362 386287	ELENA OSIPOVA	{"email": "osipova_e-1979@postgrespro.ru", "phone": "+70058252775"}
0005432891416	109BC9	4371 995740	ALEKSEY SEMENOV	{"phone": "+70619980172"}
0005432891417	109BC9	1743 676926	MARIYA ORLOVA	{"email": "mariya.orlova-28101976@postgrespro.ru", "phone": "+70206165961"}
0005432891418	F97B6F	1979 616797	ANZHELIKA ANDREEVA	{"email": "andreeva.anzhelika.12041982@postgrespro.ru", "phone": "+70620446399"}
0005432891419	F97B6F	4721 370798	OLGA KAZAKOVA	{"email": "kazakova.olga081969@postgrespro.ru", "phone": "+70349846553"}
0005432891420	CB3730	7983 108259	NATALYA SMIRNOVA	{"email": "smirnovan.12051968@postgrespro.ru", "phone": "+70914196585"}
0005432891421	F43179	6002 395302	MIKHAIL FEDOROV	{"email": "mikhail.fedorov-1964@postgrespro.ru", "phone": "+70927808964"}
0005432891422	1404FE	2329 416436	IVAN PAVLOV	{"email": "ivan_pavlov1969@postgrespro.ru", "phone": "+70613396207"}
0005432891423	1404FE	4827 487337	YULIYA BORISOVA	{"phone": "+70882958864"}
0005432891424	4C31AB	3525 495034	NATALYA FOMINA	{"phone": "+70630460636"}
0005432891425	2595BC	5071 356138	ANATOLIY ZAYCEV	{"phone": "+70266680284"}
0005432891426	2595BC	6802 578620	SERGEY SAVELEV	{"phone": "+70883031012"}
0005432891427	FC5975	6511 290861	VLADIMIR CHERNOV	{"email": "chernov_v-1977@postgrespro.ru", "phone": "+70172253798"}
0005432891428	FC5975	3571 809857	NIKOLAY MELNIKOV	{"email": "melnikov-n-031972@postgrespro.ru", "phone": "+70508609380"}
0005432891429	2B27DF	1391 467190	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana071972@postgrespro.ru", "phone": "+70426056900"}
0005432891430	2B27DF	1781 134664	GALINA GAVRILOVA	{"phone": "+70771346339"}
0005432891431	E23C93	7287 344846	STEPAN SCHERBAKOV	{"email": "stepanscherbakov-1967@postgrespro.ru", "phone": "+70145247359"}
0005432891432	E23C93	8177 107319	VLADIMIR KUZMIN	{"email": "kuzminvladimir11081976@postgrespro.ru", "phone": "+70925242848"}
0005432891433	E23C93	7141 971249	ANNA KUZNECOVA	{"email": "anna-kuznecova01021984@postgrespro.ru", "phone": "+70880932810"}
0005432891434	6060AB	0962 331210	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova-29071967@postgrespro.ru", "phone": "+70673818266"}
0005432891435	D827CA	8055 781556	NINA PAVLOVA	{"email": "nina-pavlova-1976@postgrespro.ru", "phone": "+70062671245"}
0005432891436	D827CA	3205 577974	DARYA IVANOVA	{"phone": "+70433448699"}
0005432891437	D827CA	5106 383940	LARISA KISELEVA	{"phone": "+70285937477"}
0005432891438	9ADD83	8424 270657	ELIZAVETA ZHURAVLEVA	{"email": "zhuravlevaelizaveta-121966@postgrespro.ru", "phone": "+70079366303"}
0005432891439	0D4536	5706 464693	VALENTINA GUSEVA	{"email": "guseva.valentina03091970@postgrespro.ru", "phone": "+70391137971"}
0005432891440	0D4536	9221 665561	VYACHESLAV IVANOV	{"email": "ivanov-vyacheslav1972@postgrespro.ru", "phone": "+70823776876"}
0005432891441	926A2E	7092 159894	DIANA SOROKINA	{"email": "dsorokina-061967@postgrespro.ru", "phone": "+70584730300"}
0005432891442	926A2E	8981 310459	LYUBOV ZHURAVLEVA	{"email": "lyubov-zhuravleva_01091969@postgrespro.ru", "phone": "+70662807488"}
0005432891443	226FE7	2167 938892	GENNADIY SCHERBAKOV	{"email": "g.scherbakov051972@postgrespro.ru", "phone": "+70009267579"}
0005432891444	226FE7	2027 197053	LEONID PETROV	{"email": "petrov_leonid_1976@postgrespro.ru", "phone": "+70889887647"}
0005432891445	837C5D	6068 701714	NIKOLAY BORISOV	{"email": "borisov_n-1966@postgrespro.ru", "phone": "+70728970540"}
0005432891446	708B07	6192 940939	ALEKSANDR FROLOV	{"email": "afrolov_13031968@postgrespro.ru", "phone": "+70738378398"}
0005432891447	82B879	8586 712905	LYUBOV KUZNECOVA	{"phone": "+70100880458"}
0005432891448	B65EBB	4589 798611	GEORGIY SOROKIN	{"email": "georgiysorokin.061978@postgrespro.ru", "phone": "+70169213623"}
0005432891449	B65EBB	2579 820834	RAMAZAN PETROV	{"email": "petrovramazan.1976@postgrespro.ru", "phone": "+70854429116"}
0005432891450	40C36A	5922 891206	SERGEY SMIRNOV	{"phone": "+70430047505"}
0005432891451	7E1FAA	8426 719155	OLGA YAKOVLEVA	{"email": "o-yakovleva.011969@postgrespro.ru", "phone": "+70140856301"}
0005432891452	7E1FAA	0701 756103	LYUBOV OSIPOVA	{"phone": "+70835524913"}
0005432891453	0C559B	2675 418381	MARINA EFIMOVA	{"email": "m-efimova_091969@postgrespro.ru", "phone": "+70195851982"}
0005432891454	697C5B	6971 335117	KONSTANTIN KAZAKOV	{"phone": "+70252290763"}
0005432891455	697C5B	1130 908674	OKSANA POPOVA	{"phone": "+70519831598"}
0005432891456	697C5B	0838 862396	MIKHAIL ZAYCEV	{"email": "mikhail_zaycev_1977@postgrespro.ru", "phone": "+70332474203"}
0005432891457	C5D137	9798 550815	VYACHESLAV PAVLOV	{"phone": "+70424696801"}
0005432891458	C5D137	0802 913163	RAIS IVANOV	{"phone": "+70012100971"}
0005432891459	CFE506	5907 037493	ALEKSEY BONDARENKO	{"email": "alekseybondarenko_26021967@postgrespro.ru", "phone": "+70790508730"}
0005432891460	2D8788	1067 812250	ANNA LOGINOVA	{"email": "loginova_anna-04041971@postgrespro.ru", "phone": "+70114423938"}
0005432891461	720684	5048 694783	DENIS BELOV	{"email": "dbelov_13071970@postgrespro.ru", "phone": "+70100529005"}
0005432891462	97D846	0605 611468	ALBINA NOVIKOVA	{"phone": "+70501873759"}
0005432891463	5618A8	7886 073520	ANDREY ZAYCEV	{"email": "zaycev-a-091974@postgrespro.ru", "phone": "+70615494236"}
0005432891464	468229	3949 574563	VITALIY ILIN	{"email": "v.ilin_23121962@postgrespro.ru", "phone": "+70956935546"}
0005432891465	3BAD9A	5148 665484	LYUBOV IVANOVA	{"email": "ivanoval.081972@postgrespro.ru", "phone": "+70879756101"}
0005432891466	2D01AC	3885 894806	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.nadezhda-03051971@postgrespro.ru", "phone": "+70698192373"}
0005432891467	2D01AC	0676 587695	MAKSIM OSIPOV	{"phone": "+70538689340"}
0005432891468	E45FA6	0542 329871	FARID SAVELEV	{"phone": "+70321130486"}
0005432891469	B1AC8F	6257 741599	DARYA POPOVA	{"phone": "+70752803764"}
0005432891470	08623E	3533 454683	ANATOLIY CHERNOV	{"phone": "+70389341394"}
0005432891471	C0873C	1560 987902	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr_051977@postgrespro.ru", "phone": "+70932713483"}
0005432891472	62110C	6800 837696	ELIZAVETA SIDOROVA	{"phone": "+70850071750"}
0005432891473	62110C	7087 595782	ANNA NIKITINA	{"email": "nikitina_a_1975@postgrespro.ru", "phone": "+70859083654"}
0005432891474	62110C	4592 879482	LYUBOV SERGEEVA	{"email": "sergeevalyubov031973@postgrespro.ru", "phone": "+70489017730"}
0005432891475	745A11	2776 132347	NINA NIKITINA	{"phone": "+70271829284"}
0005432891476	0478F2	1842 236616	MIKHAIL MOROZOV	{"phone": "+70330947125"}
0005432891477	8644A4	8827 105310	VLADIMIR DMITRIEV	{"phone": "+70253660029"}
0005432891478	1F5DF6	8883 752478	ANATOLIY NIKOLAEV	{"email": "anatoliy.nikolaev-08031971@postgrespro.ru", "phone": "+70816653573"}
0005432891479	8A8D37	0111 250092	IRINA BORISOVA	{"email": "borisova_irina.11051978@postgrespro.ru", "phone": "+70687430235"}
0005432891480	8A8D37	0492 728216	SVETLANA VOROBEVA	{"email": "vorobevasvetlana05021960@postgrespro.ru", "phone": "+70835184593"}
0005432891481	A9675F	2359 170808	ANZHELA MIRONOVA	{"email": "anzhela_mironova23121988@postgrespro.ru", "phone": "+70157247467"}
0005432891482	80F485	7359 235934	DARYA EFREMOVA	{"phone": "+70962979491"}
0005432891483	3C7420	0437 445021	MARIYA EFREMOVA	{"email": "m-efremova111966@postgrespro.ru", "phone": "+70950703683"}
0005432891484	4EAE0D	4722 328569	OLGA GERASIMOVA	{"phone": "+70887128325"}
0005432891485	1F91B5	6312 217529	ANTONINA NAZAROVA	{"phone": "+70078250143"}
0005432891486	1F91B5	2956 135159	NIKOLAY FEDOROV	{"phone": "+70734496272"}
0005432891487	DE9E3D	6751 189549	ELENA KUZNECOVA	{"email": "kuznecovae091966@postgrespro.ru", "phone": "+70717698492"}
0005432891488	DE9E3D	3625 648712	EVGENIY SAVELEV	{"phone": "+70141902152"}
0005432891489	E675FB	9122 594967	VIKTOR FEDOTOV	{"phone": "+70639270092"}
0005432891490	74E5F4	8031 388869	VLADIMIR POPOV	{"phone": "+70501725256"}
0005432891492	41C128	4703 520849	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev.11081965@postgrespro.ru", "phone": "+70604262984"}
0005432891494	E6D8F1	1455 014920	ANASTASIYA KOROLEVA	{"email": "koroleva_a-1984@postgrespro.ru", "phone": "+70479814176"}
0005432891495	C85521	0844 841399	VYACHESLAV BARANOV	{"email": "baranovv-071974@postgrespro.ru", "phone": "+70004533657"}
0005432891496	A40E2C	0811 539453	NATALYA ANISIMOVA	{"phone": "+70392479238"}
0005432891497	A40E2C	5890 896537	VLADIMIR MOROZOV	{"email": "morozov_v_05021965@postgrespro.ru", "phone": "+70340958001"}
0005432891498	9B4AEE	9400 527596	PETR VOROBEV	{"phone": "+70484842622"}
0005432891499	6D604D	5740 276755	NATALYA KOZLOVA	{"email": "kozlova_natalya_04051977@postgrespro.ru", "phone": "+70575194415"}
0005432891500	8789AE	6095 153233	ANASTASIYA FILIPPOVA	{"phone": "+70919195951"}
0005432891501	18668C	2541 315192	MAKSIM VLASOV	{"email": "m.vlasov.1972@postgrespro.ru", "phone": "+70858629362"}
0005432891502	18668C	2627 862292	NATALYA KOROLEVA	{"email": "natalyakoroleva.29091976@postgrespro.ru", "phone": "+70564462506"}
0005432891503	E480D3	6429 411686	ZOYA VOLKOVA	{"phone": "+70159577042"}
0005432891504	357938	3684 354592	NADEZHDA EFIMOVA	{"email": "efimovan_19071965@postgrespro.ru", "phone": "+70324521449"}
0005432891505	357938	4637 518185	VYACHESLAV SOLOVEV	{"email": "v.solovev071974@postgrespro.ru", "phone": "+70494653238"}
0005432891506	3BE38A	0470 991958	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov-091977@postgrespro.ru", "phone": "+70622842398"}
0005432891507	3BE38A	2573 906355	ELENA KOZLOVA	{"phone": "+70444025522"}
0005432891508	EF56B1	1116 795690	SVETLANA TIMOFEEVA	{"email": "timofeeva.svetlana_11111978@postgrespro.ru", "phone": "+70202292897"}
0005432891509	EF56B1	8509 384440	DARYA KUZNECOVA	{"email": "kuznecova-darya.1968@postgrespro.ru", "phone": "+70596606579"}
0005432891510	908AAB	6839 084017	ILYA BELOV	{"phone": "+70973973683"}
0005432891511	908AAB	1105 257973	YULIYA YAKOVLEVA	{"email": "yyakovleva-1973@postgrespro.ru", "phone": "+70169399822"}
0005432891512	8B6D2F	1374 723421	ZOYA KOLESNIKOVA	{"email": "zkolesnikova.15011967@postgrespro.ru", "phone": "+70325567544"}
0005432891513	8B6D2F	3791 223511	YANA AFANASEVA	{"phone": "+70372953647"}
0005432891514	23E7B1	6794 211669	NADEZHDA ABRAMOVA	{"email": "n.abramova.1980@postgrespro.ru", "phone": "+70087712755"}
0005432891515	04D13E	7065 447098	VADIM NIKITIN	{"phone": "+70122450676"}
0005432891516	9184CC	3488 320206	VERA ZHUKOVA	{"phone": "+70546349785"}
0005432891517	A566A3	2945 344413	YANA NOVIKOVA	{"phone": "+70143593846"}
0005432891518	FFB6D8	8169 530184	MAKSIM MIRONOV	{"phone": "+70910568894"}
0005432891519	414D9A	3069 828544	VALENTINA STEPANOVA	{"email": "stepanova-v-10071981@postgrespro.ru", "phone": "+70473011459"}
0005432891520	457AD8	5149 050600	ALEKSEY ABRAMOV	{"email": "abramov.a.061984@postgrespro.ru", "phone": "+70384759809"}
0005432891521	457AD8	4649 852355	ANATOLIY VASILEV	{"phone": "+70460196892"}
0005432891522	E98D89	5700 482322	ZINAIDA MARTYNOVA	{"phone": "+70004324150"}
0005432891523	746394	1338 878939	ANDREY SAVELEV	{"email": "a-savelev-081973@postgrespro.ru", "phone": "+70530759718"}
0005432891524	746394	5789 501985	NATALYA SOLOVEVA	{"email": "solovevanatalya_021967@postgrespro.ru", "phone": "+70220310653"}
0005432891525	8811A4	6151 624924	ANASTASIYA BELOVA	{"email": "anastasiyabelova.29041980@postgrespro.ru", "phone": "+70499436587"}
0005432891526	F9B947	1706 042577	LYUDMILA LUKYANOVA	{"email": "lukyanova.l31031962@postgrespro.ru", "phone": "+70467961187"}
0005432891527	773DD4	9294 253524	ALLA IVANOVA	{"email": "ivanovaa1966@postgrespro.ru", "phone": "+70635874502"}
0005432891528	641E81	0873 506523	EVGENIYA VLASOVA	{"email": "vlasovaevgeniya_011982@postgrespro.ru", "phone": "+70336516262"}
0005432891529	CAFF38	6728 364656	VALENTINA FADEEVA	{"phone": "+70433827874"}
0005432891530	98FFD0	3913 484261	KAMILLA STEPANOVA	{"email": "k-stepanova_28091965@postgrespro.ru", "phone": "+70289750021"}
0005432891531	98FFD0	3364 524530	ILMIRA SAVELEVA	{"email": "saveleva-ilmira-04071959@postgrespro.ru", "phone": "+70076561427"}
0005432891532	FBC9F4	9661 499794	OLGA IVANOVA	{"phone": "+70101533236"}
0005432891533	049EE9	1078 985890	TATYANA KUZNECOVA	{"phone": "+70784526068"}
0005432891534	049EE9	5452 303560	NATALYA ZAYCEVA	{"email": "natalya_zayceva-1969@postgrespro.ru", "phone": "+70522134628"}
0005432891535	F2384C	1014 837140	ARTEM POPOV	{"email": "popov_artem.25101970@postgrespro.ru", "phone": "+70373744262"}
0005432891536	F2384C	6220 798940	MAKSIM OSIPOV	{"phone": "+70258741493"}
0005432891537	828D66	7422 317659	YURIY SOKOLOV	{"phone": "+70392313328"}
0005432891538	F4EE0D	6344 676752	NADEZHDA OSIPOVA	{"phone": "+70062057389"}
0005432891539	F4EE0D	3976 845856	NIKOLAY NIKITIN	{"phone": "+70662819049"}
0005432891540	5397EA	7619 078379	ELENA MAKSIMOVA	{"email": "e_maksimova-1975@postgrespro.ru", "phone": "+70466692434"}
0005432891541	9A0889	1996 216206	OLGA DENISOVA	{"email": "o_denisova1958@postgrespro.ru", "phone": "+70616606503"}
0005432891542	9A0889	7196 932047	PETR MOISEEV	{"phone": "+70176253246"}
0005432891543	A21A51	0553 098121	VALENTINA ANDREEVA	{"email": "vandreeva.20111969@postgrespro.ru", "phone": "+70821530745"}
0005432891544	2CD95D	0931 951695	ROMAN IVANOV	{"phone": "+70221052799"}
0005432891545	278D01	1669 822030	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey-25091976@postgrespro.ru", "phone": "+70593688443"}
0005432891546	278D01	1415 624719	YULIYA KUZNECOVA	{"email": "ykuznecova.1967@postgrespro.ru", "phone": "+70659388959"}
0005432891547	278D01	8121 188825	PAVEL IVANOV	{"phone": "+70094590337"}
0005432891548	DE792A	6538 345117	VIKTORIYA BORISOVA	{"phone": "+70966671421"}
0005432891549	B92477	3427 280459	VLADIMIR FEDOROV	{"email": "vfedorov04021972@postgrespro.ru", "phone": "+70169997901"}
0005432891550	F5CDB6	6483 044828	SVETLANA LEBEDEVA	{"phone": "+70661698724"}
0005432891551	F5CDB6	3563 102343	DILYARA KOROLEVA	{"phone": "+70106190529"}
0005432891552	F5CDB6	0655 789106	MARINA DENISOVA	{"email": "denisova-marina_121970@postgrespro.ru", "phone": "+70885281189"}
0005432891553	C02F3B	8649 985114	OLEG VASILEV	{"phone": "+70946925132"}
0005432891554	A0BAC9	4569 063025	MARIYA MARTYNOVA	{"phone": "+70695587204"}
0005432891555	A69AF3	0918 817397	SERGEY KUZNECOV	{"email": "kuznecov_sergey-1962@postgrespro.ru", "phone": "+70423470129"}
0005432891556	A69AF3	7791 976928	ANATOLIY BARANOV	{"phone": "+70415904348"}
0005432891557	A69AF3	1577 758012	KIRILL SCHERBAKOV	{"phone": "+70944851579"}
0005432891558	F2F794	7804 736416	SERGEY MELNIKOV	{"email": "melnikov_s_24121967@postgrespro.ru", "phone": "+70964328294"}
0005432891559	2EBC54	9894 752282	ANNA VASILEVA	{"phone": "+70237986929"}
0005432891560	D886D7	0849 061868	TATYANA ISAEVA	{"email": "t.isaeva-121980@postgrespro.ru", "phone": "+70598434388"}
0005432891561	D886D7	6800 480643	ALEKSANDR MEDVEDEV	{"email": "medvedev_aleksandr.021986@postgrespro.ru", "phone": "+70614208191"}
0005432891562	20AFC9	6255 095111	EVGENIY KOZLOV	{"email": "e-kozlov.1962@postgrespro.ru", "phone": "+70011421658"}
0005432891563	154290	7519 718940	SERGEY FILIPPOV	{"phone": "+70034738754"}
0005432891564	154290	4507 688554	NATALYA ALEKSEEVA	{"email": "nalekseeva021970@postgrespro.ru", "phone": "+70959083057"}
0005432891565	93C609	6350 698073	OLGA MEDVEDEVA	{"email": "medvedeva.olga_071977@postgrespro.ru", "phone": "+70819188915"}
0005432891566	DA32B6	2728 298786	VASILIY ROMANOV	{"phone": "+70847175172"}
0005432891567	04881D	0180 681131	LYUDMILA VOROBEVA	{"email": "lvorobeva_11121953@postgrespro.ru", "phone": "+70984706843"}
0005432891568	24006C	2082 898494	VLADIMIR KUZNECOV	{"email": "v-kuznecov-1970@postgrespro.ru", "phone": "+70595119596"}
0005432891569	24006C	7816 773127	VALENTINA ANISIMOVA	{"phone": "+70527761504"}
0005432891570	749183	3480 045969	ARINA IVANOVA	{"email": "ivanova_arina-05111966@postgrespro.ru", "phone": "+70286015101"}
0005432891571	CA5A13	7341 890167	GALINA ALEKSEEVA	{"phone": "+70830165300"}
0005432891572	1CD8CD	4646 773615	DMITRIY FOMIN	{"phone": "+70318160623"}
0005432891573	9CCD0B	7529 795287	NATALYA ZOTOVA	{"phone": "+70880931080"}
0005432891574	EEA71A	8235 606860	GALINA SEMENOVA	{"phone": "+70874777848"}
0005432891575	815292	8738 428455	PETR SCHERBAKOV	{"email": "petr_scherbakov-1966@postgrespro.ru", "phone": "+70964600673"}
0005432891576	3AC2B8	1033 633753	PETR KUZNECOV	{"email": "kuznecov-p_1973@postgrespro.ru", "phone": "+70374523201"}
0005432891577	6F32B6	1076 174792	GALINA NIKITINA	{"email": "nikitina-g.15111949@postgrespro.ru", "phone": "+70944864735"}
0005432891578	240AA8	5995 008606	YURIY KUZMIN	{"phone": "+70505699722"}
0005432891579	4D0721	2894 469011	IRINA NIKITINA	{"email": "nikitina_irina_1970@postgrespro.ru", "phone": "+70781465892"}
0005432891580	35CF88	7653 631236	MARIYA NESTEROVA	{"phone": "+70766315191"}
0005432891581	40761E	2639 893565	TIMUR SHEVCHENKO	{"phone": "+70813875299"}
0005432891582	27F06E	0322 303550	TAMARA EFREMOVA	{"email": "efremova-t_02061960@postgrespro.ru", "phone": "+70725498553"}
0005432891583	27F06E	0171 245161	DMITRIY IVANOV	{"phone": "+70103100363"}
0005432891584	EEB1F2	6799 858561	NINA ILINA	{"email": "nilina021974@postgrespro.ru", "phone": "+70706574119"}
0005432891585	EEB1F2	5339 775384	IRINA ERMAKOVA	{"email": "ermakova.i.1980@postgrespro.ru", "phone": "+70801810968"}
0005432891586	E78A7F	0339 762602	VASILIY DAVYDOV	{"phone": "+70089783970"}
0005432891587	F83A2F	9132 474323	LIDIYA RODIONOVA	{"phone": "+70447826461"}
0005432891588	A6B12D	0193 365899	ELENA TARASOVA	{"email": "elena.tarasova_011971@postgrespro.ru", "phone": "+70240246162"}
0005432891589	A1A81A	8008 459550	MAKSIM ILIN	{"email": "ilinmaksim1974@postgrespro.ru", "phone": "+70297861432"}
0005432891590	A1A81A	8539 443034	TATYANA POPOVA	{"email": "popova_tatyana.081974@postgrespro.ru", "phone": "+70442617620"}
0005432891591	E93D6D	9394 719648	ZAKHAR MELNIKOV	{"email": "z_melnikov_07031976@postgrespro.ru", "phone": "+70664119205"}
0005432891592	E93D6D	2658 072876	YURIY NIKOLAEV	{"email": "yuriy.nikolaev_1964@postgrespro.ru", "phone": "+70746378310"}
0005432891593	90886C	8566 235650	OLEG NAZAROV	{"phone": "+70290036634"}
0005432891594	90886C	1637 008959	LYUBOV VASILEVA	{"email": "vasilevalyubov.1970@postgrespro.ru", "phone": "+70079742183"}
0005432891595	10B960	5160 666027	ARTEM RODIONOV	{"email": "artem-rodionov041975@postgrespro.ru", "phone": "+70838825665"}
0005432891596	E519E0	1436 193172	NATALYA SOLOVEVA	{"phone": "+70442536824"}
0005432892767	B89F1E	2177 827936	MIKHAIL GORBUNOV	{"phone": "+70419147955"}
0005432892719	37D63E	3421 743734	IGOR ANTONOV	{"email": "i_antonov08061981@postgrespro.ru", "phone": "+70007561262"}
0005432892720	F518E3	6466 357956	NADEZHDA GAVRILOVA	{"email": "gavrilova_n.09111969@postgrespro.ru", "phone": "+70108421596"}
0005432892721	F518E3	3711 328413	VLADIMIR ILIN	{"email": "ilinvladimir_25111969@postgrespro.ru", "phone": "+70328953750"}
0005432892722	F518E3	1351 163504	ELENA ORLOVA	{"phone": "+70519853479"}
0005432892723	E0E905	9456 157052	LIDIYA KUZNECOVA	{"phone": "+70573556770"}
0005432892724	E83376	6219 205424	IRINA NIKOLAEVA	{"email": "inikolaeva.12051978@postgrespro.ru", "phone": "+70208128921"}
0005432892725	2A9276	6564 144517	PETR ABRAMOV	{"email": "abramovp_101968@postgrespro.ru", "phone": "+70147320989"}
0005432892726	B7F5F9	2955 792385	GALINA DAVYDOVA	{"email": "g_davydova.26051974@postgrespro.ru", "phone": "+70178179265"}
0005432892727	B7F5F9	4222 568439	VLADIMIR PAVLOV	{"email": "vladimir-pavlov01111969@postgrespro.ru", "phone": "+70848261693"}
0005432892728	4EFABC	1798 643587	VLADIMIR GRIGOREV	{"email": "v_grigorev041972@postgrespro.ru", "phone": "+70759484370"}
0005432892729	B0D366	6280 433330	LYUDMILA MASLOVA	{"email": "maslovalyudmila051967@postgrespro.ru", "phone": "+70219830138"}
0005432892730	346573	0807 289473	RADIK DENISOV	{"email": "denisov_radik101964@postgrespro.ru", "phone": "+70562119735"}
0005432892731	DD8CBB	2545 151659	ELENA NIKOLAEVA	{"email": "nikolaeva.elena-051986@postgrespro.ru", "phone": "+70185613610"}
0005432892732	7E3795	1114 214874	ALEKSANDR POPOV	{"email": "popov.a-14071976@postgrespro.ru", "phone": "+70135548588"}
0005432892733	082717	2986 752928	ANDREY ANDREEV	{"phone": "+70497674914"}
0005432892734	B50F1D	7973 049061	OLGA NIKOLAEVA	{"phone": "+70145683302"}
0005432892735	B50F1D	3582 825306	ILYA YAKOVLEV	{"email": "i.yakovlev_23061968@postgrespro.ru", "phone": "+70759311040"}
0005432892736	421B7E	5774 254412	ANDREY VLASOV	{"phone": "+70974297480"}
0005432892737	421B7E	6135 489230	ROMAN NAZAROV	{"phone": "+70575383163"}
0005432892738	D7997B	4617 576154	TATYANA MELNIKOVA	{"phone": "+70578638844"}
0005432892739	C3356B	5563 827815	NATALYA GERASIMOVA	{"phone": "+70523690967"}
0005432892740	3B1A0B	0685 006238	EKATERINA ERMAKOVA	{"phone": "+70752171906"}
0005432892741	3B1A0B	2309 242269	GERMAN BORISOV	{"phone": "+70724922211"}
0005432892742	999552	6936 070891	SERGEY MAKAROV	{"phone": "+70314189100"}
0005432892743	999552	7144 888304	NIKOLAY SOKOLOV	{"phone": "+70814186368"}
0005432892744	F5292D	8794 389920	MIKHAIL TARASOV	{"email": "mtarasov_09041971@postgrespro.ru", "phone": "+70151766248"}
0005432892745	2D9C99	3743 404126	LIDIYA KOROLEVA	{"phone": "+70617085073"}
0005432892746	EA192F	4688 716400	ANDREY ZHUKOV	{"email": "zhukov-a.17041974@postgrespro.ru", "phone": "+70211837476"}
0005432892747	1FAF4D	0311 261349	TATYANA MOROZOVA	{"email": "morozova-t.011976@postgrespro.ru", "phone": "+70026164201"}
0005432892748	B965D2	4064 081786	VLADIMIR AFANASEV	{"email": "v.afanasev-04011976@postgrespro.ru", "phone": "+70610106919"}
0005432892749	B965D2	3742 638287	KSENIYA POTAPOVA	{"phone": "+70702142107"}
0005432892750	B965D2	0904 229019	ANNA ORLOVA	{"email": "a_orlova_28071973@postgrespro.ru", "phone": "+70000246818"}
0005432892751	7D45F7	3822 725074	OLEG MAKSIMOV	{"email": "o.maksimov1975@postgrespro.ru", "phone": "+70637709096"}
0005432892752	62A420	6650 730814	KRISTINA MIKHAYLOVA	{"email": "mikhaylova_kristina_1965@postgrespro.ru", "phone": "+70641489862"}
0005432892753	4ED865	7806 771531	OKSANA KOMAROVA	{"phone": "+70388733412"}
0005432892754	DD0100	2524 443925	ELENA KUDRYASHOVA	{"phone": "+70096757640"}
0005432892755	888959	0532 561848	NIKOLAY KAZAKOV	{"email": "kazakov-nikolay_21091966@postgrespro.ru", "phone": "+70883072150"}
0005432892756	DA8B1A	8844 665546	OLGA KOZLOVA	{"phone": "+70989616337"}
0005432892757	8707DF	7968 525394	ANASTASIYA ILINA	{"phone": "+70662278412"}
0005432892758	61ED70	6612 893781	ANDREY SOROKIN	{"email": "andreysorokin_26091976@postgrespro.ru", "phone": "+70543675670"}
0005432892759	6CCEF9	8370 571497	ALEKSANDR YAKOVLEV	{"phone": "+70120347900"}
0005432892760	AEF723	7332 602836	TATYANA NAZAROVA	{"phone": "+70631219598"}
0005432892761	AEF723	0188 748254	ELENA NIKIFOROVA	{"email": "nikiforova-e.111971@postgrespro.ru", "phone": "+70993154949"}
0005432892762	AEF723	6853 349251	ELENA GAVRILOVA	{"email": "e_gavrilova_1973@postgrespro.ru", "phone": "+70129493749"}
0005432892763	AEF723	3829 786295	VLADIMIR KARPOV	{"email": "karpov-v-05031972@postgrespro.ru", "phone": "+70767792159"}
0005432892764	3C3CEE	4140 149033	NATALYA DMITRIEVA	{"phone": "+70469279571"}
0005432892765	9F90FD	4757 573974	LIDIYA GERASIMOVA	{"phone": "+70840277549"}
0005432892766	3C0BF7	9033 106885	ALEKSANDR ZHURAVLEV	{"phone": "+70118360923"}
0005432892768	B89F1E	4733 199414	VALENTINA ILINA	{"email": "ilina_v_041966@postgrespro.ru", "phone": "+70725990448"}
0005432892769	EB6BCC	5845 823070	EVGENIY RODIONOV	{"phone": "+70878501095"}
0005432892770	EB6BCC	1960 702259	SOFYA ARKHIPOVA	{"phone": "+70275871836"}
0005432892771	EB6BCC	3679 628176	RUSLAN FEDOROV	{"email": "fedorov-ruslan_29091965@postgrespro.ru", "phone": "+70113992960"}
0005432892772	53680D	9148 540372	TATYANA EGOROVA	{"email": "egorova-t_1950@postgrespro.ru", "phone": "+70471833855"}
0005432892773	91DBEE	5262 166087	ANTONINA PETROVA	{"email": "apetrova_1975@postgrespro.ru", "phone": "+70895847648"}
0005432892774	91DBEE	4293 480386	SERGEY GAVRILOV	{"phone": "+70562925070"}
0005432892775	0D0E84	8664 508375	ALEKSANDR STEPANOV	{"phone": "+70614408861"}
0005432892776	E42B4B	4437 725561	ARINA EGOROVA	{"email": "a.egorova051977@postgrespro.ru", "phone": "+70932357682"}
0005432892777	6035ED	3486 322889	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir-121973@postgrespro.ru", "phone": "+70493260637"}
0005432892778	BF85DE	2039 438589	LIDIYA DAVYDOVA	{"phone": "+70627511392"}
0005432892779	BF85DE	7504 130231	SVETLANA IVANOVA	{"email": "svetlana-ivanova1973@postgrespro.ru", "phone": "+70832211336"}
0005432892780	92CFE6	6602 046116	ANASTASIYA POTAPOVA	{"email": "anastasiya.potapova-31081969@postgrespro.ru", "phone": "+70658919210"}
0005432892781	D72B89	9429 923135	OLGA FROLOVA	{"email": "frolova-o1978@postgrespro.ru", "phone": "+70177057594"}
0005432892782	73B02A	9836 187422	ALINA BELYAEVA	{"phone": "+70527912485"}
0005432892783	8EF498	6839 795701	KIRILL SMIRNOV	{"email": "kirillsmirnov1961@postgrespro.ru", "phone": "+70615573446"}
0005432892784	B30736	3872 655445	PAVEL MOROZOV	{"phone": "+70240718302"}
0005432892785	7B2564	6961 341882	YURIY MIRONOV	{"email": "yuriymironov011980@postgrespro.ru", "phone": "+70836454770"}
0005432892786	B5EF70	8125 505417	ALEKSANDR EGOROV	{"email": "a-egorov-1964@postgrespro.ru", "phone": "+70618536433"}
0005432892787	B5EF70	4981 650538	ANATOLIY VASILEV	{"phone": "+70952417201"}
0005432892788	49C010	5186 019369	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy-07021964@postgrespro.ru", "phone": "+70293726253"}
0005432892789	49C010	5139 310089	SERGEY ABRAMOV	{"email": "abramov.s_061971@postgrespro.ru", "phone": "+70818261274"}
0005432892790	9570D7	5894 948855	GEORGIY KUZNECOV	{"phone": "+70833965629"}
0005432892791	9570D7	5156 717255	GALINA SERGEEVA	{"email": "galinasergeeva.031976@postgrespro.ru", "phone": "+70759012119"}
0005432892792	46903D	9758 199361	LYUDMILA NIKIFOROVA	{"email": "lyudmila.nikiforova.26111968@postgrespro.ru", "phone": "+70621240438"}
0005432892793	CDD2BA	7902 537766	SERGEY KARPOV	{"phone": "+70763461849"}
0005432892794	462566	7802 874970	NATALIYA LEBEDEVA	{"email": "lebedevanataliya-021971@postgrespro.ru", "phone": "+70835851367"}
0005432892795	594A96	1401 417120	NADEZHDA EGOROVA	{"phone": "+70556061318"}
0005432892796	594A96	8565 353018	VLADLEN VOLKOV	{"phone": "+70913229477"}
0005432892797	594A96	9144 689592	OLGA ARKHIPOVA	{"phone": "+70277536995"}
0005432892798	8057B5	1667 520922	GEVORG SERGEEV	{"email": "gevorg_sergeev1974@postgrespro.ru", "phone": "+70385542396"}
0005432892799	6A3727	8448 609079	VALENTINA SERGEEVA	{"email": "sergeeva_v-061973@postgrespro.ru", "phone": "+70547986849"}
0005432892800	08D39E	0748 438688	SERGEY SIDOROV	{"phone": "+70271953060"}
0005432892801	181914	8022 387814	EVGENIYA OVCHINNIKOVA	{"phone": "+70732482945"}
0005432892802	050675	9638 864436	DARYA LUKYANOVA	{"email": "daryalukyanova21091977@postgrespro.ru", "phone": "+70286506849"}
0005432892803	050675	3248 756749	GALINA FILATOVA	{"phone": "+70320857383"}
0005432892804	A8D922	1087 711939	ILYA PETROV	{"email": "ilya-petrov_27061969@postgrespro.ru", "phone": "+70318005132"}
0005432892805	A8D922	9014 973834	NATALYA CHERNOVA	{"phone": "+70889061873"}
0005432892806	8360DB	0816 628533	KONSTANTIN SEMENOV	{"email": "semenov-k_031969@postgrespro.ru", "phone": "+70820226907"}
0005432892807	8360DB	3823 573788	PAVEL ORLOV	{"email": "orlov_p_011969@postgrespro.ru", "phone": "+70329943568"}
0005432892808	3B66D6	9973 815848	MIKHAIL MIRONOV	{"phone": "+70685339858"}
0005432892809	FB28A1	0848 872089	ROZA KOZLOVA	{"phone": "+70770411837"}
0005432892810	6D33F8	0668 833707	SERGEY KISELEV	{"phone": "+70395359347"}
0005432892811	F3A2E6	5031 355455	ARTEM IVANOV	{"phone": "+70359280021"}
0005432892812	F3A2E6	1255 818265	ALEKSANDR BARANOV	{"email": "baranovaleksandr.17071988@postgrespro.ru", "phone": "+70737275006"}
0005432892813	F3A2E6	1724 725533	ALINA SERGEEVA	{"email": "sergeeva_alina-121984@postgrespro.ru", "phone": "+70737128220"}
0005432892814	B685DE	1675 018522	ALENA NIKITINA	{"email": "alena.nikitina12031983@postgrespro.ru", "phone": "+70127536185"}
0005432892815	010905	3832 603962	VIKTOR VOROBEV	{"phone": "+70524718039"}
0005432892816	010905	0671 856698	VIKTOR SIDOROV	{"email": "sidorovv-09091969@postgrespro.ru", "phone": "+70559301395"}
0005432892817	6E892B	9885 620105	RUSLAN POPOV	{"phone": "+70829196516"}
0005432892818	9F7014	7874 247657	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev.1966@postgrespro.ru", "phone": "+70266413765"}
0005432892819	277F29	5348 399008	ALEKSANDR TIMOFEEV	{"phone": "+70634425476"}
0005432892820	C46D57	9848 821117	NADEZHDA ZAKHAROVA	{"phone": "+70916730528"}
0005432892821	811E62	1334 147873	VIKTOR FILIPPOV	{"phone": "+70078170988"}
0005432892822	811E62	7467 862726	NADEZHDA GERASIMOVA	{"phone": "+70320600344"}
0005432892823	794049	4330 512573	VLADIMIR SEMENOV	{"phone": "+70527001433"}
0005432892824	794049	5757 070746	NIKOLAY SEMENOV	{"email": "nikolay-semenov-1975@postgrespro.ru", "phone": "+70937199593"}
0005432892825	5E5A4F	5669 492722	LARISA RODIONOVA	{"phone": "+70805325361"}
0005432901385	7A63FA	1830 823396	GALINA POPOVA	{"phone": "+70029386978"}
0005432901293	25AD42	3251 928781	OKSANA FILATOVA	{"phone": "+70381522347"}
0005432901294	974865	0606 557668	GALINA KOMAROVA	{"phone": "+70866277886"}
0005432901295	6F9A8E	9809 811367	VLADIMIR KONOVALOV	{"email": "konovalovvladimir-1977@postgrespro.ru", "phone": "+70263925561"}
0005432901296	995132	8399 285472	MARIYA MOROZOVA	{"phone": "+70901329709"}
0005432901297	5CBAC3	1999 674403	ELENA KUZMINA	{"email": "kuzminaelena-121962@postgrespro.ru", "phone": "+70824257303"}
0005432901298	6E54A8	9519 402481	EKATERINA LUKYANOVA	{"phone": "+70337861552"}
0005432901299	A93B79	7438 652806	EVGENIY MIKHAYLOV	{"phone": "+70273829781"}
0005432901300	AA3FCE	0925 477284	NIKOLAY MEDVEDEV	{"email": "medvedev-nikolay-1973@postgrespro.ru", "phone": "+70901140479"}
0005432901301	E3A2C8	3116 037013	YULIYA TROFIMOVA	{"phone": "+70510628439"}
0005432901302	E3A2C8	4417 995815	NIKOLAY IVANOV	{"email": "ivanov-n-03081981@postgrespro.ru", "phone": "+70271010187"}
0005432901303	72F58C	3992 661011	SVETLANA SEMENOVA	{"phone": "+70541240886"}
0005432901304	72F58C	5222 127431	ALEKSEY KISELEV	{"phone": "+70156198187"}
0005432901305	175A23	2955 990626	ELENA GUSEVA	{"phone": "+70125219025"}
0005432901306	175A23	2409 935195	SERGEY BONDARENKO	{"phone": "+70534189092"}
0005432901307	125042	6743 985889	VERA RYABOVA	{"email": "vera-ryabova-21071972@postgrespro.ru", "phone": "+70464523365"}
0005432901308	B3BBAA	8395 869768	NIKOLAY YAKOVLEV	{"phone": "+70133436102"}
0005432901309	B3BBAA	2360 734410	SVETLANA KUZNECOVA	{"phone": "+70679742795"}
0005432901310	2A1DD3	6625 298037	ALEKSANDRA KOROLEVA	{"phone": "+70892478145"}
0005432901311	2A1DD3	2222 859839	ANNA KOROLEVA	{"phone": "+70633610616"}
0005432901312	67013A	1961 687303	ALEKSANDR AFANASEV	{"phone": "+70456486716"}
0005432901313	FE2444	8916 805441	RINAT STEPANOV	{"email": "r-stepanov081960@postgrespro.ru", "phone": "+70149545659"}
0005432901314	FE2444	8073 617133	RAMIL KRASNOV	{"phone": "+70106765594"}
0005432901315	4C8C37	1313 468925	LARISA SMIRNOVA	{"email": "smirnova.larisa-091973@postgrespro.ru", "phone": "+70678595616"}
0005432901316	CA6F87	4737 743663	VLADIMIR YAKOVLEV	{"email": "v_yakovlev-1974@postgrespro.ru", "phone": "+70435278944"}
0005432901317	CA6F87	2356 582745	EDUARD SEMENOV	{"phone": "+70662027017"}
0005432901318	C46125	3274 603268	SERGEY ROMANOV	{"phone": "+70178173255"}
0005432901319	46DFE1	0229 129463	YURIY GRIGOREV	{"phone": "+70547327359"}
0005432901320	331DAE	9452 227427	KSENIYA GERASIMOVA	{"email": "gerasimova.k011967@postgrespro.ru", "phone": "+70966379324"}
0005432901321	331DAE	3912 212730	GEORGIY VASILEV	{"phone": "+70473032237"}
0005432901322	BEB0ED	7031 433194	NINA VOROBEVA	{"email": "nina_vorobeva-011970@postgrespro.ru", "phone": "+70310561957"}
0005432901323	3A0F1E	5651 995663	LYUDMILA MIRONOVA	{"phone": "+70155686332"}
0005432901324	11D5A6	9514 419660	VIKTOR FROLOV	{"email": "v_frolov_071981@postgrespro.ru", "phone": "+70369032653"}
0005432901325	4F7219	4126 610392	PAVEL VASILEV	{"phone": "+70125893134"}
0005432901326	B59C5F	8137 871707	KLAVDIYA VLASOVA	{"email": "vlasova.klavdiya-17111966@postgrespro.ru", "phone": "+70230331589"}
0005432901327	447F39	7717 230521	ILGIZ SOKOLOV	{"email": "sokolov_ilgiz_041980@postgrespro.ru", "phone": "+70396422955"}
0005432901328	715D15	0013 759567	ANDREY IVANOV	{"email": "ivanovandrey_051982@postgrespro.ru", "phone": "+70948316334"}
0005432901329	DE0262	3432 997686	ALEKSEY MOROZOV	{"phone": "+70221146138"}
0005432901330	4BADB6	3054 267371	YURIY BELOV	{"phone": "+70610299442"}
0005432901331	AE9DC9	4493 684686	TAMARA IVANOVA	{"phone": "+70156729318"}
0005432901332	AE9DC9	2563 620807	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko.021963@postgrespro.ru", "phone": "+70272090026"}
0005432901333	4F9FDC	6832 316015	MARINA OSIPOVA	{"email": "marina.osipova-031977@postgrespro.ru", "phone": "+70866072827"}
0005432901334	4F9FDC	5468 976007	ROBERT FILIPPOV	{"email": "robert.filippov071973@postgrespro.ru", "phone": "+70712966287"}
0005432901335	E02408	2881 523374	SOFYA NIKITINA	{"phone": "+70849521861"}
0005432901336	1E7A3B	6394 479175	ALEKSEY GORBUNOV	{"phone": "+70901679486"}
0005432901337	1F1A0D	5967 919655	ANASTASIYA ISAEVA	{"email": "isaeva.a.24111973@postgrespro.ru", "phone": "+70750459833"}
0005432901338	039E30	7567 333161	SERGEY BONDARENKO	{"email": "bondarenko_sergey.111966@postgrespro.ru", "phone": "+70859769048"}
0005432901339	8C67DB	0765 668521	ALLA KOVALEVA	{"phone": "+70379935105"}
0005432901340	8C67DB	9427 483552	PAVEL BARANOV	{"email": "baranov-p.13101966@postgrespro.ru", "phone": "+70504013116"}
0005432901341	B30D68	3527 431542	SVETLANA IVANOVA	{"email": "ivanova-svetlana-071961@postgrespro.ru", "phone": "+70438188575"}
0005432901342	7072C5	8989 114505	ANDREY ANTONOV	{"phone": "+70955080964"}
0005432901343	C0E11B	8430 080459	SERGEY KOROLEV	{"email": "s-korolev-1979@postgrespro.ru", "phone": "+70101848759"}
0005432901344	C0E11B	2740 100277	NATALYA KOROLEVA	{"phone": "+70542867785"}
0005432901345	4419E9	1778 736077	MARIYA BOGDANOVA	{"phone": "+70141348948"}
0005432901346	621302	3970 810720	VLADIMIR VASILEV	{"phone": "+70358385075"}
0005432901347	863C67	7301 257045	ELENA FEDOROVA	{"email": "efedorova_021974@postgrespro.ru", "phone": "+70401904339"}
0005432901348	863C67	6484 263354	MARIYA OSIPOVA	{"email": "m-osipova_031992@postgrespro.ru", "phone": "+70347406794"}
0005432901349	863C67	5431 875061	VLADIMIR KAZAKOV	{"email": "v_kazakov1962@postgrespro.ru", "phone": "+70141942182"}
0005432901350	7FC78D	8149 875136	IGOR KARPOV	{"phone": "+70226679524"}
0005432901351	7FC78D	6847 496406	ALEKSEY GAVRILOV	{"email": "gavrilov.a.101980@postgrespro.ru", "phone": "+70983741179"}
0005432901352	BC2562	0352 464193	VLADIMIR MOROZOV	{"phone": "+70385544681"}
0005432901353	A7E96D	3216 268005	DMITRIY FEDOROV	{"email": "dfedorov-121965@postgrespro.ru", "phone": "+70011854985"}
0005432901354	B799DA	9033 470099	SERGEY FEDOTOV	{"email": "s-fedotov.031980@postgrespro.ru", "phone": "+70579993162"}
0005432901355	1E2256	1694 543760	VLADIMIR IVANOV	{"phone": "+70228092733"}
0005432901356	6A4483	3156 591406	TATYANA ANISIMOVA	{"phone": "+70023040726"}
0005432901357	7D9CDB	4964 274301	OKSANA FEDOROVA	{"phone": "+70928556529"}
0005432901358	998A22	0066 004749	IVAN SAVELEV	{"phone": "+70836461322"}
0005432901359	531CEE	7257 769668	ANNA KUDRYASHOVA	{"email": "kudryashova.anna.21121977@postgrespro.ru", "phone": "+70648437862"}
0005432901360	531CEE	4740 915591	VIKTOR FROLOV	{"phone": "+70266954952"}
0005432901361	9F17DB	0630 034451	SERGEY ALEKSEEV	{"phone": "+70901603675"}
0005432901362	2A9B80	8076 205396	YURIY ZAYCEV	{"phone": "+70182848144"}
0005432901363	0C7732	2358 271000	VITALIY KULIKOV	{"phone": "+70567079470"}
0005432901364	0C7732	9916 971894	ELENA KUZNECOVA	{"email": "kuznecova.elena-11011976@postgrespro.ru", "phone": "+70169393388"}
0005432901365	C39B6D	8409 548655	ALEKSANDRA KOZLOVA	{"phone": "+70678631786"}
0005432901366	97CCF2	6147 402761	TATYANA MOROZOVA	{"phone": "+70449983037"}
0005432901367	B891BC	5503 698902	ANASTASIYA NAUMOVA	{"email": "naumova_a1973@postgrespro.ru", "phone": "+70683385713"}
0005432901368	938C47	3244 728927	SANIYA POPOVA	{"email": "s.popova121968@postgrespro.ru", "phone": "+70348322376"}
0005432901369	593B34	5071 769637	RUSLAN PAVLOV	{"email": "ruslanpavlov-14031981@postgrespro.ru", "phone": "+70976682195"}
0005432901370	593B34	4726 450060	IVAN NIKOLAEV	{"phone": "+70627463137"}
0005432901371	C0E48F	3845 351074	LARISA ALEKSANDROVA	{"phone": "+70711961416"}
0005432901372	915B61	9279 513922	ALEKSEY ORLOV	{"phone": "+70782060944"}
0005432901373	D931DC	1765 006246	YURIY YAKOVLEV	{"email": "yuriyyakovlev.12011972@postgrespro.ru", "phone": "+70531144988"}
0005432901374	98C6D8	8647 370351	EKATERINA DENISOVA	{"phone": "+70386741023"}
0005432901375	98C6D8	6782 756473	SERGEY SMIRNOV	{"phone": "+70965787858"}
0005432901376	DBBD8B	7438 827649	VALENTINA ISAEVA	{"email": "valentina-isaeva1973@postgrespro.ru", "phone": "+70945832205"}
0005432901377	2004CB	1835 485811	NIKITA MAKSIMOV	{"phone": "+70817896748"}
0005432901378	E2CEBC	5575 099132	SERGEY ABRAMOV	{"phone": "+70800113069"}
0005432901379	BEFC9E	7782 182219	LYUDMILA VASILEVA	{"email": "vasilevalyudmila.101976@postgrespro.ru", "phone": "+70025080321"}
0005432901380	1E6985	0888 416015	ILYA GORBUNOV	{"phone": "+70404665577"}
0005432901381	1E6985	8915 717504	IVAN ZHUKOV	{"email": "zhukov.i14051977@postgrespro.ru", "phone": "+70539330728"}
0005432901382	6234ED	6713 922619	VALENTINA ZHUKOVA	{"phone": "+70450384981"}
0005432901383	6234ED	3106 157541	EVGENIY KOZLOV	{"phone": "+70226655317"}
0005432901384	7A63FA	2053 436507	VLADIMIR ILIN	{"email": "ilin.vladimir-111973@postgrespro.ru", "phone": "+70207257493"}
0005432901386	7A63FA	2825 230233	ALEKSANDRA MOISEEVA	{"phone": "+70712972084"}
0005432901387	F09ABA	5697 948862	SERGEY MAKAROV	{"email": "makarov.s_25121975@postgrespro.ru", "phone": "+70497114240"}
0005432901388	013D45	6967 654225	NATALYA MIKHAYLOVA	{"phone": "+70497730890"}
0005432901389	44FCA9	6086 903965	ANATOLIY EGOROV	{"email": "egorov.anatoliy.071979@postgrespro.ru", "phone": "+70031862127"}
0005432901390	227F56	3509 474141	KONSTANTIN ALEKSEEV	{"phone": "+70821464979"}
0005432901391	D4D8E8	2579 264257	ZINAIDA OVCHINNIKOVA	{"email": "zovchinnikova_1969@postgrespro.ru", "phone": "+70665054776"}
0005432901392	B47FF6	6064 616398	OLGA DMITRIEVA	{"email": "dmitrieva.olga-1977@postgrespro.ru", "phone": "+70088724511"}
0005432901393	11D355	6263 668291	ANASTASIYA KOROLEVA	{"email": "koroleva_anastasiya-011973@postgrespro.ru", "phone": "+70766738271"}
0005432901394	63D7E6	5441 997865	EVGENIY SMIRNOV	{"email": "smirnov.evgeniy-1966@postgrespro.ru", "phone": "+70396230451"}
0005432901395	63D7E6	8460 832136	ANDREY ISAEV	{"email": "aisaev-17061973@postgrespro.ru", "phone": "+70203183898"}
0005432901396	63D7E6	4914 894359	NIKITA MAKAROV	{"phone": "+70355916559"}
0005432901397	B4B189	3060 332064	TATYANA SIDOROVA	{"email": "sidorova-tatyana.1981@postgrespro.ru", "phone": "+70482356768"}
0005432901398	B4B189	1800 683637	OLGA PAVLOVA	{"phone": "+70001183996"}
0005432901399	C03C99	0643 840071	EVGENIY KUZNECOV	{"phone": "+70492707876"}
0005432901400	0B57AA	1983 344797	ELENA SERGEEVA	{"email": "sergeeva-e-111982@postgrespro.ru", "phone": "+70233984874"}
0005432901401	0B57AA	4163 631076	IRINA VOROBEVA	{"phone": "+70727021009"}
0005432901402	7611E8	2992 165305	IVAN IVANOV	{"phone": "+70720231110"}
0005432901403	93CE2E	4201 470202	MARAT VOLKOV	{"email": "volkovm.071973@postgrespro.ru", "phone": "+70186836365"}
0005432901404	D166C7	9889 694693	LYUBOV ZHUKOVA	{"email": "lzhukova_041974@postgrespro.ru", "phone": "+70673261006"}
0005432901405	46A21C	9567 885243	NINA DAVYDOVA	{"email": "davydova_nina1984@postgrespro.ru", "phone": "+70728897264"}
0005432901406	133611	0572 953402	LARISA KOROLEVA	{"email": "koroleva-l.24061965@postgrespro.ru", "phone": "+70322206099"}
0005432901407	B62E9E	3327 649738	ALEKSEY NAZAROV	{"phone": "+70646730957"}
0005432901408	34B55B	2794 573314	ARTEM MIKHAYLOV	{"email": "amikhaylov.091965@postgrespro.ru", "phone": "+70572017445"}
0005432901409	CF53D7	7889 426135	TATYANA MALYSHEVA	{"phone": "+70671883610"}
0005432901410	7D56C2	8769 004744	ANDREY VOLKOV	{"email": "a.volkov-1980@postgrespro.ru", "phone": "+70085979490"}
0005432901411	B06DB7	4804 298761	LILIYA FADEEVA	{"email": "fadeeva-liliya.1965@postgrespro.ru", "phone": "+70901538153"}
0005432901412	CD43DA	7423 060652	NATALYA NAUMOVA	{"email": "n-naumova_091978@postgrespro.ru", "phone": "+70188633218"}
0005432901413	CD43DA	3653 224327	NIKOLAY KISELEV	{"email": "kiselev.n.28091979@postgrespro.ru", "phone": "+70745499903"}
0005432901414	ADBF5A	6303 575278	ALEKSEY SEMENOV	{"phone": "+70838728541"}
0005432901415	F14836	8556 388308	TATYANA ANDREEVA	{"phone": "+70735363498"}
0005432901416	F1F367	6884 243941	MARIYA PETROVA	{"email": "mariyapetrova.1978@postgrespro.ru", "phone": "+70134019962"}
0005432901417	EF8467	5108 263056	VALERIYA CHERNOVA	{"phone": "+70495793290"}
0005432901418	EF8467	6181 186773	VITALIY FOMIN	{"email": "fomin_vitaliy_29031988@postgrespro.ru", "phone": "+70839588000"}
0005432901419	73457A	3979 599779	ELENA AFANASEVA	{"phone": "+70250642244"}
0005432901420	DFB39E	7520 661258	ARINA NAZAROVA	{"phone": "+70477713153"}
0005432901421	7958A9	0242 667411	DENIS PAVLOV	{"phone": "+70101895498"}
0005432901422	1FCADC	0202 880333	ARTEM ANTONOV	{"email": "antonov_artem_1973@postgrespro.ru", "phone": "+70696392980"}
0005432901423	1FCADC	8870 878113	LYUBOV ALEKSEEVA	{"email": "alekseeva_l-071964@postgrespro.ru", "phone": "+70080691094"}
0005432901424	5830FD	5128 253522	ALEKSANDR MAKAROV	{"phone": "+70235905063"}
0005432901425	5830FD	7848 319356	RAISA ZAKHAROVA	{"phone": "+70838066772"}
0005432901426	DDAF54	2712 060218	TAMARA VLASOVA	{"phone": "+70559742742"}
0005432901427	CB2C8C	8068 711767	VALENTINA LEBEDEVA	{"email": "valentina.lebedeva-091965@postgrespro.ru", "phone": "+70199686932"}
0005432901428	CB2C8C	9518 236085	GENNADIY ALEKSEEV	{"email": "galekseev_28091974@postgrespro.ru", "phone": "+70006056391"}
0005432901429	93F401	1371 194122	ELENA BOGDANOVA	{"email": "ebogdanova_101979@postgrespro.ru", "phone": "+70380770650"}
0005432901430	C61D30	1961 582110	EKATERINA SOROKINA	{"email": "e-sorokina-031973@postgrespro.ru", "phone": "+70634882269"}
0005432901431	01DBC1	4488 069994	EVGENIY DAVYDOV	{"phone": "+70939195906"}
0005432901432	01DBC1	7558 537001	SERGEY DAVYDOV	{"email": "davydov_sergey_25041963@postgrespro.ru", "phone": "+70445055924"}
0005432901433	0A2054	6108 430110	ALEKSANDR ALEKSANDROV	{"email": "a.aleksandrov.01101987@postgrespro.ru", "phone": "+70056664290"}
0005432901434	0A2054	2162 470382	YURIY SMIRNOV	{"email": "smirnov.yuriy_1980@postgrespro.ru", "phone": "+70472329358"}
0005432901435	F38661	2718 561321	IGOR NIKITIN	{"phone": "+70953688473"}
0005432901436	F38661	9657 767412	EVGENIY ANDREEV	{"phone": "+70796390492"}
0005432901437	601136	6667 050193	OLGA KUZMINA	{"email": "kuzmina.o_1968@postgrespro.ru", "phone": "+70922448644"}
0005432901438	601136	2969 952066	TATYANA MOISEEVA	{"email": "moiseeva_t.1971@postgrespro.ru", "phone": "+70278295128"}
0005432901439	601136	7499 143054	YURIY SOROKIN	{"email": "sorokin_yuriy-1970@postgrespro.ru", "phone": "+70474025631"}
0005432901440	E9D50C	6833 804028	OLGA PAVLOVA	{"phone": "+70501044787"}
0005432901441	E9D50C	6615 984525	IGOR FOMIN	{"email": "fomini_12051972@postgrespro.ru", "phone": "+70470768431"}
0005432901442	E27F92	9508 820220	LIDIYA POLYAKOVA	{"phone": "+70966206695"}
0005432901443	E27F92	2318 806380	VLADIMIR POPOV	{"phone": "+70616044663"}
0005432901444	E0613C	0489 665054	OLGA BELOVA	{"email": "belova_o.021968@postgrespro.ru", "phone": "+70805580002"}
0005432901445	575747	0531 583019	PAVEL KUZNECOV	{"phone": "+70022176989"}
0005432901446	F42654	3705 008387	IRINA TARASOVA	{"phone": "+70477432893"}
0005432901447	F42654	8067 649782	POLINA VASILEVA	{"phone": "+70946848431"}
0005432901448	CCA2A0	7817 333171	GALINA BARANOVA	{"phone": "+70346870259"}
0005432901449	26BA0F	0996 810055	YURIY PETROV	{"email": "petrov-y1971@postgrespro.ru", "phone": "+70665342266"}
0005432901450	26BA0F	8496 146882	ANNA MALYSHEVA	{"email": "malysheva-anna.10021970@postgrespro.ru", "phone": "+70812262598"}
0005432901451	26BA0F	3072 711305	ALEKSANDR SOKOLOV	{"phone": "+70300002016"}
0005432901452	505023	4208 594850	DMITRIY NIKITIN	{"email": "d.nikitin.051979@postgrespro.ru", "phone": "+70366811139"}
0005432901453	D498D4	2212 644367	EKATERINA GAVRILOVA	{"email": "ekaterinagavrilova.1973@postgrespro.ru", "phone": "+70142551871"}
0005432901454	C073A2	3068 921739	ILYAS FROLOV	{"phone": "+70503937987"}
0005432901455	512B98	8757 757331	IRINA GUSEVA	{"email": "irina-guseva.18121975@postgrespro.ru", "phone": "+70439902652"}
0005432901456	F5F372	4135 803668	EVGENIYA ZOTOVA	{"phone": "+70885781957"}
0005432901457	F5F372	8578 699454	NINA GORBUNOVA	{"email": "gorbunova_n_25081981@postgrespro.ru", "phone": "+70708447290"}
0005432901458	24CA97	7433 220301	EKATERINA ALEKSANDROVA	{"phone": "+70836654749"}
0005432901459	111910	1989 026616	ALEKSANDRA PETROVA	{"email": "aleksandra-petrova_05031974@postgrespro.ru", "phone": "+70995148842"}
0005432901460	47C5A0	4805 243043	YULIYA ROMANOVA	{"phone": "+70899275399"}
0005432901461	9736F9	4048 377240	EKATERINA GERASIMOVA	{"phone": "+70943362417"}
0005432901462	6BD2CF	1345 895362	ANNA KULIKOVA	{"email": "kulikovaa-26101984@postgrespro.ru", "phone": "+70081299588"}
0005432901463	01424B	0582 273754	SERGEY IVANOV	{"phone": "+70176114938"}
0005432901464	6ADE8F	9723 148630	VALENTINA SOKOLOVA	{"phone": "+70030765992"}
0005432901465	647C22	5552 025488	VIKTOR ZHURAVLEV	{"email": "viktor-zhuravlev_051976@postgrespro.ru", "phone": "+70320755000"}
0005432901466	D52261	7800 425248	ALEKSEY NOVIKOV	{"email": "novikov_aleksey-10091979@postgrespro.ru", "phone": "+70990455638"}
0005432901467	0A3A7A	3048 520982	ILYA GRIGOREV	{"email": "igrigorev.30031973@postgrespro.ru", "phone": "+70965150055"}
0005432901468	0A3A7A	2292 618812	KLAVDIYA NESTEROVA	{"email": "k-nesterova_1972@postgrespro.ru", "phone": "+70831214135"}
0005432901469	272D41	1086 609388	NINA SOROKINA	{"email": "sorokina_n29031975@postgrespro.ru", "phone": "+70304182274"}
0005432901470	272D41	0909 616381	MARGARITA IVANOVA	{"email": "m_ivanova011978@postgrespro.ru", "phone": "+70389470634"}
0005432901471	739DA6	1274 690884	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr23031966@postgrespro.ru", "phone": "+70582963628"}
0005432901472	739DA6	6488 343148	VLADIMIR TIMOFEEV	{"email": "timofeevv-1970@postgrespro.ru", "phone": "+70778433274"}
0005432901473	787815	1531 018509	LEONID BELOV	{"email": "leonid.belov1959@postgrespro.ru", "phone": "+70112178187"}
0005432901474	C211F6	8149 524552	ALEKSEY IVANOV	{"email": "ivanov_aleksey_04011977@postgrespro.ru", "phone": "+70875090428"}
0005432901475	D1C39D	1094 217402	ANATOLIY PETROV	{"email": "a.petrov-1976@postgrespro.ru", "phone": "+70065140215"}
0005432901476	D1C39D	7160 152781	MARINA MOISEEVA	{"email": "moiseevamarina-091982@postgrespro.ru", "phone": "+70332052144"}
0005432901477	F077CD	8286 671378	SERGEY KULIKOV	{"phone": "+70569483055"}
0005432901478	C01463	1142 389659	NIKOLAY FROLOV	{"email": "frolovnikolay-31031969@postgrespro.ru", "phone": "+70021360183"}
0005432901479	C01463	8473 868048	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova.1970@postgrespro.ru", "phone": "+70192428287"}
0005432901480	CB572C	5302 603068	NATALYA LUKYANOVA	{"phone": "+70139199735"}
0005432901481	7BBFFC	6350 818042	KRISTINA NIKITINA	{"email": "kristinanikitina021974@postgrespro.ru", "phone": "+70884670645"}
0005432901482	58A79E	4381 171375	MARAT KULIKOV	{"phone": "+70162308760"}
0005432901483	58A79E	1857 476305	VALENTIN POPOV	{"phone": "+70193667513"}
0005432901484	73A8AA	8437 169779	VIKTOR MATVEEV	{"phone": "+70633731796"}
0005432901485	73A8AA	4277 217076	EKATERINA LAZAREVA	{"email": "lazarevaekaterina.1980@postgrespro.ru", "phone": "+70776591363"}
0005432901486	2ADB56	4553 748278	OKSANA AKIMOVA	{"email": "oksana_akimova-27101979@postgrespro.ru", "phone": "+70770973247"}
0005432901487	2ADB56	2971 312157	VLADIMIR FROLOV	{"email": "vladimir.frolov-081973@postgrespro.ru", "phone": "+70885807031"}
0005432901488	2ADB56	6528 366400	VLADIMIR NOVIKOV	{"phone": "+70915462631"}
0005432901489	3807C0	6263 922064	NIKITA CHERNOV	{"email": "chernov.n_12061966@postgrespro.ru", "phone": "+70235549766"}
0005432901490	07191F	2744 908588	OLEG KUZNECOV	{"email": "kuznecov.oleg-1974@postgrespro.ru", "phone": "+70098271734"}
0005432901491	07191F	4945 290125	VALERIYA KUZNECOVA	{"email": "kuznecova.v.1968@postgrespro.ru", "phone": "+70663520260"}
0005432901492	9AFA8C	6799 035371	STANISLAV VASILEV	{"email": "vasilev-stanislav.01071968@postgrespro.ru", "phone": "+70761868439"}
0005432901493	01E61E	3277 510647	TAMARA IVANOVA	{"phone": "+70019511117"}
0005432901494	37BD36	6745 716379	NIKOLAY MEDVEDEV	{"email": "nikolay_medvedev-1974@postgrespro.ru", "phone": "+70918815944"}
0005432901495	7D6D88	7627 802857	ELIZAVETA PETROVA	{"email": "petrova-elizaveta081974@postgrespro.ru", "phone": "+70722744387"}
0005432901496	DFB99E	2320 516770	EVGENIY TIKHONOV	{"phone": "+70844612811"}
0005432901497	DFB99E	7356 545690	VALERIY GAVRILOV	{"phone": "+70166289340"}
0005432901498	0C964F	8938 151291	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikova-a.09041967@postgrespro.ru", "phone": "+70631415729"}
0005432901499	7F9EBD	3180 749080	MIKHAIL GUSEV	{"email": "gusev-mikhail-051968@postgrespro.ru", "phone": "+70096663075"}
0005432901500	7F9EBD	4900 703041	EVGENIY TIKHONOV	{"email": "tikhonove_1964@postgrespro.ru", "phone": "+70801832851"}
0005432901501	F6925A	9246 190620	DMITRIY KONOVALOV	{"email": "d.konovalov061971@postgrespro.ru", "phone": "+70877057138"}
0005432901502	A6FA61	8240 849076	LYUDMILA MIKHAYLOVA	{"phone": "+70353775555"}
0005432901503	190544	7053 178977	OLGA AKIMOVA	{"phone": "+70924471716"}
0005432901504	6BE759	6930 335616	SERGEY SCHERBAKOV	{"phone": "+70272373467"}
0005432901505	F5B01C	4122 101232	ELDAR GAVRILOV	{"phone": "+70550977613"}
0005432901506	F5B01C	4904 501079	AZAT YAKOVLEV	{"email": "yakovlev_a-12061970@postgrespro.ru", "phone": "+70238867057"}
0005432901507	FCD247	0080 783125	LYUDMILA RYABOVA	{"phone": "+70877655270"}
0005432901508	4D5F48	3005 144984	KLAVDIYA KAZAKOVA	{"phone": "+70653595785"}
0005432901509	A4C6AA	7026 768374	DMITRIY MAKSIMOV	{"phone": "+70884548832"}
0005432901510	5CF721	5200 319652	NADEZHDA SMIRNOVA	{"email": "nsmirnova031966@postgrespro.ru", "phone": "+70313046241"}
0005432901511	5CF721	7854 774808	RAISA FILIPPOVA	{"email": "r-filippova.20091970@postgrespro.ru", "phone": "+70076197288"}
0005432901512	5CF721	8777 908758	DENIS ROMANOV	{"phone": "+70385699682"}
0005432901513	899D28	5358 763350	YURIY TIKHONOV	{"email": "yuriy_tikhonov.101974@postgrespro.ru", "phone": "+70306919243"}
0005432901514	9FB01B	3497 144001	GALINA BELYAEVA	{"phone": "+70572569200"}
0005432901515	9FB01B	4333 885474	SERGEY IVANOV	{"phone": "+70894272765"}
0005432901516	C218B7	5039 907895	IGOR KUZNECOV	{"phone": "+70364656315"}
0005432901517	C218B7	3116 299390	TATYANA GUSEVA	{"phone": "+70276323908"}
0005432901518	C03201	4941 155278	LYUDMILA KUZMINA	{"phone": "+70964506870"}
0005432901519	FDFAC9	0814 316060	IGOR VLASOV	{"email": "vlasovi.27091970@postgrespro.ru", "phone": "+70754237584"}
0005432901520	FDFAC9	0009 947037	IGOR SOLOVEV	{"email": "solovev-igor_1972@postgrespro.ru", "phone": "+70490333344"}
0005432901521	7441FC	9504 294725	ALEKSEY FROLOV	{"email": "frolov-aleksey.1976@postgrespro.ru", "phone": "+70148134006"}
0005432901522	32C1D7	6629 360047	NIKITA SMIRNOV	{"email": "smirnov_n.121972@postgrespro.ru", "phone": "+70023619999"}
0005432901523	32C1D7	6520 896039	STANISLAV KISELEV	{"phone": "+70444946958"}
0005432901524	38A6D1	1267 745338	SHAMIL OSIPOV	{"email": "osipov.shamil-06111969@postgrespro.ru", "phone": "+70242316786"}
0005432901525	38A6D1	2276 295355	TATYANA GERASIMOVA	{"email": "gerasimova_tatyana-06041963@postgrespro.ru", "phone": "+70780819817"}
0005432901526	D11955	2149 340240	ARTUR IVANOV	{"phone": "+70213143464"}
0005432901527	F212D0	1227 062611	MIKHAIL NIKITIN	{"email": "m.nikitin.15041980@postgrespro.ru", "phone": "+70968798662"}
0005432901528	558F67	1532 331225	VLADIMIR SAVELEV	{"phone": "+70520409232"}
0005432901529	558F67	4555 621254	YURIY KUDRYASHOV	{"email": "yuriy.kudryashov.061963@postgrespro.ru", "phone": "+70023185126"}
0005432901530	870007	8765 124835	OLEG ZHURAVLEV	{"phone": "+70922318731"}
0005432901531	870007	7659 513422	ELINA KAZAKOVA	{"phone": "+70624537707"}
0005432901532	C4910A	7138 073465	LYUDMILA MELNIKOVA	{"email": "melnikoval_011970@postgrespro.ru", "phone": "+70908916751"}
0005432901533	C4910A	7183 646508	IVAN KUZMIN	{"phone": "+70235058697"}
0005432901534	A786EE	4074 341506	VALENTIN FOMIN	{"email": "v-fomin.1967@postgrespro.ru", "phone": "+70183681420"}
0005432901535	56AB4E	4236 806905	ANZHELIKA TROFIMOVA	{"phone": "+70110006545"}
0005432901536	56AB4E	8956 176277	PAVEL MOROZOV	{"phone": "+70804738125"}
0005432901537	56AB4E	7849 980475	YURIY PETROV	{"phone": "+70537965214"}
0005432901538	A927AB	4716 774310	SOFIYA DENISOVA	{"phone": "+70242940997"}
0005432901539	A927AB	4560 819994	DARYA MEDVEDEVA	{"email": "darya.medvedeva_25021957@postgrespro.ru", "phone": "+70931427726"}
0005432901540	A927AB	4546 948983	IRINA FOMINA	{"phone": "+70507314386"}
0005432901541	3779C5	6637 393907	NADEZHDA FROLOVA	{"email": "nadezhda_frolova.30111962@postgrespro.ru", "phone": "+70257237207"}
0005432901542	037D84	0429 692471	YULIYA BELOVA	{"phone": "+70967128449"}
0005432901543	5FDACC	6063 557715	DMITRIY KOROLEV	{"phone": "+70836368713"}
0005432901544	5261B5	8586 689590	ANNA BORISOVA	{"email": "borisovaa-20061968@postgrespro.ru", "phone": "+70052331611"}
0005432901545	5261B5	9740 691200	NIKOLAY KOZLOV	{"email": "n.kozlov1970@postgrespro.ru", "phone": "+70118121305"}
0005432901546	3C9D3E	8159 866970	DARYA ZAYCEVA	{"email": "zayceva-darya_041977@postgrespro.ru", "phone": "+70003075327"}
0005432901547	3C9D3E	4409 259014	LYUBOV KOROLEVA	{"phone": "+70518854555"}
0005432901548	F8D273	7306 145307	IRINA POPOVA	{"email": "irina.popova.021978@postgrespro.ru", "phone": "+70279701977"}
0005432901549	F8D273	1817 236815	NADEZHDA MOROZOVA	{"email": "nadezhda-morozova111960@postgrespro.ru", "phone": "+70973317205"}
0005432901550	5B7290	1372 062688	TATYANA LAZAREVA	{"phone": "+70152177381"}
0005432901551	C5DF44	9448 018126	GERMAN SOROKIN	{"phone": "+70274923432"}
0005432901552	0E2BDF	0478 759220	ANDREY EGOROV	{"phone": "+70271439245"}
0005432901553	A76A44	4223 017161	ROMAN MELNIKOV	{"email": "r-melnikov30071976@postgrespro.ru", "phone": "+70606156653"}
0005432901554	A76A44	3982 456246	ERIK ZHURAVLEV	{"email": "erik-zhuravlev_1973@postgrespro.ru", "phone": "+70317992923"}
0005432901555	334864	0586 527344	ILYA NAZAROV	{"email": "ilyanazarov1980@postgrespro.ru", "phone": "+70107932618"}
0005432901556	F772EA	9717 861938	ANNA BOGDANOVA	{"phone": "+70468360953"}
0005432901557	F772EA	4057 801534	ALEKSANDR MEDVEDEV	{"email": "a-medvedev-111974@postgrespro.ru", "phone": "+70175259633"}
0005432901558	122289	0019 681289	IRINA ZAKHAROVA	{"phone": "+70344325271"}
0005432901559	122289	9043 176471	INNA KUZNECOVA	{"email": "kuznecova-inna_23041972@postgrespro.ru", "phone": "+70028242782"}
0005432901560	632919	6210 652083	ALINA IVANOVA	{"phone": "+70815505964"}
0005432901561	632919	8870 939541	ALEKSEY EGOROV	{"email": "egorov-a_27051978@postgrespro.ru", "phone": "+70977239038"}
0005432901562	CF1080	3401 051216	TATYANA BARANOVA	{"email": "tatyana-baranova_29031977@postgrespro.ru", "phone": "+70072780943"}
0005432901563	CF1080	1425 544406	ANNA BARANOVA	{"phone": "+70794252493"}
0005432901564	63483F	7568 197855	OLEG SMIRNOV	{"phone": "+70915475926"}
0005432901565	0789E2	4377 913333	YURIY SOLOVEV	{"email": "ysolovev101974@postgrespro.ru", "phone": "+70562063606"}
0005432901625	9134FF	0761 306012	ALBINA NIKOLAEVA	{"phone": "+70279697951"}
0005432901566	B5DC45	2587 773280	VENERA IVANOVA	{"email": "v_ivanova.03081976@postgrespro.ru", "phone": "+70798844835"}
0005432901567	A18165	9154 133665	GENNADIY KUDRYASHOV	{"email": "kudryashov_g.1969@postgrespro.ru", "phone": "+70196580998"}
0005432901568	A18165	5656 674680	NIKITA EGOROV	{"phone": "+70444622488"}
0005432901569	374B07	5561 588200	ALENA POTAPOVA	{"email": "alenapotapova_1983@postgrespro.ru", "phone": "+70603322387"}
0005432901570	BC1DC3	0489 609141	ALEKSEY MOISEEV	{"phone": "+70049338327"}
0005432901571	BC1DC3	1807 099975	ANATOLIY ANDREEV	{"email": "aandreev1977@postgrespro.ru", "phone": "+70006656359"}
0005432901572	501928	1081 354888	ANNA NESTEROVA	{"phone": "+70305587682"}
0005432901573	1A20AF	2687 134620	OLGA SOKOLOVA	{"phone": "+70958465780"}
0005432901574	4477B5	8422 573021	TATYANA POPOVA	{"email": "tatyana_popova-1980@postgrespro.ru", "phone": "+70680118886"}
0005432901575	7DE1DD	4118 507592	ALEKSEY BELOV	{"email": "a.belov021986@postgrespro.ru", "phone": "+70662893226"}
0005432901576	DA07E7	5191 052767	NATALYA KUZNECOVA	{"email": "kuznecova_natalya051975@postgrespro.ru", "phone": "+70056472899"}
0005432901577	A99626	9490 731303	VLADIMIR BORISOV	{"phone": "+70314451303"}
0005432901578	A99626	5099 555412	ALENA SCHERBAKOVA	{"email": "a_scherbakova-041980@postgrespro.ru", "phone": "+70510226698"}
0005432901579	E56174	7806 713908	NATALYA SEMENOVA	{"phone": "+70857761775"}
0005432901580	E56174	0424 365014	YULIYA ANDREEVA	{"email": "y-andreeva1970@postgrespro.ru", "phone": "+70958965958"}
0005432901581	294274	5609 933304	YULIYA SOLOVEVA	{"email": "soloveva-yuliya101979@postgrespro.ru", "phone": "+70707813939"}
0005432901582	D00D45	8751 340136	ALEKSANDR IVANOV	{"email": "ivanov-a_1970@postgrespro.ru", "phone": "+70298894425"}
0005432901583	D00D45	0379 502688	DMITRIY KONOVALOV	{"email": "konovalov.d_1962@postgrespro.ru", "phone": "+70943123279"}
0005432901584	34FF20	7395 462072	MARAT VASILEV	{"phone": "+70583616706"}
0005432901585	2CEF2F	2897 514268	NATALYA ROMANOVA	{"email": "romanova.n15081962@postgrespro.ru", "phone": "+70254845868"}
0005432901586	D4E459	4739 941293	OLGA TIKHONOVA	{"email": "otikhonova20011985@postgrespro.ru", "phone": "+70094276176"}
0005432901587	CE81CC	0038 566580	YURIY SOKOLOV	{"phone": "+70147739569"}
0005432901588	CE46E6	1144 512671	VALENTINA ORLOVA	{"email": "valentina-orlova1973@postgrespro.ru", "phone": "+70109080577"}
0005432901589	CE46E6	0310 353273	LILIYA MAKAROVA	{"email": "makarova_l_1982@postgrespro.ru", "phone": "+70576144721"}
0005432901590	CE46E6	3793 635124	LYUDMILA ANDREEVA	{"email": "l_andreeva25071979@postgrespro.ru", "phone": "+70603771820"}
0005432901591	CE46E6	4324 060220	ELENA BORISOVA	{"email": "elenaborisova-30081980@postgrespro.ru", "phone": "+70884915846"}
0005432901592	0F2A60	9414 743215	VIKTOR SERGEEV	{"email": "viktor-sergeev.041979@postgrespro.ru", "phone": "+70361233380"}
0005432901593	6C37E0	1231 456875	NIKOLAY MEDVEDEV	{"email": "medvedev-n.101971@postgrespro.ru", "phone": "+70480603517"}
0005432901594	6C37E0	0432 623190	SALAVAT FEDOROV	{"email": "sfedorov-24021967@postgrespro.ru", "phone": "+70336947542"}
0005432901595	020075	7496 138019	ANTON KUZMIN	{"phone": "+70016473928"}
0005432901596	3B878B	4483 070620	VALENTINA MELNIKOVA	{"phone": "+70498367685"}
0005432901597	3A7452	1205 362589	ELENA SAVELEVA	{"email": "saveleva_e-1968@postgrespro.ru", "phone": "+70597512542"}
0005432901598	E8CC71	4621 423516	IVAN IVANOV	{"phone": "+70589942013"}
0005432901599	D66E50	7177 980081	ALEKSANDR ZAKHAROV	{"phone": "+70639704742"}
0005432901600	3E5997	0598 390405	YURIY VOROBEV	{"email": "yuriy.vorobev-011971@postgrespro.ru", "phone": "+70156659492"}
0005432901601	47A630	7457 147211	OLGA DMITRIEVA	{"email": "dmitrievaolga1959@postgrespro.ru", "phone": "+70633904219"}
0005432901602	FE8CF3	9085 154787	VLADIMIR VOROBEV	{"email": "v.vorobev-1960@postgrespro.ru", "phone": "+70099414999"}
0005432901603	FE8CF3	4719 507485	EKATERINA EFIMOVA	{"phone": "+70761163048"}
0005432901604	50DD6E	1231 660171	ZOYA KISELEVA	{"email": "kiselevazoya.22061980@postgrespro.ru", "phone": "+70809677433"}
0005432901605	CEEFEB	7286 238501	KIRILL SOROKIN	{"phone": "+70944267620"}
0005432901606	CEEFEB	1339 155398	MARIYA ABRAMOVA	{"email": "m-abramova_051977@postgrespro.ru", "phone": "+70189516530"}
0005432901607	130B3B	6247 341831	NATALYA PETROVA	{"phone": "+70102039759"}
0005432901608	7A377C	4354 766799	SVETLANA PAVLOVA	{"phone": "+70438012846"}
0005432901609	7A377C	3173 008349	ARTEM SMIRNOV	{"phone": "+70617032815"}
0005432901610	8E0E03	4979 990021	TATYANA MIKHAYLOVA	{"email": "mikhaylova_tatyana_071971@postgrespro.ru", "phone": "+70556808887"}
0005432901611	8E0E03	3019 299893	IRINA ROMANOVA	{"phone": "+70593454338"}
0005432901612	633671	4310 469604	GENNADIY ZHURAVLEV	{"phone": "+70057439131"}
0005432901613	633671	7728 342091	MARIYA TITOVA	{"email": "m_titova-121979@postgrespro.ru", "phone": "+70875106150"}
0005432901614	EF1507	8401 396710	DMITRIY SMIRNOV	{"phone": "+70639109186"}
0005432901615	513161	0524 964163	ANDREY CHERNOV	{"email": "andrey.chernov.1979@postgrespro.ru", "phone": "+70949663028"}
0005432901616	D75828	9073 009069	VLADIMIR KRASNOV	{"email": "krasnovv.07121968@postgrespro.ru", "phone": "+70327446165"}
0005432901617	38F5BE	3572 738153	NATALIYA GUSEVA	{"phone": "+70681036808"}
0005432901618	38F5BE	2788 010190	ALEKSANDR SIDOROV	{"phone": "+70709223971"}
0005432901619	EC283A	4214 493103	VALENTIN FOMIN	{"email": "fomin.v_20091964@postgrespro.ru", "phone": "+70679247024"}
0005432901620	EC283A	5254 320703	OLGA SIDOROVA	{"email": "sidorova_o.1960@postgrespro.ru", "phone": "+70805556913"}
0005432901621	38C6DB	9962 640221	ELENA OVCHINNIKOVA	{"email": "ovchinnikova.elena-081961@postgrespro.ru", "phone": "+70216022263"}
0005432901622	38C6DB	4558 872925	VLADIMIR FOMIN	{"phone": "+70173868552"}
0005432901623	48BB81	1167 242252	ELENA PETROVA	{"phone": "+70260331547"}
0005432901624	3C860F	5855 373528	OLGA PAVLOVA	{"email": "pavlova-olga09011982@postgrespro.ru", "phone": "+70587955417"}
0005432901626	E479E7	6564 622430	NATALYA KOZLOVA	{"phone": "+70769011041"}
0005432901627	E479E7	5979 391640	MIKHAIL IVANOV	{"phone": "+70628717706"}
0005432901628	51B627	0134 329124	ANASTASIYA BORISOVA	{"email": "borisova.anastasiya-021978@postgrespro.ru", "phone": "+70244873540"}
0005432901629	8C43B1	6355 989102	ALEKSANDR GERASIMOV	{"phone": "+70028364816"}
0005432901630	5C9555	0850 324769	MIKHAIL STEPANOV	{"email": "mstepanov02101970@postgrespro.ru", "phone": "+70050575019"}
0005432901631	11782E	9532 333452	LYUBOV BARANOVA	{"phone": "+70518371112"}
0005432901632	11782E	9322 956350	VLADIMIR TIKHONOV	{"phone": "+70102975858"}
0005432901633	7119CE	9004 239459	NIKOLAY FILIPPOV	{"phone": "+70284602902"}
0005432901634	A0B058	1873 533968	LILIYA SAVELEVA	{"email": "saveleval011980@postgrespro.ru", "phone": "+70586425048"}
0005432901635	5727B7	6317 320183	EVGENIY SAVELEV	{"email": "savelev.e_24031975@postgrespro.ru", "phone": "+70850538525"}
0005432901636	5727B7	8253 059084	VERONIKA MIRONOVA	{"email": "veronika_mironova_1960@postgrespro.ru", "phone": "+70407667150"}
0005432901637	12A0A2	4839 256551	ELENA KOLESNIKOVA	{"phone": "+70305362706"}
0005432901638	C40BCF	4000 912477	DINA MAKAROVA	{"phone": "+70505776248"}
0005432901639	343182	1966 690513	SVETLANA VOROBEVA	{"phone": "+70662212952"}
0005432901640	C367F6	6875 284834	ALEKSANDR MEDVEDEV	{"phone": "+70802749387"}
0005432901641	3E0B72	9664 822086	VALERIY TARASOV	{"email": "tarasov-valeriy-1980@postgrespro.ru", "phone": "+70428774150"}
0005432901642	394373	6496 625807	ALEKSEY OSIPOV	{"phone": "+70984147603"}
0005432901643	394373	0666 733175	YURIY MOROZOV	{"phone": "+70195834009"}
0005432901644	9DE0AD	6927 737885	IVAN IVANOV	{"email": "ivanovivan-31081967@postgrespro.ru", "phone": "+70620439932"}
0005432901645	7BEF43	1425 535489	VALENTINA SERGEEVA	{"email": "sergeeva.v-1975@postgrespro.ru", "phone": "+70823867405"}
0005432901646	9E7CE3	8833 611941	NADEZHDA NAUMOVA	{"phone": "+70521390089"}
0005432901647	E087C7	4695 217816	ALSU ALEKSEEVA	{"phone": "+70823741003"}
0005432901648	E087C7	6763 237145	MARAT IVANOV	{"email": "marat.ivanov-1974@postgrespro.ru", "phone": "+70173796120"}
0005432901649	DDD691	3775 881281	ALEKSEY FILIPPOV	{"phone": "+70267488704"}
0005432901650	04FDBF	7406 406280	SERGEY MELNIKOV	{"email": "melnikovsergey_25061967@postgrespro.ru", "phone": "+70823352399"}
0005432901651	0B6F56	1726 632426	ALEKSANDR KUZNECOV	{"email": "kuznecova-14021967@postgrespro.ru", "phone": "+70783578401"}
0005432901652	DC3642	8272 344664	ZINAIDA MIRONOVA	{"phone": "+70609921182"}
0005432901653	F33182	0922 346730	IREK SOKOLOV	{"phone": "+70806382578"}
0005432901654	F33182	6566 784583	GENNADIY SEMENOV	{"phone": "+70977251900"}
0005432901655	F33182	3158 576961	LYUDMILA AFANASEVA	{"email": "afanaseval.071972@postgrespro.ru", "phone": "+70741688792"}
0005432901656	FAB575	9789 935015	ELIZAVETA PAVLOVA	{"email": "pavlova_elizaveta1968@postgrespro.ru", "phone": "+70012097581"}
0005432901657	41CCB0	5640 497669	ILNUR DMITRIEV	{"phone": "+70187700967"}
0005432901658	747122	4157 419284	IRINA PETROVA	{"email": "petrova-irina_1974@postgrespro.ru", "phone": "+70967464239"}
0005432901659	18B0D7	2103 837741	SVETLANA KONOVALOVA	{"phone": "+70974583704"}
0005432901660	18B0D7	7291 748328	ELIZAVETA YAKOVLEVA	{"email": "elizaveta.yakovleva_051976@postgrespro.ru", "phone": "+70592471192"}
0005432901661	5CA566	5552 219773	ALEKSEY SERGEEV	{"phone": "+70932532559"}
0005432901662	5CA566	9206 573959	ELENA SMIRNOVA	{"phone": "+70051348728"}
0005432901663	478D0E	9977 328498	INNA KUZNECOVA	{"email": "ikuznecova-1964@postgrespro.ru", "phone": "+70197456908"}
0005432901664	478D0E	5271 290973	LARISA VOROBEVA	{"phone": "+70256385435"}
0005432901665	AF1940	2247 869380	ILYA KUZNECOV	{"phone": "+70393666474"}
0005432901723	DEC62A	0791 892270	TATYANA KOMAROVA	{"phone": "+70799639442"}
0005432901666	982197	2890 549549	ZINAIDA GUSEVA	{"email": "zinaida.guseva.13101969@postgrespro.ru", "phone": "+70524860262"}
0005432901667	2A047A	0705 885952	ALEKSEY VOLKOV	{"phone": "+70220101905"}
0005432901668	2A047A	5494 601190	VASILISA VOROBEVA	{"phone": "+70202217381"}
0005432901669	CF143D	4405 623872	LILIYA ZHURAVLEVA	{"phone": "+70191871495"}
0005432901670	A1FFAC	9674 626503	FATIMA GUSEVA	{"phone": "+70402778896"}
0005432901671	354FFC	5956 123988	GENNADIY SERGEEV	{"phone": "+70239570510"}
0005432901672	B8A56B	8568 300484	LYUDMILA NIKITINA	{"email": "lyudmila.nikitina041972@postgrespro.ru", "phone": "+70954485571"}
0005432901673	02D641	6071 324845	VASILIY DMITRIEV	{"email": "vdmitriev-1964@postgrespro.ru", "phone": "+70768999367"}
0005432901674	02D641	1928 713678	VALENTINA MOROZOVA	{"phone": "+70856791892"}
0005432901675	36BEA4	4345 975105	OLGA KOLESNIKOVA	{"email": "kolesnikova.olga_31081963@postgrespro.ru", "phone": "+70585785858"}
0005432901676	36BEA4	8468 888375	VIKTOR BONDARENKO	{"phone": "+70146896529"}
0005432901677	522E7C	1616 197732	EKATERINA ZAKHAROVA	{"email": "zakharova.e-04091980@postgrespro.ru", "phone": "+70012031690"}
0005432901678	1ABEF5	7235 413117	YURIY GERASIMOV	{"phone": "+70294436617"}
0005432901679	1ABEF5	2917 395758	TATYANA KOZLOVA	{"phone": "+70552198613"}
0005432901680	DF03CD	6494 967655	ANNA MAKAROVA	{"phone": "+70211293391"}
0005432901681	373021	2339 626762	IGOR EGOROV	{"phone": "+70906048166"}
0005432901682	D06BC7	6944 095384	OLGA SEMENOVA	{"phone": "+70883732762"}
0005432901683	D06BC7	1591 181791	LEONID MIRONOV	{"phone": "+70274042591"}
0005432901684	08F6C0	7243 618805	SERGEY MIRONOV	{"email": "s.mironov-071976@postgrespro.ru", "phone": "+70360676427"}
0005432901685	9A701B	3110 960997	LYUDMILA KALININA	{"email": "lyudmilakalinina_111965@postgrespro.ru", "phone": "+70559312448"}
0005432901686	6DE32F	0656 395176	VIKTORIYA IVANOVA	{"email": "vivanova_011963@postgrespro.ru", "phone": "+70675789663"}
0005432901687	397D17	9830 712345	VIKTORIYA RYABOVA	{"phone": "+70407688437"}
0005432901688	397D17	6563 998989	ANDREY SOROKIN	{"email": "a.sorokin.1968@postgrespro.ru", "phone": "+70692553508"}
0005432901689	88B854	7852 322046	OLGA ORLOVA	{"email": "orlova-o-021974@postgrespro.ru", "phone": "+70956146143"}
0005432901690	88B854	7057 803707	ILYAS NAZAROV	{"email": "ilyas.nazarov-051975@postgrespro.ru", "phone": "+70147223197"}
0005432901691	34CE51	9435 565257	EKATERINA ABRAMOVA	{"phone": "+70774441613"}
0005432901692	34CE51	1158 566206	LYUBOV DANILOVA	{"email": "lyubov_danilova.021983@postgrespro.ru", "phone": "+70926912022"}
0005432901693	05088D	1226 637377	EVGENIY BORISOV	{"phone": "+70150072740"}
0005432901694	0B84B6	3849 198260	ANATOLIY IVANOV	{"phone": "+70701653367"}
0005432901695	429562	4033 377701	VALENTINA ROMANOVA	{"email": "v.romanova_1972@postgrespro.ru", "phone": "+70932893981"}
0005432901696	1E6096	1040 537112	NATALYA ROMANOVA	{"phone": "+70592418192"}
0005432901697	87159F	5676 555728	YURIY NAZAROV	{"email": "nazarovy_1977@postgrespro.ru", "phone": "+70330788541"}
0005432901698	ED8AF9	5267 595595	IRINA OSIPOVA	{"phone": "+70493260350"}
0005432901699	558A2D	9731 797266	LIDIYA FROLOVA	{"phone": "+70994042079"}
0005432901700	5CDD2A	1809 848004	ALEKSANDR KUZMIN	{"email": "kuzmin_a_021973@postgrespro.ru", "phone": "+70752422296"}
0005432901701	8818CB	7519 299690	NINA KUZNECOVA	{"email": "kuznecova_nina1968@postgrespro.ru", "phone": "+70424489895"}
0005432901702	8818CB	4425 229303	MAKSIM CHERNOV	{"email": "chernov_m.071980@postgrespro.ru", "phone": "+70265190691"}
0005432901703	E3F45A	1550 631045	NINA ISAEVA	{"email": "nina_isaeva-1966@postgrespro.ru", "phone": "+70373270271"}
0005432901704	878D18	7732 384162	VLADIMIR ALEKSEEV	{"email": "vladimir_alekseev-26121964@postgrespro.ru", "phone": "+70371907000"}
0005432901705	BAEFA8	8965 503771	EKATERINA CHERNOVA	{"phone": "+70348622517"}
0005432901706	3C938D	9791 496878	LYUBOV BORISOVA	{"email": "borisova-lyubov_121956@postgrespro.ru", "phone": "+70636131929"}
0005432901707	3DB769	0627 883228	NADEZHDA KUZNECOVA	{"phone": "+70808378124"}
0005432901708	C28625	9635 814163	ANNA MOROZOVA	{"email": "amorozova051974@postgrespro.ru", "phone": "+70676034944"}
0005432901709	DF9DB4	3213 335639	YURIY BELOV	{"phone": "+70081497280"}
0005432901710	DF9DB4	2577 925791	MARINA ERMAKOVA	{"email": "ermakova-m.1971@postgrespro.ru", "phone": "+70749704275"}
0005432901711	EF9164	4347 640312	DMITRIY ABRAMOV	{"phone": "+70815383363"}
0005432901712	EF9164	8336 228898	VALENTINA ANTONOVA	{"phone": "+70201597531"}
0005432901713	210B66	4583 059567	NADEZHDA TIKHONOVA	{"phone": "+70438492642"}
0005432901714	9CE8DD	6602 900197	DMITRIY SEMENOV	{"email": "dmitriy.semenov_061973@postgrespro.ru", "phone": "+70176253982"}
0005432901715	9CE8DD	3173 359565	MARIYA KOMAROVA	{"email": "mariyakomarova-30081976@postgrespro.ru", "phone": "+70874175760"}
0005432901716	DCC656	4916 604459	TATYANA VASILEVA	{"email": "vasileva_tatyana.19091971@postgrespro.ru", "phone": "+70941258658"}
0005432901717	DCC656	7827 362259	INNA GORBUNOVA	{"phone": "+70514018302"}
0005432901718	DCC656	4258 428569	NADEZHDA OSIPOVA	{"email": "osipova.n_1985@postgrespro.ru", "phone": "+70566184987"}
0005432901719	481CB2	2591 615572	ANNA KUZMINA	{"phone": "+70515836999"}
0005432901720	481CB2	5516 502881	NINA MIRONOVA	{"phone": "+70190444449"}
0005432901721	5C5176	4139 828480	NINA MIRONOVA	{"email": "nmironova1980@postgrespro.ru", "phone": "+70660045256"}
0005432901722	5C5176	8933 315570	EGOR SEMENOV	{"phone": "+70248040983"}
0005432901724	F2C474	8626 150631	TATYANA VOROBEVA	{"phone": "+70006019774"}
0005432901725	158721	9390 035927	NADEZHDA KUDRYASHOVA	{"phone": "+70146790369"}
0005432901726	158721	2077 739117	ANNA GAVRILOVA	{"phone": "+70325987361"}
0005432901727	1B6872	3145 991648	POLINA KOLESNIKOVA	{"phone": "+70760060031"}
0005432901728	26C087	5491 969385	NINA YAKOVLEVA	{"email": "yakovlevanina-1972@postgrespro.ru", "phone": "+70974017789"}
0005432901729	662C53	5508 923658	NIKOLAY DMITRIEV	{"email": "nikolay_dmitriev-121974@postgrespro.ru", "phone": "+70764163429"}
0005432901730	662C53	2216 108951	VALENTINA NIKOLAEVA	{"phone": "+70556984693"}
0005432901731	412CDF	0599 730879	TATYANA TIKHONOVA	{"phone": "+70134106895"}
0005432901732	8A450F	1038 607499	NAZIYA KAZAKOVA	{"phone": "+70047161679"}
0005432901733	8A450F	4576 144248	OLGA ANDREEVA	{"email": "olgaandreeva091971@postgrespro.ru", "phone": "+70923861022"}
0005432901734	F2DDE5	6326 897759	ALIYA KUDRYASHOVA	{"email": "kudryashova_aliya1971@postgrespro.ru", "phone": "+70414934328"}
0005432901735	30EB7C	1482 799234	RINAT SEMENOV	{"email": "rinat.semenov.1965@postgrespro.ru", "phone": "+70349818080"}
0005432901736	4C4FE7	7373 368384	ANATOLIY VOROBEV	{"email": "anatoliy_vorobev.111976@postgrespro.ru", "phone": "+70738069749"}
0005432901737	E6C7F4	4405 422945	VLADIMIR BELOV	{"phone": "+70271154071"}
0005432901738	762411	4849 631345	NIKOLAY GORBUNOV	{"phone": "+70037098169"}
0005432901739	762411	1560 257058	YURIY ANDREEV	{"phone": "+70616982207"}
0005432901740	790D72	3375 440073	ARTEM AFANASEV	{"phone": "+70995200997"}
0005432901741	88FD9D	5071 122330	YULIYA VOLKOVA	{"email": "volkova.y-1971@postgrespro.ru", "phone": "+70754861383"}
0005432901742	78BE28	3530 512153	ALEKSEY KAZAKOV	{"phone": "+70999345472"}
0005432901743	45210A	7578 739758	VLADIMIR MELNIKOV	{"email": "vladimir_melnikov_041979@postgrespro.ru", "phone": "+70614750677"}
0005432901744	C72374	5009 235636	VALENTINA ROMANOVA	{"phone": "+70480114885"}
0005432901745	8AE79F	1950 454825	NIKITA ANDREEV	{"phone": "+70930007184"}
0005432901746	1FEECC	3054 482001	ANASTASIYA NIKOLAEVA	{"email": "nikolaeva.a.23031971@postgrespro.ru", "phone": "+70139535280"}
0005432901747	1FEECC	2942 265433	LYUBOV KOROLEVA	{"phone": "+70260900997"}
0005432901748	E93B42	4773 315555	SERGEY TIKHONOV	{"phone": "+70366301422"}
0005432901749	A6EA2C	1330 230250	DARYA TIMOFEEVA	{"phone": "+70021432872"}
0005432901750	A6EA2C	8175 991349	NIKITA NOVIKOV	{"email": "novikov-nikita_1969@postgrespro.ru", "phone": "+70704963587"}
0005432901751	3C2BC4	8435 251944	DMITRIY BORISOV	{"phone": "+70924893221"}
0005432901752	3C2BC4	1688 349303	PETR IVANOV	{"phone": "+70797709268"}
0005432901753	3C2BC4	2754 702540	ELENA RYABOVA	{"email": "ryabova-e-1964@postgrespro.ru", "phone": "+70409758096"}
0005432901754	FAC0DA	5808 573603	NATALYA GORBUNOVA	{"email": "n-gorbunova_061967@postgrespro.ru", "phone": "+70602834654"}
0005432901755	F511D4	4044 965176	IRINA BORISOVA	{"phone": "+70299226397"}
0005432901756	DEE02C	5956 502027	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov-11031965@postgrespro.ru", "phone": "+70024568153"}
0005432901757	96CBE7	2685 782453	SERGEY FEDOROV	{"phone": "+70081507712"}
0005432901758	F26FD9	8701 735810	SOFYA PETROVA	{"phone": "+70676319856"}
0005432901759	EA3E9A	9556 948931	LYUDMILA KOROLEVA	{"phone": "+70260713790"}
0005432901760	644AE4	3571 580481	ALEKSEY GERASIMOV	{"email": "gerasimovaleksey_25061973@postgrespro.ru", "phone": "+70317736842"}
0005432901761	13CF53	9564 308403	ANNA NOVIKOVA	{"email": "anna_novikova.041966@postgrespro.ru", "phone": "+70158475702"}
0005432901762	5F4621	6419 461202	SERGEY MAKAROV	{"phone": "+70101448551"}
0005432901763	C2AEF4	3643 855819	TATYANA OSIPOVA	{"phone": "+70365915617"}
0005432901764	C2AEF4	9835 695817	ELENA ZAKHAROVA	{"email": "zakharova.e011968@postgrespro.ru", "phone": "+70524136947"}
0005432901765	973A3D	5440 936824	KRISTINA NESTEROVA	{"phone": "+70346149085"}
0005432901766	6250A3	3734 169882	ANATOLIY NAUMOV	{"email": "anatoliy-naumov-1975@postgrespro.ru", "phone": "+70917216871"}
0005432901767	A08E14	6624 560651	VLADIMIR IVANOV	{"email": "ivanovvladimir-101974@postgrespro.ru", "phone": "+70156285293"}
0005432901768	0A61E8	9182 273918	OLEG SAVELEV	{"phone": "+70902455469"}
0005432901769	F51B9B	7011 442767	LYUDMILA ROMANOVA	{"email": "lyudmila.romanova.1979@postgrespro.ru", "phone": "+70498918373"}
0005432901770	DC5D30	3656 800297	NADEZHDA CHERNOVA	{"email": "nadezhdachernova021965@postgrespro.ru", "phone": "+70907862413"}
0005432901771	DC5D30	4573 850993	ELENA MELNIKOVA	{"phone": "+70143765872"}
0005432901772	7F6309	8379 628595	ANDREY ANTONOV	{"email": "a_antonov.101977@postgrespro.ru", "phone": "+70056443738"}
0005432901773	EA6003	7669 612794	ELINA MAKAROVA	{"phone": "+70044918453"}
0005432901774	EA6003	5449 888084	TATYANA BOGDANOVA	{"email": "bogdanova-tatyana_111975@postgrespro.ru", "phone": "+70023815315"}
0005432901775	EA6003	5932 149889	LILIYA MELNIKOVA	{"email": "liliya.melnikova.1972@postgrespro.ru", "phone": "+70261572079"}
0005432901776	E74769	9693 359895	VADIM MIRONOV	{"email": "vmironov-1973@postgrespro.ru", "phone": "+70560692243"}
0005432901777	9D7754	8804 277880	EKATERINA KOZLOVA	{"phone": "+70366846914"}
0005432901778	D55DC3	7664 051918	OLGA KOROLEVA	{"email": "olgakoroleva1969@postgrespro.ru", "phone": "+70440667803"}
0005432901779	16943F	0669 910888	DANIIL MAKAROV	{"email": "daniil-makarov061961@postgrespro.ru", "phone": "+70694287984"}
0005432901780	16943F	9851 438335	DARYA POPOVA	{"email": "d_popova-1964@postgrespro.ru", "phone": "+70240161701"}
0005432901781	16943F	9409 049180	OLEG TIMOFEEV	{"email": "timofeev_o-1967@postgrespro.ru", "phone": "+70144077387"}
0005432901782	B357C5	9166 141966	ANNA PETROVA	{"phone": "+70157825444"}
0005432901783	DDA2E3	1292 676862	ANNA KOZLOVA	{"email": "kozlovaa.101956@postgrespro.ru", "phone": "+70642403332"}
0005432901784	AA6774	7213 144747	SERGEY FOMIN	{"phone": "+70240347489"}
0005432901785	0B2D49	4381 391808	VALENTINA FILATOVA	{"phone": "+70076482139"}
0005432901786	5DAD23	3332 227672	LYUBOV KUZMINA	{"phone": "+70798927553"}
0005432901787	AA3FBA	1461 422894	VLADIMIR ZHUKOV	{"email": "zhukov_v-1965@postgrespro.ru", "phone": "+70700017768"}
0005432901788	D94B94	1770 894571	NATALYA KUDRYASHOVA	{"email": "natalyakudryashova1969@postgrespro.ru", "phone": "+70479983629"}
0005432901789	AC7ED8	1490 477993	NINA NAUMOVA	{"email": "naumova-n.081976@postgrespro.ru", "phone": "+70331674439"}
0005432901790	70E7E6	6072 549085	NINA ALEKSEEVA	{"phone": "+70379456670"}
0005432901791	7359B9	6208 204371	MIKHAIL MEDVEDEV	{"phone": "+70056735713"}
0005432901792	61B2A0	0646 989718	VYACHESLAV PETROV	{"email": "vyacheslav.petrov031969@postgrespro.ru", "phone": "+70157860755"}
0005432901793	AD970A	3050 530507	YULIYA PAVLOVA	{"email": "y-pavlova-21021966@postgrespro.ru", "phone": "+70370496317"}
0005432901794	9A4745	4559 572373	GENNADIY MELNIKOV	{"email": "gennadiy-melnikov021970@postgrespro.ru", "phone": "+70552788389"}
0005432901795	84A5D7	7546 729839	OLEG NAZAROV	{"phone": "+70744849895"}
0005432901796	4A5273	5166 236170	ALEKSEY IVANOV	{"phone": "+70951989899"}
0005432901797	4A5273	9493 397263	TIMUR FILIPPOV	{"phone": "+70969580661"}
0005432901798	FC6F38	0189 780550	ROMAN ALEKSEEV	{"phone": "+70029244366"}
0005432901799	0758C6	1315 332226	ROMAN KUZNECOV	{"phone": "+70811440910"}
0005432901800	4974E3	4324 717145	EKATERINA OSIPOVA	{"phone": "+70764655792"}
0005432901801	4974E3	2317 616076	ALEKSANDRA MATVEEVA	{"email": "aleksandra_matveeva-1971@postgrespro.ru", "phone": "+70592859516"}
0005432901802	B5CA23	6126 781075	VLADIMIR BONDARENKO	{"email": "v.bondarenko.02111964@postgrespro.ru", "phone": "+70301993540"}
0005432901803	7C3960	2379 277180	MIKHAIL KAZAKOV	{"email": "mikhail-kazakov_14121971@postgrespro.ru", "phone": "+70215038870"}
0005432901804	7C3960	1068 715480	SERGEY FEDOTOV	{"email": "fedotovsergey-021972@postgrespro.ru", "phone": "+70508515509"}
0005432901805	7C3960	1481 469681	OLGA VASILEVA	{"phone": "+70690588123"}
0005432901806	AFB9DC	1539 698208	ANDREY ANDREEV	{"phone": "+70972711334"}
0005432901807	476128	5224 891646	VERA POPOVA	{"phone": "+70543373179"}
0005432901808	476128	2402 062054	NINA NESTEROVA	{"email": "nesterova-n1977@postgrespro.ru", "phone": "+70911759259"}
0005432901809	E34A8D	7134 753737	ALEKSANDR SIDOROV	{"phone": "+70741585997"}
0005432901810	85C822	5488 217744	PETR FOMIN	{"phone": "+70174323075"}
0005432901811	46B46B	9275 814452	TATYANA LAZAREVA	{"email": "lazareva_t-21121969@postgrespro.ru", "phone": "+70732451608"}
0005432901812	46B46B	6355 004555	VADIM FILIPPOV	{"phone": "+70217540001"}
0005432901813	DCDC08	0735 722461	OKSANA ANISIMOVA	{"email": "oksanaanisimova_19121968@postgrespro.ru", "phone": "+70523311950"}
0005432901814	321475	8360 660095	VADIM MOROZOV	{"phone": "+70328962155"}
0005432901815	321475	4922 696418	EKATERINA POLYAKOVA	{"phone": "+70298335194"}
0005432901816	0627EE	5976 348585	IRINA KUZNECOVA	{"email": "kuznecovairina-09061955@postgrespro.ru", "phone": "+70479876804"}
0005432901817	0627EE	5082 117675	ARTEM KISELEV	{"phone": "+70998264385"}
0005432901818	69E974	3385 646980	LILIYA POTAPOVA	{"phone": "+70237153432"}
0005432901819	69E974	3292 450471	ELENA DMITRIEVA	{"email": "elena.dmitrieva-1978@postgrespro.ru", "phone": "+70763790732"}
0005432901820	99AE07	7299 391273	SERGEY KULIKOV	{"email": "sergey-kulikov_061974@postgrespro.ru", "phone": "+70235112657"}
0005432901821	35513D	7311 191212	ZOYA KOROLEVA	{"phone": "+70868641665"}
0005432901822	35513D	8994 166194	EKATERINA BORISOVA	{"phone": "+70258795983"}
0005432901823	F836C2	4201 252292	TATYANA KOZLOVA	{"phone": "+70907858232"}
0005432901824	0F62B4	1408 264823	NATALYA KUZNECOVA	{"email": "natalya_kuznecova.121977@postgrespro.ru", "phone": "+70955192813"}
0005432901825	5A7C26	4058 044053	IBRAGIM BELOV	{"phone": "+70252821682"}
0005432901826	D57A46	2459 509333	NATALIYA GRISHINA	{"phone": "+70425955279"}
0005432901827	D57A46	1545 128730	OLEG VOLKOV	{"phone": "+70769836968"}
0005432901828	2F3B19	6633 455550	ALEKSEY TARASOV	{"phone": "+70049373719"}
0005432901829	E033AE	2239 785914	DMITRIY VOLKOV	{"email": "volkov-dmitriy-011970@postgrespro.ru", "phone": "+70408497092"}
0005432901830	D86C28	0862 335761	ALEKSEY DMITRIEV	{"phone": "+70952867141"}
0005432901831	D86C28	0800 434116	ROZA PAVLOVA	{"phone": "+70649041744"}
0005432901832	9FB19A	1334 111384	ALEKSEY ANDREEV	{"email": "aleksey-andreev1976@postgrespro.ru", "phone": "+70153966456"}
0005432901833	9FB19A	7535 293974	DARYA BORISOVA	{"phone": "+70434968280"}
0005432901834	9FB19A	3086 277592	DMITRIY VLASOV	{"phone": "+70709380564"}
0005432901835	DB698B	9928 733992	ELIZAVETA DENISOVA	{"email": "edenisova_10021985@postgrespro.ru", "phone": "+70713954243"}
0005432901836	6BA469	8413 017601	MARINA DMITRIEVA	{"email": "marinadmitrieva.031972@postgrespro.ru", "phone": "+70439975887"}
0005432901837	F5C5BC	9008 970258	VIKTORIYA TARASOVA	{"email": "viktoriya.tarasova1985@postgrespro.ru", "phone": "+70979221035"}
0005432901838	F5C5BC	3506 626971	VERA KOROLEVA	{"email": "koroleva_vera.06061987@postgrespro.ru", "phone": "+70787302776"}
0005432901839	3E7424	8441 461159	ALEKSEY MAKAROV	{"email": "makarov_aleksey_021967@postgrespro.ru", "phone": "+70806292556"}
0005432901840	659F61	1291 431331	ALEKSANDR SOROKIN	{"email": "sorokin-a-02101965@postgrespro.ru", "phone": "+70683125819"}
0005432901841	46E08E	2087 978373	MARINA ZAYCEVA	{"phone": "+70131291149"}
0005432901842	348A62	3468 867758	TATYANA FEDOROVA	{"email": "fedorovat.10101972@postgrespro.ru", "phone": "+70915823373"}
0005432901843	CF9C16	1923 505559	ALEKSANDR TIKHONOV	{"email": "a_tikhonov-24041976@postgrespro.ru", "phone": "+70243318874"}
0005432901844	CF9C16	9139 827090	DMITRIY FILIPPOV	{"email": "dmitriy_filippov27051956@postgrespro.ru", "phone": "+70485431440"}
0005432901845	7A88BD	6625 901282	OLGA ABRAMOVA	{"email": "olga_abramova1976@postgrespro.ru", "phone": "+70700713573"}
0005432901846	62341E	6505 257318	SVETLANA ZOTOVA	{"phone": "+70341651263"}
0005432901847	157739	7943 801198	LIDIYA IVANOVA	{"phone": "+70476903073"}
0005432901848	157739	8858 627286	NADEZHDA VOLKOVA	{"email": "nadezhdavolkova-1971@postgrespro.ru", "phone": "+70976593481"}
0005432901849	157739	2079 986020	MARINA NESTEROVA	{"phone": "+70950047570"}
0005432901850	157739	7215 717480	TATYANA ALEKSANDROVA	{"email": "aleksandrova-tatyana-30091959@postgrespro.ru", "phone": "+70418363080"}
0005432901851	BE7217	3493 179934	DMITRIY GRIGOREV	{"phone": "+70949557379"}
0005432901852	C0D720	5778 642197	VALENTINA FILATOVA	{"email": "filatova.valentina-25071970@postgrespro.ru", "phone": "+70629177908"}
0005432901853	9FA736	9860 431522	NATALYA KONOVALOVA	{"email": "konovalova-natalya09111972@postgrespro.ru", "phone": "+70207436481"}
0005432901854	5E41F2	7973 862352	LILIYA TIMOFEEVA	{"email": "l_timofeeva.1972@postgrespro.ru", "phone": "+70976982149"}
0005432901855	0AEFD5	6307 893044	DMITRIY PETROV	{"email": "dmitriy.petrov-1964@postgrespro.ru", "phone": "+70908073397"}
0005432901856	68DBDC	9956 551951	ANATOLIY MAKSIMOV	{"phone": "+70753645663"}
0005432901857	877955	1427 937188	DMITRIY SOLOVEV	{"email": "solovev_d-1971@postgrespro.ru", "phone": "+70407723081"}
0005432901858	877955	3304 240150	MIKHAIL MEDVEDEV	{"email": "m_medvedev081964@postgrespro.ru", "phone": "+70647750587"}
0005432901859	F349FA	5458 139713	ANDREY KOZLOV	{"phone": "+70999756483"}
0005432901860	F349FA	9642 958849	VIKTOR ZAYCEV	{"phone": "+70800664047"}
0005432901861	369C1C	5408 488713	ALEKSANDR POPOV	{"phone": "+70944351191"}
0005432901862	97D42A	5805 651778	YURIY DENISOV	{"email": "denisov-y03031971@postgrespro.ru", "phone": "+70730133656"}
0005432901863	97D42A	1685 551435	IRINA ALEKSANDROVA	{"phone": "+70636239980"}
0005432901864	0C5EAD	2537 939527	NATALYA KOZLOVA	{"email": "natalya-kozlova-17091965@postgrespro.ru", "phone": "+70495591989"}
0005432901865	FAF6EE	3220 581712	DENIS EGOROV	{"phone": "+70232315557"}
0005432901866	C7C38A	8596 153023	VLADIMIR SEMENOV	{"email": "v_semenov.20031965@postgrespro.ru", "phone": "+70093579129"}
0005432901867	EB18ED	6053 232473	TATYANA KISELEVA	{"email": "t.kiseleva_06111981@postgrespro.ru", "phone": "+70383198440"}
0005432901868	EB18ED	4229 893885	DARYA ARKHIPOVA	{"email": "darya-arkhipova_1973@postgrespro.ru", "phone": "+70033522051"}
0005432901869	250C20	5819 579152	SERGEY KONOVALOV	{"email": "konovalov_s16021971@postgrespro.ru", "phone": "+70972410662"}
0005432901870	3D7592	3048 506319	ALEKSANDRA KUZNECOVA	{"phone": "+70082950934"}
0005432901871	3D7592	6739 774097	ALEKSANDR DAVYDOV	{"email": "davydov-a-26071972@postgrespro.ru", "phone": "+70167150697"}
0005432901872	FA20B5	3574 034900	LARISA SERGEEVA	{"phone": "+70012258570"}
0005432901873	19B592	7076 699476	DMITRIY FEDOROV	{"email": "fedorov_d_1970@postgrespro.ru", "phone": "+70974249914"}
0005432901874	9BE729	8903 025836	EKATERINA MOISEEVA	{"phone": "+70717861824"}
0005432901875	9BE729	1956 512463	ELENA EFIMOVA	{"email": "efimova.e_1974@postgrespro.ru", "phone": "+70732166337"}
0005432901876	EA56F8	0537 081381	VALENTINA KOROLEVA	{"email": "korolevavalentina_19121972@postgrespro.ru", "phone": "+70694370570"}
0005432901877	02E245	8249 139306	ALEKSANDR NIKITIN	{"email": "nikitin-a10121963@postgrespro.ru", "phone": "+70947131531"}
0005432901878	7809E6	7541 512708	TATYANA GAVRILOVA	{"email": "tatyanagavrilova-041979@postgrespro.ru", "phone": "+70456336282"}
0005432901879	7809E6	8427 062886	NIKITA ZHURAVLEV	{"email": "zhuravlev_n_1970@postgrespro.ru", "phone": "+70231466870"}
0005432901880	7809E6	2441 265346	OLGA ALEKSEEVA	{"email": "oalekseeva_081975@postgrespro.ru", "phone": "+70512874997"}
0005432901881	6C80BC	4336 444471	GALINA KISELEVA	{"email": "kiseleva-g1972@postgrespro.ru", "phone": "+70154816844"}
0005432901882	E6E273	7560 338990	MARIYA MIRONOVA	{"email": "mironova-mariya.1977@postgrespro.ru", "phone": "+70538504805"}
0005432901883	F8AF69	7020 354611	DANIIL AFANASEV	{"email": "afanasev-d061977@postgrespro.ru", "phone": "+70922607115"}
0005432901884	F8AF69	0320 519406	ALBINA NESTEROVA	{"phone": "+70766078880"}
0005432901885	1A9613	3159 102908	TAMARA LEBEDEVA	{"email": "lebedeva.tamara_1982@postgrespro.ru", "phone": "+70888289615"}
0005432901886	E84301	5638 393048	ALEKSANDR SOKOLOV	{"phone": "+70211779471"}
0005432901887	E84301	2585 603724	SVETLANA IVANOVA	{"email": "sivanova_19021980@postgrespro.ru", "phone": "+70389909581"}
0005432901888	0DF094	5138 079261	NINA KUZNECOVA	{"email": "kuznecovan_1976@postgrespro.ru", "phone": "+70686374935"}
0005432901889	0DF094	1302 684469	SVETLANA LOGINOVA	{"phone": "+70765937782"}
0005432901890	916130	4142 664683	ELENA KUZNECOVA	{"phone": "+70184640115"}
0005432901891	9E68E5	9345 179340	SERGEY YAKOVLEV	{"email": "yakovlev_s.1965@postgrespro.ru", "phone": "+70135636998"}
0005432901892	9E68E5	4967 144459	MARINA GAVRILOVA	{"phone": "+70792929144"}
0005432901893	C68691	3500 151304	SERGEY IVANOV	{"phone": "+70592341157"}
0005432901894	C68691	3791 196088	ALEKSEY MELNIKOV	{"phone": "+70044202288"}
0005432901895	EE2F21	1681 211822	VITALIY FEDOTOV	{"email": "fedotov-v-1962@postgrespro.ru", "phone": "+70007308599"}
0005432901896	7BADDF	3465 381709	ANATOLIY FROLOV	{"email": "frolovanatoliy_1968@postgrespro.ru", "phone": "+70910786706"}
0005432901897	0AAC61	9369 191702	IVAN GERASIMOV	{"email": "ivan.gerasimov011974@postgrespro.ru", "phone": "+70024350358"}
0005432901898	D50F51	9521 026153	GALINA VASILEVA	{"email": "galina.vasileva09011979@postgrespro.ru", "phone": "+70675254378"}
0005432901899	DE1A30	6519 610823	ARTEMIY BELOV	{"phone": "+70969613828"}
0005432901900	DE1A30	7445 609105	LYUDMILA KOVALEVA	{"email": "kovaleva_lyudmila.1965@postgrespro.ru", "phone": "+70735900534"}
0005432901901	61AB23	7188 661320	TATYANA MEDVEDEVA	{"email": "t.medvedeva24041975@postgrespro.ru", "phone": "+70137537125"}
0005432901902	EF06A6	3097 247208	SOFYA KUZMINA	{"phone": "+70508249833"}
0005432901903	2C746A	5395 660716	SERGEY KUZMIN	{"email": "sergey_kuzmin.051979@postgrespro.ru", "phone": "+70639639964"}
0005432901904	2C746A	0845 447871	IGOR IVANOV	{"phone": "+70726881303"}
0005432901905	56F318	9703 176314	TATYANA FOMINA	{"phone": "+70216495418"}
0005432901906	754246	1597 270831	NADEZHDA FROLOVA	{"email": "nadezhda_frolova1973@postgrespro.ru", "phone": "+70558786324"}
0005432901907	811273	6635 092331	PETR KULIKOV	{"phone": "+70755910665"}
0005432901908	7CA1FF	5565 395518	TATYANA DAVYDOVA	{"email": "davydova.tatyana.20111969@postgrespro.ru", "phone": "+70386040354"}
0005432901909	BAFD54	3417 845829	ANNA ZAYCEVA	{"phone": "+70258313243"}
0005432901910	9C3FBC	9727 074384	VALENTINA SOROKINA	{"phone": "+70472197425"}
0005432901911	7F7FD0	8747 281757	LIDIYA EFREMOVA	{"phone": "+70505324825"}
0005432901912	58AEB2	7256 088828	VALERIYA MAKAROVA	{"email": "v-makarova.041967@postgrespro.ru", "phone": "+70743705523"}
0005432901913	58AEB2	3653 319215	ELIZAVETA ALEKSANDROVA	{"email": "elizaveta.aleksandrova071978@postgrespro.ru", "phone": "+70255373540"}
0005432901914	806E3C	7499 110228	VALERIYA KONOVALOVA	{"phone": "+70388639374"}
0005432901915	806E3C	9402 499661	VALENTINA VOLKOVA	{"email": "volkova.valentina_16111955@postgrespro.ru", "phone": "+70232189353"}
0005432901916	8F5792	7880 132313	VALENTINA STEPANOVA	{"email": "vstepanova.15041979@postgrespro.ru", "phone": "+70752190100"}
0005432901917	E69D92	0368 134898	ALLA NIKOLAEVA	{"email": "nikolaevaalla11051980@postgrespro.ru", "phone": "+70193302348"}
0005432901918	C021A1	8787 116363	IVAN BORISOV	{"email": "ivan-borisov.1958@postgrespro.ru", "phone": "+70321768006"}
0005432901919	C021A1	6641 308310	NINA ABRAMOVA	{"email": "nina.abramova-071981@postgrespro.ru", "phone": "+70276580775"}
0005432901920	CAA03E	7242 600918	RUFINA DENISOVA	{"phone": "+70723335022"}
0005432901921	CAA03E	5201 044811	LARISA MEDVEDEVA	{"phone": "+70592647813"}
0005432901922	9556F3	4464 584798	ANNA NOVIKOVA	{"email": "anovikova1962@postgrespro.ru", "phone": "+70170123475"}
0005432901923	FDFF97	0465 939516	MARIYA KUZNECOVA	{"email": "kuznecova_m1977@postgrespro.ru", "phone": "+70726299384"}
0005432901924	FDFF97	2307 962907	VITALIY AFANASEV	{"email": "v_afanasev_1972@postgrespro.ru", "phone": "+70514133314"}
0005432901925	3F4A87	8011 710399	EKATERINA PAVLOVA	{"email": "pavlova_e-21011977@postgrespro.ru", "phone": "+70855529725"}
0005432901926	551320	2787 323108	NIKOLAY KULIKOV	{"phone": "+70328742572"}
0005432901927	F577B9	2631 918132	NINEL FILATOVA	{"email": "ninel-filatova-111980@postgrespro.ru", "phone": "+70695436512"}
0005432901928	F577B9	2755 280620	TATYANA FEDOROVA	{"email": "fedorova-tatyana121968@postgrespro.ru", "phone": "+70969033691"}
0005432901929	F577B9	1298 973062	ELENA LEBEDEVA	{"email": "lebedeva.elena_1969@postgrespro.ru", "phone": "+70921914954"}
0005432901930	785F76	5970 172727	IRINA ROMANOVA	{"phone": "+70896301615"}
0005432901931	785F76	1106 509646	SERGEY FOMIN	{"email": "fomin_s_1966@postgrespro.ru", "phone": "+70292283324"}
0005432901932	1DE743	0260 326638	VLADIMIR MIRONOV	{"email": "v_mironov-1975@postgrespro.ru", "phone": "+70630237430"}
0005432901933	D7DF04	1145 419021	RAISA MAKAROVA	{"email": "raisa.makarova.101980@postgrespro.ru", "phone": "+70304928215"}
0005432901934	DFBDCC	0755 793927	ANDREY NIKOLAEV	{"email": "nikolaeva-1972@postgrespro.ru", "phone": "+70875869873"}
0005432901935	57B6A4	1138 322946	TATYANA ZAKHAROVA	{"email": "tzakharova26121986@postgrespro.ru", "phone": "+70609938862"}
0005432901936	57B6A4	1109 253985	SVETLANA GAVRILOVA	{"phone": "+70017612674"}
0005432901937	890C72	7922 493174	VALERIY EGOROV	{"email": "valeriy.egorov.021968@postgrespro.ru", "phone": "+70645660299"}
0005432901938	890C72	8652 466708	SAVELIY MATVEEV	{"email": "matveev_saveliy07041966@postgrespro.ru", "phone": "+70144399759"}
0005432901939	E09D01	8453 471322	NIKOLAY GUSEV	{"phone": "+70673255607"}
0005432901940	E09D01	6733 101652	EVGENIY BORISOV	{"email": "e_borisov-09021970@postgrespro.ru", "phone": "+70922426785"}
0005432901941	81F0A8	7181 155747	ROSTISLAV SOLOVEV	{"phone": "+70878910991"}
0005432901942	81F0A8	5179 978307	OLGA KOMAROVA	{"email": "komarova.o-1974@postgrespro.ru", "phone": "+70292882845"}
0005432901943	C94440	7944 542932	IGOR ZAYCEV	{"phone": "+70567561263"}
0005432901944	C94440	5762 271748	EVGENIY ROMANOV	{"email": "evgeniy_romanov_21061964@postgrespro.ru", "phone": "+70235941537"}
0005432901945	C94440	0933 420462	GALINA KOVALEVA	{"email": "galina_kovaleva1963@postgrespro.ru", "phone": "+70450982477"}
0005432901946	C94440	3903 096593	DMITRIY EGOROV	{"email": "egorov.dmitriy.22091979@postgrespro.ru", "phone": "+70528329720"}
0005432901947	90F184	5457 315906	NIKITA ZHURAVLEV	{"email": "zhuravlev-nikita_031977@postgrespro.ru", "phone": "+70893036860"}
0005432901948	90F184	6167 972813	YULIYA YAKOVLEVA	{"email": "yuliyayakovleva-1977@postgrespro.ru", "phone": "+70867687956"}
0005432901949	44CDD6	6913 217639	VLADISLAV TARASOV	{"email": "tarasovv-21091961@postgrespro.ru", "phone": "+70670680663"}
0005432901950	A306EB	6799 937402	OLEG POPOV	{"phone": "+70322092391"}
0005432901951	9299F2	5173 249463	VIKTOR FILIPPOV	{"email": "filippov-v.1973@postgrespro.ru", "phone": "+70708733242"}
0005432901952	9299F2	8073 225224	ALEKSEY SOKOLOV	{"phone": "+70016051451"}
0005432901953	457869	9405 957790	ALEKSANDR VOROBEV	{"phone": "+70083257012"}
0005432901954	E77AB5	6072 555105	VALENTIN ZHUKOV	{"email": "valentin_zhukov.071975@postgrespro.ru", "phone": "+70342502354"}
0005432901955	9CD210	8461 536975	VYACHESLAV MAKAROV	{"phone": "+70298814476"}
0005432901956	9CD210	1074 028989	ALEKSANDR SEMENOV	{"phone": "+70770367313"}
0005432901957	9CD210	2943 937932	VALERIY IVANOV	{"email": "valeriy.ivanov1980@postgrespro.ru", "phone": "+70277890583"}
0005432901958	9CD210	3031 811414	ALEKSANDR GORBUNOV	{"phone": "+70148760304"}
0005432901959	158FA8	2148 769753	YURIY ZAKHAROV	{"email": "yuriyzakharov_011969@postgrespro.ru", "phone": "+70781014844"}
0005432901960	E4F2C6	0803 728099	SERGEY KUZNECOV	{"email": "sergey-kuznecov_121970@postgrespro.ru", "phone": "+70851491342"}
0005432901961	E4F2C6	6545 321513	EVGENIY PETROV	{"email": "petrovevgeniy-031978@postgrespro.ru", "phone": "+70947428160"}
0005432901962	3072BB	9470 059276	LYUBOV SEMENOVA	{"email": "semenova-l071975@postgrespro.ru", "phone": "+70972202417"}
0005432901963	C1FE2A	8804 073510	ALEKSEY VLASOV	{"email": "vlasovaleksey-061974@postgrespro.ru", "phone": "+70416397578"}
0005432901964	C1FE2A	2391 667061	ANATOLIY MARTYNOV	{"phone": "+70713870080"}
0005432901965	169F95	5939 364602	IRINA IVANOVA	{"email": "iivanova02041966@postgrespro.ru", "phone": "+70835078034"}
0005432901966	D0C468	0722 556153	ANATOLIY YAKOVLEV	{"phone": "+70637584832"}
0005432901967	D0C468	1823 993870	ALEKSANDR SIDOROV	{"email": "sidorov-a-101964@postgrespro.ru", "phone": "+70003972618"}
0005432901968	662F9E	9194 592182	VITALIY ZAYCEV	{"email": "vzaycev-1973@postgrespro.ru", "phone": "+70178821835"}
0005432901969	0C628E	7952 786114	VERA KULIKOVA	{"email": "verakulikova.051971@postgrespro.ru", "phone": "+70603014225"}
0005432901970	228179	8966 622554	GALINA GERASIMOVA	{"email": "galina.gerasimova-1962@postgrespro.ru", "phone": "+70105381388"}
0005432901971	228179	7925 932135	OLGA EFREMOVA	{"email": "efremova.o-1977@postgrespro.ru", "phone": "+70636520332"}
0005432901972	228179	8828 352774	EKATERINA SAVELEVA	{"email": "saveleva.ekaterina05051970@postgrespro.ru", "phone": "+70456116448"}
0005432901973	45D60E	1269 432382	VYACHESLAV MELNIKOV	{"email": "vyacheslav-melnikov_15091973@postgrespro.ru", "phone": "+70639451275"}
0005432901974	927105	4906 288536	OLGA VASILEVA	{"phone": "+70403178099"}
0005432901975	927105	1649 448591	NIKOLAY NOVIKOV	{"phone": "+70816269073"}
0005432901976	D6B976	2220 450071	VLADIMIR SIDOROV	{"phone": "+70755686926"}
0005432901977	4F6BC2	3397 404006	GALINA KONDRATEVA	{"email": "galina-kondrateva-08121966@postgrespro.ru", "phone": "+70910239498"}
0005432901978	4F6BC2	8183 467901	OLEG SCHERBAKOV	{"email": "oleg.scherbakov_121972@postgrespro.ru", "phone": "+70942252799"}
0005432901979	589517	3996 201736	DMITRIY IVANOV	{"email": "ivanov.dmitriy041975@postgrespro.ru", "phone": "+70889549571"}
0005432901980	F55041	2913 429839	SERGEY SCHERBAKOV	{"email": "sscherbakov.10081965@postgrespro.ru", "phone": "+70617760728"}
0005432901981	F55041	8704 342394	TIMOFEY POPOV	{"email": "timofey.popov.1970@postgrespro.ru", "phone": "+70949355456"}
0005432901982	727225	9713 260922	VLADIMIR SAVELEV	{"email": "vladimir.savelev-021976@postgrespro.ru", "phone": "+70963587651"}
0005432901983	727225	3121 328734	IVAN DAVYDOV	{"phone": "+70453598420"}
0005432901984	14E494	9269 658869	YURIY SERGEEV	{"email": "yuriysergeev_03061970@postgrespro.ru", "phone": "+70756755176"}
0005432901985	14E494	7885 209570	ELIZAVETA FILIPPOVA	{"email": "filippovaelizaveta.09111983@postgrespro.ru", "phone": "+70666456981"}
0005432901986	B364A4	1123 513181	SVETLANA FILIPPOVA	{"phone": "+70096486407"}
0005432901987	CC1121	0403 631829	DMITRIY MAKAROV	{"email": "d_makarov_01051979@postgrespro.ru", "phone": "+70170546146"}
0005432901988	CC1121	9945 404276	MARIYA ORLOVA	{"phone": "+70987565197"}
0005432901989	5C19BE	3025 762297	LYUDMILA EFREMOVA	{"email": "efremova_l_03071962@postgrespro.ru", "phone": "+70893012569"}
0005432901990	4B0253	6256 589280	NATALYA FEDOROVA	{"email": "natalya_fedorova.1966@postgrespro.ru", "phone": "+70831108363"}
0005432901991	2E166E	3326 210274	SERGEY TIKHONOV	{"phone": "+70007902686"}
0005432901992	945657	5611 555845	IRINA SMIRNOVA	{"phone": "+70919159019"}
0005432901993	945657	7360 599815	NATALYA LEBEDEVA	{"email": "natalya_lebedeva.14021969@postgrespro.ru", "phone": "+70403309210"}
0005432901994	945657	4205 040575	ANNA GAVRILOVA	{"email": "a_gavrilova1968@postgrespro.ru", "phone": "+70695794498"}
0005432901995	5A081F	5088 644953	DENIS MATVEEV	{"phone": "+70906659556"}
0005432901996	5A081F	8605 575877	ANDREY DENISOV	{"email": "a.denisov-041971@postgrespro.ru", "phone": "+70531395568"}
0005432901997	02F6FF	8438 303300	VLADIMIR FILIPPOV	{"phone": "+70654204939"}
0005432901998	9A5D5E	3575 988789	DMITRIY GRIGOREV	{"email": "grigorev.d_1968@postgrespro.ru", "phone": "+70146323109"}
0005432901999	A07484	5998 437414	VYACHESLAV NAZAROV	{"phone": "+70687950261"}
0005432902000	0E4828	6159 300304	VLADIMIR DMITRIEV	{"phone": "+70655764108"}
0005432902001	E8DA17	9612 344708	NIKITA DENISOV	{"phone": "+70010051940"}
0005432902002	F9E306	1702 392098	SVETLANA KONOVALOVA	{"phone": "+70793851581"}
0005432902003	355B99	6821 933304	ALEKSEY RODIONOV	{"email": "rodionov.aleksey_14021974@postgrespro.ru", "phone": "+70313462111"}
0005432902004	1F04C7	6368 667628	MARIANNA SCHERBAKOVA	{"phone": "+70498012929"}
0005432902005	B8F355	4235 308182	VALERIY ALEKSANDROV	{"phone": "+70626951746"}
0005432902006	A11F45	5719 398855	ZINAIDA VASILEVA	{"phone": "+70406970046"}
0005432902007	A4111A	8686 633410	VLADIMIR KARPOV	{"email": "karpov.vladimir.031968@postgrespro.ru", "phone": "+70992392972"}
0005432902008	A4111A	0303 563706	VLADIMIR MAKAROV	{"phone": "+70692060897"}
0005432902009	FCE610	4973 133386	ELENA SMIRNOVA	{"phone": "+70066624414"}
0005432902010	FCE610	6465 855883	GALINA ARKHIPOVA	{"phone": "+70389379798"}
0005432902011	09A234	0220 000662	YULIYA NIKOLAEVA	{"email": "nikolaeva_y_28021981@postgrespro.ru", "phone": "+70970665696"}
0005432902012	2EF70B	8400 259410	SABINA ZAKHAROVA	{"email": "s_zakharova_051970@postgrespro.ru", "phone": "+70967553927"}
0005432902013	C233B8	8437 360294	VLADIMIR KOZLOV	{"email": "kozlov_vladimir.081983@postgrespro.ru", "phone": "+70337220169"}
0005432902014	C233B8	5354 012351	ANASTASIYA VOLKOVA	{"email": "volkova-anastasiya1972@postgrespro.ru", "phone": "+70173713292"}
0005432902015	849472	3917 493676	VYACHESLAV SMIRNOV	{"email": "smirnovv.111973@postgrespro.ru", "phone": "+70646363897"}
0005432902016	849472	2188 053137	NADEZHDA MEDVEDEVA	{"phone": "+70130677238"}
0005432902017	9BC867	0428 053616	ANASTASIYA GUSEVA	{"phone": "+70410780242"}
0005432902018	9BC867	6558 810623	VIKTOR SOLOVEV	{"email": "solovev-v_061982@postgrespro.ru", "phone": "+70147119264"}
0005432902019	7581F9	4421 843162	ELENA POPOVA	{"phone": "+70724234919"}
0005432902020	BE3351	3643 963773	SERGEY KULIKOV	{"phone": "+70374144185"}
0005432902021	BE3351	7999 741452	RINAT KUZNECOV	{"phone": "+70316660825"}
0005432902022	1DE56A	8125 630998	EKATERINA GUSEVA	{"phone": "+70182183054"}
0005432902023	54EF3E	7584 000169	LYUDMILA SAVELEVA	{"phone": "+70639337753"}
0005432902024	54EF3E	1270 734220	LIDIYA FILIPPOVA	{"email": "filippova-l.21011957@postgrespro.ru", "phone": "+70936191468"}
0005432902025	098ACB	0780 943263	RODION FEDOROV	{"email": "fedorov_rodion.1962@postgrespro.ru", "phone": "+70626625158"}
0005432902026	098ACB	7843 569906	RINAT ISAEV	{"phone": "+70449929011"}
0005432902027	70F557	8682 476125	ALEKSANDR PETROV	{"phone": "+70911669115"}
0005432902028	FBB2F9	6199 214757	ANDREY SOLOVEV	{"phone": "+70069804754"}
0005432902029	FBB2F9	3143 967980	KSENIYA AFANASEVA	{"email": "kseniya_afanaseva.1967@postgrespro.ru", "phone": "+70186240459"}
0005432902030	F1BA00	0833 146639	NADEZHDA NAZAROVA	{"email": "nadezhdanazarova071970@postgrespro.ru", "phone": "+70102737903"}
0005432902031	B13582	3949 964936	KRISTINA GORBUNOVA	{"phone": "+70774513559"}
0005432902032	9DCE33	4749 649302	MARIYA KRASNOVA	{"phone": "+70648232497"}
0005432902033	360689	3718 634124	SERGEY MEDVEDEV	{"email": "sergey_medvedev111962@postgrespro.ru", "phone": "+70664141505"}
0005432902034	C5CB51	5268 201337	IGOR KUZNECOV	{"email": "i_kuznecov-05051968@postgrespro.ru", "phone": "+70774197524"}
0005432902035	425B45	3983 278550	VALERIY IVANOV	{"email": "ivanovv.081981@postgrespro.ru", "phone": "+70900353248"}
0005432902036	425B45	5437 844356	ANNA FILATOVA	{"phone": "+70312905317"}
0005432902037	425B45	9168 604000	LIDIYA KOZLOVA	{"phone": "+70847797026"}
0005432902038	D4E16F	9222 618684	SERGEY KUZNECOV	{"email": "s-kuznecov.24101965@postgrespro.ru", "phone": "+70683019664"}
0005432902039	2E0449	3219 141764	MARIYA EFREMOVA	{"phone": "+70347746626"}
0005432902040	2E0449	2589 522987	DARYA KUZNECOVA	{"phone": "+70734303826"}
0005432902041	342311	8160 712398	VALENTIN ZAKHAROV	{"email": "zakharov-valentin.1974@postgrespro.ru", "phone": "+70888439878"}
0005432902042	335072	8263 050362	NADEZHDA ANDREEVA	{"email": "nadezhda-andreeva-1976@postgrespro.ru", "phone": "+70825374647"}
0005432902043	335072	1840 153620	GRIGORIY FILIPPOV	{"phone": "+70339701943"}
0005432902044	93F271	1828 151190	ALEKSANDR NOVIKOV	{"email": "novikov.a1972@postgrespro.ru", "phone": "+70941073773"}
0005432902045	391D25	8393 633091	GRIGORIY NIKITIN	{"email": "grigoriy.nikitin-031975@postgrespro.ru", "phone": "+70125807389"}
0005432902046	4CB5CB	3517 142538	OLGA RODIONOVA	{"email": "o_rodionova1968@postgrespro.ru", "phone": "+70957680421"}
0005432902047	8EB365	5875 116156	ELVIRA DMITRIEVA	{"phone": "+70804232122"}
0005432902048	453C9F	1404 055946	GALINA KOLESNIKOVA	{"email": "g_kolesnikova.1971@postgrespro.ru", "phone": "+70185260854"}
0005432902049	453C9F	3811 893383	LYUDMILA ZAYCEVA	{"email": "lyudmila-zayceva_121988@postgrespro.ru", "phone": "+70470072865"}
0005432902050	D11A12	3020 061187	DMITRIY KOZLOV	{"phone": "+70928141837"}
0005432902051	4575B9	3630 299566	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana.031972@postgrespro.ru", "phone": "+70889980714"}
0005432902052	0508EE	4077 471933	VALENTINA ALEKSANDROVA	{"phone": "+70712651957"}
0005432902053	422425	1871 448063	MARIYA SOLOVEVA	{"email": "msoloveva1974@postgrespro.ru", "phone": "+70499369630"}
0005432902054	75E5D1	1505 160890	LYUDMILA GORBUNOVA	{"email": "lyudmilagorbunova-16111972@postgrespro.ru", "phone": "+70907890299"}
0005432902055	080D3B	5317 666125	OLGA SOROKINA	{"email": "olga_sorokina-021980@postgrespro.ru", "phone": "+70473210863"}
0005432902056	B14682	7266 426999	IVAN KUZNECOV	{"email": "kuznecov.ivan1970@postgrespro.ru", "phone": "+70273142983"}
0005432902057	62A8D4	7234 295704	GALIYA KULIKOVA	{"email": "galiya.kulikova_1962@postgrespro.ru", "phone": "+70765136733"}
0005432902058	F21EC8	1354 180511	YURIY ZAKHAROV	{"phone": "+70457417529"}
0005432902059	904F58	2000 332711	IRINA NOVIKOVA	{"phone": "+70164508141"}
0005432902060	3A516B	0459 210198	IGOR DMITRIEV	{"email": "igor.dmitriev.1977@postgrespro.ru", "phone": "+70178185353"}
0005432902061	005706	5204 367499	RAISA VASILEVA	{"email": "raisa.vasileva01041971@postgrespro.ru", "phone": "+70742074911"}
0005432902062	AC9EFB	8452 205799	EVGENIYA FEDOROVA	{"phone": "+70312387403"}
0005432902063	AC9EFB	8801 608634	TATYANA NOVIKOVA	{"phone": "+70279780303"}
0005432902064	9E7791	2898 456419	ALEKSANDRA FROLOVA	{"phone": "+70752379291"}
0005432902065	39AB4B	6883 631194	TATYANA ILINA	{"phone": "+70782701442"}
0005432902066	39AB4B	2254 485483	VITALIY GAVRILOV	{"phone": "+70605065051"}
0005432902067	21DBD1	7361 482201	NATALYA ANTONOVA	{"email": "nantonova_1973@postgrespro.ru", "phone": "+70195334857"}
0005432902068	21DBD1	2954 624513	YULIYA IVANOVA	{"phone": "+70644951711"}
0005432902069	21DBD1	9469 818536	NATALYA KUZMINA	{"phone": "+70341677509"}
0005432902070	9502D4	4351 718815	KSENIYA MIRONOVA	{"phone": "+70476124018"}
0005432902071	02577F	2952 856310	VIKTOR EGOROV	{"email": "viktor_egorov-041968@postgrespro.ru", "phone": "+70561446876"}
0005432902072	6CD667	2380 900484	NADEZHDA ANDREEVA	{"phone": "+70289266020"}
0005432902073	685117	2174 340110	VALERIY BORISOV	{"phone": "+70191722630"}
0005432902074	D47091	8227 349443	NINA ZOTOVA	{"email": "zotova.n.1974@postgrespro.ru", "phone": "+70746404737"}
0005432902075	D47091	8740 188591	ALEKSANDRA VOLKOVA	{"email": "volkova_a.10121987@postgrespro.ru", "phone": "+70492207661"}
0005432902076	B9BB32	9352 764614	ALEKSEY MAKSIMOV	{"phone": "+70944677246"}
0005432902077	B9BB32	4603 497989	VLADIMIR SAVELEV	{"phone": "+70719272402"}
0005432902078	F6D218	6509 717958	VASILIY POPOV	{"phone": "+70990392236"}
0005432902079	EB12F3	2578 279272	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov15121987@postgrespro.ru", "phone": "+70467028276"}
0005432902080	EB12F3	9349 621820	MIKHAIL SERGEEV	{"email": "sergeev-mikhail_061969@postgrespro.ru", "phone": "+70011224602"}
0005432902081	EB12F3	4317 636048	ALEKSEY ANDREEV	{"phone": "+70371641426"}
0005432902082	304F18	5538 566294	OLGA MIRONOVA	{"email": "mironova.olga081969@postgrespro.ru", "phone": "+70978112578"}
0005432902083	63F4B3	3394 034388	NIKITA DAVYDOV	{"phone": "+70149149419"}
0005432902084	63F4B3	1913 536521	VIKTOR MOISEEV	{"phone": "+70225457771"}
0005432902085	63F4B3	6566 814962	LARISA EFIMOVA	{"email": "efimoval_1969@postgrespro.ru", "phone": "+70433509105"}
0005432902086	B6505D	2688 106865	ASKHAT VASILEV	{"phone": "+70320778150"}
0005432902087	F97160	3799 686967	ANNA VASILEVA	{"phone": "+70491892250"}
0005432902088	F97160	5283 468892	RUSLAN KUZNECOV	{"phone": "+70179716788"}
0005432902089	495885	2261 591276	NELLI NAUMOVA	{"email": "n-naumova_03091970@postgrespro.ru", "phone": "+70323566662"}
0005432902090	495885	2414 804685	DAMIR BONDARENKO	{"email": "d-bondarenko.081974@postgrespro.ru", "phone": "+70035011244"}
0005432902091	ABCB36	4212 963926	ALEKSEY SCHERBAKOV	{"email": "a_scherbakov071973@postgrespro.ru", "phone": "+70730204072"}
0005432902092	B36EEF	8865 479486	LYUDMILA VOROBEVA	{"email": "lyudmila-vorobeva111955@postgrespro.ru", "phone": "+70235755524"}
0005432902093	401F0F	0407 893880	ANASTASIYA KONDRATEVA	{"email": "anastasiya-kondrateva_06101966@postgrespro.ru", "phone": "+70471394640"}
0005432902094	3024E6	2319 073131	ALEKSEY BORISOV	{"email": "borisov_a-1962@postgrespro.ru", "phone": "+70189289838"}
0005432902095	EB636A	3274 049473	SERGEY FOMIN	{"email": "fominsergey-11031962@postgrespro.ru", "phone": "+70003259340"}
0005432902096	EB636A	4895 874238	DENIS SERGEEV	{"email": "d-sergeev1972@postgrespro.ru", "phone": "+70644446638"}
0005432902097	0CB160	5938 762101	VALENTINA ZHUKOVA	{"phone": "+70437568542"}
0005432902098	2E7B85	3649 369002	SERGEY SOKOLOV	{"phone": "+70382692300"}
0005432902099	E9A490	3719 583355	IVAN PETROV	{"phone": "+70483131058"}
0005432902100	671652	8480 558735	FEDOR ORLOV	{"phone": "+70965135943"}
0005432902101	7F8BFD	4538 328834	ZINAIDA NESTEROVA	{"email": "z-nesterova02121970@postgrespro.ru", "phone": "+70965455723"}
0005432902102	3321A3	0946 460577	ALEKSANDRA TITOVA	{"phone": "+70369617255"}
0005432902103	CB705D	1254 042407	ELENA KUZNECOVA	{"phone": "+70853526373"}
0005432902104	CB705D	4307 569138	ANDREY CHERNOV	{"email": "achernov_041969@postgrespro.ru", "phone": "+70895115169"}
0005432902105	BEBB93	0387 190101	DMITRIY ANDREEV	{"phone": "+70702251648"}
0005432902106	630E8D	3837 064081	NATALYA SEMENOVA	{"email": "semenova-natalya-20091969@postgrespro.ru", "phone": "+70584237050"}
0005432902107	972C3E	8637 268577	ALEKSANDRA RODIONOVA	{"phone": "+70530389303"}
0005432902108	09CCF2	4361 071926	ILYA KRASNOV	{"email": "krasnov_i.07061969@postgrespro.ru", "phone": "+70986598775"}
0005432902109	09CCF2	4564 854834	VERONIKA FROLOVA	{"email": "frolova_v_15041978@postgrespro.ru", "phone": "+70585221286"}
0005432902110	BCB17A	5139 714303	VIKTOR VASILEV	{"email": "vasilev_v1972@postgrespro.ru", "phone": "+70274809893"}
0005432902111	BCB17A	5994 268195	ALENA EFIMOVA	{"email": "efimova_alena_23101980@postgrespro.ru", "phone": "+70817373929"}
0005432902112	03DE0A	7498 562638	GALINA ZHUKOVA	{"email": "g-zhukova.071977@postgrespro.ru", "phone": "+70048945816"}
0005432902113	B23CCE	3369 005125	VIKTORIYA SOKOLOVA	{"phone": "+70400161154"}
0005432902114	0BB090	3610 988955	ELENA SOROKINA	{"phone": "+70795618708"}
0005432902115	912510	1150 239266	YULIYA SOKOLOVA	{"phone": "+70686826577"}
0005432902116	0576F1	5839 581423	VLADIMIR SERGEEV	{"email": "sergeev-vladimir.041970@postgrespro.ru", "phone": "+70241779874"}
0005432902117	DDFACD	9450 238193	VIKTOR POPOV	{"email": "v.popov-1983@postgrespro.ru", "phone": "+70161531116"}
0005432902118	DDFACD	0546 674449	RINAT PETROV	{"email": "petrov_r101974@postgrespro.ru", "phone": "+70093020028"}
0005432902119	E224D2	6465 437558	SERGEY SOKOLOV	{"email": "sokolov_sergey-1968@postgrespro.ru", "phone": "+70499714777"}
0005432902120	E224D2	1671 678801	SERGEY MAKAROV	{"email": "sergey_makarov1972@postgrespro.ru", "phone": "+70629020795"}
0005432902121	821B2F	0413 835280	VALERIY KARPOV	{"phone": "+70188636747"}
0005432902122	CD6989	2177 674745	YULIYA TIKHONOVA	{"phone": "+70926694952"}
0005432902123	CD6989	8942 078880	DARYA IVANOVA	{"email": "ivanova.darya.1981@postgrespro.ru", "phone": "+70953006317"}
0005432902124	6D60C8	3531 684931	LILIYA FOMINA	{"email": "l-fomina121976@postgrespro.ru", "phone": "+70403711522"}
0005432902125	30BA33	6144 457795	PAVEL KULIKOV	{"phone": "+70562451415"}
0005432905019	698A40	1810 358055	TATYANA TIKHONOVA	{"phone": "+70445344589"}
0005432905020	698A40	3910 506622	GENNADIY IVANOV	{"phone": "+70968951654"}
0005432905021	3C86C4	8303 887579	OLGA KISELEVA	{"phone": "+70555965840"}
0005432905022	3C86C4	9995 472144	IVAN STEPANOV	{"phone": "+70045954368"}
0005432905023	0DF9E4	3610 572383	DIANA MIRONOVA	{"email": "mironova-diana.061977@postgrespro.ru", "phone": "+70721999937"}
0005432905024	DDF891	3518 012340	IRINA KUZNECOVA	{"phone": "+70371618595"}
0005432905025	DDF891	0348 807929	SERGEY DAVYDOV	{"email": "sdavydov_051963@postgrespro.ru", "phone": "+70074347151"}
0005432905026	CCF038	6427 072012	KUZMA YAKOVLEV	{"phone": "+70120128817"}
0005432905027	A4835E	1560 693508	ALEKSANDRA EFIMOVA	{"email": "efimova-a1972@postgrespro.ru", "phone": "+70256366640"}
0005432905028	A4835E	6034 955938	STANISLAV CHERNOV	{"email": "chernov.s_061965@postgrespro.ru", "phone": "+70945247590"}
0005432905029	F66E38	6361 724840	POLINA IVANOVA	{"email": "p_ivanova-21091967@postgrespro.ru", "phone": "+70564040063"}
0005432905030	3E23E4	9527 347237	VIKTORIYA GORBUNOVA	{"phone": "+70741550075"}
0005432905031	63E5A4	2733 912312	NADEZHDA BORISOVA	{"phone": "+70504220244"}
0005432905032	13EE8E	6027 590151	ANNA ILINA	{"email": "a-ilina-101976@postgrespro.ru", "phone": "+70632552814"}
0005432905033	0E456E	9989 108416	ALEKSEY VOLKOV	{"email": "volkovaleksey-1965@postgrespro.ru", "phone": "+70191517651"}
0005432905034	FEE361	8880 299742	NATALYA ORLOVA	{"email": "orlova.n15081966@postgrespro.ru", "phone": "+70693710485"}
0005432905035	FEE361	9154 323535	DMITRIY PAVLOV	{"email": "dmitriy-pavlov.1972@postgrespro.ru", "phone": "+70116357782"}
0005432905036	AC31A8	5781 196736	SVETLANA MOISEEVA	{"email": "s_moiseeva031980@postgrespro.ru", "phone": "+70303867730"}
0005432905037	996959	7368 051788	NATALYA ANISIMOVA	{"phone": "+70139189958"}
0005432905038	996959	6426 502703	SVETLANA BARANOVA	{"email": "svetlana.baranova_1974@postgrespro.ru", "phone": "+70499344888"}
0005432905039	72719A	1081 850880	VYACHESLAV STEPANOV	{"phone": "+70521522996"}
0005432905040	897E69	9710 255657	RAUZA ABRAMOVA	{"phone": "+70759371187"}
0005432905041	32C0E1	8783 578057	ARTEM ALEKSANDROV	{"email": "artem_aleksandrov-1973@postgrespro.ru", "phone": "+70263394682"}
0005432905042	3953A4	4015 944902	ARTEM GUSEV	{"email": "guseva.111974@postgrespro.ru", "phone": "+70685623248"}
0005432905043	BFE0D3	1098 974014	GALINA ANDREEVA	{"phone": "+70099044962"}
0005432905044	C21100	8629 465672	EVGENIYA NOVIKOVA	{"phone": "+70904851611"}
0005432905045	C21100	7923 361090	LYUDMILA AKIMOVA	{"email": "lyudmilaakimova1953@postgrespro.ru", "phone": "+70852714477"}
0005432905046	606CF8	6518 834924	MIKHAIL MELNIKOV	{"email": "mmelnikov.1972@postgrespro.ru", "phone": "+70216594808"}
0005432905047	606CF8	3829 623218	ALEKSANDRA KONDRATEVA	{"phone": "+70650625851"}
0005432905048	B6B5B3	7557 272972	SERGEY TARASOV	{"phone": "+70438307939"}
0005432905049	2F37E1	0158 523382	SERGEY KULIKOV	{"phone": "+70490119690"}
0005432905050	97DCFD	5071 840364	MARAT PETROV	{"phone": "+70034483431"}
0005432905051	97DCFD	1251 230533	MARFA PAVLOVA	{"phone": "+70957618069"}
0005432905052	8E1C53	1880 752521	ALEKSANDR BORISOV	{"email": "borisova1973@postgrespro.ru", "phone": "+70879419233"}
0005432905053	34449E	1439 687811	ANASTASIYA FROLOVA	{"phone": "+70560442728"}
0005432905054	FD6F07	6554 703550	VLADIMIR ANDREEV	{"email": "vladimirandreev.1976@postgrespro.ru", "phone": "+70036568092"}
0005432905055	3F1BD0	7542 252230	ALEKSANDR FILIPPOV	{"phone": "+70522485328"}
0005432905056	926443	5135 014275	SERGEY DMITRIEV	{"phone": "+70146609150"}
0005432905057	926443	6483 924428	ELENA SMIRNOVA	{"phone": "+70644957799"}
0005432905058	5F14B0	1888 399097	SOFIYA KUZNECOVA	{"email": "s_kuznecova_1967@postgrespro.ru", "phone": "+70645857277"}
0005432905059	5F14B0	2811 471533	ANTON TARASOV	{"email": "atarasov_07011985@postgrespro.ru", "phone": "+70712799291"}
0005432905060	A84903	2669 485921	AMIR TIMOFEEV	{"phone": "+70982178124"}
0005432905061	9DB736	5097 416648	VENIAMIN EGOROV	{"phone": "+70134160481"}
0005432905062	9DB736	2570 826485	KRISTINA MIKHAYLOVA	{"email": "mikhaylovakristina26111982@postgrespro.ru", "phone": "+70031161640"}
0005432905063	9E3500	6781 200431	OKSANA MIKHAYLOVA	{"email": "o_mikhaylova.05011970@postgrespro.ru", "phone": "+70402110344"}
0005432905064	D7B1C1	5216 697684	PAVEL OSIPOV	{"phone": "+70443287120"}
0005432905065	D7B1C1	3858 018660	SALAVAT FROLOV	{"email": "frolovs-021958@postgrespro.ru", "phone": "+70749918147"}
0005432905066	32BE0C	9506 265744	MARK BORISOV	{"email": "mark.borisov.15051965@postgrespro.ru", "phone": "+70868188135"}
0005432905067	32BE0C	1598 286057	VALENTINA LUKYANOVA	{"email": "lukyanova_valentina_18021964@postgrespro.ru", "phone": "+70051268348"}
0005432905068	1466C2	3884 682604	ALEKSANDRA CHERNOVA	{"email": "chernova-a.1963@postgrespro.ru", "phone": "+70731246005"}
0005432905069	1466C2	5794 092430	PAVEL NAZAROV	{"email": "pnazarov101976@postgrespro.ru", "phone": "+70933418051"}
0005432905070	3182B1	6623 386511	TATYANA BELOVA	{"phone": "+70996798833"}
0005432905071	54AFE2	3508 512413	LARISA MIKHAYLOVA	{"email": "larisa_mikhaylova_1975@postgrespro.ru", "phone": "+70724546827"}
0005432905072	54AFE2	9968 527409	ALEVTINA FROLOVA	{"email": "alevtinafrolova041978@postgrespro.ru", "phone": "+70099425965"}
0005432905073	60C718	9349 936487	DENIS CHERNOV	{"email": "d.chernov-31011971@postgrespro.ru", "phone": "+70589784794"}
0005432905074	49AC8E	4820 963020	SVETLANA BELOVA	{"phone": "+70967860690"}
0005432905075	608F9E	9444 697322	ALEKSANDR KUZMIN	{"phone": "+70758759602"}
0005432905076	BED2FF	9593 538606	LYUBOV DANILOVA	{"email": "danilova-lyubov-1964@postgrespro.ru", "phone": "+70600362884"}
0005432905077	47FA45	3884 481339	VLADIMIR FROLOV	{"email": "frolov_vladimir.12061970@postgrespro.ru", "phone": "+70604462945"}
0005432905078	47FA45	6296 879780	VIKTORIYA DENISOVA	{"phone": "+70860078600"}
0005432905079	840201	2508 499909	YULIYA ANTONOVA	{"email": "antonovayuliya_1978@postgrespro.ru", "phone": "+70860359284"}
0005432905080	840201	2895 478665	NINA EFIMOVA	{"phone": "+70937932190"}
0005432905081	99C830	3080 183533	ANDREY SCHERBAKOV	{"email": "andreyscherbakov25031967@postgrespro.ru", "phone": "+70116573984"}
0005432905082	CA87A0	6825 825358	VLADIMIR NIKOLAEV	{"phone": "+70038245403"}
0005432905083	CA87A0	6402 330616	TATYANA ABRAMOVA	{"email": "tabramova-17081984@postgrespro.ru", "phone": "+70146425242"}
0005432905084	785E02	8499 516475	TAMARA ANISIMOVA	{"phone": "+70768477219"}
0005432905085	785E02	6297 219102	VLADIMIR KAZAKOV	{"email": "v.kazakov.28101968@postgrespro.ru", "phone": "+70192001991"}
0005432905086	E89557	9699 919769	ALEKSANDR KUZMIN	{"email": "a-kuzmin011971@postgrespro.ru", "phone": "+70813523348"}
0005432905087	6C2C00	8135 618427	EVGENIYA SOROKINA	{"email": "sorokinae-041975@postgrespro.ru", "phone": "+70438229207"}
0005432905088	8B0E39	2979 849709	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana051982@postgrespro.ru", "phone": "+70878084146"}
0005432905089	8B0E39	8981 175462	VLADISLAV ALEKSANDROV	{"phone": "+70366082024"}
0005432905090	8B0E39	1815 809939	ARTUR GRIGOREV	{"email": "grigorev_artur.1971@postgrespro.ru", "phone": "+70625073238"}
0005432905091	6961A9	7715 339139	ANNA MAKAROVA	{"email": "makarova-anna-1974@postgrespro.ru", "phone": "+70574764104"}
0005432905092	6961A9	2794 813401	IRINA SOROKINA	{"email": "sorokina-irina1968@postgrespro.ru", "phone": "+70507719791"}
0005432905093	C594AF	6375 771530	ALEKSEY KUZNECOV	{"phone": "+70515450188"}
0005432905094	C594AF	1969 221833	VLADIMIR ANTONOV	{"email": "antonov_vladimir121974@postgrespro.ru", "phone": "+70212091847"}
0005432905095	A0A8D7	5080 634427	OLGA PETROVA	{"phone": "+70777869995"}
0005432905096	A0A8D7	1756 038112	DIANA POPOVA	{"phone": "+70325961730"}
0005432905097	7A885F	2032 031301	VLADIMIR CHERNOV	{"email": "chernov_vladimir-111976@postgrespro.ru", "phone": "+70405763132"}
0005432905098	7A885F	6888 017140	ALEKSANDR ALEKSEEV	{"phone": "+70983907823"}
0005432905099	4D848D	6297 962175	NATALYA KONOVALOVA	{"phone": "+70413750499"}
0005432905100	E1A9EA	1871 967657	YULIYA RYABOVA	{"phone": "+70259109043"}
0005432905101	C70B6F	4732 158986	GALINA FILIPPOVA	{"phone": "+70683267610"}
0005432905102	C70B6F	9217 968627	LEONID PAVLOV	{"phone": "+70602554469"}
0005432905103	C70B6F	5664 057319	PAVEL MELNIKOV	{"email": "p-melnikov10071973@postgrespro.ru", "phone": "+70586399449"}
0005432905104	E78445	2486 526388	TATYANA MIKHAYLOVA	{"email": "tmikhaylova.04071976@postgrespro.ru", "phone": "+70277992404"}
0005432905105	E78445	8504 768915	SVETLANA KOZLOVA	{"phone": "+70832737860"}
0005432905106	E78445	1791 654142	LYUBOV BOGDANOVA	{"email": "lyubov-bogdanova_24071970@postgrespro.ru", "phone": "+70471479094"}
0005432905107	87A562	0822 070860	DMITRIY PETROV	{"email": "d_petrov-28081972@postgrespro.ru", "phone": "+70878396805"}
0005432905108	87A562	5880 413604	LIDIYA MAKSIMOVA	{"phone": "+70237822270"}
0005432905109	73AC44	6080 787274	IRINA GAVRILOVA	{"email": "i_gavrilova-19111977@postgrespro.ru", "phone": "+70813014588"}
0005432905110	01B12C	2579 376937	RUSLAN ISAEV	{"email": "ruslan.isaev121978@postgrespro.ru", "phone": "+70314113984"}
0005432905111	01B12C	9567 188663	VERA SERGEEVA	{"email": "sergeevavera_1984@postgrespro.ru", "phone": "+70581126806"}
0005432905112	9A66BC	6296 141821	OLGA SCHERBAKOVA	{"email": "scherbakova_olga.1976@postgrespro.ru", "phone": "+70421102302"}
0005432905113	9A66BC	3005 894451	VLADIMIR ZHUKOV	{"email": "zhukovvladimir.1972@postgrespro.ru", "phone": "+70997119660"}
0005432905114	976B8B	8621 580494	LEONID NIKOLAEV	{"email": "nikolaev.l1979@postgrespro.ru", "phone": "+70955114713"}
0005432905115	B8862F	3317 031414	VLADIMIR FEDOROV	{"phone": "+70737554197"}
0005432905116	BECE0D	1211 565408	TAISIYA DANILOVA	{"email": "t.danilova-28041969@postgrespro.ru", "phone": "+70861645911"}
0005432905117	C36B83	0349 624799	ALEKSEY ISAEV	{"phone": "+70005948682"}
0005432905118	BDE649	3928 869811	TATYANA VOROBEVA	{"email": "vorobeva-t-1973@postgrespro.ru", "phone": "+70768920665"}
0005432905119	BBA84B	7491 833781	ANTON TIKHONOV	{"email": "tikhonov-a.30031970@postgrespro.ru", "phone": "+70915806881"}
0005432905120	BBA84B	4876 600028	MAKSIM MIKHAYLOV	{"phone": "+70201194022"}
0005432905121	F798A4	5584 847623	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy-041977@postgrespro.ru", "phone": "+70020048463"}
0005432905122	94A385	5407 729742	ALEKSANDR FOMIN	{"phone": "+70137211892"}
0005432905123	94A385	2913 692750	NIKOLAY KUZMIN	{"phone": "+70743756533"}
0005432905124	94A385	8045 612153	NINA TIMOFEEVA	{"phone": "+70012105648"}
0005432905180	63510A	5626 605945	ANTON ORLOV	{"phone": "+70176508544"}
0005432905125	55C0A5	6710 912889	ELENA KUZNECOVA	{"email": "kuznecova.elena_20031981@postgrespro.ru", "phone": "+70370343494"}
0005432905126	55C0A5	8144 254620	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev23081970@postgrespro.ru", "phone": "+70002522194"}
0005432905127	2C5ECA	6552 846114	ELENA MOROZOVA	{"email": "elena-morozova.1968@postgrespro.ru", "phone": "+70085516060"}
0005432905128	A7CF7E	3056 415697	SVETLANA RYABOVA	{"phone": "+70705268748"}
0005432905129	A7CF7E	8920 462067	NINA NAZAROVA	{"phone": "+70413882959"}
0005432905130	0EF49A	2178 250100	PAVEL TARASOV	{"phone": "+70975178806"}
0005432905131	4FED51	2743 133182	ALEVTINA PAVLOVA	{"phone": "+70633735790"}
0005432905132	4FED51	2765 063788	KRISTINA NIKOLAEVA	{"email": "kristinanikolaeva-05041975@postgrespro.ru", "phone": "+70790298623"}
0005432905133	5CE97E	2969 616750	NADEZHDA LUKYANOVA	{"phone": "+70504571828"}
0005432905134	9A55D3	7885 254396	IVAN TARASOV	{"phone": "+70840458982"}
0005432905135	6EAF34	9973 831752	ELENA POTAPOVA	{"email": "potapova-elena.08041963@postgrespro.ru", "phone": "+70877003318"}
0005432905136	6EAF34	3612 724525	VALENTINA POPOVA	{"email": "popova.v15121966@postgrespro.ru", "phone": "+70336248231"}
0005432905137	CB243A	5139 607401	ALEKSANDR SMIRNOV	{"email": "smirnov-a.15081975@postgrespro.ru", "phone": "+70698867599"}
0005432905138	79184A	1132 493943	OKSANA MIRONOVA	{"email": "oksana-mironova14071960@postgrespro.ru", "phone": "+70135796156"}
0005432905139	79184A	8652 492437	ELENA IVANOVA	{"phone": "+70976255232"}
0005432905140	79184A	6335 807619	VERA VASILEVA	{"email": "vasileva-vera_1974@postgrespro.ru", "phone": "+70604667325"}
0005432905141	B61609	2229 123491	ANASTASIYA KUDRYASHOVA	{"phone": "+70823447540"}
0005432905142	B61609	9043 312738	YAROSLAV MIKHAYLOV	{"email": "yaroslav_mikhaylov_10031977@postgrespro.ru", "phone": "+70136718835"}
0005432905143	76CEDF	4481 720852	BORIS SOLOVEV	{"email": "solovev.boris-041967@postgrespro.ru", "phone": "+70584364540"}
0005432905144	76CEDF	4118 859625	INNA ANISIMOVA	{"phone": "+70889878981"}
0005432905145	957722	8977 469879	VARVARA FILIPPOVA	{"email": "filippovav.1968@postgrespro.ru", "phone": "+70707239677"}
0005432905146	CF469F	9625 472967	VIKTORIYA EFIMOVA	{"phone": "+70483080940"}
0005432905147	CF469F	1128 831669	LILIYA TIKHONOVA	{"email": "ltikhonova011967@postgrespro.ru", "phone": "+70105793267"}
0005432905148	3E28DF	0058 757400	TATYANA LUKYANOVA	{"phone": "+70352124370"}
0005432905149	3E28DF	9519 500015	TIMOFEY VOLKOV	{"email": "timofey.volkov.081984@postgrespro.ru", "phone": "+70448692037"}
0005432905150	3E28DF	2259 253011	ANVAR KONOVALOV	{"phone": "+70114578877"}
0005432905151	BDCACD	3905 529068	SERGEY TIKHONOV	{"phone": "+70815894293"}
0005432905152	A5003D	8760 372623	KONSTANTIN ZAKHAROV	{"phone": "+70315860064"}
0005432905153	32A68D	4358 968188	ANDREY FOMIN	{"email": "andrey-fomin_1964@postgrespro.ru", "phone": "+70158196388"}
0005432905154	32A68D	9418 205086	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir.01041969@postgrespro.ru", "phone": "+70362851196"}
0005432905155	32A68D	0583 770856	MARIYA YAKOVLEVA	{"phone": "+70652762481"}
0005432905156	31E71F	5095 373692	VYACHESLAV AFANASEV	{"email": "vyacheslav_afanasev21011965@postgrespro.ru", "phone": "+70436564598"}
0005432905157	508234	9659 125207	MARINA VOROBEVA	{"phone": "+70607373463"}
0005432905158	508234	8883 863749	LYUDMILA SOROKINA	{"email": "sorokina-lyudmila.1983@postgrespro.ru", "phone": "+70633000356"}
0005432905159	E0C0C1	3042 987750	MILANA ARKHIPOVA	{"email": "arkhipova_m-10051966@postgrespro.ru", "phone": "+70937998879"}
0005432905160	E0C0C1	7536 386086	IVAN BELOV	{"email": "belov-i_1976@postgrespro.ru", "phone": "+70490704670"}
0005432905161	E0C0C1	6710 495842	ELENA VASILEVA	{"phone": "+70198280048"}
0005432905162	E0C0C1	7361 031522	SVETLANA ZAKHAROVA	{"email": "szakharova-121968@postgrespro.ru", "phone": "+70129629384"}
0005432905163	C43E5D	8585 309916	ALEKSEY MARTYNOV	{"phone": "+70183282579"}
0005432905164	C43E5D	1819 277260	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya011970@postgrespro.ru", "phone": "+70862139483"}
0005432905165	CE0FDC	8334 339661	SERGEY ZHURAVLEV	{"phone": "+70317283440"}
0005432905166	CE0FDC	3049 542378	ALEKSEY DENISOV	{"email": "a-denisov_24071977@postgrespro.ru", "phone": "+70327207480"}
0005432905167	CE0FDC	2747 438732	DMITRIY DMITRIEV	{"email": "dmitriy.dmitriev011968@postgrespro.ru", "phone": "+70315189483"}
0005432905168	5F2391	1749 483657	DENIS FROLOV	{"phone": "+70585616243"}
0005432905169	5941F9	7172 950530	TATYANA BELYAEVA	{"phone": "+70555264734"}
0005432905170	5941F9	1433 982743	ANGELINA KARPOVA	{"email": "karpova.angelina_27041977@postgrespro.ru", "phone": "+70542527840"}
0005432905171	8C099F	6125 896295	VLADIMIR GERASIMOV	{"phone": "+70763648543"}
0005432905172	BD1CDC	6299 949469	IVAN OSIPOV	{"email": "ivan-osipov_01091974@postgrespro.ru", "phone": "+70676548295"}
0005432905173	3993A9	1436 962416	LYUDMILA GORBUNOVA	{"email": "gorbunova_l_1978@postgrespro.ru", "phone": "+70341102700"}
0005432905174	3993A9	7361 111847	LYUBOV EFIMOVA	{"email": "lyubovefimova041974@postgrespro.ru", "phone": "+70480314359"}
0005432905175	227E1C	7140 819586	OKSANA SOKOLOVA	{"phone": "+70675856074"}
0005432905176	482435	7920 974746	NATALYA KOVALEVA	{"email": "n_kovaleva_14031974@postgrespro.ru", "phone": "+70893046894"}
0005432905177	6B4431	5820 764197	PETR ZAYCEV	{"phone": "+70511154134"}
0005432905178	6B4431	4279 767320	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov.041961@postgrespro.ru", "phone": "+70494647662"}
0005432905179	AC63F9	9072 203367	ELENA EGOROVA	{"email": "elena-egorova.16061982@postgrespro.ru", "phone": "+70665841255"}
0005432905181	FCE03C	7356 819066	LYUBOV YAKOVLEVA	{"phone": "+70725717565"}
0005432905182	FCE03C	4010 657969	NINA ROMANOVA	{"email": "romanova_n1976@postgrespro.ru", "phone": "+70809052097"}
0005432905183	FCE03C	8947 861699	ANDREY GERASIMOV	{"email": "gerasimov-andrey22101973@postgrespro.ru", "phone": "+70050359404"}
0005432905184	90BC1F	5285 200354	EVGENIYA KUZNECOVA	{"phone": "+70109630363"}
0005432905185	DB19E5	0106 996987	ANNA VLASOVA	{"phone": "+70005234757"}
0005432905186	916705	2488 081083	ANDREY ZAKHAROV	{"phone": "+70895555035"}
0005432905187	916705	0801 834975	LYUDMILA SOROKINA	{"phone": "+70309329959"}
0005432905188	BEDC68	0523 624442	NADEZHDA KUDRYASHOVA	{"email": "kudryashova-nadezhda.011975@postgrespro.ru", "phone": "+70565616256"}
0005432905189	1974D2	4668 154572	DMITRIY POPOV	{"phone": "+70566434054"}
0005432905190	1974D2	3979 584097	DMITRIY KULIKOV	{"phone": "+70148502982"}
0005432905191	DAEF70	3159 384567	ANDREY SEMENOV	{"phone": "+70830746840"}
0005432905192	1E6169	7491 340167	VASILIY RODIONOV	{"email": "rodionov_v.091976@postgrespro.ru", "phone": "+70878371461"}
0005432905193	1E6169	0612 124054	ANNA OSIPOVA	{"phone": "+70353697460"}
0005432905194	74210B	4679 184698	EVGENIY SAVELEV	{"email": "savelev_evgeniy-30011965@postgrespro.ru", "phone": "+70074847063"}
0005432905195	1A05D1	0097 937442	NATALYA MALYSHEVA	{"email": "malysheva-n.03081989@postgrespro.ru", "phone": "+70730080168"}
0005432905196	53DE04	6946 516236	NIKOLAY KISELEV	{"email": "kiselev.n_1973@postgrespro.ru", "phone": "+70047516685"}
0005432905197	53FE55	2814 512198	ALEKSEY TIKHONOV	{"phone": "+70997186732"}
0005432905198	BC7B62	1592 643054	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov.061960@postgrespro.ru", "phone": "+70438394008"}
0005432905199	B76DD5	6936 174648	MARINA IVANOVA	{"phone": "+70833175505"}
0005432905200	94B377	0129 710439	DMITRIY FEDOTOV	{"email": "dfedotov031974@postgrespro.ru", "phone": "+70223669116"}
0005432905201	94B377	7126 564106	VLADISLAV MIRONOV	{"email": "mironov_vladislav-30051978@postgrespro.ru", "phone": "+70343125911"}
0005432905202	0922ED	7866 066000	YANA KAZAKOVA	{"email": "kazakova_yana_05111968@postgrespro.ru", "phone": "+70053219934"}
0005432905203	0922ED	2942 884249	IGOR IVANOV	{"email": "igor.ivanov16061980@postgrespro.ru", "phone": "+70176561840"}
0005432905204	F07C46	3289 623732	RAISA ALEKSANDROVA	{"email": "aleksandrova.r-081974@postgrespro.ru", "phone": "+70599823777"}
0005432905205	555E53	7639 395847	ANATOLIY PETROV	{"phone": "+70176850259"}
0005432905206	C5A0EF	4050 960807	IGOR SAVELEV	{"email": "i.savelev1963@postgrespro.ru", "phone": "+70690942504"}
0005432905207	055B49	8577 429734	MIKHAIL MEDVEDEV	{"email": "medvedev.m_16121965@postgrespro.ru", "phone": "+70918491106"}
0005432905208	055B49	2593 612238	ALEVTINA KOLESNIKOVA	{"phone": "+70207590528"}
0005432905209	055B49	5211 149514	OLGA ISAEVA	{"phone": "+70446631272"}
0005432905210	FE4243	0949 117030	EVGENIY SOKOLOV	{"email": "evgeniy_sokolov021973@postgrespro.ru", "phone": "+70192661713"}
0005432905211	FE4243	2076 482713	IRAIDA POPOVA	{"email": "popova.iraida.1954@postgrespro.ru", "phone": "+70215883022"}
0005432905212	A3AE7B	4716 724419	KLAVDIYA MOISEEVA	{"email": "moiseevak1969@postgrespro.ru", "phone": "+70623207242"}
0005432905213	918CC3	2604 378790	MARINA STEPANOVA	{"phone": "+70175355078"}
0005432905214	C7AFDF	7981 369323	EVGENIY ISAEV	{"email": "evgeniyisaev-081961@postgrespro.ru", "phone": "+70047515625"}
0005432905215	C7AFDF	6864 603257	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov_111985@postgrespro.ru", "phone": "+70066213654"}
0005432905216	B646FE	6338 318860	NATALYA ZHUKOVA	{"email": "natalya.zhukova_021966@postgrespro.ru", "phone": "+70095658604"}
0005432905217	099CEA	7640 549686	ANTONINA GRISHINA	{"phone": "+70669047722"}
0005432905218	099CEA	6139 040734	ALEKSANDR DMITRIEV	{"phone": "+70695547657"}
0005432905219	C3E76E	2365 408315	VIKTOR BELOV	{"phone": "+70979533519"}
0005432905220	5148AC	2345 321426	YULIYA ABRAMOVA	{"email": "abramova_yuliya.01091974@postgrespro.ru", "phone": "+70550481969"}
0005432905221	5D0F79	9769 428254	SVETLANA ZAKHAROVA	{"phone": "+70535902039"}
0005432905222	BA4053	9247 755892	IRINA NIKOLAEVA	{"phone": "+70350024821"}
0005432905223	B5F99E	3416 728733	EKATERINA FEDOROVA	{"phone": "+70026936527"}
0005432905224	3B5B07	1901 231042	MIKHAIL SEMENOV	{"phone": "+70124141430"}
0005432905225	3B5B07	4022 900297	ANATOLIY STEPANOV	{"phone": "+70513332852"}
0005432905226	F9D50F	0888 567441	LYUBOV KOROLEVA	{"phone": "+70776917942"}
0005432905227	63013F	0154 870235	MIKHAIL NIKITIN	{"email": "nikitinmikhail_1973@postgrespro.ru", "phone": "+70685821462"}
0005432905228	63013F	1258 872031	ALENA KOZLOVA	{"email": "a.kozlova_01111961@postgrespro.ru", "phone": "+70798642523"}
0005432905229	170A59	5262 990902	ANNA KUZNECOVA	{"email": "anna.kuznecova-021968@postgrespro.ru", "phone": "+70972006304"}
0005432905230	170A59	1991 044222	GALINA ABRAMOVA	{"phone": "+70914125343"}
0005432905231	170A59	5955 511472	IGOR RODIONOV	{"phone": "+70139220937"}
0005432905232	AF016B	3305 250439	MARAT CHERNOV	{"email": "chernov-m-1979@postgrespro.ru", "phone": "+70714052192"}
0005432905233	AF016B	1765 902446	ANDREY STEPANOV	{"phone": "+70979783177"}
0005432905234	2FB055	0381 306042	ELENA SIDOROVA	{"phone": "+70664169425"}
0005432905235	C5816B	9313 763629	SERGEY ABRAMOV	{"email": "abramovsergey_05101966@postgrespro.ru", "phone": "+70734064797"}
0005432905236	C5816B	6741 368755	ALEKSANDR EGOROV	{"email": "aleksandr-egorov17091969@postgrespro.ru", "phone": "+70811905900"}
0005432905237	CED926	5909 087602	ELIZAVETA VOROBEVA	{"email": "elizaveta-vorobeva1975@postgrespro.ru", "phone": "+70952661011"}
0005432905238	A6F881	3305 468661	MARIYA KUZNECOVA	{"email": "mkuznecova-12111966@postgrespro.ru", "phone": "+70612830108"}
0005432905239	A6F881	8717 230339	MARIYA SOKOLOVA	{"email": "sokolova.mariya111974@postgrespro.ru", "phone": "+70635627446"}
0005432905240	A6F881	8309 524332	LIDIYA DENISOVA	{"phone": "+70199263833"}
0005432905241	34A744	3518 088586	ALENA POPOVA	{"email": "popova_alena_17121977@postgrespro.ru", "phone": "+70835628566"}
0005432905242	7B416E	0099 273363	VLADIMIR MOROZOV	{"phone": "+70729996159"}
0005432905243	814EF3	1852 025142	TATYANA KOROLEVA	{"phone": "+70469016210"}
0005432905244	F684A3	3029 699658	FATIMA POPOVA	{"email": "popova.f-101973@postgrespro.ru", "phone": "+70049600663"}
0005432905245	F684A3	0921 898473	MARIYA ANDREEVA	{"phone": "+70583181573"}
0005432905246	F476BF	5783 663765	GALINA VOROBEVA	{"email": "vorobeva-g_24101977@postgrespro.ru", "phone": "+70459056056"}
0005432905247	F476BF	5583 586268	ALEKSANDR ANDREEV	{"phone": "+70103215146"}
0005432905248	6A5D38	4346 737049	ANASTASIYA OVCHINNIKOVA	{"phone": "+70538577163"}
0005432905249	0722E8	5576 169932	ANASTASIYA PAVLOVA	{"email": "pavlovaanastasiya101981@postgrespro.ru", "phone": "+70308999274"}
0005432905250	BCA569	6457 788086	SERGEY GRIGOREV	{"phone": "+70710751927"}
0005432905251	2FB474	4423 393409	TATYANA LOGINOVA	{"email": "loginovatatyana_23051980@postgrespro.ru", "phone": "+70533880975"}
0005432905252	2FB474	9423 254533	VADIM FEDOTOV	{"email": "vfedotov_26071972@postgrespro.ru", "phone": "+70710426150"}
0005432905253	C1116A	7072 465273	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr_30121978@postgrespro.ru", "phone": "+70024556800"}
0005432905254	C1116A	9680 492431	YURIY KUZNECOV	{"email": "y-kuznecov.071970@postgrespro.ru", "phone": "+70551917190"}
0005432905255	2A4792	7361 844787	PETR GUSEV	{"phone": "+70131741858"}
0005432905256	2A4792	2970 823944	YULIYA ANTONOVA	{"phone": "+70300978346"}
0005432905257	1D4693	5358 626621	ILYA MAKAROV	{"email": "ilyamakarov.13081975@postgrespro.ru", "phone": "+70210363932"}
0005432905258	1D4693	1870 572362	VLADIMIR EGOROV	{"email": "egorov.v_051972@postgrespro.ru", "phone": "+70072102493"}
0005432905259	40A890	4623 154083	MARIYA ZAKHAROVA	{"phone": "+70311111514"}
0005432905260	AB20AA	0505 798166	NIKITA ZAKHAROV	{"phone": "+70963340359"}
0005432905261	AB20AA	1827 403276	NATALYA AFANASEVA	{"email": "n.afanaseva_021974@postgrespro.ru", "phone": "+70311533981"}
0005432905262	F22E4F	5756 346794	SVETLANA KOROLEVA	{"phone": "+70516734716"}
0005432905263	F22E4F	2887 752484	RAZIYA RODIONOVA	{"phone": "+70313145244"}
0005432905264	8051A2	1528 586292	NATALYA DMITRIEVA	{"phone": "+70146022625"}
0005432905265	DE6496	4964 290594	LIDIYA EGOROVA	{"phone": "+70718292290"}
0005432905266	9B138A	5218 111521	ANDREY GERASIMOV	{"email": "a_gerasimov.11031980@postgrespro.ru", "phone": "+70828910824"}
0005432905267	969088	8112 716314	MARINA NIKITINA	{"email": "marina_nikitina081979@postgrespro.ru", "phone": "+70364850021"}
0005432905268	969088	7415 651296	VALERIY VASILEV	{"phone": "+70122029197"}
0005432905269	90B730	3373 680801	SOFYA RODIONOVA	{"phone": "+70552669449"}
0005432905270	A6131F	1951 511566	OLGA ANDREEVA	{"phone": "+70884592012"}
0005432905271	E33E13	9013 451994	SERGEY MOROZOV	{"email": "morozovsergey.20051975@postgrespro.ru", "phone": "+70719685796"}
0005432905272	E33E13	5417 870157	ANNA MIRONOVA	{"email": "a-mironova-27111964@postgrespro.ru", "phone": "+70795245008"}
0005432905273	D6C4C0	2255 180718	DENIS KONOVALOV	{"phone": "+70279688443"}
0005432905274	2703D3	4644 384247	NATALYA SERGEEVA	{"phone": "+70189449091"}
0005432905275	2703D3	7962 138364	VIKTOR MOISEEV	{"email": "moiseevv01101970@postgrespro.ru", "phone": "+70328058735"}
0005432905276	63D306	4962 442994	NIKITA RODIONOV	{"email": "rodionov.n.28081973@postgrespro.ru", "phone": "+70180525109"}
0005432905277	74F555	8763 031545	VIKTORIYA MALYSHEVA	{"phone": "+70235345969"}
0005432905278	FFFF2C	6489 769349	ELENA FROLOVA	{"email": "elena-frolova1969@postgrespro.ru", "phone": "+70008892054"}
0005432905279	1E34AC	5744 232889	VALENTINA TROFIMOVA	{"phone": "+70049662753"}
0005432905280	EBC1AA	5900 588573	VIKTOR SOROKIN	{"email": "sorokin-v_041978@postgrespro.ru", "phone": "+70377044782"}
0005432905281	EBC1AA	3550 742808	VALENTINA KUZNECOVA	{"email": "kuznecova.v_101967@postgrespro.ru", "phone": "+70717192139"}
0005432905282	7F1E23	8046 576545	VERA ANISIMOVA	{"email": "anisimovav.26021961@postgrespro.ru", "phone": "+70986827769"}
0005432905283	6486B1	9814 901165	EVGENIY KONOVALOV	{"email": "e-konovalov1967@postgrespro.ru", "phone": "+70542604823"}
0005432905284	6486B1	8573 725888	SERGEY GUSEV	{"email": "sgusev_1969@postgrespro.ru", "phone": "+70456777052"}
0005432905285	58638C	6501 628635	NATALYA SMIRNOVA	{"phone": "+70627719557"}
0005432905286	B18D12	7508 800271	LYUDMILA VASILEVA	{"email": "vasileva-l.051981@postgrespro.ru", "phone": "+70513231049"}
0005432905287	B18D12	8544 983061	ELENA ARKHIPOVA	{"email": "arkhipova_e121976@postgrespro.ru", "phone": "+70232785801"}
0005432905288	3DFA0E	7987 277306	VLADISLAV CHERNOV	{"email": "vladislav.chernov_1970@postgrespro.ru", "phone": "+70526948050"}
0005432905289	8C2E36	3667 682964	ANDREY BARANOV	{"phone": "+70828294102"}
0005432905290	0935E4	0744 638244	NATALYA NAUMOVA	{"phone": "+70987534140"}
0005432905291	C55999	1478 271323	MAKSIM DENISOV	{"phone": "+70119252300"}
0005432905292	C2A9BE	6527 072816	ALEKSANDRA IVANOVA	{"phone": "+70266345649"}
0005432905293	17B5FB	7366 311034	YURIY FOMIN	{"phone": "+70143906519"}
0005432905294	17B5FB	1955 418986	ANATOLIY MARTYNOV	{"email": "anatoliy.martynov.22021985@postgrespro.ru", "phone": "+70272397271"}
0005432905295	E89027	1735 302543	ANNA KUZMINA	{"phone": "+70110304558"}
0005432906491	D001C6	0635 186825	ANDREY STEPANOV	{"phone": "+70181204940"}
0005432906607	BEF6EE	3790 821930	RAISA ABRAMOVA	{"phone": "+70483534875"}
0005432906492	D001C6	8007 388864	ANTONINA FILIPPOVA	{"email": "filippova-antonina.051970@postgrespro.ru", "phone": "+70505457814"}
0005432906493	1A23C2	8981 436262	TAMARA KUZNECOVA	{"email": "tkuznecova_011978@postgrespro.ru", "phone": "+70699564241"}
0005432906494	1A23C2	7763 327558	SVETLANA ZHURAVLEVA	{"phone": "+70522234843"}
0005432906495	71532E	1144 034380	OLGA SOROKINA	{"email": "o-sorokina1973@postgrespro.ru", "phone": "+70778416355"}
0005432906496	F0833D	6572 349831	MARIYA KUZNECOVA	{"phone": "+70116562169"}
0005432906497	0C62BE	1366 314755	VIKTOR KULIKOV	{"phone": "+70728994114"}
0005432906498	709664	7640 944718	NADEZHDA NESTEROVA	{"email": "nesterova_nadezhda-25121983@postgrespro.ru", "phone": "+70446007331"}
0005432906499	709664	7931 234726	RAMIL VASILEV	{"email": "vasilev-r.061966@postgrespro.ru", "phone": "+70520708154"}
0005432906500	3A5C7A	8880 260128	STANISLAV VOLKOV	{"phone": "+70620200693"}
0005432906501	FD878A	4467 878255	ALFIYA KULIKOVA	{"email": "kulikovaalfiya-071969@postgrespro.ru", "phone": "+70020046987"}
0005432906502	D607EE	8832 006464	ANDREY EGOROV	{"phone": "+70282380330"}
0005432906503	D607EE	0456 472856	MAKSIM NIKITIN	{"email": "maksim_nikitin091970@postgrespro.ru", "phone": "+70593534055"}
0005432906504	9EB7BF	2453 651976	DMITRIY IVANOV	{"email": "ivanovdmitriy-22031966@postgrespro.ru", "phone": "+70414253445"}
0005432906505	5F2608	2368 217695	EKATERINA KOROLEVA	{"phone": "+70593503297"}
0005432906506	5F2608	2355 361752	MARIYA NIKOLAEVA	{"email": "mnikolaeva1985@postgrespro.ru", "phone": "+70110025595"}
0005432906507	EB95CF	6490 149532	IRINA ANDREEVA	{"phone": "+70001194549"}
0005432906508	182ED9	0230 420571	ROMAN OSIPOV	{"phone": "+70247296483"}
0005432906509	120006	0334 373256	ALEKSANDR POPOV	{"phone": "+70729903048"}
0005432906510	BBC4A2	6239 994361	DMITRIY FEDOROV	{"email": "d.fedorov051967@postgrespro.ru", "phone": "+70853847742"}
0005432906511	9B1B58	7142 305102	VLADIMIR MELNIKOV	{"phone": "+70345791334"}
0005432906512	F4810D	7824 586796	NIKOLAY OSIPOV	{"email": "nikolay-osipov_1976@postgrespro.ru", "phone": "+70693083438"}
0005432906513	D419C3	0987 369322	TATYANA YUDINA	{"email": "yudina.tatyana_1982@postgrespro.ru", "phone": "+70507564665"}
0005432906514	D419C3	8828 233974	DARYA CHERNOVA	{"email": "chernova_darya-17021973@postgrespro.ru", "phone": "+70459570633"}
0005432906515	D419C3	4643 059267	VLADIMIR MOROZOV	{"phone": "+70963110027"}
0005432906516	FB759C	1074 401627	IVAN VASILEV	{"email": "i_vasilev.1968@postgrespro.ru", "phone": "+70824634122"}
0005432906517	6F6405	3317 126830	ELENA KISELEVA	{"email": "kiseleva.elena-1966@postgrespro.ru", "phone": "+70816233977"}
0005432906518	A1DB2D	1637 994799	DANIIL SEMENOV	{"phone": "+70072097125"}
0005432906519	AC2300	3909 490982	EVGENIY KUZNECOV	{"phone": "+70477251499"}
0005432906520	4F096E	2407 456489	ALLA KRASNOVA	{"email": "allakrasnova.091973@postgrespro.ru", "phone": "+70354849513"}
0005432906521	1C2177	2776 178747	LYUBOV KUDRYASHOVA	{"email": "l.kudryashova_1967@postgrespro.ru", "phone": "+70298145806"}
0005432906522	DC7C38	9421 127257	TATYANA FILIPPOVA	{"email": "t_filippova-051981@postgrespro.ru", "phone": "+70883304960"}
0005432906523	714ADC	2719 180247	OLEG BELOV	{"email": "obelov_101979@postgrespro.ru", "phone": "+70906270951"}
0005432906524	44BC83	7183 754024	ELVIRA VOROBEVA	{"phone": "+70819461602"}
0005432906525	44BC83	1811 041414	RAUF BARANOV	{"email": "baranov.r.1980@postgrespro.ru", "phone": "+70273113573"}
0005432906526	C2BAD4	6350 860646	EVGENIY AFANASEV	{"email": "afanasev.evgeniy_091974@postgrespro.ru", "phone": "+70501430154"}
0005432906527	C83538	1800 202602	SVETLANA LUKYANOVA	{"email": "lukyanova_svetlana061972@postgrespro.ru", "phone": "+70568995680"}
0005432906528	CC1536	1294 429157	VIKTORIYA ZHUKOVA	{"email": "zhukovaviktoriya031974@postgrespro.ru", "phone": "+70228406309"}
0005432906529	EF3050	4748 984750	BORIS ROMANOV	{"phone": "+70806606455"}
0005432906530	0543FA	6469 388714	ELENA MAKSIMOVA	{"phone": "+70119659929"}
0005432906531	090A4F	5487 999952	MAKSIM KULIKOV	{"email": "m-kulikov_30031980@postgrespro.ru", "phone": "+70199559174"}
0005432906532	E06480	9302 921328	NADEZHDA DMITRIEVA	{"phone": "+70567669094"}
0005432906533	8E3081	9481 429497	RASHIT YAKOVLEV	{"email": "r_yakovlev_06041976@postgrespro.ru", "phone": "+70805061008"}
0005432906534	9837A5	6592 221417	ANNA BARANOVA	{"email": "anna_baranova1972@postgrespro.ru", "phone": "+70760966257"}
0005432906535	E1E266	9543 126293	ANDREY NAZAROV	{"phone": "+70173680173"}
0005432906536	9884FD	4342 350842	GALINA LEBEDEVA	{"phone": "+70052452053"}
0005432906537	159216	1238 693501	VYACHESLAV FILIPPOV	{"email": "filippov.v-06051971@postgrespro.ru", "phone": "+70394248001"}
0005432906538	D9E978	2782 790431	IGOR PETROV	{"email": "petrov.i22101982@postgrespro.ru", "phone": "+70361269504"}
0005432906539	D9E978	2833 775754	GALINA PAVLOVA	{"email": "g.pavlova_121976@postgrespro.ru", "phone": "+70650387086"}
0005432906540	D9E978	4823 105012	KIRILL KAZAKOV	{"email": "kirill_kazakov-1966@postgrespro.ru", "phone": "+70824986901"}
0005432906541	2233A4	6802 222553	IRINA MIKHAYLOVA	{"email": "i_mikhaylova03121966@postgrespro.ru", "phone": "+70932978709"}
0005432906542	FDFDC6	9850 545849	SERGEY CHERNOV	{"email": "chernov.sergey011978@postgrespro.ru", "phone": "+70066360582"}
0005432906543	FDFDC6	6855 333897	TATYANA VOROBEVA	{"email": "tatyana_vorobeva1969@postgrespro.ru", "phone": "+70658745756"}
0005432906544	C218DA	7509 352217	YURIY BONDARENKO	{"email": "bondarenko.y23071966@postgrespro.ru", "phone": "+70365255134"}
0005432906545	550212	4927 850872	SERGEY FEDOROV	{"email": "s.fedorov.101978@postgrespro.ru", "phone": "+70165276519"}
0005432906546	561075	4174 220975	EMMA MAKAROVA	{"email": "emma_makarova-041983@postgrespro.ru", "phone": "+70473851357"}
0005432906547	561075	6038 334489	KSENIYA OVCHINNIKOVA	{"email": "kseniya_ovchinnikova01081962@postgrespro.ru", "phone": "+70843425306"}
0005432906548	561075	6136 339461	VIKTORIYA KARPOVA	{"email": "v.karpova.101976@postgrespro.ru", "phone": "+70926782495"}
0005432906549	0FBBA1	6341 050397	YULIYA VLASOVA	{"email": "y_vlasova.021973@postgrespro.ru", "phone": "+70442185237"}
0005432906550	0FBBA1	3705 641835	VALENTIN KUZMIN	{"email": "v_kuzmin-1966@postgrespro.ru", "phone": "+70020296632"}
0005432906551	8D5BA0	6303 747949	ALEKSEY ANTONOV	{"email": "antonov.a-20011968@postgrespro.ru", "phone": "+70111827318"}
0005432906552	B7D4B1	8755 753631	KIRILL VASILEV	{"phone": "+70381657386"}
0005432906553	591674	9405 330180	MIKHAIL POPOV	{"email": "m.popov29111975@postgrespro.ru", "phone": "+70508078331"}
0005432906554	591674	5652 664791	ALEKSEY ZAKHAROV	{"phone": "+70970466827"}
0005432906555	5C7448	8249 958010	TAMARA SEMENOVA	{"email": "tamara.semenova.01081970@postgrespro.ru", "phone": "+70155314704"}
0005432906556	5C7448	7206 999153	NADEZHDA KOMAROVA	{"email": "nkomarova15071967@postgrespro.ru", "phone": "+70171995292"}
0005432906557	B820EF	4172 767312	SVETLANA FILIPPOVA	{"email": "filippovas06091969@postgrespro.ru", "phone": "+70795126202"}
0005432906558	B820EF	5514 658859	ALEKSANDR KAZAKOV	{"phone": "+70931154232"}
0005432906559	C216CD	6794 916703	ANDREY DAVYDOV	{"email": "davydov-a.081980@postgrespro.ru", "phone": "+70654496147"}
0005432906560	E0D33E	6870 390433	ELENA MOROZOVA	{"email": "morozova_e111975@postgrespro.ru", "phone": "+70038268453"}
0005432906561	E0D33E	1671 817204	LARISA SCHERBAKOVA	{"phone": "+70679073868"}
0005432906562	3EEE22	2823 910675	GULNARA VOROBEVA	{"email": "g-vorobeva_111970@postgrespro.ru", "phone": "+70161597352"}
0005432906563	14C252	3762 163721	RAISA NAUMOVA	{"phone": "+70914277077"}
0005432906564	FA9040	5637 751996	OLEG KISELEV	{"phone": "+70399314943"}
0005432906565	AA7A08	4497 509664	NADEZHDA POPOVA	{"email": "nadezhda.popova.1965@postgrespro.ru", "phone": "+70218274236"}
0005432906566	AA7A08	4992 578894	LYUDMILA ZOTOVA	{"email": "zotova_lyudmila-1966@postgrespro.ru", "phone": "+70647610185"}
0005432906567	5CF4A4	2541 383103	OLGA GORBUNOVA	{"phone": "+70930470407"}
0005432906568	C46E9F	2877 566583	NINA ZOTOVA	{"phone": "+70246785022"}
0005432906569	C46E9F	3442 587242	ALEKSANDR EGOROV	{"phone": "+70311455078"}
0005432906570	C46E9F	3584 524868	VLADIMIR IVANOV	{"email": "ivanovvladimir_26101961@postgrespro.ru", "phone": "+70969959150"}
0005432906571	D3F92C	0710 561776	VLADIMIR MATVEEV	{"email": "matveevv26051976@postgrespro.ru", "phone": "+70767532204"}
0005432906572	CE3FA7	1570 979598	ALEKSANDR FROLOV	{"email": "a-frolov1973@postgrespro.ru", "phone": "+70583098304"}
0005432906573	377C0E	7705 945686	ALENA MOISEEVA	{"email": "moiseeva-a14061967@postgrespro.ru", "phone": "+70872222078"}
0005432906574	8B92CD	8476 799257	ANASTASIYA BELOVA	{"email": "belova_a.13111974@postgrespro.ru", "phone": "+70649917956"}
0005432906575	A15A28	0866 999863	TAMARA VASILEVA	{"email": "tamara-vasileva.09041965@postgrespro.ru", "phone": "+70221617416"}
0005432906576	783FE5	7130 258978	YAROSLAV VOLKOV	{"email": "volkov_yaroslav1972@postgrespro.ru", "phone": "+70417085707"}
0005432906577	43AA91	0987 208667	NATALYA KUZNECOVA	{"email": "kuznecovan_1978@postgrespro.ru", "phone": "+70120344035"}
0005432906578	24FC77	5413 255787	ALEKSANDRA MEDVEDEVA	{"email": "a.medvedeva1980@postgrespro.ru", "phone": "+70749791224"}
0005432906579	4A229A	4790 117632	VALENTINA ZHUKOVA	{"email": "zhukovav-27041970@postgrespro.ru", "phone": "+70088371528"}
0005432906580	599B69	8673 435504	VITALIY SIDOROV	{"email": "v.sidorov11101974@postgrespro.ru", "phone": "+70978970635"}
0005432906581	7FB43B	4279 312609	ALEKSANDR MELNIKOV	{"phone": "+70867576998"}
0005432906582	DF7274	7887 780832	MARINA SIDOROVA	{"email": "sidorova_marina-121985@postgrespro.ru", "phone": "+70260534005"}
0005432906583	5C9F20	6138 062989	EKATERINA NIKITINA	{"email": "e.nikitina.23011971@postgrespro.ru", "phone": "+70591458107"}
0005432906584	2104A6	6581 925023	OKSANA IVANOVA	{"phone": "+70272677682"}
0005432906585	2104A6	1342 434287	ALEKSANDR STEPANOV	{"phone": "+70741444775"}
0005432906586	C60633	3748 145129	VYACHESLAV ANTONOV	{"phone": "+70296224315"}
0005432906587	C60633	8361 064996	MARGARITA CHERNOVA	{"phone": "+70403836120"}
0005432906588	0FFFDF	5753 418715	MIKHAIL YAKOVLEV	{"email": "mikhailyakovlev.07081978@postgrespro.ru", "phone": "+70281957533"}
0005432906589	85E6D9	8857 301474	YURIY NOVIKOV	{"email": "novikovyuriy101962@postgrespro.ru", "phone": "+70860835494"}
0005432906590	8C5E4B	5008 236203	ANNA GERASIMOVA	{"email": "gerasimova_a25061969@postgrespro.ru", "phone": "+70668070943"}
0005432906591	724C04	4632 520238	ANNA KONOVALOVA	{"email": "anna-konovalova.071980@postgrespro.ru", "phone": "+70634015195"}
0005432906592	7E0E8A	4398 929710	ANASTASIYA FEDOROVA	{"phone": "+70420754075"}
0005432906593	7E0E8A	7765 609621	ANDREY MAKAROV	{"email": "makarov-andrey_22041961@postgrespro.ru", "phone": "+70535085886"}
0005432906594	D07D2F	1581 243340	TIKHON NIKOLAEV	{"email": "t-nikolaev_121973@postgrespro.ru", "phone": "+70611271544"}
0005432906595	7F6D60	5482 490749	IVAN KUZNECOV	{"email": "i.kuznecov.28101967@postgrespro.ru", "phone": "+70441925321"}
0005432906596	601811	4259 543635	VLADIMIR MAKSIMOV	{"email": "vladimir-maksimov_1972@postgrespro.ru", "phone": "+70383523465"}
0005432906597	FDFAF5	6225 216929	ANDREY YAKOVLEV	{"phone": "+70660143614"}
0005432906598	D7DE1E	8613 165424	TATYANA MELNIKOVA	{"email": "t_melnikova1974@postgrespro.ru", "phone": "+70521807180"}
0005432906599	3F8538	3437 479615	RAISA VOLKOVA	{"phone": "+70049241759"}
0005432906600	59407F	0128 385011	SERGEY KARPOV	{"phone": "+70813036993"}
0005432906601	B8FC6D	9924 638094	RUSLAN OSIPOV	{"phone": "+70543908805"}
0005432906602	63F65B	6280 531479	MARIYA BORISOVA	{"email": "borisovamariya-1968@postgrespro.ru", "phone": "+70186456471"}
0005432906603	98A24F	4812 876288	LIDIYA ZHURAVLEVA	{"phone": "+70885073111"}
0005432906604	D667E8	5677 686363	ELENA MASLOVA	{"email": "e.maslova-121976@postgrespro.ru", "phone": "+70274404675"}
0005432906605	F00357	6492 236182	ALFIYA ABRAMOVA	{"email": "alfiyaabramova-071974@postgrespro.ru", "phone": "+70001044398"}
0005432906606	BEF6EE	1815 630346	ELENA PETROVA	{"phone": "+70759620536"}
0005432906608	B80E79	4077 913405	YURIY FROLOV	{"phone": "+70303360062"}
0005432906609	B80E79	2861 053851	VASILIY ILIN	{"phone": "+70870281177"}
0005432909189	D05EFE	3033 453333	VALENTINA POLYAKOVA	{"email": "polyakova.v.06051971@postgrespro.ru", "phone": "+70498378851"}
0005432909190	325C3E	4339 185142	VALENTIN KUZNECOV	{"phone": "+70746538331"}
0005432909191	325C3E	4471 197456	RAMAZAN OSIPOV	{"email": "osipov.r021985@postgrespro.ru", "phone": "+70098640746"}
0005432909192	94383E	5237 641304	VLADIMIR ANDREEV	{"phone": "+70039517963"}
0005432909193	6C7FF9	9099 683011	SERGEY SERGEEV	{"email": "ssergeev1967@postgrespro.ru", "phone": "+70024354775"}
0005432909194	BDCAD7	0237 806065	VALERIY GERASIMOV	{"phone": "+70812746218"}
0005432909195	5F105F	8211 053178	SERGEY EGOROV	{"phone": "+70614366202"}
0005432909196	D52B45	7170 759298	PAVEL EGOROV	{"email": "egorov.pavel031982@postgrespro.ru", "phone": "+70422620365"}
0005432909197	53E010	1615 441518	VLADIMIR FILIPPOV	{"email": "v_filippov_1974@postgrespro.ru", "phone": "+70381803683"}
0005432909198	409A42	8811 903383	YULIYA LUKYANOVA	{"phone": "+70533379194"}
0005432909199	F71E93	3380 872716	NATALYA SEMENOVA	{"phone": "+70106919982"}
0005432909200	B245F7	6374 333991	SERGEY MOROZOV	{"email": "s-morozov29111966@postgrespro.ru", "phone": "+70145056676"}
0005432909201	888665	6005 058599	ALEKSEY KONOVALOV	{"phone": "+70991174920"}
0005432909202	C32316	2944 678061	ALEKSEY TIMOFEEV	{"email": "timofeev.aleksey.1976@postgrespro.ru", "phone": "+70064133657"}
0005432909203	CD95D5	3828 444420	MIKHAIL KUZMIN	{"phone": "+70181126469"}
0005432909204	A44883	1768 356637	NADEZHDA MAKSIMOVA	{"email": "maksimova_n_03041965@postgrespro.ru", "phone": "+70320607240"}
0005432909205	C06FF0	6999 110820	NATALYA NIKOLAEVA	{"phone": "+70288857241"}
0005432909206	C06FF0	7826 706696	NATALYA MOROZOVA	{"phone": "+70542752886"}
0005432909207	267615	0376 693939	ANATOLIY TARASOV	{"phone": "+70899914919"}
0005432909208	6C7304	9783 954576	TATYANA BELYAEVA	{"phone": "+70252553497"}
0005432909209	6C7304	3969 179727	VLADIMIR BONDARENKO	{"email": "vladimirbondarenko16041971@postgrespro.ru", "phone": "+70392901402"}
0005432909210	47D380	1051 872792	GALINA KUDRYASHOVA	{"email": "g.kudryashova_1962@postgrespro.ru", "phone": "+70780693996"}
0005432909211	F21B0B	9629 189930	VLADIMIR KOZLOV	{"phone": "+70191439791"}
0005432909212	91CAED	0810 363068	ELIZAVETA FEDOROVA	{"phone": "+70899696480"}
0005432909213	0F7BA2	8671 273673	IGOR MARTYNOV	{"email": "i_martynov_05051971@postgrespro.ru", "phone": "+70996835652"}
0005432909214	33FF29	5267 168831	EVGENIY KRASNOV	{"email": "krasnov-e091961@postgrespro.ru", "phone": "+70049097215"}
0005432909215	33FF29	4811 492396	NINA FILIPPOVA	{"phone": "+70598726730"}
0005432909216	12CC0F	9691 700941	ANNA POPOVA	{"email": "popovaanna061969@postgrespro.ru", "phone": "+70798384479"}
0005432909217	70B073	7995 133374	ANTONINA MOISEEVA	{"email": "a.moiseeva1969@postgrespro.ru", "phone": "+70819946966"}
0005432909218	70B073	5126 255127	DARYA NIKITINA	{"phone": "+70280387111"}
0005432909219	BCB5B2	2344 847308	ANATOLIY NIKITIN	{"email": "nikitinanatoliy121957@postgrespro.ru", "phone": "+70351600402"}
0005432909220	BCB5B2	3837 097842	PETR VOROBEV	{"phone": "+70741563185"}
0005432909221	724CF1	0320 705145	LYUDMILA FEDOROVA	{"phone": "+70184484781"}
0005432909222	AAD587	5717 754987	OLGA PETROVA	{"email": "petrova_o-1977@postgrespro.ru", "phone": "+70383091947"}
0005432909223	AAD587	1091 742815	NIKOLAY VOLKOV	{"email": "n_volkov_09031966@postgrespro.ru", "phone": "+70307326379"}
0005432909224	D13835	5849 176100	DMITRIY GUSEV	{"email": "dmitriy-gusev.1974@postgrespro.ru", "phone": "+70609931045"}
0005432909225	D13835	8892 891172	TATYANA GRISHINA	{"email": "t_grishina121972@postgrespro.ru", "phone": "+70782677171"}
0005432909226	40A271	0397 894218	MARGARITA PAVLOVA	{"phone": "+70146906668"}
0005432909227	D84DC6	2633 657859	KAMILLA ORLOVA	{"email": "k_orlova-30081979@postgrespro.ru", "phone": "+70500680173"}
0005432909228	A4E848	3020 381036	VLADIMIR SOLOVEV	{"email": "solovev-vladimir-031975@postgrespro.ru", "phone": "+70226298100"}
0005432909229	87C022	8665 205665	VASILIY EGOROV	{"email": "egorov-vasiliy_15041968@postgrespro.ru", "phone": "+70947753335"}
0005432909230	13B2AB	2679 100288	ANATOLIY FROLOV	{"phone": "+70796315314"}
0005432909231	539731	9584 057083	TATYANA NIKITINA	{"email": "tatyana_nikitina-02031974@postgrespro.ru", "phone": "+70256074897"}
0005432909232	0FCC80	2706 574552	NATALYA VASILEVA	{"email": "nvasileva_111969@postgrespro.ru", "phone": "+70935260170"}
0005432909233	FDD113	0230 918625	ZINAIDA KAZAKOVA	{"email": "kazakovazinaida.051966@postgrespro.ru", "phone": "+70964204092"}
0005432909234	DB16D9	1170 104499	KONSTANTIN MIKHAYLOV	{"phone": "+70830757716"}
0005432909235	DB16D9	3758 614574	OLGA POPOVA	{"email": "o-popova_1976@postgrespro.ru", "phone": "+70335564335"}
0005432909236	FE6495	5362 931973	ANTONIDA KUZMINA	{"email": "kuzminaantonida1970@postgrespro.ru", "phone": "+70960585480"}
0005432909237	FE6495	1081 174284	IVAN NOVIKOV	{"email": "novikovi-09111968@postgrespro.ru", "phone": "+70797556789"}
0005432909238	7A9E78	6570 419688	MARIYA SOKOLOVA	{"email": "mariyasokolova.1971@postgrespro.ru", "phone": "+70885493388"}
0005432909239	28CDC0	2251 137276	TATYANA DMITRIEVA	{"email": "dmitrievat_17081974@postgrespro.ru", "phone": "+70027928903"}
0005432909240	38D2E3	1121 765712	SERGEY SERGEEV	{"email": "sergeev_s_14071963@postgrespro.ru", "phone": "+70107642841"}
0005432909241	CF2B7B	7454 496732	ALEKSANDR KUZNECOV	{"phone": "+70270289352"}
0005432909242	84F703	6113 568887	IRINA FEDOROVA	{"email": "fedorova-irina.1968@postgrespro.ru", "phone": "+70053587752"}
0005432909243	84F703	6785 615330	ELENA KUZMINA	{"email": "elena-kuzmina_091965@postgrespro.ru", "phone": "+70814414394"}
0005432909244	27C0DB	0937 719696	NATALYA MOROZOVA	{"email": "morozova.natalya_1964@postgrespro.ru", "phone": "+70108251480"}
0005432909245	27C0DB	8855 459118	MARIYA MAKSIMOVA	{"phone": "+70783920292"}
0005432909246	403563	8619 025006	LYUDMILA SMIRNOVA	{"phone": "+70192912668"}
0005432909247	381B3D	0054 580776	YURIY SOKOLOV	{"phone": "+70056557616"}
0005432909248	381B3D	2372 045762	TATYANA PETROVA	{"email": "petrova_t-1972@postgrespro.ru", "phone": "+70959835249"}
0005432909249	ADC71B	8284 602290	VLADIMIR KAZAKOV	{"email": "kazakov.vladimir.1989@postgrespro.ru", "phone": "+70114636504"}
0005432909250	C3492A	6975 029278	FAINA SERGEEVA	{"phone": "+70152725535"}
0005432909251	81B4E1	8653 134903	PAVEL ORLOV	{"phone": "+70446397877"}
0005432909252	1BC031	4565 468040	TIMOFEY VASILEV	{"email": "vasilev_t.061980@postgrespro.ru", "phone": "+70365308973"}
0005432909253	5053DE	1820 982273	VLADIMIR IVANOV	{"phone": "+70209870116"}
0005432909254	F9AC35	8060 140114	KONSTANTIN SERGEEV	{"phone": "+70293597103"}
0005432909255	744107	5691 095499	VALENTIN IVANOV	{"phone": "+70667598777"}
0005432909256	84E7AD	9382 723451	BORIS KUZNECOV	{"email": "boris.kuznecov-25051967@postgrespro.ru", "phone": "+70543058195"}
0005432909257	8335EC	0505 844499	FEDOR ALEKSEEV	{"email": "alekseevfedor101973@postgrespro.ru", "phone": "+70907329891"}
0005432909258	8335EC	9896 485277	ALEKSEY ABRAMOV	{"phone": "+70196723860"}
0005432909259	1AC57D	9833 382910	EVGENIY KUZNECOV	{"email": "kuznecov-e-031975@postgrespro.ru", "phone": "+70532810374"}
0005432909260	1AC57D	8910 972923	TAISA PETROVA	{"phone": "+70486931242"}
0005432909261	C39035	1888 881486	TAGIR STEPANOV	{"email": "tstepanov-121962@postgrespro.ru", "phone": "+70946419203"}
0005432909262	BDCFF5	8709 170346	TATYANA ZHURAVLEVA	{"email": "zhuravleva_t_13101966@postgrespro.ru", "phone": "+70872493392"}
0005432909263	9A2DB7	1964 631367	LEONID NOVIKOV	{"phone": "+70440404505"}
0005432909264	6E36AF	0218 142452	ALEKSANDR KUZMIN	{"phone": "+70663989189"}
0005432909265	E79CC3	8506 844231	VADIM SAVELEV	{"email": "savelev-vadim_1989@postgrespro.ru", "phone": "+70889008928"}
0005432909266	A862ED	4584 218586	SERGEY KAZAKOV	{"email": "sergey.kazakov081969@postgrespro.ru", "phone": "+70432360888"}
0005432909267	1CC785	4638 088398	LYUDMILA MELNIKOVA	{"phone": "+70234286605"}
0005432909268	5BE4C0	6585 936410	EGOR EGOROV	{"phone": "+70576298842"}
0005432909269	F6114F	5825 161376	ANTON STEPANOV	{"email": "stepanov.a_061969@postgrespro.ru", "phone": "+70721832372"}
0005432909270	F6114F	6022 152128	LILIYA DAVYDOVA	{"email": "davydova_liliya121973@postgrespro.ru", "phone": "+70359777069"}
0005432909271	1497D6	9179 004353	MIKHAIL ANDREEV	{"phone": "+70421650586"}
0005432909272	FDC89B	5249 455363	GALINA ROMANOVA	{"email": "gromanova21031977@postgrespro.ru", "phone": "+70231665763"}
0005432909273	FDC89B	6451 444246	NINA MOISEEVA	{"phone": "+70702523209"}
0005432909274	2CC2D5	1205 506288	KIRILL SOROKIN	{"phone": "+70811874482"}
0005432909275	2CC2D5	6479 650370	ANDREY SOLOVEV	{"email": "asolovev.01071985@postgrespro.ru", "phone": "+70698467247"}
0005432909276	4A27B1	1409 502706	OLGA VOLKOVA	{"phone": "+70826536094"}
0005432909277	2BE483	8532 285895	VLADIMIR ZAKHAROV	{"email": "v_zakharov.081973@postgrespro.ru", "phone": "+70400568974"}
0005432909278	F4255A	9887 095354	POLINA SERGEEVA	{"email": "sergeeva-p_29041967@postgrespro.ru", "phone": "+70943432761"}
0005432909279	F4255A	3844 413222	DMITRIY ILIN	{"phone": "+70550124135"}
0005432909280	6B510B	8934 143409	ALEKSANDR BORISOV	{"phone": "+70805279225"}
0005432909281	6B510B	8008 750323	ELENA BOGDANOVA	{"phone": "+70193306094"}
0005432909282	ACE786	4817 346698	IVAN BELOV	{"email": "i_belov_121972@postgrespro.ru", "phone": "+70047198390"}
0005432909283	72E38C	5863 963932	ALEKSANDR DMITRIEV	{"phone": "+70630817065"}
0005432909284	72E38C	7027 433031	ANASTASIYA SERGEEVA	{"phone": "+70718768222"}
0005432909285	B06421	1642 417072	OKSANA AFANASEVA	{"phone": "+70973058382"}
0005432909286	B06421	3251 255070	TATYANA IVANOVA	{"email": "ivanova_t-30121966@postgrespro.ru", "phone": "+70228740897"}
0005432909287	54A903	2954 215016	VLADIMIR KULIKOV	{"phone": "+70900606388"}
0005432909288	54A903	5244 009180	SVETLANA FILATOVA	{"phone": "+70756207582"}
0005432909289	7E2B71	4029 531087	OLGA MIRONOVA	{"email": "mironova_olga_111973@postgrespro.ru", "phone": "+70655776451"}
0005432909290	7E2B71	2041 050513	SERGEY SOKOLOV	{"email": "sokolov.sergey06061975@postgrespro.ru", "phone": "+70929928558"}
0005432909291	961A78	1068 697583	YURIY ROMANOV	{"email": "romanov.yuriy.091978@postgrespro.ru", "phone": "+70508740769"}
0005432909292	6E0F9D	9787 778692	GALINA POPOVA	{"email": "popova_g.1985@postgrespro.ru", "phone": "+70038303030"}
0005432909293	AA4CE7	7683 756737	ANDREY KARPOV	{"phone": "+70866988553"}
0005432909294	AA4CE7	5283 398111	TATYANA NAZAROVA	{"email": "nazarova.tatyana.091982@postgrespro.ru", "phone": "+70351199243"}
0005432909295	D02845	1978 245725	IGOR FROLOV	{"phone": "+70253402847"}
0005432909296	D02845	2061 460777	NAIL MAKAROV	{"email": "makarov.nail_02061977@postgrespro.ru", "phone": "+70276720813"}
0005432909297	D56704	1438 603432	BORIS MEDVEDEV	{"email": "b.medvedev07041976@postgrespro.ru", "phone": "+70863330563"}
0005432909298	D56704	9498 284144	LYUDMILA MEDVEDEVA	{"phone": "+70078407316"}
0005432909299	E46449	0012 980492	YULIYA MEDVEDEVA	{"phone": "+70339132610"}
0005432909300	E46449	0463 414523	GULIYA OVCHINNIKOVA	{"email": "ovchinnikova_g-021974@postgrespro.ru", "phone": "+70300024032"}
0005432909301	894AA3	5118 291719	DMITRIY ZHURAVLEV	{"phone": "+70017531308"}
0005432909302	94FD91	7488 350690	NADEZHDA ILINA	{"email": "n.ilina_04021975@postgrespro.ru", "phone": "+70907876204"}
0005432909303	1348A6	2361 399342	GENNADIY VOLKOV	{"phone": "+70405536753"}
0005432909304	1348A6	9940 093779	SERGEY MOROZOV	{"phone": "+70022968135"}
0005432909305	2641CF	0082 111817	ILYA KAZAKOV	{"email": "kazakovi-04091975@postgrespro.ru", "phone": "+70310150399"}
0005432909306	DE52BE	6925 864824	VITALIY MOROZOV	{"email": "vitaliy.morozov.23011969@postgrespro.ru", "phone": "+70775269990"}
0005432909307	4A77B6	2681 085286	ANTONINA KARPOVA	{"phone": "+70300554852"}
0005432909308	26115A	6179 557983	EVGENIY TARASOV	{"phone": "+70852718438"}
0005432909309	94441A	3013 056252	NATALYA LAZAREVA	{"phone": "+70719895017"}
0005432909310	48D443	5821 878109	ANDREY NOVIKOV	{"email": "novikov_a.29081962@postgrespro.ru", "phone": "+70606877820"}
0005432909311	FFAED7	1708 794276	DARYA ANDREEVA	{"email": "d_andreeva.19071975@postgrespro.ru", "phone": "+70401656523"}
0005432909312	AF0F78	4477 981189	NIKOLAY SEMENOV	{"email": "semenov.nikolay.041973@postgrespro.ru", "phone": "+70392653911"}
0005432909313	F14457	8431 383023	TATYANA YUDINA	{"phone": "+70441421067"}
0005432909314	63F148	1148 124638	ELENA FILIPPOVA	{"email": "e-filippova_1964@postgrespro.ru", "phone": "+70367628436"}
0005432909315	EA6C4A	5312 540032	MARINA MAKAROVA	{"email": "makarova-marina.071973@postgrespro.ru", "phone": "+70265367122"}
0005432909316	61CBF3	4524 247092	OLEG KUZMIN	{"email": "o.kuzmin051979@postgrespro.ru", "phone": "+70137024051"}
0005432909317	51714C	3574 980359	GEORGIY ZAKHAROV	{"email": "zakharov_georgiy06011973@postgrespro.ru", "phone": "+70443361832"}
0005432909318	383A04	2859 542280	NADEZHDA NIKIFOROVA	{"email": "nikiforovanadezhda1971@postgrespro.ru", "phone": "+70719000498"}
0005432909319	D723A2	0523 063211	ANDREY KARPOV	{"email": "a.karpov1979@postgrespro.ru", "phone": "+70189429905"}
0005432909320	73593A	7021 383187	GULNAZ SEMENOVA	{"phone": "+70097271495"}
0005432909321	898C67	9837 837894	EKATERINA KOROLEVA	{"phone": "+70982531851"}
0005432909322	C2CABD	2221 925122	IGOR KOROLEV	{"email": "korolevi-1969@postgrespro.ru", "phone": "+70916719891"}
0005432909323	263398	3437 957795	ELENA KOROLEVA	{"email": "e.koroleva-26021974@postgrespro.ru", "phone": "+70111343974"}
0005432909324	263398	2179 468592	ALEKSANDRA DENISOVA	{"email": "a-denisova_19091967@postgrespro.ru", "phone": "+70241724001"}
0005432909325	6AA05C	2769 193407	NATALYA LUKYANOVA	{"email": "natalya.lukyanova23021975@postgrespro.ru", "phone": "+70849242200"}
0005432909326	6AA05C	7816 093036	ELLA ALEKSEEVA	{"email": "e_alekseeva.021974@postgrespro.ru", "phone": "+70872646200"}
0005432909327	4BD073	0290 334398	VIKTOR RODIONOV	{"email": "rodionov_v.1972@postgrespro.ru", "phone": "+70053512413"}
0005432909328	4BD073	9940 330428	ANDREY ANDREEV	{"phone": "+70544422003"}
0005432909329	DAF172	1390 888895	DARYA ZAKHAROVA	{"email": "darya-zakharova_1977@postgrespro.ru", "phone": "+70972603206"}
0005432909330	2BBD63	6707 394263	VLADIMIR IVANOV	{"email": "ivanov-v-051982@postgrespro.ru", "phone": "+70450334276"}
0005432909331	2BBD63	7076 505197	MIKHAIL SEMENOV	{"email": "semenov-mikhail15101969@postgrespro.ru", "phone": "+70397044604"}
0005432909332	C561C3	5856 919130	ANDREY SAVELEV	{"phone": "+70646351001"}
0005432909333	C561C3	1844 745147	VERONIKA FROLOVA	{"email": "frolova.v-021965@postgrespro.ru", "phone": "+70987070754"}
0005432909334	D3B1AE	3097 130816	MARIYA KUZMINA	{"phone": "+70933057296"}
0005432909335	36E744	2533 207534	ALEKSANDRA ZHUKOVA	{"phone": "+70509965494"}
0005432909336	79092B	1871 403961	ALEKSANDR PETROV	{"phone": "+70679635021"}
0005432909337	79092B	3758 898037	ALLA KRASNOVA	{"phone": "+70180473864"}
0005432909338	64D058	0295 368207	NATALYA NIKOLAEVA	{"phone": "+70180565783"}
0005432909339	5BC1E2	3378 585812	ARTEM DAVYDOV	{"phone": "+70399255815"}
0005432909340	730AC3	5194 257867	EKATERINA OSIPOVA	{"email": "osipova_e_06011985@postgrespro.ru", "phone": "+70886816055"}
0005432909341	730AC3	6215 212852	VLADIMIR FOMIN	{"phone": "+70700891177"}
0005432909342	81B44A	2832 045490	MARIYA VOLKOVA	{"email": "volkova-m_1973@postgrespro.ru", "phone": "+70570424012"}
0005432909343	CA3F9A	9269 010982	NADEZHDA DANILOVA	{"phone": "+70926288541"}
0005432909344	CA3F9A	2008 363410	VALENTINA ALEKSEEVA	{"email": "valentina_alekseeva.091972@postgrespro.ru", "phone": "+70589486859"}
0005432909345	EF8131	8926 770704	ALINA AFANASEVA	{"email": "alina_afanaseva.21041970@postgrespro.ru", "phone": "+70607651972"}
0005432909346	EF8131	8799 861055	MARINA POPOVA	{"phone": "+70669165574"}
0005432909347	8E7ED6	6217 694094	ALEKSANDR ABRAMOV	{"phone": "+70531021969"}
0005432909348	8E7ED6	3953 982526	ANNA DAVYDOVA	{"phone": "+70101737671"}
0005432909349	297054	4564 032698	MARIYA KOROLEVA	{"email": "korolevam.1977@postgrespro.ru", "phone": "+70411400235"}
0005432909350	BD07A4	1036 930176	ALEKSANDR IVANOV	{"phone": "+70754181112"}
0005432909351	F57FBD	3998 279337	TATYANA TITOVA	{"email": "titova_tatyana.041966@postgrespro.ru", "phone": "+70146530560"}
0005432909352	12A449	5085 285151	MAKSIM NIKITIN	{"phone": "+70515554419"}
0005432909353	319ECC	0069 966100	ANDREY IVANOV	{"phone": "+70861559246"}
0005432909354	79DFF5	3867 799005	GULNARA NESTEROVA	{"email": "g.nesterova_1978@postgrespro.ru", "phone": "+70074367016"}
0005432909355	79DFF5	4425 321240	SOFYA VASILEVA	{"phone": "+70340202495"}
0005432909356	730B16	7725 339048	ALEKSEY TIKHONOV	{"phone": "+70955189234"}
0005432909357	730B16	7142 687981	OLEG KISELEV	{"phone": "+70666262178"}
0005432909358	3CE44B	3797 227784	BOGDAN KAZAKOV	{"email": "bogdan_kazakov-1977@postgrespro.ru", "phone": "+70783819399"}
0005432909359	24DE8B	8151 635352	ALENA KULIKOVA	{"phone": "+70631030377"}
0005432909360	24DE8B	2547 497684	VALENTINA IVANOVA	{"phone": "+70584754792"}
0005432909361	3A80A6	3369 626942	ALEKSANDR SIDOROV	{"phone": "+70592545748"}
0005432909362	3A80A6	2661 638601	TATYANA KOLESNIKOVA	{"email": "t-kolesnikova_121964@postgrespro.ru", "phone": "+70826108207"}
0005432909363	F972C5	1314 289524	VLADIMIR VASILEV	{"email": "vasilev_v.091963@postgrespro.ru", "phone": "+70394000944"}
0005432909364	A25C9E	4581 950074	MIKHAIL VASILEV	{"email": "vasilev-mikhail101975@postgrespro.ru", "phone": "+70682576386"}
0005432909365	38D16D	9660 754779	SERGEY SERGEEV	{"phone": "+70622591824"}
0005432909366	38D16D	2504 466580	RUFIYA KONOVALOVA	{"phone": "+70940195595"}
0005432909367	CA941B	7552 171668	ANDREY RODIONOV	{"phone": "+70602601596"}
0005432909368	FE3806	2681 821330	TATYANA EFREMOVA	{"phone": "+70855774223"}
0005432909369	CEA1C0	2097 355507	DENIS FOMIN	{"email": "fomin.denis20011980@postgrespro.ru", "phone": "+70101964439"}
0005432909370	4B23F4	3011 067641	IRINA TIMOFEEVA	{"email": "i_timofeeva_041978@postgrespro.ru", "phone": "+70778485905"}
0005432909371	4B23F4	8422 325494	MIKHAIL STEPANOV	{"email": "mikhail-stepanov-011978@postgrespro.ru", "phone": "+70115464291"}
0005432909372	0BC390	7507 801502	GALINA PETROVA	{"phone": "+70504120200"}
0005432909373	FD193E	0849 072391	ELENA ROMANOVA	{"phone": "+70146458191"}
0005432909374	8BDCB4	5026 890756	ANDREY SIDOROV	{"phone": "+70530782290"}
0005432909375	AF40E6	3007 282847	GENNADIY PETROV	{"email": "gennadiypetrov-041972@postgrespro.ru", "phone": "+70537130789"}
0005432909376	AC84E4	5902 136473	ANASTASIYA KULIKOVA	{"email": "a_kulikova.08111973@postgrespro.ru", "phone": "+70501317397"}
0005432909377	AC84E4	3987 007274	SERGEY KUZMIN	{"email": "kuzmins.041973@postgrespro.ru", "phone": "+70703418533"}
0005432909378	AC84E4	3881 292489	IRINA SCHERBAKOVA	{"phone": "+70701493414"}
0005432909379	8EB388	4758 338513	SERGEY KUDRYASHOV	{"phone": "+70520558087"}
0005432909380	8EB388	8399 293163	LYUDMILA RYABOVA	{"phone": "+70834734983"}
0005432909381	A6E6ED	1055 605649	LILIYA NIKOLAEVA	{"email": "nikolaeva.l_051988@postgrespro.ru", "phone": "+70315130813"}
0005432909382	A6E6ED	7024 520080	ANASTASIYA LUKYANOVA	{"phone": "+70466107364"}
0005432909383	F2F9D2	2814 430554	ROMAN ISAEV	{"phone": "+70260573250"}
0005432909384	F9467A	2067 003677	VERA BORISOVA	{"phone": "+70917831483"}
0005432909385	9E59FF	4141 777728	OLEG PETROV	{"email": "opetrov-031967@postgrespro.ru", "phone": "+70330321219"}
0005432909386	5A3598	5206 310830	GALINA GAVRILOVA	{"phone": "+70953317873"}
0005432909387	5A3598	6603 461134	NADEZHDA ZHURAVLEVA	{"email": "zhuravleva_n.03021976@postgrespro.ru", "phone": "+70736166806"}
0005432909388	1F5782	9139 065740	MARIYA ROMANOVA	{"phone": "+70860377943"}
0005432909389	08460A	5617 055376	VALENTINA ABRAMOVA	{"email": "valentina-abramova1969@postgrespro.ru", "phone": "+70639777626"}
0005432909390	08460A	7219 710695	TATYANA IVANOVA	{"email": "ivanova_tatyana-08061982@postgrespro.ru", "phone": "+70621350624"}
0005432909391	B97F83	2911 551397	MIKHAIL KULIKOV	{"phone": "+70980758866"}
0005432909392	114C01	8139 226753	ALEKSEY EGOROV	{"email": "egorov_a-24071975@postgrespro.ru", "phone": "+70176918424"}
0005432909393	3BFE09	8062 428763	DARYA RODIONOVA	{"phone": "+70776810106"}
0005432909394	3BFE09	8307 120320	IGOR ZHUKOV	{"email": "zhukov_igor_051954@postgrespro.ru", "phone": "+70312485756"}
0005432909395	3BFE09	6826 415133	RIMMA KRASNOVA	{"phone": "+70161958797"}
0005432909396	C859EE	7518 783362	EKATERINA FOMINA	{"email": "e.fomina.1969@postgrespro.ru", "phone": "+70816750654"}
0005432909397	C951BE	8926 747566	ELENA EGOROVA	{"phone": "+70311245366"}
0005432909398	C5EF5F	2753 269119	TIMUR EGOROV	{"email": "tegorov_011969@postgrespro.ru", "phone": "+70924499512"}
0005432909399	F1D372	9222 226866	ANASTASIYA ERMAKOVA	{"phone": "+70475295510"}
0005432909400	F1D372	7790 676865	NINA YAKOVLEVA	{"email": "nyakovleva.051975@postgrespro.ru", "phone": "+70727248750"}
0005432909401	1FD67B	2688 929293	ALEKSANDR MAKAROV	{"email": "amakarov_17041975@postgrespro.ru", "phone": "+70891518891"}
0005432909402	675388	3277 222524	ALEKSANDR NIKITIN	{"phone": "+70446926481"}
0005432909403	675388	3625 522454	ALEKSEY FEDOTOV	{"phone": "+70829018129"}
0005432909404	491887	2029 530777	EKATERINA KOROLEVA	{"email": "koroleva.e.06071984@postgrespro.ru", "phone": "+70672935337"}
0005432909405	491887	0916 416540	VALENTINA FROLOVA	{"email": "v.frolova-091975@postgrespro.ru", "phone": "+70896672867"}
0005432909406	64CF00	0797 451507	NATALYA KONDRATEVA	{"email": "kondrateva_n_121975@postgrespro.ru", "phone": "+70458479121"}
0005432909407	68CD7F	2306 075802	SVETLANA MELNIKOVA	{"phone": "+70986044226"}
0005432909408	5D17EF	4591 333351	ALISA SERGEEVA	{"phone": "+70314427458"}
0005432909409	DD2741	8893 788120	ZINAIDA TIMOFEEVA	{"phone": "+70247320431"}
0005432909410	261CFE	1030 706993	DARYA ERMAKOVA	{"phone": "+70684811328"}
0005432909411	4F141E	0590 771008	ALEKSEY FEDOROV	{"phone": "+70310175170"}
0005432909412	F742B4	9772 809222	IGOR GAVRILOV	{"phone": "+70915534467"}
0005432909413	F742B4	2280 514960	NADEZHDA SMIRNOVA	{"phone": "+70411161723"}
0005432909414	D6093F	7331 065178	ALENA KUZMINA	{"phone": "+70004632881"}
0005432909415	71F2B8	8914 534851	OLGA FOMINA	{"email": "o-fomina1974@postgrespro.ru", "phone": "+70557678749"}
0005432909416	71F2B8	5563 642651	ALFIYA DENISOVA	{"email": "alfiya_denisova-1977@postgrespro.ru", "phone": "+70255453564"}
0005432909417	354EE3	7051 968715	ALEKSEY KUZNECOV	{"phone": "+70072643334"}
0005432909418	C59A01	8490 425798	MAKSIM PAVLOV	{"email": "m-pavlov-03101962@postgrespro.ru", "phone": "+70991762671"}
0005432909419	C59A01	3165 423267	DMITRIY GRIGOREV	{"email": "d-grigorev01071977@postgrespro.ru", "phone": "+70680214553"}
0005432909420	22D243	7732 339474	YURIY MIKHAYLOV	{"email": "mikhaylov.y03071982@postgrespro.ru", "phone": "+70494703876"}
0005432909421	22D243	9735 612028	KIRILL NOVIKOV	{"email": "novikov-k041984@postgrespro.ru", "phone": "+70884490212"}
0005432909422	F00E06	4441 237141	VIKTOR RODIONOV	{"email": "rodionov_v-1968@postgrespro.ru", "phone": "+70342730829"}
0005432909423	477DD2	3471 098186	KIRILL POPOV	{"email": "popov_k_1972@postgrespro.ru", "phone": "+70120209376"}
0005432909424	5F2768	3875 678666	EKATERINA POTAPOVA	{"email": "potapova_e_08081967@postgrespro.ru", "phone": "+70238453317"}
0005432909425	5C090B	1309 727236	KSENIYA POTAPOVA	{"email": "potapova-kseniya-17031968@postgrespro.ru", "phone": "+70383016816"}
0005432909426	5C090B	9849 605610	GALINA LUKYANOVA	{"phone": "+70218519475"}
0005432909427	2A2C13	9354 584893	TATYANA KUZNECOVA	{"phone": "+70105645304"}
0005432920082	EFA3BD	2824 595746	EVGENIY GORBUNOV	{"phone": "+70503481646"}
0005432909428	FE98C4	9028 577073	YURIY ANTONOV	{"email": "antonov_yuriy1966@postgrespro.ru", "phone": "+70949583146"}
0005432909429	517EE5	3923 295560	PETR GORBUNOV	{"phone": "+70731123546"}
0005432909430	9ECC7A	8415 728939	ZOYA KUZNECOVA	{"phone": "+70150621743"}
0005432909431	9ECC7A	9164 439184	VALENTINA NAUMOVA	{"email": "naumova_v-1975@postgrespro.ru", "phone": "+70286369116"}
0005432909432	A6724A	5839 172356	ARTEM SCHERBAKOV	{"phone": "+70968725299"}
0005432909433	2D7723	4988 566460	LYUBOV RYABOVA	{"email": "l-ryabova.1967@postgrespro.ru", "phone": "+70167259215"}
0005432909434	2D7723	1332 138488	OLEG MEDVEDEV	{"phone": "+70446377438"}
0005432909435	B31A17	5973 763316	VLADIMIR GUSEV	{"email": "gusev-vladimir081980@postgrespro.ru", "phone": "+70723003193"}
0005432909436	B31A17	5681 489724	TATYANA KOROLEVA	{"email": "t.koroleva04061965@postgrespro.ru", "phone": "+70649704273"}
0005432909437	C90D00	1263 045404	LYUDMILA EGOROVA	{"email": "egoroval1969@postgrespro.ru", "phone": "+70442989869"}
0005432909438	86CDF7	2882 897245	TATYANA MELNIKOVA	{"email": "tatyana.melnikova_1969@postgrespro.ru", "phone": "+70962613803"}
0005432909439	86CDF7	9341 335603	ALEKSANDR SHEVCHENKO	{"phone": "+70639728154"}
0005432909440	1712FB	0744 387499	VASILIY ZHURAVLEV	{"email": "zhuravlevv_021980@postgrespro.ru", "phone": "+70827422146"}
0005432909441	1712FB	1065 170105	SVETLANA LAZAREVA	{"phone": "+70023129257"}
0005432909442	1712FB	7522 491639	NINA DAVYDOVA	{"email": "davydovanina.021965@postgrespro.ru", "phone": "+70362907376"}
0005432909443	9D8F5E	0905 229837	TATYANA KISELEVA	{"phone": "+70030026614"}
0005432909444	94C538	4562 523278	LYUBOV KAZAKOVA	{"email": "l.kazakova111977@postgrespro.ru", "phone": "+70306442706"}
0005432919556	E50ABD	7098 098949	NINA ZOTOVA	{"phone": "+70583392494"}
0005432919503	00A48F	2164 561950	OLEG VOROBEV	{"email": "vorobevo_021976@postgrespro.ru", "phone": "+70252466205"}
0005432919504	8035C8	4052 906832	ALSU MAKAROVA	{"phone": "+70604450001"}
0005432919505	5B07CF	7756 715564	TATYANA ABRAMOVA	{"email": "tatyana-abramova_1961@postgrespro.ru", "phone": "+70026776399"}
0005432919506	1D1C53	1159 436264	YURIY SIDOROV	{"email": "sidorov_yuriy-091968@postgrespro.ru", "phone": "+70993538382"}
0005432919507	27663A	3969 839698	ANATOLIY MAKAROV	{"phone": "+70926217255"}
0005432919508	27663A	0942 151551	VALENTINA ANISIMOVA	{"email": "anisimovav_061956@postgrespro.ru", "phone": "+70792652481"}
0005432919509	27663A	7884 134289	DENIS POPOV	{"phone": "+70476198080"}
0005432919510	27663A	3794 146274	VASILIY FROLOV	{"phone": "+70045959180"}
0005432919511	1C1BD0	3470 334048	AYRAT SEMENOV	{"email": "semenova111964@postgrespro.ru", "phone": "+70454299858"}
0005432919512	1C1BD0	8623 086336	OLGA SOKOLOVA	{"email": "o.sokolova.04101981@postgrespro.ru", "phone": "+70457354554"}
0005432919513	1C1BD0	1869 659804	TATYANA PAVLOVA	{"phone": "+70562836629"}
0005432919514	C12A4D	9466 507121	KAMILLA IVANOVA	{"email": "ivanova.kamilla.101985@postgrespro.ru", "phone": "+70097967012"}
0005432919515	C12A4D	1159 765841	GEORGIY VOLKOV	{"phone": "+70622420046"}
0005432919516	420F48	5272 973177	SERGEY SIDOROV	{"email": "s-sidorov_07031964@postgrespro.ru", "phone": "+70991519408"}
0005432919517	F30C27	5619 460884	VLADIMIR CHERNOV	{"email": "vladimir-chernov_071976@postgrespro.ru", "phone": "+70742927349"}
0005432919518	F30C27	9844 663192	ANTONINA KOMAROVA	{"phone": "+70417447688"}
0005432919519	88E775	9875 203512	LYUBOV RODIONOVA	{"phone": "+70918495144"}
0005432919520	16A523	8340 642762	RUMIYA NIKOLAEVA	{"email": "nikolaeva-r.081968@postgrespro.ru", "phone": "+70195709663"}
0005432919521	BB4C39	1168 541444	VYACHESLAV NIKOLAEV	{"email": "nikolaev_vyacheslav021981@postgrespro.ru", "phone": "+70403334982"}
0005432919522	D5D65B	3946 429285	VLADISLAV ZAKHAROV	{"phone": "+70593718075"}
0005432919523	7CD148	6951 721451	OKSANA GUSEVA	{"email": "o.guseva_1972@postgrespro.ru", "phone": "+70972344211"}
0005432919524	7CD148	4056 172780	PAVEL GRIGOREV	{"email": "grigorev.p-1976@postgrespro.ru", "phone": "+70340696451"}
0005432919525	F6132B	1953 478335	EKATERINA KUZNECOVA	{"email": "kuznecova.ekaterina.1968@postgrespro.ru", "phone": "+70784779717"}
0005432919526	F6132B	0046 143828	VLADIMIR KUZNECOV	{"email": "v_kuznecov.14081963@postgrespro.ru", "phone": "+70731383514"}
0005432919527	C77436	1143 583900	EKATERINA FEDOROVA	{"email": "fedorova-ekaterina_1978@postgrespro.ru", "phone": "+70382877116"}
0005432919528	C77436	5175 019032	AMINA KONOVALOVA	{"email": "konovalovaa_071975@postgrespro.ru", "phone": "+70017508328"}
0005432919529	C77436	9291 378576	ANTONINA SAVELEVA	{"email": "saveleva.a_1980@postgrespro.ru", "phone": "+70613364977"}
0005432919530	2BE0F7	8924 815951	TATYANA VASILEVA	{"email": "vasileva.tatyana1960@postgrespro.ru", "phone": "+70924885218"}
0005432919531	ED3498	1779 392292	ELIZAVETA ZAKHAROVA	{"email": "e_zakharova26061969@postgrespro.ru", "phone": "+70467821303"}
0005432919532	67C819	8810 144135	KRISTINA GUSEVA	{"email": "kristinaguseva_091973@postgrespro.ru", "phone": "+70250618767"}
0005432919533	B36A3D	0193 397219	NATALYA SOLOVEVA	{"phone": "+70212518212"}
0005432919534	B36A3D	4768 281192	TATYANA RYABOVA	{"email": "ryabovatatyana-07081972@postgrespro.ru", "phone": "+70909624506"}
0005432919535	72106A	0119 476292	NATALIYA DANILOVA	{"email": "n_danilova-1977@postgrespro.ru", "phone": "+70235386162"}
0005432919536	B3E0CB	4756 733413	MIKHAIL SAVELEV	{"email": "savelev.mikhail-25011978@postgrespro.ru", "phone": "+70639126543"}
0005432919537	54A57C	3682 545061	SVETLANA MAKAROVA	{"email": "svetlana.makarova_1973@postgrespro.ru", "phone": "+70787287871"}
0005432919538	54A57C	8706 469500	IVAN MAKAROV	{"email": "makarovi1982@postgrespro.ru", "phone": "+70572111791"}
0005432919539	28F4A3	2248 342279	VLADIMIR SMIRNOV	{"phone": "+70341380817"}
0005432919540	95F939	9512 683482	VALENTINA NAZAROVA	{"email": "v.nazarova.111969@postgrespro.ru", "phone": "+70825865388"}
0005432919541	640FE0	7788 326761	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr-011974@postgrespro.ru", "phone": "+70645627863"}
0005432919542	607CB9	4371 953253	MARTA SMIRNOVA	{"phone": "+70799555546"}
0005432919543	5A6885	5032 122912	PETR VASILEV	{"email": "vasilev.p-10031966@postgrespro.ru", "phone": "+70561642143"}
0005432919544	93F092	9109 196768	LYUBOV OSIPOVA	{"email": "osipova-lyubov_081970@postgrespro.ru", "phone": "+70243001898"}
0005432919545	40B226	1935 113914	VLADIMIR MIRONOV	{"email": "mironov.vladimir_111982@postgrespro.ru", "phone": "+70077047142"}
0005432919546	F0BE2A	4183 296495	GERMAN BONDARENKO	{"phone": "+70382738355"}
0005432919547	7BE6FA	0631 598927	TAMARA BARANOVA	{"email": "tbaranova061984@postgrespro.ru", "phone": "+70648762137"}
0005432919548	9544C6	4019 299006	DARYA FEDOROVA	{"email": "fedorovad_1979@postgrespro.ru", "phone": "+70388329749"}
0005432919549	9F2625	9298 445771	OLGA RYABOVA	{"email": "ryabova-o_07111965@postgrespro.ru", "phone": "+70384988926"}
0005432919550	F16C64	9012 718048	VLADIMIR KARPOV	{"phone": "+70311492514"}
0005432919551	A7E471	9513 293738	ELENA NESTEROVA	{"email": "nesterova_e1974@postgrespro.ru", "phone": "+70115093643"}
0005432919552	BE6FF0	0656 298729	EKATERINA GERASIMOVA	{"phone": "+70231748128"}
0005432919553	C93425	8660 623592	IRINA KUZNECOVA	{"email": "kuznecova_i1976@postgrespro.ru", "phone": "+70447959461"}
0005432919554	83221C	3027 430220	RAUF SERGEEV	{"email": "sergeevr.041969@postgrespro.ru", "phone": "+70019967364"}
0005432919555	D980F1	3458 989870	LYUBOV SIDOROVA	{"phone": "+70128056769"}
0005432919557	E50ABD	2072 480608	MARIYA DENISOVA	{"email": "mariyadenisova-15041973@postgrespro.ru", "phone": "+70821847464"}
0005432919558	40C577	8050 227944	DMITRIY DENISOV	{"email": "denisovd.16021970@postgrespro.ru", "phone": "+70228948398"}
0005432919559	40C577	6593 781046	YULIYA OSIPOVA	{"email": "osipova-yuliya-1985@postgrespro.ru", "phone": "+70571948993"}
0005432919560	40C577	0868 968369	LEONID SAVELEV	{"email": "leonid-savelev-041982@postgrespro.ru", "phone": "+70163126189"}
0005432919561	10F4E9	7368 529783	VERA DENISOVA	{"phone": "+70878649480"}
0005432919562	62AC61	8581 591082	ALEKSEY KRASNOV	{"phone": "+70860125143"}
0005432919563	42BE8B	7120 101403	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov_05011973@postgrespro.ru", "phone": "+70603072945"}
0005432919564	42BE8B	2902 248484	VALERIY ROMANOV	{"phone": "+70949668247"}
0005432919565	2E05A8	2935 902599	ANASTASIYA GRISHINA	{"email": "a_grishina_1974@postgrespro.ru", "phone": "+70178182378"}
0005432919566	2E05A8	0473 367911	ANNA MAKAROVA	{"phone": "+70472404993"}
0005432919567	04CD83	6661 840102	ALEKSANDR SERGEEV	{"phone": "+70412125823"}
0005432919568	04CD83	4269 287995	VALERIYA POPOVA	{"email": "popova-valeriya1972@postgrespro.ru", "phone": "+70209877569"}
0005432919569	DEDCE2	2853 887130	ALEKSANDR IVANOV	{"phone": "+70305899530"}
0005432919570	DEDCE2	1618 764139	VIKTOR SHEVCHENKO	{"email": "shevchenko-v.021971@postgrespro.ru", "phone": "+70323339428"}
0005432919571	DFE042	2862 344826	NAILYA NIKITINA	{"email": "n_nikitina.021972@postgrespro.ru", "phone": "+70659679478"}
0005432919572	DA51F7	2358 144337	VLADIMIR POPOV	{"phone": "+70980695309"}
0005432919573	DA51F7	2841 264852	VADIM ANDREEV	{"phone": "+70061335875"}
0005432919574	3D879C	6411 447578	ALEKSANDR FEDOROV	{"phone": "+70054515938"}
0005432919575	E3E893	2716 647614	NINA ZAYCEVA	{"phone": "+70412847540"}
0005432919576	F085EC	6357 337549	ANNA STEPANOVA	{"phone": "+70427079829"}
0005432919577	DA72BC	9012 255629	EVGENIY BELOV	{"email": "ebelov-1974@postgrespro.ru", "phone": "+70961933611"}
0005432919634	EBC0F3	5590 346625	MARINA KOVALEVA	{"phone": "+70345401255"}
0005432919578	1AD82F	0332 656122	ANATOLIY SOROKIN	{"email": "a_sorokin_1964@postgrespro.ru", "phone": "+70985572616"}
0005432919579	C06CD2	6458 855238	ELINA GUSEVA	{"email": "guseva.elina.1968@postgrespro.ru", "phone": "+70289298703"}
0005432919580	E6EA38	3623 128625	DMITRIY MOROZOV	{"phone": "+70156614819"}
0005432919581	E6EA38	7857 620004	SERGEY KAZAKOV	{"email": "kazakovs_021970@postgrespro.ru", "phone": "+70534072033"}
0005432919582	E6EA38	8448 421955	ANDREY ZHURAVLEV	{"phone": "+70826876585"}
0005432919583	32E341	1453 378383	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov.27111954@postgrespro.ru", "phone": "+70385676489"}
0005432919584	9627D5	2859 824128	MARIYA VLASOVA	{"email": "vlasova.mariya_061982@postgrespro.ru", "phone": "+70181549493"}
0005432919585	7F9D78	2858 493647	ALEKSEY VOLKOV	{"email": "volkov-aleksey111968@postgrespro.ru", "phone": "+70340791057"}
0005432919586	7F9D78	4994 328702	OLEG TIKHONOV	{"email": "otikhonov.08071967@postgrespro.ru", "phone": "+70045194225"}
0005432919587	804614	1229 800291	ALEKSEY MOISEEV	{"email": "moiseeva121981@postgrespro.ru", "phone": "+70510668701"}
0005432919588	0E61CB	7011 558641	DMITRIY FOMIN	{"phone": "+70056445336"}
0005432919589	0E61CB	8311 787917	SVETLANA POTAPOVA	{"phone": "+70744984542"}
0005432919590	3D8F8F	9929 466062	NADEZHDA MEDVEDEVA	{"phone": "+70862902820"}
0005432919591	3D8F8F	7946 259218	GALINA FADEEVA	{"email": "g.fadeeva-091981@postgrespro.ru", "phone": "+70213869738"}
0005432919592	908978	1206 576777	LARISA NIKOLAEVA	{"phone": "+70557203883"}
0005432919593	908978	0177 096585	YULIYA PETROVA	{"email": "petrova-yuliya061959@postgrespro.ru", "phone": "+70924441010"}
0005432919594	43CF7C	3059 218304	POLINA EFIMOVA	{"phone": "+70392495467"}
0005432919595	0CC8E8	5619 573840	SERGEY FROLOV	{"email": "frolov.s_27111979@postgrespro.ru", "phone": "+70127340979"}
0005432919596	34D672	6410 134330	POLINA MIRONOVA	{"email": "polina.mironova_071970@postgrespro.ru", "phone": "+70055314513"}
0005432919597	2F0CE3	9270 398467	PAVEL KAZAKOV	{"phone": "+70648544267"}
0005432919598	B593EF	1443 525436	GALINA TROFIMOVA	{"email": "trofimova.g.19091972@postgrespro.ru", "phone": "+70039255844"}
0005432919599	B593EF	4015 825114	MIKHAIL NIKOLAEV	{"phone": "+70978130625"}
0005432919600	C37793	8570 848185	KARINA EGOROVA	{"email": "egorovak-12081963@postgrespro.ru", "phone": "+70920533783"}
0005432919601	EE5D0C	2051 208875	VITALIY MIRONOV	{"phone": "+70534649276"}
0005432919602	BFA84F	2133 166822	EKATERINA GRISHINA	{"phone": "+70347739341"}
0005432919603	59E1A8	9552 324715	YURIY OSIPOV	{"email": "y-osipov_1980@postgrespro.ru", "phone": "+70373380896"}
0005432919604	0D7C1D	4506 754924	MIKHAIL BARANOV	{"phone": "+70751719584"}
0005432919605	52123A	2883 665104	OLGA ZHUKOVA	{"phone": "+70120921929"}
0005432919606	A585BB	1969 755029	NIKOLAY MIRONOV	{"phone": "+70712112367"}
0005432919607	A585BB	8704 804369	KLAVDIYA BORISOVA	{"email": "k.borisova23101986@postgrespro.ru", "phone": "+70358796843"}
0005432919608	4E999B	7708 785640	TAMARA FROLOVA	{"email": "frolova-tamara23011974@postgrespro.ru", "phone": "+70899797424"}
0005432919609	4E999B	9014 084583	ARTEM FEDOTOV	{"phone": "+70215944163"}
0005432919610	81CFE1	6137 391556	VASILIY NOVIKOV	{"phone": "+70052650591"}
0005432919611	9D46CD	5643 000485	RUSLAN KARPOV	{"email": "karpov.ruslan-011974@postgrespro.ru", "phone": "+70152508547"}
0005432919612	DDAA6C	2349 025969	ANATOLIY FROLOV	{"phone": "+70219360005"}
0005432919613	8BB68B	7573 549394	ANASTASIYA OSIPOVA	{"email": "anastasiya_osipova_1973@postgrespro.ru", "phone": "+70017412602"}
0005432919614	A2F346	0820 715475	ANTON ALEKSEEV	{"email": "alekseeva.1969@postgrespro.ru", "phone": "+70906660195"}
0005432919615	A3D203	8702 267579	IRINA KOVALEVA	{"phone": "+70516951757"}
0005432919616	8098FE	6880 349133	SERGEY CHERNOV	{"phone": "+70665228140"}
0005432919617	8098FE	8943 424284	LIDIYA IVANOVA	{"email": "ivanova-l.1978@postgrespro.ru", "phone": "+70420188113"}
0005432919618	2362F8	2538 235350	ARTEM YAKOVLEV	{"email": "yakovlev.artem-1974@postgrespro.ru", "phone": "+70751995057"}
0005432919619	2362F8	6699 439453	NADEZHDA RODIONOVA	{"phone": "+70473269152"}
0005432919620	71A22D	6584 107015	MARIYA KUZNECOVA	{"email": "mariya.kuznecova_1969@postgrespro.ru", "phone": "+70446081572"}
0005432919621	1A3E9B	0949 351570	ANATOLIY FEDOROV	{"phone": "+70026467555"}
0005432919622	61361B	0274 832127	NIKOLAY ROMANOV	{"email": "n_romanov_011969@postgrespro.ru", "phone": "+70226330790"}
0005432919623	61361B	2740 375833	SERGEY ZHUKOV	{"phone": "+70783942920"}
0005432919624	61361B	2769 376063	TATYANA SMIRNOVA	{"email": "t-smirnova.10081969@postgrespro.ru", "phone": "+70755246558"}
0005432919625	11A0DD	1023 514346	EKATERINA KOMAROVA	{"phone": "+70851975167"}
0005432919626	EC3717	3696 826477	NIKITA DAVYDOV	{"phone": "+70076458799"}
0005432919627	EC3717	8451 812981	LEONID IVANOV	{"email": "ivanovl-05111976@postgrespro.ru", "phone": "+70389182034"}
0005432919628	1C0EE5	3535 052734	MARIYA NAUMOVA	{"phone": "+70672761018"}
0005432919629	7DAFBB	5658 324501	TAMARA NESTEROVA	{"phone": "+70402410274"}
0005432919630	8A2670	6200 807110	IGOR PETROV	{"email": "petrov_i-1963@postgrespro.ru", "phone": "+70820999256"}
0005432919631	5D64EB	2687 461661	DMITRIY MAKAROV	{"email": "dmitriy_makarov-121965@postgrespro.ru", "phone": "+70148097932"}
0005432919632	2B6CA4	9989 218610	YAROSLAV KUDRYASHOV	{"email": "kudryashov.yaroslav_05101974@postgrespro.ru", "phone": "+70214294646"}
0005432919633	3C167A	8662 365004	ALEKSANDR IVANOV	{"email": "a.ivanov_09121970@postgrespro.ru", "phone": "+70033929037"}
0005432919635	189E8E	9437 336773	LIDIYA TIKHONOVA	{"email": "tikhonoval_24031965@postgrespro.ru", "phone": "+70399763932"}
0005432919636	189E8E	3785 672408	IRINA RYABOVA	{"phone": "+70540134243"}
0005432919637	479C51	0373 130414	NIKOLAY ANDREEV	{"email": "andreev.nikolay1968@postgrespro.ru", "phone": "+70729370774"}
0005432919638	719E7E	9591 541321	ALEKSEY GORBUNOV	{"phone": "+70491730058"}
0005432919639	2DB05F	7647 453173	DMITRIY SOLOVEV	{"email": "solovev-d-031970@postgrespro.ru", "phone": "+70513511476"}
0005432919640	2DB05F	5023 552591	LYUDMILA NIKOLAEVA	{"phone": "+70265282475"}
0005432919641	9B4C08	3991 859486	EKATERINA VOLKOVA	{"email": "volkova_ekaterina.1976@postgrespro.ru", "phone": "+70813185388"}
0005432919642	9B4C08	4422 284973	ANNA VASILEVA	{"email": "vasileva_anna021975@postgrespro.ru", "phone": "+70470104121"}
0005432919643	CA897A	4980 182197	GALINA FEDOROVA	{"email": "g_fedorova-14091973@postgrespro.ru", "phone": "+70340325620"}
0005432919644	459A78	8899 345753	MARINA SOKOLOVA	{"phone": "+70077777132"}
0005432919645	456368	3270 315480	KONSTANTIN SOROKIN	{"email": "sorokinkonstantin-061972@postgrespro.ru", "phone": "+70289940972"}
0005432919646	ABF629	3581 920032	LYUBOV KARPOVA	{"email": "l-karpova_111977@postgrespro.ru", "phone": "+70858273151"}
0005432919647	ABF629	3091 691014	NIKOLAY TIKHONOV	{"phone": "+70022921764"}
0005432919648	929B31	9447 628139	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov-31031973@postgrespro.ru", "phone": "+70705870880"}
0005432919649	EF1C73	6266 831371	NATALYA KUZNECOVA	{"phone": "+70485176248"}
0005432919650	EF1C73	2721 624363	OLGA PETROVA	{"email": "olga_petrova_11041961@postgrespro.ru", "phone": "+70772663383"}
0005432919651	EF1C73	2377 725972	LYUDMILA KRASNOVA	{"phone": "+70760157640"}
0005432919652	9ED6B4	1426 388831	VERA ISAEVA	{"email": "vera_isaeva-08081960@postgrespro.ru", "phone": "+70475375425"}
0005432919653	9ED6B4	4648 506925	LARISA TIKHONOVA	{"phone": "+70038104712"}
0005432919654	206A15	3494 209200	ALINA IVANOVA	{"email": "a.ivanova.30101963@postgrespro.ru", "phone": "+70878905194"}
0005432919655	592863	6562 577333	ALEKSANDR NIKITIN	{"email": "a.nikitin_1971@postgrespro.ru", "phone": "+70252414150"}
0005432919656	060F8E	4557 735921	GULIYA MELNIKOVA	{"phone": "+70388791010"}
0005432919657	060F8E	2934 581118	VALERIY BONDARENKO	{"email": "bondarenko-v.041970@postgrespro.ru", "phone": "+70844155625"}
0005432919658	D55262	5877 532864	YULIYA GRISHINA	{"email": "yuliyagrishina_1979@postgrespro.ru", "phone": "+70140146163"}
0005432919659	1BE729	3276 023020	TIMOFEY YAKOVLEV	{"email": "yakovlev_t_031970@postgrespro.ru", "phone": "+70184372665"}
0005432919660	8D6A13	4818 017306	ALINA ZAYCEVA	{"phone": "+70400555907"}
0005432919661	2DDA85	9526 282124	VITALIY POPOV	{"email": "popov-vitaliy-1969@postgrespro.ru", "phone": "+70858353593"}
0005432919662	BEA5B5	7397 928943	TATYANA NESTEROVA	{"phone": "+70675453643"}
0005432919663	BEA5B5	6280 171038	VLADIMIR KAZAKOV	{"phone": "+70442735250"}
0005432919664	BEA5B5	9187 406795	EKATERINA MATVEEVA	{"email": "ekaterinamatveeva.25011960@postgrespro.ru", "phone": "+70368756095"}
0005432919665	4E9D47	3585 794760	ELENA KONDRATEVA	{"phone": "+70051997982"}
0005432919666	4E9D47	3603 749734	NATALYA VASILEVA	{"email": "vasileva.n06121970@postgrespro.ru", "phone": "+70441180321"}
0005432919667	FD60AB	5449 613700	DMITRIY BORISOV	{"phone": "+70599804320"}
0005432919668	863B01	9301 925711	SANIYA MIRONOVA	{"phone": "+70809017183"}
0005432919669	CD22F9	0641 598662	LYUBOV VLASOVA	{"phone": "+70064303652"}
0005432919670	1C1FAD	5563 109904	NIKOLAY PAVLOV	{"email": "nikolaypavlov.021973@postgrespro.ru", "phone": "+70136870728"}
0005432919671	B9A9F6	4707 484408	FILIPP SCHERBAKOV	{"email": "scherbakov-filipp-1989@postgrespro.ru", "phone": "+70986946252"}
0005432919672	488764	1760 349603	LARISA MALYSHEVA	{"email": "malysheva_l.1975@postgrespro.ru", "phone": "+70827855497"}
0005432919673	68A3B6	8626 541796	VLADIMIR RODIONOV	{"email": "vladimir.rodionov_061964@postgrespro.ru", "phone": "+70987819065"}
0005432919674	68A3B6	5033 216126	IRINA TIMOFEEVA	{"email": "timofeeva.irina.121980@postgrespro.ru", "phone": "+70128303816"}
0005432919675	AA5F38	0430 800511	DMITRIY KONOVALOV	{"phone": "+70936098548"}
0005432919676	37D330	9932 293932	ALEKSANDR SMIRNOV	{"phone": "+70955461552"}
0005432919677	37D330	2752 429195	IRINA FEDOROVA	{"email": "irina.fedorova-1989@postgrespro.ru", "phone": "+70830987402"}
0005432919678	0F687A	5426 770337	ANATOLIY SCHERBAKOV	{"email": "anatoliy.scherbakov-1975@postgrespro.ru", "phone": "+70927013705"}
0005432919679	0F687A	1014 347951	NADEZHDA TROFIMOVA	{"email": "n.trofimova-1979@postgrespro.ru", "phone": "+70072697156"}
0005432919680	A2D25F	2413 995725	KSENIYA DENISOVA	{"phone": "+70451081040"}
0005432919681	A2D25F	9490 767958	GALINA TARASOVA	{"email": "g_tarasova-111968@postgrespro.ru", "phone": "+70760597862"}
0005432919682	FF947A	7506 001215	NINA CHERNOVA	{"phone": "+70468514337"}
0005432919683	879F1F	2494 920844	VALENTINA LUKYANOVA	{"phone": "+70503404636"}
0005432919684	43FD79	9438 007884	IGOR FROLOV	{"email": "frolov-igor_051963@postgrespro.ru", "phone": "+70848709677"}
0005432919685	E65E5F	3608 263373	ELENA PAVLOVA	{"phone": "+70920435906"}
0005432919686	41181F	4031 694613	TATYANA RODIONOVA	{"email": "t-rodionova.021977@postgrespro.ru", "phone": "+70764218178"}
0005432919687	4B301B	0264 033148	MIKHAIL ZHURAVLEV	{"phone": "+70186387508"}
0005432919688	1E12E6	6435 299263	MAKSIM SMIRNOV	{"email": "smirnov-maksim_05041974@postgrespro.ru", "phone": "+70054176287"}
0005432919689	086E84	5476 832770	ZOYA AKIMOVA	{"phone": "+70707296227"}
0005432919690	A8FDDE	6562 923322	PAVEL NAUMOV	{"email": "naumov-p.06071975@postgrespro.ru", "phone": "+70627098966"}
0005432919691	A8FDDE	9042 921417	NATALIYA LAZAREVA	{"email": "lazarevan_11031977@postgrespro.ru", "phone": "+70192526731"}
0005432919692	2E4728	5276 780114	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva021979@postgrespro.ru", "phone": "+70129318952"}
0005432919693	B75F95	7907 094919	ALEKSANDR ALEKSEEV	{"email": "a-alekseev_16121967@postgrespro.ru", "phone": "+70191288280"}
0005432919694	DB080F	5522 299201	VLADIMIR FEDOROV	{"email": "fedorovv.1983@postgrespro.ru", "phone": "+70778906490"}
0005432919695	2817E9	8016 619068	RAISA STEPANOVA	{"phone": "+70823900973"}
0005432919696	2817E9	1003 699003	VALENTINA KOZLOVA	{"phone": "+70743890237"}
0005432919697	B66B99	4893 889698	ALEKSANDRA ANDREEVA	{"phone": "+70716802936"}
0005432919698	98CD5F	6856 778995	SVETLANA ORLOVA	{"email": "svetlana-orlova.051970@postgrespro.ru", "phone": "+70975182947"}
0005432919699	83460E	4024 955590	ARTEM KUZNECOV	{"email": "a_kuznecov-13051968@postgrespro.ru", "phone": "+70909562644"}
0005432919700	83460E	2694 639896	VLADIMIR NIKOLAEV	{"email": "nikolaev-v_1978@postgrespro.ru", "phone": "+70957598738"}
0005432919701	F9FEA7	0814 865676	PAVEL ZHURAVLEV	{"phone": "+70461965439"}
0005432919702	F9FEA7	7607 046083	GENNADIY MOROZOV	{"phone": "+70386981137"}
0005432919703	5F6426	4507 949194	NATALYA MIKHAYLOVA	{"phone": "+70771882247"}
0005432919704	BEDEC9	6091 119369	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev-121962@postgrespro.ru", "phone": "+70960388662"}
0005432919705	E9DD36	4005 018343	VALENTINA NOVIKOVA	{"email": "v.novikova.03051981@postgrespro.ru", "phone": "+70379888408"}
0005432919706	71552A	3597 851266	TATYANA GAVRILOVA	{"email": "gavrilovatatyana-1969@postgrespro.ru", "phone": "+70249386513"}
0005432919707	46A3CA	2834 972022	ALEKSEY MAKSIMOV	{"email": "amaksimov-1982@postgrespro.ru", "phone": "+70570901104"}
0005432919708	8D8458	3876 938009	VLADIMIR ALEKSEEV	{"email": "valekseev-01021978@postgrespro.ru", "phone": "+70871362279"}
0005432919709	5566AA	7625 069617	LARISA NESTEROVA	{"phone": "+70307875212"}
0005432919710	9C178D	8608 248085	OLGA IVANOVA	{"phone": "+70113891667"}
0005432919711	9C178D	8881 077143	VLADIMIR AFANASEV	{"phone": "+70390136704"}
0005432919712	65D781	4720 225716	DENIS OSIPOV	{"email": "denis_osipov061989@postgrespro.ru", "phone": "+70340241468"}
0005432919713	5C874B	8914 232200	DMITRIY MEDVEDEV	{"phone": "+70012642091"}
0005432919714	513E0C	0757 625579	ALEKSANDR IVANOV	{"email": "a.ivanov1960@postgrespro.ru", "phone": "+70069818017"}
0005432919715	513E0C	3077 352315	PAVEL KUZNECOV	{"email": "pavel_kuznecov_25101983@postgrespro.ru", "phone": "+70431097384"}
0005432919716	555BE4	1435 768970	VALERIY KOROLEV	{"phone": "+70694357055"}
0005432919717	8BFA37	6594 988589	IRINA LAZAREVA	{"email": "ilazareva_25041980@postgrespro.ru", "phone": "+70235045199"}
0005432919718	20CDEC	9896 457528	MARIYA MOROZOVA	{"phone": "+70732191957"}
0005432919719	31FC42	1668 117700	VERA POPOVA	{"phone": "+70086818849"}
0005432919720	BC1587	7563 530274	YAN FILIPPOV	{"phone": "+70636377707"}
0005432919721	081BFC	9459 663794	NIKOLAY ANDREEV	{"email": "andreev.n1979@postgrespro.ru", "phone": "+70674057521"}
0005432919722	A89AB7	1076 969244	BORIS SEMENOV	{"email": "semenov.boris_1967@postgrespro.ru", "phone": "+70124650080"}
0005432919723	A89AB7	8025 943710	GALINA KULIKOVA	{"email": "kulikova.g09031973@postgrespro.ru", "phone": "+70993013102"}
0005432919724	083B42	1791 544209	NIKOLAY VOLKOV	{"email": "n.volkov_031979@postgrespro.ru", "phone": "+70438108237"}
0005432919725	C1CE4B	4092 117495	VLADIMIR ZHUKOV	{"email": "vladimir-zhukov.1981@postgrespro.ru", "phone": "+70317791446"}
0005432919726	E49CB0	5383 969940	ELENA FROLOVA	{"email": "e-frolova.22051976@postgrespro.ru", "phone": "+70793482860"}
0005432919727	E49CB0	7691 430578	ALEKSANDR IVANOV	{"email": "ivanova_1953@postgrespro.ru", "phone": "+70023028466"}
0005432919728	7FC0FB	1873 270489	VALENTINA ZAKHAROVA	{"email": "v-zakharova_1971@postgrespro.ru", "phone": "+70735344376"}
0005432919729	692DCD	3212 255161	EKATERINA TITOVA	{"email": "titova_e-061977@postgrespro.ru", "phone": "+70485097120"}
0005432919730	692DCD	7120 394632	VIKTORIYA MAKSIMOVA	{"email": "v.maksimova-011970@postgrespro.ru", "phone": "+70893931332"}
0005432919731	921635	8254 050306	YURIY SERGEEV	{"email": "yuriy_sergeev.031981@postgrespro.ru", "phone": "+70118039015"}
0005432919732	AC1FF8	9777 363293	NINA ZAYCEVA	{"email": "n-zayceva-1982@postgrespro.ru", "phone": "+70653491281"}
0005432919733	31A390	6350 732497	TATYANA EGOROVA	{"phone": "+70901029765"}
0005432919734	B9CD68	6960 658798	NIKOLAY KULIKOV	{"phone": "+70447745271"}
0005432919735	7638EE	3375 607014	DENIS SMIRNOV	{"email": "smirnovd05121982@postgrespro.ru", "phone": "+70327092040"}
0005432919736	EEE962	8715 197693	ANASTASIYA MELNIKOVA	{"email": "a-melnikova-1967@postgrespro.ru", "phone": "+70245890707"}
0005432919737	EEE962	1330 626560	SERGEY YAKOVLEV	{"phone": "+70281772880"}
0005432919738	FAD3D6	9774 872210	NIKOLAY SHEVCHENKO	{"phone": "+70774422361"}
0005432919739	8E6FCD	9655 735366	ANASTASIYA GAVRILOVA	{"phone": "+70706040926"}
0005432919740	8ADB22	0321 211264	SERGEY VASILEV	{"email": "s_vasilev.1975@postgrespro.ru", "phone": "+70071757990"}
0005432919741	890D6D	3703 339520	KRISTINA RODIONOVA	{"phone": "+70896837966"}
0005432919742	890D6D	7790 846379	NIKOLAY KOZLOV	{"email": "n.kozlov21051979@postgrespro.ru", "phone": "+70199258694"}
0005432919743	890D6D	4598 729690	NATALYA FADEEVA	{"email": "fadeevanatalya10081967@postgrespro.ru", "phone": "+70689723634"}
0005432919744	9D40D2	3489 563002	MARIYA GORBUNOVA	{"phone": "+70787906540"}
0005432919745	2B60F6	3452 771163	PETR MAKAROV	{"email": "makarov.p09021982@postgrespro.ru", "phone": "+70699410070"}
0005432919746	6DAEA2	4446 788689	DMITRIY SMIRNOV	{"phone": "+70775269146"}
0005432919747	6DAEA2	5285 195364	LYUDMILA KONOVALOVA	{"email": "konovalovalyudmila.111980@postgrespro.ru", "phone": "+70331147268"}
0005432919748	5D8929	4107 129496	GENNADIY KOZLOV	{"phone": "+70450274483"}
0005432919749	5D8929	5324 036925	ELIZAVETA IVANOVA	{"email": "elizaveta.ivanova-12061980@postgrespro.ru", "phone": "+70653043755"}
0005432919750	F6BD52	2941 978256	MARINA EFIMOVA	{"email": "efimova-marina-18041979@postgrespro.ru", "phone": "+70191979843"}
0005432919751	F6BD52	1980 901676	NATALYA MAKAROVA	{"email": "n.makarova.1971@postgrespro.ru", "phone": "+70364552592"}
0005432919752	75B94B	5795 422447	LYUBOV VOROBEVA	{"email": "lyubovvorobeva.07101972@postgrespro.ru", "phone": "+70125472468"}
0005432919753	75B94B	6185 689675	DMITRIY KOROLEV	{"phone": "+70490005125"}
0005432919754	8B676F	6092 613561	NINA ALEKSANDROVA	{"phone": "+70235098383"}
0005432919755	8B676F	4357 677609	IRINA GORBUNOVA	{"phone": "+70805966042"}
0005432919756	9CCC4A	4568 371910	TATYANA ANDREEVA	{"phone": "+70465842891"}
0005432919757	34EF94	0188 430074	LILIYA TIKHONOVA	{"email": "l-tikhonova.081973@postgrespro.ru", "phone": "+70797339400"}
0005432919758	34EF94	8398 015647	TALGAT MAKAROV	{"email": "makarov-talgat.1975@postgrespro.ru", "phone": "+70244762752"}
0005432919759	F44D02	8413 051514	IVAN ZHUKOV	{"phone": "+70032148768"}
0005432919760	8E4040	9714 403813	VERA PETROVA	{"email": "v_petrova30041971@postgrespro.ru", "phone": "+70434734717"}
0005432919761	4C79F0	2116 221780	ANTONINA KARPOVA	{"phone": "+70593615654"}
0005432919762	4C79F0	5694 779952	ANTON KRASNOV	{"phone": "+70648921835"}
0005432919763	C29709	2669 107345	MIKHAIL FEDOROV	{"email": "m-fedorov081963@postgrespro.ru", "phone": "+70152861092"}
0005432919764	603A0E	0213 800621	KHALIDA ILINA	{"phone": "+70028934412"}
0005432919765	F5FA80	8931 017836	ALEKSANDR FROLOV	{"phone": "+70912170631"}
0005432919766	A6F521	8513 101973	ELENA ALEKSANDROVA	{"email": "aleksandrovae.061970@postgrespro.ru", "phone": "+70585730371"}
0005432919767	4558EA	4373 687480	DANILA YAKOVLEV	{"email": "yakovlev_d04111971@postgrespro.ru", "phone": "+70925742488"}
0005432919768	E1D27D	2609 753968	ROMAN KUZMIN	{"email": "roman_kuzmin_07041976@postgrespro.ru", "phone": "+70907610102"}
0005432919769	A19A29	0564 075285	MARIYA DAVYDOVA	{"phone": "+70635150371"}
0005432919770	9EF3BB	8800 060098	PAVEL ORLOV	{"email": "orlov_p1958@postgrespro.ru", "phone": "+70411948811"}
0005432919771	172BEB	2888 497806	VLADIMIR PETROV	{"phone": "+70285555539"}
0005432919772	0B1F3D	3498 661113	SERGEY KISELEV	{"phone": "+70863892576"}
0005432919773	0B1F3D	1002 380616	IGOR VLASOV	{"phone": "+70248932586"}
0005432919774	F7B241	7415 455881	ANNA NESTEROVA	{"phone": "+70168017127"}
0005432919775	F7B241	4438 996098	LYUDMILA RYABOVA	{"email": "lyudmila.ryabova_25071970@postgrespro.ru", "phone": "+70644033202"}
0005432919776	5CB5DB	7125 175902	VALERIY SAVELEV	{"email": "vsavelev_1980@postgrespro.ru", "phone": "+70986586544"}
0005432919777	0AAFAE	8914 812461	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila-1966@postgrespro.ru", "phone": "+70740069014"}
0005432919778	0AAFAE	8001 522524	ALEKSANDR SHEVCHENKO	{"phone": "+70809374806"}
0005432919779	40E0AD	0997 177524	ELENA PAVLOVA	{"phone": "+70834158493"}
0005432919780	168C89	5567 078203	SVETLANA DANILOVA	{"phone": "+70319259824"}
0005432919781	B0C8BC	6455 908559	NADEZHDA KONDRATEVA	{"email": "kondratevan_021986@postgrespro.ru", "phone": "+70875551687"}
0005432919782	B0C8BC	0432 959990	VIKTOR KUZNECOV	{"email": "kuznecov-viktor_051969@postgrespro.ru", "phone": "+70742598809"}
0005432919783	178080	5469 906013	ANDREY FROLOV	{"phone": "+70322419739"}
0005432919784	178080	4429 644651	ANTON KUZNECOV	{"email": "kuznecova24071978@postgrespro.ru", "phone": "+70710191972"}
0005432919785	E6F246	7173 856643	MAKSIM KUZNECOV	{"phone": "+70099323308"}
0005432919786	930AAA	4075 329107	ALEKSANDR BARANOV	{"phone": "+70562088671"}
0005432919787	D91064	3728 872828	NATALYA ROMANOVA	{"email": "natalya.romanova_061966@postgrespro.ru", "phone": "+70154744778"}
0005432919788	837703	2165 458957	MARINA NIKIFOROVA	{"phone": "+70686866409"}
0005432919789	43D0A2	3939 565402	ALEKSEY KAZAKOV	{"email": "alekseykazakov-041978@postgrespro.ru", "phone": "+70170353309"}
0005432919790	6DB38F	0181 088818	ALEKSEY KUZMIN	{"phone": "+70048492617"}
0005432919791	6DB38F	3112 374602	VYACHESLAV NIKITIN	{"email": "vyacheslavnikitin_23041963@postgrespro.ru", "phone": "+70020923578"}
0005432919792	6DB38F	9196 939248	KRISTINA ZAKHAROVA	{"email": "k.zakharova_1961@postgrespro.ru", "phone": "+70076023388"}
0005432919793	D527D2	7164 298164	IRINA NOVIKOVA	{"email": "novikova-i.30081974@postgrespro.ru", "phone": "+70986962911"}
0005432919794	072349	9985 393470	VERONIKA MASLOVA	{"email": "veronika.maslova_1971@postgrespro.ru", "phone": "+70109987545"}
0005432919795	137A26	7312 656295	ROMAN DENISOV	{"email": "roman.denisov.16091977@postgrespro.ru", "phone": "+70589012193"}
0005432919796	295F70	4853 226129	LYUDMILA DAVYDOVA	{"phone": "+70226527924"}
0005432919797	CDA29C	0673 156038	NATALYA MAKAROVA	{"email": "makarova_natalya_041976@postgrespro.ru", "phone": "+70726840481"}
0005432919798	CDA29C	8169 226027	KONSTANTIN FILIPPOV	{"phone": "+70998007223"}
0005432919799	93AD39	1797 594580	GENNADIY ZHUKOV	{"email": "zhukov_g_1969@postgrespro.ru", "phone": "+70439071229"}
0005432919800	93AD39	2874 359670	KLAVDIYA LUKYANOVA	{"email": "k-lukyanova-1970@postgrespro.ru", "phone": "+70029000260"}
0005432919801	ECCE1F	3136 670033	IVAN VOLKOV	{"email": "volkov-i-11021976@postgrespro.ru", "phone": "+70496065703"}
0005432919802	B4BED4	1113 223817	NADEZHDA SMIRNOVA	{"phone": "+70327239098"}
0005432919803	F08CDA	1951 696773	VALERIY POPOV	{"phone": "+70116871129"}
0005432919804	B2DCC3	5641 928753	YURIY FEDOTOV	{"phone": "+70632293682"}
0005432919805	FF734C	9003 498825	ALBERT SMIRNOV	{"phone": "+70681508853"}
0005432919806	FF734C	0532 612618	ANTON KAZAKOV	{"phone": "+70493598831"}
0005432919807	C01990	0379 089332	DANIIL PAVLOV	{"email": "d-pavlov_1984@postgrespro.ru", "phone": "+70527363308"}
0005432919808	806953	9587 818011	ANDREY VOLKOV	{"phone": "+70008446562"}
0005432919809	3BFDB8	7155 070974	NIKOLAY NIKITIN	{"phone": "+70261452174"}
0005432919810	749EFA	2003 553575	RUSLAN SMIRNOV	{"phone": "+70131346657"}
0005432919811	749EFA	9455 277495	KLAVDIYA KOVALEVA	{"email": "klavdiya-kovaleva-10081967@postgrespro.ru", "phone": "+70260857278"}
0005432919812	B9BA82	6338 865520	YANA NAZAROVA	{"phone": "+70105485604"}
0005432919813	21B17D	6771 052512	VIKTOR NOVIKOV	{"email": "v.novikov.021969@postgrespro.ru", "phone": "+70629215659"}
0005432919814	A45843	7823 183177	ANNA ROMANOVA	{"email": "romanova.a16011968@postgrespro.ru", "phone": "+70659703528"}
0005432919815	A45843	4781 601524	VIKTOR YAKOVLEV	{"email": "yakovlev_v_1977@postgrespro.ru", "phone": "+70551772030"}
0005432919816	A51D3E	7903 223245	ALEKSANDRA ALEKSEEVA	{"phone": "+70140434190"}
0005432919817	A51D3E	6090 592929	VALENTINA ZOTOVA	{"email": "zotova_valentina-01081966@postgrespro.ru", "phone": "+70163629080"}
0005432919818	A51D3E	3607 801417	ELENA ANISIMOVA	{"email": "e.anisimova_051962@postgrespro.ru", "phone": "+70190852955"}
0005432919819	9EED40	9093 209494	ALEKSEY KULIKOV	{"email": "kulikov.aleksey_10111973@postgrespro.ru", "phone": "+70293385277"}
0005432919820	9EED40	6341 343342	MARIYA EGOROVA	{"email": "mariya-egorova-1967@postgrespro.ru", "phone": "+70119647412"}
0005432919821	E5E786	8589 612352	GALINA MIKHAYLOVA	{"email": "gmikhaylova-051972@postgrespro.ru", "phone": "+70485224083"}
0005432919822	5BBEFB	6389 003913	VIKTOR SMIRNOV	{"phone": "+70366068770"}
0005432919823	C83176	0649 660261	VLADISLAV NAZAROV	{"email": "vladislav.nazarov051980@postgrespro.ru", "phone": "+70013178695"}
0005432919824	B59B7F	4097 415514	SERGEY POPOV	{"email": "s.popov_24021963@postgrespro.ru", "phone": "+70743586496"}
0005432919825	43E8F7	9124 349107	LIDIYA SEMENOVA	{"phone": "+70424121513"}
0005432919826	1CD9CE	2577 195771	IGOR ZAYCEV	{"email": "zaycev_igor28071970@postgrespro.ru", "phone": "+70177402707"}
0005432919827	1CD9CE	8010 293102	TATYANA DAVYDOVA	{"phone": "+70489745232"}
0005432919828	5C2AD2	1138 449748	ARTUR EGOROV	{"email": "artur_egorov_15051976@postgrespro.ru", "phone": "+70928382030"}
0005432919829	5C2AD2	9843 804609	GENNADIY MARTYNOV	{"phone": "+70324168151"}
0005432919830	2719BA	0294 725853	ANATOLIY ZHUKOV	{"email": "zhukovanatoliy1958@postgrespro.ru", "phone": "+70881902327"}
0005432919831	1FD73D	7536 604494	LIDIYA BELOVA	{"email": "lidiya_belova_1968@postgrespro.ru", "phone": "+70588939971"}
0005432919832	1FD73D	8599 045514	MIKHAIL SMIRNOV	{"phone": "+70013362458"}
0005432919833	0E9230	4422 130078	VLADIMIR ZHURAVLEV	{"email": "zhuravlev.v1980@postgrespro.ru", "phone": "+70590936923"}
0005432919834	E1D582	6581 065558	ANASTASIYA MOISEEVA	{"phone": "+70393281459"}
0005432920115	CE671F	2858 025677	MIKHAIL EGOROV	{"phone": "+70334786827"}
0005432919835	05E120	6234 540906	ELENA PAVLOVA	{"email": "pavlova-elena.081965@postgrespro.ru", "phone": "+70416258533"}
0005432919836	05E120	9766 664491	PAVEL NOVIKOV	{"phone": "+70454170080"}
0005432919837	E62810	3735 893461	NIKOLAY KULIKOV	{"email": "n_kulikov15041960@postgrespro.ru", "phone": "+70800387202"}
0005432919838	58DB6F	6775 210767	PETR TARASOV	{"phone": "+70650237179"}
0005432919839	58DB6F	1411 782852	ELENA MIRONOVA	{"phone": "+70467858132"}
0005432919840	A4DC0C	2506 634460	ALINA GUSEVA	{"email": "a_guseva.021972@postgrespro.ru", "phone": "+70787120031"}
0005432919841	54EF33	8532 257798	ALEKSEY BORISOV	{"email": "borisov_aleksey.041980@postgrespro.ru", "phone": "+70118249991"}
0005432919842	05DF40	5113 305315	ANDREY EGOROV	{"email": "egorov_andrey-11061964@postgrespro.ru", "phone": "+70053795250"}
0005432919843	78B1C6	0984 029667	ULYANA ZAKHAROVA	{"email": "zakharova_ulyana-01021968@postgrespro.ru", "phone": "+70299061392"}
0005432919844	07F578	3513 640528	VIKTORIYA YUDINA	{"phone": "+70627151902"}
0005432919845	84664A	9342 642289	ANASTASIYA MOISEEVA	{"email": "moiseevaa.30031975@postgrespro.ru", "phone": "+70178019816"}
0005432919846	84664A	0152 419987	VLADIMIR FEDOTOV	{"phone": "+70171550996"}
0005432919847	C5A18F	8052 241522	ANASTASIYA ROMANOVA	{"email": "romanova_a1970@postgrespro.ru", "phone": "+70818959733"}
0005432919848	B5CD78	4919 315266	ALEKSANDR ANDREEV	{"phone": "+70294797003"}
0005432919849	ED87F4	8046 806247	MARFA GUSEVA	{"email": "marfa_guseva_1975@postgrespro.ru", "phone": "+70110801092"}
0005432919850	ED87F4	8212 891098	DMITRIY ORLOV	{"phone": "+70295937617"}
0005432919851	0EDBDB	8282 761385	ROZA ANTONOVA	{"email": "antonova_roza_21071976@postgrespro.ru", "phone": "+70687016092"}
0005432919852	0EDBDB	8615 495944	NATALYA MOROZOVA	{"email": "natalya-morozova26031981@postgrespro.ru", "phone": "+70923625987"}
0005432919853	52A48D	5992 801588	LYUBOV ZAKHAROVA	{"phone": "+70091906314"}
0005432919854	D502A6	0865 897868	ZINAIDA ZHUKOVA	{"email": "zhukova_zinaida_31051957@postgrespro.ru", "phone": "+70164649912"}
0005432919855	611385	2310 218899	LYUBOV EFIMOVA	{"phone": "+70822222673"}
0005432919856	611385	7037 621632	NIKOLAY BONDARENKO	{"phone": "+70181480135"}
0005432919857	CE74D0	9219 153281	ANTON SOROKIN	{"email": "a-sorokin-1973@postgrespro.ru", "phone": "+70430522024"}
0005432919858	CE74D0	9408 114750	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr02091980@postgrespro.ru", "phone": "+70006673470"}
0005432919859	12902E	5311 130886	LYUBOV KONOVALOVA	{"phone": "+70402852361"}
0005432919860	12902E	4155 624965	GALINA NAZAROVA	{"email": "g_nazarova-021970@postgrespro.ru", "phone": "+70353289842"}
0005432919861	028E3B	6069 592333	ZHANNA STEPANOVA	{"email": "z.stepanova_1972@postgrespro.ru", "phone": "+70249087273"}
0005432919862	9005FC	3009 079559	ALEKSANDR MIRONOV	{"phone": "+70424329436"}
0005432919863	9005FC	9711 931505	VALERIY DAVYDOV	{"phone": "+70659883558"}
0005432919864	D69071	3020 338150	KSENIYA KRASNOVA	{"phone": "+70105089773"}
0005432919865	D789BF	7018 286006	TATYANA NOVIKOVA	{"phone": "+70592493840"}
0005432919866	4F4CC3	1564 116505	OLEG FOMIN	{"phone": "+70623046830"}
0005432919867	4F4CC3	7806 649794	ALEKSEY DENISOV	{"email": "a-denisov021972@postgrespro.ru", "phone": "+70489878277"}
0005432919868	FFB097	3600 416889	ALEKSEY SHEVCHENKO	{"phone": "+70720742600"}
0005432919869	FFB097	4996 476463	ALEKSEY KOROLEV	{"email": "korolev_a.111972@postgrespro.ru", "phone": "+70509558181"}
0005432919870	5C2698	6030 496595	SVETLANA GERASIMOVA	{"phone": "+70814903729"}
0005432919871	09F3C2	6787 411928	ZOYA FEDOROVA	{"email": "zoya-fedorova1968@postgrespro.ru", "phone": "+70706543663"}
0005432919872	359696	7050 372474	MARIYA TROFIMOVA	{"phone": "+70957881865"}
0005432919873	CCF61E	8990 516837	DMITRIY SMIRNOV	{"phone": "+70223537357"}
0005432919874	15D0CF	5465 789465	VIKTORIYA FEDOROVA	{"email": "viktoriya-fedorova_09101970@postgrespro.ru", "phone": "+70470518239"}
0005432919875	234ADC	8048 631361	YULIYA NOVIKOVA	{"email": "novikova-yuliya091972@postgrespro.ru", "phone": "+70633883792"}
0005432919876	A951F9	1824 764387	ALEKSANDR VLASOV	{"email": "vlasovaleksandr-21031963@postgrespro.ru", "phone": "+70213957318"}
0005432919877	A951F9	6951 664713	YULIYA MATVEEVA	{"phone": "+70850213303"}
0005432919878	17EA39	4556 461992	GLEB ALEKSEEV	{"email": "g-alekseev-1981@postgrespro.ru", "phone": "+70878532648"}
0005432919879	4BA105	5138 381151	VERA SOROKINA	{"email": "sorokina.vera-1972@postgrespro.ru", "phone": "+70145560166"}
0005432919880	4BA105	6357 140931	DANIIL MOISEEV	{"email": "d_moiseev_111967@postgrespro.ru", "phone": "+70468808911"}
0005432919881	B83DB4	6712 496152	DENIS VASILEV	{"phone": "+70251997189"}
0005432919882	B83DB4	0528 909885	ANATOLIY BELOV	{"phone": "+70916470540"}
0005432919883	5E3D74	0970 094499	VLADIMIR SIDOROV	{"email": "sidorovvladimir.1976@postgrespro.ru", "phone": "+70681427290"}
0005432919884	5E3D74	3305 316194	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova.1971@postgrespro.ru", "phone": "+70851992988"}
0005432919885	E854B7	5462 493205	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr031965@postgrespro.ru", "phone": "+70539824101"}
0005432919886	A4F986	2682 962461	TATYANA BELOVA	{"phone": "+70499715570"}
0005432919887	F76E70	7667 095188	IRINA NAZAROVA	{"email": "i.nazarova26111976@postgrespro.ru", "phone": "+70268224919"}
0005432919888	4DF476	8675 998645	GALINA MATVEEVA	{"phone": "+70874529886"}
0005432919889	10A406	6242 003915	IRINA ILINA	{"email": "i.ilina091967@postgrespro.ru", "phone": "+70733053583"}
0005432919890	10A406	8869 316373	RUSLAN GUSEV	{"phone": "+70001869366"}
0005432919891	E061B7	2640 004056	VALENTINA SOROKINA	{"email": "vsorokina.04021979@postgrespro.ru", "phone": "+70551205908"}
0005432919892	E061B7	2332 776241	VIKTOR KUZNECOV	{"email": "kuznecov.viktor20041988@postgrespro.ru", "phone": "+70844900602"}
0005432919893	67ADFD	6006 139945	ELENA DAVYDOVA	{"email": "edavydova_121960@postgrespro.ru", "phone": "+70874708451"}
0005432919894	EE2866	9776 840750	NATALYA MARTYNOVA	{"email": "natalya_martynova051973@postgrespro.ru", "phone": "+70042944540"}
0005432919895	17F7C4	0911 665177	EKATERINA VOROBEVA	{"phone": "+70569661335"}
0005432919896	C98287	5331 137633	ALEKSANDR BONDARENKO	{"phone": "+70695327881"}
0005432919897	C98287	7235 728727	ALEKSEY FEDOTOV	{"email": "fedotov.aleksey081965@postgrespro.ru", "phone": "+70307825686"}
0005432919898	F65C4F	1993 140111	OLGA SERGEEVA	{"email": "sergeevao.20011965@postgrespro.ru", "phone": "+70392183441"}
0005432919899	D0CCC4	0603 908739	IRINA ISAEVA	{"phone": "+70189661208"}
0005432919900	75A481	6643 576738	MARIYA NIKITINA	{"email": "nikitina.m_061964@postgrespro.ru", "phone": "+70463717243"}
0005432919901	80DFD6	2598 081443	VALERIY KUZMIN	{"phone": "+70924333517"}
0005432919902	25F461	4239 086551	MARIYA NESTEROVA	{"email": "m.nesterova.10061970@postgrespro.ru", "phone": "+70758068129"}
0005432919903	BABF83	4348 167323	NINA SOKOLOVA	{"phone": "+70211189061"}
0005432919904	BABF83	4378 094506	VALERIY ISAEV	{"email": "valeriyisaev_1973@postgrespro.ru", "phone": "+70039171433"}
0005432919905	4D4FD6	9825 733892	EKATERINA PETROVA	{"email": "ekaterina.petrova_1973@postgrespro.ru", "phone": "+70625191378"}
0005432919906	DBE3A2	4339 818476	LYUDMILA YAKOVLEVA	{"phone": "+70385748813"}
0005432919907	DBE3A2	6053 954435	VASILIY MELNIKOV	{"email": "vasiliy-melnikov.1989@postgrespro.ru", "phone": "+70459989587"}
0005432919908	65870F	2257 598144	OLESYA BELYAEVA	{"email": "olesyabelyaeva_22121965@postgrespro.ru", "phone": "+70387219669"}
0005432919909	13209B	3953 303151	MAYYA KULIKOVA	{"email": "kulikova-m-1970@postgrespro.ru", "phone": "+70694898833"}
0005432919910	E51ABA	7710 682343	GALINA YUDINA	{"phone": "+70450006846"}
0005432919911	4E2BA2	7268 603889	SERGEY NIKITIN	{"phone": "+70373846731"}
0005432919912	4E2BA2	4136 375980	VIKTOR NIKITIN	{"email": "nikitin-viktor-1965@postgrespro.ru", "phone": "+70344188421"}
0005432919913	4E2BA2	6425 508369	YANA DANILOVA	{"email": "danilova.y121977@postgrespro.ru", "phone": "+70931335819"}
0005432919914	2A4F2B	4388 374643	ANATOLIY SCHERBAKOV	{"email": "scherbakovanatoliy.031972@postgrespro.ru", "phone": "+70038073520"}
0005432919915	86F0D2	2602 219160	LYUBOV SMIRNOVA	{"email": "l-smirnova-1969@postgrespro.ru", "phone": "+70209922485"}
0005432919916	86F0D2	6205 637136	ELENA NIKOLAEVA	{"email": "nikolaeva-e12011969@postgrespro.ru", "phone": "+70199451361"}
0005432919917	13B6A2	2094 117493	SANIYA DANILOVA	{"phone": "+70852370149"}
0005432919918	387313	3112 626491	IRINA MAKAROVA	{"email": "irinamakarova-111974@postgrespro.ru", "phone": "+70499536829"}
0005432919919	E2E032	0818 703974	EVGENIY SCHERBAKOV	{"email": "scherbakov-e021972@postgrespro.ru", "phone": "+70486468484"}
0005432919920	708C4C	9616 832828	NATALYA ABRAMOVA	{"email": "abramovanatalya02071967@postgrespro.ru", "phone": "+70960855145"}
0005432919921	708C4C	6937 018332	MIKHAIL MOISEEV	{"phone": "+70939446925"}
0005432919922	FF2C45	9563 933087	SERGEY ZHUKOV	{"email": "sergey_zhukov051970@postgrespro.ru", "phone": "+70927021497"}
0005432919923	9B613B	7936 036010	VALENTINA VLASOVA	{"email": "valentina.vlasova_25111971@postgrespro.ru", "phone": "+70155657709"}
0005432919924	138A80	6880 932184	DARYA KULIKOVA	{"email": "d.kulikova1970@postgrespro.ru", "phone": "+70037304183"}
0005432919925	D5B1AD	9034 203112	LYUBOV ARKHIPOVA	{"phone": "+70233808172"}
0005432919926	D5B1AD	9621 246110	VLADISLAV ZAYCEV	{"phone": "+70147220019"}
0005432919927	6AD580	8754 063088	TIMOFEY KISELEV	{"phone": "+70999881154"}
0005432919928	6AD580	5440 941540	VERA FOMINA	{"email": "vera.fomina_14011977@postgrespro.ru", "phone": "+70592047219"}
0005432919929	86C99A	6277 791213	ANNA ZAYCEVA	{"email": "zayceva_a.1963@postgrespro.ru", "phone": "+70572171554"}
0005432919930	F46FEE	3292 577851	OLEG ZHURAVLEV	{"email": "o-zhuravlev041967@postgrespro.ru", "phone": "+70039371801"}
0005432919931	BEB993	5101 263303	VALERIY VOLKOV	{"email": "v_volkov.1974@postgrespro.ru", "phone": "+70040067810"}
0005432919932	2B8A61	0638 836520	NATALIYA DAVYDOVA	{"email": "nataliya.davydova-071966@postgrespro.ru", "phone": "+70954848322"}
0005432919933	461E58	2440 969873	OLGA BORISOVA	{"phone": "+70760089034"}
0005432919934	51B24F	6412 770434	TATYANA GRISHINA	{"phone": "+70708982376"}
0005432919935	AE0791	8596 423963	MARINA ZOTOVA	{"phone": "+70829002191"}
0005432919936	7AE881	8642 355003	IVAN PETROV	{"email": "petrov-ivan-071973@postgrespro.ru", "phone": "+70586756281"}
0005432919937	99F139	0999 308575	ELIZAVETA ANDREEVA	{"phone": "+70205267677"}
0005432919938	99F139	4527 187122	ANNA KONDRATEVA	{"phone": "+70290954408"}
0005432919939	24C434	9378 894762	VALENTINA POPOVA	{"email": "valentina.popova-20071982@postgrespro.ru", "phone": "+70612597599"}
0005432919940	24C434	7527 787487	VALENTINA FILIPPOVA	{"email": "valentinafilippova.121965@postgrespro.ru", "phone": "+70625092206"}
0005432919941	90B721	7733 296332	MARINA BOGDANOVA	{"email": "bogdanova.marina_14111968@postgrespro.ru", "phone": "+70340327046"}
0005432919942	90B721	6807 810155	IGOR NOVIKOV	{"phone": "+70583994153"}
0005432919943	F85F6B	5832 393567	IGOR VOROBEV	{"phone": "+70227811064"}
0005432919944	5284C0	8969 777675	ANNA GERASIMOVA	{"email": "gerasimova-a.111962@postgrespro.ru", "phone": "+70877964024"}
0005432919945	5284C0	4016 566380	SVETLANA OVCHINNIKOVA	{"phone": "+70326802392"}
0005432919946	5284C0	6122 073336	MIKHAIL ANDREEV	{"email": "m.andreev-061982@postgrespro.ru", "phone": "+70277628357"}
0005432919947	5284C0	0502 815908	VALENTINA KOROLEVA	{"phone": "+70748796168"}
0005432919948	D41BED	7132 683115	DMITRIY DMITRIEV	{"email": "dmitriy.dmitriev1957@postgrespro.ru", "phone": "+70919258318"}
0005432919949	D41BED	4816 319520	IVAN MEDVEDEV	{"phone": "+70167997668"}
0005432919950	698E49	0940 371934	ELENA VASILEVA	{"phone": "+70606179313"}
0005432919951	5BA5EC	9326 712463	VIKTORIYA IVANOVA	{"email": "ivanova.viktoriya_25051972@postgrespro.ru", "phone": "+70566601915"}
0005432919952	B12BE9	5400 316293	ALEKSANDRA SERGEEVA	{"phone": "+70436704543"}
0005432919953	F98CD2	1122 908495	ANATOLIY POPOV	{"email": "popovanatoliy-07041968@postgrespro.ru", "phone": "+70935824394"}
0005432919954	954ED2	8264 137692	IGOR NAUMOV	{"phone": "+70750705053"}
0005432919955	2F80B9	3041 929811	INGA MAKAROVA	{"email": "ingamakarova-1974@postgrespro.ru", "phone": "+70281771494"}
0005432919956	419314	2683 121421	VLADISLAV MIKHAYLOV	{"email": "mikhaylov.vladislav-06021976@postgrespro.ru", "phone": "+70425485920"}
0005432919957	414592	7812 792993	PAVEL NIKITIN	{"phone": "+70485753677"}
0005432919958	414592	4164 760375	ANNA AFANASEVA	{"phone": "+70148443078"}
0005432919959	720D0B	6611 201928	NADEZHDA SIDOROVA	{"email": "sidorova-n_22111976@postgrespro.ru", "phone": "+70183799199"}
0005432919960	C67F5E	5297 403615	FAINA IVANOVA	{"email": "ivanovafaina-1977@postgrespro.ru", "phone": "+70084060858"}
0005432919961	C67F5E	7648 319801	NATALYA VOROBEVA	{"email": "vorobeva-natalya-16031963@postgrespro.ru", "phone": "+70659831545"}
0005432919962	C1B729	3536 574278	LYUBOV KUZNECOVA	{"phone": "+70044276012"}
0005432919963	40586A	5095 669737	EKATERINA KUZMINA	{"phone": "+70285823178"}
0005432919964	FA1D66	2443 542701	NIKOLAY MAKAROV	{"phone": "+70126598758"}
0005432919965	63DADE	3626 157290	ALEKSEY BELOV	{"phone": "+70205335935"}
0005432919966	0E371D	4475 487088	PAVEL KOZLOV	{"phone": "+70247990557"}
0005432919967	640FA1	7172 557264	VLADIMIR MATVEEV	{"email": "v_matveev_1966@postgrespro.ru", "phone": "+70629885553"}
0005432919968	640FA1	8013 916660	ALBINA MATVEEVA	{"phone": "+70256487990"}
0005432919969	767F69	6977 998628	MARK STEPANOV	{"email": "stepanov.m021974@postgrespro.ru", "phone": "+70029086666"}
0005432919970	FEECDD	9902 619740	PRASKOVYA ZAKHAROVA	{"email": "zakharovapraskovya-111977@postgrespro.ru", "phone": "+70557434858"}
0005432919971	142148	6143 299598	KIRILL MOROZOV	{"phone": "+70601670710"}
0005432919972	53A05A	6584 996302	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr-061983@postgrespro.ru", "phone": "+70976952229"}
0005432919973	8BF342	5654 781747	VALENTINA MAKAROVA	{"phone": "+70821511024"}
0005432919974	19538A	8551 415534	ELENA NIKITINA	{"phone": "+70621526355"}
0005432919975	6A9879	9388 962633	VASILIY DMITRIEV	{"phone": "+70487725643"}
0005432919976	6A9879	1525 498554	POLINA TROFIMOVA	{"email": "trofimova_p1982@postgrespro.ru", "phone": "+70939767539"}
0005432919977	F9085E	3296 625401	NIKOLAY KUZNECOV	{"phone": "+70862970213"}
0005432919978	F9085E	3267 651690	IRINA OVCHINNIKOVA	{"email": "ovchinnikova.irina_21111975@postgrespro.ru", "phone": "+70607659294"}
0005432919979	51482E	3396 315900	VLADIMIR PAVLOV	{"phone": "+70506156885"}
0005432919980	A5AC24	9234 509794	DMITRIY PAVLOV	{"phone": "+70163247949"}
0005432919981	FB962A	1349 434604	NIKOLAY BORISOV	{"email": "nikolayborisov-1973@postgrespro.ru", "phone": "+70355527242"}
0005432919982	3FB8EB	0302 171280	ALLA ZOTOVA	{"phone": "+70664210196"}
0005432919983	B14270	4036 370849	LYUBOV RYABOVA	{"email": "ryabova_lyubov.1970@postgrespro.ru", "phone": "+70810098447"}
0005432919984	013EAB	3299 569530	VERA KALININA	{"phone": "+70077886571"}
0005432919985	049898	6883 866141	NINA KULIKOVA	{"email": "kulikova.nina.01031976@postgrespro.ru", "phone": "+70714966003"}
0005432919986	049898	0303 360136	NIKITA ZHUKOV	{"phone": "+70192887697"}
0005432919987	CB8324	2339 565001	YULIYA TROFIMOVA	{"phone": "+70258304000"}
0005432919988	F559A7	8264 508288	IGOR SHEVCHENKO	{"email": "shevchenko_i-1970@postgrespro.ru", "phone": "+70640652834"}
0005432919989	FC0CE1	4920 972828	MARINA MASLOVA	{"phone": "+70593950992"}
0005432919990	D4CCBF	0729 710611	ALEKSEY EGOROV	{"phone": "+70913650467"}
0005432919991	BCCFD9	3803 157000	ARSENIY MAKAROV	{"phone": "+70969230558"}
0005432919992	15926A	1845 680631	VALERIYA KOZLOVA	{"email": "kozlovavaleriya.011973@postgrespro.ru", "phone": "+70187162631"}
0005432919993	15926A	6784 970563	MARIYA KUZMINA	{"phone": "+70044416143"}
0005432919994	7FAC58	7207 760451	VYACHESLAV ZAYCEV	{"phone": "+70040829244"}
0005432919995	7FAC58	0885 342203	MARIYA KISELEVA	{"email": "kiseleva.m-17011974@postgrespro.ru", "phone": "+70834812453"}
0005432919996	ACB493	3055 328390	BORIS POPOV	{"phone": "+70409373513"}
0005432919997	ACB493	5825 821977	LYUDMILA KUDRYASHOVA	{"email": "kudryashovalyudmila1972@postgrespro.ru", "phone": "+70589596760"}
0005432919998	ACB493	7393 277422	YURIY PAVLOV	{"email": "yuriypavlov-1972@postgrespro.ru", "phone": "+70699016055"}
0005432919999	51DD5F	8886 840548	ANNA MALYSHEVA	{"email": "a_malysheva.1967@postgrespro.ru", "phone": "+70300958465"}
0005432920000	61BBE6	0753 010050	NATALYA SEMENOVA	{"email": "n.semenova1966@postgrespro.ru", "phone": "+70005574885"}
0005432920001	A43DFB	7516 563496	PAVEL BORISOV	{"phone": "+70675829570"}
0005432920002	F97859	7489 013578	ELENA MIKHAYLOVA	{"phone": "+70909029422"}
0005432920003	F97859	9810 627538	GALINA KALININA	{"email": "kalinina-g-09011975@postgrespro.ru", "phone": "+70473768091"}
0005432920004	F97859	3809 706056	SERGEY SOKOLOV	{"phone": "+70051294679"}
0005432920005	A74E15	7623 000887	ARINA MEDVEDEVA	{"phone": "+70621019601"}
0005432920006	A74E15	3589 285302	TATYANA GORBUNOVA	{"phone": "+70897932549"}
0005432920007	67C902	2842 207398	ALEKSANDR GRIGOREV	{"phone": "+70204540509"}
0005432920008	1B0E8C	6432 220868	NINA SCHERBAKOVA	{"email": "scherbakova.nina021982@postgrespro.ru", "phone": "+70085410978"}
0005432920009	F0ABE5	8653 505718	POLINA STEPANOVA	{"email": "stepanovapolina-17111970@postgrespro.ru", "phone": "+70584402585"}
0005432920010	19A43D	7374 302974	NADEZHDA LAZAREVA	{"email": "nadezhda-lazareva-041983@postgrespro.ru", "phone": "+70655101826"}
0005432920011	19A43D	5911 429025	IVAN MEDVEDEV	{"email": "imedvedev.1971@postgrespro.ru", "phone": "+70560114801"}
0005432920012	C2AF79	2125 581256	EVGENIY MOROZOV	{"phone": "+70842072044"}
0005432920013	016016	1163 292933	LIDIYA KUDRYASHOVA	{"email": "lidiyakudryashova13031978@postgrespro.ru", "phone": "+70145880905"}
0005432920014	CCFBEE	5081 766030	OLESYA STEPANOVA	{"phone": "+70558138152"}
0005432920015	16E738	0954 709349	YULIYA IVANOVA	{"email": "ivanova_y09021969@postgrespro.ru", "phone": "+70419680771"}
0005432920016	16E738	3090 271613	OLGA SMIRNOVA	{"phone": "+70454896132"}
0005432920017	D41178	4159 534135	ANTONINA NIKIFOROVA	{"email": "anikiforova.101976@postgrespro.ru", "phone": "+70554975244"}
0005432920018	081820	8381 210461	ALEKSEY NAUMOV	{"email": "aleksey_naumov.16011974@postgrespro.ru", "phone": "+70460710830"}
0005432920019	081820	1333 397859	VALERIY FROLOV	{"email": "frolov-v1971@postgrespro.ru", "phone": "+70989214703"}
0005432920020	BF5246	6831 341411	IRINA ALEKSEEVA	{"email": "irinaalekseeva-28061967@postgrespro.ru", "phone": "+70501197902"}
0005432920021	3522D0	3989 176709	YULIYA OSIPOVA	{"phone": "+70043722142"}
0005432920022	3522D0	7819 328073	ALEKSANDR PETROV	{"email": "aleksandr.petrov031977@postgrespro.ru", "phone": "+70838779333"}
0005432920023	46B74C	4127 244166	SERGEY KRASNOV	{"phone": "+70832817143"}
0005432920024	796E2F	6882 366292	VERA DMITRIEVA	{"phone": "+70811436387"}
0005432920025	6ABA6F	3634 156104	MAKSIM ZAYCEV	{"phone": "+70497588888"}
0005432920026	6ABA6F	2626 839838	YULIYA IVANOVA	{"email": "ivanova.y.28041971@postgrespro.ru", "phone": "+70422147425"}
0005432920027	AF0807	3636 207501	ELENA GRISHINA	{"phone": "+70244817185"}
0005432920028	AF0807	1733 987033	MIKHAIL EGOROV	{"email": "egorov_m.1968@postgrespro.ru", "phone": "+70005668518"}
0005432920029	2BC13C	9919 184597	ALEKSANDR NIKOLAEV	{"phone": "+70701162270"}
0005432920030	2BC13C	0781 430057	ELENA FEDOROVA	{"email": "efedorova.02121979@postgrespro.ru", "phone": "+70637682065"}
0005432920031	C37990	6194 235967	ILYA SOLOVEV	{"email": "solovev.ilya041962@postgrespro.ru", "phone": "+70433588282"}
0005432920032	9005DB	2306 869367	TAMARA DMITRIEVA	{"email": "dmitrievat_1971@postgrespro.ru", "phone": "+70799219055"}
0005432920033	3E6F7F	4533 647052	NIKOLAY AFANASEV	{"phone": "+70332819616"}
0005432920034	3E6F7F	2774 023620	ANNA IVANOVA	{"phone": "+70566702164"}
0005432920035	BB4532	0255 998467	LYUDMILA ALEKSANDROVA	{"email": "l-aleksandrova-1970@postgrespro.ru", "phone": "+70845067211"}
0005432920036	A66676	8329 220564	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev091974@postgrespro.ru", "phone": "+70213018662"}
0005432920037	A66676	3581 344440	TAMARA PAVLOVA	{"phone": "+70311251018"}
0005432920038	900ADA	0299 603864	DANIL KUZNECOV	{"email": "d.kuznecov_28011969@postgrespro.ru", "phone": "+70035072183"}
0005432920039	900ADA	8412 687210	YAN ALEKSEEV	{"phone": "+70629730836"}
0005432920040	27F7DE	4978 249708	KARINA SAVELEVA	{"phone": "+70508627653"}
0005432920041	27F7DE	7085 556524	NINA MAKAROVA	{"phone": "+70832347937"}
0005432920042	1B9490	0898 674711	LYUDMILA POLYAKOVA	{"phone": "+70831989033"}
0005432920043	B7E060	2811 740602	ALEKSEY ANTONOV	{"phone": "+70242226400"}
0005432920044	85FCB3	8466 354079	DMITRIY FEDOROV	{"email": "fedorovdmitriy_1968@postgrespro.ru", "phone": "+70644533515"}
0005432920045	6F1CF7	5661 635099	VALERIY GORBUNOV	{"phone": "+70895956608"}
0005432920046	206865	8397 953556	NINA EGOROVA	{"phone": "+70258246677"}
0005432920047	206865	1230 134313	YURIY MELNIKOV	{"email": "yuriymelnikov-13071978@postgrespro.ru", "phone": "+70262351644"}
0005432920048	16BB35	4554 952592	GENNADIY IVANOV	{"email": "ivanov_gennadiy19011976@postgrespro.ru", "phone": "+70126211096"}
0005432920049	ECF1CB	5210 490627	EVGENIY GORBUNOV	{"email": "gorbunov.evgeniy-101975@postgrespro.ru", "phone": "+70368106586"}
0005432920050	763C89	4397 678502	ALLA NIKOLAEVA	{"email": "nikolaeva.alla_09081965@postgrespro.ru", "phone": "+70222185142"}
0005432920051	763C89	2729 783503	ANDREY BELOV	{"phone": "+70269622014"}
0005432920052	AA3EDD	9864 756364	MARIYA KONOVALOVA	{"phone": "+70519317101"}
0005432920053	AA3EDD	0786 625429	DMITRIY TARASOV	{"phone": "+70707829949"}
0005432920054	FCD854	5787 997024	GALINA KOROLEVA	{"phone": "+70800883840"}
0005432920055	FCD854	1691 781855	ALLA KOROLEVA	{"phone": "+70801200668"}
0005432920056	FCD854	8393 242408	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov121960@postgrespro.ru", "phone": "+70166804410"}
0005432920057	E28F5F	8014 213676	OLEG YAKOVLEV	{"phone": "+70164939458"}
0005432920058	E28F5F	2377 855838	OLEG EGOROV	{"phone": "+70077487531"}
0005432920116	567FCC	7805 886385	ULYANA KUZNECOVA	{"phone": "+70006117464"}
0005432920059	7E9772	1777 103185	ALINA ALEKSANDROVA	{"email": "aleksandrova.alina.07031966@postgrespro.ru", "phone": "+70707324500"}
0005432920060	A1E488	7661 977698	ILMIR NIKOLAEV	{"phone": "+70271711063"}
0005432920061	A1E488	9257 381593	NATALYA PETROVA	{"phone": "+70970959121"}
0005432920062	1E6396	0518 095665	VALERIY SAVELEV	{"phone": "+70310944885"}
0005432920063	1E6396	4763 515849	ALEKSANDR KRASNOV	{"phone": "+70741982172"}
0005432920064	FA04FD	2459 687528	TATYANA MASLOVA	{"email": "tmaslova_031964@postgrespro.ru", "phone": "+70592070043"}
0005432920065	5807C1	9184 301618	ELENA BOGDANOVA	{"email": "e_bogdanova061984@postgrespro.ru", "phone": "+70101847823"}
0005432920066	98126B	5805 140442	STANISLAV DAVYDOV	{"email": "davydov-stanislav.1967@postgrespro.ru", "phone": "+70896913460"}
0005432920067	98126B	8778 714000	VALERIY KUZMIN	{"phone": "+70794741932"}
0005432920068	853C90	0584 793433	KSENIYA STEPANOVA	{"email": "stepanovakseniya.15121963@postgrespro.ru", "phone": "+70950624233"}
0005432920069	97E3F0	8090 664713	YURIY IVANOV	{"phone": "+70036828541"}
0005432920070	97E3F0	3225 556997	VALERIY MATVEEV	{"phone": "+70309188635"}
0005432920071	9E728E	4880 823899	LIDIYA OSIPOVA	{"phone": "+70991696551"}
0005432920072	29BF82	1067 622120	ARTEM DENISOV	{"phone": "+70560546213"}
0005432920073	29BF82	0106 956611	VLADIMIR BELOV	{"phone": "+70850638178"}
0005432920074	F59843	6107 056005	OLGA MAKSIMOVA	{"email": "maksimova-olga_111970@postgrespro.ru", "phone": "+70568278681"}
0005432920075	7DEBBF	9128 687765	ZINAIDA BOGDANOVA	{"phone": "+70230996038"}
0005432920076	010A46	6858 883350	ZULFIYA POLYAKOVA	{"email": "polyakova_zulfiya1969@postgrespro.ru", "phone": "+70054729149"}
0005432920077	571016	3687 865071	NADEZHDA MOISEEVA	{"email": "nadezhdamoiseeva.031982@postgrespro.ru", "phone": "+70695314674"}
0005432920078	C6C340	8399 584009	VALERIY MIRONOV	{"phone": "+70894303776"}
0005432920079	EF2095	9734 528706	RISHAT DAVYDOV	{"phone": "+70430004090"}
0005432920080	EFA3BD	8651 198158	EVGENIY BARANOV	{"phone": "+70740163624"}
0005432920081	EFA3BD	1551 982106	ANATOLIY VOLKOV	{"email": "volkovanatoliy_1978@postgrespro.ru", "phone": "+70142980113"}
0005432920083	BEEFF1	4805 365827	VALENTINA EFIMOVA	{"email": "efimovav_021976@postgrespro.ru", "phone": "+70645136791"}
0005432920084	CE73EE	0055 351611	NINA ILINA	{"email": "nina-ilina.1977@postgrespro.ru", "phone": "+70063858796"}
0005432920085	A869F6	5734 478025	YURIY SCHERBAKOV	{"phone": "+70991281021"}
0005432920086	A869F6	7857 312591	OLGA POPOVA	{"phone": "+70004107866"}
0005432920087	F04FC7	5896 119167	OKSANA FROLOVA	{"email": "frolovaoksana30101963@postgrespro.ru", "phone": "+70019815802"}
0005432920088	B509F8	0547 611537	NADEZHDA MARTYNOVA	{"phone": "+70694392315"}
0005432920089	D9CF3C	8750 864112	OLEG FROLOV	{"email": "o-frolov.09011974@postgrespro.ru", "phone": "+70136020788"}
0005432920090	D9CF3C	5288 858785	OLGA CHERNOVA	{"email": "o.chernova.091965@postgrespro.ru", "phone": "+70427851224"}
0005432920091	8040BB	1796 070368	SERGEY ROMANOV	{"email": "romanovs1974@postgrespro.ru", "phone": "+70199840711"}
0005432920092	0A69FA	2276 072574	DENIS DENISOV	{"email": "denis_denisov-1981@postgrespro.ru", "phone": "+70546835749"}
0005432920093	D55267	0119 554157	SERGEY FEDOTOV	{"phone": "+70370173836"}
0005432920094	D55267	4515 582035	IGOR POPOV	{"email": "popovi_22011963@postgrespro.ru", "phone": "+70143917362"}
0005432920095	8C8535	7342 746042	ALEKSANDR STEPANOV	{"email": "astepanov.14081976@postgrespro.ru", "phone": "+70884665166"}
0005432920096	CC411B	0376 457521	YANA MIKHAYLOVA	{"phone": "+70002430858"}
0005432920097	CC411B	4407 212871	TATYANA NIKOLAEVA	{"phone": "+70334971622"}
0005432920098	4257B7	7529 400288	SERGEY VASILEV	{"email": "vasilev_s.091965@postgrespro.ru", "phone": "+70695705746"}
0005432920099	99D188	1889 240022	KIRILL FOMIN	{"email": "kirill_fomin09011974@postgrespro.ru", "phone": "+70743503584"}
0005432920100	99D188	1872 042581	VALENTINA KOZLOVA	{"email": "valentina_kozlova_13021969@postgrespro.ru", "phone": "+70924883133"}
0005432920101	D810BA	3565 377548	VLADIMIR BONDARENKO	{"email": "v_bondarenko-011964@postgrespro.ru", "phone": "+70069334718"}
0005432920102	D810BA	2174 953947	TAMARA NESTEROVA	{"email": "tamara-nesterova.16031965@postgrespro.ru", "phone": "+70844672583"}
0005432920103	D810BA	4570 959449	ZINAIDA EFIMOVA	{"phone": "+70025248769"}
0005432920104	5113F8	4927 158590	VENERA SOLOVEVA	{"phone": "+70805352113"}
0005432920105	5B737D	7413 200536	ELENA KUZNECOVA	{"phone": "+70515935927"}
0005432920106	14140D	1655 405973	TATYANA MOISEEVA	{"email": "t-moiseeva_1966@postgrespro.ru", "phone": "+70944357948"}
0005432920107	AD46EC	7845 511681	YURIY POPOV	{"phone": "+70557522781"}
0005432920108	9F0FC4	5224 143945	ALEKSANDRA FOMINA	{"phone": "+70721650221"}
0005432920109	328EF9	0890 776101	ALEKSANDR SOKOLOV	{"phone": "+70653944971"}
0005432920110	328EF9	6526 049329	PELAGEYA PETROVA	{"phone": "+70266030570"}
0005432920111	A11BB6	2607 001985	ALEKSEY BONDARENKO	{"email": "bondarenko.a.20011974@postgrespro.ru", "phone": "+70852319067"}
0005432920112	A11BB6	4684 345487	YULIYA GORBUNOVA	{"phone": "+70447480220"}
0005432920113	A11BB6	6922 042983	ALEKSANDRA KRASNOVA	{"email": "krasnovaa_1971@postgrespro.ru", "phone": "+70044953957"}
0005432920114	CE671F	7151 667865	ALEKSANDR GAVRILOV	{"email": "gavrilov_a-11051976@postgrespro.ru", "phone": "+70326902654"}
0005432920117	5D07B2	5426 712657	VALENTINA VASILEVA	{"email": "valentina-vasileva1971@postgrespro.ru", "phone": "+70945289256"}
0005432920118	5D07B2	4590 551791	DANIIL DMITRIEV	{"email": "daniil-dmitriev.091977@postgrespro.ru", "phone": "+70408466662"}
0005432920119	5D07B2	4948 075324	VYACHESLAV IVANOV	{"email": "ivanovv_1968@postgrespro.ru", "phone": "+70532561812"}
0005432920120	8B0BBB	2056 064063	KSENIYA ROMANOVA	{"phone": "+70867437912"}
0005432920121	8B0BBB	7485 455043	ANDREY GAVRILOV	{"email": "gavrilova.07121976@postgrespro.ru", "phone": "+70378352407"}
0005432920122	F12E32	3612 942996	LIDIYA MELNIKOVA	{"phone": "+70499387684"}
0005432920123	F12E32	1113 415998	STEPAN ZAYCEV	{"phone": "+70169035969"}
0005432920124	D80008	6803 295491	VLADIMIR POPOV	{"email": "v-popov21111975@postgrespro.ru", "phone": "+70394911427"}
0005432920125	BD1BE1	5402 913877	TATYANA MEDVEDEVA	{"phone": "+70038068150"}
0005432920126	84FEDA	1871 372303	IRINA KOZLOVA	{"email": "kozlovairina-111960@postgrespro.ru", "phone": "+70885664326"}
0005432920127	BB62CB	8304 394217	DMITRIY EGOROV	{"phone": "+70589031290"}
0005432920128	6BD69C	0747 830305	SERGEY FEDOTOV	{"phone": "+70693128327"}
0005432920129	6BD69C	8100 855732	NATALYA BELOVA	{"email": "belova.natalya-021981@postgrespro.ru", "phone": "+70023252630"}
0005432920130	FC0D45	5594 765479	SVETLANA MOROZOVA	{"email": "morozova-svetlana19041976@postgrespro.ru", "phone": "+70742156973"}
0005432920131	FC0D45	4261 214197	TAMARA CHERNOVA	{"email": "chernovatamara_061971@postgrespro.ru", "phone": "+70480973433"}
0005432920132	BF17A0	0069 654846	VALERIY VOROBEV	{"phone": "+70739265882"}
0005432920133	510CD0	3990 179025	EVGENIY MAKAROV	{"email": "evgeniymakarov.28041972@postgrespro.ru", "phone": "+70013049408"}
0005432920134	973147	8410 794036	NATALYA FOMINA	{"phone": "+70274218909"}
0005432920135	973147	4875 446837	ANNA KUZNECOVA	{"email": "annakuznecova.031968@postgrespro.ru", "phone": "+70581551216"}
0005432920136	973147	0273 874610	ELENA ZHURAVLEVA	{"email": "zhuravlevaelena021986@postgrespro.ru", "phone": "+70533430823"}
0005432920137	7435B3	6235 311945	VADIM MELNIKOV	{"phone": "+70827179862"}
0005432920138	7435B3	5633 036630	ALENA MIRONOVA	{"email": "alena-mironova.061981@postgrespro.ru", "phone": "+70821671560"}
0005432920139	D60D17	4977 934440	ALEKSANDR MIRONOV	{"email": "aleksandr-mironov.08031976@postgrespro.ru", "phone": "+70468468100"}
0005432920140	D60D17	2538 735666	ANDREY KISELEV	{"phone": "+70671401109"}
0005432920141	82DBC1	3900 959163	FAINA KRASNOVA	{"email": "krasnovaf.15051971@postgrespro.ru", "phone": "+70595476492"}
0005432920142	28F9DF	0379 695617	MIKHAIL MIRONOV	{"email": "m-mironov.24071972@postgrespro.ru", "phone": "+70556617212"}
0005432920143	28F9DF	6284 991677	NADEZHDA STEPANOVA	{"email": "stepanovanadezhda-19031982@postgrespro.ru", "phone": "+70978308814"}
0005432920144	81DB76	4847 729796	ELENA KUZMINA	{"phone": "+70098331973"}
0005432920145	81DB76	5329 854964	YURIY NOVIKOV	{"email": "novikovyuriy_07121981@postgrespro.ru", "phone": "+70021489824"}
0005432920146	C5AA67	8904 012395	IVAN AFANASEV	{"phone": "+70616883272"}
0005432920147	143437	9636 595695	TAISIYA ZAKHAROVA	{"email": "zakharova-taisiya1975@postgrespro.ru", "phone": "+70014871705"}
0005432920148	143437	9509 061284	VALENTINA LOGINOVA	{"email": "loginova_valentina.081974@postgrespro.ru", "phone": "+70293771102"}
0005432920149	143437	2337 596774	EVGENIY NIKOLAEV	{"phone": "+70635554777"}
0005432920150	0DC340	7431 643120	IGOR ISAEV	{"email": "isaevigor_1975@postgrespro.ru", "phone": "+70242097457"}
0005432920151	423F08	2971 368734	MAKSIM NIKOLAEV	{"email": "nikolaevmaksim-051974@postgrespro.ru", "phone": "+70621516309"}
0005432920152	16EB8A	6635 295247	IRINA KONDRATEVA	{"email": "ikondrateva04071963@postgrespro.ru", "phone": "+70324069889"}
0005432920153	84B18E	7846 492232	NATALYA FEDOROVA	{"phone": "+70194125393"}
0005432920154	84B18E	1233 306561	TATYANA SAVELEVA	{"email": "saveleva-t_16101986@postgrespro.ru", "phone": "+70184479343"}
0005432920155	C81290	2541 921186	LYUBOV DMITRIEVA	{"email": "ldmitrieva.1984@postgrespro.ru", "phone": "+70288011502"}
0005432920156	C81290	4489 961167	IRINA GERASIMOVA	{"email": "gerasimova-i_1966@postgrespro.ru", "phone": "+70327860878"}
0005432920157	9BA602	8878 619307	RUSLAN IVANOV	{"phone": "+70623673566"}
0005432920158	7B01E5	1230 332394	OLGA KUZNECOVA	{"email": "o_kuznecova081981@postgrespro.ru", "phone": "+70310955182"}
0005432920159	B498F1	4780 794790	SERGEY EGOROV	{"email": "egorov.sergey.1985@postgrespro.ru", "phone": "+70975246852"}
0005432920160	B498F1	8910 209127	ANNA KOZLOVA	{"email": "anna_kozlova-09031965@postgrespro.ru", "phone": "+70088349791"}
0005432920161	15AE45	4774 925539	ALEKSANDR KUZNECOV	{"phone": "+70449278604"}
0005432920162	15AE45	6292 322569	LILIYA BORISOVA	{"email": "borisova_liliya_091983@postgrespro.ru", "phone": "+70171599038"}
0005432920163	D5F4E5	2710 417912	EKATERINA LAZAREVA	{"email": "lazarevae_04031973@postgrespro.ru", "phone": "+70769523524"}
0005432920164	F289EF	0971 493378	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana.061967@postgrespro.ru", "phone": "+70868759316"}
0005432920165	F289EF	4388 675323	EKATERINA DAVYDOVA	{"email": "davydova_ekaterina-061980@postgrespro.ru", "phone": "+70402499340"}
0005432920166	6B1898	3134 451397	EKATERINA MAKSIMOVA	{"phone": "+70353495935"}
0005432920167	9B9C68	5021 205863	EGOR ZAYCEV	{"phone": "+70993439901"}
0005432920168	932E7B	9550 785013	VALENTINA VOLKOVA	{"phone": "+70182751555"}
0005432920169	621BA3	0077 277452	ALINA SIDOROVA	{"phone": "+70434450982"}
0005432920170	FF3C33	1351 060079	DARYA PAVLOVA	{"phone": "+70316798176"}
0005432920171	FF3C33	0195 234385	ZOYA KUZNECOVA	{"email": "kuznecova_z.02031979@postgrespro.ru", "phone": "+70103067741"}
0005432920172	94F186	0433 376825	SERGEY EGOROV	{"email": "sergeyegorov_1970@postgrespro.ru", "phone": "+70131335246"}
0005432920173	94F186	7594 044507	ELENA ILINA	{"phone": "+70020303645"}
0005432920174	94F186	0000 293315	VIKTOR GRIGOREV	{"phone": "+70586015990"}
0005432920175	3333EA	4978 056471	SERGEY EGOROV	{"email": "sergey_egorov_1977@postgrespro.ru", "phone": "+70997403062"}
0005432920176	3333EA	9112 742633	OLEG ANTONOV	{"phone": "+70799509777"}
0005432920177	FB49C7	0426 122301	KRISTINA ALEKSEEVA	{"phone": "+70519450854"}
0005432920178	227844	7452 417560	OLEG ISAEV	{"email": "isaev_oleg-101978@postgrespro.ru", "phone": "+70305961977"}
0005432920179	547768	2736 859354	NIKOLAY NIKOLAEV	{"email": "nikolaev.n-1961@postgrespro.ru", "phone": "+70912632217"}
0005432920180	D557A6	6723 889564	SOFYA GORBUNOVA	{"phone": "+70900302553"}
0005432920181	94E0A6	1811 463209	FAINA OSIPOVA	{"phone": "+70693581844"}
0005432920182	94E0A6	1161 072737	LYUDMILA ALEKSEEVA	{"email": "alekseeva-lyudmila-1967@postgrespro.ru", "phone": "+70887251396"}
0005432920183	94E0A6	3804 026009	IRINA SAVELEVA	{"phone": "+70557372033"}
0005432920184	E1D1CE	3556 504935	VLADIMIR SHEVCHENKO	{"phone": "+70260112718"}
0005432920185	E8676F	0242 840474	VERONIKA DMITRIEVA	{"phone": "+70528735875"}
0005432920186	0B3773	5971 708945	SERGEY MAKAROV	{"phone": "+70323912160"}
0005432920187	A8AC6C	2021 124592	ALEKSANDR SAVELEV	{"phone": "+70761833359"}
0005432920188	A8AC6C	0397 572116	YANA KOLESNIKOVA	{"phone": "+70546274258"}
0005432920189	DBBB76	2845 106333	RUSLAN PETROV	{"phone": "+70504435654"}
0005432920190	0DCE4A	2295 993073	IGOR MOISEEV	{"email": "moiseev_igor_04081978@postgrespro.ru", "phone": "+70790951125"}
0005432920191	E511D6	7598 070255	TATYANA MIKHAYLOVA	{"phone": "+70176222478"}
0005432920192	639D52	3828 414837	LYUBOV MASLOVA	{"email": "l_maslova_25111982@postgrespro.ru", "phone": "+70369559539"}
0005432920193	639D52	9907 228361	ANATOLIY CHERNOV	{"email": "chernov-anatoliy_091977@postgrespro.ru", "phone": "+70109032432"}
0005432920194	1F451D	9105 269874	SERGEY KUZNECOV	{"email": "kuznecov-sergey1980@postgrespro.ru", "phone": "+70882363592"}
0005432920195	0CE02E	2189 918733	ANASTASIYA GAVRILOVA	{"email": "agavrilova_1973@postgrespro.ru", "phone": "+70925282107"}
0005432920196	342FBC	3279 413346	YURIY ORLOV	{"phone": "+70503546683"}
0005432920197	10994F	3858 268098	TAMARA DMITRIEVA	{"phone": "+70811323306"}
0005432920198	25B77A	6690 998209	ELENA POTAPOVA	{"email": "potapova.elena24051981@postgrespro.ru", "phone": "+70830157090"}
0005432920199	75E859	1537 454757	DARYA FADEEVA	{"phone": "+70082319950"}
0005432920200	48F7B7	7368 270419	ISLAM ALEKSEEV	{"phone": "+70197092056"}
0005432920201	C7DA95	7405 088358	VIKTOR RODIONOV	{"phone": "+70251394421"}
0005432920202	C7DA95	4982 212631	VYACHESLAV ABRAMOV	{"email": "v-abramov.07081974@postgrespro.ru", "phone": "+70053839089"}
0005432920203	EBCA6C	0813 900988	VIKTORIYA EGOROVA	{"phone": "+70763167076"}
0005432920204	9833D7	9475 454671	RAISA ILINA	{"phone": "+70245863967"}
0005432920205	01107F	6829 577432	ANDREY VLASOV	{"email": "vlasov_a.04071972@postgrespro.ru", "phone": "+70184306767"}
0005432920206	A288B8	1245 871096	LILIYA KUZNECOVA	{"phone": "+70680221269"}
0005432920207	DC5F13	8570 772462	VIKTOR SERGEEV	{"email": "sergeev_viktor-081975@postgrespro.ru", "phone": "+70234737597"}
0005432920208	FBF460	9685 939133	TATYANA ZAKHAROVA	{"phone": "+70994168796"}
0005432920209	88637C	5138 034818	NATALIYA SERGEEVA	{"email": "sergeeva_nataliya.1984@postgrespro.ru", "phone": "+70266326986"}
0005432920210	8090D2	9325 243697	RAIL KUZNECOV	{"email": "rail_kuznecov-1968@postgrespro.ru", "phone": "+70828703551"}
0005432920211	B1FA10	3682 067313	ARTUR FILIPPOV	{"phone": "+70365842131"}
0005432920212	B1FA10	5332 904396	ELENA TARASOVA	{"email": "elena_tarasova.29121982@postgrespro.ru", "phone": "+70967887400"}
0005432920213	4F777A	1879 949012	EVGENIY BONDARENKO	{"phone": "+70219456770"}
0005432920214	4F777A	6516 947099	ALEKSANDR TARASOV	{"email": "atarasov_19021970@postgrespro.ru", "phone": "+70682536431"}
0005432920215	9AFF72	4132 010707	IVAN TIKHONOV	{"phone": "+70366230881"}
0005432920216	A6CC7F	4904 717204	SVETLANA NESTEROVA	{"phone": "+70112393978"}
0005432920217	A6CC7F	3800 088570	ANNA ROMANOVA	{"email": "a.romanova.061968@postgrespro.ru", "phone": "+70264749429"}
0005432920218	901EC3	4814 528397	LARISA ANDREEVA	{"phone": "+70353256621"}
0005432920219	0DE07D	4132 914938	OLGA MAKAROVA	{"phone": "+70562325044"}
0005432920220	1F49E3	0176 719215	EKATERINA ISAEVA	{"email": "isaeva.ekaterina1974@postgrespro.ru", "phone": "+70279569431"}
0005432920221	5DE47B	1533 941472	DARYA KUDRYASHOVA	{"email": "d_kudryashova_111971@postgrespro.ru", "phone": "+70789758034"}
0005432920222	E7415C	0590 767010	ELENA FOMINA	{"email": "e.fomina101977@postgrespro.ru", "phone": "+70998915982"}
0005432920223	F4DB83	2142 428429	VLADIMIR ISAEV	{"email": "vladimir-isaev_101979@postgrespro.ru", "phone": "+70926072700"}
0005432920224	DBCE11	0161 239386	ELENA RODIONOVA	{"email": "elena-rodionova091975@postgrespro.ru", "phone": "+70219563901"}
0005432920225	CE53A6	5389 801363	OLGA POPOVA	{"phone": "+70587698903"}
0005432920226	DFAB3B	9574 823994	SVETLANA BORISOVA	{"phone": "+70492523330"}
0005432920227	B119F1	7966 575248	ANTONINA MEDVEDEVA	{"phone": "+70910162392"}
0005432920228	6EEBA8	0570 981221	DMITRIY GORBUNOV	{"phone": "+70441992836"}
0005432920229	0F9EFC	6248 282462	VLADISLAV EGOROV	{"phone": "+70131289331"}
0005432920230	01BDDB	8738 935138	ALEKSANDR MAKSIMOV	{"email": "maksimova061974@postgrespro.ru", "phone": "+70577430576"}
0005432920231	2DD37B	2162 935236	VLADIMIR POPOV	{"phone": "+70052239193"}
0005432920232	DD613F	7390 418306	NIKOLAY TIKHONOV	{"email": "tikhonov-nikolay.1956@postgrespro.ru", "phone": "+70853079032"}
0005432920233	B08FF7	6074 632786	EVGENIYA LEBEDEVA	{"phone": "+70611208691"}
0005432920234	B08FF7	8369 316090	ALEKSANDR ROMANOV	{"phone": "+70274099397"}
0005432920235	85414B	2806 966526	NATALYA FILIPPOVA	{"phone": "+70702575639"}
0005432920236	97DEC7	4039 302610	ZINAIDA MEDVEDEVA	{"phone": "+70697815043"}
0005432920237	97DEC7	8359 108632	KIRILL YAKOVLEV	{"email": "k_yakovlev-31011977@postgrespro.ru", "phone": "+70274106944"}
0005432920238	BE600D	3385 948927	ALEKSEY VOROBEV	{"email": "vorobevaleksey061981@postgrespro.ru", "phone": "+70464547204"}
0005432920239	D80FEF	1612 642983	EKATERINA SMIRNOVA	{"email": "smirnova_e1979@postgrespro.ru", "phone": "+70807770219"}
0005432920240	D80FEF	9277 571931	ANATOLIY KRASNOV	{"email": "akrasnov_1971@postgrespro.ru", "phone": "+70920139577"}
0005432920241	B8E27D	3715 231534	VIKTOR CHERNOV	{"email": "viktor-chernov-23041967@postgrespro.ru", "phone": "+70344003170"}
0005432920242	271C90	8104 610980	ALEKSANDRA SEMENOVA	{"email": "aleksandra.semenova.1976@postgrespro.ru", "phone": "+70681908048"}
0005432920243	5E5E98	1113 313198	ELENA KUZMINA	{"email": "elenakuzmina_1969@postgrespro.ru", "phone": "+70942374679"}
0005432920244	5E5E98	8490 001685	TATYANA SERGEEVA	{"phone": "+70196221197"}
0005432920245	F10A61	8832 391336	ALEKSANDR KUZMIN	{"phone": "+70930742013"}
0005432920246	52CD50	1734 820652	SVETLANA MIKHAYLOVA	{"phone": "+70660459909"}
0005432920247	267DC3	9434 059915	ANDREY ILIN	{"email": "ilin_a_05061975@postgrespro.ru", "phone": "+70217509455"}
0005432920248	CD67A2	6314 800479	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy.16081976@postgrespro.ru", "phone": "+70601452566"}
0005432920249	B2BDE2	9266 936779	DMITRIY MATVEEV	{"phone": "+70998176386"}
0005432920250	5B4DB6	9943 753250	NIKOLAY BARANOV	{"phone": "+70113277556"}
0005432920251	B6C649	6236 771832	ELENA TIMOFEEVA	{"email": "timofeeva-e-1973@postgrespro.ru", "phone": "+70872018576"}
0005432920252	973BCB	6286 677304	YULIYA YAKOVLEVA	{"email": "y_yakovleva1978@postgrespro.ru", "phone": "+70120506405"}
0005432920253	23B660	1293 677489	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov081974@postgrespro.ru", "phone": "+70058160189"}
0005432920254	23B660	9175 898656	BORIS MAKAROV	{"email": "makarov-b.28121976@postgrespro.ru", "phone": "+70262252353"}
0005432920255	9930F9	3411 384825	KRISTINA NAZAROVA	{"phone": "+70251915415"}
0005432920256	27FFE4	2868 580560	GALINA MARTYNOVA	{"email": "galina.martynova.121985@postgrespro.ru", "phone": "+70713903705"}
0005432920257	7C9837	4850 902397	VIKTOR TIKHONOV	{"phone": "+70378265389"}
0005432920258	7C9837	5154 851851	LYUDMILA BOGDANOVA	{"email": "bogdanova.l_1978@postgrespro.ru", "phone": "+70630054267"}
0005432920259	7C9837	0271 563910	DENIS POPOV	{"email": "popovd20041976@postgrespro.ru", "phone": "+70774244698"}
0005432920260	279AFB	0872 775076	VERA EFIMOVA	{"email": "v-efimova-081977@postgrespro.ru", "phone": "+70259322791"}
0005432920261	E47465	1273 921608	KONSTANTIN MOROZOV	{"phone": "+70899104405"}
0005432920262	E47465	6918 346235	NATALYA TIMOFEEVA	{"email": "timofeeva_n101973@postgrespro.ru", "phone": "+70256312705"}
0005432920263	F020C6	6311 504174	MARINA MIRONOVA	{"email": "marina_mironova-1962@postgrespro.ru", "phone": "+70803090033"}
0005432920264	516773	0368 042424	MARIYA ROMANOVA	{"email": "romanova_mariya-05031969@postgrespro.ru", "phone": "+70112686293"}
0005432920265	58E7B9	5268 668673	SERGEY AFANASEV	{"phone": "+70036432727"}
0005432920266	2C5375	6576 942122	SERGEY AFANASEV	{"phone": "+70462765404"}
0005432920267	90DA44	0016 067433	YULIYA AKIMOVA	{"email": "yuliya-akimova.24071967@postgrespro.ru", "phone": "+70160277654"}
0005432920268	66EC35	0148 971555	IRINA SEMENOVA	{"phone": "+70194111777"}
0005432920269	33A15E	4291 518422	ALEKSANDR DAVYDOV	{"email": "adavydov_091986@postgrespro.ru", "phone": "+70392469112"}
0005432920270	550DCA	3145 757169	IRINA NESTEROVA	{"email": "irinanesterova.17061971@postgrespro.ru", "phone": "+70718014027"}
0005432920271	CAF1E8	5205 157095	SVETLANA ISAEVA	{"email": "isaeva.s.1974@postgrespro.ru", "phone": "+70720995513"}
0005432920272	D48D29	9722 785270	LYUBOV BOGDANOVA	{"email": "bogdanova.lyubov_11031980@postgrespro.ru", "phone": "+70470728340"}
0005432920273	23E609	3105 207525	ROZA LEBEDEVA	{"phone": "+70687826212"}
0005432920274	A0F3B6	6408 866535	OLGA MEDVEDEVA	{"email": "o-medvedeva-081976@postgrespro.ru", "phone": "+70691270252"}
0005432920275	A7B981	0793 360139	IGOR FEDOTOV	{"email": "i_fedotov041970@postgrespro.ru", "phone": "+70147390965"}
0005432920276	101BB2	3869 749349	ANTON KONOVALOV	{"phone": "+70108616823"}
0005432920277	DE61D0	9808 354766	OLGA SERGEEVA	{"email": "olgasergeeva_1977@postgrespro.ru", "phone": "+70335013250"}
0005432920278	080521	9670 529126	VLADIMIR AFANASEV	{"phone": "+70801696443"}
0005432920279	A583F8	4575 158051	MIKHAIL KUZNECOV	{"phone": "+70177668517"}
0005432920280	A583F8	0804 576979	OLGA SEMENOVA	{"email": "olga-semenova-1970@postgrespro.ru", "phone": "+70809495308"}
0005432920281	A583F8	2410 898581	ANDREY PAVLOV	{"phone": "+70941009578"}
0005432920282	66D91C	5369 382570	LIDIYA ROMANOVA	{"phone": "+70583382721"}
0005432920283	D61289	0598 552270	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov-1984@postgrespro.ru", "phone": "+70232136450"}
0005432920284	D61289	6167 059743	MARIYA MIRONOVA	{"email": "m.mironova30121964@postgrespro.ru", "phone": "+70590323519"}
0005432920285	4CB299	4979 200578	LYUDMILA MEDVEDEVA	{"email": "medvedevalyudmila.01031969@postgrespro.ru", "phone": "+70147809154"}
0005432920286	B465CA	2997 456793	LIDIYA ZHUKOVA	{"email": "lidiya_zhukova_081973@postgrespro.ru", "phone": "+70839075211"}
0005432920287	40B761	4845 705435	EGOR MOROZOV	{"email": "morozov.e1970@postgrespro.ru", "phone": "+70202635140"}
0005432920288	40B761	8414 432944	IGOR KUZNECOV	{"phone": "+70131647067"}
0005432920289	40B761	5682 901343	ANASTASIYA TIKHONOVA	{"phone": "+70970532119"}
0005432920290	AB66DC	6558 002477	VALENTINA NIKOLAEVA	{"email": "valentina_nikolaeva-15111978@postgrespro.ru", "phone": "+70905742434"}
0005432920291	9741A2	4437 801477	LYUBOV DMITRIEVA	{"email": "lyubov-dmitrieva-031963@postgrespro.ru", "phone": "+70747720921"}
0005432920292	540D07	7746 297702	TATYANA POPOVA	{"email": "popova.tatyana.111980@postgrespro.ru", "phone": "+70320666412"}
0005432920293	540D07	7570 055813	MARINA IVANOVA	{"email": "ivanova.marina.02011970@postgrespro.ru", "phone": "+70610911564"}
0005432920294	A4C6FB	2288 900218	ANZHELIKA POPOVA	{"phone": "+70088220991"}
0005432920295	B8B478	7481 261993	SERGEY OSIPOV	{"phone": "+70270329053"}
0005432920296	76D7B3	8260 956648	ALEKSEY BONDARENKO	{"email": "bondarenko.aleksey1966@postgrespro.ru", "phone": "+70106021025"}
0005432920297	76D7B3	3695 711176	VASILIY CHERNOV	{"phone": "+70309164052"}
0005432920298	A1225A	0306 590945	ANZHELIKA ORLOVA	{"email": "a-orlova29061978@postgrespro.ru", "phone": "+70477480826"}
0005432920299	A1225A	1047 174206	RITA ILINA	{"phone": "+70269631797"}
0005432920300	5947B8	6506 791016	TATYANA MARTYNOVA	{"phone": "+70333595869"}
0005432920301	5947B8	2734 811203	TATYANA PAVLOVA	{"email": "t_pavlova_1964@postgrespro.ru", "phone": "+70006126161"}
0005432920302	5577F5	7566 042428	ALEKSEY GUSEV	{"email": "aleksey_gusev-1961@postgrespro.ru", "phone": "+70902939879"}
0005432920303	5577F5	9886 275058	PAVEL MATVEEV	{"phone": "+70145644520"}
0005432920304	459D2D	7368 380154	ANASTASIYA KALININA	{"phone": "+70100719473"}
0005432920305	27A216	9962 083102	NIKOLAY SERGEEV	{"phone": "+70912313289"}
0005432920306	CBBB02	9354 603568	SERGEY GAVRILOV	{"phone": "+70170110039"}
0005432920307	CBBB02	3917 683721	EKATERINA KONOVALOVA	{"email": "ekaterina-konovalova_061976@postgrespro.ru", "phone": "+70406327698"}
0005432920308	3C891B	4812 079792	ANATOLIY FROLOV	{"phone": "+70832910168"}
0005432920309	B54DA8	7531 074177	EKATERINA SAVELEVA	{"email": "saveleva-ekaterina_1970@postgrespro.ru", "phone": "+70706201992"}
0005432920310	47C473	8913 624230	GENNADIY SOROKIN	{"phone": "+70997929446"}
0005432920311	595ADA	1021 066782	NIKOLAY MIKHAYLOV	{"email": "mikhaylovn111967@postgrespro.ru", "phone": "+70717171709"}
0005432920312	42C920	9213 430837	KLAVDIYA RYABOVA	{"phone": "+70778662518"}
0005432920313	5E1DA5	1552 208943	IGOR MOISEEV	{"email": "moiseevi-23101967@postgrespro.ru", "phone": "+70504949990"}
0005432920314	5E1DA5	0031 236520	VLADIMIR ANTONOV	{"email": "antonov_v_051974@postgrespro.ru", "phone": "+70767457301"}
0005432920315	0C91E6	8292 355619	VIKTORIYA OVCHINNIKOVA	{"phone": "+70423501707"}
0005432920316	0C91E6	9284 011870	ALEKSANDRA KOLESNIKOVA	{"email": "kolesnikova_aleksandra_01021975@postgrespro.ru", "phone": "+70266774356"}
0005432920317	0D872F	4182 393965	VALERIYA ANTONOVA	{"email": "valeriya.antonova_031968@postgrespro.ru", "phone": "+70178276363"}
0005432920318	B286D9	9470 620189	DANILA ABRAMOV	{"email": "danilaabramov1962@postgrespro.ru", "phone": "+70693523937"}
0005432920319	B48DC3	0242 506346	OLEG SAVELEV	{"email": "savelev-oleg.1967@postgrespro.ru", "phone": "+70085179664"}
0005432920320	58F4B9	1770 536428	EKATERINA SIDOROVA	{"phone": "+70758422458"}
0005432920321	58F4B9	1806 837341	DMITRIY ORLOV	{"email": "d-orlov-25071977@postgrespro.ru", "phone": "+70318200059"}
0005432922532	5D7C49	3662 538743	ALBINA DAVYDOVA	{"phone": "+70718677602"}
0005432920322	A97679	9475 965412	YULIYA SAVELEVA	{"email": "y-saveleva28081973@postgrespro.ru", "phone": "+70835121941"}
0005432920323	A97679	6597 027958	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr-14011967@postgrespro.ru", "phone": "+70842222583"}
0005432920324	A97679	6533 708343	SVETLANA LUKYANOVA	{"phone": "+70765215690"}
0005432920325	FDEA71	0957 211381	NINA MAKAROVA	{"phone": "+70454026150"}
0005432920326	78E7AC	8016 396230	ANDREY BARANOV	{"email": "baranov.andrey-30121971@postgrespro.ru", "phone": "+70580992418"}
0005432920327	78E7AC	5775 269550	MARIYA NESTEROVA	{"phone": "+70170444796"}
0005432920328	17CDE0	8995 202712	ANASTASIYA SEMENOVA	{"phone": "+70409981374"}
0005432920329	17CDE0	4081 355539	IRINA ERMAKOVA	{"email": "ermakova-i24081964@postgrespro.ru", "phone": "+70450691844"}
0005432920330	94BA61	4401 942315	MARIYA ZHURAVLEVA	{"phone": "+70624591158"}
0005432920331	FEB7E1	9533 345169	KONSTANTIN ALEKSEEV	{"phone": "+70265459568"}
0005432920332	73FE84	6778 226239	ANASTASIYA MAKAROVA	{"email": "a.makarova-19071963@postgrespro.ru", "phone": "+70892304924"}
0005432920333	E8E3F1	6991 057873	ALINA MELNIKOVA	{"phone": "+70510021967"}
0005432920334	282204	3807 572386	MIKHAIL IVANOV	{"phone": "+70417402810"}
0005432920335	090FB7	2955 411819	TATYANA BORISOVA	{"email": "tborisova-26121953@postgrespro.ru", "phone": "+70605880974"}
0005432920336	090FB7	2707 686811	GLEB KONOVALOV	{"phone": "+70072889837"}
0005432920337	487637	1436 012106	GALINA STEPANOVA	{"email": "stepanova.galina121972@postgrespro.ru", "phone": "+70639102627"}
0005432920338	D0294A	5497 329372	ALEKSEY TIKHONOV	{"phone": "+70510398661"}
0005432920339	C114A8	9861 865850	VALERIYA FOMINA	{"phone": "+70196071788"}
0005432920340	7F620D	9872 903150	VALENTINA PAVLOVA	{"email": "pavlova.v16081966@postgrespro.ru", "phone": "+70871943920"}
0005432920341	7078AB	4326 955771	ELENA KOROLEVA	{"phone": "+70862955768"}
0005432920342	31510E	0244 518012	VALENTINA TITOVA	{"phone": "+70266580555"}
0005432920343	31510E	9035 507206	SERGEY MAKSIMOV	{"phone": "+70705077061"}
0005432920344	52C279	5648 829857	EKATERINA ZHUKOVA	{"phone": "+70393489835"}
0005432920345	D0827E	7849 434340	NINA ZHUKOVA	{"phone": "+70024933198"}
0005432920346	D0827E	2532 239615	NINA SMIRNOVA	{"phone": "+70733728163"}
0005432920347	D0827E	5112 543300	SERGEY SMIRNOV	{"email": "smirnov-sergey_051970@postgrespro.ru", "phone": "+70234336755"}
0005432920348	D0827E	9808 558338	YURIY KUZNECOV	{"phone": "+70326440931"}
0005432920349	484222	8205 778862	TATYANA BELOVA	{"phone": "+70885798490"}
0005432920350	691A19	5578 712847	FARID SERGEEV	{"phone": "+70291297784"}
0005432920351	23AD88	5090 044928	TATYANA VASILEVA	{"email": "vasilevatatyana_1978@postgrespro.ru", "phone": "+70063109285"}
0005432920352	17F243	7941 662998	ANNA VOLKOVA	{"email": "volkova_a1969@postgrespro.ru", "phone": "+70780247047"}
0005432920353	17F243	2307 442512	ELENA POPOVA	{"email": "popovaelena-25021968@postgrespro.ru", "phone": "+70939664903"}
0005432920354	4A6DC9	0971 269999	VIKTOR NIKOLAEV	{"email": "viktornikolaev1976@postgrespro.ru", "phone": "+70315536485"}
0005432920355	1AFCBC	1657 463242	YULIYA VOROBEVA	{"email": "yvorobeva_12111977@postgrespro.ru", "phone": "+70194515119"}
0005432920356	1AFCBC	7966 713217	EKATERINA NAZAROVA	{"phone": "+70995839923"}
0005432920357	7C7F13	9912 503997	VLADIMIR FEDOROV	{"email": "v.fedorov.021967@postgrespro.ru", "phone": "+70406934875"}
0005432920358	7C7F13	0247 956665	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov-28121962@postgrespro.ru", "phone": "+70516975609"}
0005432920359	F025AC	5298 488533	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov_101979@postgrespro.ru", "phone": "+70493095172"}
0005432920360	75C265	9486 475985	VASILIY GAVRILOV	{"phone": "+70457936603"}
0005432920361	F82122	4625 237789	ALEKSANDR DAVYDOV	{"email": "a.davydov-011966@postgrespro.ru", "phone": "+70362637642"}
0005432920362	54DAB5	8782 130185	NATALYA ZAYCEVA	{"email": "natalya.zayceva-031974@postgrespro.ru", "phone": "+70484834803"}
0005432920363	3ACF08	3764 922946	FATYMA POTAPOVA	{"phone": "+70463620864"}
0005432920364	AA512A	4891 644539	INGA RYABOVA	{"email": "ryabova.inga1965@postgrespro.ru", "phone": "+70553083760"}
0005432920365	7A06F9	2112 478899	ELENA MOISEEVA	{"email": "moiseeva-elena_071961@postgrespro.ru", "phone": "+70369861394"}
0005432920366	623501	7113 838099	GALINA MALYSHEVA	{"phone": "+70721310449"}
0005432920367	623501	6961 379971	MARGARITA KOZLOVA	{"phone": "+70229500637"}
0005432920368	B9769C	8638 478653	TAMARA ROMANOVA	{"email": "tamara_romanova.11111962@postgrespro.ru", "phone": "+70086535717"}
0005432920369	97B661	1001 682519	ANTONINA IVANOVA	{"phone": "+70893661222"}
0005432920370	2885AC	4017 942321	ALEKSANDR GORBUNOV	{"email": "aleksandrgorbunov1975@postgrespro.ru", "phone": "+70717391029"}
0005432920371	2885AC	3712 410536	ALEKSANDR CHERNOV	{"email": "chernov_a.18051971@postgrespro.ru", "phone": "+70049115022"}
0005432920372	2885AC	1562 324159	NIKITA BORISOV	{"phone": "+70401671559"}
0005432920373	CB0A07	0032 091577	LYUDMILA KUZNECOVA	{"phone": "+70180495343"}
0005432920374	701FA3	1286 623849	ANASTASIYA KOLESNIKOVA	{"email": "kolesnikovaanastasiya.01071978@postgrespro.ru", "phone": "+70903879056"}
0005432920375	D03CCD	6462 375114	GALINA OVCHINNIKOVA	{"phone": "+70418786436"}
0005432920376	0190C7	2074 418707	VALERIYA KOZLOVA	{"email": "v-kozlova1971@postgrespro.ru", "phone": "+70255910610"}
0005432920377	0190C7	2684 179020	SERGEY NIKOLAEV	{"email": "nikolaevs-051976@postgrespro.ru", "phone": "+70899385199"}
0005432920378	0D24C0	3924 348291	GALINA SEMENOVA	{"email": "semenova_galina.07081969@postgrespro.ru", "phone": "+70148957917"}
0005432920379	5E53E9	6329 015463	VLADISLAV KUZMIN	{"phone": "+70740715288"}
0005432920380	A49342	0322 165100	DMITRIY TIKHONOV	{"phone": "+70811127516"}
0005432920381	A49342	5978 827161	VITALIY BORISOV	{"phone": "+70961165663"}
0005432920382	90E3B6	3154 332903	ANTONINA RODIONOVA	{"email": "antonina.rodionova_051974@postgrespro.ru", "phone": "+70699609888"}
0005432920383	400D67	6992 659817	SVETLANA GUSEVA	{"email": "s-guseva.19111979@postgrespro.ru", "phone": "+70005482021"}
0005432920384	9870F3	3409 079353	ILYAS DAVYDOV	{"email": "i.davydov_031969@postgrespro.ru", "phone": "+70767250905"}
0005432920385	9870F3	5971 378066	TATYANA YUDINA	{"email": "tatyana_yudina_1981@postgrespro.ru", "phone": "+70679828174"}
0005432920386	1D68AE	0323 569892	ARTEM KRASNOV	{"email": "a-krasnov071975@postgrespro.ru", "phone": "+70220038530"}
0005432920387	C92E2C	1281 987829	ELENA SMIRNOVA	{"email": "smirnova-elena.28081968@postgrespro.ru", "phone": "+70345199380"}
0005432920388	19AD79	8658 077934	GENNADIY KOZLOV	{"email": "g-kozlov25061968@postgrespro.ru", "phone": "+70193025941"}
0005432920389	29924C	6187 825435	GALINA FEDOROVA	{"email": "g-fedorova_1973@postgrespro.ru", "phone": "+70937665067"}
0005432920390	5E8A82	5873 799641	KSENIYA VLASOVA	{"phone": "+70933722724"}
0005432920391	69DFE3	5433 972989	NADEZHDA ALEKSANDROVA	{"email": "aleksandrova_nadezhda_28101974@postgrespro.ru", "phone": "+70553238132"}
0005432920392	69DFE3	2665 867233	VADIM BARANOV	{"phone": "+70582849805"}
0005432920393	69DFE3	5086 610411	SOFYA OVCHINNIKOVA	{"phone": "+70351566034"}
0005432920394	CAF6A7	1209 327963	VLADIMIR ILIN	{"phone": "+70595233342"}
0005432920395	86D161	4513 753699	VERA KOLESNIKOVA	{"email": "v-kolesnikova-1979@postgrespro.ru", "phone": "+70488877109"}
0005432920396	CBA808	8053 042068	VLADIMIR STEPANOV	{"email": "vladimirstepanov27031970@postgrespro.ru", "phone": "+70356238129"}
0005432920397	17DB32	2354 622891	ANTONINA SAVELEVA	{"phone": "+70177095671"}
0005432920398	17DB32	0226 975307	ILYA IVANOV	{"phone": "+70334826522"}
0005432920399	17DB32	0085 258066	YURIY DAVYDOV	{"phone": "+70316130658"}
0005432920400	F34114	3291 683580	NATALYA OSIPOVA	{"phone": "+70480666554"}
0005432920401	0EF7B2	3380 224724	GALINA MAKSIMOVA	{"email": "maksimova_g-021963@postgrespro.ru", "phone": "+70749705333"}
0005432920402	D0A518	3011 366014	VYACHESLAV GORBUNOV	{"email": "gorbunov_vyacheslav-1967@postgrespro.ru", "phone": "+70874541203"}
0005432920403	E02191	3821 477691	IVAN ANTONOV	{"phone": "+70131583772"}
0005432920404	E02191	0348 541224	ARINA LOGINOVA	{"email": "aloginova-1979@postgrespro.ru", "phone": "+70923977303"}
0005432920405	E02191	2750 862331	NIKOLAY SOROKIN	{"phone": "+70160199889"}
0005432920406	7787A7	6116 195685	ARTUR CHERNOV	{"phone": "+70977923998"}
0005432920407	AF7022	0770 120022	SVETLANA STEPANOVA	{"email": "stepanova.svetlana_1974@postgrespro.ru", "phone": "+70960167978"}
0005432920408	7346A1	5140 225432	OLGA TARASOVA	{"email": "tarasova-olga_091963@postgrespro.ru", "phone": "+70635122317"}
0005432920409	71660E	5880 612951	ROMAN MELNIKOV	{"phone": "+70962577515"}
0005432920410	71660E	1056 546603	DARYA OSIPOVA	{"phone": "+70037634660"}
0005432920411	DB3F2C	7404 138055	ANNA ANTONOVA	{"phone": "+70879272543"}
0005432920412	0EE363	6724 998268	ALEKSEY SCHERBAKOV	{"email": "scherbakova.111964@postgrespro.ru", "phone": "+70882998373"}
0005432920413	0EE363	2481 163592	ARTEM BONDARENKO	{"phone": "+70895711809"}
0005432920414	BE3459	2686 100359	EKATERINA NESTEROVA	{"email": "ekaterinanesterova.11091967@postgrespro.ru", "phone": "+70477334126"}
0005432920415	BE3459	4448 048229	VLADIMIR MAKAROV	{"email": "makarov.v22061963@postgrespro.ru", "phone": "+70439327414"}
0005432920416	155697	7858 591335	ELENA RYABOVA	{"email": "eryabova-121969@postgrespro.ru", "phone": "+70323510111"}
0005432920417	0954C3	8430 567206	TATYANA PETROVA	{"phone": "+70124324980"}
0005432920418	6DD662	5089 669903	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina-03081966@postgrespro.ru", "phone": "+70526063955"}
0005432920419	141D7E	6663 674921	ALEKSEY NOVIKOV	{"email": "aleksey-novikov.091964@postgrespro.ru", "phone": "+70421373205"}
0005432920420	C2C9BF	8019 952139	NINA LAZAREVA	{"email": "ninalazareva.021978@postgrespro.ru", "phone": "+70449964863"}
0005432920421	C2C9BF	2609 659685	VALENTINA FILATOVA	{"phone": "+70991697893"}
0005432920422	CFEDAF	0918 503545	ALEKSANDR BORISOV	{"email": "aleksandrborisov.011971@postgrespro.ru", "phone": "+70000159632"}
0005432920423	CFEDAF	8957 712175	NATALYA MIRONOVA	{"email": "n-mironova_16071962@postgrespro.ru", "phone": "+70270516990"}
0005432920424	0A7262	6369 911276	IRINA SAVELEVA	{"email": "saveleva.irina_20021977@postgrespro.ru", "phone": "+70961467917"}
0005432920425	0A7262	5076 913477	GALINA MIRONOVA	{"phone": "+70204385570"}
0005432920426	0D6B0D	1380 134291	NINA MAKAROVA	{"phone": "+70671093618"}
0005432920427	F71D55	8202 326277	VADIM NAUMOV	{"email": "naumov_vadim051977@postgrespro.ru", "phone": "+70548508066"}
0005432920428	5AD348	7930 819039	ANATOLIY ILIN	{"email": "ilin-a_111969@postgrespro.ru", "phone": "+70936194441"}
0005432920429	5AD348	4601 371031	EVGENIY VLASOV	{"email": "vlasove_05111962@postgrespro.ru", "phone": "+70413561939"}
0005432920430	70C65F	9452 607201	LYUBOV AFANASEVA	{"email": "l.afanaseva_1969@postgrespro.ru", "phone": "+70812831214"}
0005432920431	3C8567	0831 363013	EDUARD ANDREEV	{"email": "eduard_andreev_08041979@postgrespro.ru", "phone": "+70904929089"}
0005432920432	69B545	7316 865589	GENNADIY NAZAROV	{"phone": "+70920260526"}
0005432920433	69B545	9597 093206	ELENA ANDREEVA	{"email": "e-andreeva08091969@postgrespro.ru", "phone": "+70323968743"}
0005432920434	69B545	7760 361173	MARIYA STEPANOVA	{"phone": "+70763308171"}
0005432920435	69B545	2507 344982	ALEKSANDR MEDVEDEV	{"email": "medvedev_a08051973@postgrespro.ru", "phone": "+70207900643"}
0005432920436	972A4F	9446 359423	VALERIYA FOMINA	{"email": "fomina-v-111965@postgrespro.ru", "phone": "+70682149393"}
0005432920437	1D8BAB	0415 603290	DANIIL FEDOTOV	{"email": "d.fedotov.1959@postgrespro.ru", "phone": "+70937894152"}
0005432920438	155C66	4911 304751	MIKHAIL KISELEV	{"email": "mkiselev.081978@postgrespro.ru", "phone": "+70164382946"}
0005432920439	155C66	8228 746127	RAISA DANILOVA	{"phone": "+70872403806"}
0005432920440	A26CBE	3681 880007	IGOR ORLOV	{"phone": "+70075544827"}
0005432920441	1BF3E2	0188 635890	ANGELINA KOROLEVA	{"phone": "+70233843405"}
0005432920442	A84193	7100 512965	MARIYA KUZNECOVA	{"email": "m_kuznecova-19061973@postgrespro.ru", "phone": "+70254085300"}
0005432920443	3EFAA4	9995 814301	NINA POPOVA	{"email": "popovanina_27081964@postgrespro.ru", "phone": "+70469249242"}
0005432920444	B56574	8249 594015	DMITRIY ANTONOV	{"phone": "+70888671805"}
0005432920445	622252	7825 782764	OLEG DENISOV	{"phone": "+70377961519"}
0005432920446	E386E1	8904 143350	SVETLANA MASLOVA	{"email": "maslova-s081974@postgrespro.ru", "phone": "+70350905596"}
0005432920447	1599E7	5909 450956	GALINA FILATOVA	{"email": "filatova_g-1971@postgrespro.ru", "phone": "+70610494663"}
0005432920448	1599E7	3196 796295	NIKOLAY GRIGOREV	{"phone": "+70909976245"}
0005432920449	73E32F	6905 812273	DARYA ARKHIPOVA	{"phone": "+70694808586"}
0005432920450	F8E12D	2512 970207	EGOR DENISOV	{"email": "egor_denisov-091976@postgrespro.ru", "phone": "+70362988210"}
0005432920451	8AC9AF	4579 203837	EVGENIY SAVELEV	{"email": "savelev_evgeniy.1985@postgrespro.ru", "phone": "+70044204331"}
0005432920452	8AC9AF	3717 797265	NATALYA OVCHINNIKOVA	{"email": "novchinnikova071972@postgrespro.ru", "phone": "+70541496323"}
0005432920453	A45800	4286 528410	ALLA KARPOVA	{"email": "allakarpova.1968@postgrespro.ru", "phone": "+70855513683"}
0005432920454	69EA0B	4833 978305	VYACHESLAV KUZMIN	{"email": "kuzmin_vyacheslav061975@postgrespro.ru", "phone": "+70856804889"}
0005432920455	43E77E	0398 241468	ALEKSANDR SIDOROV	{"email": "asidorov13031978@postgrespro.ru", "phone": "+70164177961"}
0005432920456	A4EA20	1899 550687	MARIYA LEBEDEVA	{"email": "lebedeva-mariya_1975@postgrespro.ru", "phone": "+70750805853"}
0005432920457	AA6EBA	3152 599347	DARYA OVCHINNIKOVA	{"email": "darya_ovchinnikova1963@postgrespro.ru", "phone": "+70852876448"}
0005432920458	AA6EBA	5141 837472	TATYANA TIKHONOVA	{"email": "t_tikhonova.1974@postgrespro.ru", "phone": "+70970943069"}
0005432920459	5B12A1	5508 199487	EGOR KUZNECOV	{"email": "egorkuznecov_26051970@postgrespro.ru", "phone": "+70194383368"}
0005432920460	048C7E	1353 996519	TATYANA LOGINOVA	{"phone": "+70489495025"}
0005432920461	048C7E	3093 894979	MAKSIM FOMIN	{"phone": "+70942659907"}
0005432920462	37C034	5699 366495	SHAMIL MIRONOV	{"phone": "+70509082495"}
0005432920463	37C034	9203 174389	SVETLANA POPOVA	{"email": "popova.s.23031972@postgrespro.ru", "phone": "+70388280387"}
0005432920464	0EBF1B	2527 623253	MIKHAIL PAVLOV	{"phone": "+70962011937"}
0005432920465	0EBF1B	9400 036014	EVGENIYA ANTONOVA	{"phone": "+70598413026"}
0005432920466	0EBF1B	4786 140438	NATALYA SOKOLOVA	{"phone": "+70189024784"}
0005432920467	D31044	9391 842646	VITALIY ANDREEV	{"email": "andreev_vitaliy-19051974@postgrespro.ru", "phone": "+70581973344"}
0005432920468	FC8AC6	3611 389455	YULIYA KUZNECOVA	{"phone": "+70022552505"}
0005432920469	266F58	3903 735101	SERGEY KOROLEV	{"email": "sergeykorolev-1963@postgrespro.ru", "phone": "+70995959632"}
0005432920470	266F58	2033 984758	POLINA NIKOLAEVA	{"email": "polina-nikolaeva_1985@postgrespro.ru", "phone": "+70046366821"}
0005432920471	266F58	8493 292370	OLEG GAVRILOV	{"phone": "+70903354028"}
0005432920472	6354D4	6977 461256	MARIYA SIDOROVA	{"email": "m.sidorova.29041979@postgrespro.ru", "phone": "+70647316355"}
0005432920473	55502E	0162 315184	IVAN SMIRNOV	{"phone": "+70061569245"}
0005432920474	8E8535	2633 519639	NADEZHDA BARANOVA	{"phone": "+70231669612"}
0005432920475	28AABA	2946 027004	ANNA FEDOROVA	{"phone": "+70268501792"}
0005432920476	BF35AE	7075 595217	ALBERT NOVIKOV	{"email": "albert-novikov091968@postgrespro.ru", "phone": "+70571013382"}
0005432920477	DAFD63	0377 774342	GLEB MAKAROV	{"phone": "+70288618980"}
0005432920478	E51EAF	2013 977594	TATYANA ARKHIPOVA	{"email": "tatyana.arkhipova071968@postgrespro.ru", "phone": "+70073804382"}
0005432920479	10A958	6932 003678	ANNA SAVELEVA	{"phone": "+70462994958"}
0005432920480	F9C14A	1053 810764	MARIYA MALYSHEVA	{"email": "mariyamalysheva.051968@postgrespro.ru", "phone": "+70582675809"}
0005432920481	8FFEC3	8091 671920	LYUDMILA ZAYCEVA	{"email": "zayceva-l-1966@postgrespro.ru", "phone": "+70574894971"}
0005432920482	7C017F	2504 505909	EKATERINA MAKSIMOVA	{"phone": "+70276090163"}
0005432922453	25E081	6093 078986	ANTON MARTYNOV	{"phone": "+70037981083"}
0005432922454	CF7FD9	8070 717319	DMITRIY SOKOLOV	{"email": "d-sokolov_071973@postgrespro.ru", "phone": "+70352051956"}
0005432922455	48FF49	8814 710122	ALEKSEY VASILEV	{"email": "a.vasilev_1971@postgrespro.ru", "phone": "+70917225768"}
0005432922456	E506FE	5566 624949	MARINA MASLOVA	{"email": "marina_maslova_1960@postgrespro.ru", "phone": "+70074228902"}
0005432922457	0F9344	0925 822269	VERONIKA BELYAEVA	{"email": "v-belyaeva111975@postgrespro.ru", "phone": "+70113910100"}
0005432922458	0F9344	9490 263528	ALEKSANDR ILIN	{"email": "aleksandrilin1972@postgrespro.ru", "phone": "+70134929657"}
0005432922459	0F9344	5070 234415	LIDIYA POLYAKOVA	{"email": "lidiya.polyakova-051975@postgrespro.ru", "phone": "+70144319364"}
0005432922460	A7D655	5509 252661	ELENA VLASOVA	{"phone": "+70584113444"}
0005432922461	DA6FCD	3654 355628	SERGEY AFANASEV	{"email": "s_afanasev.121971@postgrespro.ru", "phone": "+70929939259"}
0005432922462	DA6FCD	6108 698965	GALINA ISAEVA	{"phone": "+70380475236"}
0005432922463	9CA706	1661 929706	ALBERT GORBUNOV	{"phone": "+70706490385"}
0005432922464	11D02E	3972 252144	NIKOLAY PETROV	{"phone": "+70532222397"}
0005432922465	304873	5253 016854	ELENA EGOROVA	{"phone": "+70065447116"}
0005432922466	F14FE6	0696 342760	OLEG ANTONOV	{"email": "o.antonov.1972@postgrespro.ru", "phone": "+70170454347"}
0005432922467	143BF8	8066 783878	LYUDMILA KOROLEVA	{"email": "korolevalyudmila.05121964@postgrespro.ru", "phone": "+70762221124"}
0005432922468	83733B	3491 736066	MAYYA GERASIMOVA	{"phone": "+70662067847"}
0005432922469	D9609E	0581 602285	MARIYA KUZNECOVA	{"phone": "+70217600122"}
0005432922470	803306	0014 401460	VITALIY MEDVEDEV	{"phone": "+70708589725"}
0005432922471	803306	5144 329725	PAVEL KOZLOV	{"email": "kozlovpavel.091957@postgrespro.ru", "phone": "+70786347456"}
0005432922472	586CEE	8819 404387	LYUDMILA NESTEROVA	{"email": "l-nesterova_051978@postgrespro.ru", "phone": "+70547238340"}
0005432922473	880F01	5099 282978	YURIY MATVEEV	{"email": "matveev_y1976@postgrespro.ru", "phone": "+70329962808"}
0005432922474	7700F1	9008 710358	TATYANA ANTONOVA	{"phone": "+70988499612"}
0005432922475	24FA02	4871 540333	ALEKSEY KUDRYASHOV	{"phone": "+70364154204"}
0005432922476	24FA02	4327 009389	YULIYA KUZNECOVA	{"email": "yuliyakuznecova.22031974@postgrespro.ru", "phone": "+70851038755"}
0005432922477	6D6F32	3821 707578	DANILA ALEKSANDROV	{"phone": "+70744065264"}
0005432922478	59890A	6583 309844	SERGEY NIKITIN	{"phone": "+70283579599"}
0005432922479	80048E	9744 256364	VENIAMIN MATVEEV	{"email": "veniamin_matveev30091973@postgrespro.ru", "phone": "+70561570617"}
0005432922480	80048E	8755 610745	VALERIY PAVLOV	{"email": "pavlov.valeriy_22101986@postgrespro.ru", "phone": "+70067620380"}
0005432922481	F2694A	9329 529597	LYUDMILA VOLKOVA	{"phone": "+70551293663"}
0005432922482	D00C5F	7211 278095	ANATOLIY FEDOROV	{"phone": "+70343792950"}
0005432922483	E60A5A	8496 147086	ANATOLIY KUZNECOV	{"email": "akuznecov_111974@postgrespro.ru", "phone": "+70158880803"}
0005432922484	E15266	3430 408639	ALEKSANDR KUZNECOV	{"phone": "+70787719004"}
0005432922485	DF099C	0633 690354	NINA SERGEEVA	{"email": "sergeevanina.021974@postgrespro.ru", "phone": "+70739921036"}
0005432922486	BF723A	1034 739399	MILENA GRISHINA	{"phone": "+70785420107"}
0005432922487	F6E827	2809 527039	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr-08061967@postgrespro.ru", "phone": "+70863939459"}
0005432922488	F6E827	4689 579182	ALEKSANDR MAKAROV	{"phone": "+70279936438"}
0005432922489	F6E827	1843 626233	ALEKSEY RODIONOV	{"email": "rodionov.aleksey.21111971@postgrespro.ru", "phone": "+70886044594"}
0005432922490	FF2F57	6702 677112	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-1960@postgrespro.ru", "phone": "+70153134945"}
0005432922491	ED6008	9716 182025	SERGEY MIRONOV	{"phone": "+70997303587"}
0005432922492	ED6008	9843 484379	ANDREY DENISOV	{"email": "a-denisov.01111972@postgrespro.ru", "phone": "+70876926677"}
0005432922493	7B7C5E	8097 698783	EKATERINA BOGDANOVA	{"email": "bogdanovaekaterina_091974@postgrespro.ru", "phone": "+70807835445"}
0005432922494	D90B4D	9786 475182	LYUDMILA VLASOVA	{"email": "vlasova.l061976@postgrespro.ru", "phone": "+70494364857"}
0005432922495	D90B4D	0915 176328	POLINA MATVEEVA	{"phone": "+70369467963"}
0005432922496	F5FE8B	2219 270259	ARINA ANTONOVA	{"email": "arina.antonova_24021957@postgrespro.ru", "phone": "+70227869674"}
0005432922497	C2A888	4946 887613	VASILIY KUZMIN	{"phone": "+70691417317"}
0005432922498	947160	7837 220068	ELENA KRASNOVA	{"email": "e_krasnova051978@postgrespro.ru", "phone": "+70876117612"}
0005432922499	947160	6097 364987	GALINA ANTONOVA	{"phone": "+70703194620"}
0005432922500	947160	1994 246580	VLADIMIR KUZNECOV	{"phone": "+70015928137"}
0005432922501	859B5C	7853 257201	ANASTASIYA SAVELEVA	{"phone": "+70786992493"}
0005432922502	315DFA	0114 333396	TATYANA ROMANOVA	{"email": "tatyana-romanova.1968@postgrespro.ru", "phone": "+70726766043"}
0005432922503	6BB42E	7122 597679	OKSANA SOROKINA	{"phone": "+70498738073"}
0005432922504	C2C7E6	7202 415403	SERGEY FROLOV	{"phone": "+70193384244"}
0005432922505	C2C7E6	1014 124092	IVAN MELNIKOV	{"phone": "+70020220823"}
0005432922506	71FBDB	2860 989909	EVGENIY ANTONOV	{"phone": "+70270313928"}
0005432922507	82678C	2273 370879	LYUDMILA MAKAROVA	{"email": "makarova.l1963@postgrespro.ru", "phone": "+70657539613"}
0005432922508	82678C	8348 268020	ELENA STEPANOVA	{"email": "stepanova.e_021972@postgrespro.ru", "phone": "+70574028723"}
0005432922509	38C155	6285 590673	YURIY KONOVALOV	{"email": "konovalov_y-12031962@postgrespro.ru", "phone": "+70426986398"}
0005432922510	38C155	6936 900588	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev.101978@postgrespro.ru", "phone": "+70967936573"}
0005432922511	F44514	3601 759985	OLEG SEMENOV	{"email": "semenovo28101966@postgrespro.ru", "phone": "+70529564031"}
0005432922512	F44514	3675 595717	DENIS MELNIKOV	{"phone": "+70559535965"}
0005432922513	502D3B	1987 153889	ALEKSEY VASILEV	{"phone": "+70327681867"}
0005432922514	DA844D	5271 753709	ANASTASIYA SOROKINA	{"email": "sorokinaanastasiya_1996@postgrespro.ru", "phone": "+70954072942"}
0005432922515	C06560	9413 564508	OLGA ALEKSEEVA	{"email": "alekseeva.olga.25071974@postgrespro.ru", "phone": "+70796859220"}
0005432922516	5AFB4F	3254 437461	ANNA ORLOVA	{"email": "orlova.a-09011968@postgrespro.ru", "phone": "+70927824973"}
0005432922517	5AFB4F	1438 578970	DZHAMILYA ZAYCEVA	{"email": "dzhamilya_zayceva-121969@postgrespro.ru", "phone": "+70699449223"}
0005432922518	05DC6C	5627 258382	IRINA FILATOVA	{"phone": "+70970048026"}
0005432922519	05DC6C	9457 333810	VERA SCHERBAKOVA	{"phone": "+70388731345"}
0005432922520	BBEB42	2244 989668	ALEKSANDR SAVELEV	{"phone": "+70335702077"}
0005432922521	473BBA	4140 463361	EVGENIY KOROLEV	{"email": "e-korolev_051963@postgrespro.ru", "phone": "+70631153561"}
0005432922522	79CE05	8937 979426	GALINA YAKOVLEVA	{"phone": "+70151504422"}
0005432922523	79CE05	2885 644935	GALINA MOROZOVA	{"phone": "+70482628959"}
0005432922524	DB2291	2678 605622	MARIYA OSIPOVA	{"email": "osipovam-1984@postgrespro.ru", "phone": "+70330179995"}
0005432922525	DB2291	2601 510200	ANDREY KUZNECOV	{"phone": "+70202587041"}
0005432922526	431DF1	7534 296018	ALEKSEY ANTONOV	{"email": "aleksey-antonov05041966@postgrespro.ru", "phone": "+70271741788"}
0005432922527	2956DB	0970 632221	VLADIMIR PETROV	{"email": "v_petrov.20061975@postgrespro.ru", "phone": "+70376883846"}
0005432922528	2FC160	1286 894704	ALEKSANDR KUZNECOV	{"phone": "+70141960337"}
0005432922529	FD4F54	3699 596146	NINA KOROLEVA	{"email": "koroleva_nina_06121969@postgrespro.ru", "phone": "+70803361266"}
0005432922530	E68593	8266 522128	IRINA CHERNOVA	{"email": "i_chernova-21011976@postgrespro.ru", "phone": "+70798840324"}
0005432922531	5D7C49	2832 541321	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr031963@postgrespro.ru", "phone": "+70177802616"}
0005432922533	7BB194	7102 423283	ZINAIDA KARPOVA	{"email": "z.karpova111979@postgrespro.ru", "phone": "+70616564982"}
0005432922534	8344FB	2420 246040	KIRILL ANTONOV	{"email": "kirill-antonov-1966@postgrespro.ru", "phone": "+70100834522"}
0005432922535	B200E2	0816 756672	YURIY YAKOVLEV	{"phone": "+70040770033"}
0005432922536	4ABBA8	6514 172782	KLAVDIYA KOROLEVA	{"phone": "+70239168263"}
0005432922537	4ABBA8	1227 983338	PAVEL TIMOFEEV	{"email": "timofeevp-1981@postgrespro.ru", "phone": "+70483128012"}
0005432922538	057E7B	7300 371858	VLADIMIR NIKITIN	{"phone": "+70018628747"}
0005432922539	8288E4	3972 077202	SVETLANA BELYAEVA	{"email": "belyaeva_s.121964@postgrespro.ru", "phone": "+70548349968"}
0005432922540	A30124	6287 796863	LYUBOV MOROZOVA	{"email": "morozova.l-1968@postgrespro.ru", "phone": "+70196216272"}
0005432922541	BAB7A7	1426 695877	GALINA MATVEEVA	{"phone": "+70291615750"}
0005432922542	B1D3AC	6115 696580	ALEKSEY SMIRNOV	{"email": "a_smirnov.05101963@postgrespro.ru", "phone": "+70348695092"}
0005432922543	4380F8	7820 896439	YURIY MATVEEV	{"phone": "+70688333400"}
0005432922544	C00FE5	0163 648879	VITALIY PETROV	{"email": "petrov_vitaliy-1965@postgrespro.ru", "phone": "+70845002715"}
0005432922545	F0CB00	8504 773447	KONSTANTIN FROLOV	{"email": "frolovkonstantin_051969@postgrespro.ru", "phone": "+70273792368"}
0005432922546	38E929	2487 834814	NADEZHDA SOKOLOVA	{"email": "sokolova.n.071967@postgrespro.ru", "phone": "+70624592814"}
0005432922547	07EF4F	5728 600451	VALENTINA SEMENOVA	{"phone": "+70736052859"}
0005432922548	BE6963	1993 459393	YULIYA ILINA	{"phone": "+70339425739"}
0005432922549	9A6C71	8333 457061	RAMIL KUZNECOV	{"phone": "+70992950502"}
0005432922550	9A6C71	7330 563060	LYUDMILA KOVALEVA	{"email": "kovaleval-06021970@postgrespro.ru", "phone": "+70931365812"}
0005432922551	ECCD98	6329 188698	EVGENIY EGOROV	{"email": "evgeniy.egorov-17011969@postgrespro.ru", "phone": "+70738207408"}
0005432922552	34B5FA	9737 585959	ANNA KUZNECOVA	{"email": "kuznecova_anna_06121960@postgrespro.ru", "phone": "+70586924038"}
0005432922553	34B5FA	9555 014837	VALERIY VLASOV	{"email": "valeriy.vlasov19111972@postgrespro.ru", "phone": "+70381099585"}
0005432922554	FE86AF	3491 688885	ALEKSANDR SEMENOV	{"phone": "+70438883667"}
0005432922555	FE86AF	4681 216471	TATYANA BELYAEVA	{"phone": "+70085526199"}
0005432922556	72FA7A	0207 407199	SERGEY FOMIN	{"phone": "+70649377057"}
0005432922557	72FA7A	1842 377427	TATYANA ORLOVA	{"email": "t_orlova_031965@postgrespro.ru", "phone": "+70024212728"}
0005432922558	C8F7DB	4681 049292	OLESYA ORLOVA	{"email": "orlova.o_061977@postgrespro.ru", "phone": "+70096913532"}
0005432922559	E48058	3227 958521	OLGA PETROVA	{"phone": "+70778884688"}
0005432922560	3E705D	5617 686591	ALEKSANDR CHERNOV	{"email": "chernovaleksandr.081974@postgrespro.ru", "phone": "+70526331575"}
0005432922561	12F061	5700 101604	VIKTOR STEPANOV	{"email": "vstepanov.18031975@postgrespro.ru", "phone": "+70621068270"}
0005432922562	12F061	8485 362147	SERAFIMA LEBEDEVA	{"phone": "+70805509409"}
0005432922563	4A0FAC	5258 385752	VIOLETTA DENISOVA	{"phone": "+70850384872"}
0005432922564	4A0FAC	9864 479543	VLADIMIR ZHUKOV	{"phone": "+70622213605"}
0005432922565	E7FC4E	3018 419163	MIKHAIL KUZNECOV	{"email": "kuznecov-mikhail27121977@postgrespro.ru", "phone": "+70183067603"}
0005432922566	63DC8D	5236 808215	VIKTOR KOZLOV	{"email": "v_kozlov1976@postgrespro.ru", "phone": "+70691799965"}
0005432922567	7C5DD3	1160 670214	VIKTOR BELOV	{"email": "belov_v.051977@postgrespro.ru", "phone": "+70769961813"}
0005432922568	156AFB	0571 084225	TATYANA RODIONOVA	{"phone": "+70284776436"}
0005432922569	958F38	7675 448662	YURIY GAVRILOV	{"phone": "+70982219318"}
0005432922570	958F38	4919 016762	ANDREY PETROV	{"phone": "+70431396416"}
0005432922571	166F7E	5337 851261	NATALYA ILINA	{"email": "ilinanatalya-1973@postgrespro.ru", "phone": "+70628592270"}
0005432922572	B15CDD	9662 374749	LIDIYA VOROBEVA	{"email": "vorobevalidiya17101973@postgrespro.ru", "phone": "+70482289258"}
0005432922573	A3E784	3223 088314	GUZEL DMITRIEVA	{"email": "dmitrieva.guzel.101971@postgrespro.ru", "phone": "+70556528294"}
0005432922574	47418E	1570 417241	NADEZHDA POPOVA	{"email": "nadezhda_popova.1967@postgrespro.ru", "phone": "+70459174282"}
0005432922575	47418E	0430 077491	RAISA GUSEVA	{"phone": "+70757543776"}
0005432922576	A43B97	9340 041420	SERGEY ILIN	{"email": "ilinsergey_041971@postgrespro.ru", "phone": "+70970458209"}
0005432922577	A43B97	6944 355804	OLGA ABRAMOVA	{"email": "abramova_olga_11011970@postgrespro.ru", "phone": "+70069390527"}
0005432922578	DDD56E	4177 078533	DMITRIY NOVIKOV	{"email": "novikov-dmitriy.1965@postgrespro.ru", "phone": "+70580823094"}
0005432922579	DDD56E	3800 951509	TATYANA ORLOVA	{"phone": "+70840835151"}
0005432922580	DDD56E	0608 825746	ROMAN DENISOV	{"phone": "+70287430442"}
0005432922581	114FB8	4785 068637	GALIYA MIRONOVA	{"phone": "+70904711009"}
0005432922582	4F1C5A	1024 020179	YULIYA TITOVA	{"email": "titova.y-10101973@postgrespro.ru", "phone": "+70642248810"}
0005432922583	B3352A	4670 800872	VLADIMIR DENISOV	{"email": "denisov-v_031967@postgrespro.ru", "phone": "+70312345754"}
0005432922584	B3352A	0365 350203	ANTONINA MEDVEDEVA	{"phone": "+70279250758"}
0005432922585	67A331	3601 557938	TAMARA MELNIKOVA	{"email": "t.melnikova-021981@postgrespro.ru", "phone": "+70417527485"}
0005432922586	CD8C23	1348 249155	EVDOKIYA BOGDANOVA	{"email": "evdokiyabogdanova-09101974@postgrespro.ru", "phone": "+70767525004"}
0005432922587	941CAF	3436 044957	NINA SOROKINA	{"email": "sorokina_nina.1971@postgrespro.ru", "phone": "+70688681223"}
0005432922588	3A50DD	6246 190255	DMITRIY MAKAROV	{"email": "makarov.dmitriy.1983@postgrespro.ru", "phone": "+70053689773"}
0005432922589	F1DC9C	0750 298089	POLINA MOISEEVA	{"phone": "+70958316464"}
0005432922590	F1DC9C	5462 949609	ALEKSEY ANDREEV	{"phone": "+70069438080"}
0005432922591	F1DC9C	8013 680900	DAMIR SAVELEV	{"phone": "+70536347061"}
0005432922592	597C66	4757 557330	GRIGORIY MATVEEV	{"phone": "+70681555520"}
0005432922593	C1517B	1325 845408	LYUDMILA NESTEROVA	{"email": "lyudmila-nesterova.011972@postgrespro.ru", "phone": "+70290944173"}
0005432922594	C1517B	2170 532028	VYACHESLAV IVANOV	{"phone": "+70681826212"}
0005432922595	753830	8885 427779	OLGA ANDREEVA	{"phone": "+70076788473"}
0005432922596	DA0DBE	6744 632795	SERGEY TIKHONOV	{"email": "s-tikhonov.12011974@postgrespro.ru", "phone": "+70333898731"}
0005432922597	DA0DBE	2847 811325	OLEG ANTONOV	{"phone": "+70047537108"}
0005432922598	B31AB5	3463 317057	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov.061975@postgrespro.ru", "phone": "+70975502946"}
0005432922599	B31AB5	6128 036454	IVAN GUSEV	{"phone": "+70622545238"}
0005432922600	FF42D5	4755 578446	RAISA VLASOVA	{"email": "raisavlasova23071971@postgrespro.ru", "phone": "+70804524361"}
0005432922601	5E9D0F	5925 265168	VALERIY TARASOV	{"email": "tarasovvaleriy.29111972@postgrespro.ru", "phone": "+70665125158"}
0005432922602	18912D	9813 931106	ANNA KULIKOVA	{"email": "annakulikova-1973@postgrespro.ru", "phone": "+70490054051"}
0005432922603	103628	1964 615564	NATALYA POPOVA	{"email": "natalya-popova_29081970@postgrespro.ru", "phone": "+70673767631"}
0005432922604	BFB002	7878 277749	DMITRIY KOZLOV	{"email": "dmitriykozlov-091969@postgrespro.ru", "phone": "+70291232961"}
0005432922605	EC3621	6996 016366	NIKOLAY FEDOROV	{"phone": "+70209136038"}
0005432922606	EC3621	5036 972831	TATYANA MOISEEVA	{"phone": "+70847423101"}
0005432922607	F50749	7469 924774	MARIYA IVANOVA	{"phone": "+70418137570"}
0005432922608	F50749	7945 036732	DENIS PETROV	{"email": "petrov_d23061965@postgrespro.ru", "phone": "+70334620223"}
0005432922609	95EC11	5121 287459	EKATERINA DAVYDOVA	{"email": "davydova_ekaterina17101978@postgrespro.ru", "phone": "+70972845074"}
0005432922610	95EC11	6339 521495	ALEKSEY ISAEV	{"email": "isaevaleksey-03011977@postgrespro.ru", "phone": "+70720527844"}
0005432922611	F0FC6C	6402 953959	ALEKSEY VLASOV	{"email": "vlasov-a1969@postgrespro.ru", "phone": "+70245706457"}
0005432922612	D76EF2	7315 639834	SNEZHANA NOVIKOVA	{"phone": "+70671158775"}
0005432922613	7E3A69	0166 429980	ANNA KULIKOVA	{"email": "kulikova_a-1974@postgrespro.ru", "phone": "+70479473434"}
0005432922614	1E6633	4829 806368	VALENTINA ANTONOVA	{"email": "v.antonova18091973@postgrespro.ru", "phone": "+70647044706"}
0005432922615	722D49	9572 802156	TAMARA KOMAROVA	{"email": "t_komarova-09081963@postgrespro.ru", "phone": "+70787529847"}
0005432922616	B72391	7143 404267	SVETLANA KOMAROVA	{"phone": "+70923560593"}
0005432922617	C93B87	8097 163092	PAVEL FILIPPOV	{"email": "pfilippov-1968@postgrespro.ru", "phone": "+70770879928"}
0005432922618	1C076A	4580 864125	ANTON MATVEEV	{"email": "matveev.anton21011957@postgrespro.ru", "phone": "+70446583329"}
0005432922619	A4BBDB	0074 845971	EVGENIY POPOV	{"email": "popov-e.031968@postgrespro.ru", "phone": "+70033081272"}
0005432922620	581FB7	6340 452829	SERGEY IVANOV	{"phone": "+70993124057"}
0005432922621	A6CAF8	8839 449245	ALEKSEY VASILEV	{"email": "vasilev-aleksey_1977@postgrespro.ru", "phone": "+70146501817"}
0005432922622	365CC9	6484 695116	MAKSIM STEPANOV	{"email": "stepanovm-1974@postgrespro.ru", "phone": "+70383223472"}
0005432922623	365CC9	1996 842474	SERGEY KOROLEV	{"email": "sergey-korolev.071967@postgrespro.ru", "phone": "+70447980528"}
0005432922624	ACAB4E	3196 105983	ALEKSEY MIRONOV	{"phone": "+70085986401"}
0005432922625	ACAB4E	5924 757153	DARYA KUZMINA	{"email": "d_kuzmina1962@postgrespro.ru", "phone": "+70599675616"}
0005432922626	ACAB4E	9368 548028	VASILIY KISELEV	{"email": "vkiselev_021958@postgrespro.ru", "phone": "+70182543638"}
0005432922627	ACAB4E	6033 460721	VALENTINA FEDOROVA	{"email": "fedorova_v-1962@postgrespro.ru", "phone": "+70863560650"}
0005432922628	3073FA	2401 143808	VLADIMIR MOROZOV	{"phone": "+70270766454"}
0005432922629	EF4837	0325 315155	MARIYA KOLESNIKOVA	{"email": "kolesnikova-mariya.18041980@postgrespro.ru", "phone": "+70952288999"}
0005432922630	36DD04	0502 533817	MARINA MEDVEDEVA	{"email": "mmedvedeva.031974@postgrespro.ru", "phone": "+70808212488"}
0005432922631	779945	0248 161348	MAKSIM EGOROV	{"email": "egorovm_1974@postgrespro.ru", "phone": "+70123126512"}
0005432922632	4B47FC	9906 056280	SERGEY ISAEV	{"email": "sergeyisaev21101963@postgrespro.ru", "phone": "+70006231497"}
0005432922633	4B47FC	0099 829698	ELENA BORISOVA	{"email": "e-borisova15071964@postgrespro.ru", "phone": "+70800138711"}
0005432922634	FECCBA	6890 386216	LYUDMILA ARKHIPOVA	{"email": "arkhipova.l.021974@postgrespro.ru", "phone": "+70395586417"}
0005432922635	FECCBA	6324 173923	OKSANA NOVIKOVA	{"email": "o_novikova071973@postgrespro.ru", "phone": "+70160460756"}
0005432922636	30DD63	5777 508984	ROMAN MARTYNOV	{"email": "romanmartynov1969@postgrespro.ru", "phone": "+70815783024"}
0005432922637	55E7E0	8286 014009	ANNA SERGEEVA	{"email": "sergeeva_anna.041974@postgrespro.ru", "phone": "+70131523326"}
0005432922638	6334B8	2288 258695	GRIGORIY VOLKOV	{"phone": "+70296608615"}
0005432922639	4F7287	6745 415406	VALENTINA NESTEROVA	{"email": "nesterova_valentina-1965@postgrespro.ru", "phone": "+70326530862"}
0005432922640	4F7287	8441 393235	ELENA KUZNECOVA	{"email": "ekuznecova_03101968@postgrespro.ru", "phone": "+70679468135"}
0005432924951	85151D	6235 265386	IGOR NIKOLAEV	{"email": "igor.nikolaev_121977@postgrespro.ru", "phone": "+70836135474"}
0005432924952	85151D	9505 934277	DMITRIY KUDRYASHOV	{"email": "kudryashov_d_13031982@postgrespro.ru", "phone": "+70631044324"}
0005432924953	6257B0	6729 332823	MIKHAIL OSIPOV	{"email": "m.osipov.22081960@postgrespro.ru", "phone": "+70470703641"}
0005432924954	9A019E	7953 796947	VITALIY MAKAROV	{"phone": "+70951860197"}
0005432924955	BE3AA6	3916 129173	ANTON PAVLOV	{"email": "pavlovanton081967@postgrespro.ru", "phone": "+70278617127"}
0005432924956	6AABB6	7239 741558	DMITRIY SOROKIN	{"email": "sorokin-dmitriy-1965@postgrespro.ru", "phone": "+70898635715"}
0005432924957	EDA722	8884 886294	VADIM FEDOTOV	{"email": "v.fedotov.1972@postgrespro.ru", "phone": "+70494021523"}
0005432924958	BB0480	8750 276701	SVETLANA KOMAROVA	{"email": "komarova.svetlana_1971@postgrespro.ru", "phone": "+70556027063"}
0005432924959	EB178F	1774 021790	VIKTORIYA VOLKOVA	{"phone": "+70136985515"}
0005432924960	D4CF5D	1774 479218	OLGA KOZLOVA	{"phone": "+70429017793"}
0005432924961	10D034	1704 595131	RIMMA MATVEEVA	{"phone": "+70550379440"}
0005432924962	739D80	0257 895635	VIKTOR ILIN	{"email": "v-ilin_12051982@postgrespro.ru", "phone": "+70716526653"}
0005432924963	739D80	8203 168996	OLGA KOZLOVA	{"phone": "+70950540117"}
0005432924964	D4F4C7	2312 772063	NINA KUZMINA	{"email": "kuzmina.nina.081980@postgrespro.ru", "phone": "+70443958060"}
0005432924965	D4F4C7	2073 528045	MARTA VOROBEVA	{"phone": "+70350582995"}
0005432924966	D4F4C7	0207 180781	GALINA CHERNOVA	{"phone": "+70783476007"}
0005432924967	6499CF	9184 472691	MARIYA GERASIMOVA	{"phone": "+70029991911"}
0005432924968	23A989	2664 850669	VASILIY ANDREEV	{"phone": "+70674818989"}
0005432924969	23A989	1484 380305	YANA IVANOVA	{"email": "ivanovay_071977@postgrespro.ru", "phone": "+70801175768"}
0005432924970	F4640F	0216 564955	NATALYA MIKHAYLOVA	{"phone": "+70946764385"}
0005432924971	E9C72B	6441 240536	DARYA DENISOVA	{"phone": "+70277049079"}
0005432924972	F1DC5B	5800 593985	NIKOLAY ZAKHAROV	{"email": "zakharovn.011977@postgrespro.ru", "phone": "+70721732546"}
0005432924973	F1DC5B	6966 774162	SOFYA STEPANOVA	{"phone": "+70685227833"}
0005432924974	500904	6765 871770	ELENA VLASOVA	{"email": "elena.vlasova.041958@postgrespro.ru", "phone": "+70986500130"}
0005432924975	FBC510	1335 450805	GALINA DANILOVA	{"phone": "+70007704907"}
0005432924976	FBC510	9560 635800	EKATERINA PETROVA	{"email": "e-petrova_1976@postgrespro.ru", "phone": "+70157445327"}
0005432924977	26D5E8	8528 416119	YANA YAKOVLEVA	{"phone": "+70282693761"}
0005432924978	8A114F	5141 916998	EVGENIY NAUMOV	{"email": "e.naumov-30031970@postgrespro.ru", "phone": "+70009150069"}
0005432924979	B298BD	8796 983489	OLGA VOLKOVA	{"email": "volkovaolga.041969@postgrespro.ru", "phone": "+70469156411"}
0005432924980	D967B1	1681 650420	ELENA SCHERBAKOVA	{"email": "escherbakova04121975@postgrespro.ru", "phone": "+70139247225"}
0005432924981	D967B1	0138 633792	SERGEY ORLOV	{"email": "orlovs.1967@postgrespro.ru", "phone": "+70753336878"}
0005432924982	5FFFBD	7258 975250	ROMAN EGOROV	{"phone": "+70803249567"}
0005432924983	5FFFBD	4402 659989	PAVEL KOROLEV	{"phone": "+70681136963"}
0005432924984	867A5D	8307 786098	LYUDMILA YUDINA	{"email": "lyudmila.yudina-011979@postgrespro.ru", "phone": "+70637715271"}
0005432924985	6F6E5B	2153 225788	ALEFTINA IVANOVA	{"email": "a_ivanova04011978@postgrespro.ru", "phone": "+70345912373"}
0005432924986	AE7551	6812 863663	PAVEL POPOV	{"email": "p_popov_091978@postgrespro.ru", "phone": "+70039170218"}
0005432924987	AE7551	7026 984649	ALEKSANDR ZHUKOV	{"phone": "+70763035231"}
0005432924988	BAC56C	5398 996098	LYUDMILA NESTEROVA	{"phone": "+70015325905"}
0005432924989	98DE2B	4198 992532	VADIM PETROV	{"email": "petrov_v-1968@postgrespro.ru", "phone": "+70434243865"}
0005432924990	98DE2B	0512 824133	RUSLAN KUZMIN	{"email": "rkuzmin_25081966@postgrespro.ru", "phone": "+70386926885"}
0005432924991	3688FD	7784 172866	OLEG KAZAKOV	{"phone": "+70757770806"}
0005432924992	3688FD	8253 662349	ELENA KUZMINA	{"email": "kuzminae29111963@postgrespro.ru", "phone": "+70977641752"}
0005432924993	F7CE27	5089 298180	DMITRIY ISAEV	{"phone": "+70944991302"}
0005432924994	F7CE27	3647 033714	ZHANNA MALYSHEVA	{"phone": "+70764140907"}
0005432924995	BF7847	3841 208164	ELENA STEPANOVA	{"phone": "+70234170763"}
0005432924996	91D2FD	1535 432431	RUSTAM BORISOV	{"email": "borisovr-121960@postgrespro.ru", "phone": "+70929965174"}
0005432924997	FDBBCE	6350 599629	NATALYA NOVIKOVA	{"email": "n.novikova-1978@postgrespro.ru", "phone": "+70518794641"}
0005432924998	FDBBCE	0702 867297	KRISTINA OVCHINNIKOVA	{"phone": "+70710649554"}
0005432924999	27039F	6968 178035	VALENTINA ANISIMOVA	{"email": "anisimova-v.1974@postgrespro.ru", "phone": "+70981772981"}
0005432925000	863C29	3650 049401	VLADISLAV AFANASEV	{"phone": "+70972280945"}
0005432925001	128322	2210 185871	ALEKSANDR CHERNOV	{"email": "aleksandr.chernov.1965@postgrespro.ru", "phone": "+70081431928"}
0005432925002	12E45F	7215 383986	VERA MAKAROVA	{"phone": "+70424154447"}
0005432925003	12E45F	5287 563288	IGOR OSIPOV	{"phone": "+70757401117"}
0005432925004	D85022	0141 920524	ALEKSANDR FROLOV	{"phone": "+70712548640"}
0005432925005	CC1133	8995 545872	KONSTANTIN SIDOROV	{"phone": "+70968645263"}
0005432925006	0F46D7	6755 527356	IRINA POTAPOVA	{"phone": "+70851968332"}
0005432925007	E00B86	5366 091675	ALENA MEDVEDEVA	{"phone": "+70078663773"}
0005432925008	C47F84	3572 287742	OLEG SOKOLOV	{"email": "oleg.sokolov-1973@postgrespro.ru", "phone": "+70383003738"}
0005432925009	7DE7C9	0119 066747	TATYANA NIKITINA	{"phone": "+70623133113"}
0005432925010	291321	5856 991624	OLGA ZHURAVLEVA	{"phone": "+70116228097"}
0005432925011	291321	8892 429446	VALENTIN NIKITIN	{"email": "nikitin-v061972@postgrespro.ru", "phone": "+70213125293"}
0005432925012	CB9EF9	8457 910218	ANATOLIY MARTYNOV	{"email": "martynov_anatoliy.14081979@postgrespro.ru", "phone": "+70677324907"}
0005432925013	614148	1125 501815	ELENA SEMENOVA	{"email": "elena.semenova051973@postgrespro.ru", "phone": "+70611049457"}
0005432925014	614148	4311 830038	VALERIY MOROZOV	{"phone": "+70980433595"}
0005432925015	565946	2389 220491	YAN TIKHONOV	{"phone": "+70420337226"}
0005432925016	BE3330	4381 933051	ELENA OVCHINNIKOVA	{"email": "ovchinnikovaelena_121968@postgrespro.ru", "phone": "+70682539174"}
0005432925017	BB1403	2740 743530	MIKHAIL MEDVEDEV	{"phone": "+70019083489"}
0005432925018	1A6B29	7175 760199	SERGEY TARASOV	{"phone": "+70612052711"}
0005432925019	1A6B29	4016 167361	NADEZHDA IVANOVA	{"email": "ivanovanadezhda12051967@postgrespro.ru", "phone": "+70288922988"}
0005432925020	488B56	1740 190744	ALEKSEY KULIKOV	{"email": "kulikov_aleksey-1962@postgrespro.ru", "phone": "+70806627707"}
0005432925021	137442	1229 299514	SERGEY GRIGOREV	{"phone": "+70891409613"}
0005432925022	137442	6734 733053	YULIYA IVANOVA	{"phone": "+70091419111"}
0005432925023	9983EE	0023 338964	VLADIMIR ALEKSEEV	{"phone": "+70638115778"}
0005432925024	60C949	4674 601815	MILANA KOLESNIKOVA	{"email": "kolesnikovamilana.1972@postgrespro.ru", "phone": "+70291562468"}
0005432925025	4BA35F	8375 887113	ARKADIY SMIRNOV	{"phone": "+70155362732"}
0005432925026	E3B09C	1344 569456	YULIYA VASILEVA	{"email": "vasileva-y.021965@postgrespro.ru", "phone": "+70411819946"}
0005432925027	4F456D	5137 761129	ZOYA EGOROVA	{"email": "zoyaegorova.05011968@postgrespro.ru", "phone": "+70142980018"}
0005432925028	4F456D	9670 329646	LIDIYA KOZLOVA	{"email": "kozlova-l_1967@postgrespro.ru", "phone": "+70197229759"}
0005432925029	C661D1	0024 542753	ELENA BORISOVA	{"email": "elenaborisova_07041979@postgrespro.ru", "phone": "+70020221815"}
0005432925030	1C13E6	4147 920410	OLGA ROMANOVA	{"phone": "+70950327102"}
0005432925031	8435F4	2588 603080	SERGEY BORISOV	{"email": "s.borisov.011971@postgrespro.ru", "phone": "+70394826920"}
0005432925032	8435F4	8905 839614	SERGEY SOROKIN	{"email": "sorokin_s_1962@postgrespro.ru", "phone": "+70673753077"}
0005432925033	8F9416	0494 731641	DMITRIY SERGEEV	{"email": "sergeev_d-1983@postgrespro.ru", "phone": "+70479988851"}
0005432925034	8F9416	2054 356996	IGOR ZAKHAROV	{"email": "izakharov-111979@postgrespro.ru", "phone": "+70469889729"}
0005432925035	F4A7B8	8730 256842	PETR MAKAROV	{"email": "p-makarov_1957@postgrespro.ru", "phone": "+70206238459"}
0005432925036	B70F64	4246 459704	IRINA KRASNOVA	{"email": "i_krasnova-081971@postgrespro.ru", "phone": "+70251391473"}
0005432925037	63A583	9846 561047	ALI MIRONOV	{"phone": "+70682198355"}
0005432925038	EEB45D	8632 031055	YULIYA MOROZOVA	{"phone": "+70601017303"}
0005432925039	235D8E	6230 845207	ALEKSEY NIKOLAEV	{"phone": "+70409768346"}
0005432925040	A88FAB	4493 406808	TATYANA KARPOVA	{"phone": "+70426666343"}
0005432925041	A88FAB	7085 013699	MARIANNA NIKITINA	{"email": "marianna_nikitina_121979@postgrespro.ru", "phone": "+70238722929"}
0005432925042	598D93	0781 613627	VIKTOR FROLOV	{"phone": "+70201721410"}
0005432925043	845AAE	4606 751039	IRINA SMIRNOVA	{"email": "smirnova.irina-071983@postgrespro.ru", "phone": "+70735449380"}
0005432925044	FF7C8E	5875 225739	VIKTORIYA EFIMOVA	{"phone": "+70599906252"}
0005432925045	E2F867	3828 669731	ANTON KRASNOV	{"phone": "+70178231407"}
0005432925046	E2F867	8364 367904	MARIYA GRISHINA	{"email": "grishina.mariya11111968@postgrespro.ru", "phone": "+70750501883"}
0005432925047	9A5BBF	1760 055684	NINA VASILEVA	{"phone": "+70242280905"}
0005432925048	FEA755	3041 747265	OLGA PETROVA	{"email": "olgapetrova041987@postgrespro.ru", "phone": "+70700018919"}
0005432925049	74460D	8463 826360	ALEKSEY GERASIMOV	{"email": "gerasimov-a-1969@postgrespro.ru", "phone": "+70775709030"}
0005432925050	86F835	3195 844888	DARYA CHERNOVA	{"email": "chernova-darya.041971@postgrespro.ru", "phone": "+70245551698"}
0005432925051	CB571A	2312 094962	IRINA YAKOVLEVA	{"phone": "+70026842041"}
0005432925052	A87ED6	9969 381819	YURIY NIKOLAEV	{"phone": "+70820446334"}
0005432925053	A87ED6	1819 302144	MARINA KUZMINA	{"email": "kuzmina_marina.061974@postgrespro.ru", "phone": "+70887184069"}
0005432925054	EBC349	2223 415952	EDUARD VOLKOV	{"email": "volkove.081967@postgrespro.ru", "phone": "+70846797036"}
0005432925055	EBC349	9346 656072	VALENTINA FEDOROVA	{"phone": "+70869208771"}
0005432925056	EBC349	2880 441341	TATYANA LEBEDEVA	{"email": "tatyana_lebedeva.04041971@postgrespro.ru", "phone": "+70725768932"}
0005432925057	F39070	6261 560699	ALEKSEY PETROV	{"phone": "+70417238666"}
0005432925058	03141B	1738 283642	RAISA EFIMOVA	{"phone": "+70156276696"}
0005432925059	03141B	1118 413162	IRINA ILINA	{"email": "ilina.irina1977@postgrespro.ru", "phone": "+70576445585"}
0005432925060	D1FC25	7527 759584	ANDREY ILIN	{"phone": "+70378429060"}
0005432925061	81117F	0725 651174	DARYA GUSEVA	{"email": "d_guseva051981@postgrespro.ru", "phone": "+70204124082"}
0005432925062	A7C746	3725 947666	DMITRIY IVANOV	{"email": "dmitriy_ivanov_061974@postgrespro.ru", "phone": "+70109589392"}
0005432925063	BB2511	0952 302128	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov_24081974@postgrespro.ru", "phone": "+70300202385"}
0005432925064	BB2511	3379 077799	STEPAN KAZAKOV	{"email": "s.kazakov_101986@postgrespro.ru", "phone": "+70531873155"}
0005432925065	98DAAD	2397 804635	MARINA VASILEVA	{"phone": "+70205538274"}
0005432925066	98DAAD	2281 397149	OLEG MATVEEV	{"email": "o_matveev-23031983@postgrespro.ru", "phone": "+70041550036"}
0005432925067	720EEC	0505 291008	ALEKSANDR SOLOVEV	{"phone": "+70795703488"}
0005432925068	4B27C2	9663 961622	NATALYA FEDOROVA	{"phone": "+70784308006"}
0005432925069	76D728	2528 326715	SERGEY NIKITIN	{"email": "sergey_nikitin_11111973@postgrespro.ru", "phone": "+70605750126"}
0005432925070	9B19C9	5446 809073	ANASTASIYA VOROBEVA	{"email": "anastasiya_vorobeva_1975@postgrespro.ru", "phone": "+70518779882"}
0005432925071	9B19C9	6492 607281	MIKHAIL KARPOV	{"email": "m-karpov.1961@postgrespro.ru", "phone": "+70350539018"}
0005432925072	FB5854	3732 783107	TIMUR SOKOLOV	{"email": "sokolov.timur_04121970@postgrespro.ru", "phone": "+70235658251"}
0005432925073	65ED00	2268 092545	TAMARA BOGDANOVA	{"email": "bogdanova-t_1962@postgrespro.ru", "phone": "+70446353087"}
0005432925074	6F1FF7	5764 220166	NINA KOMAROVA	{"phone": "+70847093807"}
0005432925075	6F1FF7	1390 925873	ELENA KAZAKOVA	{"phone": "+70554557221"}
0005432925076	BD61DA	1739 838075	ANNA DMITRIEVA	{"phone": "+70611463910"}
0005432925077	BD61DA	6345 607526	NATALYA POPOVA	{"email": "popova.n121972@postgrespro.ru", "phone": "+70036475767"}
0005432925078	A6F0A4	5372 893490	IRINA IVANOVA	{"phone": "+70430470576"}
0005432925079	A6F0A4	3172 879074	VALENTINA YAKOVLEVA	{"email": "vyakovleva.041974@postgrespro.ru", "phone": "+70957688990"}
0005432925080	A8D8B1	0626 197733	MAKSIM TARASOV	{"email": "m-tarasov.071977@postgrespro.ru", "phone": "+70194200736"}
0005432925081	A8D8B1	6113 617606	TATYANA MIKHAYLOVA	{"phone": "+70107359074"}
0005432925082	CD0F3E	8362 946474	ANASTASIYA DAVYDOVA	{"phone": "+70559227830"}
0005432925083	BF1A4F	8901 473498	MARGARITA POLYAKOVA	{"email": "margarita_polyakova_24111974@postgrespro.ru", "phone": "+70058536229"}
0005432925084	EA4941	3659 565565	DARYA ZOTOVA	{"phone": "+70456974306"}
0005432925085	3AA2F2	5268 899368	GRIGORIY MELNIKOV	{"email": "g.melnikov.071974@postgrespro.ru", "phone": "+70041989380"}
0005432925086	3AA2F2	5999 550945	MIKHAIL GRIGOREV	{"email": "mikhail_grigorev-1960@postgrespro.ru", "phone": "+70981548199"}
0005432925087	7D71BB	0085 114517	ALEKSANDR ZHUKOV	{"phone": "+70024428187"}
0005432925088	453D47	1275 831021	ALINA TROFIMOVA	{"email": "a-trofimova.19081979@postgrespro.ru", "phone": "+70303396747"}
0005432925089	453D47	5957 615625	EKATERINA BELOVA	{"email": "ebelova1976@postgrespro.ru", "phone": "+70789496186"}
0005432925090	ABFF5E	7633 249049	OLGA GORBUNOVA	{"email": "gorbunova_o.16121974@postgrespro.ru", "phone": "+70121370634"}
0005432925091	ABFF5E	1814 106656	ILYA GRIGOREV	{"email": "ilya_grigorev1972@postgrespro.ru", "phone": "+70519837656"}
0005432925092	E6009A	0796 999938	RUSLAN KUZNECOV	{"email": "kuznecov.r_1971@postgrespro.ru", "phone": "+70232378311"}
0005432925093	81AB83	1624 212082	NIKOLAY MATVEEV	{"phone": "+70031592115"}
0005432925094	309558	7213 415406	DANA ALEKSEEVA	{"email": "alekseeva_d081966@postgrespro.ru", "phone": "+70609982468"}
0005432925095	309558	6077 083785	TATYANA NOVIKOVA	{"phone": "+70286065254"}
0005432925096	2739E3	5855 757367	TATYANA AFANASEVA	{"phone": "+70677107135"}
0005432925097	21DBA7	4272 178211	ALEKSANDR KOZLOV	{"phone": "+70825853963"}
0005432925098	BA38D0	5608 351844	VERA KUZNECOVA	{"phone": "+70745764467"}
0005432925099	B993BA	7978 686759	VITALIY BARANOV	{"email": "vitaliybaranov1985@postgrespro.ru", "phone": "+70109096157"}
0005432925100	B993BA	2435 843109	LARISA KARPOVA	{"email": "karpoval1974@postgrespro.ru", "phone": "+70723086370"}
0005432925101	8AA517	7136 962302	GALINA SEMENOVA	{"phone": "+70167126308"}
0005432925102	8AA517	7430 487973	ANASTASIYA ROMANOVA	{"phone": "+70092096958"}
0005432925103	463C28	6409 524458	GENNADIY SCHERBAKOV	{"phone": "+70344105645"}
0005432925104	8A57CB	6853 261350	NIKOLAY IVANOV	{"phone": "+70548218096"}
0005432925105	D38CB8	9532 698371	TATYANA DMITRIEVA	{"email": "dmitrievatatyana-08121974@postgrespro.ru", "phone": "+70256954787"}
0005432925106	D38CB8	0959 652468	NINA MAKSIMOVA	{"phone": "+70672007380"}
0005432925107	D38CB8	7934 701310	SVETLANA GORBUNOVA	{"email": "svetlana_gorbunova-041974@postgrespro.ru", "phone": "+70659591083"}
0005432925108	809BFD	4521 217599	ALENA SOROKINA	{"email": "asorokina_28091973@postgrespro.ru", "phone": "+70894367736"}
0005432925109	CEE5AC	3624 166437	ANDREY RODIONOV	{"email": "rodionova_051966@postgrespro.ru", "phone": "+70204769066"}
0005432925110	253347	8866 944468	ALEKSANDR IVANOV	{"email": "a-ivanov_071971@postgrespro.ru", "phone": "+70048351232"}
0005432925111	D9BDDF	5025 510171	VLADIMIR FILIPPOV	{"email": "vladimir-filippov.14091979@postgrespro.ru", "phone": "+70421581621"}
0005432925112	8684A8	0793 076275	ANTONINA KUDRYASHOVA	{"email": "kudryashova-a.20101973@postgrespro.ru", "phone": "+70141094746"}
0005432925113	8684A8	6016 443514	STANISLAV NAZAROV	{"email": "stanislav.nazarov-07011971@postgrespro.ru", "phone": "+70945200689"}
0005432925114	EEC3C8	5762 331828	MARIYA DMITRIEVA	{"email": "mariyadmitrieva.121980@postgrespro.ru", "phone": "+70257240369"}
0005432925115	EEC3C8	0779 553943	ALEKSEY NOVIKOV	{"phone": "+70956699598"}
0005432925116	50DDBF	1923 616333	OLGA ALEKSEEVA	{"email": "alekseeva-olga.1967@postgrespro.ru", "phone": "+70285717927"}
0005432925117	8D51AD	1707 398059	SERGEY ORLOV	{"phone": "+70845445161"}
0005432925118	8D51AD	3408 489499	PAVEL SAVELEV	{"email": "savelev-pavel-20011971@postgrespro.ru", "phone": "+70455532969"}
0005432925119	BECF4F	5067 186961	VALERIY IVANOV	{"phone": "+70295120276"}
0005432925120	3D2684	7153 131952	VLADIMIR YAKOVLEV	{"email": "vladimir.yakovlev-20121969@postgrespro.ru", "phone": "+70580493428"}
0005432925121	3D2684	2549 155407	DENIS KAZAKOV	{"email": "kazakov-d_111952@postgrespro.ru", "phone": "+70246045475"}
0005432925122	E27114	5217 485284	YANA GUSEVA	{"phone": "+70158131100"}
0005432925123	E27114	9173 526934	ILYA BORISOV	{"email": "borisov.ilya081959@postgrespro.ru", "phone": "+70170428912"}
0005432925124	E27114	6462 178885	EVGENIY VASILEV	{"email": "vasilev_e.01091969@postgrespro.ru", "phone": "+70071982100"}
0005432925125	8791D0	4966 187895	SERGEY IVANOV	{"email": "sergey_ivanov02051965@postgrespro.ru", "phone": "+70907631034"}
0005432925126	2A5624	2837 545266	MARIYA ZOTOVA	{"email": "zotova-mariya_23111961@postgrespro.ru", "phone": "+70242454634"}
0005432925127	A87ADE	2294 746812	LYUBOV DMITRIEVA	{"phone": "+70252687804"}
0005432925128	6B4BCF	3421 658696	VERA MATVEEVA	{"email": "v-matveeva.04051985@postgrespro.ru", "phone": "+70600460398"}
0005432925129	6B4BCF	3992 871481	ADELINA VOLKOVA	{"email": "volkova.a-17011982@postgrespro.ru", "phone": "+70595195569"}
0005432925130	B61A51	4838 726366	ALEKSANDR MIKHAYLOV	{"phone": "+70998724019"}
0005432925131	D78F23	2505 895815	IRINA PAVLOVA	{"email": "pavlova_i_02041970@postgrespro.ru", "phone": "+70021871278"}
0005432925132	D78F23	5306 681617	NIKOLAY ALEKSEEV	{"phone": "+70802635608"}
0005432925133	6916D1	4649 258273	MARINA MAKSIMOVA	{"phone": "+70071808098"}
0005432925134	30E42D	4020 579606	VALERIY SERGEEV	{"phone": "+70752640920"}
0005432925135	30E42D	3872 682262	TAMARA IVANOVA	{"email": "t-ivanova_1983@postgrespro.ru", "phone": "+70352840924"}
0005432925136	4571DE	0115 180416	ALEKSANDR NIKITIN	{"email": "nikitin-a_121970@postgrespro.ru", "phone": "+70601926182"}
0005432925137	4571DE	9623 619402	NIKOLAY GUSEV	{"email": "gusev-nikolay-1972@postgrespro.ru", "phone": "+70890622396"}
0005432925138	CE35FD	7430 716947	ELENA MELNIKOVA	{"email": "e.melnikova.20021975@postgrespro.ru", "phone": "+70489069207"}
0005432925139	CE35FD	8658 867411	TATYANA MASLOVA	{"phone": "+70638105349"}
0005432925140	5E0A36	4237 694049	ALEKSANDR SAVELEV	{"email": "savelev-aleksandr061970@postgrespro.ru", "phone": "+70718151115"}
0005432925141	CC6491	2641 070203	MARINA FEDOROVA	{"phone": "+70253825972"}
0005432925142	65E1F8	3478 980338	TAMARA MAKAROVA	{"email": "t-makarova_1959@postgrespro.ru", "phone": "+70983333736"}
0005432925143	65E1F8	0758 420607	SERGEY NOVIKOV	{"email": "snovikov_121968@postgrespro.ru", "phone": "+70147511280"}
0005432925144	65E1F8	7237 991883	ROMAN TARASOV	{"phone": "+70641683853"}
0005432925145	881D74	4968 133346	VITALIY FROLOV	{"phone": "+70581186436"}
0005432925146	881D74	8929 116034	IGOR POPOV	{"email": "igor_popov09101971@postgrespro.ru", "phone": "+70367842466"}
0005432925147	C81430	2417 548376	ALEKSANDR ZHURAVLEV	{"phone": "+70048304697"}
0005432925148	C81430	9452 391737	NADEZHDA NOVIKOVA	{"phone": "+70471235442"}
0005432925149	B3AFB3	6719 983414	GENNADIY GORBUNOV	{"email": "g_gorbunov_15061976@postgrespro.ru", "phone": "+70478954169"}
0005432925150	60517A	3994 469620	GALINA ERMAKOVA	{"email": "g_ermakova_011975@postgrespro.ru", "phone": "+70207874907"}
0005432925151	2D9CD3	8992 549188	ALEKSANDR POPOV	{"phone": "+70815738145"}
0005432925152	5BF672	4505 446163	ELENA ZAKHAROVA	{"email": "zakharovaelena_011967@postgrespro.ru", "phone": "+70419886214"}
0005432925153	5BF672	0949 441306	ALEKSANDR STEPANOV	{"phone": "+70525595884"}
0005432925154	ADBCCF	0797 661451	ELENA SEMENOVA	{"phone": "+70392956730"}
0005432925155	990C99	6626 881695	VALERIY SCHERBAKOV	{"email": "scherbakov_valeriy.041967@postgrespro.ru", "phone": "+70062378969"}
0005432925156	179136	0534 844621	PAVEL BORISOV	{"phone": "+70540898979"}
0005432925157	179136	6423 057804	NATALYA SCHERBAKOVA	{"phone": "+70453223271"}
0005432925158	179136	5412 594689	MAKSIM NAUMOV	{"email": "mnaumov-22021971@postgrespro.ru", "phone": "+70009645476"}
0005432925159	4E5A5C	2551 262975	NINA BARANOVA	{"email": "baranovanina1974@postgrespro.ru", "phone": "+70171803272"}
0005432925160	F4ED64	1720 449573	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov.1973@postgrespro.ru", "phone": "+70909266655"}
0005432925161	6D962E	1095 241811	GEORGIY KUZNECOV	{"email": "georgiykuznecov.1971@postgrespro.ru", "phone": "+70982525328"}
0005432925162	38F924	2287 121391	ALEKSANDR KRASNOV	{"phone": "+70948135294"}
0005432925163	38F924	9366 094173	ALEKSANDR MELNIKOV	{"email": "a.melnikov.1968@postgrespro.ru", "phone": "+70309693608"}
0005432925164	5037D9	9547 123120	TATYANA YUDINA	{"phone": "+70827075060"}
0005432925165	F2D869	0030 672107	RAFAEL RODIONOV	{"phone": "+70199134910"}
0005432925166	D21822	1278 510962	ANASTASIYA GAVRILOVA	{"email": "anastasiyagavrilova-30121974@postgrespro.ru", "phone": "+70457205636"}
0005432925167	63B057	9761 353476	EGOR KUZNECOV	{"phone": "+70258989268"}
0005432925168	19DADD	8277 661080	YULIYA KRASNOVA	{"email": "yuliyakrasnova20061959@postgrespro.ru", "phone": "+70348536666"}
0005432925169	19DADD	6796 304105	LYUDMILA MELNIKOVA	{"phone": "+70354462741"}
0005432925170	05809F	2824 736649	IRINA BOGDANOVA	{"phone": "+70404471137"}
0005432925171	05809F	5328 798274	EVGENIY NIKOLAEV	{"phone": "+70980882060"}
0005432925172	1577C0	5613 760973	NIKOLAY BONDARENKO	{"phone": "+70080362409"}
0005432925173	4224D0	4634 072947	IGOR MARTYNOV	{"email": "martynov-i-031969@postgrespro.ru", "phone": "+70797181275"}
0005432925174	4224D0	3197 362813	NATALYA SMIRNOVA	{"email": "n.smirnova-1973@postgrespro.ru", "phone": "+70843085607"}
0005432925175	DDDAE5	2838 024434	ALEKSANDR SERGEEV	{"phone": "+70567730995"}
0005432925176	D31CF9	2365 369673	VASILIY GORBUNOV	{"phone": "+70955579492"}
0005432925177	D31CF9	7386 222219	NIKOLAY NIKOLAEV	{"email": "nikolaev_nikolay_02031976@postgrespro.ru", "phone": "+70016881949"}
0005432925178	D31CF9	1863 609263	OLGA KUZNECOVA	{"email": "olga-kuznecova.011975@postgrespro.ru", "phone": "+70234163951"}
0005432927885	BEBCA6	9269 703680	ANDREY KUZNECOV	{"email": "kuznecov_andrey1967@postgrespro.ru", "phone": "+70700330043"}
0005432927886	6D9C13	8929 930374	DARYA BARANOVA	{"email": "dbaranova15111962@postgrespro.ru", "phone": "+70292028271"}
0005432927887	3D7516	8730 805342	MAKSIM VASILEV	{"phone": "+70870639214"}
0005432927888	B4F3B8	1141 384564	ANNA ILINA	{"email": "ilina_anna.23011979@postgrespro.ru", "phone": "+70985037724"}
0005432927889	DFDE2B	9144 189589	TATYANA FEDOROVA	{"phone": "+70257648404"}
0005432927890	F280F8	9493 230553	GALINA VASILEVA	{"phone": "+70959041342"}
0005432927891	963796	2791 638334	VIKTOR NIKITIN	{"phone": "+70678282608"}
0005432927892	963796	8054 659111	OLEG FEDOROV	{"email": "fedorov_o.14061978@postgrespro.ru", "phone": "+70532512887"}
0005432927893	306A2C	5452 437205	ALEKSANDRA VASILEVA	{"phone": "+70608619805"}
0005432927894	C846DE	5137 002274	TATYANA NESTEROVA	{"email": "t_nesterova04081966@postgrespro.ru", "phone": "+70387353431"}
0005432927895	8E2DD4	8932 219332	MARIYA KUZNECOVA	{"email": "mariya-kuznecova01091974@postgrespro.ru", "phone": "+70126274137"}
0005432927896	8E2DD4	1951 429346	ALEKSANDR BELOV	{"phone": "+70913029640"}
0005432927897	C2BABE	3696 221851	YULIYA IVANOVA	{"phone": "+70791641853"}
0005432927898	CCD8BC	3933 013236	VIKTORIYA MELNIKOVA	{"email": "viktoriyamelnikova.21051963@postgrespro.ru", "phone": "+70269669080"}
0005432927899	953E98	9368 540467	ANASTASIYA MOROZOVA	{"phone": "+70428819149"}
0005432927900	953E98	9021 562930	ALEKSANDRA SIDOROVA	{"email": "sidorovaa.20071981@postgrespro.ru", "phone": "+70185833537"}
0005432927901	AACE27	2299 685432	VLADIMIR POPOV	{"phone": "+70560194943"}
0005432927902	AACE27	9879 024704	ELENA SERGEEVA	{"phone": "+70598112706"}
0005432927903	8E38A3	5999 209716	MIKHAIL SEMENOV	{"phone": "+70459135634"}
0005432927904	64AC8D	0530 440438	EVGENIYA KALININA	{"phone": "+70217478342"}
0005432927905	EBE99C	1332 187613	SERGEY ILIN	{"email": "s.ilin-061969@postgrespro.ru", "phone": "+70194052317"}
0005432927906	14DCE5	7860 159511	ADELINA DENISOVA	{"phone": "+70864523569"}
0005432927907	B6B421	2232 364406	OLGA NIKOLAEVA	{"email": "nikolaevao.011963@postgrespro.ru", "phone": "+70813654190"}
0005432927908	B6B421	1146 753629	IRINA VOLKOVA	{"email": "irinavolkova.111967@postgrespro.ru", "phone": "+70660655218"}
0005432927909	34167F	5053 182725	LYUDMILA LUKYANOVA	{"email": "lyudmila-lukyanova.1979@postgrespro.ru", "phone": "+70953694420"}
0005432927910	AD1BC8	0042 193126	ANNA KUZNECOVA	{"email": "annakuznecova_1979@postgrespro.ru", "phone": "+70071950504"}
0005432927911	19191E	6386 431444	SVETLANA FILIPPOVA	{"email": "sfilippova-1977@postgrespro.ru", "phone": "+70692147878"}
0005432927912	041D0B	3457 455986	YULIYA TIMOFEEVA	{"phone": "+70503972013"}
0005432927913	041D0B	8679 193906	EKATERINA KISELEVA	{"email": "e-kiseleva03011979@postgrespro.ru", "phone": "+70860722042"}
0005432927914	44339D	1761 143615	EVDOKIYA ANISIMOVA	{"email": "anisimova.e1975@postgrespro.ru", "phone": "+70835201156"}
0005432927915	2D2865	4498 370701	ELENA KONOVALOVA	{"phone": "+70507433091"}
0005432927916	F5A467	1899 088179	PETR ZHURAVLEV	{"email": "zhuravlevp-011968@postgrespro.ru", "phone": "+70982039975"}
0005432927917	F5A467	5706 342974	KONSTANTIN KARPOV	{"email": "karpov-konstantin-1967@postgrespro.ru", "phone": "+70595200640"}
0005432927918	C43596	4532 631675	NINA MOROZOVA	{"phone": "+70364999301"}
0005432927919	C43596	6347 513553	RAFAIL SOKOLOV	{"phone": "+70447319353"}
0005432927920	C43596	6615 063672	VADIM FEDOTOV	{"phone": "+70953260047"}
0005432927921	7295EC	2328 967653	RUSTAM NIKITIN	{"email": "nikitinr-031987@postgrespro.ru", "phone": "+70285050625"}
0005432927922	B656A9	8639 545434	IRINA MOROZOVA	{"phone": "+70513293970"}
0005432927923	B656A9	3953 460900	TATYANA GRISHINA	{"phone": "+70672537268"}
0005432927924	B656A9	6366 115816	ANATOLIY KUZMIN	{"email": "kuzmin.a-20011967@postgrespro.ru", "phone": "+70199833313"}
0005432927925	36B3D0	9594 985255	ANDREY NAUMOV	{"phone": "+70829227690"}
0005432927926	FD9D63	6063 522706	ANNA KONOVALOVA	{"email": "akonovalova.04091978@postgrespro.ru", "phone": "+70803292694"}
0005432927927	7A805A	9357 071672	TATYANA POTAPOVA	{"email": "tatyana.potapova-13051974@postgrespro.ru", "phone": "+70452633491"}
0005432927928	7A805A	7397 691912	DMITRIY KISELEV	{"email": "kiselev-dmitriy_081984@postgrespro.ru", "phone": "+70972446820"}
0005432927929	79756F	1988 481965	VALENTINA KOVALEVA	{"phone": "+70646660043"}
0005432927930	79756F	0105 289498	ALEKSANDR NIKITIN	{"phone": "+70642360406"}
0005432927931	75DB60	3485 124710	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana_031977@postgrespro.ru", "phone": "+70654236277"}
0005432927932	75DB60	5053 281316	SVETLANA ALEKSANDROVA	{"email": "svetlana.aleksandrova1973@postgrespro.ru", "phone": "+70758046261"}
0005432927933	B63612	7334 779657	MARIANNA MATVEEVA	{"email": "m_matveeva.041981@postgrespro.ru", "phone": "+70436657816"}
0005432927934	B63612	8565 220592	POLINA RYABOVA	{"phone": "+70719032760"}
0005432927935	C77D77	7821 812144	IRINA MAKSIMOVA	{"phone": "+70335413377"}
0005432927936	E2DF96	5588 540464	OLGA KONDRATEVA	{"email": "o_kondrateva-081969@postgrespro.ru", "phone": "+70002710658"}
0005432927937	99DCBA	9451 897637	MAKSIM FEDOROV	{"phone": "+70789870452"}
0005432927938	99DCBA	2860 946049	ZINAIDA LOGINOVA	{"email": "z-loginova-031968@postgrespro.ru", "phone": "+70732589088"}
0005432927939	382937	1835 335838	ELENA KOZLOVA	{"phone": "+70733935035"}
0005432927940	A444D8	2477 550022	VLADIMIR MARTYNOV	{"phone": "+70371339455"}
0005432927941	49BD60	1786 999575	ANDREY AFANASEV	{"email": "a-afanasev_06071979@postgrespro.ru", "phone": "+70648856349"}
0005432927942	EE939A	9049 224685	SERGEY KOZLOV	{"email": "sergey.kozlov061970@postgrespro.ru", "phone": "+70496241860"}
0005432927943	EE939A	9225 829755	LYUBOV NIKIFOROVA	{"email": "nikiforova.l_1972@postgrespro.ru", "phone": "+70650120857"}
0005432927944	4C7A73	2890 983302	MIKHAIL SCHERBAKOV	{"email": "mikhail-scherbakov061969@postgrespro.ru", "phone": "+70613543764"}
0005432927945	4C7A73	9345 690356	ALEKSANDR RODIONOV	{"phone": "+70678658540"}
0005432927946	3A1FEC	5521 222196	IRINA IVANOVA	{"email": "ivanovai-1980@postgrespro.ru", "phone": "+70233140799"}
0005432927947	679456	2720 271337	OLGA NIKOLAEVA	{"email": "nikolaeva_olga.091981@postgrespro.ru", "phone": "+70607466171"}
0005432927948	679456	7115 331369	VLADISLAV DMITRIEV	{"email": "dmitrievv-121986@postgrespro.ru", "phone": "+70774048479"}
0005432927949	8A911C	5741 733392	ANDREY ZAKHAROV	{"phone": "+70461855276"}
0005432927950	65870D	1688 845728	OLGA GORBUNOVA	{"email": "gorbunovaolga.041966@postgrespro.ru", "phone": "+70049174347"}
0005432927951	A3F46B	3332 400852	ANDREY TIKHONOV	{"email": "tikhonov_a.031970@postgrespro.ru", "phone": "+70758517942"}
0005432927952	8ADF83	7361 296273	YURIY PAVLOV	{"email": "yuriy.pavlov06111968@postgrespro.ru", "phone": "+70125291690"}
0005432927953	C510D7	8594 572789	SERGEY NAUMOV	{"email": "sergeynaumov-021974@postgrespro.ru", "phone": "+70236182549"}
0005432927954	CB5B42	6064 371079	TAMARA MATVEEVA	{"phone": "+70990221761"}
0005432927955	1621D0	1876 595223	GALINA AFANASEVA	{"email": "afanaseva_g.1975@postgrespro.ru", "phone": "+70585032161"}
0005432927956	D500EB	3661 108955	VIKTOR FOMIN	{"phone": "+70649848911"}
0005432927957	B730FB	8471 294328	TAMARA OSIPOVA	{"email": "tamara-osipova_18091968@postgrespro.ru", "phone": "+70137518737"}
0005432927958	3B958D	6993 335276	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_081971@postgrespro.ru", "phone": "+70679721929"}
0005432927959	3B958D	9597 514703	IRAIDA MOISEEVA	{"email": "moiseeva.iraida081969@postgrespro.ru", "phone": "+70661760012"}
0005432927960	8CAA04	6887 911266	VALENTINA KUZMINA	{"email": "v.kuzmina29041975@postgrespro.ru", "phone": "+70214396443"}
0005432927961	8CAA04	6133 135355	YAKOV DENISOV	{"phone": "+70176971600"}
0005432927962	0489E4	0265 152744	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr.1956@postgrespro.ru", "phone": "+70431710023"}
0005432927963	0489E4	8611 509337	VADIM ZAKHAROV	{"phone": "+70070985724"}
0005432927964	02F803	6424 508784	NATALYA MOISEEVA	{"email": "n.moiseeva.28041973@postgrespro.ru", "phone": "+70866711410"}
0005432927965	02F803	6348 632516	YURIY STEPANOV	{"email": "stepanov.yuriy.30071984@postgrespro.ru", "phone": "+70955594535"}
0005432927966	00EC31	3273 185406	NINA SERGEEVA	{"phone": "+70543387479"}
0005432927967	00EC31	6427 170923	NATALYA KUZNECOVA	{"phone": "+70704211387"}
0005432927968	007FF3	0407 218917	EKATERINA VOROBEVA	{"phone": "+70679672000"}
0005432927969	6E10A6	5250 836059	LIDIYA ANTONOVA	{"phone": "+70940631191"}
0005432927970	C689CA	8981 000756	MARINA FROLOVA	{"phone": "+70879730977"}
0005432927971	C689CA	2350 172451	VLADIMIR MARTYNOV	{"phone": "+70868218652"}
0005432927972	FC425E	1079 556356	KIRILL ABRAMOV	{"email": "kirill-abramov-071975@postgrespro.ru", "phone": "+70576618711"}
0005432927973	FC425E	4434 541652	ALEKSANDRA ANISIMOVA	{"phone": "+70646595211"}
0005432927974	5973F5	9065 960855	SVETLANA ZAYCEVA	{"email": "svetlana.zayceva_1970@postgrespro.ru", "phone": "+70453338459"}
0005432927975	0228EB	3894 525189	YULIYA VLASOVA	{"phone": "+70287498506"}
0005432927976	0228EB	1173 375476	ALEKSANDR MOROZOV	{"email": "morozova021968@postgrespro.ru", "phone": "+70113956424"}
0005432927977	92E9E7	1288 432857	SANIYA MALYSHEVA	{"email": "s.malysheva27011964@postgrespro.ru", "phone": "+70407747365"}
0005432927978	CACA0B	6298 239648	MARIYA ZHURAVLEVA	{"email": "mariya_zhuravleva_04121968@postgrespro.ru", "phone": "+70127075682"}
0005432927979	5DD08B	8407 523111	TAISA MALYSHEVA	{"email": "tmalysheva.01031976@postgrespro.ru", "phone": "+70394308086"}
0005432927980	5DD08B	6046 217833	TAMARA KOROLEVA	{"phone": "+70139065488"}
0005432927981	419B66	8494 875310	DANILA ZAKHAROV	{"email": "zakharov_danila-1977@postgrespro.ru", "phone": "+70804093746"}
0005432927982	41E867	8003 886550	RAFAIL NOVIKOV	{"phone": "+70450524878"}
0005432927983	26A727	3679 632896	NATALYA SOLOVEVA	{"phone": "+70863123338"}
0005432927984	259144	0335 936402	ILDAR KULIKOV	{"phone": "+70603262512"}
0005432927985	1F71E2	2646 556105	YULIYA LEBEDEVA	{"email": "lebedeva-y02041982@postgrespro.ru", "phone": "+70758361974"}
0005432927986	1E7C7E	7669 006659	MAKSIM ILIN	{"email": "ilin_maksim-15121972@postgrespro.ru", "phone": "+70205477655"}
0005432927987	1E7C7E	0812 231644	ANDREY GAVRILOV	{"email": "gavrilov_andrey-041979@postgrespro.ru", "phone": "+70963441238"}
0005432927988	1E7C7E	1243 024068	NIKOLAY BONDARENKO	{"email": "nikolay-bondarenko_111972@postgrespro.ru", "phone": "+70434383685"}
0005432927989	AEA534	2469 166961	VLADIMIR MARTYNOV	{"email": "vmartynov_1973@postgrespro.ru", "phone": "+70268352343"}
0005432927990	588242	1838 060946	DMITRIY NIKOLAEV	{"email": "nikolaev.dmitriy-31011970@postgrespro.ru", "phone": "+70930314304"}
0005432927991	061C6A	4458 405489	DARYA ALEKSEEVA	{"email": "alekseeva.darya-061973@postgrespro.ru", "phone": "+70155231634"}
0005432927992	F2C99B	6233 208627	RAISA SOROKINA	{"email": "r-sorokina.22121964@postgrespro.ru", "phone": "+70021362899"}
0005432927993	7E5278	7918 175907	OKSANA ZHUKOVA	{"phone": "+70733957377"}
0005432927994	7E5278	5240 763481	TATYANA BELOVA	{"email": "tbelova02071972@postgrespro.ru", "phone": "+70483414565"}
0005432927995	EDD527	1089 294585	SERGEY ORLOV	{"phone": "+70179673605"}
0005432927996	EDD527	4615 680571	VLADISLAV GERASIMOV	{"email": "gerasimov.v-011972@postgrespro.ru", "phone": "+70406514729"}
0005432927997	693B2E	8006 887714	NATALYA NOVIKOVA	{"phone": "+70928889839"}
0005432927998	693B2E	7820 774572	EVGENIY KULIKOV	{"email": "kulikovevgeniy-28011976@postgrespro.ru", "phone": "+70091965092"}
0005432927999	0AB678	0966 923180	IVAN KRASNOV	{"email": "ikrasnov-1971@postgrespro.ru", "phone": "+70294763688"}
0005432928000	699081	1005 041580	ARTUR POPOV	{"email": "artur_popov101972@postgrespro.ru", "phone": "+70251631886"}
0005432928001	EF75C0	4139 092839	VITALIY YAKOVLEV	{"phone": "+70275161228"}
0005432928002	F57A64	3330 062939	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov-101974@postgrespro.ru", "phone": "+70127776736"}
0005432928003	0016CB	1022 190498	IRINA SERGEEVA	{"email": "sergeeva_i.1983@postgrespro.ru", "phone": "+70644814874"}
0005432928004	A1E3EF	1743 213478	DANILA DMITRIEV	{"phone": "+70882092657"}
0005432928005	C41305	9390 911224	ANTONINA FEDOROVA	{"email": "a_fedorova-051964@postgrespro.ru", "phone": "+70895081363"}
0005432928006	C41305	8974 352577	MARIYA NESTEROVA	{"phone": "+70767007162"}
0005432928007	C5CDFE	8113 478571	YURIY NAZAROV	{"email": "nazarov-yuriy.1983@postgrespro.ru", "phone": "+70263298699"}
0005432928008	22EEA7	9066 787872	SERGEY SMIRNOV	{"email": "ssmirnov-011972@postgrespro.ru", "phone": "+70581983427"}
0005432928009	084CF8	0745 394876	DARYA MOROZOVA	{"email": "morozovad.1979@postgrespro.ru", "phone": "+70585228254"}
0005432928010	F57B1A	8722 720071	SERGEY BARANOV	{"phone": "+70947753370"}
0005432928011	CFEFA4	7167 862894	OLEG BELOV	{"phone": "+70114649542"}
0005432928012	CFEFA4	2824 140755	PAVEL FEDOROV	{"email": "fedorovp-041976@postgrespro.ru", "phone": "+70244960421"}
0005432928013	CFEFA4	4939 206685	ILYA ISAEV	{"phone": "+70740351702"}
0005432928070	08218F	1648 693542	MARIYA MIRONOVA	{"phone": "+70615217789"}
0005432928014	CFEFA4	3047 901621	ALEKSEY FEDOTOV	{"email": "a_fedotov.081981@postgrespro.ru", "phone": "+70762264021"}
0005432928015	461196	1886 321487	ALEKSANDR TIMOFEEV	{"phone": "+70361176309"}
0005432928016	269341	4353 736487	DMITRIY SMIRNOV	{"email": "smirnov.dmitriy1975@postgrespro.ru", "phone": "+70516305199"}
0005432928017	269341	8153 968235	ALEKSEY POPOV	{"email": "a.popov_081967@postgrespro.ru", "phone": "+70935569282"}
0005432928018	27CA4B	5962 352224	ILYA MAKAROV	{"phone": "+70416302900"}
0005432928019	2EA0A4	2399 608713	OLGA MATVEEVA	{"email": "matveevaolga-061973@postgrespro.ru", "phone": "+70057356884"}
0005432928020	2EA0A4	4422 548471	GALINA RODIONOVA	{"phone": "+70684227748"}
0005432928021	2EA0A4	9625 074325	LYUDMILA KOVALEVA	{"phone": "+70769332017"}
0005432928022	45E1E4	1912 614409	EGOR ANDREEV	{"email": "egor-andreev-08051968@postgrespro.ru", "phone": "+70888911380"}
0005432928023	B83561	8518 547593	GALINA MEDVEDEVA	{"email": "g.medvedeva.08041976@postgrespro.ru", "phone": "+70410052338"}
0005432928024	B83561	3767 382023	SVETLANA DAVYDOVA	{"phone": "+70195711012"}
0005432928025	B5A6DA	5500 727814	ANNA FILIPPOVA	{"phone": "+70359935540"}
0005432928026	CD0939	2018 230357	NIKOLAY KUZMIN	{"phone": "+70384690906"}
0005432928027	CD0939	6461 465301	SERGEY ALEKSANDROV	{"phone": "+70080584545"}
0005432928028	CD0939	5919 660114	SERGEY NIKITIN	{"email": "nikitin.s_1971@postgrespro.ru", "phone": "+70112301893"}
0005432928029	08E74F	2737 889053	ELENA TIKHONOVA	{"email": "e-tikhonova.1977@postgrespro.ru", "phone": "+70814874321"}
0005432928030	137D88	1929 434032	SVETLANA BELOVA	{"email": "belova-s_1971@postgrespro.ru", "phone": "+70473039967"}
0005432928031	7CA694	8790 005961	ELENA GUSEVA	{"email": "guseva.elena_1986@postgrespro.ru", "phone": "+70737389486"}
0005432928032	95A43B	6258 259490	VLADIMIR ILIN	{"email": "ilinvladimir_1974@postgrespro.ru", "phone": "+70062519981"}
0005432928033	0A0310	6043 584215	ELENA VASILEVA	{"phone": "+70706107648"}
0005432928034	4CA9FE	1453 599560	ANATOLIY ALEKSEEV	{"email": "anatoliyalekseev_23031984@postgrespro.ru", "phone": "+70069256605"}
0005432928035	F8436B	5990 990194	SERGEY BORISOV	{"email": "sergey-borisov_21071959@postgrespro.ru", "phone": "+70674144074"}
0005432928036	7625E6	6222 999706	NINA ROMANOVA	{"phone": "+70855412594"}
0005432928037	3692C4	7809 602872	PAVEL SERGEEV	{"phone": "+70739171392"}
0005432928038	E2F476	9651 390226	IRAIDA ZHUKOVA	{"email": "i-zhukova_28081974@postgrespro.ru", "phone": "+70485031384"}
0005432928039	E2F476	8844 875132	ILYA ANTONOV	{"email": "antonov.ilya-12031981@postgrespro.ru", "phone": "+70065155279"}
0005432928040	D9589E	2070 725045	SVETLANA BORISOVA	{"email": "s_borisova111973@postgrespro.ru", "phone": "+70751691428"}
0005432928041	D9589E	9285 252755	VLADIMIR ANTONOV	{"email": "antonovvladimir_031978@postgrespro.ru", "phone": "+70368518040"}
0005432928042	FBC6C3	7726 499215	BOGDAN NIKITIN	{"phone": "+70297951772"}
0005432928043	CCF91F	1512 973909	NATALYA POPOVA	{"phone": "+70026583465"}
0005432928044	CCF91F	2923 355275	EKATERINA SOROKINA	{"email": "esorokina.111975@postgrespro.ru", "phone": "+70022142738"}
0005432928045	461589	8730 740959	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.18081977@postgrespro.ru", "phone": "+70252750731"}
0005432928046	7F2A5F	8472 871574	IRINA MIRONOVA	{"phone": "+70229674700"}
0005432928047	2BC4C6	5517 676912	NIKOLAY NIKITIN	{"email": "nikitin-n.021975@postgrespro.ru", "phone": "+70084140643"}
0005432928048	2BC4C6	2883 837328	ELENA NIKOLAEVA	{"phone": "+70829881147"}
0005432928049	C65DAC	3729 799844	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy.081978@postgrespro.ru", "phone": "+70813750494"}
0005432928050	C65DAC	6215 720759	NINA KUZMINA	{"phone": "+70907691032"}
0005432928051	AAEAAF	4167 429908	ALEKSANDRA KOZLOVA	{"email": "akozlova-041976@postgrespro.ru", "phone": "+70499036124"}
0005432928052	3AA573	0034 942053	TATYANA FILIPPOVA	{"email": "filippova_tatyana1973@postgrespro.ru", "phone": "+70670663403"}
0005432928053	DB84C8	1248 781644	IGOR AFANASEV	{"email": "afanasev-igor1968@postgrespro.ru", "phone": "+70368200053"}
0005432928054	DB84C8	7816 209382	PETR VOLKOV	{"email": "p-volkov.091978@postgrespro.ru", "phone": "+70208328734"}
0005432928055	DB84C8	6438 559539	VALENTINA EGOROVA	{"email": "egorovav_17021955@postgrespro.ru", "phone": "+70431276605"}
0005432928056	D53707	0676 546480	VITALIY MAKAROV	{"phone": "+70770152716"}
0005432928057	CBDB51	8990 466755	VALERIYA SCHERBAKOVA	{"email": "scherbakova_v_081968@postgrespro.ru", "phone": "+70902447836"}
0005432928058	CBDB51	2333 395796	RAISA DMITRIEVA	{"email": "r_dmitrieva-1969@postgrespro.ru", "phone": "+70380536971"}
0005432928059	1E8E73	6632 238432	OLGA KAZAKOVA	{"phone": "+70337542745"}
0005432928060	1E8E73	2938 864993	NINA VOLKOVA	{"phone": "+70719973473"}
0005432928061	78A71D	3621 483198	TATYANA MIKHAYLOVA	{"phone": "+70367688782"}
0005432928062	78A71D	9163 708375	NINA ANISIMOVA	{"email": "anisimovanina-051980@postgrespro.ru", "phone": "+70676800732"}
0005432928063	FDE023	1750 286501	DMITRIY PAVLOV	{"phone": "+70512392496"}
0005432928064	0E2489	4553 154420	VIKTOR MARTYNOV	{"email": "martynov_viktor.051984@postgrespro.ru", "phone": "+70712207071"}
0005432928065	02DDDD	7698 320488	GALINA MOISEEVA	{"email": "g.moiseeva-18101982@postgrespro.ru", "phone": "+70799690409"}
0005432928066	02DDDD	1469 602007	GUZEL POPOVA	{"phone": "+70147399311"}
0005432928067	53C189	9324 677547	VASILIY KULIKOV	{"phone": "+70462846782"}
0005432928068	911D1C	6822 186997	OKSANA ISAEVA	{"phone": "+70773597853"}
0005432928069	79947C	0870 391809	MIKHAIL KONOVALOV	{"phone": "+70233407254"}
0005432928071	45FCB7	6855 848566	DMITRIY ILIN	{"email": "d.ilin08031974@postgrespro.ru", "phone": "+70164134227"}
0005432928072	AD6D77	4519 740972	SOFIYA KRASNOVA	{"phone": "+70403346302"}
0005432928073	3E9C51	3530 467861	OLGA KUZMINA	{"phone": "+70147606444"}
0005432928074	D9946A	0545 172752	MARINA EFIMOVA	{"email": "marina.efimova1974@postgrespro.ru", "phone": "+70133318798"}
0005432928075	E81FF1	6890 817187	ROMAN PAVLOV	{"phone": "+70102330682"}
0005432928076	CFA643	3036 322206	VALERIY KUZNECOV	{"phone": "+70991521116"}
0005432928077	223F30	2322 571145	MIKHAIL FROLOV	{"phone": "+70485544255"}
0005432928078	223F30	2049 184593	ILYA TARASOV	{"phone": "+70808880444"}
0005432928079	223F30	3462 349089	IGOR FEDOTOV	{"phone": "+70866155173"}
0005432928080	8C1ECE	9487 617986	ALEKSANDR BORISOV	{"phone": "+70229976322"}
0005432928081	8C1ECE	1883 801348	DMITRIY KUDRYASHOV	{"email": "kudryashov-dmitriy.071967@postgrespro.ru", "phone": "+70468283461"}
0005432928082	4B5950	8128 546921	VADIM TARASOV	{"email": "tarasov-vadim111988@postgrespro.ru", "phone": "+70895692290"}
0005432928083	22D75D	1076 774646	VIKTOR GUSEV	{"email": "gusev.v_1978@postgrespro.ru", "phone": "+70589755486"}
0005432928084	DFF3B2	6575 016099	ANATOLIY BARANOV	{"email": "baranova.041975@postgrespro.ru", "phone": "+70203009659"}
0005432928085	318670	2034 950999	ANDREY GRIGOREV	{"phone": "+70841748412"}
0005432928086	318670	1910 654860	TIMOFEY IVANOV	{"email": "ivanov.t1975@postgrespro.ru", "phone": "+70351349324"}
0005432928087	CD731F	0102 890297	EKATERINA KOLESNIKOVA	{"phone": "+70717357785"}
0005432928088	C39BCF	4942 493861	TATYANA LUKYANOVA	{"email": "lukyanovatatyana.1963@postgrespro.ru", "phone": "+70359385435"}
0005432928089	C39BCF	8117 505277	DMITRIY EGOROV	{"phone": "+70613341947"}
0005432928090	5AD3CC	0757 526046	TATYANA FILATOVA	{"phone": "+70383087652"}
0005432928091	084C83	8371 147093	OLGA SMIRNOVA	{"email": "osmirnova_1969@postgrespro.ru", "phone": "+70515940202"}
0005432928092	A2F8CF	6219 838518	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev-1970@postgrespro.ru", "phone": "+70520838423"}
0005432928093	98339F	7531 699494	NATALYA GRISHINA	{"phone": "+70863109086"}
0005432928094	57EE57	9480 700351	LYUBOV PETROVA	{"phone": "+70169690545"}
0005432928095	C74FF4	6195 220630	IRINA FILIPPOVA	{"email": "filippova.i_1980@postgrespro.ru", "phone": "+70354613062"}
0005432928096	64CC7E	8717 092559	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-19011974@postgrespro.ru", "phone": "+70905042058"}
0005432928097	64CC7E	5241 055831	DMITRIY SCHERBAKOV	{"phone": "+70439786812"}
0005432928098	5B5A2C	0228 134728	ANNA YUDINA	{"email": "anna_yudina.1967@postgrespro.ru", "phone": "+70171633843"}
0005432928099	1DAFEA	0068 239468	SERGEY TARASOV	{"phone": "+70178633556"}
0005432928100	B008A0	4789 749819	NATALYA GERASIMOVA	{"email": "gerasimova.n_29081978@postgrespro.ru", "phone": "+70588321481"}
0005432928101	D43719	7138 789401	YULIYA EGOROVA	{"email": "yegorova-081959@postgrespro.ru", "phone": "+70401587604"}
0005432928102	D980BE	8484 749729	ANATOLIY MARTYNOV	{"phone": "+70279848057"}
0005432928103	D980BE	8119 034442	ANNA KONDRATEVA	{"email": "kondrateva.anna.12021978@postgrespro.ru", "phone": "+70641853111"}
0005432928104	E40373	0385 771321	GALINA SEMENOVA	{"phone": "+70809749102"}
0005432928105	4D2603	1552 544395	ELENA KOZLOVA	{"phone": "+70096067558"}
0005432928106	6FEEF3	6564 610710	TATYANA DANILOVA	{"email": "danilova_t-1973@postgrespro.ru", "phone": "+70886253341"}
0005432928107	6FEEF3	7097 316318	IRINA SEMENOVA	{"phone": "+70520149644"}
0005432928108	76264B	6337 055676	MIKHAIL STEPANOV	{"email": "mikhail_stepanov1977@postgrespro.ru", "phone": "+70837657163"}
0005432928109	76264B	6083 694798	ARTEM MAKAROV	{"phone": "+70215255623"}
0005432928110	8FD7A7	0071 957152	LILIYA BELOVA	{"email": "belovaliliya-121976@postgrespro.ru", "phone": "+70304410925"}
0005432928111	F70F51	9267 658373	ANDREY KOZLOV	{"email": "kozlov_andrey-1976@postgrespro.ru", "phone": "+70154998974"}
0005432928112	F2B553	3722 327595	NIKOLAY KUZNECOV	{"email": "n-kuznecov_16061974@postgrespro.ru", "phone": "+70329523510"}
0005432928113	DE00FF	2891 525828	RUSLAN EGOROV	{"phone": "+70592712200"}
0005432928114	DE00FF	3955 438675	VALERIY NIKOLAEV	{"email": "nikolaev.valeriy15021969@postgrespro.ru", "phone": "+70501510412"}
0005432928115	DE00FF	6278 001555	DANIL SIDOROV	{"phone": "+70218652796"}
0005432928116	DE00FF	6201 000425	SERGEY ILIN	{"email": "s.ilin17121971@postgrespro.ru", "phone": "+70296291565"}
0005432928117	560364	2470 843602	OLGA LAZAREVA	{"email": "lazareva_olga.071971@postgrespro.ru", "phone": "+70338198676"}
0005432928118	560364	6347 374588	SERGEY ABRAMOV	{"phone": "+70868237206"}
0005432928119	4BA696	9089 202333	VIKTOR ALEKSANDROV	{"phone": "+70008800099"}
0005432928120	D24EAB	1383 895761	VALENTINA MELNIKOVA	{"phone": "+70527947623"}
0005432928121	D24EAB	7471 666343	ANDREY KUZNECOV	{"phone": "+70034378641"}
0005432928122	7262B8	4557 121494	VERA CHERNOVA	{"email": "v_chernova_25101972@postgrespro.ru", "phone": "+70213099791"}
0005432928123	49315B	2355 290674	IRINA LUKYANOVA	{"email": "irina_lukyanova.17101961@postgrespro.ru", "phone": "+70523668033"}
0005432928124	6DD1E6	6560 750843	DMITRIY ALEKSEEV	{"email": "alekseev.dmitriy_111982@postgrespro.ru", "phone": "+70230851940"}
0005432928125	76490A	3399 202498	SERGEY MOISEEV	{"email": "moiseevs1963@postgrespro.ru", "phone": "+70260912487"}
0005432928126	76490A	4192 279602	SVETLANA ABRAMOVA	{"email": "sabramova_041975@postgrespro.ru", "phone": "+70629469104"}
0005432928127	3BB27C	3031 817126	LYUDMILA LEBEDEVA	{"email": "l.lebedeva-021970@postgrespro.ru", "phone": "+70478082578"}
0005432928128	1121CB	1448 588290	MIKHAIL SAVELEV	{"email": "savelev-mikhail18111968@postgrespro.ru", "phone": "+70160684240"}
0005432928129	58841F	2394 851149	ALEKSANDRA ANDREEVA	{"phone": "+70268239379"}
0005432928130	032796	7204 366129	VIKTORIYA SERGEEVA	{"phone": "+70223737313"}
0005432928131	C3643A	7063 803743	LILIYA SOLOVEVA	{"phone": "+70368756564"}
0005432928132	A69328	1680 471339	ANASTASIYA GAVRILOVA	{"email": "gavrilova_anastasiya_1970@postgrespro.ru", "phone": "+70936487439"}
0005432928133	A69328	0188 752446	LYUDMILA NIKOLAEVA	{"phone": "+70292795900"}
0005432928134	06CF0A	9719 232136	TATYANA POPOVA	{"phone": "+70116149816"}
0005432928135	2FB8E2	8594 851622	ALEKSEY ZAKHAROV	{"email": "aleksey.zakharov-1973@postgrespro.ru", "phone": "+70139147531"}
0005432928136	1BB995	6675 007075	VLADIMIR MOROZOV	{"email": "morozov-vladimir_121966@postgrespro.ru", "phone": "+70090252481"}
0005432928137	67F1AF	5861 416285	ROMAN SMIRNOV	{"phone": "+70553224556"}
0005432928138	DE2507	3990 293952	ALEKSANDR KRASNOV	{"phone": "+70265911400"}
0005432928139	DE2507	3590 827836	ANATOLIY PAVLOV	{"phone": "+70846529873"}
0005432928140	88182D	1830 374385	SERGEY BARANOV	{"email": "s_baranov051965@postgrespro.ru", "phone": "+70350422916"}
0005432928141	680E17	8706 101720	EVGENIYA KRASNOVA	{"phone": "+70565962260"}
0005432928142	666F29	4571 362045	BULAT MIKHAYLOV	{"phone": "+70279467222"}
0005432928143	782D76	7670 204041	NIKOLAY PETROV	{"phone": "+70491315171"}
0005432928144	782D76	8939 117820	SVETLANA MOISEEVA	{"email": "moiseeva.s-071970@postgrespro.ru", "phone": "+70166902697"}
0005432928145	F10981	1318 976068	ANDREY CHERNOV	{"email": "andrey_chernov-18091977@postgrespro.ru", "phone": "+70072530898"}
0005432928146	F10981	6978 092196	VIKTOR NAUMOV	{"email": "v-naumov.031958@postgrespro.ru", "phone": "+70196907951"}
0005432928147	67DF6E	4160 208935	NINA TIMOFEEVA	{"email": "timofeevan.121963@postgrespro.ru", "phone": "+70462232214"}
0005432928148	67DF6E	6286 166444	OLGA SOKOLOVA	{"email": "osokolova-1976@postgrespro.ru", "phone": "+70136521949"}
0005432928149	A13A0C	8071 727847	NADEZHDA SOKOLOVA	{"phone": "+70558494778"}
0005432928150	CB1E46	3542 866837	ANNA TARASOVA	{"phone": "+70265571162"}
0005432947764	E44EAD	1539 207160	EVGENIY ZHUKOV	{"phone": "+70762696743"}
0005432947765	E1E3B9	0279 461085	ELENA BORISOVA	{"email": "e.borisova.11081969@postgrespro.ru", "phone": "+70563397086"}
0005432947766	990727	3565 110271	ANGELINA SOROKINA	{"email": "sorokina-angelina_011959@postgrespro.ru", "phone": "+70841830534"}
0005432947767	990727	7972 538035	MARINA FOMINA	{"phone": "+70643700261"}
0005432947768	E03639	2827 287127	STEPAN GRIGOREV	{"phone": "+70990976645"}
0005432947769	5E2D3A	1013 560616	SVETLANA SEMENOVA	{"email": "svetlana_semenova-1974@postgrespro.ru", "phone": "+70120641452"}
0005432947770	A6C4AF	1985 710841	OLGA LUKYANOVA	{"email": "lukyanovaolga.1978@postgrespro.ru", "phone": "+70477952986"}
0005432947771	A6C4AF	5821 006476	NADEZHDA YAKOVLEVA	{"email": "yakovleva.nadezhda_1967@postgrespro.ru", "phone": "+70905728307"}
0005432947772	B2693D	3814 441810	LYUDMILA ZAYCEVA	{"email": "lyudmila.zayceva_09051975@postgrespro.ru", "phone": "+70240395989"}
0005432947773	C7766B	4756 132303	VALENTINA PETROVA	{"email": "v_petrova_061982@postgrespro.ru", "phone": "+70556276623"}
0005432947774	C7766B	7259 464924	SVETLANA ROMANOVA	{"email": "romanovasvetlana-1955@postgrespro.ru", "phone": "+70089537511"}
0005432947775	92107D	1865 726742	YULIYA MELNIKOVA	{"phone": "+70259230697"}
0005432947776	92107D	6558 754155	GENNADIY KUZNECOV	{"email": "gennadiykuznecov1980@postgrespro.ru", "phone": "+70067207882"}
0005432947777	22A377	8523 572230	NATALYA DAVYDOVA	{"email": "n_davydova-1968@postgrespro.ru", "phone": "+70011452590"}
0005432947778	B16855	2485 517021	ANATOLIY ZAYCEV	{"phone": "+70864720243"}
0005432947779	D56C31	0263 749879	IRINA KARPOVA	{"email": "karpova-i.081973@postgrespro.ru", "phone": "+70278398232"}
0005432947780	80B9A6	5541 040623	VALENTINA NAUMOVA	{"phone": "+70516795453"}
0005432947781	80B9A6	6640 316057	DARYA FOMINA	{"email": "d-fomina-071973@postgrespro.ru", "phone": "+70189586450"}
0005432947782	80B9A6	3501 524811	VLADIMIR BORISOV	{"phone": "+70319240618"}
0005432947783	981D20	3674 965779	ROZA EFIMOVA	{"phone": "+70900803624"}
0005432947784	981D20	0526 374122	YULIYA DMITRIEVA	{"email": "dmitrieva-yuliya1963@postgrespro.ru", "phone": "+70912668851"}
0005432947785	CCF6DD	2064 407463	TAMARA BOGDANOVA	{"phone": "+70047872510"}
0005432947786	D22110	4313 545869	NIKOLAY GUSEV	{"email": "ngusev.1973@postgrespro.ru", "phone": "+70253616676"}
0005432947787	D22110	3108 302439	YURIY BORISOV	{"email": "borisovy-101984@postgrespro.ru", "phone": "+70944035374"}
0005432947788	92B3F1	9845 778210	OKSANA NOVIKOVA	{"email": "novikovaoksana051985@postgrespro.ru", "phone": "+70344957609"}
0005432947789	92B3F1	1068 471317	GALINA SEMENOVA	{"email": "galina-semenova.1957@postgrespro.ru", "phone": "+70789430619"}
0005432947790	E958F4	3903 047358	ALEKSEY FEDOROV	{"email": "fedorova.1970@postgrespro.ru", "phone": "+70006868637"}
0005432947791	E958F4	2327 646730	IVAN GORBUNOV	{"phone": "+70531967326"}
0005432947792	2F129B	5612 396037	VLADIMIR MAKSIMOV	{"phone": "+70888434098"}
0005432947793	A2E176	9968 767753	LYUDMILA ILINA	{"email": "l.ilina-15051969@postgrespro.ru", "phone": "+70636298477"}
0005432947794	A2E176	8958 705115	EKATERINA SEMENOVA	{"email": "semenovaekaterina-31011975@postgrespro.ru", "phone": "+70081573786"}
0005432947795	01CBAB	9500 442128	OLGA NESTEROVA	{"email": "o_nesterova-1977@postgrespro.ru", "phone": "+70128349212"}
0005432947796	553FD1	1924 271595	TAMARA MIRONOVA	{"phone": "+70351738892"}
0005432947797	553FD1	8900 535714	NATALYA SAVELEVA	{"phone": "+70041598795"}
0005432947798	E9054D	7591 210403	LYUDMILA VOLKOVA	{"phone": "+70518710420"}
0005432947799	1CD06C	0249 167126	NIKOLAY NIKOLAEV	{"phone": "+70808385658"}
0005432947800	1CD06C	8671 550995	ANASTASIYA ABRAMOVA	{"phone": "+70552983834"}
0005432947801	9AF591	8004 931444	GALINA POPOVA	{"phone": "+70171405647"}
0005432947802	5C74A0	5748 532484	VLADIMIR ANDREEV	{"email": "andreev_vladimir_1975@postgrespro.ru", "phone": "+70505787414"}
0005432947803	6741B0	5151 807880	RIMMA KONOVALOVA	{"email": "r_konovalova1970@postgrespro.ru", "phone": "+70002367042"}
0005432947804	44047E	2541 091647	LYUDMILA SERGEEVA	{"phone": "+70057664217"}
0005432947805	E5A6E7	4391 272014	LYUDMILA ROMANOVA	{"phone": "+70192282882"}
0005432947806	E5A6E7	0451 955837	OLEG BARANOV	{"email": "oleg_baranov_21111975@postgrespro.ru", "phone": "+70691949355"}
0005432947807	E5A6E7	7005 142552	OLGA RODIONOVA	{"phone": "+70641137499"}
0005432947808	F75944	8879 721061	SERGEY NIKITIN	{"phone": "+70196390108"}
0005432947809	7ECC39	8948 844594	TATYANA SEMENOVA	{"phone": "+70329209538"}
0005432947810	7ECC39	9161 166052	VERA VOLKOVA	{"phone": "+70499948838"}
0005432947811	6B2CE6	9778 813184	OLGA SCHERBAKOVA	{"email": "oscherbakova_08121981@postgrespro.ru", "phone": "+70847490931"}
0005432947812	AA6C0A	0710 780677	MIKHAIL KUZNECOV	{"phone": "+70394892285"}
0005432947813	8CB5DB	5071 365776	VLADIMIR DENISOV	{"phone": "+70150133467"}
0005432947814	C3DD46	0002 092853	VLADIMIR FEDOTOV	{"phone": "+70341380800"}
0005432947815	C3DD46	7269 289565	OLGA VLASOVA	{"email": "vlasovao.021976@postgrespro.ru", "phone": "+70136211429"}
0005432947816	C3DD46	7866 845220	YURIY PETROV	{"email": "petrovy1967@postgrespro.ru", "phone": "+70895733451"}
0005432947817	60DB28	2333 923331	NIKITA FEDOROV	{"phone": "+70193406191"}
0005432947818	DC6F8F	8950 042715	YULIYA TIMOFEEVA	{"email": "y-timofeeva-26071976@postgrespro.ru", "phone": "+70155092688"}
0005432947819	DC6F8F	1349 450393	LYUBOV POPOVA	{"email": "lyubov_popova_071954@postgrespro.ru", "phone": "+70832673116"}
0005432947820	31FEB2	5859 427293	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey-27081956@postgrespro.ru", "phone": "+70435948131"}
0005432947821	E1542A	3750 890241	MAKSIM ZHUKOV	{"phone": "+70752021055"}
0005432947822	82CFDE	8627 815976	LARISA OSIPOVA	{"phone": "+70887701771"}
0005432947823	8E4C07	6712 359233	TATYANA NIKITINA	{"email": "tatyana.nikitina_081980@postgrespro.ru", "phone": "+70435116443"}
0005432947824	8E4C07	2787 191339	NAILYA PETROVA	{"phone": "+70858836986"}
0005432947825	190C6B	1485 414394	DMITRIY PETROV	{"email": "petrovdmitriy1979@postgrespro.ru", "phone": "+70340190692"}
0005432947826	0AB368	6099 140074	OLGA MELNIKOVA	{"email": "o.melnikova.1978@postgrespro.ru", "phone": "+70220457806"}
0005432947827	72C9DF	2467 812226	YAROSLAV ZAKHAROV	{"phone": "+70802148755"}
0005432947828	1443A0	9851 127960	YURIY SHEVCHENKO	{"email": "yuriy-shevchenko-081971@postgrespro.ru", "phone": "+70566862439"}
0005432947829	10DE25	5208 489968	LARISA OSIPOVA	{"email": "losipova_1970@postgrespro.ru", "phone": "+70390368534"}
0005432947830	76187F	2005 879467	ALEKSEY MEDVEDEV	{"email": "medvedev.aleksey111979@postgrespro.ru", "phone": "+70944684651"}
0005432947831	163D69	9990 358366	YANINA KUZNECOVA	{"email": "yaninakuznecova_09061977@postgrespro.ru", "phone": "+70833984580"}
0005432947832	163D69	2120 552742	ANNA MOROZOVA	{"phone": "+70354734675"}
0005432947833	66A7B5	2771 716423	NADEZHDA DENISOVA	{"email": "denisovanadezhda_13071966@postgrespro.ru", "phone": "+70352989887"}
0005432947834	E5D3E5	0326 512893	ALEKSANDRA KONDRATEVA	{"email": "kondrateva-a.29061968@postgrespro.ru", "phone": "+70308749097"}
0005432947835	E5D3E5	6460 460198	YURIY TIKHONOV	{"email": "ytikhonov.1972@postgrespro.ru", "phone": "+70188393247"}
0005432947836	E5D3E5	3747 599374	MAKSIM SOROKIN	{"phone": "+70566659777"}
0005432947837	5C911F	2639 105223	IRINA KOROLEVA	{"phone": "+70468769893"}
0005432947838	F4C95F	4479 865459	DARYA SMIRNOVA	{"email": "d.smirnova_1978@postgrespro.ru", "phone": "+70752039231"}
0005432947839	F4C95F	4747 134473	ALEKSANDR RODIONOV	{"email": "rodionov_aleksandr_1969@postgrespro.ru", "phone": "+70097345900"}
0005432947840	A2BF0A	1742 186208	SERGEY IVANOV	{"email": "ivanov_sergey_1971@postgrespro.ru", "phone": "+70735779428"}
0005432947841	9D234A	3869 579119	EKATERINA SERGEEVA	{"email": "sergeeva_ekaterina.1976@postgrespro.ru", "phone": "+70105785478"}
0005432947842	75B97A	0548 377759	NELLI OSIPOVA	{"email": "n_osipova.021977@postgrespro.ru", "phone": "+70207388636"}
0005432947843	626ACD	4721 243697	DILYARA MAKAROVA	{"phone": "+70851119660"}
0005432947844	50C8B8	7024 861888	EKATERINA YUDINA	{"phone": "+70625053526"}
0005432947845	50C8B8	8454 667171	LARISA MAKSIMOVA	{"email": "l_maksimova15061977@postgrespro.ru", "phone": "+70167324527"}
0005432947846	D372E0	6766 588990	OLEG BORISOV	{"phone": "+70485178596"}
0005432947847	0F6C9F	8402 588138	ALEFTINA SOKOLOVA	{"phone": "+70142685619"}
0005432947848	13A549	3513 452612	ALINA KOZLOVA	{"phone": "+70771012214"}
0005432947849	34177B	8317 528778	SERGEY ZHUKOV	{"email": "zhukovs_051966@postgrespro.ru", "phone": "+70318247375"}
0005432947850	34177B	4115 565182	ARINA ISAEVA	{"email": "isaeva_arina_111975@postgrespro.ru", "phone": "+70771788582"}
0005432947851	DACD8E	4062 056012	YULIYA ZAYCEVA	{"phone": "+70226820140"}
0005432947852	DACD8E	8836 913630	RUSLAN MATVEEV	{"email": "r-matveev1974@postgrespro.ru", "phone": "+70577495229"}
0005432947853	1E681C	3291 972883	LYUBOV MELNIKOVA	{"phone": "+70850112311"}
0005432947854	60CD9E	5676 093948	LIDIYA SCHERBAKOVA	{"email": "scherbakova_l24111966@postgrespro.ru", "phone": "+70270657297"}
0005432947855	60CD9E	4492 692480	VALENTINA KOROLEVA	{"phone": "+70527101271"}
0005432947856	60CD9E	5661 971777	YURIY GAVRILOV	{"email": "gavrilov-y_08081979@postgrespro.ru", "phone": "+70715300890"}
0005432947857	A9CE9C	2496 071245	KONSTANTIN SOKOLOV	{"phone": "+70704134296"}
0005432947858	938A32	5824 117256	VLADISLAV BONDARENKO	{"email": "bondarenko-v061970@postgrespro.ru", "phone": "+70866982201"}
0005432947859	938A32	5265 365533	ANTONINA VOROBEVA	{"email": "vorobeva_antonina_031973@postgrespro.ru", "phone": "+70871301226"}
0005432947860	95601A	9443 795483	ALEKSEY ZAKHAROV	{"phone": "+70373064464"}
0005432947861	95601A	3261 534471	TATYANA POTAPOVA	{"phone": "+70150706934"}
0005432947862	11A60F	8766 496703	VERA TROFIMOVA	{"phone": "+70922025200"}
0005432947863	7F6AED	1347 362242	SEMEN ZAKHAROV	{"email": "szakharov_071961@postgrespro.ru", "phone": "+70414393749"}
0005432947864	1E9FD2	6385 251043	OLGA ZAYCEVA	{"phone": "+70943134492"}
0005432947865	1E9FD2	7736 032247	VIKTOR SMIRNOV	{"email": "vsmirnov_021975@postgrespro.ru", "phone": "+70448966242"}
0005432947866	C2AAB7	2235 739083	DANIL MATVEEV	{"email": "danilmatveev-07121969@postgrespro.ru", "phone": "+70735816990"}
0005432947867	CE1F87	4922 550516	ELIZAVETA SOROKINA	{"phone": "+70776107835"}
0005432947868	17A321	1794 707872	OLGA MAKAROVA	{"email": "o.makarova_1974@postgrespro.ru", "phone": "+70904779994"}
0005432947869	17A321	9037 908199	VYACHESLAV ZAKHAROV	{"email": "v.zakharov.051980@postgrespro.ru", "phone": "+70806611410"}
0005432947870	C6F7E7	7657 456552	KSENIYA VLASOVA	{"email": "vlasova-kseniya-1978@postgrespro.ru", "phone": "+70270829051"}
0005432947871	C6F7E7	9165 512944	PAVEL KONOVALOV	{"email": "konovalov_pavel_1974@postgrespro.ru", "phone": "+70600831466"}
0005432947872	5F6A10	5575 197864	DINA AFANASEVA	{"email": "dina.afanaseva-091961@postgrespro.ru", "phone": "+70798501378"}
0005432947873	C1F69D	5311 618931	ILONA ALEKSANDROVA	{"email": "aleksandrovai_17121967@postgrespro.ru", "phone": "+70179191047"}
0005432947874	C1F69D	9650 624800	OLGA POPOVA	{"email": "popova-o18111961@postgrespro.ru", "phone": "+70369938383"}
0005432947875	29775F	7279 440299	ROZA ZOTOVA	{"phone": "+70225848190"}
0005432947876	E98976	7461 311176	ELENA MALYSHEVA	{"email": "e-malysheva041966@postgrespro.ru", "phone": "+70915754352"}
0005432947877	E98976	9521 865817	ANNA TITOVA	{"phone": "+70563318072"}
0005432947878	850B96	7637 615461	VLADIMIR ZAYCEV	{"email": "vzaycev101974@postgrespro.ru", "phone": "+70538692376"}
0005432947879	850B96	1442 096106	NIKITA PETROV	{"email": "nikita_petrov-24011973@postgrespro.ru", "phone": "+70820171769"}
0005432947880	850B96	8324 903805	ARTEM IVANOV	{"email": "ivanov-artem13021963@postgrespro.ru", "phone": "+70147777042"}
0005432947881	B8FDFB	0240 600508	PAVEL KUDRYASHOV	{"email": "kudryashovpavel-21061962@postgrespro.ru", "phone": "+70451185589"}
0005432947882	B8FDFB	7544 844003	EMILIYA IVANOVA	{"phone": "+70011527633"}
0005432947883	DF26FB	1322 294462	ZOYA ZAKHAROVA	{"phone": "+70286629590"}
0005432947884	DF26FB	3604 355273	YURIY PETROV	{"phone": "+70483399722"}
0005432947885	8596A2	2591 962147	EDUARD ANTONOV	{"email": "antonov.e021969@postgrespro.ru", "phone": "+70908268640"}
0005432947886	3F247B	8360 077003	LILIYA KOROLEVA	{"email": "l_koroleva_081968@postgrespro.ru", "phone": "+70730186244"}
0005432947887	7DD0AC	0050 190162	YULIYA ZHUKOVA	{"phone": "+70433484411"}
0005432947888	7DD0AC	1943 576375	VALENTINA MELNIKOVA	{"phone": "+70305390037"}
0005432947889	737773	2074 533410	ANATOLIY TARASOV	{"phone": "+70055766842"}
0005432947890	737773	8028 455725	DARYA FILIPPOVA	{"email": "filippova-darya-29071973@postgrespro.ru", "phone": "+70456904199"}
0005432947891	737773	6773 297441	NIKOLAY MIRONOV	{"phone": "+70612265618"}
0005432947892	DFD545	9700 541751	TAMARA MAKAROVA	{"email": "tamara-makarova04031960@postgrespro.ru", "phone": "+70360526259"}
0005432947893	11DD8D	6962 504922	NATALYA PETROVA	{"email": "petrovan051970@postgrespro.ru", "phone": "+70542830756"}
0005432947894	94A27A	8893 438744	IRINA SAVELEVA	{"phone": "+70136359614"}
0005432947895	94A27A	0084 394316	SVETLANA FILIPPOVA	{"phone": "+70116222789"}
0005432947896	C00AF4	3402 921786	GALINA DENISOVA	{"phone": "+70110562480"}
0005432947897	FF18C2	5745 194864	IRINA KUDRYASHOVA	{"email": "irina.kudryashova.15081971@postgrespro.ru", "phone": "+70135646758"}
0005432947898	10CBB4	1803 515791	ARTEM ZAKHAROV	{"email": "artem_zakharov-121966@postgrespro.ru", "phone": "+70137584911"}
0005432947899	08BA49	6298 266705	VLADIMIR SCHERBAKOV	{"email": "scherbakov.v.051961@postgrespro.ru", "phone": "+70699163305"}
0005432947900	D932ED	2613 487523	OLGA SMIRNOVA	{"email": "olga.smirnova.13081973@postgrespro.ru", "phone": "+70090334780"}
0005432947901	D932ED	9627 031168	ALEKSANDRA ROMANOVA	{"email": "aromanova.071974@postgrespro.ru", "phone": "+70919023297"}
0005432947902	D932ED	8355 503909	VLADIMIR TIKHONOV	{"email": "vladimirtikhonov121961@postgrespro.ru", "phone": "+70740303025"}
0005432947903	AD7EFA	2725 575388	ALEKSEY TIMOFEEV	{"email": "timofeev.a_011972@postgrespro.ru", "phone": "+70956821215"}
0005432947904	CE1493	9366 736879	NAIL DENISOV	{"phone": "+70818726746"}
0005432947905	1EF8A6	5543 560775	VLADIMIR CHERNOV	{"phone": "+70645878849"}
0005432947963	5A17B6	1707 515195	ANDREY TIKHONOV	{"phone": "+70636325043"}
0005432947906	1EF8A6	0769 920952	SERGEY BARANOV	{"email": "baranov_sergey_041981@postgrespro.ru", "phone": "+70489678680"}
0005432947907	393C31	0352 014827	ZINAIDA RODIONOVA	{"email": "rodionova.z_1966@postgrespro.ru", "phone": "+70538086602"}
0005432947908	393C31	2959 923066	MARIYA KONOVALOVA	{"email": "m_konovalova-101972@postgrespro.ru", "phone": "+70986856952"}
0005432947909	87AD9F	0481 872423	VLADIMIR VOROBEV	{"phone": "+70832917034"}
0005432947910	485754	2982 051476	VIKTOR OSIPOV	{"phone": "+70030314370"}
0005432947911	3C1553	5048 752297	TATYANA KUZNECOVA	{"phone": "+70108750919"}
0005432947912	965D84	1406 789024	ALEKSEY VASILEV	{"phone": "+70745285799"}
0005432947913	221458	8280 604962	IGOR EGOROV	{"phone": "+70303561492"}
0005432947914	221458	1223 910768	NATALYA RODIONOVA	{"phone": "+70408964802"}
0005432947915	DAD90C	2336 727329	RUSTAM MOROZOV	{"phone": "+70587928210"}
0005432947916	DAD90C	8536 493936	EVGENIY SOKOLOV	{"email": "esokolov04031969@postgrespro.ru", "phone": "+70668380366"}
0005432947917	DAD90C	0368 039288	LEONID FEDOTOV	{"email": "fedotov-l.071977@postgrespro.ru", "phone": "+70306413364"}
0005432947918	36BD88	9796 878925	ALEKSANDR SHEVCHENKO	{"phone": "+70026030303"}
0005432947919	D464C4	9591 468383	POLINA ZAKHAROVA	{"phone": "+70811121349"}
0005432947920	715476	7366 788492	EVGENIY SEMENOV	{"phone": "+70430236148"}
0005432947921	C0BB3B	2205 728756	EKATERINA FOMINA	{"email": "ekaterina_fomina.1977@postgrespro.ru", "phone": "+70634681459"}
0005432947922	9FDFD1	1678 651152	LYUBOV NAUMOVA	{"phone": "+70841936865"}
0005432947923	9FDFD1	1911 875135	NIKOLAY MAKAROV	{"email": "n.makarov14071972@postgrespro.ru", "phone": "+70840125856"}
0005432947924	9FDFD1	4878 698941	ELENA AFANASEVA	{"phone": "+70620411721"}
0005432947925	F4EBA8	2783 070326	VLADIMIR SAVELEV	{"email": "savelevvladimir081969@postgrespro.ru", "phone": "+70317334846"}
0005432947926	2BCC7E	7444 558061	ELENA FEDOROVA	{"phone": "+70537421055"}
0005432947927	2BCC7E	4248 652830	EVGENIY PETROV	{"phone": "+70061902745"}
0005432947928	63F141	9003 580444	MIKHAIL ABRAMOV	{"phone": "+70043339908"}
0005432947929	C186D6	2077 459015	ALEKSEY ILIN	{"phone": "+70392641820"}
0005432947930	C44705	1189 304946	DARYA EFIMOVA	{"email": "efimovad_1979@postgrespro.ru", "phone": "+70171446664"}
0005432947931	6851F6	1113 910131	SVETLANA KULIKOVA	{"phone": "+70584187665"}
0005432947932	6851F6	9999 460379	OLGA SMIRNOVA	{"email": "smirnova_olga_08111970@postgrespro.ru", "phone": "+70382792766"}
0005432947933	E3043F	5353 790601	ELENA VOLKOVA	{"phone": "+70345316972"}
0005432947934	BAB3CA	2531 155600	NINA GORBUNOVA	{"phone": "+70407341266"}
0005432947935	BAB3CA	6379 807531	ALEKSANDR MAKSIMOV	{"phone": "+70157510352"}
0005432947936	62DFC5	4158 028035	MARINA NOVIKOVA	{"email": "marina.novikova-10081975@postgrespro.ru", "phone": "+70798761900"}
0005432947937	62DFC5	7964 573434	EVGENIY STEPANOV	{"email": "evgeniy-stepanov111975@postgrespro.ru", "phone": "+70990687247"}
0005432947938	54AEEB	2428 325637	MIKHAIL KISELEV	{"phone": "+70518586977"}
0005432947939	7EBDC3	0050 857891	FEDOR MELNIKOV	{"phone": "+70219621504"}
0005432947940	7EBDC3	1066 781967	DENIS KUZNECOV	{"email": "kuznecovd1987@postgrespro.ru", "phone": "+70487966566"}
0005432947941	044009	9937 912259	LYUDMILA POPOVA	{"email": "lpopova.121971@postgrespro.ru", "phone": "+70442991907"}
0005432947942	044009	5095 170207	NATALYA KUZMINA	{"phone": "+70062652455"}
0005432947943	33E821	6639 351977	ANASTASIYA AKIMOVA	{"email": "akimovaanastasiya17061970@postgrespro.ru", "phone": "+70436563821"}
0005432947944	879511	8919 277074	IRINA VOROBEVA	{"phone": "+70109266976"}
0005432947945	879511	9569 213512	OLGA ORLOVA	{"email": "olgaorlova_111972@postgrespro.ru", "phone": "+70864950124"}
0005432947946	845494	7963 131242	NINA KUDRYASHOVA	{"phone": "+70745003141"}
0005432947947	6B88FE	2354 288265	ALEKSEY SOLOVEV	{"phone": "+70861370866"}
0005432947948	6D89F8	9225 672701	EKATERINA KOROLEVA	{"phone": "+70064056266"}
0005432947949	6D89F8	1665 989239	OLGA STEPANOVA	{"email": "stepanova-o21091976@postgrespro.ru", "phone": "+70196114363"}
0005432947950	72BE1D	9587 992750	ALBERT PAVLOV	{"phone": "+70525688518"}
0005432947951	38ADCB	9403 323105	OKSANA FROLOVA	{"email": "frolova_o.091977@postgrespro.ru", "phone": "+70260279417"}
0005432947952	38ADCB	7254 173043	ILMIRA MOISEEVA	{"email": "moiseeva_ilmira-061979@postgrespro.ru", "phone": "+70628154273"}
0005432947953	D140AE	0875 417593	ALEKSANDR SCHERBAKOV	{"phone": "+70472040577"}
0005432947954	AAB6B7	3439 765944	EKATERINA SEMENOVA	{"email": "semenova_ekaterina-121982@postgrespro.ru", "phone": "+70547248008"}
0005432947955	AAB6B7	1165 694807	OLGA GERASIMOVA	{"phone": "+70943101213"}
0005432947956	AAB6B7	6138 023488	ALEKSANDRA SOROKINA	{"email": "a-sorokina.051982@postgrespro.ru", "phone": "+70982417684"}
0005432947957	92F3EB	3864 557058	ALEKSEY ROMANOV	{"email": "romanova-1972@postgrespro.ru", "phone": "+70291394356"}
0005432947958	5BB45D	9867 208002	TATYANA KUZNECOVA	{"email": "kuznecovat.08081973@postgrespro.ru", "phone": "+70485760783"}
0005432947959	5BB45D	4803 679654	DMITRIY KUZNECOV	{"phone": "+70700103574"}
0005432947960	9BC536	5213 436387	EKATERINA MELNIKOVA	{"phone": "+70477279536"}
0005432947961	9BC536	8783 913515	INNA IVANOVA	{"email": "ivanova.inna_011979@postgrespro.ru", "phone": "+70078266352"}
0005432947962	5A17B6	0816 322395	NIKITA PETROV	{"email": "nikita.petrov.23031964@postgrespro.ru", "phone": "+70837080334"}
0005432947964	1904A0	3584 093252	ANNA ILINA	{"email": "ilina.anna.17021966@postgrespro.ru", "phone": "+70220464476"}
0005432947965	1904A0	3978 930336	ALBINA KUDRYASHOVA	{"email": "kudryashova.a061977@postgrespro.ru", "phone": "+70272044856"}
0005432947966	02DE2C	5421 910757	TATYANA ANTONOVA	{"phone": "+70551893012"}
0005432947967	02DE2C	4757 499305	VALENTINA ANTONOVA	{"email": "antonova_valentina1973@postgrespro.ru", "phone": "+70459045562"}
0005432947968	0FCA9B	6226 457504	MARINA STEPANOVA	{"phone": "+70352715734"}
0005432947969	904288	0849 919383	IRINA POPOVA	{"phone": "+70714542027"}
0005432947970	904288	6492 267323	ELVIRA VASILEVA	{"phone": "+70086744949"}
0005432947971	0E8BDF	8118 729544	GALINA DENISOVA	{"email": "galina_denisova-031971@postgrespro.ru", "phone": "+70109807807"}
0005432947972	458811	4861 282167	MIKHAIL ZHUKOV	{"phone": "+70170382614"}
0005432947973	458811	8443 899895	RAFAIL FROLOV	{"phone": "+70453640622"}
0005432947974	458811	2261 919254	MARIYA PAVLOVA	{"phone": "+70720925922"}
0005432947975	F1619A	8769 877039	SVETLANA YAKOVLEVA	{"email": "svetlana-yakovleva1973@postgrespro.ru", "phone": "+70508167526"}
0005432947976	F1619A	6217 187086	ALEKSANDR KISELEV	{"email": "akiselev-111959@postgrespro.ru", "phone": "+70936925972"}
0005432947977	CC0E30	9200 257369	NIKOLAY RODIONOV	{"phone": "+70381572356"}
0005432947978	66155C	6363 649577	ANDREY DMITRIEV	{"email": "dmitrievandrey-1970@postgrespro.ru", "phone": "+70905089354"}
0005432947979	669E61	0403 389320	VLADIMIR BORISOV	{"phone": "+70522286013"}
0005432947980	689485	2029 174397	KIRILL SERGEEV	{"email": "sergeev-k.081977@postgrespro.ru", "phone": "+70526419938"}
0005432947981	61ACAF	6106 310938	VALENTINA FROLOVA	{"phone": "+70161447195"}
0005432947982	0B9DFB	0811 679472	ALEKSEY KUZNECOV	{"email": "akuznecov1976@postgrespro.ru", "phone": "+70113344014"}
0005432947983	251749	2984 055057	MARINA KOZLOVA	{"email": "marina-kozlova091961@postgrespro.ru", "phone": "+70925666565"}
0005432947984	251749	1152 197308	OLGA KRASNOVA	{"email": "o-krasnova-1961@postgrespro.ru", "phone": "+70339371527"}
0005432947985	6C2C97	7098 593396	ELENA NIKITINA	{"phone": "+70372529493"}
0005432947986	6C2C97	8906 859663	GALINA KALININA	{"phone": "+70426421935"}
0005432947987	6C2C97	8006 945412	ALEKSANDR DENISOV	{"email": "denisov-a_27051976@postgrespro.ru", "phone": "+70562922329"}
0005432947988	D8E64F	2290 966140	ALEKSEY PAVLOV	{"email": "aleksey.pavlov041973@postgrespro.ru", "phone": "+70327339178"}
0005432947989	B5C1B9	2328 769587	ALEKSANDR KUZNECOV	{"email": "a-kuznecov-1970@postgrespro.ru", "phone": "+70964837168"}
0005432947990	D70571	8259 224061	ARINA BELYAEVA	{"phone": "+70993975378"}
0005432947991	D70571	4127 966636	ELENA KONOVALOVA	{"email": "e_konovalova_1980@postgrespro.ru", "phone": "+70438431638"}
0005432947992	403A50	6402 881750	VALENTINA RODIONOVA	{"email": "v.rodionova051966@postgrespro.ru", "phone": "+70691169754"}
0005432947993	403A50	7547 202722	ALEKSANDRA PETROVA	{"email": "a.petrova-101985@postgrespro.ru", "phone": "+70796959901"}
0005432947994	403A50	2838 457291	VIKTOR ISAEV	{"phone": "+70812015722"}
0005432947995	0AB9B7	7567 474544	MATVEY NIKOLAEV	{"phone": "+70060143188"}
0005432947996	3F5F7C	0233 233020	IVAN MELNIKOV	{"email": "melnikov.i-1975@postgrespro.ru", "phone": "+70639401718"}
0005432947997	EA44B7	1991 291042	MARIYA EFREMOVA	{"email": "mariya-efremova.10031969@postgrespro.ru", "phone": "+70330664069"}
0005432947998	EA44B7	2594 438636	ANDREY FEDOTOV	{"email": "afedotov.021976@postgrespro.ru", "phone": "+70735817210"}
0005432947999	90CB8B	7115 675292	NAILYA GORBUNOVA	{"phone": "+70542435329"}
0005432948000	90CB8B	7973 121220	DMITRIY SCHERBAKOV	{"email": "scherbakov-d_05031973@postgrespro.ru", "phone": "+70536561391"}
0005432948001	FB0E66	7301 673915	GALINA NESTEROVA	{"email": "galinanesterova_21011981@postgrespro.ru", "phone": "+70430634474"}
0005432948002	B10DDD	7477 884752	SVETLANA BELYAEVA	{"phone": "+70082491508"}
0005432948003	AF8489	6404 976135	YULIYA KUZNECOVA	{"phone": "+70599283551"}
0005432948004	800287	9449 248219	EVGENIY ALEKSANDROV	{"email": "aleksandrov_e_101965@postgrespro.ru", "phone": "+70409597447"}
0005432948005	6FAEC9	8222 544874	YURIY MOROZOV	{"phone": "+70301485596"}
0005432948006	6FAEC9	5176 657934	ANASTASIYA POTAPOVA	{"phone": "+70022235482"}
0005432948007	A7B0B8	2926 567031	EVGENIY KULIKOV	{"email": "evgeniy.kulikov29051967@postgrespro.ru", "phone": "+70922469211"}
0005432948008	472719	4750 011500	MIKHAIL ALEKSANDROV	{"email": "mikhail.aleksandrov_041974@postgrespro.ru", "phone": "+70909134050"}
0005432948009	472719	7025 893514	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov-1975@postgrespro.ru", "phone": "+70912707070"}
0005432948010	54EA44	0619 046017	LYUDMILA RYABOVA	{"email": "l-ryabova-1981@postgrespro.ru", "phone": "+70100488549"}
0005432948011	C8900D	1994 801213	LYUDMILA GERASIMOVA	{"email": "gerasimova-lyudmila1969@postgrespro.ru", "phone": "+70552761215"}
0005432948012	C8900D	1878 612890	RAFAIL SHEVCHENKO	{"phone": "+70551193807"}
0005432948013	CB785E	1710 617023	VALENTIN MIKHAYLOV	{"email": "mikhaylov_v_04051976@postgrespro.ru", "phone": "+70313893981"}
0005432948014	CB785E	6334 473739	RINAT FEDOROV	{"email": "fedorov_r14101968@postgrespro.ru", "phone": "+70335583049"}
0005432948015	246EBE	2221 524631	SERGEY ZAKHAROV	{"email": "zakharov_s-111974@postgrespro.ru", "phone": "+70351596906"}
0005432948016	3D3E93	2289 768458	MARAT SMIRNOV	{"email": "smirnov-marat.041977@postgrespro.ru", "phone": "+70133999739"}
0005432948017	3D3E93	9946 218418	ELENA EGOROVA	{"phone": "+70992418436"}
0005432948018	3D3E93	8992 951827	MAKSIM GORBUNOV	{"phone": "+70446600675"}
0005432948019	11885D	3765 534211	NATALYA PAVLOVA	{"email": "pavlova_n.1968@postgrespro.ru", "phone": "+70991368704"}
0005432948020	4755ED	5757 301183	ARSEN SAVELEV	{"email": "savelev-a31101975@postgrespro.ru", "phone": "+70567842741"}
0005432948021	4755ED	1924 464063	GALINA SERGEEVA	{"email": "galina_sergeeva15041973@postgrespro.ru", "phone": "+70260120634"}
0005432948022	4755ED	0739 611816	ALEKSANDR KOZLOV	{"phone": "+70465535338"}
0005432948023	411354	6140 638754	EKATERINA KUZNECOVA	{"email": "ekaterina-kuznecova23011974@postgrespro.ru", "phone": "+70502887564"}
0005432948024	45B80D	9467 361923	LYUDMILA MOROZOVA	{"email": "morozova-l-24071965@postgrespro.ru", "phone": "+70683555902"}
0005432948025	45B80D	4060 426167	YURIY BONDARENKO	{"email": "yuriy.bondarenko031979@postgrespro.ru", "phone": "+70819886649"}
0005432948026	45B80D	9586 170318	ELENA SOKOLOVA	{"phone": "+70226033769"}
0005432948027	E255BD	9617 409038	VITALIY CHERNOV	{"email": "vitaliy.chernov-1978@postgrespro.ru", "phone": "+70290845368"}
0005432948028	E255BD	8947 537527	NADEZHDA STEPANOVA	{"email": "stepanova_nadezhda_1971@postgrespro.ru", "phone": "+70930459154"}
0005432948029	F30337	8692 153787	DMITRIY POPOV	{"phone": "+70335014379"}
0005432948030	77CE30	1539 701214	ANDREY MOROZOV	{"email": "morozov_andrey_1971@postgrespro.ru", "phone": "+70035719322"}
0005432948031	FA56AD	9336 183490	SERGEY IVANOV	{"email": "sergey.ivanov24041983@postgrespro.ru", "phone": "+70253597685"}
0005432948032	FA56AD	8670 804962	ALEKSEY ISAEV	{"email": "isaev-aleksey_1968@postgrespro.ru", "phone": "+70298401793"}
0005432948033	84403B	1773 558851	SVETLANA IVANOVA	{"phone": "+70596555555"}
0005432948034	E03FD0	4508 125829	YULIYA GAVRILOVA	{"phone": "+70393506808"}
0005432948035	706E58	0782 161615	YURIY GRIGOREV	{"email": "y_grigorev10081966@postgrespro.ru", "phone": "+70919469536"}
0005432948036	E391CD	8858 022586	TATYANA PAVLOVA	{"email": "tatyana-pavlova061961@postgrespro.ru", "phone": "+70796819687"}
0005432948037	6F70BF	4009 770469	NIKITA VOROBEV	{"email": "n-vorobev121978@postgrespro.ru", "phone": "+70692799273"}
0005432948038	33C682	0366 108556	GALINA KOMAROVA	{"email": "komarovagalina_101983@postgrespro.ru", "phone": "+70055099635"}
0005432948039	FC6A61	4590 924195	YULIYA NESTEROVA	{"phone": "+70520829130"}
0005432948040	258D08	3904 190744	IRINA BOGDANOVA	{"phone": "+70824363450"}
0005432948041	C395B0	8670 643890	MIKHAIL TIKHONOV	{"phone": "+70288992522"}
0005432948042	43254D	5604 594868	SEMEN FROLOV	{"phone": "+70745201476"}
0005432948043	43254D	0423 902379	TATYANA PAVLOVA	{"email": "pavlovat.1978@postgrespro.ru", "phone": "+70843521269"}
0005432948044	B066B9	4433 331624	FATIMA ABRAMOVA	{"email": "abramova-fatima_23071966@postgrespro.ru", "phone": "+70678837573"}
0005432948045	E2E886	3471 503059	LYUDMILA MAKSIMOVA	{"email": "maksimoval.121972@postgrespro.ru", "phone": "+70745917148"}
0005432948046	E2E886	9768 628282	OLEG STEPANOV	{"email": "o-stepanov1965@postgrespro.ru", "phone": "+70687855800"}
0005432948102	53ECB0	1167 068549	ALEKSANDR MIRONOV	{"phone": "+70307868090"}
0005432948047	92A387	5816 432729	OLEG ALEKSANDROV	{"email": "aleksandrovoleg.1972@postgrespro.ru", "phone": "+70556856042"}
0005432948048	92A387	1917 947647	SVETLANA MELNIKOVA	{"email": "s-melnikova061978@postgrespro.ru", "phone": "+70086740441"}
0005432948049	D00257	4934 383204	SERGEY PAVLOV	{"phone": "+70803799080"}
0005432948050	E33163	8279 189669	ALEKSEY VLASOV	{"phone": "+70620071182"}
0005432948051	0B3143	2422 880917	LARISA STEPANOVA	{"email": "l-stepanova_041973@postgrespro.ru", "phone": "+70496679770"}
0005432948052	80BE06	0907 200523	EVGENIY NAUMOV	{"phone": "+70452968373"}
0005432948112	E1EE87	7028 209574	VADIM GUSEV	{"phone": "+70490481980"}
0005432948053	1E2DCC	3065 512009	NATALYA ARKHIPOVA	{"email": "arkhipova_natalya-111966@postgrespro.ru", "phone": "+70634454930"}
0005432948054	62DCE3	8937 874609	VLADIMIR PETROV	{"phone": "+70659649334"}
0005432948055	C2ED6F	5766 295807	DARYA ZHUKOVA	{"email": "zhukovadarya.01021983@postgrespro.ru", "phone": "+70786985917"}
0005432948056	DDFAF8	8983 972458	GALINA RODIONOVA	{"email": "g_rodionova-1968@postgrespro.ru", "phone": "+70005147671"}
0005432948057	868F61	1243 624967	YURIY YAKOVLEV	{"phone": "+70042646960"}
0005432948058	73A534	0351 148415	VLADIMIR KAZAKOV	{"phone": "+70908222284"}
0005432948059	857998	8925 690090	ROMAN ZHURAVLEV	{"phone": "+70379517848"}
0005432948060	857998	7638 371599	ARTEM SOROKIN	{"phone": "+70242910964"}
0005432948061	BFCBBD	7719 523303	VERA KUZNECOVA	{"email": "kuznecovavera_061967@postgrespro.ru", "phone": "+70482018993"}
0005432948062	BFCBBD	2693 404688	EVGENIY GAVRILOV	{"email": "gavrilov.e-101966@postgrespro.ru", "phone": "+70589919099"}
0005432948063	D121B5	3553 910889	MARIYA TIMOFEEVA	{"phone": "+70130659173"}
0005432948064	6AFCC9	8815 309829	VIKTORIYA GAVRILOVA	{"email": "viktoriya-gavrilova_081969@postgrespro.ru", "phone": "+70378465301"}
0005432948065	6AFCC9	5597 162493	VADIM MOROZOV	{"phone": "+70975680841"}
0005432948066	77F39C	3455 193957	ALEVTINA LEBEDEVA	{"email": "lebedeva_alevtina23061973@postgrespro.ru", "phone": "+70807740979"}
0005432948067	77F39C	2983 955576	ALBINA BOGDANOVA	{"phone": "+70250196430"}
0005432948068	AAFDEA	0250 071074	NINA KARPOVA	{"email": "karpova_nina.10031969@postgrespro.ru", "phone": "+70296691685"}
0005432948069	C84D4F	2431 529745	IRINA IVANOVA	{"email": "ivanova_i.1969@postgrespro.ru", "phone": "+70518397932"}
0005432948070	B522D8	3105 818553	OKSANA SOLOVEVA	{"email": "oksana_soloveva1970@postgrespro.ru", "phone": "+70802661532"}
0005432948071	55A1D2	8603 869512	VALERIY MARTYNOV	{"email": "martynovvaleriy_09021972@postgrespro.ru", "phone": "+70628917396"}
0005432948072	CF7C88	2862 899709	YULIYA KOMAROVA	{"phone": "+70648783610"}
0005432948073	01FDDA	1336 737668	GALINA ISAEVA	{"phone": "+70865011679"}
0005432948074	7AED64	4165 277197	YURIY MEDVEDEV	{"email": "medvedev.yuriy.1973@postgrespro.ru", "phone": "+70312453550"}
0005432948075	7AED64	7791 581070	LYUBOV PETROVA	{"email": "petrova-lyubov.17091982@postgrespro.ru", "phone": "+70076202176"}
0005432948076	619116	5009 910379	VLADISLAV AFANASEV	{"phone": "+70105932230"}
0005432948077	25DE19	8279 206697	DARYA GRISHINA	{"phone": "+70733419025"}
0005432948078	25DE19	3713 948866	ANNA VASILEVA	{"email": "vasileva.a-1966@postgrespro.ru", "phone": "+70060349436"}
0005432948079	970DBB	7111 770639	ALEKSANDR FEDOROV	{"email": "a_fedorov-021969@postgrespro.ru", "phone": "+70270461339"}
0005432948080	970DBB	9899 239226	GALINA KUZNECOVA	{"email": "g_kuznecova051980@postgrespro.ru", "phone": "+70866965282"}
0005432948081	6E2745	1475 614474	EKATERINA ANISIMOVA	{"email": "ekaterina.anisimova1983@postgrespro.ru", "phone": "+70907793480"}
0005432948082	3C70E4	7315 564161	VLADIMIR TIMOFEEV	{"email": "timofeev_v-10111977@postgrespro.ru", "phone": "+70576384045"}
0005432948083	B7CBF7	0363 885005	ALEKSEY KONOVALOV	{"phone": "+70736314495"}
0005432948084	D6A46F	8045 531873	NIKOLAY OSIPOV	{"phone": "+70914135640"}
0005432948085	065B2E	5820 558865	ANDREY SMIRNOV	{"email": "smirnovandrey-121977@postgrespro.ru", "phone": "+70709480911"}
0005432948086	6CCE00	2481 631555	ALEKSEY FILIPPOV	{"email": "filippov_a-27041973@postgrespro.ru", "phone": "+70210978150"}
0005432948087	AF22DC	2481 896850	ALEKSANDRA KUDRYASHOVA	{"email": "akudryashova_25031974@postgrespro.ru", "phone": "+70892017600"}
0005432948088	507057	2621 540697	ALEKSANDR FROLOV	{"email": "frolov.aleksandr061968@postgrespro.ru", "phone": "+70631725209"}
0005432948089	507057	7755 473226	RINAT KOZLOV	{"email": "kozlov.rinat.111976@postgrespro.ru", "phone": "+70849558016"}
0005432948090	49E437	8183 095395	ALEKSEY GUSEV	{"email": "gusev_a1972@postgrespro.ru", "phone": "+70149482289"}
0005432948091	49E437	0703 373454	NIKOLAY MIKHAYLOV	{"phone": "+70564192135"}
0005432948092	49E437	7577 687935	ANDREY KARPOV	{"email": "a_karpov_20081978@postgrespro.ru", "phone": "+70415436487"}
0005432948093	D6C2CB	0194 470485	NAILYA ISAEVA	{"phone": "+70859071166"}
0005432948094	4F69FB	4286 413213	ALEKSEY ANTONOV	{"email": "antonov_aleksey.1981@postgrespro.ru", "phone": "+70642141633"}
0005432948095	4F69FB	1705 929024	NATALYA ROMANOVA	{"email": "natalya-romanova.071984@postgrespro.ru", "phone": "+70625154697"}
0005432948096	4F69FB	9784 137262	TATYANA ANDREEVA	{"phone": "+70706305040"}
0005432948097	A745C6	9142 556221	VALERIY BONDARENKO	{"email": "v.bondarenko_21051969@postgrespro.ru", "phone": "+70853964278"}
0005432948098	99CD45	4640 471166	ALEKSANDR CHERNOV	{"phone": "+70702909992"}
0005432948099	A4397A	3842 427369	NATALYA EFREMOVA	{"phone": "+70316702886"}
0005432948100	858C9E	7613 981590	NATALYA VOLKOVA	{"email": "n-volkova061971@postgrespro.ru", "phone": "+70817525076"}
0005432948101	967765	3916 454196	VLADIMIR GAVRILOV	{"email": "gavrilov.v071982@postgrespro.ru", "phone": "+70239120741"}
0005432948103	862C5B	1408 485999	SOFYA IVANOVA	{"email": "s.ivanova.091982@postgrespro.ru", "phone": "+70698666719"}
0005432948104	862C5B	5266 675750	DMITRIY IVANOV	{"email": "ivanov.dmitriy.1971@postgrespro.ru", "phone": "+70134845057"}
0005432948105	EB0223	5720 461923	YULIYA BORISOVA	{"email": "y_borisova-1974@postgrespro.ru", "phone": "+70320896738"}
0005432948106	EB0223	0902 316385	IVAN NIKITIN	{"phone": "+70785645860"}
0005432948107	EB0223	8292 613647	NATALYA LEBEDEVA	{"email": "natalya-lebedeva1962@postgrespro.ru", "phone": "+70278064566"}
0005432948108	529660	0966 719952	ZINAIDA BELYAEVA	{"email": "zbelyaeva021969@postgrespro.ru", "phone": "+70896436934"}
0005432948109	529660	9405 077551	YANA KUDRYASHOVA	{"phone": "+70243712985"}
0005432948110	F49AD5	4574 127618	IGOR MAKSIMOV	{"phone": "+70035690098"}
0005432948111	F49AD5	7193 519445	ELIZAVETA POPOVA	{"email": "elizavetapopova.07121972@postgrespro.ru", "phone": "+70698024503"}
0005432948113	E1EE87	2744 526057	DMITRIY ROMANOV	{"phone": "+70725274412"}
0005432948114	E1EE87	1177 636227	LYUBOV IVANOVA	{"phone": "+70501478157"}
0005432948115	D0BCB0	5924 062275	ALEKSEY BORISOV	{"email": "borisovaleksey081972@postgrespro.ru", "phone": "+70609757212"}
0005432948116	D0BCB0	5354 133639	YAROSLAV TIMOFEEV	{"phone": "+70980420128"}
0005432948117	65529B	4042 359559	DIANA NIKITINA	{"email": "nikitinad101961@postgrespro.ru", "phone": "+70706960574"}
0005432948118	65529B	8927 996704	IGOR ISAEV	{"email": "isaev.igor-1970@postgrespro.ru", "phone": "+70351900568"}
0005432948119	3118D1	4124 357954	OLGA KUZMINA	{"email": "olga-kuzmina11041974@postgrespro.ru", "phone": "+70955664029"}
0005432948120	355F86	5833 213549	MARINA GUSEVA	{"phone": "+70326895373"}
0005432948121	F99175	2366 061223	KONSTANTIN NIKITIN	{"phone": "+70786009729"}
0005432948122	B665E4	1108 837066	LYUBOV KISELEVA	{"email": "lkiseleva_1963@postgrespro.ru", "phone": "+70950832634"}
0005432948123	0D2458	4109 033142	GENNADIY ABRAMOV	{"phone": "+70360559307"}
0005432948124	0D2458	5688 267087	VASILIY GERASIMOV	{"phone": "+70892981112"}
0005432948125	0D2458	6950 739550	OLGA KUZNECOVA	{"email": "olgakuznecova21031977@postgrespro.ru", "phone": "+70750586733"}
0005432948126	5EBB86	6976 512582	PETR NAZAROV	{"phone": "+70639558244"}
0005432948127	960FFA	0517 870436	YURIY SMIRNOV	{"email": "smirnov_y-011981@postgrespro.ru", "phone": "+70771220552"}
0005432948128	960FFA	0091 669895	ALEKSANDR DAVYDOV	{"email": "davydov-a-31011967@postgrespro.ru", "phone": "+70713614762"}
0005432948129	C519D7	6648 677476	LYUDMILA SERGEEVA	{"phone": "+70054949751"}
0005432948130	B71284	3777 340180	OLGA NIKOLAEVA	{"phone": "+70783086625"}
0005432948131	7A9191	6148 603616	VLADIMIR VOLKOV	{"phone": "+70642845134"}
0005432948132	FDA483	5050 981952	DIANA KUDRYASHOVA	{"email": "kudryashova.d061979@postgrespro.ru", "phone": "+70945773385"}
0005432948133	ECF359	0923 977625	ALEKSANDR NAZAROV	{"phone": "+70696675250"}
0005432948134	8713B6	4758 782684	VALENTINA EFREMOVA	{"email": "valentina_efremova_27101961@postgrespro.ru", "phone": "+70513156266"}
0005432948135	8713B6	9552 614240	PAVEL ORLOV	{"phone": "+70681771079"}
0005432948136	C07424	4756 376992	VIKTOR GORBUNOV	{"email": "gorbunov_v_1977@postgrespro.ru", "phone": "+70071924797"}
0005432948137	C07424	1321 617860	MARIYA NIKITINA	{"phone": "+70113472272"}
0005432948138	4979F4	2233 720813	VLADISLAV POPOV	{"email": "v.popov.1966@postgrespro.ru", "phone": "+70935820817"}
0005432948139	D1B3C9	9916 140589	NADEZHDA GORBUNOVA	{"phone": "+70730654107"}
0005432948140	D1B3C9	1708 468355	NATALYA VASILEVA	{"phone": "+70650300105"}
0005432948141	D1B3C9	8025 081266	OLGA NIKOLAEVA	{"phone": "+70911396803"}
0005432948142	4AB153	0216 503031	ALEKSEY PETROV	{"email": "aleksey.petrov.1966@postgrespro.ru", "phone": "+70826835521"}
0005432948143	4AB153	7101 171387	ANATOLIY DMITRIEV	{"phone": "+70041939671"}
0005432948144	6CDD11	3088 299213	MARINA KOLESNIKOVA	{"phone": "+70535997095"}
0005432948145	6F897F	1555 499890	GENNADIY FROLOV	{"email": "g.frolov-27051979@postgrespro.ru", "phone": "+70334845647"}
0005432948146	6F897F	2890 558658	ALISA BARANOVA	{"phone": "+70355784931"}
0005432948147	C47A69	5217 776329	VLADIMIR DMITRIEV	{"phone": "+70809535026"}
0005432948148	4D17C1	3060 216020	VYACHESLAV NIKITIN	{"email": "v_nikitin041983@postgrespro.ru", "phone": "+70276443577"}
0005432948149	22F832	7086 603181	ALENA ALEKSEEVA	{"phone": "+70096094680"}
0005432948150	DBA100	2908 141328	GALINA NESTEROVA	{"phone": "+70497767772"}
0005432948151	DBA100	3125 794660	MAKSIM FEDOROV	{"email": "fedorov.m_1977@postgrespro.ru", "phone": "+70180192769"}
0005432948152	21DCD3	4171 260349	SVYATOSLAV EGOROV	{"email": "svyatoslav-egorov-22091974@postgrespro.ru", "phone": "+70073487242"}
0005432948153	21DCD3	3870 584586	VENIAMIN MIRONOV	{"phone": "+70272223654"}
0005432948154	1701B5	8227 331573	DMITRIY NIKOLAEV	{"phone": "+70984224133"}
0005432948155	1701B5	6903 017748	LYUDMILA AFANASEVA	{"phone": "+70745861309"}
0005432948156	EB0747	6216 120934	SERGEY BORISOV	{"email": "s-borisov_091982@postgrespro.ru", "phone": "+70498887873"}
0005432948157	FE7693	8148 051937	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrova.elizaveta1968@postgrespro.ru", "phone": "+70722586614"}
0005432948158	2CF917	0563 336561	VLADIMIR NAZAROV	{"phone": "+70793766817"}
0005432948159	2CF917	1770 916956	LYUDMILA KOROLEVA	{"email": "koroleva-l-31071980@postgrespro.ru", "phone": "+70867998874"}
0005432948160	AA2953	4232 930109	DMITRIY SMIRNOV	{"email": "dmitriy.smirnov.22071973@postgrespro.ru", "phone": "+70473031767"}
0005432948161	6537E3	0700 145716	MIKHAIL MEDVEDEV	{"email": "medvedev-mikhail22031966@postgrespro.ru", "phone": "+70346186940"}
0005432948162	6537E3	2650 453429	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova-051977@postgrespro.ru", "phone": "+70359081400"}
0005432948163	6537E3	3700 550108	ELENA SMIRNOVA	{"phone": "+70482226226"}
0005432948164	4574DD	3444 817275	LYUDMILA MIRONOVA	{"phone": "+70763573708"}
0005432948165	70ABD9	5141 797746	ALEKSANDR FROLOV	{"phone": "+70451958253"}
0005432948166	70ABD9	2411 857280	SERGEY MARTYNOV	{"email": "martynovs_1976@postgrespro.ru", "phone": "+70483597965"}
0005432948167	472FA0	7049 924975	ZLATA BELOVA	{"email": "z.belova-01091979@postgrespro.ru", "phone": "+70177011565"}
0005432948168	472FA0	6392 578230	MAYA MEDVEDEVA	{"phone": "+70334906227"}
0005432948169	01770F	8510 079059	VLADIMIR VLASOV	{"phone": "+70744158647"}
0005432948170	01770F	5620 625695	TAISIYA NESTEROVA	{"email": "taisiyanesterova121965@postgrespro.ru", "phone": "+70784192601"}
0005432948171	A5CB3E	1648 507055	MARIYA IVANOVA	{"phone": "+70731337152"}
0005432948172	A5CB3E	5865 864596	ALENA ABRAMOVA	{"email": "alena-abramova-1975@postgrespro.ru", "phone": "+70725351075"}
0005432948173	3AB327	5309 451671	TATYANA KOVALEVA	{"phone": "+70069180375"}
0005432948473	BF3250	7969 841594	OLGA KONDRATEVA	{"phone": "+70549703774"}
0005432948174	3AB327	9477 796728	NIKOLAY KUZMIN	{"email": "kuzmin-n-051967@postgrespro.ru", "phone": "+70509753149"}
0005432948175	8CFDCF	0297 478519	MARINA KUZNECOVA	{"email": "mkuznecova.021974@postgrespro.ru", "phone": "+70316335352"}
0005432948176	3BB972	8490 823012	IRINA VASILEVA	{"email": "vasilevai_13051965@postgrespro.ru", "phone": "+70871717852"}
0005432948177	BCA03D	7034 493704	LYUDMILA KARPOVA	{"phone": "+70885922473"}
0005432948178	69CB03	7081 521628	OKSANA LOGINOVA	{"phone": "+70644224475"}
0005432948179	1DFBD8	9903 195229	OLGA SAVELEVA	{"phone": "+70223395376"}
0005432948180	1DFBD8	5525 707186	LYUBOV MASLOVA	{"phone": "+70950602213"}
0005432948181	60554C	3236 267798	DMITRIY EGOROV	{"phone": "+70973238238"}
0005432948182	60554C	8081 609543	ALIYA ALEKSEEVA	{"email": "alekseeva.a.1975@postgrespro.ru", "phone": "+70390332217"}
0005432948183	F85552	7817 012693	VALENTINA NOVIKOVA	{"email": "novikova-v-1976@postgrespro.ru", "phone": "+70463044190"}
0005432948184	C70155	6779 060253	VIKTOR STEPANOV	{"email": "stepanov_v-1971@postgrespro.ru", "phone": "+70258918271"}
0005432948185	C70155	9705 963803	VIKTOR BORISOV	{"phone": "+70189646608"}
0005432948186	A44D17	0820 701482	VIKTORIYA ZAYCEVA	{"phone": "+70058497572"}
0005432948187	D400B6	0592 691626	OLGA KUZMINA	{"phone": "+70754629339"}
0005432948188	D81549	2188 710860	ANNA AFANASEVA	{"phone": "+70165008060"}
0005432948189	873B78	9241 623144	ALEKSANDR AFANASEV	{"phone": "+70520174889"}
0005432948190	43D2A2	7626 094411	ROMAN KARPOV	{"phone": "+70072440451"}
0005432948191	43D2A2	1680 288004	NADEZHDA FILIPPOVA	{"email": "filippovanadezhda031990@postgrespro.ru", "phone": "+70826674725"}
0005432948192	9A4A60	5803 860628	ALLA ANTONOVA	{"email": "aantonova-1975@postgrespro.ru", "phone": "+70611669104"}
0005432948193	E046D9	9277 064421	ANTON MIKHAYLOV	{"email": "mikhaylov_a.1964@postgrespro.ru", "phone": "+70101867722"}
0005432948194	B72858	0119 622235	VIKTOR VASILEV	{"email": "v-vasilev_1963@postgrespro.ru", "phone": "+70041299195"}
0005432948195	78EA90	6298 985708	PAVEL SERGEEV	{"phone": "+70842129958"}
0005432948196	58CFB3	6971 256545	SERGEY FOMIN	{"phone": "+70413631721"}
0005432948197	C4091A	2015 589858	NATALYA MOISEEVA	{"phone": "+70324716505"}
0005432948198	E49644	7794 771362	MAKSIM SERGEEV	{"email": "sergeevmaksim-1963@postgrespro.ru", "phone": "+70141903379"}
0005432948199	95C0D0	0756 566728	NATALIYA SEMENOVA	{"email": "nataliya-semenova-1977@postgrespro.ru", "phone": "+70539863909"}
0005432948200	0A040A	7165 108031	ALEKSANDR ZAYCEV	{"phone": "+70321085991"}
0005432948201	0A040A	7923 081449	DMITRIY FROLOV	{"phone": "+70277319272"}
0005432948202	0557BC	9299 209942	ANDREY NAZAROV	{"email": "andrey.nazarov111969@postgrespro.ru", "phone": "+70728584614"}
0005432948203	0557BC	3613 840448	SVETLANA FEDOROVA	{"email": "svetlana.fedorova_1967@postgrespro.ru", "phone": "+70049916929"}
0005432948204	BA10C5	3817 526672	MARIYA TIKHONOVA	{"email": "mariya.tikhonova24051964@postgrespro.ru", "phone": "+70317114557"}
0005432948205	BA10C5	7934 079647	LYUBOV SEMENOVA	{"email": "semenova.lyubov.22031969@postgrespro.ru", "phone": "+70714049981"}
0005432948206	E6A8B6	0840 174165	KLAVDIYA KISELEVA	{"email": "klavdiyakiseleva13021975@postgrespro.ru", "phone": "+70794370756"}
0005432948207	E6A8B6	8319 627328	TATYANA GORBUNOVA	{"email": "t_gorbunova_051972@postgrespro.ru", "phone": "+70836801314"}
0005432948208	F3FACE	5728 817138	ANZHELA KUDRYASHOVA	{"phone": "+70738301812"}
0005432948209	F3FACE	4456 840493	MAKSIM DAVYDOV	{"email": "davydov-m_17051970@postgrespro.ru", "phone": "+70802251362"}
0005432948210	A29D57	7326 746935	BORIS VOLKOV	{"email": "volkov-boris_111973@postgrespro.ru", "phone": "+70387539535"}
0005432948211	FD2D5C	5552 366018	YURIY ILIN	{"phone": "+70922955754"}
0005432948212	A5FFC6	7252 907690	DMITRIY KUZNECOV	{"phone": "+70112360905"}
0005432948213	A5FFC6	5210 502572	KSENIYA LOGINOVA	{"phone": "+70880503348"}
0005432948214	21C3CB	9115 354728	LYUBOV ALEKSEEVA	{"phone": "+70792832629"}
0005432948215	21C3CB	9422 556374	SERGEY MOROZOV	{"phone": "+70839700611"}
0005432948216	32BCFB	2378 733956	LYUBOV MARTYNOVA	{"email": "martynovalyubov-24111977@postgrespro.ru", "phone": "+70212468686"}
0005432948217	32BCFB	4499 735619	ANASTASIYA KOROLEVA	{"email": "anastasiya.koroleva.1968@postgrespro.ru", "phone": "+70844533117"}
0005432948218	DB8A09	9886 554085	MARINA MOROZOVA	{"phone": "+70315438503"}
0005432948219	82FC0F	4806 943560	DMITRIY CHERNOV	{"email": "dmitriy_chernov-11031972@postgrespro.ru", "phone": "+70741105190"}
0005432948220	82FC0F	9136 345570	LYUDMILA BELOVA	{"email": "l.belova111968@postgrespro.ru", "phone": "+70217213426"}
0005432948221	EBA749	1089 462437	SVETLANA IVANOVA	{"phone": "+70984491391"}
0005432948222	43E7B3	0196 804463	MARIYA ZAYCEVA	{"phone": "+70718755984"}
0005432948223	306715	0286 807636	NINA KISELEVA	{"email": "kiseleva-n.1977@postgrespro.ru", "phone": "+70211269481"}
0005432948224	306715	4843 411370	DENIS FOMIN	{"phone": "+70228856670"}
0005432948225	AC38BD	9479 952994	INNA POPOVA	{"phone": "+70796417955"}
0005432948226	A2318D	6537 164366	LYUBOV IVANOVA	{"phone": "+70015880253"}
0005432948227	A2318D	4620 730349	ELENA CHERNOVA	{"email": "elenachernova_121971@postgrespro.ru", "phone": "+70241014499"}
0005432948228	B543CD	2097 873948	VIKTOR MOISEEV	{"email": "moiseev.v.01011969@postgrespro.ru", "phone": "+70638243389"}
0005432948229	B543CD	8503 403902	POLINA SMIRNOVA	{"phone": "+70943915848"}
0005432948230	240227	7371 315520	ALEKSANDR STEPANOV	{"phone": "+70795598141"}
0005432948231	C85AF4	6333 065263	ALEKSANDR PETROV	{"phone": "+70120507541"}
0005432948232	C85AF4	4603 275966	SERGEY PAVLOV	{"email": "pavlov_s-011969@postgrespro.ru", "phone": "+70488450286"}
0005432948233	492E78	1555 830159	NADEZHDA NAUMOVA	{"email": "naumova-nadezhda_1974@postgrespro.ru", "phone": "+70072467613"}
0005432948234	492E78	7280 941172	ALEKSANDR GAVRILOV	{"email": "agavrilov.1977@postgrespro.ru", "phone": "+70965575509"}
0005432948235	9DC7EE	3368 771759	DENIS KULIKOV	{"email": "d.kulikov12051966@postgrespro.ru", "phone": "+70129281942"}
0005432948236	650F26	7550 541486	VLADIMIR MAKSIMOV	{"phone": "+70017079478"}
0005432948237	650F26	3645 164881	NIKOLAY VOROBEV	{"phone": "+70239719741"}
0005432948238	029106	2775 154451	VALERIYA FOMINA	{"phone": "+70267884737"}
0005432948239	91850E	5107 668504	ANATOLIY EGOROV	{"email": "egorov_a031972@postgrespro.ru", "phone": "+70914057068"}
0005432948240	E81D9A	9053 528493	MARK BONDARENKO	{"email": "bondarenko-m-061967@postgrespro.ru", "phone": "+70252886094"}
0005432948296	F31577	4262 137204	SOFYA ROMANOVA	{"phone": "+70261608162"}
0005432948241	E81D9A	4912 001534	VLADIMIR ZAYCEV	{"email": "zaycev-v-21091969@postgrespro.ru", "phone": "+70740426503"}
0005432948242	F5F133	8946 385209	YULIYA SOKOLOVA	{"email": "y_sokolova_1965@postgrespro.ru", "phone": "+70476227140"}
0005432948243	CF08C8	8502 557135	OLEG PAVLOV	{"email": "o-pavlov031984@postgrespro.ru", "phone": "+70060711719"}
0005432948244	CF08C8	1643 557593	EVGENIY KOZLOV	{"email": "e.kozlov_111973@postgrespro.ru", "phone": "+70404276238"}
0005432948245	F0FAC3	7037 718348	ANATOLIY SHEVCHENKO	{"phone": "+70642548596"}
0005432948246	A82B87	5269 554643	SVETLANA KARPOVA	{"email": "svetlana_karpova-101965@postgrespro.ru", "phone": "+70776381158"}
0005432948247	A82B87	9801 043941	ELENA PETROVA	{"email": "petrova.e_051975@postgrespro.ru", "phone": "+70465153631"}
0005432948248	BDA46F	2671 715041	ALEKSANDR VOLKOV	{"phone": "+70544537073"}
0005432948249	CAC5C7	5960 480635	VALENTINA NIKITINA	{"phone": "+70589722735"}
0005432948250	233B9B	4181 583201	ZULFIYA SOROKINA	{"phone": "+70172062843"}
0005432948251	5A35F1	6628 709720	VIKTOR KISELEV	{"email": "v_kiselev1981@postgrespro.ru", "phone": "+70440625925"}
0005432948252	5A35F1	1756 584312	VALERIY VOLKOV	{"email": "volkov-valeriy_09021972@postgrespro.ru", "phone": "+70094765853"}
0005432948253	2B338F	3751 497259	VITALIY KULIKOV	{"email": "vitaliy_kulikov.1969@postgrespro.ru", "phone": "+70836757349"}
0005432948254	60AF59	8550 697530	NIKOLAY DAVYDOV	{"phone": "+70527634234"}
0005432948255	60AF59	4359 075278	VERONIKA MIKHAYLOVA	{"email": "veronika-mikhaylova091976@postgrespro.ru", "phone": "+70455802974"}
0005432948256	0992C2	5340 706762	RAISA YAKOVLEVA	{"email": "r.yakovleva-27041963@postgrespro.ru", "phone": "+70892058298"}
0005432948257	1DC2C2	6144 601638	KIRA BELOVA	{"phone": "+70784648345"}
0005432948258	1DC2C2	1633 134506	ELENA IVANOVA	{"email": "ivanova_elena.06111964@postgrespro.ru", "phone": "+70612578690"}
0005432948259	3E125B	9447 687114	DANIYA PAVLOVA	{"phone": "+70474061165"}
0005432948260	3E125B	1677 450380	BORIS ALEKSANDROV	{"phone": "+70116225199"}
0005432948261	B6256C	8671 833309	VYACHESLAV SAVELEV	{"email": "vsavelev_19091977@postgrespro.ru", "phone": "+70966656018"}
0005432948262	FAB25F	4384 686451	MARIYA KUZNECOVA	{"email": "kuznecova-m-22061963@postgrespro.ru", "phone": "+70780633984"}
0005432948263	3CF522	7784 379998	ALENA POTAPOVA	{"email": "alena_potapova28091973@postgrespro.ru", "phone": "+70511182591"}
0005432948264	15FC89	7406 302756	VLADISLAV SMIRNOV	{"email": "v_smirnov_081973@postgrespro.ru", "phone": "+70869616939"}
0005432948265	15FC89	2921 209125	LEYLA BOGDANOVA	{"email": "bogdanova-leyla-08021974@postgrespro.ru", "phone": "+70435248584"}
0005432948266	ADDA18	0817 871653	ALEKSANDRA POLYAKOVA	{"email": "polyakova-aleksandra_1968@postgrespro.ru", "phone": "+70131235875"}
0005432948267	ADDA18	4125 951591	RIMMA MAKAROVA	{"phone": "+70654945097"}
0005432948268	4B30CD	2619 406235	DANIL KULIKOV	{"email": "danil-kulikov.27011982@postgrespro.ru", "phone": "+70954086814"}
0005432948269	975AB0	2471 129388	NINA KISELEVA	{"email": "kiseleva_n-19011969@postgrespro.ru", "phone": "+70642084991"}
0005432948270	67C3A1	3239 514663	YAROSLAV POPOV	{"email": "y-popov-23081971@postgrespro.ru", "phone": "+70250195724"}
0005432948271	73CAA8	6724 173177	EVGENIY BELOV	{"phone": "+70921987712"}
0005432948272	294E99	7202 793104	SVETLANA PAVLOVA	{"phone": "+70851821045"}
0005432948273	2DA201	4571 657572	TATYANA MELNIKOVA	{"phone": "+70699513539"}
0005432948274	973673	7831 872739	VALERIY ROMANOV	{"email": "valeriy_romanov_18041971@postgrespro.ru", "phone": "+70202982264"}
0005432948275	973673	9245 229146	MAKSIM PETROV	{"email": "petrov_m_05021976@postgrespro.ru", "phone": "+70969905306"}
0005432948276	8C6817	4304 978273	VALERIY VLASOV	{"phone": "+70195728083"}
0005432948277	239AE6	4035 503472	IRINA GAVRILOVA	{"email": "gavrilova_irina_021978@postgrespro.ru", "phone": "+70793161661"}
0005432948278	239AE6	3939 808723	VIKTOR FROLOV	{"phone": "+70191491764"}
0005432948279	6C88E6	0717 803121	TATYANA IVANOVA	{"email": "t.ivanova_23031977@postgrespro.ru", "phone": "+70548585324"}
0005432948280	C5A5D7	9740 872454	ROMAN GUSEV	{"phone": "+70258006975"}
0005432948281	C5A5D7	8830 079069	YANINA VASILEVA	{"email": "y-vasileva061971@postgrespro.ru", "phone": "+70985282086"}
0005432948282	8252C5	1948 679099	VALENTINA POLYAKOVA	{"email": "valentinapolyakova_1953@postgrespro.ru", "phone": "+70112664764"}
0005432948283	E5BC99	5892 639892	VENIAMIN SCHERBAKOV	{"phone": "+70750173043"}
0005432948284	E5BC99	0400 887722	KRISTINA GERASIMOVA	{"phone": "+70761553219"}
0005432948285	724A83	0106 692943	VLADIMIR SERGEEV	{"email": "sergeev-vladimir_091972@postgrespro.ru", "phone": "+70880181413"}
0005432948286	CE12EA	2116 914310	ALEKSEY EGOROV	{"email": "egorov_a.21021989@postgrespro.ru", "phone": "+70474499160"}
0005432948287	7955DD	6390 223096	ALEKSANDR FEDOROV	{"phone": "+70218511710"}
0005432948288	F0ABD2	1434 409783	OLGA GORBUNOVA	{"phone": "+70444858327"}
0005432948289	FEFBA0	2139 049385	DENIS BORISOV	{"email": "denis-borisov_1973@postgrespro.ru", "phone": "+70470007993"}
0005432948290	B7C49A	9975 343200	ANASTASIYA PAVLOVA	{"phone": "+70938934678"}
0005432948291	B7C49A	9596 550503	GULNARA SMIRNOVA	{"email": "smirnova.gulnara_1975@postgrespro.ru", "phone": "+70500425146"}
0005432948292	9FFC31	5873 015201	MARK MIKHAYLOV	{"phone": "+70679200595"}
0005432948293	E0C3B7	7637 901902	DMITRIY KONOVALOV	{"email": "konovalovd.031964@postgrespro.ru", "phone": "+70853522591"}
0005432948294	E0C3B7	7753 856228	VADIM SOLOVEV	{"email": "v_solovev_25021980@postgrespro.ru", "phone": "+70117488179"}
0005432948295	3D71A5	4336 810516	EVGENIY ALEKSANDROV	{"phone": "+70044063114"}
0005432948297	F31577	6393 510374	OKSANA POTAPOVA	{"phone": "+70816064225"}
0005432948298	A479A3	1928 548939	TATYANA KOZLOVA	{"phone": "+70110135620"}
0005432948299	900766	5454 066922	VLADIMIR TARASOV	{"email": "tarasovv_061969@postgrespro.ru", "phone": "+70640362634"}
0005432948300	1CCE82	4405 973194	KSENIYA BARANOVA	{"phone": "+70933614435"}
0005432948301	00438B	9319 114780	ANASTASIYA FEDOROVA	{"email": "fedorovaa10061979@postgrespro.ru", "phone": "+70169209853"}
0005432948302	D6EA3D	2641 509620	MARINA CHERNOVA	{"phone": "+70128676300"}
0005432948303	D6EA3D	5106 077870	ELENA GORBUNOVA	{"phone": "+70731326144"}
0005432948304	0D9B74	1140 890147	DIANA KOROLEVA	{"email": "diana.koroleva_19061971@postgrespro.ru", "phone": "+70163964884"}
0005432948305	0E19E7	3793 440040	VLADIMIR KUZNECOV	{"phone": "+70032594391"}
0005432948306	D4599F	4977 323653	LIDIYA SCHERBAKOVA	{"email": "scherbakova-l.23081972@postgrespro.ru", "phone": "+70854602146"}
0005432948307	A8E9DA	6190 271790	ALENA LAZAREVA	{"phone": "+70286818402"}
0005432948308	0370A4	9201 198277	ALEKSANDR NIKOLAEV	{"email": "nikolaev_aleksandr071967@postgrespro.ru", "phone": "+70907303816"}
0005432948309	0370A4	3263 603469	OKSANA NESTEROVA	{"phone": "+70404044851"}
0005432948310	2270BB	9304 319012	SVETLANA KOMAROVA	{"phone": "+70124311621"}
0005432948311	2270BB	5989 999101	VLADIMIR ANDREEV	{"phone": "+70013045975"}
0005432948312	AD4ADC	5083 034221	OKSANA ANTONOVA	{"phone": "+70819306836"}
0005432948313	62BFD5	6525 411871	VLADISLAV FILIPPOV	{"email": "vladislav-filippov-061971@postgrespro.ru", "phone": "+70930997606"}
0005432948314	7872FC	1083 365329	MARIYA ORLOVA	{"phone": "+70430809864"}
0005432948315	7872FC	5864 128532	ALEKSANDR ANTONOV	{"email": "antonova.17091965@postgrespro.ru", "phone": "+70794557483"}
0005432948316	88E021	2452 113441	DMITRIY KOROLEV	{"email": "korolevd-21021987@postgrespro.ru", "phone": "+70910090686"}
0005432948317	CAC5B2	1974 175193	OLGA MOROZOVA	{"email": "morozovaolga-051981@postgrespro.ru", "phone": "+70586372857"}
0005432948318	E08115	2023 025391	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr.1990@postgrespro.ru", "phone": "+70788278946"}
0005432948319	579471	3383 968751	VLADIMIR KOROLEV	{"email": "korolevv_20011973@postgrespro.ru", "phone": "+70209495715"}
0005432948320	579471	3806 541773	ALEKSEY KAZAKOV	{"phone": "+70609247051"}
0005432948321	8BFF65	0084 468988	ZINAIDA KRASNOVA	{"email": "zinaida_krasnova.031974@postgrespro.ru", "phone": "+70901760508"}
0005432948322	8BFF65	6080 591771	AMIR PETROV	{"email": "amirpetrov10031956@postgrespro.ru", "phone": "+70237926908"}
0005432948323	5083A2	8020 190214	ANASTASIYA ABRAMOVA	{"phone": "+70264085766"}
0005432948324	5083A2	8431 461116	OLESYA DAVYDOVA	{"email": "davydova-olesya-1965@postgrespro.ru", "phone": "+70792709814"}
0005432948325	BF9F4A	5489 268172	ANASTASIYA POLYAKOVA	{"email": "a_polyakova1973@postgrespro.ru", "phone": "+70183779499"}
0005432948326	CAD5F5	5435 118203	SERGEY ABRAMOV	{"email": "sergey-abramov.1974@postgrespro.ru", "phone": "+70276566049"}
0005432948327	749876	8169 963335	VLADISLAV NOVIKOV	{"phone": "+70187217776"}
0005432948328	749876	7736 718315	ALEVTINA POPOVA	{"phone": "+70448559085"}
0005432948329	CCF74E	0150 280101	LYUDMILA AKIMOVA	{"phone": "+70093633682"}
0005432948330	A322A3	2282 200387	GENNADIY SOROKIN	{"email": "sorokin_gennadiy-111968@postgrespro.ru", "phone": "+70384030516"}
0005432948331	939694	5457 851005	VIKTORIYA MEDVEDEVA	{"email": "v.medvedeva.051964@postgrespro.ru", "phone": "+70606371964"}
0005432948332	713676	6886 295596	SERGEY GORBUNOV	{"phone": "+70062348015"}
0005432948333	5AE22E	8129 068686	ANDREY GAVRILOV	{"email": "a_gavrilov.26011971@postgrespro.ru", "phone": "+70590046358"}
0005432948334	53DACD	0098 256959	MARIYA KUZNECOVA	{"phone": "+70695992306"}
0005432948335	3680C1	7475 103285	ALEKSANDR FEDOROV	{"email": "fedorova-01121981@postgrespro.ru", "phone": "+70120392128"}
0005432948336	26E1A0	2920 773876	ALEKSANDR MOROZOV	{"phone": "+70834305883"}
0005432948337	53B3D9	1478 102614	SVETLANA ERMAKOVA	{"email": "ermakova-s1970@postgrespro.ru", "phone": "+70063278415"}
0005432948338	B07536	1239 540405	NATALYA KOLESNIKOVA	{"email": "n_kolesnikova_13091963@postgrespro.ru", "phone": "+70833297612"}
0005432948339	305013	1005 240606	NATALYA VOLKOVA	{"phone": "+70098618521"}
0005432948340	305013	9069 327817	RUSHANIYA FILATOVA	{"phone": "+70161616544"}
0005432948341	305013	0529 752244	LYUBOV ABRAMOVA	{"email": "abramova_l-1970@postgrespro.ru", "phone": "+70680890962"}
0005432948342	4E8822	3617 171696	ALEKSANDR KAZAKOV	{"phone": "+70044235904"}
0005432948343	21B5B8	7136 375199	VIKTOR KULIKOV	{"phone": "+70360489228"}
0005432948344	21B5B8	3398 905478	BORIS PAVLOV	{"phone": "+70659516745"}
0005432948345	D5188D	7968 059793	NATALYA KONOVALOVA	{"email": "konovalova.natalya-1972@postgrespro.ru", "phone": "+70698140171"}
0005432948346	D5188D	1099 065800	ALLA YUDINA	{"email": "alla_yudina1971@postgrespro.ru", "phone": "+70561406396"}
0005432948347	0104B1	8106 192913	RAISA IVANOVA	{"email": "ivanova.r_20041987@postgrespro.ru", "phone": "+70398982086"}
0005432948348	022106	4165 715236	MARIYA KOROLEVA	{"email": "korolevam.16031974@postgrespro.ru", "phone": "+70477116690"}
0005432948349	9505FF	3815 821702	VADIM FOMIN	{"email": "v-fomin1960@postgrespro.ru", "phone": "+70869386698"}
0005432948350	9505FF	3593 347159	KONSTANTIN STEPANOV	{"phone": "+70715587590"}
0005432948351	314BB9	5079 450061	VIOLETTA KONOVALOVA	{"email": "konovalovavioletta.27021979@postgrespro.ru", "phone": "+70269979892"}
0005432948352	0CA5D5	7832 031170	DANIL FEDOROV	{"email": "d.fedorov.101973@postgrespro.ru", "phone": "+70038409680"}
0005432948353	D72339	0842 225373	SVETLANA FADEEVA	{"email": "fadeevas.1971@postgrespro.ru", "phone": "+70719713837"}
0005432948354	34C32A	5660 027828	NIKOLAY VOLKOV	{"email": "nikolay.volkov_091982@postgrespro.ru", "phone": "+70247126138"}
0005432948355	9D11F8	0136 466080	ELENA LOGINOVA	{"email": "loginova.e-041979@postgrespro.ru", "phone": "+70386292090"}
0005432948356	9D11F8	1263 008077	ILGIZ ANTONOV	{"email": "antonov_ilgiz22021969@postgrespro.ru", "phone": "+70442560283"}
0005432948357	9D11F8	4711 036760	VASILIY VASILEV	{"phone": "+70026581400"}
0005432948358	A0A5FC	8934 294613	SERGEY KOROLEV	{"email": "sergey_korolev091964@postgrespro.ru", "phone": "+70572326700"}
0005432948359	A0A5FC	5896 931397	ANNA SERGEEVA	{"email": "asergeeva_051981@postgrespro.ru", "phone": "+70955037717"}
0005432948360	7EF552	3133 516632	YANA EFIMOVA	{"email": "efimova-yana-24101974@postgrespro.ru", "phone": "+70626763295"}
0005432948361	AA9831	8683 810457	VLADIMIR MIRONOV	{"phone": "+70227049652"}
0005432948362	AB2D0C	3730 045246	DANILA SHEVCHENKO	{"email": "d.shevchenko-081982@postgrespro.ru", "phone": "+70586491781"}
0005432948363	2B532C	2238 827793	ZOYA VOROBEVA	{"phone": "+70265551011"}
0005432948364	34FCAF	1010 241686	NINA PAVLOVA	{"email": "npavlova_29111966@postgrespro.ru", "phone": "+70651053860"}
0005432948365	34FCAF	1641 731416	FARID VASILEV	{"email": "fvasilev-1976@postgrespro.ru", "phone": "+70724085379"}
0005432948366	500EBC	9210 834499	ANATOLIY PAVLOV	{"phone": "+70730411800"}
0005432948367	DEEB9F	7714 513190	TATYANA BORISOVA	{"phone": "+70975436484"}
0005432948368	DEEB9F	9649 543264	VLADIMIR IVANOV	{"email": "vladimir-ivanov-1977@postgrespro.ru", "phone": "+70473217068"}
0005432948369	68CE70	2552 012062	GALINA GERASIMOVA	{"email": "galina-gerasimova-1976@postgrespro.ru", "phone": "+70317402363"}
0005432948370	BB8B0F	3416 583594	NADEZHDA SEMENOVA	{"phone": "+70493969148"}
0005432948371	4E8305	4884 483649	ANDREY MAKSIMOV	{"email": "maksimovandrey.1973@postgrespro.ru", "phone": "+70259209833"}
0005432948372	E6046B	5207 156809	ARTEM GERASIMOV	{"email": "gerasimov.a_051966@postgrespro.ru", "phone": "+70987047519"}
0005432948373	4009B2	4127 055753	LYUDMILA MIRONOVA	{"email": "mironova_l_1969@postgrespro.ru", "phone": "+70568244329"}
0005432948374	CB3AE9	7719 298050	ANTONINA ILINA	{"email": "ilinaantonina.031978@postgrespro.ru", "phone": "+70643542019"}
0005432948375	849D28	2260 264449	RAZIYA ALEKSANDROVA	{"phone": "+70413151093"}
0005432948376	B8387E	8187 332267	VALENTINA MAKAROVA	{"email": "valentina-makarova_30041971@postgrespro.ru", "phone": "+70832736966"}
0005432948377	ED9104	6761 970158	OLEG ZAKHAROV	{"phone": "+70605247821"}
0005432948378	DA7FD8	8079 600340	ANTON BORISOV	{"phone": "+70266489660"}
0005432948379	D74E31	7539 020208	VIKTOR SEMENOV	{"email": "semenov_viktor101978@postgrespro.ru", "phone": "+70177849563"}
0005432948380	CDF525	8662 965530	YURIY ABRAMOV	{"phone": "+70552722176"}
0005432948381	C2809D	8659 597581	VASILIY ZAKHAROV	{"email": "zakharov-vasiliy-091966@postgrespro.ru", "phone": "+70840936587"}
0005432948382	9517A0	8552 730877	SOFYA GUSEVA	{"email": "gusevasofya.101972@postgrespro.ru", "phone": "+70469963354"}
0005432948383	6C6E11	9335 679329	ALEKSANDR VASILEV	{"phone": "+70818347275"}
0005432948384	249025	1303 904893	OLGA SIDOROVA	{"phone": "+70432085574"}
0005432948385	249025	6978 364014	YULIYA ANISIMOVA	{"email": "y_anisimova.1982@postgrespro.ru", "phone": "+70845040849"}
0005432948386	17B315	4643 913751	TATYANA OVCHINNIKOVA	{"phone": "+70782781193"}
0005432948387	17B315	0422 728249	IRINA STEPANOVA	{"email": "irina.stepanova_1981@postgrespro.ru", "phone": "+70629441569"}
0005432948388	EDB58E	2771 080540	NIKITA ILIN	{"phone": "+70005624848"}
0005432948389	5C8177	7030 875074	SVETLANA MELNIKOVA	{"email": "melnikova.svetlana-051981@postgrespro.ru", "phone": "+70610493500"}
0005432948390	5C8177	4196 293853	ANDREY RODIONOV	{"phone": "+70682738141"}
0005432948391	2B8C77	9247 658060	SANIYA KONOVALOVA	{"phone": "+70395827138"}
0005432948392	8E930A	6530 672092	EVGENIYA TIMOFEEVA	{"phone": "+70025551258"}
0005432948393	60D85C	1950 818320	TATYANA MAKSIMOVA	{"phone": "+70514485189"}
0005432948394	60D85C	6063 818397	VLADIMIR ZHURAVLEV	{"email": "vladimir_zhuravlev.031969@postgrespro.ru", "phone": "+70540860228"}
0005432948395	60D85C	2621 272102	GENNADIY VOROBEV	{"email": "g_vorobev011976@postgrespro.ru", "phone": "+70049174040"}
0005432948396	980E34	0158 536796	ALEKSEY KUZNECOV	{"phone": "+70932533948"}
0005432948397	ED4DDC	9915 168558	ELENA NIKITINA	{"phone": "+70669942300"}
0005432948398	FAB795	2787 354335	EKATERINA MIRONOVA	{"email": "ekaterina_mironova.25081967@postgrespro.ru", "phone": "+70021975604"}
0005432948399	DC8DD4	4786 170284	ANTONINA SOKOLOVA	{"phone": "+70492560150"}
0005432948400	9712FB	8811 790241	SVETLANA GUSEVA	{"email": "guseva-s-1960@postgrespro.ru", "phone": "+70308248439"}
0005432948401	1AF1E9	8059 105208	GALINA AFANASEVA	{"phone": "+70938843276"}
0005432948402	1AF1E9	5386 983061	ALEKSANDR BORISOV	{"phone": "+70197937772"}
0005432948403	97C986	6621 486918	VLADIMIR NAUMOV	{"phone": "+70211978484"}
0005432948404	97C986	4236 215474	SERGEY KULIKOV	{"phone": "+70416128378"}
0005432948405	674B24	2815 293210	MAKSIM MAKSIMOV	{"phone": "+70658868547"}
0005432948406	A8DC9E	8359 251611	MARINA SAVELEVA	{"phone": "+70490048221"}
0005432948407	A8DC9E	8920 042591	NIKOLAY SMIRNOV	{"email": "smirnov_n111959@postgrespro.ru", "phone": "+70150718322"}
0005432948408	2116DE	1672 551033	DENIS FILIPPOV	{"phone": "+70292586688"}
0005432948409	2116DE	9713 254460	ANTON PAVLOV	{"phone": "+70188436664"}
0005432948410	A8AAE1	4289 772026	IGOR FROLOV	{"phone": "+70513074803"}
0005432948411	823CCF	7699 876199	PAVEL GRIGOREV	{"email": "pavel-grigorev-111970@postgrespro.ru", "phone": "+70705616332"}
0005432948412	823CCF	4771 825363	TAMARA KOROLEVA	{"phone": "+70217589930"}
0005432948413	E173F9	5410 381761	MAYYA ALEKSANDROVA	{"phone": "+70148364792"}
0005432948414	D9B937	3113 597177	EKATERINA ZOTOVA	{"email": "e.zotova.031962@postgrespro.ru", "phone": "+70148380743"}
0005432948415	1E7454	0022 288869	OLEG MELNIKOV	{"email": "melnikovo.091977@postgrespro.ru", "phone": "+70177248064"}
0005432948416	CF8076	2303 384362	ANDREY DMITRIEV	{"email": "admitriev.1960@postgrespro.ru", "phone": "+70077007147"}
0005432948417	29717F	2322 642727	ELENA TARASOVA	{"email": "e_tarasova-15121975@postgrespro.ru", "phone": "+70640914053"}
0005432948418	8CC681	6776 978099	ALEKSANDR VOROBEV	{"email": "avorobev-101960@postgrespro.ru", "phone": "+70052743747"}
0005432948419	8CC681	5049 146698	MIKHAIL SIDOROV	{"email": "m-sidorov1973@postgrespro.ru", "phone": "+70248364726"}
0005432948420	D3A154	3275 408307	LYUDMILA RYABOVA	{"phone": "+70736173110"}
0005432948421	DE3502	0742 934846	ALINA KOZLOVA	{"phone": "+70334973896"}
0005432948422	4E480B	1798 726138	STANISLAV ILIN	{"phone": "+70441807882"}
0005432948423	78B713	2851 383036	OLESYA VASILEVA	{"email": "olesya.vasileva1967@postgrespro.ru", "phone": "+70784392404"}
0005432948424	210CB2	8480 532572	SVETLANA SMIRNOVA	{"phone": "+70214987864"}
0005432948425	47F471	1807 392606	TAMARA MALYSHEVA	{"email": "tmalysheva-101962@postgrespro.ru", "phone": "+70514484559"}
0005432948426	47F471	4667 971638	EKATERINA ANDREEVA	{"email": "e_andreeva27111976@postgrespro.ru", "phone": "+70225199641"}
0005432948427	C21CAA	2540 535803	ALEKSANDR MAKAROV	{"phone": "+70291089810"}
0005432948428	C21CAA	0216 234958	ELENA BELOVA	{"email": "belova_elena1962@postgrespro.ru", "phone": "+70479661767"}
0005432948429	C21CAA	8575 997867	SERGEY SIDOROV	{"phone": "+70146853682"}
0005432948430	1E7C99	9883 925625	ALEKSANDR ZAKHAROV	{"email": "a_zakharov25111980@postgrespro.ru", "phone": "+70459047906"}
0005432948431	1E7C99	8978 579926	LILIYA KOROLEVA	{"email": "koroleva_liliya.091976@postgrespro.ru", "phone": "+70000987963"}
0005432948432	2E3289	8642 843688	TATYANA KUZNECOVA	{"phone": "+70853981197"}
0005432948433	E3FB74	0067 703074	MIKHAIL POPOV	{"email": "popov-mikhail_111975@postgrespro.ru", "phone": "+70364154454"}
0005432948434	CDC2C4	9301 762356	ELIZAVETA KUZNECOVA	{"email": "e-kuznecova.10091969@postgrespro.ru", "phone": "+70743947293"}
0005432948435	97FE8B	2964 755294	VLADIMIR PETROV	{"phone": "+70741533270"}
0005432948436	BE3B0D	0667 871351	YURIY TARASOV	{"email": "tarasovy011983@postgrespro.ru", "phone": "+70850289149"}
0005432948437	3E00E8	5277 893674	MIKHAIL ANDREEV	{"email": "m.andreev-1967@postgrespro.ru", "phone": "+70012843710"}
0005432948438	D30F84	3797 441863	VIKTOR MIRONOV	{"email": "mironovviktor1964@postgrespro.ru", "phone": "+70837202639"}
0005432948439	D30F84	6406 578283	IRINA SMIRNOVA	{"phone": "+70541915409"}
0005432948440	D30F84	5811 472327	OLGA MEDVEDEVA	{"phone": "+70513455673"}
0005432948441	8C0528	8008 368032	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr30051966@postgrespro.ru", "phone": "+70561514624"}
0005432948442	9530EF	6073 397789	VLADIMIR NIKOLAEV	{"phone": "+70112150290"}
0005432948443	45E30C	7109 176000	LIDIYA PETROVA	{"email": "lidiya.petrova08041973@postgrespro.ru", "phone": "+70804580242"}
0005432948444	7F1DC7	1573 583613	DENIS KUZNECOV	{"email": "kuznecov-d-061965@postgrespro.ru", "phone": "+70762279821"}
0005432948445	7F1DC7	6974 564370	NAIL PETROV	{"email": "nailpetrov-1978@postgrespro.ru", "phone": "+70282839908"}
0005432948446	01BF36	7371 127073	TAMARA TARASOVA	{"email": "tarasova_tamara071973@postgrespro.ru", "phone": "+70960435969"}
0005432948447	D2C546	9603 002523	IRINA NIKITINA	{"email": "nikitina.irina.1972@postgrespro.ru", "phone": "+70309542738"}
0005432948448	A0698D	8255 594851	SOFYA VOLKOVA	{"phone": "+70850591441"}
0005432948449	15B3AF	4393 082985	ARTUR EGOROV	{"phone": "+70679810420"}
0005432948450	15B3AF	0699 410587	GEORGIY DMITRIEV	{"email": "dmitriev-georgiy_111969@postgrespro.ru", "phone": "+70118485743"}
0005432948451	ACCBA0	5165 249522	SERGEY NAZAROV	{"email": "nazarovsergey121949@postgrespro.ru", "phone": "+70447957196"}
0005432948452	4008BD	2753 613339	IGOR MAKAROV	{"phone": "+70723976479"}
0005432948453	4008BD	1642 386240	MARINA BOGDANOVA	{"email": "bogdanova.marina.031980@postgrespro.ru", "phone": "+70429740064"}
0005432948454	3CCA0F	5153 458443	DMITRIY SEMENOV	{"phone": "+70575435317"}
0005432948455	5BBC03	8014 887390	IRINA SEMENOVA	{"phone": "+70824177327"}
0005432948456	FF21B2	8750 619915	EVGENIY NIKOLAEV	{"phone": "+70531173738"}
0005432948457	2B786E	4294 195997	VASILIY IVANOV	{"phone": "+70327863960"}
0005432948458	2233F1	1770 996036	IVAN GORBUNOV	{"email": "gorbunov-ivan.1962@postgrespro.ru", "phone": "+70232194716"}
0005432948459	09FE16	7406 325722	TATYANA SAVELEVA	{"email": "savelevatatyana_071978@postgrespro.ru", "phone": "+70544483783"}
0005432948460	D17B8D	3957 778008	EKATERINA NESTEROVA	{"phone": "+70607341350"}
0005432948461	20E659	1890 078451	ELENA FILIPPOVA	{"email": "filippovaelena.101976@postgrespro.ru", "phone": "+70709840773"}
0005432948462	5E1623	8881 757014	DMITRIY ZHURAVLEV	{"phone": "+70442775292"}
0005432948463	C6E101	9579 866910	OKSANA YUDINA	{"phone": "+70406927070"}
0005432948464	C6E101	8696 051512	ELENA SOROKINA	{"email": "sorokina.e.24031969@postgrespro.ru", "phone": "+70102534719"}
0005432948465	27E593	4011 347347	ALIK KUZNECOV	{"email": "alik_kuznecov061982@postgrespro.ru", "phone": "+70215134686"}
0005432948466	27E593	4744 137762	IGOR AFANASEV	{"email": "iafanasev.1971@postgrespro.ru", "phone": "+70264266925"}
0005432948467	BA1D3B	5416 203433	FEDOR FEDOTOV	{"email": "fedotov.f.111977@postgrespro.ru", "phone": "+70802898429"}
0005432948468	BA1D3B	3281 098942	SVETLANA PETROVA	{"phone": "+70629534261"}
0005432948469	4D370E	7357 528718	VALENTINA KUZNECOVA	{"phone": "+70237603324"}
0005432948470	70D16C	5655 904609	ANDREY NOVIKOV	{"phone": "+70326461932"}
0005432948471	8DBF21	3829 875650	NATALYA ORLOVA	{"phone": "+70946993997"}
0005432948472	1682F5	8036 205277	YULIYA ISAEVA	{"email": "yuliya.isaeva.1979@postgrespro.ru", "phone": "+70901242879"}
0005432948474	332466	0681 097403	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov.01041969@postgrespro.ru", "phone": "+70820501210"}
0005432948475	332466	3748 919675	LYUDMILA EGOROVA	{"email": "lyudmila_egorova25021968@postgrespro.ru", "phone": "+70945822513"}
0005432948476	FA37A9	3810 437940	OLGA MARTYNOVA	{"phone": "+70537862267"}
0005432948477	FA37A9	1913 098139	EVGENIY MOROZOV	{"phone": "+70987554422"}
0005432948478	E701C4	9336 172779	VLADIMIR MEDVEDEV	{"phone": "+70054146444"}
0005432948479	E2BB6C	3794 137508	LYUDMILA MOROZOVA	{"email": "morozova.l-091970@postgrespro.ru", "phone": "+70824975846"}
0005432948480	684CF8	1669 059411	ANNA MAKAROVA	{"phone": "+70444975531"}
0005432948481	C077A1	6458 955089	DENIS GORBUNOV	{"email": "gorbunovd-1980@postgrespro.ru", "phone": "+70560179113"}
0005432948482	21CC93	3703 850048	SERGEY DAVYDOV	{"phone": "+70793358056"}
0005432948483	EE241A	4692 368813	NADEZHDA KOROLEVA	{"email": "koroleva_n_18031970@postgrespro.ru", "phone": "+70657465912"}
0005432948484	EE241A	1539 311257	DARYA KOROLEVA	{"phone": "+70976246546"}
0005432948485	404440	1290 569097	ALEKSEY BORISOV	{"email": "aleksey-borisov.081970@postgrespro.ru", "phone": "+70204321452"}
0005432948486	347EA5	8755 012692	SVETLANA NOVIKOVA	{"phone": "+70658101062"}
0005432948487	347EA5	4729 815619	EKATERINA BOGDANOVA	{"phone": "+70277520513"}
0005432948488	202D2D	0869 746169	DENIS ROMANOV	{"email": "d-romanov.051954@postgrespro.ru", "phone": "+70291444710"}
0005432948489	EC0AED	3734 158861	TATYANA MOISEEVA	{"phone": "+70064986971"}
0005432948490	EC0AED	2647 053339	ELDAR GAVRILOV	{"phone": "+70181498433"}
0005432948491	7CBE34	8783 479651	ALEKSANDR RODIONOV	{"email": "rodionov_a-1974@postgrespro.ru", "phone": "+70984133342"}
0005432948492	7CBE34	2753 839572	VALENTINA ZAKHAROVA	{"phone": "+70092702047"}
0005432948493	E59FC5	4298 404860	NATALYA OVCHINNIKOVA	{"email": "ovchinnikovanatalya20071988@postgrespro.ru", "phone": "+70846385665"}
0005432948494	57A876	0570 170429	TAISIYA KONOVALOVA	{"phone": "+70074389601"}
0005432948495	8A940A	4875 203253	VALENTINA BORISOVA	{"email": "borisova_v_1983@postgrespro.ru", "phone": "+70121596662"}
0005432948496	D7443E	2088 155521	IGOR VLASOV	{"phone": "+70716962164"}
0005432948497	D7443E	4782 525745	NIKOLAY NIKOLAEV	{"phone": "+70827468737"}
0005432948498	9B31D3	8407 872287	IRINA LUKYANOVA	{"email": "lukyanovairina_051979@postgrespro.ru", "phone": "+70700596773"}
0005432948499	0AB9EE	3535 866738	ELENA KALININA	{"email": "kalinina.e.1980@postgrespro.ru", "phone": "+70212550263"}
0005432948500	6368B9	1779 792192	VALERIY KRASNOV	{"phone": "+70932130987"}
0005432948501	6368B9	8637 815040	ANATOLIY IVANOV	{"email": "ivanov.anatoliy.09051979@postgrespro.ru", "phone": "+70788460594"}
0005432948502	F8D7D5	2603 686545	MIKHAIL ALEKSANDROV	{"phone": "+70896585880"}
0005432948503	81F42E	8593 904064	ALEKSANDRA IVANOVA	{"phone": "+70081116495"}
0005432948504	81F42E	2694 078924	SERGEY KRASNOV	{"email": "krasnov.s24021975@postgrespro.ru", "phone": "+70636153543"}
0005432948505	2A7F2E	7129 439879	ZOYA PAVLOVA	{"phone": "+70532158661"}
0005432948506	2A7F2E	0787 767055	SVETLANA PAVLOVA	{"phone": "+70203438171"}
0005432948507	07D700	2169 453585	NIKOLAY CHERNOV	{"phone": "+70498187688"}
0005432948508	B53DC9	6122 093683	VLADIMIR DMITRIEV	{"email": "vladimir_dmitriev021978@postgrespro.ru", "phone": "+70383393763"}
0005432948509	36A5B1	2738 340822	TATYANA NOVIKOVA	{"email": "tnovikova.24121969@postgrespro.ru", "phone": "+70867950580"}
0005432948510	36A5B1	7632 836713	IVAN SMIRNOV	{"phone": "+70050450894"}
0005432948511	ED1BA3	5165 687064	ROBERT GORBUNOV	{"email": "gorbunovrobert111972@postgrespro.ru", "phone": "+70228340398"}
0005432948512	ED1BA3	5523 079648	IRINA ALEKSANDROVA	{"phone": "+70366974895"}
0005432948513	ED1BA3	1022 752896	TATYANA IVANOVA	{"email": "t_ivanova.041978@postgrespro.ru", "phone": "+70225333209"}
0005432948514	A4A4DD	9484 550920	OLGA ILINA	{"email": "ilinaolga.1969@postgrespro.ru", "phone": "+70107612113"}
0005432948515	A7C11A	3780 443893	NIKITA DMITRIEV	{"email": "nikita_dmitriev091971@postgrespro.ru", "phone": "+70055907725"}
0005432948516	600629	8260 809347	ELENA POPOVA	{"email": "popova-elena-1976@postgrespro.ru", "phone": "+70681372626"}
0005432948517	3D9607	9521 527550	OLGA PETROVA	{"phone": "+70863393302"}
0005432948518	EE8DB8	9902 908894	ANDREY MAKSIMOV	{"email": "andrey-maksimov081967@postgrespro.ru", "phone": "+70774870351"}
0005432948519	9C12C9	5707 865274	LYUBOV ZHURAVLEVA	{"phone": "+70912103438"}
0005432948520	9C12C9	1367 062376	PAVEL STEPANOV	{"email": "stepanov_p-02021975@postgrespro.ru", "phone": "+70070582042"}
0005432948521	AB223E	1733 545028	GALIYA KOZLOVA	{"phone": "+70539567982"}
0005432948522	AB223E	3995 020986	ALEKSANDR ILIN	{"phone": "+70244157017"}
0005432948523	F287DD	0174 505196	ROMAN KOROLEV	{"email": "r.korolev_13031966@postgrespro.ru", "phone": "+70726358100"}
0005432948524	FAB0FF	3465 785293	SERGEY PETROV	{"phone": "+70272430091"}
0005432948525	335D14	1489 096937	ARTUR SCHERBAKOV	{"email": "artur-scherbakov.13071964@postgrespro.ru", "phone": "+70331188352"}
0005432948526	335D14	2073 298812	DINA VASILEVA	{"email": "dina-vasileva02051972@postgrespro.ru", "phone": "+70326986436"}
0005432948527	3DFEC8	3007 597402	GALINA NESTEROVA	{"email": "nesterova.g.09061967@postgrespro.ru", "phone": "+70449690316"}
0005432948528	CD8684	4361 355373	ANNA MOROZOVA	{"email": "annamorozova.12051969@postgrespro.ru", "phone": "+70148577283"}
0005432948529	54622C	5251 418902	EVGENIYA POPOVA	{"phone": "+70354885949"}
0005432948530	8BC220	0607 081732	NIKOLAY ZAYCEV	{"phone": "+70349350140"}
0005432948531	D09782	8907 995191	ELENA SEMENOVA	{"email": "semenova_elena-27121979@postgrespro.ru", "phone": "+70247831752"}
0005432948532	9BB920	9007 989896	LYUDMILA RODIONOVA	{"phone": "+70462002387"}
0005432948533	EA01F4	0442 634999	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-1968@postgrespro.ru", "phone": "+70143572537"}
0005432948534	EA01F4	6370 192272	YULIYA ZAYCEVA	{"phone": "+70562161228"}
0005432948535	3552C5	8502 769099	IRINA IVANOVA	{"email": "ivanova-i081965@postgrespro.ru", "phone": "+70734987994"}
0005432948536	30FFB9	6951 488916	ALEKSANDR RODIONOV	{"phone": "+70464632844"}
0005432948537	050364	5836 686909	ELENA RODIONOVA	{"phone": "+70195246279"}
0005432948538	050364	7833 258732	ANATOLIY SAVELEV	{"phone": "+70911294428"}
0005432948539	845F31	3629 063050	VLADIMIR KRASNOV	{"email": "krasnovvladimir.091966@postgrespro.ru", "phone": "+70148248040"}
0005432948540	845F31	6489 607212	GALINA VASILEVA	{"email": "vasileva_g.04021974@postgrespro.ru", "phone": "+70347452621"}
0005432948541	D92D43	5056 741466	TATYANA NIKITINA	{"phone": "+70370975338"}
0005432948542	D92D43	2142 947763	VITALIY ALEKSEEV	{"email": "alekseev_v_31081967@postgrespro.ru", "phone": "+70514440268"}
0005432948543	FF1161	6213 767259	KRISTINA STEPANOVA	{"phone": "+70082145794"}
0005432948544	FF1161	0839 177408	ELENA PAVLOVA	{"phone": "+70636277339"}
0005432948545	E9DA31	2002 286253	MARIYA OSIPOVA	{"email": "osipova.mariya.23071979@postgrespro.ru", "phone": "+70383929762"}
0005432948546	67B503	5171 898073	VLADIMIR FROLOV	{"email": "vladimir_frolov-02101974@postgrespro.ru", "phone": "+70040909359"}
0005432948547	CE0405	0392 541135	VALENTINA SMIRNOVA	{"phone": "+70499653827"}
0005432948548	CE0405	3863 413608	VLADIMIR MELNIKOV	{"email": "v_melnikov-081970@postgrespro.ru", "phone": "+70639606668"}
0005432948549	42AA82	4935 092909	SERGEY ANDREEV	{"phone": "+70339492610"}
0005432948550	8B4436	7783 618990	VLADISLAV IVANOV	{"phone": "+70158015198"}
0005432948551	4570F6	5704 674392	MIKHAIL TIMOFEEV	{"phone": "+70312640087"}
0005432948552	4570F6	8161 453142	LARISA VASILEVA	{"email": "larisa.vasileva20021977@postgrespro.ru", "phone": "+70955660331"}
0005432948553	48D464	0134 178085	EVGENIY NAUMOV	{"email": "enaumov.1971@postgrespro.ru", "phone": "+70322894407"}
0005432948554	9521A2	4501 320802	ALISA IVANOVA	{"phone": "+70668664061"}
0005432948555	9521A2	4343 757732	NADEZHDA MAKAROVA	{"email": "nadezhdamakarova-20081977@postgrespro.ru", "phone": "+70743273477"}
0005432948556	D364E3	3223 392680	EKATERINA VLASOVA	{"phone": "+70296737296"}
0005432948557	D364E3	4872 073608	VLADIMIR DAVYDOV	{"email": "davydov_v_15031979@postgrespro.ru", "phone": "+70711316368"}
0005432948558	C7495F	4776 593239	YULIYA IVANOVA	{"email": "yuliya-ivanova_21011967@postgrespro.ru", "phone": "+70167062639"}
0005432948559	C7495F	3052 199924	EVGENIYA BOGDANOVA	{"email": "bogdanova-evgeniya121973@postgrespro.ru", "phone": "+70718978774"}
0005432948560	251A31	4870 624699	ALEKSANDR PETROV	{"phone": "+70423827782"}
0005432948561	01EDB7	2741 808135	IRINA BELYAEVA	{"phone": "+70639972584"}
0005432948562	01EDB7	7783 857837	KONSTANTIN IVANOV	{"email": "k_ivanov1969@postgrespro.ru", "phone": "+70489382485"}
0005432948563	9EDD9F	3860 427685	NADEZHDA MAKAROVA	{"phone": "+70197997486"}
0005432948564	9EDD9F	9837 076705	VALENTINA VASILEVA	{"email": "valentinavasileva.101971@postgrespro.ru", "phone": "+70169217984"}
0005432948565	9EDD9F	7172 868476	SERGEY MAKSIMOV	{"phone": "+70979010518"}
0005432948566	1B2EAC	4798 458612	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev.05071982@postgrespro.ru", "phone": "+70584336173"}
0005432948567	4D5E78	1472 760939	IRINA KOZLOVA	{"email": "kozlova_irina_041984@postgrespro.ru", "phone": "+70048301726"}
0005432948568	4D5E78	0863 071428	NIKITA STEPANOV	{"phone": "+70597931700"}
0005432948569	4D5E78	4106 291423	MAKSIM KUZNECOV	{"phone": "+70115989382"}
0005432948570	3E09CB	8405 338954	LYUBOV ANISIMOVA	{"phone": "+70757878649"}
0005432948571	C0EB90	0156 362134	VYACHESLAV AFANASEV	{"email": "afanasev.vyacheslav.091967@postgrespro.ru", "phone": "+70279004757"}
0005432948572	011592	3404 810880	ALEKSANDRA IVANOVA	{"phone": "+70703409213"}
0005432948573	93F3EE	9741 308236	NINA BORISOVA	{"phone": "+70406787561"}
0005432948574	1FFFE6	1101 999578	ANATOLIY VOLKOV	{"email": "volkov.anatoliy1970@postgrespro.ru", "phone": "+70927982316"}
0005432948575	1FFFE6	4069 142844	ANNA KUZNECOVA	{"email": "a_kuznecova041966@postgrespro.ru", "phone": "+70446370602"}
0005432948576	F9050F	3744 032186	DMITRIY MELNIKOV	{"phone": "+70664468512"}
0005432948577	6B3F90	5330 393626	VIKTOR IVANOV	{"email": "ivanovviktor_061968@postgrespro.ru", "phone": "+70448848682"}
0005432948578	6B3F90	5595 073982	DAMIR GERASIMOV	{"email": "gerasimovdamir-25111971@postgrespro.ru", "phone": "+70408808447"}
0005432948579	A60ED8	0777 407186	IVAN SAVELEV	{"email": "isavelev1961@postgrespro.ru", "phone": "+70878564647"}
0005432948580	A60ED8	3917 120887	MARIYA TARASOVA	{"email": "m-tarasova.091969@postgrespro.ru", "phone": "+70560120327"}
0005432948581	ECB99F	7568 876513	IVAN TIKHONOV	{"email": "ivantikhonov-28031976@postgrespro.ru", "phone": "+70624991576"}
0005432948582	ECB99F	1688 565801	VALENTINA YUDINA	{"phone": "+70471568210"}
0005432948583	11A1BD	4626 066125	SERGEY IVANOV	{"email": "ivanov_s1972@postgrespro.ru", "phone": "+70290975845"}
0005432948584	7CD73E	5163 828256	SVETLANA KALININA	{"phone": "+70369641893"}
0005432948585	5DBE13	2646 891940	ALEKSEY MAKAROV	{"phone": "+70950510048"}
0005432948586	217130	9467 554790	SVETLANA SCHERBAKOVA	{"phone": "+70535268164"}
0005432948587	0A155E	1534 545665	BULAT FOMIN	{"phone": "+70023726099"}
0005432948588	0A155E	8942 647444	VLADIMIR VASILEV	{"email": "v_vasilev.23081974@postgrespro.ru", "phone": "+70387209483"}
0005432948589	80365F	4026 236037	YANINA POPOVA	{"phone": "+70235178526"}
0005432948590	967615	9210 612344	VLADIMIR PAVLOV	{"email": "v_pavlov_1968@postgrespro.ru", "phone": "+70106280972"}
0005432948591	967615	6736 296007	EVGENIY KRASNOV	{"email": "krasnove_1982@postgrespro.ru", "phone": "+70155869365"}
0005432948592	1322AD	9651 765908	ANNA FOMINA	{"phone": "+70846427673"}
0005432948593	6B1AAA	6617 434535	EKATERINA MARTYNOVA	{"email": "e.martynova-04111977@postgrespro.ru", "phone": "+70892105722"}
0005432948594	6B1AAA	2010 165979	EVGENIYA STEPANOVA	{"phone": "+70822211525"}
0005432948595	6B1AAA	2418 183635	LYUBOV SAVELEVA	{"email": "lyubov-saveleva1964@postgrespro.ru", "phone": "+70975509771"}
0005432948596	21AB97	7583 859978	VARVARA CHERNOVA	{"phone": "+70192945651"}
0005432948597	922B5E	2396 352939	IVAN PETROV	{"email": "ivan-petrov1973@postgrespro.ru", "phone": "+70009137992"}
0005432948598	3D3A8C	0600 261297	DENIS KUDRYASHOV	{"phone": "+70694248285"}
0005432948599	3D3A8C	0446 448954	EKATERINA IVANOVA	{"phone": "+70547675756"}
0005432948600	A9D0B5	9557 671789	ALEKSANDR KUZNECOV	{"phone": "+70400593364"}
0005432948601	A9D0B5	5561 180629	ALEKSEY GERASIMOV	{"email": "agerasimov.1964@postgrespro.ru", "phone": "+70163551978"}
0005432948602	52660A	4902 140133	LIDIYA BELYAEVA	{"phone": "+70082605347"}
0005432948603	7BBA50	2352 697642	YULIYA ANTONOVA	{"phone": "+70492712800"}
0005432948604	A0D672	0897 016987	IVAN GORBUNOV	{"phone": "+70798110950"}
0005432948605	FBE267	7321 506475	VLADISLAV MELNIKOV	{"email": "melnikov.vladislav.111970@postgrespro.ru", "phone": "+70012525281"}
0005432948606	9D2130	7508 356590	MARINA ANTONOVA	{"phone": "+70749174802"}
0005432948607	9D2130	3296 726180	KLAVDIYA KOLESNIKOVA	{"email": "k.kolesnikova.071968@postgrespro.ru", "phone": "+70792083846"}
0005432948608	B2514E	5844 268883	DMITRIY KOZLOV	{"phone": "+70957055619"}
0005432948609	311606	2532 208270	VIKTOR BELOV	{"email": "belovviktor.1974@postgrespro.ru", "phone": "+70996846018"}
0005432948610	91074C	2002 114510	SERGEY FEDOROV	{"phone": "+70845657465"}
0005432948611	87C7ED	0145 298184	RUSLAN SOKOLOV	{"email": "r_sokolov-041973@postgrespro.ru", "phone": "+70849855277"}
0005432948612	4E8517	1096 324198	VITALIY GAVRILOV	{"email": "gavrilovvitaliy.1973@postgrespro.ru", "phone": "+70701116796"}
0005432948613	539DB0	9648 891409	ALEKSEY BORISOV	{"phone": "+70907096906"}
0005432948614	47E2DE	8702 529095	ANZHELIKA VASILEVA	{"phone": "+70653000781"}
0005432948615	8FEF03	0861 664435	VITALIY SERGEEV	{"email": "sergeev_vitaliy_01081980@postgrespro.ru", "phone": "+70599046897"}
0005432948616	4F6893	4505 495443	SVETLANA SEMENOVA	{"phone": "+70195625385"}
0005432948617	4F6893	2470 686519	GENNADIY BORISOV	{"email": "g-borisov_09061975@postgrespro.ru", "phone": "+70787790602"}
0005432948618	4F6893	5950 077601	ANTON POPOV	{"email": "popova_18121971@postgrespro.ru", "phone": "+70273122056"}
0005432948619	C50C0A	6096 341393	VALERIY ZAKHAROV	{"email": "zakharov.v24091972@postgrespro.ru", "phone": "+70471271275"}
0005432948620	017C74	4282 860551	EKATERINA PETROVA	{"email": "petrova.ekaterina-081977@postgrespro.ru", "phone": "+70856393593"}
0005432948621	017C74	7261 359743	IGOR TARASOV	{"phone": "+70669272072"}
0005432948622	017C74	7152 136654	GALINA ZHURAVLEVA	{"email": "zhuravleva_g_21051978@postgrespro.ru", "phone": "+70239875322"}
0005432948623	1842E1	1630 862696	POLINA SCHERBAKOVA	{"email": "scherbakovapolina_30011976@postgrespro.ru", "phone": "+70326299849"}
0005432948624	252B8F	4988 180136	NATALIYA TARASOVA	{"email": "tarasova.nataliya_1974@postgrespro.ru", "phone": "+70463956251"}
0005432948625	80FBB3	4151 493713	VALENTINA KOZLOVA	{"phone": "+70330881160"}
0005432948626	2452D8	1891 591448	OKSANA GAVRILOVA	{"phone": "+70369821746"}
0005432948627	2452D8	7712 166227	ILYA VOROBEV	{"email": "i_vorobev.1973@postgrespro.ru", "phone": "+70065432683"}
0005432948628	31034A	8325 039268	IVAN EGOROV	{"phone": "+70567936159"}
0005432948629	F82A14	2370 283559	PETR SOLOVEV	{"phone": "+70046911431"}
0005432948630	BA905C	9118 215549	VALERIY KUZNECOV	{"email": "kuznecov-valeriy1975@postgrespro.ru", "phone": "+70696037125"}
0005432948631	110854	3178 821583	ELENA IVANOVA	{"email": "e.ivanova-12031969@postgrespro.ru", "phone": "+70838882375"}
0005432948632	110854	3497 064069	ANASTASIYA SMIRNOVA	{"phone": "+70151111973"}
0005432948633	41B92F	7387 086837	LYUDMILA PAVLOVA	{"email": "lpavlova-081979@postgrespro.ru", "phone": "+70109785818"}
0005432948634	41B92F	3176 471909	IRINA PETROVA	{"email": "petrovai-1970@postgrespro.ru", "phone": "+70728589492"}
0005432948635	C61407	4365 413117	DMITRIY BELOV	{"phone": "+70677280063"}
0005432948636	DF0BE2	1130 332811	ELENA KUZMINA	{"email": "elenakuzmina_30041958@postgrespro.ru", "phone": "+70973764458"}
0005432948637	EC9F8B	6281 672092	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda-031971@postgrespro.ru", "phone": "+70948813576"}
0005432948638	EC9F8B	9145 077877	SERGEY POPOV	{"email": "popovs_031977@postgrespro.ru", "phone": "+70018454830"}
0005432948639	EC9F8B	8168 685759	ELENA KUZNECOVA	{"email": "elenakuznecova_081972@postgrespro.ru", "phone": "+70058712788"}
0005432948640	D08950	1287 166039	IVAN SIDOROV	{"email": "ivan_sidorov.1973@postgrespro.ru", "phone": "+70536609245"}
0005432948641	D08950	6637 143176	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr29061982@postgrespro.ru", "phone": "+70110599077"}
0005432948642	6A7BC3	6544 394649	NIKOLAY IVANOV	{"phone": "+70261913151"}
0005432948643	6A7BC3	9284 396092	EKATERINA NIKITINA	{"email": "e_nikitina-031972@postgrespro.ru", "phone": "+70825958374"}
0005432948644	FA9D34	6478 580944	ARTEM KARPOV	{"email": "karpov.artem-11061980@postgrespro.ru", "phone": "+70830919385"}
0005432948645	E588B4	6941 331549	IVAN ORLOV	{"phone": "+70402521130"}
0005432948646	ABB8B8	7268 341430	NATALYA FROLOVA	{"phone": "+70801352881"}
0005432948647	3AFA03	6045 152896	NADEZHDA SMIRNOVA	{"phone": "+70210886389"}
0005432948648	F412D5	1276 787376	ANDREY PETROV	{"phone": "+70099747278"}
0005432948649	F412D5	9335 955716	ALEKSANDR EGOROV	{"email": "a.egorov_1968@postgrespro.ru", "phone": "+70227423341"}
0005432948650	96C30A	0152 590166	NIKOLAY SOLOVEV	{"phone": "+70467637893"}
0005432948651	96C30A	0414 285382	SERGEY MAKSIMOV	{"phone": "+70350534104"}
0005432948652	7F28C4	0267 483486	TATYANA KULIKOVA	{"phone": "+70342580293"}
0005432948653	E7E8FC	1231 919027	EVGENIY ZAYCEV	{"email": "zayceve30121978@postgrespro.ru", "phone": "+70365512258"}
0005432948654	94040F	3404 064002	VALENTINA KUZNECOVA	{"phone": "+70705241380"}
0005432948655	94040F	9644 286652	VLADIMIR PETROV	{"email": "v_petrov.031981@postgrespro.ru", "phone": "+70682666463"}
0005432948656	F90DA6	7275 980382	ELENA PETROVA	{"email": "petrova_elena-22051967@postgrespro.ru", "phone": "+70876745486"}
0005432948657	DDA216	8049 014964	RAISA BELOVA	{"phone": "+70058811007"}
0005432948658	36AD25	2426 441951	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov1967@postgrespro.ru", "phone": "+70391880743"}
0005432948659	1FBF7F	8273 878525	ALEKSEY FROLOV	{"email": "frolov-a-18061974@postgrespro.ru", "phone": "+70348769902"}
0005432948660	1FBF7F	5362 552520	MARIYA AKIMOVA	{"phone": "+70448304012"}
0005432948661	1FBF7F	8369 368034	ANATOLIY BONDARENKO	{"phone": "+70739623765"}
0005432948662	1A9522	7800 155628	GALINA PETROVA	{"phone": "+70865838564"}
0005432948663	BDA70E	4012 427780	ANDREY VASILEV	{"phone": "+70451090514"}
0005432948664	FDB79F	4073 921037	GENNADIY SOLOVEV	{"phone": "+70610528626"}
0005432948665	06DBAB	1224 030807	EKATERINA IVANOVA	{"email": "ivanova.ekaterina-041982@postgrespro.ru", "phone": "+70992866141"}
0005432948666	EE968A	8208 464670	ANATOLIY SIDOROV	{"phone": "+70805042900"}
0005432948667	55E2CE	1063 948138	VASILIY KUDRYASHOV	{"email": "kudryashovvasiliy-071970@postgrespro.ru", "phone": "+70538701838"}
0005432948668	A9A9EF	8858 284340	VLADIMIR RODIONOV	{"phone": "+70742134599"}
0005432948669	A9A9EF	6407 615765	LARISA SIDOROVA	{"phone": "+70840874829"}
0005432948670	608BA4	0440 265238	VALENTINA ANISIMOVA	{"email": "anisimova-v_061977@postgrespro.ru", "phone": "+70608242536"}
0005432948671	823E8E	3708 320855	PAVEL SHEVCHENKO	{"email": "p_shevchenko.24091960@postgrespro.ru", "phone": "+70764144977"}
0005432948672	11F517	9055 201609	ALINA MIKHAYLOVA	{"email": "mikhaylovaalina.06061963@postgrespro.ru", "phone": "+70181764390"}
0005432948673	11F517	4395 050022	ALEKSANDR FEDOTOV	{"email": "fedotov_a-1971@postgrespro.ru", "phone": "+70676543101"}
0005432948674	11F517	2842 098824	RIM BARANOV	{"email": "baranov.rim-121971@postgrespro.ru", "phone": "+70909059885"}
0005432948675	ACE478	2950 675269	MARINA RODIONOVA	{"email": "marina.rodionova_1970@postgrespro.ru", "phone": "+70707625636"}
0005432948676	091383	3917 422746	LYUBOV DAVYDOVA	{"email": "davydova_lyubov-1969@postgrespro.ru", "phone": "+70132657238"}
0005432948677	7FA323	8452 790726	EKATERINA FADEEVA	{"email": "fadeeva_ekaterina_081976@postgrespro.ru", "phone": "+70491989506"}
0005432948678	7FA323	5855 082056	SVETLANA GAVRILOVA	{"email": "svetlanagavrilova.31031961@postgrespro.ru", "phone": "+70698359300"}
0005432948679	43C4E3	4329 728941	ANASTASIYA KOVALEVA	{"email": "a_kovaleva.101976@postgrespro.ru", "phone": "+70132735266"}
0005432948680	DE9961	5835 404355	TATYANA FEDOROVA	{"email": "fedorova_t-1977@postgrespro.ru", "phone": "+70421931902"}
0005432948681	D28347	7601 166470	NINA KALININA	{"email": "n_kalinina-111975@postgrespro.ru", "phone": "+70408900589"}
0005432948682	6132C7	0342 900227	MARAT FROLOV	{"email": "m.frolov_1971@postgrespro.ru", "phone": "+70796497690"}
0005432948683	3203F2	6009 844489	ELENA KUZMINA	{"phone": "+70082890495"}
0005432948684	F56DC5	1188 290209	GALINA POPOVA	{"phone": "+70680753660"}
0005432948685	12B723	5886 288423	VLADIMIR IVANOV	{"phone": "+70276623874"}
0005432948686	945C2A	2089 153130	VLADIMIR POPOV	{"email": "v.popov_27121979@postgrespro.ru", "phone": "+70558828462"}
0005432948687	2793AD	7515 061785	NATALYA STEPANOVA	{"phone": "+70275620677"}
0005432948688	49A05D	6609 436095	MARINA NOVIKOVA	{"email": "m.novikova-10091978@postgrespro.ru", "phone": "+70590699328"}
0005432948689	49A05D	5191 734584	DENIS SHEVCHENKO	{"phone": "+70609533733"}
0005432948690	964806	4017 681259	TATYANA MALYSHEVA	{"email": "malysheva-t_03101970@postgrespro.ru", "phone": "+70676739317"}
0005432948691	964806	4256 653069	OLGA KOLESNIKOVA	{"phone": "+70513941033"}
0005432948692	659A12	1483 970713	VALENTINA OSIPOVA	{"email": "osipova.valentina1968@postgrespro.ru", "phone": "+70298062445"}
0005432948693	659A12	3602 829448	ROMAN SIDOROV	{"phone": "+70662425348"}
0005432948694	988624	7798 937634	VALENTINA FEDOROVA	{"phone": "+70574886141"}
0005432948695	D204D7	1743 475282	ANASTASIYA MOISEEVA	{"phone": "+70242322467"}
0005432948696	B48E8D	8226 034529	EVGENIYA ZAYCEVA	{"email": "zayceva_e_13091983@postgrespro.ru", "phone": "+70678492131"}
0005432948697	C7B580	7338 294036	LYUBOV ANTONOVA	{"phone": "+70256019985"}
0005432948698	C7B580	5118 986001	MARIYA AFANASEVA	{"email": "afanaseva-mariya.121963@postgrespro.ru", "phone": "+70407307508"}
0005432948699	B98A4C	8889 428911	NATALYA DENISOVA	{"phone": "+70928031856"}
0005432948700	4D72E5	2149 904839	EKATERINA ANISIMOVA	{"phone": "+70897325187"}
0005432948701	4D72E5	1053 882735	ULYANA ORLOVA	{"phone": "+70444130571"}
0005432948702	4D72E5	6858 856445	OLGA MAKAROVA	{"phone": "+70967875869"}
0005432948703	E68577	5755 695779	MARGARITA ZAKHAROVA	{"email": "zakharova-m_1967@postgrespro.ru", "phone": "+70489990077"}
0005432948704	CC9942	9649 240823	ALENA ZOTOVA	{"email": "a_zotova101973@postgrespro.ru", "phone": "+70355800135"}
0005432948705	CC9942	5249 684095	ANDREY ZAKHAROV	{"phone": "+70781699146"}
0005432948706	83855D	9432 483824	MARK MIKHAYLOV	{"email": "mikhaylov.mark_22051965@postgrespro.ru", "phone": "+70901334830"}
0005432948707	83855D	0037 283352	MAKSIM KUZNECOV	{"phone": "+70520318005"}
0005432948708	DC9356	8440 469896	LYUBOV PETROVA	{"email": "petrovalyubov-041972@postgrespro.ru", "phone": "+70985004084"}
0005432948709	721C02	8401 854979	NADEZHDA MIRONOVA	{"email": "mironova.n.31071975@postgrespro.ru", "phone": "+70904359476"}
0005432948710	20E77E	1122 608974	RUSTAM STEPANOV	{"phone": "+70018968994"}
0005432948711	02C01B	7673 481132	LYUDMILA ABRAMOVA	{"phone": "+70986730397"}
0005432948712	67FD20	9956 127158	ZINAIDA LAZAREVA	{"email": "zinaida_lazareva.1962@postgrespro.ru", "phone": "+70294034225"}
0005432948713	67FD20	5517 654951	ALENA TROFIMOVA	{"phone": "+70322176752"}
0005432948714	67FD20	7872 201998	VLADIMIR FROLOV	{"phone": "+70002339872"}
0005432948715	B553D9	0778 642247	ANTON FILIPPOV	{"email": "anton.filippov121966@postgrespro.ru", "phone": "+70982633263"}
0005432948716	B553D9	0463 938228	ARTUR VOROBEV	{"email": "avorobev.13011978@postgrespro.ru", "phone": "+70317578608"}
0005432948717	FB82E6	6516 963951	EKATERINA VOROBEVA	{"email": "ekaterina_vorobeva07041971@postgrespro.ru", "phone": "+70884863308"}
0005432948718	5695DE	4146 249188	ANTON CHERNOV	{"phone": "+70482087769"}
0005432948719	415024	8863 139800	ZHANNA VOROBEVA	{"email": "vorobevaz-23121969@postgrespro.ru", "phone": "+70751405079"}
0005432948720	415024	9763 104832	IGOR PAVLOV	{"phone": "+70382367382"}
0005432948721	B17FB0	0543 391383	SERGEY ZAKHAROV	{"phone": "+70090076689"}
0005432948722	888301	0741 221532	MARINA MEDVEDEVA	{"email": "medvedeva.m.12011977@postgrespro.ru", "phone": "+70236974692"}
0005432948723	A07A4E	8473 644330	MARIYA IVANOVA	{"email": "m.ivanova29101968@postgrespro.ru", "phone": "+70802048320"}
0005432948724	62AB16	5759 358187	VALERIYA KOROLEVA	{"phone": "+70151928758"}
0005432948725	55D5C5	1735 273780	ROMAN STEPANOV	{"phone": "+70053769959"}
0005432948726	55D5C5	0238 128799	NATALYA MELNIKOVA	{"phone": "+70018979710"}
0005432948727	E07E85	4620 225624	EVGENIY ZAYCEV	{"email": "zaycev_e_081959@postgrespro.ru", "phone": "+70046375800"}
0005432948728	C0BB3A	0211 409855	DMITRIY MIKHAYLOV	{"phone": "+70234675674"}
0005432948729	C0BB3A	8703 220785	MARIYA DENISOVA	{"phone": "+70397900817"}
0005432948730	5A6CC8	0954 711188	SERGEY SOKOLOV	{"phone": "+70253719145"}
0005432948731	24DDDB	4018 649632	NADEZHDA KUZNECOVA	{"phone": "+70626632396"}
0005432948732	42400F	6295 912034	NATALYA ZAKHAROVA	{"phone": "+70041766511"}
0005432948733	4CAF4B	5349 252943	ALEKSANDR KOROLEV	{"email": "a-korolev.1976@postgrespro.ru", "phone": "+70151835535"}
0005432948734	424C4B	2385 581561	LYUDMILA EFREMOVA	{"email": "l_efremova051974@postgrespro.ru", "phone": "+70081973050"}
0005432948735	424C4B	6306 677081	ILDAR DAVYDOV	{"email": "davydov.i-18071961@postgrespro.ru", "phone": "+70785397990"}
0005432948736	110A1E	5934 777692	IGOR NAUMOV	{"email": "naumov-i.101975@postgrespro.ru", "phone": "+70795646420"}
0005432948737	110A1E	1383 719851	DMITRIY NIKITIN	{"phone": "+70083999172"}
0005432948738	DAFAC8	1065 615787	OLEG FOMIN	{"email": "fominoleg.1957@postgrespro.ru", "phone": "+70016580840"}
0005432948739	5E37BA	1780 872780	DMITRIY SERGEEV	{"phone": "+70273284096"}
0005432948740	929860	7234 596142	IRINA VOROBEVA	{"email": "vorobevairina_1981@postgrespro.ru", "phone": "+70416261391"}
0005432948741	3C3868	6474 141896	SERGEY RODIONOV	{"phone": "+70469860353"}
0005432948742	B2D491	3000 486432	ANATOLIY GORBUNOV	{"email": "gorbunov-anatoliy1978@postgrespro.ru", "phone": "+70349638399"}
0005432948743	B2D491	0703 552165	POLINA TIMOFEEVA	{"phone": "+70018174936"}
0005432948744	505F85	5715 198258	SERGEY KOROLEV	{"email": "korolev.sergey.021970@postgrespro.ru", "phone": "+70260315888"}
0005432948745	EC0677	0451 626615	ARTEM KONOVALOV	{"email": "artem.konovalov1967@postgrespro.ru", "phone": "+70421329106"}
0005432948746	E16042	3029 938725	NADEZHDA ISAEVA	{"email": "nadezhdaisaeva-021975@postgrespro.ru", "phone": "+70367061024"}
0005432948747	0C9416	4798 105582	IVAN TIKHONOV	{"phone": "+70068466384"}
0005432948748	952032	0258 528754	OLGA ZAYCEVA	{"email": "ozayceva_14011969@postgrespro.ru", "phone": "+70316316154"}
0005432948749	EE0764	5242 399143	KIRILL YAKOVLEV	{"phone": "+70596180010"}
0005432948750	DBA829	9669 450019	MAKSIM ZHUKOV	{"email": "mzhukov.1980@postgrespro.ru", "phone": "+70874751812"}
0005432948751	DBA829	2602 116185	KARINA KOVALEVA	{"email": "kovaleva_k.04051969@postgrespro.ru", "phone": "+70696853613"}
0005432948752	DBA829	6284 940109	ALEKSEY MEDVEDEV	{"email": "medvedev.a-041969@postgrespro.ru", "phone": "+70975746167"}
0005432948753	BFDB28	6957 041921	NIKOLAY NAUMOV	{"email": "naumovn_1971@postgrespro.ru", "phone": "+70783405399"}
0005432948754	7D62E0	0675 413647	YURIY SOKOLOV	{"email": "sokolov_y.23041970@postgrespro.ru", "phone": "+70784447443"}
0005432948755	80F930	8535 241249	VLADIMIR SIDOROV	{"phone": "+70545674696"}
0005432948756	80F930	4879 151588	ANATOLIY MAKAROV	{"phone": "+70659959801"}
0005432948757	F2FD01	3726 770294	KIRA SOLOVEVA	{"phone": "+70906055543"}
0005432948758	01AB4F	4470 143303	ALEKSEY VLASOV	{"phone": "+70923352725"}
0005432948759	99FE40	2008 608990	OLGA EFREMOVA	{"email": "efremova.o.1967@postgrespro.ru", "phone": "+70290411331"}
0005432948760	99FE40	5900 442240	LIDIYA STEPANOVA	{"phone": "+70104469298"}
0005432948761	99FE40	7610 978153	VLADIMIR ALEKSEEV	{"phone": "+70614154528"}
0005432948762	1C2E26	7286 887597	TATYANA VASILEVA	{"email": "vasileva-t031967@postgrespro.ru", "phone": "+70631980462"}
0005432948763	1710F6	9333 156425	ROMAN KULIKOV	{"phone": "+70747247442"}
0005432948764	1710F6	3034 418831	KSENIYA STEPANOVA	{"email": "kseniya-stepanova.06071975@postgrespro.ru", "phone": "+70220597269"}
0005432948765	1710F6	5670 393662	ANNA TROFIMOVA	{"phone": "+70393931586"}
0005432948766	5CC1E4	6849 045181	NATALYA VLASOVA	{"phone": "+70797258747"}
0005432948767	B65E6B	1373 494830	NIKOLAY KUZMIN	{"email": "n.kuzmin-1975@postgrespro.ru", "phone": "+70758518855"}
0005432948768	2EFB25	6610 360118	OLGA NAZAROVA	{"phone": "+70057370511"}
0005432948769	2EFB25	4636 151013	GALINA LAZAREVA	{"email": "lazareva-galina-071974@postgrespro.ru", "phone": "+70189944090"}
0005432948770	582AA7	7534 518084	VLADIMIR FEDOROV	{"email": "fedorovv.051975@postgrespro.ru", "phone": "+70040409688"}
0005432948771	582AA7	5246 745445	NINA NAZAROVA	{"email": "n.nazarova.07021975@postgrespro.ru", "phone": "+70286470603"}
0005432948772	582AA7	9444 439347	ARINA PETROVA	{"email": "petrova_arina.1974@postgrespro.ru", "phone": "+70681195007"}
0005432948773	582AA7	7707 608377	VITALIY ZHURAVLEV	{"email": "vitaliy-zhuravlev-1961@postgrespro.ru", "phone": "+70085069254"}
0005432948774	6D9CFA	5707 474593	ANATOLIY NAZAROV	{"phone": "+70530769090"}
0005432948775	6D9CFA	4524 449296	ANASTASIYA KOZLOVA	{"email": "kozlova.anastasiya_1981@postgrespro.ru", "phone": "+70895584623"}
0005432948776	0C9DD7	5670 031619	ALEKSEY FOMIN	{"email": "aleksey.fomin.061971@postgrespro.ru", "phone": "+70400148924"}
0005432948777	5D45BE	1127 847557	ANDREY ROMANOV	{"phone": "+70551725119"}
0005432948778	8B28DD	0943 191214	KSENIYA EFIMOVA	{"phone": "+70625886863"}
0005432948779	33A2EE	5962 570896	TATYANA SEMENOVA	{"email": "t-semenova011968@postgrespro.ru", "phone": "+70219822139"}
0005432948780	D8670B	3798 438389	REGINA IVANOVA	{"phone": "+70002939084"}
0005432948781	937665	4633 868799	LYUDMILA SCHERBAKOVA	{"phone": "+70680539922"}
0005432948782	937665	5104 396140	VALERIY ROMANOV	{"phone": "+70256841189"}
0005432948783	7555A7	2247 671800	OLGA ANDREEVA	{"email": "andreevaolga_031968@postgrespro.ru", "phone": "+70603218178"}
0005432948784	49490E	7462 218889	KSENIYA ARKHIPOVA	{"phone": "+70704328637"}
0005432948785	49490E	3660 323234	ALEKSANDR KUZMIN	{"email": "kuzmin-a-021969@postgrespro.ru", "phone": "+70932046621"}
0005432948786	49490E	4072 451832	MATVEY MOROZOV	{"phone": "+70011241942"}
0005432948787	00F041	4753 563675	ANATOLIY SOKOLOV	{"email": "a.sokolov_1974@postgrespro.ru", "phone": "+70860084615"}
0005432948788	EDF49D	7373 073305	RUDOLF KOROLEV	{"phone": "+70233795462"}
0005432948789	0B2F9C	8249 220783	SERGEY ALEKSEEV	{"phone": "+70434695633"}
0005432948790	24E111	5836 083488	VLADIMIR BORISOV	{"email": "borisovv051969@postgrespro.ru", "phone": "+70814757238"}
0005432948791	299753	1049 141941	ANNA KOMAROVA	{"email": "komarovaanna.1979@postgrespro.ru", "phone": "+70579542929"}
0005432948792	299753	0658 126767	SAMIR MIKHAYLOV	{"email": "mikhaylov_samir_061975@postgrespro.ru", "phone": "+70548221210"}
0005432948793	299753	2617 872946	MARIYA POLYAKOVA	{"phone": "+70076951930"}
0005432948794	92A7C4	2776 202788	DMITRIY ABRAMOV	{"phone": "+70615281246"}
0005432948795	92A7C4	0683 897967	KLAVDIYA SERGEEVA	{"phone": "+70297677476"}
0005432948796	B79465	9671 974929	ALEKSEY ORLOV	{"email": "aleksey_orlov_061981@postgrespro.ru", "phone": "+70639934945"}
0005432948797	B79465	3994 421716	SERGEY ABRAMOV	{"email": "s.abramov_101974@postgrespro.ru", "phone": "+70763505519"}
0005432948798	8233E8	0534 660703	NIKOLAY ALEKSANDROV	{"phone": "+70826238991"}
0005432948799	66913D	2051 525103	DARYA KUDRYASHOVA	{"phone": "+70768613921"}
0005432948800	66913D	1992 278691	ELENA KUZMINA	{"email": "kuzmina-elena.1975@postgrespro.ru", "phone": "+70730415598"}
0005432948801	DF812F	7560 964043	ALINA NOVIKOVA	{"email": "novikova-alina1969@postgrespro.ru", "phone": "+70859805051"}
0005432948802	C558BB	4856 453200	ALEKSANDR NAZAROV	{"phone": "+70256575669"}
0005432948803	29BA9F	2556 475046	VASILIY BONDARENKO	{"phone": "+70853976267"}
0005432948804	66D242	2154 204246	NINA POLYAKOVA	{"email": "polyakova.nina1968@postgrespro.ru", "phone": "+70945638501"}
0005432948805	66D242	7959 100196	ELENA SMIRNOVA	{"phone": "+70216910780"}
0005432948806	13AD04	8788 779055	GALINA TIKHONOVA	{"email": "gtikhonova_17081981@postgrespro.ru", "phone": "+70658300614"}
0005432948807	5350F4	0503 478151	VALENTINA KUDRYASHOVA	{"phone": "+70721892929"}
0005432948808	4FFD3E	3652 879466	ALEKSEY SAVELEV	{"email": "a-savelev-071976@postgrespro.ru", "phone": "+70450724558"}
0005432948809	CC2220	0957 099847	TAMARA KUZNECOVA	{"email": "tamara-kuznecova-24111976@postgrespro.ru", "phone": "+70090063803"}
0005432948810	8BF5C7	8047 132869	SERGEY ANDREEV	{"email": "sergey_andreev.30061963@postgrespro.ru", "phone": "+70762811098"}
0005432948811	5D30C5	5873 689692	IGOR ROMANOV	{"email": "romanov.igor_021973@postgrespro.ru", "phone": "+70594176522"}
0005432948812	5FB1DE	6945 766427	ANTONINA KAZAKOVA	{"email": "a.kazakova051974@postgrespro.ru", "phone": "+70969861110"}
0005432948813	F2AA91	0692 451602	IGOR NIKOLAEV	{"email": "inikolaev.23051965@postgrespro.ru", "phone": "+70528305794"}
0005432948814	F2AA91	8726 872901	ROBERT MARTYNOV	{"phone": "+70611379267"}
0005432948815	0DE9DB	8706 838009	ALEKSANDR VOLKOV	{"phone": "+70998903727"}
0005432948816	AA4289	4756 019988	IRINA NIKOLAEVA	{"phone": "+70200071595"}
0005432948817	AA4289	2096 129968	VIKTORIYA OVCHINNIKOVA	{"email": "viktoriya_ovchinnikova_02081981@postgrespro.ru", "phone": "+70258232973"}
0005432948818	6B037A	3305 678935	NADEZHDA KUZNECOVA	{"email": "kuznecovan_12111974@postgrespro.ru", "phone": "+70640374735"}
0005432948819	6DED27	0194 238860	SERGEY SAVELEV	{"email": "s_savelev-07031965@postgrespro.ru", "phone": "+70021405959"}
0005432948820	BB6E40	5696 159040	SERGEY ZAYCEV	{"phone": "+70824641329"}
0005432948821	2C10D5	9207 889618	FARIDA KUZNECOVA	{"email": "kuznecova.farida15071972@postgrespro.ru", "phone": "+70936595190"}
0005432948822	5E8E34	5132 376034	VLADIMIR OSIPOV	{"email": "osipovv_061962@postgrespro.ru", "phone": "+70511584398"}
0005432948823	0244BB	4343 122552	DMITRIY ALEKSEEV	{"email": "dalekseev_27071980@postgrespro.ru", "phone": "+70575267594"}
0005432948824	0244BB	1684 676689	NAIL EGOROV	{"phone": "+70695508685"}
0005432948825	0244BB	3158 035742	VALENTINA BORISOVA	{"phone": "+70114085597"}
0005432948826	0244BB	1589 303912	ROMAN STEPANOV	{"email": "roman_stepanov.081985@postgrespro.ru", "phone": "+70549649436"}
0005432948827	B0E86A	5106 042054	NATALYA VOLKOVA	{"email": "n-volkova_1969@postgrespro.ru", "phone": "+70339928884"}
0005432948828	96A77C	3455 221887	ANTON SOLOVEV	{"email": "solovev.a-19091975@postgrespro.ru", "phone": "+70623206492"}
0005432948829	66AB2A	3345 924587	VLADISLAV MAKSIMOV	{"phone": "+70816802737"}
0005432948830	73E60B	3260 668431	ALEKSANDR ZAKHAROV	{"phone": "+70004246118"}
0005432948831	B79C31	3716 662213	ALEKSEY SIDOROV	{"phone": "+70669033775"}
0005432948832	B79C31	9075 217787	ARTEM GRIGOREV	{"email": "artemgrigorev1974@postgrespro.ru", "phone": "+70880528638"}
0005432948833	A0148C	0104 739219	RAISA KUZMINA	{"phone": "+70835683114"}
0005432948834	154FEF	1271 412718	ELENA MALYSHEVA	{"phone": "+70823109030"}
0005432948835	154FEF	4240 624080	DENIS SIDOROV	{"email": "denis_sidorov_16081976@postgrespro.ru", "phone": "+70577689433"}
0005432948836	99C4C1	4700 734139	MARIYA ARKHIPOVA	{"email": "markhipova1970@postgrespro.ru", "phone": "+70541111366"}
0005432948837	688598	0521 202556	NINA MEDVEDEVA	{"email": "nmedvedeva1974@postgrespro.ru", "phone": "+70770454852"}
0005432948838	688598	9904 795461	ALINA VASILEVA	{"email": "alina.vasileva-25091978@postgrespro.ru", "phone": "+70326841106"}
0005432948839	688598	2330 838725	EVGENIY KUZNECOV	{"phone": "+70574040384"}
0005432948840	2ED335	2946 615705	ZOYA KUZNECOVA	{"email": "kuznecovazoya-051967@postgrespro.ru", "phone": "+70641018821"}
0005432948841	2ED335	2049 579251	ALEKSANDR IVANOV	{"phone": "+70943269373"}
0005432948842	144BAB	5923 117718	SERGEY SOKOLOV	{"email": "sokolov_sergey1978@postgrespro.ru", "phone": "+70150297005"}
0005432948843	124F86	9392 640184	GALINA IVANOVA	{"email": "galinaivanova.16101965@postgrespro.ru", "phone": "+70653657350"}
0005432948844	124F86	2335 448110	ALSU BARANOVA	{"phone": "+70851948415"}
0005432948845	A203F8	9780 462912	ILYA KONOVALOV	{"phone": "+70430370380"}
0005432948846	570619	6034 210591	ELENA ANDREEVA	{"phone": "+70321640889"}
0005432948847	7802C5	4847 128525	ALEKSANDR GORBUNOV	{"phone": "+70898146476"}
0005432948848	84A2F0	2616 640157	ANNA KARPOVA	{"email": "a-karpova-091970@postgrespro.ru", "phone": "+70669562765"}
0005432948849	ACB255	7134 645788	ALEKSANDR BELOV	{"email": "aleksandr_belov_1971@postgrespro.ru", "phone": "+70954917005"}
0005432948850	5338D8	7639 188600	ALEKSANDR PAVLOV	{"phone": "+70925951369"}
0005432948851	43FF8B	2755 991968	ALEKSEY FEDOTOV	{"email": "aleksey_fedotov041974@postgrespro.ru", "phone": "+70330161636"}
0005432948852	0DC0A3	2259 504898	LILIYA KUZNECOVA	{"phone": "+70806507082"}
0005432948853	0DC0A3	7201 248364	NATALYA NOVIKOVA	{"email": "novikova_natalya_16061977@postgrespro.ru", "phone": "+70419807362"}
0005432948854	0DC0A3	6591 243737	ALBERT GERASIMOV	{"phone": "+70118971918"}
0005432948855	984F95	9829 433265	SERGEY NOVIKOV	{"email": "sergey.novikov-101982@postgrespro.ru", "phone": "+70258593462"}
0005432948856	6EA284	8491 764624	STEPAN ORLOV	{"email": "s.orlov_121971@postgrespro.ru", "phone": "+70246889480"}
0005432948857	6EA284	9997 699205	LIDIYA LUKYANOVA	{"phone": "+70715707607"}
0005432948858	9816C6	6895 787827	ALEKSANDR FROLOV	{"email": "frolov_aleksandr_021978@postgrespro.ru", "phone": "+70696224692"}
0005432948859	9816C6	6949 862862	GALINA KONOVALOVA	{"email": "galina_konovalova_1972@postgrespro.ru", "phone": "+70727928036"}
0005432948860	0B8C39	6909 136545	KIRILL KARPOV	{"email": "kirill-karpov_061985@postgrespro.ru", "phone": "+70448335003"}
0005432948861	43FDFD	8067 840240	NADEZHDA KUZNECOVA	{"phone": "+70636944387"}
0005432948862	D50307	3219 844976	KRISTINA MIRONOVA	{"phone": "+70155867315"}
0005432948863	D50307	3011 215544	RAISA SOKOLOVA	{"email": "r-sokolova_021973@postgrespro.ru", "phone": "+70861525775"}
0005432948864	F125E3	5778 122041	LYUBOV KARPOVA	{"phone": "+70036693885"}
0005432948865	F125E3	5330 124703	VALERIYA ABRAMOVA	{"phone": "+70523574722"}
0005432948866	F125E3	8117 760635	RAISA MASLOVA	{"email": "raisamaslova-14101967@postgrespro.ru", "phone": "+70387895042"}
0005432948867	6AF83F	4572 388629	KONSTANTIN KARPOV	{"email": "konstantin.karpov.1975@postgrespro.ru", "phone": "+70265438914"}
0005432948868	7164A2	9937 334301	IRINA BARANOVA	{"email": "ibaranova_041978@postgrespro.ru", "phone": "+70520547038"}
0005432948869	ADCBE0	0202 486348	VIKTOR CHERNOV	{"phone": "+70027770738"}
0005432948870	856362	6040 584931	SVETLANA SOROKINA	{"phone": "+70119422079"}
0005432948871	6274B9	9742 132542	VLADIMIR DENISOV	{"email": "denisovv1984@postgrespro.ru", "phone": "+70481218736"}
0005432948872	064F17	3230 279049	ZOYA NOVIKOVA	{"email": "novikova_z15101965@postgrespro.ru", "phone": "+70681829799"}
0005432948873	E66A59	1650 726466	NADEZHDA KALININA	{"phone": "+70614111683"}
0005432948874	6B6042	0179 562820	TATYANA EFIMOVA	{"email": "t.efimova-081967@postgrespro.ru", "phone": "+70159122749"}
0005432948875	6B6042	8201 685760	YANA VOROBEVA	{"email": "vorobeva_y.29011967@postgrespro.ru", "phone": "+70655919277"}
0005432948876	A41365	5271 568842	ROMAN IVANOV	{"email": "ivanov-roman.18091975@postgrespro.ru", "phone": "+70551994054"}
0005432948877	844459	3942 858808	VADIM EGOROV	{"phone": "+70037805286"}
0005432948878	DDA987	4729 625093	ANNA STEPANOVA	{"phone": "+70986345668"}
0005432948879	D80295	5146 648958	TATYANA SMIRNOVA	{"email": "smirnova-t_03071977@postgrespro.ru", "phone": "+70857367174"}
0005432948880	D80295	0697 089164	PELAGEYA BELOVA	{"email": "belovap.20031965@postgrespro.ru", "phone": "+70423625779"}
0005432948881	8AD15A	0368 733800	ALEKSANDR TARASOV	{"phone": "+70704126045"}
0005432948882	67DE0A	9432 442705	VIKTOR NAUMOV	{"email": "vnaumov061964@postgrespro.ru", "phone": "+70100859493"}
0005432948883	F13BFB	3080 482355	SERGEY SEMENOV	{"phone": "+70519612427"}
0005432948884	F13BFB	3874 098188	VALENTINA POPOVA	{"phone": "+70464408701"}
0005432948885	F13BFB	5164 658989	MARINA MIKHAYLOVA	{"phone": "+70168184950"}
0005432948886	470706	2713 698507	ALEKSANDR KRASNOV	{"phone": "+70395106069"}
0005432948887	37120D	9669 515670	ALLA VASILEVA	{"email": "a_vasileva.1972@postgrespro.ru", "phone": "+70564802123"}
0005432948888	37120D	8035 182352	ANASTASIYA NIKOLAEVA	{"phone": "+70870208519"}
0005432948889	37120D	9867 631371	LIDIYA ZAYCEVA	{"phone": "+70504830999"}
0005432948890	37120D	2643 151587	OLGA KUZMINA	{"phone": "+70939954843"}
0005432948891	2FE71C	4064 022948	ALEKSANDR AFANASEV	{"phone": "+70617704395"}
0005432948892	9DFD2D	2866 467735	SERGEY YAKOVLEV	{"phone": "+70264507143"}
0005432948893	9DFD2D	4257 780036	ZOYA ILINA	{"phone": "+70599218657"}
0005432948894	C5474A	2684 138192	SERGEY OSIPOV	{"email": "sergey.osipov_1965@postgrespro.ru", "phone": "+70008992569"}
0005432948895	C5474A	6443 141169	EGOR ALEKSEEV	{"email": "alekseev-e-28121963@postgrespro.ru", "phone": "+70695637211"}
0005432948896	E18BE6	4016 022948	VERA ANTONOVA	{"email": "vantonova-1967@postgrespro.ru", "phone": "+70752944636"}
0005432948897	A68491	1622 494763	VALENTINA SOKOLOVA	{"phone": "+70854566388"}
0005432948898	1CA0A4	3924 855514	DARYA BORISOVA	{"phone": "+70505601527"}
0005432948899	1CA0A4	8477 248691	ANDREY IVANOV	{"email": "a-ivanov-02111970@postgrespro.ru", "phone": "+70367841204"}
0005432948900	A0183C	6553 670028	SERGEY OSIPOV	{"phone": "+70960172180"}
0005432948901	A0183C	2537 624994	EVDOKIYA KUZNECOVA	{"email": "evdokiya.kuznecova_111976@postgrespro.ru", "phone": "+70992083302"}
0005432948902	CCDB13	4191 115781	ANATOLIY FILIPPOV	{"phone": "+70216569581"}
0005432948903	CCDB13	8136 435105	YURIY NIKOLAEV	{"email": "yuriy.nikolaev_27091976@postgrespro.ru", "phone": "+70056917319"}
0005432948904	630373	7722 090183	LIDIYA KOROLEVA	{"phone": "+70289223327"}
0005432948905	E726CB	4985 017695	EVGENIY ANTONOV	{"phone": "+70493475007"}
0005432948906	FB4643	9330 236625	MATVEY SOROKIN	{"phone": "+70278343482"}
0005432948907	47C706	5326 891610	ANASTASIYA SIDOROVA	{"phone": "+70367112543"}
0005432948908	92FAEB	6180 850147	ELENA POTAPOVA	{"phone": "+70579403635"}
0005432948909	FE766B	3769 245660	EVGENIY KARPOV	{"email": "karpovevgeniy.1977@postgrespro.ru", "phone": "+70765673706"}
0005432948910	A2A742	7519 061596	KIRILL MOROZOV	{"email": "kirill-morozov-031974@postgrespro.ru", "phone": "+70997635712"}
0005432948911	AC6077	1370 026478	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev-03041987@postgrespro.ru", "phone": "+70647498024"}
0005432948912	05F1E4	1866 868749	KSENIYA FILATOVA	{"email": "filatovakseniya-1974@postgrespro.ru", "phone": "+70229339722"}
0005432948913	05F1E4	5693 539793	SERGEY ALEKSEEV	{"email": "s-alekseev_041969@postgrespro.ru", "phone": "+70540204357"}
0005432948914	97ED66	2547 368859	NIKOLAY TARASOV	{"email": "ntarasov19071978@postgrespro.ru", "phone": "+70578428260"}
0005432948915	383563	3881 911116	IVAN VASILEV	{"phone": "+70869913665"}
0005432948916	FCC374	1267 265602	OLGA IVANOVA	{"email": "o.ivanova_07031969@postgrespro.ru", "phone": "+70623626626"}
0005432948917	FCC374	2854 663693	VIKTOR IVANOV	{"email": "ivanov-v22041973@postgrespro.ru", "phone": "+70813959758"}
0005432948918	DC6175	1426 813199	VLADISLAV KOZLOV	{"phone": "+70688027997"}
0005432948919	D8AA98	0711 546455	OLESYA SIDOROVA	{"email": "olesyasidorova091981@postgrespro.ru", "phone": "+70569643644"}
0005432948920	DB7E17	2683 216279	ANASTASIYA AKIMOVA	{"phone": "+70431349633"}
0005432948921	14F6A8	1542 098072	ALEKSANDR MOISEEV	{"phone": "+70540538816"}
0005432948922	14F6A8	9213 963002	ELENA FEDOROVA	{"phone": "+70993457174"}
0005432948923	1E8AEB	4495 462197	SERGEY DAVYDOV	{"email": "davydov_s-1960@postgrespro.ru", "phone": "+70106954690"}
0005432948924	A2517B	8064 430073	ALEKSANDR POPOV	{"email": "a.popov-021970@postgrespro.ru", "phone": "+70791290024"}
0005432948925	D515A3	9923 112470	OLGA NAZAROVA	{"phone": "+70783054387"}
0005432948926	1C639B	9200 840215	IGOR ZHURAVLEV	{"email": "i.zhuravlev_1970@postgrespro.ru", "phone": "+70712217263"}
0005432948927	7B72B3	4020 553059	SERGEY ALEKSEEV	{"email": "s_alekseev-08081978@postgrespro.ru", "phone": "+70029539733"}
0005432948928	77453C	6672 068561	TATYANA ILINA	{"phone": "+70147108145"}
0005432948929	77453C	1890 169334	SERGEY BONDARENKO	{"phone": "+70575300676"}
0005432948930	DFB9FD	2907 936258	KRISTINA MOROZOVA	{"phone": "+70088446781"}
0005432948931	31CBAF	8986 689335	SERGEY FOMIN	{"phone": "+70029820373"}
0005432948932	65FDFF	7906 778589	TATYANA ALEKSANDROVA	{"email": "aleksandrova_t_01101975@postgrespro.ru", "phone": "+70585406487"}
0005432948933	65FDFF	7508 519022	TATYANA MELNIKOVA	{"email": "t.melnikova_081972@postgrespro.ru", "phone": "+70947494411"}
0005432948934	661B66	7947 666531	DANILA GAVRILOV	{"email": "danila-gavrilov_01061951@postgrespro.ru", "phone": "+70876744423"}
0005432948935	661B66	7419 333267	OLESYA IVANOVA	{"phone": "+70580559595"}
0005432948936	661B66	3960 961846	ELENA ZOTOVA	{"email": "e-zotova101978@postgrespro.ru", "phone": "+70345055393"}
0005432948937	2CFEDC	4721 145381	NATALYA KAZAKOVA	{"email": "kazakova-natalya.02071972@postgrespro.ru", "phone": "+70403540491"}
0005432948938	2CFEDC	3093 721088	YURIY MELNIKOV	{"phone": "+70451146654"}
0005432948939	308D0D	4263 276764	VLADISLAV ZHURAVLEV	{"email": "vladislavzhuravlev_1975@postgrespro.ru", "phone": "+70869241295"}
0005432948940	556A98	0348 521883	SVETLANA NAZAROVA	{"email": "nazarova_s051961@postgrespro.ru", "phone": "+70657647913"}
0005432948941	B314EE	7259 688279	ANASTASIYA SEMENOVA	{"email": "anastasiyasemenova.1981@postgrespro.ru", "phone": "+70262786254"}
0005432948942	9ACDBE	6698 767164	LYUBOV PETROVA	{"phone": "+70730131674"}
0005432948943	3B3386	7192 350499	ARTEM BARANOV	{"email": "baranov-artem-07111989@postgrespro.ru", "phone": "+70211466052"}
0005432948944	AC25E3	3489 884249	DMITRIY SHEVCHENKO	{"email": "dshevchenko_101972@postgrespro.ru", "phone": "+70676901755"}
0005432948945	AC25E3	6714 772029	VALENTINA AFANASEVA	{"email": "v-afanaseva_1975@postgrespro.ru", "phone": "+70214664286"}
0005432948946	B02207	6465 593830	LIDIYA GUSEVA	{"email": "lidiya_guseva.1959@postgrespro.ru", "phone": "+70973698762"}
0005432948947	F04B63	4440 836065	NINA STEPANOVA	{"phone": "+70841266305"}
0005432948948	F04B63	0175 504098	RINAT IVANOV	{"email": "ivanov.rinat071970@postgrespro.ru", "phone": "+70416900043"}
0005432948949	631909	4796 069837	OLGA KONDRATEVA	{"email": "kondratevao031970@postgrespro.ru", "phone": "+70689728336"}
0005432948950	0B5B24	3972 816505	ALEKSANDR MOROZOV	{"phone": "+70793712098"}
0005432948951	F90B8B	9100 484674	NATALYA MEDVEDEVA	{"phone": "+70436052069"}
0005432948952	F90B8B	1606 399303	ANASTASIYA SOLOVEVA	{"email": "soloveva_a_1968@postgrespro.ru", "phone": "+70845615766"}
0005432948953	1B262C	1136 865295	LYUDMILA AFANASEVA	{"email": "afanaseva_lyudmila.19121965@postgrespro.ru", "phone": "+70589278242"}
0005432948954	1B262C	8230 834444	ALEKSANDRA GORBUNOVA	{"email": "a.gorbunova_1968@postgrespro.ru", "phone": "+70674196728"}
0005432948955	F69D19	7068 501650	TATYANA VOLKOVA	{"phone": "+70385517668"}
0005432948956	FB2103	9621 013792	ELENA VOROBEVA	{"email": "elena_vorobeva101963@postgrespro.ru", "phone": "+70899278601"}
0005432948957	FB2103	1165 389067	FARIDA PETROVA	{"email": "petrova-f_1973@postgrespro.ru", "phone": "+70326301435"}
0005432948958	04ACEE	5079 844464	VALENTINA ZAYCEVA	{"phone": "+70886591162"}
0005432948959	FB27BA	8358 056246	VERA MAKSIMOVA	{"phone": "+70882428076"}
0005432948960	26DF1F	5446 640366	SERGEY SEMENOV	{"phone": "+70487565643"}
0005432948961	B05249	6290 116194	LIDIYA IVANOVA	{"email": "ivanova.l_1970@postgrespro.ru", "phone": "+70602049155"}
0005432948962	AE7736	9900 503489	LYUDMILA ALEKSEEVA	{"email": "lyudmila_alekseeva-17071967@postgrespro.ru", "phone": "+70612994772"}
0005432948963	AE7736	6533 440617	VYACHESLAV NAZAROV	{"email": "v_nazarov011975@postgrespro.ru", "phone": "+70819123615"}
0005432948964	AE7736	4254 716565	MARIYA POPOVA	{"email": "popovamariya011960@postgrespro.ru", "phone": "+70555654439"}
0005432948965	F0F580	1443 154703	RAISA BORISOVA	{"email": "raisaborisova.091972@postgrespro.ru", "phone": "+70128528930"}
0005432948966	F0F580	4000 601621	EKATERINA EGOROVA	{"phone": "+70170523675"}
0005432948967	058D0A	9621 525954	LYUBOV MALYSHEVA	{"email": "malysheval_1963@postgrespro.ru", "phone": "+70310997770"}
0005432948968	058D0A	2518 001912	ARTEM IVANOV	{"email": "ivanov.a_1971@postgrespro.ru", "phone": "+70744855055"}
0005432948969	B1F912	4971 695824	NIKOLAY ZAKHAROV	{"email": "zakharov-nikolay.03051967@postgrespro.ru", "phone": "+70049572606"}
0005432948970	B1F912	3357 231500	LYUDMILA RODIONOVA	{"phone": "+70055305005"}
0005432948971	EFF7CD	6794 091074	ZULFIYA NIKOLAEVA	{"phone": "+70575897958"}
0005432948972	EFF7CD	3332 131829	RAVILYA EGOROVA	{"phone": "+70313153540"}
0005432948973	EFF7CD	2742 902507	SVETLANA MOROZOVA	{"email": "morozova-svetlana08101966@postgrespro.ru", "phone": "+70567419869"}
0005432948974	FCCF7D	1132 308313	TIGRAN EGOROV	{"email": "tigranegorov-19041967@postgrespro.ru", "phone": "+70998364293"}
0005432948975	CBABDC	2971 139878	ARTEM BELOV	{"email": "artem.belov-27051962@postgrespro.ru", "phone": "+70412107478"}
0005432948976	D19293	9969 748123	MIKHAIL KOROLEV	{"email": "m-korolev-031975@postgrespro.ru", "phone": "+70634428942"}
0005432948977	D19293	9166 372482	SERGEY MOROZOV	{"email": "morozov.sergey_1970@postgrespro.ru", "phone": "+70072535080"}
0005432948978	5F9F4B	4601 472043	LYUBOV TITOVA	{"email": "titova_l.22041976@postgrespro.ru", "phone": "+70470029472"}
0005432948979	8D8241	0082 703083	NATALYA SMIRNOVA	{"email": "nsmirnova-1962@postgrespro.ru", "phone": "+70788701158"}
0005432948980	8D8241	5941 962264	MARIYA SOROKINA	{"phone": "+70500684338"}
0005432948981	1E01BF	6810 871730	SOFYA ANDREEVA	{"email": "andreeva-sofya.11031967@postgrespro.ru", "phone": "+70792670574"}
0005432948982	F6FE71	7602 578892	VERA BELOVA	{"phone": "+70095720584"}
0005432948983	539775	2168 953433	TATYANA LOGINOVA	{"email": "t_loginova_071971@postgrespro.ru", "phone": "+70772909762"}
0005432948984	4288E5	3883 812185	GALINA DENISOVA	{"email": "g.denisova_121975@postgrespro.ru", "phone": "+70638157662"}
0005432948985	4288E5	8080 654493	DMITRIY VASILEV	{"phone": "+70278262832"}
0005432948986	4288E5	6526 111229	ELIZAVETA KOMAROVA	{"phone": "+70564434449"}
0005432948987	860971	1108 282669	ANDREY YAKOVLEV	{"phone": "+70792586561"}
0005432948988	860971	0597 092186	ELMIRA TIKHONOVA	{"email": "elmira.tikhonova.091963@postgrespro.ru", "phone": "+70288483079"}
0005432948989	D88826	0716 167092	ALLA MIRONOVA	{"phone": "+70749839895"}
0005432948990	B1413F	5574 371181	NADEZHDA GORBUNOVA	{"email": "nadezhda_gorbunova051972@postgrespro.ru", "phone": "+70916210888"}
0005432948991	DD730F	7830 683790	EKATERINA SMIRNOVA	{"email": "smirnova_ekaterina-121975@postgrespro.ru", "phone": "+70444938500"}
0005432948992	DD730F	7358 854430	IVAN BONDARENKO	{"email": "bondarenkoi.051982@postgrespro.ru", "phone": "+70293292768"}
0005432948993	D5A102	7916 763917	ANASTASIYA ORLOVA	{"phone": "+70988555883"}
0005432948994	D5A102	0692 428873	ALEKSANDR TARASOV	{"email": "a_tarasov_1975@postgrespro.ru", "phone": "+70553005501"}
0005432948995	51B9B0	0412 460423	ZOYA KARPOVA	{"email": "karpova.zoya.051979@postgrespro.ru", "phone": "+70232065174"}
0005432948996	E94206	7579 705708	TATYANA FILIPPOVA	{"email": "tfilippova-08031975@postgrespro.ru", "phone": "+70635388351"}
0005432948997	E94206	5765 391862	IRINA KISELEVA	{"email": "kiselevai.13051968@postgrespro.ru", "phone": "+70359081822"}
0005432948998	21C612	2088 585966	ALEKSANDRA STEPANOVA	{"phone": "+70828978509"}
0005432948999	E20020	8490 429814	OLGA ZAYCEVA	{"email": "zayceva.o.14111975@postgrespro.ru", "phone": "+70301440615"}
0005432949000	E20020	3555 135483	ALEKSANDR BORISOV	{"email": "a.borisov-071961@postgrespro.ru", "phone": "+70769171656"}
0005432949001	53A7A2	2598 686657	NADEZHDA LOGINOVA	{"phone": "+70902403988"}
0005432949002	53A7A2	3299 175544	TIMUR ORLOV	{"email": "timurorlov-13121976@postgrespro.ru", "phone": "+70621304731"}
0005432949003	F0B9BD	6510 333732	LYUBOV ROMANOVA	{"phone": "+70270530745"}
0005432949004	F0B9BD	1668 864063	NIKOLAY ORLOV	{"email": "n_orlov_31101975@postgrespro.ru", "phone": "+70205409027"}
0005432949005	AC7505	8016 447356	ANNA KOROLEVA	{"email": "koroleva.anna-051957@postgrespro.ru", "phone": "+70429799423"}
0005432949006	AC7505	0534 704989	TATYANA TARASOVA	{"email": "tarasova_tatyana.101968@postgrespro.ru", "phone": "+70531871992"}
0005432949007	E2000C	4093 049906	NIKOLAY YAKOVLEV	{"email": "nikolay_yakovlev-1973@postgrespro.ru", "phone": "+70240875804"}
0005432949008	01D3B0	6395 091672	VLADIMIR NAZAROV	{"email": "vladimir-nazarov.111969@postgrespro.ru", "phone": "+70032993805"}
0005432949009	01D3B0	6180 262032	ROMAN MAKAROV	{"phone": "+70727205444"}
0005432949010	5A8B75	3317 596004	SOFIYA ROMANOVA	{"phone": "+70503616334"}
0005432949011	5A8B75	4735 295043	DARYA ILINA	{"email": "ilina_d.071978@postgrespro.ru", "phone": "+70866943323"}
0005432949012	E14023	8649 404462	IVAN MIRONOV	{"email": "i.mironov_051956@postgrespro.ru", "phone": "+70041118278"}
0005432949013	E14023	6469 241746	IVAN VOLKOV	{"email": "ivolkov_01021963@postgrespro.ru", "phone": "+70272077800"}
0005432949014	1349B0	5538 007453	EVGENIY DENISOV	{"phone": "+70145872619"}
0005432949015	FAB5EE	6001 232822	OLGA NESTEROVA	{"email": "nesterova-o-021970@postgrespro.ru", "phone": "+70518487617"}
0005432949016	BB6E02	9862 622410	EVGENIYA MAKSIMOVA	{"phone": "+70189668237"}
0005432949017	BB6E02	6374 850570	LYUDMILA BOGDANOVA	{"phone": "+70583274153"}
0005432949018	20524E	4755 532498	NADEZHDA SOROKINA	{"email": "n.sorokina_1967@postgrespro.ru", "phone": "+70162302767"}
0005432949019	7859EF	9280 207734	EVGENIY NIKOLAEV	{"email": "nikolaev_e.05101973@postgrespro.ru", "phone": "+70091034637"}
0005432949020	F39E07	2139 077654	OKSANA IVANOVA	{"email": "oivanova23031976@postgrespro.ru", "phone": "+70604095608"}
0005432949021	D2FE1A	7170 626636	VLADIMIR FEDOROV	{"email": "fedorov-vladimir_06071967@postgrespro.ru", "phone": "+70698591446"}
0005432949022	D2FE1A	2262 226619	ANNA NIKOLAEVA	{"email": "nikolaeva.a1968@postgrespro.ru", "phone": "+70011118567"}
0005432949023	CCE808	3542 618527	OLGA MIRONOVA	{"phone": "+70905212783"}
0005432949024	A37EDE	9618 372898	PAVEL TARASOV	{"phone": "+70347842470"}
0005432949025	A37EDE	2767 653478	GULIYA ALEKSEEVA	{"email": "alekseeva-g-18011965@postgrespro.ru", "phone": "+70591731536"}
0005432949026	F6F8FA	2933 897405	ALEKSEY GORBUNOV	{"phone": "+70021108177"}
0005432949027	B271C3	9997 875781	GALINA ALEKSEEVA	{"phone": "+70464198827"}
0005432949028	B271C3	6538 551554	ALEKSANDR ZHURAVLEV	{"email": "aleksandrzhuravlev_101972@postgrespro.ru", "phone": "+70713698196"}
0005432949029	2FB2F6	7128 652924	FEDOR KARPOV	{"email": "f-karpov.061974@postgrespro.ru", "phone": "+70032552324"}
0005432949030	2FB2F6	4181 662119	RAISA VASILEVA	{"email": "vasileva_r_11021977@postgrespro.ru", "phone": "+70528504859"}
0005432949031	26A2DD	9036 746913	IVAN STEPANOV	{"email": "ivan-stepanov.29091965@postgrespro.ru", "phone": "+70034710234"}
0005432949032	86F985	3490 877065	ILYA SOROKIN	{"phone": "+70457178893"}
0005432949033	B2D0D9	6330 384696	ALEKSANDR SCHERBAKOV	{"phone": "+70425752862"}
0005432949034	B2D0D9	0437 482374	MARIYA NIKOLAEVA	{"phone": "+70043792571"}
0005432949035	97A509	4107 713200	SERGEY ZAYCEV	{"phone": "+70331932877"}
0005432949036	DB00AE	3717 921742	IRINA IVANOVA	{"phone": "+70912898388"}
0005432949037	B126D1	3822 614059	ALEKSANDR KUDRYASHOV	{"email": "kudryashovaleksandr.041971@postgrespro.ru", "phone": "+70570015412"}
0005432949038	925F8F	0294 734586	VIKTOR MELNIKOV	{"phone": "+70390959522"}
0005432949039	E23613	1349 973820	DMITRIY MATVEEV	{"email": "d.matveev_1958@postgrespro.ru", "phone": "+70973702602"}
0005432949040	678C68	7112 870391	MARINA GAVRILOVA	{"email": "gavrilova_marina.07051980@postgrespro.ru", "phone": "+70777929002"}
0005432949041	E47F57	6096 590393	ANASTASIYA FEDOROVA	{"phone": "+70645406981"}
0005432949042	E47F57	9776 748035	LILIYA SERGEEVA	{"phone": "+70477016371"}
0005432949043	DDF367	5447 681673	IRINA ILINA	{"email": "i_ilina_1976@postgrespro.ru", "phone": "+70014840485"}
0005432949044	5AB694	5454 005839	MARINA GORBUNOVA	{"email": "marina-gorbunova-19101968@postgrespro.ru", "phone": "+70346322989"}
0005432949045	813BAD	2293 275943	NATALYA MOROZOVA	{"email": "morozova-natalya.061971@postgrespro.ru", "phone": "+70737883164"}
0005432949046	CC8CAF	6817 752755	ARTEM MOISEEV	{"email": "a-moiseev091974@postgrespro.ru", "phone": "+70205901633"}
0005432949047	796ED5	5877 351621	KRISTINA SEMENOVA	{"phone": "+70128683043"}
0005432949048	796ED5	7749 113330	TATYANA BELOVA	{"email": "belova_t_17091974@postgrespro.ru", "phone": "+70067475155"}
0005432949049	79904F	5337 059934	TATYANA KULIKOVA	{"email": "t_kulikova.03011969@postgrespro.ru", "phone": "+70263614457"}
0005432949050	4058EE	8848 500598	NINA KUDRYASHOVA	{"email": "nkudryashova.101974@postgrespro.ru", "phone": "+70725405022"}
0005432949051	C1EEC8	6005 297861	ALEKSANDRA SOLOVEVA	{"email": "a.soloveva1972@postgrespro.ru", "phone": "+70765284279"}
0005432949052	C1EEC8	0640 444848	ALINA NAZAROVA	{"phone": "+70558616235"}
0005432949053	6824B4	0864 422083	ZINAIDA EGOROVA	{"phone": "+70052013817"}
0005432949054	6824B4	1839 822180	ALEKSANDR CHERNOV	{"email": "achernov_01091976@postgrespro.ru", "phone": "+70580102686"}
0005432949055	6824B4	1421 351422	ANDREY MAKAROV	{"phone": "+70122825168"}
0005432949056	6824B4	0143 117779	SEMEN ZAKHAROV	{"email": "s_zakharov-1958@postgrespro.ru", "phone": "+70123858676"}
0005432949057	E66B02	3782 950724	LARISA IVANOVA	{"phone": "+70187294459"}
0005432949058	2E5873	8317 676569	VALERIY YAKOVLEV	{"email": "vyakovlev.10051965@postgrespro.ru", "phone": "+70023520345"}
0005432949059	2E5873	9677 434128	IVAN VASILEV	{"phone": "+70146843379"}
0005432949060	E04B13	9254 074177	ALEKSANDR NOVIKOV	{"email": "a_novikov.1973@postgrespro.ru", "phone": "+70645133230"}
0005432949061	6478F5	0306 268142	ELENA SOKOLOVA	{"phone": "+70415450038"}
0005432949062	6478F5	4805 321345	GALINA BOGDANOVA	{"email": "g_bogdanova-091966@postgrespro.ru", "phone": "+70742709676"}
0005432949063	C43C28	0377 437473	IVAN NAUMOV	{"email": "naumovivan_24091976@postgrespro.ru", "phone": "+70169601131"}
0005432949064	C2A9BF	5807 304059	OLGA PAVLOVA	{"email": "pavlova-olga-21121972@postgrespro.ru", "phone": "+70358112114"}
0005432949065	78DF26	1805 909247	FEDOR AFANASEV	{"email": "f.afanasev.031975@postgrespro.ru", "phone": "+70872468355"}
0005432949066	78DF26	7755 135158	VIKTOR IVANOV	{"email": "ivanov-viktor.05051964@postgrespro.ru", "phone": "+70558736734"}
0005432949067	76C981	0816 499491	VIOLETTA EGOROVA	{"phone": "+70319039168"}
0005432949068	76C981	0555 212819	LILIYA POPOVA	{"email": "popova-l06011978@postgrespro.ru", "phone": "+70513236121"}
0005432949069	77E6DE	8110 454306	VLADISLAV KOZLOV	{"email": "v-kozlov-1976@postgrespro.ru", "phone": "+70612700948"}
0005432949070	049F04	7340 595603	LYUBOV YAKOVLEVA	{"phone": "+70744060573"}
0005432949071	B35641	8242 509630	ANASTASIYA LEBEDEVA	{"phone": "+70642823058"}
0005432949072	B35641	1193 401554	IVAN ROMANOV	{"email": "romanov.i.121983@postgrespro.ru", "phone": "+70311288250"}
0005432949073	EEAAFB	5072 223334	ALEKSANDR SAVELEV	{"email": "a-savelev_1977@postgrespro.ru", "phone": "+70004167834"}
0005432949074	EEAAFB	6907 212346	PAVEL SERGEEV	{"phone": "+70095938965"}
0005432949075	9FDBF8	1047 267512	TATYANA MARTYNOVA	{"email": "tatyana-martynova_03091989@postgrespro.ru", "phone": "+70075613816"}
0005432949076	FD52D8	2825 750889	ANZHELA TROFIMOVA	{"email": "trofimovaa-17121973@postgrespro.ru", "phone": "+70185474360"}
0005432949077	536135	2334 091202	ALEKSANDR SMIRNOV	{"email": "asmirnov_1967@postgrespro.ru", "phone": "+70980427977"}
0005432949078	4DEA22	8266 683828	GALINA MEDVEDEVA	{"email": "medvedeva-galina1988@postgrespro.ru", "phone": "+70408105040"}
0005432949079	7168CC	8156 024608	MARIYA VOLKOVA	{"email": "volkova-mariya.1974@postgrespro.ru", "phone": "+70795761525"}
0005432949080	C404DA	2237 752447	DMITRIY ANTONOV	{"phone": "+70920357131"}
0005432949081	C404DA	3454 830951	NATALYA BELOVA	{"email": "belova.natalya-051976@postgrespro.ru", "phone": "+70715805971"}
0005432949082	6F4003	5630 475631	ELENA POPOVA	{"email": "popova-elena-1963@postgrespro.ru", "phone": "+70065201275"}
0005432949083	0F1872	1409 023482	TATYANA MATVEEVA	{"email": "matveeva.tatyana-101968@postgrespro.ru", "phone": "+70853025868"}
0005432949084	961532	2716 369110	ALEKSEY NIKOLAEV	{"email": "a-nikolaev-29071965@postgrespro.ru", "phone": "+70807477301"}
0005432949085	770306	5935 335100	NIKOLAY GORBUNOV	{"phone": "+70195330171"}
0005432949086	C87B35	3857 387535	YULIYA TARASOVA	{"phone": "+70517836362"}
0005432949087	1FD12E	5305 362748	ANASTASIYA MELNIKOVA	{"email": "amelnikova071980@postgrespro.ru", "phone": "+70441264284"}
0005432949088	DC9C60	6440 836093	ANNA ISAEVA	{"phone": "+70328656194"}
0005432949089	DC9C60	7680 519571	ALEKSANDR KAZAKOV	{"phone": "+70951133383"}
0005432949090	FB0FE4	5677 135751	ALEKSANDR MAKAROV	{"phone": "+70683129308"}
0005432949091	3E1F18	5233 159677	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva_111972@postgrespro.ru", "phone": "+70510212066"}
0005432949092	3E1F18	0375 055616	ALENA ANISIMOVA	{"email": "anisimova.alena.23021980@postgrespro.ru", "phone": "+70180668960"}
0005432949093	EFB230	2463 657584	NIKOLAY BARANOV	{"phone": "+70801881972"}
0005432949094	F82039	0660 482154	LYUBOV POPOVA	{"email": "popoval-21061974@postgrespro.ru", "phone": "+70385070530"}
0005432949095	28AF4F	4465 858571	NINA VOLKOVA	{"phone": "+70772400028"}
0005432949096	E55A50	2566 609684	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov.011974@postgrespro.ru", "phone": "+70434713700"}
0005432949097	28237D	0311 063888	VLADIMIR KONOVALOV	{"email": "konovalov_vladimir20121974@postgrespro.ru", "phone": "+70861689015"}
0005432949098	4DD0AF	0875 994661	DMITRIY FEDOROV	{"phone": "+70730426133"}
0005432949099	168BB0	7751 109531	VASILIY OSIPOV	{"phone": "+70113169189"}
0005432949100	257D91	6457 103960	ALEKSEY TIMOFEEV	{"phone": "+70362976973"}
0005432949101	257D91	6695 752562	NIKOLAY ABRAMOV	{"email": "abramovnikolay_021961@postgrespro.ru", "phone": "+70639348785"}
0005432949102	0A74E7	5506 310326	EVGENIY ANTONOV	{"email": "antonovevgeniy_1969@postgrespro.ru", "phone": "+70743321231"}
0005432949103	C7CA94	5546 813497	NIKOLAY FEDOROV	{"phone": "+70142884236"}
0005432949104	4F9626	3645 689517	VLADIMIR PAVLOV	{"phone": "+70276092413"}
0005432949105	4CFC6C	0460 119704	ALEKSEY PAVLOV	{"email": "a_pavlov1974@postgrespro.ru", "phone": "+70330380341"}
0005432949106	054392	2231 929923	PETR KUZNECOV	{"phone": "+70329672457"}
0005432949107	557B5F	2856 785004	ALENA KUZNECOVA	{"email": "kuznecovaalena_1969@postgrespro.ru", "phone": "+70749730123"}
0005432949108	2EC8F8	7165 734499	OLGA ANTONOVA	{"phone": "+70158147718"}
0005432949109	A45845	2679 297505	ALEKSANDR IVANOV	{"email": "aleksandrivanov-10101971@postgrespro.ru", "phone": "+70268011731"}
0005432949110	A45845	7692 263146	SERGEY FEDOROV	{"phone": "+70443576026"}
0005432949111	D2AB45	4394 429315	ANDREY ISAEV	{"phone": "+70625439887"}
0005432949112	AF5902	2562 430802	NATALYA MATVEEVA	{"email": "n-matveeva071972@postgrespro.ru", "phone": "+70526108945"}
0005432949113	6F9A5C	5181 961204	MARK IVANOV	{"phone": "+70797663009"}
0005432949114	6F9A5C	9189 517179	SERGEY VLASOV	{"email": "vlasovsergey_18011955@postgrespro.ru", "phone": "+70209001087"}
0005432949115	7C807E	6638 698304	ILYA KISELEV	{"phone": "+70141439103"}
0005432949116	7C807E	8509 155123	KONSTANTIN NAZAROV	{"email": "konstantin-nazarov_30061971@postgrespro.ru", "phone": "+70332033057"}
0005432949117	239758	0477 620774	NIKOLAY MAKAROV	{"phone": "+70414987932"}
0005432949118	4D59BE	0488 277173	LYUBOV PETROVA	{"phone": "+70822991858"}
0005432949119	E20CFD	0241 027101	OLEG BONDARENKO	{"email": "bondarenko-oleg11111983@postgrespro.ru", "phone": "+70143070283"}
0005432949120	E1FF1E	6699 808443	SERGEY TARASOV	{"email": "tarasovs-08071960@postgrespro.ru", "phone": "+70470661558"}
0005432949121	F23B2E	5152 181430	POLINA MOISEEVA	{"email": "polinamoiseeva-11011967@postgrespro.ru", "phone": "+70152916289"}
0005432949122	92E5E8	9634 814962	ANTON POPOV	{"phone": "+70146330115"}
0005432949123	80EA30	8977 029821	VALERIYA TITOVA	{"phone": "+70984776467"}
0005432949124	80EA30	0115 230375	DMITRIY MIRONOV	{"email": "mironovd-16061972@postgrespro.ru", "phone": "+70238468677"}
0005432949125	4BF0F1	4378 137907	VLADIMIR KULIKOV	{"phone": "+70118749204"}
0005432949126	4BF0F1	4610 912272	VALENTINA ILINA	{"email": "valentina.ilina_06111985@postgrespro.ru", "phone": "+70686097742"}
0005432949127	B83C68	9902 227178	DMITRIY MAKAROV	{"phone": "+70359261195"}
0005432949128	18E8EF	0663 266437	ZINAIDA IVANOVA	{"email": "zivanova-09091966@postgrespro.ru", "phone": "+70813054515"}
0005432949129	0106F4	8236 085742	ALISA NIKITINA	{"phone": "+70537304546"}
0005432949130	0106F4	7564 907727	SVETLANA STEPANOVA	{"email": "svetlana-stepanova06051978@postgrespro.ru", "phone": "+70628133602"}
0005432949131	FEB716	4090 423999	NATALYA KOROLEVA	{"phone": "+70741337641"}
0005432949132	FEB716	6279 854339	YURIY KUZNECOV	{"email": "kuznecov-yuriy.1958@postgrespro.ru", "phone": "+70187420516"}
0005432949133	49EF00	0810 785625	TATYANA RYABOVA	{"email": "ryabovat_21111982@postgrespro.ru", "phone": "+70489316098"}
0005432949134	49EF00	2091 773436	TAMARA DMITRIEVA	{"phone": "+70144705984"}
0005432949135	B3A6EA	3342 449114	SERGEY FROLOV	{"email": "frolov_sergey_23091978@postgrespro.ru", "phone": "+70288598209"}
0005432949136	B3A6EA	7477 408499	YULIYA ANDREEVA	{"email": "yuliya-andreeva091967@postgrespro.ru", "phone": "+70209103934"}
0005432949137	4B49D0	7211 509619	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr-021984@postgrespro.ru", "phone": "+70172115346"}
0005432949138	4B49D0	1635 777673	LYUDMILA SCHERBAKOVA	{"email": "lyudmila-scherbakova.04081964@postgrespro.ru", "phone": "+70027702027"}
0005432949139	1EC3D7	1398 002733	MARIYA POPOVA	{"email": "popovamariya_1967@postgrespro.ru", "phone": "+70287776457"}
0005432949140	4EF1E5	0436 224082	SERGEY GUSEV	{"email": "s_gusev.081975@postgrespro.ru", "phone": "+70068478811"}
0005432949141	4EF1E5	3950 670827	MIKHAIL FEDOROV	{"email": "mfedorov-1979@postgrespro.ru", "phone": "+70537367955"}
0005432949142	4EF1E5	0777 892351	RINAT GRIGOREV	{"phone": "+70841179260"}
0005432949143	0FEE83	0848 121438	IGOR KARPOV	{"email": "karpov-igor-111977@postgrespro.ru", "phone": "+70513562321"}
0005432949144	ADD70D	0568 236265	DMITRIY STEPANOV	{"phone": "+70668537854"}
0005432949145	ADD70D	0920 292665	LYUBOV IVANOVA	{"email": "ivanovalyubov_13051969@postgrespro.ru", "phone": "+70370676980"}
0005432949146	BFE4D4	8255 703108	DANIIL MOISEEV	{"phone": "+70903926573"}
0005432949147	BFE4D4	6853 790454	EVGENIY NIKITIN	{"phone": "+70768142039"}
0005432949148	38B489	2658 380771	VALENTINA FILIPPOVA	{"email": "filippova.v.1968@postgrespro.ru", "phone": "+70639163996"}
0005432949149	38B489	7598 281492	TATYANA GUSEVA	{"email": "guseva.t_061960@postgrespro.ru", "phone": "+70434537845"}
0005432949150	FF2132	3904 651695	IRINA BORISOVA	{"phone": "+70218114353"}
0005432949151	FF2132	4073 025151	LYUDMILA KOROLEVA	{"phone": "+70229062423"}
0005432949152	3AB401	0441 313320	GEORGIY SOROKIN	{"phone": "+70393122287"}
0005432949153	2A896B	1879 437777	VIKTOR OSIPOV	{"email": "osipov.v12041974@postgrespro.ru", "phone": "+70353039926"}
0005432949154	3E6661	3745 370574	NATALYA SCHERBAKOVA	{"email": "scherbakova_n.1981@postgrespro.ru", "phone": "+70680261918"}
0005432949155	0C968E	3958 984347	EKATERINA KUZNECOVA	{"email": "kuznecova_ekaterina_1969@postgrespro.ru", "phone": "+70436842132"}
0005432949156	0C968E	9148 508115	ELENA DENISOVA	{"email": "denisovae_1966@postgrespro.ru", "phone": "+70402768059"}
0005432949157	BC8336	0436 779750	OLGA KOROLEVA	{"email": "o-koroleva_1961@postgrespro.ru", "phone": "+70382524656"}
0005432949158	BC8336	3498 703403	TATYANA OVCHINNIKOVA	{"email": "t.ovchinnikova_16011979@postgrespro.ru", "phone": "+70783634010"}
0005432949159	FFAE15	3426 423310	VENERA BELYAEVA	{"email": "v-belyaeva_1962@postgrespro.ru", "phone": "+70374259251"}
0005432949160	FFAE15	4800 999136	SERGEY BONDARENKO	{"phone": "+70646023286"}
0005432949161	3B4DDA	3491 871263	KONSTANTIN ALEKSANDROV	{"phone": "+70857613769"}
0005432949162	3B4DDA	5594 618602	NATALYA NIKITINA	{"phone": "+70433614975"}
0005432949163	16E9C8	0522 692029	MARIYA BORISOVA	{"email": "borisova.m-091974@postgrespro.ru", "phone": "+70189099682"}
0005432949164	404E34	4265 703353	ANDREY IVANOV	{"phone": "+70342515992"}
0005432949165	6624EE	8394 672714	IGOR GRIGOREV	{"email": "grigorevigor.051977@postgrespro.ru", "phone": "+70975078778"}
0005432949166	40A40D	7127 635335	PAVEL VLASOV	{"email": "vlasov-pavel051973@postgrespro.ru", "phone": "+70648414832"}
0005432949167	4424F6	1644 655506	YULIYA KAZAKOVA	{"phone": "+70930740923"}
0005432949168	2A8057	1032 747956	IGOR BELOV	{"email": "belovi1966@postgrespro.ru", "phone": "+70904621700"}
0005432949169	D43195	8235 895805	NINA RODIONOVA	{"email": "rodionova-nina.22011977@postgrespro.ru", "phone": "+70633345180"}
0005432949170	085EF9	7101 622585	ELENA RODIONOVA	{"phone": "+70517801414"}
0005432949171	F3F3EE	0692 629649	GUZEL GRISHINA	{"phone": "+70279389009"}
0005432949172	1E87BA	9897 235406	KONSTANTIN KOROLEV	{"email": "k-korolev03101981@postgrespro.ru", "phone": "+70453793742"}
0005432949173	F2BE58	0345 125531	IRINA NIKITINA	{"phone": "+70665466738"}
0005432949174	F2BE58	3002 654051	VASILIY TIMOFEEV	{"phone": "+70915825707"}
0005432949175	308DDB	8240 588744	NINA FOMINA	{"email": "fomina.nina.081970@postgrespro.ru", "phone": "+70889250815"}
0005432949176	DEB614	5145 829419	GENNADIY ZHUKOV	{"email": "g-zhukov1984@postgrespro.ru", "phone": "+70314114845"}
0005432949177	79739C	6896 666367	DANILA SEMENOV	{"email": "semenov.d-1973@postgrespro.ru", "phone": "+70849706256"}
0005432949178	483B1A	4610 780537	ALISA YUDINA	{"phone": "+70263697000"}
0005432949179	483B1A	4860 843964	ANATOLIY MATVEEV	{"email": "a-matveev041970@postgrespro.ru", "phone": "+70343801235"}
0005432949180	29C1FF	5740 523578	ALLA MOROZOVA	{"email": "alla_morozova.03101965@postgrespro.ru", "phone": "+70363967820"}
0005432949181	26C5C8	9999 558760	ALEKSANDR FEDOROV	{"email": "fedorov_a.04021964@postgrespro.ru", "phone": "+70073003978"}
0005432949182	26C5C8	3893 149593	VALERIY IVANOV	{"email": "v.ivanov.16051968@postgrespro.ru", "phone": "+70577535417"}
0005432949183	894BC7	9647 560579	ALEKSANDR KARPOV	{"phone": "+70720864434"}
0005432949184	018EA7	0588 568113	LYUBOV VLASOVA	{"email": "lyubov_vlasova-09021962@postgrespro.ru", "phone": "+70501830410"}
0005432949185	AB4793	0358 630239	ANNA KUDRYASHOVA	{"email": "kudryashova_a07121969@postgrespro.ru", "phone": "+70564881267"}
0005432949186	AB4793	8869 918167	ILYA KULIKOV	{"email": "i.kulikov_111969@postgrespro.ru", "phone": "+70082542884"}
0005432949187	AB4793	4551 391846	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir-1963@postgrespro.ru", "phone": "+70177840685"}
0005432949188	C8F1C3	6143 924902	EVGENIY ZAYCEV	{"email": "e.zaycev03021979@postgrespro.ru", "phone": "+70506956572"}
0005432949189	C8F1C3	8851 534088	SERGEY SOKOLOV	{"phone": "+70622705149"}
0005432949190	4162CF	9859 008888	VADIM TIKHONOV	{"email": "tikhonov-vadim-041977@postgrespro.ru", "phone": "+70423959405"}
0005432949191	AF6330	5063 854976	NIKITA SAVELEV	{"email": "savelevn.1970@postgrespro.ru", "phone": "+70011988350"}
0005432949192	AF6330	9624 377362	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_1978@postgrespro.ru", "phone": "+70453865738"}
0005432949193	4B82EB	6915 894883	VLADIMIR ZAKHAROV	{"phone": "+70882844864"}
0005432949194	7925EE	3136 164900	EVGENIYA KOZLOVA	{"email": "kozlovaevgeniya1977@postgrespro.ru", "phone": "+70102413424"}
0005432949195	86FE37	4378 147963	ALEKSANDR FEDOROV	{"phone": "+70465275409"}
0005432949196	86FE37	1031 043153	ALEKSANDR KUZNECOV	{"phone": "+70871402900"}
0005432949197	86FE37	9337 243204	NIKITA KULIKOV	{"phone": "+70214691738"}
0005432949198	6195AD	6356 452735	ELENA ZOTOVA	{"email": "e_zotova-031972@postgrespro.ru", "phone": "+70013915739"}
0005432949199	F90603	5962 737528	ANDREY NAZAROV	{"email": "nazarov.a1973@postgrespro.ru", "phone": "+70164829473"}
0005432949200	01E0D1	0919 106009	DARYA BORISOVA	{"phone": "+70472700226"}
0005432949201	6C3DD3	9847 976743	RAISA ZAYCEVA	{"phone": "+70146913140"}
0005432949202	6C3DD3	8313 607851	YAKOV PETROV	{"phone": "+70459384030"}
0005432949203	602AAC	9651 708764	DENIS MAKAROV	{"email": "d_makarov-1969@postgrespro.ru", "phone": "+70983480424"}
0005432949204	602AAC	3795 978327	ANASTASIYA POPOVA	{"email": "popova-a1974@postgrespro.ru", "phone": "+70032994195"}
0005432949205	39E5AB	9480 550910	ELEONORA EFIMOVA	{"email": "eleonora_efimova-1973@postgrespro.ru", "phone": "+70973196095"}
0005432949206	39E5AB	8454 652651	MIKHAIL DMITRIEV	{"phone": "+70336061532"}
0005432949207	AAD323	0364 117703	ELENA TITOVA	{"phone": "+70043117032"}
0005432949208	73B085	2008 998940	ALEKSANDR ISAEV	{"email": "isaevaleksandr-06081961@postgrespro.ru", "phone": "+70399728987"}
0005432949209	5E9A27	0229 934015	VIKTOR MAKAROV	{"phone": "+70790560957"}
0005432949210	410107	5290 817079	YULIYA AFANASEVA	{"phone": "+70813613459"}
0005432949211	410107	8800 235874	POLINA MATVEEVA	{"phone": "+70730013263"}
0005432949212	F34B71	5728 007211	DMITRIY GUSEV	{"email": "dgusev.30101974@postgrespro.ru", "phone": "+70925803256"}
0005432949213	F34B71	6059 235255	SVETLANA MOISEEVA	{"email": "moiseeva_s.111975@postgrespro.ru", "phone": "+70848269014"}
0005432949214	9A79A2	5057 105583	NIKOLAY TIKHONOV	{"email": "tikhonov_nikolay1974@postgrespro.ru", "phone": "+70663279748"}
0005432949215	0B231F	7808 006130	VIKTORIYA SEMENOVA	{"phone": "+70201780564"}
0005432949216	0B231F	2065 015161	MAKSIM NOVIKOV	{"email": "m_novikov_14031985@postgrespro.ru", "phone": "+70660062806"}
0005432949217	0B231F	8416 054975	OLGA KOMAROVA	{"phone": "+70768078720"}
0005432949218	72E289	3977 296282	MARIYA YUDINA	{"phone": "+70744655207"}
0005432949219	52EEEB	7297 268902	ANGELINA NIKIFOROVA	{"phone": "+70668506806"}
0005432949220	52EEEB	1644 221032	VALENTINA ZOTOVA	{"phone": "+70205914743"}
0005432949221	C7E741	4555 111350	ALEKSEY IVANOV	{"email": "a_ivanov-1982@postgrespro.ru", "phone": "+70714438714"}
0005432949222	D2E811	0133 402960	RUZALIYA STEPANOVA	{"email": "stepanovaruzaliya-1971@postgrespro.ru", "phone": "+70007484010"}
0005432949223	D2E811	8580 689670	TATYANA KAZAKOVA	{"phone": "+70237062276"}
0005432949224	3E286F	4054 363605	OLGA EFREMOVA	{"phone": "+70921215333"}
0005432949225	A1D937	4962 212370	VALERIY KISELEV	{"email": "v_kiselev-18121975@postgrespro.ru", "phone": "+70384680477"}
0005432949226	8E8DC3	9236 663249	LIDIYA FADEEVA	{"phone": "+70656450621"}
0005432949227	BB3FCE	2273 067419	VLADISLAV SHEVCHENKO	{"phone": "+70290569249"}
0005432949228	98B04C	1166 487210	ALEKSANDR BORISOV	{"email": "aleksandr_borisov_20091975@postgrespro.ru", "phone": "+70691445446"}
0005432949229	11444B	5399 944197	MIKHAIL CHERNOV	{"email": "m_chernov-1967@postgrespro.ru", "phone": "+70717365336"}
0005432949230	FEB1A6	0233 340206	LARISA ZAKHAROVA	{"phone": "+70044832428"}
0005432949231	FEB1A6	2244 871041	YULIYA KOZLOVA	{"phone": "+70389490275"}
0005432949232	7C7BFB	2648 303475	VLADIMIR TARASOV	{"phone": "+70990166573"}
0005432949233	6CC2EF	3586 762866	SVETLANA CHERNOVA	{"email": "svetlana-chernova-1979@postgrespro.ru", "phone": "+70370564562"}
0005432949234	6CC2EF	3363 211219	SVETLANA CHERNOVA	{"phone": "+70255383804"}
0005432949235	BFB7A1	5030 265104	NATALYA NIKOLAEVA	{"email": "n.nikolaeva1962@postgrespro.ru", "phone": "+70690912548"}
0005432949236	BFB7A1	7897 385440	ALEKSANDR SIDOROV	{"email": "asidorov.061969@postgrespro.ru", "phone": "+70053391036"}
0005432949237	9E8520	9165 178113	IVAN ZAKHAROV	{"email": "i-zakharov.25091961@postgrespro.ru", "phone": "+70671101520"}
0005432949238	E90918	7216 846611	ALEKSANDR TARASOV	{"phone": "+70050164616"}
0005432949239	B61683	9405 747195	MARINA PETROVA	{"email": "m_petrova-21101976@postgrespro.ru", "phone": "+70893492691"}
0005432949240	B61683	1513 179729	DARYA NIKITINA	{"phone": "+70644572035"}
0005432949241	2E0C1C	2949 873720	DARYA FADEEVA	{"email": "fadeeva_darya-22091967@postgrespro.ru", "phone": "+70830123050"}
0005432949242	29FAEB	6620 873804	OLEG MIKHAYLOV	{"email": "oleg_mikhaylov_1978@postgrespro.ru", "phone": "+70535884793"}
0005432949243	29FAEB	2919 308987	KONSTANTIN GUSEV	{"email": "gusev_konstantin.071978@postgrespro.ru", "phone": "+70019734630"}
0005432949244	F1EF6E	7099 839822	MATVEY BONDARENKO	{"phone": "+70175977620"}
0005432949245	D6391B	6929 611048	SERGEY SMIRNOV	{"phone": "+70685578482"}
0005432949246	EBBF11	2255 117481	VIKTOR POPOV	{"phone": "+70451329772"}
0005432949247	1B5544	3921 894490	ALEKSANDR VASILEV	{"email": "a-vasilev_1967@postgrespro.ru", "phone": "+70713907363"}
0005432949248	1B5544	6883 392387	VERA BOGDANOVA	{"email": "vera_bogdanova-16051975@postgrespro.ru", "phone": "+70492271729"}
0005432949249	80FD09	7120 995789	VALERIY ILIN	{"phone": "+70600861680"}
0005432949250	80FD09	1070 696381	NATALYA NIKOLAEVA	{"phone": "+70520290420"}
0005432949251	80FD09	2867 161568	ROSTISLAV GERASIMOV	{"email": "gerasimov_rostislav19041964@postgrespro.ru", "phone": "+70538087729"}
0005432949252	50E4B8	9570 788916	VLADIMIR PAVLOV	{"phone": "+70752841400"}
0005432949253	EB734E	3978 550509	ELENA KOMAROVA	{"phone": "+70632123546"}
0005432949254	D1D732	1676 010275	ELENA RODIONOVA	{"email": "rodionova_elena.1976@postgrespro.ru", "phone": "+70335794986"}
0005432949255	00A778	0791 991861	GRIGORIY SEMENOV	{"email": "grigoriy.semenov.19061973@postgrespro.ru", "phone": "+70878513506"}
0005432949256	B8FB47	5639 673708	RAISA IVANOVA	{"phone": "+70505377701"}
0005432949257	B8FB47	5576 621859	NINA ZAYCEVA	{"email": "nina-zayceva-061979@postgrespro.ru", "phone": "+70825890493"}
0005432949258	C79030	0753 559267	EVGENIYA IVANOVA	{"phone": "+70293589199"}
0005432949259	1CBCB2	1068 963395	GALINA MOROZOVA	{"email": "morozova-galina_23081964@postgrespro.ru", "phone": "+70647773720"}
0005432949260	1CBCB2	4595 525315	VSEVOLOD IVANOV	{"email": "ivanov-v-07021962@postgrespro.ru", "phone": "+70402725029"}
0005432949261	6E9741	9772 293825	EKATERINA BARANOVA	{"email": "baranova.ekaterina-13111970@postgrespro.ru", "phone": "+70181262568"}
0005432949262	6E9741	8489 230012	NIKITA ROMANOV	{"email": "romanov.nikita-01061966@postgrespro.ru", "phone": "+70776127044"}
0005432949263	BB2F6B	1269 940664	VLADIMIR KUDRYASHOV	{"phone": "+70969786258"}
0005432949264	360536	7677 293367	YANA LEBEDEVA	{"phone": "+70493912981"}
0005432949265	360536	9649 310485	RAISA ORLOVA	{"email": "orlova-r.1974@postgrespro.ru", "phone": "+70345066235"}
0005432949266	05CA27	9810 954362	VERA NIKOLAEVA	{"email": "v_nikolaeva_27081974@postgrespro.ru", "phone": "+70695078449"}
0005432949267	05CA27	0063 061301	SERGEY SOROKIN	{"phone": "+70091554849"}
0005432949268	C56E49	0089 990789	NATALYA KOVALEVA	{"email": "n_kovaleva-16031968@postgrespro.ru", "phone": "+70569776495"}
0005432949269	5F6035	2736 628672	YULIYA IVANOVA	{"email": "yivanova-01071976@postgrespro.ru", "phone": "+70829736776"}
0005432949270	5F6035	2208 138503	ANNA SOLOVEVA	{"email": "solovevaanna-11041966@postgrespro.ru", "phone": "+70120878644"}
0005432949271	AB88A9	0006 022966	VIKTOR FEDOTOV	{"email": "viktor.fedotov.101978@postgrespro.ru", "phone": "+70743222975"}
0005432949272	AB88A9	7304 805637	DENIS MIKHAYLOV	{"email": "mikhaylov-d-04051974@postgrespro.ru", "phone": "+70724700361"}
0005432949273	AB88A9	6827 826291	NATALYA PETROVA	{"phone": "+70027501924"}
0005432949274	D6B86A	6578 942999	VIKTOR OSIPOV	{"phone": "+70351554273"}
0005432949275	B3A255	1882 104475	ALEKSANDRA GAVRILOVA	{"phone": "+70842409419"}
0005432949276	8FBC86	9675 693507	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko_061967@postgrespro.ru", "phone": "+70266746910"}
0005432949277	2AE96C	6521 921052	DMITRIY SERGEEV	{"email": "dmitriysergeev_18041972@postgrespro.ru", "phone": "+70543157320"}
0005432949278	3D0B52	9104 092478	RUSTAM VOROBEV	{"email": "r-vorobev_1965@postgrespro.ru", "phone": "+70123190765"}
0005432949279	17777D	8747 838448	ARTEM KUZNECOV	{"email": "artem_kuznecov_1978@postgrespro.ru", "phone": "+70268947198"}
0005432949280	17777D	9628 420130	ANDREY TARASOV	{"phone": "+70171681595"}
0005432949281	2A9A94	2353 928410	LARISA FOMINA	{"email": "larisa.fomina.27111969@postgrespro.ru", "phone": "+70054913641"}
0005432949282	DA2B0E	2689 924709	IVAN MAKAROV	{"phone": "+70209777382"}
0005432949283	52B2F7	6217 515422	DMITRIY ZAYCEV	{"phone": "+70419027774"}
0005432949284	A79032	4045 154596	TATYANA ORLOVA	{"email": "orlovat_041969@postgrespro.ru", "phone": "+70069378648"}
0005432949285	A79032	1857 499722	RINAT SERGEEV	{"phone": "+70977780974"}
0005432949286	DEE287	7958 575400	TAMARA ZAKHAROVA	{"email": "tzakharova_05071976@postgrespro.ru", "phone": "+70287755539"}
0005432949287	2C3E5F	9427 864042	SVETLANA MAKAROVA	{"phone": "+70295585892"}
0005432949288	DFC033	3583 239730	ELENA KUDRYASHOVA	{"email": "e-kudryashova051973@postgrespro.ru", "phone": "+70156232326"}
0005432949289	317D0C	3860 036996	SERGEY ZAYCEV	{"phone": "+70507807033"}
0005432949290	D59FCA	4670 940399	LYUDMILA KARPOVA	{"phone": "+70039324087"}
0005432949291	76D2C7	9926 915495	OLGA GRISHINA	{"email": "o-grishina.1968@postgrespro.ru", "phone": "+70654392342"}
0005432949292	C5592D	1335 697207	ANNA MELNIKOVA	{"email": "anna_melnikova.1969@postgrespro.ru", "phone": "+70469292658"}
0005432949293	C5592D	6077 096620	GALINA GUSEVA	{"phone": "+70230248479"}
0005432949294	5A437E	3266 710307	NINA PAVLOVA	{"phone": "+70780284946"}
0005432949295	89CF4C	5782 777700	IVAN FILIPPOV	{"phone": "+70117584736"}
0005432949296	8FFC6A	3231 891779	MARIYA IVANOVA	{"email": "ivanova.m_17031969@postgrespro.ru", "phone": "+70438634180"}
0005432949297	8FFC6A	6385 627485	VERA MOISEEVA	{"phone": "+70288887178"}
0005432949298	63FC1D	5380 531420	ELENA POPOVA	{"email": "e_popova-011983@postgrespro.ru", "phone": "+70552165917"}
0005432949299	1FF7DF	3683 660735	LYUBOV MALYSHEVA	{"phone": "+70454643684"}
0005432949300	67B260	0441 768127	ALEKSANDRA ROMANOVA	{"email": "aromanova_08021969@postgrespro.ru", "phone": "+70580393581"}
0005432949301	3019CE	9837 958848	LYUBOV NOVIKOVA	{"phone": "+70898217450"}
0005432949302	17ABCD	8437 927946	ILYA ROMANOV	{"email": "i.romanov021971@postgrespro.ru", "phone": "+70235780778"}
0005432949303	F50D85	2613 101083	ALEKSEY IVANOV	{"phone": "+70656712328"}
0005432949304	BCF5E6	3255 971816	IVAN KAZAKOV	{"phone": "+70043096602"}
0005432949305	BCF5E6	1433 823655	VALENTINA ABRAMOVA	{"email": "abramova.valentina-121974@postgrespro.ru", "phone": "+70771058388"}
0005432949306	8A12C6	1815 425943	LIDIYA SMIRNOVA	{"phone": "+70548915058"}
0005432949307	8A12C6	6631 788686	SERGEY DENISOV	{"phone": "+70731329921"}
0005432949308	C9B5CD	7485 023801	ELENA ILINA	{"phone": "+70875363621"}
0005432949309	C9B5CD	2442 364820	EVDOKIYA NIKOLAEVA	{"email": "nikolaeva_evdokiya011978@postgrespro.ru", "phone": "+70042481196"}
0005432949310	EFEFEA	9429 466854	NIKOLAY PAVLOV	{"phone": "+70086125019"}
0005432949311	4DB703	6393 048065	KRISTINA KISELEVA	{"phone": "+70894498129"}
0005432949312	B47CFC	4521 191415	ALEKSEY BELOV	{"email": "belov_a.071973@postgrespro.ru", "phone": "+70544130733"}
0005432949313	9C2FFF	5983 778496	KLAVDIYA SCHERBAKOVA	{"email": "k_scherbakova_1972@postgrespro.ru", "phone": "+70735163631"}
0005432949314	9C2FFF	1787 726023	ANATOLIY SEMENOV	{"email": "anatoliy_semenov_1967@postgrespro.ru", "phone": "+70279339724"}
0005432949315	ADD5EB	9432 253733	ELENA GORBUNOVA	{"phone": "+70656579722"}
0005432949316	ADD5EB	8905 641367	SVETLANA EGOROVA	{"email": "egorova_s051980@postgrespro.ru", "phone": "+70823258472"}
0005432949317	6589E4	9962 568218	SERGEY KUZMIN	{"phone": "+70165684246"}
0005432949318	418639	6979 696382	LYUBOV OSIPOVA	{"email": "lyubov.osipova_09061985@postgrespro.ru", "phone": "+70589651334"}
0005432949319	E6F121	4833 272761	LYUBOV PETROVA	{"phone": "+70721248367"}
0005432949320	E6F121	9642 708385	ULYANA SOKOLOVA	{"phone": "+70232045866"}
0005432949321	296246	3009 417926	ARSEN MIKHAYLOV	{"phone": "+70341780339"}
0005432949322	0F815B	9861 691460	VLADIMIR PAVLOV	{"email": "pavlovv_081968@postgrespro.ru", "phone": "+70257689576"}
0005432949323	0F815B	2511 975672	VALERIY STEPANOV	{"phone": "+70048670541"}
0005432949324	5C2902	5790 872130	IGOR EGOROV	{"email": "i.egorov1976@postgrespro.ru", "phone": "+70062958590"}
0005432949325	826BF6	0167 153660	SERGEY FROLOV	{"phone": "+70505066651"}
0005432949326	826BF6	3953 588977	VLADIMIR GAVRILOV	{"email": "v_gavrilov051969@postgrespro.ru", "phone": "+70848222022"}
0005432949327	826BF6	8525 181168	ANTONINA SEMENOVA	{"email": "asemenova.071968@postgrespro.ru", "phone": "+70401605821"}
0005432949328	5BBD0A	9786 885658	GALINA GRISHINA	{"email": "grishina_galina20081968@postgrespro.ru", "phone": "+70494628674"}
0005432949329	BB3810	1987 945808	VLADIMIR MARTYNOV	{"email": "vladimirmartynov.071969@postgrespro.ru", "phone": "+70916276393"}
0005432949330	7658B1	2727 414845	IRINA TIMOFEEVA	{"phone": "+70336969026"}
0005432949331	7658B1	0227 264998	MAKSIM GAVRILOV	{"phone": "+70241147842"}
0005432949332	F5D2E8	0620 027204	VLADIMIR TIKHONOV	{"phone": "+70453978785"}
0005432949333	C65460	5513 023604	YURIY VASILEV	{"email": "vasilevy-1979@postgrespro.ru", "phone": "+70758021545"}
0005432949334	C65460	1775 907393	LYUBOV TIKHONOVA	{"email": "tikhonoval.11011981@postgrespro.ru", "phone": "+70563303467"}
0005432949335	742818	3635 476808	ELENA FOMINA	{"email": "fomina_elena18051968@postgrespro.ru", "phone": "+70254316287"}
0005432949336	637FEE	4224 041219	ELENA BELYAEVA	{"email": "elena_belyaeva-021968@postgrespro.ru", "phone": "+70864662251"}
0005432949337	C7A054	3658 903039	NATALYA KUZNECOVA	{"phone": "+70530499549"}
0005432949338	C7A054	2717 645161	VALENTINA BELOVA	{"phone": "+70185274477"}
0005432949339	127B01	1666 614122	VLADIMIR NOVIKOV	{"email": "novikov-vladimir.071969@postgrespro.ru", "phone": "+70279981227"}
0005432949340	F15C8B	3380 638500	SERGEY SCHERBAKOV	{"phone": "+70993810745"}
0005432949341	61DB8A	8641 594882	YURIY MOROZOV	{"email": "y-morozov_021973@postgrespro.ru", "phone": "+70984865412"}
0005432949342	594D05	0869 182591	TATYANA SIDOROVA	{"phone": "+70371190193"}
0005432949343	594D05	6817 659177	ANTON SAVELEV	{"email": "a.savelev051973@postgrespro.ru", "phone": "+70968757107"}
0005432949344	8A028A	8692 469622	VASILIY PETROV	{"email": "petrov-vasiliy.30081972@postgrespro.ru", "phone": "+70913360959"}
0005432949345	F1D558	5084 212855	YULIYA ZAKHAROVA	{"phone": "+70350761053"}
0005432949346	B8E53D	8950 264269	ILYA IVANOV	{"email": "ivanovi11121974@postgrespro.ru", "phone": "+70920810308"}
0005432949347	1D2CC2	2265 685862	GENNADIY ZAKHAROV	{"phone": "+70836949244"}
0005432949348	2E6CAF	4223 585430	LYUDMILA KARPOVA	{"email": "karpovalyudmila_19111982@postgrespro.ru", "phone": "+70924724081"}
0005432949349	7E7764	2130 581744	NIKOLAY ROMANOV	{"phone": "+70635414604"}
0005432949350	E3D9A7	1212 524582	EKATERINA CHERNOVA	{"email": "ekaterina-chernova1982@postgrespro.ru", "phone": "+70297661082"}
0005432949351	4C6849	3636 886677	ANDREY VOLKOV	{"email": "a.volkov-1965@postgrespro.ru", "phone": "+70303280908"}
0005432949352	4C6849	8881 074000	ALEKSANDR MIRONOV	{"phone": "+70371120892"}
0005432949353	DC4FC6	7188 711636	ROMAN MEDVEDEV	{"email": "medvedevr_1965@postgrespro.ru", "phone": "+70988268456"}
0005432949354	DC4FC6	8276 819655	IRINA KUZNECOVA	{"phone": "+70747822566"}
0005432949355	0BC946	0398 160850	OLGA AFANASEVA	{"phone": "+70446724760"}
0005432949356	C57E7C	1556 610542	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova-081975@postgrespro.ru", "phone": "+70852029140"}
0005432949357	C57E7C	0073 036547	SERGEY KOROLEV	{"phone": "+70712820485"}
0005432949358	1945A4	2574 344828	YURIY KOROLEV	{"phone": "+70123059924"}
0005432949359	1945A4	7898 883701	VARVARA NIKOLAEVA	{"phone": "+70337893485"}
0005432949360	671B21	3231 128570	TIMUR SOLOVEV	{"email": "timur.solovev_1972@postgrespro.ru", "phone": "+70127697431"}
0005432949361	671B21	2628 435426	OLGA MOISEEVA	{"phone": "+70622932812"}
0005432949362	85A962	7916 767717	VIKTOR ANDREEV	{"phone": "+70724724231"}
0005432949363	85A962	0917 822762	VALERIY SHEVCHENKO	{"phone": "+70532503654"}
0005432949364	F42F53	5584 067354	ANDREY ABRAMOV	{"phone": "+70802082937"}
0005432949365	C79FC1	1048 398201	ALEKSEY FROLOV	{"email": "frolov-aleksey-1965@postgrespro.ru", "phone": "+70604179096"}
0005432949366	296D29	1950 473043	VIKTOR KOZLOV	{"phone": "+70876798868"}
0005432949367	E1E530	4644 986977	SABINA SAVELEVA	{"phone": "+70112016783"}
0005432949368	E1E530	3210 278676	VIKTOR POPOV	{"email": "viktor_popov-16031966@postgrespro.ru", "phone": "+70957729485"}
0005432949369	17646B	7206 825605	IRINA BORISOVA	{"phone": "+70481281247"}
0005432949370	17646B	5887 818249	NATALYA VOROBEVA	{"email": "n.vorobeva_061987@postgrespro.ru", "phone": "+70821261312"}
0005432949371	ABA8A2	3710 838061	VYACHESLAV ZHURAVLEV	{"phone": "+70636861902"}
0005432949372	ABA8A2	4344 947348	NATALYA NAUMOVA	{"email": "naumova_natalya-081972@postgrespro.ru", "phone": "+70717159885"}
0005432949373	ABA8A2	7918 314622	IRINA KUZMINA	{"email": "irinakuzmina_1972@postgrespro.ru", "phone": "+70402657717"}
0005432949374	F5D549	8748 685191	VARVARA GRISHINA	{"email": "varvaragrishina.041982@postgrespro.ru", "phone": "+70257727732"}
0005432949375	371046	2848 317007	MIKHAIL MARTYNOV	{"phone": "+70528578861"}
0005432949376	D87E84	8954 015792	YANA NAZAROVA	{"email": "nazarova-yana-25031960@postgrespro.ru", "phone": "+70906893534"}
0005432949377	DC46E9	2688 761209	YULIYA NIKOLAEVA	{"phone": "+70741909599"}
0005432949378	DC46E9	9939 801574	VERA MAKAROVA	{"email": "makarovavera_031964@postgrespro.ru", "phone": "+70274212042"}
0005432949379	21776D	9272 414346	ANDREY SAVELEV	{"phone": "+70010230186"}
0005432949380	DC44DC	9637 338263	ELDAR POPOV	{"email": "popov-e.07081970@postgrespro.ru", "phone": "+70301437825"}
0005432949381	DC44DC	9187 539997	LYUDMILA IVANOVA	{"email": "ivanovalyudmila.27121973@postgrespro.ru", "phone": "+70851543729"}
0005432949382	34E519	9475 007979	VALENTINA SEMENOVA	{"email": "valentina_semenova-23031961@postgrespro.ru", "phone": "+70040343731"}
0005432949383	8C92AF	1455 140909	EKATERINA IVANOVA	{"email": "ivanova_ekaterina.1960@postgrespro.ru", "phone": "+70223609340"}
0005432949384	2D01B2	6053 883069	ELENA SOKOLOVA	{"email": "elena-sokolova091961@postgrespro.ru", "phone": "+70518288807"}
0005432949385	2D01B2	8092 021773	ALEKSANDR SMIRNOV	{"phone": "+70120606993"}
0005432949386	086D70	3110 055523	PAVEL YAKOVLEV	{"email": "yakovlev.pavel.1968@postgrespro.ru", "phone": "+70457548294"}
0005432949387	36A5FF	6729 438618	ALEKSANDRA SMIRNOVA	{"phone": "+70770319618"}
0005432949388	36A5FF	6615 557958	IRINA MATVEEVA	{"phone": "+70651908859"}
0005432949389	36A5FF	7325 638078	ANASTASIYA OVCHINNIKOVA	{"phone": "+70485422406"}
0005432949390	33994C	3982 108459	VIKTOR IVANOV	{"phone": "+70951661137"}
0005432949391	B9790C	4939 219289	ALEKSANDR KUZNECOV	{"email": "akuznecov_1984@postgrespro.ru", "phone": "+70746170818"}
0005432949392	B9790C	3689 146933	EVGENIY MATVEEV	{"phone": "+70222899501"}
0005432949393	1A89CA	4940 407737	ALEKSEY KISELEV	{"phone": "+70843729177"}
0005432949394	2F6E95	8204 764616	ALEKSANDR DAVYDOV	{"phone": "+70654340870"}
0005432949395	0C8B4D	6957 045219	VIKTOR NOVIKOV	{"email": "novikovviktor-01111967@postgrespro.ru", "phone": "+70268784320"}
0005432949396	5661F8	8575 785174	GALINA KUZNECOVA	{"email": "kuznecova-galina-18031965@postgrespro.ru", "phone": "+70405805848"}
0005432949397	7B135F	0253 929660	ANATOLIY SHEVCHENKO	{"email": "anatoliy_shevchenko_28101976@postgrespro.ru", "phone": "+70236509982"}
0005432949398	76A899	6884 031896	NATALYA ZOTOVA	{"email": "zotova-n-021960@postgrespro.ru", "phone": "+70171936965"}
0005432949399	62C119	7927 074728	IVAN MAKAROV	{"email": "ivan-makarov-15051985@postgrespro.ru", "phone": "+70374405878"}
0005432949400	848B5B	7051 257149	ANASTASIYA NIKITINA	{"phone": "+70271079448"}
0005432949401	C81C90	3974 783831	IVAN MARTYNOV	{"phone": "+70342779530"}
0005432949402	589E91	6073 348446	ARTEM MAKSIMOV	{"phone": "+70845369747"}
0005432949403	589E91	7554 998616	KIRILL ANDREEV	{"email": "andreev.kirill-041965@postgrespro.ru", "phone": "+70151656942"}
0005432949404	F87B75	9269 139270	OLGA OSIPOVA	{"email": "osipova-o_1973@postgrespro.ru", "phone": "+70542986357"}
0005432949405	E1A680	1574 841218	MARIYA IVANOVA	{"phone": "+70087515659"}
0005432949406	1573A5	2857 210719	ALEKSEY NIKITIN	{"email": "nikitina04011977@postgrespro.ru", "phone": "+70731148533"}
0005432949407	EFBC59	1386 584052	VITALIY ALEKSEEV	{"email": "v.alekseev111973@postgrespro.ru", "phone": "+70595828344"}
0005432949408	2F46E5	1191 759494	VALERIY POPOV	{"email": "vpopov.031970@postgrespro.ru", "phone": "+70816513280"}
0005432949409	CC01F3	6488 647256	LIDIYA PETROVA	{"email": "lidiyapetrova1978@postgrespro.ru", "phone": "+70131977086"}
0005432949410	0FE22D	9467 927665	ELMIRA KUZNECOVA	{"email": "kuznecova_elmira.021978@postgrespro.ru", "phone": "+70839183334"}
0005432949411	C9DF8F	0212 533595	ALEKSEY ZAKHAROV	{"phone": "+70888483949"}
0005432949412	C9DF8F	7573 118244	SERGEY SERGEEV	{"email": "ssergeev-22051977@postgrespro.ru", "phone": "+70687936606"}
0005432949413	0791E8	2368 438325	VLADIMIR VOLKOV	{"phone": "+70460445375"}
0005432949414	A9C4E8	8131 626059	BORIS KUZNECOV	{"email": "boris.kuznecov13041982@postgrespro.ru", "phone": "+70050085567"}
0005432949415	C522F4	4426 834111	NIKOLAY STEPANOV	{"phone": "+70114606963"}
0005432949416	C522F4	2128 539691	OKSANA KOVALEVA	{"email": "o_kovaleva_1972@postgrespro.ru", "phone": "+70688464851"}
0005432949417	C1F9E7	8904 848535	SVETLANA ZHURAVLEVA	{"phone": "+70204333677"}
0005432949418	18B514	0208 583006	ALEKSANDRA VOLKOVA	{"email": "volkovaa-19021969@postgrespro.ru", "phone": "+70456326081"}
0005432949419	18B514	8849 504984	NIKOLAY ANTONOV	{"phone": "+70492795792"}
0005432949420	E4C98E	6356 631349	ALEKSANDR MIRONOV	{"email": "a_mironov.071977@postgrespro.ru", "phone": "+70853341576"}
0005432949421	628EEB	5645 520011	OLESYA MAKAROVA	{"phone": "+70100309520"}
0005432949422	284C53	5381 301498	NATALYA NAZAROVA	{"phone": "+70732243421"}
0005432949423	284C53	3889 957790	VYACHESLAV PAVLOV	{"phone": "+70436666312"}
0005432949424	4A99E3	9117 497927	ALEKSEY DMITRIEV	{"email": "a-dmitriev.16081966@postgrespro.ru", "phone": "+70972834689"}
0005432949425	3DA014	8189 505652	MAKSIM GUSEV	{"email": "gusevmaksim_29091964@postgrespro.ru", "phone": "+70718592141"}
0005432949426	3DA014	8434 495963	MARIYA MELNIKOVA	{"email": "m.melnikova.011980@postgrespro.ru", "phone": "+70585775211"}
0005432949427	F7A86E	6537 449343	LIDIYA NAUMOVA	{"phone": "+70291378883"}
0005432949428	236C76	5287 175867	VIKTOR KUZNECOV	{"phone": "+70616916080"}
0005432949429	344D2C	9066 240101	ROMAN IVANOV	{"phone": "+70587812524"}
0005432949430	4A2B33	1673 495599	GENNADIY VOLKOV	{"phone": "+70738747587"}
0005432949431	34BACE	0621 938944	VALERIY PETROV	{"phone": "+70668969906"}
0005432949432	6F1C06	9710 812104	TATYANA IVANOVA	{"email": "tatyana.ivanova30071982@postgrespro.ru", "phone": "+70536106710"}
0005432949433	A85779	0905 794009	DENIS VOLKOV	{"email": "volkov.d.24081973@postgrespro.ru", "phone": "+70902231692"}
0005432949434	E0C85E	1784 436161	TATYANA KISELEVA	{"phone": "+70759590835"}
0005432949435	4AD838	3715 474733	VALENTINA POLYAKOVA	{"email": "valentina_polyakova1961@postgrespro.ru", "phone": "+70753652710"}
0005432949436	4AD838	6733 861418	SERGEY VASILEV	{"phone": "+70718704279"}
0005432949437	74E356	5324 510835	ELIZAVETA SEMENOVA	{"email": "elizaveta-semenova-17041970@postgrespro.ru", "phone": "+70396437213"}
0005432949438	74E356	0217 106843	ALEKSANDR KOROLEV	{"email": "koroleva_1969@postgrespro.ru", "phone": "+70265327586"}
0005432949439	74E356	3852 375047	NATALYA MOROZOVA	{"phone": "+70841687828"}
0005432949440	5B4E9B	6812 997384	NIKOLAY NAZAROV	{"email": "nazarovn.011962@postgrespro.ru", "phone": "+70030884508"}
0005432949441	5B4E9B	4817 816333	ALEKSANDR MOROZOV	{"phone": "+70070070078"}
0005432949442	FF0FDA	6352 940957	MARINA IVANOVA	{"email": "m-ivanova.13101973@postgrespro.ru", "phone": "+70498921298"}
0005432949443	6463F6	2501 590469	LYUDMILA ISAEVA	{"email": "lyudmila-isaeva_23071972@postgrespro.ru", "phone": "+70087083941"}
0005432949444	00CCC6	3083 301487	VLADIMIR ANTONOV	{"phone": "+70662559256"}
0005432949445	F4E382	2379 611295	VLADISLAV ZAKHAROV	{"email": "zakharov-v-051977@postgrespro.ru", "phone": "+70283589645"}
0005432949446	D0B7CF	2378 115706	ALEKSANDR MEDVEDEV	{"email": "a.medvedev_031963@postgrespro.ru", "phone": "+70435223321"}
0005432949447	4BA4E2	7293 173079	LYUDMILA KISELEVA	{"email": "kiseleva-lyudmila-1966@postgrespro.ru", "phone": "+70938359918"}
0005432949448	4BA4E2	0893 552791	YULIYA MELNIKOVA	{"phone": "+70318116285"}
0005432949449	24EC60	3713 901261	ALEKSANDR ISAEV	{"email": "aleksandr.isaev-1966@postgrespro.ru", "phone": "+70796405854"}
0005432949450	5F6438	9719 304971	DMITRIY DMITRIEV	{"email": "dmitriev.d.1956@postgrespro.ru", "phone": "+70140472461"}
0005432949451	B9D296	5460 920178	ELENA PETROVA	{"email": "e.petrova-111974@postgrespro.ru", "phone": "+70546672082"}
0005432949452	00CA8B	9114 617372	MARGARITA VASILEVA	{"phone": "+70642504685"}
0005432949453	66885F	7831 727677	MARIYA KOZLOVA	{"phone": "+70347411320"}
0005432949454	718823	8586 256197	LARISA LAZAREVA	{"email": "lazarevalarisa_15011967@postgrespro.ru", "phone": "+70859739190"}
0005432949455	8B86E6	1085 418103	IRINA ANDREEVA	{"phone": "+70674475410"}
0005432949456	C06CB7	1680 127828	RUSLAN KULIKOV	{"email": "kulikovruslan-1963@postgrespro.ru", "phone": "+70153094854"}
0005432949457	EA4811	4887 574363	PAVEL POPOV	{"phone": "+70477992936"}
0005432949458	02A990	7032 059707	MAKSIM SMIRNOV	{"phone": "+70141941101"}
0005432949459	3987EE	7070 069767	NATALYA ALEKSEEVA	{"email": "alekseeva-natalya-081959@postgrespro.ru", "phone": "+70219443805"}
0005432949460	3987EE	5804 747970	ALEKSANDR AFANASEV	{"phone": "+70078119387"}
0005432949461	A076C9	4823 271510	LARISA BORISOVA	{"email": "l_borisova_05051981@postgrespro.ru", "phone": "+70655671174"}
0005432949462	A076C9	7577 240113	ELENA PAVLOVA	{"email": "pavlova_e031981@postgrespro.ru", "phone": "+70017083243"}
0005432949463	A076C9	3269 856666	MIKHAIL SEMENOV	{"phone": "+70371163889"}
0005432949464	1659BA	4735 970181	TATYANA MASLOVA	{"email": "maslova.tatyana1968@postgrespro.ru", "phone": "+70925827621"}
0005432949465	00C8E8	7128 319932	EKATERINA NESTEROVA	{"email": "nesterova_e-1976@postgrespro.ru", "phone": "+70644799341"}
0005432949466	00C8E8	4425 365992	SERGEY MAKAROV	{"email": "sergeymakarov15081973@postgrespro.ru", "phone": "+70897338909"}
0005432949467	90AA27	0115 330147	TATYANA BELOVA	{"phone": "+70616113739"}
0005432949468	3B1C2E	2515 367381	VLADISLAV NAZAROV	{"email": "nazarov-v17031977@postgrespro.ru", "phone": "+70500108116"}
0005432949469	0762F9	8023 880158	OLGA NESTEROVA	{"email": "nesterova-o-1969@postgrespro.ru", "phone": "+70263643837"}
0005432949581	3ABA2F	1436 235663	ELMIRA ANDREEVA	{"phone": "+70592920690"}
0005432949470	E9365B	4124 527567	VLADIMIR MOISEEV	{"email": "vladimir_moiseev_02041978@postgrespro.ru", "phone": "+70620219629"}
0005432949471	E9365B	5278 306920	ALEKSEY STEPANOV	{"email": "astepanov.081979@postgrespro.ru", "phone": "+70934948467"}
0005432949472	D3591D	5417 758164	KONSTANTIN NAUMOV	{"email": "naumov_konstantin-28051979@postgrespro.ru", "phone": "+70755577112"}
0005432949473	A3CE9A	7945 087480	FARIT MAKSIMOV	{"phone": "+70559503441"}
0005432949474	A3CE9A	5930 576043	ALEKSANDR GERASIMOV	{"phone": "+70840845719"}
0005432949475	A3CE9A	5400 286576	PETR BARANOV	{"email": "baranovp-1972@postgrespro.ru", "phone": "+70564876025"}
0005432949476	2B0A84	0589 855133	PAVEL FROLOV	{"email": "p-frolov.01091977@postgrespro.ru", "phone": "+70967105052"}
0005432949477	2B0A84	0989 230244	VLADIMIR NIKITIN	{"phone": "+70693644751"}
0005432949478	2B0A84	8329 858165	ELENA VLASOVA	{"email": "vlasova_e.061985@postgrespro.ru", "phone": "+70143748191"}
0005432949479	B2EB70	1033 265553	OLGA MIKHAYLOVA	{"email": "o.mikhaylova_1977@postgrespro.ru", "phone": "+70668577950"}
0005432949480	1957E7	7553 610588	ELVIRA KONOVALOVA	{"phone": "+70772096631"}
0005432949481	1957E7	3856 953885	VLADIMIR NIKITIN	{"phone": "+70578617343"}
0005432949482	D7BE5C	6585 021600	GENNADIY VASILEV	{"email": "gennadiy-vasilev1971@postgrespro.ru", "phone": "+70832417300"}
0005432949483	42FFAD	7141 367651	ALEKSANDR SHEVCHENKO	{"phone": "+70505744719"}
0005432949484	42FFAD	8684 961933	PAVEL STEPANOV	{"phone": "+70111620420"}
0005432949485	42FFAD	1766 612006	EVGENIY IVANOV	{"phone": "+70318187210"}
0005432949486	CCCB0C	1986 227337	ANDREY ZAKHAROV	{"email": "andreyzakharov-1966@postgrespro.ru", "phone": "+70262829895"}
0005432949487	CCCB0C	9423 917685	ALEKSANDR ANTONOV	{"phone": "+70926924980"}
0005432949488	3933F2	4388 372680	ALEKSANDR ISAEV	{"email": "isaev.aleksandr041966@postgrespro.ru", "phone": "+70087783873"}
0005432949489	61649A	7910 111186	OLEG MAKAROV	{"phone": "+70417575958"}
0005432949490	61649A	6909 111534	NATALYA MOROZOVA	{"phone": "+70933239826"}
0005432949491	86E7D8	0969 667156	MIKHAIL KISELEV	{"email": "mkiselev_04091976@postgrespro.ru", "phone": "+70117000695"}
0005432949492	0490E2	4650 883480	VIKTOR TIKHONOV	{"email": "tikhonov-v-23071978@postgrespro.ru", "phone": "+70422107783"}
0005432949493	B4906D	3151 391599	ALEKSEY STEPANOV	{"email": "aleksey_stepanov-29041971@postgrespro.ru", "phone": "+70517988089"}
0005432949494	F506B5	1709 751733	IRINA KUZNECOVA	{"email": "kuznecova-irina1976@postgrespro.ru", "phone": "+70926721039"}
0005432949495	CFFF18	1972 396688	NIKOLAY KONOVALOV	{"phone": "+70167800832"}
0005432949496	CFFF18	4478 314592	ALEKSEY EGOROV	{"email": "egorov_aleksey.031974@postgrespro.ru", "phone": "+70357642394"}
0005432949497	CDB063	1381 021202	VYACHESLAV SAVELEV	{"phone": "+70251766228"}
0005432949498	342B92	9221 185622	DMITRIY ROMANOV	{"email": "dmitriyromanov1967@postgrespro.ru", "phone": "+70336948894"}
0005432949499	342B92	3007 889790	LIDIYA TIKHONOVA	{"phone": "+70894464057"}
0005432949500	E2CA81	3449 404335	DMITRIY KOROLEV	{"email": "korolev_d-021973@postgrespro.ru", "phone": "+70770303105"}
0005432949501	461785	5487 708049	NIKOLAY RODIONOV	{"phone": "+70405431821"}
0005432949502	461785	8595 080089	VITALIY ZAKHAROV	{"phone": "+70739990341"}
0005432949503	737045	4112 517343	NATALYA PAVLOVA	{"email": "pavlova-natalya-1971@postgrespro.ru", "phone": "+70055481692"}
0005432949504	E04639	4426 026976	ELENA SOLOVEVA	{"email": "solovevaelena031968@postgrespro.ru", "phone": "+70452000226"}
0005432949505	E04639	9780 110790	ALEKSANDR YAKOVLEV	{"phone": "+70690235417"}
0005432949506	080823	9031 867192	SVETLANA KISELEVA	{"email": "kiselevas.111968@postgrespro.ru", "phone": "+70840462074"}
0005432949507	080823	7862 040996	ALEKSANDR ZAKHAROV	{"phone": "+70617992090"}
0005432949508	AACA91	1541 218264	MAKSIM BELOV	{"phone": "+70857199113"}
0005432949509	E8513C	8565 102176	POLINA ZHUKOVA	{"phone": "+70752967240"}
0005432949510	E8513C	9631 471940	ALEKSEY KOROLEV	{"phone": "+70683203062"}
0005432949511	211F49	3523 995623	ALBINA FEDOROVA	{"phone": "+70849215161"}
0005432949512	5F78C6	2092 510084	ANNA ZOTOVA	{"phone": "+70643854722"}
0005432949513	CD7B73	5318 493504	ANDREY SCHERBAKOV	{"phone": "+70135481964"}
0005432949514	CD7B73	4040 069760	ALEKSEY SHEVCHENKO	{"phone": "+70719069593"}
0005432949515	E27F24	8072 776857	IGOR TARASOV	{"email": "tarasov-i081962@postgrespro.ru", "phone": "+70404211388"}
0005432949516	E27F24	0351 426407	VALENTINA KALININA	{"phone": "+70624480191"}
0005432949517	776F89	3901 209983	MARIYA LEBEDEVA	{"email": "lebedeva-m-1975@postgrespro.ru", "phone": "+70315150071"}
0005432949518	776F89	8668 776918	OLGA POPOVA	{"phone": "+70597116199"}
0005432949519	776F89	9750 117299	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.1975@postgrespro.ru", "phone": "+70051120260"}
0005432949520	63A9DF	9138 873080	VERA KUZNECOVA	{"email": "kuznecova.v101974@postgrespro.ru", "phone": "+70647847668"}
0005432949521	7F4725	6418 456243	ALEKSEY ZAYCEV	{"email": "zaycevaleksey_101977@postgrespro.ru", "phone": "+70487370697"}
0005432949522	B38713	1788 656293	IVAN MOROZOV	{"email": "morozov.ivan.061975@postgrespro.ru", "phone": "+70302597590"}
0005432949523	228B8B	6555 016084	ALEKSEY NAUMOV	{"email": "naumov.aleksey.1973@postgrespro.ru", "phone": "+70720600524"}
0005432949524	228B8B	6618 868801	VLADIMIR OSIPOV	{"phone": "+70680535459"}
0005432949525	F127BA	9207 167850	ELIZAVETA KISELEVA	{"email": "ekiseleva121972@postgrespro.ru", "phone": "+70292530994"}
0005432949526	E2E0CA	6705 712020	ALEKSANDR IVANOV	{"email": "a_ivanov_081975@postgrespro.ru", "phone": "+70652968864"}
0005432949527	E2E0CA	0503 939421	NURLAN BONDARENKO	{"phone": "+70049782945"}
0005432949528	DF9CA2	9211 693520	VIKTOR FEDOTOV	{"phone": "+70714046701"}
0005432949529	02CCE9	5017 933047	ILYA NIKOLAEV	{"phone": "+70737785254"}
0005432949530	157580	7398 489587	YURIY RODIONOV	{"phone": "+70634967331"}
0005432949531	157580	6071 115148	SERGEY POPOV	{"email": "popov_s111975@postgrespro.ru", "phone": "+70057910341"}
0005432949532	4CB1C7	4363 349708	NADEZHDA ROMANOVA	{"email": "romanova-nadezhda20031969@postgrespro.ru", "phone": "+70869221459"}
0005432949533	4CB1C7	1357 917056	ELENA KUZNECOVA	{"email": "elena-kuznecova_1973@postgrespro.ru", "phone": "+70047815677"}
0005432949534	67C8D1	6865 885319	MAKSIM FILIPPOV	{"email": "filippov-m.1971@postgrespro.ru", "phone": "+70807971022"}
0005432949535	67C8D1	7319 927254	VALERIYA NIKOLAEVA	{"email": "nikolaevavaleriya-13031966@postgrespro.ru", "phone": "+70052535538"}
0005432949536	FD7F3E	1504 418150	EVGENIYA KOROLEVA	{"email": "koroleva-evgeniya051974@postgrespro.ru", "phone": "+70730015715"}
0005432949537	FD7F3E	9937 675605	NATALIYA MOROZOVA	{"email": "nataliya-morozova_27011966@postgrespro.ru", "phone": "+70942169675"}
0005432949538	67B52C	6694 759329	VALERIYA STEPANOVA	{"email": "stepanova-valeriya-20081960@postgrespro.ru", "phone": "+70608503474"}
0005432949539	67B52C	3100 797648	ANASTASIYA BELYAEVA	{"phone": "+70803524910"}
0005432949540	1BAF88	7633 480833	DENIS GORBUNOV	{"phone": "+70229846770"}
0005432949541	1BAF88	8358 146020	BORIS VASILEV	{"email": "borisvasilev_031978@postgrespro.ru", "phone": "+70226570370"}
0005432949542	BB82CE	0628 177986	ANZHELIKA KUZNECOVA	{"email": "kuznecovaanzhelika11011980@postgrespro.ru", "phone": "+70215016559"}
0005432949543	BB82CE	3037 658777	VLADIMIR STEPANOV	{"email": "stepanov-vladimir-1976@postgrespro.ru", "phone": "+70820264874"}
0005432949544	BB82CE	0143 706069	LYUBOV ZAKHAROVA	{"email": "lyubov-zakharova-12031981@postgrespro.ru", "phone": "+70944274015"}
0005432949545	343936	7573 306455	TAISIYA AKIMOVA	{"email": "t-akimova-1966@postgrespro.ru", "phone": "+70133898361"}
0005432949546	D2EE4F	1844 810204	ALEKSANDR SEMENOV	{"phone": "+70798417521"}
0005432949547	96EE1D	8055 411517	OLGA NAZAROVA	{"email": "onazarova.27031970@postgrespro.ru", "phone": "+70302961453"}
0005432949548	52BC93	7179 054931	ARTEM ILIN	{"email": "ilin_a061988@postgrespro.ru", "phone": "+70096918105"}
0005432949549	52BC93	7754 224176	ALEKSANDR CHERNOV	{"phone": "+70412840863"}
0005432949550	179067	1447 849950	ELENA KOZLOVA	{"email": "kozlova.elena_1957@postgrespro.ru", "phone": "+70091051992"}
0005432949551	B55769	9451 400970	TIMUR ILIN	{"email": "timur.ilin1970@postgrespro.ru", "phone": "+70510335542"}
0005432949552	FF69DA	3928 106664	LARISA VLASOVA	{"email": "lvlasova.1966@postgrespro.ru", "phone": "+70963273303"}
0005432949553	A8E3FC	4780 695867	TATYANA MAKSIMOVA	{"phone": "+70754863446"}
0005432949554	BDC09F	6781 922860	VLADIMIR KULIKOV	{"phone": "+70757825286"}
0005432949555	536B60	8600 333300	VIKTOR ORLOV	{"email": "v_orlov.22031977@postgrespro.ru", "phone": "+70566442118"}
0005432949556	536B60	4534 648742	VALERIYA STEPANOVA	{"phone": "+70328221773"}
0005432949557	4AF0A3	6511 372003	DARYA ORLOVA	{"email": "orlova-d_31031968@postgrespro.ru", "phone": "+70385970572"}
0005432949558	AAB911	7213 755072	ALEKSANDRA DENISOVA	{"phone": "+70544995581"}
0005432949559	AAB911	0590 505689	OLGA FROLOVA	{"email": "frolova-olga.26101962@postgrespro.ru", "phone": "+70000749459"}
0005432949560	7BCAD4	2047 507191	NATALYA KOROLEVA	{"phone": "+70473362229"}
0005432949561	0DAC62	8928 159179	NINA NIKOLAEVA	{"phone": "+70728601992"}
0005432949562	0DAC62	5610 026767	NIKOLAY SMIRNOV	{"phone": "+70100356991"}
0005432949563	767F53	9278 568757	TATYANA NIKOLAEVA	{"email": "nikolaeva.t-20111977@postgrespro.ru", "phone": "+70090515101"}
0005432949564	318652	2140 030895	MATVEY STEPANOV	{"phone": "+70000983790"}
0005432949565	318652	9381 061684	ANNA KOMAROVA	{"phone": "+70495899391"}
0005432949566	50FA58	5209 645861	ANASTASIYA NOVIKOVA	{"email": "novikovaa-1968@postgrespro.ru", "phone": "+70583757122"}
0005432949567	50FA58	8243 260496	IGOR FROLOV	{"email": "ifrolov-19081969@postgrespro.ru", "phone": "+70868686705"}
0005432949568	5712D9	1341 445482	IRINA ANDREEVA	{"phone": "+70922355687"}
0005432949569	5712D9	0094 818096	VIKTOR SMIRNOV	{"phone": "+70183102794"}
0005432949570	B67088	7301 610977	EVGENIYA MEDVEDEVA	{"phone": "+70240009360"}
0005432949571	B8870A	6664 647259	GALINA ANTONOVA	{"email": "gantonova.061964@postgrespro.ru", "phone": "+70674995288"}
0005432949572	21FC2F	7324 209405	SERGEY NOVIKOV	{"email": "sergey-novikov_1973@postgrespro.ru", "phone": "+70922951849"}
0005432949573	818FE6	5952 564905	ZAKHAR KUZNECOV	{"phone": "+70436955696"}
0005432949574	781453	2535 927776	VADIM SHEVCHENKO	{"email": "v.shevchenko111969@postgrespro.ru", "phone": "+70283021689"}
0005432949575	50B86E	5774 266115	VALERIYA GERASIMOVA	{"email": "gerasimova-valeriya.051985@postgrespro.ru", "phone": "+70326422043"}
0005432949576	7E54C2	3183 860491	IRINA TITOVA	{"email": "titova.i25101978@postgrespro.ru", "phone": "+70609427113"}
0005432949577	7E54C2	5734 342913	NATALYA POPOVA	{"email": "n-popova19081967@postgrespro.ru", "phone": "+70761195051"}
0005432949578	DC967E	9579 941727	VIKTORIYA ORLOVA	{"email": "v_orlova-1971@postgrespro.ru", "phone": "+70216517522"}
0005432949579	F03530	5873 121568	SERGEY VOLKOV	{"email": "sergey-volkov081983@postgrespro.ru", "phone": "+70030697756"}
0005432949580	3ABA2F	2143 005692	VLADISLAV SERGEEV	{"phone": "+70043929984"}
0005432949582	D5D4BE	4809 184685	OLGA ERMAKOVA	{"email": "ermakovaolga_1971@postgrespro.ru", "phone": "+70872959455"}
0005432949583	0C52A6	3680 913053	RAFAEL ILIN	{"phone": "+70140973137"}
0005432949584	FA59A7	3694 577282	VLADIMIR POPOV	{"email": "v.popov_061979@postgrespro.ru", "phone": "+70189640687"}
0005432949585	FA59A7	3833 403045	EVGENIY GORBUNOV	{"phone": "+70036849541"}
0005432949586	D507C8	8043 943703	ALEKSANDR VASILEV	{"phone": "+70571859017"}
0005432949587	D507C8	9231 412783	VALENTINA LEBEDEVA	{"email": "lebedeva_v.07031972@postgrespro.ru", "phone": "+70840200315"}
0005432949588	B4340D	2319 440956	EKATERINA BOGDANOVA	{"phone": "+70785746661"}
0005432949589	B4340D	2982 731290	SERGEY IVANOV	{"phone": "+70515133559"}
0005432949590	2482C1	9524 710283	NADEZHDA IVANOVA	{"email": "n-ivanova.19091962@postgrespro.ru", "phone": "+70874607032"}
0005432949591	CEFAB8	8862 234419	MAKSIM MAKAROV	{"email": "makarov-maksim.18081968@postgrespro.ru", "phone": "+70474301362"}
0005432949592	CEFAB8	5559 002511	ANASTASIYA AKIMOVA	{"email": "anastasiyaakimova_1970@postgrespro.ru", "phone": "+70052737394"}
0005432949593	CEFAB8	7658 925268	ANASTASIYA BELOVA	{"email": "anastasiyabelova1964@postgrespro.ru", "phone": "+70612894721"}
0005432949594	2800B5	1193 498496	NELLI POLYAKOVA	{"phone": "+70515868083"}
0005432949595	FD4B04	5121 057478	IRINA FILIPPOVA	{"email": "i_filippova.01081972@postgrespro.ru", "phone": "+70862118701"}
0005432949596	FD4B04	4016 431251	LIDIYA ABRAMOVA	{"email": "l-abramova.28081959@postgrespro.ru", "phone": "+70192528006"}
0005432949597	913A5A	1070 727219	ARTEM PETROV	{"email": "petrov_a-01071966@postgrespro.ru", "phone": "+70211124176"}
0005432949598	913A5A	2357 646244	VLADIMIR IVANOV	{"phone": "+70249842705"}
0005432949599	315117	0181 561948	YULIYA SEMENOVA	{"phone": "+70805946398"}
0005432949600	315117	4132 034971	VASILIY IVANOV	{"phone": "+70368552838"}
0005432949601	10367E	7732 820550	EVGENIYA SCHERBAKOVA	{"email": "evgeniya_scherbakova_091975@postgrespro.ru", "phone": "+70656067792"}
0005432949602	10367E	8917 632538	ANDREY FEDOROV	{"phone": "+70663172330"}
0005432949603	0231D6	4440 993016	VIKTOR GAVRILOV	{"email": "viktor-gavrilov1975@postgrespro.ru", "phone": "+70735215237"}
0005432949604	8239C9	7486 128289	ANATOLIY MAKAROV	{"phone": "+70497090771"}
0005432949605	96EAD8	8708 848987	DILYARA GORBUNOVA	{"email": "gorbunova_d-02041973@postgrespro.ru", "phone": "+70855291843"}
0005432949606	96EAD8	1007 344596	MARIYA PAVLOVA	{"email": "m.pavlova.17011980@postgrespro.ru", "phone": "+70514048016"}
0005432949607	3112F8	7227 445304	LYUDMILA VASILEVA	{"phone": "+70734403562"}
0005432949608	7C4736	0628 895735	ELENA OSIPOVA	{"email": "osipovaelena14081986@postgrespro.ru", "phone": "+70031148669"}
0005432953810	F35F27	5124 492080	ALINA IVANOVA	{"phone": "+70394866314"}
0005432949609	882DF7	6889 072034	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir-17071970@postgrespro.ru", "phone": "+70869264092"}
0005432949610	882DF7	6212 943712	MARIYA TARASOVA	{"phone": "+70886359280"}
0005432949611	60E48C	4457 142695	VITALIY SMIRNOV	{"email": "v.smirnov-1962@postgrespro.ru", "phone": "+70480412124"}
0005432949612	60E48C	4056 374508	GRIGORIY KOZLOV	{"email": "kozlov-g-04081963@postgrespro.ru", "phone": "+70437184637"}
0005432949613	8C2D48	5006 830008	ANATOLIY NIKOLAEV	{"phone": "+70024083276"}
0005432949614	8C2D48	1308 067531	ELENA PAVLOVA	{"email": "pavlovaelena-1971@postgrespro.ru", "phone": "+70514132673"}
0005432949615	E5176B	7854 027554	ARTEM MAKAROV	{"phone": "+70125031955"}
0005432949616	E5176B	0803 173658	FAINA MAKAROVA	{"email": "makarovafaina_1972@postgrespro.ru", "phone": "+70807832858"}
0005432949617	1FF7F7	2781 788662	OLGA GERASIMOVA	{"email": "ogerasimova1972@postgrespro.ru", "phone": "+70123024655"}
0005432949618	1FF7F7	2780 950286	VASILIY SOKOLOV	{"email": "sokolov.v.18061977@postgrespro.ru", "phone": "+70860697145"}
0005432949619	1FF7F7	4785 569430	SERGEY YAKOVLEV	{"phone": "+70647780516"}
0005432949620	DB4998	8015 522933	ALEKSEY ZAYCEV	{"email": "zaycev_a-011971@postgrespro.ru", "phone": "+70577725010"}
0005432949621	DB4998	5439 557475	ANNA NIKITINA	{"phone": "+70120148669"}
0005432949622	B0686E	1720 781396	ALSU DMITRIEVA	{"email": "dmitrieva-a.23101970@postgrespro.ru", "phone": "+70257392939"}
0005432949623	D28930	1492 193883	MARIYA SIDOROVA	{"phone": "+70958775195"}
0005432949624	FA8B70	9146 290417	LYUBOV VASILEVA	{"email": "vasileva-l071981@postgrespro.ru", "phone": "+70066900202"}
0005432949625	FA8B70	3720 581935	DMITRIY BELOV	{"email": "belov_dmitriy_1971@postgrespro.ru", "phone": "+70288541114"}
0005432949626	FA8B70	9582 841925	VALERIYA ZHUKOVA	{"phone": "+70921770869"}
0005432949627	9D7C39	2824 258151	ALENA VOLKOVA	{"email": "alena.volkova081973@postgrespro.ru", "phone": "+70349284467"}
0005432949628	9D7C39	0186 439713	VLADISLAV BONDARENKO	{"phone": "+70398868613"}
0005432949629	2B8257	0804 216658	IRINA POPOVA	{"email": "popovai-1971@postgrespro.ru", "phone": "+70436630693"}
0005432949630	5264DC	9990 850009	ANATOLIY NIKITIN	{"email": "a.nikitin.11071981@postgrespro.ru", "phone": "+70965190960"}
0005432949631	D39617	6661 351331	ALEKSANDR NAZAROV	{"email": "anazarov-061980@postgrespro.ru", "phone": "+70340800359"}
0005432949632	0051DC	1879 223640	TATYANA FOMINA	{"phone": "+70689844685"}
0005432949633	0051DC	1174 693380	ARINA POLYAKOVA	{"phone": "+70247527247"}
0005432949634	0051DC	5098 699061	MARAT KUZNECOV	{"email": "kuznecov-m-111961@postgrespro.ru", "phone": "+70934976393"}
0005432949635	D07580	0590 434392	ANNA KUZNECOVA	{"email": "a-kuznecova01011967@postgrespro.ru", "phone": "+70742771323"}
0005432949636	D99459	8632 816652	YULIYA IVANOVA	{"email": "ivanovayuliya1971@postgrespro.ru", "phone": "+70952568355"}
0005432949637	457DE0	9026 122099	ELENA DMITRIEVA	{"email": "elenadmitrieva.02011965@postgrespro.ru", "phone": "+70749680045"}
0005432949638	457DE0	0346 581590	ANTONINA DANILOVA	{"email": "danilovaa_021964@postgrespro.ru", "phone": "+70460780780"}
0005432949639	BD7B51	3910 871590	GRIGORIY YAKOVLEV	{"email": "yakovlev_grigoriy_23021975@postgrespro.ru", "phone": "+70968305200"}
0005432949640	BD7B51	9125 103420	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr_1980@postgrespro.ru", "phone": "+70063918214"}
0005432949641	BD7B51	6318 210021	TATYANA ANDREEVA	{"email": "andreeva_tatyana23031966@postgrespro.ru", "phone": "+70253815145"}
0005432949642	2BDB33	8238 313078	KONSTANTIN NIKOLAEV	{"email": "knikolaev_11031985@postgrespro.ru", "phone": "+70801165370"}
0005432949643	74B853	8013 302770	YURIY MIKHAYLOV	{"email": "y_mikhaylov_1969@postgrespro.ru", "phone": "+70301075309"}
0005432949644	61704B	7402 089377	IVAN FEDOROV	{"email": "ivan_fedorov04041977@postgrespro.ru", "phone": "+70262355255"}
0005432949645	BF6A6B	5963 283980	VLADIMIR SOKOLOV	{"phone": "+70480781744"}
0005432949646	BF6A6B	3993 265997	TATYANA POPOVA	{"email": "popova.t-011976@postgrespro.ru", "phone": "+70747208324"}
0005432949647	29C88B	4698 936989	OLGA BORISOVA	{"phone": "+70447202710"}
0005432949648	07B417	4324 595047	ELENA MAKSIMOVA	{"email": "maksimova.elena_1974@postgrespro.ru", "phone": "+70679932429"}
0005432949649	07B417	4708 353147	ANTON FEDOROV	{"email": "a_fedorov.18041968@postgrespro.ru", "phone": "+70914307686"}
0005432949650	B3D8E9	1082 141293	IRINA POTAPOVA	{"email": "potapova-i-091970@postgrespro.ru", "phone": "+70703461141"}
0005432949651	E31EC8	0052 244569	ALEKSANDR STEPANOV	{"phone": "+70983785506"}
0005432949652	9FE0A1	0771 485517	LYUDMILA TIKHONOVA	{"email": "lyudmila-tikhonova13061977@postgrespro.ru", "phone": "+70378165895"}
0005432949653	663C0F	9870 248113	LYUDMILA SCHERBAKOVA	{"phone": "+70698444805"}
0005432949654	07DE17	7020 861971	GALINA OSIPOVA	{"phone": "+70674511464"}
0005432949655	07DE17	9743 754725	OLEG NIKITIN	{"email": "oleg_nikitin27041967@postgrespro.ru", "phone": "+70310049356"}
0005432949656	768322	9299 249373	LARISA SCHERBAKOVA	{"phone": "+70797066395"}
0005432949657	913279	3963 314666	ARTEMIY SCHERBAKOV	{"phone": "+70707424535"}
0005432949658	913279	0906 610768	VALERIY SERGEEV	{"email": "sergeevv_121961@postgrespro.ru", "phone": "+70868925053"}
0005432949659	913279	0518 469374	ANDREY PAVLOV	{"phone": "+70953580915"}
0005432949660	913279	7778 988126	EKATERINA MIRONOVA	{"email": "ekaterina-mironova-1963@postgrespro.ru", "phone": "+70179075463"}
0005432949661	C240CC	3526 446811	NATALYA KOZLOVA	{"phone": "+70904495677"}
0005432949662	BFA96D	8272 530376	VLADIMIR KULIKOV	{"phone": "+70048813237"}
0005432949663	BFA96D	0809 361402	ROZALIYA MIKHAYLOVA	{"phone": "+70891773090"}
0005432949664	7D4132	7811 885479	ELENA ABRAMOVA	{"phone": "+70862659516"}
0005432949665	1E87DE	8970 783990	TIMOFEY MARTYNOV	{"email": "martynov_timofey_29071972@postgrespro.ru", "phone": "+70950880308"}
0005432949666	1E87DE	6971 732837	NIKOLAY ABRAMOV	{"email": "nikolayabramov_071972@postgrespro.ru", "phone": "+70317744822"}
0005432949667	32403A	7553 744606	VALENTINA IVANOVA	{"email": "ivanova.v_111976@postgrespro.ru", "phone": "+70126600850"}
0005432949668	32403A	5540 366057	VLADIMIR ZAKHAROV	{"phone": "+70674938897"}
0005432949669	15A416	7131 367746	GALINA BORISOVA	{"phone": "+70323919774"}
0005432949670	15A416	9097 056505	MIKHAIL VOROBEV	{"email": "vorobev-mikhail1972@postgrespro.ru", "phone": "+70437140876"}
0005432949671	79E0B8	4246 739936	ANATOLIY RODIONOV	{"phone": "+70405570432"}
0005432949672	EA3317	9312 563799	SERGEY DENISOV	{"email": "sergey.denisov.1967@postgrespro.ru", "phone": "+70745209425"}
0005432949673	329BEE	5650 040599	YURIY SHEVCHENKO	{"phone": "+70300209291"}
0005432949674	329BEE	4785 128687	EVGENIY NOVIKOV	{"email": "enovikov1966@postgrespro.ru", "phone": "+70560455463"}
0005432949675	329BEE	6174 436806	OLGA TIMOFEEVA	{"phone": "+70297379182"}
0005432949676	12A3D9	2146 736669	OLGA ROMANOVA	{"phone": "+70186771793"}
0005432949677	6DE06F	5914 674246	ALEKSANDRA PAVLOVA	{"email": "a-pavlova.14051980@postgrespro.ru", "phone": "+70499480841"}
0005432949678	6DE06F	5514 186594	IRINA SIDOROVA	{"phone": "+70103207896"}
0005432949679	C5F89F	3278 471755	MIKHAIL ZHUKOV	{"email": "mikhail_zhukov.111979@postgrespro.ru", "phone": "+70107164057"}
0005432949680	F4A9DE	6407 731936	VASILIY ZAYCEV	{"email": "vasiliyzaycev.111968@postgrespro.ru", "phone": "+70418171876"}
0005432949681	F4A9DE	8350 313114	VLADIMIR STEPANOV	{"email": "v.stepanov.111981@postgrespro.ru", "phone": "+70347658328"}
0005432949682	C31EA9	1956 727314	SERGEY DAVYDOV	{"email": "sergeydavydov_24091973@postgrespro.ru", "phone": "+70082530402"}
0005432949683	A2C906	7894 552343	LYUDMILA KONDRATEVA	{"phone": "+70718902980"}
0005432949684	A2C906	2372 800411	TATYANA FILATOVA	{"email": "t_filatova.1977@postgrespro.ru", "phone": "+70240489715"}
0005432949685	23473C	7911 000580	SANIYA SIDOROVA	{"email": "s-sidorova-1967@postgrespro.ru", "phone": "+70926988426"}
0005432949686	586A1A	0754 804100	EKATERINA ERMAKOVA	{"phone": "+70567431811"}
0005432949687	586A1A	6071 213792	OLESYA ZHURAVLEVA	{"phone": "+70042391332"}
0005432949688	2C5047	8591 343344	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko-081969@postgrespro.ru", "phone": "+70207633580"}
0005432949689	901B35	3606 894127	ANDREY KUZNECOV	{"email": "andrey.kuznecov.06061983@postgrespro.ru", "phone": "+70465266378"}
0005432949690	901B35	0684 293801	MARGARITA GERASIMOVA	{"email": "mgerasimova_071984@postgrespro.ru", "phone": "+70433175180"}
0005432949691	CF0B05	4661 431048	NADEZHDA KUZNECOVA	{"phone": "+70079020161"}
0005432949692	2BA51D	5786 181294	ALEKSANDR AFANASEV	{"email": "aafanasev.111969@postgrespro.ru", "phone": "+70881217391"}
0005432949693	C6036A	6619 455668	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva.121972@postgrespro.ru", "phone": "+70320685026"}
0005432949694	0564B4	2713 780998	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev_121969@postgrespro.ru", "phone": "+70208281005"}
0005432949695	4BC26A	8756 950164	OLGA SEMENOVA	{"email": "semenova_o.1982@postgrespro.ru", "phone": "+70281940324"}
0005432949696	87A8D4	7650 210640	RUSLAN KUZNECOV	{"email": "kuznecovruslan-26011970@postgrespro.ru", "phone": "+70933154000"}
0005432949697	99F5C5	9969 700743	YULIYA SEMENOVA	{"phone": "+70826719824"}
0005432949698	1760CD	8716 582598	OLGA VASILEVA	{"email": "olga-vasileva-30091974@postgrespro.ru", "phone": "+70799553546"}
0005432949699	D72C1A	0035 485607	NIKITA FEDOROV	{"email": "nikita.fedorov05081969@postgrespro.ru", "phone": "+70682231201"}
0005432949700	FF4E8C	8468 975411	ALEKSEY ABRAMOV	{"phone": "+70905789508"}
0005432953785	C020E3	3958 660483	DMITRIY IVANOV	{"email": "d-ivanov.1964@postgrespro.ru", "phone": "+70632554893"}
0005432953786	EBDA9A	2832 037565	LYUBOV MIKHAYLOVA	{"email": "l-mikhaylova.19061974@postgrespro.ru", "phone": "+70830740531"}
0005432953787	BC4F5E	2816 463654	GALINA ERMAKOVA	{"phone": "+70062642607"}
0005432953788	BC4F5E	4325 040171	ALEKSEY BARANOV	{"phone": "+70987834589"}
0005432953789	357FF0	0418 053539	ALEKSANDR KISELEV	{"phone": "+70657045361"}
0005432953790	E943E4	6744 598679	NINA MOISEEVA	{"phone": "+70677548385"}
0005432953791	547A19	1471 992483	ELENA ZOTOVA	{"phone": "+70863386515"}
0005432953792	547A19	8621 026390	ALEKSANDR KOROLEV	{"email": "korolevaleksandr.03011981@postgrespro.ru", "phone": "+70985956147"}
0005432953793	C0236B	4389 132659	NIKOLAY ILIN	{"email": "ilinn.02111956@postgrespro.ru", "phone": "+70054973757"}
0005432953794	ABBD88	2485 203886	ELENA SERGEEVA	{"email": "elena_sergeeva_10041979@postgrespro.ru", "phone": "+70349056144"}
0005432953795	C5D934	2392 271192	TATYANA ZOTOVA	{"phone": "+70863748666"}
0005432953796	9662F3	0880 983006	GENNADIY ISAEV	{"email": "isaev_g-16121978@postgrespro.ru", "phone": "+70334066105"}
0005432953797	A879DB	0817 021112	ARTEM VASILEV	{"phone": "+70746123727"}
0005432953798	D2C0D5	2894 460143	ANNA BARANOVA	{"email": "baranovaanna-041978@postgrespro.ru", "phone": "+70479453734"}
0005432953799	3D89F9	9586 034123	VADIM AFANASEV	{"email": "v_afanasev.25091975@postgrespro.ru", "phone": "+70154298849"}
0005432953800	3D89F9	5889 023126	OLEG POPOV	{"email": "oleg_popov_111979@postgrespro.ru", "phone": "+70376136542"}
0005432953801	7483A8	0198 969728	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva_l.041968@postgrespro.ru", "phone": "+70683448714"}
0005432953802	7483A8	6497 665898	OLGA NIKIFOROVA	{"phone": "+70072255997"}
0005432953803	4FB3E5	3270 328370	SERGEY ZHURAVLEV	{"phone": "+70304195713"}
0005432953804	6D40D4	7707 962982	MARIYA IVANOVA	{"phone": "+70534076232"}
0005432953805	C5B693	2021 463739	ALEKSEY IVANOV	{"email": "alekseyivanov_071957@postgrespro.ru", "phone": "+70817700511"}
0005432953806	8CEC6A	8164 461494	TATYANA SEMENOVA	{"email": "tsemenova_091970@postgrespro.ru", "phone": "+70155270520"}
0005432953807	8CEC6A	5517 267116	LYUBOV VOLKOVA	{"email": "volkova.lyubov-16091982@postgrespro.ru", "phone": "+70061813243"}
0005432953808	F55C68	1566 737384	ALENA ROMANOVA	{"phone": "+70629662895"}
0005432953809	4EB169	2116 216331	OLESYA ZAKHAROVA	{"email": "zakharovaolesya-111961@postgrespro.ru", "phone": "+70432029271"}
0005432953811	891E0D	1118 719632	MAKSIM MAKAROV	{"phone": "+70375183919"}
0005432953812	AD4A2A	1386 638733	ANTON DAVYDOV	{"email": "davydov.anton.1973@postgrespro.ru", "phone": "+70105607133"}
0005432953813	47D846	1527 752504	ALEKSEY TIMOFEEV	{"phone": "+70149086974"}
0005432953814	B41D2B	2455 370624	IVAN ALEKSANDROV	{"email": "aleksandrov-ivan1968@postgrespro.ru", "phone": "+70992600590"}
0005432953815	B41D2B	5124 127023	ALEKSANDR PAVLOV	{"phone": "+70094342062"}
0005432953816	AA1CDE	4113 308241	SVETLANA VLASOVA	{"phone": "+70464855642"}
0005432953817	AA1CDE	1881 536150	VALENTINA NIKITINA	{"email": "valentina-nikitina-101975@postgrespro.ru", "phone": "+70535411014"}
0005432953818	19C950	6458 705926	ALEKSANDR MIRONOV	{"phone": "+70363140026"}
0005432953819	DDB072	5707 463808	ANASTASIYA ZAKHAROVA	{"phone": "+70785734505"}
0005432953820	6B33CB	0074 627909	ARINA NOVIKOVA	{"email": "arina_novikova-121970@postgrespro.ru", "phone": "+70384249212"}
0005432953821	86EE5C	1197 758050	MIKHAIL VOLKOV	{"phone": "+70929309660"}
0005432953822	86EE5C	4987 075539	NATALYA MAKSIMOVA	{"email": "natalya.maksimova.10021972@postgrespro.ru", "phone": "+70834435809"}
0005432953823	9E0551	4703 301376	VALENTINA RODIONOVA	{"phone": "+70720182106"}
0005432953824	8AEA4A	3103 299067	LIDIYA IVANOVA	{"phone": "+70119995678"}
0005432953825	8AEA4A	6706 702831	DARYA MOISEEVA	{"email": "moiseeva_d021972@postgrespro.ru", "phone": "+70763755005"}
0005432953826	8AEA4A	1002 481916	DENIS PETROV	{"email": "denispetrov_22101972@postgrespro.ru", "phone": "+70074471182"}
0005432953827	12B297	7682 908091	NATALYA GUSEVA	{"email": "guseva_n_1965@postgrespro.ru", "phone": "+70235570926"}
0005432953828	D7AE94	3171 072772	LIDIYA VASILEVA	{"email": "lidiya-vasileva_101963@postgrespro.ru", "phone": "+70973875996"}
0005432953829	D7AE94	5476 989954	DIANA MIKHAYLOVA	{"phone": "+70738506050"}
0005432953830	074DDE	1174 426336	VLADIMIR PAVLOV	{"email": "pavlovvladimir.25011981@postgrespro.ru", "phone": "+70558349480"}
0005432953831	5FDB62	6186 187100	ANDREY KISELEV	{"email": "kiselevandrey1966@postgrespro.ru", "phone": "+70012708166"}
0005432953832	0271EE	0043 286664	ALEKSANDR KONOVALOV	{"phone": "+70404432948"}
0005432953833	EB7699	1735 498475	MIKHAIL POPOV	{"email": "m_popov-101985@postgrespro.ru", "phone": "+70874701893"}
0005432953834	F2C402	1746 950347	VIKTOR FILIPPOV	{"phone": "+70353145740"}
0005432953835	F2C402	9648 177258	MIKHAIL STEPANOV	{"phone": "+70512583499"}
0005432953836	2A93A1	3122 416277	GULNARA SIDOROVA	{"email": "sidorova-gulnara_041969@postgrespro.ru", "phone": "+70845676770"}
0005432953837	6B0F85	1211 655071	SERGEY SEMENOV	{"phone": "+70953100392"}
0005432953838	F4CC07	4033 907280	VALENTINA SAVELEVA	{"email": "valentina.saveleva_1972@postgrespro.ru", "phone": "+70725968605"}
0005432953839	33D20F	4227 161055	OLGA ALEKSEEVA	{"phone": "+70455633305"}
0005432953840	D41882	9441 506171	VYACHESLAV KOZLOV	{"phone": "+70490728081"}
0005432953841	896892	8853 242461	SVETLANA KUDRYASHOVA	{"phone": "+70036526651"}
0005432953842	FBD384	7298 610714	NIKOLAY SERGEEV	{"phone": "+70171015201"}
0005432953843	FBD384	3625 471939	DMITRIY MAKAROV	{"email": "makarovd.111978@postgrespro.ru", "phone": "+70665691536"}
0005432953844	CA5AEC	7775 505991	KLAVDIYA STEPANOVA	{"email": "stepanova-klavdiya-30041977@postgrespro.ru", "phone": "+70891998879"}
0005432953845	CA5AEC	1201 867131	SERGEY NOVIKOV	{"email": "novikov_s1971@postgrespro.ru", "phone": "+70505355976"}
0005432953846	81CD12	3390 947710	YURIY ZAKHAROV	{"email": "zakharov.yuriy_021972@postgrespro.ru", "phone": "+70062403111"}
0005432953847	81CD12	3274 605628	KRISTINA FILIPPOVA	{"phone": "+70592598311"}
0005432953848	0D1782	2071 381270	ALEKSANDR ABRAMOV	{"phone": "+70517713470"}
0005432953849	53FD73	7047 522604	SOFIYA KULIKOVA	{"email": "sofiya.kulikova_041963@postgrespro.ru", "phone": "+70327237836"}
0005432953850	3211A9	2065 543393	ALEKSANDR GRIGOREV	{"phone": "+70277244105"}
0005432953851	B5B1FE	7474 567099	YAROSLAV KUZMIN	{"phone": "+70164661801"}
0005432953852	B5B1FE	0531 082995	NATALYA POPOVA	{"email": "popova.n_13031976@postgrespro.ru", "phone": "+70892359578"}
0005432953853	46BCB9	1321 229325	SERGEY POPOV	{"phone": "+70434782885"}
0005432953854	30B8CA	2381 119387	LYUDMILA IVANOVA	{"phone": "+70800372243"}
0005432953855	A24BAD	9740 904576	ANTONINA ANISIMOVA	{"email": "a-anisimova-011971@postgrespro.ru", "phone": "+70007252425"}
0005432953856	A24BAD	8741 426439	MIKHAIL MELNIKOV	{"phone": "+70412742632"}
0005432953857	A24BAD	3697 755370	FEDOR TIKHONOV	{"email": "tikhonov_fedor_1957@postgrespro.ru", "phone": "+70692492043"}
0005432953858	1A6221	6170 450145	RIMMA KISELEVA	{"email": "r.kiseleva.29041972@postgrespro.ru", "phone": "+70583860865"}
0005432953859	1A6221	7128 464742	ALEKSEY MOISEEV	{"email": "moiseevaleksey_1973@postgrespro.ru", "phone": "+70801595492"}
0005432953860	1A6221	0935 827528	VLADIMIR EGOROV	{"email": "egorov.vladimir_031980@postgrespro.ru", "phone": "+70877707739"}
0005432953861	B156D3	6022 241952	VIKTORIYA MAKSIMOVA	{"phone": "+70520094783"}
0005432953862	A4B4D0	5764 670099	NADEZHDA FEDOROVA	{"email": "nadezhda-fedorova-09091975@postgrespro.ru", "phone": "+70911349214"}
0005432953863	A4B4D0	3045 704988	VALENTINA CHERNOVA	{"phone": "+70223467270"}
0005432953864	B72A4D	6243 035927	MAKSIM CHERNOV	{"email": "m_chernov.1968@postgrespro.ru", "phone": "+70036758676"}
0005432953865	B72A4D	7791 561290	ELENA ROMANOVA	{"email": "e-romanova1976@postgrespro.ru", "phone": "+70531706797"}
0005432953866	6B7786	4318 824629	VALERIY NIKOLAEV	{"phone": "+70204127272"}
0005432953867	6B7786	1419 182724	VALENTINA POPOVA	{"email": "popova-v05061974@postgrespro.ru", "phone": "+70029353002"}
0005432953868	6B7786	0322 274416	KSENIYA NOVIKOVA	{"phone": "+70559953077"}
0005432953869	6B7786	3855 634525	GENNADIY MAKSIMOV	{"email": "gennadiymaksimov-081972@postgrespro.ru", "phone": "+70237497816"}
0005432953870	76B514	8627 886858	DENIS PETROV	{"phone": "+70821647945"}
0005432953871	72F60D	1861 497259	ANNA KUZMINA	{"email": "a-kuzmina1991@postgrespro.ru", "phone": "+70713087956"}
0005432953872	72F60D	9172 411041	OKSANA FEDOROVA	{"phone": "+70855049789"}
0005432953873	4EF3BE	5616 604073	NIKOLAY ZHURAVLEV	{"phone": "+70261646469"}
0005432953874	4EF3BE	5445 801397	MIKHAIL PAVLOV	{"phone": "+70529448815"}
0005432953875	8BD6C3	0212 036559	NIKITA ORLOV	{"phone": "+70364413488"}
0005432953876	D02749	8805 860124	ELENA MAKAROVA	{"email": "makarova_elena-121969@postgrespro.ru", "phone": "+70402070913"}
0005432953877	6DF453	9649 794453	ANATOLIY FROLOV	{"phone": "+70242008285"}
0005432953878	12DFE8	3925 539318	GRIGORIY SAVELEV	{"email": "savelevgrigoriy-051965@postgrespro.ru", "phone": "+70413705687"}
0005432953879	E09D1D	5652 844081	RUSTAM SEMENOV	{"phone": "+70225280649"}
0005432953880	E09D1D	6248 338456	VERA ZHURAVLEVA	{"phone": "+70796731106"}
0005432953881	E09D1D	3946 910112	ELENA NOVIKOVA	{"email": "elenanovikova_071971@postgrespro.ru", "phone": "+70689476153"}
0005432953882	2875BF	8349 005158	LEONID ZAYCEV	{"email": "zaycev_leonid101959@postgrespro.ru", "phone": "+70774781045"}
0005432953883	E9207E	6917 618818	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev.1973@postgrespro.ru", "phone": "+70226568932"}
0005432953884	BDDC22	6973 412006	ELENA DANILOVA	{"email": "e-danilova.031975@postgrespro.ru", "phone": "+70576718795"}
0005432953885	BDDC22	2815 681347	TATYANA STEPANOVA	{"phone": "+70116492361"}
0005432953886	BDDC22	0686 743791	MARIYA BOGDANOVA	{"phone": "+70526371459"}
0005432953887	BDDC22	0059 910195	IVAN ANTONOV	{"phone": "+70547245762"}
0005432953888	3403E5	7302 948449	TATYANA EFIMOVA	{"email": "t-efimova26091982@postgrespro.ru", "phone": "+70660622086"}
0005432953889	3E1232	6524 878713	TATYANA LEBEDEVA	{"phone": "+70257247849"}
0005432953890	7139E6	5123 539791	NADEZHDA MELNIKOVA	{"phone": "+70454365840"}
0005432953891	7139E6	7600 261715	LIDIYA NIKOLAEVA	{"email": "nikolaevalidiya.1958@postgrespro.ru", "phone": "+70860642439"}
0005432953892	7139E6	6501 567265	VITALIY SAVELEV	{"email": "vitaliy_savelev.10111967@postgrespro.ru", "phone": "+70137982602"}
0005432953893	9FF298	2646 144928	VASILIY SOLOVEV	{"email": "solovev.v_12051965@postgrespro.ru", "phone": "+70842475464"}
0005432953894	9FF298	9868 826399	IVAN FOMIN	{"phone": "+70175610665"}
0005432953895	546021	7533 104900	ROMAN CHERNOV	{"email": "chernov.roman.27101975@postgrespro.ru", "phone": "+70523860816"}
0005432953896	D75EAB	5088 905706	ILSHAT NOVIKOV	{"phone": "+70927460170"}
0005432953897	D75EAB	9246 664859	ALEKSEY POPOV	{"phone": "+70869818509"}
0005432953898	857381	2412 105569	PETR GORBUNOV	{"phone": "+70209448137"}
0005432953899	CFA05A	9547 154864	LIDIYA YUDINA	{"email": "yudinal.1971@postgrespro.ru", "phone": "+70978215977"}
0005432953900	AB9ABA	4252 901003	LYUBOV ZHUKOVA	{"phone": "+70609004988"}
0005432953901	43C56B	6065 661447	YULIYA DAVYDOVA	{"email": "davydovay1966@postgrespro.ru", "phone": "+70421286793"}
0005432953902	8AE4AD	4619 868232	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr_101972@postgrespro.ru", "phone": "+70441707671"}
0005432953903	B7F3B7	0266 605896	VLADIMIR POPOV	{"phone": "+70991653569"}
0005432953904	47877B	5188 948594	VALENTINA VASILEVA	{"phone": "+70265131374"}
0005432953905	FD76D7	7398 611122	ANDREY KONOVALOV	{"phone": "+70193057460"}
0005432953906	FD76D7	0387 916296	NIKOLAY MAKAROV	{"phone": "+70886390731"}
0005432953907	FF753F	6285 897120	OLEG BONDARENKO	{"phone": "+70375937867"}
0005432953908	7AFB7D	8868 938130	VLADIMIR ROMANOV	{"phone": "+70199865847"}
0005432953909	DEF125	3355 646981	OLEG KUZMIN	{"phone": "+70602319894"}
0005432953910	7D2343	4386 276542	DANILA VASILEV	{"email": "vasilev.d.1963@postgrespro.ru", "phone": "+70644651946"}
0005432953911	7D2343	5313 806884	NATALYA MARTYNOVA	{"phone": "+70115193475"}
0005432953912	0DF324	8098 131961	ALEKSANDR VOLKOV	{"email": "a_volkov091968@postgrespro.ru", "phone": "+70284442840"}
0005432953913	CB2DAE	7979 638086	TATYANA KUZNECOVA	{"email": "t-kuznecova_091982@postgrespro.ru", "phone": "+70581596937"}
0005432953914	DC644E	7847 729976	ANASTASIYA SERGEEVA	{"phone": "+70632306029"}
0005432953915	331DBC	8441 110322	ELENA VASILEVA	{"email": "vasileva-elena-12031977@postgrespro.ru", "phone": "+70153759023"}
0005432953916	084D02	0208 021403	SVETLANA SOKOLOVA	{"email": "sokolova.s-1972@postgrespro.ru", "phone": "+70368886827"}
0005432953917	9C11D0	1613 404747	LARISA RYABOVA	{"phone": "+70440707175"}
0005432953918	543FB6	8060 962340	DARYA MAKSIMOVA	{"email": "maksimova_d1972@postgrespro.ru", "phone": "+70078525386"}
0005432953919	7C8CCB	3080 397430	NATALYA PAVLOVA	{"email": "natalya.pavlova061971@postgrespro.ru", "phone": "+70328332543"}
0005432953920	602F29	4434 044422	LYUBOV DAVYDOVA	{"email": "lyubovdavydova1964@postgrespro.ru", "phone": "+70171728690"}
0005432953921	717DED	3136 973544	IRINA SOKOLOVA	{"phone": "+70506613963"}
0005432953922	40F041	5852 937339	ZINAIDA KAZAKOVA	{"email": "kazakova_z_1966@postgrespro.ru", "phone": "+70766432422"}
0005432953923	40F041	3505 894413	NINA NIKITINA	{"email": "nikitinanina_011977@postgrespro.ru", "phone": "+70295774150"}
0005432953924	66FBE6	9625 557988	VYACHESLAV FILIPPOV	{"phone": "+70623843462"}
0005432953925	66FBE6	4240 149884	GALINA KOVALEVA	{"phone": "+70572955262"}
0005432953926	66FBE6	8020 887798	EVGENIY GUSEV	{"email": "evgeniygusev.09051968@postgrespro.ru", "phone": "+70397642527"}
0005432953927	ACB2BC	7114 726530	KRISTINA ZAYCEVA	{"phone": "+70629023903"}
0005432953928	ACB2BC	6776 113681	VASILIY NAZAROV	{"email": "nazarov-v121971@postgrespro.ru", "phone": "+70455843463"}
0005432953929	6CEBA1	1374 490808	VLADIMIR IVANOV	{"phone": "+70900033761"}
0005432953930	6CEBA1	3101 105189	LYUDMILA LOGINOVA	{"email": "loginoval05101970@postgrespro.ru", "phone": "+70653636859"}
0005432953931	CE1FC4	8055 269453	ANDREY BORISOV	{"phone": "+70775610251"}
0005432953932	0FE4C3	8260 310603	ANATOLIY SIDOROV	{"phone": "+70207630920"}
0005432953933	0FE4C3	3382 797180	ALEKSEY ZAKHAROV	{"email": "zakharov.aleksey1968@postgrespro.ru", "phone": "+70956063327"}
0005432953934	352A8F	7122 435284	DMITRIY VOROBEV	{"email": "vorobevdmitriy.061975@postgrespro.ru", "phone": "+70884501848"}
0005432953935	72628E	1070 218317	SVETLANA ANTONOVA	{"phone": "+70886686702"}
0005432953936	72628E	7044 869276	SVETLANA MOROZOVA	{"email": "svetlanamorozova1982@postgrespro.ru", "phone": "+70174969873"}
0005432953937	2D973A	9201 214975	VLADIMIR KISELEV	{"phone": "+70718275191"}
0005432953938	2D973A	5863 200380	TIMUR PETROV	{"email": "petrovtimur1970@postgrespro.ru", "phone": "+70460962691"}
0005432953939	FCDF94	1528 331539	DANILA SHEVCHENKO	{"phone": "+70399180723"}
0005432953940	FCDF94	5827 161897	PAVEL KONOVALOV	{"email": "pavelkonovalov-1977@postgrespro.ru", "phone": "+70238713477"}
0005432953941	A3A1BE	0634 090540	MIKHAIL ILIN	{"email": "ilinmikhail.041969@postgrespro.ru", "phone": "+70583298533"}
0005432953942	A3A1BE	8710 703554	ANDREY IVANOV	{"email": "andrey.ivanov-1963@postgrespro.ru", "phone": "+70127996519"}
0005432953943	2CE30D	8280 293252	ALEKSEY ANDREEV	{"phone": "+70877637197"}
0005432953944	FF8642	1054 026537	NAIL IVANOV	{"email": "n_ivanov_1973@postgrespro.ru", "phone": "+70220376450"}
0005432953945	30A87A	7174 355137	VERA MAKAROVA	{"phone": "+70060547604"}
0005432953946	30A87A	3255 051912	OLGA KAZAKOVA	{"email": "kazakova.olga1968@postgrespro.ru", "phone": "+70248995631"}
0005432953947	CE1558	2230 796985	ALINA TARASOVA	{"email": "tarasova-alina071966@postgrespro.ru", "phone": "+70441892119"}
0005432953948	9834B1	8361 086318	LYUBOV KOZLOVA	{"email": "kozlova.lyubov-1974@postgrespro.ru", "phone": "+70196726347"}
0005432953949	9834B1	2917 361839	SERGEY RODIONOV	{"email": "rodionov.sergey-10061966@postgrespro.ru", "phone": "+70132772644"}
0005432953950	20BD3B	0025 178580	ANDREY ILIN	{"phone": "+70347780432"}
0005432953951	8CEC8B	1434 066757	TATYANA NESTEROVA	{"phone": "+70434225970"}
0005432953952	288DEB	1803 463717	EVGENIY SERGEEV	{"email": "evgeniy.sergeev.1972@postgrespro.ru", "phone": "+70600394320"}
0005432953953	288DEB	0809 502306	TATYANA POTAPOVA	{"email": "tpotapova.18101980@postgrespro.ru", "phone": "+70323826064"}
0005432953954	B50A73	3700 561201	IRINA PETROVA	{"email": "i_petrova-1975@postgrespro.ru", "phone": "+70468362032"}
0005432953955	AD381D	9919 703444	ANDREY SOKOLOV	{"email": "sokolov_a.08041965@postgrespro.ru", "phone": "+70886426704"}
0005432953956	D9D532	9897 200460	OLESYA KRASNOVA	{"email": "okrasnova_1980@postgrespro.ru", "phone": "+70164808925"}
0005432953957	323422	3189 519750	ANGELINA NIKITINA	{"phone": "+70529628621"}
0005432953958	19CBC3	6464 258716	YULIYA ROMANOVA	{"phone": "+70925773436"}
0005432953959	D489B6	6154 796331	EVDOKIYA NOVIKOVA	{"phone": "+70766906399"}
0005432953960	C74542	4060 466905	ANNA MAKSIMOVA	{"email": "anna-maksimova-30081972@postgrespro.ru", "phone": "+70140568810"}
0005432953961	FAB40C	9374 739473	YAROSLAV SIDOROV	{"phone": "+70571428076"}
0005432953962	64CBDF	6672 727154	ROMAN MAKSIMOV	{"email": "maksimovr_1970@postgrespro.ru", "phone": "+70256700478"}
0005432953963	2B39C5	1985 615796	NINA MASLOVA	{"phone": "+70670315176"}
0005432953964	2B39C5	0287 241553	VERA KOROLEVA	{"phone": "+70575599489"}
0005432953965	E8E509	4571 778296	EKATERINA VASILEVA	{"phone": "+70503164942"}
0005432953966	E8E509	8498 125516	EVGENIY PAVLOV	{"email": "epavlov-1979@postgrespro.ru", "phone": "+70922160419"}
0005432953967	F281D3	0631 845465	ANASTASIYA KUZMINA	{"phone": "+70686266846"}
0005432953968	F281D3	2973 303554	LIDIYA ANDREEVA	{"phone": "+70481815359"}
0005432953969	C874EE	6695 601929	LYUBOV VOLKOVA	{"email": "volkova_l1974@postgrespro.ru", "phone": "+70763565637"}
0005432953970	C4F35D	2336 004492	SERGEY VASILEV	{"phone": "+70872897371"}
0005432953971	1A9D24	1490 720930	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-061978@postgrespro.ru", "phone": "+70941241061"}
0005432953972	8C2068	9725 138433	ELIZAVETA POTAPOVA	{"phone": "+70296979376"}
0005432953973	F51AE4	6557 861894	SERGEY MIRONOV	{"email": "s_mironov_081984@postgrespro.ru", "phone": "+70066438874"}
0005432953974	5B34A8	7042 829693	ALBERT TIKHONOV	{"phone": "+70445295294"}
0005432953975	5B34A8	6336 551968	NATALYA ALEKSANDROVA	{"email": "aleksandrova.natalya-091985@postgrespro.ru", "phone": "+70970489776"}
0005432953976	08B8A7	3348 183871	SERGEY MAKSIMOV	{"email": "maksimov_s.1969@postgrespro.ru", "phone": "+70837405676"}
0005432953977	88C20F	4886 449223	ANASTASIYA KUZNECOVA	{"email": "a_kuznecova_13011973@postgrespro.ru", "phone": "+70530383311"}
0005432953978	9E31AF	3351 438595	NADEZHDA OSIPOVA	{"phone": "+70556342198"}
0005432953979	9E31AF	1677 240291	SERGEY FROLOV	{"phone": "+70208005248"}
0005432953980	0343AB	7756 873104	GALINA IVANOVA	{"email": "g.ivanova.05041975@postgrespro.ru", "phone": "+70997149253"}
0005432953981	9B0758	8014 106125	VIKTOR BORISOV	{"phone": "+70303976352"}
0005432953982	8CDE9F	8259 749670	MARIYA DENISOVA	{"email": "denisova_m.021975@postgrespro.ru", "phone": "+70352159329"}
0005432953983	62F6FE	7695 864718	NATALYA DENISOVA	{"phone": "+70219619597"}
0005432953984	62F6FE	5877 180500	VITALIY GUSEV	{"email": "gusev-v-011969@postgrespro.ru", "phone": "+70116628291"}
0005432953985	62F6FE	2044 823878	OLGA ABRAMOVA	{"phone": "+70639751917"}
0005432953986	4FB90E	0721 053260	VIKTOR POPOV	{"phone": "+70199515646"}
0005432953987	4FB90E	8839 585523	ALEKSANDR KAZAKOV	{"phone": "+70100758526"}
0005432953988	6029DA	6448 517777	EGOR ZAKHAROV	{"phone": "+70743281649"}
0005432953989	4A8FCE	5039 736241	ANDREY NAZAROV	{"phone": "+70556495344"}
0005432953990	4A8FCE	0773 176071	RAFAIL POPOV	{"email": "popov_rafail-27041976@postgrespro.ru", "phone": "+70270548924"}
0005432953991	442499	9857 909859	YULIYA TIKHONOVA	{"phone": "+70459837715"}
0005432953992	90A645	1175 545310	GALINA BELYAEVA	{"email": "galinabelyaeva-041972@postgrespro.ru", "phone": "+70855778134"}
0005432953993	CA4CD0	1852 832376	YURIY BELOV	{"phone": "+70627760072"}
0005432953994	AF308F	6152 952005	MARIYA BARANOVA	{"email": "baranova-m.011977@postgrespro.ru", "phone": "+70672146412"}
0005432953995	83FE02	3293 111133	IRINA KUZNECOVA	{"email": "kuznecova_i_111975@postgrespro.ru", "phone": "+70171735107"}
0005432953996	064657	3579 679397	ALEKSEY SHEVCHENKO	{"phone": "+70064025215"}
0005432953997	AF1D2A	0581 687958	GALINA MOISEEVA	{"phone": "+70516623520"}
0005432953998	AF1D2A	1014 279468	PETR VLASOV	{"phone": "+70705802446"}
0005432953999	CCDE53	8858 642553	SERGEY GERASIMOV	{"email": "gerasimov-sergey_1966@postgrespro.ru", "phone": "+70281665930"}
0005432954000	CCDE53	8975 834619	AMINA SIDOROVA	{"phone": "+70865220767"}
0005432954001	212CDC	6042 170998	IVAN EGOROV	{"phone": "+70963065536"}
0005432954002	212CDC	8030 360455	POLINA AFANASEVA	{"phone": "+70041609669"}
0005432954003	50724D	0671 051211	ALEKSANDR GRIGOREV	{"phone": "+70377865820"}
0005432954004	94D0A4	0379 345363	IVAN ANDREEV	{"phone": "+70743969496"}
0005432954005	94D0A4	4238 754603	SERGEY KONOVALOV	{"phone": "+70959112517"}
0005432954006	A4560E	7678 938659	VALENTIN IVANOV	{"email": "v_ivanov071978@postgrespro.ru", "phone": "+70874839154"}
0005432954007	8FCA80	0284 418127	ANDREY BONDARENKO	{"email": "bondarenkoa-091964@postgrespro.ru", "phone": "+70995221987"}
0005432954008	D813E7	2980 655761	VALERIYA SMIRNOVA	{"phone": "+70817012872"}
0005432954009	E90226	0951 846560	IRINA ZAKHAROVA	{"email": "zakharova-irina19011968@postgrespro.ru", "phone": "+70116030293"}
0005432954010	8B61A8	2910 004866	OLEG CHERNOV	{"phone": "+70726920468"}
0005432954011	8B61A8	2747 551252	VALENTINA NOVIKOVA	{"email": "novikovavalentina.1969@postgrespro.ru", "phone": "+70702413721"}
0005432954012	5F94B8	0618 121087	VERA KUZMINA	{"email": "v.kuzmina051971@postgrespro.ru", "phone": "+70642414470"}
0005432954013	C05079	5168 414903	IVAN IVANOV	{"email": "ivan_ivanov-041973@postgrespro.ru", "phone": "+70056835275"}
0005432954014	C05079	8837 177441	GRIGORIY SEMENOV	{"phone": "+70201422600"}
0005432954015	15B5A4	2067 352879	VALENTINA KUZNECOVA	{"email": "kuznecovavalentina-28101963@postgrespro.ru", "phone": "+70535396192"}
0005432954016	622ABA	2466 759321	DANIIL ISAEV	{"email": "isaevdaniil_101961@postgrespro.ru", "phone": "+70990708468"}
0005432954017	1DCD5D	6341 175524	EVGENIY GUSEV	{"email": "evgeniy-gusev1979@postgrespro.ru", "phone": "+70227594312"}
0005432954018	1DCD5D	1042 769724	TATYANA SAVELEVA	{"phone": "+70492196054"}
0005432954019	34489E	3850 920238	ALEKSEY ZAKHAROV	{"email": "zakharov_aleksey_13101973@postgrespro.ru", "phone": "+70633739029"}
0005432954020	E47853	5191 208893	MARIYA BOGDANOVA	{"email": "bogdanova-m.061969@postgrespro.ru", "phone": "+70783913995"}
0005432954021	E47853	7760 912808	DANILA OSIPOV	{"phone": "+70527250370"}
0005432954022	0B2699	8307 270808	ALENA KUDRYASHOVA	{"email": "kudryashova-alena1970@postgrespro.ru", "phone": "+70797376781"}
0005432954023	ADF237	9406 471267	NADEZHDA PAVLOVA	{"phone": "+70061350899"}
0005432954024	B4A2F8	7781 766416	IGOR FEDOROV	{"email": "fedorov_i_091958@postgrespro.ru", "phone": "+70635106215"}
0005432954025	B4A2F8	2922 857633	ELENA FEDOROVA	{"email": "fedorova-elena.101968@postgrespro.ru", "phone": "+70508739263"}
0005432954026	646F3F	5747 047961	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov011976@postgrespro.ru", "phone": "+70263201386"}
0005432954027	02FBE5	7638 197494	MARIYA PETROVA	{"phone": "+70888762217"}
0005432954028	D1D9F7	0036 764915	SERGEY ANDREEV	{"email": "s_andreev101971@postgrespro.ru", "phone": "+70449278166"}
0005432954029	BD591A	5553 125634	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-03051979@postgrespro.ru", "phone": "+70219676062"}
0005432954030	5DD6DA	5139 246581	ANASTASIYA STEPANOVA	{"phone": "+70854577814"}
0005432954031	5DD6DA	6812 620672	RAMIL RODIONOV	{"phone": "+70925034966"}
0005432954144	0154E2	1601 866532	DMITRIY VLASOV	{"phone": "+70389415412"}
0005432954032	4AAB26	6334 713195	VALENTINA IVANOVA	{"email": "valentina.ivanova21011974@postgrespro.ru", "phone": "+70851583539"}
0005432954033	4AAB26	3609 017869	OLGA NAUMOVA	{"email": "olga_naumova.1976@postgrespro.ru", "phone": "+70144592915"}
0005432954034	831488	4037 241889	ANDREY GAVRILOV	{"email": "andrey-gavrilov_031970@postgrespro.ru", "phone": "+70604317031"}
0005432954035	831488	4400 298641	NATALYA GORBUNOVA	{"phone": "+70791589680"}
0005432954036	3F9FC8	9683 502935	ALEKSANDR DMITRIEV	{"email": "dmitrieva051963@postgrespro.ru", "phone": "+70255849666"}
0005432954037	3F9FC8	0944 456061	IVAN PAVLOV	{"phone": "+70120591057"}
0005432954038	B432BE	8554 401651	TATYANA DENISOVA	{"email": "denisova.tatyana.17041966@postgrespro.ru", "phone": "+70633402404"}
0005432954039	15AB88	8088 631004	EKATERINA GRISHINA	{"email": "e.grishina_04031981@postgrespro.ru", "phone": "+70993259937"}
0005432954040	1E38D8	5307 859123	IRINA MARTYNOVA	{"phone": "+70003058340"}
0005432954041	2C2282	9340 597693	SVETLANA GAVRILOVA	{"email": "gavrilova.s-031970@postgrespro.ru", "phone": "+70527573204"}
0005432954042	2C2282	4756 650344	RUSLAN VOROBEV	{"email": "ruslan_vorobev-04011967@postgrespro.ru", "phone": "+70197689083"}
0005432954043	469501	4639 871966	SERGEY MOROZOV	{"email": "morozovsergey091972@postgrespro.ru", "phone": "+70933464508"}
0005432954044	87A61E	5137 109870	VALENTINA MOROZOVA	{"email": "vmorozova1972@postgrespro.ru", "phone": "+70639329146"}
0005432954045	A1860B	3095 158913	VALERIY IVANOV	{"email": "ivanov.v.1966@postgrespro.ru", "phone": "+70693066250"}
0005432954046	167F58	2259 076061	ANATOLIY MAKSIMOV	{"phone": "+70560380354"}
0005432954047	167F58	8675 885224	TIMOFEY VOLKOV	{"email": "timofey_volkov_061969@postgrespro.ru", "phone": "+70897967875"}
0005432954048	D96AA7	7365 627230	VLADIMIR FOMIN	{"phone": "+70808060094"}
0005432954049	6E2117	1111 014944	ANASTASIYA ARKHIPOVA	{"email": "arkhipova_anastasiya_1971@postgrespro.ru", "phone": "+70293196692"}
0005432954050	6E2117	9907 431512	IVAN SAVELEV	{"phone": "+70240417900"}
0005432954051	FF2882	4531 933927	NELLYA LAZAREVA	{"phone": "+70662543930"}
0005432954052	FF2882	1242 288100	DMITRIY VOROBEV	{"email": "vorobev-d-1974@postgrespro.ru", "phone": "+70185369120"}
0005432954053	ACE1E0	5369 763237	MARINA KISELEVA	{"phone": "+70281394535"}
0005432954054	ACE1E0	5923 020342	EVGENIYA KOROLEVA	{"phone": "+70057056077"}
0005432954055	9B941C	4648 637594	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr061971@postgrespro.ru", "phone": "+70487957461"}
0005432954056	0B06AB	7681 018108	MARINA FOMINA	{"phone": "+70610638849"}
0005432954057	2D18AD	2956 163352	ALEKSEY BARANOV	{"email": "aleksey-baranov1972@postgrespro.ru", "phone": "+70295601917"}
0005432954058	2D18AD	9735 076237	ANTONINA KULIKOVA	{"email": "antonina_kulikova_091964@postgrespro.ru", "phone": "+70600164503"}
0005432954059	2FEBF8	4981 165358	DMITRIY KUZNECOV	{"phone": "+70869103474"}
0005432954060	5012DF	8784 372305	LIDIYA ISAEVA	{"email": "lidiya.isaeva-19041972@postgrespro.ru", "phone": "+70357225801"}
0005432954061	A82F4D	7495 132255	LIDIYA FROLOVA	{"phone": "+70173915153"}
0005432954062	A16F1C	9407 084481	ANATOLIY SERGEEV	{"phone": "+70382644028"}
0005432954063	E93C95	4720 369856	VLADIMIR MATVEEV	{"phone": "+70225754506"}
0005432954064	022F05	2698 033006	ALEKSEY FOMIN	{"email": "fomin.aleksey_1977@postgrespro.ru", "phone": "+70688026296"}
0005432954065	17B986	4368 437797	NATALYA SERGEEVA	{"email": "n-sergeeva.011974@postgrespro.ru", "phone": "+70266518401"}
0005432954066	DEEBE8	9111 705463	ARTEM PETROV	{"phone": "+70795146454"}
0005432954067	DEEBE8	1266 568777	MAKSIM KUZMIN	{"phone": "+70130069193"}
0005432954068	D4A158	4182 395753	NATALYA KRASNOVA	{"email": "krasnovan-05041975@postgrespro.ru", "phone": "+70159569520"}
0005432954069	00B9BF	8466 684432	TIMUR SOKOLOV	{"email": "timursokolov.02091979@postgrespro.ru", "phone": "+70999216913"}
0005432954070	00B9BF	7417 438677	VIKTOR TIKHONOV	{"phone": "+70609323991"}
0005432954071	CCE1D7	5940 468237	LYUDMILA DENISOVA	{"phone": "+70975148664"}
0005432954072	CCE1D7	9093 954953	LYUDMILA BOGDANOVA	{"phone": "+70001898554"}
0005432954073	5F17D4	4855 572812	NADEZHDA SIDOROVA	{"phone": "+70830377524"}
0005432954074	4D3EED	2994 796292	NIKOLAY KOZLOV	{"phone": "+70206597463"}
0005432954075	4D3EED	0702 520688	IDA MAKAROVA	{"phone": "+70610079688"}
0005432954076	81283E	7800 040627	OLGA MOROZOVA	{"email": "o-morozova-011966@postgrespro.ru", "phone": "+70556762584"}
0005432954077	641CBB	2283 581388	LYUDMILA POPOVA	{"phone": "+70133670646"}
0005432954078	6410C1	0216 342850	KSENIYA KUZMINA	{"email": "kuzminak-1967@postgrespro.ru", "phone": "+70345392871"}
0005432954079	1077B6	8383 967510	VLADIMIR VOLKOV	{"phone": "+70950425211"}
0005432954080	1BB56E	8801 715678	ALEKSANDR KUZMIN	{"phone": "+70330918895"}
0005432954081	01863E	2973 255536	DMITRIY DMITRIEV	{"email": "dmitriev-d-26041972@postgrespro.ru", "phone": "+70193792284"}
0005432954082	01863E	8726 960044	TAMARA ANDREEVA	{"phone": "+70990352083"}
0005432954083	8E2837	0700 191431	NADEZHDA KOMAROVA	{"email": "n_komarova1986@postgrespro.ru", "phone": "+70380338802"}
0005432954084	7AA070	6440 948148	IRINA ZAKHAROVA	{"email": "zakharovairina-041960@postgrespro.ru", "phone": "+70551175340"}
0005432954085	1C2FD5	3176 281718	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva_101982@postgrespro.ru", "phone": "+70219428789"}
0005432954086	1C2FD5	8738 137786	VALERIY KUZNECOV	{"email": "kuznecov.v_19081969@postgrespro.ru", "phone": "+70730097467"}
0005432954087	1C2FD5	4067 661448	SERGEY ZHURAVLEV	{"phone": "+70521488444"}
0005432954088	796E5B	4196 572022	SVETLANA NIKITINA	{"email": "svetlana_nikitina.1976@postgrespro.ru", "phone": "+70566393072"}
0005432954089	0A8C12	2623 223960	TATYANA MOROZOVA	{"phone": "+70070808680"}
0005432954090	B036D2	5080 517961	DANIIL NAZAROV	{"phone": "+70324499768"}
0005432954091	1580DC	6447 643642	DMITRIY STEPANOV	{"email": "stepanov_d.041963@postgrespro.ru", "phone": "+70311648489"}
0005432954092	6664C7	2238 856019	MIKHAIL PETROV	{"phone": "+70213655774"}
0005432954093	FF7A1A	7755 887730	ROMAN KUZMIN	{"phone": "+70083700981"}
0005432954094	FF7A1A	5336 879873	ARINA ZAKHAROVA	{"email": "zakharova.a081968@postgrespro.ru", "phone": "+70434138589"}
0005432954095	F15600	6238 837931	OLEG DENISOV	{"email": "oleg.denisov.1975@postgrespro.ru", "phone": "+70142593094"}
0005432954096	F15600	9924 488724	EVGENIY PAVLOV	{"phone": "+70425268132"}
0005432954097	63FB4E	7979 556321	VALENTIN BELOV	{"email": "belov_valentin_031972@postgrespro.ru", "phone": "+70569461213"}
0005432954098	C56857	5578 109396	OKSANA MELNIKOVA	{"phone": "+70627694953"}
0005432954099	C56857	1500 120772	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov.051975@postgrespro.ru", "phone": "+70184149361"}
0005432954100	B23DBB	6457 600236	DMITRIY POPOV	{"phone": "+70403446985"}
0005432954101	77CCE2	4295 997699	NATALYA ABRAMOVA	{"phone": "+70312180207"}
0005432954102	C59E5A	9838 074678	ANNA GERASIMOVA	{"phone": "+70601390830"}
0005432954103	C59E5A	0780 515419	ALEKSANDR ANDREEV	{"phone": "+70863996188"}
0005432954104	8AC279	3324 381010	LYUDMILA ABRAMOVA	{"phone": "+70719805706"}
0005432954105	9F6E6E	1434 580900	SERGEY KARPOV	{"email": "sergey.karpov121971@postgrespro.ru", "phone": "+70047969175"}
0005432954106	25410A	1821 080928	NIKOLAY FROLOV	{"email": "frolov-n_08031968@postgrespro.ru", "phone": "+70741606448"}
0005432954107	25410A	1777 603758	ANNA POPOVA	{"phone": "+70055560518"}
0005432954108	9B7EE0	6302 018909	GENNADIY IVANOV	{"phone": "+70389402955"}
0005432954109	992528	8923 106590	NIKOLAY MIRONOV	{"email": "mironov-n-021979@postgrespro.ru", "phone": "+70189204515"}
0005432954110	556C45	4721 481691	EVGENIY NAZAROV	{"email": "nazarovevgeniy_29061977@postgrespro.ru", "phone": "+70506930440"}
0005432954111	4D8253	4440 345684	VERA NAZAROVA	{"email": "nazarova-v111972@postgrespro.ru", "phone": "+70454843897"}
0005432954112	785F12	0947 217877	VALENTINA KULIKOVA	{"email": "kulikova-valentina_12061982@postgrespro.ru", "phone": "+70742593057"}
0005432954113	785F12	3873 769299	DANIIL SOLOVEV	{"phone": "+70175489029"}
0005432954114	D6FF6B	7785 410009	ANNA KONDRATEVA	{"email": "a_kondrateva-26031972@postgrespro.ru", "phone": "+70008138943"}
0005432954115	E11727	4765 447349	NATALIYA MAKAROVA	{"email": "makarova-n.121979@postgrespro.ru", "phone": "+70757367905"}
0005432954116	E11727	2879 402721	ANTON MELNIKOV	{"email": "melnikov.a-071973@postgrespro.ru", "phone": "+70621724223"}
0005432954117	E3FC52	7857 182304	ALEKSANDR KOROLEV	{"phone": "+70794916608"}
0005432954118	56B138	5414 119809	NATALYA KISELEVA	{"email": "kiseleva_natalya-1973@postgrespro.ru", "phone": "+70834056406"}
0005432954119	56B138	4793 813665	FEDOR SEMENOV	{"email": "semenovfedor-1976@postgrespro.ru", "phone": "+70865738538"}
0005432954120	CDD1AF	7929 902997	VLADIMIR TARASOV	{"phone": "+70366258935"}
0005432954121	37B884	0451 955743	SERGEY VOROBEV	{"email": "vorobev_sergey_15011969@postgrespro.ru", "phone": "+70303185345"}
0005432954122	37B884	9614 018711	LYUDMILA KOROLEVA	{"email": "koroleva-lyudmila.071979@postgrespro.ru", "phone": "+70029917927"}
0005432954123	433855	9118 593138	OLGA SOROKINA	{"phone": "+70541760215"}
0005432954124	433855	6262 822405	PAVEL KUZMIN	{"email": "kuzmin-pavel.12011978@postgrespro.ru", "phone": "+70587933423"}
0005432954125	1D9371	5661 770020	ANNA ROMANOVA	{"email": "romanovaa-18051967@postgrespro.ru", "phone": "+70178409595"}
0005432954126	021A02	2314 408115	INNA TIKHONOVA	{"email": "itikhonova051973@postgrespro.ru", "phone": "+70057090378"}
0005432954127	181604	5665 675422	LYUBOV FROLOVA	{"phone": "+70105365170"}
0005432954128	21FE45	1165 243403	ALEKSANDR GORBUNOV	{"phone": "+70973245344"}
0005432954129	21FE45	4595 441282	VALENTINA KUZMINA	{"phone": "+70808370469"}
0005432954130	EC4B68	2636 271027	VLADIMIR ANDREEV	{"phone": "+70708577124"}
0005432954131	67F055	4886 358920	ANDREY ISAEV	{"email": "isaev_andrey1973@postgrespro.ru", "phone": "+70245360842"}
0005432954132	67F055	6281 241896	DARYA ALEKSANDROVA	{"email": "d.aleksandrova_1962@postgrespro.ru", "phone": "+70265872594"}
0005432954133	67F055	2837 096675	IRINA SMIRNOVA	{"email": "smirnova.irina1970@postgrespro.ru", "phone": "+70609196447"}
0005432954134	B7C5DA	7777 713426	PAVEL SAVELEV	{"phone": "+70085463677"}
0005432954135	A42159	8767 396071	VYACHESLAV KUZMIN	{"phone": "+70950335223"}
0005432954136	618C90	0934 072171	ALEKSANDR RODIONOV	{"phone": "+70909713290"}
0005432954137	976506	4771 354589	VITALIY NAZAROV	{"email": "nazarovv_121973@postgrespro.ru", "phone": "+70471818015"}
0005432954138	307A8C	6766 029866	VLADIMIR EGOROV	{"phone": "+70978745715"}
0005432954139	307A8C	4350 317289	EVGENIY MAKSIMOV	{"email": "maksimov.evgeniy.051969@postgrespro.ru", "phone": "+70520387280"}
0005432954140	872A6F	0897 874178	GALINA KOROLEVA	{"email": "galina_koroleva121972@postgrespro.ru", "phone": "+70012928532"}
0005432954141	872A6F	7663 186046	TATYANA MAKAROVA	{"phone": "+70392539391"}
0005432954142	7444D8	4802 635155	NIKOLAY MELNIKOV	{"email": "nikolay_melnikov_1966@postgrespro.ru", "phone": "+70340281885"}
0005432954143	DD8884	6897 009031	TATYANA SOLOVEVA	{"email": "tatyana_soloveva1977@postgrespro.ru", "phone": "+70939233884"}
0005432954145	4AE414	5074 317625	TAMARA GORBUNOVA	{"phone": "+70928590419"}
0005432954146	4AE414	6620 830794	MIKHAIL KONOVALOV	{"email": "konovalov-mikhail26111966@postgrespro.ru", "phone": "+70660118358"}
0005432954147	F2A4E8	6435 096188	OLESYA GORBUNOVA	{"phone": "+70813919404"}
0005432954148	2EDD35	5956 131157	ANDREY TIKHONOV	{"email": "tikhonov_a.27071974@postgrespro.ru", "phone": "+70373201999"}
0005432954149	F9F66F	4934 863311	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana26111982@postgrespro.ru", "phone": "+70628974737"}
0005432954150	3FB9D4	1205 278039	KRISTINA IVANOVA	{"phone": "+70527378986"}
0005432954151	C1B834	1102 820435	LYUDMILA KOLESNIKOVA	{"phone": "+70888772041"}
0005432954152	C1B834	7892 818616	INGA KARPOVA	{"email": "ikarpova.1972@postgrespro.ru", "phone": "+70044223051"}
0005432954153	4C6176	4662 209428	LARISA GORBUNOVA	{"phone": "+70091497944"}
0005432954154	ADF875	2267 443693	VLADIMIR POPOV	{"email": "popov-vladimir_1982@postgrespro.ru", "phone": "+70077507280"}
0005432954155	EB1E86	4267 183607	SERGEY GORBUNOV	{"phone": "+70689250079"}
0005432954156	3BAAF3	5795 580791	LIDIYA MIRONOVA	{"email": "l.mironova.111984@postgrespro.ru", "phone": "+70009474609"}
0005432954157	665F2E	0843 821088	ANATOLIY YAKOVLEV	{"email": "yakovlev_a18071976@postgrespro.ru", "phone": "+70890981598"}
0005432954158	665F2E	9049 034246	VYACHESLAV KUZNECOV	{"email": "vyacheslav.kuznecov_011978@postgrespro.ru", "phone": "+70453029661"}
0005432954159	CD8552	7487 927532	OKSANA SERGEEVA	{"phone": "+70841330019"}
0005432954160	AE7768	7318 117576	EKATERINA BELYAEVA	{"email": "e_belyaeva1978@postgrespro.ru", "phone": "+70154945050"}
0005432954161	5B2BE0	4737 800674	ANNA KARPOVA	{"email": "karpova_a-021970@postgrespro.ru", "phone": "+70371688440"}
0005432954162	5B2BE0	5305 687206	ALEKSANDR TIMOFEEV	{"phone": "+70951026677"}
0005432954163	913C0C	1604 532155	IVAN IVANOV	{"email": "ivanov_i-1976@postgrespro.ru", "phone": "+70393998121"}
0005432954164	C828B8	3930 793439	FAINA PAVLOVA	{"email": "f-pavlova101966@postgrespro.ru", "phone": "+70925273753"}
0005432954165	A4FC35	1030 943848	ANDREY MOROZOV	{"phone": "+70789943466"}
0005432954166	A4FC35	1757 505364	VALERIYA MARTYNOVA	{"phone": "+70146141499"}
0005432954167	3AB48D	9747 239196	NADEZHDA KARPOVA	{"phone": "+70658556286"}
0005432954168	4A3D71	6318 904850	ANTONINA FEDOROVA	{"email": "fedorova_antonina_1973@postgrespro.ru", "phone": "+70800067274"}
0005432954169	4A3D71	1080 909450	LIDIYA NIKITINA	{"email": "lidiyanikitina_1977@postgrespro.ru", "phone": "+70684878830"}
0005432954170	46DE24	8533 514793	EVGENIY KUZMIN	{"email": "evgeniy.kuzmin1982@postgrespro.ru", "phone": "+70584756862"}
0005432954171	46DE24	0389 168503	ANDREY ZHURAVLEV	{"email": "zhuravlevandrey-021973@postgrespro.ru", "phone": "+70026665651"}
0005432954172	04CDC1	7373 589323	TATYANA ALEKSANDROVA	{"phone": "+70735502318"}
0005432954173	04CDC1	6796 388847	ALEKSEY GRIGOREV	{"phone": "+70856001761"}
0005432954174	F2442C	1335 864727	SERGEY ROMANOV	{"phone": "+70457713040"}
0005432954175	DF6AAD	4777 732788	TATYANA MAKAROVA	{"phone": "+70667251736"}
0005432954176	8D109A	6020 701429	VLADIMIR KISELEV	{"email": "kiselev_v26021972@postgrespro.ru", "phone": "+70544297301"}
0005432954177	8D109A	5617 882266	ALEKSANDR ROMANOV	{"phone": "+70991158780"}
0005432954178	025C14	6265 090235	VIKTOR PETROV	{"phone": "+70874488640"}
0005432954179	025C14	2405 033706	GENNADIY TARASOV	{"phone": "+70302018682"}
0005432954180	033929	4630 017098	VALENTINA KUZNECOVA	{"phone": "+70511112074"}
0005432954181	033929	8299 370390	IRINA FILATOVA	{"email": "irina_filatova_041969@postgrespro.ru", "phone": "+70159657423"}
0005432954182	F9FB1A	6624 777675	OLEG POPOV	{"email": "o-popov.071970@postgrespro.ru", "phone": "+70835629910"}
0005432954183	611A4C	5355 359882	ALINA KOLESNIKOVA	{"phone": "+70019635434"}
0005432954184	611A4C	8807 005646	TATYANA DANILOVA	{"phone": "+70225271492"}
0005432954185	611A4C	8381 263270	IVAN ZAKHAROV	{"email": "ivan.zakharov.26031970@postgrespro.ru", "phone": "+70247915035"}
0005432954186	4E70FA	7471 822309	NATALYA VOLKOVA	{"email": "volkova-n_031968@postgrespro.ru", "phone": "+70601975036"}
0005432954187	F47A4F	0792 402624	VIKTOR PAVLOV	{"phone": "+70563427695"}
0005432954188	F47A4F	6196 579493	NINA DMITRIEVA	{"phone": "+70285434137"}
0005432954189	8B9D6F	7089 398109	PETR KUDRYASHOV	{"phone": "+70964240959"}
0005432954190	DEA0C0	9229 761699	SERGEY ROMANOV	{"phone": "+70684048058"}
0005432954191	0C8ADC	2843 141173	EKATERINA MOROZOVA	{"phone": "+70527698807"}
0005432954192	A82381	1177 247621	VLADISLAV KUZMIN	{"phone": "+70531369045"}
0005432954193	A82381	5587 113776	PAVEL MEDVEDEV	{"phone": "+70199661008"}
0005432954194	A82381	6086 022511	IVAN VASILEV	{"email": "ivan.vasilev07051981@postgrespro.ru", "phone": "+70739474196"}
0005432954195	7D244B	1444 745298	EKATERINA PAVLOVA	{"phone": "+70591033535"}
0005432954196	10F2A3	0962 598008	OLGA STEPANOVA	{"phone": "+70758355352"}
0005432954197	610B26	6555 067909	KIRILL ISAEV	{"phone": "+70247646386"}
0005432954198	2B820B	6217 539817	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov-021970@postgrespro.ru", "phone": "+70395537336"}
0005432954199	5FFE64	8877 494156	YULIYA NIKITINA	{"email": "ynikitina-1972@postgrespro.ru", "phone": "+70894132326"}
0005432954200	88CA29	9092 974915	ALEKSANDR KAZAKOV	{"email": "a.kazakov.041974@postgrespro.ru", "phone": "+70353305736"}
0005432954201	88CA29	8676 866582	MARINA FILIPPOVA	{"email": "m_filippova-051982@postgrespro.ru", "phone": "+70972319039"}
0005432966479	C0E308	3526 911673	VLADIMIR SOLOVEV	{"phone": "+70633093918"}
0005432966480	3CD689	4018 383185	KIRA MIRONOVA	{"email": "kira.mironova_24041972@postgrespro.ru", "phone": "+70193358834"}
0005432966481	3CD689	6057 035559	BORIS VASILEV	{"phone": "+70998321280"}
0005432966482	4C973F	2586 694010	ELENA SEMENOVA	{"email": "semenova-elena_1977@postgrespro.ru", "phone": "+70536748541"}
0005432966483	4C973F	1236 114979	YULIYA KALININA	{"email": "ykalinina-061973@postgrespro.ru", "phone": "+70220711173"}
0005432966484	A588E9	3435 958877	INNA SOROKINA	{"phone": "+70077883920"}
0005432966485	A588E9	5008 829935	ANASTASIYA ISAEVA	{"email": "isaevaa.121978@postgrespro.ru", "phone": "+70754366547"}
0005432966486	79D831	7455 676588	GALINA TIKHONOVA	{"email": "g_tikhonova_30101966@postgrespro.ru", "phone": "+70300205277"}
0005432966487	54199E	0196 711769	DANIIL ROMANOV	{"phone": "+70218610166"}
0005432966488	54199E	9288 149706	RUSLAN SCHERBAKOV	{"email": "ruslan.scherbakov01031978@postgrespro.ru", "phone": "+70682301934"}
0005432966489	CA5D61	2866 515811	SERGEY ZHUKOV	{"email": "s-zhukov.051974@postgrespro.ru", "phone": "+70575817482"}
0005432966490	C469E8	8143 749682	ALEKSANDR ROMANOV	{"phone": "+70826127665"}
0005432966491	309BF4	5956 212247	ANNA BOGDANOVA	{"email": "bogdanova-a_04031965@postgrespro.ru", "phone": "+70334834452"}
0005432966492	311C0A	2190 238844	ALENA SMIRNOVA	{"phone": "+70473901797"}
0005432966493	311C0A	8970 902800	DMITRIY PAVLOV	{"email": "pavlov-d.081965@postgrespro.ru", "phone": "+70692728544"}
0005432966494	610479	3056 969177	LYUDMILA TIMOFEEVA	{"phone": "+70215871456"}
0005432966495	E36531	6089 167794	FLYURA IVANOVA	{"phone": "+70359390582"}
0005432966496	E36531	7973 227711	NIKOLAY VLASOV	{"email": "vlasov.n-1973@postgrespro.ru", "phone": "+70779445390"}
0005432966497	115261	9012 971871	ANDREY VOLKOV	{"phone": "+70672561687"}
0005432966498	115261	5629 368151	EKATERINA ANTONOVA	{"phone": "+70833833166"}
0005432966499	B0BE2C	8429 663873	VIKTOR MIRONOV	{"email": "viktor-mironov_28041970@postgrespro.ru", "phone": "+70566591964"}
0005432966500	103AE0	4575 208608	EVGENIY ZHURAVLEV	{"email": "evgeniy.zhuravlev_011970@postgrespro.ru", "phone": "+70004346650"}
0005432966501	103AE0	5979 551494	ALEKSANDR KUZNECOV	{"email": "kuznecov.a-1986@postgrespro.ru", "phone": "+70367673299"}
0005432966502	1A4B27	9415 032724	ANATOLIY ANDREEV	{"phone": "+70098589792"}
0005432966503	626725	8775 034219	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov_1980@postgrespro.ru", "phone": "+70102568571"}
0005432966504	626725	0753 607769	NATALYA NIKITINA	{"email": "n_nikitina021972@postgrespro.ru", "phone": "+70874369230"}
0005432966505	735FB8	8874 764500	NIKOLAY FROLOV	{"email": "n_frolov_121981@postgrespro.ru", "phone": "+70887450793"}
0005432966506	925D67	5555 839944	SVETLANA POLYAKOVA	{"email": "svetlana_polyakova_071977@postgrespro.ru", "phone": "+70765793551"}
0005432966507	D53A5D	8569 742858	OKSANA BELYAEVA	{"phone": "+70961237416"}
0005432966508	50A990	4191 786244	TATYANA KUZMINA	{"phone": "+70660474864"}
0005432966509	D397A5	1936 659351	NADEZHDA POPOVA	{"email": "nadezhdapopova21071979@postgrespro.ru", "phone": "+70089496416"}
0005432966510	7968A0	5717 453212	EVGENIY FEDOROV	{"email": "evgeniyfedorov_1977@postgrespro.ru", "phone": "+70738753210"}
0005432966511	7968A0	4591 172110	ZOYA TARASOVA	{"email": "z_tarasova-1975@postgrespro.ru", "phone": "+70971875447"}
0005432966512	72E28C	3421 690963	SNEZHANA MAKAROVA	{"phone": "+70145978794"}
0005432966513	72E28C	7928 241138	DANILA KUZMIN	{"email": "kuzmin_d_21081978@postgrespro.ru", "phone": "+70731417035"}
0005432966514	A2C364	3638 157482	OKSANA FOMINA	{"email": "fomina_oksana-061972@postgrespro.ru", "phone": "+70265151234"}
0005432966515	A2C364	7999 061312	MARAT SERGEEV	{"phone": "+70948582509"}
0005432966516	952FF4	1434 336095	GENNADIY KISELEV	{"email": "kiselevg.071974@postgrespro.ru", "phone": "+70217360396"}
0005432966517	CA1913	8127 775430	ANNA IVANOVA	{"email": "ivanovaanna_20011975@postgrespro.ru", "phone": "+70978850859"}
0005432966518	C32F4A	6228 491924	LIDIYA MAKAROVA	{"email": "lidiyamakarova.061978@postgrespro.ru", "phone": "+70345312780"}
0005432966519	6064ED	6475 423074	VIKTOR SEMENOV	{"email": "viktorsemenov_24011962@postgrespro.ru", "phone": "+70614717527"}
0005432966520	20C954	8987 147493	SERGEY MIRONOV	{"email": "sergeymironov_08121976@postgrespro.ru", "phone": "+70522217492"}
0005432966521	9C5EDC	4397 505458	KLAVDIYA IVANOVA	{"phone": "+70857398058"}
0005432966522	65A04F	5644 561438	NIKOLAY SIDOROV	{"phone": "+70923924991"}
0005432966523	65A04F	9823 887865	OLGA ZHURAVLEVA	{"phone": "+70205969092"}
0005432966524	AD9AAF	2619 714984	ELENA NAZAROVA	{"phone": "+70277794328"}
0005432966525	C565F6	4451 463201	YULIYA RYABOVA	{"phone": "+70893058944"}
0005432966526	16EFE3	8228 169380	ILYA AFANASEV	{"email": "iafanasev.03041963@postgrespro.ru", "phone": "+70183995271"}
0005432966527	4D2625	3572 369796	YURIY KUZNECOV	{"phone": "+70988887797"}
0005432966528	4D2625	1268 397707	SERGEY ANDREEV	{"email": "andreevsergey-1980@postgrespro.ru", "phone": "+70445659964"}
0005432966529	FAE644	0390 363157	VADIM EGOROV	{"phone": "+70663333879"}
0005432966530	0AEE04	6166 714571	ALEKSANDR SEMENOV	{"email": "semenov.a-1978@postgrespro.ru", "phone": "+70985341933"}
0005432966531	7F3682	1312 026878	NIKITA MELNIKOV	{"email": "melnikov_n-1967@postgrespro.ru", "phone": "+70690023047"}
0005432966532	34CEE9	2506 980341	ALENA BELOVA	{"phone": "+70007654988"}
0005432966533	CDA559	8601 496947	MARFA SERGEEVA	{"email": "sergeeva.m.1969@postgrespro.ru", "phone": "+70035682352"}
0005432966534	CDA559	4756 050860	DMITRIY ILIN	{"phone": "+70510909581"}
0005432966535	79931F	6802 747115	EVGENIYA GUSEVA	{"email": "evgeniya-guseva051967@postgrespro.ru", "phone": "+70420844174"}
0005432966536	EDD2CD	9024 988626	NIKITA IVANOV	{"email": "nikitaivanov101971@postgrespro.ru", "phone": "+70023218892"}
0005432966537	0AB2A1	3789 310192	DARYA FEDOROVA	{"email": "daryafedorova_071968@postgrespro.ru", "phone": "+70219297137"}
0005432966538	0C1E84	3552 365395	EKATERINA KISELEVA	{"phone": "+70423878411"}
0005432966539	7B66B7	7326 403302	ANASTASIYA BELOVA	{"email": "belovaa_101973@postgrespro.ru", "phone": "+70262686385"}
0005432966540	7B66B7	6761 889733	VLADISLAV FILIPPOV	{"phone": "+70796999491"}
0005432966541	8ED606	6695 607373	ILYA KONOVALOV	{"phone": "+70075122096"}
0005432966542	8ED606	6184 349456	SERGEY POPOV	{"email": "s-popov071975@postgrespro.ru", "phone": "+70447397671"}
0005432966543	C55811	9925 737113	ELVIRA VOROBEVA	{"email": "elvira_vorobeva.1979@postgrespro.ru", "phone": "+70957291159"}
0005432966544	3EF817	5201 542089	IRINA EGOROVA	{"phone": "+70104421020"}
0005432966545	6763AD	1498 191593	ELENA BELYAEVA	{"phone": "+70803184028"}
0005432966546	031C66	5536 660187	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l1966@postgrespro.ru", "phone": "+70936697583"}
0005432966547	CF0CF6	2166 652353	GALINA FOMINA	{"email": "fomina_g-1976@postgrespro.ru", "phone": "+70561411912"}
0005432966548	CF0CF6	4160 594504	OLGA SMIRNOVA	{"email": "smirnova_o_1956@postgrespro.ru", "phone": "+70893936751"}
0005432966549	901EA3	3413 007289	TATYANA BARANOVA	{"email": "baranova-tatyana_09121965@postgrespro.ru", "phone": "+70795339183"}
0005432966550	067B8E	9851 347560	ELENA SOROKINA	{"email": "e_sorokina.1959@postgrespro.ru", "phone": "+70937937791"}
0005432966551	C0E9BA	9240 768263	EKATERINA GUSEVA	{"phone": "+70422885890"}
0005432966552	D1456B	2367 366604	BORIS CHERNOV	{"phone": "+70197682116"}
0005432966553	01BDA7	5363 173467	NATALYA MIKHAYLOVA	{"phone": "+70842305305"}
0005432966554	7A0EA7	6281 306236	VLADIMIR MAKAROV	{"phone": "+70016844228"}
0005432966555	5D2AC5	7020 326605	VLADISLAV FILIPPOV	{"phone": "+70664073952"}
0005432966556	5D2AC5	6018 821359	NATALYA ZHURAVLEVA	{"email": "zhuravleva-natalya.01071980@postgrespro.ru", "phone": "+70380296564"}
0005432966557	205F5E	3964 572897	GENNADIY ANDREEV	{"email": "gandreev1965@postgrespro.ru", "phone": "+70165479807"}
0005432966558	0ACE76	9763 970550	VERONIKA KUZNECOVA	{"phone": "+70364666629"}
0005432966559	B55226	2209 273630	YURIY DAVYDOV	{"phone": "+70275575523"}
0005432966560	E55555	5836 678127	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova.l-19021978@postgrespro.ru", "phone": "+70828183444"}
0005432966561	E55555	8647 866836	LYUDMILA KONOVALOVA	{"phone": "+70485166990"}
0005432966562	DE398F	3956 520278	EVGENIYA LOGINOVA	{"phone": "+70505103958"}
0005432966563	DE398F	8342 403964	TIMUR MARTYNOV	{"email": "martynov.timur-1971@postgrespro.ru", "phone": "+70617791368"}
0005432966564	B33B51	6145 592020	OLEG ZAYCEV	{"phone": "+70527600771"}
0005432966565	7BFB5E	9613 438171	ROZA NOVIKOVA	{"phone": "+70545247482"}
0005432966566	7BFB5E	1167 906600	NATALYA FILIPPOVA	{"phone": "+70808327618"}
0005432966567	D71F25	1698 429887	ILYA ROMANOV	{"email": "romanov-i.011970@postgrespro.ru", "phone": "+70478068797"}
0005432966568	D71F25	6469 375053	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov.24071981@postgrespro.ru", "phone": "+70929814274"}
0005432966569	B2AB5B	1497 621687	VLADIMIR TIKHONOV	{"email": "vladimirtikhonov.121981@postgrespro.ru", "phone": "+70452712714"}
0005432966570	BD2F40	7813 113659	ALEKSANDR EGOROV	{"email": "aleksandr.egorov_10111962@postgrespro.ru", "phone": "+70468218244"}
0005432966571	BD2F40	4099 721704	YULIYA LUKYANOVA	{"phone": "+70578338847"}
0005432966572	221A19	6468 764071	SVETLANA OSIPOVA	{"phone": "+70127329460"}
0005432966573	221A19	9378 340473	LARISA SAVELEVA	{"phone": "+70657996376"}
0005432966574	43EE88	5390 519819	LYUDMILA NIKOLAEVA	{"phone": "+70069615808"}
0005432966575	A7CD09	4390 991716	VIKTOR IVANOV	{"phone": "+70761437713"}
0005432966576	5EEB47	2902 439360	NINA ISAEVA	{"email": "isaeva_nina-021976@postgrespro.ru", "phone": "+70595347999"}
0005432966577	8F305D	1129 117784	ANNA ANDREEVA	{"email": "annaandreeva_1972@postgrespro.ru", "phone": "+70123113336"}
0005432966578	8F305D	3065 515073	VIKTORIYA VOLKOVA	{"phone": "+70841606037"}
0005432966579	30705E	6237 965807	LYUDMILA ANTONOVA	{"email": "lantonova.101968@postgrespro.ru", "phone": "+70653191930"}
0005432966580	7FCED9	1778 539021	VERA BORISOVA	{"phone": "+70139709451"}
0005432966581	80E169	4664 651321	SHAVKAT POPOV	{"phone": "+70141252240"}
0005432966582	80E169	6369 286869	GENNADIY MARTYNOV	{"email": "gennadiy.martynov-21081973@postgrespro.ru", "phone": "+70537551102"}
0005432966583	85FB8E	6330 121534	NIKOLAY FROLOV	{"email": "n-frolov_021977@postgrespro.ru", "phone": "+70205607763"}
0005432966584	B2B5C6	1036 183277	NIKOLAY PAVLOV	{"phone": "+70342892208"}
0005432966585	1DC278	6974 195751	NADEZHDA KAZAKOVA	{"phone": "+70247234795"}
0005432966586	1DC278	1120 015438	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev-071960@postgrespro.ru", "phone": "+70657175698"}
0005432966587	1A48B4	9199 251098	MIKHAIL NIKITIN	{"email": "mikhail_nikitin_121978@postgrespro.ru", "phone": "+70001681417"}
0005432966588	3B1658	0336 729600	IRINA GAVRILOVA	{"phone": "+70613233910"}
0005432966589	1DC164	7164 886034	SERGEY MAKSIMOV	{"email": "maksimov.sergey-03041979@postgrespro.ru", "phone": "+70291842125"}
0005432966590	1DC164	9643 426836	VLADIMIR NIKITIN	{"phone": "+70334876698"}
0005432966591	E551D6	9893 808373	LIDIYA VOLKOVA	{"phone": "+70816033917"}
0005432966592	683CB6	8832 071619	ALEKSANDR IVANOV	{"email": "a-ivanov_1972@postgrespro.ru", "phone": "+70253221071"}
0005432966593	683CB6	4763 386389	ALEKSEY DENISOV	{"phone": "+70909947127"}
0005432966594	683CB6	1149 959896	ARTEM NAUMOV	{"phone": "+70345217145"}
0005432966595	28D661	7894 550508	ALEKSANDR GORBUNOV	{"phone": "+70400158648"}
0005432966596	F60916	0094 601144	VLADIMIR MARTYNOV	{"email": "martynov.vladimir-1967@postgrespro.ru", "phone": "+70127096983"}
0005432966597	F60916	7540 975438	IVAN ALEKSEEV	{"phone": "+70135317738"}
0005432966598	07FB67	2344 914236	SERGEY KUZNECOV	{"phone": "+70228869738"}
0005432966599	F31C98	4917 796576	DARYA MIKHAYLOVA	{"phone": "+70495769597"}
0005432966600	F31C98	0714 670419	RAISA DENISOVA	{"email": "raisa_denisova_22081960@postgrespro.ru", "phone": "+70913292086"}
0005432966601	5F4156	2975 526731	OLGA ALEKSANDROVA	{"phone": "+70121056017"}
0005432966602	5F4156	9296 130726	IVAN PAVLOV	{"phone": "+70740124290"}
0005432966603	5F4156	4332 530392	EVGENIY VOLKOV	{"phone": "+70841301412"}
0005432966604	A4813C	0746 478680	OLGA DENISOVA	{"email": "denisovao-1954@postgrespro.ru", "phone": "+70111534654"}
0005432966605	AD6FB9	1214 986072	LYUBOV MEDVEDEVA	{"phone": "+70850640298"}
0005432966606	03BF1E	6923 449437	NATALYA ZAKHAROVA	{"email": "zakharova-n_011976@postgrespro.ru", "phone": "+70908131045"}
0005432966607	E5FFA8	6405 011330	VALERIY MAKSIMOV	{"phone": "+70736979310"}
0005432966608	55A2B7	5889 615555	NIKITA KOZLOV	{"phone": "+70776825185"}
0005432966609	40727D	0908 178710	MARINA TIMOFEEVA	{"email": "m.timofeeva011986@postgrespro.ru", "phone": "+70557358113"}
0005432966610	A74622	4155 890487	YURIY GORBUNOV	{"email": "y-gorbunov_1968@postgrespro.ru", "phone": "+70351957094"}
0005432966611	04D9AD	2565 837748	ALEKSEY SIDOROV	{"phone": "+70742550693"}
0005432966612	5D351D	1968 045122	YULIYA POPOVA	{"email": "y-popova-14111983@postgrespro.ru", "phone": "+70242258016"}
0005432966613	A11B11	0755 833881	ANATOLIY PETROV	{"email": "petrov-a-1981@postgrespro.ru", "phone": "+70240542101"}
0005432966614	765329	2723 927055	ANDREY MOISEEV	{"email": "moiseev.a-1967@postgrespro.ru", "phone": "+70738386683"}
0005432966615	006FFF	5960 408273	PAVEL SEMENOV	{"email": "semenov-pavel-18051969@postgrespro.ru", "phone": "+70653566357"}
0005432966616	006FFF	7854 463953	TAMARA SEMENOVA	{"email": "semenova.t_1968@postgrespro.ru", "phone": "+70051683226"}
0005432966617	D591E7	5668 753017	VERA GRISHINA	{"email": "vera-grishina_1976@postgrespro.ru", "phone": "+70808929725"}
0005432966618	45DD6C	7168 184003	MAKSIM GAVRILOV	{"phone": "+70731414795"}
0005432966619	A3EC28	0291 389093	NIKOLAY ANDREEV	{"email": "nikolay_andreev11071974@postgrespro.ru", "phone": "+70230881707"}
0005432966620	B86BF6	1521 170583	RINAT EGOROV	{"email": "egorov-rinat_081965@postgrespro.ru", "phone": "+70916265226"}
0005432966621	B86BF6	4707 990989	NINA EFIMOVA	{"email": "ninaefimova.011960@postgrespro.ru", "phone": "+70105054646"}
0005432966622	2CFD46	8248 016817	NATALYA LAZAREVA	{"phone": "+70867162215"}
0005432966623	F69CF7	2840 158657	ALEKSEY DENISOV	{"phone": "+70144785127"}
0005432966624	F69CF7	8846 307296	OLGA SCHERBAKOVA	{"phone": "+70882632023"}
0005432966625	F69CF7	8984 790581	VLADIMIR FOMIN	{"email": "fomin_v-12021976@postgrespro.ru", "phone": "+70966503074"}
0005432966626	8DB182	1236 606241	SVETLANA PAVLOVA	{"email": "pavlovasvetlana1977@postgrespro.ru", "phone": "+70140603537"}
0005432966627	8DB182	4136 265760	LYUDMILA ANDREEVA	{"phone": "+70365208113"}
0005432966628	DD935C	3140 193167	VARVARA ALEKSEEVA	{"phone": "+70004687855"}
0005432966629	DD935C	4394 280702	VERA KUZNECOVA	{"email": "vera.kuznecova.21021964@postgrespro.ru", "phone": "+70126759927"}
0005432966630	8BBDF5	7474 699040	OLESYA MOROZOVA	{"phone": "+70237205503"}
0005432966631	386A30	6644 487470	ANNA KARPOVA	{"phone": "+70201869333"}
0005432966632	5A8D1F	1835 779529	SVETLANA FILATOVA	{"phone": "+70328068259"}
0005432966633	5A8D1F	2597 492588	ELENA YUDINA	{"email": "e-yudina_1975@postgrespro.ru", "phone": "+70217705181"}
0005432966813	E75455	4335 076581	TATYANA DANILOVA	{"phone": "+70178900859"}
0005432966634	1D4F82	8347 743188	MARGARITA POLYAKOVA	{"email": "polyakova.m011980@postgrespro.ru", "phone": "+70612862584"}
0005432966635	51C28E	5080 543186	EVGENIYA MOROZOVA	{"phone": "+70283996186"}
0005432966636	8754D6	3528 279231	IVAN ABRAMOV	{"email": "abramov_ivan011966@postgrespro.ru", "phone": "+70999790944"}
0005432966637	8754D6	3982 022812	VALERIY SERGEEV	{"phone": "+70782862226"}
0005432966638	572A3C	1633 374574	NIKOLAY VASILEV	{"phone": "+70760086360"}
0005432966639	9CB834	5435 873995	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n.081973@postgrespro.ru", "phone": "+70502597601"}
0005432966640	93AC47	8696 859731	YURIY SERGEEV	{"email": "ysergeev_1965@postgrespro.ru", "phone": "+70986178157"}
0005432966641	93AC47	3647 554718	LILIYA ZOTOVA	{"email": "zotova-liliya_101971@postgrespro.ru", "phone": "+70016249045"}
0005432966642	0DC254	6298 465604	YANA KOMAROVA	{"phone": "+70590845164"}
0005432966643	6F7556	9921 489421	LYUDMILA VASILEVA	{"email": "lyudmilavasileva.071975@postgrespro.ru", "phone": "+70389333320"}
0005432966644	6F7556	1515 773960	VALENTINA RYABOVA	{"phone": "+70767627384"}
0005432966645	2BEC05	4573 076044	ROMAN MAKSIMOV	{"phone": "+70007490457"}
0005432966646	893DDE	8040 693938	LIDIYA KUZNECOVA	{"email": "kuznecova_l_111967@postgrespro.ru", "phone": "+70199356085"}
0005432966647	626931	7611 608442	VALENTINA KOROLEVA	{"email": "valentinakoroleva.20061973@postgrespro.ru", "phone": "+70789644102"}
0005432966648	626931	3494 146017	ZOYA SERGEEVA	{"email": "z.sergeeva1971@postgrespro.ru", "phone": "+70099078001"}
0005432966649	452D43	7629 082961	DENIS MEDVEDEV	{"email": "denis.medvedev-031967@postgrespro.ru", "phone": "+70930208301"}
0005432966650	FEBB77	2391 653158	ANDREY FILIPPOV	{"email": "filippovandrey_091976@postgrespro.ru", "phone": "+70306848935"}
0005432966651	56C962	2382 167568	SVETLANA DANILOVA	{"email": "s_danilova09041979@postgrespro.ru", "phone": "+70406571467"}
0005432966652	56C962	6139 419772	EVGENIY KUZNECOV	{"phone": "+70188560097"}
0005432966653	30D367	1696 574322	TATYANA LEBEDEVA	{"email": "lebedeva.t1962@postgrespro.ru", "phone": "+70326894627"}
0005432966654	AB4D7E	1866 165311	VIKTOR VASILEV	{"email": "vasilev.viktor15091968@postgrespro.ru", "phone": "+70314265975"}
0005432966655	1CE253	6868 216669	ALINA POTAPOVA	{"phone": "+70803035334"}
0005432966656	814E70	6102 105005	NATALYA BELYAEVA	{"phone": "+70255067831"}
0005432966657	55BE94	0218 983138	KIRILL RODIONOV	{"phone": "+70193113126"}
0005432966658	55BE94	4483 737317	NINA VOLKOVA	{"email": "volkova-n05031970@postgrespro.ru", "phone": "+70451498657"}
0005432966659	55BE94	9125 338534	VALERIYA ZAYCEVA	{"phone": "+70485267148"}
0005432966660	55BE94	6491 394645	ANATOLIY FOMIN	{"phone": "+70616435412"}
0005432966661	751CF8	8154 461598	IRINA IVANOVA	{"phone": "+70870964247"}
0005432966662	751CF8	9650 928261	NINA KUZNECOVA	{"phone": "+70391251821"}
0005432966663	3F6F44	6372 294456	POLINA ZAKHAROVA	{"email": "p_zakharova_1967@postgrespro.ru", "phone": "+70452473776"}
0005432966664	3F6F44	8608 226777	VLADIMIR MELNIKOV	{"phone": "+70107237983"}
0005432966665	835331	9807 715224	VITALIY ZAKHAROV	{"phone": "+70872906308"}
0005432966666	81C5B5	1441 704176	LIDIYA SCHERBAKOVA	{"phone": "+70430559485"}
0005432966667	81C5B5	8176 618955	NATALYA SOROKINA	{"phone": "+70936331119"}
0005432966668	69115A	8991 688785	ALEKSANDR FOMIN	{"email": "fomin.a_111966@postgrespro.ru", "phone": "+70949572438"}
0005432966669	69115A	9888 505804	MIKHAIL SOROKIN	{"email": "sorokin.mikhail_1977@postgrespro.ru", "phone": "+70297559268"}
0005432966670	51A66A	4757 444956	OKSANA YAKOVLEVA	{"email": "yakovleva.oksana041977@postgrespro.ru", "phone": "+70541863070"}
0005432966671	0BDAC4	9160 341296	DMITRIY KOROLEV	{"email": "d-korolev09021958@postgrespro.ru", "phone": "+70359241376"}
0005432966672	F0BFA0	6149 854499	PAVEL YAKOVLEV	{"phone": "+70378284418"}
0005432966673	CB3A3D	3838 025533	LEONID SMIRNOV	{"phone": "+70178509146"}
0005432966674	F7D7F6	6403 695586	NINA KUZMINA	{"email": "nkuzmina.13111971@postgrespro.ru", "phone": "+70829043605"}
0005432966675	A84371	5678 970865	VLADIMIR SCHERBAKOV	{"phone": "+70002325416"}
0005432966676	DDDC8A	5470 049255	GALINA BOGDANOVA	{"email": "bogdanova_g.111976@postgrespro.ru", "phone": "+70641691749"}
0005432966677	A6826B	8822 817497	VALENTINA NIKITINA	{"email": "nikitinav.17111972@postgrespro.ru", "phone": "+70088700052"}
0005432966678	A6826B	5380 648782	OLEG MIRONOV	{"email": "o_mironov-29061975@postgrespro.ru", "phone": "+70109914629"}
0005432966679	A6826B	1882 411008	MAKSIM GAVRILOV	{"phone": "+70599694706"}
0005432966680	1BB969	2347 315975	MIKHAIL VLASOV	{"phone": "+70328033336"}
0005432966681	1BB969	7705 954156	VLADIMIR GUSEV	{"phone": "+70206203526"}
0005432966682	1BB969	7675 120759	VITALIY EGOROV	{"email": "egorov.v_011962@postgrespro.ru", "phone": "+70938233780"}
0005432966683	3F98A1	5618 899376	NATALYA MOISEEVA	{"phone": "+70396860563"}
0005432966684	3F98A1	5042 091255	MARIYA ARKHIPOVA	{"phone": "+70410643618"}
0005432966685	C009B5	9560 787555	ALBINA NAUMOVA	{"phone": "+70356519901"}
0005432966686	C009B5	8437 872697	DARYA GRISHINA	{"email": "grishina-darya_121974@postgrespro.ru", "phone": "+70316420864"}
0005432966687	FD6651	9610 797570	ANTONINA KUZNECOVA	{"phone": "+70675203428"}
0005432966688	4B298B	2932 564640	SOFIYA KUZNECOVA	{"email": "kuznecova_sofiya_1977@postgrespro.ru", "phone": "+70452635540"}
0005432966689	4B298B	9028 162587	LYUBOV MASLOVA	{"email": "maslova_l-17061968@postgrespro.ru", "phone": "+70770626476"}
0005432966690	4B298B	2316 020967	DMITRIY IVANOV	{"email": "ivanovd-011977@postgrespro.ru", "phone": "+70720923550"}
0005432966691	A30921	0137 349587	VALENTINA KUZNECOVA	{"phone": "+70445184838"}
0005432966692	746573	8973 951624	STANISLAV IVANOV	{"phone": "+70164865274"}
0005432966693	437210	7473 938955	SERGEY VASILEV	{"phone": "+70174018768"}
0005432966694	437210	1252 622001	VERA VOLKOVA	{"phone": "+70943142270"}
0005432966695	437210	2582 310408	VYACHESLAV KRASNOV	{"email": "krasnovvyacheslav051972@postgrespro.ru", "phone": "+70192030470"}
0005432966696	C3EF43	4065 853711	YURIY RODIONOV	{"email": "yuriy-rodionov_111976@postgrespro.ru", "phone": "+70078990696"}
0005432966697	2E32F4	5340 871161	ALEKSANDR AFANASEV	{"email": "afanasev-a_1971@postgrespro.ru", "phone": "+70801716721"}
0005432966698	B6DFA2	0359 217207	GALINA GAVRILOVA	{"email": "gavrilova.galina-041976@postgrespro.ru", "phone": "+70234586036"}
0005432966699	B6DFA2	2128 821335	DMITRIY KOROLEV	{"email": "korolev_d-1969@postgrespro.ru", "phone": "+70787216763"}
0005432966700	E85156	7014 929897	ALEKSEY VOROBEV	{"phone": "+70899554852"}
0005432966701	BF70D3	3157 707982	PETR KUZMIN	{"phone": "+70795900732"}
0005432966702	BF70D3	1812 419267	ALEKSEY KULIKOV	{"email": "aleksey-kulikov.20101968@postgrespro.ru", "phone": "+70393464562"}
0005432966703	F381EF	5490 281257	OLGA SCHERBAKOVA	{"phone": "+70594416259"}
0005432966704	D49AC8	2763 307654	LYUDMILA KOZLOVA	{"email": "kozlova.l-1982@postgrespro.ru", "phone": "+70380302857"}
0005432966705	894C5E	3769 765948	ROMAN SCHERBAKOV	{"phone": "+70343060941"}
0005432966706	894C5E	7204 339358	ROMAN STEPANOV	{"email": "r.stepanov_1974@postgrespro.ru", "phone": "+70154226418"}
0005432966707	9D6D5E	7653 723088	VLADIMIR SHEVCHENKO	{"phone": "+70851003565"}
0005432966708	8979BD	1936 287379	ILYA ZAKHAROV	{"phone": "+70728260356"}
0005432966709	8979BD	8436 538447	IVAN SCHERBAKOV	{"phone": "+70504210884"}
0005432966710	D30684	8438 323876	MAKSIM BONDARENKO	{"email": "mbondarenko04091980@postgrespro.ru", "phone": "+70031223363"}
0005432966711	420BD9	6643 227153	MARINA GRISHINA	{"phone": "+70803920584"}
0005432966712	4AE7FA	3454 929618	NINA MATVEEVA	{"email": "n.matveeva.021967@postgrespro.ru", "phone": "+70805932209"}
0005432966713	CD669F	5229 332009	MAKAR MEDVEDEV	{"phone": "+70937860457"}
0005432966714	CD669F	7398 193135	OLEG MIRONOV	{"phone": "+70745464500"}
0005432966715	CD669F	4781 877916	NATALYA GUSEVA	{"phone": "+70658062757"}
0005432966716	E44980	2317 179856	PAVEL NOVIKOV	{"email": "pavel-novikov081977@postgrespro.ru", "phone": "+70043950521"}
0005432966717	C23B1B	8020 794193	OLGA SMIRNOVA	{"email": "o-smirnova.101973@postgrespro.ru", "phone": "+70727686570"}
0005432966718	6F248E	8436 137843	OLGA ILINA	{"email": "olgailina111969@postgrespro.ru", "phone": "+70909008749"}
0005432966719	5DE780	8364 530953	ARTEM KARPOV	{"email": "karpov-a_1981@postgrespro.ru", "phone": "+70729750671"}
0005432966720	88B56B	6898 863193	ALEKSANDR EGOROV	{"email": "aleksandr-egorov.25071979@postgrespro.ru", "phone": "+70017993240"}
0005432966721	88B56B	7214 296744	VYACHESLAV SAVELEV	{"email": "v.savelev.1983@postgrespro.ru", "phone": "+70521333092"}
0005432966722	08D784	3049 681615	NAIL DENISOV	{"phone": "+70747277270"}
0005432966723	277DAB	2794 754115	ALEKSANDR PAVLOV	{"phone": "+70201430982"}
0005432966724	277DAB	0905 431091	ILYA ROMANOV	{"email": "romanov_ilya-09081971@postgrespro.ru", "phone": "+70116404967"}
0005432966725	277DAB	8457 838609	IRINA YAKOVLEVA	{"phone": "+70945745207"}
0005432966726	4E54E2	0760 644875	ALEKSANDR EGOROV	{"email": "egorov.a_1979@postgrespro.ru", "phone": "+70074128982"}
0005432966727	0831A9	8069 031723	NIKOLAY IVANOV	{"email": "ivanovnikolay_1979@postgrespro.ru", "phone": "+70580062502"}
0005432966728	0831A9	1855 725085	MAKSIM KOZLOV	{"phone": "+70644329656"}
0005432966729	2FF1CD	4220 986731	MILENA VOLKOVA	{"email": "milena.volkova-011966@postgrespro.ru", "phone": "+70018905494"}
0005432966730	730CDB	4276 883046	VERA MALYSHEVA	{"phone": "+70111529488"}
0005432966731	E08781	8934 030948	ALEKSANDR MAKAROV	{"phone": "+70907731364"}
0005432966732	476629	8231 671054	DANILA TIMOFEEV	{"phone": "+70165153693"}
0005432966733	4D29E0	6063 440943	GENNADIY NAZAROV	{"phone": "+70013283631"}
0005432966734	82E3AE	0132 032107	TATYANA SOLOVEVA	{"email": "solovevatatyana14081973@postgrespro.ru", "phone": "+70138419532"}
0005432966735	D3F0C9	4840 856955	NATALYA ABRAMOVA	{"email": "abramovanatalya_1975@postgrespro.ru", "phone": "+70907056826"}
0005432966736	D3F0C9	9142 602249	SERGEY PETROV	{"email": "petrov-sergey1982@postgrespro.ru", "phone": "+70728660183"}
0005432966737	AC904B	4617 860604	NATALIYA SOKOLOVA	{"phone": "+70936410182"}
0005432966738	FC5057	3196 961464	GALINA CHERNOVA	{"email": "chernova-galina_07061970@postgrespro.ru", "phone": "+70072559344"}
0005432966739	FC5057	8176 505154	SERGEY ZHURAVLEV	{"email": "s-zhuravlev.071980@postgrespro.ru", "phone": "+70276477499"}
0005432966740	C2A50F	1154 311088	POLINA PAVLOVA	{"email": "pavlova_polina.11081967@postgrespro.ru", "phone": "+70992203043"}
0005432966741	232FC3	3161 296809	TATYANA STEPANOVA	{"email": "stepanova_t_1974@postgrespro.ru", "phone": "+70472505135"}
0005432966742	F2F40F	9573 794876	ALEKSANDR ANDREEV	{"phone": "+70679071934"}
0005432966743	2B97E7	0666 716454	ILGIZ AFANASEV	{"phone": "+70361773299"}
0005432966744	7EB933	2117 357836	KARINA MIRONOVA	{"email": "kmironova.1975@postgrespro.ru", "phone": "+70161720842"}
0005432966745	A29631	1286 630622	YAN ZHUKOV	{"email": "yan_zhukov_111964@postgrespro.ru", "phone": "+70891629920"}
0005432966746	679728	3716 606910	ALEKSANDR GERASIMOV	{"phone": "+70390704604"}
0005432966747	679728	3722 741696	NADEZHDA MASLOVA	{"email": "maslova-n23051990@postgrespro.ru", "phone": "+70065064833"}
0005432966748	F91673	5189 872493	ANTONINA KISELEVA	{"phone": "+70967259763"}
0005432966749	3501AF	2968 421632	LEONID MAKAROV	{"email": "l.makarov_1980@postgrespro.ru", "phone": "+70132006142"}
0005432966750	3501AF	7761 399296	VALERIY PAVLOV	{"phone": "+70132388041"}
0005432966751	3501AF	5091 527962	IRINA SOLOVEVA	{"email": "i.soloveva-01051968@postgrespro.ru", "phone": "+70823840666"}
0005432966752	514B12	9700 655699	YURIY SEMENOV	{"email": "semenov.y.22021972@postgrespro.ru", "phone": "+70791398589"}
0005432966753	08F312	7613 311455	ANATOLIY DAVYDOV	{"email": "a-davydov-121976@postgrespro.ru", "phone": "+70802142752"}
0005432966754	1ECEE0	8282 142462	ZHANNA ROMANOVA	{"email": "zhanna-romanova-1972@postgrespro.ru", "phone": "+70178475185"}
0005432966755	1ECEE0	9039 346927	ALFIYA ROMANOVA	{"email": "romanova-alfiya.07011965@postgrespro.ru", "phone": "+70588505343"}
0005432966756	A62D22	4458 235647	NIKOLAY MIKHAYLOV	{"phone": "+70408163008"}
0005432966757	A62D22	7804 649102	ANATOLIY ANDREEV	{"email": "andreev.a.041964@postgrespro.ru", "phone": "+70955950549"}
0005432966758	D1055D	5271 390558	MARIYA MAKAROVA	{"email": "mariyamakarova_21031980@postgrespro.ru", "phone": "+70793221617"}
0005432966759	5E3C19	1742 542853	RAISA ZAYCEVA	{"phone": "+70761619637"}
0005432966760	5E3C19	6170 814186	ELENA IVANOVA	{"email": "elenaivanova_30111988@postgrespro.ru", "phone": "+70569925494"}
0005432966761	FE6E18	8656 648965	DMITRIY SMIRNOV	{"phone": "+70611523570"}
0005432966762	FE6E18	1280 692077	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov_1968@postgrespro.ru", "phone": "+70329739501"}
0005432966763	FE6E18	6225 284004	IRINA KOMAROVA	{"phone": "+70615064990"}
0005432966764	38617E	2135 139809	VADIM MIKHAYLOV	{"phone": "+70186467378"}
0005432966765	F8BA54	3374 287132	ELENA MAKAROVA	{"email": "e.makarova091978@postgrespro.ru", "phone": "+70079919237"}
0005432966766	4AEC0C	2373 165870	TATYANA ZOTOVA	{"email": "zotova_tatyana_071970@postgrespro.ru", "phone": "+70577472291"}
0005432966767	4AEC0C	0652 107741	EKATERINA VOLKOVA	{"email": "e-volkova_1978@postgrespro.ru", "phone": "+70438409030"}
0005432966768	9D1C96	8891 949592	SVETLANA FROLOVA	{"phone": "+70019282084"}
0005432966769	498A13	0660 644379	SERGEY MIRONOV	{"email": "sergeymironov.111957@postgrespro.ru", "phone": "+70194460115"}
0005432966770	498A13	9958 173149	OLGA ZOTOVA	{"phone": "+70227844953"}
0005432966771	AB5308	6242 108858	YANA SIDOROVA	{"phone": "+70465457061"}
0005432966772	41B887	0254 198883	YULIYA VOROBEVA	{"phone": "+70618793858"}
0005432966773	DEAC90	5662 601899	MARIYA GUSEVA	{"email": "guseva-mariya_05061975@postgrespro.ru", "phone": "+70005970290"}
0005432966774	6595FC	7902 020807	YANINA KAZAKOVA	{"phone": "+70632875196"}
0005432966775	A4E977	1786 688136	NATALYA EFREMOVA	{"email": "efremova-natalya-071978@postgrespro.ru", "phone": "+70462750794"}
0005432966776	B09060	1635 942273	VERA DANILOVA	{"email": "vera_danilova1980@postgrespro.ru", "phone": "+70498025436"}
0005432966777	444803	0915 833084	BORIS PAVLOV	{"phone": "+70655670993"}
0005432966778	444803	0714 662034	ARTEM KOZLOV	{"email": "artemkozlov091973@postgrespro.ru", "phone": "+70444085181"}
0005432966779	A2F746	3272 433606	VLADIMIR SMIRNOV	{"email": "v_smirnov.09021975@postgrespro.ru", "phone": "+70866200706"}
0005432966780	6E96FA	2126 197121	ALEKSANDR NOVIKOV	{"phone": "+70289676828"}
0005432966781	A644A3	0112 175579	VERA MOISEEVA	{"email": "vera_moiseeva.021976@postgrespro.ru", "phone": "+70500577965"}
0005432966782	69ACC3	0388 887067	SVETLANA LUKYANOVA	{"email": "lukyanovas.071966@postgrespro.ru", "phone": "+70335649898"}
0005432966783	69ACC3	9994 770618	DENIS STEPANOV	{"email": "dstepanov021971@postgrespro.ru", "phone": "+70427551848"}
0005432966784	69ACC3	2012 829281	SERGEY MEDVEDEV	{"phone": "+70989701124"}
0005432966785	1715C6	5744 267345	SERGEY MAKAROV	{"email": "sergey-makarov-09071967@postgrespro.ru", "phone": "+70479505638"}
0005432966786	BDA394	2871 168574	INESSA IVANOVA	{"phone": "+70190067380"}
0005432966787	F3F48E	1766 640918	DMITRIY IVANOV	{"email": "ivanovd.121968@postgrespro.ru", "phone": "+70959378497"}
0005432966788	F3F48E	3230 293344	ANNA GERASIMOVA	{"phone": "+70307985189"}
0005432966789	F3F48E	0095 593073	LIDIYA RYABOVA	{"phone": "+70652896542"}
0005432966790	43F09D	1321 933185	VLADIMIR ISAEV	{"email": "v_isaev.03021966@postgrespro.ru", "phone": "+70101413971"}
0005432966791	851502	8207 308438	GENNADIY ISAEV	{"email": "isaev-g_26011961@postgrespro.ru", "phone": "+70012690175"}
0005432966792	F8FBD6	1730 290087	OLGA POLYAKOVA	{"email": "olga.polyakova021981@postgrespro.ru", "phone": "+70310482548"}
0005432966793	27B1C0	6976 267158	GALINA KRASNOVA	{"email": "g_krasnova-041978@postgrespro.ru", "phone": "+70446314562"}
0005432966794	7F20A1	9807 281064	MARIYA ROMANOVA	{"email": "romanova_m_051959@postgrespro.ru", "phone": "+70477759353"}
0005432966795	7F20A1	6722 727709	ALENA TIKHONOVA	{"email": "a-tikhonova-25101978@postgrespro.ru", "phone": "+70788499998"}
0005432966796	419327	7169 477233	VLADIMIR KUZNECOV	{"phone": "+70492338516"}
0005432967130	A434D5	4632 080936	NIKOLAY KOZLOV	{"phone": "+70717198972"}
0005432966797	419327	6591 853958	ANNA BORISOVA	{"email": "a-borisova.1970@postgrespro.ru", "phone": "+70692545856"}
0005432966798	9AB6E8	2807 049866	SERGEY KUZNECOV	{"email": "s-kuznecov_1973@postgrespro.ru", "phone": "+70241420611"}
0005432966799	7A40F4	9946 408831	ANATOLIY KAZAKOV	{"phone": "+70154701419"}
0005432966800	7A40F4	4484 519810	ELIZAVETA MATVEEVA	{"email": "elizaveta_matveeva.1969@postgrespro.ru", "phone": "+70234201066"}
0005432966801	5E6DC9	4274 874895	DANILA KUZNECOV	{"phone": "+70128327549"}
0005432966802	5E6DC9	9275 211872	VLADIMIR DENISOV	{"phone": "+70911392277"}
0005432966803	B6E4CC	7123 221677	NIKOLAY IVANOV	{"phone": "+70200294620"}
0005432966804	F27760	1804 992104	RADIK TIKHONOV	{"email": "radik_tikhonov-1968@postgrespro.ru", "phone": "+70561621528"}
0005432966805	3D7F6B	7060 737404	IVAN KONOVALOV	{"email": "konovalov.ivan021964@postgrespro.ru", "phone": "+70006608715"}
0005432966806	D31087	9759 954080	ANNA NIKOLAEVA	{"phone": "+70770826762"}
0005432966807	D75235	0031 799203	ANATOLIY ROMANOV	{"email": "anatoliy.romanov29081967@postgrespro.ru", "phone": "+70540814884"}
0005432966808	758CF6	7796 166573	ALEKSANDR KONOVALOV	{"phone": "+70353541322"}
0005432966809	8A7066	8115 299207	ROMAN PAVLOV	{"email": "pavlovroman1957@postgrespro.ru", "phone": "+70502606356"}
0005432966810	8A7066	9040 077139	SERGEY ZHURAVLEV	{"phone": "+70912109791"}
0005432966811	8A7066	6072 831546	SVETLANA KONOVALOVA	{"phone": "+70874879813"}
0005432966812	6A0646	4352 436959	VITALIY FROLOV	{"phone": "+70277027590"}
0005432966814	E75455	9001 701704	ANDREY KARPOV	{"email": "akarpov_31101974@postgrespro.ru", "phone": "+70031692258"}
0005432966815	BA5401	6989 926560	SVETLANA KUZMINA	{"phone": "+70707485939"}
0005432966816	BA5401	3253 387307	ANDREY VLASOV	{"phone": "+70847431431"}
0005432966817	7B49FB	7530 871369	VERA FILATOVA	{"phone": "+70055258251"}
0005432966818	2AE980	8352 104429	ALEKSANDR BARANOV	{"email": "baranov.a.13021976@postgrespro.ru", "phone": "+70406967917"}
0005432966819	16AD69	4040 772297	MIKHAIL IVANOV	{"email": "ivanov_mikhail.071964@postgrespro.ru", "phone": "+70298350815"}
0005432966820	16AD69	6246 011160	VALENTINA POPOVA	{"email": "valentina_popova.09051966@postgrespro.ru", "phone": "+70171347574"}
0005432966821	B4A1C4	6234 502683	ELIZAVETA KOZLOVA	{"phone": "+70094733981"}
0005432966822	91E9A4	2460 869265	ANASTASIYA MATVEEVA	{"phone": "+70784509791"}
0005432966823	37DBBE	8238 486913	NATALYA MASLOVA	{"email": "maslovanatalya-031963@postgrespro.ru", "phone": "+70550465960"}
0005432966824	63B23F	0937 641086	ALSU ARKHIPOVA	{"phone": "+70567897394"}
0005432966825	63B23F	3355 143711	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay11051982@postgrespro.ru", "phone": "+70828246725"}
0005432966826	63B23F	5841 017194	ANDREY FEDOTOV	{"email": "a.fedotov.27011971@postgrespro.ru", "phone": "+70699868033"}
0005432966827	5E1782	6214 269377	NIKOLAY EGOROV	{"email": "nikolay-egorov-051976@postgrespro.ru", "phone": "+70934880902"}
0005432966828	39DF0D	6661 259899	PELAGEYA FADEEVA	{"phone": "+70446934005"}
0005432966829	39DF0D	4184 998807	EVGENIY KUZNECOV	{"phone": "+70374654029"}
0005432966830	B7DE26	2634 455940	ALEKSANDRA MAKAROVA	{"email": "aleksandra-makarova1965@postgrespro.ru", "phone": "+70027113314"}
0005432966831	9A0368	5023 785769	MAKSIM IVANOV	{"email": "ivanov.m_1965@postgrespro.ru", "phone": "+70859276289"}
0005432966832	EC4E0B	1816 255924	ANNA FROLOVA	{"phone": "+70087925026"}
0005432966833	5EF1C6	8243 661610	GALINA IVANOVA	{"email": "g-ivanova1966@postgrespro.ru", "phone": "+70735932771"}
0005432966834	5EF1C6	2323 248750	SERGEY MOROZOV	{"phone": "+70522359433"}
0005432966835	A48A82	3113 843694	ALISA ROMANOVA	{"phone": "+70874365798"}
0005432966836	A48A82	8293 161342	NATALYA ARKHIPOVA	{"email": "n.arkhipova_041976@postgrespro.ru", "phone": "+70090693084"}
0005432966837	A48A82	8728 959310	SOFYA EGOROVA	{"phone": "+70275795659"}
0005432966838	477CBA	1754 244229	EKATERINA NESTEROVA	{"phone": "+70963121692"}
0005432966839	784F0F	3627 477594	ALEVTINA ANTONOVA	{"phone": "+70067621488"}
0005432966840	784F0F	8053 636539	ANDREY AFANASEV	{"email": "afanasev-a-1976@postgrespro.ru", "phone": "+70768521525"}
0005432966841	2BFD52	1047 029425	IVAN SEMENOV	{"phone": "+70846718875"}
0005432966842	2BFD52	7109 134654	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr-1982@postgrespro.ru", "phone": "+70194253204"}
0005432966843	28702B	5590 620343	OLESYA KUZNECOVA	{"phone": "+70528550838"}
0005432966844	C7AB11	8425 584790	ALEKSANDR POPOV	{"phone": "+70689568499"}
0005432966845	04D7FB	5073 249206	MARIYA SOKOLOVA	{"email": "msokolova.1968@postgrespro.ru", "phone": "+70231462346"}
0005432966846	32D81D	9850 571313	ANDREY EGOROV	{"email": "andrey.egorov011975@postgrespro.ru", "phone": "+70011208080"}
0005432966847	32D81D	3986 038688	ANNA KOROLEVA	{"email": "akoroleva.1970@postgrespro.ru", "phone": "+70863173970"}
0005432966848	9012D1	6604 195510	RINAT NIKOLAEV	{"email": "nikolaev-rinat-111966@postgrespro.ru", "phone": "+70633875227"}
0005432966849	1C2758	5812 862564	ANATOLIY ROMANOV	{"phone": "+70742243935"}
0005432966850	5C9A63	6647 308740	PAVEL MOROZOV	{"phone": "+70594782655"}
0005432966851	5C9A63	4056 984062	VALENTINA SERGEEVA	{"phone": "+70583282907"}
0005432966852	414E67	3271 170869	GALINA ARKHIPOVA	{"phone": "+70986227730"}
0005432966853	5A26EF	0139 777642	MAKSIM MOROZOV	{"phone": "+70030204214"}
0005432966854	F3B345	5821 424485	TATYANA SOKOLOVA	{"email": "tatyana_sokolova_081972@postgrespro.ru", "phone": "+70513738838"}
0005432966855	F3B345	3059 010728	ELENA LAZAREVA	{"email": "lazareva-elena.081965@postgrespro.ru", "phone": "+70455803114"}
0005432966856	7CE243	7496 839936	ANNA MOISEEVA	{"phone": "+70804569006"}
0005432966857	7CE243	8041 382517	IRINA VASILEVA	{"email": "vasileva_irina-011977@postgrespro.ru", "phone": "+70376649740"}
0005432966858	22C672	4360 945019	NATALYA MAKAROVA	{"email": "n.makarova-051973@postgrespro.ru", "phone": "+70738049127"}
0005432966859	719250	4277 010133	YULIYA ANDREEVA	{"email": "yuliya.andreeva_31121981@postgrespro.ru", "phone": "+70207512840"}
0005432966860	719250	0258 237544	DMITRIY ALEKSANDROV	{"email": "aleksandrov.d-20071974@postgrespro.ru", "phone": "+70630590054"}
0005432966861	3EF425	2979 094919	KLAVDIYA GRISHINA	{"phone": "+70322645326"}
0005432966862	5E6B77	4042 265999	MIKHAIL NAZAROV	{"phone": "+70546919413"}
0005432966863	A7CE9C	4585 886518	OKSANA NAUMOVA	{"phone": "+70759687416"}
0005432966864	D7C50B	0518 393351	ELENA KUZNECOVA	{"phone": "+70399205128"}
0005432966865	96911D	3639 940676	LIYA STEPANOVA	{"phone": "+70535557673"}
0005432966866	96911D	4110 461104	RUSLAN DENISOV	{"phone": "+70008729437"}
0005432966867	72C52B	0419 919463	ALEKSANDR BONDARENKO	{"email": "a-bondarenko_07101977@postgrespro.ru", "phone": "+70863621353"}
0005432966868	8D5BD3	5004 656064	ILDUS MAKSIMOV	{"phone": "+70797499239"}
0005432966869	8D5BD3	8620 484958	EKATERINA MAKAROVA	{"email": "ekaterina_makarova-1966@postgrespro.ru", "phone": "+70364099999"}
0005432966870	8D5BD3	4577 224041	ALEKSEY EGOROV	{"phone": "+70352242852"}
0005432966871	B918A3	0846 151132	ANASTASIYA SOKOLOVA	{"phone": "+70872769837"}
0005432966872	16601B	9829 031557	OLGA KUZNECOVA	{"email": "olga.kuznecova.02081973@postgrespro.ru", "phone": "+70439477197"}
0005432966873	16601B	4283 198319	KSENIYA KOMAROVA	{"phone": "+70596472122"}
0005432966874	612621	7657 975415	NIKITA PETROV	{"email": "nikitapetrov1967@postgrespro.ru", "phone": "+70026873793"}
0005432966875	EDB1C0	0108 341791	VLADIMIR SIDOROV	{"phone": "+70970063091"}
0005432966876	E06A37	0499 051995	ANASTASIYA KALININA	{"email": "akalinina.1968@postgrespro.ru", "phone": "+70363162492"}
0005432966877	5833E9	6079 983055	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov-22071966@postgrespro.ru", "phone": "+70649097489"}
0005432966878	5833E9	6596 882099	MARINA ALEKSEEVA	{"email": "marina_alekseeva-061969@postgrespro.ru", "phone": "+70803746032"}
0005432966879	326AD6	0881 847766	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev_051974@postgrespro.ru", "phone": "+70236154025"}
0005432966880	FBEE91	1188 075177	YAROSLAV NIKOLAEV	{"email": "y.nikolaev101982@postgrespro.ru", "phone": "+70418680804"}
0005432966881	818493	8041 607371	GALINA MARTYNOVA	{"email": "martynovag1982@postgrespro.ru", "phone": "+70518743360"}
0005432966882	B49070	4446 202622	MARIYA CHERNOVA	{"phone": "+70089905062"}
0005432966883	B49070	8996 122954	SERGEY TARASOV	{"email": "sergey.tarasov.1980@postgrespro.ru", "phone": "+70240271619"}
0005432966884	D7C8F7	6453 379624	NIKOLAY SERGEEV	{"email": "n-sergeev_06111974@postgrespro.ru", "phone": "+70382435686"}
0005432966885	93DF0C	0588 738296	VALERIYA KALININA	{"phone": "+70833682643"}
0005432966886	93DF0C	7696 197595	LILIYA DENISOVA	{"email": "denisoval1974@postgrespro.ru", "phone": "+70382824780"}
0005432966887	6BB887	5873 288704	VALENTINA GUSEVA	{"phone": "+70832697663"}
0005432966888	636820	1109 585170	NIKOLAY MAKAROV	{"email": "makarov.nikolay12051980@postgrespro.ru", "phone": "+70245679828"}
0005432966889	636820	5608 130894	RUSLAN ANDREEV	{"phone": "+70719983431"}
0005432966890	3BB24E	4283 407232	YULIYA NESTEROVA	{"email": "nesterova.y1970@postgrespro.ru", "phone": "+70832430417"}
0005432966891	3D4D05	7127 908182	EKATERINA SMIRNOVA	{"phone": "+70874521242"}
0005432966892	3D4D05	9371 951325	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr_101971@postgrespro.ru", "phone": "+70934023667"}
0005432966893	C72982	0239 354856	ALEKSEY ZAYCEV	{"phone": "+70608012323"}
0005432966894	23A990	3704 424627	YURIY TIMOFEEV	{"phone": "+70916263968"}
0005432966895	23A990	2472 100924	ELENA GAVRILOVA	{"email": "gavrilova-elena-29031964@postgrespro.ru", "phone": "+70528404883"}
0005432966896	CB69D2	3378 425628	YULIYA ZHUKOVA	{"phone": "+70848480112"}
0005432966897	7462BA	1278 590349	VLADIMIR SEMENOV	{"phone": "+70566922502"}
0005432966898	7462BA	8909 475704	SVETLANA LEBEDEVA	{"email": "svetlana.lebedeva_1966@postgrespro.ru", "phone": "+70650178020"}
0005432966899	131DBA	0232 307233	OLGA NIKITINA	{"email": "nikitina-olga_061977@postgrespro.ru", "phone": "+70362216641"}
0005432966900	4BA6AA	7892 394612	NATALYA GAVRILOVA	{"email": "gavrilova.n_101975@postgrespro.ru", "phone": "+70066876120"}
0005432966901	C23D3C	5221 190887	VERA LEBEDEVA	{"email": "v.lebedeva-1965@postgrespro.ru", "phone": "+70233195427"}
0005432966902	15B973	9240 840918	IVAN VOROBEV	{"phone": "+70054948745"}
0005432966903	9A6286	1319 330209	SVETLANA ZAKHAROVA	{"email": "zakharovasvetlana_1977@postgrespro.ru", "phone": "+70116937375"}
0005432966904	9A6286	6684 781972	NATALYA EGOROVA	{"phone": "+70897083167"}
0005432966905	9A6286	6898 762360	ANATOLIY IVANOV	{"phone": "+70635004435"}
0005432966906	D86759	3580 039149	ALEKSEY KOZLOV	{"email": "kozlov-a-091979@postgrespro.ru", "phone": "+70936880704"}
0005432966907	D86759	7090 447329	TATYANA KULIKOVA	{"phone": "+70651200285"}
0005432966908	AC78F8	0539 519247	ANASTASIYA ZAKHAROVA	{"email": "zakharova-anastasiya.051975@postgrespro.ru", "phone": "+70830092380"}
0005432966909	6CC15C	8500 527064	IRINA ZHURAVLEVA	{"email": "zhuravleva_i.091974@postgrespro.ru", "phone": "+70449832505"}
0005432966910	6CC15C	4262 417564	EVDOKIYA SOKOLOVA	{"email": "evdokiyasokolova.091962@postgrespro.ru", "phone": "+70968048537"}
0005432966911	56FA73	4551 137801	DARINA MOISEEVA	{"email": "darina-moiseeva-11111965@postgrespro.ru", "phone": "+70950022859"}
0005432966912	7902C1	0018 039223	NATALYA LAZAREVA	{"email": "lazarevan.1967@postgrespro.ru", "phone": "+70617360196"}
0005432966913	7902C1	6793 793687	NINA NIKITINA	{"phone": "+70334336451"}
0005432966914	956E04	4101 819740	EKATERINA MEDVEDEVA	{"email": "medvedeva-e-1981@postgrespro.ru", "phone": "+70808127000"}
0005432966915	C74A88	1154 028057	ANNA FILIPPOVA	{"phone": "+70895760980"}
0005432966916	C74A88	7461 645293	ZHANNA SCHERBAKOVA	{"phone": "+70363927576"}
0005432966917	C74A88	2715 922691	KRISTINA STEPANOVA	{"email": "kristina_stepanova03101967@postgrespro.ru", "phone": "+70454579696"}
0005432966918	C6FF73	6303 208080	MARINA CHERNOVA	{"phone": "+70954974746"}
0005432966919	839EDF	6901 111458	ANDREY VOROBEV	{"phone": "+70652267483"}
0005432966920	839EDF	5386 875451	NIKOLAY SOROKIN	{"phone": "+70186009911"}
0005432966921	1A1156	5190 269540	NIKITA KRASNOV	{"email": "krasnov-n-1979@postgrespro.ru", "phone": "+70408312775"}
0005432966922	D22121	7919 679728	ILMIR NIKOLAEV	{"email": "i_nikolaev-19111964@postgrespro.ru", "phone": "+70066182718"}
0005432966923	555F2D	4914 928687	LYUBOV SERGEEVA	{"phone": "+70407641767"}
0005432966924	1BD5E6	0282 723323	IVAN TARASOV	{"email": "tarasov-i_071976@postgrespro.ru", "phone": "+70157368591"}
0005432966925	1BD5E6	1563 176264	ANNA BORISOVA	{"email": "borisova_anna.1968@postgrespro.ru", "phone": "+70079643758"}
0005432966926	1BD5E6	8124 333244	ALEKSANDR ALEKSANDROV	{"phone": "+70300864350"}
0005432966927	05D8C1	5494 407304	ALEKSANDR KUZMIN	{"phone": "+70075525378"}
0005432966928	72ADED	5276 761657	MAKSIM AFANASEV	{"email": "maksimafanasev_061973@postgrespro.ru", "phone": "+70244409201"}
0005432966929	72ADED	5395 113732	YULIYA NOVIKOVA	{"phone": "+70429900748"}
0005432966930	EA1826	5460 532301	ALEKSANDR SAVELEV	{"email": "aleksandr.savelev-1967@postgrespro.ru", "phone": "+70316145253"}
0005432966931	561661	0304 001019	ANDREY NIKITIN	{"phone": "+70011926470"}
0005432966932	0EBADD	4837 175706	SERGEY ZAYCEV	{"email": "zaycev_s-29011983@postgrespro.ru", "phone": "+70987171039"}
0005432966933	1BA965	9306 770421	VYACHESLAV MIRONOV	{"email": "vyacheslavmironov-091982@postgrespro.ru", "phone": "+70169198437"}
0005432966993	C5BE46	4441 891689	ELENA SOKOLOVA	{"phone": "+70611894061"}
0005432966934	3BC6B6	6492 526940	SEMEN SCHERBAKOV	{"email": "s_scherbakov27081987@postgrespro.ru", "phone": "+70276834717"}
0005432966935	232DD3	2194 601728	ALEKSANDR GUSEV	{"phone": "+70608187949"}
0005432966936	EFECE7	2402 563165	NADEZHDA KUDRYASHOVA	{"email": "nadezhda-kudryashova.111977@postgrespro.ru", "phone": "+70009403382"}
0005432966937	A9AF14	9450 940795	ELENA IVANOVA	{"phone": "+70666068475"}
0005432966938	A9AF14	5730 076459	DENIS VLASOV	{"phone": "+70944247782"}
0005432966939	C5A386	5786 183148	VIKTOR FEDOROV	{"phone": "+70822002687"}
0005432966940	08D2C6	9063 500944	DENIS MAKSIMOV	{"phone": "+70559272560"}
0005432966941	EA6BF2	2465 273097	ALEKSANDR ANDREEV	{"email": "aandreev051967@postgrespro.ru", "phone": "+70953785960"}
0005432966942	EA6BF2	0701 290285	ALEKSEY KUZNECOV	{"email": "kuznecova.30081975@postgrespro.ru", "phone": "+70025993066"}
0005432967167	7429DA	9384 638453	ANASTASIYA ROMANOVA	{"phone": "+70356634103"}
0005432966943	BD76DA	4909 488095	ANNA NAZAROVA	{"email": "anazarova-041973@postgrespro.ru", "phone": "+70017078392"}
0005432966944	771E29	5810 782991	ALEKSEY EGOROV	{"email": "a_egorov101969@postgrespro.ru", "phone": "+70895118956"}
0005432966945	33256A	7749 276448	NIKOLAY PETROV	{"phone": "+70247358774"}
0005432966946	73FA66	8438 135558	DILYARA NIKITINA	{"phone": "+70244117998"}
0005432966947	73FA66	4409 328624	GENNADIY PAVLOV	{"phone": "+70893201432"}
0005432966948	A84EBA	6635 252567	ALEKSANDR KUZNECOV	{"email": "kuznecova-061970@postgrespro.ru", "phone": "+70471873112"}
0005432966949	4F07F0	0695 025386	YANA NIKIFOROVA	{"phone": "+70407343611"}
0005432966950	4F07F0	4513 455305	NINA TARASOVA	{"phone": "+70520504011"}
0005432966951	3A3407	9992 551330	DANIIL TIKHONOV	{"email": "d.tikhonov-1965@postgrespro.ru", "phone": "+70666778530"}
0005432966952	3FBCDB	0288 817968	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin20081973@postgrespro.ru", "phone": "+70174460859"}
0005432966953	EE655D	1347 321052	SERGEY MAKAROV	{"phone": "+70557513400"}
0005432966954	84C4A3	4749 602206	DMITRIY FEDOTOV	{"phone": "+70870925095"}
0005432966955	84C4A3	2855 118159	STANISLAV PAVLOV	{"email": "stanislav.pavlov-18071975@postgrespro.ru", "phone": "+70510032206"}
0005432966956	2AA216	3675 588019	VITALIY ANDREEV	{"phone": "+70568908284"}
0005432966957	3331E4	0432 748279	LYUDMILA NIKIFOROVA	{"phone": "+70140726975"}
0005432966958	6A2B7F	0340 803476	POLINA VOROBEVA	{"phone": "+70084512781"}
0005432966959	3E7B1C	4025 059160	VLADIMIR SIDOROV	{"email": "vladimir_sidorov.1971@postgrespro.ru", "phone": "+70693303180"}
0005432966960	0A0B83	0632 086631	VERA POPOVA	{"phone": "+70704724346"}
0005432966961	6716C7	1275 145878	ALENA KOROLEVA	{"email": "alena_koroleva-13041981@postgrespro.ru", "phone": "+70631029830"}
0005432966962	6716C7	4407 367165	NADEZHDA KONOVALOVA	{"phone": "+70935706974"}
0005432966963	594F16	2748 256925	NADEZHDA TIMOFEEVA	{"email": "n.timofeeva1966@postgrespro.ru", "phone": "+70899388337"}
0005432966964	594F16	9544 552545	SERGEY MIKHAYLOV	{"email": "smikhaylov.1979@postgrespro.ru", "phone": "+70302126860"}
0005432966965	989308	4970 351120	MIKHAIL NOVIKOV	{"email": "novikov_m_041983@postgrespro.ru", "phone": "+70073365213"}
0005432966966	6DFF51	8149 521813	DANIIL NIKITIN	{"email": "nikitin_d-061975@postgrespro.ru", "phone": "+70564084189"}
0005432966967	DF6CD1	5474 815517	VITALIY KISELEV	{"phone": "+70313017130"}
0005432966968	274A28	9401 359277	DMITRIY MATVEEV	{"email": "matveev-dmitriy_111960@postgrespro.ru", "phone": "+70381470629"}
0005432966969	2C0438	2763 688988	ARINA ANTONOVA	{"phone": "+70923751333"}
0005432966970	780662	2238 194480	BOGDAN ZAKHAROV	{"email": "zakharovbogdan.02051980@postgrespro.ru", "phone": "+70551756495"}
0005432966971	38CB2B	0618 619936	SERGEY VOROBEV	{"email": "s.vorobev_05101983@postgrespro.ru", "phone": "+70314881080"}
0005432966972	845BC7	5384 291956	NADEZHDA KOROLEVA	{"email": "nadezhda.koroleva_27091964@postgrespro.ru", "phone": "+70069930294"}
0005432966973	D2FC41	8427 221790	ANDREY KAZAKOV	{"email": "kazakov_andrey-1975@postgrespro.ru", "phone": "+70159006406"}
0005432966974	D60D11	3046 856148	EVGENIY KULIKOV	{"phone": "+70316199784"}
0005432966975	D60D11	9734 558823	VASILIY CHERNOV	{"email": "chernovvasiliy031976@postgrespro.ru", "phone": "+70649766935"}
0005432966976	1C38CB	7853 308582	DANIL POPOV	{"email": "danilpopov_111986@postgrespro.ru", "phone": "+70353568173"}
0005432966977	23FDB7	2448 693135	ZINAIDA ROMANOVA	{"phone": "+70131350477"}
0005432966978	23FDB7	1842 119348	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr1973@postgrespro.ru", "phone": "+70206309948"}
0005432966979	F07F21	4649 453795	ANASTASIYA KAZAKOVA	{"email": "anastasiya-kazakova101968@postgrespro.ru", "phone": "+70290801232"}
0005432966980	F07F21	8946 752275	NINA ALEKSANDROVA	{"phone": "+70566816498"}
0005432966981	EA1ABA	7214 110488	VLADISLAV NIKOLAEV	{"phone": "+70700920459"}
0005432966982	CCE7F4	4485 192656	DMITRIY MAKAROV	{"phone": "+70817564463"}
0005432966983	7A3C77	1881 669918	ANTON SOROKIN	{"email": "a_sorokin_19091971@postgrespro.ru", "phone": "+70777309181"}
0005432966984	7A3C77	9200 881929	ARTEM SIDOROV	{"phone": "+70303816319"}
0005432966985	7A3C77	1217 429584	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-27091969@postgrespro.ru", "phone": "+70924074285"}
0005432966986	8C56CC	8730 216572	LILIYA FEDOROVA	{"phone": "+70709373347"}
0005432966987	8C56CC	1478 715317	OKSANA POPOVA	{"phone": "+70829854007"}
0005432966988	DDE3E6	4171 292681	NINA EFIMOVA	{"email": "nina-efimova02071983@postgrespro.ru", "phone": "+70683239580"}
0005432966989	F250BC	5310 569619	RADIK GORBUNOV	{"email": "gorbunovradik-08031974@postgrespro.ru", "phone": "+70651588660"}
0005432966990	2DBA08	4815 551065	ANASTASIYA GRISHINA	{"phone": "+70130910761"}
0005432966991	59F4C3	2766 791710	STEPAN VOROBEV	{"email": "vorobev.stepan.1978@postgrespro.ru", "phone": "+70278434246"}
0005432966992	C37D28	6974 607397	ALEKSEY NAUMOV	{"email": "naumov-aleksey111970@postgrespro.ru", "phone": "+70550542723"}
0005432966994	DB7305	0882 179064	MIKHAIL DAVYDOV	{"email": "davydov.mikhail_1974@postgrespro.ru", "phone": "+70161679276"}
0005432966995	27E341	2435 170514	GENNADIY KAZAKOV	{"phone": "+70186571335"}
0005432966996	C80111	6026 922994	SVETLANA GORBUNOVA	{"phone": "+70207896524"}
0005432966997	21836D	6880 774362	NIKITA ILIN	{"email": "nilin1978@postgrespro.ru", "phone": "+70682787798"}
0005432966998	0623A4	9768 761745	VALENTINA FROLOVA	{"email": "valentinafrolova-021981@postgrespro.ru", "phone": "+70720676848"}
0005432966999	ECD74E	9715 150530	RUMIYA ROMANOVA	{"email": "romanova-r.1971@postgrespro.ru", "phone": "+70467122581"}
0005432967000	4071A1	5327 070277	LYUBOV DMITRIEVA	{"email": "l-dmitrieva_11031977@postgrespro.ru", "phone": "+70090882598"}
0005432967001	2F77A0	0889 620031	SERGEY DAVYDOV	{"phone": "+70642978744"}
0005432967002	ED0D7A	1763 747995	OLGA ILINA	{"email": "olgailina-111964@postgrespro.ru", "phone": "+70370612811"}
0005432967003	ED0D7A	6880 811868	ELIZAVETA FOMINA	{"email": "fomina.elizaveta-1972@postgrespro.ru", "phone": "+70858679940"}
0005432967004	8E0140	6271 188147	YURIY SERGEEV	{"email": "sergeev.y-071972@postgrespro.ru", "phone": "+70018492761"}
0005432967005	8E0140	9531 504119	VALENTINA FADEEVA	{"email": "v_fadeeva04091964@postgrespro.ru", "phone": "+70815888682"}
0005432967006	AE7486	4303 644908	EKATERINA ZAYCEVA	{"email": "ezayceva.1984@postgrespro.ru", "phone": "+70015163039"}
0005432967007	1D777C	3372 539130	ARTEM ZAKHAROV	{"email": "a.zakharov021955@postgrespro.ru", "phone": "+70132011084"}
0005432967008	8972C3	6621 435653	LYUBOV FEDOROVA	{"email": "l_fedorova-1973@postgrespro.ru", "phone": "+70740670508"}
0005432967009	518B85	8609 914362	ALENA ZHURAVLEVA	{"email": "zhuravleva.alena.111970@postgrespro.ru", "phone": "+70576690143"}
0005432967010	7CC945	9028 929890	NATALYA DANILOVA	{"phone": "+70799217269"}
0005432967011	2D1F50	4003 167180	OLGA OVCHINNIKOVA	{"email": "olga_ovchinnikova-28041962@postgrespro.ru", "phone": "+70991399081"}
0005432967012	B506DD	2583 728320	VALENTINA OSIPOVA	{"email": "valentina-osipova-041985@postgrespro.ru", "phone": "+70538820007"}
0005432967013	4CBD01	1138 009735	SERGEY IVANOV	{"email": "ivanov.sergey-19111972@postgrespro.ru", "phone": "+70608205318"}
0005432967014	583ABF	2570 304022	VLADIMIR DAVYDOV	{"email": "davydovvladimir-1981@postgrespro.ru", "phone": "+70043342984"}
0005432967015	759A87	1859 627024	VASILIY MATVEEV	{"phone": "+70633791206"}
0005432967016	04B8CF	5322 155016	TATYANA MOROZOVA	{"phone": "+70775346346"}
0005432967017	6D97E8	8735 827195	ALEKSANDR TIKHONOV	{"phone": "+70665114680"}
0005432967018	FB891A	7628 472349	SVETLANA VOROBEVA	{"phone": "+70283248229"}
0005432967019	81041C	7991 574605	SVETLANA ZHUKOVA	{"email": "zhukova-svetlana-1981@postgrespro.ru", "phone": "+70044849983"}
0005432967020	81041C	8752 535252	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy.1976@postgrespro.ru", "phone": "+70421367855"}
0005432967021	5A1ED3	7610 658235	ANATOLIY GUSEV	{"phone": "+70854475958"}
0005432967022	F6AFA5	2311 715663	NINA GERASIMOVA	{"email": "nina.gerasimova-20081967@postgrespro.ru", "phone": "+70838496037"}
0005432967023	9965B0	7301 990802	NATALYA AFANASEVA	{"email": "afanaseva.natalya14021968@postgrespro.ru", "phone": "+70713861967"}
0005432967024	9965B0	2127 575282	ARTEM SOKOLOV	{"email": "sokolovartem-1968@postgrespro.ru", "phone": "+70454739133"}
0005432967025	044905	7050 191259	MARIYA GAVRILOVA	{"phone": "+70463053012"}
0005432967026	044905	2321 806834	OLGA CHERNOVA	{"email": "o-chernova_23041960@postgrespro.ru", "phone": "+70207951238"}
0005432967027	1D0665	3356 171320	MARIYA MOROZOVA	{"email": "morozovam_071964@postgrespro.ru", "phone": "+70857162592"}
0005432967028	1AACFD	9926 513736	VYACHESLAV FOMIN	{"phone": "+70475386655"}
0005432967029	7018B9	2975 830660	ALLA IVANOVA	{"email": "allaivanova.1970@postgrespro.ru", "phone": "+70507622874"}
0005432967030	21986A	9411 238284	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov-1974@postgrespro.ru", "phone": "+70553421981"}
0005432967031	55A7C9	2297 550102	IRINA DMITRIEVA	{"email": "idmitrieva30051977@postgrespro.ru", "phone": "+70251707275"}
0005432967032	BC8CA1	0655 461840	TATYANA EGOROVA	{"phone": "+70818875809"}
0005432967033	DD6BF3	5134 940446	ANNA ALEKSANDROVA	{"email": "anna-aleksandrova_091981@postgrespro.ru", "phone": "+70769763381"}
0005432967034	65B6B1	3277 020925	ANDREY KONOVALOV	{"email": "andreykonovalov.031971@postgrespro.ru", "phone": "+70554514195"}
0005432967035	C11774	9528 426621	DANILA PETROV	{"phone": "+70482914398"}
0005432967036	43DF56	6529 499138	OKSANA DANILOVA	{"phone": "+70758538639"}
0005432967037	E92FF8	7492 935238	ARTEM ALEKSANDROV	{"phone": "+70333502824"}
0005432967038	75A548	4209 683061	YAROSLAV ZHURAVLEV	{"phone": "+70735530300"}
0005432967039	3FC918	3824 903638	TATYANA NAZAROVA	{"email": "t.nazarova-1967@postgrespro.ru", "phone": "+70257219314"}
0005432967040	CC17ED	9838 718067	MARGARITA KUZNECOVA	{"email": "kuznecovamargarita011974@postgrespro.ru", "phone": "+70876316223"}
0005432967041	4AB73C	2382 215923	OLEG ANTONOV	{"email": "antonov_o_19011978@postgrespro.ru", "phone": "+70931348056"}
0005432967042	665F8F	7552 266469	VALENTINA MATVEEVA	{"email": "valentinamatveeva-121969@postgrespro.ru", "phone": "+70018453668"}
0005432967043	665F8F	7317 937573	OLESYA SOKOLOVA	{"phone": "+70690504285"}
0005432967044	665F8F	5380 836512	OLEG KUZNECOV	{"email": "o.kuznecov.29111973@postgrespro.ru", "phone": "+70520924596"}
0005432967045	480D65	0591 659647	MIKHAIL EGOROV	{"phone": "+70378523761"}
0005432967046	480D65	5340 123672	YULIYA ORLOVA	{"email": "orlova-yuliya.021960@postgrespro.ru", "phone": "+70289235967"}
0005432967047	FC1E78	9529 065204	OLGA DMITRIEVA	{"phone": "+70449041690"}
0005432967048	27190B	4635 193460	NATALYA ZOTOVA	{"email": "zotova_natalya.03091975@postgrespro.ru", "phone": "+70174649767"}
0005432967049	27190B	6646 062631	ANASTASIYA SEMENOVA	{"email": "semenova_anastasiya_091970@postgrespro.ru", "phone": "+70725894740"}
0005432967050	4473DB	1075 590528	ELENA MIKHAYLOVA	{"email": "mikhaylovaelena-021967@postgrespro.ru", "phone": "+70120941314"}
0005432967051	CEB358	4028 219107	ANTONINA FOMINA	{"email": "fomina_a.1972@postgrespro.ru", "phone": "+70778853350"}
0005432967052	7493F9	6439 583143	PAVEL KUZMIN	{"phone": "+70235729773"}
0005432967053	7EBBFB	8709 651958	ANTON STEPANOV	{"phone": "+70313469078"}
0005432967054	F2477D	4624 182378	NATALYA IVANOVA	{"email": "ivanovanatalya.091961@postgrespro.ru", "phone": "+70908724795"}
0005432967055	EDE727	2516 313222	LYUDMILA BELYAEVA	{"phone": "+70662700611"}
0005432967056	E24F7E	7129 258485	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana_1974@postgrespro.ru", "phone": "+70280614946"}
0005432967057	1D2F94	5493 604587	EVGENIYA ZAKHAROVA	{"email": "e-zakharova011966@postgrespro.ru", "phone": "+70164169144"}
0005432967058	AEE540	6185 241814	SVETLANA KOROLEVA	{"phone": "+70274184594"}
0005432967059	AEE540	5254 521822	VLADISLAV KAZAKOV	{"email": "kazakovvladislav.1972@postgrespro.ru", "phone": "+70100088335"}
0005432967060	A71AE8	4488 033042	ANDREY NIKOLAEV	{"email": "nikolaev-a.03081978@postgrespro.ru", "phone": "+70677896237"}
0005432967061	A71AE8	2441 002974	YULIYA FROLOVA	{"phone": "+70449104506"}
0005432967062	14C63B	7899 658952	ANASTASIYA POLYAKOVA	{"email": "anastasiya.polyakova-061974@postgrespro.ru", "phone": "+70861598788"}
0005432967063	63DBB4	8799 061076	DMITRIY SOKOLOV	{"phone": "+70330499110"}
0005432967064	63DBB4	5726 988644	OLGA MASLOVA	{"email": "olga_maslova-14031979@postgrespro.ru", "phone": "+70692689853"}
0005432967065	3258ED	2429 982580	ELENA VOLKOVA	{"phone": "+70262774424"}
0005432967066	3258ED	6876 933646	DMITRIY TARASOV	{"email": "dmitriy_tarasov.021966@postgrespro.ru", "phone": "+70434082191"}
0005432967067	00274A	7892 233122	IRAIDA DAVYDOVA	{"phone": "+70994930348"}
0005432967068	98B4BC	7982 533409	SERGEY CHERNOV	{"email": "chernovs021969@postgrespro.ru", "phone": "+70595472105"}
0005432967069	3278D8	9375 634804	IGOR KUZNECOV	{"email": "kuznecovigor-1981@postgrespro.ru", "phone": "+70155140234"}
0005432967070	0E989C	1364 633309	ELIZAVETA SOROKINA	{"email": "sorokina_e.1964@postgrespro.ru", "phone": "+70837618724"}
0005432967071	0E989C	5215 163461	SVETLANA EFREMOVA	{"email": "efremovasvetlana1971@postgrespro.ru", "phone": "+70228590196"}
0005432967072	9E0478	5213 306691	OLEG SEMENOV	{"email": "oleg-semenov-121974@postgrespro.ru", "phone": "+70171809985"}
0005432967131	9C8E0E	3328 642802	LARISA KUZNECOVA	{"phone": "+70487903057"}
0005432967073	6FE0D9	8111 698978	MARIYA KUZNECOVA	{"email": "kuznecova-mariya-26041981@postgrespro.ru", "phone": "+70178319088"}
0005432967074	6FE0D9	4422 758522	ARTEM VLASOV	{"phone": "+70947644890"}
0005432967075	95417F	3034 863670	EVGENIY MOROZOV	{"phone": "+70917032026"}
0005432967076	DFECB3	0980 826227	MAKSIM VOLKOV	{"email": "volkov_maksim_23061972@postgrespro.ru", "phone": "+70402470728"}
0005432967077	636A24	2249 376466	LIDIYA ROMANOVA	{"email": "lidiya-romanova29121976@postgrespro.ru", "phone": "+70679819380"}
0005432967078	636A24	6469 719324	NIKOLAY ZAKHAROV	{"email": "n-zakharov_1976@postgrespro.ru", "phone": "+70987580041"}
0005432967079	276264	1176 626441	MAKSIM ANDREEV	{"phone": "+70735782994"}
0005432967080	F0ED8F	2272 445238	GALINA NIKOLAEVA	{"email": "nikolaevag1971@postgrespro.ru", "phone": "+70705590473"}
0005432967081	F0ED8F	8337 504728	PAVEL CHERNOV	{"email": "p-chernov071981@postgrespro.ru", "phone": "+70760288585"}
0005432967082	F0ED8F	3827 811006	MARIYA KUZNECOVA	{"email": "kuznecova_m-091973@postgrespro.ru", "phone": "+70598147387"}
0005432967083	55D8EC	1228 719266	EVGENIYA AKIMOVA	{"phone": "+70889537507"}
0005432967084	55D8EC	2836 533914	ALEKSANDRA YUDINA	{"phone": "+70500446873"}
0005432967085	269694	7249 867243	MARIYA KUZNECOVA	{"phone": "+70304204181"}
0005432967086	269694	5001 423019	SVETLANA DENISOVA	{"phone": "+70306019271"}
0005432967087	A00070	6251 785930	REGINA ZAYCEVA	{"phone": "+70505404472"}
0005432967088	198B80	0312 862215	SVETLANA ALEKSEEVA	{"phone": "+70130137526"}
0005432967089	CF4D27	4918 283728	GALINA MAKAROVA	{"phone": "+70789279140"}
0005432967090	325287	8223 864154	VASILIY GUSEV	{"phone": "+70237678563"}
0005432967091	049324	8393 202994	STANISLAV ZAKHAROV	{"email": "zakharov-s.1968@postgrespro.ru", "phone": "+70172342908"}
0005432967092	6A80B5	2671 189563	IRINA ERMAKOVA	{"email": "irina-ermakova.021983@postgrespro.ru", "phone": "+70534647912"}
0005432967093	2BD830	5993 079083	GALINA KOROLEVA	{"email": "g.koroleva-17021980@postgrespro.ru", "phone": "+70237844914"}
0005432967094	B97533	7647 972707	VIKTOR ROMANOV	{"phone": "+70247899489"}
0005432967095	756C94	1356 343571	YURIY ZAYCEV	{"phone": "+70979002084"}
0005432967096	8A1A05	2733 427828	DMITRIY KOZLOV	{"phone": "+70387305975"}
0005432967097	4BA935	9610 194168	ANDREY SEMENOV	{"email": "andreysemenov071985@postgrespro.ru", "phone": "+70729250926"}
0005432967098	4BA935	7247 200006	ALEKSANDR MOROZOV	{"email": "morozov.a-06011964@postgrespro.ru", "phone": "+70685393449"}
0005432967099	A89514	0808 743305	ALINA TIMOFEEVA	{"phone": "+70788567494"}
0005432967100	2EFE5A	0249 393437	OLEG ALEKSEEV	{"phone": "+70622877792"}
0005432967101	2EFE5A	8575 746431	MIKHAIL GUSEV	{"phone": "+70879561996"}
0005432967102	2EFE5A	1195 535872	ELENA ALEKSANDROVA	{"phone": "+70456657947"}
0005432967103	BD0A20	8702 162228	ALEKSANDR ROMANOV	{"phone": "+70135590319"}
0005432967104	F56F11	0268 533567	VYACHESLAV KOROLEV	{"email": "korolevv-15011970@postgrespro.ru", "phone": "+70400354866"}
0005432967105	A46154	7220 583826	MARIYA ZAYCEVA	{"email": "zayceva.m041972@postgrespro.ru", "phone": "+70021603390"}
0005432967106	A46154	4707 803478	TAISA KUZNECOVA	{"phone": "+70460475119"}
0005432967107	AFA9F3	2941 657334	VIKTOR ABRAMOV	{"email": "abramovviktor-10021972@postgrespro.ru", "phone": "+70491041631"}
0005432967108	0C2EC4	8604 122056	DMITRIY VASILEV	{"email": "dvasilev1972@postgrespro.ru", "phone": "+70180488001"}
0005432967109	0C2EC4	0235 606409	OLGA POPOVA	{"email": "olga.popova31071970@postgrespro.ru", "phone": "+70313303680"}
0005432967110	0C2EC4	4114 230293	ALEKSEY GORBUNOV	{"email": "gorbunov-a_091971@postgrespro.ru", "phone": "+70715759715"}
0005432967111	0C2EC4	8255 616969	IRINA DANILOVA	{"phone": "+70626927744"}
0005432967112	10B770	8495 815096	VIKTORIYA MOROZOVA	{"email": "morozovav121973@postgrespro.ru", "phone": "+70150843392"}
0005432967113	10B770	3255 073881	VIKTORIYA KAZAKOVA	{"email": "kazakova-viktoriya1986@postgrespro.ru", "phone": "+70779595391"}
0005432967114	3F0291	9732 207218	ALEKSANDR PETROV	{"phone": "+70351177856"}
0005432967115	3F0291	2183 869682	GENNADIY NAUMOV	{"phone": "+70455284810"}
0005432967116	9D8C89	1102 400611	NATALYA MOROZOVA	{"phone": "+70081282076"}
0005432967117	9D8C89	4704 574810	ANDREY NAUMOV	{"email": "naumovandrey.1978@postgrespro.ru", "phone": "+70429243258"}
0005432967118	731EE3	9792 914510	OLEG POPOV	{"email": "popovoleg_02121963@postgrespro.ru", "phone": "+70780767438"}
0005432967119	375E88	2666 422618	IGOR TIKHONOV	{"phone": "+70957357526"}
0005432967120	72BB43	8514 675492	MAKSIM ILIN	{"email": "m-ilin.30031976@postgrespro.ru", "phone": "+70695008304"}
0005432967121	72BB43	2666 091347	VERONIKA ANTONOVA	{"phone": "+70147359463"}
0005432967122	7C4A54	5782 986143	SERGEY MELNIKOV	{"email": "melnikov-s_21121969@postgrespro.ru", "phone": "+70099631602"}
0005432967123	BC202B	3489 478648	ANDREY VOROBEV	{"email": "vorobev_andrey_091974@postgrespro.ru", "phone": "+70196765995"}
0005432967124	3D388E	5660 806696	IGOR NIKITIN	{"email": "i-nikitin-1970@postgrespro.ru", "phone": "+70224108807"}
0005432967125	55C7B8	6245 573212	DENIS KUZNECOV	{"email": "d_kuznecov-021976@postgrespro.ru", "phone": "+70224513108"}
0005432967126	55C7B8	1383 438811	IRAIDA FROLOVA	{"phone": "+70872670719"}
0005432967127	7B356F	4117 248270	DMITRIY SOLOVEV	{"phone": "+70260508625"}
0005432967128	7B356F	4704 245311	ALEKSANDR MOISEEV	{"phone": "+70683641976"}
0005432967129	A434D5	5948 901020	VALERIY KOROLEV	{"email": "v-korolev.22041980@postgrespro.ru", "phone": "+70825102119"}
0005432967132	9C8E0E	1208 161626	ALEKSANDR KOROLEV	{"phone": "+70205486186"}
0005432967133	D7A9B5	7571 515519	LARISA NIKIFOROVA	{"phone": "+70059430981"}
0005432967134	4D3C6F	2807 862057	VERA FEDOROVA	{"phone": "+70246344342"}
0005432967135	4D3C6F	7506 174188	IRINA SOROKINA	{"phone": "+70917989592"}
0005432967136	1CA0A0	0189 486247	PETR SOROKIN	{"email": "sorokin.p_1975@postgrespro.ru", "phone": "+70469082618"}
0005432967137	A7D834	1843 606502	ALEKSANDR EGOROV	{"email": "egorov_a.09121968@postgrespro.ru", "phone": "+70244439060"}
0005432967138	8B8B44	6970 668814	VALENTINA KOZLOVA	{"email": "v_kozlova_051984@postgrespro.ru", "phone": "+70641950161"}
0005432967139	CFA775	5741 538728	ANATOLIY ZHURAVLEV	{"phone": "+70356399784"}
0005432967140	CFA775	4738 609635	DMITRIY ZAKHAROV	{"phone": "+70468307080"}
0005432967141	13DFA5	8401 947941	ALEKSANDR KUZNECOV	{"email": "kuznecova091966@postgrespro.ru", "phone": "+70435126170"}
0005432967142	F4615B	1251 514772	GALINA ORLOVA	{"email": "orlova_galina10041979@postgrespro.ru", "phone": "+70041014494"}
0005432967143	F4615B	4195 599243	VALENTINA EGOROVA	{"phone": "+70321882449"}
0005432967144	CCF811	6653 639849	RENAT IVANOV	{"email": "ivanov.renat-011972@postgrespro.ru", "phone": "+70438984970"}
0005432967145	CCF811	1080 959893	IGOR AFANASEV	{"phone": "+70712189770"}
0005432967146	82FE6F	7941 875731	OLEG SEMENOV	{"email": "semenov_oleg_16061964@postgrespro.ru", "phone": "+70888764423"}
0005432967147	8E1DD0	5371 580810	SERGEY KISELEV	{"email": "kiselev_s031972@postgrespro.ru", "phone": "+70358006268"}
0005432967148	5EA461	0713 554887	DMITRIY SAVELEV	{"phone": "+70765218734"}
0005432967149	B9ED7A	3448 025705	OLEG CHERNOV	{"email": "chernovoleg.021981@postgrespro.ru", "phone": "+70439659964"}
0005432967150	B9ED7A	4299 281450	ANDREY SERGEEV	{"phone": "+70283284008"}
0005432967151	128E2A	8446 820631	SVETLANA SOKOLOVA	{"phone": "+70880789538"}
0005432967152	FAAF2F	6715 766784	IRINA VLASOVA	{"email": "vlasova-irina1962@postgrespro.ru", "phone": "+70172284028"}
0005432967153	A1C88D	9036 222635	ROMAN MAKAROV	{"phone": "+70738068423"}
0005432967154	97239B	1854 373834	OLEG KUZNECOV	{"phone": "+70996669658"}
0005432967155	97239B	1849 071940	KONSTANTIN KULIKOV	{"email": "konstantin.kulikov_061967@postgrespro.ru", "phone": "+70887808721"}
0005432967156	41209A	4738 897867	IVAN MIRONOV	{"email": "i-mironov-04101961@postgrespro.ru", "phone": "+70319197363"}
0005432967157	41209A	9799 311097	SERGEY SAVELEV	{"email": "s.savelev-081975@postgrespro.ru", "phone": "+70127165714"}
0005432967158	15C181	6449 826893	SERGEY NIKOLAEV	{"email": "nikolaev.s-1982@postgrespro.ru", "phone": "+70563415082"}
0005432967159	0CCE87	0545 356712	ANDREY NIKOLAEV	{"phone": "+70565599883"}
0005432967160	0CCE87	7485 057573	ROBERT FOMIN	{"email": "robert.fomin06071959@postgrespro.ru", "phone": "+70717658592"}
0005432967161	ACE584	7784 644172	VALERIY KISELEV	{"phone": "+70081136508"}
0005432967162	ACE584	1239 364629	ZOYA ZAYCEVA	{"phone": "+70516920006"}
0005432967163	1AFDE1	9363 835934	ELVIRA KUDRYASHOVA	{"email": "e_kudryashova.18091977@postgrespro.ru", "phone": "+70886345452"}
0005432967164	1AFDE1	5558 129305	OKSANA ILINA	{"phone": "+70544071495"}
0005432967165	1AFDE1	6230 507002	TATYANA MELNIKOVA	{"phone": "+70364353754"}
0005432967166	1F1C5E	0663 706454	LARISA ANTONOVA	{"email": "antonova.larisa061968@postgrespro.ru", "phone": "+70745540100"}
0005432967168	E9F67F	9575 539068	KLAVDIYA YAKOVLEVA	{"phone": "+70383831729"}
0005432967169	542D26	7720 663609	ANNA IVANOVA	{"email": "ivanovaanna-09051967@postgrespro.ru", "phone": "+70252407919"}
0005432967170	ADEF84	2149 281760	IVAN GERASIMOV	{"email": "ivan.gerasimov-1984@postgrespro.ru", "phone": "+70229287885"}
0005432967171	FA0991	1299 161361	YURIY MELNIKOV	{"email": "y-melnikov1969@postgrespro.ru", "phone": "+70912528596"}
0005432967172	FA0991	7000 861384	ARSENIY ANTONOV	{"email": "a.antonov_091963@postgrespro.ru", "phone": "+70802558984"}
0005432967173	4418F8	5685 829473	RAFIK OSIPOV	{"phone": "+70781531475"}
0005432967174	167341	9672 010623	TATYANA POPOVA	{"email": "popova.tatyana051976@postgrespro.ru", "phone": "+70598628164"}
0005432967175	5A6988	1915 219047	VLADISLAV MOROZOV	{"phone": "+70687330517"}
0005432967176	77FA6C	9264 113951	ANTON ZAKHAROV	{"email": "a_zakharov.091974@postgrespro.ru", "phone": "+70716999393"}
0005432967177	77FA6C	1312 136653	VALENTINA SCHERBAKOVA	{"email": "scherbakova.valentina.041975@postgrespro.ru", "phone": "+70505785901"}
0005432967178	306655	4876 806264	ALENA KOZLOVA	{"email": "kozlovaalena_121978@postgrespro.ru", "phone": "+70878692042"}
0005432967179	670A99	4709 018425	VLADIMIR FILIPPOV	{"email": "vladimirfilippov-05091978@postgrespro.ru", "phone": "+70269043606"}
0005432967180	670A99	0705 756166	ANTON ABRAMOV	{"email": "abramovanton-121976@postgrespro.ru", "phone": "+70776519454"}
0005432967181	4D9B18	4078 490957	ANTON SOROKIN	{"email": "a.sorokin_04091970@postgrespro.ru", "phone": "+70014288803"}
0005432967182	4D9B18	0912 842866	DMITRIY DENISOV	{"email": "dmitriydenisov_12081982@postgrespro.ru", "phone": "+70773806959"}
0005432967183	8D4504	6308 980424	FANIYA LUKYANOVA	{"email": "f_lukyanova_121981@postgrespro.ru", "phone": "+70534225459"}
0005432967184	97DE74	6634 763098	KSENIYA NIKOLAEVA	{"phone": "+70622688481"}
0005432967185	97DE74	8997 686273	RAFAIL KOZLOV	{"phone": "+70585279098"}
0005432967186	91121C	1337 993362	NIKOLAY GERASIMOV	{"email": "gerasimovnikolay-30101975@postgrespro.ru", "phone": "+70530872447"}
0005432967187	91121C	7520 005370	NATALIYA TIKHONOVA	{"phone": "+70363958225"}
0005432967188	F0964B	4930 448193	IVAN GUSEV	{"email": "gusevi1966@postgrespro.ru", "phone": "+70484712188"}
0005432967189	80A767	2589 790801	EVGENIY FEDOROV	{"phone": "+70610288250"}
0005432967190	80A767	7459 937577	IVAN KOROLEV	{"phone": "+70999493422"}
0005432967191	0D1A3B	8470 222900	VIKTOR MAKAROV	{"email": "makarov.viktor_041967@postgrespro.ru", "phone": "+70992055646"}
0005432967192	0D1A3B	5879 236989	SERGEY ISAEV	{"email": "isaev.s011956@postgrespro.ru", "phone": "+70074139850"}
0005432967193	BDCDD3	9871 753007	DMITRIY SEMENOV	{"phone": "+70724851699"}
0005432967194	BDCDD3	1346 885522	NIKOLAY FROLOV	{"email": "n.frolov051966@postgrespro.ru", "phone": "+70963190442"}
0005432967195	BE260E	1191 701615	LIDIYA SAVELEVA	{"phone": "+70180915444"}
0005432967196	6577BD	5589 344314	OLGA NESTEROVA	{"phone": "+70519371152"}
0005432967197	0BFFA9	1540 645440	IGOR FOMIN	{"email": "fomini-19121973@postgrespro.ru", "phone": "+70086285152"}
0005432967198	CBC6B4	8493 977283	ANASTASIYA GORBUNOVA	{"email": "gorbunovaa.18091971@postgrespro.ru", "phone": "+70763034618"}
0005432967199	C0AF92	3896 245847	MARINA MOROZOVA	{"email": "morozovamarina081963@postgrespro.ru", "phone": "+70724888177"}
0005432967200	2300CE	4090 218216	GENNADIY TARASOV	{"phone": "+70723965670"}
0005432967201	2300CE	5379 639671	VALENTINA BARANOVA	{"phone": "+70898606504"}
0005432967202	E5A49F	9877 527740	SERGEY SOLOVEV	{"phone": "+70022533699"}
0005432967203	1A58CA	0660 689812	ALEKSEY SMIRNOV	{"email": "smirnov-a18031984@postgrespro.ru", "phone": "+70284376545"}
0005432967204	BB2F5C	3724 723636	NINA SAVELEVA	{"email": "nina-saveleva011960@postgrespro.ru", "phone": "+70894822925"}
0005432967205	B95C55	5214 462399	SERGEY BARANOV	{"phone": "+70391449537"}
0005432967206	19EFE4	5474 273000	ALEKSANDR VASILEV	{"phone": "+70968091461"}
0005432967207	93449A	6419 706146	VASILIY PETROV	{"email": "v.petrov_051984@postgrespro.ru", "phone": "+70096733548"}
0005432967208	6CB903	1140 387910	VIKTOR AFANASEV	{"phone": "+70540350583"}
0005432967209	EA775F	0346 762347	MIKHAIL KUZNECOV	{"email": "kuznecov_m_11101967@postgrespro.ru", "phone": "+70083284853"}
0005432967210	54EE33	1789 026485	ALENA ARKHIPOVA	{"phone": "+70631885507"}
0005432967211	BCBD3B	2594 639198	ALEKSANDR AFANASEV	{"phone": "+70872286507"}
0005432967212	17C0F5	0033 386526	DMITRIY MIRONOV	{"phone": "+70542200485"}
0005432967213	B42754	7325 941692	OLEG FROLOV	{"phone": "+70975337996"}
0005432967214	B42754	5071 718600	EGOR SOROKIN	{"phone": "+70243230248"}
0005432967215	CF669F	3958 582583	VERA EFREMOVA	{"email": "vera_efremova-25081970@postgrespro.ru", "phone": "+70262929612"}
0005432967216	C782AD	4803 793373	MARINA ZHURAVLEVA	{"email": "marina-zhuravleva.04011970@postgrespro.ru", "phone": "+70182193266"}
0005432967217	4C1FFE	9791 448759	VITALIY DMITRIEV	{"phone": "+70996280571"}
0005432967218	0EBBE5	8969 396264	GERMAN ROMANOV	{"email": "germanromanov_011974@postgrespro.ru", "phone": "+70164881682"}
0005432967219	ABE17A	3353 480613	ALEKSANDRA MOISEEVA	{"email": "amoiseeva111977@postgrespro.ru", "phone": "+70774879250"}
0005432967220	ABE17A	7449 642069	NATALYA SCHERBAKOVA	{"email": "n.scherbakova.1959@postgrespro.ru", "phone": "+70749399392"}
0005432967221	452B53	1490 885671	NADEZHDA SERGEEVA	{"email": "nadezhda-sergeeva.1974@postgrespro.ru", "phone": "+70552094850"}
0005432967222	452B53	7574 556328	VASILIY PAVLOV	{"email": "vasiliypavlov_071973@postgrespro.ru", "phone": "+70810154431"}
0005432967223	A8CD11	0274 071315	TATYANA NIKOLAEVA	{"email": "nikolaeva.t-1967@postgrespro.ru", "phone": "+70925275628"}
0005432967224	5D12CD	2710 773714	ELENA SCHERBAKOVA	{"email": "scherbakova.elena.1970@postgrespro.ru", "phone": "+70017253877"}
0005432967225	AE29F8	4829 402448	VALERIY KUZNECOV	{"phone": "+70373064703"}
0005432967226	05DA4E	9926 674966	ELENA EFREMOVA	{"email": "e-efremova.25091966@postgrespro.ru", "phone": "+70472863647"}
0005432967227	D985D6	7704 063058	NINA KOZLOVA	{"phone": "+70505887345"}
0005432967228	8F33C8	0319 967837	NIKOLAY RODIONOV	{"email": "n.rodionov1968@postgrespro.ru", "phone": "+70969755142"}
0005432967229	8F33C8	1174 968467	PAVEL STEPANOV	{"email": "stepanov-p_1967@postgrespro.ru", "phone": "+70176151848"}
0005432967230	80CF93	5913 810371	YURIY FEDOROV	{"phone": "+70774233370"}
0005432967231	80CF93	0916 288600	ELIZAVETA MIKHAYLOVA	{"phone": "+70569875831"}
0005432967232	45E514	1720 191312	SERGEY DENISOV	{"email": "sergey-denisov1963@postgrespro.ru", "phone": "+70005671834"}
0005432967233	62B22A	0278 442703	IVAN POPOV	{"phone": "+70094550883"}
0005432967234	62B22A	7564 768438	VLADIMIR GORBUNOV	{"email": "gorbunovvladimir.25071968@postgrespro.ru", "phone": "+70885103564"}
0005432967235	9AF292	3978 756766	ANATOLIY KRASNOV	{"email": "anatoliy-krasnov_1977@postgrespro.ru", "phone": "+70052105493"}
0005432967236	9AF292	2773 341872	LIDIYA ANDREEVA	{"email": "andreeval_28081973@postgrespro.ru", "phone": "+70581976218"}
0005432967237	0981F3	3724 598630	YURIY KOROLEV	{"phone": "+70205454345"}
0005432967238	0981F3	2652 661453	LEONID IVANOV	{"phone": "+70312876802"}
0005432967239	969717	9779 191853	VIKTOR BARANOV	{"email": "baranov.v25011970@postgrespro.ru", "phone": "+70702731823"}
0005432967240	5532D5	1146 364153	ELENA MAKAROVA	{"email": "elena-makarova-1973@postgrespro.ru", "phone": "+70626505633"}
0005432967241	5012C8	0559 602199	PAVEL KOZLOV	{"email": "pavel_kozlov15021963@postgrespro.ru", "phone": "+70629805542"}
0005432967242	E7CA9F	6269 239752	KRISTINA IVANOVA	{"phone": "+70127686661"}
0005432967243	22FFDF	9916 699875	ANATOLIY MOROZOV	{"email": "anatoliy-morozov_16071970@postgrespro.ru", "phone": "+70166779056"}
0005432967244	22FFDF	1056 697208	VASILIY IVANOV	{"phone": "+70724967518"}
0005432967245	648E47	0875 913911	TALGAT KUZMIN	{"email": "kuzmin_talgat_19111975@postgrespro.ru", "phone": "+70208236941"}
0005432967246	976411	9085 749164	SERGEY STEPANOV	{"email": "stepanov_sergey.14111963@postgrespro.ru", "phone": "+70784513692"}
0005432967247	7703BE	0064 545406	SERGEY ORLOV	{"phone": "+70559728404"}
0005432967248	9422A4	1759 879622	MARIYA SOLOVEVA	{"email": "m.soloveva-031982@postgrespro.ru", "phone": "+70111023215"}
0005432967249	1CA6F1	5057 141200	TATYANA NOVIKOVA	{"phone": "+70047311990"}
0005432967250	D22118	6517 307478	GENNADIY SCHERBAKOV	{"email": "g-scherbakov-17111976@postgrespro.ru", "phone": "+70066758058"}
0005432967251	D22118	0576 322900	VALENTINA FEDOROVA	{"phone": "+70160092266"}
0005432967252	B394BB	8792 720139	MARK BORISOV	{"phone": "+70668630919"}
0005432967253	47EF10	8139 023862	LYUBOV FILATOVA	{"phone": "+70720167312"}
0005432967254	15D29D	5398 106010	ANNA LEBEDEVA	{"email": "annalebedeva.051970@postgrespro.ru", "phone": "+70105755966"}
0005432967255	15D29D	1765 899222	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov.06061976@postgrespro.ru", "phone": "+70665341172"}
0005432967256	CBC557	0972 455103	OLEG SIDOROV	{"phone": "+70914406109"}
0005432967257	9A43CF	8750 986833	NATALYA KOZLOVA	{"email": "n_kozlova-021977@postgrespro.ru", "phone": "+70258882566"}
0005432967258	9A43CF	2789 510780	KSENIYA ISAEVA	{"email": "kisaeva1975@postgrespro.ru", "phone": "+70814246859"}
0005432967259	521F20	9254 913221	KRISTINA NIKIFOROVA	{"email": "kristina-nikiforova_1968@postgrespro.ru", "phone": "+70033945153"}
0005432967260	B66CCB	0791 162035	VLADIMIR BORISOV	{"phone": "+70885573230"}
0005432967261	29BCFF	9359 146442	VALERIY EGOROV	{"phone": "+70106229862"}
0005432967262	29BCFF	0589 616438	ALEKSEY MAKAROV	{"phone": "+70167413449"}
0005432967263	AAEA35	2694 688651	EVGENIYA ZOTOVA	{"phone": "+70622683756"}
0005432967264	26BAFF	1811 890791	ALLA MELNIKOVA	{"phone": "+70952018066"}
0005432967265	3A723D	6743 343754	ANASTASIYA POPOVA	{"phone": "+70285840064"}
0005432967266	3A723D	3651 447119	ANNA NIKITINA	{"email": "anna_nikitina-1968@postgrespro.ru", "phone": "+70338017020"}
0005432967267	D78380	5463 604624	IRINA KOVALEVA	{"phone": "+70670965687"}
0005432967268	6A5D34	3276 671508	OLEG ABRAMOV	{"phone": "+70607555785"}
0005432967269	F583D8	5778 310622	SEMEN GAVRILOV	{"phone": "+70026190149"}
0005432967270	FB438F	1169 624555	MAKSIM IVANOV	{"email": "maksim.ivanov_1959@postgrespro.ru", "phone": "+70347322339"}
0005432967271	BBA3DB	7039 514435	VALENTINA ZAYCEVA	{"email": "zaycevav-01071972@postgrespro.ru", "phone": "+70591950947"}
0005432967272	F00A08	6539 326190	TAMARA ERMAKOVA	{"email": "t.ermakova_1979@postgrespro.ru", "phone": "+70863922218"}
0005432967273	724C5E	1138 309862	RUSLAN NIKITIN	{"phone": "+70058191156"}
0005432967274	724C5E	8102 226514	EKATERINA FILATOVA	{"phone": "+70087885986"}
0005432967275	D0A454	8178 928692	VERA LOGINOVA	{"email": "loginovavera20011973@postgrespro.ru", "phone": "+70803394177"}
0005432967276	95E92A	6847 463871	MARIYA NESTEROVA	{"phone": "+70338851518"}
0005432967277	7F0A49	6072 718436	ANNA POTAPOVA	{"phone": "+70299932995"}
0005432967278	7F0A49	2448 491784	YURIY BELOV	{"phone": "+70502887908"}
0005432967279	514E59	7660 111018	OKSANA MAKAROVA	{"email": "oksana.makarova.1977@postgrespro.ru", "phone": "+70425804846"}
0005432967280	514E59	1591 941307	ANATOLIY KUZMIN	{"phone": "+70480330791"}
0005432967281	4B8A82	5180 208463	NATALIYA ISAEVA	{"email": "isaeva_n121966@postgrespro.ru", "phone": "+70323975090"}
0005432967282	4B8A82	3417 193092	ALEKSANDR MAKAROV	{"email": "makarovaleksandr-1977@postgrespro.ru", "phone": "+70166232172"}
0005432967283	D810B6	3608 266989	NATALYA ALEKSANDROVA	{"email": "aleksandrova_n_1992@postgrespro.ru", "phone": "+70296075880"}
0005432967284	2A50A5	4148 737448	MIKHAIL EGOROV	{"phone": "+70396180359"}
0005432967285	6ADB3D	2338 380444	IVAN SOKOLOV	{"email": "isokolov_1988@postgrespro.ru", "phone": "+70298137561"}
0005432967286	232495	1848 103123	SERGEY ILIN	{"phone": "+70565113568"}
0005432967287	232495	0159 746415	ANASTASIYA SOROKINA	{"email": "sorokina-anastasiya-051968@postgrespro.ru", "phone": "+70259385488"}
0005432967288	965EF4	1890 020634	LARISA KONOVALOVA	{"phone": "+70691508156"}
0005432967289	965EF4	5733 552825	NIKOLAY FOMIN	{"email": "nikolay_fomin101974@postgrespro.ru", "phone": "+70312572222"}
0005432967290	1A154F	0672 346396	MIKHAIL DENISOV	{"phone": "+70017331030"}
0005432967291	7A8551	2670 644416	GALINA ARKHIPOVA	{"email": "galina_arkhipova1970@postgrespro.ru", "phone": "+70823367391"}
0005432967353	85B9F9	7908 515174	ANASTASIYA ANTONOVA	{"phone": "+70711814787"}
0005432967292	4593F8	3693 415712	ANNA KOROLEVA	{"email": "akoroleva-081975@postgrespro.ru", "phone": "+70873431635"}
0005432967293	E9BE53	2916 144398	ANDREY KUZNECOV	{"email": "kuznecova.11041969@postgrespro.ru", "phone": "+70874212403"}
0005432967294	8F4F20	5873 647427	ANNA GRISHINA	{"phone": "+70123352264"}
0005432967295	8F4F20	1455 771625	VLADISLAV VOLKOV	{"phone": "+70480554980"}
0005432967296	8F85A5	1131 208894	ARTEM FROLOV	{"phone": "+70407781980"}
0005432967297	91B2C5	2370 131402	NADEZHDA PETROVA	{"phone": "+70545733986"}
0005432967298	55DA23	7273 220474	TATYANA STEPANOVA	{"email": "t.stepanova-20011968@postgrespro.ru", "phone": "+70074486949"}
0005432967299	7BD6D0	5905 610916	SOFYA LUKYANOVA	{"phone": "+70704747839"}
0005432967300	7FCAC6	8103 708883	GALINA MOROZOVA	{"email": "galinamorozova_1970@postgrespro.ru", "phone": "+70263157520"}
0005432967301	EF0CEE	9102 478960	IRINA GAVRILOVA	{"phone": "+70861440932"}
0005432967302	89C2EC	0047 587460	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr1971@postgrespro.ru", "phone": "+70872727366"}
0005432967303	52CEDE	8789 373086	VLADIMIR KISELEV	{"phone": "+70059564100"}
0005432967304	FBA0E4	4559 011039	GALINA ANTONOVA	{"phone": "+70812486935"}
0005432967305	FBA0E4	5492 967378	GLEB MOISEEV	{"email": "glebmoiseev.1968@postgrespro.ru", "phone": "+70233306854"}
0005432967306	561E1A	4765 911948	ELENA VLASOVA	{"phone": "+70551895040"}
0005432967307	561E1A	2047 806650	ILYA KOROLEV	{"phone": "+70759105044"}
0005432967308	91CEC9	9238 851658	OLGA BELOVA	{"phone": "+70959483501"}
0005432967309	16836F	9738 365941	ANDREY POPOV	{"phone": "+70933174601"}
0005432967310	047B6D	3313 109352	DMITRIY AFANASEV	{"phone": "+70269750149"}
0005432967311	047B6D	9637 107880	KRISTINA MALYSHEVA	{"email": "malyshevak-1966@postgrespro.ru", "phone": "+70622594097"}
0005432967312	BB24AE	3313 400534	ELENA KUZMINA	{"email": "e.kuzmina.17031976@postgrespro.ru", "phone": "+70176241124"}
0005432967313	7CFEC7	9839 349587	LILIYA VASILEVA	{"phone": "+70410888530"}
0005432967314	7CFEC7	2983 936427	GALINA POLYAKOVA	{"email": "galinapolyakova23081978@postgrespro.ru", "phone": "+70313294558"}
0005432967315	6E222C	0148 097799	ARKADIY NIKITIN	{"phone": "+70009101105"}
0005432967316	6E222C	3505 415663	ARTEM ILIN	{"email": "a_ilin_18071988@postgrespro.ru", "phone": "+70999567325"}
0005432967317	4CA495	3460 201498	ANNA PETROVA	{"phone": "+70313149668"}
0005432967318	4CA495	5442 097908	TATYANA MATVEEVA	{"phone": "+70153270221"}
0005432967319	32E589	2381 000399	VITALIY SIDOROV	{"email": "sidorov.vitaliy21031971@postgrespro.ru", "phone": "+70096940625"}
0005432967320	32E589	1233 019116	ELIZAVETA PETROVA	{"phone": "+70751224101"}
0005432967321	16431D	3647 501289	TATYANA ZHUKOVA	{"phone": "+70978490069"}
0005432967322	16431D	4094 259256	VITALIY MARTYNOV	{"phone": "+70161598436"}
0005432967323	DEB660	5886 621583	TAMARA GRISHINA	{"email": "tamara-grishina-17051981@postgrespro.ru", "phone": "+70443705679"}
0005432967324	DEB660	4824 260236	OLGA SCHERBAKOVA	{"email": "scherbakovao_19051980@postgrespro.ru", "phone": "+70244590688"}
0005432967325	7C3A18	4500 569909	ALEKSANDR ALEKSANDROV	{"phone": "+70984312635"}
0005432967326	7C3A18	5771 575118	DINA ABRAMOVA	{"phone": "+70112869164"}
0005432967327	B987EB	6308 836349	EKATERINA EFIMOVA	{"email": "ekaterina-efimova_1965@postgrespro.ru", "phone": "+70042975734"}
0005432967328	2DC803	2427 847800	SERGEY SOLOVEV	{"email": "solovev_sergey-20021959@postgrespro.ru", "phone": "+70593551768"}
0005432967329	35684C	7945 446389	SERGEY SOKOLOV	{"phone": "+70818995090"}
0005432967330	086EF9	2003 616356	FARIT RODIONOV	{"phone": "+70016924121"}
0005432967331	57A686	0201 920191	YURIY SCHERBAKOV	{"phone": "+70240600419"}
0005432967332	2A2219	1222 494053	VERA DANILOVA	{"phone": "+70691110753"}
0005432967333	C9D675	1222 920398	VIKTOR YAKOVLEV	{"phone": "+70725275585"}
0005432967334	09EFE6	7070 428894	NINA MIKHAYLOVA	{"email": "mikhaylova-nina.1973@postgrespro.ru", "phone": "+70407210589"}
0005432967335	69BE6A	7260 568836	LYUBOV GAVRILOVA	{"phone": "+70952099841"}
0005432967336	69BE6A	3716 743726	TAMARA MOISEEVA	{"phone": "+70399001842"}
0005432967337	319222	5693 746338	VALENTINA ZAYCEVA	{"email": "valentina-zayceva081974@postgrespro.ru", "phone": "+70736452954"}
0005432967338	C4B2B5	0574 505044	DMITRIY SEMENOV	{"email": "semenov_d-20061970@postgrespro.ru", "phone": "+70257865838"}
0005432967339	95F7F0	0280 943264	MIKHAIL TARASOV	{"phone": "+70371797163"}
0005432967340	09C1CB	9197 012189	LARISA VLASOVA	{"email": "larisa_vlasova091966@postgrespro.ru", "phone": "+70247676968"}
0005432967341	09C1CB	2332 698054	GALINA PAVLOVA	{"email": "pavlova.galina051974@postgrespro.ru", "phone": "+70510147391"}
0005432967342	0F0A43	1377 342059	ANNA KRASNOVA	{"email": "a_krasnova-041985@postgrespro.ru", "phone": "+70275490504"}
0005432967343	308BDC	8421 563396	VERA STEPANOVA	{"phone": "+70933429769"}
0005432967344	308BDC	3692 347024	OLGA ZAKHAROVA	{"email": "zakharova-o-22041970@postgrespro.ru", "phone": "+70910916125"}
0005432967345	53FE24	5093 002561	ANZHELA EFIMOVA	{"email": "efimova_anzhela.21081974@postgrespro.ru", "phone": "+70763235077"}
0005432967346	16D8E4	7549 809522	EVGENIY BORISOV	{"email": "e_borisov_1972@postgrespro.ru", "phone": "+70444673303"}
0005432967347	EDEA3E	5710 815671	VALENTINA RODIONOVA	{"email": "valentina.rodionova081971@postgrespro.ru", "phone": "+70304925159"}
0005432967348	C946AC	3284 257651	EVGENIY MAKAROV	{"phone": "+70509772436"}
0005432967349	E7E9AC	4110 469517	MIKHAIL GERASIMOV	{"email": "mikhail_gerasimov081977@postgrespro.ru", "phone": "+70241346771"}
0005432967350	BD465B	8952 429195	PAVEL MIKHAYLOV	{"email": "pavel.mikhaylov_12011977@postgrespro.ru", "phone": "+70582325548"}
0005432967351	BD465B	8042 178620	RAMIL SMIRNOV	{"email": "smirnov.ramil.071979@postgrespro.ru", "phone": "+70762881502"}
0005432967352	72C083	4048 972602	SVETLANA BOGDANOVA	{"email": "sbogdanova061975@postgrespro.ru", "phone": "+70072969900"}
0005432967354	3C5E97	0956 755574	DIANA LEBEDEVA	{"email": "lebedevad1974@postgrespro.ru", "phone": "+70262071625"}
0005432967355	3C5E97	2228 389728	ANDREY SEMENOV	{"phone": "+70344434501"}
0005432967356	69D6E0	8011 596202	ANNA ALEKSEEVA	{"phone": "+70390647955"}
0005432967357	69D6E0	0511 254357	VASILIY DAVYDOV	{"email": "davydov.v-1970@postgrespro.ru", "phone": "+70444798281"}
0005432967358	830FF6	1310 243425	IGOR FEDOROV	{"phone": "+70623527013"}
0005432967359	830FF6	1698 824188	MARINA MASLOVA	{"phone": "+70206966981"}
0005432967360	830FF6	3162 875512	MARIYA NAZAROVA	{"phone": "+70864975320"}
0005432967361	53C465	9987 799060	TATYANA MIKHAYLOVA	{"email": "tatyana-mikhaylova15121975@postgrespro.ru", "phone": "+70666078294"}
0005432967362	62A8C4	4035 444371	LILIYA KOVALEVA	{"phone": "+70996731292"}
0005432967363	62A8C4	5143 987189	ARTEM FOMIN	{"email": "fomin-artem.1974@postgrespro.ru", "phone": "+70937006261"}
0005432967364	D60ADC	3138 821079	PRASKOVYA EFREMOVA	{"email": "efremova-p.22021965@postgrespro.ru", "phone": "+70789909376"}
0005432967365	43FBD0	7266 268225	SERGEY FEDOTOV	{"email": "fedotov_s081981@postgrespro.ru", "phone": "+70757653367"}
0005432967366	C515CC	8630 818403	LIDIYA VASILEVA	{"email": "vasilevalidiya1965@postgrespro.ru", "phone": "+70500979163"}
0005432967367	C515CC	5980 178660	ALEKSANDR ILIN	{"email": "a.ilin051975@postgrespro.ru", "phone": "+70426421949"}
0005432967368	885BB0	2963 697158	SERGEY KULIKOV	{"email": "kulikov_s.121971@postgrespro.ru", "phone": "+70437764089"}
0005432967369	61BFB3	1593 304654	IVAN IVANOV	{"phone": "+70250242038"}
0005432967370	7745F0	8109 405091	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-101979@postgrespro.ru", "phone": "+70083927321"}
0005432967371	5B569F	1459 194731	ZAKHAR VOLKOV	{"phone": "+70216419277"}
0005432967372	875A78	6629 247363	DARYA MAKAROVA	{"email": "makarova-darya_121967@postgrespro.ru", "phone": "+70298853578"}
0005432967373	761055	7189 410479	VALERIY SOROKIN	{"phone": "+70760923885"}
0005432967374	761055	7609 515838	ALEKSANDRA TARASOVA	{"phone": "+70623675114"}
0005432967375	B2B685	1174 612723	DMITRIY GRIGOREV	{"phone": "+70969973347"}
0005432967376	D90BA3	8266 146115	VASILIY ANDREEV	{"phone": "+70420324970"}
0005432967377	C2B20C	6950 019918	YURIY ILIN	{"email": "yuriy-ilin.22031980@postgrespro.ru", "phone": "+70251030611"}
0005432967378	AEE33D	2065 281935	ALENA ZAKHAROVA	{"phone": "+70356743331"}
0005432967379	AEE33D	4229 409051	ALEKSANDR ISAEV	{"phone": "+70302425899"}
0005432967380	6BEA5F	8579 791297	MARGARITA EGOROVA	{"email": "margarita_egorova28061972@postgrespro.ru", "phone": "+70553946000"}
0005432967381	6BEA5F	7983 168764	EVGENIY PETROV	{"email": "e.petrov.1972@postgrespro.ru", "phone": "+70003834570"}
0005432967382	E8D9D9	6231 215792	TATYANA EGOROVA	{"phone": "+70538100572"}
0005432967383	3014E1	6000 710868	ZOYA CHERNOVA	{"email": "zoyachernova_31051953@postgrespro.ru", "phone": "+70118854907"}
0005432967384	4F3820	5739 654579	MARIYA GERASIMOVA	{"phone": "+70517343213"}
0005432967385	114B1B	6616 813809	KIRA TIKHONOVA	{"email": "k_tikhonova_1968@postgrespro.ru", "phone": "+70312882957"}
0005432967386	114B1B	9214 720704	ANNA SOKOLOVA	{"phone": "+70240415420"}
0005432967387	830F4D	0790 566682	NATALYA MAKAROVA	{"email": "natalya_makarova041961@postgrespro.ru", "phone": "+70072024852"}
0005432967388	EC61F4	5338 633047	ROMAN KISELEV	{"email": "roman_kiselev.061970@postgrespro.ru", "phone": "+70278980752"}
0005432967389	A30FB6	2760 794947	VIKTOR KARPOV	{"phone": "+70715751147"}
0005432967390	5E7F41	8152 345671	SANIYA KRASNOVA	{"email": "krasnova_saniya.1972@postgrespro.ru", "phone": "+70719373038"}
0005432967391	185431	5493 102963	ALEKSEY MOISEEV	{"phone": "+70025573374"}
0005432967392	32B3EB	9136 783117	ALEKSANDRA MAKAROVA	{"email": "amakarova.041979@postgrespro.ru", "phone": "+70352889472"}
0005432967505	CE7E03	5533 093815	OLGA DAVYDOVA	{"phone": "+70391122929"}
0005432967393	033183	0788 414478	ELENA KOROLEVA	{"email": "koroleva.e.06041981@postgrespro.ru", "phone": "+70376472403"}
0005432967394	8B5544	1116 649859	NAILYA ABRAMOVA	{"phone": "+70649587490"}
0005432967395	665DB9	1944 226009	OLEG IVANOV	{"phone": "+70775365270"}
0005432967396	ABE1D4	9743 534747	GALINA KOMAROVA	{"phone": "+70752607135"}
0005432967397	B73341	7108 506913	YURIY SCHERBAKOV	{"phone": "+70695878944"}
0005432967398	F3665C	2960 605955	ALEKSEY KARPOV	{"email": "karpov-a-1970@postgrespro.ru", "phone": "+70178793309"}
0005432967399	F3665C	3570 405993	YURIY KUZNECOV	{"phone": "+70666281530"}
0005432967400	BF600C	9008 628455	VADIM NIKITIN	{"email": "vadim-nikitin121971@postgrespro.ru", "phone": "+70998414129"}
0005432967401	22DA5F	9384 507239	ELENA ARKHIPOVA	{"phone": "+70531906242"}
0005432967402	4F73E3	6839 095907	OKSANA ZAYCEVA	{"phone": "+70406532181"}
0005432967403	2CA6EF	5178 555430	ILYA VOLKOV	{"phone": "+70141657723"}
0005432967404	9F6487	4570 591577	ILNUR ABRAMOV	{"phone": "+70655535923"}
0005432967405	E02304	9268 140204	SERGEY ZAKHAROV	{"phone": "+70355004185"}
0005432967406	30E904	1793 192902	NINA SOROKINA	{"email": "nsorokina.01021982@postgrespro.ru", "phone": "+70178549783"}
0005432967407	F794E4	8918 097153	SERGEY IVANOV	{"phone": "+70953598398"}
0005432967408	A1A0FC	0659 242931	ARTEM PETROV	{"email": "artempetrov_21071970@postgrespro.ru", "phone": "+70050980044"}
0005432967409	073399	7720 058985	DMITRIY PAVLOV	{"phone": "+70696035961"}
0005432967410	F993DD	6557 910290	VALENTINA KOROLEVA	{"email": "koroleva.v.10091982@postgrespro.ru", "phone": "+70035041412"}
0005432967411	F993DD	0456 829154	OLGA EGOROVA	{"email": "egorova_olga111975@postgrespro.ru", "phone": "+70983671896"}
0005432967412	867BC9	4479 483087	NATALIYA BELOVA	{"phone": "+70738133150"}
0005432967413	3F7202	2554 300197	DMITRIY DMITRIEV	{"phone": "+70478042368"}
0005432967414	FC5346	8391 738409	DMITRIY GERASIMOV	{"phone": "+70152378610"}
0005432967415	94DC9F	5098 833497	ANDREY KUZMIN	{"phone": "+70383086784"}
0005432967416	217768	6576 768342	OLGA PAVLOVA	{"email": "olga.pavlova.17061986@postgrespro.ru", "phone": "+70513004840"}
0005432967417	6DB124	5026 447802	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova09061975@postgrespro.ru", "phone": "+70593330926"}
0005432967418	6DB124	4075 305276	VALENTINA MIKHAYLOVA	{"phone": "+70704195864"}
0005432967419	3B7AE8	3968 133793	SERGEY OSIPOV	{"email": "osipovs1977@postgrespro.ru", "phone": "+70170752507"}
0005432967420	E80647	9829 523126	DMITRIY MAKAROV	{"phone": "+70115317797"}
0005432967421	225FD0	7847 529157	YAKOV ZAYCEV	{"email": "yzaycev-07041975@postgrespro.ru", "phone": "+70588282531"}
0005432967422	7EB3A5	8023 849567	ANNA KUZNECOVA	{"email": "a-kuznecova011967@postgrespro.ru", "phone": "+70304761210"}
0005432967423	7593F4	1220 037191	DMITRIY MAKSIMOV	{"phone": "+70252223822"}
0005432967424	7593F4	1293 753503	EKATERINA NIKOLAEVA	{"phone": "+70288864536"}
0005432967425	7593F4	8767 612689	SERGEY POPOV	{"email": "sergey.popov_031964@postgrespro.ru", "phone": "+70985427579"}
0005432967426	F36CEB	6041 600479	OLGA KONOVALOVA	{"email": "konovalova_o-1965@postgrespro.ru", "phone": "+70146329057"}
0005432967427	F36CEB	0543 481373	VYACHESLAV SIDOROV	{"email": "vsidorov_071974@postgrespro.ru", "phone": "+70602792769"}
0005432967428	627F69	9279 259572	NONNA ORLOVA	{"phone": "+70651528706"}
0005432967429	F1E50A	7726 362758	TAMARA OSIPOVA	{"phone": "+70859723073"}
0005432967430	D70588	3440 845790	TATYANA SERGEEVA	{"email": "tsergeeva19031972@postgrespro.ru", "phone": "+70903734159"}
0005432967431	178082	3515 225988	LYUBOV TIKHONOVA	{"email": "tikhonova-l-1965@postgrespro.ru", "phone": "+70564092765"}
0005432967432	178082	7081 459903	EVDOKIYA NIKOLAEVA	{"email": "nikolaeva.evdokiya_03031976@postgrespro.ru", "phone": "+70411047793"}
0005432967433	178082	5698 265448	ALEKSEY KOROLEV	{"email": "aleksey_korolev-1971@postgrespro.ru", "phone": "+70912712283"}
0005432967434	A6DA8F	5082 907539	OLGA KULIKOVA	{"phone": "+70192377624"}
0005432967435	80104E	9869 922548	TAISIYA NESTEROVA	{"email": "nesterova.t.121968@postgrespro.ru", "phone": "+70416363723"}
0005432967436	B11A77	9927 165494	ELIZAVETA SERGEEVA	{"phone": "+70785854374"}
0005432967437	B11A77	4139 612368	ALEKSANDR ABRAMOV	{"phone": "+70342330867"}
0005432967438	B11A77	7875 903886	ANDREY KUZNECOV	{"phone": "+70297258553"}
0005432967439	C067FA	7691 696154	TATYANA NESTEROVA	{"email": "nesterova.t.07021968@postgrespro.ru", "phone": "+70707680533"}
0005432967440	D7E90F	1543 768837	EVGENIY ROMANOV	{"email": "evgeniy-romanov_09031973@postgrespro.ru", "phone": "+70815076369"}
0005432967441	CED7C7	7712 129401	ELENA OVCHINNIKOVA	{"email": "ovchinnikova.e15121966@postgrespro.ru", "phone": "+70196694249"}
0005432967442	0846A6	2324 951391	ANDREY BELOV	{"email": "belov-andrey-12091974@postgrespro.ru", "phone": "+70147139379"}
0005432967443	959140	9879 794002	LYUBOV PAVLOVA	{"phone": "+70941357708"}
0005432967444	93E9F4	9573 440235	TATYANA KULIKOVA	{"email": "tatyana-kulikova-27081979@postgrespro.ru", "phone": "+70975919815"}
0005432967445	93E9F4	8371 217639	ALEKSEY MELNIKOV	{"email": "melnikovaleksey.041966@postgrespro.ru", "phone": "+70359988022"}
0005432967446	215234	9582 115990	MIKHAIL SIDOROV	{"email": "sidorov.mikhail_1967@postgrespro.ru", "phone": "+70373909015"}
0005432967447	2F68CC	3657 824171	ALEKSANDR MEDVEDEV	{"email": "aleksandrmedvedev_19121980@postgrespro.ru", "phone": "+70888207873"}
0005432967448	2F68CC	0527 789267	YULIYA STEPANOVA	{"phone": "+70837566749"}
0005432967449	70C8AC	9372 449896	SERGEY KUZNECOV	{"email": "s-kuznecov071975@postgrespro.ru", "phone": "+70307219398"}
0005432967450	75816C	2979 469711	VLADIMIR POPOV	{"email": "popov_vladimir.041973@postgrespro.ru", "phone": "+70800730673"}
0005432967451	D840BC	3779 772897	DINA POPOVA	{"phone": "+70169709462"}
0005432967452	5CF1CD	9489 515033	MARIYA MARTYNOVA	{"email": "martynova_m16071980@postgrespro.ru", "phone": "+70591602666"}
0005432967453	6BD69E	7113 287474	ANATOLIY SMIRNOV	{"phone": "+70358508213"}
0005432967454	BBFEAB	2907 600047	ALEKSANDR KUZMIN	{"email": "a.kuzmin.1969@postgrespro.ru", "phone": "+70431825944"}
0005432967455	41F688	6846 241751	ALEKSEY GUSEV	{"email": "a_gusev_1981@postgrespro.ru", "phone": "+70564322447"}
0005432967456	41F688	5253 029567	MARIYA FOMINA	{"email": "fomina-m.1980@postgrespro.ru", "phone": "+70730434752"}
0005432967457	1C5FDC	0216 906649	ROMAN MIKHAYLOV	{"email": "mikhaylov_r-16031971@postgrespro.ru", "phone": "+70227483458"}
0005432967458	1C5FDC	3937 927638	SVETLANA KOROLEVA	{"phone": "+70282150619"}
0005432967459	B33686	5415 162094	NIKOLAY KAZAKOV	{"phone": "+70576238073"}
0005432967460	93612B	8894 192515	PAVEL IVANOV	{"email": "p.ivanov031981@postgrespro.ru", "phone": "+70192231740"}
0005432967461	93612B	1181 998710	EVGENIYA IVANOVA	{"email": "evgeniya_ivanova_15081965@postgrespro.ru", "phone": "+70314141204"}
0005432967462	4817F6	8099 803703	IGOR MIKHAYLOV	{"phone": "+70915139816"}
0005432967463	55E72A	1482 919536	IRAIDA AKIMOVA	{"phone": "+70478301777"}
0005432967464	55E72A	7374 539368	ANNA KUZMINA	{"email": "a-kuzmina.111970@postgrespro.ru", "phone": "+70802478307"}
0005432967465	7175C8	0759 921686	EKATERINA SOKOLOVA	{"phone": "+70096017477"}
0005432967466	28FE44	5800 810999	ELENA ZAKHAROVA	{"phone": "+70271407509"}
0005432967467	28FE44	8130 092563	DARYA FEDOROVA	{"email": "fedorovad03041979@postgrespro.ru", "phone": "+70736961732"}
0005432967468	7521AA	6684 461572	ALEKSEY NOVIKOV	{"email": "novikov_aleksey.1975@postgrespro.ru", "phone": "+70990651511"}
0005432967469	7521AA	6667 263386	KONSTANTIN IVANOV	{"email": "konstantin_ivanov-18041974@postgrespro.ru", "phone": "+70458819766"}
0005432967470	7521AA	7819 384929	RAISA KUZMINA	{"email": "kuzminar031977@postgrespro.ru", "phone": "+70711973417"}
0005432967471	D67F2B	9193 339827	VLADIMIR SOLOVEV	{"email": "vsolovev.021971@postgrespro.ru", "phone": "+70671984357"}
0005432967472	A9FC10	0003 400531	MIKHAIL ZHUKOV	{"email": "zhukovm.021968@postgrespro.ru", "phone": "+70693847449"}
0005432967473	459F0D	0933 610997	KSENIYA KONOVALOVA	{"phone": "+70412094650"}
0005432967474	459F0D	5131 858984	MARINA ARKHIPOVA	{"email": "marinaarkhipova.1973@postgrespro.ru", "phone": "+70750496083"}
0005432967475	F5AF33	9912 117117	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy.1972@postgrespro.ru", "phone": "+70708040425"}
0005432967476	F5AF33	2438 123678	VIKTORIYA VOROBEVA	{"phone": "+70377252556"}
0005432967477	17947D	1289 171084	NAZAR SOKOLOV	{"phone": "+70018540620"}
0005432967478	FF2134	9976 343013	ALEKSANDR ZAYCEV	{"phone": "+70201109186"}
0005432967479	D71B50	8113 050976	PAVEL KUZMIN	{"email": "kuzmin_p-031973@postgrespro.ru", "phone": "+70425219938"}
0005432967480	D71B50	5562 587488	NAIL FROLOV	{"email": "frolov_n1975@postgrespro.ru", "phone": "+70057140560"}
0005432967481	D71B50	6206 381387	MIKHAIL RODIONOV	{"email": "mikhail-rodionov_1968@postgrespro.ru", "phone": "+70568819540"}
0005432967482	DCD43D	8919 020876	YULIYA GERASIMOVA	{"phone": "+70109431744"}
0005432967483	F3D892	4874 457091	TIMOFEY TIMOFEEV	{"phone": "+70359298489"}
0005432967484	FAEC47	1949 387730	VYACHESLAV ILIN	{"phone": "+70349401156"}
0005432967485	FAEC47	4656 745315	ALEKSANDR ZAYCEV	{"email": "zaycevaleksandr.1964@postgrespro.ru", "phone": "+70850372438"}
0005432967486	A19D64	5326 830741	SVETLANA ZHURAVLEVA	{"phone": "+70505808684"}
0005432967487	A19D64	5055 972559	NATALYA CHERNOVA	{"phone": "+70453202654"}
0005432967488	E40EF4	1279 411270	DMITRIY SIDOROV	{"email": "d-sidorov-1969@postgrespro.ru", "phone": "+70149409719"}
0005432967489	E40EF4	8928 132930	ALEKSANDR MAKAROV	{"email": "makarov_a_121962@postgrespro.ru", "phone": "+70814109653"}
0005432967490	AEFB7A	0544 635961	ANDREY ZHUKOV	{"email": "zhukov-a.10021965@postgrespro.ru", "phone": "+70507364884"}
0005432967491	F584A6	2987 062156	TATYANA MAKAROVA	{"email": "makarova-t.081977@postgrespro.ru", "phone": "+70167795128"}
0005432967492	F584A6	9915 176438	NAILYA SCHERBAKOVA	{"email": "scherbakova.n.12111969@postgrespro.ru", "phone": "+70125528313"}
0005432967493	BD4379	7083 225516	EKATERINA POPOVA	{"email": "ekaterina_popova_1981@postgrespro.ru", "phone": "+70926617750"}
0005432967494	BD4379	7650 596956	VALENTINA LEBEDEVA	{"email": "lebedeva.v_111981@postgrespro.ru", "phone": "+70608766219"}
0005432967495	94E785	8788 947429	EVGENIY STEPANOV	{"phone": "+70222394184"}
0005432967496	A69F5D	6984 356062	VASILIY KUZNECOV	{"phone": "+70146260845"}
0005432967497	A69F5D	9536 199202	DMITRIY ALEKSANDROV	{"email": "dmitriyaleksandrov_1979@postgrespro.ru", "phone": "+70562264278"}
0005432967498	2B49B7	0342 896944	IVAN SEMENOV	{"email": "semenov.i.07021976@postgrespro.ru", "phone": "+70954086146"}
0005432967499	0CB15A	4841 939021	DANIIL GORBUNOV	{"email": "dgorbunov-111968@postgrespro.ru", "phone": "+70020582516"}
0005432967500	0CB15A	0306 839457	LARISA NOVIKOVA	{"phone": "+70801826116"}
0005432967501	BB4BC2	1118 643816	YURIY DMITRIEV	{"email": "y_dmitriev11091982@postgrespro.ru", "phone": "+70845212698"}
0005432967502	DBDCFF	9743 108035	NADEZHDA KOZLOVA	{"email": "nkozlova-1964@postgrespro.ru", "phone": "+70069049057"}
0005432967503	402EF0	2229 755924	ALBINA BORISOVA	{"phone": "+70649167490"}
0005432967504	20E615	1999 024569	ANNA KALININA	{"email": "a_kalinina.1967@postgrespro.ru", "phone": "+70832981606"}
0005432967506	7AE6C4	6985 698520	GERMAN ISAEV	{"phone": "+70662599555"}
0005432967507	3DBB9E	5084 213782	OLGA KULIKOVA	{"email": "olga.kulikova.15031979@postgrespro.ru", "phone": "+70123965217"}
0005432967508	4B24F6	4142 009695	VALERIY NIKOLAEV	{"phone": "+70745468836"}
0005432967509	4B24F6	4357 328019	KAMILLA KARPOVA	{"email": "karpova_kamilla_1975@postgrespro.ru", "phone": "+70968940709"}
0005432967510	1E8D22	4314 333987	IRINA LAZAREVA	{"phone": "+70617456821"}
0005432967511	C10FC0	2001 161410	ANDREY ORLOV	{"phone": "+70917078168"}
0005432967512	7E55F2	9138 480798	SERGEY BELOV	{"phone": "+70347014049"}
0005432967513	0DCDE9	6183 386848	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov.09091974@postgrespro.ru", "phone": "+70955648677"}
0005432967514	4FC9A4	6292 202638	VASILIY SOROKIN	{"email": "sorokin.vasiliy-1972@postgrespro.ru", "phone": "+70587046247"}
0005432967515	C06C7C	0995 714561	VERONIKA BELOVA	{"email": "veronika.belova.17081971@postgrespro.ru", "phone": "+70090336521"}
0005432967516	C06C7C	8132 606611	SVETLANA ALEKSEEVA	{"email": "alekseeva.svetlana.041965@postgrespro.ru", "phone": "+70033461947"}
0005432967517	D1E66F	4310 726619	LYUDMILA KUZMINA	{"email": "kuzminal_101973@postgrespro.ru", "phone": "+70306522668"}
0005432967518	178A6A	0502 310327	KAMIL MOROZOV	{"email": "morozov.k_091985@postgrespro.ru", "phone": "+70490593547"}
0005432967519	2F4E17	1397 839538	FANIS SOKOLOV	{"email": "sokolov.f-031977@postgrespro.ru", "phone": "+70403156714"}
0005432967520	4A84EE	3163 857405	EVGENIYA EFREMOVA	{"phone": "+70192416529"}
0005432967521	174DC2	1632 462582	MARIYA SMIRNOVA	{"email": "smirnova.mariya1971@postgrespro.ru", "phone": "+70140635128"}
0005432967522	174DC2	8494 153910	ANATOLIY BORISOV	{"email": "anatoliy_borisov06091978@postgrespro.ru", "phone": "+70913991184"}
0005432967523	157766	8540 362861	ANNA GUSEVA	{"phone": "+70156875729"}
0005432967524	157766	2979 378009	GALINA VOLKOVA	{"email": "volkova_galina-091964@postgrespro.ru", "phone": "+70655050255"}
0005432967525	1F8444	0131 255526	SERGEY SOKOLOV	{"phone": "+70869390407"}
0005432967526	1F8444	0892 589937	YULIYA DMITRIEVA	{"email": "dmitrievayuliya.04121966@postgrespro.ru", "phone": "+70818147381"}
0005432967527	1F8444	5217 781277	ANDREY EGOROV	{"phone": "+70169072127"}
0005432967528	1F8444	1156 478887	VLADIMIR VOLKOV	{"email": "v-volkov_1977@postgrespro.ru", "phone": "+70012493770"}
0005432967529	62653F	2000 883850	NADEZHDA NIKIFOROVA	{"email": "nikiforova_n.1975@postgrespro.ru", "phone": "+70972468529"}
0005432967530	A34C1B	5734 585043	MAKSIM STEPANOV	{"phone": "+70014277477"}
0005432967531	CE5A84	5967 093444	DANIYA NOVIKOVA	{"email": "daniya_novikova1960@postgrespro.ru", "phone": "+70840575803"}
0005432967532	5DB828	9091 614788	YULIYA DENISOVA	{"phone": "+70979314116"}
0005432967590	DC808C	3020 590650	EVGENIY KUZNECOV	{"phone": "+70588339422"}
0005432967533	AC0B49	3916 682925	IVAN KOROLEV	{"email": "korolev.ivan-051972@postgrespro.ru", "phone": "+70280521322"}
0005432967534	6DAFA7	8847 190097	KLAVDIYA MIRONOVA	{"phone": "+70645705100"}
0005432967535	6DAFA7	8580 509096	VALENTINA KRASNOVA	{"email": "vkrasnova1972@postgrespro.ru", "phone": "+70342978858"}
0005432967536	01407A	1227 813647	IVAN SOKOLOV	{"phone": "+70618990876"}
0005432967537	39B0C8	7443 295098	VIKTOR STEPANOV	{"phone": "+70133149405"}
0005432967538	38F76D	9302 962689	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova1968@postgrespro.ru", "phone": "+70052175812"}
0005432967539	38F76D	0811 088376	LYUBOV KUZNECOVA	{"phone": "+70770074447"}
0005432967540	73C352	5011 919534	SALAVAT ALEKSEEV	{"email": "salekseev_1965@postgrespro.ru", "phone": "+70971660163"}
0005432967541	08B014	8192 363671	VALENTINA OSIPOVA	{"email": "osipova_valentina.1975@postgrespro.ru", "phone": "+70086636273"}
0005432967542	6C752C	1582 457613	ANATOLIY DENISOV	{"phone": "+70606185842"}
0005432967543	2A67B8	8657 879924	PRASKOVYA VOLKOVA	{"email": "volkovapraskovya1967@postgrespro.ru", "phone": "+70215077824"}
0005432967544	D5F0CA	9237 130240	PETR IVANOV	{"email": "p.ivanov.101979@postgrespro.ru", "phone": "+70443889729"}
0005432967545	BF94AB	9506 186283	NIKOLAY NAZAROV	{"email": "nikolaynazarov_27121977@postgrespro.ru", "phone": "+70328837391"}
0005432967546	BF94AB	8413 283169	MARINA ILINA	{"email": "marina.ilina101976@postgrespro.ru", "phone": "+70357754194"}
0005432967547	1DD438	8012 968426	VALERIY POPOV	{"phone": "+70017037366"}
0005432967548	1DD438	9128 462076	LARISA ALEKSEEVA	{"email": "alekseeva.larisa10061964@postgrespro.ru", "phone": "+70088434005"}
0005432967549	42985F	1321 493931	VIKTOR PETROV	{"email": "petrov-viktor_091974@postgrespro.ru", "phone": "+70913409145"}
0005432967550	42985F	1735 670584	OLEG MOROZOV	{"phone": "+70492520974"}
0005432967551	DEF55A	7698 323249	IRINA PAVLOVA	{"phone": "+70985452662"}
0005432967552	DEF55A	7930 993766	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov_1973@postgrespro.ru", "phone": "+70572556932"}
0005432967553	EEB3F5	3964 912037	ILYA MAKSIMOV	{"email": "ilya.maksimov1977@postgrespro.ru", "phone": "+70430145303"}
0005432967554	2BF9D9	3122 533182	GALINA MASLOVA	{"email": "g.maslova08081965@postgrespro.ru", "phone": "+70742053438"}
0005432967555	2BF9D9	3937 072436	NATALYA KONOVALOVA	{"phone": "+70672208626"}
0005432967556	ACBD43	2500 027783	GALINA TARASOVA	{"email": "gtarasova.1965@postgrespro.ru", "phone": "+70826745210"}
0005432967557	8F6BD1	8578 938615	OLGA DMITRIEVA	{"phone": "+70860616620"}
0005432967558	CB9C8D	2414 887807	YURIY ANTONOV	{"email": "antonov.yuriy_1965@postgrespro.ru", "phone": "+70219765895"}
0005432967559	F9BAFC	4582 600767	LYUDMILA NOVIKOVA	{"email": "novikova-l111987@postgrespro.ru", "phone": "+70137437024"}
0005432967560	F9BAFC	3796 272385	ANATOLIY OSIPOV	{"email": "a.osipov_041972@postgrespro.ru", "phone": "+70036154720"}
0005432967561	F114BC	6560 679633	ANDREY POPOV	{"phone": "+70227218106"}
0005432967562	FBE6E7	8503 781170	SERGEY POPOV	{"email": "popov.sergey_1979@postgrespro.ru", "phone": "+70166212748"}
0005432967563	EFAB0D	6385 126391	NIKOLAY SCHERBAKOV	{"email": "n.scherbakov-1970@postgrespro.ru", "phone": "+70212677246"}
0005432967564	57FAD3	4145 507479	PAVEL FROLOV	{"phone": "+70481326664"}
0005432967565	E74195	8086 113600	LIDIYA VLASOVA	{"phone": "+70259372834"}
0005432967566	A18241	2364 526649	VIKTOR BELOV	{"email": "belov.viktor_1974@postgrespro.ru", "phone": "+70358610922"}
0005432967567	A18241	2854 715051	ZHANNA LUKYANOVA	{"email": "zhanna.lukyanova.041984@postgrespro.ru", "phone": "+70692827658"}
0005432967568	9C0E65	6066 105171	KHALIDA SMIRNOVA	{"phone": "+70863590378"}
0005432967569	9C0E65	8566 308167	ALEKSANDR EGOROV	{"email": "egorov-a_1977@postgrespro.ru", "phone": "+70162678070"}
0005432967570	DF0A44	0225 757070	NATALYA TIMOFEEVA	{"email": "natalya.timofeeva-041978@postgrespro.ru", "phone": "+70395410127"}
0005432967571	DF0A44	2541 126130	IRINA POTAPOVA	{"phone": "+70536128587"}
0005432967572	993191	0470 180769	NIKOLAY STEPANOV	{"phone": "+70638369208"}
0005432967573	7E1706	0844 560025	MIKHAIL FROLOV	{"email": "frolov-mikhail_04081963@postgrespro.ru", "phone": "+70508702424"}
0005432967574	5486C9	9508 581185	NATALYA BORISOVA	{"phone": "+70737490439"}
0005432967575	8B1E67	7301 115635	IRINA KULIKOVA	{"email": "kulikova.irina.03121976@postgrespro.ru", "phone": "+70124509330"}
0005432967576	913431	9523 724661	ALEKSANDR VOROBEV	{"phone": "+70284335666"}
0005432967577	0CDB21	2636 688945	DMITRIY SOLOVEV	{"email": "solovevdmitriy.1977@postgrespro.ru", "phone": "+70412016233"}
0005432967578	0B0418	9782 698823	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr_021973@postgrespro.ru", "phone": "+70739847583"}
0005432967579	EF628D	6260 472966	LYUDMILA GORBUNOVA	{"phone": "+70209847868"}
0005432967636	F465A6	7719 347252	NIKOLAY FROLOV	{"phone": "+70079923699"}
0005432967580	EF628D	2865 977786	NATALYA BELOVA	{"email": "belova-natalya05091976@postgrespro.ru", "phone": "+70429710922"}
0005432967581	E8DE21	6724 262934	ZINAIDA PAVLOVA	{"phone": "+70097415541"}
0005432967582	211219	0835 456152	VALENTINA KUZNECOVA	{"email": "vkuznecova22121973@postgrespro.ru", "phone": "+70961975291"}
0005432967583	211219	5218 371698	VLADIMIR VASILEV	{"email": "vladimir_vasilev011980@postgrespro.ru", "phone": "+70986258555"}
0005432967584	4744F8	0617 231973	KLAVDIYA VASILEVA	{"email": "vasilevak-021972@postgrespro.ru", "phone": "+70140944812"}
0005432967585	084450	2803 503426	OLGA SERGEEVA	{"email": "sergeeva-olga.09121976@postgrespro.ru", "phone": "+70988398139"}
0005432967586	308097	9939 215261	ALEKSANDR SEMENOV	{"email": "semenov_a_03101972@postgrespro.ru", "phone": "+70669865854"}
0005432967587	308097	5255 457714	GENNADIY VASILEV	{"email": "gennadiyvasilev-1988@postgrespro.ru", "phone": "+70850946465"}
0005432967588	308097	9302 851422	ALENA IVANOVA	{"phone": "+70007454575"}
0005432967589	DC808C	9960 510085	LYUBOV LUKYANOVA	{"email": "lukyanova_lyubov.08021983@postgrespro.ru", "phone": "+70412057137"}
0005432967591	B28730	3116 940036	VIKTORIYA KUZNECOVA	{"email": "kuznecova-viktoriya1980@postgrespro.ru", "phone": "+70794042073"}
0005432967592	B28730	6612 516110	MIKHAIL VLASOV	{"email": "mikhail.vlasov1986@postgrespro.ru", "phone": "+70560513664"}
0005432967593	410F9A	8186 605759	ALEKSANDRA KAZAKOVA	{"phone": "+70290616382"}
0005432967594	410F9A	6317 326171	PAVEL KARPOV	{"email": "pavel.karpov.1975@postgrespro.ru", "phone": "+70274206123"}
0005432967595	7E5FC8	4943 322902	ALEKSANDRA NIKITINA	{"phone": "+70713316611"}
0005432967596	090C8F	1056 667838	ZOYA NIKOLAEVA	{"phone": "+70599226650"}
0005432967597	090C8F	4134 674858	DMITRIY NAZAROV	{"email": "nazarovd.011961@postgrespro.ru", "phone": "+70481851043"}
0005432967598	6DA41A	4035 888685	IRINA KUZNECOVA	{"email": "kuznecova.irina.30031973@postgrespro.ru", "phone": "+70618039041"}
0005432967599	38C8FD	7091 886718	LYUDMILA DMITRIEVA	{"email": "dmitrieva_lyudmila-11121979@postgrespro.ru", "phone": "+70643154127"}
0005432967600	873A44	1349 944656	LIDIYA RODIONOVA	{"email": "lrodionova.1975@postgrespro.ru", "phone": "+70047231166"}
0005432967601	873A44	4492 088446	MARIYA KUDRYASHOVA	{"phone": "+70372333728"}
0005432967602	CED176	4532 309107	ALEKSANDR ZAKHAROV	{"phone": "+70073484750"}
0005432967603	CED176	0657 607429	OLGA ORLOVA	{"email": "orlova-olga_031969@postgrespro.ru", "phone": "+70334567655"}
0005432967604	CED176	1554 180835	RAMIL SMIRNOV	{"phone": "+70673081907"}
0005432967605	CED176	9673 205875	IGOR VLASOV	{"phone": "+70917022773"}
0005432967606	C5B29C	3414 697304	NIKOLAY VLASOV	{"phone": "+70371240319"}
0005432967607	ACBFAE	1035 375726	DMITRIY KUZNECOV	{"phone": "+70087588966"}
0005432967608	ACBFAE	0323 272210	ELENA ABRAMOVA	{"email": "abramova.elena-031979@postgrespro.ru", "phone": "+70308323483"}
0005432967609	ACBFAE	3170 963739	NIKITA VOLKOV	{"email": "volkovnikita-121966@postgrespro.ru", "phone": "+70049751327"}
0005432967610	B0D80D	8834 260363	KSENIYA NIKOLAEVA	{"email": "k.nikolaeva13121975@postgrespro.ru", "phone": "+70562155691"}
0005432967611	88DAB2	4885 326858	NINA NAZAROVA	{"email": "n.nazarova_24021979@postgrespro.ru", "phone": "+70277853369"}
0005432967612	A42D36	7185 686949	ALEKSANDR SOROKIN	{"phone": "+70805190673"}
0005432967613	E7B0A2	4627 783044	VIKTORIYA IVANOVA	{"phone": "+70489678317"}
0005432967614	E7B0A2	1393 758940	NINA KONOVALOVA	{"phone": "+70080320626"}
0005432967615	13176A	8297 675619	OLGA LUKYANOVA	{"phone": "+70895597459"}
0005432967616	513C40	3403 420782	ALLA SIDOROVA	{"email": "sidorova_a.1978@postgrespro.ru", "phone": "+70985575172"}
0005432967617	4A25F6	6022 283100	EVDOKIYA ALEKSANDROVA	{"phone": "+70904042846"}
0005432967618	23394D	9247 625812	ANDREY VASILEV	{"email": "a.vasilev091981@postgrespro.ru", "phone": "+70606906203"}
0005432967619	23394D	9053 882298	ALEKSANDR IVANOV	{"email": "a_ivanov-1981@postgrespro.ru", "phone": "+70399626169"}
0005432967620	17C830	7184 566344	MARGARITA BELYAEVA	{"email": "margaritabelyaeva_101972@postgrespro.ru", "phone": "+70780303349"}
0005432967621	9262F8	3144 697762	EVGENIY DENISOV	{"phone": "+70664482461"}
0005432967622	AEB1B4	2927 992994	ELIZAVETA NIKOLAEVA	{"email": "elizaveta-nikolaeva.111975@postgrespro.ru", "phone": "+70904248011"}
0005432967623	4143AB	8267 753307	ANASTASIYA KOZLOVA	{"phone": "+70049596804"}
0005432967624	CCF127	2508 954444	ANDREY BONDARENKO	{"phone": "+70566761767"}
0005432967625	38E711	8419 964356	VLADIMIR ANDREEV	{"phone": "+70623662008"}
0005432967626	4EAC39	0139 309715	YAROSLAV KONOVALOV	{"phone": "+70808944540"}
0005432967627	8C07FE	7823 253303	ANDREY ZAKHAROV	{"email": "andrey-zakharov1977@postgrespro.ru", "phone": "+70408075259"}
0005432967628	08A899	2918 986929	VLADIMIR ALEKSANDROV	{"email": "v.aleksandrov.1964@postgrespro.ru", "phone": "+70130749950"}
0005432967629	C3952E	3671 974553	ELENA MELNIKOVA	{"email": "elena.melnikova-1974@postgrespro.ru", "phone": "+70193203457"}
0005432967630	B31A7F	2885 586790	ALINA LEBEDEVA	{"phone": "+70292755366"}
0005432967631	7F4135	7087 524652	NINA BORISOVA	{"email": "borisova_n-25041975@postgrespro.ru", "phone": "+70166589099"}
0005432967632	920922	7381 625954	LYUDMILA AFANASEVA	{"phone": "+70400082906"}
0005432967633	EFC02F	1398 352815	NIKOLAY SMIRNOV	{"phone": "+70647389079"}
0005432967634	BD7264	9653 832182	YULIYA ABRAMOVA	{"phone": "+70142716364"}
0005432967635	BD7264	1724 466871	NATALIYA DENISOVA	{"email": "nataliyadenisova_1984@postgrespro.ru", "phone": "+70328985222"}
0005432967637	27E0A3	7258 852020	VLADIMIR OSIPOV	{"email": "osipovvladimir.081970@postgrespro.ru", "phone": "+70952881957"}
0005432967638	E7F05E	1639 157128	ANATOLIY KUZNECOV	{"phone": "+70450040865"}
0005432967639	E7F05E	6691 409794	ANDREY ROMANOV	{"email": "aromanov1968@postgrespro.ru", "phone": "+70611712302"}
0005432967640	2B067E	7740 675985	SVETLANA KISELEVA	{"email": "svetlana_kiseleva.18081976@postgrespro.ru", "phone": "+70712650277"}
0005432967641	619531	1300 286416	SVETLANA KUZMINA	{"phone": "+70373605788"}
0005432967642	619531	3650 293212	SVETLANA NAUMOVA	{"phone": "+70226262210"}
0005432967643	948409	5284 201824	VIKTOR KUZMIN	{"phone": "+70322881002"}
0005432967644	948409	3652 686682	VALERIY KUDRYASHOV	{"phone": "+70557393185"}
0005432967645	B7773B	5456 851430	NIKOLAY GAVRILOV	{"email": "gavrilovnikolay_1981@postgrespro.ru", "phone": "+70510277089"}
0005432967646	B7773B	3044 295909	VYACHESLAV KUZNECOV	{"email": "kuznecov-vyacheslav_051972@postgrespro.ru", "phone": "+70291308990"}
0005432967647	674EEC	2731 287402	NADEZHDA RODIONOVA	{"phone": "+70749578099"}
0005432967648	674EEC	1667 805833	IRAIDA VASILEVA	{"phone": "+70860162966"}
0005432967649	9DA99F	2236 724157	ALEKSANDR MEDVEDEV	{"phone": "+70263593723"}
0005432967650	0E6AE6	3619 088242	IGOR ILIN	{"phone": "+70241235738"}
0005432967651	0E6AE6	8533 747959	LYUDMILA YUDINA	{"phone": "+70447113585"}
0005432967652	393DE5	6236 200071	MARINA ZHUKOVA	{"email": "marinazhukova19111971@postgrespro.ru", "phone": "+70145536729"}
0005432967653	393DE5	3119 815602	AMIR MAKAROV	{"phone": "+70100678655"}
0005432967654	3158A6	4924 921093	ELIZAVETA SAVELEVA	{"phone": "+70364393580"}
0005432967655	F138B2	0217 509895	ANTONINA NESTEROVA	{"phone": "+70061049099"}
0005432967656	AF8BBB	7533 408951	VALENTIN KUZMIN	{"phone": "+70580311931"}
0005432967657	8A4631	4804 902273	ALEKSANDRA MELNIKOVA	{"email": "aleksandramelnikova011971@postgrespro.ru", "phone": "+70837557405"}
0005432967658	8A4631	2661 550484	NADEZHDA GRISHINA	{"phone": "+70852041737"}
0005432967659	AF651C	6603 825080	VIKTORIYA DMITRIEVA	{"email": "dmitrieva_v_1968@postgrespro.ru", "phone": "+70421323871"}
0005432967660	DD8292	8169 911366	ALEKSANDRA BORISOVA	{"email": "borisova-aleksandra-08081971@postgrespro.ru", "phone": "+70430365484"}
0005432967661	DD8292	8823 751470	NIKOLAY NIKOLAEV	{"email": "nikolay_nikolaev.101974@postgrespro.ru", "phone": "+70090873328"}
0005432967662	D3440E	3313 801473	GALINA ORLOVA	{"email": "orlovagalina_1977@postgrespro.ru", "phone": "+70980489465"}
0005432967663	DA76C4	5131 605981	VYACHESLAV SEMENOV	{"phone": "+70691824266"}
0005432967664	4C85C8	9394 213701	PETR ILIN	{"email": "ilin-p1971@postgrespro.ru", "phone": "+70914370603"}
0005432967665	4C85C8	3956 377981	RUSTEM VOLKOV	{"phone": "+70775615676"}
0005432967666	8FFF97	8602 394375	IRINA NIKITINA	{"phone": "+70501546359"}
0005432967667	85EBB9	0720 391755	VADIM ZAYCEV	{"phone": "+70161141617"}
0005432967668	93D596	9623 861116	ARTEM OSIPOV	{"phone": "+70460197272"}
0005432967669	93D596	8434 007064	OLGA ROMANOVA	{"phone": "+70143726620"}
0005432967670	732985	4334 679400	ELENA GAVRILOVA	{"phone": "+70600692112"}
0005432967671	E9DE3D	3674 213428	ARTEM TIKHONOV	{"phone": "+70257019939"}
0005432967672	DB5C21	2782 113860	VITALIY POPOV	{"phone": "+70273811697"}
0005432967673	268A8B	2370 334439	VADIM ISAEV	{"email": "isaev.v111966@postgrespro.ru", "phone": "+70907329906"}
0005432967674	243C2B	0503 913891	VITALIY NAUMOV	{"phone": "+70339923199"}
0005432967675	476610	4050 733353	TATYANA MEDVEDEVA	{"email": "t_medvedeva_05051971@postgrespro.ru", "phone": "+70565778122"}
0005432967676	C841E2	1495 029400	SVETLANA POPOVA	{"phone": "+70014804552"}
0005432967677	159219	2699 209108	VALERIY TIMOFEEV	{"email": "v_timofeev.101974@postgrespro.ru", "phone": "+70919764174"}
0005432967678	8E8812	7055 363806	OLGA MIKHAYLOVA	{"phone": "+70144863376"}
0005432967679	6BCDBD	4894 217518	VLADIMIR OSIPOV	{"phone": "+70499192039"}
0005432967680	6BCDBD	1121 787025	NATALYA FOMINA	{"email": "natalya_fomina.101961@postgrespro.ru", "phone": "+70233445146"}
0005432967681	016B09	9894 020431	VALENTINA ALEKSEEVA	{"phone": "+70343677649"}
0005432967682	016B09	8572 616245	ELENA FROLOVA	{"email": "frolova_elena121967@postgrespro.ru", "phone": "+70354137395"}
0005432967683	016B09	2710 259557	OKSANA ERMAKOVA	{"email": "ermakova-o.061981@postgrespro.ru", "phone": "+70112782545"}
0005432967684	2B7D95	5637 779925	OLGA KUZNECOVA	{"phone": "+70577196880"}
0005432967685	95BF19	4294 174417	ZHANNA NESTEROVA	{"email": "z-nesterova-08091977@postgrespro.ru", "phone": "+70145127493"}
0005432967686	B3781B	2383 621457	OLESYA MIKHAYLOVA	{"email": "mikhaylova.o-15101968@postgrespro.ru", "phone": "+70462450535"}
0005432968896	404522	7318 657026	DMITRIY TARASOV	{"phone": "+70772432488"}
0005432968801	24D203	2857 453682	MARIYA AKIMOVA	{"email": "akimovamariya.1971@postgrespro.ru", "phone": "+70861775914"}
0005432968802	DF2574	4026 134707	ELENA SOLOVEVA	{"email": "e.soloveva.111981@postgrespro.ru", "phone": "+70709305078"}
0005432968803	DF2574	9974 766737	ANTONINA NIKOLAEVA	{"email": "nikolaeva.a-061982@postgrespro.ru", "phone": "+70480835597"}
0005432968804	945701	7008 450759	VIKTOR SEMENOV	{"phone": "+70041958147"}
0005432968805	945701	8537 833485	INNA ALEKSEEVA	{"phone": "+70442679619"}
0005432968806	3C6F2F	7873 629688	NIKOLAY ALEKSANDROV	{"email": "nikolayaleksandrov031968@postgrespro.ru", "phone": "+70111164363"}
0005432968807	39AB90	7121 917907	ZOYA FEDOROVA	{"email": "z.fedorova.041979@postgrespro.ru", "phone": "+70303881328"}
0005432968808	D5FAE7	8326 872179	LARISA PAVLOVA	{"email": "pavlova.larisa-1980@postgrespro.ru", "phone": "+70780894114"}
0005432968809	D5FAE7	9744 550607	ELMIRA MASLOVA	{"phone": "+70717525270"}
0005432968810	4B8DDC	2723 408642	EVGENIYA MOISEEVA	{"phone": "+70253078875"}
0005432968811	F6D65A	5180 660587	ALEKSANDR KARPOV	{"email": "karpov_aleksandr_20051975@postgrespro.ru", "phone": "+70415805150"}
0005432968812	875E4C	0293 461254	VLADIMIR SEMENOV	{"email": "semenov_vladimir_1973@postgrespro.ru", "phone": "+70050640329"}
0005432968813	5382EE	5217 050506	LIDIYA MOROZOVA	{"email": "morozova.lidiya031971@postgrespro.ru", "phone": "+70983816089"}
0005432968814	5382EE	5692 496554	VLADIMIR SOROKIN	{"email": "vladimirsorokin_17021968@postgrespro.ru", "phone": "+70468135110"}
0005432968815	E61971	7477 715993	ELENA KISELEVA	{"email": "kiseleva_e.1970@postgrespro.ru", "phone": "+70198892753"}
0005432968816	D0FE6C	6026 410547	ANNA ZOTOVA	{"phone": "+70130895883"}
0005432968817	D0FE6C	9070 095981	AMIR KUDRYASHOV	{"email": "kudryashov.a-121975@postgrespro.ru", "phone": "+70724801184"}
0005432968818	B20FB4	0730 572639	VLADIMIR DENISOV	{"email": "v.denisov_011968@postgrespro.ru", "phone": "+70257534955"}
0005432968819	0ED372	5364 371950	VERA MASLOVA	{"phone": "+70460294390"}
0005432968820	9F0132	4098 744370	DMITRIY POPOV	{"email": "d_popov031974@postgrespro.ru", "phone": "+70050733350"}
0005432968821	DED3D2	9141 856976	RAISA VASILEVA	{"email": "raisa_vasileva19081968@postgrespro.ru", "phone": "+70398295113"}
0005432968822	DED3D2	0528 203858	NATALYA MATVEEVA	{"phone": "+70391762559"}
0005432968823	F1839D	8256 142552	SERGEY POPOV	{"email": "sergey.popov.05011976@postgrespro.ru", "phone": "+70286399778"}
0005432968824	F1839D	7318 963101	NINA FOMINA	{"email": "fomina-n.1973@postgrespro.ru", "phone": "+70787733156"}
0005432968825	3FAD41	4874 272242	VLADIMIR KUZMIN	{"phone": "+70805322166"}
0005432968826	9FB126	2377 909634	SERGEY NAZAROV	{"email": "sergey_nazarov_29071973@postgrespro.ru", "phone": "+70131507823"}
0005432968827	C30902	9248 143433	OLGA MASLOVA	{"email": "maslova.olga_1981@postgrespro.ru", "phone": "+70479587324"}
0005432968828	4F741E	8561 342750	ANATOLIY MOROZOV	{"email": "a_morozov1968@postgrespro.ru", "phone": "+70105217892"}
0005432968829	4F741E	8742 816907	SERGEY POPOV	{"phone": "+70893536823"}
0005432968830	5992C0	4310 325816	OLGA BELOVA	{"email": "o_belova-26101954@postgrespro.ru", "phone": "+70675641096"}
0005432968831	8C38CB	7224 283761	NAILYA ZAKHAROVA	{"email": "zakharova.nailya_27021964@postgrespro.ru", "phone": "+70368779128"}
0005432968832	098A74	1243 450032	VLADISLAV IVANOV	{"phone": "+70011179673"}
0005432968833	098A74	5857 409200	OLGA DENISOVA	{"phone": "+70561365261"}
0005432968834	99B168	7811 700655	VITALIY GERASIMOV	{"phone": "+70948204750"}
0005432968835	99B168	5912 509545	EKATERINA OSIPOVA	{"email": "e.osipova_121974@postgrespro.ru", "phone": "+70385155101"}
0005432968836	99B168	0129 983717	RUSLAN KOZLOV	{"email": "r_kozlov071973@postgrespro.ru", "phone": "+70779044704"}
0005432968837	F6CCE5	9659 545003	MARINA FILIPPOVA	{"email": "filippova-marina.15121965@postgrespro.ru", "phone": "+70579212084"}
0005432968838	B042B1	6986 571841	NIKOLAY EGOROV	{"phone": "+70554295133"}
0005432968839	02E498	1504 809771	ZOYA EFIMOVA	{"phone": "+70749579473"}
0005432968840	56D83A	6683 085495	LYUDMILA KUZNECOVA	{"phone": "+70311652976"}
0005432968841	56D83A	1782 403496	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a_051968@postgrespro.ru", "phone": "+70704706926"}
0005432968842	85BDFC	7143 509414	IRINA AFANASEVA	{"email": "irinaafanaseva-1978@postgrespro.ru", "phone": "+70302842829"}
0005432968843	658DD1	8317 927749	ZINAIDA KOROLEVA	{"email": "koroleva-zinaida-1969@postgrespro.ru", "phone": "+70748702866"}
0005432968844	2E0349	8107 843681	VYACHESLAV ZAYCEV	{"phone": "+70125942861"}
0005432968845	F44A93	2584 830686	ALEKSEY PAVLOV	{"email": "aleksey_pavlov-05011966@postgrespro.ru", "phone": "+70829452002"}
0005432968846	381B09	4967 120060	EKATERINA MIKHAYLOVA	{"email": "mikhaylova_e_1963@postgrespro.ru", "phone": "+70317631637"}
0005432968847	381B09	3396 248182	YULIYA TARASOVA	{"phone": "+70136531013"}
0005432968848	064A71	9655 697097	IVAN CHERNOV	{"phone": "+70044550217"}
0005432968849	F758EE	0510 233395	VLADIMIR KISELEV	{"email": "kiselev.v-09101962@postgrespro.ru", "phone": "+70144372121"}
0005432968850	F758EE	3601 863002	ALEKSEY VLASOV	{"email": "aleksey_vlasov081977@postgrespro.ru", "phone": "+70136399307"}
0005432968851	3F9994	5585 953597	ALESYA AFANASEVA	{"email": "a.afanaseva-071981@postgrespro.ru", "phone": "+70760714883"}
0005432968852	3F9994	4591 633200	VALERIY MIKHAYLOV	{"phone": "+70567438996"}
0005432968853	2FB596	6345 259814	TATYANA ILINA	{"email": "tilina-24111971@postgrespro.ru", "phone": "+70937845342"}
0005432968854	2FB596	4960 251096	TATYANA POPOVA	{"phone": "+70505391217"}
0005432968855	AAE83A	3695 432054	LYUBOV MOROZOVA	{"email": "morozova-l-27091974@postgrespro.ru", "phone": "+70171355173"}
0005432968856	229AA8	1716 163389	EVGENIYA KARPOVA	{"email": "evgeniya-karpova1977@postgrespro.ru", "phone": "+70233121218"}
0005432968857	229AA8	2033 322750	VLADISLAV NIKOLAEV	{"email": "vnikolaev-1962@postgrespro.ru", "phone": "+70505076984"}
0005432968858	B8518B	9144 031141	EKATERINA SCHERBAKOVA	{"email": "scherbakova.e-13011975@postgrespro.ru", "phone": "+70962087123"}
0005432968859	B8518B	2723 358294	TATYANA ANDREEVA	{"email": "tandreeva-051979@postgrespro.ru", "phone": "+70154975411"}
0005432968860	8DB077	7579 109276	IVAN NOVIKOV	{"email": "i_novikov-071966@postgrespro.ru", "phone": "+70193923399"}
0005432968861	95D05D	5878 212533	OLGA BELYAEVA	{"email": "o_belyaeva.021960@postgrespro.ru", "phone": "+70940101608"}
0005432968862	A7C084	9832 923327	KONSTANTIN MIKHAYLOV	{"email": "k-mikhaylov1963@postgrespro.ru", "phone": "+70163411275"}
0005432968863	A7C084	0867 048060	EVA OVCHINNIKOVA	{"phone": "+70469680546"}
0005432968864	F1CC2B	4846 201418	NATALYA AFANASEVA	{"phone": "+70580195505"}
0005432968865	F1B746	2363 160355	TATYANA DMITRIEVA	{"email": "dmitrievat.1966@postgrespro.ru", "phone": "+70882201314"}
0005432968866	F1B746	8894 819996	DARYA OVCHINNIKOVA	{"phone": "+70492693424"}
0005432968867	521D58	5391 904434	NADEZHDA ZAYCEVA	{"phone": "+70437129584"}
0005432968868	3A8430	1326 283026	SERGEY NIKITIN	{"email": "s_nikitin_28051966@postgrespro.ru", "phone": "+70299319020"}
0005432968869	1B4291	8519 285090	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr121981@postgrespro.ru", "phone": "+70703209041"}
0005432968870	2C9921	5051 347195	ANASTASIYA DANILOVA	{"email": "a.danilova1968@postgrespro.ru", "phone": "+70345360713"}
0005432968871	2C9921	5405 768939	NINA DANILOVA	{"phone": "+70911710298"}
0005432968872	A3854A	4303 278831	TATYANA ANTONOVA	{"email": "antonovatatyana18111964@postgrespro.ru", "phone": "+70867696305"}
0005432968873	F8ACE0	9056 171931	EGOR FROLOV	{"phone": "+70689578730"}
0005432968874	F8ACE0	1917 333048	NIKOLAY MAKAROV	{"phone": "+70059662435"}
0005432968875	763FD5	1014 582637	EGOR CHERNOV	{"email": "e-chernov_25101972@postgrespro.ru", "phone": "+70877752675"}
0005432968876	70E4E4	2405 446544	INNA CHERNOVA	{"email": "chernova-inna-1976@postgrespro.ru", "phone": "+70586802400"}
0005432968877	8EB645	2943 161738	VALENTINA KUZMINA	{"email": "v.kuzmina.061966@postgrespro.ru", "phone": "+70228398987"}
0005432968878	37D049	4210 730899	IRINA IVANOVA	{"phone": "+70998866895"}
0005432968879	CDBA56	0727 638091	ALBINA ZAKHAROVA	{"phone": "+70797809096"}
0005432968880	C3428E	0068 382345	ANNA KUZNECOVA	{"phone": "+70997611379"}
0005432968881	28C417	8371 604574	ANNA VOLKOVA	{"email": "anna-volkova_21011975@postgrespro.ru", "phone": "+70806331508"}
0005432968882	28C417	6914 763622	NATALYA KONOVALOVA	{"email": "n.konovalova.1962@postgrespro.ru", "phone": "+70657406694"}
0005432968883	85F412	4595 114326	EVGENIYA EGOROVA	{"phone": "+70279921209"}
0005432968884	85F412	5564 824118	DARYA KAZAKOVA	{"phone": "+70729715867"}
0005432968885	0D5CEF	8867 143507	NATALYA SCHERBAKOVA	{"email": "scherbakova-natalya.10061973@postgrespro.ru", "phone": "+70007984935"}
0005432968886	5A99FB	6640 011794	VALERIY KUZNECOV	{"email": "v-kuznecov1957@postgrespro.ru", "phone": "+70047885533"}
0005432968887	5A99FB	3505 749153	NATALIYA MOISEEVA	{"email": "nmoiseeva_06061975@postgrespro.ru", "phone": "+70840460337"}
0005432968888	5A99FB	5134 457400	LYUDMILA ANTONOVA	{"email": "antonova_l061978@postgrespro.ru", "phone": "+70112066214"}
0005432968889	C7C123	1978 068141	EDUARD NAZAROV	{"phone": "+70844237792"}
0005432968890	F7942B	4272 602456	TATYANA IVANOVA	{"email": "t_ivanova1979@postgrespro.ru", "phone": "+70275624027"}
0005432968891	00EC8D	2723 446790	OLEG GERASIMOV	{"email": "gerasimov.o.051985@postgrespro.ru", "phone": "+70025424642"}
0005432968892	6B0C5C	3241 545684	NIKITA PETROV	{"email": "nikita.petrov_1972@postgrespro.ru", "phone": "+70375194789"}
0005432968893	C93CDA	1261 840229	MARINA ZAYCEVA	{"email": "marinazayceva_111977@postgrespro.ru", "phone": "+70563602697"}
0005432968894	C93CDA	0769 084189	VYACHESLAV NOVIKOV	{"phone": "+70766726908"}
0005432968895	B6A39B	7194 045208	VLADIMIR CHERNOV	{"email": "vladimir-chernov.1977@postgrespro.ru", "phone": "+70685199714"}
0005432968897	404522	6384 107127	LYUBOV ANTONOVA	{"email": "lantonova.1973@postgrespro.ru", "phone": "+70439689464"}
0005432968898	62D590	7061 753515	LYUBOV CHERNOVA	{"email": "chernova.l_1972@postgrespro.ru", "phone": "+70903635875"}
0005432968899	62D590	5078 208709	MARGARITA KULIKOVA	{"email": "kulikova_margarita18091976@postgrespro.ru", "phone": "+70447460438"}
0005432968900	D7F134	2312 302690	IVAN CHERNOV	{"email": "chernov-i.1966@postgrespro.ru", "phone": "+70331212192"}
0005432968901	D7F134	4127 139610	GALINA STEPANOVA	{"phone": "+70630599342"}
0005432968902	A8E1E0	1441 361660	ALEKSANDR SERGEEV	{"email": "sergeev.a_101962@postgrespro.ru", "phone": "+70388251706"}
0005432968903	A8E1E0	1286 008090	DMITRIY SERGEEV	{"email": "dmitriysergeev_121967@postgrespro.ru", "phone": "+70777405532"}
0005432968904	CFF336	2916 926442	NADEZHDA DMITRIEVA	{"phone": "+70788344316"}
0005432968905	1CC70A	0182 408168	ALEKSANDR OSIPOV	{"phone": "+70894644381"}
0005432968906	9D9419	8331 577573	ALEKSEY SAVELEV	{"phone": "+70165117093"}
0005432968907	9D9419	5421 963730	OLGA BORISOVA	{"email": "borisova-o-1973@postgrespro.ru", "phone": "+70676105898"}
0005432968908	DF0A8D	1209 724909	VIKTOR KUZNECOV	{"email": "kuznecov-viktor.1978@postgrespro.ru", "phone": "+70910928214"}
0005432968909	DF0A8D	1988 976054	ARTEM MIKHAYLOV	{"email": "mikhaylova01071975@postgrespro.ru", "phone": "+70439184016"}
0005432968910	F78159	1506 036135	ALEKSANDR ABRAMOV	{"phone": "+70712455110"}
0005432968911	C028C4	2415 940014	MARINA AFANASEVA	{"email": "m-afanaseva021974@postgrespro.ru", "phone": "+70747751443"}
0005432984500	5ADF21	1200 149393	VIKTOR PAVLOV	{"email": "pavlovv-01031973@postgrespro.ru", "phone": "+70028734234"}
0005432984501	2CE838	3955 015784	SERGEY NIKOLAEV	{"email": "nikolaev-s-1963@postgrespro.ru", "phone": "+70298021699"}
0005432984502	2CE838	3562 498226	RASHID CHERNOV	{"phone": "+70370462287"}
0005432984503	7287A0	0117 439211	KLAVDIYA AFANASEVA	{"email": "afanasevaklavdiya-1969@postgrespro.ru", "phone": "+70905794543"}
0005432984504	0294F1	2749 323532	EKATERINA VLASOVA	{"email": "ekaterina.vlasova.08091976@postgrespro.ru", "phone": "+70757742783"}
0005432984505	0294F1	0206 885949	ANTON DENISOV	{"email": "adenisov1976@postgrespro.ru", "phone": "+70870670979"}
0005432984506	BD7A4B	4432 139882	VALERIY SMIRNOV	{"email": "valeriy.smirnov-1970@postgrespro.ru", "phone": "+70861371316"}
0005432984507	4B6B2B	3605 784161	ELENA ORLOVA	{"phone": "+70767858701"}
0005432984508	C7DB47	1585 679206	MARGARITA IVANOVA	{"email": "ivanova_margarita.051971@postgrespro.ru", "phone": "+70101051213"}
0005432984509	D5E680	7285 915711	ARTEM NIKITIN	{"email": "artem-nikitin1971@postgrespro.ru", "phone": "+70596068468"}
0005432984510	D5E680	4641 848750	PAVEL KAZAKOV	{"email": "kazakov_pavel-11021982@postgrespro.ru", "phone": "+70693927975"}
0005432984511	E7652C	3910 022099	SEMEN CHERNOV	{"email": "chernov-semen_1967@postgrespro.ru", "phone": "+70507888579"}
0005432984512	619B0D	2141 465601	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov14031976@postgrespro.ru", "phone": "+70780565058"}
0005432984513	EFE944	8586 532583	OLEG ZAKHAROV	{"email": "oleg.zakharov_1975@postgrespro.ru", "phone": "+70727210636"}
0005432984514	EFE944	1206 449685	VIKTOR SCHERBAKOV	{"phone": "+70233052043"}
0005432984515	7DD5F3	0031 988959	VALENTINA STEPANOVA	{"email": "stepanovavalentina1979@postgrespro.ru", "phone": "+70056209055"}
0005432984516	D56D54	8793 515293	KRISTINA KOROLEVA	{"email": "k-koroleva.08041968@postgrespro.ru", "phone": "+70451073486"}
0005432984517	D57462	1837 767325	SVETLANA LAZAREVA	{"phone": "+70816997242"}
0005432984518	A53920	6908 492714	KRISTINA PETROVA	{"email": "k.petrova.011975@postgrespro.ru", "phone": "+70121070091"}
0005432984519	FA5DEF	2102 407177	ANNA YAKOVLEVA	{"email": "yakovleva-anna_1972@postgrespro.ru", "phone": "+70217198711"}
0005432984520	C3B18F	3011 974840	NIKOLAY PAVLOV	{"phone": "+70733363935"}
0005432984521	20C4B4	5086 516170	SVETLANA KONDRATEVA	{"email": "skondrateva_1969@postgrespro.ru", "phone": "+70447991751"}
0005432984522	20C4B4	5658 608127	PAVEL ZAKHAROV	{"email": "zakharov-p-101956@postgrespro.ru", "phone": "+70270874550"}
0005432984523	7F2CE5	4197 010518	KIRILL DMITRIEV	{"phone": "+70284603212"}
0005432984524	118DCB	0850 592911	NATALYA VASILEVA	{"email": "natalya-vasileva.02051973@postgrespro.ru", "phone": "+70963868643"}
0005432984525	118DCB	7830 560657	NATALYA MAKAROVA	{"email": "nmakarova.12011968@postgrespro.ru", "phone": "+70791130151"}
0005432984526	6DA20D	4344 957308	VYACHESLAV MOISEEV	{"email": "moiseevvyacheslav-121975@postgrespro.ru", "phone": "+70872640388"}
0005432984527	6DA20D	0214 133930	PAVEL BELOV	{"email": "belov.p.18021969@postgrespro.ru", "phone": "+70880684488"}
0005432984528	9553C0	5462 476163	ALENA SOROKINA	{"phone": "+70615838900"}
0005432984529	D2D151	0581 304896	VLADIMIR DMITRIEV	{"phone": "+70531792924"}
0005432984530	9A07D3	1670 631279	EVGENIY ILIN	{"email": "eilin-29121968@postgrespro.ru", "phone": "+70784045461"}
0005432984531	6D9239	8731 688778	TATYANA NIKITINA	{"phone": "+70153978583"}
0005432984532	882ADF	7164 363175	MARINA NAZAROVA	{"phone": "+70838423674"}
0005432984533	1BB83B	5096 747702	NIKITA KOZLOV	{"email": "kozlov.n_1968@postgrespro.ru", "phone": "+70904313642"}
0005432984534	32E11D	3480 448194	ALEKSEY FEDOTOV	{"email": "aleksey-fedotov-1966@postgrespro.ru", "phone": "+70920982534"}
0005432984535	A43255	1151 192599	OLGA FROLOVA	{"email": "frolova_o_30101970@postgrespro.ru", "phone": "+70018534258"}
0005432984536	A43255	2725 215255	ALEKSEY ALEKSANDROV	{"phone": "+70056478496"}
0005432984537	3BECCD	4933 525497	ANDREY CHERNOV	{"email": "chernov_andrey-021967@postgrespro.ru", "phone": "+70673121914"}
0005432984538	705DBD	2568 065582	EVDOKIYA BELOVA	{"phone": "+70986685893"}
0005432984539	6A702F	3901 183894	SERGEY FOMIN	{"email": "sergey-fomin_1973@postgrespro.ru", "phone": "+70352200176"}
0005432984540	4B45E7	9890 760192	ALEKSANDR KARPOV	{"email": "karpova1955@postgrespro.ru", "phone": "+70513346851"}
0005432984541	DFA631	7517 721428	VALENTINA BELOVA	{"email": "vbelova-1960@postgrespro.ru", "phone": "+70330769018"}
0005432984542	245645	5161 054707	YURIY FOMIN	{"email": "fomin-y-011973@postgrespro.ru", "phone": "+70069801716"}
0005432984543	245645	5751 335235	NADEZHDA ANTONOVA	{"email": "n_antonova.1971@postgrespro.ru", "phone": "+70587717821"}
0005432984544	E1FD3D	9003 507741	ILNUR POPOV	{"phone": "+70990862422"}
0005432984545	9D613D	1864 137769	VADIM ANTONOV	{"email": "vadim.antonov.041977@postgrespro.ru", "phone": "+70084179181"}
0005432984546	9D613D	4993 341718	NIKITA MOISEEV	{"phone": "+70532321581"}
0005432984547	79EDF7	2658 201826	LIDIYA ZAKHAROVA	{"phone": "+70479606690"}
0005432984548	79EDF7	1468 992005	SERGEY YAKOVLEV	{"phone": "+70365482339"}
0005432984549	0C0D1F	5518 451507	PETR KULIKOV	{"phone": "+70956876968"}
0005432984550	8AE566	8252 237040	VIKTORIYA NOVIKOVA	{"email": "viktoriya-novikova23051972@postgrespro.ru", "phone": "+70154696423"}
0005432984551	8AE566	0811 674037	NAILYA NAZAROVA	{"email": "nazarova_nailya-1973@postgrespro.ru", "phone": "+70227326523"}
0005432984552	10A939	5908 865096	VLADIMIR CHERNOV	{"email": "v_chernov-1975@postgrespro.ru", "phone": "+70129450168"}
0005432984553	B8628A	0474 243442	VLADIMIR DAVYDOV	{"email": "vladimir_davydov-17041981@postgrespro.ru", "phone": "+70488813481"}
0005432984554	C2422A	2060 395475	ELENA FOMINA	{"email": "fominaelena.121974@postgrespro.ru", "phone": "+70445175111"}
0005432984555	B7BF0B	1871 361527	ALEKSANDR KRASNOV	{"email": "a-krasnov_1972@postgrespro.ru", "phone": "+70313958033"}
0005432984556	B7BF0B	6434 045947	RAISA FILATOVA	{"email": "r_filatova28061982@postgrespro.ru", "phone": "+70836396047"}
0005432984557	5CA43F	4068 304728	VITALIY NAZAROV	{"email": "v-nazarov1983@postgrespro.ru", "phone": "+70358675339"}
0005432984558	7EF28B	3980 168657	TATYANA FILIPPOVA	{"phone": "+70411912476"}
0005432984559	950957	1474 322809	SERGEY POPOV	{"email": "sergey-popov.16021983@postgrespro.ru", "phone": "+70877965630"}
0005432984560	419E52	0234 120303	VALENTINA RYABOVA	{"email": "v_ryabova_021967@postgrespro.ru", "phone": "+70668518633"}
0005432984561	B00386	6577 401857	NADEZHDA ABRAMOVA	{"email": "abramovanadezhda081981@postgrespro.ru", "phone": "+70255902233"}
0005432984562	4AC572	0956 093666	VIKTORIYA RODIONOVA	{"email": "rodionova-viktoriya_1958@postgrespro.ru", "phone": "+70078797847"}
0005432984563	DDF789	2835 962392	ALEKSANDR PETROV	{"phone": "+70356256998"}
0005432984564	6E49C2	1193 515224	NATALYA YUDINA	{"email": "yudina.n-081968@postgrespro.ru", "phone": "+70630489971"}
0005432984565	F7FD8C	2908 711481	GALINA AFANASEVA	{"email": "g.afanaseva.17101972@postgrespro.ru", "phone": "+70824002402"}
0005432984566	4F01DC	0711 331423	MARIYA KONDRATEVA	{"email": "m.kondrateva-1976@postgrespro.ru", "phone": "+70212353224"}
0005432984567	2158D8	0670 369329	VIKTOR BORISOV	{"phone": "+70073321220"}
0005432984568	B3C0CB	5459 556850	IVAN FILIPPOV	{"phone": "+70324546708"}
0005432984569	5717CC	8728 499493	IVAN ROMANOV	{"phone": "+70464876888"}
0005432984570	5717CC	0576 977014	SVETLANA ZHURAVLEVA	{"phone": "+70697508587"}
0005432984571	F02173	0796 840334	IGOR FEDOROV	{"email": "fedorov.igor.041963@postgrespro.ru", "phone": "+70296450064"}
0005432984572	D692C1	4790 192402	ALEKSANDR KULIKOV	{"email": "kulikov-a.07121973@postgrespro.ru", "phone": "+70873304696"}
0005432984573	F26C41	6732 542103	NIKOLAY ZAKHAROV	{"phone": "+70347576429"}
0005432984574	BF6A81	0892 836375	EVGENIY VLASOV	{"phone": "+70521577707"}
0005432984575	4699BE	7975 964870	NINA ERMAKOVA	{"phone": "+70102459856"}
0005432984576	4309FD	4535 868624	OLGA ROMANOVA	{"phone": "+70192048389"}
0005432984577	4309FD	9478 021378	EVGENIY EGOROV	{"phone": "+70930507013"}
0005432984578	4309FD	2661 968482	VITALIY MAKSIMOV	{"phone": "+70140277184"}
0005432984579	B6B744	3950 013445	TATYANA NAZAROVA	{"email": "tatyana_nazarova09071963@postgrespro.ru", "phone": "+70264335740"}
0005432984580	1E86D1	5657 104810	ALEKSEY MIRONOV	{"phone": "+70209176187"}
0005432984581	ADAA0C	3971 075224	YULIYA KAZAKOVA	{"email": "kazakova.yuliya_14041975@postgrespro.ru", "phone": "+70544342001"}
0005432984582	5AB33D	4016 330994	VASILIY KUZMIN	{"email": "kuzminvasiliy_051964@postgrespro.ru", "phone": "+70960351116"}
0005432984583	E4BBB6	4492 711223	SERGEY MARTYNOV	{"email": "s_martynov.30051970@postgrespro.ru", "phone": "+70313620355"}
0005432984584	E4BBB6	6948 569636	MARIYA SERGEEVA	{"phone": "+70165643994"}
0005432984585	067325	6914 013454	LYUDMILA VASILEVA	{"phone": "+70994526768"}
0005432984586	6BF5B2	4307 866657	EMIL DMITRIEV	{"email": "dmitriev-e.1973@postgrespro.ru", "phone": "+70476429606"}
0005432984587	921A09	1053 293388	NADEZHDA ZOTOVA	{"email": "nzotova_1987@postgrespro.ru", "phone": "+70843185152"}
0005432984588	A1BF4D	6177 013581	ANNA AFANASEVA	{"phone": "+70410638555"}
0005432984589	450631	6319 201767	LARISA KOZLOVA	{"phone": "+70883376591"}
0005432984590	C6903B	8292 337298	ALEKSANDR GUSEV	{"email": "gusev.a_071963@postgrespro.ru", "phone": "+70145234665"}
0005432984591	4B22D7	2206 273676	BORIS FILIPPOV	{"email": "filippov-b-021977@postgrespro.ru", "phone": "+70938923346"}
0005432984592	DF8591	5203 767014	TATYANA MOROZOVA	{"phone": "+70750399192"}
0005432984593	DF8591	8163 860677	VASILIY KUZNECOV	{"phone": "+70158612242"}
0005432984594	74AB1A	4310 065468	YULIYA SEMENOVA	{"phone": "+70788285379"}
0005432984595	74AB1A	0131 584242	VERONIKA RODIONOVA	{"phone": "+70265992177"}
0005432984596	6C8CA1	5303 374518	ARTEM SMIRNOV	{"phone": "+70410636951"}
0005432984597	6C8CA1	4366 819722	ANATOLIY NIKITIN	{"phone": "+70381844046"}
0005432984598	6C8CA1	8381 996208	ALEKSANDR VOROBEV	{"phone": "+70981842606"}
0005432984599	07C1AA	6328 482638	IRINA CHERNOVA	{"email": "chernova.irina-23111970@postgrespro.ru", "phone": "+70950858118"}
0005432984600	5E56FF	8106 378289	VALENTINA SERGEEVA	{"phone": "+70644345323"}
0005432984601	5E56FF	6793 592289	SERGEY KAZAKOV	{"email": "kazakov.s.12031977@postgrespro.ru", "phone": "+70300103887"}
0005432984602	165EFB	0047 435318	ALEKSANDR MATVEEV	{"phone": "+70042173151"}
0005432984603	0BDB44	8162 284046	NINA FILIPPOVA	{"email": "n.filippova.061969@postgrespro.ru", "phone": "+70745154973"}
0005432984604	D91E80	7150 594708	SERGEY IVANOV	{"email": "ivanov_sergey.1976@postgrespro.ru", "phone": "+70750976087"}
0005432984605	F11565	5993 933624	MARIYA GAVRILOVA	{"phone": "+70534217091"}
0005432984606	F11565	3123 533962	YULIYA MAKSIMOVA	{"phone": "+70551094733"}
0005432984607	1F88DE	0315 174540	NADEZHDA KUDRYASHOVA	{"phone": "+70106618020"}
0005432984608	73A0E4	3522 335114	MARIYA POPOVA	{"phone": "+70731258113"}
0005432984609	73A0E4	4813 883812	SERGEY KUZNECOV	{"phone": "+70011638483"}
0005432984610	6965E0	6209 510797	OLGA ILINA	{"email": "o_ilina.1971@postgrespro.ru", "phone": "+70668997085"}
0005432984611	44AECA	5732 437215	ALEKSANDRA NESTEROVA	{"email": "nesterova-aleksandra-02031987@postgrespro.ru", "phone": "+70536675428"}
0005432984612	5945B4	5000 750719	DENIS NIKITIN	{"email": "denis_nikitin.061971@postgrespro.ru", "phone": "+70129204506"}
0005432984613	F14C0B	1857 551794	RAFAEL SIDOROV	{"phone": "+70975615371"}
0005432984614	2AA691	9020 406686	NATALYA MIKHAYLOVA	{"email": "mikhaylovanatalya.041974@postgrespro.ru", "phone": "+70804734237"}
0005432984615	E7B748	6769 718309	DMITRIY STEPANOV	{"email": "stepanov_dmitriy.14041968@postgrespro.ru", "phone": "+70204259711"}
0005432984616	E7B748	9532 543046	DANIIL CHERNOV	{"phone": "+70649092780"}
0005432984617	2A62FF	2355 052477	ELENA NOVIKOVA	{"phone": "+70109609947"}
0005432984618	7DACAB	8749 371812	LYUDMILA IVANOVA	{"phone": "+70417966094"}
0005432984619	FDC42C	4127 156628	YURIY SOROKIN	{"email": "y_sorokin_1977@postgrespro.ru", "phone": "+70201212668"}
0005432984620	FDC42C	3660 180220	SERGEY ZHUKOV	{"email": "zhukovsergey.1963@postgrespro.ru", "phone": "+70167660363"}
0005432984621	FB93EA	2973 284139	ELENA NESTEROVA	{"phone": "+70870816127"}
0005432984622	4DD7DF	5047 508594	ANNA LUKYANOVA	{"phone": "+70322916910"}
0005432984623	C136E7	4397 769444	TIMUR KARPOV	{"email": "karpov.t.1975@postgrespro.ru", "phone": "+70897494121"}
0005432984624	40019A	5974 774325	ELIZAVETA CHERNOVA	{"phone": "+70618166674"}
0005432984625	40019A	7155 986474	ARTEM NIKITIN	{"email": "nikitin_artem27111968@postgrespro.ru", "phone": "+70240825622"}
0005432984626	40019A	7418 628096	DINA KUDRYASHOVA	{"phone": "+70582182258"}
0005432984627	6603BA	1203 187109	ELENA TITOVA	{"email": "elena-titova.27051975@postgrespro.ru", "phone": "+70556477672"}
0005432984628	9CB71A	0000 446510	TATYANA DMITRIEVA	{"phone": "+70948041798"}
0005432984629	C18C41	9054 661145	ELENA STEPANOVA	{"phone": "+70451897687"}
0005432984630	72CDF3	2224 261766	GALINA VOLKOVA	{"email": "volkova_g_10081983@postgrespro.ru", "phone": "+70836089534"}
0005432984631	3FE0DC	9282 653863	MAKSIM SCHERBAKOV	{"phone": "+70994079199"}
0005432984632	DE6362	6063 301306	VALENTINA IVANOVA	{"email": "v_ivanova23091972@postgrespro.ru", "phone": "+70521350316"}
0005432984633	6632EE	2587 914320	NATALYA ZHUKOVA	{"email": "natalyazhukova.1972@postgrespro.ru", "phone": "+70508711715"}
0005432984634	E74FB1	9270 305623	NATALIYA KUZMINA	{"phone": "+70781341150"}
0005432984635	25E2E9	0047 743519	EKATERINA NESTEROVA	{"email": "ekaterina.nesterova_061973@postgrespro.ru", "phone": "+70476546060"}
0005432984636	28AFC9	6035 460596	OLGA NIKOLAEVA	{"email": "olganikolaeva1971@postgrespro.ru", "phone": "+70325464527"}
0005432984637	E477D9	2626 219412	EKATERINA VOROBEVA	{"phone": "+70216476924"}
0005432984638	DC6067	8623 876669	EVGENIY SIDOROV	{"phone": "+70712600627"}
0005432984639	33C067	4935 446969	PAVEL BORISOV	{"phone": "+70111968958"}
0005432984640	33C067	4134 423932	ALEKSANDR SEMENOV	{"phone": "+70161814746"}
0005432984641	DAD914	1526 918542	ALEKSEY PETROV	{"email": "apetrov.041966@postgrespro.ru", "phone": "+70054183570"}
0005432984642	EB0BC4	7294 254393	IRINA ILINA	{"phone": "+70471461880"}
0005432984643	E0B8A5	2015 228025	ELENA ZAKHAROVA	{"phone": "+70690450688"}
0005432984644	E0B8A5	8054 964037	OKSANA BARANOVA	{"phone": "+70464941166"}
0005432984645	F11211	9276 566117	NATALYA VOLKOVA	{"phone": "+70832627661"}
0005432984646	34A9CD	0150 973940	OLEG IVANOV	{"phone": "+70770230139"}
0005432984647	BE038A	8088 543501	ALEKSANDR KULIKOV	{"phone": "+70734041707"}
0005432984648	EF58B5	2849 203294	MARIYA KONDRATEVA	{"phone": "+70274145246"}
0005432984649	C8D3C9	7943 549300	ANDREY FEDOTOV	{"email": "fedotov_andrey_1966@postgrespro.ru", "phone": "+70488456549"}
0005432984650	67FAF3	2748 856819	ALEKSANDR IVANOV	{"email": "aivanov_1962@postgrespro.ru", "phone": "+70449239253"}
0005432984651	C1D408	7314 712555	DENIS PETROV	{"phone": "+70917345205"}
0005432984652	0B253D	0871 685053	LARISA ZAYCEVA	{"phone": "+70828939803"}
0005432984653	0B253D	5590 701044	ALEKSANDR VASILEV	{"email": "a_vasilev_15101974@postgrespro.ru", "phone": "+70829394770"}
0005432984654	3EE112	8114 250404	TATYANA ZAYCEVA	{"phone": "+70661047402"}
0005432984655	14F727	7851 721935	VIKTOR YAKOVLEV	{"email": "viktor.yakovlev1964@postgrespro.ru", "phone": "+70732208208"}
0005432984656	2524CB	2373 570581	ALEKSEY SEMENOV	{"phone": "+70343858599"}
0005432984657	28A3D9	8268 983308	GALINA MIRONOVA	{"email": "mironova-galina.1976@postgrespro.ru", "phone": "+70373342245"}
0005432984658	7E1C9B	8777 068142	VYACHESLAV VASILEV	{"email": "vasilevv_1979@postgrespro.ru", "phone": "+70230685421"}
0005432984659	FF3758	6653 541283	TATYANA ABRAMOVA	{"email": "abramovat-1958@postgrespro.ru", "phone": "+70713303555"}
0005432984660	653634	1253 210034	NINA MASLOVA	{"email": "maslova_nina.1973@postgrespro.ru", "phone": "+70336955153"}
0005432984661	653634	8715 441188	YULIYA DENISOVA	{"email": "denisova-yuliya-031975@postgrespro.ru", "phone": "+70771050593"}
0005432984662	53433F	8575 443401	VALENTINA GRISHINA	{"phone": "+70310869894"}
0005432984663	53433F	0076 341894	NATALYA GORBUNOVA	{"phone": "+70899660339"}
0005432984664	E07EF2	5008 546447	ANASTASIYA MELNIKOVA	{"phone": "+70106056735"}
0005432984665	F4835D	0223 951454	ALEKSEY ROMANOV	{"phone": "+70655430307"}
0005432984666	F4835D	3450 287489	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir-06091957@postgrespro.ru", "phone": "+70938038587"}
0005432984667	6B13B7	7831 783927	VIKTORIYA NAZAROVA	{"phone": "+70217278614"}
0005432984668	6B13B7	4958 085405	VALERIY TARASOV	{"phone": "+70127566744"}
0005432984669	14F179	0529 482615	OLGA GERASIMOVA	{"email": "gerasimova.olga-08011970@postgrespro.ru", "phone": "+70703069262"}
0005432984670	14F179	7527 163421	PETR KULIKOV	{"email": "kulikov.petr-051963@postgrespro.ru", "phone": "+70205187333"}
0005432984671	CB6DCF	7614 617154	ALEKSEY GUSEV	{"email": "agusev-28101981@postgrespro.ru", "phone": "+70287423275"}
0005432984672	6497BD	8530 420609	SERGEY KUZMIN	{"phone": "+70515639254"}
0005432984673	3ADA40	8623 463747	EKATERINA ORLOVA	{"email": "orlova-e1973@postgrespro.ru", "phone": "+70488922170"}
0005432984674	465630	6969 678776	ALEKSANDR KISELEV	{"phone": "+70674398204"}
0005432984675	8A904E	6972 866226	ARTEM FEDOROV	{"email": "fedorovartem_31051967@postgrespro.ru", "phone": "+70523768249"}
0005432984676	D1A5E6	6005 636536	ALEKSANDR BORISOV	{"phone": "+70427715789"}
0005432984677	C949D0	9598 943588	VERA KUZMINA	{"email": "kuzmina_vera061979@postgrespro.ru", "phone": "+70321063873"}
0005432984678	8BC3CC	0340 374018	IRINA KOROLEVA	{"email": "irina-koroleva-02031966@postgrespro.ru", "phone": "+70472190911"}
0005432984679	8BC3CC	7303 446274	VIKTOR FEDOROV	{"email": "fedorov.v.121979@postgrespro.ru", "phone": "+70488328839"}
0005432984680	8BC3CC	5684 385651	EVGENIY TIKHONOV	{"phone": "+70350096606"}
0005432984681	70E8BE	7020 378690	IRINA KISELEVA	{"email": "irina-kiseleva.121973@postgrespro.ru", "phone": "+70610216099"}
0005432984682	3FB8D3	9612 096186	LYUDMILA ZHUKOVA	{"phone": "+70096029980"}
0005432984683	3FB8D3	9107 708303	ELENA EGOROVA	{"phone": "+70526003410"}
0005432984684	3FB8D3	5645 156211	TATYANA BORISOVA	{"phone": "+70793081714"}
0005432984685	D4598F	4509 006865	ALEKSANDR VASILEV	{"phone": "+70040676583"}
0005432984686	1BAC54	7969 355900	ALEKSEY SAVELEV	{"phone": "+70442594109"}
0005432984687	1BAC54	2622 290972	ALEKSANDR RODIONOV	{"phone": "+70925525349"}
0005432984688	F650D3	1223 630167	ANASTASIYA POTAPOVA	{"phone": "+70468545971"}
0005432984689	3333A2	0428 398759	GALINA ROMANOVA	{"email": "galina_romanova06011970@postgrespro.ru", "phone": "+70434333542"}
0005432984690	3333A2	5846 054876	ALENA YAKOVLEVA	{"email": "a.yakovleva-08051967@postgrespro.ru", "phone": "+70657107740"}
0005432984691	3333A2	3322 123069	MARIYA PETROVA	{"email": "m.petrova1969@postgrespro.ru", "phone": "+70080123931"}
0005432984692	B20C8B	3540 422595	FATYMA MIKHAYLOVA	{"phone": "+70836576589"}
0005432984693	CDA53A	2077 778305	NADEZHDA KUZNECOVA	{"email": "nadezhdakuznecova081970@postgrespro.ru", "phone": "+70388472118"}
0005432984694	EFC023	3308 206136	ALEKSANDR VASILEV	{"phone": "+70887241846"}
0005432984695	5F0743	2342 534758	ALLA SEMENOVA	{"email": "semenovaa-041973@postgrespro.ru", "phone": "+70583295608"}
0005432984696	5F0743	7536 377944	MARINA SEMENOVA	{"phone": "+70531166422"}
0005432984697	5F0743	6825 808051	DENIS MIKHAYLOV	{"email": "mikhaylov-d_1974@postgrespro.ru", "phone": "+70017164583"}
0005432984698	CE37A6	1415 633460	ALEKSANDR TARASOV	{"phone": "+70250208685"}
0005432984699	113583	0365 192529	OLGA ERMAKOVA	{"email": "o.ermakova101971@postgrespro.ru", "phone": "+70474095518"}
0005432984700	113583	5261 617388	MAKSIM FEDOROV	{"email": "fedorov-m-01091958@postgrespro.ru", "phone": "+70220747288"}
0005432984701	FB302D	4624 702829	MARINA ZHUKOVA	{"phone": "+70613678008"}
0005432984702	87140A	9840 651307	SVETLANA SMIRNOVA	{"email": "smirnovasvetlana051979@postgrespro.ru", "phone": "+70573107487"}
0005432984703	AB3FDF	5506 950289	VALENTINA KUZNECOVA	{"phone": "+70580151853"}
0005432984704	AB3FDF	3720 960360	ELVIRA ALEKSANDROVA	{"email": "aleksandrova.elvira_11111969@postgrespro.ru", "phone": "+70736986081"}
0005432984705	7420D5	8114 366295	ELENA OVCHINNIKOVA	{"email": "ovchinnikovaelena.011976@postgrespro.ru", "phone": "+70118705666"}
0005432984706	972032	3147 695860	LYUDMILA ALEKSEEVA	{"email": "alekseevalyudmila07121964@postgrespro.ru", "phone": "+70322853312"}
0005432984707	972032	7250 529874	KONSTANTIN VASILEV	{"phone": "+70712557359"}
0005432984708	D300A7	1390 531654	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr.31031976@postgrespro.ru", "phone": "+70460806534"}
0005432984709	D300A7	1080 952943	TATYANA BOGDANOVA	{"email": "bogdanova.t-1979@postgrespro.ru", "phone": "+70309122420"}
0005432984710	61C094	5030 708886	EVDOKIYA IVANOVA	{"email": "eivanova1974@postgrespro.ru", "phone": "+70082050410"}
0005432984711	7BEADF	5438 687184	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov28101970@postgrespro.ru", "phone": "+70630832732"}
0005432984712	7BEADF	2609 174432	VLADISLAV POPOV	{"email": "vladislav_popov10071969@postgrespro.ru", "phone": "+70551302312"}
0005432984713	A60D25	8044 994402	ZLATA SOROKINA	{"email": "zlata-sorokina-021976@postgrespro.ru", "phone": "+70990675146"}
0005432984714	8D517C	3847 911802	VLADISLAV KONOVALOV	{"phone": "+70657213956"}
0005432984715	8D517C	5822 839409	VIKTOR ALEKSEEV	{"email": "valekseev-121970@postgrespro.ru", "phone": "+70524470269"}
0005432984716	D4AF17	4011 850648	ALEKSANDR KULIKOV	{"phone": "+70102252582"}
0005432984717	D28C7B	4958 862290	ELMIRA KAZAKOVA	{"email": "kazakovaelmira.1956@postgrespro.ru", "phone": "+70015858614"}
0005432984718	D28C7B	7836 275646	ALEKSANDR PETROV	{"email": "petrov_aleksandr-1982@postgrespro.ru", "phone": "+70956533827"}
0005432984719	D28C7B	0497 782546	ALEKSANDR MARTYNOV	{"phone": "+70390532377"}
0005432984720	C2FA2B	9800 035023	MIKHAIL ALEKSANDROV	{"email": "aleksandrovmikhail.071964@postgrespro.ru", "phone": "+70152136830"}
0005432984721	95ABA2	6242 279019	NINA ANISIMOVA	{"email": "n-anisimova-22091979@postgrespro.ru", "phone": "+70748306269"}
0005432984722	4CAC5B	0205 526108	VENERA SEMENOVA	{"phone": "+70541937009"}
0005432984723	BFAFA6	5440 105387	GALINA DENISOVA	{"email": "denisova.galina1963@postgrespro.ru", "phone": "+70877671858"}
0005432984724	938BB8	9592 724591	ALEKSEY NIKITIN	{"phone": "+70251249438"}
0005432984725	938BB8	9562 637030	NATALYA SEMENOVA	{"email": "semenova_natalya_081987@postgrespro.ru", "phone": "+70589801978"}
0005432984726	80A643	8803 409982	IRINA IVANOVA	{"email": "irina-ivanova-1962@postgrespro.ru", "phone": "+70605146474"}
0005432984727	3BB4AA	9764 416785	SERGEY IVANOV	{"email": "ivanovs.091966@postgrespro.ru", "phone": "+70464450308"}
0005432984728	EEE7A3	7864 514919	NIKOLAY ABRAMOV	{"email": "abramov-n_20051959@postgrespro.ru", "phone": "+70632882406"}
0005432984729	2597D8	2227 222563	VALENTIN FEDOROV	{"phone": "+70301926700"}
0005432984730	169C6A	4946 969098	SERGEY MAKAROV	{"phone": "+70680844368"}
0005432984731	62EA69	1023 217442	ELIZAVETA ILINA	{"phone": "+70799855087"}
0005432984732	4E60C7	6248 740991	VALERIY OSIPOV	{"email": "v-osipov_011975@postgrespro.ru", "phone": "+70955972009"}
0005432984733	4E60C7	1910 090183	MARIYA NESTEROVA	{"email": "m.nesterova.011980@postgrespro.ru", "phone": "+70054352708"}
0005432984734	E16281	4658 230229	MARIANNA VASILEVA	{"phone": "+70609632185"}
0005432984735	066F86	8996 251591	ELENA FROLOVA	{"phone": "+70865991286"}
0005432984736	C7DF82	6590 383471	ANTONINA POPOVA	{"phone": "+70288168163"}
0005432984737	07F8D7	7615 470415	PRASKOVYA MIRONOVA	{"phone": "+70427402550"}
0005432984738	77EA23	1788 605416	DARYA AKIMOVA	{"phone": "+70294297657"}
0005432984739	77EA23	6687 141485	LYUBOV VLASOVA	{"phone": "+70070261155"}
0005432984740	50F815	9906 450745	NADEZHDA SCHERBAKOVA	{"phone": "+70688690696"}
0005432984741	EE51FC	7910 812144	GENNADIY MIRONOV	{"phone": "+70635177259"}
0005432984742	7006DE	3107 836833	IVAN ISAEV	{"phone": "+70650805254"}
0005432984743	2CE56D	1781 991353	VLADIMIR ANDREEV	{"email": "v.andreev_1973@postgrespro.ru", "phone": "+70657660122"}
0005432984744	EA7186	3598 868879	VLADIMIR ABRAMOV	{"phone": "+70239273154"}
0005432984745	61A39A	4013 538160	OLGA KOROLEVA	{"email": "koroleva.o.011968@postgrespro.ru", "phone": "+70753648429"}
0005432984746	EB2EF9	0814 412048	NIKOLAY VASILEV	{"email": "vasilev.nikolay_02021971@postgrespro.ru", "phone": "+70489426977"}
0005432984747	BE8C42	3698 654278	LEV VOROBEV	{"email": "vorobev_lev08121967@postgrespro.ru", "phone": "+70461764749"}
0005432984748	BE8C42	1232 340704	GALINA NESTEROVA	{"phone": "+70251037289"}
0005432984749	A0F99D	6073 363716	DARYA ANDREEVA	{"phone": "+70439287407"}
0005432984750	1BA830	1633 862867	LARISA MAKAROVA	{"phone": "+70311531091"}
0005432984751	CBE27F	8783 326722	SERGEY ALEKSEEV	{"email": "alekseev.s_061969@postgrespro.ru", "phone": "+70819731016"}
0005432984752	CBE27F	6107 705176	LYUDMILA GUSEVA	{"phone": "+70226913769"}
0005432984753	D73E83	1642 864100	IRINA MAKAROVA	{"email": "makarova.i_1965@postgrespro.ru", "phone": "+70153384770"}
0005432984754	D73E83	2306 021613	GENNADIY KUZMIN	{"phone": "+70628014760"}
0005432984755	DA3084	9728 027001	LARISA KUZNECOVA	{"phone": "+70957397883"}
0005432984756	661C8E	7230 097202	RAIL MOISEEV	{"email": "moiseevrail_1965@postgrespro.ru", "phone": "+70937249263"}
0005432984757	661C8E	2130 069688	ALEKSANDR IVANOV	{"phone": "+70025950072"}
0005432984758	F22721	2389 725178	KIRILL SCHERBAKOV	{"phone": "+70979942847"}
0005432984759	CBAD4C	0549 289673	TIMOFEY ANDREEV	{"phone": "+70411020820"}
0005432984760	9B0ACF	1448 785576	LYUBOV BELYAEVA	{"email": "belyaeva.l.071968@postgrespro.ru", "phone": "+70804814809"}
0005432984761	1BB8A8	4702 635166	PAVEL ANTONOV	{"email": "antonov_pavel-1961@postgrespro.ru", "phone": "+70343847908"}
0005432984762	1BB8A8	4528 888799	ALEKSEY IVANOV	{"phone": "+70744998734"}
0005432984763	82E197	6237 897746	IVAN KUZNECOV	{"phone": "+70966570276"}
0005432984764	82E197	4234 071164	EVGENIY IVANOV	{"phone": "+70475955500"}
0005432984765	C97958	4017 630660	OKSANA OSIPOVA	{"email": "oksana.osipova.1968@postgrespro.ru", "phone": "+70355259463"}
0005432984766	4C3B1B	2972 727034	NADEZHDA MOROZOVA	{"phone": "+70743094476"}
0005432984767	4C3B1B	2196 054037	ALEKSANDR GERASIMOV	{"phone": "+70586820308"}
0005432984768	4C3B1B	6166 060681	ALLA LOGINOVA	{"phone": "+70779179207"}
0005432984769	3B08B1	9889 860654	DANIL SMIRNOV	{"email": "d_smirnov24081972@postgrespro.ru", "phone": "+70567965682"}
0005432984770	3B08B1	6874 747927	ALLA ISAEVA	{"email": "alla_isaeva.10091975@postgrespro.ru", "phone": "+70297857403"}
0005432984771	F8B67C	0084 496217	RISHAT KISELEV	{"phone": "+70505785243"}
0005432984772	A99DDD	1311 264489	VIKTORIYA PETROVA	{"email": "petrova-viktoriya04111963@postgrespro.ru", "phone": "+70880795414"}
0005432984773	540939	3321 237375	DMITRIY ISAEV	{"email": "d.isaev081979@postgrespro.ru", "phone": "+70408331663"}
0005432984774	3CA838	3701 555269	RINAT GORBUNOV	{"email": "r.gorbunov.16021962@postgrespro.ru", "phone": "+70429462522"}
0005432984775	3CA838	8093 382789	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_1976@postgrespro.ru", "phone": "+70053266374"}
0005432984776	C98ACE	9554 224464	MATVEY NAUMOV	{"phone": "+70854878186"}
0005432984777	D5612D	9905 271054	MARIYA KUZNECOVA	{"email": "kuznecova.mariya.1962@postgrespro.ru", "phone": "+70945838636"}
0005432984778	D5612D	1974 244677	DANILA TIKHONOV	{"phone": "+70750950351"}
0005432984779	A11A59	3528 185003	EVGENIYA ORLOVA	{"phone": "+70154572611"}
0005432984780	A11A59	2355 092850	PAVEL DMITRIEV	{"phone": "+70046567227"}
0005432984781	67D331	4090 276859	EDUARD KULIKOV	{"email": "kulikove_071966@postgrespro.ru", "phone": "+70078292690"}
0005432984782	67D331	1482 058900	ILONA TITOVA	{"phone": "+70412998255"}
0005432984783	67D331	4219 933083	NATALYA LAZAREVA	{"phone": "+70191634621"}
0005432984784	53F665	9881 500799	POLINA VLASOVA	{"phone": "+70136045160"}
0005432984785	8C4214	4619 281499	ANTONINA GRISHINA	{"email": "antonina_grishina23051972@postgrespro.ru", "phone": "+70136311398"}
0005432984786	EFBED7	4273 078875	ANATOLIY ANTONOV	{"phone": "+70011426170"}
0005432984787	9AD6C4	8738 287361	ALEKSEY VOLKOV	{"phone": "+70175808276"}
0005432984788	F5AF69	8279 146732	EGOR ALEKSEEV	{"email": "ealekseev-1976@postgrespro.ru", "phone": "+70539140373"}
0005432984789	D79538	5735 953927	VALENTINA VASILEVA	{"email": "vvasileva_1974@postgrespro.ru", "phone": "+70236277772"}
0005432984790	72A075	4264 732444	VIKTORIYA TARASOVA	{"phone": "+70907431350"}
0005432984791	72A075	9188 769991	DMITRIY SEMENOV	{"phone": "+70750787285"}
0005432984792	18C723	7868 330779	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov-13021969@postgrespro.ru", "phone": "+70245155704"}
0005432984793	18C723	6911 497690	VLADIMIR STEPANOV	{"phone": "+70681253876"}
0005432984794	326F98	0256 091340	VALERIY MARTYNOV	{"phone": "+70641643075"}
0005432984795	70EB97	5043 374161	NATALYA STEPANOVA	{"email": "natalya_stepanova021958@postgrespro.ru", "phone": "+70514219999"}
0005432984796	D199AE	7793 264230	ALEKSEY ZAYCEV	{"email": "zaycev.a.29071972@postgrespro.ru", "phone": "+70421483696"}
0005432984797	923019	0036 508126	DARYA ZAYCEVA	{"phone": "+70007688298"}
0005432984798	923019	4417 112199	VLADIMIR OSIPOV	{"email": "osipovv.081971@postgrespro.ru", "phone": "+70437874191"}
0005432984799	1A6958	1852 062904	SERGEY DAVYDOV	{"phone": "+70720556653"}
0005432984800	1A6958	6375 114231	NATALYA CHERNOVA	{"email": "chernova-natalya.081973@postgrespro.ru", "phone": "+70222082194"}
0005432984801	88925C	8799 135262	EMILIYA NIKIFOROVA	{"phone": "+70767320378"}
0005432984802	4D7807	8580 160483	ARTEM BARANOV	{"email": "baranovartem.051972@postgrespro.ru", "phone": "+70583275945"}
0005432984803	F30EF9	9956 006891	ELENA ZOTOVA	{"email": "zotovaelena.16011975@postgrespro.ru", "phone": "+70790904207"}
0005432984804	F30EF9	5563 976136	LIDIYA GUSEVA	{"email": "gusevalidiya.1963@postgrespro.ru", "phone": "+70421682826"}
0005432984805	9D7B52	3398 936772	DENIS FILIPPOV	{"email": "filippov_denis-04091969@postgrespro.ru", "phone": "+70832468258"}
0005432984806	9D7B52	1869 242120	SERGEY ALEKSEEV	{"phone": "+70941802238"}
0005432984807	DC2A4C	8834 590067	VLADIMIR FROLOV	{"email": "vladimir_frolov-1973@postgrespro.ru", "phone": "+70256233450"}
0005432984808	F21DE4	1219 190855	VASILIY NOVIKOV	{"phone": "+70485383439"}
0005432984809	F21DE4	7634 842349	SERGEY DAVYDOV	{"phone": "+70929010950"}
0005432984810	F21DE4	3795 206420	TAMARA NIKITINA	{"phone": "+70874486606"}
0005432984811	9CA20C	6949 773231	VLADIMIR SOROKIN	{"phone": "+70408929217"}
0005432984812	9CA20C	0851 006945	VIKTORIYA SOLOVEVA	{"phone": "+70319723978"}
0005432984813	1E316B	4018 914880	SERGEY SAVELEV	{"email": "savelev-s05111965@postgrespro.ru", "phone": "+70102398483"}
0005432984814	1E316B	5883 617062	LYUBOV KONOVALOVA	{"email": "konovaloval-1966@postgrespro.ru", "phone": "+70377726182"}
0005432984815	0E1F00	6089 305505	DMITRIY KUZMIN	{"email": "dmitriy-kuzmin.101973@postgrespro.ru", "phone": "+70970141231"}
0005432984816	0E1F00	2236 662456	MIKHAIL NIKITIN	{"email": "nikitin.m.101972@postgrespro.ru", "phone": "+70570245684"}
0005432984817	9C4AE0	8312 819090	VLADIMIR ZAYCEV	{"email": "vzaycev.01101963@postgrespro.ru", "phone": "+70804107307"}
0005432984818	6609FB	5121 949412	ALIYA MIRONOVA	{"email": "mironova_a.1969@postgrespro.ru", "phone": "+70726176579"}
0005432984819	6609FB	9362 583609	ANISA NAZAROVA	{"phone": "+70758016123"}
0005432984820	C00A5A	1154 338037	ELENA ARKHIPOVA	{"phone": "+70211312487"}
0005432984821	B11D1C	8884 111169	RUSLAN NAUMOV	{"phone": "+70072124886"}
0005432984822	E365E6	1262 013891	VLADIMIR ILIN	{"phone": "+70075483839"}
0005432984823	325DC2	1227 381257	VERONIKA IVANOVA	{"email": "veronika.ivanova_01021978@postgrespro.ru", "phone": "+70262977899"}
0005432984824	710BA8	5991 692306	MARIYA ISAEVA	{"phone": "+70141706342"}
0005432984825	45AE44	8759 878400	NIKOLAY EGOROV	{"email": "egorov_nikolay-1971@postgrespro.ru", "phone": "+70888487017"}
0005432984826	83FEC5	0313 993959	LYUDMILA MAKAROVA	{"email": "lyudmila-makarova-031968@postgrespro.ru", "phone": "+70828283919"}
0005432984827	83FEC5	0427 085859	RAISA KOLESNIKOVA	{"phone": "+70970744232"}
0005432984828	83FEC5	2863 532166	LYUDMILA FROLOVA	{"email": "frolova-l_071973@postgrespro.ru", "phone": "+70647889551"}
0005432984829	18AD6B	4936 222569	DAMIR MAKSIMOV	{"phone": "+70051650822"}
0005432984830	659DEF	6521 865581	NATALYA MATVEEVA	{"phone": "+70808739423"}
0005432984831	BDBD8C	6022 448337	IRINA NIKIFOROVA	{"phone": "+70847860695"}
0005432984832	4B4AB4	2227 010871	IRINA MASLOVA	{"email": "i-maslova_1974@postgrespro.ru", "phone": "+70517285540"}
0005432984833	4B4AB4	7574 939763	KSENIYA SCHERBAKOVA	{"email": "kseniya.scherbakova-1967@postgrespro.ru", "phone": "+70705627122"}
0005432984834	B3BEC5	6868 525705	LYUDMILA KUZNECOVA	{"email": "l-kuznecova.06091966@postgrespro.ru", "phone": "+70300878172"}
0005432984835	06D09C	1204 859912	OLEG NOVIKOV	{"phone": "+70100517792"}
0005432984836	3C92B9	2936 301028	DZHAMILYA FROLOVA	{"email": "dzhamilya_frolova1978@postgrespro.ru", "phone": "+70342489770"}
0005432984837	7AC267	5723 418085	NADEZHDA ZHURAVLEVA	{"phone": "+70862802644"}
0005432984838	7AC267	2676 953438	GALINA MAKAROVA	{"phone": "+70893891013"}
0005432984839	F0A410	1460 210990	ILYA BORISOV	{"email": "i_borisov111964@postgrespro.ru", "phone": "+70582713377"}
0005432984840	307EFB	3466 401332	IGOR ANDREEV	{"email": "andreev_igor_031970@postgrespro.ru", "phone": "+70505681389"}
0005432984841	307EFB	2351 756093	IGOR IVANOV	{"phone": "+70618987198"}
0005432984842	806274	7011 322437	KIRILL MIKHAYLOV	{"email": "mikhaylov.k-25081958@postgrespro.ru", "phone": "+70350743695"}
0005432984843	8CD5F0	4129 504880	SERGEY STEPANOV	{"phone": "+70565717504"}
0005432984844	5D6255	9309 694855	DMITRIY MAKAROV	{"phone": "+70890808155"}
0005432984845	C67DAD	2007 654658	LARISA KISELEVA	{"phone": "+70686585016"}
0005432984846	C67DAD	5166 007436	OLEG KUZNECOV	{"phone": "+70598945704"}
0005432984847	6ED08D	0768 316298	ROMAN IVANOV	{"email": "r.ivanov.10031978@postgrespro.ru", "phone": "+70380799528"}
0005432984848	D4660B	0067 115348	ANATOLIY POPOV	{"email": "popovanatoliy.21061972@postgrespro.ru", "phone": "+70168258313"}
0005432984849	D4660B	6696 911194	YANA KOROLEVA	{"email": "ykoroleva-1951@postgrespro.ru", "phone": "+70131743301"}
0005432984850	50AEA3	5849 304424	ANTONINA DMITRIEVA	{"phone": "+70142259794"}
0005432984851	443C41	7803 572669	BULAT PAVLOV	{"email": "b_pavlov081969@postgrespro.ru", "phone": "+70511134393"}
0005432984852	443C41	1998 598637	ELENA MAKAROVA	{"email": "makarova.elena081965@postgrespro.ru", "phone": "+70271902190"}
0005432984853	EAF12E	6745 999119	NINA MELNIKOVA	{"phone": "+70219751982"}
0005432984854	F29274	2508 230972	ALEKSANDRA KUZNECOVA	{"phone": "+70871194802"}
0005432984855	10E741	2683 900554	MARIYA KOMAROVA	{"phone": "+70852427179"}
0005432984856	292A57	9385 657764	YURIY SCHERBAKOV	{"email": "yuriyscherbakov-1967@postgrespro.ru", "phone": "+70520377751"}
0005432984857	292A57	1417 348105	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr.13011978@postgrespro.ru", "phone": "+70330228051"}
0005432984858	FDA592	4825 804034	DMITRIY NAZAROV	{"phone": "+70861338810"}
0005432984859	22BDC1	6784 219905	TATYANA FOMINA	{"email": "fominatatyana.1967@postgrespro.ru", "phone": "+70233519697"}
0005432984860	9A692E	1339 764836	ALEKSANDR MATVEEV	{"email": "matveev-aleksandr_17031984@postgrespro.ru", "phone": "+70950229848"}
0005432984861	9425E5	1396 468110	TATYANA KOZLOVA	{"email": "kozlova.t19081960@postgrespro.ru", "phone": "+70781734042"}
0005432984862	239183	8200 087485	VALERIY EGOROV	{"email": "egorov_valeriy.28021966@postgrespro.ru", "phone": "+70953204746"}
0005432984863	239183	8917 493542	DMITRIY VOLKOV	{"email": "dmitriy_volkov_091976@postgrespro.ru", "phone": "+70353872968"}
0005432984864	B8C7E2	7703 066561	LYUBOV ILINA	{"email": "ilina_l1969@postgrespro.ru", "phone": "+70242996889"}
0005432984865	B8C7E2	7062 121658	MAKSIM KULIKOV	{"phone": "+70227010234"}
0005432984866	73A144	7208 134748	YANA FEDOROVA	{"email": "fedorovay031965@postgrespro.ru", "phone": "+70686697603"}
0005432984867	73A144	8843 408217	SVETLANA BELOVA	{"phone": "+70082143923"}
0005432985422	64C94E	0648 857714	VLADIMIR VASILEV	{"phone": "+70870605659"}
0005432984868	D7A6C2	7740 611704	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir.01101984@postgrespro.ru", "phone": "+70978732467"}
0005432984869	C942C3	2344 609069	ANNA OSIPOVA	{"email": "a.osipova051967@postgrespro.ru", "phone": "+70244887302"}
0005432984870	0203C1	8947 671126	ANASTASIYA KONDRATEVA	{"phone": "+70893888880"}
0005432984871	7DDDB9	7437 828240	SERGEY AFANASEV	{"phone": "+70352807780"}
0005432984872	E7D675	4903 935853	NADEZHDA EGOROVA	{"phone": "+70828297788"}
0005432984873	E507BB	7250 485680	VALENTINA RYABOVA	{"email": "valentinaryabova071976@postgrespro.ru", "phone": "+70486480709"}
0005432984874	E507BB	8695 489971	MIKHAIL NAZAROV	{"email": "mikhail_nazarov_021967@postgrespro.ru", "phone": "+70655887940"}
0005432984875	5AA3CC	4462 215099	LYUDMILA KUZNECOVA	{"phone": "+70112898454"}
0005432984876	866863	1459 902236	ALEKSANDR KUZNECOV	{"phone": "+70308564340"}
0005432984877	3D31D4	0282 675099	MIKHAIL MOISEEV	{"phone": "+70321605017"}
0005432984878	3D31D4	0404 422266	VIKTORIYA SMIRNOVA	{"email": "v_smirnova05091972@postgrespro.ru", "phone": "+70973197486"}
0005432984879	8B57DE	4842 681647	ANGELINA POPOVA	{"phone": "+70776684085"}
0005432984880	8B57DE	8638 845258	LYUDMILA NIKITINA	{"email": "nikitina.l-01101972@postgrespro.ru", "phone": "+70823007997"}
0005432984881	00AD0A	5643 002891	MAKSIM ALEKSEEV	{"email": "alekseev-m.1956@postgrespro.ru", "phone": "+70532904277"}
0005432984882	00AD0A	3682 007645	NINA MALYSHEVA	{"email": "nina.malysheva.1972@postgrespro.ru", "phone": "+70142851882"}
0005432984883	00AD0A	6676 080485	GALINA STEPANOVA	{"phone": "+70712069842"}
0005432984884	99F8AA	7366 247429	ALEKSANDR GUSEV	{"email": "aleksandr-gusev.111971@postgrespro.ru", "phone": "+70173780276"}
0005432984885	A669F3	4251 678724	NADEZHDA GERASIMOVA	{"email": "gerasimova.nadezhda_041962@postgrespro.ru", "phone": "+70255310986"}
0005432984886	A669F3	1786 018599	OLGA POPOVA	{"email": "olga_popova30041975@postgrespro.ru", "phone": "+70496065657"}
0005432984887	A669F3	4124 833221	KSENIYA MOROZOVA	{"phone": "+70656088867"}
0005432984888	FC1314	0436 781645	TAMARA ORLOVA	{"phone": "+70668655002"}
0005432984889	FC1314	2329 544804	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana-10101977@postgrespro.ru", "phone": "+70847510372"}
0005432984890	27CBDD	9383 672228	KLAVDIYA STEPANOVA	{"email": "stepanova_k-1967@postgrespro.ru", "phone": "+70375833629"}
0005432984891	03BE0B	6027 024620	DMITRIY VASILEV	{"phone": "+70794484096"}
0005432984892	FF0AD4	6129 698320	TATYANA DAVYDOVA	{"email": "tatyana-davydova1973@postgrespro.ru", "phone": "+70031650985"}
0005432984893	EBA6D6	3801 712761	DMITRIY KOZLOV	{"phone": "+70864676330"}
0005432984894	677C64	6114 199238	OLGA SIDOROVA	{"phone": "+70014882243"}
0005432984895	677C64	5711 414628	ALEKSEY KUZNECOV	{"email": "kuznecova-01061968@postgrespro.ru", "phone": "+70199066329"}
0005432984896	379556	6271 434566	ALEKSEY PAVLOV	{"email": "pavlov-a-1973@postgrespro.ru", "phone": "+70889822273"}
0005432984897	379556	9293 945548	SERGEY ZHUKOV	{"email": "s-zhukov-101962@postgrespro.ru", "phone": "+70952149440"}
0005432984898	379556	0506 724744	LIDIYA KUZNECOVA	{"email": "l_kuznecova-15071972@postgrespro.ru", "phone": "+70673072067"}
0005432984899	74E00F	4435 521454	DARYA KARPOVA	{"phone": "+70592129155"}
0005432984900	629F5E	8583 564021	DENIS NOVIKOV	{"phone": "+70315782985"}
0005432984901	9B2FC8	8356 644107	OLGA IVANOVA	{"email": "ivanova.olga26101957@postgrespro.ru", "phone": "+70694976283"}
0005432984902	9B2FC8	2010 547150	NADEZHDA TIMOFEEVA	{"email": "n-timofeeva10061966@postgrespro.ru", "phone": "+70590693753"}
0005432984903	FC96BE	7450 476886	ALEKSANDR GAVRILOV	{"phone": "+70646767943"}
0005432984904	FC96BE	7067 932710	ELENA OVCHINNIKOVA	{"email": "ovchinnikova.elena_041969@postgrespro.ru", "phone": "+70509149104"}
0005432984905	9B636E	8252 042377	NIKOLAY YAKOVLEV	{"email": "yakovlev.n-1970@postgrespro.ru", "phone": "+70364372457"}
0005432984906	9B636E	8027 976342	SVETLANA MAKAROVA	{"email": "makarova-s_30061978@postgrespro.ru", "phone": "+70261944720"}
0005432984907	9B636E	0694 832212	KIRILL FEDOTOV	{"email": "kirill_fedotov-1976@postgrespro.ru", "phone": "+70419579462"}
0005432984908	6488B8	0025 246243	MAKSIM KAZAKOV	{"email": "maksim_kazakov03101968@postgrespro.ru", "phone": "+70661912158"}
0005432984909	910FF5	2316 729096	ALEKSANDR CHERNOV	{"phone": "+70809209451"}
0005432984910	910FF5	3207 799626	DENIS ORLOV	{"email": "denis-orlov-29101970@postgrespro.ru", "phone": "+70296320829"}
0005432984911	FB4334	8894 668567	SERGEY IVANOV	{"email": "s.ivanov-111974@postgrespro.ru", "phone": "+70188151965"}
0005432984912	FB4334	2577 918059	ANNA FILIPPOVA	{"phone": "+70938318017"}
0005432984913	781991	4297 359747	NADEZHDA KOROLEVA	{"email": "nadezhda.koroleva021983@postgrespro.ru", "phone": "+70577199362"}
0005432984914	350863	8746 463318	LYUBOV BORISOVA	{"phone": "+70167623034"}
0005432984915	A17DBB	4087 789730	MARIYA MATVEEVA	{"phone": "+70603129569"}
0005432984916	032630	2780 405765	RAISA FROLOVA	{"phone": "+70026303286"}
0005432984917	A78B32	5130 660383	GALINA SMIRNOVA	{"email": "smirnova_g031967@postgrespro.ru", "phone": "+70787789137"}
0005432984918	7D8303	6595 109292	MAKSIM GORBUNOV	{"phone": "+70641301430"}
0005432984919	C9A735	9469 987892	NIKOLAY ALEKSEEV	{"email": "alekseev-nikolay071978@postgrespro.ru", "phone": "+70911623334"}
0005432984920	9FF145	3898 907479	NADEZHDA MAKAROVA	{"email": "makarova_nadezhda.07051979@postgrespro.ru", "phone": "+70013850731"}
0005432984921	557FE6	5564 287973	ANTON DMITRIEV	{"email": "dmitriev.a-08061968@postgrespro.ru", "phone": "+70340777407"}
0005432984922	447473	5086 472039	SVETLANA FILATOVA	{"phone": "+70087111741"}
0005432984923	447473	2212 626400	KLAVDIYA MIRONOVA	{"email": "mironova-klavdiya_071971@postgrespro.ru", "phone": "+70823310973"}
0005432984924	B72832	0836 631164	EKATERINA GUSEVA	{"email": "guseva.e1970@postgrespro.ru", "phone": "+70437540654"}
0005432984925	85E64E	4250 052575	TATYANA AKIMOVA	{"email": "tatyanaakimova_091970@postgrespro.ru", "phone": "+70837822727"}
0005432984926	85E64E	3759 824372	OLGA NOVIKOVA	{"email": "onovikova_21041970@postgrespro.ru", "phone": "+70743100203"}
0005432984927	0758EC	0621 924453	SERGEY NAUMOV	{"phone": "+70512346384"}
0005432984928	AEE30D	8043 420135	ANDREY KUZNECOV	{"email": "kuznecov_andrey_121973@postgrespro.ru", "phone": "+70799151853"}
0005432984929	AEE30D	7283 135938	DENIS NOVIKOV	{"email": "novikov_d.1977@postgrespro.ru", "phone": "+70409750842"}
0005432984930	A76749	0151 613000	SERGEY RODIONOV	{"email": "rodionovsergey-07031969@postgrespro.ru", "phone": "+70806328500"}
0005432984931	7511FF	8977 771760	YANA POPOVA	{"email": "popova-y1978@postgrespro.ru", "phone": "+70045001488"}
0005432984932	C5053C	3464 955013	VLADIMIR VOLKOV	{"email": "volkovvladimir_24031964@postgrespro.ru", "phone": "+70935492629"}
0005432984933	D41796	3217 261164	ZINAIDA NIKOLAEVA	{"phone": "+70362092599"}
0005432984934	D41796	8503 238046	VLADIMIR ZHUKOV	{"email": "vzhukov.061981@postgrespro.ru", "phone": "+70526403290"}
0005432984935	0BD195	2901 778010	TATYANA FILATOVA	{"phone": "+70953794098"}
0005432984936	96ADFF	3033 592967	EKATERINA MASLOVA	{"phone": "+70949711184"}
0005432984937	C842CA	9399 527276	ALEKSANDRA KOROLEVA	{"phone": "+70996629036"}
0005432984938	EB085E	8907 749475	VLADIMIR ZHUKOV	{"email": "vladimir_zhukov.1971@postgrespro.ru", "phone": "+70000906187"}
0005432984939	EB085E	0279 766829	NATALYA ANDREEVA	{"email": "andreeva_n-14121964@postgrespro.ru", "phone": "+70412250111"}
0005432984940	A408D9	4829 790572	SEMEN DMITRIEV	{"phone": "+70890668768"}
0005432984941	14F89B	9979 945500	VASILIY FOMIN	{"phone": "+70185647883"}
0005432984942	14F89B	8675 677573	MARIYA EFIMOVA	{"email": "m_efimova.1974@postgrespro.ru", "phone": "+70611715987"}
0005432984943	6BE7EA	3493 966185	ALEKSANDRA BOGDANOVA	{"email": "bogdanova_aleksandra.22081968@postgrespro.ru", "phone": "+70404480207"}
0005432984944	6BE7EA	6838 083206	VERA TARASOVA	{"email": "vera-tarasova1975@postgrespro.ru", "phone": "+70219108629"}
0005432984945	70D58B	1256 265400	ARTEMIY SMIRNOV	{"phone": "+70914256795"}
0005432984946	62B5FC	7609 154730	OKSANA EGOROVA	{"phone": "+70013496059"}
0005432984947	3C04F6	3041 475278	ALEKSANDR BELOV	{"phone": "+70142048091"}
0005432984948	3C04F6	8189 717096	MIKHAIL DMITRIEV	{"phone": "+70593763982"}
0005432984949	0634CE	8788 791512	LYUDMILA NAZAROVA	{"phone": "+70035646010"}
0005432984950	2265F0	2265 847448	ANGELINA KONDRATEVA	{"email": "a.kondrateva-1978@postgrespro.ru", "phone": "+70542183148"}
0005432984951	2265F0	2371 240750	TAMARA KUZNECOVA	{"email": "tamara.kuznecova.1961@postgrespro.ru", "phone": "+70034855372"}
0005432984952	2265F0	7949 155112	ALENA KUZNECOVA	{"phone": "+70463758732"}
0005432984953	05A4F8	9482 921630	VALERIY SMIRNOV	{"phone": "+70977724981"}
0005432984954	1FF129	5705 386056	NINA POPOVA	{"email": "n_popova_15111966@postgrespro.ru", "phone": "+70320594779"}
0005432984955	1FF129	8153 882430	ANNA SOKOLOVA	{"email": "sokolovaanna1960@postgrespro.ru", "phone": "+70148756283"}
0005432984956	899665	3946 431821	SERGEY FILIPPOV	{"phone": "+70862101237"}
0005432984957	BAB116	5932 811404	LYUDMILA TIMOFEEVA	{"email": "lyudmilatimofeeva16061975@postgrespro.ru", "phone": "+70772723739"}
0005432984958	BAB116	8029 403318	ALEKSANDR KUZNECOV	{"phone": "+70467784068"}
0005432984959	C7785F	8660 581352	EVGENIY KUZMIN	{"email": "kuzmin_e-10081969@postgrespro.ru", "phone": "+70473013502"}
0005432984960	52F8E9	5126 888880	LARISA ZOTOVA	{"email": "larisa.zotova.01101967@postgrespro.ru", "phone": "+70220374924"}
0005432984961	61E488	9664 336631	SERGEY KAZAKOV	{"email": "kazakov-s041974@postgrespro.ru", "phone": "+70179783079"}
0005432984962	A7BF4B	1489 669947	ANASTASIYA POTAPOVA	{"email": "anastasiyapotapova_1974@postgrespro.ru", "phone": "+70156441324"}
0005432984963	A7BF4B	8788 583322	LYUBOV PETROVA	{"phone": "+70615216198"}
0005432984964	A7BF4B	8023 766387	OKSANA POPOVA	{"email": "oksana_popova1973@postgrespro.ru", "phone": "+70712195462"}
0005432984965	E5BF1E	4630 222003	OLESYA KAZAKOVA	{"phone": "+70966476934"}
0005432984966	6CBBBA	2572 698292	YULIYA KOMAROVA	{"phone": "+70776902962"}
0005432984967	876F72	4772 692424	VALERIYA KAZAKOVA	{"email": "kazakova_valeriya1969@postgrespro.ru", "phone": "+70094011165"}
0005432984968	F224DF	3541 177878	ALEKSANDR ZHUKOV	{"email": "a_zhukov101977@postgrespro.ru", "phone": "+70754983540"}
0005432984969	980A94	6193 041393	ALENA DANILOVA	{"phone": "+70562490673"}
0005432984970	980A94	1297 050619	YULIYA TIMOFEEVA	{"phone": "+70932863581"}
0005432984971	6919AA	3965 819820	EKATERINA VOLKOVA	{"email": "e_volkova-1967@postgrespro.ru", "phone": "+70170710525"}
0005432984972	32798D	3437 672031	ANATOLIY MATVEEV	{"phone": "+70480619140"}
0005432984973	32798D	0663 979780	DMITRIY BORISOV	{"phone": "+70752528237"}
0005432984974	4123A6	9398 071261	VITALIY IVANOV	{"phone": "+70877328770"}
0005432984975	39ED5B	9660 301530	RAMIL POPOV	{"email": "popov-ramil-24031963@postgrespro.ru", "phone": "+70955298091"}
0005432984976	39ED5B	0054 259550	EVGENIY VASILEV	{"phone": "+70433792582"}
0005432984977	39ED5B	7224 580666	ELENA MOISEEVA	{"email": "moiseevae.08031965@postgrespro.ru", "phone": "+70793892590"}
0005432984978	95D42F	9806 731490	ALEKSANDR RODIONOV	{"email": "arodionov_071964@postgrespro.ru", "phone": "+70054568816"}
0005432984979	95D42F	7151 559708	VLADIMIR VLASOV	{"email": "vlasov_vladimir_23071968@postgrespro.ru", "phone": "+70124843087"}
0005432984980	95D42F	5188 134144	VLADIMIR KOZLOV	{"email": "kozlov_vladimir-051978@postgrespro.ru", "phone": "+70137795562"}
0005432984981	D88D6E	9065 690239	ILMIR YAKOVLEV	{"email": "yakovlev_ilmir_031977@postgrespro.ru", "phone": "+70971271803"}
0005432984982	12750F	0641 858901	OLGA ALEKSEEVA	{"email": "olgaalekseeva_06041977@postgrespro.ru", "phone": "+70753727209"}
0005432984983	A1C3DC	3709 586276	VALERIY KOROLEV	{"phone": "+70863248221"}
0005432984984	F4DB23	2068 757152	ELENA LEBEDEVA	{"email": "e-lebedeva_20091970@postgrespro.ru", "phone": "+70686009607"}
0005432984985	F4DB23	0284 679834	IVAN NOVIKOV	{"email": "novikov.i.21091971@postgrespro.ru", "phone": "+70831168300"}
0005432984986	47BBDE	3129 553049	LIDIYA KUZMINA	{"phone": "+70349977286"}
0005432984987	47BBDE	4630 528446	GALINA RODIONOVA	{"phone": "+70633211270"}
0005432984988	E9F0A8	7911 716899	LYUBOV ZHURAVLEVA	{"email": "zhuravleva.lyubov_30041962@postgrespro.ru", "phone": "+70581845514"}
0005432984989	C888CA	0408 363195	MIKHAIL YAKOVLEV	{"email": "yakovlevmikhail.04061962@postgrespro.ru", "phone": "+70117029847"}
0005432984990	C888CA	5195 924501	VASILIY FILIPPOV	{"email": "vfilippov_121972@postgrespro.ru", "phone": "+70138552389"}
0005432984991	C888CA	3921 021324	MAKSIM KUZMIN	{"phone": "+70984810987"}
0005432984992	A71C6A	4656 416729	DMITRIY SOKOLOV	{"email": "dmitriy-sokolov_04031971@postgrespro.ru", "phone": "+70518326439"}
0005432984993	40CB24	0344 474873	TATYANA VOLKOVA	{"email": "volkova-tatyana-091973@postgrespro.ru", "phone": "+70925676630"}
0005432984994	D8CA82	2845 818076	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr061978@postgrespro.ru", "phone": "+70354470332"}
0005432984995	B52294	3935 963610	ELENA EGOROVA	{"email": "egorovae.18101963@postgrespro.ru", "phone": "+70928415923"}
0005432984996	B6AE28	3730 388622	VALENTIN KUZNECOV	{"email": "kuznecov.v14071966@postgrespro.ru", "phone": "+70104608630"}
0005432984997	B6AE28	2977 214844	ALEKSANDR BELOV	{"email": "belov-aleksandr-011978@postgrespro.ru", "phone": "+70829135198"}
0005432984998	F3EBA0	2036 577388	EVELINA MOROZOVA	{"email": "evelina-morozova-1985@postgrespro.ru", "phone": "+70201236667"}
0005432984999	5E6977	1146 757827	ANASTASIYA BARANOVA	{"phone": "+70462251912"}
0005432985000	E78B70	3924 539830	ANDREY SEMENOV	{"phone": "+70269236342"}
0005432985001	E78B70	2018 600681	MARIYA NIKOLAEVA	{"email": "nikolaeva.m03011961@postgrespro.ru", "phone": "+70138671983"}
0005432985002	0D24F0	2823 952599	OLEG VOLKOV	{"phone": "+70193259012"}
0005432985003	A62001	8191 192969	ALENA DAVYDOVA	{"phone": "+70872160933"}
0005432985004	A62001	5340 617970	SERGEY KUZNECOV	{"email": "kuznecovsergey-021978@postgrespro.ru", "phone": "+70932610871"}
0005432985005	DF50A8	9136 908534	GALINA CHERNOVA	{"email": "chernovagalina1973@postgrespro.ru", "phone": "+70788295383"}
0005432985006	DF50A8	9573 765158	IRINA ROMANOVA	{"phone": "+70235908587"}
0005432985007	5C1ECD	4013 793197	MIKHAIL KOZLOV	{"email": "m-kozlov.1971@postgrespro.ru", "phone": "+70597945600"}
0005432985008	8E6831	3442 537571	ANASTASIYA MIRONOVA	{"email": "mironovaa101979@postgrespro.ru", "phone": "+70234113413"}
0005432985009	8E6831	9880 502019	SVETLANA LAZAREVA	{"email": "svetlanalazareva.30061967@postgrespro.ru", "phone": "+70080845238"}
0005432985010	E6B8F9	0817 872629	SVETLANA DENISOVA	{"phone": "+70800501102"}
0005432985011	E6B8F9	9651 181182	ELENA MEDVEDEVA	{"phone": "+70982138079"}
0005432985012	74387F	7769 525524	DANIIL ANDREEV	{"email": "andreev_d.09061970@postgrespro.ru", "phone": "+70540422214"}
0005432985013	013C26	9457 522671	DANIIL SERGEEV	{"email": "daniil_sergeev_1969@postgrespro.ru", "phone": "+70131927631"}
0005432985014	013C26	3890 367976	IVAN TIKHONOV	{"email": "tikhonov.i.021972@postgrespro.ru", "phone": "+70599778522"}
0005432985015	013C26	9210 300874	VLADIMIR ANDREEV	{"email": "andreev_vladimir_08031971@postgrespro.ru", "phone": "+70358936511"}
0005432985016	37D146	4044 700045	YURIY YAKOVLEV	{"phone": "+70310660213"}
0005432985017	8D8F7E	5810 763437	OLEG KUZNECOV	{"phone": "+70964918645"}
0005432985018	570FB3	9480 489225	LARISA KAZAKOVA	{"phone": "+70562686397"}
0005432985019	570FB3	6458 467070	DMITRIY ROMANOV	{"phone": "+70069447948"}
0005432985020	E438DC	2007 529706	ALEKSANDR MOROZOV	{"email": "a.morozov.16011984@postgrespro.ru", "phone": "+70949367871"}
0005432985021	5E374A	7600 612113	EVGENIYA SERGEEVA	{"email": "e.sergeeva.111970@postgrespro.ru", "phone": "+70978560018"}
0005432985022	E29C52	9693 426354	ARTUR TIMOFEEV	{"email": "timofeev-artur-081975@postgrespro.ru", "phone": "+70220197039"}
0005432985023	E29C52	7690 064624	VLADIMIR POPOV	{"phone": "+70307718004"}
0005432985024	1818BB	4557 717242	SVETLANA GUSEVA	{"email": "svetlana-guseva-03121979@postgrespro.ru", "phone": "+70207728990"}
0005432985025	1818BB	3423 382648	NATALYA ALEKSEEVA	{"phone": "+70732592720"}
0005432985026	C5E8B0	9768 546567	NIKITA GORBUNOV	{"phone": "+70152694736"}
0005432985027	C5E8B0	9484 499289	MARIYA MIRONOVA	{"email": "mironova.m071979@postgrespro.ru", "phone": "+70134573378"}
0005432985028	8583E0	0238 597076	LYUDMILA NIKOLAEVA	{"email": "nikolaeva-l.1969@postgrespro.ru", "phone": "+70313045231"}
0005432985029	8583E0	5799 245119	VIKTOR ALEKSANDROV	{"email": "aleksandrovv.1973@postgrespro.ru", "phone": "+70374488733"}
0005432985030	8583E0	5351 671277	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev-1971@postgrespro.ru", "phone": "+70648524688"}
0005432985031	BDB236	9625 339246	VASILIY SIDOROV	{"email": "sidorov-v_08081978@postgrespro.ru", "phone": "+70756393017"}
0005432985032	21294E	3438 924708	EKATERINA MIRONOVA	{"email": "emironova-26091975@postgrespro.ru", "phone": "+70381312980"}
0005432985423	59A34D	1472 808839	KRISTINA MIKHAYLOVA	{"phone": "+70110042957"}
0005432985033	21294E	0679 413411	VLADISLAV YAKOVLEV	{"email": "v_yakovlev051981@postgrespro.ru", "phone": "+70459329638"}
0005432985034	05E946	1846 815961	RASHIT DMITRIEV	{"phone": "+70898210521"}
0005432985035	18F2E2	6621 541612	DENIS MIKHAYLOV	{"phone": "+70121900523"}
0005432985036	363FEA	6015 406194	LYUBOV YUDINA	{"email": "lyubov-yudina-22081980@postgrespro.ru", "phone": "+70827715142"}
0005432985037	363FEA	3919 505346	TAISIYA KARPOVA	{"email": "t.karpova.071971@postgrespro.ru", "phone": "+70821698437"}
0005432985038	42B741	4024 264345	YURIY FROLOV	{"email": "yfrolov-1972@postgrespro.ru", "phone": "+70663076494"}
0005432985039	42B741	4928 796741	NINA AFANASEVA	{"email": "n_afanaseva_011981@postgrespro.ru", "phone": "+70402786755"}
0005432985040	AD27B4	1371 119927	MARINA VASILEVA	{"phone": "+70407272021"}
0005432985041	BEAC84	5871 302477	VLADIMIR FOMIN	{"phone": "+70020861456"}
0005432985042	6D4A71	0967 651472	ZINAIDA TARASOVA	{"email": "zinaida.tarasova-061964@postgrespro.ru", "phone": "+70035979149"}
0005432985043	74CC3A	3710 059615	ALINA KISELEVA	{"phone": "+70486586881"}
0005432985044	74CC3A	4723 585703	KONSTANTIN TARASOV	{"phone": "+70085244700"}
0005432985045	502053	5595 178549	MARIYA KONOVALOVA	{"email": "konovalovamariya-19071972@postgrespro.ru", "phone": "+70021974381"}
0005432985046	0F4590	3082 469839	VALENTINA KOLESNIKOVA	{"email": "kolesnikovav_10091968@postgrespro.ru", "phone": "+70082617377"}
0005432985047	8521D5	5914 931553	SERGEY DMITRIEV	{"email": "sergey.dmitriev_1981@postgrespro.ru", "phone": "+70378508104"}
0005432985048	77EEA8	9790 501918	SERGEY SOROKIN	{"email": "sorokinsergey01091952@postgrespro.ru", "phone": "+70151411326"}
0005432985049	8E9BA7	4290 943227	IRINA ORLOVA	{"email": "irina_orlova.041967@postgrespro.ru", "phone": "+70137003428"}
0005432985050	8E9BA7	9192 607354	LYUDMILA KAZAKOVA	{"phone": "+70635224355"}
0005432985051	06B715	1209 319561	LYUBOV KAZAKOVA	{"email": "l-kazakova_071979@postgrespro.ru", "phone": "+70111676255"}
0005432985052	06B715	7178 544384	MARINA FILIPPOVA	{"phone": "+70053661982"}
0005432985053	61605A	7573 306386	SERGEY OSIPOV	{"phone": "+70891594392"}
0005432985054	61605A	6909 447945	VLADIMIR VASILEV	{"phone": "+70043025212"}
0005432985055	88789D	0789 614724	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey1970@postgrespro.ru", "phone": "+70436334471"}
0005432985056	AC22FB	3317 308419	VERA MELNIKOVA	{"phone": "+70463172231"}
0005432985057	8CAA09	2523 097666	EKATERINA FEDOROVA	{"phone": "+70035804572"}
0005432985058	8CAA09	5152 782978	TATYANA LUKYANOVA	{"email": "lukyanova.t041990@postgrespro.ru", "phone": "+70555395405"}
0005432985059	BFBC9D	4828 454488	MARINA MEDVEDEVA	{"email": "marina_medvedeva_24111969@postgrespro.ru", "phone": "+70058813736"}
0005432985060	BFBC9D	5075 277970	ALEKSANDR IVANOV	{"email": "a-ivanov.1970@postgrespro.ru", "phone": "+70764915434"}
0005432985061	7AB1A4	7004 007663	EKATERINA NIKOLAEVA	{"phone": "+70525467615"}
0005432985062	9E2AF3	6577 494275	EDUARD VOLKOV	{"phone": "+70526955228"}
0005432985063	2C6B60	5764 768971	IVAN KARPOV	{"phone": "+70494704120"}
0005432985064	2C6B60	5442 619633	ELENA BELOVA	{"phone": "+70615912819"}
0005432985065	2C6B60	8753 102731	VLADISLAV MATVEEV	{"phone": "+70446997021"}
0005432985066	57F4E3	1463 845197	ALBINA NIKITINA	{"email": "anikitina111965@postgrespro.ru", "phone": "+70265696783"}
0005432985067	9F2E72	1441 794936	NADEZHDA NIKIFOROVA	{"phone": "+70071035742"}
0005432985068	C2A78D	5946 366474	ILYA TIKHONOV	{"email": "ilya-tikhonov_1976@postgrespro.ru", "phone": "+70175330459"}
0005432985189	1DD827	6340 540277	YULIYA FILATOVA	{"phone": "+70276461850"}
0005432985069	5D2501	3592 604436	OLGA KUZNECOVA	{"email": "kuznecova-o_1963@postgrespro.ru", "phone": "+70207486288"}
0005432985070	BE039D	5964 650259	EVGENIY SCHERBAKOV	{"phone": "+70057077721"}
0005432985071	7B2E84	7448 423952	EVGENIYA MAKAROVA	{"email": "makarova.e.071981@postgrespro.ru", "phone": "+70485873669"}
0005432985072	BD5DA1	0541 646419	EVGENIY SIDOROV	{"phone": "+70582613279"}
0005432985073	BD5DA1	8141 225773	SERGEY DENISOV	{"email": "denisov_s.28111978@postgrespro.ru", "phone": "+70885457057"}
0005432985074	ABC7A3	3977 137125	SERGEY VLASOV	{"email": "vlasov_s-16061975@postgrespro.ru", "phone": "+70083957690"}
0005432985075	31154F	6809 634250	SALAVAT VOROBEV	{"email": "vorobev_salavat_05031966@postgrespro.ru", "phone": "+70503396524"}
0005432985076	DB6C60	0117 893126	SVETLANA VASILEVA	{"email": "vasilevasvetlana-15121962@postgrespro.ru", "phone": "+70850901869"}
0005432985077	AE634B	9891 738763	ALEKSEY KAZAKOV	{"email": "kazakov-aleksey.1974@postgrespro.ru", "phone": "+70283664008"}
0005432985078	964CDE	3796 850425	SERGEY SOKOLOV	{"phone": "+70048869419"}
0005432985079	964CDE	2454 314809	NINA GUSEVA	{"email": "n-guseva07031982@postgrespro.ru", "phone": "+70379098999"}
0005432985080	32E779	9436 262248	ALENA MATVEEVA	{"phone": "+70301544990"}
0005432985081	5D5BBF	4953 158293	SERGEY KOROLEV	{"phone": "+70713676728"}
0005432985082	4C7786	3241 779396	OLEG ANDREEV	{"email": "andreev.o_041961@postgrespro.ru", "phone": "+70442978212"}
0005432985083	8D5BE4	9433 858490	MARIYA KUDRYASHOVA	{"phone": "+70704974484"}
0005432985084	8D5BE4	3767 743591	KRISTINA SOLOVEVA	{"phone": "+70898826081"}
0005432985085	24200B	7886 155763	MIKHAIL IVANOV	{"email": "mikhail-ivanov-041973@postgrespro.ru", "phone": "+70758871365"}
0005432985086	4B68E0	2235 367070	IVAN MAKAROV	{"phone": "+70997378959"}
0005432985087	6816A7	1961 497570	SERGEY NAUMOV	{"phone": "+70989541724"}
0005432985088	82DA52	1193 273712	TATYANA KAZAKOVA	{"email": "tatyana.kazakova.1963@postgrespro.ru", "phone": "+70928687976"}
0005432985089	82DA52	8225 564209	PAVEL NOVIKOV	{"email": "pavel.novikov121973@postgrespro.ru", "phone": "+70807504051"}
0005432985090	950015	0090 831519	ANTONINA LUKYANOVA	{"phone": "+70711373944"}
0005432985091	950015	6193 274750	YULIYA KRASNOVA	{"phone": "+70354407726"}
0005432985092	DC717F	1860 616173	TATYANA MIKHAYLOVA	{"email": "tmikhaylova.1975@postgrespro.ru", "phone": "+70068304589"}
0005432985093	4E81F6	3106 483952	ILYA KARPOV	{"email": "karpov.ilya1977@postgrespro.ru", "phone": "+70313877441"}
0005432985094	4E81F6	3640 014845	ANASTASIYA BELOVA	{"phone": "+70824778239"}
0005432985095	A6845E	0129 318687	VASILIY SEMENOV	{"email": "vasiliy.semenov1973@postgrespro.ru", "phone": "+70414623833"}
0005432985096	F8CCB0	0331 254050	ILYAS SOKOLOV	{"phone": "+70069587767"}
0005432985097	71C755	3414 586899	ALEKSANDR ORLOV	{"phone": "+70931541018"}
0005432985098	A71831	9540 599292	VADIM KULIKOV	{"phone": "+70552118079"}
0005432985099	A71831	3999 275203	SHAMIL DENISOV	{"email": "denisovs_031967@postgrespro.ru", "phone": "+70240931128"}
0005432985100	DC2A6E	1412 242867	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko1965@postgrespro.ru", "phone": "+70359827521"}
0005432985101	59F9ED	6074 649565	NIKOLAY SIDOROV	{"phone": "+70249154390"}
0005432985102	6E71DA	7813 724010	NATALYA PETROVA	{"email": "n-petrova.1970@postgrespro.ru", "phone": "+70587324191"}
0005432985103	2A407C	7969 743117	VIKTOR ZHURAVLEV	{"phone": "+70223232076"}
0005432985104	624288	6898 670581	ELENA GERASIMOVA	{"phone": "+70639356954"}
0005432985105	C21AAC	8437 888722	YULIYA IVANOVA	{"phone": "+70551475890"}
0005432985106	33E323	8487 233876	OLGA KUDRYASHOVA	{"email": "o.kudryashova1976@postgrespro.ru", "phone": "+70884217176"}
0005432985107	2B98CF	4619 362271	NIKITA POPOV	{"phone": "+70211875716"}
0005432985108	1BC3A9	9384 252938	LYUBOV SOKOLOVA	{"phone": "+70118872876"}
0005432985109	1BC3A9	9092 085892	ELENA KISELEVA	{"phone": "+70806752354"}
0005432985110	1BC3A9	4369 155534	ALEKSANDR GAVRILOV	{"email": "gavrilova_17011988@postgrespro.ru", "phone": "+70691841001"}
0005432985111	A80F5C	1715 649165	YURIY TIMOFEEV	{"phone": "+70495420460"}
0005432985112	AB0481	5774 294792	NINA BELOVA	{"email": "belova.nina-14041973@postgrespro.ru", "phone": "+70505891354"}
0005432985113	AB0481	1841 273073	GENNADIY OSIPOV	{"email": "osipov-gennadiy.18041967@postgrespro.ru", "phone": "+70517475949"}
0005432985114	AB0481	9728 979183	MAKSIM TARASOV	{"email": "tarasov.maksim-1963@postgrespro.ru", "phone": "+70408666395"}
0005432985115	6E2A09	5294 387587	ALEKSANDR KOZLOV	{"email": "kozlova071977@postgrespro.ru", "phone": "+70204617787"}
0005432985116	8603ED	9535 287564	VLADIMIR BARANOV	{"phone": "+70311791899"}
0005432985117	8603ED	0392 964067	NIKOLAY ZAKHAROV	{"email": "nikolay.zakharov.20111974@postgrespro.ru", "phone": "+70504378762"}
0005432985118	E0847D	2779 067485	TATYANA KUZNECOVA	{"phone": "+70880233952"}
0005432985119	BF8491	2242 915083	YULIYA MARTYNOVA	{"phone": "+70354774863"}
0005432985120	BF8491	5602 278489	ANNA NAZAROVA	{"phone": "+70082502962"}
0005432985121	56DE1B	3451 399948	LYUDMILA ISAEVA	{"phone": "+70428336961"}
0005432985122	56DE1B	7635 394760	VLADIMIR VASILEV	{"email": "v.vasilev121990@postgrespro.ru", "phone": "+70269855009"}
0005432985123	3ADA1F	0409 213485	IGOR FEDOROV	{"email": "fedorov-i-081976@postgrespro.ru", "phone": "+70375881846"}
0005432985124	62D0E6	7255 018603	DENIS ALEKSEEV	{"email": "alekseev-d-1968@postgrespro.ru", "phone": "+70052966538"}
0005432985125	D3C3AF	7505 155947	ELIZAVETA KOLESNIKOVA	{"email": "elizaveta_kolesnikova011979@postgrespro.ru", "phone": "+70115484588"}
0005432985126	D3C3AF	0013 581129	NADEZHDA BORISOVA	{"email": "borisovan-1971@postgrespro.ru", "phone": "+70854811829"}
0005432985127	AEADAF	6177 564331	VLADIMIR KARPOV	{"phone": "+70819139425"}
0005432985128	62B297	8900 507228	VLADIMIR DENISOV	{"phone": "+70195255167"}
0005432985129	82A153	8129 958536	MARIYA KUZNECOVA	{"phone": "+70930391232"}
0005432985130	82A153	9734 183002	ALEKSANDRA MASLOVA	{"email": "maslova-a-13081972@postgrespro.ru", "phone": "+70560779197"}
0005432985131	82A153	7764 232419	GENNADIY ANTONOV	{"phone": "+70798114644"}
0005432985132	3A2A40	3867 537712	ANNA FILATOVA	{"phone": "+70041459565"}
0005432985133	3A2A40	8486 020655	ANASTASIYA VLASOVA	{"phone": "+70134629825"}
0005432985134	EEE824	3756 269823	KAMILA MELNIKOVA	{"phone": "+70498054433"}
0005432985135	4D7750	1646 912291	IRINA KUZMINA	{"phone": "+70800795548"}
0005432985136	5CD162	2126 065831	TIMOFEY MOISEEV	{"email": "timofey.moiseev.07011967@postgrespro.ru", "phone": "+70712203979"}
0005432985137	5CD162	6017 290244	TIMUR ABRAMOV	{"phone": "+70015768809"}
0005432985138	C0C78B	2101 591237	EKATERINA KOMAROVA	{"phone": "+70890692310"}
0005432985139	2C7B1B	0054 430250	NINA KONOVALOVA	{"email": "konovalovanina.071971@postgrespro.ru", "phone": "+70636908688"}
0005432985140	2C7B1B	4588 220217	YULIYA IVANOVA	{"email": "ivanova_y-1988@postgrespro.ru", "phone": "+70206959171"}
0005432985141	36BAE5	0487 565383	OLGA NOVIKOVA	{"phone": "+70848712656"}
0005432985142	D609CE	0531 609343	LEONID DMITRIEV	{"email": "leonid.dmitriev1972@postgrespro.ru", "phone": "+70502125304"}
0005432985143	D609CE	6403 312561	ALFIYA SERGEEVA	{"phone": "+70155387238"}
0005432985144	D609CE	0732 840349	LIDIYA FROLOVA	{"phone": "+70158498793"}
0005432985145	143A10	7680 012280	ANNA KUZNECOVA	{"email": "kuznecova-anna_091970@postgrespro.ru", "phone": "+70735528127"}
0005432985146	50FD0A	3056 768575	ALEKSANDR MEDVEDEV	{"email": "aleksandrmedvedev_1974@postgrespro.ru", "phone": "+70916284606"}
0005432985147	50FD0A	0112 484914	DENIS GERASIMOV	{"phone": "+70602915507"}
0005432985148	50FD0A	7524 019247	SVETLANA MAKAROVA	{"email": "svetlana_makarova_28121969@postgrespro.ru", "phone": "+70404571101"}
0005432985149	B89555	2761 865110	OLGA ZAKHAROVA	{"email": "zakharovaolga-1980@postgrespro.ru", "phone": "+70275640126"}
0005432985150	B89555	9501 001499	ANNA MIRONOVA	{"email": "mironova.anna_27061974@postgrespro.ru", "phone": "+70249172085"}
0005432985151	751540	4160 573790	TATYANA PAVLOVA	{"phone": "+70292673798"}
0005432985152	D59177	3261 925552	OLEG NOVIKOV	{"phone": "+70557938382"}
0005432985153	C3BFBF	0775 030856	NATALYA NESTEROVA	{"email": "nesterova_n.101968@postgrespro.ru", "phone": "+70150790848"}
0005432985154	1D3CAA	5704 608863	DMITRIY SIDOROV	{"phone": "+70008657932"}
0005432985155	D6867D	2662 523485	NADEZHDA BELYAEVA	{"email": "belyaeva_n-1968@postgrespro.ru", "phone": "+70302637571"}
0005432985156	2D985E	2898 803106	OLGA SAVELEVA	{"email": "olga-saveleva111975@postgrespro.ru", "phone": "+70920712795"}
0005432985157	2D985E	2024 942449	VLADIMIR KUZNECOV	{"phone": "+70670811367"}
0005432985158	477452	6093 317936	LYUBOV PETROVA	{"phone": "+70998367362"}
0005432985159	ED1CD4	8597 036689	ARTEM MOISEEV	{"email": "moiseev_a13031968@postgrespro.ru", "phone": "+70460526609"}
0005432985160	ED1CD4	8661 561627	MATVEY CHERNOV	{"email": "matveychernov.031976@postgrespro.ru", "phone": "+70272988840"}
0005432985161	DCC15A	6381 031953	TATYANA ZAYCEVA	{"phone": "+70174029758"}
0005432985162	1E5ED7	7117 517060	TATYANA BOGDANOVA	{"phone": "+70848495718"}
0005432985163	8F1236	2100 787669	OLGA EGOROVA	{"email": "egorova.olga011978@postgrespro.ru", "phone": "+70913414470"}
0005432985164	8F1236	8265 596783	VERA ZAKHAROVA	{"phone": "+70425479323"}
0005432985165	B95107	5608 059487	ANDREY SOROKIN	{"email": "asorokin_1982@postgrespro.ru", "phone": "+70708009795"}
0005432985166	6018C5	0538 865318	ALEKSANDR GUSEV	{"email": "gusev-aleksandr.08071963@postgrespro.ru", "phone": "+70758232318"}
0005432985167	6018C5	7311 443673	ALEKSEY SMIRNOV	{"email": "alekseysmirnov-1978@postgrespro.ru", "phone": "+70782570326"}
0005432985168	074115	7496 870064	NIKOLAY PETROV	{"email": "n_petrov_071972@postgrespro.ru", "phone": "+70757335437"}
0005432985169	D43BE5	0728 964975	ALEKSEY PAVLOV	{"email": "aleksey-pavlov-1982@postgrespro.ru", "phone": "+70235056260"}
0005432985170	604060	9056 405437	ALENA NIKIFOROVA	{"email": "nikiforova-alena11061976@postgrespro.ru", "phone": "+70788985815"}
0005432985171	43CBBE	7965 662899	NATALYA EGOROVA	{"phone": "+70718708048"}
0005432985172	DEE1AB	6943 974385	ANDREY ANTONOV	{"email": "antonov_andrey_1973@postgrespro.ru", "phone": "+70928611946"}
0005432985173	E8D053	9801 951189	LYUDMILA GAVRILOVA	{"email": "lyudmila.gavrilova-101973@postgrespro.ru", "phone": "+70353388842"}
0005432985174	E8D053	0266 584951	VLADISLAV MATVEEV	{"email": "matveev-vladislav.121965@postgrespro.ru", "phone": "+70503287502"}
0005432985175	4990E7	2262 093508	EVGENIY GUSEV	{"email": "gusevevgeniy.1974@postgrespro.ru", "phone": "+70285343980"}
0005432985176	52DC9E	0897 234657	MILANA ANDREEVA	{"email": "m-andreeva.17061966@postgrespro.ru", "phone": "+70205409348"}
0005432985177	D7DC95	2864 813121	KSENIYA SMIRNOVA	{"email": "k_smirnova1973@postgrespro.ru", "phone": "+70584726042"}
0005432985178	D7DC95	6115 172458	OLGA MALYSHEVA	{"phone": "+70080512537"}
0005432985179	A22D0E	6584 964459	LYUDMILA FILIPPOVA	{"email": "filippova-l.021974@postgrespro.ru", "phone": "+70657933476"}
0005432985180	7A58A7	4684 967041	GEORGIY YAKOVLEV	{"phone": "+70648909384"}
0005432985181	9F7D27	7220 327440	PETR AFANASEV	{"email": "pafanasev.1970@postgrespro.ru", "phone": "+70078882017"}
0005432985182	25EF40	5032 776203	IRINA KUZNECOVA	{"phone": "+70866829303"}
0005432985183	7310BE	0925 660535	YULIYA KUZNECOVA	{"phone": "+70431687156"}
0005432985184	91E7BE	8918 658387	EVGENIY SMIRNOV	{"email": "evgeniy.smirnov_04071973@postgrespro.ru", "phone": "+70404920750"}
0005432985185	4A7754	0330 388985	PELAGEYA MIKHAYLOVA	{"email": "pelageya-mikhaylova011974@postgrespro.ru", "phone": "+70444345706"}
0005432985186	DA0BA8	0490 457165	YURIY NOVIKOV	{"phone": "+70568881232"}
0005432985187	DA0BA8	2604 308313	ELENA ALEKSANDROVA	{"email": "e.aleksandrova24071972@postgrespro.ru", "phone": "+70265096852"}
0005432985188	F93B2C	5961 980753	ANATOLIY MIKHAYLOV	{"email": "anatoliy.mikhaylov.08061974@postgrespro.ru", "phone": "+70083126484"}
0005432985190	1DD827	4397 125431	OLGA LOGINOVA	{"email": "ologinova.081974@postgrespro.ru", "phone": "+70534804183"}
0005432985191	730523	8398 440404	YANA FILIPPOVA	{"phone": "+70311189182"}
0005432985192	730523	4441 783242	MIKHAIL ABRAMOV	{"phone": "+70381504795"}
0005432985193	9DFBF1	1689 603526	ELENA ILINA	{"phone": "+70056793831"}
0005432985194	9DFBF1	8769 315481	ALEKSANDR DENISOV	{"phone": "+70917519274"}
0005432985195	9DFBF1	1471 749180	SERGEY BORISOV	{"phone": "+70428338343"}
0005432985196	EEBA67	4090 675781	VALENTINA KOROLEVA	{"phone": "+70979793879"}
0005432985197	EEBA67	7057 335959	TATYANA GUSEVA	{"email": "gusevat1974@postgrespro.ru", "phone": "+70098431552"}
0005432985198	22B35C	3462 624176	ALEKSANDR MIRONOV	{"email": "aleksandrmironov_051970@postgrespro.ru", "phone": "+70643427596"}
0005432985199	E1CA5A	8955 156407	SERGEY PETROV	{"phone": "+70558526485"}
0005432985200	E1CA5A	9461 739058	YULIYA IVANOVA	{"phone": "+70362740110"}
0005432985201	8A8204	6029 005400	ARSENIY ZHUKOV	{"email": "zhukov-arseniy_031990@postgrespro.ru", "phone": "+70603222179"}
0005432985202	0483FC	9771 267743	NADEZHDA KOZLOVA	{"email": "n-kozlova_111970@postgrespro.ru", "phone": "+70890071866"}
0005432985203	0483FC	5441 171965	KLAVDIYA DANILOVA	{"email": "k_danilova_1973@postgrespro.ru", "phone": "+70567268574"}
0005432985204	84B6FA	7693 140565	NATALYA ANDREEVA	{"email": "n-andreeva.26051966@postgrespro.ru", "phone": "+70166789476"}
0005432985205	6F396C	1628 990787	VALERIY IVANOV	{"email": "ivanovvaleriy_08011968@postgrespro.ru", "phone": "+70259259580"}
0005432985206	64C44C	8259 330139	TAMARA STEPANOVA	{"phone": "+70242265875"}
0005432985207	5B884E	8506 183691	STEPAN MELNIKOV	{"phone": "+70195867608"}
0005432985208	480643	7356 883353	SERGEY ISAEV	{"email": "sisaev-041979@postgrespro.ru", "phone": "+70066310853"}
0005432985209	480643	6608 572172	PETR KAZAKOV	{"email": "petrkazakov-12011982@postgrespro.ru", "phone": "+70808051390"}
0005432985210	0B8C70	0785 970868	YURIY SAVELEV	{"email": "yuriysavelev_081978@postgrespro.ru", "phone": "+70202012327"}
0005432985211	8543FC	6913 785812	ELINA POLYAKOVA	{"phone": "+70926893526"}
0005432985212	CEF0D8	6534 130068	ANATOLIY ZAYCEV	{"phone": "+70557000894"}
0005432985213	756BA3	9399 898120	ELENA GERASIMOVA	{"phone": "+70244899115"}
0005432985214	1C7EC3	7362 111568	DENIS KUZNECOV	{"email": "denis-kuznecov_21031971@postgrespro.ru", "phone": "+70299451439"}
0005432985215	1C7EC3	9232 237925	NIKOLAY IVANOV	{"phone": "+70930388903"}
0005432985216	F8E7B8	1070 358202	LARISA FADEEVA	{"email": "fadeeval101972@postgrespro.ru", "phone": "+70753647883"}
0005432985217	F8E7B8	4044 738375	VLADIMIR KONOVALOV	{"email": "konovalovvladimir-05071975@postgrespro.ru", "phone": "+70142777825"}
0005432985218	2E2184	3318 275837	NINA IVANOVA	{"phone": "+70162063878"}
0005432985219	2E2184	8898 650868	ANNA KOVALEVA	{"email": "kovaleva-anna.1968@postgrespro.ru", "phone": "+70974793948"}
0005432985220	022A0F	3957 311353	RAISA MARTYNOVA	{"phone": "+70973645866"}
0005432985221	E7675E	2554 990693	VLADISLAV KOZLOV	{"phone": "+70101532008"}
0005432985222	C8A2A4	6402 326522	BOGDAN KUZMIN	{"email": "bkuzmin061968@postgrespro.ru", "phone": "+70125132596"}
0005432985223	C8A2A4	4394 257032	GALINA ALEKSANDROVA	{"email": "aleksandrova.galina07071982@postgrespro.ru", "phone": "+70486104916"}
0005432985224	94F535	4447 547188	ANNA POLYAKOVA	{"email": "polyakova.anna.021972@postgrespro.ru", "phone": "+70561682967"}
0005432985225	5EB4DA	7725 389896	VLADIMIR MATVEEV	{"phone": "+70874671786"}
0005432985226	3A8450	0290 704971	ZINAIDA DMITRIEVA	{"email": "zdmitrieva.091982@postgrespro.ru", "phone": "+70532798478"}
0005432985227	3A8450	2322 481505	DMITRIY SOKOLOV	{"phone": "+70867714909"}
0005432985228	3A8450	1574 172380	ROMAN NIKOLAEV	{"email": "r-nikolaev_28101973@postgrespro.ru", "phone": "+70163538759"}
0005432985229	035937	0818 726289	LILIYA MALYSHEVA	{"email": "l.malysheva.101978@postgrespro.ru", "phone": "+70002426564"}
0005432985230	8A0168	7565 334123	ZINAIDA KULIKOVA	{"email": "kulikova_zinaida_1971@postgrespro.ru", "phone": "+70173258506"}
0005432985231	AAB250	9551 976304	SERGEY VOLKOV	{"email": "volkov-sergey.1973@postgrespro.ru", "phone": "+70898290041"}
0005432985232	AAB250	1198 733183	DMITRIY EGOROV	{"phone": "+70978161050"}
0005432985233	EE43C4	6601 534175	OLGA OVCHINNIKOVA	{"phone": "+70704467176"}
0005432985234	54AEBF	9548 798129	MARINA TIKHONOVA	{"phone": "+70651518456"}
0005432985235	A1767F	4652 161941	ELENA MIKHAYLOVA	{"email": "e_mikhaylova_011981@postgrespro.ru", "phone": "+70048611737"}
0005432985236	AC08A6	3888 423455	MARINA KUZNECOVA	{"email": "kuznecova.m1974@postgrespro.ru", "phone": "+70327051681"}
0005432985237	617C39	6166 033077	NATALYA TROFIMOVA	{"email": "trofimova_natalya.13051979@postgrespro.ru", "phone": "+70253994287"}
0005432985238	B7132E	9270 653936	NADEZHDA MOROZOVA	{"email": "morozova_n1967@postgrespro.ru", "phone": "+70905163668"}
0005432985239	481DBA	1542 860721	NATALYA POLYAKOVA	{"email": "natalya_polyakova-021976@postgrespro.ru", "phone": "+70864339194"}
0005432985240	66D26A	4513 914343	LYUBOV KUZNECOVA	{"phone": "+70982719380"}
0005432985241	D335D1	7581 408586	VERA KUZNECOVA	{"email": "v-kuznecova.111974@postgrespro.ru", "phone": "+70287585118"}
0005432985242	D335D1	1163 271371	EVGENIY NIKOLAEV	{"email": "nikolaev_evgeniy-19071980@postgrespro.ru", "phone": "+70337943546"}
0005432985243	CCDE95	0081 391193	VLADIMIR GAVRILOV	{"email": "vladimir_gavrilov-1966@postgrespro.ru", "phone": "+70630452035"}
0005432985244	CCDE95	4657 906165	VIKTORIYA STEPANOVA	{"phone": "+70785475018"}
0005432985245	29F6D2	5620 801124	ALEKSANDR NIKITIN	{"email": "nikitin-a-30111970@postgrespro.ru", "phone": "+70102818386"}
0005432985246	AA2616	1383 350790	ALEKSANDR KUZNECOV	{"email": "a.kuznecov22091978@postgrespro.ru", "phone": "+70679940536"}
0005432985247	A4E33C	9563 328810	MARIYA TIMOFEEVA	{"phone": "+70281551696"}
0005432985248	A4E33C	5073 791736	GENNADIY KUZNECOV	{"email": "gkuznecov-091984@postgrespro.ru", "phone": "+70236245280"}
0005432985249	C2D996	8096 709789	TIMOFEY SEMENOV	{"email": "t-semenov_15061972@postgrespro.ru", "phone": "+70700309317"}
0005432985250	D07DEC	1520 200910	EVGENIY ZAYCEV	{"email": "zaycev.evgeniy1974@postgrespro.ru", "phone": "+70697671042"}
0005432985251	7F788D	7370 040215	EKATERINA BORISOVA	{"phone": "+70231928065"}
0005432985252	7F788D	2378 970871	KONSTANTIN KUZNECOV	{"email": "kuznecovk_1968@postgrespro.ru", "phone": "+70228864708"}
0005432985253	52BF13	6111 176351	VLADIMIR KUZNECOV	{"phone": "+70706269280"}
0005432985254	52BF13	4521 114356	ROZA ILINA	{"phone": "+70214154306"}
0005432985255	77A9C4	9791 047500	GALINA GAVRILOVA	{"email": "galina_gavrilova04081968@postgrespro.ru", "phone": "+70863817414"}
0005432985256	494610	6378 621873	ANNA ZHURAVLEVA	{"email": "azhuravleva-02061977@postgrespro.ru", "phone": "+70318272346"}
0005432985257	C607B2	2039 212847	DMITRIY KOROLEV	{"email": "dkorolev_1968@postgrespro.ru", "phone": "+70915865843"}
0005432985258	0A47B8	7848 526530	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya_101976@postgrespro.ru", "phone": "+70692779821"}
0005432985259	0A47B8	8957 393400	ELENA NIKITINA	{"phone": "+70960832917"}
0005432985260	6C1787	0809 762862	ANASTASIYA NIKITINA	{"email": "anikitina.15111964@postgrespro.ru", "phone": "+70064720284"}
0005432985261	F13221	9637 559374	TATYANA FADEEVA	{"phone": "+70873099703"}
0005432985262	D935FE	1724 310926	SERGEY SEMENOV	{"phone": "+70628364768"}
0005432985263	D935FE	6847 079695	SERGEY NIKOLAEV	{"phone": "+70214989101"}
0005432985264	4C873F	6227 181381	VADIM SCHERBAKOV	{"email": "vadim.scherbakov_30061976@postgrespro.ru", "phone": "+70900945576"}
0005432985265	4C873F	6642 669100	IVAN VASILEV	{"phone": "+70910808375"}
0005432985266	B54A45	5309 620796	OLGA KULIKOVA	{"phone": "+70554272077"}
0005432985267	B54A45	9103 047347	VLADIMIR ILIN	{"email": "ilin_vladimir.26041975@postgrespro.ru", "phone": "+70360355750"}
0005432985268	A0D659	7971 993509	LYUBOV IVANOVA	{"email": "l.ivanova.17111966@postgrespro.ru", "phone": "+70597271903"}
0005432985269	409F68	4905 027255	YURIY NAZAROV	{"phone": "+70953807192"}
0005432985270	409F68	2606 968464	GULNARA FILIPPOVA	{"email": "gulnara_filippova-1970@postgrespro.ru", "phone": "+70721076541"}
0005432985271	48C3C3	8904 147058	YULIYA NIKOLAEVA	{"email": "ynikolaeva-1966@postgrespro.ru", "phone": "+70225304679"}
0005432985272	FA5A2A	7441 494898	ALEKSANDR KOZLOV	{"email": "kozlov.a_091965@postgrespro.ru", "phone": "+70031555604"}
0005432985273	FA5A2A	3178 075270	YURIY ISAEV	{"email": "isaev-y-011983@postgrespro.ru", "phone": "+70073662419"}
0005432985274	09EBDA	0354 911305	MARINA MAKAROVA	{"phone": "+70163586778"}
0005432985275	09EBDA	0193 246431	SERGEY ALEKSANDROV	{"phone": "+70704967939"}
0005432985276	09EBDA	4706 197799	IRAIDA POPOVA	{"email": "iraidapopova_1975@postgrespro.ru", "phone": "+70855627188"}
0005432985277	8AE3A1	6250 963407	VIKTOR EGOROV	{"email": "viktor.egorov-28011974@postgrespro.ru", "phone": "+70880481225"}
0005432985278	80A07B	0345 077642	ALEKSEY MELNIKOV	{"phone": "+70605670099"}
0005432985279	80A07B	4610 031882	VALENTIN KUZNECOV	{"email": "valentinkuznecov_111985@postgrespro.ru", "phone": "+70237783751"}
0005432985280	8629EF	2886 777974	VLADIMIR ROMANOV	{"email": "romanovv.19121973@postgrespro.ru", "phone": "+70304637328"}
0005432985281	8629EF	8224 526916	EVDOKIYA KOZLOVA	{"phone": "+70865270694"}
0005432985282	8629EF	5458 127255	DARYA ANDREEVA	{"phone": "+70551310690"}
0005432985283	802803	8920 842590	DIANA ISAEVA	{"email": "dianaisaeva_1975@postgrespro.ru", "phone": "+70022286581"}
0005432985284	B6B937	8114 259193	MARIYA SIDOROVA	{"email": "sidorovamariya021971@postgrespro.ru", "phone": "+70498810308"}
0005432985285	ADEACC	4652 033999	ARTEM FEDOROV	{"email": "fedorov_artem16041971@postgrespro.ru", "phone": "+70121404069"}
0005432985286	7925A0	4577 185233	RUSLAN ROMANOV	{"phone": "+70376121840"}
0005432985287	6F4E6D	6775 724965	YURIY YAKOVLEV	{"phone": "+70103861657"}
0005432985288	04795A	0539 785211	SERGEY NIKITIN	{"email": "snikitin-12041972@postgrespro.ru", "phone": "+70037837505"}
0005432985289	95B55F	4236 799860	NATALIYA IVANOVA	{"email": "n_ivanova.22111968@postgrespro.ru", "phone": "+70298340919"}
0005432985290	A115C2	9572 482395	VLADIMIR MATVEEV	{"email": "vladimir.matveev.1988@postgrespro.ru", "phone": "+70428038463"}
0005432985291	1DB7F4	4670 625037	MARINA FEDOROVA	{"phone": "+70206313643"}
0005432985292	2F3698	3568 777937	EKATERINA EFREMOVA	{"phone": "+70967249987"}
0005432985293	92344A	2167 077710	EKATERINA ROMANOVA	{"phone": "+70880026496"}
0005432985294	182009	2222 767231	DMITRIY MIKHAYLOV	{"email": "mikhaylov.d13081965@postgrespro.ru", "phone": "+70307982032"}
0005432985295	A991FD	9318 572335	VASILIY VOLKOV	{"phone": "+70277968501"}
0005432985296	169D88	7849 146003	OLGA BELOVA	{"email": "o.belova.111979@postgrespro.ru", "phone": "+70472042189"}
0005432985297	45F17B	1857 624591	ALEKSANDR VOROBEV	{"phone": "+70838332600"}
0005432985298	45F17B	9470 505255	ELENA DMITRIEVA	{"phone": "+70304636880"}
0005432985299	BF074B	9281 473918	EVGENIY POPOV	{"email": "popove051972@postgrespro.ru", "phone": "+70227525413"}
0005432985300	BF074B	8624 115833	ALEKSANDR SMIRNOV	{"phone": "+70653646749"}
0005432985301	E1C7A5	2284 632103	PAVEL KUZNECOV	{"phone": "+70003706394"}
0005432985302	9131F6	5990 938739	EVGENIYA POPOVA	{"email": "popova-evgeniya061976@postgrespro.ru", "phone": "+70045495895"}
0005432985303	F72C1E	5358 854938	DANILA KONOVALOV	{"email": "konovalov-danila-1966@postgrespro.ru", "phone": "+70938442990"}
0005432985304	F72C1E	6465 751977	ILYA MOROZOV	{"phone": "+70217926431"}
0005432985305	CCA93D	0524 427528	NATALYA IVANOVA	{"email": "nivanova.1970@postgrespro.ru", "phone": "+70163105492"}
0005432985306	CCA93D	2385 831134	ANATOLIY SERGEEV	{"email": "asergeev19051969@postgrespro.ru", "phone": "+70166787663"}
0005432985307	8D5132	6800 335972	ALEKSANDR GAVRILOV	{"email": "a_gavrilov011977@postgrespro.ru", "phone": "+70099960987"}
0005432985308	8D5132	1950 566240	NADEZHDA KOROLEVA	{"phone": "+70696844082"}
0005432985309	8D5132	1559 993258	GULNARA OVCHINNIKOVA	{"phone": "+70210177900"}
0005432985310	302F90	8561 492011	LEONID YAKOVLEV	{"phone": "+70857318140"}
0005432985311	A75E04	4967 003172	EKATERINA NIKOLAEVA	{"phone": "+70801810535"}
0005432985312	4C048E	3045 207211	MAKSIM GORBUNOV	{"email": "maksim_gorbunov.061974@postgrespro.ru", "phone": "+70055624407"}
0005432985313	9D351F	9323 125083	ELENA MELNIKOVA	{"email": "melnikova_e-1975@postgrespro.ru", "phone": "+70683916024"}
0005432985314	F57AE4	6598 479790	NATALYA LOGINOVA	{"phone": "+70830391009"}
0005432985315	93D88F	8543 834622	NATALYA DMITRIEVA	{"email": "dmitrievan-041976@postgrespro.ru", "phone": "+70904806455"}
0005432985316	93D88F	2227 192017	IRINA VOROBEVA	{"phone": "+70901256601"}
0005432985317	93D88F	0532 536901	ALEKSANDR SOROKIN	{"phone": "+70202906119"}
0005432985318	CFCD4D	8530 715700	VALERIY GUSEV	{"phone": "+70171033984"}
0005432985319	2403F9	9737 104931	OLGA ZAKHAROVA	{"email": "zakharova_o_1977@postgrespro.ru", "phone": "+70887725626"}
0005432985320	E0F3BF	4273 547719	TATYANA SCHERBAKOVA	{"phone": "+70442608695"}
0005432985321	E0F3BF	1559 927633	NIKOLAY FOMIN	{"phone": "+70824232261"}
0005432985322	BC0463	1872 445554	OLGA SOKOLOVA	{"email": "sokolovaolga_111969@postgrespro.ru", "phone": "+70888499517"}
0005432985323	BC0463	0219 896203	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin.111967@postgrespro.ru", "phone": "+70955472276"}
0005432985324	3C0BDF	0776 731303	ANATOLIY GRIGOREV	{"email": "grigorev_a.1983@postgrespro.ru", "phone": "+70542790257"}
0005432985325	3C0BDF	8128 970054	SVETLANA ZHUKOVA	{"phone": "+70946754125"}
0005432985326	E8EA10	9230 883079	GALINA BELOVA	{"phone": "+70936407458"}
0005432985327	E8EA10	5641 472077	PRASKOVYA BORISOVA	{"email": "praskovya_borisova1971@postgrespro.ru", "phone": "+70752800731"}
0005432985328	D8AB27	7910 359062	MIKHAIL KOROLEV	{"phone": "+70827454188"}
0005432985329	66F0AB	6612 151159	YURIY DENISOV	{"email": "denisov-y_1979@postgrespro.ru", "phone": "+70997753696"}
0005432985330	66F0AB	4834 443209	NATALYA ABRAMOVA	{"phone": "+70796706476"}
0005432985331	F432E6	9090 119002	MIKHAIL FROLOV	{"phone": "+70558653701"}
0005432985332	2A411B	1705 007404	NADIYA ALEKSANDROVA	{"email": "n-aleksandrova_1959@postgrespro.ru", "phone": "+70913682058"}
0005432985333	CA45E8	1663 041427	VALERIYA PETROVA	{"email": "v_petrova-1967@postgrespro.ru", "phone": "+70177576893"}
0005432985334	97AC28	4157 259044	YURIY MOISEEV	{"email": "moiseev-yuriy-1967@postgrespro.ru", "phone": "+70084069428"}
0005432985335	E97D79	5142 991989	IVAN NIKOLAEV	{"email": "nikolaev_i_111977@postgrespro.ru", "phone": "+70825909101"}
0005432985336	0CB46F	9235 461745	TATYANA POTAPOVA	{"email": "tatyana-potapova.011982@postgrespro.ru", "phone": "+70467086088"}
0005432985337	1C7275	9257 708172	DMITRIY SHEVCHENKO	{"email": "shevchenko-d1966@postgrespro.ru", "phone": "+70483362334"}
0005432985338	CC0D74	2297 308799	ELENA YAKOVLEVA	{"phone": "+70383926174"}
0005432985339	D52B79	0551 315927	TATYANA GORBUNOVA	{"phone": "+70177979776"}
0005432985340	AF3B4A	6011 052289	YURIY BORISOV	{"phone": "+70637366494"}
0005432985341	1442C1	0173 801732	NIKOLAY MOROZOV	{"email": "morozov-n_1977@postgrespro.ru", "phone": "+70948775663"}
0005432985342	1442C1	4820 506752	GALINA SOLOVEVA	{"phone": "+70510048401"}
0005432985343	3F8284	5187 408743	VALENTINA LAZAREVA	{"phone": "+70858652466"}
0005432985344	B9AABF	6512 350125	OKSANA GRISHINA	{"email": "grishina_oksana081973@postgrespro.ru", "phone": "+70219663096"}
0005432985345	FEF5F1	5041 252705	MAKSIM MIRONOV	{"phone": "+70024992650"}
0005432985346	FEF5F1	8715 006775	ANTONINA YAKOVLEVA	{"email": "antoninayakovleva-121963@postgrespro.ru", "phone": "+70614455594"}
0005432985347	FEF5F1	2530 324449	MAYA MAKAROVA	{"email": "m_makarova12121973@postgrespro.ru", "phone": "+70965300627"}
0005432985348	CFF67C	7159 882146	IVAN MOROZOV	{"email": "morozovi1970@postgrespro.ru", "phone": "+70192977994"}
0005432985349	21568D	5275 065727	ALEKSANDR IVANOV	{"email": "ivanov-a.17021973@postgrespro.ru", "phone": "+70818549557"}
0005432985350	76E368	2655 895309	ANNA AFANASEVA	{"email": "afanaseva_a_031975@postgrespro.ru", "phone": "+70358451071"}
0005432985351	6E8B25	3759 423502	VALERIY MAKSIMOV	{"phone": "+70605611551"}
0005432985352	92D8B3	7434 862388	ULYANA KUDRYASHOVA	{"phone": "+70382729743"}
0005432985353	54CF42	8852 647013	EKATERINA POTAPOVA	{"phone": "+70911241790"}
0005432985354	8574C8	2156 163026	TATYANA KOZLOVA	{"phone": "+70593276942"}
0005432985355	D2C0E6	5185 703419	ANDREY BORISOV	{"phone": "+70913236875"}
0005432985356	D2C0E6	9524 727500	SERGEY ZAKHAROV	{"phone": "+70847719706"}
0005432985357	A317C4	6616 613429	DMITRIY FILIPPOV	{"phone": "+70392300689"}
0005432985358	A317C4	9646 836092	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr_12031972@postgrespro.ru", "phone": "+70318004853"}
0005432985359	2B879A	0390 222366	GALINA SERGEEVA	{"email": "galina.sergeeva-1978@postgrespro.ru", "phone": "+70612275964"}
0005432985360	C98E3C	9715 900047	POLINA BOGDANOVA	{"phone": "+70934659106"}
0005432985361	C98E3C	2747 499132	IGOR TIKHONOV	{"phone": "+70309904410"}
0005432985362	B8C174	9583 799809	ALEKSANDR FILIPPOV	{"phone": "+70703437141"}
0005432985363	263921	9010 804339	YURIY DENISOV	{"phone": "+70834216475"}
0005432985364	A5057D	5890 200075	FEDOR NIKITIN	{"phone": "+70923801862"}
0005432985365	F7B2EE	4459 291658	ILDAR RODIONOV	{"email": "ildarrodionov-19021973@postgrespro.ru", "phone": "+70337517730"}
0005432985366	A68E9C	4030 293215	ELIZAVETA FILATOVA	{"email": "filatovae_091968@postgrespro.ru", "phone": "+70713775248"}
0005432985367	D5952B	3358 143594	NIKOLAY MOISEEV	{"email": "moiseev.n-1973@postgrespro.ru", "phone": "+70590985209"}
0005432985368	D5952B	2558 405989	SERGEY KONOVALOV	{"email": "konovalov-s.101974@postgrespro.ru", "phone": "+70182636918"}
0005432985369	B4BB54	7264 198803	KLAVDIYA PETROVA	{"phone": "+70210489542"}
0005432985370	B4BB54	6915 291287	SVETLANA MAKAROVA	{"phone": "+70035909664"}
0005432985371	B4BB54	3981 516007	MARIANNA VASILEVA	{"email": "vasilevam_041971@postgrespro.ru", "phone": "+70033839172"}
0005432985372	5CD07D	8150 343249	NAILYA POLYAKOVA	{"phone": "+70452303210"}
0005432985373	9B77F0	0453 499587	ROMAN IVANOV	{"email": "roman.ivanov.17051970@postgrespro.ru", "phone": "+70103688086"}
0005432985374	B75704	7625 450710	ALEKSEY KOROLEV	{"email": "a-korolev071969@postgrespro.ru", "phone": "+70442967251"}
0005432985375	417764	6552 323200	ANASTASIYA VLASOVA	{"email": "avlasova031961@postgrespro.ru", "phone": "+70275034142"}
0005432985376	0A99B9	1237 316099	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr-051972@postgrespro.ru", "phone": "+70977610897"}
0005432985377	0A99B9	1756 630274	VALENTINA PAVLOVA	{"phone": "+70623815085"}
0005432985378	661D01	9826 855522	TATYANA SMIRNOVA	{"email": "smirnova.t.011979@postgrespro.ru", "phone": "+70178086295"}
0005432985379	044E05	6744 884301	LYUDMILA ANISIMOVA	{"email": "l.anisimova_1983@postgrespro.ru", "phone": "+70769879720"}
0005432985380	2CB469	8969 047363	SVETLANA BELYAEVA	{"email": "svetlana-belyaeva_081978@postgrespro.ru", "phone": "+70068968526"}
0005432985381	2CB469	0186 069931	VALENTINA KALININA	{"email": "v-kalinina.24091967@postgrespro.ru", "phone": "+70395241852"}
0005432985382	A5F20C	9555 402998	YULIYA MASLOVA	{"phone": "+70504361303"}
0005432985383	20F95B	8620 964624	VERA KONOVALOVA	{"phone": "+70660204203"}
0005432985384	20F95B	0269 636895	ELENA KRASNOVA	{"email": "e.krasnova10091969@postgrespro.ru", "phone": "+70716443764"}
0005432985385	20F95B	7604 176331	SERGEY STEPANOV	{"email": "stepanovsergey_04051973@postgrespro.ru", "phone": "+70985341149"}
0005432985386	5BCC59	4505 626969	TATYANA SEMENOVA	{"email": "semenova_t.17051970@postgrespro.ru", "phone": "+70606546983"}
0005432985387	5BCC59	9668 361751	ANDREY DENISOV	{"email": "a_denisov-041976@postgrespro.ru", "phone": "+70605566781"}
0005432985388	3DE8CB	8591 655242	LYUDMILA BARANOVA	{"email": "lyudmila-baranova-28061974@postgrespro.ru", "phone": "+70201584733"}
0005432985389	626FAE	3253 320645	ANATOLIY SEMENOV	{"phone": "+70359859420"}
0005432985390	626FAE	0161 751431	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev_01081974@postgrespro.ru", "phone": "+70350250462"}
0005432985391	06CC78	5735 425998	ALEKSANDRA KISELEVA	{"email": "kiseleva.a-1967@postgrespro.ru", "phone": "+70507028689"}
0005432985392	06CC78	3875 978513	ALEKSANDRA KOROLEVA	{"phone": "+70966234800"}
0005432985393	7D2C4A	5095 132534	SVETLANA MEDVEDEVA	{"email": "medvedeva.svetlana-1971@postgrespro.ru", "phone": "+70942402891"}
0005432985394	7D2C4A	1902 156576	VALERIY MELNIKOV	{"phone": "+70947914527"}
0005432985453	2A4599	9617 993306	EVGENIYA ABRAMOVA	{"phone": "+70963494207"}
0005432985395	BCC4DE	2966 391304	ALEKSANDR ORLOV	{"email": "orlov-aleksandr-07061984@postgrespro.ru", "phone": "+70069112269"}
0005432985396	8ECD68	2182 010205	MARIYA GORBUNOVA	{"email": "m.gorbunova.1964@postgrespro.ru", "phone": "+70168773319"}
0005432985397	85C753	2771 623517	NATALYA KISELEVA	{"phone": "+70328467670"}
0005432985398	85C753	2505 141387	VLADIMIR GORBUNOV	{"phone": "+70031367350"}
0005432985399	2E59C9	2724 881274	ALEKSANDR KULIKOV	{"email": "kulikova.07041965@postgrespro.ru", "phone": "+70845728446"}
0005432985400	2E59C9	7619 425292	VIKTOR SERGEEV	{"phone": "+70854159620"}
0005432985401	96D530	8586 231428	BOGDAN IVANOV	{"phone": "+70916300846"}
0005432985402	D0C648	4992 104604	ELENA MAKAROVA	{"email": "makarova_elena081973@postgrespro.ru", "phone": "+70337488387"}
0005432985403	C05752	1060 066674	BORIS PAVLOV	{"email": "b.pavlov_1971@postgrespro.ru", "phone": "+70464170673"}
0005432985404	C05752	9908 100999	ALEKSANDR VOROBEV	{"email": "vorobev-a-031972@postgrespro.ru", "phone": "+70602443365"}
0005432985405	A22199	1707 363441	OLESYA ANISIMOVA	{"phone": "+70912197639"}
0005432985406	4E7C45	9096 834416	LYUBOV TROFIMOVA	{"email": "trofimoval-01111974@postgrespro.ru", "phone": "+70590760987"}
0005432985407	A2CB4C	8567 169479	OLGA LEBEDEVA	{"phone": "+70671636982"}
0005432985408	C3366C	6429 891066	NATALYA MEDVEDEVA	{"email": "natalyamedvedeva-111976@postgrespro.ru", "phone": "+70880191352"}
0005432985409	F0ADF7	3535 244640	ARINA MIRONOVA	{"phone": "+70023544300"}
0005432985410	A12945	1936 723632	NATALYA ARKHIPOVA	{"email": "arkhipova_natalya_1966@postgrespro.ru", "phone": "+70272918099"}
0005432985411	5A4B98	4101 717827	NATALIYA ZHURAVLEVA	{"email": "zhuravlevanataliya09111971@postgrespro.ru", "phone": "+70264310900"}
0005432985412	B6AC1B	8616 349492	SOFYA CHERNOVA	{"phone": "+70153690778"}
0005432985413	B6AC1B	9212 015338	NIKITA SEMENOV	{"email": "semenov-n.101979@postgrespro.ru", "phone": "+70785161518"}
0005432985414	AC5340	6950 932823	VITALIY NIKITIN	{"email": "nikitin_vitaliy_06081971@postgrespro.ru", "phone": "+70363275353"}
0005432985415	D92E01	5900 469545	DMITRIY KARPOV	{"email": "d_karpov.28041963@postgrespro.ru", "phone": "+70543820452"}
0005432985416	D92E01	6635 696527	VALENTINA FOMINA	{"email": "v_fomina13031975@postgrespro.ru", "phone": "+70001036081"}
0005432985417	1DD573	3750 018029	OLGA PETROVA	{"email": "opetrova15051975@postgrespro.ru", "phone": "+70624445392"}
0005432985418	4A86E8	9695 874409	VALENTIN GUSEV	{"email": "v-gusev_23031974@postgrespro.ru", "phone": "+70837727497"}
0005432985419	4A86E8	7273 913392	VLADIMIR GORBUNOV	{"phone": "+70533959721"}
0005432985420	4A86E8	2579 983069	VIKTORIYA IVANOVA	{"email": "v_ivanova01111965@postgrespro.ru", "phone": "+70249827307"}
0005432985421	594694	3069 309263	SVETLANA VASILEVA	{"phone": "+70672203188"}
0005432985424	E89F80	1952 688175	DARYA MAKAROVA	{"email": "darya_makarova12041966@postgrespro.ru", "phone": "+70695636302"}
0005432985425	E89F80	5780 295301	DENIS DENISOV	{"email": "denisovdenis_091983@postgrespro.ru", "phone": "+70645475769"}
0005432985426	EED9D0	2238 794393	LYUDMILA BELOVA	{"phone": "+70647606802"}
0005432985427	50E33E	9818 815653	ROMAN MIKHAYLOV	{"phone": "+70281350424"}
0005432985428	814F65	2021 068619	ALEKSANDR SEMENOV	{"phone": "+70595807136"}
0005432985489	EC28F7	1917 689603	SERGEY KUZNECOV	{"phone": "+70843924969"}
0005432985429	0DB3CA	5354 877677	MARINA MOROZOVA	{"email": "marinamorozova.1974@postgrespro.ru", "phone": "+70075543672"}
0005432985430	7982AF	7921 807346	ANDREY EGOROV	{"phone": "+70045102768"}
0005432985431	855480	1324 239169	MARINA KALININA	{"phone": "+70921193310"}
0005432985432	855480	6760 909313	ANASTASIYA MARTYNOVA	{"phone": "+70862095231"}
0005432985433	8F00CB	1741 560337	RENAT BORISOV	{"email": "renat-borisov09121975@postgrespro.ru", "phone": "+70760751962"}
0005432985434	2FAF09	9391 831076	ZHANNA NOVIKOVA	{"email": "z_novikova.041969@postgrespro.ru", "phone": "+70829302636"}
0005432985435	4D5837	3527 532053	EGOR GUSEV	{"email": "egor-gusev_121969@postgrespro.ru", "phone": "+70358924839"}
0005432985436	4D5837	0386 227928	ILNUR ZHUKOV	{"email": "i.zhukov111981@postgrespro.ru", "phone": "+70288476375"}
0005432985437	253EFC	0933 044647	IRINA BARANOVA	{"phone": "+70690266077"}
0005432985438	B8C41F	4589 313118	ELENA TIKHONOVA	{"email": "tikhonovae.121984@postgrespro.ru", "phone": "+70655759240"}
0005432985439	FF62CA	9871 766417	EKATERINA PETROVA	{"phone": "+70354696864"}
0005432985440	0B0913	7829 097594	TAMARA ANTONOVA	{"email": "tamaraantonova-091975@postgrespro.ru", "phone": "+70728276248"}
0005432985441	4EAABE	4645 703969	NIKOLAY IVANOV	{"email": "n.ivanov1980@postgrespro.ru", "phone": "+70710325779"}
0005432985442	E0AF87	3369 096685	LYUDMILA SOROKINA	{"phone": "+70767333513"}
0005432985443	9E5E4D	9056 227267	SEMEN OSIPOV	{"email": "osipov_semen.1970@postgrespro.ru", "phone": "+70425532799"}
0005432985444	7E80F9	2274 714650	IGOR ANDREEV	{"email": "andreev_igor_111974@postgrespro.ru", "phone": "+70710829424"}
0005432985445	CCAF54	1652 912955	OLEG FEDOROV	{"email": "fedorov.o_28031972@postgrespro.ru", "phone": "+70007618090"}
0005432985446	1F3086	1363 109906	LILIYA RYABOVA	{"email": "ryabova.liliya_1973@postgrespro.ru", "phone": "+70888347157"}
0005432985447	1F3086	9663 408577	ILYA GERASIMOV	{"phone": "+70242058896"}
0005432985448	2B9ACF	1399 425588	VIKTORIYA ALEKSANDROVA	{"email": "viktoriyaaleksandrova-1967@postgrespro.ru", "phone": "+70592571964"}
0005432985449	2B9ACF	1310 001635	KONSTANTIN PETROV	{"phone": "+70793464549"}
0005432985450	3519A7	1637 626566	LYUBOV RYABOVA	{"phone": "+70158202137"}
0005432985451	855A39	6179 830797	LYUDMILA MIKHAYLOVA	{"phone": "+70678109664"}
0005432985452	2E3138	0123 909985	ALINA KOMAROVA	{"phone": "+70592623265"}
0005432985454	F3B361	7800 130007	OLGA KUZNECOVA	{"phone": "+70144401685"}
0005432985455	F3B361	6466 569202	PAVEL ANDREEV	{"email": "pavel_andreev121969@postgrespro.ru", "phone": "+70762962393"}
0005432985456	F3C4BC	2093 563340	ALEKSEY MAKSIMOV	{"email": "amaksimov_041980@postgrespro.ru", "phone": "+70129046610"}
0005432985457	F3C4BC	5544 903671	NINA IVANOVA	{"email": "ivanova-n.1974@postgrespro.ru", "phone": "+70470964332"}
0005432985458	F3C4BC	5013 493477	EKATERINA SOROKINA	{"email": "e_sorokina_16061968@postgrespro.ru", "phone": "+70286274787"}
0005432985459	87D0AD	0188 303305	SERGEY KUZNECOV	{"email": "sergey_kuznecov-11091971@postgrespro.ru", "phone": "+70743595560"}
0005432985460	87D0AD	3568 275793	EKATERINA FROLOVA	{"phone": "+70777661929"}
0005432985461	87D0AD	6941 401875	LYUBOV DANILOVA	{"phone": "+70630666003"}
0005432985462	87D0AD	0301 356104	GALINA FILIPPOVA	{"email": "filippova.g_04011985@postgrespro.ru", "phone": "+70575757860"}
0005432985463	E86A22	2562 220887	ALEKSANDR EGOROV	{"email": "egorov-aleksandr29091980@postgrespro.ru", "phone": "+70124566033"}
0005432985464	73AC5D	9998 895900	POLINA GORBUNOVA	{"phone": "+70867202653"}
0005432985465	523580	7251 668239	IVAN GERASIMOV	{"email": "i.gerasimov.091978@postgrespro.ru", "phone": "+70799720723"}
0005432985466	50E807	2139 549350	NAIL YAKOVLEV	{"email": "yakovlev.n1968@postgrespro.ru", "phone": "+70138719303"}
0005432985467	50E807	9790 508377	ALEKSANDR KRASNOV	{"email": "krasnov.a-1967@postgrespro.ru", "phone": "+70627051864"}
0005432985468	91331D	3569 927014	IRINA SEMENOVA	{"email": "semenova-irina-1972@postgrespro.ru", "phone": "+70908935348"}
0005432985469	4609B9	5417 280803	SEMEN ZAKHAROV	{"phone": "+70306874843"}
0005432985470	4609B9	5198 079164	NATALYA PAVLOVA	{"email": "npavlova.111979@postgrespro.ru", "phone": "+70040211310"}
0005432985471	6B444C	3960 050889	VYACHESLAV ALEKSEEV	{"phone": "+70067000370"}
0005432985472	10BC74	6899 685298	NATALYA FEDOROVA	{"email": "natalyafedorova.1959@postgrespro.ru", "phone": "+70645409198"}
0005432985473	10BC74	5276 290580	DMITRIY KARPOV	{"phone": "+70717497627"}
0005432985474	135398	4702 387506	EKATERINA ROMANOVA	{"phone": "+70759528072"}
0005432985475	135398	6769 815117	LIDIYA ALEKSEEVA	{"email": "alekseeva-lidiya.1973@postgrespro.ru", "phone": "+70006482118"}
0005432985476	0850F9	1931 362583	STANISLAV ANDREEV	{"phone": "+70968418189"}
0005432985477	35D18D	5816 177681	LYUBOV TARASOVA	{"phone": "+70893703095"}
0005432985478	35D18D	6114 317566	ELENA TROFIMOVA	{"email": "trofimova_elena-101966@postgrespro.ru", "phone": "+70019397618"}
0005432985479	06543A	9089 486426	NIKOLAY NOVIKOV	{"phone": "+70989546885"}
0005432985480	D0AEEB	1428 216485	TATYANA ZHUKOVA	{"email": "zhukovatatyana.021970@postgrespro.ru", "phone": "+70213063442"}
0005432985481	CB5DDB	0239 669704	NINA KOROLEVA	{"email": "koroleva.nina.091960@postgrespro.ru", "phone": "+70807826893"}
0005432985482	5A9D6C	0371 616359	ALEKSANDRA FROLOVA	{"email": "afrolova-121980@postgrespro.ru", "phone": "+70474864280"}
0005432985483	3CC1A9	2649 139038	ANDREY CHERNOV	{"email": "andrey.chernov30041969@postgrespro.ru", "phone": "+70113953089"}
0005432985484	DEFF46	0957 725536	MATVEY NIKITIN	{"phone": "+70685352881"}
0005432985485	1D4F0A	0906 459200	OLEG BARANOV	{"email": "baranov_o_071962@postgrespro.ru", "phone": "+70706194737"}
0005432985486	9050BF	9727 579376	YULIYA FEDOROVA	{"phone": "+70622432966"}
0005432985487	9050BF	0779 842689	NIKOLAY IVANOV	{"email": "ivanov.nikolay_061974@postgrespro.ru", "phone": "+70994763651"}
0005432985488	2D113F	2026 722831	ARTEM BORISOV	{"phone": "+70299128621"}
0005432985490	41F8D4	6759 083394	MAKSIM YAKOVLEV	{"email": "maksimyakovlev_021954@postgrespro.ru", "phone": "+70077776583"}
0005432985491	41F8D4	0137 954812	SERGEY GERASIMOV	{"phone": "+70034132365"}
0005432985492	F3CCA3	5946 158027	YURIY FILIPPOV	{"phone": "+70630230987"}
0005432985493	F3CCA3	9824 222188	SVETLANA GAVRILOVA	{"email": "gavrilova_s29091970@postgrespro.ru", "phone": "+70561952604"}
0005432985494	F3CCA3	7645 287373	TATYANA NOVIKOVA	{"phone": "+70333470982"}
0005432985495	29A7CE	9420 599545	IGOR DAVYDOV	{"email": "davydov_i.031974@postgrespro.ru", "phone": "+70406270728"}
0005432985496	29A7CE	0226 896630	SERGEY KUZMIN	{"email": "sergey_kuzmin.1964@postgrespro.ru", "phone": "+70544689766"}
0005432985497	29A7CE	2485 106485	ALEKSEY FEDOROV	{"phone": "+70161342762"}
0005432985498	202026	8399 981808	IVAN AFANASEV	{"phone": "+70376014864"}
0005432985499	6EDC14	1481 484614	EVGENIY YAKOVLEV	{"email": "yakovlev.e.061968@postgrespro.ru", "phone": "+70158597699"}
0005432985500	8F9B7F	0458 794698	ALEKSANDRA VOLKOVA	{"phone": "+70101292304"}
0005432985501	8F9B7F	6809 518316	OLESYA NAUMOVA	{"phone": "+70596384212"}
0005432985502	15C07B	4764 897966	KRISTINA IVANOVA	{"phone": "+70665397532"}
0005432985503	F32716	1651 505446	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov011964@postgrespro.ru", "phone": "+70969658829"}
0005432985504	F32716	5296 596186	VLADISLAV ABRAMOV	{"phone": "+70432230560"}
0005432985505	F32716	4243 297157	ALEKSANDR KOROLEV	{"phone": "+70461232706"}
0005432985506	F32716	4266 756790	VLADIMIR BORISOV	{"email": "borisov-vladimir.25071969@postgrespro.ru", "phone": "+70589389429"}
0005432985507	C29488	3017 004309	ANTONINA VASILEVA	{"phone": "+70703445314"}
0005432985508	684CDA	4441 238375	ZHANNA ERMAKOVA	{"phone": "+70643492011"}
0005432985509	3128E6	2590 578995	LYUDMILA TITOVA	{"phone": "+70858984339"}
0005432985510	5CA11D	8546 117216	SERGEY SEMENOV	{"phone": "+70852127265"}
0005432985511	CF7167	6963 311798	ALEKSANDRA SOROKINA	{"email": "a-sorokina_10111969@postgrespro.ru", "phone": "+70493848298"}
0005432985512	5ECF30	5204 334489	TATYANA ARKHIPOVA	{"phone": "+70484788186"}
0005432985513	5ECF30	4512 379547	KIRILL KRASNOV	{"email": "krasnov.k.19061971@postgrespro.ru", "phone": "+70120442909"}
0005432985514	5A44D1	0785 860999	OLGA SOROKINA	{"phone": "+70516004918"}
0005432985515	287DF7	8687 897882	IRINA NIKITINA	{"email": "irina.nikitina-11021983@postgrespro.ru", "phone": "+70389416748"}
0005432985516	793E41	0468 712393	YULIYA NAZAROVA	{"phone": "+70119654274"}
0005432985517	AA20BB	8042 668541	OLGA KUZNECOVA	{"phone": "+70777913093"}
0005432985518	16A686	7731 046698	YULIYA NAZAROVA	{"phone": "+70678291421"}
0005432985519	13C20B	2426 567924	MARIYA MASLOVA	{"email": "maslova-m_1969@postgrespro.ru", "phone": "+70319088191"}
0005432985520	D4FEB7	1444 158410	NADEZHDA MOROZOVA	{"email": "nadezhdamorozova.09071976@postgrespro.ru", "phone": "+70885261343"}
0005432985521	B90311	8312 190650	YURIY KUZNECOV	{"phone": "+70948044532"}
0005432985522	B90311	9163 469243	ILYA ISAEV	{"phone": "+70189350812"}
0005432985523	47B539	3494 514852	VLADIMIR SIDOROV	{"email": "vladimir.sidorov.1973@postgrespro.ru", "phone": "+70784627984"}
0005432985524	47B539	5427 143749	ALEKSANDR KONOVALOV	{"phone": "+70261105241"}
0005432985525	24168A	1544 499469	GALINA SEMENOVA	{"phone": "+70602771520"}
0005432985526	47D4B0	4028 666368	AMIR EGOROV	{"email": "egorovamir_041956@postgrespro.ru", "phone": "+70432494244"}
0005432985527	47D4B0	1284 460164	ARTEM EGOROV	{"phone": "+70219516884"}
0005432985528	F69FE8	8558 463583	FEDOR SERGEEV	{"email": "sergeev_fedor-1979@postgrespro.ru", "phone": "+70927502127"}
0005432985529	FE9A92	6023 091116	OLGA KUZNECOVA	{"phone": "+70185298814"}
0005432985530	FE9A92	8365 155678	EVGENIY SEMENOV	{"phone": "+70304571026"}
0005432985531	BB1786	4491 076989	ALEKSANDRA DENISOVA	{"phone": "+70059190837"}
0005432985532	38AF5F	6768 599827	EKATERINA ZAYCEVA	{"phone": "+70820832804"}
0005432985533	E15335	7807 012613	VALENTINA NOVIKOVA	{"phone": "+70475891333"}
0005432985534	744215	8778 900963	ELIZAVETA PAVLOVA	{"phone": "+70431538190"}
0005432985535	744215	6259 740822	OLGA ERMAKOVA	{"email": "o.ermakova1972@postgrespro.ru", "phone": "+70255432800"}
0005432985536	D1CB10	6305 904381	OLGA DANILOVA	{"phone": "+70541175543"}
0005432985537	E982AE	4375 305103	LYUBOV SOLOVEVA	{"email": "lyubov-soloveva_1980@postgrespro.ru", "phone": "+70136491343"}
0005432985538	3C1672	9698 543903	OLGA ALEKSEEVA	{"phone": "+70297369331"}
0005432985539	F40FDC	3340 453329	SERGEY IVANOV	{"email": "sergeyivanov1983@postgrespro.ru", "phone": "+70003106151"}
0005432985540	856886	6030 811452	ELENA MELNIKOVA	{"phone": "+70754893657"}
0005432985541	162E21	7425 411728	EVGENIYA SERGEEVA	{"phone": "+70693765666"}
0005432985542	162E21	4614 514414	EDUARD MAKAROV	{"phone": "+70186456293"}
0005432985543	A99749	7501 296821	NATALYA ALEKSANDROVA	{"email": "aleksandrova_natalya.121969@postgrespro.ru", "phone": "+70695580809"}
0005432985544	A99749	7263 781530	OLGA GERASIMOVA	{"email": "olga-gerasimova1982@postgrespro.ru", "phone": "+70276084911"}
0005432985545	6CF151	7803 851218	RUSLAN AFANASEV	{"email": "ruslanafanasev.1974@postgrespro.ru", "phone": "+70108068023"}
0005432985546	31C9F0	4524 913105	MAKSIM SMIRNOV	{"phone": "+70230849047"}
0005432985547	6D24A5	3358 384820	ALEKSANDR AFANASEV	{"phone": "+70167427574"}
0005432985548	99C109	9413 811405	ARTEM KULIKOV	{"email": "kulikov.artem-081965@postgrespro.ru", "phone": "+70658639413"}
0005432985549	0B5A44	7032 739047	SVETLANA DMITRIEVA	{"phone": "+70991229974"}
0005432985550	0A5646	6507 766590	GALINA TIKHONOVA	{"email": "g-tikhonova_11081975@postgrespro.ru", "phone": "+70453070982"}
0005432985551	733657	2299 734745	SERGEY ZAYCEV	{"phone": "+70271654821"}
0005432985552	99BC99	6259 085034	VALERIY MIRONOV	{"email": "mironov.valeriy.1972@postgrespro.ru", "phone": "+70791465733"}
0005432985553	FBA211	2910 697579	IVAN DENISOV	{"email": "denisov-i_1956@postgrespro.ru", "phone": "+70171350671"}
0005432985554	E97F64	3950 564153	ALEKSANDR KRASNOV	{"email": "aleksandr_krasnov-1972@postgrespro.ru", "phone": "+70805693257"}
0005432985555	422F0F	7949 177130	YULIYA SERGEEVA	{"email": "sergeeva.yuliya-1967@postgrespro.ru", "phone": "+70885408481"}
0005432985556	3624CE	4345 464454	DANIIL MAKAROV	{"phone": "+70069111257"}
0005432985557	3624CE	8769 213961	LIDIYA FEDOROVA	{"phone": "+70767924759"}
0005432985558	FBFC77	9108 108254	OLEG GUSEV	{"email": "ogusev_061973@postgrespro.ru", "phone": "+70945332072"}
0005432985559	5A7451	4471 479307	ANZHELIKA KOVALEVA	{"phone": "+70841519409"}
0005432985560	EB899E	2248 503983	ANASTASIYA MAKAROVA	{"email": "a-makarova-111969@postgrespro.ru", "phone": "+70221064059"}
0005432985561	EB899E	9905 323495	EKATERINA KUZNECOVA	{"email": "ekaterina.kuznecova_1974@postgrespro.ru", "phone": "+70199321767"}
0005432985562	329E8B	9127 567898	ANNA TIKHONOVA	{"email": "a-tikhonova_1971@postgrespro.ru", "phone": "+70517339444"}
0005432985563	7A284C	8054 742896	NIKOLAY MAKAROV	{"email": "nmakarov21111963@postgrespro.ru", "phone": "+70758436074"}
0005432985564	1208D9	7049 443979	LYUBOV IVANOVA	{"email": "ivanova_lyubov_1970@postgrespro.ru", "phone": "+70538800789"}
0005432985565	1208D9	3756 744903	ANASTASIYA BELOVA	{"phone": "+70931704388"}
0005432985676	A026C2	1605 092304	ANNA VASILEVA	{"phone": "+70115384108"}
0005432985566	57EBFB	6386 861733	YURIY MATVEEV	{"email": "matveevyuriy.31051980@postgrespro.ru", "phone": "+70734284650"}
0005432985567	57EBFB	7145 347457	PAVEL ZAKHAROV	{"phone": "+70288994747"}
0005432985568	F68D59	3627 199966	GALINA KALININA	{"email": "kalininagalina1985@postgrespro.ru", "phone": "+70401649695"}
0005432985569	F68D59	6139 639362	ANNA ANISIMOVA	{"email": "anna-anisimova.19051976@postgrespro.ru", "phone": "+70036499362"}
0005432985570	01AD26	1967 949527	NIKOLAY TIMOFEEV	{"email": "timofeev_n1968@postgrespro.ru", "phone": "+70580463171"}
0005432985571	01AD26	9618 171159	KSENIYA MATVEEVA	{"email": "matveevakseniya.02091975@postgrespro.ru", "phone": "+70552111909"}
0005432985572	8B5B33	1306 836149	VITALIY MATVEEV	{"phone": "+70584205722"}
0005432985573	AF1E7C	1883 270096	TAMARA EFREMOVA	{"phone": "+70957414903"}
0005432985574	215545	8752 871818	DARYA KUDRYASHOVA	{"phone": "+70080212998"}
0005432985575	4C15F2	7433 970995	OLGA PETROVA	{"phone": "+70709667641"}
0005432985576	192D7E	3781 913265	VLADIMIR ZHUKOV	{"phone": "+70619613967"}
0005432985577	192D7E	3442 692946	VLADIMIR MELNIKOV	{"phone": "+70636192391"}
0005432985578	93C7C8	1507 361044	ALEKSEY FOMIN	{"phone": "+70614039788"}
0005432985579	2E904B	8604 011116	DMITRIY POPOV	{"email": "d-popov081968@postgrespro.ru", "phone": "+70632248326"}
0005432985580	B37504	5056 087891	OLEG KOROLEV	{"email": "korolev.o.09011968@postgrespro.ru", "phone": "+70377460343"}
0005432985581	B37504	4125 952255	VALENTINA MARTYNOVA	{"phone": "+70093785401"}
0005432985582	12D1E3	4709 360458	ARINA EFREMOVA	{"email": "efremovaarina_1963@postgrespro.ru", "phone": "+70370655145"}
0005432985583	DEE408	2418 790617	MIKHAIL BORISOV	{"email": "mborisov.27111958@postgrespro.ru", "phone": "+70596577836"}
0005432985584	DEE408	5301 485453	KSENIYA DMITRIEVA	{"phone": "+70015585125"}
0005432985585	368B9C	1113 736806	EKATERINA NIKITINA	{"email": "nikitina-ekaterina-071975@postgrespro.ru", "phone": "+70070140793"}
0005432985586	82B4D6	3084 107638	VALERIYA FILATOVA	{"email": "filatova-v_061981@postgrespro.ru", "phone": "+70641279829"}
0005432985587	82B4D6	7999 551712	OLEG SCHERBAKOV	{"email": "oleg.scherbakov-041967@postgrespro.ru", "phone": "+70934400974"}
0005432985588	82B4D6	1875 629520	NINA EFIMOVA	{"phone": "+70487707587"}
0005432985589	981DD7	9901 792221	ANASTASIYA IVANOVA	{"email": "ivanova-a.26101970@postgrespro.ru", "phone": "+70860511367"}
0005432985590	785651	2553 836454	ANASTASIYA NIKOLAEVA	{"phone": "+70477472026"}
0005432985591	39CCC0	2104 041745	VIKTOR KUZNECOV	{"email": "viktor_kuznecov.18041976@postgrespro.ru", "phone": "+70613482204"}
0005432985592	39CCC0	7384 954069	TATYANA ZOTOVA	{"phone": "+70710251379"}
0005432985593	AFD6D6	5914 373003	NATALYA ZHUKOVA	{"email": "zhukova.n1984@postgrespro.ru", "phone": "+70391475016"}
0005432985594	4E4249	4185 074208	ANDREY ISAEV	{"email": "isaev_andrey.13051983@postgrespro.ru", "phone": "+70647355538"}
0005432985595	4E4249	7802 035146	YULIYA FEDOROVA	{"email": "yuliya-fedorova.1964@postgrespro.ru", "phone": "+70447688392"}
0005432985596	599487	5278 883079	MARGARITA KOZLOVA	{"email": "margarita_kozlova-101976@postgrespro.ru", "phone": "+70467484137"}
0005432985597	773253	3535 905429	ANNA ZAYCEVA	{"phone": "+70129768492"}
0005432985598	8795D7	0579 225513	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov091980@postgrespro.ru", "phone": "+70927938454"}
0005432985599	8795D7	9749 446813	NIKOLAY DENISOV	{"email": "n_denisov1974@postgrespro.ru", "phone": "+70861458739"}
0005432985600	A76A49	2658 396979	SVETLANA KAZAKOVA	{"email": "kazakovasvetlana25121962@postgrespro.ru", "phone": "+70706184872"}
0005432985601	48E264	2435 021865	VASILIY EGOROV	{"phone": "+70752402219"}
0005432985602	864E3D	9818 504269	ALEKSEY ABRAMOV	{"email": "abramov-a-1977@postgrespro.ru", "phone": "+70081925075"}
0005432985603	864E3D	6956 426870	GENNADIY YAKOVLEV	{"email": "gennadiy_yakovlev071972@postgrespro.ru", "phone": "+70638229574"}
0005432985604	864E3D	1871 300073	ANNA IVANOVA	{"phone": "+70316135200"}
0005432985605	A9D2A9	6274 690582	VALERIY IVANOV	{"phone": "+70868053906"}
0005432985606	C72C3A	6539 848358	VALENTINA PAVLOVA	{"email": "pavlova.v.09081971@postgrespro.ru", "phone": "+70564392123"}
0005432985607	5CB294	0999 149469	ZARINA SEMENOVA	{"email": "semenovaz_22081978@postgrespro.ru", "phone": "+70497804294"}
0005432985608	44E764	6646 154979	TATYANA DAVYDOVA	{"phone": "+70314364977"}
0005432985609	6D94FF	8019 152582	LYUBOV GERASIMOVA	{"email": "gerasimova_lyubov_1962@postgrespro.ru", "phone": "+70371651493"}
0005432985610	517D7D	3130 965957	DMITRIY MIRONOV	{"email": "d.mironov_011968@postgrespro.ru", "phone": "+70480932695"}
0005432985611	E6603D	8823 885036	ANZHELIKA FROLOVA	{"phone": "+70618493016"}
0005432985612	9F0071	2008 093436	MIKHAIL FILIPPOV	{"email": "filippov_m-28031980@postgrespro.ru", "phone": "+70441902430"}
0005432985613	00F3D2	9887 712517	ELENA FEDOROVA	{"phone": "+70256239943"}
0005432985614	4C395F	4649 090511	DMITRIY AFANASEV	{"email": "afanasev_dmitriy-071967@postgrespro.ru", "phone": "+70327914082"}
0005432985615	E6C58A	0885 912369	ELIZAVETA FILIPPOVA	{"phone": "+70744925617"}
0005432985616	E6C58A	2150 187254	ALEKSEY PETROV	{"email": "petrov_a.29111968@postgrespro.ru", "phone": "+70664269602"}
0005432985617	849D14	2687 966929	ANNA BORISOVA	{"email": "borisova_a031972@postgrespro.ru", "phone": "+70767721298"}
0005432985618	849D14	6675 889390	VLADIMIR VOROBEV	{"phone": "+70674717417"}
0005432985619	849D14	9164 901685	ANNA DANILOVA	{"email": "danilova_a01061966@postgrespro.ru", "phone": "+70765849148"}
0005432985620	849D14	9514 755185	DARYA KAZAKOVA	{"phone": "+70960633517"}
0005432985902	463315	9649 510585	LYUDMILA BORISOVA	{"phone": "+70136386559"}
0005432985621	D4A182	6408 166890	OLGA GAVRILOVA	{"email": "gavrilova-o_21051975@postgrespro.ru", "phone": "+70995551079"}
0005432985622	D4A182	6869 299350	ALINA KRASNOVA	{"phone": "+70884759264"}
0005432985623	5929FE	3025 943022	GALINA MAKSIMOVA	{"email": "maksimova_galina.041973@postgrespro.ru", "phone": "+70629590983"}
0005432985624	5929FE	5293 385953	GALINA GUSEVA	{"phone": "+70958847127"}
0005432985625	60F86A	0603 206518	MIKHAIL SEMENOV	{"email": "m.semenov_041970@postgrespro.ru", "phone": "+70264010998"}
0005432985626	ADD54A	7134 951220	NADEZHDA ANDREEVA	{"email": "andreevanadezhda011970@postgrespro.ru", "phone": "+70068332862"}
0005432985627	9C6B7E	8386 913358	NINA MAKSIMOVA	{"email": "n.maksimova.08041977@postgrespro.ru", "phone": "+70857155845"}
0005432985628	59267D	4197 860259	SERGEY MELNIKOV	{"phone": "+70495793755"}
0005432985629	36E388	4930 284126	ALEKSANDR SOLOVEV	{"phone": "+70840110911"}
0005432985630	36E388	0035 285690	VADIM KULIKOV	{"phone": "+70608431984"}
0005432985631	19F248	8357 080465	ELENA SCHERBAKOVA	{"phone": "+70663919302"}
0005432985632	65B1EA	1433 014428	LYUBOV KOVALEVA	{"phone": "+70522122966"}
0005432985633	9FCDA5	1969 943548	VLADIMIR KAZAKOV	{"phone": "+70933936151"}
0005432985634	9FCDA5	1924 042086	ELENA KUZMINA	{"phone": "+70671366271"}
0005432985635	F49CEB	3699 204358	VALENTINA SMIRNOVA	{"email": "valentina-smirnova-051964@postgrespro.ru", "phone": "+70419513355"}
0005432985636	0F238E	9548 835052	IRINA MIRONOVA	{"email": "mironova_i071966@postgrespro.ru", "phone": "+70675083151"}
0005432985637	0F238E	2527 928704	ARTEM MAKSIMOV	{"phone": "+70556658486"}
0005432985638	DD48E3	9191 092507	ELVIRA MIRONOVA	{"email": "elvira_mironova.12071962@postgrespro.ru", "phone": "+70745492269"}
0005432985639	DD48E3	4682 473704	SVETLANA MAKAROVA	{"phone": "+70665541046"}
0005432985640	416FFD	1997 804650	MILENA KUZNECOVA	{"email": "m_kuznecova-1978@postgrespro.ru", "phone": "+70335803669"}
0005432985641	C60781	4296 121254	ALINA GUSEVA	{"email": "guseva_alina-1981@postgrespro.ru", "phone": "+70002878530"}
0005432985642	0E43A3	9697 805805	DENIS ISAEV	{"email": "isaev-denis26121963@postgrespro.ru", "phone": "+70164540975"}
0005432985643	0E72F6	7010 831559	VLADISLAV ROMANOV	{"phone": "+70826053992"}
0005432985644	0E72F6	5843 870621	VLADIMIR NIKOLAEV	{"phone": "+70280419520"}
0005432985645	1E5B27	8372 653186	ALEKSEY VASILEV	{"phone": "+70892389411"}
0005432985646	1E5B27	2162 252911	VLADIMIR NIKITIN	{"email": "v-nikitin_29041970@postgrespro.ru", "phone": "+70555996180"}
0005432985647	1E44DF	0615 578354	ANTON FEDOTOV	{"email": "fedotov.a-21061973@postgrespro.ru", "phone": "+70829142269"}
0005432985872	7FC8BE	3955 173383	PAVEL MARTYNOV	{"phone": "+70617045129"}
0005432985648	1E44DF	3560 390008	ARTEM NIKOLAEV	{"email": "nikolaev.artem_121972@postgrespro.ru", "phone": "+70177976466"}
0005432985649	E0A0A1	2192 904721	MARIYA MIKHAYLOVA	{"email": "m.mikhaylova-1975@postgrespro.ru", "phone": "+70276476213"}
0005432985650	EAD456	9484 144656	ELINA MELNIKOVA	{"email": "e.melnikova24021963@postgrespro.ru", "phone": "+70093848133"}
0005432985651	EAD456	6847 890598	MARINA NIKIFOROVA	{"email": "nikiforova-m-1972@postgrespro.ru", "phone": "+70676048220"}
0005432985652	47F42B	2132 298062	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov.20021978@postgrespro.ru", "phone": "+70347277957"}
0005432985653	8C7E98	0838 846256	ZHANNA DAVYDOVA	{"phone": "+70167277738"}
0005432985654	8C7E98	4090 400337	ELENA ALEKSEEVA	{"email": "alekseeva.elena-081975@postgrespro.ru", "phone": "+70602172052"}
0005432985655	F4D301	1507 628659	DENIS KUDRYASHOV	{"email": "d_kudryashov_1962@postgrespro.ru", "phone": "+70502858455"}
0005432985656	0F9B5E	4042 736877	ALEKSANDR FOMIN	{"email": "a-fomin_081974@postgrespro.ru", "phone": "+70325006321"}
0005432985657	0F9B5E	8305 416842	ANNA DENISOVA	{"phone": "+70260339295"}
0005432985658	0F9B5E	0673 807653	OKSANA ANDREEVA	{"phone": "+70089314148"}
0005432985659	601019	8466 875252	IRINA VASILEVA	{"email": "vasileva.i_1977@postgrespro.ru", "phone": "+70229136701"}
0005432985660	085D81	2620 253067	ANASTASIYA LEBEDEVA	{"phone": "+70805806690"}
0005432985661	7CEA56	0026 157776	MARIYA SAVELEVA	{"email": "saveleva_m-27101977@postgrespro.ru", "phone": "+70289012453"}
0005432985662	79B11F	0848 869800	NIKOLAY ZAKHAROV	{"phone": "+70612618573"}
0005432985663	79B11F	5436 805218	ANASTASIYA DENISOVA	{"email": "denisova.anastasiya.081956@postgrespro.ru", "phone": "+70643196208"}
0005432985664	79B11F	7744 324392	ALEKSEY ORLOV	{"phone": "+70505162752"}
0005432985665	C357D7	2243 700376	ALEKSEY ROMANOV	{"email": "alekseyromanov_061967@postgrespro.ru", "phone": "+70382543357"}
0005432985666	C357D7	0691 645503	IGOR MAKSIMOV	{"phone": "+70328289597"}
0005432985667	FCED7E	9809 270878	TAMARA SMIRNOVA	{"email": "tsmirnova_1961@postgrespro.ru", "phone": "+70575388147"}
0005432985668	43D47D	5413 560874	ALEKSANDR MELNIKOV	{"email": "a.melnikov29071980@postgrespro.ru", "phone": "+70917627556"}
0005432985669	43D47D	9054 346776	GALINA FEDOROVA	{"email": "fedorovagalina.071978@postgrespro.ru", "phone": "+70016067281"}
0005432985670	1089DC	6478 108594	OLGA MAKAROVA	{"email": "makarova_olga.25121961@postgrespro.ru", "phone": "+70567515076"}
0005432985671	0E6DD2	1637 233759	ANDREY NOVIKOV	{"phone": "+70325959167"}
0005432985672	65A682	3260 722205	VLADIMIR SOKOLOV	{"phone": "+70838965560"}
0005432985673	5F19A3	8046 957663	ANATOLIY NIKOLAEV	{"email": "anatoliynikolaev_1968@postgrespro.ru", "phone": "+70323179399"}
0005432985674	63FD1D	4857 655113	LYUDMILA SOLOVEVA	{"phone": "+70764412164"}
0005432985675	1D47F5	7692 327087	MARIYA KONOVALOVA	{"phone": "+70581754464"}
0005432985677	8EB57B	7302 394000	SERGEY ALEKSANDROV	{"email": "sergey.aleksandrov021967@postgrespro.ru", "phone": "+70153406235"}
0005432985678	8EB57B	4803 276161	NATALYA SAVELEVA	{"phone": "+70818539080"}
0005432985679	DAC0D7	7868 775066	VIKTOR CHERNOV	{"email": "vchernov1975@postgrespro.ru", "phone": "+70061257622"}
0005432985680	AE72A4	0196 621816	TATYANA SCHERBAKOVA	{"phone": "+70273019175"}
0005432985681	AE72A4	2245 084370	NATALYA GRISHINA	{"email": "natalya-grishina.1976@postgrespro.ru", "phone": "+70952628213"}
0005432985682	EF9CD3	5521 465678	LEONID ZAYCEV	{"email": "zaycev.l_22121973@postgrespro.ru", "phone": "+70843918377"}
0005432985683	622950	0568 125882	ALEKSANDR SCHERBAKOV	{"phone": "+70069965706"}
0005432985684	08787E	4188 348047	ALEKSEY ILIN	{"email": "aleksey-ilin.051969@postgrespro.ru", "phone": "+70813015928"}
0005432985685	2C9AB5	8528 888637	ILYA POPOV	{"email": "ipopov111968@postgrespro.ru", "phone": "+70831732894"}
0005432985686	2C9AB5	2024 905004	ANASTASIYA PETROVA	{"email": "a.petrova091977@postgrespro.ru", "phone": "+70482238599"}
0005432985687	843B26	5080 015770	NATALYA ABRAMOVA	{"email": "abramova_natalya-071972@postgrespro.ru", "phone": "+70166283226"}
0005432985688	EDB301	6065 895811	EVGENIY TARASOV	{"email": "tarasov-e-1963@postgrespro.ru", "phone": "+70690341352"}
0005432985689	EDB301	1258 390637	IRINA POTAPOVA	{"phone": "+70871833651"}
0005432985690	FC8989	9914 995583	NATALYA VOROBEVA	{"phone": "+70098258280"}
0005432985691	04FC35	7825 056977	OLGA MAKSIMOVA	{"phone": "+70102689257"}
0005432985692	04FC35	2839 631660	GALINA ORLOVA	{"email": "galina_orlova031973@postgrespro.ru", "phone": "+70775667765"}
0005432985693	04FC35	6387 677659	TATYANA KULIKOVA	{"email": "t-kulikova.26071976@postgrespro.ru", "phone": "+70251427537"}
0005432985694	04FC35	5445 123600	VYACHESLAV POPOV	{"email": "popov_vyacheslav.23091968@postgrespro.ru", "phone": "+70525884543"}
0005432985695	0A0743	5155 780540	ANDREY VASILEV	{"phone": "+70812323882"}
0005432985696	0A0743	8933 459645	POLINA ANDREEVA	{"email": "andreeva.polina_1970@postgrespro.ru", "phone": "+70491590855"}
0005432985697	788D50	4379 208924	OLEG MAKAROV	{"phone": "+70535227346"}
0005432985698	788D50	8194 838082	NATALYA SEMENOVA	{"phone": "+70660944989"}
0005432985699	6455DC	7837 916732	NINA KOZLOVA	{"email": "nkozlova-071973@postgrespro.ru", "phone": "+70862781637"}
0005432985700	00A95D	4982 771419	SVETLANA OSIPOVA	{"email": "osipova-svetlana.30091978@postgrespro.ru", "phone": "+70429718218"}
0005432985701	00A95D	4530 185594	VIKTOR MATVEEV	{"phone": "+70403656122"}
0005432985702	00A95D	0734 827057	YURIY PAVLOV	{"phone": "+70527400385"}
0005432985703	8E07BB	4543 028823	ALIYA KONDRATEVA	{"phone": "+70173487943"}
0005432985704	073217	9951 804384	MARINA FEDOROVA	{"email": "fedorova-marina1974@postgrespro.ru", "phone": "+70357342446"}
0005432985705	730994	6123 952424	ELENA KOROLEVA	{"phone": "+70544309891"}
0005432985706	2728D5	2809 473241	LEONID MEDVEDEV	{"email": "medvedev.l_111971@postgrespro.ru", "phone": "+70298135503"}
0005432985707	2728D5	4992 096189	ELENA ALEKSEEVA	{"email": "elena-alekseeva_031972@postgrespro.ru", "phone": "+70739927327"}
0005432985708	0A02BA	9984 389433	VALENTINA NAZAROVA	{"phone": "+70240465051"}
0005432985709	9123F8	8515 485091	PELAGEYA IVANOVA	{"email": "ivanova.pelageya-16051970@postgrespro.ru", "phone": "+70872435667"}
0005432985710	2839D1	0715 186624	DENIS KARPOV	{"phone": "+70792967389"}
0005432985711	BD020F	3974 405511	LYUBOV NAZAROVA	{"email": "lyubov-nazarova.21011979@postgrespro.ru", "phone": "+70163139656"}
0005432985712	BD020F	7125 294313	NIKOLAY POPOV	{"email": "popov_nikolay.21071972@postgrespro.ru", "phone": "+70997216221"}
0005432985713	E2BF76	1615 614343	MAKSIM GUSEV	{"phone": "+70235136970"}
0005432985714	E2BF76	5590 584781	SERGEY KRASNOV	{"phone": "+70669247254"}
0005432985715	E2BF76	5518 428924	ARINA LAZAREVA	{"phone": "+70767615668"}
0005432985716	16A542	1012 181156	SVETLANA MIRONOVA	{"phone": "+70658737956"}
0005432985717	1F8DB8	7336 120266	GALINA NAUMOVA	{"phone": "+70191814364"}
0005432985718	1F8DB8	5304 093362	VITALIY RODIONOV	{"phone": "+70297791792"}
0005432985719	2D5E65	0763 700763	VASILIY PETROV	{"phone": "+70793737688"}
0005432985720	2D5E65	2164 907058	NADEZHDA NIKIFOROVA	{"email": "nikiforova.nadezhda.1979@postgrespro.ru", "phone": "+70176433993"}
0005432985721	2CF4AC	8428 081799	ALEKSEY NIKITIN	{"email": "nikitin-a.18041977@postgrespro.ru", "phone": "+70155180876"}
0005432985722	2CF4AC	7526 939602	OKSANA NIKOLAEVA	{"email": "oksana.nikolaeva-13081965@postgrespro.ru", "phone": "+70839238586"}
0005432985723	950F64	6511 562798	KSENIYA ZAKHAROVA	{"email": "kseniya_zakharova_23041968@postgrespro.ru", "phone": "+70983472024"}
0005432985724	95373E	9237 892981	VIKTOR IVANOV	{"email": "viktor-ivanov03031972@postgrespro.ru", "phone": "+70752660495"}
0005432985725	6E2AD9	7115 918654	ALEKSEY MEDVEDEV	{"email": "aleksey_medvedev081973@postgrespro.ru", "phone": "+70863860829"}
0005432985726	C4C1E0	2119 875324	EVGENIYA NAUMOVA	{"email": "naumova_evgeniya_011970@postgrespro.ru", "phone": "+70333717749"}
0005432985727	002FE3	7785 717614	NATALYA PAVLOVA	{"email": "pavlova.n-121981@postgrespro.ru", "phone": "+70695114743"}
0005432985728	FBAB1E	3777 631142	VALENTINA EFREMOVA	{"phone": "+70410882714"}
0005432985729	FBAB1E	7312 124008	VIKTORIYA POPOVA	{"email": "popova-viktoriya_22091966@postgrespro.ru", "phone": "+70265188094"}
0005432985730	FBAB1E	7294 111531	NATALYA IVANOVA	{"email": "n-ivanova1971@postgrespro.ru", "phone": "+70100637184"}
0005432985731	2AC108	1495 228014	ANTON FROLOV	{"email": "anton-frolov111976@postgrespro.ru", "phone": "+70494269500"}
0005432985903	463315	9147 938722	MAKSIM AFANASEV	{"phone": "+70643654666"}
0005432985732	139BA4	8885 851194	ALINA EGOROVA	{"email": "alina-egorova.09011962@postgrespro.ru", "phone": "+70122370456"}
0005432985733	139BA4	9719 650092	ALEKSEY ALEKSEEV	{"phone": "+70501853944"}
0005432985734	36C224	3383 525924	ALEKSANDR KRASNOV	{"phone": "+70378206477"}
0005432985735	80C812	9086 618047	ANNA GORBUNOVA	{"email": "gorbunovaa-1971@postgrespro.ru", "phone": "+70163756802"}
0005432985736	28CD16	3071 955400	VLADIMIR ILIN	{"phone": "+70656704943"}
0005432985737	54D80F	8069 931855	ANTONINA ZHUKOVA	{"email": "zhukovaa1980@postgrespro.ru", "phone": "+70507201820"}
0005432985738	F17C5A	2718 698789	NATALYA NOVIKOVA	{"email": "novikova-n_101968@postgrespro.ru", "phone": "+70021057307"}
0005432985739	FBE4D1	4183 149709	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov-061975@postgrespro.ru", "phone": "+70266965960"}
0005432985740	FBE4D1	2382 525050	NIKOLAY VLASOV	{"email": "vlasov-nikolay-1964@postgrespro.ru", "phone": "+70256999958"}
0005432985741	6B5B41	3984 156047	ILONA BORISOVA	{"phone": "+70732688740"}
0005432985742	6B5B41	1627 356070	OLGA SEMENOVA	{"email": "o.semenova.111973@postgrespro.ru", "phone": "+70722681374"}
0005432985743	5E553A	1884 411127	ROMAN DAVYDOV	{"phone": "+70156495142"}
0005432985744	5E553A	7197 418400	PAVEL KRASNOV	{"phone": "+70345665434"}
0005432985745	927AC1	1076 252749	ALEKSEY SOROKIN	{"phone": "+70619829263"}
0005432985746	5C9B99	1248 265735	VADIM CHERNOV	{"phone": "+70072885265"}
0005432985747	83B53C	0115 873129	ALEKSEY NAZAROV	{"phone": "+70150510908"}
0005432985748	83B53C	0687 217954	LEONID BARANOV	{"email": "leonid_baranov_1975@postgrespro.ru", "phone": "+70117024402"}
0005432985749	78134D	7852 425147	SERGEY FROLOV	{"email": "frolov-sergey011967@postgrespro.ru", "phone": "+70576281922"}
0005432985750	78134D	4501 004332	YURIY NIKOLAEV	{"email": "ynikolaev1980@postgrespro.ru", "phone": "+70935779026"}
0005432985751	1C732D	8486 653389	SVETLANA DANILOVA	{"email": "s.danilova1975@postgrespro.ru", "phone": "+70862979711"}
0005432985752	334AF4	4714 981246	DMITRIY PETROV	{"phone": "+70535385167"}
0005432985753	9E9B9B	4121 247015	ANNA NIKIFOROVA	{"phone": "+70003673013"}
0005432985754	9E9B9B	6521 411280	EKATERINA ANDREEVA	{"phone": "+70106651314"}
0005432985755	9D9C83	3059 026034	ANDREY SEMENOV	{"email": "semenovandrey.15081959@postgrespro.ru", "phone": "+70550920204"}
0005432985756	7B04DC	0243 119874	ALEKSANDRA DENISOVA	{"email": "denisova_a-1978@postgrespro.ru", "phone": "+70356587896"}
0005432985757	00CDFE	1665 275648	OLESYA LUKYANOVA	{"email": "olesya.lukyanova.1960@postgrespro.ru", "phone": "+70204176152"}
0005432985758	D3B725	3907 711522	NINA FROLOVA	{"phone": "+70688241365"}
0005432985759	9452D1	7949 052047	ALEKSANDRA NIKITINA	{"phone": "+70913758649"}
0005432985760	CADFB3	9545 823079	YURIY SMIRNOV	{"email": "smirnov_yuriy-121974@postgrespro.ru", "phone": "+70587264969"}
0005432985761	B1CC0F	0353 092625	VIKTORIYA ROMANOVA	{"phone": "+70769201819"}
0005432985762	B1CC0F	2748 993692	VIKTOR SCHERBAKOV	{"email": "v-scherbakov-091972@postgrespro.ru", "phone": "+70137260284"}
0005432985763	D8F273	7949 701621	EVA SOROKINA	{"email": "e-sorokina-1966@postgrespro.ru", "phone": "+70003936514"}
0005432985764	D8F273	5958 900018	IGOR NIKITIN	{"email": "nikitin_i111972@postgrespro.ru", "phone": "+70695884192"}
0005432985765	2056DE	3797 442490	OKSANA IVANOVA	{"phone": "+70642448103"}
0005432985766	BBE293	5207 107919	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v-30081969@postgrespro.ru", "phone": "+70130508923"}
0005432985767	1EDB40	4410 317390	ALEKSANDR CHERNOV	{"email": "a-chernov.1975@postgrespro.ru", "phone": "+70267150643"}
0005432985768	6A8A65	1916 144183	SERGEY SHEVCHENKO	{"phone": "+70629680920"}
0005432985769	6A8A65	8834 116433	VIKTOR IVANOV	{"phone": "+70580035975"}
0005432985770	8463A7	6593 816416	SERGEY KUZMIN	{"email": "kuzmin-s07091974@postgrespro.ru", "phone": "+70612341992"}
0005432985771	8463A7	7859 652358	OLGA ISAEVA	{"email": "oisaeva041967@postgrespro.ru", "phone": "+70667144973"}
0005432985772	CC3BB4	8328 984169	YURIY MARTYNOV	{"phone": "+70941437561"}
0005432985773	CC3BB4	6222 497284	ANDREY POPOV	{"phone": "+70093460039"}
0005432985774	7B81B0	3953 610876	LYUBOV SOKOLOVA	{"phone": "+70212537789"}
0005432985775	3BB2EA	0764 841730	ELENA ZHURAVLEVA	{"phone": "+70252623838"}
0005432985776	E962DF	2652 370376	NIKOLAY MIRONOV	{"email": "nikolay.mironov-1985@postgrespro.ru", "phone": "+70688354072"}
0005432985777	953811	3615 754759	GENNADIY FILIPPOV	{"phone": "+70291257400"}
0005432985778	4488EC	0394 228181	IRINA PAVLOVA	{"email": "i-pavlova.021975@postgrespro.ru", "phone": "+70448463195"}
0005432985779	B18E76	6533 852537	KAMILA LAZAREVA	{"phone": "+70182658675"}
0005432985780	E8231D	9118 905267	MAKSIM POPOV	{"phone": "+70629485692"}
0005432985781	E8231D	4889 338091	NATALYA CHERNOVA	{"phone": "+70982118058"}
0005432985782	E8231D	6173 865811	ELENA KOROLEVA	{"email": "korolevaelena.041976@postgrespro.ru", "phone": "+70210869020"}
0005432985783	6B56C5	2312 678881	ANDREY GAVRILOV	{"email": "a_gavrilov-051984@postgrespro.ru", "phone": "+70461700363"}
0005432985784	44188C	9843 517814	IVAN PETROV	{"email": "ivanpetrov-071968@postgrespro.ru", "phone": "+70663597902"}
0005432985785	E2E7E6	0534 143986	ALEKSANDR PETROV	{"email": "aleksandr_petrov-20101966@postgrespro.ru", "phone": "+70914662804"}
0005432985786	ABA8E7	2577 754871	DANILA POPOV	{"phone": "+70777474047"}
0005432985787	B661A3	7842 546598	KONSTANTIN SOKOLOV	{"phone": "+70884742102"}
0005432985788	C98759	3166 794710	ALEKSEY NIKITIN	{"phone": "+70084335145"}
0005432985789	C98759	9210 211137	OLGA BOGDANOVA	{"email": "olga.bogdanova-30051968@postgrespro.ru", "phone": "+70956020927"}
0005432985790	5523B9	0658 941609	LEONID NIKITIN	{"phone": "+70007585300"}
0005432985791	64A866	9080 546221	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov_081972@postgrespro.ru", "phone": "+70499280506"}
0005432985792	FEBF92	4285 208788	EVGENIY MIRONOV	{"phone": "+70688363724"}
0005432985793	C0B6A2	7557 999956	ZINAIDA ANDREEVA	{"email": "andreevazinaida_1976@postgrespro.ru", "phone": "+70170785553"}
0005432985794	C0B6A2	0536 550211	IGOR ZAYCEV	{"email": "zaycev.i.31081973@postgrespro.ru", "phone": "+70189519284"}
0005432985795	E133D8	7469 640144	VIKTORIYA STEPANOVA	{"phone": "+70883828007"}
0005432985796	A391A4	5725 272799	NADEZHDA ANDREEVA	{"phone": "+70280472762"}
0005432985797	3543F6	9832 798357	ALENA TROFIMOVA	{"phone": "+70950402010"}
0005432985798	3543F6	6359 819646	KIRA IVANOVA	{"email": "ivanova-k_031965@postgrespro.ru", "phone": "+70437759576"}
0005432985799	B04995	2273 586694	VALERIYA ZHUKOVA	{"email": "valeriyazhukova30111970@postgrespro.ru", "phone": "+70541223753"}
0005432985800	3A12F5	8057 296809	GALINA ZAKHAROVA	{"email": "g-zakharova_28071961@postgrespro.ru", "phone": "+70187019942"}
0005432985801	3A12F5	3624 696946	MATRENA VOLKOVA	{"email": "m.volkova.1967@postgrespro.ru", "phone": "+70592404930"}
0005432985802	5AA552	7566 875014	NADEZHDA RYABOVA	{"email": "n_ryabova-1962@postgrespro.ru", "phone": "+70066252122"}
0005432985803	5951E1	7178 044063	ARTEM MARTYNOV	{"phone": "+70776084546"}
0005432985804	B69B89	6968 526021	ANNA ALEKSANDROVA	{"phone": "+70477544165"}
0005432985805	9B98AF	0468 347737	ARTEM ABRAMOV	{"email": "abramov.artem-1980@postgrespro.ru", "phone": "+70108536695"}
0005432985806	9B98AF	1164 113936	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov_30071969@postgrespro.ru", "phone": "+70084999938"}
0005432985807	ABD599	4912 706499	LIDIYA FEDOROVA	{"phone": "+70654145386"}
0005432985808	ABD599	2721 316672	EVGENIY TARASOV	{"phone": "+70648142181"}
0005432985809	3AA048	1034 113167	LIDIYA YAKOVLEVA	{"email": "yakovlevalidiya.041976@postgrespro.ru", "phone": "+70326933529"}
0005432985810	3AA048	9561 910695	NATALYA LUKYANOVA	{"phone": "+70634313242"}
0005432985811	3AA048	1253 773794	ALISA KRASNOVA	{"email": "krasnova_alisa.1971@postgrespro.ru", "phone": "+70673775961"}
0005432985812	9B2A97	7234 093541	ALEKSEY VLASOV	{"email": "vlasov_a1974@postgrespro.ru", "phone": "+70848944044"}
0005432985813	2F9B37	0019 313240	ARSEN FEDOROV	{"phone": "+70186833204"}
0005432985814	795F60	0955 909203	SVETLANA SCHERBAKOVA	{"email": "scherbakovas.121975@postgrespro.ru", "phone": "+70049487169"}
0005432985815	B8C9E8	2113 974457	IGOR FROLOV	{"phone": "+70211858152"}
0005432985816	6FE9BD	6789 785003	SERGEY CHERNOV	{"email": "sergey-chernov-1976@postgrespro.ru", "phone": "+70333303320"}
0005432985817	0733D4	8659 100133	ALEKSEY BORISOV	{"phone": "+70128747369"}
0005432985818	3F18F6	4169 079947	EVGENIY ANDREEV	{"email": "andreev_evgeniy_01071976@postgrespro.ru", "phone": "+70298695899"}
0005432985819	ED7AC9	8460 371689	IRINA EGOROVA	{"email": "irina_egorova_121983@postgrespro.ru", "phone": "+70460270565"}
0005432985820	906B2C	4769 015055	DMITRIY NIKITIN	{"phone": "+70599149040"}
0005432985821	9274B6	4475 190230	EVGENIY KOZLOV	{"phone": "+70366818718"}
0005432985822	9274B6	9033 612990	ILYA ALEKSEEV	{"email": "i.alekseev1971@postgrespro.ru", "phone": "+70017812585"}
0005432985823	9274B6	7114 184565	TATYANA MAKSIMOVA	{"phone": "+70448782731"}
0005432985824	9EB357	7729 773350	TATYANA MOROZOVA	{"email": "tatyana-morozova101977@postgrespro.ru", "phone": "+70254178790"}
0005432985825	F93EDF	8194 031957	ALEKSANDR SEMENOV	{"email": "a_semenov.14011976@postgrespro.ru", "phone": "+70948810895"}
0005432985826	F93EDF	8263 721239	ALEKSANDRA TIKHONOVA	{"phone": "+70945255357"}
0005432985827	B21BF3	4289 364371	OLGA RODIONOVA	{"phone": "+70486596841"}
0005432985828	B21BF3	8227 032409	LEYLA FOMINA	{"phone": "+70292699856"}
0005432985829	B21BF3	9897 939402	ALEKSEY MELNIKOV	{"phone": "+70116477458"}
0005432985830	1D5874	8583 073299	YULIYA BARANOVA	{"phone": "+70648659547"}
0005432985831	E3D789	5479 705488	SERGEY GUSEV	{"phone": "+70881580121"}
0005432985832	3738B7	5405 838377	EKATERINA MAKAROVA	{"phone": "+70846048358"}
0005432985833	4A18F3	3693 975463	VYACHESLAV SOROKIN	{"phone": "+70119539435"}
0005432985834	ECFD70	4124 118950	KRISTINA SCHERBAKOVA	{"email": "scherbakova-k18111981@postgrespro.ru", "phone": "+70570230089"}
0005432985835	9396C6	8012 465531	LYUBOV NIKITINA	{"email": "l_nikitina_031976@postgrespro.ru", "phone": "+70542648561"}
0005432985836	9396C6	4370 619133	SERGEY ANTONOV	{"phone": "+70204198241"}
0005432985837	9396C6	0449 845873	TAISIYA MOISEEVA	{"phone": "+70849021071"}
0005432985838	7CCA28	4411 625148	VIKTOR MAKAROV	{"phone": "+70098250105"}
0005432985839	301081	4494 623882	ALEKSANDR TIMOFEEV	{"phone": "+70181582597"}
0005432985840	1E4235	9726 515043	NATALYA SCHERBAKOVA	{"email": "scherbakovanatalya-021991@postgrespro.ru", "phone": "+70120363248"}
0005432985841	99CE1E	7767 923737	MIKHAIL MIKHAYLOV	{"email": "mikhail_mikhaylov-10121975@postgrespro.ru", "phone": "+70764908597"}
0005432985842	99CE1E	8821 135224	DMITRIY VASILEV	{"email": "dmitriyvasilev-071960@postgrespro.ru", "phone": "+70167599293"}
0005432985843	648966	3285 129991	PAVEL VASILEV	{"phone": "+70350426119"}
0005432985844	4F658A	1968 633316	VALERIY SERGEEV	{"email": "sergeevvaleriy.041971@postgrespro.ru", "phone": "+70782770297"}
0005432985845	4F658A	6205 266302	ALENA SAVELEVA	{"email": "asaveleva081963@postgrespro.ru", "phone": "+70429126905"}
0005432985846	C85B34	9420 816889	IRINA STEPANOVA	{"email": "i.stepanova_071967@postgrespro.ru", "phone": "+70624347235"}
0005432985847	C85B34	2215 849728	ANDREY KRASNOV	{"phone": "+70220203296"}
0005432985848	AEFDCB	4395 806312	SERGEY SHEVCHENKO	{"phone": "+70748099745"}
0005432985849	AEFDCB	0169 543418	TIMOFEY VOROBEV	{"phone": "+70954282629"}
0005432985850	C40824	6951 074670	ALEKSANDR SMIRNOV	{"email": "a_smirnov-011991@postgrespro.ru", "phone": "+70851371077"}
0005432985851	890C3F	2329 084419	SVETLANA MARTYNOVA	{"phone": "+70846046454"}
0005432985852	41B0D9	0316 865806	PELAGEYA FILATOVA	{"email": "filatova_pelageya.051970@postgrespro.ru", "phone": "+70195902451"}
0005432985853	41B0D9	3794 429198	ANNA ORLOVA	{"phone": "+70017813607"}
0005432985854	535780	4561 771341	NATALYA KOROLEVA	{"email": "korolevan_1973@postgrespro.ru", "phone": "+70664600818"}
0005432985855	535780	5910 337629	VARVARA KUZNECOVA	{"phone": "+70931379126"}
0005432985856	EF1B90	0515 037923	ALEKSANDRA VOLKOVA	{"email": "a-volkova_1983@postgrespro.ru", "phone": "+70938339147"}
0005432985857	2824EA	8337 652252	SVETLANA RYABOVA	{"email": "svetlanaryabova.091966@postgrespro.ru", "phone": "+70262348850"}
0005432985858	2824EA	3511 106440	ANNA YAKOVLEVA	{"email": "yakovleva-anna_1971@postgrespro.ru", "phone": "+70054784545"}
0005432985859	0D6A04	6056 704962	VADIM DAVYDOV	{"phone": "+70873883783"}
0005432985860	786875	9622 601258	EVGENIY YAKOVLEV	{"email": "eyakovlev-12091978@postgrespro.ru", "phone": "+70088198768"}
0005432985861	44C1DD	9902 059347	OLGA VASILEVA	{"email": "olga_vasileva_1978@postgrespro.ru", "phone": "+70686868478"}
0005432985862	44C1DD	4099 277360	ANDREY MIKHAYLOV	{"email": "mikhaylov_andrey.1965@postgrespro.ru", "phone": "+70316563491"}
0005432985863	1E1655	3159 705169	ANTON FROLOV	{"phone": "+70718478212"}
0005432985864	1E1655	4467 136897	KIRILL MAKAROV	{"email": "makarovkirill-101969@postgrespro.ru", "phone": "+70540275604"}
0005432985865	764DFB	8763 486382	RAMILYA KUZMINA	{"email": "r_kuzmina-1975@postgrespro.ru", "phone": "+70858632725"}
0005432985866	764DFB	3665 134698	SERGEY FILIPPOV	{"phone": "+70684169577"}
0005432985867	DD76C2	1693 029648	MARINA SOKOLOVA	{"email": "m-sokolova.011974@postgrespro.ru", "phone": "+70936672578"}
0005432985868	9D531B	3215 665486	ANASTASIYA POLYAKOVA	{"phone": "+70857726282"}
0005432985869	A8DC30	7259 714287	SANIYA MIRONOVA	{"email": "saniya_mironova-22081968@postgrespro.ru", "phone": "+70617362383"}
0005432985870	594767	6296 112001	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_aleksandr1971@postgrespro.ru", "phone": "+70930791307"}
0005432985871	594767	4932 196954	ALEKSANDR SEMENOV	{"phone": "+70475732992"}
0005432985873	7FC8BE	1857 482533	ANTON AFANASEV	{"email": "afanasev-anton051966@postgrespro.ru", "phone": "+70229158953"}
0005432985874	21BDD3	8153 002994	RAISA NAZAROVA	{"email": "nazarovaraisa.22111982@postgrespro.ru", "phone": "+70981372551"}
0005432985875	21BDD3	6299 006191	DARYA NAUMOVA	{"phone": "+70024382100"}
0005432985876	0E9687	4734 682978	LIDIYA ZHUKOVA	{"email": "lidiya.zhukova.20091980@postgrespro.ru", "phone": "+70157872664"}
0005432985877	8D9C80	5622 269071	OLESYA MATVEEVA	{"phone": "+70122184192"}
0005432985878	67A441	6268 536508	ALEKSANDR KRASNOV	{"phone": "+70261604552"}
0005432985879	63A98E	9788 518810	EVGENIYA NOVIKOVA	{"email": "enovikova-1967@postgrespro.ru", "phone": "+70509669970"}
0005432985880	E9C1F6	3845 919602	SVETLANA KOVALEVA	{"phone": "+70009601495"}
0005432985881	9D2A23	7322 409298	LIDIYA FROLOVA	{"email": "frolova-lidiya.23011976@postgrespro.ru", "phone": "+70407312948"}
0005432985882	93DABF	2875 096214	TAMARA GRISHINA	{"phone": "+70987629190"}
0005432985883	504872	2097 452255	NATALYA KONDRATEVA	{"email": "natalya.kondrateva.1979@postgrespro.ru", "phone": "+70364930924"}
0005432985884	4370EA	6677 095908	MARIYA KONOVALOVA	{"email": "mkonovalova28051982@postgrespro.ru", "phone": "+70937543757"}
0005432985885	7D820D	1628 907674	ALEKSANDR MOROZOV	{"phone": "+70091757079"}
0005432985886	7D820D	0761 640539	VLADIMIR MELNIKOV	{"email": "v-melnikov_30031968@postgrespro.ru", "phone": "+70261381963"}
0005432985887	7D820D	0592 493513	TATYANA KUZNECOVA	{"phone": "+70317035292"}
0005432985888	C90FFA	5878 301019	KSENIYA AFANASEVA	{"phone": "+70166478454"}
0005432985889	C90FFA	1062 536459	EVGENIY NOVIKOV	{"email": "evgeniy.novikov_02031977@postgrespro.ru", "phone": "+70122755666"}
0005432985890	5B2B52	8681 674412	YURIY NAZAROV	{"email": "y.nazarov1973@postgrespro.ru", "phone": "+70303738922"}
0005432985891	5B2B52	8240 172452	YURIY NOVIKOV	{"email": "y.novikov.1967@postgrespro.ru", "phone": "+70066059039"}
0005432985892	2E16BA	1407 867097	ALEKSANDR SEMENOV	{"phone": "+70992373539"}
0005432985893	2E16BA	8577 403191	ALEKSANDR VASILEV	{"phone": "+70888188142"}
0005432985894	2C99E7	2781 077001	VITALIY STEPANOV	{"phone": "+70049769113"}
0005432985895	2C99E7	4875 828019	SERGEY GAVRILOV	{"email": "sergey-gavrilov_05061981@postgrespro.ru", "phone": "+70688862044"}
0005432985896	8CF3C9	9081 436520	ANNA MAKSIMOVA	{"phone": "+70539259400"}
0005432985897	6FC32E	8736 692730	OLGA MELNIKOVA	{"email": "melnikova.o_1970@postgrespro.ru", "phone": "+70771683033"}
0005432985898	E4DB40	6925 633377	POLINA BOGDANOVA	{"email": "bogdanova.p101976@postgrespro.ru", "phone": "+70193797504"}
0005432985899	089482	3727 143449	ANATOLIY SMIRNOV	{"phone": "+70082651649"}
0005432985900	089482	2911 170128	TATYANA VOLKOVA	{"phone": "+70016904708"}
0005432985901	463315	5396 476608	NATALIYA IVANOVA	{"phone": "+70127751812"}
0005432985904	772060	3346 438081	ALEKSANDR SERGEEV	{"phone": "+70890937735"}
0005432985905	4E66CF	2586 543448	OLEG FEDOROV	{"email": "oleg_fedorov_1974@postgrespro.ru", "phone": "+70574800360"}
0005432985906	4E66CF	1096 456515	ALENA LUKYANOVA	{"email": "alena_lukyanova.11051980@postgrespro.ru", "phone": "+70890531861"}
0005432985907	A88981	3782 671791	EKATERINA FOMINA	{"email": "e_fomina_1978@postgrespro.ru", "phone": "+70774885899"}
0005432985908	3E1103	6896 698513	VLADIMIR GRIGOREV	{"phone": "+70748673599"}
0005432985909	3E1103	6260 727896	PETR NOVIKOV	{"email": "novikov.petr1972@postgrespro.ru", "phone": "+70491743739"}
0005432985910	3E1103	8057 332174	LILIYA DMITRIEVA	{"phone": "+70637386433"}
0005432985911	4CC6D2	8657 279031	VALENTINA VOLKOVA	{"email": "valentina_volkova.111959@postgrespro.ru", "phone": "+70432092126"}
0005432985912	4CC6D2	9722 277862	YULIYA SAVELEVA	{"email": "yuliya.saveleva_1957@postgrespro.ru", "phone": "+70182768661"}
0005432985913	28C909	2241 970939	ANAIT TITOVA	{"email": "anait-titova071982@postgrespro.ru", "phone": "+70104346674"}
0005432985914	28C909	9924 741819	TATYANA KUZMINA	{"phone": "+70761800128"}
0005432985915	28C909	7179 950304	ANNA KRASNOVA	{"phone": "+70621702982"}
0005432985916	3BB729	4102 808545	ALEKSANDR FEDOTOV	{"email": "aleksandrfedotov_1975@postgrespro.ru", "phone": "+70315469545"}
0005432985917	3BB729	9537 814055	ALEKSEY SEMENOV	{"email": "semenov-aleksey25031982@postgrespro.ru", "phone": "+70431208438"}
0005432985918	78581B	3400 879201	MARIYA KOZLOVA	{"phone": "+70469194510"}
0005432985919	71AB92	4975 768967	OLEG SEMENOV	{"email": "oleg.semenov.121980@postgrespro.ru", "phone": "+70993140754"}
0005432985920	40A3B9	6942 839941	YULIYA AKIMOVA	{"phone": "+70048343900"}
0005432985921	DA4E7E	2328 865730	MARINA LAZAREVA	{"email": "lazareva.marina-031979@postgrespro.ru", "phone": "+70898718536"}
0005432985922	48399D	2365 584314	NINA ZAKHAROVA	{"phone": "+70496750265"}
0005432985923	CC62CE	2339 938675	VALERIY PETROV	{"phone": "+70745567583"}
0005432985924	CC62CE	6758 815795	LIDIYA NESTEROVA	{"phone": "+70188278098"}
0005432985925	CC62CE	3113 020905	ROMAN FROLOV	{"email": "frolov-roman.111965@postgrespro.ru", "phone": "+70786784365"}
0005432985926	979075	0830 621890	NINA VOLKOVA	{"phone": "+70447918021"}
0005432985927	F2C4AC	7347 959129	TATYANA KUZNECOVA	{"phone": "+70285981975"}
0005432985928	F2C4AC	1967 874703	SERGEY SEMENOV	{"phone": "+70533135348"}
0005432985929	E4A7A4	2191 576506	DMITRIY MIKHAYLOV	{"email": "mikhaylov-d_011987@postgrespro.ru", "phone": "+70607206964"}
0005432985930	E4A7A4	0715 778613	IGOR VASILEV	{"phone": "+70830829939"}
0005432985931	4147C2	5333 938658	MARIYA PETROVA	{"email": "m_petrova-20121963@postgrespro.ru", "phone": "+70343911681"}
0005432985932	4147C2	0265 530886	ELIZAVETA MARTYNOVA	{"phone": "+70440246144"}
0005432985933	B3BF6B	6542 676865	ALEKSANDR KULIKOV	{"email": "a.kulikov_061960@postgrespro.ru", "phone": "+70288580359"}
0005432985934	A870B7	8848 632739	ELVIRA KUZMINA	{"email": "kuzmina-elvira_1973@postgrespro.ru", "phone": "+70441795118"}
0005432985935	9E5A5E	7567 553310	IGOR POPOV	{"phone": "+70896106760"}
0005432985936	5E881C	3222 376543	VLADIMIR POPOV	{"email": "popov-v.031971@postgrespro.ru", "phone": "+70193246171"}
0005432985937	3B4EB6	7684 161352	LYUBOV EGOROVA	{"phone": "+70579684376"}
0005432985938	12824D	7599 149823	IVAN FEDOROV	{"phone": "+70195720434"}
0005432985939	4DFC1D	5439 636909	ALEKSANDR VOLKOV	{"phone": "+70070113171"}
0005432985940	4DFC1D	8422 438073	MARIYA NIKITINA	{"phone": "+70143552985"}
0005432985941	4DFC1D	9332 032572	RODION GUSEV	{"email": "gusevr-1974@postgrespro.ru", "phone": "+70683840261"}
0005432985942	4DFC1D	9332 548949	ANATOLIY EGOROV	{"email": "a.egorov-15021976@postgrespro.ru", "phone": "+70190840028"}
0005432985943	1CAEBA	9634 494504	GALINA POPOVA	{"email": "galina-popova.011970@postgrespro.ru", "phone": "+70425550211"}
0005432985944	31B305	8079 761710	OLGA FROLOVA	{"phone": "+70820436231"}
0005432985945	31B305	0938 218042	LYUDMILA ZAKHAROVA	{"email": "zakharova.l_1971@postgrespro.ru", "phone": "+70189086332"}
0005432985946	D170B2	0542 242729	ALEKSANDR ANDREEV	{"email": "andreeva1973@postgrespro.ru", "phone": "+70201871357"}
0005432985947	D170B2	9309 875450	NATALYA PETROVA	{"phone": "+70233226638"}
0005432985948	7878C5	9864 092074	DMITRIY KOZLOV	{"phone": "+70903622787"}
0005432985949	1402F7	8832 101232	VERA MOISEEVA	{"email": "moiseevav19041968@postgrespro.ru", "phone": "+70781333061"}
0005432985950	1402F7	8604 468815	VALENTINA PAVLOVA	{"phone": "+70506681221"}
0005432985951	1402F7	5950 270533	DMITRIY MELNIKOV	{"phone": "+70078597886"}
0005432985952	1402F7	1374 304436	SVETLANA TIMOFEEVA	{"email": "stimofeeva-16081974@postgrespro.ru", "phone": "+70394086579"}
0005432985953	20D3A8	4255 842212	OLESYA EGOROVA	{"email": "o.egorova071968@postgrespro.ru", "phone": "+70579721496"}
0005432985954	22E247	6005 112493	LILIYA OSIPOVA	{"email": "osipova_liliya-041965@postgrespro.ru", "phone": "+70092454141"}
0005432985955	DFD27F	9818 246454	ALEKSANDR NAUMOV	{"email": "a-naumov-1970@postgrespro.ru", "phone": "+70825602393"}
0005432985956	21D8A8	7269 799008	EVGENIY CHERNOV	{"phone": "+70196240926"}
0005432985957	0C87E2	6896 987187	EKATERINA KOZLOVA	{"email": "ekozlova_1980@postgrespro.ru", "phone": "+70999926799"}
0005432985958	0C87E2	1081 175350	ELENA ZAYCEVA	{"email": "zayceva_elena.061976@postgrespro.ru", "phone": "+70696499143"}
0005432985959	94A9DA	8240 219981	NATALYA ZAKHAROVA	{"email": "n_zakharova_29091963@postgrespro.ru", "phone": "+70235061061"}
0005432985960	94A9DA	7951 635692	RAFAIL SHEVCHENKO	{"phone": "+70527106138"}
0005432985961	94A9DA	6767 780478	PAVEL ZAKHAROV	{"phone": "+70533149631"}
0005432985962	94A9DA	0006 729373	OLEG VOROBEV	{"email": "o-vorobev.28041978@postgrespro.ru", "phone": "+70849697718"}
0005432985963	2FAD00	1825 812767	NATALYA NIKOLAEVA	{"email": "nikolaeva.natalya.1970@postgrespro.ru", "phone": "+70024583413"}
0005432985964	D7D100	4054 173408	ANATOLIY SMIRNOV	{"email": "anatoliy-smirnov29051976@postgrespro.ru", "phone": "+70513867449"}
0005432985965	2642BD	6948 349805	TATYANA MELNIKOVA	{"phone": "+70156357742"}
0005432985966	2642BD	2643 082902	LARISA PAVLOVA	{"phone": "+70906145821"}
0005432985967	6D5D72	0813 112757	MARINA BARANOVA	{"phone": "+70377079661"}
0005432985968	6D5D72	6088 597338	ANNA IVANOVA	{"phone": "+70906667573"}
0005432985969	EACF88	2815 322843	OLGA STEPANOVA	{"phone": "+70057561950"}
0005432985970	C1E112	9280 552031	VLADISLAV PAVLOV	{"email": "pavlovv1972@postgrespro.ru", "phone": "+70432500176"}
0005432985971	C1E112	8441 493112	OLGA IVANOVA	{"email": "olgaivanova041965@postgrespro.ru", "phone": "+70820676859"}
0005432985972	322290	8281 947448	MARIYA ZAYCEVA	{"email": "zaycevam.061990@postgrespro.ru", "phone": "+70010183073"}
0005432985973	2A8663	4729 228088	GALINA TIKHONOVA	{"email": "tikhonova-galina-27041975@postgrespro.ru", "phone": "+70384606467"}
0005432985974	E53B44	5004 083501	ALEKSEY CHERNOV	{"email": "chernov-a-031973@postgrespro.ru", "phone": "+70257152842"}
0005432985975	2F1BB8	8709 684512	VLADIMIR OSIPOV	{"phone": "+70211852466"}
0005432985976	2F1BB8	2322 186899	LYUDMILA ABRAMOVA	{"email": "lyudmila_abramova.051978@postgrespro.ru", "phone": "+70500449971"}
0005432985977	2E8B37	5900 185535	SVETLANA NIKOLAEVA	{"email": "nikolaeva_s-1970@postgrespro.ru", "phone": "+70371052766"}
0005432985978	2E8B37	4434 035060	SVETLANA SCHERBAKOVA	{"email": "scherbakova_svetlana.31101973@postgrespro.ru", "phone": "+70299290641"}
0005432985979	CCF9E4	0859 312550	TATYANA PETROVA	{"email": "petrovat.091990@postgrespro.ru", "phone": "+70405486305"}
0005432985980	DD7183	5558 356403	VALERIY FROLOV	{"phone": "+70916596866"}
0005432985981	DD7183	1748 096927	VARVARA SERGEEVA	{"phone": "+70792021176"}
0005432985982	8644D9	2091 129353	DENIS STEPANOV	{"email": "d_stepanov1974@postgrespro.ru", "phone": "+70216786743"}
0005432985983	DA1955	5788 950903	ANNA YAKOVLEVA	{"phone": "+70297010871"}
0005432985984	125611	3623 912598	ALEKSANDR GERASIMOV	{"phone": "+70096509436"}
0005432985985	125611	1208 746342	YULIYA KOROLEVA	{"email": "koroleva.y_24031958@postgrespro.ru", "phone": "+70045436506"}
0005432985986	58BDCE	2651 376607	VERONIKA AFANASEVA	{"email": "v_afanaseva23061972@postgrespro.ru", "phone": "+70176716886"}
0005432985987	58BDCE	3399 437500	GEORGIY EGOROV	{"email": "gegorov01081976@postgrespro.ru", "phone": "+70311232029"}
0005432985988	267B1C	9122 974816	OLGA SOLOVEVA	{"email": "olga_soloveva1964@postgrespro.ru", "phone": "+70709950805"}
0005432985989	4F53A5	3751 265784	NATALYA SCHERBAKOVA	{"email": "scherbakova_n-091974@postgrespro.ru", "phone": "+70921346925"}
0005432985990	CC6D62	5003 868532	NIKOLAY SOROKIN	{"email": "sorokinn1969@postgrespro.ru", "phone": "+70953917501"}
0005432985991	CC6D62	7918 715603	ZOYA SERGEEVA	{"email": "zsergeeva1962@postgrespro.ru", "phone": "+70340291364"}
0005432985992	35866C	1860 567341	EVGENIY EGOROV	{"phone": "+70064893528"}
0005432985993	200CF3	2611 908013	SERGEY YAKOVLEV	{"email": "sergey.yakovlev21081970@postgrespro.ru", "phone": "+70817838620"}
0005432985994	E7137D	8261 797040	VLADIMIR MAKSIMOV	{"email": "maksimov_v-10031967@postgrespro.ru", "phone": "+70003622777"}
0005432985995	4D4B92	3084 016868	OLGA KULIKOVA	{"email": "o.kulikova10041968@postgrespro.ru", "phone": "+70121191582"}
0005432985996	4D4B92	6081 739527	ALEKSEY GAVRILOV	{"phone": "+70917150365"}
0005432985997	471E83	3093 376766	DINA FROLOVA	{"phone": "+70034700324"}
0005432985998	341730	4565 232277	ELLA NAZAROVA	{"phone": "+70485752568"}
0005432985999	DF657A	4814 395469	GENNADIY SEMENOV	{"email": "semenov_g011971@postgrespro.ru", "phone": "+70781344521"}
0005432986000	DF657A	6950 926197	VASILIY SMIRNOV	{"phone": "+70407122127"}
0005432986001	9EE072	2046 249643	LYUBOV IVANOVA	{"email": "lyubov_ivanova_1980@postgrespro.ru", "phone": "+70489080974"}
0005432986002	9EE072	7665 629265	TATYANA SEMENOVA	{"phone": "+70739276649"}
0005432986003	9508F2	3410 530919	KIRILL KUZNECOV	{"phone": "+70104087381"}
0005432986004	BAAA80	9948 469789	EVGENIY ABRAMOV	{"email": "abramove.1968@postgrespro.ru", "phone": "+70378684605"}
0005432986005	7CD399	3270 009522	VLADIMIR MAKSIMOV	{"phone": "+70102333387"}
0005432986006	CF2C2A	6563 239157	DMITRIY STEPANOV	{"email": "stepanov.d-071971@postgrespro.ru", "phone": "+70559509786"}
0005432986007	C01B4C	2329 977689	IRINA MELNIKOVA	{"phone": "+70066775355"}
0005432986008	BCC80F	2031 853110	SERGEY ORLOV	{"phone": "+70071402139"}
0005432986009	11331D	2660 546597	VIKTOR STEPANOV	{"email": "stepanov_viktor_07101962@postgrespro.ru", "phone": "+70194218839"}
0005432986010	01DF88	5609 477012	NATALYA DAVYDOVA	{"email": "davydova-n.1965@postgrespro.ru", "phone": "+70772995507"}
0005432986011	0514E4	6249 725717	VLADIMIR GERASIMOV	{"phone": "+70459766185"}
0005432986012	5FF723	0157 439752	ALEKSANDR SIDOROV	{"phone": "+70134721071"}
0005432986013	5FF723	2425 992422	STEPAN KUZMIN	{"phone": "+70697082112"}
0005432986014	322624	8090 093417	NINA EGOROVA	{"phone": "+70469165884"}
0005432986015	322624	4607 252437	SERGEY IVANOV	{"email": "ivanovsergey-091966@postgrespro.ru", "phone": "+70239635799"}
0005432986016	E20C10	9917 340106	EVGENIY KUZNECOV	{"email": "kuznecove.021975@postgrespro.ru", "phone": "+70071999061"}
0005432986017	5EFB80	7613 406613	ALEKSANDR EGOROV	{"phone": "+70941742664"}
0005432986018	5EFB80	3046 486189	NATALYA KOROLEVA	{"email": "natalyakoroleva_16081976@postgrespro.ru", "phone": "+70970960153"}
0005433007822	39F252	2336 538532	DMITRIY ROMANOV	{"email": "dromanov_071969@postgrespro.ru", "phone": "+70000299584"}
0005433007823	B0190A	9740 868496	YURIY ZHURAVLEV	{"phone": "+70980609157"}
0005433007824	16BB8C	5760 609066	ILYA IVANOV	{"email": "ivanovilya071974@postgrespro.ru", "phone": "+70029583372"}
0005433007825	395B96	8539 273772	LYUDMILA MOROZOVA	{"phone": "+70391748364"}
0005433007826	38140D	4605 020720	ALEKSANDR VLASOV	{"phone": "+70295602846"}
0005433007827	38140D	5011 188338	ALEKSANDR BORISOV	{"phone": "+70686009211"}
0005433007828	178C4C	9068 364076	VLADIMIR ANDREEV	{"phone": "+70511611307"}
0005433007829	178C4C	8595 289582	ARTEM MAKSIMOV	{"email": "artem_maksimov-061978@postgrespro.ru", "phone": "+70825360132"}
0005433007830	108AA9	3646 116387	VALENTINA MOISEEVA	{"phone": "+70340901351"}
0005433007831	108AA9	7912 634505	MIKHAIL NOVIKOV	{"email": "novikov-m-1971@postgrespro.ru", "phone": "+70331503035"}
0005433007832	F20FA6	3264 610634	YURIY IVANOV	{"phone": "+70526702240"}
0005433007833	C5316E	9373 683245	ALBINA DAVYDOVA	{"email": "albinadavydova_1970@postgrespro.ru", "phone": "+70130600291"}
0005433007834	5B5B28	9945 930578	DMITRIY KULIKOV	{"phone": "+70170821078"}
0005433007835	B087C8	5288 382854	LIDIYA ARKHIPOVA	{"email": "lidiya.arkhipova_1972@postgrespro.ru", "phone": "+70257492498"}
0005433007836	640B18	4633 755371	NINA EGOROVA	{"email": "nina_egorova_1958@postgrespro.ru", "phone": "+70441631622"}
0005433007837	0D7AA5	9423 604063	NATALYA MELNIKOVA	{"phone": "+70783112532"}
0005433007838	8FE593	0605 420583	IRINA SMIRNOVA	{"email": "smirnova_irina-03011972@postgrespro.ru", "phone": "+70313372141"}
0005433007839	9566D7	2967 133604	MARIYA IVANOVA	{"email": "m-ivanova.101976@postgrespro.ru", "phone": "+70093070800"}
0005433007840	8E3479	7370 072173	VLADIMIR KULIKOV	{"phone": "+70258230788"}
0005433007841	0F79F6	9532 948082	ANTONINA KISELEVA	{"phone": "+70955849334"}
0005433007842	0467E6	8994 258067	MAKSIM RODIONOV	{"phone": "+70737504796"}
0005433007843	1AA8B7	8495 531274	VERONIKA ERMAKOVA	{"phone": "+70793360811"}
0005433007844	7D9401	9329 778284	GALINA SAVELEVA	{"phone": "+70825829176"}
0005433007845	65BB6C	1388 776208	IVAN TARASOV	{"email": "tarasov.ivan_19061963@postgrespro.ru", "phone": "+70871662893"}
0005433007846	65BB6C	5490 215602	LYUDMILA KAZAKOVA	{"phone": "+70751249760"}
0005433007847	4CBC4A	8575 638071	OLGA NIKOLAEVA	{"email": "nikolaeva-olga-1975@postgrespro.ru", "phone": "+70864452405"}
0005433007848	4CBC4A	9795 587617	NATALIYA BELYAEVA	{"phone": "+70238701330"}
0005433007849	25EF35	6012 638995	ALEKSANDR SERGEEV	{"email": "sergeev.aleksandr1983@postgrespro.ru", "phone": "+70308438976"}
0005433007850	379664	9080 170690	RAVIL POPOV	{"email": "popov-r-05081955@postgrespro.ru", "phone": "+70945056113"}
0005433007851	1E9FDB	4715 842510	ELENA EGOROVA	{"email": "egorova_e_121976@postgrespro.ru", "phone": "+70165036147"}
0005433007852	C2A231	2883 658997	LYUDMILA VLASOVA	{"phone": "+70695221133"}
0005433007853	A69A05	4880 235977	ANNA TITOVA	{"phone": "+70390361054"}
0005433007854	442EC5	1503 520005	LYUDMILA TIMOFEEVA	{"phone": "+70883396027"}
0005433007855	098F33	1256 513304	SERGEY NIKITIN	{"phone": "+70225073676"}
0005433007856	098F33	8799 671917	VALERIY STEPANOV	{"email": "valeriy_stepanov.06041970@postgrespro.ru", "phone": "+70718548410"}
0005433007857	B9F8C2	8481 904960	TAMARA KALININA	{"phone": "+70302133144"}
0005433007858	939A43	3068 770934	VIKTOR SCHERBAKOV	{"email": "viktorscherbakov1971@postgrespro.ru", "phone": "+70098721863"}
0005433007859	58319A	8070 557395	SVETLANA NAZAROVA	{"phone": "+70529479520"}
0005433007860	402460	5052 155277	ROMAN OSIPOV	{"phone": "+70282412820"}
0005433007861	38214E	8975 237778	VALENTINA MIRONOVA	{"email": "mironova_v-14051961@postgrespro.ru", "phone": "+70329140436"}
0005433007862	BF0BBD	1468 419725	SERGEY IVANOV	{"email": "s.ivanov-1977@postgrespro.ru", "phone": "+70006254957"}
0005433007863	BF0BBD	0024 776708	ALEKSANDR SEMENOV	{"phone": "+70878436385"}
0005433007864	851E8F	7529 844461	PAVEL KUZNECOV	{"email": "p-kuznecov.1976@postgrespro.ru", "phone": "+70297408152"}
0005433007865	FD9BD3	6212 360329	RAISA NESTEROVA	{"phone": "+70396611739"}
0005433007866	FD9BD3	3985 253911	YULIYA KOMAROVA	{"email": "komarova-yuliya-10121968@postgrespro.ru", "phone": "+70497691733"}
0005433007867	FD9BD3	9231 718265	GALINA NIKITINA	{"email": "nikitina.galina_121965@postgrespro.ru", "phone": "+70517670939"}
0005433007868	ED2C76	4340 325349	ALEKSEY MATVEEV	{"phone": "+70271233330"}
0005433007869	2B1B51	1424 048751	VALERIY SIDOROV	{"email": "vsidorov.091974@postgrespro.ru", "phone": "+70376196472"}
0005433007870	2B1B51	0534 032551	ELENA NOVIKOVA	{"phone": "+70700156292"}
0005433007871	B70FB9	8070 470902	ANASTASIYA STEPANOVA	{"phone": "+70420284669"}
0005433007872	61C04F	3356 455114	MARIYA NAZAROVA	{"email": "m_nazarova1976@postgrespro.ru", "phone": "+70001075481"}
0005433007873	21F314	5866 060002	ALEKSANDR DENISOV	{"phone": "+70010044892"}
0005433007874	21F314	3958 634722	VARVARA KUZNECOVA	{"email": "kuznecova.varvara-051970@postgrespro.ru", "phone": "+70607749340"}
0005433007875	B508CF	6203 758800	DMITRIY KISELEV	{"email": "kiselevd121971@postgrespro.ru", "phone": "+70225485740"}
0005433007876	B508CF	7281 663191	YULIYA KUZNECOVA	{"email": "kuznecovay-1973@postgrespro.ru", "phone": "+70269870008"}
0005433007877	997F68	0957 194373	SOFIYA DENISOVA	{"phone": "+70572897560"}
0005433007878	5DBE69	7899 967076	KIRILL PETROV	{"phone": "+70650718812"}
0005433007879	5DBE69	4806 315481	NINA PETROVA	{"email": "n_petrova_1966@postgrespro.ru", "phone": "+70055706691"}
0005433007880	8149AB	6967 884083	SVETLANA ILINA	{"email": "svetlana_ilina071964@postgrespro.ru", "phone": "+70063202737"}
0005433007881	006132	1667 116592	IVAN MIKHAYLOV	{"email": "mikhaylov.ivan.091978@postgrespro.ru", "phone": "+70634721994"}
0005433007882	006132	0168 505614	EVGENIYA ROMANOVA	{"phone": "+70802546375"}
0005433007883	1B135E	6039 917933	MIROSLAV CHERNOV	{"email": "chernov_miroslav_13101968@postgrespro.ru", "phone": "+70179792776"}
0005433007884	F2467F	0517 582418	ZOYA ARKHIPOVA	{"phone": "+70212809107"}
0005433007885	BA681C	9943 541103	VLADIMIR POPOV	{"email": "vladimir_popov_1961@postgrespro.ru", "phone": "+70862384315"}
0005433007886	22BD86	3263 969215	EKATERINA MIKHAYLOVA	{"phone": "+70861314599"}
0005433007887	22BD86	1617 715821	MIKHAIL SEMENOV	{"phone": "+70981880323"}
0005433007888	A0EFEC	6037 481693	NADEZHDA NAZAROVA	{"email": "nazarova_n19061969@postgrespro.ru", "phone": "+70846509232"}
0005433007889	E9DC65	6792 464955	VALENTIN VOROBEV	{"email": "vorobev-valentin-27101973@postgrespro.ru", "phone": "+70696261458"}
0005433007890	FC847F	0337 099978	OLGA KOROLEVA	{"email": "koroleva.olga-1960@postgrespro.ru", "phone": "+70357498623"}
0005433007891	C6E5E7	8635 654824	ILDAR VOROBEV	{"email": "vorobev_ildar.08011983@postgrespro.ru", "phone": "+70329123378"}
0005433007892	CF1A92	1711 873051	TAMARA GORBUNOVA	{"email": "gorbunova_t11091982@postgrespro.ru", "phone": "+70836412943"}
0005433007893	9FFCBE	8957 393601	EKATERINA IVANOVA	{"email": "ivanova.ekaterina_1969@postgrespro.ru", "phone": "+70538294293"}
0005433007894	B2DA67	4862 375008	KIRILL VASILEV	{"email": "vasilev-k1975@postgrespro.ru", "phone": "+70209723924"}
0005433007895	D37611	0740 210870	ZOYA RODIONOVA	{"email": "z.rodionova.03111968@postgrespro.ru", "phone": "+70316341061"}
0005433007896	6007B2	3685 105654	ALEKSANDR DMITRIEV	{"phone": "+70611870229"}
0005433007897	C5BB92	0141 108361	EKATERINA ISAEVA	{"phone": "+70773142244"}
0005433007898	C5BB92	4737 050431	MARINA FEDOROVA	{"phone": "+70088911100"}
0005433007899	8709EE	4210 528460	MIKHAIL GRIGOREV	{"email": "grigorev.m_1983@postgrespro.ru", "phone": "+70150803424"}
0005433007900	70CA7E	4000 309038	TATYANA MALYSHEVA	{"email": "malysheva-t-1967@postgrespro.ru", "phone": "+70670307092"}
0005433007901	70CA7E	2442 196462	NIKOLAY VOLKOV	{"phone": "+70010672690"}
0005433007902	DA1DD6	7708 385655	ANDREY EGOROV	{"email": "a.egorov_26041971@postgrespro.ru", "phone": "+70318104550"}
0005433007903	DA1DD6	1319 140500	ILDAR CHERNOV	{"phone": "+70429762620"}
0005433007904	0C0BED	2254 396358	ELENA STEPANOVA	{"email": "stepanovae1971@postgrespro.ru", "phone": "+70604087346"}
0005433007905	0C0BED	5722 409506	ALEKSANDR DENISOV	{"email": "denisov.aleksandr1973@postgrespro.ru", "phone": "+70269144795"}
0005433007906	5C9697	9484 333046	ANATOLIY POPOV	{"phone": "+70161190784"}
0005433007907	FF2CFA	1373 950091	NATALYA NESTEROVA	{"phone": "+70106767002"}
0005433007908	7229A6	4228 515003	PETR FROLOV	{"email": "frolovpetr_121975@postgrespro.ru", "phone": "+70439213379"}
0005433007909	29C42D	1586 371486	EKATERINA PAVLOVA	{"email": "ekaterina-pavlova.121979@postgrespro.ru", "phone": "+70249599728"}
0005433007910	9ABB3C	1276 697938	ANDREY GERASIMOV	{"phone": "+70279962144"}
0005433007911	9ABB3C	1683 908790	SVETLANA MIKHAYLOVA	{"phone": "+70892415189"}
0005433007912	A64F3D	0042 426036	MIKHAIL ZAYCEV	{"phone": "+70998578803"}
0005433007913	D7BE1D	4647 331982	NINA GUSEVA	{"email": "ninaguseva1969@postgrespro.ru", "phone": "+70049671340"}
0005433007914	9EB3D0	8839 880873	ALEKSANDRA MAKAROVA	{"phone": "+70451242553"}
0005433007915	9AED82	0712 678489	ELENA SOKOLOVA	{"email": "sokolovae_22111974@postgrespro.ru", "phone": "+70349011009"}
0005433007916	9AED82	8752 203978	YURIY NIKITIN	{"phone": "+70329296831"}
0005433007917	575AB2	4299 850984	ANTONINA ANTONOVA	{"email": "antonova.antonina.051977@postgrespro.ru", "phone": "+70245197568"}
0005433007918	23539C	9746 187232	ALEKSANDR SOROKIN	{"phone": "+70579695363"}
0005433007919	23539C	0799 618429	VERA ARKHIPOVA	{"email": "vera_arkhipova.1981@postgrespro.ru", "phone": "+70585542674"}
0005433007920	BE1C7A	5080 593170	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey-011971@postgrespro.ru", "phone": "+70799035311"}
0005433007921	BE1C7A	8683 504391	EKATERINA RODIONOVA	{"email": "ekaterinarodionova-1967@postgrespro.ru", "phone": "+70735633156"}
0005433007922	B29013	4684 466670	RENAT MAKAROV	{"phone": "+70565355636"}
0005433007923	E7F24E	1697 593879	ALEKSANDR SOROKIN	{"phone": "+70414198489"}
0005433007924	E7F24E	6268 750860	TAMARA EGOROVA	{"phone": "+70600192272"}
0005433007925	6FFDE8	7959 889217	ARTEM KONOVALOV	{"phone": "+70428067813"}
0005433007926	232BF9	9475 288140	SERGEY ZAYCEV	{"phone": "+70112861046"}
0005433007927	B1AC15	6738 479383	BOGDAN KUZNECOV	{"phone": "+70016616352"}
0005433007928	8BC7A3	3349 568107	ZINAIDA ILINA	{"phone": "+70299630451"}
0005433007929	5A0850	5873 339140	YULIYA GERASIMOVA	{"email": "yuliya_gerasimova-091965@postgrespro.ru", "phone": "+70453393598"}
0005433007930	A8290A	8103 973393	ZOYA KOZLOVA	{"phone": "+70480108583"}
0005433007931	9FC322	0169 617792	MARIYA ZAKHAROVA	{"phone": "+70444551733"}
0005433007932	24F8D5	9604 883768	ELENA KAZAKOVA	{"phone": "+70371985816"}
0005433007933	6C6D1A	4291 391388	VLADIMIR ANTONOV	{"email": "v.antonov-061962@postgrespro.ru", "phone": "+70582659344"}
0005433007934	6C6D1A	8875 727075	MAKSIM PAVLOV	{"phone": "+70546766502"}
0005433007935	41F732	3013 063829	VASILIY IVANOV	{"email": "ivanov.vasiliy.02121975@postgrespro.ru", "phone": "+70268036660"}
0005433007936	41F732	6966 616127	DMITRIY SOROKIN	{"phone": "+70929402558"}
0005433007937	9C152E	9874 336193	ANATOLIY PETROV	{"phone": "+70556983662"}
0005433007938	256B47	1444 349338	MAKSIM IVANOV	{"phone": "+70312001879"}
0005433007939	256B47	5715 127274	ANATOLIY KUZNECOV	{"phone": "+70821007124"}
0005433007940	EF9193	9983 663463	GALINA STEPANOVA	{"email": "stepanovagalina09121980@postgrespro.ru", "phone": "+70705998399"}
0005433007941	AE72D3	9666 155698	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.041970@postgrespro.ru", "phone": "+70268910591"}
0005433007942	AE72D3	4342 874771	LYUCIYA EGOROVA	{"email": "egorova_l-29011971@postgrespro.ru", "phone": "+70877074929"}
0005433007943	905F51	9852 882891	VASILIY ZAKHAROV	{"phone": "+70582329892"}
0005433007944	905F51	1675 996467	OLGA VLASOVA	{"email": "vlasova-olga_1969@postgrespro.ru", "phone": "+70287050964"}
0005433007945	B03655	9980 100800	VYACHESLAV OSIPOV	{"phone": "+70861379069"}
0005433007946	0C9BCB	7311 480234	ANTON DENISOV	{"email": "antondenisov.03011977@postgrespro.ru", "phone": "+70774588293"}
0005433007947	0C9BCB	3194 899292	MIKHAIL NAUMOV	{"email": "naumovm-1976@postgrespro.ru", "phone": "+70480585495"}
0005433007948	55C537	2977 111136	ROMAN VASILEV	{"email": "vasilevr1971@postgrespro.ru", "phone": "+70379625972"}
0005433007949	F84C89	2969 527307	MARIYA SOLOVEVA	{"email": "mariya_soloveva_041961@postgrespro.ru", "phone": "+70200947298"}
0005433007950	7FEBD7	2972 937230	NIKOLAY DAVYDOV	{"email": "davydov.n_1971@postgrespro.ru", "phone": "+70091263904"}
0005433007951	1B5096	4300 787561	SVETLANA MOISEEVA	{"phone": "+70807134749"}
0005433007952	1B5096	6646 869019	ANTONINA SOROKINA	{"email": "antoninasorokina30061972@postgrespro.ru", "phone": "+70889350577"}
0005433007953	21566D	8060 119062	ALEKSANDR PETROV	{"email": "petrovaleksandr-1968@postgrespro.ru", "phone": "+70845775784"}
0005433007954	9C8D28	3538 607810	VASILIY KULIKOV	{"email": "kulikov-v_081978@postgrespro.ru", "phone": "+70648912377"}
0005433007955	F9E7AC	6289 172784	ZOYA ALEKSEEVA	{"email": "alekseevazoya1970@postgrespro.ru", "phone": "+70253975337"}
0005433007956	9A7A67	6967 266130	ALEKSEY PAVLOV	{"email": "apavlov_031975@postgrespro.ru", "phone": "+70913245398"}
0005433007957	9A7A67	9239 924002	SERGEY ZAYCEV	{"email": "sergey.zaycev.1963@postgrespro.ru", "phone": "+70291157682"}
0005433007958	3B254C	2771 226142	ALEKSEY KUZNECOV	{"email": "a-kuznecov_24071973@postgrespro.ru", "phone": "+70526238621"}
0005433007959	3B254C	3682 338499	ANATOLIY GAVRILOV	{"email": "gavrilov.a051979@postgrespro.ru", "phone": "+70416877017"}
0005433007960	8A5D0C	2785 523872	ANNA SERGEEVA	{"email": "sergeeva-anna-04041968@postgrespro.ru", "phone": "+70240520308"}
0005433007961	6B199B	8076 395962	ROMAN BONDARENKO	{"phone": "+70026019743"}
0005433007962	6B199B	8235 931095	SHAMIL PETROV	{"phone": "+70638255194"}
0005433007963	B23380	4350 515592	VALENTINA BORISOVA	{"email": "borisova_v_1978@postgrespro.ru", "phone": "+70679255091"}
0005433007964	87BC15	0402 954839	LYUDMILA KOMAROVA	{"email": "komarova-lyudmila27111973@postgrespro.ru", "phone": "+70071558863"}
0005433007965	5D052E	8079 878229	MARIYA ORLOVA	{"email": "m-orlova.051978@postgrespro.ru", "phone": "+70930385366"}
0005433007966	5D052E	9305 978391	DANIIL KOZLOV	{"email": "daniil.kozlov.12041967@postgrespro.ru", "phone": "+70931809139"}
0005433007967	5E5C72	9908 772144	ROMAN KUZNECOV	{"phone": "+70961237371"}
0005433007968	46189E	5028 024728	ELENA GUSEVA	{"email": "guseva_e_14041979@postgrespro.ru", "phone": "+70258023423"}
0005433007969	C4BAF1	0891 426943	GALINA PETROVA	{"phone": "+70472929226"}
0005433007970	C4BAF1	5814 444696	ANTONINA ZHUKOVA	{"email": "antonina_zhukova.011972@postgrespro.ru", "phone": "+70427614080"}
0005433007971	C4BAF1	7174 478994	ALEKSANDR IVANOV	{"email": "a.ivanov.05121966@postgrespro.ru", "phone": "+70354637161"}
0005433007972	E5BCBE	2279 980360	NIKOLAY ZAYCEV	{"email": "zaycevnikolay_1966@postgrespro.ru", "phone": "+70536275295"}
0005433007973	E5BCBE	3066 788619	GALINA SOROKINA	{"email": "galina_sorokina-1975@postgrespro.ru", "phone": "+70409888373"}
0005433007974	807C95	7892 040767	ELENA SEMENOVA	{"phone": "+70931372545"}
0005433007975	807C95	1518 138177	NIKOLAY ALEKSEEV	{"phone": "+70541369887"}
0005433007976	5AE10B	0448 576053	VALENTINA NIKITINA	{"email": "nikitinavalentina-031967@postgrespro.ru", "phone": "+70920520608"}
0005433007977	B0D034	8781 736990	ANDREY MAKAROV	{"phone": "+70162664610"}
0005433007978	4B8A1E	8626 964710	LYUDMILA KAZAKOVA	{"email": "kazakova-l091960@postgrespro.ru", "phone": "+70637114054"}
0005433007979	5822B3	9337 011288	VERA KONDRATEVA	{"phone": "+70157684061"}
0005433007980	5822B3	1957 629233	NIKOLAY POPOV	{"phone": "+70540948335"}
0005433007981	A52296	1103 380473	NINA KARPOVA	{"email": "n_karpova_071984@postgrespro.ru", "phone": "+70850143239"}
0005433007982	A52296	2614 320827	NINA FADEEVA	{"email": "fadeeva.n-14031956@postgrespro.ru", "phone": "+70722473140"}
0005433007983	FD920A	6607 630281	YURIY BARANOV	{"phone": "+70290747480"}
0005433007984	6A324A	3853 782175	IRINA SERGEEVA	{"email": "sergeeva.i-06041975@postgrespro.ru", "phone": "+70537286229"}
0005433007985	574BE7	4684 884760	YURIY IVANOV	{"email": "yuriy.ivanov_1984@postgrespro.ru", "phone": "+70793812073"}
0005433007986	574BE7	5150 485608	VITALIY ANDREEV	{"email": "v.andreev20021967@postgrespro.ru", "phone": "+70496098469"}
0005433007987	574BE7	2005 181234	VLADIMIR PAVLOV	{"email": "pavlovvladimir.26101970@postgrespro.ru", "phone": "+70715631018"}
0005433007988	84C487	5808 283222	ELENA IVANOVA	{"email": "e_ivanova101977@postgrespro.ru", "phone": "+70763764415"}
0005433007989	84C487	3251 511298	DMITRIY SHEVCHENKO	{"email": "shevchenko_d_03071972@postgrespro.ru", "phone": "+70068193761"}
0005433007990	84C487	9733 738012	MARIYA ROMANOVA	{"phone": "+70871740463"}
0005433007991	84C487	3937 087416	ALEKSANDR IVANOV	{"phone": "+70587245230"}
0005433007992	B17554	1667 733388	OLGA STEPANOVA	{"phone": "+70859125171"}
0005433007993	C3B679	1228 384692	PAVEL KUZNECOV	{"phone": "+70411608833"}
0005433007994	F12604	0174 909099	ALEKSEY VASILEV	{"email": "vasilev_a-11061972@postgrespro.ru", "phone": "+70048730914"}
0005433007995	F12604	0357 138220	NATALYA PETROVA	{"phone": "+70759332245"}
0005433007996	270962	2983 607514	PAVEL KOZLOV	{"email": "pavel_kozlov.051974@postgrespro.ru", "phone": "+70099120556"}
0005433007997	8EE1E2	6181 347496	VALENTINA SERGEEVA	{"phone": "+70002320709"}
0005433007998	D28DD8	2392 754037	ANDREY VOROBEV	{"email": "vorobev.andrey_081958@postgrespro.ru", "phone": "+70767963254"}
0005433007999	D28DD8	0668 146644	SVETLANA ARKHIPOVA	{"phone": "+70913479868"}
0005433008000	333DC7	8584 860411	ANNA BELYAEVA	{"phone": "+70067546352"}
0005433008001	333DC7	4706 717513	EVGENIY ZAKHAROV	{"email": "ezakharov27111973@postgrespro.ru", "phone": "+70046667883"}
0005433008002	084EAD	0399 530309	ALISA IVANOVA	{"email": "alisaivanova051975@postgrespro.ru", "phone": "+70771376792"}
0005433008003	084EAD	7582 796945	SVETLANA LOGINOVA	{"phone": "+70961820248"}
0005433008004	084EAD	4951 313534	VALERIY NAZAROV	{"phone": "+70336434583"}
0005433008005	97D543	0882 018009	DMITRIY GAVRILOV	{"email": "dmitriy_gavrilov-1968@postgrespro.ru", "phone": "+70472375730"}
0005433008006	5EAA4F	4410 005985	VALENTIN PETROV	{"phone": "+70146481810"}
0005433008007	B76B03	6441 264597	STANISLAV MARTYNOV	{"phone": "+70010433879"}
0005433008008	B4ED83	3308 060573	ILYA SAVELEV	{"email": "savelev.ilya_31011979@postgrespro.ru", "phone": "+70445055197"}
0005433008009	C92412	0303 014821	IRINA MIKHAYLOVA	{"phone": "+70353235116"}
0005433008010	788BC8	6429 512957	SVETLANA VLASOVA	{"email": "vlasova.svetlana.1974@postgrespro.ru", "phone": "+70975715515"}
0005433008011	788BC8	6759 898816	BORIS POPOV	{"phone": "+70887153084"}
0005433008012	788BC8	2968 565821	MAKSIM ABRAMOV	{"email": "maksim.abramov-041966@postgrespro.ru", "phone": "+70103999371"}
0005433008013	0B7FFE	8325 904088	SVETLANA SOLOVEVA	{"email": "soloveva_svetlana.051973@postgrespro.ru", "phone": "+70028257027"}
0005433008014	021348	5020 512263	ALEKSEY RODIONOV	{"phone": "+70217954772"}
0005433008015	021348	3970 973436	DENIS ILIN	{"phone": "+70966794363"}
0005433008016	363BFC	6937 764683	NINA PETROVA	{"email": "petrova-nina-121981@postgrespro.ru", "phone": "+70122144245"}
0005433008017	D03777	1524 519962	TATYANA RYABOVA	{"email": "ryabova-t031980@postgrespro.ru", "phone": "+70615822092"}
0005433008018	A3B398	1934 054588	ALLA IVANOVA	{"phone": "+70362188294"}
0005433008019	A3B398	6965 355994	NIKITA MOROZOV	{"email": "morozovnikita.031969@postgrespro.ru", "phone": "+70304629942"}
0005433008020	9EF84F	6130 360084	EVGENIY SIDOROV	{"email": "sidorov-e091968@postgrespro.ru", "phone": "+70389905632"}
0005433008021	7FD2CC	2389 005928	DMITRIY KOZLOV	{"phone": "+70309062953"}
0005433008022	22771B	0276 629296	ALEKSANDR DMITRIEV	{"phone": "+70769943035"}
0005433008023	22771B	9239 276877	ANTON DAVYDOV	{"phone": "+70879924332"}
0005433008024	7D9C5A	6287 389200	ELENA FROLOVA	{"email": "e_frolova021970@postgrespro.ru", "phone": "+70152218719"}
0005433008025	6AB131	0622 663565	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr-081984@postgrespro.ru", "phone": "+70144863822"}
0005433008026	4062AE	8002 281519	SERGEY ROMANOV	{"phone": "+70659718700"}
0005433008027	C1C7A8	2570 303005	ANNA EGOROVA	{"phone": "+70684518432"}
0005433008028	C1C7A8	6450 163409	VALERIY ZHUKOV	{"email": "valeriy-zhukov-25081963@postgrespro.ru", "phone": "+70528038507"}
0005433008029	DFE7F5	4935 832237	VIKTORIYA AFANASEVA	{"email": "afanasevav_1979@postgrespro.ru", "phone": "+70762332023"}
0005433008030	18A3E9	0690 025916	EKATERINA ZHUKOVA	{"phone": "+70380174530"}
0005433008031	18A3E9	9083 627696	STEPAN MAKAROV	{"phone": "+70224607227"}
0005433008032	18A3E9	7452 898448	ALEKSEY AFANASEV	{"email": "a.afanasev101984@postgrespro.ru", "phone": "+70670507708"}
0005433008033	A03CD2	7276 997984	OLGA RODIONOVA	{"phone": "+70200934419"}
0005433008034	C43E01	2421 174937	VIKTOR VASILEV	{"email": "vasilev_viktor.121955@postgrespro.ru", "phone": "+70277343691"}
0005433008035	7AF874	8386 294847	IRINA NOVIKOVA	{"email": "i-novikova_021970@postgrespro.ru", "phone": "+70264684227"}
0005433008036	7AF874	6477 812454	ROMAN POPOV	{"phone": "+70574611182"}
0005433008037	7AF874	2728 491008	GALINA MIRONOVA	{"email": "mironova.g.01091970@postgrespro.ru", "phone": "+70237566231"}
0005433008038	510725	0347 776748	NIKOLAY FROLOV	{"phone": "+70052318688"}
0005433008039	D961D6	4391 998073	ANDREY KOROLEV	{"phone": "+70517008507"}
0005433008040	CD50D4	4793 399022	VIKTORIYA KUZMINA	{"email": "viktoriya-kuzmina-051980@postgrespro.ru", "phone": "+70500961407"}
0005433008041	EB01E6	2703 813808	VYACHESLAV KUZNECOV	{"phone": "+70932511681"}
0005433008042	FC700B	5542 932031	SERGEY ILIN	{"email": "ilin-s-07101970@postgrespro.ru", "phone": "+70868002361"}
0005433008043	FC700B	1403 447567	VALENTINA ZAKHAROVA	{"email": "zakharova.valentina-1963@postgrespro.ru", "phone": "+70522666290"}
0005433008044	260B85	5802 821269	IRINA MIKHAYLOVA	{"email": "imikhaylova_1971@postgrespro.ru", "phone": "+70812244865"}
0005433008045	0B0C9C	3204 395831	ELENA RYABOVA	{"email": "ryabova.e061978@postgrespro.ru", "phone": "+70254394972"}
0005433008046	B645CF	7776 040927	VLADIMIR NOVIKOV	{"phone": "+70465865086"}
0005433008047	B645CF	2037 596620	ANNA PETROVA	{"email": "petrova.anna.1979@postgrespro.ru", "phone": "+70170633479"}
0005433008048	FA6C1E	4323 075520	SEMEN BORISOV	{"email": "semenborisov_1978@postgrespro.ru", "phone": "+70528737112"}
0005433008049	9CC1D0	7882 383258	ALEKSEY ZAYCEV	{"email": "aleksey_zaycev-021966@postgrespro.ru", "phone": "+70536963605"}
0005433008050	9CC1D0	7044 935821	ALEKSANDR FROLOV	{"phone": "+70604247589"}
0005433008051	569590	0671 560774	ALEKSEY ANDREEV	{"phone": "+70623406408"}
0005433008052	569590	1063 288754	ANATOLIY MELNIKOV	{"email": "a_melnikov1967@postgrespro.ru", "phone": "+70867522930"}
0005433008053	D4E797	3489 349353	IRINA NIKIFOROVA	{"phone": "+70472170141"}
0005433008054	D4E797	9263 892326	DMITRIY SCHERBAKOV	{"phone": "+70141034812"}
0005433008055	9CFDC1	3924 585290	SERGEY DENISOV	{"email": "sergeydenisov-02081971@postgrespro.ru", "phone": "+70484442637"}
0005433008056	CD6EAA	7182 971446	TAMARA KAZAKOVA	{"phone": "+70218203288"}
0005433008057	2226E4	1154 744692	ALEKSEY KUDRYASHOV	{"phone": "+70769166669"}
0005433008058	F29B12	4363 633226	TATYANA NIKOLAEVA	{"email": "nikolaeva.tatyana061961@postgrespro.ru", "phone": "+70679974013"}
0005433008059	E51B82	7700 046607	LYUDMILA SERGEEVA	{"email": "sergeeval-041978@postgrespro.ru", "phone": "+70493477816"}
0005433008060	2C4910	4393 159566	ANATOLIY TIMOFEEV	{"email": "timofeev-a101970@postgrespro.ru", "phone": "+70216515645"}
0005433008061	2C4910	8799 687743	TATYANA POPOVA	{"phone": "+70797806728"}
0005433008062	E83D5A	9032 740663	EKATERINA YAKOVLEVA	{"phone": "+70700913625"}
0005433008063	AE7C52	6851 285007	GALINA BELYAEVA	{"email": "belyaeva-galina-23091974@postgrespro.ru", "phone": "+70855889528"}
0005433008064	253C74	0019 862810	OLGA ANISIMOVA	{"phone": "+70129579463"}
0005433008065	253C74	8171 875220	NIKITA VLASOV	{"phone": "+70597905144"}
0005433008066	9A1BD5	2315 514166	ALEKSEY ABRAMOV	{"email": "a_abramov_091976@postgrespro.ru", "phone": "+70754843848"}
0005433008067	9A1BD5	9690 702151	DMITRIY KUZNECOV	{"phone": "+70961733840"}
0005433008068	841EB0	2533 927906	ELENA KOLESNIKOVA	{"email": "e.kolesnikova11071955@postgrespro.ru", "phone": "+70066750547"}
0005433008069	841EB0	2864 505877	MARINA DANILOVA	{"email": "marina.danilova.09111973@postgrespro.ru", "phone": "+70809463570"}
0005433008070	6EA3CE	8757 887239	TAMARA BARANOVA	{"phone": "+70633383368"}
0005433008071	F26633	4439 203243	PETR KOROLEV	{"phone": "+70139690573"}
0005433008072	F26633	9881 546433	TATYANA YAKOVLEVA	{"email": "tyakovleva101968@postgrespro.ru", "phone": "+70811662451"}
0005433008073	A98138	5585 483402	SVETLANA NAUMOVA	{"email": "naumovasvetlana-1967@postgrespro.ru", "phone": "+70539790213"}
0005433008074	A98138	9515 338344	NIKOLAY KOZLOV	{"email": "kozlovn-1971@postgrespro.ru", "phone": "+70354593484"}
0005433008075	2EED0A	8930 578922	ANNA TIKHONOVA	{"email": "anna.tikhonova29081980@postgrespro.ru", "phone": "+70440996281"}
0005433008076	B399FE	8589 196484	DMITRIY SIDOROV	{"email": "sidorov-dmitriy_11041978@postgrespro.ru", "phone": "+70195532782"}
0005433008077	444E3B	5205 631043	KAMILLA GORBUNOVA	{"phone": "+70734581127"}
0005433008078	7100FE	6512 530623	IGOR CHERNOV	{"email": "igorchernov.1975@postgrespro.ru", "phone": "+70791419288"}
0005433008079	85CAFD	7585 564037	ALEKSANDR PETROV	{"phone": "+70234757500"}
0005433008080	C1D8E3	0773 699353	ALEKSEY KUZNECOV	{"phone": "+70980408501"}
0005433008081	C1D8E3	7505 548876	NIKITA TIMOFEEV	{"email": "timofeev_nikita_15091965@postgrespro.ru", "phone": "+70253811211"}
0005433008082	1C9D8D	5478 538717	NADEZHDA RODIONOVA	{"phone": "+70596187245"}
0005433008083	1C9D8D	7189 234295	LYUDMILA DANILOVA	{"phone": "+70721164174"}
0005433008084	79C2C1	7336 920828	VIKTOR TIMOFEEV	{"email": "viktor.timofeev_1980@postgrespro.ru", "phone": "+70111671059"}
0005433008085	CF3025	1240 337982	LEONID NIKITIN	{"phone": "+70975696071"}
0005433008086	3379B2	7845 276910	RIMMA ORLOVA	{"phone": "+70578113572"}
0005433008087	CD8091	9180 385431	LYUDMILA GAVRILOVA	{"email": "gavrilova.l.011971@postgrespro.ru", "phone": "+70099176238"}
0005433008088	1F330E	9987 956687	ROMAN KUZNECOV	{"email": "kuznecovroman_071976@postgrespro.ru", "phone": "+70715242003"}
0005433008089	1F330E	3720 433820	EVGENIYA FILIPPOVA	{"phone": "+70512764712"}
0005433008090	B494FB	6078 187366	GENNADIY NAUMOV	{"email": "naumovg_02041957@postgrespro.ru", "phone": "+70602692093"}
0005433008091	022176	8209 386122	TATYANA POPOVA	{"email": "t-popova1976@postgrespro.ru", "phone": "+70186683228"}
0005433008092	022176	8904 347294	VALERIY FEDOROV	{"email": "fedorov-valeriy1965@postgrespro.ru", "phone": "+70739837638"}
0005433008093	49D480	5013 009998	LIDIYA EGOROVA	{"phone": "+70184972294"}
0005433008094	B6B29F	3406 849375	YURIY KUZNECOV	{"email": "ykuznecov061972@postgrespro.ru", "phone": "+70122793013"}
0005433008095	B6B29F	3783 526371	SERGEY SOROKIN	{"email": "s_sorokin_051969@postgrespro.ru", "phone": "+70258131321"}
0005433008096	9D7936	8344 284257	VERA SIDOROVA	{"phone": "+70944103548"}
0005433008097	9D7936	2904 610711	KIRILL RODIONOV	{"email": "kirill-rodionov011975@postgrespro.ru", "phone": "+70789535381"}
0005433008098	9D7936	1666 845833	ANASTASIYA AKIMOVA	{"email": "a.akimova021966@postgrespro.ru", "phone": "+70839009908"}
0005433008099	483A3D	1429 708881	SVETLANA MARTYNOVA	{"email": "svetlana-martynova.23101971@postgrespro.ru", "phone": "+70414937719"}
0005433008100	CB1B3B	1568 899205	ANTON KRASNOV	{"phone": "+70703276079"}
0005433008101	CB1B3B	7581 563198	IRINA FOMINA	{"email": "fomina_i_04091973@postgrespro.ru", "phone": "+70068459257"}
0005433008102	CB1B3B	8730 793295	LUIZA KUZMINA	{"email": "kuzminaluiza111972@postgrespro.ru", "phone": "+70488249053"}
0005433008103	B05893	3581 014163	VYACHESLAV SIDOROV	{"email": "sidorov-vyacheslav.091975@postgrespro.ru", "phone": "+70253626893"}
0005433008104	B05893	7662 686494	OKSANA KUZNECOVA	{"email": "kuznecova.o-101972@postgrespro.ru", "phone": "+70817221089"}
0005433008105	D6D691	3217 863275	PAVEL IVANOV	{"phone": "+70505342085"}
0005433008106	878B15	4527 583355	OLGA NAZAROVA	{"phone": "+70480747279"}
0005433008107	627DB0	9704 017597	NATALIYA FADEEVA	{"phone": "+70554603908"}
0005433008108	823CF8	1919 140007	BORIS BORISOV	{"phone": "+70816056199"}
0005433008109	63960B	3036 660470	VLADIMIR GRIGOREV	{"phone": "+70202517701"}
0005433008110	B44ADE	6753 285695	IRINA LEBEDEVA	{"phone": "+70312068831"}
0005433008111	92C09B	0994 453589	ALEKSEY SOKOLOV	{"phone": "+70265461139"}
0005433008112	BAC991	2154 606304	DARYA KUZNECOVA	{"phone": "+70304552127"}
0005433008113	407F59	8834 310660	ANATOLIY MIKHAYLOV	{"email": "mikhaylov.a.121973@postgrespro.ru", "phone": "+70080606864"}
0005433008114	407F59	6859 787490	ALEKSANDR DENISOV	{"phone": "+70829633141"}
0005433008115	CE3E4A	3360 976070	DENIS SCHERBAKOV	{"email": "denis-scherbakov1979@postgrespro.ru", "phone": "+70094271392"}
0005433008116	CF42B6	9176 516070	ALEKSEY ORLOV	{"email": "orlov_a-1976@postgrespro.ru", "phone": "+70551732830"}
0005433008117	65F0C6	0315 789460	ALEKSEY ORLOV	{"phone": "+70724968218"}
0005433008118	A17C3B	9138 295525	TATYANA ILINA	{"email": "ilina-t_28111971@postgrespro.ru", "phone": "+70638078680"}
0005433008119	A17C3B	1000 551926	MARIYA FOMINA	{"phone": "+70808328989"}
0005433008120	0BE364	2309 556523	LARISA MALYSHEVA	{"email": "larisa_malysheva-111968@postgrespro.ru", "phone": "+70380782445"}
0005433008121	8E732C	2388 496361	ALEKSEY BORISOV	{"email": "borisova-1973@postgrespro.ru", "phone": "+70158433997"}
0005433008122	DC8BE8	5437 122995	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila_1969@postgrespro.ru", "phone": "+70107748145"}
0005433008123	1F61C5	0898 314079	KSENIYA RODIONOVA	{"phone": "+70073383678"}
0005433008124	1F61C5	5779 248640	ELENA IVANOVA	{"phone": "+70224054275"}
0005433008125	2F3A6B	4254 230237	VALENTIN MELNIKOV	{"phone": "+70178413829"}
0005433008126	2F3A6B	5509 236544	OLGA SOLOVEVA	{"email": "osoloveva.121972@postgrespro.ru", "phone": "+70409441197"}
0005433008127	4AA68A	1636 965121	TATYANA RYABOVA	{"phone": "+70496871553"}
0005433008128	C4FFB8	5252 538826	TATYANA STEPANOVA	{"phone": "+70300436778"}
0005433008129	4DE444	9382 242568	KONSTANTIN FEDOTOV	{"email": "fedotovkonstantin-10081981@postgrespro.ru", "phone": "+70347559254"}
0005433008130	4DE444	7145 371873	PAVEL STEPANOV	{"email": "p.stepanov061961@postgrespro.ru", "phone": "+70233840926"}
0005433008131	31EDC9	2836 267359	ANNA NAZAROVA	{"email": "anna.nazarova1984@postgrespro.ru", "phone": "+70328852238"}
0005433008132	31EDC9	8323 241429	NINA FILIPPOVA	{"email": "n_filippova011990@postgrespro.ru", "phone": "+70871900364"}
0005433008133	DB8FD4	6175 051472	YULIYA SAVELEVA	{"email": "yuliyasaveleva_031979@postgrespro.ru", "phone": "+70926780021"}
0005433008134	384583	9804 472722	ANTONINA KOZLOVA	{"email": "kozlova_antonina-29101958@postgrespro.ru", "phone": "+70640937985"}
0005433008135	384583	9814 686481	EVGENIY KRASNOV	{"email": "krasnov-evgeniy.1971@postgrespro.ru", "phone": "+70064497204"}
0005433008136	FA9725	2645 576010	ILYA ISAEV	{"phone": "+70598360156"}
0005433008137	91608E	0836 703793	MARIYA NESTEROVA	{"email": "mariya-nesterova_1981@postgrespro.ru", "phone": "+70980720188"}
0005433008138	30BEF0	2657 753628	GALINA MATVEEVA	{"phone": "+70946291916"}
0005433008139	30BEF0	0572 257131	ALEKSEY KUZNECOV	{"phone": "+70963008552"}
0005433008140	A90EE7	7187 603147	IGOR KUZNECOV	{"email": "kuznecov_igor-24071970@postgrespro.ru", "phone": "+70557026585"}
0005433008141	A90EE7	8676 612904	ANTONINA KOLESNIKOVA	{"email": "antoninakolesnikova-1973@postgrespro.ru", "phone": "+70688804653"}
0005433008142	F1B062	1696 991413	VERA MELNIKOVA	{"phone": "+70920141649"}
0005433008143	48B245	3382 752085	DANILA NIKITIN	{"email": "nikitin.danila-061984@postgrespro.ru", "phone": "+70414822196"}
0005433008144	1BD344	6059 842476	EVGENIY MIKHAYLOV	{"email": "mikhaylovevgeniy-1968@postgrespro.ru", "phone": "+70628889171"}
0005433008145	6161BB	2334 844577	GENNADIY NIKOLAEV	{"phone": "+70506325449"}
0005433008146	6161BB	2630 600117	VIKTOR VOLKOV	{"phone": "+70879500173"}
0005433008147	8B6181	8302 761318	NINA MALYSHEVA	{"phone": "+70566363772"}
0005433008148	D88EE4	0035 627104	YURIY DAVYDOV	{"email": "yuriy.davydov1979@postgrespro.ru", "phone": "+70399886750"}
0005433008149	D88EE4	9149 898109	ZINAIDA ROMANOVA	{"email": "z.romanova.1971@postgrespro.ru", "phone": "+70510256335"}
0005433008150	F31813	8680 748652	VALENTINA MAKAROVA	{"phone": "+70741403852"}
0005433008151	F31813	4392 440167	ELENA SAVELEVA	{"phone": "+70417887178"}
0005433008152	40B9C1	9152 448681	SERGEY ALEKSEEV	{"email": "alekseev-sergey_08071966@postgrespro.ru", "phone": "+70702364895"}
0005433008153	40B9C1	3345 536701	ANDREY PETROV	{"phone": "+70093580683"}
0005433008154	CF229A	6733 365711	EKATERINA KOROLEVA	{"phone": "+70765347701"}
0005433008155	DEB350	1053 710599	VADIM SIDOROV	{"phone": "+70727899372"}
0005433008156	08696D	3233 974501	PETR IVANOV	{"email": "ivanovp_1979@postgrespro.ru", "phone": "+70632449619"}
0005433008157	451230	1359 466023	LIDIYA MALYSHEVA	{"phone": "+70855203502"}
0005433008158	88D03B	2991 383543	VALENTINA PETROVA	{"phone": "+70632195922"}
0005433008159	88D03B	4362 672837	ANDREY IVANOV	{"phone": "+70392256020"}
0005433008160	E1FDA6	1318 066948	SERGEY NIKITIN	{"email": "nikitin-sergey-091967@postgrespro.ru", "phone": "+70937189656"}
0005433008161	A658A0	2675 677475	ANDREY VOROBEV	{"phone": "+70068444573"}
0005433008162	A658A0	0504 680500	ALEKSEY NIKOLAEV	{"email": "nikolaev_a15071974@postgrespro.ru", "phone": "+70810844259"}
0005433008163	D3F840	6575 571012	LARISA SEMENOVA	{"phone": "+70875105532"}
0005433008164	D3F840	1364 130059	LYUBOV KRASNOVA	{"phone": "+70380250769"}
0005433008165	6EB1E6	6361 813346	VLADISLAV VASILEV	{"phone": "+70138360298"}
0005433008166	6EB1E6	6565 518892	ALISHER BARANOV	{"email": "baranova.17071975@postgrespro.ru", "phone": "+70426662871"}
0005433008167	65D4C6	3007 212624	VYACHESLAV BONDARENKO	{"phone": "+70685289238"}
0005433008168	440422	3718 139755	VLADIMIR KOROLEV	{"phone": "+70229908563"}
0005433008169	440422	0110 362086	LARISA TIKHONOVA	{"phone": "+70549706739"}
0005433008170	D81AF4	5652 457719	ALEKSANDR YAKOVLEV	{"email": "aleksandryakovlev_031964@postgrespro.ru", "phone": "+70116771171"}
0005433008171	3948E7	2345 967975	KRISTINA TROFIMOVA	{"email": "trofimovakristina-1976@postgrespro.ru", "phone": "+70562278184"}
0005433008172	62CEB9	4541 089209	OKSANA VOLKOVA	{"email": "volkovaoksana-111978@postgrespro.ru", "phone": "+70523468984"}
0005433008173	B2F78C	0396 339496	OLGA NIKOLAEVA	{"email": "onikolaeva-111968@postgrespro.ru", "phone": "+70104235605"}
0005433008174	E47C05	8619 921065	MIKHAIL SIDOROV	{"email": "sidorov_mikhail-061968@postgrespro.ru", "phone": "+70469766145"}
0005433008175	C8084D	7887 206980	YULIYA KOROLEVA	{"phone": "+70164777989"}
0005433008176	B092FA	2329 944173	LYUDMILA KUZNECOVA	{"phone": "+70259017913"}
0005433008177	67EBA1	9184 896497	GALINA ABRAMOVA	{"phone": "+70392765245"}
0005433008178	DABD99	0158 023714	ALEKSANDR ALEKSEEV	{"phone": "+70231255546"}
0005433008179	69D44A	6566 535399	RAISA SMIRNOVA	{"phone": "+70304493898"}
0005433008180	69D44A	6356 536176	KIRILL ANDREEV	{"phone": "+70160553082"}
0005433008181	9109B4	6647 074496	OLEG STEPANOV	{"phone": "+70743547970"}
0005433008182	3889AA	2602 226102	GALINA FROLOVA	{"phone": "+70832801518"}
0005433008183	80175F	2229 008209	MIKHAIL ISAEV	{"email": "isaev.mikhail_1980@postgrespro.ru", "phone": "+70376068449"}
0005433008184	80175F	3470 461302	SVETLANA FROLOVA	{"email": "frolova-s.1976@postgrespro.ru", "phone": "+70730738934"}
0005433008185	2FDA45	9326 452122	OLEG KUZNECOV	{"phone": "+70305540181"}
0005433008186	8208D7	0460 486222	ALEKSANDR SAVELEV	{"phone": "+70173924984"}
0005433008187	E23F77	4055 196103	VALERIYA NIKITINA	{"phone": "+70067436653"}
0005433008188	E23F77	2444 071125	YULIYA ROMANOVA	{"email": "romanova_y-1966@postgrespro.ru", "phone": "+70136821503"}
0005433008189	74E9F5	4934 335462	YULIYA ZHUKOVA	{"phone": "+70171421397"}
0005433008190	0DD774	9545 878366	MARIYA SOROKINA	{"phone": "+70662536816"}
0005433008191	0DD774	9008 578588	ELENA BELYAEVA	{"email": "belyaeva-e.05101963@postgrespro.ru", "phone": "+70445691340"}
0005433008192	4ED2F4	6112 680977	VALENTINA LEBEDEVA	{"phone": "+70679076012"}
0005433008193	4ED2F4	2405 679783	ANTON AFANASEV	{"phone": "+70378060208"}
0005433008194	39A11B	6067 412169	LARISA BORISOVA	{"email": "borisova-larisa_041972@postgrespro.ru", "phone": "+70448326733"}
0005433008195	941EC1	0097 521498	LARISA STEPANOVA	{"email": "stepanova_larisa.041975@postgrespro.ru", "phone": "+70774379161"}
0005433008196	7D9FC7	8644 003412	VALERIY TIMOFEEV	{"email": "v.timofeev-30091962@postgrespro.ru", "phone": "+70398112390"}
0005433008197	350D44	0931 850173	ANNA SERGEEVA	{"phone": "+70843157957"}
0005433008198	D6DF0E	3600 997002	STANISLAV NOVIKOV	{"email": "novikov-stanislav_081979@postgrespro.ru", "phone": "+70301974278"}
0005433008199	C96E9D	8791 654018	NINA FILIPPOVA	{"phone": "+70477212182"}
0005433008200	DF6778	4282 142473	DMITRIY TIKHONOV	{"phone": "+70413195321"}
0005433008201	D31E84	8350 550244	OLEG DENISOV	{"phone": "+70177378566"}
0005433008202	D31E84	6491 597917	BORIS IVANOV	{"phone": "+70339806183"}
0005433008203	A75C3D	7286 878505	EKATERINA ZAYCEVA	{"email": "zayceva-e.14061971@postgrespro.ru", "phone": "+70469165291"}
0005433008204	C5A9E3	7279 193751	VALERIY FROLOV	{"email": "valeriyfrolov.28011965@postgrespro.ru", "phone": "+70199835939"}
0005433008205	1EF529	7065 293674	IRINA EGOROVA	{"email": "i_egorova_1974@postgrespro.ru", "phone": "+70394079750"}
0005433008206	1EF529	4372 863241	IGOR BELOV	{"email": "belovi_021977@postgrespro.ru", "phone": "+70135248132"}
0005433008207	3F6199	8592 695962	MILENA ILINA	{"email": "milina1983@postgrespro.ru", "phone": "+70984138831"}
0005433008208	34F998	1312 740672	PAVEL NIKITIN	{"email": "nikitin.pavel_07091968@postgrespro.ru", "phone": "+70304220586"}
0005433008209	C6F3DE	3956 260856	SERGEY IVANOV	{"email": "sergey-ivanov.101971@postgrespro.ru", "phone": "+70408033543"}
0005433008210	966DB8	8396 354527	RAFIS ANTONOV	{"email": "antonov_r_051962@postgrespro.ru", "phone": "+70223103642"}
0005433008211	966DB8	3421 751221	LYUDMILA EFIMOVA	{"phone": "+70259521408"}
0005433008212	5F7031	2199 619794	ANNA IVANOVA	{"email": "a.ivanova06111980@postgrespro.ru", "phone": "+70309567036"}
0005433008213	4461A5	5255 711697	EVGENIY IVANOV	{"phone": "+70639866963"}
0005433008214	4461A5	4767 437820	EVGENIY ORLOV	{"email": "e-orlov.091958@postgrespro.ru", "phone": "+70139412566"}
0005433008215	E704A0	4409 210254	ALENA YUDINA	{"email": "a_yudina011983@postgrespro.ru", "phone": "+70250583375"}
0005433008216	E93F77	8875 179979	SERGEY KUZNECOV	{"email": "s-kuznecov-1962@postgrespro.ru", "phone": "+70709468958"}
0005433008217	AB36F6	2514 102014	EVGENIY SAVELEV	{"phone": "+70667963417"}
0005433008218	57FE1A	0645 807042	ANASTASIYA SCHERBAKOVA	{"phone": "+70860058640"}
0005433008219	E9952A	0271 905610	LYUDMILA NAZAROVA	{"phone": "+70868891691"}
0005433008220	8CEE84	1981 778795	LYUBOV SAVELEVA	{"phone": "+70263669304"}
0005433008221	8CEE84	8941 328802	SERGEY BARANOV	{"phone": "+70619467018"}
0005433008222	054F75	6494 909429	IRINA ANDREEVA	{"phone": "+70885184507"}
0005433008223	1BC292	2006 071153	IGOR ZAKHAROV	{"email": "zakharov_igor_091959@postgrespro.ru", "phone": "+70875847175"}
0005433008224	52EFF1	1951 841669	ANDREY IVANOV	{"email": "aivanov.101979@postgrespro.ru", "phone": "+70481598243"}
0005433008225	501C58	2204 024202	TATYANA NAUMOVA	{"email": "t-naumova.061972@postgrespro.ru", "phone": "+70661412922"}
0005433008226	501C58	3619 832906	NIKITA SIDOROV	{"phone": "+70024059210"}
0005433008227	501C58	1920 800282	ALEKSEY POPOV	{"email": "a-popov-10091979@postgrespro.ru", "phone": "+70728261913"}
0005433008228	ED2970	4934 539239	ALISA IVANOVA	{"email": "alisaivanova-1969@postgrespro.ru", "phone": "+70012523452"}
0005433008229	A3CC54	7516 299407	ROMAN KUZNECOV	{"phone": "+70533774139"}
0005433008230	A3CC54	7210 749451	SVETLANA STEPANOVA	{"email": "stepanova-s.1981@postgrespro.ru", "phone": "+70767969790"}
0005433008231	95ACE4	2758 835643	ILYA ORLOV	{"email": "orlovilya29041966@postgrespro.ru", "phone": "+70889023370"}
0005433008232	B03D75	1653 481777	GALINA KAZAKOVA	{"email": "galina_kazakova.29061970@postgrespro.ru", "phone": "+70293346386"}
0005433008233	9FCB84	5486 822606	ELENA MIKHAYLOVA	{"email": "mikhaylovae1972@postgrespro.ru", "phone": "+70547736971"}
0005433008234	9FCB84	6080 081952	VIKTOR GUSEV	{"email": "v-gusev1977@postgrespro.ru", "phone": "+70917885750"}
0005433008235	767003	8860 128293	NIKOLAY POPOV	{"email": "popov-nikolay021969@postgrespro.ru", "phone": "+70652863881"}
0005433008236	63B355	0915 491158	VALENTINA NAUMOVA	{"email": "naumova-v-1969@postgrespro.ru", "phone": "+70470323448"}
0005433008237	63B355	7542 598681	ANTON MELNIKOV	{"email": "antonmelnikov-28091983@postgrespro.ru", "phone": "+70718161676"}
0005433008238	C8829E	1138 505975	EKATERINA SOLOVEVA	{"phone": "+70757084101"}
0005433008239	774501	0176 251440	EKATERINA OVCHINNIKOVA	{"email": "ekaterina_ovchinnikova11111970@postgrespro.ru", "phone": "+70010834077"}
0005433008240	47EE68	1507 302925	ELENA GUSEVA	{"phone": "+70591454524"}
0005433008241	DCCA8C	4125 312826	GALINA TIMOFEEVA	{"phone": "+70053909824"}
0005433008242	F34B89	5465 997778	VIKTOR ROMANOV	{"email": "romanov_viktor-18121975@postgrespro.ru", "phone": "+70244416844"}
0005433008243	9E4F88	2744 324504	MIKHAIL KISELEV	{"email": "m_kiselev1982@postgrespro.ru", "phone": "+70061052831"}
0005433008244	F7F0C8	2731 142265	TATYANA EGOROVA	{"email": "t-egorova_101970@postgrespro.ru", "phone": "+70591951474"}
0005433008245	282C9E	7986 530976	VLADIMIR MELNIKOV	{"email": "melnikov_v_1971@postgrespro.ru", "phone": "+70800577426"}
0005433008246	282C9E	6214 974905	YURIY CHERNOV	{"phone": "+70787629437"}
0005433008247	0D492C	5304 042101	TATYANA FROLOVA	{"email": "tatyana-frolova_18111975@postgrespro.ru", "phone": "+70984122963"}
0005433008248	1E9BA7	2372 688109	PLATON FEDOROV	{"email": "p.fedorov-051974@postgrespro.ru", "phone": "+70717709833"}
0005433008249	1E9BA7	0631 699035	YANA KONDRATEVA	{"phone": "+70486296993"}
0005433008250	1E7BF5	4759 674219	NINA FOMINA	{"phone": "+70749711358"}
0005433008251	D78E00	3700 823092	MARINA BELOVA	{"email": "marina-belova1967@postgrespro.ru", "phone": "+70686885233"}
0005433008252	D78E00	5366 511290	EKATERINA FADEEVA	{"email": "ekaterina.fadeeva_1987@postgrespro.ru", "phone": "+70178828847"}
0005433008253	95E314	2605 312567	VALENTINA CHERNOVA	{"email": "valentina.chernova_1963@postgrespro.ru", "phone": "+70944485052"}
0005433008254	CDA951	6485 258387	NIKOLAY SEMENOV	{"email": "n-semenov-1965@postgrespro.ru", "phone": "+70728152160"}
0005433008255	3162DE	4735 322824	NATALYA ERMAKOVA	{"email": "ermakova-n-1976@postgrespro.ru", "phone": "+70067432911"}
0005433008256	3162DE	5402 257902	KSENIYA MEDVEDEVA	{"email": "kmedvedeva24061967@postgrespro.ru", "phone": "+70938313076"}
0005433008257	B1534B	4350 564412	ALEKSANDR ZHUKOV	{"phone": "+70504409696"}
0005433008258	755F6C	8182 103758	MARIYA FEDOROVA	{"email": "mfedorova-04011980@postgrespro.ru", "phone": "+70826909249"}
0005433008259	755F6C	3451 672184	IVAN DAVYDOV	{"phone": "+70551816225"}
0005433008260	25A4D1	4081 855935	TATYANA MARTYNOVA	{"email": "martynovat081972@postgrespro.ru", "phone": "+70590740903"}
0005433008261	5CC6B2	7022 886054	OLGA ZHUKOVA	{"email": "olga.zhukova_09041973@postgrespro.ru", "phone": "+70372941983"}
0005433008262	5CC6B2	2576 823462	OLGA NESTEROVA	{"email": "olga_nesterova_21121969@postgrespro.ru", "phone": "+70414311031"}
0005433008263	CBF3EF	3448 209325	ELIZAVETA RYABOVA	{"phone": "+70505481113"}
0005433008264	485223	9257 223796	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov.25111969@postgrespro.ru", "phone": "+70995299341"}
0005433008265	485223	7280 299082	ALISA YAKOVLEVA	{"phone": "+70057963945"}
0005433008266	7D91BC	1264 019304	TATYANA NESTEROVA	{"email": "nesterova.tatyana_1978@postgrespro.ru", "phone": "+70308309326"}
0005433008267	4B0AFE	9562 214456	ALENA PETROVA	{"email": "a_petrova_11081973@postgrespro.ru", "phone": "+70694843447"}
0005433008268	4B0AFE	0193 150104	NIKOLAY FOMIN	{"email": "n_fomin.111972@postgrespro.ru", "phone": "+70029686631"}
0005433008269	E2755B	6180 987355	IGOR KOZLOV	{"email": "kozlovi-051968@postgrespro.ru", "phone": "+70262603453"}
0005433008270	8B0891	6363 807133	PAVEL PAVLOV	{"phone": "+70811833115"}
0005433008271	8B0891	6370 534822	SERGEY KULIKOV	{"phone": "+70753585206"}
0005433008272	F870C6	3493 250667	SERGEY ANTONOV	{"email": "antonovsergey-021974@postgrespro.ru", "phone": "+70837051037"}
0005433008273	F870C6	9776 451507	TATYANA ANDREEVA	{"phone": "+70922850822"}
0005433008274	8403CA	8980 725393	ELENA MOROZOVA	{"email": "morozovae061979@postgrespro.ru", "phone": "+70118312053"}
0005433008275	C5C7CB	0045 610234	ANNA YUDINA	{"email": "ayudina-1974@postgrespro.ru", "phone": "+70468863466"}
0005433008276	60FEB9	8059 840963	NATALYA IVANOVA	{"phone": "+70949007555"}
0005433008277	DE7B68	7396 498740	ELENA EGOROVA	{"email": "egorova_e.1969@postgrespro.ru", "phone": "+70009013814"}
0005433008278	EFB617	3454 291795	LYUBOV GERASIMOVA	{"phone": "+70096648358"}
0005433008279	5110C9	2338 167964	KLAVDIYA OVCHINNIKOVA	{"phone": "+70976421997"}
0005433008280	5110C9	6292 213949	NATALYA STEPANOVA	{"phone": "+70905878429"}
0005433008281	F46102	4413 592084	VYACHESLAV KOZLOV	{"email": "vyacheslav.kozlov.28111973@postgrespro.ru", "phone": "+70244008392"}
0005433008282	B86B4F	5638 728877	ARTEM DMITRIEV	{"email": "admitriev.30111969@postgrespro.ru", "phone": "+70252956553"}
0005433008283	5148A7	7695 472526	MARFA KISELEVA	{"phone": "+70032526028"}
0005433008284	5148A7	8389 475921	ANATOLIY FEDOROV	{"email": "a-fedorov.23121975@postgrespro.ru", "phone": "+70793925020"}
0005433008285	07D2A0	9530 187706	SVETLANA MAKAROVA	{"phone": "+70937647505"}
0005433008286	5F873F	0576 624899	SOFYA ROMANOVA	{"phone": "+70865533708"}
0005433008287	CF63AD	6261 889837	ANNA PETROVA	{"email": "anna_petrova-041972@postgrespro.ru", "phone": "+70967423512"}
0005433008288	E784FA	5135 168693	ANASTASIYA ORLOVA	{"phone": "+70147343027"}
0005433008289	7CFC1C	0817 657119	ALEKSANDRA STEPANOVA	{"email": "stepanova_a_1971@postgrespro.ru", "phone": "+70329331181"}
0005433008290	18D8D8	9697 405445	VERA PAVLOVA	{"email": "pavlova_v_03121966@postgrespro.ru", "phone": "+70037520492"}
0005433008291	F0AF7D	1785 499548	DANIIL GAVRILOV	{"phone": "+70414251239"}
0005433008292	7DB4DA	7705 636562	SERGEY ALEKSANDROV	{"email": "aleksandrov.s_021979@postgrespro.ru", "phone": "+70215301078"}
0005433008293	7DB4DA	6283 099338	DMITRIY STEPANOV	{"email": "stepanov.dmitriy20021971@postgrespro.ru", "phone": "+70343627075"}
0005433008294	7DB4DA	0095 346228	IRINA DAVYDOVA	{"email": "irina_davydova-1972@postgrespro.ru", "phone": "+70578934452"}
0005433008295	607D02	1470 724515	ELENA KOZLOVA	{"email": "e_kozlova05041961@postgrespro.ru", "phone": "+70092366637"}
0005433008296	607D02	0487 812913	LYUBOV TIMOFEEVA	{"email": "l.timofeeva1960@postgrespro.ru", "phone": "+70809395713"}
0005433008297	607D02	1761 129215	VERA KUZNECOVA	{"email": "vera.kuznecova-27101964@postgrespro.ru", "phone": "+70983952103"}
0005433008298	C96747	5385 928373	ALEKSEY NIKITIN	{"email": "nikitin-aleksey.06031968@postgrespro.ru", "phone": "+70874958700"}
0005433008299	C96747	6325 444876	VIKTORIYA SOLOVEVA	{"email": "soloveva-viktoriya-1966@postgrespro.ru", "phone": "+70261857665"}
0005433008300	76C06D	0272 694924	DAVID ZAYCEV	{"email": "david_zaycev_031978@postgrespro.ru", "phone": "+70159078086"}
0005433008301	8E4F80	6848 417257	ALEKSANDR SOROKIN	{"phone": "+70782243087"}
0005433008302	F3E349	3891 010005	ALEKSANDR MIRONOV	{"phone": "+70475060734"}
0005433008303	9E7035	6630 485726	ALINA KONOVALOVA	{"phone": "+70874764533"}
0005433008304	9E7035	5783 199306	OKSANA KUZNECOVA	{"email": "kuznecovaoksana_101967@postgrespro.ru", "phone": "+70144045829"}
0005433008305	70C3E1	9295 855958	LYUDMILA RYABOVA	{"email": "lyudmila.ryabova.091983@postgrespro.ru", "phone": "+70379435025"}
0005433008306	879BD8	9057 830657	ZINAIDA ANTONOVA	{"phone": "+70253072998"}
0005433008307	7C6CB7	0860 262652	NINA GUSEVA	{"email": "nina-guseva.041973@postgrespro.ru", "phone": "+70010063025"}
0005433008308	190F27	1982 774745	SVETLANA POPOVA	{"phone": "+70477143853"}
0005433008309	190F27	2153 760245	MARIYA PAVLOVA	{"email": "pavlova.m_1969@postgrespro.ru", "phone": "+70695553213"}
0005433008310	186753	3833 636460	KIRILL POPOV	{"phone": "+70172581803"}
0005433008311	02A77D	9127 730516	VIKTOR PETROV	{"email": "petrov.v-021976@postgrespro.ru", "phone": "+70542130411"}
0005433008312	EB59A0	1149 681192	MIKHAIL GORBUNOV	{"email": "mikhail_gorbunov_021979@postgrespro.ru", "phone": "+70990483721"}
0005433008313	EB59A0	3265 258090	EKATERINA SOROKINA	{"email": "sorokina.e1967@postgrespro.ru", "phone": "+70434064071"}
0005433008314	892510	5762 698898	IRAIDA MAKAROVA	{"phone": "+70511534006"}
0005433008315	29EB25	5772 505743	ALEKSANDR ZAYCEV	{"email": "a_zaycev.1976@postgrespro.ru", "phone": "+70275420526"}
0005433008316	FAD577	5575 896117	ALEKSANDR MAKAROV	{"phone": "+70725514139"}
0005433008317	E586E0	9700 192074	YURIY EGOROV	{"phone": "+70245001482"}
0005433008318	A8FBF0	1001 879447	ALEKSEY GRIGOREV	{"email": "grigorev.aleksey_13101973@postgrespro.ru", "phone": "+70349049189"}
0005433008319	DFC554	7699 281126	EKATERINA SIDOROVA	{"email": "e_sidorova-031978@postgrespro.ru", "phone": "+70544222433"}
0005433008320	DFC554	6315 446729	ELENA FROLOVA	{"email": "e.frolova_111965@postgrespro.ru", "phone": "+70342334779"}
0005433008321	59C1B7	0102 361214	OLGA SOROKINA	{"email": "sorokina-olga1973@postgrespro.ru", "phone": "+70593687596"}
0005433008322	CD9BF9	7367 829376	AMINA ANTONOVA	{"email": "amina.antonova28021974@postgrespro.ru", "phone": "+70193591131"}
0005433008323	CD9BF9	3636 709059	ELENA IVANOVA	{"phone": "+70695094313"}
0005433008324	DF7885	1006 005940	VASILIY BARANOV	{"email": "baranov_vasiliy.10101976@postgrespro.ru", "phone": "+70507342770"}
0005433008325	AD9CE1	7534 170734	LARISA EGOROVA	{"phone": "+70173406927"}
0005433008326	191B98	1951 827100	MAKSIM KUZNECOV	{"email": "kuznecov-m-03061972@postgrespro.ru", "phone": "+70732443435"}
0005433008327	B4C404	0602 446357	LEONID ZAKHAROV	{"phone": "+70610972408"}
0005433008328	BE9C2E	5960 526174	NADEZHDA DMITRIEVA	{"phone": "+70971889801"}
0005433008329	21DBBF	0200 287842	ALEKSEY ORLOV	{"email": "orlovaleksey1974@postgrespro.ru", "phone": "+70536526583"}
0005433008330	21DBBF	3178 685586	RENAT BONDARENKO	{"email": "bondarenko.renat_1974@postgrespro.ru", "phone": "+70244287063"}
0005433008331	1EB696	2805 567401	YULIYA NOVIKOVA	{"email": "novikova.y07091967@postgrespro.ru", "phone": "+70549244202"}
0005433008332	1EB696	3556 143342	SERGEY KUZNECOV	{"email": "kuznecov-sergey_081976@postgrespro.ru", "phone": "+70820777623"}
0005433008333	7E7123	1986 113391	ARINA ISAEVA	{"email": "arinaisaeva.1963@postgrespro.ru", "phone": "+70836196184"}
0005433008334	79DD2E	1875 021834	ALEKSANDR ZHUKOV	{"phone": "+70667303695"}
0005433008335	C4362A	0674 688495	BORIS IVANOV	{"email": "b-ivanov.1966@postgrespro.ru", "phone": "+70413028737"}
0005433008336	C4362A	1384 088239	ALEKSANDR GRIGOREV	{"phone": "+70977362446"}
0005433008337	0EA8B6	6048 200570	VALENTINA KARPOVA	{"email": "v-karpova.23121982@postgrespro.ru", "phone": "+70675400581"}
0005433008338	0EA8B6	2644 193004	MARINA KARPOVA	{"phone": "+70484828879"}
0005433008339	30523E	5354 042828	GALINA ALEKSANDROVA	{"email": "aleksandrovagalina-29071966@postgrespro.ru", "phone": "+70615052976"}
0005433008340	49DB09	9889 023043	VALERIY FROLOV	{"email": "frolov_valeriy_1976@postgrespro.ru", "phone": "+70834431928"}
0005433008341	693D6E	1216 671059	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.1980@postgrespro.ru", "phone": "+70135665883"}
0005433008342	9DD396	3930 390816	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov1974@postgrespro.ru", "phone": "+70405991988"}
0005433008343	BC4140	6599 807969	SVETLANA AKIMOVA	{"phone": "+70688496863"}
0005433008344	BC4140	9180 521849	ANDREY FILIPPOV	{"email": "andrey-filippov1973@postgrespro.ru", "phone": "+70758299946"}
0005433008345	5E4436	9819 082780	ALEKSANDR ZAKHAROV	{"email": "a_zakharov111971@postgrespro.ru", "phone": "+70017899951"}
0005433008346	E40A2C	4272 007408	SERGEY MIKHAYLOV	{"phone": "+70085830019"}
0005433008347	E40A2C	2787 779585	LYUDMILA ZHUKOVA	{"phone": "+70983956538"}
0005433008348	41CA3C	5120 193037	KLAVDIYA FEDOROVA	{"email": "k.fedorova_071968@postgrespro.ru", "phone": "+70187077203"}
0005433008349	AB761E	4002 499046	NADEZHDA MASLOVA	{"phone": "+70465705697"}
0005433008350	14186E	5519 355914	ALEKSANDR ABRAMOV	{"email": "a_abramov_1969@postgrespro.ru", "phone": "+70903065947"}
0005433008351	14186E	9941 986693	ANTON IVANOV	{"phone": "+70747178179"}
0005433008352	14186E	0627 703843	SERGEY BONDARENKO	{"phone": "+70433777296"}
0005433008353	87376A	1466 918062	SERGEY NAZAROV	{"email": "sergey.nazarov-14061973@postgrespro.ru", "phone": "+70189515762"}
0005433008354	7BF268	6512 572435	MARIYA BARANOVA	{"phone": "+70623102577"}
0005433008355	B2E2FE	9676 457652	SERGEY VOLKOV	{"email": "s_volkov.071972@postgrespro.ru", "phone": "+70822010352"}
0005433008356	D53FF6	2585 250659	ILYA SMIRNOV	{"email": "i-smirnov_19091977@postgrespro.ru", "phone": "+70053704956"}
0005433008357	D2E17B	6688 189040	SVETLANA SCHERBAKOVA	{"email": "scherbakova_s-1976@postgrespro.ru", "phone": "+70557111936"}
0005433008358	55F3AD	1804 307153	STANISLAV KUZNECOV	{"email": "s-kuznecov_051977@postgrespro.ru", "phone": "+70313536319"}
0005433008359	DDBD58	7583 340806	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev_22041978@postgrespro.ru", "phone": "+70676651472"}
0005433008360	20B508	8107 324379	IRINA ANTONOVA	{"email": "antonovairina04051974@postgrespro.ru", "phone": "+70408587687"}
0005433008361	912547	5400 250663	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov-011977@postgrespro.ru", "phone": "+70495794480"}
0005433008362	912547	5889 512999	NINA FROLOVA	{"phone": "+70708528661"}
0005433008363	698064	2161 982722	LARISA FOMINA	{"email": "l.fomina-24081969@postgrespro.ru", "phone": "+70051740534"}
0005433008364	1D8407	8859 149736	EKATERINA KRASNOVA	{"email": "e-krasnova.30031967@postgrespro.ru", "phone": "+70416852241"}
0005433008365	1D8407	1141 750102	NADEZHDA KOVALEVA	{"email": "kovalevanadezhda-111981@postgrespro.ru", "phone": "+70666533929"}
0005433008366	2A999E	9668 348600	NATALYA MEDVEDEVA	{"phone": "+70462270852"}
0005433008367	2A999E	0750 877207	DARYA TROFIMOVA	{"email": "trofimova-darya.111975@postgrespro.ru", "phone": "+70383545866"}
0005433008368	A1AB9A	0196 730130	ANDREY AFANASEV	{"phone": "+70700048888"}
0005433008369	A1AB9A	6287 531867	ALEKSANDRA DENISOVA	{"email": "denisovaa.1977@postgrespro.ru", "phone": "+70416224793"}
0005433008370	866A58	1440 338817	NINA ZHURAVLEVA	{"phone": "+70636586924"}
0005433008371	D10A1B	9641 080577	YULIYA VOLKOVA	{"email": "volkova.yuliya-091975@postgrespro.ru", "phone": "+70046894633"}
0005433008372	84D5B3	3876 075785	ALEKSEY MELNIKOV	{"email": "a.melnikov.27011964@postgrespro.ru", "phone": "+70737130470"}
0005433008373	92CBC7	2122 823215	VERA NAZAROVA	{"phone": "+70853341893"}
0005433008374	92CBC7	2297 885384	VLADIMIR BELOV	{"email": "belov_vladimir101975@postgrespro.ru", "phone": "+70942072970"}
0005433008375	A07B16	6138 541198	GALINA DAVYDOVA	{"phone": "+70456970077"}
0005433008376	A07B16	2685 015427	VALENTINA YAKOVLEVA	{"phone": "+70556507834"}
0005433008377	60BD58	0401 799683	YULIYA KUZNECOVA	{"phone": "+70109820862"}
0005433008378	60BD58	2014 093438	LARISA SERGEEVA	{"phone": "+70108463769"}
0005433008379	4FB143	8076 119089	OLGA GRISHINA	{"email": "grishinao_011961@postgrespro.ru", "phone": "+70853774121"}
0005433008380	76571E	9822 129625	DMITRIY KOZLOV	{"phone": "+70723803761"}
0005433008381	76571E	7441 774099	OLGA AFANASEVA	{"email": "o_afanaseva.121969@postgrespro.ru", "phone": "+70444456315"}
0005433008382	76571E	9589 255658	IRINA IVANOVA	{"email": "i.ivanova1975@postgrespro.ru", "phone": "+70302659753"}
0005433008383	402CA7	6487 412033	LYUBOV BARANOVA	{"phone": "+70667879419"}
0005433008384	E1E976	1292 268977	LYUDMILA KONDRATEVA	{"email": "kondratevalyudmila-071969@postgrespro.ru", "phone": "+70936087470"}
0005433008385	E1E976	8814 259909	ALEKSEY ZAYCEV	{"email": "aleksey_zaycev_051973@postgrespro.ru", "phone": "+70916065039"}
0005433008386	E1E976	6880 117085	IRINA KAZAKOVA	{"email": "kazakova.irina12031974@postgrespro.ru", "phone": "+70828037820"}
0005433008387	1E432C	0819 396527	IGOR ZAKHAROV	{"email": "izakharov_1958@postgrespro.ru", "phone": "+70441968681"}
0005433008388	1E432C	2978 505292	YURIY TIMOFEEV	{"email": "yuriy-timofeev-1961@postgrespro.ru", "phone": "+70833969137"}
0005433008389	7C78E2	2090 438375	ALEKSEY GERASIMOV	{"email": "agerasimov_091973@postgrespro.ru", "phone": "+70309710158"}
0005433008390	EEE19F	1158 483771	DARYA KUZMINA	{"email": "d.kuzmina_1988@postgrespro.ru", "phone": "+70180930861"}
0005433008391	7EE2EB	8307 696755	MARIYA PAVLOVA	{"phone": "+70488891923"}
0005433008392	F4BD09	0547 160646	NINA NIKOLAEVA	{"phone": "+70000112016"}
0005433008393	BD29C7	7058 182708	ELENA EGOROVA	{"phone": "+70963897784"}
0005433008394	D866B8	3494 669121	YANA SERGEEVA	{"email": "yanasergeeva.1981@postgrespro.ru", "phone": "+70349279898"}
0005433008395	06E54D	1396 220801	EKATERINA RODIONOVA	{"email": "rodionovae1980@postgrespro.ru", "phone": "+70398584167"}
0005433008396	6F2B20	8593 970738	IGOR KUZNECOV	{"email": "kuznecov_igor_111960@postgrespro.ru", "phone": "+70626613104"}
0005433008397	29EDBE	6692 219888	OLGA MOROZOVA	{"phone": "+70213925580"}
0005433008398	465DF9	0683 614057	MIKHAIL OSIPOV	{"phone": "+70750624044"}
0005433008399	E62FDA	0799 079498	DMITRIY SOLOVEV	{"email": "dmitriy_solovev.061979@postgrespro.ru", "phone": "+70606904969"}
0005433008400	32004F	5413 871316	VALENTINA FILIPPOVA	{"email": "valentina.filippova01101972@postgrespro.ru", "phone": "+70042279176"}
0005433008401	27AA87	7091 574080	YULIYA TITOVA	{"phone": "+70499794481"}
0005433008402	03CDB5	4442 586808	SERGEY KISELEV	{"email": "sergey_kiselev_10101973@postgrespro.ru", "phone": "+70529605047"}
0005433008403	03CDB5	8206 830209	LYUBOV TIKHONOVA	{"phone": "+70371088706"}
0005433008404	F63D8D	0916 382653	LYUDMILA PETROVA	{"email": "petrova-l_28121972@postgrespro.ru", "phone": "+70520792497"}
0005433008405	BD89AE	4724 770492	LYUDMILA FADEEVA	{"phone": "+70631864373"}
0005433008406	7F8547	2972 583619	ALEKSEY IVANOV	{"phone": "+70125372988"}
0005433008407	7F8547	6627 979561	ANATOLIY TIMOFEEV	{"phone": "+70338952917"}
0005433008408	7E5C74	5930 111761	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov.13081974@postgrespro.ru", "phone": "+70415791772"}
0005433008409	FFCB44	2875 050933	OLEG PETROV	{"email": "petrovoleg-1967@postgrespro.ru", "phone": "+70019215647"}
0005433008410	FFCB44	8921 919559	OLGA MATVEEVA	{"email": "olgamatveeva_1958@postgrespro.ru", "phone": "+70322499445"}
0005433008411	8DA681	5926 513445	IRINA STEPANOVA	{"email": "irinastepanova-111974@postgrespro.ru", "phone": "+70226632117"}
0005433008412	8DA681	4718 988455	VLADIMIR AFANASEV	{"email": "afanasev_v.26011965@postgrespro.ru", "phone": "+70090773141"}
0005433008413	0127E5	6397 612194	VALENTINA FILATOVA	{"phone": "+70893285474"}
0005433008414	153F2B	1687 871041	OKSANA KAZAKOVA	{"phone": "+70640262387"}
0005433008415	5B9ADC	0207 269943	OKSANA NESTEROVA	{"phone": "+70548743482"}
0005433008416	327BA0	3992 105340	OLGA MALYSHEVA	{"phone": "+70467434527"}
0005433008417	3C76BD	7105 982362	OLGA NIKITINA	{"phone": "+70814897916"}
0005433008418	A3B2C0	3457 900961	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr.1976@postgrespro.ru", "phone": "+70884877996"}
0005433008419	A3B2C0	1362 851696	LYUDMILA ROMANOVA	{"email": "romanova-l061985@postgrespro.ru", "phone": "+70451397929"}
0005433008420	A3B2C0	3159 553929	LYUBOV KAZAKOVA	{"email": "lyubovkazakova.031971@postgrespro.ru", "phone": "+70796932661"}
0005433008421	447CF2	5925 492672	ELENA MOROZOVA	{"email": "morozovae_051976@postgrespro.ru", "phone": "+70510221728"}
0005433008422	85FC31	8223 059735	ANZHELIKA KOVALEVA	{"email": "kovalevaanzhelika.041966@postgrespro.ru", "phone": "+70748427250"}
0005433008423	85FC31	1931 217803	SVETLANA ZHURAVLEVA	{"phone": "+70849475848"}
0005433008424	6E5985	1195 241875	VALENTINA MASLOVA	{"phone": "+70845860184"}
0005433008425	A34A23	5320 100973	ELENA KRASNOVA	{"phone": "+70368601650"}
0005433008426	8CF8B9	5116 879027	VLADISLAV ZAYCEV	{"email": "v_zaycev.011975@postgrespro.ru", "phone": "+70920224142"}
0005433008427	D3C157	0919 391626	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov-021989@postgrespro.ru", "phone": "+70256810255"}
0005433008428	D3C157	4722 223293	TATYANA ILINA	{"phone": "+70719120314"}
0005433008429	E70812	9451 367948	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy_1971@postgrespro.ru", "phone": "+70395567374"}
0005433008430	583F80	9166 811398	RUSLAN FROLOV	{"phone": "+70623989098"}
0005433008431	583F80	7972 763544	OLGA SMIRNOVA	{"phone": "+70099681411"}
0005433008432	1FCC96	1524 655246	IRINA BELOVA	{"phone": "+70526395303"}
0005433008433	B21962	8622 820581	ELENA DMITRIEVA	{"phone": "+70905580257"}
0005433008434	B21962	9941 436101	EVGENIY FEDOTOV	{"phone": "+70636409772"}
0005433008435	DD93D2	4919 250628	ANDREY VASILEV	{"phone": "+70091117073"}
0005433008436	DD93D2	9081 440649	NINA SAVELEVA	{"email": "saveleva.nina-061966@postgrespro.ru", "phone": "+70573538277"}
0005433008437	DD93D2	4166 853672	VALERIY GAVRILOV	{"email": "gavrilov.v-101970@postgrespro.ru", "phone": "+70288938626"}
0005433008438	800F0F	7469 877018	YURIY DMITRIEV	{"phone": "+70960531524"}
0005433008439	800F0F	1334 307103	TAMARA AFANASEVA	{"email": "t-afanaseva-11041968@postgrespro.ru", "phone": "+70426703628"}
0005433008440	800F0F	7682 220236	EVELINA EGOROVA	{"phone": "+70603792386"}
0005433008441	00BCEC	2207 585505	ALEKSANDR SCHERBAKOV	{"phone": "+70408296099"}
0005433008442	64449A	9113 780632	NIKOLAY KULIKOV	{"phone": "+70830573151"}
0005433008443	2ADD66	6062 510004	VLADIMIR GRIGOREV	{"email": "grigorev_vladimir14061987@postgrespro.ru", "phone": "+70743587933"}
0005433008444	6C68A1	3646 304579	ROZA KOROLEVA	{"phone": "+70526003383"}
0005433008445	96EDEF	1274 105522	MARIYA POPOVA	{"email": "m-popova_1980@postgrespro.ru", "phone": "+70189523856"}
0005433008446	3CA4EA	5568 017557	ANASTASIYA KOZLOVA	{"email": "kozlovaanastasiya.07011970@postgrespro.ru", "phone": "+70602499841"}
0005433008447	3CA4EA	5043 030764	VIKTOR NOVIKOV	{"phone": "+70907099088"}
0005433008448	55E40B	7671 048544	PAVEL TIKHONOV	{"email": "pavel_tikhonov071958@postgrespro.ru", "phone": "+70019301648"}
0005433008449	55E40B	2564 040833	NATALYA ORLOVA	{"email": "orlovanatalya.1972@postgrespro.ru", "phone": "+70059906588"}
0005433008450	6294F6	7397 473428	SVETLANA NIKOLAEVA	{"phone": "+70707195781"}
0005433008451	332AE9	1646 313029	IRINA LUKYANOVA	{"phone": "+70095822778"}
0005433008452	4A5757	3555 112292	SVETLANA TIKHONOVA	{"phone": "+70895279827"}
0005433008453	21737D	5685 917112	SVETLANA ZAKHAROVA	{"phone": "+70173968464"}
0005433008454	21737D	2664 205447	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir111964@postgrespro.ru", "phone": "+70048609260"}
0005433008455	21737D	1862 124630	IGOR SOLOVEV	{"phone": "+70756419529"}
0005433008456	0F9FBD	2218 498994	DMITRIY AFANASEV	{"email": "afanasev_dmitriy_081973@postgrespro.ru", "phone": "+70599403588"}
0005433008457	1A5392	7859 717822	TAMARA PAVLOVA	{"email": "pavlova_tamara.31011973@postgrespro.ru", "phone": "+70802373753"}
0005433008458	02E55D	8912 853392	OLEG KAZAKOV	{"email": "kazakovoleg.1964@postgrespro.ru", "phone": "+70292482215"}
0005433008459	02E55D	0446 848753	ELENA CHERNOVA	{"email": "chernova_e-22081980@postgrespro.ru", "phone": "+70657182155"}
0005433008460	8BEB2B	2560 720084	MARIANNA EFREMOVA	{"phone": "+70822993056"}
0005433008461	985EEC	2591 723500	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov_1963@postgrespro.ru", "phone": "+70610339248"}
0005433008462	F08396	5758 736480	LARISA MELNIKOVA	{"email": "melnikova_larisa_1972@postgrespro.ru", "phone": "+70727046108"}
0005433008463	A0C294	1087 557087	ELDAR TARASOV	{"phone": "+70622762902"}
0005433008464	DDE83F	7261 559904	ALEKSEY ROMANOV	{"phone": "+70493226065"}
0005433008465	131583	0175 041381	OLGA ERMAKOVA	{"email": "ermakova_olga111978@postgrespro.ru", "phone": "+70787441544"}
0005433008466	80FAAA	6703 029600	LEV MELNIKOV	{"email": "l.melnikov.041966@postgrespro.ru", "phone": "+70055269563"}
0005433008467	75C992	8821 417517	YULIYA KUDRYASHOVA	{"phone": "+70391620383"}
0005433008468	75C992	2941 468582	ILYA TARASOV	{"email": "tarasov_ilya30071967@postgrespro.ru", "phone": "+70521249380"}
0005433008469	D49590	9250 536513	EKATERINA SERGEEVA	{"phone": "+70166255357"}
0005433008470	3A458F	7437 921312	MIKHAIL AFANASEV	{"phone": "+70798437076"}
0005433008471	3A458F	7076 008693	ALEKSEY SEMENOV	{"email": "semenov_a.101967@postgrespro.ru", "phone": "+70322798549"}
0005433008472	41A4A8	3656 197562	ALEKSANDR KUDRYASHOV	{"email": "kudryashovaleksandr071980@postgrespro.ru", "phone": "+70593434792"}
0005433008473	613364	5529 477693	NIKOLAY GUSEV	{"email": "gusev-nikolay-061979@postgrespro.ru", "phone": "+70770099537"}
0005433008474	7C8854	7216 612303	YULIYA NAZAROVA	{"phone": "+70817350715"}
0005433008475	0B8501	7227 465151	DMITRIY SOLOVEV	{"phone": "+70196291115"}
0005433008476	34BCAF	3503 098244	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov.051975@postgrespro.ru", "phone": "+70564347542"}
0005433008477	E43479	9754 542823	SERGEY VOLKOV	{"email": "sergey-volkov.1974@postgrespro.ru", "phone": "+70895951272"}
0005433008478	CCD369	7972 366312	POLINA BORISOVA	{"phone": "+70654945014"}
0005433008479	82B248	0376 439948	BORIS KOROLEV	{"email": "korolev-b1978@postgrespro.ru", "phone": "+70726728462"}
0005433008480	7AB240	0989 867650	ALIYA IVANOVA	{"email": "ivanovaa.07011969@postgrespro.ru", "phone": "+70642612886"}
0005433008481	257BAD	6337 088249	SERGEY IVANOV	{"phone": "+70055618113"}
0005433008482	801139	1935 261420	SERGEY MEDVEDEV	{"email": "medvedev.s.021985@postgrespro.ru", "phone": "+70290209472"}
0005433008483	7ABA0F	8217 574199	ALEKSANDR IVANOV	{"phone": "+70618436002"}
0005433008484	7ABA0F	7142 283181	ANATOLIY OSIPOV	{"email": "osipovanatoliy-08041974@postgrespro.ru", "phone": "+70708024913"}
0005433008485	7ABA0F	1333 110432	OLGA KONOVALOVA	{"email": "konovalova-o_1978@postgrespro.ru", "phone": "+70359288436"}
0005433008486	B13F2D	5868 160767	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov.071971@postgrespro.ru", "phone": "+70506271251"}
0005433008487	D9F9B0	6672 850022	NADEZHDA SIDOROVA	{"email": "n.sidorova051982@postgrespro.ru", "phone": "+70975696869"}
0005433008488	D9F9B0	7348 681936	NIKOLAY ZHUKOV	{"email": "zhukovn-1967@postgrespro.ru", "phone": "+70091597118"}
0005433008489	C92964	8456 271127	LYUBOV ISAEVA	{"email": "lyubov-isaeva09101962@postgrespro.ru", "phone": "+70603364611"}
0005433008490	9B9557	9087 388731	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir.071972@postgrespro.ru", "phone": "+70658377385"}
0005433008491	9B9557	4109 353320	ALEKSANDRA OVCHINNIKOVA	{"email": "aleksandra.ovchinnikova.29121964@postgrespro.ru", "phone": "+70508629970"}
0005433008492	9B9557	8890 794625	SVETLANA RYABOVA	{"phone": "+70883474348"}
0005433008493	002705	1151 975319	NATALYA TIKHONOVA	{"phone": "+70749859956"}
0005433008494	1ACBEB	7207 038552	MARIYA ZAKHAROVA	{"phone": "+70241982159"}
0005433008495	E79277	2270 804860	ALEKSANDR PETROV	{"phone": "+70917820747"}
0005433008496	E79277	9735 122727	IGOR IVANOV	{"phone": "+70000583993"}
0005433008497	24BCA3	6075 667109	MAKSIM SERGEEV	{"email": "sergeev-m_24031975@postgrespro.ru", "phone": "+70110737658"}
0005433008498	5D3104	1783 453287	TAISIYA PAVLOVA	{"email": "pavlova_taisiya.11121976@postgrespro.ru", "phone": "+70466885568"}
0005433008499	5D3104	2139 148829	GLEB SHEVCHENKO	{"email": "g-shevchenko_021975@postgrespro.ru", "phone": "+70541558901"}
0005433008500	187C85	9729 760267	YULIYA YAKOVLEVA	{"email": "yuliya_yakovleva1980@postgrespro.ru", "phone": "+70065579270"}
0005433008501	FC7238	7075 733723	ALEKSANDR SERGEEV	{"phone": "+70912064682"}
0005433008502	FC7238	9439 693010	ALEKSANDRA MAKAROVA	{"email": "makarova_aleksandra_29071963@postgrespro.ru", "phone": "+70317817248"}
0005433008503	E8E0D7	8991 561731	MARIYA MAKAROVA	{"phone": "+70804313449"}
0005433008504	E8E0D7	2944 913599	ANTON GERASIMOV	{"phone": "+70888153073"}
0005433008505	E8E0D7	0286 198647	YAN MIKHAYLOV	{"phone": "+70687432676"}
0005433008506	831FF6	6638 691405	VLADIMIR RODIONOV	{"phone": "+70266458939"}
0005433008507	1EC553	8213 350123	INNA FEDOROVA	{"email": "inna.fedorova-021972@postgrespro.ru", "phone": "+70111653296"}
0005433008508	F6D99C	2150 847701	ROMAN NOVIKOV	{"phone": "+70158282684"}
0005433008509	1B1809	4941 450644	SVETLANA KONOVALOVA	{"email": "svetlana_konovalova_1970@postgrespro.ru", "phone": "+70283306359"}
0005433008510	1B1809	6767 267411	ANTONINA KARPOVA	{"email": "karpova-antonina_101975@postgrespro.ru", "phone": "+70376494560"}
0005433008511	372189	8187 309910	NATALYA MIRONOVA	{"phone": "+70810783639"}
0005433008512	D043E6	3461 864638	ARINA ISAEVA	{"phone": "+70537157437"}
0005433008513	D043E6	9344 070998	DENIS SIDOROV	{"email": "denis-sidorov_011978@postgrespro.ru", "phone": "+70414784599"}
0005433008514	3F7F5D	0656 199019	MATVEY IVANOV	{"email": "m.ivanov_031975@postgrespro.ru", "phone": "+70920711913"}
0005433008515	42CAEA	7719 769337	LARISA BORISOVA	{"phone": "+70841627855"}
0005433008516	C70DCB	7117 250154	ELENA ROMANOVA	{"phone": "+70474256398"}
0005433008517	178CB8	9208 644327	VLADIMIR DAVYDOV	{"phone": "+70175521364"}
0005433008518	E486D7	0263 121728	DENIS KONOVALOV	{"phone": "+70750262512"}
0005433008630	D3CA0C	7467 970403	ANDREY SCHERBAKOV	{"phone": "+70042204746"}
0005433008519	40B7C1	8649 267235	RAISA ALEKSEEVA	{"email": "raisaalekseeva071972@postgrespro.ru", "phone": "+70779122957"}
0005433008520	7DB253	7871 594160	NIKITA DAVYDOV	{"phone": "+70007566289"}
0005433008521	7DB253	7826 220814	EKATERINA ZAYCEVA	{"phone": "+70608509166"}
0005433008522	964930	5447 721363	IGOR ZHURAVLEV	{"phone": "+70727003846"}
0005433008523	85C828	9612 611471	DENIS MIRONOV	{"email": "d.mironov_1967@postgrespro.ru", "phone": "+70600480402"}
0005433008524	807E04	6901 523262	EVGENIY NIKITIN	{"phone": "+70622225378"}
0005433008525	ED2279	3316 719785	LYUBOV IVANOVA	{"phone": "+70872451370"}
0005433008526	1CA28C	5804 809097	NIKOLAY KUZNECOV	{"email": "n.kuznecov_1977@postgrespro.ru", "phone": "+70649685165"}
0005433008527	E9D006	1228 074188	NADEZHDA VASILEVA	{"email": "nadezhda_vasileva-18021973@postgrespro.ru", "phone": "+70832414844"}
0005433008528	882121	7502 502467	ALEKSANDR KOZLOV	{"phone": "+70925552329"}
0005433008529	641DF1	3079 303970	DMITRIY KUZNECOV	{"phone": "+70993596782"}
0005433008530	0810EE	1671 477694	LIDIYA DANILOVA	{"email": "danilova_l_02041974@postgrespro.ru", "phone": "+70623977164"}
0005433008531	0AFF58	4815 579380	NINA SCHERBAKOVA	{"email": "scherbakovan_18041985@postgrespro.ru", "phone": "+70669705163"}
0005433008532	0E2DDC	6327 410378	VALENTINA ZHURAVLEVA	{"phone": "+70243936609"}
0005433008533	018AD9	8235 742143	ANATOLIY KARPOV	{"phone": "+70441198043"}
0005433008534	3476B6	5618 116886	ANDREY IVANOV	{"email": "ivanov_andrey03101982@postgrespro.ru", "phone": "+70169936670"}
0005433008535	3476B6	3721 590280	ANNA FILATOVA	{"phone": "+70889883533"}
0005433008536	6E3A7F	1810 662581	VASILIY KOZLOV	{"email": "v-kozlov_1972@postgrespro.ru", "phone": "+70093451876"}
0005433008537	4E09C6	3196 726764	LYUBOV KRASNOVA	{"email": "krasnova_l_061967@postgrespro.ru", "phone": "+70734810574"}
0005433008538	19E105	7124 793575	VALERIY PAVLOV	{"email": "pavlov_v-26091965@postgrespro.ru", "phone": "+70061988306"}
0005433008539	455C27	3164 296335	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir_02101969@postgrespro.ru", "phone": "+70441072495"}
0005433008540	455C27	3290 610257	MARIYA KOVALEVA	{"email": "kovaleva_mariya.061955@postgrespro.ru", "phone": "+70896587780"}
0005433008541	8BD38E	6535 361838	TATYANA DENISOVA	{"email": "tdenisova-1979@postgrespro.ru", "phone": "+70044275187"}
0005433008542	0F7AEE	5691 045200	ANDREY POPOV	{"phone": "+70714647207"}
0005433008543	0F7AEE	4446 222713	DMITRIY BELOV	{"email": "dmitriybelov.111978@postgrespro.ru", "phone": "+70670920620"}
0005433008544	C6E42E	4218 433435	EKATERINA BORISOVA	{"email": "borisova_e-1974@postgrespro.ru", "phone": "+70964104203"}
0005433008545	C6E42E	7972 405992	ELENA CHERNOVA	{"email": "elena.chernova_13071964@postgrespro.ru", "phone": "+70263437645"}
0005433008546	B39BCB	3114 440875	KLAVDIYA PETROVA	{"email": "petrovaklavdiya_1973@postgrespro.ru", "phone": "+70010984341"}
0005433008547	2BDD44	9737 158393	VLADIMIR FROLOV	{"email": "frolov.vladimir_111969@postgrespro.ru", "phone": "+70360253890"}
0005433008548	2BDD44	9576 666051	OLGA PAVLOVA	{"email": "o.pavlova.1958@postgrespro.ru", "phone": "+70358628976"}
0005433008549	AD9951	8925 583793	SERGEY MAKAROV	{"email": "smakarov-1965@postgrespro.ru", "phone": "+70602476679"}
0005433008550	1E3202	8978 321477	VLADIMIR TIMOFEEV	{"email": "timofeev-vladimir26121975@postgrespro.ru", "phone": "+70360985333"}
0005433008551	A21BAA	6475 210676	TATYANA KULIKOVA	{"phone": "+70315606934"}
0005433008552	207F2F	3261 421141	SVETLANA ZAYCEVA	{"phone": "+70381977329"}
0005433008553	207F2F	9338 034828	ILYA SIDOROV	{"email": "isidorov-10071978@postgrespro.ru", "phone": "+70699108798"}
0005433008554	1C85BA	8397 744440	ANNA DENISOVA	{"phone": "+70544554728"}
0005433008555	AE1FCA	8707 790925	VALENTINA SIDOROVA	{"phone": "+70901726351"}
0005433008556	6F3A55	0056 986649	MARINA YAKOVLEVA	{"phone": "+70157722395"}
0005433008557	01A494	3726 501692	OLGA POPOVA	{"email": "popova_o1964@postgrespro.ru", "phone": "+70663736511"}
0005433008558	89FA8D	0512 478811	NIKOLAY SERGEEV	{"email": "n_sergeev1958@postgrespro.ru", "phone": "+70200626292"}
0005433008559	FC90A5	5844 289182	ALEKSANDR KISELEV	{"email": "kiselev_a_06111969@postgrespro.ru", "phone": "+70915549312"}
0005433008560	D1B790	4857 070872	EKATERINA GORBUNOVA	{"email": "gorbunova.ekaterina-20081970@postgrespro.ru", "phone": "+70017020729"}
0005433008561	CFEB04	2606 400253	MIKHAIL MOROZOV	{"phone": "+70813498809"}
0005433008562	E1EB20	8058 580592	VERA RYABOVA	{"email": "ryabova_v-1969@postgrespro.ru", "phone": "+70129492980"}
0005433008563	E1EB20	4346 136711	KRISTINA NOVIKOVA	{"phone": "+70535761449"}
0005433008564	40FB6A	0158 509607	TATYANA KUZMINA	{"phone": "+70454478257"}
0005433008565	01D50C	2593 426982	ANASTASIYA DENISOVA	{"email": "anastasiya_denisova.27031970@postgrespro.ru", "phone": "+70755578560"}
0005433008566	A20A3E	1692 419539	MIKHAIL VOLKOV	{"email": "volkov.m_1965@postgrespro.ru", "phone": "+70971641052"}
0005433008567	E16584	6459 073307	RUSLAN EGOROV	{"phone": "+70339996325"}
0005433008568	541013	5102 827872	ARTEM SCHERBAKOV	{"email": "scherbakov_a.21121964@postgrespro.ru", "phone": "+70112199166"}
0005433008569	FFF812	0692 696396	ALIK IVANOV	{"phone": "+70666534067"}
0005433008570	C4EA72	7954 363666	ANTON ROMANOV	{"email": "a-romanov1973@postgrespro.ru", "phone": "+70852816779"}
0005433008571	90ABDE	7842 323002	DMITRIY BONDARENKO	{"phone": "+70666189803"}
0005433008572	5DE8F7	7343 551589	NATALYA MAKAROVA	{"phone": "+70263851710"}
0005433008573	5DE8F7	9203 003426	VLADIMIR FEDOTOV	{"email": "vladimir-fedotov.111975@postgrespro.ru", "phone": "+70559702536"}
0005433008574	05A44D	5576 631092	SERGEY NIKOLAEV	{"phone": "+70759633481"}
0005433008575	B5DF1F	0574 627735	NADEZHDA VLASOVA	{"email": "vlasova_nadezhda-14081973@postgrespro.ru", "phone": "+70592138005"}
0005433008576	B8BB2C	1768 509029	NIKOLAY YAKOVLEV	{"phone": "+70544142895"}
0005433008577	3A99DC	2360 186928	RAVIL FROLOV	{"email": "ravil_frolov-091969@postgrespro.ru", "phone": "+70973295883"}
0005433008578	F82F30	3922 347259	ELENA FROLOVA	{"email": "frolova-e-061970@postgrespro.ru", "phone": "+70925697974"}
0005433008579	61B0DD	0611 378124	ALEKSANDR ANDREEV	{"phone": "+70148670638"}
0005433008580	F9EFAE	9810 876203	OLGA SERGEEVA	{"email": "sergeeva.olga24041967@postgrespro.ru", "phone": "+70722357733"}
0005433008581	CB065C	3775 505617	IVAN KUZMIN	{"email": "kuzmin.ivan_121973@postgrespro.ru", "phone": "+70007973963"}
0005433008582	17CE65	7169 902472	GALINA DAVYDOVA	{"email": "g_davydova.1968@postgrespro.ru", "phone": "+70923416234"}
0005433008583	62B488	5624 676549	SERGEY SEMENOV	{"email": "ssemenov.22051966@postgrespro.ru", "phone": "+70298271283"}
0005433008584	FC46C0	3838 772563	VASILIY SOLOVEV	{"email": "solovev.v-13031966@postgrespro.ru", "phone": "+70051954405"}
0005433008585	FC46C0	4290 800848	NELLI SOKOLOVA	{"email": "nelli-sokolova.01061974@postgrespro.ru", "phone": "+70233298566"}
0005433008586	5FD69C	3191 760957	ANTONINA KUZMINA	{"email": "kuzmina-antonina_111977@postgrespro.ru", "phone": "+70153157926"}
0005433008587	E98C6B	5987 245196	IVAN PAVLOV	{"email": "i.pavlov011963@postgrespro.ru", "phone": "+70504668527"}
0005433008588	61FFD5	9588 572987	IRINA LAZAREVA	{"email": "irina_lazareva-24041961@postgrespro.ru", "phone": "+70549955364"}
0005433008589	D286CC	0351 436633	SVETLANA ROMANOVA	{"email": "romanova_s-081978@postgrespro.ru", "phone": "+70440556429"}
0005433008590	0BA2A9	7670 821902	LIDIYA PETROVA	{"email": "petrova.l_061968@postgrespro.ru", "phone": "+70802427114"}
0005433008591	7DCA59	6097 554877	VALERIY MATVEEV	{"email": "matveevv081969@postgrespro.ru", "phone": "+70874010692"}
0005433008592	507AD1	4808 921658	MARAT CHERNOV	{"email": "marat.chernov.1978@postgrespro.ru", "phone": "+70619494653"}
0005433008593	BBF75E	6658 059356	GENNADIY ZHUKOV	{"phone": "+70958322051"}
0005433008594	C1F4F5	2597 920968	DMITRIY SAVELEV	{"email": "savelev-dmitriy.18021971@postgrespro.ru", "phone": "+70434243841"}
0005433008595	4A3989	1659 419625	YULIYA LEBEDEVA	{"phone": "+70584906495"}
0005433008596	D14FE3	5874 582898	KRISTINA KUZNECOVA	{"phone": "+70388652990"}
0005433008597	ADF44A	4884 363616	GALINA TITOVA	{"email": "titova-galina-20081971@postgrespro.ru", "phone": "+70043507466"}
0005433008598	ADF44A	8930 007905	VIKTOR NIKOLAEV	{"email": "viktor_nikolaev-061972@postgrespro.ru", "phone": "+70045373165"}
0005433008599	5274A6	2647 164741	ANATOLIY POPOV	{"phone": "+70674514493"}
0005433008600	5274A6	1982 595174	DMITRIY SMIRNOV	{"email": "smirnov_d1971@postgrespro.ru", "phone": "+70859949866"}
0005433008601	9BBB0C	9503 515541	EKATERINA STEPANOVA	{"phone": "+70858387754"}
0005433008602	3FA2B2	6690 052261	VADIM KAZAKOV	{"email": "v_kazakov.061973@postgrespro.ru", "phone": "+70508873074"}
0005433008603	686C65	9324 053245	DIANA ABRAMOVA	{"email": "d-abramova_021979@postgrespro.ru", "phone": "+70800597878"}
0005433008604	4D2457	4266 641570	IGOR ALEKSEEV	{"phone": "+70978302195"}
0005433008605	7D407E	2583 628683	LEYLA FILIPPOVA	{"phone": "+70563437403"}
0005433008606	B1C321	1896 827802	GENNADIY SERGEEV	{"phone": "+70416443585"}
0005433008607	4967F9	7391 857440	MARINA KOZLOVA	{"email": "m-kozlova_011965@postgrespro.ru", "phone": "+70872238876"}
0005433008608	30D66B	5631 620473	RASIM TIKHONOV	{"email": "tikhonov-rasim-1967@postgrespro.ru", "phone": "+70058839940"}
0005433008609	30D66B	4324 904782	PAVEL ROMANOV	{"phone": "+70880295323"}
0005433008610	9E7539	0286 050443	NIKITA IVANOV	{"phone": "+70169412943"}
0005433008611	E50AEB	5398 268501	ALEKSANDR ANDREEV	{"email": "a.andreev1973@postgrespro.ru", "phone": "+70131423171"}
0005433008612	2E0816	5395 225397	LIDIYA GAVRILOVA	{"phone": "+70311309295"}
0005433008613	2E0816	5524 068581	LYUDMILA MAKSIMOVA	{"phone": "+70239369696"}
0005433008614	F66915	2412 935008	OLGA OSIPOVA	{"email": "osipova.olga061965@postgrespro.ru", "phone": "+70626832448"}
0005433008615	B72B70	3122 883345	NINA POPOVA	{"phone": "+70600088934"}
0005433008616	B72B70	3906 397047	VYACHESLAV FOMIN	{"phone": "+70385902352"}
0005433008617	527550	7770 920097	MARGARITA KUZNECOVA	{"phone": "+70304048573"}
0005433008618	BA5C4E	6752 908001	ANASTASIYA KOZLOVA	{"phone": "+70337124855"}
0005433008619	F38363	1992 778529	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_021967@postgrespro.ru", "phone": "+70363631086"}
0005433008620	3F4361	0558 274405	ANNA VASILEVA	{"email": "a_vasileva_1969@postgrespro.ru", "phone": "+70940102065"}
0005433008621	3F4361	6481 936926	VALERIY GORBUNOV	{"phone": "+70737329908"}
0005433008622	81560F	2882 659294	ANTONINA ABRAMOVA	{"email": "antoninaabramova071971@postgrespro.ru", "phone": "+70569591958"}
0005433008623	D8129F	8971 942906	VIOLETTA ZAYCEVA	{"email": "zayceva_violetta011978@postgrespro.ru", "phone": "+70006230996"}
0005433008624	107313	8417 372548	VALENTIN FOMIN	{"email": "fominvalentin17071985@postgrespro.ru", "phone": "+70883974950"}
0005433008625	107313	7757 426065	IVAN ZAKHAROV	{"phone": "+70433131340"}
0005433008626	29EC5C	0034 958692	ARINA VOROBEVA	{"phone": "+70038487272"}
0005433008627	9F264D	8123 867366	ELENA DAVYDOVA	{"email": "elena.davydova.03021973@postgrespro.ru", "phone": "+70086807124"}
0005433008628	9F264D	7764 074997	VLADIMIR MOROZOV	{"phone": "+70690620515"}
0005433008629	ABCFD8	2921 112389	MARIYA ZHUKOVA	{"phone": "+70899386456"}
0005433008631	544AB3	0099 416388	ANATOLIY KUZNECOV	{"phone": "+70630975578"}
0005433008632	976784	5779 369489	LYUDMILA SEMENOVA	{"phone": "+70174130907"}
0005433008633	58F441	0096 451766	TATYANA OVCHINNIKOVA	{"email": "tatyana_ovchinnikova.1966@postgrespro.ru", "phone": "+70041679182"}
0005433008634	BCCACB	2955 295775	ANATOLIY ANDREEV	{"email": "andreev.a-01071977@postgrespro.ru", "phone": "+70484507417"}
0005433008635	F672B9	7625 497724	MARIYA SOROKINA	{"phone": "+70486549130"}
0005433008636	72A4A3	6283 053006	YULIYA ZHURAVLEVA	{"email": "yuliya_zhuravleva_1969@postgrespro.ru", "phone": "+70323507678"}
0005433008637	72A4A3	9470 381798	LYUBOV FILIPPOVA	{"email": "filippova.l_091983@postgrespro.ru", "phone": "+70729421786"}
0005433008638	B95559	1792 712178	SERGEY ZHURAVLEV	{"email": "szhuravlev1987@postgrespro.ru", "phone": "+70874514206"}
0005433008639	F2C05F	5838 304720	ALBERT STEPANOV	{"email": "a-stepanov091966@postgrespro.ru", "phone": "+70357668687"}
0005433008640	B846E9	7334 452460	VERA MEDVEDEVA	{"email": "vera_medvedeva_09041975@postgrespro.ru", "phone": "+70271771296"}
0005433008641	B846E9	2239 084695	YURIY BELOV	{"phone": "+70508482620"}
0005433008642	12C30B	7040 391089	RAFAIL GAVRILOV	{"email": "gavrilovrafail.1977@postgrespro.ru", "phone": "+70247914300"}
0005433008643	12C30B	9806 352578	IRINA MIRONOVA	{"email": "mironovairina24121972@postgrespro.ru", "phone": "+70895212646"}
0005433008644	58A1CA	4151 183873	VALENTINA KRASNOVA	{"phone": "+70518458796"}
0005433008645	2CE849	4917 580959	KSENIYA SOROKINA	{"email": "kseniya_sorokina-081974@postgrespro.ru", "phone": "+70056685212"}
0005433008646	2CE849	0795 344345	LYUBOV ABRAMOVA	{"phone": "+70914728255"}
0005433008647	F0AA41	5026 608268	YURIY ILIN	{"email": "ilin-yuriy-03071965@postgrespro.ru", "phone": "+70018745489"}
0005433008648	F0AA41	9334 575598	ALEKSEY MARTYNOV	{"email": "martynov_aleksey.1967@postgrespro.ru", "phone": "+70100643713"}
0005433008649	86E37C	5516 029930	NADEZHDA KUZNECOVA	{"email": "kuznecova_n.02071966@postgrespro.ru", "phone": "+70099401090"}
0005433008650	7D5DC9	7606 443287	TATYANA ROMANOVA	{"email": "tromanova1973@postgrespro.ru", "phone": "+70500912364"}
0005433008651	BD1A6D	4648 184588	NIKITA ZAYCEV	{"email": "zaycev-n_11101959@postgrespro.ru", "phone": "+70632958683"}
0005433008652	A91811	8175 850112	SNEZHANA FROLOVA	{"email": "frolova_s-07071974@postgrespro.ru", "phone": "+70085358537"}
0005433008653	A91811	1942 805649	KONSTANTIN POPOV	{"phone": "+70347811581"}
0005433008654	ABFECB	6273 627130	ANATOLIY PETROV	{"email": "petrov_anatoliy-091974@postgrespro.ru", "phone": "+70239253472"}
0005433008655	14DA97	0728 866197	ZINAIDA KONOVALOVA	{"phone": "+70056250491"}
0005433008656	FF1902	0765 283977	ANNA ROMANOVA	{"email": "a.romanova111977@postgrespro.ru", "phone": "+70393220574"}
0005433008657	3A9BF0	4715 510453	OLGA BORISOVA	{"email": "borisovaolga-041973@postgrespro.ru", "phone": "+70537042007"}
0005433008658	3A9BF0	7785 507137	NADEZHDA YAKOVLEVA	{"email": "yakovlevanadezhda08061975@postgrespro.ru", "phone": "+70603932528"}
0005433008659	4517C2	8223 214806	VIKTOR KULIKOV	{"phone": "+70309836526"}
0005433008660	F90EB1	0591 847985	SERGEY BELOV	{"email": "belovsergey1982@postgrespro.ru", "phone": "+70422979300"}
0005433008661	F60A09	6449 296908	ALEKSEY MAKAROV	{"email": "makarov-aleksey15011972@postgrespro.ru", "phone": "+70695190749"}
0005433008662	5F947A	8518 173131	ANASTASIYA TROFIMOVA	{"phone": "+70434699630"}
0005433008663	5F947A	9745 832145	ALEKSANDRA ZHUKOVA	{"email": "zhukova-a1977@postgrespro.ru", "phone": "+70952058099"}
0005433008664	D11571	1440 627796	GALINA MELNIKOVA	{"email": "melnikova-galina_1967@postgrespro.ru", "phone": "+70495700341"}
0005433008665	D11571	6793 685888	SERGEY VASILEV	{"email": "vasilev_s-16071968@postgrespro.ru", "phone": "+70787841803"}
0005433008666	3EBA12	9218 853820	ELENA ORLOVA	{"phone": "+70870502226"}
0005433008667	12486E	5710 532791	VIKTOR SEMENOV	{"phone": "+70680818145"}
0005433008668	12486E	9591 123222	DMITRIY MIRONOV	{"email": "mironov-dmitriy_18101976@postgrespro.ru", "phone": "+70434356104"}
0005433008669	C223FB	1845 255711	ELENA KUZNECOVA	{"email": "kuznecova-e_22101972@postgrespro.ru", "phone": "+70451302912"}
0005433008670	C50181	9409 014029	KIRILL SOROKIN	{"email": "kirillsorokin-1978@postgrespro.ru", "phone": "+70055682251"}
0005433008671	C50181	1993 960117	ANDREY KARPOV	{"email": "andrey-karpov1968@postgrespro.ru", "phone": "+70770270646"}
0005433008672	CB3B0E	2299 642412	VLADIMIR NAZAROV	{"phone": "+70524603541"}
0005433008673	94818A	1026 517327	NIKOLAY ABRAMOV	{"email": "n.abramov.03031965@postgrespro.ru", "phone": "+70619384034"}
0005433008674	94818A	4111 238474	SVETLANA MAKAROVA	{"phone": "+70771373808"}
0005433008675	94818A	1698 957484	OLESYA ANISIMOVA	{"phone": "+70307411933"}
0005433008676	EC2301	0264 358215	ANNA FADEEVA	{"phone": "+70491949417"}
0005433008677	6E6ACE	3153 791938	ELENA EFIMOVA	{"phone": "+70423331632"}
0005433008678	C65313	4865 637391	ANNA NAZAROVA	{"email": "anazarova-1964@postgrespro.ru", "phone": "+70246876832"}
0005433008679	C65313	1433 134487	ALEKSEY VOLKOV	{"phone": "+70808057068"}
0005433008680	914B13	1736 898574	ZHANNA ROMANOVA	{"email": "romanova-zhanna-121974@postgrespro.ru", "phone": "+70267433334"}
0005433008681	914B13	6971 320371	OKSANA IVANOVA	{"email": "o-ivanova_1977@postgrespro.ru", "phone": "+70601188291"}
0005433008682	2EC604	9606 417887	ANDREY AFANASEV	{"email": "afanasev.andrey041975@postgrespro.ru", "phone": "+70248576684"}
0005433008683	2EC604	1185 220868	KIRILL IVANOV	{"phone": "+70527404616"}
0005433008684	41DC3C	2657 726745	ELENA STEPANOVA	{"email": "e-stepanova_03041974@postgrespro.ru", "phone": "+70504808033"}
0005433008685	85AB28	1068 416150	NIKOLAY PETROV	{"email": "petrovnikolay_26101974@postgrespro.ru", "phone": "+70357599011"}
0005433008686	184220	1018 213188	OLGA KAZAKOVA	{"phone": "+70079502750"}
0005433008687	184220	1721 427774	EKATERINA NIKOLAEVA	{"phone": "+70811418225"}
0005433008688	26BB10	1738 004391	MARINA IVANOVA	{"phone": "+70132336404"}
0005433008689	B55AEC	6330 401894	VASILIY ANTONOV	{"email": "v_antonov031983@postgrespro.ru", "phone": "+70573777179"}
0005433008690	9B1688	3064 836596	VLADIMIR IVANOV	{"phone": "+70849618719"}
0005433008691	9B1688	1477 875711	MARINA VASILEVA	{"email": "m.vasileva_02101987@postgrespro.ru", "phone": "+70459566711"}
0005433008692	F7FFEB	0790 884797	GENNADIY BORISOV	{"phone": "+70202007136"}
0005433008693	D9E1A4	2253 444719	SHAMIL PETROV	{"email": "petrov.s021974@postgrespro.ru", "phone": "+70571333134"}
0005433008694	D9E1A4	5318 315936	EGOR KRASNOV	{"phone": "+70657090399"}
0005433008695	C3E86B	7891 090830	ALEKSEY DENISOV	{"email": "a.denisov-13031979@postgrespro.ru", "phone": "+70526211577"}
0005433008696	04DBCC	4390 458658	SERGEY EGOROV	{"phone": "+70818092129"}
0005433008697	8EE447	8282 356858	PAVEL DENISOV	{"email": "denisovpavel1977@postgrespro.ru", "phone": "+70550142863"}
0005433008698	EB3AD1	7278 449017	VLADIMIR STEPANOV	{"phone": "+70741318559"}
0005433008699	EB3AD1	8437 340912	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov-101968@postgrespro.ru", "phone": "+70707145063"}
0005433008700	41ECCC	5013 924717	ZINAIDA SMIRNOVA	{"email": "smirnova_zinaida.1972@postgrespro.ru", "phone": "+70798048671"}
0005433008701	3B0D80	0652 609237	VALENTINA KOZLOVA	{"email": "kozlovav_041975@postgrespro.ru", "phone": "+70717336897"}
0005433008702	425A08	9399 366605	LYUDMILA KUDRYASHOVA	{"phone": "+70863415448"}
0005433008703	B36ADA	4796 200262	ANNA BELOVA	{"email": "belova_anna1965@postgrespro.ru", "phone": "+70825538641"}
0005433008704	B36ADA	0170 495685	LARISA YUDINA	{"phone": "+70387510756"}
0005433008705	2892FB	0445 065977	LEONID ANDREEV	{"email": "leonid.andreev011966@postgrespro.ru", "phone": "+70905645741"}
0005433008706	08CB35	1637 915978	TATYANA SERGEEVA	{"phone": "+70537349412"}
0005433008707	0BE9E0	4709 883777	EMIL DAVYDOV	{"email": "davydov_emil_041972@postgrespro.ru", "phone": "+70156611804"}
0005433008708	0BE9E0	6866 554301	DMITRIY VOLKOV	{"email": "dmitriyvolkov-1963@postgrespro.ru", "phone": "+70896290366"}
0005433008709	F585E0	7917 004521	ELIZAVETA KOVALEVA	{"phone": "+70533271068"}
0005433008710	5EA0B5	9511 214098	TATYANA BOGDANOVA	{"phone": "+70645231795"}
0005433008711	493B29	3805 009918	MAKSIM BORISOV	{"phone": "+70937803369"}
0005433008712	493B29	8836 204121	NINA SIDOROVA	{"phone": "+70419966585"}
0005433008713	CEAE8C	0948 227653	GENNADIY PETROV	{"phone": "+70081633158"}
0005433008714	2870CC	9449 145478	OLGA KUZNECOVA	{"email": "kuznecovao.1975@postgrespro.ru", "phone": "+70972460957"}
0005433008715	0798F6	0988 168230	GULFIYA VASILEVA	{"phone": "+70600565301"}
0005433008716	39D2E1	1431 415212	ALEKSANDRA ISAEVA	{"phone": "+70484615777"}
0005433008717	2EE343	5776 848259	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.14051972@postgrespro.ru", "phone": "+70009611713"}
0005433008718	2EE343	3665 398756	IGOR MAKSIMOV	{"email": "i.maksimov_1978@postgrespro.ru", "phone": "+70917478389"}
0005433008719	F74F7F	3514 056569	LYUBOV ANTONOVA	{"phone": "+70089226149"}
0005433008720	3D5B2D	4103 088937	VALENTINA AKIMOVA	{"phone": "+70794119708"}
0005433008721	3D5B2D	8867 903665	VLADISLAV RODIONOV	{"email": "vladislavrodionov_1972@postgrespro.ru", "phone": "+70606502150"}
0005433008722	58D775	3682 580975	ALEKSANDR KULIKOV	{"phone": "+70091557150"}
0005433008723	45345A	9222 373457	OLGA DMITRIEVA	{"phone": "+70640311830"}
0005433008724	45345A	1730 948701	ALENA SAVELEVA	{"phone": "+70034192861"}
0005433008725	3E0BDC	3149 444242	OLGA TROFIMOVA	{"email": "olga_trofimova_021972@postgrespro.ru", "phone": "+70572283662"}
0005433008726	31A5F7	6454 428254	EVGENIY GERASIMOV	{"phone": "+70955194703"}
0005433008727	BC5341	2860 521429	OLGA KRASNOVA	{"email": "krasnovaolga-06041988@postgrespro.ru", "phone": "+70519424206"}
0005433008728	A8B6DB	0140 640830	OLESYA DMITRIEVA	{"phone": "+70436481228"}
0005433008729	546D1C	4452 907046	VIKTORIYA MEDVEDEVA	{"phone": "+70493014563"}
0005433008730	4359E4	8906 576861	ANDREY SMIRNOV	{"phone": "+70785493009"}
0005433008731	4359E4	7313 069573	VALENTINA LAZAREVA	{"phone": "+70783449008"}
0005433008732	8FE44A	6747 199560	ARTEM EGOROV	{"phone": "+70773760460"}
0005433008733	8FE44A	5052 577149	ANNA POPOVA	{"email": "anna-popova_1969@postgrespro.ru", "phone": "+70594132013"}
0005433008734	079E47	5518 003763	ARTEM GERASIMOV	{"email": "gerasimovartem-07091965@postgrespro.ru", "phone": "+70131831954"}
0005433008735	079E47	7978 557451	VERA VOROBEVA	{"email": "vorobeva.vera_1971@postgrespro.ru", "phone": "+70058935312"}
0005433008736	BE867E	1830 003742	MARINA IVANOVA	{"phone": "+70454589486"}
0005433008737	DB6872	2323 343229	ANASTASIYA KISELEVA	{"phone": "+70216606499"}
0005433008738	9CC66B	7180 467612	IVAN KUZNECOV	{"phone": "+70323435628"}
0005433008739	9CC66B	8103 525796	DIANA KOROLEVA	{"phone": "+70345341874"}
0005433008740	9C60F7	2003 490156	VIKTOR ALEKSEEV	{"phone": "+70257336799"}
0005433008741	62F8A7	8045 452532	IVAN FILIPPOV	{"email": "filippov.i-07011970@postgrespro.ru", "phone": "+70861433789"}
0005433008742	D534B1	5366 766776	NATALYA FOMINA	{"email": "n-fomina-1976@postgrespro.ru", "phone": "+70275159407"}
0005433008743	C35E90	6843 509514	GALINA PAVLOVA	{"email": "g-pavlova-1974@postgrespro.ru", "phone": "+70716107252"}
0005433008744	F98730	4298 981060	ANASTASIYA POPOVA	{"email": "popova-anastasiya_1971@postgrespro.ru", "phone": "+70446898873"}
0005433008745	CA7EE2	8230 969515	TATYANA LEBEDEVA	{"email": "t_lebedeva.23111961@postgrespro.ru", "phone": "+70287023620"}
0005433008746	FF9C28	2536 177349	PAVEL SERGEEV	{"phone": "+70747235782"}
0005433008747	7503E5	8663 203500	GULNARA VLASOVA	{"email": "g-vlasova_081972@postgrespro.ru", "phone": "+70767675655"}
0005433008748	431EEA	3010 832220	ANNA TIMOFEEVA	{"phone": "+70997004894"}
0005433008749	431EEA	8698 245033	ANATOLIY ZAKHAROV	{"phone": "+70957900898"}
0005433008750	4B810C	0915 710036	ANATOLIY FOMIN	{"phone": "+70258513487"}
0005433008751	5AB807	8373 730987	GALINA EFREMOVA	{"email": "galinaefremova_22071980@postgrespro.ru", "phone": "+70759376686"}
0005433008752	5AB807	4877 954889	DMITRIY DAVYDOV	{"phone": "+70192572528"}
0005433008753	C6C1F3	9233 074056	VLADIMIR POPOV	{"email": "popov.v051974@postgrespro.ru", "phone": "+70022552531"}
0005433008754	48A302	9229 864941	OLGA GERASIMOVA	{"phone": "+70484647198"}
0005433008755	48A302	7995 734834	SERGEY TIMOFEEV	{"email": "timofeev_s-091970@postgrespro.ru", "phone": "+70813324752"}
0005433008756	48A302	9613 892774	NATALYA TIKHONOVA	{"phone": "+70538021446"}
0005433008757	E3F502	5989 367302	EVGENIYA RODIONOVA	{"phone": "+70753676593"}
0005433008758	E3F502	5783 316164	IVAN POPOV	{"email": "i-popov_1970@postgrespro.ru", "phone": "+70884836266"}
0005433008759	7DA2E6	3272 919227	MARIYA KUZNECOVA	{"email": "kuznecova.mariya_121968@postgrespro.ru", "phone": "+70818404568"}
0005433008760	A47100	7142 726459	LILIYA ZHURAVLEVA	{"email": "zhuravleva-liliya-16121968@postgrespro.ru", "phone": "+70140111534"}
0005433008761	A47100	3820 735511	NINA DENISOVA	{"phone": "+70402862053"}
0005433008762	A47100	2833 150936	VLADIMIR CHERNOV	{"email": "vladimir.chernov051991@postgrespro.ru", "phone": "+70923993489"}
0005433008763	E77666	6892 788417	VLADIMIR VOLKOV	{"phone": "+70320425984"}
0005433008764	E77666	2412 881297	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy1977@postgrespro.ru", "phone": "+70000226895"}
0005433008765	E77666	1211 196773	TAMARA SMIRNOVA	{"email": "tamarasmirnova_1971@postgrespro.ru", "phone": "+70271492581"}
0005433008766	DBA748	1392 228459	NADEZHDA ALEKSANDROVA	{"phone": "+70406813631"}
0005433008767	37973D	4942 678961	ELENA MOISEEVA	{"email": "moiseeva_e.091965@postgrespro.ru", "phone": "+70931533081"}
0005433008768	77BF40	2262 321415	NINA IVANOVA	{"email": "ivanovan-1954@postgrespro.ru", "phone": "+70949720401"}
0005433008769	77BF40	6194 107887	ELENA DMITRIEVA	{"email": "dmitrieva-e1971@postgrespro.ru", "phone": "+70618386491"}
0005433008770	B3AD93	2713 007327	KONSTANTIN MAKSIMOV	{"phone": "+70780853835"}
0005433008771	BEEA46	6822 484855	NATALYA POTAPOVA	{"phone": "+70072747450"}
0005433008772	9133B8	9577 856809	NATALYA MOISEEVA	{"email": "moiseevanatalya_121971@postgrespro.ru", "phone": "+70538205480"}
0005433008773	04E778	3552 581733	ELENA PAVLOVA	{"email": "elena.pavlova111956@postgrespro.ru", "phone": "+70455923519"}
0005433008774	788137	8895 407966	OLGA MALYSHEVA	{"email": "o_malysheva.1962@postgrespro.ru", "phone": "+70453875482"}
0005433008775	788137	8694 821409	EDUARD GUSEV	{"phone": "+70465244337"}
0005433008776	788137	7452 155714	SERGEY NAZAROV	{"email": "s.nazarov.30051973@postgrespro.ru", "phone": "+70917099591"}
0005433008777	A1AE47	1954 033708	DENIS ZAKHAROV	{"phone": "+70432789296"}
0005433008778	A1AE47	6130 747368	OLEG ILIN	{"email": "ilino_1971@postgrespro.ru", "phone": "+70985808882"}
0005433008779	A1AE47	4170 119669	IRINA GAVRILOVA	{"email": "gavrilova_irina061968@postgrespro.ru", "phone": "+70438685276"}
0005433008780	9A5FEA	8350 018782	GALINA SCHERBAKOVA	{"phone": "+70406070711"}
0005433008781	078EE5	4954 249619	NINA VASILEVA	{"email": "ninavasileva10081972@postgrespro.ru", "phone": "+70822049857"}
0005433008782	E1089A	8289 023837	TAMARA POPOVA	{"phone": "+70930276557"}
0005433008783	E1089A	5244 629203	ELENA ILINA	{"email": "ilina_e28091982@postgrespro.ru", "phone": "+70612169962"}
0005433008784	4889D7	4251 550871	ANNA KUZNECOVA	{"email": "anna_kuznecova-16051980@postgrespro.ru", "phone": "+70194039992"}
0005433008785	F9F612	3891 916532	DMITRIY ISAEV	{"email": "dmitriyisaev1963@postgrespro.ru", "phone": "+70392380789"}
0005433008786	F9F612	1715 365104	ELENA NOVIKOVA	{"phone": "+70683057591"}
0005433008787	2D5386	0568 245022	VLADISLAV DENISOV	{"email": "vladislav_denisov_071972@postgrespro.ru", "phone": "+70071196315"}
0005433008788	A78452	9448 719454	ALEKSANDR SIDOROV	{"email": "asidorov_1981@postgrespro.ru", "phone": "+70438987767"}
0005433008789	A78452	6944 333516	EVGENIY ROMANOV	{"email": "eromanov.041974@postgrespro.ru", "phone": "+70276245242"}
0005433008790	FA1175	2470 743036	ELENA SAVELEVA	{"phone": "+70793418859"}
0005433008791	675720	3961 019234	OKSANA ZAKHAROVA	{"email": "oksana-zakharova_13041979@postgrespro.ru", "phone": "+70440781274"}
0005433008792	51471C	1836 856354	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov_031972@postgrespro.ru", "phone": "+70512846645"}
0005433008793	51471C	7445 052293	VIKTOR VOLKOV	{"email": "volkov.viktor.23101976@postgrespro.ru", "phone": "+70699102967"}
0005433008794	97F4D5	1532 733880	OLGA VASILEVA	{"email": "vasilevaolga-1965@postgrespro.ru", "phone": "+70553405678"}
0005433008795	641BB6	3370 646417	VALERIYA GORBUNOVA	{"phone": "+70908151434"}
0005433008796	641BB6	4146 830174	LEONID CHERNOV	{"phone": "+70663045089"}
0005433008797	F514DF	7748 782715	NADEZHDA POTAPOVA	{"phone": "+70661213783"}
0005433008798	9AA9DE	2137 040749	OLGA KULIKOVA	{"phone": "+70707492195"}
0005433008799	095F96	7025 397400	ALEKSEY DMITRIEV	{"email": "dmitriev.aleksey_021969@postgrespro.ru", "phone": "+70983546817"}
0005433008800	095F96	0361 879820	NINA SMIRNOVA	{"email": "smirnova_n.28081974@postgrespro.ru", "phone": "+70601250455"}
0005433008801	095F96	7737 033673	DMITRIY ANTONOV	{"email": "d.antonov.1977@postgrespro.ru", "phone": "+70336001622"}
0005433008802	1092C7	5164 755174	ALEKSANDR FROLOV	{"email": "frolov_a_1970@postgrespro.ru", "phone": "+70789349431"}
0005433008803	1092C7	0221 809107	ZINAIDA IVANOVA	{"phone": "+70819410045"}
0005433008804	CE8212	1025 953034	GALINA BARANOVA	{"phone": "+70312846768"}
0005433008805	CE8212	1737 951083	VYACHESLAV YAKOVLEV	{"email": "vyacheslavyakovlev_02111966@postgrespro.ru", "phone": "+70298933770"}
0005433008806	CE8212	2320 114544	GENNADIY NIKITIN	{"phone": "+70914953273"}
0005433008807	CE8212	6618 803727	ANDREY KONOVALOV	{"phone": "+70234068564"}
0005433008808	C59F68	9880 620714	DENIS MOISEEV	{"email": "moiseev_d.071970@postgrespro.ru", "phone": "+70706021687"}
0005433008809	C59F68	0037 297408	SERGEY ANTONOV	{"email": "antonov.sergey13091978@postgrespro.ru", "phone": "+70046306590"}
0005433008810	495221	0416 794257	NATALYA GORBUNOVA	{"email": "n_gorbunova-021981@postgrespro.ru", "phone": "+70918027672"}
0005433008811	495221	4973 857032	SOFYA VASILEVA	{"phone": "+70851324662"}
0005433008812	A26465	1010 743849	NELLI VOROBEVA	{"email": "vorobeva-n.091987@postgrespro.ru", "phone": "+70437970074"}
0005433008813	9DCB6D	8988 272823	SVETLANA PETROVA	{"phone": "+70839838454"}
0005433008814	DCBA9A	6560 635282	DMITRIY FEDOROV	{"email": "dmitriy-fedorov1959@postgrespro.ru", "phone": "+70250250242"}
0005433008815	3C4693	3659 671326	VYACHESLAV STEPANOV	{"email": "stepanov-vyacheslav10081967@postgrespro.ru", "phone": "+70776151870"}
0005433008816	0CC2EF	2901 879597	SERGEY ABRAMOV	{"phone": "+70220871391"}
0005433008817	0CC2EF	8764 538921	TATYANA KULIKOVA	{"phone": "+70718146418"}
0005433008818	8E1C69	5536 918168	ALEKSANDR IVANOV	{"email": "ivanov_a-22111973@postgrespro.ru", "phone": "+70192382606"}
0005433008819	C96BF9	3679 197348	SERGEY NOVIKOV	{"email": "sergey_novikov-051964@postgrespro.ru", "phone": "+70325930587"}
0005433008820	397702	1069 799065	ALEKSANDR FILIPPOV	{"phone": "+70508707811"}
0005433008821	397702	7987 584658	ANASTASIYA BARANOVA	{"email": "a.baranova-1980@postgrespro.ru", "phone": "+70668268544"}
0005433008822	F410F4	8530 277778	SERGEY DENISOV	{"email": "sergey_denisov_1967@postgrespro.ru", "phone": "+70432998994"}
0005433008823	F8414A	2465 940205	ANDREY ANTONOV	{"phone": "+70142417925"}
0005433008824	A52DBD	5454 657129	OLGA NIKITINA	{"phone": "+70226577506"}
0005433008825	A52DBD	7896 004420	PETR GUSEV	{"email": "p_gusev15071981@postgrespro.ru", "phone": "+70997376920"}
0005433008826	93DA7F	0055 538920	RUSTAM ISAEV	{"phone": "+70860637746"}
0005433008827	73C206	0565 151288	VLADIMIR KUZNECOV	{"phone": "+70451189242"}
0005433008828	73C206	5740 506441	LILIYA NAUMOVA	{"phone": "+70684953683"}
0005433008829	C9EFBA	3814 722315	SERGEY KULIKOV	{"phone": "+70717305190"}
0005433008830	0A6E6F	2567 340192	MARIYA KUDRYASHOVA	{"email": "mkudryashova_121961@postgrespro.ru", "phone": "+70280615663"}
0005433008831	0A6E6F	9971 949617	DIANA FROLOVA	{"email": "d-frolova.20031965@postgrespro.ru", "phone": "+70403272608"}
0005433008832	E92998	0336 168983	EVGENIY IVANOV	{"email": "e.ivanov_04041967@postgrespro.ru", "phone": "+70918296696"}
0005433008833	6F0541	5229 188170	TATYANA LAZAREVA	{"phone": "+70193455582"}
0005433008834	6F0541	5624 124528	DMITRIY GERASIMOV	{"phone": "+70358300941"}
0005433008891	DE8510	3526 819323	ALEKSEY ALEKSEEV	{"phone": "+70777218748"}
0005433008835	6F0541	9030 221107	LYUDMILA MOISEEVA	{"email": "moiseeval_031970@postgrespro.ru", "phone": "+70378146081"}
0005433008836	86F584	4800 411514	DARYA IVANOVA	{"email": "ivanovadarya011978@postgrespro.ru", "phone": "+70449666717"}
0005433008837	B2886D	1590 031730	SALAVAT TIKHONOV	{"phone": "+70123922300"}
0005433008838	0B9957	5565 444567	OLESYA ANDREEVA	{"email": "andreeva-olesya_1965@postgrespro.ru", "phone": "+70288398220"}
0005433008839	CEFDCE	7112 877017	YANA KUZNECOVA	{"email": "y_kuznecova_08111962@postgrespro.ru", "phone": "+70959080628"}
0005433008840	4E1CE9	3456 556367	MARAT SOLOVEV	{"email": "marat_solovev-20041981@postgrespro.ru", "phone": "+70890785057"}
0005433008841	94B0B3	2876 733434	NINA RODIONOVA	{"phone": "+70806882130"}
0005433008842	3DF584	9897 966680	NINA ZAKHAROVA	{"email": "zakharova_nina.13081959@postgrespro.ru", "phone": "+70130011411"}
0005433008843	3DF584	9217 201859	ANASTASIYA POLYAKOVA	{"email": "polyakova.a031975@postgrespro.ru", "phone": "+70516507530"}
0005433008844	C08E59	6631 027768	ELENA FEDOROVA	{"email": "fedorovae.051971@postgrespro.ru", "phone": "+70169701860"}
0005433008845	C08E59	4091 972354	ALEKSANDRA MOISEEVA	{"phone": "+70031874803"}
0005433008846	D53970	5302 182884	TAMARA KOROLEVA	{"phone": "+70219197176"}
0005433008847	0BA308	9819 430334	MAGOMED ILIN	{"email": "milin.31071979@postgrespro.ru", "phone": "+70445177293"}
0005433008848	0BA308	5469 534044	ALEKSANDR TARASOV	{"email": "aleksandrtarasov.28101975@postgrespro.ru", "phone": "+70226028230"}
0005433008849	0BA308	8903 183522	LYUDMILA FILIPPOVA	{"phone": "+70515376752"}
0005433008850	6AD41C	1933 772622	LYUDMILA ZHURAVLEVA	{"phone": "+70383712776"}
0005433008851	6AD41C	6696 807161	SVETLANA KARPOVA	{"phone": "+70874934768"}
0005433008852	6C0B6D	1278 247472	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_nikolay_111963@postgrespro.ru", "phone": "+70351871250"}
0005433008853	20F22D	9173 601568	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov20081969@postgrespro.ru", "phone": "+70477069590"}
0005433008854	E703B6	3399 038761	IRINA TIMOFEEVA	{"phone": "+70910245228"}
0005433008855	12BE50	6422 600129	RAISA NIKOLAEVA	{"phone": "+70729129357"}
0005433008856	12BE50	1515 808008	PETR SMIRNOV	{"email": "smirnov.p011965@postgrespro.ru", "phone": "+70923042559"}
0005433008857	12BE50	0880 765475	YANA BORISOVA	{"email": "yborisova.1971@postgrespro.ru", "phone": "+70548083398"}
0005433008858	A03B04	0017 369682	SERGEY SAVELEV	{"email": "s_savelev1960@postgrespro.ru", "phone": "+70249866608"}
0005433008859	26215C	4033 642354	ANDREY FROLOV	{"email": "afrolov081972@postgrespro.ru", "phone": "+70636486866"}
0005433008860	8B6BDB	4263 578537	VLADIMIR NAZAROV	{"phone": "+70393464225"}
0005433008861	4DA423	6403 309081	TATYANA IVANOVA	{"phone": "+70906273834"}
0005433008862	EC80B8	3399 699381	VYACHESLAV SAVELEV	{"phone": "+70121833957"}
0005433008863	319490	2693 748875	LYUDMILA ROMANOVA	{"phone": "+70579764200"}
0005433008864	319490	2314 021164	SVETLANA POPOVA	{"email": "popovas.09111978@postgrespro.ru", "phone": "+70753322689"}
0005433008865	1D0658	5856 372375	AZAT GORBUNOV	{"email": "a_gorbunov111977@postgrespro.ru", "phone": "+70141196630"}
0005433008866	1D0658	2702 868662	ALEKSANDR KUZNECOV	{"phone": "+70636568097"}
0005433008867	ABD76A	8964 184605	DMITRIY KUZNECOV	{"phone": "+70506228104"}
0005433008868	29FCB5	6481 079667	VLADIMIR MOROZOV	{"email": "morozovvladimir30101978@postgrespro.ru", "phone": "+70430488995"}
0005433008869	FDE769	8710 629202	ALFIYA MELNIKOVA	{"phone": "+70108454122"}
0005433008870	7293DE	6470 493981	SVETLANA GAVRILOVA	{"email": "s.gavrilova-27051980@postgrespro.ru", "phone": "+70738846771"}
0005433008871	5B6A73	0995 057733	KONSTANTIN OSIPOV	{"phone": "+70639199295"}
0005433008872	9E324B	9239 363803	EVGENIY KOZLOV	{"email": "kozlov-e.1977@postgrespro.ru", "phone": "+70273387173"}
0005433008873	DAD23E	0253 646391	ANDREY DMITRIEV	{"phone": "+70729731944"}
0005433008874	A7500C	9540 070733	TAMARA KALININA	{"phone": "+70706151300"}
0005433008875	67AFF9	2683 435754	LEONID NIKOLAEV	{"phone": "+70153271287"}
0005433008876	046449	3937 176368	KSENIYA SMIRNOVA	{"email": "smirnova.k1977@postgrespro.ru", "phone": "+70102071236"}
0005433008877	E6483B	8043 133576	NINA KUZMINA	{"phone": "+70380315586"}
0005433008878	BAF83E	3747 386860	ALEKSEY SAVELEV	{"email": "asavelev.1976@postgrespro.ru", "phone": "+70638205722"}
0005433008879	BAF83E	4826 588856	VIKTORIYA IVANOVA	{"email": "viktoriya.ivanova_121970@postgrespro.ru", "phone": "+70370148371"}
0005433008880	558E8C	6437 072851	VYACHESLAV ZAKHAROV	{"email": "zakharov_v1959@postgrespro.ru", "phone": "+70699460231"}
0005433008881	558E8C	9073 380079	VADIM PETROV	{"email": "petrov_v.1966@postgrespro.ru", "phone": "+70895037135"}
0005433008882	847070	8262 178923	NIKOLAY PETROV	{"email": "nikolay-petrov_1970@postgrespro.ru", "phone": "+70533684700"}
0005433008883	847070	8101 899916	LYUDMILA MATVEEVA	{"email": "matveeva.l_1961@postgrespro.ru", "phone": "+70994513927"}
0005433008884	0F622F	4137 610361	DMITRIY GRIGOREV	{"email": "grigorev-d.07021974@postgrespro.ru", "phone": "+70164469073"}
0005433008885	48CFB3	5687 166145	MAKSIM SMIRNOV	{"phone": "+70331710558"}
0005433008886	DD2535	3770 497009	VLADISLAV NIKOLAEV	{"email": "vladislav.nikolaev-28011970@postgrespro.ru", "phone": "+70269694104"}
0005433008887	DD2535	7241 992599	VLADIMIR MIRONOV	{"email": "v.mironov-041973@postgrespro.ru", "phone": "+70326678686"}
0005433008888	465281	0654 284320	KSENIYA CHERNOVA	{"phone": "+70145603419"}
0005433008889	465281	2729 486254	TIMOFEY SOKOLOV	{"phone": "+70126949936"}
0005433008890	DE8510	2585 593828	SERGEY ALEKSANDROV	{"phone": "+70411618620"}
0005433008892	0BDC26	5443 367441	TATYANA BELOVA	{"phone": "+70421723541"}
0005433008893	0BDC26	4970 693000	ZOYA ABRAMOVA	{"phone": "+70435111722"}
0005433008894	8338E0	5080 150300	ASIYA KOZLOVA	{"email": "kozlova_asiya_1976@postgrespro.ru", "phone": "+70797948168"}
0005433008895	7593C2	4725 390617	NIKITA IVANOV	{"email": "ivanov_nikita.14081969@postgrespro.ru", "phone": "+70033230207"}
0005433008896	3B6F55	3498 909692	VYACHESLAV NOVIKOV	{"phone": "+70400966399"}
0005433008897	3B6F55	9599 448116	MIKHAIL NIKOLAEV	{"email": "nikolaev_m-041965@postgrespro.ru", "phone": "+70452213982"}
0005433008898	E4B633	9804 120255	TATYANA NIKITINA	{"phone": "+70566088975"}
0005433008899	ECC9E0	6579 280629	LYUDMILA LAZAREVA	{"phone": "+70523777416"}
0005433008900	EF29C6	2646 871588	NIKITA EGOROV	{"email": "negorov_111988@postgrespro.ru", "phone": "+70239299649"}
0005433008901	EF29C6	0794 723732	ALEKSANDR NOVIKOV	{"email": "anovikov04101979@postgrespro.ru", "phone": "+70341313339"}
0005433008902	0CFB3D	2257 932170	MARIYA KOROLEVA	{"phone": "+70968616796"}
0005433008903	236ED7	2276 661986	IGOR ZHUKOV	{"phone": "+70869224794"}
0005433008904	E80AE9	2882 446169	SERGEY ANDREEV	{"phone": "+70772200465"}
0005433008905	E15A73	7125 524758	ANTON VASILEV	{"email": "vasilev_a_011959@postgrespro.ru", "phone": "+70291339933"}
0005433008906	E15A73	5037 084940	YULIYA MIKHAYLOVA	{"phone": "+70353831006"}
0005433008907	AED393	6639 711541	EVGENIY SOROKIN	{"email": "e-sorokin_1975@postgrespro.ru", "phone": "+70864892161"}
0005433008908	EC2595	8895 104006	LARISA ERMAKOVA	{"phone": "+70757700854"}
0005433008909	EC2595	9153 315456	NAIL ALEKSEEV	{"phone": "+70707607993"}
0005433008910	224C41	3117 895593	FEDOR PETROV	{"email": "f_petrov.1982@postgrespro.ru", "phone": "+70588762419"}
0005433008911	5BBAA8	9636 227246	TIMOFEY SOROKIN	{"email": "sorokin-timofey_101987@postgrespro.ru", "phone": "+70675802124"}
0005433008912	670BEE	7902 626893	NINA POPOVA	{"phone": "+70310603853"}
0005433008913	349ECA	2412 726223	IRINA ZAKHAROVA	{"phone": "+70218188955"}
0005433008914	51BF45	5685 441297	SVETLANA FEDOROVA	{"phone": "+70062172841"}
0005433008915	51BF45	6627 178466	DARYA SOKOLOVA	{"email": "darya-sokolova.101963@postgrespro.ru", "phone": "+70385625776"}
0005433008916	70C544	4303 501276	NINA ERMAKOVA	{"email": "n-ermakova.1973@postgrespro.ru", "phone": "+70052123458"}
0005433008917	86DE77	8205 450996	ALEKSEY STEPANOV	{"email": "a.stepanov-1969@postgrespro.ru", "phone": "+70263954485"}
0005433008918	83AD5A	6462 659682	IVAN SHEVCHENKO	{"phone": "+70738550175"}
0005433008919	83AD5A	0796 476175	NURLAN TIKHONOV	{"phone": "+70837000124"}
0005433008920	E356EB	7263 307053	EKATERINA EGOROVA	{"email": "ekaterina_egorova.091979@postgrespro.ru", "phone": "+70245901288"}
0005433008921	E356EB	7380 381385	SHAMIL ANDREEV	{"phone": "+70036072830"}
0005433008922	6A3C23	4255 040493	ANATOLIY KUZNECOV	{"phone": "+70218121407"}
0005433008923	BDF8A6	6892 150954	ILYA ANTONOV	{"email": "iantonov1980@postgrespro.ru", "phone": "+70547644956"}
0005433008924	12CF23	0617 223072	ILYA KUDRYASHOV	{"phone": "+70202387650"}
0005433008925	3E7632	3374 283248	DMITRIY STEPANOV	{"phone": "+70133914786"}
0005433008926	3E7632	6399 091320	OLGA SCHERBAKOVA	{"phone": "+70021794060"}
0005433008927	9E154D	5123 221774	ALEKSANDRA ISAEVA	{"email": "aleksandra-isaeva_09071984@postgrespro.ru", "phone": "+70164750947"}
0005433008928	DE8E67	7740 451427	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev_041971@postgrespro.ru", "phone": "+70051264309"}
0005433008929	47564C	6430 596037	ELENA GORBUNOVA	{"email": "e.gorbunova-1973@postgrespro.ru", "phone": "+70894289252"}
0005433008930	42EC34	7438 090467	NATALYA ORLOVA	{"phone": "+70135882223"}
0005433008931	2C8D0C	5879 864965	NATALYA AFANASEVA	{"email": "afanasevan071976@postgrespro.ru", "phone": "+70444308714"}
0005433008932	141FA7	8828 051241	ALEKSANDR KARPOV	{"email": "aleksandr.karpov-1964@postgrespro.ru", "phone": "+70759889722"}
0005433008933	05671F	6829 581558	VLADIMIR PAVLOV	{"phone": "+70233545117"}
0005433008934	138A17	8578 480049	NATALYA EFIMOVA	{"phone": "+70966862393"}
0005433008935	138A17	0852 995343	SERGEY GORBUNOV	{"phone": "+70772806014"}
0005433008936	138A17	5561 246217	ALEKSANDR GERASIMOV	{"email": "gerasimov-a.1973@postgrespro.ru", "phone": "+70561379176"}
0005433008937	138A17	6170 502607	FARIDA KONOVALOVA	{"phone": "+70849430168"}
0005433008938	A29656	7126 147676	TATYANA ISAEVA	{"email": "isaeva-t_12071974@postgrespro.ru", "phone": "+70400929252"}
0005433008939	E2A230	1065 602853	POLINA BELYAEVA	{"email": "pbelyaeva.1964@postgrespro.ru", "phone": "+70223288901"}
0005433008940	89D7B1	8665 096219	VIKTORIYA KUZNECOVA	{"phone": "+70382091294"}
0005433008941	89D7B1	8484 219534	VALENTINA BORISOVA	{"phone": "+70120537825"}
0005433008942	498E5E	1777 228285	MAKSIM DAVYDOV	{"phone": "+70100343102"}
0005433008943	498E5E	7320 113068	ROMAN FROLOV	{"phone": "+70760545674"}
0005433008944	94AA9E	6599 451112	EKATERINA MAKSIMOVA	{"phone": "+70173363057"}
0005433008945	34EB9C	6618 898736	MAKSIM DENISOV	{"phone": "+70905393393"}
0005433008946	3E875C	3772 170587	ANDREY ILIN	{"email": "a-ilin.18121969@postgrespro.ru", "phone": "+70433390283"}
0005433008947	3E875C	8439 161893	SERGEY SIDOROV	{"phone": "+70298493463"}
0005433008948	3D8FB3	0976 105250	ALEKSANDR IVANOV	{"email": "ivanov_a-04111975@postgrespro.ru", "phone": "+70309488006"}
0005433008949	EA70DB	5144 894386	EDUARD BELOV	{"phone": "+70112761580"}
0005433008950	EA70DB	2526 035336	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_19031969@postgrespro.ru", "phone": "+70083774331"}
0005433008951	EA70DB	4006 069970	DENIS GORBUNOV	{"phone": "+70797130639"}
0005433008952	805C59	3981 270633	EKATERINA LAZAREVA	{"phone": "+70128333007"}
0005433008953	428AAB	9463 995542	DMITRIY DMITRIEV	{"email": "dmitrievdmitriy011978@postgrespro.ru", "phone": "+70109589654"}
0005433008954	428AAB	1521 141478	ANTON KUZNECOV	{"phone": "+70884590476"}
0005433008955	36BBDE	8926 648381	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir_051978@postgrespro.ru", "phone": "+70020970188"}
0005433008956	23BE81	5409 040529	TATYANA STEPANOVA	{"email": "stepanova.t-041977@postgrespro.ru", "phone": "+70377578107"}
0005433008957	647A5A	8319 762895	YANA MOROZOVA	{"phone": "+70871219776"}
0005433008958	0964CB	8688 695536	ROMAN GUSEV	{"phone": "+70267047477"}
0005433008959	0964CB	0446 759699	VERONIKA POLYAKOVA	{"phone": "+70375615491"}
0005433008960	AF5142	3035 750556	NINA NESTEROVA	{"email": "ninanesterova.021969@postgrespro.ru", "phone": "+70913197602"}
0005433008961	AF5142	8939 742930	SERGEY PAVLOV	{"email": "pavlovs_111983@postgrespro.ru", "phone": "+70623287268"}
0005433008962	F38096	5055 754059	VALENTINA SMIRNOVA	{"email": "valentina-smirnova_15111969@postgrespro.ru", "phone": "+70670351481"}
0005433008963	F38096	6265 283840	VALENTIN MAKSIMOV	{"email": "v-maksimov.1970@postgrespro.ru", "phone": "+70387358841"}
0005433008964	E348F1	1182 489136	ANNA FADEEVA	{"email": "fadeeva-anna031968@postgrespro.ru", "phone": "+70981915612"}
0005433008965	38DED3	3728 810447	DENIS BARANOV	{"phone": "+70338794555"}
0005433008966	99E3EC	7654 449599	EKATERINA RODIONOVA	{"email": "ekaterina_rodionova_28111973@postgrespro.ru", "phone": "+70367329524"}
0005433008967	8FFD76	2181 646438	NIKITA IVANOV	{"phone": "+70558068157"}
0005433008968	8FFD76	0364 142120	GALINA ISAEVA	{"email": "isaeva_g.081978@postgrespro.ru", "phone": "+70693688605"}
0005433008969	8FFD76	9652 691223	NADEZHDA SMIRNOVA	{"email": "smirnovanadezhda-091970@postgrespro.ru", "phone": "+70042474204"}
0005433008970	AE3920	5346 932242	GALINA GUSEVA	{"phone": "+70846679214"}
0005433008971	AE3920	7773 674077	VLADIMIR IVANOV	{"email": "ivanov-vladimir.29091954@postgrespro.ru", "phone": "+70189794418"}
0005433008972	DEF201	6265 440697	YULIYA POPOVA	{"phone": "+70967485601"}
0005433008973	DEF201	4430 266903	LYUDMILA DANILOVA	{"email": "danilova.lyudmila121982@postgrespro.ru", "phone": "+70707984589"}
0005433008974	DEF201	7825 377246	DMITRIY GRIGOREV	{"phone": "+70256686544"}
0005433008975	49125D	0681 233272	OLEG KOZLOV	{"email": "o.kozlov-10031975@postgrespro.ru", "phone": "+70183547051"}
0005433008976	ACB17F	1254 637321	VLADIMIR TARASOV	{"email": "tarasov-vladimir.1962@postgrespro.ru", "phone": "+70797309577"}
0005433008977	B58389	5371 459994	SERGEY FOMIN	{"email": "sergey-fomin-1959@postgrespro.ru", "phone": "+70390623387"}
0005433008978	7E4875	9219 159167	VALENTIN SAVELEV	{"email": "valentin_savelev_091973@postgrespro.ru", "phone": "+70039016703"}
0005433008979	BAA7C1	2941 218854	LIDIYA ZHURAVLEVA	{"email": "lzhuravleva-10121963@postgrespro.ru", "phone": "+70687070567"}
0005433008980	BAA7C1	2883 337971	VENERA VOROBEVA	{"email": "vorobevavenera-21041968@postgrespro.ru", "phone": "+70410764115"}
0005433008981	BAA7C1	9867 770292	ELENA MEDVEDEVA	{"phone": "+70475833022"}
0005433008982	3AD1C3	4639 508779	ALEVTINA MARTYNOVA	{"email": "martynova-alevtina111971@postgrespro.ru", "phone": "+70284628949"}
0005433008983	3AD1C3	1910 002579	ANDREY GRIGOREV	{"email": "grigorev.andrey-121978@postgrespro.ru", "phone": "+70759700265"}
0005433008984	E5AD5F	1428 261167	ALEKSEY SMIRNOV	{"phone": "+70790075524"}
0005433008985	DFE4AD	2171 572849	LARISA SCHERBAKOVA	{"email": "l-scherbakova-091985@postgrespro.ru", "phone": "+70700479000"}
0005433008986	DFE4AD	1740 670479	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr13041971@postgrespro.ru", "phone": "+70061692491"}
0005433008987	8ABAAC	1347 539124	LEONID SERGEEV	{"phone": "+70923086234"}
0005433008988	1D8A15	4939 055608	NATALYA ZAYCEVA	{"phone": "+70496121802"}
0005433008989	947E74	0806 540627	LYUDMILA FADEEVA	{"phone": "+70814568461"}
0005433008990	947E74	7813 428463	DMITRIY MELNIKOV	{"email": "d_melnikov1966@postgrespro.ru", "phone": "+70295253515"}
0005433008991	0B9C3E	6990 323998	ALEKSANDRA DMITRIEVA	{"phone": "+70979282233"}
0005433008992	CD76AA	0576 546882	SERGEY SMIRNOV	{"email": "smirnov-sergey16081962@postgrespro.ru", "phone": "+70815894593"}
0005433008993	9CA51D	1803 163954	TATYANA ANDREEVA	{"phone": "+70857411571"}
0005433008994	00A85A	1752 584323	MARIYA KOROLEVA	{"email": "koroleva-m.16091965@postgrespro.ru", "phone": "+70992800366"}
0005433008995	00A85A	8528 984419	VASILISA IVANOVA	{"phone": "+70247923186"}
0005433008996	00A85A	8792 681637	LARISA BORISOVA	{"email": "borisovalarisa24121978@postgrespro.ru", "phone": "+70095122839"}
0005433008997	7A106C	8441 450010	ELENA IVANOVA	{"email": "ivanova-elena-1974@postgrespro.ru", "phone": "+70467162114"}
0005433008998	B976F6	3948 292487	ANATOLIY PETROV	{"email": "petrov.a_061967@postgrespro.ru", "phone": "+70414820063"}
0005433008999	74AED7	5013 889391	NATALYA KOZLOVA	{"email": "kozlovan_1975@postgrespro.ru", "phone": "+70042579514"}
0005433009000	74AED7	6503 699672	ANTONINA BOGDANOVA	{"email": "bogdanovaa1970@postgrespro.ru", "phone": "+70306365314"}
0005433009001	0994D5	2454 620057	STEPAN SCHERBAKOV	{"phone": "+70867631476"}
0005433009002	0994D5	1192 285530	ANNA NIKOLAEVA	{"phone": "+70646989718"}
0005433009003	C70EA7	9184 603113	VALENTINA NIKIFOROVA	{"phone": "+70596709550"}
0005433009004	C70EA7	2186 294247	SERGEY BELOV	{"phone": "+70047035329"}
0005433009005	58062B	2706 649365	ANDREY SERGEEV	{"phone": "+70532050649"}
0005433009006	4419B9	9027 661095	VLADIMIR GRIGOREV	{"phone": "+70743817032"}
0005433009007	5CFFE4	6790 375560	OLGA VOROBEVA	{"phone": "+70050593795"}
0005433009008	5CFFE4	2707 441466	PAVEL FEDOROV	{"phone": "+70955626101"}
0005433009009	12397E	5503 332655	ALEKSANDR PETROV	{"email": "petrov-a_051983@postgrespro.ru", "phone": "+70348734614"}
0005433009010	12397E	6278 553490	SERGEY FILIPPOV	{"email": "sergey_filippov.29111971@postgrespro.ru", "phone": "+70935534439"}
0005433009011	C90AFF	0197 623297	ALEKSANDR KUZMIN	{"phone": "+70405319559"}
0005433009012	1D2C9A	7275 316526	VERA POTAPOVA	{"phone": "+70479139523"}
0005433009013	02AC95	6263 725130	SVETLANA SEMENOVA	{"email": "ssemenova-101967@postgrespro.ru", "phone": "+70778816413"}
0005433009014	F98C64	9294 938273	VERA SMIRNOVA	{"phone": "+70920382665"}
0005433009015	A4584A	9790 244898	NATALYA FROLOVA	{"phone": "+70968321914"}
0005433009016	A4584A	5669 253739	ANASTASIYA SMIRNOVA	{"phone": "+70655971948"}
0005433009017	37487B	8737 135377	SVETLANA EGOROVA	{"phone": "+70206251638"}
0005433009018	7DAC30	7775 686839	MIKHAIL KUZNECOV	{"email": "mkuznecov-04101978@postgrespro.ru", "phone": "+70704262084"}
0005433009019	496C5B	1543 245347	ADELINA NOVIKOVA	{"email": "adelina.novikova101968@postgrespro.ru", "phone": "+70793776885"}
0005433009020	40EB97	6353 625302	ALEKSEY KUZNECOV	{"phone": "+70954862751"}
0005433009021	40EB97	7770 478766	TATYANA ANDREEVA	{"email": "andreeva_tatyana091968@postgrespro.ru", "phone": "+70854521110"}
0005433009022	40EB97	4338 086129	ANNA LAZAREVA	{"phone": "+70552923961"}
0005433009023	FFD123	1003 751671	VASILIY BONDARENKO	{"email": "v_bondarenko_1985@postgrespro.ru", "phone": "+70987679729"}
0005433009024	F09527	7608 035571	MAKSIM GRIGOREV	{"email": "grigorevmaksim_121970@postgrespro.ru", "phone": "+70848484520"}
0005433009025	BA7D0F	5843 090906	ILYA PAVLOV	{"email": "ilya.pavlov_021986@postgrespro.ru", "phone": "+70991849579"}
0005433009026	13D6A9	9398 673397	TATYANA PETROVA	{"phone": "+70267235048"}
0005433009027	380FC2	8978 189083	DENIS MOROZOV	{"phone": "+70371303016"}
0005433009028	9E6459	6334 358611	SERGEY CHERNOV	{"email": "chernov-s071972@postgrespro.ru", "phone": "+70302967184"}
0005433009029	1C408A	4802 883452	VIKTORIYA ZAYCEVA	{"email": "v_zayceva_10011962@postgrespro.ru", "phone": "+70693396428"}
0005433009030	1C408A	3959 079462	SERGEY MOROZOV	{"email": "sergey-morozov_27111964@postgrespro.ru", "phone": "+70308517564"}
0005433009031	1C408A	9458 492565	VYACHESLAV SCHERBAKOV	{"phone": "+70037864282"}
0005433009032	F65C12	5163 700114	ARTEM KUZMIN	{"phone": "+70991882539"}
0005433009033	C5FB85	6261 533839	NIKITA ORLOV	{"email": "nikitaorlov-011968@postgrespro.ru", "phone": "+70697660350"}
0005433009034	13B1EA	0357 183298	SVETLANA KOZLOVA	{"email": "s.kozlova-1975@postgrespro.ru", "phone": "+70496316595"}
0005433009035	13B1EA	5122 856415	ANNA IVANOVA	{"phone": "+70041447603"}
0005433009036	6D0135	4685 215437	MARINA MEDVEDEVA	{"email": "medvedevamarina_1967@postgrespro.ru", "phone": "+70886835350"}
0005433009037	B79CE6	5195 935143	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr-1977@postgrespro.ru", "phone": "+70654041068"}
0005433009038	413D08	7970 620689	VALERIY ZHUKOV	{"email": "zhukov.valeriy.1971@postgrespro.ru", "phone": "+70152662186"}
0005433009039	413D08	2218 450116	NIKOLAY PAVLOV	{"email": "pavlovnikolay.1968@postgrespro.ru", "phone": "+70933246236"}
0005433009040	DAF6B2	1768 649141	ALEKSANDR POPOV	{"email": "popov.a031980@postgrespro.ru", "phone": "+70850990059"}
0005433009041	AFCD95	9166 904813	YURIY MIKHAYLOV	{"phone": "+70684032383"}
0005433009042	AFCD95	7951 498354	IVAN KONOVALOV	{"phone": "+70754896810"}
0005433009043	38DDB0	8289 855502	SERGEY IVANOV	{"email": "s.ivanov1969@postgrespro.ru", "phone": "+70255410956"}
0005433009044	A611F4	3557 162832	SERGEY KRASNOV	{"email": "sergey-krasnov-17121962@postgrespro.ru", "phone": "+70369974063"}
0005433009045	D68827	5419 599915	SERGEY KUDRYASHOV	{"phone": "+70771295704"}
0005433009046	094E08	9673 879578	SVETLANA NAUMOVA	{"phone": "+70572299742"}
0005433009047	37C20B	2650 097916	VALERIY VASILEV	{"email": "vasilev_valeriy_091981@postgrespro.ru", "phone": "+70672798579"}
0005433009048	6E5B4F	0978 865278	MARIYA PAVLOVA	{"phone": "+70692249259"}
0005433009049	C7CD80	5539 406058	NATALYA NESTEROVA	{"email": "nesterova.natalya.1968@postgrespro.ru", "phone": "+70555223781"}
0005433009050	B30D60	1759 220548	NATALYA CHERNOVA	{"phone": "+70360471877"}
0005433009051	07979C	7742 362646	MAKSIM SERGEEV	{"email": "m-sergeev.13041971@postgrespro.ru", "phone": "+70045246709"}
0005433009052	268507	7364 486381	IGOR EGOROV	{"email": "egorov.igor.1964@postgrespro.ru", "phone": "+70044781947"}
0005433009053	15BFD8	7540 726896	IRINA KARPOVA	{"phone": "+70957234902"}
0005433009054	15BFD8	3654 666553	VIKTOR KULIKOV	{"email": "kulikovv-1974@postgrespro.ru", "phone": "+70183112677"}
0005433009055	CC40D8	6980 844215	PRASKOVYA KUZNECOVA	{"email": "p_kuznecova.17031976@postgrespro.ru", "phone": "+70117593800"}
0005433009056	CC40D8	3388 583267	EKATERINA STEPANOVA	{"email": "stepanovae.081978@postgrespro.ru", "phone": "+70538551598"}
0005433009057	4EB75B	7266 125367	LYUBOV IVANOVA	{"email": "ivanova-lyubov_13121959@postgrespro.ru", "phone": "+70424664172"}
0005433009058	783C84	9369 972688	VLADIMIR ALEKSANDROV	{"phone": "+70632961705"}
0005433009059	783C84	7689 066975	TIMUR VASILEV	{"email": "timur_vasilev-1975@postgrespro.ru", "phone": "+70582381479"}
0005433009060	5FC9E6	0468 929215	RAISA FILIPPOVA	{"email": "filippova_raisa_28081971@postgrespro.ru", "phone": "+70967329628"}
0005433009061	E17FD5	0011 405507	YURIY SEMENOV	{"phone": "+70630679310"}
0005433009062	90D4F6	6395 738811	NIKOLAY NIKITIN	{"phone": "+70240063732"}
0005433009063	90D4F6	3352 734495	IVAN ABRAMOV	{"email": "abramovivan_1975@postgrespro.ru", "phone": "+70192192979"}
0005433009064	F3EFF2	4534 045590	SVETLANA MOISEEVA	{"email": "smoiseeva061962@postgrespro.ru", "phone": "+70033217340"}
0005433009065	8D7C68	1710 535300	SERGEY KUDRYASHOV	{"phone": "+70096538457"}
0005433009066	BADE0E	7689 944520	YURIY KULIKOV	{"email": "y-kulikov021968@postgrespro.ru", "phone": "+70897854695"}
0005433009067	C5360B	1136 596322	OLGA ZHUKOVA	{"email": "olga_zhukova-1976@postgrespro.ru", "phone": "+70595477022"}
0005433009068	C0EBC7	9332 509844	DMITRIY IVANOV	{"phone": "+70763729590"}
0005433009069	31CC3D	7768 716132	EKATERINA MATVEEVA	{"phone": "+70584963749"}
0005433009070	98E35B	6750 689853	PETR POPOV	{"email": "popov_petr.1969@postgrespro.ru", "phone": "+70519252745"}
0005433009071	FBDEE5	7517 483683	ANTON DENISOV	{"email": "adenisov.18011969@postgrespro.ru", "phone": "+70282933758"}
0005433009072	32CF89	6878 122404	YULIANA IVANOVA	{"phone": "+70966825018"}
0005433009073	32CF89	7682 407598	DARYA SOKOLOVA	{"phone": "+70962038937"}
0005433009074	F62EC8	0622 837725	SERGEY AFANASEV	{"phone": "+70041532542"}
0005433009075	1F60D8	0462 505026	MARIYA ILINA	{"email": "ilina_m-1977@postgrespro.ru", "phone": "+70538557263"}
0005433009076	1F60D8	3546 913134	MAKSIM ANTONOV	{"phone": "+70653029050"}
0005433009077	3226AE	7143 768670	ELENA ZOTOVA	{"email": "e_zotova-021975@postgrespro.ru", "phone": "+70324258747"}
0005433009078	FCA2AE	2923 129784	MIKHAIL VOLKOV	{"email": "mikhail_volkov_111967@postgrespro.ru", "phone": "+70247470234"}
0005433009079	B8C787	7166 688756	ALEKSANDR GORBUNOV	{"phone": "+70972672843"}
0005433009080	6380C6	0713 986109	KONSTANTIN PETROV	{"phone": "+70485281254"}
0005433009081	6380C6	8502 845690	OLGA KOZLOVA	{"email": "olga.kozlova-21031974@postgrespro.ru", "phone": "+70142380211"}
0005433009082	89EF95	5137 576650	DMITRIY TIMOFEEV	{"email": "d-timofeev-121988@postgrespro.ru", "phone": "+70045234328"}
0005433009083	89EF95	0745 290165	OKSANA KARPOVA	{"phone": "+70350918991"}
0005433009084	A87D5D	4983 933211	YURIY KULIKOV	{"email": "kulikov_yuriy_1962@postgrespro.ru", "phone": "+70038506904"}
0005433009085	A87D5D	3566 517488	TATYANA ISAEVA	{"email": "t.isaeva.30041983@postgrespro.ru", "phone": "+70404382141"}
0005433009086	A87D5D	7729 145822	ELENA POPOVA	{"email": "popova_elena-09021976@postgrespro.ru", "phone": "+70649206862"}
0005433009087	84DD38	2921 897553	ANNA PAVLOVA	{"email": "pavlova.a-1971@postgrespro.ru", "phone": "+70549107004"}
0005433009088	84DD38	6305 285977	VLADIMIR MOROZOV	{"email": "morozovvladimir1989@postgrespro.ru", "phone": "+70514416587"}
0005433009089	84DD38	1345 829207	DENIS AFANASEV	{"email": "d_afanasev-1983@postgrespro.ru", "phone": "+70537973160"}
0005433009090	19D342	5613 706485	ELENA POLYAKOVA	{"phone": "+70074249704"}
0005433009091	19D342	2249 750527	ANASTASIYA TARASOVA	{"phone": "+70064018313"}
0005433009092	58BF7F	9179 328374	MARIYA POLYAKOVA	{"email": "polyakova_m-021970@postgrespro.ru", "phone": "+70151460969"}
0005433009093	58BF7F	8023 952818	RAMIS NIKITIN	{"phone": "+70691645305"}
0005433009094	9CFD28	0583 093970	EVGENIY SEMENOV	{"phone": "+70639870182"}
0005433009095	260A37	2223 060229	STANISLAV ROMANOV	{"email": "s_romanov1968@postgrespro.ru", "phone": "+70725558754"}
0005433009096	3D3ABB	4406 253350	ALEKSEY ANTONOV	{"email": "alekseyantonov.081973@postgrespro.ru", "phone": "+70270166915"}
0005433009097	5F1DFB	0937 025194	OLGA BELOVA	{"email": "belova_o_1987@postgrespro.ru", "phone": "+70805543550"}
0005433009098	5F1DFB	3896 907906	LYUBOV KISELEVA	{"email": "kiseleva_l011969@postgrespro.ru", "phone": "+70466273674"}
0005433009099	D17C4F	8164 596454	YULIYA KOZLOVA	{"email": "yuliya-kozlova-04061975@postgrespro.ru", "phone": "+70984653271"}
0005433009100	D17C4F	6266 247321	VLADIMIR VOLKOV	{"phone": "+70361443501"}
0005433009101	ED68E4	7664 601611	KIRILL KOZLOV	{"phone": "+70179685008"}
0005433009102	ED68E4	9055 461538	VALERIY MATVEEV	{"email": "valeriy_matveev.081965@postgrespro.ru", "phone": "+70749995834"}
0005433009103	ED68E4	6635 406560	VLADIMIR STEPANOV	{"email": "stepanov.vladimir031984@postgrespro.ru", "phone": "+70835469912"}
0005433009104	22914F	1394 851231	VLADIMIR SHEVCHENKO	{"email": "v.shevchenko12111974@postgrespro.ru", "phone": "+70945450784"}
0005433009105	083BBD	3168 008586	LIDIYA VASILEVA	{"phone": "+70420036714"}
0005433009106	C6EA33	9022 985196	PAVEL KUZNECOV	{"email": "pkuznecov_15081974@postgrespro.ru", "phone": "+70444304564"}
0005433009107	F3EC68	8466 501075	SVETLANA FEDOROVA	{"email": "fedorovasvetlana-17101977@postgrespro.ru", "phone": "+70474615790"}
0005433009108	55F4AF	2847 987343	INNA PAVLOVA	{"email": "i_pavlova-011972@postgrespro.ru", "phone": "+70085255567"}
0005433009109	55F4AF	6294 184742	DMITRIY ISAEV	{"email": "isaevdmitriy-081983@postgrespro.ru", "phone": "+70331135176"}
0005433009110	6341CC	2520 648437	DMITRIY ANDREEV	{"email": "andreev-dmitriy.111976@postgrespro.ru", "phone": "+70366946855"}
0005433009111	6341CC	3570 549820	VLADIMIR VOROBEV	{"phone": "+70921002654"}
0005433009112	50533E	0102 300709	VLADIMIR STEPANOV	{"email": "vladimir-stepanov061979@postgrespro.ru", "phone": "+70605303508"}
0005433009113	50533E	1060 327191	ANASTASIYA NESTEROVA	{"email": "nesterova_a_12121974@postgrespro.ru", "phone": "+70226638874"}
0005433009114	50533E	2565 393563	VALERIYA SOKOLOVA	{"email": "v-sokolova_1962@postgrespro.ru", "phone": "+70418979187"}
0005433009115	47D95B	7991 430236	MARINA LUKYANOVA	{"phone": "+70813591085"}
0005433009116	92F919	7630 473520	ILYA MATVEEV	{"email": "i-matveev.03121976@postgrespro.ru", "phone": "+70367842154"}
0005433009117	92F919	9247 831871	EKATERINA MAKAROVA	{"email": "e.makarova.14111971@postgrespro.ru", "phone": "+70341690731"}
0005433009118	FCA6F0	2683 252731	VERONIKA DAVYDOVA	{"email": "veronika.davydova-1974@postgrespro.ru", "phone": "+70484407192"}
0005433009119	143D50	3264 377557	PETR SOKOLOV	{"phone": "+70870797791"}
0005433009120	0D60C1	0525 113216	ANNA KOZLOVA	{"email": "annakozlova16101973@postgrespro.ru", "phone": "+70869799864"}
0005433009121	0D60C1	9641 460690	ELENA AKIMOVA	{"email": "e_akimova04011980@postgrespro.ru", "phone": "+70384175350"}
0005433009122	0D60C1	5668 760484	KONSTANTIN MIKHAYLOV	{"email": "mikhaylov.konstantin08111964@postgrespro.ru", "phone": "+70700083229"}
0005433009123	0D60C1	2636 617939	VENIAMIN VASILEV	{"email": "veniamin_vasilev_081975@postgrespro.ru", "phone": "+70654137862"}
0005433009124	C05FA8	4987 782800	ROMAN ANDREEV	{"email": "r-andreev-011962@postgrespro.ru", "phone": "+70667465887"}
0005433009125	C3FCC5	4787 759454	ALINA PAVLOVA	{"phone": "+70883944813"}
0005433009126	C3FCC5	3793 288297	TATYANA SAVELEVA	{"email": "t_saveleva_111973@postgrespro.ru", "phone": "+70635765347"}
0005433009127	C3FCC5	9501 273206	ARINA MOROZOVA	{"phone": "+70803568246"}
0005433009128	BF9AEA	1600 414562	PAVEL POPOV	{"phone": "+70287281058"}
0005433009129	BF9AEA	2877 547435	ELENA FOMINA	{"phone": "+70040061242"}
0005433009130	83DB57	6868 411880	VALERIY ILIN	{"phone": "+70461858539"}
0005433009131	36851E	2406 694978	STEPAN SIDOROV	{"phone": "+70533409916"}
0005433009132	DF7611	8327 721225	POLINA VLASOVA	{"phone": "+70094314754"}
0005433009133	7EB1DC	3133 480366	IVAN POPOV	{"phone": "+70021076353"}
0005433009134	5965FF	3274 435407	ALFIYA FEDOROVA	{"phone": "+70672894899"}
0005433009135	02D74A	8160 600789	GALINA VOROBEVA	{"email": "galina.vorobeva10021969@postgrespro.ru", "phone": "+70767230491"}
0005433009136	309833	7024 840954	YANA SOKOLOVA	{"email": "ysokolova.08021980@postgrespro.ru", "phone": "+70506351070"}
0005433009137	751903	5412 397734	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva20101976@postgrespro.ru", "phone": "+70584660657"}
0005433009138	B10F3F	4336 073044	VIKTOR MIKHAYLOV	{"phone": "+70382001509"}
0005433009139	CC2DFF	9598 209653	ELENA ALEKSANDROVA	{"email": "elena_aleksandrova1983@postgrespro.ru", "phone": "+70391077426"}
0005433009140	CC2DFF	2123 015308	VIKTOR BONDARENKO	{"phone": "+70264140370"}
0005433009141	82A7B2	1037 785717	IRINA LAZAREVA	{"email": "lazareva.i.041967@postgrespro.ru", "phone": "+70528444092"}
0005433009142	855E43	2616 037073	ALEKSANDR ANDREEV	{"phone": "+70915390811"}
0005433009143	855E43	2930 697600	ANDREY SCHERBAKOV	{"phone": "+70226994269"}
0005433009144	75645B	7527 872105	MARIYA EFREMOVA	{"phone": "+70428012945"}
0005433009145	D213A1	5405 692456	ANDREY KUDRYASHOV	{"phone": "+70435037141"}
0005433009146	D213A1	6550 137717	PETR KUZNECOV	{"phone": "+70843766916"}
0005433009147	A4BE66	4910 717158	VERA NOVIKOVA	{"phone": "+70010558689"}
0005433009148	2EE608	5305 613014	ANDREY VASILEV	{"phone": "+70071016068"}
0005433009149	5E582E	3855 050080	SERGEY GAVRILOV	{"phone": "+70975095069"}
0005433009150	B22546	7048 813344	GENNADIY STEPANOV	{"phone": "+70322381273"}
0005433009151	B22546	0355 731368	DARYA KUZNECOVA	{"email": "darya-kuznecova_071976@postgrespro.ru", "phone": "+70203256872"}
0005433009152	C45153	4489 208386	ALEKSANDR RODIONOV	{"email": "a-rodionov-031971@postgrespro.ru", "phone": "+70509848201"}
0005433009153	C45153	0669 686529	VLADIMIR ANDREEV	{"phone": "+70659647829"}
0005433009154	C45153	9127 397929	NATALYA KUZNECOVA	{"email": "kuznecovanatalya.091969@postgrespro.ru", "phone": "+70298048824"}
0005433009155	0D5358	7169 976675	ANATOLIY KUZNECOV	{"phone": "+70231099565"}
0005433009156	0D5358	3967 853914	YULIYA YUDINA	{"phone": "+70617041626"}
0005433009157	369F1C	3936 148145	OKSANA DENISOVA	{"phone": "+70621443112"}
0005433009158	2605E6	7001 471264	DANILA MIKHAYLOV	{"phone": "+70753216305"}
0005433009159	2605E6	2350 787821	ELENA BELOVA	{"phone": "+70395204856"}
0005433009160	2605E6	5129 463468	ARTUR MIRONOV	{"email": "amironov_1975@postgrespro.ru", "phone": "+70066997209"}
0005433009161	2CD45F	9427 849960	MARINA KOZLOVA	{"phone": "+70507962845"}
0005433009162	2CD45F	1507 122759	SVETLANA ERMAKOVA	{"phone": "+70594586792"}
0005433009163	95E140	4580 121183	VIOLETTA SERGEEVA	{"email": "v.sergeeva-16051963@postgrespro.ru", "phone": "+70077951735"}
0005433009164	95E140	1550 817818	IVAN POPOV	{"phone": "+70598838448"}
0005433009165	7D2984	7327 808060	MARINA DENISOVA	{"email": "m.denisova.04101977@postgrespro.ru", "phone": "+70578540622"}
0005433009166	7D2984	8130 741319	ALEKSEY NIKOLAEV	{"phone": "+70851862593"}
0005433009167	7D2984	5691 124007	ELENA TIMOFEEVA	{"email": "e_timofeeva.1970@postgrespro.ru", "phone": "+70070659249"}
0005433009168	031BAD	2710 163241	OLGA EFIMOVA	{"phone": "+70408636767"}
0005433009169	4A2A42	4422 243672	SERGEY SEMENOV	{"email": "ssemenov_1977@postgrespro.ru", "phone": "+70098455240"}
0005433009170	4A2A42	1271 073309	DENIS KRASNOV	{"email": "krasnov-denis.061967@postgrespro.ru", "phone": "+70996540099"}
0005433009171	15EE92	3289 470975	VLADIMIR BARANOV	{"email": "baranov-vladimir091974@postgrespro.ru", "phone": "+70551999716"}
0005433009172	6AB0BD	8969 226920	DANILA ZAKHAROV	{"phone": "+70172116763"}
0005433009173	F36016	6743 824723	DMITRIY SMIRNOV	{"phone": "+70118033835"}
0005433009174	F36016	3616 086023	LEONID VASILEV	{"email": "leonidvasilev1961@postgrespro.ru", "phone": "+70462302590"}
0005433009175	059FD5	9825 140576	OLGA BELOVA	{"phone": "+70360844833"}
0005433009176	059FD5	4602 815922	MARINA FADEEVA	{"phone": "+70050975026"}
0005433009177	ADA0B4	2373 832997	IRINA KISELEVA	{"email": "kiseleva_irina-30101969@postgrespro.ru", "phone": "+70712913748"}
0005433009178	ADA0B4	1140 890733	DENIS VASILEV	{"email": "vasilevd_081967@postgrespro.ru", "phone": "+70399229842"}
0005433009179	6863A5	9274 655091	TATYANA FEDOROVA	{"email": "tatyana.fedorova1972@postgrespro.ru", "phone": "+70416711417"}
0005433009180	6863A5	5565 878543	DMITRIY FROLOV	{"email": "d_frolov_23081966@postgrespro.ru", "phone": "+70760095423"}
0005433009181	6863A5	6193 569833	LYUBOV ALEKSANDROVA	{"email": "aleksandrova_lyubov_1967@postgrespro.ru", "phone": "+70728561924"}
0005433009182	C887C3	0983 390588	IRINA MEDVEDEVA	{"phone": "+70315674359"}
0005433009183	F36963	1564 746021	TATYANA NIKOLAEVA	{"phone": "+70676753292"}
0005433009184	FE93DA	8059 068241	NAIL SOLOVEV	{"email": "n-solovev111979@postgrespro.ru", "phone": "+70027544650"}
0005433009185	34782B	7434 394214	ALEKSANDR FEDOROV	{"phone": "+70372230102"}
0005433009186	34782B	2873 803714	ALEKSEY PAVLOV	{"email": "pavlovaleksey23021965@postgrespro.ru", "phone": "+70921401528"}
0005433009187	692205	7578 974377	MAKSIM ZAYCEV	{"phone": "+70011978266"}
0005433009188	692205	8108 479862	LILIYA MOROZOVA	{"phone": "+70586867629"}
0005433009189	0B82AB	0305 659011	ALEKSANDR GERASIMOV	{"phone": "+70722428389"}
0005433009190	0B82AB	9818 278581	EVGENIY KOZLOV	{"email": "evgeniykozlov_14061972@postgrespro.ru", "phone": "+70525603806"}
0005433009191	C6764F	9651 421921	NADEZHDA MELNIKOVA	{"phone": "+70870615318"}
0005433009192	F1ACA8	6714 028238	ANDREY ZHURAVLEV	{"phone": "+70245884343"}
0005433009193	A1496A	6367 822370	NATALYA LUKYANOVA	{"phone": "+70046493811"}
0005433009194	DB0245	5823 746481	PAVEL KOROLEV	{"email": "korolev_p_021968@postgrespro.ru", "phone": "+70772523640"}
0005433009195	6FAFFD	8209 645063	ANASTASIYA NIKOLAEVA	{"email": "a_nikolaeva-1971@postgrespro.ru", "phone": "+70256487523"}
0005433009196	6AC07F	8579 541752	DANIL NIKITIN	{"phone": "+70958217983"}
0005433009197	38F378	5936 239810	ALEKSANDR PAVLOV	{"phone": "+70096453581"}
0005433009198	689E54	8315 191049	VITALIY SHEVCHENKO	{"email": "vitaliy_shevchenko_1979@postgrespro.ru", "phone": "+70121850361"}
0005433009199	746458	9160 502059	LYUDMILA MIKHAYLOVA	{"email": "mikhaylovalyudmila-011978@postgrespro.ru", "phone": "+70978423856"}
0005433009200	438BAD	1358 304417	NATALIYA KUZNECOVA	{"email": "kuznecovanataliya_1971@postgrespro.ru", "phone": "+70472873162"}
0005433009201	FE5CFF	1277 451182	ALEKSANDR GORBUNOV	{"phone": "+70539603892"}
0005433009202	FE5CFF	2243 220437	DARYA ANTONOVA	{"email": "daryaantonova_1973@postgrespro.ru", "phone": "+70887073611"}
0005433009203	EB7BAF	9673 327213	NIKOLAY GAVRILOV	{"email": "gavrilov_n051966@postgrespro.ru", "phone": "+70432311676"}
0005433009204	B78B15	5040 239286	ANTONINA NIKOLAEVA	{"email": "nikolaeva_antonina.25061984@postgrespro.ru", "phone": "+70083904516"}
0005433009205	88A27D	7722 150441	KONSTANTIN POPOV	{"email": "popov-k_1972@postgrespro.ru", "phone": "+70963951000"}
0005433009206	88A27D	1741 400443	VALENTINA KOZLOVA	{"email": "kozlova_valentina.1971@postgrespro.ru", "phone": "+70898331796"}
0005433009207	24F2E1	3196 977612	MARINA ORLOVA	{"email": "m-orlova_22011974@postgrespro.ru", "phone": "+70401224095"}
0005433009208	24F2E1	4547 185029	NAZAR SOROKIN	{"phone": "+70379024351"}
0005433009209	FF7699	6297 099647	KLAVDIYA GERASIMOVA	{"email": "klavdiya-gerasimova-23021976@postgrespro.ru", "phone": "+70804401138"}
0005433009210	AB2F5F	6733 821956	ALEKSEY SMIRNOV	{"phone": "+70311974697"}
0005433009211	736779	3179 215783	EVGENIY SAVELEV	{"phone": "+70921115134"}
0005433009212	3807C8	5408 335388	DENIS BONDARENKO	{"email": "d-bondarenko.081968@postgrespro.ru", "phone": "+70510019994"}
0005433009213	81BA0D	1020 929345	VLADIMIR ZAKHAROV	{"email": "zakharovv101975@postgrespro.ru", "phone": "+70163675673"}
0005433009214	81BA0D	2649 456834	VERA ALEKSANDROVA	{"phone": "+70864204405"}
0005433009215	DF3530	1005 483005	YURIY SOKOLOV	{"email": "ysokolov.121979@postgrespro.ru", "phone": "+70414816631"}
0005433009216	94B56B	4604 383218	SERGEY KOROLEV	{"email": "korolev_sergey-041970@postgrespro.ru", "phone": "+70123350181"}
0005433009217	FF354F	6294 519020	SERGEY MEDVEDEV	{"email": "sergey_medvedev.1980@postgrespro.ru", "phone": "+70412463576"}
0005433009218	1AEFBC	2853 589618	NIKOLAY KUZNECOV	{"phone": "+70127730932"}
0005433009219	7ACCB1	2364 473959	KONSTANTIN SERGEEV	{"email": "konstantin-sergeev.031962@postgrespro.ru", "phone": "+70544279747"}
0005433009220	7ACCB1	4606 904157	LYUDMILA KISELEVA	{"phone": "+70936473055"}
0005433009221	03F048	0934 032550	SVETLANA NOVIKOVA	{"email": "s.novikova.09031963@postgrespro.ru", "phone": "+70221832935"}
0005433009222	03F048	6603 617532	EVGENIY GORBUNOV	{"email": "evgeniygorbunov-021972@postgrespro.ru", "phone": "+70357707387"}
0005433009223	6326A2	5957 111731	VALENTIN SERGEEV	{"email": "valentinsergeev.07041973@postgrespro.ru", "phone": "+70782047708"}
0005433009224	ECC296	1336 508251	MARINA YAKOVLEVA	{"phone": "+70199848825"}
0005433009225	ECC296	7393 634662	IVAN FROLOV	{"email": "frolov_i_081970@postgrespro.ru", "phone": "+70070122864"}
0005433009226	ECC296	2755 903821	VLADIMIR BARANOV	{"email": "baranov-vladimir-1969@postgrespro.ru", "phone": "+70913014743"}
0005433009227	E57890	6991 649835	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey081972@postgrespro.ru", "phone": "+70856269052"}
0005433009228	E57890	0406 357072	EVGENIY ANDREEV	{"phone": "+70084517052"}
0005433009229	E57890	3906 547979	MARIYA KULIKOVA	{"email": "mariya.kulikova101982@postgrespro.ru", "phone": "+70708550622"}
0005433009230	B2E7CA	3690 938426	IGOR ANTONOV	{"phone": "+70942559444"}
0005433009231	B2E7CA	5178 871998	ALENA KONOVALOVA	{"phone": "+70596246539"}
0005433009232	38CFB5	9154 580567	NATALYA ANDREEVA	{"phone": "+70521873959"}
0005433009233	9B57C7	8917 089732	SVETLANA KOZLOVA	{"email": "kozlovasvetlana23031969@postgrespro.ru", "phone": "+70064901865"}
0005433009234	33165C	4302 966132	NIKITA POPOV	{"phone": "+70779674524"}
0005433009235	33165C	9721 491400	OKSANA EFIMOVA	{"email": "efimovao17081971@postgrespro.ru", "phone": "+70407312700"}
0005433009236	3F8C3E	3031 016687	VLADIMIR ZAYCEV	{"email": "zaycevvladimir-1968@postgrespro.ru", "phone": "+70046652427"}
0005433009237	63F763	8753 131382	GALINA LUKYANOVA	{"phone": "+70150404071"}
0005433009238	D87C13	3858 275834	KLAVDIYA EGOROVA	{"phone": "+70431125779"}
0005433009239	D87C13	8460 023334	GALINA DAVYDOVA	{"email": "gdavydova-1967@postgrespro.ru", "phone": "+70247427863"}
0005433009240	DF19F1	1833 343781	ANNA SMIRNOVA	{"phone": "+70233591212"}
0005433009241	6412F0	3971 351265	VLADIMIR SEMENOV	{"phone": "+70861260578"}
0005433009242	6412F0	8393 754217	EVGENIYA KUZNECOVA	{"phone": "+70498779594"}
0005433009243	6412F0	0429 801248	ALEKSEY KUZMIN	{"phone": "+70619445691"}
0005433009244	1E6741	1708 665820	MIKHAIL MOISEEV	{"email": "mmoiseev09051985@postgrespro.ru", "phone": "+70263116365"}
0005433009245	E66DE0	3231 347386	NIKOLAY MATVEEV	{"phone": "+70482536949"}
0005433009246	229F9D	2425 642375	PAVEL KARPOV	{"phone": "+70975923652"}
0005433009413	C15B01	9979 976930	VASILIY ZAYCEV	{"phone": "+70823930670"}
0005433009247	986233	3169 567922	SVETLANA MAKSIMOVA	{"email": "svetlanamaksimova_071967@postgrespro.ru", "phone": "+70921319166"}
0005433009248	9CD05B	9031 608222	ALEKSEY PETROV	{"phone": "+70905256118"}
0005433009249	473796	7082 118924	IRINA IVANOVA	{"email": "ivanova-i-011975@postgrespro.ru", "phone": "+70677694487"}
0005433009250	B3A4A6	0784 437514	LYUBOV OSIPOVA	{"email": "osipova-l-111963@postgrespro.ru", "phone": "+70632663185"}
0005433009251	B3A4A6	1205 210472	ZINAIDA NIKITINA	{"phone": "+70950054059"}
0005433009252	7BDB4F	7311 456392	ALEKSEY KOROLEV	{"phone": "+70352178905"}
0005433009253	34C93D	3613 547232	PAVEL ZAYCEV	{"phone": "+70089431580"}
0005433009254	1D3A30	1748 204599	OLESYA BOGDANOVA	{"email": "bogdanova-olesya_101963@postgrespro.ru", "phone": "+70080622303"}
0005433009255	9B6B85	1565 935328	MIKHAIL KARPOV	{"phone": "+70086578263"}
0005433009256	5B19A9	5753 113800	DAMIR SERGEEV	{"phone": "+70718943903"}
0005433009257	5B19A9	6299 122408	TATYANA PETROVA	{"phone": "+70502494802"}
0005433009258	62F476	0294 803497	VLADIMIR TIKHONOV	{"phone": "+70776819129"}
0005433009259	DF8088	6947 588872	TATYANA KUZNECOVA	{"email": "tkuznecova-101968@postgrespro.ru", "phone": "+70399722826"}
0005433009260	E90F8F	6861 801886	ELENA MIRONOVA	{"phone": "+70950014399"}
0005433009261	E90F8F	1025 709609	TATYANA KUDRYASHOVA	{"phone": "+70752675753"}
0005433009262	865755	8812 190626	VALERIYA TITOVA	{"phone": "+70234953965"}
0005433009263	BD1B89	1514 442668	VLADIMIR TIKHONOV	{"email": "tikhonovvladimir_031970@postgrespro.ru", "phone": "+70694344488"}
0005433009264	00DE63	9914 034236	NATALYA SOROKINA	{"email": "sorokina.natalya041960@postgrespro.ru", "phone": "+70788451502"}
0005433009265	5B7E36	0712 796289	NIKITA FROLOV	{"email": "frolovnikita31071967@postgrespro.ru", "phone": "+70323566394"}
0005433009266	DE7876	6737 024181	DMITRIY BORISOV	{"email": "borisov-d.1968@postgrespro.ru", "phone": "+70755713738"}
0005433009267	DD05A7	7279 994817	SERGEY KUZNECOV	{"phone": "+70908941862"}
0005433009268	DD05A7	4294 622854	LYUDMILA NIKOLAEVA	{"phone": "+70952847782"}
0005433009269	DD05A7	4847 176034	EVGENIY GORBUNOV	{"phone": "+70578913841"}
0005433009270	E77A46	8916 542335	RAISA ZAKHAROVA	{"email": "rzakharova_1972@postgrespro.ru", "phone": "+70340375739"}
0005433009271	111F05	2196 570298	LYUDMILA MARTYNOVA	{"phone": "+70706239516"}
0005433009272	C13A37	4262 848523	TATYANA GAVRILOVA	{"phone": "+70503026574"}
0005433009273	C13A37	5604 460544	PETR ANDREEV	{"email": "p_andreev.1977@postgrespro.ru", "phone": "+70210970424"}
0005433009274	480F5D	1823 411432	NINA NIKIFOROVA	{"email": "nnikiforova1975@postgrespro.ru", "phone": "+70349718414"}
0005433009275	480F5D	4394 243225	IGOR TIKHONOV	{"phone": "+70685335565"}
0005433009276	76D074	0519 862813	ANNA SOROKINA	{"email": "anna-sorokina-091967@postgrespro.ru", "phone": "+70827110959"}
0005433009277	D3B4F1	7831 883698	IRINA ANISIMOVA	{"email": "anisimovai.11061971@postgrespro.ru", "phone": "+70350046603"}
0005433009278	89B103	6585 165543	IRINA KOZLOVA	{"email": "kozlova.irina.27071978@postgrespro.ru", "phone": "+70107328423"}
0005433009279	B05224	3897 053847	GULNARA VOROBEVA	{"phone": "+70273913436"}
0005433009280	B05224	6718 408400	MARIYA BORISOVA	{"phone": "+70016669795"}
0005433009281	601AA7	3164 584553	KLAVDIYA NIKITINA	{"email": "nikitina_k.11101967@postgrespro.ru", "phone": "+70838297225"}
0005433009282	601AA7	9130 452186	MARIYA EGOROVA	{"phone": "+70294112058"}
0005433009283	5B1CBD	8778 068727	EDGAR NIKOLAEV	{"phone": "+70380831048"}
0005433009284	FBF2FD	2315 729722	VLADIMIR VOLKOV	{"email": "volkovv_1980@postgrespro.ru", "phone": "+70095892616"}
0005433009285	FBF2FD	4096 404545	TATYANA TIKHONOVA	{"phone": "+70658447201"}
0005433009286	7CCAA4	7768 410375	ANASTASIYA IVANOVA	{"phone": "+70689182309"}
0005433009287	C6BED8	2619 252118	VIKTOR SOKOLOV	{"phone": "+70495521118"}
0005433009288	CD4FA1	3244 960505	ELENA EGOROVA	{"email": "egorova_e_1967@postgrespro.ru", "phone": "+70671065290"}
0005433009289	3BD4D6	9143 732826	POLINA KAZAKOVA	{"email": "kazakova.p.061959@postgrespro.ru", "phone": "+70238003087"}
0005433009290	3BD4D6	5325 587667	NADEZHDA GORBUNOVA	{"phone": "+70261207334"}
0005433009291	2FFCC8	6904 067742	VLADIMIR ALEKSEEV	{"email": "v-alekseev03121965@postgrespro.ru", "phone": "+70658520406"}
0005433009292	73FFC5	9465 951494	SERGEY SOROKIN	{"email": "sergey-sorokin-1972@postgrespro.ru", "phone": "+70522568151"}
0005433009293	C723F0	7909 694819	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a-13011971@postgrespro.ru", "phone": "+70000664100"}
0005433009294	C723F0	0144 117777	NATALYA ARKHIPOVA	{"phone": "+70597579014"}
0005433009295	082722	0728 092702	ALEKSANDR BORISOV	{"email": "aleksandrborisov-1969@postgrespro.ru", "phone": "+70153854255"}
0005433009296	94F9B3	4919 319216	OKSANA KUZNECOVA	{"email": "o.kuznecova1958@postgrespro.ru", "phone": "+70975500217"}
0005433009297	33D9D2	3768 991548	ELENA IVANOVA	{"phone": "+70910719182"}
0005433009298	33D9D2	7937 273604	OLGA KULIKOVA	{"phone": "+70811214479"}
0005433009299	33D9D2	4880 394764	ARTEM SERGEEV	{"phone": "+70277949403"}
0005433009300	6806FE	3292 800329	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova.05101984@postgrespro.ru", "phone": "+70427017645"}
0005433009301	61B590	8786 817821	SVYATOSLAV FROLOV	{"phone": "+70907701171"}
0005433009302	61B590	8272 601374	ALEKSANDR SOKOLOV	{"phone": "+70164606325"}
0005433009303	4C05B7	3921 462807	IVAN ZAKHAROV	{"email": "ivan_zakharov-04051970@postgrespro.ru", "phone": "+70639077966"}
0005433009304	258B42	1649 298431	LIDIYA OVCHINNIKOVA	{"email": "ovchinnikova.lidiya-1980@postgrespro.ru", "phone": "+70497582589"}
0005433009305	7F0E42	8865 311308	LYUBOV IVANOVA	{"phone": "+70919845237"}
0005433009306	1EF9B5	7255 334389	KRISTINA OSIPOVA	{"email": "osipova.k-111973@postgrespro.ru", "phone": "+70855695325"}
0005433009307	BF3FB8	6602 757076	YURIY ORLOV	{"email": "orlovy_1963@postgrespro.ru", "phone": "+70668894734"}
0005433009308	4B1256	5714 306580	NATALYA TROFIMOVA	{"phone": "+70586567729"}
0005433009309	4B1256	6810 538848	DANILA SCHERBAKOV	{"phone": "+70944181568"}
0005433009310	AC2EFE	6352 251785	MIKHAIL IVANOV	{"email": "m_ivanov-111980@postgrespro.ru", "phone": "+70030757937"}
0005433009311	AC2EFE	7234 191144	ALSU NOVIKOVA	{"phone": "+70374865695"}
0005433009312	A60E2C	8768 694490	YURIY SMIRNOV	{"email": "yuriysmirnov-01021975@postgrespro.ru", "phone": "+70892468168"}
0005433009313	DC0C08	1389 002691	SERGEY ZAKHAROV	{"phone": "+70622901442"}
0005433009314	10A346	7022 376649	YURIY SERGEEV	{"phone": "+70382713289"}
0005433009315	79522D	6953 431383	DENIS IVANOV	{"email": "d_ivanov-031976@postgrespro.ru", "phone": "+70670898922"}
0005433009316	77EE09	5700 047861	DMITRIY SAVELEV	{"email": "savelev.d.08071970@postgrespro.ru", "phone": "+70233783636"}
0005433009317	77EE09	9653 120530	ROZA BELOVA	{"email": "roza-belova.10101968@postgrespro.ru", "phone": "+70557493501"}
0005433009318	A926CF	5629 114731	VALERIY SIDOROV	{"email": "sidorovvaleriy1971@postgrespro.ru", "phone": "+70259513637"}
0005433009319	ADE273	2913 119048	VIKTOR ISAEV	{"phone": "+70694811058"}
0005433009320	401133	4533 631767	ELENA BARANOVA	{"email": "baranova_e24081974@postgrespro.ru", "phone": "+70684091074"}
0005433009321	28BB97	4318 569076	NIKOLAY POPOV	{"email": "popovnikolay_011970@postgrespro.ru", "phone": "+70396161910"}
0005433009322	536F27	0675 902547	OLGA SERGEEVA	{"phone": "+70445236843"}
0005433009323	EE9EA3	4550 135609	ANNA KOZLOVA	{"email": "kozlova-anna.1973@postgrespro.ru", "phone": "+70213071472"}
0005433009324	EE9EA3	2022 054865	MATVEY KAZAKOV	{"phone": "+70393122522"}
0005433009325	D1EEB1	1708 419808	SERGEY KOROLEV	{"email": "korolev-sergey-27111983@postgrespro.ru", "phone": "+70137561327"}
0005433009326	D1EEB1	7603 039826	SERGEY MOROZOV	{"email": "sergey-morozov17051970@postgrespro.ru", "phone": "+70684546609"}
0005433009327	02DE6C	3177 691741	DMITRIY MIRONOV	{"phone": "+70058816727"}
0005433009328	72567F	6317 015543	GENNADIY PAVLOV	{"email": "pavlovg.20111972@postgrespro.ru", "phone": "+70310780097"}
0005433009329	72567F	0622 813041	ALISHER MAKAROV	{"email": "a_makarov021964@postgrespro.ru", "phone": "+70188579358"}
0005433009330	72567F	7603 464708	LYUDMILA NIKITINA	{"email": "lyudmila-nikitina_28021978@postgrespro.ru", "phone": "+70838813554"}
0005433009331	6FE669	2253 266218	VIKTORIYA KISELEVA	{"email": "kiseleva-viktoriya_1965@postgrespro.ru", "phone": "+70203841376"}
0005433009332	7E0A33	2892 344232	NIKOLAY OSIPOV	{"email": "n-osipov_1979@postgrespro.ru", "phone": "+70584766275"}
0005433009333	7E0A33	7834 165132	ALEKSANDR SIDOROV	{"phone": "+70961330698"}
0005433009334	9E6B4E	4912 107124	ALEKSANDR VASILEV	{"phone": "+70698059158"}
0005433009335	7B1682	4413 779004	ALEKSANDR ROMANOV	{"phone": "+70594017288"}
0005433009336	0B8040	3599 996788	ANATOLIY GRIGOREV	{"email": "grigorev-anatoliy_04111972@postgrespro.ru", "phone": "+70213732195"}
0005433009337	DBEBCF	2399 304142	ZOYA ZAKHAROVA	{"phone": "+70570728896"}
0005433009338	DBEBCF	4904 226846	VLADIMIR BARANOV	{"email": "vladimirbaranov.18061974@postgrespro.ru", "phone": "+70994628843"}
0005433009450	59DDBF	9809 737609	EVGENIY MAKAROV	{"phone": "+70065284856"}
0005433009339	53067E	8868 386002	VIKTOR KOZLOV	{"email": "viktor-kozlov_081984@postgrespro.ru", "phone": "+70546976985"}
0005433009340	53067E	3810 231585	NATALYA TIMOFEEVA	{"email": "timofeeva_n_1977@postgrespro.ru", "phone": "+70552878108"}
0005433009341	157368	3500 096712	ALEKSANDRA GUSEVA	{"email": "guseva-a_111967@postgrespro.ru", "phone": "+70475305805"}
0005433009342	157368	4970 493897	ELENA ZHUKOVA	{"phone": "+70342656604"}
0005433009343	F90A8D	2726 597170	MIKHAIL SEMENOV	{"phone": "+70510144289"}
0005433009344	F90A8D	7097 486437	ARSEN ISAEV	{"phone": "+70913050748"}
0005433009345	AB7C27	8578 600671	ELENA KOROLEVA	{"email": "korolevaelena_1974@postgrespro.ru", "phone": "+70363953905"}
0005433009346	AB7C27	2561 928319	VLADIMIR TIKHONOV	{"email": "v-tikhonov_061976@postgrespro.ru", "phone": "+70629128732"}
0005433009347	AB7C27	0286 574715	TATYANA GORBUNOVA	{"email": "t.gorbunova-101981@postgrespro.ru", "phone": "+70778329464"}
0005433009348	B4DFA7	0240 221991	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr111973@postgrespro.ru", "phone": "+70965930964"}
0005433009349	254A83	6553 441615	ARTEM ZAKHAROV	{"phone": "+70410163232"}
0005433009350	254A83	0865 114094	NATALYA FROLOVA	{"phone": "+70491660192"}
0005433009351	DCD589	2665 622860	GENNADIY KRASNOV	{"phone": "+70258684575"}
0005433009352	5BDB81	0299 325295	VLADIMIR MIKHAYLOV	{"email": "mikhaylovv-1980@postgrespro.ru", "phone": "+70734298766"}
0005433009353	061EAD	9110 169223	NADEZHDA SERGEEVA	{"phone": "+70307274993"}
0005433009354	306E6C	0004 948363	MATRENA KARPOVA	{"email": "karpova.matrena_10091963@postgrespro.ru", "phone": "+70357310910"}
0005433009355	306E6C	6110 804233	VLADIMIR SMIRNOV	{"phone": "+70721052931"}
0005433009356	8E3264	5481 436911	KSENIYA ISAEVA	{"email": "k_isaeva091976@postgrespro.ru", "phone": "+70257166705"}
0005433009357	8E3264	3422 617054	ALEKSEY BELOV	{"email": "belova-1969@postgrespro.ru", "phone": "+70772450040"}
0005433009470	A0E846	3478 903939	ELENA VOLKOVA	{"phone": "+70893741659"}
0005433009358	3AAC3A	5884 533774	ANNA TIMOFEEVA	{"email": "timofeevaanna111978@postgrespro.ru", "phone": "+70800739127"}
0005433009359	DCD943	2443 887525	PAVEL FROLOV	{"email": "frolov_p.1983@postgrespro.ru", "phone": "+70886281901"}
0005433009360	DCD943	5844 277495	VASILIY SIDOROV	{"email": "sidorovvasiliy_121984@postgrespro.ru", "phone": "+70680783172"}
0005433009361	45E04B	7963 519272	ANTON ISAEV	{"phone": "+70270484915"}
0005433009362	45E04B	8238 109233	ALEKSEY VASILEV	{"email": "a.vasilev1964@postgrespro.ru", "phone": "+70579159224"}
0005433009363	D26976	2883 179825	YURIY OSIPOV	{"phone": "+70530152334"}
0005433009364	826FE2	0799 098843	DARYA IVANOVA	{"email": "divanova_111970@postgrespro.ru", "phone": "+70166991848"}
0005433009365	3CF33E	3471 392471	VLADIMIR IVANOV	{"email": "vladimir.ivanov-1967@postgrespro.ru", "phone": "+70656835409"}
0005433009366	3CF33E	4504 613228	ANDREY NIKOLAEV	{"phone": "+70537618120"}
0005433009367	8EC9B5	5594 348337	LIDIYA SMIRNOVA	{"email": "smirnova-lidiya23071973@postgrespro.ru", "phone": "+70358892124"}
0005433009368	1A8219	5638 740018	TATYANA IVANOVA	{"phone": "+70985237036"}
0005433009369	170236	2911 477611	ROMAN KARPOV	{"email": "r-karpov-29051974@postgrespro.ru", "phone": "+70207175457"}
0005433009370	170236	8020 744803	OLGA NIKOLAEVA	{"email": "nikolaeva-o09091956@postgrespro.ru", "phone": "+70228317160"}
0005433009371	E3585E	1402 982007	DMITRIY ORLOV	{"phone": "+70156536334"}
0005433009372	67C5B8	3568 685507	MARIYA KALININA	{"email": "kalinina_m051975@postgrespro.ru", "phone": "+70428616336"}
0005433009373	4F7F50	0478 599580	IRINA RODIONOVA	{"email": "irina_rodionova-25061969@postgrespro.ru", "phone": "+70925818194"}
0005433009374	E73FF0	4870 284887	YURIY FEDOROV	{"email": "fedorov-y.041974@postgrespro.ru", "phone": "+70928932882"}
0005433009375	E73FF0	9802 235414	ANDREY DMITRIEV	{"phone": "+70185151397"}
0005433009376	E73FF0	6841 493921	TIMOFEY BORISOV	{"phone": "+70594793711"}
0005433009377	553BD3	1618 901228	VLADIMIR MOROZOV	{"phone": "+70410097117"}
0005433009378	BDFEE9	1431 883089	EVGENIY FROLOV	{"phone": "+70907173957"}
0005433009379	EA6ECC	2181 540650	TATYANA FROLOVA	{"phone": "+70596688937"}
0005433009380	928410	6947 565316	MAKSIM EGOROV	{"phone": "+70785088289"}
0005433009381	928410	8557 297606	MAKSIM IVANOV	{"email": "ivanov_maksim_09111971@postgrespro.ru", "phone": "+70345039898"}
0005433009382	7D3BD9	5586 033368	OLGA NESTEROVA	{"email": "nesterova-olga-1979@postgrespro.ru", "phone": "+70254686406"}
0005433009383	7D3BD9	6444 281770	ALISA LUKYANOVA	{"phone": "+70423942867"}
0005433009384	D9241E	8913 208668	VERA SCHERBAKOVA	{"email": "scherbakova_v.1972@postgrespro.ru", "phone": "+70929028344"}
0005433009385	D9241E	8096 155331	MARINA KALININA	{"email": "m.kalinina.12041974@postgrespro.ru", "phone": "+70707622293"}
0005433009386	93F332	3534 927598	LIDIYA NAUMOVA	{"phone": "+70192131324"}
0005433009387	884CC3	4833 929487	IGOR SHEVCHENKO	{"email": "igor_shevchenko.091966@postgrespro.ru", "phone": "+70896391691"}
0005433009388	6F38CD	3771 578246	TATYANA GRISHINA	{"email": "grishina_t121957@postgrespro.ru", "phone": "+70280116921"}
0005433009389	2FD6B0	6556 456247	VLADIMIR MARTYNOV	{"email": "vladimir_martynov.17061979@postgrespro.ru", "phone": "+70976479465"}
0005433009390	9D2453	1527 857332	ROMAN ROMANOV	{"email": "romanov-r1971@postgrespro.ru", "phone": "+70525607749"}
0005433009391	9D2453	3230 590041	GALINA AFANASEVA	{"phone": "+70882098171"}
0005433009392	C81060	5552 396454	ANATOLIY DAVYDOV	{"email": "anatoliy-davydov_1970@postgrespro.ru", "phone": "+70828998032"}
0005433009393	D5F3CB	4813 996921	ELENA NIKOLAEVA	{"email": "nikolaeva-elena-26111972@postgrespro.ru", "phone": "+70569053585"}
0005433009675	C7AF19	3571 388841	VLADIMIR KOZLOV	{"phone": "+70443866787"}
0005433009394	D5F3CB	2344 751214	SERGEY FILIPPOV	{"email": "sergey_filippov.1978@postgrespro.ru", "phone": "+70196281152"}
0005433009395	B126A0	7180 988108	ARKADIY VOLKOV	{"email": "volkov.arkadiy-111960@postgrespro.ru", "phone": "+70455152059"}
0005433009396	B126A0	8498 468481	ALEKSEY RODIONOV	{"phone": "+70449696855"}
0005433009397	30A115	2487 736095	VLADIMIR ORLOV	{"email": "v-orlov1962@postgrespro.ru", "phone": "+70190060368"}
0005433009398	96FC6E	4669 370834	ELENA FROLOVA	{"phone": "+70277356501"}
0005433009399	977870	7209 782873	MARAT KUZNECOV	{"phone": "+70696314806"}
0005433009400	BDD022	6893 919694	VLADIMIR KUDRYASHOV	{"phone": "+70743218977"}
0005433009401	F4CFA6	9929 664998	VASILIY FEDOROV	{"phone": "+70487297238"}
0005433009402	A20637	7862 684886	ALENA TROFIMOVA	{"phone": "+70868724798"}
0005433009403	1B9939	9083 887972	OLGA IVANOVA	{"phone": "+70685086909"}
0005433009404	AFF060	4114 454201	YURIY SMIRNOV	{"email": "smirnovy21031984@postgrespro.ru", "phone": "+70469735235"}
0005433009405	7EB9D4	5994 657681	VLADIMIR KAZAKOV	{"phone": "+70295589809"}
0005433009406	D35425	6528 215282	VIKTOR GRIGOREV	{"email": "v.grigorev-29121979@postgrespro.ru", "phone": "+70372347747"}
0005433009407	C88D35	8036 309842	PAVEL VLASOV	{"email": "vlasov-p_1986@postgrespro.ru", "phone": "+70612413872"}
0005433009408	9230D0	3982 801179	SERGEY FOMIN	{"phone": "+70074915420"}
0005433009409	9230D0	6220 360328	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.a-13051972@postgrespro.ru", "phone": "+70110288979"}
0005433009410	268C1D	1921 821139	VITALIY EGOROV	{"phone": "+70017269536"}
0005433009411	268C1D	2701 050576	NINA TIMOFEEVA	{"email": "timofeevan_1966@postgrespro.ru", "phone": "+70024764007"}
0005433009412	5A0823	2728 665952	MAKSIM BORISOV	{"phone": "+70727521493"}
0005433009414	C15B01	8507 223623	LYUDMILA VASILEVA	{"email": "vasileva_lyudmila-031966@postgrespro.ru", "phone": "+70346031916"}
0005433009415	713813	9686 433065	ALEKSANDRA KUZMINA	{"phone": "+70929762733"}
0005433009416	C58E38	4827 517052	YURIY VOROBEV	{"email": "vorobev.yuriy-1975@postgrespro.ru", "phone": "+70059666397"}
0005433009417	C58E38	9330 753201	SERGEY GORBUNOV	{"email": "s.gorbunov_121962@postgrespro.ru", "phone": "+70511055493"}
0005433009418	905BE5	5647 089651	LARISA SOKOLOVA	{"email": "sokolova_larisa_101972@postgrespro.ru", "phone": "+70602762128"}
0005433009419	4023F8	4930 803550	ALEKSEY TARASOV	{"phone": "+70871999272"}
0005433009420	2BF51B	0159 761950	VALENTINA KOZLOVA	{"phone": "+70161157268"}
0005433009421	2099D8	6778 923203	DANILA YAKOVLEV	{"email": "d-yakovlev-1971@postgrespro.ru", "phone": "+70267441962"}
0005433009422	2099D8	1790 682293	MARINA IVANOVA	{"email": "m-ivanova011974@postgrespro.ru", "phone": "+70629642971"}
0005433009423	5D0B08	5448 600315	LYUBOV NOVIKOVA	{"phone": "+70100435147"}
0005433009424	415D74	2250 454285	RITA SOKOLOVA	{"email": "rita-sokolova_24101970@postgrespro.ru", "phone": "+70489886944"}
0005433009425	E110C1	8755 705593	ELENA ANDREEVA	{"email": "elenaandreeva_1967@postgrespro.ru", "phone": "+70665161838"}
0005433009426	5F9435	3573 052212	KIRILL POPOV	{"phone": "+70883584512"}
0005433009427	5F9435	7182 677282	EKATERINA GAVRILOVA	{"phone": "+70380435082"}
0005433009428	067229	0280 624923	LYUBOV LOGINOVA	{"email": "loginova_lyubov_1963@postgrespro.ru", "phone": "+70518368584"}
0005433009429	067229	7944 248151	ALEKSANDR GORBUNOV	{"email": "a-gorbunov-08071968@postgrespro.ru", "phone": "+70939344884"}
0005433009430	6D45FD	3703 741665	VALERIY NIKOLAEV	{"phone": "+70644050613"}
0005433009431	6D45FD	4201 554618	NATALYA SERGEEVA	{"phone": "+70814681508"}
0005433009432	D21F16	7022 625885	EKATERINA MOROZOVA	{"email": "ekaterina_morozova_021974@postgrespro.ru", "phone": "+70633384526"}
0005433009433	60D140	8072 259874	ZHANNA IVANOVA	{"email": "ivanovazhanna091984@postgrespro.ru", "phone": "+70601765707"}
0005433009434	337456	6232 193524	VITALIY MELNIKOV	{"email": "melnikov-vitaliy.28011983@postgrespro.ru", "phone": "+70233395589"}
0005433009435	B34D9E	4306 488710	ANTONINA BOGDANOVA	{"phone": "+70500304884"}
0005433009436	F95F0A	8292 550793	VIKTOR SCHERBAKOV	{"email": "scherbakovv_13051977@postgrespro.ru", "phone": "+70943834749"}
0005433009437	F95F0A	2845 100529	ANATOLIY VOLKOV	{"email": "volkov.a.14021979@postgrespro.ru", "phone": "+70776414987"}
0005433009438	FC0D1A	8768 013144	ZINAIDA MIRONOVA	{"phone": "+70181067775"}
0005433009439	AC8160	7448 932239	NADEZHDA ZHURAVLEVA	{"email": "nzhuravleva1959@postgrespro.ru", "phone": "+70420659635"}
0005433009440	7696F0	0859 621202	ELENA BELYAEVA	{"email": "belyaevaelena.101961@postgrespro.ru", "phone": "+70490752426"}
0005433009441	7696F0	4411 107462	NINA KONOVALOVA	{"phone": "+70368731134"}
0005433009442	7696F0	8809 612295	MARINA EFREMOVA	{"phone": "+70527343940"}
0005433009443	EBD88D	5500 675239	IRINA DENISOVA	{"phone": "+70734787623"}
0005433009444	EBD88D	9691 516201	ANATOLIY STEPANOV	{"phone": "+70194331734"}
0005433009445	C5D281	3404 474119	ZOYA DAVYDOVA	{"phone": "+70278025616"}
0005433009446	EC59B0	0309 137827	LYUDMILA BELOVA	{"email": "belova_lyudmila-1965@postgrespro.ru", "phone": "+70054407910"}
0005433009447	F0DECE	9039 400302	PETR POPOV	{"email": "popov_petr.041968@postgrespro.ru", "phone": "+70382356724"}
0005433009448	87B7F7	4565 407838	VALENTIN SMIRNOV	{"phone": "+70095451210"}
0005433009449	4EF787	8749 261372	YURIY KULIKOV	{"email": "kulikov.yuriy.1975@postgrespro.ru", "phone": "+70358149041"}
0005433009451	1ED07F	8693 580630	TATYANA TIKHONOVA	{"email": "tikhonovat1969@postgrespro.ru", "phone": "+70266644725"}
0005433009452	1ED07F	5281 782567	TATYANA IVANOVA	{"email": "ivanova-t_1972@postgrespro.ru", "phone": "+70915182037"}
0005433009453	5CC6FD	5643 913233	ELENA IVANOVA	{"phone": "+70897952769"}
0005433009454	ED2BDA	0816 111350	DARYA POLYAKOVA	{"phone": "+70991686358"}
0005433009455	ED2BDA	0974 042339	ANDREY ROMANOV	{"email": "romanov.a-1980@postgrespro.ru", "phone": "+70328575298"}
0005433009456	2B6050	1818 346138	NADEZHDA KALININA	{"email": "kalinina_nadezhda021973@postgrespro.ru", "phone": "+70285386083"}
0005433009457	4CFDB5	8035 973937	VLADIMIR KOZLOV	{"email": "v.kozlov17051978@postgrespro.ru", "phone": "+70948780830"}
0005433009458	7BD364	3185 252883	ALISA VOLKOVA	{"phone": "+70073358154"}
0005433009459	7BD364	8889 100278	ARTEM GERASIMOV	{"phone": "+70191767923"}
0005433009460	A6CD05	5864 461708	YURIY FEDOTOV	{"email": "yuriyfedotov_031962@postgrespro.ru", "phone": "+70700949105"}
0005433009461	A6CD05	5895 432399	YULIYA SAVELEVA	{"phone": "+70229898037"}
0005433009462	A6CD05	4631 355045	VALENTINA IVANOVA	{"email": "ivanova_v.25031960@postgrespro.ru", "phone": "+70335787396"}
0005433009463	37CC71	5558 497453	IVAN BARANOV	{"email": "ivan.baranov_051971@postgrespro.ru", "phone": "+70371004172"}
0005433009464	37CC71	5695 931033	ELENA IVANOVA	{"email": "ivanova.e-021974@postgrespro.ru", "phone": "+70462663763"}
0005433009465	37CC71	1617 649117	NATALYA ARKHIPOVA	{"email": "arkhipova.natalya_011981@postgrespro.ru", "phone": "+70091420707"}
0005433009466	B5D5F0	9482 859218	TATYANA NIKITINA	{"email": "tatyana-nikitina01101958@postgrespro.ru", "phone": "+70284644119"}
0005433009467	B5D5F0	3088 189170	ALEKSANDR ISAEV	{"email": "isaevaleksandr-1972@postgrespro.ru", "phone": "+70020441390"}
0005433009468	AF9F0A	2916 303588	ANDREY ZAKHAROV	{"email": "zakharov.a031979@postgrespro.ru", "phone": "+70358739990"}
0005433009469	18EE3B	5137 879769	VALENTINA DMITRIEVA	{"email": "v_dmitrieva.1975@postgrespro.ru", "phone": "+70577530934"}
0005433009471	A0E846	0567 586938	DMITRIY VASILEV	{"email": "vasilev_dmitriy-1958@postgrespro.ru", "phone": "+70755549091"}
0005433009472	6F1C97	6866 359679	ZOYA ANDREEVA	{"phone": "+70581267550"}
0005433009473	90C434	6668 759715	ARTEM SCHERBAKOV	{"email": "scherbakov-a.081974@postgrespro.ru", "phone": "+70901159426"}
0005433009474	90C434	0412 890849	SERGEY KUZNECOV	{"phone": "+70133795037"}
0005433009475	C83CAE	3585 887065	GERMAN BONDARENKO	{"email": "bondarenkogerman.1982@postgrespro.ru", "phone": "+70836041023"}
0005433009476	A4ABFC	8843 817760	ANASTASIYA IVANOVA	{"email": "ivanova.anastasiya_1968@postgrespro.ru", "phone": "+70879818532"}
0005433009477	A4ABFC	1837 700151	ANTONINA ZAYCEVA	{"phone": "+70340533028"}
0005433009478	710F93	3348 589551	TATYANA NAZAROVA	{"phone": "+70260618743"}
0005433009479	1FD847	1447 576438	ANTONINA VLASOVA	{"phone": "+70574823137"}
0005433009480	5AC59F	4323 022172	YULIYA KONOVALOVA	{"email": "y_konovalova.111964@postgrespro.ru", "phone": "+70837332398"}
0005433009481	8BDFCF	1943 687489	YURIY VOLKOV	{"phone": "+70228010089"}
0005433009482	587B06	9942 469641	DMITRIY ZAKHAROV	{"phone": "+70217965517"}
0005433009483	587B06	0502 962908	VLADIMIR ILIN	{"email": "vladimir.ilin-21051970@postgrespro.ru", "phone": "+70351783317"}
0005433009484	6FF153	0950 004310	NIKOLAY PETROV	{"phone": "+70205074914"}
0005433009485	537119	4688 859030	SERGEY ZHUKOV	{"email": "s.zhukov-12041961@postgrespro.ru", "phone": "+70682028754"}
0005433009486	537119	8335 680887	GENNADIY NAZAROV	{"email": "gnazarov-30031965@postgrespro.ru", "phone": "+70096282557"}
0005433009487	537119	4528 668294	EVGENIYA RODIONOVA	{"phone": "+70198651032"}
0005433009488	01F2B5	7151 709941	ALEKSEY FROLOV	{"email": "frolov-a-1969@postgrespro.ru", "phone": "+70711915425"}
0005433009489	C76E98	9074 355833	POLINA NAZAROVA	{"email": "p.nazarova.071974@postgrespro.ru", "phone": "+70274524479"}
0005433009490	D96118	2087 665434	OLGA TITOVA	{"email": "titovao_1961@postgrespro.ru", "phone": "+70955694705"}
0005433009491	D96118	5825 986955	ALEKSANDR ZHURAVLEV	{"phone": "+70072237700"}
0005433009492	DE0310	0708 682122	SVETLANA SMIRNOVA	{"phone": "+70359474141"}
0005433009493	597FC8	5642 961448	IRINA PETROVA	{"phone": "+70127381170"}
0005433009494	597FC8	5772 070933	IRINA SOROKINA	{"phone": "+70492638259"}
0005433009495	B43EEB	2464 953894	NINA MELNIKOVA	{"phone": "+70155471557"}
0005433009496	83C972	7142 409307	VLADISLAV IVANOV	{"phone": "+70843064327"}
0005433009497	22EC4A	6676 064084	ALEKSANDR KUZNECOV	{"email": "akuznecov_27081973@postgrespro.ru", "phone": "+70853888776"}
0005433009498	D02294	1035 236932	ARTEMIY KONOVALOV	{"email": "artemiy-konovalov.27121983@postgrespro.ru", "phone": "+70930007204"}
0005433009499	D02294	4098 266117	SERGEY MARTYNOV	{"email": "martynovs-031963@postgrespro.ru", "phone": "+70596849803"}
0005433009500	D02294	7759 961807	EVGENIYA GERASIMOVA	{"email": "evgeniya-gerasimova-1974@postgrespro.ru", "phone": "+70679315126"}
0005433009501	3D2DCC	8615 521687	ELENA ALEKSEEVA	{"email": "alekseeva-e1970@postgrespro.ru", "phone": "+70079899231"}
0005433009502	59D377	6179 557640	ILYA BORISOV	{"phone": "+70589717082"}
0005433009503	59D377	0696 422559	MIKHAIL VASILEV	{"email": "m.vasilev.01061978@postgrespro.ru", "phone": "+70099233905"}
0005433009504	F60E4E	1900 134490	MARINA LEBEDEVA	{"email": "lebedeva-marina.111969@postgrespro.ru", "phone": "+70472162830"}
0005433009505	F60E4E	0643 541741	SVYATOSLAV SHEVCHENKO	{"phone": "+70471191254"}
0005433009506	6E197C	1689 068439	IRINA ANDREEVA	{"email": "i_andreeva021963@postgrespro.ru", "phone": "+70058981296"}
0005433009507	6E197C	5780 316411	LARISA MAKAROVA	{"email": "makarova-l.111971@postgrespro.ru", "phone": "+70684799425"}
0005433009508	7A657F	2366 480774	NIKITA FILIPPOV	{"email": "filippov-n_04091958@postgrespro.ru", "phone": "+70312570231"}
0005433009509	7A657F	4580 310734	ALEKSANDR IVANOV	{"phone": "+70736411083"}
0005433009510	74CBE7	9388 201190	YURIY FROLOV	{"email": "frolov-yuriy-121967@postgrespro.ru", "phone": "+70948114491"}
0005433009511	1ECAB1	2987 555214	KONSTANTIN SERGEEV	{"email": "k-sergeev.111980@postgrespro.ru", "phone": "+70911240676"}
0005433009512	176CF7	7367 900980	OLGA POPOVA	{"phone": "+70968102730"}
0005433009513	C5D78B	8378 883441	ALEKSANDR KUZMIN	{"email": "a.kuzmin-15051964@postgrespro.ru", "phone": "+70318932284"}
0005433009514	C5D78B	4311 884962	ELENA DMITRIEVA	{"email": "e-dmitrieva_1975@postgrespro.ru", "phone": "+70078084851"}
0005433009515	92BFCE	4559 073070	LIDIYA CHERNOVA	{"phone": "+70261503071"}
0005433009516	92BFCE	4449 950630	IVAN KRASNOV	{"phone": "+70748606680"}
0005433009517	617946	8067 427587	OLEG POPOV	{"phone": "+70096773054"}
0005433009518	617946	5110 613592	DMITRIY MIRONOV	{"phone": "+70158794949"}
0005433009519	5F1888	5421 144026	TAMARA NIKITINA	{"email": "tamara_nikitina-17051979@postgrespro.ru", "phone": "+70690214501"}
0005433009520	C61536	1533 448898	IVAN IVANOV	{"phone": "+70567725402"}
0005433009521	7DB2E9	4887 207693	RASHIT EGOROV	{"phone": "+70187001981"}
0005433009522	C8B991	0848 302722	ALEKSEY MATVEEV	{"email": "a.matveev_051968@postgrespro.ru", "phone": "+70360939709"}
0005433009523	6D08C7	1746 041027	ALEKSEY KOZLOV	{"phone": "+70135011470"}
0005433009524	900A00	6147 990805	NINA KRASNOVA	{"phone": "+70460857992"}
0005433009525	16EEB4	3265 630047	SERGEY BORISOV	{"phone": "+70046760160"}
0005433009526	943260	4461 703055	DENIS KUZNECOV	{"email": "kuznecov.denis.041971@postgrespro.ru", "phone": "+70523894002"}
0005433009527	943260	9968 853337	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova-1963@postgrespro.ru", "phone": "+70984993105"}
0005433009528	08642C	0328 130313	ARTEM STEPANOV	{"phone": "+70687666052"}
0005433009529	F72D11	9307 463618	LILIYA MEDVEDEVA	{"email": "l-medvedeva011977@postgrespro.ru", "phone": "+70252136838"}
0005433009530	F72D11	5958 465714	OLGA MOISEEVA	{"phone": "+70723315685"}
0005433009531	74A79E	3764 943062	ALEKSANDRA MEDVEDEVA	{"phone": "+70807355139"}
0005433009532	E9F0B4	1105 411696	MARIYA STEPANOVA	{"phone": "+70991594480"}
0005433009533	22A60E	3883 753363	DMITRIY SCHERBAKOV	{"phone": "+70153348335"}
0005433009534	22A60E	2659 244046	NINEL ALEKSEEVA	{"phone": "+70048569000"}
0005433009535	000909	3720 983323	ALEKSEY SOLOVEV	{"email": "aleksey.solovev031974@postgrespro.ru", "phone": "+70598487208"}
0005433009536	384ED4	2268 623970	OLGA KUZNECOVA	{"email": "kuznecova_olga041973@postgrespro.ru", "phone": "+70377168594"}
0005433009537	384ED4	3782 388961	IVAN ZAYCEV	{"email": "zaycev-ivan.03051972@postgrespro.ru", "phone": "+70010258259"}
0005433009538	C3548B	5266 655485	TATYANA PETROVA	{"phone": "+70012261685"}
0005433009539	22A6F7	5412 773718	GALINA POTAPOVA	{"phone": "+70245892243"}
0005433009540	D93794	7074 241294	ANDREY VLASOV	{"phone": "+70555267364"}
0005433009541	45DB16	5051 665285	NADEZHDA MEDVEDEVA	{"phone": "+70134482655"}
0005433009542	F917D5	2373 528976	NADEZHDA DMITRIEVA	{"email": "n.dmitrieva_1977@postgrespro.ru", "phone": "+70929732503"}
0005433009543	453A7F	8079 880646	LYUBOV KISELEVA	{"phone": "+70605922769"}
0005433009544	453A7F	4188 453884	LYUBOV BARANOVA	{"phone": "+70126815955"}
0005433009545	2A5E10	0307 510488	DMITRIY SOROKIN	{"email": "d-sorokin-07041967@postgrespro.ru", "phone": "+70427436435"}
0005433009546	45FBAD	0551 900037	EVDOKIYA ROMANOVA	{"phone": "+70704625592"}
0005433009547	CC21DD	3212 319152	OLGA BARANOVA	{"email": "o-baranova_1973@postgrespro.ru", "phone": "+70419372705"}
0005433009548	8D32B7	1910 840916	NADEZHDA SMIRNOVA	{"email": "smirnova_n051974@postgrespro.ru", "phone": "+70527736281"}
0005433009549	1574D3	6546 030224	ALEKSANDR FILIPPOV	{"phone": "+70462830930"}
0005433009550	4E94D8	4713 847658	NIKOLAY TIMOFEEV	{"phone": "+70097549159"}
0005433009551	4E94D8	8662 105005	INNA POPOVA	{"email": "popovainna_1960@postgrespro.ru", "phone": "+70663875942"}
0005433009552	4E94D8	9072 198497	EVGENIYA CHERNOVA	{"phone": "+70225888139"}
0005433009553	A16594	0731 129535	ROMAN OSIPOV	{"phone": "+70741053775"}
0005433009554	A16594	9813 313340	ANDREY MAKAROV	{"email": "makarov.andrey_021976@postgrespro.ru", "phone": "+70121277502"}
0005433009555	C04DBE	0201 858113	TATYANA ZAKHAROVA	{"email": "zakharova.tatyana071969@postgrespro.ru", "phone": "+70446132447"}
0005433009556	BE1F08	3300 005251	EKATERINA BARANOVA	{"email": "e.baranova-071968@postgrespro.ru", "phone": "+70026129041"}
0005433009557	8A3692	4496 099875	ALENA SOROKINA	{"email": "sorokina-alena.101961@postgrespro.ru", "phone": "+70741719323"}
0005433009558	20F0AE	6722 495763	NIKITA BORISOV	{"phone": "+70565401669"}
0005433009559	20F0AE	4496 504129	EKATERINA MATVEEVA	{"email": "matveevaekaterina031969@postgrespro.ru", "phone": "+70378092627"}
0005433009560	20F0AE	0429 671994	ANASTASIYA EGOROVA	{"phone": "+70003617324"}
0005433009561	B7B139	7241 057712	ALENA KARPOVA	{"email": "karpova_alena-1983@postgrespro.ru", "phone": "+70753476052"}
0005433009562	B7B139	8829 272765	OLGA MASLOVA	{"phone": "+70917552226"}
0005433009563	C9966D	2939 880339	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir_11051963@postgrespro.ru", "phone": "+70453418759"}
0005433009564	C9966D	9004 784287	NATALYA ISAEVA	{"email": "isaeva_n.05031975@postgrespro.ru", "phone": "+70742574636"}
0005433009565	525ECD	8506 149648	RAISA IVANOVA	{"email": "raisa_ivanova.1969@postgrespro.ru", "phone": "+70654894665"}
0005433009566	CCEEBE	8973 670050	LIDIYA POTAPOVA	{"phone": "+70592076344"}
0005433009567	CCEEBE	0166 880368	LYUDMILA ANTONOVA	{"email": "antonova-l_30061992@postgrespro.ru", "phone": "+70568061948"}
0005433009568	C18FF3	0985 972388	LARISA KOZLOVA	{"email": "larisa-kozlova-14041966@postgrespro.ru", "phone": "+70855590760"}
0005433009569	C20363	9245 830548	OLGA LOGINOVA	{"phone": "+70828407376"}
0005433009570	078BAD	5805 476750	PETR ZAKHAROV	{"phone": "+70988273058"}
0005433009571	078BAD	1782 581778	YURIY KRASNOV	{"email": "y_krasnov18021963@postgrespro.ru", "phone": "+70767768243"}
0005433009572	6771F0	6442 064261	ALEKSEY ILIN	{"phone": "+70391600397"}
0005433009573	04ECAC	8625 803190	ALFIYA NAZAROVA	{"phone": "+70194201086"}
0005433009574	04ECAC	6527 783502	ELENA IVANOVA	{"phone": "+70056453597"}
0005433009575	A9535E	8176 586126	NINA SMIRNOVA	{"email": "ninasmirnova.041973@postgrespro.ru", "phone": "+70271115047"}
0005433009576	A9535E	7763 430128	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr_1972@postgrespro.ru", "phone": "+70286054794"}
0005433009577	A9535E	1422 192323	ALEKSEY TIMOFEEV	{"phone": "+70379770709"}
0005433009578	187A7A	7094 919810	LYUBOV FILIPPOVA	{"phone": "+70203956981"}
0005433009579	187A7A	1164 628687	ALEKSANDR FROLOV	{"phone": "+70466790020"}
0005433009580	1D46E5	8928 834375	ILFAT POPOV	{"email": "popovi.121986@postgrespro.ru", "phone": "+70693793431"}
0005433009581	AD0FDF	0677 572631	NATALYA VASILEVA	{"phone": "+70639304587"}
0005433009582	AD0FDF	8769 281492	SERGEY BORISOV	{"email": "sborisov.091967@postgrespro.ru", "phone": "+70622004929"}
0005433009583	D80947	8296 567673	NATALYA MAKAROVA	{"phone": "+70268718538"}
0005433009584	553698	8076 962058	VLADIMIR KOZLOV	{"email": "vladimirkozlov_111959@postgrespro.ru", "phone": "+70434628855"}
0005433009585	50D57B	9670 008922	VASILIY ZAKHAROV	{"phone": "+70644263283"}
0005433009586	50D57B	0455 347482	IRINA ZAKHAROVA	{"email": "i_zakharova121969@postgrespro.ru", "phone": "+70753756586"}
0005433009587	C902F8	5843 032519	LYUBOV MAKSIMOVA	{"email": "lyubov_maksimova19061960@postgrespro.ru", "phone": "+70190470981"}
0005433009588	478871	2853 853447	DAMIR POPOV	{"email": "popov-damir_09071964@postgrespro.ru", "phone": "+70807941755"}
0005433009589	624455	3129 425951	NELYA ZHUKOVA	{"email": "nelya.zhukova_24011963@postgrespro.ru", "phone": "+70842045533"}
0005433009590	524C30	1682 635954	LYUDMILA KONOVALOVA	{"phone": "+70353728879"}
0005433009591	F2190F	9872 596306	ARTEM BARANOV	{"phone": "+70199165948"}
0005433009592	F2190F	6995 282448	LYUDMILA VASILEVA	{"email": "vasileva-lyudmila-23091972@postgrespro.ru", "phone": "+70361962583"}
0005433009593	91F4FF	3984 947466	MIKHAIL FILIPPOV	{"phone": "+70047535054"}
0005433009594	C48B94	1808 965232	YURIY NIKOLAEV	{"email": "nikolaev_yuriy-121957@postgrespro.ru", "phone": "+70837215966"}
0005433009595	C48B94	6742 051886	TATYANA ZHURAVLEVA	{"email": "tatyanazhuravleva05041980@postgrespro.ru", "phone": "+70717702998"}
0005433009596	552E9F	1286 409253	IRINA KOLESNIKOVA	{"email": "kolesnikovairina-081978@postgrespro.ru", "phone": "+70128363204"}
0005433009597	552E9F	2946 807339	PAVEL ZAYCEV	{"email": "zaycevpavel031961@postgrespro.ru", "phone": "+70130033239"}
0005433009598	84A531	3679 164793	POLINA KUZNECOVA	{"email": "polina.kuznecova-08091977@postgrespro.ru", "phone": "+70282758116"}
0005433009599	84A531	0510 421131	ELENA RODIONOVA	{"email": "rodionova-e1965@postgrespro.ru", "phone": "+70362091094"}
0005433009600	7B76EE	3479 527463	NADEZHDA OVCHINNIKOVA	{"email": "n-ovchinnikova.22101978@postgrespro.ru", "phone": "+70157247862"}
0005433009601	7B76EE	9011 735190	LYUBOV DAVYDOVA	{"email": "lyubovdavydova_041975@postgrespro.ru", "phone": "+70414023151"}
0005433009602	37ADA9	0793 985898	GALINA SIDOROVA	{"email": "galinasidorova_061972@postgrespro.ru", "phone": "+70099747617"}
0005433009603	37ADA9	6002 414193	KAMILLA VASILEVA	{"phone": "+70729125250"}
0005433009604	CA5109	2254 876074	YURIY NIKITIN	{"email": "nikitin.y-1968@postgrespro.ru", "phone": "+70328391075"}
0005433009605	D991DF	7091 459273	ALEKSANDR IVANOV	{"phone": "+70547851236"}
0005433009606	D991DF	4557 229094	ANTON VLASOV	{"phone": "+70387658739"}
0005433009607	242F19	7983 676914	NINA POTAPOVA	{"phone": "+70676711814"}
0005433009608	198F62	2183 229650	NADEZHDA ANDREEVA	{"phone": "+70841509712"}
0005433009609	4036FA	7711 198725	LYUDMILA DENISOVA	{"phone": "+70200052871"}
0005433009610	56F30A	5132 533197	KAMIL VASILEV	{"email": "vasilev-k-071963@postgrespro.ru", "phone": "+70736943145"}
0005433009611	9DB22F	9375 300251	ANDREY KOZLOV	{"email": "andrey_kozlov061989@postgrespro.ru", "phone": "+70859789373"}
0005433009612	0FB46F	9022 451942	EKATERINA MOISEEVA	{"phone": "+70932300537"}
0005433009613	E2F8FE	3716 772829	SERGEY PAVLOV	{"email": "pavlovsergey-24111974@postgrespro.ru", "phone": "+70181996409"}
0005433009614	6B8670	0114 242477	NATALYA EGOROVA	{"phone": "+70146725998"}
0005433009615	5CDD33	7373 916017	LILIYA FEDOROVA	{"phone": "+70163950889"}
0005433009616	955EFE	5087 951893	ELENA VASILEVA	{"phone": "+70210819278"}
0005433009617	E5D93C	6942 587340	SERGEY FEDOTOV	{"email": "sergeyfedotov.121968@postgrespro.ru", "phone": "+70570258842"}
0005433009618	0807CE	4414 027279	OLGA FOMINA	{"phone": "+70573732515"}
0005433009619	0807CE	4114 307464	OLGA MARTYNOVA	{"email": "martynova-olga-1964@postgrespro.ru", "phone": "+70552680681"}
0005433009620	31C3ED	6702 529158	ELENA RODIONOVA	{"phone": "+70209745973"}
0005433009621	62DC6F	4025 863029	VALERIY VASILEV	{"email": "vvasilev_111970@postgrespro.ru", "phone": "+70595631290"}
0005433009622	9B1551	4566 899692	ANGELINA VLASOVA	{"email": "a-vlasova.09041970@postgrespro.ru", "phone": "+70451810950"}
0005433009623	9B1551	4745 321506	ANTONINA MAKAROVA	{"email": "a-makarova-27061963@postgrespro.ru", "phone": "+70136298950"}
0005433009624	5E74BB	6849 707964	ALEKSANDR SOROKIN	{"email": "aleksandrsorokin_021973@postgrespro.ru", "phone": "+70253564502"}
0005433009625	5E74BB	7684 947344	NINA ILINA	{"email": "nina.ilina111969@postgrespro.ru", "phone": "+70789260859"}
0005433009626	1C6448	1079 616301	TAMARA KULIKOVA	{"phone": "+70369610388"}
0005433009627	751F03	1595 482761	ANDREY MOROZOV	{"phone": "+70037248347"}
0005433009628	8F4428	1548 189078	LYUDMILA IVANOVA	{"phone": "+70098953102"}
0005433009629	A12ACC	1692 863794	ALEKSEY NOVIKOV	{"email": "aleksey.novikov-19081974@postgrespro.ru", "phone": "+70908114307"}
0005433009630	419090	2037 764676	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy1968@postgrespro.ru", "phone": "+70306409991"}
0005433009631	45F9EF	1459 959674	SVETLANA ABRAMOVA	{"email": "abramova.svetlana.20081969@postgrespro.ru", "phone": "+70796028639"}
0005433009632	9B9405	9756 728601	SERGEY FILIPPOV	{"phone": "+70521618223"}
0005433009633	9B9405	7061 194185	OLGA EFREMOVA	{"phone": "+70850642898"}
0005433009634	400042	4195 585488	VLADIMIR TIMOFEEV	{"phone": "+70487478088"}
0005433009635	E825E1	4112 737732	EVGENIY SMIRNOV	{"email": "e-smirnov20031979@postgrespro.ru", "phone": "+70815091456"}
0005433009636	E825E1	9350 080053	GALINA SOROKINA	{"email": "sorokina_galina-1989@postgrespro.ru", "phone": "+70269532764"}
0005433009637	C7A6C6	4726 308406	TATYANA MOROZOVA	{"phone": "+70634000983"}
0005433009638	E4621A	0157 773905	IRINA SMIRNOVA	{"email": "ismirnova-07111971@postgrespro.ru", "phone": "+70822492649"}
0005433009639	65549D	8909 502511	KSENIYA ALEKSANDROVA	{"phone": "+70109124046"}
0005433009640	65549D	1229 466605	NADEZHDA DMITRIEVA	{"phone": "+70716140864"}
0005433009641	EF6ED3	2368 691186	LYUDMILA ZAYCEVA	{"phone": "+70717119200"}
0005433009642	EF6ED3	7625 420034	IRINA ALEKSANDROVA	{"email": "i_aleksandrova021975@postgrespro.ru", "phone": "+70035432633"}
0005433009643	5290C4	1492 209695	YURIY DENISOV	{"phone": "+70490410472"}
0005433009644	A45D86	5136 739640	NATALYA PAVLOVA	{"email": "pavlovanatalya011972@postgrespro.ru", "phone": "+70479081145"}
0005433009645	A45D86	1183 440966	VIKTOR BORISOV	{"phone": "+70004362422"}
0005433009646	FED713	2388 124189	GALINA ANDREEVA	{"email": "gandreeva26101966@postgrespro.ru", "phone": "+70214727220"}
0005433009647	DE24E8	0395 040999	VALERIY KUZNECOV	{"email": "v.kuznecov_28121975@postgrespro.ru", "phone": "+70608175572"}
0005433009648	41466E	6128 469365	TATYANA FEDOROVA	{"email": "fedorova-t-15041967@postgrespro.ru", "phone": "+70409657899"}
0005433009649	41466E	9166 543469	KONSTANTIN VOLKOV	{"email": "volkovk-1981@postgrespro.ru", "phone": "+70918907115"}
0005433009650	7F9F3E	2889 654352	OKSANA LAZAREVA	{"phone": "+70752469799"}
0005433009651	7F9F3E	5805 915889	PAVEL POPOV	{"email": "popov-pavel-091978@postgrespro.ru", "phone": "+70046047527"}
0005433009652	6E64A8	2989 145074	ALEKSEY VOLKOV	{"email": "a_volkov_071961@postgrespro.ru", "phone": "+70859854072"}
0005433009653	CBA3EE	0142 182184	OLEG OSIPOV	{"phone": "+70603870952"}
0005433009654	0D2894	4633 479694	YULIYA ROMANOVA	{"phone": "+70508133177"}
0005433009655	493240	3842 205617	YURIY CHERNOV	{"email": "yuriy.chernov_1973@postgrespro.ru", "phone": "+70739729226"}
0005433009656	C77AF0	4571 597257	NATALYA ARKHIPOVA	{"phone": "+70909385042"}
0005433009657	34A5A6	7187 745401	VLADIMIR VOROBEV	{"phone": "+70263090997"}
0005433009658	34A5A6	7053 142074	NADEZHDA MALYSHEVA	{"email": "nadezhda-malysheva15101972@postgrespro.ru", "phone": "+70023305513"}
0005433009659	ABB33F	9255 754600	NINA VASILEVA	{"phone": "+70837209950"}
0005433009660	E18516	8903 121648	SERGEY SEMENOV	{"email": "semenov_s1965@postgrespro.ru", "phone": "+70875760321"}
0005433009661	83CD1C	3500 106553	ANATOLIY POPOV	{"phone": "+70247810141"}
0005433009662	6F5DD2	0821 145143	MARIYA LAZAREVA	{"phone": "+70384162703"}
0005433009663	95765D	6573 844520	IRINA IVANOVA	{"email": "ivanova.i_051968@postgrespro.ru", "phone": "+70550367079"}
0005433009664	95765D	3175 245898	GALINA POPOVA	{"email": "galinapopova.121977@postgrespro.ru", "phone": "+70828174595"}
0005433009665	7041EA	4146 123283	TAMARA NAUMOVA	{"phone": "+70342906235"}
0005433009666	006624	8045 440124	ALINA SOLOVEVA	{"phone": "+70197227608"}
0005433009667	84155C	0494 617407	ZHANNA YAKOVLEVA	{"email": "zyakovleva-1979@postgrespro.ru", "phone": "+70055178291"}
0005433009668	84155C	8610 491328	DMITRIY VOLKOV	{"phone": "+70256655247"}
0005433009669	123A8D	0887 090646	ELENA KALININA	{"phone": "+70570861324"}
0005433009670	123A8D	6247 754752	DMITRIY VLASOV	{"phone": "+70621304373"}
0005433009671	E68453	4805 446235	IVAN PAVLOV	{"phone": "+70586702203"}
0005433009672	E68453	0423 579749	IRINA KUZNECOVA	{"phone": "+70492259065"}
0005433009673	312474	9392 214185	TATYANA SEMENOVA	{"email": "t.semenova-091965@postgrespro.ru", "phone": "+70585716920"}
0005433009674	312474	6476 383628	VLADIMIR FEDOROV	{"email": "fedorov-v-1980@postgrespro.ru", "phone": "+70921472766"}
0005433009676	88F01A	8732 134621	EVGENIYA BORISOVA	{"phone": "+70375107081"}
0005433009677	FD386B	3190 281875	KRISTINA MAKSIMOVA	{"email": "maksimova-kristina.1968@postgrespro.ru", "phone": "+70257423715"}
0005433009678	261DE2	3682 682953	VALERIY GAVRILOV	{"phone": "+70400492525"}
0005433009679	2EE85C	0118 061176	ANDREY KUZMIN	{"email": "andrey.kuzmin24051976@postgrespro.ru", "phone": "+70773150384"}
0005433009680	145CA6	6840 000257	VYACHESLAV KULIKOV	{"phone": "+70313499997"}
0005433009681	145CA6	4891 921963	SVETLANA SOLOVEVA	{"email": "solovevasvetlana_1975@postgrespro.ru", "phone": "+70401317023"}
0005433009682	B9A81B	2418 459601	IRINA NESTEROVA	{"email": "nesterovairina1978@postgrespro.ru", "phone": "+70545848585"}
0005433009683	B9A81B	8251 560355	ANTON KUZMIN	{"email": "akuzmin1962@postgrespro.ru", "phone": "+70075634662"}
0005433009684	0248E7	5066 335656	ANATOLIY KUZNECOV	{"email": "kuznecov_a1961@postgrespro.ru", "phone": "+70099449133"}
0005433009685	7555CA	1628 850946	IRINA GORBUNOVA	{"email": "gorbunova-irina_1973@postgrespro.ru", "phone": "+70661790873"}
0005433009686	5CFDB9	9007 602935	VALENTINA ILINA	{"phone": "+70476847918"}
0005433009687	5CFDB9	2560 917221	SVETLANA EFIMOVA	{"phone": "+70753591929"}
0005433009688	5CFDB9	6032 390532	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr.22121958@postgrespro.ru", "phone": "+70916168569"}
0005433009980	D319C5	3986 398916	VIKTORIYA MAKAROVA	{"phone": "+70949173339"}
0005433009689	F87C8B	2844 737826	OLGA OVCHINNIKOVA	{"email": "ovchinnikova_o12011978@postgrespro.ru", "phone": "+70757809486"}
0005433009690	D11761	3535 719984	EVGENIY ANDREEV	{"phone": "+70114657029"}
0005433009691	D937E1	9591 768305	IVAN VOROBEV	{"email": "vorobev-ivan1971@postgrespro.ru", "phone": "+70275399374"}
0005433009692	DE1D71	9587 571430	SERGEY ZHUKOV	{"email": "zhukov-sergey_13081964@postgrespro.ru", "phone": "+70607743987"}
0005433009693	152593	6748 835456	VIKTOR VLASOV	{"email": "viktor.vlasov-1972@postgrespro.ru", "phone": "+70877636970"}
0005433009694	5DBE18	8281 870671	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_v_1971@postgrespro.ru", "phone": "+70919053425"}
0005433009695	E60B2D	8372 129118	VIKTORIYA OVCHINNIKOVA	{"phone": "+70450815025"}
0005433009696	CCE3BF	7154 771863	IVAN MELNIKOV	{"email": "melnikov_ivan.121972@postgrespro.ru", "phone": "+70977373345"}
0005433009697	E6D5FD	3585 337783	ALEKSEY MEDVEDEV	{"phone": "+70260551863"}
0005433009698	664B7F	9675 316897	MAKSIM ALEKSEEV	{"phone": "+70841428757"}
0005433009699	664B7F	3989 125605	VLADIMIR EGOROV	{"email": "v.egorov.26011964@postgrespro.ru", "phone": "+70576765138"}
0005433009700	F17AE2	9809 151164	LYUDMILA NOVIKOVA	{"phone": "+70601852423"}
0005433009701	AD31BC	6978 238028	VALERIY ZHURAVLEV	{"phone": "+70561822966"}
0005433009702	619E5C	8271 651357	ARTUR KUDRYASHOV	{"email": "kudryashov_a06031967@postgrespro.ru", "phone": "+70550515906"}
0005433009703	619E5C	5811 105712	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov011967@postgrespro.ru", "phone": "+70977836490"}
0005433009704	CDC733	2804 836934	ALEKSANDR FROLOV	{"email": "frolov-aleksandr.071980@postgrespro.ru", "phone": "+70747420228"}
0005433009705	F16341	6393 926509	VALENTINA PAVLOVA	{"email": "pavlova-valentina.1981@postgrespro.ru", "phone": "+70347226963"}
0005433009706	F16341	5406 890647	VALENTINA BORISOVA	{"phone": "+70130160094"}
0005433009707	4FAEE3	7962 748989	MARINA ILINA	{"email": "marina.ilina-26021977@postgrespro.ru", "phone": "+70021850761"}
0005433009708	4FAEE3	2893 127538	OLGA SIDOROVA	{"email": "o_sidorova_1965@postgrespro.ru", "phone": "+70422528527"}
0005433009709	8F0643	6334 234187	SERGEY NAZAROV	{"email": "nazarov-sergey-1986@postgrespro.ru", "phone": "+70438686889"}
0005433009710	8F0643	7535 660106	SERGEY SOROKIN	{"email": "sorokin_sergey1970@postgrespro.ru", "phone": "+70372965060"}
0005433009711	1AE87D	6958 851545	VLADIMIR ZAKHAROV	{"phone": "+70211984178"}
0005433009712	1AE87D	2196 576145	ANNA CHERNOVA	{"email": "chernova_anna_1977@postgrespro.ru", "phone": "+70759130761"}
0005433009713	0D8477	0276 992787	DMITRIY SOLOVEV	{"email": "dsolovev-1964@postgrespro.ru", "phone": "+70223719990"}
0005433009714	DDC1B6	4884 071825	TATYANA PETROVA	{"phone": "+70281676654"}
0005433009715	DDC1B6	2590 022373	VENERA SERGEEVA	{"phone": "+70976147616"}
0005433009716	1D8E63	4556 103925	VLADIMIR POPOV	{"email": "popov-v1977@postgrespro.ru", "phone": "+70040943950"}
0005433009717	985DE8	2048 841197	IVAN MOISEEV	{"phone": "+70478469764"}
0005433009718	457C28	5188 797989	OLEG NIKOLAEV	{"phone": "+70891725867"}
0005433009719	457C28	2664 217610	NINA CHERNOVA	{"email": "chernova-nina_27021968@postgrespro.ru", "phone": "+70794820916"}
0005433009720	457C28	4906 793581	LYUDMILA KISELEVA	{"email": "l-kiseleva121967@postgrespro.ru", "phone": "+70950572821"}
0005433009721	238A80	3312 578247	DANIIL VASILEV	{"email": "d.vasilev.28021968@postgrespro.ru", "phone": "+70318977305"}
0005433009722	06C30D	8281 477868	OLEG SEMENOV	{"email": "semenov-o-06091970@postgrespro.ru", "phone": "+70982931343"}
0005433009723	0A8BA9	5866 047142	ALEKSANDR KUZMIN	{"email": "kuzmin-a24021976@postgrespro.ru", "phone": "+70713082452"}
0005433009724	AFDF69	4752 153948	MIKHAIL FOMIN	{"phone": "+70324379272"}
0005433009725	D701C4	7654 995109	OLEG MATVEEV	{"email": "matveevoleg26101986@postgrespro.ru", "phone": "+70125934782"}
0005433009726	5921EB	2089 434166	VIKTOR MIRONOV	{"email": "vmironov.1980@postgrespro.ru", "phone": "+70873246706"}
0005433009727	BE6589	3569 241028	NATALYA ANDREEVA	{"email": "andreeva_natalya-05061982@postgrespro.ru", "phone": "+70478971741"}
0005433009728	796E38	2167 224480	OLGA VOLKOVA	{"phone": "+70440579238"}
0005433009729	796E38	3357 506693	ELENA MELNIKOVA	{"email": "melnikovaelena_07071976@postgrespro.ru", "phone": "+70741857992"}
0005433009730	A2623C	9932 409526	OLEG BARANOV	{"email": "baranov.o.20041976@postgrespro.ru", "phone": "+70288137639"}
0005433009731	B90C5B	0455 423598	YURIY MAKAROV	{"email": "ymakarov-081978@postgrespro.ru", "phone": "+70082279393"}
0005433009732	562ED7	3552 593410	MARAT ALEKSEEV	{"email": "malekseev-081961@postgrespro.ru", "phone": "+70603493738"}
0005433009733	5D561B	7329 355618	EVGENIYA MATVEEVA	{"email": "matveeva-evgeniya091975@postgrespro.ru", "phone": "+70622361056"}
0005433009734	BB4576	8749 535174	VERA MEDVEDEVA	{"phone": "+70776564112"}
0005433009735	BB4576	0747 714537	MARIYA PAVLOVA	{"phone": "+70329366606"}
0005433009736	7FB8D3	6450 858836	VALERIYA ROMANOVA	{"email": "romanova.v_07051980@postgrespro.ru", "phone": "+70305063923"}
0005433009737	5A878A	3655 751952	DENIS SEMENOV	{"email": "semenovdenis-1977@postgrespro.ru", "phone": "+70896636745"}
0005433009738	5A878A	3790 576494	OLGA KISELEVA	{"email": "kiseleva.olga.071973@postgrespro.ru", "phone": "+70955116212"}
0005433009739	958CBE	4212 971594	NATALYA STEPANOVA	{"email": "stepanova_natalya_31101969@postgrespro.ru", "phone": "+70981519393"}
0005433009740	2A4F2F	1319 183368	NATALYA NOVIKOVA	{"email": "n.novikova-111971@postgrespro.ru", "phone": "+70807334821"}
0005433009741	4D354F	1304 830450	EKATERINA MAKAROVA	{"email": "makarovaekaterina-021980@postgrespro.ru", "phone": "+70159328349"}
0005433009742	07FF84	1300 954552	DANIS ZHURAVLEV	{"email": "zhuravlevdanis.03031966@postgrespro.ru", "phone": "+70953117174"}
0005433009743	752A28	9223 242637	YULIYA IVANOVA	{"email": "yuliya.ivanova30111966@postgrespro.ru", "phone": "+70115440750"}
0005433009744	BA0C66	8132 460247	IRINA ANTONOVA	{"phone": "+70336130315"}
0005433009745	BA0C66	7989 541503	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov11021972@postgrespro.ru", "phone": "+70311247185"}
0005433009746	06063C	4896 495833	KRISTINA VASILEVA	{"email": "kristinavasileva-041971@postgrespro.ru", "phone": "+70684678135"}
0005433009747	7AC967	6184 004329	TATYANA PETROVA	{"email": "petrova_t.10061971@postgrespro.ru", "phone": "+70100423879"}
0005433009748	7D817B	1087 200867	ALEKSANDR FEDOROV	{"phone": "+70273977300"}
0005433009749	6CA4F5	6721 423060	ELENA SIDOROVA	{"phone": "+70963690175"}
0005433009750	6CA4F5	2677 681075	RAISA BELOVA	{"email": "belova.r.051972@postgrespro.ru", "phone": "+70872663518"}
0005433009751	353F9C	0932 999773	NINA BARANOVA	{"email": "n-baranova-10081970@postgrespro.ru", "phone": "+70445292033"}
0005433009752	353F9C	7717 732014	TATYANA BELYAEVA	{"email": "tatyana.belyaeva02081962@postgrespro.ru", "phone": "+70712552132"}
0005433009753	353F9C	1258 200863	PETR MIKHAYLOV	{"email": "mikhaylov-p_1980@postgrespro.ru", "phone": "+70106037548"}
0005433009754	14947C	2394 565542	ALEKSANDR IVANOV	{"phone": "+70796936184"}
0005433009755	74C91F	2781 244864	LYUBOV TIMOFEEVA	{"phone": "+70343035105"}
0005433009756	1FF5CA	2164 943355	NELLI SIDOROVA	{"phone": "+70666244332"}
0005433009757	1FF5CA	1414 389786	ANASTASIYA ILINA	{"email": "a.ilina26111981@postgrespro.ru", "phone": "+70151962958"}
0005433009758	B874FF	6085 008221	OKSANA SCHERBAKOVA	{"phone": "+70941195406"}
0005433009759	B874FF	4804 537916	ALEKSANDR ALEKSANDROV	{"email": "aleksandr.aleksandrov-051964@postgrespro.ru", "phone": "+70090798290"}
0005433009760	CD6580	4615 184533	DMITRIY KISELEV	{"email": "dkiselev_1968@postgrespro.ru", "phone": "+70921026236"}
0005433009761	CD6580	4396 891832	LYUBOV KOROLEVA	{"phone": "+70414402997"}
0005433009762	DB4772	3484 474359	ELENA FROLOVA	{"email": "frolova_elena_11071982@postgrespro.ru", "phone": "+70258214152"}
0005433009763	DB4772	6334 024207	SVETLANA MEDVEDEVA	{"phone": "+70660160244"}
0005433009764	E22353	4232 894999	ULYANA KUDRYASHOVA	{"phone": "+70887095447"}
0005433009765	E22353	5628 119408	EKATERINA NOVIKOVA	{"email": "novikova_ekaterina-1971@postgrespro.ru", "phone": "+70189519270"}
0005433009766	D95856	4507 292150	ALEKSANDR IVANOV	{"phone": "+70979921308"}
0005433009767	2390D4	2274 802398	ISLAM ALEKSANDROV	{"email": "islam.aleksandrov.071974@postgrespro.ru", "phone": "+70361599888"}
0005433009768	5A721E	7580 028744	MARAT EGOROV	{"phone": "+70483491610"}
0005433009769	ACF4A3	4737 057369	RAISA ORLOVA	{"email": "orlova.r_02061981@postgrespro.ru", "phone": "+70307801956"}
0005433009770	FFCA10	5446 274975	ANTONINA YUDINA	{"email": "yudinaantonina25061963@postgrespro.ru", "phone": "+70322836670"}
0005433009771	0948AB	8191 556205	VITALIY SOLOVEV	{"phone": "+70085280429"}
0005433009772	0BE501	5116 451581	LYUDMILA MAKAROVA	{"email": "lyudmila.makarova.07011958@postgrespro.ru", "phone": "+70231633624"}
0005433009773	8AFAB9	3852 381554	ALEKSEY ALEKSEEV	{"email": "alekseev.aleksey.081977@postgrespro.ru", "phone": "+70596777573"}
0005433009774	2BAB58	5683 518000	VASILISA TIKHONOVA	{"email": "v_tikhonova_1966@postgrespro.ru", "phone": "+70002626901"}
0005433009775	3ED415	3154 930747	ZINAIDA KUZNECOVA	{"email": "zinaidakuznecova-091967@postgrespro.ru", "phone": "+70025525679"}
0005433009776	3ED415	9968 526346	NIKOLAY SOLOVEV	{"email": "solovev-nikolay_041978@postgrespro.ru", "phone": "+70443788262"}
0005433009777	B34838	5665 029607	NIKOLAY FROLOV	{"phone": "+70059910146"}
0005433009778	B34838	3701 839084	EKATERINA BORISOVA	{"email": "e-borisova.051975@postgrespro.ru", "phone": "+70794257027"}
0005433009779	B34838	4330 953435	MIKHAIL SEMENOV	{"phone": "+70319419710"}
0005433009780	823529	2591 456682	TAMARA ANDREEVA	{"email": "andreeva_t.1965@postgrespro.ru", "phone": "+70755941137"}
0005433009781	DA85C9	5110 963795	ANNA MALYSHEVA	{"email": "annamalysheva.021985@postgrespro.ru", "phone": "+70202293215"}
0005433009782	FE77A9	3405 038979	NINA SMIRNOVA	{"email": "n-smirnova.101977@postgrespro.ru", "phone": "+70772188988"}
0005433009783	FE77A9	7711 824364	ALEKSANDRA DENISOVA	{"phone": "+70314751128"}
0005433009784	A5584E	1974 672082	SERGEY VOLKOV	{"phone": "+70658388324"}
0005433009785	A5584E	2147 703483	PAVEL SOKOLOV	{"email": "p.sokolov_06121974@postgrespro.ru", "phone": "+70200143479"}
0005433009786	60252F	1571 800178	VYACHESLAV PETROV	{"phone": "+70966270020"}
0005433009787	60252F	5808 116425	DIANA KOVALEVA	{"phone": "+70590236682"}
0005433009788	1BF011	8026 291151	TAMARA KONDRATEVA	{"email": "tamara.kondrateva-051972@postgrespro.ru", "phone": "+70297846023"}
0005433009789	1BF011	5999 494549	DMITRIY SHEVCHENKO	{"phone": "+70215014523"}
0005433009790	2322D9	5194 235356	IGOR GERASIMOV	{"email": "igorgerasimov021985@postgrespro.ru", "phone": "+70913815957"}
0005433009791	2322D9	9175 553251	ANDREY ROMANOV	{"email": "a-romanov_1972@postgrespro.ru", "phone": "+70780234928"}
0005433009792	986E36	0810 064812	MARINA BORISOVA	{"email": "marinaborisova1970@postgrespro.ru", "phone": "+70542432096"}
0005433009793	986E36	7662 636526	EKATERINA MOROZOVA	{"email": "e-morozova111979@postgrespro.ru", "phone": "+70712700663"}
0005433009794	5BB9B2	8517 528041	ROMAN NIKITIN	{"phone": "+70447338102"}
0005433009795	801BF2	6602 496475	MARINA DAVYDOVA	{"phone": "+70351704122"}
0005433009796	028B18	5491 332236	VLADISLAV VASILEV	{"email": "vasilev.vladislav.091963@postgrespro.ru", "phone": "+70745782508"}
0005433009797	C9557C	5393 385914	ALEKSANDR GERASIMOV	{"phone": "+70903018137"}
0005433009798	B58D5A	6186 217813	LYUBOV ILINA	{"phone": "+70362839229"}
0005433009799	6DB930	7554 430414	EVGENIY ANDREEV	{"phone": "+70329042219"}
0005433009800	539476	8483 373544	GEORGIY DMITRIEV	{"email": "dmitriev-g.22081983@postgrespro.ru", "phone": "+70004361208"}
0005433009801	539476	4850 791636	IRINA FROLOVA	{"email": "ifrolova_091972@postgrespro.ru", "phone": "+70365538582"}
0005433009802	9C0248	8101 419115	ANNA KONOVALOVA	{"email": "anna_konovalova121977@postgrespro.ru", "phone": "+70575272549"}
0005433009803	5CD552	5939 756526	SERGEY SOLOVEV	{"email": "sergeysolovev1974@postgrespro.ru", "phone": "+70272441996"}
0005433009804	5CD552	8159 753940	LIDIYA VLASOVA	{"phone": "+70862202473"}
0005433009805	5CD552	1175 690094	YURIY VASILEV	{"email": "y_vasilev-011978@postgrespro.ru", "phone": "+70445260783"}
0005433009806	EE64A8	2660 405628	ILYA KUZNECOV	{"phone": "+70116464859"}
0005433009807	EE64A8	8029 418183	RAISA GAVRILOVA	{"email": "gavrilova-raisa_09081964@postgrespro.ru", "phone": "+70577616533"}
0005433009808	AEEB08	7568 337279	OKSANA SOKOLOVA	{"email": "osokolova081978@postgrespro.ru", "phone": "+70695569205"}
0005433009809	AEEB08	4162 204324	KSENIYA SERGEEVA	{"email": "ksergeeva.20041964@postgrespro.ru", "phone": "+70407559397"}
0005433009810	2B8CC9	9390 062272	VASILIY TARASOV	{"email": "vasiliy_tarasov_17061964@postgrespro.ru", "phone": "+70309629759"}
0005433009811	20162E	9501 262037	SVETLANA LAZAREVA	{"email": "lazareva-s16041969@postgrespro.ru", "phone": "+70841058793"}
0005433009812	CB5812	1864 873504	EVGENIY AFANASEV	{"email": "afanasev_evgeniy-031978@postgrespro.ru", "phone": "+70938345695"}
0005433009813	3839AE	6747 816928	ANDREY SERGEEV	{"email": "sergeev_a_01021976@postgrespro.ru", "phone": "+70864347901"}
0005433009814	B81F05	3502 915128	TATYANA OSIPOVA	{"email": "tosipova_15031973@postgrespro.ru", "phone": "+70011387622"}
0005433009815	10F872	9361 696201	VYACHESLAV BONDARENKO	{"email": "bondarenko-vyacheslav1967@postgrespro.ru", "phone": "+70999776009"}
0005433009816	10F872	5628 097831	TAMARA MIKHAYLOVA	{"email": "mikhaylova_tamara-1972@postgrespro.ru", "phone": "+70476382929"}
0005433009817	B446B8	3762 944472	EKATERINA NIKITINA	{"email": "nikitina.e-29011963@postgrespro.ru", "phone": "+70984433503"}
0005433009818	7F5783	6614 021094	ALEKSEY FEDOTOV	{"phone": "+70451603603"}
0005433009819	7F5783	9583 931456	LYUBOV ISAEVA	{"email": "isaevalyubov.03021963@postgrespro.ru", "phone": "+70927409215"}
0005433009820	9768F2	3289 585240	ALEKSANDR MIKHAYLOV	{"phone": "+70773397658"}
0005433009821	7DF96A	2262 672017	RAMILYA ARKHIPOVA	{"email": "ramilya_arkhipova_1989@postgrespro.ru", "phone": "+70442308872"}
0005433009822	D9753D	7849 895242	ALEKSANDRA POTAPOVA	{"email": "a-potapova_051962@postgrespro.ru", "phone": "+70302764831"}
0005433009823	AE366B	3041 589498	NATALYA OVCHINNIKOVA	{"phone": "+70362638515"}
0005433009824	B48A80	0498 771544	MARAT KOZLOV	{"email": "mkozlov-20071978@postgrespro.ru", "phone": "+70655096232"}
0005433009825	10BD74	6365 775731	DMITRIY PAVLOV	{"phone": "+70709303285"}
0005433009826	10BD74	1804 532174	SERGEY IVANOV	{"phone": "+70973713156"}
0005433009827	A28ED5	5165 464741	MAKAR IVANOV	{"email": "ivanov-makar1976@postgrespro.ru", "phone": "+70753422896"}
0005433009828	1FF3DA	6526 580023	MARIYA CHERNOVA	{"phone": "+70694762305"}
0005433009829	1FF3DA	2771 067361	VLADIMIR BARANOV	{"email": "v-baranov.1976@postgrespro.ru", "phone": "+70127669610"}
0005433009830	82DD11	0970 007794	ELIZAVETA GERASIMOVA	{"email": "gerasimova-elizaveta-1979@postgrespro.ru", "phone": "+70601150224"}
0005433009831	97B803	5107 207165	ANTON NIKOLAEV	{"phone": "+70922842103"}
0005433009832	A4B5DA	4035 598565	ANASTASIYA LAZAREVA	{"phone": "+70464744525"}
0005433009833	78E77A	9155 623151	VLADIMIR KISELEV	{"phone": "+70454704982"}
0005433009834	898BCD	5503 990446	ARSENIY ABRAMOV	{"phone": "+70479715575"}
0005433009835	2FF3CE	1445 827634	SERGEY ALEKSEEV	{"email": "s.alekseev.26081975@postgrespro.ru", "phone": "+70172247789"}
0005433009836	2FF3CE	7158 041032	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov.011965@postgrespro.ru", "phone": "+70777283597"}
0005433009837	67D88C	7834 192648	VASILIY SAVELEV	{"phone": "+70466104508"}
0005433009838	67D88C	1130 032969	VIKTOR TARASOV	{"email": "v_tarasov-01011964@postgrespro.ru", "phone": "+70312794534"}
0005433009839	4C69B6	5506 921296	TATYANA MARTYNOVA	{"phone": "+70380957310"}
0005433009840	5CC223	9697 780762	EVGENIY ROMANOV	{"phone": "+70133570411"}
0005433009841	1EFD86	8512 373443	NINA KOVALEVA	{"email": "kovalevan-1959@postgrespro.ru", "phone": "+70467886847"}
0005433009842	B4F84B	2057 179465	RAMIL ZAKHAROV	{"phone": "+70217898907"}
0005433009843	B4F84B	1960 674227	VLADIMIR ORLOV	{"phone": "+70531074484"}
0005433009844	6CABC3	2878 982412	KSENIYA TARASOVA	{"email": "k.tarasova-081971@postgrespro.ru", "phone": "+70676158334"}
0005433009845	11E7B2	5915 701308	GALINA ZAKHAROVA	{"email": "zakharova.galina_061977@postgrespro.ru", "phone": "+70603051984"}
0005433009846	11E7B2	2921 147418	NATALIYA MATVEEVA	{"phone": "+70014454903"}
0005433009847	11E7B2	0812 777563	VERA ERMAKOVA	{"phone": "+70496211055"}
0005433009848	F42635	9793 910900	VIKTOR ALEKSANDROV	{"email": "aleksandrov_v-1971@postgrespro.ru", "phone": "+70392104063"}
0005433009849	0E1D8F	9477 037293	VALENTINA VOLKOVA	{"phone": "+70654966590"}
0005433009850	0E1D8F	4860 769399	IRINA IVANOVA	{"email": "irinaivanova.031978@postgrespro.ru", "phone": "+70682344369"}
0005433009851	3A1C91	4589 953817	SERGEY ANDREEV	{"email": "sandreev.20081972@postgrespro.ru", "phone": "+70189821366"}
0005433009852	3A1C91	0827 390526	VIKTOR VASILEV	{"phone": "+70901943228"}
0005433009853	19FC5C	1818 305731	IRINA KOROLEVA	{"email": "i_koroleva-081969@postgrespro.ru", "phone": "+70572231364"}
0005433009854	78021B	1766 496558	ALINA STEPANOVA	{"email": "alina-stepanova-101973@postgrespro.ru", "phone": "+70640658060"}
0005433009855	9FB835	9352 098041	ALEKSEY VOLKOV	{"phone": "+70912864141"}
0005433009856	FC2C56	5294 551343	SVETLANA MASLOVA	{"phone": "+70079607869"}
0005433009857	5EECBC	0815 570310	KIRILL NIKOLAEV	{"email": "nikolaevk.1966@postgrespro.ru", "phone": "+70274936750"}
0005433009858	AF6110	9693 777465	ANASTASIYA MAKAROVA	{"email": "a.makarova_1973@postgrespro.ru", "phone": "+70814607240"}
0005433009859	3ED642	2621 604631	LIDIYA ROMANOVA	{"phone": "+70663934755"}
0005433009860	93AB3D	7407 255739	NADEZHDA MOISEEVA	{"phone": "+70135655743"}
0005433009861	93AB3D	7240 606417	MARIYA PAVLOVA	{"phone": "+70411232763"}
0005433009862	679DBA	8769 214036	ELENA DAVYDOVA	{"email": "davydova.e_041963@postgrespro.ru", "phone": "+70955933623"}
0005433009863	679DBA	2294 986275	ANATOLIY KOROLEV	{"phone": "+70550387827"}
0005433009864	679DBA	1813 868163	VLADIMIR NAUMOV	{"email": "naumov.v-1971@postgrespro.ru", "phone": "+70605640506"}
0005433009865	D96572	6045 255401	VLADIMIR MOROZOV	{"email": "vmorozov-09051976@postgrespro.ru", "phone": "+70664101230"}
0005433009866	FF4182	4376 395533	ALEKSANDRA VASILEVA	{"phone": "+70218686427"}
0005433009867	7F3653	5433 225504	FARIT NIKITIN	{"email": "farit_nikitin1978@postgrespro.ru", "phone": "+70593050978"}
0005433009868	7F3653	8870 547442	VLADIMIR FROLOV	{"email": "vladimirfrolov_031967@postgrespro.ru", "phone": "+70679633429"}
0005433009869	0C126E	8657 291931	ARTEM STEPANOV	{"email": "artemstepanov.1974@postgrespro.ru", "phone": "+70247790458"}
0005433009870	0C126E	3143 754300	VLADIMIR SEMENOV	{"phone": "+70576731174"}
0005433009871	1700E7	1965 610927	GENNADIY IVANOV	{"email": "ivanov.gennadiy-26041971@postgrespro.ru", "phone": "+70971528755"}
0005433009872	8EE888	4605 594625	NINA KISELEVA	{"phone": "+70986269081"}
0005433009873	8EE888	2530 436257	LYUDMILA POPOVA	{"phone": "+70518414047"}
0005433009874	FFDCCB	3872 724660	MARIYA VOROBEVA	{"email": "mvorobeva1977@postgrespro.ru", "phone": "+70492914856"}
0005433009875	AA9177	8629 524283	OKSANA AFANASEVA	{"email": "afanasevao_1977@postgrespro.ru", "phone": "+70593236840"}
0005433009876	236BF1	8694 174972	SVETLANA ZAYCEVA	{"email": "zayceva.s_16101976@postgrespro.ru", "phone": "+70781942322"}
0005433009877	5AF76B	1834 350436	MAYYA PAVLOVA	{"email": "m-pavlova_14121967@postgrespro.ru", "phone": "+70486286120"}
0005433009878	96AB10	8369 726089	OLGA SOLOVEVA	{"email": "olgasoloveva.1977@postgrespro.ru", "phone": "+70287915083"}
0005433009879	A57DCC	3218 858472	OLGA GERASIMOVA	{"email": "o-gerasimova.30121976@postgrespro.ru", "phone": "+70809761324"}
0005433009880	A57DCC	9399 907014	DENIS MEDVEDEV	{"phone": "+70075475951"}
0005433009881	A57DCC	9144 491931	IRINA SEMENOVA	{"phone": "+70038609774"}
0005433009882	B617D1	8294 394556	EVGENIY MEDVEDEV	{"email": "evgeniymedvedev.1978@postgrespro.ru", "phone": "+70561549691"}
0005433009883	D7E954	6460 701496	VALERIYA ZOTOVA	{"email": "zotova.valeriya1960@postgrespro.ru", "phone": "+70626185060"}
0005433009884	54DFAD	2640 511346	YURIY ZHUKOV	{"email": "yuriyzhukov23071971@postgrespro.ru", "phone": "+70680571146"}
0005433009885	74ECB4	9567 881606	NATALIYA FOMINA	{"phone": "+70237880451"}
0005433009886	74ECB4	2571 989498	YULIYA NIKITINA	{"email": "nikitina.y.08031981@postgrespro.ru", "phone": "+70462175419"}
0005433009887	74ECB4	9129 053132	GENNADIY KUZMIN	{"phone": "+70920184458"}
0005433009888	74ECB4	4960 685164	NIKITA ISAEV	{"phone": "+70454497042"}
0005433009889	76CFC0	8077 527729	NADEZHDA KUDRYASHOVA	{"email": "kudryashovan1971@postgrespro.ru", "phone": "+70768036094"}
0005433009890	685BBE	2431 120644	ALEKSEY KUZNECOV	{"email": "a-kuznecov-071964@postgrespro.ru", "phone": "+70159361165"}
0005433009891	E044A6	3307 352434	EKATERINA NAZAROVA	{"phone": "+70542484798"}
0005433009892	E044A6	2233 455866	SERGEY ILIN	{"email": "ilin_sergey-1968@postgrespro.ru", "phone": "+70476169728"}
0005433009893	111BCF	8334 976843	TATYANA MOROZOVA	{"email": "morozova-tatyana_1977@postgrespro.ru", "phone": "+70564070541"}
0005433009894	111BCF	9836 457863	VLADIMIR DAVYDOV	{"email": "davydovvladimir1965@postgrespro.ru", "phone": "+70219399568"}
0005433009895	33641F	0892 257219	NATALYA CHERNOVA	{"phone": "+70111328882"}
0005433009896	AA207C	4811 903351	ANDREY VOLKOV	{"email": "volkov_a.1982@postgrespro.ru", "phone": "+70534995226"}
0005433009897	01576A	6879 782845	SERGEY POPOV	{"email": "popovs_121968@postgrespro.ru", "phone": "+70210562724"}
0005433009898	01576A	0064 215270	ANTONINA TARASOVA	{"email": "tarasova-a.071977@postgrespro.ru", "phone": "+70737473497"}
0005433009899	66C281	8100 998880	VALENTINA SMIRNOVA	{"email": "valentina.smirnova-031979@postgrespro.ru", "phone": "+70319790645"}
0005433009900	D534C8	4338 630857	ELENA DANILOVA	{"phone": "+70989038945"}
0005433009901	366B11	0722 207290	YURIY KRASNOV	{"phone": "+70458836516"}
0005433009902	366B11	6595 765920	ELENA GORBUNOVA	{"email": "elena-gorbunova.1980@postgrespro.ru", "phone": "+70864008844"}
0005433009903	FFD230	8197 493512	DMITRIY NIKOLAEV	{"email": "d_nikolaev16051974@postgrespro.ru", "phone": "+70284956281"}
0005433009904	737873	4489 007595	VALERIY MOISEEV	{"phone": "+70342434333"}
0005433009905	737873	8571 104457	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr.111966@postgrespro.ru", "phone": "+70358114825"}
0005433009906	052CC0	1983 659278	GALINA EGOROVA	{"phone": "+70615336948"}
0005433009907	DD074B	2982 454463	MIKHAIL MATVEEV	{"email": "matveevmikhail.17041965@postgrespro.ru", "phone": "+70531303368"}
0005433009908	DD074B	7230 115091	DMITRIY EGOROV	{"email": "d-egorov_02111958@postgrespro.ru", "phone": "+70637115861"}
0005433009909	F1B876	7682 968623	GALINA FEDOROVA	{"email": "fedorovag-091973@postgrespro.ru", "phone": "+70671653893"}
0005433009910	F1B876	1374 185635	ROMAN YAKOVLEV	{"email": "roman-yakovlev.071976@postgrespro.ru", "phone": "+70468227292"}
0005433009911	5422EB	8525 069998	EVGENIY KUZMIN	{"email": "e_kuzmin_14111962@postgrespro.ru", "phone": "+70302139694"}
0005433009912	3321DD	2609 125081	VASILIY DENISOV	{"email": "denisovvasiliy12061978@postgrespro.ru", "phone": "+70987360495"}
0005433009913	3321DD	1665 852861	IRINA AKIMOVA	{"email": "akimova-irina-1972@postgrespro.ru", "phone": "+70675037073"}
0005433009914	B7FDE4	0286 120253	ZINAIDA EGOROVA	{"phone": "+70530861107"}
0005433009915	B7FDE4	6408 762318	VLADIMIR IVANOV	{"phone": "+70662605956"}
0005433009916	B7FDE4	5301 265692	ELENA BORISOVA	{"phone": "+70730789410"}
0005433009917	5BE82B	4014 441722	MIKHAIL ANTONOV	{"phone": "+70772547322"}
0005433009918	5BE82B	1757 561172	EVGENIYA KUDRYASHOVA	{"phone": "+70223076059"}
0005433009919	8F0C67	0407 669927	ANASTASIYA KUZNECOVA	{"phone": "+70131330862"}
0005433009920	8F0C67	9339 597903	VALENTIN SMIRNOV	{"email": "vsmirnov_101958@postgrespro.ru", "phone": "+70198868163"}
0005433009921	F2DB1F	7338 882363	OLGA ROMANOVA	{"phone": "+70449191697"}
0005433035471	BD6587	4681 321367	SVETLANA POLYAKOVA	{"phone": "+70392089928"}
0005433009922	5BF8A8	9208 636920	VALENTINA ROMANOVA	{"email": "romanova-v-05121967@postgrespro.ru", "phone": "+70859422873"}
0005433009923	282917	0040 033358	NATALYA VASILEVA	{"phone": "+70894665721"}
0005433009924	C7743A	3807 000738	NADEZHDA KOROLEVA	{"email": "koroleva_n-081974@postgrespro.ru", "phone": "+70541202083"}
0005433009925	3E5E73	8616 989495	VALENTINA MASLOVA	{"email": "maslova_v.09101979@postgrespro.ru", "phone": "+70118259939"}
0005433009926	BC8FF2	4110 085615	MARIYA TIKHONOVA	{"email": "tikhonovam1977@postgrespro.ru", "phone": "+70229735657"}
0005433009927	6BDE96	7790 854916	NIKOLAY NAZAROV	{"email": "nazarov_nikolay081964@postgrespro.ru", "phone": "+70863821751"}
0005433009928	6BDE96	3634 847003	ALEKSANDR RODIONOV	{"phone": "+70969871151"}
0005433009929	73E11B	6834 152528	ANASTASIYA ERMAKOVA	{"email": "a.ermakova_031964@postgrespro.ru", "phone": "+70702933911"}
0005433009930	73E11B	7759 882894	EKATERINA KAZAKOVA	{"email": "ekaterina_kazakova_1971@postgrespro.ru", "phone": "+70034752879"}
0005433009931	61520C	8624 364739	ELENA SEMENOVA	{"email": "semenova.e_071982@postgrespro.ru", "phone": "+70430324696"}
0005433009932	765242	7798 661556	MATVEY POPOV	{"email": "m-popov16041977@postgrespro.ru", "phone": "+70158374976"}
0005433009933	6618A4	9038 361033	VALENTINA BELOVA	{"email": "belova_v_1982@postgrespro.ru", "phone": "+70315908933"}
0005433009934	6618A4	4995 277212	ROMAN BORISOV	{"phone": "+70493465781"}
0005433009935	3ACDDB	7083 994050	OKSANA IVANOVA	{"email": "o_ivanova.1977@postgrespro.ru", "phone": "+70455276466"}
0005433009936	3ACDDB	9566 726909	ELENA ANDREEVA	{"phone": "+70064995153"}
0005433009937	03B554	3850 484851	NATALYA LUKYANOVA	{"phone": "+70501466568"}
0005433009938	41489F	4507 006728	VLADIMIR SOKOLOV	{"phone": "+70499668191"}
0005433009939	C37815	2630 521802	EKATERINA BELOVA	{"email": "e_belova.1982@postgrespro.ru", "phone": "+70524426177"}
0005433009940	357E24	1290 937507	ANDREY KUZNECOV	{"phone": "+70344986033"}
0005433009941	EF69B9	9089 376354	ARINA MAKSIMOVA	{"email": "a-maksimova-05061960@postgrespro.ru", "phone": "+70357889328"}
0005433009942	EF69B9	5945 552959	ANNA LUKYANOVA	{"email": "alukyanova.05011959@postgrespro.ru", "phone": "+70817214248"}
0005433009943	962A35	1419 610194	VERA KOROLEVA	{"phone": "+70706394359"}
0005433009944	962A35	9610 559032	KIRILL SEMENOV	{"email": "semenov.kirill13021969@postgrespro.ru", "phone": "+70345978150"}
0005433009945	DE81D5	3053 522792	NIKOLAY MARTYNOV	{"email": "martynov.n-1972@postgrespro.ru", "phone": "+70169152480"}
0005433009946	DE81D5	7766 932199	PELAGEYA DANILOVA	{"phone": "+70810064167"}
0005433009947	96CD67	5442 888976	ALBERT PETROV	{"phone": "+70879288034"}
0005433009948	96CD67	0995 367742	GEORGIY SHEVCHENKO	{"email": "shevchenko-georgiy_031972@postgrespro.ru", "phone": "+70283026063"}
0005433009949	134300	1927 020874	VALENTINA POLYAKOVA	{"email": "vpolyakova_121972@postgrespro.ru", "phone": "+70105576560"}
0005433009950	CF66D9	4675 214886	ARTEM ISAEV	{"email": "a-isaev-071962@postgrespro.ru", "phone": "+70115323574"}
0005433009951	60C98E	3342 220954	EKATERINA MATVEEVA	{"email": "matveeva-ekaterina-091976@postgrespro.ru", "phone": "+70626707581"}
0005433009952	4A1779	3156 050820	DMITRIY RODIONOV	{"phone": "+70151068113"}
0005433009953	4A1779	6279 225157	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr.031972@postgrespro.ru", "phone": "+70152527771"}
0005433009954	39687B	4975 807305	EVGENIY SIDOROV	{"email": "e.sidorov14011983@postgrespro.ru", "phone": "+70180171938"}
0005433009955	15F53E	5689 587926	VLADIMIR KULIKOV	{"email": "kulikovv.22061966@postgrespro.ru", "phone": "+70959224725"}
0005433009956	D0BF00	4188 317520	ELENA KULIKOVA	{"email": "kulikova-elena_16011974@postgrespro.ru", "phone": "+70810716016"}
0005433009957	D0BF00	4364 466556	NADEZHDA KUDRYASHOVA	{"phone": "+70935940232"}
0005433009958	350EC4	3992 610372	ALEKSANDR ROMANOV	{"email": "a-romanov_06061977@postgrespro.ru", "phone": "+70533982364"}
0005433009959	350EC4	2816 910707	EKATERINA KUZMINA	{"email": "kuzmina-e_1964@postgrespro.ru", "phone": "+70560157807"}
0005433009960	350EC4	3872 564573	VYACHESLAV IVANOV	{"phone": "+70168413576"}
0005433009961	8DAA4F	3764 439212	STANISLAV POPOV	{"phone": "+70268278346"}
0005433009962	03DE87	7592 853846	YULIYA PETROVA	{"email": "petrovay_031973@postgrespro.ru", "phone": "+70797903229"}
0005433009963	03DE87	6710 037005	FARID TARASOV	{"phone": "+70092179145"}
0005433009964	297CA9	7440 797688	TATYANA MOROZOVA	{"email": "tatyana-morozova1965@postgrespro.ru", "phone": "+70460518535"}
0005433009965	4A2AF1	9733 396682	VIKTOR MEDVEDEV	{"phone": "+70751230348"}
0005433009966	2F62CA	8339 811748	GALIYA NAZAROVA	{"phone": "+70666190994"}
0005433009967	04CAE0	6669 270523	IGOR KARPOV	{"phone": "+70059766595"}
0005433009968	81E3FF	7494 001046	MARAT FROLOV	{"phone": "+70028180959"}
0005433009969	C828DE	0172 071050	ARTEM DMITRIEV	{"email": "artemdmitriev.28021982@postgrespro.ru", "phone": "+70239098331"}
0005433009970	C828DE	6867 217211	ALEKSEY NOVIKOV	{"phone": "+70338503553"}
0005433009971	6BD42F	6100 656365	MATVEY GAVRILOV	{"email": "m_gavrilov27051979@postgrespro.ru", "phone": "+70949486567"}
0005433009972	6BD42F	3837 084005	DMITRIY KUZMIN	{"phone": "+70864679476"}
0005433009973	6F5B65	1850 723390	VALENTINA CHERNOVA	{"email": "chernova_valentina_04061962@postgrespro.ru", "phone": "+70067082095"}
0005433009974	6F5B65	1730 602405	SERGEY KRASNOV	{"email": "s.krasnov-121973@postgrespro.ru", "phone": "+70135323229"}
0005433009975	6F5B65	5392 511814	DIANA SAVELEVA	{"email": "dianasaveleva.1976@postgrespro.ru", "phone": "+70899782885"}
0005433009976	0C442B	8012 665662	IRINA DENISOVA	{"email": "denisovai_081963@postgrespro.ru", "phone": "+70675789308"}
0005433009977	679B15	1914 441695	DMITRIY DENISOV	{"email": "dmitriydenisov22071968@postgrespro.ru", "phone": "+70345985553"}
0005433009978	D319C5	4587 510745	OLGA MAKAROVA	{"email": "makarova-olga06091964@postgrespro.ru", "phone": "+70705147409"}
0005433009979	D319C5	0829 965700	VALENTINA DAVYDOVA	{"email": "valentinadavydova.1984@postgrespro.ru", "phone": "+70770773067"}
0005433009981	76E50A	1256 113182	ANNA ZHUKOVA	{"email": "azhukova_1964@postgrespro.ru", "phone": "+70774218605"}
0005433009982	5FCBC7	5049 513943	ALEKSANDR BELOV	{"phone": "+70450379902"}
0005433009983	5FCBC7	9026 917397	NATALYA PAVLOVA	{"phone": "+70593664399"}
0005433035490	D8D252	0180 381451	NINA TITOVA	{"phone": "+70413376558"}
0005433035356	19AAD9	8429 377973	SERGEY ANDREEV	{"email": "andreev-sergey-05101978@postgrespro.ru", "phone": "+70151179452"}
0005433035357	19AAD9	6204 974731	LYUDMILA KUZNECOVA	{"email": "lkuznecova-051991@postgrespro.ru", "phone": "+70249864046"}
0005433035358	4557A4	2394 254274	EKATERINA MARTYNOVA	{"email": "emartynova_1973@postgrespro.ru", "phone": "+70436585850"}
0005433035359	E6F9D9	6151 332542	SERGEY FROLOV	{"email": "sergeyfrolov031980@postgrespro.ru", "phone": "+70710728983"}
0005433035360	E6F9D9	0721 777396	TATYANA NIKOLAEVA	{"email": "nikolaeva-t.1970@postgrespro.ru", "phone": "+70152045526"}
0005433035361	111C38	6422 400092	OLGA MATVEEVA	{"email": "matveeva.o.1988@postgrespro.ru", "phone": "+70354473898"}
0005433035362	20AD4E	8487 448020	ALEKSEY STEPANOV	{"phone": "+70378376282"}
0005433035363	4E56EA	7757 252657	VASILIY MATVEEV	{"email": "v.matveev-05021970@postgrespro.ru", "phone": "+70974771470"}
0005433035364	C7C90A	7736 573611	VIKTOR ORLOV	{"email": "viktor-orlov1959@postgrespro.ru", "phone": "+70017122396"}
0005433035365	3C797B	1750 710488	VALERIY MOROZOV	{"email": "morozov_valeriy.1988@postgrespro.ru", "phone": "+70933484895"}
0005433035366	3C797B	8057 585679	STEPAN ORLOV	{"phone": "+70810709029"}
0005433035367	332D30	6942 748165	MIKHAIL ABRAMOV	{"email": "m-abramov_1982@postgrespro.ru", "phone": "+70992862157"}
0005433035368	2A4331	8638 430580	NATALYA ORLOVA	{"email": "norlova09091968@postgrespro.ru", "phone": "+70710289955"}
0005433035369	3674E1	1335 350226	ZOYA VOROBEVA	{"phone": "+70687962729"}
0005433035370	3674E1	7890 099895	NIKITA IVANOV	{"email": "ivanov.n_26041975@postgrespro.ru", "phone": "+70803991489"}
0005433035371	3674E1	5475 636696	NIKOLAY NAZAROV	{"email": "n_nazarov-1980@postgrespro.ru", "phone": "+70250522261"}
0005433035372	1FE1CD	1949 307857	IVAN ORLOV	{"email": "orlovivan-25041967@postgrespro.ru", "phone": "+70192120631"}
0005433035373	9818FA	5865 506054	NINA SOLOVEVA	{"phone": "+70732070514"}
0005433035374	9818FA	0848 384548	ANATOLIY PETROV	{"email": "petrov-anatoliy07041982@postgrespro.ru", "phone": "+70175017418"}
0005433035375	72E305	8245 284511	SVETLANA KOVALEVA	{"phone": "+70181135071"}
0005433035376	76882A	6191 834402	NIKOLAY ZAYCEV	{"phone": "+70087726715"}
0005433035377	1D47C5	8061 233256	ANDREY DMITRIEV	{"phone": "+70379860028"}
0005433035378	DEAE1B	9816 062578	EKATERINA VASILEVA	{"phone": "+70236764480"}
0005433035379	D37C23	5564 126749	MAKSIM KOZLOV	{"email": "kozlov.maksim_1965@postgrespro.ru", "phone": "+70504330269"}
0005433035380	D37C23	1965 552623	NINA ERMAKOVA	{"phone": "+70446253198"}
0005433035381	83DB38	9558 766908	VLADIMIR NIKITIN	{"phone": "+70987350379"}
0005433035382	83DB38	4759 232890	IRINA MASLOVA	{"email": "irinamaslova_1976@postgrespro.ru", "phone": "+70009305890"}
0005433035383	E797F0	6059 087614	NATALYA MELNIKOVA	{"phone": "+70236027170"}
0005433035384	0B7DD4	1610 703619	ELIZAVETA ZAKHAROVA	{"email": "zakharova-e-041967@postgrespro.ru", "phone": "+70335582620"}
0005433035385	0F0DB8	9158 925552	ALEKSEY KULIKOV	{"email": "a.kulikov-26011965@postgrespro.ru", "phone": "+70319572955"}
0005433035386	9DE76C	9679 997115	OLESYA KARPOVA	{"phone": "+70030508847"}
0005433035387	9DE76C	3418 398746	PAVEL FEDOTOV	{"phone": "+70445940435"}
0005433035388	86AB5B	5126 844210	ANATOLIY SERGEEV	{"phone": "+70147150871"}
0005433035389	87B1C2	4066 857741	ALEKSANDR KAZAKOV	{"email": "kazakov.aleksandr_02081976@postgrespro.ru", "phone": "+70889920535"}
0005433035390	87B1C2	2892 407496	MARYAM MAKAROVA	{"phone": "+70848025034"}
0005433035391	87B1C2	8011 997023	ANNA GUSEVA	{"email": "anna_guseva.14101970@postgrespro.ru", "phone": "+70135008487"}
0005433035392	7E52D5	4696 881773	GALINA NOVIKOVA	{"email": "g_novikova-27041973@postgrespro.ru", "phone": "+70075128782"}
0005433035393	1A37A1	3542 857648	NIKOLAY VASILEV	{"email": "vasilev_n091974@postgrespro.ru", "phone": "+70057813566"}
0005433035394	17474E	7435 023988	RASHIT GRIGOREV	{"email": "grigorev_rashit-05051974@postgrespro.ru", "phone": "+70550977986"}
0005433035395	D0861D	1680 250737	ALLA VOROBEVA	{"phone": "+70891517977"}
0005433035396	5C31BF	3352 511782	VITALIY KULIKOV	{"phone": "+70281626901"}
0005433035397	BAD1F9	1529 340644	IVAN EGOROV	{"phone": "+70642225690"}
0005433035398	E21A83	5309 912346	PAVEL GUSEV	{"phone": "+70904522078"}
0005433035399	8AF2AA	8189 407669	VYACHESLAV BORISOV	{"email": "borisov-vyacheslav.081965@postgrespro.ru", "phone": "+70075876916"}
0005433035400	FEA8EE	6434 882755	LIDIYA ALEKSANDROVA	{"email": "lidiya_aleksandrova-30081971@postgrespro.ru", "phone": "+70132063137"}
0005433035401	3E1BFF	9749 599555	YANA VOROBEVA	{"phone": "+70781695559"}
0005433035402	3B0FA5	3315 146990	NADEZHDA KAZAKOVA	{"phone": "+70675850153"}
0005433035403	3B0FA5	9470 533329	LARISA GRISHINA	{"email": "grishinal.24121979@postgrespro.ru", "phone": "+70591585471"}
0005433035404	277732	2851 136428	ZHANNA NAUMOVA	{"email": "naumovazhanna.1975@postgrespro.ru", "phone": "+70711305078"}
0005433035405	64903E	0138 341678	KRISTINA PAVLOVA	{"email": "kristinapavlova.1962@postgrespro.ru", "phone": "+70397292273"}
0005433035406	84A7A2	5887 740967	DARYA FILIPPOVA	{"phone": "+70459687707"}
0005433035407	84A7A2	4703 943514	OLGA ABRAMOVA	{"email": "abramova_olga19081971@postgrespro.ru", "phone": "+70081005979"}
0005433035408	8AE9A2	9585 765869	ANDREY MOROZOV	{"phone": "+70308860386"}
0005433035409	7AFA73	7963 989116	VIOLETTA ANTONOVA	{"phone": "+70529453301"}
0005433035410	7AFA73	9782 245424	DMITRIY MARTYNOV	{"phone": "+70407981222"}
0005433035411	A2D187	5349 526565	YURIY STEPANOV	{"email": "y-stepanov-21071972@postgrespro.ru", "phone": "+70567757825"}
0005433035412	AD682B	5474 157779	RAISA OSIPOVA	{"email": "rosipova22121976@postgrespro.ru", "phone": "+70243238480"}
0005433035413	6BC480	3531 064560	SERGEY ROMANOV	{"email": "s.romanov-30091975@postgrespro.ru", "phone": "+70524084397"}
0005433035414	6BC480	7093 632387	OLGA SIDOROVA	{"phone": "+70713996905"}
0005433035415	527BFB	4978 582518	GALINA IVANOVA	{"email": "givanova.071983@postgrespro.ru", "phone": "+70172010982"}
0005433035416	527BFB	6390 640542	IVAN KOZLOV	{"phone": "+70088167504"}
0005433035417	527BFB	7130 845668	AIDA NOVIKOVA	{"phone": "+70515212488"}
0005433035418	7A1917	1197 349366	KSENIYA SOKOLOVA	{"email": "kseniyasokolova1978@postgrespro.ru", "phone": "+70907415458"}
0005433035419	67543E	1213 513054	MAKSIM BONDARENKO	{"phone": "+70885227478"}
0005433035420	B902DF	0864 502464	VLADIMIR POPOV	{"phone": "+70901336748"}
0005433035421	120C50	1603 353445	ALEKSANDR VOLKOV	{"email": "aleksandrvolkov_1976@postgrespro.ru", "phone": "+70459928871"}
0005433035422	120C50	9024 424886	VALENTINA POTAPOVA	{"email": "valentina-potapova_1972@postgrespro.ru", "phone": "+70516312381"}
0005433035423	98BB36	4192 296564	VERA GORBUNOVA	{"email": "veragorbunova1968@postgrespro.ru", "phone": "+70137611302"}
0005433035424	410E53	5402 373408	ANGELINA PETROVA	{"phone": "+70475928084"}
0005433035425	FD0BD9	0663 359601	OLGA ANDREEVA	{"email": "andreeva.o.28091969@postgrespro.ru", "phone": "+70932812441"}
0005433035426	88B58A	8067 537151	KLAVDIYA FROLOVA	{"phone": "+70624866765"}
0005433035427	88B58A	2545 220292	ANASTASIYA NAUMOVA	{"phone": "+70749462945"}
0005433035428	41B641	4743 799723	PAVEL GRIGOREV	{"email": "pavel-grigorev061980@postgrespro.ru", "phone": "+70853197692"}
0005433035429	41B641	1208 100924	RADIK DAVYDOV	{"email": "radik.davydov_081966@postgrespro.ru", "phone": "+70151814667"}
0005433035430	91591D	6195 227046	MIKHAIL MAKSIMOV	{"email": "maksimovm021966@postgrespro.ru", "phone": "+70752972611"}
0005433035431	91591D	9962 474146	ALEKSEY PAVLOV	{"email": "a-pavlov22051975@postgrespro.ru", "phone": "+70358580527"}
0005433035432	17E53E	1619 237192	ANASTASIYA VASILEVA	{"email": "vasileva-a.1967@postgrespro.ru", "phone": "+70611642684"}
0005433035433	17E53E	4145 066985	LILIYA SIDOROVA	{"email": "liliya-sidorova.28031975@postgrespro.ru", "phone": "+70074733249"}
0005433035434	64B142	7104 830074	ANATOLIY NOVIKOV	{"phone": "+70660082181"}
0005433035435	592226	8291 621703	IGOR IVANOV	{"email": "iivanov.1981@postgrespro.ru", "phone": "+70364721959"}
0005433035436	7E11C3	5566 445993	NATALYA GORBUNOVA	{"phone": "+70648486000"}
0005433035437	4EE23C	0332 384746	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.051978@postgrespro.ru", "phone": "+70499150825"}
0005433035438	0A6B5A	1590 620259	OLGA VOROBEVA	{"phone": "+70190827749"}
0005433035439	C949B9	9871 008127	TAMARA MIRONOVA	{"phone": "+70092296381"}
0005433035440	5A4B83	2654 334746	LILIYA KUZNECOVA	{"phone": "+70114943894"}
0005433035441	5F69A2	1776 191154	INGA SIDOROVA	{"phone": "+70461779835"}
0005433035442	5F69A2	8775 913974	GALINA MIKHAYLOVA	{"phone": "+70927273429"}
0005433035443	E4B3A0	9025 209978	IVAN OSIPOV	{"email": "iosipov1979@postgrespro.ru", "phone": "+70945231207"}
0005433035444	E4B3A0	8640 660714	TATYANA ANTONOVA	{"email": "antonova_tatyana-30061976@postgrespro.ru", "phone": "+70223066433"}
0005433035445	5B5DCD	4655 098020	ANATOLIY KUZNECOV	{"email": "a-kuznecov-111974@postgrespro.ru", "phone": "+70193321355"}
0005433035446	937270	5736 079952	VYACHESLAV ABRAMOV	{"email": "abramovvyacheslav-15101962@postgrespro.ru", "phone": "+70215228949"}
0005433035447	3593D0	3062 919258	SEMEN IVANOV	{"phone": "+70452556051"}
0005433035448	BFCECE	0980 031634	ARTEM KOZLOV	{"phone": "+70314883753"}
0005433035449	BFCECE	9194 260785	TATYANA AFANASEVA	{"email": "afanaseva_tatyana.1973@postgrespro.ru", "phone": "+70484531559"}
0005433035450	502867	0277 115971	VIKTOR KOZLOV	{"email": "v-kozlov1974@postgrespro.ru", "phone": "+70203514639"}
0005433035451	D3F8AE	6656 959355	ANTON KISELEV	{"email": "kiselev-a.031975@postgrespro.ru", "phone": "+70036546979"}
0005433035452	C0ADDB	5754 950766	ELENA KARPOVA	{"email": "elena_karpova.101968@postgrespro.ru", "phone": "+70920946073"}
0005433035453	6799ED	9179 822393	SERGEY KONOVALOV	{"phone": "+70158609019"}
0005433035454	31676A	3691 090645	PAVEL STEPANOV	{"phone": "+70953249587"}
0005433035455	D616B7	7260 165681	ELIZAVETA KUZNECOVA	{"phone": "+70523316764"}
0005433035456	D65BF6	9561 849980	OLEG ORLOV	{"email": "olegorlov.021967@postgrespro.ru", "phone": "+70934976761"}
0005433035457	D65BF6	5137 818801	NINA ANTONOVA	{"phone": "+70500545471"}
0005433035458	CC4689	7806 794404	NIKITA SOROKIN	{"email": "n_sorokin-121982@postgrespro.ru", "phone": "+70126008579"}
0005433035459	FA6AD2	7572 974654	LARISA ORLOVA	{"phone": "+70475163041"}
0005433035460	06BF57	7153 771800	ROMAN MIKHAYLOV	{"email": "mikhaylov.roman.091950@postgrespro.ru", "phone": "+70176896963"}
0005433035461	F2E4E8	2980 411853	VLADIMIR KARPOV	{"phone": "+70118517649"}
0005433035462	F2E4E8	0157 756066	OLGA IVANOVA	{"email": "ivanova_olga.071978@postgrespro.ru", "phone": "+70786806858"}
0005433035463	F2E4E8	8794 477801	YULIYA MALYSHEVA	{"email": "yuliya.malysheva_1970@postgrespro.ru", "phone": "+70565484886"}
0005433035464	E2E8EA	5831 171403	NATALYA PETROVA	{"email": "natalya.petrova1958@postgrespro.ru", "phone": "+70156036366"}
0005433035465	E2E8EA	9435 874585	ANATOLIY DMITRIEV	{"email": "dmitriev.anatoliy.1968@postgrespro.ru", "phone": "+70999632119"}
0005433035466	26367C	3965 626314	ANTONINA KOZLOVA	{"phone": "+70043709195"}
0005433035467	FD2E80	0989 345474	ALIYA OVCHINNIKOVA	{"phone": "+70410284863"}
0005433035468	8759F8	0417 865437	NADEZHDA LEBEDEVA	{"email": "nadezhda.lebedeva1971@postgrespro.ru", "phone": "+70837162233"}
0005433035469	BD6587	0017 353783	LYUBOV POPOVA	{"phone": "+70031061413"}
0005433035470	BD6587	1065 672206	MARIYA STEPANOVA	{"email": "mariyastepanova_06081974@postgrespro.ru", "phone": "+70459935362"}
0005433035472	79328E	5741 484490	ALEKSEY DMITRIEV	{"email": "aleksey_dmitriev-121971@postgrespro.ru", "phone": "+70369010223"}
0005433035473	3C1815	3420 250550	ZARINA NESTEROVA	{"email": "nesterovaz081958@postgrespro.ru", "phone": "+70156077434"}
0005433035474	3C1815	1272 261334	YULIYA KARPOVA	{"phone": "+70687424842"}
0005433035475	18FFBC	0267 109710	KLAVDIYA PAVLOVA	{"phone": "+70784534329"}
0005433035476	F2882A	1634 931472	LYUDMILA YAKOVLEVA	{"email": "yakovleva.l1983@postgrespro.ru", "phone": "+70390061987"}
0005433035477	30E9B5	5541 723601	ULYANA GORBUNOVA	{"email": "gorbunova_ulyana_01111973@postgrespro.ru", "phone": "+70862207548"}
0005433035647	8F4DE2	6556 699590	ANDREY ABRAMOV	{"phone": "+70234692639"}
0005433035478	10AC4F	1935 584553	VIKTOR SCHERBAKOV	{"email": "v-scherbakov-011978@postgrespro.ru", "phone": "+70874409336"}
0005433035479	FE188F	6715 768678	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir-28121959@postgrespro.ru", "phone": "+70763109677"}
0005433035480	E75422	8232 423827	TAMARA VOROBEVA	{"phone": "+70231590416"}
0005433035481	E75422	8259 448781	OKSANA SMIRNOVA	{"phone": "+70905774229"}
0005433035482	89B804	8645 755573	MIKHAIL IVANOV	{"phone": "+70968672835"}
0005433035483	89B804	5360 324869	VERA KONOVALOVA	{"phone": "+70505229869"}
0005433035484	D6721D	8479 553905	ALEKSEY ABRAMOV	{"email": "alekseyabramov_19031966@postgrespro.ru", "phone": "+70725943924"}
0005433035485	D6721D	5259 017778	SERGEY GRIGOREV	{"email": "grigorevs30101971@postgrespro.ru", "phone": "+70640031507"}
0005433035486	D6721D	2583 161727	VADIM MOROZOV	{"phone": "+70119748117"}
0005433035487	DB6C0B	7660 322336	MAKSIM BORISOV	{"phone": "+70779996813"}
0005433035488	D8D252	0773 546506	EVGENIY AFANASEV	{"phone": "+70573682189"}
0005433035489	D8D252	0952 592145	KSENIYA TARASOVA	{"phone": "+70173359902"}
0005433035491	E74FE6	2652 914090	RUSLAN POPOV	{"phone": "+70836877021"}
0005433035492	952788	6331 089627	ELIZAVETA ORLOVA	{"phone": "+70993412339"}
0005433035493	952788	8494 560269	NIKITA MELNIKOV	{"phone": "+70332227166"}
0005433035494	702467	9267 805545	VALENTIN NAUMOV	{"phone": "+70573740677"}
0005433035495	591A84	3746 974890	OLEG GORBUNOV	{"email": "o-gorbunov1976@postgrespro.ru", "phone": "+70049754215"}
0005433035496	809B30	8093 990779	ALEKSANDR VOROBEV	{"email": "a.vorobev-21031976@postgrespro.ru", "phone": "+70610020503"}
0005433035497	809B30	4839 400078	VERA MELNIKOVA	{"email": "v-melnikova031963@postgrespro.ru", "phone": "+70232205496"}
0005433035498	F13451	4590 755786	MIKHAIL BELOV	{"phone": "+70940666459"}
0005433035499	F13451	4667 066944	MAKSIM GUSEV	{"email": "maksimgusev-31101967@postgrespro.ru", "phone": "+70806778624"}
0005433035500	31402C	4270 495991	SERGEY IVANOV	{"email": "s-ivanov_1949@postgrespro.ru", "phone": "+70035343837"}
0005433035501	31402C	0006 351988	SERGEY KUZNECOV	{"email": "sergeykuznecov11081965@postgrespro.ru", "phone": "+70383503042"}
0005433035502	381850	8451 370229	ANATOLIY KRASNOV	{"email": "a-krasnov.09071975@postgrespro.ru", "phone": "+70944255218"}
0005433035503	FE80A4	4036 480296	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov.1975@postgrespro.ru", "phone": "+70473069300"}
0005433035504	FE80A4	3115 440655	YANA MAKAROVA	{"email": "yana-makarova_1968@postgrespro.ru", "phone": "+70590412208"}
0005433035505	5EA252	5604 956146	OKSANA SCHERBAKOVA	{"email": "scherbakova-oksana09071967@postgrespro.ru", "phone": "+70557160121"}
0005433035506	1A8AC8	6913 123261	YAROSLAV STEPANOV	{"phone": "+70816635351"}
0005433035507	078AAA	3047 048587	RAISA MALYSHEVA	{"phone": "+70796990924"}
0005433035508	078AAA	9837 800597	ALEKSANDR GERASIMOV	{"phone": "+70243761055"}
0005433035509	F52EBA	2447 593143	SVETLANA LUKYANOVA	{"phone": "+70238194604"}
0005433035510	B04693	9027 840937	ALEKSEY VASILEV	{"phone": "+70589960614"}
0005433035511	B04693	3745 418101	MARINA IVANOVA	{"phone": "+70435886338"}
0005433035512	9AD452	0045 226630	VLADIMIR FOMIN	{"email": "v_fomin_16121977@postgrespro.ru", "phone": "+70980268264"}
0005433035513	AD9E14	0640 787620	MIKHAIL MARTYNOV	{"phone": "+70559476661"}
0005433035514	7433A8	1099 105547	MIKHAIL STEPANOV	{"phone": "+70261134849"}
0005433035515	7433A8	1635 229288	VYACHESLAV KULIKOV	{"email": "kulikov.vyacheslav05031976@postgrespro.ru", "phone": "+70559944673"}
0005433035516	8C7F39	8043 310224	OLGA ZAYCEVA	{"phone": "+70438962349"}
0005433035517	CC69AA	7688 280566	LYUDMILA NIKITINA	{"phone": "+70358495188"}
0005433035518	CC69AA	1918 020963	VALENTINA KUZNECOVA	{"email": "v-kuznecova091980@postgrespro.ru", "phone": "+70824773480"}
0005433035519	FC9450	9371 387849	VALERIY ISAEV	{"phone": "+70102218976"}
0005433035520	6B0B3C	1013 715216	VASILIY GUSEV	{"email": "gusev.vasiliy031970@postgrespro.ru", "phone": "+70232173142"}
0005433035521	B622D9	2881 086874	MARINA SEMENOVA	{"phone": "+70321561178"}
0005433035522	B622D9	8006 636086	ANATOLIY ROMANOV	{"email": "anatoliy_romanov-06051973@postgrespro.ru", "phone": "+70124137499"}
0005433035523	B4EAE9	4827 613796	ALEKSEY MIKHAYLOV	{"email": "mikhaylov-aleksey-1972@postgrespro.ru", "phone": "+70596673782"}
0005433035524	B4EAE9	6868 072064	SERGEY NIKITIN	{"email": "nikitin.sergey-05031970@postgrespro.ru", "phone": "+70195162950"}
0005433035525	03B416	5301 364152	LEONID GAVRILOV	{"phone": "+70420962541"}
0005433035526	03B416	4260 950755	VADIM FEDOROV	{"phone": "+70385530257"}
0005433035527	A99AE8	8821 039939	ALEKSEY AFANASEV	{"email": "a_afanasev031973@postgrespro.ru", "phone": "+70315880479"}
0005433035528	05B4D9	0807 856260	VYACHESLAV KUZMIN	{"phone": "+70904008471"}
0005433035529	EC4D84	3446 378979	KLAVDIYA LAZAREVA	{"email": "lazareva_klavdiya.061978@postgrespro.ru", "phone": "+70471597070"}
0005433035530	EC4D84	7657 405455	VALENTINA MAKSIMOVA	{"phone": "+70755179526"}
0005433035531	B1466E	4148 833740	ANNA BOGDANOVA	{"phone": "+70742327594"}
0005433035532	8C1CE7	3845 866833	ALEKSANDR KUZMIN	{"phone": "+70395207353"}
0005433035533	49850B	4848 177834	ALEKSANDR ALEKSANDROV	{"phone": "+70367205452"}
0005433035534	626CB9	9780 296766	ALEKSANDR SHEVCHENKO	{"phone": "+70933831009"}
0005433035535	626CB9	0182 903698	EKATERINA NESTEROVA	{"email": "nesterovae.091977@postgrespro.ru", "phone": "+70948033609"}
0005433035536	690411	0749 736197	KIRILL ORLOV	{"email": "orlovkirill121972@postgrespro.ru", "phone": "+70435174590"}
0005433035537	FBEAC8	9714 040031	VALERIY ISAEV	{"phone": "+70023165934"}
0005433035538	1BEADA	9293 142837	GENNADIY IVANOV	{"email": "gennadiy-ivanov_1971@postgrespro.ru", "phone": "+70643879899"}
0005433035539	92926B	4829 482913	TAGIR EGOROV	{"phone": "+70639405511"}
0005433035540	B0C6A6	9642 689626	DMITRIY ALEKSEEV	{"phone": "+70844768725"}
0005433035541	0CF844	0559 648923	OLGA OSIPOVA	{"phone": "+70608965582"}
0005433035542	20D567	3634 459568	DARYA MAKAROVA	{"phone": "+70157365744"}
0005433035543	2E9179	6190 185954	ANASTASIYA POPOVA	{"phone": "+70483771874"}
0005433035544	65B54F	5307 082870	NADEZHDA MAKAROVA	{"email": "nmakarova1976@postgrespro.ru", "phone": "+70084794475"}
0005433035545	65B54F	6367 930507	OLEG NOVIKOV	{"email": "oleg_novikov-1985@postgrespro.ru", "phone": "+70922104255"}
0005433035546	B68767	0381 288965	VIKTOR SERGEEV	{"phone": "+70755923922"}
0005433035547	041D62	0538 546058	TATYANA KUZNECOVA	{"phone": "+70019691622"}
0005433035548	041D62	8144 145758	ARTEM DMITRIEV	{"phone": "+70148091586"}
0005433035549	73763D	3416 239459	ALEKSEY SCHERBAKOV	{"email": "aleksey-scherbakov_061980@postgrespro.ru", "phone": "+70567264939"}
0005433035550	73763D	2252 879712	ELENA IVANOVA	{"email": "elena.ivanova.09031972@postgrespro.ru", "phone": "+70484112397"}
0005433035551	9C244D	5733 800983	KRISTINA ZAKHAROVA	{"email": "zakharova-k031964@postgrespro.ru", "phone": "+70457027202"}
0005433035552	BC0D53	2492 235645	OLGA KISELEVA	{"phone": "+70670681333"}
0005433035553	671A73	8879 901890	ELENA KUZNECOVA	{"email": "elena.kuznecova.121975@postgrespro.ru", "phone": "+70717226919"}
0005433035554	4ED901	6624 263855	ARINA KAZAKOVA	{"phone": "+70021408894"}
0005433035555	4ED901	5493 801586	IRINA MATVEEVA	{"email": "matveeva-irina_02091967@postgrespro.ru", "phone": "+70661237688"}
0005433035556	011F4A	8712 546134	MILENA EGOROVA	{"email": "egorovam_051965@postgrespro.ru", "phone": "+70192522992"}
0005433035557	D9D575	3378 895583	INNA LEBEDEVA	{"phone": "+70347491117"}
0005433035558	37B44A	4444 591994	ALENA VOLKOVA	{"email": "alena-volkova-1976@postgrespro.ru", "phone": "+70478045678"}
0005433035559	E6CF0A	9273 787703	SERGEY DAVYDOV	{"phone": "+70745796699"}
0005433035560	9AE1F9	4202 026140	EKATERINA ERMAKOVA	{"email": "ermakovae1971@postgrespro.ru", "phone": "+70968626372"}
0005433035561	9AE1F9	9995 856569	ANTONINA KOVALEVA	{"email": "kovalevaantonina061978@postgrespro.ru", "phone": "+70481280234"}
0005433035562	B86BD9	6461 281432	OLGA NOVIKOVA	{"phone": "+70262471783"}
0005433035563	99DC35	4707 045043	OKSANA SMIRNOVA	{"phone": "+70991254959"}
0005433035564	567B3A	1674 011285	MARIYA VOROBEVA	{"email": "vorobeva_mariya_1970@postgrespro.ru", "phone": "+70341788601"}
0005433035565	567B3A	1462 404411	OLEG MOISEEV	{"phone": "+70324927311"}
0005433035566	567B3A	9673 676417	MAKSIM DENISOV	{"phone": "+70209629839"}
0005433035567	374619	8441 241823	VIKTOR TIMOFEEV	{"email": "timofeev-viktor21031965@postgrespro.ru", "phone": "+70166110364"}
0005433035568	5BEC38	4865 372952	MARAT ORLOV	{"email": "m-orlov1970@postgrespro.ru", "phone": "+70519577279"}
0005433035569	B6582A	3744 157662	MARIYA ANDREEVA	{"email": "mariya.andreeva.28041973@postgrespro.ru", "phone": "+70317512363"}
0005433035570	B6582A	2987 264598	ALEKSANDR TIKHONOV	{"phone": "+70775076339"}
0005433035571	4E91DB	3310 989864	ELENA FADEEVA	{"phone": "+70717492365"}
0005433035572	D225D3	0984 014457	NINA FILIPPOVA	{"phone": "+70089518321"}
0005433035573	F6C7DD	7351 223076	VLADIMIR GRIGOREV	{"email": "grigorev_vladimir.1979@postgrespro.ru", "phone": "+70925633107"}
0005433035574	F6C7DD	0788 919827	NADEZHDA VOLKOVA	{"phone": "+70835308651"}
0005433035575	DD31BE	2105 990273	VIKTOR CHERNOV	{"phone": "+70760853586"}
0005433035576	BD3446	0053 539900	EDUARD MELNIKOV	{"email": "melnikoveduard_1975@postgrespro.ru", "phone": "+70469045106"}
0005433035577	B6672F	6493 908211	NATALYA NIKOLAEVA	{"email": "natalya-nikolaeva_1971@postgrespro.ru", "phone": "+70976009475"}
0005433035578	AC0D71	8546 388178	EVGENIYA ERMAKOVA	{"email": "evgeniya-ermakova-071985@postgrespro.ru", "phone": "+70432673189"}
0005433035579	AC0D71	3628 225151	LIDIYA FILIPPOVA	{"phone": "+70729560427"}
0005433035580	A1FD24	2470 718210	VALENTINA MASLOVA	{"email": "maslova-valentina_25011989@postgrespro.ru", "phone": "+70681562446"}
0005433035581	A1FD24	8359 524707	OKSANA KOROLEVA	{"phone": "+70407340110"}
0005433035582	CC963C	3532 848836	SERGEY BORISOV	{"email": "sergeyborisov031968@postgrespro.ru", "phone": "+70699452251"}
0005433035583	8B3316	3388 892002	ARTEM SOROKIN	{"phone": "+70369706065"}
0005433035584	4CF367	2059 786832	EKATERINA PAVLOVA	{"phone": "+70934459365"}
0005433035585	1B26C7	6282 697150	ELENA FEDOROVA	{"phone": "+70558346985"}
0005433035586	22400D	1682 200698	OLGA BELOVA	{"email": "belova-o1979@postgrespro.ru", "phone": "+70058467262"}
0005433035587	5D5136	6446 745232	BORIS YAKOVLEV	{"phone": "+70403791306"}
0005433035588	D501BB	1934 103958	ELENA IVANOVA	{"phone": "+70937733257"}
0005433035589	D501BB	1800 353316	ELENA KOROLEVA	{"phone": "+70313517165"}
0005433035590	30FB59	7299 748712	DENIS KAZAKOV	{"phone": "+70106591507"}
0005433035591	1DB38E	7108 887575	ANTON KUZNECOV	{"email": "a_kuznecov_111964@postgrespro.ru", "phone": "+70691026257"}
0005433035592	DCA3C6	6876 603193	ALEKSANDR DENISOV	{"email": "denisov-a_1972@postgrespro.ru", "phone": "+70924113406"}
0005433035593	DD194C	0682 133223	NADEZHDA IVANOVA	{"email": "nadezhda-ivanova-1966@postgrespro.ru", "phone": "+70421283444"}
0005433035594	D95A15	5522 376345	VALENTINA KUZNECOVA	{"email": "v-kuznecova.1970@postgrespro.ru", "phone": "+70704393813"}
0005433035595	D95A15	7560 017604	RUSTEM FEDOROV	{"email": "fedorovrustem-16111967@postgrespro.ru", "phone": "+70000793115"}
0005433035596	6C6738	9409 339738	NIKOLAY SOROKIN	{"email": "sorokin-n101981@postgrespro.ru", "phone": "+70783807450"}
0005433035597	B955A0	8005 894139	VLADIMIR VOLKOV	{"phone": "+70137767484"}
0005433035598	8431A2	2895 095991	ALENA DENISOVA	{"email": "a.denisova-081967@postgrespro.ru", "phone": "+70255336658"}
0005433035599	8431A2	5258 652408	SERGEY PAVLOV	{"email": "sergey_pavlov.1971@postgrespro.ru", "phone": "+70137102825"}
0005433035600	C7976B	8904 616857	VIKTOR KAZAKOV	{"email": "kazakovviktor_03121967@postgrespro.ru", "phone": "+70327618288"}
0005433035601	C7976B	9270 051642	NAIL PETROV	{"email": "nail.petrov_20061969@postgrespro.ru", "phone": "+70362995811"}
0005433035602	D6C31D	1626 331246	YURIY CHERNOV	{"email": "chernov_yuriy11041968@postgrespro.ru", "phone": "+70192212033"}
0005433035603	F094AF	9269 166412	NINA NOVIKOVA	{"phone": "+70238404342"}
0005433035604	CA999C	1590 681349	KONSTANTIN KOZLOV	{"email": "kozlov.k_011963@postgrespro.ru", "phone": "+70897653639"}
0005433035605	FAED4C	6204 913989	DMITRIY TIMOFEEV	{"phone": "+70555216368"}
0005433035606	214D0B	6010 398070	VALENTINA FILIPPOVA	{"email": "v.filippova1962@postgrespro.ru", "phone": "+70614588732"}
0005433035607	214D0B	3551 011531	RUSLAN ANDREEV	{"email": "andreevr_091971@postgrespro.ru", "phone": "+70989405882"}
0005433035608	2408AC	8937 113416	ELENA KRASNOVA	{"email": "elena.krasnova_091974@postgrespro.ru", "phone": "+70514973823"}
0005433035609	CF755A	2548 255263	GALINA GAVRILOVA	{"phone": "+70906131250"}
0005433035610	5FC420	7112 190982	NATALIYA TROFIMOVA	{"email": "nataliyatrofimova1973@postgrespro.ru", "phone": "+70137195446"}
0005433035611	87E8BE	7784 557845	NADEZHDA ZAYCEVA	{"email": "nadezhda_zayceva071973@postgrespro.ru", "phone": "+70380904314"}
0005433035612	87E8BE	9742 560462	GENNADIY KONOVALOV	{"email": "konovalov_g.1980@postgrespro.ru", "phone": "+70843533680"}
0005433035613	87E8BE	2048 394265	LYUBOV POTAPOVA	{"email": "lyubovpotapova-24051970@postgrespro.ru", "phone": "+70617491802"}
0005433035614	560B39	7937 160609	IGOR DENISOV	{"email": "denisov-i.011980@postgrespro.ru", "phone": "+70181726251"}
0005433035615	560B39	7605 397164	ANTONINA KOMAROVA	{"email": "a-komarova061965@postgrespro.ru", "phone": "+70198386023"}
0005433035616	436350	8332 539766	DENIS SMIRNOV	{"email": "d.smirnov_12091958@postgrespro.ru", "phone": "+70800453751"}
0005433035617	436350	6464 459798	GALINA RODIONOVA	{"phone": "+70223914991"}
0005433035618	990DE3	2206 236240	LYUDMILA MOROZOVA	{"phone": "+70603699796"}
0005433035619	993B46	5621 019800	ALEKSEY ROMANOV	{"email": "aleksey-romanov_1965@postgrespro.ru", "phone": "+70052957932"}
0005433035620	993B46	9823 412504	VITALIY EGOROV	{"phone": "+70121989505"}
0005433035621	C3AD30	2938 416251	TATYANA SCHERBAKOVA	{"email": "tatyana-scherbakova.28101972@postgrespro.ru", "phone": "+70748305971"}
0005433035622	B6C12B	6250 058262	NINA MEDVEDEVA	{"phone": "+70390413025"}
0005433035623	644941	6064 353607	ANASTASIYA SOROKINA	{"phone": "+70221268062"}
0005433035624	3FA503	4326 632636	TATYANA GERASIMOVA	{"email": "t_gerasimova.09041973@postgrespro.ru", "phone": "+70464723808"}
0005433035625	EEB949	8970 504499	VITALIY SMIRNOV	{"email": "smirnov-vitaliy-1968@postgrespro.ru", "phone": "+70378238821"}
0005433035626	6B3A94	3310 652687	YURIY MAKAROV	{"email": "makarov-y.071972@postgrespro.ru", "phone": "+70229329562"}
0005433035627	31420B	0329 250597	ALEKSANDR KISELEV	{"email": "akiselev121978@postgrespro.ru", "phone": "+70353655894"}
0005433035628	31420B	5892 917259	SERGEY BORISOV	{"email": "borisovs_1974@postgrespro.ru", "phone": "+70580373151"}
0005433035629	7FD93A	0090 989634	ANATOLIY STEPANOV	{"phone": "+70957504166"}
0005433035630	D833D9	0373 049956	LYUBOV DANILOVA	{"email": "daniloval-031973@postgrespro.ru", "phone": "+70390847717"}
0005433035631	BF6FAC	1113 728575	VIKTORIYA KUZMINA	{"email": "kuzmina-viktoriya081973@postgrespro.ru", "phone": "+70089530206"}
0005433035632	711359	9996 478051	PETR KUZNECOV	{"phone": "+70801920708"}
0005433035633	847DDC	7066 745768	NADEZHDA ANTONOVA	{"email": "n_antonova-12081974@postgrespro.ru", "phone": "+70038625012"}
0005433035634	847DDC	3769 669145	GERMAN ZAKHAROV	{"phone": "+70949654360"}
0005433035635	847DDC	0205 610288	MARINA KUZNECOVA	{"email": "kuznecova-marina.1955@postgrespro.ru", "phone": "+70579651764"}
0005433035636	9B88E5	9261 545221	ELENA FILIPPOVA	{"phone": "+70962982532"}
0005433035637	BC45B8	6374 726825	LILIYA GRISHINA	{"phone": "+70414507075"}
0005433035638	F25890	5576 401104	DMITRIY POPOV	{"email": "dmitriy-popov_1970@postgrespro.ru", "phone": "+70141339866"}
0005433035639	8443E9	1902 415372	DMITRIY MOROZOV	{"email": "morozov_d_27041972@postgrespro.ru", "phone": "+70123814025"}
0005433035640	CD1455	3267 336258	YURIY SAVELEV	{"email": "savelev_yuriy_031962@postgrespro.ru", "phone": "+70776157148"}
0005433035641	05323E	4485 169064	LIDIYA KALININA	{"phone": "+70665118662"}
0005433035642	05323E	3337 625564	SERGEY MAKAROV	{"email": "makarov_s.22071971@postgrespro.ru", "phone": "+70436977453"}
0005433035643	05323E	6246 511395	ANDREY VOLKOV	{"phone": "+70221880509"}
0005433035644	77B392	4692 737136	MARGARITA SAVELEVA	{"phone": "+70883847468"}
0005433035645	792EB1	7478 206687	NIKOLAY EGOROV	{"phone": "+70396108650"}
0005433035646	CAE513	0530 506778	TATYANA VASILEVA	{"phone": "+70881998447"}
0005433035648	8F4DE2	2995 919631	NATALYA ROMANOVA	{"phone": "+70171873191"}
0005433035649	645759	4794 612667	TIMOFEY GUSEV	{"phone": "+70559284303"}
0005433035650	526123	2290 526272	FEDOR SEMENOV	{"phone": "+70873072332"}
0005433035651	8D9177	3824 022385	NATALYA LAZAREVA	{"email": "natalyalazareva-1973@postgrespro.ru", "phone": "+70729836256"}
0005433035652	870055	8186 908806	ALEKSANDR STEPANOV	{"email": "a-stepanov_111961@postgrespro.ru", "phone": "+70301620130"}
0005433035653	F53A1C	0384 285082	ANDREY SCHERBAKOV	{"phone": "+70903099305"}
0005433035654	F53A1C	5630 050608	ALENA BELOVA	{"phone": "+70176458248"}
0005433035655	7DF64B	0479 564284	RASHID ABRAMOV	{"phone": "+70016033713"}
0005433035656	FADFA0	0143 747355	SEMEN MOROZOV	{"email": "morozovs1963@postgrespro.ru", "phone": "+70709638668"}
0005433035657	FADFA0	1650 885189	ANASTASIYA SEMENOVA	{"email": "semenova-anastasiya_1984@postgrespro.ru", "phone": "+70106121487"}
0005433035658	0085C7	8601 303612	VYACHESLAV PETROV	{"email": "vyacheslav.petrov-081973@postgrespro.ru", "phone": "+70280142091"}
0005433035659	0085C7	2805 953717	VLADIMIR SMIRNOV	{"phone": "+70788886986"}
0005433035660	326368	7037 729614	ANTON MAKAROV	{"phone": "+70148093268"}
0005433035661	B11076	9727 341114	NINA AFANASEVA	{"phone": "+70895692384"}
0005433035662	B11076	9266 080108	ELENA IVANOVA	{"email": "ivanovaelena.1966@postgrespro.ru", "phone": "+70302001779"}
0005433035663	B182F6	9464 973039	ILYA CHERNOV	{"email": "chernov.i.091961@postgrespro.ru", "phone": "+70653286138"}
0005433035664	FAB79A	8755 230660	GALINA NIKITINA	{"phone": "+70309187798"}
0005433035665	682715	5538 099685	NIKOLAY KAZAKOV	{"email": "kazakov.nikolay091965@postgrespro.ru", "phone": "+70612898590"}
0005433035666	682715	3730 872023	NINA ANTONOVA	{"phone": "+70643880494"}
0005433035667	682715	7569 091179	GALINA LUKYANOVA	{"phone": "+70809894261"}
0005433035668	68A32F	8042 188861	ELENA KUZNECOVA	{"phone": "+70524646911"}
0005433035669	CAFCA2	9028 223619	POLINA YAKOVLEVA	{"email": "polina.yakovleva.1978@postgrespro.ru", "phone": "+70857890748"}
0005433035670	9816D2	3570 183623	TATYANA AFANASEVA	{"email": "afanasevatatyana_1978@postgrespro.ru", "phone": "+70758348752"}
0005433035671	503B0B	8534 362976	DANILA SCHERBAKOV	{"email": "scherbakov.d02071963@postgrespro.ru", "phone": "+70469372068"}
0005433035672	136D1E	6265 002460	EVGENIYA KOZLOVA	{"phone": "+70649486158"}
0005433035673	FD34FB	3274 687971	ANDREY ANTONOV	{"phone": "+70743000733"}
0005433035674	1A4BAD	1638 235445	OKSANA TARASOVA	{"phone": "+70487599308"}
0005433035675	1A4BAD	3507 583851	LYUDMILA KULIKOVA	{"email": "lyudmila_kulikova101961@postgrespro.ru", "phone": "+70952150321"}
0005433035676	7B9114	9047 525347	DENIS NIKOLAEV	{"phone": "+70206521087"}
0005433035677	73A0A1	4569 175152	ANDREY GAVRILOV	{"phone": "+70008292514"}
0005433035678	3BB033	6644 353347	NIKITA VOLKOV	{"email": "volkov.n.021970@postgrespro.ru", "phone": "+70836928048"}
0005433035679	3BB033	7446 976305	STANISLAV ISAEV	{"email": "isaev-s.04101981@postgrespro.ru", "phone": "+70737533088"}
0005433035680	DC529D	7713 213783	VLADIMIR ANTONOV	{"phone": "+70194511502"}
0005433035681	4794D8	8948 540419	DMITRIY SHEVCHENKO	{"email": "dmitriy-shevchenko_1963@postgrespro.ru", "phone": "+70818022141"}
0005433035682	1832CA	2094 355637	TATYANA GORBUNOVA	{"phone": "+70934752377"}
0005433035683	B66F68	7881 331088	PAVEL FOMIN	{"phone": "+70189151599"}
0005433035684	B66F68	0902 794004	EKATERINA VLASOVA	{"email": "vlasova-e-27051988@postgrespro.ru", "phone": "+70541399066"}
0005433035685	636B66	2399 477269	EVGENIY ZHUKOV	{"email": "zhukovevgeniy.061969@postgrespro.ru", "phone": "+70591993599"}
0005433035686	310543	4311 595742	ANASTASIYA VLASOVA	{"email": "vlasovaa.051976@postgrespro.ru", "phone": "+70509619561"}
0005433035687	EA1F42	8548 631224	NIKOLAY NAZAROV	{"phone": "+70413349684"}
0005433035688	9896E7	1285 141812	TIMUR DAVYDOV	{"phone": "+70156495663"}
0005433035689	A6DE9F	0145 993943	NAIL KONOVALOV	{"phone": "+70236397177"}
0005433035690	1B8B53	2731 472400	OLGA MEDVEDEVA	{"phone": "+70031707880"}
0005433035691	9D541B	4959 136465	STEPAN KAZAKOV	{"email": "kazakovs.051988@postgrespro.ru", "phone": "+70421849809"}
0005433035692	69401A	1957 363428	STEPAN KOZLOV	{"phone": "+70955638893"}
0005433035693	69401A	0718 068891	VLADIMIR MAKAROV	{"email": "v_makarov.23081968@postgrespro.ru", "phone": "+70294307379"}
0005433035694	69401A	0347 304190	NATALYA ZHURAVLEVA	{"phone": "+70330206233"}
0005433035695	798AA9	2237 899911	TIMOFEY CHERNOV	{"email": "chernov-timofey-13121975@postgrespro.ru", "phone": "+70026240452"}
0005433035696	5D5B30	8288 007258	MARGARITA KALININA	{"phone": "+70774705373"}
0005433035697	5D5B30	8524 995383	ELENA ZAKHAROVA	{"phone": "+70375681089"}
0005433035698	5D5B30	8927 148248	LYUDMILA POPOVA	{"email": "l_popova.1965@postgrespro.ru", "phone": "+70152074318"}
0005433035699	AAA61A	4310 125119	ZLATA GUSEVA	{"email": "zlata-guseva081977@postgrespro.ru", "phone": "+70018713034"}
0005433035700	6D15B8	2226 326875	GENNADIY MARTYNOV	{"email": "martynov.g1978@postgrespro.ru", "phone": "+70433804272"}
0005433035701	DC316D	8205 429741	BORIS KUZNECOV	{"email": "kuznecovb.17091962@postgrespro.ru", "phone": "+70991152470"}
0005433035702	DC316D	5680 543101	VALENTINA MARTYNOVA	{"phone": "+70321761338"}
0005433035703	3CB054	7766 958076	DARYA ZAKHAROVA	{"email": "d-zakharova_071965@postgrespro.ru", "phone": "+70341478635"}
0005433035760	9CC974	3574 237756	VENIAMIN MOISEEV	{"phone": "+70486204979"}
0005433035704	ED4F9E	1166 245157	MARINA NAUMOVA	{"email": "naumova.m071964@postgrespro.ru", "phone": "+70935705924"}
0005433035705	ED4F9E	3709 849319	OLESYA DANILOVA	{"email": "danilova.o061963@postgrespro.ru", "phone": "+70074607120"}
0005433035706	ED4F9E	5010 553565	OLGA POPOVA	{"phone": "+70437985753"}
0005433035707	C2FA35	4066 922529	ALEKSEY MAKSIMOV	{"phone": "+70699416489"}
0005433035708	C2FA35	4237 486583	MIKHAIL BORISOV	{"email": "mikhailborisov1976@postgrespro.ru", "phone": "+70895604824"}
0005433035709	412604	4522 328756	ALEKSEY ANDREEV	{"email": "aleksey_andreev-1965@postgrespro.ru", "phone": "+70034258784"}
0005433035710	09B825	2712 974183	DENIS MOROZOV	{"phone": "+70551524851"}
0005433035711	7F0612	4624 706238	ANASTASIYA FOMINA	{"email": "fomina.anastasiya1980@postgrespro.ru", "phone": "+70972403191"}
0005433035712	835C53	1310 433808	ANASTASIYA VASILEVA	{"email": "vasilevaa.08111976@postgrespro.ru", "phone": "+70722963282"}
0005433035713	835C53	6593 402498	ANASTASIYA KUZNECOVA	{"email": "anastasiya-kuznecova14011967@postgrespro.ru", "phone": "+70468776755"}
0005433035714	0C34A3	9780 793642	GENNADIY SMIRNOV	{"phone": "+70669398594"}
0005433035715	B4C124	9785 128693	IRINA IVANOVA	{"email": "ivanovairina03021972@postgrespro.ru", "phone": "+70907235041"}
0005433035716	F64AB0	7964 416411	RAMILYA ZAYCEVA	{"phone": "+70737997420"}
0005433035717	F64AB0	8652 332951	OLESYA DANILOVA	{"phone": "+70331886985"}
0005433035718	72EE8F	8341 812890	VALENTINA SOLOVEVA	{"email": "valentina_soloveva.041974@postgrespro.ru", "phone": "+70817439997"}
0005433035719	67212F	8310 106425	GUZEL KRASNOVA	{"email": "guzel_krasnova.01031971@postgrespro.ru", "phone": "+70857605944"}
0005433035720	C9692F	9981 810729	MARINA NESTEROVA	{"email": "nesterova_marina-1973@postgrespro.ru", "phone": "+70971613295"}
0005433035721	7A2FD5	5064 342510	ALEKSEY DMITRIEV	{"phone": "+70475597934"}
0005433035722	698BCE	9221 262563	ALEKSEY NOVIKOV	{"phone": "+70038026283"}
0005433035723	F25B26	8400 195535	TAMARA NIKITINA	{"email": "t-nikitina.011979@postgrespro.ru", "phone": "+70505495428"}
0005433035724	F25B26	9608 675221	VLADIMIR VOROBEV	{"email": "v_vorobev081966@postgrespro.ru", "phone": "+70122664313"}
0005433035725	100A61	0115 329042	SERGEY BELOV	{"email": "belov_sergey111972@postgrespro.ru", "phone": "+70483559495"}
0005433035726	D6D610	5606 007720	ANDREY MAKSIMOV	{"email": "andrey_maksimov_04041969@postgrespro.ru", "phone": "+70046819217"}
0005433035727	DC3258	4186 322574	YURIY SCHERBAKOV	{"phone": "+70319587158"}
0005433035728	DC3258	3664 506576	ALENA GAVRILOVA	{"phone": "+70824475305"}
0005433035729	78A752	5608 969726	YURIY SOKOLOV	{"email": "sokolov-yuriy.091967@postgrespro.ru", "phone": "+70659474032"}
0005433035730	855ACE	4011 975388	GENNADIY TIMOFEEV	{"email": "timofeev_g061976@postgrespro.ru", "phone": "+70466684184"}
0005433035731	855ACE	3588 988562	MARINA GUSEVA	{"phone": "+70088844666"}
0005433035732	261142	0980 836141	EGOR TARASOV	{"phone": "+70191869222"}
0005433035733	FD0E3A	1194 295308	ANNA MEDVEDEVA	{"phone": "+70753092737"}
0005433035734	FD0E3A	3287 708344	ALEKSANDR NAZAROV	{"phone": "+70349943146"}
0005433035735	1B5712	0346 073578	LYUDMILA BARANOVA	{"phone": "+70666461329"}
0005433035736	1B5712	1979 852067	GALINA PETROVA	{"email": "g.petrova-121972@postgrespro.ru", "phone": "+70627393537"}
0005433035737	86C8A0	2909 708555	ANATOLIY GORBUNOV	{"phone": "+70225705650"}
0005433035738	B4296F	5977 856637	EVGENIY NAZAROV	{"phone": "+70548635934"}
0005433035739	52C0D1	1432 167092	SVETLANA ABRAMOVA	{"email": "svetlanaabramova.18071978@postgrespro.ru", "phone": "+70730170212"}
0005433035740	0F148A	4878 448745	MIKHAIL ZHUKOV	{"email": "mzhukov1971@postgrespro.ru", "phone": "+70689364887"}
0005433035741	1537A5	7492 802071	MAYYA FROLOVA	{"phone": "+70657694989"}
0005433035742	AB1080	6874 086041	ANATOLIY GORBUNOV	{"phone": "+70525569847"}
0005433035743	4CA877	5327 791906	VIKTORIYA FROLOVA	{"phone": "+70750603243"}
0005433035744	0AFBB2	8025 956304	MARINA ISAEVA	{"phone": "+70842693359"}
0005433035745	B4866A	7271 172182	VALENTINA POPOVA	{"phone": "+70407644109"}
0005433035746	EC77A1	7904 050702	SERGEY IVANOV	{"phone": "+70663639769"}
0005433035747	9DB6A1	9032 324693	MARIYA KUZNECOVA	{"email": "kuznecova.mariya.081973@postgrespro.ru", "phone": "+70523904098"}
0005433035748	6287FF	0516 208264	OLGA NIKOLAEVA	{"email": "nikolaeva.o.1972@postgrespro.ru", "phone": "+70609295202"}
0005433035749	C51A6D	6711 953079	ELENA ARKHIPOVA	{"email": "arkhipovae_18021974@postgrespro.ru", "phone": "+70026857869"}
0005433035750	FF2369	6568 043459	VLADIMIR KUZMIN	{"phone": "+70205269029"}
0005433035751	FF2369	8658 669459	ANNA TITOVA	{"email": "a_titova1971@postgrespro.ru", "phone": "+70466168029"}
0005433035752	9735D9	9030 088771	SVETLANA ZHURAVLEVA	{"phone": "+70193307928"}
0005433035753	BB87CB	5438 689798	DENIS FILIPPOV	{"phone": "+70307766935"}
0005433035754	BB87CB	5216 599549	IVAN ZAKHAROV	{"email": "zakharov_i_1976@postgrespro.ru", "phone": "+70423565595"}
0005433035755	BB87CB	4187 440363	NIKOLAY ISAEV	{"email": "n_isaev-1974@postgrespro.ru", "phone": "+70103033031"}
0005433035756	1EC79F	4623 284925	PAVEL MAKAROV	{"phone": "+70328045469"}
0005433035757	32DD75	4024 138856	LARISA MOROZOVA	{"email": "morozovalarisa_081966@postgrespro.ru", "phone": "+70970408310"}
0005433035758	F87FDC	3430 565785	VALERIYA MASLOVA	{"phone": "+70700851968"}
0005433035759	283BF2	1978 817595	EGOR KUDRYASHOV	{"phone": "+70426199055"}
0005433035761	9CC974	5143 797229	YULIYA KISELEVA	{"email": "yuliyakiseleva_31101971@postgrespro.ru", "phone": "+70768039045"}
0005433035762	15216C	0202 325379	EVGENIY IVANOV	{"email": "e_ivanov_1975@postgrespro.ru", "phone": "+70274547712"}
0005433035763	7CB3FE	3358 550991	SERGEY ZAYCEV	{"phone": "+70036500309"}
0005433035764	1B4967	5394 186900	VALENTINA MAKSIMOVA	{"phone": "+70244974163"}
0005433035765	E8106D	4739 596580	LYUDMILA KOZLOVA	{"email": "lkozlova1968@postgrespro.ru", "phone": "+70411872402"}
0005433035766	3A14EE	6214 002561	DARYA PAVLOVA	{"email": "pavlova.darya-01011974@postgrespro.ru", "phone": "+70565015113"}
0005433035767	3A14EE	6397 821655	ILYA SOLOVEV	{"phone": "+70806681277"}
0005433035768	884EA4	1263 562997	ANATOLIY MAKAROV	{"phone": "+70697837987"}
0005433035769	884EA4	4473 959720	YULIYA GERASIMOVA	{"email": "gerasimova-yuliya_18121972@postgrespro.ru", "phone": "+70893155286"}
0005433035770	66DD47	7368 851350	YULIYA STEPANOVA	{"phone": "+70179480421"}
0005433035771	45BCA2	2983 834230	VALENTINA POTAPOVA	{"email": "valentina_potapova1981@postgrespro.ru", "phone": "+70483651432"}
0005433035772	9D1011	9886 834089	SVETLANA ZHURAVLEVA	{"phone": "+70632709300"}
0005433035773	9D1011	4153 079705	ANATOLIY MAKAROV	{"email": "a-makarov1983@postgrespro.ru", "phone": "+70940041538"}
0005433035774	378516	5988 069720	ELENA DAVYDOVA	{"email": "e_davydova-011969@postgrespro.ru", "phone": "+70806863570"}
0005433035775	378516	8761 832764	SERGEY MAKAROV	{"phone": "+70418179064"}
0005433035833	B2E111	2281 367091	ANASTASIYA SOROKINA	{"phone": "+70763043917"}
0005433035776	E70E02	6189 984918	VALENTINA MARTYNOVA	{"email": "valentina-martynova.071971@postgrespro.ru", "phone": "+70865739970"}
0005433035777	965558	1745 578857	NIKOLAY KAZAKOV	{"email": "nikolay-kazakov-07021966@postgrespro.ru", "phone": "+70700807984"}
0005433035778	965558	8780 038831	TATYANA NESTEROVA	{"email": "nesterova_t-17111982@postgrespro.ru", "phone": "+70171465451"}
0005433035779	8579D8	8723 377226	VALENTINA ORLOVA	{"email": "v-orlova.1986@postgrespro.ru", "phone": "+70468973255"}
0005433035780	8579D8	4909 299762	YULIYA ILINA	{"phone": "+70602616565"}
0005433035781	6B53A0	2742 314047	OLGA SIDOROVA	{"phone": "+70022025271"}
0005433035782	6BA562	2444 814078	KRISTINA SCHERBAKOVA	{"phone": "+70696445379"}
0005433035783	D3A67E	6613 763600	ROMAN DMITRIEV	{"email": "dmitriev_r1967@postgrespro.ru", "phone": "+70277964806"}
0005433035784	818E9B	2816 595545	DANIIL ORLOV	{"phone": "+70552785937"}
0005433035785	7A7EAC	1218 427385	NATALYA ZOTOVA	{"email": "zotova-natalya_061984@postgrespro.ru", "phone": "+70605093644"}
0005433035786	7A7EAC	0557 896723	OLGA ISAEVA	{"email": "isaeva.olga_1974@postgrespro.ru", "phone": "+70017053671"}
0005433035787	D44792	2601 563817	MARIYA SMIRNOVA	{"phone": "+70441815852"}
0005433035788	340629	7821 100011	NINA ZHUKOVA	{"phone": "+70770444378"}
0005433035789	AC52F6	6959 500769	NADEZHDA ALEKSANDROVA	{"email": "aleksandrova-nadezhda031970@postgrespro.ru", "phone": "+70455257682"}
0005433035790	AC52F6	0882 196317	ANATOLIY FROLOV	{"email": "frolov.anatoliy_061971@postgrespro.ru", "phone": "+70927106476"}
0005433035791	F6C4F0	6324 106863	SVETLANA ZOTOVA	{"email": "svetlana.zotova101979@postgrespro.ru", "phone": "+70411579857"}
0005433035792	0B62C2	1849 587942	DMITRIY MELNIKOV	{"email": "melnikovdmitriy29091979@postgrespro.ru", "phone": "+70495451771"}
0005433035793	04F211	8051 181371	ELENA MIKHAYLOVA	{"email": "mikhaylova.e-1955@postgrespro.ru", "phone": "+70543136562"}
0005433035794	8FCBAE	8963 861912	OKSANA KOROLEVA	{"phone": "+70677458515"}
0005433035795	8FCBAE	7271 266818	LYUBOV VOLKOVA	{"phone": "+70821129906"}
0005433035796	8FCBAE	6029 977448	VLADIMIR STEPANOV	{"phone": "+70849426982"}
0005433035797	F3AB0C	7191 649766	ALEKSEY MAKAROV	{"email": "makarov_aleksey_061966@postgrespro.ru", "phone": "+70315845951"}
0005433035798	8BCEC7	3116 608413	ALEKSEY VLASOV	{"email": "vlasovaleksey_081969@postgrespro.ru", "phone": "+70610384027"}
0005433035799	2269A1	5908 390333	YURIY KUZNECOV	{"email": "kuznecov_y.041968@postgrespro.ru", "phone": "+70161897143"}
0005433035800	39CB7A	8391 199680	LYUBOV ZHURAVLEVA	{"email": "lzhuravleva.1977@postgrespro.ru", "phone": "+70416715840"}
0005433035801	39CB7A	0017 142691	NIKOLAY PAVLOV	{"phone": "+70558308921"}
0005433035802	1AE74E	8809 228804	ELENA ALEKSANDROVA	{"email": "ealeksandrova1971@postgrespro.ru", "phone": "+70851380339"}
0005433035803	CFD71F	3151 366977	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr051974@postgrespro.ru", "phone": "+70750606374"}
0005433035804	CFD71F	6179 641667	TATYANA DAVYDOVA	{"phone": "+70768234817"}
0005433035805	0FA0DD	0624 923735	EVGENIY ALEKSANDROV	{"email": "evgeniy-aleksandrov-101961@postgrespro.ru", "phone": "+70943028823"}
0005433035806	0FA0DD	6663 968212	EVDOKIYA PETROVA	{"phone": "+70145444839"}
0005433035807	24E9B3	2453 645256	SOFIYA KUZMINA	{"email": "skuzmina071983@postgrespro.ru", "phone": "+70567656001"}
0005433035808	428CB8	7846 255856	ARTEM DAVYDOV	{"email": "davydov-artem_041978@postgrespro.ru", "phone": "+70077393432"}
0005433035809	D2E6FA	4916 347576	NATALYA FROLOVA	{"email": "n_frolova_101975@postgrespro.ru", "phone": "+70103528546"}
0005433035810	974E65	5486 512282	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr-23111970@postgrespro.ru", "phone": "+70706992829"}
0005433035811	4EF7DD	1572 511614	KRISTINA NIKOLAEVA	{"email": "kristina.nikolaeva23091964@postgrespro.ru", "phone": "+70516285566"}
0005433035812	987E47	5966 095896	ALEKSANDRA FADEEVA	{"email": "fadeeva-a1982@postgrespro.ru", "phone": "+70708095165"}
0005433035813	9BDDDF	0145 854176	MARIYA ANTONOVA	{"email": "antonovam-051976@postgrespro.ru", "phone": "+70017510735"}
0005433035814	9BDDDF	0243 000412	NINA LEBEDEVA	{"phone": "+70401658883"}
0005433035815	9BDDDF	2760 746690	OLGA VLASOVA	{"email": "o_vlasova25011967@postgrespro.ru", "phone": "+70356441962"}
0005433035816	8C4EE5	9655 418470	ALENA KOMAROVA	{"phone": "+70096057593"}
0005433035817	8C4EE5	8478 566939	VIKTOR IVANOV	{"email": "ivanov_v-07121975@postgrespro.ru", "phone": "+70285968618"}
0005433035818	E87643	6656 452792	INNA TARASOVA	{"phone": "+70442404826"}
0005433035819	E87643	8034 402904	OLEG NIKITIN	{"email": "o.nikitin.1980@postgrespro.ru", "phone": "+70585679055"}
0005433035820	E87643	8620 092733	ALEKSEY KOZLOV	{"email": "aleksey.kozlov-1972@postgrespro.ru", "phone": "+70581307891"}
0005433035821	902C23	1833 995265	GULNARA VOLKOVA	{"email": "gulnara-volkova-1974@postgrespro.ru", "phone": "+70938453456"}
0005433035822	CCFF4C	0560 215690	VASILIY KUZNECOV	{"phone": "+70358483723"}
0005433035823	CCFF4C	9605 095710	NIKOLAY SEMENOV	{"phone": "+70720959814"}
0005433035824	6EA69A	6783 895591	ALEKSANDR FEDOTOV	{"email": "aleksandrfedotov-051969@postgrespro.ru", "phone": "+70617910677"}
0005433035825	BDCCCE	3801 167079	LYUBOV FROLOVA	{"phone": "+70400594032"}
0005433035826	05D27B	7931 939790	DMITRIY MAKAROV	{"email": "makarov_dmitriy-1962@postgrespro.ru", "phone": "+70915972240"}
0005433035827	05D27B	7526 041237	TATYANA SERGEEVA	{"email": "t_sergeeva_14051982@postgrespro.ru", "phone": "+70954043771"}
0005433035828	717712	5475 404565	VIKTOR KUZNECOV	{"email": "v-kuznecov_02031967@postgrespro.ru", "phone": "+70614111429"}
0005433035829	4B7F5B	6823 497184	GALINA MEDVEDEVA	{"email": "medvedevagalina_1986@postgrespro.ru", "phone": "+70745630193"}
0005433035830	5AB942	7905 671471	ANASTASIYA KONOVALOVA	{"phone": "+70120212261"}
0005433035831	9C20DA	6057 986648	OLESYA MATVEEVA	{"email": "o.matveeva-14081969@postgrespro.ru", "phone": "+70896406361"}
0005433035832	B2E111	1656 216515	NINA MEDVEDEVA	{"email": "nina.medvedeva071985@postgrespro.ru", "phone": "+70041374247"}
0005433035834	8D15E7	8293 456058	VERA NIKOLAEVA	{"phone": "+70257109400"}
0005433035835	8D15E7	1583 067838	SERGEY ZAKHAROV	{"phone": "+70054343538"}
0005433035836	5699F3	6442 432901	GENNADIY GUSEV	{"email": "g_gusev.01031970@postgrespro.ru", "phone": "+70144510378"}
0005433035837	D7E581	2995 754167	NIKOLAY DENISOV	{"email": "denisov_nikolay.081968@postgrespro.ru", "phone": "+70933760631"}
0005433035838	B2BAED	5747 151844	VYACHESLAV SHEVCHENKO	{"email": "shevchenkovyacheslav-1957@postgrespro.ru", "phone": "+70229371613"}
0005433035839	D5CBE4	4240 365787	SERGEY SMIRNOV	{"email": "smirnovs.1976@postgrespro.ru", "phone": "+70931566969"}
0005433035840	D5CBE4	0289 943497	RAISA VASILEVA	{"email": "r_vasileva-061980@postgrespro.ru", "phone": "+70117696097"}
0005433035841	51AAA6	1495 405220	TATYANA IVANOVA	{"phone": "+70989235984"}
0005433035842	E82720	3411 158732	LEV SHEVCHENKO	{"phone": "+70282103525"}
0005433035843	AECE55	3035 325334	ELENA SOROKINA	{"email": "sorokina_elena10081978@postgrespro.ru", "phone": "+70754450757"}
0005433035844	DD8CA9	7149 391155	DIANA NOVIKOVA	{"email": "diananovikova121968@postgrespro.ru", "phone": "+70762348505"}
0005433035845	4B4F97	6683 914053	ALEVTINA DANILOVA	{"phone": "+70618208442"}
0005433035846	4B4F97	3669 423559	IVAN KOZLOV	{"email": "i_kozlov-081962@postgrespro.ru", "phone": "+70402028470"}
0005433035847	4EC1D8	1413 303645	DANILA KARPOV	{"phone": "+70081030225"}
0005433035848	4EC1D8	2917 132720	ALEKSANDR PETROV	{"phone": "+70927661853"}
0005433035849	FCE366	7216 390279	ELENA POPOVA	{"phone": "+70824832111"}
0005433035850	FCE366	1684 513514	ELENA MOISEEVA	{"phone": "+70546359383"}
0005433035851	FD3623	0936 143724	ZINAIDA KUZNECOVA	{"phone": "+70014597515"}
0005433035852	FD3623	4812 297459	NADEZHDA BELYAEVA	{"phone": "+70561637059"}
0005433035853	089AAD	6751 595080	ELENA NIKIFOROVA	{"phone": "+70424180455"}
0005433035854	089AAD	6938 315395	EVGENIY NIKITIN	{"email": "nikitin_e_1970@postgrespro.ru", "phone": "+70759682035"}
0005433035855	089AAD	0399 382657	ALEKSANDR ZHUKOV	{"email": "zhukova.15111984@postgrespro.ru", "phone": "+70445294097"}
0005433035856	3D54C1	6845 569392	SVETLANA KISELEVA	{"email": "kiseleva-svetlana.091975@postgrespro.ru", "phone": "+70433937603"}
0005433035857	3AD344	6225 229539	KSENIYA SOLOVEVA	{"email": "k_soloveva.1968@postgrespro.ru", "phone": "+70822214092"}
0005433035858	DAF2E8	1383 281245	LYUDMILA MOROZOVA	{"email": "lyudmila_morozova081975@postgrespro.ru", "phone": "+70599998889"}
0005433035859	1025BF	5657 264193	SOFYA SAVELEVA	{"phone": "+70649174969"}
0005433035860	9D0F8C	4450 657145	ALEKSANDR DMITRIEV	{"phone": "+70420328586"}
0005433035861	1755C4	1137 590468	OLEG ALEKSEEV	{"phone": "+70160353312"}
0005433035862	D81C11	3877 198298	LILIYA OSIPOVA	{"email": "osipovaliliya091968@postgrespro.ru", "phone": "+70637628087"}
0005433035863	D81C11	6932 151045	IGOR DENISOV	{"phone": "+70555146990"}
0005433035864	E1DBA6	2869 291513	OLEG POPOV	{"email": "popov.oleg16021967@postgrespro.ru", "phone": "+70000615524"}
0005433035865	7FAC6F	8146 998772	NINA KALININA	{"email": "n_kalinina.1977@postgrespro.ru", "phone": "+70033319759"}
0005433035866	3575DE	5793 214058	ELENA YAKOVLEVA	{"email": "elena.yakovleva05031967@postgrespro.ru", "phone": "+70928959359"}
0005433035867	754A88	9357 292839	GALINA VOROBEVA	{"phone": "+70128970613"}
0005433035868	754A88	0958 117184	IRINA BARANOVA	{"email": "baranova_irina24081977@postgrespro.ru", "phone": "+70535898219"}
0005433035869	C6CD1F	3551 863463	SVETLANA IVANOVA	{"email": "sivanova011967@postgrespro.ru", "phone": "+70395154713"}
0005433035870	C6CD1F	4543 144987	SERGEY ROMANOV	{"phone": "+70361637165"}
0005433035871	C6CD1F	2389 514907	LIDIYA FROLOVA	{"phone": "+70157074112"}
0005433035872	C4621A	2366 417781	MIKHAIL KUZNECOV	{"phone": "+70833527608"}
0005433035873	CAD72A	2466 760155	VLADIMIR BARANOV	{"email": "v.baranov.1967@postgrespro.ru", "phone": "+70301486455"}
0005433035874	B5912F	9179 943305	PAVEL BORISOV	{"email": "pavel.borisov091970@postgrespro.ru", "phone": "+70386896750"}
0005433035875	B5912F	2178 726017	EKATERINA MALYSHEVA	{"email": "malysheva_e-061990@postgrespro.ru", "phone": "+70478046160"}
0005433035876	2FC21F	8767 259828	PAVEL FOMIN	{"phone": "+70346802975"}
0005433035877	C490D6	4690 990523	ANNA NESTEROVA	{"email": "a.nesterova.091981@postgrespro.ru", "phone": "+70592826722"}
0005433035878	B1493B	0038 925310	VIKTOR ZHUKOV	{"phone": "+70259925591"}
0005433035879	B1493B	6279 988882	YAROSLAV ZAYCEV	{"email": "zaycev_yaroslav_22071974@postgrespro.ru", "phone": "+70580870879"}
0005433035880	F6F05E	8375 966335	DARYA CHERNOVA	{"phone": "+70234027648"}
0005433035881	40718D	5640 740575	VIKTORIYA KUZNECOVA	{"phone": "+70752963986"}
0005433035882	2C1201	9402 700157	NIKOLAY POPOV	{"email": "popov.n13041979@postgrespro.ru", "phone": "+70444598136"}
0005433035883	2C1201	4134 787271	VALERIYA ZAKHAROVA	{"phone": "+70044117577"}
0005433035884	F71240	9478 240669	NADEZHDA EFREMOVA	{"phone": "+70548898526"}
0005433035885	7322A2	1398 433445	MARIYA FEDOROVA	{"email": "m-fedorova_31071981@postgrespro.ru", "phone": "+70303654001"}
0005433035886	7322A2	7411 420051	IRINA BARANOVA	{"phone": "+70536807495"}
0005433035887	278FFE	7274 664653	IGOR ZHURAVLEV	{"phone": "+70026916759"}
0005433035888	05B0AF	5496 076547	PETR NIKOLAEV	{"phone": "+70769298767"}
0005433035889	05B0AF	1269 474754	OLGA BORISOVA	{"phone": "+70845998943"}
0005433035890	D127E8	9243 591696	ANDREY KONOVALOV	{"phone": "+70593205770"}
0005433035891	AF3549	1025 078425	ANDREY MATVEEV	{"email": "matveev_a-111961@postgrespro.ru", "phone": "+70523470032"}
0005433035892	AF3549	3119 684011	NADEZHDA EFIMOVA	{"phone": "+70779007237"}
0005433035893	0F3385	8925 005541	VIKTOR MAKAROV	{"phone": "+70222249016"}
0005433035894	0F3385	5230 944413	ANDREY SEMENOV	{"phone": "+70341823251"}
0005433035895	4516FA	6003 318208	NIKITA POPOV	{"email": "popov_n-121964@postgrespro.ru", "phone": "+70825227498"}
0005433035896	4516FA	3673 646181	ALEKSANDR KOZLOV	{"phone": "+70885131061"}
0005433035897	198537	5096 862576	RAVIL MAKSIMOV	{"phone": "+70949628278"}
0005433035898	198537	5324 754241	OKSANA KUZMINA	{"email": "oksana-kuzmina031971@postgrespro.ru", "phone": "+70105985411"}
0005433035899	561E98	9933 863798	VLADISLAV MOISEEV	{"phone": "+70904675102"}
0005433035900	BCF04D	3860 523164	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr041986@postgrespro.ru", "phone": "+70765929087"}
0005433035901	990139	5647 981927	ELMIRA STEPANOVA	{"email": "stepanovaelmira-22061966@postgrespro.ru", "phone": "+70510880469"}
0005433035902	7B902D	4230 344522	ELENA EGOROVA	{"phone": "+70956901618"}
0005433035903	6BB0FB	2444 845507	LYUDMILA BARANOVA	{"phone": "+70188983063"}
0005433035904	248433	9181 322379	ANASTASIYA ZAKHAROVA	{"email": "a-zakharova.101975@postgrespro.ru", "phone": "+70353513226"}
0005433035905	248433	3908 000017	IVAN IVANOV	{"phone": "+70626386019"}
0005433035906	81FA2C	4375 896869	OLGA ERMAKOVA	{"phone": "+70501715146"}
0005433035907	81FA2C	0003 073145	ILYA ROMANOV	{"phone": "+70549484273"}
0005433035908	1813C4	3629 918613	RUSLAN VOLKOV	{"email": "r-volkov25101982@postgrespro.ru", "phone": "+70527368418"}
0005433035909	FEA283	2933 045846	VALERIY SOLOVEV	{"email": "solovev-valeriy051974@postgrespro.ru", "phone": "+70106596807"}
0005433035910	19D6FE	3213 843225	IRINA KULIKOVA	{"email": "kulikova_irina-1974@postgrespro.ru", "phone": "+70100428164"}
0005433035911	D04604	8649 605045	NADEZHDA NIKOLAEVA	{"email": "nadezhda_nikolaeva_111986@postgrespro.ru", "phone": "+70757226616"}
0005433035912	D04604	7965 341779	FEDOR NIKOLAEV	{"phone": "+70021845074"}
0005433035913	3C9DD3	0727 588672	DMITRIY MIRONOV	{"phone": "+70490207878"}
0005433035914	DB8CC8	3522 217462	VALENTINA KUZNECOVA	{"email": "kuznecova.v.121969@postgrespro.ru", "phone": "+70762119715"}
0005433035915	50A0D5	2511 006064	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.t-1972@postgrespro.ru", "phone": "+70213483778"}
0005433035916	50A0D5	5471 728659	GALINA ABRAMOVA	{"email": "galina_abramova_071973@postgrespro.ru", "phone": "+70373880046"}
0005433035917	42E0A2	7434 595433	VALENTINA GUSEVA	{"email": "guseva.v-29031962@postgrespro.ru", "phone": "+70349409552"}
0005433035918	42E0A2	0794 802697	SERGEY KAZAKOV	{"phone": "+70193565930"}
0005433035919	67D46B	5945 351698	MIKHAIL MAKAROV	{"phone": "+70957088268"}
0005433035920	DE9A9B	5507 753592	YURIY ZAKHAROV	{"phone": "+70859329788"}
0005433035921	DE9A9B	3937 880373	LYUDMILA NIKIFOROVA	{"email": "lyudmila.nikiforova_14081976@postgrespro.ru", "phone": "+70807401462"}
0005433035922	DE9A9B	5478 633454	OLEG NAZAROV	{"phone": "+70988770635"}
0005433035923	F2265F	4726 218194	ELENA RODIONOVA	{"phone": "+70766534622"}
0005433035924	F2265F	6829 356455	ALEKSANDR POPOV	{"phone": "+70475316025"}
0005433035925	8EECA4	3222 777484	SERGEY NAZAROV	{"phone": "+70228224091"}
0005433035926	C63876	7197 664633	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a-011977@postgrespro.ru", "phone": "+70197424387"}
0005433035927	96EE27	5594 069679	LIDIYA SOLOVEVA	{"phone": "+70291278536"}
0005433035928	7116BE	0023 387483	GENNADIY GORBUNOV	{"email": "g.gorbunov.091972@postgrespro.ru", "phone": "+70729579313"}
0005433035929	7116BE	1128 821025	EVGENIY PAVLOV	{"phone": "+70585977171"}
0005433035930	7116BE	8371 458371	SERGEY FEDOROV	{"email": "fedorov_sergey.091956@postgrespro.ru", "phone": "+70173552793"}
0005433035931	08BE45	4522 536271	DARYA POPOVA	{"email": "popovad091972@postgrespro.ru", "phone": "+70720453609"}
0005433035932	04948A	5336 147671	MIKHAIL ALEKSANDROV	{"phone": "+70062894944"}
0005433035933	DA049B	7775 225374	IVAN ZAYCEV	{"email": "zaycev_ivan_1972@postgrespro.ru", "phone": "+70307995351"}
0005433035934	9B4AB9	1852 642134	DMITRIY ANDREEV	{"phone": "+70563178929"}
0005433035935	9B4AB9	5436 789215	ANDREY ISAEV	{"email": "andrey_isaev.1965@postgrespro.ru", "phone": "+70143575994"}
0005433035936	426438	4778 755393	VALENTINA VASILEVA	{"phone": "+70023954631"}
0005433035937	426438	8666 332364	NATALYA KUZMINA	{"phone": "+70979503695"}
0005433035938	426438	7631 074961	VLADIMIR BORISOV	{"email": "vladimir-borisov1968@postgrespro.ru", "phone": "+70400762725"}
0005433035939	B8A63D	5473 972578	ELENA ANDREEVA	{"email": "andreeva-e_111958@postgrespro.ru", "phone": "+70253290697"}
0005433035940	0723AD	0352 401470	ANASTASIYA KUZNECOVA	{"phone": "+70321669780"}
0005433035941	0723AD	5692 234981	MIKHAIL OSIPOV	{"phone": "+70164209886"}
0005433035942	0598E2	3011 603745	SERGEY BELOV	{"phone": "+70963812947"}
0005433035943	76B8E0	9108 921984	GLEB NIKOLAEV	{"phone": "+70883692725"}
0005433035944	8AB191	2891 777724	DARINA KUZNECOVA	{"email": "darinakuznecova31101986@postgrespro.ru", "phone": "+70283559969"}
0005433035945	8AB191	5214 587264	VLADIMIR NIKOLAEV	{"email": "nikolaev_v-111980@postgrespro.ru", "phone": "+70586622797"}
0005433035946	568B8C	2969 836083	VLADIMIR ZHURAVLEV	{"phone": "+70598120798"}
0005433035947	4FA0CD	0951 996417	NATALYA KUZMINA	{"email": "kuzmina.natalya1969@postgrespro.ru", "phone": "+70326316935"}
0005433035948	526EBD	5831 995522	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy.1971@postgrespro.ru", "phone": "+70177003152"}
0005433035949	83EE3D	2652 613787	VIKTOR FROLOV	{"email": "frolovv_041979@postgrespro.ru", "phone": "+70518158678"}
0005433035950	83EE3D	4846 024455	NIKITA KOZLOV	{"email": "nikita_kozlov-15051971@postgrespro.ru", "phone": "+70443873548"}
0005433035951	3D7D85	6965 490435	NIKITA PETROV	{"phone": "+70227264002"}
0005433035952	3D7D85	3195 320176	ALEKSANDR EGOROV	{"email": "egorovaleksandr-111973@postgrespro.ru", "phone": "+70624674971"}
0005433035953	3D7D85	7602 811583	OLGA KALININA	{"phone": "+70110708070"}
0005433035954	DFD2D9	6912 807674	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr-081978@postgrespro.ru", "phone": "+70485274332"}
0005433035955	3E4A82	1322 148783	ELENA MATVEEVA	{"email": "e.matveeva-1970@postgrespro.ru", "phone": "+70911666650"}
0005433035956	3E4A82	6289 302311	DMITRIY ZAKHAROV	{"email": "dmitriy-zakharov1984@postgrespro.ru", "phone": "+70453109123"}
0005433035957	39FD7A	1703 397937	VERA KONDRATEVA	{"email": "kondrateva.v_021985@postgrespro.ru", "phone": "+70384366220"}
0005433035958	EA31E4	8359 908914	EKATERINA NAZAROVA	{"phone": "+70279380893"}
0005433035959	24D05A	5976 677053	GALINA MIRONOVA	{"phone": "+70456293840"}
0005433035960	07C8FD	9416 502344	NATALYA FILIPPOVA	{"phone": "+70972237750"}
0005433035961	1CEE1B	4799 999815	EVGENIY ALEKSEEV	{"email": "e.alekseev_1978@postgrespro.ru", "phone": "+70168055435"}
0005433035962	49055C	0699 080752	DENIS NAUMOV	{"phone": "+70718712642"}
0005433035963	E739D9	6146 256812	YURIY NOVIKOV	{"email": "novikov-y041970@postgrespro.ru", "phone": "+70615392738"}
0005433035964	E739D9	6554 566301	INNA KULIKOVA	{"email": "inna.kulikova_111988@postgrespro.ru", "phone": "+70558605393"}
0005433035965	FCFE59	9469 243221	DENIS KUZMIN	{"phone": "+70178764863"}
0005433035966	FEEA12	4474 255231	VLADIMIR MOROZOV	{"email": "v-morozov.28011974@postgrespro.ru", "phone": "+70027246179"}
0005433035967	FEEA12	2925 822698	ELENA DANILOVA	{"email": "elena-danilova.1971@postgrespro.ru", "phone": "+70185972396"}
0005433035968	FEEA12	3547 533906	NATALYA TARASOVA	{"email": "ntarasova-121968@postgrespro.ru", "phone": "+70716183427"}
0005433035969	24388F	3893 938737	FARIDA TIKHONOVA	{"phone": "+70938752332"}
0005433035970	1BEF46	5973 281716	GALINA DENISOVA	{"phone": "+70817013764"}
0005433035971	E6A0D3	4497 944237	NINA BELOVA	{"phone": "+70413169974"}
0005433035972	691F9F	2546 121155	EKATERINA KONOVALOVA	{"phone": "+70734338415"}
0005433035973	08A66E	7575 693807	ARTEM SCHERBAKOV	{"email": "scherbakov-artem011966@postgrespro.ru", "phone": "+70090620439"}
0005433035974	08A66E	1228 104030	OLEG SEMENOV	{"email": "semenovo.011962@postgrespro.ru", "phone": "+70777111277"}
0005433035975	155F26	9289 210847	LYUDMILA VASILEVA	{"phone": "+70456656823"}
0005433035976	155F26	6935 973879	GALINA VASILEVA	{"email": "gvasileva_031980@postgrespro.ru", "phone": "+70404980265"}
0005433035977	A5DAE0	4571 046744	ANATOLIY ZAKHAROV	{"phone": "+70644011962"}
0005433035978	A5DAE0	1433 068673	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev-021977@postgrespro.ru", "phone": "+70191501962"}
0005433035979	BC3513	1425 704365	KONSTANTIN NIKOLAEV	{"phone": "+70868322569"}
0005433035980	2D8462	7384 739552	VIKTOR CHERNOV	{"email": "viktorchernov1967@postgrespro.ru", "phone": "+70021502786"}
0005433035981	E71455	5267 767552	VALERIY SIDOROV	{"email": "sidorov-valeriy.081977@postgrespro.ru", "phone": "+70976644929"}
0005433035982	308682	6324 726767	NIKOLAY CHERNOV	{"email": "chernov-nikolay-121968@postgrespro.ru", "phone": "+70986756102"}
0005433035983	51D191	9727 491761	ZOYA MATVEEVA	{"email": "matveeva.zoya051975@postgrespro.ru", "phone": "+70960812734"}
0005433035984	51D191	8538 280485	MARINA NESTEROVA	{"phone": "+70643182983"}
0005433035985	51D191	8459 144595	SEMEN PETROV	{"email": "semen-petrov_1963@postgrespro.ru", "phone": "+70063679689"}
0005433035986	D17EAE	1228 954597	SOFIYA OSIPOVA	{"email": "osipova.sofiya041966@postgrespro.ru", "phone": "+70632402445"}
0005433035987	7B8FDD	0230 196354	TATYANA SERGEEVA	{"email": "tatyana_sergeeva_1965@postgrespro.ru", "phone": "+70359991022"}
0005433035988	7B8FDD	3142 551900	ALEKSANDR KARPOV	{"email": "karpov-a_041974@postgrespro.ru", "phone": "+70425589746"}
0005433035989	BD3131	6838 691032	ELLA NIKITINA	{"phone": "+70663687158"}
0005433035990	17FD0B	5482 698588	TATYANA BELOVA	{"phone": "+70745809736"}
0005433035991	9BEA2D	1162 052159	TATYANA NIKITINA	{"phone": "+70630894312"}
0005433035992	1F11DE	4239 590259	EVGENIY ANDREEV	{"email": "andreev-evgeniy_1966@postgrespro.ru", "phone": "+70022336940"}
0005433035993	C84FC6	1217 939510	OLESYA NESTEROVA	{"email": "o_nesterova-23091982@postgrespro.ru", "phone": "+70251730975"}
0005433035994	D141B5	2314 848252	KIRILL IVANOV	{"phone": "+70421585747"}
0005433035995	94192C	9052 004236	LIDIYA FOMINA	{"phone": "+70879253391"}
0005433035996	61BA78	2616 404437	TATYANA NIKITINA	{"phone": "+70777969286"}
0005433035997	53631B	3684 314634	SVETLANA YAKOVLEVA	{"email": "yakovleva_svetlana-111964@postgrespro.ru", "phone": "+70569387491"}
0005433035998	53631B	2458 096907	VIKTOR TIMOFEEV	{"email": "timofeev-viktor_041973@postgrespro.ru", "phone": "+70897199904"}
0005433035999	68BA42	5419 263771	NATALIYA SOKOLOVA	{"email": "nataliyasokolova1969@postgrespro.ru", "phone": "+70897219885"}
0005433036000	68BA42	1829 329939	MILANA BORISOVA	{"phone": "+70149082418"}
0005433036001	1B2498	8467 144553	MIKHAIL PAVLOV	{"email": "mikhail-pavlov_03041981@postgrespro.ru", "phone": "+70377218934"}
0005433036002	81760E	0634 313744	ANDREY TIMOFEEV	{"phone": "+70608091035"}
0005433036003	D890CE	1801 326984	EKATERINA FROLOVA	{"phone": "+70513376029"}
0005433036004	85BF75	8604 587695	ANDREY PAVLOV	{"email": "andrey.pavlov.20061963@postgrespro.ru", "phone": "+70322610726"}
0005433036005	85BF75	0215 900704	MARIYA YAKOVLEVA	{"phone": "+70170089430"}
0005433036006	BD197B	5661 836485	YAROSLAV IVANOV	{"email": "y_ivanov04041968@postgrespro.ru", "phone": "+70029212186"}
0005433036007	BD197B	6829 702277	VLADIMIR NAZAROV	{"email": "nazarovvladimir081969@postgrespro.ru", "phone": "+70688472529"}
0005433036008	4BD2FD	5659 411576	SERGEY STEPANOV	{"phone": "+70848415252"}
0005433036009	EF2B24	1189 661143	GALINA KUZNECOVA	{"phone": "+70026324636"}
0005433036010	9A4F2A	9272 107402	DARYA YUDINA	{"phone": "+70674503636"}
0005433036011	0F49FC	7261 455503	LYUDMILA MAKAROVA	{"phone": "+70884168511"}
0005433036012	7ECC2D	5348 130606	NATALYA PETROVA	{"email": "petrovanatalya21051971@postgrespro.ru", "phone": "+70018050085"}
0005433036013	7ECC2D	0224 319437	NATALYA KUZNECOVA	{"email": "natalya.kuznecova011962@postgrespro.ru", "phone": "+70074926658"}
0005433036014	350460	5188 087706	SERGEY TARASOV	{"email": "tarasovsergey-011967@postgrespro.ru", "phone": "+70623655007"}
0005433036015	615696	9777 094930	VASILIY BORISOV	{"email": "borisovv28041968@postgrespro.ru", "phone": "+70032917814"}
0005433036016	EDDB18	9757 168796	SVETLANA ALEKSEEVA	{"phone": "+70643077379"}
0005433036017	B644C8	1502 585964	VALENTINA MELNIKOVA	{"email": "melnikova_v121967@postgrespro.ru", "phone": "+70040597251"}
0005433036018	7007FB	6037 434561	IRINA EGOROVA	{"phone": "+70175215300"}
0005433036019	49B8BC	6429 204243	ILYA GAVRILOV	{"phone": "+70914620203"}
0005433036020	49B8BC	4548 214851	LYUBOV ZAKHAROVA	{"email": "lyubov-zakharova.091968@postgrespro.ru", "phone": "+70591683582"}
0005433036021	BB4D01	8420 221297	KONSTANTIN KUZNECOV	{"phone": "+70753993956"}
0005433036022	841084	5910 500511	DMITRIY VLASOV	{"email": "vlasov.dmitriy-031977@postgrespro.ru", "phone": "+70287799843"}
0005433036023	D7BC9C	0463 776340	NATALYA PETROVA	{"email": "petrova_natalya_1965@postgrespro.ru", "phone": "+70843391090"}
0005433036024	76EB34	1315 690319	MIKHAIL KAZAKOV	{"phone": "+70097235511"}
0005433036025	3E89AA	4985 410152	EVGENIY BORISOV	{"phone": "+70989424048"}
0005433036026	3E89AA	6500 469163	NADEZHDA KALININA	{"phone": "+70148909590"}
0005433036027	4553D3	3768 601943	TAMARA SERGEEVA	{"phone": "+70473769502"}
0005433036028	932FE7	9388 673497	MAKSIM IVANOV	{"phone": "+70173407321"}
0005433036029	3C324F	4084 687987	SVETLANA YAKOVLEVA	{"phone": "+70038513925"}
0005433036030	AE2D50	6573 566213	ALEKSANDR GUSEV	{"phone": "+70183768621"}
0005433036031	7C9C37	0883 618856	MIKHAIL ANTONOV	{"email": "antonov.m-101976@postgrespro.ru", "phone": "+70863821430"}
0005433036032	A14831	6321 157449	MAKSIM NAZAROV	{"phone": "+70786341524"}
0005433036033	867972	0264 670918	LYUBOV ZAYCEVA	{"email": "lyubovzayceva.061981@postgrespro.ru", "phone": "+70258927660"}
0005433036034	867972	6695 558953	NIKOLAY SEMENOV	{"phone": "+70680186766"}
0005433036035	C91612	6332 314274	VALENTINA ANTONOVA	{"email": "antonova.valentina1967@postgrespro.ru", "phone": "+70299428570"}
0005433036036	C91612	2693 518590	MARINA BELYAEVA	{"email": "belyaeva-marina_31121976@postgrespro.ru", "phone": "+70923461617"}
0005433036037	948A17	4484 594166	VIKTOR GRIGOREV	{"phone": "+70028096266"}
0005433036038	7569F7	6741 737018	VALENTINA SERGEEVA	{"phone": "+70702750104"}
0005433036039	66A0FA	8108 941456	OLESYA SCHERBAKOVA	{"phone": "+70345230606"}
0005433036040	66A0FA	3133 686028	LILIYA NOVIKOVA	{"email": "novikova-liliya.101966@postgrespro.ru", "phone": "+70851325033"}
0005433036041	A20347	9722 272523	VLADIMIR ZAYCEV	{"email": "vladimir_zaycev-1974@postgrespro.ru", "phone": "+70034604480"}
0005433036042	2FE84E	6018 665542	ANDREY MELNIKOV	{"phone": "+70354347505"}
0005433036043	2FE84E	2098 474581	VADIM ANTONOV	{"email": "vantonov-22031973@postgrespro.ru", "phone": "+70922059903"}
0005433036044	EAC321	9992 793099	ALEKSANDR ANTONOV	{"phone": "+70326807360"}
0005433036045	1E6AC3	2284 433300	EVGENIY RODIONOV	{"email": "rodionov-evgeniy.021965@postgrespro.ru", "phone": "+70021975124"}
0005433036046	1E6AC3	8939 019037	ELENA SEMENOVA	{"phone": "+70042725769"}
0005433036047	6BFAF1	5308 635308	VYACHESLAV VLASOV	{"email": "v.vlasov_041962@postgrespro.ru", "phone": "+70937422563"}
0005433036048	123045	5042 221088	NIKITA KUZMIN	{"phone": "+70113061034"}
0005433036049	BB38B4	6258 584316	VIKTORIYA MEDVEDEVA	{"email": "medvedeva.viktoriya031976@postgrespro.ru", "phone": "+70685140027"}
0005433036050	BB38B4	0824 632339	MAKSIM KOZLOV	{"email": "kozlovmaksim_081967@postgrespro.ru", "phone": "+70909692667"}
0005433036051	BB38B4	3065 145067	LILIYA KOZLOVA	{"email": "kozlova.l.05111969@postgrespro.ru", "phone": "+70518041251"}
0005433036052	DC709B	8802 994008	ELENA PETROVA	{"email": "e.petrova.1970@postgrespro.ru", "phone": "+70917783746"}
0005433036053	DC709B	1321 729895	VALERIY ILIN	{"email": "valeriy_ilin.10041968@postgrespro.ru", "phone": "+70428889337"}
0005433036054	2E8825	1525 898463	ALEKSANDRA KONOVALOVA	{"email": "konovalova-a10071963@postgrespro.ru", "phone": "+70011763834"}
0005433036055	3FFAE4	1171 156909	DMITRIY GRIGOREV	{"email": "dmitriy.grigorev.091974@postgrespro.ru", "phone": "+70020339730"}
0005433036056	11AC7B	6733 130728	PAVEL SOKOLOV	{"email": "sokolov-p_1969@postgrespro.ru", "phone": "+70973000991"}
0005433036057	5C634F	4050 622838	MARINA KISELEVA	{"email": "kiselevam-1972@postgrespro.ru", "phone": "+70503667913"}
0005433036058	5C634F	5483 268325	ELENA RODIONOVA	{"email": "elena_rodionova_09101967@postgrespro.ru", "phone": "+70598912003"}
0005433036059	B4B4FE	5406 777929	YAN POPOV	{"email": "yan-popov-081977@postgrespro.ru", "phone": "+70254290885"}
0005433036060	CFB2C8	1420 114283	MARIYA VASILEVA	{"email": "vasilevamariya-25081974@postgrespro.ru", "phone": "+70091525498"}
0005433036061	576BD6	2527 835608	LARISA EGOROVA	{"phone": "+70294865215"}
0005433036062	576BD6	6097 732913	OKSANA ABRAMOVA	{"email": "abramovao-041962@postgrespro.ru", "phone": "+70535962157"}
0005433036063	55539B	8260 111847	RUSTAM FEDOTOV	{"email": "fedotov.r-1980@postgrespro.ru", "phone": "+70733967617"}
0005433036064	4143BF	5897 333416	GALINA IVANOVA	{"email": "galina-ivanova_29081973@postgrespro.ru", "phone": "+70721554002"}
0005433036065	8430ED	8442 174623	NADEZHDA ILINA	{"email": "ilina_n09031960@postgrespro.ru", "phone": "+70341575885"}
0005433036066	B03435	7479 063435	LIDIYA SOROKINA	{"email": "lidiyasorokina_1962@postgrespro.ru", "phone": "+70470350277"}
0005433036067	6E3220	5834 683944	TATYANA GORBUNOVA	{"phone": "+70832986714"}
0005433036068	6FADE9	7149 504502	ANNA SMIRNOVA	{"email": "smirnova.anna.09111978@postgrespro.ru", "phone": "+70024477220"}
0005433036069	582600	0443 284208	MAKSIM SOLOVEV	{"phone": "+70899757608"}
0005433036070	9801B6	9650 995427	ROZA SEMENOVA	{"phone": "+70699063911"}
0005433036071	B426A6	5025 436355	IVAN ZAYCEV	{"email": "ivanzaycev_061981@postgrespro.ru", "phone": "+70647335246"}
0005433036072	B426A6	7393 072898	ANDREY FEDOROV	{"email": "afedorov-27121965@postgrespro.ru", "phone": "+70840363237"}
0005433036073	06F429	3831 812868	IGOR STEPANOV	{"phone": "+70319571837"}
0005433036074	AA7025	1274 861789	NIKOLAY EGOROV	{"email": "nikolayegorov25071977@postgrespro.ru", "phone": "+70931742984"}
0005433036075	AA7025	7653 105895	SERGEY ALEKSEEV	{"email": "alekseev.s091983@postgrespro.ru", "phone": "+70312946735"}
0005433036076	2876E3	7967 509788	ALEKSANDR FEDOROV	{"phone": "+70388919892"}
0005433036077	575DCC	7644 800819	LIDIYA MOROZOVA	{"phone": "+70241807266"}
0005433036078	F6B5E7	6428 514719	ARINA KARPOVA	{"phone": "+70944865516"}
0005433036079	D8DC6E	3197 673866	NINA GORBUNOVA	{"phone": "+70878403970"}
0005433036080	751D8D	7058 102214	EVGENIY ZAYCEV	{"phone": "+70337845675"}
0005433036081	F86A4A	9666 575602	LEONID CHERNOV	{"email": "lchernov-1973@postgrespro.ru", "phone": "+70930358409"}
0005433036082	94D07F	2679 699108	VLADIMIR SCHERBAKOV	{"phone": "+70098467518"}
0005433036083	7C23C3	5475 460344	EKATERINA LUKYANOVA	{"phone": "+70752485761"}
0005433036084	75477A	4162 948482	TATYANA IVANOVA	{"email": "tatyana.ivanova.1979@postgrespro.ru", "phone": "+70922456204"}
0005433036085	80DFF3	9002 574943	NINA PAVLOVA	{"phone": "+70402523439"}
0005433036086	807956	6316 854663	ROMAN MOROZOV	{"email": "r_morozov09071982@postgrespro.ru", "phone": "+70601512757"}
0005433036087	27BFE4	5849 643456	EGOR MATVEEV	{"email": "e-matveev_081970@postgrespro.ru", "phone": "+70399851011"}
0005433036088	27BFE4	5900 180023	NADEZHDA MOROZOVA	{"phone": "+70610715047"}
0005433036089	27BFE4	1487 969482	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr-13021969@postgrespro.ru", "phone": "+70798687127"}
0005433036090	47B738	5819 943227	SVETLANA FILIPPOVA	{"email": "s_filippova_07031977@postgrespro.ru", "phone": "+70484240002"}
0005433036091	47B738	9092 980985	GENNADIY SOLOVEV	{"phone": "+70830111929"}
0005433036092	679FC1	0632 533574	DARYA KISELEVA	{"phone": "+70074528901"}
0005433036093	1B5962	3403 169575	MAKSIM DENISOV	{"email": "maksimdenisov.1978@postgrespro.ru", "phone": "+70432865515"}
0005433036094	B0E63D	6351 036902	DANILA SERGEEV	{"phone": "+70906211069"}
0005433036095	8A1EE8	9072 196932	DENIS NOVIKOV	{"email": "denisnovikov_25101973@postgrespro.ru", "phone": "+70761365252"}
0005433036096	73501F	3528 422665	ANNA ZHUKOVA	{"phone": "+70853098565"}
0005433036097	73501F	5957 973848	NADEZHDA ROMANOVA	{"email": "n-romanova_23011969@postgrespro.ru", "phone": "+70775628527"}
0005433036098	3F9E0B	6380 241066	VALENTIN GORBUNOV	{"phone": "+70814196112"}
0005433036099	3F9E0B	4946 259381	MIKHAIL MIRONOV	{"email": "mironov_m_1968@postgrespro.ru", "phone": "+70246244521"}
0005433036100	20BF06	3177 729177	VLADA MOISEEVA	{"phone": "+70449725119"}
0005433036101	F9919D	4357 693264	YULIYA IVANOVA	{"phone": "+70332516425"}
0005433036102	AE0DDA	1499 803925	VALENTIN DAVYDOV	{"phone": "+70797246615"}
0005433036103	11A6C5	3116 617254	POLINA FOMINA	{"phone": "+70295877410"}
0005433036104	11A6C5	9759 099287	KIRILL VOLKOV	{"phone": "+70664654750"}
0005433036105	1723F5	9952 867765	LARISA ZHUKOVA	{"email": "zhukova_l-1980@postgrespro.ru", "phone": "+70710252696"}
0005433036106	F51F90	8296 318908	NATALYA OSIPOVA	{"email": "n.osipova_121967@postgrespro.ru", "phone": "+70639079064"}
0005433036107	891C8A	2606 507015	RAMILYA ZHURAVLEVA	{"email": "zhuravleva_ramilya1973@postgrespro.ru", "phone": "+70517311823"}
0005433036108	A217D8	4511 694661	LARISA DENISOVA	{"phone": "+70868677061"}
0005433036109	A217D8	7823 491919	FATYMA VOLKOVA	{"phone": "+70256682583"}
0005433036110	FBF765	1121 350331	EKATERINA LAZAREVA	{"email": "ekaterina-lazareva1964@postgrespro.ru", "phone": "+70610165522"}
0005433036111	CC9561	8191 508063	GENNADIY SERGEEV	{"phone": "+70839931714"}
0005433036112	CC9561	6143 439701	IGOR NIKITIN	{"phone": "+70078255040"}
0005433036113	CC9561	2960 004423	ELENA KULIKOVA	{"email": "elena.kulikova-25101969@postgrespro.ru", "phone": "+70732685143"}
0005433036114	44FEF2	0164 747112	ALEKSANDRA EGOROVA	{"email": "aleksandra-egorova.26051977@postgrespro.ru", "phone": "+70955794759"}
0005433036115	5716C6	2365 008962	LYUBOV IVANOVA	{"email": "lyubov-ivanova-061968@postgrespro.ru", "phone": "+70710892849"}
0005433036116	B25CC0	9475 509801	PAVEL ZHURAVLEV	{"email": "pzhuravlev.1968@postgrespro.ru", "phone": "+70799094932"}
0005433036117	B25CC0	8878 143065	ANATOLIY VOROBEV	{"phone": "+70071098770"}
0005433036118	D598E2	0280 330931	EDUARD ANDREEV	{"phone": "+70209685299"}
0005433036119	4BAF1D	4233 229968	NATALYA ZHUKOVA	{"email": "zhukova-n31071975@postgrespro.ru", "phone": "+70007037711"}
0005433036120	648773	4629 573765	VERA GUSEVA	{"email": "vera_guseva061959@postgrespro.ru", "phone": "+70831236620"}
0005433036121	F82178	9701 311067	IVAN ABRAMOV	{"phone": "+70884200646"}
0005433036122	94472F	6854 846952	NADEZHDA RYABOVA	{"email": "ryabova-n.09031973@postgrespro.ru", "phone": "+70473375987"}
0005433036123	B8619C	6187 017916	VLADIMIR KOROLEV	{"email": "vladimir_korolev-1977@postgrespro.ru", "phone": "+70396821079"}
0005433036124	E8AAD4	6112 919618	ANATOLIY SEMENOV	{"email": "asemenov_27051966@postgrespro.ru", "phone": "+70270803193"}
0005433036125	4A44AA	8259 305141	SERGEY PAVLOV	{"email": "spavlov_1965@postgrespro.ru", "phone": "+70204439887"}
0005433036126	4A44AA	7665 663796	GALINA ROMANOVA	{"email": "romanova-galina091975@postgrespro.ru", "phone": "+70059184881"}
0005433036127	8C5057	3271 880640	VALENTINA KONDRATEVA	{"phone": "+70555534368"}
0005433036128	82DC9C	4034 210959	ALENA ANDREEVA	{"email": "andreevaalena.1971@postgrespro.ru", "phone": "+70524403979"}
0005433036129	82DC9C	7975 907298	DMITRIY IVANOV	{"phone": "+70795436994"}
0005433036130	E47E77	4044 342941	KONSTANTIN FILIPPOV	{"email": "filippov.k-04081970@postgrespro.ru", "phone": "+70103004165"}
0005433036131	F47AF9	7360 473702	LYUDMILA RYABOVA	{"phone": "+70956575495"}
0005433036132	F47AF9	6395 921304	VIKTOR MATVEEV	{"phone": "+70093322849"}
0005433036133	3C5694	2415 124854	VALERIY DAVYDOV	{"email": "valeriy.davydov.1966@postgrespro.ru", "phone": "+70235517222"}
0005433036134	3B29D8	0797 818404	SERGEY PAVLOV	{"email": "pavlovs25061976@postgrespro.ru", "phone": "+70995220086"}
0005433036135	3B29D8	9819 937749	OKSANA PAVLOVA	{"email": "o.pavlova_1981@postgrespro.ru", "phone": "+70814827593"}
0005433036136	565C2B	0683 388984	IGOR GAVRILOV	{"email": "gavrilov_igor.031982@postgrespro.ru", "phone": "+70353977219"}
0005433036137	307BB7	4521 214193	DANILA SIDOROV	{"email": "danilasidorov-1980@postgrespro.ru", "phone": "+70410664105"}
0005433036138	307BB7	0076 279097	GALINA NOVIKOVA	{"email": "novikova-galina.081976@postgrespro.ru", "phone": "+70626808526"}
0005433036139	578C86	7438 941089	BORIS SMIRNOV	{"phone": "+70485113732"}
0005433036140	578C86	0446 247353	ANASTASIYA VOLKOVA	{"email": "anastasiyavolkova-19051964@postgrespro.ru", "phone": "+70027708439"}
0005433036141	7F78ED	9958 814607	LARISA DAVYDOVA	{"phone": "+70077229553"}
0005433036142	7F78ED	2968 836850	OLGA NAZAROVA	{"phone": "+70798645798"}
0005433036143	7F78ED	6056 112261	VLADIMIR ISAEV	{"email": "isaev_v_1982@postgrespro.ru", "phone": "+70124728231"}
0005433036144	7F78ED	8022 004553	LYUDMILA NIKITINA	{"email": "l_nikitina.02111966@postgrespro.ru", "phone": "+70992718753"}
0005433036145	952619	5223 910399	ALBINA YUDINA	{"phone": "+70301965873"}
0005433036146	788059	9856 614545	PAVEL BONDARENKO	{"email": "bondarenko_pavel091964@postgrespro.ru", "phone": "+70288325483"}
0005433036147	788059	7309 175747	VALENTINA GORBUNOVA	{"email": "gorbunova-valentina-1973@postgrespro.ru", "phone": "+70048328417"}
0005433036148	E44A84	6211 808444	LEONID EGOROV	{"email": "egorov-leonid26011968@postgrespro.ru", "phone": "+70823737627"}
0005433036149	E44A84	8332 904914	KSENIYA SERGEEVA	{"phone": "+70009084840"}
0005433036150	F2CE36	4983 290895	ALEKSEY OSIPOV	{"email": "aleksey_osipov.061969@postgrespro.ru", "phone": "+70504119691"}
0005433036151	F2CE36	3109 769293	ELIZAVETA KULIKOVA	{"phone": "+70931747591"}
0005433036152	C9198B	4778 724698	VLADIMIR DENISOV	{"phone": "+70866966436"}
0005433036153	0002F3	1001 058091	ILYA MOROZOV	{"email": "ilyamorozov_031978@postgrespro.ru", "phone": "+70123614037"}
0005433036154	0002F3	6805 332631	ILYA PETROV	{"email": "ipetrov14061968@postgrespro.ru", "phone": "+70891846264"}
0005433036155	0002F3	7293 080905	NATALYA KISELEVA	{"email": "n_kiseleva-16071971@postgrespro.ru", "phone": "+70989197928"}
0005433036156	D40184	6446 006292	NIKITA KULIKOV	{"email": "kulikov_nikita-1960@postgrespro.ru", "phone": "+70958816609"}
0005433036157	D40184	6101 429399	VLADIMIR ZAYCEV	{"phone": "+70455245462"}
0005433036158	69146E	3644 024551	TARAS KUZNECOV	{"email": "kuznecovtaras_081972@postgrespro.ru", "phone": "+70253101732"}
0005433036159	FF9025	5902 033849	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev.02051970@postgrespro.ru", "phone": "+70503278542"}
0005433036160	FF9025	3854 658132	BORIS MIRONOV	{"phone": "+70144642752"}
0005433036161	FF9025	6036 280105	LYUBOV BORISOVA	{"email": "borisovalyubov.121972@postgrespro.ru", "phone": "+70231238284"}
0005433036162	E444F3	2488 387598	SEMEN SHEVCHENKO	{"phone": "+70552093650"}
0005433036163	E444F3	2436 376228	ALEKSANDR SAVELEV	{"email": "asavelev-25031972@postgrespro.ru", "phone": "+70913625748"}
0005433036164	FA9A96	2381 474072	VADIM ALEKSEEV	{"phone": "+70752730350"}
0005433036165	2BF0F5	9470 625026	DMITRIY ANTONOV	{"email": "dmitriyantonov-031969@postgrespro.ru", "phone": "+70852363218"}
0005433036166	613418	3616 189751	PETR PETROV	{"email": "petrov-petr-1973@postgrespro.ru", "phone": "+70426224861"}
0005433036167	0E8650	3765 803296	ELENA LUKYANOVA	{"email": "lukyanova-elena05031961@postgrespro.ru", "phone": "+70857502294"}
0005433036168	98267B	2912 897520	MAKSIM SMIRNOV	{"phone": "+70537848860"}
0005433036169	98267B	9613 440908	IGOR ROMANOV	{"phone": "+70630703012"}
0005433036170	E5EB48	3658 550287	NATALYA KUZMINA	{"email": "natalya_kuzmina.1966@postgrespro.ru", "phone": "+70192858354"}
0005433036171	E5EB48	0940 555014	ANDREY KOZLOV	{"email": "andreykozlov_1975@postgrespro.ru", "phone": "+70973480541"}
0005433036172	F164C9	6312 181600	ILDAR TIKHONOV	{"email": "tikhonov_i-1972@postgrespro.ru", "phone": "+70583554455"}
0005433036173	CCCCE1	6261 834507	EKATERINA TITOVA	{"email": "etitova.1982@postgrespro.ru", "phone": "+70749113975"}
0005433036174	9E5CE9	8679 907512	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov_061984@postgrespro.ru", "phone": "+70275030845"}
0005433036175	081F53	5763 462606	POLINA MAKAROVA	{"email": "makarova_polina-13011971@postgrespro.ru", "phone": "+70227398082"}
0005433036176	49AEFB	4189 086281	LYUBOV NAZAROVA	{"phone": "+70697958040"}
0005433036177	720F84	5068 588096	ANDREY BELOV	{"email": "a-belov-06091962@postgrespro.ru", "phone": "+70080867023"}
0005433036178	6A5A82	3429 378506	IVAN VOLKOV	{"phone": "+70369048848"}
0005433036179	4C28FA	3146 945249	VERA GRISHINA	{"phone": "+70443577613"}
0005433036180	4C28FA	6804 016659	IVAN KISELEV	{"email": "ivan.kiselev-01111972@postgrespro.ru", "phone": "+70637025821"}
0005433036181	74705B	7506 600495	ANATOLIY KRASNOV	{"email": "a_krasnov011977@postgrespro.ru", "phone": "+70245440622"}
0005433036182	405725	4868 680033	ANDREY KOZLOV	{"phone": "+70992157071"}
0005433036183	3D4904	1254 850872	IRINA KONOVALOVA	{"email": "ikonovalova_02041966@postgrespro.ru", "phone": "+70252254820"}
0005433036184	3D4904	6488 227329	ALEKSEY ANTONOV	{"phone": "+70173847700"}
0005433036185	579ABE	1901 421597	NIKOLAY SOROKIN	{"email": "nikolay-sorokin.25051976@postgrespro.ru", "phone": "+70046829101"}
0005433036186	579ABE	0375 513604	GRIGORIY ZAKHAROV	{"email": "zakharovgrigoriy.18051968@postgrespro.ru", "phone": "+70827875348"}
0005433036187	AAF4F5	0818 827814	NELLI KULIKOVA	{"phone": "+70630776211"}
0005433036188	AAF4F5	9573 334515	NATALYA MOROZOVA	{"email": "natalya-morozova-26081969@postgrespro.ru", "phone": "+70419619086"}
0005433036189	AAF4F5	2836 511335	TAMARA SCHERBAKOVA	{"email": "scherbakova_t.27111968@postgrespro.ru", "phone": "+70114078993"}
0005433036190	781912	6557 413856	OLGA AFANASEVA	{"phone": "+70368175092"}
0005433036191	E437E3	7708 117876	EKATERINA CHERNOVA	{"phone": "+70728498807"}
0005433036192	A29A9E	5289 943154	ANDREY SMIRNOV	{"email": "a_smirnov-071984@postgrespro.ru", "phone": "+70334556873"}
0005433036193	60B32F	7152 949679	OLGA KARPOVA	{"email": "o_karpova-1968@postgrespro.ru", "phone": "+70373052263"}
0005433036194	60B32F	2688 248956	LILIYA NIKOLAEVA	{"email": "nikolaeva-liliya-19081969@postgrespro.ru", "phone": "+70714589300"}
0005433036195	EB3799	6911 797135	DMITRIY TARASOV	{"phone": "+70089875275"}
0005433036196	1A162D	2871 453413	SERGEY SCHERBAKOV	{"phone": "+70402603805"}
0005433036197	2DADE1	1069 998443	VALERIY YAKOVLEV	{"phone": "+70242103851"}
0005433036198	2DADE1	0668 085429	ANASTASIYA EFIMOVA	{"email": "efimova.a19031979@postgrespro.ru", "phone": "+70394846620"}
0005433036199	21BF9B	4568 112952	OLEG BARANOV	{"phone": "+70691771461"}
0005433036200	506CE1	1712 972250	ALENA ANDREEVA	{"phone": "+70891599816"}
0005433036201	506CE1	7050 139490	ALEKSANDR SOLOVEV	{"phone": "+70455818433"}
0005433036202	57D226	5995 814436	TAMARA GORBUNOVA	{"phone": "+70359766902"}
0005433036203	57D226	3084 347511	FEDOR FILIPPOV	{"email": "fedor-filippov-06071976@postgrespro.ru", "phone": "+70792493652"}
0005433036204	749054	1508 088454	ALEKSEY MAKAROV	{"email": "makarov_aleksey_1969@postgrespro.ru", "phone": "+70669769703"}
0005433036205	C31B05	8542 798143	ALEKSANDRA SOKOLOVA	{"phone": "+70480571251"}
0005433036206	BC7B8E	6324 407198	MARIYA BELOVA	{"phone": "+70820275450"}
0005433036207	BC7B8E	8497 195237	NIKOLAY KOROLEV	{"email": "n.korolev.111972@postgrespro.ru", "phone": "+70047757351"}
0005433036208	CAAACC	1469 943435	TATYANA TROFIMOVA	{"email": "trofimova.tatyana.051964@postgrespro.ru", "phone": "+70557384148"}
0005433036209	FEB94C	2371 265146	NATALYA FILIPPOVA	{"email": "filippova.n29081982@postgrespro.ru", "phone": "+70418612414"}
0005433036210	51428D	5730 387342	ANDREY PETROV	{"email": "apetrov.071969@postgrespro.ru", "phone": "+70619328006"}
0005433036211	51428D	6309 327072	DIANA KULIKOVA	{"email": "diana_kulikova.16061970@postgrespro.ru", "phone": "+70501374141"}
0005433036212	430E4C	6332 812064	NATALYA BORISOVA	{"phone": "+70233958983"}
0005433036213	2CB821	6399 967955	ELIZAVETA MELNIKOVA	{"email": "emelnikova-1972@postgrespro.ru", "phone": "+70564093776"}
0005433036214	9BD310	1114 861149	GLEB MAKSIMOV	{"phone": "+70076774465"}
0005433036215	D8C68F	7940 150336	GENNADIY TARASOV	{"email": "g_tarasov-071978@postgrespro.ru", "phone": "+70517829473"}
0005433036216	D8C68F	8190 096224	ANDREY SEMENOV	{"phone": "+70419085370"}
0005433036217	D8C68F	2581 632061	OKSANA LOGINOVA	{"email": "loginova.o.1970@postgrespro.ru", "phone": "+70241936482"}
0005433036218	F59842	4351 944742	LILIYA KONDRATEVA	{"email": "kondrateva_l.06041984@postgrespro.ru", "phone": "+70038820399"}
0005433036219	2B91FE	6202 667653	LEONID IVANOV	{"email": "leonid-ivanov-1970@postgrespro.ru", "phone": "+70963496253"}
0005433036220	2B91FE	2586 267057	VLADIMIR DAVYDOV	{"email": "davydovvladimir.101978@postgrespro.ru", "phone": "+70838321817"}
0005433036221	A46D3C	6033 660179	VITALIY KUZNECOV	{"phone": "+70268531108"}
0005433036222	5D27F3	9657 339509	TATYANA BORISOVA	{"phone": "+70077955451"}
0005433036223	00ADDF	8864 421099	SVETLANA MIKHAYLOVA	{"phone": "+70445328903"}
0005433036224	00ADDF	0855 225261	ALEKSANDR IVANOV	{"phone": "+70388718479"}
0005433036225	3FF2E7	1515 952423	VALENTINA KOROLEVA	{"email": "v_koroleva1966@postgrespro.ru", "phone": "+70988279930"}
0005433036226	B8ECD1	1978 290198	OLGA ZAKHAROVA	{"phone": "+70569529700"}
0005433036227	143786	5140 646511	VLADIMIR SEMENOV	{"email": "semenov-vladimir07011981@postgrespro.ru", "phone": "+70290259580"}
0005433036228	B7BBEC	9518 398711	ANDREY NIKOLAEV	{"phone": "+70105488608"}
0005433036229	8F1C88	2596 043767	LYUBOV IVANOVA	{"phone": "+70011118716"}
0005433036230	8F1C88	8644 292638	ALEKSEY FEDOTOV	{"phone": "+70472263267"}
0005433036231	EDE574	1996 338082	SERGEY STEPANOV	{"phone": "+70389387704"}
0005433036232	EDE574	9130 637584	TATYANA SEMENOVA	{"email": "semenova.t.1970@postgrespro.ru", "phone": "+70379631359"}
0005433036233	1AA4DC	3322 825936	TATYANA ISAEVA	{"phone": "+70192390626"}
0005433036234	1AA4DC	1322 764898	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr1976@postgrespro.ru", "phone": "+70807993713"}
0005433036235	1AA4DC	2295 108414	VLADIMIR TIMOFEEV	{"phone": "+70860206459"}
0005433036236	94DA45	5313 374851	ALEKSANDRA NESTEROVA	{"phone": "+70518179815"}
0005433036237	6C30B4	7133 579449	IVAN KUZNECOV	{"phone": "+70321879149"}
0005433036238	E83092	1019 328589	NINA EFIMOVA	{"phone": "+70093378317"}
0005433036239	5ED4DE	4697 341203	VLADIMIR STEPANOV	{"email": "v.stepanov07051978@postgrespro.ru", "phone": "+70803090655"}
0005433036240	5ED4DE	1468 797582	ANNA SEMENOVA	{"email": "semenova.anna-01011973@postgrespro.ru", "phone": "+70730638210"}
0005433036241	CB5899	8846 730805	ALEKSANDR ROMANOV	{"phone": "+70267501646"}
0005433036242	55EEC9	1475 996233	IVAN POPOV	{"phone": "+70762311402"}
0005433036243	DD3296	6614 650096	OLEG FILIPPOV	{"phone": "+70422127571"}
0005433036244	2F8663	2512 311027	ZLATA YAKOVLEVA	{"phone": "+70219066514"}
0005433036245	2F8663	7889 881950	ROMAN EGOROV	{"email": "roman.egorov_061959@postgrespro.ru", "phone": "+70133336011"}
0005433036246	78E1A2	3822 246285	YULIYA FILATOVA	{"phone": "+70778324849"}
0005433036247	B5AFE0	6079 598997	ARTEM YAKOVLEV	{"phone": "+70801406652"}
0005433036248	8FEB3B	9553 885235	LARISA PETROVA	{"phone": "+70856246738"}
0005433036249	35754A	1559 422271	EVGENIY POPOV	{"phone": "+70569331403"}
0005433036250	E3B643	5604 019474	ANATOLIY ANTONOV	{"email": "antonov.a.1974@postgrespro.ru", "phone": "+70412052088"}
0005433036251	E3B643	8630 901704	TIMUR ANDREEV	{"email": "andreev_t.24071971@postgrespro.ru", "phone": "+70164830403"}
0005433036252	50F2EA	2236 958935	VIKTOR GERASIMOV	{"email": "gerasimov-viktor-1967@postgrespro.ru", "phone": "+70150553759"}
0005433036253	4F0FD1	7897 026244	ALEKSANDRA EGOROVA	{"email": "egorova_aleksandra.05051983@postgrespro.ru", "phone": "+70097318853"}
0005433036254	4F0FD1	9975 791113	DENIS PAVLOV	{"phone": "+70641410533"}
0005433036255	D34797	1360 545531	ANDREY TIKHONOV	{"email": "a-tikhonov.15031973@postgrespro.ru", "phone": "+70229296731"}
0005433036256	8A2354	6892 128461	VLADIMIR DENISOV	{"email": "denisov-vladimir061979@postgrespro.ru", "phone": "+70314537083"}
0005433036257	8A2354	1154 117026	YULIYA MARTYNOVA	{"email": "y.martynova_10031980@postgrespro.ru", "phone": "+70360263794"}
0005433036258	8A2354	8692 754148	ZINAIDA NIKIFOROVA	{"phone": "+70622619136"}
0005433036259	6827F4	3239 757536	LYUBOV AFANASEVA	{"phone": "+70341819778"}
0005433036260	A6F203	7012 229213	DMITRIY VOROBEV	{"email": "dmitriy.vorobev_061970@postgrespro.ru", "phone": "+70282938081"}
0005433036261	02FF6E	0221 593955	NINA ANDREEVA	{"email": "n_andreeva-26091974@postgrespro.ru", "phone": "+70521880542"}
0005433036262	06CE81	1106 769671	SERGEY PAVLOV	{"email": "s.pavlov-1965@postgrespro.ru", "phone": "+70061585655"}
0005433036263	06CE81	1073 842657	NATALYA POPOVA	{"phone": "+70823374053"}
0005433036264	E130D0	0461 396979	MAKSIM MAKAROV	{"email": "m.makarov.111971@postgrespro.ru", "phone": "+70576333228"}
0005433036265	9B0F81	6127 983420	VALERIY MEDVEDEV	{"email": "v_medvedev17031986@postgrespro.ru", "phone": "+70938255046"}
0005433036266	6AF48B	2661 742179	VLADIMIR FROLOV	{"email": "vladimir_frolov-1976@postgrespro.ru", "phone": "+70693557629"}
0005433036267	D27C2D	6923 633579	OLEG MAKAROV	{"phone": "+70022736097"}
0005433036268	C78042	0839 543488	LIDIYA SEMENOVA	{"email": "lidiyasemenova_17021963@postgrespro.ru", "phone": "+70702258039"}
0005433036269	BE25C2	1331 538726	ZINAIDA KOZLOVA	{"phone": "+70670323185"}
0005433036270	6D8F5B	8805 657360	NIKOLAY SERGEEV	{"email": "nikolay-sergeev.17091970@postgrespro.ru", "phone": "+70857247020"}
0005433036271	6D8F5B	9364 381723	RAISA SOKOLOVA	{"phone": "+70197838443"}
0005433036272	D4AFC2	5742 654454	OLGA FROLOVA	{"phone": "+70923893457"}
0005433036273	D4AFC2	2776 974128	TATYANA ARKHIPOVA	{"email": "tatyana_arkhipova-1978@postgrespro.ru", "phone": "+70494310476"}
0005433036274	A77005	2251 361997	EKATERINA MARTYNOVA	{"phone": "+70090940822"}
0005433036275	A77005	7258 095278	ANDREY NIKOLAEV	{"phone": "+70039530225"}
0005433036276	C215DF	1058 504261	KIRA ZAKHAROVA	{"email": "zakharovak.1974@postgrespro.ru", "phone": "+70990954036"}
0005433036277	1BFFF3	1974 436937	VARVARA NIKITINA	{"email": "nikitinavarvara041971@postgrespro.ru", "phone": "+70493638582"}
0005433036278	423DF1	2566 500928	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev_08061974@postgrespro.ru", "phone": "+70958913873"}
0005433036279	98A281	2625 431060	DANIIL KULIKOV	{"email": "d_kulikov.17031969@postgrespro.ru", "phone": "+70960473911"}
0005433036280	98A281	3240 964247	ILDAR FROLOV	{"phone": "+70528799162"}
0005433036281	86264A	1621 592300	ANASTASIYA DANILOVA	{"phone": "+70658300858"}
0005433036282	B51FD6	5882 091128	YURIY IVANOV	{"email": "ivanov-yuriy.011964@postgrespro.ru", "phone": "+70482721052"}
0005433036283	B51FD6	8828 867594	NATALIYA KUZMINA	{"phone": "+70475963488"}
0005433036284	CB77BE	1893 474971	IRINA BORISOVA	{"phone": "+70474121253"}
0005433036285	CB77BE	0614 324130	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev.041966@postgrespro.ru", "phone": "+70891464614"}
0005433036286	99D42D	6656 700482	KRISTINA KULIKOVA	{"phone": "+70589672830"}
0005433036287	3F35BB	7162 906654	LYUDMILA SERGEEVA	{"email": "l.sergeeva-13121980@postgrespro.ru", "phone": "+70920248703"}
0005433036288	3F35BB	9328 107115	ALEKSANDR FROLOV	{"email": "a-frolov1964@postgrespro.ru", "phone": "+70040407209"}
0005433036289	F21C2A	9603 941668	VLADIMIR KUZNECOV	{"phone": "+70227232530"}
0005433036290	F21C2A	1466 392358	SVETLANA POPOVA	{"phone": "+70540633023"}
0005433036291	F21C2A	0994 419099	OKSANA ABRAMOVA	{"phone": "+70046294864"}
0005433036292	7CB473	0813 770298	GALINA GAVRILOVA	{"email": "gavrilovag_1975@postgrespro.ru", "phone": "+70362525762"}
0005433036293	78C645	0005 388592	STEPAN PAVLOV	{"email": "stepanpavlov_041978@postgrespro.ru", "phone": "+70335960678"}
0005433036294	7222E0	2053 605558	SOFYA KUZNECOVA	{"phone": "+70524590973"}
0005433036295	F636CE	0912 383706	RUSLAN ABRAMOV	{"email": "abramov.ruslan_1981@postgrespro.ru", "phone": "+70767358193"}
0005433036296	F636CE	4310 956198	ANATOLIY TIKHONOV	{"phone": "+70006115313"}
0005433036297	3EFA55	8021 897082	POLINA LOGINOVA	{"email": "p.loginova-011972@postgrespro.ru", "phone": "+70164172281"}
0005433036298	3EFA55	9707 312909	LYUDMILA CHERNOVA	{"email": "l_chernova-1961@postgrespro.ru", "phone": "+70972469859"}
0005433036299	4DCADA	0238 597108	IVAN NIKITIN	{"email": "i_nikitin.1958@postgrespro.ru", "phone": "+70795762885"}
0005433036300	05144A	1033 252303	EVGENIY MAKAROV	{"email": "makarov_e.021979@postgrespro.ru", "phone": "+70285017015"}
0005433036301	AF0B81	9198 642165	TATYANA SAVELEVA	{"phone": "+70617412596"}
0005433036302	56DF8A	4090 526487	LYUDMILA FILATOVA	{"email": "filatova.lyudmila_30111965@postgrespro.ru", "phone": "+70817913434"}
0005433036303	56DF8A	2115 459252	ILYA GORBUNOV	{"phone": "+70443887543"}
0005433036304	F28F1D	8942 536005	NINA KUZMINA	{"phone": "+70418682687"}
0005433036305	882615	6839 358464	NADEZHDA VASILEVA	{"phone": "+70536949113"}
0005433036306	882615	8357 623592	MARIYA MEDVEDEVA	{"phone": "+70549158907"}
0005433036307	948A8C	8163 687677	TATYANA SOKOLOVA	{"phone": "+70252922997"}
0005433036308	F11727	2324 235748	ALEKSEY NAZAROV	{"phone": "+70597063991"}
0005433036309	BD2BE7	4920 387417	MARIYA VASILEVA	{"email": "mariya_vasileva_17031975@postgrespro.ru", "phone": "+70394180572"}
0005433036310	BD2BE7	4014 049849	MARINA TITOVA	{"email": "marinatitova1969@postgrespro.ru", "phone": "+70196783345"}
0005433036311	AF4C34	3820 565074	NINA KUZNECOVA	{"phone": "+70078681697"}
0005433036312	F9A3DE	8047 816539	INGA OSIPOVA	{"phone": "+70785288635"}
0005433036313	8C4A15	7104 017471	VITALIY SCHERBAKOV	{"phone": "+70920727923"}
0005433036314	529072	3522 880756	VLADIMIR CHERNOV	{"email": "v.chernov-19091963@postgrespro.ru", "phone": "+70498700953"}
0005433036315	529072	2755 928257	RUSLAN KONOVALOV	{"email": "konovalovruslan-1965@postgrespro.ru", "phone": "+70399375684"}
0005433036316	4B5CD6	3096 715426	ALEKSANDR DENISOV	{"phone": "+70364217714"}
0005433036317	4B5CD6	4256 844163	MARIYA IVANOVA	{"phone": "+70308897130"}
0005433036318	F8D9F5	7648 650789	LYUBOV MAKAROVA	{"phone": "+70729945627"}
0005433036319	A77AF5	6692 069151	SERGEY DAVYDOV	{"email": "sergey.davydov06051975@postgrespro.ru", "phone": "+70481667626"}
0005433036320	A77AF5	8769 127550	DILYARA NAZAROVA	{"phone": "+70243469675"}
0005433036321	39AA8F	5380 030844	NATALYA YUDINA	{"phone": "+70861731203"}
0005433036322	39AA8F	0122 691737	ANDREY NIKOLAEV	{"email": "nikolaev.a031969@postgrespro.ru", "phone": "+70635286133"}
0005433036323	414821	8138 198231	OLGA TARASOVA	{"phone": "+70175871347"}
0005433036324	04F8D1	2716 217178	ANATOLIY ORLOV	{"email": "anatoliy_orlov_1972@postgrespro.ru", "phone": "+70400085787"}
0005433036325	6D921A	6674 902393	TATYANA KALININA	{"phone": "+70617626528"}
0005433036326	6D921A	3406 154904	TATYANA MEDVEDEVA	{"phone": "+70598528114"}
0005433036327	82DEC8	6246 940689	SVETLANA VOLKOVA	{"email": "s-volkova.1975@postgrespro.ru", "phone": "+70837290359"}
0005433036328	82DEC8	2273 050431	VALENTINA NAUMOVA	{"email": "vnaumova.12021978@postgrespro.ru", "phone": "+70839092906"}
0005433036329	E99139	7145 755010	ALEKSANDRA IVANOVA	{"email": "aleksandra-ivanova22081967@postgrespro.ru", "phone": "+70131059549"}
0005433036330	40042F	7261 874564	ELIZAVETA EFIMOVA	{"email": "e.efimova26041985@postgrespro.ru", "phone": "+70126762549"}
0005433036331	894086	6942 824485	EKATERINA VOLKOVA	{"email": "volkovaekaterina-1971@postgrespro.ru", "phone": "+70309821088"}
0005433036332	B092D3	8312 822949	GALINA TIMOFEEVA	{"phone": "+70097401873"}
0005433036333	DA7103	2526 898869	NATALIYA ZHURAVLEVA	{"phone": "+70649445726"}
0005433036334	B96F61	8243 004777	SVETLANA ERMAKOVA	{"email": "ermakovasvetlana1971@postgrespro.ru", "phone": "+70929631988"}
0005433036335	C6473F	4852 338694	VALERIY ILIN	{"email": "v_ilin_031974@postgrespro.ru", "phone": "+70108651970"}
0005433036336	CD1754	2378 300488	GALINA ZHURAVLEVA	{"phone": "+70294576439"}
0005433036337	F43D20	4081 781446	IRINA KRASNOVA	{"email": "krasnova.irina.061977@postgrespro.ru", "phone": "+70034062025"}
0005433036338	F9B20A	8358 761381	ANDREY ZAYCEV	{"phone": "+70421672269"}
0005433036339	362693	6620 999527	NIKOLAY FROLOV	{"email": "frolov-nikolay-1967@postgrespro.ru", "phone": "+70590803768"}
0005433036340	73D5E0	7911 294000	BORIS MIRONOV	{"phone": "+70126293824"}
0005433036341	20258E	8820 783354	DMITRIY KAZAKOV	{"email": "kazakov-dmitriy.10101987@postgrespro.ru", "phone": "+70849680000"}
0005433036342	E5AD6E	4954 137323	ANASTASIYA KUZNECOVA	{"email": "kuznecova.anastasiya_061961@postgrespro.ru", "phone": "+70568576870"}
0005433036343	DD7BDE	2108 395205	SAMIR YAKOVLEV	{"phone": "+70778873559"}
0005433036344	DD7BDE	6848 142211	ALEKSANDR GUSEV	{"email": "a-gusev.24071984@postgrespro.ru", "phone": "+70191157128"}
0005433036345	908A1B	7263 158933	GALINA LUKYANOVA	{"email": "lukyanova-galina_1968@postgrespro.ru", "phone": "+70342971911"}
0005433036346	908A1B	0314 384777	ZINAIDA POPOVA	{"email": "popova-z_1972@postgrespro.ru", "phone": "+70693636060"}
0005433036347	07AFF1	5670 381069	VLADIMIR ABRAMOV	{"email": "abramovvladimir_1969@postgrespro.ru", "phone": "+70651312991"}
0005433036348	07AFF1	1816 798757	ALEKSANDR PAVLOV	{"email": "a.pavlov-1968@postgrespro.ru", "phone": "+70766880831"}
0005433036349	2F15BF	3857 516456	ALEKSANDR KONOVALOV	{"email": "aleksandr-konovalov.091955@postgrespro.ru", "phone": "+70945973555"}
0005433036350	A8D885	8302 217372	ELENA KALININA	{"phone": "+70140957423"}
0005433036351	866C17	5878 338786	ANATOLIY STEPANOV	{"phone": "+70080791875"}
0005433036352	866C17	0896 773970	ELENA NIKITINA	{"phone": "+70303766925"}
0005433036353	66682B	5922 265756	YULIYA KONOVALOVA	{"email": "yuliyakonovalova.14071973@postgrespro.ru", "phone": "+70482156937"}
0005433036354	66682B	3916 428130	ALEVTINA KARPOVA	{"email": "karpova_alevtina-20041972@postgrespro.ru", "phone": "+70026137262"}
0005433036355	829530	1130 705359	VLADIMIR POPOV	{"email": "popovv-011974@postgrespro.ru", "phone": "+70112635492"}
0005433036356	E62E2F	3578 632588	IRINA MOROZOVA	{"email": "irina.morozova-04071974@postgrespro.ru", "phone": "+70247040642"}
0005433036357	215080	9303 792316	VASILIY AFANASEV	{"phone": "+70263816474"}
0005433036358	215080	2514 110880	IVAN ROMANOV	{"email": "romanov-ivan.1972@postgrespro.ru", "phone": "+70364286479"}
0005433036359	F02288	4394 413589	OLGA AFANASEVA	{"email": "o-afanaseva22121971@postgrespro.ru", "phone": "+70412336799"}
0005433036360	F02288	8845 496952	DMITRIY BELOV	{"phone": "+70249978810"}
0005433036361	B6D82B	4939 144674	SERGEY ALEKSEEV	{"email": "alekseevsergey-18071975@postgrespro.ru", "phone": "+70948597431"}
0005433036362	E9CB8D	5603 788366	OLEG SIDOROV	{"phone": "+70112819411"}
0005433036363	DCF4C9	5462 171311	TATYANA SOKOLOVA	{"phone": "+70315235434"}
0005433036364	33ADF9	5453 989026	LIDIYA ERMAKOVA	{"phone": "+70876497082"}
0005433036365	6D1249	4780 325289	VLADIMIR FEDOTOV	{"email": "fedotovv_26021968@postgrespro.ru", "phone": "+70347754645"}
0005433036366	A64E94	0115 830568	SERGEY MOROZOV	{"phone": "+70800817692"}
0005433036367	280F25	6035 530527	ANDREY CHERNOV	{"email": "chernov.andrey-21111963@postgrespro.ru", "phone": "+70714376588"}
0005433036368	280F25	7093 618420	ALEKSANDRA PAVLOVA	{"email": "aleksandra-pavlova14041982@postgrespro.ru", "phone": "+70918704724"}
0005433036369	FD5981	1166 715296	ALEKSEY SMIRNOV	{"phone": "+70114259909"}
0005433036370	22807D	3401 073515	PAVEL NAZAROV	{"email": "p_nazarov-27051973@postgrespro.ru", "phone": "+70026204124"}
0005433036371	8469CB	8283 913224	VERA MOROZOVA	{"phone": "+70280582211"}
0005433036372	8469CB	0819 976462	GALINA MOROZOVA	{"phone": "+70149338406"}
0005433036373	02BEA6	0633 465506	SERGEY ALEKSANDROV	{"email": "aleksandrov.s.1972@postgrespro.ru", "phone": "+70710632133"}
0005433036374	959CAF	9182 254541	OLGA MAKAROVA	{"email": "makarova-olga-081970@postgrespro.ru", "phone": "+70063628262"}
0005433036375	1C7CF8	1458 167617	NINA NIKITINA	{"phone": "+70205219705"}
0005433036376	77B513	6958 698295	OLGA FEDOROVA	{"email": "fedorova_olga.081972@postgrespro.ru", "phone": "+70337607112"}
0005433036377	CC97BC	5710 385322	MAKSIM ZHUKOV	{"email": "maksim_zhukov-17081973@postgrespro.ru", "phone": "+70704836793"}
0005433036378	A413EF	7988 285533	VLADIMIR SOLOVEV	{"phone": "+70581193933"}
0005433036379	A413EF	3189 846848	SERGEY MIKHAYLOV	{"phone": "+70108934818"}
0005433036380	2B8026	4683 259147	EDGAR KUZNECOV	{"email": "kuznecov-edgar_041970@postgrespro.ru", "phone": "+70400955652"}
0005433036381	6E56EA	1610 786848	YULIYA POPOVA	{"email": "yuliya_popova031977@postgrespro.ru", "phone": "+70288644302"}
0005433036382	F8ADBB	5977 699148	ANNA ANTONOVA	{"email": "antonova.anna-12071976@postgrespro.ru", "phone": "+70239452181"}
0005433036383	F8ADBB	6521 044946	ANATOLIY MAKAROV	{"email": "makarov-anatoliy011959@postgrespro.ru", "phone": "+70365674869"}
0005433036384	54C635	5126 118853	ANATOLIY PAVLOV	{"phone": "+70919848008"}
0005433036385	1D5CCA	0333 447527	MARIYA NOVIKOVA	{"phone": "+70581026759"}
0005433036386	5167CE	9359 562783	ALEKSANDR STEPANOV	{"phone": "+70133027227"}
0005433036387	08FA4F	5653 520824	OLEG NAZAROV	{"phone": "+70558449058"}
0005433036388	C4B6B5	7133 955304	NINA ALEKSEEVA	{"email": "alekseeva-n.041971@postgrespro.ru", "phone": "+70920350386"}
0005433036389	C4B6B5	9197 538546	ANTON TARASOV	{"phone": "+70966837757"}
0005433036390	A764DD	2269 871355	GALINA GERASIMOVA	{"email": "gerasimova.g.26051969@postgrespro.ru", "phone": "+70832380219"}
0005433036391	A764DD	9587 491359	OLEG SOLOVEV	{"phone": "+70950142606"}
0005433036392	EFA4CC	4764 073282	ELENA MIKHAYLOVA	{"phone": "+70832062182"}
0005433036393	EFA4CC	9835 566089	ALEKSEY KOROLEV	{"email": "korolev_a.1979@postgrespro.ru", "phone": "+70356379525"}
0005433036394	31C5F3	2142 796145	VLADISLAV KUZNECOV	{"phone": "+70580694528"}
0005433036395	31C5F3	3804 886458	DMITRIY SMIRNOV	{"email": "smirnov_d_1972@postgrespro.ru", "phone": "+70722254764"}
0005433036396	4306EE	2819 768810	VIKTORIYA ANISIMOVA	{"email": "viktoriyaanisimova.061979@postgrespro.ru", "phone": "+70812069967"}
0005433036397	4306EE	3344 227633	ELENA ZOTOVA	{"phone": "+70846568128"}
0005433036398	356470	0234 096776	ELVIRA MALYSHEVA	{"email": "e_malysheva.05121965@postgrespro.ru", "phone": "+70917594874"}
0005433036399	410486	5129 368188	ANDREY BORISOV	{"phone": "+70716904261"}
0005433036400	410486	6140 924444	VALENTINA MOISEEVA	{"email": "valentina.moiseeva.011978@postgrespro.ru", "phone": "+70248992514"}
0005433036401	410486	7537 001067	ALEKSANDR ANDREEV	{"email": "a.andreev031965@postgrespro.ru", "phone": "+70262934820"}
0005433036402	6D929A	0716 939166	OLESYA BOGDANOVA	{"phone": "+70323597261"}
0005433036403	6D929A	8090 697801	VALERIY SEMENOV	{"email": "semenovvaleriy.23021977@postgrespro.ru", "phone": "+70955845855"}
0005433036404	18118F	1219 109455	EVGENIY SMIRNOV	{"phone": "+70983104681"}
0005433036405	71102B	6873 934983	VALERIY DAVYDOV	{"email": "davydov_valeriy1984@postgrespro.ru", "phone": "+70063067072"}
0005433036406	71102B	0805 447772	ANDREY ORLOV	{"phone": "+70505835033"}
0005433036407	B510FF	9811 636815	ELENA DENISOVA	{"email": "denisova_elena_03061975@postgrespro.ru", "phone": "+70851711965"}
0005433036408	7A95D6	5722 647881	VLADIMIR SEMENOV	{"phone": "+70105551497"}
0005433036409	F48EB7	0334 267268	VLADIMIR MIKHAYLOV	{"phone": "+70835043375"}
0005433036410	F48EB7	4618 933594	ANDREY SEMENOV	{"email": "semenov_andrey1957@postgrespro.ru", "phone": "+70089159866"}
0005433036411	FD0D7B	2165 123010	ELENA DMITRIEVA	{"phone": "+70526376077"}
0005433036412	FD0D7B	2974 620587	DANIIL ANDREEV	{"phone": "+70866544146"}
0005433036413	04E92D	8062 370827	VLADISLAV FOMIN	{"phone": "+70136303408"}
0005433036414	04E92D	7255 338221	ALEKSANDR BARANOV	{"phone": "+70124412652"}
0005433036415	A05B6F	8155 754577	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev_041958@postgrespro.ru", "phone": "+70458007190"}
0005433036416	B8518A	9048 280967	VIKTOR ANDREEV	{"email": "andreevv07051962@postgrespro.ru", "phone": "+70620291999"}
0005433036417	47A423	8817 077754	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a111968@postgrespro.ru", "phone": "+70657767495"}
0005433036418	3594DF	6670 733633	NIKOLAY TARASOV	{"phone": "+70785890435"}
0005433036419	66B21F	7380 073118	NATALYA MALYSHEVA	{"email": "malyshevan_031973@postgrespro.ru", "phone": "+70216105222"}
0005433036420	AE6604	3459 417427	DARYA ZAYCEVA	{"phone": "+70652019375"}
0005433036421	F0B503	0595 357445	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a-15031969@postgrespro.ru", "phone": "+70054688737"}
0005433036422	F0B503	0746 573693	NATALYA OSIPOVA	{"phone": "+70184948542"}
0005433036423	E21531	8551 316461	ERIK STEPANOV	{"phone": "+70847389557"}
0005433036424	093A82	3057 776372	SERGEY ANDREEV	{"phone": "+70889832989"}
0005433036425	0FE430	0898 296205	VARVARA YAKOVLEVA	{"phone": "+70541324906"}
0005433036426	4C086A	4092 677343	ALEKSANDR ORLOV	{"phone": "+70538233794"}
0005433036427	4C086A	9471 307434	ANNA BOGDANOVA	{"email": "bogdanovaanna_1975@postgrespro.ru", "phone": "+70458195077"}
0005433036428	3A82B2	3237 671415	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova_svetlana.29051968@postgrespro.ru", "phone": "+70870307236"}
0005433036429	EA116F	6827 714988	MARINA KONOVALOVA	{"email": "konovalova-m-06091965@postgrespro.ru", "phone": "+70942902184"}
0005433036430	C84CC1	1357 180228	LYUDMILA DMITRIEVA	{"phone": "+70188806066"}
0005433036431	992727	3611 853608	LARISA MAKSIMOVA	{"email": "maksimova_larisa_1977@postgrespro.ru", "phone": "+70734066534"}
0005433036432	8A614F	0978 920565	ANTONINA TARASOVA	{"phone": "+70767084286"}
0005433036433	8A614F	2846 565903	SVETLANA MEDVEDEVA	{"phone": "+70440442547"}
0005433036434	C93C0D	9462 474932	LEONID MEDVEDEV	{"email": "medvedev.l_1961@postgrespro.ru", "phone": "+70438265672"}
0005433036435	A6828B	5788 333714	SERGEY CHERNOV	{"phone": "+70183999106"}
0005433036436	A6828B	9645 790833	ANASTASIYA VASILEVA	{"email": "anastasiya.vasileva.1973@postgrespro.ru", "phone": "+70631058968"}
0005433036437	89683D	8495 013411	GENNADIY NAUMOV	{"email": "gennadiy-naumov-061966@postgrespro.ru", "phone": "+70531426096"}
0005433036438	898B4D	0159 437790	VLADIMIR POPOV	{"phone": "+70474234590"}
0005433036439	63C1E2	5378 125056	ANDREY ABRAMOV	{"email": "abramov_andrey-01021981@postgrespro.ru", "phone": "+70145786617"}
0005433036440	8B3C41	4855 319057	TATYANA IVANOVA	{"email": "ivanova.tatyana051964@postgrespro.ru", "phone": "+70723767960"}
0005433036441	458FA7	1195 262735	VALENTINA DENISOVA	{"email": "denisova.valentina1978@postgrespro.ru", "phone": "+70728944385"}
0005433036442	458FA7	6624 604589	OLGA SAVELEVA	{"phone": "+70443423578"}
0005433036443	85522D	7358 658694	SVETLANA IVANOVA	{"email": "s_ivanova1978@postgrespro.ru", "phone": "+70111437906"}
0005433036444	244769	3097 755443	PETR KUZMIN	{"phone": "+70680163526"}
0005433036445	244769	9926 102905	LIDIYA SEMENOVA	{"phone": "+70957704006"}
0005433036446	EFB809	6576 599008	ALEKSEY PETROV	{"email": "aleksey_petrov_04011975@postgrespro.ru", "phone": "+70463452846"}
0005433036447	F3EEDF	2912 358159	MARIYA IVANOVA	{"email": "ivanova.mariya.1969@postgrespro.ru", "phone": "+70558036176"}
0005433036448	F3EEDF	9719 725370	ANATOLIY FEDOROV	{"phone": "+70183852860"}
0005433036449	609FC5	7269 021812	YURIY SHEVCHENKO	{"phone": "+70048355345"}
0005433036450	57756C	8916 428316	PAVEL DAVYDOV	{"email": "davydovp.01011971@postgrespro.ru", "phone": "+70091476171"}
0005433036451	E5B468	1420 061641	TATYANA SERGEEVA	{"phone": "+70926836805"}
0005433036452	8B6D6E	2128 754369	EVDOKIYA POTAPOVA	{"email": "potapova.evdokiya071962@postgrespro.ru", "phone": "+70604395602"}
0005433036453	8B6D6E	1864 415377	ALEKSEY GRIGOREV	{"email": "a-grigorev051973@postgrespro.ru", "phone": "+70752020795"}
0005433036454	9967C5	6553 187244	FARIDA PETROVA	{"email": "petrova-f02111977@postgrespro.ru", "phone": "+70852291800"}
0005433036455	78856A	9558 485854	EVGENIYA DENISOVA	{"email": "denisova_evgeniya.07111960@postgrespro.ru", "phone": "+70363755685"}
0005433036456	78856A	1955 497974	DMITRIY IVANOV	{"phone": "+70844698773"}
0005433036457	3A15F1	7305 797670	KARINA KUZNECOVA	{"phone": "+70630132406"}
0005433036458	3A15F1	3168 669309	VITALIY STEPANOV	{"email": "stepanov_v111975@postgrespro.ru", "phone": "+70827402780"}
0005433036459	259E4E	0169 327412	MARIYA IVANOVA	{"phone": "+70387906102"}
0005433036460	DF87AB	5561 030206	LARISA ABRAMOVA	{"phone": "+70388105326"}
0005433036461	9CD791	2174 650673	INNA MATVEEVA	{"email": "matveeva.inna-121971@postgrespro.ru", "phone": "+70178233763"}
0005433036462	AF4511	9806 655643	IVAN KUZNECOV	{"phone": "+70424422039"}
0005433036463	AF4511	4186 422957	OLGA OVCHINNIKOVA	{"email": "olga.ovchinnikova.14091965@postgrespro.ru", "phone": "+70111623030"}
0005433036464	775F6F	2766 624950	RUSTAM ZAKHAROV	{"phone": "+70644812509"}
0005433036465	E36054	3984 572350	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov04031963@postgrespro.ru", "phone": "+70972101359"}
0005433036466	E36054	7516 248348	OLEG ZHUKOV	{"phone": "+70761639137"}
0005433036467	95FD5C	8132 385147	LIDIYA MELNIKOVA	{"phone": "+70821120169"}
0005433036468	A858B1	7528 445275	ELENA KUZNECOVA	{"phone": "+70562261673"}
0005433036469	F6785E	8455 730576	VADIM SMIRNOV	{"phone": "+70978953927"}
0005433036470	F76728	5305 905745	NIKOLAY ANTONOV	{"phone": "+70095070973"}
0005433036471	C858CB	4938 946251	ELENA ZHUKOVA	{"email": "zhukovae-101966@postgrespro.ru", "phone": "+70194564508"}
0005433036472	C858CB	7456 086269	EVGENIY KARPOV	{"email": "evgeniy.karpov-1967@postgrespro.ru", "phone": "+70660565230"}
0005433036473	366F56	5412 471160	SVETLANA SOROKINA	{"email": "sorokina-svetlana-20061964@postgrespro.ru", "phone": "+70562036441"}
0005433036474	C88CC3	5077 795643	LYUBOV SCHERBAKOVA	{"phone": "+70175066037"}
0005433036475	C88CC3	7003 917005	ROZA KOVALEVA	{"phone": "+70716492901"}
0005433036476	C9EC6F	9986 255185	ELENA KUDRYASHOVA	{"email": "e_kudryashova-10031991@postgrespro.ru", "phone": "+70485574196"}
0005433036477	C9EC6F	9784 639454	TATYANA POPOVA	{"phone": "+70509853600"}
0005433036478	C9EC6F	4080 850317	SERGEY SIDOROV	{"email": "s-sidorov.021971@postgrespro.ru", "phone": "+70719101494"}
0005433036479	E22408	5088 973876	RUSLAN VOROBEV	{"email": "ruslan.vorobev.121976@postgrespro.ru", "phone": "+70485376225"}
0005433036480	A80846	7675 381145	OLGA PAVLOVA	{"phone": "+70975351646"}
0005433036481	0E8009	7851 295378	NATALYA MATVEEVA	{"email": "matveevanatalya.10051979@postgrespro.ru", "phone": "+70500095627"}
0005433036482	F55199	7113 272236	LYUBOV MAKAROVA	{"phone": "+70418184855"}
0005433036483	E53BF7	0054 830854	GALINA BARANOVA	{"phone": "+70518664819"}
0005433036484	09AA98	9898 134054	MIKHAIL PAVLOV	{"email": "mpavlov_20041967@postgrespro.ru", "phone": "+70162001064"}
0005433036485	91EAC0	1604 435738	ANASTASIYA NAZAROVA	{"phone": "+70235746533"}
0005433036486	91EAC0	5165 404009	ANNA MALYSHEVA	{"phone": "+70591793218"}
0005433036487	3A9ABC	6427 917444	ALENA OVCHINNIKOVA	{"phone": "+70999436873"}
0005433036488	495305	7865 624671	MIKHAIL KAZAKOV	{"email": "m.kazakov.1976@postgrespro.ru", "phone": "+70536135610"}
0005433036489	495305	0798 101958	GALINA ROMANOVA	{"phone": "+70613432298"}
0005433036490	495305	1265 948799	NATALYA KOMAROVA	{"phone": "+70997194038"}
0005433036491	D275E9	6536 467423	VASILIY RODIONOV	{"email": "rodionov.vasiliy.121966@postgrespro.ru", "phone": "+70424916694"}
0005433036492	D275E9	8293 480853	GENNADIY ANDREEV	{"phone": "+70043754573"}
0005433036493	82B364	9019 848166	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr-20061967@postgrespro.ru", "phone": "+70064454851"}
0005433036494	82B364	2014 784430	ANNA IVANOVA	{"email": "ivanova-a.061965@postgrespro.ru", "phone": "+70040705723"}
0005433036495	8F8307	5470 578369	EKATERINA BORISOVA	{"email": "borisova.e-1969@postgrespro.ru", "phone": "+70863915458"}
0005433036496	5E7FD7	4774 169991	SERGEY OSIPOV	{"email": "sergey-osipov1982@postgrespro.ru", "phone": "+70969285048"}
0005433036497	BC2D19	1321 376643	VIKTORIYA MOROZOVA	{"phone": "+70820745122"}
0005433036498	BC2D19	6457 579014	MARIYA ANDREEVA	{"email": "andreeva.m-20101972@postgrespro.ru", "phone": "+70580481510"}
0005433036499	5766E5	8823 295654	TATYANA NIKITINA	{"email": "tatyana.nikitina_24091967@postgrespro.ru", "phone": "+70550892093"}
0005433036500	5766E5	9546 757130	ANDREY POPOV	{"phone": "+70205194802"}
0005433036501	4A8677	8975 514453	DMITRIY KUZNECOV	{"phone": "+70839091812"}
0005433036502	F78515	9634 145255	ALEKSANDR KAZAKOV	{"email": "kazakova1972@postgrespro.ru", "phone": "+70182010908"}
0005433036503	F78515	8977 016636	VLADISLAV MAKSIMOV	{"phone": "+70071196429"}
0005433036504	F0C250	2186 007732	SERGEY TIMOFEEV	{"email": "sergey_timofeev1964@postgrespro.ru", "phone": "+70802222549"}
0005433036505	F0C250	3155 607470	NIKOLAY SHEVCHENKO	{"phone": "+70312759369"}
0005433036506	F0C250	5832 185321	YULIYA MATVEEVA	{"email": "ymatveeva.23061981@postgrespro.ru", "phone": "+70288641483"}
0005433036507	7E6687	5872 863305	OLEG GAVRILOV	{"phone": "+70351594281"}
0005433036508	0B15F6	2908 832004	GULNARA KOZLOVA	{"phone": "+70464766970"}
0005433036509	0885E6	2935 420912	ROMAN MAKSIMOV	{"email": "rmaksimov.11111977@postgrespro.ru", "phone": "+70468003367"}
0005433036510	0885E6	3934 994051	IRINA LEBEDEVA	{"phone": "+70883940615"}
0005433036511	F19939	4042 514692	YURIY GORBUNOV	{"email": "y-gorbunov_1964@postgrespro.ru", "phone": "+70780727873"}
0005433036512	FC7943	6404 909782	VIKTOR GORBUNOV	{"email": "viktorgorbunov.101968@postgrespro.ru", "phone": "+70856034626"}
0005433036513	FC7943	9708 937646	RAMILYA PETROVA	{"email": "petrova_ramilya_1966@postgrespro.ru", "phone": "+70537948658"}
0005433036514	F920EA	1075 864743	NIKOLAY SOROKIN	{"email": "nikolaysorokin.1963@postgrespro.ru", "phone": "+70225117371"}
0005433036515	F920EA	9542 266512	DARYA GRISHINA	{"email": "dgrishina.101977@postgrespro.ru", "phone": "+70297850066"}
0005433036516	529DA6	4125 378294	ALEKSANDR POPOV	{"phone": "+70271694563"}
0005433036517	5A0C8B	3088 107446	ALEKSEY SCHERBAKOV	{"phone": "+70941217979"}
0005433036518	5A0C8B	8795 965446	SERGEY ILIN	{"email": "sergey.ilin-1970@postgrespro.ru", "phone": "+70181827242"}
0005433036519	40DE3D	3237 940693	MARINA ISAEVA	{"email": "isaevam-04071979@postgrespro.ru", "phone": "+70130954095"}
0005433036520	580CD9	7828 262949	VENERA SOKOLOVA	{"phone": "+70382230825"}
0005433036521	CCFCBD	7593 126042	ELENA KAZAKOVA	{"phone": "+70853046603"}
0005433036522	CCFCBD	5204 268867	IRINA EGOROVA	{"phone": "+70276156910"}
0005433036523	9FF2A3	3496 774084	ALEKSANDR YAKOVLEV	{"phone": "+70663614493"}
0005433036524	9FF2A3	8068 205025	ANDREY KUZNECOV	{"phone": "+70750210011"}
0005433036525	CABA60	8603 273213	STANISLAV NOVIKOV	{"email": "stanislavnovikov1970@postgrespro.ru", "phone": "+70940714657"}
0005433036526	CABA60	0807 723128	MARGARITA MAKAROVA	{"email": "margarita-makarova_30081971@postgrespro.ru", "phone": "+70093809924"}
0005433036527	AE2ED1	2819 578185	TAMARA EFREMOVA	{"email": "efremova_tamara-121974@postgrespro.ru", "phone": "+70481357506"}
0005433036528	F44318	3568 113354	MAKSIM FROLOV	{"phone": "+70154349474"}
0005433036529	7E2B25	5400 046284	ANNA OSIPOVA	{"email": "a.osipova_011977@postgrespro.ru", "phone": "+70622377564"}
0005433036530	5D0262	8576 460593	ELENA GAVRILOVA	{"email": "gavrilova_e_1983@postgrespro.ru", "phone": "+70683678273"}
0005433036531	5D0262	4397 839569	ALEKSANDR GERASIMOV	{"phone": "+70295606014"}
0005433036532	E4D000	3151 277639	MARIYA DANILOVA	{"email": "danilova-mariya.061968@postgrespro.ru", "phone": "+70251511156"}
0005433036533	8330E1	5137 590600	VERA EGOROVA	{"email": "vera_egorova.081976@postgrespro.ru", "phone": "+70769243881"}
0005433036534	4D5DBB	8614 652333	ZINAIDA KUZMINA	{"phone": "+70334229580"}
0005433036535	4D5DBB	7582 130893	OLEG KOZLOV	{"email": "kozlov-oleg_15021981@postgrespro.ru", "phone": "+70094773165"}
0005433036536	F3A9AA	0822 228189	TATYANA IVANOVA	{"email": "ivanova.t-051968@postgrespro.ru", "phone": "+70119992054"}
0005433036537	030628	3802 037500	ALEKSANDR POPOV	{"email": "a_popov_1969@postgrespro.ru", "phone": "+70270450914"}
0005433036538	030628	3907 602632	ALEKSANDR DMITRIEV	{"phone": "+70520569288"}
0005433036539	030628	6174 571206	KONSTANTIN MOISEEV	{"email": "kmoiseev_101955@postgrespro.ru", "phone": "+70064346835"}
0005433036540	030628	3325 789127	ALEKSEY POPOV	{"phone": "+70242524434"}
0005433036541	2926B0	3073 391714	OLESYA PETROVA	{"email": "o.petrova_1979@postgrespro.ru", "phone": "+70546713307"}
0005433036542	CF150F	4524 283457	GEORGIY DMITRIEV	{"phone": "+70766853799"}
0005433036543	501F4E	6245 079363	ALEKSEY KULIKOV	{"email": "a.kulikov.1986@postgrespro.ru", "phone": "+70824251862"}
0005433036544	11FEBE	6689 384710	TAMARA NESTEROVA	{"phone": "+70509199028"}
0005433036545	11FEBE	5860 278638	KARINA MAKAROVA	{"email": "makarova-k.101971@postgrespro.ru", "phone": "+70966758750"}
0005433036546	11FEBE	0697 659317	VIKTORIYA KOZLOVA	{"email": "v_kozlova071959@postgrespro.ru", "phone": "+70486835962"}
0005433036547	09E476	4054 891645	VLADIMIR ZHURAVLEV	{"phone": "+70393792702"}
0005433036548	09E476	8806 494535	VLADIMIR SMIRNOV	{"email": "v_smirnov_1976@postgrespro.ru", "phone": "+70700326053"}
0005433036549	09E476	2114 919843	ALEKSANDR MOISEEV	{"phone": "+70208053536"}
0005433036550	C8A1E8	6741 309989	VLADIMIR GERASIMOV	{"phone": "+70360523653"}
0005433036551	B058F6	0728 527410	VITALIY SOROKIN	{"phone": "+70357881501"}
0005433036552	B058F6	7346 121442	ANTON KUZNECOV	{"phone": "+70903682524"}
0005433036553	B058F6	2557 478668	IGOR GERASIMOV	{"email": "gerasimov-i.041972@postgrespro.ru", "phone": "+70806794600"}
0005433036554	7EB84F	4647 266432	YULIYA FROLOVA	{"phone": "+70147451148"}
0005433036555	430E51	7779 242095	MIKHAIL EGOROV	{"phone": "+70189168892"}
0005433036556	22831E	1421 992217	VYACHESLAV DAVYDOV	{"email": "vyacheslav.davydov_071961@postgrespro.ru", "phone": "+70618787682"}
0005433036557	22831E	3176 833352	MAKSIM PETROV	{"email": "petrov-m23121970@postgrespro.ru", "phone": "+70042943681"}
0005433036558	D91634	3694 655862	VITALIY DAVYDOV	{"phone": "+70563699401"}
0005433036559	167CBD	5815 059625	ALEKSANDR FILIPPOV	{"phone": "+70126075646"}
0005433036560	6B1C95	5491 468262	NATALYA KUZNECOVA	{"email": "natalya.kuznecova031966@postgrespro.ru", "phone": "+70740131804"}
0005433036561	6B1C95	0571 308767	VITALIY BARANOV	{"email": "baranov-v_081963@postgrespro.ru", "phone": "+70972191903"}
0005433036562	541A01	1185 129719	NADEZHDA SERGEEVA	{"email": "sergeevan071976@postgrespro.ru", "phone": "+70149940663"}
0005433036563	541A01	3638 633676	MARIYA NAUMOVA	{"phone": "+70575810314"}
0005433036564	A66949	8392 261311	VALENTIN KUZNECOV	{"phone": "+70136167308"}
0005433036565	A66949	4087 556318	MARIYA BELOVA	{"phone": "+70990490802"}
0005433036566	F17B5E	5037 460532	ALEKSANDR KUZNECOV	{"phone": "+70094703264"}
0005433036567	F17B5E	8938 177109	ELIZAVETA ISAEVA	{"email": "elizaveta-isaeva_02051972@postgrespro.ru", "phone": "+70333050910"}
0005433036568	F17B5E	8739 316109	ELENA MELNIKOVA	{"phone": "+70363191816"}
0005433036569	1A5D17	0407 189685	VYACHESLAV MAKAROV	{"email": "vyacheslav_makarov_1977@postgrespro.ru", "phone": "+70786941323"}
0005433036570	2A1DA8	1812 969768	SVETLANA NESTEROVA	{"phone": "+70642150787"}
0005433036571	2A1DA8	0628 344222	GALINA MIKHAYLOVA	{"phone": "+70664113098"}
0005433036572	2A1DA8	8487 446736	TATYANA AFANASEVA	{"phone": "+70272946577"}
0005433036573	78C35F	1112 032981	ALEKSANDR PETROV	{"email": "a-petrov_03061973@postgrespro.ru", "phone": "+70855706291"}
0005433036574	12950E	8246 917260	ANDREY KUZMIN	{"phone": "+70515232841"}
0005433036575	12950E	8238 974453	ALEKSANDR FROLOV	{"email": "afrolov_1970@postgrespro.ru", "phone": "+70305479785"}
0005433036576	EB5073	1083 820233	MIKHAIL SEMENOV	{"phone": "+70029823934"}
0005433036577	582219	4398 387770	GALINA RODIONOVA	{"email": "rodionova_g1972@postgrespro.ru", "phone": "+70597719994"}
0005433036578	582219	5243 981264	OLGA ILINA	{"phone": "+70344141181"}
0005433036579	AF6FFA	1538 516980	ANATOLIY ZAKHAROV	{"phone": "+70421934908"}
0005433036580	AF6FFA	1865 672811	SERGEY SOKOLOV	{"email": "sokolov-sergey101973@postgrespro.ru", "phone": "+70359200937"}
0005433036581	841704	6712 431228	IVAN SMIRNOV	{"email": "i-smirnov.1965@postgrespro.ru", "phone": "+70577042253"}
0005433036582	0ADED5	8124 166613	SVETLANA MAKAROVA	{"phone": "+70980592017"}
0005433036583	B8F66D	0436 187136	VERONIKA KOROLEVA	{"email": "koroleva.veronika.1966@postgrespro.ru", "phone": "+70489734700"}
0005433036584	B8F66D	5748 905014	EKATERINA NAZAROVA	{"email": "nazarova.ekaterina.061959@postgrespro.ru", "phone": "+70425935745"}
0005433036585	A39226	9645 467608	TAMARA IVANOVA	{"phone": "+70427603335"}
0005433036586	DF949B	4420 956835	MIKHAIL SERGEEV	{"email": "mikhail.sergeev.1966@postgrespro.ru", "phone": "+70906511390"}
0005433036587	835FAB	7408 193426	ANTONINA DMITRIEVA	{"phone": "+70202894276"}
0005433036588	835FAB	9731 925876	NADEZHDA YAKOVLEVA	{"phone": "+70361599383"}
0005433036589	46D636	8766 687332	VALENTINA ABRAMOVA	{"email": "valentina.abramova-29121971@postgrespro.ru", "phone": "+70404885177"}
0005433036590	AC6680	7280 262001	ALLA CHERNOVA	{"phone": "+70085941663"}
0005433036591	AC6680	6013 252062	VASILIY VASILEV	{"phone": "+70912922602"}
0005433036592	77C6E3	1886 317545	MARIYA KOMAROVA	{"email": "komarovamariya_13081979@postgrespro.ru", "phone": "+70234911331"}
0005433036593	77C6E3	3253 200930	LYUDMILA ZOTOVA	{"email": "lyudmilazotova-061966@postgrespro.ru", "phone": "+70657760398"}
0005433036594	44EDE3	9715 794883	ANNA SERGEEVA	{"email": "anna-sergeeva-051963@postgrespro.ru", "phone": "+70957018569"}
0005433036595	5FA9A7	3038 656295	VALERIY RODIONOV	{"email": "v.rodionov-101978@postgrespro.ru", "phone": "+70616990267"}
0005433036596	5FA9A7	5061 066393	TATYANA SEMENOVA	{"email": "tatyana.semenova_091976@postgrespro.ru", "phone": "+70099051745"}
0005433036597	5FA9A7	5143 004317	EVGENIY PAVLOV	{"email": "pavlov.evgeniy24011980@postgrespro.ru", "phone": "+70701394785"}
0005433036598	42FA4E	3673 820110	DENIS BELOV	{"email": "denisbelov-1970@postgrespro.ru", "phone": "+70313510792"}
0005433036599	42FA4E	8596 540428	ELENA KUZMINA	{"email": "elenakuzmina.1978@postgrespro.ru", "phone": "+70025848500"}
0005433036600	F33DFD	8676 274284	VALENTINA YAKOVLEVA	{"phone": "+70900574898"}
0005433036601	9ABDEB	0323 451073	NADEZHDA ZAKHAROVA	{"email": "n.zakharova1975@postgrespro.ru", "phone": "+70247127185"}
0005433036602	551013	9728 319524	VLADIMIR VOLKOV	{"phone": "+70870205955"}
0005433036603	551013	8424 170279	MAKSIM SOROKIN	{"phone": "+70696423040"}
0005433036604	BC4ABD	3387 559942	ALEKSEY MAKAROV	{"phone": "+70374677005"}
0005433036605	81B536	1382 032717	VERA POLYAKOVA	{"email": "vpolyakova.14081971@postgrespro.ru", "phone": "+70051697391"}
0005433036606	81B536	0041 370576	RINAT MIKHAYLOV	{"email": "mikhaylov-rinat.03121970@postgrespro.ru", "phone": "+70587417694"}
0005433036607	E47F45	0256 895552	MAKSIM VASILEV	{"email": "maksim_vasilev06111952@postgrespro.ru", "phone": "+70754118815"}
0005433036608	2D70D4	2477 543273	VALERIY SOROKIN	{"phone": "+70539573388"}
0005433036609	BC7082	1744 024525	GALINA ALEKSEEVA	{"phone": "+70386339022"}
0005433036610	310A7D	8015 997460	SERGEY SERGEEV	{"email": "s-sergeev1976@postgrespro.ru", "phone": "+70478091080"}
0005433036611	310A7D	3363 047895	LIDIYA BORISOVA	{"email": "l-borisova-1967@postgrespro.ru", "phone": "+70433844748"}
0005433036612	9C02F2	7258 660534	ELENA FROLOVA	{"email": "elena_frolova_13041975@postgrespro.ru", "phone": "+70006812062"}
0005433036613	E79A10	6584 125301	ANATOLIY NIKITIN	{"email": "anatoliy-nikitin.031974@postgrespro.ru", "phone": "+70357300858"}
0005433036614	5400C9	0032 202423	NIKITA ILIN	{"email": "nikita-ilin.1978@postgrespro.ru", "phone": "+70472121544"}
0005433036615	7C32D4	6719 128267	SERGEY NOVIKOV	{"email": "novikovsergey021960@postgrespro.ru", "phone": "+70424673592"}
0005433036616	7C32D4	5132 086886	OKSANA MATVEEVA	{"email": "matveevaoksana.11121963@postgrespro.ru", "phone": "+70212493956"}
0005433036617	A7F40F	8812 271550	NATALYA KAZAKOVA	{"email": "kazakovan1967@postgrespro.ru", "phone": "+70592296675"}
0005433036618	32DBDD	1308 607264	ALEKSANDR PETROV	{"email": "aleksandr-petrov_16071964@postgrespro.ru", "phone": "+70091542706"}
0005433036619	32DBDD	2486 298495	NATALYA TITOVA	{"email": "titova.n-071982@postgrespro.ru", "phone": "+70413988592"}
0005433036620	B7A2B8	7816 886860	VASILIY FROLOV	{"phone": "+70753593296"}
0005433036621	9E9BA5	7773 851193	EVGENIY KAZAKOV	{"email": "kazakovevgeniy_1975@postgrespro.ru", "phone": "+70455494934"}
0005433036622	3E85DC	2503 360218	VLADIMIR MELNIKOV	{"email": "melnikovvladimir-1967@postgrespro.ru", "phone": "+70471614633"}
0005433036623	73DB5F	1365 751945	NATALYA VLASOVA	{"phone": "+70955805908"}
0005433036624	6B29B2	1517 820508	SVETLANA MATVEEVA	{"phone": "+70102497888"}
0005433036625	B11716	2144 427851	OLGA SERGEEVA	{"email": "olga_sergeeva-1970@postgrespro.ru", "phone": "+70341438825"}
0005433036626	B11716	3550 171470	MARIYA LAZAREVA	{"phone": "+70912371397"}
0005433036627	9C9678	3889 465191	NATALYA AKIMOVA	{"email": "natalya.akimova041971@postgrespro.ru", "phone": "+70254377732"}
0005433036628	9C9678	2849 034544	ELENA ZAKHAROVA	{"email": "zakharova.e.1975@postgrespro.ru", "phone": "+70773755315"}
0005433036629	442A9B	7590 875932	MARINA AFANASEVA	{"phone": "+70485933921"}
0005433036630	926304	9849 605011	ANNA MOISEEVA	{"email": "a.moiseeva29111972@postgrespro.ru", "phone": "+70223608566"}
0005433036631	AAE8E4	5520 837302	LARISA KOZLOVA	{"email": "larisakozlova23081977@postgrespro.ru", "phone": "+70968277691"}
0005433036632	6F683D	2704 461873	ZHANNA STEPANOVA	{"email": "stepanova-zhanna.041972@postgrespro.ru", "phone": "+70810413728"}
0005433036633	6F683D	3816 422347	SERGEY ALEKSEEV	{"phone": "+70533754739"}
0005433036634	636FB9	3420 123038	LYUDMILA NAZAROVA	{"phone": "+70082363515"}
0005433036635	636FB9	3185 391718	YULIYA MOISEEVA	{"phone": "+70919537827"}
0005433036636	57FB11	3131 036426	RINAT MATVEEV	{"email": "matveevrinat-071969@postgrespro.ru", "phone": "+70962322069"}
0005433036637	599E50	8818 057119	NIKOLAY IVANOV	{"phone": "+70108559175"}
0005433036638	D3C6C9	0320 349680	YULIYA ZAKHAROVA	{"phone": "+70520094736"}
0005433036639	751A20	5277 818579	LYUDMILA TIKHONOVA	{"email": "lyudmila_tikhonova1969@postgrespro.ru", "phone": "+70918964452"}
0005433036640	062230	6479 577635	BOGDAN GUSEV	{"email": "bgusev-17111979@postgrespro.ru", "phone": "+70721109809"}
0005433036641	A77364	4789 278501	IRINA ZAYCEVA	{"phone": "+70755638881"}
0005433036642	4E7B1B	5532 226985	SERGEY NOVIKOV	{"email": "sergey_novikov-19051975@postgrespro.ru", "phone": "+70537025018"}
0005433036643	4E7B1B	8833 306261	NINA PAVLOVA	{"phone": "+70967620952"}
0005433036644	635347	7689 267567	ALEKSANDR FILIPPOV	{"email": "filippov.a.1978@postgrespro.ru", "phone": "+70357823564"}
0005433036645	635347	3108 666144	ALEKSANDR MATVEEV	{"email": "matveevaleksandr.041973@postgrespro.ru", "phone": "+70523941590"}
0005433036646	635347	2453 096801	IBRAGIM BELOV	{"phone": "+70323661005"}
0005433036647	C8A4DB	9949 464882	RAISA ORLOVA	{"email": "orlova_raisa-021969@postgrespro.ru", "phone": "+70472610479"}
0005433036648	C8A4DB	2230 210912	ANZHELIKA BORISOVA	{"email": "borisova_a.121967@postgrespro.ru", "phone": "+70210787461"}
0005433036649	6B3F7A	2590 341400	ANNA IVANOVA	{"phone": "+70340023092"}
0005433036650	F08EEF	6502 392691	ELVINA IVANOVA	{"email": "eivanova_021969@postgrespro.ru", "phone": "+70104269976"}
0005433036651	7A5069	9970 050209	SOFYA LAZAREVA	{"phone": "+70991781398"}
0005433036652	7A5069	6877 249906	VLADISLAV KUZMIN	{"email": "v-kuzmin_1973@postgrespro.ru", "phone": "+70256301620"}
0005433036653	2E8D74	8712 293558	ANDREY KOZLOV	{"phone": "+70099266839"}
0005433036654	7DEA3B	3603 267625	ANNA ZOTOVA	{"phone": "+70632267161"}
0005433036655	D5117C	8830 758006	ANNA LUKYANOVA	{"email": "anna-lukyanova13041986@postgrespro.ru", "phone": "+70617656469"}
0005433036656	D5117C	6421 675549	TAMARA ISAEVA	{"phone": "+70215667616"}
0005433036657	F23C5A	5878 276850	OLESYA ZAYCEVA	{"email": "o_zayceva_04101965@postgrespro.ru", "phone": "+70247207676"}
0005433036658	30C72B	7334 056821	VERA KRASNOVA	{"phone": "+70592832426"}
0005433036659	A60D83	2583 570887	IRINA KUZNECOVA	{"email": "irina.kuznecova-1971@postgrespro.ru", "phone": "+70233978694"}
0005433036660	C2315E	8239 831828	MIKHAIL SEMENOV	{"phone": "+70640530173"}
0005433036661	FBB641	7571 324451	ALEKSANDR SOKOLOV	{"email": "sokolov.a_1978@postgrespro.ru", "phone": "+70199977141"}
0005433036662	99FFD4	3810 036702	VLADIMIR GRIGOREV	{"email": "v_grigorev.02101974@postgrespro.ru", "phone": "+70042411441"}
0005433036663	99FFD4	2183 185372	ALEKSEY AFANASEV	{"email": "aafanasev27021969@postgrespro.ru", "phone": "+70429195129"}
0005433036664	99FFD4	4805 256474	ALEKSANDR VOROBEV	{"email": "aleksandr.vorobev_071964@postgrespro.ru", "phone": "+70879375441"}
0005433036665	3CFF21	7181 916796	SERGEY ZAYCEV	{"email": "sergey_zaycev-11041977@postgrespro.ru", "phone": "+70670394893"}
0005433036666	61239A	2352 464191	VIKTOR IVANOV	{"phone": "+70489887734"}
0005433036667	85F49C	3850 878184	LADA MEDVEDEVA	{"email": "l-medvedeva-111970@postgrespro.ru", "phone": "+70126098624"}
0005433036668	3D2B2E	7998 404895	KSENIYA ROMANOVA	{"phone": "+70854526598"}
0005433036669	616866	1418 217973	IRINA SMIRNOVA	{"email": "smirnova.i_1972@postgrespro.ru", "phone": "+70332706082"}
0005433036670	2FD468	4339 684844	VALENTINA FEDOROVA	{"email": "fedorovavalentina.1968@postgrespro.ru", "phone": "+70271822563"}
0005433036671	597F90	8091 313548	NADEZHDA BELOVA	{"phone": "+70177647128"}
0005433036672	597F90	0063 415934	NIKOLAY KARPOV	{"email": "nikolay-karpov-1974@postgrespro.ru", "phone": "+70982285003"}
0005433036734	D23048	9777 783233	DMITRIY SERGEEV	{"phone": "+70326021292"}
0005433036673	E1D261	3912 314010	VALERIY SIDOROV	{"email": "sidorov.v.02041971@postgrespro.ru", "phone": "+70895862450"}
0005433036674	EF339E	9146 119107	ARTEM SOROKIN	{"phone": "+70162476750"}
0005433036675	17D1F5	9191 762955	ALEKSANDR ALEKSEEV	{"phone": "+70249516806"}
0005433036676	B8CA9D	8230 449735	ANNA FADEEVA	{"phone": "+70652924787"}
0005433036677	78E5BC	2854 999303	SEMEN ISAEV	{"email": "semen.isaev_111986@postgrespro.ru", "phone": "+70119746763"}
0005433036678	D73FC7	0290 212530	VALERIY SIDOROV	{"phone": "+70125437923"}
0005433036679	1A95B2	1137 129775	VALERIY ZHUKOV	{"email": "valeriy.zhukov.1974@postgrespro.ru", "phone": "+70269338613"}
0005433036680	95C298	5159 581198	NIKITA TARASOV	{"email": "tarasov-n-1977@postgrespro.ru", "phone": "+70037176958"}
0005433036681	95C298	2663 056525	VALERIY IVANOV	{"phone": "+70813685697"}
0005433036682	26603D	9122 679590	ALEKSANDR SOROKIN	{"email": "sorokin-a1965@postgrespro.ru", "phone": "+70021404486"}
0005433036683	62BE54	1809 178974	ELENA MATVEEVA	{"email": "elena.matveeva-1975@postgrespro.ru", "phone": "+70493192232"}
0005433036684	3FDC1C	3480 758954	VERA MOISEEVA	{"email": "vera_moiseeva-25111969@postgrespro.ru", "phone": "+70843116672"}
0005433036685	3FDC1C	7523 458789	VALENTINA CHERNOVA	{"email": "vchernova041970@postgrespro.ru", "phone": "+70769080815"}
0005433036686	19E66A	7514 514315	TATYANA IVANOVA	{"email": "ivanova.tatyana-1967@postgrespro.ru", "phone": "+70523298245"}
0005433036687	E65B1D	0172 813839	SERGEY NOVIKOV	{"phone": "+70736348298"}
0005433036688	95292E	0786 317731	NINA AKIMOVA	{"phone": "+70326708049"}
0005433036689	95292E	5638 159767	IVAN PETROV	{"email": "ivan-petrov051976@postgrespro.ru", "phone": "+70932127367"}
0005433036690	86800F	3727 547466	ALEKSANDR MOISEEV	{"email": "moiseev.a121976@postgrespro.ru", "phone": "+70364685310"}
0005433036691	F3A5B2	6015 702772	EKATERINA GUSEVA	{"phone": "+70134315378"}
0005433036692	79EDBD	1038 397924	ANNA VASILEVA	{"email": "vasileva-a27011969@postgrespro.ru", "phone": "+70414292573"}
0005433036693	41C83B	5012 636129	LYUBOV DENISOVA	{"email": "denisova-lyubov_1973@postgrespro.ru", "phone": "+70371470976"}
0005433036694	F6FF13	5996 819244	ALEKSEY ISAEV	{"email": "aisaev.021972@postgrespro.ru", "phone": "+70711426245"}
0005433036695	8641E4	5934 771363	LYUDMILA NIKOLAEVA	{"email": "l_nikolaeva-1961@postgrespro.ru", "phone": "+70694318182"}
0005433036696	8641E4	0932 926532	OLGA MATVEEVA	{"email": "matveeva-o121979@postgrespro.ru", "phone": "+70421626309"}
0005433036697	B61F24	0399 359952	MARIYA ZHUKOVA	{"email": "zhukova_m1960@postgrespro.ru", "phone": "+70431822586"}
0005433036698	D9BB56	9896 432411	ALEKSANDRA EGOROVA	{"phone": "+70336873964"}
0005433036699	EC3404	1773 503988	LYUBOV SOKOLOVA	{"email": "sokolova-lyubov.25041983@postgrespro.ru", "phone": "+70491305435"}
0005433036700	68D835	5939 955683	MARINA NOVIKOVA	{"phone": "+70921345735"}
0005433036701	6C7CD4	7953 732913	ANASTASIYA FROLOVA	{"phone": "+70691827170"}
0005433036702	333D44	6766 294380	ANDREY ANDREEV	{"phone": "+70390194990"}
0005433036703	7500C8	9117 690712	ANTONINA VOLKOVA	{"phone": "+70091378218"}
0005433036704	721D88	7051 911068	YULIYA NAZAROVA	{"phone": "+70110859586"}
0005433036705	65C359	9001 464067	ELENA MAKAROVA	{"email": "makarova_e1983@postgrespro.ru", "phone": "+70783141734"}
0005433036706	65C359	7783 275749	VLADIMIR BORISOV	{"phone": "+70880537882"}
0005433036707	4BBC74	6096 399204	TIGRAN KRASNOV	{"phone": "+70342539613"}
0005433036708	4BBC74	0918 156155	YULIYA SERGEEVA	{"email": "y_sergeeva-031977@postgrespro.ru", "phone": "+70097961342"}
0005433036709	4BBC74	0962 764487	STANISLAV MOROZOV	{"phone": "+70233969785"}
0005433036710	21A35F	6983 321810	ILNAR SIDOROV	{"email": "ilnar_sidorov-21011977@postgrespro.ru", "phone": "+70834987545"}
0005433036711	E31A91	1594 097697	BULAT ANDREEV	{"phone": "+70303297429"}
0005433036712	8869CB	2100 882723	ALEKSANDR ORLOV	{"email": "orlov.aleksandr26031966@postgrespro.ru", "phone": "+70223592195"}
0005433036713	2D3049	3985 600187	NADEZHDA MOISEEVA	{"email": "nadezhda.moiseeva_1973@postgrespro.ru", "phone": "+70038017191"}
0005433036714	A2A54C	4722 644028	YULIYA POTAPOVA	{"phone": "+70436180436"}
0005433036715	6D148B	5551 709257	SVETLANA KOZLOVA	{"email": "svetlana-kozlova_23111973@postgrespro.ru", "phone": "+70254619440"}
0005433036716	A51A77	7335 588139	IRINA ZAYCEVA	{"phone": "+70252309952"}
0005433036717	4F882C	0319 957767	LIDIYA STEPANOVA	{"phone": "+70741587239"}
0005433036718	0DC579	6616 934623	YULIYA POPOVA	{"phone": "+70221381484"}
0005433036719	0DC579	0916 968833	ELIZAVETA ANTONOVA	{"phone": "+70349088284"}
0005433036720	B8ED83	9098 097951	NATALYA KUZNECOVA	{"phone": "+70238119345"}
0005433036721	E3D193	5894 442943	REGINA SERGEEVA	{"phone": "+70147013611"}
0005433036722	EEC646	6659 681601	EGOR NOVIKOV	{"email": "novikov_egor-1975@postgrespro.ru", "phone": "+70478768528"}
0005433036723	615C2B	0319 404862	ALEKSEY PETROV	{"phone": "+70703617128"}
0005433036724	D12CF9	5277 653358	VIKTOR KARPOV	{"email": "karpov.v-25071967@postgrespro.ru", "phone": "+70157248373"}
0005433036725	E6665F	8469 228291	TATYANA LUKYANOVA	{"phone": "+70336474880"}
0005433036726	CFD7CA	2472 933021	ANTON ANDREEV	{"email": "andreev_anton-061971@postgrespro.ru", "phone": "+70861535089"}
0005433036727	4A94A7	3128 214136	EKATERINA ABRAMOVA	{"phone": "+70079281508"}
0005433036728	164E8B	9330 583221	VALENTINA MALYSHEVA	{"email": "malyshevavalentina_18061974@postgrespro.ru", "phone": "+70424892683"}
0005433036729	E83575	6324 145343	ARTUR MEDVEDEV	{"phone": "+70812845281"}
0005433036730	E9BF93	7297 903613	SERGEY ANTONOV	{"email": "sergey_antonov23021959@postgrespro.ru", "phone": "+70633201886"}
0005433036731	1ED541	6047 944280	NIKOLAY ALEKSEEV	{"email": "alekseev.nikolay021970@postgrespro.ru", "phone": "+70795762612"}
0005433036732	D23048	3578 358067	IVAN BELOV	{"email": "i.belov-14031974@postgrespro.ru", "phone": "+70281442862"}
0005433036733	D23048	6368 371493	EVGENIYA MASLOVA	{"phone": "+70769803472"}
0005433036735	077E2E	0017 851710	ANTON ANDREEV	{"email": "anton_andreev111974@postgrespro.ru", "phone": "+70443874896"}
0005433036736	077E2E	2366 709036	ELDAR MIKHAYLOV	{"email": "mikhaylove021973@postgrespro.ru", "phone": "+70145257957"}
0005433036737	F04DF8	5216 608368	DMITRIY VLASOV	{"email": "vlasov-dmitriy.14031975@postgrespro.ru", "phone": "+70600514153"}
0005433036738	F04DF8	7978 679304	IRINA BELYAEVA	{"phone": "+70829037897"}
0005433036739	31C070	7078 569992	VERA AKIMOVA	{"phone": "+70431657959"}
0005433036740	2D7F88	7564 153235	IRINA ZHURAVLEVA	{"phone": "+70184777834"}
0005433036741	3F60C8	8405 535747	SERGEY KOROLEV	{"phone": "+70796721467"}
0005433036742	3F60C8	0088 388711	DARYA MAKSIMOVA	{"email": "daryamaksimova091973@postgrespro.ru", "phone": "+70619620711"}
0005433036743	3F60C8	4631 215338	SVETLANA FILATOVA	{"phone": "+70324892295"}
0005433036744	B09497	5472 642952	NINA DENISOVA	{"email": "denisova.n-061968@postgrespro.ru", "phone": "+70196226982"}
0005433036745	B09497	5092 642468	LYUBOV SEMENOVA	{"phone": "+70514717077"}
0005433036746	43EC23	1129 233068	RAISA MELNIKOVA	{"email": "raisa.melnikova.101973@postgrespro.ru", "phone": "+70598175638"}
0005433036747	09F61E	1328 397312	NAIL FEDOROV	{"phone": "+70928433002"}
0005433036748	4AEDA2	2295 110610	ELENA MOISEEVA	{"email": "emoiseeva-081975@postgrespro.ru", "phone": "+70716109541"}
0005433036749	FAA865	2907 123895	OLGA ANISIMOVA	{"phone": "+70569452935"}
0005433036750	FAA865	2430 307746	NIKOLAY ZAYCEV	{"phone": "+70698498816"}
0005433036751	9B3E4F	0548 790363	TIMUR ANDREEV	{"email": "andreev.t.06081970@postgrespro.ru", "phone": "+70789881335"}
0005433036752	D21BD1	8401 946416	ALENA SERGEEVA	{"email": "sergeevaa.1962@postgrespro.ru", "phone": "+70136006649"}
0005433036753	47C24A	0092 856316	ANZHELIKA KONDRATEVA	{"email": "kondrateva_anzhelika_051984@postgrespro.ru", "phone": "+70808295962"}
0005433036754	75E05C	2627 950226	NATALYA STEPANOVA	{"phone": "+70119147886"}
0005433036755	985442	9003 519887	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy1962@postgrespro.ru", "phone": "+70457694758"}
0005433036756	985442	2555 928543	EVGENIY MELNIKOV	{"phone": "+70260033284"}
0005433036757	C4BADD	8797 139480	TATYANA ARKHIPOVA	{"phone": "+70215112425"}
0005433036758	325A93	1826 504983	NATALYA GORBUNOVA	{"email": "gorbunova_natalya-1968@postgrespro.ru", "phone": "+70955682951"}
0005433036759	FF2FCA	5597 386938	VIKTOR ABRAMOV	{"email": "v_abramov-011970@postgrespro.ru", "phone": "+70060331845"}
0005433036760	FF2FCA	3880 421763	VALERIY PAVLOV	{"email": "v.pavlov101979@postgrespro.ru", "phone": "+70233292015"}
0005433036761	807B64	7190 642697	NIKOLAY KUZMIN	{"phone": "+70087188525"}
0005433036762	807B64	7983 269740	PAVEL SEMENOV	{"email": "pavelsemenov.101969@postgrespro.ru", "phone": "+70456477113"}
0005433036763	20099A	3455 867238	EVGENIY KOROLEV	{"email": "korolev_e091981@postgrespro.ru", "phone": "+70044964492"}
0005433036764	9466F3	0450 915018	ANASTASIYA GORBUNOVA	{"email": "gorbunova.a041970@postgrespro.ru", "phone": "+70404473281"}
0005433036765	9466F3	1071 002743	INGA YAKOVLEVA	{"email": "yakovleva.inga.11011972@postgrespro.ru", "phone": "+70037692757"}
0005433036766	9466F3	7002 603082	KRISTINA BORISOVA	{"phone": "+70119872857"}
0005433036767	906139	2515 409961	OKSANA ZHURAVLEVA	{"email": "oksana-zhuravleva.071971@postgrespro.ru", "phone": "+70894138570"}
0005433036768	906139	6825 166945	TATYANA VOLKOVA	{"phone": "+70101798762"}
0005433036769	48196E	1331 274564	SOFYA MAKAROVA	{"phone": "+70943156739"}
0005433036770	635084	0972 870799	DMITRIY ROMANOV	{"phone": "+70426380533"}
0005433036771	635084	1367 702907	IRINA KUZNECOVA	{"phone": "+70027591342"}
0005433036772	3A6E5E	4992 232157	NATALYA NESTEROVA	{"phone": "+70097102252"}
0005433036773	96CD90	3304 775240	VALENTINA FILIPPOVA	{"phone": "+70858323645"}
0005433036774	49B509	7409 757296	VERA NIKIFOROVA	{"phone": "+70834275886"}
0005433036775	C4F43A	5784 897413	LYUBOV YAKOVLEVA	{"phone": "+70293478796"}
0005433036776	C4F43A	7409 483348	ANGELINA IVANOVA	{"email": "ivanova-a-1977@postgrespro.ru", "phone": "+70074060379"}
0005433036777	F8893D	3895 179636	LYUBOV KISELEVA	{"email": "lyubov-kiseleva.05021970@postgrespro.ru", "phone": "+70119971916"}
0005433036778	8ABC8A	5825 195857	NADEZHDA NESTEROVA	{"phone": "+70455191894"}
0005433036779	00FFDD	1563 660909	ALEKSANDR PAVLOV	{"phone": "+70280885629"}
0005433036780	00FFDD	4417 236206	ANNA KUZNECOVA	{"email": "a.kuznecova-15071956@postgrespro.ru", "phone": "+70852219760"}
0005433036781	00FFDD	9778 081980	ANASTASIYA NOVIKOVA	{"phone": "+70339615792"}
0005433036782	1CF579	0823 576053	ALEKSANDR TIMOFEEV	{"phone": "+70190997539"}
0005433036783	A708D4	3972 150397	YURIY SMIRNOV	{"email": "ysmirnov_1982@postgrespro.ru", "phone": "+70260237008"}
0005433036784	C4CF2C	7371 817614	NIKOLAY MIRONOV	{"phone": "+70824367300"}
0005433036785	C947E6	0249 931818	OLGA SOROKINA	{"phone": "+70098908073"}
0005433036786	9B99CA	9022 183062	ALLA KOROLEVA	{"email": "koroleva-a-07021974@postgrespro.ru", "phone": "+70136714870"}
0005433036787	8805F8	4276 801283	ALI ANTONOV	{"phone": "+70317815748"}
0005433036788	6B5374	8326 380442	ALEKSANDR ANDREEV	{"phone": "+70022913066"}
0005433036789	6B5374	9138 963742	VADIM SHEVCHENKO	{"email": "v.shevchenko.1958@postgrespro.ru", "phone": "+70460382841"}
0005433036790	6B5374	4113 746164	VALENTINA KISELEVA	{"email": "v.kiseleva041970@postgrespro.ru", "phone": "+70912645623"}
0005433036791	C219B9	6543 492750	EKATERINA ALEKSEEVA	{"phone": "+70579590141"}
0005433036792	AECAA3	9760 406469	TAMARA MASLOVA	{"email": "maslova.tamara.1970@postgrespro.ru", "phone": "+70146506921"}
0005433036793	43DEEA	6723 352991	NIKOLAY ORLOV	{"phone": "+70392976106"}
0005433036794	6C4BEA	3780 197254	VIKTORIYA AKIMOVA	{"phone": "+70136147908"}
0005433036795	EF9AC0	4975 048199	ALEKSEY KRASNOV	{"phone": "+70397484044"}
0005433036853	0F4EA7	3519 699143	NADEZHDA VLASOVA	{"phone": "+70465692484"}
0005433036796	E86D82	9789 670929	NINA NIKOLAEVA	{"email": "nikolaevanina.011969@postgrespro.ru", "phone": "+70394286915"}
0005433036797	FBE73E	7420 172968	ELENA SERGEEVA	{"email": "elena_sergeeva011983@postgrespro.ru", "phone": "+70270966158"}
0005433036798	A82A74	3315 975517	LYUDMILA SERGEEVA	{"email": "lyudmila_sergeeva_12101973@postgrespro.ru", "phone": "+70625494206"}
0005433036799	1E4921	5613 570872	GENNADIY TARASOV	{"email": "gennadiy-tarasov_021964@postgrespro.ru", "phone": "+70749568862"}
0005433036800	3D60AB	0668 316272	VERA BELYAEVA	{"phone": "+70616265270"}
0005433036801	ABB5FC	0360 233378	IGOR ZAKHAROV	{"email": "zakharov_igor_25091977@postgrespro.ru", "phone": "+70849661799"}
0005433036802	ABB5FC	7257 360203	ANTON YAKOVLEV	{"email": "yakovlev.anton-1978@postgrespro.ru", "phone": "+70262354473"}
0005433036803	C00DC4	8913 026446	DARYA SERGEEVA	{"phone": "+70312857673"}
0005433036804	C00DC4	5312 616877	MARIYA MOROZOVA	{"email": "m.morozova_30041971@postgrespro.ru", "phone": "+70812748694"}
0005433036805	3D5C80	9320 054093	ALEKSEY BONDARENKO	{"phone": "+70701303994"}
0005433036806	828AEB	7043 217894	YURIY DMITRIEV	{"phone": "+70941674535"}
0005433036807	56E894	5327 167377	TATYANA MIKHAYLOVA	{"email": "tatyana-mikhaylova071975@postgrespro.ru", "phone": "+70499325247"}
0005433036808	EBBE50	5802 576280	ALEKSEY KISELEV	{"email": "kiselev.a25121971@postgrespro.ru", "phone": "+70913014228"}
0005433036809	C7456F	4369 643641	ANASTASIYA ZHUKOVA	{"phone": "+70029485267"}
0005433036810	04BE61	7945 545185	ANNA FADEEVA	{"email": "fadeevaanna1964@postgrespro.ru", "phone": "+70330649197"}
0005433036811	303B9C	9957 603191	ALEKSANDR ROMANOV	{"email": "aromanov_1969@postgrespro.ru", "phone": "+70339943434"}
0005433036812	D4ADCB	9390 856227	NATALYA ZAKHAROVA	{"email": "n_zakharova.121967@postgrespro.ru", "phone": "+70737500180"}
0005433036813	D4ADCB	1392 657038	VLADIMIR ALEKSEEV	{"phone": "+70637609731"}
0005433036814	AC971D	3321 413140	LYUBOV MEDVEDEVA	{"phone": "+70220643339"}
0005433036815	381816	9585 264650	RUSLAN KUDRYASHOV	{"email": "kudryashov.ruslan-06041976@postgrespro.ru", "phone": "+70899319032"}
0005433036816	318BA0	9597 058146	MIKHAIL STEPANOV	{"email": "mstepanov27021971@postgrespro.ru", "phone": "+70686359098"}
0005433036817	534405	6382 375368	SERGEY DAVYDOV	{"phone": "+70798015054"}
0005433036818	BD737A	9302 472105	VYACHESLAV MELNIKOV	{"email": "melnikov_v-1975@postgrespro.ru", "phone": "+70832790113"}
0005433036819	EA5F2C	9880 866216	ZUKHRA TARASOVA	{"email": "z.tarasova021981@postgrespro.ru", "phone": "+70008455803"}
0005433036820	DB03AB	6700 598768	OLGA GUSEVA	{"phone": "+70666688885"}
0005433036821	BAB4C0	3328 498892	NIKOLAY VOLKOV	{"email": "volkov.nikolay.101971@postgrespro.ru", "phone": "+70249527993"}
0005433036822	8A73A3	8094 666705	ALEVTINA IVANOVA	{"phone": "+70272624837"}
0005433036823	571F57	6158 416190	DMITRIY IVANOV	{"email": "d_ivanov-14051960@postgrespro.ru", "phone": "+70691921877"}
0005433036824	B92619	7950 788347	NATALYA NIKOLAEVA	{"phone": "+70608355085"}
0005433036825	B92619	0674 626480	MARIYA FROLOVA	{"phone": "+70090542133"}
0005433036826	B92619	4863 245218	NIKOLAY ANDREEV	{"email": "nikolay-andreev1972@postgrespro.ru", "phone": "+70302190795"}
0005433036827	496FB2	9393 395217	IRINA VASILEVA	{"email": "vasilevai-1971@postgrespro.ru", "phone": "+70224454761"}
0005433036828	496FB2	1661 384964	KSENIYA POPOVA	{"email": "popova-kseniya-1974@postgrespro.ru", "phone": "+70646633216"}
0005433036829	B0FBE2	2926 483767	EVGENIYA PETROVA	{"email": "e-petrova-011976@postgrespro.ru", "phone": "+70461246112"}
0005433036830	B0FBE2	1828 010300	ALEKSEY SIDOROV	{"email": "aleksey.sidorov_1972@postgrespro.ru", "phone": "+70843684161"}
0005433036831	D58F91	7622 060915	ANDREY FROLOV	{"email": "andrey_frolov-1974@postgrespro.ru", "phone": "+70760244470"}
0005433036832	D58F91	4886 793568	VERA POLYAKOVA	{"email": "polyakovavera.1967@postgrespro.ru", "phone": "+70611434199"}
0005433036833	D58F91	5806 707811	TAISIYA SIDOROVA	{"phone": "+70948566458"}
0005433036834	B9D542	8316 867384	ANNA BELOVA	{"email": "anna_belova-1965@postgrespro.ru", "phone": "+70746027759"}
0005433036835	B9D542	1782 536919	MIKHAIL MIKHAYLOV	{"email": "mikhaylov.mikhail-21121965@postgrespro.ru", "phone": "+70823063595"}
0005433036836	11A133	7625 126041	BORIS KOZLOV	{"email": "boriskozlov_1969@postgrespro.ru", "phone": "+70773148904"}
0005433036837	11A133	1523 588326	VIKTOR VASILEV	{"email": "vasilev-viktor26021978@postgrespro.ru", "phone": "+70413303608"}
0005433036838	084BFF	2782 785160	VALENTINA KUZNECOVA	{"email": "v_kuznecova.111982@postgrespro.ru", "phone": "+70024971298"}
0005433036839	084BFF	0915 106028	ELENA ANDREEVA	{"email": "elena-andreeva_01031971@postgrespro.ru", "phone": "+70953408649"}
0005433036840	AE15E5	1064 299490	IRINA AFANASEVA	{"email": "afanasevairina-1973@postgrespro.ru", "phone": "+70679489917"}
0005433036841	AE15E5	6618 965838	GENNADIY NOVIKOV	{"email": "novikovg-10111968@postgrespro.ru", "phone": "+70033038842"}
0005433036842	DE4BEC	3169 540750	ANNA KISELEVA	{"phone": "+70431980150"}
0005433036843	4C93E7	4203 604940	VARVARA NIKOLAEVA	{"email": "varvaranikolaeva-021972@postgrespro.ru", "phone": "+70905086288"}
0005433036844	4C93E7	0421 837048	VLADISLAV SIDOROV	{"phone": "+70462851569"}
0005433036845	4C93E7	0774 402068	VALENTINA KONDRATEVA	{"email": "valentinakondrateva.101980@postgrespro.ru", "phone": "+70588818492"}
0005433036846	7B0C28	7974 990820	IRINA NOVIKOVA	{"phone": "+70210028999"}
0005433036847	EAE2D8	4509 439869	LYUBOV ORLOVA	{"phone": "+70176002605"}
0005433036848	EAE2D8	2482 406739	LYUDMILA GORBUNOVA	{"phone": "+70011345211"}
0005433036849	EAE2D8	0921 190577	YURIY BARANOV	{"email": "baranovy-1977@postgrespro.ru", "phone": "+70397023117"}
0005433036850	7AADB2	3707 026587	ELENA SAVELEVA	{"email": "saveleva-e_1967@postgrespro.ru", "phone": "+70803720059"}
0005433036851	0F4EA7	3369 362330	PAVEL KARPOV	{"email": "karpov-pavel_19121961@postgrespro.ru", "phone": "+70859705599"}
0005433036852	0F4EA7	8221 530845	EVGENIY SEMENOV	{"email": "semenov-e-1973@postgrespro.ru", "phone": "+70485705775"}
0005433036854	2D59B0	4387 231405	NIKOLAY POPOV	{"phone": "+70463313948"}
0005433036855	7C88AB	8078 213078	TATYANA POPOVA	{"phone": "+70961683727"}
0005433036856	291841	4863 801227	PELAGEYA KOZLOVA	{"phone": "+70653977433"}
0005433036857	009431	1144 512044	NATALYA MAKAROVA	{"email": "makarovan.1968@postgrespro.ru", "phone": "+70692295748"}
0005433036858	92AF7C	0332 731865	ALEKSANDR VOLKOV	{"phone": "+70647562643"}
0005433036859	92AF7C	6102 284340	LIDIYA MARTYNOVA	{"email": "martynova-l-1974@postgrespro.ru", "phone": "+70921919739"}
0005433036860	68E449	8172 181683	SVETLANA GAVRILOVA	{"email": "s_gavrilova-121977@postgrespro.ru", "phone": "+70189042933"}
0005433036861	82206D	8839 748150	NIKOLAY KUZMIN	{"phone": "+70135814606"}
0005433036862	C189C0	2445 941135	OLEG ZAYCEV	{"email": "o-zaycev.26081970@postgrespro.ru", "phone": "+70626871907"}
0005433036863	D7FBFD	8159 264641	OLGA POPOVA	{"phone": "+70514119975"}
0005433036864	D7FBFD	9804 145676	VALENTINA KOROLEVA	{"phone": "+70452920810"}
0005433036865	E5616D	9420 446205	NIKOLAY SCHERBAKOV	{"email": "n-scherbakov1979@postgrespro.ru", "phone": "+70739699738"}
0005433036866	E08153	0398 259288	SERGEY ZAYCEV	{"email": "sergeyzaycev.011962@postgrespro.ru", "phone": "+70134952934"}
0005433036867	CF0215	9473 887050	VLADIMIR IVANOV	{"email": "ivanovvladimir-1961@postgrespro.ru", "phone": "+70945079369"}
0005433036868	5AEF70	2722 398603	SERGEY NAUMOV	{"email": "sergeynaumov_17031975@postgrespro.ru", "phone": "+70148565617"}
0005433036869	AECBFA	8546 292334	SERGEY ZAKHAROV	{"email": "s.zakharov30101967@postgrespro.ru", "phone": "+70458390198"}
0005433036870	1F9505	8594 459981	ANZHELIKA EFREMOVA	{"phone": "+70426745713"}
0005433036871	82405A	8442 973357	VASILIY ROMANOV	{"email": "v_romanov_041979@postgrespro.ru", "phone": "+70358326931"}
0005433036872	82405A	0270 222074	ANDREY NAUMOV	{"email": "a.naumov_1971@postgrespro.ru", "phone": "+70743526635"}
0005433036873	1021F8	5853 795028	ELIZAVETA SMIRNOVA	{"email": "e.smirnova_21101971@postgrespro.ru", "phone": "+70955271495"}
0005433036874	E1774B	2693 318261	LIDIYA POPOVA	{"phone": "+70290632206"}
0005433036875	712513	7280 415797	VLADIMIR VOROBEV	{"email": "vladimir.vorobev_1988@postgrespro.ru", "phone": "+70044169517"}
0005433036876	492C02	4088 931218	EVGENIY MOISEEV	{"phone": "+70652097252"}
0005433036877	82D30F	8920 812110	ANDREY ALEKSEEV	{"email": "andrey-alekseev_1979@postgrespro.ru", "phone": "+70872637972"}
0005433036878	B2A65D	3091 770096	NATALYA SMIRNOVA	{"phone": "+70724367270"}
0005433036879	EC047A	0992 782075	ALFIYA TARASOVA	{"email": "tarasovaalfiya.1973@postgrespro.ru", "phone": "+70246415363"}
0005433036880	E0C663	9467 429962	MIKHAIL PAVLOV	{"phone": "+70010937718"}
0005433036881	DBCCB9	0994 435909	ZARINA POPOVA	{"email": "z-popova_1981@postgrespro.ru", "phone": "+70415312846"}
0005433036882	0445E0	2304 617813	ARINA KRASNOVA	{"email": "a_krasnova.1975@postgrespro.ru", "phone": "+70942594994"}
0005433036883	0445E0	8841 814451	KIRILL NAZAROV	{"phone": "+70232369933"}
0005433036884	F1C7CE	8501 046687	AZAT KOZLOV	{"email": "azat_kozlov-1965@postgrespro.ru", "phone": "+70611544689"}
0005433036885	534E9D	7742 818154	TATYANA FEDOROVA	{"email": "fedorova-t-1977@postgrespro.ru", "phone": "+70366999459"}
0005433036886	534E9D	5216 330269	NADEZHDA TIKHONOVA	{"email": "ntikhonova.061963@postgrespro.ru", "phone": "+70055373785"}
0005433036887	9ADE0D	5101 585235	NIKOLAY KUZMIN	{"phone": "+70654364501"}
0005433036943	090A04	5200 425744	OLGA NIKITINA	{"phone": "+70101957073"}
0005433036888	3E996F	6809 702439	NINA POLYAKOVA	{"email": "polyakovan_1977@postgrespro.ru", "phone": "+70697612021"}
0005433036889	3E996F	2849 960159	ALEKSEY FEDOROV	{"phone": "+70266391166"}
0005433036890	9ED3D4	1592 328294	VLADISLAV KUZMIN	{"email": "v_kuzmin-19011974@postgrespro.ru", "phone": "+70204688688"}
0005433036891	EEE9C7	3548 853369	VADIM KARPOV	{"phone": "+70897704061"}
0005433036892	B49800	8789 086344	POLINA KUZMINA	{"phone": "+70164729224"}
0005433036893	B49800	9160 980319	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy-011974@postgrespro.ru", "phone": "+70300778579"}
0005433036894	B49800	1093 682304	EKATERINA VASILEVA	{"email": "ekaterinavasileva.1973@postgrespro.ru", "phone": "+70674181343"}
0005433036895	801232	9891 068584	EGOR TARASOV	{"email": "tarasove_28041977@postgrespro.ru", "phone": "+70414872303"}
0005433036896	491B24	0459 990466	IRINA LAZAREVA	{"phone": "+70955051850"}
0005433036897	794581	4541 397584	YURIY ILIN	{"email": "yuriy_ilin_01081969@postgrespro.ru", "phone": "+70013697701"}
0005433036898	794581	6666 329155	LARISA KUZMINA	{"email": "kuzmina.larisa_051969@postgrespro.ru", "phone": "+70824272866"}
0005433036899	7E3C52	1873 823267	ALEKSANDR EGOROV	{"email": "aleksandr.egorov_1960@postgrespro.ru", "phone": "+70033601993"}
0005433036900	7E3C52	8194 722295	ELENA GUSEVA	{"email": "e-guseva-061958@postgrespro.ru", "phone": "+70056995610"}
0005433036901	EA192B	2861 889925	OLESYA DMITRIEVA	{"email": "dmitrieva-olesya_21051969@postgrespro.ru", "phone": "+70582977383"}
0005433036902	C2712A	9871 489511	LYUBOV ROMANOVA	{"phone": "+70113904448"}
0005433036903	A45A7D	8896 761816	NINA SOKOLOVA	{"email": "n_sokolova-13041974@postgrespro.ru", "phone": "+70877630611"}
0005433036904	EE3201	6723 016004	LIDIYA MELNIKOVA	{"email": "l.melnikova.031965@postgrespro.ru", "phone": "+70620074110"}
0005433036905	EE3201	1741 515715	VLADIMIR KULIKOV	{"phone": "+70704143224"}
0005433036906	784F43	4254 022773	LILIYA SMIRNOVA	{"email": "l_smirnova_28031965@postgrespro.ru", "phone": "+70001276769"}
0005433036907	3AF4B3	1305 259163	ALEKSEY KAZAKOV	{"phone": "+70936391635"}
0005433036908	3AF4B3	6405 354096	ALEKSANDR NAZAROV	{"phone": "+70977215960"}
0005433036909	400376	3783 941825	SERGEY TARASOV	{"email": "s_tarasov1988@postgrespro.ru", "phone": "+70094064224"}
0005433036910	C90241	4653 649257	DENIS NOVIKOV	{"phone": "+70191100704"}
0005433036911	9B0643	0900 908870	VLADIMIR IVANOV	{"phone": "+70501815578"}
0005433037093	1830C4	8449 820003	SERGEY NAZAROV	{"phone": "+70328570131"}
0005433036912	1C440F	4990 694837	DMITRIY FEDOROV	{"email": "fedorov_dmitriy.1981@postgrespro.ru", "phone": "+70188827759"}
0005433036913	5E4A09	7374 283062	OKSANA BORISOVA	{"email": "borisova_o.101970@postgrespro.ru", "phone": "+70596821903"}
0005433036914	36BA53	3477 915728	SERGEY MELNIKOV	{"phone": "+70410289963"}
0005433036915	074D59	9991 155449	RAISA OSIPOVA	{"email": "raisa.osipova1977@postgrespro.ru", "phone": "+70843596105"}
0005433036916	8B3C56	8648 311293	IVAN KUDRYASHOV	{"email": "kudryashov_i.021971@postgrespro.ru", "phone": "+70516503177"}
0005433036917	8B3C56	3799 541225	NADEZHDA KONDRATEVA	{"phone": "+70542748643"}
0005433036918	47AF0E	8754 047332	ALEKSANDRA ROMANOVA	{"email": "aromanova_1971@postgrespro.ru", "phone": "+70220387170"}
0005433036919	47AF0E	5777 312993	VADIM NIKOLAEV	{"email": "nikolaev-v_1980@postgrespro.ru", "phone": "+70243742536"}
0005433036920	AFAF1A	2732 215098	ALEKSEY GRIGOREV	{"email": "aleksey-grigorev19081965@postgrespro.ru", "phone": "+70339178130"}
0005433036921	CF9950	5732 775389	NIKOLAY KONOVALOV	{"email": "n-konovalov08041979@postgrespro.ru", "phone": "+70972546346"}
0005433036922	CEFB65	0247 939697	ELINA NIKOLAEVA	{"email": "nikolaevaelina27041971@postgrespro.ru", "phone": "+70973014280"}
0005433036923	1618AB	7129 673532	PETR KUZNECOV	{"phone": "+70827228655"}
0005433036924	1618AB	3262 255344	ALEKSANDR MAKSIMOV	{"phone": "+70449860975"}
0005433036925	0CA081	3695 248132	NIKOLAY OSIPOV	{"email": "nikolay_osipov-051977@postgrespro.ru", "phone": "+70375702926"}
0005433036926	934631	5827 037090	OLGA KUDRYASHOVA	{"email": "kudryashovaolga_1970@postgrespro.ru", "phone": "+70051217169"}
0005433036927	363882	1488 654395	LIDIYA MAKAROVA	{"email": "lidiya_makarova01091972@postgrespro.ru", "phone": "+70512543300"}
0005433036928	363882	6708 762726	SERGEY ZAKHAROV	{"email": "sergeyzakharov-1968@postgrespro.ru", "phone": "+70763320008"}
0005433036929	733DFD	3220 042349	VALENTINA SAVELEVA	{"email": "saveleva_valentina-1972@postgrespro.ru", "phone": "+70108820514"}
0005433036930	68910B	3702 266119	ILYA NIKITIN	{"phone": "+70858606302"}
0005433036931	D85041	6120 507028	ALEKSANDR PETROV	{"email": "petrovaleksandr_091992@postgrespro.ru", "phone": "+70154069161"}
0005433036932	CFB85C	7715 819454	NIKOLAY KUZNECOV	{"email": "kuznecovn_1963@postgrespro.ru", "phone": "+70290081132"}
0005433036933	20A18B	1478 863933	IRINA MOROZOVA	{"phone": "+70258260069"}
0005433036934	20A18B	5488 583379	VIKTORIYA MOROZOVA	{"email": "morozova_viktoriya_051955@postgrespro.ru", "phone": "+70937495796"}
0005433036935	3D0E6E	1580 681062	IRINA KONOVALOVA	{"phone": "+70313733566"}
0005433036936	11C3DA	4383 877911	ELENA MAKAROVA	{"phone": "+70296575705"}
0005433036937	11C3DA	1715 141726	ARINA KOZLOVA	{"email": "arinakozlova.1966@postgrespro.ru", "phone": "+70827388801"}
0005433036938	10FFBF	8860 597059	GENNADIY IVANOV	{"phone": "+70705811476"}
0005433036939	10FFBF	1170 958245	DMITRIY KUZNECOV	{"phone": "+70500688997"}
0005433036940	AB92B0	6407 502557	ALEKSANDR ANTONOV	{"email": "antonova-08011968@postgrespro.ru", "phone": "+70741466136"}
0005433036941	AB92B0	1038 994994	ANASTASIYA SOROKINA	{"phone": "+70923468194"}
0005433036942	090A04	0127 869307	OLGA TITOVA	{"email": "titova-olga.1972@postgrespro.ru", "phone": "+70457684148"}
0005433036944	541E9D	4844 776406	GENNADIY TIKHONOV	{"phone": "+70402820343"}
0005433036945	5F321B	6130 427830	VIKTOR RODIONOV	{"phone": "+70416755766"}
0005433036946	89C500	8877 123340	YULIYA DMITRIEVA	{"email": "yuliya_dmitrieva_1987@postgrespro.ru", "phone": "+70539100374"}
0005433036947	DD19D8	1887 387181	LEONID ROMANOV	{"email": "l.romanov081976@postgrespro.ru", "phone": "+70957660869"}
0005433036948	98C6BA	1780 941501	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.091959@postgrespro.ru", "phone": "+70888054983"}
0005433036949	98C6BA	1296 033462	ALEKSEY NIKOLAEV	{"phone": "+70268808315"}
0005433036950	98C6BA	8796 967291	VALENTINA IVANOVA	{"phone": "+70166870537"}
0005433036951	E08C7D	8319 874598	VITALIY MIKHAYLOV	{"phone": "+70468689962"}
0005433036952	BA120E	6744 667311	MAKSIM STEPANOV	{"phone": "+70554872046"}
0005433036953	A086BE	8007 626213	ANDREY ZHUKOV	{"email": "zhukov_andrey-30011980@postgrespro.ru", "phone": "+70747314845"}
0005433036954	82FF84	0098 204609	KONSTANTIN FROLOV	{"email": "frolov-konstantin.031966@postgrespro.ru", "phone": "+70527627093"}
0005433036955	C2100A	8137 709741	SERGEY ALEKSANDROV	{"phone": "+70906060296"}
0005433036956	F7041F	4316 894469	VITALIY SMIRNOV	{"phone": "+70355456900"}
0005433036957	D7194A	3891 183755	ANGELINA NOVIKOVA	{"email": "a_novikova1960@postgrespro.ru", "phone": "+70577273377"}
0005433036958	EAB7DD	2037 280052	TATYANA IVANOVA	{"email": "ivanovatatyana02041973@postgrespro.ru", "phone": "+70606735301"}
0005433036959	EED2B7	1769 954933	MARIYA KOROLEVA	{"phone": "+70656348505"}
0005433036960	EED2B7	8660 282389	IGOR MAKAROV	{"phone": "+70305483106"}
0005433036961	B9BD4B	6784 927354	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva-lyudmila.01121979@postgrespro.ru", "phone": "+70144862288"}
0005433036962	FDBADF	7766 046883	OLEG BORISOV	{"phone": "+70191231996"}
0005433036963	FDBADF	1240 581029	VIKTOR FROLOV	{"email": "frolov_viktor1980@postgrespro.ru", "phone": "+70140544143"}
0005433036964	A2417E	3789 803638	VALENTINA STEPANOVA	{"email": "v.stepanova31101981@postgrespro.ru", "phone": "+70808865739"}
0005433036965	B37BF8	7661 565437	EKATERINA SERGEEVA	{"phone": "+70522210264"}
0005433036966	B37BF8	2275 925847	NADEZHDA ZAKHAROVA	{"email": "zakharovanadezhda_11091973@postgrespro.ru", "phone": "+70123193369"}
0005433036967	9E7631	5898 595284	NADEZHDA SIDOROVA	{"phone": "+70423350422"}
0005433036968	2889F5	8688 243474	GULFIYA ROMANOVA	{"phone": "+70927167015"}
0005433036969	E85FCB	2204 885476	TATYANA VLASOVA	{"email": "tvlasova-22081967@postgrespro.ru", "phone": "+70002175828"}
0005433036970	E85FCB	7292 177520	KLARA SOKOLOVA	{"phone": "+70132661396"}
0005433036971	32DD03	7121 616884	PAVEL TIKHONOV	{"phone": "+70140035679"}
0005433036972	ADE7CC	0071 022297	YURIY YAKOVLEV	{"email": "yuriy-yakovlev_091967@postgrespro.ru", "phone": "+70053545866"}
0005433036973	1C3152	4925 061659	VLADIMIR TIKHONOV	{"phone": "+70050840157"}
0005433036974	BEA7A2	6543 447462	ALEKSEY MATVEEV	{"email": "a_matveev.081968@postgrespro.ru", "phone": "+70022414495"}
0005433036975	0B9DE9	4725 342083	MIKHAIL ANDREEV	{"email": "mikhailandreev-031960@postgrespro.ru", "phone": "+70992253606"}
0005433036976	585EEC	6240 212584	EVGENIY MATVEEV	{"email": "e_matveev-1971@postgrespro.ru", "phone": "+70911860944"}
0005433036977	A868E4	5648 612780	KAPITALINA DANILOVA	{"email": "kapitalina-danilova_101968@postgrespro.ru", "phone": "+70324806092"}
0005433036978	A868E4	1507 226102	ALEKSEY KUZNECOV	{"phone": "+70033429072"}
0005433036979	334900	0097 727998	SERGEY KOZLOV	{"phone": "+70621260101"}
0005433036980	53EF23	6279 041671	VLADIMIR SMIRNOV	{"email": "smirnov-v-031972@postgrespro.ru", "phone": "+70651967225"}
0005433036981	10DBCD	2547 040833	NIKOLAY SOLOVEV	{"phone": "+70063293120"}
0005433036982	57E141	0787 120297	NADEZHDA MEDVEDEVA	{"email": "n_medvedeva-16021978@postgrespro.ru", "phone": "+70450570266"}
0005433036983	57E141	5234 336283	GALINA VASILEVA	{"email": "galina_vasileva.021969@postgrespro.ru", "phone": "+70292833749"}
0005433036984	62AD8F	8424 039633	MIKHAIL KOZLOV	{"phone": "+70968995171"}
0005433036985	62AD8F	5066 933358	VYACHESLAV VLASOV	{"phone": "+70456364644"}
0005433036986	C15BC7	1535 299725	ALEKSANDR SERGEEV	{"phone": "+70907571047"}
0005433036987	6182C6	7050 763017	NINA SEMENOVA	{"phone": "+70924241063"}
0005433036988	876953	2526 416315	VIKTOR FEDOROV	{"email": "fedorov_viktor_1978@postgrespro.ru", "phone": "+70909506012"}
0005433036989	B14CA9	6480 385862	OLGA ORLOVA	{"phone": "+70256103458"}
0005433036990	040C56	3837 740336	NATALIYA MALYSHEVA	{"phone": "+70968834775"}
0005433036991	C21591	8634 565110	VIKTORIYA VOLKOVA	{"phone": "+70863212624"}
0005433036992	3DDB5F	0022 407812	NIKOLAY SOROKIN	{"email": "sorokin-nikolay13081960@postgrespro.ru", "phone": "+70249667884"}
0005433036993	3DDB5F	3155 848998	VIKTORIYA ILINA	{"email": "viktoriya.ilina051972@postgrespro.ru", "phone": "+70285270228"}
0005433036994	6789A0	7712 810655	PAVEL MIRONOV	{"phone": "+70772793328"}
0005433036995	6789A0	0052 457775	IGOR VOLKOV	{"email": "igor_volkov_07071979@postgrespro.ru", "phone": "+70937756288"}
0005433036996	11A33D	8926 892304	NINA MIKHAYLOVA	{"email": "mikhaylova-nina-1971@postgrespro.ru", "phone": "+70822670166"}
0005433036997	11A33D	7216 714967	DARYA VASILEVA	{"phone": "+70733387614"}
0005433036998	BC8CD7	4991 935832	MARINA KOVALEVA	{"email": "kovaleva_marina.03121970@postgrespro.ru", "phone": "+70870049580"}
0005433036999	C80C05	8839 906272	YULIYA KONDRATEVA	{"email": "kondrateva-yuliya.051969@postgrespro.ru", "phone": "+70628464499"}
0005433037000	C80C05	2496 020798	ANTONINA RODIONOVA	{"phone": "+70520931815"}
0005433037001	3EB415	0398 114036	NINA STEPANOVA	{"email": "n_stepanova1969@postgrespro.ru", "phone": "+70097330582"}
0005433037002	3EB415	6629 388671	ALEKSANDRA ILINA	{"email": "ilina-a-1967@postgrespro.ru", "phone": "+70146598163"}
0005433037003	D170B5	7654 493742	ANDREY TIMOFEEV	{"phone": "+70456750847"}
0005433037004	D170B5	7734 758783	ANATOLIY KAZAKOV	{"email": "kazakov-a-1974@postgrespro.ru", "phone": "+70533034480"}
0005433037005	D630B7	0043 067591	DMITRIY YAKOVLEV	{"email": "yakovlev.d.1972@postgrespro.ru", "phone": "+70279858535"}
0005433037006	D630B7	6258 529076	OLGA AFANASEVA	{"email": "afanaseva_olga-1970@postgrespro.ru", "phone": "+70753565547"}
0005433037007	48D419	4380 701393	OKSANA ILINA	{"phone": "+70695183413"}
0005433037008	48D419	1036 791379	EGOR GORBUNOV	{"phone": "+70465179349"}
0005433037009	261DA1	0400 185060	ANDREY FEDOROV	{"phone": "+70555936870"}
0005433037010	274B89	7751 593995	IRINA ANDREEVA	{"phone": "+70852468335"}
0005433037011	E79DC0	3946 268415	LIDIYA SOKOLOVA	{"phone": "+70994130330"}
0005433037012	E79DC0	8082 945776	NADEZHDA NOVIKOVA	{"phone": "+70044654448"}
0005433037013	7D68AE	9960 217495	IVAN NIKOLAEV	{"phone": "+70442760325"}
0005433037014	2448B3	9656 002197	OLGA SIDOROVA	{"phone": "+70608221239"}
0005433037015	2448B3	2760 048595	NATALYA ABRAMOVA	{"email": "natalya.abramova_1978@postgrespro.ru", "phone": "+70705930446"}
0005433037016	DA92B8	2872 178305	NADEZHDA FILIPPOVA	{"phone": "+70624293264"}
0005433037017	68B60F	8769 846245	POLINA SOKOLOVA	{"email": "polina_sokolova-02061975@postgrespro.ru", "phone": "+70797393746"}
0005433037018	68B60F	2120 920221	OLGA POPOVA	{"phone": "+70742863673"}
0005433037019	605359	3176 308238	ANNA YUDINA	{"email": "anna.yudina_23051969@postgrespro.ru", "phone": "+70218829676"}
0005433037020	D5C2B5	5329 781287	DARYA NIKITINA	{"phone": "+70853709641"}
0005433037021	33E95E	4619 028745	SERGEY SHEVCHENKO	{"phone": "+70727191740"}
0005433037022	B5167B	6077 127830	VLADISLAV BARANOV	{"email": "vladislav-baranov.091973@postgrespro.ru", "phone": "+70882128075"}
0005433037023	B923AF	4766 803607	OKSANA KONOVALOVA	{"phone": "+70295506029"}
0005433037024	71DAC8	6874 371599	INNA SIDOROVA	{"phone": "+70854633792"}
0005433037025	71DAC8	1871 918001	VALERIY TARASOV	{"phone": "+70452444790"}
0005433037026	AD027A	9469 680373	NIKOLAY DMITRIEV	{"phone": "+70209785471"}
0005433037027	AD027A	8476 546624	NADEZHDA VOROBEVA	{"email": "vorobeva_nadezhda-20091985@postgrespro.ru", "phone": "+70852941641"}
0005433037028	33936A	8744 249538	YURIY VOLKOV	{"email": "volkov.yuriy-08121977@postgrespro.ru", "phone": "+70420156821"}
0005433037029	33936A	2852 666892	VALENTINA IVANOVA	{"email": "valentina.ivanova-091963@postgrespro.ru", "phone": "+70816216840"}
0005433037030	480072	8142 380124	FANIL SERGEEV	{"phone": "+70688773181"}
0005433037031	480072	2730 908197	ANASTASIYA TARASOVA	{"phone": "+70918360286"}
0005433037032	90DC6B	0168 969062	RIMMA NAUMOVA	{"phone": "+70475522829"}
0005433037033	7BF509	1382 262830	SERGEY KONOVALOV	{"email": "konovalovs-27041974@postgrespro.ru", "phone": "+70445472403"}
0005433037034	434B56	6707 744841	VLADIMIR CHERNOV	{"phone": "+70426600278"}
0005433037035	B9DE89	4479 903578	OLGA MARTYNOVA	{"phone": "+70010258883"}
0005433037036	B9DE89	1452 344810	OLGA ALEKSEEVA	{"email": "alekseeva-o-081978@postgrespro.ru", "phone": "+70361333755"}
0005433037037	0BCAF0	1498 422467	TATYANA GAVRILOVA	{"email": "gavrilova_tatyana_1968@postgrespro.ru", "phone": "+70232607577"}
0005433037038	B3E7A3	2081 345142	ALENA PAVLOVA	{"email": "pavlova_a-1970@postgrespro.ru", "phone": "+70552964781"}
0005433037039	B3E7A3	1557 501609	EKATERINA MAKAROVA	{"email": "e_makarova_1964@postgrespro.ru", "phone": "+70357282365"}
0005433037040	437B59	6042 313280	DINARA MATVEEVA	{"phone": "+70105865791"}
0005433037041	352C97	1744 810253	ZINAIDA NIKITINA	{"email": "zinaida-nikitina_1972@postgrespro.ru", "phone": "+70911967532"}
0005433037042	5F3905	7017 486793	NINA NIKITINA	{"phone": "+70177109210"}
0005433037043	5F3905	2630 493459	ANTONINA MALYSHEVA	{"phone": "+70488514155"}
0005433037044	18981E	0723 587151	VALENTINA TITOVA	{"email": "titovav_1972@postgrespro.ru", "phone": "+70188095993"}
0005433037045	18981E	0319 434910	ANNA NIKOLAEVA	{"email": "anna.nikolaeva111980@postgrespro.ru", "phone": "+70366625031"}
0005433037046	9306AE	0436 214620	VLADIMIR BELOV	{"phone": "+70678472196"}
0005433037047	392EE2	0839 133600	OLEG VOLKOV	{"phone": "+70471512005"}
0005433037048	392EE2	9799 072509	ANTONINA POPOVA	{"email": "popova_a.011976@postgrespro.ru", "phone": "+70968566013"}
0005433037049	B0E5D7	8467 991373	VITALIY OSIPOV	{"phone": "+70050445829"}
0005433037050	CF6AAF	8799 784732	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov1968@postgrespro.ru", "phone": "+70711670322"}
0005433037051	4F4D83	4983 212369	ARTEM NIKOLAEV	{"phone": "+70374753392"}
0005433037052	4F4D83	7196 667729	VLADIMIR KONOVALOV	{"phone": "+70133142116"}
0005433037053	F4A9C3	9194 753750	RAISA BOGDANOVA	{"email": "bogdanovar_24031977@postgrespro.ru", "phone": "+70510030624"}
0005433037054	2460A2	3603 775581	ANGELINA AKIMOVA	{"email": "akimova_angelina.1981@postgrespro.ru", "phone": "+70029778211"}
0005433037055	2460A2	8516 052085	KIRILL VASILEV	{"email": "kirill-vasilev1963@postgrespro.ru", "phone": "+70136471035"}
0005433037056	2E250F	1001 632440	KSENIYA FILATOVA	{"email": "kseniyafilatova.101969@postgrespro.ru", "phone": "+70272047331"}
0005433037057	2E250F	6110 056176	TAISIYA MELNIKOVA	{"phone": "+70659404529"}
0005433037058	B3A812	0968 224163	SVETLANA POPOVA	{"phone": "+70108766385"}
0005433037059	326D25	0222 618392	PAVEL MEDVEDEV	{"email": "medvedevp_1973@postgrespro.ru", "phone": "+70031703636"}
0005433037060	326D25	6802 524540	VITALIY FEDOROV	{"email": "fedorovv-1960@postgrespro.ru", "phone": "+70476350270"}
0005433037061	CE1CB2	4497 349412	KRISTINA MEDVEDEVA	{"phone": "+70321717956"}
0005433037062	999829	9969 327579	MARIYA ANDREEVA	{"phone": "+70714840279"}
0005433037063	EE770F	3030 955909	TATYANA SOKOLOVA	{"phone": "+70101769939"}
0005433037064	C2B5ED	8073 639138	ANDREY BELOV	{"phone": "+70840296779"}
0005433037065	947083	2431 322597	AYRAT POPOV	{"email": "apopov121976@postgrespro.ru", "phone": "+70360227059"}
0005433037066	947083	0414 451547	OLEG BELOV	{"phone": "+70990115310"}
0005433037067	947083	4710 432185	NATALYA ILINA	{"email": "ilinanatalya.121967@postgrespro.ru", "phone": "+70516716479"}
0005433037068	FB1AB0	9015 406786	ARTUR SERGEEV	{"email": "sergeev-a_091965@postgrespro.ru", "phone": "+70949338485"}
0005433037069	FB1AB0	8989 772167	ALENA DMITRIEVA	{"phone": "+70736210879"}
0005433037070	A280AF	3694 599777	EKATERINA ORLOVA	{"phone": "+70032848448"}
0005433037071	A280AF	1880 604517	VITALIY ANTONOV	{"phone": "+70086098771"}
0005433037072	F24252	0804 563673	ANNA FILIPPOVA	{"phone": "+70662543317"}
0005433037073	F24252	0908 153484	MIKHAIL SOKOLOV	{"email": "mikhailsokolov121964@postgrespro.ru", "phone": "+70928290556"}
0005433037074	A9D3DF	1778 248613	ANTONINA SERGEEVA	{"phone": "+70784188115"}
0005433037075	C19722	9827 423699	MIKHAIL ZAYCEV	{"phone": "+70786196901"}
0005433037076	6E04F2	2909 403927	ANDREY SOROKIN	{"phone": "+70041569878"}
0005433037077	1B246B	0167 191995	IRINA SOKOLOVA	{"email": "sokolovai09101973@postgrespro.ru", "phone": "+70014357531"}
0005433037078	1B246B	7160 094890	SVETLANA MELNIKOVA	{"phone": "+70807307600"}
0005433037079	BDE8E2	4442 027915	VALENTIN GAVRILOV	{"phone": "+70341263364"}
0005433037080	B6A948	7662 325408	BORIS BELOV	{"phone": "+70630937253"}
0005433037081	B6A948	7025 486639	IRINA MARTYNOVA	{"email": "i.martynova.1974@postgrespro.ru", "phone": "+70249264514"}
0005433037082	DE7A2D	6457 256153	DARYA LUKYANOVA	{"email": "darya.lukyanova.061974@postgrespro.ru", "phone": "+70408259836"}
0005433037083	6DCBEF	9787 514912	ALSU KOLESNIKOVA	{"phone": "+70778709392"}
0005433037084	B9FBCF	8671 608061	VIKTOR AFANASEV	{"email": "afanasev-v05101971@postgrespro.ru", "phone": "+70353274469"}
0005433037085	162BE2	0501 313669	NINA ISAEVA	{"email": "nina_isaeva_021985@postgrespro.ru", "phone": "+70446200227"}
0005433037086	5C9612	1723 698593	OLGA MELNIKOVA	{"email": "olgamelnikova091979@postgrespro.ru", "phone": "+70446868907"}
0005433037087	69BD8E	4515 223384	GENNADIY ZAKHAROV	{"email": "g.zakharov-1979@postgrespro.ru", "phone": "+70176579091"}
0005433037088	69BD8E	2134 333804	SERGEY SIDOROV	{"email": "sidorov_sergey-1975@postgrespro.ru", "phone": "+70670006740"}
0005433037089	B41F3F	3941 500956	VASILIY ISAEV	{"email": "vasiliyisaev_061975@postgrespro.ru", "phone": "+70527221928"}
0005433037090	B41F3F	3270 583317	YURIY ILIN	{"email": "yuriyilin101971@postgrespro.ru", "phone": "+70361585986"}
0005433037091	D43B4B	4927 428242	SERGEY SEMENOV	{"email": "ssemenov_06011975@postgrespro.ru", "phone": "+70033966878"}
0005433037092	1FC04F	7531 996479	YULIYA SOROKINA	{"email": "sorokina.y1966@postgrespro.ru", "phone": "+70667430895"}
0005433037094	4B3B47	7961 084171	YURIY KUZMIN	{"email": "yuriykuzmin-1961@postgrespro.ru", "phone": "+70749935369"}
0005433037095	B8EF8F	5555 359960	EVGENIY IVANOV	{"email": "evgeniy_ivanov_031975@postgrespro.ru", "phone": "+70804896260"}
0005433037096	1BBA46	1761 426857	TAMARA BELYAEVA	{"email": "tbelyaeva.051971@postgrespro.ru", "phone": "+70060776512"}
0005433037097	DBFD38	5892 305282	ALEKSANDR GRIGOREV	{"email": "agrigorev081973@postgrespro.ru", "phone": "+70995317291"}
0005433037098	F46DD9	7353 548741	VENERA SERGEEVA	{"email": "sergeeva.v.1972@postgrespro.ru", "phone": "+70371021301"}
0005433037099	4140D9	3256 403113	EVGENIY EGOROV	{"email": "evgeniy-egorov.1972@postgrespro.ru", "phone": "+70815346647"}
0005433037100	66136C	3651 232778	EVGENIY KONOVALOV	{"phone": "+70498975260"}
0005433037101	E2593D	0701 667771	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov.081972@postgrespro.ru", "phone": "+70089986493"}
0005433037102	AF0460	8968 145134	SERGEY IVANOV	{"phone": "+70783648598"}
0005433037103	F60BEA	9977 356840	ALEKSANDRA IVANOVA	{"phone": "+70283511579"}
0005433037104	F60BEA	4612 949665	DMITRIY OSIPOV	{"email": "dmitriyosipov.1977@postgrespro.ru", "phone": "+70385287251"}
0005433037105	F60BEA	2388 841596	KLAVDIYA BARANOVA	{"phone": "+70804724032"}
0005433037106	A43DA7	7059 610980	OKSANA DAVYDOVA	{"email": "odavydova_03011970@postgrespro.ru", "phone": "+70117739624"}
0005433037107	E5B236	6640 978133	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin-08011969@postgrespro.ru", "phone": "+70761403774"}
0005433037108	E5B236	3499 946535	ANDREY ROMANOV	{"phone": "+70246843160"}
0005433037109	87087A	9760 160908	IRINA MIKHAYLOVA	{"email": "irinamikhaylova_011962@postgrespro.ru", "phone": "+70233286108"}
0005433037110	87087A	5561 075539	ANATOLIY KISELEV	{"phone": "+70328710493"}
0005433037111	30DC36	3256 716117	EKATERINA ALEKSANDROVA	{"phone": "+70422196038"}
0005433037112	30DC36	6441 850731	VLADIMIR KUZNECOV	{"phone": "+70468915929"}
0005433037113	B4523F	6184 720522	NATALYA KOROLEVA	{"phone": "+70292779835"}
0005433037114	D81DE7	5047 011289	ELENA GUSEVA	{"email": "elena-guseva.1957@postgrespro.ru", "phone": "+70578533288"}
0005433037115	932424	1477 028053	NATALIYA ZOTOVA	{"email": "nataliya.zotova-06101987@postgrespro.ru", "phone": "+70868225732"}
0005433037116	932424	8302 376238	VALENTINA IVANOVA	{"email": "valentina-ivanova-1967@postgrespro.ru", "phone": "+70873376632"}
0005433037117	398508	4047 824186	DMITRIY ROMANOV	{"phone": "+70674654155"}
0005433037118	C0B71B	5160 343229	ALEKSANDR NAZAROV	{"phone": "+70863135508"}
0005433037119	17EF4F	5157 940740	MARINA SOROKINA	{"phone": "+70765350520"}
0005433037120	17EF4F	0091 968231	ELENA NESTEROVA	{"email": "e_nesterova_1963@postgrespro.ru", "phone": "+70473170352"}
0005433037121	9D6FF3	1190 796593	NIKOLAY EGOROV	{"phone": "+70200678253"}
0005433037122	A16BD9	7611 188215	ANDREY GAVRILOV	{"email": "gavrilov-andrey-011974@postgrespro.ru", "phone": "+70178910233"}
0005433037123	A16BD9	9453 178099	EVDOKIYA ORLOVA	{"email": "orlova_evdokiya_10111970@postgrespro.ru", "phone": "+70380557018"}
0005433037124	4B8FA6	3302 649726	ANATOLIY TARASOV	{"phone": "+70982064705"}
0005433037125	DC8C95	7625 801299	ANDREY MOROZOV	{"phone": "+70506572447"}
0005433037126	511755	5079 225603	VIKTOR VLASOV	{"email": "vlasovv_1969@postgrespro.ru", "phone": "+70604659066"}
0005433037127	511755	2095 365846	TATYANA BORISOVA	{"phone": "+70706394210"}
0005433037128	395D18	1375 437554	VALENTINA NOVIKOVA	{"email": "novikova.v-051965@postgrespro.ru", "phone": "+70295173642"}
0005433037129	395D18	4649 566673	VALERIY NOVIKOV	{"phone": "+70430445450"}
0005433037130	395D18	1445 669278	RENAT TARASOV	{"email": "r-tarasov15091975@postgrespro.ru", "phone": "+70042477844"}
0005433037131	395D18	8911 504896	RAFIS SOROKIN	{"email": "sorokin_r_1974@postgrespro.ru", "phone": "+70955980033"}
0005433037132	F8CAC4	2328 370283	ALEKSANDR SERGEEV	{"phone": "+70820444722"}
0005433037133	F8CAC4	3961 891255	GALINA MAKSIMOVA	{"email": "maksimova-galina_1979@postgrespro.ru", "phone": "+70291329751"}
0005433037134	34F25E	7155 196434	ANASTASIYA DAVYDOVA	{"email": "anastasiya.davydova.1967@postgrespro.ru", "phone": "+70824646317"}
0005433037135	3CD245	2868 822407	ALEKSANDR OSIPOV	{"phone": "+70814741305"}
0005433037136	3CD245	2274 993634	ALEKSEY SEMENOV	{"email": "alekseysemenov.1981@postgrespro.ru", "phone": "+70275453397"}
0005433037137	92280B	2166 587878	VASILIY SEMENOV	{"phone": "+70642863211"}
0005433037138	14E905	5679 380074	ALEKSANDR AFANASEV	{"email": "afanasev_a_28101963@postgrespro.ru", "phone": "+70586243481"}
0005433037139	5FB78E	3675 955376	ELENA TITOVA	{"email": "titova.elena011969@postgrespro.ru", "phone": "+70350564370"}
0005433037140	9781D0	5102 383071	EVGENIY PETROV	{"email": "e-petrov1972@postgrespro.ru", "phone": "+70811339708"}
0005433037141	E0911B	3541 614091	LARISA ORLOVA	{"email": "larisa.orlova-1974@postgrespro.ru", "phone": "+70245792109"}
0005433037142	E0911B	8043 481204	ELENA STEPANOVA	{"phone": "+70977258450"}
0005433037143	B37D10	4509 323457	YURIY ALEKSANDROV	{"email": "aleksandrov.yuriy_1973@postgrespro.ru", "phone": "+70093146113"}
0005433037144	616180	1785 129813	VLADIMIR SCHERBAKOV	{"email": "scherbakovv111968@postgrespro.ru", "phone": "+70041075825"}
0005433037145	C868D3	0939 316197	TATYANA ANDREEVA	{"phone": "+70774455368"}
0005433037146	C868D3	8744 131312	OLGA BELYAEVA	{"phone": "+70077849618"}
0005433037147	23DAE1	5974 783830	ELVIRA MOROZOVA	{"phone": "+70816422778"}
0005433037148	46E781	3393 193566	GLEB FEDOTOV	{"email": "fedotov_g-031976@postgrespro.ru", "phone": "+70991377373"}
0005433037149	46E781	7184 164432	VASILIY VOLKOV	{"email": "vasiliyvolkov-05111959@postgrespro.ru", "phone": "+70002240740"}
0005433037150	46E781	5150 369051	REGINA KONOVALOVA	{"phone": "+70020391057"}
0005433037151	11E05D	7408 983532	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr.05031985@postgrespro.ru", "phone": "+70284015837"}
0005433037152	3FA333	0342 897045	ZOYA BORISOVA	{"email": "z-borisova081983@postgrespro.ru", "phone": "+70895871198"}
0005433037153	3FA333	6117 184343	GALINA MOISEEVA	{"email": "galinamoiseeva.28061975@postgrespro.ru", "phone": "+70449095865"}
0005433037154	9AB7C9	0310 195782	ZINAIDA MAKSIMOVA	{"email": "zinaida_maksimova.21041974@postgrespro.ru", "phone": "+70160565604"}
0005433037155	5EBC58	7539 599451	DMITRIY VASILEV	{"email": "vasilev.d_01061963@postgrespro.ru", "phone": "+70980585245"}
0005433037156	E080E7	7879 863302	ZINAIDA FROLOVA	{"email": "frolovaz_1972@postgrespro.ru", "phone": "+70833293679"}
0005433037157	4B8B9D	4715 665957	NADEZHDA KAZAKOVA	{"email": "n-kazakova-19121969@postgrespro.ru", "phone": "+70914315835"}
0005433037158	4B8B9D	0377 329709	KRISTINA NESTEROVA	{"email": "kristina.nesterova.1984@postgrespro.ru", "phone": "+70809269813"}
0005433037159	F59C0D	0496 035205	VIKTOR TARASOV	{"email": "tarasovviktor_1981@postgrespro.ru", "phone": "+70009729416"}
0005433037160	F59C0D	6788 451928	ALBINA SMIRNOVA	{"phone": "+70418750513"}
0005433037161	547302	8866 368209	DMITRIY ANTONOV	{"phone": "+70797261506"}
0005433037162	271C91	3512 175745	LIDIYA TIKHONOVA	{"email": "tikhonovalidiya-121974@postgrespro.ru", "phone": "+70886827505"}
0005433037163	417942	3655 588308	ALEKSANDR KAZAKOV	{"email": "akazakov.18051963@postgrespro.ru", "phone": "+70922788222"}
0005433037164	C4CAF8	1343 828264	ANNA KUZNECOVA	{"email": "kuznecova-a_081961@postgrespro.ru", "phone": "+70948833142"}
0005433037165	C4CAF8	0241 357136	NATALYA RODIONOVA	{"phone": "+70977083745"}
0005433037166	038130	7659 250792	GALINA ZHURAVLEVA	{"phone": "+70298866345"}
0005433037167	038130	0375 565781	VLADIMIR GORBUNOV	{"phone": "+70984019512"}
0005433037168	9EC0C5	5789 071215	SERGEY MAKAROV	{"phone": "+70048591856"}
0005433037169	9EC0C5	6943 105256	LYUDMILA MAKSIMOVA	{"phone": "+70273253086"}
0005433037170	49DE64	9087 389346	PETR OSIPOV	{"phone": "+70310831335"}
0005433037171	49DE64	7688 767401	NIKOLAY VASILEV	{"phone": "+70008702403"}
0005433037172	49DE64	1377 303023	DIANA MASLOVA	{"phone": "+70540550810"}
0005433037173	E9332E	7477 938390	ALEKSANDR KAZAKOV	{"email": "aleksandr_kazakov_31121975@postgrespro.ru", "phone": "+70058243289"}
0005433037174	E9332E	1748 957809	VLADIMIR ORLOV	{"phone": "+70892403764"}
0005433037175	CB1F41	5190 492115	ELMIRA SOKOLOVA	{"phone": "+70130095750"}
0005433037176	AE07BB	0940 748563	ALEKSANDR GAVRILOV	{"phone": "+70872354591"}
0005433037177	E96C13	4362 986898	ARTEM SAVELEV	{"phone": "+70811447038"}
0005433037178	86A1F0	2672 320711	VERA ALEKSANDROVA	{"email": "vera_aleksandrova-1975@postgrespro.ru", "phone": "+70804386928"}
0005433037179	86A1F0	3416 958488	VIKTOR KUZNECOV	{"email": "vkuznecov_051958@postgrespro.ru", "phone": "+70242217593"}
0005433037180	86E7E0	9365 499223	ALEKSANDR SOKOLOV	{"phone": "+70237138550"}
0005433037181	86E7E0	9686 305585	MARINA FILIPPOVA	{"email": "m.filippova.101969@postgrespro.ru", "phone": "+70351873736"}
0005433037182	598A2F	8952 849279	ELENA IVANOVA	{"email": "e_ivanova-071965@postgrespro.ru", "phone": "+70358888371"}
0005433037183	598A2F	8550 116318	DMITRIY BORISOV	{"phone": "+70149610787"}
0005433037184	1A83D3	2328 257013	NIKOLAY IVANOV	{"email": "ivanov-nikolay061976@postgrespro.ru", "phone": "+70098269189"}
0005433037185	1A83D3	7062 588182	YULIYA KOROLEVA	{"email": "korolevayuliya_021964@postgrespro.ru", "phone": "+70898190709"}
0005433037186	1A83D3	0088 355789	LYUDMILA NESTEROVA	{"email": "lyudmila_nesterova061973@postgrespro.ru", "phone": "+70126635625"}
0005433037187	1A83D3	3220 473351	LARISA ANTONOVA	{"email": "antonova.larisa-071977@postgrespro.ru", "phone": "+70761270046"}
0005433037188	A821D3	0097 779370	YURIY TIKHONOV	{"email": "tikhonov-yuriy.09021992@postgrespro.ru", "phone": "+70775850458"}
0005433037189	19CF0C	8389 518283	EVGENIY MIRONOV	{"email": "e-mironov_27011978@postgrespro.ru", "phone": "+70808672685"}
0005433037190	19CF0C	9009 260627	SERGEY BONDARENKO	{"email": "sergeybondarenko_1980@postgrespro.ru", "phone": "+70318797119"}
0005433037191	E28B8A	7959 771552	ANATOLIY KUZNECOV	{"email": "kuznecov.anatoliy12071982@postgrespro.ru", "phone": "+70931943673"}
0005433037192	DE4BDE	4248 594058	ALEKSEY ALEKSEEV	{"phone": "+70690091280"}
0005433037193	DE4BDE	7493 578541	EKATERINA KISELEVA	{"email": "kiseleva-ekaterina_04051978@postgrespro.ru", "phone": "+70012193592"}
0005433037194	C9A894	7091 532387	ILYA TIMOFEEV	{"phone": "+70961542337"}
0005433037195	96B8F3	8443 165370	NIKOLAY PAVLOV	{"phone": "+70129141640"}
0005433037196	E3E042	2665 053331	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev.31031965@postgrespro.ru", "phone": "+70246376309"}
0005433037197	EDD3D9	0085 621125	VLADIMIR KOZLOV	{"email": "kozlovv.021975@postgrespro.ru", "phone": "+70769917444"}
0005433037198	EDD3D9	4798 107737	GALINA ZAKHAROVA	{"email": "zakharovag-121975@postgrespro.ru", "phone": "+70848895461"}
0005433037199	CB781F	3430 989224	VIKTORIYA KOROLEVA	{"email": "koroleva-v-011972@postgrespro.ru", "phone": "+70989777649"}
0005433037200	CB781F	1334 694537	MARINA RODIONOVA	{"phone": "+70211783865"}
0005433037201	8F8386	4856 087541	ANDREY MAKAROV	{"email": "a-makarov-1975@postgrespro.ru", "phone": "+70888746824"}
0005433037202	B6DFA1	7732 646082	ANDREY STEPANOV	{"email": "andreystepanov-1969@postgrespro.ru", "phone": "+70957701578"}
0005433037203	B6DFA1	5001 977323	NINA MATVEEVA	{"phone": "+70101209574"}
0005433037204	B6DFA1	0302 740591	SVETLANA EFIMOVA	{"email": "sefimova-29031967@postgrespro.ru", "phone": "+70973289852"}
0005433037205	FBAF58	8279 707852	ALEKSEY MOROZOV	{"email": "morozova19011973@postgrespro.ru", "phone": "+70661045950"}
0005433037206	376E4D	9459 238538	EVGENIYA ALEKSEEVA	{"phone": "+70201590330"}
0005433037207	376E4D	0977 637243	VIKTOR DMITRIEV	{"email": "v_dmitriev-121974@postgrespro.ru", "phone": "+70931785368"}
0005433037208	4E98FE	4515 778668	POLINA ALEKSANDROVA	{"email": "paleksandrova_09081969@postgrespro.ru", "phone": "+70162768301"}
0005433037209	906F79	8780 262259	ANTON MOROZOV	{"email": "morozov.anton1978@postgrespro.ru", "phone": "+70160974170"}
0005433037210	B36378	0520 399448	VENIAMIN KOZLOV	{"phone": "+70941949671"}
0005433037211	B36378	7270 243976	DENIS SIDOROV	{"phone": "+70478992997"}
0005433037212	FBF811	1353 093124	VERA STEPANOVA	{"email": "stepanovavera_05051962@postgrespro.ru", "phone": "+70890240210"}
0005433037213	B6CE70	4094 792655	VALENTINA KULIKOVA	{"phone": "+70092846545"}
0005433037214	36F249	9162 664437	IRINA TARASOVA	{"phone": "+70500834068"}
0005433037215	5F7F17	5432 624900	VALENTINA SERGEEVA	{"phone": "+70700894995"}
0005433037216	E32621	3526 950204	MARIYA MALYSHEVA	{"email": "malysheva_mariya.01061971@postgrespro.ru", "phone": "+70546841966"}
0005433037217	E32621	0707 420375	ANTON SIDOROV	{"phone": "+70007515765"}
0005433037218	2C169D	0702 846384	VASILIY NIKOLAEV	{"phone": "+70707338755"}
0005433037219	2C169D	2173 225356	EKATERINA FOMINA	{"email": "ekaterina_fomina.041977@postgrespro.ru", "phone": "+70483888652"}
0005433037220	53226A	9277 427205	ZINAIDA SEMENOVA	{"phone": "+70868855951"}
0005433037221	E08511	3657 215854	VLADIMIR IVANOV	{"email": "ivanovv-27101965@postgrespro.ru", "phone": "+70208860396"}
0005433037222	736B9A	4310 427871	VERONIKA YUDINA	{"phone": "+70031709597"}
0005433037223	736B9A	8510 255311	ZINAIDA KUZMINA	{"email": "kuzmina_zinaida111973@postgrespro.ru", "phone": "+70378391821"}
0005433037224	9E9310	4931 705347	GALINA NIKOLAEVA	{"email": "g.nikolaeva_091962@postgrespro.ru", "phone": "+70301130068"}
0005433037225	CCE80D	2075 032769	ELENA KISELEVA	{"email": "elena.kiseleva_1973@postgrespro.ru", "phone": "+70182882800"}
0005433037226	CCE80D	8461 267911	MARAT ANDREEV	{"phone": "+70773714153"}
0005433037227	48F2C5	0122 357787	ALEKSANDR ORLOV	{"email": "orlov-a_09031978@postgrespro.ru", "phone": "+70984541601"}
0005433037228	46418A	6027 478251	ANDREY ALEKSEEV	{"phone": "+70745445665"}
0005433037229	F09032	8623 854690	ANASTASIYA VASILEVA	{"email": "vasileva.a.081965@postgrespro.ru", "phone": "+70751795685"}
0005433037230	F09032	7406 399725	NINA TIMOFEEVA	{"phone": "+70860795739"}
0005433037231	04229A	0276 988590	MARIYA IVANOVA	{"email": "m_ivanova30011973@postgrespro.ru", "phone": "+70621917107"}
0005433037232	04229A	6509 649108	NINA KALININA	{"email": "nkalinina13121971@postgrespro.ru", "phone": "+70635560594"}
0005433037233	D68F50	8311 213778	ELENA ZAKHAROVA	{"email": "zakharovaelena_031980@postgrespro.ru", "phone": "+70629183130"}
0005433037234	1E30C8	9387 947274	SVETLANA VLASOVA	{"phone": "+70933361867"}
0005433037235	AE91C2	1624 945166	MAKSIM KUZNECOV	{"email": "m-kuznecov15091972@postgrespro.ru", "phone": "+70512761418"}
0005433037236	4CD743	8207 539798	ALEKSEY VLASOV	{"phone": "+70250683688"}
0005433037237	8EFDA7	4906 567436	ALEKSANDR IVANOV	{"email": "ivanovaleksandr1965@postgrespro.ru", "phone": "+70299370235"}
0005433037238	8EFDA7	2415 337075	MAKSIM NOVIKOV	{"phone": "+70209540904"}
0005433037239	91CF26	6108 151768	IGOR KULIKOV	{"phone": "+70222722951"}
0005433037240	F81205	7447 403086	DIANA KOMAROVA	{"phone": "+70295163071"}
0005433037241	F81205	6540 110542	TAMARA BORISOVA	{"phone": "+70864873370"}
0005433037242	59B9BE	0102 907819	DMITRIY ANDREEV	{"email": "dmitriyandreev.031971@postgrespro.ru", "phone": "+70298248699"}
0005433037243	59B9BE	0249 216754	GALINA MOROZOVA	{"email": "galina_morozova-03051981@postgrespro.ru", "phone": "+70519295165"}
0005433037244	669B32	5236 132856	ALEVTINA ALEKSEEVA	{"email": "alekseeva_a.11031973@postgrespro.ru", "phone": "+70150776728"}
0005433037245	669B32	4978 038569	ELENA MEDVEDEVA	{"email": "elena-medvedeva.01031965@postgrespro.ru", "phone": "+70249218028"}
0005433037246	A3D422	7181 772214	SVETLANA ZAYCEVA	{"email": "svetlana.zayceva_30081965@postgrespro.ru", "phone": "+70422291092"}
0005433037247	CF1AA6	2299 728188	SERGEY KRASNOV	{"phone": "+70230940556"}
0005433037248	CF1AA6	6237 701959	NADEZHDA LAZAREVA	{"phone": "+70355242545"}
0005433037249	879CE4	4899 558917	ELENA PETROVA	{"phone": "+70701980110"}
0005433037250	503287	0504 400816	DMITRIY KUZNECOV	{"phone": "+70178543156"}
0005433037251	503287	0237 497774	VASILIY SOROKIN	{"email": "v_sorokin-041966@postgrespro.ru", "phone": "+70876206675"}
0005433037252	68AAE1	0826 146394	SERGEY IVANOV	{"email": "s.ivanov_1968@postgrespro.ru", "phone": "+70285080707"}
0005433037253	53B926	5595 326934	NATALIYA GERASIMOVA	{"email": "gerasimovan.1973@postgrespro.ru", "phone": "+70624790805"}
0005433037254	53B926	7951 540502	GALINA SMIRNOVA	{"phone": "+70227425756"}
0005433037255	52FCA1	3238 668456	NATALIYA LOGINOVA	{"phone": "+70546928944"}
0005433037256	52FCA1	5765 523529	EVGENIYA ALEKSEEVA	{"email": "alekseeva.evgeniya_03121964@postgrespro.ru", "phone": "+70254611383"}
0005433037257	1F2A60	4206 510354	VALERIY KISELEV	{"email": "v-kiselev_1972@postgrespro.ru", "phone": "+70460058676"}
0005433037258	1F2A60	0692 268933	VADIM ALEKSEEV	{"phone": "+70117010076"}
0005433037259	1F2A60	0593 397325	ALEKSANDR SMIRNOV	{"email": "smirnov-a.081978@postgrespro.ru", "phone": "+70189106399"}
0005433037260	073355	1113 328412	ANASTASIYA NIKOLAEVA	{"phone": "+70679060116"}
0005433037261	9B7D78	8086 319492	ALEKSEY VOLKOV	{"phone": "+70804213525"}
0005433037262	9B7D78	7700 506748	LYUDMILA PETROVA	{"email": "lyudmila.petrova-011974@postgrespro.ru", "phone": "+70888712553"}
0005433037263	96F868	8037 748279	ANATOLIY MIRONOV	{"email": "mironovanatoliy_1981@postgrespro.ru", "phone": "+70010601750"}
0005433037264	E0F5D6	2330 050457	OLGA KOROLEVA	{"phone": "+70287065321"}
0005433037265	E0F5D6	5866 963112	IGOR NOVIKOV	{"email": "igor.novikov_1977@postgrespro.ru", "phone": "+70976116198"}
0005433037266	35DF09	8055 160576	ANATOLIY ZAYCEV	{"phone": "+70457664770"}
0005433037267	2D123F	1942 210350	ZINAIDA ALEKSEEVA	{"phone": "+70247787818"}
0005433037268	7746AD	1970 798987	ALEKSANDR POPOV	{"email": "popov_a-1980@postgrespro.ru", "phone": "+70721593858"}
0005433037269	DA8564	7146 387509	ALEKSEY KUZNECOV	{"phone": "+70199348703"}
0005433037270	F05148	5809 450957	YULIYA GORBUNOVA	{"email": "yuliya_gorbunova.031976@postgrespro.ru", "phone": "+70251067204"}
0005433037688	0C3C35	8295 497748	TATYANA NIKITINA	{"phone": "+70439851190"}
0005433037271	F05148	0986 462532	ALEKSANDRA ABRAMOVA	{"email": "a.abramova-1971@postgrespro.ru", "phone": "+70876778208"}
0005433037272	F05148	7408 574980	VLADIMIR FROLOV	{"email": "v-frolov1970@postgrespro.ru", "phone": "+70990348788"}
0005433037273	360B9B	1366 230573	VYACHESLAV BELOV	{"phone": "+70131712172"}
0005433037274	0627CB	2715 905260	NATALYA KOMAROVA	{"email": "komarovanatalya-1986@postgrespro.ru", "phone": "+70332480121"}
0005433037275	DBE54C	7082 248108	YURIY ROMANOV	{"phone": "+70079313163"}
0005433037276	03E355	4895 409580	YULIYA DANILOVA	{"phone": "+70506206335"}
0005433037277	93AF54	1638 095557	ARSENIY KOZLOV	{"email": "kozlov.arseniy.1972@postgrespro.ru", "phone": "+70263349597"}
0005433037278	36B6B9	6443 073163	DARYA KONDRATEVA	{"phone": "+70587606436"}
0005433037279	60D803	8452 425938	DILYARA TARASOVA	{"phone": "+70262707921"}
0005433037280	006B01	1012 402359	ANNA VASILEVA	{"email": "a_vasileva-1976@postgrespro.ru", "phone": "+70195488191"}
0005433037281	006B01	7534 153494	ALEKSANDR GORBUNOV	{"phone": "+70672427325"}
0005433037282	006B01	2055 131775	VALENTIN VASILEV	{"phone": "+70885632610"}
0005433037283	8E2891	0763 964292	PAVEL NAZAROV	{"email": "p.nazarov.30071976@postgrespro.ru", "phone": "+70225585063"}
0005433037284	8E2891	6992 553567	VERA SOROKINA	{"email": "verasorokina.30091977@postgrespro.ru", "phone": "+70718257460"}
0005433037285	D8F0BB	8459 552797	ELENA VLASOVA	{"email": "vlasova-e_031968@postgrespro.ru", "phone": "+70471301669"}
0005433037286	8FB8A4	7055 030514	EDGAR PETROV	{"phone": "+70337144469"}
0005433037287	02E686	6645 898763	ALEKSANDRA SERGEEVA	{"phone": "+70874396297"}
0005433037288	462DFE	7690 136687	NATALYA POPOVA	{"email": "natalya-popova_03031979@postgrespro.ru", "phone": "+70575068907"}
0005433037289	462DFE	8704 233666	OLGA SOKOLOVA	{"email": "osokolova031979@postgrespro.ru", "phone": "+70578546419"}
0005433037290	73FF12	8488 182589	ALEKSANDR VOLKOV	{"email": "a-volkov.01081976@postgrespro.ru", "phone": "+70156960167"}
0005433037291	6F5657	7781 933237	LYUBOV POPOVA	{"phone": "+70069232866"}
0005433037292	6F5657	0409 553473	KLAVDIYA PETROVA	{"email": "k-petrova_29051977@postgrespro.ru", "phone": "+70901257892"}
0005433037293	148CC8	8343 849335	ALEKSANDR SOKOLOV	{"email": "sokolov.a_041970@postgrespro.ru", "phone": "+70924001151"}
0005433037294	A7F21D	4285 435923	LYUDMILA VASILEVA	{"phone": "+70385829300"}
0005433037295	A7F21D	2440 061266	DAVID PAVLOV	{"email": "dpavlov_1977@postgrespro.ru", "phone": "+70237045157"}
0005433037296	54D7D9	2103 851784	ELENA SOLOVEVA	{"phone": "+70595472810"}
0005433037297	A7E851	6791 668337	SAMVEL STEPANOV	{"email": "samvel_stepanov.1964@postgrespro.ru", "phone": "+70859461874"}
0005433037298	5D56CF	5006 781427	SOFIYA SOROKINA	{"email": "sorokina.s_11021968@postgrespro.ru", "phone": "+70545263460"}
0005433037299	A1A67E	1801 337038	ANATOLIY KUZNECOV	{"phone": "+70303146736"}
0005433037300	A1A67E	5116 498247	NINA KOMAROVA	{"phone": "+70719949071"}
0005433037301	0B67A1	1581 174080	SVETLANA MELNIKOVA	{"email": "melnikova-svetlana.1960@postgrespro.ru", "phone": "+70295061903"}
0005433037302	3C0489	3811 762010	NIKITA IVANOV	{"phone": "+70586152333"}
0005433037303	3C0489	4670 282659	ELENA IVANOVA	{"phone": "+70194634790"}
0005433037304	A0CD97	9137 970693	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a1965@postgrespro.ru", "phone": "+70660778533"}
0005433037305	A0CD97	1800 399536	ARMEN GUSEV	{"email": "agusev.101962@postgrespro.ru", "phone": "+70420936182"}
0005433037306	64395F	5384 599406	ELENA FILIPPOVA	{"phone": "+70685620491"}
0005433037307	64395F	5258 253576	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana.17021962@postgrespro.ru", "phone": "+70308921986"}
0005433037308	54301D	8986 221150	ALEKSANDR KAZAKOV	{"phone": "+70624721272"}
0005433037309	4A7035	5281 696721	EKATERINA TROFIMOVA	{"phone": "+70443971279"}
0005433037310	D5A579	3905 453142	LIDIYA ILINA	{"phone": "+70599379472"}
0005433037311	CC00B5	8438 526022	ELIZAVETA KISELEVA	{"email": "kiseleva-elizaveta071967@postgrespro.ru", "phone": "+70627913262"}
0005433037312	C5C4E6	5456 942870	TAMARA ZHURAVLEVA	{"phone": "+70495811530"}
0005433037313	139C46	7364 461387	SERGEY SERGEEV	{"phone": "+70081181155"}
0005433037314	8A167E	1358 916177	ANNA TIMOFEEVA	{"email": "a.timofeeva-1960@postgrespro.ru", "phone": "+70349130288"}
0005433037315	C0A7BC	4535 548335	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko-1984@postgrespro.ru", "phone": "+70924539265"}
0005433037316	6CD126	6975 025903	ANDREY KOZLOV	{"phone": "+70736944602"}
0005433037317	6CD126	6120 235519	VLADIMIR STEPANOV	{"email": "stepanov_vladimir_22111970@postgrespro.ru", "phone": "+70114954184"}
0005433037318	86E2AC	4025 575612	SVETLANA KUZNECOVA	{"phone": "+70751060833"}
0005433037319	86E2AC	5564 552648	ELENA FOMINA	{"email": "fominae.25101967@postgrespro.ru", "phone": "+70614671900"}
0005433037320	2FFB03	0409 768207	STANISLAV GAVRILOV	{"email": "gavrilov_stanislav-1995@postgrespro.ru", "phone": "+70306944617"}
0005433037321	2FFB03	6929 155739	VALENTINA LUKYANOVA	{"email": "lukyanovavalentina.1972@postgrespro.ru", "phone": "+70933039281"}
0005433037322	627DD9	9273 179421	NADEZHDA GRISHINA	{"email": "grishinan-02121964@postgrespro.ru", "phone": "+70784765119"}
0005433037323	8446F6	0003 207189	TATYANA ROMANOVA	{"email": "tromanova11111967@postgrespro.ru", "phone": "+70518857684"}
0005433037324	9455CC	9154 776386	ALEKSANDR DENISOV	{"phone": "+70847790281"}
0005433037325	6F48AE	7127 861861	PAVEL SEMENOV	{"email": "semenov_pavel_091982@postgrespro.ru", "phone": "+70487571622"}
0005433037326	6F48AE	7304 674119	LYUDMILA FROLOVA	{"email": "lyudmila-frolova.1970@postgrespro.ru", "phone": "+70984479566"}
0005433037327	6F48AE	5187 998697	SERGEY SEMENOV	{"phone": "+70283088036"}
0005433037328	2E4C00	7296 281472	SERGEY PAVLOV	{"phone": "+70134448491"}
0005433037329	2E4C00	4629 100270	EVGENIYA KUZNECOVA	{"phone": "+70873564330"}
0005433037330	E015D8	4108 201740	PAVEL RODIONOV	{"email": "pavel.rodionov05071982@postgrespro.ru", "phone": "+70685707687"}
0005433037331	3387CF	8054 103485	EVGENIY ALEKSEEV	{"email": "alekseev.evgeniy021967@postgrespro.ru", "phone": "+70669811282"}
0005433037332	3387CF	8263 875681	ELENA SCHERBAKOVA	{"email": "elena_scherbakova-1980@postgrespro.ru", "phone": "+70465703423"}
0005433037333	3387CF	6735 188987	RUSLAN KUZMIN	{"email": "ruslan-kuzmin.1969@postgrespro.ru", "phone": "+70387870392"}
0005433037334	83CA64	5908 113744	VLADIMIR SAVELEV	{"phone": "+70655620630"}
0005433037838	7C8965	8370 736445	ILYA KISELEV	{"phone": "+70799233233"}
0005433037335	A4C659	4980 115541	IGOR ZAKHAROV	{"email": "zakharov.igor-1975@postgrespro.ru", "phone": "+70920987864"}
0005433037336	A4C659	4602 681521	RAMIL MAKAROV	{"phone": "+70566103054"}
0005433037337	64793B	8503 973725	ANDREY KUZNECOV	{"email": "andrey.kuznecov_21061972@postgrespro.ru", "phone": "+70873807426"}
0005433037338	64793B	2497 941581	DARYA MAKAROVA	{"email": "makarovad.1967@postgrespro.ru", "phone": "+70519294385"}
0005433037339	678A42	4487 901103	DANIL FEDOROV	{"email": "fedorov.d18031970@postgrespro.ru", "phone": "+70970658261"}
0005433037340	678A42	7136 486913	VIOLETTA KOZLOVA	{"phone": "+70235492981"}
0005433037341	90539B	6492 624724	DENIS IVANOV	{"email": "ivanov_d_011967@postgrespro.ru", "phone": "+70863420676"}
0005433037342	AA1F74	2021 810042	ANNA STEPANOVA	{"phone": "+70454938995"}
0005433037343	AA1F74	8339 554779	SVETLANA BELOVA	{"phone": "+70567237030"}
0005433037344	FE3F6E	4673 149572	SVETLANA MOROZOVA	{"email": "smorozova011975@postgrespro.ru", "phone": "+70641738358"}
0005433037345	407D13	8313 360953	MIKHAIL VLASOV	{"phone": "+70825196033"}
0005433037346	031F1C	4874 109354	EVGENIY MARTYNOV	{"email": "martynove_24071974@postgrespro.ru", "phone": "+70068600569"}
0005433037347	A38B07	0646 171880	DIANA POPOVA	{"email": "popova-diana.29011970@postgrespro.ru", "phone": "+70399985329"}
0005433037348	C53932	9790 058579	ALEKSEY BONDARENKO	{"phone": "+70577511910"}
0005433037349	C53932	9668 946919	VYACHESLAV IVANOV	{"email": "vyacheslav.ivanov_021971@postgrespro.ru", "phone": "+70529599130"}
0005433037350	DEF01E	1808 876221	OLGA MIRONOVA	{"phone": "+70754239970"}
0005433037351	21E30A	3014 881151	SVETLANA ABRAMOVA	{"phone": "+70936747464"}
0005433037352	236C38	2413 678398	KIRILL ANDREEV	{"phone": "+70232861185"}
0005433037353	236C38	2834 949507	ANNA KOROLEVA	{"phone": "+70095298726"}
0005433037354	3060C4	7493 564235	YURIY KARPOV	{"email": "yuriykarpov-041959@postgrespro.ru", "phone": "+70264203526"}
0005433037355	3060C4	3004 855900	EKATERINA KOVALEVA	{"email": "ekovaleva-05091965@postgrespro.ru", "phone": "+70636054681"}
0005433037356	97E090	9177 083259	KSENIYA ANTONOVA	{"email": "antonovak.03091973@postgrespro.ru", "phone": "+70334444434"}
0005433037357	F7830A	3227 234976	LYUBOV DMITRIEVA	{"email": "lyubov.dmitrieva.1965@postgrespro.ru", "phone": "+70096460302"}
0005433037358	F7830A	8490 793556	VALENTINA ANDREEVA	{"email": "valentina.andreeva_021978@postgrespro.ru", "phone": "+70786596458"}
0005433037359	14E6B8	3678 824766	ZOYA FROLOVA	{"phone": "+70501987170"}
0005433037360	B5257A	7019 837916	ELENA ZHUKOVA	{"email": "zhukova-elena-071978@postgrespro.ru", "phone": "+70491433442"}
0005433037361	F5CC4B	2496 211929	GLEB MAKAROV	{"phone": "+70176585284"}
0005433037362	939BDA	2311 047220	GALINA MOROZOVA	{"email": "g-morozova-1972@postgrespro.ru", "phone": "+70909064444"}
0005433037363	939BDA	2557 603496	DANIIL ALEKSANDROV	{"phone": "+70949792593"}
0005433037364	939BDA	7220 544674	KSENIYA AFANASEVA	{"phone": "+70537202254"}
0005433037365	EA6B58	4282 947490	SVETLANA ANTONOVA	{"phone": "+70877558928"}
0005433037366	EA6B58	4253 890505	SERGEY NAZAROV	{"phone": "+70637515926"}
0005433037367	E63025	2599 770316	SERGEY ALEKSEEV	{"phone": "+70043943748"}
0005433037368	E63025	6687 311583	ELENA PETROVA	{"phone": "+70887508411"}
0005433037369	F5A5AA	7753 910152	IRINA KONDRATEVA	{"email": "kondrateva-i.121969@postgrespro.ru", "phone": "+70483072259"}
0005433037370	F5A5AA	8960 140179	MAKSIM SMIRNOV	{"phone": "+70759719447"}
0005433037371	7035A0	5522 339223	YURIY FILIPPOV	{"email": "yuriy_filippov021961@postgrespro.ru", "phone": "+70305942469"}
0005433037372	7035A0	2329 531296	MARINA ABRAMOVA	{"phone": "+70714230721"}
0005433037373	1AF01E	4476 204138	VLADIMIR YAKOVLEV	{"phone": "+70606080251"}
0005433037374	B65D86	2622 402080	ALEKSANDR POPOV	{"email": "aleksandr-popov.011966@postgrespro.ru", "phone": "+70665205882"}
0005433037375	669FA6	0121 657685	SERGEY KISELEV	{"phone": "+70235718518"}
0005433037376	97828B	2230 726534	SVETLANA MAKAROVA	{"phone": "+70883859440"}
0005433037377	DF9682	4972 765168	ANATOLIY EGOROV	{"email": "egorov.a.121980@postgrespro.ru", "phone": "+70141401860"}
0005433037378	DF9682	0787 750071	VALERIY DAVYDOV	{"email": "davydov.v051986@postgrespro.ru", "phone": "+70867528120"}
0005433037379	167429	5611 860796	EVGENIY EGOROV	{"phone": "+70640501912"}
0005433037380	4A5E3A	8814 687138	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr1974@postgrespro.ru", "phone": "+70931996496"}
0005433037381	DB021A	2457 882620	MARINA SOROKINA	{"email": "sorokina-m_02081972@postgrespro.ru", "phone": "+70370811538"}
0005433037382	94A4C3	1702 785398	YURIY IVANOV	{"phone": "+70904118862"}
0005433037383	94A4C3	1707 219788	EDUARD DAVYDOV	{"email": "eduard-davydov.051967@postgrespro.ru", "phone": "+70940350248"}
0005433037384	A02C16	6286 169805	VALENTINA SERGEEVA	{"phone": "+70394095160"}
0005433037385	828519	8988 050133	NATALYA PAVLOVA	{"email": "natalya.pavlova101975@postgrespro.ru", "phone": "+70405143656"}
0005433037386	828519	2735 306149	IVAN AFANASEV	{"email": "iafanasev_011971@postgrespro.ru", "phone": "+70294973393"}
0005433037387	8D576D	4417 702335	SERGEY KUZNECOV	{"email": "kuznecov-s.101983@postgrespro.ru", "phone": "+70802620359"}
0005433037388	8D576D	0482 648980	EVGENIY BONDARENKO	{"email": "bondarenko-e1967@postgrespro.ru", "phone": "+70948076853"}
0005433037389	147879	1623 943853	ALENA KUDRYASHOVA	{"phone": "+70964653946"}
0005433037390	C8F618	8298 287963	NADEZHDA IVANOVA	{"email": "nadezhda_ivanova-10011969@postgrespro.ru", "phone": "+70644973328"}
0005433037391	EE2117	4054 194283	OLGA SCHERBAKOVA	{"email": "olgascherbakova_1970@postgrespro.ru", "phone": "+70061361787"}
0005433037392	72B112	1732 118285	VALENTIN AFANASEV	{"email": "valentinafanasev.1981@postgrespro.ru", "phone": "+70881582342"}
0005433037393	A36685	5687 879478	ANASTASIYA YAKOVLEVA	{"email": "yakovleva_a-051980@postgrespro.ru", "phone": "+70237523588"}
0005433037394	CD8274	1603 715151	IVAN PAVLOV	{"email": "pavlov-ivan.091972@postgrespro.ru", "phone": "+70944257827"}
0005433037395	A298B6	9644 548263	KLAVDIYA SOROKINA	{"email": "klavdiya-sorokina1959@postgrespro.ru", "phone": "+70126609565"}
0005433037396	A298B6	8497 645097	GRIGORIY IVANOV	{"phone": "+70539486863"}
0005433037397	A258F1	8226 674831	MAKSIM KISELEV	{"email": "kiselev-maksim_011983@postgrespro.ru", "phone": "+70375669678"}
0005433037398	3B8A40	5555 177197	VALENTINA ISAEVA	{"email": "valentina-isaeva-14111981@postgrespro.ru", "phone": "+70476891153"}
0005433037399	867BE9	2344 559337	MIKHAIL BORISOV	{"email": "borisov-mikhail_1971@postgrespro.ru", "phone": "+70738258708"}
0005433037400	3AF477	3987 123594	OLGA KUZMINA	{"email": "kuzminaolga.121971@postgrespro.ru", "phone": "+70563296801"}
0005433037401	3AF477	3690 462596	PAVEL DMITRIEV	{"phone": "+70162084050"}
0005433037402	AAADF4	2966 543854	LADA IVANOVA	{"email": "ivanova_lada-121975@postgrespro.ru", "phone": "+70145773781"}
0005433037403	FA84F2	5354 485707	SERGEY MOROZOV	{"phone": "+70828684898"}
0005433037404	2FF813	0292 189841	OLGA KONDRATEVA	{"phone": "+70222841610"}
0005433037405	05ACE0	3119 294960	VYACHESLAV GORBUNOV	{"email": "gorbunov.v_1971@postgrespro.ru", "phone": "+70686812888"}
0005433037406	C5C564	1718 396077	OKSANA AFANASEVA	{"email": "afanaseva.o-30121986@postgrespro.ru", "phone": "+70373533289"}
0005433037407	BC1D93	8413 147435	LYUDMILA DENISOVA	{"phone": "+70028544358"}
0005433037408	BC1D93	8813 588547	OKSANA POPOVA	{"phone": "+70518377233"}
0005433037409	9AA5F6	7177 818210	ADELINA EGOROVA	{"phone": "+70787776511"}
0005433037410	A3F0C7	3263 190777	EGOR MATVEEV	{"email": "egor.matveev.1966@postgrespro.ru", "phone": "+70429637174"}
0005433037411	122C27	8005 989394	DENIS YAKOVLEV	{"email": "yakovlev_denis_041981@postgrespro.ru", "phone": "+70626864419"}
0005433037412	122C27	0128 256867	FEDOR MOISEEV	{"email": "moiseev.fedor-1973@postgrespro.ru", "phone": "+70935056064"}
0005433037413	78556C	5424 462940	TATYANA PAVLOVA	{"phone": "+70666259266"}
0005433037414	276595	3734 736317	SVETLANA ILINA	{"email": "ilinasvetlana_04051960@postgrespro.ru", "phone": "+70982219321"}
0005433037415	276595	5804 860547	VLADIMIR IVANOV	{"email": "vivanov-18011966@postgrespro.ru", "phone": "+70620939623"}
0005433037416	B3F9E8	1572 901880	VALENTINA KUZNECOVA	{"phone": "+70527080615"}
0005433037417	BD89A2	2997 638887	ALEKSANDRA ANDREEVA	{"phone": "+70037661746"}
0005433037418	BD89A2	6447 429163	SERGEY BONDARENKO	{"email": "s-bondarenko-071962@postgrespro.ru", "phone": "+70712922616"}
0005433037419	D394BC	4671 748800	MARIYA LUKYANOVA	{"email": "lukyanova-m_1966@postgrespro.ru", "phone": "+70630405830"}
0005433037420	D394BC	9504 450472	GENNADIY BORISOV	{"phone": "+70809298154"}
0005433037421	D394BC	0342 798959	SVETLANA KOZLOVA	{"email": "kozlova.s.04071975@postgrespro.ru", "phone": "+70601374637"}
0005433037422	D394BC	2005 075709	KIRILL DMITRIEV	{"phone": "+70397329627"}
0005433037423	E98573	9660 879933	ANASTASIYA KOROLEVA	{"email": "anastasiya-koroleva.091966@postgrespro.ru", "phone": "+70742064020"}
0005433037424	E98573	7477 295208	ELENA KOROLEVA	{"phone": "+70563313023"}
0005433037425	B229A4	3663 230325	SVETLANA FILATOVA	{"email": "sfilatova041969@postgrespro.ru", "phone": "+70190368390"}
0005433037426	B229A4	0461 240723	LIDIYA SERGEEVA	{"email": "sergeeva.lidiya.111960@postgrespro.ru", "phone": "+70813763030"}
0005433037427	195B6F	7150 837194	LYUDMILA NIKITINA	{"email": "l_nikitina_1972@postgrespro.ru", "phone": "+70477627604"}
0005433037428	411784	3265 718177	YULIYA FADEEVA	{"phone": "+70404196590"}
0005433037429	A11BD8	0944 623178	VITALIY ZAYCEV	{"email": "zaycevvitaliy-071969@postgrespro.ru", "phone": "+70945719508"}
0005433037430	AF7CBD	7880 992313	DAMIR ANTONOV	{"phone": "+70900746739"}
0005433037431	AF7CBD	6762 091905	SERAFIMA ILINA	{"phone": "+70560011186"}
0005433037432	CFF3DB	6148 710140	ELENA BOGDANOVA	{"phone": "+70894106057"}
0005433037433	CFF3DB	2437 335140	ALEKSEY GAVRILOV	{"email": "gavrilov.aleksey21121982@postgrespro.ru", "phone": "+70855177406"}
0005433037434	F4C91C	2264 419191	SVETLANA KUZNECOVA	{"phone": "+70372713525"}
0005433037435	F4C91C	3682 101268	RASIM FEDOTOV	{"email": "r-fedotov-011968@postgrespro.ru", "phone": "+70323275332"}
0005433037436	F929FB	1243 111354	STEPAN DENISOV	{"email": "denisovstepan05121971@postgrespro.ru", "phone": "+70928113337"}
0005433037437	2431A4	0235 610747	LYUDMILA ROMANOVA	{"phone": "+70248773454"}
0005433037438	60A564	9666 822887	VIKTOR MOISEEV	{"email": "viktor-moiseev.1969@postgrespro.ru", "phone": "+70019567397"}
0005433037439	93BAF7	8304 543592	DMITRIY PAVLOV	{"email": "pavlovd_091971@postgrespro.ru", "phone": "+70935151536"}
0005433037440	93BAF7	3578 425201	SVETLANA BELOVA	{"email": "belovas1979@postgrespro.ru", "phone": "+70346561390"}
0005433037441	7638D2	0529 741347	NINA BELOVA	{"email": "belova.n_17071976@postgrespro.ru", "phone": "+70913933520"}
0005433037442	7638D2	9625 635931	ALEKSANDR KRASNOV	{"phone": "+70273101017"}
0005433037443	1123B0	0452 398547	TATYANA NAUMOVA	{"phone": "+70297660504"}
0005433037444	E108D1	7034 267768	DMITRIY MOISEEV	{"email": "dmitriymoiseev.11071975@postgrespro.ru", "phone": "+70551826793"}
0005433037445	0EA383	7333 055831	SERGEY ANDREEV	{"phone": "+70911591384"}
0005433037446	0EA383	3201 212430	ALEKSEY KUZMIN	{"email": "akuzmin.1977@postgrespro.ru", "phone": "+70163458898"}
0005433037447	85027B	5481 030478	SERGEY SOROKIN	{"email": "sorokinsergey-13081977@postgrespro.ru", "phone": "+70459517048"}
0005433037448	D57603	5902 102241	TAMARA RODIONOVA	{"email": "rodionova-t-061986@postgrespro.ru", "phone": "+70784361986"}
0005433037449	F48D64	4613 747254	ALEKSANDR SOROKIN	{"phone": "+70193591100"}
0005433037450	F48D64	5702 425361	OKSANA RYABOVA	{"phone": "+70326617393"}
0005433037451	F48D64	5614 177349	DARINA PETROVA	{"phone": "+70915855942"}
0005433037452	E41BAA	9775 723185	NATALYA MIKHAYLOVA	{"phone": "+70488484122"}
0005433037453	518AC1	6936 690046	VALENTINA AFANASEVA	{"email": "valentina.afanaseva-1965@postgrespro.ru", "phone": "+70289377942"}
0005433037454	7C2A51	4451 355754	VIKTORIYA MARTYNOVA	{"email": "v-martynova.111966@postgrespro.ru", "phone": "+70142770468"}
0005433037455	4BA9F8	6772 874928	DAMIR IVANOV	{"phone": "+70282902905"}
0005433037456	4BA9F8	5585 277960	VASILIY ANTONOV	{"phone": "+70004550083"}
0005433037457	C7ED6E	5416 532864	ALENA KRASNOVA	{"phone": "+70264645998"}
0005433037458	17D85D	1502 247751	ELENA BOGDANOVA	{"email": "bogdanova.e-1965@postgrespro.ru", "phone": "+70223273357"}
0005433037459	C77350	8270 206404	NATALYA ANDREEVA	{"phone": "+70880804926"}
0005433037460	C77350	4986 107895	VLADIMIR KUDRYASHOV	{"phone": "+70753899225"}
0005433037461	77B4C7	2424 831950	SERGEY ROMANOV	{"phone": "+70712390117"}
0005433037462	16BA1E	0797 476160	DMITRIY IVANOV	{"email": "ivanov_dmitriy.1979@postgrespro.ru", "phone": "+70644905380"}
0005433037463	16BA1E	2096 791990	NIKOLAY PETROV	{"email": "nikolay-petrov_041968@postgrespro.ru", "phone": "+70193406926"}
0005433037464	2AFE3F	5866 644794	ANATOLIY ORLOV	{"email": "orlovanatoliy1973@postgrespro.ru", "phone": "+70560460025"}
0005433037465	2AFE3F	6317 827179	VLADIMIR GORBUNOV	{"email": "gorbunov_vladimir_1976@postgrespro.ru", "phone": "+70619425615"}
0005433037466	2AFE3F	1508 825084	KRISTINA ZOTOVA	{"phone": "+70237044177"}
0005433037467	127B8C	1812 015182	TATYANA MELNIKOVA	{"email": "melnikova-tatyana.041961@postgrespro.ru", "phone": "+70277424724"}
0005433037468	756026	8013 865094	ANASTASIYA AKIMOVA	{"phone": "+70729738454"}
0005433037469	0750CC	7781 765013	IRINA SOKOLOVA	{"phone": "+70744077773"}
0005433037470	472201	9334 882992	LYUBOV PAVLOVA	{"email": "pavloval.1963@postgrespro.ru", "phone": "+70482526661"}
0005433037471	E2E6F9	5907 428432	VALENTIN NOVIKOV	{"phone": "+70958410811"}
0005433037472	515183	3410 127537	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.22111973@postgrespro.ru", "phone": "+70802162300"}
0005433037473	515183	9344 107804	LIDIYA MATVEEVA	{"phone": "+70323706650"}
0005433037474	D79679	6690 743172	VERONIKA MIRONOVA	{"email": "v_mironova.091962@postgrespro.ru", "phone": "+70822663606"}
0005433037475	D79679	0727 131300	OLGA MEDVEDEVA	{"phone": "+70780121011"}
0005433037476	BA6BB4	6215 503876	IGOR SERGEEV	{"email": "sergeev-igor_1968@postgrespro.ru", "phone": "+70188047944"}
0005433037477	F38952	6921 783431	VERA ZAKHAROVA	{"email": "zakharova.vera101965@postgrespro.ru", "phone": "+70495919745"}
0005433037478	D631D6	4181 243704	VIKTOR POPOV	{"phone": "+70361367105"}
0005433037479	D631D6	6059 770949	OLGA VOLKOVA	{"phone": "+70424533047"}
0005433037480	22D332	9096 226965	POLINA RYABOVA	{"email": "ryabova.p24121963@postgrespro.ru", "phone": "+70728517911"}
0005433037481	22D332	5284 476638	INNA BORISOVA	{"phone": "+70701141271"}
0005433037482	22D332	6856 632551	VALENTINA BELOVA	{"email": "valentina_belova.1980@postgrespro.ru", "phone": "+70570882732"}
0005433037483	A25220	5231 765208	ELENA CHERNOVA	{"email": "chernovae-14081975@postgrespro.ru", "phone": "+70457534030"}
0005433037484	4EB2B4	5618 249165	NATALYA OSIPOVA	{"email": "osipova_natalya.1981@postgrespro.ru", "phone": "+70563775488"}
0005433037485	79B2E8	8595 140127	SERGEY ORLOV	{"phone": "+70303454231"}
0005433037486	352613	3793 530915	ALEKSANDRA ZAYCEVA	{"phone": "+70052942098"}
0005433037487	352613	8756 102551	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva-1990@postgrespro.ru", "phone": "+70893192462"}
0005433037488	41287C	5906 412487	PETR SOROKIN	{"email": "p.sorokin1975@postgrespro.ru", "phone": "+70084782355"}
0005433037489	41287C	3938 434526	RAMZIYA OVCHINNIKOVA	{"phone": "+70558993276"}
0005433037490	B39825	5995 855410	EVGENIY NAZAROV	{"email": "evgeniynazarov.041958@postgrespro.ru", "phone": "+70350482281"}
0005433037491	B39825	6733 669969	YURIY BONDARENKO	{"phone": "+70775504584"}
0005433037492	368775	4024 602454	ROZA YUDINA	{"email": "r-yudina.1968@postgrespro.ru", "phone": "+70555014035"}
0005433037493	A5DC7F	9654 446641	OLGA MIRONOVA	{"phone": "+70336341587"}
0005433037494	D0C785	2769 772449	NINA KARPOVA	{"phone": "+70743602258"}
0005433037495	AEB673	6695 195573	ALEKSEY KUZNECOV	{"phone": "+70019833500"}
0005433037496	AEB673	7025 463563	ALEKSANDRA MALYSHEVA	{"phone": "+70496036314"}
0005433037497	66B00F	9982 027842	VLADIMIR SMIRNOV	{"email": "v_smirnov-1967@postgrespro.ru", "phone": "+70702144108"}
0005433037498	4A3165	9009 462036	EVGENIY OSIPOV	{"phone": "+70856101436"}
0005433037499	4A3165	0808 530817	LYUBOV NIKITINA	{"phone": "+70607836985"}
0005433037500	9E9502	2167 075511	VLADIMIR KONOVALOV	{"phone": "+70924780595"}
0005433037501	597018	5701 883396	IVAN IVANOV	{"phone": "+70982886132"}
0005433037502	EFBBE7	3756 026404	VERA SOROKINA	{"email": "sorokina_v11041971@postgrespro.ru", "phone": "+70949049542"}
0005433037503	EFBBE7	1793 779475	POLINA ANDREEVA	{"email": "andreeva_p-27021970@postgrespro.ru", "phone": "+70199876893"}
0005433037504	2D6708	8002 860853	ALEKSEY PETROV	{"email": "petrov_a.111976@postgrespro.ru", "phone": "+70486656859"}
0005433037505	84C627	9634 203508	VASILISA IVANOVA	{"phone": "+70022258212"}
0005433037506	84C627	2651 540260	ANASTASIYA DENISOVA	{"email": "anastasiya.denisova-011963@postgrespro.ru", "phone": "+70643057044"}
0005433037507	06035B	3363 360262	LIDIYA MATVEEVA	{"phone": "+70132874210"}
0005433037508	4E60E9	5452 265023	SERGEY VLASOV	{"email": "s-vlasov-1973@postgrespro.ru", "phone": "+70729353393"}
0005433037509	769821	8146 289787	ANZHELA ANDREEVA	{"phone": "+70185179276"}
0005433037510	D34156	1500 000062	NINA KOZLOVA	{"email": "kozlovan-28101975@postgrespro.ru", "phone": "+70360032434"}
0005433037511	D34156	6143 060049	VIKTOR KULIKOV	{"phone": "+70979833444"}
0005433037512	319A9C	9553 485516	ILYA ZAYCEV	{"email": "izaycev_26041977@postgrespro.ru", "phone": "+70363214345"}
0005433037513	319A9C	6796 073903	VIKTOR KUDRYASHOV	{"email": "kudryashovviktor-1968@postgrespro.ru", "phone": "+70558971990"}
0005433037514	95F50E	8166 295182	ELENA ABRAMOVA	{"phone": "+70518378160"}
0005433037515	101DB2	2527 640759	ANNA SMIRNOVA	{"phone": "+70640970577"}
0005433037516	9512A0	9354 889874	ANDREY KULIKOV	{"phone": "+70779722697"}
0005433037517	9512A0	9616 506489	VALERIYA FILATOVA	{"phone": "+70686293085"}
0005433037518	83F2F1	7971 017785	AIDA BORISOVA	{"phone": "+70766468087"}
0005433037519	0671C2	7095 864124	ROMAN ANDREEV	{"phone": "+70929621589"}
0005433037520	0671C2	7180 837094	LYUDMILA NESTEROVA	{"email": "nesterova-lyudmila-1970@postgrespro.ru", "phone": "+70664667750"}
0005433037521	FB9A8B	1957 931691	IVAN ABRAMOV	{"phone": "+70961622621"}
0005433037522	220DCB	9911 093241	VYACHESLAV GUSEV	{"email": "gusevvyacheslav_041965@postgrespro.ru", "phone": "+70257760000"}
0005433037523	E73036	2095 652980	VLADISLAV NAUMOV	{"phone": "+70723344893"}
0005433037524	E73036	4080 220687	LILIYA GAVRILOVA	{"phone": "+70628903801"}
0005433037525	572890	2004 716021	NIKOLAY SERGEEV	{"email": "sergeev_n.1971@postgrespro.ru", "phone": "+70223882016"}
0005433037526	572890	7278 359746	MIKHAIL GORBUNOV	{"email": "mgorbunov1970@postgrespro.ru", "phone": "+70177153025"}
0005433037527	03DA35	6180 309650	EVGENIYA ILINA	{"email": "evgeniyailina_1978@postgrespro.ru", "phone": "+70846669813"}
0005433037528	78C23A	2337 435803	TAMARA MARTYNOVA	{"email": "martynova-t_24051977@postgrespro.ru", "phone": "+70451255507"}
0005433037529	7CA8E2	4754 647054	SERGEY PAVLOV	{"phone": "+70026645762"}
0005433037530	D24FD6	8193 925576	YURIY KAZAKOV	{"phone": "+70830620693"}
0005433037531	9BAF0C	7427 777362	OLEG KUZNECOV	{"phone": "+70451125019"}
0005433037532	9BAF0C	0295 257182	VLADISLAV TARASOV	{"email": "tarasov-v1962@postgrespro.ru", "phone": "+70286439484"}
0005433037533	E0BAE8	7138 571074	LIDIYA VOROBEVA	{"phone": "+70641253266"}
0005433037534	D98DE3	8423 092353	GALINA NIKITINA	{"phone": "+70702449894"}
0005433037535	78275E	9000 972494	VIKTOR FILIPPOV	{"email": "v.filippov101974@postgrespro.ru", "phone": "+70969945381"}
0005433037536	78275E	2107 282605	LYUDMILA PETROVA	{"email": "petrova_lyudmila_1973@postgrespro.ru", "phone": "+70923913713"}
0005433037537	60F3ED	7261 419101	ALEKSEY DENISOV	{"email": "denisova.041982@postgrespro.ru", "phone": "+70512589219"}
0005433037538	32330F	7273 189552	EVGENIY VASILEV	{"phone": "+70195507390"}
0005433037539	0269CF	0212 718344	NIKOLAY CHERNOV	{"phone": "+70183758848"}
0005433037540	0269CF	2886 639385	EVGENIYA MIKHAYLOVA	{"email": "evgeniya-mikhaylova02091965@postgrespro.ru", "phone": "+70065970653"}
0005433037541	012680	8523 282604	EVGENIY ROMANOV	{"email": "romanov.evgeniy.1979@postgrespro.ru", "phone": "+70679887200"}
0005433037542	92CBB3	6008 346375	NADEZHDA TROFIMOVA	{"email": "nadezhda_trofimova.24121972@postgrespro.ru", "phone": "+70055116322"}
0005433037543	BEC5A4	0701 884002	NATALYA KOZLOVA	{"email": "n.kozlova.1975@postgrespro.ru", "phone": "+70226335262"}
0005433037544	BEC5A4	5293 138311	KRISTINA NESTEROVA	{"phone": "+70987425193"}
0005433037545	BEC5A4	4249 516805	ALEKSANDR KULIKOV	{"phone": "+70271703070"}
0005433037546	A734E6	5312 571721	EVGENIY PAVLOV	{"phone": "+70548736716"}
0005433037547	2ADE0E	5585 422282	VIKTOR VOROBEV	{"phone": "+70144883910"}
0005433037548	2ADE0E	2949 856953	ILYA CHERNOV	{"email": "ilya-chernov071974@postgrespro.ru", "phone": "+70317470797"}
0005433037549	7A0193	2116 926819	NIKOLAY KUZMIN	{"phone": "+70682526309"}
0005433037550	7A0193	6648 442208	MAKSIM MELNIKOV	{"email": "maksim_melnikov_20061970@postgrespro.ru", "phone": "+70759688999"}
0005433037551	9E5036	0690 026893	ZINAIDA SMIRNOVA	{"email": "smirnova_z-14031976@postgrespro.ru", "phone": "+70519496553"}
0005433037552	9DAEC5	9989 256473	YANA KALININA	{"phone": "+70598586777"}
0005433037553	F7CA67	1034 706865	ARINA ZAKHAROVA	{"phone": "+70666058850"}
0005433037554	DEDAD5	9605 234110	ALEKSANDR GAVRILOV	{"email": "a_gavrilov-1983@postgrespro.ru", "phone": "+70356792565"}
0005433037555	56E171	9689 829860	LYUBOV CHERNOVA	{"email": "l_chernova_031974@postgrespro.ru", "phone": "+70775136503"}
0005433037556	C03691	7827 332869	GALINA ZHUKOVA	{"email": "zhukova.g1975@postgrespro.ru", "phone": "+70012349507"}
0005433037557	C96EA7	9723 330264	SERGEY CHERNOV	{"phone": "+70136134406"}
0005433037558	C45C04	0110 328226	MARIYA IVANOVA	{"phone": "+70962788047"}
0005433037559	4D949B	3568 374466	SOFIYA STEPANOVA	{"phone": "+70104595329"}
0005433037560	DCEFC6	6305 424838	ALEKSANDR MARTYNOV	{"email": "aleksandr.martynov_16101969@postgrespro.ru", "phone": "+70450779058"}
0005433037561	8CC1AE	0763 548370	SVETLANA MOROZOVA	{"phone": "+70399692414"}
0005433037562	8CC1AE	4388 257706	OLGA ANTONOVA	{"email": "antonova.o-16091960@postgrespro.ru", "phone": "+70247982181"}
0005433037563	7FA5B3	9964 630387	EKATERINA MATVEEVA	{"email": "e-matveeva_23021971@postgrespro.ru", "phone": "+70899611685"}
0005433037564	82EE9D	1069 497421	ANDREY KRASNOV	{"phone": "+70058318277"}
0005433037565	0951CC	5662 505673	VENIAMIN KUZNECOV	{"phone": "+70023094486"}
0005433037566	757376	7361 015914	SERGEY TIMOFEEV	{"email": "timofeev.s_1974@postgrespro.ru", "phone": "+70108345506"}
0005433037567	3DA4A7	3225 068300	VALENTINA MATVEEVA	{"phone": "+70090919948"}
0005433037568	BEEF04	9941 973321	OLGA SOROKINA	{"phone": "+70227004116"}
0005433037569	755271	6758 553678	VALENTINA AKIMOVA	{"phone": "+70239512903"}
0005433037570	755271	0073 145530	SERGEY POPOV	{"email": "popovs1970@postgrespro.ru", "phone": "+70829364627"}
0005433037571	755271	4666 943941	VIKTOR MOROZOV	{"email": "morozov-viktor06071964@postgrespro.ru", "phone": "+70849088071"}
0005433037572	E9F726	6047 251988	NATALYA FILIPPOVA	{"phone": "+70248012587"}
0005433037573	B5AA96	6880 425817	VERA NESTEROVA	{"email": "v-nesterova-12061977@postgrespro.ru", "phone": "+70710555218"}
0005433037574	47E446	1108 527646	ELENA GAVRILOVA	{"phone": "+70062408029"}
0005433037575	D78621	3918 121650	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey_19051984@postgrespro.ru", "phone": "+70083469232"}
0005433037576	D78621	0388 901432	NADEZHDA SOKOLOVA	{"email": "nadezhda-sokolova_1978@postgrespro.ru", "phone": "+70469062209"}
0005433037577	E988B9	5716 166225	VYACHESLAV AFANASEV	{"email": "v.afanasev_031972@postgrespro.ru", "phone": "+70773913015"}
0005433037578	752E6C	8469 503121	VLADIMIR KUZNECOV	{"email": "v-kuznecov_1966@postgrespro.ru", "phone": "+70462479328"}
0005433037579	88070E	0217 500727	ARTEM FROLOV	{"email": "frolov_a09101962@postgrespro.ru", "phone": "+70920209848"}
0005433037580	88070E	5345 902531	NATALYA VLASOVA	{"email": "n-vlasova011979@postgrespro.ru", "phone": "+70052604266"}
0005433037581	9AEE0B	6874 323640	NIKOLAY BORISOV	{"email": "borisov_nikolay-24081974@postgrespro.ru", "phone": "+70305814451"}
0005433037582	486059	4811 555423	EVGENIY ROMANOV	{"phone": "+70790757637"}
0005433037583	6956CC	3861 359696	TATYANA FADEEVA	{"phone": "+70776490855"}
0005433037584	4FE313	6431 749374	LYUDMILA ZHURAVLEVA	{"phone": "+70013147274"}
0005433037585	EAD490	6281 945950	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikova-v04091967@postgrespro.ru", "phone": "+70182258928"}
0005433037586	EAD490	5116 688141	KSENIYA MALYSHEVA	{"email": "malysheva-kseniya-03101969@postgrespro.ru", "phone": "+70478859049"}
0005433037587	9EDF8E	5265 433226	MIKHAIL MAKSIMOV	{"phone": "+70806348383"}
0005433037588	5CEC09	8812 721530	ANNA BOGDANOVA	{"phone": "+70583149591"}
0005433037589	5CEC09	5889 599836	NINA MAKAROVA	{"email": "makarova-n-1972@postgrespro.ru", "phone": "+70832094078"}
0005433037590	5CEC09	2504 691699	TATYANA KOMAROVA	{"phone": "+70608015420"}
0005433037591	D94318	1927 509548	VYACHESLAV IVANOV	{"phone": "+70132538610"}
0005433037592	F143F0	8783 680248	NIKOLAY KUZNECOV	{"phone": "+70527088689"}
0005433037593	F143F0	9197 321428	TAMARA POLYAKOVA	{"email": "t.polyakova19121974@postgrespro.ru", "phone": "+70078883272"}
0005433037594	C2A42E	8704 942301	REGINA NAZAROVA	{"email": "nazarova.r061975@postgrespro.ru", "phone": "+70011192400"}
0005433037595	65E661	1286 321571	ANZHELA SOLOVEVA	{"email": "a-soloveva.1967@postgrespro.ru", "phone": "+70401089923"}
0005433037596	999B1F	5673 876178	ANNA ILINA	{"email": "ilina-a.05071969@postgrespro.ru", "phone": "+70005350693"}
0005433037597	4C0D90	9767 699267	YULIYA VASILEVA	{"phone": "+70577781627"}
0005433037598	E234DB	3776 598982	ANDREY IVANOV	{"email": "ivanov-andrey-08041968@postgrespro.ru", "phone": "+70127997056"}
0005433037599	AF457D	4291 874611	TAMARA SOKOLOVA	{"email": "sokolova.tamara_091978@postgrespro.ru", "phone": "+70543684368"}
0005433037600	A79FE2	0609 899330	PAVEL KONOVALOV	{"phone": "+70524133039"}
0005433037601	959B72	8398 465577	YANA MELNIKOVA	{"email": "y.melnikova.04091975@postgrespro.ru", "phone": "+70862658305"}
0005433037602	3E6ADA	3887 407265	TAMARA AKIMOVA	{"phone": "+70148269266"}
0005433037603	3C8F64	0807 091110	NATALYA ZAKHAROVA	{"email": "zakharova-natalya_10091974@postgrespro.ru", "phone": "+70974313384"}
0005433037604	B4BFA8	1218 974458	VERA MIKHAYLOVA	{"phone": "+70504197449"}
0005433037605	6A7862	9959 117771	DMITRIY ZAYCEV	{"phone": "+70864112536"}
0005433037606	319254	1391 981210	ALEKSANDR FOMIN	{"email": "afomin-07071967@postgrespro.ru", "phone": "+70185693114"}
0005433037607	C8BFA6	4835 511258	ANNA KOROLEVA	{"phone": "+70997352052"}
0005433037608	559BAB	7754 771514	TATYANA PAVLOVA	{"email": "tatyana-pavlova-07091978@postgrespro.ru", "phone": "+70586381867"}
0005433037609	559BAB	0532 103817	ALEKSANDRA BELOVA	{"email": "belova_aleksandra-1973@postgrespro.ru", "phone": "+70745638825"}
0005433037610	729AFD	5079 232359	ALEKSANDR MAKAROV	{"email": "makarovaleksandr_1963@postgrespro.ru", "phone": "+70455347456"}
0005433037611	E3AF36	3616 713289	GULNARA SEMENOVA	{"email": "semenova-gulnara_041973@postgrespro.ru", "phone": "+70667821488"}
0005433037612	E3AF36	3673 213321	YULIYA KUDRYASHOVA	{"email": "kudryashova.y.1964@postgrespro.ru", "phone": "+70909009891"}
0005433037613	29C3EA	9760 916822	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr.061971@postgrespro.ru", "phone": "+70418292318"}
0005433037614	404B27	8768 602005	EVGENIYA STEPANOVA	{"email": "stepanovaevgeniya-091971@postgrespro.ru", "phone": "+70365549417"}
0005433037615	D21FF1	3602 609343	ANTON ZAYCEV	{"email": "antonzaycev.1971@postgrespro.ru", "phone": "+70635781767"}
0005433037616	A3AB45	8328 247104	ANDREY GUSEV	{"email": "agusev-041976@postgrespro.ru", "phone": "+70379575704"}
0005433037617	081CB8	9544 459956	ALEKSANDR DAVYDOV	{"phone": "+70096131587"}
0005433037618	081CB8	2506 445960	VIKTOR KOROLEV	{"email": "korolev.viktor_1962@postgrespro.ru", "phone": "+70736171543"}
0005433037619	6FCEEC	6585 166894	DENIS NAZAROV	{"phone": "+70596629116"}
0005433037620	7CA791	8493 267199	TATYANA FROLOVA	{"phone": "+70474388404"}
0005433037621	1AC976	1503 331926	VALENTINA KOZLOVA	{"email": "kozlova_valentina_31071974@postgrespro.ru", "phone": "+70269216098"}
0005433037622	1AC976	9720 707673	NIKITA IVANOV	{"email": "ivanov_nikita.1976@postgrespro.ru", "phone": "+70984623594"}
0005433037623	1B6B35	5772 766519	NIKOLAY BORISOV	{"email": "borisovnikolay1966@postgrespro.ru", "phone": "+70619352173"}
0005433037624	45FF27	3552 802259	YURIY PETROV	{"phone": "+70834600248"}
0005433037625	45FF27	4565 118757	VIKTOR SERGEEV	{"email": "sergeev_v_1970@postgrespro.ru", "phone": "+70297184042"}
0005433037626	8DA95E	7208 859087	NATALYA KALININA	{"email": "n-kalinina_051968@postgrespro.ru", "phone": "+70015682377"}
0005433037627	C283BC	4876 720075	ANATOLIY SEMENOV	{"email": "semenov_anatoliy.041973@postgrespro.ru", "phone": "+70266910978"}
0005433037628	FFE57B	1526 188560	NATALIYA ZAYCEVA	{"email": "zayceva-nataliya.21081977@postgrespro.ru", "phone": "+70461697051"}
0005433037629	FF9F09	8979 282183	SERGEY MATVEEV	{"email": "matveevsergey.101966@postgrespro.ru", "phone": "+70472935799"}
0005433037630	61EE0C	3415 229871	VALENTINA TIMOFEEVA	{"email": "timofeeva_valentina.1977@postgrespro.ru", "phone": "+70208766575"}
0005433037631	61EE0C	8154 432213	ANDREY ZHURAVLEV	{"email": "andreyzhuravlev-1971@postgrespro.ru", "phone": "+70407168049"}
0005433037632	E8C22D	3213 040718	VLADISLAV MIRONOV	{"phone": "+70963419747"}
0005433037633	BA2FC3	3166 934749	VADIM DENISOV	{"phone": "+70403487120"}
0005433037634	1848DC	4010 401009	DENIS SEMENOV	{"email": "denissemenov-21091973@postgrespro.ru", "phone": "+70082306109"}
0005433037635	0E8EAC	3754 308568	SVETLANA FADEEVA	{"phone": "+70607642540"}
0005433037636	0E8EAC	8395 753856	VLADISLAV ROMANOV	{"email": "vladislav_romanov-051966@postgrespro.ru", "phone": "+70988123128"}
0005433037637	0E8EAC	9796 417985	EVGENIY DAVYDOV	{"phone": "+70656235774"}
0005433037638	E0E3AB	6405 538895	ALEKSANDR BORISOV	{"phone": "+70725208917"}
0005433037639	E0E3AB	8232 646400	LYUDMILA FROLOVA	{"email": "lyudmila-frolova_1971@postgrespro.ru", "phone": "+70049685180"}
0005433037640	E0E3AB	5365 556898	DMITRIY ZAYCEV	{"phone": "+70994374373"}
0005433037641	8BE21D	2570 692894	SERGEY ZAKHAROV	{"email": "sergey_zakharov071977@postgrespro.ru", "phone": "+70262258424"}
0005433037642	8BE21D	4585 740229	VASILIY ZAKHAROV	{"phone": "+70209515381"}
0005433037643	9412D9	4411 525079	NATALYA NESTEROVA	{"email": "n.nesterova-1968@postgrespro.ru", "phone": "+70296142772"}
0005433037644	5D60C3	5416 460730	NINA ABRAMOVA	{"email": "nabramova031978@postgrespro.ru", "phone": "+70502933577"}
0005433037645	96F7E0	8507 198207	DANIIL ILIN	{"phone": "+70325446817"}
0005433037646	94CC89	1006 040239	ILYA ANDREEV	{"email": "i.andreev1977@postgrespro.ru", "phone": "+70794455640"}
0005433037647	8E9D4F	8434 055647	MARIYA NIKOLAEVA	{"phone": "+70345226342"}
0005433037648	CA8A36	6388 396486	EVELINA ZAYCEVA	{"phone": "+70841708196"}
0005433037649	15B8B0	7818 914370	YURIY GRIGOREV	{"email": "grigorev-yuriy1973@postgrespro.ru", "phone": "+70719042354"}
0005433037650	15B8B0	9956 782050	VLADIMIR FEDOROV	{"email": "fedorov.vladimir_1973@postgrespro.ru", "phone": "+70619683377"}
0005433037651	85D9C4	9579 234581	MARINA RYABOVA	{"email": "ryabova-m1970@postgrespro.ru", "phone": "+70450520997"}
0005433037652	CD67B5	8480 198931	IRINA ROMANOVA	{"email": "romanovai.111961@postgrespro.ru", "phone": "+70983031486"}
0005433037653	8DF2F4	5581 610697	ARTEM ANDREEV	{"email": "artem-andreev_1971@postgrespro.ru", "phone": "+70632654630"}
0005433037654	5457DF	9939 514436	EGOR KUZMIN	{"email": "kuzmin_e1963@postgrespro.ru", "phone": "+70661077759"}
0005433037655	A2D521	3853 642089	SVETLANA POLYAKOVA	{"phone": "+70083545785"}
0005433037656	A2D521	0376 333379	VLADIMIR POPOV	{"phone": "+70647631096"}
0005433037657	4B55F6	5292 426967	MIKHAIL STEPANOV	{"email": "stepanovm_1966@postgrespro.ru", "phone": "+70835419586"}
0005433037658	4B55F6	0042 626526	VIKTOR PAVLOV	{"email": "pavlov.v111960@postgrespro.ru", "phone": "+70000189355"}
0005433037659	F2330E	1993 563633	ANDREY SEMENOV	{"email": "a-semenov1971@postgrespro.ru", "phone": "+70091115273"}
0005433037660	A53BBE	9897 631184	VLADIMIR MIRONOV	{"phone": "+70827789245"}
0005433037661	A53BBE	1375 306357	SERGEY SAVELEV	{"phone": "+70757912020"}
0005433037662	CDA428	7185 058718	MARGARITA KUZNECOVA	{"email": "m_kuznecova-031975@postgrespro.ru", "phone": "+70000921851"}
0005433037663	CBE558	6819 567105	YURIY KUZNECOV	{"phone": "+70776769544"}
0005433037664	CBE558	0734 491162	OLGA KOROLEVA	{"email": "o_koroleva1972@postgrespro.ru", "phone": "+70439258188"}
0005433037665	CBE558	1830 003723	VLADISLAV OSIPOV	{"email": "v_osipov.17011977@postgrespro.ru", "phone": "+70321031112"}
0005433037666	868455	0400 170511	ANNA SIDOROVA	{"email": "sidorova.a.041984@postgrespro.ru", "phone": "+70305914460"}
0005433037667	2C7283	0507 261615	TIGRAN KUZNECOV	{"phone": "+70073324546"}
0005433037668	2C7283	8190 073233	GALINA BORISOVA	{"phone": "+70697723793"}
0005433037669	8A1B1D	8874 158355	ANATOLIY ALEKSEEV	{"email": "alekseeva_1961@postgrespro.ru", "phone": "+70569652936"}
0005433037670	8A1B1D	0575 792024	TATYANA ILINA	{"email": "tatyanailina-23111973@postgrespro.ru", "phone": "+70081466559"}
0005433037671	D5FCF0	7237 192992	OLGA MELNIKOVA	{"email": "olga.melnikova011981@postgrespro.ru", "phone": "+70357254267"}
0005433037672	D5FCF0	3040 003949	NADEZHDA TARASOVA	{"email": "n.tarasova-021970@postgrespro.ru", "phone": "+70164871454"}
0005433037673	F21E94	8263 567965	GULIYA FEDOROVA	{"phone": "+70777287049"}
0005433037674	A97495	8645 170669	GULSINA MAKSIMOVA	{"phone": "+70159833333"}
0005433037675	CE5B03	2557 654599	NIKOLAY FILIPPOV	{"phone": "+70215957916"}
0005433037676	A1E7E4	8279 230721	VIKTOR RODIONOV	{"email": "rodionovv-12081978@postgrespro.ru", "phone": "+70402961715"}
0005433037677	A1DAE5	3926 162493	VASILIY SCHERBAKOV	{"phone": "+70266443041"}
0005433037678	A1DAE5	1284 181687	ALEKSANDR TIMOFEEV	{"phone": "+70414520511"}
0005433037679	B918F6	3879 547082	KIRILL BORISOV	{"phone": "+70680932276"}
0005433037680	B918F6	8215 733286	OLEG BORISOV	{"email": "oleg.borisov071970@postgrespro.ru", "phone": "+70407331866"}
0005433037681	ECDD00	6473 649249	OLGA SOROKINA	{"phone": "+70831358437"}
0005433037682	0D2987	2738 621516	SVETLANA VASILEVA	{"phone": "+70859681599"}
0005433037683	0D2987	4171 946647	VALENTINA ANDREEVA	{"email": "andreeva_v.071962@postgrespro.ru", "phone": "+70509556608"}
0005433037684	B70550	5401 475563	VLADIMIR KISELEV	{"phone": "+70110953378"}
0005433037685	C7C5ED	9844 103383	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_041967@postgrespro.ru", "phone": "+70066240936"}
0005433037686	0C3C35	9356 952375	DIANA KONOVALOVA	{"email": "konovalova_d1984@postgrespro.ru", "phone": "+70102270546"}
0005433037687	0C3C35	5619 424616	IVAN PAVLOV	{"email": "pavlov-ivan_061967@postgrespro.ru", "phone": "+70817970935"}
0005433037689	A64624	7454 371498	GALINA POPOVA	{"phone": "+70654131225"}
0005433037690	B466B5	5919 416688	EGOR FEDOROV	{"email": "egor-fedorov-16101970@postgrespro.ru", "phone": "+70768483597"}
0005433037691	E50C3D	8631 030256	IVAN GERASIMOV	{"email": "gerasimov.i-021978@postgrespro.ru", "phone": "+70613275385"}
0005433037692	7825D0	7941 039430	NIKOLAY ZAKHAROV	{"email": "zakharov-n.1976@postgrespro.ru", "phone": "+70598211008"}
0005433037693	7825D0	5765 098313	MIKHAIL NOVIKOV	{"email": "m-novikov.09041983@postgrespro.ru", "phone": "+70023160942"}
0005433037694	B87D5F	6684 707117	IRINA ZAKHAROVA	{"phone": "+70912427153"}
0005433037695	B87D5F	0146 179379	IRINA FADEEVA	{"phone": "+70488948454"}
0005433037696	547937	0341 190198	KIRILL KRASNOV	{"phone": "+70215758799"}
0005433037697	547937	0945 200623	DMITRIY VASILEV	{"email": "d-vasilev-011963@postgrespro.ru", "phone": "+70535212403"}
0005433037698	F0466B	4382 363127	EKATERINA ZHURAVLEVA	{"email": "ezhuravleva-02101966@postgrespro.ru", "phone": "+70690440684"}
0005433037699	F0466B	4246 919592	ALEKSANDR POPOV	{"phone": "+70824794968"}
0005433037700	CB1AEC	9229 296196	PRASKOVYA VASILEVA	{"phone": "+70945047296"}
0005433037701	CB1AEC	2332 406438	TATYANA IVANOVA	{"phone": "+70117043185"}
0005433037702	89E6FB	3875 718462	NIKOLAY ANDREEV	{"email": "andreev_n.09121979@postgrespro.ru", "phone": "+70423401340"}
0005433037703	7D4E38	1618 597170	MARAT KUZNECOV	{"email": "kuznecov.marat_1969@postgrespro.ru", "phone": "+70264230462"}
0005433037704	6F8EE7	5465 546844	OKSANA MOISEEVA	{"email": "oksanamoiseeva-01061962@postgrespro.ru", "phone": "+70156660350"}
0005433037705	6F8EE7	7038 925461	PETR GUSEV	{"phone": "+70764099198"}
0005433037706	E37F92	1120 176777	OLGA VASILEVA	{"email": "olga.vasileva25111968@postgrespro.ru", "phone": "+70972551974"}
0005433037707	228FC5	7650 742472	OLGA ALEKSEEVA	{"phone": "+70466461918"}
0005433037708	228FC5	6365 817400	KSENIYA TARASOVA	{"email": "ktarasova-02081983@postgrespro.ru", "phone": "+70398976083"}
0005433037709	228FC5	6920 031168	MAKSIM NOVIKOV	{"phone": "+70782909422"}
0005433037710	F78BBC	6816 513160	EDUARD GRIGOREV	{"email": "e_grigorev.1969@postgrespro.ru", "phone": "+70172484360"}
0005433037711	2294E4	3442 164172	RAVIL KUZNECOV	{"email": "kuznecovr.1972@postgrespro.ru", "phone": "+70474371315"}
0005433037712	3FEC26	2241 390987	TATYANA IVANOVA	{"email": "t-ivanova-061980@postgrespro.ru", "phone": "+70701547845"}
0005433037713	3F41E6	5154 035740	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey-071968@postgrespro.ru", "phone": "+70692865624"}
0005433037714	3F41E6	7394 633439	OLGA ZAYCEVA	{"phone": "+70405652693"}
0005433037715	1B8287	3097 690503	ALEKSANDR ABRAMOV	{"phone": "+70942803924"}
0005433037716	B03299	3553 228676	ELENA KAZAKOVA	{"email": "kazakova-elena1973@postgrespro.ru", "phone": "+70822150361"}
0005433037717	B03299	6511 526421	LYUDMILA KOROLEVA	{"phone": "+70989529000"}
0005433037718	B49664	5230 964951	LIDIYA NOVIKOVA	{"phone": "+70546830440"}
0005433037719	B49664	5272 816715	MAKSIM GERASIMOV	{"email": "mgerasimov26021967@postgrespro.ru", "phone": "+70355733594"}
0005433037720	B79CA9	4246 002736	NATALYA LAZAREVA	{"email": "n_lazareva_1970@postgrespro.ru", "phone": "+70830278843"}
0005433037721	B79CA9	2306 569388	VASILIY BORISOV	{"email": "v-borisov.1963@postgrespro.ru", "phone": "+70046176537"}
0005433037722	B79CA9	2536 334909	YURIY AFANASEV	{"phone": "+70913197625"}
0005433037723	B79CA9	2518 222456	DMITRIY KUZNECOV	{"phone": "+70381318427"}
0005433037724	A3DF79	6602 734118	KRISTINA EGOROVA	{"email": "egorova-k04091969@postgrespro.ru", "phone": "+70457498199"}
0005433037725	A3DF79	4480 850313	VLADISLAV KARPOV	{"phone": "+70977646430"}
0005433037726	146DC0	7246 916754	NIKOLAY BELOV	{"email": "nikolay.belov_111983@postgrespro.ru", "phone": "+70895555238"}
0005433037727	146DC0	8830 946594	IVAN MEDVEDEV	{"email": "medvedevivan_1972@postgrespro.ru", "phone": "+70293516537"}
0005433037728	146DC0	9965 197143	ZINAIDA MAKSIMOVA	{"phone": "+70470627587"}
0005433037729	8010CB	2948 448945	MIKHAIL MAKAROV	{"phone": "+70294052926"}
0005433037730	1DD2AD	6840 342368	VLADISLAV GORBUNOV	{"phone": "+70564690724"}
0005433037731	1DD2AD	0244 336606	ELENA EGOROVA	{"email": "e.egorova_17031975@postgrespro.ru", "phone": "+70359162901"}
0005433037732	9A5479	8356 878755	ALEKSANDR SOROKIN	{"email": "asorokin-1974@postgrespro.ru", "phone": "+70235532273"}
0005433037733	9A5479	1183 995175	GALINA BARANOVA	{"email": "galina_baranova.1965@postgrespro.ru", "phone": "+70979806064"}
0005433037734	368B57	5432 924065	NIKOLAY IVANOV	{"phone": "+70089100625"}
0005433037735	0D4EB4	1296 167327	NINA ZAKHAROVA	{"phone": "+70027989121"}
0005433037736	0D4EB4	9086 721616	NINA KUDRYASHOVA	{"email": "nina_kudryashova_01121984@postgrespro.ru", "phone": "+70721764942"}
0005433037737	0D4EB4	0797 465285	ALEKSANDRA NIKIFOROVA	{"phone": "+70235365505"}
0005433037738	911B07	8384 927802	VITALIY TARASOV	{"email": "vitaliy-tarasov.101977@postgrespro.ru", "phone": "+70796306533"}
0005433037739	CB7C12	5264 597372	VALERIY NAZAROV	{"phone": "+70139165713"}
0005433037740	CB7C12	5375 586324	VIKTOR NIKOLAEV	{"email": "nikolaev.viktor-03021983@postgrespro.ru", "phone": "+70958985606"}
0005433037741	AF8052	2862 301683	SERGEY PETROV	{"phone": "+70399243842"}
0005433037742	E38FD0	1176 871881	ALEKSANDRA KALININA	{"email": "kalinina-aleksandra1969@postgrespro.ru", "phone": "+70147128294"}
0005433037743	093DF8	7420 299945	GALINA KOLESNIKOVA	{"email": "kolesnikova.g.27021979@postgrespro.ru", "phone": "+70360253116"}
0005433037744	093DF8	6088 583924	TAMARA PETROVA	{"phone": "+70464278541"}
0005433037745	B1ED15	7060 892267	TATYANA ZAKHAROVA	{"phone": "+70548119916"}
0005433037746	A78426	2527 040700	GALINA SIDOROVA	{"phone": "+70282307674"}
0005433037747	77D350	8156 276185	ALEKSEY TARASOV	{"phone": "+70661555120"}
0005433037748	778A0B	8734 732686	OKSANA ARKHIPOVA	{"email": "o.arkhipova-17081978@postgrespro.ru", "phone": "+70027838143"}
0005433037749	778A0B	1702 353653	VALENTINA MALYSHEVA	{"phone": "+70589890694"}
0005433037750	3F9FE3	4052 757220	VALERIY MAKSIMOV	{"email": "maksimov_valeriy.041983@postgrespro.ru", "phone": "+70574890412"}
0005433037751	3F9FE3	4058 785411	LILIYA KONOVALOVA	{"phone": "+70336030101"}
0005433037752	A8E118	7424 839170	GALINA FROLOVA	{"phone": "+70002006900"}
0005433037753	A8E118	9534 310605	NADEZHDA BOGDANOVA	{"phone": "+70799114724"}
0005433037754	636604	2259 673610	ANDREY FEDOROV	{"phone": "+70269279582"}
0005433037755	1FFC79	9892 545113	ELENA KOZLOVA	{"email": "e.kozlova-1982@postgrespro.ru", "phone": "+70808963595"}
0005433037756	1118B1	2349 080437	VASILIY ANDREEV	{"phone": "+70197410782"}
0005433037757	2BB384	1678 054030	INNA KONDRATEVA	{"email": "kondrateva-i.021972@postgrespro.ru", "phone": "+70976478532"}
0005433037758	73A269	5585 956877	IGOR VLASOV	{"phone": "+70016362932"}
0005433037759	AD60D4	5781 239411	EVGENIY GRIGOREV	{"phone": "+70973842100"}
0005433037760	AD60D4	1229 090038	NATALYA ZHUKOVA	{"phone": "+70657242194"}
0005433037761	71B9BB	2157 874161	ANNA ZAYCEVA	{"phone": "+70315272699"}
0005433037762	E6CDB6	0759 441673	VLADIMIR KUZMIN	{"phone": "+70867515411"}
0005433037763	E6CDB6	5337 592454	IRINA NIKOLAEVA	{"phone": "+70463148701"}
0005433037764	17C769	1558 460958	VALERIY FROLOV	{"email": "valeriy-frolov-16051978@postgrespro.ru", "phone": "+70246984484"}
0005433037765	17C769	6204 301385	EKATERINA ZAYCEVA	{"email": "e-zayceva-1983@postgrespro.ru", "phone": "+70090499316"}
0005433037766	7CA222	2486 265003	ALLA SIDOROVA	{"email": "sidorova.a_011975@postgrespro.ru", "phone": "+70103406343"}
0005433037767	A2D304	5449 515046	OLGA MIRONOVA	{"email": "mironovaolga-1966@postgrespro.ru", "phone": "+70899468191"}
0005433037768	8F9363	1456 874885	OLGA SEMENOVA	{"phone": "+70629720965"}
0005433037769	091C70	9229 739669	LIDIYA OVCHINNIKOVA	{"phone": "+70246364599"}
0005433037770	A6B0A3	8193 899857	VALERIYA DENISOVA	{"email": "valeriya_denisova-111983@postgrespro.ru", "phone": "+70991370421"}
0005433037771	92AD03	7597 428658	MARIYA GORBUNOVA	{"email": "mariya_gorbunova_011979@postgrespro.ru", "phone": "+70177336499"}
0005433037772	EB945F	5855 134805	ARTEM KONOVALOV	{"phone": "+70154012836"}
0005433037773	422E8A	5176 419785	VALENTINA EGOROVA	{"phone": "+70588159855"}
0005433037774	568730	5485 837018	IVAN EGOROV	{"email": "egorov-i-1975@postgrespro.ru", "phone": "+70596982103"}
0005433037775	36B02C	4830 623485	TATYANA SMIRNOVA	{"phone": "+70792020033"}
0005433037776	FC013F	8058 796836	NINA FEDOROVA	{"phone": "+70896724618"}
0005433037777	B6CD32	1272 874263	ANTON GRIGOREV	{"phone": "+70755884409"}
0005433037778	B6CD32	3150 271921	GULIYA POTAPOVA	{"phone": "+70788024728"}
0005433037779	DBB8AA	3547 069869	IGOR SMIRNOV	{"phone": "+70262042733"}
0005433037780	D94498	8909 845979	DMITRIY MARTYNOV	{"phone": "+70427587506"}
0005433037781	BD0614	3484 160485	VLADISLAV NAZAROV	{"email": "nazarov.v_111963@postgrespro.ru", "phone": "+70945984180"}
0005433037782	06A263	8928 930055	ARTEM KONOVALOV	{"email": "artemkonovalov.101972@postgrespro.ru", "phone": "+70910842573"}
0005433037783	0FB870	1575 758744	ALEKSANDR SERGEEV	{"email": "sergeev-aleksandr.1970@postgrespro.ru", "phone": "+70418500522"}
0005433037784	0FB870	5490 297362	ANATOLIY FEDOROV	{"email": "anatoliyfedorov-15021975@postgrespro.ru", "phone": "+70782970424"}
0005433037785	FE6879	3422 659386	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov021970@postgrespro.ru", "phone": "+70640685605"}
0005433037786	FE6879	8826 437164	EKATERINA ZAYCEVA	{"email": "e.zayceva.1973@postgrespro.ru", "phone": "+70882947053"}
0005433037787	FE6879	1280 113386	TATYANA MASLOVA	{"email": "maslovat-01121961@postgrespro.ru", "phone": "+70775841313"}
0005433037788	FE6879	5426 560819	MARIYA RODIONOVA	{"phone": "+70674766461"}
0005433037789	B8AF02	4519 396671	VALENTINA YAKOVLEVA	{"phone": "+70339230299"}
0005433037790	B8AF02	3553 788909	IRINA NIKIFOROVA	{"phone": "+70045911717"}
0005433037791	B8AF02	7141 314721	ANASTASIYA ZAYCEVA	{"email": "a.zayceva.24111971@postgrespro.ru", "phone": "+70923343824"}
0005433037792	493083	8956 414445	VALENTINA LEBEDEVA	{"email": "lebedeva_valentina_23031977@postgrespro.ru", "phone": "+70378744224"}
0005433037793	493083	7696 524106	MARINA FILIPPOVA	{"phone": "+70460421317"}
0005433037794	9DFE6C	4368 909396	RUSLAN TIMOFEEV	{"phone": "+70813508098"}
0005433037795	9DFE6C	4722 621867	EVGENIY MOROZOV	{"phone": "+70910349873"}
0005433037796	5B1568	7406 962346	IGOR MOROZOV	{"phone": "+70197889678"}
0005433037797	5B1568	6997 093730	DMITRIY TIKHONOV	{"email": "tikhonov-d-031968@postgrespro.ru", "phone": "+70654348276"}
0005433037798	0409B5	7021 272602	NATALYA ABRAMOVA	{"phone": "+70539930635"}
0005433037799	69CCB2	6630 043430	KRISTINA GORBUNOVA	{"email": "kristina_gorbunova_06041973@postgrespro.ru", "phone": "+70410183611"}
0005433037800	08CA39	1959 365622	OLGA GUSEVA	{"phone": "+70031638190"}
0005433037801	5F8720	6097 864200	VIKTOR MELNIKOV	{"email": "viktor_melnikov1970@postgrespro.ru", "phone": "+70436047377"}
0005433037802	721F28	8246 099399	LYUDMILA ANDREEVA	{"email": "landreeva.051954@postgrespro.ru", "phone": "+70770980854"}
0005433037803	2FE65C	2731 594242	SVETLANA MIKHAYLOVA	{"phone": "+70067259295"}
0005433037804	A4D6A0	1598 209327	ALEKSANDR TARASOV	{"phone": "+70116632206"}
0005433037805	3C6E4C	0333 709723	ANATOLIY VOROBEV	{"email": "anatoliy_vorobev.061970@postgrespro.ru", "phone": "+70118914562"}
0005433037806	EADCF2	7971 585355	ANASTASIYA STEPANOVA	{"email": "stepanovaanastasiya021974@postgrespro.ru", "phone": "+70039555808"}
0005433037807	FCF292	8846 319603	SVETLANA IVANOVA	{"phone": "+70288119761"}
0005433037808	0AB9C2	1911 091538	OLGA FILATOVA	{"phone": "+70849746282"}
0005433037809	BAC913	4054 701508	IRINA KUZMINA	{"email": "kuzmina-irina14081965@postgrespro.ru", "phone": "+70188337668"}
0005433037810	70D897	0843 067956	IRINA KUZNECOVA	{"email": "irina.kuznecova.23031975@postgrespro.ru", "phone": "+70739966118"}
0005433037811	6F55F1	7380 246444	ANNA PETROVA	{"email": "apetrova_1970@postgrespro.ru", "phone": "+70847253171"}
0005433037812	62E1E8	1086 612022	VLADIMIR ZHUKOV	{"email": "zhukov.v-041972@postgrespro.ru", "phone": "+70524788030"}
0005433037813	C9AEAE	2032 109834	MARIYA OSIPOVA	{"phone": "+70374453223"}
0005433037814	C9AEAE	1706 729345	VALENTINA KUZMINA	{"phone": "+70162873847"}
0005433037815	4F4B5D	0819 902498	STEPAN FILIPPOV	{"phone": "+70685200271"}
0005433037816	3D55B5	3359 874772	DAMIR MOROZOV	{"phone": "+70857337743"}
0005433037817	5DD67B	9214 431770	SERGEY ANTONOV	{"email": "antonov-s16101978@postgrespro.ru", "phone": "+70041365131"}
0005433037818	5DD67B	5587 862490	YULIYA BORISOVA	{"email": "borisovayuliya101958@postgrespro.ru", "phone": "+70120796868"}
0005433037819	5DD67B	2504 017590	VYACHESLAV PAVLOV	{"email": "vyacheslav_pavlov-1978@postgrespro.ru", "phone": "+70012239336"}
0005433037820	B80011	2672 602213	TATYANA TIKHONOVA	{"email": "tikhonova.t_071960@postgrespro.ru", "phone": "+70185364883"}
0005433037821	B80011	4478 300799	IVAN VOLKOV	{"phone": "+70036190064"}
0005433037822	B80011	7850 680178	VALENTINA NIKOLAEVA	{"email": "vnikolaeva021970@postgrespro.ru", "phone": "+70563434868"}
0005433037823	C2A230	8227 509615	PAVEL IVANOV	{"phone": "+70780213934"}
0005433037824	C2A230	1190 264921	TATYANA ZAKHAROVA	{"email": "t_zakharova.101970@postgrespro.ru", "phone": "+70965400422"}
0005433037825	CB859F	1709 846227	ANNA NIKIFOROVA	{"email": "nikiforova.a.071973@postgrespro.ru", "phone": "+70072996627"}
0005433037826	231FD5	0263 640128	KIRILL CHERNOV	{"email": "k-chernov_1965@postgrespro.ru", "phone": "+70520983477"}
0005433037827	50EDDA	8494 998283	ALISHER NOVIKOV	{"phone": "+70820843692"}
0005433037828	50EDDA	6033 383280	RUSTAM RODIONOV	{"email": "rustam_rodionov_061970@postgrespro.ru", "phone": "+70701153819"}
0005433037829	01CF77	3685 200308	ELENA KOROLEVA	{"phone": "+70416128456"}
0005433037830	01CF77	1648 198527	VLADIMIR FEDOTOV	{"email": "fedotov-v_091965@postgrespro.ru", "phone": "+70632078995"}
0005433037831	4573C4	5000 852059	TATYANA OVCHINNIKOVA	{"phone": "+70736813028"}
0005433037832	266AA2	4921 527406	LARISA DMITRIEVA	{"phone": "+70821429540"}
0005433037833	266AA2	2638 754247	SVETLANA KOROLEVA	{"email": "s-koroleva11061980@postgrespro.ru", "phone": "+70379502276"}
0005433037834	F42FC1	5868 817124	LYUBOV AFANASEVA	{"email": "l.afanaseva-031971@postgrespro.ru", "phone": "+70612139484"}
0005433037835	31BC71	6946 956412	GALINA MOROZOVA	{"email": "galina.morozova-1983@postgrespro.ru", "phone": "+70699896095"}
0005433037836	48C7BB	7263 622105	VIKTOR SIDOROV	{"email": "v.sidorov-1983@postgrespro.ru", "phone": "+70031199297"}
0005433037837	D6B07C	7202 583150	RAIL SEMENOV	{"email": "rail.semenov_121966@postgrespro.ru", "phone": "+70837174260"}
0005433037839	D903C8	1246 923344	ALEKSEY SCHERBAKOV	{"email": "scherbakova.051977@postgrespro.ru", "phone": "+70070059143"}
0005433037840	CE6D5B	3904 695634	LARISA LAZAREVA	{"email": "larisa.lazareva051979@postgrespro.ru", "phone": "+70489076703"}
0005433037841	CE6D5B	2339 805420	SERGEY KRASNOV	{"phone": "+70779333776"}
0005433037842	21A291	6217 233264	VASILIY DMITRIEV	{"email": "dmitrievvasiliy-13091967@postgrespro.ru", "phone": "+70035653153"}
0005433037843	EBD04D	2442 887262	LIDIYA KRASNOVA	{"phone": "+70570883950"}
0005433037844	25E213	4602 752788	ALEKSANDR BONDARENKO	{"email": "aleksandr.bondarenko-1974@postgrespro.ru", "phone": "+70224300487"}
0005433037845	8E97A5	9215 926761	TIMOFEY VOROBEV	{"email": "vorobev-t_09091980@postgrespro.ru", "phone": "+70583216422"}
0005433037846	4DC691	2083 089973	VASILIY KOZLOV	{"email": "vasiliy-kozlov.1970@postgrespro.ru", "phone": "+70624853340"}
0005433037847	C03AFD	8372 587413	SVETLANA YAKOVLEVA	{"email": "yakovleva_svetlana.16091961@postgrespro.ru", "phone": "+70662930359"}
0005433037848	6F655B	5454 311095	GALINA MASLOVA	{"phone": "+70102554885"}
0005433037849	CEE1EB	8447 132949	NATALYA KONOVALOVA	{"email": "konovalova-natalya.20081978@postgrespro.ru", "phone": "+70708706494"}
0005433037850	3E19E8	6750 200753	NATALYA VASILEVA	{"phone": "+70879264870"}
0005433037851	D2D58A	8284 442427	PAVEL FEDOROV	{"phone": "+70150642661"}
0005433037852	1E6430	0827 195377	DANIL GORBUNOV	{"phone": "+70324099450"}
0005433037853	802408	0239 834759	NATALYA AKIMOVA	{"email": "akimovanatalya1978@postgrespro.ru", "phone": "+70156759819"}
0005433037854	802408	1305 542543	DMITRIY IVANOV	{"email": "ivanov.dmitriy1978@postgrespro.ru", "phone": "+70798282662"}
0005433037855	8E2C55	4419 469829	KSENIYA ANDREEVA	{"phone": "+70443365551"}
0005433037856	8E2C55	9669 506803	VIKTOR YAKOVLEV	{"phone": "+70592938284"}
0005433037857	8E2C55	9887 774694	DMITRIY SOKOLOV	{"phone": "+70719111901"}
0005433057171	AC2D4F	7768 048343	NINA AKIMOVA	{"phone": "+70097298918"}
0005433057284	6BE418	8988 037527	ANTONINA IVANOVA	{"phone": "+70746706773"}
0005433057168	1471A2	1049 624863	OLEG STEPANOV	{"email": "stepanov-o_21031980@postgrespro.ru", "phone": "+70196770472"}
0005433057169	39F6F6	6050 919867	ANDREY TARASOV	{"phone": "+70775148667"}
0005433057170	39F6F6	0986 404280	ARINA PETROVA	{"phone": "+70727191536"}
0005433057172	B4E863	3253 005273	OLGA NIKIFOROVA	{"email": "olga.nikiforova_03111973@postgrespro.ru", "phone": "+70118511853"}
0005433057173	ED64AA	6564 871165	ALEKSEY ANTONOV	{"email": "antonov.a.121974@postgrespro.ru", "phone": "+70544234194"}
0005433057174	ED64AA	5648 814136	LARISA KUZMINA	{"email": "kuzminal-1967@postgrespro.ru", "phone": "+70483439579"}
0005433057175	B5968B	6606 080970	DZHAMILYA SOLOVEVA	{"email": "dzhamilya-soloveva-111956@postgrespro.ru", "phone": "+70425499225"}
0005433057176	B5968B	7713 504304	OLGA GORBUNOVA	{"phone": "+70933452109"}
0005433057177	8CDEC8	6840 449347	SERGEY SMIRNOV	{"phone": "+70218688975"}
0005433057178	E122EF	8197 569326	IRINA SERGEEVA	{"email": "irina_sergeeva_1971@postgrespro.ru", "phone": "+70200444644"}
0005433057179	1EF713	7360 652271	NATALYA FOMINA	{"email": "natalya-fomina_051979@postgrespro.ru", "phone": "+70976792058"}
0005433057180	D87905	0337 900320	VERONIKA IVANOVA	{"email": "v-ivanova-081979@postgrespro.ru", "phone": "+70082850024"}
0005433057181	D87905	9344 652613	DMITRIY KONOVALOV	{"phone": "+70916004092"}
0005433057182	47EE24	5037 854579	ELENA BOGDANOVA	{"email": "ebogdanova02101985@postgrespro.ru", "phone": "+70435884709"}
0005433057183	715BCD	2463 696027	MIKHAIL EGOROV	{"phone": "+70118389056"}
0005433057184	9F8DBC	3342 432008	NADEZHDA ZHUKOVA	{"email": "zhukova_nadezhda.051981@postgrespro.ru", "phone": "+70319114891"}
0005433057185	9F8DBC	0385 241461	EDGAR FEDOTOV	{"phone": "+70488077804"}
0005433057186	4F65FF	6666 625623	TAISIYA RYABOVA	{"email": "ryabova.taisiya01071962@postgrespro.ru", "phone": "+70565892489"}
0005433057187	1B1494	0934 980163	TAMARA SOKOLOVA	{"phone": "+70173047644"}
0005433057188	03ACAD	9077 861391	SVETLANA SAVELEVA	{"email": "savelevasvetlana_081955@postgrespro.ru", "phone": "+70277468504"}
0005433057189	777297	0347 845877	VALERIY ALEKSANDROV	{"phone": "+70671581893"}
0005433057190	DAB8E9	2412 268276	ALEKSEY IVANOV	{"email": "aleksey-ivanov071981@postgrespro.ru", "phone": "+70080684461"}
0005433057191	DAB8E9	3471 669224	ALEKSANDRA ANTONOVA	{"phone": "+70118782976"}
0005433057192	440F90	2092 593738	NINA MARTYNOVA	{"email": "ninamartynova_04031975@postgrespro.ru", "phone": "+70851038521"}
0005433057193	89734C	5546 176537	ELIZAVETA NAZAROVA	{"phone": "+70880969249"}
0005433057194	BF787B	3029 919129	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a.031959@postgrespro.ru", "phone": "+70508314112"}
0005433057195	6C92DD	3941 475581	KRISTINA KOROLEVA	{"email": "koroleva_kristina041970@postgrespro.ru", "phone": "+70988094071"}
0005433057196	6C92DD	1082 060843	VLADIMIR FOMIN	{"email": "vladimir_fomin.1973@postgrespro.ru", "phone": "+70760895839"}
0005433057197	6C92DD	7554 632608	ANDREY GUSEV	{"email": "gusev-a1980@postgrespro.ru", "phone": "+70649512560"}
0005433057198	CD72D2	6426 947630	ALSU ZAYCEVA	{"email": "zayceva_a091965@postgrespro.ru", "phone": "+70361448114"}
0005433057199	CD72D2	7172 631948	TATYANA SOKOLOVA	{"email": "t_sokolova1964@postgrespro.ru", "phone": "+70918133121"}
0005433057200	5334D7	4506 845886	MIKHAIL SOROKIN	{"phone": "+70820855673"}
0005433057201	35C5D0	5238 909043	RUSLAN SMIRNOV	{"email": "ruslan.smirnov-051973@postgrespro.ru", "phone": "+70621053770"}
0005433057202	F62D64	3710 722025	ELENA POPOVA	{"phone": "+70215649700"}
0005433057203	5484BE	9742 030595	GALINA PAVLOVA	{"email": "pavlova_galina1970@postgrespro.ru", "phone": "+70346313876"}
0005433057204	0E873C	0726 811765	MIKHAIL KUDRYASHOV	{"email": "kudryashovm-29031967@postgrespro.ru", "phone": "+70737001843"}
0005433057205	0E873C	8368 705666	ZOYA SMIRNOVA	{"phone": "+70153596646"}
0005433057206	1AC2CB	6297 665174	ALEKSANDR POPOV	{"phone": "+70969511865"}
0005433057207	1AC2CB	9492 224535	NINA TIKHONOVA	{"email": "tikhonovan_10111966@postgrespro.ru", "phone": "+70392250665"}
0005433057208	E0D813	0800 200682	ANNA BORISOVA	{"phone": "+70684895677"}
0005433057209	CE0F5B	0856 434603	MARIYA EGOROVA	{"email": "mariya.egorova03091994@postgrespro.ru", "phone": "+70410494045"}
0005433057210	5D902E	9977 716086	SERGEY KUDRYASHOV	{"phone": "+70555217728"}
0005433057211	F860C7	7679 360474	VLADIMIR NIKITIN	{"email": "v.nikitin071960@postgrespro.ru", "phone": "+70977538427"}
0005433057212	026FFF	7881 844215	IRINA NOVIKOVA	{"phone": "+70095768519"}
0005433057213	90EABC	5165 518093	VLADIMIR BONDARENKO	{"email": "bondarenko.v061969@postgrespro.ru", "phone": "+70974870319"}
0005433057214	A29D71	9786 760976	OLGA KULIKOVA	{"email": "olga-kulikova-1980@postgrespro.ru", "phone": "+70979558784"}
0005433057215	A29D71	3053 112368	SERGEY PAVLOV	{"email": "pavlov_sergey.091973@postgrespro.ru", "phone": "+70099491971"}
0005433057216	8BD2EB	3802 308388	NADEZHDA FADEEVA	{"phone": "+70477431863"}
0005433057217	8BD2EB	0072 680216	VIKTOR SIDOROV	{"phone": "+70356567781"}
0005433057218	663DB1	8260 952775	VERA KOMAROVA	{"phone": "+70526939653"}
0005433057219	663DB1	3556 311827	EVGENIY FEDOROV	{"email": "fedorov.evgeniy.01061970@postgrespro.ru", "phone": "+70930051722"}
0005433057220	71C43F	6626 146918	ARTEM SOKOLOV	{"email": "sokolov_a_051978@postgrespro.ru", "phone": "+70095289075"}
0005433057221	B8D306	4367 773458	MIKHAIL YAKOVLEV	{"email": "yakovlev.mikhail.1977@postgrespro.ru", "phone": "+70413672808"}
0005433057222	B8D306	4728 119024	SERGEY KUZNECOV	{"email": "s-kuznecov-07031968@postgrespro.ru", "phone": "+70459476214"}
0005433057223	B8D306	1966 065166	EVGENIYA EGOROVA	{"email": "evgeniya-egorova.1969@postgrespro.ru", "phone": "+70626092810"}
0005433057224	1E4F75	0445 402751	NIKITA ORLOV	{"email": "n-orlov031974@postgrespro.ru", "phone": "+70926620003"}
0005433057225	4EDFF0	0899 917949	YAROSLAV CHERNOV	{"email": "chernovy061982@postgrespro.ru", "phone": "+70726954638"}
0005433057226	4EDFF0	6658 243407	OLGA TROFIMOVA	{"phone": "+70197754946"}
0005433057227	9C1218	5748 262850	SVYATOSLAV GORBUNOV	{"email": "gorbunov_svyatoslav27021963@postgrespro.ru", "phone": "+70378921968"}
0005433057228	13EB08	6443 093612	ALEKSEY IVANOV	{"email": "alekseyivanov061973@postgrespro.ru", "phone": "+70854722030"}
0005433057229	EE5C08	6193 537503	NATALIYA KUZNECOVA	{"phone": "+70391408457"}
0005433057230	3D7AD3	5739 285017	TAMARA VASILEVA	{"phone": "+70309396647"}
0005433057231	341324	1038 849955	OLESYA LUKYANOVA	{"phone": "+70452700658"}
0005433057232	9685AA	8751 480946	VALENTINA DENISOVA	{"phone": "+70197840940"}
0005433057233	D99E42	0939 978127	NINA MOISEEVA	{"phone": "+70283960256"}
0005433057234	D99E42	5811 793471	ANDREY KRASNOV	{"phone": "+70680328651"}
0005433057235	F41EEF	1195 720091	NATALYA FEDOROVA	{"email": "fedorova.n_121978@postgrespro.ru", "phone": "+70056885082"}
0005433057236	3806A8	8731 723850	ALENA ORLOVA	{"phone": "+70416998773"}
0005433057237	7B9DA7	7430 974298	NATALYA ORLOVA	{"phone": "+70690591239"}
0005433057238	322A8C	7085 768050	VIKTOR NIKOLAEV	{"phone": "+70430413910"}
0005433057301	ED1635	8205 010449	ARTEM TIMOFEEV	{"phone": "+70214853289"}
0005433057239	779D55	2971 739758	ALEKSANDR ROMANOV	{"email": "romanov_a_031982@postgrespro.ru", "phone": "+70358080273"}
0005433057240	779D55	5251 382829	MIKHAIL FEDOTOV	{"phone": "+70629955898"}
0005433057241	5A2AD2	1973 346163	LYUBOV NIKIFOROVA	{"phone": "+70699952394"}
0005433057242	5A2AD2	5691 981283	NINA STEPANOVA	{"email": "stepanova.nina13051972@postgrespro.ru", "phone": "+70359550814"}
0005433057243	F40B19	6855 718708	VALERIY ILIN	{"email": "v_ilin-021964@postgrespro.ru", "phone": "+70685688849"}
0005433057244	C49AAF	7563 993491	VLADIMIR EGOROV	{"phone": "+70421023575"}
0005433057245	95A2E0	2006 459751	VITALIY DENISOV	{"phone": "+70861722997"}
0005433057246	393AC1	7763 990690	VIKTORIYA PAVLOVA	{"phone": "+70378939694"}
0005433057247	6E6517	1437 411450	GENNADIY SOLOVEV	{"email": "solovevg-17121975@postgrespro.ru", "phone": "+70656419446"}
0005433057248	255A44	3596 743777	EKATERINA DANILOVA	{"phone": "+70620087554"}
0005433057249	EB112A	4122 474687	TATYANA POTAPOVA	{"phone": "+70624594410"}
0005433057250	88FB76	2261 794711	MARIYA DENISOVA	{"phone": "+70958248145"}
0005433057251	88FB76	5651 049664	ANTONINA SIDOROVA	{"phone": "+70698468315"}
0005433057252	88FB76	7253 240890	ALEKSANDR ABRAMOV	{"email": "abramov_a.1974@postgrespro.ru", "phone": "+70825237073"}
0005433057253	4F95B2	2499 102034	OLGA KALININA	{"email": "kalinina-olga-071972@postgrespro.ru", "phone": "+70543026584"}
0005433057254	F57BF2	7056 165738	ELENA GERASIMOVA	{"phone": "+70478792154"}
0005433057255	F57BF2	4051 604282	DANIIL ROMANOV	{"email": "romanovd1967@postgrespro.ru", "phone": "+70575732823"}
0005433057256	62768A	6327 270437	OLEG SCHERBAKOV	{"email": "oscherbakov-081972@postgrespro.ru", "phone": "+70046994332"}
0005433057257	0E0ED2	7449 344762	POLINA BOGDANOVA	{"phone": "+70937164330"}
0005433057258	F25034	4959 764515	INNA SMIRNOVA	{"email": "inna.smirnova_1959@postgrespro.ru", "phone": "+70129730317"}
0005433057259	E03884	8302 089146	TIMUR SEMENOV	{"email": "semenov_t-081969@postgrespro.ru", "phone": "+70725214170"}
0005433057260	E03884	7679 984018	ROMAN KUDRYASHOV	{"email": "r_kudryashov_011962@postgrespro.ru", "phone": "+70666751331"}
0005433057261	D94037	2776 835033	PAVEL FOMIN	{"phone": "+70161209470"}
0005433057262	D94037	7965 176101	NIKOLAY POPOV	{"email": "npopov.04071967@postgrespro.ru", "phone": "+70481060347"}
0005433057263	512158	2526 069779	ANDREY KOZLOV	{"phone": "+70421250663"}
0005433057264	512158	2913 529275	ALEKSEY KARPOV	{"phone": "+70650252438"}
0005433057265	512158	0306 056766	RAFIS FOMIN	{"phone": "+70098069606"}
0005433057266	07C893	9639 556266	ALEKSEY VASILEV	{"email": "vasilev_a-021964@postgrespro.ru", "phone": "+70301084166"}
0005433057267	46D49B	1149 257919	VLADIMIR RODIONOV	{"phone": "+70449941011"}
0005433057268	84FD1C	8777 493074	KSENIYA MARTYNOVA	{"phone": "+70656982908"}
0005433057269	4BB04B	0744 329076	ANDREY ROMANOV	{"email": "aromanov031956@postgrespro.ru", "phone": "+70752718665"}
0005433057270	4BB04B	1376 542591	ROMAN CHERNOV	{"phone": "+70843722746"}
0005433057271	952258	6582 982849	TAISIYA ANISIMOVA	{"phone": "+70409244939"}
0005433057272	330B0C	7676 990248	TATYANA POPOVA	{"email": "tatyana.popova_1965@postgrespro.ru", "phone": "+70444035588"}
0005433057273	330B0C	2137 880396	NATALYA STEPANOVA	{"phone": "+70644456849"}
0005433057274	330B0C	3212 142260	TATYANA ALEKSANDROVA	{"email": "aleksandrova_tatyana-1975@postgrespro.ru", "phone": "+70139046950"}
0005433057275	030FDF	0343 829607	LYUDMILA PETROVA	{"phone": "+70432445469"}
0005433057276	BBD79F	6352 496569	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov1970@postgrespro.ru", "phone": "+70032336619"}
0005433057277	BBD79F	0868 344955	VIKTORIYA FILIPPOVA	{"phone": "+70935861519"}
0005433057278	96EEC8	6497 437965	MIKHAIL ANDREEV	{"phone": "+70089626352"}
0005433057279	1AD190	1657 649860	VADIM GERASIMOV	{"phone": "+70199043589"}
0005433057280	6CC454	1926 318632	TATYANA LAZAREVA	{"email": "lazareva.t13051972@postgrespro.ru", "phone": "+70531180694"}
0005433057281	0D961E	5786 496076	TATYANA MIRONOVA	{"email": "t-mironova_121973@postgrespro.ru", "phone": "+70524351460"}
0005433057282	E8D1DD	4103 840848	ELENA ORLOVA	{"email": "eorlova_1969@postgrespro.ru", "phone": "+70644627393"}
0005433057283	A5B382	1931 773235	DANIIL KUZMIN	{"phone": "+70206855687"}
0005433057285	6BE418	2737 238331	POLINA KONOVALOVA	{"email": "pkonovalova-30121972@postgrespro.ru", "phone": "+70228530781"}
0005433057286	E9B390	1064 537283	DMITRIY MAKAROV	{"phone": "+70115214234"}
0005433057287	3BA984	7679 891327	TATYANA GAVRILOVA	{"phone": "+70733410864"}
0005433057288	7D1BC4	2099 662111	ANASTASIYA KOROLEVA	{"phone": "+70915253025"}
0005433057289	F9D17F	2692 468540	OLGA SMIRNOVA	{"email": "olga_smirnova.17091971@postgrespro.ru", "phone": "+70369453676"}
0005433057290	B5F269	1604 690965	SERGEY MOISEEV	{"phone": "+70359952936"}
0005433057291	B924DD	3743 842440	ALEKSEY ABRAMOV	{"phone": "+70348972045"}
0005433057292	50FD50	2222 916272	ANATOLIY SMIRNOV	{"phone": "+70154027718"}
0005433057293	ED2120	8500 189998	DMITRIY VASILEV	{"email": "vasilev-dmitriy_1977@postgrespro.ru", "phone": "+70029746981"}
0005433057294	ED2120	5887 712883	ELENA VOROBEVA	{"email": "elenavorobeva_25051968@postgrespro.ru", "phone": "+70040321843"}
0005433057295	075971	8306 486689	DMITRIY VASILEV	{"email": "dvasilev071979@postgrespro.ru", "phone": "+70636653946"}
0005433057296	4C9A02	2435 460514	VERA LEBEDEVA	{"email": "vera.lebedeva_11091968@postgrespro.ru", "phone": "+70873476575"}
0005433057297	4C9A02	4480 127955	EKATERINA VOLKOVA	{"email": "volkova-e-081977@postgrespro.ru", "phone": "+70291230812"}
0005433057298	6B1637	4935 146432	VLADIMIR SHEVCHENKO	{"email": "vladimir-shevchenko.25111964@postgrespro.ru", "phone": "+70906624897"}
0005433057299	856A27	7928 684892	EKATERINA STEPANOVA	{"email": "estepanova111976@postgrespro.ru", "phone": "+70237905057"}
0005433057300	856A27	5169 331656	DMITRIY VASILEV	{"email": "vasilev-dmitriy021981@postgrespro.ru", "phone": "+70835270637"}
0005433057302	ED1635	2371 700076	TAMARA BOGDANOVA	{"email": "bogdanova.tamara23111975@postgrespro.ru", "phone": "+70002144774"}
0005433057303	D3AC63	5692 300637	EGOR KULIKOV	{"phone": "+70276677441"}
0005433057304	1598B8	7194 091453	KRISTINA DAVYDOVA	{"email": "davydova-kristina_041968@postgrespro.ru", "phone": "+70393565127"}
0005433057305	1598B8	6720 042717	KLAVDIYA KULIKOVA	{"phone": "+70374473306"}
0005433057306	1598B8	3344 162318	STANISLAV FEDOROV	{"email": "s_fedorov061974@postgrespro.ru", "phone": "+70074527535"}
0005433057307	252113	4708 373016	TATYANA KULIKOVA	{"phone": "+70278919676"}
0005433057308	252113	8762 797794	MIKHAIL YAKOVLEV	{"email": "yakovlev_m021985@postgrespro.ru", "phone": "+70465172291"}
0005433057309	246AF8	8607 682041	VYACHESLAV CHERNOV	{"email": "v-chernov1966@postgrespro.ru", "phone": "+70372302442"}
0005433057310	9D4A64	4616 961063	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov1971@postgrespro.ru", "phone": "+70081135914"}
0005433057311	9387A0	1618 108808	ARTEM CHERNOV	{"phone": "+70910989235"}
0005433057312	A1C6C7	6471 532767	NINA IVANOVA	{"email": "ivanova.n_1966@postgrespro.ru", "phone": "+70581185739"}
0005433057313	08EB0C	9940 807861	SERGEY PETROV	{"email": "petrovs-26021979@postgrespro.ru", "phone": "+70126284152"}
0005433057314	8335C8	3345 670245	ANASTASIYA LEBEDEVA	{"email": "a.lebedeva_081985@postgrespro.ru", "phone": "+70020035413"}
0005433057315	CBCC64	8485 513665	IVAN AFANASEV	{"email": "i_afanasev1965@postgrespro.ru", "phone": "+70515378352"}
0005433057316	19BA1F	4241 932476	ELENA GORBUNOVA	{"email": "elena.gorbunova.1972@postgrespro.ru", "phone": "+70599488259"}
0005433057317	19BA1F	1095 593682	VLADIMIR SERGEEV	{"phone": "+70743025977"}
0005433057318	750E5A	9949 809045	VIKTOR IVANOV	{"phone": "+70424228341"}
0005433057319	750E5A	8098 966470	OLGA FOMINA	{"phone": "+70918001633"}
0005433057320	17767E	8465 021379	AMIR GAVRILOV	{"email": "amir-gavrilov_1973@postgrespro.ru", "phone": "+70201298310"}
0005433057321	2FDDD3	3951 807725	ELENA SIDOROVA	{"email": "elenasidorova.111972@postgrespro.ru", "phone": "+70461771645"}
0005433057322	CD4666	3086 670431	MAKSIM GORBUNOV	{"email": "maksim-gorbunov_061969@postgrespro.ru", "phone": "+70082074811"}
0005433057323	CD4666	7232 460683	RAISA POPOVA	{"email": "r_popova.1979@postgrespro.ru", "phone": "+70365982020"}
0005433057324	5224A9	6177 378475	VLADISLAV OSIPOV	{"email": "vladislav.osipov-13071972@postgrespro.ru", "phone": "+70062563090"}
0005433057325	0B268F	0333 730724	ALEKSANDRA CHERNOVA	{"phone": "+70939843011"}
0005433057326	0B268F	3971 725921	DARYA KARPOVA	{"phone": "+70310370979"}
0005433057327	F73362	8125 895993	MARIYA AFANASEVA	{"phone": "+70992857797"}
0005433057328	F73362	4869 113245	PAVEL SOROKIN	{"phone": "+70072247498"}
0005433057329	99C269	1200 065966	ILYA DMITRIEV	{"phone": "+70955896629"}
0005433057330	2BE2F8	4450 410561	VLADIMIR NOVIKOV	{"email": "novikovvladimir.01021975@postgrespro.ru", "phone": "+70106005108"}
0005433057331	37954A	5666 700128	LUIZA MIRONOVA	{"phone": "+70779831270"}
0005433057332	0D28FB	3324 825555	ILNAR ALEKSEEV	{"phone": "+70278317098"}
0005433057333	046843	3799 822601	VASILIY KULIKOV	{"phone": "+70142665644"}
0005433057334	046843	8383 514830	YULIYA VASILEVA	{"phone": "+70855555528"}
0005433057335	046843	3420 101783	NINA YAKOVLEVA	{"email": "yakovleva_n_1981@postgrespro.ru", "phone": "+70167962796"}
0005433057336	D39D39	8497 521587	ALEKSANDR ALEKSEEV	{"phone": "+70363066895"}
0005433057337	E2D481	1320 892310	LYUDMILA MAKAROVA	{"phone": "+70564848544"}
0005433057338	E2D481	6082 685535	ALEKSANDR MEDVEDEV	{"phone": "+70476031752"}
0005433057339	E2D481	4321 277881	IGOR ZHURAVLEV	{"phone": "+70426851375"}
0005433057340	7A25BD	0556 608092	MAKSIM SERGEEV	{"email": "sergeev.maksim1969@postgrespro.ru", "phone": "+70479238408"}
0005433057341	7A25BD	2822 249846	RAFIK IVANOV	{"email": "ivanovrafik_041971@postgrespro.ru", "phone": "+70129126261"}
0005433057342	98D9D4	8422 901469	RAISA ZHURAVLEVA	{"email": "raisazhuravleva.1970@postgrespro.ru", "phone": "+70082502216"}
0005433057343	3C7BC9	1322 673725	ALINA DANILOVA	{"email": "danilovaalina1979@postgrespro.ru", "phone": "+70392604350"}
0005433057344	3B182B	1603 649637	PETR POPOV	{"email": "popov.petr_18081964@postgrespro.ru", "phone": "+70802396814"}
0005433057345	4463A5	0420 642712	ALINA VOLKOVA	{"phone": "+70515274011"}
0005433057346	AF1752	9230 230750	VLADIMIR GERASIMOV	{"phone": "+70657374644"}
0005433057347	E6BEC8	8214 028282	OLGA BELOVA	{"email": "obelova1963@postgrespro.ru", "phone": "+70894726025"}
0005433057348	06A76D	2210 487252	ANDREY MAKSIMOV	{"phone": "+70253306751"}
0005433057349	740F49	2832 180233	GALINA FILIPPOVA	{"phone": "+70648114242"}
0005433057350	740F49	3082 044562	RAFAIL FILIPPOV	{"email": "filippovr.10061964@postgrespro.ru", "phone": "+70283063624"}
0005433057351	DCAD72	0196 126021	VERA IVANOVA	{"email": "ivanovav1959@postgrespro.ru", "phone": "+70916553934"}
0005433057352	F69382	8314 599411	EVGENIY ZAYCEV	{"email": "zaycevevgeniy_06081972@postgrespro.ru", "phone": "+70298170936"}
0005433057353	D18E57	8315 052381	MARIYA BORISOVA	{"phone": "+70776039123"}
0005433057354	F2BA2B	4724 879161	ANDREY KUZNECOV	{"email": "kuznecov_andrey-091977@postgrespro.ru", "phone": "+70355203318"}
0005433057355	9A6FAA	8546 360206	ZOYA ARKHIPOVA	{"phone": "+70247160741"}
0005433057356	449649	3287 823102	ANATOLIY FOMIN	{"phone": "+70989987688"}
0005433057357	449649	7669 304288	VALENTINA MASLOVA	{"email": "vmaslova03111962@postgrespro.ru", "phone": "+70890339882"}
0005433057358	8A3CB4	6317 737575	VLADIMIR SOROKIN	{"email": "vladimir_sorokin-09091975@postgrespro.ru", "phone": "+70833183653"}
0005433057359	E06734	1937 545186	MAKSIM KOROLEV	{"phone": "+70772457879"}
0005433057360	A99552	0460 613377	ANTONINA PETROVA	{"email": "petrova.antonina1978@postgrespro.ru", "phone": "+70081243378"}
0005433057361	6E624A	5526 172616	DMITRIY VLASOV	{"email": "d-vlasov.041965@postgrespro.ru", "phone": "+70458902428"}
0005433057362	01881E	6302 456295	VYACHESLAV SOROKIN	{"phone": "+70413821557"}
0005433057363	01881E	1764 532535	SVETLANA NESTEROVA	{"email": "nesterova.s-1964@postgrespro.ru", "phone": "+70626247574"}
0005433057364	FCB612	7702 108004	OLGA DAVYDOVA	{"email": "odavydova_121965@postgrespro.ru", "phone": "+70609043227"}
0005433057365	FCB612	7578 337354	AYRAT VLASOV	{"phone": "+70166526901"}
0005433057366	4C9C17	3805 581357	IGOR SIDOROV	{"email": "sidorov.i_031969@postgrespro.ru", "phone": "+70094310312"}
0005433057367	9CC2C6	7735 341954	ALEKSANDR FEDOROV	{"email": "a-fedorov.29051972@postgrespro.ru", "phone": "+70680868176"}
0005433057368	9CC2C6	1644 308843	NINA MAKAROVA	{"email": "n-makarova1979@postgrespro.ru", "phone": "+70954847795"}
0005433057369	40FC88	4291 356215	ANNA FADEEVA	{"phone": "+70513075138"}
0005433057370	B94C0B	6868 835937	IRINA MARTYNOVA	{"email": "i.martynova.011965@postgrespro.ru", "phone": "+70466719604"}
0005433057371	3CAD2A	5192 934376	ANNA FILATOVA	{"email": "filatovaanna_1973@postgrespro.ru", "phone": "+70504420835"}
0005433057372	887F66	3158 880159	ELENA MIKHAYLOVA	{"phone": "+70193425676"}
0005433057373	887F66	5641 112357	TIMOFEY MATVEEV	{"email": "matveev_timofey.1978@postgrespro.ru", "phone": "+70072808886"}
0005433057374	6D5B80	8385 809878	EKATERINA ZAKHAROVA	{"phone": "+70802053702"}
0005433057375	58BBD4	3299 580612	NATALYA MAKAROVA	{"email": "makarovanatalya-081959@postgrespro.ru", "phone": "+70602372501"}
0005433057376	FA5DBD	7730 947409	GALINA KUZNECOVA	{"email": "kuznecova_galina_071961@postgrespro.ru", "phone": "+70948302650"}
0005433057377	7A8C7D	9764 778123	RINAT ANDREEV	{"phone": "+70446662734"}
0005433057378	CE1237	1149 056510	SERGEY KAZAKOV	{"email": "kazakov-s.041975@postgrespro.ru", "phone": "+70661915148"}
0005433057379	CE1237	5841 053629	ROMAN NIKITIN	{"email": "nikitin_r_23101978@postgrespro.ru", "phone": "+70278553508"}
0005433057380	F3A73E	2081 379228	VYACHESLAV ANDREEV	{"email": "andreev-vyacheslav.24041974@postgrespro.ru", "phone": "+70672608718"}
0005433057381	F3A73E	0408 137691	ALEKSANDR SAVELEV	{"email": "a_savelev-24031971@postgrespro.ru", "phone": "+70790441338"}
0005433057382	7595D2	7900 482258	VLADISLAV ZAYCEV	{"email": "zaycev_vladislav-13081961@postgrespro.ru", "phone": "+70278542743"}
0005433057383	7595D2	5258 472001	SOFYA DAVYDOVA	{"phone": "+70438873009"}
0005433057384	7595D2	9876 041947	PAVEL NIKOLAEV	{"phone": "+70507386805"}
0005433057385	9F1DEA	4164 877608	VYACHESLAV EGOROV	{"phone": "+70008627299"}
0005433057386	3207C9	1983 863307	VASILIY KRASNOV	{"phone": "+70337050606"}
0005433057387	3207C9	4675 100610	INNA FROLOVA	{"email": "innafrolova_25111981@postgrespro.ru", "phone": "+70115895179"}
0005433057388	C17DEA	2528 958936	ANTON TIMOFEEV	{"phone": "+70102014613"}
0005433057389	C265CB	5964 716830	VALENTINA GRISHINA	{"email": "vgrishina-061968@postgrespro.ru", "phone": "+70359855945"}
0005433057390	0FF8C2	4790 259466	ARTEM ILIN	{"phone": "+70479830659"}
0005433057391	0FF8C2	6179 002658	VALENTINA AFANASEVA	{"phone": "+70823267387"}
0005433057392	DA2B9C	9067 801445	YULIYA EFIMOVA	{"phone": "+70146993407"}
0005433057393	3EE849	3113 471775	ANATOLIY ILIN	{"email": "ilin_a011965@postgrespro.ru", "phone": "+70998572021"}
0005433057394	3F4958	9887 234856	ANASTASIYA FEDOROVA	{"phone": "+70161965156"}
0005433057395	3315B3	2706 429008	TATYANA NESTEROVA	{"phone": "+70768094464"}
0005433057396	481863	8752 647516	ELENA MAKAROVA	{"phone": "+70163670769"}
0005433057397	A36C09	0637 413970	ALEKSEY MAKAROV	{"phone": "+70428512551"}
0005433057398	812883	2614 914452	ELENA ILINA	{"phone": "+70646663281"}
0005433057399	BC9E37	7907 285800	VIKTOR YAKOVLEV	{"email": "v_yakovlev_09041971@postgrespro.ru", "phone": "+70416756232"}
0005433057400	E49870	0770 998128	SVETLANA SOKOLOVA	{"email": "s_sokolova.04021961@postgrespro.ru", "phone": "+70533367136"}
0005433057401	E49870	4294 284227	ANNA SMIRNOVA	{"phone": "+70499303054"}
0005433057402	03BB2B	1873 165960	ANNA TROFIMOVA	{"email": "a_trofimova-1974@postgrespro.ru", "phone": "+70711627903"}
0005433057403	200689	4280 966055	LYUBOV NESTEROVA	{"email": "l_nesterova.24031973@postgrespro.ru", "phone": "+70893528477"}
0005433057404	003EB0	0507 180825	KONSTANTIN PETROV	{"phone": "+70998587969"}
0005433057405	049B0B	8281 624856	ALEKSANDR DMITRIEV	{"email": "dmitriev.a18071974@postgrespro.ru", "phone": "+70652637961"}
0005433057406	32B994	9575 707015	ALEKSANDR IVANOV	{"phone": "+70988398888"}
0005433057407	799ADF	2318 175792	IVAN OSIPOV	{"phone": "+70556932474"}
0005433057408	37F050	9058 825917	SERGEY BARANOV	{"email": "baranovs-051978@postgrespro.ru", "phone": "+70728482157"}
0005433057409	2AF6D9	4548 494727	NADEZHDA ILINA	{"phone": "+70609614356"}
0005433057410	EEB7A0	4816 682600	SOFYA DANILOVA	{"phone": "+70913321360"}
0005433057411	F47FBE	0191 410059	NINA ZHURAVLEVA	{"email": "zhuravleva-nina.021973@postgrespro.ru", "phone": "+70761927157"}
0005433057412	F47FBE	4010 774629	NINA KOROLEVA	{"email": "koroleva-nina19111963@postgrespro.ru", "phone": "+70693325842"}
0005433057413	F47FBE	3425 035394	ALEKSANDR MEDVEDEV	{"email": "medvedev.a-1967@postgrespro.ru", "phone": "+70017584398"}
0005433057414	901E3F	6376 695716	ALEKSEY KRASNOV	{"email": "alekseykrasnov.111968@postgrespro.ru", "phone": "+70293920125"}
0005433057415	F2A033	0582 686503	ARTEM FEDOTOV	{"email": "fedotovartem1980@postgrespro.ru", "phone": "+70515887914"}
0005433057416	3831FC	4788 205228	OKSANA KAZAKOVA	{"email": "kazakova_oksana-111964@postgrespro.ru", "phone": "+70884123243"}
0005433057417	FBC26D	0244 391900	VIKTOR FILIPPOV	{"phone": "+70555811622"}
0005433057418	FBC26D	2930 505221	ELENA TARASOVA	{"phone": "+70317805211"}
0005433057419	FC36C6	5450 949065	ALEKSEY CHERNOV	{"email": "chernov-a1981@postgrespro.ru", "phone": "+70221992084"}
0005433057420	FC36C6	4289 419187	VASILIY SOROKIN	{"phone": "+70906805031"}
0005433057421	6A6E93	3801 098426	ELENA NIKITINA	{"email": "nikitina.elena_111982@postgrespro.ru", "phone": "+70614893278"}
0005433057422	E44983	5669 941082	SEMEN KRASNOV	{"phone": "+70439314402"}
0005433057423	E44983	8152 393252	OKSANA ZAYCEVA	{"phone": "+70967416149"}
0005433057424	D437E5	7489 500641	OLGA ZOTOVA	{"phone": "+70834489545"}
0005433057425	FB4D65	0760 098854	NINA NAUMOVA	{"phone": "+70539079068"}
0005433057426	93EB14	5348 963411	VLADIMIR SHEVCHENKO	{"phone": "+70326139174"}
0005433057427	93EB14	4240 149499	NIKOLAY KUZNECOV	{"phone": "+70423961404"}
0005433057428	953064	0082 379445	NIKOLAY POPOV	{"email": "n-popov15081980@postgrespro.ru", "phone": "+70537280609"}
0005433057429	33E8D3	3224 087572	EKATERINA ZHURAVLEVA	{"email": "e_zhuravleva.1977@postgrespro.ru", "phone": "+70110324375"}
0005433057430	51E31D	5576 954319	OLGA EGOROVA	{"phone": "+70943823957"}
0005433057431	51E31D	5246 768528	ANFISA SCHERBAKOVA	{"email": "anfisascherbakova.031970@postgrespro.ru", "phone": "+70759700519"}
0005433057432	426A18	1767 175958	DARYA IVANOVA	{"email": "ivanovadarya-1967@postgrespro.ru", "phone": "+70134779687"}
0005433057433	E0C054	3604 208878	DMITRIY MIKHAYLOV	{"email": "mikhaylovdmitriy-1972@postgrespro.ru", "phone": "+70741617754"}
0005433057434	694839	0095 931233	MARINA EGOROVA	{"email": "egorova.marina1972@postgrespro.ru", "phone": "+70605113594"}
0005433057435	0F5E66	3920 904628	DMITRIY GRIGOREV	{"phone": "+70543718099"}
0005433057436	D1B6F5	0565 280819	LIDIYA KOROLEVA	{"email": "lidiya.koroleva-09091978@postgrespro.ru", "phone": "+70156561251"}
0005433057437	EB6D2C	5703 062800	MARIYA KUZNECOVA	{"email": "mariyakuznecova.07071971@postgrespro.ru", "phone": "+70835267664"}
0005433057438	010513	4326 126010	VLADIMIR ALEKSEEV	{"email": "alekseev-vladimir-1964@postgrespro.ru", "phone": "+70247373008"}
0005433057439	EEBC92	4983 568567	VYACHESLAV DENISOV	{"email": "vyacheslavdenisov.03081975@postgrespro.ru", "phone": "+70498776216"}
0005433057440	FBA066	4812 536614	ALEKSEY KAZAKOV	{"email": "kazakov.a-04021964@postgrespro.ru", "phone": "+70291288657"}
0005433057441	F327FB	8540 160859	OLGA VLASOVA	{"phone": "+70343620882"}
0005433057442	5ACA5C	7632 411521	EVDOKIYA SERGEEVA	{"email": "evdokiya-sergeeva1975@postgrespro.ru", "phone": "+70852196158"}
0005433057443	5ACA5C	0017 985044	DMITRIY BORISOV	{"phone": "+70629105135"}
0005433057444	B8DB66	1902 448249	IRINA FOMINA	{"phone": "+70223180698"}
0005433057445	E2EF67	9146 819740	LIDIYA TIKHONOVA	{"email": "tikhonova-lidiya-27061975@postgrespro.ru", "phone": "+70795558551"}
0005433057446	E2EF67	9133 119775	NINA ALEKSEEVA	{"phone": "+70956192993"}
0005433057447	C58066	1607 884624	MIKHAIL EGOROV	{"email": "egorov_mikhail_28121958@postgrespro.ru", "phone": "+70680439457"}
0005433057448	C58066	3628 635241	VERA MOROZOVA	{"email": "morozova.vera.14121973@postgrespro.ru", "phone": "+70447564833"}
0005433057449	C53C3B	2909 981796	SERGEY OSIPOV	{"email": "osipov-sergey1972@postgrespro.ru", "phone": "+70620178591"}
0005433057450	C53C3B	7176 670526	EVGENIY ALEKSANDROV	{"email": "evgeniy_aleksandrov25091976@postgrespro.ru", "phone": "+70458990771"}
0005433057451	9B6C84	9575 039866	EKATERINA KUZNECOVA	{"phone": "+70741161102"}
0005433057510	414A1D	6674 275923	ANATOLIY EGOROV	{"phone": "+70149900715"}
0005433057452	9B6C84	1334 090190	DMITRIY SOKOLOV	{"email": "d.sokolov_1972@postgrespro.ru", "phone": "+70384175838"}
0005433057453	9B6C84	8860 287589	MARINA KULIKOVA	{"phone": "+70346845407"}
0005433057454	9B6C84	4793 823728	YURIY BARANOV	{"email": "yuriy_baranov-1965@postgrespro.ru", "phone": "+70409820292"}
0005433057455	9F42DB	3982 247438	EKATERINA MASLOVA	{"phone": "+70857737070"}
0005433057456	8BD079	4776 325598	IRINA IVANOVA	{"email": "ivanova-i-09081979@postgrespro.ru", "phone": "+70234442344"}
0005433057457	BD46DF	6796 882885	DIANA BOGDANOVA	{"phone": "+70824403458"}
0005433057458	BD46DF	8801 806967	ANDREY MIRONOV	{"phone": "+70679842540"}
0005433057459	BD46DF	1730 607307	LYUBOV KISELEVA	{"phone": "+70938069707"}
0005433057460	F99E7C	5814 139780	REGINA LUKYANOVA	{"email": "regina.lukyanova-1974@postgrespro.ru", "phone": "+70468658309"}
0005433057461	594A74	9308 873826	TAMARA MAKAROVA	{"email": "tamara-makarova_1971@postgrespro.ru", "phone": "+70791434592"}
0005433057462	594A74	9246 195758	TATYANA MASLOVA	{"phone": "+70614287118"}
0005433057463	594A74	5588 482218	SVETLANA OSIPOVA	{"phone": "+70320969514"}
0005433057464	7784C4	9540 302700	VALERIY MEDVEDEV	{"email": "vmedvedev.1965@postgrespro.ru", "phone": "+70006769305"}
0005433057465	2FE6CA	7195 110000	ALENA SERGEEVA	{"phone": "+70948253970"}
0005433057466	FA5890	1952 510652	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-1977@postgrespro.ru", "phone": "+70992031185"}
0005433057467	15D26D	9625 131954	ANDREY SOROKIN	{"phone": "+70758030835"}
0005433057468	3F6A3E	6301 934656	OLEG SAVELEV	{"email": "o-savelev.011960@postgrespro.ru", "phone": "+70305309921"}
0005433057469	3F6A3E	0508 576624	OLEG TARASOV	{"phone": "+70777361858"}
0005433057470	DB9D49	5409 850598	ANNA FILIPPOVA	{"phone": "+70071342889"}
0005433057471	2D9123	0253 776227	MAKSIM ORLOV	{"email": "maksim.orlov.22071985@postgrespro.ru", "phone": "+70289135499"}
0005433057472	2D9123	1054 339510	ROMAN KOZLOV	{"phone": "+70227448341"}
0005433057473	E89239	4198 866394	MARGARITA ALEKSANDROVA	{"phone": "+70868383731"}
0005433057474	228235	7761 524877	ANNA POPOVA	{"email": "apopova-031971@postgrespro.ru", "phone": "+70770067333"}
0005433057475	228235	8391 257628	VIKTOR YAKOVLEV	{"phone": "+70850795049"}
0005433057476	473468	1123 579876	POLINA FOMINA	{"phone": "+70570725416"}
0005433057477	473468	0502 756998	VYACHESLAV STEPANOV	{"phone": "+70661477968"}
0005433057478	DFED8F	1250 982742	NIKOLAY FEDOTOV	{"email": "n.fedotov-1978@postgrespro.ru", "phone": "+70858297203"}
0005433057479	E3AA69	8418 840426	ANNA EGOROVA	{"phone": "+70031670621"}
0005433057480	7960C8	4509 955559	EVGENIY ABRAMOV	{"email": "eabramov-011983@postgrespro.ru", "phone": "+70350979239"}
0005433057481	A637AD	1747 078226	VIKTOR KUZNECOV	{"phone": "+70889223733"}
0005433057482	9D97C9	4649 698717	SERGEY KUZNECOV	{"phone": "+70083314005"}
0005433057483	5DD692	8230 275458	ROMAN NAUMOV	{"email": "roman.naumov-051962@postgrespro.ru", "phone": "+70706569448"}
0005433057484	5DD692	4727 199656	MARIYA KOROLEVA	{"phone": "+70586088219"}
0005433057485	10BCF6	0374 616867	ALEKSANDR IVANOV	{"email": "a-ivanov-091958@postgrespro.ru", "phone": "+70656247661"}
0005433057486	70F288	2572 511612	VIKTOR BORISOV	{"email": "viktor-borisov_081969@postgrespro.ru", "phone": "+70156318785"}
0005433057487	5117DF	3799 740068	IRINA ANDREEVA	{"phone": "+70937176160"}
0005433057488	5117DF	1481 002715	VYACHESLAV KUZNECOV	{"phone": "+70125963963"}
0005433057489	BF6649	2477 069613	ALEKSANDR KUZNECOV	{"phone": "+70653561606"}
0005433057490	E440F6	0549 215241	EGOR KULIKOV	{"email": "egorkulikov.061966@postgrespro.ru", "phone": "+70455005685"}
0005433057491	E440F6	1894 805822	ILYA ZHURAVLEV	{"phone": "+70139290131"}
0005433057492	E440F6	8409 225011	PAVEL VOLKOV	{"phone": "+70910152192"}
0005433057493	BC4F9C	7167 504985	EVGENIY ALEKSEEV	{"phone": "+70530440360"}
0005433057494	4277FC	4790 883548	VASILIY MIRONOV	{"phone": "+70421402522"}
0005433057495	B5CFA9	5488 132945	ANDREY ILIN	{"email": "andrey-ilin-1975@postgrespro.ru", "phone": "+70664029274"}
0005433057496	E69515	3020 948794	YURIY ZHURAVLEV	{"phone": "+70338108828"}
0005433057497	811DF2	6690 239720	POLINA SCHERBAKOVA	{"email": "p.scherbakova_29111971@postgrespro.ru", "phone": "+70589870517"}
0005433057498	811DF2	8192 048789	ALEKSANDR ANDREEV	{"phone": "+70193162638"}
0005433057499	1A57BA	0601 956291	IRINA POPOVA	{"email": "popova_i_20081971@postgrespro.ru", "phone": "+70708960540"}
0005433057500	AC565A	2290 267157	IRINA RODIONOVA	{"phone": "+70535240411"}
0005433057501	975578	2815 481336	OLEG TIMOFEEV	{"phone": "+70159344948"}
0005433057502	975578	7639 715903	DENIS SHEVCHENKO	{"phone": "+70993038330"}
0005433057503	A07A8F	5406 922138	LYUDMILA TITOVA	{"phone": "+70690728656"}
0005433057504	A07A8F	7363 740891	FAINA SEMENOVA	{"email": "semenova.f10081980@postgrespro.ru", "phone": "+70451871839"}
0005433057505	3483B2	9118 846344	VALENTINA MELNIKOVA	{"email": "melnikova-valentina.07031973@postgrespro.ru", "phone": "+70391356592"}
0005433057506	3483B2	9547 467246	VIKTOR SEMENOV	{"email": "viktor_semenov061981@postgrespro.ru", "phone": "+70739764669"}
0005433057507	2D4CFA	3527 000169	MAKSIM KISELEV	{"email": "kiselev-m_1972@postgrespro.ru", "phone": "+70087443839"}
0005433057508	3B70EC	3657 852471	ANNA GUSEVA	{"email": "gusevaa.041973@postgrespro.ru", "phone": "+70892517162"}
0005433057509	F3973E	6773 983346	VALENTINA POPOVA	{"phone": "+70638194690"}
0005433057511	4390ED	5018 016565	IVAN FEDOTOV	{"phone": "+70485056712"}
0005433057512	B53730	7754 440297	SERGEY KUZNECOV	{"email": "sergey.kuznecov-021968@postgrespro.ru", "phone": "+70764959399"}
0005433057513	51ABA9	9386 370224	TATYANA ANDREEVA	{"email": "andreevatatyana.27041971@postgrespro.ru", "phone": "+70600128345"}
0005433057514	1AB10A	2796 824578	FANIYA KOZLOVA	{"phone": "+70047775043"}
0005433057515	9441EF	2520 129515	DENIS SEMENOV	{"email": "semenov.d101971@postgrespro.ru", "phone": "+70035407507"}
0005433057516	BD0B84	3053 920717	SERGEY TARASOV	{"phone": "+70820706251"}
0005433057517	B30643	0394 920546	ANTONINA EFREMOVA	{"phone": "+70379770096"}
0005433057518	B30643	8720 122167	ELENA POPOVA	{"email": "popovae27011972@postgrespro.ru", "phone": "+70200134467"}
0005433057519	C79DAA	6992 863702	VASILIY CHERNOV	{"email": "v.chernov.12011979@postgrespro.ru", "phone": "+70853999576"}
0005433057520	1AC386	4752 964279	GLEB KAZAKOV	{"email": "gleb_kazakov.061982@postgrespro.ru", "phone": "+70999166724"}
0005433057521	293EE9	9147 154670	NIKOLAY MOISEEV	{"email": "moiseevn_11071969@postgrespro.ru", "phone": "+70373603400"}
0005433057522	0D84DB	4076 249760	RUSLAN MOROZOV	{"email": "morozov-r_14071981@postgrespro.ru", "phone": "+70075295774"}
0005433057523	0D84DB	7398 342906	EKATERINA ANDREEVA	{"email": "e_andreeva1966@postgrespro.ru", "phone": "+70243970939"}
0005433057524	6B38B0	9415 729683	EVGENIY ANTONOV	{"phone": "+70326118633"}
0005433057525	43C787	7821 351458	MIKHAIL MAKAROV	{"email": "mikhailmakarov-1985@postgrespro.ru", "phone": "+70041288352"}
0005433057526	55819B	0371 061072	IVAN ANDREEV	{"phone": "+70443730468"}
0005433057527	55819B	2250 157049	ANATOLIY ZHUKOV	{"phone": "+70380557587"}
0005433057528	4B58F5	1533 293151	SERGEY NOVIKOV	{"email": "s.novikov-03091973@postgrespro.ru", "phone": "+70264264852"}
0005433057529	689D80	7189 822187	ANNA FOMINA	{"phone": "+70299856076"}
0005433057530	104488	5645 551610	ZHANNA KOROLEVA	{"phone": "+70921517243"}
0005433057531	104488	1979 711499	ELIZAVETA KISELEVA	{"phone": "+70699329933"}
0005433057532	8D457B	2210 330715	SERGEY DMITRIEV	{"email": "s_dmitriev_011959@postgrespro.ru", "phone": "+70955275322"}
0005433057533	DC029D	7428 158410	MARIYA OSIPOVA	{"email": "osipova_mariya_1970@postgrespro.ru", "phone": "+70050518478"}
0005433057534	DC029D	1171 285918	ANDREY MIKHAYLOV	{"email": "a_mikhaylov-121979@postgrespro.ru", "phone": "+70065114455"}
0005433057535	FDC5A6	1082 077356	EVGENIY SCHERBAKOV	{"phone": "+70335903866"}
0005433057536	FDC5A6	2768 835861	YURIY SOKOLOV	{"email": "y.sokolov1974@postgrespro.ru", "phone": "+70160752098"}
0005433057537	C28753	8122 267358	ANDREY KAZAKOV	{"email": "kazakovandrey-30041970@postgrespro.ru", "phone": "+70408858396"}
0005433057538	780014	2719 646303	DMITRIY DAVYDOV	{"email": "davydov.dmitriy-02101966@postgrespro.ru", "phone": "+70505060459"}
0005433057539	780014	6339 544527	OLESYA KALININA	{"phone": "+70539831050"}
0005433057540	CC6005	2073 933911	KSENIYA STEPANOVA	{"phone": "+70065425392"}
0005433057541	CC6005	7149 127621	SERGEY BARANOV	{"phone": "+70173091208"}
0005433057542	1B8F75	5272 098859	ANZHELIKA DENISOVA	{"phone": "+70465780278"}
0005433057543	1B8F75	1343 308192	VALENTINA SOROKINA	{"email": "valentina_sorokina-1979@postgrespro.ru", "phone": "+70108191516"}
0005433057544	2BEDE2	7397 147334	TATYANA MATVEEVA	{"email": "t-matveeva.16031986@postgrespro.ru", "phone": "+70719253052"}
0005433057545	257126	5105 626300	SVETLANA BARANOVA	{"email": "svetlana.baranova-1964@postgrespro.ru", "phone": "+70878493231"}
0005433057546	E79364	0428 973002	IRINA MAKAROVA	{"email": "irina.makarova061980@postgrespro.ru", "phone": "+70004025725"}
0005433057547	FFB6DB	0535 009736	OLGA BARANOVA	{"phone": "+70497233081"}
0005433057548	B68EE4	7226 329674	YULIYA DENISOVA	{"phone": "+70257424873"}
0005433057549	19BEBE	8267 991864	NIKOLAY KRASNOV	{"phone": "+70493160786"}
0005433057550	1939A1	8279 710836	VALERIY PAVLOV	{"email": "pavlov.valeriy051976@postgrespro.ru", "phone": "+70364295183"}
0005433057551	1939A1	4804 776694	STANISLAV SOKOLOV	{"phone": "+70099211708"}
0005433057552	F9710F	1433 854623	VALENTINA PETROVA	{"email": "petrova-valentina-1971@postgrespro.ru", "phone": "+70974026828"}
0005433057553	EF83B5	4091 251067	ANASTASIYA GAVRILOVA	{"phone": "+70328916110"}
0005433057554	EF83B5	5371 813973	KIRILL BELOV	{"email": "belov_k.031962@postgrespro.ru", "phone": "+70544584777"}
0005433057555	6CA87F	4645 311913	PAVEL KUZNECOV	{"email": "pavelkuznecov-06101970@postgrespro.ru", "phone": "+70076874247"}
0005433057556	6CA87F	9670 081021	TATYANA TARASOVA	{"email": "tarasova.t1968@postgrespro.ru", "phone": "+70545409936"}
0005433057557	B150B3	8165 017069	IVAN ZHURAVLEV	{"email": "ivan.zhuravlev-18031981@postgrespro.ru", "phone": "+70555022805"}
0005433057558	3707FE	0610 133667	OLGA IVANOVA	{"phone": "+70778349482"}
0005433057559	3707FE	5007 788240	ALEKSEY ALEKSANDROV	{"email": "aleksandrov-a-041973@postgrespro.ru", "phone": "+70653275472"}
0005433057560	395800	9057 038248	NIKOLAY SOLOVEV	{"phone": "+70058819735"}
0005433057561	00893C	3900 150182	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir_081965@postgrespro.ru", "phone": "+70075634729"}
0005433057562	00893C	0547 810259	VALERIY MATVEEV	{"email": "matveev-v.091969@postgrespro.ru", "phone": "+70904248375"}
0005433057563	C00CBB	3861 102642	DMITRIY ANDREEV	{"email": "andreev-d-29051983@postgrespro.ru", "phone": "+70093567919"}
0005433057564	C00CBB	2189 510337	EVGENIY OSIPOV	{"phone": "+70046018232"}
0005433057565	815251	9611 147201	GEORGIY ILIN	{"email": "ilin_georgiy1970@postgrespro.ru", "phone": "+70419449792"}
0005433057566	6E4A1A	8629 963019	SVETLANA KOROLEVA	{"phone": "+70340777799"}
0005433057567	6E4A1A	5933 370952	EKATERINA YAKOVLEVA	{"email": "eyakovleva-1970@postgrespro.ru", "phone": "+70542603732"}
0005433057568	816DA6	1882 121731	NINA DMITRIEVA	{"phone": "+70033150700"}
0005433057569	248F66	4356 947862	ANASTASIYA GORBUNOVA	{"email": "a-gorbunova_05071969@postgrespro.ru", "phone": "+70726816036"}
0005433057570	248F66	8247 002383	MARIYA KISELEVA	{"phone": "+70530393965"}
0005433057571	248F66	9759 829274	NIKOLAY KONOVALOV	{"phone": "+70140857641"}
0005433057572	248F66	2024 491954	ANASTASIYA KRASNOVA	{"email": "a-krasnova_041973@postgrespro.ru", "phone": "+70022783463"}
0005433057573	232BB2	7425 299460	GALINA ZAYCEVA	{"phone": "+70568137648"}
0005433057574	F74B7D	2778 558953	ALEKSANDR GUSEV	{"email": "a.gusev_021965@postgrespro.ru", "phone": "+70088970801"}
0005433057575	F74B7D	2300 651206	ARMEN KOZLOV	{"phone": "+70285544028"}
0005433057576	F74B7D	9595 017971	ANDREY SIDOROV	{"phone": "+70455540372"}
0005433057577	DD0DC2	2443 328098	ANNA SERGEEVA	{"email": "sergeevaanna.1966@postgrespro.ru", "phone": "+70732255548"}
0005433057578	6D6349	3779 566603	LIDIYA KOLESNIKOVA	{"phone": "+70581361301"}
0005433057579	6D6349	1419 198576	OLGA LOGINOVA	{"email": "olga-loginova17081974@postgrespro.ru", "phone": "+70770859640"}
0005433057580	CED71D	1144 377825	ALEKSANDRA SOKOLOVA	{"email": "sokolova_a_21021978@postgrespro.ru", "phone": "+70963630393"}
0005433057581	D47248	4835 736325	VLADIMIR DMITRIEV	{"email": "dmitriev_v05031973@postgrespro.ru", "phone": "+70595350709"}
0005433057582	D47248	5080 663097	ALBERT SHEVCHENKO	{"email": "shevchenko_albert091968@postgrespro.ru", "phone": "+70540051381"}
0005433057583	6B9C4B	8240 028612	NADEZHDA VLASOVA	{"phone": "+70540169310"}
0005433057584	6B9C4B	8945 818773	LARISA KONDRATEVA	{"email": "kondrateva_l1968@postgrespro.ru", "phone": "+70871599819"}
0005433057585	D670D5	2247 571660	ANDREY EGOROV	{"phone": "+70287201059"}
0005433057586	D670D5	1802 426409	TATYANA KUZNECOVA	{"phone": "+70402847243"}
0005433057587	271E4A	9079 372284	EVGENIY MIRONOV	{"phone": "+70347453028"}
0005433057588	426360	6381 291993	ANASTASIYA POPOVA	{"email": "popova_anastasiya_021970@postgrespro.ru", "phone": "+70066858174"}
0005433057589	0BE809	3500 943176	VLADIMIR TIMOFEEV	{"phone": "+70961270768"}
0005433057590	9F34A1	0024 010870	GALINA SERGEEVA	{"phone": "+70742668258"}
0005433057591	A09747	9037 266380	LYUDMILA KISELEVA	{"email": "lyudmila_kiseleva-1984@postgrespro.ru", "phone": "+70614618408"}
0005433057592	A09747	4428 866655	NIKOLAY KOROLEV	{"phone": "+70453510521"}
0005433057593	F70C13	5816 071612	ALEKSANDR FEDOTOV	{"phone": "+70702619149"}
0005433057594	D9AD03	4608 895041	NIKOLAY SMIRNOV	{"email": "smirnov-n-1960@postgrespro.ru", "phone": "+70258685846"}
0005433057595	D9AD03	2767 790778	LYUBOV ROMANOVA	{"email": "romanova.lyubov_051971@postgrespro.ru", "phone": "+70716198263"}
0005433057596	24E746	1358 722976	IGOR VOROBEV	{"phone": "+70697858006"}
0005433057597	EE0A48	4340 893994	MARIYA ANDREEVA	{"email": "andreeva-mariya_1970@postgrespro.ru", "phone": "+70870491607"}
0005433057598	65211C	7351 171977	NATALIYA SMIRNOVA	{"email": "smirnova.n.081965@postgrespro.ru", "phone": "+70348092404"}
0005433057599	D1856A	1090 486455	KONSTANTIN IVANOV	{"email": "ivanov.konstantin-1989@postgrespro.ru", "phone": "+70875473344"}
0005433057600	FA7744	7012 445025	RIMMA FROLOVA	{"phone": "+70571978980"}
0005433057601	6C4D48	3659 820827	VYACHESLAV PAVLOV	{"email": "pavlov.vyacheslav_1975@postgrespro.ru", "phone": "+70843978562"}
0005433057602	1DE1F0	2015 536150	VALENTINA LEBEDEVA	{"email": "valentina-lebedeva_011968@postgrespro.ru", "phone": "+70130102332"}
0005433057603	1DE1F0	7906 683947	IVAN IVANOV	{"email": "ivanov-i_081964@postgrespro.ru", "phone": "+70147803505"}
0005433057604	CF957E	4039 269026	VALENTINA VASILEVA	{"email": "vasilevavalentina051978@postgrespro.ru", "phone": "+70199639561"}
0005433057605	A2DF30	8635 819450	SVETLANA FADEEVA	{"phone": "+70028539741"}
0005433057606	A2DF30	7059 921278	LYUDMILA IVANOVA	{"phone": "+70731219298"}
0005433057607	AFF259	9262 258094	ALEKSANDR TARASOV	{"phone": "+70734946162"}
0005433057608	8438B8	7803 184778	ELENA POPOVA	{"phone": "+70329445048"}
0005433057609	8438B8	8672 743854	GALINA MOROZOVA	{"phone": "+70033620385"}
0005433057610	1975F6	7901 711364	MARIYA ORLOVA	{"email": "orlova-m_19081979@postgrespro.ru", "phone": "+70783391170"}
0005433057611	1975F6	2779 260610	ANNA ANISIMOVA	{"phone": "+70198405820"}
0005433057612	1975F6	3600 511267	ALEKSANDR SOLOVEV	{"phone": "+70116421611"}
0005433057613	92DB49	5759 993944	MIKHAIL NAUMOV	{"email": "naumov-mikhail-1970@postgrespro.ru", "phone": "+70178050470"}
0005433057614	F908F5	2397 393152	SVETLANA KUZNECOVA	{"email": "s.kuznecova_1977@postgrespro.ru", "phone": "+70567256537"}
0005433057615	F908F5	5483 896040	DIANA MOROZOVA	{"phone": "+70322601925"}
0005433057616	C877AA	9116 124461	VADIM TIKHONOV	{"email": "tikhonovv.071964@postgrespro.ru", "phone": "+70390662751"}
0005433057617	78B0B7	4579 841355	ANNA KUDRYASHOVA	{"phone": "+70582713252"}
0005433057618	78B0B7	3335 738893	IGOR BARANOV	{"phone": "+70047541853"}
0005433057619	AB8A30	0027 839655	ANDREY KONOVALOV	{"phone": "+70258968003"}
0005433057620	AB8A30	9237 688984	NIKOLAY ALEKSANDROV	{"email": "nikolay_aleksandrov_07091971@postgrespro.ru", "phone": "+70861277587"}
0005433057621	034F85	7105 640795	NADEZHDA POLYAKOVA	{"email": "polyakova_nadezhda_051982@postgrespro.ru", "phone": "+70373704755"}
0005433057622	7AC43C	6430 152635	KLAVDIYA YAKOVLEVA	{"phone": "+70229987689"}
0005433057623	4062C9	7147 890275	ELENA ISAEVA	{"email": "e.isaeva_13121965@postgrespro.ru", "phone": "+70644625100"}
0005433057624	DF5969	0026 825500	RAISA VASILEVA	{"email": "rvasileva_031970@postgrespro.ru", "phone": "+70313452031"}
0005433057625	9B496F	7231 645041	TATYANA MAKAROVA	{"email": "makarova.tatyana-29121967@postgrespro.ru", "phone": "+70378600370"}
0005433057626	A22113	0183 226013	VIKTORIYA LAZAREVA	{"email": "lazarevaviktoriya_01101961@postgrespro.ru", "phone": "+70652155722"}
0005433057627	8E7F82	4227 639466	LARISA MELNIKOVA	{"email": "melnikova-l11121960@postgrespro.ru", "phone": "+70916047479"}
0005433057628	7190F3	3070 418149	ANTONINA BELYAEVA	{"email": "antoninabelyaeva1965@postgrespro.ru", "phone": "+70398711598"}
0005433057629	3A9871	0064 560972	ALEKSANDR OSIPOV	{"phone": "+70138441544"}
0005433057630	3A9871	5193 921164	SOFIYA MIKHAYLOVA	{"phone": "+70719733528"}
0005433057631	016954	6441 210893	ELENA MOROZOVA	{"phone": "+70164419578"}
0005433057632	6DC8CF	8841 453538	VIKTORIYA LOGINOVA	{"email": "vloginova_1976@postgrespro.ru", "phone": "+70443432883"}
0005433057633	6DC8CF	7141 000307	ANTON DMITRIEV	{"phone": "+70937768398"}
0005433057634	2A4DEB	4843 054335	YANA KISELEVA	{"email": "kiselevayana.1976@postgrespro.ru", "phone": "+70007268421"}
0005433057635	65C91C	0060 179204	ROMAN ALEKSEEV	{"phone": "+70438322214"}
0005433057636	B02757	6638 649452	NINA MELNIKOVA	{"phone": "+70276064672"}
0005433057637	D592DB	0667 126136	IGOR BORISOV	{"email": "igor.borisov01101974@postgrespro.ru", "phone": "+70175977723"}
0005433057638	D4E553	8956 637148	NATALYA VOLKOVA	{"email": "volkova_natalya-021968@postgrespro.ru", "phone": "+70525682767"}
0005433057639	81F4C1	4371 422588	ALEKSANDR VASILEV	{"phone": "+70351009033"}
0005433057640	81F4C1	0258 649462	KSENIYA MIKHAYLOVA	{"phone": "+70249719231"}
0005433057641	A6A2E6	7221 016006	SVETLANA SEMENOVA	{"phone": "+70371659512"}
0005433057642	A6A2E6	3066 085214	ALEKSANDR GERASIMOV	{"phone": "+70643396636"}
0005433057643	A6A2E6	4484 696350	LYUDMILA OSIPOVA	{"email": "osipova.l-121969@postgrespro.ru", "phone": "+70677956492"}
0005433057644	F477A6	2103 474961	POLINA KUZNECOVA	{"phone": "+70664316389"}
0005433057645	AC30BB	5078 545191	ALEKSEY KISELEV	{"phone": "+70512563502"}
0005433057646	AC30BB	1933 624862	RAMIL STEPANOV	{"email": "ramil.stepanov_1969@postgrespro.ru", "phone": "+70416643558"}
0005433057647	32A891	9794 897991	ANATOLIY MELNIKOV	{"phone": "+70356517414"}
0005433057648	C6AB9E	4423 776246	ANASTASIYA ERMAKOVA	{"phone": "+70110430693"}
0005433057649	A33899	8719 842683	YULIYA FROLOVA	{"email": "frolova.y-14021969@postgrespro.ru", "phone": "+70766510369"}
0005433057650	26350D	9467 068469	SERGEY NOVIKOV	{"phone": "+70048937295"}
0005433057651	5A26D9	9689 376102	NIKOLAY ROMANOV	{"phone": "+70647432032"}
0005433057652	331217	9902 057285	TATYANA VOROBEVA	{"email": "tatyana.vorobeva29081968@postgrespro.ru", "phone": "+70026628007"}
0005433057653	E1254E	2893 186306	VALENTINA ARKHIPOVA	{"email": "v.arkhipova-01121969@postgrespro.ru", "phone": "+70605453879"}
0005433057654	E1254E	0591 828442	NATALYA KULIKOVA	{"email": "kulikova_n_111969@postgrespro.ru", "phone": "+70838144863"}
0005433057655	7C1168	7787 215065	IRINA SOROKINA	{"phone": "+70029572506"}
0005433057656	24C7DC	3776 502821	SERGEY MIKHAYLOV	{"email": "mikhaylov_sergey-04011971@postgrespro.ru", "phone": "+70102712544"}
0005433057657	0E6A18	7930 805124	SERGEY PAVLOV	{"email": "pavlov.sergey1964@postgrespro.ru", "phone": "+70324792578"}
0005433057658	0E6A18	8613 160660	MARIYA SOROKINA	{"email": "mariya-sorokina-101966@postgrespro.ru", "phone": "+70786857177"}
0005433057659	FC755D	1489 752529	POLINA SAVELEVA	{"phone": "+70609404167"}
0005433057660	E02C65	9984 047433	VASILIY KISELEV	{"phone": "+70368540766"}
0005433057661	4D3DE8	3918 846789	VIKTOR IVANOV	{"email": "ivanov_v-061961@postgrespro.ru", "phone": "+70599285920"}
0005433057662	4D3DE8	9016 970167	IRINA MAKAROVA	{"phone": "+70181710675"}
0005433057663	922E4F	6152 690879	VALERIYA KONOVALOVA	{"phone": "+70002746317"}
0005433057664	4D16D5	1056 396870	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov1965@postgrespro.ru", "phone": "+70984026128"}
0005433057665	094131	5043 327916	SERGEY ISAEV	{"phone": "+70039557146"}
0005433057666	A2EDB9	0944 442136	ALINA ANISIMOVA	{"email": "anisimova.a1980@postgrespro.ru", "phone": "+70308475244"}
0005433057667	7E750F	4854 621167	ANASTASIYA MIKHAYLOVA	{"phone": "+70440151054"}
0005433057668	EFB722	5082 737662	ANNA EFREMOVA	{"email": "annaefremova1984@postgrespro.ru", "phone": "+70718582215"}
0005433057669	082302	9635 299633	ANDREY SIDOROV	{"email": "sidorov_a_1983@postgrespro.ru", "phone": "+70282095022"}
0005433057670	E97136	8369 234397	EKATERINA KARPOVA	{"email": "karpovae1958@postgrespro.ru", "phone": "+70184972203"}
0005433057671	E97136	3661 507655	NATALYA GRISHINA	{"phone": "+70540557862"}
0005433057672	E7CF5B	5223 894119	ILYA EGOROV	{"phone": "+70448454551"}
0005433057673	673D29	0394 187985	ANDREY KULIKOV	{"phone": "+70181275668"}
0005433057674	A4F4AE	9130 985184	OLGA PAVLOVA	{"phone": "+70613731138"}
0005433057675	A4F4AE	0887 298282	ALEKSANDR VOROBEV	{"phone": "+70774218532"}
0005433057676	DDA57A	7632 752832	VERA FEDOROVA	{"email": "fedorova-vera_12061981@postgrespro.ru", "phone": "+70714747410"}
0005433057677	DE4007	7445 608897	VIKTOR MOROZOV	{"phone": "+70637875334"}
0005433057678	23A5C3	8075 367275	VIKTOR SIDOROV	{"phone": "+70739002979"}
0005433057679	23A5C3	8563 301110	TATYANA ANDREEVA	{"phone": "+70916937754"}
0005433057680	7EE5B0	3006 371364	VASILIY KUZMIN	{"phone": "+70600123089"}
0005433057681	7EE5B0	4675 575008	MARIYA ANISIMOVA	{"email": "mariyaanisimova-101982@postgrespro.ru", "phone": "+70964018707"}
0005433057682	7A1F9A	0536 909724	GALINA KOZLOVA	{"phone": "+70214416170"}
0005433057683	7A1F9A	7373 364701	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko111979@postgrespro.ru", "phone": "+70260385914"}
0005433057684	7A1F9A	7571 839984	RAFIS ALEKSEEV	{"email": "alekseev-r06121977@postgrespro.ru", "phone": "+70397928590"}
0005433057685	0DAF42	4022 323400	LILIYA NIKIFOROVA	{"phone": "+70328590794"}
0005433057686	05B201	4481 254876	NATALYA YUDINA	{"phone": "+70463312023"}
0005433057687	05B201	9927 405565	VLADISLAV NAUMOV	{"email": "naumovv-1973@postgrespro.ru", "phone": "+70634834690"}
0005433057688	4A22A0	0677 199743	LIDIYA KOZLOVA	{"email": "kozloval24021972@postgrespro.ru", "phone": "+70747283447"}
0005433057689	4A22A0	5134 024806	SVETLANA KALININA	{"phone": "+70033275749"}
0005433057690	D172DB	0847 101690	YULIYA POTAPOVA	{"email": "yuliya.potapova_1973@postgrespro.ru", "phone": "+70027889323"}
0005433057691	D172DB	8378 513069	DMITRIY SHEVCHENKO	{"phone": "+70486425405"}
0005433057692	DFD031	6820 951630	ALEKSANDR KRASNOV	{"phone": "+70830748532"}
0005433057693	FEFEAB	8605 090694	LYUDMILA POPOVA	{"email": "l-popova.18061972@postgrespro.ru", "phone": "+70044043659"}
0005433057694	D2A13A	5759 439555	TATYANA SIDOROVA	{"email": "tatyana-sidorova.061970@postgrespro.ru", "phone": "+70741043633"}
0005433057695	BA8FFE	5188 729508	VLADIMIR IVANOV	{"email": "ivanov_vladimir07021980@postgrespro.ru", "phone": "+70307292726"}
0005433057696	AE9D86	1311 482945	SERGEY SERGEEV	{"email": "sergeevs021971@postgrespro.ru", "phone": "+70259543805"}
0005433057697	2C1470	2949 456072	IVAN SERGEEV	{"phone": "+70937331824"}
0005433057698	98B296	7960 767690	ELENA POLYAKOVA	{"phone": "+70797683059"}
0005433057699	98B296	2529 229461	YURIY SOROKIN	{"phone": "+70726604426"}
0005433057700	E09948	3080 095231	ALENA CHERNOVA	{"phone": "+70800920298"}
0005433057701	A3CC58	8834 471033	DAVID BONDARENKO	{"email": "bondarenko-david.031988@postgrespro.ru", "phone": "+70678213883"}
0005433057702	E0A28D	2333 658752	VALERIY BARANOV	{"email": "baranov_valeriy-30101975@postgrespro.ru", "phone": "+70425494752"}
0005433057703	0B92BD	7367 773422	ALEKSANDR POPOV	{"phone": "+70885786283"}
0005433057704	8C51F4	2851 189407	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev_27111963@postgrespro.ru", "phone": "+70200490781"}
0005433057705	34C42C	4148 060430	YURIY ZAYCEV	{"email": "yuriy_zaycev-1979@postgrespro.ru", "phone": "+70288098472"}
0005433057706	34C42C	3774 740208	ANTONINA ABRAMOVA	{"phone": "+70454285212"}
0005433057707	DBFDEE	1259 234977	VALENTINA KUZMINA	{"email": "valentina_kuzmina-26111976@postgrespro.ru", "phone": "+70504270093"}
0005433057708	58B0E3	8586 280847	ALEKSEY MELNIKOV	{"email": "a-melnikov-25101967@postgrespro.ru", "phone": "+70250497913"}
0005433057709	58B0E3	5421 426790	EVGENIY BONDARENKO	{"phone": "+70300546245"}
0005433057710	C6F7D6	5486 922615	KIRILL MEDVEDEV	{"email": "k.medvedev.081965@postgrespro.ru", "phone": "+70395527924"}
0005433057711	C6F7D6	1557 097202	NIKOLAY NIKITIN	{"email": "nikolay.nikitin.07091973@postgrespro.ru", "phone": "+70982573578"}
0005433057712	271B5B	6239 024505	ANTONINA BORISOVA	{"phone": "+70767639058"}
0005433057713	DADF85	2039 336776	DENIS POPOV	{"phone": "+70714551410"}
0005433057714	AF3214	0553 926348	TATYANA KAZAKOVA	{"email": "tatyana.kazakova_26041974@postgrespro.ru", "phone": "+70941749255"}
0005433057715	AF3214	4636 401485	IGOR ZHURAVLEV	{"phone": "+70741122677"}
0005433057716	ED6AD7	7691 337020	ANDREY NAZAROV	{"phone": "+70953951301"}
0005433057717	ED6AD7	1968 194585	ARTEM GERASIMOV	{"email": "artem.gerasimov08061982@postgrespro.ru", "phone": "+70203699449"}
0005433057718	81DBBD	6401 504480	ANASTASIYA NAZAROVA	{"phone": "+70677888106"}
0005433057719	C928D0	0737 664557	SERGEY EGOROV	{"email": "egorov.sergey-051965@postgrespro.ru", "phone": "+70120447975"}
0005433057720	33F809	3800 444876	ROMAN KONOVALOV	{"phone": "+70141227069"}
0005433057721	C5C5E6	0841 463411	LYUDMILA NOVIKOVA	{"email": "l-novikova091971@postgrespro.ru", "phone": "+70696373721"}
0005433057722	21103C	5863 150329	EKATERINA BORISOVA	{"phone": "+70208480372"}
0005433057723	FDC341	6749 483655	NIKOLAY ZHURAVLEV	{"email": "n-zhuravlev_1979@postgrespro.ru", "phone": "+70859977570"}
0005433057783	51B8B6	0125 738286	VLADIMIR ORLOV	{"phone": "+70618562513"}
0005433057724	FDC341	6607 339103	YAROSLAVA NESTEROVA	{"email": "nesterovay081957@postgrespro.ru", "phone": "+70631375865"}
0005433057725	130E4A	3647 791078	VIKTOR MIRONOV	{"phone": "+70113741543"}
0005433057726	52252D	9632 442004	SERGEY KUZNECOV	{"phone": "+70262734560"}
0005433057727	7E8E23	7076 835378	VLADISLAV KUZNECOV	{"email": "kuznecovv121984@postgrespro.ru", "phone": "+70149369958"}
0005433057728	7E8E23	7537 554155	VLADIMIR EGOROV	{"phone": "+70110280655"}
0005433057729	961DF1	9289 251835	LYUBOV DANILOVA	{"phone": "+70412856182"}
0005433057730	D605E0	6443 020024	VALENTINA KONDRATEVA	{"email": "valentinakondrateva02121965@postgrespro.ru", "phone": "+70082072122"}
0005433057731	20D389	1697 459930	VLADIMIR PETROV	{"email": "vladimir.petrov011961@postgrespro.ru", "phone": "+70199836302"}
0005433057732	50343D	4314 248302	GRIGORIY AFANASEV	{"email": "grigoriyafanasev.1962@postgrespro.ru", "phone": "+70601648818"}
0005433057733	561FBF	0241 060754	LYUDMILA LOGINOVA	{"phone": "+70897601940"}
0005433057734	561FBF	2448 807209	TATYANA VOLKOVA	{"email": "tatyanavolkova-081978@postgrespro.ru", "phone": "+70228028763"}
0005433057735	3E0616	6492 084475	YULIYA MAKAROVA	{"phone": "+70062841031"}
0005433057736	BD0679	2180 813349	ALEKSANDR ANTONOV	{"phone": "+70561906045"}
0005433057737	F049AB	6696 388043	ALEVTINA VOROBEVA	{"email": "vorobeva_a_081968@postgrespro.ru", "phone": "+70604534139"}
0005433057738	F049AB	2190 554164	TATYANA SERGEEVA	{"email": "tatyanasergeeva26051972@postgrespro.ru", "phone": "+70364086794"}
0005433057739	596C7F	4891 314490	ALEKSANDRA ANISIMOVA	{"phone": "+70489307147"}
0005433057740	64D1CB	9112 552594	MARINA POPOVA	{"email": "popovam.101967@postgrespro.ru", "phone": "+70907258796"}
0005433057741	64D1CB	8140 717397	NATALIYA SIDOROVA	{"phone": "+70611858886"}
0005433057742	64D1CB	4687 570789	NIKOLAY RODIONOV	{"email": "rodionov.nikolay_031980@postgrespro.ru", "phone": "+70524653941"}
0005433057743	C67906	2393 719741	DENIS SERGEEV	{"phone": "+70604480886"}
0005433057744	C67906	2599 442324	DMITRIY SCHERBAKOV	{"email": "scherbakov.dmitriy.051975@postgrespro.ru", "phone": "+70453511103"}
0005433057745	D50053	6564 698746	ARKADIY OSIPOV	{"email": "a_osipov-1970@postgrespro.ru", "phone": "+70138310798"}
0005433057746	D50053	4011 704483	LYUDMILA KUZNECOVA	{"phone": "+70688012588"}
0005433057747	7B7D16	2572 732428	ALEKSANDR BELOV	{"email": "aleksandr_belov.06101974@postgrespro.ru", "phone": "+70219101323"}
0005433057748	7B7D16	6312 570691	MAKSIM VLASOV	{"phone": "+70238470687"}
0005433057749	6BA0A3	1495 351508	TATYANA KUZNECOVA	{"email": "kuznecova-t.1962@postgrespro.ru", "phone": "+70353572934"}
0005433057750	63788A	2701 235600	ELENA ZAKHAROVA	{"phone": "+70730957097"}
0005433057751	80CC81	2987 879932	MILANA LOGINOVA	{"phone": "+70696229414"}
0005433057752	80CC81	1532 399486	IVAN MIKHAYLOV	{"email": "i-mikhaylov-031978@postgrespro.ru", "phone": "+70230230166"}
0005433057753	DB2A4C	0567 253632	ANNA SOROKINA	{"phone": "+70959417078"}
0005433057754	0B1551	0689 644099	GENNADIY BORISOV	{"email": "g-borisov-10081970@postgrespro.ru", "phone": "+70051832390"}
0005433057755	6AFE7A	2158 808755	ALEKSEY SMIRNOV	{"email": "smirnovaleksey-071969@postgrespro.ru", "phone": "+70222236269"}
0005433057756	6AFE7A	1246 084892	RAISA KUZNECOVA	{"phone": "+70012550019"}
0005433057757	2FEF1B	5666 816755	MAKSIM KOROLEV	{"phone": "+70946773054"}
0005433057758	474524	7125 232009	MIKHAIL VASILEV	{"email": "mikhailvasilev-061979@postgrespro.ru", "phone": "+70806160126"}
0005433057759	7CFF30	3111 652186	LYUDMILA KUDRYASHOVA	{"phone": "+70950822569"}
0005433057760	BA9B88	4540 143022	IRAIDA KAZAKOVA	{"email": "kazakova.iraida.111978@postgrespro.ru", "phone": "+70512810908"}
0005433057761	4A26BE	7717 641303	ANDREY VOLKOV	{"email": "volkov.andrey.061972@postgrespro.ru", "phone": "+70580008497"}
0005433057762	8D1116	0087 718039	VLADISLAV ANDREEV	{"phone": "+70266870430"}
0005433057763	8D1116	7216 737307	DANIIL TIMOFEEV	{"phone": "+70952074650"}
0005433057764	D9A536	5603 961706	GENNADIY IVANOV	{"phone": "+70331217231"}
0005433057765	84F5A3	8813 764402	IRINA LAZAREVA	{"email": "irina_lazareva_111977@postgrespro.ru", "phone": "+70759217743"}
0005433057766	862F9B	5011 402801	IVAN MATVEEV	{"email": "matveev_ivan_1966@postgrespro.ru", "phone": "+70618575066"}
0005433057767	862F9B	4138 797318	ANDREY SOKOLOV	{"email": "andrey-sokolov-12051973@postgrespro.ru", "phone": "+70913174861"}
0005433057768	7B060C	0505 748723	DMITRIY STEPANOV	{"email": "dmitriy-stepanov-061974@postgrespro.ru", "phone": "+70671185929"}
0005433057769	7B060C	9221 438697	ELENA FILATOVA	{"phone": "+70353480376"}
0005433057770	7B060C	2790 336877	NADEZHDA RODIONOVA	{"phone": "+70518654440"}
0005433057771	6DC318	7047 792254	ALEKSANDR SEMENOV	{"phone": "+70187654254"}
0005433057772	6DC318	5165 508489	ANTONINA BOGDANOVA	{"phone": "+70585783919"}
0005433057773	C9B090	5004 900769	VITALIY ROMANOV	{"email": "vitaliy-romanov-081958@postgrespro.ru", "phone": "+70887149119"}
0005433057774	C53FA5	5436 348895	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy_071969@postgrespro.ru", "phone": "+70776959397"}
0005433057775	9AA20E	5039 621489	PAVEL NIKITIN	{"phone": "+70307848540"}
0005433057776	D2A5A0	9429 959105	EVGENIY ANTONOV	{"email": "antonov_e_1978@postgrespro.ru", "phone": "+70000814634"}
0005433057777	D2A5A0	8602 494920	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko.23061974@postgrespro.ru", "phone": "+70906940176"}
0005433057778	592EEB	7473 902272	EVGENIY BORISOV	{"email": "e-borisov_17071970@postgrespro.ru", "phone": "+70955335927"}
0005433057779	56C34E	0442 380187	YANA SAVELEVA	{"email": "savelevay_1971@postgrespro.ru", "phone": "+70510017790"}
0005433057780	20E45D	8774 357779	DENIS TIKHONOV	{"email": "tikhonovdenis.101965@postgrespro.ru", "phone": "+70612214837"}
0005433057781	20E45D	0149 518792	NADEZHDA KOMAROVA	{"phone": "+70479518007"}
0005433057782	3330AA	1394 931317	NATALYA AFANASEVA	{"email": "afanasevanatalya.1981@postgrespro.ru", "phone": "+70985266379"}
0005433057784	130093	3606 600605	ANDREY NOVIKOV	{"email": "novikov.a.121973@postgrespro.ru", "phone": "+70277475726"}
0005433057785	130093	6192 411247	DANIIL PAVLOV	{"email": "d-pavlov_1988@postgrespro.ru", "phone": "+70319635596"}
0005433057786	3DDC75	3230 403132	ALEKSANDRA CHERNOVA	{"email": "chernovaaleksandra_25031969@postgrespro.ru", "phone": "+70045333962"}
0005433057787	3DDC75	4074 578539	NINA IVANOVA	{"email": "ivanova-nina-1973@postgrespro.ru", "phone": "+70000925206"}
0005433057788	619DA1	2164 350618	ALEKSANDR PAVLOV	{"phone": "+70212337326"}
0005433057789	619DA1	0034 982317	NINA AFANASEVA	{"phone": "+70941263938"}
0005433057790	619DA1	9270 290181	NINA SOROKINA	{"phone": "+70518791692"}
0005433057791	5D872E	8269 354302	EDUARD KULIKOV	{"email": "eduard_kulikov-1965@postgrespro.ru", "phone": "+70123626687"}
0005433057792	996905	9788 325368	PAVEL VOLKOV	{"email": "pavel.volkov_1960@postgrespro.ru", "phone": "+70088493630"}
0005433057793	996905	7697 385309	ANNA TIKHONOVA	{"email": "annatikhonova.1979@postgrespro.ru", "phone": "+70556557744"}
0005433057794	229CCA	4581 215014	OLGA KUDRYASHOVA	{"phone": "+70908365889"}
0005433057795	229CCA	6730 647885	MIKHAIL SHEVCHENKO	{"phone": "+70246759925"}
0005433057796	229CCA	0329 417985	OLEG SERGEEV	{"email": "sergeev-o_111968@postgrespro.ru", "phone": "+70300253677"}
0005433057797	A8F69D	3898 563836	ELINA IVANOVA	{"email": "ivanova-elina_021982@postgrespro.ru", "phone": "+70653313740"}
0005433057798	BAB861	9029 467500	VYACHESLAV PETROV	{"email": "vpetrov_1961@postgrespro.ru", "phone": "+70436044397"}
0005433057799	8C6701	0400 725188	NADEZHDA EGOROVA	{"email": "nadezhda.egorova-08091981@postgrespro.ru", "phone": "+70278765907"}
0005433057800	8C6701	3859 909091	EKATERINA SERGEEVA	{"email": "sergeeva_ekaterina.1969@postgrespro.ru", "phone": "+70770613102"}
0005433057801	81F84C	9905 890245	IRINA POTAPOVA	{"email": "potapovairina-1984@postgrespro.ru", "phone": "+70859461899"}
0005433057802	81F84C	4040 323792	NATALYA FOMINA	{"phone": "+70935645367"}
0005433057803	B45912	7144 042817	VALENTINA KALININA	{"email": "vkalinina-101974@postgrespro.ru", "phone": "+70029660765"}
0005433057804	B45912	6277 461446	ANNA ANDREEVA	{"phone": "+70178205147"}
0005433057805	4CB889	7354 949140	YULIYA FROLOVA	{"email": "yuliya.frolova.021975@postgrespro.ru", "phone": "+70658340021"}
0005433057806	E7A768	4947 943290	VLADIMIR ZHURAVLEV	{"phone": "+70690432201"}
0005433057807	E7A768	9813 181319	ELENA ZAYCEVA	{"email": "elenazayceva_1965@postgrespro.ru", "phone": "+70008596850"}
0005433057808	5C4365	9999 677832	VITALIY KUZMIN	{"phone": "+70764239146"}
0005433057809	50B5B0	4327 207899	GALINA MATVEEVA	{"email": "matveeva_g.091963@postgrespro.ru", "phone": "+70828855115"}
0005433057810	8C2A83	8231 037423	RUFIYA SOKOLOVA	{"phone": "+70347639029"}
0005433057811	10164C	7905 892914	NINA KOLESNIKOVA	{"phone": "+70587102519"}
0005433057812	D96E73	3366 339953	MIKHAIL FILIPPOV	{"phone": "+70940852792"}
0005433057813	89C233	5629 871946	YURIY ZAYCEV	{"phone": "+70333132258"}
0005433057814	15C734	5572 258092	NATALYA STEPANOVA	{"email": "stepanovanatalya12101969@postgrespro.ru", "phone": "+70725574004"}
0005433057815	065C57	7748 424626	VALENTINA SOKOLOVA	{"email": "v_sokolova081967@postgrespro.ru", "phone": "+70856139834"}
0005433057816	065C57	7879 939930	ALEKSANDR GRIGOREV	{"email": "a.grigorev.021972@postgrespro.ru", "phone": "+70387223975"}
0005433057817	078C3D	2789 244957	NATALYA IVANOVA	{"email": "ivanova_n-1969@postgrespro.ru", "phone": "+70489166495"}
0005433057818	272158	6458 743369	ZAKHAR FEDOROV	{"phone": "+70920092943"}
0005433057819	F42322	6555 754403	MARIYA BOGDANOVA	{"email": "bogdanova-m-101980@postgrespro.ru", "phone": "+70835784735"}
0005433057820	BAAA81	7307 063998	TAMARA MOROZOVA	{"email": "morozovat1979@postgrespro.ru", "phone": "+70710223507"}
0005433057821	BAAA81	4842 596357	ANATOLIY ROMANOV	{"email": "a_romanov-17111965@postgrespro.ru", "phone": "+70502441297"}
0005433057822	E12B31	3022 912919	LYUBOV MEDVEDEVA	{"phone": "+70180711267"}
0005433057823	E12B31	5175 818890	TATYANA KOVALEVA	{"phone": "+70236951595"}
0005433057824	E12B31	2099 498382	ILMIR SERGEEV	{"email": "sergeev.ilmir_081968@postgrespro.ru", "phone": "+70798552067"}
0005433057825	C18F7D	2299 890337	SVETLANA PETROVA	{"phone": "+70587376785"}
0005433057826	C18F7D	2475 377060	ELENA KUZNECOVA	{"phone": "+70576401215"}
0005433057827	0CD1F5	6073 153671	RASHID SMIRNOV	{"email": "r-smirnov-021978@postgrespro.ru", "phone": "+70642359290"}
0005433057828	D94831	3559 233751	IRINA ZHURAVLEVA	{"email": "i.zhuravleva.111975@postgrespro.ru", "phone": "+70850178129"}
0005433057829	D94831	6240 639773	SVETLANA VOROBEVA	{"phone": "+70033309727"}
0005433057830	D94831	4623 837591	OLGA FILATOVA	{"email": "olgafilatova06031973@postgrespro.ru", "phone": "+70652973629"}
0005433057831	B7E7AA	2601 291575	ANATOLIY POPOV	{"phone": "+70935867894"}
0005433057832	204A16	3291 300497	VASILIY IVANOV	{"email": "ivanovv_21011969@postgrespro.ru", "phone": "+70086230454"}
0005433057833	BC06C4	0047 165196	SVETLANA SERGEEVA	{"phone": "+70425856226"}
0005433057834	BC06C4	0827 674924	OLGA NIKOLAEVA	{"phone": "+70714476408"}
0005433057835	F8124A	3692 587136	ILYA BELOV	{"email": "ilya_belov_051966@postgrespro.ru", "phone": "+70799899788"}
0005433057836	F8124A	4523 510568	VLADIMIR NIKITIN	{"email": "nikitin-v-1987@postgrespro.ru", "phone": "+70701507635"}
0005433057837	E7995B	3415 724873	EKATERINA KISELEVA	{"email": "e.kiseleva_04061965@postgrespro.ru", "phone": "+70642233376"}
0005433057838	90D03B	6997 951284	SERGEY EGOROV	{"phone": "+70356721135"}
0005433057839	858416	2368 111974	ANATOLIY NIKOLAEV	{"phone": "+70744573806"}
0005433057840	2E06A2	0357 951022	KIRILL YAKOVLEV	{"email": "kirill-yakovlev_01031974@postgrespro.ru", "phone": "+70058495278"}
0005433057841	C264DC	5900 051604	NADEZHDA FOMINA	{"email": "nfomina_091972@postgrespro.ru", "phone": "+70305711533"}
0005433057842	C264DC	0211 825730	LYUBOV BOGDANOVA	{"phone": "+70784131003"}
0005433057843	C264DC	4274 488047	EVGENIY SOLOVEV	{"email": "solovevevgeniy-1976@postgrespro.ru", "phone": "+70392901510"}
0005433057844	673D86	3071 912588	ALEKSEY ABRAMOV	{"email": "aleksey_abramov-14101988@postgrespro.ru", "phone": "+70542284245"}
0005433057845	673D86	9542 003627	OLEG BORISOV	{"email": "o.borisov1964@postgrespro.ru", "phone": "+70577333897"}
0005433057846	168691	1790 402330	YURIY KUZNECOV	{"email": "kuznecov.yuriy-031977@postgrespro.ru", "phone": "+70090410352"}
0005433057847	188085	3013 421275	NATALIYA ORLOVA	{"phone": "+70191119818"}
0005433057848	50CDB5	1190 818003	SERAFIMA KONDRATEVA	{"email": "kondrateva-serafima_24071963@postgrespro.ru", "phone": "+70779804916"}
0005433057849	807FAC	4349 631584	SERGEY GUSEV	{"email": "sergey.gusev-05051965@postgrespro.ru", "phone": "+70332844434"}
0005433057850	7C9771	1292 348067	GALINA NAUMOVA	{"email": "naumova-galina-21061965@postgrespro.ru", "phone": "+70224001037"}
0005433057851	81EEAC	0058 767706	SERAFIMA FROLOVA	{"phone": "+70333638266"}
0005433057852	26F2CE	7751 138368	ANATOLIY BORISOV	{"phone": "+70937337130"}
0005433057853	C850A3	5849 964793	TIMUR VOLKOV	{"phone": "+70973420847"}
0005433057854	C850A3	7761 186398	ELENA KAZAKOVA	{"email": "kazakova_e1979@postgrespro.ru", "phone": "+70182453127"}
0005433057855	0DE03E	7363 854235	ANTON KUZMIN	{"email": "kuzmin.anton.1970@postgrespro.ru", "phone": "+70139196876"}
0005433057856	6EF351	2018 136898	NINA KRASNOVA	{"phone": "+70464669212"}
0005433057857	D4FFFA	1776 220629	EVGENIY MARTYNOV	{"email": "martynov.e_1970@postgrespro.ru", "phone": "+70533062714"}
0005433057858	16BFBB	7477 037060	ARKADIY ORLOV	{"email": "arkadiy_orlov1975@postgrespro.ru", "phone": "+70762431288"}
0005433057859	5837D8	1225 036075	VLADIMIR PAVLOV	{"phone": "+70852744941"}
0005433057860	76DB09	9772 157164	OLGA FILATOVA	{"email": "filatovao_07021973@postgrespro.ru", "phone": "+70486054823"}
0005433057861	76DB09	6580 932516	VALENTINA KONOVALOVA	{"email": "vkonovalova.23041954@postgrespro.ru", "phone": "+70087026328"}
0005433057862	76DB09	6370 063274	NIKOLAY TIMOFEEV	{"phone": "+70081488177"}
0005433057863	2D0271	9493 638252	NATALIYA KUZNECOVA	{"email": "n_kuznecova_1970@postgrespro.ru", "phone": "+70187403984"}
0005433057864	2D0271	2196 238164	MARINA RYABOVA	{"phone": "+70275500187"}
0005433057865	2D7717	5215 892335	ELENA VOROBEVA	{"phone": "+70661652745"}
0005433057866	965430	4414 737587	NADEZHDA KUZMINA	{"phone": "+70557493706"}
0005433057867	965430	2551 466020	LYUDMILA BORISOVA	{"email": "l_borisova101966@postgrespro.ru", "phone": "+70248297982"}
0005433057868	337400	4609 162047	VYACHESLAV TARASOV	{"email": "tarasov-v_18081968@postgrespro.ru", "phone": "+70097753969"}
0005433057869	E15D5F	0996 774717	SERGEY ABRAMOV	{"phone": "+70511193264"}
0005433057870	E15D5F	5605 678588	LYUDMILA MALYSHEVA	{"email": "malyshevalyudmila_101972@postgrespro.ru", "phone": "+70903393457"}
0005433057871	E15D5F	9158 913712	ANDREY SAVELEV	{"phone": "+70092447031"}
0005433057872	A1DBAC	4491 124813	TAMARA MOISEEVA	{"phone": "+70824529320"}
0005433057873	6195F3	4860 408427	VERONIKA KUZMINA	{"phone": "+70990232854"}
0005433057874	6195F3	8311 125464	ARINA ZAYCEVA	{"phone": "+70201714505"}
0005433057875	61CCFA	1327 062105	ALEKSEY NAUMOV	{"phone": "+70041755792"}
0005433057876	A9F330	8150 223387	SERGEY OSIPOV	{"phone": "+70793629269"}
0005433057877	A9F330	5699 114534	IVAN NAZAROV	{"email": "nazarov-ivan-031970@postgrespro.ru", "phone": "+70022559616"}
0005433057878	A93CC0	0032 997747	EVGENIY MIKHAYLOV	{"email": "evgeniy.mikhaylov_18121981@postgrespro.ru", "phone": "+70226967294"}
0005433057879	4CB2F0	7441 264000	MARIYA MIRONOVA	{"phone": "+70696095979"}
0005433057880	4CB2F0	2689 738979	ALEKSEY ANDREEV	{"email": "a.andreev-081971@postgrespro.ru", "phone": "+70142513641"}
0005433057881	0FC251	7782 928819	TAMARA LAZAREVA	{"email": "tamara_lazareva_111962@postgrespro.ru", "phone": "+70445320642"}
0005433057882	0FC251	4368 967767	DENIS FOMIN	{"phone": "+70694078011"}
0005433057883	5BFFDB	8591 474903	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr1979@postgrespro.ru", "phone": "+70941463857"}
0005433057884	876BB7	5159 710572	INNA EFIMOVA	{"email": "i.efimova_091984@postgrespro.ru", "phone": "+70744921185"}
0005433057885	876BB7	9022 135976	TATYANA GORBUNOVA	{"email": "gorbunovat.1982@postgrespro.ru", "phone": "+70218468517"}
0005433057886	CBF8D8	1970 361617	GENNADIY MOROZOV	{"email": "morozov_gennadiy-1975@postgrespro.ru", "phone": "+70849652577"}
0005433057887	CBF8D8	7677 431525	EKATERINA POPOVA	{"phone": "+70527126694"}
0005433057888	AEB89A	4497 936665	EKATERINA EGOROVA	{"phone": "+70176767697"}
0005433057889	CA2F78	5517 554817	ANNA MARTYNOVA	{"email": "anna.martynova_16031959@postgrespro.ru", "phone": "+70938601141"}
0005433057890	3B85B9	0742 481459	MAKSIM ROMANOV	{"email": "romanov.m_08061976@postgrespro.ru", "phone": "+70656562943"}
0005433057891	3B85B9	9151 177125	SVETLANA RYABOVA	{"email": "ryabova.svetlana.09121967@postgrespro.ru", "phone": "+70626266040"}
0005433057892	F7CC03	5354 891416	GALINA VASILEVA	{"email": "vasileva-galina23011980@postgrespro.ru", "phone": "+70812944016"}
0005433057893	5C8C8E	9862 777566	VITALIY KAZAKOV	{"email": "kazakovv101971@postgrespro.ru", "phone": "+70868559818"}
0005433057894	A9077E	6476 242493	VYACHESLAV KAZAKOV	{"phone": "+70444202814"}
0005433057895	C29E7E	3621 604195	LIDIYA ABRAMOVA	{"email": "abramoval-021973@postgrespro.ru", "phone": "+70430950687"}
0005433057896	3AF950	2284 712810	PAVEL KUZNECOV	{"phone": "+70350218703"}
0005433057897	DBE3EB	1330 516039	VLADIMIR PAVLOV	{"email": "pavlovvladimir_18101975@postgrespro.ru", "phone": "+70181896490"}
0005433057898	DC7E28	0946 158590	VITALIY KARPOV	{"email": "vitaliy_karpov-021960@postgrespro.ru", "phone": "+70935825355"}
0005433057899	E2534D	8613 592917	DMITRIY IVANOV	{"phone": "+70368326484"}
0005433057900	915922	7077 534731	EVGENIY POPOV	{"phone": "+70531317478"}
0005433057901	915922	4307 890213	SERGEY FEDOROV	{"email": "sergey.fedorov07061968@postgrespro.ru", "phone": "+70234413964"}
0005433057902	915922	3820 016989	ALEKSANDR ZAKHAROV	{"email": "zakharov_a.121968@postgrespro.ru", "phone": "+70104844163"}
0005433057903	45E87F	9338 543403	IRINA LOGINOVA	{"email": "irinaloginova28021970@postgrespro.ru", "phone": "+70820759828"}
0005433057904	94F48E	4886 148530	VIKTOR KUDRYASHOV	{"email": "viktor_kudryashov011987@postgrespro.ru", "phone": "+70766159788"}
0005433057905	94F48E	8107 319259	OKSANA MOROZOVA	{"email": "omorozova.101973@postgrespro.ru", "phone": "+70380653858"}
0005433057906	94F48E	6047 429709	ROMAN IVANOV	{"email": "r.ivanov-11081969@postgrespro.ru", "phone": "+70949477583"}
0005433057907	4D4544	7671 643490	GALINA BORISOVA	{"phone": "+70830182878"}
0005433057908	59DBCE	6149 765395	ALEKSEY SHEVCHENKO	{"email": "aleksey.shevchenko.1964@postgrespro.ru", "phone": "+70829612231"}
0005433057909	F1E6B1	4996 183077	TATYANA LOGINOVA	{"phone": "+70082361624"}
0005433057910	6B2E32	1670 177158	ALEKSANDR BORISOV	{"phone": "+70223445937"}
0005433057911	409C58	4776 255221	ELENA VOLKOVA	{"email": "volkova-e.1981@postgrespro.ru", "phone": "+70165249811"}
0005433057912	409C58	9744 379316	ALEKSEY IVANOV	{"email": "aivanov-1977@postgrespro.ru", "phone": "+70499218423"}
0005433057913	409C58	5535 035959	IGOR FEDOTOV	{"email": "fedotov-igor_1978@postgrespro.ru", "phone": "+70554839652"}
0005433057914	D96962	3291 048851	EVGENIYA TIKHONOVA	{"email": "evgeniyatikhonova_011980@postgrespro.ru", "phone": "+70076826536"}
0005433057915	D96962	8289 293217	GALINA KOZLOVA	{"phone": "+70551729238"}
0005433057916	D9A281	2324 020341	SERGEY SOLOVEV	{"email": "s_solovev.081970@postgrespro.ru", "phone": "+70619345607"}
0005433057917	EA07BC	4338 118425	NATALYA NIKOLAEVA	{"email": "nikolaeva-natalya.28081961@postgrespro.ru", "phone": "+70328450220"}
0005433057918	FF2493	6261 188373	VIKTORIYA SOKOLOVA	{"phone": "+70174407219"}
0005433057919	FF2493	2104 067035	LYUDMILA IVANOVA	{"phone": "+70975685960"}
0005433057920	3E3891	1323 884314	ANDREY SCHERBAKOV	{"phone": "+70452798985"}
0005433057921	76AF10	4969 451116	ALEKSEY KRASNOV	{"email": "krasnova-19041966@postgrespro.ru", "phone": "+70093570123"}
0005433057922	76AF10	4241 730750	VLADIMIR IVANOV	{"phone": "+70219780943"}
0005433057923	CE9A2C	2025 946444	DMITRIY KARPOV	{"phone": "+70297474098"}
0005433057924	CE9A2C	2769 045321	PLATON SOKOLOV	{"email": "p-sokolov-081971@postgrespro.ru", "phone": "+70167512488"}
0005433057925	BDF9DB	0042 670245	NATALYA NIKOLAEVA	{"phone": "+70823004255"}
0005433057926	BDF9DB	7993 443109	PETR EGOROV	{"email": "petregorov_1963@postgrespro.ru", "phone": "+70959837478"}
0005433057927	089FCD	6497 521739	ALEKSANDR VASILEV	{"email": "vasilev_a031973@postgrespro.ru", "phone": "+70702280203"}
0005433057928	B9B4EC	9870 826853	NIKOLAY ALEKSEEV	{"email": "alekseev-n1969@postgrespro.ru", "phone": "+70674744539"}
0005433057929	34C21C	6848 821508	IGOR IVANOV	{"phone": "+70948405647"}
0005433057930	8FE9EF	7310 477583	TATYANA MASLOVA	{"email": "t_maslova_1969@postgrespro.ru", "phone": "+70005075286"}
0005433057931	C10027	8845 415951	VALENTINA IVANOVA	{"phone": "+70415451787"}
0005433057932	DD619E	5505 472550	EVGENIY FOMIN	{"email": "fominevgeniy061978@postgrespro.ru", "phone": "+70149013006"}
0005433057933	778DE4	7712 084074	ALEVTINA OSIPOVA	{"email": "aosipova1971@postgrespro.ru", "phone": "+70017347459"}
0005433057934	1F95C2	9102 018780	MARIYA EFREMOVA	{"email": "mariyaefremova_21031967@postgrespro.ru", "phone": "+70467368010"}
0005433057935	0779F9	8179 106757	STANISLAV BARANOV	{"email": "stanislav-baranov_04061965@postgrespro.ru", "phone": "+70331094723"}
0005433057936	82887D	5585 881191	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov1967@postgrespro.ru", "phone": "+70973629676"}
0005433057937	82887D	2949 719700	SERGEY FOMIN	{"phone": "+70901636557"}
0005433057938	4167D6	5917 569854	KSENIYA KOROLEVA	{"email": "koroleva-k-1983@postgrespro.ru", "phone": "+70607962483"}
0005433057939	4167D6	2840 700688	NADEZHDA LAZAREVA	{"email": "n-lazareva_021961@postgrespro.ru", "phone": "+70884125856"}
0005433057940	EDE125	2327 300869	NATALYA KRASNOVA	{"email": "n-krasnova-26121983@postgrespro.ru", "phone": "+70704063777"}
0005433057941	F06274	6001 509485	DMITRIY POPOV	{"email": "popov_d-1968@postgrespro.ru", "phone": "+70269030864"}
0005433057942	058C27	8815 769652	OLGA ZAYCEVA	{"phone": "+70790590198"}
0005433057943	058C27	2427 230093	PAVEL AFANASEV	{"email": "afanasev.p_1969@postgrespro.ru", "phone": "+70377084258"}
0005433057944	8ABE73	3410 897866	VLADIMIR MELNIKOV	{"email": "melnikovv_011981@postgrespro.ru", "phone": "+70511299709"}
0005433057945	8ABE73	3581 061370	YULIYA LEBEDEVA	{"phone": "+70567173624"}
0005433057946	6560C1	8558 400623	PAVEL SIDOROV	{"phone": "+70504211203"}
0005433057947	02F518	3004 349261	MARIYA SIDOROVA	{"email": "sidorova.mariya1977@postgrespro.ru", "phone": "+70399802614"}
0005433057948	537456	9934 367193	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova-08011991@postgrespro.ru", "phone": "+70372679471"}
0005433057949	87C686	7030 215761	VALENTINA FROLOVA	{"email": "valentinafrolova-1970@postgrespro.ru", "phone": "+70911410912"}
0005433057950	45438B	1703 767914	ALEKSEY POPOV	{"phone": "+70770969622"}
0005433057951	603A40	7821 967168	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.svetlana-03101980@postgrespro.ru", "phone": "+70600672415"}
0005433057952	603A40	1746 392787	DMITRIY IVANOV	{"phone": "+70560372096"}
0005433057953	38D021	2113 654138	ARTEM KUZNECOV	{"phone": "+70329767526"}
0005433057954	E75FB7	1084 529852	DMITRIY AFANASEV	{"email": "d_afanasev26101967@postgrespro.ru", "phone": "+70571387577"}
0005433057955	7C8A55	9207 251903	DANILA NIKOLAEV	{"email": "nikolaev.danila.121969@postgrespro.ru", "phone": "+70391605192"}
0005433057956	7C8A55	6916 819376	OLGA SIDOROVA	{"phone": "+70713957948"}
0005433057957	1B825A	8555 789471	TATYANA KUZNECOVA	{"phone": "+70531107135"}
0005433057958	1D90BC	0723 798806	VLADIMIR MIKHAYLOV	{"phone": "+70976978876"}
0005433057959	1965B4	0247 938701	DMITRIY BONDARENKO	{"email": "dbondarenko_111954@postgrespro.ru", "phone": "+70986287694"}
0005433057960	8CDAD4	3591 288117	IVAN IVANOV	{"phone": "+70381321973"}
0005433057961	F68BED	4049 375975	OLGA SEMENOVA	{"phone": "+70258020757"}
0005433057962	F68BED	6785 808964	EVGENIY ZHUKOV	{"phone": "+70602825861"}
0005433057963	B0CE94	7514 131601	OLGA LUKYANOVA	{"email": "olga-lukyanova111964@postgrespro.ru", "phone": "+70110842634"}
0005433057964	972FDA	4445 968856	KSENIYA POPOVA	{"email": "k_popova-011978@postgrespro.ru", "phone": "+70851077663"}
0005433057965	187905	3161 872222	YURIY GRIGOREV	{"email": "grigorevy.17021983@postgrespro.ru", "phone": "+70126026118"}
0005433057966	843152	9253 454859	YULIYA NIKOLAEVA	{"phone": "+70012348785"}
0005433057967	05801B	4680 576157	PETR SCHERBAKOV	{"phone": "+70594752731"}
0005433057968	05801B	3401 949099	VYACHESLAV CHERNOV	{"email": "chernov_v_1969@postgrespro.ru", "phone": "+70059702456"}
0005433057969	AE80ED	2443 982910	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova24041968@postgrespro.ru", "phone": "+70507470411"}
0005433057970	157BD9	0881 765704	IVAN SHEVCHENKO	{"phone": "+70787487123"}
0005433057971	AC1D79	5089 605271	ROMAN VOLKOV	{"phone": "+70246888177"}
0005433057972	AC1D79	0440 254836	ANASTASIYA AKIMOVA	{"phone": "+70332201465"}
0005433057973	BA23BA	3430 051264	VALERIY MIKHAYLOV	{"email": "valeriy-mikhaylov-11111979@postgrespro.ru", "phone": "+70961670300"}
0005433057974	D2F11E	8942 052959	LYUDMILA SIDOROVA	{"email": "sidorova_lyudmila_1974@postgrespro.ru", "phone": "+70836604996"}
0005433057975	F57C61	3441 810118	SERGEY ABRAMOV	{"email": "s.abramov_1963@postgrespro.ru", "phone": "+70627429966"}
0005433057976	F57C61	1635 169865	NIKITA ZHUKOV	{"email": "zhukov.n1961@postgrespro.ru", "phone": "+70461034941"}
0005433057977	737913	0753 758552	DMITRIY VLASOV	{"phone": "+70584291249"}
0005433057978	1F0A18	3923 543908	SERGEY GRIGOREV	{"email": "s.grigorev-05041964@postgrespro.ru", "phone": "+70379511552"}
0005433057979	1F0A18	4217 004674	BORIS ZAKHAROV	{"phone": "+70572311978"}
0005433057980	1F0A18	9594 182973	ZINAIDA ZAKHAROVA	{"email": "zakharova.z041975@postgrespro.ru", "phone": "+70278024561"}
0005433057981	D43290	9031 080247	MARIYA ZAKHAROVA	{"phone": "+70139046930"}
0005433057982	A2768F	5057 502282	EVGENIY TIKHONOV	{"email": "tikhonov_e.101970@postgrespro.ru", "phone": "+70667105039"}
0005433057983	A2768F	0409 865711	NATALIYA PETROVA	{"email": "n-petrova_1977@postgrespro.ru", "phone": "+70969997915"}
0005433057984	A2768F	9596 062567	LYUBOV SERGEEVA	{"email": "sergeevalyubov.1971@postgrespro.ru", "phone": "+70603370535"}
0005433057985	CAC18D	6688 003996	TATYANA SEMENOVA	{"email": "t-semenova-25101964@postgrespro.ru", "phone": "+70100012225"}
0005433057986	951545	9697 207477	MIKHAIL FROLOV	{"phone": "+70240360884"}
0005433057987	9844FB	4450 855932	ALEKSEY NIKITIN	{"email": "anikitin05051977@postgrespro.ru", "phone": "+70757592340"}
0005433057988	9844FB	3729 654550	VLADIMIR ORLOV	{"email": "v.orlov_101971@postgrespro.ru", "phone": "+70050792370"}
0005433057989	535E63	9131 283266	NINA TIMOFEEVA	{"email": "nina-timofeeva1967@postgrespro.ru", "phone": "+70832152836"}
0005433057990	535E63	0182 368043	ANDREY KUZNECOV	{"phone": "+70996548234"}
0005433057991	535E63	7988 556898	INNA SAVELEVA	{"email": "saveleva-inna.04061960@postgrespro.ru", "phone": "+70327326808"}
0005433057992	7A93BB	0936 987528	NIKOLAY SOKOLOV	{"phone": "+70045609031"}
0005433057993	E90613	6220 646694	RINAT ALEKSEEV	{"email": "alekseev-r_1979@postgrespro.ru", "phone": "+70292695950"}
0005433057994	E90613	9441 614405	ANTONINA KRASNOVA	{"email": "a_krasnova.011966@postgrespro.ru", "phone": "+70764314400"}
0005433057995	1A98F2	6106 816916	VADIM TIKHONOV	{"phone": "+70194284728"}
0005433057996	EE2CA5	1148 112410	ALEKSANDR PETROV	{"phone": "+70671829662"}
0005433057997	EE2CA5	0325 873164	DMITRIY SOKOLOV	{"email": "d_sokolov.041971@postgrespro.ru", "phone": "+70222868154"}
0005433057998	C0FA05	8195 432454	VADIM MELNIKOV	{"phone": "+70716486407"}
0005433057999	C0FA05	2775 255889	SERGEY AFANASEV	{"email": "s.afanasev061970@postgrespro.ru", "phone": "+70693739117"}
0005433058000	B504DD	5953 517718	DMITRIY MELNIKOV	{"phone": "+70041466298"}
0005433058001	B504DD	8776 621521	NATALYA YUDINA	{"email": "yudina_natalya021966@postgrespro.ru", "phone": "+70405621322"}
0005433058228	2FE940	7294 215540	TATYANA KOZLOVA	{"phone": "+70353107685"}
0005433058002	B504DD	7634 386581	LYUBOV SAVELEVA	{"email": "lsaveleva25111975@postgrespro.ru", "phone": "+70602256952"}
0005433058003	C8A01C	4440 217497	KLAVDIYA MAKAROVA	{"phone": "+70335296503"}
0005433058004	DF2B4A	2891 207034	ANTONINA FROLOVA	{"email": "frolova.antonina_03021977@postgrespro.ru", "phone": "+70722089202"}
0005433058005	97980D	5289 876647	ANDREY BELOV	{"phone": "+70584252800"}
0005433058006	AD7CA9	9030 285526	OLGA KRASNOVA	{"phone": "+70235571448"}
0005433058007	AD7CA9	0303 314824	ALEKSANDR AFANASEV	{"email": "afanasev-aleksandr081976@postgrespro.ru", "phone": "+70535607865"}
0005433058008	E616D2	8477 978262	EKATERINA IVANOVA	{"email": "ekaterina_ivanova.1980@postgrespro.ru", "phone": "+70545769031"}
0005433058009	E616D2	0111 960882	MARINA ROMANOVA	{"email": "marina_romanova081972@postgrespro.ru", "phone": "+70993555206"}
0005433058010	E616D2	4574 030773	LARISA MAKAROVA	{"email": "larisa_makarova.111977@postgrespro.ru", "phone": "+70187730861"}
0005433058011	1DFDA9	1559 481841	ANDREY EGOROV	{"phone": "+70475843939"}
0005433058012	F297BE	2550 899181	EVGENIYA VASILEVA	{"phone": "+70700920666"}
0005433058013	F297BE	5486 477949	MARIYA POTAPOVA	{"email": "m.potapova_08081968@postgrespro.ru", "phone": "+70848627080"}
0005433058014	9E26D0	3076 441610	NIKOLAY PETROV	{"phone": "+70344029318"}
0005433058015	9E26D0	1319 100909	IVAN MOISEEV	{"email": "moiseev-i-1967@postgrespro.ru", "phone": "+70005656679"}
0005433058016	B2C37F	3008 056913	TATYANA MAKAROVA	{"phone": "+70264622817"}
0005433058017	FA51DF	9900 806948	VIKTOR VASILEV	{"phone": "+70126730114"}
0005433058018	FA51DF	2102 285168	SERGEY ANTONOV	{"phone": "+70868489519"}
0005433058019	19FE8A	5508 051007	VIKTOR MIRONOV	{"email": "mironovviktor13111975@postgrespro.ru", "phone": "+70656432009"}
0005433058020	19FE8A	6875 170144	SOFYA EGOROVA	{"phone": "+70325088376"}
0005433058021	736039	5569 490211	TATYANA PETROVA	{"email": "tatyanapetrova_14091978@postgrespro.ru", "phone": "+70843055662"}
0005433058022	68D92C	3916 786876	NINA GERASIMOVA	{"phone": "+70969460884"}
0005433058023	2880AD	7547 035634	GALINA ILINA	{"email": "ilina-galina_08081967@postgrespro.ru", "phone": "+70705051807"}
0005433058024	2880AD	7010 032728	ANNA AFANASEVA	{"phone": "+70981451076"}
0005433058025	2880AD	9123 701472	SERGEY MAKSIMOV	{"email": "maksimov.s21051975@postgrespro.ru", "phone": "+70252482764"}
0005433058026	2880AD	7537 475786	DARYA ZHURAVLEVA	{"phone": "+70152804400"}
0005433058027	A6F331	5695 070275	EKATERINA NESTEROVA	{"email": "ekaterina.nesterova-1969@postgrespro.ru", "phone": "+70290399201"}
0005433058028	A6F331	1691 919699	MARIYA POPOVA	{"email": "m_popova_041966@postgrespro.ru", "phone": "+70689276179"}
0005433058029	86AC87	3717 959373	ELENA GERASIMOVA	{"phone": "+70104810428"}
0005433058030	91625F	1609 370123	VALENTINA POTAPOVA	{"email": "valentina.potapova.111977@postgrespro.ru", "phone": "+70312049625"}
0005433058031	4B4E41	1000 355953	VLADA FROLOVA	{"phone": "+70394951081"}
0005433058032	1528D4	6890 636699	VIKTOR ZAYCEV	{"email": "zaycev_viktor.1972@postgrespro.ru", "phone": "+70267240654"}
0005433058033	4321DD	5673 818229	NADEZHDA LUKYANOVA	{"phone": "+70535384864"}
0005433058034	42E746	9851 842547	ANASTASIYA CHERNOVA	{"phone": "+70881921561"}
0005433058035	ED42A7	4363 217648	RAISA SMIRNOVA	{"phone": "+70969740504"}
0005433058036	ED42A7	7597 811905	SERGEY KUZNECOV	{"phone": "+70254306422"}
0005433058037	905E95	4606 246012	ANDREY FEDOTOV	{"phone": "+70046973484"}
0005433058038	FE4D4F	9404 391096	NIKOLAY AFANASEV	{"phone": "+70979248295"}
0005433058039	896950	0669 576522	VITALIY ORLOV	{"phone": "+70719606528"}
0005433058040	896950	6077 882437	POLINA PETROVA	{"phone": "+70421864896"}
0005433058041	A4834E	8692 810758	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov_011959@postgrespro.ru", "phone": "+70879102560"}
0005433058042	A4834E	0357 288688	VLADIMIR VOLKOV	{"email": "volkov_v.03041972@postgrespro.ru", "phone": "+70894056436"}
0005433058043	7CEE72	4455 711342	SERGEY ALEKSEEV	{"phone": "+70846902692"}
0005433058044	F7C5FA	7833 774160	YULIYA MIKHAYLOVA	{"email": "ymikhaylova1978@postgrespro.ru", "phone": "+70961072755"}
0005433058045	5341CC	6375 156051	ANDREY TIMOFEEV	{"email": "a_timofeev1973@postgrespro.ru", "phone": "+70257569946"}
0005433058046	5341CC	8535 365531	SERGEY NIKOLAEV	{"email": "nikolaev-sergey.1976@postgrespro.ru", "phone": "+70588483762"}
0005433058047	5341CC	2616 544083	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.1968@postgrespro.ru", "phone": "+70901678120"}
0005433058048	19DB4E	6063 300534	ALEKSANDR SEMENOV	{"phone": "+70445493376"}
0005433058049	19DB4E	0301 046180	VIKTOR BONDARENKO	{"email": "bondarenko-v.07031985@postgrespro.ru", "phone": "+70177615686"}
0005433058050	E6B240	6151 249884	EKATERINA MOROZOVA	{"email": "emorozova1969@postgrespro.ru", "phone": "+70545159572"}
0005433058051	E6B240	4877 197377	VALENTINA FROLOVA	{"email": "frolova.valentina.101973@postgrespro.ru", "phone": "+70168970025"}
0005433058052	1F2FD8	4054 643597	ALEKSANDR KOROLEV	{"phone": "+70165201333"}
0005433058053	3B3175	3190 245072	GRIGORIY MEDVEDEV	{"phone": "+70348073913"}
0005433058054	C20B64	4768 611056	DARYA FADEEVA	{"phone": "+70457774102"}
0005433058055	C20B64	7465 735685	LYUBOV MIKHAYLOVA	{"email": "lyubov-mikhaylova03111967@postgrespro.ru", "phone": "+70052597057"}
0005433058056	FF6C44	2211 859660	KONSTANTIN SEMENOV	{"email": "semenov_konstantin.03041975@postgrespro.ru", "phone": "+70082246490"}
0005433058057	03DD39	2990 405898	IRINA MELNIKOVA	{"email": "irina_melnikova_1963@postgrespro.ru", "phone": "+70274141830"}
0005433058058	3C4107	6827 948228	IVAN BELOV	{"email": "ivanbelov1961@postgrespro.ru", "phone": "+70724915814"}
0005433058059	218D64	2741 234305	NATALYA PAVLOVA	{"email": "n-pavlova1967@postgrespro.ru", "phone": "+70930865212"}
0005433058060	3D4E79	2698 716212	ALEKSEY KOZLOV	{"phone": "+70034370899"}
0005433058061	7EDACF	4616 405776	NATALYA ZHUKOVA	{"phone": "+70035728074"}
0005433058062	7EDACF	4678 076978	MARIYA CHERNOVA	{"email": "mariya_chernova.1974@postgrespro.ru", "phone": "+70961304548"}
0005433058063	7EDACF	1510 528002	OLEG MOISEEV	{"email": "omoiseev_1982@postgrespro.ru", "phone": "+70369618388"}
0005433058064	28287A	9299 351836	ZINAIDA SEMENOVA	{"phone": "+70881313028"}
0005433058065	4A7428	7128 554979	POLINA KONOVALOVA	{"email": "p-konovalova-011974@postgrespro.ru", "phone": "+70572170753"}
0005433058066	074520	4206 283485	LYUDMILA LEBEDEVA	{"phone": "+70972567151"}
0005433058067	074520	5967 800865	PETR SIDOROV	{"email": "p-sidorov20091962@postgrespro.ru", "phone": "+70760036014"}
0005433058068	11A380	2619 918036	VERA BORISOVA	{"phone": "+70703035141"}
0005433058069	11A380	7087 248666	ALEKSANDR SERGEEV	{"email": "asergeev-1965@postgrespro.ru", "phone": "+70724962032"}
0005433058070	C555D5	5980 326360	VALERIY MEDVEDEV	{"phone": "+70962236561"}
0005433058071	82F458	2841 663647	ANDREY KUZNECOV	{"phone": "+70100777990"}
0005433058072	B0E741	1261 307722	VLADIMIR ABRAMOV	{"email": "vabramov121962@postgrespro.ru", "phone": "+70488344646"}
0005433058073	0CF30A	9631 075912	YULIYA KULIKOVA	{"phone": "+70132129013"}
0005433058074	6B5723	7544 012986	SEMEN GERASIMOV	{"phone": "+70375763550"}
0005433058075	B8F2FD	0084 400841	MIKHAIL SOROKIN	{"email": "sorokin-m_031972@postgrespro.ru", "phone": "+70621043018"}
0005433058076	B8F2FD	2403 160526	ARTUR MAKAROV	{"email": "makarov_artur.21111971@postgrespro.ru", "phone": "+70582731274"}
0005433058077	17ADF4	8141 090121	ALEKSANDRA BORISOVA	{"email": "a-borisova.1978@postgrespro.ru", "phone": "+70582336438"}
0005433058078	C82E12	0844 805599	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov_1962@postgrespro.ru", "phone": "+70771725569"}
0005433058079	8C03EF	9425 245607	ALEKSANDR MOROZOV	{"email": "morozov-a1987@postgrespro.ru", "phone": "+70435123315"}
0005433058080	916A69	8794 743543	VASILIY MOROZOV	{"phone": "+70650442918"}
0005433058081	916A69	0815 476526	YURIY FROLOV	{"email": "y.frolov-081968@postgrespro.ru", "phone": "+70742254181"}
0005433058082	A3DBFF	7584 863241	ANDREY IVANOV	{"email": "ivanov-andrey_101986@postgrespro.ru", "phone": "+70123545957"}
0005433058083	8E8B2E	3604 319712	GENNADIY VLASOV	{"phone": "+70239605603"}
0005433058084	30B8E9	1151 231393	ELIZAVETA ZAKHAROVA	{"email": "zakharova-elizaveta_1961@postgrespro.ru", "phone": "+70494419681"}
0005433058085	30B8E9	4075 452655	TAGIR SAVELEV	{"email": "t-savelev-1978@postgrespro.ru", "phone": "+70316163652"}
0005433058086	C5B3F2	8803 977750	VADIM STEPANOV	{"phone": "+70942425944"}
0005433058087	CB7A3F	0538 188768	NINA KONOVALOVA	{"phone": "+70522076240"}
0005433058088	47C6EA	7721 863663	NIKOLAY IVANOV	{"email": "ivanov_n_041976@postgrespro.ru", "phone": "+70680204571"}
0005433058089	6ED29B	5795 415177	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov.111966@postgrespro.ru", "phone": "+70202637114"}
0005433058090	27900F	1031 169761	OKSANA EFREMOVA	{"phone": "+70020607641"}
0005433058091	27900F	6453 881053	ANTON SEMENOV	{"phone": "+70829117588"}
0005433058092	5E7CB2	0035 737489	ZINAIDA KOZLOVA	{"email": "zinaidakozlova24081976@postgrespro.ru", "phone": "+70506368437"}
0005433058093	5E7CB2	1644 548571	IVAN IVANOV	{"phone": "+70783949592"}
0005433058094	5E7CB2	1219 029552	ALEKSANDR BONDARENKO	{"email": "bondarenko_a.1962@postgrespro.ru", "phone": "+70295350784"}
0005433058095	076B44	1582 504551	LYUDMILA IVANOVA	{"email": "lyudmilaivanova1967@postgrespro.ru", "phone": "+70959596077"}
0005433058096	06CFF9	5933 371375	GALINA MASLOVA	{"phone": "+70249161488"}
0005433058097	E465C5	7676 381852	MARINA BARANOVA	{"email": "mbaranova_25101969@postgrespro.ru", "phone": "+70385053464"}
0005433058098	E465C5	6406 422870	NINA TITOVA	{"phone": "+70365966721"}
0005433058099	6EA99B	0094 341388	EKATERINA KUZNECOVA	{"email": "kuznecova.e_1973@postgrespro.ru", "phone": "+70942211964"}
0005433058100	53EAF4	7927 630563	YURIY NIKITIN	{"email": "yuriy-nikitin.1974@postgrespro.ru", "phone": "+70421563578"}
0005433058101	AF80CE	7303 383273	TAMARA TARASOVA	{"email": "tarasova_tamara-1975@postgrespro.ru", "phone": "+70372316828"}
0005433058102	0F6842	5292 687560	EVDOKIYA KISELEVA	{"phone": "+70894912204"}
0005433058103	E6D47B	7171 462561	EVGENIY DENISOV	{"phone": "+70959692526"}
0005433058104	B95173	8374 897773	VIKTOR CHERNOV	{"phone": "+70328244119"}
0005433058105	C0BC51	7631 916482	SOFYA OVCHINNIKOVA	{"phone": "+70796202872"}
0005433058106	C0BC51	5376 293624	VIKTORIYA CHERNOVA	{"phone": "+70571601085"}
0005433058107	6E8D8D	5887 135789	DMITRIY SEMENOV	{"email": "semenovdmitriy.1974@postgrespro.ru", "phone": "+70299290800"}
0005433058108	6E8D8D	8750 478604	SERGEY VASILEV	{"phone": "+70331064122"}
0005433058109	658795	5911 911498	TATYANA SAVELEVA	{"phone": "+70098619381"}
0005433058110	17EC66	1996 232544	TATYANA SAVELEVA	{"email": "saveleva.t-1968@postgrespro.ru", "phone": "+70227712072"}
0005433058111	17EC66	9682 929613	ANDREY IVANOV	{"email": "ivanovandrey-1969@postgrespro.ru", "phone": "+70580549679"}
0005433058112	64DD2A	1547 493359	DMITRIY KUZNECOV	{"phone": "+70598175600"}
0005433058113	64DD2A	5321 245569	DMITRIY IVANOV	{"email": "dmitriyivanov_081956@postgrespro.ru", "phone": "+70719013180"}
0005433058114	A5D904	3141 973596	VALENTINA ALEKSEEVA	{"email": "alekseeva.valentina-041976@postgrespro.ru", "phone": "+70150234932"}
0005433058115	A5D904	3956 899669	ALLA MIRONOVA	{"phone": "+70368136407"}
0005433058116	06C9A4	8568 841025	NIKOLAY RODIONOV	{"email": "rodionov_n-29121974@postgrespro.ru", "phone": "+70229186019"}
0005433058117	AF9601	5340 315230	EKATERINA KUDRYASHOVA	{"email": "kudryashova_e1959@postgrespro.ru", "phone": "+70413094427"}
0005433058118	0CD311	6722 860905	SERGEY EGOROV	{"phone": "+70708863928"}
0005433058119	A16E82	0722 817702	VIKTORIYA CHERNOVA	{"phone": "+70672596303"}
0005433058120	A16E82	5940 365136	VLADIMIR SEMENOV	{"phone": "+70720047007"}
0005433058121	1277E5	7964 533554	IGOR KUZNECOV	{"phone": "+70609930975"}
0005433058122	3CC65C	5808 222225	TATYANA ANDREEVA	{"phone": "+70540103022"}
0005433058123	3CC65C	3023 047876	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova.1980@postgrespro.ru", "phone": "+70142912151"}
0005433058124	822FEC	3970 262003	IGOR KULIKOV	{"email": "kulikov.i.051974@postgrespro.ru", "phone": "+70976827926"}
0005433058125	822FEC	6621 483482	ZINAIDA KISELEVA	{"phone": "+70183126350"}
0005433058126	D4F869	7476 387784	GALINA DAVYDOVA	{"phone": "+70487577328"}
0005433058127	D1CA89	3589 464689	VALERIY FEDOROV	{"phone": "+70430137057"}
0005433058128	D1CA89	5479 388881	VIKTOR SCHERBAKOV	{"email": "v.scherbakov_011979@postgrespro.ru", "phone": "+70378755326"}
0005433058129	C42D13	2964 166250	KIRILL MAKAROV	{"phone": "+70157563003"}
0005433058130	D37630	9205 617055	NINA TIKHONOVA	{"phone": "+70553594252"}
0005433058131	538B80	2657 613725	NATALYA FOMINA	{"phone": "+70992838401"}
0005433058132	6336C8	1890 558016	ALIYA KRASNOVA	{"phone": "+70261964266"}
0005433058133	6336C8	1482 891765	MIKHAIL EGOROV	{"email": "egorov-mikhail.08091973@postgrespro.ru", "phone": "+70970035995"}
0005433058134	8F9E06	9042 325743	ANATOLIY NIKITIN	{"email": "nikitin.a-02031980@postgrespro.ru", "phone": "+70926618735"}
0005433058135	1114F2	2861 401516	OLGA MEDVEDEVA	{"phone": "+70258018957"}
0005433058136	9CDC3C	2809 631752	SVETLANA VLASOVA	{"email": "svlasova_15091970@postgrespro.ru", "phone": "+70868146735"}
0005433058137	D2CBE5	4885 081813	NINA SERGEEVA	{"phone": "+70617372936"}
0005433058138	CD7038	0190 444951	VARVARA MOROZOVA	{"phone": "+70069639268"}
0005433058139	CF70ED	5002 538178	MARIYA KUZNECOVA	{"phone": "+70674756396"}
0005433058140	E0D040	3181 549786	OLGA ZAYCEVA	{"phone": "+70064741491"}
0005433058141	3614EA	3419 646681	DENIS DAVYDOV	{"phone": "+70623193991"}
0005433058142	3614EA	9004 789671	ILMIRA YAKOVLEVA	{"phone": "+70682816520"}
0005433058143	66404D	5747 616520	VITALIY KUZMIN	{"email": "kuzmin-vitaliy1975@postgrespro.ru", "phone": "+70297874235"}
0005433058144	66404D	0038 947239	ELENA IVANOVA	{"phone": "+70804384979"}
0005433058145	0FAC9D	7886 161527	IVAN ANTONOV	{"phone": "+70411772651"}
0005433058146	1CA2AB	0682 180803	ULYANA OVCHINNIKOVA	{"phone": "+70878828675"}
0005433058147	1CA2AB	4754 939674	VLADIMIR SOLOVEV	{"email": "vsolovev_1971@postgrespro.ru", "phone": "+70935437051"}
0005433058148	AC6E19	6901 661227	MARINA ZHURAVLEVA	{"email": "m_zhuravleva04071975@postgrespro.ru", "phone": "+70468036481"}
0005433058149	3B9D91	5200 362728	ALEKSEY IVANOV	{"phone": "+70886549137"}
0005433058150	0C1162	0146 989163	KLAVDIYA KUZNECOVA	{"email": "k_kuznecova_1970@postgrespro.ru", "phone": "+70936680227"}
0005433058151	0127A1	8831 746982	VALERIY ISAEV	{"phone": "+70772183213"}
0005433058152	A0172D	4085 699125	ALINA MEDVEDEVA	{"phone": "+70751863735"}
0005433058153	99B980	5225 600895	ANDREY MAKAROV	{"phone": "+70896780587"}
0005433058154	8CE684	6522 021311	FEDOR POPOV	{"email": "popov.fedor101971@postgrespro.ru", "phone": "+70919622002"}
0005433058155	31686A	7533 619893	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov_1981@postgrespro.ru", "phone": "+70650468191"}
0005433058156	35DFA3	1008 812215	LIDIYA LUKYANOVA	{"email": "lidiyalukyanova18011962@postgrespro.ru", "phone": "+70152299668"}
0005433058157	35DFA3	0385 970637	ALEKSANDR IVANOV	{"email": "ivanov_a09011964@postgrespro.ru", "phone": "+70215894161"}
0005433058158	BEDC60	0965 036384	DANIIL MAKAROV	{"email": "daniilmakarov_04101967@postgrespro.ru", "phone": "+70932631553"}
0005433058159	BEDC60	5955 955143	VASILIY KUDRYASHOV	{"email": "v_kudryashov1970@postgrespro.ru", "phone": "+70914879788"}
0005433058160	DE4211	7481 054044	MARIYA DAVYDOVA	{"phone": "+70955211658"}
0005433058161	DE4211	5657 991303	GALINA MIRONOVA	{"email": "mironovagalina_1984@postgrespro.ru", "phone": "+70063662112"}
0005433058162	DE4211	8872 095670	GALINA TARASOVA	{"phone": "+70004234957"}
0005433058163	2D0708	5742 999681	TAISIYA KUZNECOVA	{"email": "kuznecova.t.081970@postgrespro.ru", "phone": "+70502828538"}
0005433058164	15FF68	9204 782289	OLESYA VLASOVA	{"email": "vlasova.olesya_18021978@postgrespro.ru", "phone": "+70275776742"}
0005433058165	15FF68	2540 680337	OLGA IVANOVA	{"email": "o.ivanova.06101960@postgrespro.ru", "phone": "+70103475627"}
0005433058166	469D86	8818 106515	MAKSIM KRASNOV	{"phone": "+70186312807"}
0005433058167	469D86	6869 287136	KRISTINA SEMENOVA	{"email": "semenova.k-1980@postgrespro.ru", "phone": "+70128735865"}
0005433058168	DA2F61	6521 792906	IGOR BELOV	{"email": "igor-belov12081978@postgrespro.ru", "phone": "+70893694040"}
0005433058169	9A02AB	0899 596630	ALEKSANDRA KALININA	{"phone": "+70686571568"}
0005433058170	9A02AB	2239 110492	NATALYA CHERNOVA	{"phone": "+70311857968"}
0005433058171	8636D0	7655 050365	DINA GAVRILOVA	{"email": "dina_gavrilova_1968@postgrespro.ru", "phone": "+70718854595"}
0005433058172	026CDE	2657 367218	VIKTOR SOLOVEV	{"email": "solovev_viktor06121985@postgrespro.ru", "phone": "+70257032792"}
0005433058173	026CDE	6347 469572	NATALYA SIDOROVA	{"phone": "+70396591378"}
0005433058174	3E1749	0588 021991	ALEKSANDR MIKHAYLOV	{"phone": "+70086542356"}
0005433058175	3E1749	2770 734156	YURIY PAVLOV	{"phone": "+70103657717"}
0005433058176	B40468	9389 518540	GALINA DMITRIEVA	{"email": "galinadmitrieva27031975@postgrespro.ru", "phone": "+70732479034"}
0005433058177	E2BAC3	2193 504660	PAVEL BONDARENKO	{"email": "pavelbondarenko.111970@postgrespro.ru", "phone": "+70130972647"}
0005433058178	E2BAC3	6082 194875	VYACHESLAV DENISOV	{"phone": "+70102945422"}
0005433058179	A1A6C2	0280 275596	ROMAN NOVIKOV	{"phone": "+70621025887"}
0005433058180	0ADE98	7009 295480	LYUBOV POPOVA	{"phone": "+70853177799"}
0005433058181	0ADE98	9375 893982	KONSTANTIN STEPANOV	{"phone": "+70282534415"}
0005433058182	A1CFB4	5477 398563	GERMAN NAZAROV	{"email": "nazarov-german.17081975@postgrespro.ru", "phone": "+70376554617"}
0005433058183	6FD99C	6683 562278	ANDREY ZAYCEV	{"email": "andrey_zaycev041973@postgrespro.ru", "phone": "+70914206894"}
0005433058184	6FD99C	9525 299191	VYACHESLAV NOVIKOV	{"email": "novikovvyacheslav-1981@postgrespro.ru", "phone": "+70368541520"}
0005433058185	2A7CF0	6230 065987	SEMEN GERASIMOV	{"email": "gerasimov-s_1975@postgrespro.ru", "phone": "+70399806529"}
0005433058186	2A7CF0	9517 048017	MIKHAIL ORLOV	{"email": "morlov_17081968@postgrespro.ru", "phone": "+70098054312"}
0005433058187	55CEAD	4792 401966	EVGENIY SOROKIN	{"phone": "+70779314877"}
0005433058188	B26BC5	9801 032267	MIKHAIL PETROV	{"phone": "+70225501876"}
0005433058189	B26BC5	5450 629953	LYUDMILA MAKAROVA	{"email": "lyudmila_makarova_1980@postgrespro.ru", "phone": "+70195197200"}
0005433058190	4088F0	8014 766622	VLADISLAV GRIGOREV	{"phone": "+70884177204"}
0005433058191	CDCC99	4009 976716	ANASTASIYA GUSEVA	{"email": "guseva-anastasiya.081981@postgrespro.ru", "phone": "+70362927725"}
0005433058192	88A2B7	1606 240562	VALERIY IVANOV	{"phone": "+70490443532"}
0005433058193	101790	1992 487765	ILYA PETROV	{"email": "ipetrov1976@postgrespro.ru", "phone": "+70245125756"}
0005433058194	101790	5400 527428	YULIYA SEMENOVA	{"phone": "+70746203959"}
0005433058195	CCBC6E	3860 892279	IRINA ZHUKOVA	{"phone": "+70250502052"}
0005433058196	CCBC6E	4841 907107	YURIY FROLOV	{"email": "y.frolov-061969@postgrespro.ru", "phone": "+70680625690"}
0005433058197	CCBC6E	0511 720069	VLADIMIR FEDOTOV	{"email": "fedotovv.1973@postgrespro.ru", "phone": "+70682942267"}
0005433058198	7C682D	5111 118875	NINEL ILINA	{"email": "ninel.ilina-1985@postgrespro.ru", "phone": "+70636847462"}
0005433058199	EE0268	3609 770962	STEPAN SCHERBAKOV	{"phone": "+70717391457"}
0005433058200	EE0268	7651 309808	LIDIYA KOZLOVA	{"email": "l.kozlova1973@postgrespro.ru", "phone": "+70305663005"}
0005433058201	EE0268	5786 387133	ALINA MATVEEVA	{"phone": "+70694985690"}
0005433058202	6243EC	9650 186930	RUSHANIYA VASILEVA	{"email": "vasilevar1976@postgrespro.ru", "phone": "+70753216289"}
0005433058203	6243EC	7472 307065	MARK BELOV	{"email": "mark-belov-031971@postgrespro.ru", "phone": "+70808696352"}
0005433058204	6243EC	2894 247400	YULIYA ANISIMOVA	{"phone": "+70603381084"}
0005433058205	E6164F	2563 803350	ANDREY GRIGOREV	{"phone": "+70343217744"}
0005433058206	800D31	6914 514814	MIKHAIL FROLOV	{"email": "mikhail-frolov.04031971@postgrespro.ru", "phone": "+70238251190"}
0005433058207	800D31	7907 337518	EGOR KISELEV	{"phone": "+70107360008"}
0005433058208	A5F4F0	1145 484851	MIKHAIL SMIRNOV	{"phone": "+70850397183"}
0005433058209	C69D45	3625 995109	DENIS AFANASEV	{"phone": "+70599530869"}
0005433058210	C69D45	9124 686007	SERGEY EGOROV	{"phone": "+70099256437"}
0005433058211	C69D45	7413 562012	OLGA SCHERBAKOVA	{"phone": "+70289460205"}
0005433058212	427C61	2948 586230	BORIS SOROKIN	{"phone": "+70930830581"}
0005433058213	0E7E4D	1190 771634	ZOYA KRASNOVA	{"phone": "+70960162915"}
0005433058214	0E7E4D	8646 833405	NATALYA GERASIMOVA	{"email": "natalya.gerasimova.091969@postgrespro.ru", "phone": "+70945226665"}
0005433058215	42F4FA	0281 387666	YULIYA ROMANOVA	{"phone": "+70356733571"}
0005433058216	A2C79A	1378 965429	ANDREY BONDARENKO	{"email": "bondarenko_andrey041978@postgrespro.ru", "phone": "+70961050572"}
0005433058217	A2C79A	7862 963788	IVAN KUZMIN	{"phone": "+70805001878"}
0005433058218	93D180	0524 113669	VIKTOR MOROZOV	{"phone": "+70329629045"}
0005433058219	93D180	9559 943615	IGOR SOLOVEV	{"email": "igor.solovev-111969@postgrespro.ru", "phone": "+70537513143"}
0005433058220	DCB081	5107 131342	DANIL SAVELEV	{"phone": "+70585245392"}
0005433058221	8A2680	7505 685408	EVGENIY DENISOV	{"email": "e-denisov-011984@postgrespro.ru", "phone": "+70641804331"}
0005433058222	0383DE	4534 198076	NIKOLAY OSIPOV	{"phone": "+70003890629"}
0005433058223	DB9157	5256 629428	ANDREY IVANOV	{"phone": "+70181254825"}
0005433058224	4EADDD	4401 438768	ANASTASIYA MAKAROVA	{"phone": "+70090797234"}
0005433058225	ED52DE	4119 568125	TATYANA LEBEDEVA	{"email": "tatyana.lebedeva-041970@postgrespro.ru", "phone": "+70594337932"}
0005433058226	1877A5	2429 584248	TATYANA PAVLOVA	{"email": "pavlova.t-1974@postgrespro.ru", "phone": "+70136412936"}
0005433058227	3EBFB0	0338 968766	LYUDMILA DMITRIEVA	{"phone": "+70559543702"}
0005433058229	2FE940	1483 822769	NADEZHDA ZAYCEVA	{"phone": "+70705752678"}
0005433058230	69829B	6481 623471	ANASTASIYA ROMANOVA	{"phone": "+70589713993"}
0005433058231	3C3652	5930 848651	OLGA MEDVEDEVA	{"phone": "+70111948207"}
0005433058232	1E06D0	2277 600668	SEMEN STEPANOV	{"email": "s-stepanov-30071988@postgrespro.ru", "phone": "+70457653407"}
0005433058233	92EC02	1477 542835	DIANA NIKOLAEVA	{"email": "diana_nikolaeva-11071984@postgrespro.ru", "phone": "+70218047827"}
0005433058234	502BCE	8835 610349	EGOR BONDARENKO	{"phone": "+70385734369"}
0005433058235	502BCE	8771 650001	VIKTORIYA ROMANOVA	{"email": "v-romanova.031979@postgrespro.ru", "phone": "+70376444276"}
0005433058236	84856C	3492 313569	EVELINA VLASOVA	{"email": "vlasova-evelina.07031956@postgrespro.ru", "phone": "+70582718741"}
0005433058237	F9FC62	6782 957805	VIKTORIYA KALININA	{"email": "v-kalinina_1962@postgrespro.ru", "phone": "+70085788533"}
0005433058238	63E7F8	4040 395900	ANDREY VLASOV	{"email": "vlasov.a.1971@postgrespro.ru", "phone": "+70041636859"}
0005433058239	5744BD	5601 015102	VLADIMIR POPOV	{"email": "popovvladimir-1972@postgrespro.ru", "phone": "+70911533728"}
0005433058240	5744BD	2977 322357	VALENTINA BELOVA	{"phone": "+70109170834"}
0005433058241	FBA8EB	1796 135872	LIDIYA KRASNOVA	{"email": "krasnova_lidiya-13091975@postgrespro.ru", "phone": "+70220020522"}
0005433058242	ACE5D4	6921 638160	ANDREY KUZNECOV	{"email": "kuznecov.a041974@postgrespro.ru", "phone": "+70398272184"}
0005433058243	58F150	0404 037972	NATALIYA NIKIFOROVA	{"phone": "+70853794216"}
0005433058244	65E973	4141 499129	ELENA KOZLOVA	{"email": "elena_kozlova-04071976@postgrespro.ru", "phone": "+70953545198"}
0005433058245	E90556	5375 773385	NATALYA NIKOLAEVA	{"email": "nikolaeva_n_1979@postgrespro.ru", "phone": "+70346863790"}
0005433058246	E90556	8284 247056	TATYANA OSIPOVA	{"email": "osipova_tatyana1967@postgrespro.ru", "phone": "+70839018381"}
0005433058247	BB3187	2874 314452	BORIS NIKITIN	{"email": "boris_nikitin_09081969@postgrespro.ru", "phone": "+70774470279"}
0005433058248	BB3187	9359 386749	LYUDMILA KALININA	{"phone": "+70553953877"}
0005433058249	73D1FB	4164 901499	GALINA ALEKSEEVA	{"email": "galinaalekseeva.1972@postgrespro.ru", "phone": "+70934552345"}
0005433058250	73D1FB	8708 474727	GEORGIY KOZLOV	{"email": "georgiy.kozlov_071968@postgrespro.ru", "phone": "+70395982418"}
0005433058251	ADE099	2951 820654	ANTON DMITRIEV	{"email": "dmitriev.a-13041972@postgrespro.ru", "phone": "+70265835093"}
0005433058252	ADE099	7146 884141	LILIYA SOLOVEVA	{"email": "soloveva_liliya22071974@postgrespro.ru", "phone": "+70729955184"}
0005433058253	7D883A	4683 784919	VALENTINA MAKAROVA	{"email": "makarova-v_26051980@postgrespro.ru", "phone": "+70489919455"}
0005433058254	7D1065	4184 336582	NATALYA BELOVA	{"phone": "+70435288043"}
0005433058255	CC04BA	7256 046581	EKATERINA IVANOVA	{"email": "e_ivanova_31101968@postgrespro.ru", "phone": "+70165938758"}
0005433058256	C201CD	6641 316310	MAKSIM VASILEV	{"email": "m.vasilev_1976@postgrespro.ru", "phone": "+70879259968"}
0005433058257	C201CD	5672 890351	TATYANA IVANOVA	{"email": "t.ivanova-26041964@postgrespro.ru", "phone": "+70161511901"}
0005433058258	E6DF65	4242 822850	OLGA ANTONOVA	{"email": "olga.antonova01071965@postgrespro.ru", "phone": "+70157327099"}
0005433058259	E6DF65	3055 720389	VALERIYA SERGEEVA	{"email": "sergeeva-valeriya-1977@postgrespro.ru", "phone": "+70113172959"}
0005433058260	E6DF65	7670 492001	KONSTANTIN IVANOV	{"email": "ivanov-k.14011979@postgrespro.ru", "phone": "+70051670808"}
0005433058261	D20355	7696 906040	NIKOLAY MOISEEV	{"phone": "+70879666987"}
0005433058262	DB0BC1	3336 127421	VLADIMIR ANTONOV	{"phone": "+70231153666"}
0005433058263	ECADB5	1488 152816	EVDOKIYA NIKITINA	{"phone": "+70237238719"}
0005433058264	ECADB5	7872 194375	POLINA NIKOLAEVA	{"email": "nikolaeva_polina_1976@postgrespro.ru", "phone": "+70420229319"}
0005433058265	ECADB5	8891 419797	ALEKSANDR MOROZOV	{"email": "amorozov-1960@postgrespro.ru", "phone": "+70992121494"}
0005433058266	39A98E	4740 573464	SERGEY NAZAROV	{"phone": "+70782414135"}
0005433058267	39A98E	0707 603926	LYUDMILA MIRONOVA	{"email": "mironova.l_1976@postgrespro.ru", "phone": "+70871440760"}
0005433058268	A35131	8079 701545	YURIY IVANOV	{"phone": "+70254403778"}
0005433058269	A35131	6170 287609	ALEKSANDR NIKOLAEV	{"phone": "+70144475307"}
0005433058270	56E829	1610 185447	NATALYA ALEKSEEVA	{"phone": "+70958317454"}
0005433058271	56E829	0837 642118	ALEKSEY TARASOV	{"email": "tarasov-a1974@postgrespro.ru", "phone": "+70415102658"}
0005433058272	F832DF	6134 652627	ANATOLIY ABRAMOV	{"email": "anatoliyabramov1969@postgrespro.ru", "phone": "+70366261660"}
0005433058273	967483	3116 390993	VLADIMIR EGOROV	{"email": "egorov-v_1973@postgrespro.ru", "phone": "+70301655058"}
0005433058274	56340A	7355 351851	EKATERINA ZOTOVA	{"email": "ekaterinazotova1971@postgrespro.ru", "phone": "+70738470970"}
0005433058275	56340A	1426 178560	OLGA IVANOVA	{"phone": "+70861331388"}
0005433058276	48709C	6697 132018	RAISA IVANOVA	{"email": "ivanova.r_1967@postgrespro.ru", "phone": "+70668444695"}
0005433058277	70E9F2	3724 833158	VLADIMIR SHEVCHENKO	{"email": "vladimirshevchenko.121972@postgrespro.ru", "phone": "+70766863638"}
0005433058278	A8FE73	4870 563895	OLEG STEPANOV	{"phone": "+70890065071"}
0005433058279	1BDD09	5504 032299	TATYANA PAVLOVA	{"email": "tatyana_pavlova_1969@postgrespro.ru", "phone": "+70236743146"}
0005433058280	1BDD09	3527 140216	VERA PETROVA	{"email": "petrovav-1968@postgrespro.ru", "phone": "+70214733733"}
0005433058281	1BDD09	0451 034827	TATYANA SAVELEVA	{"email": "t.saveleva_1973@postgrespro.ru", "phone": "+70234311607"}
0005433058282	1E3D32	7894 387327	EMILIYA KOZLOVA	{"email": "kozlovae_071977@postgrespro.ru", "phone": "+70358303177"}
0005433058283	1E3D32	2720 120307	VLADIMIR VASILEV	{"phone": "+70070254715"}
0005433058284	1E3D32	6377 000287	ALEKSEY FEDOROV	{"email": "fedorov.aleksey_08061959@postgrespro.ru", "phone": "+70209419660"}
0005433058285	854E9D	1171 344546	ANDREY ILIN	{"email": "ilin-andrey_101969@postgrespro.ru", "phone": "+70503203712"}
0005433058286	980858	6022 813707	VIKTOR BORISOV	{"phone": "+70177205901"}
0005433058287	B4669C	1427 206262	ANDREY OSIPOV	{"email": "osipov.a_1979@postgrespro.ru", "phone": "+70572473734"}
0005433058288	1095C0	8632 688243	EDUARD KUZNECOV	{"email": "eduard_kuznecov1957@postgrespro.ru", "phone": "+70138232435"}
0005433058289	073123	8499 506485	PAVEL NIKITIN	{"email": "p_nikitin22111968@postgrespro.ru", "phone": "+70368618416"}
0005433058290	76D6D3	3092 087246	EKATERINA DAVYDOVA	{"email": "e_davydova1962@postgrespro.ru", "phone": "+70226406013"}
0005433058291	76D6D3	6356 212246	SERGEY KOZLOV	{"email": "sergeykozlov.09101978@postgrespro.ru", "phone": "+70361943188"}
0005433058292	79FAFE	4583 966035	ANNA NIKOLAEVA	{"email": "nikolaeva-a.031975@postgrespro.ru", "phone": "+70657549452"}
0005433058293	887431	8761 211570	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov.021977@postgrespro.ru", "phone": "+70573116742"}
0005433058294	887431	7788 987507	MAKSIM FEDOTOV	{"email": "maksimfedotov011973@postgrespro.ru", "phone": "+70520142910"}
0005433058295	A6756B	5247 164117	ALEKSEY KISELEV	{"email": "kiselevaleksey101971@postgrespro.ru", "phone": "+70282891668"}
0005433058296	56131E	0352 290302	ANNA KONDRATEVA	{"email": "anna.kondrateva.121971@postgrespro.ru", "phone": "+70510536713"}
0005433058297	56131E	0356 370226	ANNA IVANOVA	{"phone": "+70620231572"}
0005433058298	6AB0E9	3639 830626	ELIZAVETA PAVLOVA	{"email": "pavlova_e1963@postgrespro.ru", "phone": "+70771969812"}
0005433058299	6B9AD4	2622 900736	YULIYA SEMENOVA	{"email": "semenovayuliya_1968@postgrespro.ru", "phone": "+70436099800"}
0005433058300	6B9AD4	1702 481581	OLGA IVANOVA	{"phone": "+70116241566"}
0005433058301	6E9879	2524 272907	IRINA BORISOVA	{"phone": "+70015071594"}
0005433058302	616C6A	8488 039374	DMITRIY SERGEEV	{"phone": "+70137818232"}
0005433058303	FFED56	9036 302751	GALINA GORBUNOVA	{"email": "galinagorbunova051974@postgrespro.ru", "phone": "+70847896361"}
0005433058304	EAA13C	3537 924771	GALINA FROLOVA	{"email": "frolova-g_071969@postgrespro.ru", "phone": "+70362344535"}
0005433058305	BFC6BA	8867 020861	KRISTINA ZAYCEVA	{"email": "kristina.zayceva18021966@postgrespro.ru", "phone": "+70820431526"}
0005433058306	365F9B	9358 528151	OLGA BORISOVA	{"email": "o.borisova-28031966@postgrespro.ru", "phone": "+70172239177"}
0005433058307	9291C0	6228 382720	VALERIY ROMANOV	{"email": "v.romanov-1965@postgrespro.ru", "phone": "+70492096894"}
0005433058308	9291C0	4332 772068	VALENTINA MOISEEVA	{"phone": "+70839284634"}
0005433058309	CE4A87	2443 208315	EKATERINA SEMENOVA	{"email": "ekaterina.semenova_041968@postgrespro.ru", "phone": "+70298461207"}
0005433058310	6B9ED0	0275 179149	VLADIMIR SMIRNOV	{"phone": "+70040685970"}
0005433058311	E8CF28	8690 328131	NIKOLAY KOZLOV	{"email": "kozlovn061979@postgrespro.ru", "phone": "+70202519741"}
0005433058312	4A6B8C	3406 609903	VASILIY FOMIN	{"phone": "+70629335580"}
0005433058313	7018E9	9563 636186	ANDREY GORBUNOV	{"email": "gorbunov.a-06041973@postgrespro.ru", "phone": "+70843373617"}
0005433058314	7018E9	6623 026111	MARINA GUSEVA	{"phone": "+70838675672"}
0005433058315	7018E9	4382 589206	VERA GUSEVA	{"email": "guseva.v_01061977@postgrespro.ru", "phone": "+70750544001"}
0005433058316	5E795D	4206 853990	ANATOLIY VASILEV	{"email": "anatoliy_vasilev_1968@postgrespro.ru", "phone": "+70758940773"}
0005433058317	5E795D	4204 911570	SVETLANA KISELEVA	{"phone": "+70474411546"}
0005433058318	4854CC	9585 060387	LYUDMILA MELNIKOVA	{"phone": "+70201218601"}
0005433058319	B9F019	7531 852418	NADEZHDA BOGDANOVA	{"phone": "+70771432454"}
0005433058320	BA2191	7000 248869	SERGEY FROLOV	{"email": "sergeyfrolov.06011967@postgrespro.ru", "phone": "+70619099814"}
0005433058321	BA2191	1896 611919	ALEKSANDR ZHUKOV	{"phone": "+70316561190"}
0005433058322	DD9B03	4600 153755	OLESYA SOLOVEVA	{"email": "soloveva.o_091970@postgrespro.ru", "phone": "+70455505759"}
0005433058323	DD9B03	0995 186782	DMITRIY VASILEV	{"email": "vasilev.dmitriy-1974@postgrespro.ru", "phone": "+70356819172"}
0005433058324	F5AA7A	4233 203400	ANDREY MAKAROV	{"phone": "+70740193896"}
0005433058325	1D6A36	6399 536299	ILYA RODIONOV	{"email": "rodionov.i1990@postgrespro.ru", "phone": "+70959122370"}
0005433058326	1D6A36	9535 192199	BORIS SAVELEV	{"phone": "+70694401296"}
0005433058327	1D6A36	0939 209283	NADEZHDA LUKYANOVA	{"email": "lukyanovan.031964@postgrespro.ru", "phone": "+70295429968"}
0005433058328	AA6B9E	8655 370232	VENIAMIN MATVEEV	{"email": "v_matveev_031969@postgrespro.ru", "phone": "+70932256382"}
0005433058329	188F23	9620 986671	SERGEY MAKSIMOV	{"email": "sergeymaksimov-021975@postgrespro.ru", "phone": "+70466256698"}
0005433058330	188F23	6468 675787	VLADIMIR STEPANOV	{"email": "stepanov-vladimir1972@postgrespro.ru", "phone": "+70681293066"}
0005433058331	188F23	4067 759863	SVETLANA VOLKOVA	{"email": "s.volkova_07021971@postgrespro.ru", "phone": "+70791796238"}
0005433058332	D6F224	8522 300706	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.1970@postgrespro.ru", "phone": "+70492746193"}
0005433058333	51C343	2434 701851	ROMAN KISELEV	{"email": "r_kiselev_051968@postgrespro.ru", "phone": "+70733470679"}
0005433058334	BE6829	2114 669644	ANDREY KUZNECOV	{"email": "kuznecov.andrey091961@postgrespro.ru", "phone": "+70810510631"}
0005433058335	BE6829	5352 142894	DIANA FEDOROVA	{"email": "fedorova-d_031970@postgrespro.ru", "phone": "+70538037697"}
0005433058336	24DCA5	2359 879708	VALENTINA FILIPPOVA	{"phone": "+70843508694"}
0005433058337	24DCA5	2361 392976	GENNADIY MOROZOV	{"email": "morozov-gennadiy-031962@postgrespro.ru", "phone": "+70588526096"}
0005433058504	A4C57C	5656 817690	YURIY PETROV	{"phone": "+70544064608"}
0005433058338	9649B7	0456 958015	ARTEM GERASIMOV	{"email": "gerasimov_artem.24031970@postgrespro.ru", "phone": "+70606907257"}
0005433058339	9649B7	7075 936381	ALEKSANDR KONOVALOV	{"email": "konovalov_a.1968@postgrespro.ru", "phone": "+70232717970"}
0005433058340	5D62F7	9731 329756	VADIM ILIN	{"phone": "+70174345803"}
0005433058341	653C37	1137 361831	ELENA BARANOVA	{"phone": "+70108788700"}
0005433058342	653C37	6495 363836	ANNA KOMAROVA	{"email": "annakomarova.061971@postgrespro.ru", "phone": "+70182920834"}
0005433058343	6F8207	4720 528441	TATYANA MELNIKOVA	{"email": "melnikova.tatyana28081966@postgrespro.ru", "phone": "+70323347029"}
0005433058344	6F8207	0510 861949	SERGEY KUZMIN	{"email": "sergey.kuzmin-111982@postgrespro.ru", "phone": "+70855372310"}
0005433058345	253FD0	4821 331467	IRINA NAUMOVA	{"email": "naumova.i.1972@postgrespro.ru", "phone": "+70850075766"}
0005433058346	253FD0	0273 385963	VLADIMIR SOKOLOV	{"email": "sokolov.vladimir-1971@postgrespro.ru", "phone": "+70336237772"}
0005433058347	67AD39	3859 811556	IRINA KONOVALOVA	{"phone": "+70325109111"}
0005433058348	1C1722	0748 557445	IRINA GERASIMOVA	{"email": "irina-gerasimova1978@postgrespro.ru", "phone": "+70063148313"}
0005433058349	BC2846	4755 709826	ALEKSANDR ZAKHAROV	{"phone": "+70331544755"}
0005433058350	140EAF	1180 496511	OLGA TITOVA	{"email": "olga.titova071969@postgrespro.ru", "phone": "+70033536069"}
0005433058351	F864E3	8540 701230	AZAT TARASOV	{"phone": "+70069649044"}
0005433058352	CD8779	8382 871217	ALENA MOROZOVA	{"email": "morozova-alena021976@postgrespro.ru", "phone": "+70571401146"}
0005433058353	CD8779	6851 476769	DANILA BORISOV	{"phone": "+70097905555"}
0005433058354	E15659	1625 333974	ANDREY NAUMOV	{"phone": "+70596793774"}
0005433058355	F0695B	0025 428448	ALEKSANDRA ERMAKOVA	{"phone": "+70025941958"}
0005433058356	F0695B	2666 965587	VYACHESLAV CHERNOV	{"email": "vyacheslav-chernov1974@postgrespro.ru", "phone": "+70283929238"}
0005433058357	C31A2A	9462 809308	KIRILL SMIRNOV	{"email": "kirill.smirnov.18081959@postgrespro.ru", "phone": "+70782640328"}
0005433058358	E046CA	3402 773434	ANDREY DAVYDOV	{"email": "a_davydov.1969@postgrespro.ru", "phone": "+70908559836"}
0005433058359	EA45A1	7167 948879	NADEZHDA NESTEROVA	{"phone": "+70137364352"}
0005433058360	EA45A1	5761 016643	PAVEL SMIRNOV	{"phone": "+70166636522"}
0005433058361	75DADA	3396 292186	DMITRIY KOROLEV	{"email": "korolev.d_101970@postgrespro.ru", "phone": "+70061452655"}
0005433058362	C1561A	7094 332500	SVETLANA DENISOVA	{"email": "s-denisova-1964@postgrespro.ru", "phone": "+70663928692"}
0005433058363	1A7858	5034 600054	ANDREY KISELEV	{"phone": "+70129153573"}
0005433058364	1A7858	2058 882185	ILYA ALEKSEEV	{"email": "i.alekseev1956@postgrespro.ru", "phone": "+70487438432"}
0005433058365	6F58BB	1619 172296	PAVEL MIKHAYLOV	{"email": "mikhaylov_p.02081970@postgrespro.ru", "phone": "+70962674675"}
0005433058366	6F58BB	9321 547477	ALEKSANDR FOMIN	{"phone": "+70344628192"}
0005433058367	F5EC81	1315 178066	LYUDMILA KUZNECOVA	{"phone": "+70364670321"}
0005433058368	F5EC81	9871 409315	ELENA MATVEEVA	{"email": "matveeva_elena11111980@postgrespro.ru", "phone": "+70419570611"}
0005433058369	FDDFE8	4143 591498	OLGA ABRAMOVA	{"email": "o.abramova.1979@postgrespro.ru", "phone": "+70392317283"}
0005433058370	647BF4	0612 573288	PRASKOVYA ANISIMOVA	{"phone": "+70584510064"}
0005433058371	647BF4	4286 112000	ANNA MIKHAYLOVA	{"phone": "+70064338615"}
0005433058372	42D336	0563 571860	VLADISLAV RODIONOV	{"email": "vladislav.rodionov.121975@postgrespro.ru", "phone": "+70305465493"}
0005433058373	42D336	7563 481697	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr.121970@postgrespro.ru", "phone": "+70834099330"}
0005433058374	0EFB0F	8625 438783	ILYA GORBUNOV	{"email": "ilya.gorbunov26081957@postgrespro.ru", "phone": "+70382460543"}
0005433058375	0EFB0F	4957 533591	ANDREY BARANOV	{"email": "andrey_baranov.28101975@postgrespro.ru", "phone": "+70774179156"}
0005433058376	CC47B0	8550 955178	ANNA VOLKOVA	{"phone": "+70854205782"}
0005433058377	CC47B0	5543 530434	YULIYA SOROKINA	{"email": "sorokina_y-25111982@postgrespro.ru", "phone": "+70802794130"}
0005433058378	FAC020	5842 593542	ALEKSEY ANDREEV	{"email": "alekseyandreev-051958@postgrespro.ru", "phone": "+70174778650"}
0005433058379	FAC020	6454 682149	FARIDA POTAPOVA	{"phone": "+70595703583"}
0005433058380	9E9563	7182 659725	ALEKSANDRA KOVALEVA	{"email": "kovaleva-aleksandra.27091958@postgrespro.ru", "phone": "+70006391735"}
0005433058381	331CBE	9125 644911	EKATERINA SOKOLOVA	{"email": "sokolova.ekaterina.29011961@postgrespro.ru", "phone": "+70339148608"}
0005433058382	67BAD7	2627 290044	VERA SOKOLOVA	{"phone": "+70950195273"}
0005433058383	67BAD7	7381 667362	ANNA SCHERBAKOVA	{"email": "a_scherbakova.18061963@postgrespro.ru", "phone": "+70069195752"}
0005433058384	1099B6	8625 637234	ROZA ALEKSANDROVA	{"email": "aleksandrovar.091983@postgrespro.ru", "phone": "+70322224214"}
0005433058385	1099B6	2649 975841	VIKTOR TIKHONOV	{"email": "tikhonov.viktor-10041961@postgrespro.ru", "phone": "+70235652735"}
0005433058386	1099B6	8217 422708	SVETLANA SOKOLOVA	{"email": "sokolova_s.1980@postgrespro.ru", "phone": "+70560235775"}
0005433058387	C6C002	9640 050544	VALERIYA KULIKOVA	{"email": "valeriyakulikova.11111967@postgrespro.ru", "phone": "+70783545187"}
0005433058388	7891B8	1530 945418	YURIY ZHURAVLEV	{"phone": "+70120300294"}
0005433058389	2377E0	0761 397890	EVDOKIYA NESTEROVA	{"phone": "+70951966612"}
0005433058390	2377E0	8006 957599	MIKHAIL GRIGOREV	{"phone": "+70996356065"}
0005433058391	68D4DA	6295 356515	VERA SOKOLOVA	{"phone": "+70204272088"}
0005433058392	68D4DA	4321 919220	IVAN GRIGOREV	{"phone": "+70843808940"}
0005433058393	CD9257	4686 996987	IVAN ZAKHAROV	{"email": "ivan.zakharov.111969@postgrespro.ru", "phone": "+70194119947"}
0005433058394	235DA6	9178 543074	ALEKSEY NIKOLAEV	{"phone": "+70878104668"}
0005433058395	933F4B	6994 355736	ANDREY KRASNOV	{"email": "andrey_krasnov_1982@postgrespro.ru", "phone": "+70393309820"}
0005433058396	933F4B	6932 911973	RUMIYA GERASIMOVA	{"email": "gerasimova-rumiya051979@postgrespro.ru", "phone": "+70401240488"}
0005433058397	B4FCA9	4281 725582	VIKTOR ORLOV	{"phone": "+70029045562"}
0005433058398	4A8F02	3742 686766	OLEG KONOVALOV	{"phone": "+70368555299"}
0005433058399	960260	7953 519920	YULIYA TROFIMOVA	{"phone": "+70858103269"}
0005433058400	960260	8320 205929	SERGEY KUZNECOV	{"phone": "+70778767844"}
0005433058401	960260	5635 494158	ALEKSANDR MOROZOV	{"phone": "+70112662406"}
0005433058402	04831C	3506 843878	NINA DENISOVA	{"email": "denisovanina.1980@postgrespro.ru", "phone": "+70043066012"}
0005433058403	F4CF27	5624 164184	EDGAR FOMIN	{"email": "edgar-fomin18091965@postgrespro.ru", "phone": "+70300948745"}
0005433058404	5DBE14	1561 860991	YURIY KULIKOV	{"phone": "+70038398235"}
0005433058405	23A044	2768 720938	ALEKSANDR GUSEV	{"phone": "+70536557407"}
0005433058406	283B0C	3878 186022	YULIYA SIDOROVA	{"phone": "+70406372339"}
0005433058407	4E2B0F	4639 588161	YULIYA NOVIKOVA	{"email": "novikova_yuliya_011968@postgrespro.ru", "phone": "+70434286779"}
0005433058408	4E2B0F	9240 411276	TATYANA MIKHAYLOVA	{"email": "mikhaylova.t.1984@postgrespro.ru", "phone": "+70283164976"}
0005433058409	06943C	3550 228088	VERA POPOVA	{"phone": "+70767330411"}
0005433058410	06943C	3536 040146	IRAIDA KRASNOVA	{"email": "krasnova-i_03071971@postgrespro.ru", "phone": "+70717061876"}
0005433058411	8C271B	4626 720572	LYUDMILA GRISHINA	{"phone": "+70797031017"}
0005433058412	8C271B	7585 180536	VIKTOR VOLKOV	{"phone": "+70745561624"}
0005433058413	080123	4468 375114	VALERIYA NAZAROVA	{"email": "nazarova-valeriya01011975@postgrespro.ru", "phone": "+70630831543"}
0005433058414	115B8F	6956 361989	MARINA NOVIKOVA	{"phone": "+70665387562"}
0005433058415	965AAC	8233 187957	VLADISLAV GORBUNOV	{"email": "gorbunov.v_26021980@postgrespro.ru", "phone": "+70876392400"}
0005433058416	F23E2C	6466 828136	VERA SMIRNOVA	{"email": "vsmirnova.1972@postgrespro.ru", "phone": "+70621759206"}
0005433058417	F23E2C	1921 077932	ALEKSEY NOVIKOV	{"email": "novikov-a1963@postgrespro.ru", "phone": "+70256049628"}
0005433058418	ECBF94	4050 352069	DMITRIY ROMANOV	{"phone": "+70832641849"}
0005433058419	ECBF94	2484 424559	VALENTINA NAZAROVA	{"email": "nazarova-valentina-101972@postgrespro.ru", "phone": "+70877221265"}
0005433058420	AC229E	2007 604300	SVETLANA ZAYCEVA	{"phone": "+70023676553"}
0005433058421	AC229E	6659 485857	ALEKSANDR POPOV	{"email": "aleksandr_popov-01041961@postgrespro.ru", "phone": "+70964892146"}
0005433058422	AC229E	6167 576217	TATYANA PETROVA	{"email": "tpetrova.1981@postgrespro.ru", "phone": "+70493146720"}
0005433058423	386EEF	5948 711723	VADIM ZHUKOV	{"phone": "+70357924282"}
0005433058424	6014D4	8651 868561	ALEKSANDR POPOV	{"email": "aleksandr.popov1975@postgrespro.ru", "phone": "+70961506318"}
0005433058425	6014D4	1716 041537	NATALYA KONOVALOVA	{"phone": "+70441641959"}
0005433058426	6014D4	4379 137603	ELENA VLASOVA	{"phone": "+70278620724"}
0005433058427	6B0CC4	1203 987309	LIDIYA NAZAROVA	{"email": "lnazarova081965@postgrespro.ru", "phone": "+70901371565"}
0005433058428	6B0CC4	5084 165707	ALEKSANDR VLASOV	{"phone": "+70793281636"}
0005433058429	3DBCD5	8931 034177	LARISA CHERNOVA	{"email": "chernoval18111983@postgrespro.ru", "phone": "+70813194103"}
0005433058430	A503E6	5937 530977	MAKSIM SOKOLOV	{"phone": "+70611685048"}
0005433058431	A503E6	9274 785867	OKSANA MIRONOVA	{"email": "mironova_oksana.011960@postgrespro.ru", "phone": "+70690358848"}
0005433058432	A503E6	1958 358257	ALEKSANDR TIKHONOV	{"email": "aleksandr_tikhonov_061964@postgrespro.ru", "phone": "+70499230193"}
0005433058433	0CC667	2946 243813	EDUARD KONOVALOV	{"email": "eduard.konovalov1983@postgrespro.ru", "phone": "+70317711435"}
0005433058434	3C45EC	2786 499322	VALERIY KAZAKOV	{"phone": "+70308695317"}
0005433058435	3C45EC	4984 530997	DARINA DAVYDOVA	{"email": "davydova.darina.021977@postgrespro.ru", "phone": "+70706214561"}
0005433058436	41F76A	1410 936918	ROMAN SEMENOV	{"phone": "+70989830027"}
0005433058437	30CED1	9323 653772	NATALYA MOROZOVA	{"phone": "+70453410918"}
0005433058438	30CED1	7360 143672	ALEKSANDR PETROV	{"phone": "+70676677815"}
0005433058439	020F3A	3327 246667	IRINA SAVELEVA	{"email": "i_saveleva_12111976@postgrespro.ru", "phone": "+70106469675"}
0005433058440	8D4EB2	3793 206056	VIKTOR FEDOTOV	{"email": "fedotov.viktor.011977@postgrespro.ru", "phone": "+70229082933"}
0005433058441	5AC3F5	1436 876625	LYUDMILA ANTONOVA	{"email": "l-antonova.041975@postgrespro.ru", "phone": "+70546479878"}
0005433058442	77AF16	5202 248999	SALAVAT FEDOROV	{"email": "s_fedorov-1967@postgrespro.ru", "phone": "+70862386922"}
0005433058443	CB4915	2223 992821	LYUDMILA CHERNOVA	{"email": "chernovalyudmila-1983@postgrespro.ru", "phone": "+70840948666"}
0005433058444	BA3E81	9835 611623	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev_12061979@postgrespro.ru", "phone": "+70165201664"}
0005433058445	9E2272	2160 914919	PAVEL AFANASEV	{"email": "afanasev-pavel-121972@postgrespro.ru", "phone": "+70945135319"}
0005433058446	B193E5	1166 051960	LARISA SOROKINA	{"email": "larisa-sorokina041972@postgrespro.ru", "phone": "+70063922377"}
0005433058447	A52011	9489 812910	VLADISLAV TIMOFEEV	{"phone": "+70183874619"}
0005433058448	8F3AC6	7209 725622	SERGEY SOKOLOV	{"email": "sergeysokolov1969@postgrespro.ru", "phone": "+70122035856"}
0005433058449	7CD720	3941 525522	NINA GERASIMOVA	{"email": "gerasimova_nina-07081983@postgrespro.ru", "phone": "+70853989803"}
0005433058450	7CD720	8513 935772	SERGEY STEPANOV	{"phone": "+70219433974"}
0005433058451	5D83C5	2275 808523	MIKHAIL ISAEV	{"email": "m.isaev_1981@postgrespro.ru", "phone": "+70323237301"}
0005433058452	5D83C5	5085 138691	ALEKSEY ANDREEV	{"phone": "+70419835275"}
0005433058453	58EF98	3382 921551	ISLAM GORBUNOV	{"phone": "+70411309165"}
0005433058454	58EF98	7247 849737	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey-1987@postgrespro.ru", "phone": "+70672629058"}
0005433058455	0C633A	9446 015055	ANGELINA KUZNECOVA	{"email": "angelina_kuznecova_30011969@postgrespro.ru", "phone": "+70728178994"}
0005433058456	0C633A	1006 675315	OLGA NESTEROVA	{"email": "nesterova.olga_03111972@postgrespro.ru", "phone": "+70080404367"}
0005433058457	B6509F	2613 372250	LYUDMILA RODIONOVA	{"email": "lyudmilarodionova1981@postgrespro.ru", "phone": "+70145168589"}
0005433058458	B6509F	9542 668842	DINA POPOVA	{"email": "dina_popova.10061981@postgrespro.ru", "phone": "+70561156200"}
0005433058459	08DB55	1147 760157	MARINA SOKOLOVA	{"phone": "+70494814676"}
0005433058460	6EAF98	9086 681410	TATYANA ZAKHAROVA	{"phone": "+70297553853"}
0005433058461	DBB1DA	5020 457432	VLADIMIR POPOV	{"email": "popovvladimir-27111976@postgrespro.ru", "phone": "+70693131867"}
0005433058462	D6D17C	1201 516747	NADEZHDA MOROZOVA	{"email": "morozova_n_091973@postgrespro.ru", "phone": "+70141494545"}
0005433058463	D6D17C	7057 492307	IRINA RODIONOVA	{"phone": "+70781666311"}
0005433058464	A4D52B	9915 617405	ALEKSANDR NOVIKOV	{"email": "aleksandr_novikov_25121969@postgrespro.ru", "phone": "+70872676130"}
0005433058465	67C458	3023 754451	ARTEM NIKOLAEV	{"email": "artem.nikolaev.17051985@postgrespro.ru", "phone": "+70279831816"}
0005433058466	7867B8	6786 798050	ZOYA TIKHONOVA	{"email": "tikhonova.zoya.1972@postgrespro.ru", "phone": "+70809739994"}
0005433058467	7867B8	9736 337601	GALINA IVANOVA	{"email": "galinaivanova111981@postgrespro.ru", "phone": "+70038936598"}
0005433058468	7F19E0	0269 647015	NIKOLAY BARANOV	{"email": "baranov-nikolay_031976@postgrespro.ru", "phone": "+70317526776"}
0005433058469	E93B5A	7565 028066	EKATERINA VASILEVA	{"phone": "+70831042914"}
0005433058470	A3D9CF	0275 670101	NINA MOROZOVA	{"email": "morozova.nina041965@postgrespro.ru", "phone": "+70944635602"}
0005433058471	A3D9CF	6371 262426	VALERIY EGOROV	{"email": "egorov_v13011964@postgrespro.ru", "phone": "+70152465190"}
0005433058472	A4B821	2948 546131	SERGEY KUZNECOV	{"phone": "+70235022651"}
0005433058473	C3B2D3	5946 763968	ANNA KUZNECOVA	{"email": "kuznecova_anna.15061977@postgrespro.ru", "phone": "+70507674333"}
0005433058474	40503B	3216 698413	ELENA YAKOVLEVA	{"email": "yakovleva-e1977@postgrespro.ru", "phone": "+70108744888"}
0005433058475	75BCA1	9898 184246	ARTEM AFANASEV	{"phone": "+70587451073"}
0005433058476	75BCA1	4604 131845	NADEZHDA NOVIKOVA	{"phone": "+70634911491"}
0005433058477	180098	8622 228135	VERA KUZNECOVA	{"phone": "+70995676250"}
0005433058478	180098	1169 040429	ALEKSANDR DAVYDOV	{"email": "a.davydov1980@postgrespro.ru", "phone": "+70055586247"}
0005433058479	F5F51E	7039 385471	VASILIY MELNIKOV	{"phone": "+70112530344"}
0005433058480	F5F51E	7380 078861	EKATERINA ALEKSEEVA	{"phone": "+70258368706"}
0005433058481	E8AD93	9706 294467	LARISA BOGDANOVA	{"phone": "+70108529245"}
0005433058482	E8AD93	6293 064116	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-22011970@postgrespro.ru", "phone": "+70360525601"}
0005433058483	E8AD93	7691 208993	ZINAIDA MIKHAYLOVA	{"phone": "+70842774241"}
0005433058484	4AC86E	7160 803135	ELENA ALEKSEEVA	{"email": "e-alekseeva.10101976@postgrespro.ru", "phone": "+70911160799"}
0005433058485	745BCE	0137 234255	VLADIMIR ISAEV	{"email": "v.isaev.1967@postgrespro.ru", "phone": "+70954183002"}
0005433058486	3F11B8	9584 973940	ALENA VASILEVA	{"phone": "+70812016748"}
0005433058487	3F11B8	2612 993295	ANDREY VLASOV	{"email": "vlasov.andrey.1984@postgrespro.ru", "phone": "+70208055834"}
0005433058488	472A17	3562 026278	IGOR GERASIMOV	{"email": "gerasimovigor.10121971@postgrespro.ru", "phone": "+70013522552"}
0005433058489	472A17	2544 403936	OLGA ILINA	{"phone": "+70140578891"}
0005433058490	E3BCA2	1273 699531	TATYANA ZOTOVA	{"phone": "+70341520081"}
0005433058491	B12050	9196 772384	ALEKSANDR POPOV	{"phone": "+70918015011"}
0005433058492	B12050	3143 194830	SERGEY CHERNOV	{"phone": "+70368826478"}
0005433058493	F412BB	2332 079678	KSENIYA BELOVA	{"email": "kseniya_belova-101961@postgrespro.ru", "phone": "+70573056732"}
0005433058494	2A3F5C	8715 190947	EVDOKIYA LOGINOVA	{"email": "loginova_e.071967@postgrespro.ru", "phone": "+70710215675"}
0005433058495	0E58A6	1917 614051	YURIY PETROV	{"phone": "+70380412467"}
0005433058496	96CD7B	6645 146737	BORIS DMITRIEV	{"email": "b.dmitriev041967@postgrespro.ru", "phone": "+70653525133"}
0005433058497	96CD7B	6763 066047	ANATOLIY IVANOV	{"email": "a.ivanov.08031977@postgrespro.ru", "phone": "+70214482482"}
0005433058498	F11D58	8589 174541	KAMILLA TARASOVA	{"email": "tarasova-k_17051977@postgrespro.ru", "phone": "+70516641337"}
0005433058499	10E7C8	3832 430692	PAVEL KUZNECOV	{"email": "pavel_kuznecov.1975@postgrespro.ru", "phone": "+70755028932"}
0005433058500	10E7C8	0162 518390	EVGENIYA KOROLEVA	{"email": "evgeniya_koroleva.19081972@postgrespro.ru", "phone": "+70656988013"}
0005433058501	649E62	0126 366236	TATYANA TARASOVA	{"email": "tarasovatatyana_1963@postgrespro.ru", "phone": "+70987478802"}
0005433058502	9E426A	0450 187551	DMITRIY GAVRILOV	{"phone": "+70434643982"}
0005433058503	9E426A	1368 712548	MARIYA GUSEVA	{"phone": "+70695870939"}
0005433058505	9A684E	5402 505182	TATYANA OVCHINNIKOVA	{"phone": "+70464253150"}
0005433058506	E401A1	2523 534084	SVETLANA STEPANOVA	{"email": "s-stepanova-041970@postgrespro.ru", "phone": "+70393947740"}
0005433058507	5A1CEE	6317 432002	SERGEY SAVELEV	{"email": "savelev-sergey-01121964@postgrespro.ru", "phone": "+70222871771"}
0005433058508	AC358D	8422 376152	MARINA ILINA	{"phone": "+70127211167"}
0005433058509	7C3432	5026 976816	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova-nadezhda_24111968@postgrespro.ru", "phone": "+70781845855"}
0005433058510	7C3432	4095 764237	VADIM BARANOV	{"email": "vadim_baranov_1974@postgrespro.ru", "phone": "+70315864305"}
0005433058511	2DA6A3	1165 053770	GEORGIY KUZNECOV	{"email": "georgiykuznecov021980@postgrespro.ru", "phone": "+70558603121"}
0005433058512	2D2051	8062 175972	IGOR AFANASEV	{"phone": "+70766427215"}
0005433058513	A9D4D7	1829 476687	MARIYA ROMANOVA	{"phone": "+70562710291"}
0005433058623	7B86B7	0252 558403	NADEZHDA KISELEVA	{"phone": "+70041127485"}
0005433058514	B3B70A	9251 490721	LARISA EFIMOVA	{"email": "larisa-efimova.051967@postgrespro.ru", "phone": "+70047544156"}
0005433058515	B3B70A	3528 458299	GALINA SMIRNOVA	{"email": "gsmirnova_09061963@postgrespro.ru", "phone": "+70766417020"}
0005433058516	46F50B	7151 857848	VLADIMIR AFANASEV	{"phone": "+70747225464"}
0005433058517	8B8B76	7264 817934	LYUDMILA MIRONOVA	{"phone": "+70357675551"}
0005433058518	8B8B76	6833 936698	OLGA LOGINOVA	{"email": "olga-loginova061958@postgrespro.ru", "phone": "+70244531150"}
0005433058519	1AA307	0927 806314	LYUDMILA ERMAKOVA	{"phone": "+70735111897"}
0005433058520	1AA307	5667 258310	IGOR IVANOV	{"email": "ivanov-igor-1982@postgrespro.ru", "phone": "+70227884216"}
0005433058521	17C615	3284 718462	YANA GRISHINA	{"phone": "+70549276468"}
0005433058522	38AC4D	4206 864794	MIKHAIL KONOVALOV	{"phone": "+70030339375"}
0005433058523	38AC4D	8509 822825	TATYANA SAVELEVA	{"phone": "+70755791556"}
0005433058524	1FEEA9	3451 090639	ANATOLIY ANTONOV	{"email": "antonova-1975@postgrespro.ru", "phone": "+70769370567"}
0005433058525	1FEEA9	7887 408909	VLADIMIR MOROZOV	{"email": "v-morozov-19121966@postgrespro.ru", "phone": "+70271849448"}
0005433058526	8AB2C4	0617 261966	ALEKSEY IVANOV	{"phone": "+70600645915"}
0005433058527	94320D	5088 220935	ANATOLIY ANDREEV	{"phone": "+70513314468"}
0005433058528	262071	1260 159618	OLGA LUKYANOVA	{"phone": "+70175835051"}
0005433058529	262071	2456 431057	ARINA NESTEROVA	{"email": "nesterova-arina_041974@postgrespro.ru", "phone": "+70366802746"}
0005433058530	0749A2	0883 696685	PAVEL VOROBEV	{"email": "p.vorobev.061969@postgrespro.ru", "phone": "+70552943153"}
0005433058531	0749A2	0597 923494	ALEKSANDRA FEDOROVA	{"phone": "+70985179945"}
0005433058532	0749A2	2935 054007	NATALYA KOMAROVA	{"phone": "+70813186781"}
0005433058533	0749A2	6753 619545	RINAT PAVLOV	{"email": "r.pavlov_091972@postgrespro.ru", "phone": "+70396878073"}
0005433058534	142B20	1418 757108	ALEKSANDR ILIN	{"email": "aleksandr.ilin07081967@postgrespro.ru", "phone": "+70439767586"}
0005433058535	4BC5C9	7623 132246	DMITRIY ZAKHAROV	{"phone": "+70213831080"}
0005433058536	585566	9171 882607	TATYANA PAVLOVA	{"phone": "+70215705880"}
0005433058537	9C4F4C	7082 638367	ANATOLIY ALEKSANDROV	{"email": "aleksandrova07061972@postgrespro.ru", "phone": "+70785821238"}
0005433058538	9C4F4C	0812 041161	VLADIMIR SAVELEV	{"email": "vladimir-savelev1977@postgrespro.ru", "phone": "+70506546861"}
0005433058539	9C4F4C	5969 682678	VLADIMIR ORLOV	{"phone": "+70528605261"}
0005433058540	F1EEC4	1808 349975	ALENA BARANOVA	{"email": "baranovaalena-081980@postgrespro.ru", "phone": "+70410312513"}
0005433058541	F1EEC4	5321 751356	MARIYA SAVELEVA	{"phone": "+70784750821"}
0005433058542	F1EEC4	1824 308383	LARISA KUZNECOVA	{"email": "kuznecova.l-28121981@postgrespro.ru", "phone": "+70885346932"}
0005433058543	A53197	2670 278203	ALEKSANDR OSIPOV	{"phone": "+70822336398"}
0005433058544	A53197	0867 702596	KRISTINA NIKOLAEVA	{"phone": "+70577715931"}
0005433058545	BFF42C	1742 687357	GENNADIY NIKITIN	{"email": "nikitin-g_071970@postgrespro.ru", "phone": "+70619388449"}
0005433058546	BFF42C	5417 593418	IVAN DMITRIEV	{"email": "dmitriev_ivan_1964@postgrespro.ru", "phone": "+70787291872"}
0005433058547	FC646E	0015 737493	VIKTOR SCHERBAKOV	{"email": "v-scherbakov111980@postgrespro.ru", "phone": "+70561097940"}
0005433058548	4A4E43	4792 105785	MARIYA SMIRNOVA	{"email": "mariya-smirnova_22061964@postgrespro.ru", "phone": "+70563623488"}
0005433058549	61CF8E	6147 797142	DMITRIY PETROV	{"phone": "+70996370758"}
0005433058550	61CF8E	6482 918600	SERGEY KARPOV	{"phone": "+70160111611"}
0005433058551	BCAC3A	9843 830005	ALEKSANDR FOMIN	{"phone": "+70106023665"}
0005433058552	31290E	6753 769542	ALEKSANDRA NIKIFOROVA	{"phone": "+70152713248"}
0005433058553	E47A36	0966 995511	LYUDMILA FADEEVA	{"phone": "+70347402666"}
0005433058554	E47A36	5749 226703	LYUBOV IVANOVA	{"email": "ivanoval_29111959@postgrespro.ru", "phone": "+70244528911"}
0005433058555	E958DA	9796 497983	ANASTASIYA MOROZOVA	{"email": "morozovaanastasiya.111972@postgrespro.ru", "phone": "+70211398921"}
0005433058556	E958DA	6391 394367	ANTON FOMIN	{"email": "a_fomin.1973@postgrespro.ru", "phone": "+70814098846"}
0005433058557	5FFC85	8708 439781	VASILIY ANDREEV	{"email": "vasiliy_andreev_17081972@postgrespro.ru", "phone": "+70464930682"}
0005433058558	989BB8	7226 325449	EVGENIY KULIKOV	{"phone": "+70683432658"}
0005433058559	AACECE	1868 139153	DMITRIY VASILEV	{"email": "dmitriy-vasilev_1988@postgrespro.ru", "phone": "+70417272586"}
0005433058560	3E4895	5225 863654	VIKTORIYA IVANOVA	{"email": "vivanova20111969@postgrespro.ru", "phone": "+70557105266"}
0005433058561	D2E7F5	8324 277797	SERGEY KUZMIN	{"email": "sergey-kuzmin.08091976@postgrespro.ru", "phone": "+70270118846"}
0005433058562	EA0054	9357 100664	VIKTOR AFANASEV	{"email": "viktor_afanasev-011976@postgrespro.ru", "phone": "+70570462961"}
0005433058563	1D5A54	8615 369617	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr_1973@postgrespro.ru", "phone": "+70532673836"}
0005433058564	1D5A54	7998 547374	NADEZHDA EGOROVA	{"email": "egorovanadezhda_26111978@postgrespro.ru", "phone": "+70057806868"}
0005433058565	F306C7	9216 110062	LYUDMILA POLYAKOVA	{"email": "polyakovalyudmila_091973@postgrespro.ru", "phone": "+70793627361"}
0005433058566	3D4CAB	2219 205600	ALEKSEY DENISOV	{"email": "denisova-1970@postgrespro.ru", "phone": "+70407591786"}
0005433058567	3D4CAB	5618 581389	VIKTOR SAVELEV	{"email": "v-savelev1959@postgrespro.ru", "phone": "+70653159098"}
0005433058568	633007	9404 912448	ANNA NESTEROVA	{"email": "nesterovaa-08011968@postgrespro.ru", "phone": "+70699290948"}
0005433058569	FAE58C	6576 276213	RAVIL TIKHONOV	{"email": "ravil_tikhonov-1970@postgrespro.ru", "phone": "+70716980196"}
0005433058570	FAE58C	5980 211661	LYUDMILA STEPANOVA	{"phone": "+70272506837"}
0005433058571	FAE58C	8197 536058	NADEZHDA TROFIMOVA	{"email": "ntrofimova.031964@postgrespro.ru", "phone": "+70029415293"}
0005433058572	89F17A	8829 911862	OLGA AFANASEVA	{"email": "olga.afanaseva071969@postgrespro.ru", "phone": "+70249440718"}
0005433058573	F61333	9865 606649	SERGEY NAZAROV	{"phone": "+70627066087"}
0005433058574	F61333	2536 686972	VLADIMIR VOROBEV	{"email": "vorobevvladimir.24021979@postgrespro.ru", "phone": "+70580009192"}
0005433058575	D43C7A	3194 279557	NADEZHDA MAKAROVA	{"email": "makarova_n14011967@postgrespro.ru", "phone": "+70593269619"}
0005433058576	D43C7A	7582 292899	YURIY SEMENOV	{"email": "yuriy-semenov_21021981@postgrespro.ru", "phone": "+70030651748"}
0005433058577	D43C7A	1949 130547	SERGEY MAKAROV	{"email": "sergey_makarov.091981@postgrespro.ru", "phone": "+70814697415"}
0005433058578	5222C4	6584 166183	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.aleksandr-1960@postgrespro.ru", "phone": "+70400055121"}
0005433058579	BF54F9	9616 681083	IVAN SOKOLOV	{"phone": "+70482289847"}
0005433058580	BF54F9	5367 567712	LYUBOV KAZAKOVA	{"email": "l.kazakova101971@postgrespro.ru", "phone": "+70915354155"}
0005433058581	A791C1	9080 731065	ALEKSANDR GORBUNOV	{"phone": "+70114696510"}
0005433058582	635C2E	9881 736046	LYUBOV PETROVA	{"email": "l.petrova-01111962@postgrespro.ru", "phone": "+70470727055"}
0005433058583	635C2E	0614 259576	TATYANA PAVLOVA	{"phone": "+70337892670"}
0005433058584	46882C	3207 236220	ALEKSANDRA ANISIMOVA	{"phone": "+70116612164"}
0005433058585	46882C	5584 322238	ANNA ALEKSEEVA	{"email": "alekseeva_a.30111971@postgrespro.ru", "phone": "+70105098265"}
0005433058586	A0DA24	8737 832033	YURIY NIKOLAEV	{"phone": "+70175925739"}
0005433058587	E7DF4C	9817 145047	VALERIY IVANOV	{"email": "ivanov.valeriy.1973@postgrespro.ru", "phone": "+70516941810"}
0005433058588	C3F515	1816 970662	PAVEL ABRAMOV	{"email": "abramov.p-02121971@postgrespro.ru", "phone": "+70861090706"}
0005433058589	2AE800	2651 342493	ANASTASIYA POLYAKOVA	{"phone": "+70123774936"}
0005433058590	F639A2	2748 259846	ZOYA SOKOLOVA	{"phone": "+70272079935"}
0005433058591	317A5B	8840 472782	ALEKSEY ORLOV	{"email": "orlov-aleksey-1972@postgrespro.ru", "phone": "+70550388024"}
0005433058592	817ED3	2674 015707	ALEKSEY VASILEV	{"phone": "+70975902245"}
0005433058593	6E4A46	6690 979123	KONSTANTIN NOVIKOV	{"email": "novikov.k.051968@postgrespro.ru", "phone": "+70386847546"}
0005433058594	6E4A46	4872 798171	MIKHAIL IVANOV	{"email": "mivanov1975@postgrespro.ru", "phone": "+70158605414"}
0005433058595	B5F508	3025 295679	VALENTINA NOVIKOVA	{"phone": "+70621128211"}
0005433058596	4FD22B	2919 522352	ANTON MOROZOV	{"email": "a-morozov.101977@postgrespro.ru", "phone": "+70633013077"}
0005433058597	6884E4	1820 113570	TAMARA BORISOVA	{"email": "borisova.tamara.03121974@postgrespro.ru", "phone": "+70031116549"}
0005433058598	68ED40	2765 083845	IRINA IVANOVA	{"email": "iivanova.1957@postgrespro.ru", "phone": "+70793126782"}
0005433058599	D98924	3768 003893	ELENA ALEKSANDROVA	{"email": "elenaaleksandrova.01091976@postgrespro.ru", "phone": "+70160880935"}
0005433058600	D98924	5752 312483	GEORGIY MELNIKOV	{"email": "melnikovg_071970@postgrespro.ru", "phone": "+70336961555"}
0005433058601	D98924	6481 450320	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva-1985@postgrespro.ru", "phone": "+70296423793"}
0005433058602	148F36	0617 898256	VADIM MIRONOV	{"email": "mironov-vadim.1982@postgrespro.ru", "phone": "+70324553982"}
0005433058603	826D6F	0555 431391	VERA KAZAKOVA	{"phone": "+70785894200"}
0005433058604	BCD340	4426 773979	NINA GAVRILOVA	{"email": "gavrilova-n.081973@postgrespro.ru", "phone": "+70403184075"}
0005433058605	E90421	3777 547419	LYUDMILA FADEEVA	{"email": "fadeeva-lyudmila15081971@postgrespro.ru", "phone": "+70136946270"}
0005433058606	E90421	5264 076971	ELENA MOISEEVA	{"phone": "+70633203770"}
0005433058607	C3D762	8339 184816	DMITRIY MOROZOV	{"email": "d_morozov.1967@postgrespro.ru", "phone": "+70497006657"}
0005433058608	59416E	2364 598085	NATALYA SOKOLOVA	{"email": "sokolova_natalya-09101973@postgrespro.ru", "phone": "+70270021469"}
0005433058609	59416E	2449 448778	IGOR ALEKSEEV	{"phone": "+70618150369"}
0005433058610	977C0B	2155 702427	VITALIY YAKOVLEV	{"email": "v-yakovlev.051974@postgrespro.ru", "phone": "+70106001607"}
0005433058611	4BFF54	1712 014262	VLADIMIR VASILEV	{"email": "v_vasilev091966@postgrespro.ru", "phone": "+70477059511"}
0005433058612	339E4D	2170 361144	VALERIY SIDOROV	{"email": "sidorov.valeriy041974@postgrespro.ru", "phone": "+70485883257"}
0005433058613	8A3205	4331 823110	SERGEY ANTONOV	{"phone": "+70500125884"}
0005433058614	5551C1	5990 121213	GALINA KARPOVA	{"email": "galina_karpova061962@postgrespro.ru", "phone": "+70605169271"}
0005433058615	6FCB48	5026 394340	SERGEY KUDRYASHOV	{"email": "s-kudryashov_101979@postgrespro.ru", "phone": "+70382700714"}
0005433058616	2B47D4	8386 529315	ELENA KUZMINA	{"email": "kuzmina.e.14051975@postgrespro.ru", "phone": "+70524957469"}
0005433058617	C50094	6945 796069	VALENTINA GORBUNOVA	{"phone": "+70291443679"}
0005433058618	C50094	1511 322531	VLADIMIR SOLOVEV	{"email": "solovev-v_24061969@postgrespro.ru", "phone": "+70314637393"}
0005433058619	651CBF	1283 653788	ANTONINA SIDOROVA	{"email": "sidorova_antonina071962@postgrespro.ru", "phone": "+70364379969"}
0005433058620	1B0C43	9022 056522	SERGEY DENISOV	{"email": "denisov_sergey_1969@postgrespro.ru", "phone": "+70901260055"}
0005433058621	C773EA	3119 199728	ALEKSANDR MAKAROV	{"email": "makarova_28031975@postgrespro.ru", "phone": "+70073135024"}
0005433058622	C773EA	6828 985759	VIKTOR NOVIKOV	{"phone": "+70084282381"}
0005433058624	7B86B7	5812 581992	MAKSIM VOLKOV	{"phone": "+70582607818"}
0005433058625	0EF835	2963 354328	ELENA MATVEEVA	{"email": "matveevae.1984@postgrespro.ru", "phone": "+70865622051"}
0005433058626	22E9A2	0475 823932	VERA ZAKHAROVA	{"phone": "+70996825161"}
0005433058627	2269A5	5542 525663	NIKITA SMIRNOV	{"email": "smirnov-n_14021972@postgrespro.ru", "phone": "+70216494404"}
0005433058628	5A9B8D	4767 052349	NADEZHDA BOGDANOVA	{"phone": "+70218083748"}
0005433058629	5A9B8D	2236 020716	ROMAN MAKAROV	{"phone": "+70034777351"}
0005433058630	D70399	5834 727631	NINA ANDREEVA	{"phone": "+70855692670"}
0005433058631	1DB5C3	6172 964719	LARISA SEMENOVA	{"phone": "+70484449095"}
0005433058632	1DB5C3	7898 691998	TIMOFEY KULIKOV	{"email": "kulikov.t.071965@postgrespro.ru", "phone": "+70460794866"}
0005433058633	1DB5C3	7580 306651	NIKOLAY DMITRIEV	{"email": "dmitrievnikolay1979@postgrespro.ru", "phone": "+70996311303"}
0005433058634	1DB5C3	7304 985352	ANATOLIY STEPANOV	{"email": "anatoliy-stepanov.1973@postgrespro.ru", "phone": "+70198677959"}
0005433058635	B81EBF	5760 088404	SERGEY KUZNECOV	{"email": "kuznecovs_27071965@postgrespro.ru", "phone": "+70337984259"}
0005433058636	B81EBF	8106 825029	LYUDMILA KUZNECOVA	{"email": "kuznecoval-1981@postgrespro.ru", "phone": "+70097377701"}
0005433058637	E6FF5D	3194 607184	YULIYA YAKOVLEVA	{"phone": "+70037240351"}
0005433058638	66C64B	3278 750900	MARINA KOZLOVA	{"email": "marina_kozlova1973@postgrespro.ru", "phone": "+70309831612"}
0005433058639	A2B7BE	6873 234735	ELIZAVETA IVANOVA	{"email": "eivanova11011966@postgrespro.ru", "phone": "+70146268486"}
0005433058640	EAA722	0829 785120	SVETLANA ABRAMOVA	{"phone": "+70250287354"}
0005433058641	59D123	2052 805530	MARIYA KALININA	{"email": "m_kalinina.19041971@postgrespro.ru", "phone": "+70839251465"}
0005433058642	A43084	0645 511050	KSENIYA KOROLEVA	{"email": "koroleva_kseniya_071973@postgrespro.ru", "phone": "+70174577890"}
0005433058643	CDC52D	4120 120105	MARIYA SOKOLOVA	{"phone": "+70047908790"}
0005433058644	CDC52D	4500 227107	MARIYA TROFIMOVA	{"email": "trofimovamariya_08051955@postgrespro.ru", "phone": "+70078350792"}
0005433058645	2DAB6C	8307 744683	DINA RODIONOVA	{"phone": "+70131549158"}
0005433058646	2DAB6C	6677 752652	OKSANA ARKHIPOVA	{"phone": "+70747202165"}
0005433058647	2DAB6C	8947 343505	ANNA TITOVA	{"email": "annatitova.05031970@postgrespro.ru", "phone": "+70429933535"}
0005433058648	9EA216	2703 566083	TATYANA POTAPOVA	{"phone": "+70245765545"}
0005433058649	E1F479	2713 354616	ALEKSANDR KARPOV	{"phone": "+70335025851"}
0005433058650	E1F479	2034 648558	TATYANA EFIMOVA	{"email": "t_efimova-1974@postgrespro.ru", "phone": "+70278673354"}
0005433058651	F76183	3772 786521	LYUBOV ZOTOVA	{"email": "zotova_l.28101976@postgrespro.ru", "phone": "+70438668985"}
0005433058652	BB6625	8245 448822	ROMAN MATVEEV	{"email": "matveev-r1979@postgrespro.ru", "phone": "+70533866138"}
0005433058653	AA346B	2150 845273	ELENA SAVELEVA	{"phone": "+70463655156"}
0005433058654	AA346B	2945 430072	ANASTASIYA POTAPOVA	{"phone": "+70250824049"}
0005433058655	2F6539	4605 998415	LARISA ZAKHAROVA	{"phone": "+70675062244"}
0005433058656	366268	6738 793526	NATALYA EGOROVA	{"email": "egorovanatalya.08011972@postgrespro.ru", "phone": "+70640074132"}
0005433058657	6FEF75	4319 321997	GALINA MOISEEVA	{"email": "moiseeva.galina_081970@postgrespro.ru", "phone": "+70486971446"}
0005433058658	23F34A	9914 137732	LYUDMILA LAZAREVA	{"phone": "+70022320403"}
0005433058659	23F34A	0108 980357	IVAN CHERNOV	{"email": "chernov_ivan_16031970@postgrespro.ru", "phone": "+70754357604"}
0005433058660	23F34A	7877 621616	VLADIMIR GRIGOREV	{"phone": "+70428116235"}
0005433058661	65C078	1483 982332	LARISA GUSEVA	{"phone": "+70547186464"}
0005433058662	30ADE4	9371 181290	ANDREY PAVLOV	{"phone": "+70593729045"}
0005433058663	E98468	0937 380776	NIKOLAY MELNIKOV	{"phone": "+70544546392"}
0005433058664	E98468	3077 453038	SERGEY MIKHAYLOV	{"email": "mikhaylov.s.021971@postgrespro.ru", "phone": "+70303710386"}
0005433058665	66F8D7	8077 213901	KONSTANTIN SEMENOV	{"email": "konstantin.semenov.07061965@postgrespro.ru", "phone": "+70485796257"}
0005433058666	2A6969	2759 390782	TAISIYA PETROVA	{"email": "taisiya-petrova_091978@postgrespro.ru", "phone": "+70083907136"}
0005433058667	A160DA	9555 556491	KONSTANTIN DAVYDOV	{"email": "k.davydov_121974@postgrespro.ru", "phone": "+70746246743"}
0005433058668	A160DA	5554 471121	LARISA KOLESNIKOVA	{"phone": "+70193091983"}
0005433058669	C6E8F7	3622 528874	OLGA KOVALEVA	{"phone": "+70534219186"}
0005433058670	A6C91D	6704 621827	SVETLANA EGOROVA	{"phone": "+70028956050"}
0005433058730	B8EC01	9754 903923	YURIY FROLOV	{"phone": "+70287912392"}
0005433058671	A6C91D	8893 597667	VLADISLAV ROMANOV	{"email": "vromanov.08071979@postgrespro.ru", "phone": "+70043659159"}
0005433058672	812B52	0632 995429	NADEZHDA KOZLOVA	{"email": "kozlova-n_111977@postgrespro.ru", "phone": "+70801665065"}
0005433058673	812B52	0569 068625	TATYANA DMITRIEVA	{"email": "dmitrieva.tatyana-19081976@postgrespro.ru", "phone": "+70078218781"}
0005433058674	5B8EBE	7775 958743	IVAN PETROV	{"email": "i_petrov.111969@postgrespro.ru", "phone": "+70932805161"}
0005433058675	640757	2192 703824	EKATERINA KULIKOVA	{"email": "e_kulikova_011972@postgrespro.ru", "phone": "+70645683471"}
0005433058676	640757	7588 983816	MARIYA DAVYDOVA	{"phone": "+70205386748"}
0005433058677	960400	5352 880411	YULIYA FILATOVA	{"phone": "+70704083321"}
0005433058678	78BBE9	9344 218571	OLESYA KOVALEVA	{"email": "kovaleva.olesya_19061972@postgrespro.ru", "phone": "+70706375380"}
0005433058679	CB0AA2	7384 818734	RIMMA NIKIFOROVA	{"email": "rimma.nikiforova071981@postgrespro.ru", "phone": "+70411867901"}
0005433058680	FAA259	3049 243479	TATYANA FADEEVA	{"email": "fadeeva-t_101965@postgrespro.ru", "phone": "+70948714002"}
0005433058681	FAA259	8177 308469	LYUDMILA IVANOVA	{"email": "livanova-1977@postgrespro.ru", "phone": "+70582965348"}
0005433058682	E7AD81	2339 441844	EVGENIY IVANOV	{"email": "e-ivanov_1981@postgrespro.ru", "phone": "+70578300623"}
0005433058683	277709	3377 745856	MAKAR SOLOVEV	{"phone": "+70926021442"}
0005433058684	689545	0715 350157	IGOR FEDOTOV	{"email": "fedotov-igor1970@postgrespro.ru", "phone": "+70647532709"}
0005433058685	689545	1198 415748	ALEVTINA FEDOROVA	{"phone": "+70486848608"}
0005433058686	67153D	3770 087137	EKATERINA BELYAEVA	{"email": "belyaeva.ekaterina.22041967@postgrespro.ru", "phone": "+70217520513"}
0005433058687	3DACFA	5068 525475	VIKTORIYA EGOROVA	{"phone": "+70379948778"}
0005433058688	8D9C3F	9651 675340	NATALYA SMIRNOVA	{"email": "smirnovanatalya_071980@postgrespro.ru", "phone": "+70928614468"}
0005433058689	1767EC	9912 777299	SERGEY CHERNOV	{"email": "chernovsergey1978@postgrespro.ru", "phone": "+70258618337"}
0005433058690	1767EC	8923 163095	SERGEY VASILEV	{"email": "s-vasilev-16081979@postgrespro.ru", "phone": "+70420891634"}
0005433058691	8A3BA6	4408 039570	TATYANA STEPANOVA	{"email": "tatyanastepanova-041969@postgrespro.ru", "phone": "+70119736020"}
0005433058692	8A3BA6	3769 443550	GEORGIY GORBUNOV	{"phone": "+70554956054"}
0005433058693	8A3BA6	0694 021406	TATYANA SERGEEVA	{"phone": "+70764514079"}
0005433058694	CFF36E	8885 022069	ELIZAVETA NESTEROVA	{"phone": "+70514042352"}
0005433058695	C534ED	9210 954004	NADEZHDA GORBUNOVA	{"phone": "+70579875686"}
0005433058696	C534ED	4662 277180	ALEKSANDR MARTYNOV	{"phone": "+70207325946"}
0005433058697	E85CB5	5883 953229	VYACHESLAV FOMIN	{"email": "v.fomin_1979@postgrespro.ru", "phone": "+70068231336"}
0005433058698	E85CB5	3220 083203	LYUDMILA ALEKSANDROVA	{"phone": "+70531221984"}
0005433058699	B60F6F	5782 461813	VLADIMIR SERGEEV	{"phone": "+70577031464"}
0005433058700	B60F6F	5207 272567	IRINA KOZLOVA	{"phone": "+70158749796"}
0005433058701	5420CE	9912 246825	TAISIYA PETROVA	{"phone": "+70164099760"}
0005433058702	9E70DC	0991 263675	SERGEY FROLOV	{"phone": "+70254284815"}
0005433058703	1BC7C5	6512 853369	DANIIL KOZLOV	{"email": "daniilkozlov29071972@postgrespro.ru", "phone": "+70332633036"}
0005433058704	1BC7C5	6597 475415	NATALYA SOROKINA	{"email": "natalyasorokina_101973@postgrespro.ru", "phone": "+70920919836"}
0005433058705	69E9A0	3906 517124	ZOYA KOVALEVA	{"email": "kovalevaz_19061970@postgrespro.ru", "phone": "+70864357382"}
0005433058706	3F9FEB	5575 453704	ELENA DMITRIEVA	{"email": "dmitrieva_elena-1958@postgrespro.ru", "phone": "+70798424960"}
0005433058707	3F9FEB	1760 229633	ALEKSEY SIDOROV	{"email": "alekseysidorov_1971@postgrespro.ru", "phone": "+70256134713"}
0005433058708	E40FDD	2253 091947	VADIM MELNIKOV	{"phone": "+70046291451"}
0005433058709	9B710D	2528 437178	EVGENIY KONOVALOV	{"email": "konovalove_1972@postgrespro.ru", "phone": "+70468380053"}
0005433058710	9B710D	2153 507421	ALEKSEY SAVELEV	{"email": "a_savelev_1965@postgrespro.ru", "phone": "+70772671412"}
0005433058711	691446	6674 287100	MIKHAIL ZAKHAROV	{"phone": "+70039231455"}
0005433058712	5E71DC	9588 878699	MARINA IVANOVA	{"email": "marina.ivanova-20021974@postgrespro.ru", "phone": "+70989199233"}
0005433058713	5E71DC	2617 139217	VYACHESLAV IVANOV	{"phone": "+70368298368"}
0005433058714	5E71DC	5117 627340	VALENTINA FILIPPOVA	{"email": "filippova-valentina1959@postgrespro.ru", "phone": "+70579510340"}
0005433058715	916CE7	0426 033359	SVETLANA IVANOVA	{"phone": "+70319783407"}
0005433058716	BE26A6	1282 170362	ANATOLIY MIRONOV	{"phone": "+70706089891"}
0005433058717	DA4175	3801 262077	ANASTASIYA MELNIKOVA	{"phone": "+70649076824"}
0005433058718	8B7CF5	4536 583874	ANASTASIYA FOMINA	{"email": "fomina.anastasiya.1968@postgrespro.ru", "phone": "+70308011862"}
0005433058719	4C795B	8649 085370	ELENA ILINA	{"email": "e_ilina.10101976@postgrespro.ru", "phone": "+70520847780"}
0005433058720	780708	4047 397524	EVGENIY NIKITIN	{"phone": "+70948339629"}
0005433058721	67687A	3533 614209	NATALYA KUZMINA	{"email": "n_kuzmina-041976@postgrespro.ru", "phone": "+70450073140"}
0005433058722	67687A	7793 319460	YURIY ZAKHAROV	{"email": "yuriy.zakharov.1971@postgrespro.ru", "phone": "+70480701155"}
0005433058723	7C8876	2937 312505	ANVAR SOKOLOV	{"phone": "+70179212450"}
0005433058724	7C8876	1309 289778	LYUBOV STEPANOVA	{"phone": "+70453107051"}
0005433058725	4C157D	6734 961615	IRINA RODIONOVA	{"phone": "+70858931707"}
0005433058726	D11B19	5595 546293	SERGEY NIKITIN	{"email": "nikitin.s.28121970@postgrespro.ru", "phone": "+70017485459"}
0005433058727	5975B3	6292 827383	SERGEY KUZNECOV	{"email": "sergey-kuznecov-23101980@postgrespro.ru", "phone": "+70589614282"}
0005433058728	5975B3	9207 780450	ALEKSANDR ISAEV	{"email": "aleksandr-isaev_1975@postgrespro.ru", "phone": "+70220107327"}
0005433058729	DD329E	9014 693823	ELVIRA KUZNECOVA	{"phone": "+70066408252"}
0005433058731	C0A7C2	6427 682911	YAROSLAV POPOV	{"phone": "+70353741898"}
0005433058732	C0A7C2	8710 398909	NINA NESTEROVA	{"email": "nina_nesterova_051958@postgrespro.ru", "phone": "+70933545583"}
0005433058733	C0A7C2	3021 291895	NIKOLAY KUZNECOV	{"phone": "+70915852832"}
0005433058734	2F4712	4359 031556	MARINA TARASOVA	{"phone": "+70675195994"}
0005433058735	469D82	0176 905943	RAISA STEPANOVA	{"email": "raisa_stepanova_1969@postgrespro.ru", "phone": "+70208541132"}
0005433058736	3E2087	6079 899522	ALEKSANDR DMITRIEV	{"email": "a_dmitriev-05051971@postgrespro.ru", "phone": "+70671321746"}
0005433058737	3E2087	4409 391772	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov.051974@postgrespro.ru", "phone": "+70370671520"}
0005433058738	8DA3A2	9414 123412	MIKHAIL SOLOVEV	{"phone": "+70640663266"}
0005433058739	DEB3B3	3651 699395	VADIM SOROKIN	{"phone": "+70118360226"}
0005433058740	4D06A5	9300 813152	ANATOLIY IVANOV	{"email": "ivanov-anatoliy10011984@postgrespro.ru", "phone": "+70151338141"}
0005433058741	6A609D	9508 311822	ELENA EGOROVA	{"email": "e.egorova_021982@postgrespro.ru", "phone": "+70584026418"}
0005433058742	B9E069	7899 184773	KSENIYA SERGEEVA	{"email": "kseniyasergeeva-1966@postgrespro.ru", "phone": "+70253316779"}
0005433058743	B32CF6	4571 283998	VALENTINA RYABOVA	{"phone": "+70333481210"}
0005433058744	E10EF6	1021 462178	NIKITA KUZNECOV	{"phone": "+70804722669"}
0005433058745	0D3BE3	8036 430715	ANDREY ROMANOV	{"phone": "+70646024895"}
0005433058746	FC2664	4709 284898	ANGELINA DAVYDOVA	{"email": "davydova_a_1974@postgrespro.ru", "phone": "+70547366673"}
0005433058747	FC2664	8614 937846	LARISA MEDVEDEVA	{"email": "larisa_medvedeva.1981@postgrespro.ru", "phone": "+70361400847"}
0005433058748	414427	9696 699056	ANATOLIY GRIGOREV	{"email": "a_grigorev-1967@postgrespro.ru", "phone": "+70229536852"}
0005433058749	993CDB	8739 682003	DENIS VLASOV	{"email": "vlasov.denis_1964@postgrespro.ru", "phone": "+70477242861"}
0005433058750	324068	7795 501214	ANNA ALEKSANDROVA	{"phone": "+70423013003"}
0005433058751	324068	8222 387495	TATYANA MELNIKOVA	{"phone": "+70256815381"}
0005433058752	2F89DC	1822 888179	ALEKSEY VASILEV	{"phone": "+70650065439"}
0005433058753	2F89DC	9954 480670	NAZIYA MIRONOVA	{"email": "mironovanaziya_26091975@postgrespro.ru", "phone": "+70357809475"}
0005433058754	2F89DC	1864 582408	VALERIY KUZNECOV	{"phone": "+70749213099"}
0005433058755	2B1DFC	2006 232170	GENNADIY ZHURAVLEV	{"email": "zhuravlevg1975@postgrespro.ru", "phone": "+70179614223"}
0005433058756	2B1DFC	4895 657045	ELENA POTAPOVA	{"email": "potapovaelena.05091961@postgrespro.ru", "phone": "+70735066061"}
0005433058757	2BE65E	0629 023605	VIKTORIYA EGOROVA	{"email": "egorova-v_04111966@postgrespro.ru", "phone": "+70064073277"}
0005433058758	ED94EA	1393 505345	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.1961@postgrespro.ru", "phone": "+70016313133"}
0005433058759	96C746	9237 497281	VALENTIN SIDOROV	{"phone": "+70431722348"}
0005433058760	96C746	2189 053431	DMITRIY GERASIMOV	{"phone": "+70422342341"}
0005433058761	C1A45E	4856 309271	NIKOLAY MELNIKOV	{"email": "melnikov_n.051963@postgrespro.ru", "phone": "+70995872602"}
0005433058762	60B88F	2304 116383	VASILIY KUZNECOV	{"email": "v_kuznecov-06021982@postgrespro.ru", "phone": "+70591535296"}
0005433058763	7DC277	6046 893017	VADIM MARTYNOV	{"email": "martynov-vadim.1969@postgrespro.ru", "phone": "+70401302944"}
0005433058764	3F4A4D	9713 383642	NATALYA NIKOLAEVA	{"email": "nikolaeva.n07101971@postgrespro.ru", "phone": "+70153832835"}
0005433058765	73EF82	3543 044290	NINA VASILEVA	{"phone": "+70772642279"}
0005433058766	CC8CC4	2319 017452	OLGA ZAKHAROVA	{"email": "o-zakharova_1966@postgrespro.ru", "phone": "+70049917142"}
0005433058767	504A3F	9348 086747	VIKTOR IVANOV	{"email": "ivanovviktor1974@postgrespro.ru", "phone": "+70743733319"}
0005433058768	504A3F	5974 049547	EMIL NIKITIN	{"phone": "+70810657100"}
0005433058769	4A823D	3371 914467	PAVEL ZAKHAROV	{"email": "zakharov_p_081975@postgrespro.ru", "phone": "+70958245331"}
0005433058770	4A823D	4697 174607	MIKHAIL NAZAROV	{"email": "m_nazarov.1961@postgrespro.ru", "phone": "+70564034258"}
0005433058771	500DEB	5566 075509	DMITRIY ANDREEV	{"email": "d-andreev1971@postgrespro.ru", "phone": "+70735534222"}
0005433058772	71CDEB	1491 917309	VLADIMIR NIKOLAEV	{"email": "nikolaev.v.1973@postgrespro.ru", "phone": "+70443360583"}
0005433058773	71CDEB	8485 805671	ALEKSANDR MAKSIMOV	{"email": "maksimov_a031979@postgrespro.ru", "phone": "+70246763114"}
0005433058774	71CDEB	7024 927148	ELENA KISELEVA	{"phone": "+70773215142"}
0005433058775	5B5440	6306 279821	VIKTOR KUZNECOV	{"email": "viktor_kuznecov1971@postgrespro.ru", "phone": "+70765235173"}
0005433058776	5B5440	4994 392654	ZLATA NESTEROVA	{"email": "zlata.nesterova1977@postgrespro.ru", "phone": "+70697998933"}
0005433058777	28CF6D	0013 224528	ANDREY MELNIKOV	{"phone": "+70085189586"}
0005433058778	63216C	8456 432547	MARIYA DENISOVA	{"phone": "+70105941114"}
0005433058779	5D3B0E	1211 167321	ANNA YAKOVLEVA	{"phone": "+70142611588"}
0005433058780	5D3B0E	2419 357503	SERGEY VOLKOV	{"email": "s-volkov1963@postgrespro.ru", "phone": "+70359347441"}
0005433058781	AAD0CB	5835 923901	NIKOLAY BELOV	{"phone": "+70506842847"}
0005433058782	AAD0CB	3639 042959	ANTONINA ZHURAVLEVA	{"phone": "+70154429873"}
0005433058783	AAD0CB	4499 658489	MARINA SMIRNOVA	{"email": "m.smirnova-13021977@postgrespro.ru", "phone": "+70388641941"}
0005433058784	C93B4D	1386 494241	SERGEY KARPOV	{"email": "karpov_s041964@postgrespro.ru", "phone": "+70029554093"}
0005433058785	7CB6D5	0168 302231	ALINA TIMOFEEVA	{"phone": "+70855203784"}
0005433058786	7CB6D5	8378 605492	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin17041973@postgrespro.ru", "phone": "+70788854468"}
0005433058787	83667E	9816 571321	YURIY KOROLEV	{"phone": "+70474009479"}
0005433058788	78A39A	7759 888005	ALENA FROLOVA	{"email": "alena-frolova.021988@postgrespro.ru", "phone": "+70239516679"}
0005433058789	4170C6	6828 816468	ALEKSANDR KONOVALOV	{"phone": "+70037617430"}
0005433058790	22CC36	2870 247019	SERGEY MAKAROV	{"email": "s-makarov.081971@postgrespro.ru", "phone": "+70199565739"}
0005433058791	BF7815	1537 033615	IGOR ABRAMOV	{"email": "abramov_igor-1970@postgrespro.ru", "phone": "+70772374412"}
0005433058792	FEAA9E	2600 443710	DARYA KOMAROVA	{"email": "darya.komarova_111973@postgrespro.ru", "phone": "+70335338982"}
0005433058793	03EDBE	7217 618588	POLINA DAVYDOVA	{"phone": "+70469203761"}
0005433058794	12FAE1	7179 538529	VITALIY MELNIKOV	{"email": "v.melnikov_021980@postgrespro.ru", "phone": "+70526070370"}
0005433058795	12FAE1	6812 793022	SERGEY KISELEV	{"phone": "+70872973936"}
0005433058796	0E241A	2924 600669	NIKOLAY ROMANOV	{"phone": "+70062520714"}
0005433058797	0E241A	5950 488244	OLEG KUZNECOV	{"email": "kuznecov-o1963@postgrespro.ru", "phone": "+70474769940"}
0005433058798	CF97FA	8437 056428	DMITRIY ANDREEV	{"phone": "+70510312670"}
0005433058799	055ABE	1185 705423	ALEKSEY VOLKOV	{"phone": "+70122551450"}
0005433058800	526DA2	3701 349997	IRINA STEPANOVA	{"phone": "+70270621851"}
0005433058801	EF8E62	8618 076389	NADEZHDA EGOROVA	{"email": "egorova.nadezhda1969@postgrespro.ru", "phone": "+70239615822"}
0005433058802	EF8E62	4726 133790	TATYANA ORLOVA	{"phone": "+70050334407"}
0005433058803	C18A89	9768 009685	VIKTOR SEMENOV	{"phone": "+70512642303"}
0005433058804	274B50	8133 822242	NIKOLAY KULIKOV	{"email": "n_kulikov_081977@postgrespro.ru", "phone": "+70682074818"}
0005433058805	9541C1	6785 841975	VALERIY ISAEV	{"email": "v_isaev111972@postgrespro.ru", "phone": "+70081231374"}
0005433058806	75786B	8243 177017	VIKTORIYA TROFIMOVA	{"phone": "+70500246164"}
0005433058807	FBF032	0329 733061	PETR KUDRYASHOV	{"email": "kudryashov_p091967@postgrespro.ru", "phone": "+70068407007"}
0005433058808	FBF032	7898 397484	GALINA OSIPOVA	{"email": "g.osipova09041976@postgrespro.ru", "phone": "+70105205069"}
0005433058809	3DDD43	1143 552279	IGOR GUSEV	{"email": "gusev_i_11091966@postgrespro.ru", "phone": "+70513838591"}
0005433058810	3DDD43	7919 725191	EVDOKIYA ISAEVA	{"email": "evdokiya.isaeva_051989@postgrespro.ru", "phone": "+70931667308"}
0005433058811	F4B00B	7864 640362	SOFIYA KULIKOVA	{"email": "kulikovasofiya-101978@postgrespro.ru", "phone": "+70525800817"}
0005433058812	6C6BBF	8650 164995	NIKOLAY TIKHONOV	{"phone": "+70642200081"}
0005433058813	0FECCB	0769 867701	LARISA SIDOROVA	{"phone": "+70286276115"}
0005433058814	506726	4133 577178	SVETLANA MAKAROVA	{"phone": "+70153206010"}
0005433058815	61D676	9420 354463	MARINA FROLOVA	{"phone": "+70489710588"}
0005433058816	BFB955	3521 062391	OLGA FROLOVA	{"email": "o-frolova1966@postgrespro.ru", "phone": "+70981412025"}
0005433058817	BFB955	0223 005218	SERGEY ZAYCEV	{"phone": "+70036020911"}
0005433058818	131C78	5613 165647	ELENA CHERNOVA	{"phone": "+70026009359"}
0005433058819	0ED03A	0804 039800	ANATOLIY FOMIN	{"email": "anatoliy_fomin_1982@postgrespro.ru", "phone": "+70808691457"}
0005433058820	131327	2823 050762	MARIYA LUKYANOVA	{"phone": "+70879724646"}
0005433058821	131327	4467 598925	ANASTASIYA LOGINOVA	{"email": "a.loginova23021975@postgrespro.ru", "phone": "+70411222695"}
0005433058822	4D09F4	1807 448831	LYUDMILA ZAYCEVA	{"email": "lyudmila_zayceva27091974@postgrespro.ru", "phone": "+70308882928"}
0005433058823	4D09F4	9770 499069	ALINA PAVLOVA	{"email": "a_pavlova09081974@postgrespro.ru", "phone": "+70055504250"}
0005433058824	A6E7FA	8274 895550	YULIYA KONOVALOVA	{"email": "yuliya_konovalova.11041983@postgrespro.ru", "phone": "+70125640414"}
0005433058825	ACDCA8	7084 443460	AYRAT KISELEV	{"phone": "+70290030579"}
0005433058826	ACDCA8	2420 698808	IGOR ISAEV	{"email": "igor_isaev1970@postgrespro.ru", "phone": "+70451078139"}
0005433058827	5D1B9A	3117 788573	EKATERINA TIMOFEEVA	{"phone": "+70046630850"}
0005433058828	C677E9	7983 370894	VITALIY ZAYCEV	{"phone": "+70597528212"}
0005433058829	C677E9	2802 077328	NIKOLAY ZAKHAROV	{"email": "zakharov_nikolay_21021971@postgrespro.ru", "phone": "+70357164872"}
0005433058830	E612B2	5038 955837	MARINA ISAEVA	{"email": "marina_isaeva16061976@postgrespro.ru", "phone": "+70420250768"}
0005433058831	B344EB	8673 047751	MAKSIM MEDVEDEV	{"phone": "+70767093570"}
0005433058832	B344EB	5296 205685	MARINA VOLKOVA	{"email": "volkova_marina091967@postgrespro.ru", "phone": "+70859807688"}
0005433058833	795620	3732 004471	TATYANA MAKAROVA	{"email": "makarovatatyana_29051964@postgrespro.ru", "phone": "+70067794752"}
0005433058834	674CD2	0655 460353	ELENA FADEEVA	{"email": "fadeeva_elena.071962@postgrespro.ru", "phone": "+70937881726"}
0005433058835	4FBA8F	6395 547400	ILNUR FROLOV	{"phone": "+70413937991"}
0005433058836	035F04	9487 142190	LARISA TITOVA	{"phone": "+70053856073"}
0005433058837	035F04	3050 613326	ALEKSEY MIKHAYLOV	{"email": "amikhaylov1972@postgrespro.ru", "phone": "+70043600083"}
0005433058838	8DF6F2	9708 391965	ANASTASIYA ZAYCEVA	{"email": "zayceva_a091958@postgrespro.ru", "phone": "+70088323681"}
0005433058839	8DF6F2	1965 346999	YULIYA ZAYCEVA	{"email": "zayceva-y-1972@postgrespro.ru", "phone": "+70766914308"}
0005433058840	8DF6F2	3562 591542	ALEKSANDR IVANOV	{"phone": "+70528805729"}
0005433058841	D050B1	3483 891806	ANATOLIY PAVLOV	{"email": "anatoliy.pavlov1972@postgrespro.ru", "phone": "+70481964287"}
0005433058842	D050B1	6740 468993	OKSANA KOZLOVA	{"email": "kozlova_o.011970@postgrespro.ru", "phone": "+70775744089"}
0005433058843	13627B	3938 783833	ILDAR SAVELEV	{"email": "ildarsavelev.1971@postgrespro.ru", "phone": "+70435301713"}
0005433058844	64AD20	0211 384780	ANDREY NAZAROV	{"phone": "+70713577318"}
0005433058845	64AD20	8181 041422	SERGEY MARTYNOV	{"phone": "+70411052903"}
0005433058846	338063	6370 819747	ZOYA VOROBEVA	{"email": "zoya-vorobeva.04061968@postgrespro.ru", "phone": "+70971826509"}
0005433058847	A77716	6810 874747	NAIL PAVLOV	{"email": "pavlov_n1967@postgrespro.ru", "phone": "+70858607963"}
0005433058848	8278C1	9018 141191	ULYANA KUZMINA	{"email": "ulyana-kuzmina.101973@postgrespro.ru", "phone": "+70500281353"}
0005433058849	2E9B3A	1311 062327	SERGEY ABRAMOV	{"email": "abramovs.1982@postgrespro.ru", "phone": "+70387254757"}
0005433058850	8791D7	5899 023329	VALERIYA MELNIKOVA	{"phone": "+70126239927"}
0005433058851	7E8FDF	4496 578697	YAN KISELEV	{"email": "y.kiselev-021974@postgrespro.ru", "phone": "+70000588811"}
0005433058852	800005	4836 058422	EVGENIY IVANOV	{"phone": "+70655481127"}
0005433058853	800005	3967 801585	GALINA BARANOVA	{"email": "baranova-galina.1966@postgrespro.ru", "phone": "+70050732647"}
0005433058854	800005	8891 242077	VALENTINA FEDOROVA	{"email": "valentinafedorova1972@postgrespro.ru", "phone": "+70379897465"}
0005433058855	6E08E1	1007 736496	NAILYA ERMAKOVA	{"phone": "+70331011410"}
0005433058856	6E08E1	1741 828985	ZOYA MAKSIMOVA	{"email": "maksimova_z1974@postgrespro.ru", "phone": "+70194506984"}
0005433058857	7F3F91	5804 347227	ALEKSANDR ALEKSEEV	{"phone": "+70310555313"}
0005433058858	3AC0D1	9999 893789	MARIYA MIKHAYLOVA	{"phone": "+70482972161"}
0005433058859	3AC0D1	6360 735458	DMITRIY POPOV	{"email": "dmitriy_popov1970@postgrespro.ru", "phone": "+70677754942"}
0005433058860	74F565	2597 199239	VALERIY PAVLOV	{"email": "v_pavlov-30061973@postgrespro.ru", "phone": "+70060580056"}
0005433058861	856952	7301 217249	ROMAN KUZNECOV	{"email": "roman_kuznecov1974@postgrespro.ru", "phone": "+70588599061"}
0005433058862	D9EA01	6958 115009	MARIYA FEDOROVA	{"phone": "+70856491880"}
0005433058863	402034	2692 766885	PAVEL KUZNECOV	{"phone": "+70106162144"}
0005433058864	402034	9997 552841	ALEKSANDR SERGEEV	{"email": "a.sergeev_24031984@postgrespro.ru", "phone": "+70251598067"}
0005433058865	652415	6133 070917	GENNADIY MIKHAYLOV	{"phone": "+70545584588"}
0005433058866	74755C	2894 921321	NATALYA KUZNECOVA	{"email": "kuznecova-n.19101969@postgrespro.ru", "phone": "+70250327470"}
0005433058867	2E8CF3	4031 126104	OKSANA NESTEROVA	{"email": "o-nesterova_081971@postgrespro.ru", "phone": "+70539340639"}
0005433058868	2E8CF3	4282 107395	IRINA TARASOVA	{"phone": "+70129520656"}
0005433058869	929567	6843 150508	OLEG FEDOTOV	{"email": "olegfedotov.19011974@postgrespro.ru", "phone": "+70095398207"}
0005433058870	DB21C8	2798 916185	VLADIMIR TIMOFEEV	{"phone": "+70824585200"}
0005433058871	8C8E2E	3981 541535	ANTONINA LUKYANOVA	{"email": "lukyanovaantonina-27091963@postgrespro.ru", "phone": "+70888244503"}
0005433058872	8C8E2E	4782 830227	RAISA RODIONOVA	{"email": "rodionova_r_061964@postgrespro.ru", "phone": "+70283931140"}
0005433058873	F63B6A	6142 153797	VLADIMIR EGOROV	{"email": "egorov_vladimir_12061967@postgrespro.ru", "phone": "+70756632920"}
0005433058874	11D810	5736 386627	BORIS MATVEEV	{"email": "boris_matveev-25051965@postgrespro.ru", "phone": "+70903794918"}
0005433058875	11D810	4493 661300	ROZA KOZLOVA	{"email": "rozakozlova.081973@postgrespro.ru", "phone": "+70048103646"}
0005433058876	DEFDD0	6015 664973	ALEKSANDR AFANASEV	{"phone": "+70097991006"}
0005433058877	DEFDD0	6646 020304	IRINA STEPANOVA	{"phone": "+70761228449"}
0005433058878	093A5C	1720 494204	ALEKSANDR ANDREEV	{"phone": "+70955543478"}
0005433058879	4D9B0B	7722 598276	ANATOLIY ZHUKOV	{"email": "a-zhukov_111973@postgrespro.ru", "phone": "+70419966082"}
0005433058880	E9B889	8186 258052	NATALYA POPOVA	{"email": "popova_natalya1981@postgrespro.ru", "phone": "+70527758890"}
0005433058881	1A89CD	9874 430696	ANDREY IVANOV	{"email": "ivanov-andrey_1973@postgrespro.ru", "phone": "+70659709347"}
0005433058882	1A89CD	4569 579924	PETR SMIRNOV	{"phone": "+70766809217"}
0005433058883	3E4649	9104 962201	ELENA KOROLEVA	{"email": "elena_koroleva.02011976@postgrespro.ru", "phone": "+70974553333"}
0005433058884	636FF7	0953 220575	ELENA ABRAMOVA	{"phone": "+70536018555"}
0005433058885	0A0216	4328 003023	GALINA NAZAROVA	{"phone": "+70650038650"}
0005433058886	0A0216	3322 580442	NIKOLAY KUZNECOV	{"phone": "+70651540905"}
0005433058887	CCC928	4848 886963	STANISLAV VOROBEV	{"email": "stanislavvorobev.1974@postgrespro.ru", "phone": "+70252519808"}
0005433058888	732ACD	0928 322607	DANIIL VASILEV	{"email": "daniil_vasilev081971@postgrespro.ru", "phone": "+70696498778"}
0005433058889	732ACD	5853 470953	EVGENIY FILIPPOV	{"email": "filippov_e-051981@postgrespro.ru", "phone": "+70987971402"}
0005433058890	A698E9	4344 737929	ARTEM KOZLOV	{"email": "artem.kozlov1966@postgrespro.ru", "phone": "+70649352147"}
0005433058891	A698E9	5041 303795	LYUDMILA BORISOVA	{"email": "lyudmila.borisova1982@postgrespro.ru", "phone": "+70715338625"}
0005433058892	A698E9	5379 641799	SVETLANA SEMENOVA	{"email": "semenova_svetlana-1976@postgrespro.ru", "phone": "+70381491534"}
0005433058893	2D3BED	8639 771093	TATYANA MELNIKOVA	{"email": "melnikova_t_121984@postgrespro.ru", "phone": "+70764896143"}
0005433058894	E034AD	5770 232641	STANISLAV YAKOVLEV	{"email": "yakovlevs-10111964@postgrespro.ru", "phone": "+70694779241"}
0005433058895	E034AD	8386 455622	ALEKSANDRA FILIPPOVA	{"phone": "+70018020016"}
0005433058896	829F70	6726 303190	NINA LAZAREVA	{"email": "n-lazareva19101968@postgrespro.ru", "phone": "+70721677250"}
0005433058897	829F70	0838 405241	NATALYA KULIKOVA	{"phone": "+70061964199"}
0005433058898	93B813	9762 149792	YULIYA VASILEVA	{"email": "vasileva.y011970@postgrespro.ru", "phone": "+70859569524"}
0005433058899	93B813	9103 536460	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr-26021979@postgrespro.ru", "phone": "+70318920219"}
0005433058900	93B813	2685 281803	GALINA MATVEEVA	{"email": "galina-matveeva_081977@postgrespro.ru", "phone": "+70304635479"}
0005433058901	F7EDCD	1302 273194	DMITRIY VOROBEV	{"email": "dvorobev.1971@postgrespro.ru", "phone": "+70369390170"}
0005433058902	465002	1158 488754	VIKTOR STEPANOV	{"phone": "+70228261046"}
0005433058903	C7E14D	7778 790021	GENNADIY CHERNOV	{"phone": "+70858867002"}
0005433058904	70480A	0085 005450	POLINA GORBUNOVA	{"email": "polina.gorbunova-111967@postgrespro.ru", "phone": "+70929608815"}
0005433058905	291AD7	4119 272572	EVGENIY SAVELEV	{"phone": "+70781113773"}
0005433058906	6292FE	8298 330257	KSENIYA BOGDANOVA	{"phone": "+70341892456"}
0005433058907	6292FE	9377 895206	SERGEY FILIPPOV	{"phone": "+70343390935"}
0005433058908	2F751F	7340 052340	ALEKSANDR IVANOV	{"phone": "+70240498442"}
0005433058909	2F751F	6841 333118	TATYANA MIRONOVA	{"email": "t_mironova.06031972@postgrespro.ru", "phone": "+70503293046"}
0005433058910	E04BDC	1176 550238	NATALIYA POTAPOVA	{"phone": "+70608832448"}
0005433058911	E04BDC	8816 785004	NATALIYA KONOVALOVA	{"phone": "+70456517136"}
0005433058912	9E77FF	5457 392335	ARINA AFANASEVA	{"email": "a_afanaseva.041976@postgrespro.ru", "phone": "+70178079551"}
0005433058913	CC6BEF	4494 013398	SERGEY OSIPOV	{"email": "osipov-s041974@postgrespro.ru", "phone": "+70546761005"}
0005433058914	D4D226	8060 571628	VADIM IVANOV	{"phone": "+70023022074"}
0005433058915	D4D226	3274 532899	ELIZAVETA PAVLOVA	{"phone": "+70812107742"}
0005433058916	C7FD32	7147 810380	LYUDMILA EFREMOVA	{"email": "l_efremova-28031978@postgrespro.ru", "phone": "+70550348087"}
0005433058917	AC0F0C	3040 239660	TATYANA KOVALEVA	{"email": "t-kovaleva_021973@postgrespro.ru", "phone": "+70381756938"}
0005433058918	AC0F0C	8581 192627	SVETLANA EGOROVA	{"email": "egorova-s.051970@postgrespro.ru", "phone": "+70472447856"}
0005433058919	FA0B51	1311 346039	NIKITA KUZNECOV	{"email": "n-kuznecov_071972@postgrespro.ru", "phone": "+70045859648"}
0005433058920	6F7F93	1879 371633	ANTON KUZNECOV	{"phone": "+70516382011"}
0005433058921	6F7F93	7573 042642	SERGEY KOZLOV	{"phone": "+70139064609"}
0005433058922	6F7F93	2915 916353	SERGEY YAKOVLEV	{"email": "yakovlevsergey22071977@postgrespro.ru", "phone": "+70529697686"}
0005433058923	6F7F93	3686 895822	MARIANNA MEDVEDEVA	{"phone": "+70232521429"}
0005433058924	345179	8761 216085	YURIY ROMANOV	{"email": "romanov_y29081967@postgrespro.ru", "phone": "+70294321055"}
0005433058925	345179	5472 116554	VLADIMIR MATVEEV	{"phone": "+70220152047"}
0005433058926	AC8FFE	3667 894786	MARIYA LEBEDEVA	{"phone": "+70112195477"}
0005433058927	06288D	2308 102278	OLGA TIKHONOVA	{"email": "o_tikhonova-1969@postgrespro.ru", "phone": "+70164121212"}
0005433058928	285B62	2832 750000	SAVELIY SHEVCHENKO	{"email": "shevchenkos.071958@postgrespro.ru", "phone": "+70707116583"}
0005433058929	54ECD8	0537 599426	OLEG STEPANOV	{"email": "o.stepanov.041986@postgrespro.ru", "phone": "+70364974707"}
0005433058930	706452	9356 664287	SVETLANA KARPOVA	{"phone": "+70384194342"}
0005433058931	69C0E8	8370 759669	NATALYA KONDRATEVA	{"phone": "+70809951359"}
0005433058932	164F02	1425 876695	EVGENIY ANDREEV	{"email": "andreev_e.07111980@postgrespro.ru", "phone": "+70429812583"}
0005433058933	B21F64	8067 289325	TAISIYA MIKHAYLOVA	{"email": "mikhaylova-t_1974@postgrespro.ru", "phone": "+70253365485"}
0005433058934	B21F64	2093 506290	NIKOLAY VASILEV	{"phone": "+70553793942"}
0005433058935	93DC72	5015 884653	NATALYA SCHERBAKOVA	{"phone": "+70544391039"}
0005433058936	8E9EE4	5505 887693	ELENA POTAPOVA	{"email": "elena.potapova-111975@postgrespro.ru", "phone": "+70747324626"}
0005433058937	18BDDF	7137 371632	YURIY ALEKSEEV	{"email": "alekseev-y02051977@postgrespro.ru", "phone": "+70912872267"}
0005433058938	17CE1C	4703 582157	ELENA ZAYCEVA	{"email": "e-zayceva15091965@postgrespro.ru", "phone": "+70874717158"}
0005433058939	687614	6303 491499	POLINA POTAPOVA	{"email": "potapovapolina_23041978@postgrespro.ru", "phone": "+70020670307"}
0005433058940	90984E	3243 339399	ARTUR GORBUNOV	{"email": "artur-gorbunov-23061965@postgrespro.ru", "phone": "+70333498413"}
0005433058941	EB615C	4386 124239	MARINA KISELEVA	{"email": "kiselevam-071977@postgrespro.ru", "phone": "+70493521175"}
0005433058942	EB615C	0075 185959	VITALIY BORISOV	{"phone": "+70865740675"}
0005433058943	B5DD25	6285 815093	OLGA GERASIMOVA	{"email": "olga-gerasimova_041969@postgrespro.ru", "phone": "+70442540647"}
0005433058944	CC2745	5813 702721	KIRILL VOLKOV	{"email": "volkov.k19051976@postgrespro.ru", "phone": "+70127964211"}
0005433058945	CC2745	0155 010103	ALEKSANDRA BARANOVA	{"email": "a-baranova.03111975@postgrespro.ru", "phone": "+70268939870"}
0005433058946	86DD62	3199 721467	RUFIYA NAZAROVA	{"phone": "+70141373298"}
0005433058947	012B92	2776 983973	MARIYA KOMAROVA	{"email": "komarova-mariya22031973@postgrespro.ru", "phone": "+70786008896"}
0005433058948	C5649D	8689 010229	KIRA PAVLOVA	{"email": "pavlova-k_061964@postgrespro.ru", "phone": "+70484498224"}
0005433058949	9B25E0	5942 359273	VIKTOR NIKITIN	{"phone": "+70497932064"}
0005433058950	9B25E0	0172 616768	OLGA IVANOVA	{"phone": "+70759644233"}
0005433058951	1BE483	3382 245643	VARVARA MIRONOVA	{"email": "v-mironova_02101964@postgrespro.ru", "phone": "+70793684268"}
0005433058952	DE9E34	6240 033728	RAISA GUSEVA	{"email": "r-guseva.051982@postgrespro.ru", "phone": "+70027935585"}
0005433058953	CF49F4	5215 722881	EVGENIY MEDVEDEV	{"phone": "+70383245270"}
0005433058954	CF49F4	9321 641260	SVETLANA PETROVA	{"email": "petrova_s1971@postgrespro.ru", "phone": "+70582910838"}
0005433058955	B275D5	2849 787516	LYUDMILA MARTYNOVA	{"phone": "+70896327394"}
0005433058956	5F767E	2587 379533	TATYANA MAKAROVA	{"email": "tatyana_makarova.091968@postgrespro.ru", "phone": "+70066497584"}
0005433058957	5F767E	9219 453483	ANASTASIYA KOROLEVA	{"phone": "+70963422504"}
0005433058958	5F767E	7934 203011	SVETLANA EGOROVA	{"phone": "+70301920754"}
0005433058959	BAFD73	7108 199524	VLADIMIR FEDOROV	{"email": "vladimir-fedorov-14031972@postgrespro.ru", "phone": "+70594047640"}
0005433058960	EA0932	9159 370974	VLADISLAV SIDOROV	{"email": "sidorovv021968@postgrespro.ru", "phone": "+70237053604"}
0005433058961	84E54D	1695 674679	EKATERINA ANDREEVA	{"email": "andreeva-e.30051964@postgrespro.ru", "phone": "+70960789491"}
0005433058962	C0DE32	7558 133096	YAROSLAV MOISEEV	{"email": "moiseev-y.121974@postgrespro.ru", "phone": "+70213016171"}
0005433058963	C0DE32	1767 346970	MARIYA AKIMOVA	{"phone": "+70175410068"}
0005433058964	622167	5350 999842	RAISA SERGEEVA	{"phone": "+70303809964"}
0005433058965	426033	2329 773185	OLEG TIKHONOV	{"phone": "+70425044306"}
0005433058966	426033	1248 155366	EDUARD ROMANOV	{"email": "romanoveduard-081978@postgrespro.ru", "phone": "+70972489927"}
0005433058967	2D6A09	8758 389555	OLGA SERGEEVA	{"email": "olga_sergeeva_1976@postgrespro.ru", "phone": "+70644089795"}
0005433058968	90AD5A	4385 299711	ANATOLIY FOMIN	{"email": "fomina1972@postgrespro.ru", "phone": "+70173808528"}
0005433058969	90AD5A	1898 190296	PETR KOZLOV	{"email": "p.kozlov.29031970@postgrespro.ru", "phone": "+70317924371"}
0005433058970	3834BE	6557 283481	EKATERINA NOVIKOVA	{"phone": "+70640358975"}
0005433058971	E1726F	2496 086016	TAMARA KUZNECOVA	{"phone": "+70290630604"}
0005433058972	E170D1	8388 104706	OLGA ALEKSANDROVA	{"phone": "+70387312976"}
0005433058973	4C8956	2777 941848	EVGENIY IVANOV	{"phone": "+70751838792"}
0005433058974	4C8956	4630 106813	VIKTOR DAVYDOV	{"phone": "+70857425105"}
0005433058975	F85B16	7927 494327	TATYANA ROMANOVA	{"email": "tatyana-romanova.20021969@postgrespro.ru", "phone": "+70768310995"}
0005433058976	F85B16	5119 901033	GALINA TITOVA	{"phone": "+70524128503"}
0005433058977	4E1AA4	0874 361591	NADEZHDA AKIMOVA	{"phone": "+70674756416"}
0005433058978	D586D9	9102 070713	VLADIMIR ISAEV	{"phone": "+70149467246"}
0005433058979	D586D9	2189 123226	SERGEY PAVLOV	{"phone": "+70613733289"}
0005433058980	D586D9	2903 821173	SERGEY PAVLOV	{"email": "sergey-pavlov.1978@postgrespro.ru", "phone": "+70735327558"}
0005433058981	D586D9	6718 166327	KLAVDIYA MIRONOVA	{"email": "kmironova.25111955@postgrespro.ru", "phone": "+70575385307"}
0005433058982	9A4E88	5745 383495	IRINA LOGINOVA	{"email": "loginova.i-25061961@postgrespro.ru", "phone": "+70094077323"}
0005433058983	F63078	4052 772156	ALEKSANDR MAKAROV	{"phone": "+70104834601"}
0005433058984	04C655	1294 606701	LYUDMILA KUZNECOVA	{"email": "l.kuznecova17031968@postgrespro.ru", "phone": "+70325899035"}
0005433058985	10287A	4692 810533	OLGA FROLOVA	{"email": "frolova_o-14111963@postgrespro.ru", "phone": "+70193348758"}
0005433058986	FFCF7B	6784 009483	VLADIMIR BARANOV	{"email": "baranov_v.10031963@postgrespro.ru", "phone": "+70881329353"}
0005433058987	FFCF7B	5343 963013	ELENA FROLOVA	{"email": "elena.frolova061984@postgrespro.ru", "phone": "+70713425837"}
0005433058988	7AE722	9506 745307	DAMIR KUZNECOV	{"phone": "+70007209965"}
0005433058989	CEFFA2	2334 176318	VARVARA BORISOVA	{"email": "borisovavarvara_15101977@postgrespro.ru", "phone": "+70791989652"}
0005433058990	CEFFA2	5095 067218	GALINA DMITRIEVA	{"phone": "+70124895390"}
0005433058991	578F82	2071 133084	ELENA NAUMOVA	{"phone": "+70421715326"}
0005433058992	EDAAFA	8154 893577	EKATERINA AFANASEVA	{"email": "eafanaseva_1952@postgrespro.ru", "phone": "+70038932511"}
0005433058993	EDAAFA	6007 177491	ALIYA BORISOVA	{"phone": "+70022844671"}
0005433058994	78D156	2690 533242	ALEKSEY EGOROV	{"phone": "+70208762603"}
0005433058995	1078AD	6154 861158	DARYA MIKHAYLOVA	{"phone": "+70913068002"}
0005433058996	A28E59	7366 907494	VERONIKA MAKAROVA	{"email": "makarovav_03101981@postgrespro.ru", "phone": "+70174618607"}
0005433058997	A28E59	0968 708094	VLADIMIR CHERNOV	{"email": "chernov-v_121973@postgrespro.ru", "phone": "+70840549793"}
0005433058998	0FEEF1	5705 248723	RASHIT FEDOROV	{"email": "fedorovrashit.051976@postgrespro.ru", "phone": "+70462710487"}
0005433058999	1B7541	0760 941479	ARTEM PETROV	{"phone": "+70361583600"}
0005433059000	522694	4715 267106	SERGEY KUDRYASHOV	{"email": "kudryashovs-1985@postgrespro.ru", "phone": "+70994744897"}
0005433059001	522694	5997 736696	LYUDMILA NAZAROVA	{"phone": "+70797081047"}
0005433059002	167569	1311 963380	VALENTIN VLASOV	{"phone": "+70481184631"}
0005433059003	F782AE	0760 083664	NINA ANISIMOVA	{"phone": "+70979941706"}
0005433059004	F30726	6434 599222	VERA KUZNECOVA	{"phone": "+70990842082"}
0005433059062	718C91	9360 007035	IRINA FADEEVA	{"phone": "+70012399828"}
0005433059005	F30726	4923 244751	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov_091970@postgrespro.ru", "phone": "+70114475971"}
0005433059006	9A45D2	8364 410522	MARIYA ILINA	{"email": "ilina.mariya_09101976@postgrespro.ru", "phone": "+70934542959"}
0005433059007	E206FF	1414 137505	GALINA ROMANOVA	{"phone": "+70647404621"}
0005433059008	D389DD	9797 824444	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov-011966@postgrespro.ru", "phone": "+70724943977"}
0005433059009	D389DD	1893 860101	EGOR BELOV	{"email": "belov_egor.1970@postgrespro.ru", "phone": "+70587665421"}
0005433059010	D389DD	0431 454935	VLADIMIR NOVIKOV	{"email": "novikov.v.1969@postgrespro.ru", "phone": "+70474765911"}
0005433059011	959107	8589 835502	NATALYA BELYAEVA	{"email": "belyaeva_natalya-18021966@postgrespro.ru", "phone": "+70643986288"}
0005433059012	959107	7292 912325	ALEKSANDRA SCHERBAKOVA	{"phone": "+70867444507"}
0005433059013	BBB574	0759 528942	SVETLANA KRASNOVA	{"email": "s_krasnova-24061973@postgrespro.ru", "phone": "+70137988336"}
0005433059014	BBB574	5629 972071	VLADIMIR KUZMIN	{"phone": "+70220543661"}
0005433059015	E3A5A4	9624 924181	EVGENIY KONOVALOV	{"phone": "+70492250607"}
0005433059016	E3A5A4	5416 223619	IVAN POPOV	{"phone": "+70673291781"}
0005433059017	8E3576	3816 265233	MARIYA TIKHONOVA	{"phone": "+70481717886"}
0005433059018	890B05	2086 389311	NATALYA IVANOVA	{"phone": "+70423039759"}
0005433059019	7E228C	8988 681417	NADEZHDA CHERNOVA	{"phone": "+70131203753"}
0005433059020	86BD26	3771 317112	ALEKSANDR GERASIMOV	{"phone": "+70934332131"}
0005433059021	EA3954	0112 211910	VLADIMIR FEDOROV	{"phone": "+70989699246"}
0005433059022	B608F9	2613 446747	ALEKSEY ROMANOV	{"email": "alekseyromanov_1971@postgrespro.ru", "phone": "+70106302774"}
0005433059023	8BD480	6596 775250	OKSANA DMITRIEVA	{"email": "oksanadmitrieva-18121977@postgrespro.ru", "phone": "+70090155035"}
0005433059024	06E488	8163 252387	ALEKSANDRA NESTEROVA	{"phone": "+70993657825"}
0005433059025	06E488	8545 078437	SVETLANA ALEKSEEVA	{"email": "alekseeva-s-1976@postgrespro.ru", "phone": "+70619186433"}
0005433059026	6A3DA1	9213 302929	VLADIMIR KUZNECOV	{"phone": "+70939529914"}
0005433059027	4BEB36	5940 434134	PAVEL POPOV	{"phone": "+70814575059"}
0005433059028	6C4C3C	8055 907469	ANNA GRISHINA	{"phone": "+70883161597"}
0005433059029	52236D	9397 235574	ELENA IVANOVA	{"phone": "+70318103062"}
0005433059030	CE6807	1508 723395	NINA ROMANOVA	{"phone": "+70122668297"}
0005433059031	CE6807	0790 954014	VALERIY SEMENOV	{"phone": "+70142599296"}
0005433059032	1A833B	8771 949758	YULIYA MIKHAYLOVA	{"email": "y.mikhaylova.1962@postgrespro.ru", "phone": "+70833138047"}
0005433059033	C368EB	5781 985004	ALEKSANDRA KRASNOVA	{"phone": "+70720301493"}
0005433059034	48484C	9136 021656	SVETLANA DENISOVA	{"email": "denisova.svetlana_071973@postgrespro.ru", "phone": "+70387114363"}
0005433059035	48484C	9017 648901	TATYANA DMITRIEVA	{"phone": "+70290151942"}
0005433059036	3957A6	5113 474534	ELENA KOROLEVA	{"email": "koroleva.elena20021973@postgrespro.ru", "phone": "+70424417647"}
0005433059037	3957A6	5442 626837	TATYANA MELNIKOVA	{"phone": "+70161254800"}
0005433059038	FDEEDC	7696 803226	OLGA PAVLOVA	{"phone": "+70441545505"}
0005433059039	FDEEDC	3303 781820	MARINA KISELEVA	{"email": "m_kiseleva.071989@postgrespro.ru", "phone": "+70901768060"}
0005433059040	3F45DF	2855 134366	EVGENIY SEMENOV	{"email": "semenov.e_011973@postgrespro.ru", "phone": "+70061112532"}
0005433059041	3F45DF	9148 979215	SOFIYA MIKHAYLOVA	{"email": "mikhaylova.sofiya.121973@postgrespro.ru", "phone": "+70422050130"}
0005433059042	A9202B	1981 916265	MARINA RYABOVA	{"phone": "+70332760852"}
0005433059043	6FF474	0566 443356	OKSANA IVANOVA	{"email": "oksanaivanova.051958@postgrespro.ru", "phone": "+70807050863"}
0005433059044	7FF1E0	0209 683829	OLGA SCHERBAKOVA	{"phone": "+70480757263"}
0005433059045	08AC94	2358 126427	VASILIY KUZNECOV	{"email": "kuznecov-vasiliy_1975@postgrespro.ru", "phone": "+70053851268"}
0005433059046	08AC94	3438 424556	LARISA ANISIMOVA	{"email": "anisimova_l011961@postgrespro.ru", "phone": "+70084333415"}
0005433059047	A5D783	3489 784013	MIKHAIL IVANOV	{"phone": "+70545050256"}
0005433059048	BE3025	0375 171708	VYACHESLAV MAKSIMOV	{"phone": "+70939816205"}
0005433059049	2563B3	5845 314633	YURIY SMIRNOV	{"phone": "+70940791335"}
0005433059050	2563B3	0379 702686	NATALYA BELOVA	{"email": "natalyabelova-1966@postgrespro.ru", "phone": "+70353320672"}
0005433059051	2563B3	5901 817705	YURIY FILIPPOV	{"email": "y.filippov1968@postgrespro.ru", "phone": "+70176070704"}
0005433059052	1CBED4	1436 731066	DARYA NIKOLAEVA	{"phone": "+70696090053"}
0005433059053	1CBED4	7940 932680	ANATOLIY FROLOV	{"phone": "+70968221868"}
0005433059054	434B54	6832 154858	ALEKSEY KUZNECOV	{"phone": "+70989890363"}
0005433059055	434B54	8845 826091	ALEKSANDR GUSEV	{"phone": "+70686104245"}
0005433059056	6E3C06	2982 166584	ROMAN CHERNOV	{"phone": "+70371545344"}
0005433059057	2861B1	0043 800741	EKATERINA TITOVA	{"email": "e-titova051974@postgrespro.ru", "phone": "+70114759313"}
0005433059058	40AFE0	3127 168921	NATALYA KARPOVA	{"email": "karpova_natalya-101967@postgrespro.ru", "phone": "+70420072700"}
0005433059059	5A0377	6415 023562	GALINA KOLESNIKOVA	{"email": "kolesnikova_g_1974@postgrespro.ru", "phone": "+70017448114"}
0005433059060	4A1940	6682 530213	NIKOLAY BORISOV	{"phone": "+70210908839"}
0005433059061	C74190	0830 513136	NIKITA OSIPOV	{"email": "n_osipov_1966@postgrespro.ru", "phone": "+70506405941"}
0005433059063	718C91	0737 055803	VASILIY NIKOLAEV	{"phone": "+70251256528"}
0005433059064	C922A9	6105 253641	ANDREY ALEKSANDROV	{"email": "aleksandrov-a23031975@postgrespro.ru", "phone": "+70248116237"}
0005433059065	3BF923	8415 612088	SERGEY FEDOROV	{"email": "sfedorov.15081981@postgrespro.ru", "phone": "+70614839395"}
0005433059066	9A40F6	5242 176219	KSENIYA KUZMINA	{"phone": "+70564214797"}
0005433059067	DB6C89	5461 673896	SOFYA KUZNECOVA	{"phone": "+70960416630"}
0005433060366	32AE23	1390 271064	MARGARITA SERGEEVA	{"phone": "+70166257446"}
0005433060367	DA25C0	5438 597923	LYUDMILA ROMANOVA	{"email": "lyudmila-romanova_081975@postgrespro.ru", "phone": "+70661897753"}
0005433060368	29EF79	4071 091498	ARINA FADEEVA	{"phone": "+70080725073"}
0005433060369	49B66E	0845 384575	EVGENIY ZAYCEV	{"email": "zaycev_evgeniy_1972@postgrespro.ru", "phone": "+70698480254"}
0005433060370	723BBD	1728 091450	VLADISLAV RODIONOV	{"email": "vladislav_rodionov.06041977@postgrespro.ru", "phone": "+70006293771"}
0005433060371	2456DA	6250 369764	ANDREY KOZLOV	{"email": "kozlovandrey.061974@postgrespro.ru", "phone": "+70282875992"}
0005433060372	0CE044	7568 669541	NATALYA KOVALEVA	{"email": "natalya-kovaleva101978@postgrespro.ru", "phone": "+70497852659"}
0005433060373	E483A7	2374 974384	ALEKSEY KUZNECOV	{"phone": "+70349747649"}
0005433060374	E483A7	3057 237490	VIKTOR KAZAKOV	{"email": "kazakov-viktor.1962@postgrespro.ru", "phone": "+70836826891"}
0005433060375	0F42E1	3049 231408	EKATERINA KUZNECOVA	{"email": "ekaterina_kuznecova-1968@postgrespro.ru", "phone": "+70654293415"}
0005433060376	0F42E1	5949 327228	IVAN POPOV	{"email": "ivanpopov_1971@postgrespro.ru", "phone": "+70022668521"}
0005433060377	D279C7	3436 872425	ALEKSANDR POPOV	{"phone": "+70566200562"}
0005433060378	FBB28A	0216 652947	LYUDMILA NOVIKOVA	{"email": "novikova.l.10121970@postgrespro.ru", "phone": "+70989945773"}
0005433060379	FBB28A	2983 328610	IVAN PETROV	{"email": "petrov.i13101976@postgrespro.ru", "phone": "+70710734801"}
0005433060380	4ABD98	5782 991426	VIKTOR KUZNECOV	{"email": "viktorkuznecov_25061970@postgrespro.ru", "phone": "+70565370122"}
0005433060381	3D6F1E	0576 411497	NINA FROLOVA	{"email": "n_frolova_101966@postgrespro.ru", "phone": "+70377604813"}
0005433060382	3D6F1E	6853 141306	NADEZHDA ROMANOVA	{"phone": "+70670135095"}
0005433060383	BE03B9	1852 266230	ARTEM VOLKOV	{"email": "volkov-artem1963@postgrespro.ru", "phone": "+70535411734"}
0005433060384	16606A	9126 814900	DMITRIY CHERNOV	{"email": "chernovdmitriy_111970@postgrespro.ru", "phone": "+70127513499"}
0005433060385	7F76FF	5164 562331	NADEZHDA RODIONOVA	{"email": "nadezhda-rodionova021973@postgrespro.ru", "phone": "+70646123317"}
0005433060386	7F76FF	4872 645476	ELENA MOROZOVA	{"email": "elena.morozova-25031978@postgrespro.ru", "phone": "+70730433336"}
0005433060387	1C804A	5330 773608	ALEKSEY IVANOV	{"phone": "+70212438140"}
0005433060388	0DCD43	0981 055971	SVETLANA NESTEROVA	{"email": "s-nesterova091974@postgrespro.ru", "phone": "+70329683936"}
0005433060389	215C0D	9086 703616	NIKOLAY ROMANOV	{"phone": "+70101594971"}
0005433060390	39EFE0	7371 518915	ALEKSANDR ANTONOV	{"phone": "+70551191083"}
0005433060391	4FF3DB	4851 716633	MARINA MELNIKOVA	{"phone": "+70357884604"}
0005433060392	4FF3DB	0866 435867	IGOR GERASIMOV	{"phone": "+70512138795"}
0005433060393	1DE2DA	1910 713587	OLEG KARPOV	{"phone": "+70978870148"}
0005433060394	FF89C4	6314 678036	VLADIMIR VASILEV	{"email": "vasilev.vladimir-1978@postgrespro.ru", "phone": "+70191255318"}
0005433060395	8C93BC	2384 290407	NADEZHDA ZOTOVA	{"phone": "+70739336318"}
0005433060396	5DCFD1	4871 189130	EKATERINA IVANOVA	{"email": "e.ivanova_23111979@postgrespro.ru", "phone": "+70569098592"}
0005433060397	C63BF9	1369 464709	VLADIMIR BELOV	{"phone": "+70071334739"}
0005433060398	FE8149	7529 929028	YURIY CHERNOV	{"phone": "+70777955153"}
0005433060399	E2D503	0632 686301	ANTONINA NIKITINA	{"phone": "+70885506992"}
0005433060400	A6E0DA	2498 418157	ZAKHAR BONDARENKO	{"email": "zakhar.bondarenko-14091973@postgrespro.ru", "phone": "+70281071362"}
0005433060401	A6E0DA	5127 449354	RUDOLF MARTYNOV	{"phone": "+70247400862"}
0005433060402	2BE886	4094 466790	ALEFTINA KONOVALOVA	{"email": "konovalova_aleftina.091964@postgrespro.ru", "phone": "+70358418548"}
0005433060403	AC877F	1164 966610	MAKSIM ZHUKOV	{"email": "m_zhukov-19091972@postgrespro.ru", "phone": "+70943014478"}
0005433060404	031836	1939 720501	OLEG KAZAKOV	{"phone": "+70316963648"}
0005433060405	36B26B	1814 268720	SERGEY ILIN	{"phone": "+70410643515"}
0005433060406	36B26B	6606 258993	ANATOLIY MATVEEV	{"email": "matveevanatoliy101967@postgrespro.ru", "phone": "+70262640532"}
0005433060407	94C0A7	5331 670693	ALEKSANDR MAKSIMOV	{"email": "maksimov-a_1969@postgrespro.ru", "phone": "+70792726672"}
0005433060408	54011B	7444 447616	FANIL OSIPOV	{"phone": "+70860840601"}
0005433060409	C61FB5	7976 483623	MARIYA EFREMOVA	{"phone": "+70218807378"}
0005433060410	C61FB5	4255 644004	LYUDMILA NIKOLAEVA	{"phone": "+70319072386"}
0005433060411	C61FB5	4698 380308	LYUBOV VOROBEVA	{"phone": "+70632283148"}
0005433060412	60CC0A	8546 859362	ANTONINA IVANOVA	{"phone": "+70064297366"}
0005433060413	60CC0A	7884 763316	EVGENIY PETROV	{"email": "evgeniypetrov-05091971@postgrespro.ru", "phone": "+70338538752"}
0005433060414	4CE9AA	8950 851619	VALENTINA TARASOVA	{"email": "tarasovavalentina.29031976@postgrespro.ru", "phone": "+70796997493"}
0005433060415	726D6C	8906 885034	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev_091968@postgrespro.ru", "phone": "+70387699624"}
0005433060416	88C1BC	0784 386820	PETR GRIGOREV	{"email": "pgrigorev04081980@postgrespro.ru", "phone": "+70460500698"}
0005433060417	88C1BC	4402 650445	ALEKSANDR NOVIKOV	{"phone": "+70618042911"}
0005433060418	DC9A77	9782 187622	ARTEM ZAKHAROV	{"phone": "+70960067566"}
0005433060419	DC9A77	0222 593667	ALEKSANDR KONOVALOV	{"phone": "+70595899952"}
0005433060420	90D503	0978 388112	VALENTINA ORLOVA	{"email": "orlovav02021974@postgrespro.ru", "phone": "+70943498905"}
0005433060421	1812C7	9517 522070	IGOR KUDRYASHOV	{"email": "i-kudryashov_121981@postgrespro.ru", "phone": "+70261759674"}
0005433060422	1812C7	4952 515222	ELMIRA ZOTOVA	{"email": "zotova_e.1971@postgrespro.ru", "phone": "+70511379351"}
0005433060423	56E213	2507 619700	RUSLAN ALEKSANDROV	{"phone": "+70663797099"}
0005433060424	AB0133	1769 194449	SERGEY VLASOV	{"email": "svlasov1975@postgrespro.ru", "phone": "+70080425978"}
0005433060425	AB0133	3114 536300	MIKHAIL SAVELEV	{"email": "msavelev_081978@postgrespro.ru", "phone": "+70461133286"}
0005433060426	4DF82F	9592 514816	EKATERINA POPOVA	{"email": "e_popova.021982@postgrespro.ru", "phone": "+70335777155"}
0005433060427	2A6916	9150 187619	ALEKSANDR EGOROV	{"email": "egorov-aleksandr_25021974@postgrespro.ru", "phone": "+70874032490"}
0005433060428	3C1A56	7277 386742	VLADIMIR MEDVEDEV	{"email": "v-medvedev.021989@postgrespro.ru", "phone": "+70420764268"}
0005433060429	B671BE	5478 561519	ALEKSEY SHEVCHENKO	{"phone": "+70645787982"}
0005433060430	33B150	0145 627719	GENNADIY KAZAKOV	{"phone": "+70117514536"}
0005433060431	33B150	3454 578543	ALEKSANDR DENISOV	{"email": "a-denisov_111968@postgrespro.ru", "phone": "+70153922789"}
0005433060432	33B150	1489 294027	DENIS PETROV	{"phone": "+70647367494"}
0005433060433	33B150	0938 758595	VIKTOR SOLOVEV	{"email": "solovev-v-20111987@postgrespro.ru", "phone": "+70196830934"}
0005433060434	B724BE	7325 281782	ELENA KULIKOVA	{"email": "e.kulikova_031979@postgrespro.ru", "phone": "+70395802768"}
0005433060435	B724BE	4783 768117	GENNADIY EGOROV	{"phone": "+70674115877"}
0005433060436	B724BE	2220 307568	MARIYA SAVELEVA	{"email": "saveleva.mariya-041969@postgrespro.ru", "phone": "+70906769601"}
0005433060437	1E7167	8232 346504	ALEKSEY MEDVEDEV	{"email": "a_medvedev.1973@postgrespro.ru", "phone": "+70935085667"}
0005433060438	1E7167	2926 937600	ANASTASIYA IVANOVA	{"phone": "+70866274849"}
0005433060439	1E7167	0978 975707	TATYANA ZAYCEVA	{"email": "zayceva-tatyana_091967@postgrespro.ru", "phone": "+70264332986"}
0005433060440	D8F14E	6369 561233	NIKOLAY NOVIKOV	{"phone": "+70377448234"}
0005433060441	07C735	6558 269366	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr12071966@postgrespro.ru", "phone": "+70202474791"}
0005433060442	27236D	3160 446824	EKATERINA SERGEEVA	{"email": "e-sergeeva_061973@postgrespro.ru", "phone": "+70671214015"}
0005433060443	BB9D84	2937 823403	YURIY MOISEEV	{"phone": "+70166844626"}
0005433060444	BB9D84	9865 404506	ANTONINA KULIKOVA	{"phone": "+70980393864"}
0005433060445	4595BD	3480 993158	ALEKSANDR ZAYCEV	{"email": "zaycev.a_011966@postgrespro.ru", "phone": "+70448300799"}
0005433060446	21AAF4	5952 290917	SERGEY ZAYCEV	{"email": "zaycev_sergey23071961@postgrespro.ru", "phone": "+70803490015"}
0005433060447	A85114	1998 751988	PAVEL GERASIMOV	{"phone": "+70416339925"}
0005433060448	2E257E	5517 147300	SEMEN ANDREEV	{"email": "semen_andreev-1973@postgrespro.ru", "phone": "+70619151560"}
0005433060449	DDCE92	9535 930074	ALEKSANDR SAVELEV	{"phone": "+70347387817"}
0005433060450	F913A5	3137 058162	VASILISA SCHERBAKOVA	{"email": "scherbakova_v-13081973@postgrespro.ru", "phone": "+70319333591"}
0005433060451	CD4ED3	2355 235365	VLADISLAV KONOVALOV	{"email": "konovalov_v_091968@postgrespro.ru", "phone": "+70049013071"}
0005433060452	C39BF1	9918 165952	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov-061972@postgrespro.ru", "phone": "+70612753181"}
0005433060453	C39BF1	3675 630060	IRINA KOVALEVA	{"email": "kovaleva-i_28031978@postgrespro.ru", "phone": "+70389149866"}
0005433060454	24E0B7	8517 872324	VITALIY ROMANOV	{"email": "romanov.vitaliy_041971@postgrespro.ru", "phone": "+70888464605"}
0005433060455	24E0B7	6667 716565	SERGEY SOLOVEV	{"email": "solovev.s-061983@postgrespro.ru", "phone": "+70821737424"}
0005433060456	94C5EF	5065 239621	OLGA FEDOROVA	{"phone": "+70226788457"}
0005433060457	94C5EF	8188 220894	TATYANA IVANOVA	{"email": "tatyana_ivanova1985@postgrespro.ru", "phone": "+70049829309"}
0005433060458	C2DBC5	8995 343386	ALEKSEY SMIRNOV	{"phone": "+70663204805"}
0005433060459	A824EC	3042 615325	DENIS AFANASEV	{"email": "afanasevdenis.031971@postgrespro.ru", "phone": "+70375440082"}
0005433060460	3C84F7	0822 258716	ARTEM EGOROV	{"email": "egorov-a.1975@postgrespro.ru", "phone": "+70421810857"}
0005433060461	9D8B32	5907 173987	SERGEY MOISEEV	{"phone": "+70861968651"}
0005433060462	6A1472	9255 025780	MAKSIM SMIRNOV	{"phone": "+70231924710"}
0005433060463	6A1472	5166 062347	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.17081965@postgrespro.ru", "phone": "+70791617406"}
0005433060464	07878E	5822 805627	PLATON FEDOTOV	{"phone": "+70224827679"}
0005433060465	F1EA10	1745 519451	EVGENIYA MALYSHEVA	{"phone": "+70642913299"}
0005433060466	E18854	2200 661616	MARIYA PAVLOVA	{"phone": "+70086026394"}
0005433060467	EE09E4	4389 130224	ILYA FROLOV	{"phone": "+70287776578"}
0005433060468	EC55AC	3299 778186	LYUDMILA NIKOLAEVA	{"phone": "+70517206698"}
0005433060469	EC55AC	4114 395062	MILENA SEMENOVA	{"email": "milenasemenova1976@postgrespro.ru", "phone": "+70171073255"}
0005433060470	9B766E	5997 793843	DENIS DENISOV	{"phone": "+70577334590"}
0005433060471	D97155	2901 069542	VALENTINA FADEEVA	{"phone": "+70753853500"}
0005433060472	E20406	2019 465685	VIKTOR FROLOV	{"phone": "+70287203230"}
0005433060473	90FCEF	4892 167909	ALEKSANDRA EFIMOVA	{"phone": "+70865473451"}
0005433060474	7F258D	6419 619790	GALINA DENISOVA	{"phone": "+70370228494"}
0005433060475	8177CA	4210 568548	SERGEY BELOV	{"phone": "+70286095565"}
0005433060476	627BC9	9178 700113	TATYANA KISELEVA	{"email": "t_kiseleva1969@postgrespro.ru", "phone": "+70218445164"}
0005433060477	6005D5	0256 927894	MIKHAIL SEMENOV	{"phone": "+70106025250"}
0005433060478	FD5A2F	8873 869031	ELENA KOZLOVA	{"phone": "+70738241163"}
0005433060479	4F6807	7096 929725	VLADISLAV KOZLOV	{"email": "kozlov.v-031968@postgrespro.ru", "phone": "+70666412909"}
0005433060480	4F6807	0708 350615	MAKSIM VASILEV	{"phone": "+70268377895"}
0005433060481	4E90CF	0367 029444	VLADIMIR KUZNECOV	{"email": "kuznecov_v.13101968@postgrespro.ru", "phone": "+70370005876"}
0005433060482	4E90CF	5289 340678	NATALYA SOKOLOVA	{"email": "natalyasokolova.1967@postgrespro.ru", "phone": "+70541142135"}
0005433060483	4E90CF	0535 038682	GALINA RYABOVA	{"phone": "+70009959914"}
0005433060484	AD5456	0667 764065	MARINA ISAEVA	{"phone": "+70167045480"}
0005433060485	AD5456	1318 158938	NIKOLAY SMIRNOV	{"phone": "+70209487202"}
0005433060486	D82A47	7783 100015	GALINA DENISOVA	{"phone": "+70246373180"}
0005433060487	D82A47	4078 658538	DANIIL STEPANOV	{"phone": "+70401701932"}
0005433060488	650215	6143 943112	VALERIY BELOV	{"phone": "+70945097131"}
0005433060489	650215	3689 164836	TATYANA ZHUKOVA	{"email": "zhukova-tatyana28101973@postgrespro.ru", "phone": "+70807734172"}
0005433060490	DD868F	9811 636061	VITALIY NIKITIN	{"phone": "+70182210905"}
0005433060491	E1C152	0929 839872	NADEZHDA MALYSHEVA	{"email": "malyshevan-061977@postgrespro.ru", "phone": "+70668892232"}
0005433060492	C9BCA1	9782 872815	ALEKSANDR ALEKSANDROV	{"phone": "+70948326043"}
0005433074196	255C9A	1324 499266	TATYANA SOROKINA	{"phone": "+70049466193"}
0005433074197	E56341	1203 230478	RADIK KUZNECOV	{"email": "r.kuznecov-14011971@postgrespro.ru", "phone": "+70511497992"}
0005433074198	D05B86	1739 489341	ANATOLIY ZHUKOV	{"email": "zhukov.a111968@postgrespro.ru", "phone": "+70344507043"}
0005433074199	A7868E	9038 406521	IRINA SMIRNOVA	{"phone": "+70281899313"}
0005433074200	091456	3277 308812	ALENA POPOVA	{"email": "a.popova041978@postgrespro.ru", "phone": "+70554859975"}
0005433074201	091456	9867 065746	KIRILL ABRAMOV	{"phone": "+70709219856"}
0005433074202	FD9CA5	1148 591282	NIKOLAY SEMENOV	{"phone": "+70208539332"}
0005433074203	39F27A	4082 260533	YULIYA SEMENOVA	{"email": "yuliya_semenova_121970@postgrespro.ru", "phone": "+70117150901"}
0005433074204	39F27A	4159 824515	VADIM SEMENOV	{"email": "semenovvadim24011968@postgrespro.ru", "phone": "+70069095605"}
0005433074205	5451C1	8602 544255	LIDIYA NAUMOVA	{"phone": "+70134264046"}
0005433074206	FB3074	3975 988067	ALEKSANDR MIRONOV	{"phone": "+70274810209"}
0005433074207	FB3074	8180 334717	ANDREY PETROV	{"phone": "+70638546830"}
0005433074208	E2520E	9267 902879	VADIM SOROKIN	{"phone": "+70042659154"}
0005433074209	E2520E	6695 898266	OKSANA MARTYNOVA	{"phone": "+70505132716"}
0005433074210	647734	5066 252085	VLADIMIR STEPANOV	{"phone": "+70434236983"}
0005433074211	9944E0	4404 373981	EVGENIY MATVEEV	{"email": "matveev.evgeniy19111970@postgrespro.ru", "phone": "+70445768206"}
0005433074212	9944E0	8502 797002	ANDREY KOZLOV	{"phone": "+70248549247"}
0005433074213	970289	5277 777557	MARIANNA DAVYDOVA	{"phone": "+70836456157"}
0005433074438	04A948	7962 047139	IRINA LEBEDEVA	{"phone": "+70616723193"}
0005433074214	970289	5864 956379	KONSTANTIN NIKITIN	{"email": "nikitin-k-071975@postgrespro.ru", "phone": "+70233932370"}
0005433074215	B70688	8232 018711	VERA SOROKINA	{"email": "sorokina_v_031978@postgrespro.ru", "phone": "+70947975831"}
0005433074216	B70688	0722 036939	ANATOLIY SMIRNOV	{"email": "smirnov-a071973@postgrespro.ru", "phone": "+70456248553"}
0005433074217	3E4461	0500 614447	EVGENIYA SCHERBAKOVA	{"email": "scherbakovaevgeniya_1971@postgrespro.ru", "phone": "+70791337356"}
0005433074218	460CE2	9535 042712	EKATERINA ABRAMOVA	{"email": "abramova-e.20021975@postgrespro.ru", "phone": "+70979308828"}
0005433074219	FFB3BD	1911 663787	ANASTASIYA MASLOVA	{"email": "maslovaanastasiya_09081978@postgrespro.ru", "phone": "+70612123464"}
0005433074220	12A0CA	3853 051126	VLADIMIR BELOV	{"email": "vladimir_belov.28031979@postgrespro.ru", "phone": "+70097644238"}
0005433074221	328FB3	0268 685765	NINA NIKOLAEVA	{"phone": "+70490786344"}
0005433074222	328FB3	3489 860101	MARIYA KONOVALOVA	{"phone": "+70091039137"}
0005433074223	328FB3	7132 161624	NINA DENISOVA	{"email": "denisova.n19091969@postgrespro.ru", "phone": "+70591689717"}
0005433074224	574192	4030 183315	ANDREY EGOROV	{"email": "andrey-egorov_15081977@postgrespro.ru", "phone": "+70808212650"}
0005433074225	E3A2D1	7056 779619	VLADIMIR ALEKSEEV	{"email": "alekseevv.1971@postgrespro.ru", "phone": "+70063337879"}
0005433074226	669598	9119 960238	ALEKSANDR ORLOV	{"phone": "+70557750854"}
0005433074227	83DA72	0664 475784	SERGEY ILIN	{"phone": "+70933506575"}
0005433074228	83DA72	8754 890378	ELENA GRISHINA	{"email": "elena.grishina1963@postgrespro.ru", "phone": "+70089897960"}
0005433074229	F9C42C	8316 502519	ELENA ZHURAVLEVA	{"phone": "+70633679998"}
0005433074230	830E0A	0988 158538	VITALIY POPOV	{"phone": "+70966256493"}
0005433074231	85675F	7777 832246	KIRILL VLASOV	{"phone": "+70685415012"}
0005433074232	ACFD71	2772 190842	ALEKSEY KOZLOV	{"email": "kozlov_a_10021978@postgrespro.ru", "phone": "+70995159998"}
0005433074233	3905E6	1277 229490	TIMOFEY IVANOV	{"phone": "+70095584367"}
0005433074234	197842	1323 458840	SVETLANA IVANOVA	{"phone": "+70831587232"}
0005433074235	CBD038	5397 079710	ARKADIY POPOV	{"email": "arkadiy.popov.091969@postgrespro.ru", "phone": "+70389345119"}
0005433074236	3FBA09	7747 258389	LIDIYA ARKHIPOVA	{"email": "arkhipova.lidiya-1965@postgrespro.ru", "phone": "+70273922414"}
0005433074237	3FBA09	2447 564780	YULIYA KOLESNIKOVA	{"phone": "+70109253453"}
0005433074238	C6E553	4523 931499	ANTONINA LUKYANOVA	{"email": "lukyanova_antonina-1974@postgrespro.ru", "phone": "+70864773887"}
0005433074239	846EA3	6681 721416	SVETLANA MAKAROVA	{"email": "svetlana-makarova_041973@postgrespro.ru", "phone": "+70551768208"}
0005433074240	846EA3	9503 054542	NATALIYA OSIPOVA	{"email": "nosipova-111972@postgrespro.ru", "phone": "+70600230233"}
0005433074241	98B488	9723 267891	ALEKSEY EGOROV	{"phone": "+70592682387"}
0005433074242	8AD013	4378 668766	VSEVOLOD MATVEEV	{"email": "matveevvsevolod-1969@postgrespro.ru", "phone": "+70207106375"}
0005433074243	322807	7729 780964	ANTON SOROKIN	{"email": "antonsorokin-17031974@postgrespro.ru", "phone": "+70791323560"}
0005433074244	322807	2629 067186	ALEKSANDRA KULIKOVA	{"phone": "+70741591998"}
0005433074245	322807	6100 892945	LIDIYA ILINA	{"email": "lidiya_ilina.091976@postgrespro.ru", "phone": "+70388405396"}
0005433074246	41160A	7676 485872	SERGEY SOROKIN	{"email": "sorokin-sergey_031973@postgrespro.ru", "phone": "+70082815583"}
0005433074247	C13D85	1456 232340	DANIIL GAVRILOV	{"email": "gavrilov_daniil08081970@postgrespro.ru", "phone": "+70607168207"}
0005433074248	F4B273	5144 769871	NINA ERMAKOVA	{"email": "n.ermakova_1967@postgrespro.ru", "phone": "+70742350163"}
0005433074249	F4B273	3148 505671	VERA SOKOLOVA	{"phone": "+70358964259"}
0005433074250	F4B273	6131 893228	NIKOLAY SMIRNOV	{"email": "nikolay-smirnov-1967@postgrespro.ru", "phone": "+70426105568"}
0005433074251	F4D46C	7452 619769	LYUDMILA SCHERBAKOVA	{"email": "l-scherbakova-1964@postgrespro.ru", "phone": "+70511042884"}
0005433074252	F4D46C	6853 084473	ILYA ALEKSANDROV	{"email": "i.aleksandrov_1972@postgrespro.ru", "phone": "+70476274538"}
0005433074253	821BA2	9524 920338	VERA IVANOVA	{"phone": "+70626444953"}
0005433074254	821BA2	1725 494616	ARTEM ALEKSEEV	{"phone": "+70807117995"}
0005433074255	4533A9	8847 707103	SERGEY FILIPPOV	{"phone": "+70404241587"}
0005433074256	4533A9	7714 511503	ANDREY VASILEV	{"email": "vasileva_1967@postgrespro.ru", "phone": "+70205424737"}
0005433074257	4533A9	6564 805985	SERGEY GAVRILOV	{"phone": "+70381416548"}
0005433074258	227054	2779 108731	GALINA ROMANOVA	{"email": "gromanova.13041969@postgrespro.ru", "phone": "+70251912266"}
0005433074259	227054	6831 022347	GENNADIY KUZNECOV	{"phone": "+70497631736"}
0005433074260	DA2EB3	2806 769303	ANDREY KISELEV	{"phone": "+70739546010"}
0005433074261	23B3CC	0158 084482	ARTEM VLASOV	{"email": "vlasov.a.111969@postgrespro.ru", "phone": "+70170670918"}
0005433074262	64F11A	0525 803674	NATALYA DMITRIEVA	{"phone": "+70595022006"}
0005433074263	0EAC03	1890 618378	VERA BOGDANOVA	{"email": "v-bogdanova1967@postgrespro.ru", "phone": "+70533666956"}
0005433074264	D98916	8246 826454	VIKTOR GRIGOREV	{"email": "viktorgrigorev.18031973@postgrespro.ru", "phone": "+70329564052"}
0005433074265	071AA6	6800 978778	NADEZHDA OSIPOVA	{"phone": "+70116665648"}
0005433074266	860EE3	1537 209836	ANDREY ZAKHAROV	{"phone": "+70258277975"}
0005433074267	860EE3	2417 805648	TATYANA FILATOVA	{"phone": "+70837591634"}
0005433074268	DDD597	4023 713663	KAMILA GORBUNOVA	{"phone": "+70926885127"}
0005433074495	AC961E	3810 585238	ELIZAVETA FILIPPOVA	{"phone": "+70148728695"}
0005433074269	0CAD4F	9355 320265	EVGENIY VOLKOV	{"email": "evgeniy_volkov16091974@postgrespro.ru", "phone": "+70666804896"}
0005433074270	B5E623	3402 434573	ANGELINA NIKIFOROVA	{"phone": "+70176070601"}
0005433074271	B5E623	5434 387424	ZINAIDA MALYSHEVA	{"phone": "+70548632775"}
0005433074272	059B9D	9765 439829	VIKTORIYA KONOVALOVA	{"phone": "+70733589923"}
0005433074273	EE4113	9580 352599	ALEKSANDR KAZAKOV	{"phone": "+70011029576"}
0005433074274	EE4113	1457 509778	SERGEY GORBUNOV	{"email": "sgorbunov.17101980@postgrespro.ru", "phone": "+70964250690"}
0005433074275	92F711	0517 068481	ANTONINA VOLKOVA	{"phone": "+70097908798"}
0005433074276	AD1732	5498 251265	MAKSIM DENISOV	{"phone": "+70359344435"}
0005433074277	204BA8	5062 917387	TATYANA FROLOVA	{"phone": "+70045137918"}
0005433074278	659DF2	1712 286437	OLGA KONOVALOVA	{"email": "o.konovalova1973@postgrespro.ru", "phone": "+70239233143"}
0005433074279	7E8679	8662 257980	NATALYA MAKAROVA	{"email": "makarova-n.1966@postgrespro.ru", "phone": "+70530337734"}
0005433074280	18325A	4785 001579	LYUDMILA MARTYNOVA	{"phone": "+70007131002"}
0005433074281	18325A	6362 680478	ANTONINA ZAYCEVA	{"phone": "+70362023717"}
0005433074282	D1C6D2	2333 117007	YULIYA DMITRIEVA	{"phone": "+70117708378"}
0005433074283	D1C6D2	5333 899136	LYUDMILA NIKOLAEVA	{"phone": "+70425836722"}
0005433074284	D9166B	4871 876056	MIKHAIL GORBUNOV	{"phone": "+70238065275"}
0005433074285	7844E0	5621 400522	VIKTOR EGOROV	{"email": "viktor-egorov1975@postgrespro.ru", "phone": "+70166350904"}
0005433074286	70C441	4480 290232	YULIYA VOROBEVA	{"phone": "+70635176121"}
0005433074287	70C441	2251 597931	DARYA BORISOVA	{"email": "borisova_darya.12071963@postgrespro.ru", "phone": "+70809483437"}
0005433074288	F77B7B	5420 395471	ANNA PETROVA	{"phone": "+70879177428"}
0005433074289	0A3A82	3656 025031	LYUBOV POTAPOVA	{"phone": "+70317684462"}
0005433074290	189C1A	7227 326200	NADEZHDA POTAPOVA	{"phone": "+70339455698"}
0005433074291	3560B5	8351 668804	OLGA POPOVA	{"email": "popovaolga_051969@postgrespro.ru", "phone": "+70127371145"}
0005433074292	3560B5	8936 380004	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov-1980@postgrespro.ru", "phone": "+70202797867"}
0005433074293	07F18A	0153 821321	OLEG TIKHONOV	{"phone": "+70681725621"}
0005433074294	2092A2	8720 935189	VALERIY POPOV	{"email": "popovv-121968@postgrespro.ru", "phone": "+70290118700"}
0005433074295	2092A2	7402 603714	MAKSIM SIDOROV	{"phone": "+70657713025"}
0005433074296	CB6751	9986 326095	IRINA NOVIKOVA	{"phone": "+70413280148"}
0005433074297	CB6751	1401 727118	YULIYA EGOROVA	{"phone": "+70212166903"}
0005433074298	A2907B	0746 324675	ALEKSANDRA IVANOVA	{"email": "ivanovaa_1975@postgrespro.ru", "phone": "+70033714589"}
0005433074299	4367BC	0339 732513	DARYA SEMENOVA	{"email": "darya_semenova.101969@postgrespro.ru", "phone": "+70388101724"}
0005433074300	4367BC	1279 980816	DMITRIY NIKOLAEV	{"phone": "+70906477657"}
0005433074301	061C74	9791 551921	VASILIY VOLKOV	{"email": "v-volkov_041975@postgrespro.ru", "phone": "+70744535858"}
0005433074302	061C74	1964 700654	KSENIYA ZAYCEVA	{"phone": "+70941013119"}
0005433074303	D7E016	8464 950333	SVETLANA ANISIMOVA	{"email": "s-anisimova.1961@postgrespro.ru", "phone": "+70494214782"}
0005433074304	3B2A87	8268 151674	ANDREY PETROV	{"phone": "+70051481143"}
0005433074305	3B2A87	2933 233032	LYUBOV NAUMOVA	{"email": "naumova_lyubov-1982@postgrespro.ru", "phone": "+70009654313"}
0005433074306	25BEDE	0538 689026	IRINA NOVIKOVA	{"email": "inovikova121970@postgrespro.ru", "phone": "+70828484808"}
0005433074307	F91384	6125 490968	YANA MIKHAYLOVA	{"email": "mikhaylova.yana_1965@postgrespro.ru", "phone": "+70191026426"}
0005433074308	F91384	3689 435103	GENNADIY SIDOROV	{"phone": "+70380338105"}
0005433074309	DAE0E1	4261 403486	LYUBOV KUDRYASHOVA	{"email": "kudryashova.l051970@postgrespro.ru", "phone": "+70352567310"}
0005433074310	C70CB2	1667 857621	SERGEY ILIN	{"phone": "+70096032426"}
0005433074311	C70CB2	0456 034257	STEPAN SMIRNOV	{"phone": "+70578406837"}
0005433074312	046F48	3921 256223	MARIYA KOZLOVA	{"phone": "+70796802024"}
0005433074313	046F48	5093 815810	NINA PETROVA	{"phone": "+70645576379"}
0005433074314	046F48	3997 373752	VLADISLAV SERGEEV	{"email": "sergeev.vladislav1981@postgrespro.ru", "phone": "+70327459697"}
0005433074315	85232A	1389 535218	MAKSIM ORLOV	{"phone": "+70208351268"}
0005433074316	0E3140	5030 921871	EVGENIY KUDRYASHOV	{"phone": "+70268791918"}
0005433074317	F177B5	0854 339718	ANDREY MOISEEV	{"phone": "+70177471004"}
0005433074318	8CBE1B	9243 186811	LIYA GUSEVA	{"phone": "+70891493028"}
0005433074319	95114F	2289 681166	VALENTIN KRASNOV	{"email": "valentin.krasnov.1985@postgrespro.ru", "phone": "+70626117049"}
0005433074320	EFA069	8019 569441	VASILIY FEDOROV	{"phone": "+70511919937"}
0005433074321	5870E2	6875 294862	VALERIYA MIKHAYLOVA	{"email": "valeriyamikhaylova27091962@postgrespro.ru", "phone": "+70542239318"}
0005433074322	5F2B50	4632 404984	DANILA KUZNECOV	{"email": "danilakuznecov05111971@postgrespro.ru", "phone": "+70217064111"}
0005433074323	5F2B50	8243 722702	RAVIL ZAKHAROV	{"phone": "+70793712972"}
0005433074324	E6A42E	5550 628562	VLADIMIR ANTONOV	{"email": "v.antonov101986@postgrespro.ru", "phone": "+70685550873"}
0005433074325	E6A42E	6378 317705	EVGENIY SOKOLOV	{"phone": "+70813699375"}
0005433074552	81AAE4	9347 953583	LYUBOV SEMENOVA	{"phone": "+70970814834"}
0005433074326	664C61	1669 029260	PAVEL VASILEV	{"email": "vasilev-pavel-031966@postgrespro.ru", "phone": "+70093398411"}
0005433074327	664C61	6091 287534	GALINA ALEKSEEVA	{"email": "alekseeva.g_121965@postgrespro.ru", "phone": "+70434889906"}
0005433074328	8018EB	7275 932138	VALERIY MOROZOV	{"email": "morozovv1964@postgrespro.ru", "phone": "+70845427017"}
0005433074329	B92C89	6985 029593	EKATERINA TIKHONOVA	{"phone": "+70981093746"}
0005433074330	3B9CBD	8690 669285	GENNADIY ABRAMOV	{"phone": "+70167523436"}
0005433074331	E67661	0207 045435	VYACHESLAV NAZAROV	{"email": "vyacheslav-nazarov041972@postgrespro.ru", "phone": "+70797393774"}
0005433074332	0DAD4F	8391 718474	DMITRIY DMITRIEV	{"email": "dmitriev_d_081973@postgrespro.ru", "phone": "+70764151577"}
0005433074333	34A819	5762 530541	KSENIYA ZAKHAROVA	{"email": "zakharova_kseniya.19021971@postgrespro.ru", "phone": "+70509747170"}
0005433074334	34A819	4244 193831	LYUDMILA BORISOVA	{"email": "borisova.l.111971@postgrespro.ru", "phone": "+70563955851"}
0005433074335	7FA545	9711 268599	OLGA MAKSIMOVA	{"phone": "+70244308514"}
0005433074336	73206B	5675 826167	KSENIYA NOVIKOVA	{"phone": "+70673415034"}
0005433074337	FE6501	1600 270457	SVETLANA ZAYCEVA	{"phone": "+70790080028"}
0005433074338	FE6501	5737 215200	EVGENIY SHEVCHENKO	{"phone": "+70247727473"}
0005433074339	AE193C	7651 020869	ALEKSANDR KUZNECOV	{"phone": "+70124591130"}
0005433074340	6E14EB	3794 311445	VALENTINA ZOTOVA	{"phone": "+70438949760"}
0005433074341	B1DEBE	5742 483940	SERGEY KAZAKOV	{"email": "s_kazakov_22081971@postgrespro.ru", "phone": "+70443843933"}
0005433074342	878E03	4146 266238	NINA ANISIMOVA	{"email": "anisimova.n-1957@postgrespro.ru", "phone": "+70836113814"}
0005433074343	878E03	7659 064631	ZHANNA VOROBEVA	{"phone": "+70494993112"}
0005433074344	B81888	1662 375979	YULIYA BORISOVA	{"email": "yuliya-borisova-021967@postgrespro.ru", "phone": "+70274817504"}
0005433074345	ECCC97	8089 170100	VERA SMIRNOVA	{"email": "vera.smirnova.30111974@postgrespro.ru", "phone": "+70784363427"}
0005433074346	F40A34	8876 085968	NADEZHDA TIKHONOVA	{"phone": "+70917029209"}
0005433074347	F40A34	7447 222393	EVGENIYA NIKOLAEVA	{"phone": "+70913601973"}
0005433074348	8E1A9A	9466 624364	TATYANA DENISOVA	{"phone": "+70703945146"}
0005433074349	8E1A9A	9040 914615	ILDAR ZAKHAROV	{"phone": "+70562298945"}
0005433074350	02B80C	1563 478024	DANIIL KUZNECOV	{"email": "daniil_kuznecov081977@postgrespro.ru", "phone": "+70188484776"}
0005433074351	820456	0308 584397	ALIYA IVANOVA	{"phone": "+70012201740"}
0005433074352	820456	0804 949012	VALENTINA MASLOVA	{"email": "v.maslova.16021964@postgrespro.ru", "phone": "+70120478796"}
0005433074353	C1ED83	5661 347006	VIKTORIYA SIDOROVA	{"email": "viktoriya.sidorova1968@postgrespro.ru", "phone": "+70122015308"}
0005433074354	AA61CB	4520 316318	ELENA MAKSIMOVA	{"email": "maksimova_elena041968@postgrespro.ru", "phone": "+70180522073"}
0005433074355	CCDE01	9272 882342	SERGEY VOLKOV	{"phone": "+70319833950"}
0005433074356	933E46	6865 289114	DENIS ILIN	{"email": "ilin.denis_11071971@postgrespro.ru", "phone": "+70051029367"}
0005433074357	552D4E	3751 904740	GENNADIY SIDOROV	{"email": "sidorovg.1962@postgrespro.ru", "phone": "+70179816072"}
0005433074358	5D2F04	9741 348306	LYUDMILA ROMANOVA	{"phone": "+70342289543"}
0005433074359	3D24E1	2571 791443	ARTEM SIDOROV	{"email": "sidorovartem-1967@postgrespro.ru", "phone": "+70129558655"}
0005433074360	44AC35	8307 940623	DMITRIY SAVELEV	{"phone": "+70698495827"}
0005433074361	44AC35	0377 903404	YURIY FROLOV	{"phone": "+70979387003"}
0005433074362	44AC35	7937 469793	NATALYA EGOROVA	{"email": "natalya_egorova-1979@postgrespro.ru", "phone": "+70315826790"}
0005433074363	3F780C	3009 425242	ALEKSANDRA TITOVA	{"phone": "+70807877466"}
0005433074364	369C5A	3345 529163	TATYANA GERASIMOVA	{"email": "gerasimova-t_13091968@postgrespro.ru", "phone": "+70395222500"}
0005433074365	7CC927	0716 211387	ELENA IVANOVA	{"phone": "+70793295467"}
0005433074366	087930	8402 883274	YULIYA MAKSIMOVA	{"phone": "+70663228623"}
0005433074367	AC5B0D	6476 058641	YURIY PAVLOV	{"email": "pavlov_yuriy.1972@postgrespro.ru", "phone": "+70146352996"}
0005433074368	0C34A7	2204 912731	VASILIY GERASIMOV	{"email": "gerasimov-v-1979@postgrespro.ru", "phone": "+70523629820"}
0005433074369	606159	7573 195980	ROMAN BONDARENKO	{"phone": "+70543335552"}
0005433074370	315594	3415 610613	LYUDMILA SAVELEVA	{"phone": "+70687556455"}
0005433074371	8698FA	6264 219621	NATALYA YUDINA	{"email": "n-yudina.23021984@postgrespro.ru", "phone": "+70144281488"}
0005433074372	8698FA	3494 076753	VIKTOR EGOROV	{"phone": "+70725977811"}
0005433074373	8698FA	7314 077951	KIRILL IVANOV	{"email": "ivanovkirill-10121974@postgrespro.ru", "phone": "+70035307875"}
0005433074374	AC6567	8135 577610	DENIS KAZAKOV	{"phone": "+70003699870"}
0005433074375	99E921	8012 652791	TATYANA VOROBEVA	{"email": "vorobevatatyana-24011967@postgrespro.ru", "phone": "+70750658880"}
0005433074376	5BFB1E	4098 884321	LIDIYA SMIRNOVA	{"email": "smirnova.lidiya021978@postgrespro.ru", "phone": "+70267903272"}
0005433074377	95E4ED	1702 423801	ALENA YAKOVLEVA	{"phone": "+70229552353"}
0005433074378	5FED49	8717 621577	GALINA MELNIKOVA	{"phone": "+70870824029"}
0005433074379	5E0E94	3845 578929	SVETLANA SEMENOVA	{"phone": "+70111340895"}
0005433074380	4DCF38	4591 876128	VALENTINA TARASOVA	{"email": "valentina-tarasova.111968@postgrespro.ru", "phone": "+70709563618"}
0005433074381	4DCF38	9271 998188	TATYANA PETROVA	{"phone": "+70776373246"}
0005433074382	9D6DE6	0411 099436	OLESYA ROMANOVA	{"email": "olesya_romanova091956@postgrespro.ru", "phone": "+70916921118"}
0005433074383	9D6DE6	8575 187065	VERA ZAYCEVA	{"email": "vzayceva-1967@postgrespro.ru", "phone": "+70754040242"}
0005433074384	9D7B99	2136 801232	OLGA NAZAROVA	{"phone": "+70767626094"}
0005433074385	9F934A	5352 760480	YAN KAZAKOV	{"email": "kazakov_y_05101993@postgrespro.ru", "phone": "+70347875056"}
0005433074386	DC787A	1064 340181	GALINA SCHERBAKOVA	{"email": "g.scherbakova_1970@postgrespro.ru", "phone": "+70816896747"}
0005433074387	DC787A	5076 094049	TATYANA SMIRNOVA	{"email": "t-smirnova-041972@postgrespro.ru", "phone": "+70004832835"}
0005433074388	B12CE4	7067 706807	SVETLANA TITOVA	{"email": "titova.s_1984@postgrespro.ru", "phone": "+70605363993"}
0005433074389	8E0E56	9433 038027	MIKHAIL VASILEV	{"email": "mvasilev.30111973@postgrespro.ru", "phone": "+70439601091"}
0005433074390	8E0E56	6396 054826	KIRILL KUZNECOV	{"email": "kirill.kuznecov1969@postgrespro.ru", "phone": "+70178384679"}
0005433074391	862522	8339 626811	VLADIMIR EGOROV	{"phone": "+70647459907"}
0005433074392	9135D7	5917 527795	YULIYA FILIPPOVA	{"phone": "+70590161589"}
0005433074513	23B2C1	4347 570693	OLGA FILATOVA	{"phone": "+70123287689"}
0005433074393	9135D7	9053 844558	NADEZHDA VOROBEVA	{"email": "n_vorobeva-041969@postgrespro.ru", "phone": "+70738275063"}
0005433074394	0E6A78	4259 884597	LARISA EFIMOVA	{"email": "efimovalarisa.1971@postgrespro.ru", "phone": "+70626745255"}
0005433074395	0E6A78	0876 395224	LYUDMILA SOLOVEVA	{"email": "soloveva-lyudmila041973@postgrespro.ru", "phone": "+70164631225"}
0005433074396	899B37	3396 327772	ALEKSANDR BELOV	{"phone": "+70273702690"}
0005433074397	B052FA	1608 974994	SERGEY STEPANOV	{"phone": "+70640013020"}
0005433074398	AF6C3D	5205 028235	EKATERINA BELOVA	{"email": "ekaterinabelova.08021976@postgrespro.ru", "phone": "+70613771796"}
0005433074399	AF6C3D	1366 156687	NINA MATVEEVA	{"phone": "+70501966321"}
0005433074400	AF6C3D	2129 479941	ALEKSEY VOLKOV	{"phone": "+70947191288"}
0005433074401	0E172F	4061 093876	NINA PETROVA	{"phone": "+70251499198"}
0005433074402	2548D1	9596 238974	VYACHESLAV SEMENOV	{"email": "vyacheslav_semenov1966@postgrespro.ru", "phone": "+70108063895"}
0005433074403	A0B75B	2586 942337	KLAVDIYA SEMENOVA	{"phone": "+70044964223"}
0005433074404	EF656E	8404 911325	ALEKSEY ALEKSEEV	{"email": "alekseev_a.31071979@postgrespro.ru", "phone": "+70145020421"}
0005433074405	21DFDF	1073 882383	VERA MAKAROVA	{"email": "makarovavera-17081971@postgrespro.ru", "phone": "+70840871382"}
0005433074406	4FC115	7914 593536	LIDIYA VLASOVA	{"phone": "+70754645949"}
0005433074407	4FC115	7408 196824	OKSANA PAVLOVA	{"phone": "+70914594792"}
0005433074408	30CBA7	8444 772641	VLADIMIR KUZNECOV	{"phone": "+70056532155"}
0005433074409	C183DD	0217 484747	ELENA SIDOROVA	{"email": "sidorova.e-091961@postgrespro.ru", "phone": "+70696778919"}
0005433074410	7AEEBB	7958 173657	DANIIL SEMENOV	{"phone": "+70337364620"}
0005433074411	A01B22	2457 358607	LYUDMILA TROFIMOVA	{"phone": "+70952715611"}
0005433074412	E40831	4172 657562	SERGEY ALEKSEEV	{"phone": "+70142223816"}
0005433074413	361F91	8593 980845	VALERIYA FILATOVA	{"email": "valeriya-filatova10051979@postgrespro.ru", "phone": "+70184492259"}
0005433074414	1BF6E8	8322 600969	DANIIL KOZLOV	{"email": "d-kozlov19121980@postgrespro.ru", "phone": "+70729084099"}
0005433074415	D653C6	8887 406193	DARYA MAKSIMOVA	{"email": "darya.maksimova-1954@postgrespro.ru", "phone": "+70544349686"}
0005433074416	D653C6	2403 244048	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr_031972@postgrespro.ru", "phone": "+70416290310"}
0005433074417	5472BA	7580 852135	ZINAIDA KOROLEVA	{"email": "z-koroleva.11011991@postgrespro.ru", "phone": "+70430504190"}
0005433074418	1B48AD	9978 098971	EKATERINA SMIRNOVA	{"phone": "+70867274093"}
0005433074419	1635DB	2615 382499	RAFAIL BELOV	{"email": "belov_rafail_29061977@postgrespro.ru", "phone": "+70387320612"}
0005433074420	619258	9247 213983	MIKHAIL ROMANOV	{"phone": "+70975899280"}
0005433074421	D43C93	2575 135031	NIKOLAY FOMIN	{"phone": "+70502872425"}
0005433074422	213131	7174 867099	TATYANA PETROVA	{"phone": "+70925891978"}
0005433074423	213131	3980 340424	RASHID PAVLOV	{"phone": "+70419989590"}
0005433074424	213131	9826 735410	TAMARA ROMANOVA	{"email": "tamara-romanova-071974@postgrespro.ru", "phone": "+70477846652"}
0005433074425	3CF8FB	4722 808131	ULYANA ANISIMOVA	{"phone": "+70974405051"}
0005433074426	762E59	5832 973218	IRINA MELNIKOVA	{"phone": "+70671535175"}
0005433074427	13E513	6360 573175	ALEKSANDRA MARTYNOVA	{"email": "martynova.a-27061964@postgrespro.ru", "phone": "+70135411666"}
0005433074428	D4D610	1984 509306	ALIK SEMENOV	{"email": "a-semenov-051961@postgrespro.ru", "phone": "+70239806214"}
0005433074429	F36B4F	9940 424824	LIDIYA KALININA	{"phone": "+70243916601"}
0005433074430	F36B4F	6235 032946	ALEKSANDRA KOMAROVA	{"phone": "+70385901489"}
0005433074431	2EE73F	5435 627947	ANDREY KOZLOV	{"email": "andrey.kozlov_29121972@postgrespro.ru", "phone": "+70000037478"}
0005433074432	2EE73F	7640 334686	ALEKSEY KUZMIN	{"email": "kuzminaleksey_19091967@postgrespro.ru", "phone": "+70031064820"}
0005433074433	46C0FE	3797 333194	ALINA KONOVALOVA	{"email": "a-konovalova-1964@postgrespro.ru", "phone": "+70781422592"}
0005433074434	46C0FE	8065 523852	ALENA OSIPOVA	{"email": "alena.osipova1984@postgrespro.ru", "phone": "+70159174762"}
0005433074435	94F786	4194 079691	DARYA FADEEVA	{"email": "d_fadeeva_1980@postgrespro.ru", "phone": "+70306366014"}
0005433074436	5376CE	3521 299890	MARIYA KRASNOVA	{"phone": "+70497410372"}
0005433074437	5376CE	2752 489458	NATALYA TITOVA	{"email": "titova_natalya.051970@postgrespro.ru", "phone": "+70409474664"}
0005433074439	CE4377	5823 398743	NATALYA MAKSIMOVA	{"email": "maksimova-n_1960@postgrespro.ru", "phone": "+70295476451"}
0005433074440	CE4377	9530 048419	OLGA ISAEVA	{"email": "o_isaeva-1973@postgrespro.ru", "phone": "+70719376071"}
0005433074441	CE4377	8489 134309	ELENA GERASIMOVA	{"email": "gerasimova_elena_111973@postgrespro.ru", "phone": "+70551841975"}
0005433074442	CE4377	7910 625548	ELENA PAVLOVA	{"email": "epavlova.1981@postgrespro.ru", "phone": "+70675938840"}
0005433074443	E717AF	1426 402429	VALERIYA KUZNECOVA	{"email": "kuznecova.valeriya.051977@postgrespro.ru", "phone": "+70556704137"}
0005433074444	E717AF	2571 660669	LYUDMILA STEPANOVA	{"phone": "+70862227437"}
0005433074445	A4411C	3322 705261	ANATOLIY KISELEV	{"email": "anatoliy-kiselev_011979@postgrespro.ru", "phone": "+70746444052"}
0005433074446	A4411C	0967 271171	NINA KARPOVA	{"phone": "+70041340985"}
0005433074447	A4411C	1511 707120	NATALYA ANDREEVA	{"phone": "+70494778429"}
0005433074448	51D5CE	8492 351409	ALEKSANDR SOLOVEV	{"phone": "+70775936934"}
0005433074449	51D5CE	6403 308425	ALEKSEY SOROKIN	{"email": "sorokin.aleksey_02021969@postgrespro.ru", "phone": "+70217431162"}
0005433074450	51D5CE	2736 426501	ANDREY SOKOLOV	{"phone": "+70836041597"}
0005433074451	93B3FC	3958 087709	NIKOLAY FOMIN	{"phone": "+70341668292"}
0005433074452	9AF50E	1283 977081	VLADIMIR VOROBEV	{"phone": "+70166336102"}
0005433074453	6BE04B	2708 119797	ALSU ZAKHAROVA	{"email": "a.zakharova091976@postgrespro.ru", "phone": "+70663103111"}
0005433074454	EA4E5B	5249 539753	LYUDMILA SMIRNOVA	{"email": "smirnovalyudmila.051973@postgrespro.ru", "phone": "+70304088344"}
0005433074455	53470E	0213 966996	VALENTIN MOROZOV	{"email": "morozov-v.1966@postgrespro.ru", "phone": "+70697757513"}
0005433074456	4B8110	8253 864241	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov-28081989@postgrespro.ru", "phone": "+70294228635"}
0005433074457	4B8110	8486 239359	BORIS PETROV	{"email": "petrov_boris121968@postgrespro.ru", "phone": "+70341218260"}
0005433074458	4B8110	8424 776573	SERGEY ANTONOV	{"phone": "+70951258746"}
0005433074459	0CA723	7891 428302	KRISTINA SOKOLOVA	{"email": "sokolova.k04031979@postgrespro.ru", "phone": "+70865282643"}
0005433074460	353477	7061 265947	MIKHAIL FOMIN	{"phone": "+70604067839"}
0005433074461	62376F	2637 756128	TATYANA IVANOVA	{"email": "t.ivanova_1972@postgrespro.ru", "phone": "+70353921616"}
0005433074462	62376F	6526 744344	MIKHAIL VASILEV	{"phone": "+70822676544"}
0005433074463	62376F	8277 737705	LYUDMILA ALEKSEEVA	{"phone": "+70376690222"}
0005433074464	096AF2	4647 619803	INNA ZAKHAROVA	{"email": "inna_zakharova15021988@postgrespro.ru", "phone": "+70569527870"}
0005433074465	8F13B1	2434 876690	NADEZHDA PETROVA	{"phone": "+70742737128"}
0005433074466	3F9FA8	0799 152675	IRINA IVANOVA	{"email": "ivanova-irina.101972@postgrespro.ru", "phone": "+70125032130"}
0005433074467	3F9FA8	3831 401229	LEONID GRIGOREV	{"phone": "+70388715933"}
0005433074468	E7766C	2698 884876	EVGENIY MARTYNOV	{"phone": "+70393793618"}
0005433074469	FD20BC	6588 206920	ALENA ZHUKOVA	{"email": "a.zhukova11081979@postgrespro.ru", "phone": "+70876940991"}
0005433074470	FD20BC	9806 799227	RUSLAN BELOV	{"phone": "+70776942375"}
0005433074471	FF8624	6640 146931	IVAN ILIN	{"email": "ivan_ilin1974@postgrespro.ru", "phone": "+70989853061"}
0005433074472	E65DC4	7258 220324	OLESYA KUZNECOVA	{"email": "kuznecova-o-25051989@postgrespro.ru", "phone": "+70525683741"}
0005433074473	C582AD	5146 445382	LIDIYA ZAYCEVA	{"email": "lidiya_zayceva_29091969@postgrespro.ru", "phone": "+70424534647"}
0005433074474	3FE53F	8747 731563	TATYANA MATVEEVA	{"phone": "+70005121461"}
0005433074475	DF5E5D	7716 614898	MARINA PAVLOVA	{"phone": "+70336628358"}
0005433074476	E43CAA	1579 680033	OLGA DAVYDOVA	{"phone": "+70719745240"}
0005433074477	E43CAA	7505 602074	TATYANA SOLOVEVA	{"phone": "+70729715249"}
0005433074478	E58B8F	0214 582264	EVGENIY KAZAKOV	{"email": "evgeniykazakov.101971@postgrespro.ru", "phone": "+70818662711"}
0005433074479	91C106	0810 433278	ANTON ZAKHAROV	{"phone": "+70010699783"}
0005433074480	16FDAC	7885 670181	ALBINA ANDREEVA	{"phone": "+70715529804"}
0005433074481	16FDAC	5994 811837	NADEZHDA BOGDANOVA	{"email": "nadezhda_bogdanova.051973@postgrespro.ru", "phone": "+70009499037"}
0005433074482	A507A1	9420 600178	NIKITA GRIGOREV	{"email": "nikita_grigorev.17021981@postgrespro.ru", "phone": "+70049652457"}
0005433074483	BA02FC	9697 964746	OKSANA GRISHINA	{"phone": "+70008370757"}
0005433074484	BA02FC	4960 797059	ELIZAVETA ISAEVA	{"email": "e-isaeva.121967@postgrespro.ru", "phone": "+70812167190"}
0005433074485	79DCDF	5311 816406	REGINA KONOVALOVA	{"email": "rkonovalova1964@postgrespro.ru", "phone": "+70751085667"}
0005433074486	79DCDF	6165 641744	ALEKSANDR DMITRIEV	{"phone": "+70147502665"}
0005433074487	538D14	3212 962542	ANASTASIYA NIKIFOROVA	{"email": "nikiforova_anastasiya.04031977@postgrespro.ru", "phone": "+70835585960"}
0005433074488	02CE03	8005 026269	OKSANA CHERNOVA	{"email": "chernovaoksana.07081965@postgrespro.ru", "phone": "+70150041373"}
0005433074489	02CE03	4223 429328	ANTONINA FILIPPOVA	{"phone": "+70835436325"}
0005433074490	5FF2D4	4238 959591	IRINA MARTYNOVA	{"email": "irinamartynova-1963@postgrespro.ru", "phone": "+70380390523"}
0005433074491	88F3D8	9033 902972	NIKITA GUSEV	{"email": "gusev.n-1980@postgrespro.ru", "phone": "+70623864622"}
0005433074492	B7111B	6434 911460	OLGA SOKOLOVA	{"phone": "+70482439900"}
0005433074493	C298FD	7493 701484	RUSTAM MOROZOV	{"phone": "+70924421528"}
0005433074494	16A54E	9689 793235	ELENA ZHURAVLEVA	{"email": "elena-zhuravleva19031971@postgrespro.ru", "phone": "+70642952802"}
0005433074496	AC961E	9033 878568	IVAN KONOVALOV	{"email": "konovalovi.26101977@postgrespro.ru", "phone": "+70586484145"}
0005433074497	7122CA	7105 925368	DANIIL AFANASEV	{"email": "d-afanasev.011976@postgrespro.ru", "phone": "+70839342207"}
0005433074498	58AA43	7470 672410	ALEKSEY MOISEEV	{"email": "moiseev-aleksey.121967@postgrespro.ru", "phone": "+70713107302"}
0005433074499	BAAFD7	7323 049890	SERGEY MIKHAYLOV	{"email": "s-mikhaylov22021974@postgrespro.ru", "phone": "+70218769948"}
0005433074500	9430D2	4910 346780	EVGENIYA KUZMINA	{"email": "kuzminae.101967@postgrespro.ru", "phone": "+70295321837"}
0005433074501	A7215E	7915 109631	NIKOLAY NIKOLAEV	{"email": "nnikolaev01051963@postgrespro.ru", "phone": "+70533912024"}
0005433074502	B209F0	7051 463507	MARIYA KOROLEVA	{"email": "m-koroleva1979@postgrespro.ru", "phone": "+70650704146"}
0005433074503	B209F0	8173 701016	EKATERINA BORISOVA	{"phone": "+70522841759"}
0005433074504	255D3F	8469 252207	VLADIMIR ABRAMOV	{"email": "abramovv_01121971@postgrespro.ru", "phone": "+70898592749"}
0005433074505	B0B6E9	3145 004232	OLGA NAUMOVA	{"email": "olga_naumova_1976@postgrespro.ru", "phone": "+70866109909"}
0005433074506	615B6F	2015 757713	ELENA KUZNECOVA	{"email": "kuznecova-elena-111974@postgrespro.ru", "phone": "+70247517439"}
0005433074507	366C3B	4108 941420	ANASTASIYA TIKHONOVA	{"phone": "+70837340907"}
0005433074508	62DDC5	7163 560546	ARTEM PAVLOV	{"email": "pavlovartem-091978@postgrespro.ru", "phone": "+70616322388"}
0005433074509	62DDC5	4634 012703	VALENTINA LOGINOVA	{"email": "loginova-v.14071975@postgrespro.ru", "phone": "+70609624912"}
0005433074510	1FE08E	4259 068063	DMITRIY EGOROV	{"email": "d_egorov-041978@postgrespro.ru", "phone": "+70352379030"}
0005433074511	BC3E58	0107 951268	LYUDMILA YUDINA	{"phone": "+70481554019"}
0005433074512	E6602D	6527 497549	EVGENIY RODIONOV	{"email": "erodionov-021961@postgrespro.ru", "phone": "+70956237237"}
0005433074514	23B2C1	1585 793248	EKATERINA KOMAROVA	{"email": "e.komarova_021976@postgrespro.ru", "phone": "+70203047108"}
0005433074515	41962F	4115 468302	ANTONINA ZHURAVLEVA	{"phone": "+70015066968"}
0005433074516	E5ABDB	2243 594320	ALEKSANDR ISAEV	{"phone": "+70564513280"}
0005433074517	E5ABDB	5681 587933	VALENTIN BORISOV	{"email": "borisov_valentin.051970@postgrespro.ru", "phone": "+70335884378"}
0005433074518	E5ABDB	0753 929445	ANASTASIYA ZOTOVA	{"phone": "+70760834409"}
0005433074519	D27BB3	7805 623667	NINA VOROBEVA	{"email": "vorobeva_nina_011980@postgrespro.ru", "phone": "+70037213320"}
0005433074520	D049C1	6663 105488	TAMARA BELYAEVA	{"email": "tbelyaeva-04101976@postgrespro.ru", "phone": "+70933237661"}
0005433074521	D049C1	5682 120693	ALEKSEY VASILEV	{"phone": "+70347252774"}
0005433074522	93C86B	4892 100522	NATALYA SIDOROVA	{"phone": "+70865507930"}
0005433074523	40C91F	0121 683970	DARYA LUKYANOVA	{"phone": "+70870221216"}
0005433074524	40C91F	5521 661127	VALENTINA EGOROVA	{"phone": "+70091031747"}
0005433074525	B5FB8C	4224 826276	GENNADIY MAKAROV	{"phone": "+70330772770"}
0005433074526	228FD9	6795 370391	ANASTASIYA SERGEEVA	{"phone": "+70352779731"}
0005433074527	228FD9	0472 477189	NATALYA KUZNECOVA	{"phone": "+70928892628"}
0005433074528	228FD9	6691 902343	DANIL MIKHAYLOV	{"phone": "+70473872260"}
0005433074529	B45F1F	8324 959234	MATVEY NOVIKOV	{"email": "novikov-m08111975@postgrespro.ru", "phone": "+70274205000"}
0005433074530	1FB406	6730 353869	TATYANA ORLOVA	{"email": "orlova_t29091965@postgrespro.ru", "phone": "+70742343786"}
0005433074531	4DE712	2636 275771	VIKTOR VASILEV	{"phone": "+70447871450"}
0005433074532	140F37	9057 074977	ANDREY KUZNECOV	{"email": "andrey.kuznecov_03111971@postgrespro.ru", "phone": "+70787570902"}
0005433074533	140F37	4894 570966	IVAN IVANOV	{"email": "ivanovivan01011978@postgrespro.ru", "phone": "+70723152144"}
0005433074534	1AFF60	6704 957095	VLADIMIR KUZNECOV	{"email": "v.kuznecov-031964@postgrespro.ru", "phone": "+70109040792"}
0005433074535	A865D5	7636 181855	ELENA POPOVA	{"phone": "+70141732710"}
0005433074536	A865D5	2010 913735	LYUDMILA KOROLEVA	{"phone": "+70314265708"}
0005433074537	0993D1	6188 848818	NATALYA IVANOVA	{"phone": "+70424772926"}
0005433074538	0993D1	3261 158389	DIANA TIMOFEEVA	{"email": "d-timofeeva.11121954@postgrespro.ru", "phone": "+70392293943"}
0005433074539	18F73A	2413 091259	DENIS GRIGOREV	{"email": "grigorev-d021968@postgrespro.ru", "phone": "+70993755791"}
0005433074540	18F73A	8353 098605	GENNADIY NIKITIN	{"email": "nikitin_g011977@postgrespro.ru", "phone": "+70776147399"}
0005433074541	6D0256	6230 399950	VLADIMIR GAVRILOV	{"email": "vladimir-gavrilov_091974@postgrespro.ru", "phone": "+70157668419"}
0005433074542	6D0256	0284 409654	MAKSIM ANTONOV	{"email": "maksim_antonov-21091967@postgrespro.ru", "phone": "+70571283440"}
0005433074543	6D0256	8868 466244	ANATOLIY BONDARENKO	{"phone": "+70845565166"}
0005433074544	934466	2098 305451	FARID VASILEV	{"phone": "+70899815088"}
0005433074545	AB1D20	5213 222202	ANDREY VLASOV	{"email": "vlasova.041977@postgrespro.ru", "phone": "+70624129988"}
0005433074546	5D972E	3723 594625	ANATOLIY KAZAKOV	{"email": "kazakov.a_1972@postgrespro.ru", "phone": "+70740843164"}
0005433074547	E0888C	7190 999959	VLADIMIR SOKOLOV	{"phone": "+70122722062"}
0005433074548	E0888C	9007 635568	RAISA POTAPOVA	{"phone": "+70013257521"}
0005433074549	7BB278	7753 053902	DMITRIY IVANOV	{"email": "ivanov_dmitriy_071976@postgrespro.ru", "phone": "+70779862352"}
0005433074550	D4F3ED	7222 134074	SERGEY ZAYCEV	{"email": "zaycev_s1969@postgrespro.ru", "phone": "+70029703563"}
0005433074551	81AAE4	6588 051929	ELENA MOROZOVA	{"email": "morozova.elena19111975@postgrespro.ru", "phone": "+70388092653"}
0005433074553	5E0391	1047 273455	MIKHAIL SAVELEV	{"email": "mikhailsavelev.081971@postgrespro.ru", "phone": "+70537746012"}
0005433074554	EE3A4C	7603 770217	EVGENIY ZAKHAROV	{"phone": "+70816184438"}
0005433074555	1C89BD	4417 858011	ALEKSANDR POPOV	{"phone": "+70081856501"}
0005433074556	64BC3B	9056 041389	IRINA KARPOVA	{"phone": "+70698643433"}
0005433074557	5FC63C	3745 723062	MARIYA SMIRNOVA	{"phone": "+70964140123"}
0005433074558	EED677	6328 877485	VLADIMIR NAZAROV	{"email": "nazarov.vladimir28031973@postgrespro.ru", "phone": "+70438434605"}
0005433074559	87C56C	0870 353673	OLGA VASILEVA	{"phone": "+70215980710"}
0005433074560	626889	4924 320250	GENNADIY SOLOVEV	{"email": "gennadiy-solovev_091978@postgrespro.ru", "phone": "+70793402637"}
0005433074561	626889	7874 747796	NINA CHERNOVA	{"email": "nina_chernova-1969@postgrespro.ru", "phone": "+70143178088"}
0005433074562	5B86CC	9289 422667	NATALYA IVANOVA	{"phone": "+70669063588"}
0005433074563	B83939	7486 160351	TATYANA MEDVEDEVA	{"phone": "+70856204300"}
0005433074564	DB31E7	0011 041057	MARGARITA MASLOVA	{"email": "maslova-m.1983@postgrespro.ru", "phone": "+70792479785"}
0005433074565	EB3173	0457 564755	LILIYA IVANOVA	{"email": "liliya_ivanova-1978@postgrespro.ru", "phone": "+70066220062"}
0005433074566	EB3173	7510 951503	ALEKSEY SOROKIN	{"email": "sorokin-a-1983@postgrespro.ru", "phone": "+70954909664"}
0005433074567	3EB847	5932 007700	ANDREY IVANOV	{"phone": "+70966403649"}
0005433074568	B8B9AC	8086 102150	MIKHAIL ANTONOV	{"phone": "+70207615850"}
0005433074569	D0C034	5093 521392	MATVEY KUDRYASHOV	{"email": "matvey_kudryashov23041978@postgrespro.ru", "phone": "+70485192486"}
0005433074570	D0C034	1264 018866	ILYA POPOV	{"phone": "+70256052512"}
0005433074571	FF3268	9114 307577	PAVEL YAKOVLEV	{"email": "yakovlev_pavel_01011981@postgrespro.ru", "phone": "+70782851812"}
0005433074572	9A0BEC	1242 913114	MIKHAIL ZAKHAROV	{"phone": "+70103032456"}
0005433074573	9A0BEC	6676 240759	ZINAIDA MARTYNOVA	{"phone": "+70513960908"}
0005433074574	733D25	8223 466444	PLATON FILIPPOV	{"phone": "+70754408546"}
0005433074575	10B5E0	8127 455729	OLGA TARASOVA	{"email": "tarasova_olga.1976@postgrespro.ru", "phone": "+70339588015"}
0005433074576	4B863A	1950 699977	ELENA KOLESNIKOVA	{"phone": "+70739958196"}
0005433074577	4B863A	9866 688450	LYUBOV POPOVA	{"phone": "+70196909356"}
0005433074578	957112	9724 415159	VYACHESLAV CHERNOV	{"email": "v_chernov.13021970@postgrespro.ru", "phone": "+70376176705"}
0005433074579	40FB6D	5915 990328	IGOR VLASOV	{"phone": "+70548458658"}
0005433074580	40FB6D	8902 933999	VIKTOR MAKAROV	{"phone": "+70439977342"}
0005433074581	0E411D	3687 905036	OLEG VOLKOV	{"phone": "+70959751285"}
0005433074582	0E411D	1840 832807	NINA FOMINA	{"phone": "+70240021385"}
0005433074583	2DFBF4	6420 153634	GLEB MOROZOV	{"phone": "+70849348926"}
0005433074584	E91323	9350 286583	NIKOLAY TIMOFEEV	{"phone": "+70610396048"}
0005433074585	E91323	8652 815130	IVAN CHERNOV	{"email": "i_chernov_051973@postgrespro.ru", "phone": "+70464054282"}
0005433074586	5AEFCD	1099 772953	SERGEY DENISOV	{"phone": "+70744994285"}
0005433074587	DFE9D9	9276 445414	VLADIMIR SIDOROV	{"phone": "+70964283871"}
0005433074588	21DB0B	2989 886759	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov-14111970@postgrespro.ru", "phone": "+70375371475"}
0005433074589	A5D81F	5914 442718	LYUDMILA MIRONOVA	{"phone": "+70779702614"}
0005433074590	A5D81F	1629 799178	DINA PAVLOVA	{"phone": "+70083666962"}
0005433074591	1DE6B2	6130 869561	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov16111965@postgrespro.ru", "phone": "+70917018260"}
0005433074592	113F51	4867 453302	GALINA ILINA	{"phone": "+70608220392"}
0005433074593	5FA98E	8625 844547	ELENA KUZNECOVA	{"email": "elenakuznecova.28071974@postgrespro.ru", "phone": "+70149452652"}
0005433074594	AD3E86	4414 180531	MARIYA IVANOVA	{"phone": "+70270850894"}
0005433074595	AD3E86	6157 049535	SVETLANA MAKAROVA	{"phone": "+70272775787"}
0005433074596	AD3E86	0356 765963	GALINA MAKAROVA	{"email": "makarova.g-1977@postgrespro.ru", "phone": "+70374449545"}
0005433074597	1D3F3B	7500 971406	LARISA FROLOVA	{"phone": "+70540079075"}
0005433074598	1D3F3B	3880 934162	DARYA ORLOVA	{"phone": "+70749226552"}
0005433074599	1DEFDA	8330 050584	IGOR ALEKSANDROV	{"phone": "+70889480425"}
0005433074600	396BB2	7941 363544	TIMUR ZAKHAROV	{"phone": "+70638037678"}
0005433074601	0198BC	0509 158322	OLEG BONDARENKO	{"phone": "+70607245440"}
0005433074602	EE7FE0	3043 484576	ALEKSANDRA ISAEVA	{"phone": "+70099321973"}
0005433074603	1DDF79	1130 551768	ANASTASIYA SMIRNOVA	{"phone": "+70112029668"}
0005433074604	1DDF79	0060 307495	DMITRIY VASILEV	{"phone": "+70306489961"}
0005433074605	275A31	7723 078726	ALEKSEY GORBUNOV	{"phone": "+70820358502"}
0005433074606	9157AA	0555 477269	GALINA ANTONOVA	{"phone": "+70237480014"}
0005433074607	9157AA	6692 489240	KONSTANTIN MIRONOV	{"email": "konstantin_mironov111964@postgrespro.ru", "phone": "+70471477556"}
0005433074608	74D8CA	4733 365045	ANDREY BARANOV	{"phone": "+70334495101"}
0005433074609	74D8CA	4683 495083	SOFIYA AFANASEVA	{"phone": "+70138891286"}
0005433074610	7E93FC	6415 476078	ALEKSANDR BELOV	{"phone": "+70794260679"}
0005433074611	46BD4C	8876 315775	ALEKSEY ZAYCEV	{"phone": "+70232041098"}
0005433074612	F729D0	0991 008857	LYUDMILA MOISEEVA	{"email": "lyudmila_moiseeva081962@postgrespro.ru", "phone": "+70546958718"}
0005433074613	5467C0	7834 972745	MIKHAIL MIKHAYLOV	{"phone": "+70191017573"}
0005433074614	6228CB	6680 431755	RAISA YAKOVLEVA	{"email": "ryakovleva.18071969@postgrespro.ru", "phone": "+70216801332"}
0005433074615	6228CB	8802 126423	YURIY SEMENOV	{"phone": "+70152982097"}
0005433074616	79D286	4941 724091	DENIS GORBUNOV	{"email": "gorbunov_d-031976@postgrespro.ru", "phone": "+70685647652"}
0005433074617	768FD7	2340 740431	IGOR NIKOLAEV	{"email": "igor.nikolaev_1966@postgrespro.ru", "phone": "+70979332127"}
0005433074618	768FD7	5519 677871	OLGA EGOROVA	{"phone": "+70913145157"}
0005433074619	C6769A	4174 108119	OLGA SEMENOVA	{"phone": "+70572136149"}
0005433074620	EDE5E6	4484 773244	ANASTASIYA EGOROVA	{"phone": "+70569332133"}
0005433074621	EDE5E6	4383 738934	ELENA FILATOVA	{"phone": "+70188184537"}
0005433074622	073F17	3140 827966	VLADIMIR RODIONOV	{"email": "rodionov-vladimir-111970@postgrespro.ru", "phone": "+70413481748"}
0005433074623	D9F2FF	9658 906690	OLGA STEPANOVA	{"phone": "+70543642017"}
0005433074624	D9F2FF	0654 190774	ANNA EGOROVA	{"email": "a-egorova-121983@postgrespro.ru", "phone": "+70572948890"}
0005433074625	219A1C	6117 215222	SERGEY EGOROV	{"phone": "+70551485393"}
0005433074626	2C1A15	8988 093754	SVETLANA GAVRILOVA	{"phone": "+70795290783"}
0005433074627	2C1A15	4633 575295	ALEKSEY MIKHAYLOV	{"phone": "+70241200379"}
0005433074628	CDD7D8	0069 208330	IRINA KOZLOVA	{"email": "irina_kozlova101967@postgrespro.ru", "phone": "+70512873661"}
0005433074629	284A8F	5175 391673	SVETLANA KOROLEVA	{"email": "s.koroleva.101971@postgrespro.ru", "phone": "+70638116108"}
0005433074630	284A8F	4143 245019	ANNA KOVALEVA	{"phone": "+70230423719"}
0005433074631	284A8F	1497 606163	KSENIYA MAKAROVA	{"phone": "+70560032430"}
0005433074632	6FB36A	2611 661796	ROBERT FROLOV	{"email": "r-frolov-1984@postgrespro.ru", "phone": "+70031229678"}
0005433074633	ABFE9C	8311 713373	SVETLANA KULIKOVA	{"phone": "+70653607909"}
0005433074634	A61DE7	1263 806210	SERGEY PETROV	{"email": "sergey_petrov.101967@postgrespro.ru", "phone": "+70263740520"}
0005433074635	18189D	5532 094896	LYUBOV KULIKOVA	{"email": "kulikova-l.031971@postgrespro.ru", "phone": "+70696169508"}
0005433074636	18189D	7524 758028	VLADIMIR DAVYDOV	{"email": "davydov_v.27081973@postgrespro.ru", "phone": "+70630151242"}
0005433074637	3F515C	8325 968890	ANNA LEBEDEVA	{"email": "lebedeva_a_1969@postgrespro.ru", "phone": "+70412038728"}
0005433074638	3F515C	7562 339104	DARYA MOROZOVA	{"email": "darya.morozova_1984@postgrespro.ru", "phone": "+70588792669"}
0005433074639	F12409	1322 061185	SVETLANA POPOVA	{"phone": "+70221119181"}
0005433074640	8A18D6	9827 911960	NINA IVANOVA	{"phone": "+70709812372"}
0005433074641	D3355E	3221 896205	EKATERINA ZAKHAROVA	{"phone": "+70740576066"}
0005433074642	D3355E	3853 781316	YURIY GUSEV	{"phone": "+70647093427"}
0005433074643	9F7E10	6698 934554	YURIY KUZMIN	{"phone": "+70951708635"}
0005433074644	258B58	6484 498069	ANASTASIYA SMIRNOVA	{"phone": "+70197412903"}
0005433074645	05E725	6490 169567	VIKTOR MAKAROV	{"phone": "+70398843222"}
0005433074646	E8E611	0203 071299	EVGENIY BARANOV	{"email": "e.baranov1966@postgrespro.ru", "phone": "+70982198746"}
0005433074647	E8E611	7299 711864	EVGENIY SIDOROV	{"phone": "+70027517858"}
0005433074648	E8E611	4144 303173	OKSANA MEDVEDEVA	{"phone": "+70481081610"}
0005433074649	F6D5F7	0156 122087	VIKTOR MIRONOV	{"email": "mironov-viktor_03011978@postgrespro.ru", "phone": "+70991992286"}
0005433074650	86282F	1492 223394	VLADIMIR BORISOV	{"email": "vborisov-08071957@postgrespro.ru", "phone": "+70110261741"}
0005433074651	2E717D	2102 878184	NIKOLAY ZHURAVLEV	{"phone": "+70876769181"}
0005433074652	2E717D	2105 386606	DINA NIKITINA	{"email": "dina_nikitina041970@postgrespro.ru", "phone": "+70516687650"}
0005433074653	098E02	3268 122757	SERGEY AFANASEV	{"phone": "+70362833459"}
0005433074654	149566	2835 574617	NIKOLAY PETROV	{"phone": "+70327708789"}
0005433074655	4C3B62	0736 706415	ELENA YUDINA	{"phone": "+70983287193"}
0005433074656	504471	8024 259225	NATALYA NIKITINA	{"email": "nikitina.n1973@postgrespro.ru", "phone": "+70310962012"}
0005433074657	4CC126	1078 354018	VLADIMIR KUZNECOV	{"phone": "+70872549560"}
0005433074658	84A8DF	3548 713706	LARISA LOGINOVA	{"phone": "+70687810962"}
0005433074659	5833D6	1683 398007	SERGEY GORBUNOV	{"phone": "+70196405875"}
0005433074660	FE5219	4108 329696	NATALIYA TIMOFEEVA	{"phone": "+70220322463"}
0005433074661	28C00F	5005 117928	ILYAS VOLKOV	{"phone": "+70767073068"}
0005433074662	A25B14	6300 906630	SVETLANA IVANOVA	{"phone": "+70738899274"}
0005433074663	A25B14	7950 858337	NATALYA DMITRIEVA	{"email": "dmitrieva-natalya_03121977@postgrespro.ru", "phone": "+70472290924"}
0005433074664	73AA98	2511 602747	TATYANA SIDOROVA	{"phone": "+70613869035"}
0005433074665	1212A5	2260 138832	NADEZHDA SMIRNOVA	{"email": "n_smirnova11061973@postgrespro.ru", "phone": "+70908951619"}
0005433074666	FD154D	0811 569870	EKATERINA DMITRIEVA	{"email": "e_dmitrieva021964@postgrespro.ru", "phone": "+70180314101"}
0005433074667	B7590F	4280 021046	TATYANA BELOVA	{"email": "tbelova_1970@postgrespro.ru", "phone": "+70798538441"}
0005433074668	06D9B2	0094 338793	MARIYA AFANASEVA	{"phone": "+70648580329"}
0005433074669	F56E3C	9018 932272	KIRA ZOTOVA	{"phone": "+70075620752"}
0005433074670	F56E3C	4487 385299	MARIYA KONOVALOVA	{"phone": "+70808189280"}
0005433074671	F064BD	6038 737757	GRIGORIY SOKOLOV	{"email": "grigoriy_sokolov071985@postgrespro.ru", "phone": "+70651093128"}
0005433074672	7BEDDC	8293 293463	TATYANA SCHERBAKOVA	{"email": "scherbakovat_021969@postgrespro.ru", "phone": "+70912351299"}
0005433074673	B45FFD	1362 366936	RAISA ERMAKOVA	{"email": "raisa-ermakova1974@postgrespro.ru", "phone": "+70768579248"}
0005433074674	8465A4	4434 842613	VYACHESLAV KISELEV	{"email": "kiselev-v.1984@postgrespro.ru", "phone": "+70012135542"}
0005433074675	8465A4	6488 393604	LYUBOV KOZLOVA	{"phone": "+70251130869"}
0005433074676	F6E454	9093 412462	ANNA STEPANOVA	{"phone": "+70653708929"}
0005433074677	5CAD3E	7592 635803	ANDREY ABRAMOV	{"phone": "+70380495730"}
0005433074678	5CAD3E	9244 662960	LYUBOV BELOVA	{"phone": "+70180002297"}
0005433074679	A1E270	0822 791764	VLADIMIR SMIRNOV	{"email": "smirnov.v-081980@postgrespro.ru", "phone": "+70127052613"}
0005433074680	A1E270	8518 483275	ANATOLIY ROMANOV	{"email": "anatoliy-romanov_1961@postgrespro.ru", "phone": "+70419624479"}
0005433074681	A1E270	9338 096848	LIDIYA KARPOVA	{"email": "karpova-lidiya15071966@postgrespro.ru", "phone": "+70014395434"}
0005433074682	04D754	9388 346864	NIKOLAY IVANOV	{"email": "n.ivanov_1973@postgrespro.ru", "phone": "+70490674207"}
0005433074683	967A47	8789 631714	ELENA MAKSIMOVA	{"phone": "+70699055495"}
0005433074684	2AD195	6271 080252	ALEKSANDR IVANOV	{"phone": "+70109048371"}
0005433074685	2AD195	8386 512791	ARTEM ABRAMOV	{"email": "abramovartem-1965@postgrespro.ru", "phone": "+70474622169"}
0005433074686	FD51DB	3333 307465	ANASTASIYA KARPOVA	{"email": "a_karpova111978@postgrespro.ru", "phone": "+70403787862"}
0005433074687	FA51DA	3156 910996	MIKHAIL ANTONOV	{"email": "mikhail-antonov021963@postgrespro.ru", "phone": "+70504250721"}
0005433074688	3A36A1	0929 759376	VALERIY SMIRNOV	{"phone": "+70053766864"}
0005433074689	1D2139	5867 847712	LARISA LUKYANOVA	{"phone": "+70437731737"}
0005433074690	7E2BC7	6498 553340	YULIYA BELOVA	{"email": "belovay.061963@postgrespro.ru", "phone": "+70219714142"}
0005433074691	2CDA41	2424 297074	LIDIYA NIKOLAEVA	{"phone": "+70524664447"}
0005433074692	BA6A79	7487 125633	ROMAN ALEKSEEV	{"phone": "+70157149170"}
0005433074693	84F389	1337 804131	MARIYA GORBUNOVA	{"email": "gorbunovam051966@postgrespro.ru", "phone": "+70039499745"}
0005433074694	84F389	1483 856507	EKATERINA IVANOVA	{"email": "ivanovaekaterina_031970@postgrespro.ru", "phone": "+70312656735"}
0005433074695	DC2BC5	4287 516562	RINAT FEDOROV	{"email": "rinat_fedorov31011965@postgrespro.ru", "phone": "+70451912532"}
0005433074696	DC2BC5	8296 764023	SERGEY SERGEEV	{"email": "s-sergeev-08041979@postgrespro.ru", "phone": "+70612061661"}
0005433074697	FD0565	0561 791361	ALEVTINA DENISOVA	{"email": "denisova-alevtina-101974@postgrespro.ru", "phone": "+70674973526"}
0005433074698	5783A5	8832 358071	EVGENIY FROLOV	{"phone": "+70736145051"}
0005433074699	00B6FE	7260 479549	VALENTIN BORISOV	{"email": "valentin-borisov_1966@postgrespro.ru", "phone": "+70935950846"}
0005433074700	26EAB9	4641 510513	NATALIYA SERGEEVA	{"email": "sergeeva_n021964@postgrespro.ru", "phone": "+70545064497"}
0005433074701	4FC0A4	2322 636013	YURIY NIKOLAEV	{"email": "yuriy-nikolaev.12111968@postgrespro.ru", "phone": "+70361962462"}
0005433074702	4FC0A4	5054 128441	VLADIMIR IVANOV	{"email": "vladimirivanov1966@postgrespro.ru", "phone": "+70072112783"}
0005433074703	4FC0A4	8253 554001	ALEKSEY FROLOV	{"phone": "+70320797893"}
0005433074704	01655A	0316 383255	ELENA ZAYCEVA	{"email": "zayceva-elena-051971@postgrespro.ru", "phone": "+70819991792"}
0005433074705	01655A	2239 412956	KONSTANTIN SOROKIN	{"phone": "+70787086217"}
0005433074706	A9F341	2556 394496	ELENA KRASNOVA	{"phone": "+70394868032"}
0005433074707	A9F341	3652 356081	STANISLAV RODIONOV	{"email": "stanislavrodionov021969@postgrespro.ru", "phone": "+70076741897"}
0005433074708	A9F341	2947 913368	ALEKSANDR POPOV	{"email": "popova-1979@postgrespro.ru", "phone": "+70424120849"}
0005433074709	DC1505	2159 391276	ARINA ORLOVA	{"phone": "+70411304641"}
0005433074710	DA8F06	7503 688628	VERA ABRAMOVA	{"phone": "+70162540859"}
0005433074711	66D562	4603 616553	ALEKSANDR FEDOTOV	{"phone": "+70306338431"}
0005433074712	66D562	2192 902339	EKATERINA BELYAEVA	{"phone": "+70689016091"}
0005433074713	421064	0988 533651	NATALYA ZAKHAROVA	{"phone": "+70789474672"}
0005433074714	FE90ED	7618 240239	ALEKSANDR ZHURAVLEV	{"email": "a.zhuravlev.30101973@postgrespro.ru", "phone": "+70772809673"}
0005433074715	958A98	7542 812577	ANTONINA MOISEEVA	{"email": "a.moiseeva.101978@postgrespro.ru", "phone": "+70367674669"}
0005433074716	958A98	2789 202905	ELENA IVANOVA	{"phone": "+70446612225"}
0005433074717	7B3C23	3124 558971	VALENTINA BELYAEVA	{"email": "belyaeva_v-1973@postgrespro.ru", "phone": "+70358185202"}
0005433074718	F68882	9141 676840	ALINA FEDOROVA	{"phone": "+70477930600"}
0005433074719	FCDE22	5046 840000	KSENIYA TIMOFEEVA	{"phone": "+70022716005"}
0005433074720	FCDE22	6069 410664	VALERIY MARTYNOV	{"email": "martynovvaleriy.051976@postgrespro.ru", "phone": "+70292891508"}
0005433074721	EB2D19	6161 554073	DANILA SIDOROV	{"email": "danila-sidorov.051967@postgrespro.ru", "phone": "+70281767081"}
0005433074722	982BC3	0030 060974	ELENA KUZMINA	{"phone": "+70451667065"}
0005433074723	25E516	5813 617498	NADEZHDA SMIRNOVA	{"email": "n-smirnova.07081973@postgrespro.ru", "phone": "+70036110092"}
0005433074724	25E516	0874 880750	OLGA SMIRNOVA	{"email": "smirnova_o071969@postgrespro.ru", "phone": "+70440717616"}
0005433074725	D702C6	5797 453991	ANNA KUZNECOVA	{"phone": "+70751125552"}
0005433074726	D702C6	4176 139717	ALEKSANDR NOVIKOV	{"phone": "+70389575778"}
0005433074727	439957	8327 012112	NADEZHDA ERMAKOVA	{"email": "n-ermakova.1961@postgrespro.ru", "phone": "+70615525138"}
0005433074728	439957	2241 556404	SVETLANA PETROVA	{"email": "petrova.svetlana-1969@postgrespro.ru", "phone": "+70641952985"}
0005433074729	47BBCE	6798 173753	VALENTINA KOVALEVA	{"email": "valentina-kovaleva_1970@postgrespro.ru", "phone": "+70343814873"}
0005433074730	91853A	1507 961590	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1966@postgrespro.ru", "phone": "+70735996952"}
0005433074731	3B7E41	9889 441221	VIKTOR NIKITIN	{"phone": "+70768409669"}
0005433074732	3B7E41	7038 967803	ANDREY MELNIKOV	{"email": "a_melnikov061969@postgrespro.ru", "phone": "+70120881106"}
0005433074733	0DD443	2870 989537	ELENA MAKSIMOVA	{"email": "e.maksimova-021973@postgrespro.ru", "phone": "+70350888589"}
0005433074734	0DD443	9258 727817	VLADISLAV VASILEV	{"email": "v-vasilev-1971@postgrespro.ru", "phone": "+70022991922"}
0005433074735	0DD443	3951 992163	VALENTINA TIKHONOVA	{"phone": "+70400149121"}
0005433074736	E9F00C	9201 338098	RINAT PETROV	{"email": "rinat_petrov-17111978@postgrespro.ru", "phone": "+70038964635"}
0005433074737	E9F00C	2433 672207	NATALYA YAKOVLEVA	{"phone": "+70261329000"}
0005433074738	E9F00C	5516 816779	ANTON KISELEV	{"email": "anton.kiselev_16051969@postgrespro.ru", "phone": "+70959604115"}
0005433074739	CF588E	2832 592714	EVGENIY MOISEEV	{"email": "evgeniy_moiseev-15011976@postgrespro.ru", "phone": "+70379354338"}
0005433074740	CF588E	4284 363873	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov051983@postgrespro.ru", "phone": "+70819017731"}
0005433074741	668A87	5664 529815	LYUDMILA FEDOROVA	{"phone": "+70249431352"}
0005433074742	668A87	6710 525605	VIKTORIYA KISELEVA	{"phone": "+70926300218"}
0005433074743	76DE04	5134 776002	LYUDMILA BORISOVA	{"email": "l.borisova.061965@postgrespro.ru", "phone": "+70200150476"}
0005433074744	1E8EA1	9935 985095	IRINA STEPANOVA	{"email": "irina-stepanova-08111963@postgrespro.ru", "phone": "+70589969590"}
0005433074745	E7F5F8	7568 990467	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a_061983@postgrespro.ru", "phone": "+70471004242"}
0005433074746	E7F5F8	1604 601972	YULIYA NESTEROVA	{"phone": "+70393657265"}
0005433074747	CDECDD	7500 681217	VIKTOR VASILEV	{"email": "v_vasilev-11091974@postgrespro.ru", "phone": "+70932850020"}
0005433074748	CDECDD	2642 312621	KAPITALINA NIKITINA	{"email": "nikitina-k.021966@postgrespro.ru", "phone": "+70917154310"}
0005433074749	66F9BF	4669 350083	ALEKSANDR FOMIN	{"phone": "+70598878161"}
0005433074750	66F9BF	0749 767398	TATYANA POPOVA	{"email": "tatyanapopova.1968@postgrespro.ru", "phone": "+70584175499"}
0005433074751	66F9BF	7296 763360	NIKOLAY SCHERBAKOV	{"phone": "+70018654441"}
0005433074752	E9EB10	5891 841578	VASILIY NIKITIN	{"email": "vasiliy_nikitin_18071976@postgrespro.ru", "phone": "+70912777945"}
0005433074753	E9EB10	0129 349930	KONSTANTIN IVANOV	{"phone": "+70482030108"}
0005433074754	656F3D	7671 413923	GENNADIY VASILEV	{"phone": "+70138305398"}
0005433074755	656F3D	2016 432207	ANNA PETROVA	{"phone": "+70851954880"}
0005433074756	656F3D	0689 164895	EKATERINA KUZMINA	{"phone": "+70235087537"}
0005433074757	01787E	0627 045135	YANA ZHURAVLEVA	{"email": "zhuravleva.y01051986@postgrespro.ru", "phone": "+70272342815"}
0005433074758	146892	4340 287447	INGA BARANOVA	{"phone": "+70255165056"}
0005433074759	146892	5529 925957	SERGEY BELOV	{"email": "sergey-belov.021972@postgrespro.ru", "phone": "+70692309400"}
0005433074760	146892	1917 346652	YULIYA BOGDANOVA	{"email": "bogdanova.y.06081978@postgrespro.ru", "phone": "+70147617426"}
0005433074761	34B26A	1313 787524	GALINA MOISEEVA	{"email": "moiseevag041961@postgrespro.ru", "phone": "+70271635861"}
0005433074762	CC64DC	8145 245303	SVETLANA ZOTOVA	{"phone": "+70467183176"}
0005433074763	FA2648	9457 569918	VLADIMIR FILIPPOV	{"phone": "+70368243467"}
0005433074764	4433A2	1879 383254	VITALIY NAZAROV	{"email": "vitaliynazarov.101973@postgrespro.ru", "phone": "+70417815346"}
0005433074765	4433A2	3350 725233	NATALIYA MELNIKOVA	{"email": "nataliyamelnikova_23031969@postgrespro.ru", "phone": "+70390133732"}
0005433074766	C08864	1665 474627	YURIY TARASOV	{"email": "yuriytarasov_16071969@postgrespro.ru", "phone": "+70288828569"}
0005433074767	620C41	6096 702773	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov-1976@postgrespro.ru", "phone": "+70363341887"}
0005433074768	620C41	1122 203784	IRINA FEDOROVA	{"email": "irina_fedorova-1979@postgrespro.ru", "phone": "+70938290226"}
0005433074769	5E1631	3550 041668	TIMOFEY STEPANOV	{"email": "stepanov-timofey.111975@postgrespro.ru", "phone": "+70986563068"}
0005433074770	7C34D0	1109 383629	GENNADIY GUSEV	{"phone": "+70271560101"}
0005433074771	7C34D0	8328 682956	OLGA DENISOVA	{"email": "o_denisova_14101957@postgrespro.ru", "phone": "+70032896341"}
0005433074772	D7781E	0186 395302	ANTONINA KULIKOVA	{"email": "antonina.kulikova.19011977@postgrespro.ru", "phone": "+70763790805"}
0005433074773	D7781E	3648 504556	NADEZHDA OVCHINNIKOVA	{"email": "novchinnikova_05031966@postgrespro.ru", "phone": "+70674789732"}
0005433074774	729BF2	9248 305008	ARSEN ALEKSEEV	{"email": "arsen.alekseev30031963@postgrespro.ru", "phone": "+70287745335"}
0005433074775	CD9668	3119 693090	RUZALIYA EGOROVA	{"phone": "+70326817368"}
0005433074776	AF69CE	4182 893006	VERA BELYAEVA	{"email": "belyaeva-v.021964@postgrespro.ru", "phone": "+70008350495"}
0005433074777	7E78E6	5256 908859	DANIIL SIDOROV	{"phone": "+70073599021"}
0005433074778	FC0D22	9957 863539	YULIYA ROMANOVA	{"phone": "+70775696887"}
0005433074779	A615DC	1348 132339	IRINA RODIONOVA	{"phone": "+70643013245"}
0005433074780	A615DC	6891 763770	VITALIY ILIN	{"email": "ilin-v.041963@postgrespro.ru", "phone": "+70233088010"}
0005433074781	A615DC	6792 978590	VADIM DMITRIEV	{"email": "dmitrievvadim.28021973@postgrespro.ru", "phone": "+70519598829"}
0005433074782	09D414	1477 999435	VLADIMIR VASILEV	{"email": "vasilev.v.22061980@postgrespro.ru", "phone": "+70319942862"}
0005433074783	15F7D6	0260 745763	ZAKHAR SCHERBAKOV	{"email": "scherbakov_z1973@postgrespro.ru", "phone": "+70065387856"}
0005433074784	15F7D6	3889 323662	ELENA GUSEVA	{"email": "elenaguseva-071969@postgrespro.ru", "phone": "+70171942058"}
0005433074785	28A104	8575 199167	VIKTOR FOMIN	{"phone": "+70051872875"}
0005433074786	28A104	1799 214311	ELENA IVANOVA	{"phone": "+70821013496"}
0005433074787	B698DD	2080 037294	TATYANA SOLOVEVA	{"email": "solovevat.1985@postgrespro.ru", "phone": "+70606493255"}
0005433074788	ADF048	0228 087214	BOGDAN ORLOV	{"phone": "+70104661967"}
0005433074789	ADF048	5847 104831	EVGENIY STEPANOV	{"phone": "+70866633362"}
0005433074790	DA2F78	2651 897617	DARYA YAKOVLEVA	{"phone": "+70847224651"}
0005433074791	DA2F78	6428 002977	MARAT MATVEEV	{"phone": "+70981664744"}
0005433074792	B39442	3397 746458	MIKHAIL SMIRNOV	{"email": "smirnov.m.10061962@postgrespro.ru", "phone": "+70163073992"}
0005433074793	8A66DF	7981 217272	VIKTOR BORISOV	{"phone": "+70335758376"}
0005433074794	8A66DF	3275 581925	DMITRIY GERASIMOV	{"phone": "+70065520128"}
0005433074795	172D2A	8719 708977	SVETLANA KUZNECOVA	{"email": "svetlana.kuznecova1981@postgrespro.ru", "phone": "+70474369724"}
0005433074796	F42256	6788 619386	ANASTASIYA ARKHIPOVA	{"email": "arkhipovaanastasiya_11091966@postgrespro.ru", "phone": "+70412165493"}
0005433074797	F42256	6715 120638	ALLA ZHURAVLEVA	{"email": "a.zhuravleva29121962@postgrespro.ru", "phone": "+70245638686"}
0005433074798	F42256	9402 866929	ELIZAVETA FROLOVA	{"phone": "+70185877156"}
0005433074799	7A8791	8436 399675	VERONIKA AFANASEVA	{"email": "afanaseva.v_05121979@postgrespro.ru", "phone": "+70106805205"}
0005433074800	7A8791	6688 687937	ANDREY SOROKIN	{"email": "sorokinandrey26061975@postgrespro.ru", "phone": "+70966881651"}
0005433074801	9AFC34	1223 377717	ANTON VOLKOV	{"email": "a-volkov06111970@postgrespro.ru", "phone": "+70600055327"}
0005433074802	89386B	3101 047916	ANDREY FEDOROV	{"phone": "+70375509727"}
0005433074803	89386B	3857 636611	ALEKSANDR SEMENOV	{"phone": "+70717705430"}
0005433074804	757F9A	7923 601877	MARINA PAVLOVA	{"phone": "+70546594614"}
0005433074805	B85EC4	7205 269871	ALEKSANDR ALEKSEEV	{"phone": "+70961689721"}
0005433074806	64F8D7	5322 626443	IVAN YAKOVLEV	{"phone": "+70383530750"}
0005433074807	85C5DD	2378 960375	VALENTINA ZAYCEVA	{"phone": "+70163056801"}
0005433074808	E87465	4384 386100	SVETLANA ZHUKOVA	{"phone": "+70666591413"}
0005433074809	023949	8099 922962	VITALIY BELOV	{"email": "belov-vitaliy.031970@postgrespro.ru", "phone": "+70396097314"}
0005433074810	023949	8816 795161	VYACHESLAV ALEKSEEV	{"email": "valekseev-091974@postgrespro.ru", "phone": "+70660733137"}
0005433074811	4D4270	8978 149821	IGOR GORBUNOV	{"phone": "+70337129310"}
0005433074812	4D4270	2462 528450	GALINA STEPANOVA	{"email": "galina-stepanova_1974@postgrespro.ru", "phone": "+70776741412"}
0005433074813	35F837	6608 667628	ELENA ANDREEVA	{"email": "elena_andreeva-051967@postgrespro.ru", "phone": "+70516280713"}
0005433074814	23CA61	0996 287626	SERGEY SCHERBAKOV	{"phone": "+70610787316"}
0005433074815	B16C5F	6570 757612	SERGEY NIKOLAEV	{"phone": "+70999868653"}
0005433074816	486552	6230 673635	LYUDMILA LEBEDEVA	{"email": "lebedeva.l-051971@postgrespro.ru", "phone": "+70091349263"}
0005433074817	1AA197	9217 036392	ANNA VOLKOVA	{"phone": "+70510384956"}
0005433074818	1AA197	2070 511285	IGOR EGOROV	{"email": "egorov-igor1964@postgrespro.ru", "phone": "+70336059279"}
0005433074819	5DF3F1	3739 306968	ANTON SIDOROV	{"phone": "+70896210527"}
0005433074820	8B26DD	0530 679696	RAFAEL ANDREEV	{"email": "r-andreev-14051964@postgrespro.ru", "phone": "+70898657257"}
0005433074821	FABB8B	0496 613063	MARIYA MAKAROVA	{"email": "m.makarova-101963@postgrespro.ru", "phone": "+70103720967"}
0005433074822	6D8641	8972 987505	ALEKSANDRA KALININA	{"email": "aleksandra.kalinina_091977@postgrespro.ru", "phone": "+70931531216"}
0005433074823	6D8641	0909 372706	MIKHAIL CHERNOV	{"email": "chernov.m-121963@postgrespro.ru", "phone": "+70105010295"}
0005433074824	9F9481	3199 836822	OLEG NIKITIN	{"email": "o_nikitin-1966@postgrespro.ru", "phone": "+70019822815"}
0005433074825	717800	3703 127496	ALEKSANDR MAKSIMOV	{"phone": "+70171312972"}
0005433074826	6C36EF	8619 043656	TATYANA AKIMOVA	{"phone": "+70123441425"}
0005433074827	836F96	8721 112136	VLADIMIR POPOV	{"email": "popov_vladimir-1979@postgrespro.ru", "phone": "+70101287828"}
0005433074828	836F96	1629 887960	ALEKSEY KUZMIN	{"phone": "+70782988132"}
0005433074829	2F08DF	1209 980984	EGOR SCHERBAKOV	{"phone": "+70315815548"}
0005433074830	3B9CE0	7687 398971	ELENA LAZAREVA	{"email": "lazareva-e.031977@postgrespro.ru", "phone": "+70344668858"}
0005433074831	F32F3A	6440 694473	ARTEM FROLOV	{"phone": "+70055041613"}
0005433074832	7BE0E2	0801 061318	OLGA IVANOVA	{"email": "olgaivanova.1978@postgrespro.ru", "phone": "+70568436065"}
0005433074833	7BE0E2	0479 773964	MIKHAIL KRASNOV	{"email": "mikhail_krasnov1978@postgrespro.ru", "phone": "+70015333223"}
0005433074834	C877A7	6907 611714	RUSLAN VASILEV	{"email": "vasilevr1982@postgrespro.ru", "phone": "+70536814495"}
0005433074835	C877A7	6605 637739	EKATERINA KOVALEVA	{"phone": "+70585180219"}
0005433074892	CB17AD	5042 005297	DIANA ALEKSEEVA	{"phone": "+70273443753"}
0005433074836	C877A7	6599 183098	VALENTINA FEDOROVA	{"email": "fedorova-valentina.011983@postgrespro.ru", "phone": "+70646328706"}
0005433074837	050594	9318 436499	LIDIYA SCHERBAKOVA	{"email": "scherbakova_l1980@postgrespro.ru", "phone": "+70152732780"}
0005433074838	B79E7C	7823 253515	ANNA ISAEVA	{"email": "annaisaeva13051973@postgrespro.ru", "phone": "+70532640675"}
0005433074839	CCA651	5278 569261	ANATOLIY GRIGOREV	{"email": "anatoliygrigorev_1979@postgrespro.ru", "phone": "+70844123711"}
0005433074840	D6D5D1	9499 312815	ALEKSANDR BARANOV	{"phone": "+70705542462"}
0005433074841	6EFA1B	8112 098537	MARIYA KUZNECOVA	{"phone": "+70688141592"}
0005433074842	B2F8E0	9009 466371	OLESYA ZHURAVLEVA	{"phone": "+70287256887"}
0005433074843	0E0F52	7158 296466	MARIYA GRISHINA	{"phone": "+70342831792"}
0005433074844	0E0F52	8230 540367	VALERIY NAUMOV	{"email": "naumov.v_1970@postgrespro.ru", "phone": "+70720525439"}
0005433074845	DE83A5	5611 873980	MIKHAIL DAVYDOV	{"phone": "+70613039598"}
0005433074846	793CE4	9431 525393	NADEZHDA YAKOVLEVA	{"email": "nadezhdayakovleva_29101970@postgrespro.ru", "phone": "+70755049474"}
0005433074847	793CE4	4144 844877	VLADIMIR KUZNECOV	{"phone": "+70475038777"}
0005433074848	67330C	5674 731850	DMITRIY ZHURAVLEV	{"email": "zhuravlev_d-1971@postgrespro.ru", "phone": "+70217593404"}
0005433074849	67330C	3435 905612	SOFYA KUZNECOVA	{"phone": "+70348078738"}
0005433074850	C29C4E	6274 173401	SVETLANA DANILOVA	{"phone": "+70174336201"}
0005433074851	026E8C	3400 422160	LIDIYA GUSEVA	{"email": "lidiya.guseva_09091975@postgrespro.ru", "phone": "+70793504243"}
0005433074852	FD2901	5097 670142	ZOYA KOZLOVA	{"phone": "+70441612543"}
0005433074853	1EA0C7	3777 022095	ALEKSANDR SCHERBAKOV	{"phone": "+70907645038"}
0005433074854	59A3F8	4718 230267	ALBINA AFANASEVA	{"phone": "+70068100643"}
0005433074855	F5F517	4213 961856	VALENTINA SMIRNOVA	{"phone": "+70622698707"}
0005433074856	F5F517	3996 024134	NATALYA KONOVALOVA	{"phone": "+70951506557"}
0005433074857	F5F517	7501 684765	MAKSIM SIDOROV	{"email": "m.sidorov_26031964@postgrespro.ru", "phone": "+70328321703"}
0005433074858	DFF2BE	1804 867730	NIKITA GRIGOREV	{"email": "n.grigorev.25081975@postgrespro.ru", "phone": "+70715815840"}
0005433074859	DFF2BE	9771 325113	INESSA POPOVA	{"phone": "+70188213090"}
0005433074860	E561AA	0241 476524	RUSHANIYA NIKOLAEVA	{"email": "nikolaevar-081982@postgrespro.ru", "phone": "+70249503753"}
0005433074861	403980	6137 176576	ANTON DENISOV	{"phone": "+70683499736"}
0005433074862	AA5822	7734 781040	ANNA NIKITINA	{"phone": "+70572963412"}
0005433074863	AA5822	1626 455550	GALINA TARASOVA	{"email": "tarasova.galina-04111980@postgrespro.ru", "phone": "+70922233805"}
0005433074864	8BDA89	7021 433500	IRINA MARTYNOVA	{"phone": "+70758600193"}
0005433074865	99ADF4	4743 641554	ARTEM NOVIKOV	{"email": "novikov_artem.1971@postgrespro.ru", "phone": "+70417497403"}
0005433074866	99ADF4	8391 471689	ALEKSEY BARANOV	{"email": "aleksey.baranov111976@postgrespro.ru", "phone": "+70619176297"}
0005433074867	7BCD0A	3398 027077	NINA BORISOVA	{"email": "borisova-n.011974@postgrespro.ru", "phone": "+70119477163"}
0005433074868	7BCD0A	5696 056552	EVGENIYA SERGEEVA	{"phone": "+70218035235"}
0005433074869	7BCD0A	0890 666779	NATALYA SEMENOVA	{"email": "semenovanatalya.1967@postgrespro.ru", "phone": "+70307271988"}
0005433074870	E04D5D	6792 339712	DMITRIY SEMENOV	{"email": "d_semenov.29011969@postgrespro.ru", "phone": "+70208619306"}
0005433074871	A45401	6255 840775	IGOR POPOV	{"email": "popov_i-19021968@postgrespro.ru", "phone": "+70756152646"}
0005433074872	E9C0E5	7510 389844	OLESYA LAZAREVA	{"phone": "+70534429114"}
0005433074873	E9C0E5	4511 958354	LIDIYA ZAKHAROVA	{"email": "zakharoval-121974@postgrespro.ru", "phone": "+70330592509"}
0005433074874	C418B2	1674 854700	ALEKSANDR KULIKOV	{"phone": "+70373899851"}
0005433074875	C418B2	2994 722879	RUSLAN KOZLOV	{"phone": "+70284770378"}
0005433074876	0BEFDD	7985 271946	ANDREY NAUMOV	{"email": "naumov_andrey.23021965@postgrespro.ru", "phone": "+70743195392"}
0005433074877	0BEFDD	9343 349090	VASILIY NOVIKOV	{"email": "vasiliy-novikov.1978@postgrespro.ru", "phone": "+70406272123"}
0005433074878	416DA2	0521 228626	OLGA FROLOVA	{"email": "o.frolova031973@postgrespro.ru", "phone": "+70435887931"}
0005433074879	84735D	9447 276371	SERGEY KULIKOV	{"email": "kulikovs_1977@postgrespro.ru", "phone": "+70342369116"}
0005433074880	1F0B86	3360 929547	TATYANA SMIRNOVA	{"phone": "+70874300724"}
0005433074881	0F44D5	1030 342013	GALINA RYABOVA	{"email": "galinaryabova.051959@postgrespro.ru", "phone": "+70545421118"}
0005433074882	925700	8531 091790	IVAN KUZNECOV	{"email": "kuznecov.ivan06111974@postgrespro.ru", "phone": "+70940046952"}
0005433074883	925700	4272 662588	RAMIL BARANOV	{"phone": "+70281510695"}
0005433074884	1B0574	8920 937843	EDUARD MELNIKOV	{"phone": "+70980198665"}
0005433074885	3AD4BE	9232 967604	MARINA POPOVA	{"phone": "+70424609557"}
0005433074886	E5E65A	6311 662993	NATALIYA ROMANOVA	{"email": "n_romanova_15021977@postgrespro.ru", "phone": "+70594317134"}
0005433074887	5B4FEF	0660 662597	ANDREY ANDREEV	{"phone": "+70739291249"}
0005433074888	5B4FEF	6794 859141	VALENTINA SIDOROVA	{"phone": "+70372293099"}
0005433074889	6AC1F3	7963 516710	ILFAT ZHUKOV	{"phone": "+70726227480"}
0005433074890	407C58	7305 330084	PETR EGOROV	{"email": "egorov_petr_1972@postgrespro.ru", "phone": "+70268901925"}
0005433074891	CB17AD	1040 026490	VALERIY STEPANOV	{"email": "valeriy-stepanov_061976@postgrespro.ru", "phone": "+70207486244"}
0005433074893	78257D	3043 943337	ILYA SOROKIN	{"email": "sorokin.ilya_1977@postgrespro.ru", "phone": "+70128914253"}
0005433074894	78257D	8717 944093	VLADIMIR MIRONOV	{"phone": "+70931239323"}
0005433074895	E1F5F7	2824 810784	MIKHAIL MARTYNOV	{"email": "mikhail.martynov_13081974@postgrespro.ru", "phone": "+70853961318"}
0005433074896	E1F5F7	6893 566944	OLGA PETROVA	{"phone": "+70195050691"}
0005433074897	71ADE6	4918 974966	GALINA KISELEVA	{"email": "g_kiseleva-23031955@postgrespro.ru", "phone": "+70429416301"}
0005433074898	14FE20	3645 109983	MATVEY MEDVEDEV	{"phone": "+70667126127"}
0005433074899	B58434	3150 890536	TATYANA VASILEVA	{"phone": "+70507768494"}
0005433074900	15B4FF	1197 515106	ELIZAVETA ORLOVA	{"email": "orlovaelizaveta_081970@postgrespro.ru", "phone": "+70726819712"}
0005433074901	430B6E	3531 240031	FEDOR SOLOVEV	{"email": "f_solovev-1966@postgrespro.ru", "phone": "+70183525869"}
0005433074902	38AC33	0833 362025	SERGEY OSIPOV	{"phone": "+70245362018"}
0005433074903	F00B58	3238 446832	RUSLAN TARASOV	{"email": "tarasovr_1976@postgrespro.ru", "phone": "+70818291066"}
0005433074904	5A8326	7218 194139	NIKOLAY SOKOLOV	{"phone": "+70241507483"}
0005433074905	856D58	8772 308915	EVGENIY SEMENOV	{"email": "semenov.e-21111964@postgrespro.ru", "phone": "+70914540035"}
0005433074906	3BEE09	1192 165927	GENNADIY NAZAROV	{"email": "nazarov.gennadiy_1969@postgrespro.ru", "phone": "+70678271161"}
0005433074907	827A34	7348 856794	EKATERINA MEDVEDEVA	{"email": "ekaterina.medvedeva.1977@postgrespro.ru", "phone": "+70974187208"}
0005433074908	827A34	8899 806452	EKATERINA SMIRNOVA	{"email": "smirnovaekaterina1970@postgrespro.ru", "phone": "+70911906679"}
0005433074909	62716F	5247 681283	MIKHAIL ISAEV	{"email": "isaev.m_1982@postgrespro.ru", "phone": "+70606114729"}
0005433074910	AF6FBC	7827 951242	ALEKSANDR STEPANOV	{"email": "a-stepanov_021980@postgrespro.ru", "phone": "+70935547127"}
0005433074911	27EA74	7890 693815	EGOR PAVLOV	{"phone": "+70537298262"}
0005433074912	27EA74	8037 593621	NINA PETROVA	{"phone": "+70943526959"}
0005433074913	587E73	5569 320285	TATYANA ERMAKOVA	{"email": "ermakova-t-25081969@postgrespro.ru", "phone": "+70064237861"}
0005433074914	587E73	7823 250347	ELENA ABRAMOVA	{"phone": "+70340400473"}
0005433074915	A19ED3	7283 825592	TATYANA STEPANOVA	{"email": "stepanovatatyana_1972@postgrespro.ru", "phone": "+70409831534"}
0005433074916	0791F1	2607 165622	RADIK DAVYDOV	{"email": "davydov.radik13011975@postgrespro.ru", "phone": "+70832095296"}
0005433074917	4ABA72	8028 901092	VASILIY PAVLOV	{"email": "v.pavlov-081971@postgrespro.ru", "phone": "+70176722706"}
0005433074918	4ABA72	5524 775602	VIKTORIYA FOMINA	{"phone": "+70510435862"}
0005433074919	306FDB	2270 747898	ELENA KOROLEVA	{"email": "koroleva.elena24091974@postgrespro.ru", "phone": "+70247676599"}
0005433074920	306FDB	1032 420274	ALEKSANDR PETROV	{"email": "petrov.aleksandr-011974@postgrespro.ru", "phone": "+70071029804"}
0005433074921	8A2FDA	5015 794157	SERGEY NIKOLAEV	{"phone": "+70750592417"}
0005433074922	130612	2669 914844	ARTEM VOLKOV	{"email": "artem.volkov061961@postgrespro.ru", "phone": "+70140153143"}
0005433074923	130612	2082 449462	PAVEL NAZAROV	{"email": "p_nazarov.30101971@postgrespro.ru", "phone": "+70390339974"}
0005433074924	830EB7	6475 566571	GENNADIY SOKOLOV	{"email": "gennadiy-sokolov.26031970@postgrespro.ru", "phone": "+70571907915"}
0005433074925	135DBB	4042 488515	DMITRIY MIRONOV	{"email": "dmironov_1971@postgrespro.ru", "phone": "+70289989609"}
0005433074926	0AA8A6	5064 351907	ELIZAVETA GAVRILOVA	{"phone": "+70707489714"}
0005433074927	EEE795	6762 486933	VALENTINA ZAYCEVA	{"email": "valentina-zayceva121970@postgrespro.ru", "phone": "+70657874925"}
0005433074928	649938	3868 962097	SERGEY GORBUNOV	{"email": "gorbunov.sergey_1974@postgrespro.ru", "phone": "+70743626178"}
0005433074929	51DC5F	5074 544687	ELENA KUZMINA	{"phone": "+70865551926"}
0005433074930	47E185	9900 720540	EVDOKIYA LUKYANOVA	{"phone": "+70438117102"}
0005433074931	80E5AB	0188 203036	ALEKSANDR PAVLOV	{"email": "aleksandr.pavlov081970@postgrespro.ru", "phone": "+70181760812"}
0005433074932	80E5AB	1458 574589	EKATERINA EFIMOVA	{"email": "efimova.e19011976@postgrespro.ru", "phone": "+70435313664"}
0005433074933	F080F4	6226 904867	TATYANA NOVIKOVA	{"phone": "+70417610678"}
0005433074934	F080F4	6457 016893	ANDREY KOROLEV	{"phone": "+70937073044"}
0005433074935	F080F4	6341 195881	KONSTANTIN BONDARENKO	{"phone": "+70278255341"}
0005433074936	CA0B23	7473 462315	ELENA IVANOVA	{"email": "ivanova-e_041968@postgrespro.ru", "phone": "+70833029730"}
0005433074937	CA0B23	9629 941728	ALEKSANDRA SEMENOVA	{"phone": "+70224452877"}
0005433074938	814913	4192 248384	SVETLANA KAZAKOVA	{"phone": "+70023838237"}
0005433074939	814913	3573 243876	PETR NOVIKOV	{"email": "p.novikov31081966@postgrespro.ru", "phone": "+70773354924"}
0005433074940	EA1291	2166 578054	ALEKSEY IVANOV	{"email": "alekseyivanov.11021975@postgrespro.ru", "phone": "+70168123126"}
0005433074941	7562B9	9460 851526	VLADIMIR NIKITIN	{"email": "nikitin-vladimir011974@postgrespro.ru", "phone": "+70495282728"}
0005433074942	75E425	4019 684143	LYUBOV SOROKINA	{"email": "sorokina.l111964@postgrespro.ru", "phone": "+70465191785"}
0005433074943	E1BCAD	8497 076990	MIKHAIL IVANOV	{"email": "m-ivanov-071975@postgrespro.ru", "phone": "+70303831596"}
0005433074944	A92B9A	4793 458017	STEPAN EGOROV	{"phone": "+70364586961"}
0005433074945	A92B9A	2268 038561	ZINAIDA FROLOVA	{"phone": "+70269919620"}
0005433074946	A92B9A	1359 930545	GEORGIY ANTONOV	{"phone": "+70325143901"}
0005433074947	319F7B	9130 972998	YURIY BELOV	{"email": "belovy.071964@postgrespro.ru", "phone": "+70498269229"}
0005433075004	2BE8C0	8406 660665	VALENTINA ZHURAVLEVA	{"phone": "+70632876482"}
0005433074948	319F7B	1834 167977	ANATOLIY VASILEV	{"email": "a-vasilev_1982@postgrespro.ru", "phone": "+70356221172"}
0005433074949	8CEDCA	6573 187716	PAVEL ZAKHAROV	{"phone": "+70277741096"}
0005433074950	97B169	9572 672325	NINA MELNIKOVA	{"email": "nina-melnikova-24051982@postgrespro.ru", "phone": "+70833776307"}
0005433074951	97B169	3498 394127	NATALYA MALYSHEVA	{"email": "nmalysheva-011981@postgrespro.ru", "phone": "+70566363068"}
0005433074952	46CB75	8508 756362	VADIM KUZNECOV	{"phone": "+70489811015"}
0005433074953	46CB75	6630 597959	SEMEN KULIKOV	{"email": "s_kulikov-19011975@postgrespro.ru", "phone": "+70206965680"}
0005433074954	DEA642	1003 871346	ELENA MAKAROVA	{"phone": "+70973698471"}
0005433074955	BCD970	3516 557142	ELENA ZOTOVA	{"email": "elena-zotova_01071964@postgrespro.ru", "phone": "+70911449327"}
0005433074956	F8704C	8187 678401	ANTONINA VOLKOVA	{"email": "volkova_a-19091967@postgrespro.ru", "phone": "+70655116052"}
0005433074957	F96AD1	8988 331337	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir-1970@postgrespro.ru", "phone": "+70976867429"}
0005433074958	1AD74E	2421 030906	YULIYA FROLOVA	{"email": "frolova_yuliya111979@postgrespro.ru", "phone": "+70210237713"}
0005433074959	2C2EC3	2188 043105	VALENTINA BELOVA	{"phone": "+70147226947"}
0005433074960	58317C	6680 813374	NINA TIMOFEEVA	{"phone": "+70378314134"}
0005433074961	F6124A	7902 280573	GALINA MASLOVA	{"phone": "+70923113171"}
0005433074962	5DBBAA	6175 293634	ALEKSEY PETROV	{"email": "a.petrov.1976@postgrespro.ru", "phone": "+70078620832"}
0005433074963	18851D	9350 486367	ELENA PETROVA	{"email": "petrova.elena26111968@postgrespro.ru", "phone": "+70252718119"}
0005433074964	18851D	9150 594297	VLADIMIR FEDOROV	{"email": "fedorovv06011971@postgrespro.ru", "phone": "+70683607306"}
0005433074965	CA66EE	6963 909464	VLADIMIR KISELEV	{"phone": "+70996947984"}
0005433074966	8C4636	6840 404263	NATALYA KUDRYASHOVA	{"phone": "+70576569812"}
0005433074967	28A166	3342 547337	GENNADIY KUZMIN	{"phone": "+70798921222"}
0005433074968	87EA93	8521 644814	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr.13081980@postgrespro.ru", "phone": "+70949082552"}
0005433074969	80733E	0813 383712	NATALYA IVANOVA	{"phone": "+70620779923"}
0005433074970	80733E	1218 716932	ZOYA FROLOVA	{"email": "frolova-zoya1965@postgrespro.ru", "phone": "+70972894684"}
0005433074971	9D513F	2599 855645	ELENA NIKITINA	{"email": "elenanikitina.25041977@postgrespro.ru", "phone": "+70639661567"}
0005433074972	DFB515	4910 885216	LIDIYA BARANOVA	{"email": "l_baranova1965@postgrespro.ru", "phone": "+70762843493"}
0005433074973	DFB515	5328 310132	NIKOLAY SMIRNOV	{"email": "smirnov-n_10081964@postgrespro.ru", "phone": "+70579018722"}
0005433074974	C8D164	4772 490180	ALEKSEY SOROKIN	{"phone": "+70760214540"}
0005433074975	1AB789	9771 680661	ILYA BORISOV	{"phone": "+70537315747"}
0005433074976	F865A7	5159 205034	OLEG ANDREEV	{"email": "andreev-o.061976@postgrespro.ru", "phone": "+70528938520"}
0005433074977	572C89	0959 129398	EVGENIY KUDRYASHOV	{"email": "kudryashov-e_22071966@postgrespro.ru", "phone": "+70500588036"}
0005433074978	572C89	0838 753675	MAKSIM FOMIN	{"phone": "+70238774756"}
0005433074979	BE32E7	9670 797885	MARINA KRASNOVA	{"email": "marina_krasnova.061971@postgrespro.ru", "phone": "+70798539453"}
0005433074980	86EABC	3529 431269	EKATERINA TROFIMOVA	{"email": "ekaterina-trofimova_08121966@postgrespro.ru", "phone": "+70249855822"}
0005433074981	5F11D3	3562 091901	VLADIMIR SOROKIN	{"phone": "+70126012367"}
0005433074982	AE461F	6737 346914	RAISA KULIKOVA	{"email": "raisa.kulikova.17031978@postgrespro.ru", "phone": "+70943383754"}
0005433074983	CF55B0	7362 554791	ILDUS ROMANOV	{"email": "iromanov-14101966@postgrespro.ru", "phone": "+70855256975"}
0005433074984	8A29D6	8381 964286	DMITRIY SOROKIN	{"email": "sorokin_dmitriy_02111975@postgrespro.ru", "phone": "+70295726325"}
0005433074985	2330CC	1558 297597	OKSANA OSIPOVA	{"email": "osipova.o1982@postgrespro.ru", "phone": "+70364849619"}
0005433074986	6EAD98	8551 387831	VALENTINA VOROBEVA	{"phone": "+70712500847"}
0005433074987	5D1004	0797 236553	SERGEY ZAKHAROV	{"phone": "+70769068572"}
0005433074988	5D1004	1363 448993	NIKOLAY KULIKOV	{"phone": "+70190297682"}
0005433074989	0D8036	2643 877970	IGOR NAUMOV	{"phone": "+70020290417"}
0005433074990	0D8036	0119 653299	SERGEY RODIONOV	{"phone": "+70576406497"}
0005433074991	7E3ACB	8922 725726	OLGA PAVLOVA	{"email": "olga-pavlova06121971@postgrespro.ru", "phone": "+70580558380"}
0005433074992	014780	5816 470386	ZHANNA SAVELEVA	{"email": "savelevazhanna18081968@postgrespro.ru", "phone": "+70730967681"}
0005433074993	EDCA10	0796 402236	VLADIMIR KAZAKOV	{"phone": "+70896700540"}
0005433074994	8FBE2B	0251 736443	OLEG IVANOV	{"phone": "+70396465574"}
0005433074995	B17D35	7037 588335	BORIS KUDRYASHOV	{"phone": "+70897167529"}
0005433074996	7D294C	9514 409853	EVGENIY GUSEV	{"email": "gusevevgeniy1979@postgrespro.ru", "phone": "+70334271972"}
0005433074997	F7E125	7959 662477	NONNA OSIPOVA	{"email": "n.osipova.23091967@postgrespro.ru", "phone": "+70811251604"}
0005433075118	AA9162	1873 070317	ALEKSANDR MAKAROV	{"phone": "+70075953154"}
0005433074998	F7E125	1498 878239	VADIM VOLKOV	{"email": "volkovvadim-091963@postgrespro.ru", "phone": "+70924591285"}
0005433074999	63888C	0361 318427	SERGEY DAVYDOV	{"phone": "+70096729801"}
0005433075000	62E4E4	5408 894074	ALEKSEY ANTONOV	{"phone": "+70173770807"}
0005433075001	B09475	9458 422935	LIDIYA IVANOVA	{"phone": "+70548747988"}
0005433075002	FBF4DB	0298 719769	SERGEY FEDOROV	{"email": "s_fedorov-1973@postgrespro.ru", "phone": "+70546058113"}
0005433075003	2BE8C0	9528 668569	ALEKSANDR FROLOV	{"email": "aleksandr_frolov.1974@postgrespro.ru", "phone": "+70691046985"}
0005433075005	55D6E9	5372 878022	PAVEL ROMANOV	{"email": "pavel_romanov1980@postgrespro.ru", "phone": "+70249600456"}
0005433075006	47400C	2749 330148	ANDREY ALEKSEEV	{"phone": "+70096023695"}
0005433075007	D39DA4	1047 927235	ANDREY IVANOV	{"phone": "+70121912645"}
0005433075008	0A6E14	8777 402756	ANTONINA YUDINA	{"phone": "+70088633478"}
0005433075009	0A6E14	5293 332703	VASILIY KUZNECOV	{"email": "kuznecov-v19121976@postgrespro.ru", "phone": "+70053663002"}
0005433075010	720D29	8778 557210	ALEKSANDR MOROZOV	{"email": "a-morozov-1977@postgrespro.ru", "phone": "+70126504771"}
0005433075011	4DAFF7	8037 672645	VYACHESLAV MELNIKOV	{"email": "melnikov-vyacheslav.1977@postgrespro.ru", "phone": "+70978362165"}
0005433075012	EDC58B	5049 890268	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina_101972@postgrespro.ru", "phone": "+70016238282"}
0005433075013	9A3E73	7096 204654	VYACHESLAV MAKAROV	{"email": "makarov.v091973@postgrespro.ru", "phone": "+70402760876"}
0005433075014	2CD721	9705 341560	DENIS TIKHONOV	{"phone": "+70832765705"}
0005433075015	145C3C	2391 238786	SERGEY SMIRNOV	{"email": "smirnov.sergey_02031974@postgrespro.ru", "phone": "+70305602270"}
0005433075016	F82A92	7219 641753	SERGEY BELOV	{"phone": "+70297049211"}
0005433075017	F82A92	2665 561889	YULIYA KUZNECOVA	{"phone": "+70000417307"}
0005433075018	6F4F92	6431 346219	POLINA MELNIKOVA	{"phone": "+70219893917"}
0005433075019	4F451B	9772 799929	NIKOLAY FILIPPOV	{"email": "filippov.n_061960@postgrespro.ru", "phone": "+70254024542"}
0005433075020	4F451B	7065 768219	NATALYA MEDVEDEVA	{"email": "n-medvedeva.011969@postgrespro.ru", "phone": "+70372958259"}
0005433075021	4F451B	2076 683419	SVETLANA SEMENOVA	{"phone": "+70709795526"}
0005433075022	4D2798	7167 608451	ELIZAVETA IVANOVA	{"email": "ivanovae.08101971@postgrespro.ru", "phone": "+70516988674"}
0005433075023	39CBED	0053 435944	NIKOLAY PETROV	{"phone": "+70068239852"}
0005433075024	9DF9C9	0985 766685	RODION ZAKHAROV	{"email": "zakharovr01091959@postgrespro.ru", "phone": "+70306269027"}
0005433075025	9DF9C9	6575 371947	DMITRIY KUDRYASHOV	{"phone": "+70493596451"}
0005433075026	19944C	2061 828510	MARK FOMIN	{"email": "m.fomin051973@postgrespro.ru", "phone": "+70005514093"}
0005433075027	19944C	9009 158048	VLADIMIR ZHURAVLEV	{"email": "v.zhuravlev.111969@postgrespro.ru", "phone": "+70636662736"}
0005433075028	19944C	6194 792713	TATYANA MALYSHEVA	{"email": "tatyana-malysheva_25031982@postgrespro.ru", "phone": "+70589392527"}
0005433075029	66A2CA	4605 422984	LYUDMILA KOZLOVA	{"phone": "+70521827475"}
0005433075030	D97D4F	9263 409962	ANATOLIY PETROV	{"phone": "+70014767311"}
0005433075031	6FC7A8	5291 187245	ANASTASIYA NIKOLAEVA	{"phone": "+70186757503"}
0005433075032	E08D0F	5860 594603	ANTONIDA SOROKINA	{"phone": "+70193423649"}
0005433075033	2D4F13	8365 762032	YULIANA DAVYDOVA	{"email": "davydova-y.1974@postgrespro.ru", "phone": "+70140038367"}
0005433075034	2D4F13	5672 223783	VIKTORIYA SIDOROVA	{"phone": "+70626480760"}
0005433075035	038704	4388 418397	EKATERINA VLASOVA	{"phone": "+70419914729"}
0005433075036	3512EA	3032 856142	RUSTAM ANTONOV	{"phone": "+70550891927"}
0005433075037	3512EA	0805 009163	SERGEY MAKAROV	{"phone": "+70163765111"}
0005433075038	BA01B8	9436 152614	VERA KUZNECOVA	{"phone": "+70717121227"}
0005433075039	BA01B8	4944 064643	LYUDMILA TIKHONOVA	{"phone": "+70761118826"}
0005433075040	D28C8F	5052 795691	ROZA ANTONOVA	{"email": "rozaantonova.05081964@postgrespro.ru", "phone": "+70501342479"}
0005433075041	F00E7A	2681 285698	MIKHAIL SOROKIN	{"phone": "+70178439977"}
0005433075042	F00E7A	5043 970954	IRINA ILINA	{"phone": "+70477896350"}
0005433075043	F00E7A	3287 246317	IRINA GORBUNOVA	{"email": "gorbunovai_25021968@postgrespro.ru", "phone": "+70319853656"}
0005433075044	F88BE2	9487 956409	TATYANA ORLOVA	{"email": "tatyana.orlova.021975@postgrespro.ru", "phone": "+70500995144"}
0005433075045	6C0975	6924 767558	MIKHAIL NAZAROV	{"email": "nazarovm-071979@postgrespro.ru", "phone": "+70747767316"}
0005433075046	6C0975	5820 885401	NINA ZAKHAROVA	{"email": "n_zakharova.011980@postgrespro.ru", "phone": "+70420352227"}
0005433075047	EBD9AB	9148 214762	OLGA MAKAROVA	{"email": "omakarova.021973@postgrespro.ru", "phone": "+70267783739"}
0005433075048	EBD9AB	9584 157800	VLADIMIR IVANOV	{"phone": "+70554009110"}
0005433075049	EBD9AB	8130 157170	RAISA KALININA	{"email": "kalininar021980@postgrespro.ru", "phone": "+70244636086"}
0005433075050	B3BB38	5157 378098	LYUBOV GORBUNOVA	{"email": "lyubov.gorbunova14111957@postgrespro.ru", "phone": "+70405517323"}
0005433075051	DD888C	8180 147160	OKSANA KOROLEVA	{"email": "oksana.koroleva-111986@postgrespro.ru", "phone": "+70334806572"}
0005433075052	F9FF47	9341 758123	ALEKSANDR TARASOV	{"phone": "+70243545049"}
0005433075053	322D90	8489 057379	IGNAT KUZMIN	{"phone": "+70758879465"}
0005433075054	A79B72	0213 749011	KAMIL ALEKSEEV	{"phone": "+70245178014"}
0005433075055	A79B72	5433 897048	SERGEY FOMIN	{"phone": "+70961297607"}
0005433075056	D13CCE	0531 679769	TATYANA KOLESNIKOVA	{"email": "tkolesnikova_1975@postgrespro.ru", "phone": "+70837002326"}
0005433075057	E09D9E	0175 553384	SVETLANA VOLKOVA	{"email": "s-volkova_06121975@postgrespro.ru", "phone": "+70977815331"}
0005433075058	AF7F9B	6681 795767	SERGEY IVANOV	{"email": "ivanovs_29071959@postgrespro.ru", "phone": "+70746528112"}
0005433075178	165AF0	2334 488078	YURIY KISELEV	{"phone": "+70422800337"}
0005433075059	F606A2	5851 220836	ANDREY KARPOV	{"email": "a-karpov-28061977@postgrespro.ru", "phone": "+70427971178"}
0005433075060	94418B	2092 851247	SVETLANA FEDOROVA	{"email": "svetlana.fedorova.061967@postgrespro.ru", "phone": "+70089304845"}
0005433075061	5299EB	8398 151936	VLADISLAV FEDOROV	{"email": "fedorov-vladislav_051977@postgrespro.ru", "phone": "+70607629272"}
0005433075062	5299EB	5040 316927	NATALYA CHERNOVA	{"email": "natalya.chernova_071983@postgrespro.ru", "phone": "+70108600377"}
0005433075063	51A5E4	1976 888050	YULIYA KRASNOVA	{"phone": "+70049857677"}
0005433075064	51A5E4	7229 544243	KLAVDIYA KUZNECOVA	{"phone": "+70976002904"}
0005433075065	C2B717	7511 046069	VERA SOKOLOVA	{"phone": "+70816496436"}
0005433075066	0EAC4F	5995 046809	ANDREY STEPANOV	{"phone": "+70417264587"}
0005433075067	0EAC4F	6736 023779	SERGEY ZHURAVLEV	{"phone": "+70315713651"}
0005433075068	764AFA	9084 320505	MARINA PAVLOVA	{"email": "m_pavlova.111966@postgrespro.ru", "phone": "+70090761598"}
0005433075069	01436E	5242 542765	NATALYA KOROLEVA	{"email": "natalyakoroleva.1972@postgrespro.ru", "phone": "+70826631188"}
0005433075070	0808FA	4503 701931	ALEKSEY DAVYDOV	{"phone": "+70797839758"}
0005433075071	ADC92F	3116 778927	SOFIYA IVANOVA	{"phone": "+70542293652"}
0005433075072	913404	1824 889837	ELIZAVETA PAVLOVA	{"email": "e_pavlova1971@postgrespro.ru", "phone": "+70002541422"}
0005433075073	7F022B	6524 394849	EVDOKIYA SOROKINA	{"email": "sorokina-e.101973@postgrespro.ru", "phone": "+70400936188"}
0005433075074	6BA179	9633 622836	ANTON MOROZOV	{"email": "morozov-a_03121966@postgrespro.ru", "phone": "+70441754525"}
0005433075075	7667BA	7523 759594	SERGEY BORISOV	{"email": "borisov_s_1981@postgrespro.ru", "phone": "+70102186596"}
0005433075076	7667BA	1613 730340	VERA IVANOVA	{"phone": "+70767294618"}
0005433075077	7667BA	4100 183343	OLESYA NIKOLAEVA	{"phone": "+70666132373"}
0005433075078	7667BA	6914 582162	SERGEY MOISEEV	{"phone": "+70262072991"}
0005433075079	79B174	7664 656763	SERGEY SOLOVEV	{"email": "s.solovev_011977@postgrespro.ru", "phone": "+70309713349"}
0005433075080	79B174	2646 275786	MARTA TROFIMOVA	{"phone": "+70060543211"}
0005433075081	575BA8	9162 262410	KIRILL RODIONOV	{"email": "rodionovkirill1976@postgrespro.ru", "phone": "+70227077696"}
0005433075082	9AB222	9411 519204	NATALYA NIKITINA	{"email": "nikitinan051974@postgrespro.ru", "phone": "+70248354651"}
0005433075083	9AB222	3097 796715	SHAMIL STEPANOV	{"email": "stepanov_s.091967@postgrespro.ru", "phone": "+70710559838"}
0005433075084	CE6C5F	6505 880047	OLGA KOVALEVA	{"email": "olga.kovaleva.071986@postgrespro.ru", "phone": "+70298047879"}
0005433075085	2B8B8C	6907 302643	NATALYA MAKAROVA	{"email": "makarovan-111968@postgrespro.ru", "phone": "+70260926614"}
0005433075086	2B8B8C	9224 582986	DARYA OSIPOVA	{"email": "daryaosipova-121965@postgrespro.ru", "phone": "+70168449611"}
0005433075087	10E865	9330 633265	YULIYA YUDINA	{"phone": "+70543111342"}
0005433075088	10E865	9433 943978	ALEKSANDR ZHURAVLEV	{"phone": "+70653609722"}
0005433075089	C96725	4576 317266	MARINA ROMANOVA	{"email": "mromanova-051966@postgrespro.ru", "phone": "+70816182272"}
0005433075090	C96725	2893 113284	NADEZHDA PAVLOVA	{"email": "pavlova_nadezhda_1983@postgrespro.ru", "phone": "+70437536170"}
0005433075091	0B5992	7247 974381	BORIS ZHUKOV	{"phone": "+70519160509"}
0005433075092	0B5992	3067 099196	DENIS BARANOV	{"email": "baranov_denis_02101969@postgrespro.ru", "phone": "+70817395450"}
0005433075093	CADCAD	9893 966791	GALINA DANILOVA	{"email": "danilova-g_1970@postgrespro.ru", "phone": "+70142536837"}
0005433075094	C5CF7D	6164 257944	OLEG PETROV	{"phone": "+70951476680"}
0005433075095	FF3E50	7343 862288	ALEKSEY MAKAROV	{"phone": "+70432809548"}
0005433075096	EC0111	7783 608320	SERGEY POPOV	{"email": "s.popov01061966@postgrespro.ru", "phone": "+70274877860"}
0005433075097	438464	0124 088224	MIKHAIL GUSEV	{"phone": "+70227386872"}
0005433075098	3B915D	5167 048374	ALEKSANDR SCHERBAKOV	{"phone": "+70279485882"}
0005433075099	353D1F	6844 641915	VIKTORIYA POPOVA	{"phone": "+70669368816"}
0005433075100	4BA7AA	5992 622276	NINA PAVLOVA	{"email": "nina-pavlova09071976@postgrespro.ru", "phone": "+70607016171"}
0005433075101	117010	6578 551025	NINA FOMINA	{"phone": "+70258901900"}
0005433075102	117010	2565 290494	ALEKSANDRA PAVLOVA	{"email": "pavlova_a1970@postgrespro.ru", "phone": "+70959580248"}
0005433075103	89E45D	2474 055905	NATALYA KUZNECOVA	{"phone": "+70607515566"}
0005433075104	2BF24E	0736 234852	OKSANA PAVLOVA	{"phone": "+70208295028"}
0005433075105	1A8D8D	5524 965405	YULIYA NOVIKOVA	{"phone": "+70019069947"}
0005433075106	1A8D8D	4269 999415	SVETLANA AFANASEVA	{"email": "safanaseva30051978@postgrespro.ru", "phone": "+70759941477"}
0005433075107	97AF63	9245 106743	ARSENIY ALEKSEEV	{"email": "a.alekseev.1968@postgrespro.ru", "phone": "+70473422233"}
0005433075108	97AF63	1544 880724	ANASTASIYA GRISHINA	{"email": "grishinaa-101971@postgrespro.ru", "phone": "+70451759548"}
0005433075109	C59628	5070 540493	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev.041975@postgrespro.ru", "phone": "+70188912274"}
0005433075110	C59628	6492 885533	NIKITA SEMENOV	{"email": "nsemenov.19031969@postgrespro.ru", "phone": "+70713643354"}
0005433075111	991413	5377 107800	NIKOLAY SMIRNOV	{"phone": "+70538179479"}
0005433075112	4DC0B0	7821 106340	TAISIYA PETROVA	{"email": "taisiya_petrova-071976@postgrespro.ru", "phone": "+70737356935"}
0005433075113	D42D15	0356 288269	VERA VOROBEVA	{"email": "v-vorobeva29051974@postgrespro.ru", "phone": "+70611099860"}
0005433075114	D42D15	9964 343504	PAVEL KONOVALOV	{"phone": "+70560090640"}
0005433075115	91B48E	9844 134193	ARTUR KUZMIN	{"email": "kuzmin-artur1963@postgrespro.ru", "phone": "+70755555147"}
0005433075116	632B2D	9904 690012	ROZA KRASNOVA	{"email": "krasnova-roza_1963@postgrespro.ru", "phone": "+70683151854"}
0005433075117	632B2D	7445 140317	RAISA ALEKSEEVA	{"email": "alekseevar_1970@postgrespro.ru", "phone": "+70961839012"}
0005433075119	AA9162	6138 846029	SVETLANA SMIRNOVA	{"email": "smirnovas101968@postgrespro.ru", "phone": "+70432128351"}
0005433075120	FB41D1	6386 092507	ALEKSANDR ZAKHAROV	{"phone": "+70444036217"}
0005433075121	FB41D1	6469 289376	ALEKSEY VOROBEV	{"email": "aleksey_vorobev_1977@postgrespro.ru", "phone": "+70191972595"}
0005433075122	A25E8E	0904 893110	VALERIYA MOISEEVA	{"email": "moiseeva.v_041965@postgrespro.ru", "phone": "+70339935415"}
0005433075123	F0487E	0090 854015	SERGEY VOLKOV	{"email": "volkov-sergey.12051975@postgrespro.ru", "phone": "+70954893934"}
0005433075124	D3934C	9138 486058	MAKSIM MARTYNOV	{"email": "m-martynov28101966@postgrespro.ru", "phone": "+70594409211"}
0005433075125	B8F62E	6075 633464	ALEKSEY BONDARENKO	{"email": "bondarenko_aleksey091993@postgrespro.ru", "phone": "+70626785214"}
0005433075126	16620E	3365 282254	MARIYA PETROVA	{"email": "petrova.m031979@postgrespro.ru", "phone": "+70361906709"}
0005433075127	5AC274	9548 208203	VALENTINA ISAEVA	{"email": "isaeva.v.061972@postgrespro.ru", "phone": "+70603652352"}
0005433075128	114C16	7503 885150	VALERIY SERGEEV	{"email": "sergeev.v011969@postgrespro.ru", "phone": "+70547445640"}
0005433075129	114C16	8218 950424	ARTEM BELOV	{"phone": "+70998478696"}
0005433075130	FAC3F6	5888 950857	OLGA LEBEDEVA	{"email": "lebedeva.olga_14031968@postgrespro.ru", "phone": "+70395225443"}
0005433075131	0650B3	9297 180315	SVETLANA NIKITINA	{"phone": "+70724144635"}
0005433075132	0650B3	0070 220589	OLGA EGOROVA	{"email": "o_egorova.16071970@postgrespro.ru", "phone": "+70795954758"}
0005433075133	42C1EF	4200 399941	MADINA ANTONOVA	{"phone": "+70395452761"}
0005433075134	2657A9	3061 425458	RADIK KRASNOV	{"phone": "+70068098594"}
0005433075135	2657A9	0561 691688	ALINA MAKSIMOVA	{"email": "amaksimova1964@postgrespro.ru", "phone": "+70703555979"}
0005433075136	A0F413	7982 206302	LARISA NIKITINA	{"phone": "+70553306840"}
0005433075137	A0F413	9205 055327	ANASTASIYA BORISOVA	{"email": "anastasiya-borisova.1981@postgrespro.ru", "phone": "+70815371754"}
0005433075138	CE5436	1969 277745	EKATERINA POPOVA	{"email": "popova.e.16061972@postgrespro.ru", "phone": "+70963068816"}
0005433075139	2A8CAB	7174 923962	ANASTASIYA NESTEROVA	{"phone": "+70002178028"}
0005433075140	2A8CAB	7494 685134	ANASTASIYA KUZMINA	{"email": "kuzminaa111966@postgrespro.ru", "phone": "+70486119822"}
0005433075141	04489B	1821 100924	SERGEY OSIPOV	{"phone": "+70790469890"}
0005433075142	04489B	3171 971915	FEDOR FEDOTOV	{"email": "f-fedotov1951@postgrespro.ru", "phone": "+70934703172"}
0005433075143	22E9A0	8009 467503	VALENTINA IVANOVA	{"email": "ivanova.valentina-081968@postgrespro.ru", "phone": "+70054815870"}
0005433075144	22E9A0	8739 451723	ANNA PETROVA	{"email": "anna_petrova.091977@postgrespro.ru", "phone": "+70568266120"}
0005433075145	27FA3A	4671 378859	ANATOLIY IVANOV	{"phone": "+70574522290"}
0005433075146	8C1EC9	4857 673389	EGOR ZAYCEV	{"phone": "+70586009118"}
0005433075147	96E71D	6405 420363	DENIS KUZMIN	{"email": "kuzmin-denis-28081971@postgrespro.ru", "phone": "+70795910863"}
0005433075148	28CDBA	6395 508076	VASILIY SIDOROV	{"email": "vasiliy-sidorov-1968@postgrespro.ru", "phone": "+70988346715"}
0005433075149	25C1C7	4987 295444	ALI ALEKSANDROV	{"email": "aleksandrov.ali_27051979@postgrespro.ru", "phone": "+70236530269"}
0005433075150	18A8B5	2910 752040	VITALIY KOZLOV	{"email": "v.kozlov_121967@postgrespro.ru", "phone": "+70338653581"}
0005433075151	18A8B5	8392 691302	OLGA DENISOVA	{"phone": "+70833216993"}
0005433075152	245F4C	1895 946372	YULIYA GUSEVA	{"phone": "+70440939265"}
0005433075153	D480CF	2147 042632	VERA DENISOVA	{"phone": "+70877476265"}
0005433075154	D480CF	7454 955682	ALEVTINA RYABOVA	{"phone": "+70639072802"}
0005433075155	4DAE90	5564 167623	YURIY NIKITIN	{"phone": "+70846782275"}
0005433075156	3C7337	3912 677343	SERGEY STEPANOV	{"phone": "+70467488698"}
0005433075157	F71E6C	1769 812926	RAISA ZHUKOVA	{"email": "raisa-zhukova_18051981@postgrespro.ru", "phone": "+70068354930"}
0005433075158	F90853	6651 641988	LILIYA MATVEEVA	{"phone": "+70729612934"}
0005433075159	F90853	9835 388020	ALEKSEY KOZLOV	{"email": "kozlov-aleksey-031977@postgrespro.ru", "phone": "+70375834762"}
0005433075160	A2DD3B	4149 654367	LYUBOV ZHUKOVA	{"phone": "+70579310009"}
0005433075161	D18656	4014 910645	OLGA BORISOVA	{"email": "borisova-o_1972@postgrespro.ru", "phone": "+70124323224"}
0005433075162	D18656	6748 089232	EVGENIY ORLOV	{"phone": "+70158207392"}
0005433075163	802E28	0068 057187	ALEKSEY KOROLEV	{"email": "aleksey-korolev_08011979@postgrespro.ru", "phone": "+70357354183"}
0005433075164	802E28	0106 388607	NATALYA BELYAEVA	{"email": "belyaeva.natalya081973@postgrespro.ru", "phone": "+70593939064"}
0005433075165	7E5A1A	3770 423054	ALEKSANDR KULIKOV	{"phone": "+70559435224"}
0005433075166	19854A	6831 161821	PAVEL MAKAROV	{"phone": "+70074899003"}
0005433075167	150F1E	7879 175820	ALESYA KOZLOVA	{"email": "alesya_kozlova-021969@postgrespro.ru", "phone": "+70066566417"}
0005433075168	150F1E	5640 045929	ALEKSEY GORBUNOV	{"email": "gorbunovaleksey_111970@postgrespro.ru", "phone": "+70173273681"}
0005433075169	573C89	2899 402593	ALI FROLOV	{"phone": "+70610760404"}
0005433075170	95C926	6755 790797	YANA KARPOVA	{"email": "y_karpova_1974@postgrespro.ru", "phone": "+70804133978"}
0005433075171	1E84C5	1402 963424	EVGENIY ZHURAVLEV	{"phone": "+70333788253"}
0005433075172	1E84C5	5287 490050	EVGENIY VOLKOV	{"email": "evgeniy.volkov061968@postgrespro.ru", "phone": "+70077773045"}
0005433075173	C37FB5	6014 401565	VIKTOR MOISEEV	{"email": "vmoiseev021972@postgrespro.ru", "phone": "+70272330732"}
0005433075174	C37FB5	6978 474220	VALENTINA POPOVA	{"email": "popova.v27101968@postgrespro.ru", "phone": "+70948355893"}
0005433075175	C37FB5	2503 040487	OLGA TITOVA	{"phone": "+70431201540"}
0005433075176	E1A9DD	3643 047648	MARINA IVANOVA	{"email": "m-ivanova.30011976@postgrespro.ru", "phone": "+70821200380"}
0005433075177	E1A9DD	1989 733139	TATYANA BORISOVA	{"phone": "+70349363331"}
0005433075179	C9F4A9	3503 333659	ANDREY KAZAKOV	{"phone": "+70618771457"}
0005433075180	6C7EF6	2779 889945	FEDOR TIKHONOV	{"email": "tikhonov-f011967@postgrespro.ru", "phone": "+70694231706"}
0005433075181	6C7EF6	5947 543001	YURIY KUDRYASHOV	{"email": "yuriy_kudryashov_1980@postgrespro.ru", "phone": "+70182129737"}
0005433075182	6C7EF6	9062 369200	SERGEY MARTYNOV	{"email": "s-martynov.1975@postgrespro.ru", "phone": "+70211591091"}
0005433075183	36D14D	1762 955815	SAVELIY FROLOV	{"email": "frolov_s_031965@postgrespro.ru", "phone": "+70126108675"}
0005433075184	043533	6749 850092	ALEKSEY BORISOV	{"phone": "+70159211792"}
0005433075185	EDFCBB	1186 756531	ALEKSEY RODIONOV	{"email": "a.rodionov20121977@postgrespro.ru", "phone": "+70126087794"}
0005433075186	CB6B87	7232 136436	YURIY IVANOV	{"phone": "+70350133505"}
0005433075187	CB6B87	2279 416155	SEMEN SHEVCHENKO	{"email": "semen.shevchenko.1976@postgrespro.ru", "phone": "+70743207509"}
0005433075188	DFE058	3293 184748	VITALIY MAKAROV	{"email": "makarov-vitaliy091963@postgrespro.ru", "phone": "+70210141097"}
0005433075189	C71821	8499 693858	ELENA KRASNOVA	{"phone": "+70671594416"}
0005433075190	C71821	7298 108426	ALEKSEY SMIRNOV	{"phone": "+70119140907"}
0005433075191	D3B195	4189 030511	ELENA TARASOVA	{"email": "tarasovaelena-1965@postgrespro.ru", "phone": "+70522601367"}
0005433075192	D3B195	7573 342980	VYACHESLAV DENISOV	{"phone": "+70406841539"}
0005433075193	AF8B0A	8952 588165	ELIZAVETA CHERNOVA	{"phone": "+70427568134"}
0005433075194	AF8B0A	9685 263010	SERGEY SHEVCHENKO	{"email": "s.shevchenko071976@postgrespro.ru", "phone": "+70255377827"}
0005433075195	2979A9	8447 339819	EVGENIY TARASOV	{"email": "tarasov-evgeniy_14061964@postgrespro.ru", "phone": "+70059789263"}
0005433075196	5B71D0	0780 585585	ANNA DENISOVA	{"phone": "+70617651109"}
0005433075197	EC39B1	3526 371560	VLADIMIR PAVLOV	{"phone": "+70984252666"}
0005433075198	EC39B1	9390 946764	YURIY FROLOV	{"phone": "+70583835458"}
0005433075199	532DE0	6210 268564	RAISA NIKIFOROVA	{"email": "nikiforova.raisa.04071975@postgrespro.ru", "phone": "+70242726529"}
0005433075200	532DE0	0610 344616	NINA OSIPOVA	{"phone": "+70960812241"}
0005433075201	CFE47B	0828 291185	SERGEY BELOV	{"email": "sbelov.1970@postgrespro.ru", "phone": "+70021417530"}
0005433075202	CFE47B	4735 518948	SERGEY SIDOROV	{"email": "sidorov.sergey011969@postgrespro.ru", "phone": "+70433279248"}
0005433075203	E2D969	2210 321915	TAMARA POPOVA	{"phone": "+70223678236"}
0005433075204	E2D969	3152 007693	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva-08071974@postgrespro.ru", "phone": "+70027624538"}
0005433075205	75A25E	1518 800304	ALEKSEY VOROBEV	{"email": "avorobev-05011963@postgrespro.ru", "phone": "+70715561564"}
0005433075206	75A25E	1789 332911	KIRILL KAZAKOV	{"phone": "+70887566134"}
0005433075207	14A843	5183 329174	MARIYA SEMENOVA	{"phone": "+70778444260"}
0005433075208	1C2666	5750 477628	ALEKSANDR GERASIMOV	{"email": "aleksandr.gerasimov071978@postgrespro.ru", "phone": "+70448273667"}
0005433075209	1C2666	9858 932208	LARISA LEBEDEVA	{"email": "lebedeva.larisa.25101974@postgrespro.ru", "phone": "+70080257432"}
0005433075210	2327D8	6604 162307	ELENA EGOROVA	{"email": "egorova-e_051979@postgrespro.ru", "phone": "+70583383544"}
0005433075211	31490F	1404 715122	KONSTANTIN BONDARENKO	{"phone": "+70722282210"}
0005433075212	11F993	3797 482459	LYUDMILA YAKOVLEVA	{"phone": "+70097533366"}
0005433075213	CC464A	1067 449092	SERGEY GRIGOREV	{"phone": "+70802408272"}
0005433075214	65C2D9	4702 347971	TATYANA SOLOVEVA	{"phone": "+70206962657"}
0005433075215	CBB3A4	3328 336613	SVETLANA ZAYCEVA	{"email": "zaycevas_121976@postgrespro.ru", "phone": "+70958148970"}
0005433075216	CBB3A4	1232 568191	OLGA GRISHINA	{"phone": "+70329594643"}
0005433075217	D69BFE	3886 126973	VITALIY SMIRNOV	{"email": "smirnov-v_19041975@postgrespro.ru", "phone": "+70546723989"}
0005433075218	A66FB0	1729 414079	TATYANA DMITRIEVA	{"email": "tatyana-dmitrieva_041969@postgrespro.ru", "phone": "+70186014560"}
0005433075219	DF7715	1752 404580	MARGARITA ANTONOVA	{"email": "m.antonova_1975@postgrespro.ru", "phone": "+70016569395"}
0005433075220	EFD77B	8251 616976	BORIS AFANASEV	{"email": "b-afanasev091978@postgrespro.ru", "phone": "+70442898880"}
0005433075221	3D9B03	0815 348800	BORIS YAKOVLEV	{"phone": "+70171155156"}
0005433075222	AA441E	2094 214167	MARGARITA POPOVA	{"email": "popova-margarita1977@postgrespro.ru", "phone": "+70237957731"}
0005433075223	8FE18E	5870 290694	MARINA ISAEVA	{"phone": "+70620869843"}
0005433075224	3BD5B8	0680 890071	SERGEY IVANOV	{"phone": "+70969503705"}
0005433075225	3BD5B8	7907 335143	VALENTINA BELOVA	{"email": "v.belova-1978@postgrespro.ru", "phone": "+70059461454"}
0005433075226	C0DD34	3059 744510	NADEZHDA LEBEDEVA	{"email": "nadezhda_lebedeva_121974@postgrespro.ru", "phone": "+70937460988"}
0005433075227	074560	9029 023663	VALENTIN KUZNECOV	{"phone": "+70231679015"}
0005433075228	F940C6	1805 703434	ELENA IVANOVA	{"email": "ivanova-e031982@postgrespro.ru", "phone": "+70231671092"}
0005433075229	CA12CC	4936 391638	NADEZHDA ORLOVA	{"email": "nadezhda_orlova101960@postgrespro.ru", "phone": "+70691503418"}
0005433075230	C3FE0D	1692 174092	TATYANA TROFIMOVA	{"phone": "+70992249704"}
0005433075231	C3FE0D	5072 527598	TATYANA ARKHIPOVA	{"phone": "+70230330709"}
0005433075232	C1E027	8250 388784	ELENA OSIPOVA	{"phone": "+70743420881"}
0005433075233	C1E027	5703 413512	ELENA GUSEVA	{"phone": "+70480889768"}
0005433075234	F0DBD0	2349 183821	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr051974@postgrespro.ru", "phone": "+70166769881"}
0005433075235	F0DBD0	5095 406896	MARINA KONDRATEVA	{"phone": "+70317211738"}
0005433075236	9B1139	3533 468434	ELENA MEDVEDEVA	{"phone": "+70838195314"}
0005433075237	9B1139	8096 950948	ARTEM KULIKOV	{"email": "a_kulikov_1983@postgrespro.ru", "phone": "+70477755864"}
0005433075238	589062	9309 633476	FAINA KALININA	{"email": "kalininaf-25031966@postgrespro.ru", "phone": "+70354646116"}
0005433075239	835D7B	9896 209734	VIKTORIYA LEBEDEVA	{"email": "v-lebedeva_05081978@postgrespro.ru", "phone": "+70406826821"}
0005433075240	D6FA2D	9542 452038	VALENTINA MIRONOVA	{"phone": "+70520740062"}
0005433075241	BA067D	6971 695385	ROBERT VOLKOV	{"phone": "+70614163236"}
0005433075242	0EA5EB	0888 927744	ELENA GERASIMOVA	{"phone": "+70945882130"}
0005433075243	0EA5EB	3753 196400	ALEKSANDR MAKSIMOV	{"email": "maksimov-a091970@postgrespro.ru", "phone": "+70244821766"}
0005433075244	630AFB	3709 485222	ANNA OSIPOVA	{"phone": "+70188238270"}
0005433075245	630AFB	2523 488382	TAMARA KOMAROVA	{"email": "tamara.komarova111975@postgrespro.ru", "phone": "+70005754826"}
0005433075246	1FE17D	9498 353894	MIKHAIL MELNIKOV	{"phone": "+70588213866"}
0005433075247	9C5756	9000 300654	LYUDMILA AFANASEVA	{"email": "lyudmila_afanaseva.111982@postgrespro.ru", "phone": "+70045753259"}
0005433075248	C450B6	8975 644836	DENIS NAZAROV	{"email": "nazarov.denis.27091976@postgrespro.ru", "phone": "+70180218823"}
0005433075249	64062B	8865 326852	OLEG MIKHAYLOV	{"email": "olegmikhaylov_22011967@postgrespro.ru", "phone": "+70262359116"}
0005433075250	C2A188	5772 670405	LYUDMILA SIDOROVA	{"phone": "+70777426466"}
0005433075251	4B901C	4265 788705	KONSTANTIN PETROV	{"phone": "+70101563684"}
0005433075252	4B901C	1918 786356	ALEKSANDR DAVYDOV	{"phone": "+70815350790"}
0005433075253	005C6C	8195 145840	IRINA NAUMOVA	{"phone": "+70752452059"}
0005433075254	4DAC4E	0176 223056	BORIS GRIGOREV	{"email": "grigorevboris031972@postgrespro.ru", "phone": "+70735243755"}
0005433075255	17E2D6	0669 021482	VLADIMIR KUZMIN	{"email": "vladimirkuzmin.09021974@postgrespro.ru", "phone": "+70009016441"}
0005433075256	139F66	8667 300252	NATALYA FOMINA	{"email": "fominan-29011981@postgrespro.ru", "phone": "+70285495062"}
0005433075257	4B53AE	5011 215609	VENERA SOKOLOVA	{"email": "sokolova.v_041970@postgrespro.ru", "phone": "+70140482183"}
0005433075258	4B53AE	4118 270645	TIMUR ZHUKOV	{"email": "t-zhukov1967@postgrespro.ru", "phone": "+70499209521"}
0005433075259	4B53AE	4216 644709	ANDREY GERASIMOV	{"phone": "+70570752931"}
0005433075260	7C002E	0867 209966	ZINAIDA KALININA	{"phone": "+70091102093"}
0005433075261	1D5BDD	4709 060131	ELENA ANTONOVA	{"phone": "+70003576950"}
0005433075262	1D5BDD	2981 861703	DANIIL ABRAMOV	{"email": "dabramov.18011979@postgrespro.ru", "phone": "+70545984562"}
0005433075263	8FE8C9	9306 817213	VLADIMIR SCHERBAKOV	{"phone": "+70322013963"}
0005433075264	8FE8C9	4535 218145	ELIZAVETA ABRAMOVA	{"email": "elizaveta_abramova.031978@postgrespro.ru", "phone": "+70536322925"}
0005433075265	6D133E	2263 484751	VLADISLAV MOISEEV	{"email": "moiseev_vladislav_121966@postgrespro.ru", "phone": "+70493455149"}
0005433075266	919A11	3076 697758	SERGEY SMIRNOV	{"phone": "+70243438396"}
0005433075267	919A11	9139 457201	YULIYA KRASNOVA	{"phone": "+70945819939"}
0005433075268	919A11	1344 188868	OKSANA ZAYCEVA	{"email": "zayceva.oksana.13031968@postgrespro.ru", "phone": "+70688665629"}
0005433075269	1EF711	9283 449232	RUSLAN MATVEEV	{"email": "matveev.ruslan.15121971@postgrespro.ru", "phone": "+70485741627"}
0005433075270	3A9CB1	9330 849076	GEORGIY IVANOV	{"phone": "+70988533265"}
0005433075271	3A9CB1	8321 305173	FEDOR VOROBEV	{"email": "fedorvorobev_071971@postgrespro.ru", "phone": "+70732533469"}
0005433075272	82B984	9971 618814	ALEKSEY SCHERBAKOV	{"email": "scherbakovaleksey1970@postgrespro.ru", "phone": "+70765757003"}
0005433075273	82B984	8684 656023	GRIGORIY KUZNECOV	{"email": "gkuznecov26061966@postgrespro.ru", "phone": "+70718749282"}
0005433075274	573D40	7225 987136	VLADIMIR SHEVCHENKO	{"phone": "+70995393550"}
0005433075275	573D40	0630 383742	GENNADIY SOROKIN	{"phone": "+70679961281"}
0005433075276	BD7591	0506 398239	YULIYA ARKHIPOVA	{"email": "arkhipova-yuliya.1969@postgrespro.ru", "phone": "+70972239150"}
0005433075277	F2D994	9905 655781	MARINA GAVRILOVA	{"email": "marina_gavrilova29101976@postgrespro.ru", "phone": "+70658453933"}
0005433075278	F2D994	8352 874803	ALEKSANDR NIKITIN	{"phone": "+70829208884"}
0005433075279	FCD379	5879 888286	ALINA SCHERBAKOVA	{"email": "alina-scherbakova_24101961@postgrespro.ru", "phone": "+70575726524"}
0005433075280	142E40	9355 575114	IGOR IVANOV	{"phone": "+70960687868"}
0005433075281	142E40	1715 772257	NINA NIKIFOROVA	{"phone": "+70525175367"}
0005433075282	75B5F1	1353 110218	ALEKSANDR EGOROV	{"email": "aleksandregorov20031970@postgrespro.ru", "phone": "+70858645744"}
0005433075283	75B5F1	3287 184279	VALENTINA TIMOFEEVA	{"email": "timofeeva-v051984@postgrespro.ru", "phone": "+70785271479"}
0005433075284	83B42B	5432 612409	GALINA KRASNOVA	{"phone": "+70127658909"}
0005433075285	808B0E	0360 949575	EVGENIYA ISAEVA	{"phone": "+70795648233"}
0005433075286	808B0E	1869 719467	EVGENIY STEPANOV	{"email": "stepanov.e_1985@postgrespro.ru", "phone": "+70240606342"}
0005433075287	89D171	8796 591257	NIKITA MELNIKOV	{"phone": "+70095933645"}
0005433075288	5586F5	6155 236145	EVGENIYA FOMINA	{"phone": "+70697554815"}
0005433075289	5586F5	7547 261561	NINA LAZAREVA	{"email": "lazareva.n111972@postgrespro.ru", "phone": "+70029204750"}
0005433075290	25AE37	9653 856733	SERGEY ROMANOV	{"email": "sromanov-07041965@postgrespro.ru", "phone": "+70510150342"}
0005433075291	FE0FB5	5503 222727	GALINA FEDOROVA	{"email": "fedorova_g.1970@postgrespro.ru", "phone": "+70466681402"}
0005433075292	153EB9	0992 772411	DMITRIY VOROBEV	{"email": "vorobev.dmitriy07121976@postgrespro.ru", "phone": "+70565888830"}
0005433075293	E37826	4056 245212	DMITRIY FOMIN	{"phone": "+70311704939"}
0005433075294	5015F4	8315 326756	GALINA ANISIMOVA	{"email": "anisimova_galina23051970@postgrespro.ru", "phone": "+70776755672"}
0005433075295	5015F4	9875 053521	MARIYA ISAEVA	{"phone": "+70405792736"}
0005433075296	5015F4	7179 828532	MARIYA ALEKSEEVA	{"email": "alekseevam051975@postgrespro.ru", "phone": "+70741464379"}
0005433075297	5015F4	7254 887539	DMITRIY POPOV	{"email": "d.popov_101960@postgrespro.ru", "phone": "+70484182648"}
0005433075298	1EC887	7274 654708	OLEG POPOV	{"phone": "+70870483943"}
0005433075299	1EC887	4960 141221	VASILIY MAKAROV	{"email": "makarovv101972@postgrespro.ru", "phone": "+70240886010"}
0005433075300	CDAED0	4501 738141	DANIIL MAKSIMOV	{"email": "daniil-maksimov.1965@postgrespro.ru", "phone": "+70008213539"}
0005433075301	28F16D	7627 731120	MARIYA NIKITINA	{"email": "nikitina_m_17091972@postgrespro.ru", "phone": "+70238294140"}
0005433075302	26AF25	4879 819756	LYUDMILA STEPANOVA	{"phone": "+70365579294"}
0005433075303	26AF25	6548 562022	SERGEY GAVRILOV	{"email": "sergey_gavrilov-1971@postgrespro.ru", "phone": "+70189078979"}
0005433075304	2B6E1E	7961 816091	ALINA ZHURAVLEVA	{"phone": "+70748332987"}
0005433075305	3B4978	1743 151988	ALEKSANDR KUDRYASHOV	{"phone": "+70235905320"}
0005433075306	3B4978	6952 156153	ANGELINA PETROVA	{"phone": "+70834035446"}
0005433075307	C8B5F6	4150 957072	ANATOLIY ROMANOV	{"email": "anatoliyromanov031970@postgrespro.ru", "phone": "+70161378943"}
0005433075308	EBD3DD	8138 369009	YULIYA MOROZOVA	{"phone": "+70477301461"}
0005433075309	EBD3DD	6849 751024	ALEKSEY GORBUNOV	{"phone": "+70166389009"}
0005433075310	EBD3DD	7098 547285	VLADIMIR IVANOV	{"email": "vivanov.031969@postgrespro.ru", "phone": "+70179165478"}
0005433075311	22E697	7312 911855	ALEKSANDR BORISOV	{"email": "aleksandr_borisov06031966@postgrespro.ru", "phone": "+70191518090"}
0005433075312	5C5D35	7840 281992	TATYANA SOLOVEVA	{"email": "solovevatatyana-1965@postgrespro.ru", "phone": "+70226744586"}
0005433075313	248C26	9274 734322	ANTON MARTYNOV	{"email": "antonmartynov_081962@postgrespro.ru", "phone": "+70868901328"}
0005433075314	248C26	9460 844963	SERGEY BORISOV	{"phone": "+70476217490"}
0005433075315	248C26	6898 945013	YULIYA BELOVA	{"email": "yuliyabelova15111973@postgrespro.ru", "phone": "+70921110331"}
0005433075316	678221	6862 364319	VIKTOR VOROBEV	{"email": "vorobev_viktor-071975@postgrespro.ru", "phone": "+70560946375"}
0005433075317	8E6379	4097 947175	ANDREY MAKSIMOV	{"email": "andrey.maksimov.1965@postgrespro.ru", "phone": "+70255043291"}
0005433075318	8E6379	6471 047487	ELENA SIDOROVA	{"email": "sidorova_elena-09041979@postgrespro.ru", "phone": "+70364855019"}
0005433075319	EB95C0	6810 308396	DANIIL MATVEEV	{"email": "matveevdaniil01031969@postgrespro.ru", "phone": "+70893630986"}
0005433075320	936F17	0654 063259	ALEKSANDR ROMANOV	{"email": "romanova-19051970@postgrespro.ru", "phone": "+70413338100"}
0005433075321	936F17	4558 235801	ARINA BELYAEVA	{"phone": "+70559720958"}
0005433075322	FFFB39	4736 648020	DMITRIY PAVLOV	{"phone": "+70784573834"}
0005433075323	475126	7701 924222	EGOR ZHURAVLEV	{"email": "e-zhuravlev_091985@postgrespro.ru", "phone": "+70140343161"}
0005433075324	475126	0811 703162	KSENIYA KUZMINA	{"email": "kseniya.kuzmina-1972@postgrespro.ru", "phone": "+70729432967"}
0005433075325	B74F6D	5801 097241	RAISA DENISOVA	{"email": "denisova_r.121966@postgrespro.ru", "phone": "+70323430719"}
0005433075326	B5621E	6924 843030	MARIYA SMIRNOVA	{"phone": "+70763028000"}
0005433075327	B5621E	8757 088457	GALINA NIKITINA	{"email": "galinanikitina1968@postgrespro.ru", "phone": "+70548288041"}
0005433075328	2A0206	8662 062325	YURIY GORBUNOV	{"email": "gorbunovyuriy1968@postgrespro.ru", "phone": "+70315117308"}
0005433075329	6C7191	1263 791247	TATYANA ORLOVA	{"phone": "+70915176803"}
0005433075330	6C7191	6472 906462	ANNA ANTONOVA	{"email": "antonovaa.1962@postgrespro.ru", "phone": "+70164322349"}
0005433075331	6C7191	6333 110607	NELLI SERGEEVA	{"phone": "+70812686007"}
0005433075332	8D0240	0547 481621	VLADIMIR SIDOROV	{"phone": "+70980319531"}
0005433075333	187D80	8637 605245	YULIYA ARKHIPOVA	{"email": "arkhipova_y1971@postgrespro.ru", "phone": "+70327926033"}
0005433075334	2E2C77	1385 100888	ANDREY POPOV	{"phone": "+70127166578"}
0005433075335	567702	6968 806798	ALEKSEY SERGEEV	{"phone": "+70701995894"}
0005433075336	0EC849	3773 125001	GALINA MOROZOVA	{"phone": "+70854571696"}
0005433075337	44F34E	3395 265997	TATYANA NOVIKOVA	{"email": "tatyana_novikova1968@postgrespro.ru", "phone": "+70121172349"}
0005433075338	44F34E	9591 795636	ANDREY ZAKHAROV	{"email": "andreyzakharov031973@postgrespro.ru", "phone": "+70413292194"}
0005433075339	1164C4	2309 791282	EDUARD ZHUKOV	{"email": "zhukove.101960@postgrespro.ru", "phone": "+70451987252"}
0005433075340	8E412C	5242 734148	SERGEY SAVELEV	{"phone": "+70772803816"}
0005433075341	8E412C	6225 323349	SERGEY SOROKIN	{"email": "s_sorokin-1977@postgrespro.ru", "phone": "+70497328130"}
0005433075342	AF4B89	7958 040816	OLGA BOGDANOVA	{"phone": "+70098809308"}
0005433075343	1C26B2	3153 612899	ALEKSANDR ZAKHAROV	{"phone": "+70884791465"}
0005433075344	5C91E2	8872 221847	IVAN ANTONOV	{"phone": "+70809802278"}
0005433075345	891982	1786 102735	GALINA MARTYNOVA	{"email": "martynova_g-101965@postgrespro.ru", "phone": "+70283659862"}
0005433075346	891982	5963 050298	GALINA NESTEROVA	{"email": "g_nesterova-1977@postgrespro.ru", "phone": "+70212613366"}
0005433075347	E15D40	4423 024862	IRINA FOMINA	{"email": "fominai1972@postgrespro.ru", "phone": "+70638357198"}
0005433075348	BA3C42	0994 377701	TATYANA YUDINA	{"phone": "+70705581590"}
0005433075349	84E902	8924 394710	MILANA ZAKHAROVA	{"phone": "+70125020872"}
0005433075350	53FFC2	5675 740428	NIKOLAY SCHERBAKOV	{"email": "scherbakov-n-1971@postgrespro.ru", "phone": "+70527696059"}
0005433075351	B32500	9406 094567	EKATERINA PETROVA	{"phone": "+70614367353"}
0005433075352	2D8519	6446 125589	NIKOLAY FEDOROV	{"email": "fedorov-nikolay041976@postgrespro.ru", "phone": "+70139049475"}
0005433075353	5E67B3	0116 440922	VLADISLAV CHERNOV	{"email": "chernov.v.1967@postgrespro.ru", "phone": "+70395602131"}
0005433075354	B9DDC5	5985 216320	NATALYA ABRAMOVA	{"email": "abramova_n121970@postgrespro.ru", "phone": "+70821464155"}
0005433075355	B9DDC5	1981 165529	MARK GAVRILOV	{"email": "mark_gavrilov.091972@postgrespro.ru", "phone": "+70521792234"}
0005433075356	9C8E7A	3857 631664	EKATERINA BOGDANOVA	{"email": "ekaterina_bogdanova1957@postgrespro.ru", "phone": "+70640925101"}
0005433075357	9C8E7A	2177 750969	EKATERINA NIKIFOROVA	{"email": "ekaterina.nikiforova-051967@postgrespro.ru", "phone": "+70550178775"}
0005433075358	D67C30	0533 935196	OLGA KUZNECOVA	{"phone": "+70544921211"}
0005433075359	D67C30	5056 758864	YURIY SOKOLOV	{"phone": "+70453060885"}
0005433075360	439D81	9312 661730	VLADIMIR SCHERBAKOV	{"phone": "+70995299048"}
0005433075361	439D81	7126 282930	MAKSIM KULIKOV	{"email": "maksim-kulikov_13051969@postgrespro.ru", "phone": "+70834878756"}
0005433075362	7903EB	1127 118214	ALEKSANDR ZHUKOV	{"phone": "+70580023598"}
0005433075363	94DA43	9783 518438	VIKTOR SHEVCHENKO	{"email": "viktorshevchenko.16071973@postgrespro.ru", "phone": "+70038247727"}
0005433075364	94DA43	7351 370443	ANNA NAUMOVA	{"phone": "+70366366090"}
0005433075365	CC86A4	4543 984884	VLADIMIR GERASIMOV	{"phone": "+70310550184"}
0005433075366	CC86A4	4652 657432	MARIYA BELOVA	{"email": "m-belova-1975@postgrespro.ru", "phone": "+70928400555"}
0005433075367	225E03	7367 318184	DIANA KRASNOVA	{"phone": "+70799339321"}
0005433075368	225E03	5756 170812	MAKSIM IVANOV	{"email": "maksimivanov.051983@postgrespro.ru", "phone": "+70637502296"}
0005433075369	3A1ABA	9181 090787	DMITRIY VASILEV	{"email": "dvasilev-26011971@postgrespro.ru", "phone": "+70656736220"}
0005433075370	DC6A60	4933 738537	NAILYA MOROZOVA	{"phone": "+70166810887"}
0005433075371	07E890	9401 985676	EKATERINA ILINA	{"email": "ilina_e-1967@postgrespro.ru", "phone": "+70387281287"}
0005433075372	A9D921	5219 497816	PAVEL VLASOV	{"email": "vlasov-p-091977@postgrespro.ru", "phone": "+70337071503"}
0005433075373	A9D921	1660 941623	VLADIMIR DENISOV	{"email": "v-denisov_09121963@postgrespro.ru", "phone": "+70001620329"}
0005433075374	A9D921	0434 623364	LEONID FILIPPOV	{"phone": "+70104199701"}
0005433075375	FB9F18	2837 015208	ALEKSANDR SIDOROV	{"phone": "+70575312897"}
0005433075376	D9C6C3	2576 608959	MARIYA BORISOVA	{"email": "borisova_m-30071975@postgrespro.ru", "phone": "+70193849913"}
0005433075377	D9C6C3	7111 832281	MARINA DAVYDOVA	{"phone": "+70189156150"}
0005433075378	D73A61	6060 431799	EKATERINA GORBUNOVA	{"email": "gorbunova.e20101974@postgrespro.ru", "phone": "+70959520906"}
0005433075379	2A7226	2124 776832	SERGEY ZAYCEV	{"email": "zaycevsergey-021977@postgrespro.ru", "phone": "+70482602942"}
0005433075380	FA5A47	0885 234747	OLGA KUDRYASHOVA	{"email": "o.kudryashova.25061963@postgrespro.ru", "phone": "+70627885685"}
0005433075381	FA5A47	5076 725954	SERGEY GAVRILOV	{"email": "s.gavrilov-30071970@postgrespro.ru", "phone": "+70513669701"}
0005433075382	AC39BF	9677 864480	ANDREY ANDREEV	{"email": "andreeva-25051958@postgrespro.ru", "phone": "+70646850465"}
0005433075383	BEA027	8555 188494	EVGENIY ZHURAVLEV	{"phone": "+70040451148"}
0005433075384	2B9811	2991 648079	VALENTIN SAVELEV	{"email": "valentin_savelev1968@postgrespro.ru", "phone": "+70795678395"}
0005433075385	2B9811	8800 884099	IRINA FOMINA	{"email": "fomina.irina071970@postgrespro.ru", "phone": "+70753355397"}
0005433075386	8F345D	2840 857551	VARVARA FEDOROVA	{"email": "fedorovav031959@postgrespro.ru", "phone": "+70693570601"}
0005433075387	E4E2EC	5932 150453	ALBERT KONOVALOV	{"email": "konovalov-albert1966@postgrespro.ru", "phone": "+70277947585"}
0005433075388	CD131F	1122 209610	GALINA SCHERBAKOVA	{"email": "scherbakova_g1971@postgrespro.ru", "phone": "+70829142307"}
0005433075389	8A842F	0433 014442	GRIGORIY PETROV	{"phone": "+70336742566"}
0005433075390	7B024C	4305 058755	ALEKSANDRA VASILEVA	{"email": "vasileva.a-04041976@postgrespro.ru", "phone": "+70592641537"}
0005433075391	7B024C	9337 728897	VIKTOR KRASNOV	{"phone": "+70183455747"}
0005433075392	7B024C	5118 938586	OLGA EFIMOVA	{"phone": "+70749889513"}
0005433075393	CA9ADE	4719 225949	SERGEY MIKHAYLOV	{"phone": "+70414966221"}
0005433075394	1978C2	3929 155586	ARTEM MOISEEV	{"email": "moiseeva-1969@postgrespro.ru", "phone": "+70224362663"}
0005433075395	1978C2	1414 622929	SERGEY NIKITIN	{"phone": "+70092013817"}
0005433075396	9F0AF1	0149 838539	NATALYA ANDREEVA	{"phone": "+70797141169"}
0005433075397	0B1D60	9711 925972	GALINA RYABOVA	{"email": "galinaryabova.01021965@postgrespro.ru", "phone": "+70078460393"}
0005433075398	0B1D60	3290 796502	EVGENIYA FILATOVA	{"email": "filatova-evgeniya.1971@postgrespro.ru", "phone": "+70536987006"}
0005433075399	7ED308	0244 679754	ARTEM MATVEEV	{"phone": "+70703176266"}
0005433075400	020E6C	9559 367803	ALENA MELNIKOVA	{"email": "melnikova_alena_1972@postgrespro.ru", "phone": "+70873305923"}
0005433075401	5F28B9	1767 366247	TATYANA ALEKSEEVA	{"phone": "+70700893205"}
0005433075402	21ED61	0743 905111	VALERIY NIKOLAEV	{"email": "nikolaev.v_1980@postgrespro.ru", "phone": "+70895586992"}
0005433075403	3EB6F5	5884 025679	NATALYA FADEEVA	{"email": "fadeeva.natalya111969@postgrespro.ru", "phone": "+70745025882"}
0005433075404	7EADED	6733 004262	ANNA POTAPOVA	{"email": "potapova.anna.1961@postgrespro.ru", "phone": "+70924073050"}
0005433075405	AF9BEA	2773 592763	VYACHESLAV KOZLOV	{"email": "vyacheslav.kozlov08111969@postgrespro.ru", "phone": "+70000382081"}
0005433075406	AF9BEA	0282 698958	GEORGIY FEDOROV	{"phone": "+70020038331"}
0005433075407	AF9BEA	9769 282601	ALEKSANDR SMIRNOV	{"phone": "+70508168929"}
0005433075408	E45DCA	7757 631057	VIKTORIYA VASILEVA	{"phone": "+70523857141"}
0005433075409	4F6E13	6210 106317	OLGA MEDVEDEVA	{"email": "medvedeva.o.121971@postgrespro.ru", "phone": "+70028615534"}
0005433075410	4F6E13	8101 248563	KARINA FROLOVA	{"email": "karina-frolova-1979@postgrespro.ru", "phone": "+70974646128"}
0005433075411	1C95A6	0276 556063	NIKOLAY ISAEV	{"email": "n-isaev_121980@postgrespro.ru", "phone": "+70937001218"}
0005433075412	BD3B91	7003 609797	TATYANA ZHURAVLEVA	{"phone": "+70799396926"}
0005433075413	5AD8BA	0727 017034	MIKHAIL SEMENOV	{"email": "semenov_mikhail1970@postgrespro.ru", "phone": "+70367918585"}
0005433075414	B256D9	9502 542038	ANASTASIYA ANDREEVA	{"email": "anastasiya-andreeva.30041969@postgrespro.ru", "phone": "+70479615842"}
0005433075415	AC4DDA	3968 958811	ARMAN DAVYDOV	{"phone": "+70480813795"}
0005433075416	AC4DDA	5122 161333	SERGEY ZHUKOV	{"phone": "+70399782735"}
0005433075417	2869B0	1836 287026	ANATOLIY MAKSIMOV	{"phone": "+70332729242"}
0005433075418	2869B0	6255 124794	KRISTINA DENISOVA	{"email": "denisova-k30071972@postgrespro.ru", "phone": "+70726288158"}
0005433075419	F170D5	2015 754802	MARINA BELYAEVA	{"phone": "+70768105980"}
0005433075420	F170D5	9129 165684	SVETLANA KONOVALOVA	{"email": "svetlana.konovalova-01061960@postgrespro.ru", "phone": "+70811274155"}
0005433075421	F170D5	4897 131812	RAISA MELNIKOVA	{"email": "r_melnikova-1959@postgrespro.ru", "phone": "+70820267219"}
0005433075422	ED49A2	0903 028258	SERGEY IVANOV	{"email": "ivanov_sergey07021978@postgrespro.ru", "phone": "+70116928970"}
0005433075423	ED49A2	9692 647633	VASILIY KUZNECOV	{"phone": "+70150854772"}
0005433075424	477633	2888 495350	EKATERINA EFREMOVA	{"email": "efremova_ekaterina-031977@postgrespro.ru", "phone": "+70758951031"}
0005433075425	477633	6965 289447	ARINA KUZNECOVA	{"phone": "+70698445865"}
0005433075426	3DFD3C	3223 519994	MARIYA AKIMOVA	{"phone": "+70419410262"}
0005433075427	5B4667	3834 576638	GALINA VOLKOVA	{"phone": "+70118714305"}
0005433075428	60191E	6710 527082	NIKITA ROMANOV	{"email": "nikita_romanov23111963@postgrespro.ru", "phone": "+70118141690"}
0005433075429	60191E	6498 107097	KIRA ANTONOVA	{"email": "kantonova_111980@postgrespro.ru", "phone": "+70139429424"}
0005433075430	60191E	8584 539777	ANATOLIY MAKAROV	{"email": "makarovanatoliy_02071968@postgrespro.ru", "phone": "+70491552095"}
0005433075431	E64B9A	9143 595549	NATALYA IVANOVA	{"email": "ivanovan.13081967@postgrespro.ru", "phone": "+70949345100"}
0005433075432	C9619C	8029 676777	DARYA NOVIKOVA	{"email": "novikova.d1971@postgrespro.ru", "phone": "+70816068374"}
0005433075433	C9619C	4855 706935	NATALYA ANDREEVA	{"email": "natalya-andreeva-011980@postgrespro.ru", "phone": "+70628511005"}
0005433075434	B42902	2350 490692	SVETLANA FEDOROVA	{"phone": "+70684963592"}
0005433075435	AA915D	1366 919304	SERGEY MAKSIMOV	{"email": "maksimov.sergey.111971@postgrespro.ru", "phone": "+70896963486"}
0005433075436	AA915D	6394 031700	VLADIMIR KONOVALOV	{"email": "v.konovalov_121974@postgrespro.ru", "phone": "+70962163501"}
0005433075437	AA915D	7668 060256	VALERIY KARPOV	{"email": "karpov-v22031966@postgrespro.ru", "phone": "+70922739798"}
0005433075438	834E9B	8249 207993	GALINA ALEKSEEVA	{"email": "alekseevagalina_041977@postgrespro.ru", "phone": "+70566053434"}
0005433075439	834E9B	3469 065129	RAISA OVCHINNIKOVA	{"phone": "+70291209748"}
0005433075440	89E481	7709 780250	TAMARA IVANOVA	{"phone": "+70472583742"}
0005433075441	6D5FF2	0324 498561	NIKITA NOVIKOV	{"phone": "+70149298021"}
0005433075442	F00889	6022 564772	NATALYA BELOVA	{"email": "belova.n.06101972@postgrespro.ru", "phone": "+70381631562"}
0005433075443	F00889	2627 858267	KIRILL SCHERBAKOV	{"email": "scherbakovkirill-1975@postgrespro.ru", "phone": "+70306415178"}
0005433075444	D31CCF	9667 279918	GALINA SEMENOVA	{"phone": "+70679934577"}
0005433075445	572A61	8060 384528	IRINA KOVALEVA	{"phone": "+70438854329"}
0005433075446	572A61	5635 336899	MIKHAIL KULIKOV	{"phone": "+70437291736"}
0005433075447	9C945F	4351 238128	MAKSIM MEDVEDEV	{"email": "medvedev_m-01071971@postgrespro.ru", "phone": "+70673213737"}
0005433075448	BD0F49	6579 899124	TATYANA LEBEDEVA	{"email": "tlebedeva_051973@postgrespro.ru", "phone": "+70575440063"}
0005433075449	7ED79D	8217 494605	IRINA NIKIFOROVA	{"email": "inikiforova_031979@postgrespro.ru", "phone": "+70563213273"}
0005433075450	B44E94	8047 646987	ALEKSANDRA FOMINA	{"phone": "+70336505329"}
0005433075451	1B20C7	5575 812308	ALLA VASILEVA	{"email": "a.vasileva.1974@postgrespro.ru", "phone": "+70771625288"}
0005433075452	B88DB2	9889 692619	SERGEY VOLKOV	{"email": "s-volkov_1974@postgrespro.ru", "phone": "+70351907175"}
0005433075453	79C519	2749 936370	ALEKSANDR ZHUKOV	{"phone": "+70377717248"}
0005433075454	325EDB	0952 386711	DENIS KONOVALOV	{"phone": "+70661700880"}
0005433075455	325EDB	7687 026444	NATALYA TITOVA	{"email": "ntitova-071974@postgrespro.ru", "phone": "+70719764191"}
0005433075456	0FB401	4026 200364	ALEKSANDR MATVEEV	{"email": "a.matveev.091965@postgrespro.ru", "phone": "+70651579515"}
0005433075457	0FB401	8245 407727	IGOR VASILEV	{"phone": "+70630350587"}
0005433075458	0FB401	2678 342402	ALEKSANDR ORLOV	{"phone": "+70493501761"}
0005433075459	D49734	0636 458942	OLGA BARANOVA	{"email": "baranovao.1964@postgrespro.ru", "phone": "+70865067843"}
0005433075460	D49734	1769 581522	ALEKSANDR IVANOV	{"phone": "+70993844817"}
0005433075461	9B4CEF	4239 467064	EVGENIY YAKOVLEV	{"phone": "+70019834720"}
0005433075462	9B4CEF	3645 900724	SVETLANA KOZLOVA	{"phone": "+70590016852"}
0005433075463	3DD1F0	4092 671641	ROMAN FEDOTOV	{"email": "fedotov-r-08041976@postgrespro.ru", "phone": "+70491796933"}
0005433075464	15ECAC	3386 633324	SVETLANA TROFIMOVA	{"email": "svetlana-trofimova26091971@postgrespro.ru", "phone": "+70293132020"}
0005433075465	A05816	4057 562963	VADIM FEDOROV	{"phone": "+70628862079"}
0005433075466	A05816	8036 990630	MIKHAIL SOROKIN	{"email": "sorokinm-19111980@postgrespro.ru", "phone": "+70674619951"}
0005433075467	A05816	1945 343704	ROMAN IVANOV	{"email": "roman_ivanov1967@postgrespro.ru", "phone": "+70391333390"}
0005433075468	06979F	0615 882997	SERGEY NIKITIN	{"phone": "+70075394854"}
0005433075469	06979F	7919 462405	VLADIMIR IVANOV	{"email": "ivanov.v121968@postgrespro.ru", "phone": "+70522273221"}
0005433075470	88E87A	1435 263588	TATYANA TROFIMOVA	{"phone": "+70698232979"}
0005433075471	F98008	5459 278683	NATALYA KARPOVA	{"email": "natalya-karpova.18031957@postgrespro.ru", "phone": "+70756669860"}
0005433075472	F98008	8627 486218	IRINA EFIMOVA	{"phone": "+70324613649"}
0005433075473	39B708	7851 146430	MARIANNA MAKSIMOVA	{"email": "m.maksimova_1971@postgrespro.ru", "phone": "+70927523235"}
0005433075474	C92C59	5247 364071	VALERIY ANTONOV	{"email": "valeriy.antonov.121964@postgrespro.ru", "phone": "+70244829143"}
0005433075475	C92C59	0923 577462	DARYA FOMINA	{"email": "fomina.d-1962@postgrespro.ru", "phone": "+70791693732"}
0005433075476	9EE775	4207 182101	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova20091973@postgrespro.ru", "phone": "+70656218637"}
0005433075477	9EE775	5853 013369	ILYA ANTONOV	{"email": "antonov_ilya-1972@postgrespro.ru", "phone": "+70929846980"}
0005433075478	9EE775	5154 455476	ANNA MAKAROVA	{"phone": "+70031916373"}
0005433075479	07D6EC	3382 989383	ELIZAVETA BOGDANOVA	{"email": "elizavetabogdanova1966@postgrespro.ru", "phone": "+70400148451"}
0005433075480	BDB2C9	8744 219844	ALEKSANDR KAZAKOV	{"phone": "+70122012237"}
0005433075481	7EE8CC	7235 459287	PAVEL MOROZOV	{"phone": "+70307847981"}
0005433075482	1A153A	1254 565950	VLADIMIR DAVYDOV	{"phone": "+70326912385"}
0005433075483	1A153A	8941 850638	DMITRIY IVANOV	{"email": "ivanov_d.1974@postgrespro.ru", "phone": "+70568751721"}
0005433075484	D04785	1466 115414	MIKHAIL DAVYDOV	{"phone": "+70744200660"}
0005433075485	ABB00C	5027 035438	VALERIYA ISAEVA	{"email": "isaeva-valeriya_1964@postgrespro.ru", "phone": "+70235164489"}
0005433075486	4F3DD6	7351 246144	ELENA LEBEDEVA	{"email": "elena.lebedeva_09071972@postgrespro.ru", "phone": "+70681085164"}
0005433075487	2F9891	7310 120425	EVELINA LEBEDEVA	{"email": "elebedeva-04021969@postgrespro.ru", "phone": "+70612557870"}
0005433075488	2F9891	4924 461306	MIKHAIL TARASOV	{"email": "tarasovm-021971@postgrespro.ru", "phone": "+70721172860"}
0005433075489	2F189B	9813 881122	SERGEY VOLKOV	{"email": "volkov_sergey.1973@postgrespro.ru", "phone": "+70154235469"}
0005433075490	E6506A	0667 983544	MARIYA KUZNECOVA	{"phone": "+70493272737"}
0005433075491	5AA21F	7223 136387	NATALYA TITOVA	{"phone": "+70202431754"}
0005433075492	5AA21F	9167 150689	NADEZHDA KOLESNIKOVA	{"phone": "+70017016830"}
0005433075493	8E3171	1673 397859	IRINA ZAKHAROVA	{"phone": "+70331445917"}
0005433075494	C78089	6573 904079	ANTON SIDOROV	{"phone": "+70858854831"}
0005433075495	C78089	5438 332261	VALENTIN DMITRIEV	{"email": "dmitriev.v-1974@postgrespro.ru", "phone": "+70460282882"}
0005433075496	99CE98	0662 882806	EKATERINA SMIRNOVA	{"email": "ekaterina_smirnova.09041980@postgrespro.ru", "phone": "+70276475196"}
0005433075497	C0301A	3283 955663	NATALYA GERASIMOVA	{"email": "gerasimova-natalya-1973@postgrespro.ru", "phone": "+70412561499"}
0005433075498	8E9A76	6518 963783	NATALYA TROFIMOVA	{"email": "natalyatrofimova-16041976@postgrespro.ru", "phone": "+70890611729"}
0005433075499	D1437B	2362 612515	OLEG IVANOV	{"email": "oleg_ivanov061975@postgrespro.ru", "phone": "+70287541618"}
0005433075500	D1437B	3257 805961	TATYANA ZHUKOVA	{"phone": "+70158585699"}
0005433075501	295EDE	6152 153245	TATYANA GORBUNOVA	{"email": "gorbunova.t.021983@postgrespro.ru", "phone": "+70162753772"}
0005433075502	73E5E8	2575 361472	EVGENIY KOZLOV	{"phone": "+70213395702"}
0005433075503	79D3B5	5900 354891	OLGA AFANASEVA	{"email": "o.afanaseva.19121973@postgrespro.ru", "phone": "+70981176755"}
0005433075504	A7B63D	9460 498670	ZINAIDA KAZAKOVA	{"email": "kazakova-z1973@postgrespro.ru", "phone": "+70717299735"}
0005433075505	A7B63D	0817 313267	KRISTINA FROLOVA	{"email": "kristina_frolova_061981@postgrespro.ru", "phone": "+70247302887"}
0005433075506	44EED5	2921 316762	NIKOLAY SERGEEV	{"email": "n.sergeev091974@postgrespro.ru", "phone": "+70373820609"}
0005433075507	44EED5	2261 742732	ARSENIY SOKOLOV	{"phone": "+70662856935"}
0005433075508	CD4CD1	0289 831809	LYUBOV FEDOROVA	{"phone": "+70879606550"}
0005433075509	CD4CD1	1216 527026	ELENA YAKOVLEVA	{"email": "yakovleva-elena_1978@postgrespro.ru", "phone": "+70891170982"}
0005433075510	FEA96D	9964 625611	ALEKSEY STEPANOV	{"email": "a-stepanov_1968@postgrespro.ru", "phone": "+70367050337"}
0005433075511	5C2E8A	2484 178028	NIKOLAY VLASOV	{"email": "vlasov-n_03011957@postgrespro.ru", "phone": "+70055456028"}
0005433075512	742C25	7632 912140	TAMARA KUDRYASHOVA	{"email": "t_kudryashova071974@postgrespro.ru", "phone": "+70852824445"}
0005433075513	742C25	3721 851093	TATYANA LAZAREVA	{"email": "tatyana_lazareva_1979@postgrespro.ru", "phone": "+70771948958"}
0005433075514	936E4D	3009 272392	NATALYA NIKIFOROVA	{"email": "natalya.nikiforova.1969@postgrespro.ru", "phone": "+70347098184"}
0005433075515	B64329	4660 078241	VITALIY NIKITIN	{"phone": "+70713308050"}
0005433075516	B64329	8492 770990	PAVEL ROMANOV	{"phone": "+70348072979"}
0005433075517	B64329	2343 685744	EVGENIYA VOROBEVA	{"email": "vorobevaevgeniya081966@postgrespro.ru", "phone": "+70590868598"}
0005433075518	DE8BC8	4118 395232	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda_021982@postgrespro.ru", "phone": "+70624903922"}
0005433075519	DE8BC8	7906 121241	TARAS RODIONOV	{"email": "rodionov-taras_26081990@postgrespro.ru", "phone": "+70992394092"}
0005433075520	DE8BC8	7856 148371	ANDREY TARASOV	{"email": "tarasovandrey_05031973@postgrespro.ru", "phone": "+70360046476"}
0005433075521	6EBC7A	8955 338009	NINA SERGEEVA	{"email": "sergeeva-nina_1986@postgrespro.ru", "phone": "+70544588466"}
0005433075522	CF6EE4	4081 263655	YULIYA KULIKOVA	{"email": "kulikovayuliya_061977@postgrespro.ru", "phone": "+70477521632"}
0005433075523	1EC614	7132 019732	LIYA SCHERBAKOVA	{"email": "scherbakova_liya.06101975@postgrespro.ru", "phone": "+70125575871"}
0005433075524	7E87B4	9979 280222	ZINAIDA RODIONOVA	{"email": "rodionova.z_26021979@postgrespro.ru", "phone": "+70876404218"}
0005433075525	7E87B4	1195 566670	TATYANA ANISIMOVA	{"phone": "+70676754840"}
0005433075526	434402	5523 430247	DARYA GUSEVA	{"phone": "+70187175096"}
0005433075527	434402	8620 469549	STANISLAV ILIN	{"phone": "+70557872970"}
0005433075528	C35BA3	3165 783987	YULIYA SMIRNOVA	{"phone": "+70814897198"}
0005433075529	907775	7217 636928	ZLATA VLASOVA	{"email": "zlata.vlasova_31081974@postgrespro.ru", "phone": "+70045742608"}
0005433075530	907775	3827 845630	ALEKSANDR KRASNOV	{"email": "aleksandr-krasnov.1973@postgrespro.ru", "phone": "+70702163732"}
0005433075531	7C1233	6770 565142	YURIY RODIONOV	{"email": "rodionov.yuriy_03061963@postgrespro.ru", "phone": "+70845343651"}
0005433075532	6BB017	1218 217307	VASILIY POPOV	{"phone": "+70839713067"}
0005433075533	87491E	8800 474464	NATALYA SEMENOVA	{"phone": "+70929417410"}
0005433075534	87491E	5981 812399	NIKOLAY PETROV	{"email": "nikolaypetrov-011969@postgrespro.ru", "phone": "+70131041177"}
0005433075535	899679	7221 080725	ANATOLIY DAVYDOV	{"phone": "+70601072364"}
0005433075536	830156	7956 225421	ANATOLIY CHERNOV	{"phone": "+70263840858"}
0005433075537	830156	7215 932070	TAMARA BOGDANOVA	{"phone": "+70560666211"}
0005433075538	830156	7152 636422	IGOR NIKITIN	{"phone": "+70919252301"}
0005433075539	830156	9612 288272	ALEKSANDR GORBUNOV	{"phone": "+70929870005"}
0005433075540	29D851	7182 836788	VYACHESLAV FOMIN	{"email": "fomin_vyacheslav-01081970@postgrespro.ru", "phone": "+70626916744"}
0005433075541	F0A67B	1277 565976	VALENTINA ZAKHAROVA	{"phone": "+70437120005"}
0005433075542	583891	7259 179988	NATALYA MAKAROVA	{"phone": "+70944885394"}
0005433075543	51CC86	0541 447619	MARINA POTAPOVA	{"email": "m_potapova.1959@postgrespro.ru", "phone": "+70460981914"}
0005433075544	51CC86	2572 583045	EVGENIYA IVANOVA	{"email": "e_ivanova_1972@postgrespro.ru", "phone": "+70327726269"}
0005433075545	FF3BA7	4722 203670	ZHANNA KONOVALOVA	{"email": "konovalova.z.23101973@postgrespro.ru", "phone": "+70145220091"}
0005433075546	D06CD6	8414 552150	KSENIYA ALEKSANDROVA	{"email": "kseniya.aleksandrova_101979@postgrespro.ru", "phone": "+70004401925"}
0005433075547	2EE51E	4706 691124	ELENA ZHUKOVA	{"email": "e.zhukova.1968@postgrespro.ru", "phone": "+70723482571"}
0005433075548	365C85	7974 158048	ANASTASIYA KOROLEVA	{"email": "a_koroleva_121973@postgrespro.ru", "phone": "+70314203865"}
0005433075549	6926DE	5691 464158	ALEKSANDR AFANASEV	{"email": "afanasev_a.27071964@postgrespro.ru", "phone": "+70996211892"}
0005433101148	895AE9	9324 911903	IVAN GERASIMOV	{"phone": "+70921457631"}
0005433101149	F2CCD6	7189 344343	ANDREY CHERNOV	{"email": "chernov-a.1984@postgrespro.ru", "phone": "+70776732951"}
0005433101150	F2CCD6	0690 629793	LYUBOV FEDOROVA	{"email": "l_fedorova_1967@postgrespro.ru", "phone": "+70422924781"}
0005433101151	A43E07	3832 802406	RUZALIYA NIKIFOROVA	{"phone": "+70757291542"}
0005433101152	0D7C45	7461 599883	VLADIMIR OSIPOV	{"email": "vladimirosipov_1971@postgrespro.ru", "phone": "+70960487112"}
0005433101153	0D7C45	9357 903993	ILYA KUZNECOV	{"phone": "+70862682384"}
0005433101154	0D5C27	5854 917228	VERONIKA SEMENOVA	{"email": "veronika_semenova-041969@postgrespro.ru", "phone": "+70510750609"}
0005433101155	6073B8	0803 277385	ILYA PETROV	{"phone": "+70357865542"}
0005433101156	E9F793	3477 182301	VALERIY PETROV	{"email": "v_petrov-081968@postgrespro.ru", "phone": "+70841885756"}
0005433101157	3212E9	7039 941557	FARIDA DAVYDOVA	{"phone": "+70983221796"}
0005433101158	2104F5	7838 505885	IRINA CHERNOVA	{"phone": "+70950222831"}
0005433101159	2104F5	2291 186769	RAFAIL ZAYCEV	{"phone": "+70841625967"}
0005433101160	131A72	0453 416089	VLADIMIR RODIONOV	{"email": "rodionov_v04111968@postgrespro.ru", "phone": "+70904617501"}
0005433101161	B395F8	3651 050562	KRISTINA KOROLEVA	{"phone": "+70517189651"}
0005433101162	B395F8	2472 898422	IVAN ZHURAVLEV	{"email": "zhuravlev.ivan05011968@postgrespro.ru", "phone": "+70317019618"}
0005433101163	A8FB04	3380 768829	ALEKSEY STEPANOV	{"phone": "+70594564231"}
0005433101164	34BF36	6185 630762	VARVARA FOMINA	{"email": "varvara-fomina_15091972@postgrespro.ru", "phone": "+70885862234"}
0005433101165	B519D5	7799 117369	SERGEY KARPOV	{"phone": "+70478000703"}
0005433101166	95C204	2072 794210	OLGA NAUMOVA	{"email": "o_naumova.1965@postgrespro.ru", "phone": "+70451496643"}
0005433101167	95C204	9684 874292	YURIY RODIONOV	{"email": "yuriyrodionov-21101976@postgrespro.ru", "phone": "+70792240701"}
0005433101168	5A4FF6	5832 903604	IVAN EGOROV	{"phone": "+70876255389"}
0005433101169	5B87EC	7835 726893	VALENTINA ORLOVA	{"email": "orlova_v_051974@postgrespro.ru", "phone": "+70624540590"}
0005433101170	159423	2710 831960	ALEKSANDR DMITRIEV	{"phone": "+70207532930"}
0005433101171	950EF2	2307 781119	VALENTINA OSIPOVA	{"email": "v_osipova1974@postgrespro.ru", "phone": "+70489105953"}
0005433101172	950EF2	5217 583532	NADEZHDA ZAKHAROVA	{"phone": "+70790525749"}
0005433101173	79FCE9	1035 351173	DANIIL MIRONOV	{"email": "daniil.mironov.08041976@postgrespro.ru", "phone": "+70874392049"}
0005433101174	681F05	5612 287177	ARTEM STEPANOV	{"email": "stepanov_artem.1969@postgrespro.ru", "phone": "+70492622282"}
0005433101175	103893	1868 316535	NATALYA IVANOVA	{"phone": "+70475964086"}
0005433101176	103893	8457 067621	ANDREY TIKHONOV	{"phone": "+70802212750"}
0005433101177	7AE68F	8172 869621	DAMIR VOROBEV	{"phone": "+70658239869"}
0005433101178	779618	4834 840652	EVGENIY PETROV	{"phone": "+70659998057"}
0005433101179	779618	0993 945427	IVAN PETROV	{"phone": "+70092160926"}
0005433101180	1B22E1	9443 440027	ANASTASIYA POLYAKOVA	{"email": "polyakova-anastasiya.1975@postgrespro.ru", "phone": "+70620658597"}
0005433101181	01C20D	4505 886825	LYUBOV KOROLEVA	{"phone": "+70672453946"}
0005433101182	01C20D	1769 708460	NINA SIDOROVA	{"email": "sidorova_nina.101976@postgrespro.ru", "phone": "+70645947246"}
0005433101183	01C20D	5425 278053	ARTEM KUZNECOV	{"email": "kuznecovartem-18111973@postgrespro.ru", "phone": "+70013098093"}
0005433101184	A73500	8092 737395	EKATERINA LEBEDEVA	{"phone": "+70561366138"}
0005433101185	A73500	3897 780463	NATALYA FROLOVA	{"email": "frolova.n.081969@postgrespro.ru", "phone": "+70178030232"}
0005433101186	A5E303	8529 867087	TATYANA POTAPOVA	{"phone": "+70862213354"}
0005433101187	3EEC43	5193 186053	SERGEY ISAEV	{"email": "sisaev1968@postgrespro.ru", "phone": "+70692248920"}
0005433101299	3CC985	5680 473150	OLEG KONOVALOV	{"phone": "+70725252037"}
0005433101188	F3F98D	2016 728611	FARID GAVRILOV	{"email": "gavrilov_farid.20091977@postgrespro.ru", "phone": "+70610386590"}
0005433101189	F3F98D	8733 764154	MAKSIM KUZMIN	{"email": "maksim-kuzmin_15081968@postgrespro.ru", "phone": "+70758783574"}
0005433101190	632C39	3582 107444	ANDREY KULIKOV	{"email": "andrey_kulikov.011973@postgrespro.ru", "phone": "+70902021245"}
0005433101191	A88BEE	4561 219573	ALEKSEY ROMANOV	{"phone": "+70344371685"}
0005433101611	E74F3E	3199 773611	NATALIYA KUZNECOVA	{"phone": "+70838710363"}
0005433101192	4F2C46	1265 882859	MAKSIM PAVLOV	{"email": "mpavlov01071984@postgrespro.ru", "phone": "+70220905648"}
0005433101193	4F2C46	3057 754148	LIDIYA FADEEVA	{"phone": "+70094831925"}
0005433101194	53EDEE	2751 590994	NATALYA POPOVA	{"email": "popova.natalya-27041979@postgrespro.ru", "phone": "+70775906418"}
0005433101195	EB9E0B	0533 117708	VALERIY ANDREEV	{"email": "v-andreev101977@postgrespro.ru", "phone": "+70038094327"}
0005433101196	B96232	7126 845640	FEDOR BONDARENKO	{"phone": "+70578498410"}
0005433101197	96699A	1755 290515	LARISA SCHERBAKOVA	{"email": "l-scherbakova111969@postgrespro.ru", "phone": "+70327126550"}
0005433101198	7673BB	3067 638806	ELIZAVETA KARPOVA	{"phone": "+70518160400"}
0005433101199	7673BB	1051 697510	MARIYA VASILEVA	{"email": "mvasileva_12111977@postgrespro.ru", "phone": "+70447558086"}
0005433101200	511B0B	1604 324011	ARTEM IVANOV	{"email": "ivanov_a-06031983@postgrespro.ru", "phone": "+70094403936"}
0005433101201	217BD1	7496 609308	KRISTINA POPOVA	{"phone": "+70732185130"}
0005433101202	60B5E3	3667 396623	EKATERINA KOVALEVA	{"email": "e_kovaleva.011968@postgrespro.ru", "phone": "+70401093405"}
0005433101203	E0ACCC	1345 530487	ALEKSANDR KRASNOV	{"phone": "+70493324794"}
0005433101204	E0ACCC	2653 555343	SERGEY PETROV	{"email": "petrov-s-1974@postgrespro.ru", "phone": "+70274791005"}
0005433101205	E0ACCC	6937 344800	VLADIMIR FILIPPOV	{"phone": "+70449658095"}
0005433101206	D6510F	0187 509777	SVETLANA BARANOVA	{"email": "baranova.svetlana.1984@postgrespro.ru", "phone": "+70634105486"}
0005433101207	8A678A	6089 834197	ANDREY EGOROV	{"email": "egorov_andrey.1976@postgrespro.ru", "phone": "+70504773617"}
0005433101208	DD07A7	8640 887282	YURIY BELOV	{"email": "ybelov_111985@postgrespro.ru", "phone": "+70861077880"}
0005433101209	44688B	0430 784253	EKATERINA MELNIKOVA	{"phone": "+70179955783"}
0005433101210	44688B	8198 035444	SERGEY TIKHONOV	{"email": "tikhonov-s_1970@postgrespro.ru", "phone": "+70585531930"}
0005433101211	CDC231	9954 818805	ANNA ANTONOVA	{"phone": "+70259092078"}
0005433101212	C97428	6571 619078	ALBINA OVCHINNIKOVA	{"phone": "+70064151426"}
0005433101213	58F311	0439 645759	MARIYA SAVELEVA	{"phone": "+70700447831"}
0005433101214	60C606	1329 228829	YURIY SHEVCHENKO	{"phone": "+70365752199"}
0005433101215	60C606	5436 404081	KIRILL ZHURAVLEV	{"phone": "+70741981584"}
0005433101216	13C910	7335 251731	ALEKSANDR KUZMIN	{"email": "kuzmina1979@postgrespro.ru", "phone": "+70206491665"}
0005433101217	5230CD	8022 360365	MARINA STEPANOVA	{"phone": "+70230149062"}
0005433101218	CDFBD8	6849 135235	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov_1975@postgrespro.ru", "phone": "+70882731640"}
0005433101219	ED2515	6385 549842	LIDIYA TIKHONOVA	{"email": "l_tikhonova_031967@postgrespro.ru", "phone": "+70539790907"}
0005433101220	C1AB09	2939 050906	SVETLANA GRISHINA	{"phone": "+70483764925"}
0005433101221	4E49D4	9623 021129	LYUDMILA SERGEEVA	{"email": "sergeeva_l.20011971@postgrespro.ru", "phone": "+70617466938"}
0005433101222	4E49D4	3792 356916	DMITRIY RODIONOV	{"email": "drodionov_061967@postgrespro.ru", "phone": "+70143610161"}
0005433101223	4E49D4	3958 566570	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr18051974@postgrespro.ru", "phone": "+70605137969"}
0005433101224	A0FDDC	7587 115642	GENNADIY POPOV	{"email": "g_popov-03101978@postgrespro.ru", "phone": "+70687564829"}
0005433101225	A0FDDC	2792 777482	VALENTINA VOLKOVA	{"email": "valentina.volkova071977@postgrespro.ru", "phone": "+70584050931"}
0005433101226	E5E3CC	0597 285644	YURIY KRASNOV	{"email": "krasnov_yuriy-09011963@postgrespro.ru", "phone": "+70521596388"}
0005433101227	D5203B	7949 790891	YURIY TARASOV	{"phone": "+70510749222"}
0005433101228	D5203B	6309 136584	TAMARA DENISOVA	{"email": "denisovat.12091972@postgrespro.ru", "phone": "+70521144055"}
0005433101229	238937	6348 160015	ALEKSANDR IVANOV	{"email": "a_ivanov111972@postgrespro.ru", "phone": "+70413765743"}
0005433101230	238937	9445 505982	IGOR PAVLOV	{"phone": "+70919405843"}
0005433101231	CB20C2	2079 483239	ANDREY GUSEV	{"phone": "+70514411825"}
0005433101232	BF6D1F	9626 155059	NINA LUKYANOVA	{"email": "nina.lukyanova-061962@postgrespro.ru", "phone": "+70693967461"}
0005433101233	BF6D1F	9731 912201	LARISA KUZMINA	{"phone": "+70048322453"}
0005433101234	A4D63B	0242 712266	MIKHAIL POPOV	{"phone": "+70690411484"}
0005433101235	9B8049	4783 555641	VADIM SERGEEV	{"email": "sergeev.v1974@postgrespro.ru", "phone": "+70086211968"}
0005433101236	FCB9F8	2538 111689	SERGEY ZAKHAROV	{"email": "sergey_zakharov.061972@postgrespro.ru", "phone": "+70280725309"}
0005433101237	317A6C	1022 958333	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov-021972@postgrespro.ru", "phone": "+70470394867"}
0005433101238	5A821C	8968 543596	YULIYA EGOROVA	{"email": "yegorova.061981@postgrespro.ru", "phone": "+70286634754"}
0005433101239	32CF91	0561 822190	RITA TITOVA	{"email": "titovarita_1967@postgrespro.ru", "phone": "+70714936058"}
0005433101240	32CF91	6177 712483	RUSLAN KUZNECOV	{"phone": "+70814054605"}
0005433101241	77B813	1957 779260	ALEKSANDR VLASOV	{"phone": "+70540646528"}
0005433101242	CF6C44	0014 153393	ALEFTINA POPOVA	{"phone": "+70161406026"}
0005433101355	361517	9880 709544	ANDREY PETROV	{"phone": "+70035783642"}
0005433101243	9BD711	6727 267667	EVGENIY IVANOV	{"email": "e-ivanov_111972@postgrespro.ru", "phone": "+70311455763"}
0005433101244	9BD711	6225 060486	IRINA KOROLEVA	{"phone": "+70732244691"}
0005433101245	5986DA	5211 099507	LYUDMILA KONOVALOVA	{"email": "konovalova_lyudmila-09061986@postgrespro.ru", "phone": "+70181171771"}
0005433101246	051F9B	0533 306406	SERGEY POPOV	{"phone": "+70064130300"}
0005433101247	4CFCB7	3289 927272	SERAFIMA ZOTOVA	{"phone": "+70535721921"}
0005433101248	4CFCB7	6312 668578	LARISA LEBEDEVA	{"email": "lebedeval_20031977@postgrespro.ru", "phone": "+70877079849"}
0005433101249	DB83A9	3415 605101	NATALYA ORLOVA	{"phone": "+70311999220"}
0005433101250	05A067	1843 150988	VLADIMIR KARPOV	{"phone": "+70914819336"}
0005433101251	10351D	6952 106316	ELINA BORISOVA	{"email": "e_borisova_1960@postgrespro.ru", "phone": "+70273458160"}
0005433101252	10351D	8446 869902	ALEKSANDR MOROZOV	{"phone": "+70063436964"}
0005433101253	6E1007	5260 665434	IGOR SOKOLOV	{"phone": "+70967271055"}
0005433101254	6E1007	9539 769312	ALEKSANDR DMITRIEV	{"phone": "+70675955803"}
0005433101255	6E1007	2304 159064	ILYA KULIKOV	{"phone": "+70373140785"}
0005433101256	B79F7B	7311 959696	OLGA ARKHIPOVA	{"phone": "+70953534428"}
0005433101257	B79F7B	6249 719369	TATYANA ERMAKOVA	{"email": "ermakovat.21011971@postgrespro.ru", "phone": "+70766574200"}
0005433101258	D82F9B	1879 220553	NADEZHDA BELYAEVA	{"phone": "+70997727675"}
0005433101259	F27915	2059 544961	ALEKSANDR VLASOV	{"email": "aleksandrvlasov_1965@postgrespro.ru", "phone": "+70170767428"}
0005433101260	530737	6970 499490	LYUBOV SCHERBAKOVA	{"email": "lyubovscherbakova121954@postgrespro.ru", "phone": "+70404402712"}
0005433101261	46DF20	7474 063629	ALEKSANDR GERASIMOV	{"email": "a.gerasimov.22111970@postgrespro.ru", "phone": "+70001691683"}
0005433101262	46DF20	2583 578374	ELENA CHERNOVA	{"phone": "+70923904382"}
0005433101263	46DF20	5397 434014	KLAVDIYA KISELEVA	{"phone": "+70681282603"}
0005433101264	2244C3	0545 315697	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr.10121977@postgrespro.ru", "phone": "+70268699313"}
0005433101265	2244C3	6255 469577	TAMARA FADEEVA	{"email": "t_fadeeva-101984@postgrespro.ru", "phone": "+70034086224"}
0005433101266	3DBB21	3520 928127	OLEG AFANASEV	{"email": "olegafanasev_07051971@postgrespro.ru", "phone": "+70124385437"}
0005433101267	3DBB21	8482 391489	EDUARD DENISOV	{"email": "eduard_denisov.031986@postgrespro.ru", "phone": "+70761068448"}
0005433101268	A85D69	2817 489707	SERGEY VASILEV	{"email": "s_vasilev_121972@postgrespro.ru", "phone": "+70130081399"}
0005433101269	D7E434	4920 990239	ARTEM TARASOV	{"phone": "+70140050789"}
0005433101270	81507C	9602 009639	MARIYA DMITRIEVA	{"phone": "+70096849174"}
0005433101271	81507C	1757 108557	DANILA FROLOV	{"email": "frolovdanila.13061967@postgrespro.ru", "phone": "+70518196196"}
0005433101272	1F300A	9925 666027	DMITRIY NOVIKOV	{"email": "dmitriynovikov_09031960@postgrespro.ru", "phone": "+70306710415"}
0005433101273	1F300A	1230 733707	VALENTIN KRASNOV	{"email": "valentinkrasnov-031983@postgrespro.ru", "phone": "+70556261369"}
0005433101274	929CBA	6436 983206	ANTONINA IVANOVA	{"email": "ivanova-a.14041971@postgrespro.ru", "phone": "+70995283923"}
0005433101275	929CBA	9448 888171	VALERIY KISELEV	{"phone": "+70154973189"}
0005433101276	830599	8191 634024	ALEKSANDRA SOKOLOVA	{"phone": "+70667084450"}
0005433101277	FDC6E0	0820 972708	EVGENIY SAVELEV	{"phone": "+70125004159"}
0005433101278	FDC6E0	9151 041623	ILYAS ANTONOV	{"phone": "+70091789410"}
0005433101279	5031B4	5335 117890	ALEKSANDR POPOV	{"email": "aleksandrpopov.031970@postgrespro.ru", "phone": "+70417754334"}
0005433101280	000511	6156 354411	ANATOLIY MIKHAYLOV	{"phone": "+70932836108"}
0005433101281	1F107D	4544 571385	OLGA LEBEDEVA	{"email": "lebedeva.o.12091964@postgrespro.ru", "phone": "+70862190752"}
0005433101282	6F9386	8006 721689	VLADIMIR MOROZOV	{"email": "morozov.vladimir051961@postgrespro.ru", "phone": "+70829039929"}
0005433101283	5869FD	8817 953019	YULIYA STEPANOVA	{"phone": "+70492490539"}
0005433101284	DBCC27	8203 601598	ELENA EFIMOVA	{"email": "efimovaelena.091977@postgrespro.ru", "phone": "+70898268715"}
0005433101285	8B4EFB	9656 263177	RAMIL ROMANOV	{"phone": "+70603304316"}
0005433101286	F4464B	2100 283334	BOGDAN GERASIMOV	{"phone": "+70088457494"}
0005433101287	5A08ED	1801 623906	VALENTIN KOZLOV	{"email": "valentin-kozlov.09101985@postgrespro.ru", "phone": "+70248365187"}
0005433101288	80E462	2678 983386	SERGEY GRIGOREV	{"phone": "+70786490545"}
0005433101289	80E462	5973 975625	ELENA DAVYDOVA	{"phone": "+70194691842"}
0005433101290	0CC331	9017 706775	VERA KOVALEVA	{"email": "kovaleva_v.12021977@postgrespro.ru", "phone": "+70997711788"}
0005433101291	1249CF	8693 020244	MARINA NIKITINA	{"phone": "+70994555195"}
0005433101292	1249CF	3493 858379	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr-011985@postgrespro.ru", "phone": "+70513856497"}
0005433101293	1A276A	2587 181801	VALERIYA MELNIKOVA	{"phone": "+70921923504"}
0005433101294	780C2B	4188 125925	VLADIMIR GERASIMOV	{"email": "v_gerasimov.121965@postgrespro.ru", "phone": "+70321585964"}
0005433101295	CBFD86	4752 233945	GALINA NIKOLAEVA	{"phone": "+70929086670"}
0005433101296	CBFD86	0389 718305	VALENTINA ZHURAVLEVA	{"phone": "+70517433582"}
0005433101297	B4C1E0	9824 151552	SERGEY EGOROV	{"email": "egorov-s121981@postgrespro.ru", "phone": "+70713399123"}
0005433101298	4DF904	5226 023525	VLADA ANDREEVA	{"phone": "+70783506952"}
0005433101300	7AE489	3078 027692	MAKSIM FILIPPOV	{"email": "maksimfilippov1971@postgrespro.ru", "phone": "+70409687689"}
0005433101301	497966	1179 705956	MARINA RYABOVA	{"email": "mryabova121975@postgrespro.ru", "phone": "+70115992428"}
0005433101302	5ECCAD	6416 731179	ANNA STEPANOVA	{"phone": "+70429240239"}
0005433101303	5ECCAD	3184 816715	VLADIMIR IVANOV	{"phone": "+70769908499"}
0005433101304	5E19C6	2357 647531	DARYA NAUMOVA	{"email": "naumova_darya.26081963@postgrespro.ru", "phone": "+70125770924"}
0005433101305	8A396A	3669 091987	RAISA SOKOLOVA	{"phone": "+70101847492"}
0005433101306	8A396A	2646 577139	VALERIYA TITOVA	{"email": "v-titova_1983@postgrespro.ru", "phone": "+70274309852"}
0005433101307	E6C925	5745 807325	ANATOLIY MOROZOV	{"email": "morozov.a-17111974@postgrespro.ru", "phone": "+70444332449"}
0005433101308	E6C925	2799 486367	VALENTINA ZAKHAROVA	{"email": "zakharova_valentina_1972@postgrespro.ru", "phone": "+70220120364"}
0005433101309	56B098	5951 129375	ANDREY KOROLEV	{"phone": "+70550108300"}
0005433101310	339DBE	5872 929937	ILDAR MAKAROV	{"phone": "+70723661429"}
0005433101311	716997	5375 001279	SVETLANA FEDOROVA	{"email": "s-fedorova.1979@postgrespro.ru", "phone": "+70706860297"}
0005433101312	716997	7066 793163	RAVIL BORISOV	{"phone": "+70937652315"}
0005433101313	6A167A	5330 211826	KSENIYA NIKOLAEVA	{"email": "knikolaeva_19061970@postgrespro.ru", "phone": "+70573002482"}
0005433101314	F41978	8396 888715	SOFYA PETROVA	{"phone": "+70127504629"}
0005433101315	45A537	3771 010589	FARID EGOROV	{"phone": "+70718300145"}
0005433101316	45A537	6850 541692	OLEG TIMOFEEV	{"phone": "+70721739374"}
0005433101317	516394	0374 971103	GALINA VLASOVA	{"email": "vlasova_galina1986@postgrespro.ru", "phone": "+70137577951"}
0005433101318	516394	7650 392268	VIKTORIYA MOROZOVA	{"phone": "+70817968158"}
0005433101319	28DA14	8554 489804	EKATERINA SERGEEVA	{"email": "sergeeva_ekaterina.071974@postgrespro.ru", "phone": "+70260297935"}
0005433101320	8C4978	4335 260650	ALLA BORISOVA	{"phone": "+70819267197"}
0005433101321	8C4978	5791 375677	ALEKSANDR BELOV	{"email": "aleksandr.belov1966@postgrespro.ru", "phone": "+70067392796"}
0005433101322	D757FC	0891 536816	OLEG ANTONOV	{"phone": "+70344038422"}
0005433101323	EF86EE	6817 492526	ANTONINA ALEKSEEVA	{"email": "alekseevaa-1969@postgrespro.ru", "phone": "+70564003171"}
0005433101324	21AAD0	2881 446969	EVGENIY SCHERBAKOV	{"email": "scherbakov-e_1978@postgrespro.ru", "phone": "+70694661398"}
0005433101325	21AAD0	2016 967307	KIRILL EGOROV	{"phone": "+70286927987"}
0005433101326	3B8D1F	7973 251105	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy14061971@postgrespro.ru", "phone": "+70679326823"}
0005433101327	3B8D1F	2136 183300	TATYANA FEDOROVA	{"phone": "+70506636094"}
0005433101328	3B8D1F	3922 384680	IRINA ANDREEVA	{"phone": "+70544178597"}
0005433101329	FD12C6	1716 694957	NATALYA KALININA	{"email": "kalinina-n.111971@postgrespro.ru", "phone": "+70297616116"}
0005433101330	FD12C6	0927 476288	ALEKSANDR PETROV	{"phone": "+70044200432"}
0005433101331	30912F	3827 624101	MARIYA CHERNOVA	{"email": "mchernova21111968@postgrespro.ru", "phone": "+70599565900"}
0005433101332	30912F	2006 193504	ANTONINA ZHUKOVA	{"phone": "+70317883491"}
0005433101333	30912F	3894 738764	SVETLANA LUKYANOVA	{"phone": "+70322254501"}
0005433101334	15CF0C	1482 559237	ILDAR SOKOLOV	{"phone": "+70749947555"}
0005433101335	8C7255	5267 657592	LYUDMILA ABRAMOVA	{"email": "l-abramova-1968@postgrespro.ru", "phone": "+70827495218"}
0005433101336	6BE079	6511 314921	POLINA MATVEEVA	{"email": "matveevap.011962@postgrespro.ru", "phone": "+70369340467"}
0005433101337	E28F42	3128 287449	SERGEY SOROKIN	{"email": "sorokin_s111965@postgrespro.ru", "phone": "+70322375019"}
0005433101338	E28F42	7099 350417	ALEKSEY SERGEEV	{"email": "sergeev_aleksey_091974@postgrespro.ru", "phone": "+70286883513"}
0005433101339	37E92E	5782 111876	DANILA GORBUNOV	{"email": "d.gorbunov1974@postgrespro.ru", "phone": "+70794003033"}
0005433101340	37E92E	0435 962981	MARIYA OSIPOVA	{"email": "mariya_osipova_1965@postgrespro.ru", "phone": "+70340382839"}
0005433101341	37E92E	9267 986189	ELIZAVETA NESTEROVA	{"phone": "+70703290611"}
0005433101342	E27BD7	4297 232025	NIKOLAY KUZNECOV	{"email": "kuznecov_n.041974@postgrespro.ru", "phone": "+70855891572"}
0005433101343	71AFA3	6094 214618	ALEKSEY DENISOV	{"phone": "+70037703933"}
0005433101344	F6E62B	2598 599353	FAINA ZAYCEVA	{"phone": "+70648695683"}
0005433101345	F6E62B	8843 083734	SALAVAT KUZNECOV	{"phone": "+70542223125"}
0005433101457	0BA577	2356 883268	ARTEM EGOROV	{"phone": "+70775915985"}
0005433101346	3418FF	6803 656910	VIKTOR POPOV	{"email": "v_popov-01111974@postgrespro.ru", "phone": "+70045536033"}
0005433101347	F25C27	8954 187345	VLADIMIR MAKAROV	{"email": "vmakarov_06071974@postgrespro.ru", "phone": "+70226052476"}
0005433101348	5C752C	3533 579335	GENNADIY EGOROV	{"phone": "+70892656933"}
0005433101349	2F2D63	2839 489667	POLINA NAZAROVA	{"email": "nazarova-p1970@postgrespro.ru", "phone": "+70626485548"}
0005433101350	CBA031	4905 447706	NIKITA MIKHAYLOV	{"phone": "+70180075102"}
0005433101351	D2FEDB	0368 041397	NATALYA MAKAROVA	{"phone": "+70511623467"}
0005433101352	61881E	7253 875967	LYUDMILA LEBEDEVA	{"email": "lyudmila.lebedeva_1970@postgrespro.ru", "phone": "+70666252369"}
0005433101353	361517	0441 864923	ZOYA NIKITINA	{"email": "z_nikitina_071969@postgrespro.ru", "phone": "+70381707832"}
0005433101354	361517	7365 258039	TATYANA PAVLOVA	{"phone": "+70846851644"}
0005433101356	488E5F	2000 310291	NIKITA GUSEV	{"phone": "+70656244452"}
0005433101357	A23A50	6264 780285	ALEKSANDRA KISELEVA	{"email": "kiseleva_a_1972@postgrespro.ru", "phone": "+70019972981"}
0005433101358	A23A50	0731 775000	GALINA KUZNECOVA	{"email": "kuznecova_g_1980@postgrespro.ru", "phone": "+70084618100"}
0005433101359	7B1DC1	2066 262353	TATYANA MOISEEVA	{"phone": "+70630048438"}
0005433101360	FD48A2	7345 335793	OLGA KUZNECOVA	{"phone": "+70005189903"}
0005433101361	83E505	6301 573723	VLADIMIR GERASIMOV	{"phone": "+70280931798"}
0005433101362	83E505	2290 006001	DMITRIY AFANASEV	{"email": "dmitriy_afanasev_11121971@postgrespro.ru", "phone": "+70792744086"}
0005433101363	B0B3D8	1502 887392	YULIYA FROLOVA	{"phone": "+70270647156"}
0005433101364	293058	9783 134379	ALEKSANDR NIKOLAEV	{"phone": "+70543510154"}
0005433101365	12A60A	8350 288909	VLADIMIR NAZAROV	{"phone": "+70695030494"}
0005433101366	803A8B	5621 428723	ALEKSANDR SMIRNOV	{"phone": "+70611008934"}
0005433101367	F01685	0102 771383	NINA VASILEVA	{"phone": "+70784552576"}
0005433101368	26A43C	3390 370505	ELENA ZAKHAROVA	{"email": "zakharova_elena1979@postgrespro.ru", "phone": "+70535762498"}
0005433101369	D238DC	4342 528640	VIKTOR RODIONOV	{"phone": "+70092391602"}
0005433101370	5796F4	1172 918693	LIDIYA EFIMOVA	{"phone": "+70822642832"}
0005433101371	442B41	8475 966143	ANDREY EGOROV	{"email": "a_egorov_1981@postgrespro.ru", "phone": "+70428589198"}
0005433101372	14CD6C	6887 631954	ALEKSANDRA KISELEVA	{"phone": "+70554361896"}
0005433101373	14CD6C	4147 787166	DMITRIY ZAKHAROV	{"email": "dmitriy.zakharov-16091975@postgrespro.ru", "phone": "+70994627499"}
0005433101374	01EE01	2002 207114	VLADISLAV KUZNECOV	{"email": "vkuznecov-031974@postgrespro.ru", "phone": "+70834124824"}
0005433101375	A94FD8	1867 189979	ILDAR VOLKOV	{"email": "i-volkov111957@postgrespro.ru", "phone": "+70770404675"}
0005433101376	408838	4446 928602	SERGEY VOROBEV	{"email": "sergeyvorobev_041980@postgrespro.ru", "phone": "+70960628516"}
0005433101377	24985F	1043 780792	IVAN POPOV	{"phone": "+70955978754"}
0005433101378	CFE058	2604 520256	VALENTIN MAKAROV	{"email": "v-makarov_19021978@postgrespro.ru", "phone": "+70960357215"}
0005433101379	3CCF56	6113 717439	DENIS MELNIKOV	{"email": "d-melnikov_06021957@postgrespro.ru", "phone": "+70809487135"}
0005433101380	70EA42	3424 816507	NIKITA KRASNOV	{"phone": "+70551778598"}
0005433101381	70EA42	5398 537397	RAISA SCHERBAKOVA	{"email": "raisa.scherbakova_1970@postgrespro.ru", "phone": "+70598622682"}
0005433101382	8D5163	2264 284025	ROMAN MARTYNOV	{"email": "romanmartynov_1962@postgrespro.ru", "phone": "+70978760771"}
0005433101383	8D5163	4236 055089	OLGA MAKAROVA	{"phone": "+70933598253"}
0005433101384	81274C	9502 923714	SERGEY SERGEEV	{"phone": "+70145555850"}
0005433101385	611D77	6988 678614	PELAGEYA SOROKINA	{"email": "pelageya-sorokina_01061979@postgrespro.ru", "phone": "+70812941040"}
0005433101386	611D77	5486 442471	OLGA KULIKOVA	{"phone": "+70884216605"}
0005433101387	724CA8	8382 125912	YULIYA KOZLOVA	{"email": "kozlovay1969@postgrespro.ru", "phone": "+70525585135"}
0005433101388	724CA8	1126 039601	YURIY MOROZOV	{"email": "morozov-yuriy081966@postgrespro.ru", "phone": "+70972086396"}
0005433101389	AEE134	4698 179735	NIKITA POPOV	{"phone": "+70347307883"}
0005433101390	AEE134	9684 174343	ALEKSANDR KRASNOV	{"phone": "+70496846396"}
0005433101391	F32C0B	1185 930080	NATALYA MARTYNOVA	{"email": "natalyamartynova13071956@postgrespro.ru", "phone": "+70433017216"}
0005433101392	EF1841	8694 263999	PAVEL NOVIKOV	{"phone": "+70581260520"}
0005433101393	EF1841	5966 274757	SERGEY PAVLOV	{"phone": "+70082268002"}
0005433101394	EF1841	9169 384057	VASILIY PETROV	{"email": "vasiliy_petrov02021968@postgrespro.ru", "phone": "+70381707126"}
0005433101395	B42B7C	9717 843651	ALEKSEY ZHUKOV	{"email": "a-zhukov-1976@postgrespro.ru", "phone": "+70036426067"}
0005433101396	3883F3	2318 762164	VASILIY VASILEV	{"phone": "+70771911040"}
0005433101397	3883F3	8487 950804	GALIYA KRASNOVA	{"email": "krasnova-galiya.101970@postgrespro.ru", "phone": "+70059906987"}
0005433101398	270FA8	4152 875834	TATYANA POPOVA	{"email": "popovat.1977@postgrespro.ru", "phone": "+70537469270"}
0005433101399	270FA8	5709 020479	RENAT NIKOLAEV	{"phone": "+70949614469"}
0005433101400	FE4077	3801 384311	VYACHESLAV VASILEV	{"phone": "+70632242128"}
0005433101401	2457B2	4500 965175	ZINAIDA VOROBEVA	{"email": "vorobeva-zinaida_061985@postgrespro.ru", "phone": "+70200668364"}
0005433101680	5B7ACF	7772 341389	VALENTINA KRASNOVA	{"phone": "+70629344514"}
0005433101402	2457B2	1660 213772	VALENTINA NOVIKOVA	{"email": "novikova.valentina-04011972@postgrespro.ru", "phone": "+70562880804"}
0005433101403	81CC39	8812 236208	OLGA NIKOLAEVA	{"email": "nikolaeva.olga01081970@postgrespro.ru", "phone": "+70780416361"}
0005433101404	A2DEC9	8329 474596	RUSLAN ALEKSEEV	{"email": "alekseevruslan14121977@postgrespro.ru", "phone": "+70306766601"}
0005433101405	25E6EE	5487 223168	VALERIY SOROKIN	{"email": "v-sorokin-18081957@postgrespro.ru", "phone": "+70341654334"}
0005433101406	B917B1	2254 693578	KRISTINA MOROZOVA	{"email": "morozova.k031973@postgrespro.ru", "phone": "+70955534096"}
0005433101407	B0F544	9720 732705	EKATERINA LAZAREVA	{"phone": "+70610558030"}
0005433101408	D33C33	2215 043757	NIKOLAY KUZNECOV	{"phone": "+70989841218"}
0005433101409	602647	8471 895852	LYUBOV PETROVA	{"phone": "+70924098483"}
0005433101410	1D11EA	9842 976726	ANASTASIYA ARKHIPOVA	{"email": "arkhipova.a-1963@postgrespro.ru", "phone": "+70977311896"}
0005433101411	457A20	8960 591648	LYUBOV MAKSIMOVA	{"email": "maksimova-l-07101968@postgrespro.ru", "phone": "+70300395252"}
0005433101412	41DB49	1208 551504	NIKOLAY TARASOV	{"phone": "+70566514679"}
0005433101413	EDD1F5	6321 833901	VLADIMIR MAKAROV	{"phone": "+70711144927"}
0005433101414	AFE444	2407 713041	ALEKSANDR ANDREEV	{"phone": "+70907648900"}
0005433101415	AFE444	4756 900704	ALENA EGOROVA	{"phone": "+70777199827"}
0005433101416	2024DD	2245 981216	IRINA POTAPOVA	{"phone": "+70343842029"}
0005433101417	2024DD	7963 321369	RAISA KALININA	{"email": "r.kalinina18061975@postgrespro.ru", "phone": "+70080971968"}
0005433101418	22A23D	6209 602328	DENIS ABRAMOV	{"email": "abramov_d25071975@postgrespro.ru", "phone": "+70113614483"}
0005433101419	794522	3854 745833	VSEVOLOD SCHERBAKOV	{"email": "v-scherbakov_021982@postgrespro.ru", "phone": "+70938187121"}
0005433101420	794522	6023 995454	ZOYA VASILEVA	{"email": "zoyavasileva.1982@postgrespro.ru", "phone": "+70041322696"}
0005433101421	F18762	7227 778913	GENNADIY IVANOV	{"phone": "+70766070272"}
0005433101422	F18762	6179 213276	ELENA KISELEVA	{"phone": "+70776551252"}
0005433101423	FD8225	1808 610185	LEONID GAVRILOV	{"phone": "+70436496262"}
0005433101424	74BB56	5801 560474	SERGEY EGOROV	{"email": "s-egorov-18041967@postgrespro.ru", "phone": "+70595935000"}
0005433101425	6366F5	6819 285036	ANNA ANTONOVA	{"email": "anna.antonova-111979@postgrespro.ru", "phone": "+70671842564"}
0005433101426	6366F5	4620 973615	LYUBOV TARASOVA	{"phone": "+70989334838"}
0005433101427	10449E	4049 478768	MIKHAIL VOLKOV	{"email": "volkov_mikhail-051975@postgrespro.ru", "phone": "+70196239832"}
0005433101428	BAAA57	0105 615690	NATALYA ZAKHAROVA	{"email": "zakharova_n061990@postgrespro.ru", "phone": "+70412025013"}
0005433101429	57CA9D	9497 921845	PAVEL ILIN	{"phone": "+70514753267"}
0005433101430	7F091B	7520 271042	RAISA POLYAKOVA	{"email": "r-polyakova.021960@postgrespro.ru", "phone": "+70055947930"}
0005433101431	9F0C1F	9864 261638	DMITRIY RODIONOV	{"email": "rodionov_dmitriy.1979@postgrespro.ru", "phone": "+70463793547"}
0005433101432	B40A4B	6693 679236	ANDREY KARPOV	{"email": "karpova28041961@postgrespro.ru", "phone": "+70926351238"}
0005433101612	41BFF6	2894 581975	LYUDMILA ROMANOVA	{"phone": "+70662697790"}
0005433101433	D1C4CF	5105 427902	SOFYA RODIONOVA	{"email": "rodionova_s_061966@postgrespro.ru", "phone": "+70760763369"}
0005433101434	B41C0A	4048 771817	MARIYA FROLOVA	{"phone": "+70862669624"}
0005433101435	B41C0A	0263 114213	EVGENIY GAVRILOV	{"email": "e-gavrilov.09011977@postgrespro.ru", "phone": "+70725335407"}
0005433101436	9BB938	8628 758324	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v-1978@postgrespro.ru", "phone": "+70522620793"}
0005433101437	9BB938	7452 027009	ANATOLIY KISELEV	{"phone": "+70001277697"}
0005433101438	3249E1	1631 305465	ALEVTINA BELYAEVA	{"email": "belyaeva_alevtina.1973@postgrespro.ru", "phone": "+70431566736"}
0005433101439	3249E1	3399 366900	POLINA STEPANOVA	{"phone": "+70615896193"}
0005433101440	53775C	6968 483675	VERA GUSEVA	{"email": "v.guseva12061976@postgrespro.ru", "phone": "+70366654558"}
0005433101441	4C9428	9452 861774	TATYANA ZHUKOVA	{"phone": "+70649611823"}
0005433101442	79357F	2076 804242	ALEKSANDR VASILEV	{"phone": "+70685092288"}
0005433101443	1DC5FC	5643 095808	VERA MIKHAYLOVA	{"email": "vera-mikhaylova18111973@postgrespro.ru", "phone": "+70200841195"}
0005433101444	59CEC4	9948 661468	ELENA NIKIFOROVA	{"email": "nikiforova-elena.1959@postgrespro.ru", "phone": "+70825870616"}
0005433101445	59CEC4	0828 886783	ALEKSANDR IVANOV	{"email": "aivanov-021981@postgrespro.ru", "phone": "+70854545535"}
0005433101446	4B4A92	5249 267394	STEPAN MARTYNOV	{"email": "martynov_s_081969@postgrespro.ru", "phone": "+70393291499"}
0005433101447	49C809	6513 345176	TATYANA ROMANOVA	{"email": "tatyanaromanova16061959@postgrespro.ru", "phone": "+70252329425"}
0005433101448	49C809	8737 474955	EVGENIY ALEKSEEV	{"phone": "+70949311722"}
0005433101449	9DFC7D	5306 809853	ALEKSANDR KUZNECOV	{"phone": "+70444659803"}
0005433101450	9DFC7D	3197 885741	SERGEY OSIPOV	{"email": "sergey.osipov-16031967@postgrespro.ru", "phone": "+70003103894"}
0005433101451	9DFC7D	8869 281609	OKSANA CHERNOVA	{"email": "chernova_oksana-15031970@postgrespro.ru", "phone": "+70345158202"}
0005433101452	013127	7409 323019	SEMEN YAKOVLEV	{"email": "yakovlev.s09091976@postgrespro.ru", "phone": "+70000650569"}
0005433101453	36ADF2	6189 445251	YULIYA FOMINA	{"phone": "+70002635164"}
0005433101454	253D91	7831 414272	ELENA FROLOVA	{"phone": "+70984825793"}
0005433101455	0BA577	1131 052500	VLADIMIR AFANASEV	{"email": "afanasev.v_1962@postgrespro.ru", "phone": "+70354315525"}
0005433101456	0BA577	6505 991484	LARISA ORLOVA	{"email": "larisa-orlova-03021967@postgrespro.ru", "phone": "+70565748450"}
0005433101458	640E88	9454 217293	NATALYA AKIMOVA	{"email": "nakimova_1976@postgrespro.ru", "phone": "+70723951004"}
0005433101459	48998B	4273 687788	DMITRIY YAKOVLEV	{"phone": "+70140273984"}
0005433101460	48998B	5874 996236	YURIY TIKHONOV	{"email": "tikhonovy1979@postgrespro.ru", "phone": "+70499813463"}
0005433101461	97D3BB	0261 257460	ALEKSANDR SEMENOV	{"phone": "+70506409270"}
0005433101462	04703D	5462 387888	ELENA BELYAEVA	{"email": "elenabelyaeva-121972@postgrespro.ru", "phone": "+70531070341"}
0005433101463	33EE30	6545 269372	YURIY KOZLOV	{"email": "kozlov.yuriy.04081961@postgrespro.ru", "phone": "+70542708775"}
0005433101464	819567	8724 065833	ANASTASIYA ANDREEVA	{"email": "anastasiya-andreeva.1959@postgrespro.ru", "phone": "+70519355238"}
0005433101465	3D57C8	0807 025534	ALEKSEY PAVLOV	{"phone": "+70372445869"}
0005433101466	2610D8	7719 749115	LARISA MAKAROVA	{"phone": "+70313662151"}
0005433101467	2443A6	2877 239895	IVAN FILIPPOV	{"phone": "+70028562251"}
0005433101468	2443A6	2804 073344	VERA NIKIFOROVA	{"phone": "+70996724491"}
0005433101469	938355	0052 792967	DIANA FEDOROVA	{"phone": "+70023995125"}
0005433101470	938355	5963 039654	EKATERINA MOROZOVA	{"email": "morozova.e.1982@postgrespro.ru", "phone": "+70755088157"}
0005433101471	836CEC	1114 566268	ANATOLIY MOROZOV	{"email": "morozov-a08031966@postgrespro.ru", "phone": "+70421948008"}
0005433101472	4CD52E	5196 046947	ARTEM NAUMOV	{"phone": "+70459937814"}
0005433101473	FA3625	8725 470883	OLGA OSIPOVA	{"email": "osipova.olga.1984@postgrespro.ru", "phone": "+70765755123"}
0005433101474	5E0512	6979 079993	DMITRIY GAVRILOV	{"phone": "+70086301246"}
0005433101475	5E0512	7484 242688	OKSANA PETROVA	{"phone": "+70773845873"}
0005433101476	A43037	5262 538604	IGOR FOMIN	{"email": "igor.fomin061967@postgrespro.ru", "phone": "+70208961968"}
0005433101477	63D532	6699 444560	EVGENIY NOVIKOV	{"phone": "+70022797934"}
0005433101478	F7082C	5729 686565	IGOR BELOV	{"email": "igor_belov.21071960@postgrespro.ru", "phone": "+70066448275"}
0005433101479	9A0507	2075 161724	SVETLANA NESTEROVA	{"email": "s_nesterova121975@postgrespro.ru", "phone": "+70882511739"}
0005433101480	6852CB	6533 240441	MIKHAIL POPOV	{"email": "popov_m_1970@postgrespro.ru", "phone": "+70344309642"}
0005433101481	6852CB	9269 422714	VERONIKA NIKITINA	{"phone": "+70219588730"}
0005433101482	B27A4D	4164 046091	ALEKSANDRA MALYSHEVA	{"phone": "+70611647429"}
0005433101483	B27A4D	2945 497454	OLEG SERGEEV	{"phone": "+70510577233"}
0005433101484	8601BE	9482 804480	MARINA ANISIMOVA	{"email": "marina.anisimova_011965@postgrespro.ru", "phone": "+70724509584"}
0005433101485	382CF1	4520 749478	ALENA ZOTOVA	{"phone": "+70998076822"}
0005433101486	8003FC	0131 036697	PAVEL KUZMIN	{"email": "p-kuzmin1958@postgrespro.ru", "phone": "+70935923920"}
0005433101487	5C4B54	2747 888652	SERGEY ZHURAVLEV	{"phone": "+70780642960"}
0005433101488	5C4B54	6973 351562	ANGELINA TIKHONOVA	{"phone": "+70668389914"}
0005433101489	78EDDC	5522 072018	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov_101972@postgrespro.ru", "phone": "+70797384108"}
0005433101490	78EDDC	6410 161156	GALINA GORBUNOVA	{"email": "g.gorbunova.111971@postgrespro.ru", "phone": "+70804323478"}
0005433101491	F01EF3	3904 927261	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr-27061978@postgrespro.ru", "phone": "+70377319150"}
0005433101492	872A97	5987 624332	ALEKSEY DENISOV	{"email": "a.denisov.1958@postgrespro.ru", "phone": "+70113389010"}
0005433101493	C08563	4586 564567	OLGA BELOVA	{"phone": "+70762251099"}
0005433101494	00F26A	9660 471888	DENIS FILIPPOV	{"email": "denis.filippov041962@postgrespro.ru", "phone": "+70785373529"}
0005433101495	4F97A3	1974 306567	MARGARITA LOGINOVA	{"phone": "+70272909892"}
0005433101496	7C6F20	7929 304213	EVGENIYA FEDOROVA	{"phone": "+70575150722"}
0005433101497	C47D68	1522 123967	SOFYA MELNIKOVA	{"phone": "+70544946395"}
0005433101498	C47D68	4893 166364	EVGENIY SAVELEV	{"email": "savelev.e1965@postgrespro.ru", "phone": "+70968264272"}
0005433101499	FDCCB4	9398 689786	DMITRIY VASILEV	{"phone": "+70377499997"}
0005433101500	1DC107	4536 760493	IRINA KOROLEVA	{"email": "korolevairina_071977@postgrespro.ru", "phone": "+70830208944"}
0005433101501	1DC107	2656 471210	ALEKSEY VOLKOV	{"email": "volkov_aleksey09041971@postgrespro.ru", "phone": "+70875610549"}
0005433101502	B3F5E4	2342 593030	RUSLAN KISELEV	{"phone": "+70139454078"}
0005433101503	C61171	1428 122080	RAISA VOROBEVA	{"email": "raisa-vorobeva.1970@postgrespro.ru", "phone": "+70337285091"}
0005433101504	C61171	8542 624876	KRISTINA ORLOVA	{"email": "orlova.k-1962@postgrespro.ru", "phone": "+70849176654"}
0005433101505	3B09D6	9967 565907	DINA KOVALEVA	{"phone": "+70574913215"}
0005433101506	8837BE	1949 772885	VALERIY TIKHONOV	{"email": "v_tikhonov_051972@postgrespro.ru", "phone": "+70856684716"}
0005433101507	7507F0	8281 660987	MARK FILIPPOV	{"email": "filippov.mark_1965@postgrespro.ru", "phone": "+70665964624"}
0005433101508	7507F0	4841 941331	ALEKSEY SMIRNOV	{"email": "smirnov-aleksey-1967@postgrespro.ru", "phone": "+70355558054"}
0005433101509	AB9D00	2713 282352	VYACHESLAV CHERNOV	{"email": "chernov_vyacheslav-091983@postgrespro.ru", "phone": "+70086377299"}
0005433101510	AB9D00	3850 336352	VALENTINA SIDOROVA	{"email": "sidorova.valentina-1976@postgrespro.ru", "phone": "+70250267523"}
0005433101511	008E62	7599 695576	VYACHESLAV BONDARENKO	{"phone": "+70423937238"}
0005433101512	7A04B5	9958 173701	ALFIYA VOROBEVA	{"phone": "+70053281423"}
0005433101513	7A04B5	7265 922521	ELENA ANDREEVA	{"phone": "+70861489641"}
0005433101514	7A04B5	0043 205090	NATALYA ALEKSEEVA	{"email": "alekseeva-natalya.1975@postgrespro.ru", "phone": "+70442112263"}
0005433101515	053CDB	0437 332442	ARTEM PETROV	{"phone": "+70601117690"}
0005433101516	053CDB	1764 953405	OLGA IVANOVA	{"email": "ivanovaolga1972@postgrespro.ru", "phone": "+70943118592"}
0005433101517	93AA0D	9133 305112	ELENA KUZNECOVA	{"email": "e.kuznecova-091967@postgrespro.ru", "phone": "+70460336465"}
0005433101518	93AA0D	5744 563302	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova.1973@postgrespro.ru", "phone": "+70387096528"}
0005433101519	830F06	0839 163304	ZINAIDA RYABOVA	{"email": "zryabova.19091975@postgrespro.ru", "phone": "+70246268978"}
0005433101520	8FB50E	6403 056247	EKATERINA POPOVA	{"phone": "+70488950149"}
0005433101521	11D142	5524 167063	MARIYA TIKHONOVA	{"email": "m_tikhonova-041978@postgrespro.ru", "phone": "+70867108787"}
0005433101522	E85EEA	9649 594314	VASILIY EGOROV	{"email": "vasiliyegorov-1971@postgrespro.ru", "phone": "+70373619307"}
0005433101523	805D6B	3633 024295	SVETLANA LAZAREVA	{"email": "lazarevasvetlana_041975@postgrespro.ru", "phone": "+70152439818"}
0005433101524	AE01EF	8819 464592	YULIYA VLASOVA	{"phone": "+70593401512"}
0005433101525	924F07	0619 977653	GALINA KISELEVA	{"phone": "+70780514278"}
0005433101526	468E23	4821 708347	ALENA FILATOVA	{"email": "filatova_a111961@postgrespro.ru", "phone": "+70756861736"}
0005433101527	526215	6125 682815	ANTONINA NAZAROVA	{"email": "antonina-nazarova021972@postgrespro.ru", "phone": "+70229896845"}
0005433101528	8242BE	1897 386359	GRIGORIY SOROKIN	{"email": "grigoriy-sorokin.011985@postgrespro.ru", "phone": "+70908325598"}
0005433101529	6DACB7	2871 162074	ANTONIDA ORLOVA	{"email": "orlova-a_1964@postgrespro.ru", "phone": "+70542470572"}
0005433101530	6DACB7	9093 850684	NAILYA NAZAROVA	{"phone": "+70302340177"}
0005433101531	F7F8C2	3671 165420	PETR TIKHONOV	{"email": "tikhonov-p.08071981@postgrespro.ru", "phone": "+70861807870"}
0005433101532	03BB6A	3926 755080	VITALIY KOZLOV	{"phone": "+70277681077"}
0005433101533	03BB6A	9650 558202	NIKOLAY MIKHAYLOV	{"phone": "+70398494325"}
0005433101534	D4B383	2337 736830	LILIYA KOROLEVA	{"email": "liliya-koroleva.1980@postgrespro.ru", "phone": "+70500614360"}
0005433101535	706CE3	4951 625324	TATYANA RODIONOVA	{"email": "rodionova.t061967@postgrespro.ru", "phone": "+70104838360"}
0005433101536	706CE3	6842 805028	SERGEY ISAEV	{"email": "s-isaev.081959@postgrespro.ru", "phone": "+70306574912"}
0005433101537	C4FD5C	8064 217829	RUSLAN GRIGOREV	{"phone": "+70631758886"}
0005433101538	C4FD5C	1349 053414	OLEG ZAKHAROV	{"email": "oleg-zakharov24011957@postgrespro.ru", "phone": "+70395049855"}
0005433101539	F7FE2D	3836 936329	ALLA ZAYCEVA	{"phone": "+70712706911"}
0005433101540	F7FE2D	1776 107087	VALENTIN SOLOVEV	{"phone": "+70056145262"}
0005433101541	547751	9806 318799	ROMAN MARTYNOV	{"phone": "+70367285259"}
0005433101542	547751	6612 171837	ANNA GUSEVA	{"email": "anna.guseva-021967@postgrespro.ru", "phone": "+70782295269"}
0005433101543	547751	6097 420736	ANDREY SERGEEV	{"email": "a.sergeev-051977@postgrespro.ru", "phone": "+70477118654"}
0005433101544	18B2EB	7741 453779	SVETLANA DENISOVA	{"phone": "+70794831664"}
0005433101545	243FD8	0585 335646	IGOR NIKITIN	{"email": "nikitin.igor1961@postgrespro.ru", "phone": "+70667302737"}
0005433101546	8B88B4	4946 528492	LYUDMILA FILIPPOVA	{"email": "lfilippova06061967@postgrespro.ru", "phone": "+70120327084"}
0005433101547	6FEA1C	4681 121822	MARIYA KOVALEVA	{"phone": "+70796341710"}
0005433101548	6FEA1C	6349 805697	ANNA FADEEVA	{"phone": "+70345343026"}
0005433101549	327A4C	1528 285139	ANASTASIYA FOMINA	{"phone": "+70516062922"}
0005433101550	E3F0DD	4686 542641	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr.1975@postgrespro.ru", "phone": "+70077705891"}
0005433101551	94BB46	6641 721624	VLADIMIR MIRONOV	{"phone": "+70534396923"}
0005433101552	94E528	0360 610532	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr.17041966@postgrespro.ru", "phone": "+70778556400"}
0005433101553	C52B44	0366 098309	ANDREY SOROKIN	{"email": "sorokin-a081975@postgrespro.ru", "phone": "+70659397898"}
0005433101554	53109A	8939 074203	OLGA MEDVEDEVA	{"email": "olgamedvedeva-11111976@postgrespro.ru", "phone": "+70148631198"}
0005433101555	528CE2	7620 914976	TATYANA STEPANOVA	{"email": "tatyana-stepanova-04081978@postgrespro.ru", "phone": "+70310171176"}
0005433101556	65DFB8	5768 646858	LYUDMILA ANTONOVA	{"phone": "+70974503238"}
0005433101557	5AFDAC	1392 367454	TATYANA KUDRYASHOVA	{"email": "t_kudryashova.071969@postgrespro.ru", "phone": "+70994430784"}
0005433101558	392CBE	6893 516981	TATYANA ABRAMOVA	{"email": "abramova.t_1975@postgrespro.ru", "phone": "+70402546473"}
0005433101559	606EE3	3028 430006	ELENA PAVLOVA	{"phone": "+70298820049"}
0005433101560	606EE3	0583 637489	ANTON EGOROV	{"phone": "+70523832326"}
0005433101561	606EE3	0515 691937	FEDOR NOVIKOV	{"phone": "+70432705153"}
0005433101562	1D8FAC	0698 394024	NATALYA MIKHAYLOVA	{"phone": "+70140950347"}
0005433101563	0AE4C8	4808 736813	BORIS VASILEV	{"email": "borisvasilev011990@postgrespro.ru", "phone": "+70371591954"}
0005433101564	EF4610	6719 118201	TATYANA AFANASEVA	{"phone": "+70858690559"}
0005433101565	EF4610	9787 566429	VALERIY BORISOV	{"email": "borisov_valeriy-17031975@postgrespro.ru", "phone": "+70576845065"}
0005433101566	C66175	0334 297308	VALERIYA PETROVA	{"phone": "+70810168343"}
0005433101567	C66175	5339 240049	DAVID ABRAMOV	{"email": "abramov-david.111975@postgrespro.ru", "phone": "+70483401013"}
0005433101568	A2F9F5	1188 029250	ALINA ORLOVA	{"phone": "+70996288769"}
0005433101960	16C536	0236 733520	ALEKSEY NIKOLAEV	{"phone": "+70781473257"}
0005433101569	2A7947	4400 569105	SVETLANA TIKHONOVA	{"email": "svetlanatikhonova-1968@postgrespro.ru", "phone": "+70295414703"}
0005433101570	2A7947	7876 864729	NINA KOZLOVA	{"email": "kozlova-n02071973@postgrespro.ru", "phone": "+70237492916"}
0005433101571	2A7947	6766 664035	LYUBOV ZOTOVA	{"email": "zotova.lyubov1974@postgrespro.ru", "phone": "+70637972021"}
0005433101572	E7604C	7406 057431	TAISIYA IVANOVA	{"email": "taisiya_ivanova.10091963@postgrespro.ru", "phone": "+70263230522"}
0005433101573	1EE4BD	5986 132750	TAMARA SEMENOVA	{"email": "tamarasemenova_101973@postgrespro.ru", "phone": "+70459153948"}
0005433101574	654C14	6528 254544	NURLAN ILIN	{"email": "ilin-n_1968@postgrespro.ru", "phone": "+70512709494"}
0005433101575	AB5526	0130 206420	LEONID ORLOV	{"email": "orlov_leonid_011983@postgrespro.ru", "phone": "+70605462752"}
0005433101576	AB5526	8946 862884	BORIS FEDOROV	{"email": "boris-fedorov.30101974@postgrespro.ru", "phone": "+70216136585"}
0005433101577	6F475A	8039 276769	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena_1983@postgrespro.ru", "phone": "+70265078681"}
0005433101578	6F475A	3651 111509	DMITRIY NIKOLAEV	{"phone": "+70218244263"}
0005433101579	221ECC	9278 902110	TATYANA ANDREEVA	{"email": "tatyana-andreeva-061963@postgrespro.ru", "phone": "+70730585796"}
0005433101580	221ECC	6261 949911	PAVEL NAUMOV	{"phone": "+70198753954"}
0005433101581	32BFC2	5133 298690	KRISTINA DENISOVA	{"phone": "+70535286964"}
0005433101582	DFC363	4013 775281	ANNA TIKHONOVA	{"phone": "+70339970844"}
0005433101583	EC1403	2448 093148	ANASTASIYA KISELEVA	{"email": "a_kiseleva-21011977@postgrespro.ru", "phone": "+70466187465"}
0005433101584	53D67C	6042 641712	TATYANA KONOVALOVA	{"phone": "+70475174550"}
0005433101585	53D67C	1453 330366	OLGA NIKITINA	{"email": "onikitina-02111969@postgrespro.ru", "phone": "+70712062461"}
0005433101586	1B8E16	1488 677923	ANASTASIYA NIKITINA	{"email": "nikitinaa071968@postgrespro.ru", "phone": "+70167858248"}
0005433101587	50AA92	5576 817794	RUSLAN KAZAKOV	{"email": "kazakov.ruslan_1974@postgrespro.ru", "phone": "+70678269364"}
0005433101588	50AA92	9157 618370	LIDIYA FILATOVA	{"phone": "+70897098766"}
0005433101589	2D2CB4	0558 882572	ILYA TARASOV	{"email": "ilyatarasov_1973@postgrespro.ru", "phone": "+70055467430"}
0005433101590	ECD83B	0880 714610	ELENA BOGDANOVA	{"phone": "+70095995006"}
0005433101591	69B2A5	5434 594313	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov_03121983@postgrespro.ru", "phone": "+70715108937"}
0005433101592	84C4CC	2337 858828	NIKOLAY FOMIN	{"email": "nikolay_fomin-14121964@postgrespro.ru", "phone": "+70652443000"}
0005433101593	474BCF	7380 804686	DANIIL GRIGOREV	{"phone": "+70268170532"}
0005433101594	C7A5DD	6846 441637	DIANA CHERNOVA	{"phone": "+70777201944"}
0005433101595	C7A5DD	9105 506271	DANIIL KUZNECOV	{"email": "d.kuznecov-081970@postgrespro.ru", "phone": "+70775111415"}
0005433101596	080882	1107 388591	NIKOLAY FILIPPOV	{"email": "filippov-n24011978@postgrespro.ru", "phone": "+70662106528"}
0005433101597	F8BF54	0952 656734	YULIYA YAKOVLEVA	{"email": "yuliya_yakovleva-1985@postgrespro.ru", "phone": "+70703881394"}
0005433101598	F8BF54	3366 330072	ALEKSANDR ZHURAVLEV	{"email": "aleksandrzhuravlev.121972@postgrespro.ru", "phone": "+70216402678"}
0005433101599	A0C0C2	7871 297662	IRINA KOVALEVA	{"phone": "+70647461673"}
0005433101600	3F0D99	8065 869937	YANA EGOROVA	{"phone": "+70749846649"}
0005433101601	C498F2	4370 947951	YURIY DENISOV	{"phone": "+70412877098"}
0005433101602	808CF2	4809 868740	ANDREY ANDREEV	{"phone": "+70082017211"}
0005433101603	C0E467	4581 589985	ALEKSANDR MELNIKOV	{"phone": "+70786800134"}
0005433101604	97FDEC	8001 632052	ILYA SIDOROV	{"email": "ilya-sidorov-011976@postgrespro.ru", "phone": "+70196128226"}
0005433101605	33F5A5	5968 149809	SERGEY AFANASEV	{"email": "s_afanasev_1971@postgrespro.ru", "phone": "+70205366788"}
0005433101606	33F5A5	9999 872539	MIKHAIL TARASOV	{"phone": "+70076541473"}
0005433101607	7118E8	8224 427057	VIKTORIYA DMITRIEVA	{"email": "dmitrievav-22041971@postgrespro.ru", "phone": "+70725847779"}
0005433101608	D22921	4325 794426	DMITRIY VOROBEV	{"email": "d_vorobev_061975@postgrespro.ru", "phone": "+70233099324"}
0005433101609	D22921	1705 224083	ALEKSANDR MIKHAYLOV	{"phone": "+70406605166"}
0005433101610	E74F3E	6258 204567	DMITRIY POPOV	{"email": "dmitriy.popov_11041974@postgrespro.ru", "phone": "+70490520548"}
0005433101613	41BFF6	3755 640142	GEVORG ALEKSANDROV	{"email": "aleksandrov_gevorg_29031984@postgrespro.ru", "phone": "+70409700708"}
0005433101614	A9D64F	7370 928302	LYUDMILA SERGEEVA	{"email": "l.sergeeva_12071983@postgrespro.ru", "phone": "+70520137282"}
0005433101615	5F024C	0308 838388	LYUDMILA ARKHIPOVA	{"phone": "+70469754483"}
0005433101616	0FBCEB	5240 289662	GALINA ANDREEVA	{"email": "andreeva-galina.071973@postgrespro.ru", "phone": "+70933503050"}
0005433101617	0FBCEB	3742 461794	VADIM POPOV	{"phone": "+70481900185"}
0005433101618	5EAC82	3693 919673	EVGENIY DENISOV	{"email": "evgeniy_denisov_1978@postgrespro.ru", "phone": "+70563155375"}
0005433101619	B6F45B	6857 378868	NADEZHDA ANTONOVA	{"email": "n.antonova051970@postgrespro.ru", "phone": "+70009280758"}
0005433101620	68105A	1728 317635	ALEKSANDRA KOROLEVA	{"phone": "+70299290474"}
0005433101621	68105A	9276 293391	VALENTIN SERGEEV	{"phone": "+70206325706"}
0005433101622	CB9931	2683 859502	MARGARITA NIKITINA	{"email": "m.nikitina_1978@postgrespro.ru", "phone": "+70390158461"}
0005433101623	1AFA8D	7348 997084	SERGEY MELNIKOV	{"phone": "+70367485403"}
0005433101624	A4132E	7887 566279	ANTONINA MIRONOVA	{"email": "amironova_03071982@postgrespro.ru", "phone": "+70566471261"}
0005433101625	34A637	1537 567458	ALEKSANDR KUDRYASHOV	{"email": "kudryashovaleksandr.1971@postgrespro.ru", "phone": "+70606479619"}
0005433101626	31EC80	5264 407227	MARIYA VASILEVA	{"email": "vasileva_mariya-10051978@postgrespro.ru", "phone": "+70611544219"}
0005433101627	31EC80	3311 901554	GEORGIY KUZMIN	{"email": "georgiykuzmin.1968@postgrespro.ru", "phone": "+70746836932"}
0005433101628	4248F5	9162 947152	ARTEM SEMENOV	{"phone": "+70428611275"}
0005433101629	4248F5	9945 495230	LIDIYA VLASOVA	{"phone": "+70748134176"}
0005433101630	A24CE3	6708 008146	IREK SHEVCHENKO	{"phone": "+70828354074"}
0005433101631	A24CE3	2267 755116	YANA KISELEVA	{"phone": "+70835187942"}
0005433101632	A24CE3	5216 975287	DMITRIY MOROZOV	{"email": "morozov_d-1978@postgrespro.ru", "phone": "+70983843027"}
0005433101633	65B7AB	9378 480229	TATYANA NIKOLAEVA	{"phone": "+70404945170"}
0005433101634	439F90	4662 273183	ANNA OVCHINNIKOVA	{"phone": "+70570254114"}
0005433101635	F9542B	8822 048094	SVETLANA KARPOVA	{"phone": "+70921065793"}
0005433101636	17D50B	7475 648833	ARSENIY GAVRILOV	{"email": "arseniy-gavrilov-1975@postgrespro.ru", "phone": "+70714447243"}
0005433101637	17D50B	5559 215763	VLADIMIR KRASNOV	{"phone": "+70169590739"}
0005433101638	D09572	5045 747543	NIKOLAY FOMIN	{"phone": "+70852115591"}
0005433101639	B61918	0597 866875	VIKTOR ZHUKOV	{"phone": "+70628453717"}
0005433101640	62956D	9288 183727	ALISA IVANOVA	{"email": "alisa_ivanova091961@postgrespro.ru", "phone": "+70622200189"}
0005433101641	66C66D	4032 798752	VASILIY KUZNECOV	{"email": "v-kuznecov_061992@postgrespro.ru", "phone": "+70100287835"}
0005433101642	92309C	3829 372195	YANINA KOLESNIKOVA	{"email": "yanina-kolesnikova-28111974@postgrespro.ru", "phone": "+70446298226"}
0005433101643	92309C	4622 847064	ALEKSANDRA KRASNOVA	{"phone": "+70443672797"}
0005433101644	3C02FA	0539 203519	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov.1978@postgrespro.ru", "phone": "+70043496372"}
0005433101645	1F4DFE	9647 396806	IVAN MOROZOV	{"email": "ivanmorozov_1964@postgrespro.ru", "phone": "+70969225954"}
0005433101646	E12345	3112 336887	EKATERINA KUZNECOVA	{"phone": "+70285397993"}
0005433101647	C4642D	7977 535866	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaaleksandra.09111980@postgrespro.ru", "phone": "+70733909110"}
0005433101648	C4642D	3764 841428	IGOR GORBUNOV	{"phone": "+70618880463"}
0005433101649	D71CFB	4819 000106	NIKOLAY BELOV	{"email": "belov-nikolay1982@postgrespro.ru", "phone": "+70677537023"}
0005433101650	D71CFB	3856 838134	NIKOLAY KARPOV	{"email": "n_karpov.101969@postgrespro.ru", "phone": "+70544211187"}
0005433101651	909650	9404 993414	TATYANA KUZNECOVA	{"phone": "+70259790155"}
0005433101652	C1E6CC	7004 655760	RADIK TIMOFEEV	{"phone": "+70587862602"}
0005433101653	8173A4	9760 939003	ALENA GAVRILOVA	{"phone": "+70380260359"}
0005433101654	323D58	0759 362843	OLGA AKIMOVA	{"phone": "+70420806730"}
0005433101655	323D58	9189 073137	SOFYA KOVALEVA	{"phone": "+70376776394"}
0005433101656	C02D86	3737 665933	NADEZHDA SAVELEVA	{"phone": "+70688104563"}
0005433101657	C02D86	1328 063481	SERGEY SCHERBAKOV	{"email": "scherbakov_s22111975@postgrespro.ru", "phone": "+70983015111"}
0005433101658	6F91EC	1858 009064	NATALYA IVANOVA	{"email": "ivanova.n_081967@postgrespro.ru", "phone": "+70630692570"}
0005433101659	075B3B	5274 914644	NATALYA IVANOVA	{"email": "natalya_ivanova-071972@postgrespro.ru", "phone": "+70149867843"}
0005433101660	075B3B	7938 495876	DMITRIY ORLOV	{"email": "d-orlov-041977@postgrespro.ru", "phone": "+70191607727"}
0005433101661	075B3B	1052 699306	ANASTASIYA MARTYNOVA	{"email": "martynova.a.011964@postgrespro.ru", "phone": "+70169469790"}
0005433101662	FD089F	6825 482723	YULIYA NAZAROVA	{"email": "y-nazarova-051980@postgrespro.ru", "phone": "+70934468887"}
0005433101663	FD089F	8836 864583	DMITRIY FOMIN	{"phone": "+70767124801"}
0005433101664	FD089F	7788 860531	GALINA YUDINA	{"email": "g-yudina-28011965@postgrespro.ru", "phone": "+70428419132"}
0005433101665	573E38	2751 472971	OLGA ALEKSANDROVA	{"phone": "+70652793333"}
0005433101666	A76029	5182 406571	OLEG RODIONOV	{"phone": "+70223761729"}
0005433101667	A76029	6337 760806	MATVEY STEPANOV	{"phone": "+70487302674"}
0005433101668	A76029	8449 390659	KONSTANTIN GAVRILOV	{"email": "konstantingavrilov_1971@postgrespro.ru", "phone": "+70043793206"}
0005433101669	847FA6	4843 401856	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr_1966@postgrespro.ru", "phone": "+70675637761"}
0005433101670	08EBAD	4438 149166	ALENA ARKHIPOVA	{"phone": "+70302012784"}
0005433101671	9E3347	0145 734586	ELENA BORISOVA	{"phone": "+70124988867"}
0005433101672	E671A6	4271 427910	VIKTOR PAVLOV	{"email": "pavlov-viktor_091969@postgrespro.ru", "phone": "+70177443842"}
0005433101673	65450A	4248 792497	OLGA GERASIMOVA	{"phone": "+70295656954"}
0005433101674	49A347	3598 838756	ANDREY FOMIN	{"email": "fomina.27111975@postgrespro.ru", "phone": "+70093736280"}
0005433101675	3E9EDC	2171 562561	DMITRIY GUSEV	{"email": "d_gusev.071965@postgrespro.ru", "phone": "+70192385670"}
0005433101676	3E9EDC	0398 399506	SERGEY BORISOV	{"phone": "+70039354756"}
0005433101677	78605F	8967 147970	VLADIMIR IVANOV	{"phone": "+70388794845"}
0005433101678	78605F	7653 484308	ANATOLIY POPOV	{"email": "anatoliy_popov_28031979@postgrespro.ru", "phone": "+70819070909"}
0005433101679	5B7ACF	8956 897033	NIKOLAY MOROZOV	{"phone": "+70284954841"}
0005433101681	E4B740	3745 029405	NINA MIKHAYLOVA	{"email": "nina_mikhaylova1985@postgrespro.ru", "phone": "+70088657430"}
0005433101682	71D6A9	6729 344349	RINAT POPOV	{"phone": "+70912007182"}
0005433101683	71D6A9	2598 969198	ELENA SEMENOVA	{"phone": "+70321649463"}
0005433101684	0FFAD4	7425 218632	ALEKSANDRA VLASOVA	{"phone": "+70917044699"}
0005433101685	C5B03F	2721 489932	VALENTIN KARPOV	{"phone": "+70810209561"}
0005433101686	7F0B87	1949 554857	ALEKSANDRA KALININA	{"email": "kalininaa.09121983@postgrespro.ru", "phone": "+70295853695"}
0005433101687	57960C	8667 407119	ALEKSANDR VASILEV	{"phone": "+70504070089"}
0005433101688	1320FB	8113 387529	NIKITA VOLKOV	{"email": "nikita.volkov_1973@postgrespro.ru", "phone": "+70903058853"}
0005433101689	1320FB	8269 504296	DMITRIY SAVELEV	{"phone": "+70857927333"}
0005433101690	202D02	6377 179946	LYUDMILA KAZAKOVA	{"phone": "+70644851825"}
0005433101691	202D02	1506 719457	ZINAIDA DMITRIEVA	{"phone": "+70560045138"}
0005433101692	C829E0	8231 536742	VYACHESLAV TIMOFEEV	{"phone": "+70701647032"}
0005433101693	C829E0	2492 727036	NIKOLAY SEMENOV	{"phone": "+70083215108"}
0005433101694	45AFD3	2464 200658	ALEKSANDR VOROBEV	{"email": "vorobeva_051965@postgrespro.ru", "phone": "+70055137367"}
0005433101695	B041E5	2685 403828	ANNA RYABOVA	{"phone": "+70720590274"}
0005433101696	B041E5	1724 540875	LYUDMILA KARPOVA	{"email": "karpova.l041965@postgrespro.ru", "phone": "+70291408239"}
0005433101697	EC70EB	7802 445923	SERGEY ABRAMOV	{"email": "abramov_s_1974@postgrespro.ru", "phone": "+70399340124"}
0005433101698	D1E5B6	3322 427786	NATALYA MARTYNOVA	{"phone": "+70250782736"}
0005433101699	D1E5B6	6117 360690	ELENA KALININA	{"email": "e.kalinina-04111973@postgrespro.ru", "phone": "+70488948330"}
0005433101700	BC778E	7069 691352	IVAN KARPOV	{"email": "karpov-ivan-28031973@postgrespro.ru", "phone": "+70669911588"}
0005433101701	EED237	5630 133666	ELENA STEPANOVA	{"phone": "+70523554929"}
0005433101702	EED237	1722 587721	PRASKOVYA STEPANOVA	{"phone": "+70674021506"}
0005433101703	C5B674	8882 444531	ALEKSANDR KUZNECOV	{"email": "akuznecov_19061969@postgrespro.ru", "phone": "+70598517598"}
0005433101704	A6AF23	4198 329770	ALEVTINA TIKHONOVA	{"phone": "+70853999266"}
0005433101705	B8AEC8	8399 497745	VASILIY MIKHAYLOV	{"phone": "+70675117042"}
0005433101706	632049	4504 235127	IRINA BELOVA	{"email": "irinabelova-15111976@postgrespro.ru", "phone": "+70399324986"}
0005433101707	632049	5699 481038	NATALYA CHERNOVA	{"phone": "+70648761335"}
0005433101708	C7E244	7447 435068	ALEKSANDR STEPANOV	{"email": "stepanov.a.021969@postgrespro.ru", "phone": "+70117812630"}
0005433101709	C7E244	5884 821720	YAN TIKHONOV	{"phone": "+70613871443"}
0005433101710	75EE63	0989 840747	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina.07011975@postgrespro.ru", "phone": "+70188860549"}
0005433101711	800528	4817 106351	EKATERINA TARASOVA	{"email": "tarasova_ekaterina.20121973@postgrespro.ru", "phone": "+70295688707"}
0005433101712	BCB23A	1892 052108	RAISA GERASIMOVA	{"email": "gerasimovar.1975@postgrespro.ru", "phone": "+70953844148"}
0005433101713	BCB23A	2102 523298	MARIYA ANISIMOVA	{"email": "m-anisimova011972@postgrespro.ru", "phone": "+70930678480"}
0005433101714	AA0903	4643 290493	LARISA GUSEVA	{"email": "larisa_guseva.1975@postgrespro.ru", "phone": "+70484595821"}
0005433101715	0A4098	8819 216671	ALINA KOROLEVA	{"phone": "+70313421396"}
0005433101716	0A4098	6341 668185	RAVIL DENISOV	{"phone": "+70238885030"}
0005433101717	485272	7607 697489	LARISA ROMANOVA	{"email": "l-romanova011971@postgrespro.ru", "phone": "+70034478183"}
0005433101718	8C600E	8532 450907	ANTONINA NIKOLAEVA	{"phone": "+70019729826"}
0005433101719	8C600E	5967 476507	SERGEY ZHUKOV	{"email": "sergey.zhukov_1978@postgrespro.ru", "phone": "+70024471329"}
0005433101720	C2B52C	2177 898456	VIKTORIYA KOZLOVA	{"email": "kozlova-v_021971@postgrespro.ru", "phone": "+70411542541"}
0005433101721	606238	9391 156842	NADEZHDA MIRONOVA	{"email": "n-mironova_121975@postgrespro.ru", "phone": "+70564590459"}
0005433101722	CF82B4	6891 746361	SERGEY ALEKSEEV	{"phone": "+70522289182"}
0005433101723	D55689	4205 862726	PAVEL MAKAROV	{"email": "makarov.pavel.091982@postgrespro.ru", "phone": "+70407838910"}
0005433101724	A7BB02	7940 939705	ANATOLIY ABRAMOV	{"phone": "+70719342195"}
0005433101725	A7BB02	5188 082950	IGOR ZHUKOV	{"phone": "+70109837045"}
0005433101726	A7BB02	1476 117962	NATALYA SAVELEVA	{"phone": "+70783772767"}
0005433101727	2C0DA6	5205 987033	VYACHESLAV MIKHAYLOV	{"email": "mikhaylovvyacheslav20111971@postgrespro.ru", "phone": "+70190037318"}
0005433101728	2C0DA6	8184 861948	MARGARITA TITOVA	{"phone": "+70511653730"}
0005433101729	C1E10A	3595 705970	ALEKSEY VASILEV	{"phone": "+70716988866"}
0005433101730	C1E10A	9102 412424	OLEG ALEKSANDROV	{"phone": "+70772807734"}
0005433101731	C1E10A	1952 043402	IRINA KOVALEVA	{"email": "kovaleva-irina-26111965@postgrespro.ru", "phone": "+70446908600"}
0005433101732	B81012	4878 307562	VADIM MEDVEDEV	{"phone": "+70227822750"}
0005433101733	D13342	4155 648274	GEORGIY GRIGOREV	{"phone": "+70398947103"}
0005433101734	D13342	7060 148137	VALENTINA KUDRYASHOVA	{"email": "vkudryashova-1971@postgrespro.ru", "phone": "+70351883095"}
0005433101854	658926	0010 247227	LYUBOV FEDOROVA	{"phone": "+70388508236"}
0005433101735	BD64D3	7415 070317	VLADIMIR ZAYCEV	{"email": "zaycev.vladimir.031972@postgrespro.ru", "phone": "+70105287776"}
0005433101736	04D382	8646 053731	MARINA NIKITINA	{"phone": "+70347016128"}
0005433101961	16C536	1139 450428	ELENA MEDVEDEVA	{"phone": "+70578165744"}
0005433101737	BDD227	2528 796639	NINA NIKIFOROVA	{"email": "nnikiforova_1971@postgrespro.ru", "phone": "+70247344725"}
0005433101738	FA9984	8208 766876	KLAVDIYA MAKAROVA	{"phone": "+70552012709"}
0005433101739	AED20A	2163 579332	LYUBOV BOGDANOVA	{"email": "l_bogdanova-16031967@postgrespro.ru", "phone": "+70097020248"}
0005433101740	AED20A	2940 932672	IVAN EGOROV	{"email": "i-egorov011969@postgrespro.ru", "phone": "+70490442356"}
0005433101741	B06799	5609 754647	NATALIYA PAVLOVA	{"phone": "+70532538094"}
0005433101742	B4C72D	7956 812527	DMITRIY SIDOROV	{"phone": "+70280172317"}
0005433101743	B9D11D	7280 020733	ELENA SOLOVEVA	{"phone": "+70640689709"}
0005433101744	B9D11D	6466 182051	NADEZHDA MAKAROVA	{"email": "makarova.nadezhda-061980@postgrespro.ru", "phone": "+70349855110"}
0005433101745	EE5EA7	4495 490475	VLADIMIR SERGEEV	{"phone": "+70252639272"}
0005433101746	EE5EA7	5557 964199	ANDREY GERASIMOV	{"email": "gerasimov-andrey-021986@postgrespro.ru", "phone": "+70861529116"}
0005433101747	BE3BF3	8796 415927	MARIYA POPOVA	{"email": "popovam_061982@postgrespro.ru", "phone": "+70479601347"}
0005433101748	A75917	0024 287817	ALINA ROMANOVA	{"email": "a.romanova-051985@postgrespro.ru", "phone": "+70725816023"}
0005433101749	969CB1	3913 885674	ANTONINA FROLOVA	{"email": "frolova_a17121984@postgrespro.ru", "phone": "+70876596790"}
0005433101750	B4C4E9	2186 081206	YANA FEDOROVA	{"phone": "+70078220295"}
0005433101751	B4C4E9	8807 448441	OLGA SERGEEVA	{"email": "olga-sergeeva_16091979@postgrespro.ru", "phone": "+70729711337"}
0005433101752	64BA3B	0914 453985	VIKTORIYA IVANOVA	{"email": "ivanova_viktoriya-26061973@postgrespro.ru", "phone": "+70815945956"}
0005433101753	EA0757	5069 427447	VLADIMIR ALEKSEEV	{"email": "alekseev.vladimir.10011976@postgrespro.ru", "phone": "+70544733200"}
0005433101754	29154F	4272 186608	NINA EGOROVA	{"phone": "+70092811875"}
0005433101755	29154F	8179 861430	OLGA FILATOVA	{"phone": "+70971885616"}
0005433101756	2F4045	8034 094402	OLGA ZAKHAROVA	{"phone": "+70332147179"}
0005433101757	916F32	9901 188776	ALEKSANDR MOROZOV	{"phone": "+70760563859"}
0005433101758	A2A471	3331 284348	ALINA NAUMOVA	{"email": "alina.naumova_091981@postgrespro.ru", "phone": "+70461081185"}
0005433101759	3744A5	8379 062945	MADINA VASILEVA	{"phone": "+70359437918"}
0005433101760	35D5E6	9116 328066	KIRILL KOZLOV	{"email": "k-kozlov_18061976@postgrespro.ru", "phone": "+70184803914"}
0005433101761	35D5E6	0968 473506	DMITRIY ALEKSANDROV	{"email": "aleksandrov_dmitriy-1968@postgrespro.ru", "phone": "+70597379141"}
0005433101762	35D5E6	9178 812724	SERGEY POPOV	{"phone": "+70157703378"}
0005433101763	99F847	4509 725540	OKSANA PAVLOVA	{"email": "oksanapavlova.101970@postgrespro.ru", "phone": "+70983207483"}
0005433101764	317202	6085 064677	OLGA KOZLOVA	{"email": "olgakozlova-061979@postgrespro.ru", "phone": "+70166674541"}
0005433101765	317202	8107 469095	VALENTINA MIRONOVA	{"phone": "+70017229914"}
0005433101766	7A96B8	0713 418239	SVETLANA FEDOROVA	{"email": "fedorova_svetlana.091974@postgrespro.ru", "phone": "+70238904650"}
0005433101767	4BFBB5	4750 685659	SERGEY AFANASEV	{"email": "sergey.afanasev_1979@postgrespro.ru", "phone": "+70522290878"}
0005433101768	9552B9	0582 315369	ILYA STEPANOV	{"email": "stepanovilya-121965@postgrespro.ru", "phone": "+70582672859"}
0005433101769	9552B9	1320 984315	NIKOLAY NAZAROV	{"phone": "+70011312349"}
0005433101770	ACA555	7711 849647	SERGEY ROMANOV	{"phone": "+70205664642"}
0005433101771	29F752	1824 768132	ROMAN NIKOLAEV	{"email": "roman_nikolaev1973@postgrespro.ru", "phone": "+70841182226"}
0005433101772	F7D8CC	5374 451954	NATALYA ANDREEVA	{"phone": "+70603806835"}
0005433101773	F7D8CC	7543 289010	VLADIMIR POPOV	{"phone": "+70174882360"}
0005433101774	654C73	0400 545380	VLADIMIR ZHURAVLEV	{"phone": "+70470835595"}
0005433101775	654C73	6784 760753	ELEONORA ORLOVA	{"phone": "+70226199520"}
0005433101776	4CF2A3	6570 233414	MARINA KISELEVA	{"email": "m.kiseleva-011974@postgrespro.ru", "phone": "+70560969310"}
0005433101777	4CF2A3	6645 548725	ALEKSEY STEPANOV	{"phone": "+70251629814"}
0005433101778	6CBF65	6309 558125	LYUBOV KRASNOVA	{"email": "l_krasnova.121968@postgrespro.ru", "phone": "+70487882150"}
0005433101779	084CC8	3494 161989	LIDIYA MIKHAYLOVA	{"email": "l.mikhaylova.21091957@postgrespro.ru", "phone": "+70510863965"}
0005433101780	495C5D	0876 386601	LYUDMILA NAZAROVA	{"email": "nazarova-l-05021968@postgrespro.ru", "phone": "+70251778984"}
0005433101781	495C5D	0650 657991	SERGEY IVANOV	{"phone": "+70303521919"}
0005433101782	E530F5	1149 919491	VERA MALYSHEVA	{"phone": "+70454017336"}
0005433101783	E530F5	1762 136440	VALENTINA MELNIKOVA	{"email": "melnikova-valentina.1972@postgrespro.ru", "phone": "+70309404886"}
0005433101784	830E45	4396 524824	NIKITA ABRAMOV	{"email": "nabramov.1978@postgrespro.ru", "phone": "+70186089419"}
0005433101785	761A71	9408 809639	YULIYA TROFIMOVA	{"email": "trofimovay_1980@postgrespro.ru", "phone": "+70636778899"}
0005433101786	761A71	5637 070232	TAMARA KUZNECOVA	{"email": "t.kuznecova18051973@postgrespro.ru", "phone": "+70634664778"}
0005433101787	2CC534	0604 412279	TATYANA VOROBEVA	{"email": "vorobeva-tatyana_12101969@postgrespro.ru", "phone": "+70475691763"}
0005433101788	2CC534	5310 729685	TATYANA ARKHIPOVA	{"phone": "+70165680705"}
0005433101789	3324CE	9591 891377	EKATERINA KUZNECOVA	{"phone": "+70423546201"}
0005433101790	13AC90	6313 064524	ANATOLIY KOZLOV	{"email": "anatoliy_kozlov-1971@postgrespro.ru", "phone": "+70232768458"}
0005433101791	727F00	3920 001976	OLGA BARANOVA	{"email": "baranova-olga-1978@postgrespro.ru", "phone": "+70783465322"}
0005433101792	727F00	3229 082913	OLEG MOISEEV	{"phone": "+70455798433"}
0005433102205	F3B333	8946 468825	NINA YAKOVLEVA	{"phone": "+70684504142"}
0005433101793	D3BB5E	9544 009628	TATYANA DAVYDOVA	{"email": "tatyanadavydova.30041981@postgrespro.ru", "phone": "+70862911481"}
0005433101794	ABA7BA	3136 883278	ANNA IVANOVA	{"phone": "+70832084612"}
0005433101795	AAF2D4	9736 403037	EVGENIY IVANOV	{"phone": "+70928229790"}
0005433101796	C08B24	0607 286381	VALERIY SIDOROV	{"phone": "+70498420176"}
0005433101797	C08B24	8651 905314	MARIYA IVANOVA	{"phone": "+70249169725"}
0005433101798	C08B24	2855 328916	VLADISLAV MARTYNOV	{"email": "martynovv-1975@postgrespro.ru", "phone": "+70978576611"}
0005433101799	14DDB4	8828 980995	SERGEY GUSEV	{"email": "gusevs_1970@postgrespro.ru", "phone": "+70998717925"}
0005433101800	14DDB4	9877 270953	ARTEM ZHURAVLEV	{"email": "zhuravlev-a-051985@postgrespro.ru", "phone": "+70982105694"}
0005433101801	8D1D30	6220 255383	KRISTINA SMIRNOVA	{"phone": "+70371377375"}
0005433101802	4F0209	6243 847133	VLADIMIR BORISOV	{"email": "v.borisov-25121976@postgrespro.ru", "phone": "+70884321547"}
0005433101803	CDD7F0	7839 577397	NATALYA VASILEVA	{"email": "vasileva.natalya-081961@postgrespro.ru", "phone": "+70480870438"}
0005433101804	48C6CE	0889 550496	NADEZHDA SERGEEVA	{"phone": "+70923295165"}
0005433101805	48C6CE	3307 152808	GALINA YUDINA	{"email": "yudina.g.06031974@postgrespro.ru", "phone": "+70110632867"}
0005433101806	0C7746	5689 630390	LYUDMILA NIKITINA	{"email": "lyudmila.nikitina19091970@postgrespro.ru", "phone": "+70360243470"}
0005433101807	A3858B	7800 789863	TATYANA KUZMINA	{"email": "kuzminat.02041963@postgrespro.ru", "phone": "+70450994056"}
0005433101808	A3858B	3446 732730	ALEKSANDRA GAVRILOVA	{"email": "gavrilova-a22111967@postgrespro.ru", "phone": "+70166387287"}
0005433101809	2D7CBA	6805 844742	LYUBOV ZAYCEVA	{"email": "zayceva.l_101972@postgrespro.ru", "phone": "+70068037869"}
0005433101810	2D7CBA	8341 533074	ILDAR SAVELEV	{"email": "savelevildar_06121969@postgrespro.ru", "phone": "+70182094543"}
0005433101811	AE84D6	4309 603720	KRISTINA ZAYCEVA	{"phone": "+70018222019"}
0005433101812	C7EF9A	7878 699425	BULAT NIKOLAEV	{"email": "nikolaevb_121976@postgrespro.ru", "phone": "+70508802387"}
0005433101813	A403F5	6188 121603	NADEZHDA OSIPOVA	{"email": "osipova-nadezhda-1985@postgrespro.ru", "phone": "+70536338061"}
0005433101814	A403F5	9767 435424	KSENIYA ISAEVA	{"phone": "+70369642621"}
0005433101815	A403F5	9048 754941	KONSTANTIN IVANOV	{"phone": "+70747132356"}
0005433101816	FC3489	9644 666038	IGNAT ANTONOV	{"phone": "+70414419870"}
0005433101817	0875DF	2409 665622	ELENA ISAEVA	{"phone": "+70682921367"}
0005433101818	0875DF	0366 657699	DANIIL ILIN	{"phone": "+70758447006"}
0005433101819	0875DF	4827 266355	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr071974@postgrespro.ru", "phone": "+70303703866"}
0005433101820	24F93E	9604 386101	NIKOLAY MAKAROV	{"phone": "+70064151871"}
0005433101821	24F93E	5520 906268	ANATOLIY NIKITIN	{"phone": "+70862947268"}
0005433101822	00E5E8	0420 198965	ALEKSANDR SOROKIN	{"phone": "+70560955619"}
0005433101823	6EF50C	1874 980629	ALENA VOLKOVA	{"email": "alena.volkova_1979@postgrespro.ru", "phone": "+70022124570"}
0005433101824	6EF50C	3419 944801	ELIZAVETA KUZNECOVA	{"email": "kuznecova.e30011972@postgrespro.ru", "phone": "+70080958686"}
0005433101825	3149BF	8233 117561	MARIYA ZAKHAROVA	{"phone": "+70517935023"}
0005433101826	3149BF	9336 329709	NATALYA ANDREEVA	{"email": "natalya_andreeva1971@postgrespro.ru", "phone": "+70372849694"}
0005433101827	2889CC	7163 880473	ANNA MAKAROVA	{"phone": "+70573705199"}
0005433101828	2889CC	6558 249138	VALERIY SIDOROV	{"email": "valeriysidorov-1980@postgrespro.ru", "phone": "+70919916988"}
0005433101829	61EBDE	6981 567775	VLADIMIR BELOV	{"phone": "+70155794994"}
0005433101830	1918D1	4216 233396	LIDIYA KONDRATEVA	{"email": "lidiya.kondrateva.091967@postgrespro.ru", "phone": "+70468674245"}
0005433101831	0139DD	3074 203316	TATYANA SIDOROVA	{"email": "tatyana-sidorova-1973@postgrespro.ru", "phone": "+70736103700"}
0005433101832	C9ACF8	1865 919008	VIKTOR KUZNECOV	{"phone": "+70669143280"}
0005433101833	A69940	3031 818727	VALENTINA LAZAREVA	{"email": "valentinalazareva.081974@postgrespro.ru", "phone": "+70457680360"}
0005433101834	A69940	5431 958184	MIKHAIL SCHERBAKOV	{"phone": "+70159218268"}
0005433101835	C50A2B	7069 629440	SVETLANA DENISOVA	{"phone": "+70180218440"}
0005433101836	F8498A	4649 643074	NIKITA POPOV	{"email": "n.popov-1967@postgrespro.ru", "phone": "+70280595955"}
0005433101837	1CFC5F	6319 882089	OLGA TROFIMOVA	{"email": "trofimova-o16051976@postgrespro.ru", "phone": "+70553658819"}
0005433101838	491C1B	3791 053667	RAMIL MEDVEDEV	{"phone": "+70282719586"}
0005433101839	491C1B	9626 106812	IGOR OSIPOV	{"phone": "+70743203397"}
0005433101840	2FABC8	7907 070648	RINAT EGOROV	{"phone": "+70384225637"}
0005433101841	E107EA	5282 187067	IVAN BORISOV	{"email": "borisov-ivan1968@postgrespro.ru", "phone": "+70876798851"}
0005433101842	FB5F80	8167 406856	VLADIMIR SEMENOV	{"phone": "+70604072100"}
0005433101843	1F812C	1493 686371	VYACHESLAV SOLOVEV	{"phone": "+70086625359"}
0005433101844	1F812C	9794 711944	SERGEY NIKITIN	{"phone": "+70258927970"}
0005433101845	1F812C	3145 792071	VASILIY POPOV	{"email": "popov_v-031958@postgrespro.ru", "phone": "+70000853761"}
0005433101846	6AB242	8394 726153	LYUBOV TARASOVA	{"email": "tarasova_lyubov_28061975@postgrespro.ru", "phone": "+70981177218"}
0005433101847	B22C86	2871 214636	VITALIY GERASIMOV	{"email": "gerasimov-vitaliy-10061969@postgrespro.ru", "phone": "+70902371010"}
0005433101848	B22C86	0215 319860	SERGEY POPOV	{"email": "s.popov.011972@postgrespro.ru", "phone": "+70488241248"}
0005433101849	B22C86	9449 607352	VIKTORIYA BORISOVA	{"email": "borisova-viktoriya1985@postgrespro.ru", "phone": "+70321115934"}
0005433101850	5A9BC4	9061 867829	VLADIMIR KUZNECOV	{"phone": "+70102928808"}
0005433101851	34BB66	4913 363737	VIKTORIYA BOGDANOVA	{"phone": "+70259180685"}
0005433101852	1C175F	7815 377170	VIKTOR KOZLOV	{"phone": "+70075690204"}
0005433101853	A865E3	1352 344563	GALINA ZHUKOVA	{"phone": "+70525181287"}
0005433101855	09B117	1466 830102	NADEZHDA ZAYCEVA	{"email": "n.zayceva-1977@postgrespro.ru", "phone": "+70045064429"}
0005433101856	08AFDD	1170 368335	MIKHAIL ANDREEV	{"email": "m-andreev.04111974@postgrespro.ru", "phone": "+70906368877"}
0005433101857	08AFDD	9429 270680	NIKOLAY ZHUKOV	{"phone": "+70388084801"}
0005433101858	2FE822	0788 426089	MARIYA FEDOROVA	{"email": "fedorova-m-021967@postgrespro.ru", "phone": "+70692334304"}
0005433101859	72A682	4201 380284	DARYA KOROLEVA	{"email": "koroleva.darya-27021971@postgrespro.ru", "phone": "+70493404159"}
0005433101860	A7B22F	7556 063608	LYUDMILA NAZAROVA	{"email": "nazarova-lyudmila_1973@postgrespro.ru", "phone": "+70982545748"}
0005433101861	A7B22F	2484 826494	MARIYA PETROVA	{"phone": "+70400741155"}
0005433101862	21B588	7705 614486	SOFIYA EGOROVA	{"email": "egorova_sofiya1976@postgrespro.ru", "phone": "+70253146619"}
0005433101863	160184	9866 983964	DINA ABRAMOVA	{"phone": "+70935554151"}
0005433101864	9CC74F	4550 411802	IRINA GUSEVA	{"phone": "+70578801377"}
0005433101865	9CC74F	5236 016600	NIKOLAY MELNIKOV	{"email": "melnikov-n.091987@postgrespro.ru", "phone": "+70357742699"}
0005433101866	3C622D	8229 983327	VERA NIKITINA	{"email": "vnikitina.1968@postgrespro.ru", "phone": "+70765078084"}
0005433101867	3C622D	8604 152671	TATYANA FADEEVA	{"email": "tatyana-fadeeva.08061959@postgrespro.ru", "phone": "+70622943636"}
0005433101868	D26326	0490 702395	ANNA DENISOVA	{"email": "anna_denisova16021967@postgrespro.ru", "phone": "+70873049069"}
0005433101869	219848	6828 978822	TATYANA VOROBEVA	{"email": "vorobevat_051964@postgrespro.ru", "phone": "+70116020630"}
0005433101870	A74A56	5669 057149	ALEKSANDRA VASILEVA	{"email": "aleksandra_vasileva.10091991@postgrespro.ru", "phone": "+70763148874"}
0005433101871	2C256F	2063 054167	DMITRIY GRIGOREV	{"phone": "+70293108483"}
0005433101872	5BF2E6	1955 457905	VALERIYA MOISEEVA	{"email": "moiseeva.v.1962@postgrespro.ru", "phone": "+70998418647"}
0005433101873	679CF6	6119 526584	ELENA IVANOVA	{"phone": "+70296106363"}
0005433101874	00362F	7953 747478	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina26041970@postgrespro.ru", "phone": "+70283220505"}
0005433101875	00362F	0849 971147	LYUDMILA KOZLOVA	{"email": "kozlovalyudmila-1964@postgrespro.ru", "phone": "+70365334215"}
0005433101876	4560B3	5095 629776	MARIYA MARTYNOVA	{"email": "martynovam111972@postgrespro.ru", "phone": "+70838808065"}
0005433101877	8FCC3E	6796 434357	VYACHESLAV SHEVCHENKO	{"phone": "+70346686081"}
0005433101878	241A36	0975 601150	ALEKSANDR TARASOV	{"email": "tarasov.a-011978@postgrespro.ru", "phone": "+70361886985"}
0005433101879	A1D9E0	1223 082127	ALEKSANDR ZAYCEV	{"phone": "+70517524588"}
0005433101880	C36D43	9117 889892	ALEKSANDR MAKAROV	{"phone": "+70367732987"}
0005433101881	64531F	2930 295809	ANATOLIY MAKAROV	{"email": "a_makarov-1969@postgrespro.ru", "phone": "+70636846187"}
0005433101882	CFB9FE	8512 719009	RASHIT ALEKSANDROV	{"phone": "+70803875374"}
0005433101883	7CB752	1052 684298	VALERIY ANTONOV	{"phone": "+70390079230"}
0005433101884	7CB752	3794 593902	VLADIMIR KUZNECOV	{"email": "kuznecovv_031970@postgrespro.ru", "phone": "+70365363191"}
0005433101885	7CB752	3777 100689	NINA KOROLEVA	{"phone": "+70569740657"}
0005433101886	E9296D	2189 547138	ELENA NESTEROVA	{"email": "e_nesterova.17031968@postgrespro.ru", "phone": "+70654879918"}
0005433101887	E9296D	9077 580885	VALENTINA ZHUKOVA	{"phone": "+70293514885"}
0005433101888	B43A02	7404 483666	NIKOLAY GAVRILOV	{"phone": "+70124405517"}
0005433101889	B43A02	6015 939562	KIRILL KUZMIN	{"phone": "+70113064565"}
0005433101890	9E2FB1	3692 064602	ANDREY EGOROV	{"email": "egorova031983@postgrespro.ru", "phone": "+70254740309"}
0005433101891	C46DF2	5582 290617	ZINAIDA GORBUNOVA	{"email": "zinaida.gorbunova_1971@postgrespro.ru", "phone": "+70609974501"}
0005433101892	AF5BE8	2620 998512	VLADISLAV GORBUNOV	{"phone": "+70179368552"}
0005433101893	3688E4	2764 288379	IGOR KOROLEV	{"phone": "+70426128863"}
0005433101894	F81AEE	6116 286400	EVGENIY FEDOTOV	{"email": "fedotov.evgeniy021970@postgrespro.ru", "phone": "+70006634884"}
0005433101895	40373A	8059 357092	EVA MIKHAYLOVA	{"phone": "+70497490040"}
0005433101896	576170	1195 106613	EVGENIYA CHERNOVA	{"email": "e-chernova30051976@postgrespro.ru", "phone": "+70076939089"}
0005433101897	576170	0952 140145	ARKADIY KARPOV	{"email": "karpova_15061973@postgrespro.ru", "phone": "+70490830272"}
0005433101898	187174	4827 851572	NATALYA KOZLOVA	{"phone": "+70738607082"}
0005433101899	187174	1163 825301	ARINA EFIMOVA	{"email": "efimovaa_071969@postgrespro.ru", "phone": "+70759280494"}
0005433101900	187174	2000 068953	IVAN ANTONOV	{"email": "antonov_ivan1970@postgrespro.ru", "phone": "+70285829770"}
0005433101901	1CACC8	7153 088147	DENIS KOZLOV	{"phone": "+70970158703"}
0005433101902	FABB7B	7674 206942	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov_1975@postgrespro.ru", "phone": "+70522199863"}
0005433101903	81A783	1882 727184	SVETLANA OSIPOVA	{"email": "sosipova.16051976@postgrespro.ru", "phone": "+70835115533"}
0005433101904	F8C854	1217 405756	KIRILL POPOV	{"email": "kirill.popov071966@postgrespro.ru", "phone": "+70759036915"}
0005433101905	F8C854	8371 169623	ANATOLIY ZHUKOV	{"email": "anatoliy_zhukov.1987@postgrespro.ru", "phone": "+70405845593"}
0005433101906	24DC9D	4377 006004	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy_071981@postgrespro.ru", "phone": "+70883833629"}
0005433101907	85702D	9050 998879	EKATERINA GAVRILOVA	{"email": "gavrilovae_1967@postgrespro.ru", "phone": "+70168907939"}
0005433101908	85702D	8063 227859	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila1964@postgrespro.ru", "phone": "+70794505227"}
0005433101909	2D64E1	0024 907351	ALEKSANDR ZHUKOV	{"phone": "+70000641976"}
0005433101910	2D64E1	2410 311422	NINA NIKITINA	{"phone": "+70887121377"}
0005433101911	4849A8	7324 242714	KONSTANTIN VOLKOV	{"email": "konstantinvolkov.17111967@postgrespro.ru", "phone": "+70482193498"}
0005433101912	E931B7	6085 295423	BORIS ZAYCEV	{"phone": "+70206977625"}
0005433101913	4266E5	6130 098341	EVGENIY SOKOLOV	{"email": "evgeniysokolov_051964@postgrespro.ru", "phone": "+70362159655"}
0005433101914	8FE456	3448 511522	DMITRIY PETROV	{"email": "petrov.dmitriy_011974@postgrespro.ru", "phone": "+70676625194"}
0005433101915	0CD274	5073 305726	EKATERINA VLASOVA	{"email": "ekaterina.vlasova.17081986@postgrespro.ru", "phone": "+70698482927"}
0005433101916	95A27C	2959 158925	ALEKSANDR KOZLOV	{"phone": "+70393252193"}
0005433101917	AA5E63	9178 561184	NINA KARPOVA	{"email": "karpova.n_1966@postgrespro.ru", "phone": "+70717425451"}
0005433101918	2A45F1	6299 285806	SVETLANA MIKHAYLOVA	{"phone": "+70504187092"}
0005433101919	2A45F1	2907 848833	ANDREY VASILEV	{"email": "andreyvasilev_1972@postgrespro.ru", "phone": "+70628261237"}
0005433101920	09E8AF	6654 041846	NIKOLAY IVANOV	{"email": "ivanov_n-05051972@postgrespro.ru", "phone": "+70390402795"}
0005433101921	6AA153	2932 912823	ELISEY MELNIKOV	{"email": "melnikov.e.1971@postgrespro.ru", "phone": "+70626288396"}
0005433101922	6AA153	2266 280280	GRIGORIY FOMIN	{"phone": "+70614727234"}
0005433101923	CBF684	1377 595668	MARIYA ALEKSANDROVA	{"email": "mariya_aleksandrova.1963@postgrespro.ru", "phone": "+70810049684"}
0005433101924	9B514D	6759 389592	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov-v.25121972@postgrespro.ru", "phone": "+70209400172"}
0005433101925	D4D331	2584 995456	YURIY BORISOV	{"email": "borisovy1962@postgrespro.ru", "phone": "+70986012904"}
0005433101926	D4D331	9295 383532	EKATERINA IVANOVA	{"email": "ivanova.ekaterina.10111965@postgrespro.ru", "phone": "+70707004437"}
0005433101927	D4D331	5839 966282	ALBINA IVANOVA	{"email": "ivanova_albina_1967@postgrespro.ru", "phone": "+70700566203"}
0005433101928	35C4AA	6407 016584	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova041970@postgrespro.ru", "phone": "+70926517132"}
0005433101929	1ABF63	0874 993838	ALEKSANDR BONDARENKO	{"email": "a.bondarenko1958@postgrespro.ru", "phone": "+70945412441"}
0005433101930	60763E	6858 565492	ROMAN TIMOFEEV	{"email": "roman.timofeev_17101970@postgrespro.ru", "phone": "+70921070872"}
0005433101931	F26B71	7508 728901	EVGENIY KISELEV	{"phone": "+70644873329"}
0005433101932	F26B71	1500 946970	LIDIYA ZAKHAROVA	{"email": "zakharova-l_031970@postgrespro.ru", "phone": "+70272622352"}
0005433101933	155EA6	2218 802676	ANNA IVANOVA	{"email": "anna.ivanova_1982@postgrespro.ru", "phone": "+70281805457"}
0005433101934	43A01C	8346 420030	OLGA CHERNOVA	{"email": "chernova-o-06011969@postgrespro.ru", "phone": "+70261355665"}
0005433101935	A6D3A8	2015 357737	LYUDMILA KONDRATEVA	{"email": "kondratevalyudmila-1973@postgrespro.ru", "phone": "+70138495829"}
0005433101936	4DFCE2	8273 643478	SVETLANA ROMANOVA	{"email": "s_romanova-25051970@postgrespro.ru", "phone": "+70809711981"}
0005433101937	4DFCE2	6723 471555	GALINA EGOROVA	{"phone": "+70277718369"}
0005433101938	D2F42F	3759 126935	IVAN ALEKSEEV	{"email": "alekseev_i091970@postgrespro.ru", "phone": "+70896903185"}
0005433101939	313635	9249 497475	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir121975@postgrespro.ru", "phone": "+70242191325"}
0005433101940	2889E6	8560 554465	NIKOLAY ISAEV	{"email": "n_isaev.031977@postgrespro.ru", "phone": "+70175659628"}
0005433101941	A2DB5F	3327 916823	SVETLANA POTAPOVA	{"email": "potapova.s-1970@postgrespro.ru", "phone": "+70999563884"}
0005433101942	A2DB5F	8127 851126	BORIS GAVRILOV	{"phone": "+70992772451"}
0005433101943	D08E58	0732 293932	ALINA KUZMINA	{"email": "kuzmina_a_31051972@postgrespro.ru", "phone": "+70973421494"}
0005433101944	7F931E	7763 518236	ALLA VOLKOVA	{"phone": "+70243406858"}
0005433101945	EE65B6	7752 135551	ALEKSEY EGOROV	{"phone": "+70794351514"}
0005433101946	9F702F	6526 922544	MAKSIM SAVELEV	{"phone": "+70215576217"}
0005433101947	C9AC2F	8795 934301	NINA BELOVA	{"email": "nina-belova_1981@postgrespro.ru", "phone": "+70157176836"}
0005433101948	C9AC2F	5892 999040	VITALIY GRIGOREV	{"email": "vgrigorev-09011973@postgrespro.ru", "phone": "+70809267671"}
0005433101949	B09E57	9608 602417	KSENIYA POPOVA	{"phone": "+70044164084"}
0005433101950	B09E57	5664 771807	ANDREY SEMENOV	{"email": "andreysemenov.061958@postgrespro.ru", "phone": "+70847913983"}
0005433101951	6822BE	8465 463023	ALFIYA STEPANOVA	{"phone": "+70531540447"}
0005433101952	1B425E	2153 301011	VASILIY ALEKSANDROV	{"phone": "+70686572881"}
0005433101953	2A895C	0134 527301	OLGA POPOVA	{"phone": "+70328091495"}
0005433101954	1829E9	3028 718312	GENNADIY SOLOVEV	{"email": "gennadiy.solovev.14071962@postgrespro.ru", "phone": "+70294098936"}
0005433101955	1829E9	8321 633777	OLEG NAZAROV	{"email": "nazarov-o.04051969@postgrespro.ru", "phone": "+70522593746"}
0005433101956	700E30	4460 021311	RENAT TIMOFEEV	{"email": "timofeevr15071969@postgrespro.ru", "phone": "+70713219998"}
0005433101957	700E30	3437 532432	OLGA FADEEVA	{"phone": "+70703583158"}
0005433101958	700E30	8592 113511	OLEG SOLOVEV	{"email": "solovevoleg12091972@postgrespro.ru", "phone": "+70435305314"}
0005433101959	0EEAE0	2846 512259	VALENTINA DENISOVA	{"phone": "+70256017798"}
0005433101962	AA27EA	1797 161627	SVETLANA STEPANOVA	{"email": "svetlana_stepanova.1960@postgrespro.ru", "phone": "+70729785517"}
0005433101963	BD812A	1442 920879	SVETLANA DANILOVA	{"phone": "+70637017365"}
0005433101964	7CEF1E	2591 110027	TATYANA EFIMOVA	{"phone": "+70949434315"}
0005433101965	EA6F4D	2702 248509	NATALYA SEMENOVA	{"email": "natalyasemenova1973@postgrespro.ru", "phone": "+70559498145"}
0005433101966	EA6F4D	6324 358323	NAIL BORISOV	{"email": "n-borisov-1962@postgrespro.ru", "phone": "+70272581725"}
0005433101967	0B6AA1	0258 180490	KSENIYA VOLKOVA	{"email": "kseniyavolkova.1971@postgrespro.ru", "phone": "+70004499244"}
0005433101968	38A32C	4396 472197	ELENA NESTEROVA	{"phone": "+70831993835"}
0005433101969	38A32C	1332 502103	TATYANA POPOVA	{"email": "popova_t-07021972@postgrespro.ru", "phone": "+70443426111"}
0005433101970	38A32C	2542 135451	ANNA POTAPOVA	{"email": "potapova-a-02021970@postgrespro.ru", "phone": "+70965737516"}
0005433101971	EFBD1A	8271 543757	NADEZHDA DAVYDOVA	{"phone": "+70418708496"}
0005433101972	4DA29A	3033 760811	IGOR DMITRIEV	{"email": "idmitriev.20091963@postgrespro.ru", "phone": "+70576528805"}
0005433101973	A5667A	5014 777605	ALEKSANDR IVANOV	{"phone": "+70281860285"}
0005433101974	A5667A	1862 739148	NATALYA FROLOVA	{"phone": "+70851624897"}
0005433101975	897E6B	7970 056735	ELENA OVCHINNIKOVA	{"phone": "+70312947616"}
0005433101976	C4CDCC	4184 549032	EKATERINA ZHURAVLEVA	{"email": "e-zhuravleva-17021972@postgrespro.ru", "phone": "+70047735403"}
0005433101977	711D41	4222 131747	NIKOLAY ZHUKOV	{"phone": "+70992343227"}
0005433101978	711D41	7962 440642	VERA ANTONOVA	{"email": "vera.antonova1971@postgrespro.ru", "phone": "+70379488916"}
0005433101979	4F601C	3635 430833	VIKTOR IVANOV	{"email": "v_ivanov24091986@postgrespro.ru", "phone": "+70929752893"}
0005433101980	4F601C	6321 293773	ANATOLIY KUZMIN	{"phone": "+70497640051"}
0005433101981	4F601C	5555 240168	ALEKSEY MOISEEV	{"email": "aleksey.moiseev.091961@postgrespro.ru", "phone": "+70243023407"}
0005433101982	01E413	4030 047683	DMITRIY NAUMOV	{"email": "dmitriynaumov_111970@postgrespro.ru", "phone": "+70366353371"}
0005433101983	298BCF	0970 645597	ANNA KOZLOVA	{"email": "kozlova.a-011964@postgrespro.ru", "phone": "+70097660505"}
0005433101984	1879BC	0727 456625	VALERIY FEDOTOV	{"email": "valeriy_fedotov.101976@postgrespro.ru", "phone": "+70327851410"}
0005433101985	82A229	5998 455805	ALEKSANDR GUSEV	{"email": "a.gusev1979@postgrespro.ru", "phone": "+70279231055"}
0005433101986	72E37C	0938 285218	ALEKSANDR FROLOV	{"email": "afrolov.09081975@postgrespro.ru", "phone": "+70339788904"}
0005433101987	44CC1C	1491 133367	MIKHAIL KUZMIN	{"phone": "+70600608625"}
0005433101988	44CC1C	1410 209637	OLESYA ZHURAVLEVA	{"email": "zhuravleva.o1965@postgrespro.ru", "phone": "+70576584924"}
0005433101989	929773	5253 975587	NIKOLAY SCHERBAKOV	{"phone": "+70283276251"}
0005433101990	C03885	1802 649998	ANTONINA MALYSHEVA	{"email": "malysheva.a06041977@postgrespro.ru", "phone": "+70414789280"}
0005433101991	C03885	3856 940625	SERGEY ANDREEV	{"email": "sergey_andreev-1971@postgrespro.ru", "phone": "+70877186357"}
0005433101992	661D06	1897 558653	VALENTINA KOROLEVA	{"phone": "+70768024213"}
0005433101993	E2C7E3	9960 801210	NINA POLYAKOVA	{"email": "polyakova_n.21091972@postgrespro.ru", "phone": "+70082081846"}
0005433101994	23841D	0946 343862	ANASTASIYA BELOVA	{"email": "belova-a24031985@postgrespro.ru", "phone": "+70285913234"}
0005433101995	5F5626	4822 553809	SERGEY SMIRNOV	{"phone": "+70247908003"}
0005433101996	AC09FE	9213 853261	KONSTANTIN MEDVEDEV	{"phone": "+70371909719"}
0005433101997	864170	4493 533444	LYUDMILA OSIPOVA	{"email": "osipovalyudmila.1968@postgrespro.ru", "phone": "+70791163442"}
0005433101998	510B2D	3556 002431	LARISA LEBEDEVA	{"email": "larisa-lebedeva.1960@postgrespro.ru", "phone": "+70848780816"}
0005433101999	7A0685	6515 962322	ALEKSEY BONDARENKO	{"phone": "+70041671989"}
0005433102000	56ADA6	5548 395804	ANASTASIYA AFANASEVA	{"email": "afanaseva-a_121984@postgrespro.ru", "phone": "+70187489445"}
0005433102001	926E00	7509 878307	ELENA KALININA	{"email": "kalinina_e061972@postgrespro.ru", "phone": "+70768389776"}
0005433102002	19487F	4076 336356	ROMAN NAUMOV	{"email": "naumov-roman_19071969@postgrespro.ru", "phone": "+70737415375"}
0005433102003	23964E	5328 095146	SVETLANA SERGEEVA	{"email": "s_sergeeva081970@postgrespro.ru", "phone": "+70204375828"}
0005433102004	23964E	4255 801719	ELENA NIKITINA	{"email": "elena-nikitina-16121972@postgrespro.ru", "phone": "+70396494084"}
0005433102005	9ECB4E	2384 499673	VALENTINA SEMENOVA	{"email": "semenova.v_1967@postgrespro.ru", "phone": "+70969591762"}
0005433102006	9ECB4E	4127 804881	ALEKSANDR SEMENOV	{"phone": "+70373274587"}
0005433102007	95433F	9799 820364	LIDIYA VASILEVA	{"email": "vasileva-lidiya-041970@postgrespro.ru", "phone": "+70507063197"}
0005433102008	95433F	3946 742748	YURIY ALEKSEEV	{"email": "alekseevyuriy-17061967@postgrespro.ru", "phone": "+70040238657"}
0005433102009	A41BEC	8323 455805	RAISA KOMAROVA	{"email": "komarova-r_15101974@postgrespro.ru", "phone": "+70991774267"}
0005433102010	A41BEC	5458 799946	KIRILL EGOROV	{"phone": "+70845284845"}
0005433102011	F0BAD9	0025 516954	MARIYA ANTONOVA	{"email": "mariya-antonova05091972@postgrespro.ru", "phone": "+70229268126"}
0005433102012	F0BAD9	9623 931510	EVGENIYA EGOROVA	{"email": "evgeniya.egorova_091979@postgrespro.ru", "phone": "+70120085209"}
0005433102013	5E7EE3	1776 791329	VITALIY BORISOV	{"phone": "+70662369441"}
0005433102014	5E7EE3	5905 937236	IRINA KOROLEVA	{"phone": "+70565048426"}
0005433102015	93CD0B	4745 205407	VALERIY IVANOV	{"email": "valeriy.ivanov.051968@postgrespro.ru", "phone": "+70558721550"}
0005433102016	D8AF8D	9113 762196	LIDIYA NIKOLAEVA	{"phone": "+70660137401"}
0005433102017	D8AF8D	3296 577521	OLGA ALEKSANDROVA	{"phone": "+70872740486"}
0005433102018	AEDF0F	2784 060764	VLADIMIR FILIPPOV	{"phone": "+70574210968"}
0005433102019	BE30F7	5411 537690	SERGEY ZAYCEV	{"email": "sergey_zaycev021967@postgrespro.ru", "phone": "+70625306591"}
0005433102020	C7143D	9798 114159	GENNADIY VASILEV	{"email": "gvasilev_07051964@postgrespro.ru", "phone": "+70585399134"}
0005433102021	C7143D	4468 025767	MAKSIM POPOV	{"phone": "+70489777241"}
0005433102022	C7143D	9085 905891	LYUBOV FEDOROVA	{"email": "l_fedorova-16121969@postgrespro.ru", "phone": "+70972427576"}
0005433102023	D0E3D2	6985 006825	YANA MIKHAYLOVA	{"phone": "+70046427373"}
0005433102024	C7D463	1605 397230	YURIY EGOROV	{"phone": "+70758048412"}
0005433102025	C7D463	7989 784571	SERGEY SCHERBAKOV	{"phone": "+70178549522"}
0005433102026	D02B0C	1388 928199	EKATERINA KOVALEVA	{"email": "kovaleva-ekaterina_30051979@postgrespro.ru", "phone": "+70932000015"}
0005433102027	928467	6096 657173	OLGA GERASIMOVA	{"email": "olga_gerasimova.19031967@postgrespro.ru", "phone": "+70972414389"}
0005433102028	8381A4	0250 972861	MIKHAIL ZAKHAROV	{"email": "mzakharov_1968@postgrespro.ru", "phone": "+70833728946"}
0005433102029	8381A4	4732 570670	VLADIMIR GRIGOREV	{"phone": "+70967524730"}
0005433102030	7302DC	0374 566418	ANNA KUZMINA	{"email": "kuzmina_a121954@postgrespro.ru", "phone": "+70866769218"}
0005433102031	9843A8	3601 068760	VALENTINA ZAYCEVA	{"email": "zayceva.v.04091969@postgrespro.ru", "phone": "+70833841499"}
0005433102032	9843A8	1978 437882	SERGEY FROLOV	{"email": "frolov_s-011981@postgrespro.ru", "phone": "+70329099652"}
0005433102033	9843A8	0591 646856	SERGEY SMIRNOV	{"email": "sergey-smirnov-1981@postgrespro.ru", "phone": "+70286675671"}
0005433102034	700DE5	2612 878173	REGINA KOROLEVA	{"email": "regina.koroleva-071970@postgrespro.ru", "phone": "+70683614206"}
0005433102035	CBF2B7	0828 315399	ARTUR DENISOV	{"email": "arturdenisov-08081972@postgrespro.ru", "phone": "+70571303115"}
0005433102036	DC515C	7315 187839	SVETLANA PAVLOVA	{"email": "pavlova.s_101975@postgrespro.ru", "phone": "+70389461218"}
0005433102037	DC515C	5604 788362	TATYANA RODIONOVA	{"email": "rodionova_t_1969@postgrespro.ru", "phone": "+70250241345"}
0005433102038	E4CAFE	0149 015460	ALEKSANDR BORISOV	{"email": "aleksandrborisov.27081985@postgrespro.ru", "phone": "+70266129755"}
0005433102039	E4CAFE	3428 782834	OLGA KOROLEVA	{"email": "o_koroleva_1951@postgrespro.ru", "phone": "+70644739002"}
0005433102040	69807E	8424 928885	LIDIYA KARPOVA	{"email": "lidiyakarpova.1989@postgrespro.ru", "phone": "+70915684275"}
0005433102041	BE0581	6434 090742	IRINA BOGDANOVA	{"phone": "+70743194000"}
0005433102042	BE0581	2335 623479	LYUDMILA POPOVA	{"email": "lyudmilapopova_1976@postgrespro.ru", "phone": "+70398184060"}
0005433102043	BE0581	2552 942904	VLADIMIR ISAEV	{"email": "v_isaev_20021972@postgrespro.ru", "phone": "+70844218870"}
0005433102044	611C04	4573 772573	ELENA IVANOVA	{"email": "eivanova_29111966@postgrespro.ru", "phone": "+70116837266"}
0005433102045	611C04	5103 739675	INNA BELYAEVA	{"email": "belyaeva-inna071973@postgrespro.ru", "phone": "+70489253719"}
0005433102046	F3FAD9	6887 031814	ELENA POPOVA	{"email": "popova-elena051980@postgrespro.ru", "phone": "+70963826544"}
0005433102047	F3FAD9	0191 194247	ELENA MEDVEDEVA	{"phone": "+70324235639"}
0005433102048	F3FAD9	2901 873588	KSENIYA DAVYDOVA	{"email": "davydova-kseniya_01091979@postgrespro.ru", "phone": "+70591116515"}
0005433102049	AF1171	4861 016188	ALEKSANDR ROMANOV	{"phone": "+70733366291"}
0005433102050	AF1171	8244 401765	MAKSIM STEPANOV	{"email": "m-stepanov-18071978@postgrespro.ru", "phone": "+70915578073"}
0005433102051	AF1171	4331 954477	TAMARA KUZNECOVA	{"email": "t_kuznecova.1963@postgrespro.ru", "phone": "+70936227604"}
0005433102052	4DBDD5	4394 370409	NINA KAZAKOVA	{"email": "nina-kazakova.26021970@postgrespro.ru", "phone": "+70391523210"}
0005433102053	1FBB11	2907 143734	VYACHESLAV BORISOV	{"phone": "+70712438608"}
0005433102054	22303E	4490 286045	SVETLANA MARTYNOVA	{"email": "martynova.svetlana-031969@postgrespro.ru", "phone": "+70827768641"}
0005433102055	DD6F19	0167 969728	PAVEL FROLOV	{"email": "frolovp.28051979@postgrespro.ru", "phone": "+70203881187"}
0005433102056	84FC29	0466 948555	MARINA ZHUKOVA	{"email": "m.zhukova.1968@postgrespro.ru", "phone": "+70491489649"}
0005433102057	84FC29	7858 367072	ALEKSANDR DMITRIEV	{"phone": "+70351952414"}
0005433102058	84FC29	5786 979887	IVAN FEDOTOV	{"email": "fedotov.ivan.081971@postgrespro.ru", "phone": "+70665529551"}
0005433102059	7A4395	7404 363503	MAKSIM NIKOLAEV	{"phone": "+70960660183"}
0005433102060	42DEA0	0459 862375	BORIS FROLOV	{"email": "frolov-boris.101982@postgrespro.ru", "phone": "+70839459115"}
0005433102061	6E9A96	5422 215639	EKATERINA KUZNECOVA	{"phone": "+70367409786"}
0005433102062	6E9A96	0704 323108	GALIYA DENISOVA	{"email": "denisova.galiya-02101970@postgrespro.ru", "phone": "+70693573858"}
0005433102063	F37C99	3333 544537	TATYANA IVANOVA	{"email": "tivanova10071958@postgrespro.ru", "phone": "+70809085802"}
0005433102064	E4EA44	2927 917783	VALENTINA IVANOVA	{"email": "v-ivanova_041978@postgrespro.ru", "phone": "+70728189055"}
0005433102065	23D265	9276 557515	TATYANA TITOVA	{"phone": "+70227981820"}
0005433102066	0F8879	1123 140576	EGOR ZAKHAROV	{"email": "egorzakharov-051973@postgrespro.ru", "phone": "+70779016907"}
0005433102067	F81A01	7395 479199	VLADIMIR BORISOV	{"email": "v.borisov.021970@postgrespro.ru", "phone": "+70224646381"}
0005433102068	499B74	3581 208765	LIDIYA MIRONOVA	{"email": "l-mironova-22051974@postgrespro.ru", "phone": "+70733986593"}
0005433102069	3BF6F4	3056 465577	GENNADIY NIKITIN	{"phone": "+70209743232"}
0005433102070	F265B1	9966 002938	ALEKSANDR STEPANOV	{"email": "stepanova_29101951@postgrespro.ru", "phone": "+70911382265"}
0005433102071	30B6C3	0100 497611	NADEZHDA MAKAROVA	{"email": "n.makarova1965@postgrespro.ru", "phone": "+70749129613"}
0005433102072	30B6C3	5566 878484	EKATERINA KAZAKOVA	{"phone": "+70884024630"}
0005433102073	585C2E	2036 563972	OLGA LEBEDEVA	{"phone": "+70094920323"}
0005433102074	585C2E	6310 687391	ALEKSANDR VOLKOV	{"email": "a.volkov_28051975@postgrespro.ru", "phone": "+70510734379"}
0005433102075	9176E9	3815 459131	ULYANA MEDVEDEVA	{"phone": "+70962669627"}
0005433102076	C3BF7F	2004 374914	DENIS GRIGOREV	{"phone": "+70660685215"}
0005433102077	D6A645	6554 002761	OLESYA FILATOVA	{"email": "filatova_o_1967@postgrespro.ru", "phone": "+70194370172"}
0005433102078	D6A645	6622 038577	TATYANA ISAEVA	{"phone": "+70479086504"}
0005433102079	B3EE9C	4773 202800	OLGA KISELEVA	{"email": "olga_kiseleva1970@postgrespro.ru", "phone": "+70080919425"}
0005433102080	D046B7	9243 541307	SVETLANA KUZNECOVA	{"phone": "+70267254056"}
0005433102081	CAB6A3	1882 017186	TATYANA AKIMOVA	{"phone": "+70942352115"}
0005433102082	B80EC0	1595 726636	VIOLETTA GERASIMOVA	{"phone": "+70439462919"}
0005433102083	A52BF3	0241 352136	LYUBOV DAVYDOVA	{"email": "davydova_lyubov-1968@postgrespro.ru", "phone": "+70142912735"}
0005433102084	A52BF3	0982 952332	IVAN SCHERBAKOV	{"phone": "+70655616034"}
0005433102085	192FCE	8434 573978	IVAN CHERNOV	{"phone": "+70098530093"}
0005433102086	192FCE	7423 660719	ALEKSANDR TARASOV	{"email": "tarasov_a12041979@postgrespro.ru", "phone": "+70144833407"}
0005433102509	1240F1	2826 535031	VLADIMIR KOZLOV	{"phone": "+70852389225"}
0005433102087	D7FABE	7176 721405	TATYANA NOVIKOVA	{"email": "novikova.t_011965@postgrespro.ru", "phone": "+70864169636"}
0005433102088	D7FABE	5253 545433	ALSU VASILEVA	{"phone": "+70507795318"}
0005433102089	5FE733	8877 249173	VALERIY KUZNECOV	{"email": "kuznecov-v.121978@postgrespro.ru", "phone": "+70628097806"}
0005433102090	5FE733	6514 728503	RAISA ALEKSEEVA	{"phone": "+70862277745"}
0005433102091	A4B97C	5838 386681	LYUBOV TARASOVA	{"phone": "+70510222613"}
0005433102092	23D0B2	2253 280269	ANASTASIYA ALEKSANDROVA	{"phone": "+70887236023"}
0005433102093	BA8060	8329 514660	GALINA SOKOLOVA	{"email": "g-sokolova011962@postgrespro.ru", "phone": "+70864959967"}
0005433102094	BA8060	7641 930496	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila_1971@postgrespro.ru", "phone": "+70720995989"}
0005433102095	A40687	8600 933135	NATALYA KOROLEVA	{"email": "koroleva_natalya_111971@postgrespro.ru", "phone": "+70106429686"}
0005433102096	A40687	4099 734139	EKATERINA DAVYDOVA	{"email": "davydova_ekaterina.121966@postgrespro.ru", "phone": "+70212435418"}
0005433102097	BFFDAE	8410 087359	GALINA PETROVA	{"phone": "+70924701658"}
0005433102098	A041DC	3583 781286	SVETLANA SOKOLOVA	{"phone": "+70664254205"}
0005433102099	A041DC	1748 589323	SVETLANA POPOVA	{"email": "popova-svetlana_101971@postgrespro.ru", "phone": "+70782143294"}
0005433102100	78DBA7	5926 808910	ALEKSEY KUZNECOV	{"email": "alekseykuznecov091981@postgrespro.ru", "phone": "+70383156574"}
0005433102101	9073BE	0236 380197	LARISA NIKOLAEVA	{"phone": "+70200104079"}
0005433102102	9073BE	2300 117802	TATYANA KAZAKOVA	{"email": "t-kazakova.051969@postgrespro.ru", "phone": "+70434737465"}
0005433102103	BF3CEC	5971 162634	SVETLANA MIRONOVA	{"email": "mironova_svetlana-09021983@postgrespro.ru", "phone": "+70884438509"}
0005433102104	FBFC18	3841 563704	VALERIY POPOV	{"email": "valeriy-popov_081976@postgrespro.ru", "phone": "+70338148508"}
0005433102105	FBFC18	3650 688012	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-1983@postgrespro.ru", "phone": "+70096540869"}
0005433102106	0AC0B8	3407 464863	RAISA VOLKOVA	{"email": "volkova_r.1980@postgrespro.ru", "phone": "+70741306761"}
0005433102107	73412E	9668 405434	ALEKSEY KUZNECOV	{"email": "a-kuznecov_24031979@postgrespro.ru", "phone": "+70315476617"}
0005433102108	11CBA9	8363 276344	ELENA PETROVA	{"phone": "+70963198492"}
0005433102109	D3255C	6317 422720	ALEKSANDR BARANOV	{"phone": "+70453023126"}
0005433102110	570F6E	8756 846653	YAKOV EGOROV	{"phone": "+70045411197"}
0005433102111	042816	6541 404067	EVGENIY FILIPPOV	{"email": "filippovevgeniy.1980@postgrespro.ru", "phone": "+70565184266"}
0005433102112	5FF703	1323 411693	OLGA KONDRATEVA	{"phone": "+70772280946"}
0005433102113	DA6DE8	7257 699101	SERGEY KRASNOV	{"phone": "+70039573003"}
0005433102114	DA6DE8	4433 969322	SVETLANA STEPANOVA	{"phone": "+70823308283"}
0005433102115	8BE4EB	2934 228020	ALEKSANDRA ARKHIPOVA	{"phone": "+70090473053"}
0005433102116	8BE4EB	9284 949296	MAKSIM IVANOV	{"phone": "+70223811165"}
0005433102117	BA5F96	0541 461321	NINA FROLOVA	{"email": "frolovan_091960@postgrespro.ru", "phone": "+70012845564"}
0005433102118	F33449	0875 366222	SERGEY KUZNECOV	{"email": "kuznecovs-071972@postgrespro.ru", "phone": "+70443651027"}
0005433102119	D4BD11	6710 880701	MARINA TROFIMOVA	{"phone": "+70428542967"}
0005433102120	C28367	5805 167351	MARIYA LEBEDEVA	{"phone": "+70070505124"}
0005433102121	C28367	6369 094038	YULIYA LEBEDEVA	{"phone": "+70545675543"}
0005433102122	B8F17F	5458 305534	ALEKSEY KUZMIN	{"phone": "+70631207936"}
0005433102123	F6D936	4035 988046	DMITRIY VOROBEV	{"email": "d_vorobev-31011971@postgrespro.ru", "phone": "+70571987592"}
0005433102124	091C76	6989 691622	EVGENIY KUDRYASHOV	{"phone": "+70001758204"}
0005433102125	B2BF24	3960 555172	OLGA SOLOVEVA	{"phone": "+70032240465"}
0005433102126	76613F	1091 420679	PRASKOVYA POTAPOVA	{"email": "praskovya-potapova26071972@postgrespro.ru", "phone": "+70536653002"}
0005433102127	0D6112	2128 519523	ALEKSEY IVANOV	{"phone": "+70405098091"}
0005433102128	0C461C	2355 438410	SERGEY ZHUKOV	{"email": "sergey-zhukov_1973@postgrespro.ru", "phone": "+70394809222"}
0005433102129	0C461C	6760 278961	IRINA GUSEVA	{"email": "i.guseva.02041963@postgrespro.ru", "phone": "+70686688153"}
0005433102130	62461A	6464 100695	VLADIMIR ISAEV	{"email": "vladimirisaev111973@postgrespro.ru", "phone": "+70861521622"}
0005433102131	C6F773	3815 086979	LARISA KUZMINA	{"email": "kuzmina_l.01081966@postgrespro.ru", "phone": "+70419120266"}
0005433102132	04EBAF	7159 731636	SERGEY SERGEEV	{"email": "sergeev.s.1978@postgrespro.ru", "phone": "+70086970228"}
0005433102133	091B09	9676 369485	KSENIYA MASLOVA	{"phone": "+70985880313"}
0005433102134	69FFBD	5281 935653	VIOLETTA KUZMINA	{"email": "kuzmina.violetta_21011971@postgrespro.ru", "phone": "+70011080463"}
0005433102135	69FFBD	0187 869779	SERGEY VASILEV	{"email": "vasilevsergey_081964@postgrespro.ru", "phone": "+70811623041"}
0005433102136	696C2E	6469 076193	LYUBOV KUZMINA	{"email": "lyubov.kuzmina19071972@postgrespro.ru", "phone": "+70138770813"}
0005433102137	696C2E	1169 691417	SERGEY KUZNECOV	{"phone": "+70676905939"}
0005433102138	8E6F1F	2752 421963	NATALYA ZAYCEVA	{"email": "n-zayceva-041977@postgrespro.ru", "phone": "+70394164685"}
0005433102139	8E6F1F	1561 743508	VIKTOR GUSEV	{"email": "gusevv1977@postgrespro.ru", "phone": "+70783263630"}
0005433102140	91D950	8304 178797	MARINA ZAKHAROVA	{"email": "m.zakharova_011983@postgrespro.ru", "phone": "+70620961904"}
0005433102141	DD65D8	0191 981538	RODION GUSEV	{"phone": "+70981743910"}
0005433102142	AA4AE1	2523 073227	VITALIY KUZNECOV	{"email": "vitaliy-kuznecov.1968@postgrespro.ru", "phone": "+70224316762"}
0005433102143	0D6524	1940 895364	VIKTORIYA NESTEROVA	{"email": "nesterovaviktoriya-02091978@postgrespro.ru", "phone": "+70618612117"}
0005433102144	7EDA0F	4825 974988	PETR MOISEEV	{"phone": "+70723871535"}
0005433102145	F3AE32	8478 864844	VALENTINA TIKHONOVA	{"phone": "+70738100574"}
0005433102569	B8809C	8900 498480	NIKOLAY IVANOV	{"phone": "+70990532806"}
0005433102146	0B9264	9757 088502	SVETLANA ZAYCEVA	{"email": "s-zayceva_031973@postgrespro.ru", "phone": "+70295453350"}
0005433102147	C4D9C7	1439 437421	ALEKSANDR ANTONOV	{"email": "antonovaleksandr.1970@postgrespro.ru", "phone": "+70623214777"}
0005433102148	F2B829	7660 145939	MARIYA IVANOVA	{"email": "ivanova-m-031979@postgrespro.ru", "phone": "+70256368110"}
0005433102149	F2B829	8635 747330	ELENA GORBUNOVA	{"email": "gorbunova-e-121970@postgrespro.ru", "phone": "+70570288072"}
0005433102150	6231FC	9248 086794	LYUDMILA VLASOVA	{"phone": "+70328282182"}
0005433102151	04366C	5446 859321	FEDOR BORISOV	{"email": "f.borisov_041977@postgrespro.ru", "phone": "+70433345748"}
0005433102152	4653CE	1181 665765	ALEKSANDR ALEKSEEV	{"email": "alekseev-a-02101972@postgrespro.ru", "phone": "+70372994563"}
0005433102153	4653CE	0656 744154	RAVIL ANDREEV	{"email": "andreev.ravil.25101970@postgrespro.ru", "phone": "+70194717257"}
0005433102154	B005A5	8202 109265	GALINA TIMOFEEVA	{"email": "g.timofeeva-031983@postgrespro.ru", "phone": "+70487349341"}
0005433102155	B005A5	2469 061675	TATYANA ANTONOVA	{"phone": "+70730514321"}
0005433102156	3B0EE3	9852 095543	VIKTOR KISELEV	{"email": "v_kiselev_21011970@postgrespro.ru", "phone": "+70905639298"}
0005433102157	3B0EE3	4379 989394	ILYA VLASOV	{"email": "vlasovilya_021971@postgrespro.ru", "phone": "+70734534912"}
0005433102158	09EFFA	8095 091101	ROMAN GAVRILOV	{"email": "gavrilov_roman_1966@postgrespro.ru", "phone": "+70100938299"}
0005433102159	0F65A0	6979 594468	ALEKSEY MOROZOV	{"phone": "+70151345443"}
0005433102160	31CF7A	7934 261111	RAISA SOKOLOVA	{"phone": "+70010969945"}
0005433102161	1A6A5A	9670 715789	ANGELINA ARKHIPOVA	{"phone": "+70528506893"}
0005433102162	D6CC69	1088 703264	ELIZAVETA IVANOVA	{"email": "ivanova-elizaveta_011968@postgrespro.ru", "phone": "+70003268127"}
0005433102163	D6CC69	4394 220093	NATALYA POPOVA	{"email": "natalyapopova-1973@postgrespro.ru", "phone": "+70368555758"}
0005433102164	A731C1	7004 665268	VLADIMIR SIDOROV	{"email": "v-sidorov_1974@postgrespro.ru", "phone": "+70547122828"}
0005433102165	A731C1	9844 379008	KIRA KOVALEVA	{"email": "kovalevakira1974@postgrespro.ru", "phone": "+70933983542"}
0005433102166	994860	0670 591188	OLGA KOROLEVA	{"phone": "+70893773848"}
0005433102167	2A2A9E	3974 280046	NIKOLAY BELOV	{"email": "nikolay.belov_031976@postgrespro.ru", "phone": "+70888124254"}
0005433102168	F484D2	5433 259061	ALEKSANDRA SERGEEVA	{"phone": "+70886218505"}
0005433102169	F484D2	7636 443928	ELENA ABRAMOVA	{"phone": "+70592227447"}
0005433102170	D8A882	5041 119426	DMITRIY NIKITIN	{"email": "d.nikitin_18071983@postgrespro.ru", "phone": "+70513955483"}
0005433102171	1727ED	0505 875288	ROMAN NIKOLAEV	{"phone": "+70403147801"}
0005433102172	6ABEA0	2360 036059	POLINA PETROVA	{"phone": "+70313663505"}
0005433102173	F41FCE	5138 583801	DANILA POPOV	{"email": "danilapopov_19071969@postgrespro.ru", "phone": "+70490715496"}
0005433102174	F41FCE	1198 695428	ANZHELA SEMENOVA	{"email": "a.semenova-1969@postgrespro.ru", "phone": "+70329483733"}
0005433102175	06E14F	4563 929000	TAMARA VASILEVA	{"email": "tamara.vasileva-111976@postgrespro.ru", "phone": "+70227914615"}
0005433102176	AA3D0A	0059 335261	ANNA MASLOVA	{"email": "maslova.anna-1973@postgrespro.ru", "phone": "+70218640890"}
0005433102177	3D1229	6575 906508	MIKHAIL MAKAROV	{"email": "mikhail.makarov-071986@postgrespro.ru", "phone": "+70456717158"}
0005433102178	FB73FB	7500 189886	OLGA MAKAROVA	{"phone": "+70180675993"}
0005433102179	609551	1851 670456	EVGENIY MIKHAYLOV	{"phone": "+70098520577"}
0005433102180	265A89	6855 994010	ALEKSEY FEDOTOV	{"phone": "+70571614111"}
0005433102181	97D812	3533 148692	ALEKSANDR GORBUNOV	{"phone": "+70391023333"}
0005433102182	600205	8602 454456	NIKOLAY NAUMOV	{"email": "naumov.nikolay_101969@postgrespro.ru", "phone": "+70267431923"}
0005433102183	600205	1415 050199	DARYA BORISOVA	{"email": "borisova_d-1975@postgrespro.ru", "phone": "+70530390313"}
0005433102184	149D5D	9302 924294	NURIYA MARTYNOVA	{"phone": "+70062937889"}
0005433102185	149D5D	9402 844363	ELENA KARPOVA	{"email": "e-karpova_05101980@postgrespro.ru", "phone": "+70464394414"}
0005433102186	1C9BEC	5344 534248	VLADIMIR IVANOV	{"email": "ivanov_v.091967@postgrespro.ru", "phone": "+70470946379"}
0005433102187	891423	3132 776711	IVAN MAKAROV	{"email": "i-makarov-1970@postgrespro.ru", "phone": "+70838836120"}
0005433102188	891423	4356 364064	NADEZHDA PETROVA	{"email": "nadezhda.petrova-02061979@postgrespro.ru", "phone": "+70249638422"}
0005433102189	03ADF4	5191 205015	OKSANA YAKOVLEVA	{"phone": "+70789649590"}
0005433102190	03ADF4	2809 941310	NIKOLAY VASILEV	{"email": "nikolay-vasilev011960@postgrespro.ru", "phone": "+70038019305"}
0005433102191	010A87	7164 325996	KIRILL CHERNOV	{"email": "k.chernov_1975@postgrespro.ru", "phone": "+70801376360"}
0005433102192	EF12D4	3543 589614	ANATOLIY ANTONOV	{"phone": "+70546749348"}
0005433102193	1CCC69	3145 716884	KONSTANTIN FOMIN	{"email": "kfomin-061967@postgrespro.ru", "phone": "+70111097718"}
0005433102194	1CCC69	3214 524419	IVAN KUZNECOV	{"phone": "+70789645639"}
0005433102195	909D78	6573 803047	SOFYA SERGEEVA	{"phone": "+70958203549"}
0005433102196	909D78	9975 656890	ANTON MOROZOV	{"email": "morozovanton.011983@postgrespro.ru", "phone": "+70460093734"}
0005433102197	6E2701	7295 570584	FEDOR KOZLOV	{"phone": "+70757357602"}
0005433102198	6E2701	9222 353516	NINA SOKOLOVA	{"email": "n-sokolova1962@postgrespro.ru", "phone": "+70390895659"}
0005433102199	BBA9B0	1648 668436	NINA GORBUNOVA	{"phone": "+70004619198"}
0005433102200	BBA9B0	5225 908554	IRINA IVANOVA	{"phone": "+70662032014"}
0005433102201	E96A40	4796 254215	DANIL BORISOV	{"phone": "+70996708929"}
0005433102202	89A643	7110 670032	VLADIMIR SOLOVEV	{"phone": "+70129134698"}
0005433102203	84841C	7697 832627	ALEKSEY STEPANOV	{"email": "a.stepanov27041970@postgrespro.ru", "phone": "+70523842539"}
0005433102204	84841C	0624 623379	LEONTIY DMITRIEV	{"email": "leontiy-dmitriev1973@postgrespro.ru", "phone": "+70767176065"}
0005433102206	280E0D	1995 066917	VALENTINA KRASNOVA	{"email": "krasnovav1968@postgrespro.ru", "phone": "+70341464772"}
0005433102207	CF22B1	5008 063696	TATYANA POTAPOVA	{"email": "t.potapova-27071971@postgrespro.ru", "phone": "+70869771588"}
0005433102208	342A9D	3024 427235	DMITRIY KOROLEV	{"phone": "+70229754427"}
0005433102209	342A9D	0704 325605	ALEKSEY AFANASEV	{"phone": "+70835731665"}
0005433102210	481B81	0077 902986	NIKOLAY KONOVALOV	{"phone": "+70996977131"}
0005433102211	481B81	7879 469223	SNEZHANA NIKOLAEVA	{"email": "nikolaeva_s.11031975@postgrespro.ru", "phone": "+70162535899"}
0005433102212	D9F123	1412 394974	ANTONINA KUZNECOVA	{"phone": "+70854035657"}
0005433102213	CC27B2	4827 402233	ANATOLIY MAKSIMOV	{"email": "maksimov.anatoliy_31051978@postgrespro.ru", "phone": "+70396334233"}
0005433102214	CC27B2	3244 012322	ANNA BORISOVA	{"email": "borisova.anna021975@postgrespro.ru", "phone": "+70726776532"}
0005433102215	2AF462	5342 422043	IVAN IVANOV	{"phone": "+70507258574"}
0005433102216	54BE64	2183 747388	ANDREY ALEKSEEV	{"phone": "+70423204469"}
0005433102217	54BE64	2489 104836	NADEZHDA MAKSIMOVA	{"phone": "+70458128630"}
0005433102218	E3AF51	2090 047083	IGOR CHERNOV	{"email": "i.chernov_1976@postgrespro.ru", "phone": "+70518240672"}
0005433102219	E3AF51	5637 369537	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey_061973@postgrespro.ru", "phone": "+70930599349"}
0005433102220	2012C6	4685 468983	ALENA GORBUNOVA	{"email": "gorbunova_alena-1970@postgrespro.ru", "phone": "+70223631501"}
0005433102221	2012C6	7549 258339	ILYA KUZMIN	{"email": "kuzmini.1971@postgrespro.ru", "phone": "+70691289217"}
0005433102222	119E42	0748 794872	DMITRIY MOROZOV	{"email": "morozov.d_1959@postgrespro.ru", "phone": "+70328224902"}
0005433102223	119E42	1888 463166	OLESYA MASLOVA	{"email": "o_maslova_07011969@postgrespro.ru", "phone": "+70708049241"}
0005433102224	21A7E2	4271 962539	MARIYA SOKOLOVA	{"email": "msokolova041978@postgrespro.ru", "phone": "+70889255280"}
0005433102225	21A7E2	2122 108912	VLADIMIR OSIPOV	{"email": "vladimir_osipov_021978@postgrespro.ru", "phone": "+70925070916"}
0005433102226	D118D1	3463 913336	VIKTORIYA VOROBEVA	{"email": "vorobeva-v-1967@postgrespro.ru", "phone": "+70196374513"}
0005433102227	D118D1	6509 578884	NATALYA DENISOVA	{"phone": "+70600138400"}
0005433102228	3B7652	0970 198791	ALFIYA SOKOLOVA	{"email": "sokolova-a041979@postgrespro.ru", "phone": "+70936531366"}
0005433102229	3B7652	9759 226021	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr-1963@postgrespro.ru", "phone": "+70123483386"}
0005433102230	5DE1FF	3167 392318	ALEKSEY BORISOV	{"email": "borisov_a_1974@postgrespro.ru", "phone": "+70296476984"}
0005433102231	556281	8404 622763	LYUBOV MIRONOVA	{"phone": "+70644896438"}
0005433102232	2E221A	3234 589195	TATYANA ALEKSEEVA	{"email": "alekseeva.tatyana1976@postgrespro.ru", "phone": "+70926581254"}
0005433102233	7511D3	8590 453963	VYACHESLAV KISELEV	{"phone": "+70967970008"}
0005433102234	796468	6837 388919	DMITRIY VOLKOV	{"email": "volkov_dmitriy-101977@postgrespro.ru", "phone": "+70789321059"}
0005433102235	796468	7792 156271	MIKHAIL MAKAROV	{"phone": "+70552058590"}
0005433102236	1263ED	7441 572925	OLGA CHERNOVA	{"phone": "+70943322173"}
0005433102237	861BB6	4559 191447	KONSTANTIN NIKOLAEV	{"email": "knikolaev-031974@postgrespro.ru", "phone": "+70744898235"}
0005433102238	64662F	4747 007560	EVDOKIYA KOROLEVA	{"phone": "+70690565081"}
0005433102239	408AEF	8252 895358	ELENA EFIMOVA	{"email": "e_efimova-1976@postgrespro.ru", "phone": "+70406239776"}
0005433102240	87990F	8871 440437	MIKHAIL ANTONOV	{"phone": "+70435139075"}
0005433102241	C64507	7992 934607	ALEKSEY POPOV	{"email": "popova1959@postgrespro.ru", "phone": "+70859876027"}
0005433102242	843679	6413 614706	ANGELINA ZAYCEVA	{"email": "zaycevaa101967@postgrespro.ru", "phone": "+70884677247"}
0005433102243	482FAB	3084 988083	VLADIMIR DAVYDOV	{"email": "davydov-v_1959@postgrespro.ru", "phone": "+70595993586"}
0005433102244	482FAB	0126 344917	ALEKSEY MEDVEDEV	{"email": "a_medvedev-19091965@postgrespro.ru", "phone": "+70462142325"}
0005433102245	289CAF	1279 057393	VIKTOR GORBUNOV	{"phone": "+70810433072"}
0005433102246	289CAF	8807 123115	YULIYA KOLESNIKOVA	{"email": "kolesnikova-yuliya-11041966@postgrespro.ru", "phone": "+70590527648"}
0005433102247	F151C3	1111 839606	ALEKSANDR IVANOV	{"phone": "+70780399452"}
0005433102248	CBD470	2656 174858	NATALYA VOROBEVA	{"email": "vorobeva_natalya_121977@postgrespro.ru", "phone": "+70058482618"}
0005433102249	CBD470	1098 994357	ALEKSEY OSIPOV	{"phone": "+70021724535"}
0005433102250	9B98C0	4210 219021	EVGENIY FROLOV	{"email": "frolov_e.22031971@postgrespro.ru", "phone": "+70839961388"}
0005433102251	05D95F	3023 091871	ROZA MEDVEDEVA	{"phone": "+70914635609"}
0005433102252	4F616E	0108 496183	EDUARD MELNIKOV	{"email": "eduard.melnikov.09111971@postgrespro.ru", "phone": "+70876894646"}
0005433102253	532232	9552 826175	KAMILLA ZHUKOVA	{"email": "zhukovak.031967@postgrespro.ru", "phone": "+70601406990"}
0005433102254	532232	5954 579270	ELENA PETROVA	{"email": "e_petrova-1969@postgrespro.ru", "phone": "+70567685834"}
0005433102255	532232	2408 139839	MIKHAIL RODIONOV	{"phone": "+70180517046"}
0005433102256	FECB75	7420 559367	STANISLAV POPOV	{"phone": "+70463250205"}
0005433102257	92C415	2933 438319	ARTEM MOROZOV	{"email": "morozov.artem-1978@postgrespro.ru", "phone": "+70253624734"}
0005433102258	92C415	1827 460406	EVGENIYA BELYAEVA	{"phone": "+70558115416"}
0005433102259	629C7C	0939 666709	ALEKSEY VASILEV	{"email": "vasileva.061974@postgrespro.ru", "phone": "+70957223391"}
0005433102260	629C7C	0604 962897	YURIY OSIPOV	{"phone": "+70787925119"}
0005433102261	89D25F	5711 027318	MARAT VASILEV	{"phone": "+70178964493"}
0005433102262	CB2CD2	2583 377282	VASILIY ROMANOV	{"phone": "+70486891231"}
0005433102263	CB2CD2	8731 168377	IRINA PETROVA	{"email": "petrova.irina.1978@postgrespro.ru", "phone": "+70187188557"}
0005433102264	A3EBAD	6867 300445	DMITRIY SERGEEV	{"email": "sergeev.d31081966@postgrespro.ru", "phone": "+70779061371"}
0005433102265	CDFB8B	1519 068756	ELIZAVETA KRASNOVA	{"email": "elizavetakrasnova_121971@postgrespro.ru", "phone": "+70193634471"}
0005433102266	CDFB8B	7819 607420	NADEZHDA VASILEVA	{"email": "vasileva-n-1971@postgrespro.ru", "phone": "+70922166223"}
0005433102267	83466B	1471 754424	VALENTINA KOZLOVA	{"phone": "+70609419867"}
0005433102268	E23AB1	1276 135623	PAVEL KUZMIN	{"email": "pkuzmin.1976@postgrespro.ru", "phone": "+70256388376"}
0005433102269	5F3C31	3689 097200	MIKHAIL FEDOROV	{"phone": "+70316031578"}
0005433102270	5F3C31	0945 731645	IGOR KUZNECOV	{"phone": "+70737881892"}
0005433102271	5F3C31	6280 909634	VALERIYA POPOVA	{"phone": "+70472782661"}
0005433102272	11B5A7	2063 413611	ANDREY GORBUNOV	{"phone": "+70679024197"}
0005433102273	11B5A7	2637 743198	DANILA VLASOV	{"phone": "+70479949792"}
0005433102274	A20C07	5658 545872	LARISA SERGEEVA	{"email": "larisa-sergeeva-041974@postgrespro.ru", "phone": "+70648589117"}
0005433102275	A20C07	7135 171240	ALEKSANDR FROLOV	{"phone": "+70037518752"}
0005433102276	89FDBB	9742 804609	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr.061956@postgrespro.ru", "phone": "+70143253916"}
0005433102277	89FDBB	0167 553080	ALEKSEY FEDOTOV	{"phone": "+70926111864"}
0005433102278	0F62D1	9337 995346	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-09061968@postgrespro.ru", "phone": "+70259616359"}
0005433102279	8EE6F5	8061 504399	VALENTINA EFIMOVA	{"email": "efimovav1975@postgrespro.ru", "phone": "+70909804099"}
0005433102280	8EE6F5	5737 156507	NATALYA ALEKSEEVA	{"email": "natalya.alekseeva_10061979@postgrespro.ru", "phone": "+70220281669"}
0005433102281	8EE6F5	1080 074215	MARIYA ISAEVA	{"phone": "+70643004622"}
0005433102282	D283DA	5258 377548	ANDREY KRASNOV	{"email": "krasnov-andrey.021979@postgrespro.ru", "phone": "+70341889190"}
0005433102283	829B83	6026 564386	ELENA KUDRYASHOVA	{"email": "kudryashovaelena-1962@postgrespro.ru", "phone": "+70425462559"}
0005433102284	829B83	3589 471991	NIKOLAY IVANOV	{"email": "nikolayivanov_16091975@postgrespro.ru", "phone": "+70701690421"}
0005433102285	829B83	3313 582631	SERGEY SEMENOV	{"phone": "+70434291441"}
0005433102286	A62B8B	7183 755940	OLGA FADEEVA	{"email": "fadeevaolga17121977@postgrespro.ru", "phone": "+70231668181"}
0005433102287	7FEDCE	3172 711137	VLADIMIR IVANOV	{"phone": "+70814723439"}
0005433102288	4FC8D3	7594 326478	IVAN ANDREEV	{"email": "i-andreev06081974@postgrespro.ru", "phone": "+70039576065"}
0005433102289	41AA04	1412 576172	VLADIMIR ILIN	{"phone": "+70725706298"}
0005433102290	F4CEFF	2558 849670	IVAN ZHUKOV	{"email": "i_zhukov.041976@postgrespro.ru", "phone": "+70125156387"}
0005433102291	FC0788	5943 696290	ANASTASIYA VASILEVA	{"phone": "+70127438210"}
0005433102292	EC1FCC	8774 916035	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_10121976@postgrespro.ru", "phone": "+70928409199"}
0005433102293	A071A5	5751 578903	NATALYA ILINA	{"phone": "+70836730653"}
0005433102294	3492CB	8937 676196	LIDIYA DMITRIEVA	{"email": "l_dmitrieva_1969@postgrespro.ru", "phone": "+70001877471"}
0005433102295	F1C322	9874 854146	IRINA POPOVA	{"email": "irina-popova.30121962@postgrespro.ru", "phone": "+70443892484"}
0005433102296	F1C322	7893 088972	ANDREY NIKITIN	{"phone": "+70195706721"}
0005433102297	F1C322	0409 849963	IVAN SCHERBAKOV	{"email": "scherbakovivan15061973@postgrespro.ru", "phone": "+70998032762"}
0005433102298	854ABF	1641 823660	EVGENIY DAVYDOV	{"email": "davydov-evgeniy_1969@postgrespro.ru", "phone": "+70731195576"}
0005433102299	776EEC	0712 623459	KONSTANTIN ABRAMOV	{"email": "abramovkonstantin-071965@postgrespro.ru", "phone": "+70581407417"}
0005433102300	91EF6E	4349 932952	VALENTINA ALEKSEEVA	{"email": "valentina.alekseeva08061970@postgrespro.ru", "phone": "+70569032866"}
0005433102301	F94E69	4123 422572	AYRAT TIKHONOV	{"phone": "+70320164394"}
0005433102302	14BA44	1172 371549	VITALIY DAVYDOV	{"phone": "+70766733998"}
0005433102303	E8A32C	2228 695790	IGOR KISELEV	{"phone": "+70580635991"}
0005433102304	E8A32C	1374 537102	SERGEY VOLKOV	{"phone": "+70992628352"}
0005433102305	5DC09A	5524 730940	EVGENIY MATVEEV	{"email": "matveev.evgeniy15011981@postgrespro.ru", "phone": "+70496464741"}
0005433102306	5DC09A	0229 213868	NATALIYA FEDOROVA	{"phone": "+70236598798"}
0005433102307	318959	1623 182040	SERGEY NIKOLAEV	{"email": "nikolaev_s_1976@postgrespro.ru", "phone": "+70360264067"}
0005433102308	318959	3468 193521	SERGEY KUZMIN	{"email": "kuzmins.111968@postgrespro.ru", "phone": "+70170656596"}
0005433102309	E92B68	8500 590731	ANATOLIY MATVEEV	{"email": "a.matveev-27061976@postgrespro.ru", "phone": "+70387315711"}
0005433102310	E92B68	9888 614356	RAFAEL KUZNECOV	{"phone": "+70262015336"}
0005433102311	AA9D2B	0971 965940	VALENTINA ANISIMOVA	{"phone": "+70139784055"}
0005433102312	FDEF61	4051 607479	LILIYA KUZNECOVA	{"phone": "+70723782864"}
0005433102313	2DE17A	3296 949172	ANZHELA KOVALEVA	{"phone": "+70963052751"}
0005433102314	CB1801	9484 590639	KARINA IVANOVA	{"email": "karinaivanova-021966@postgrespro.ru", "phone": "+70491840182"}
0005433102315	CB1801	8435 344680	OLGA SMIRNOVA	{"phone": "+70303123082"}
0005433102316	2B5B58	4717 966309	VYACHESLAV KONOVALOV	{"phone": "+70570259771"}
0005433102317	2B5B58	9152 915535	YULIYA RYABOVA	{"phone": "+70417053137"}
0005433102318	FAB379	9237 882728	ELZA ZAYCEVA	{"email": "zayceva.elza.1976@postgrespro.ru", "phone": "+70538476850"}
0005433102319	2AC4F2	7866 589671	ANTONINA KULIKOVA	{"email": "kulikova-a.22031978@postgrespro.ru", "phone": "+70534847260"}
0005433102320	EAEBDA	7201 183590	ANATOLIY MAKAROV	{"email": "makarova-101980@postgrespro.ru", "phone": "+70259295389"}
0005433102321	CE50B4	5151 033230	EVGENIY TIMOFEEV	{"email": "evgeniy.timofeev_1983@postgrespro.ru", "phone": "+70240822331"}
0005433102322	EEA736	7253 596873	ALEKSANDRA KOZLOVA	{"phone": "+70875265889"}
0005433102323	3DF7EB	6033 868038	ELENA SEMENOVA	{"phone": "+70013514955"}
0005433102324	3DF7EB	6730 825432	PETR MEDVEDEV	{"phone": "+70645599367"}
0005433102325	AC6ECF	2047 702054	NATALYA NIKITINA	{"phone": "+70976899095"}
0005433102326	AC6ECF	4790 823056	ANZHELA KOVALEVA	{"email": "kovaleva_anzhela.1976@postgrespro.ru", "phone": "+70210554327"}
0005433102327	369313	2357 128939	OLGA EGOROVA	{"phone": "+70946679101"}
0005433102328	369313	0473 880956	VALERIYA SEMENOVA	{"phone": "+70450336178"}
0005433102329	369313	2740 376806	YULIYA BELYAEVA	{"email": "yuliya-belyaeva-061971@postgrespro.ru", "phone": "+70379864630"}
0005433102330	BA0FB5	1899 791773	NINA LUKYANOVA	{"email": "ninalukyanova29091978@postgrespro.ru", "phone": "+70915031312"}
0005433102331	BA0FB5	8012 335493	OLGA GORBUNOVA	{"phone": "+70181129454"}
0005433102332	BA0FB5	2596 142334	OLEG EGOROV	{"phone": "+70997819173"}
0005433102333	601FE6	7162 193117	MARINA BORISOVA	{"phone": "+70370378523"}
0005433102334	275D55	9085 986472	ROMAN ROMANOV	{"phone": "+70749885506"}
0005433102335	275D55	1512 836889	ANTONINA EFREMOVA	{"phone": "+70144801802"}
0005433102336	E97A0F	8914 406570	ROMAN MOROZOV	{"phone": "+70618970110"}
0005433102337	E97A0F	7611 826597	SERGEY KOZLOV	{"phone": "+70837630395"}
0005433102338	3587FA	9575 276750	NATALIYA OSIPOVA	{"email": "nosipova.031969@postgrespro.ru", "phone": "+70123008736"}
0005433102339	3587FA	8392 345000	RAMIL PAVLOV	{"phone": "+70493303090"}
0005433102340	E07959	2641 171696	VALERIY NAUMOV	{"phone": "+70051695535"}
0005433102341	E07959	3342 224067	ALEKSEY ROMANOV	{"phone": "+70768997418"}
0005433102342	D1883C	7608 723362	OLESYA KRASNOVA	{"email": "olesyakrasnova05031969@postgrespro.ru", "phone": "+70886114592"}
0005433102343	96BE0C	8491 991346	VIKTORIYA NAUMOVA	{"phone": "+70418353440"}
0005433102344	5DEE77	7145 636434	IVAN NIKITIN	{"phone": "+70205082093"}
0005433102345	5DEE77	2362 165330	TAMARA FOMINA	{"phone": "+70454194975"}
0005433102346	5DEE77	0907 971297	VYACHESLAV KONOVALOV	{"email": "konovalov.v_1979@postgrespro.ru", "phone": "+70127224743"}
0005433102347	5DEE77	7549 165577	MAKSIM KAZAKOV	{"phone": "+70046808709"}
0005433102348	419AFC	8240 086575	ALEKSANDR SIDOROV	{"phone": "+70839187811"}
0005433102349	419AFC	3837 881829	ALEKSANDRA VASILEVA	{"email": "vasileva.a021974@postgrespro.ru", "phone": "+70732997490"}
0005433102350	467C62	2685 168747	YULIYA AFANASEVA	{"phone": "+70641573495"}
0005433102351	49B0C4	5046 854832	NATALYA POLYAKOVA	{"phone": "+70970993621"}
0005433102352	96677C	7386 249732	ARINA IVANOVA	{"email": "arinaivanova-1973@postgrespro.ru", "phone": "+70312902165"}
0005433102353	01CEE8	5853 496637	ANASTASIYA ABRAMOVA	{"email": "abramova-anastasiya02071978@postgrespro.ru", "phone": "+70259564208"}
0005433102354	A7083E	1832 441028	VITALIY PETROV	{"email": "vitaliypetrov.011976@postgrespro.ru", "phone": "+70705399933"}
0005433102355	7221D0	8426 998820	LARISA MAKAROVA	{"email": "larisamakarova061973@postgrespro.ru", "phone": "+70414855832"}
0005433102356	BF32AB	1184 812783	VIKTOR ROMANOV	{"email": "viktor_romanov.1973@postgrespro.ru", "phone": "+70621975126"}
0005433102357	1E1D9A	1865 844451	ALLA BORISOVA	{"phone": "+70005081488"}
0005433102358	1E1D9A	2461 864411	GALINA PETROVA	{"email": "petrovag1971@postgrespro.ru", "phone": "+70123969876"}
0005433102359	1E1D9A	0287 293227	LYUDMILA KUZNECOVA	{"email": "lyudmila_kuznecova011985@postgrespro.ru", "phone": "+70596708195"}
0005433102360	01EE93	2482 558315	OLGA VOROBEVA	{"email": "vorobeva-olga_11041973@postgrespro.ru", "phone": "+70661034566"}
0005433102361	7AE4FE	1834 258605	OLGA TARASOVA	{"email": "olgatarasova1974@postgrespro.ru", "phone": "+70224351521"}
0005433102362	17D3C9	2942 727212	KLAVDIYA MARTYNOVA	{"phone": "+70477922541"}
0005433102363	11E69F	4756 670367	STANISLAV SIDOROV	{"email": "sidorov.s-1969@postgrespro.ru", "phone": "+70378153606"}
0005433102364	11E69F	3678 805033	ALEKSEY PETROV	{"phone": "+70019253438"}
0005433102365	692B07	5286 350416	LYUDMILA TIMOFEEVA	{"phone": "+70530826855"}
0005433102366	A593F1	9239 746395	BORIS RODIONOV	{"email": "rodionovboris-1977@postgrespro.ru", "phone": "+70712580546"}
0005433102367	A593F1	5634 695750	SERAFIM KUDRYASHOV	{"email": "kudryashov.s-111969@postgrespro.ru", "phone": "+70493543151"}
0005433102368	76676D	6046 166426	MARINA FROLOVA	{"phone": "+70271836333"}
0005433102369	F569F2	7096 477819	MIKHAIL KOZLOV	{"email": "mikhail_kozlov_1974@postgrespro.ru", "phone": "+70509079651"}
0005433102370	F569F2	7921 783728	ALLA DANILOVA	{"phone": "+70514833620"}
0005433102371	E3D290	6509 742606	VALERIYA DANILOVA	{"phone": "+70045315414"}
0005433102372	E3D290	7046 056671	KONSTANTIN ANDREEV	{"email": "kandreev_031965@postgrespro.ru", "phone": "+70798625841"}
0005433102373	DE12C3	1975 099812	ANNA LUKYANOVA	{"phone": "+70080532992"}
0005433102374	DE12C3	1417 553568	ARTUR PETROV	{"phone": "+70675082555"}
0005433102375	AB22CC	0865 188764	ANDREY OSIPOV	{"email": "andrey-osipov-1973@postgrespro.ru", "phone": "+70659514889"}
0005433102376	118662	4668 403990	YURIY KULIKOV	{"phone": "+70699096309"}
0005433102377	118662	9462 377292	KONSTANTIN MIRONOV	{"phone": "+70976627109"}
0005433102378	7D07F7	4609 919790	ALEKSEY ILIN	{"phone": "+70448400254"}
0005433102379	180D31	5504 512670	NURLAN SHEVCHENKO	{"phone": "+70534678412"}
0005433102380	180D31	8074 638137	ALEKSANDRA NAUMOVA	{"email": "a.naumova-1973@postgrespro.ru", "phone": "+70692384672"}
0005433102381	526BFC	4532 821633	OLGA EFREMOVA	{"phone": "+70195522902"}
0005433102382	526BFC	8678 167373	ALENA VASILEVA	{"email": "vasilevaa.061976@postgrespro.ru", "phone": "+70847796575"}
0005433102383	483D8C	2569 683522	DENIS TARASOV	{"phone": "+70673241762"}
0005433102384	483D8C	8868 565938	LYUBOV MOROZOVA	{"phone": "+70693837106"}
0005433102385	8A927E	2665 753009	SVETLANA ILINA	{"email": "s.ilina.02021974@postgrespro.ru", "phone": "+70259880657"}
0005433102386	182D92	3038 235829	EKATERINA KOLESNIKOVA	{"email": "kolesnikova_e-1972@postgrespro.ru", "phone": "+70893111776"}
0005433102387	9D6175	2898 647311	NIKOLAY KRASNOV	{"email": "nikolay_krasnov_051975@postgrespro.ru", "phone": "+70389383942"}
0005433102388	9D6175	0911 624688	ELENA VOLKOVA	{"email": "elena.volkova.081972@postgrespro.ru", "phone": "+70327835391"}
0005433102389	9D6175	4167 421292	YURIY SEMENOV	{"phone": "+70727777612"}
0005433102390	6B7193	1335 049612	LIDIYA LOGINOVA	{"email": "loginoval-1972@postgrespro.ru", "phone": "+70420970566"}
0005433102391	A2DED5	0996 772078	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin20081981@postgrespro.ru", "phone": "+70357590230"}
0005433102392	A2DED5	9090 619720	TATYANA PAVLOVA	{"email": "t.pavlova_28061969@postgrespro.ru", "phone": "+70501333080"}
0005433102393	589EB5	1646 910665	RAISA TIKHONOVA	{"phone": "+70815534763"}
0005433102394	E6FF5A	0556 495573	ANDREY FEDOROV	{"email": "a_fedorov_021972@postgrespro.ru", "phone": "+70085274261"}
0005433102395	E9846A	8034 651551	NADEZHDA KONOVALOVA	{"phone": "+70520263896"}
0005433102396	E9846A	6638 104724	VALERIY DAVYDOV	{"phone": "+70102488732"}
0005433102397	BB46BA	6885 534061	MARINA ROMANOVA	{"phone": "+70872556742"}
0005433102398	BB46BA	6972 710456	DMITRIY SMIRNOV	{"email": "dsmirnov_1973@postgrespro.ru", "phone": "+70901391264"}
0005433102399	BB46BA	9158 805421	MAKSIM ROMANOV	{"email": "romanovmaksim-1973@postgrespro.ru", "phone": "+70117074386"}
0005433102400	A998ED	3968 346549	ZARINA ROMANOVA	{"email": "z.romanova.101978@postgrespro.ru", "phone": "+70557094472"}
0005433102401	C89734	2203 007872	GRIGORIY SIDOROV	{"email": "sidorov-grigoriy.111962@postgrespro.ru", "phone": "+70091991951"}
0005433102402	C89734	6187 615104	ELENA ISAEVA	{"email": "isaeva.elena-1975@postgrespro.ru", "phone": "+70972933990"}
0005433102403	0BF8CB	0613 408677	ELENA RYABOVA	{"email": "ryabova.e.19121973@postgrespro.ru", "phone": "+70401043672"}
0005433102404	0BF8CB	0718 813960	MAKSIM KOZLOV	{"phone": "+70193289099"}
0005433102405	8FC449	4387 230119	ALEKSANDR CHERNOV	{"email": "chernov.a.1963@postgrespro.ru", "phone": "+70022721727"}
0005433102406	DF822B	3477 079918	ALEKSANDR MELNIKOV	{"phone": "+70150680149"}
0005433102407	03A695	1215 594322	ILYA BARANOV	{"email": "baranovilya.1980@postgrespro.ru", "phone": "+70698796982"}
0005433102464	0B6EC6	7250 856144	ALEKSANDR NAUMOV	{"phone": "+70112885285"}
0005433102408	9F4165	8776 476812	NINA FADEEVA	{"email": "fadeeva_n.22091979@postgrespro.ru", "phone": "+70526359520"}
0005433102409	71AFC7	8954 199456	SERGEY MARTYNOV	{"email": "martynovs_14021966@postgrespro.ru", "phone": "+70075469128"}
0005433102410	2BC21A	0437 326947	ALLA TIKHONOVA	{"email": "alla-tikhonova-23031967@postgrespro.ru", "phone": "+70446211220"}
0005433102411	48F394	8734 090917	NADEZHDA AFANASEVA	{"email": "afanaseva-nadezhda-041982@postgrespro.ru", "phone": "+70195117711"}
0005433102412	9F8420	4876 199434	OLGA GRISHINA	{"email": "grishina-o-14011973@postgrespro.ru", "phone": "+70108857586"}
0005433102413	9F8420	9862 033117	ALEKSEY PETROV	{"email": "petrovaleksey071975@postgrespro.ru", "phone": "+70325841253"}
0005433102414	382881	4114 247978	ARTEM ZAYCEV	{"phone": "+70763421500"}
0005433102415	382881	6262 658937	ELENA POPOVA	{"email": "e.popova.101974@postgrespro.ru", "phone": "+70842633553"}
0005433102416	9B0E9B	1942 044576	EVGENIY SIDOROV	{"email": "evgeniy.sidorov-09071973@postgrespro.ru", "phone": "+70442915205"}
0005433102417	DB0204	2389 011730	ELENA IVANOVA	{"email": "ivanova.e-081968@postgrespro.ru", "phone": "+70387373394"}
0005433102418	DB0204	7509 007122	TATYANA FILIPPOVA	{"email": "filippovatatyana-1968@postgrespro.ru", "phone": "+70813925787"}
0005433102419	6EFBBA	1991 169244	VLADIMIR BELOV	{"phone": "+70931395575"}
0005433102420	276FD7	0815 028089	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr.31011959@postgrespro.ru", "phone": "+70723636040"}
0005433102421	C864C9	3057 388009	VALERIY ANDREEV	{"phone": "+70436781092"}
0005433102422	946F2A	8697 407652	ALEKSANDR SOKOLOV	{"phone": "+70725621705"}
0005433102423	E70AFB	0025 913485	DANIIL KOROLEV	{"phone": "+70206457923"}
0005433102424	46CF3B	2470 547924	OKSANA PAVLOVA	{"phone": "+70115507852"}
0005433102425	46CF3B	2503 381946	ULYANA ZAKHAROVA	{"phone": "+70849226806"}
0005433102426	7298E2	4033 634198	LYUDMILA MIRONOVA	{"phone": "+70695478110"}
0005433102427	7298E2	9427 930296	ALEKSANDR DMITRIEV	{"email": "a_dmitriev_24061974@postgrespro.ru", "phone": "+70680112306"}
0005433102428	7298E2	0555 467853	NATALYA VOLKOVA	{"phone": "+70411557263"}
0005433102429	0F7791	9454 471432	TATYANA SEMENOVA	{"phone": "+70644067206"}
0005433102430	D94A32	5806 551444	TAMARA FADEEVA	{"email": "tamara.fadeeva.06071966@postgrespro.ru", "phone": "+70875411939"}
0005433102431	060622	8057 448306	SVETLANA PAVLOVA	{"phone": "+70649505339"}
0005433102432	060622	0112 308847	ANNA FROLOVA	{"email": "a.frolova-1983@postgrespro.ru", "phone": "+70228281821"}
0005433102433	EE65CA	6878 121933	VLADISLAV DAVYDOV	{"email": "davydov.vladislav-14111978@postgrespro.ru", "phone": "+70631708286"}
0005433102434	0BE7D3	9059 356118	YURIY ALEKSANDROV	{"email": "y_aleksandrov02111969@postgrespro.ru", "phone": "+70347140043"}
0005433102435	0BE7D3	5252 732930	EVGENIY KAZAKOV	{"phone": "+70041864887"}
0005433102436	245FE4	1913 913817	ANTONINA FEDOROVA	{"phone": "+70306416813"}
0005433102437	245FE4	5233 780953	VLADISLAV FEDOROV	{"email": "fedorov-v.13021973@postgrespro.ru", "phone": "+70867819003"}
0005433102438	A861E8	7961 836836	SVETLANA YAKOVLEVA	{"phone": "+70751025794"}
0005433102439	9A4156	3094 942659	DMITRIY MOISEEV	{"email": "dmitriy_moiseev-041974@postgrespro.ru", "phone": "+70098849722"}
0005433102440	9A4156	1924 563728	LYUDMILA MIRONOVA	{"phone": "+70040142750"}
0005433102441	97B578	4002 795513	DMITRIY KOZLOV	{"phone": "+70745835049"}
0005433102442	0EC964	4767 026594	OLEG TIMOFEEV	{"phone": "+70431872762"}
0005433102443	D9B6CC	9533 224647	ELENA SERGEEVA	{"phone": "+70866819817"}
0005433102444	FDD78C	6943 935045	NATALIYA TIKHONOVA	{"email": "tikhonova-nataliya13061971@postgrespro.ru", "phone": "+70838356692"}
0005433102445	7B71A4	3412 993698	DARYA VASILEVA	{"email": "darya_vasileva.1976@postgrespro.ru", "phone": "+70691470631"}
0005433102446	A9C808	8296 974435	VIKTOR PETROV	{"email": "petrovviktor-061967@postgrespro.ru", "phone": "+70511957339"}
0005433102447	A9C808	3580 242568	OKSANA KOROLEVA	{"email": "oksana.koroleva.041974@postgrespro.ru", "phone": "+70185761538"}
0005433102448	1DF42E	0887 801030	VALENTINA MAKAROVA	{"email": "vmakarova1964@postgrespro.ru", "phone": "+70972493080"}
0005433102449	1DF42E	9570 223665	ALEKSANDR TARASOV	{"phone": "+70861003235"}
0005433102450	FE6D44	1314 414783	SOFIYA MOROZOVA	{"phone": "+70331150608"}
0005433102451	FE6D44	2239 611625	LIDIYA MAKSIMOVA	{"phone": "+70784129025"}
0005433102452	52CCA3	2021 650229	VALENTINA IVANOVA	{"email": "ivanova-valentina-1963@postgrespro.ru", "phone": "+70307078746"}
0005433102453	54A679	6511 301855	VASILIY ALEKSEEV	{"phone": "+70113638795"}
0005433102454	9B5807	8084 596705	LIDIYA ROMANOVA	{"email": "romanova_l-1969@postgrespro.ru", "phone": "+70386823772"}
0005433102455	9B5807	5267 571996	NIKOLAY NAUMOV	{"email": "naumovn-04081970@postgrespro.ru", "phone": "+70841013112"}
0005433102456	534215	7992 576349	ANNA POLYAKOVA	{"phone": "+70769048531"}
0005433102457	D3B336	9834 489854	YULIYA KOROLEVA	{"phone": "+70957552797"}
0005433102458	867FCD	3041 580521	ALEKSANDR MIKHAYLOV	{"phone": "+70596389756"}
0005433102459	867FCD	2571 360416	NINA ERMAKOVA	{"email": "ermakova_nina091962@postgrespro.ru", "phone": "+70999772429"}
0005433102460	3FAB15	2736 804740	ANTON MIRONOV	{"phone": "+70210714716"}
0005433102461	3FAB15	4428 317814	TATYANA DANILOVA	{"phone": "+70895391095"}
0005433102462	14F836	3880 717599	ALEKSEY SMIRNOV	{"email": "smirnov_a021973@postgrespro.ru", "phone": "+70373552784"}
0005433102463	0B6EC6	9071 695247	NIKITA EGOROV	{"email": "egorov.n.14041980@postgrespro.ru", "phone": "+70451183937"}
0005433102465	0B6EC6	5604 941444	TATYANA KOROLEVA	{"email": "tkoroleva_16061964@postgrespro.ru", "phone": "+70147791291"}
0005433102466	E185C2	6644 335356	IVAN TIMOFEEV	{"email": "timofeev-ivan.09101975@postgrespro.ru", "phone": "+70576528493"}
0005433102467	757546	4429 644088	MAKSIM BORISOV	{"phone": "+70085074616"}
0005433102468	A750ED	4797 811280	MARIYA BELYAEVA	{"email": "belyaeva_mariya1991@postgrespro.ru", "phone": "+70271166092"}
0005433102469	A750ED	9174 208075	MARIYA RODIONOVA	{"phone": "+70478069768"}
0005433102470	4D540D	2587 425074	ARTEMIY KUZNECOV	{"email": "a_kuznecov011963@postgrespro.ru", "phone": "+70126974535"}
0005433102471	F52B9F	3626 788878	PETR SIDOROV	{"phone": "+70619051631"}
0005433102472	97C0A3	7677 154500	ANNA OSIPOVA	{"phone": "+70471065684"}
0005433102473	97C0A3	4028 537391	ALEKSANDR MOROZOV	{"email": "a-morozov_011967@postgrespro.ru", "phone": "+70123094822"}
0005433102474	BBE89F	4853 952979	ULYANA KUZNECOVA	{"email": "kuznecova-u-11081979@postgrespro.ru", "phone": "+70473566233"}
0005433102475	05B02B	2127 832502	TATYANA NIKITINA	{"phone": "+70693790890"}
0005433102476	8D1701	6491 721826	LYUBOV ORLOVA	{"phone": "+70519111791"}
0005433102477	9E263F	8724 139212	ALLA TIMOFEEVA	{"phone": "+70156864179"}
0005433102478	501917	7635 848138	NIKOLAY TARASOV	{"phone": "+70633795313"}
0005433102479	152C8B	3800 786760	SERGEY BORISOV	{"phone": "+70824655696"}
0005433102480	152C8B	3980 264787	VALENTINA ALEKSANDROVA	{"phone": "+70856029760"}
0005433102481	DBC196	0068 263870	ALEKSANDR KUZNECOV	{"phone": "+70701747667"}
0005433102482	DBC196	7865 050962	SERGEY IVANOV	{"phone": "+70971903138"}
0005433102483	DBC196	3407 002319	ALENA OVCHINNIKOVA	{"phone": "+70105501101"}
0005433102484	229F2B	7230 508386	IVAN NOVIKOV	{"email": "novikov-i_101959@postgrespro.ru", "phone": "+70501338708"}
0005433102485	229F2B	1752 929784	MAKSIM KUZNECOV	{"phone": "+70432534236"}
0005433102486	C6B007	6201 859232	ANDREY TIMOFEEV	{"phone": "+70311574777"}
0005433102487	C6B007	5296 688680	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov121968@postgrespro.ru", "phone": "+70113086808"}
0005433102488	AD4458	1141 088645	TAMARA NAZAROVA	{"email": "nazarovat031974@postgrespro.ru", "phone": "+70052371326"}
0005433102489	3FE8E6	3750 313901	DMITRIY KUZMIN	{"phone": "+70071680218"}
0005433102490	D4CFD4	8210 943782	DENIS NOVIKOV	{"email": "novikov.denis.061965@postgrespro.ru", "phone": "+70921363465"}
0005433102491	EC090C	1553 441141	DMITRIY ROMANOV	{"phone": "+70673817094"}
0005433102492	704DD4	1145 837075	MAKSIM VASILEV	{"email": "m.vasilev.1968@postgrespro.ru", "phone": "+70281868260"}
0005433102493	18EA9B	1405 771490	KRISTINA NAZAROVA	{"email": "nazarovak_1987@postgrespro.ru", "phone": "+70189321674"}
0005433102494	D19A83	2738 954250	ANATOLIY BARANOV	{"phone": "+70836835799"}
0005433102495	526548	1977 639020	NADEZHDA VASILEVA	{"email": "n_vasileva.121976@postgrespro.ru", "phone": "+70184859833"}
0005433102496	CD6C85	6614 279221	NIKITA KUZNECOV	{"phone": "+70297697696"}
0005433102497	8F77CB	2783 549492	VSEVOLOD KARPOV	{"email": "vsevolod-karpov1973@postgrespro.ru", "phone": "+70374050202"}
0005433102498	9D85A1	3307 319015	EKATERINA KUZNECOVA	{"email": "kuznecovae101975@postgrespro.ru", "phone": "+70796641936"}
0005433102499	7917C8	0989 362514	IRINA ROMANOVA	{"email": "irinaromanova_1972@postgrespro.ru", "phone": "+70080265870"}
0005433102500	25FC03	3839 213296	SERGEY VOLKOV	{"email": "sergey_volkov.071967@postgrespro.ru", "phone": "+70886639447"}
0005433102501	38B2D1	9454 957599	VALENTINA ZAYCEVA	{"phone": "+70388627459"}
0005433102502	7F9717	8080 003140	MARINA KUZNECOVA	{"phone": "+70282653008"}
0005433102503	B7865F	5338 234515	NINA MIKHAYLOVA	{"phone": "+70830507055"}
0005433102504	B7865F	9310 565701	MARIYA MALYSHEVA	{"phone": "+70629693643"}
0005433102505	16A55A	6160 936346	NATALYA KOROLEVA	{"phone": "+70120846284"}
0005433102506	F42B75	9139 649546	LILIYA PAVLOVA	{"email": "liliya-pavlova_081962@postgrespro.ru", "phone": "+70119612345"}
0005433102507	5FD884	7015 556994	EKATERINA NIKITINA	{"email": "nikitina-ekaterina.021974@postgrespro.ru", "phone": "+70362327517"}
0005433102508	5FD884	4464 714380	ALEKSANDR EGOROV	{"phone": "+70518072288"}
0005433102510	D757E0	9574 469498	LYUDMILA VLASOVA	{"email": "l-vlasova-021978@postgrespro.ru", "phone": "+70846680621"}
0005433102511	F9E95D	3947 209079	NATALYA NESTEROVA	{"email": "nnesterova_14121965@postgrespro.ru", "phone": "+70451281627"}
0005433102512	8A79F5	4762 751266	ILYA BARANOV	{"phone": "+70250678735"}
0005433102513	8A79F5	8036 903735	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr.081971@postgrespro.ru", "phone": "+70770693549"}
0005433102514	994165	6537 486121	FEDOR ZAYCEV	{"email": "zaycev-fedor-26021977@postgrespro.ru", "phone": "+70706037685"}
0005433102515	B37A18	5982 780723	YURIY ZAYCEV	{"email": "y_zaycev29041974@postgrespro.ru", "phone": "+70972406185"}
0005433102516	04F180	4778 670252	EKATERINA MOROZOVA	{"phone": "+70932862954"}
0005433102517	744AF1	7697 345682	OLEG EGOROV	{"phone": "+70108628770"}
0005433102518	744AF1	4385 034921	OLEG MELNIKOV	{"email": "melnikov-o_12051975@postgrespro.ru", "phone": "+70222183978"}
0005433102519	207443	3891 487061	FEDOR GRIGOREV	{"email": "grigorev_fedor-05051972@postgrespro.ru", "phone": "+70847710683"}
0005433102520	47E912	2155 841774	ALEKSANDR MATVEEV	{"email": "a-matveev_1972@postgrespro.ru", "phone": "+70063319353"}
0005433102521	47E912	5750 255278	ELENA BELYAEVA	{"phone": "+70153184410"}
0005433102522	47E912	6048 799480	ZOYA SERGEEVA	{"email": "zoya_sergeeva-11051969@postgrespro.ru", "phone": "+70955328386"}
0005433102523	0212DD	9230 090200	ANASTASIYA NIKITINA	{"email": "anikitina_041963@postgrespro.ru", "phone": "+70711105765"}
0005433102524	0212DD	0633 817387	VALERIY ABRAMOV	{"email": "abramov.v-25081974@postgrespro.ru", "phone": "+70399759926"}
0005433102525	A697B3	5156 082880	VALERIY SOROKIN	{"email": "sorokin-v041973@postgrespro.ru", "phone": "+70844080602"}
0005433102526	01E20A	9220 406148	ILYA RODIONOV	{"phone": "+70642623623"}
0005433102527	01E20A	6495 615372	OLEG KARPOV	{"email": "karpovoleg.091966@postgrespro.ru", "phone": "+70866017925"}
0005433102528	2BC386	9033 444917	IVAN MOROZOV	{"phone": "+70340855058"}
0005433102529	4A3A84	2086 373054	LYUBOV VASILEVA	{"phone": "+70301770521"}
0005433102530	EA0632	7733 072197	OLGA SERGEEVA	{"email": "olga_sergeeva.101967@postgrespro.ru", "phone": "+70306183578"}
0005433102531	3B35A8	4471 377665	ANATOLIY SHEVCHENKO	{"phone": "+70202618201"}
0005433102532	F0C1CB	1868 219881	OLGA OVCHINNIKOVA	{"email": "oovchinnikova-081990@postgrespro.ru", "phone": "+70060196578"}
0005433102533	F0C1CB	7430 228000	KARINA SAVELEVA	{"email": "savelevak-031985@postgrespro.ru", "phone": "+70088968993"}
0005433102534	1E1A83	9942 560318	MAKSIM MEDVEDEV	{"phone": "+70032241816"}
0005433102535	1E1A83	5782 099845	ANASTASIYA NAZAROVA	{"email": "anazarova-03111988@postgrespro.ru", "phone": "+70754927661"}
0005433102536	596B09	9074 897020	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana_14121972@postgrespro.ru", "phone": "+70073152928"}
0005433102537	596B09	5689 755324	ILDAR ALEKSANDROV	{"email": "aleksandrov-i23021966@postgrespro.ru", "phone": "+70177990537"}
0005433102538	F15A0E	8891 401455	NATALYA IVANOVA	{"phone": "+70726993891"}
0005433102539	FD325A	9499 554777	IGOR POPOV	{"phone": "+70479687000"}
0005433102540	1AEB0F	2254 934748	NIKOLAY ABRAMOV	{"phone": "+70133896822"}
0005433102541	E3A85C	2041 037303	SERGEY EGOROV	{"email": "sergey-egorov31101988@postgrespro.ru", "phone": "+70277733609"}
0005433102542	AEF5A9	7546 280857	YAKOV ZHUKOV	{"phone": "+70009311146"}
0005433102543	09C2AD	8998 044710	NATALYA TITOVA	{"phone": "+70243609559"}
0005433102544	09C2AD	1596 858967	VASILIY NIKOLAEV	{"email": "vasiliy_nikolaev_1966@postgrespro.ru", "phone": "+70521858486"}
0005433102545	85D900	2355 562453	ALEKSEY MAKAROV	{"email": "a.makarov_061966@postgrespro.ru", "phone": "+70669512260"}
0005433102546	BCE6EF	2980 435149	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir.14061976@postgrespro.ru", "phone": "+70688620796"}
0005433102547	63CD41	0723 668376	ALEKSANDR SOROKIN	{"email": "sorokina_031969@postgrespro.ru", "phone": "+70671889281"}
0005433102548	63CD41	1296 037855	GALINA ZHUKOVA	{"phone": "+70733051639"}
0005433102549	63CD41	0424 272280	GENNADIY BARANOV	{"phone": "+70769439633"}
0005433102550	1FA52A	4664 107714	VERA SERGEEVA	{"phone": "+70199055994"}
0005433102551	1FA52A	9513 264069	OKSANA POPOVA	{"phone": "+70523694439"}
0005433102552	C80CC6	6415 534412	MARIYA BORISOVA	{"email": "borisova.m_29041976@postgrespro.ru", "phone": "+70493438825"}
0005433102553	2D14C0	0221 778102	FEDOR VASILEV	{"phone": "+70550519082"}
0005433102554	96A96C	0407 456460	SERGEY SERGEEV	{"email": "sergeev-sergey.081967@postgrespro.ru", "phone": "+70055533196"}
0005433102555	96A96C	9211 273744	ZHANNA NESTEROVA	{"email": "nesterova_z.24101976@postgrespro.ru", "phone": "+70306688589"}
0005433102556	3AC38A	1676 519884	VLADIMIR FEDOROV	{"phone": "+70478068994"}
0005433102557	299EE7	2757 943246	NATALYA FEDOROVA	{"phone": "+70698759166"}
0005433102558	D76ABE	3586 149476	VALERIY ZAYCEV	{"email": "valeriy-zaycev14121963@postgrespro.ru", "phone": "+70341469259"}
0005433102559	A3820D	5314 778443	MARAT NIKOLAEV	{"phone": "+70142770105"}
0005433102560	DF7599	8878 691887	OLEG SIDOROV	{"email": "sidorov_o1967@postgrespro.ru", "phone": "+70169392016"}
0005433102561	4F637F	5413 117798	VASILIY CHERNOV	{"email": "chernovv-121967@postgrespro.ru", "phone": "+70361482880"}
0005433102562	4F637F	5279 634302	DMITRIY NOVIKOV	{"email": "dmitriynovikov041975@postgrespro.ru", "phone": "+70610605097"}
0005433102563	8A2B7A	2212 308220	IVAN ROMANOV	{"email": "romanovivan_101968@postgrespro.ru", "phone": "+70242499336"}
0005433102564	8A2B7A	9178 769651	NADEZHDA EGOROVA	{"email": "negorova-1981@postgrespro.ru", "phone": "+70968454446"}
0005433102565	C4F466	1167 762384	NINA MAKSIMOVA	{"phone": "+70702018894"}
0005433102566	C4F466	1433 218380	VLADIMIR CHERNOV	{"email": "chernov-vladimir_19041966@postgrespro.ru", "phone": "+70794475255"}
0005433102567	43D80D	5014 817130	GALINA LOGINOVA	{"email": "loginova.g_051977@postgrespro.ru", "phone": "+70379100068"}
0005433102568	44432F	5281 141155	ILYA KRASNOV	{"email": "i-krasnov-1965@postgrespro.ru", "phone": "+70263397592"}
0005433102570	A3F56A	2421 677778	SERGEY VOLKOV	{"email": "volkov.sergey-1981@postgrespro.ru", "phone": "+70865912057"}
0005433102571	A3F56A	7993 224873	NIKOLAY BELOV	{"phone": "+70271190597"}
0005433102572	9AEBD1	9222 526458	NIKOLAY VOLKOV	{"phone": "+70721704027"}
0005433102573	91C31B	0073 550899	SERGEY KARPOV	{"email": "sergey_karpov1972@postgrespro.ru", "phone": "+70424395357"}
0005433102574	62B64C	7541 409937	ANDREY ZAYCEV	{"phone": "+70553484792"}
0005433102575	62B64C	0480 868863	ANASTASIYA SERGEEVA	{"phone": "+70230422022"}
0005433102576	BF9298	2464 476377	ALEKSANDR KISELEV	{"phone": "+70832008297"}
0005433102577	3C16DB	2041 906146	DANILA EGOROV	{"phone": "+70888402274"}
0005433102578	488C7B	1963 683586	ALEKSANDR ILIN	{"phone": "+70750429365"}
0005433102579	CD3892	1427 738597	MARINA KUZNECOVA	{"phone": "+70491677132"}
0005433102580	CD3892	2186 878506	NIKOLAY DAVYDOV	{"phone": "+70675413549"}
0005433102581	1525DB	2525 065696	ARTEM KISELEV	{"email": "akiselev_23021983@postgrespro.ru", "phone": "+70869988634"}
0005433102582	1525DB	2150 578264	OLGA POPOVA	{"phone": "+70699333028"}
0005433102583	82123A	3459 117229	NATALYA KOVALEVA	{"email": "n.kovaleva-121985@postgrespro.ru", "phone": "+70573456111"}
0005433102584	28942B	0948 547045	RIFAT POPOV	{"phone": "+70496845954"}
0005433102752	788FA7	5350 812872	KONSTANTIN NIKOLAEV	{"phone": "+70273850425"}
0005433102585	764777	0760 152037	LARISA EGOROVA	{"email": "legorova_13071975@postgrespro.ru", "phone": "+70028260670"}
0005433102586	7AE43F	1357 490176	ANTON POPOV	{"email": "anton_popov_1971@postgrespro.ru", "phone": "+70884360274"}
0005433102587	76F587	2176 674888	ARTUR DMITRIEV	{"email": "a-dmitriev10121968@postgrespro.ru", "phone": "+70590946363"}
0005433102588	76F587	0142 596218	NIKOLAY ROMANOV	{"email": "nromanov_1969@postgrespro.ru", "phone": "+70465331747"}
0005433102589	49B998	3831 552490	IGOR GORBUNOV	{"email": "i.gorbunov091979@postgrespro.ru", "phone": "+70339110106"}
0005433102590	49B998	6051 254690	MIKHAIL KARPOV	{"email": "m-karpov1972@postgrespro.ru", "phone": "+70249074021"}
0005433102591	E8A78B	3950 187675	SERGEY CHERNOV	{"email": "sergey-chernov071974@postgrespro.ru", "phone": "+70802086832"}
0005433102592	E8A78B	5749 209933	ALEKSANDR KULIKOV	{"phone": "+70705207791"}
0005433102593	9F2ED5	1608 440248	ANDREY GORBUNOV	{"email": "andreygorbunov1976@postgrespro.ru", "phone": "+70951012254"}
0005433102594	9F2ED5	7975 416030	MARINA KUZMINA	{"email": "kuzminam_1965@postgrespro.ru", "phone": "+70611757927"}
0005433102595	478BF8	9423 572207	ALEKSANDR SOROKIN	{"email": "sorokin_a121971@postgrespro.ru", "phone": "+70661363647"}
0005433102596	8496A0	8920 175964	NIKOLAY CHERNOV	{"email": "nikolay_chernov.1972@postgrespro.ru", "phone": "+70084520752"}
0005433102597	8496A0	1472 539916	NATALYA KOMAROVA	{"phone": "+70594743730"}
0005433102598	63A94D	7703 197593	PAVEL POPOV	{"phone": "+70282263218"}
0005433102599	63A94D	2462 165483	KRISTINA FILIPPOVA	{"phone": "+70901528634"}
0005433102600	97E1F1	6905 692969	ALEKSANDR KISELEV	{"phone": "+70544889341"}
0005433102601	97E1F1	9357 742796	DENIS ANDREEV	{"phone": "+70860280557"}
0005433102602	BFA741	1439 065276	IRINA IVANOVA	{"email": "i.ivanova.051983@postgrespro.ru", "phone": "+70569222913"}
0005433102603	3D60AD	6452 820573	VADIM SAVELEV	{"email": "savelev-vadim.05061981@postgrespro.ru", "phone": "+70184737041"}
0005433102604	3D60AD	1353 623492	MIKHAIL KISELEV	{"phone": "+70470124815"}
0005433102605	207FD7	6887 598707	SERGEY SERGEEV	{"phone": "+70406626565"}
0005433102606	A49AF6	9464 776049	ALEKSANDR FROLOV	{"phone": "+70356534760"}
0005433102607	A49AF6	3801 224411	SVETLANA SMIRNOVA	{"email": "smirnova_svetlana_1984@postgrespro.ru", "phone": "+70148317528"}
0005433102608	A49AF6	7451 904487	ANASTASIYA ANTONOVA	{"phone": "+70235610366"}
0005433102609	A7A19B	3083 930046	LIDIYA KALININA	{"phone": "+70798023372"}
0005433102610	E37FC9	2034 164022	NADEZHDA GERASIMOVA	{"email": "gerasimova-nadezhda101971@postgrespro.ru", "phone": "+70010008074"}
0005433102611	3F7C0D	7143 396803	NIKOLAY BELOV	{"phone": "+70280220446"}
0005433102612	3F7C0D	1994 972607	ROZA FILATOVA	{"email": "filatova.r.111990@postgrespro.ru", "phone": "+70641188304"}
0005433102613	59D58B	5064 131785	NINA KUZNECOVA	{"email": "kuznecova-nina.21021971@postgrespro.ru", "phone": "+70293726675"}
0005433102614	282BA0	1432 162152	ALINA BOGDANOVA	{"email": "alinabogdanova.071972@postgrespro.ru", "phone": "+70593317417"}
0005433102615	282BA0	7403 655252	LILIYA ALEKSEEVA	{"email": "alekseeva.liliya111973@postgrespro.ru", "phone": "+70636280751"}
0005433102616	D41394	6659 819582	ELENA KUZNECOVA	{"email": "e.kuznecova-021958@postgrespro.ru", "phone": "+70280586446"}
0005433102617	23BDFB	7062 606414	DANIS KUDRYASHOV	{"phone": "+70331622351"}
0005433102618	DD3F80	2613 697048	ANASTASIYA DAVYDOVA	{"email": "adavydova_1970@postgrespro.ru", "phone": "+70241880289"}
0005433102619	DD3F80	3944 639202	VLADISLAV SOLOVEV	{"email": "solovev_vladislav_101962@postgrespro.ru", "phone": "+70904304911"}
0005433102620	DD3F80	4905 629790	SERGEY KRASNOV	{"email": "s_krasnov_21021980@postgrespro.ru", "phone": "+70361067500"}
0005433102621	28CE26	8953 458867	YULIYA DMITRIEVA	{"email": "dmitrievay-18111975@postgrespro.ru", "phone": "+70062736865"}
0005433102622	4A9213	6236 658805	MAKSIM SIDOROV	{"phone": "+70167155214"}
0005433102623	95B7B5	3395 893948	VIKTORIYA LOGINOVA	{"email": "v-loginova-071968@postgrespro.ru", "phone": "+70877958281"}
0005433102624	B4589B	6054 110451	OKSANA KUZNECOVA	{"email": "oksana.kuznecova.16081966@postgrespro.ru", "phone": "+70247037969"}
0005433102625	B4589B	0538 350319	OKSANA GRISHINA	{"phone": "+70185852558"}
0005433102626	FD6322	6713 061886	ANATOLIY SCHERBAKOV	{"phone": "+70950936489"}
0005433102627	FD6322	4800 310177	EVGENIY GUSEV	{"phone": "+70027133210"}
0005433102628	EC84E1	5362 423160	LIDIYA NAZAROVA	{"email": "nazarova_l.20101972@postgrespro.ru", "phone": "+70627006942"}
0005433102629	D05506	9773 304462	NIKITA DENISOV	{"email": "n_denisov081966@postgrespro.ru", "phone": "+70021114272"}
0005433102630	05FC43	1217 312144	MIKHAIL MOROZOV	{"phone": "+70529746467"}
0005433102631	689F08	8350 922313	NIKOLAY SAVELEV	{"email": "savelev-nikolay.1974@postgrespro.ru", "phone": "+70237121003"}
0005433102632	1BE2BF	7984 369465	MARIYA FROLOVA	{"email": "m.frolova08111975@postgrespro.ru", "phone": "+70545169884"}
0005433102633	1BE2BF	6811 448698	EKATERINA IVANOVA	{"email": "ivanovae051983@postgrespro.ru", "phone": "+70617197089"}
0005433102634	654535	8952 439986	SERGEY DAVYDOV	{"email": "davydov_s02041974@postgrespro.ru", "phone": "+70644294596"}
0005433102635	654535	8540 518928	IGOR VLASOV	{"phone": "+70839304376"}
0005433102636	B60318	5060 983350	TAISIYA FROLOVA	{"email": "frolova.t.1972@postgrespro.ru", "phone": "+70079305183"}
0005433102637	326A6C	0623 426304	VALENTINA TIKHONOVA	{"phone": "+70556251516"}
0005433102638	CB6BFF	6335 625892	DENIS NOVIKOV	{"phone": "+70893518897"}
0005433102639	CB6BFF	7960 096551	YULIYA TITOVA	{"phone": "+70036174381"}
0005433102753	788FA7	2369 281993	ANNA RODIONOVA	{"phone": "+70621895328"}
0005433102640	CB6BFF	0824 955714	OLGA SERGEEVA	{"email": "olga.sergeeva_1967@postgrespro.ru", "phone": "+70018999919"}
0005433102641	8F9E45	7828 261745	MARINA SERGEEVA	{"phone": "+70858918759"}
0005433102642	F99CD7	4884 931768	ANDREY TARASOV	{"email": "tarasov.a_061970@postgrespro.ru", "phone": "+70540216529"}
0005433102643	EB7CBD	0952 917378	ALEKSEY VOROBEV	{"phone": "+70023787032"}
0005433102644	7FCCD9	6137 577693	NIKOLAY KARPOV	{"email": "nikolay.karpov09061982@postgrespro.ru", "phone": "+70550404335"}
0005433102645	7FCCD9	9306 753256	NINA FILATOVA	{"phone": "+70051765006"}
0005433102646	F923D2	2736 952020	MIKHAIL FEDOROV	{"email": "fedorov.m081972@postgrespro.ru", "phone": "+70884053785"}
0005433102647	296B0A	8903 116355	VLADISLAV ANTONOV	{"phone": "+70992244087"}
0005433102648	296B0A	4840 508130	TATYANA DANILOVA	{"phone": "+70812541437"}
0005433102649	8FF7F3	9073 604632	YULIYA FOMINA	{"email": "yuliya_fomina-23121971@postgrespro.ru", "phone": "+70066949143"}
0005433102650	8FF7F3	6532 480765	PAVEL DMITRIEV	{"email": "dmitrievpavel-1979@postgrespro.ru", "phone": "+70991025624"}
0005433102651	FE1469	7068 255739	DENIS ZHURAVLEV	{"email": "zhuravlev.denis.051978@postgrespro.ru", "phone": "+70202676459"}
0005433102652	946A31	0876 567777	FILIPP IVANOV	{"email": "f-ivanov.1971@postgrespro.ru", "phone": "+70910113257"}
0005433102653	EDFEEE	5571 730377	ALEKSEY GORBUNOV	{"phone": "+70029143967"}
0005433102654	EDFEEE	3219 499704	ALEKSANDR FROLOV	{"phone": "+70981854321"}
0005433102655	EDFEEE	9017 783587	YULIYA IVANOVA	{"email": "yuliya_ivanova.05091977@postgrespro.ru", "phone": "+70700930408"}
0005433102656	D3E794	1188 526510	IRINA POPOVA	{"email": "irina.popova-1970@postgrespro.ru", "phone": "+70621242659"}
0005433102657	834C12	8629 308499	IRINA ANDREEVA	{"email": "andreevairina_14041965@postgrespro.ru", "phone": "+70403742384"}
0005433102658	358AA1	4110 006702	ALEKSANDR GORBUNOV	{"email": "agorbunov_101963@postgrespro.ru", "phone": "+70886253824"}
0005433102659	68E305	2485 829403	YANA VASILEVA	{"email": "vasilevayana.021980@postgrespro.ru", "phone": "+70965044459"}
0005433102660	2780AE	5534 276592	EGOR KUZNECOV	{"phone": "+70860067076"}
0005433102661	2780AE	1386 583630	ANDREY SOLOVEV	{"email": "solovev.andrey.051980@postgrespro.ru", "phone": "+70707841128"}
0005433102662	81EDF9	1336 495992	ARKADIY MARTYNOV	{"phone": "+70566133716"}
0005433102663	D47ED5	1226 022732	PETR NIKOLAEV	{"email": "nikolaev-petr.1971@postgrespro.ru", "phone": "+70519201936"}
0005433102664	D47ED5	2563 021867	GALINA KULIKOVA	{"email": "kulikova.galina011978@postgrespro.ru", "phone": "+70386863648"}
0005433102665	34A0C1	6191 012630	LYUDMILA BORISOVA	{"phone": "+70880857872"}
0005433102666	DADA71	0838 825243	NATALIYA FILIPPOVA	{"phone": "+70423040666"}
0005433102667	400C50	7576 388025	YURIY KAZAKOV	{"email": "kazakov-yuriy-1978@postgrespro.ru", "phone": "+70308254903"}
0005433102668	C9493C	1669 080581	ANASTASIYA SMIRNOVA	{"phone": "+70602423698"}
0005433102669	C9493C	4113 105574	ALEKSEY ILIN	{"email": "ilinaleksey-04021969@postgrespro.ru", "phone": "+70394823855"}
0005433102670	D7A760	3404 195319	ALEKSEY KUZNECOV	{"email": "kuznecova-28081981@postgrespro.ru", "phone": "+70441581467"}
0005433102671	749EFE	1827 158728	NIKOLAY ALEKSANDROV	{"email": "aleksandrov-nikolay.021979@postgrespro.ru", "phone": "+70180862198"}
0005433102672	749EFE	5958 319852	ASIYA MAKSIMOVA	{"email": "maksimovaasiya.1980@postgrespro.ru", "phone": "+70974702558"}
0005433102673	749EFE	3033 827943	ALEKSEY KISELEV	{"email": "aleksey_kiselev_18051971@postgrespro.ru", "phone": "+70649064267"}
0005433102674	3683DD	7585 881000	ALEKSANDR DENISOV	{"email": "adenisov_1976@postgrespro.ru", "phone": "+70215438876"}
0005433102675	AF1F20	5863 620095	SERGEY SEMENOV	{"email": "s-semenov_1974@postgrespro.ru", "phone": "+70551594832"}
0005433102676	AF1F20	4026 711895	TATYANA NAZAROVA	{"email": "nazarova-tatyana.05051965@postgrespro.ru", "phone": "+70817180845"}
0005433102677	53A46F	0622 776682	NATALYA MAKSIMOVA	{"email": "n.maksimova_1966@postgrespro.ru", "phone": "+70463825866"}
0005433102678	53A46F	9651 406877	NATALYA RODIONOVA	{"email": "natalyarodionova_1963@postgrespro.ru", "phone": "+70005970654"}
0005433102679	CB805C	4855 348697	SERGEY RODIONOV	{"phone": "+70283333610"}
0005433102680	0D4841	3724 355280	ALEKSANDR MIKHAYLOV	{"phone": "+70103846204"}
0005433102681	0D4841	9337 471119	PAVEL BORISOV	{"phone": "+70513962835"}
0005433102682	A71958	7019 004491	ANTON ZAKHAROV	{"phone": "+70952751672"}
0005433102683	A71958	4719 979982	PAVEL SMIRNOV	{"phone": "+70706091473"}
0005433102684	260395	3743 335128	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova.1978@postgrespro.ru", "phone": "+70177917102"}
0005433102685	219A0E	3767 476981	MIKHAIL BARANOV	{"phone": "+70801862543"}
0005433102686	DE36BC	7522 707553	YULIYA ZAYCEVA	{"phone": "+70911644570"}
0005433102687	CAFF11	7458 347422	ALEKSEY STEPANOV	{"email": "alekseystepanov.041975@postgrespro.ru", "phone": "+70193086120"}
0005433102688	E99377	3858 525572	RAMIL SHEVCHENKO	{"phone": "+70059837772"}
0005433102689	9AEAB3	4772 942546	ALEKSEY MEDVEDEV	{"phone": "+70078076554"}
0005433102690	9AEAB3	9182 259170	SERGEY CHERNOV	{"phone": "+70630742369"}
0005433102691	D86DE6	3918 262526	EVGENIY OSIPOV	{"phone": "+70875865592"}
0005433102692	D86DE6	7585 179755	VYACHESLAV KUZNECOV	{"phone": "+70703868047"}
0005433102693	D86DE6	2562 865939	VERONIKA NESTEROVA	{"email": "v-nesterova_1978@postgrespro.ru", "phone": "+70947139016"}
0005433102694	46CDB5	2077 772453	SERGEY POPOV	{"email": "spopov_1966@postgrespro.ru", "phone": "+70823772468"}
0005433102695	46CDB5	2022 559617	VLADIMIR FILIPPOV	{"email": "filippov_v_1976@postgrespro.ru", "phone": "+70580058386"}
0005433102696	3FB8F5	8362 872202	STANISLAV BELOV	{"email": "belov-stanislav.1973@postgrespro.ru", "phone": "+70669154883"}
0005433102697	3FB8F5	4983 317969	SERGEY SOKOLOV	{"email": "s-sokolov24011971@postgrespro.ru", "phone": "+70114730011"}
0005433102698	230D5F	8868 324744	ALEKSANDR IVANOV	{"email": "a-ivanov_051975@postgrespro.ru", "phone": "+70855960533"}
0005433102699	230D5F	1453 413216	ALEKSANDR AFANASEV	{"phone": "+70010450820"}
0005433102700	C7F046	2126 866630	RAFIK KRASNOV	{"email": "rkrasnov1973@postgrespro.ru", "phone": "+70890093002"}
0005433102701	8385DD	3560 715457	ANATOLIY ISAEV	{"email": "a.isaev.23021976@postgrespro.ru", "phone": "+70910126292"}
0005433102702	6CB720	4573 975254	OLGA ILINA	{"email": "o-ilina.111977@postgrespro.ru", "phone": "+70767284756"}
0005433102703	A1943F	8389 383988	VLADIMIR ZAKHAROV	{"email": "zakharov_v-1969@postgrespro.ru", "phone": "+70027047908"}
0005433102704	A1943F	3988 013158	VALENTINA STEPANOVA	{"phone": "+70555200692"}
0005433102705	31CD2D	2785 547081	MARINA PAVLOVA	{"email": "pavlovam-11091969@postgrespro.ru", "phone": "+70685069804"}
0005433102706	591F92	3274 710989	ANDREY SOKOLOV	{"phone": "+70608702527"}
0005433102707	CD4102	7331 472193	GALINA GUSEVA	{"email": "gusevag_1975@postgrespro.ru", "phone": "+70619223784"}
0005433102708	D7AEEB	5187 012690	ALEKSEY KUZNECOV	{"phone": "+70526103459"}
0005433102709	D7AEEB	7344 471319	SALAVAT FILIPPOV	{"phone": "+70191644439"}
0005433102710	D4BD4D	3119 495610	SERGEY SERGEEV	{"phone": "+70330982861"}
0005433102711	C3D013	5277 627697	TATYANA POPOVA	{"phone": "+70104897450"}
0005433102712	F1FA2B	1977 914905	NIKOLAY TIMOFEEV	{"email": "n.timofeev16051968@postgrespro.ru", "phone": "+70188572041"}
0005433102713	81652B	4251 714509	DMITRIY BELOV	{"phone": "+70797886384"}
0005433102714	3A7D97	4403 506655	EVGENIY KONOVALOV	{"email": "evgeniy-konovalov_12121979@postgrespro.ru", "phone": "+70645753012"}
0005433102715	028D79	9172 980882	MARIYA VLASOVA	{"phone": "+70521581383"}
0005433102716	A106B0	7383 895607	DMITRIY KULIKOV	{"email": "kulikovdmitriy1973@postgrespro.ru", "phone": "+70911288902"}
0005433102717	0134FB	8992 772214	KRISTINA MATVEEVA	{"phone": "+70483713037"}
0005433102718	1F444A	5943 127872	TAMARA NIKITINA	{"email": "tamara.nikitina081957@postgrespro.ru", "phone": "+70996017685"}
0005433102719	1F444A	1133 172983	LYUDMILA IVANOVA	{"phone": "+70867599295"}
0005433102720	A40038	1423 099464	YULIYA KOVALEVA	{"phone": "+70702531022"}
0005433102721	507F78	0250 814234	ANASTASIYA KARPOVA	{"phone": "+70479090771"}
0005433102722	6DAAE4	1689 164452	RENATA IVANOVA	{"phone": "+70921178760"}
0005433102723	3EF681	9824 767886	VALERIY PETROV	{"email": "valeriy-petrov_18031970@postgrespro.ru", "phone": "+70235131746"}
0005433102724	DDCD42	5364 947023	GALINA KULIKOVA	{"email": "kulikova.g-01021986@postgrespro.ru", "phone": "+70786410568"}
0005433102725	BE2275	8264 078129	LYUBOV MATVEEVA	{"phone": "+70095809473"}
0005433102726	BE2275	7986 825168	ELENA DMITRIEVA	{"email": "e_dmitrieva-21121967@postgrespro.ru", "phone": "+70635873617"}
0005433102727	031613	9136 672367	DARYA IVANOVA	{"phone": "+70456136627"}
0005433102728	23C47B	1391 471544	ALEKSANDR AFANASEV	{"phone": "+70001427073"}
0005433102729	23C47B	2086 766529	ALEKSANDR MELNIKOV	{"phone": "+70207626386"}
0005433102730	23C47B	3248 068744	NINA SERGEEVA	{"email": "sergeeva_n011973@postgrespro.ru", "phone": "+70103633948"}
0005433102731	FFEB09	6859 017202	IGNAT ANTONOV	{"phone": "+70417273880"}
0005433102732	429007	1859 155414	LYUBOV IVANOVA	{"phone": "+70668444087"}
0005433102733	429007	9425 891757	ANTON FILIPPOV	{"email": "filippovanton_1962@postgrespro.ru", "phone": "+70242560788"}
0005433102734	DE8A5C	7481 547213	OKSANA YAKOVLEVA	{"phone": "+70133979805"}
0005433102735	FEFA6E	6271 559932	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr-06021975@postgrespro.ru", "phone": "+70907657619"}
0005433102736	0A2FEE	3150 457551	VIKTORIYA OVCHINNIKOVA	{"phone": "+70936890284"}
0005433102737	576BAB	8744 941038	NINA KUZNECOVA	{"email": "ninakuznecova-061986@postgrespro.ru", "phone": "+70570851018"}
0005433102738	0C3679	7152 728031	NATALYA TARASOVA	{"phone": "+70652067474"}
0005433102739	D869B1	2330 753250	VITALIY NIKOLAEV	{"email": "nikolaev-vitaliy_1965@postgrespro.ru", "phone": "+70805958257"}
0005433102740	A7D4D3	2631 726061	NIKITA KISELEV	{"phone": "+70596397637"}
0005433102741	533C63	1509 364654	YURIY ZHUKOV	{"phone": "+70768906594"}
0005433102742	B18D92	7639 819751	SERGEY BELOV	{"email": "s.belov_13011982@postgrespro.ru", "phone": "+70550006244"}
0005433102743	4A16F9	3458 462401	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov20111966@postgrespro.ru", "phone": "+70355691254"}
0005433102744	ADF265	9534 882907	VLADIMIR KUZNECOV	{"phone": "+70113445920"}
0005433102745	ADF265	4134 044589	EVGENIY ILIN	{"email": "iline-08081959@postgrespro.ru", "phone": "+70060629079"}
0005433102746	C3CD99	2728 228455	TATYANA DAVYDOVA	{"phone": "+70276561400"}
0005433102747	C3CD99	3484 482974	VLADIMIR PAVLOV	{"email": "vladimir.pavlov.22041983@postgrespro.ru", "phone": "+70156030880"}
0005433102748	EE0B89	5259 852744	ALEKSANDR POPOV	{"phone": "+70644531175"}
0005433102749	EE0B89	5387 537881	TAMARA KOROLEVA	{"email": "t.koroleva1980@postgrespro.ru", "phone": "+70878961525"}
0005433102750	DCDB76	5406 032992	IRINA BELOVA	{"email": "belova_i_1982@postgrespro.ru", "phone": "+70247883387"}
0005433102751	D31CF6	1622 553354	VLADIMIR ABRAMOV	{"email": "vladimir_abramov.09031969@postgrespro.ru", "phone": "+70016527536"}
0005433102754	61DB55	6264 376905	NIKOLAY VASILEV	{"phone": "+70766922518"}
0005433102755	61DB55	1953 700859	MIKHAIL TARASOV	{"email": "tarasov-m25101959@postgrespro.ru", "phone": "+70289833528"}
0005433102756	596E1C	1185 848359	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr1962@postgrespro.ru", "phone": "+70995734784"}
0005433102757	2465DC	3834 673927	VALENTINA KULIKOVA	{"phone": "+70470095893"}
0005433102758	8DB368	8011 627615	YURIY VASILEV	{"email": "vasilev-yuriy-1968@postgrespro.ru", "phone": "+70924705811"}
0005433102759	8DB368	1989 165263	NINA RODIONOVA	{"email": "rodionova-nina.1980@postgrespro.ru", "phone": "+70062822067"}
0005433102760	EE2E40	0275 734548	NATALYA ERMAKOVA	{"email": "nermakova.07121977@postgrespro.ru", "phone": "+70364145165"}
0005433102761	35A667	1721 758885	VIKTORIYA TIMOFEEVA	{"phone": "+70778504825"}
0005433102762	32199D	0856 157346	ALEKSANDR MAKSIMOV	{"phone": "+70130370373"}
0005433102763	32199D	4565 842893	YULIYA SOROKINA	{"phone": "+70863612555"}
0005433102764	E9E02D	5553 628016	VLADIMIR EGOROV	{"phone": "+70459270210"}
0005433102765	E9E02D	8474 975391	GENNADIY TIKHONOV	{"email": "g.tikhonov-121976@postgrespro.ru", "phone": "+70796170761"}
0005433102766	169DF5	0694 309175	YURIY NIKITIN	{"phone": "+70382744039"}
0005433102767	169DF5	3634 929225	ALEKSANDR RODIONOV	{"email": "rodionov_a_27061965@postgrespro.ru", "phone": "+70291303677"}
0005433102768	3C42A1	3926 918026	MARINA GUSEVA	{"phone": "+70297887735"}
0005433102769	3C42A1	7182 848589	VALERIY SEMENOV	{"phone": "+70741659411"}
0005433102770	693373	4808 806058	RAISA POPOVA	{"phone": "+70111631393"}
0005433102771	693373	2794 265763	IRINA KOROLEVA	{"email": "koroleva.irina1967@postgrespro.ru", "phone": "+70990603875"}
0005433102772	C0A9F9	9963 196964	GALINA KOZLOVA	{"phone": "+70804703941"}
0005433102773	C0A9F9	1846 920433	ANATOLIY ZHUKOV	{"email": "a.zhukov-041958@postgrespro.ru", "phone": "+70716753335"}
0005433102774	200612	5297 513531	DMITRIY MIKHAYLOV	{"phone": "+70165042001"}
0005433102775	37A6A6	8241 094979	IGOR SIDOROV	{"email": "sidorov_igor_1972@postgrespro.ru", "phone": "+70262293720"}
0005433102776	17CB87	8993 822449	DANIL SOKOLOV	{"email": "danil_sokolov_111964@postgrespro.ru", "phone": "+70835172672"}
0005433102777	17CB87	8767 165409	OLEG STEPANOV	{"phone": "+70346086156"}
0005433102778	227D30	8951 879313	SERGEY AFANASEV	{"email": "afanasev_sergey.1973@postgrespro.ru", "phone": "+70234583251"}
0005433102779	227D30	1423 855310	VLADIMIR PAVLOV	{"phone": "+70035146901"}
0005433102780	6911D7	4655 680099	IRINA KOROLEVA	{"email": "korolevai_07051977@postgrespro.ru", "phone": "+70171725217"}
0005433102781	3811D7	8888 852596	FAINA FILATOVA	{"email": "filatovafaina_041982@postgrespro.ru", "phone": "+70045597815"}
0005433102782	2DD968	5819 606815	RAILYA PETROVA	{"phone": "+70624694416"}
0005433102783	8A07B8	9769 989806	PAVEL IVANOV	{"email": "p-ivanov30111968@postgrespro.ru", "phone": "+70727933260"}
0005433102784	CA1123	0696 286599	NIKOLAY SCHERBAKOV	{"email": "n-scherbakov-101982@postgrespro.ru", "phone": "+70381204299"}
0005433102785	B5220B	1630 276996	ANATOLIY MATVEEV	{"email": "matveev_anatoliy121970@postgrespro.ru", "phone": "+70443753813"}
0005433102786	1B0D02	7643 203257	EKATERINA MIKHAYLOVA	{"email": "e-mikhaylova-1962@postgrespro.ru", "phone": "+70138929203"}
0005433102787	E62FDC	0323 227632	YAROSLAV BORISOV	{"email": "borisov_y.071981@postgrespro.ru", "phone": "+70065162781"}
0005433102788	E62FDC	2245 900676	ELIZAVETA ABRAMOVA	{"phone": "+70133042072"}
0005433102789	E62FDC	5269 583931	NINA ZHUKOVA	{"phone": "+70698651788"}
0005433102790	961D4D	6925 821756	ARTEM VOLKOV	{"phone": "+70307014985"}
0005433102791	961D4D	3511 786561	SERGEY NAZAROV	{"phone": "+70270720233"}
0005433102792	1DC44A	3128 726543	DAVID ANDREEV	{"email": "andreev-david1979@postgrespro.ru", "phone": "+70795556038"}
0005433102793	76BCDF	1784 806981	PAVEL POPOV	{"phone": "+70737279272"}
0005433102794	1D3497	0433 731134	OLGA FROLOVA	{"email": "olga.frolova18111977@postgrespro.ru", "phone": "+70004235829"}
0005433102795	1D3497	4484 598790	LARISA ZHUKOVA	{"email": "larisa.zhukova_22111968@postgrespro.ru", "phone": "+70799525739"}
0005433102796	39F0BE	1933 735903	ZINAIDA MARTYNOVA	{"phone": "+70823256244"}
0005433102797	21CFA1	8784 468685	EVELINA TARASOVA	{"phone": "+70419667511"}
0005433102798	3F043C	7411 046569	MARIYA PAVLOVA	{"email": "pavlovam121969@postgrespro.ru", "phone": "+70170103755"}
0005433102799	3F043C	5582 960610	TATYANA ANTONOVA	{"email": "tatyana.antonova.02051971@postgrespro.ru", "phone": "+70719884289"}
0005433102800	3B60EF	5322 125491	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr.051974@postgrespro.ru", "phone": "+70707020170"}
0005433102801	454CB9	2182 404658	VALENTINA ALEKSANDROVA	{"phone": "+70392832238"}
0005433102802	454CB9	8556 076538	NADEZHDA DENISOVA	{"email": "nadezhda-denisova.041971@postgrespro.ru", "phone": "+70385334651"}
0005433102803	3B32B4	4372 472718	YURIY MEDVEDEV	{"phone": "+70258587659"}
0005433102804	0A7A13	0287 044049	GRIGORIY SOKOLOV	{"email": "g-sokolov.1989@postgrespro.ru", "phone": "+70184671384"}
0005433102805	6892DF	0816 904771	OLGA SERGEEVA	{"phone": "+70908748192"}
0005433102806	E73BF4	6953 101943	IRINA FEDOROVA	{"phone": "+70454595374"}
0005433102807	EB358E	7198 871131	ANTONINA ABRAMOVA	{"phone": "+70557424851"}
0005433102808	EB358E	7894 648282	IVAN POPOV	{"email": "popov_ivan.061969@postgrespro.ru", "phone": "+70563375898"}
0005433102809	6F5638	1734 563475	VALENTINA MAKAROVA	{"phone": "+70559195389"}
0005433102810	38DC8C	0790 257433	VITALIY IVANOV	{"phone": "+70342066411"}
0005433102811	38DC8C	6513 012926	MAKSIM FEDOROV	{"email": "maksim.fedorov.021976@postgrespro.ru", "phone": "+70239132627"}
0005433102812	F90EE2	6634 011720	ANTON KULIKOV	{"email": "kulikov.anton011976@postgrespro.ru", "phone": "+70801491911"}
0005433102813	F90EE2	1594 416642	MIKHAIL SHEVCHENKO	{"email": "shevchenkomikhail.27081971@postgrespro.ru", "phone": "+70481071455"}
0005433102814	843BAA	5193 493688	LYUDMILA TARASOVA	{"email": "tarasova_l.26011971@postgrespro.ru", "phone": "+70262093237"}
0005433102815	843BAA	1901 941755	NIKOLAY BARANOV	{"email": "baranov.nikolay-071976@postgrespro.ru", "phone": "+70781530468"}
0005433102816	8F7E69	4455 851859	EVGENIY VOROBEV	{"phone": "+70338065392"}
0005433102817	7990C4	4354 372524	NINA SEMENOVA	{"phone": "+70735434804"}
0005433102818	A40CE0	0938 404830	SVETLANA AKIMOVA	{"email": "svetlana-akimova021975@postgrespro.ru", "phone": "+70933860157"}
0005433102819	A40CE0	2447 493490	ANTONINA KARPOVA	{"phone": "+70477986906"}
0005433102820	94B62C	7154 854172	FANIL KUDRYASHOV	{"email": "f.kudryashov_06101969@postgrespro.ru", "phone": "+70753654435"}
0005433102821	327971	4932 804981	ELENA ZHUKOVA	{"phone": "+70570805021"}
0005433102822	A139D4	5913 884678	LYUDMILA ANISIMOVA	{"email": "lyudmila-anisimova.24071960@postgrespro.ru", "phone": "+70283347938"}
0005433102823	A139D4	8602 814413	SVETLANA KISELEVA	{"email": "kiselevas.1968@postgrespro.ru", "phone": "+70602357794"}
0005433102824	0DCD64	9956 129895	LYUBOV POTAPOVA	{"email": "potapovalyubov-05011976@postgrespro.ru", "phone": "+70799426859"}
0005433102825	61DB70	0021 911876	DMITRIY FOMIN	{"phone": "+70774971462"}
0005433102826	3037EB	7379 625163	MARIYA PETROVA	{"phone": "+70168431684"}
0005433102827	9069FD	3802 532711	OLGA DENISOVA	{"email": "denisova-o-1975@postgrespro.ru", "phone": "+70674824083"}
0005433102828	9069FD	5673 815970	ANATOLIY DENISOV	{"email": "anatoliy_denisov-1956@postgrespro.ru", "phone": "+70567815135"}
0005433102829	9069FD	3897 953931	LYUDMILA PETROVA	{"phone": "+70572291912"}
0005433102830	D763B2	9713 879278	RADMIR MIKHAYLOV	{"phone": "+70449400159"}
0005433102831	D763B2	1367 912586	KLAVDIYA POPOVA	{"email": "klavdiya_popova_1975@postgrespro.ru", "phone": "+70303483515"}
0005433102832	D763B2	7057 553493	VERA ANTONOVA	{"email": "veraantonova-30051976@postgrespro.ru", "phone": "+70638686785"}
0005433102833	F4023F	4930 382140	GALINA NAUMOVA	{"email": "g_naumova-17011976@postgrespro.ru", "phone": "+70249405734"}
0005433102834	F4023F	2840 394898	NATALYA KAZAKOVA	{"email": "n-kazakova01061972@postgrespro.ru", "phone": "+70684052493"}
0005433102835	E20BF9	7816 715573	VALENTIN DMITRIEV	{"email": "valentindmitriev_031978@postgrespro.ru", "phone": "+70866024641"}
0005433102836	E20BF9	3221 946937	ALEKSANDR KUZNECOV	{"email": "kuznecova01111976@postgrespro.ru", "phone": "+70982364530"}
0005433102837	61A1EA	1461 492088	TAMARA KRASNOVA	{"email": "tamara-krasnova_031966@postgrespro.ru", "phone": "+70630694006"}
0005433102838	9FC2E2	9839 037013	IRINA NIKIFOROVA	{"email": "nikiforova_i_1970@postgrespro.ru", "phone": "+70649727881"}
0005433102839	2722A9	0199 298515	GLEB ZAYCEV	{"email": "glebzaycev.081978@postgrespro.ru", "phone": "+70861896836"}
0005433102840	3C0240	2652 880997	KLAVDIYA KONOVALOVA	{"email": "konovalova-k.1956@postgrespro.ru", "phone": "+70481118891"}
0005433102841	3C0240	9244 685292	LYUBOV ALEKSEEVA	{"email": "lalekseeva28091977@postgrespro.ru", "phone": "+70291382333"}
0005433102842	96E6F4	2072 221746	PELAGEYA AFANASEVA	{"email": "afanasevapelageya.081975@postgrespro.ru", "phone": "+70290965350"}
0005433102843	96E6F4	4788 985690	VALENTINA KOZLOVA	{"email": "kozlova-v06051980@postgrespro.ru", "phone": "+70346535641"}
0005433102844	812D59	8003 591160	SERGEY SAVELEV	{"email": "savelev.sergey-11121982@postgrespro.ru", "phone": "+70838737223"}
0005433102845	812D59	9676 366171	KIRILL IVANOV	{"email": "kirill_ivanov101974@postgrespro.ru", "phone": "+70436110464"}
0005433102846	966CDF	9860 640524	ANATOLIY ZHUKOV	{"phone": "+70842276634"}
0005433102847	D9AD0A	3138 576263	VIKTOR SMIRNOV	{"phone": "+70798497284"}
0005433102848	A16E0C	4317 746622	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov.111974@postgrespro.ru", "phone": "+70490019417"}
0005433102849	9258AE	4270 880204	MAKSIM FROLOV	{"phone": "+70030286469"}
0005433102850	027BD6	7345 268752	ELENA VOROBEVA	{"email": "vorobeva_elena.1968@postgrespro.ru", "phone": "+70629216761"}
0005433102851	92027C	3436 087644	SERGEY IVANOV	{"phone": "+70463906087"}
0005433102852	667426	5275 618434	SVETLANA YAKOVLEVA	{"phone": "+70163530162"}
0005433102853	667426	2123 764677	GALINA TARASOVA	{"email": "tarasova_galina_071977@postgrespro.ru", "phone": "+70593807610"}
0005433102854	27DCA8	3893 775302	TATYANA VASILEVA	{"email": "vasileva-t121975@postgrespro.ru", "phone": "+70473267575"}
0005433102855	7C2225	1875 130198	IGOR YAKOVLEV	{"email": "igor_yakovlev-081981@postgrespro.ru", "phone": "+70365242916"}
0005433102856	03AA00	5507 881833	IRINA MIKHAYLOVA	{"phone": "+70946873089"}
0005433102857	A4851E	6889 075387	LYUDMILA GAVRILOVA	{"phone": "+70559796046"}
0005433102858	5E0495	3129 480437	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila_01031961@postgrespro.ru", "phone": "+70789375642"}
0005433102859	5E0495	0770 151343	IRINA SMIRNOVA	{"email": "smirnovairina.18121974@postgrespro.ru", "phone": "+70914026387"}
0005433102860	3D4955	4149 365327	DARYA OSIPOVA	{"email": "d.osipova1973@postgrespro.ru", "phone": "+70050384559"}
0005433102861	974A6C	2377 727948	VITALIY ZAKHAROV	{"phone": "+70651440558"}
0005433102862	BF8228	1138 894579	KIRILL KISELEV	{"email": "kiselev-kirill.081970@postgrespro.ru", "phone": "+70772422560"}
0005433102863	D3297F	4152 291673	ANTONINA SCHERBAKOVA	{"email": "scherbakova_antonina_071966@postgrespro.ru", "phone": "+70389772108"}
0005433102864	415D83	0636 118092	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov_1959@postgrespro.ru", "phone": "+70004220133"}
0005433102865	AC8E6A	3376 060459	OLGA KOROLEVA	{"phone": "+70642081309"}
0005433102866	AC8E6A	4842 907663	ELENA SEMENOVA	{"email": "semenova.elena051965@postgrespro.ru", "phone": "+70115482759"}
0005433102867	C844D5	1592 848421	ILYA MARTYNOV	{"email": "i_martynov-27071988@postgrespro.ru", "phone": "+70457726854"}
0005433102868	F9F707	8519 148216	VLADIMIR KRASNOV	{"email": "v_krasnov22051968@postgrespro.ru", "phone": "+70668564888"}
0005433102869	683EE1	7487 159158	VLADIMIR POPOV	{"email": "popov-v_1969@postgrespro.ru", "phone": "+70569271167"}
0005433102870	4F3370	4734 625941	ADELINA AFANASEVA	{"email": "afanaseva_adelina-1960@postgrespro.ru", "phone": "+70868634381"}
0005433102871	4F3370	6878 642793	LYUBOV NAZAROVA	{"email": "nazarova_l1962@postgrespro.ru", "phone": "+70191023612"}
0005433102872	5FCF88	4031 439554	VADIM KOZLOV	{"phone": "+70526009154"}
0005433102873	5FCF88	1451 048850	SVETLANA NESTEROVA	{"phone": "+70771664152"}
0005433102874	CB629A	8344 108130	MAKSIM PETROV	{"email": "petrov.maksim_29041977@postgrespro.ru", "phone": "+70960101973"}
0005433102875	CB629A	1370 445983	SAVELIY ZHURAVLEV	{"phone": "+70167213846"}
0005433102876	44BC78	5196 743346	YURIY GUSEV	{"email": "gusevyuriy-101971@postgrespro.ru", "phone": "+70121384243"}
0005433102877	3BC5F4	5708 405839	VASILIY PETROV	{"email": "v.petrov.011976@postgrespro.ru", "phone": "+70768795976"}
0005433102878	7B2470	7545 039241	IRINA ALEKSEEVA	{"phone": "+70517735772"}
0005433102879	EA35F1	4192 774916	VALENTINA ROMANOVA	{"email": "romanovav.051969@postgrespro.ru", "phone": "+70041959020"}
0005433102880	B53D6E	5551 784459	SERGEY OSIPOV	{"phone": "+70539068073"}
0005433102881	B53D6E	7898 077286	ELENA SAVELEVA	{"phone": "+70841806882"}
0005433102882	6058FB	4399 946249	ELENA PETROVA	{"phone": "+70602029126"}
0005433102883	6058FB	9460 609284	ALEKSANDR SOLOVEV	{"email": "solovev_a041961@postgrespro.ru", "phone": "+70054480135"}
0005433102884	06146A	8888 974838	NIKOLAY SEMENOV	{"phone": "+70831479647"}
0005433102885	06146A	5231 748638	IGOR FEDOROV	{"phone": "+70709780421"}
0005433102886	3C2543	6199 727020	NADEZHDA MOROZOVA	{"phone": "+70031285998"}
0005433102887	5C322F	7315 395622	OLGA DAVYDOVA	{"phone": "+70164028090"}
0005433102888	5C322F	2809 132707	EKATERINA EFIMOVA	{"phone": "+70717081665"}
0005433102889	BFC531	1260 795412	ANZHELIKA ISAEVA	{"phone": "+70355392988"}
0005433102890	BFC531	9182 106245	EKATERINA MEDVEDEVA	{"phone": "+70064954960"}
0005433102891	BFC531	9857 280171	ARTEM BORISOV	{"email": "a-borisov_09101972@postgrespro.ru", "phone": "+70016899645"}
0005433102892	748525	2690 562730	ALEKSANDR GERASIMOV	{"email": "a.gerasimov011964@postgrespro.ru", "phone": "+70062666738"}
0005433102893	748525	7360 815010	ANNA FILIPPOVA	{"email": "filippovaa_1975@postgrespro.ru", "phone": "+70055265484"}
0005433102894	0E1D8D	8626 501444	VIKTORIYA SOROKINA	{"email": "sorokina-v071978@postgrespro.ru", "phone": "+70232723583"}
0005433102895	0E1D8D	7906 037744	IGOR IVANOV	{"phone": "+70470565165"}
0005433102896	B71AF3	9964 532563	LYUDMILA KOZLOVA	{"phone": "+70935964867"}
0005433102897	274165	9796 634693	ZOYA MAKSIMOVA	{"phone": "+70205306306"}
0005433102898	274165	8763 767721	LYUBOV NIKOLAEVA	{"email": "l.nikolaeva1975@postgrespro.ru", "phone": "+70978223268"}
0005433102899	D2391E	4171 809114	SERGEY FEDOTOV	{"phone": "+70470848140"}
0005433102900	CEE9C6	1501 803297	SERGEY STEPANOV	{"email": "s_stepanov-031972@postgrespro.ru", "phone": "+70802306518"}
0005433102901	CEE9C6	1147 741004	TAMARA NOVIKOVA	{"phone": "+70091044465"}
0005433102902	604CC7	7151 484009	PELAGEYA PETROVA	{"phone": "+70256960117"}
0005433102903	8DCCD5	7110 735010	VYACHESLAV BELOV	{"phone": "+70668469118"}
0005433102904	1D78CA	0261 165832	SVETLANA KONDRATEVA	{"phone": "+70619362355"}
0005433102905	E18487	3670 375168	ALEKSEY VASILEV	{"email": "a_vasilev1964@postgrespro.ru", "phone": "+70315525466"}
0005433102906	E18487	0889 657876	VADIM DAVYDOV	{"email": "davydov.v.17111981@postgrespro.ru", "phone": "+70636016814"}
0005433102907	B935CA	4843 628372	SERGEY ZHUKOV	{"email": "s-zhukov051975@postgrespro.ru", "phone": "+70252531375"}
0005433102908	2125C6	6864 367713	NIKITA FEDOTOV	{"email": "nikita_fedotov-1962@postgrespro.ru", "phone": "+70152906000"}
0005433102909	3AC21B	4512 091740	VLADA LAZAREVA	{"email": "lazareva-v121976@postgrespro.ru", "phone": "+70602736703"}
0005433102910	0DCC7D	1234 367251	EVGENIY ZAKHAROV	{"email": "e.zakharov_28021967@postgrespro.ru", "phone": "+70686941944"}
0005433102911	0E893B	3401 973836	RAMILYA MALYSHEVA	{"phone": "+70526208640"}
0005433102912	57A182	7775 031216	NATALYA NAUMOVA	{"email": "n.naumova.1961@postgrespro.ru", "phone": "+70377913999"}
0005433102913	0F2BB9	9709 153661	ALEKSANDR POPOV	{"email": "popov_aleksandr1971@postgrespro.ru", "phone": "+70824117201"}
0005433102914	2D7E59	2149 918074	SERGEY YAKOVLEV	{"phone": "+70142560561"}
0005433102915	3FB1AD	4352 895494	ANDREY KONOVALOV	{"email": "andreykonovalov-03121976@postgrespro.ru", "phone": "+70076595312"}
0005433102916	10C289	3592 198877	MIKHAIL ANDREEV	{"email": "andreev_m1963@postgrespro.ru", "phone": "+70201976208"}
0005433102917	52C3F8	5912 331686	ALFIYA ROMANOVA	{"phone": "+70774834332"}
0005433102918	2D2AE0	1314 263528	RAISA ROMANOVA	{"email": "romanova-raisa-1973@postgrespro.ru", "phone": "+70527491028"}
0005433102919	2D2AE0	9696 063465	VALENTINA KOROLEVA	{"email": "koroleva.valentina1977@postgrespro.ru", "phone": "+70945354847"}
0005433102920	40D6A5	5162 294125	EVDOKIYA ANDREEVA	{"email": "e.andreeva071979@postgrespro.ru", "phone": "+70165901206"}
0005433102921	186638	3997 083287	PAVEL MAKAROV	{"phone": "+70112327115"}
0005433102922	186638	0209 345170	LIDIYA KUZNECOVA	{"email": "kuznecova-lidiya1975@postgrespro.ru", "phone": "+70577762605"}
0005433102923	D7A539	1085 933220	SERGEY ZAKHAROV	{"phone": "+70066444213"}
0005433102924	7A7EF5	3669 595382	DMITRIY KULIKOV	{"phone": "+70597726741"}
0005433102925	0B66D1	3799 026977	OLEG SIDOROV	{"email": "sidorovo.071967@postgrespro.ru", "phone": "+70799538820"}
0005433102926	0B66D1	0007 010248	VERA STEPANOVA	{"email": "v.stepanova.1964@postgrespro.ru", "phone": "+70166328020"}
0005433102927	0B66D1	3026 267647	TATYANA SAVELEVA	{"email": "tatyana_saveleva-18081977@postgrespro.ru", "phone": "+70887704365"}
0005433102928	2F9484	1885 047701	OLGA SIDOROVA	{"phone": "+70040266894"}
0005433102929	2F9484	0551 201996	VIKTOR MOISEEV	{"phone": "+70836232235"}
0005433102930	2F9484	3363 848258	SVETLANA KOROLEVA	{"phone": "+70164279521"}
0005433102931	60BFB7	1797 517468	MAKSIM MEDVEDEV	{"email": "medvedev-m23031970@postgrespro.ru", "phone": "+70324072736"}
0005433102932	60BFB7	9785 071023	ELENA MAKAROVA	{"phone": "+70703281388"}
0005433102933	A2386C	3821 745050	IRINA FADEEVA	{"phone": "+70976533120"}
0005433102934	37A705	5676 695780	SVETLANA SOROKINA	{"phone": "+70879317576"}
0005433102935	37A705	9184 851911	LYUBOV ZAKHAROVA	{"phone": "+70813399614"}
0005433102936	F380E7	0315 014924	OKSANA VLASOVA	{"email": "vlasova-o.1970@postgrespro.ru", "phone": "+70006261409"}
0005433102937	7549D9	4279 304200	LYUDMILA MALYSHEVA	{"phone": "+70450613051"}
0005433102938	D8AB59	6236 331444	MIKHAIL DAVYDOV	{"phone": "+70047916465"}
0005433102939	B8BE9D	1654 555411	IVAN MELNIKOV	{"email": "i.melnikov09121965@postgrespro.ru", "phone": "+70242876800"}
0005433102940	3E0FEA	7239 805315	EVGENIYA ANTONOVA	{"email": "antonova.e1970@postgrespro.ru", "phone": "+70079521193"}
0005433102941	3E0FEA	6760 178594	VLADIMIR TARASOV	{"email": "vladimir-tarasov-1974@postgrespro.ru", "phone": "+70010319237"}
0005433102942	3E0FEA	3543 771194	YURIY OSIPOV	{"email": "osipov_y-1966@postgrespro.ru", "phone": "+70045569576"}
0005433102943	31F4CC	7381 643798	ALEKSANDR MOROZOV	{"phone": "+70969521900"}
0005433102944	31F4CC	0955 634478	YURIY PETROV	{"email": "petrov-y.27111960@postgrespro.ru", "phone": "+70087611697"}
0005433102945	1DD0C8	4578 509252	YULIYA DENISOVA	{"email": "y.denisova031975@postgrespro.ru", "phone": "+70927693042"}
0005433102946	8D8339	4645 509583	EVGENIY MOROZOV	{"phone": "+70416192341"}
0005433102947	7C4116	4618 716230	VIKTOR MAKAROV	{"email": "v_makarov_1975@postgrespro.ru", "phone": "+70386702104"}
0005433102948	898D06	5054 456986	VLADIMIR IVANOV	{"email": "vladimir_ivanov.1974@postgrespro.ru", "phone": "+70752896878"}
0005433102949	1A76BD	4185 852428	DIANA BORISOVA	{"email": "borisova.diana_1972@postgrespro.ru", "phone": "+70805420927"}
0005433102950	49EF5B	8953 853200	ALENA SOKOLOVA	{"email": "a-sokolova1960@postgrespro.ru", "phone": "+70349068818"}
0005433102951	702689	6554 791018	RUSTAM ZHUKOV	{"email": "zhukov.rustam_011976@postgrespro.ru", "phone": "+70378588875"}
0005433102952	1E7613	8902 429467	ALEKSANDR IVANOV	{"phone": "+70532888154"}
0005433102953	AE8EE2	8740 146326	ANNA ZAKHAROVA	{"email": "zakharova-a.101971@postgrespro.ru", "phone": "+70474541543"}
0005433102954	9625DE	8751 169827	NINA LOGINOVA	{"email": "loginova.nina.1977@postgrespro.ru", "phone": "+70240222060"}
0005433102955	F94127	1364 502495	FANIL IVANOV	{"email": "fivanov-091977@postgrespro.ru", "phone": "+70998770329"}
0005433102956	F94127	5419 382888	YULIYA KISELEVA	{"email": "kiseleva.yuliya24031968@postgrespro.ru", "phone": "+70412695736"}
0005433102957	B1522F	4211 669744	IVAN ALEKSEEV	{"phone": "+70534192029"}
0005433102958	B1522F	4208 129470	VLADIMIR GORBUNOV	{"email": "gorbunovvladimir26121972@postgrespro.ru", "phone": "+70731423453"}
0005433102959	0DD60B	5010 139096	SERGEY IVANOV	{"email": "sergeyivanov_031985@postgrespro.ru", "phone": "+70596913945"}
0005433102960	25D8F2	1052 223949	ALEKSANDR IVANOV	{"phone": "+70683780925"}
0005433102961	548FAC	7762 046320	ANDREY IVANOV	{"email": "a_ivanov_28091982@postgrespro.ru", "phone": "+70081532250"}
0005433102962	AF5332	8130 355586	ELENA CHERNOVA	{"phone": "+70815698995"}
0005433102963	ACFAD3	2970 582071	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr.1967@postgrespro.ru", "phone": "+70075483230"}
0005433102964	4499E1	2017 913574	ELENA FADEEVA	{"email": "e.fadeeva-02021968@postgrespro.ru", "phone": "+70854861056"}
0005433102965	4499E1	8153 686393	YULIYA ZHUKOVA	{"phone": "+70384674908"}
0005433102966	4B007A	2002 578889	IVAN GUSEV	{"email": "ivan_gusev.021975@postgrespro.ru", "phone": "+70496951441"}
0005433102967	3E7300	9112 776013	ALEKSANDRA YAKOVLEVA	{"email": "aleksandra_yakovleva-051980@postgrespro.ru", "phone": "+70503903898"}
0005433102968	3E7300	2744 254310	ANATOLIY ROMANOV	{"email": "anatoliy.romanov1971@postgrespro.ru", "phone": "+70058923026"}
0005433102969	E63075	1336 481256	TATYANA MOROZOVA	{"email": "morozova-tatyana-13031971@postgrespro.ru", "phone": "+70574484205"}
0005433102970	6150A4	0867 288397	ALINA LAZAREVA	{"phone": "+70011903707"}
0005433102971	6A7DA1	8760 451375	NATALYA KULIKOVA	{"phone": "+70406133042"}
0005433102972	6A7DA1	3626 041442	VALENTINA ANTONOVA	{"phone": "+70226664817"}
0005433102973	6A7DA1	7253 121332	DANILA ALEKSEEV	{"email": "alekseev-d031969@postgrespro.ru", "phone": "+70030994841"}
0005433102974	ADFBDD	4295 656344	NATALYA TIKHONOVA	{"phone": "+70653965637"}
0005433103086	FF22A6	8039 191415	VERA MOROZOVA	{"phone": "+70519840321"}
0005433102975	AA3057	0312 857011	SERGEY KUZNECOV	{"email": "skuznecov_21051974@postgrespro.ru", "phone": "+70327022372"}
0005433102976	A5A7BF	6975 672705	DINARA POPOVA	{"phone": "+70261289120"}
0005433102977	FEBA5C	3292 245784	OKSANA KALININA	{"email": "oksana-kalinina-041974@postgrespro.ru", "phone": "+70320598163"}
0005433102978	97B1AA	9749 067368	ANTONINA KUZNECOVA	{"phone": "+70757565541"}
0005433102979	97B1AA	1068 136469	ANDREY KUDRYASHOV	{"email": "kudryashov_a-24081971@postgrespro.ru", "phone": "+70696870562"}
0005433102980	96710F	1169 444758	SVETLANA PETROVA	{"phone": "+70487044730"}
0005433102981	96710F	9079 867981	NIKOLAY KULIKOV	{"email": "kulikov.n081961@postgrespro.ru", "phone": "+70865685829"}
0005433102982	5DD2C4	9658 384456	ANDREY YAKOVLEV	{"email": "yakovlev-a_1972@postgrespro.ru", "phone": "+70338370411"}
0005433102983	7CA1D7	0794 961057	VITALIY SIDOROV	{"email": "sidorov.v.26061973@postgrespro.ru", "phone": "+70050976034"}
0005433102984	7E2EBB	0067 993345	NIKOLAY ISAEV	{"email": "nisaev_1957@postgrespro.ru", "phone": "+70029759786"}
0005433102985	EAFF93	8145 282278	PAVEL VOLKOV	{"email": "volkov-p28011967@postgrespro.ru", "phone": "+70203432379"}
0005433102986	3143BF	3967 153073	EVGENIY ANTONOV	{"email": "antonov-e-041974@postgrespro.ru", "phone": "+70145682155"}
0005433102987	3143BF	1767 488293	ALEKSANDR ZAKHAROV	{"phone": "+70671513118"}
0005433102988	3143BF	7663 408042	MARINA IVANOVA	{"email": "m_ivanova111974@postgrespro.ru", "phone": "+70432837657"}
0005433102989	31C0C3	8754 832346	YULIYA ABRAMOVA	{"email": "yabramova.18121975@postgrespro.ru", "phone": "+70876293678"}
0005433102990	CE76F5	9918 018235	ANTONINA BORISOVA	{"phone": "+70256540726"}
0005433102991	5C5B48	5363 462373	IGOR KOROLEV	{"phone": "+70137255113"}
0005433102992	21FC9C	9323 933880	VALENTINA YUDINA	{"phone": "+70934726327"}
0005433102993	21FC9C	4668 574190	RAFIS NAZAROV	{"phone": "+70519988423"}
0005433102994	59E5EA	2401 723936	NINA YAKOVLEVA	{"phone": "+70185915980"}
0005433102995	C7324B	1481 741106	MIKHAIL KISELEV	{"email": "m.kiselev_12061980@postgrespro.ru", "phone": "+70103708681"}
0005433102996	E663E3	3937 390646	YURIY KUZNECOV	{"phone": "+70875151564"}
0005433102997	4F29B8	8695 960896	LIDIYA KRASNOVA	{"email": "krasnova_lidiya.041970@postgrespro.ru", "phone": "+70749494532"}
0005433102998	4F29B8	0680 268994	EKATERINA MARTYNOVA	{"email": "martynova-ekaterina13021980@postgrespro.ru", "phone": "+70754397099"}
0005433102999	4F29B8	2689 719483	PAVEL KRASNOV	{"phone": "+70661586984"}
0005433103000	808150	4178 159601	OLGA PETROVA	{"email": "o.petrova1981@postgrespro.ru", "phone": "+70890789420"}
0005433103001	3D7F1D	7873 267524	IRINA KARPOVA	{"phone": "+70555362176"}
0005433103002	3D7F1D	5893 653142	ANTON KUZMIN	{"phone": "+70570782970"}
0005433103003	42BA2B	1248 920283	IRINA ZHUKOVA	{"phone": "+70788447945"}
0005433103004	04A490	1486 393493	SERGEY ISAEV	{"phone": "+70027510300"}
0005433103005	C7559C	3632 143813	VITALIY MOROZOV	{"phone": "+70648137893"}
0005433103006	627561	9537 068867	OLGA KALININA	{"email": "olga-kalinina-1972@postgrespro.ru", "phone": "+70069930357"}
0005433103007	DA163D	5920 162540	NADEZHDA FILIPPOVA	{"email": "nfilippova_1965@postgrespro.ru", "phone": "+70599804655"}
0005433103008	DDF981	1293 191085	NATALYA KUDRYASHOVA	{"phone": "+70238763684"}
0005433103009	68B5E8	8094 843580	YAROSLAVA KOROLEVA	{"email": "y_koroleva25121975@postgrespro.ru", "phone": "+70381964354"}
0005433103010	358037	4015 807824	SVETLANA SOROKINA	{"email": "sorokinasvetlana_091966@postgrespro.ru", "phone": "+70679201875"}
0005433103011	6FF5CA	9910 093833	ALEKSANDR EGOROV	{"email": "aegorov-071967@postgrespro.ru", "phone": "+70283518232"}
0005433103012	DF8200	1316 888946	VLADIMIR KISELEV	{"phone": "+70484437965"}
0005433103013	E2508C	1790 974912	GALINA GUSEVA	{"email": "g_guseva.091961@postgrespro.ru", "phone": "+70052773874"}
0005433103014	802EA0	5613 184487	VALERIYA KOZLOVA	{"phone": "+70970078976"}
0005433103015	802EA0	2429 941153	DARYA SOKOLOVA	{"phone": "+70554455518"}
0005433103016	480FB4	0584 084225	VALENTINA AKIMOVA	{"phone": "+70733558081"}
0005433103017	5D14EA	4445 915321	PAVEL DENISOV	{"email": "denisov.pavel-25021971@postgrespro.ru", "phone": "+70352545954"}
0005433103018	5D14EA	9365 591640	DMITRIY PAVLOV	{"phone": "+70111239009"}
0005433103019	68E3CE	1739 164791	YULIYA MAKAROVA	{"email": "makarova_y.1960@postgrespro.ru", "phone": "+70729516657"}
0005433103020	C46CB0	5868 564837	IGOR IVANOV	{"email": "ivanov_i101969@postgrespro.ru", "phone": "+70749413989"}
0005433103021	D143D6	1771 686674	VALERIY AFANASEV	{"phone": "+70511106887"}
0005433103022	8E414E	6056 307383	ALEKSEY IVANOV	{"phone": "+70438452035"}
0005433103023	7DD614	1220 819166	ELIZAVETA NOVIKOVA	{"email": "novikova.elizaveta_1970@postgrespro.ru", "phone": "+70168866820"}
0005433103024	7DD614	5887 448329	VALENTINA OSIPOVA	{"email": "osipova.valentina07051977@postgrespro.ru", "phone": "+70562077527"}
0005433103025	954BCB	8288 988462	VASILISA KUZNECOVA	{"email": "v.kuznecova_21041975@postgrespro.ru", "phone": "+70861921961"}
0005433103026	954BCB	2832 026714	VLADISLAV ZAKHAROV	{"email": "zakharov_vladislav-081968@postgrespro.ru", "phone": "+70117654594"}
0005433103027	0EF47E	4559 933392	GENNADIY MELNIKOV	{"email": "melnikov_gennadiy.19011970@postgrespro.ru", "phone": "+70920514969"}
0005433103028	0EF47E	6598 112411	LEONID PETROV	{"email": "petrov-leonid.18011973@postgrespro.ru", "phone": "+70822036752"}
0005433103029	0A3530	2560 042602	EVDOKIYA GRISHINA	{"email": "grishinae_051968@postgrespro.ru", "phone": "+70304296268"}
0005433103087	FBE978	4766 315127	DANILA FOMIN	{"phone": "+70627216258"}
0005433103030	0A3530	5391 979448	ALEKSANDR ALEKSEEV	{"email": "alekseevaleksandr_05111973@postgrespro.ru", "phone": "+70701318115"}
0005433103031	A11F3B	0266 779675	ALEKSEY IVANOV	{"phone": "+70359634199"}
0005433103032	A11F3B	9880 646964	LYUDMILA FADEEVA	{"phone": "+70101409410"}
0005433103033	C10D18	4402 934370	NADEZHDA KOVALEVA	{"phone": "+70072821231"}
0005433103034	0383E4	9239 376301	EKATERINA KOVALEVA	{"email": "e-kovaleva_1975@postgrespro.ru", "phone": "+70987362643"}
0005433103035	47DB4A	7157 965617	ALEKSANDR GUSEV	{"email": "aleksandr-gusev_111969@postgrespro.ru", "phone": "+70831325112"}
0005433103036	53B64C	5727 565236	VLADIMIR SAVELEV	{"email": "savelev.vladimir.081975@postgrespro.ru", "phone": "+70606880794"}
0005433103037	62053F	2346 265834	VALERIY VOROBEV	{"email": "valeriy-vorobev29081972@postgrespro.ru", "phone": "+70855775783"}
0005433103038	62053F	4749 041339	KLAVDIYA PETROVA	{"email": "petrova.klavdiya-1973@postgrespro.ru", "phone": "+70877023212"}
0005433103039	1B3AAF	6200 054668	VLADISLAV SOLOVEV	{"phone": "+70820369060"}
0005433103040	1B3AAF	8537 710064	ALEVTINA SIDOROVA	{"email": "alevtina_sidorova_06061968@postgrespro.ru", "phone": "+70520000282"}
0005433103041	0BD146	4587 096471	NATALYA VOLKOVA	{"email": "natalyavolkova_1960@postgrespro.ru", "phone": "+70510774152"}
0005433103042	7494BB	5309 494532	SVETLANA BELOVA	{"phone": "+70642104447"}
0005433103043	C68EE3	8381 587609	VIKTOR SOKOLOV	{"phone": "+70130624518"}
0005433103044	C68EE3	1137 480307	FEDOR SAVELEV	{"phone": "+70185811131"}
0005433103045	C68EE3	9744 228212	ELIZAVETA ANDREEVA	{"email": "andreeva-elizaveta.091969@postgrespro.ru", "phone": "+70698156242"}
0005433103046	8CEC2F	2279 235607	ELENA KOVALEVA	{"email": "kovalevae1984@postgrespro.ru", "phone": "+70305240389"}
0005433103047	6ED77E	6144 717652	TIMUR EGOROV	{"email": "egorov_timur_1973@postgrespro.ru", "phone": "+70747511023"}
0005433103048	A0154F	2295 588309	IRINA IVANOVA	{"email": "ivanova_i-07021963@postgrespro.ru", "phone": "+70989099745"}
0005433103049	A0154F	9992 445046	VYACHESLAV GUSEV	{"phone": "+70469113313"}
0005433103050	7DCF7B	2554 346512	GALINA MELNIKOVA	{"phone": "+70881822203"}
0005433103051	7DCF7B	6925 983495	YURIY POPOV	{"email": "popovyuriy_1980@postgrespro.ru", "phone": "+70101330557"}
0005433103052	B4BBFA	2918 854432	VIKTOR IVANOV	{"email": "viktor.ivanov05091974@postgrespro.ru", "phone": "+70521233665"}
0005433103053	B4BBFA	9709 029733	LYUDMILA ZAKHAROVA	{"email": "l-zakharova1980@postgrespro.ru", "phone": "+70336808130"}
0005433103054	DB85F2	0408 255487	DMITRIY POPOV	{"email": "d_popov_1968@postgrespro.ru", "phone": "+70961397763"}
0005433103055	DB85F2	6069 438053	ANASTASIYA ZAYCEVA	{"phone": "+70773875096"}
0005433103056	03266D	3895 262065	MAKSIM YAKOVLEV	{"phone": "+70122678930"}
0005433103057	546B5B	8131 346108	VALENTINA IVANOVA	{"phone": "+70829743289"}
0005433103058	35FBB1	6508 407620	DMITRIY KISELEV	{"phone": "+70352371795"}
0005433103059	DF57FC	9703 483741	VLADIMIR MOROZOV	{"phone": "+70098652629"}
0005433103060	7B627E	8578 187819	YULIYA MAKAROVA	{"phone": "+70372039301"}
0005433103061	7B627E	1083 852703	VALERIY MAKAROV	{"phone": "+70207371601"}
0005433103062	07F60D	6956 169698	RAILYA EGOROVA	{"email": "egorovarailya_12111973@postgrespro.ru", "phone": "+70190980623"}
0005433103063	418CEF	0100 571195	NINA ANDREEVA	{"email": "n_andreeva.17081969@postgrespro.ru", "phone": "+70588628139"}
0005433103064	2FED6F	4270 239352	DMITRIY ILIN	{"email": "dmitriy-ilin1967@postgrespro.ru", "phone": "+70548211503"}
0005433103065	2FED6F	4531 871440	DMITRIY PETROV	{"email": "petrovd031972@postgrespro.ru", "phone": "+70626295948"}
0005433103066	2FED6F	3482 410445	PETR ZHUKOV	{"email": "zhukov.p_1982@postgrespro.ru", "phone": "+70415818009"}
0005433103067	72AC13	7790 752973	YULIYA NAUMOVA	{"email": "naumovay_22111975@postgrespro.ru", "phone": "+70290177128"}
0005433103068	72AC13	3526 853618	LIDIYA VOLKOVA	{"phone": "+70507354578"}
0005433103069	72AC13	1733 692374	SERGEY GORBUNOV	{"email": "gorbunov.s081972@postgrespro.ru", "phone": "+70405844524"}
0005433103070	72AC13	8288 165719	VYACHESLAV KUZMIN	{"phone": "+70221503860"}
0005433103071	8517F2	5629 455684	TATYANA ORLOVA	{"email": "orlova_tatyana-28081968@postgrespro.ru", "phone": "+70834704221"}
0005433103072	67183B	5137 002000	OLGA MELNIKOVA	{"phone": "+70136363430"}
0005433103073	16A8D5	7889 105705	EKATERINA PAVLOVA	{"email": "e_pavlova.1977@postgrespro.ru", "phone": "+70808566225"}
0005433103074	E4398D	7426 037230	EVGENIY POPOV	{"email": "evgeniy_popov27061981@postgrespro.ru", "phone": "+70475865514"}
0005433103075	242907	7503 412271	OLEG PETROV	{"email": "petrov.o-21031961@postgrespro.ru", "phone": "+70621446042"}
0005433103076	242907	7265 320971	ALEKSANDR SHEVCHENKO	{"email": "aleksandr.shevchenko1964@postgrespro.ru", "phone": "+70574418985"}
0005433103077	242907	5911 051679	LYUDMILA ILINA	{"email": "l.ilina-1973@postgrespro.ru", "phone": "+70301739920"}
0005433103078	78749C	6079 528148	VLADISLAV ISAEV	{"phone": "+70807498994"}
0005433103079	331544	2885 543522	NADEZHDA BORISOVA	{"phone": "+70496195209"}
0005433103080	ED8E75	7711 126214	ELENA ZOTOVA	{"email": "elenazotova28051961@postgrespro.ru", "phone": "+70950856017"}
0005433103081	ED8E75	4647 691173	MATVEY KISELEV	{"phone": "+70509586203"}
0005433103082	ED8E75	7610 693179	NINA FROLOVA	{"email": "nfrolova031971@postgrespro.ru", "phone": "+70225808355"}
0005433103083	ECFE19	3895 314950	NIKOLAY KULIKOV	{"email": "nikolay_kulikov.081982@postgrespro.ru", "phone": "+70596148055"}
0005433103084	ECFE19	2618 177394	MARAT SMIRNOV	{"phone": "+70412944953"}
0005433103085	FF22A6	7669 218974	IVAN RODIONOV	{"email": "rodionov.ivan24011982@postgrespro.ru", "phone": "+70900597035"}
0005433103088	FBE978	0463 819517	MARINA MAKSIMOVA	{"email": "mmaksimova.041977@postgrespro.ru", "phone": "+70847240713"}
0005433103089	93EDF8	6934 863351	RASHID VOROBEV	{"email": "vorobevrashid.30011970@postgrespro.ru", "phone": "+70281232455"}
0005433103090	4F9C45	9985 507320	DARYA ISAEVA	{"phone": "+70461007628"}
0005433103091	967DA2	5104 592928	NADEZHDA DAVYDOVA	{"phone": "+70353135627"}
0005433103092	81B3D5	5230 755638	OLGA KOLESNIKOVA	{"email": "kolesnikova.o.1980@postgrespro.ru", "phone": "+70957741068"}
0005433103093	81B3D5	7759 816579	VALENTIN SIDOROV	{"phone": "+70516375754"}
0005433103094	E98A8E	0486 441135	NATALYA ANDREEVA	{"phone": "+70974058676"}
0005433103095	8FAD32	9269 948674	VALENTINA NAUMOVA	{"email": "naumova-valentina1965@postgrespro.ru", "phone": "+70851932363"}
0005433103096	A04999	9717 174287	TATYANA BARANOVA	{"phone": "+70413321473"}
0005433103097	A04999	1760 292839	DMITRIY DENISOV	{"phone": "+70146496682"}
0005433103098	319F6C	2999 845564	VERA VOROBEVA	{"email": "v_vorobeva.1968@postgrespro.ru", "phone": "+70599431495"}
0005433103099	319F6C	7779 079757	ANTONINA SIDOROVA	{"phone": "+70325921395"}
0005433103100	81C7B0	7369 835120	ANATOLIY SIDOROV	{"phone": "+70377613021"}
0005433103101	81C7B0	3878 498662	LADA NAUMOVA	{"phone": "+70116942746"}
0005433103102	F85954	0475 343215	RAISA EGOROVA	{"email": "raisa_egorova-051960@postgrespro.ru", "phone": "+70114132193"}
0005433103103	C6C8A8	3527 293223	ALEKSANDR GAVRILOV	{"phone": "+70142028624"}
0005433103104	6EF7D8	9634 656967	SERGEY POPOV	{"email": "s.popov-1976@postgrespro.ru", "phone": "+70614878975"}
0005433103105	0F9262	7372 297485	LEV CHERNOV	{"phone": "+70575303958"}
0005433103106	EE0A30	1458 777760	OLEG ANDREEV	{"phone": "+70878385441"}
0005433103107	7AD35E	8284 989992	DANIYA RYABOVA	{"phone": "+70898142807"}
0005433103108	1FDC4C	9338 159228	ALEKSANDR OSIPOV	{"phone": "+70425037398"}
0005433103109	1FDC4C	3267 123167	ALISA MIRONOVA	{"phone": "+70979201926"}
0005433103110	8A1B8D	0123 974528	ALEKSANDRA LAZAREVA	{"email": "alazareva111965@postgrespro.ru", "phone": "+70141571601"}
0005433103111	80F46B	3368 396596	OLGA MARTYNOVA	{"phone": "+70152416747"}
0005433103112	52E0F2	6759 002327	ALENA ANTONOVA	{"phone": "+70902025267"}
0005433103113	52E0F2	0449 283991	SERGEY ZHURAVLEV	{"phone": "+70765555277"}
0005433103114	4E206B	7971 585829	YULIYA KULIKOVA	{"email": "y_kulikova11121972@postgrespro.ru", "phone": "+70297203301"}
0005433103115	4E206B	1044 979162	VALERIY AFANASEV	{"phone": "+70859873636"}
0005433103116	7F9794	1647 296322	OLGA POPOVA	{"phone": "+70240177813"}
0005433103117	4116EE	9740 364004	LYUBOV NESTEROVA	{"phone": "+70665336663"}
0005433103118	5D85C1	6158 868595	ANATOLIY FROLOV	{"phone": "+70762434032"}
0005433103119	5D85C1	3700 329581	ANASTASIYA KOROLEVA	{"email": "koroleva_a1978@postgrespro.ru", "phone": "+70166566102"}
0005433103120	24F312	7624 816020	ALEKSANDR DAVYDOV	{"phone": "+70185390496"}
0005433103121	4AB02E	6399 875112	ALEKSEY MELNIKOV	{"email": "a-melnikov.1971@postgrespro.ru", "phone": "+70210526838"}
0005433103122	4AB02E	9061 165340	IRINA PETROVA	{"email": "petrovai.031982@postgrespro.ru", "phone": "+70795710736"}
0005433103123	4AB02E	6732 277133	NATALYA NOVIKOVA	{"phone": "+70630296969"}
0005433103124	199FA0	0245 146227	MARGARITA KONOVALOVA	{"phone": "+70231996471"}
0005433103125	199FA0	2460 016509	LYUBOV ANTONOVA	{"email": "antonova-l.06121966@postgrespro.ru", "phone": "+70089288250"}
0005433103126	12C17C	5192 223678	OLEG ANTONOV	{"phone": "+70844506802"}
0005433103127	FF0602	1979 379983	ALEKSEY VASILEV	{"phone": "+70888637098"}
0005433103128	5C24E4	5848 039022	KONSTANTIN PAVLOV	{"email": "pavlov.k_061981@postgrespro.ru", "phone": "+70579574047"}
0005433103129	3B2781	2366 490187	ALEKSANDR KAZAKOV	{"email": "aleksandr-kazakov.1975@postgrespro.ru", "phone": "+70627570205"}
0005433103130	6E02C2	6528 549208	ALEKSANDR FEDOROV	{"email": "afedorov_101976@postgrespro.ru", "phone": "+70495372804"}
0005433103131	77B237	0247 894843	MARIYA ZHUKOVA	{"phone": "+70652261788"}
0005433103132	77B237	1577 402876	EVGENIY GERASIMOV	{"phone": "+70780945143"}
0005433103133	14E768	9930 861239	EKATERINA GERASIMOVA	{"phone": "+70089810216"}
0005433103134	14E768	7180 205116	GALINA EGOROVA	{"phone": "+70486399876"}
0005433103135	AB153B	0057 044144	ALEKSANDR POPOV	{"email": "popov.a_1963@postgrespro.ru", "phone": "+70887728249"}
0005433103136	AB153B	8498 143760	ANNA NIKITINA	{"email": "nikitinaanna1971@postgrespro.ru", "phone": "+70888757399"}
0005433103137	AA8B82	3773 112893	NADEZHDA SOKOLOVA	{"email": "n-sokolova-1958@postgrespro.ru", "phone": "+70103182252"}
0005433103138	53FA3F	7236 812097	LYUDMILA ZAKHAROVA	{"email": "lyudmilazakharova.1974@postgrespro.ru", "phone": "+70964383288"}
0005433103139	7098D1	8462 479089	DARYA NAZAROVA	{"phone": "+70103552322"}
0005433103140	7098D1	1363 911625	LIDIYA NIKOLAEVA	{"email": "lidiyanikolaeva.17081977@postgrespro.ru", "phone": "+70636489912"}
0005433103141	506DA8	7414 892327	ANZHELIKA MIRONOVA	{"email": "mironovaa.1973@postgrespro.ru", "phone": "+70365446627"}
0005433103142	C1F0D6	2908 112549	TATYANA KONOVALOVA	{"email": "konovalova.t-03121975@postgrespro.ru", "phone": "+70901106947"}
0005433103143	E2A2CA	2498 260365	ELENA KOROLEVA	{"email": "elena.koroleva_021965@postgrespro.ru", "phone": "+70616595528"}
0005433103144	27AA5E	9008 969126	GALINA MOROZOVA	{"email": "morozova-g.1972@postgrespro.ru", "phone": "+70217234113"}
0005433103145	59CBAF	7170 711279	MARIYA FILIPPOVA	{"email": "m.filippova1973@postgrespro.ru", "phone": "+70958520638"}
0005433103146	59CBAF	9325 202893	ANNA NESTEROVA	{"email": "anesterova.111964@postgrespro.ru", "phone": "+70250422150"}
0005433103147	89EB3A	8252 574422	ALEKSANDR VOLKOV	{"email": "a.volkov_071987@postgrespro.ru", "phone": "+70548331114"}
0005433103148	542175	9865 610340	ELENA KUZNECOVA	{"phone": "+70671790139"}
0005433103149	F0407E	8700 668706	SERGEY MAKAROV	{"phone": "+70839590467"}
0005433103150	E2E884	4581 972859	IVAN KOZLOV	{"email": "kozlov_ivan15091973@postgrespro.ru", "phone": "+70398892803"}
0005433103151	246A23	7762 072497	SERGEY BELOV	{"email": "belov_s_1974@postgrespro.ru", "phone": "+70111645041"}
0005433103152	791758	7081 665993	ANASTASIYA KALININA	{"email": "kalinina.a.12061967@postgrespro.ru", "phone": "+70049354910"}
0005433103153	ABE527	7604 117871	VADIM PAVLOV	{"phone": "+70600370253"}
0005433103154	ABE527	1530 014334	MARINA MOROZOVA	{"email": "morozova_m-1971@postgrespro.ru", "phone": "+70984051620"}
0005433103155	CB58F9	2701 487378	TAMARA KRASNOVA	{"phone": "+70523298221"}
0005433103156	64B71B	4334 515671	OLGA LEBEDEVA	{"email": "olga_lebedeva_1974@postgrespro.ru", "phone": "+70105031189"}
0005433103157	DE5F86	1590 168020	NATALYA GUSEVA	{"email": "guseva.n.01051961@postgrespro.ru", "phone": "+70831399812"}
0005433103158	684B16	3045 916626	SVETLANA SEMENOVA	{"phone": "+70488049871"}
0005433103159	684B16	8394 562229	VALERIY YAKOVLEV	{"phone": "+70320726260"}
0005433103160	8C67A5	2558 181886	YULIYA MELNIKOVA	{"email": "y.melnikova_11051979@postgrespro.ru", "phone": "+70439873483"}
0005433103161	545634	1964 022332	ALEKSANDR RODIONOV	{"phone": "+70200500015"}
0005433103162	545634	3114 405086	MIKHAIL POPOV	{"email": "mikhail-popov-30111976@postgrespro.ru", "phone": "+70386921612"}
0005433103163	7F64CF	7580 597769	OKSANA MELNIKOVA	{"email": "melnikovao_1981@postgrespro.ru", "phone": "+70572930309"}
0005433103164	7F64CF	6848 184604	ELEONORA ALEKSEEVA	{"email": "alekseeva.eleonora1977@postgrespro.ru", "phone": "+70058589562"}
0005433103165	7F64CF	2066 798708	POLINA POPOVA	{"phone": "+70047218281"}
0005433103166	7F64CF	5349 303550	NATALIYA EFREMOVA	{"phone": "+70137712171"}
0005433103167	375A23	2902 819413	SERGEY ALEKSEEV	{"email": "alekseev_s-091978@postgrespro.ru", "phone": "+70524406766"}
0005433103168	3617CA	8052 051364	LYUDMILA FEDOROVA	{"phone": "+70784994731"}
0005433103169	3617CA	8397 865902	LYUBOV DAVYDOVA	{"phone": "+70214958542"}
0005433103170	3617CA	8105 994471	NIKOLAY KISELEV	{"email": "kiselevnikolay.111981@postgrespro.ru", "phone": "+70549808616"}
0005433103171	A78F28	0315 512409	IRAIDA PAVLOVA	{"email": "pavlova_iraida.21031962@postgrespro.ru", "phone": "+70088531551"}
0005433103172	169BE1	3853 018204	VLADIMIR OSIPOV	{"email": "osipov_v_03101968@postgrespro.ru", "phone": "+70203395774"}
0005433103173	169BE1	8863 266139	ELMIRA KALININA	{"email": "kalinina.e051973@postgrespro.ru", "phone": "+70231233813"}
0005433103174	F6F163	9454 664389	ALEKSANDR NIKITIN	{"email": "nikitin_a-03041966@postgrespro.ru", "phone": "+70271630202"}
0005433103175	AA05B7	7496 495671	ALEKSEY FROLOV	{"email": "frolov-a.1962@postgrespro.ru", "phone": "+70609566183"}
0005433103176	40CCE8	8331 734606	DANIYA STEPANOVA	{"email": "stepanova.d_27121969@postgrespro.ru", "phone": "+70782985851"}
0005433103177	F46EE9	0105 083289	TIMOFEY KUDRYASHOV	{"phone": "+70336318738"}
0005433103178	B87956	4364 315790	TATYANA OSIPOVA	{"phone": "+70307100036"}
0005433103179	B0AC48	0107 474524	ANDREY FOMIN	{"email": "fomina24041970@postgrespro.ru", "phone": "+70275299344"}
0005433103180	B0AC48	9258 612051	DMITRIY KUZNECOV	{"phone": "+70131015225"}
0005433103181	F7C62C	8568 985659	MAKSIM ABRAMOV	{"email": "abramovmaksim.04041961@postgrespro.ru", "phone": "+70800681903"}
0005433103182	26CC2B	1235 358809	ALEKSANDR KAZAKOV	{"email": "kazakov.a041971@postgrespro.ru", "phone": "+70398285143"}
0005433103183	09B231	0638 284219	SVETLANA IVANOVA	{"email": "svetlana.ivanova-071966@postgrespro.ru", "phone": "+70424854203"}
0005433103184	09B231	2945 220507	SERGEY MELNIKOV	{"phone": "+70092387779"}
0005433103185	338EC9	9300 362300	LIDIYA ORLOVA	{"email": "l-orlova_1981@postgrespro.ru", "phone": "+70202858637"}
0005433103186	338EC9	4950 569687	SERGEY STEPANOV	{"email": "sergey_stepanov.10111977@postgrespro.ru", "phone": "+70106220699"}
0005433103187	AE3865	9930 196798	EVGENIY FROLOV	{"email": "frolov_e031968@postgrespro.ru", "phone": "+70224584816"}
0005433103188	6629AE	1080 121608	ANATOLIY CHERNOV	{"email": "a_chernov_1975@postgrespro.ru", "phone": "+70625083005"}
0005433103189	485A86	0196 578599	ALEKSANDR VOROBEV	{"phone": "+70923717326"}
0005433103190	485A86	7606 431944	YURIY VLASOV	{"email": "vlasovy.121971@postgrespro.ru", "phone": "+70929637726"}
0005433103191	4748F6	1827 018496	VIKTOR SAVELEV	{"phone": "+70782463262"}
0005433103192	26EBD4	3921 043549	VYACHESLAV POPOV	{"email": "vyacheslav_popov_1980@postgrespro.ru", "phone": "+70908190056"}
0005433103193	A86A87	6583 886452	ALINA IVANOVA	{"email": "ivanova_alina.14081974@postgrespro.ru", "phone": "+70341514254"}
0005433103194	8CAD52	7097 031160	SERGEY PETROV	{"email": "spetrov-051981@postgrespro.ru", "phone": "+70637471314"}
0005433103195	5E4B4E	5996 792018	SVETLANA ILINA	{"email": "svetlana_ilina-071972@postgrespro.ru", "phone": "+70130543701"}
0005433103196	B8CCA2	8559 873211	MARYAM ZOTOVA	{"phone": "+70166590926"}
0005433103197	54BFAA	2641 033644	OKSANA KUZNECOVA	{"phone": "+70895229332"}
0005433103198	FFC26B	6049 832623	LIDIYA KUZNECOVA	{"phone": "+70225805528"}
0005433103199	FFC26B	8072 000328	LYUDMILA NAUMOVA	{"email": "lnaumova18111988@postgrespro.ru", "phone": "+70147229394"}
0005433103200	4CC4CB	6679 922886	KRISTINA ANTONOVA	{"phone": "+70638509411"}
0005433103201	710CD1	1073 543508	VITALIY IVANOV	{"email": "ivanov_vitaliy-09121969@postgrespro.ru", "phone": "+70505189641"}
0005433103202	36C913	6018 635039	LIDIYA KUDRYASHOVA	{"phone": "+70221937406"}
0005433103203	B4E696	3445 089617	NATALYA LAZAREVA	{"email": "lazareva.natalya.1978@postgrespro.ru", "phone": "+70343975557"}
0005433103204	B4E696	3092 852350	DAVID NIKOLAEV	{"phone": "+70514260793"}
0005433103205	B0C3B5	9860 454746	ILDAR MOROZOV	{"email": "imorozov-02071978@postgrespro.ru", "phone": "+70271483134"}
0005433103206	B0C3B5	3502 718943	GALINA AFANASEVA	{"email": "afanaseva_g_021985@postgrespro.ru", "phone": "+70964580611"}
0005433103207	77AED5	9012 312987	ROMAN MIKHAYLOV	{"email": "r-mikhaylov-091964@postgrespro.ru", "phone": "+70789880071"}
0005433103208	C3D608	2566 911741	KIRILL YAKOVLEV	{"phone": "+70391654321"}
0005433103209	CC5534	2920 407394	NATALYA ZOTOVA	{"phone": "+70823754350"}
0005433103210	F63CEF	0975 086698	NATALIYA TIMOFEEVA	{"email": "n_timofeeva-07011974@postgrespro.ru", "phone": "+70635252063"}
0005433103211	145276	6491 601248	NIKOLAY GUSEV	{"email": "nikolaygusev.11061975@postgrespro.ru", "phone": "+70448205295"}
0005433103212	4B2F97	0099 393043	MARIYA DAVYDOVA	{"email": "davydova_m-26041958@postgrespro.ru", "phone": "+70292419028"}
0005433103213	E839DB	3902 019183	TAMARA CHERNOVA	{"email": "chernova.t.24011977@postgrespro.ru", "phone": "+70377290857"}
0005433103214	E839DB	4129 261291	DMITRIY MARTYNOV	{"phone": "+70936403097"}
0005433103215	099077	8545 155905	ALEKSANDR SERGEEV	{"phone": "+70589894301"}
0005433103216	099077	4880 971310	ELENA BELOVA	{"phone": "+70156678295"}
0005433103217	FDCBAA	3874 409927	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy.041961@postgrespro.ru", "phone": "+70991985517"}
0005433103218	7EC094	5238 200427	TATYANA IVANOVA	{"phone": "+70825637621"}
0005433103219	80AACF	4405 375288	LYUDMILA AFANASEVA	{"phone": "+70391185871"}
0005433103220	296337	3591 597608	ANDREY KOZLOV	{"email": "andrey_kozlov.1968@postgrespro.ru", "phone": "+70041339361"}
0005433103221	F4E20A	6687 890389	SVETLANA GAVRILOVA	{"phone": "+70747482567"}
0005433103222	30EBB5	1958 818352	VLADIMIR FEDOROV	{"phone": "+70033778060"}
0005433103223	D997DE	3036 444868	SVETLANA EFREMOVA	{"email": "s-efremova_06061967@postgrespro.ru", "phone": "+70748905874"}
0005433103224	AF1C27	8300 299705	NATALYA KULIKOVA	{"phone": "+70632026676"}
0005433103225	088535	3317 814187	IRINA TIMOFEEVA	{"email": "i.timofeeva_041980@postgrespro.ru", "phone": "+70799763686"}
0005433103226	088535	2050 516666	VALERIY EGOROV	{"phone": "+70168786362"}
0005433103227	E36300	7880 246367	IVAN NAZAROV	{"phone": "+70878827813"}
0005433103228	82100F	4121 747661	VASILIY MAKAROV	{"phone": "+70186151608"}
0005433103229	C0B0F0	6301 329829	LILIYA SMIRNOVA	{"email": "liliya-smirnova-17121977@postgrespro.ru", "phone": "+70122946766"}
0005433103230	6BD075	3345 281859	VIKTORIYA ORLOVA	{"phone": "+70771463700"}
0005433103231	7868A4	5843 619936	MARIYA LEBEDEVA	{"email": "m.lebedeva.111965@postgrespro.ru", "phone": "+70290158614"}
0005433103232	9ADA23	4878 617361	VIKTORIYA MAKSIMOVA	{"phone": "+70376270316"}
0005433103233	9ADA23	1386 433366	RUSLAN SMIRNOV	{"email": "r-smirnov.04061976@postgrespro.ru", "phone": "+70393056132"}
0005433103234	A6EC44	5032 174595	EKATERINA ZHURAVLEVA	{"email": "ekaterina.zhuravleva_1979@postgrespro.ru", "phone": "+70167486935"}
0005433103235	9628D9	2265 542293	LARISA KOZLOVA	{"phone": "+70633700169"}
0005433103236	9628D9	5659 782923	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev.041977@postgrespro.ru", "phone": "+70031592953"}
0005433103237	55B2CE	2355 935721	DENIS KUDRYASHOV	{"phone": "+70145822515"}
0005433103238	433EA3	4220 757672	IGOR BONDARENKO	{"email": "bondarenko-igor-1959@postgrespro.ru", "phone": "+70229785692"}
0005433103239	17E4D0	5364 209228	OLGA GUSEVA	{"phone": "+70628641737"}
0005433103240	3DD125	4080 008938	DMITRIY FOMIN	{"email": "fomind-05051969@postgrespro.ru", "phone": "+70037521793"}
0005433103241	68AEC8	4966 399959	VIKTOR VASILEV	{"phone": "+70029179259"}
0005433103242	68AEC8	6611 447101	IVAN VOROBEV	{"email": "ivan-vorobev-1972@postgrespro.ru", "phone": "+70748990608"}
0005433103243	C16AF0	9081 064957	NINA KONOVALOVA	{"phone": "+70368336745"}
0005433103244	6461D5	5191 677713	DARYA MIRONOVA	{"phone": "+70031452345"}
0005433103245	E23956	3441 290382	ANASTASIYA VASILEVA	{"email": "vasileva.anastasiya-14021972@postgrespro.ru", "phone": "+70002607552"}
0005433103246	98E3B5	7542 635158	ANTONINA STEPANOVA	{"email": "stepanova-a061966@postgrespro.ru", "phone": "+70379730781"}
0005433103247	227F84	1982 978787	IVAN KUZNECOV	{"email": "kuznecov.i_071978@postgrespro.ru", "phone": "+70634211325"}
0005433103248	D70C3D	1373 050240	ALEKSEY ISAEV	{"phone": "+70290812586"}
0005433103249	A9114E	5833 503628	VALENTINA ARKHIPOVA	{"phone": "+70736833516"}
0005433103250	1D9405	9264 694179	ALEKSEY BONDARENKO	{"email": "a_bondarenko.18071971@postgrespro.ru", "phone": "+70234303767"}
0005433103251	B1DF77	4879 210172	VERA IVANOVA	{"email": "ivanovav_1963@postgrespro.ru", "phone": "+70118861850"}
0005433103252	D098B3	2307 081580	DMITRIY FROLOV	{"phone": "+70016513573"}
0005433103253	27C443	6114 321094	OLGA MATVEEVA	{"email": "o-matveeva-071955@postgrespro.ru", "phone": "+70332774235"}
0005433103254	97C892	2164 481321	VERA SOROKINA	{"email": "verasorokina26021972@postgrespro.ru", "phone": "+70849502311"}
0005433103255	213B51	0222 382615	GENNADIY MOROZOV	{"email": "gennadiy-morozov-1968@postgrespro.ru", "phone": "+70998245048"}
0005433103256	D1286A	7744 520474	SERGEY MAKSIMOV	{"email": "sergeymaksimov_121976@postgrespro.ru", "phone": "+70550611075"}
0005433103257	089D6E	2647 934167	ANTONINA MAKSIMOVA	{"email": "a.maksimova041983@postgrespro.ru", "phone": "+70912135336"}
0005433103258	A846A1	9770 544536	EKATERINA POPOVA	{"phone": "+70770411934"}
0005433103259	A6BCE5	5810 188647	ANNA KOROLEVA	{"phone": "+70970417529"}
0005433103260	A6BCE5	6868 832115	ALBINA VASILEVA	{"phone": "+70806469471"}
0005433103261	6C303E	6236 624972	IRINA EFIMOVA	{"email": "efimova_irina.1976@postgrespro.ru", "phone": "+70066512500"}
0005433103262	7C95A2	8971 058515	ANATOLIY NIKITIN	{"email": "anatoliy.nikitin13111978@postgrespro.ru", "phone": "+70028738841"}
0005433103263	5197DD	8348 097948	FEDOR KISELEV	{"phone": "+70547026510"}
0005433103264	380F99	7347 566624	MARINA ABRAMOVA	{"phone": "+70952494751"}
0005433103265	ECC75E	6912 881269	LYUDMILA ZHURAVLEVA	{"email": "lzhuravleva_021970@postgrespro.ru", "phone": "+70191437117"}
0005433103266	ECC75E	6302 386018	MIKHAIL DENISOV	{"phone": "+70020507816"}
0005433103267	30C42D	3720 231546	ALEKSEY POPOV	{"email": "aleksey-popov-1978@postgrespro.ru", "phone": "+70893085510"}
0005433103268	30C42D	3368 807233	SVETLANA TROFIMOVA	{"email": "svetlana.trofimova.15081976@postgrespro.ru", "phone": "+70143122323"}
0005433103269	AFA490	3755 835228	SERGEY KARPOV	{"phone": "+70467253838"}
0005433103270	5914E1	2025 942956	NIKOLAY SIDOROV	{"phone": "+70948666816"}
0005433103271	5914E1	4533 859086	PAVEL MOISEEV	{"phone": "+70641086279"}
0005433103272	5914E1	7124 815849	ELENA VASILEVA	{"phone": "+70852628479"}
0005433103273	C5F8EF	7437 458729	ALEKSANDR PETROV	{"email": "a-petrov.1976@postgrespro.ru", "phone": "+70258355329"}
0005433103274	C5F8EF	4922 809884	LYUDMILA EFIMOVA	{"email": "lyudmila-efimova.071962@postgrespro.ru", "phone": "+70673834195"}
0005433103275	7DF43B	9639 300317	VLADIMIR ZHURAVLEV	{"phone": "+70550307260"}
0005433103276	7DF43B	8477 091302	NATALYA FEDOROVA	{"email": "fedorova_natalya.15061971@postgrespro.ru", "phone": "+70729104761"}
0005433103277	5AC3B0	1051 410461	IRINA VASILEVA	{"email": "vasileva-irina071970@postgrespro.ru", "phone": "+70736945116"}
0005433103278	D9A652	6510 798924	NINA MOROZOVA	{"email": "n.morozova_1969@postgrespro.ru", "phone": "+70951750626"}
0005433103279	0DDDCC	4650 905066	SERGEY SEMENOV	{"phone": "+70795888886"}
0005433103280	12D709	5074 050484	TAMARA SIDOROVA	{"phone": "+70870164872"}
0005433103281	A3B4D0	9624 882947	RAFAEL KAZAKOV	{"phone": "+70771741809"}
0005433103282	A3B4D0	3749 486638	NATALYA TIKHONOVA	{"email": "tikhonovanatalya_081961@postgrespro.ru", "phone": "+70059482556"}
0005433103283	F653F9	0100 503451	ARTEM IVANOV	{"email": "artem-ivanov-17011975@postgrespro.ru", "phone": "+70150363826"}
0005433103284	AFA7AC	9514 478870	YURIY KUDRYASHOV	{"email": "kudryashov_y_121976@postgrespro.ru", "phone": "+70105177932"}
0005433103285	AFA7AC	0979 657146	NIKOLAY POPOV	{"email": "popov_n081964@postgrespro.ru", "phone": "+70194633268"}
0005433103286	633569	7706 309036	YURIY ALEKSEEV	{"phone": "+70224901863"}
0005433103287	5D79C2	3898 327010	TATYANA DAVYDOVA	{"phone": "+70635560781"}
0005433103288	5D79C2	1187 331877	ANATOLIY MATVEEV	{"phone": "+70827882480"}
0005433103289	E1584A	2757 257671	VIKTOR KOZLOV	{"email": "viktor-kozlov-30101979@postgrespro.ru", "phone": "+70487217319"}
0005433103290	18A789	1731 444088	EVGENIY SEMENOV	{"phone": "+70262015269"}
0005433103291	18A789	7690 542268	IRINA MEDVEDEVA	{"email": "medvedeva_irina.1981@postgrespro.ru", "phone": "+70824478434"}
0005433103292	64AB9B	6304 664411	ALEKSEY MIRONOV	{"email": "mironov.a031973@postgrespro.ru", "phone": "+70464835788"}
0005433103293	251EA1	3205 891071	VITALIY KOZLOV	{"phone": "+70169992155"}
0005433103294	E18113	0142 456080	EKATERINA GERASIMOVA	{"phone": "+70094254778"}
0005433103295	9199C0	7983 305074	PETR KOROLEV	{"phone": "+70247726635"}
0005433103296	3A6E1B	0831 976043	EVGENIY SAVELEV	{"email": "savelev-e.25121980@postgrespro.ru", "phone": "+70958548443"}
0005433103297	970694	4979 211109	EGOR ANTONOV	{"email": "egorantonov-071979@postgrespro.ru", "phone": "+70656217579"}
0005433103298	970694	6025 063904	GENNADIY NIKOLAEV	{"phone": "+70981706387"}
0005433103299	63AE65	2584 114179	ANTON KRASNOV	{"email": "krasnovanton1964@postgrespro.ru", "phone": "+70342677536"}
0005433103300	63AE65	4975 994937	MARINA MEDVEDEVA	{"email": "m.medvedeva.18041976@postgrespro.ru", "phone": "+70206084513"}
0005433103301	63AE65	6246 043111	POLINA KOROLEVA	{"email": "korolevapolina-011972@postgrespro.ru", "phone": "+70784902634"}
0005433103302	63AE65	7665 489408	VLADIMIR KOROLEV	{"phone": "+70990093912"}
0005433103303	7EAACC	2857 377935	VLADIMIR SOROKIN	{"email": "sorokin-vladimir31051979@postgrespro.ru", "phone": "+70881379647"}
0005433103304	7EAACC	6224 532343	DMITRIY FROLOV	{"email": "d_frolov_1972@postgrespro.ru", "phone": "+70527860417"}
0005433103305	7EAACC	3479 323005	YURIY KISELEV	{"email": "kiselev_y.11101973@postgrespro.ru", "phone": "+70033728030"}
0005433103306	7EAACC	1118 869558	SERGEY ILIN	{"email": "ilins061977@postgrespro.ru", "phone": "+70243353216"}
0005433103307	D77A71	4141 814711	NINA LOGINOVA	{"email": "loginovan.051974@postgrespro.ru", "phone": "+70464944136"}
0005433103308	8BBAEF	1381 950009	VLADIMIR EGOROV	{"phone": "+70830267010"}
0005433103309	8BBAEF	7882 024629	SVETLANA ABRAMOVA	{"phone": "+70989623390"}
0005433103310	809C2F	5015 983641	YANA SOKOLOVA	{"email": "yana-sokolova_061983@postgrespro.ru", "phone": "+70165693720"}
0005433103311	978C2B	8488 325869	NADEZHDA MAKSIMOVA	{"phone": "+70893126227"}
0005433103312	A24FE4	8224 920373	NATALYA SERGEEVA	{"email": "sergeeva.natalya_071973@postgrespro.ru", "phone": "+70353761777"}
0005433103313	A24FE4	8195 451028	BORIS KUZNECOV	{"phone": "+70135363265"}
0005433103314	F53A9E	8593 784309	MIKHAIL NAZAROV	{"phone": "+70537884325"}
0005433103315	F53A9E	7084 184749	OLEG SCHERBAKOV	{"email": "scherbakovo.1970@postgrespro.ru", "phone": "+70811414237"}
0005433103316	54DE1B	6353 433654	OLGA KOLESNIKOVA	{"email": "okolesnikova1970@postgrespro.ru", "phone": "+70869660178"}
0005433103317	54DE1B	9339 650818	ALEKSEY EGOROV	{"email": "aleksey.egorov_081981@postgrespro.ru", "phone": "+70945221858"}
0005433103318	54DE1B	2453 617256	ALEKSANDR GUSEV	{"email": "gusev_a.1963@postgrespro.ru", "phone": "+70988550688"}
0005433103319	54DE1B	8745 830611	ELENA KOROLEVA	{"phone": "+70898361772"}
0005433103320	D91334	1248 927569	KRISTINA STEPANOVA	{"email": "k_stepanova031983@postgrespro.ru", "phone": "+70116411189"}
0005433103321	9DEDBC	8357 979939	SANIYA MARTYNOVA	{"phone": "+70870344136"}
0005433103322	9DEDBC	7820 581447	DENIS STEPANOV	{"email": "stepanov.denis.1959@postgrespro.ru", "phone": "+70912624429"}
0005433103323	DC2E19	3324 266062	VLADIMIR KRASNOV	{"phone": "+70079671015"}
0005433103324	DC2E19	3527 406657	VYACHESLAV GORBUNOV	{"email": "v.gorbunov_30091959@postgrespro.ru", "phone": "+70690594932"}
0005433103325	14085A	1985 092023	SVETLANA FILIPPOVA	{"phone": "+70784801146"}
0005433103326	EE46B9	0863 213442	ARMAN EGOROV	{"email": "arman_egorov-18061972@postgrespro.ru", "phone": "+70928316003"}
0005433103327	EE46B9	2269 797666	ZINAIDA IVANOVA	{"email": "z_ivanova_24041971@postgrespro.ru", "phone": "+70547731146"}
0005433103328	EE46B9	8921 978721	LYUBOV MASLOVA	{"phone": "+70892740706"}
0005433103329	04F62A	6115 959039	LYUBOV ZAYCEVA	{"email": "zayceva-l.121980@postgrespro.ru", "phone": "+70616207948"}
0005433103330	D09BDC	4418 663267	YAN TARASOV	{"email": "tarasov_yan_1977@postgrespro.ru", "phone": "+70565529492"}
0005433103331	3483B6	7995 851864	ALEKSEY MATVEEV	{"phone": "+70243356533"}
0005433103332	3483B6	7610 985124	KONSTANTIN KONOVALOV	{"email": "k.konovalov_21011969@postgrespro.ru", "phone": "+70091914796"}
0005433103333	3483B6	3075 959476	SERGEY SOKOLOV	{"phone": "+70305147381"}
0005433103334	F5966A	4927 662129	PAVEL SCHERBAKOV	{"email": "pavel_scherbakov-06011976@postgrespro.ru", "phone": "+70868695436"}
0005433103335	F5966A	7073 839953	EKATERINA PAVLOVA	{"phone": "+70352709374"}
0005433103336	F5966A	9196 782443	MIKHAIL FROLOV	{"phone": "+70730248632"}
0005433103337	562E9A	5363 059108	VLADIMIR FEDOTOV	{"phone": "+70310016411"}
0005433103338	21F5CB	1287 169925	MIKHAIL MAKAROV	{"email": "makarovmikhail-24041978@postgrespro.ru", "phone": "+70468035437"}
0005433103339	BA1D6E	0196 312192	OLEG NIKOLAEV	{"email": "nikolaevoleg.10121972@postgrespro.ru", "phone": "+70761336898"}
0005433103340	24457E	5914 679988	ELENA GORBUNOVA	{"email": "gorbunova_e.11071971@postgrespro.ru", "phone": "+70030235464"}
0005433103341	EE1C7B	7260 401690	YULIYA NIKITINA	{"phone": "+70773073417"}
0005433103342	BAA9B1	0170 976784	DANILA ZHURAVLEV	{"email": "zhuravlev_d_1971@postgrespro.ru", "phone": "+70553197876"}
0005433103343	05ACED	2981 551085	ANASTASIYA FEDOROVA	{"email": "a.fedorova02121963@postgrespro.ru", "phone": "+70086433294"}
0005433103344	05ACED	6955 775626	TATYANA KUZMINA	{"email": "tatyana.kuzmina_1976@postgrespro.ru", "phone": "+70419546973"}
0005433103345	FF14B5	3935 163390	LYUBOV KAZAKOVA	{"email": "lyubov_kazakova-1973@postgrespro.ru", "phone": "+70833828301"}
0005433103346	FF14B5	4062 596124	PETR FROLOV	{"phone": "+70608521059"}
0005433103347	69B126	9512 413194	EVGENIY ZAKHAROV	{"phone": "+70122595203"}
0005433103348	3A14B5	3050 989814	VALENTINA TIKHONOVA	{"email": "v-tikhonova-111969@postgrespro.ru", "phone": "+70718579560"}
0005433103349	03DD16	9733 047743	EVGENIY DENISOV	{"email": "denisov-e-1975@postgrespro.ru", "phone": "+70214832829"}
0005433103350	A61E2C	5709 950973	SVETLANA ZAYCEVA	{"email": "zayceva.s.16021966@postgrespro.ru", "phone": "+70989908427"}
0005433103351	6947D6	0412 667156	DMITRIY IVANOV	{"email": "d_ivanov_29031980@postgrespro.ru", "phone": "+70055708762"}
0005433103352	883D12	6783 592111	NIKOLAY SMIRNOV	{"email": "smirnov_nikolay.1965@postgrespro.ru", "phone": "+70466476281"}
0005433103353	148379	5742 669298	ILMIRA PETROVA	{"phone": "+70860517230"}
0005433103354	148379	9672 533566	LARISA PAVLOVA	{"email": "pavlova_larisa-1974@postgrespro.ru", "phone": "+70028859623"}
0005433103355	148379	7196 113333	VALENTINA VASILEVA	{"email": "valentina_vasileva13101980@postgrespro.ru", "phone": "+70817416294"}
0005433103356	32F414	5875 804925	ANATOLIY MOROZOV	{"phone": "+70834166481"}
0005433103357	9C63F3	5066 231232	EVGENIY KOZLOV	{"email": "kozlov_evgeniy_061970@postgrespro.ru", "phone": "+70366512975"}
0005433103358	3706A7	0923 948446	NIKITA MOROZOV	{"email": "nikita_morozov-20081968@postgrespro.ru", "phone": "+70241895122"}
0005433103359	E96792	5842 235110	SEMEN KUZNECOV	{"email": "s-kuznecov.101972@postgrespro.ru", "phone": "+70724250000"}
0005433103360	D48295	5995 080557	TATYANA TIKHONOVA	{"email": "tikhonova.tatyana-27091964@postgrespro.ru", "phone": "+70982105062"}
0005433103361	881556	2290 969090	VERA SEMENOVA	{"phone": "+70380225902"}
0005433103362	881556	8604 513013	VIKTOR BORISOV	{"email": "v_borisov.07041977@postgrespro.ru", "phone": "+70226772475"}
0005433103363	100855	6984 672042	SVETLANA KUZNECOVA	{"phone": "+70220530733"}
0005433103364	6155CF	0492 368575	VALENTINA ERMAKOVA	{"email": "ermakova.v-23091967@postgrespro.ru", "phone": "+70626167690"}
0005433103365	6155CF	2077 360811	PAVEL MOROZOV	{"email": "morozov-pavel-1972@postgrespro.ru", "phone": "+70182891000"}
0005433103366	6155CF	7605 821838	MARINA GUSEVA	{"email": "marina.guseva_121966@postgrespro.ru", "phone": "+70713851506"}
0005433103367	FA53D4	6185 597827	ANTONINA ALEKSANDROVA	{"email": "aleksandrova.antonina051974@postgrespro.ru", "phone": "+70604256066"}
0005433103368	4FC3A2	4832 957064	ALEKSANDR ORLOV	{"phone": "+70196238815"}
0005433103369	7588DB	8398 403828	OKSANA VOLKOVA	{"email": "oksana-volkova-15011982@postgrespro.ru", "phone": "+70087510542"}
0005433103370	7588DB	2914 784785	KLAVDIYA AKIMOVA	{"phone": "+70162282806"}
0005433103371	AB2E53	3740 285398	LYUDMILA MEDVEDEVA	{"phone": "+70533312248"}
0005433103372	535BFD	6322 900128	NATALYA MIKHAYLOVA	{"phone": "+70983901085"}
0005433103373	463CE6	6264 317308	IGOR DMITRIEV	{"email": "i.dmitriev081963@postgrespro.ru", "phone": "+70024772534"}
0005433103374	2022FF	7020 896320	ALENA ILINA	{"email": "ailina_1980@postgrespro.ru", "phone": "+70629288495"}
0005433103375	2022FF	8433 073696	IRINA KISELEVA	{"email": "i-kiseleva.1960@postgrespro.ru", "phone": "+70447012755"}
0005433103376	5BC43A	6905 168713	NIKOLAY EGOROV	{"phone": "+70453520981"}
0005433103377	5BC43A	6926 101856	MAKSIM MARTYNOV	{"email": "martynov.maksim-10121978@postgrespro.ru", "phone": "+70734017191"}
0005433103378	7B3730	8732 549404	VALERIY MOROZOV	{"phone": "+70025763384"}
0005433103379	7B3730	4456 967412	MAKSIM MATVEEV	{"email": "matveevmaksim_30111959@postgrespro.ru", "phone": "+70289295753"}
0005433103380	5F6AD9	9589 449320	MIKHAIL IVANOV	{"phone": "+70807899393"}
0005433103381	D137B9	0263 545217	EVGENIY FEDOTOV	{"email": "efedotov091973@postgrespro.ru", "phone": "+70962064641"}
0005433103382	D137B9	8128 052466	NINA ALEKSANDROVA	{"email": "n-aleksandrova-1969@postgrespro.ru", "phone": "+70309930833"}
0005433103383	D46A8D	1448 823921	KONSTANTIN KUZNECOV	{"phone": "+70791098709"}
0005433103384	D46A8D	7760 772900	VIKTORIYA STEPANOVA	{"phone": "+70279797729"}
0005433103385	7A5006	9808 120286	OLGA KOVALEVA	{"email": "kovaleva_olga_30111965@postgrespro.ru", "phone": "+70886271707"}
0005433103386	7A5006	7035 912710	SERGEY SMIRNOV	{"phone": "+70435530472"}
0005433103387	50CA5D	0364 609326	KONSTANTIN IVANOV	{"phone": "+70171872324"}
0005433103388	1864D9	4872 800332	RENAT YAKOVLEV	{"email": "yakovlev.renat1970@postgrespro.ru", "phone": "+70137880399"}
0005433103389	1864D9	2470 069725	NIKOLAY RODIONOV	{"phone": "+70103763746"}
0005433103390	D3F0E3	4151 264313	NINA ZHUKOVA	{"phone": "+70651405458"}
0005433103391	D3F0E3	7751 773556	OLEG SAVELEV	{"email": "savelev-o_061976@postgrespro.ru", "phone": "+70446744973"}
0005433103392	8979EF	9867 388157	VLADIMIR PETROV	{"phone": "+70222065871"}
0005433103393	8979EF	7040 945403	NIKOLAY KRASNOV	{"email": "krasnov-nikolay1955@postgrespro.ru", "phone": "+70985157089"}
0005433103394	BEB753	9430 854544	VALERIYA BOGDANOVA	{"email": "bogdanova_valeriya1979@postgrespro.ru", "phone": "+70977898115"}
0005433103395	A6A013	3578 974076	PAVEL BELOV	{"phone": "+70581326951"}
0005433103396	A6A013	0715 689530	VIKTOR KUZNECOV	{"email": "vkuznecov-021974@postgrespro.ru", "phone": "+70516596953"}
0005433103397	167B54	4775 903574	IVAN ANDREEV	{"email": "ivan-andreev-081971@postgrespro.ru", "phone": "+70261982434"}
0005433103398	805BD7	4825 626094	KONSTANTIN ZAKHAROV	{"email": "zakharov-k01091969@postgrespro.ru", "phone": "+70556628433"}
0005433103399	805BD7	5598 850518	VALERIY MIRONOV	{"email": "mironov.valeriy.031972@postgrespro.ru", "phone": "+70376429551"}
0005433103400	1C6E48	7664 076479	ALEKSEY GUSEV	{"email": "a.gusev_051970@postgrespro.ru", "phone": "+70098208176"}
0005433103401	29FCA4	7837 448491	PAVEL KUDRYASHOV	{"email": "pavelkudryashov02021973@postgrespro.ru", "phone": "+70413248505"}
0005433103402	45DA2E	7880 652579	ALEKSANDR YAKOVLEV	{"email": "ayakovlev.27021975@postgrespro.ru", "phone": "+70877455441"}
0005433103403	45DA2E	0187 700482	ALEKSEY RODIONOV	{"email": "aleksey_rodionov-121963@postgrespro.ru", "phone": "+70446438283"}
0005433103404	5EEFB8	6379 188877	NATALYA IVANOVA	{"phone": "+70225827317"}
0005433103405	5EEFB8	9682 095092	ARTEM ABRAMOV	{"phone": "+70998318789"}
0005433103406	D3DC33	8746 517347	VYACHESLAV ZHURAVLEV	{"email": "v_zhuravlev.1967@postgrespro.ru", "phone": "+70156899556"}
0005433103407	C2739F	3546 232582	NATALYA ABRAMOVA	{"phone": "+70352300597"}
0005433103408	C2739F	4362 559200	MARIYA AFANASEVA	{"email": "afanaseva.mariya-1974@postgrespro.ru", "phone": "+70582068531"}
0005433103409	6E2CF2	9492 053348	ANASTASIYA SEMENOVA	{"phone": "+70795717873"}
0005433103410	80172F	8651 372056	DMITRIY FROLOV	{"email": "d_frolov_1974@postgrespro.ru", "phone": "+70062611929"}
0005433103411	368131	5114 575617	NATALYA NOVIKOVA	{"phone": "+70460242419"}
0005433103412	44497C	8270 968639	ALEKSANDRA GORBUNOVA	{"phone": "+70375479662"}
0005433103413	44497C	3609 362615	MARINA TIKHONOVA	{"phone": "+70295177550"}
0005433103414	608B6B	1394 172718	ALEKSANDR SERGEEV	{"phone": "+70724664434"}
0005433103415	CC15F5	5353 783827	ELENA MELNIKOVA	{"phone": "+70607568007"}
0005433103416	CC15F5	8900 211285	ALEKSANDR ZAYCEV	{"email": "a-zaycev1968@postgrespro.ru", "phone": "+70063369320"}
0005433103417	CC15F5	6177 800487	RODION YAKOVLEV	{"phone": "+70745261554"}
0005433103418	20BA21	4131 986254	SVETLANA NESTEROVA	{"phone": "+70432894000"}
0005433103419	95F330	8076 129015	SERGEY ABRAMOV	{"phone": "+70816545842"}
0005433103420	23602B	5522 484524	ALEKSANDRA ERMAKOVA	{"phone": "+70860124381"}
0005433103421	E2FA56	6414 943506	ANASTASIYA SERGEEVA	{"email": "sergeeva-a.101978@postgrespro.ru", "phone": "+70678133325"}
0005433103422	561557	3405 522757	ANASTASIYA OVCHINNIKOVA	{"phone": "+70498596813"}
0005433103423	81ABF2	3039 268689	ZINAIDA FADEEVA	{"email": "fadeeva-zinaida-17091975@postgrespro.ru", "phone": "+70873805259"}
0005433103424	4D7BD1	5929 109752	NATALYA BOGDANOVA	{"email": "natalyabogdanova-1981@postgrespro.ru", "phone": "+70032848026"}
0005433103425	677189	5387 130360	YURIY ABRAMOV	{"email": "abramov.yuriy_1983@postgrespro.ru", "phone": "+70347662481"}
0005433103426	8F17D1	8928 769188	ELENA ALEKSEEVA	{"email": "elena-alekseeva081961@postgrespro.ru", "phone": "+70179205142"}
0005433103427	8F17D1	7329 311677	SEMEN NIKITIN	{"email": "nikitin-s-021966@postgrespro.ru", "phone": "+70585997986"}
0005433103428	0D14B2	4798 098209	ELENA KUZMINA	{"email": "kuzminaelena091968@postgrespro.ru", "phone": "+70067740908"}
0005433103429	8D28DB	5544 451025	MARIYA KUZNECOVA	{"email": "mariya-kuznecova-1972@postgrespro.ru", "phone": "+70711910190"}
0005433103430	65B34B	0297 162895	EVGENIY KONOVALOV	{"email": "konovalove.1983@postgrespro.ru", "phone": "+70686169933"}
0005433103431	665B8B	4853 369816	VASILIY MAKSIMOV	{"phone": "+70819900563"}
0005433103432	665B8B	4850 759911	KLAVDIYA POTAPOVA	{"phone": "+70785298977"}
0005433103433	2567F7	4704 705102	VLADIMIR NIKITIN	{"email": "vladimir.nikitin.06011964@postgrespro.ru", "phone": "+70412485573"}
0005433103434	973532	4930 914181	GALINA DAVYDOVA	{"email": "davydova-galina-1981@postgrespro.ru", "phone": "+70566107182"}
0005433103435	F6C90E	8485 980850	GLEB NIKITIN	{"email": "glebnikitin25051971@postgrespro.ru", "phone": "+70514549257"}
0005433103436	F6C90E	7577 955053	IGOR VASILEV	{"phone": "+70218067495"}
0005433103437	F6C90E	6155 928833	ELENA CHERNOVA	{"email": "elenachernova_1970@postgrespro.ru", "phone": "+70328255799"}
0005433103438	F6C90E	6862 212610	MIKHAIL OSIPOV	{"email": "osipov-mikhail111987@postgrespro.ru", "phone": "+70602821520"}
0005433103439	696EC9	4937 795020	IGOR BORISOV	{"email": "borisov.igor.071973@postgrespro.ru", "phone": "+70176412822"}
0005433103440	9E8C02	6159 441853	VALENTINA ABRAMOVA	{"email": "v-abramova-1974@postgrespro.ru", "phone": "+70753588438"}
0005433103441	D54CDF	3811 168445	TATYANA MOROZOVA	{"email": "tatyana-morozova.101968@postgrespro.ru", "phone": "+70671709660"}
0005433103442	D54CDF	1880 444900	ANNA IVANOVA	{"email": "ivanova_anna-101970@postgrespro.ru", "phone": "+70471075421"}
0005433103443	06BCC7	3021 552204	IRINA KOROLEVA	{"email": "irina_koroleva_091964@postgrespro.ru", "phone": "+70556199762"}
0005433103444	016C51	8474 248471	SVETLANA MOROZOVA	{"phone": "+70061592130"}
0005433103445	050DEA	2504 404853	NADEZHDA MEDVEDEVA	{"email": "medvedeva_n_1981@postgrespro.ru", "phone": "+70019296023"}
0005433103446	050DEA	7345 015823	DINA BELOVA	{"phone": "+70936887938"}
0005433103447	BE2EC0	3755 446597	IGOR ILIN	{"email": "ilini.041980@postgrespro.ru", "phone": "+70132768782"}
0005433103448	BE2EC0	9156 548745	MIKHAIL ANTONOV	{"phone": "+70340952639"}
0005433103449	12EF47	5725 727012	ROMAN SOKOLOV	{"phone": "+70196553642"}
0005433103450	C49E66	8358 648402	TATYANA POPOVA	{"email": "popovat-1977@postgrespro.ru", "phone": "+70776305690"}
0005433103451	C49E66	2982 344217	ANNA POLYAKOVA	{"email": "anna.polyakova.1972@postgrespro.ru", "phone": "+70843501359"}
0005433103452	C49E66	3511 967540	SERGEY MAKAROV	{"phone": "+70661955687"}
0005433103453	937AC0	7293 795495	VLADIMIR TARASOV	{"phone": "+70250370870"}
0005433103454	937AC0	0614 414569	NIKOLAY ABRAMOV	{"email": "n_abramov-1978@postgrespro.ru", "phone": "+70568726799"}
0005433103455	937AC0	2139 958506	NATALYA KUZNECOVA	{"phone": "+70921891278"}
0005433103456	2AE6BA	9238 245308	RASHID GUSEV	{"phone": "+70975716100"}
0005433103457	B7E39C	7172 720060	EVGENIY FEDOTOV	{"email": "fedotove29031973@postgrespro.ru", "phone": "+70156393255"}
0005433103458	06815F	0365 602272	SERGEY IVANOV	{"email": "sergeyivanov.04041966@postgrespro.ru", "phone": "+70733822798"}
0005433103459	A7276D	2146 876547	IRINA CHERNOVA	{"email": "chernova-i-071972@postgrespro.ru", "phone": "+70158211718"}
0005433103460	5FF42B	9299 341296	ALISA DENISOVA	{"email": "alisadenisova26051964@postgrespro.ru", "phone": "+70307820808"}
0005433103461	C0F113	9117 713092	ALEKSANDR ORLOV	{"email": "a_orlov101975@postgrespro.ru", "phone": "+70490781542"}
0005433103462	C0F113	9971 872309	MARINA LEBEDEVA	{"phone": "+70946469538"}
0005433103463	20EFEE	0515 043966	EVGENIY VLASOV	{"phone": "+70954553204"}
0005433103464	11B705	6911 470258	EKATERINA ROMANOVA	{"email": "romanova_e-031972@postgrespro.ru", "phone": "+70301653157"}
0005433103465	11B705	8428 541627	MARIYA MATVEEVA	{"email": "matveeva_mariya.1969@postgrespro.ru", "phone": "+70401086721"}
0005433103466	11B705	5847 190746	YURIY ANTONOV	{"phone": "+70497760475"}
0005433103467	6C90ED	5731 678126	NIKOLAY POPOV	{"phone": "+70610216439"}
0005433103468	6C90ED	2218 882236	ALEKSEY FROLOV	{"email": "a-frolov_1971@postgrespro.ru", "phone": "+70770247820"}
0005433103469	386BFD	6665 368453	RAISA MAKSIMOVA	{"email": "raisa_maksimova_1972@postgrespro.ru", "phone": "+70433444919"}
0005433103470	7A16B6	7793 598299	OLEG NIKOLAEV	{"phone": "+70371090972"}
0005433103471	6D0D3F	0662 989331	LYUBOV VASILEVA	{"email": "lyubov.vasileva-011974@postgrespro.ru", "phone": "+70545402825"}
0005433103472	C8C50C	3670 153744	TATYANA KALININA	{"email": "tatyanakalinina-27011965@postgrespro.ru", "phone": "+70397365937"}
0005433103473	0BB9DD	2928 173572	LYUDMILA SMIRNOVA	{"email": "smirnoval28011969@postgrespro.ru", "phone": "+70100965275"}
0005433103474	927ADE	6690 803362	MARINA POPOVA	{"phone": "+70437391513"}
0005433103475	927ADE	1497 055910	VIKTOR NIKOLAEV	{"phone": "+70817478120"}
0005433103476	9C2CDA	9211 221598	RAISA FOMINA	{"email": "raisa_fomina_05121958@postgrespro.ru", "phone": "+70474651096"}
0005433103477	F36C3D	8035 649026	OLGA IVANOVA	{"email": "olga-ivanova081974@postgrespro.ru", "phone": "+70905760936"}
0005433103478	F36C3D	1883 232230	PAVEL GUSEV	{"email": "gusev.pavel031955@postgrespro.ru", "phone": "+70043690569"}
0005433103479	F36C3D	1993 986461	YULIYA NOVIKOVA	{"phone": "+70182847235"}
0005433103480	54E239	0827 034253	LARISA LOGINOVA	{"email": "larisaloginova-1979@postgrespro.ru", "phone": "+70665085985"}
0005433103481	1E152B	4870 421422	VITALIY KRASNOV	{"phone": "+70138571483"}
0005433103482	1E152B	4560 911854	IGOR GRIGOREV	{"phone": "+70531880727"}
0005433103483	F3C5D3	0388 816861	ANDREY NIKITIN	{"email": "nikitin_andrey-071970@postgrespro.ru", "phone": "+70628946876"}
0005433103484	7829D6	6661 718198	ANASTASIYA SAVELEVA	{"phone": "+70483858587"}
0005433103485	7829D6	8167 145553	IVAN SAVELEV	{"phone": "+70250211841"}
0005433103486	14AC36	5858 152088	ALEKSANDR GERASIMOV	{"phone": "+70443806561"}
0005433103487	645DD8	4807 439254	NATALYA ANDREEVA	{"phone": "+70514718802"}
0005433103488	645DD8	7031 608238	IGOR SMIRNOV	{"phone": "+70795770046"}
0005433103489	2F3FC2	5126 625990	DMITRIY VLASOV	{"phone": "+70040853890"}
0005433103490	2F3FC2	3626 760486	VALERIY PETROV	{"phone": "+70278916351"}
0005433103491	2F3FC2	3186 988079	PAVEL NIKOLAEV	{"email": "nikolaev-p.18041972@postgrespro.ru", "phone": "+70280767135"}
0005433103492	37FDC3	6326 230837	LYUDMILA DENISOVA	{"phone": "+70718123381"}
0005433103493	4F32E4	6865 011188	ELENA ISAEVA	{"phone": "+70405747666"}
0005433103494	67CAC5	0354 548390	VLADIMIR GORBUNOV	{"email": "gorbunov.v.121983@postgrespro.ru", "phone": "+70627878845"}
0005433103495	3829F7	3574 253913	VLADIMIR VASILEV	{"email": "vasilev_vladimir_23031964@postgrespro.ru", "phone": "+70172948280"}
0005433103496	3829F7	2777 289089	EVGENIY SOKOLOV	{"email": "sokolov_e_1971@postgrespro.ru", "phone": "+70251738816"}
0005433103497	213B0C	7432 437914	EKATERINA ILINA	{"email": "ekaterina-ilina.041967@postgrespro.ru", "phone": "+70086754575"}
0005433103498	213B0C	7769 743730	DMITRIY SOKOLOV	{"phone": "+70028921856"}
0005433103499	E3AFAD	0800 503021	OLESYA ZAYCEVA	{"phone": "+70053436218"}
0005433103500	E3AFAD	8500 309859	ALEKSEY ISAEV	{"phone": "+70922763334"}
0005433103501	F97A78	9410 040316	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev-26061976@postgrespro.ru", "phone": "+70260144457"}
0005433103502	DD6517	9619 272342	VIKTOR VOLKOV	{"email": "volkov.v091967@postgrespro.ru", "phone": "+70412479235"}
0005433103503	8D5CB0	8292 893381	TATYANA KOZLOVA	{"email": "kozlova.tatyana.18121980@postgrespro.ru", "phone": "+70139349619"}
0005433103504	8D5CB0	6733 810314	VLADIMIR OSIPOV	{"phone": "+70877635552"}
0005433103505	6F94ED	2619 258689	VERA FILATOVA	{"email": "v_filatova-04061973@postgrespro.ru", "phone": "+70320842899"}
0005433103506	4E3B92	6038 123745	YULIYA DANILOVA	{"phone": "+70352726415"}
0005433103507	06B806	4169 822536	DARYA ANTONOVA	{"email": "d_antonova-021971@postgrespro.ru", "phone": "+70665160447"}
0005433103508	23E95C	2596 225637	MARFA POPOVA	{"email": "marfa_popova-1978@postgrespro.ru", "phone": "+70895046657"}
0005433103509	891450	7895 042807	OLGA ISAEVA	{"email": "isaeva_o1965@postgrespro.ru", "phone": "+70625229099"}
0005433103510	CE0C53	3988 125096	KIRILL PETROV	{"email": "petrov_kirill_19111964@postgrespro.ru", "phone": "+70860252309"}
0005433103511	762DD7	2986 765732	NIKOLAY KOZLOV	{"phone": "+70972824969"}
0005433103512	614D19	5507 718913	SVETLANA STEPANOVA	{"email": "s_stepanova121985@postgrespro.ru", "phone": "+70764598729"}
0005433103513	A9685F	5317 702278	SVETLANA ALEKSEEVA	{"email": "s-alekseeva-1976@postgrespro.ru", "phone": "+70992349542"}
0005433103514	1FFFD7	4023 702998	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila.09021965@postgrespro.ru", "phone": "+70153281151"}
0005433103515	1FFFD7	3560 313576	VALENTINA SERGEEVA	{"email": "sergeevavalentina-1972@postgrespro.ru", "phone": "+70422770091"}
0005433103516	E0A4AD	8233 922089	VALERIY BONDARENKO	{"email": "v.bondarenko_21041979@postgrespro.ru", "phone": "+70877859008"}
0005433103517	E0A4AD	8071 703746	NIKITA SOKOLOV	{"email": "sokolov-nikita.1976@postgrespro.ru", "phone": "+70115581330"}
0005433103518	84B284	6259 287376	ANTON MOROZOV	{"phone": "+70509831519"}
0005433103519	44B067	8240 135373	FILIPP FEDOROV	{"email": "f.fedorov_28071973@postgrespro.ru", "phone": "+70648569134"}
0005433103520	44B067	2451 051723	ALEKSANDR BARANOV	{"email": "aleksandrbaranov.071968@postgrespro.ru", "phone": "+70346289152"}
0005433103887	7D9060	7836 185741	MAKSIM ILIN	{"phone": "+70876708319"}
0005433103521	D1CBFD	9721 376654	NIKOLAY BONDARENKO	{"email": "n_bondarenko_051971@postgrespro.ru", "phone": "+70553190056"}
0005433103522	D1CBFD	7413 110117	PETR ZHUKOV	{"phone": "+70865012411"}
0005433103523	719B82	6218 018247	VERA YAKOVLEVA	{"email": "yakovlevav071969@postgrespro.ru", "phone": "+70084034280"}
0005433103524	719B82	4883 219576	DENIS GORBUNOV	{"phone": "+70438851234"}
0005433103525	455EAC	5330 323275	OLEG SAVELEV	{"phone": "+70092173684"}
0005433103526	3097B2	9999 397524	NIKOLAY YAKOVLEV	{"email": "yakovlev.nikolay-011967@postgrespro.ru", "phone": "+70994131758"}
0005433103527	3F1BFE	4970 592592	NADEZHDA TIMOFEEVA	{"phone": "+70399657494"}
0005433103528	3F1BFE	8560 221716	LARISA NESTEROVA	{"phone": "+70791455467"}
0005433103529	9F94AF	8229 294950	ANATOLIY ISAEV	{"email": "isaev.anatoliy30111970@postgrespro.ru", "phone": "+70791716685"}
0005433103530	8C864B	3463 514434	NADEZHDA DANILOVA	{"phone": "+70131580477"}
0005433103531	28D6C0	7504 216278	VALERIY ZAYCEV	{"email": "v.zaycev111978@postgrespro.ru", "phone": "+70676516663"}
0005433103532	28D6C0	3018 792197	ANNA BOGDANOVA	{"phone": "+70637382518"}
0005433103533	28D6C0	4024 602005	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr-21081979@postgrespro.ru", "phone": "+70386449615"}
0005433103534	FF668B	1311 164723	DMITRIY FEDOROV	{"phone": "+70997903838"}
0005433103535	FF668B	4062 105671	TATYANA MEDVEDEVA	{"email": "medvedeva.tatyana1972@postgrespro.ru", "phone": "+70395649184"}
0005433103536	8D965C	5716 519467	VLADIMIR VASILEV	{"email": "vladimir_vasilev081975@postgrespro.ru", "phone": "+70611506056"}
0005433103537	2154B6	7048 835510	KSENIYA LUKYANOVA	{"email": "kseniya-lukyanova-1977@postgrespro.ru", "phone": "+70425773461"}
0005433103538	FC0610	3031 556663	TATYANA TIMOFEEVA	{"email": "tatyana_timofeeva.1981@postgrespro.ru", "phone": "+70985907054"}
0005433103539	FC0610	7161 002159	VALERIY PETROV	{"phone": "+70310888742"}
0005433103540	C7D201	4163 328263	ALEKSANDR NAZAROV	{"phone": "+70171020180"}
0005433103541	143ACE	0475 838971	ANATOLIY NIKOLAEV	{"email": "anatoliynikolaev.1984@postgrespro.ru", "phone": "+70274439239"}
0005433103542	EDA6B9	6702 523036	VIKTOR MOROZOV	{"email": "morozovv-16011972@postgrespro.ru", "phone": "+70073310298"}
0005433103543	EDA6B9	3325 853838	ALENA MAKAROVA	{"phone": "+70804305900"}
0005433103544	A03C81	7668 533754	VLADIMIR GAVRILOV	{"phone": "+70826523052"}
0005433103545	4079FE	8356 139959	MARIYA IVANOVA	{"phone": "+70194397343"}
0005433103546	4079FE	8639 757642	LARISA KOMAROVA	{"email": "komarova-l08061974@postgrespro.ru", "phone": "+70485599215"}
0005433103547	676A26	5147 995446	SVETLANA MATVEEVA	{"phone": "+70747920772"}
0005433103548	8E5921	5326 800136	IGOR ILIN	{"phone": "+70746654734"}
0005433103549	196722	6538 706797	ANASTASIYA YUDINA	{"email": "yudina-anastasiya_011972@postgrespro.ru", "phone": "+70036233145"}
0005433103550	196722	9483 353668	ELIZAVETA ANDREEVA	{"email": "e-andreeva.06021967@postgrespro.ru", "phone": "+70516659903"}
0005433103551	43F5AA	7439 954697	VITALIY SOLOVEV	{"phone": "+70388843562"}
0005433103552	5C3306	1389 442412	ALEKSEY IVANOV	{"phone": "+70688268898"}
0005433103553	9FD509	4776 690507	VLADIMIR BORISOV	{"phone": "+70794559432"}
0005433103554	A67D1F	1699 230292	ALEKSANDR EGOROV	{"phone": "+70928864510"}
0005433103555	B49AE3	1382 321498	SVETLANA ABRAMOVA	{"phone": "+70930474169"}
0005433103556	B49AE3	4097 886295	LARISA KULIKOVA	{"email": "larisakulikova.1962@postgrespro.ru", "phone": "+70291048978"}
0005433103557	A883C1	9993 542160	ELENA ORLOVA	{"email": "e_orlova_021971@postgrespro.ru", "phone": "+70203808525"}
0005433103558	45AB00	6657 816956	SOFYA MELNIKOVA	{"phone": "+70403866314"}
0005433103559	2BEA5B	9437 929452	VERONIKA NAZAROVA	{"phone": "+70911641450"}
0005433103560	49202F	0779 977276	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov_041974@postgrespro.ru", "phone": "+70363822287"}
0005433103561	49202F	9523 729054	ANDREY NAUMOV	{"email": "naumov_andrey1975@postgrespro.ru", "phone": "+70797532881"}
0005433103562	266881	2042 871538	VALERIY EGOROV	{"phone": "+70883835066"}
0005433103563	266881	9585 597051	SERGEY MELNIKOV	{"email": "melnikov.sergey1964@postgrespro.ru", "phone": "+70713220658"}
0005433103564	99D35C	0971 055700	EVGENIY VOLKOV	{"phone": "+70264495185"}
0005433103565	99D35C	2441 945504	TATYANA KRASNOVA	{"email": "tatyanakrasnova_1984@postgrespro.ru", "phone": "+70479170904"}
0005433103566	7AD79B	3382 445703	VLADIMIR FEDOROV	{"email": "fedorovvladimir.13021971@postgrespro.ru", "phone": "+70907419914"}
0005433103567	A804D8	5101 700278	TAMARA SOROKINA	{"phone": "+70457461932"}
0005433103568	576D15	8859 257772	VALERIY NIKOLAEV	{"phone": "+70469894695"}
0005433103569	576D15	3122 495595	OLGA SOKOLOVA	{"phone": "+70768972789"}
0005433103570	320F32	9285 518859	PAVEL NOVIKOV	{"phone": "+70252761381"}
0005433103571	567326	6511 756978	TAMARA NAUMOVA	{"email": "tamara_naumova1981@postgrespro.ru", "phone": "+70590227063"}
0005433103572	AE2DFF	4047 397327	IGOR ZHURAVLEV	{"email": "igor.zhuravlev1975@postgrespro.ru", "phone": "+70841636062"}
0005433103573	AE2DFF	7240 231302	OKSANA BORISOVA	{"email": "oksana.borisova_06111974@postgrespro.ru", "phone": "+70588315919"}
0005433103574	1352B8	7444 082858	VALERIY ROMANOV	{"phone": "+70672214160"}
0005433103575	1352B8	8157 868283	ANNA KULIKOVA	{"email": "anna_kulikova.051986@postgrespro.ru", "phone": "+70434127241"}
0005433103576	21AA5F	2173 067072	DANIYA KUZNECOVA	{"email": "d.kuznecova.07031977@postgrespro.ru", "phone": "+70516462398"}
0005433103577	277ED9	4361 612052	VIKTOR SERGEEV	{"email": "sergeev_viktor-11041973@postgrespro.ru", "phone": "+70963190782"}
0005433103578	241D7A	0909 065615	EVGENIY VASILEV	{"phone": "+70522942640"}
0005433103579	241D7A	0884 228715	ALEKSEY STEPANOV	{"email": "a_stepanov_051971@postgrespro.ru", "phone": "+70610492981"}
0005433103580	7A3CE2	2642 829786	YURIY ANDREEV	{"email": "yuriy.andreev-031966@postgrespro.ru", "phone": "+70533297610"}
0005433103581	7A3CE2	9281 844076	VALENTIN MOROZOV	{"email": "v-morozov.02031967@postgrespro.ru", "phone": "+70951995111"}
0005433103582	7A3CE2	1974 337458	RAISA VASILEVA	{"email": "r.vasileva_031979@postgrespro.ru", "phone": "+70077364530"}
0005433103583	606D70	7618 808399	MARIYA MELNIKOVA	{"phone": "+70885652614"}
0005433103584	606D70	1692 863904	GALINA KOZLOVA	{"phone": "+70538587593"}
0005433103585	606D70	5781 296444	ALEKSANDR PETROV	{"email": "a_petrov1968@postgrespro.ru", "phone": "+70840398010"}
0005433103586	C19D7F	9077 057995	ALEKSANDR DAVYDOV	{"phone": "+70197497913"}
0005433103587	C19D7F	2762 043054	ALEKSEY POPOV	{"phone": "+70199832542"}
0005433103588	C19D7F	1953 829599	GLEB GORBUNOV	{"phone": "+70676639995"}
0005433103589	A870BE	8848 593841	ELENA POTAPOVA	{"email": "potapovae.23101980@postgrespro.ru", "phone": "+70478298746"}
0005433103590	DDC765	6523 595980	ALEKSANDR MELNIKOV	{"phone": "+70670921841"}
0005433103591	D8DDCD	2058 414249	SABINA ORLOVA	{"email": "orlovasabina-27011959@postgrespro.ru", "phone": "+70304367133"}
0005433103592	61A3FB	4150 816651	ALEKSANDR ANDREEV	{"phone": "+70724382391"}
0005433103593	7D2DD4	6639 088230	NATALYA FILIPPOVA	{"phone": "+70672071678"}
0005433103594	1F6F02	7492 439385	VIKTOR GUSEV	{"phone": "+70643190191"}
0005433103595	1F6F02	6046 629393	ANTON MIKHAYLOV	{"phone": "+70672494869"}
0005433103596	0E4256	3589 563815	DARYA TIMOFEEVA	{"phone": "+70899286383"}
0005433103597	BE2B78	1038 433349	MARGARITA KOZLOVA	{"phone": "+70687468357"}
0005433103598	BE2B78	5623 562868	YANA MATVEEVA	{"phone": "+70957774074"}
0005433103599	E4FA57	6279 298768	PAVEL MOROZOV	{"email": "morozovpavel1980@postgrespro.ru", "phone": "+70931826366"}
0005433103600	E73F56	3203 181194	ALEKSANDR ISAEV	{"phone": "+70811384448"}
0005433103601	9F994E	1469 211042	RAISA BORISOVA	{"phone": "+70420366063"}
0005433103602	9F994E	2273 258465	YURIY NAZAROV	{"phone": "+70241190190"}
0005433103603	A826BC	3452 216564	VALENTINA ABRAMOVA	{"phone": "+70028782256"}
0005433103604	473811	0745 047993	ALEKSANDR ROMANOV	{"phone": "+70571300791"}
0005433103605	81481A	2360 659034	ANDREY FILIPPOV	{"phone": "+70916347951"}
0005433103606	C3C189	8336 351249	ALEKSEY KUZNECOV	{"phone": "+70007121392"}
0005433103607	A00A98	2286 829029	KRISTINA AKIMOVA	{"phone": "+70757154571"}
0005433103608	B5A62B	3684 501481	DMITRIY ANDREEV	{"email": "dmitriy_andreev.051980@postgrespro.ru", "phone": "+70265334736"}
0005433103609	3A19BB	7539 207375	KIRILL FEDOROV	{"phone": "+70103187610"}
0005433103610	3A19BB	8599 787970	VITALIY VOROBEV	{"phone": "+70051633204"}
0005433103611	3A19BB	7436 231196	ANDREY ZHUKOV	{"phone": "+70739950669"}
0005433103612	040E52	8950 923915	VALERIY ROMANOV	{"email": "valeriyromanov121969@postgrespro.ru", "phone": "+70164799555"}
0005433103613	040E52	2071 980671	GENNADIY FEDOROV	{"email": "g.fedorov_1973@postgrespro.ru", "phone": "+70861485517"}
0005433103614	D8A5A9	2133 644494	KLAVDIYA VLASOVA	{"phone": "+70950255737"}
0005433103615	CD4402	2406 984636	NATALYA KONDRATEVA	{"phone": "+70365017888"}
0005433103616	498329	9557 181951	ALEKSANDRA GUSEVA	{"phone": "+70073878070"}
0005433103617	110718	1847 028680	BORIS ROMANOV	{"phone": "+70260920073"}
0005433103618	36B8B2	5124 618032	MIKHAIL ZAYCEV	{"email": "mikhail.zaycev_021969@postgrespro.ru", "phone": "+70246806521"}
0005433103619	E9AFD7	4939 502991	IRINA KOVALEVA	{"email": "i_kovaleva.30041967@postgrespro.ru", "phone": "+70887452884"}
0005433103620	581AA7	7012 471827	VLADIMIR IVANOV	{"email": "ivanov_v_08111967@postgrespro.ru", "phone": "+70508650001"}
0005433103621	F218DC	5487 898360	MAKSIM CHERNOV	{"email": "chernov_maksim_1969@postgrespro.ru", "phone": "+70131997656"}
0005433103622	F218DC	2547 830550	LYUDMILA GUSEVA	{"email": "lyudmila-guseva1982@postgrespro.ru", "phone": "+70120504102"}
0005433103623	19B2CB	5678 491558	ANASTASIYA KISELEVA	{"phone": "+70945506219"}
0005433103624	19B2CB	3719 919822	VALENTINA VOLKOVA	{"email": "volkovav-031985@postgrespro.ru", "phone": "+70783942547"}
0005433103625	19B2CB	8275 893520	VALENTINA ALEKSANDROVA	{"phone": "+70403059645"}
0005433103626	4D095E	3399 602126	DENIS IVANOV	{"email": "ivanov_denis.031973@postgrespro.ru", "phone": "+70686551218"}
0005433103627	51432B	3683 492903	IRINA OSIPOVA	{"email": "osipovairina1980@postgrespro.ru", "phone": "+70039996792"}
0005433103628	54A276	9023 287017	ALEKSEY GAVRILOV	{"phone": "+70943930200"}
0005433103629	54A276	1036 218043	LEONID SOROKIN	{"phone": "+70171961384"}
0005433103630	C9C991	6395 672233	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev-1968@postgrespro.ru", "phone": "+70615768480"}
0005433103631	C9C991	0297 233471	VLADISLAV STEPANOV	{"email": "v_stepanov28051982@postgrespro.ru", "phone": "+70586684839"}
0005433103632	C9C991	7459 264898	NIKOLAY ISAEV	{"email": "n.isaev-1983@postgrespro.ru", "phone": "+70622791312"}
0005433103633	03EC95	0508 659464	ALLA NIKOLAEVA	{"email": "nikolaeva-alla_1985@postgrespro.ru", "phone": "+70901248521"}
0005433103634	6F132E	8615 324614	SVETLANA SOROKINA	{"email": "s-sorokina.1962@postgrespro.ru", "phone": "+70374365861"}
0005433103635	104B86	3281 501098	VYACHESLAV GERASIMOV	{"phone": "+70452084091"}
0005433103636	851F88	5027 621371	ELENA NIKOLAEVA	{"email": "elena.nikolaeva-10091970@postgrespro.ru", "phone": "+70020028020"}
0005433103637	9B219B	5506 003035	SERGEY VOROBEV	{"email": "sergey.vorobev_1958@postgrespro.ru", "phone": "+70795002619"}
0005433103638	A7F295	1139 396927	NADEZHDA MIRONOVA	{"phone": "+70029260982"}
0005433103639	A7F295	4297 429461	GALINA MELNIKOVA	{"email": "galinamelnikova_1975@postgrespro.ru", "phone": "+70183256943"}
0005433103640	AD388B	5144 740812	ANTONINA MIRONOVA	{"phone": "+70817070061"}
0005433103641	AD388B	0011 242358	RUSTAM SERGEEV	{"phone": "+70813776539"}
0005433103642	71E35A	3277 871427	SERGEY IVANOV	{"phone": "+70091439608"}
0005433103643	71E35A	8183 632951	VERA EFIMOVA	{"phone": "+70818113570"}
0005433103644	BD4414	4803 304302	DANIL RODIONOV	{"email": "rodionov_danil.1964@postgrespro.ru", "phone": "+70308637117"}
0005433103645	BD4414	7181 917981	GRIGORIY YAKOVLEV	{"email": "yakovlev.grigoriy_021972@postgrespro.ru", "phone": "+70841868316"}
0005433103646	B14A95	5914 181573	NATALYA VLASOVA	{"email": "nvlasova_20031968@postgrespro.ru", "phone": "+70072656185"}
0005433103647	2E3250	3342 557813	POLINA NAUMOVA	{"phone": "+70839882711"}
0005433103648	352CE9	3236 015359	ALEKSANDR FILIPPOV	{"phone": "+70806473953"}
0005433103649	B15092	7825 811376	NIKITA ABRAMOV	{"phone": "+70940292976"}
0005433103650	B15092	5177 450732	NURLAN ZAYCEV	{"email": "zaycev_nurlan041959@postgrespro.ru", "phone": "+70118408401"}
0005433103651	65CDBF	9763 526952	ALENA MAKAROVA	{"phone": "+70827602094"}
0005433103652	65CDBF	6154 196700	ELENA ALEKSEEVA	{"email": "e.alekseeva.031974@postgrespro.ru", "phone": "+70668645471"}
0005433103653	4E0284	3159 960517	TATYANA KOLESNIKOVA	{"phone": "+70073602607"}
0005433103654	4E0284	9259 831203	EVGENIYA KALININA	{"phone": "+70214758408"}
0005433103655	503C2A	7578 192582	NATALYA PETROVA	{"phone": "+70052033553"}
0005433103656	A98311	4330 932376	ALEKSANDRA OSIPOVA	{"email": "osipovaa_03071981@postgrespro.ru", "phone": "+70745814198"}
0005433103657	B921DF	0503 797203	IRINA SOKOLOVA	{"email": "isokolova-1979@postgrespro.ru", "phone": "+70454432829"}
0005433103658	39EB8B	8961 314462	ELENA KUZNECOVA	{"phone": "+70653471029"}
0005433103659	39EB8B	3904 648848	YULIYA MOROZOVA	{"email": "yuliya_morozova11111969@postgrespro.ru", "phone": "+70046971400"}
0005433103660	A5598B	5241 249145	OLGA GERASIMOVA	{"email": "gerasimova.olga-031962@postgrespro.ru", "phone": "+70172886619"}
0005433103661	504689	0084 359331	ANNA MATVEEVA	{"phone": "+70965845203"}
0005433103662	504689	7083 948861	RUSLAN VOROBEV	{"phone": "+70589178750"}
0005433103663	54FAE1	0730 336901	TAMARA SEMENOVA	{"email": "tamara_semenova.02081981@postgrespro.ru", "phone": "+70404981770"}
0005433103664	54FAE1	9480 852186	DENIS MIRONOV	{"email": "denis_mironov_1971@postgrespro.ru", "phone": "+70934923153"}
0005433103665	6AAE97	1671 806574	VLADIMIR SMIRNOV	{"phone": "+70731822568"}
0005433103666	6AAE97	0463 643574	MARIYA ALEKSEEVA	{"email": "mariya-alekseeva_061977@postgrespro.ru", "phone": "+70826525163"}
0005433103667	D0071A	6650 645532	NATALYA ISAEVA	{"phone": "+70715585640"}
0005433103668	D7BBFD	6046 201133	VIKTOR FOMIN	{"phone": "+70033976979"}
0005433103669	D7BBFD	0336 676642	EVGENIY SMIRNOV	{"email": "e-smirnov011974@postgrespro.ru", "phone": "+70249438330"}
0005433103670	D7BBFD	0619 652385	OKSANA MELNIKOVA	{"phone": "+70467547629"}
0005433103671	BF97B2	7447 683474	MIKHAIL CHERNOV	{"email": "chernov_mikhail.021984@postgrespro.ru", "phone": "+70010972972"}
0005433103672	BF97B2	5310 860451	EKATERINA GERASIMOVA	{"phone": "+70773864642"}
0005433103673	5CE1F8	2366 159589	ALENA IVANOVA	{"phone": "+70166134520"}
0005433103674	15656F	7878 397991	NINA PAVLOVA	{"phone": "+70808800239"}
0005433103675	15656F	3926 912470	VALENTINA EFREMOVA	{"email": "efremovav_081969@postgrespro.ru", "phone": "+70384979835"}
0005433103676	A8A61D	8087 955264	ALEKSANDR KUDRYASHOV	{"phone": "+70077623327"}
0005433103677	A8A61D	7484 168015	ALEKSEY MIRONOV	{"email": "mironov.a_1966@postgrespro.ru", "phone": "+70677404068"}
0005433103678	81FAEF	4322 395340	EGOR MIKHAYLOV	{"email": "egor-mikhaylov.011982@postgrespro.ru", "phone": "+70778534738"}
0005433103679	3AF65B	9226 831220	RISHAT FOMIN	{"phone": "+70086853688"}
0005433103680	9D3C62	8842 575779	MARIYA ANDREEVA	{"phone": "+70984692178"}
0005433103681	ACE605	6817 540133	VIKTOR DENISOV	{"phone": "+70110159188"}
0005433103682	4C7212	2903 662001	NATALYA ZHURAVLEVA	{"email": "natalyazhuravleva.011969@postgrespro.ru", "phone": "+70166405265"}
0005433103683	582A77	3767 824484	MARINA MAKAROVA	{"phone": "+70389735698"}
0005433103684	83F702	9480 222497	YURIY FROLOV	{"phone": "+70885808471"}
0005433103685	5947F1	8737 641156	NINA RYABOVA	{"email": "nina.ryabova-041964@postgrespro.ru", "phone": "+70029714607"}
0005433103686	0914CA	7646 741934	GALINA ALEKSANDROVA	{"email": "aleksandrovagalina-1972@postgrespro.ru", "phone": "+70110245023"}
0005433103687	D89498	9758 168758	NINA TROFIMOVA	{"email": "trofimovan04041969@postgrespro.ru", "phone": "+70294898061"}
0005433103688	E12771	4920 349483	ELENA DMITRIEVA	{"phone": "+70580461647"}
0005433103689	561948	9934 634364	ALEKSANDRA BELOVA	{"email": "abelova05051981@postgrespro.ru", "phone": "+70625028281"}
0005433103690	AE3C5A	3061 700620	SVETLANA KONOVALOVA	{"phone": "+70230283916"}
0005433103691	AE3C5A	2684 811500	KONSTANTIN FOMIN	{"email": "k.fomin.1975@postgrespro.ru", "phone": "+70715543265"}
0005433103692	AE3C5A	3596 900095	DANILA PETROV	{"phone": "+70508930514"}
0005433103693	A40593	0264 199360	ALBERT ZAKHAROV	{"email": "albert_zakharov1972@postgrespro.ru", "phone": "+70233921099"}
0005433103694	A40593	3563 927051	ANTONINA EFIMOVA	{"phone": "+70243398845"}
0005433103695	4F86B6	4630 534978	MARIYA ABRAMOVA	{"email": "abramovamariya-11121965@postgrespro.ru", "phone": "+70913414097"}
0005433103696	DB45CB	3056 771984	ANATOLIY MARTYNOV	{"phone": "+70602960892"}
0005433103697	95BF69	3698 599032	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov-04011977@postgrespro.ru", "phone": "+70289888227"}
0005433103698	95BF69	3210 671317	STANISLAV KOZLOV	{"phone": "+70783983556"}
0005433103699	2EDB83	0631 464649	IRINA YUDINA	{"phone": "+70600324925"}
0005433103700	28DAEC	2356 902342	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova_lyubov.27101977@postgrespro.ru", "phone": "+70852966529"}
0005433103701	28DAEC	7899 507347	ELENA LUKYANOVA	{"email": "e_lukyanova1974@postgrespro.ru", "phone": "+70459849687"}
0005433103702	263257	0128 255114	PETR VOLKOV	{"email": "petr-volkov.101976@postgrespro.ru", "phone": "+70010052680"}
0005433103703	E5CAC0	3266 159865	LIDIYA FOMINA	{"email": "fomina_l-20041970@postgrespro.ru", "phone": "+70367712574"}
0005433103704	290307	9295 664504	VALERIY KUZNECOV	{"phone": "+70653886913"}
0005433103705	074534	0742 251192	YURIY FROLOV	{"email": "frolovy02031977@postgrespro.ru", "phone": "+70025993151"}
0005433103706	074534	4089 276630	SERGEY FROLOV	{"email": "sergey_frolov_09081978@postgrespro.ru", "phone": "+70342349282"}
0005433103707	EE3822	1636 590560	VITALIY SERGEEV	{"phone": "+70512540350"}
0005433103708	EE3822	4090 670617	VALENTINA SMIRNOVA	{"phone": "+70907248201"}
0005433103709	55E6B8	2167 369096	MIKHAIL GORBUNOV	{"email": "gorbunovmikhail1976@postgrespro.ru", "phone": "+70377844993"}
0005433103710	55E6B8	0297 438680	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev.1977@postgrespro.ru", "phone": "+70715578295"}
0005433103711	590D0A	7356 151118	DINARA ANTONOVA	{"email": "dinara.antonova.1975@postgrespro.ru", "phone": "+70437222367"}
0005433103712	590D0A	7874 978743	VERONIKA KOZLOVA	{"phone": "+70855397389"}
0005433103713	B7839C	6877 932829	VIKTOR NIKOLAEV	{"phone": "+70706675360"}
0005433103714	B7839C	8746 496189	ALEKSANDR SOROKIN	{"email": "sorokin_a-021975@postgrespro.ru", "phone": "+70360729857"}
0005433103715	B7839C	1401 313814	ALEKSANDR FEDOROV	{"phone": "+70568791970"}
0005433103716	11D451	3956 173826	VIKTOR YAKOVLEV	{"phone": "+70671741334"}
0005433103717	C66EAC	7344 096339	GALINA IVANOVA	{"email": "g-ivanova1975@postgrespro.ru", "phone": "+70638341877"}
0005433103718	068F7B	6627 424602	ELENA SERGEEVA	{"phone": "+70907147469"}
0005433103719	1218D8	3206 964978	EKATERINA ISAEVA	{"email": "ekaterina_isaeva021976@postgrespro.ru", "phone": "+70929529883"}
0005433103720	E5EDE1	4460 994750	KRISTINA ANISIMOVA	{"email": "kanisimova-1977@postgrespro.ru", "phone": "+70679053664"}
0005433103721	833CCA	0286 860636	SVETLANA ARKHIPOVA	{"phone": "+70290166010"}
0005433103722	89F597	3933 798681	MARINA SCHERBAKOVA	{"phone": "+70695645947"}
0005433103723	89F597	1218 459970	OLESYA KOROLEVA	{"email": "koroleva_olesya_061971@postgrespro.ru", "phone": "+70136382972"}
0005433103724	14B9CB	7393 319965	DMITRIY CHERNOV	{"phone": "+70932401049"}
0005433103725	14B9CB	0633 608787	YULIYA NIKOLAEVA	{"email": "nikolaeva.y081980@postgrespro.ru", "phone": "+70376862861"}
0005433103726	5EAA3B	4599 263209	MARINA ZAKHAROVA	{"phone": "+70669127679"}
0005433103727	C1C540	5346 469428	NIKOLAY SIDOROV	{"email": "sidorov-nikolay_11041968@postgrespro.ru", "phone": "+70336733209"}
0005433103728	BE62D4	8863 486925	TATYANA KISELEVA	{"phone": "+70397978357"}
0005433103729	FDB985	6117 325664	EVGENIYA KAZAKOVA	{"email": "e.kazakova_051973@postgrespro.ru", "phone": "+70561267061"}
0005433103730	F87553	2629 622933	PAVEL YAKOVLEV	{"phone": "+70428317997"}
0005433103731	F393E9	6635 785050	VIKTOR SOROKIN	{"phone": "+70742453205"}
0005433103732	804D88	3340 843913	ALEKSEY SMIRNOV	{"phone": "+70368188072"}
0005433103733	AD1ABE	5029 188684	NADEZHDA STEPANOVA	{"email": "stepanova-n.081970@postgrespro.ru", "phone": "+70928608664"}
0005433103734	005A30	8009 575432	NIKOLAY NAZAROV	{"email": "nnazarov1953@postgrespro.ru", "phone": "+70017603889"}
0005433103735	3474FA	5678 342103	OKSANA BORISOVA	{"email": "borisova_o_1970@postgrespro.ru", "phone": "+70831718577"}
0005433103736	2B97D2	0151 500268	ZOYA SCHERBAKOVA	{"email": "zscherbakova-061984@postgrespro.ru", "phone": "+70691202711"}
0005433103737	4BDFC8	9086 334363	MARIYA MOROZOVA	{"phone": "+70764273814"}
0005433103738	8F5F40	5191 256910	NINA KUZNECOVA	{"email": "nina_kuznecova1981@postgrespro.ru", "phone": "+70009700574"}
0005433103739	8F5F40	0461 961544	YURIY GUSEV	{"email": "gusev.y051965@postgrespro.ru", "phone": "+70532232878"}
0005433103740	8F5F40	0040 379515	OLGA ZHURAVLEVA	{"email": "zhuravlevao101971@postgrespro.ru", "phone": "+70428953198"}
0005433103741	133089	2884 962345	ALEKSANDR PETROV	{"email": "petrova-1972@postgrespro.ru", "phone": "+70196780048"}
0005433103742	81B3D1	9254 750407	VLADIMIR KUZNECOV	{"email": "kuznecov-v.061977@postgrespro.ru", "phone": "+70706408248"}
0005433103743	AD79D4	4924 259544	TATYANA NIKOLAEVA	{"phone": "+70971796462"}
0005433103744	96818F	2170 626355	OLEG MIRONOV	{"phone": "+70717553742"}
0005433103745	96818F	8734 510502	TAISIYA EFIMOVA	{"email": "taisiya_efimova.1968@postgrespro.ru", "phone": "+70115192426"}
0005433103746	96818F	9153 799925	ANDREY SIDOROV	{"phone": "+70989036477"}
0005433103747	934D28	4720 750283	VIKTOR SHEVCHENKO	{"email": "shevchenko-viktor_1982@postgrespro.ru", "phone": "+70546559108"}
0005433103748	934D28	1664 556508	ELENA PETROVA	{"email": "petrova-e_061977@postgrespro.ru", "phone": "+70710167571"}
0005433103749	934D28	0224 476916	ALEKSEY MIRONOV	{"phone": "+70002681096"}
0005433103750	7527C0	0163 645783	EDUARD KRASNOV	{"phone": "+70629837801"}
0005433103751	7527C0	4637 304130	RUSLAN ANDREEV	{"email": "ruslan_andreev1968@postgrespro.ru", "phone": "+70434549936"}
0005433103752	BCFBED	6003 185896	OLGA SAVELEVA	{"email": "o-saveleva-1969@postgrespro.ru", "phone": "+70492721420"}
0005433103753	BCFBED	0608 896692	IGOR NIKITIN	{"phone": "+70437430785"}
0005433103754	44CAF9	9991 871002	ALEKSEY ZAYCEV	{"phone": "+70414917968"}
0005433103755	BE6806	3623 262536	ALEKSANDR NOVIKOV	{"email": "novikov.a1975@postgrespro.ru", "phone": "+70938510926"}
0005433103756	BBAACD	9307 563276	ALEKSANDR VASILEV	{"email": "avasilev.02111974@postgrespro.ru", "phone": "+70843044668"}
0005433103757	6EDD07	5883 377511	VLADIMIR ILIN	{"email": "vladimir_ilin-101974@postgrespro.ru", "phone": "+70601164835"}
0005433103758	6EDD07	5928 740615	ALEKSANDRA ERMAKOVA	{"phone": "+70741982206"}
0005433103759	6EDD07	4314 683069	ANASTASIYA NIKIFOROVA	{"phone": "+70926192000"}
0005433103760	395EAE	3075 890690	LYUBOV STEPANOVA	{"phone": "+70426765060"}
0005433103761	EE6744	4361 965182	VASILIY IVANOV	{"phone": "+70734314541"}
0005433103762	EE6744	1921 450676	NINA KRASNOVA	{"phone": "+70168411346"}
0005433103763	AEA5E3	2412 957793	GENNADIY YAKOVLEV	{"email": "gennadiy-yakovlev_20111993@postgrespro.ru", "phone": "+70652768022"}
0005433103764	0E45AE	1869 763538	DANIIL FOMIN	{"email": "d-fomin_1963@postgrespro.ru", "phone": "+70289533785"}
0005433103765	521A25	8429 160410	LYUBOV MELNIKOVA	{"email": "melnikova.lyubov041974@postgrespro.ru", "phone": "+70910046533"}
0005433103766	521A25	8929 726985	ANNA KUZNECOVA	{"phone": "+70548212557"}
0005433103767	C6E7E1	5148 376189	ANDREY KOROLEV	{"phone": "+70881696363"}
0005433103768	C6E7E1	1089 984831	ALEKSANDR BELOV	{"email": "a-belov.1969@postgrespro.ru", "phone": "+70492904581"}
0005433103769	77BC8D	2198 233400	LILIYA VASILEVA	{"phone": "+70724379366"}
0005433103770	2438AE	7880 235098	ELENA MIRONOVA	{"email": "mironova_elena_1974@postgrespro.ru", "phone": "+70709785853"}
0005433103771	058BB3	3480 952821	TATYANA BARANOVA	{"email": "baranovatatyana_20011967@postgrespro.ru", "phone": "+70811717969"}
0005433103772	058BB3	6977 308292	ELENA KUZMINA	{"email": "ekuzmina-041978@postgrespro.ru", "phone": "+70526390190"}
0005433103773	B6DFB8	5556 057252	VLADIMIR TARASOV	{"phone": "+70706167649"}
0005433103774	B6DFB8	5366 185722	MARIYA KUZMINA	{"email": "kuzmina.m09011966@postgrespro.ru", "phone": "+70153327809"}
0005433103775	B6DFB8	7901 976499	VALERIY TIKHONOV	{"email": "tikhonov_v_1971@postgrespro.ru", "phone": "+70476871563"}
0005433103776	B6DFB8	4987 270866	ELENA KOLESNIKOVA	{"email": "e-kolesnikova17071966@postgrespro.ru", "phone": "+70730828437"}
0005433103777	8532B3	5091 171178	LYUDMILA NIKOLAEVA	{"phone": "+70380264930"}
0005433103778	804940	7101 821915	NADEZHDA KOZLOVA	{"phone": "+70654508702"}
0005433103779	AAC983	7509 462691	SOFIYA FADEEVA	{"phone": "+70980361132"}
0005433103780	F68D6C	5270 393990	DMITRIY ZAYCEV	{"phone": "+70046094588"}
0005433103781	91F520	9468 365821	IVAN ZHURAVLEV	{"email": "ivanzhuravlev.02121973@postgrespro.ru", "phone": "+70181309152"}
0005433103782	15D219	3155 641276	ANZHELIKA ORLOVA	{"email": "anzhelika.orlova.14091968@postgrespro.ru", "phone": "+70766265014"}
0005433103783	15D219	5562 624665	SERGEY YAKOVLEV	{"email": "sergey.yakovlev.1954@postgrespro.ru", "phone": "+70670511121"}
0005433103784	3EC3D5	1604 959404	LIDIYA BELOVA	{"email": "lidiya.belova-011982@postgrespro.ru", "phone": "+70640739473"}
0005433103785	F6CD7B	2979 157262	VENERA RODIONOVA	{"email": "rodionova.v-1965@postgrespro.ru", "phone": "+70607201532"}
0005433103786	9A2FD4	3810 284934	SERGEY KRASNOV	{"email": "krasnovs-1970@postgrespro.ru", "phone": "+70124701403"}
0005433103787	9A2FD4	7532 835373	MARIYA KALININA	{"email": "kalinina_mariya.22111969@postgrespro.ru", "phone": "+70531793353"}
0005433103788	2F880B	1119 188741	NIKOLAY STEPANOV	{"phone": "+70807922359"}
0005433103789	0D6607	7773 960273	VLADIMIR KOZLOV	{"email": "kozlov-v-29091975@postgrespro.ru", "phone": "+70661753330"}
0005433103790	0D6607	8123 887874	ARTEM IVANOV	{"email": "aivanov10081973@postgrespro.ru", "phone": "+70383207441"}
0005433103791	CB8AF6	0558 733138	GALINA MAKAROVA	{"email": "g.makarova.23101967@postgrespro.ru", "phone": "+70952830814"}
0005433103792	C30C9A	5762 578521	ALEKSANDR KONOVALOV	{"phone": "+70763446589"}
0005433103793	E3CAFE	7065 981807	OLEG NIKITIN	{"email": "o_nikitin-1980@postgrespro.ru", "phone": "+70812033182"}
0005433103794	30A851	2065 090945	INNA LAZAREVA	{"email": "lazareva-inna_011965@postgrespro.ru", "phone": "+70321583353"}
0005433103795	30A851	1517 773765	GALINA KUZNECOVA	{"phone": "+70064336060"}
0005433103796	5599C2	4559 238145	ALEVTINA TROFIMOVA	{"email": "a_trofimova051971@postgrespro.ru", "phone": "+70024113940"}
0005433103797	45F1CF	9603 411803	VITALIY KAZAKOV	{"email": "vitaliy-kazakov-01061972@postgrespro.ru", "phone": "+70949231547"}
0005433103798	45F1CF	5085 073116	VLADIMIR ORLOV	{"email": "orlov-vladimir111982@postgrespro.ru", "phone": "+70617701086"}
0005433103799	68ED6D	0821 125439	DENIS SMIRNOV	{"phone": "+70582176335"}
0005433103800	68ED6D	2429 313013	NATALYA ANTONOVA	{"phone": "+70214274840"}
0005433103801	FAC930	8083 911701	SERGEY MIKHAYLOV	{"phone": "+70484222161"}
0005433103802	FAC930	2763 923394	NIKITA MEDVEDEV	{"phone": "+70792875727"}
0005433103803	085321	6391 134780	SERGEY ILIN	{"phone": "+70091191897"}
0005433103804	3737A9	5162 551315	TAMARA AKIMOVA	{"phone": "+70747703500"}
0005433103805	DDFE91	5795 678955	ANASTASIYA ORLOVA	{"phone": "+70402147165"}
0005433103806	7050DD	0540 213686	SOFYA KUZNECOVA	{"email": "sofyakuznecova_121967@postgrespro.ru", "phone": "+70571809051"}
0005433103807	66CD44	7205 665065	ROMAN FROLOV	{"phone": "+70410170086"}
0005433103808	66CD44	8052 035971	ANDREY NIKOLAEV	{"email": "nikolaev-andrey-051968@postgrespro.ru", "phone": "+70780202940"}
0005433103809	93C8BE	0339 757633	EVGENIYA TITOVA	{"email": "titova-evgeniya.031960@postgrespro.ru", "phone": "+70036040679"}
0005433103810	8B8955	5522 785669	ELENA KUZNECOVA	{"phone": "+70496288485"}
0005433103811	17A79E	4077 126562	ELENA CHERNOVA	{"phone": "+70723345526"}
0005433103812	0180B3	6914 735358	NINA POPOVA	{"email": "popova-nina_17031968@postgrespro.ru", "phone": "+70399274059"}
0005433103813	2BD3E0	8864 031279	VALENTIN KOROLEV	{"phone": "+70696782526"}
0005433103814	6358BC	7892 819861	ALEKSANDR ORLOV	{"phone": "+70088967485"}
0005433103815	F7F2A3	9244 442221	NATALYA MOISEEVA	{"email": "nmoiseeva_101975@postgrespro.ru", "phone": "+70682319645"}
0005433103816	83D8E5	1087 174298	IRINA KONDRATEVA	{"phone": "+70277788274"}
0005433103817	418821	7969 899065	LYUDMILA KOMAROVA	{"email": "komarovalyudmila_1972@postgrespro.ru", "phone": "+70699136537"}
0005433103818	9A925E	9529 674166	KIRILL FEDOROV	{"email": "fedorov-k.1971@postgrespro.ru", "phone": "+70366395329"}
0005433103819	3A7369	3479 774275	VERONIKA MIRONOVA	{"phone": "+70131614834"}
0005433103820	3A7369	9082 968806	ANDREY KUZNECOV	{"email": "kuznecov_andrey.061972@postgrespro.ru", "phone": "+70865391692"}
0005433103821	2E0BD2	6586 642065	SVETLANA ZAYCEVA	{"phone": "+70158087802"}
0005433103822	7C824A	0535 010252	TATYANA NAUMOVA	{"phone": "+70045249035"}
0005433103823	725125	4743 995382	ILMIRA MAKAROVA	{"email": "makarova_i.071972@postgrespro.ru", "phone": "+70847277714"}
0005433103824	FCB251	1771 868098	SERGEY SAVELEV	{"email": "s-savelev1981@postgrespro.ru", "phone": "+70729845740"}
0005433103825	1921B7	3926 829278	SERGEY POPOV	{"email": "sergeypopov-15051964@postgrespro.ru", "phone": "+70875212621"}
0005433103826	1921B7	4416 519603	VASILIY OSIPOV	{"phone": "+70661952513"}
0005433103827	D9906C	1938 591059	VLADISLAV PAVLOV	{"phone": "+70840568461"}
0005433103828	2FFC47	4803 681879	GALINA FADEEVA	{"email": "fadeeva-galina.21081974@postgrespro.ru", "phone": "+70892933957"}
0005433103829	2FFC47	9996 809346	VALERIY ZAKHAROV	{"email": "valeriy_zakharov.1979@postgrespro.ru", "phone": "+70999514917"}
0005433103830	5455D6	0344 307615	VALENTINA ARKHIPOVA	{"phone": "+70043769475"}
0005433103831	53D86F	8453 331666	ANDREY VASILEV	{"phone": "+70525261213"}
0005433103832	53D86F	0655 727724	ALEKSANDR NAZAROV	{"email": "nazarov_a15021969@postgrespro.ru", "phone": "+70573580613"}
0005433103833	13446C	3154 100371	SERGEY MAKSIMOV	{"email": "maksimovsergey_1974@postgrespro.ru", "phone": "+70570896766"}
0005433103834	96CD36	1652 803321	LARISA SEMENOVA	{"email": "larisa_semenova1977@postgrespro.ru", "phone": "+70738053840"}
0005433103835	9A17CF	2142 132060	ALEKSEY ZHURAVLEV	{"phone": "+70812690416"}
0005433103836	E2E9E0	2076 235647	ARTUR MAKSIMOV	{"phone": "+70945849057"}
0005433103837	E2E9E0	1571 870379	PETR KOZLOV	{"phone": "+70344637019"}
0005433103838	7CA267	3347 610778	VIKTOR GERASIMOV	{"email": "v_gerasimov-20111980@postgrespro.ru", "phone": "+70247330161"}
0005433103839	30D06F	3298 535109	GRIGORIY MEDVEDEV	{"phone": "+70757043187"}
0005433103840	30D06F	1729 342321	DMITRIY BORISOV	{"email": "borisov.dmitriy.1983@postgrespro.ru", "phone": "+70135726513"}
0005433103841	CA9EB7	1204 250100	LYUBOV KOROLEVA	{"phone": "+70545170954"}
0005433103842	8684A3	0332 863969	EVGENIY DENISOV	{"phone": "+70202923407"}
0005433103843	AA2BDB	4603 756298	IVAN KUZNECOV	{"email": "kuznecov-ivan061977@postgrespro.ru", "phone": "+70458446700"}
0005433103844	CD770A	0275 669697	ALEKSANDR POPOV	{"email": "aleksandr_popov091964@postgrespro.ru", "phone": "+70715873226"}
0005433103845	E6978E	3640 183550	DMITRIY SIDOROV	{"email": "dsidorov.06011976@postgrespro.ru", "phone": "+70720760387"}
0005433103846	E6978E	0162 577277	DANIL YAKOVLEV	{"phone": "+70547696292"}
0005433103847	9F74DF	6308 842662	LYUDMILA BELOVA	{"email": "beloval_14111972@postgrespro.ru", "phone": "+70064111187"}
0005433103848	C206E8	9916 362460	LYUDMILA KUZNECOVA	{"phone": "+70931872600"}
0005433103849	C206E8	0818 883305	RAISA YAKOVLEVA	{"email": "yakovleva_r081989@postgrespro.ru", "phone": "+70355193995"}
0005433103850	06CE9B	3498 365510	VALENTINA ZAYCEVA	{"phone": "+70923310406"}
0005433103851	217F37	0402 124996	TAMARA STEPANOVA	{"phone": "+70810445413"}
0005433103852	7C0477	8744 770571	NIKOLAY KAZAKOV	{"email": "kazakov_n1985@postgrespro.ru", "phone": "+70341360236"}
0005433103853	0DA8E9	3109 791670	ARTEM NAUMOV	{"phone": "+70715315113"}
0005433103854	0DA8E9	2170 564636	DANIIL ROMANOV	{"phone": "+70208689745"}
0005433103855	D2D970	6950 246972	MARSEL IVANOV	{"phone": "+70743230862"}
0005433103856	F58CFC	5880 799256	LYUBOV SEMENOVA	{"email": "lsemenova.021975@postgrespro.ru", "phone": "+70986642801"}
0005433103857	F58CFC	1258 832984	MIKHAIL KUZMIN	{"email": "kuzmin.mikhail21041973@postgrespro.ru", "phone": "+70847933278"}
0005433103858	725E90	5839 794390	SVETLANA KOZLOVA	{"phone": "+70152893603"}
0005433103859	725E90	1072 206658	YAROSLAVA STEPANOVA	{"phone": "+70516376675"}
0005433103860	FCB7ED	2347 723921	SVETLANA KRASNOVA	{"email": "s-krasnova13111963@postgrespro.ru", "phone": "+70898459272"}
0005433103861	FCB7ED	2640 496974	MAKSIM PAVLOV	{"phone": "+70096046875"}
0005433103862	FCB7ED	5559 050755	IRAIDA DANILOVA	{"phone": "+70739389694"}
0005433103863	77737A	4700 631136	ALEKSEY NIKITIN	{"phone": "+70306833411"}
0005433103864	C21930	8469 038650	IGOR TIKHONOV	{"phone": "+70425804803"}
0005433103865	A10112	0702 139584	DANILA MARTYNOV	{"email": "martynovdanila.1974@postgrespro.ru", "phone": "+70486432431"}
0005433103866	A10112	7466 223313	YURIY YAKOVLEV	{"phone": "+70872945746"}
0005433103867	558AE8	0213 067698	SERGEY KUZNECOV	{"phone": "+70043886206"}
0005433103868	2E9A80	8469 979365	VERA GRISHINA	{"email": "vera-grishina061974@postgrespro.ru", "phone": "+70651623158"}
0005433103869	799292	6279 238744	VLADIMIR NOVIKOV	{"phone": "+70470647323"}
0005433103870	AB505D	4925 186659	MARIYA KOROLEVA	{"email": "mariyakoroleva-08031976@postgrespro.ru", "phone": "+70162479862"}
0005433103871	4B0251	1296 022065	ALEKSANDR EGOROV	{"email": "egorov_aleksandr_01061978@postgrespro.ru", "phone": "+70268883457"}
0005433103872	B59114	7085 872162	ELENA FILIPPOVA	{"email": "e.filippova1966@postgrespro.ru", "phone": "+70370557198"}
0005433103873	587B63	0893 276260	SVETLANA BARANOVA	{"phone": "+70149775603"}
0005433103874	48E615	8861 616354	OKSANA TROFIMOVA	{"phone": "+70152617986"}
0005433103875	A39944	5482 051729	ROMAN ROMANOV	{"phone": "+70032666141"}
0005433103876	A39944	8259 855233	RUSTAM NOVIKOV	{"phone": "+70851420341"}
0005433103877	0296D2	8527 149387	ALEVTINA SOROKINA	{"phone": "+70262239006"}
0005433103878	4C8665	5421 294785	DILYARA ISAEVA	{"phone": "+70740423439"}
0005433103879	4010B2	3413 872877	MARIYA BARANOVA	{"email": "baranova_mariya.081967@postgrespro.ru", "phone": "+70044441060"}
0005433103880	280E6B	9656 959762	BORIS MAKAROV	{"email": "b.makarov_061975@postgrespro.ru", "phone": "+70795913373"}
0005433103881	4BD639	5264 688263	LARISA FADEEVA	{"email": "fadeeva-larisa_24081969@postgrespro.ru", "phone": "+70342794598"}
0005433103882	A252F0	4121 913708	EKATERINA NIKOLAEVA	{"email": "nikolaeva.ekaterina_121972@postgrespro.ru", "phone": "+70942941074"}
0005433103883	11E9FE	8667 031050	ELENA LOGINOVA	{"phone": "+70140523447"}
0005433103884	11E9FE	4013 205781	ALBINA FILIPPOVA	{"phone": "+70918905399"}
0005433103885	ED71F5	3811 354464	NINA KAZAKOVA	{"email": "nkazakova-011980@postgrespro.ru", "phone": "+70964083584"}
0005433103886	ED71F5	5010 206575	VASILIY BONDARENKO	{"phone": "+70796088425"}
0005433103888	7D9060	4817 744825	ANDREY SOROKIN	{"phone": "+70380748438"}
0005433103889	7D9060	6878 403317	AMINA MOROZOVA	{"email": "aminamorozova_061974@postgrespro.ru", "phone": "+70286910684"}
0005433103890	15C5D8	4583 539110	VERA IVANOVA	{"email": "vera.ivanova_021969@postgrespro.ru", "phone": "+70793741090"}
0005433103891	DBF13D	8660 047437	NINA DMITRIEVA	{"phone": "+70781601223"}
0005433103892	74A2A9	9669 178043	DANIIL SOKOLOV	{"phone": "+70778189609"}
0005433103893	231800	3160 275119	SERGEY KISELEV	{"phone": "+70193935771"}
0005433103894	5A726D	2061 968405	ALEKSANDR KOROLEV	{"email": "korolev_a-121962@postgrespro.ru", "phone": "+70768223651"}
0005433103895	64631C	1948 321933	MIKHAIL EGOROV	{"email": "megorov-1979@postgrespro.ru", "phone": "+70819496438"}
0005433103896	2B5ABB	0001 524610	TATYANA NESTEROVA	{"email": "tnesterova.121982@postgrespro.ru", "phone": "+70317320774"}
0005433103897	61BAFD	6820 629883	DANILA ANDREEV	{"phone": "+70438958725"}
0005433103898	CD09B2	9908 679486	VLADIMIR SEMENOV	{"phone": "+70511125002"}
0005433103899	CD09B2	3467 795698	IVAN RODIONOV	{"email": "rodionov.ivan1978@postgrespro.ru", "phone": "+70522252746"}
0005433103900	6EA696	7966 591269	ALEKSANDR GUSEV	{"email": "gusev-aleksandr.17041983@postgrespro.ru", "phone": "+70477432601"}
0005433103901	239853	6546 442012	NIKOLAY YAKOVLEV	{"email": "yakovlev.n_121974@postgrespro.ru", "phone": "+70091766967"}
0005433103902	239853	4737 821701	MIKHAIL ANDREEV	{"phone": "+70029185116"}
0005433103903	BEAF81	7687 659814	OLESYA VOLKOVA	{"email": "o.volkova1974@postgrespro.ru", "phone": "+70661819486"}
0005433103904	C12162	9557 021478	EKATERINA BARANOVA	{"phone": "+70271981881"}
0005433103905	94C434	1660 247192	ANTON MAKAROV	{"email": "makarov_a-071971@postgrespro.ru", "phone": "+70063677587"}
0005433103906	D9A411	1324 594492	ANNA SMIRNOVA	{"phone": "+70525000680"}
0005433103907	D9A411	1336 804162	SERGEY IVANOV	{"email": "ivanovs_16111951@postgrespro.ru", "phone": "+70933802241"}
0005433103908	199824	6510 277555	VLADISLAV VLASOV	{"phone": "+70515023476"}
0005433103909	24CCB0	1484 002833	YURIY ILIN	{"phone": "+70023774355"}
0005433103910	24CCB0	6174 996035	TATYANA FEDOROVA	{"email": "tatyana.fedorova121965@postgrespro.ru", "phone": "+70086687149"}
0005433103911	92A4B1	3363 560250	TATYANA LAZAREVA	{"email": "t_lazareva071967@postgrespro.ru", "phone": "+70815979028"}
0005433103912	92A4B1	9817 984047	ALEKSANDR KULIKOV	{"email": "a_kulikov_121961@postgrespro.ru", "phone": "+70369820301"}
0005433103913	DB0683	5073 319161	SERGEY KUZNECOV	{"email": "sergey-kuznecov-091978@postgrespro.ru", "phone": "+70232172385"}
0005433103914	DB0683	5759 009673	MIKHAIL KULIKOV	{"email": "kulikov_m.1977@postgrespro.ru", "phone": "+70764136289"}
0005433103915	A84FFC	4024 909049	IVAN KRASNOV	{"email": "krasnov-ivan-12081971@postgrespro.ru", "phone": "+70123061521"}
0005433103916	D30BB3	5356 717816	NATALYA SCHERBAKOVA	{"phone": "+70077737879"}
0005433103917	D30BB3	6862 452085	ALFIYA ALEKSANDROVA	{"phone": "+70148559566"}
0005433103918	0FD4CE	2962 881448	DMITRIY SOLOVEV	{"email": "dmitriy_solovev.27011969@postgrespro.ru", "phone": "+70814101424"}
0005433103919	0FD4CE	1934 583942	VLADISLAV KISELEV	{"email": "kiselev_vladislav071971@postgrespro.ru", "phone": "+70596268722"}
0005433103920	5EDCC2	7757 277279	DMITRIY MIRONOV	{"phone": "+70984412388"}
0005433103921	589554	7706 474085	NIKOLAY ANTONOV	{"phone": "+70566686479"}
0005433103922	589554	7049 795248	ALEKSANDR KONOVALOV	{"email": "konovalov_a-21011961@postgrespro.ru", "phone": "+70213791921"}
0005433103923	1D5254	1727 517486	NIKOLAY ZAYCEV	{"phone": "+70105787671"}
0005433103924	272ED5	4449 336842	ALEKSEY ABRAMOV	{"email": "abramov-aleksey_091967@postgrespro.ru", "phone": "+70681550972"}
0005433103925	81AB2A	2113 793949	GALINA FEDOROVA	{"email": "fedorova-g-1976@postgrespro.ru", "phone": "+70809748317"}
0005433103926	42226C	5977 416241	ALEKSANDR NAZAROV	{"phone": "+70976670368"}
0005433103927	260F32	5791 011291	ALEKSANDR KUZNECOV	{"phone": "+70379981729"}
0005433103928	DCED1E	8829 902518	ROMAN IVANOV	{"email": "ivanov_roman-14051980@postgrespro.ru", "phone": "+70483960711"}
0005433103929	410E28	5766 644109	ANATOLIY TARASOV	{"phone": "+70119651244"}
0005433103930	E35EB4	2508 268436	STANISLAV FEDOTOV	{"email": "fedotov_stanislav1975@postgrespro.ru", "phone": "+70676483243"}
0005433103931	E35EB4	5061 830855	SVETLANA EGOROVA	{"email": "egorova_svetlana-031972@postgrespro.ru", "phone": "+70831188681"}
0005433103932	34DD8D	7265 883619	ARTEM ALEKSANDROV	{"phone": "+70639163395"}
0005433103933	C1BF64	9422 866853	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov.061971@postgrespro.ru", "phone": "+70607747163"}
0005433103934	C1BF64	6178 673123	GALINA FEDOROVA	{"phone": "+70069899279"}
0005433103935	C1BF64	2904 274907	NADEZHDA MARTYNOVA	{"email": "nadezhda_martynova.021982@postgrespro.ru", "phone": "+70339830996"}
0005433103936	072D2B	6392 468528	IRINA OSIPOVA	{"email": "osipova.i_091967@postgrespro.ru", "phone": "+70987878639"}
0005433103937	A18B5D	9928 996072	VLADIMIR NAUMOV	{"phone": "+70701131508"}
0005433103938	A18B5D	1223 460796	LIDIYA POPOVA	{"phone": "+70013559576"}
0005433103939	C7ACB1	3998 664267	NIKITA SOROKIN	{"email": "sorokin.n-081978@postgrespro.ru", "phone": "+70456100327"}
0005433103940	C7ACB1	7101 231971	ANASTASIYA ALEKSANDROVA	{"phone": "+70430098680"}
0005433103941	E3D6A8	2933 140958	GRIGORIY MOISEEV	{"phone": "+70157456700"}
0005433103942	1E5180	8832 063746	MIKHAIL ZHURAVLEV	{"phone": "+70699791662"}
0005433103943	30013D	0484 023744	SERGEY PAVLOV	{"email": "pavlovs1963@postgrespro.ru", "phone": "+70775423391"}
0005433103944	520E55	6037 337726	ELENA NAUMOVA	{"phone": "+70217346975"}
0005433103945	D7EC9C	5561 615879	LYUBOV NESTEROVA	{"email": "nesterova-lyubov-1980@postgrespro.ru", "phone": "+70849233743"}
0005433103946	7D3637	2812 200640	SVETLANA ILINA	{"email": "ilina_svetlana091984@postgrespro.ru", "phone": "+70127152082"}
0005433103947	76ECBA	8936 701059	VYACHESLAV IVANOV	{"phone": "+70141412732"}
0005433103948	7E9699	4044 765172	TATYANA MIRONOVA	{"email": "t-mironova_22111967@postgrespro.ru", "phone": "+70564146168"}
0005433103949	7E9699	0814 069518	TATYANA MARTYNOVA	{"phone": "+70360953427"}
0005433103950	732AD6	0423 338332	IRINA FEDOROVA	{"phone": "+70570923441"}
0005433103951	732AD6	8296 418950	MAYYA AFANASEVA	{"phone": "+70565955065"}
0005433103952	732AD6	7447 981076	MARIYA NIKITINA	{"email": "nikitina_m.1970@postgrespro.ru", "phone": "+70126820497"}
0005433103953	732AD6	4939 452566	ANATOLIY BELOV	{"phone": "+70124820541"}
0005433103954	F07DE7	2984 347452	ANNA BORISOVA	{"phone": "+70675735008"}
0005433103955	F07DE7	6663 074065	NIKOLAY CHERNOV	{"email": "chernov_n.1973@postgrespro.ru", "phone": "+70502261792"}
0005433103956	7E529A	0227 173590	ANASTASIYA SAVELEVA	{"email": "anastasiya_saveleva041963@postgrespro.ru", "phone": "+70601040356"}
0005433103957	0C82AC	0224 575702	ALEKSANDRA KUZNECOVA	{"email": "aleksandra_kuznecova_031980@postgrespro.ru", "phone": "+70459260913"}
0005433103958	F5B586	9894 626233	OLGA NIKOLAEVA	{"phone": "+70228871680"}
0005433103959	75E0AF	0452 110646	IVAN KOZLOV	{"email": "i_kozlov-28051966@postgrespro.ru", "phone": "+70166508932"}
0005433103960	F746AF	4129 716786	ALEKSANDR NOVIKOV	{"email": "a_novikov02011965@postgrespro.ru", "phone": "+70901188271"}
0005433103961	F746AF	5500 750251	VLADIMIR DENISOV	{"email": "denisovvladimir-06111978@postgrespro.ru", "phone": "+70648087156"}
0005433103962	F746AF	7802 931697	ALEKSANDR BORISOV	{"phone": "+70518671792"}
0005433103963	EA20AF	0664 856976	SOFYA KOZLOVA	{"email": "kozlova-sofya-041980@postgrespro.ru", "phone": "+70860696827"}
0005433103964	9F1758	7782 589318	VLADISLAV BONDARENKO	{"phone": "+70614550397"}
0005433103965	9F1758	2715 162671	ANTONINA NIKIFOROVA	{"phone": "+70873428024"}
0005433103966	9F1758	3844 979188	VADIM PETROV	{"email": "petrov_vadim_021981@postgrespro.ru", "phone": "+70336332735"}
0005433103967	00BADF	6378 739841	LIDIYA NAZAROVA	{"email": "l.nazarova10071978@postgrespro.ru", "phone": "+70457622523"}
0005433103968	911E84	5800 459988	IRINA SOKOLOVA	{"email": "sokolova-i.011983@postgrespro.ru", "phone": "+70770650062"}
0005433103969	CD57F8	8248 759484	NATALYA ANTONOVA	{"email": "nantonova_08121963@postgrespro.ru", "phone": "+70813897189"}
0005433103970	B7DB1D	0100 026186	ALEKSEY TIMOFEEV	{"phone": "+70134124419"}
0005433103971	B7DB1D	7321 029101	ALENA LEBEDEVA	{"phone": "+70891900308"}
0005433103972	B424D7	4891 275432	VIKTOR STEPANOV	{"email": "stepanov_viktor011967@postgrespro.ru", "phone": "+70364857960"}
0005433103973	6F7F58	8556 210182	VIKTOR MARTYNOV	{"email": "v.martynov101980@postgrespro.ru", "phone": "+70857546318"}
0005433103974	219723	1424 439917	ELENA RYABOVA	{"phone": "+70188466591"}
0005433103975	219723	2068 947664	OLGA DANILOVA	{"email": "danilova.olga_14041968@postgrespro.ru", "phone": "+70066260999"}
0005433103976	008C35	4547 308818	ANTON KAZAKOV	{"email": "kazakova_24091973@postgrespro.ru", "phone": "+70961095260"}
0005433103977	A0599E	3699 491938	SNEZHANA MOROZOVA	{"email": "snezhanamorozova02031968@postgrespro.ru", "phone": "+70280882399"}
0005433103978	BF24D3	4140 138666	MARIYA GERASIMOVA	{"email": "gerasimova-mariya-101978@postgrespro.ru", "phone": "+70685510671"}
0005433103979	BF24D3	0133 315766	LYUBOV POPOVA	{"email": "l_popova1973@postgrespro.ru", "phone": "+70946434776"}
0005433103980	BE2DCE	7549 733402	ALEKSEY SIDOROV	{"email": "sidorova-16121963@postgrespro.ru", "phone": "+70430910712"}
0005433103981	BE2DCE	5276 287923	ANNA MIKHAYLOVA	{"email": "anna-mikhaylova.031980@postgrespro.ru", "phone": "+70033719348"}
0005433103982	BE2DCE	4156 547667	PAVEL SEMENOV	{"email": "semenov.pavel_081969@postgrespro.ru", "phone": "+70616690557"}
0005433103983	512062	6959 602362	ALEKSANDR MOROZOV	{"email": "a_morozov_1966@postgrespro.ru", "phone": "+70016266576"}
0005433103984	D75B8B	6759 247443	VIKTORIYA NIKITINA	{"email": "viktoriya_nikitina-08031968@postgrespro.ru", "phone": "+70816211889"}
0005433103985	8C3421	8691 108743	ALINA ZHUKOVA	{"phone": "+70108316654"}
0005433103986	8C3421	9366 056537	GALINA FROLOVA	{"email": "frolovag07101983@postgrespro.ru", "phone": "+70378814050"}
0005433103987	97B0DB	2781 003761	LYUBOV LUKYANOVA	{"email": "lukyanoval1967@postgrespro.ru", "phone": "+70738277842"}
0005433103988	E67ED9	2117 919432	VALENTINA SERGEEVA	{"email": "v-sergeeva_1968@postgrespro.ru", "phone": "+70184258920"}
0005433103989	548A3B	4328 016729	YULIYA AFANASEVA	{"email": "afanasevay_18071965@postgrespro.ru", "phone": "+70143040288"}
0005433103990	84CF4A	9453 393322	SERGEY SIDOROV	{"email": "sergey.sidorov_011973@postgrespro.ru", "phone": "+70180611081"}
0005433103991	F3E655	5993 079056	OLGA ZAYCEVA	{"email": "zayceva-o11121967@postgrespro.ru", "phone": "+70732846538"}
0005433103992	476ABA	6229 037882	MARINA FROLOVA	{"phone": "+70529146955"}
0005433103993	476ABA	2633 063925	MAKSIM ZAYCEV	{"phone": "+70779431495"}
0005433103994	9AC420	7538 950960	IVAN NAUMOV	{"phone": "+70192216507"}
0005433103995	9AC420	7850 537204	YULIYA SMIRNOVA	{"phone": "+70130042082"}
0005433103996	2EB024	0147 371329	LARISA STEPANOVA	{"email": "stepanova.l19061982@postgrespro.ru", "phone": "+70307720618"}
0005433103997	9D7A9C	5890 121186	NATALYA MOISEEVA	{"email": "moiseevan.09011965@postgrespro.ru", "phone": "+70379927668"}
0005433103998	9D7A9C	8071 883141	YULIYA NIKIFOROVA	{"phone": "+70866849826"}
0005433103999	9D7A9C	5084 728800	NINA KUZNECOVA	{"phone": "+70573469656"}
0005433104000	378AEC	1302 908479	VERA KARPOVA	{"phone": "+70238986313"}
0005433104001	BC1641	1037 065640	OLESYA KAZAKOVA	{"email": "o.kazakova.1972@postgrespro.ru", "phone": "+70259821591"}
0005433104002	BC1641	0078 647513	GALINA PETROVA	{"email": "galinapetrova061976@postgrespro.ru", "phone": "+70533525463"}
0005433104003	BC1641	3756 360166	ILYA DMITRIEV	{"email": "dmitriev.ilya.1972@postgrespro.ru", "phone": "+70254561980"}
0005433104004	1B79D8	5310 208974	GALINA NESTEROVA	{"email": "nesterovag-05021975@postgrespro.ru", "phone": "+70201669290"}
0005433104005	1B79D8	3736 851827	MARINA POPOVA	{"phone": "+70475918920"}
0005433104006	44747E	8576 227630	ANDREY GRIGOREV	{"email": "grigorev_a_09081978@postgrespro.ru", "phone": "+70048882541"}
0005433104007	0F7DEE	1012 966232	ANASTASIYA NOVIKOVA	{"email": "novikova-anastasiya_031972@postgrespro.ru", "phone": "+70373301431"}
0005433104008	029922	8295 960371	SERGEY NIKITIN	{"phone": "+70877111117"}
0005433104009	00DD00	5402 154608	EVGENIY IVANOV	{"email": "evgeniy-ivanov_17091974@postgrespro.ru", "phone": "+70112287943"}
0005433104010	00DD00	8182 786828	TAMARA ZHUKOVA	{"email": "zhukova_tamara.121981@postgrespro.ru", "phone": "+70808984891"}
0005433110074	77910E	2304 402139	DARYA PETROVA	{"phone": "+70222152128"}
0005433109837	706CB6	8490 403609	NATALYA KOMAROVA	{"phone": "+70483539028"}
0005433109838	706CB6	6366 364340	ALEKSANDR FOMIN	{"phone": "+70365627340"}
0005433109839	706CB6	9158 177876	DANIIL KULIKOV	{"email": "daniilkulikov-1972@postgrespro.ru", "phone": "+70591800209"}
0005433109840	584B6D	0084 127404	ALEKSEY RODIONOV	{"email": "aleksey.rodionov_1975@postgrespro.ru", "phone": "+70945834197"}
0005433109841	584B6D	1235 807169	OLGA KUZNECOVA	{"email": "o-kuznecova_31031980@postgrespro.ru", "phone": "+70507465814"}
0005433109842	9BAB72	3710 662753	ANATOLIY KOZLOV	{"phone": "+70653410410"}
0005433109843	974051	9948 787109	GALINA MIKHAYLOVA	{"phone": "+70451454772"}
0005433109844	F15E0E	3890 275783	NINA KUZMINA	{"email": "kuzmina-nina-1983@postgrespro.ru", "phone": "+70971730517"}
0005433109845	16202F	5815 018220	TATYANA KUZNECOVA	{"phone": "+70371783081"}
0005433109846	16202F	0175 823691	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana1975@postgrespro.ru", "phone": "+70714259400"}
0005433109847	E70B46	4973 533988	ALEKSANDR MAKAROV	{"email": "makarovaleksandr.051958@postgrespro.ru", "phone": "+70384007519"}
0005433109848	E70B46	8866 915312	ANDREY BELOV	{"email": "belova.13071968@postgrespro.ru", "phone": "+70893029453"}
0005433109849	8ED4AD	9257 742260	ELENA NAZAROVA	{"phone": "+70243032887"}
0005433109850	115B01	9793 625719	VLADIMIR AFANASEV	{"email": "vladimir-afanasev19031982@postgrespro.ru", "phone": "+70689575971"}
0005433109851	115B01	5067 252305	ELENA PETROVA	{"email": "petrova.e-1971@postgrespro.ru", "phone": "+70879077201"}
0005433109852	D77207	0201 525370	IRINA GUSEVA	{"phone": "+70986318783"}
0005433109853	BCD5BE	2395 394515	TATYANA FOMINA	{"email": "fomina.tatyana-30081973@postgrespro.ru", "phone": "+70480740992"}
0005433109854	BCD5BE	1850 657008	ELEONORA KOLESNIKOVA	{"phone": "+70136496257"}
0005433109855	A3282B	6053 004094	SVETLANA KISELEVA	{"email": "kiselevas_26041977@postgrespro.ru", "phone": "+70607852038"}
0005433109856	17EBE0	6446 996192	ANDREY MAKAROV	{"email": "andrey_makarov03021965@postgrespro.ru", "phone": "+70849227410"}
0005433109857	24CE60	0455 950138	KSENIYA LOGINOVA	{"email": "loginova_k.1972@postgrespro.ru", "phone": "+70217823251"}
0005433109858	24CE60	3631 922248	TATYANA KISELEVA	{"phone": "+70985925418"}
0005433109859	5A6969	2559 554320	TAMARA EGOROVA	{"email": "tamara_egorova_1964@postgrespro.ru", "phone": "+70110868981"}
0005433109860	0F3EEC	6008 162884	SERGEY BARANOV	{"phone": "+70109116918"}
0005433109861	0F3EEC	0979 403290	OLGA NIKOLAEVA	{"email": "olganikolaeva_26081968@postgrespro.ru", "phone": "+70572508652"}
0005433109862	82E80B	9139 676188	NADEZHDA OVCHINNIKOVA	{"phone": "+70590254660"}
0005433109863	DDA72A	5760 503756	SVETLANA RODIONOVA	{"email": "rodionova_s.031970@postgrespro.ru", "phone": "+70431373119"}
0005433109864	95F1E2	6604 700098	ZOYA SOLOVEVA	{"email": "z.soloveva.101978@postgrespro.ru", "phone": "+70624015152"}
0005433109865	6DF808	1670 131057	DENIS SEMENOV	{"email": "denissemenov_1971@postgrespro.ru", "phone": "+70042536370"}
0005433109866	11F2BA	7975 261188	SERGEY ORLOV	{"email": "orlovs.1962@postgrespro.ru", "phone": "+70265452582"}
0005433109867	11F2BA	4917 009185	SVETLANA SOLOVEVA	{"phone": "+70847461046"}
0005433109868	7EC70E	6292 586652	DARYA MOROZOVA	{"phone": "+70481223075"}
0005433109869	7EC70E	6468 462217	ANATOLIY EGOROV	{"email": "a-egorov.1981@postgrespro.ru", "phone": "+70584520349"}
0005433109870	28301F	4373 074904	ELENA FOMINA	{"email": "fomina.e.12061975@postgrespro.ru", "phone": "+70054216602"}
0005433109871	66B295	8433 977513	SERGEY DMITRIEV	{"email": "dmitriev-s061978@postgrespro.ru", "phone": "+70334220900"}
0005433109872	1C12A2	1517 591603	ROMAN ANDREEV	{"email": "andreev_r.17051968@postgrespro.ru", "phone": "+70152426979"}
0005433109873	6F2A08	0844 804723	ANDREY BORISOV	{"phone": "+70968981540"}
0005433109874	5D7745	3693 540017	TATYANA NESTEROVA	{"email": "nesterova_t-021977@postgrespro.ru", "phone": "+70807511412"}
0005433109875	5D7745	4114 639449	OLGA ZAKHAROVA	{"email": "olga_zakharova-1965@postgrespro.ru", "phone": "+70974249166"}
0005433109876	80C12E	4935 752063	GALINA SEMENOVA	{"phone": "+70252478544"}
0005433109877	B1247E	8795 738986	NATALYA ROMANOVA	{"phone": "+70555114233"}
0005433109878	B1247E	3483 187257	NATALYA IVANOVA	{"email": "natalya_ivanova-1979@postgrespro.ru", "phone": "+70550379087"}
0005433109879	9A5BEB	5574 678457	VIKTOR KONOVALOV	{"phone": "+70436683591"}
0005433109880	AE6471	3714 456304	VADIM IVANOV	{"phone": "+70174499388"}
0005433109881	AE6471	6301 436794	SVETLANA LAZAREVA	{"email": "s-lazareva-1976@postgrespro.ru", "phone": "+70103218180"}
0005433109882	AE6471	1891 397926	SERGEY KUZNECOV	{"email": "kuznecov.s03081968@postgrespro.ru", "phone": "+70431137507"}
0005433109883	AE6471	9421 858430	KSENIYA NOVIKOVA	{"phone": "+70222831170"}
0005433109884	EB803C	2237 786920	NIKOLAY KUZNECOV	{"phone": "+70819848908"}
0005433109885	EB803C	1847 894876	VALERIY FEDOROV	{"phone": "+70205301651"}
0005433109886	AD5A43	4986 820163	OLEG IVANOV	{"email": "oleg_ivanov041965@postgrespro.ru", "phone": "+70144314931"}
0005433109887	AD5A43	1154 724731	PETR KUZNECOV	{"email": "p_kuznecov-18071979@postgrespro.ru", "phone": "+70826813355"}
0005433109888	AD5A43	8031 288781	SERGEY DAVYDOV	{"email": "davydov_s.041975@postgrespro.ru", "phone": "+70799630040"}
0005433109889	384CF1	3944 059149	OLGA KUZMINA	{"phone": "+70946999821"}
0005433109890	E95CC1	9955 281736	SERGEY KUZNECOV	{"phone": "+70481358235"}
0005433109891	A8CEDA	9603 287592	VLADISLAV MIRONOV	{"email": "mironov-v-17011966@postgrespro.ru", "phone": "+70693501829"}
0005433109892	E81480	0585 488053	NATALYA NIKITINA	{"phone": "+70529377774"}
0005433109893	655F1B	6469 774655	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy02051965@postgrespro.ru", "phone": "+70488958614"}
0005433109894	655F1B	6453 335028	LYUBOV PAVLOVA	{"phone": "+70328319736"}
0005433109895	07AF97	2644 071006	NADEZHDA KUZMINA	{"email": "kuzmina.nadezhda021975@postgrespro.ru", "phone": "+70382228090"}
0005433109896	07AF97	9562 852251	VIKTOR TIMOFEEV	{"phone": "+70583201661"}
0005433109897	E8A02B	8528 358849	NINA TARASOVA	{"email": "tarasovan-22071963@postgrespro.ru", "phone": "+70300280866"}
0005433109898	7E80FA	0894 553418	SERGEY FOMIN	{"phone": "+70556731477"}
0005433109899	7E1469	1686 658080	ANGELINA IVANOVA	{"email": "a-ivanova061964@postgrespro.ru", "phone": "+70168959459"}
0005433109900	C17D7C	9351 407069	ANNA KUZNECOVA	{"email": "anna_kuznecova_091972@postgrespro.ru", "phone": "+70879335916"}
0005433109901	E8706F	3011 820321	ANTON OSIPOV	{"phone": "+70653248745"}
0005433109902	A71086	4394 071091	DARYA PETROVA	{"phone": "+70133193601"}
0005433109903	2B3260	3324 078840	ROMAN ZHURAVLEV	{"email": "roman-zhuravlev061963@postgrespro.ru", "phone": "+70566742410"}
0005433109904	AF52F9	0790 736395	NATALYA ERMAKOVA	{"email": "nermakova17041977@postgrespro.ru", "phone": "+70707512817"}
0005433109905	038C23	7671 993863	ARTUR KUZMIN	{"phone": "+70654030850"}
0005433109906	788081	1326 526308	ELENA AFANASEVA	{"email": "e_afanaseva-111972@postgrespro.ru", "phone": "+70490994927"}
0005433109907	65A136	8718 780238	LYUBOV SMIRNOVA	{"phone": "+70792972328"}
0005433109908	65A136	9246 964983	IGOR YAKOVLEV	{"email": "igoryakovlev_28041977@postgrespro.ru", "phone": "+70838306500"}
0005433109909	FC88E1	3812 186520	VLADISLAV KOROLEV	{"phone": "+70185817118"}
0005433109910	00E758	5549 168871	ELENA FEDOROVA	{"email": "fedorova_elena-1969@postgrespro.ru", "phone": "+70207182402"}
0005433109911	00E758	8043 114040	ANDREY ROMANOV	{"email": "romanov_a.071960@postgrespro.ru", "phone": "+70115668651"}
0005433109912	7ED2C4	7753 981935	SVETLANA LUKYANOVA	{"email": "slukyanova1982@postgrespro.ru", "phone": "+70725225411"}
0005433109913	7ED2C4	1506 950653	VLADIMIR ROMANOV	{"phone": "+70148553597"}
0005433109914	CEF99E	0996 485894	ROBERT ZHURAVLEV	{"phone": "+70201841322"}
0005433109915	CEF99E	0593 283302	INGA MARTYNOVA	{"email": "martynovai_05121973@postgrespro.ru", "phone": "+70134143840"}
0005433109916	CB1194	4548 448597	ZARINA RODIONOVA	{"phone": "+70261366060"}
0005433109917	3D1140	3945 194774	VIKTOR FILIPPOV	{"phone": "+70919134502"}
0005433109918	3D1140	6505 336006	ALEKSANDR MARTYNOV	{"email": "martynova-1966@postgrespro.ru", "phone": "+70576554868"}
0005433109919	847572	0475 427061	SVETLANA PETROVA	{"phone": "+70641797075"}
0005433109920	BB6819	7672 493191	VLADIMIR ZAYCEV	{"phone": "+70521619979"}
0005433109921	198B1F	9853 406013	IVAN OSIPOV	{"email": "osipov_ivan.1968@postgrespro.ru", "phone": "+70076881622"}
0005433109922	198B1F	5388 019964	BORIS GERASIMOV	{"email": "gerasimov.b_111970@postgrespro.ru", "phone": "+70424839705"}
0005433109923	8010B3	7415 499355	VERA RYABOVA	{"phone": "+70513757522"}
0005433109924	00F088	2426 430012	ANTONINA LUKYANOVA	{"email": "a.lukyanova031967@postgrespro.ru", "phone": "+70229695121"}
0005433109925	00F088	2400 554940	IREK KUZNECOV	{"phone": "+70501191243"}
0005433109926	90CB66	3190 919614	ANASTASIYA ZHURAVLEVA	{"phone": "+70460488202"}
0005433109927	E595F4	5481 053347	SVETLANA ZAYCEVA	{"phone": "+70634298581"}
0005433109928	899740	1478 012326	YURIY TIMOFEEV	{"email": "y.timofeev.17091972@postgrespro.ru", "phone": "+70779710960"}
0005433109929	66A40D	4456 582692	YULIYA ORLOVA	{"phone": "+70348334652"}
0005433109930	66A40D	2919 213236	ANDREY ABRAMOV	{"email": "andreyabramov.111978@postgrespro.ru", "phone": "+70381623087"}
0005433109931	D1EB7D	5396 726044	ALEKSANDR KOROLEV	{"phone": "+70650054043"}
0005433109932	1094C0	8713 715011	TAMARA SERGEEVA	{"email": "tamara-sergeeva.13081967@postgrespro.ru", "phone": "+70743064850"}
0005433109933	86A7AE	5735 362756	NINA POPOVA	{"email": "ninapopova-1965@postgrespro.ru", "phone": "+70356371382"}
0005433109934	5F11C2	0369 515679	DMITRIY PETROV	{"email": "dmitriy.petrov-1985@postgrespro.ru", "phone": "+70414803857"}
0005433109935	83A626	5645 917771	ELENA POPOVA	{"phone": "+70342359994"}
0005433109936	284F95	6087 994076	VALENTINA ZAYCEVA	{"email": "vzayceva_1986@postgrespro.ru", "phone": "+70290484156"}
0005433109937	284F95	6933 302981	SERGEY VOROBEV	{"email": "vorobev_sergey.081963@postgrespro.ru", "phone": "+70883208392"}
0005433109938	284F95	7292 977903	VALERIY SMIRNOV	{"email": "v.smirnov1981@postgrespro.ru", "phone": "+70366668055"}
0005433109939	AC189C	3287 964020	VALENTINA EFREMOVA	{"email": "efremovav.091976@postgrespro.ru", "phone": "+70276324841"}
0005433109940	2102B2	0388 107153	ALEKSANDR DAVYDOV	{"phone": "+70372991445"}
0005433109941	F1F035	1536 806734	VLADIMIR IVANOV	{"phone": "+70777685310"}
0005433109942	7553FC	6262 670968	EKATERINA LOGINOVA	{"email": "ekaterina_loginova-15041973@postgrespro.ru", "phone": "+70080186365"}
0005433109943	7553FC	0640 081942	YULIYA ZAYCEVA	{"phone": "+70320910677"}
0005433109944	1C7ADA	8634 783631	PETR DAVYDOV	{"phone": "+70743038316"}
0005433109945	4E18BC	8997 630387	OLGA SEMENOVA	{"email": "o.semenova_111963@postgrespro.ru", "phone": "+70888448508"}
0005433109946	4E18BC	2828 607959	LYUDMILA OVCHINNIKOVA	{"phone": "+70941724969"}
0005433109947	7E51DD	5436 082540	VIKTOR VLASOV	{"email": "vlasov_viktor-1963@postgrespro.ru", "phone": "+70014014845"}
0005433109948	7E51DD	5837 360880	ELENA CHERNOVA	{"phone": "+70275763681"}
0005433109949	A2E3D5	2621 241535	TATYANA PETROVA	{"phone": "+70615938418"}
0005433109950	A2E3D5	3077 891495	ALEKSANDR TIKHONOV	{"phone": "+70782896444"}
0005433109951	8D0742	6726 314106	ELIZAVETA AKIMOVA	{"email": "akimovaelizaveta.1975@postgrespro.ru", "phone": "+70734511933"}
0005433109952	653A9E	1982 128908	PAVEL KUZNECOV	{"email": "kuznecovp-09051986@postgrespro.ru", "phone": "+70616861105"}
0005433109953	653A9E	3785 769660	GALINA POPOVA	{"email": "galina_popova_061975@postgrespro.ru", "phone": "+70093452652"}
0005433109954	2EFC5D	3109 473305	ALSU NOVIKOVA	{"email": "a_novikova_021971@postgrespro.ru", "phone": "+70276508987"}
0005433109955	3787D2	5550 419899	MAKSIM KUZNECOV	{"email": "kuznecov-maksim.17081972@postgrespro.ru", "phone": "+70119183200"}
0005433109956	CE588E	2475 479161	NIKOLAY NOVIKOV	{"email": "novikov_nikolay_1973@postgrespro.ru", "phone": "+70626616076"}
0005433109957	CE588E	0934 456368	DMITRIY MATVEEV	{"email": "matveev_d-24081965@postgrespro.ru", "phone": "+70907229354"}
0005433109958	408617	0332 258543	TATYANA KISELEVA	{"email": "t.kiseleva_08091966@postgrespro.ru", "phone": "+70015942482"}
0005433109959	D4FABF	7223 311539	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila.031975@postgrespro.ru", "phone": "+70214435646"}
0005433109960	7D0948	8440 674277	GALINA ZAYCEVA	{"email": "galina.zayceva-09121968@postgrespro.ru", "phone": "+70606474252"}
0005433109961	7D0948	6389 986747	VYACHESLAV ILIN	{"email": "vyacheslav_ilin_111977@postgrespro.ru", "phone": "+70080210502"}
0005433109962	4E0645	6255 559272	SVETLANA IVANOVA	{"email": "s.ivanova_111954@postgrespro.ru", "phone": "+70712957430"}
0005433109963	4E0645	3215 247478	ELENA ABRAMOVA	{"email": "elena_abramova_1967@postgrespro.ru", "phone": "+70365416521"}
0005433109964	CCC8B3	7151 545195	GALINA TIMOFEEVA	{"email": "g.timofeeva.1978@postgrespro.ru", "phone": "+70572352333"}
0005433109965	CCC8B3	3136 696736	DMITRIY NOVIKOV	{"phone": "+70807466503"}
0005433109966	E1BC1F	9358 681096	DENIS AFANASEV	{"email": "afanasev-d.041972@postgrespro.ru", "phone": "+70134904911"}
0005433109967	EDF7AB	4479 080416	ANASTASIYA ZAKHAROVA	{"phone": "+70529644915"}
0005433109968	A5A91A	0833 303682	VIKTORIYA TITOVA	{"phone": "+70748543409"}
0005433109969	F12D29	8507 526727	ARTEM BONDARENKO	{"email": "a.bondarenko_18041972@postgrespro.ru", "phone": "+70152906822"}
0005433109970	5687C0	5167 349174	RAMZIYA FILATOVA	{"phone": "+70882003999"}
0005433109971	5687C0	8353 973161	GALINA GUSEVA	{"email": "galina.guseva-071964@postgrespro.ru", "phone": "+70379224512"}
0005433109972	E3CABC	6497 726307	ANDREY STEPANOV	{"phone": "+70606855304"}
0005433109973	36CA71	3964 410159	DENIS KOZLOV	{"phone": "+70015227264"}
0005433109974	F48FF0	0084 658814	YURIY GERASIMOV	{"phone": "+70009343430"}
0005433109975	8E3959	3121 689610	GALINA NOVIKOVA	{"email": "gnovikova-24111972@postgrespro.ru", "phone": "+70032147414"}
0005433109976	8E3959	1589 679088	ANTONINA NIKITINA	{"email": "anikitina-21051977@postgrespro.ru", "phone": "+70470864693"}
0005433109977	477129	6333 068279	ANDREY NIKOLAEV	{"email": "andrey.nikolaev.011984@postgrespro.ru", "phone": "+70525041469"}
0005433109978	22EF97	6509 579950	SVETLANA IVANOVA	{"phone": "+70498455181"}
0005433109979	EC5447	5713 979844	ANGELINA KUDRYASHOVA	{"email": "kudryashova-angelina-091989@postgrespro.ru", "phone": "+70144241140"}
0005433109980	38E8C9	5255 122609	DMITRIY VASILEV	{"email": "vasilev.dmitriy-1975@postgrespro.ru", "phone": "+70150394045"}
0005433109981	38E8C9	7724 599194	LYUDMILA KOZLOVA	{"phone": "+70611446012"}
0005433109982	B7D5D8	1000 467025	OLGA ZHUKOVA	{"email": "zhukovao_12041972@postgrespro.ru", "phone": "+70813014506"}
0005433109983	B7D5D8	6298 589757	GALINA MASLOVA	{"phone": "+70798139220"}
0005433109984	34FD41	5005 385771	OKSANA MIKHAYLOVA	{"email": "mikhaylova-o_28091970@postgrespro.ru", "phone": "+70116555837"}
0005433109985	6DCCEF	8347 870416	PAVEL KISELEV	{"email": "p-kiselev_1970@postgrespro.ru", "phone": "+70728053878"}
0005433109986	2E56A4	1895 763143	ALEKSEY ALEKSEEV	{"email": "a-alekseev.06061964@postgrespro.ru", "phone": "+70268120203"}
0005433109987	2E56A4	2372 062698	TATYANA KRASNOVA	{"email": "krasnova-t_1978@postgrespro.ru", "phone": "+70227227168"}
0005433109988	2E56A4	0937 494061	KIRILL GUSEV	{"phone": "+70304001443"}
0005433109989	2E56A4	8797 041662	ALEKSANDR ANDREEV	{"phone": "+70020835244"}
0005433109990	12E339	2862 657831	EVGENIY FILIPPOV	{"phone": "+70392175418"}
0005433109991	8B3B1F	7135 092328	EVGENIY KULIKOV	{"phone": "+70998362137"}
0005433109992	0487CE	4424 099321	MARIYA KOROLEVA	{"email": "korolevamariya-08031985@postgrespro.ru", "phone": "+70216352768"}
0005433109993	597AD5	5585 025831	LYUDMILA VOROBEVA	{"phone": "+70303264460"}
0005433109994	C993DF	7245 702990	EKATERINA TARASOVA	{"phone": "+70068595560"}
0005433109995	71BAC8	6054 878405	VITALIY ILIN	{"phone": "+70151945476"}
0005433109996	4579D3	6916 731042	VIKTOR PAVLOV	{"email": "pavlov-viktor_06041980@postgrespro.ru", "phone": "+70703552078"}
0005433109997	4579D3	4893 556968	ELENA FOMINA	{"email": "e_fomina-12031979@postgrespro.ru", "phone": "+70362167931"}
0005433109998	7FA50E	4174 895045	OLGA LUKYANOVA	{"email": "lukyanova-o031961@postgrespro.ru", "phone": "+70048946073"}
0005433109999	7FA50E	8989 404117	VERA FOMINA	{"phone": "+70587865765"}
0005433110000	C448A1	7316 371872	MIKHAIL PETROV	{"email": "mpetrov24101979@postgrespro.ru", "phone": "+70237535312"}
0005433110001	C448A1	9747 750871	ANATOLIY IVANOV	{"phone": "+70383522037"}
0005433110002	600139	1337 373477	ANTONINA MOROZOVA	{"email": "amorozova.1971@postgrespro.ru", "phone": "+70590434152"}
0005433110003	600139	1169 623669	ALEKSEY IVANOV	{"phone": "+70716701301"}
0005433110004	600139	6192 829989	MATVEY OSIPOV	{"email": "matveyosipov.061967@postgrespro.ru", "phone": "+70094985713"}
0005433110005	736DA3	1436 088485	GLEB ANTONOV	{"phone": "+70118108836"}
0005433110006	736DA3	4044 917013	ELENA GAVRILOVA	{"phone": "+70152877066"}
0005433110007	940103	8038 400108	IVAN VASILEV	{"phone": "+70930899894"}
0005433110008	BC7B09	3230 167606	EVGENIY SIDOROV	{"email": "esidorov-11121974@postgrespro.ru", "phone": "+70026394317"}
0005433110009	9F9C2A	0778 342773	IRINA MALYSHEVA	{"phone": "+70494633443"}
0005433110010	AD1313	8492 673960	PETR ZAKHAROV	{"email": "zakharovp_061969@postgrespro.ru", "phone": "+70036604268"}
0005433110011	CE7AEE	1206 834682	ARTEM SOLOVEV	{"phone": "+70497047210"}
0005433110012	5663A0	9440 615339	VLADIMIR EGOROV	{"phone": "+70792704070"}
0005433110013	2F4797	4795 715977	ANDREY CHERNOV	{"phone": "+70384181561"}
0005433110014	A7719B	2481 380885	MARINA DENISOVA	{"phone": "+70268236343"}
0005433110015	A22652	4503 513290	IVAN MATVEEV	{"phone": "+70562096304"}
0005433110016	C96587	1238 250451	VALENTINA BORISOVA	{"email": "borisovav_1978@postgrespro.ru", "phone": "+70771149596"}
0005433110017	B4A1DB	6442 171403	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev.101968@postgrespro.ru", "phone": "+70397680906"}
0005433110018	B4A1DB	8790 201216	ANNA ANDREEVA	{"email": "andreeva.a.1973@postgrespro.ru", "phone": "+70072826368"}
0005433110019	58E3C9	2120 864046	VLADIMIR NAZAROV	{"email": "vnazarov-1960@postgrespro.ru", "phone": "+70211707889"}
0005433110020	1AAB5F	8135 635790	ALEKSEY ZAYCEV	{"phone": "+70757859129"}
0005433110021	A8DF88	2700 151973	SVETLANA ANTONOVA	{"phone": "+70707007131"}
0005433110022	85E7AF	5605 435649	VLADIMIR SEMENOV	{"phone": "+70478659448"}
0005433110023	436CBA	8209 684350	VALENTIN FOMIN	{"phone": "+70699240958"}
0005433110024	CE473A	6453 501960	MAKSIM KUZNECOV	{"email": "kuznecov_maksim-041962@postgrespro.ru", "phone": "+70230634101"}
0005433110025	E882E7	6871 705953	ALEKSANDR KONOVALOV	{"phone": "+70794832437"}
0005433110026	E882E7	3264 523264	ALEKSEY BARANOV	{"email": "a-baranov-1965@postgrespro.ru", "phone": "+70788599464"}
0005433110027	E882E7	6558 517731	ARINA EGOROVA	{"phone": "+70924164929"}
0005433110028	E5B827	4215 915022	DMITRIY MARTYNOV	{"email": "d.martynov.1963@postgrespro.ru", "phone": "+70394742240"}
0005433110029	E5B827	5053 439062	VIKTOR FEDOTOV	{"phone": "+70230155744"}
0005433110030	E5B827	1950 628896	ALEKSANDR PETROV	{"phone": "+70829086204"}
0005433110031	F2D271	6446 179665	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy07101970@postgrespro.ru", "phone": "+70151438968"}
0005433110032	F2D271	9464 779383	RAMIL KUZNECOV	{"email": "ramil.kuznecov.1969@postgrespro.ru", "phone": "+70895540600"}
0005433110033	F2D271	6821 945928	ALEKSANDR SOROKIN	{"phone": "+70966202680"}
0005433110034	F2D271	7553 970015	ALFIYA LUKYANOVA	{"email": "lukyanova_a011970@postgrespro.ru", "phone": "+70430079278"}
0005433110035	2B5ADA	2251 630960	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov_041980@postgrespro.ru", "phone": "+70800332800"}
0005433110036	2B5ADA	8746 627246	ALEKSEY POPOV	{"phone": "+70574717041"}
0005433110037	DF69E0	2266 218102	ANATOLIY GRIGOREV	{"email": "grigorev.anatoliy.111976@postgrespro.ru", "phone": "+70340080982"}
0005433110038	B945CA	4853 658034	ANDREY MARTYNOV	{"phone": "+70091636480"}
0005433110039	E2C4E0	0938 365135	ALEKSANDRA PAVLOVA	{"email": "pavlovaa.051965@postgrespro.ru", "phone": "+70530061553"}
0005433110040	71B7EF	9749 121388	IRINA EFIMOVA	{"phone": "+70547104787"}
0005433110041	71B7EF	1340 959507	OLEG MAKAROV	{"phone": "+70106940522"}
0005433110042	E0C2FC	9234 225253	EVGENIY DAVYDOV	{"email": "davydov.e_18011967@postgrespro.ru", "phone": "+70299357105"}
0005433110043	287F7F	2569 348130	OLGA VOLKOVA	{"email": "olga-volkova_1973@postgrespro.ru", "phone": "+70472912322"}
0005433110044	343D4E	8700 762946	POLINA KUZNECOVA	{"email": "kuznecova-polina.1971@postgrespro.ru", "phone": "+70834422059"}
0005433110045	343D4E	4767 127211	OLGA KOVALEVA	{"phone": "+70491218145"}
0005433110046	343D4E	1512 843114	OLEG NAUMOV	{"email": "naumov_oleg051983@postgrespro.ru", "phone": "+70908037438"}
0005433110047	EE2E20	5764 156629	NIKITA KUZNECOV	{"email": "nikitakuznecov_1966@postgrespro.ru", "phone": "+70952915573"}
0005433110048	386776	2531 391452	GALIYA ILINA	{"email": "galiya.ilina.121972@postgrespro.ru", "phone": "+70249433781"}
0005433110049	1FD437	6993 267135	SERGEY OSIPOV	{"phone": "+70697718366"}
0005433110050	11F20C	6949 713521	LYUBOV SERGEEVA	{"email": "sergeevalyubov.1978@postgrespro.ru", "phone": "+70265884337"}
0005433110051	31E5DF	9789 776886	NINA GRISHINA	{"email": "n-grishina.1974@postgrespro.ru", "phone": "+70362201106"}
0005433110052	E7EC1A	2024 821318	VERA ALEKSEEVA	{"phone": "+70125682209"}
0005433110053	EAAF1E	9069 970334	VALENTIN BELOV	{"email": "valentin_belov011974@postgrespro.ru", "phone": "+70802772097"}
0005433110054	40F139	6700 251126	LARISA KISELEVA	{"email": "kiseleva-l.031976@postgrespro.ru", "phone": "+70636974247"}
0005433110055	40F139	1571 098883	ALEKSANDR PETROV	{"phone": "+70197982332"}
0005433110056	9796A3	4796 797015	VITALIY ABRAMOV	{"phone": "+70411261397"}
0005433110057	9796A3	1388 523859	ANNA ROMANOVA	{"email": "romanova_anna1962@postgrespro.ru", "phone": "+70877538219"}
0005433110058	3A92BB	8760 902479	VERONIKA MIKHAYLOVA	{"email": "mikhaylova-v_1966@postgrespro.ru", "phone": "+70188828564"}
0005433110059	BD5BBE	0508 008262	ARTEM ZAYCEV	{"phone": "+70733755053"}
0005433110060	BD5BBE	8980 934911	ALEKSANDR VOLKOV	{"phone": "+70055593666"}
0005433110061	9CB4C2	8734 659791	EGOR GUSEV	{"email": "egor-gusev-1981@postgrespro.ru", "phone": "+70192381656"}
0005433110062	E20D92	0763 406327	ANASTASIYA VOLKOVA	{"email": "a-volkova_1976@postgrespro.ru", "phone": "+70437589654"}
0005433110063	E9BB26	8474 591412	OKSANA ALEKSEEVA	{"phone": "+70714330190"}
0005433110064	496336	2612 491231	NIKOLAY KOROLEV	{"email": "korolev-nikolay1971@postgrespro.ru", "phone": "+70100650777"}
0005433110065	698DD7	0825 620641	EGOR MIKHAYLOV	{"phone": "+70187838395"}
0005433110066	698DD7	8396 204865	EVGENIY MATVEEV	{"phone": "+70042811810"}
0005433110067	107DFB	6229 136565	VALERIY SOROKIN	{"email": "valeriy.sorokin-081963@postgrespro.ru", "phone": "+70805953190"}
0005433110068	A1EA65	4370 998272	IVAN POPOV	{"phone": "+70068703150"}
0005433110069	A44674	7123 969239	MIKHAIL GAVRILOV	{"email": "mgavrilov1976@postgrespro.ru", "phone": "+70083576724"}
0005433110130	71A0C1	6604 322811	IVAN KOROLEV	{"phone": "+70947961639"}
0005433110070	A44674	7002 675969	IVAN SOKOLOV	{"email": "sokolov_ivan_1962@postgrespro.ru", "phone": "+70948142150"}
0005433110071	F25A31	4589 742509	GENNADIY RODIONOV	{"email": "grodionov1967@postgrespro.ru", "phone": "+70033061449"}
0005433110072	F25A31	5580 368377	NATALYA MOROZOVA	{"email": "n.morozova1969@postgrespro.ru", "phone": "+70667448211"}
0005433110073	77910E	9286 209958	ALEKSEY FEDOROV	{"phone": "+70757215173"}
0005433110075	A03DEB	2518 611933	ANASTASIYA SAVELEVA	{"email": "anastasiya.saveleva-1967@postgrespro.ru", "phone": "+70204063494"}
0005433110076	A03DEB	5524 184472	DMITRIY ILIN	{"phone": "+70788363718"}
0005433110077	D028A1	0984 132273	RINAT KUZMIN	{"email": "r-kuzmin-1989@postgrespro.ru", "phone": "+70783787598"}
0005433110078	D028A1	7988 674970	ANDREY TARASOV	{"email": "a_tarasov-031973@postgrespro.ru", "phone": "+70129621921"}
0005433110079	181A52	7986 223351	SERGEY KONOVALOV	{"phone": "+70636885268"}
0005433110080	6C2DA7	4479 506876	VIKTOR VASILEV	{"phone": "+70125022218"}
0005433110081	D7F5EF	0998 397163	TATYANA GORBUNOVA	{"phone": "+70754131995"}
0005433110082	7EA4FA	5722 026409	ANDREY PETROV	{"phone": "+70221965038"}
0005433110083	BDD9B3	2214 141542	VIKTOR VOLKOV	{"email": "volkov_viktor071970@postgrespro.ru", "phone": "+70696419641"}
0005433110084	EB9071	5889 202773	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr-1980@postgrespro.ru", "phone": "+70642807683"}
0005433110085	EB9071	9724 606885	VYACHESLAV ILIN	{"email": "vyacheslav-ilin-061968@postgrespro.ru", "phone": "+70389902383"}
0005433110086	B66028	0310 558411	NATALYA EGOROVA	{"email": "egorova.n_26081979@postgrespro.ru", "phone": "+70713764798"}
0005433110087	1C145C	5769 468974	FAINA IVANOVA	{"email": "ivanova.faina_061966@postgrespro.ru", "phone": "+70330078796"}
0005433110088	670693	8776 128121	ANATOLIY KULIKOV	{"phone": "+70274273064"}
0005433110089	31819B	7625 362299	VIKTOR ANDREEV	{"email": "andreevv16021967@postgrespro.ru", "phone": "+70398694174"}
0005433110090	0154EF	3674 607790	NIKITA SEMENOV	{"email": "n.semenov-081965@postgrespro.ru", "phone": "+70707769846"}
0005433110091	473EAF	4284 526868	VERA MELNIKOVA	{"phone": "+70766891606"}
0005433110092	5AA07E	8017 548918	IGOR SAVELEV	{"phone": "+70951386773"}
0005433110093	5AA07E	7487 898455	TATYANA PAVLOVA	{"phone": "+70296230708"}
0005433110094	789D20	3740 211647	NATALYA ROMANOVA	{"email": "natalya.romanova_021966@postgrespro.ru", "phone": "+70785650800"}
0005433110095	8A71EC	1779 768471	YULIYA POPOVA	{"email": "popova_y-08101966@postgrespro.ru", "phone": "+70649567632"}
0005433110096	278F61	9226 010142	ANZHELA KUZMINA	{"phone": "+70914116607"}
0005433110097	2BBBB3	3735 551770	ELENA IVANOVA	{"email": "ivanovaelena_051977@postgrespro.ru", "phone": "+70622228198"}
0005433110098	A18CAB	3709 463881	NIKOLAY NAZAROV	{"phone": "+70110190668"}
0005433110099	40D6F7	7006 777178	LIDIYA VOLKOVA	{"email": "lidiya-volkova_041967@postgrespro.ru", "phone": "+70795588951"}
0005433110100	83B92B	9073 811943	NADEZHDA SEMENOVA	{"email": "n-semenova-081962@postgrespro.ru", "phone": "+70798869436"}
0005433110101	6857CA	7142 388415	EGOR KUZNECOV	{"phone": "+70208188101"}
0005433110102	13CD1C	8338 083951	OLEG MIKHAYLOV	{"email": "mikhaylov_o_011971@postgrespro.ru", "phone": "+70950502235"}
0005433110103	13CD1C	8076 536915	ALEKSANDR BORISOV	{"email": "aleksandr.borisov.1969@postgrespro.ru", "phone": "+70893229759"}
0005433110104	5432A5	7201 683423	ANNA STEPANOVA	{"phone": "+70844918855"}
0005433110105	C43E9D	7603 698850	MARIYA PAVLOVA	{"email": "pavlova.mariya071962@postgrespro.ru", "phone": "+70142339734"}
0005433110106	4D7425	7580 249158	ARTEM DENISOV	{"phone": "+70992389809"}
0005433110107	4D7425	0959 293872	POLINA VOLKOVA	{"email": "volkova.polina_1969@postgrespro.ru", "phone": "+70843623534"}
0005433110108	206ABC	1531 769710	OLGA POPOVA	{"email": "olgapopova.12111981@postgrespro.ru", "phone": "+70337260916"}
0005433110109	825E39	5661 423815	OLGA ISAEVA	{"phone": "+70469474185"}
0005433110110	C342B5	7206 875466	VALENTINA PAVLOVA	{"phone": "+70950938101"}
0005433110111	C342B5	5865 682760	ZINAIDA GORBUNOVA	{"phone": "+70721384895"}
0005433110112	8B26F8	5042 992899	NIKOLAY POPOV	{"email": "popov_nikolay.1966@postgrespro.ru", "phone": "+70852921609"}
0005433110113	8B26F8	6867 329709	ELIZAVETA KUZNECOVA	{"email": "elizaveta_kuznecova-1964@postgrespro.ru", "phone": "+70195955060"}
0005433110114	B32881	3784 008889	OLEG BARANOV	{"phone": "+70502025459"}
0005433110115	CD3B1B	3381 651068	TATYANA ZAYCEVA	{"email": "t.zayceva.26091964@postgrespro.ru", "phone": "+70621064525"}
0005433110116	5AEC1B	9199 909241	DENIS SIDOROV	{"phone": "+70307475280"}
0005433110117	ACF331	0350 246538	EKATERINA OVCHINNIKOVA	{"email": "ekaterinaovchinnikova_03051970@postgrespro.ru", "phone": "+70665421012"}
0005433110118	12EBB3	6160 732248	SERGEY KAZAKOV	{"email": "kazakov_sergey.26051978@postgrespro.ru", "phone": "+70225447580"}
0005433110119	F31F50	7844 152621	MARIYA SOLOVEVA	{"phone": "+70112658293"}
0005433110120	D4232F	0158 847006	NATALYA KUZMINA	{"phone": "+70974387806"}
0005433110121	644A3D	4531 429711	ALEKSANDR EGOROV	{"email": "aleksandr.egorov061972@postgrespro.ru", "phone": "+70663532777"}
0005433110122	67073F	7189 075653	MARIYA GORBUNOVA	{"phone": "+70975424661"}
0005433110123	A4F60C	9709 849662	MIKHAIL POPOV	{"email": "mikhailpopov1976@postgrespro.ru", "phone": "+70038251387"}
0005433110124	7F7057	7633 219391	EVGENIY SOKOLOV	{"email": "sokolov-e-1962@postgrespro.ru", "phone": "+70753425046"}
0005433110125	11EBA0	4281 434059	VITALIY ROMANOV	{"email": "v-romanov.091974@postgrespro.ru", "phone": "+70612022437"}
0005433110126	11EBA0	9782 619727	NINA KOZLOVA	{"phone": "+70423919124"}
0005433110127	4B651F	6411 655882	VIKTORIYA KONDRATEVA	{"email": "kondrateva-viktoriya-02061974@postgrespro.ru", "phone": "+70457819452"}
0005433110128	4B651F	1271 229534	YULIYA BORISOVA	{"phone": "+70831817521"}
0005433110129	C08B89	9538 295283	GALINA SMIRNOVA	{"email": "g.smirnova_27111965@postgrespro.ru", "phone": "+70278626736"}
0005433110131	D11D50	4844 574911	EKATERINA GUSEVA	{"email": "guseva.ekaterina.13101974@postgrespro.ru", "phone": "+70522399949"}
0005433110132	76DC9D	9733 780859	ZULFIYA VASILEVA	{"email": "zulfiya.vasileva.1974@postgrespro.ru", "phone": "+70096336892"}
0005433110133	E1FAF5	5229 770370	DMITRIY KUZNECOV	{"phone": "+70890850512"}
0005433110134	E1FAF5	6041 302685	VIKTOR ROMANOV	{"phone": "+70435946337"}
0005433110135	F05D05	1978 244826	VERA TIKHONOVA	{"phone": "+70191640476"}
0005433110136	F05D05	1411 102640	ILDAR SCHERBAKOV	{"email": "ischerbakov1985@postgrespro.ru", "phone": "+70578949579"}
0005433110137	762487	9806 736637	MAKSIM MOROZOV	{"email": "morozov.m-1977@postgrespro.ru", "phone": "+70265932440"}
0005433110138	762487	8398 828842	ALEKSANDR KUZNECOV	{"email": "a-kuznecov.1989@postgrespro.ru", "phone": "+70684843712"}
0005433110139	ABFBDC	3838 346091	DMITRIY EGOROV	{"email": "egorov-dmitriy_071977@postgrespro.ru", "phone": "+70369019711"}
0005433110140	A3A89E	0023 043424	YULIYA YAKOVLEVA	{"email": "yakovleva.y-1977@postgrespro.ru", "phone": "+70200651216"}
0005433110141	A3A89E	2340 842123	DANIIL FILIPPOV	{"phone": "+70454692084"}
0005433110142	DDE803	0754 126067	MIKHAIL BELOV	{"phone": "+70861884087"}
0005433110143	DDE803	9216 708705	ANDREY DAVYDOV	{"phone": "+70521851242"}
0005433110144	5A23C2	7244 101059	SERGEY KONOVALOV	{"email": "konovalov-sergey_1964@postgrespro.ru", "phone": "+70862800727"}
0005433110145	885ABA	4116 801482	VLADIMIR ALEKSANDROV	{"email": "aleksandrovv.1968@postgrespro.ru", "phone": "+70173752346"}
0005433110146	A6D3E7	4944 084581	MIKHAIL DMITRIEV	{"phone": "+70961663990"}
0005433110147	E6C5EA	8171 832643	SERGEY TIMOFEEV	{"phone": "+70754890334"}
0005433110148	3CE8AC	7353 822579	ZINAIDA ERMAKOVA	{"phone": "+70783194469"}
0005433110149	3CE8AC	6175 725085	PAVEL NAZAROV	{"phone": "+70232405320"}
0005433110150	CD81C0	5666 506341	EGOR ALEKSANDROV	{"email": "ealeksandrov08091976@postgrespro.ru", "phone": "+70688690803"}
0005433110151	D522F2	3064 329639	SVETLANA ORLOVA	{"email": "orlova-svetlana.09011975@postgrespro.ru", "phone": "+70493061311"}
0005433110152	D522F2	6864 122928	NATALYA NIKOLAEVA	{"phone": "+70554931204"}
0005433110153	226007	0194 808269	LYUDMILA MATVEEVA	{"phone": "+70517416236"}
0005433110154	226007	2476 409292	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_051976@postgrespro.ru", "phone": "+70127346780"}
0005433110155	8FF525	4393 481964	ALEKSANDR PETROV	{"email": "petrov.aleksandr-11101970@postgrespro.ru", "phone": "+70179525891"}
0005433110156	E7E570	2171 843911	MAKSIM NAZAROV	{"phone": "+70390446490"}
0005433110157	E7E570	2798 725921	EKATERINA AFANASEVA	{"email": "ekaterina-afanaseva-031967@postgrespro.ru", "phone": "+70286789985"}
0005433110158	2139B2	1676 914890	LARISA SERGEEVA	{"phone": "+70406978375"}
0005433110159	24DF3A	5695 732234	OLGA GRISHINA	{"email": "grishina_o02121966@postgrespro.ru", "phone": "+70325056339"}
0005433110160	F637B2	6771 927693	MARINA ISAEVA	{"email": "m.isaeva_01011964@postgrespro.ru", "phone": "+70229983712"}
0005433110161	AFC13A	5315 156256	KLAVDIYA FEDOROVA	{"email": "fedorova_k.30041977@postgrespro.ru", "phone": "+70131424232"}
0005433110162	49F768	8993 477306	NIKITA POPOV	{"phone": "+70804326535"}
0005433110163	1605A3	0411 827619	OLGA IVANOVA	{"email": "ivanova.olga_03051978@postgrespro.ru", "phone": "+70424772872"}
0005433110164	177CA1	1075 101008	ALEKSANDRA DENISOVA	{"email": "aleksandradenisova27111976@postgrespro.ru", "phone": "+70574678197"}
0005433110165	F39212	1408 020749	VERA DMITRIEVA	{"phone": "+70059108218"}
0005433110166	E31B55	7393 981099	ALEKSANDRA KOLESNIKOVA	{"email": "kolesnikova.a.28031973@postgrespro.ru", "phone": "+70518078120"}
0005433110167	E31B55	9336 456575	ARTEMIY FROLOV	{"email": "frolova-1968@postgrespro.ru", "phone": "+70992522939"}
0005433110168	78EF55	2446 932851	GALINA ALEKSANDROVA	{"email": "aleksandrova_g.02081970@postgrespro.ru", "phone": "+70013745238"}
0005433110169	78EF55	1465 057978	GALINA MAKAROVA	{"email": "g-makarova_21111965@postgrespro.ru", "phone": "+70126357790"}
0005433110170	055A46	2637 666707	OLGA MAKAROVA	{"email": "makarova.olga-051981@postgrespro.ru", "phone": "+70428628101"}
0005433110171	5C84CB	7912 125331	OLGA TIMOFEEVA	{"email": "olga.timofeeva_101972@postgrespro.ru", "phone": "+70979586802"}
0005433110172	5C84CB	5744 712693	EKATERINA PETROVA	{"phone": "+70917699881"}
0005433110173	5C84CB	5402 350195	MAKSIM MOROZOV	{"phone": "+70194365451"}
0005433110174	85B600	5983 483519	VIKTOR FEDOTOV	{"phone": "+70124347563"}
0005433110175	85B600	3767 729798	OLGA SOKOLOVA	{"email": "sokolova.olga_09091970@postgrespro.ru", "phone": "+70157785302"}
0005433110176	85B600	9952 611869	DANIIL VASILEV	{"email": "vasilev-daniil-1982@postgrespro.ru", "phone": "+70076014036"}
0005433110177	8F22EE	4466 557062	ELENA KUZMINA	{"phone": "+70063000219"}
0005433110178	714058	0779 591649	ANNA IVANOVA	{"email": "a_ivanova_21021964@postgrespro.ru", "phone": "+70731892409"}
0005433110179	714058	2234 938703	OLGA STEPANOVA	{"phone": "+70651369901"}
0005433110180	7F8286	2576 423544	ALEKSANDR SIDOROV	{"email": "sidorov.a.071978@postgrespro.ru", "phone": "+70239504684"}
0005433110181	7F8286	7377 858945	TATYANA YAKOVLEVA	{"email": "yakovleva-tatyana041965@postgrespro.ru", "phone": "+70921185680"}
0005433110182	3F5244	4238 378947	LYUBOV TROFIMOVA	{"phone": "+70356022091"}
0005433110183	3F5244	4432 199878	NIKOLAY MIKHAYLOV	{"email": "nikolay-mikhaylov-041966@postgrespro.ru", "phone": "+70938251624"}
0005433110184	1D5926	6283 397154	SERGEY GERASIMOV	{"email": "sergey.gerasimov_09121975@postgrespro.ru", "phone": "+70014145105"}
0005433110185	EE0727	9575 171066	SERGEY TIMOFEEV	{"email": "timofeev.sergey.10121972@postgrespro.ru", "phone": "+70470048628"}
0005433110186	EE0727	1771 265459	ANATOLIY KOZLOV	{"phone": "+70390200728"}
0005433110187	BC6280	5888 414394	VALENTINA BORISOVA	{"email": "v-borisova-08021982@postgrespro.ru", "phone": "+70382540874"}
0005433110188	BC6280	2601 295870	NADEZHDA ANTONOVA	{"email": "antonova_n-03091973@postgrespro.ru", "phone": "+70316151957"}
0005433110189	BA5F28	4992 444516	VALENTINA SOKOLOVA	{"email": "sokolova-valentina15031972@postgrespro.ru", "phone": "+70861083464"}
0005433110190	AFA59F	0216 864675	PAVEL IVANOV	{"email": "ivanov.p.101972@postgrespro.ru", "phone": "+70649824932"}
0005433110191	5128E6	1918 453428	SERGEY NIKOLAEV	{"phone": "+70913235615"}
0005433110192	70544C	6419 394879	GALINA IVANOVA	{"email": "ivanova-galina.081986@postgrespro.ru", "phone": "+70416232492"}
0005433110193	70544C	6576 496495	DENIS ZAKHAROV	{"phone": "+70740643608"}
0005433110194	70544C	5186 110956	ANDREY PETROV	{"email": "a.petrov_1982@postgrespro.ru", "phone": "+70116882119"}
0005433110195	A79ED5	7128 756641	VALERIYA KUZNECOVA	{"email": "kuznecova.v121974@postgrespro.ru", "phone": "+70699499298"}
0005433110196	35B1AF	8537 513590	ALEKSEY NIKOLAEV	{"phone": "+70412468356"}
0005433110197	18B153	9375 843008	OLGA ZAKHAROVA	{"email": "zakharova-o.081971@postgrespro.ru", "phone": "+70413754663"}
0005433110198	4112E0	3474 910906	GALINA FROLOVA	{"email": "g_frolova20111958@postgrespro.ru", "phone": "+70184766287"}
0005433110199	EA9DF0	2708 284224	SVETLANA GORBUNOVA	{"email": "svetlanagorbunova1972@postgrespro.ru", "phone": "+70796267419"}
0005433110200	EA9DF0	2194 095765	SVETLANA MATVEEVA	{"email": "svetlana-matveeva_1964@postgrespro.ru", "phone": "+70890336269"}
0005433110201	224215	5433 102265	FAINA POPOVA	{"phone": "+70838270711"}
0005433110202	224215	6568 014285	OLGA MAKSIMOVA	{"email": "maksimovao-21081972@postgrespro.ru", "phone": "+70918982695"}
0005433110203	2343A2	6812 339616	ROMAN SERGEEV	{"email": "roman_sergeev-1962@postgrespro.ru", "phone": "+70262869977"}
0005433110204	2343A2	0925 516208	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-v.1979@postgrespro.ru", "phone": "+70494246781"}
0005433110205	6257C4	4288 308124	VALENTINA LUKYANOVA	{"email": "vlukyanova_21101961@postgrespro.ru", "phone": "+70620076084"}
0005433110206	BBA099	3490 289604	LARISA POPOVA	{"phone": "+70197212485"}
0005433110207	2183E6	8411 940836	EKATERINA LEBEDEVA	{"email": "lebedevae1964@postgrespro.ru", "phone": "+70936468582"}
0005433110208	43F60D	9559 540661	ANZHELIKA SOKOLOVA	{"phone": "+70257676885"}
0005433110209	C2EE22	2367 184183	MARFA GERASIMOVA	{"phone": "+70532202663"}
0005433110210	BE07F4	4730 168395	ROMAN STEPANOV	{"email": "roman_stepanov011963@postgrespro.ru", "phone": "+70481220421"}
0005433110211	8A586E	1469 074099	MIKHAIL SHEVCHENKO	{"phone": "+70774846908"}
0005433110212	BE50F1	9541 426069	NADEZHDA MIRONOVA	{"email": "mironova.nadezhda.15071979@postgrespro.ru", "phone": "+70466392320"}
0005433110213	BE50F1	1799 247838	EVGENIY PETROV	{"phone": "+70585190122"}
0005433110214	9E862D	2635 891820	EKATERINA EGOROVA	{"email": "egorova_ekaterina_061979@postgrespro.ru", "phone": "+70406842460"}
0005433110215	F24B9D	0112 871362	KIRILL YAKOVLEV	{"email": "kirill-yakovlev061966@postgrespro.ru", "phone": "+70350227833"}
0005433110216	F24B9D	6652 611407	SERGEY KOZLOV	{"phone": "+70460900089"}
0005433110217	554BF4	2450 199705	ALEKSANDR SMIRNOV	{"email": "smirnov-a051979@postgrespro.ru", "phone": "+70394996519"}
0005433110218	FB0A1A	5874 341634	YULIYA DANILOVA	{"email": "danilova-yuliya-1963@postgrespro.ru", "phone": "+70563754694"}
0005433110219	D0A789	0018 523312	LINAR SOROKIN	{"phone": "+70274049843"}
0005433110220	D0A789	8136 846285	VERA VASILEVA	{"phone": "+70581545357"}
0005433110221	01D1A3	5554 407856	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev.30041984@postgrespro.ru", "phone": "+70119793872"}
0005433110222	9C93AE	9774 439487	SVETLANA NIKITINA	{"phone": "+70568653851"}
0005433110223	A37F7C	9026 455747	IRINA MEDVEDEVA	{"phone": "+70705844976"}
0005433110224	952E0D	5521 499831	ELENA IVANOVA	{"email": "e-ivanova.081967@postgrespro.ru", "phone": "+70804301886"}
0005433110225	BAC5AE	0331 915188	KSENIYA VOLKOVA	{"phone": "+70623142177"}
0005433110226	BAC5AE	9895 065774	ALEKSANDRA ANISIMOVA	{"email": "a.anisimova-26061963@postgrespro.ru", "phone": "+70083779124"}
0005433110227	820E36	8034 914870	ANDREY FEDOROV	{"email": "fedorov-andrey1970@postgrespro.ru", "phone": "+70137726156"}
0005433110228	820E36	3191 576628	NONNA KUZNECOVA	{"email": "nonnakuznecova11091963@postgrespro.ru", "phone": "+70580883223"}
0005433110229	0D3A2D	8263 731974	MARIYA RYABOVA	{"email": "mryabova111975@postgrespro.ru", "phone": "+70927208273"}
0005433110230	A18517	5543 883916	OLEG MELNIKOV	{"phone": "+70569211584"}
0005433110231	550A01	0172 692472	EKATERINA MELNIKOVA	{"email": "melnikova.ekaterina.031984@postgrespro.ru", "phone": "+70382720297"}
0005433110232	037150	9811 581812	PETR STEPANOV	{"phone": "+70117782136"}
0005433110233	4D5A61	3249 167070	ANASTASIYA ZAKHAROVA	{"phone": "+70608941631"}
0005433110234	4D5A61	1525 945735	MIKHAIL KONOVALOV	{"phone": "+70590338260"}
0005433110235	7041CB	0811 674721	ELENA GERASIMOVA	{"email": "egerasimova_03061984@postgrespro.ru", "phone": "+70690409095"}
0005433110236	F9F823	6112 122260	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev.1965@postgrespro.ru", "phone": "+70155254315"}
0005433110237	3BBD27	6386 268588	IRINA MAKAROVA	{"email": "makarovairina-1966@postgrespro.ru", "phone": "+70612544641"}
0005433110238	25AC97	6906 452095	VALERIY SMIRNOV	{"phone": "+70430904997"}
0005433110239	5335E1	9426 096229	NIKOLAY ABRAMOV	{"email": "abramovnikolay-05041971@postgrespro.ru", "phone": "+70218657121"}
0005433110240	8C9359	1600 519896	OKSANA KOZLOVA	{"phone": "+70848022448"}
0005433110241	C1B8F2	4262 389951	DANIS KOROLEV	{"email": "korolev_d_1964@postgrespro.ru", "phone": "+70435621455"}
0005433110242	4D7BBF	7910 562055	MARINA ALEKSANDROVA	{"email": "aleksandrovam041979@postgrespro.ru", "phone": "+70416154652"}
0005433110243	4D7BBF	5500 726067	MARIYA IVANOVA	{"phone": "+70290067378"}
0005433110244	E53EF3	8826 143175	ELENA RYABOVA	{"email": "ryabova.e-121973@postgrespro.ru", "phone": "+70704684646"}
0005433110245	E53EF3	2308 586759	ALEKSANDR VOROBEV	{"email": "vorobev_a041968@postgrespro.ru", "phone": "+70458122555"}
0005433110246	E53EF3	9070 964253	NATALYA MAKSIMOVA	{"phone": "+70085005426"}
0005433110247	34C210	5491 846455	KLAVDIYA LOGINOVA	{"phone": "+70324001916"}
0005433110248	C94010	7705 919524	NURIYA MAKAROVA	{"email": "makarova-nuriya.041983@postgrespro.ru", "phone": "+70522435879"}
0005433110249	A78E8A	7524 605932	IRINA NOVIKOVA	{"phone": "+70568518754"}
0005433110250	2B1DEA	9737 200659	NINA KUZNECOVA	{"email": "kuznecova-nina1968@postgrespro.ru", "phone": "+70316124484"}
0005433110251	5E4201	7123 721959	VASILIY EGOROV	{"phone": "+70262806687"}
0005433110252	5E4201	0488 975526	DANILA PETROV	{"email": "petrov.danila-091963@postgrespro.ru", "phone": "+70952400360"}
0005433110253	1BE54D	5637 015227	NATALYA VLASOVA	{"email": "vlasova.n021973@postgrespro.ru", "phone": "+70215863156"}
0005433110254	1BE54D	4901 106428	VALENTINA YAKOVLEVA	{"email": "yakovlevavalentina23011976@postgrespro.ru", "phone": "+70388013950"}
0005433110255	FBA0DB	1442 276869	YULIYA SIDOROVA	{"email": "sidorova-yuliya-07061966@postgrespro.ru", "phone": "+70715927772"}
0005433110256	B619D0	0445 776257	TATYANA KUZNECOVA	{"phone": "+70974602703"}
0005433110257	B619D0	8846 815146	VALERIY SOROKIN	{"email": "valeriysorokin08071985@postgrespro.ru", "phone": "+70258041874"}
0005433110258	075ED1	3674 115678	SERGEY PAVLOV	{"phone": "+70942678373"}
0005433110259	4A215D	4159 458771	MAKSIM MAKAROV	{"email": "maksim-makarov-1980@postgrespro.ru", "phone": "+70948298588"}
0005433110260	9FD9D1	9000 322084	NATALYA KUZNECOVA	{"phone": "+70056105256"}
0005433110261	9FD9D1	3934 657894	GALINA IVANOVA	{"phone": "+70194632956"}
0005433110262	7C7456	3956 547800	EGOR POPOV	{"email": "popove.111974@postgrespro.ru", "phone": "+70224077412"}
0005433110263	7C7456	8230 984314	NATALIYA KUZMINA	{"phone": "+70724409858"}
0005433110264	9BD80D	6330 120355	GENNADIY SOROKIN	{"email": "gennadiy-sorokin.011973@postgrespro.ru", "phone": "+70219009169"}
0005433110265	898F41	1958 165872	SERGEY MELNIKOV	{"phone": "+70725670172"}
0005433110266	898F41	9898 894500	LYUBOV VOLKOVA	{"email": "volkova_lyubov.071970@postgrespro.ru", "phone": "+70382048888"}
0005433110267	898F41	4466 341884	ANASTASIYA LUKYANOVA	{"phone": "+70775648056"}
0005433110268	443805	4729 564941	RUSLAN GRIGOREV	{"email": "ruslangrigorev-08121976@postgrespro.ru", "phone": "+70372923007"}
0005433110269	443805	8277 326632	OLGA NAUMOVA	{"phone": "+70938778739"}
0005433110270	BA75EE	6297 738113	ANNA SCHERBAKOVA	{"phone": "+70447424896"}
0005433110271	0E4961	5356 838709	POLINA SCHERBAKOVA	{"email": "scherbakovapolina_1962@postgrespro.ru", "phone": "+70709882499"}
0005433110272	5BDEB9	6490 532502	ALEKSEY DAVYDOV	{"email": "davydov_a_091973@postgrespro.ru", "phone": "+70191704629"}
0005433110273	D3A740	8613 900724	ZOYA VASILEVA	{"phone": "+70368117818"}
0005433110274	D3A740	0165 226396	VIKTOR SOKOLOV	{"email": "sokolovviktor_1978@postgrespro.ru", "phone": "+70441468918"}
0005433110275	65BC91	2110 762916	KONSTANTIN CHERNOV	{"email": "chernov.konstantin-1967@postgrespro.ru", "phone": "+70657860773"}
0005433110276	D16FB7	6579 708449	VLADIMIR YAKOVLEV	{"phone": "+70837956574"}
0005433110277	0378AF	6295 412174	KSENIYA IVANOVA	{"phone": "+70626638490"}
0005433110278	AD3677	3582 071089	VIKTOR KUDRYASHOV	{"email": "v_kudryashov-061978@postgrespro.ru", "phone": "+70905492716"}
0005433110279	AD3677	5586 532425	MARIYA YAKOVLEVA	{"phone": "+70058342991"}
0005433110280	365F50	8735 513752	ANTON SERGEEV	{"phone": "+70555577032"}
0005433110281	3C1763	3587 840245	NINA ZAYCEVA	{"phone": "+70240780724"}
0005433110282	3C1763	7278 939450	LIDIYA LAZAREVA	{"email": "lidiya.lazareva.041970@postgrespro.ru", "phone": "+70928695258"}
0005433110283	014F9A	4466 595331	NIKITA KISELEV	{"email": "kiselev.n21101978@postgrespro.ru", "phone": "+70108338192"}
0005433110284	317CB6	8158 766564	MARYAM VASILEVA	{"email": "m-vasileva-1984@postgrespro.ru", "phone": "+70367477576"}
0005433110285	D9ED68	9981 802302	DMITRIY OSIPOV	{"phone": "+70500779714"}
0005433110286	D9ED68	3688 870380	IRINA SAVELEVA	{"email": "saveleva.i_1972@postgrespro.ru", "phone": "+70991673686"}
0005433110287	0DEC3E	8949 429911	BORIS ABRAMOV	{"phone": "+70027688009"}
0005433110288	0DEC3E	2499 142576	DARYA CHERNOVA	{"phone": "+70792949105"}
0005433110289	E650E4	3788 966783	TATYANA FEDOROVA	{"email": "tatyana_fedorova_06081974@postgrespro.ru", "phone": "+70842413508"}
0005433110290	B5B475	4322 851368	RITA KOROLEVA	{"phone": "+70580902051"}
0005433110291	B5B475	6199 927129	ALEKSANDR SMIRNOV	{"email": "a_smirnov.101969@postgrespro.ru", "phone": "+70290871207"}
0005433110292	862C21	0571 549790	YULIYA OSIPOVA	{"email": "osipova.yuliya_031988@postgrespro.ru", "phone": "+70457431045"}
0005433110293	E5908C	3796 328469	ANDREY CHERNOV	{"phone": "+70598732213"}
0005433110294	D85D83	9396 545046	VERA DAVYDOVA	{"email": "davydovavera-22051980@postgrespro.ru", "phone": "+70807719378"}
0005433110295	CA6AEA	9240 185662	GALINA KONOVALOVA	{"email": "konovalova.g.10051979@postgrespro.ru", "phone": "+70452723286"}
0005433110296	CA6AEA	8289 561882	ANNA MASLOVA	{"phone": "+70623259563"}
0005433110297	3FC3FB	3505 834683	ANATOLIY DENISOV	{"phone": "+70496868776"}
0005433110298	CBD2B3	2529 143774	NIKOLAY MELNIKOV	{"phone": "+70430552890"}
0005433110299	CBD2B3	1065 485350	VIKTOR KOZLOV	{"email": "kozlov.viktor.061967@postgrespro.ru", "phone": "+70651249127"}
0005433110300	88B981	9013 659066	EVGENIY GAVRILOV	{"email": "e-gavrilov02051972@postgrespro.ru", "phone": "+70181365924"}
0005433110301	26B00B	5368 587053	VLADIMIR SCHERBAKOV	{"phone": "+70908549871"}
0005433110302	F0B115	0213 361447	ANTONINA ANTONOVA	{"phone": "+70464455047"}
0005433110303	9FDC1D	9254 390508	SVETLANA KOVALEVA	{"phone": "+70114062016"}
0005433110304	35B97C	6531 810073	YULIYA MALYSHEVA	{"phone": "+70979088469"}
0005433110305	241C40	0370 244736	YURIY SMIRNOV	{"email": "smirnov.y.28051981@postgrespro.ru", "phone": "+70254977096"}
0005433110306	482B07	4639 969724	TATYANA ORLOVA	{"email": "tatyanaorlova.081984@postgrespro.ru", "phone": "+70843179370"}
0005433110307	F4245C	1357 681473	ALEKSANDR FROLOV	{"phone": "+70642505655"}
0005433110308	D8BC3D	9627 407167	SERGEY SCHERBAKOV	{"phone": "+70939194018"}
0005433110309	822856	1713 523493	VALENTINA KARPOVA	{"email": "karpova_v.011971@postgrespro.ru", "phone": "+70922549796"}
0005433110310	A69D5D	4887 321076	VALERIY AFANASEV	{"phone": "+70452788022"}
0005433110311	43CE99	9166 197164	EKATERINA STEPANOVA	{"phone": "+70967674674"}
0005433110312	DFB2B5	3567 785490	IGOR STEPANOV	{"email": "stepanov-i091969@postgrespro.ru", "phone": "+70182407446"}
0005433110313	4BC2E1	8102 210478	TIMUR VASILEV	{"phone": "+70447155973"}
0005433110314	6F2D10	1314 421190	INNA VOLKOVA	{"phone": "+70633258136"}
0005433110315	6F2D10	5177 440652	ANTONINA ZAKHAROVA	{"phone": "+70046961842"}
0005433110316	8D5D8F	0305 895305	ANTON PAVLOV	{"phone": "+70269780525"}
0005433110317	8D5D8F	2403 543306	ALEKSANDR PAVLOV	{"email": "a_pavlov.101964@postgrespro.ru", "phone": "+70070208715"}
0005433110318	7F2625	5321 373600	GALINA KOROLEVA	{"phone": "+70551740109"}
0005433110319	05476B	3210 754042	EKATERINA KUDRYASHOVA	{"email": "ekaterina-kudryashova_101971@postgrespro.ru", "phone": "+70006105601"}
0005433110320	05476B	6369 976509	ELIZAVETA SOROKINA	{"email": "sorokina.e-11041972@postgrespro.ru", "phone": "+70803064502"}
0005433110321	333C4C	6311 650109	MIKHAIL PETROV	{"phone": "+70157663255"}
0005433110322	333C4C	0829 945161	OLGA PETROVA	{"email": "olga_petrova.10011982@postgrespro.ru", "phone": "+70359051448"}
0005433110323	6C0DFD	8499 700288	VALERIYA IVANOVA	{"email": "ivanova_valeriya_021976@postgrespro.ru", "phone": "+70164231585"}
0005433110324	6C0DFD	5685 663256	SERGEY BORISOV	{"phone": "+70581812130"}
0005433110325	C5F741	8044 408877	ALEKSANDR DAVYDOV	{"email": "a-davydov_09121966@postgrespro.ru", "phone": "+70291671643"}
0005433110326	C5F741	5355 292281	VIKTORIYA KUZMINA	{"email": "v_kuzmina08021974@postgrespro.ru", "phone": "+70627502851"}
0005433110327	F4023C	1638 768001	ANDREY IVANOV	{"phone": "+70968866974"}
0005433110328	F4023C	5289 255441	PETR MATVEEV	{"email": "petrmatveev.1976@postgrespro.ru", "phone": "+70137262226"}
0005433110329	35A01A	5053 782058	ANDREY POPOV	{"email": "popov-a-14041965@postgrespro.ru", "phone": "+70781655237"}
0005433110330	35A01A	9433 205722	DMITRIY KUZMIN	{"email": "kuzmin_d.1969@postgrespro.ru", "phone": "+70271459930"}
0005433110331	35A01A	3998 797905	ANDREY BELOV	{"phone": "+70909873871"}
0005433110332	FD542D	0039 859056	MARINA PAVLOVA	{"email": "pavlova_m17111979@postgrespro.ru", "phone": "+70916069599"}
0005433110333	FD542D	2584 074135	RAVIL MIKHAYLOV	{"email": "mikhaylovravil-30061978@postgrespro.ru", "phone": "+70301289084"}
0005433110334	97D8C8	8477 875869	GALINA SOLOVEVA	{"phone": "+70875300874"}
0005433110335	97D8C8	5257 430628	LYUBOV EGOROVA	{"email": "lyubovegorova.081969@postgrespro.ru", "phone": "+70732235409"}
0005433110336	712E37	0999 568843	SERGEY SAVELEV	{"email": "savelev-sergey_071978@postgrespro.ru", "phone": "+70552138963"}
0005433110337	1BB03C	4366 935995	SERGEY KISELEV	{"phone": "+70415499189"}
0005433110338	55582D	0331 698165	ANNA MOISEEVA	{"email": "anna.moiseeva091975@postgrespro.ru", "phone": "+70503026777"}
0005433110339	FEEB7D	9965 389153	KSENIYA NESTEROVA	{"email": "k_nesterova.1963@postgrespro.ru", "phone": "+70177683068"}
0005433110340	5BB7E8	0638 854147	ANDREY SEMENOV	{"phone": "+70820847715"}
0005433110341	0A19A1	3989 791448	SVETLANA LEBEDEVA	{"email": "svetlana-lebedeva-071968@postgrespro.ru", "phone": "+70610470188"}
0005433110342	0A19A1	2053 863235	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr-1966@postgrespro.ru", "phone": "+70105779918"}
0005433110343	E042E3	4209 810674	ANNA KONOVALOVA	{"email": "konovalova-anna.17081975@postgrespro.ru", "phone": "+70411410385"}
0005433110344	E042E3	2350 612633	ALEKSANDR BORISOV	{"email": "aborisov_24071977@postgrespro.ru", "phone": "+70400186760"}
0005433110345	E042E3	9134 424822	SERGEY SEMENOV	{"phone": "+70002656681"}
0005433110346	0C0A28	5694 556719	FARIT KOROLEV	{"phone": "+70536763524"}
0005433110347	D15946	6906 759058	NADEZHDA MASLOVA	{"phone": "+70906743377"}
0005433110348	D15946	1553 772555	VALERIYA ANISIMOVA	{"email": "vanisimova.091979@postgrespro.ru", "phone": "+70201881661"}
0005433110349	53F4BB	5318 175004	LILIYA ILINA	{"phone": "+70926657665"}
0005433110350	7AE5AC	8638 579793	PAVEL VASILEV	{"phone": "+70219777122"}
0005433110351	7B4BE8	3493 884547	VLADIMIR STEPANOV	{"phone": "+70953308878"}
0005433110352	7B4BE8	4757 424249	SEMEN MAKSIMOV	{"phone": "+70325933336"}
0005433110353	2A44FB	9965 543841	YULIYA KAZAKOVA	{"email": "yuliya_kazakova041967@postgrespro.ru", "phone": "+70442588334"}
0005433110354	F311BE	5512 158034	MAKSIM MATVEEV	{"phone": "+70499616533"}
0005433110355	F311BE	2785 521845	VLADIMIR PETROV	{"email": "v-petrov.1983@postgrespro.ru", "phone": "+70102714004"}
0005433110356	E61F3F	4503 112986	ALEKSEY RODIONOV	{"email": "aleksey_rodionov1963@postgrespro.ru", "phone": "+70936769572"}
0005433110357	B2D10B	1252 006081	ALEKSEY VASILEV	{"email": "aleksey-vasilev.09121968@postgrespro.ru", "phone": "+70728299521"}
0005433110358	70B3FA	5921 963244	NATALYA POPOVA	{"phone": "+70517477028"}
0005433110359	DCF752	8618 885141	BORIS PAVLOV	{"email": "pavlov_b091977@postgrespro.ru", "phone": "+70049170628"}
0005433110360	DCF752	9866 876626	SVETLANA KOZLOVA	{"phone": "+70468647612"}
0005433110361	DCF752	7280 810723	EKATERINA KOROLEVA	{"email": "ekaterina_koroleva1957@postgrespro.ru", "phone": "+70282610503"}
0005433110362	DCF752	6416 130706	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova-13061977@postgrespro.ru", "phone": "+70962157347"}
0005433110363	B29A8A	0749 944464	SERGEY PAVLOV	{"email": "pavlovs_11081974@postgrespro.ru", "phone": "+70211626021"}
0005433110364	B29A8A	2426 597838	ALEKSANDR FEDOTOV	{"email": "fedotov-aleksandr051969@postgrespro.ru", "phone": "+70958804447"}
0005433110365	DB5089	1074 390941	MARIYA KOLESNIKOVA	{"phone": "+70416566177"}
0005433110366	00F7ED	6903 469208	YURIY KOZLOV	{"email": "ykozlov.1959@postgrespro.ru", "phone": "+70444724212"}
0005433110367	04B23A	2199 423787	VIKTOR GUSEV	{"email": "viktor.gusev_081978@postgrespro.ru", "phone": "+70162714407"}
0005433110368	C2AE66	0262 917251	ANASTASIYA SIDOROVA	{"phone": "+70228523146"}
0005433110369	C21A0E	2606 688022	EKATERINA MALYSHEVA	{"email": "e-malysheva.1967@postgrespro.ru", "phone": "+70895372806"}
0005433110370	9A65C6	7076 802831	IRINA NOVIKOVA	{"phone": "+70352778072"}
0005433110371	F95ED4	4350 895063	PAVEL KUZNECOV	{"email": "p-kuznecov09071961@postgrespro.ru", "phone": "+70867424702"}
0005433110372	336A37	1905 739905	OLESYA RYABOVA	{"email": "oryabova20111969@postgrespro.ru", "phone": "+70612799669"}
0005433110373	E016B2	2177 040525	ELENA AFANASEVA	{"email": "afanasevae_081980@postgrespro.ru", "phone": "+70813088029"}
0005433110374	CA5B95	9410 280187	TATYANA FILATOVA	{"phone": "+70189532652"}
0005433110375	D1483E	9778 890766	DARYA ANISIMOVA	{"phone": "+70563272216"}
0005433110376	14A33D	6095 589723	ZOYA POLYAKOVA	{"phone": "+70986799515"}
0005433110377	14A33D	2591 556552	ELENA GERASIMOVA	{"phone": "+70610696552"}
0005433110378	7F66AE	6030 608976	EVGENIY GUSEV	{"email": "gusev.e-02121970@postgrespro.ru", "phone": "+70631206382"}
0005433110379	7F66AE	3801 899248	VLADISLAV BONDARENKO	{"email": "vladislav.bondarenko_1973@postgrespro.ru", "phone": "+70342392042"}
0005433110380	51B05D	6300 479499	MAKSIM SIDOROV	{"phone": "+70542518767"}
0005433110381	E308A4	7194 886353	ALEKSEY POPOV	{"phone": "+70150027574"}
0005433110382	4D58DB	0504 116703	ANTONINA KOVALEVA	{"email": "kovaleva.antonina-15091968@postgrespro.ru", "phone": "+70000462309"}
0005433110383	F6D589	4739 644055	RIMMA EFIMOVA	{"email": "efimova_rimma111981@postgrespro.ru", "phone": "+70729321347"}
0005433110384	B87531	2050 097307	ARTEM KOROLEV	{"phone": "+70042361803"}
0005433110385	A31050	9924 909301	LYUDMILA GUSEVA	{"email": "lguseva.1971@postgrespro.ru", "phone": "+70439859150"}
0005433110386	6687F0	3420 116433	VALENTINA ZOTOVA	{"phone": "+70956847741"}
0005433110387	73A562	5035 569708	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.051989@postgrespro.ru", "phone": "+70171479897"}
0005433110388	67267C	4330 115787	ANASTASIYA TIMOFEEVA	{"phone": "+70094739271"}
0005433110389	0C6D96	5113 485518	SERGEY FOMIN	{"email": "s.fomin.071956@postgrespro.ru", "phone": "+70654597460"}
0005433110390	3ADDD1	5143 598371	DMITRIY IVANOV	{"email": "ivanovdmitriy121965@postgrespro.ru", "phone": "+70427422708"}
0005433110391	3CBB5B	9789 585075	VLADIMIR SIDOROV	{"phone": "+70074350258"}
0005433110392	12BC8A	4685 602625	ALEKSANDR NAUMOV	{"phone": "+70810326015"}
0005433110393	A9672C	3193 146349	TATYANA NOVIKOVA	{"email": "tatyananovikova051974@postgrespro.ru", "phone": "+70536421118"}
0005433110394	A9672C	7200 714704	ELENA STEPANOVA	{"email": "stepanova.elena1967@postgrespro.ru", "phone": "+70132457974"}
0005433110395	06F0BE	2835 097987	LARISA MIKHAYLOVA	{"phone": "+70777642146"}
0005433110396	06F0BE	1749 002152	SVETLANA ORLOVA	{"email": "orlova-s-14071968@postgrespro.ru", "phone": "+70329023813"}
0005433111467	9AD26F	4737 518683	EVGENIY MOISEEV	{"phone": "+70274214592"}
0005433111468	237233	9682 921538	PAVEL BONDARENKO	{"email": "pavel-bondarenko-27101972@postgrespro.ru", "phone": "+70705793170"}
0005433111469	237233	3054 311966	VALENTINA KALININA	{"email": "v_kalinina_1968@postgrespro.ru", "phone": "+70898087746"}
0005433111470	98AC90	0268 164739	SOFYA KALININA	{"email": "s-kalinina_081971@postgrespro.ru", "phone": "+70182135000"}
0005433111471	F517D8	6982 958248	DANILA PETROV	{"phone": "+70659764176"}
0005433111472	4A0894	8124 824581	SERGEY VOLKOV	{"email": "volkovsergey_10041979@postgrespro.ru", "phone": "+70790770738"}
0005433111473	DC5DBA	1426 691635	VLADIMIR SOKOLOV	{"email": "sokolov.v_1969@postgrespro.ru", "phone": "+70716318370"}
0005433111474	8D2649	2320 388696	OKSANA TIKHONOVA	{"email": "oksana-tikhonova.1980@postgrespro.ru", "phone": "+70120572684"}
0005433111475	8D2649	5244 155856	MARIYA EGOROVA	{"email": "egorovam-28071980@postgrespro.ru", "phone": "+70827225367"}
0005433111476	611446	3087 374451	VALENTINA POPOVA	{"phone": "+70299602800"}
0005433111477	611446	3547 737893	MARIYA NAZAROVA	{"email": "nazarova-m.101976@postgrespro.ru", "phone": "+70014092707"}
0005433111478	611446	4916 277352	ALEKSANDR GERASIMOV	{"phone": "+70318902585"}
0005433111479	14212D	5397 102487	OLGA MOISEEVA	{"phone": "+70662955719"}
0005433111480	14212D	9115 685207	GENNADIY KUZNECOV	{"phone": "+70416531829"}
0005433111481	E65C80	4362 189633	ALEKSEY SERGEEV	{"phone": "+70868912110"}
0005433111482	977EA9	0028 100023	ANDREY KUZNECOV	{"email": "andrey-kuznecov_24101982@postgrespro.ru", "phone": "+70984405071"}
0005433111483	DA13BD	2288 923255	ANASTASIYA TIMOFEEVA	{"phone": "+70332237314"}
0005433111484	DA13BD	0765 309766	EMIL SOROKIN	{"phone": "+70378995595"}
0005433111485	E7278E	0997 310376	ARTEM ANDREEV	{"email": "andreev_a-1980@postgrespro.ru", "phone": "+70931757366"}
0005433111486	21612C	7854 396930	IGOR NOVIKOV	{"email": "novikov.igor1966@postgrespro.ru", "phone": "+70411343831"}
0005433111487	21612C	3017 233887	ELENA FILATOVA	{"phone": "+70138548342"}
0005433111488	21612C	9935 429627	LARISA STEPANOVA	{"phone": "+70878580216"}
0005433111489	40167D	8786 525504	PAVEL SOROKIN	{"email": "p.sorokin.1966@postgrespro.ru", "phone": "+70443359867"}
0005433111490	296832	5162 022665	VIKTORIYA ALEKSANDROVA	{"phone": "+70897425398"}
0005433111491	76D33F	2219 922224	LYUDMILA VOLKOVA	{"phone": "+70580553117"}
0005433111492	1B8614	4262 785232	NIKOLAY TARASOV	{"email": "tarasovn.041958@postgrespro.ru", "phone": "+70597226717"}
0005433111493	1B8614	8117 764203	VERA KARPOVA	{"email": "v-karpova_1965@postgrespro.ru", "phone": "+70700764362"}
0005433111494	1B8614	3717 821143	MIKHAIL ANDREEV	{"phone": "+70774478004"}
0005433111495	1B8614	0505 274318	ZOYA KOVALEVA	{"email": "kovaleva_zoya19011976@postgrespro.ru", "phone": "+70112931989"}
0005433111496	A520A2	0597 832944	ADELINA SMIRNOVA	{"email": "smirnova-adelina071968@postgrespro.ru", "phone": "+70847254398"}
0005433111497	6F33C3	3147 992309	ARTEM FEDOTOV	{"phone": "+70943572359"}
0005433111498	C8689D	1777 807740	ANDREY KAZAKOV	{"email": "kazakov-a-1972@postgrespro.ru", "phone": "+70365383893"}
0005433111499	5E5284	8689 333256	ANZHELIKA KUZNECOVA	{"phone": "+70520104816"}
0005433111500	7BC401	5356 859086	NIKITA ABRAMOV	{"phone": "+70241108039"}
0005433111501	7BC401	6802 047226	ALBINA ERMAKOVA	{"phone": "+70779967473"}
0005433111502	B18BC4	1100 797825	ALEKSEY KOZLOV	{"phone": "+70545871725"}
0005433111503	36D15D	5140 477299	NIKOLAY BORISOV	{"email": "n-borisov.1969@postgrespro.ru", "phone": "+70791880443"}
0005433111504	83277A	8649 534766	VADIM NIKITIN	{"phone": "+70008966664"}
0005433111505	FBC807	2854 362681	VALENTINA VASILEVA	{"phone": "+70671368048"}
0005433111506	AB0CCF	3524 398400	MARINA MOISEEVA	{"phone": "+70958040908"}
0005433111507	FD039F	5139 937218	YULIYA VASILEVA	{"email": "yuliya.vasileva.11051966@postgrespro.ru", "phone": "+70869938247"}
0005433111508	3A72E9	2259 682032	YULIYA BOGDANOVA	{"email": "y.bogdanova-1958@postgrespro.ru", "phone": "+70490284661"}
0005433111509	3A72E9	6397 427695	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n_031974@postgrespro.ru", "phone": "+70916735179"}
0005433111510	F0A780	3728 682359	LYUDMILA SAVELEVA	{"phone": "+70450507687"}
0005433111511	E27F28	1665 444708	ELENA PETROVA	{"phone": "+70403878188"}
0005433111512	DDAC15	4795 908272	MIKHAIL KOZLOV	{"email": "kozlov-mikhail.20021971@postgrespro.ru", "phone": "+70482879909"}
0005433111513	FCAE3D	3005 015899	NATALYA KULIKOVA	{"phone": "+70111394247"}
0005433111514	CD4AA9	4472 131914	ALEKSANDR IVANOV	{"email": "ivanov.a_1965@postgrespro.ru", "phone": "+70347642013"}
0005433111515	31B5C9	6433 371035	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova.121970@postgrespro.ru", "phone": "+70366115488"}
0005433111516	31B5C9	6865 127897	RUSTAM KUZNECOV	{"email": "kuznecov_rustam-1972@postgrespro.ru", "phone": "+70683971869"}
0005433111517	A3D251	8658 901465	YULIYA SCHERBAKOVA	{"email": "scherbakova-y.061968@postgrespro.ru", "phone": "+70257466030"}
0005433111518	DD33BB	2825 931559	NATALYA MAKAROVA	{"email": "nmakarova.061974@postgrespro.ru", "phone": "+70244749571"}
0005433111519	DD33BB	4036 762655	OLEG BORISOV	{"phone": "+70896028802"}
0005433111520	3284A6	6144 062425	KLAVDIYA VOLKOVA	{"phone": "+70732348536"}
0005433111521	1A111A	1067 572870	VLADIMIR VOROBEV	{"email": "vorobevv-25041972@postgrespro.ru", "phone": "+70105940030"}
0005433111522	1A111A	3810 538171	SERGEY DAVYDOV	{"phone": "+70084078578"}
0005433111523	1A111A	6477 302276	VLADIMIR FILIPPOV	{"email": "vladimir.filippov_29101964@postgrespro.ru", "phone": "+70792757965"}
0005433111524	86037D	3938 750973	DMITRIY SOROKIN	{"phone": "+70381837143"}
0005433111525	52AD7A	0696 428442	OLEG MAKSIMOV	{"phone": "+70081050304"}
0005433111526	460BE8	9565 596787	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova10101965@postgrespro.ru", "phone": "+70610557527"}
0005433111527	9EB213	3171 348850	VASILIY IVANOV	{"phone": "+70050810584"}
0005433111528	FFFC22	1675 636853	IGOR SEMENOV	{"email": "semenov_igor10051968@postgrespro.ru", "phone": "+70675309648"}
0005433111529	FFFC22	7211 498713	NATALYA DENISOVA	{"phone": "+70577714055"}
0005433111530	A24899	7672 085260	PAVEL DENISOV	{"phone": "+70328900981"}
0005433111531	A72542	9536 406128	NADEZHDA OSIPOVA	{"email": "osipova-nadezhda_06101966@postgrespro.ru", "phone": "+70791863637"}
0005433111532	B1DE35	6943 340542	ALEKSEY SMIRNOV	{"email": "smirnov.a14051972@postgrespro.ru", "phone": "+70438536923"}
0005433111533	88E213	0013 975976	YURIY MIKHAYLOV	{"email": "yuriy_mikhaylov-071969@postgrespro.ru", "phone": "+70834298226"}
0005433111534	88E213	8582 311365	ANZHELA YAKOVLEVA	{"phone": "+70167320200"}
0005433111535	11C7F4	7488 618589	VASILIY KUZNECOV	{"email": "vasiliy-kuznecov-1980@postgrespro.ru", "phone": "+70972671121"}
0005433111536	64EE20	4322 211857	SVETLANA KOROLEVA	{"email": "s-koroleva.17021969@postgrespro.ru", "phone": "+70900660712"}
0005433111537	348C84	0671 605904	ALEKSANDR NAZAROV	{"email": "a.nazarov_051966@postgrespro.ru", "phone": "+70867326522"}
0005433111538	348C84	3754 964420	ALEKSANDR KOROLEV	{"email": "aleksandr_korolev-1966@postgrespro.ru", "phone": "+70863626268"}
0005433111539	E300AB	1935 495265	ILDAR BELOV	{"phone": "+70429074104"}
0005433111540	FA2B57	2200 178339	SVETLANA KUZNECOVA	{"phone": "+70382702233"}
0005433111541	7338AC	8036 996704	VLADIMIR KUDRYASHOV	{"email": "kudryashov-vladimir051973@postgrespro.ru", "phone": "+70875115693"}
0005433111542	7338AC	2235 203695	INNA MOISEEVA	{"phone": "+70913540137"}
0005433111543	441C96	5432 808192	VIKTOR KOZLOV	{"phone": "+70800802038"}
0005433111544	58E8AA	3271 922416	ANATOLIY DENISOV	{"phone": "+70208893571"}
0005433111545	EC46E9	5371 989999	VALENTINA KOROLEVA	{"email": "koroleva-v-031980@postgrespro.ru", "phone": "+70408111582"}
0005433111546	EC46E9	0321 763894	TATYANA FEDOROVA	{"phone": "+70329001661"}
0005433111547	6E02DD	0566 800319	ALEKSANDRA YAKOVLEVA	{"email": "aleksandrayakovleva_1973@postgrespro.ru", "phone": "+70810783333"}
0005433111548	6E02DD	5028 051548	ANATOLIY MELNIKOV	{"phone": "+70844829907"}
0005433111549	9CDFFF	2358 626080	MARINA SOLOVEVA	{"email": "m.soloveva.03121970@postgrespro.ru", "phone": "+70065364279"}
0005433111550	9CDFFF	2540 533829	DANIIL MAKAROV	{"phone": "+70060272573"}
0005433111551	1C5B2C	8871 650397	ALEKSEY MOROZOV	{"email": "aleksey-morozov.08031969@postgrespro.ru", "phone": "+70389744107"}
0005433111552	C408DC	4838 011752	EVGENIYA RODIONOVA	{"phone": "+70314067805"}
0005433111553	C408DC	6427 331462	DMITRIY NIKITIN	{"email": "dmitriy-nikitin-1968@postgrespro.ru", "phone": "+70413369829"}
0005433111554	1EB3D1	0419 518632	KSENIYA FROLOVA	{"email": "kfrolova_1976@postgrespro.ru", "phone": "+70424081257"}
0005433111555	457951	0583 168959	RINAT VOLKOV	{"email": "rinat_volkov031973@postgrespro.ru", "phone": "+70524676726"}
0005433111556	56EFF1	0776 874082	TATYANA STEPANOVA	{"phone": "+70833863517"}
0005433111557	56EFF1	0627 509026	NIKOLAY KUZNECOV	{"phone": "+70581975393"}
0005433111558	1F4247	7180 033333	SERGEY GERASIMOV	{"email": "sgerasimov-031965@postgrespro.ru", "phone": "+70529599760"}
0005433111559	ACB289	4427 896643	LYUBOV ISAEVA	{"email": "lyubovisaeva.12111981@postgrespro.ru", "phone": "+70150232857"}
0005433111560	B3EB49	0333 952091	ELENA OVCHINNIKOVA	{"phone": "+70234008946"}
0005433111561	B3EB49	3898 456339	VALENTINA IVANOVA	{"email": "valentina_ivanova.011964@postgrespro.ru", "phone": "+70200150055"}
0005433111562	50497A	1714 018521	ALEKSANDR KUZNECOV	{"phone": "+70981463888"}
0005433111563	50497A	1673 607717	OLGA GORBUNOVA	{"email": "gorbunova_o-23051969@postgrespro.ru", "phone": "+70622019472"}
0005433111564	963557	0110 208421	ALEKSANDR MARTYNOV	{"phone": "+70269786135"}
0005433111565	5B2482	0637 671307	ALEKSANDR NAZAROV	{"phone": "+70463252660"}
0005433111566	5B2482	4190 151524	NIKOLAY KUZNECOV	{"phone": "+70223335513"}
0005433111567	C96192	3407 963867	YULIYA NESTEROVA	{"phone": "+70583494321"}
0005433111568	521C31	8165 080373	KIRILL SOKOLOV	{"email": "k-sokolov-051964@postgrespro.ru", "phone": "+70016017918"}
0005433112350	01206A	7367 948524	GALINA MARTYNOVA	{"email": "g.martynova-091971@postgrespro.ru", "phone": "+70843772949"}
0005433112351	4E7680	4830 503313	TATYANA ABRAMOVA	{"phone": "+70640950028"}
0005433112352	4E7680	7193 882119	ZHANNA EFIMOVA	{"email": "efimova_z-04101971@postgrespro.ru", "phone": "+70868625829"}
0005433112353	7AD2C6	8212 775534	VALENTINA KOROLEVA	{"email": "vkoroleva11021971@postgrespro.ru", "phone": "+70590062227"}
0005433112354	6190DF	8485 400248	ELZA IVANOVA	{"phone": "+70907234627"}
0005433112355	43D748	3833 315560	DARYA MIKHAYLOVA	{"phone": "+70957105130"}
0005433112356	55696F	9291 432220	MARINA VLASOVA	{"email": "marinavlasova.051965@postgrespro.ru", "phone": "+70503908048"}
0005433112357	DBAEE1	9515 172296	SVETLANA ROMANOVA	{"email": "sromanova-1973@postgrespro.ru", "phone": "+70520051791"}
0005433112358	7FEC99	9960 873426	SVETLANA MELNIKOVA	{"phone": "+70676332937"}
0005433112359	270230	5499 604388	SVETLANA KRASNOVA	{"phone": "+70358063628"}
0005433112360	09E73C	8619 769802	ILYA KRASNOV	{"phone": "+70498563350"}
0005433112361	09E73C	5199 444762	STANISLAV PETROV	{"email": "petrov_s-13011973@postgrespro.ru", "phone": "+70447738113"}
0005433112362	8F5B8C	6512 387918	NATALYA YAKOVLEVA	{"email": "yakovlevan_111978@postgrespro.ru", "phone": "+70850483113"}
0005433112363	6BEE0A	3061 505579	EKATERINA SOLOVEVA	{"phone": "+70701427779"}
0005433112364	6BEE0A	3140 907486	VIKTORIYA OVCHINNIKOVA	{"email": "ovchinnikova-v_1967@postgrespro.ru", "phone": "+70945934089"}
0005433112365	F9FE5D	0973 648093	SVETLANA KARPOVA	{"email": "s-karpova.1968@postgrespro.ru", "phone": "+70626755058"}
0005433112366	9C86BA	3612 206342	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev-15111975@postgrespro.ru", "phone": "+70051154710"}
0005433112367	3E0FD5	9601 348181	AIDA LOGINOVA	{"phone": "+70170060251"}
0005433112368	3E0FD5	0193 387831	PAVEL IVANOV	{"email": "pavel_ivanov101972@postgrespro.ru", "phone": "+70276824708"}
0005433112369	C5714C	7096 951438	ALEKSANDR ALEKSEEV	{"phone": "+70940104108"}
0005433112370	6523B7	1523 704129	NINA KUDRYASHOVA	{"phone": "+70311357891"}
0005433112371	77979C	4387 565741	ANTONINA NOVIKOVA	{"phone": "+70318021307"}
0005433112372	45BC43	8722 799792	IVAN PAVLOV	{"email": "pavlov-ivan_101960@postgrespro.ru", "phone": "+70633862516"}
0005433112373	AB28B6	7527 005701	VLADIMIR MELNIKOV	{"phone": "+70731366766"}
0005433112374	AE092D	9948 587933	NATALYA MAKAROVA	{"phone": "+70902198651"}
0005433112375	39B543	9961 799781	IRINA ERMAKOVA	{"email": "ermakova.i1979@postgrespro.ru", "phone": "+70320870591"}
0005433112376	386BF3	0499 821192	ANNA FROLOVA	{"email": "frolova-a_11081972@postgrespro.ru", "phone": "+70669011774"}
0005433112377	386BF3	5126 557952	ANDREY YAKOVLEV	{"phone": "+70569195497"}
0005433112378	386BF3	2514 550799	IRINA SOROKINA	{"phone": "+70644039697"}
0005433112379	B74639	7734 073032	NATALYA BARANOVA	{"email": "natalya.baranova1981@postgrespro.ru", "phone": "+70321064705"}
0005433112380	C4A93D	4205 536537	VALENTINA KOVALEVA	{"phone": "+70416996090"}
0005433112381	C4A93D	1314 205798	ARTEM FILIPPOV	{"email": "filippov_a1977@postgrespro.ru", "phone": "+70006299007"}
0005433112382	C114F1	1880 550822	ANDREY SEMENOV	{"email": "semenov-andrey_101975@postgrespro.ru", "phone": "+70012886350"}
0005433112383	91FEDB	1683 662521	LIDIYA POPOVA	{"phone": "+70682733911"}
0005433112384	B00937	2765 979296	KIRILL STEPANOV	{"email": "kirill_stepanov_14051972@postgrespro.ru", "phone": "+70379826705"}
0005433112385	B00937	6939 232819	TATYANA MAKAROVA	{"email": "makarovatatyana.071973@postgrespro.ru", "phone": "+70756605001"}
0005433112386	CA2E21	7394 391040	VIKTOR NIKOLAEV	{"email": "vnikolaev.1977@postgrespro.ru", "phone": "+70535470854"}
0005433112387	A2212E	4694 777974	VLADIMIR NOVIKOV	{"email": "novikovvladimir-25081970@postgrespro.ru", "phone": "+70524243345"}
0005433112388	A1042F	9158 690695	LARISA NAZAROVA	{"email": "l.nazarova.09051968@postgrespro.ru", "phone": "+70919729122"}
0005433112389	A1042F	5896 449084	ALEKSEY PAVLOV	{"email": "a.pavlov_121971@postgrespro.ru", "phone": "+70231654647"}
0005433112390	8D01C6	6766 593096	SOFIYA IVANOVA	{"email": "s_ivanova051980@postgrespro.ru", "phone": "+70339776440"}
0005433112391	8D01C6	0751 632709	GALINA NOVIKOVA	{"phone": "+70412229638"}
0005433112392	3C7963	2655 280050	VADIM SAVELEV	{"email": "savelev.v_08061977@postgrespro.ru", "phone": "+70916628363"}
0005433112393	092E79	4865 435912	TIMUR ORLOV	{"email": "orlov-timur04121971@postgrespro.ru", "phone": "+70188748459"}
0005433112394	D6C7FB	5592 425590	NIKOLAY PETROV	{"email": "petrov_n_081976@postgrespro.ru", "phone": "+70165787296"}
0005433112395	D6C7FB	4281 690722	LIDIYA SIDOROVA	{"email": "lidiya_sidorova03011976@postgrespro.ru", "phone": "+70204914810"}
0005433112396	AE5C2D	8247 642413	IRINA KULIKOVA	{"phone": "+70782172892"}
0005433112397	4A5AC8	1114 540760	MARGARITA SEMENOVA	{"email": "msemenova1962@postgrespro.ru", "phone": "+70982185230"}
0005433112398	4A5AC8	8219 320293	ALEKSANDR ROMANOV	{"phone": "+70116692304"}
0005433112399	3213AE	8639 533142	ILDAR NIKOLAEV	{"email": "i.nikolaev-07111979@postgrespro.ru", "phone": "+70045477589"}
0005433112400	38D377	2234 508043	ANASTASIYA PETROVA	{"email": "petrovaa.16101967@postgrespro.ru", "phone": "+70933260904"}
0005433112401	38D377	4432 657909	NATALYA MAKAROVA	{"phone": "+70798204889"}
0005433112402	DD8E26	4820 965869	ALEKSANDR RODIONOV	{"email": "a-rodionov.1982@postgrespro.ru", "phone": "+70932670774"}
0005433112403	DD8E26	9005 024187	KRISTINA RYABOVA	{"email": "kristina-ryabova-06121968@postgrespro.ru", "phone": "+70973695211"}
0005433112404	83F733	5753 383764	ILYA KRASNOV	{"email": "ilya-krasnov-01041969@postgrespro.ru", "phone": "+70901282308"}
0005433112405	83F733	9994 767072	MIKHAIL FROLOV	{"email": "mikhailfrolov_1970@postgrespro.ru", "phone": "+70864141441"}
0005433112406	E23C00	7477 022973	ANNA NOVIKOVA	{"phone": "+70444344475"}
0005433112407	E23C00	0197 803200	SERGEY ZAYCEV	{"email": "zaycev-s_1980@postgrespro.ru", "phone": "+70982420774"}
0005433112408	837D36	3281 941511	VLADIMIR POPOV	{"email": "popov_vladimir_071955@postgrespro.ru", "phone": "+70805212822"}
0005433112409	F278B2	6923 296301	ANTONINA MAKAROVA	{"phone": "+70612356886"}
0005433112410	9263E4	7109 228506	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir041975@postgrespro.ru", "phone": "+70327987715"}
0005433112411	9263E4	9828 111572	LYUBOV EFIMOVA	{"email": "efimova.l-051969@postgrespro.ru", "phone": "+70730305700"}
0005433112412	41CE7D	5240 047894	ELENA FROLOVA	{"phone": "+70332291913"}
0005433112413	AF5C1F	3411 718499	IRINA MELNIKOVA	{"email": "irina_melnikova.27011976@postgrespro.ru", "phone": "+70515989535"}
0005433112414	E3E72D	7681 734402	SVETLANA ZAKHAROVA	{"phone": "+70310695396"}
0005433112415	E3E72D	3993 672773	ELEONORA POLYAKOVA	{"phone": "+70651424669"}
0005433112416	EBF987	1349 932643	MAKSIM ANDREEV	{"phone": "+70363246606"}
0005433112417	EBF987	2821 287446	DARYA DENISOVA	{"email": "denisova.darya_051973@postgrespro.ru", "phone": "+70310222784"}
0005433112418	D0C623	1447 920824	YURIY VASILEV	{"phone": "+70018943425"}
0005433112419	D607F3	4469 361258	ILDUS AFANASEV	{"phone": "+70114216089"}
0005433112420	D607F3	1028 599339	GENNADIY FROLOV	{"phone": "+70457469488"}
0005433112421	C8FEEC	3503 048299	SERGEY YAKOVLEV	{"email": "s_yakovlev-17111978@postgrespro.ru", "phone": "+70809575044"}
0005433112422	C8FEEC	5740 736706	TATYANA ORLOVA	{"phone": "+70776363827"}
0005433112423	B48732	2074 927862	VYACHESLAV EGOROV	{"email": "egorov-v.101966@postgrespro.ru", "phone": "+70012820975"}
0005433112424	E43207	5625 653616	VITALIY KUZNECOV	{"email": "vitaliy.kuznecov_02031982@postgrespro.ru", "phone": "+70079979818"}
0005433112425	E43207	6876 594359	ELENA KUZNECOVA	{"email": "kuznecova.e_1987@postgrespro.ru", "phone": "+70545575072"}
0005433113590	79D3E1	4847 724342	EDUARD CHERNOV	{"phone": "+70277877680"}
0005433113495	5F578C	7971 371373	SAMIRA MARTYNOVA	{"email": "martynova-samira_13121964@postgrespro.ru", "phone": "+70276304772"}
0005433113496	159783	6054 816494	VLADIMIR RODIONOV	{"email": "rodionovvladimir_02091980@postgrespro.ru", "phone": "+70905411290"}
0005433113497	60C181	1953 032551	ELENA MELNIKOVA	{"email": "melnikovaelena-1978@postgrespro.ru", "phone": "+70231670146"}
0005433113498	3110A7	1720 101524	LYUBOV FEDOROVA	{"email": "fedorova-l-26021971@postgrespro.ru", "phone": "+70492646178"}
0005433113499	3110A7	1083 061626	SOFIYA OVCHINNIKOVA	{"phone": "+70522577916"}
0005433113500	962F29	9635 326953	DMITRIY NIKITIN	{"email": "dmitriy-nikitin.071972@postgrespro.ru", "phone": "+70690246422"}
0005433113501	214E97	8459 127362	ELLA EFREMOVA	{"email": "efremova_ella_25091972@postgrespro.ru", "phone": "+70775158706"}
0005433113502	4C7F5D	5167 451553	MAKSIM SOKOLOV	{"email": "sokolovm-31011971@postgrespro.ru", "phone": "+70480606265"}
0005433113503	408D60	2758 049279	MARIYA ANDREEVA	{"email": "m.andreeva1971@postgrespro.ru", "phone": "+70203629548"}
0005433113504	408D60	6205 870875	VLADIMIR SERGEEV	{"email": "sergeev.vladimir-071976@postgrespro.ru", "phone": "+70352253638"}
0005433113505	2C8E56	7957 628032	ARTUR NIKOLAEV	{"email": "nikolaev_a.15021967@postgrespro.ru", "phone": "+70133454121"}
0005433113506	166106	8549 261724	IRINA IVANOVA	{"email": "ivanovairina-1966@postgrespro.ru", "phone": "+70582653961"}
0005433113507	166106	0559 049451	VADIM MOROZOV	{"email": "vadim_morozov-121974@postgrespro.ru", "phone": "+70252635921"}
0005433113508	EF686D	1405 053126	GALINA VASILEVA	{"email": "vasileva.g-22061969@postgrespro.ru", "phone": "+70192269251"}
0005433113509	01FF1F	6975 874996	LYUDMILA MAKAROVA	{"email": "lyudmila_makarova.09021969@postgrespro.ru", "phone": "+70218107796"}
0005433113510	B622A9	1982 711267	VIKTOR FEDOROV	{"email": "fedorovviktor.1974@postgrespro.ru", "phone": "+70566223639"}
0005433113511	68BDD6	6029 321302	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr081975@postgrespro.ru", "phone": "+70366819249"}
0005433113512	174A70	1754 418211	YULIYA DMITRIEVA	{"email": "ydmitrieva-12091979@postgrespro.ru", "phone": "+70725853879"}
0005433113513	72612E	9157 422798	PETR MIKHAYLOV	{"email": "mikhaylov.p_1974@postgrespro.ru", "phone": "+70457523422"}
0005433113514	72612E	7359 576089	VLADIMIR MEDVEDEV	{"phone": "+70404880901"}
0005433113515	72612E	1553 166001	MAKSIM KUZNECOV	{"email": "m.kuznecov.03061972@postgrespro.ru", "phone": "+70387820532"}
0005433113516	72612E	8445 902398	VASILIY ALEKSANDROV	{"email": "aleksandrov.vasiliy.31121967@postgrespro.ru", "phone": "+70969308720"}
0005433113517	AF0F8E	2391 258280	STEPAN KARPOV	{"email": "karpovs-1975@postgrespro.ru", "phone": "+70322121080"}
0005433113518	AF0F8E	6368 013924	OLEG STEPANOV	{"email": "o.stepanov1963@postgrespro.ru", "phone": "+70710339257"}
0005433113519	6D64E4	6821 254376	SOFIYA GORBUNOVA	{"email": "s_gorbunova1964@postgrespro.ru", "phone": "+70293011760"}
0005433113520	6D64E4	5457 673237	VALENTINA TARASOVA	{"phone": "+70034397153"}
0005433113521	6D64E4	6903 450761	EVDOKIYA SOROKINA	{"email": "sorokina-e06021982@postgrespro.ru", "phone": "+70370552181"}
0005433113522	6D64E4	3107 867146	NINA ZAYCEVA	{"phone": "+70358716093"}
0005433113523	2CB53F	2409 215883	NIKITA MATVEEV	{"email": "matveev.nikita.111974@postgrespro.ru", "phone": "+70625508123"}
0005433113524	1140E6	0774 420798	RUSLAN ANTONOV	{"email": "antonov_r.021969@postgrespro.ru", "phone": "+70239922049"}
0005433113525	7D2C6E	4757 471765	OLGA POPOVA	{"email": "popova.o_091982@postgrespro.ru", "phone": "+70234524214"}
0005433113526	C25C86	9890 506513	ANASTASIYA IVANOVA	{"phone": "+70426492366"}
0005433113527	426F3A	8569 545661	VLADIMIR VLASOV	{"email": "vlasov.vladimir1974@postgrespro.ru", "phone": "+70480475963"}
0005433113528	426F3A	3071 210792	LYUDMILA GORBUNOVA	{"email": "gorbunova.lyudmila-1976@postgrespro.ru", "phone": "+70191678565"}
0005433113529	7CC2F2	5976 305554	POLINA SIDOROVA	{"phone": "+70446346988"}
0005433113530	81EDAF	9995 221240	VLADIMIR TIKHONOV	{"phone": "+70208034184"}
0005433113531	2B994E	2694 352801	ALEKSEY FROLOV	{"email": "afrolov_1960@postgrespro.ru", "phone": "+70120339252"}
0005433113532	D6BBBF	5696 568898	LARISA DAVYDOVA	{"email": "ldavydova_1971@postgrespro.ru", "phone": "+70617010913"}
0005433113533	B0941E	1009 312981	LARISA MALYSHEVA	{"email": "l-malysheva.031983@postgrespro.ru", "phone": "+70043538276"}
0005433113534	6F5610	0612 685193	ANDREY KAZAKOV	{"email": "kazakov_a_091981@postgrespro.ru", "phone": "+70111992243"}
0005433113535	5949C6	1468 019172	ALEKSANDR EGOROV	{"phone": "+70919948583"}
0005433113536	D2E5A6	0873 126741	VIKTORIYA KUZNECOVA	{"phone": "+70493673876"}
0005433113537	279E25	5274 463976	ANNA POPOVA	{"email": "annapopova10031971@postgrespro.ru", "phone": "+70920761480"}
0005433113538	279E25	5216 230410	DENIS KRASNOV	{"phone": "+70272918091"}
0005433113539	126D2F	2738 081699	SERGEY SEMENOV	{"email": "semenov_sergey-011976@postgrespro.ru", "phone": "+70159973947"}
0005433113540	EFFA4A	5852 184979	OLEG ZHURAVLEV	{"email": "oleg_zhuravlev_03061972@postgrespro.ru", "phone": "+70352844790"}
0005433113541	3B0A9C	1468 049490	ANNA NAUMOVA	{"phone": "+70776827866"}
0005433113542	3E6AC6	1709 651423	ARTEMIY ZAKHAROV	{"phone": "+70525678922"}
0005433113543	7EB5BE	5484 262606	TATYANA KOVALEVA	{"phone": "+70568267036"}
0005433113544	D9837F	0981 419250	RADMIR MOISEEV	{"email": "moiseevradmir-091961@postgrespro.ru", "phone": "+70651504646"}
0005433113545	9410AB	6109 415203	IRINA KONOVALOVA	{"email": "irina.konovalova-17021968@postgrespro.ru", "phone": "+70301262402"}
0005433113546	4A8F1E	2994 667637	MAKSIM MEDVEDEV	{"phone": "+70560182482"}
0005433113547	DACDF3	0886 432562	KSENIYA KISELEVA	{"email": "kiseleva.kseniya_091957@postgrespro.ru", "phone": "+70046817842"}
0005433113548	4EC912	2531 908932	LYUDMILA ZOTOVA	{"phone": "+70389398500"}
0005433113549	4EC912	3113 989428	SVETLANA NAUMOVA	{"phone": "+70752175743"}
0005433113550	4EC912	2097 912712	VALENTINA DMITRIEVA	{"phone": "+70432287620"}
0005433113551	7E813E	0011 480288	EKATERINA ARKHIPOVA	{"email": "e_arkhipova-1978@postgrespro.ru", "phone": "+70228937766"}
0005433113552	CAA493	4114 282367	VLADIMIR DAVYDOV	{"email": "vladimir_davydov_011971@postgrespro.ru", "phone": "+70204155761"}
0005433113553	CAA493	8551 204338	OLGA KUZNECOVA	{"email": "o.kuznecova.031975@postgrespro.ru", "phone": "+70200594070"}
0005433113554	8F93F2	5201 306055	SERGEY RODIONOV	{"phone": "+70890086150"}
0005433113555	395C3C	7335 778131	OLESYA ISAEVA	{"email": "o.isaeva-24091978@postgrespro.ru", "phone": "+70638244719"}
0005433113556	A020A0	5131 349334	NIKOLAY MEDVEDEV	{"phone": "+70826839418"}
0005433113557	AEF351	7370 798343	KIRILL NOVIKOV	{"email": "kirill-novikov.1969@postgrespro.ru", "phone": "+70798392700"}
0005433113558	C97EB3	0819 348505	VALERIY OSIPOV	{"email": "osipov-valeriy-1973@postgrespro.ru", "phone": "+70200741732"}
0005433113559	C97EB3	3469 407222	TIMOFEY NOVIKOV	{"phone": "+70457836892"}
0005433113560	C97EB3	7628 983505	ALEKSANDR FEDOROV	{"phone": "+70991881882"}
0005433113561	576EFE	3951 798416	DENIS ZAYCEV	{"phone": "+70540146093"}
0005433113562	576EFE	1255 924927	EKATERINA FOMINA	{"email": "ekaterina_fomina.051970@postgrespro.ru", "phone": "+70579477989"}
0005433113563	87FA73	6293 098693	ALEKSANDR NAZAROV	{"email": "a-nazarov_081968@postgrespro.ru", "phone": "+70450819541"}
0005433113564	437941	8715 205211	NIKOLAY KUZNECOV	{"phone": "+70072247325"}
0005433113565	F336DD	0607 445387	VLADIMIR NIKITIN	{"email": "vladimir.nikitin.27041980@postgrespro.ru", "phone": "+70559164663"}
0005433113566	724485	2874 825499	ANDREY VASILEV	{"email": "andrey.vasilev.1974@postgrespro.ru", "phone": "+70082068460"}
0005433113567	3BF23E	9900 900285	INNA OVCHINNIKOVA	{"email": "ovchinnikovai081971@postgrespro.ru", "phone": "+70836406545"}
0005433113568	F3345D	5469 629376	ALEKSEY VOLKOV	{"email": "volkova_1962@postgrespro.ru", "phone": "+70779794722"}
0005433113569	F3345D	5418 746358	IRINA MIKHAYLOVA	{"email": "irina_mikhaylova.1971@postgrespro.ru", "phone": "+70666465430"}
0005433113570	547F11	9954 625361	VALENTINA TITOVA	{"phone": "+70075275186"}
0005433113571	547F11	4420 819872	MIKHAIL STEPANOV	{"email": "stepanov.m051973@postgrespro.ru", "phone": "+70800424921"}
0005433113572	3E56BD	3838 041181	ELDAR SCHERBAKOV	{"phone": "+70681997878"}
0005433113573	377E12	8224 500484	ANASTASIYA MOROZOVA	{"phone": "+70635814117"}
0005433113574	377E12	6007 128000	ELENA POLYAKOVA	{"email": "epolyakova.1974@postgrespro.ru", "phone": "+70789881720"}
0005433113575	708135	6332 589034	GALINA YAKOVLEVA	{"phone": "+70110300536"}
0005433113576	713C67	0261 131289	RAISA FROLOVA	{"email": "frolova.r.031973@postgrespro.ru", "phone": "+70046630906"}
0005433113577	595AF6	8354 100721	MAKSIM MIRONOV	{"phone": "+70946025566"}
0005433113578	A3DC57	0247 694912	TATYANA SEMENOVA	{"email": "semenovat1974@postgrespro.ru", "phone": "+70683606251"}
0005433113579	960736	2451 812998	MAKSIM SMIRNOV	{"email": "smirnovmaksim_031978@postgrespro.ru", "phone": "+70825172240"}
0005433113580	1AE2DE	1358 891150	TATYANA VOLKOVA	{"email": "volkova-t1965@postgrespro.ru", "phone": "+70866597477"}
0005433113581	C2EA4D	5784 256124	VALENTINA ARKHIPOVA	{"email": "arkhipova-v.1957@postgrespro.ru", "phone": "+70015885718"}
0005433113582	160807	2676 011934	VERONIKA ALEKSEEVA	{"email": "alekseeva_v011979@postgrespro.ru", "phone": "+70879457884"}
0005433113583	232C25	0385 983781	OKSANA ILINA	{"phone": "+70402473129"}
0005433113584	B34508	9995 776605	MARIYA KOROLEVA	{"email": "m_koroleva-051982@postgrespro.ru", "phone": "+70676096157"}
0005433113585	B34508	9080 348445	TATYANA DANILOVA	{"email": "danilova_tatyana1967@postgrespro.ru", "phone": "+70008457505"}
0005433113586	78B578	0433 535881	RAISA KRASNOVA	{"phone": "+70538763774"}
0005433113587	914806	5159 343981	LYUBOV TITOVA	{"phone": "+70978387814"}
0005433113588	914806	4505 045993	NIKOLAY KUZMIN	{"email": "kuzmin.nikolay_1969@postgrespro.ru", "phone": "+70719992514"}
0005433113589	E6BC16	5767 914487	ALEKSEY DENISOV	{"email": "denisov.aleksey-031980@postgrespro.ru", "phone": "+70604421401"}
0005433113591	E25794	4896 604641	NATALYA VOLKOVA	{"phone": "+70177479127"}
0005433113592	E37203	8879 384740	VALENTINA VOLKOVA	{"email": "volkova.valentina_26111976@postgrespro.ru", "phone": "+70153890318"}
0005433113593	3D2A2E	6964 146057	VIKTOR ROMANOV	{"phone": "+70872310883"}
0005433113594	45DE12	1033 399033	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.20111973@postgrespro.ru", "phone": "+70128978115"}
0005433113595	8F7BCA	1848 700051	YANA KUZNECOVA	{"phone": "+70009694914"}
0005433113596	8F7BCA	0402 458072	TATYANA LUKYANOVA	{"phone": "+70351069018"}
0005433113597	6D1CF4	6063 902283	SVETLANA ZOTOVA	{"phone": "+70005605470"}
0005433113598	38F3D1	1060 885035	VLADIMIR VLASOV	{"phone": "+70707483158"}
0005433113618	A36B06	7152 695320	KSENIYA MOROZOVA	{"email": "morozovakseniya_081963@postgrespro.ru", "phone": "+70385867915"}
0005433113619	A55C62	6002 458570	OKSANA AFANASEVA	{"phone": "+70226483153"}
0005433113620	A55C62	1990 290783	ALINA TITOVA	{"phone": "+70551440421"}
0005433123565	F8015D	8041 953264	LYUBOV KAZAKOVA	{"phone": "+70587390677"}
0005433123566	224926	9377 628635	MAKSIM IVANOV	{"email": "maksim_ivanov.27041965@postgrespro.ru", "phone": "+70176951082"}
0005433123567	224926	3248 484328	ANASTASIYA PETROVA	{"email": "petrovaanastasiya-1969@postgrespro.ru", "phone": "+70426028465"}
0005433123568	EAEC03	5943 148813	NINA IVANOVA	{"phone": "+70923951019"}
0005433123569	EAEC03	5625 294436	ELENA TIMOFEEVA	{"email": "timofeeva-elena25111968@postgrespro.ru", "phone": "+70389389187"}
0005433123570	2D7632	6767 993904	ALEKSANDR PETROV	{"email": "petrov.aleksandr1977@postgrespro.ru", "phone": "+70764293163"}
0005433123571	068287	4421 787526	ALENA ANTONOVA	{"email": "antonova.a011975@postgrespro.ru", "phone": "+70225327482"}
0005433123572	F7F2B8	9438 487608	ALEKSEY SIDOROV	{"phone": "+70814704275"}
0005433123573	C45EA2	9869 516411	OLESYA KISELEVA	{"email": "kiseleva_o_02051961@postgrespro.ru", "phone": "+70440800636"}
0005433123574	C45EA2	9592 491737	PRASKOVYA GUSEVA	{"email": "praskovyaguseva-1989@postgrespro.ru", "phone": "+70568403982"}
0005433123575	FF86E1	4407 274285	SERGEY MIRONOV	{"email": "sergey_mironov.061978@postgrespro.ru", "phone": "+70283045747"}
0005433123576	ABE889	9004 781732	LYUDMILA MASLOVA	{"phone": "+70821404413"}
0005433123577	7DEDA8	9213 645291	MIKHAIL SMIRNOV	{"email": "m.smirnov1977@postgrespro.ru", "phone": "+70729376761"}
0005433123578	40542F	8506 101979	YURIY ZAKHAROV	{"email": "zakharov-y20071974@postgrespro.ru", "phone": "+70665760218"}
0005433123579	40542F	2267 449019	DMITRIY ROMANOV	{"email": "dmitriy-romanov091973@postgrespro.ru", "phone": "+70655562274"}
0005433123580	8AE33A	1078 682839	VLADIMIR KUDRYASHOV	{"email": "kudryashovv_021972@postgrespro.ru", "phone": "+70536320348"}
0005433123581	FFCB87	8914 558707	IGOR FILIPPOV	{"email": "igor.filippov-02041968@postgrespro.ru", "phone": "+70339759134"}
0005433123582	05D47C	6584 535986	ANASTASIYA ERMAKOVA	{"email": "a-ermakova-021975@postgrespro.ru", "phone": "+70429398415"}
0005433123583	713E3E	4639 234083	OKSANA MIRONOVA	{"email": "mironova-oksana_1975@postgrespro.ru", "phone": "+70345716374"}
0005433123584	713E3E	3854 887575	NIKOLAY FOMIN	{"phone": "+70312812815"}
0005433123585	E9738E	0566 778671	MARIYA SOROKINA	{"email": "msorokina.1970@postgrespro.ru", "phone": "+70541767400"}
0005433123586	BA4206	4999 206373	NADEZHDA ZAKHAROVA	{"email": "n_zakharova_051973@postgrespro.ru", "phone": "+70022267534"}
0005433123587	BA4206	8048 286296	SERGEY FROLOV	{"phone": "+70223746687"}
0005433123644	71895E	0737 720719	NATALYA MOROZOVA	{"phone": "+70151192978"}
0005433123588	CA6388	7994 005674	ELENA KOROLEVA	{"email": "e-koroleva.041971@postgrespro.ru", "phone": "+70163888574"}
0005433123589	C683E1	4638 595425	VLADIMIR FROLOV	{"phone": "+70963782656"}
0005433123590	A867F9	7796 167830	ALEKSANDR SIDOROV	{"phone": "+70128876435"}
0005433123591	A867F9	8434 197350	TATYANA FOMINA	{"phone": "+70589610992"}
0005433123592	DBE91E	5261 636502	GEORGIY MEDVEDEV	{"email": "georgiy-medvedev_1974@postgrespro.ru", "phone": "+70170419676"}
0005433123593	00ED3C	6542 303910	MARINA AFANASEVA	{"email": "mafanaseva-1977@postgrespro.ru", "phone": "+70134649082"}
0005433123594	18C18D	2421 719804	GALINA SOKOLOVA	{"email": "sokolova-galina-1965@postgrespro.ru", "phone": "+70081617728"}
0005433123708	C233F0	3775 043043	MARIYA BARANOVA	{"phone": "+70128169667"}
0005433123595	0549CD	9773 501409	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov1970@postgrespro.ru", "phone": "+70104544813"}
0005433123596	063F96	8480 847533	ANZHELA BELYAEVA	{"email": "anzhelabelyaeva_1958@postgrespro.ru", "phone": "+70527546433"}
0005433123597	F1429E	9319 013793	DINARA IVANOVA	{"phone": "+70253091235"}
0005433123598	BD60E2	0359 306798	IVAN IVANOV	{"phone": "+70216561717"}
0005433123599	BD60E2	1021 478963	VALENTINA MATVEEVA	{"phone": "+70352067189"}
0005433123600	BD60E2	6617 952591	NINA MIKHAYLOVA	{"email": "mikhaylova.n1974@postgrespro.ru", "phone": "+70394068459"}
0005433123601	8F61CA	4195 785995	DINA ROMANOVA	{"email": "dromanova09081963@postgrespro.ru", "phone": "+70470607474"}
0005433123602	8F61CA	3510 584033	IRAIDA KUZNECOVA	{"phone": "+70924340741"}
0005433123603	F69AFE	2122 519931	LIDIYA MATVEEVA	{"email": "matveevalidiya_1971@postgrespro.ru", "phone": "+70191714797"}
0005433123604	B60299	4014 828038	ANDREY KUZNECOV	{"email": "kuznecov-a-17011977@postgrespro.ru", "phone": "+70555242746"}
0005433123605	8BC8A4	3062 308408	ANDREY VLASOV	{"phone": "+70097671388"}
0005433123606	6CDAD4	4812 734541	NATALYA BELOVA	{"phone": "+70064562834"}
0005433123607	432162	8665 112406	SERGEY BONDARENKO	{"email": "s.bondarenko03071974@postgrespro.ru", "phone": "+70111603904"}
0005433123608	432162	5998 401260	RUSLAN TARASOV	{"phone": "+70116262003"}
0005433123609	FF249C	4886 440478	DMITRIY GERASIMOV	{"email": "gerasimov_dmitriy1979@postgrespro.ru", "phone": "+70880273501"}
0005433123610	0619F6	7374 059877	ANNA SERGEEVA	{"phone": "+70223424914"}
0005433123611	6D8DAD	0454 346107	VALENTINA ZAYCEVA	{"phone": "+70488590930"}
0005433123612	65AA5C	2303 345044	ALEKSEY SMIRNOV	{"phone": "+70343394266"}
0005433123613	65AA5C	3515 538338	KONSTANTIN GORBUNOV	{"email": "konstantin.gorbunov_19091970@postgrespro.ru", "phone": "+70088776508"}
0005433123614	E6667D	1352 363183	RIMMA KULIKOVA	{"email": "kulikova-rimma-1977@postgrespro.ru", "phone": "+70685630759"}
0005433123615	44253C	7867 198652	ILYA POPOV	{"email": "ipopov_081975@postgrespro.ru", "phone": "+70842744420"}
0005433123616	33A2A1	7364 528618	ALEKSANDR MATVEEV	{"phone": "+70396874850"}
0005433123617	B49622	0577 691927	ALEKSANDR GORBUNOV	{"email": "gorbunov_a_31011972@postgrespro.ru", "phone": "+70133480764"}
0005433123618	975AA0	1764 296650	RIMMA ARKHIPOVA	{"email": "arkhipova.rimma-1979@postgrespro.ru", "phone": "+70306074830"}
0005433123619	975AA0	9691 568586	TATYANA NOVIKOVA	{"email": "novikova-tatyana.101980@postgrespro.ru", "phone": "+70511250016"}
0005433123620	975AA0	6272 075733	ANDREY MARTYNOV	{"phone": "+70898637913"}
0005433123621	160C04	2401 291013	EVGENIY SIDOROV	{"email": "e.sidorov_011979@postgrespro.ru", "phone": "+70068713054"}
0005433123622	020ADC	9277 674906	GALINA ERMAKOVA	{"email": "ermakovagalina14031980@postgrespro.ru", "phone": "+70816442018"}
0005433123623	C90DBC	7477 872916	PELAGEYA ANDREEVA	{"phone": "+70048477183"}
0005433123624	C90DBC	5071 347449	SVETLANA MAKAROVA	{"phone": "+70319585195"}
0005433123625	FDC509	7077 965688	NADEZHDA MEDVEDEVA	{"email": "medvedevan_20021974@postgrespro.ru", "phone": "+70279276894"}
0005433123626	A3B3D0	9594 956310	VALERIY NIKOLAEV	{"phone": "+70839229681"}
0005433123627	4D3243	8979 802859	MAKSIM FEDOROV	{"email": "maksim_fedorov-11111980@postgrespro.ru", "phone": "+70355007728"}
0005433123628	CF80B8	9397 938280	IRINA IVANOVA	{"phone": "+70985956890"}
0005433123629	CF80B8	7341 975715	VADIM ZAKHAROV	{"phone": "+70176320741"}
0005433123630	D56065	8759 891422	NATALYA ZOTOVA	{"phone": "+70213283227"}
0005433123631	1F5A45	4590 846331	ANDREY MAKAROV	{"email": "makarovandrey_13061970@postgrespro.ru", "phone": "+70905430113"}
0005433123632	FF73D3	7065 354305	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova.a_121975@postgrespro.ru", "phone": "+70941760672"}
0005433123633	6AE697	6701 686053	VIKTOR ZAKHAROV	{"phone": "+70209767546"}
0005433123634	EC3BF8	1772 481579	VARVARA PETROVA	{"phone": "+70834495569"}
0005433123635	EC3BF8	6908 786906	IGOR KUDRYASHOV	{"email": "kudryashovigor-021975@postgrespro.ru", "phone": "+70326241956"}
0005433123636	1718DC	7250 758467	MARK TIKHONOV	{"email": "m.tikhonov.09011963@postgrespro.ru", "phone": "+70593245564"}
0005433123637	2C0532	1162 954031	TATYANA MIRONOVA	{"email": "mironova.tatyana-121968@postgrespro.ru", "phone": "+70263034199"}
0005433123638	A16941	9702 926083	IVAN STEPANOV	{"email": "ivan-stepanov-091979@postgrespro.ru", "phone": "+70200231848"}
0005433123639	B5D49B	6972 153141	ALEKSEY DMITRIEV	{"phone": "+70039720670"}
0005433123640	3AAF93	2353 413304	OLGA NIKOLAEVA	{"phone": "+70767275319"}
0005433123641	3AAF93	9212 795022	ALBERT ANDREEV	{"phone": "+70414137806"}
0005433123642	04F5C1	5297 468039	ALEKSEY DAVYDOV	{"phone": "+70544260780"}
0005433123643	71895E	7378 577446	ANDREY NAUMOV	{"email": "naumova1979@postgrespro.ru", "phone": "+70343298123"}
0005433123645	3E9C6F	8704 020604	TATYANA FROLOVA	{"email": "tatyana-frolova07111965@postgrespro.ru", "phone": "+70483943970"}
0005433123646	E3E321	8037 478922	NIKOLAY MARTYNOV	{"email": "martynov.nikolay1973@postgrespro.ru", "phone": "+70749420514"}
0005433123647	3F234C	5581 916533	VALERIY SMIRNOV	{"email": "valeriy_smirnov081974@postgrespro.ru", "phone": "+70553341643"}
0005433123648	3F234C	4917 320007	OLGA KOMAROVA	{"phone": "+70226295955"}
0005433123649	3F234C	0168 902239	ANZHELIKA MOISEEVA	{"phone": "+70360304617"}
0005433123650	A9467A	2292 012961	DENIS DAVYDOV	{"phone": "+70364290851"}
0005433123651	77C5CE	6943 827529	VLADISLAV DAVYDOV	{"phone": "+70276631163"}
0005433123652	0118A6	4225 193260	NAIL SIDOROV	{"email": "nail-sidorov-1974@postgrespro.ru", "phone": "+70780547246"}
0005433123653	ED1267	4897 775903	LIDIYA FOMINA	{"phone": "+70134798159"}
0005433123654	ED1267	0296 776605	LYUDMILA VASILEVA	{"phone": "+70023863783"}
0005433123655	9A65BF	6905 229362	TATYANA SMIRNOVA	{"phone": "+70228511219"}
0005433123656	C05FFD	2063 112119	ALEKSANDR YAKOVLEV	{"phone": "+70464150823"}
0005433123657	DAF1E9	2248 648222	KIRILL NAZAROV	{"phone": "+70221651420"}
0005433123658	74620D	5844 641018	EVGENIY KAZAKOV	{"phone": "+70532324051"}
0005433123659	99EFC1	5641 157777	VITALIY MEDVEDEV	{"phone": "+70956863804"}
0005433123660	9BB26E	7156 897974	IRINA SIDOROVA	{"email": "sidorova.irina.29061982@postgrespro.ru", "phone": "+70679049085"}
0005433123661	105EC2	5218 201063	GALINA ORLOVA	{"phone": "+70688642679"}
0005433123662	96D83C	7252 799533	VITALIY KRASNOV	{"email": "v-krasnov.121977@postgrespro.ru", "phone": "+70570782419"}
0005433123663	FD8927	1973 740818	ELENA DENISOVA	{"email": "denisova_elena_091991@postgrespro.ru", "phone": "+70289329306"}
0005433123664	9330C6	0013 809944	PAVEL KUZNECOV	{"phone": "+70088575508"}
0005433123665	9C364D	4989 555764	NADEZHDA EFIMOVA	{"email": "efimova_nadezhda.021972@postgrespro.ru", "phone": "+70506417486"}
0005433123666	9C364D	4375 395757	MIKHAIL NIKOLAEV	{"phone": "+70629489955"}
0005433123667	9C364D	3760 876345	LYUBOV VLASOVA	{"email": "vlasoval_1985@postgrespro.ru", "phone": "+70741224891"}
0005433123668	E6B1FE	9598 347988	NIKITA GRIGOREV	{"email": "grigorev-nikita051978@postgrespro.ru", "phone": "+70342252484"}
0005433123669	E6B1FE	9919 512016	ALEKSANDR MAKAROV	{"email": "amakarov20051987@postgrespro.ru", "phone": "+70136844107"}
0005433123670	1DB2EC	8812 095552	NIKOLAY BORISOV	{"email": "nikolayborisov_1958@postgrespro.ru", "phone": "+70139888763"}
0005433123671	1DB2EC	6356 320494	ANNA KUZNECOVA	{"email": "anna_kuznecova.1968@postgrespro.ru", "phone": "+70326527053"}
0005433123672	C27971	6331 580451	TATYANA MIKHAYLOVA	{"email": "tatyana-mikhaylova-11111964@postgrespro.ru", "phone": "+70690902738"}
0005433123673	792D5F	0910 909848	RUSLAN PETROV	{"email": "petrov_ruslan-101968@postgrespro.ru", "phone": "+70052815386"}
0005433123674	E98804	4764 948990	EKATERINA TARASOVA	{"phone": "+70816884878"}
0005433123675	E98804	8098 752546	ALEKSEY NOVIKOV	{"email": "a_novikov101964@postgrespro.ru", "phone": "+70021640379"}
0005433123676	4BEC4C	1227 989513	NADEZHDA RODIONOVA	{"email": "rodionovanadezhda_1962@postgrespro.ru", "phone": "+70758438562"}
0005433123677	460126	7220 362298	MARINA SIDOROVA	{"email": "msidorova021973@postgrespro.ru", "phone": "+70553581655"}
0005433123678	460126	8839 385245	SERGEY KONOVALOV	{"phone": "+70571607761"}
0005433123679	9BE533	7142 130465	SVETLANA SOKOLOVA	{"email": "svetlana.sokolova25081965@postgrespro.ru", "phone": "+70120599438"}
0005433123680	1FCED7	2527 180128	DZHAMILYA NIKITINA	{"phone": "+70012583654"}
0005433123681	14CC75	5312 384775	NATALYA VLASOVA	{"email": "n_vlasova20121973@postgrespro.ru", "phone": "+70979267803"}
0005433123682	53D69F	8216 778350	NATALYA FROLOVA	{"email": "nfrolova.08061985@postgrespro.ru", "phone": "+70576713717"}
0005433123683	CD8F2C	0977 170755	VIKTORIYA BOGDANOVA	{"phone": "+70631865683"}
0005433123684	EE935D	6314 065064	ANASTASIYA TIMOFEEVA	{"phone": "+70722175464"}
0005433123685	18666A	4341 192205	LYUBOV NIKITINA	{"email": "l.nikitina111968@postgrespro.ru", "phone": "+70212970451"}
0005433123686	5F4955	2207 816294	MARINA NIKOLAEVA	{"phone": "+70664215520"}
0005433123687	7AC552	9945 268108	NINA NIKOLAEVA	{"email": "nikolaeva_nina.30051972@postgrespro.ru", "phone": "+70851445054"}
0005433123688	7AC552	0213 762388	VALENTINA POPOVA	{"phone": "+70405243990"}
0005433123689	944972	6881 644979	ZHANNA SOLOVEVA	{"email": "zhannasoloveva_1976@postgrespro.ru", "phone": "+70434944794"}
0005433123690	E1B469	2167 142329	ANASTASIYA MEDVEDEVA	{"email": "anastasiya-medvedeva_22011969@postgrespro.ru", "phone": "+70925861545"}
0005433123691	E1B469	5534 663629	FILIPP SCHERBAKOV	{"phone": "+70974463756"}
0005433123692	617505	8255 599301	DMITRIY BORISOV	{"email": "dmitriy_borisov_1973@postgrespro.ru", "phone": "+70352012684"}
0005433123693	A04BF1	6401 257646	ANASTASIYA FEDOROVA	{"phone": "+70521388121"}
0005433123694	F880A8	0588 278824	DENIS PETROV	{"email": "petrov.d.091965@postgrespro.ru", "phone": "+70697563354"}
0005433123695	35CD9E	4413 626533	MAKSIM IVANOV	{"phone": "+70419007683"}
0005433123696	E88900	6399 200718	SVETLANA TIKHONOVA	{"email": "s.tikhonova021985@postgrespro.ru", "phone": "+70604181738"}
0005433123697	E88900	4961 783552	OLEG VASILEV	{"phone": "+70035032388"}
0005433123698	E88900	9740 521673	ALEKSANDR ZAKHAROV	{"phone": "+70079874926"}
0005433123699	568BA3	2151 222683	TAISA AFANASEVA	{"phone": "+70795574013"}
0005433123700	5C3A1C	8455 807707	EVGENIYA FOMINA	{"phone": "+70312196309"}
0005433123701	FCC0FA	0706 877750	SNEZHANA SIDOROVA	{"phone": "+70170003148"}
0005433123702	35EC00	0205 112195	ANNA SEMENOVA	{"phone": "+70957319422"}
0005433123703	6AF522	9229 968955	EVGENIY KISELEV	{"phone": "+70695280328"}
0005433123704	B40156	2017 137279	ALEKSANDR ILIN	{"email": "aleksandr-ilin-23091967@postgrespro.ru", "phone": "+70750175937"}
0005433123705	F60A5E	4151 071453	ANDREY MOISEEV	{"email": "moiseev_a_01061963@postgrespro.ru", "phone": "+70188825817"}
0005433123706	3D2A3F	9136 412850	IVAN PETROV	{"email": "i_petrov-18041969@postgrespro.ru", "phone": "+70211769385"}
0005433123707	3D2A3F	7719 104633	ALEKSANDR PETROV	{"email": "petrov-aleksandr_10041968@postgrespro.ru", "phone": "+70681477762"}
0005433123709	E3041A	3319 107617	EVGENIY MARTYNOV	{"email": "emartynov.1975@postgrespro.ru", "phone": "+70468969807"}
0005433123710	404913	0672 151890	NIKITA GORBUNOV	{"phone": "+70919299091"}
0005433123711	BAB1AC	4919 429429	IRINA AFANASEVA	{"email": "i.afanaseva_05091978@postgrespro.ru", "phone": "+70583370971"}
0005433123712	BAB1AC	2311 336274	NIKOLAY SCHERBAKOV	{"phone": "+70708724333"}
0005433123713	97FEE6	6880 901973	MARIYA TIKHONOVA	{"email": "mtikhonova_12101971@postgrespro.ru", "phone": "+70548536395"}
0005433123714	008D61	9255 612321	VIKTOR MAKAROV	{"phone": "+70811362242"}
0005433123715	D22B00	3197 312038	VLADIMIR ANDREEV	{"phone": "+70907514838"}
0005433123716	35F616	5167 601213	IRINA KOMAROVA	{"phone": "+70685084297"}
0005433123717	54A5EE	8351 642674	ANATOLIY AFANASEV	{"phone": "+70863187648"}
0005433123718	98E719	7868 571785	VLADIMIR TIMOFEEV	{"phone": "+70257047359"}
0005433123719	469D33	0789 989181	ALEKSANDR ALEKSEEV	{"phone": "+70571526670"}
0005433123720	7662DE	1964 677403	VLADIMIR MOISEEV	{"email": "vladimir_moiseev_071974@postgrespro.ru", "phone": "+70380938170"}
0005433123721	76A0F0	5243 309559	SERGEY NIKITIN	{"phone": "+70768547802"}
0005433123722	F6E83D	6516 681841	LYUDMILA PAVLOVA	{"email": "lyudmilapavlova.041977@postgrespro.ru", "phone": "+70632914536"}
0005433123781	D87ED9	0168 599646	VIKTOR MAKSIMOV	{"phone": "+70308362625"}
0005433123723	DCA6FB	8383 026590	ANDREY BORISOV	{"email": "borisov.a-31121968@postgrespro.ru", "phone": "+70291485512"}
0005433123724	B533B3	4836 000560	VALENTINA MARTYNOVA	{"email": "v_martynova-1972@postgrespro.ru", "phone": "+70343713250"}
0005433123725	0E4460	6993 301855	TATYANA STEPANOVA	{"phone": "+70278205539"}
0005433123726	1BC43E	2333 048994	MARIYA ANTONOVA	{"phone": "+70850774869"}
0005433123727	1BC43E	1922 276422	IRINA ROMANOVA	{"email": "i_romanova-11121967@postgrespro.ru", "phone": "+70175892697"}
0005433123728	F1A890	6459 879992	POLINA DMITRIEVA	{"email": "dmitrievapolina_1969@postgrespro.ru", "phone": "+70666369661"}
0005433123729	F1A890	2277 198612	NATALIYA FEDOROVA	{"email": "fedorovanataliya1981@postgrespro.ru", "phone": "+70003300850"}
0005433123730	723BFC	6305 113367	RAISA IVANOVA	{"phone": "+70468570677"}
0005433123731	723BFC	6125 577968	NATALIYA FEDOROVA	{"email": "n.fedorova_13021980@postgrespro.ru", "phone": "+70258905340"}
0005433123732	21F9E0	1791 339120	MARIYA IVANOVA	{"email": "ivanova.m_1975@postgrespro.ru", "phone": "+70345862612"}
0005433123733	21F9E0	3026 397488	DANILA KUZNECOV	{"email": "danilakuznecov1969@postgrespro.ru", "phone": "+70916689091"}
0005433123734	61E24E	6777 652777	LYUBOV MIKHAYLOVA	{"email": "l-mikhaylova.1986@postgrespro.ru", "phone": "+70684138862"}
0005433123735	116733	9580 570811	VALENTINA VLASOVA	{"email": "v-vlasova_041968@postgrespro.ru", "phone": "+70266451170"}
0005433123736	E1EDBA	1497 118491	SERGEY ANDREEV	{"email": "andreev-s.15121965@postgrespro.ru", "phone": "+70445671985"}
0005433123737	B059E8	1650 719393	EKATERINA YAKOVLEVA	{"phone": "+70767763828"}
0005433123738	71B1CF	1066 340678	VALENTINA FROLOVA	{"email": "frolovav17081969@postgrespro.ru", "phone": "+70542892922"}
0005433123739	71B1CF	2508 209073	IRINA FILIPPOVA	{"email": "i_filippova-1967@postgrespro.ru", "phone": "+70738246456"}
0005433123740	F84BE1	1821 656760	NIKOLAY PETROV	{"email": "nikolay-petrov.1975@postgrespro.ru", "phone": "+70552028815"}
0005433123741	A436FD	5408 922354	SVETLANA KUZMINA	{"email": "s_kuzmina-011974@postgrespro.ru", "phone": "+70674311672"}
0005433123742	8F4104	3036 847543	EGOR RODIONOV	{"phone": "+70666697016"}
0005433123743	19D595	3555 531156	VLADISLAV MAKSIMOV	{"email": "maksimov-vladislav1962@postgrespro.ru", "phone": "+70313969920"}
0005433123744	19D595	1932 009243	NADEZHDA OVCHINNIKOVA	{"phone": "+70902198248"}
0005433123745	A2C38C	3320 729149	TATYANA TITOVA	{"email": "tatyana-titova-071973@postgrespro.ru", "phone": "+70332348147"}
0005433123746	A2C38C	4563 352416	VLADIMIR NAUMOV	{"email": "v-naumov-1966@postgrespro.ru", "phone": "+70272298841"}
0005433123747	D7AD1C	4648 945225	DMITRIY GRIGOREV	{"email": "grigorevd101972@postgrespro.ru", "phone": "+70619526784"}
0005433123748	D7AD1C	9824 530762	LYUBOV SMIRNOVA	{"phone": "+70076291649"}
0005433123749	5F282B	3495 292524	ALEKSANDR ANDREEV	{"email": "aandreev1966@postgrespro.ru", "phone": "+70065339259"}
0005433123750	6AAA0B	6816 274122	VLADIMIR FILIPPOV	{"phone": "+70528404810"}
0005433123751	6AAA0B	6459 420914	VERA KONOVALOVA	{"email": "vkonovalova-1980@postgrespro.ru", "phone": "+70658196830"}
0005433123752	12CB15	4968 875576	EVGENIY NAUMOV	{"phone": "+70344295789"}
0005433123753	12CB15	9278 405808	ANNA STEPANOVA	{"phone": "+70968206103"}
0005433123754	D98F77	9627 977776	ALEKSANDR CHERNOV	{"phone": "+70683260451"}
0005433123755	D98F77	4934 577451	LEONID FEDOROV	{"email": "l_fedorov_30051970@postgrespro.ru", "phone": "+70375844887"}
0005433123923	31418F	6846 870004	TAISIYA KARPOVA	{"phone": "+70164729243"}
0005433123756	BEDAD1	7460 526323	SERGEY EGOROV	{"email": "sergey.egorov071971@postgrespro.ru", "phone": "+70047887013"}
0005433123757	F12620	8717 611068	NATALYA VLASOVA	{"email": "vlasova.natalya031978@postgrespro.ru", "phone": "+70111849396"}
0005433123758	F12620	5942 093982	ALEKSANDR PAVLOV	{"phone": "+70340034616"}
0005433123759	033CB9	4881 746463	ANNA VLASOVA	{"email": "vlasova-a.041967@postgrespro.ru", "phone": "+70243950493"}
0005433123760	B497BF	0874 593308	EVGENIY VLASOV	{"email": "vlasov.evgeniy031971@postgrespro.ru", "phone": "+70045075085"}
0005433123761	B8759F	4794 978040	FARIDA FADEEVA	{"phone": "+70482627245"}
0005433123762	43A0D6	7731 469795	LYUBOV ZHURAVLEVA	{"email": "l-zhuravleva08021966@postgrespro.ru", "phone": "+70333252915"}
0005433123763	F7D78A	2253 580284	ALEKSANDR KISELEV	{"phone": "+70491366437"}
0005433123764	F7D78A	8253 758477	VIKTOR NIKOLAEV	{"phone": "+70353705646"}
0005433123765	65980D	1173 368710	OLGA MELNIKOVA	{"phone": "+70401126877"}
0005433123766	E1521D	3407 504025	EKATERINA BARANOVA	{"email": "baranova-e-041972@postgrespro.ru", "phone": "+70270010724"}
0005433123767	8E0CAF	7786 623320	GENNADIY KUZMIN	{"phone": "+70572716496"}
0005433123768	B75EB1	6707 143074	NINA KULIKOVA	{"phone": "+70070238741"}
0005433123769	254778	9178 752542	GENNADIY KUZNECOV	{"phone": "+70111829804"}
0005433123770	680102	6244 151797	VASILIY KAZAKOV	{"email": "vkazakov031970@postgrespro.ru", "phone": "+70378461439"}
0005433123771	F19C46	5829 029823	ANDREY KOROLEV	{"phone": "+70494501308"}
0005433123772	084F66	0338 288402	IVAN PETROV	{"email": "petrovivan-29031966@postgrespro.ru", "phone": "+70608338882"}
0005433123773	DD402B	7019 221369	ELENA NIKITINA	{"email": "nikitinaelena_20111969@postgrespro.ru", "phone": "+70258238765"}
0005433123774	E4B05A	2155 819897	MAKSIM TARASOV	{"phone": "+70789674738"}
0005433123775	AC0DAC	9571 034625	VASILIY AFANASEV	{"phone": "+70736804637"}
0005433123776	A9638C	2277 672081	MARINA TARASOVA	{"email": "m_tarasova_091963@postgrespro.ru", "phone": "+70822062011"}
0005433123777	63B77B	7850 901194	NATALYA YAKOVLEVA	{"email": "natalya-yakovleva_071955@postgrespro.ru", "phone": "+70686917208"}
0005433123778	63B77B	9838 700878	DENIS KULIKOV	{"phone": "+70044768650"}
0005433123779	B996A2	5021 460124	SVETLANA ORLOVA	{"email": "orlova-svetlana1966@postgrespro.ru", "phone": "+70982404219"}
0005433123780	15C432	5774 140011	ANASTASIYA ABRAMOVA	{"phone": "+70822445600"}
0005433123782	D87ED9	9335 467958	ALEKSANDRA FILATOVA	{"phone": "+70429784762"}
0005433123783	DE671F	0178 599130	EVGENIY KOZLOV	{"email": "kozlov.evgeniy101972@postgrespro.ru", "phone": "+70023750077"}
0005433123784	DE671F	3083 098837	ALEKSANDR GERASIMOV	{"email": "gerasimovaleksandr_051966@postgrespro.ru", "phone": "+70812078561"}
0005433123785	2FDCAC	4962 152247	ALEKSANDRA FILATOVA	{"email": "filatova_a-05101956@postgrespro.ru", "phone": "+70132807502"}
0005433123786	2E3194	6141 222268	ANDREY SIDOROV	{"email": "andrey.sidorov-06021969@postgrespro.ru", "phone": "+70748898267"}
0005433123787	3E1336	7738 666019	ANATOLIY FEDOROV	{"phone": "+70788824129"}
0005433123788	3E1336	5920 662428	ILDAR PETROV	{"email": "petrovildar-101969@postgrespro.ru", "phone": "+70123797395"}
0005433123789	D9D298	5155 092746	EVGENIY ZHURAVLEV	{"email": "zhuravlev.evgeniy_021979@postgrespro.ru", "phone": "+70470594287"}
0005433123790	D9D298	6259 449433	MARIYA KUZNECOVA	{"email": "mariyakuznecova_30101985@postgrespro.ru", "phone": "+70481989414"}
0005433123791	9FF659	3825 299781	MARIYA IVANOVA	{"phone": "+70434246576"}
0005433123792	9FF659	0001 452969	VIKTOR SIDOROV	{"email": "vsidorov1965@postgrespro.ru", "phone": "+70254734948"}
0005433123793	8C2981	0331 882176	VLADIMIR SERGEEV	{"phone": "+70542734730"}
0005433123794	7B0570	5844 530386	GENNADIY KARPOV	{"phone": "+70018606338"}
0005433123795	556000	0759 954822	IGOR GORBUNOV	{"email": "gorbunov_igor.1974@postgrespro.ru", "phone": "+70731139318"}
0005433123796	6DBF39	4464 044733	EVGENIY GRIGOREV	{"email": "grigorev_evgeniy.18011966@postgrespro.ru", "phone": "+70971407900"}
0005433123797	830AF4	4302 208256	NIKITA KULIKOV	{"phone": "+70139302188"}
0005433123798	830AF4	0969 526319	LYUDMILA LUKYANOVA	{"phone": "+70957550407"}
0005433123799	A38795	1704 270485	NATALYA DENISOVA	{"email": "denisova_n111971@postgrespro.ru", "phone": "+70580834467"}
0005433123800	81BE70	0808 910232	ARTEM SOLOVEV	{"phone": "+70504576329"}
0005433123801	114F7F	4252 430697	ANZHELA MIKHAYLOVA	{"email": "mikhaylova-anzhela1967@postgrespro.ru", "phone": "+70884595947"}
0005433123802	114F7F	5603 038568	EKATERINA GAVRILOVA	{"phone": "+70991134779"}
0005433123803	3C0867	6604 789340	AMIR TIKHONOV	{"email": "a.tikhonov-1978@postgrespro.ru", "phone": "+70397777261"}
0005433123804	FC5D9A	7655 330538	DMITRIY KONOVALOV	{"email": "d_konovalov-061971@postgrespro.ru", "phone": "+70164282290"}
0005433123805	256064	3693 277057	SERGEY ROMANOV	{"phone": "+70464860890"}
0005433123806	2DF55D	0376 923214	VLADIMIR MAKAROV	{"email": "vmakarov_20101979@postgrespro.ru", "phone": "+70490303399"}
0005433123807	6E48D2	3691 295148	ILYA ALEKSEEV	{"email": "i_alekseev.121968@postgrespro.ru", "phone": "+70718727091"}
0005433123808	6E48D2	9840 775950	RADIK KUZNECOV	{"phone": "+70735267563"}
0005433123809	E95EF7	8978 703414	IRINA ZAKHAROVA	{"phone": "+70171868762"}
0005433123810	D7383B	3782 193724	NATALYA KUZMINA	{"phone": "+70586656242"}
0005433123811	1BB49B	9157 434647	TATYANA GUSEVA	{"phone": "+70456991196"}
0005433123812	A76B5E	0624 355603	NIKOLAY PETROV	{"email": "n_petrov_08121980@postgrespro.ru", "phone": "+70458312734"}
0005433123813	A76B5E	8209 085933	PELAGEYA DMITRIEVA	{"email": "pelageyadmitrieva-27111970@postgrespro.ru", "phone": "+70581359740"}
0005433123814	68582C	9821 123733	ELENA TIMOFEEVA	{"email": "elena.timofeeva.051984@postgrespro.ru", "phone": "+70063479978"}
0005433123815	68582C	3183 804160	VALERIY FOMIN	{"phone": "+70989697947"}
0005433123816	5CB4D3	6310 749152	NIKITA SHEVCHENKO	{"email": "nshevchenko-22121967@postgrespro.ru", "phone": "+70564820521"}
0005433123817	5CB4D3	8879 265427	ELENA SMIRNOVA	{"phone": "+70740320883"}
0005433123818	9DDBC0	0668 030479	YULIYA RYABOVA	{"email": "ryabova_y.011989@postgrespro.ru", "phone": "+70438038411"}
0005433123819	6A0523	9376 415039	TAISIYA KOMAROVA	{"phone": "+70665841160"}
0005433123820	A81268	7620 896947	VALERIY DAVYDOV	{"email": "v.davydov1962@postgrespro.ru", "phone": "+70847650327"}
0005433123821	A81268	5364 010844	ELIZAVETA KUZNECOVA	{"email": "elizaveta.kuznecova-13021957@postgrespro.ru", "phone": "+70623240405"}
0005433123822	DBF932	6047 528549	ELENA ZAKHAROVA	{"phone": "+70767654833"}
0005433123823	E5151B	7530 804642	ARSENIY SMIRNOV	{"phone": "+70798694056"}
0005433123824	6327ED	2737 208011	NATALYA KOZLOVA	{"email": "n-kozlova1968@postgrespro.ru", "phone": "+70117715833"}
0005433123825	EC14B6	0251 665884	MIKHAIL IVANOV	{"email": "ivanov-mikhail-1966@postgrespro.ru", "phone": "+70990729913"}
0005433123826	58AB04	8752 943408	KRISTINA STEPANOVA	{"email": "stepanova_k23121963@postgrespro.ru", "phone": "+70844156164"}
0005433123827	A35125	3965 135901	ELENA FROLOVA	{"email": "efrolova.03041975@postgrespro.ru", "phone": "+70269011905"}
0005433123828	2DD679	8475 008311	ZOYA KRASNOVA	{"email": "krasnova_z.1971@postgrespro.ru", "phone": "+70139493006"}
0005433123829	AC6EC5	1968 176875	NATALYA ARKHIPOVA	{"phone": "+70381957586"}
0005433123830	AC6EC5	8816 509221	VIKTOR IVANOV	{"phone": "+70515308527"}
0005433123831	37F87D	1937 685393	IVAN VLASOV	{"email": "ivanvlasov-031962@postgrespro.ru", "phone": "+70302119332"}
0005433123832	C578A0	2333 734316	DMITRIY MOROZOV	{"email": "d-morozov_1976@postgrespro.ru", "phone": "+70742680289"}
0005433123833	C578A0	7483 017012	OLEG ALEKSEEV	{"phone": "+70826416527"}
0005433123834	EC043F	1266 664631	MARIYA SEMENOVA	{"phone": "+70959396501"}
0005433123835	2DDE10	7602 883634	ARTUR SHEVCHENKO	{"phone": "+70598349554"}
0005433123836	9EFBAC	3755 023283	VLADIMIR ANDREEV	{"phone": "+70276265964"}
0005433123837	9EFBAC	6940 983199	ELENA SMIRNOVA	{"email": "smirnovaelena.23051972@postgrespro.ru", "phone": "+70858507523"}
0005433123838	86E87A	9135 079431	SERGEY SIDOROV	{"phone": "+70349428499"}
0005433123839	86E87A	5569 067611	ASIYA KONOVALOVA	{"email": "asiyakonovalova021978@postgrespro.ru", "phone": "+70017255975"}
0005433123840	75E72C	9149 345764	ALEKSANDR GUSEV	{"email": "gusevaleksandr-03081980@postgrespro.ru", "phone": "+70619788265"}
0005433123841	A8B233	7416 055098	OLGA TITOVA	{"phone": "+70498870401"}
0005433123842	A8B233	6113 514196	SERGEY DAVYDOV	{"phone": "+70788110509"}
0005433123843	9AF851	1661 259556	SERGEY CHERNOV	{"email": "chernov_sergey_091972@postgrespro.ru", "phone": "+70502399217"}
0005433123844	B176E1	9725 348639	OLEG NIKITIN	{"phone": "+70466953980"}
0005433123845	B1FB8D	7826 752905	TATYANA MIKHAYLOVA	{"phone": "+70058486195"}
0005433123846	B1FB8D	2777 060502	IVAN SIDOROV	{"email": "sidorovivan_01081970@postgrespro.ru", "phone": "+70483604840"}
0005433123847	B1FB8D	3743 543409	EVGENIY VOROBEV	{"email": "evgeniy.vorobev_041977@postgrespro.ru", "phone": "+70208873622"}
0005433123848	A01A3B	7871 269951	ALINA FROLOVA	{"phone": "+70854090335"}
0005433123849	38800C	3476 866270	MIKHAIL PAVLOV	{"phone": "+70621203123"}
0005433123850	31A345	0699 820935	FEDOR ABRAMOV	{"email": "abramov-fedor051965@postgrespro.ru", "phone": "+70477698009"}
0005433123851	31A345	7522 799579	PAVEL KULIKOV	{"phone": "+70990231041"}
0005433123852	4DCBE9	4604 020688	NIKITA TARASOV	{"phone": "+70750756647"}
0005433123853	AE0927	8625 362436	LYUBOV KARPOVA	{"phone": "+70797109394"}
0005433123854	2A61DA	6449 747523	RUSLAN FEDOROV	{"email": "fedorovr-1975@postgrespro.ru", "phone": "+70991085586"}
0005433123855	9A97D4	6790 811676	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a-061971@postgrespro.ru", "phone": "+70441284282"}
0005433123856	9A97D4	2485 747960	LIDIYA NIKITINA	{"phone": "+70847467696"}
0005433123857	2AC162	6149 437696	VIKTOR KUDRYASHOV	{"phone": "+70254236651"}
0005433123858	85E137	7499 899395	ELENA BELYAEVA	{"phone": "+70558261628"}
0005433123859	FEE7D0	2088 200132	EVGENIYA DMITRIEVA	{"phone": "+70950345577"}
0005433123860	FEE7D0	9769 593897	DMITRIY NOVIKOV	{"phone": "+70978772209"}
0005433123861	FEE7D0	9045 580503	YURIY ALEKSANDROV	{"email": "aleksandrovy_1974@postgrespro.ru", "phone": "+70830415603"}
0005433123862	C563B8	7652 714477	VLADIMIR ANDREEV	{"email": "vladimir-andreev-1964@postgrespro.ru", "phone": "+70736186201"}
0005433123863	4DA339	9952 452456	KSENIYA KUZNECOVA	{"email": "kuznecova-kseniya.1972@postgrespro.ru", "phone": "+70540089639"}
0005433123864	118CE0	9697 355874	NIKITA KAZAKOV	{"email": "kazakovnikita_011976@postgrespro.ru", "phone": "+70599463921"}
0005433123865	DD0109	9637 384931	OLESYA KUZNECOVA	{"phone": "+70386590125"}
0005433123866	369AD6	9376 066502	SERGEY KAZAKOV	{"email": "sergey.kazakov1965@postgrespro.ru", "phone": "+70201302437"}
0005433123867	EEFA39	5888 093078	VYACHESLAV PAVLOV	{"phone": "+70659402775"}
0005433123868	988DB8	1888 691426	VIKTOR MAKAROV	{"email": "makarovviktor-1976@postgrespro.ru", "phone": "+70820606327"}
0005433123869	F8715C	4991 319402	ALEKSEY FEDOTOV	{"email": "a.fedotov13081974@postgrespro.ru", "phone": "+70636361959"}
0005433123870	B89183	0121 608847	DMITRIY KUZNECOV	{"phone": "+70424588093"}
0005433123871	EC2369	2587 761151	YULIYA NOVIKOVA	{"email": "novikova_y.1977@postgrespro.ru", "phone": "+70124188317"}
0005433123872	C06362	5967 593325	LYUDMILA NESTEROVA	{"email": "nesterovalyudmila_011973@postgrespro.ru", "phone": "+70135257719"}
0005433123873	5ECB5B	7942 682338	ALEKSANDR DAVYDOV	{"phone": "+70420739612"}
0005433123874	5ECB5B	4395 599768	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov_1982@postgrespro.ru", "phone": "+70100718491"}
0005433123875	C28642	7551 657319	RAISA VOLKOVA	{"phone": "+70867169824"}
0005433123876	72B15E	0237 106154	ALEKSANDR SEMENOV	{"phone": "+70576369084"}
0005433123877	3BB8E9	5423 468436	PAVEL PAVLOV	{"email": "pavelpavlov.011963@postgrespro.ru", "phone": "+70298948638"}
0005433123878	254335	1105 303091	VALENTINA NESTEROVA	{"phone": "+70535022134"}
0005433123879	CAD71B	4442 199860	MARINA KOLESNIKOVA	{"email": "kolesnikova_marina16061963@postgrespro.ru", "phone": "+70399766680"}
0005433123880	CAD71B	3292 813919	VYACHESLAV GUSEV	{"phone": "+70353955078"}
0005433123881	C019F5	9836 920691	DMITRIY BORISOV	{"phone": "+70733731150"}
0005433123882	029502	2545 690889	ANDREY SIDOROV	{"email": "sidorovandrey_091969@postgrespro.ru", "phone": "+70949328901"}
0005433123883	2956AB	9428 123323	TATYANA SOROKINA	{"email": "sorokinat.031966@postgrespro.ru", "phone": "+70464722696"}
0005433123884	014831	2594 860602	OLGA AFANASEVA	{"email": "afanaseva.o.1970@postgrespro.ru", "phone": "+70607954030"}
0005433123885	014831	0506 454873	IGOR ROMANOV	{"email": "romanov_igor_16071980@postgrespro.ru", "phone": "+70517760829"}
0005433123886	C60DDA	5964 829047	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda-1970@postgrespro.ru", "phone": "+70109178363"}
0005433123887	D33708	9886 920971	OLESYA ZAKHAROVA	{"email": "olesyazakharova1980@postgrespro.ru", "phone": "+70860103681"}
0005433123888	E434E9	3837 180704	ROMAN MELNIKOV	{"email": "melnikovroman1965@postgrespro.ru", "phone": "+70582893116"}
0005433123889	D6CB6E	8770 599651	ANATOLIY MAKAROV	{"phone": "+70612723768"}
0005433123890	D6CB6E	6404 309543	ALEKSANDR NIKITIN	{"email": "nikitina1977@postgrespro.ru", "phone": "+70689056299"}
0005433123891	D6CB6E	9965 931855	OLGA SOROKINA	{"email": "olga-sorokina.07021966@postgrespro.ru", "phone": "+70065975010"}
0005433123892	8C4531	2063 414173	GALINA PETROVA	{"email": "galina-petrova_22011970@postgrespro.ru", "phone": "+70322626537"}
0005433123893	8C4531	4437 480817	RINAT VASILEV	{"email": "rinat.vasilev-11091968@postgrespro.ru", "phone": "+70481224953"}
0005433123894	ACFBC5	3613 529808	VALENTINA ANISIMOVA	{"email": "vanisimova_1970@postgrespro.ru", "phone": "+70320555827"}
0005433123895	9DC1AC	5169 114435	MIKHAIL DMITRIEV	{"email": "dmitriev.mikhail-1959@postgrespro.ru", "phone": "+70679423136"}
0005433123896	3F1743	5442 163775	SERGEY SOKOLOV	{"phone": "+70801349340"}
0005433123897	C2EA1E	3028 215138	YANA ZAKHAROVA	{"email": "zakharova-y-26051975@postgrespro.ru", "phone": "+70829238010"}
0005433123898	3C9B5B	0375 980522	ALEKSEY AFANASEV	{"email": "a_afanasev-071968@postgrespro.ru", "phone": "+70494064477"}
0005433123899	5E217E	1551 967097	VLADIMIR GRIGOREV	{"phone": "+70665709972"}
0005433123900	536F44	7218 559448	MIKHAIL PETROV	{"phone": "+70829341645"}
0005433123901	536F44	5565 624853	TATYANA KALININA	{"phone": "+70251579885"}
0005433123902	536F44	2634 758366	GENNADIY SIDOROV	{"email": "g-sidorov091972@postgrespro.ru", "phone": "+70549990493"}
0005433123903	F87131	5886 452225	TATYANA FOMINA	{"email": "fomina_tatyana_011973@postgrespro.ru", "phone": "+70299813905"}
0005433123904	A408BB	9590 710462	VADIM IVANOV	{"phone": "+70446731829"}
0005433123905	541D60	3816 740139	NATALYA BELYAEVA	{"phone": "+70437134141"}
0005433123906	C7F59E	9340 815759	VYACHESLAV SOKOLOV	{"email": "sokolov-vyacheslav-051987@postgrespro.ru", "phone": "+70185203265"}
0005433123907	722DF5	0319 666308	VERA SOKOLOVA	{"phone": "+70597678646"}
0005433123908	CBCE64	8722 603779	EKATERINA ZAKHAROVA	{"email": "zakharova_ekaterina_1974@postgrespro.ru", "phone": "+70952202531"}
0005433123909	CBCE64	1326 621055	ILDAR VOROBEV	{"phone": "+70453779361"}
0005433123910	5473C7	9808 316774	VALENTINA MAKAROVA	{"phone": "+70028845656"}
0005433123911	F99D65	6661 181378	ALEKSEY PETROV	{"email": "petrovaleksey-1966@postgrespro.ru", "phone": "+70130496803"}
0005433123912	F99D65	5285 384439	ANNA MATVEEVA	{"phone": "+70942525287"}
0005433123913	F20323	9977 894842	ANATOLIY VOLKOV	{"phone": "+70282111438"}
0005433123914	4F6BA4	8261 736332	MARAT DENISOV	{"phone": "+70049640830"}
0005433123915	4F6BA4	9882 977958	MARIYA CHERNOVA	{"email": "m_chernova_03011974@postgrespro.ru", "phone": "+70576156918"}
0005433123916	CE5039	7398 930637	ALEKSEY NAZAROV	{"email": "nazarov-a011964@postgrespro.ru", "phone": "+70119386454"}
0005433123917	CE5039	8873 298273	TATYANA FADEEVA	{"email": "tatyana.fadeeva.17121959@postgrespro.ru", "phone": "+70706481958"}
0005433123918	C3B3D8	2242 160402	ALEKSANDR KONOVALOV	{"email": "konovalov-a061984@postgrespro.ru", "phone": "+70159462360"}
0005433123919	001789	3982 997408	DIANA SMIRNOVA	{"email": "smirnovad.07061969@postgrespro.ru", "phone": "+70117888026"}
0005433123920	3BD222	6196 635111	ALLA NIKITINA	{"phone": "+70412507258"}
0005433123921	E780C1	7002 411462	ALEKSEY POPOV	{"email": "popov_a-1983@postgrespro.ru", "phone": "+70384549572"}
0005433123922	E2C6E3	9599 156672	VERA SCHERBAKOVA	{"email": "scherbakova.vera.15041972@postgrespro.ru", "phone": "+70004096468"}
0005433123924	C2CAE8	7610 028022	LYUDMILA BOGDANOVA	{"email": "bogdanova_lyudmila1970@postgrespro.ru", "phone": "+70929615315"}
0005433123925	06E6CB	1783 625011	ALEKSANDR BARANOV	{"phone": "+70392285886"}
0005433123926	9CAC88	0799 757419	ANNA BELOVA	{"phone": "+70589415824"}
0005433123927	C14859	1274 123865	ALEKSANDR IVANOV	{"phone": "+70511130149"}
0005433123928	0B3851	7211 505745	RIMA ILINA	{"email": "ilina-rima19051977@postgrespro.ru", "phone": "+70973175908"}
0005433123929	0B3851	6346 246438	ALEKSANDRA FILATOVA	{"phone": "+70132256138"}
0005433123930	3EC66B	9950 862877	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova-061964@postgrespro.ru", "phone": "+70541290354"}
0005433123931	4B64A2	1316 307738	VITALIY ALEKSEEV	{"phone": "+70092038373"}
0005433123932	4B64A2	8022 452661	SERGEY KUZMIN	{"email": "skuzmin_061967@postgrespro.ru", "phone": "+70046462550"}
0005433123933	992944	8333 817266	RUSLAN KAZAKOV	{"email": "kazakov.r-04121981@postgrespro.ru", "phone": "+70034167887"}
0005433123934	C46C2D	2980 155647	EMIL STEPANOV	{"email": "stepanov_emil-031973@postgrespro.ru", "phone": "+70350684637"}
0005433123935	C46C2D	3999 009604	ARTUR IVANOV	{"email": "ivanov.artur_27041969@postgrespro.ru", "phone": "+70171015263"}
0005433123936	904118	2353 836654	LIDIYA EFIMOVA	{"phone": "+70316139095"}
0005433123937	E66DA7	8024 369558	VLADIMIR ANDREEV	{"email": "andreevv.30011973@postgrespro.ru", "phone": "+70385914714"}
0005433123938	E66DA7	4452 197385	MARAT VOLKOV	{"email": "volkov-m091967@postgrespro.ru", "phone": "+70957302379"}
0005433123939	C504AC	2552 238889	YURIY BORISOV	{"phone": "+70438669361"}
0005433123940	656B36	8091 313360	EKATERINA ANDREEVA	{"phone": "+70786959120"}
0005433123941	656B36	6314 698964	MIKHAIL IVANOV	{"email": "m_ivanov_1973@postgrespro.ru", "phone": "+70269139613"}
0005433123942	B4E473	5913 281574	ILSHAT PETROV	{"email": "petrov.ilshat.1970@postgrespro.ru", "phone": "+70478023620"}
0005433123943	B4E473	2579 896361	NATALYA GAVRILOVA	{"email": "natalyagavrilova1978@postgrespro.ru", "phone": "+70876751866"}
0005433123944	B4E473	8721 652146	IRINA MALYSHEVA	{"phone": "+70061534107"}
0005433123945	17A559	4320 467841	KSENIYA NIKOLAEVA	{"phone": "+70363342833"}
0005433123946	17A559	1629 677762	RAFAIL VOROBEV	{"email": "rafail-vorobev26081972@postgrespro.ru", "phone": "+70383487838"}
0005433123947	FDB299	2619 104311	VALENTINA NIKOLAEVA	{"email": "valentina-nikolaeva-11101970@postgrespro.ru", "phone": "+70917197702"}
0005433123948	FDB299	2125 349851	ANNA BELOVA	{"phone": "+70616948216"}
0005433123949	44C02B	7312 690107	ILYA IVANOV	{"email": "ivanov.ilya.30061986@postgrespro.ru", "phone": "+70886758145"}
0005433123950	44C02B	0854 054033	RUSLAN KUZNECOV	{"email": "kuznecov.r-111975@postgrespro.ru", "phone": "+70784035161"}
0005433123951	F26389	5627 890105	TATYANA MAKAROVA	{"phone": "+70158597833"}
0005433123952	637FAF	2685 056864	SERGEY KUZMIN	{"email": "kuzminsergey-011969@postgrespro.ru", "phone": "+70520288399"}
0005433123953	637FAF	4354 747006	RUSLAN ANDREEV	{"email": "randreev1964@postgrespro.ru", "phone": "+70583692331"}
0005433123954	0F832E	9271 094830	ALEKSANDRA PETROVA	{"email": "a.petrova-041964@postgrespro.ru", "phone": "+70827872142"}
0005433123955	0F832E	4879 931040	LARISA MOROZOVA	{"phone": "+70586681376"}
0005433123956	37E6C2	7891 813947	PETR KUZNECOV	{"email": "petr_kuznecov_1989@postgrespro.ru", "phone": "+70742480026"}
0005433123957	37E6C2	4451 258974	SERGEY KUZNECOV	{"phone": "+70325221166"}
0005433123958	7FEE38	4539 122110	ELINA ORLOVA	{"email": "orlova_elina-02041973@postgrespro.ru", "phone": "+70303556821"}
0005433123959	5E7B19	9442 388805	NADEZHDA FROLOVA	{"email": "n.frolova-25121982@postgrespro.ru", "phone": "+70640521406"}
0005433123960	5E7B19	7570 078795	IRINA FEDOROVA	{"email": "irina.fedorova-11091974@postgrespro.ru", "phone": "+70561240558"}
0005433123961	5E7B19	4449 526504	DANIIL SCHERBAKOV	{"phone": "+70620488991"}
0005433123962	440682	1816 859543	YURIY SIDOROV	{"email": "sidorov.y.071964@postgrespro.ru", "phone": "+70226965432"}
0005433123963	440682	0213 009688	IGOR POPOV	{"phone": "+70958865377"}
0005433123964	1DACE4	7536 883742	ALESYA ALEKSEEVA	{"phone": "+70983173696"}
0005433123965	0F7109	5844 107961	NADEZHDA IVANOVA	{"phone": "+70767524247"}
0005433123966	F89F6B	4937 059367	LYUBOV ALEKSEEVA	{"phone": "+70033178759"}
0005433123967	F89F6B	9059 267236	ANASTASIYA KONDRATEVA	{"email": "kondrateva_a_06071971@postgrespro.ru", "phone": "+70461521612"}
0005433123968	D89F47	7544 530156	ILYA TARASOV	{"phone": "+70923189680"}
0005433123969	16A241	0586 696181	ANASTASIYA KONDRATEVA	{"phone": "+70541821094"}
0005433123970	68184E	1944 014158	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a.31101985@postgrespro.ru", "phone": "+70150011256"}
0005433123971	3C2292	1668 856159	VIKTOR SEMENOV	{"email": "semenovv31081968@postgrespro.ru", "phone": "+70839206104"}
0005433123972	3C2292	0271 285530	ALEKSANDR SMIRNOV	{"phone": "+70455167148"}
0005433123973	378D83	8577 084999	OLESYA KUZNECOVA	{"email": "kuznecova-olesya_16091978@postgrespro.ru", "phone": "+70919441046"}
0005433123974	2AEEE9	5231 664533	SVETLANA CHERNOVA	{"phone": "+70836766709"}
0005433123975	F482A3	8400 768276	ANTONINA TIKHONOVA	{"email": "tikhonovaa-121975@postgrespro.ru", "phone": "+70615274719"}
0005433123976	2340EB	2600 594521	YANA ILINA	{"phone": "+70568099873"}
0005433123977	2340EB	2187 983482	LYUBOV AKIMOVA	{"email": "lyubov-akimova1980@postgrespro.ru", "phone": "+70825499577"}
0005433123978	A3A00A	8377 032045	ANNA VASILEVA	{"email": "vasileva-anna_1974@postgrespro.ru", "phone": "+70829084885"}
0005433123979	DFCE43	5698 907862	ALEKSEY ILIN	{"phone": "+70300524761"}
0005433123980	DFCE43	1584 725439	TAMARA ABRAMOVA	{"email": "tabramova031978@postgrespro.ru", "phone": "+70811576908"}
0005433123981	A11AE6	2088 283589	VALERIY KUZNECOV	{"phone": "+70336965620"}
0005433123982	A11AE6	6787 449167	VLADISLAV SIDOROV	{"phone": "+70723264210"}
0005433123983	BAC441	6055 624501	NIKOLAY ANDREEV	{"email": "andreev_n.21041979@postgrespro.ru", "phone": "+70426473752"}
0005433123984	BAC441	7970 299173	DMITRIY FROLOV	{"email": "dmitriyfrolov02051969@postgrespro.ru", "phone": "+70775445935"}
0005433123985	68DBF2	0963 417171	DMITRIY MELNIKOV	{"phone": "+70152389888"}
0005433123986	68DBF2	6433 161108	IVAN POPOV	{"email": "ivan.popov081969@postgrespro.ru", "phone": "+70574362672"}
0005433123987	147088	6840 571900	MARIYA FEDOROVA	{"email": "fedorova.mariya_061971@postgrespro.ru", "phone": "+70065044186"}
0005433123988	9EBBEA	7509 710981	EKATERINA GAVRILOVA	{"email": "ekaterina.gavrilova-1968@postgrespro.ru", "phone": "+70060565267"}
0005433123989	9EBBEA	4396 564725	GALINA KUZNECOVA	{"email": "kuznecovag.17071961@postgrespro.ru", "phone": "+70886782036"}
0005433123990	782AF9	0908 940841	PAVEL TIMOFEEV	{"email": "timofeev.pavel.1969@postgrespro.ru", "phone": "+70183520395"}
0005433123991	A7BE5A	1553 915237	OLEG CHERNOV	{"email": "chernov-oleg-101980@postgrespro.ru", "phone": "+70472209588"}
0005433123992	106401	1401 120826	MAKSIM KOZLOV	{"phone": "+70025442311"}
0005433123993	106401	7586 000981	DARYA MAKAROVA	{"email": "makarova-darya_06111976@postgrespro.ru", "phone": "+70463457373"}
0005433123994	E77B0A	6827 327310	ILYA MATVEEV	{"phone": "+70336781478"}
0005433123995	14A2D6	9074 312790	DMITRIY CHERNOV	{"email": "dmitriychernov-01031981@postgrespro.ru", "phone": "+70068143084"}
0005433123996	1F4365	8933 164115	GALINA ROMANOVA	{"email": "g-romanova_1979@postgrespro.ru", "phone": "+70985273473"}
0005433123997	C70B7C	5554 806380	SVYATOSLAV VOROBEV	{"phone": "+70749291389"}
0005433123998	27B31C	3119 279733	ZOYA MATVEEVA	{"email": "matveeva-zoya-041960@postgrespro.ru", "phone": "+70093541459"}
0005433123999	CD331B	1350 498820	MARIYA POTAPOVA	{"phone": "+70255225664"}
0005433124000	F08F8E	4862 597584	NATALYA VOROBEVA	{"email": "nvorobeva_051969@postgrespro.ru", "phone": "+70280901011"}
0005433124001	1967EB	3146 362520	PETR NIKOLAEV	{"email": "nikolaev.p031969@postgrespro.ru", "phone": "+70284305798"}
0005433124002	1967EB	5137 041024	ELENA GORBUNOVA	{"email": "gorbunova_elena_02091978@postgrespro.ru", "phone": "+70551722161"}
0005433124003	028423	4672 139740	ANASTASIYA NIKIFOROVA	{"email": "nikiforova.anastasiya29121966@postgrespro.ru", "phone": "+70826981845"}
0005433124004	BE6E46	9078 695442	ALEKSANDR ANDREEV	{"phone": "+70185235529"}
0005433124005	BE6E46	4284 244870	LYUBOV DENISOVA	{"phone": "+70169522602"}
0005433124006	A3102A	7774 801649	ELENA MOISEEVA	{"email": "moiseeva_e.1971@postgrespro.ru", "phone": "+70124237433"}
0005433124007	61ACB0	9339 101473	TATYANA DENISOVA	{"phone": "+70656338236"}
0005433124008	DE3B7F	5809 367883	ALEKSANDR SIDOROV	{"phone": "+70303739563"}
0005433124009	DE3B7F	8903 504779	ANDREY GORBUNOV	{"email": "a_gorbunov_10031964@postgrespro.ru", "phone": "+70194764180"}
0005433124010	BFEF39	5717 077037	NINA GERASIMOVA	{"email": "n-gerasimova.24111967@postgrespro.ru", "phone": "+70139487623"}
0005433124011	BFEF39	9646 641789	ANNA FILIPPOVA	{"email": "anna.filippova_091978@postgrespro.ru", "phone": "+70494235235"}
0005433124012	861401	3814 441617	ALEKSANDR KRASNOV	{"email": "krasnov.a_1975@postgrespro.ru", "phone": "+70585115698"}
0005433124013	861401	7141 903381	VALENTINA VLASOVA	{"email": "vlasova-valentina_041978@postgrespro.ru", "phone": "+70932341656"}
0005433124014	982AE1	1109 304560	IGOR NIKITIN	{"phone": "+70928946399"}
0005433124015	7F97E0	3430 699529	TATYANA ZAYCEVA	{"email": "zayceva_tatyana_111963@postgrespro.ru", "phone": "+70226758552"}
0005433124016	291803	6283 029941	YAKOV IVANOV	{"phone": "+70417051540"}
0005433124017	397B04	4768 683045	MARINA SCHERBAKOVA	{"phone": "+70009125507"}
0005433124018	650940	2603 180564	SERGEY ANDREEV	{"phone": "+70233563214"}
0005433124019	CA6458	0053 713388	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov-1975@postgrespro.ru", "phone": "+70760109667"}
0005433124020	954041	1721 355496	ELENA EFIMOVA	{"phone": "+70460775242"}
0005433124021	8968F2	4567 700290	ANDREY BELOV	{"email": "belov.andrey_25021967@postgrespro.ru", "phone": "+70922980315"}
0005433124022	8968F2	8828 910564	ELMIRA IVANOVA	{"phone": "+70832514092"}
0005433124023	FBD328	0838 061957	IRINA NOVIKOVA	{"email": "inovikova_14121968@postgrespro.ru", "phone": "+70369667348"}
0005433124024	C9D11E	3625 997783	MARIYA DAVYDOVA	{"phone": "+70088317944"}
0005433124025	C9D11E	2400 727354	VLADISLAV KARPOV	{"email": "karpov_vladislav-01091976@postgrespro.ru", "phone": "+70282765767"}
0005433124026	D280DA	7835 075574	SERGEY ANTONOV	{"phone": "+70076856724"}
0005433124027	12652F	4704 873218	PAVEL GRIGOREV	{"email": "grigorev.pavel-021972@postgrespro.ru", "phone": "+70145586248"}
0005433124028	12652F	1759 758233	TAISIYA ZHURAVLEVA	{"email": "taisiyazhuravleva.24101962@postgrespro.ru", "phone": "+70763604255"}
0005433124029	71FBBB	3276 768543	TATYANA ANDREEVA	{"phone": "+70291384793"}
0005433124030	71FBBB	8866 047868	ROMAN BONDARENKO	{"phone": "+70684207818"}
0005433124031	DA74CD	2971 061114	EKATERINA KOLESNIKOVA	{"email": "ekaterina.kolesnikova_29061969@postgrespro.ru", "phone": "+70573924854"}
0005433124032	229E15	5010 837402	DMITRIY ANTONOV	{"phone": "+70230277663"}
0005433124033	229E15	8348 425063	VIKTOR ROMANOV	{"email": "v.romanov.101970@postgrespro.ru", "phone": "+70231515455"}
0005433124034	6611C8	2745 430641	MIKHAIL SOLOVEV	{"email": "m-solovev-11111969@postgrespro.ru", "phone": "+70408662375"}
0005433124035	703241	0414 934944	NIKOLAY MOISEEV	{"email": "moiseevn.04061963@postgrespro.ru", "phone": "+70932780299"}
0005433124036	703241	2505 246233	VLADIMIR TARASOV	{"email": "vtarasov_1981@postgrespro.ru", "phone": "+70972040453"}
0005433124037	3D6F16	0229 290449	ALBINA MOROZOVA	{"email": "albina_morozova11091974@postgrespro.ru", "phone": "+70240049912"}
0005433124038	3D6F16	1503 112855	VALENTINA KUZNECOVA	{"phone": "+70867265099"}
0005433124039	0DA799	6920 180323	MARINA NOVIKOVA	{"phone": "+70435305577"}
0005433124040	F7B59D	6430 241989	GALINA NAZAROVA	{"email": "nazarova_g1968@postgrespro.ru", "phone": "+70695721180"}
0005433124041	F7B59D	7340 761830	SERGEY SMIRNOV	{"phone": "+70421780494"}
0005433124042	6C995F	5808 884146	ALFIYA KONOVALOVA	{"email": "konovalovaa-16011970@postgrespro.ru", "phone": "+70817458176"}
0005433124043	6C995F	1605 819313	VIKTOR GUSEV	{"phone": "+70123700638"}
0005433124044	32133D	2041 933840	LYUDMILA EFREMOVA	{"email": "lyudmila_efremova.20081974@postgrespro.ru", "phone": "+70899210946"}
0005433124045	4A7681	5669 576843	ULYANA ERMAKOVA	{"phone": "+70034012280"}
0005433124046	406B15	3978 772475	YURIY ZAKHAROV	{"email": "yuriy_zakharov-03121978@postgrespro.ru", "phone": "+70768793720"}
0005433124047	844F00	1563 019041	STANISLAV RODIONOV	{"phone": "+70993049898"}
0005433124048	0C7B3A	4319 138135	MIKHAIL YAKOVLEV	{"email": "yakovlev_m1966@postgrespro.ru", "phone": "+70617215598"}
0005433124049	0C7B3A	2756 931911	ANDREY ABRAMOV	{"email": "aabramov061965@postgrespro.ru", "phone": "+70210366153"}
0005433124050	70E89D	2687 391064	ALEKSEY NOVIKOV	{"email": "a-novikov.031954@postgrespro.ru", "phone": "+70953080409"}
0005433124051	18CD8C	0360 848804	IRINA IVANOVA	{"phone": "+70578899054"}
0005433124052	BB027E	8551 221769	DMITRIY SEMENOV	{"phone": "+70693733061"}
0005433124053	C23910	2284 167762	IRINA CHERNOVA	{"phone": "+70811455571"}
0005433124054	77696D	7625 163966	OLGA VASILEVA	{"phone": "+70124237221"}
0005433124055	77696D	3019 117547	MARINA POPOVA	{"phone": "+70260228689"}
0005433124056	9ADDB8	3364 225888	VALENTINA MARTYNOVA	{"phone": "+70995552845"}
0005433124057	B59427	4619 321046	VLADIMIR MAKSIMOV	{"email": "v.maksimov-011969@postgrespro.ru", "phone": "+70045519794"}
0005433124058	6FEFE3	1248 911790	VALENTINA VOROBEVA	{"phone": "+70721607512"}
0005433124059	D9EABA	4599 783112	ANASTASIYA VLASOVA	{"email": "anastasiya.vlasova121968@postgrespro.ru", "phone": "+70153200582"}
0005433124060	199963	7526 258141	VASILIY ANDREEV	{"email": "andreevvasiliy081971@postgrespro.ru", "phone": "+70057561957"}
0005433124061	DDEA55	6684 888935	RAISA SAVELEVA	{"email": "raisasaveleva.25081968@postgrespro.ru", "phone": "+70423527194"}
0005433124062	1627C3	2590 360972	STANISLAV SOROKIN	{"email": "stanislavsorokin-031968@postgrespro.ru", "phone": "+70601509787"}
0005433124063	485D4F	7601 727947	IVAN OSIPOV	{"email": "osipovi.091973@postgrespro.ru", "phone": "+70058469540"}
0005433124064	485D4F	2284 944363	KLAVDIYA EFIMOVA	{"email": "klavdiya.efimova-101966@postgrespro.ru", "phone": "+70687353341"}
0005433124065	96A3C2	5694 478155	ANGELINA FROLOVA	{"phone": "+70711341275"}
0005433124066	90F508	2212 495802	SVETLANA SOLOVEVA	{"phone": "+70319374773"}
0005433124067	90F508	8203 493452	EVGENIY ZHURAVLEV	{"phone": "+70891645996"}
0005433124068	35C951	4245 927660	GENNADIY KUZNECOV	{"phone": "+70067868447"}
0005433124069	9CEED9	5561 285831	ALEKSEY KONOVALOV	{"phone": "+70107822521"}
0005433124070	D6058C	1495 828423	DARYA ZHURAVLEVA	{"email": "zhuravlevadarya1975@postgrespro.ru", "phone": "+70974380903"}
0005433124071	D6058C	5839 657608	ZAKHAR NOVIKOV	{"email": "zakhar.novikov1972@postgrespro.ru", "phone": "+70048096638"}
0005433124072	C639CA	1667 840738	YULIYA FROLOVA	{"email": "frolova_yuliya.1960@postgrespro.ru", "phone": "+70693414195"}
0005433124073	FCF77D	2650 976944	AYRAT YAKOVLEV	{"phone": "+70215535276"}
0005433124074	9132F6	1756 466290	KONSTANTIN CHERNOV	{"phone": "+70128722063"}
0005433124075	9132F6	0702 829366	ANATOLIY KOZLOV	{"phone": "+70325757170"}
0005433124076	EB7B66	2610 603088	VALERIY MIKHAYLOV	{"phone": "+70572349394"}
0005433124077	0BD8DE	2797 217245	TAMARA ALEKSANDROVA	{"email": "tamara.aleksandrova-22051952@postgrespro.ru", "phone": "+70583157183"}
0005433124078	0BD8DE	6065 921028	NIKITA GUSEV	{"email": "gusev.nikita_111968@postgrespro.ru", "phone": "+70310290554"}
0005433124079	177716	4628 732816	VALENTINA NAUMOVA	{"phone": "+70453215613"}
0005433124080	177716	9041 359585	VALENTINA DENISOVA	{"email": "denisova_v021969@postgrespro.ru", "phone": "+70421791452"}
0005433124081	C2631F	3250 391527	NINA FILIPPOVA	{"email": "filippova_n_1980@postgrespro.ru", "phone": "+70200811457"}
0005433124082	15BE08	7917 270074	SERAFIM FEDOROV	{"email": "s.fedorov.041975@postgrespro.ru", "phone": "+70364299412"}
0005433124083	0B29DD	9574 999527	ELIZAVETA VASILEVA	{"email": "vasileva-e.061976@postgrespro.ru", "phone": "+70673709953"}
0005433124084	AD9591	0379 663425	ROZALIYA ALEKSEEVA	{"email": "rozaliya-alekseeva-1974@postgrespro.ru", "phone": "+70873755927"}
0005433124085	AD9591	9063 700675	EVGENIY ALEKSEEV	{"phone": "+70742185792"}
0005433124086	2546F3	0060 355511	VASILIY OSIPOV	{"phone": "+70094605649"}
0005433124087	DAF04D	7358 584511	NIKOLAY PETROV	{"email": "petrov-nikolay_1975@postgrespro.ru", "phone": "+70494795171"}
0005433124088	078779	9725 579283	ANDREY SOKOLOV	{"email": "sokolov.andrey-08041975@postgrespro.ru", "phone": "+70882529026"}
0005433124089	B4DAC1	1261 884868	LIDIYA MIKHAYLOVA	{"phone": "+70147970145"}
0005433124090	63BCAC	9080 414415	NAILYA POLYAKOVA	{"phone": "+70747220203"}
0005433124091	6E26E1	5589 077346	VALERIY PETROV	{"email": "petrovv.011965@postgrespro.ru", "phone": "+70087480462"}
0005433124092	6E26E1	5644 973468	IGOR VASILEV	{"phone": "+70060544166"}
0005433124093	5CA1B7	4960 214891	IVAN NIKOLAEV	{"email": "nikolaev_i1980@postgrespro.ru", "phone": "+70655172653"}
0005433124094	529617	2114 483866	DMITRIY ANTONOV	{"email": "antonov.d051987@postgrespro.ru", "phone": "+70536350230"}
0005433124095	648424	7658 918361	MIKHAIL SHEVCHENKO	{"email": "mikhail.shevchenko_1963@postgrespro.ru", "phone": "+70110301497"}
0005433124096	512396	7097 791427	ANATOLIY BORISOV	{"phone": "+70243314085"}
0005433124097	3B04A7	8564 942553	SERGEY KISELEV	{"email": "kiselevsergey.021966@postgrespro.ru", "phone": "+70047352435"}
0005433124098	281564	1182 562245	DMITRIY OSIPOV	{"email": "osipov.dmitriy.1959@postgrespro.ru", "phone": "+70779652562"}
0005433124099	52124E	3703 705424	DANILA ISAEV	{"email": "danila-isaev-011968@postgrespro.ru", "phone": "+70941419118"}
0005433124100	52124E	0798 570136	TATYANA POTAPOVA	{"phone": "+70457322032"}
0005433124101	52124E	2784 202769	NINA MEDVEDEVA	{"phone": "+70256203246"}
0005433124102	04377B	8326 626812	SERGEY VASILEV	{"phone": "+70965512006"}
0005433124103	509619	7531 458352	ZINAIDA KONDRATEVA	{"phone": "+70376185737"}
0005433124104	A420E6	6797 639226	EKATERINA OSIPOVA	{"phone": "+70937635462"}
0005433124105	976C61	0788 363836	IRINA ILINA	{"email": "ilina.irina-06021974@postgrespro.ru", "phone": "+70585071601"}
0005433124106	2E39D9	1785 612661	MARIYA KUZNECOVA	{"email": "mariya.kuznecova-1963@postgrespro.ru", "phone": "+70308097150"}
0005433124107	2E39D9	3414 203177	VYACHESLAV ZAKHAROV	{"email": "v.zakharov-051969@postgrespro.ru", "phone": "+70128799596"}
0005433124108	2E39D9	2551 893913	VALERIY STEPANOV	{"email": "stepanov.v_111967@postgrespro.ru", "phone": "+70595520158"}
0005433124109	8CBFCB	9849 644991	EVGENIY KOZLOV	{"email": "e-kozlov091977@postgrespro.ru", "phone": "+70408781908"}
0005433124110	4B35B4	1664 634210	ANDREY FEDOROV	{"phone": "+70371926411"}
0005433124111	A06BEA	0774 782047	ELENA KAZAKOVA	{"phone": "+70266192853"}
0005433124112	38412F	3447 503594	OLGA EGOROVA	{"phone": "+70881706707"}
0005433124113	F5574C	4886 180459	SERGEY VASILEV	{"phone": "+70090199101"}
0005433124114	F5574C	2621 085978	LYUBOV DAVYDOVA	{"phone": "+70924209089"}
0005433124115	DB3CD2	5081 293068	TAMARA TROFIMOVA	{"email": "trofimova-t_18061968@postgrespro.ru", "phone": "+70296183562"}
0005433124116	DB3CD2	2108 110013	ELIZAVETA IVANOVA	{"phone": "+70790994050"}
0005433124117	692D4E	2461 268142	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva_1977@postgrespro.ru", "phone": "+70143984359"}
0005433124118	692D4E	1031 179373	EKATERINA ORLOVA	{"email": "orlova.ekaterina121969@postgrespro.ru", "phone": "+70771677369"}
0005433124119	108A8F	3478 500749	VALENTINA KUZNECOVA	{"phone": "+70258936154"}
0005433124120	1A2A2A	4385 377272	ANDREY KUZNECOV	{"email": "a_kuznecov02071981@postgrespro.ru", "phone": "+70089692103"}
0005433124121	06FC05	0287 826383	ALEKSANDR GUSEV	{"phone": "+70871186686"}
0005433124122	C3458E	5045 135916	DANILA SAVELEV	{"phone": "+70628089042"}
0005433124123	4E761A	0788 024583	ELENA SOKOLOVA	{"email": "esokolova.29121967@postgrespro.ru", "phone": "+70105075305"}
0005433124124	191926	4119 281725	NATALIYA SOLOVEVA	{"email": "soloveva.nataliya-01041964@postgrespro.ru", "phone": "+70400805726"}
0005433124125	EE2281	9821 941576	VALENTINA OSIPOVA	{"email": "valentina.osipova_27061979@postgrespro.ru", "phone": "+70868246218"}
0005433124126	EE2281	6585 190853	ALEKSEY ROMANOV	{"email": "aromanov-1969@postgrespro.ru", "phone": "+70771328616"}
0005433124127	8BF833	7073 938065	GALINA MAKAROVA	{"phone": "+70954920460"}
0005433124128	8FAEB3	0877 700067	MARINA STEPANOVA	{"email": "marina_stepanova-02101979@postgrespro.ru", "phone": "+70150222576"}
0005433124129	8FAEB3	1045 855923	GALINA KUZNECOVA	{"email": "g_kuznecova_1971@postgrespro.ru", "phone": "+70379816663"}
0005433124130	09E2FC	6049 883335	LYUDMILA ZAYCEVA	{"email": "zaycevalyudmila_02061965@postgrespro.ru", "phone": "+70797245975"}
0005433124131	A1EB3F	1258 069947	ELMIRA LUKYANOVA	{"phone": "+70964149170"}
0005433124132	56E521	0029 960162	OLGA SMIRNOVA	{"email": "smirnova_olga.05011976@postgrespro.ru", "phone": "+70833764343"}
0005433124133	56E521	3030 082580	TATYANA VOLKOVA	{"phone": "+70065683883"}
0005433124134	56E521	1751 377044	LYUDMILA POLYAKOVA	{"email": "lyudmila_polyakova1962@postgrespro.ru", "phone": "+70293098340"}
0005433124135	42BBF0	2213 024605	ANDREY AFANASEV	{"phone": "+70247527807"}
0005433124136	C7BBBF	3478 062779	ANATOLIY KOZLOV	{"phone": "+70944218782"}
0005433124137	FCE8A1	0948 472636	NATALYA KOLESNIKOVA	{"email": "kolesnikovanatalya.08021980@postgrespro.ru", "phone": "+70303333801"}
0005433124138	FCE8A1	9179 426853	VALERIY MIKHAYLOV	{"phone": "+70521738401"}
0005433124139	FCE8A1	6724 803626	ALBERT DENISOV	{"phone": "+70716982477"}
0005433124140	1035E2	9772 577027	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr-1982@postgrespro.ru", "phone": "+70645426304"}
0005433124141	91A75C	6666 418588	SERGEY FROLOV	{"phone": "+70988640575"}
0005433124142	B09374	8604 063672	OLGA POPOVA	{"phone": "+70487094003"}
0005433124143	B09374	6365 790799	DENIS IVANOV	{"phone": "+70666874313"}
0005433124144	10D1BC	8227 928879	MIKHAIL IVANOV	{"phone": "+70264184081"}
0005433124145	EB628A	8736 716839	VLADIMIR ISAEV	{"phone": "+70852595941"}
0005433124146	EB628A	0698 981814	ALENA VOROBEVA	{"email": "vorobeva.alena_16051975@postgrespro.ru", "phone": "+70348173247"}
0005433124147	180CA7	8936 421613	YURIY NIKITIN	{"phone": "+70498751886"}
0005433124148	180CA7	1147 597361	ALEKSANDR IVANOV	{"email": "aivanov_1958@postgrespro.ru", "phone": "+70231551241"}
0005433124149	B342BC	4192 623063	IVAN NIKOLAEV	{"phone": "+70960832655"}
0005433124150	B342BC	8162 996689	ELENA BELOVA	{"email": "e_belova.041959@postgrespro.ru", "phone": "+70089705255"}
0005433124151	FB9518	4968 011994	IRINA EFIMOVA	{"phone": "+70387280338"}
0005433124152	FB9518	4831 809497	IVAN BORISOV	{"phone": "+70813990709"}
0005433124153	FB9518	6362 206989	ANTONINA VASILEVA	{"email": "a.vasileva.29041979@postgrespro.ru", "phone": "+70726429260"}
0005433124263	C122BE	0784 022425	EVGENIY AFANASEV	{"phone": "+70935239259"}
0005433124154	AFC55B	2825 812090	EVGENIY MEDVEDEV	{"email": "medvedev-evgeniy.08081971@postgrespro.ru", "phone": "+70080526215"}
0005433124155	21B481	5897 976474	ANNA KUZNECOVA	{"phone": "+70342608884"}
0005433124156	21B481	2017 757149	ROMAN SCHERBAKOV	{"email": "scherbakov_r-28021980@postgrespro.ru", "phone": "+70962245734"}
0005433124157	21B481	7470 188358	ELIZAVETA KONDRATEVA	{"email": "kondrateva_elizaveta_1976@postgrespro.ru", "phone": "+70713566998"}
0005433124158	668661	9154 073662	VIKTOR KUZMIN	{"phone": "+70874774053"}
0005433124159	F0ED2A	6551 013425	EKATERINA MALYSHEVA	{"email": "ekaterinamalysheva.1973@postgrespro.ru", "phone": "+70737857864"}
0005433124160	F0ED2A	9062 762010	YULIYA KULIKOVA	{"email": "y_kulikova.24021974@postgrespro.ru", "phone": "+70959967006"}
0005433124161	283563	4659 859489	VERA NIKITINA	{"email": "nikitinav_13101967@postgrespro.ru", "phone": "+70200366108"}
0005433124162	283563	3272 380033	KRISTINA ABRAMOVA	{"email": "k-abramova.021973@postgrespro.ru", "phone": "+70470895565"}
0005433124163	283563	3976 825344	OLEG MIRONOV	{"phone": "+70355342491"}
0005433124164	40CBC2	9562 959725	VITALIY IVANOV	{"phone": "+70889203620"}
0005433124165	E28C7C	7907 486478	GALINA NIKOLAEVA	{"email": "g.nikolaeva_041965@postgrespro.ru", "phone": "+70004550909"}
0005433124166	173E23	3970 865993	DANIIL SHEVCHENKO	{"email": "shevchenko_daniil12101980@postgrespro.ru", "phone": "+70935511712"}
0005433124167	678B17	7066 749509	ELENA SCHERBAKOVA	{"phone": "+70959077161"}
0005433124168	C7825E	4758 245096	LYUDMILA BORISOVA	{"email": "borisova.l.17121968@postgrespro.ru", "phone": "+70854300799"}
0005433124169	A46D84	1390 184808	TATYANA MOROZOVA	{"email": "morozova_tatyana.03031976@postgrespro.ru", "phone": "+70197472382"}
0005433124170	A46D84	9167 889818	EVGENIY SOKOLOV	{"phone": "+70413812751"}
0005433124171	0B9AD7	8305 939438	TATYANA IVANOVA	{"phone": "+70450314638"}
0005433124172	E0CA00	8385 321056	ALEKSEY KULIKOV	{"phone": "+70559272427"}
0005433124173	D2E435	3092 548921	LILIYA POPOVA	{"email": "popova_liliya-121970@postgrespro.ru", "phone": "+70635351491"}
0005433124174	AB8F6A	6825 477262	IGOR NOVIKOV	{"email": "novikov.i_061968@postgrespro.ru", "phone": "+70708874724"}
0005433124175	AB8F6A	0790 323800	IRINA NAZAROVA	{"email": "irina-nazarova_1974@postgrespro.ru", "phone": "+70899869343"}
0005433124176	7AD995	2165 094679	ARTEM ANDREEV	{"email": "a-andreev.29121972@postgrespro.ru", "phone": "+70499272919"}
0005433124177	62728B	0139 883167	LYUBOV ERMAKOVA	{"email": "ermakovalyubov_091972@postgrespro.ru", "phone": "+70802666850"}
0005433124178	EDBA4B	8815 971170	VERA KUZNECOVA	{"phone": "+70757934209"}
0005433124179	EDBA4B	1678 162219	ANDREY PAVLOV	{"email": "andrey.pavlov.1969@postgrespro.ru", "phone": "+70885725425"}
0005433124180	A7687C	2059 989441	SERGEY NAZAROV	{"email": "sergey-nazarov.061975@postgrespro.ru", "phone": "+70198259654"}
0005433124181	2D0C31	5772 406294	IRINA VOROBEVA	{"phone": "+70435955386"}
0005433124182	52CE4F	1513 695321	ALEKSANDR VOLKOV	{"email": "volkova-15081974@postgrespro.ru", "phone": "+70800938295"}
0005433124183	52CE4F	5960 425570	FARID TARASOV	{"email": "tarasov-farid_1977@postgrespro.ru", "phone": "+70140958463"}
0005433124184	52CE4F	2446 332645	OKSANA SIDOROVA	{"phone": "+70363941927"}
0005433124185	66B5A7	9229 732265	VLADIMIR KOZLOV	{"email": "vladimirkozlov-06111979@postgrespro.ru", "phone": "+70631728757"}
0005433124186	66B5A7	2563 277607	NIKOLAY NAUMOV	{"phone": "+70729176530"}
0005433124187	99AC4C	6750 364730	NIKOLAY BORISOV	{"phone": "+70744529196"}
0005433124188	99AC4C	2166 933144	YULIYA MOROZOVA	{"phone": "+70187217199"}
0005433124189	F7E40C	0312 082656	MIKHAIL NIKOLAEV	{"email": "nikolaev-mikhail-25071958@postgrespro.ru", "phone": "+70796913679"}
0005433124190	3D13BD	7102 540905	ALEKSEY FILIPPOV	{"email": "filippovaleksey-1960@postgrespro.ru", "phone": "+70801034010"}
0005433124191	B88E45	9157 614343	OLEG AFANASEV	{"phone": "+70581365150"}
0005433124192	B88E45	2665 167177	ARTEM DAVYDOV	{"email": "davydov_artem111960@postgrespro.ru", "phone": "+70366890668"}
0005433124193	CDA1EF	9029 906614	TATYANA POTAPOVA	{"email": "tatyana.potapova.12101973@postgrespro.ru", "phone": "+70074490155"}
0005433124194	16BA40	2366 918185	RIMMA DENISOVA	{"email": "denisovarimma.021981@postgrespro.ru", "phone": "+70654233772"}
0005433124195	16BA40	2987 598098	MAKSIM VASILEV	{"email": "maksimvasilev09021970@postgrespro.ru", "phone": "+70694311341"}
0005433124196	47492A	6397 853530	VIKTORIYA LEBEDEVA	{"email": "lebedeva_v.1976@postgrespro.ru", "phone": "+70618550088"}
0005433124315	6DDB2B	4513 022127	NIKOLAY MELNIKOV	{"phone": "+70719846104"}
0005433124197	F3E5AF	6614 564122	SVETLANA ZHURAVLEVA	{"email": "zhuravlevasvetlana051977@postgrespro.ru", "phone": "+70264075251"}
0005433124198	F3E5AF	0391 589687	RAFAEL FOMIN	{"email": "rafael.fomin_11011978@postgrespro.ru", "phone": "+70816709885"}
0005433124199	D14300	3064 140978	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir.22061971@postgrespro.ru", "phone": "+70134648257"}
0005433124200	96A0DF	3010 733207	ZINAIDA KAZAKOVA	{"phone": "+70036700096"}
0005433124201	F83E79	5746 257163	NAILYA ZOTOVA	{"phone": "+70951797065"}
0005433124202	83489E	2650 504673	MARINA EGOROVA	{"email": "egorovam_1966@postgrespro.ru", "phone": "+70563778233"}
0005433124203	EEE294	9401 405618	ELENA FEDOROVA	{"phone": "+70192485011"}
0005433124204	74EDCC	8276 985953	GALINA ALEKSEEVA	{"email": "alekseeva_g_1977@postgrespro.ru", "phone": "+70796630953"}
0005433124205	8A11FF	5355 052387	YURIY NIKITIN	{"email": "nikitin.yuriy071968@postgrespro.ru", "phone": "+70419474406"}
0005433124206	C48D89	3286 322296	VIKTOR TIKHONOV	{"email": "v_tikhonov-011973@postgrespro.ru", "phone": "+70333477277"}
0005433124207	B96417	5751 193156	DINARA NAZAROVA	{"email": "d_nazarova011959@postgrespro.ru", "phone": "+70045622442"}
0005433124208	3B34A2	9293 525458	LIDIYA ALEKSEEVA	{"email": "lidiya.alekseeva.091974@postgrespro.ru", "phone": "+70516441361"}
0005433124209	DAE635	0841 245775	KSENIYA NAZAROVA	{"email": "nazarova-k1959@postgrespro.ru", "phone": "+70672258296"}
0005433124210	82ABCD	7860 236954	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa-11061979@postgrespro.ru", "phone": "+70305008423"}
0005433124211	82ABCD	5921 664611	TATYANA SAVELEVA	{"email": "saveleva_t.1965@postgrespro.ru", "phone": "+70240321797"}
0005433124212	82ABCD	0741 149706	PAVEL ZAKHAROV	{"email": "pavel.zakharov.13081970@postgrespro.ru", "phone": "+70120707441"}
0005433124213	02BBD2	7453 048981	NATALYA POPOVA	{"phone": "+70731811022"}
0005433124214	56FFAC	2807 927098	YULIYA KOVALEVA	{"phone": "+70544509606"}
0005433124215	56FFAC	0692 774931	ANGELINA ARKHIPOVA	{"phone": "+70539130764"}
0005433124216	D25BBC	8264 063362	ARTEM KOZLOV	{"email": "artemkozlov_081971@postgrespro.ru", "phone": "+70059866401"}
0005433124217	D25BBC	0420 062045	NATALYA IVANOVA	{"email": "natalya-ivanova22011973@postgrespro.ru", "phone": "+70817056436"}
0005433124218	767A2D	7234 022968	IRINA MOROZOVA	{"phone": "+70197165548"}
0005433124219	15925A	5780 793753	NINA BELOVA	{"email": "belova_n-101981@postgrespro.ru", "phone": "+70369849591"}
0005433124220	37658F	3606 062803	TATYANA VASILEVA	{"phone": "+70647492070"}
0005433124221	A1DFD9	3235 291980	OLGA MEDVEDEVA	{"email": "medvedeva-olga.091969@postgrespro.ru", "phone": "+70909160792"}
0005433124222	140F73	2665 997071	GALINA CHERNOVA	{"email": "galina_chernova04101982@postgrespro.ru", "phone": "+70728968641"}
0005433124223	948811	3466 717452	OKSANA RYABOVA	{"email": "ryabova-o.091969@postgrespro.ru", "phone": "+70325687478"}
0005433124224	B6EDCA	2340 315105	VITALIY FROLOV	{"email": "vitaliy-frolov121974@postgrespro.ru", "phone": "+70828725274"}
0005433124225	EEB4BE	7993 453026	MAKSIM EGOROV	{"email": "egorov_m101976@postgrespro.ru", "phone": "+70367814012"}
0005433124226	435259	0954 215167	GALINA DANILOVA	{"email": "danilovagalina071979@postgrespro.ru", "phone": "+70984360821"}
0005433124227	435259	1297 910369	GALINA SAVELEVA	{"phone": "+70119743967"}
0005433124228	186790	9077 052328	TAMARA POPOVA	{"phone": "+70701969763"}
0005433124229	4F4C0A	7144 653723	LARISA RODIONOVA	{"email": "l.rodionova-1965@postgrespro.ru", "phone": "+70998977878"}
0005433124230	58B076	0712 766976	MARIYA PETROVA	{"email": "petrova.m_121970@postgrespro.ru", "phone": "+70643587484"}
0005433124231	28CF44	5384 258695	NATALYA MAKAROVA	{"email": "makarovanatalya-041969@postgrespro.ru", "phone": "+70155169894"}
0005433124232	28CF44	2189 850413	SHAMIL TARASOV	{"email": "tarasov_shamil-1978@postgrespro.ru", "phone": "+70954952851"}
0005433124233	2F6D97	9665 738010	ANNA IVANOVA	{"phone": "+70339001901"}
0005433124234	2F6D97	6435 254725	OLGA ALEKSEEVA	{"email": "alekseeva-olga-051974@postgrespro.ru", "phone": "+70868142712"}
0005433124235	59306E	9859 881823	GALINA AKIMOVA	{"phone": "+70719041609"}
0005433124236	59306E	3102 167898	TATYANA KUZNECOVA	{"phone": "+70058865171"}
0005433124237	EEDA63	7624 936667	ANDREY GORBUNOV	{"phone": "+70317091554"}
0005433124238	EEDA63	7697 404046	SVETLANA MAKAROVA	{"email": "svetlana.makarova02031982@postgrespro.ru", "phone": "+70966708892"}
0005433124239	BC478A	0602 455846	GULIYA MOROZOVA	{"phone": "+70742937279"}
0005433124240	2B90A9	4499 263705	OLEG SOKOLOV	{"email": "o.sokolov-031988@postgrespro.ru", "phone": "+70592162143"}
0005433124241	9BE542	9390 539758	YULIYA VASILEVA	{"email": "vasilevayuliya.20071972@postgrespro.ru", "phone": "+70086725295"}
0005433124242	71483B	1573 527329	NADEZHDA GERASIMOVA	{"phone": "+70624113441"}
0005433124243	FDCE50	0820 792099	NATALIYA KUZNECOVA	{"email": "nataliyakuznecova-051978@postgrespro.ru", "phone": "+70455343489"}
0005433124244	05C9F5	8298 358538	VENERA TIKHONOVA	{"email": "tikhonovav-1977@postgrespro.ru", "phone": "+70054026595"}
0005433124245	05C9F5	5491 041170	TATYANA SOROKINA	{"phone": "+70168812983"}
0005433124246	5EDBEF	7746 381181	PAVEL ANDREEV	{"phone": "+70974867032"}
0005433124247	78A0DD	0762 689602	NIKITA NAZAROV	{"phone": "+70417576567"}
0005433124248	C7198D	5738 439826	ANASTASIYA BELOVA	{"phone": "+70979611215"}
0005433124249	C7198D	5791 723835	VLADIMIR SAVELEV	{"email": "vladimir.savelev_22041976@postgrespro.ru", "phone": "+70185375686"}
0005433124250	B8BDB6	6804 945049	ALEKSANDR KULIKOV	{"email": "kulikov-a_1967@postgrespro.ru", "phone": "+70858175633"}
0005433124251	6AF21A	1182 356078	VYACHESLAV ROMANOV	{"phone": "+70774781649"}
0005433124252	D1A4CC	7070 596814	VLADIMIR TARASOV	{"phone": "+70864281820"}
0005433124253	D6609A	3132 659785	SVETLANA GUSEVA	{"phone": "+70469136531"}
0005433124254	D6609A	0350 217216	DENIS NOVIKOV	{"phone": "+70090268795"}
0005433124255	A99130	2303 624724	MATVEY EGOROV	{"email": "m-egorov-12041974@postgrespro.ru", "phone": "+70919299541"}
0005433124256	9B8B15	2815 477900	SVETLANA KONDRATEVA	{"email": "skondrateva.021974@postgrespro.ru", "phone": "+70953566936"}
0005433124257	9B8B15	1036 876887	EVGENIY MATVEEV	{"email": "matveev-e.06121966@postgrespro.ru", "phone": "+70644633326"}
0005433124258	FFA574	0223 084745	OLEG BORISOV	{"email": "olegborisov.041980@postgrespro.ru", "phone": "+70802965491"}
0005433124259	C16231	2879 184355	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov-1973@postgrespro.ru", "phone": "+70086364843"}
0005433124260	8BFCEC	8204 090172	OKSANA NAZAROVA	{"email": "onazarova1964@postgrespro.ru", "phone": "+70060493121"}
0005433124261	5103F7	7181 373251	VALENTINA EFIMOVA	{"phone": "+70088415500"}
0005433124262	5103F7	9840 568977	VASILIY ANDREEV	{"phone": "+70046651097"}
0005433124264	71970A	0537 992378	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov-18051975@postgrespro.ru", "phone": "+70247067608"}
0005433124265	71970A	2508 838370	VIKTORIYA FADEEVA	{"email": "vfadeeva1989@postgrespro.ru", "phone": "+70850315186"}
0005433124266	37A2AF	7808 771575	VLADIMIR KARPOV	{"email": "vladimir.karpov071970@postgrespro.ru", "phone": "+70719952252"}
0005433124267	F8E123	0249 659573	OLGA SIDOROVA	{"email": "o-sidorova.041977@postgrespro.ru", "phone": "+70894278253"}
0005433124268	39AC0B	1554 935466	NATALIYA EGOROVA	{"email": "egorova_n_1968@postgrespro.ru", "phone": "+70831427751"}
0005433124269	39AC0B	5149 538174	ANTON VASILEV	{"email": "anton_vasilev.091969@postgrespro.ru", "phone": "+70011892442"}
0005433124270	AD1097	0992 971684	PETR TARASOV	{"email": "tarasov-p-1972@postgrespro.ru", "phone": "+70062492943"}
0005433124271	AD1097	3132 784068	ANNA SAVELEVA	{"email": "anna.saveleva-09111968@postgrespro.ru", "phone": "+70833019166"}
0005433124272	AD1097	6137 039067	GENNADIY MIRONOV	{"phone": "+70932754434"}
0005433124273	1F99BE	8602 536752	MAKSIM FEDOTOV	{"phone": "+70237038765"}
0005433124274	A05869	0489 410708	VIKTOR KOROLEV	{"email": "korolev.v_111968@postgrespro.ru", "phone": "+70581467272"}
0005433124275	4A8ABC	7849 537593	LYUBOV MOROZOVA	{"email": "morozova-l111972@postgrespro.ru", "phone": "+70585228808"}
0005433124276	B630F8	5482 893823	MAKSIM OSIPOV	{"phone": "+70849451077"}
0005433124277	B630F8	5436 615560	RIMMA ZAKHAROVA	{"phone": "+70277935221"}
0005433124278	1A4E4D	5156 128518	MATVEY ANDREEV	{"email": "m-andreev011973@postgrespro.ru", "phone": "+70548753715"}
0005433124279	C512EF	3454 825739	YULIYA SCHERBAKOVA	{"phone": "+70610767946"}
0005433124280	324D12	9195 731217	VLADIMIR VOLKOV	{"phone": "+70070154830"}
0005433124281	AEAD86	3544 931050	VLADISLAV OSIPOV	{"email": "osipov.v.26011973@postgrespro.ru", "phone": "+70500031173"}
0005433124282	BD59E2	4733 291546	NINA KISELEVA	{"phone": "+70356649547"}
0005433124283	63EDBD	3674 449668	MARGARITA AKIMOVA	{"email": "makimova-081970@postgrespro.ru", "phone": "+70497695508"}
0005433124284	63EDBD	1179 651695	TATYANA MIKHAYLOVA	{"phone": "+70365994914"}
0005433124285	A43513	1315 245178	ELENA NESTEROVA	{"phone": "+70473668028"}
0005433124286	A43513	8877 630164	LYUDMILA KOLESNIKOVA	{"email": "kolesnikoval1968@postgrespro.ru", "phone": "+70848840417"}
0005433124287	A43513	6454 766889	SERGEY GRIGOREV	{"phone": "+70653051269"}
0005433124288	75196A	8568 108273	ALEKSANDR SOKOLOV	{"email": "a_sokolov021972@postgrespro.ru", "phone": "+70900431347"}
0005433124289	DD1D50	7933 853358	ZOYA VASILEVA	{"email": "vasileva-zoya_1972@postgrespro.ru", "phone": "+70209848990"}
0005433124290	B7AF2D	0013 093634	MARIANNA MAKAROVA	{"email": "makarovam-111973@postgrespro.ru", "phone": "+70508659724"}
0005433124291	B7AF2D	5480 329062	YURIY ZAYCEV	{"email": "y.zaycev03061972@postgrespro.ru", "phone": "+70813438506"}
0005433124292	B087A2	7761 890546	NATALYA NIKITINA	{"email": "n_nikitina.1979@postgrespro.ru", "phone": "+70007949443"}
0005433124293	B087A2	0373 350117	NELLYA ROMANOVA	{"email": "nellya-romanova26121963@postgrespro.ru", "phone": "+70808234753"}
0005433124294	6BD0A5	9594 918099	ELINA KOLESNIKOVA	{"phone": "+70140334082"}
0005433124295	6CE16A	2085 429608	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr.061969@postgrespro.ru", "phone": "+70150403588"}
0005433124296	6CE16A	7023 500892	IVAN SMIRNOV	{"email": "ivan-smirnov.1971@postgrespro.ru", "phone": "+70338894163"}
0005433124297	CAC8BB	3103 081904	VIKTORIYA TIKHONOVA	{"email": "tikhonovav1968@postgrespro.ru", "phone": "+70852542949"}
0005433124298	B3971E	5474 162648	MARIYA YUDINA	{"phone": "+70133068774"}
0005433124299	A5AA4B	5519 929925	TATYANA SAVELEVA	{"phone": "+70523906962"}
0005433124300	4070C1	2348 798379	ELENA MIRONOVA	{"email": "mironova_e-1968@postgrespro.ru", "phone": "+70980784020"}
0005433124301	4070C1	6358 068971	MIKHAIL BORISOV	{"phone": "+70727683591"}
0005433124302	EA6B49	5767 436472	NINA SOROKINA	{"phone": "+70359502670"}
0005433124303	CDE9B2	9805 660966	ANASTASIYA MASLOVA	{"email": "anastasiya.maslova.11091963@postgrespro.ru", "phone": "+70125870379"}
0005433124304	CDE9B2	1062 129753	GALINA MIKHAYLOVA	{"email": "galina.mikhaylova-05121970@postgrespro.ru", "phone": "+70530494807"}
0005433124305	CDE9B2	1545 005474	LYUBOV MIRONOVA	{"phone": "+70083302095"}
0005433124306	5C8B9F	9350 401515	VYACHESLAV SOROKIN	{"email": "sorokin.v-02011977@postgrespro.ru", "phone": "+70122962679"}
0005433124307	5C8B9F	3570 356174	GENNADIY IVANOV	{"phone": "+70855094943"}
0005433124308	4B9790	6625 327953	NINA KISELEVA	{"phone": "+70813474601"}
0005433124309	5D7AEF	5312 890203	SERGEY VASILEV	{"email": "vasilev_sergey101965@postgrespro.ru", "phone": "+70818454412"}
0005433124310	2C3123	4730 768913	SERGEY MELNIKOV	{"email": "smelnikov-17111970@postgrespro.ru", "phone": "+70329986389"}
0005433124311	15CBB9	1848 554023	ZINAIDA FOMINA	{"email": "fomina.z.051978@postgrespro.ru", "phone": "+70029844395"}
0005433124312	C4A766	6046 647284	ALEKSANDR NIKITIN	{"email": "nikitin.a-18051970@postgrespro.ru", "phone": "+70172744349"}
0005433124313	069442	3025 187143	NATALYA SMIRNOVA	{"email": "smirnovanatalya.1969@postgrespro.ru", "phone": "+70319776056"}
0005433124314	6DDB2B	7486 067114	DMITRIY RODIONOV	{"email": "rodionov.dmitriy-1966@postgrespro.ru", "phone": "+70022376164"}
0005433124316	BCE21C	3014 448340	MARAT DAVYDOV	{"email": "marat_davydov-11021982@postgrespro.ru", "phone": "+70690919507"}
0005433124317	BCE21C	2969 453808	NADEZHDA ALEKSEEVA	{"phone": "+70487920124"}
0005433124318	429D9D	3491 521533	ANTONINA LAZAREVA	{"phone": "+70620570583"}
0005433124319	F33591	1409 901455	RUMIYA STEPANOVA	{"phone": "+70934277552"}
0005433124320	F33591	4084 880211	ALEKSANDR FEDOROV	{"phone": "+70584005182"}
0005433124321	363DC5	4632 052276	GENNADIY KUZNECOV	{"phone": "+70935723444"}
0005433124322	363DC5	1067 327757	LYUBOV MOISEEVA	{"phone": "+70744937059"}
0005433124323	71BBB6	7585 346493	ELENA VASILEVA	{"phone": "+70493000056"}
0005433124324	CDCAB6	1697 898848	TAMARA SOKOLOVA	{"email": "sokolovat_051960@postgrespro.ru", "phone": "+70432127543"}
0005433124325	28C7E5	1577 694665	OLGA PAVLOVA	{"email": "pavlova.olga061965@postgrespro.ru", "phone": "+70601186298"}
0005433124326	28C7E5	3109 964445	EKATERINA TIKHONOVA	{"email": "ekaterina-tikhonova.1971@postgrespro.ru", "phone": "+70696746347"}
0005433124327	5DF8F4	5177 742673	ILYA CHERNOV	{"phone": "+70552047928"}
0005433124328	8B53CA	6884 386504	VIKTOR FOMIN	{"email": "v_fomin.12021981@postgrespro.ru", "phone": "+70970030308"}
0005433124329	8B53CA	2151 539545	ANASTASIYA MAKAROVA	{"phone": "+70674711578"}
0005433124330	8B53CA	1140 383332	GENNADIY VASILEV	{"phone": "+70385269633"}
0005433124331	A3B61E	4416 415701	TATYANA MOROZOVA	{"email": "tatyana.morozova-28091975@postgrespro.ru", "phone": "+70743490417"}
0005433124332	8F11E7	3000 604422	VALENTIN BARANOV	{"email": "baranov.v.24101968@postgrespro.ru", "phone": "+70769810398"}
0005433124333	71A56A	0811 203378	OLGA STEPANOVA	{"phone": "+70352935100"}
0005433124334	8A25DC	0471 581821	DMITRIY BORISOV	{"phone": "+70910780397"}
0005433124335	B2F746	6710 286095	NADEZHDA KUZNECOVA	{"phone": "+70532595654"}
0005433124336	C199E3	5390 793270	SVETLANA RODIONOVA	{"phone": "+70710402654"}
0005433124337	C199E3	1641 435009	NIKOLAY BARANOV	{"email": "n.baranov-091965@postgrespro.ru", "phone": "+70385556558"}
0005433124338	E94495	7383 436166	MARGARITA SAVELEVA	{"phone": "+70387964936"}
0005433124339	BB0A4B	3943 498687	VIKTOR KUZNECOV	{"email": "kuznecov-v_041968@postgrespro.ru", "phone": "+70763882726"}
0005433124340	CA7C35	5782 148929	GENNADIY SIDOROV	{"email": "sidorovg.051972@postgrespro.ru", "phone": "+70886501445"}
0005433124341	E06E71	5561 458830	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova_lyudmila.20071979@postgrespro.ru", "phone": "+70063371925"}
0005433124342	EEDBFB	7662 679531	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko-121974@postgrespro.ru", "phone": "+70108222316"}
0005433124343	7ED28D	0282 632774	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin_111981@postgrespro.ru", "phone": "+70076717345"}
0005433124344	B594AE	7124 618677	YULIYA MARTYNOVA	{"email": "martynovay051974@postgrespro.ru", "phone": "+70013568070"}
0005433124345	AA94F1	5008 722358	DMITRIY FROLOV	{"email": "d-frolov091964@postgrespro.ru", "phone": "+70507604591"}
0005433124346	B6B146	6915 890144	ARKADIY KARPOV	{"phone": "+70027462032"}
0005433124347	B6B146	8290 703313	LYUBOV BARANOVA	{"phone": "+70062322857"}
0005433124348	69ADBE	0093 004100	ANASTASIYA VLASOVA	{"email": "vlasovaa18071977@postgrespro.ru", "phone": "+70579042662"}
0005433124349	69ADBE	1122 629511	MIKHAIL MAKAROV	{"email": "makarov-mikhail-061965@postgrespro.ru", "phone": "+70170188224"}
0005433124350	0DF827	0541 904506	VLADIMIR MEDVEDEV	{"phone": "+70893807800"}
0005433124351	0DF827	1335 752363	LYUBOV TIMOFEEVA	{"email": "lyubov_timofeeva111971@postgrespro.ru", "phone": "+70121124330"}
0005433124352	F3F695	2988 252370	MARIYA CHERNOVA	{"phone": "+70649241687"}
0005433124353	069F8F	2470 729346	EKATERINA RYABOVA	{"email": "ryabova_e.111977@postgrespro.ru", "phone": "+70491811416"}
0005433124354	069F8F	0834 329742	VLADIMIR BORISOV	{"email": "v.borisov1962@postgrespro.ru", "phone": "+70087460769"}
0005433124355	31ED15	0840 677543	DIANA PETROVA	{"phone": "+70435751199"}
0005433124356	31ED15	1483 284589	TAMARA ALEKSEEVA	{"phone": "+70754865660"}
0005433124357	EFB767	6731 586619	ELENA ROMANOVA	{"email": "romanova_elena22081971@postgrespro.ru", "phone": "+70345392771"}
0005433124358	0C96EE	4676 676573	ELENA GUSEVA	{"phone": "+70525016296"}
0005433124359	B9EFC8	9166 778389	EVGENIY TIMOFEEV	{"email": "timofeev-e.011978@postgrespro.ru", "phone": "+70085564708"}
0005433124360	35B20D	5079 741691	ALEKSEY FROLOV	{"phone": "+70359031021"}
0005433124361	35B20D	5137 254625	NATALYA VLASOVA	{"email": "vlasova.natalya.1987@postgrespro.ru", "phone": "+70530526736"}
0005433124362	66784F	6994 562179	EVGENIY MAKAROV	{"email": "makarov_e_1963@postgrespro.ru", "phone": "+70925715314"}
0005433124363	52E885	6881 665511	ALEKSEY FROLOV	{"phone": "+70152222740"}
0005433124364	52E885	5851 500508	IVAN SMIRNOV	{"phone": "+70934690123"}
0005433124365	48026A	9000 986222	KONSTANTIN IVANOV	{"phone": "+70824770861"}
0005433124366	4D105C	4804 486169	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova_anastasiya_1982@postgrespro.ru", "phone": "+70795712397"}
0005433124367	4D105C	2947 616489	IRINA NAUMOVA	{"phone": "+70622235168"}
0005433124368	4D0311	0475 062286	MARIYA RODIONOVA	{"phone": "+70498650433"}
0005433124369	30BDCF	8596 780166	VERA MOROZOVA	{"email": "v_morozova.13031964@postgrespro.ru", "phone": "+70074879663"}
0005433124370	9DA0B5	8607 819847	ANGELINA VOLKOVA	{"phone": "+70741100814"}
0005433124371	9DA0B5	6722 230239	PETR DAVYDOV	{"phone": "+70926914553"}
0005433124372	FFEB66	0712 426382	TAMARA FADEEVA	{"email": "fadeeva_t-101974@postgrespro.ru", "phone": "+70628362862"}
0005433124373	B39DC2	7972 935723	ROMAN CHERNOV	{"email": "r.chernov.1970@postgrespro.ru", "phone": "+70352902834"}
0005433124374	B39DC2	3725 556116	MARIYA BELOVA	{"phone": "+70482312696"}
0005433124431	B97770	1693 230584	ELENA KOMAROVA	{"phone": "+70473113063"}
0005433124375	B81C0B	8273 272873	NINA GRISHINA	{"email": "nina_grishina_1972@postgrespro.ru", "phone": "+70637810760"}
0005433124376	D93566	3836 918017	OLGA FILATOVA	{"phone": "+70519681584"}
0005433124377	D93566	2016 573551	PAVEL IVANOV	{"phone": "+70462086878"}
0005433124378	C665D7	1091 664069	EVGENIYA DAVYDOVA	{"phone": "+70415035414"}
0005433124379	911B98	1706 403577	STANISLAV GERASIMOV	{"phone": "+70016158831"}
0005433124380	2022D9	8247 097411	EVGENIY FEDOROV	{"email": "e_fedorov-22031989@postgrespro.ru", "phone": "+70890160280"}
0005433124381	CDC4B2	3868 663629	YULIYA KONDRATEVA	{"email": "kondrateva.y-24021964@postgrespro.ru", "phone": "+70760625334"}
0005433124382	5F6AAF	0737 851557	OKSANA MASLOVA	{"phone": "+70021418388"}
0005433124383	3DABA4	6525 502115	YURIY MAKSIMOV	{"phone": "+70347445948"}
0005433124384	3DABA4	6170 133046	RIMMA KUZNECOVA	{"phone": "+70356520974"}
0005433124385	2B4193	8301 049350	RUSLAN KUZMIN	{"email": "r.kuzmin1980@postgrespro.ru", "phone": "+70971415626"}
0005433124386	EA7866	0244 822919	STEPAN IVANOV	{"email": "stepan.ivanov.08061978@postgrespro.ru", "phone": "+70882538785"}
0005433124387	25DCE3	0313 393571	ELENA IVANOVA	{"email": "ivanova-e_041977@postgrespro.ru", "phone": "+70407054620"}
0005433124388	25DCE3	1489 638514	PAVEL PETROV	{"phone": "+70611698798"}
0005433124389	318493	5673 392108	MARIYA ROMANOVA	{"phone": "+70418357296"}
0005433124390	05A91A	0869 729787	RAMIL ISAEV	{"phone": "+70365912076"}
0005433124391	79F392	6347 695261	SERGEY IVANOV	{"phone": "+70709705496"}
0005433124392	79F392	1557 776763	ALEKSANDR SEMENOV	{"email": "semenova-07071981@postgrespro.ru", "phone": "+70544957345"}
0005433124393	C382A5	5816 877928	IRINA ANDREEVA	{"email": "andreeva-irina_021978@postgrespro.ru", "phone": "+70881921951"}
0005433124394	8EF6E9	9437 735351	IVAN NAZAROV	{"phone": "+70579633634"}
0005433124395	497E2C	8949 415807	ANNA ARKHIPOVA	{"phone": "+70919360750"}
0005433124396	497E2C	6881 272458	ARTEM MATVEEV	{"email": "matveev_artem-051972@postgrespro.ru", "phone": "+70687889887"}
0005433124397	A45B53	2245 657419	VALERIYA ROMANOVA	{"email": "romanova.v051969@postgrespro.ru", "phone": "+70592633023"}
0005433124398	A45B53	4992 305478	ALEVTINA KARPOVA	{"email": "akarpova-26101977@postgrespro.ru", "phone": "+70237564143"}
0005433124399	A45B53	6592 841752	ALEKSEY DMITRIEV	{"phone": "+70612978995"}
0005433124400	35954B	3955 529812	ALEKSEY ILIN	{"phone": "+70301592176"}
0005433124401	35954B	4214 532711	RINAT SIDOROV	{"phone": "+70599327908"}
0005433124402	73BE6D	9127 307764	YANA MALYSHEVA	{"email": "malysheva_y-1972@postgrespro.ru", "phone": "+70357561097"}
0005433124403	73BE6D	5358 779905	VLADIMIR SOROKIN	{"email": "vladimir.sorokin-21011970@postgrespro.ru", "phone": "+70089042802"}
0005433124404	7791C1	9637 624823	NADEZHDA SERGEEVA	{"email": "sergeeva.nadezhda22121966@postgrespro.ru", "phone": "+70023455292"}
0005433124405	F8221A	8613 630821	IVAN ALEKSANDROV	{"phone": "+70669543692"}
0005433124406	5A1D65	9389 735385	NIKOLAY SOROKIN	{"email": "nikolay-sorokin101982@postgrespro.ru", "phone": "+70079354982"}
0005433124407	DF2937	6859 764440	NATALYA TITOVA	{"email": "titova-n.17051979@postgrespro.ru", "phone": "+70818686716"}
0005433124408	4B89C3	4344 820931	DMITRIY MOROZOV	{"email": "d-morozov091962@postgrespro.ru", "phone": "+70855560717"}
0005433124409	368728	8317 785631	ELENA MALYSHEVA	{"email": "malyshevae-23031976@postgrespro.ru", "phone": "+70056150550"}
0005433124410	CB4C58	4601 876837	ALLA MIKHAYLOVA	{"phone": "+70035287027"}
0005433124411	5ECCF1	3853 860746	ANNA KOVALEVA	{"email": "kovaleva_anna07091957@postgrespro.ru", "phone": "+70674371842"}
0005433124412	600FFA	5363 797470	SVETLANA SMIRNOVA	{"email": "smirnova_s-19121968@postgrespro.ru", "phone": "+70310838997"}
0005433124413	1E2E44	4706 486778	NIKOLAY TIMOFEEV	{"email": "timofeev.n1969@postgrespro.ru", "phone": "+70103169757"}
0005433124414	1E2E44	5040 402468	DARYA KAZAKOVA	{"email": "kazakova.darya1964@postgrespro.ru", "phone": "+70865675240"}
0005433124415	0ECC99	7183 224648	SERGEY OSIPOV	{"phone": "+70759839092"}
0005433124416	4C0969	6111 747190	TATYANA MAKAROVA	{"email": "t.makarova_1982@postgrespro.ru", "phone": "+70637862413"}
0005433124417	27AA8F	9596 766017	SERGEY ALEKSANDROV	{"email": "aleksandrov-sergey_021971@postgrespro.ru", "phone": "+70365281769"}
0005433124418	5B9B18	2055 193240	NADEZHDA FILIPPOVA	{"email": "n-filippova23111979@postgrespro.ru", "phone": "+70150593812"}
0005433124419	3466F5	5807 046278	KAMILLA NIKOLAEVA	{"email": "nikolaevakamilla_1975@postgrespro.ru", "phone": "+70769708906"}
0005433124420	3466F5	6357 963206	DMITRIY PAVLOV	{"email": "d_pavlov_1957@postgrespro.ru", "phone": "+70167198336"}
0005433124421	E3964A	9448 560185	MIKHAIL POPOV	{"email": "m.popov-061965@postgrespro.ru", "phone": "+70640350703"}
0005433124422	E3964A	5382 106203	OLEG PAVLOV	{"email": "pavlov-oleg1971@postgrespro.ru", "phone": "+70475002411"}
0005433124423	62907E	2024 453066	EVGENIY ISAEV	{"email": "e_isaev_111978@postgrespro.ru", "phone": "+70501771162"}
0005433124424	7EF406	0444 116690	IGOR ALEKSEEV	{"phone": "+70577921480"}
0005433124425	627182	7874 559654	SVETLANA OVCHINNIKOVA	{"phone": "+70955574213"}
0005433124426	7CBABC	3081 042627	KHASAN BELOV	{"email": "khasan-belov-031959@postgrespro.ru", "phone": "+70476294449"}
0005433124427	A8D37C	3154 572931	LIDIYA ALEKSEEVA	{"phone": "+70497847488"}
0005433124428	A8D37C	4725 883220	TATYANA GAVRILOVA	{"phone": "+70362276521"}
0005433124429	77BF23	8209 581392	NATALIYA ANDREEVA	{"email": "nataliyaandreeva.041966@postgrespro.ru", "phone": "+70207774020"}
0005433124430	77BF23	6750 920092	VIKTOR KULIKOV	{"phone": "+70698262121"}
0005433124432	B97770	5216 749736	ALINA IVANOVA	{"email": "ivanova-alina.22071976@postgrespro.ru", "phone": "+70176344932"}
0005433124433	F40415	8736 767394	ELENA FROLOVA	{"phone": "+70534823735"}
0005433124434	F40415	5214 311983	TIMUR MELNIKOV	{"phone": "+70210010164"}
0005433124435	DAA897	1341 625644	VSEVOLOD GRIGOREV	{"email": "vgrigorev.1976@postgrespro.ru", "phone": "+70684017456"}
0005433124436	6A17B8	3254 384255	ELENA FADEEVA	{"email": "fadeevaelena19101974@postgrespro.ru", "phone": "+70677958041"}
0005433124437	063DD0	2415 767275	VALENTINA ZAKHAROVA	{"phone": "+70634482115"}
0005433124438	B4EAA1	4140 028845	YAROSLAV ORLOV	{"email": "orlov.y_21051969@postgrespro.ru", "phone": "+70741050722"}
0005433124439	B4EAA1	7552 007701	VIKTOR KUZNECOV	{"email": "kuznecov-v18091961@postgrespro.ru", "phone": "+70605007128"}
0005433124440	2D75DE	7628 229895	ALEKSEY BORISOV	{"email": "borisova.1972@postgrespro.ru", "phone": "+70814779328"}
0005433124441	2D75DE	2533 233505	OLGA ALEKSEEVA	{"phone": "+70524646688"}
0005433124442	212213	2235 311764	VALERIY NIKOLAEV	{"phone": "+70541980107"}
0005433124443	72CFD4	9333 890502	TATYANA NIKITINA	{"phone": "+70712460553"}
0005433124444	2F1D80	3393 712872	ALEKSANDR MAKAROV	{"email": "amakarov-17101980@postgrespro.ru", "phone": "+70454901222"}
0005433124445	2F1D80	4827 540342	ALEKSEY DMITRIEV	{"phone": "+70384384226"}
0005433124446	4FAE2F	1495 717043	BORIS SHEVCHENKO	{"phone": "+70867957632"}
0005433124447	4FAE2F	5357 020217	ALEKSANDR KUDRYASHOV	{"email": "aleksandr-kudryashov-05081963@postgrespro.ru", "phone": "+70267129009"}
0005433124448	E8FAF0	7522 296038	ALEKSEY BORISOV	{"phone": "+70153529927"}
0005433124449	915AF1	8335 006058	VYACHESLAV MELNIKOV	{"phone": "+70115587134"}
0005433124450	915AF1	2647 348541	YULIYA VLASOVA	{"email": "vlasova_yuliya101984@postgrespro.ru", "phone": "+70449897035"}
0005433124451	BFF162	7531 882090	ALEKSANDR NAZAROV	{"email": "a_nazarov-1969@postgrespro.ru", "phone": "+70419337644"}
0005433124452	C940C2	8818 914719	DMITRIY ZAYCEV	{"phone": "+70918810360"}
0005433124453	61BE98	4454 658860	TATYANA DENISOVA	{"phone": "+70697630674"}
0005433124454	61BE98	6687 797370	NIKOLAY KUZNECOV	{"phone": "+70749553972"}
0005433124455	F709C3	6209 305439	PETR ANDREEV	{"phone": "+70420655398"}
0005433124456	F709C3	4967 391872	ALEKSANDR VASILEV	{"phone": "+70633785492"}
0005433124457	2A634F	6208 667806	VIKTOR ZAKHAROV	{"email": "viktorzakharov_021968@postgrespro.ru", "phone": "+70861896563"}
0005433124458	2513FF	3746 038802	MARIYA KARPOVA	{"email": "m-karpova.1978@postgrespro.ru", "phone": "+70169909950"}
0005433124459	C1AEA5	0194 399330	ALEKSANDR KAZAKOV	{"email": "kazakov_a22081959@postgrespro.ru", "phone": "+70985925007"}
0005433124460	5940C3	0520 108103	NATALIYA KOMAROVA	{"email": "komarovan_011978@postgrespro.ru", "phone": "+70185304561"}
0005433124461	5940C3	5038 837261	ANNA PETROVA	{"email": "petrova_anna05041970@postgrespro.ru", "phone": "+70815145873"}
0005433124462	90A1A6	9456 018141	SERGEY VASILEV	{"email": "vasilev.sergey-011980@postgrespro.ru", "phone": "+70278856852"}
0005433124463	89AD61	4597 155077	DENIS FEDOROV	{"phone": "+70247579453"}
0005433124464	A972F8	1431 594575	OLGA MIRONOVA	{"email": "omironova101971@postgrespro.ru", "phone": "+70846690978"}
0005433124465	A972F8	4260 284317	ANASTASIYA NOVIKOVA	{"email": "novikova-anastasiya_04111972@postgrespro.ru", "phone": "+70557457326"}
0005433124466	A972F8	0619 403448	RAISA DMITRIEVA	{"email": "rdmitrieva_1970@postgrespro.ru", "phone": "+70903424088"}
0005433124467	6E59CA	0198 940405	ALENA MOROZOVA	{"email": "morozova.alena_1986@postgrespro.ru", "phone": "+70945796711"}
0005433124468	D50BBE	4772 201417	VLADIMIR VLASOV	{"phone": "+70136518097"}
0005433124469	0C4112	8858 714840	ALEKSEY MAKAROV	{"email": "makarov-a_1976@postgrespro.ru", "phone": "+70773152992"}
0005433124470	A51E49	2046 480832	LYUBOV FROLOVA	{"phone": "+70270025935"}
0005433124471	A51E49	3724 562931	EVGENIY FROLOV	{"phone": "+70693778527"}
0005433124472	6F3D4F	5368 747859	DMITRIY PETROV	{"email": "d.petrov_031969@postgrespro.ru", "phone": "+70287114370"}
0005433124473	98B698	1212 828467	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey_051967@postgrespro.ru", "phone": "+70266273327"}
0005433124474	B636E0	1609 953887	ANDREY NAZAROV	{"phone": "+70418487423"}
0005433124475	B636E0	0016 299549	ALINA KUZNECOVA	{"email": "kuznecova-alina-1972@postgrespro.ru", "phone": "+70657984295"}
0005433124476	B636E0	8961 540861	SERGEY ALEKSANDROV	{"email": "aleksandrovs_07101965@postgrespro.ru", "phone": "+70005700900"}
0005433124477	19BF61	9110 936981	YAROSLAV ZHUKOV	{"phone": "+70937199399"}
0005433124478	E7D481	1418 886270	ANDREY SAVELEV	{"email": "andrey-savelev-061976@postgrespro.ru", "phone": "+70978993134"}
0005433124479	953AE3	9467 295563	NINA IVANOVA	{"email": "n-ivanova.1968@postgrespro.ru", "phone": "+70300481814"}
0005433124480	953AE3	2941 649261	VALERIY OSIPOV	{"email": "v-osipov-05091975@postgrespro.ru", "phone": "+70885092895"}
0005433124481	953AE3	5998 092899	VASILIY KRASNOV	{"email": "vkrasnov_1968@postgrespro.ru", "phone": "+70972211564"}
0005433124482	8C72A5	0481 924397	GALINA BELOVA	{"phone": "+70635163009"}
0005433124483	1DAE12	7273 544971	GALINA FROLOVA	{"email": "frolova-g_091976@postgrespro.ru", "phone": "+70619284612"}
0005433124484	1DAE12	2432 170885	MARINA ALEKSEEVA	{"phone": "+70635514416"}
0005433124485	3CBB1F	6183 938237	ELENA IVANOVA	{"email": "e_ivanova1984@postgrespro.ru", "phone": "+70210779706"}
0005433124486	A6D9A1	8336 251161	YULIYA VASILEVA	{"email": "y.vasileva29031961@postgrespro.ru", "phone": "+70799188676"}
0005433124487	A6D9A1	4478 887716	TAISIYA KISELEVA	{"phone": "+70263018125"}
0005433124488	8D8A13	3580 931373	VALERIY FOMIN	{"email": "fominvaleriy_071972@postgrespro.ru", "phone": "+70601435156"}
0005433124489	CA3000	6418 183471	YURIY SAVELEV	{"phone": "+70914659566"}
0005433124490	10D950	7750 000615	MIKHAIL FILIPPOV	{"phone": "+70096022899"}
0005433124491	10D950	6235 229928	NIKOLAY NOVIKOV	{"phone": "+70250846669"}
0005433124492	E7A940	1800 274189	MARINA IVANOVA	{"email": "marina_ivanova.1964@postgrespro.ru", "phone": "+70729744035"}
0005433124493	E7A940	8080 578836	SERGEY KOROLEV	{"phone": "+70023629358"}
0005433124494	C41D64	6704 932494	NIKOLAY FILIPPOV	{"phone": "+70939180828"}
0005433124495	D6C29C	7189 266559	DMITRIY NIKOLAEV	{"phone": "+70040767591"}
0005433124496	D6C29C	6823 126759	ELIZAVETA GAVRILOVA	{"phone": "+70312005748"}
0005433124497	C8F619	6005 990136	PETR SMIRNOV	{"phone": "+70310875998"}
0005433124498	E69B48	4620 467536	ELENA LAZAREVA	{"phone": "+70345971027"}
0005433124499	60BC55	2571 090104	MIKHAIL KUZNECOV	{"email": "kuznecov-mikhail_011963@postgrespro.ru", "phone": "+70072199629"}
0005433124500	CDF816	5273 961433	KONSTANTIN STEPANOV	{"phone": "+70764125593"}
0005433124501	CDF816	6496 791805	EVGENIYA KONOVALOVA	{"email": "ekonovalova-1978@postgrespro.ru", "phone": "+70844290719"}
0005433124502	721017	2838 711071	SERGEY SEMENOV	{"email": "semenov-sergey_13061971@postgrespro.ru", "phone": "+70093245099"}
0005433124503	721017	2031 888433	SERGEY KOZLOV	{"email": "sergey-kozlov-101971@postgrespro.ru", "phone": "+70237097274"}
0005433124504	857B14	5910 676938	ARSENIY ABRAMOV	{"email": "abramov_a_1978@postgrespro.ru", "phone": "+70391397475"}
0005433124505	857B14	7553 657838	NADEZHDA VASILEVA	{"phone": "+70156325590"}
0005433124506	154FD4	3797 587895	DMITRIY FILIPPOV	{"phone": "+70322294773"}
0005433124507	154FD4	1870 979988	YULIYA SOLOVEVA	{"email": "yuliya.soloveva1970@postgrespro.ru", "phone": "+70906981070"}
0005433124508	DE0EC7	0543 270313	ALEKSEY TIMOFEEV	{"email": "a.timofeev-17011980@postgrespro.ru", "phone": "+70409633550"}
0005433124509	367F84	3602 786740	SVETLANA STEPANOVA	{"email": "stepanovas-1974@postgrespro.ru", "phone": "+70596280984"}
0005433124510	151620	5545 238775	YAROSLAVA SOROKINA	{"email": "y-sorokina-1974@postgrespro.ru", "phone": "+70184084138"}
0005433124511	151620	6837 717815	SERGEY SCHERBAKOV	{"email": "scherbakov-s_22091965@postgrespro.ru", "phone": "+70354080836"}
0005433124512	2AE330	2577 481626	IRINA ZAKHAROVA	{"phone": "+70928667268"}
0005433124513	E591F3	4651 913933	KONSTANTIN BORISOV	{"email": "borisovkonstantin-16031970@postgrespro.ru", "phone": "+70858360122"}
0005433124514	E591F3	0342 117777	ELENA KOROLEVA	{"phone": "+70262489578"}
0005433124515	C45A28	8839 175604	ALEKSANDRA MOROZOVA	{"email": "morozova_a.071977@postgrespro.ru", "phone": "+70517820385"}
0005433124516	BE8F2D	1918 755430	ARSENIY GUSEV	{"email": "a_gusev.15101982@postgrespro.ru", "phone": "+70404662395"}
0005433124517	BE8F2D	3173 324546	EVGENIY ALEKSEEV	{"phone": "+70440588818"}
0005433124518	2AA331	3746 171526	VLADIMIR IVANOV	{"email": "ivanovv-01041969@postgrespro.ru", "phone": "+70700616800"}
0005433124519	F39E95	7483 585523	ANDREY KRASNOV	{"email": "andrey_krasnov011971@postgrespro.ru", "phone": "+70521209967"}
0005433124520	A7FBA7	9200 430146	LYUDMILA PAVLOVA	{"email": "l-pavlova.061970@postgrespro.ru", "phone": "+70052770171"}
0005433124521	A7FBA7	8859 146591	YANA ANDREEVA	{"phone": "+70396266600"}
0005433124522	37C196	4123 811819	SVETLANA FOMINA	{"email": "svetlana-fomina031966@postgrespro.ru", "phone": "+70726281404"}
0005433124523	8BC608	4116 428062	PAVEL GRIGOREV	{"email": "pavelgrigorev-1971@postgrespro.ru", "phone": "+70333935595"}
0005433124524	8F74A4	7352 941680	LYUBOV ZOTOVA	{"phone": "+70520920396"}
0005433124525	8F74A4	6176 999808	ALEVTINA FOMINA	{"phone": "+70769264188"}
0005433124526	F8601F	9574 037525	VIKTOR FEDOROV	{"phone": "+70654912134"}
0005433124527	F8601F	8151 366990	ANASTASIYA MAKAROVA	{"email": "anastasiya.makarova061970@postgrespro.ru", "phone": "+70153179690"}
0005433124528	40D4DB	0500 280841	EVGENIY SERGEEV	{"email": "e.sergeev.121965@postgrespro.ru", "phone": "+70321874762"}
0005433124529	55B1F3	2383 582100	EVDOKIYA DMITRIEVA	{"email": "evdokiya.dmitrieva.1975@postgrespro.ru", "phone": "+70422920017"}
0005433124530	4C1F0C	9863 664247	ELENA SEMENOVA	{"phone": "+70612543232"}
0005433124531	59F786	4457 490087	MARIYA SAVELEVA	{"phone": "+70158307130"}
0005433124532	59F786	3158 503356	ANTON BARANOV	{"phone": "+70241776294"}
0005433124533	DC8627	4999 909283	VIKTOR GORBUNOV	{"email": "gorbunovv_11121963@postgrespro.ru", "phone": "+70510362364"}
0005433124534	5E6296	3929 122218	VLADIMIR GRIGOREV	{"email": "grigorev_v_061976@postgrespro.ru", "phone": "+70036936640"}
0005433124535	52A66E	0712 396400	KIRA GRISHINA	{"email": "grishina_kira-061978@postgrespro.ru", "phone": "+70225291757"}
0005433124536	52A66E	0972 902143	MARINA KULIKOVA	{"email": "marina-kulikova_04091971@postgrespro.ru", "phone": "+70503630055"}
0005433124537	BB4436	7694 160150	VLADIMIR VOROBEV	{"phone": "+70080159734"}
0005433124538	74FE55	1477 962561	ELENA TARASOVA	{"email": "tarasova-e-05031985@postgrespro.ru", "phone": "+70682308920"}
0005433124539	4584F0	3624 049710	IGOR MEDVEDEV	{"phone": "+70129344261"}
0005433124540	361E89	7839 294842	VALERIY MAKSIMOV	{"email": "maksimovvaleriy-10041978@postgrespro.ru", "phone": "+70157519868"}
0005433124541	278E6E	3223 633190	LYUBOV MIKHAYLOVA	{"email": "lmikhaylova_1966@postgrespro.ru", "phone": "+70787605001"}
0005433124542	1F224A	5632 027004	VIKTOR PAVLOV	{"phone": "+70246505735"}
0005433124543	7C65CE	8982 396772	SERGEY ALEKSEEV	{"email": "alekseev.s-14051968@postgrespro.ru", "phone": "+70752773009"}
0005433124544	7C65CE	0105 279358	DARYA YAKOVLEVA	{"email": "yakovleva.d051967@postgrespro.ru", "phone": "+70462031724"}
0005433124545	46B86C	6722 600249	LYUDMILA GUSEVA	{"phone": "+70703115604"}
0005433124546	46B86C	7717 649359	NADEZHDA TROFIMOVA	{"phone": "+70628862488"}
0005433124547	F9B7CF	2394 267718	VERA KULIKOVA	{"phone": "+70799599832"}
0005433124548	65E16D	9295 163927	NINA NOVIKOVA	{"email": "novikova-nina.1980@postgrespro.ru", "phone": "+70491620017"}
0005433124549	D3BAC7	4524 712781	NATALYA ABRAMOVA	{"email": "natalyaabramova061969@postgrespro.ru", "phone": "+70360860293"}
0005433124550	C297E6	0097 384330	SAMVEL VASILEV	{"phone": "+70454998919"}
0005433124551	BF50CC	7733 116416	VLADIMIR BARANOV	{"email": "v.baranov.29061973@postgrespro.ru", "phone": "+70898192357"}
0005433124552	29D94A	8864 312681	IVAN SOROKIN	{"email": "sorokin.i_26041966@postgrespro.ru", "phone": "+70473441408"}
0005433124553	7F2DCB	1282 034972	DIANA MATVEEVA	{"phone": "+70269768728"}
0005433124554	7F2DCB	1142 468910	MIKHAIL MOROZOV	{"email": "mikhail-morozov_1974@postgrespro.ru", "phone": "+70765360487"}
0005433126768	BFFF5D	5699 310682	IGOR NAZAROV	{"email": "igor.nazarov-03081980@postgrespro.ru", "phone": "+70132809690"}
0005433126769	BFFF5D	9643 815928	VALENTINA MOROZOVA	{"email": "valentina.morozova_031971@postgrespro.ru", "phone": "+70509635979"}
0005433126770	308192	6774 788715	RUSTAM MIRONOV	{"phone": "+70816214825"}
0005433126771	308192	8010 509734	ROMAN ALEKSEEV	{"phone": "+70115734373"}
0005433126772	C7427E	7494 997584	EKATERINA EGOROVA	{"email": "e-egorova-111973@postgrespro.ru", "phone": "+70595517642"}
0005433126773	C7427E	8753 875858	NATALYA ROMANOVA	{"email": "n.romanova-1980@postgrespro.ru", "phone": "+70336832879"}
0005433126774	D28020	6774 194523	PETR SMIRNOV	{"phone": "+70268999558"}
0005433126775	D28020	0684 759729	ELENA VASILEVA	{"email": "vasileva.elena_01031967@postgrespro.ru", "phone": "+70661919420"}
0005433126776	D28020	2414 633633	SERGEY ORLOV	{"phone": "+70955768324"}
0005433126777	E2B532	5074 258532	DZHAMILYA ZAYCEVA	{"email": "zayceva-d_1967@postgrespro.ru", "phone": "+70383599508"}
0005433126778	2859C4	3502 640897	VLADIMIR SOKOLOV	{"email": "sokolov.v_1973@postgrespro.ru", "phone": "+70546731682"}
0005433126779	2859C4	4593 410980	NATALIYA BARANOVA	{"phone": "+70386643193"}
0005433126780	1FD0E9	9150 142309	OLGA MALYSHEVA	{"email": "malysheva-o_1960@postgrespro.ru", "phone": "+70365935962"}
0005433126781	4A656E	2671 266748	TATYANA FILIPPOVA	{"email": "filippova.t_091984@postgrespro.ru", "phone": "+70235304247"}
0005433126782	3BD5BC	1797 244902	VALENTINA ZAYCEVA	{"email": "v-zayceva-28061961@postgrespro.ru", "phone": "+70321101664"}
0005433126783	3BD5BC	8365 810053	EKATERINA GERASIMOVA	{"email": "gerasimova_e1963@postgrespro.ru", "phone": "+70547328597"}
0005433126784	3BD5BC	5529 703319	EKATERINA MATVEEVA	{"email": "matveevae-06061967@postgrespro.ru", "phone": "+70456848006"}
0005433126785	7600A6	0495 151965	LYUDMILA SOLOVEVA	{"email": "l_soloveva-19051975@postgrespro.ru", "phone": "+70154018859"}
0005433126786	A327C6	6414 363478	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey1988@postgrespro.ru", "phone": "+70811833979"}
0005433126787	A327C6	1846 968115	VALENTIN TIMOFEEV	{"email": "v.timofeev-1971@postgrespro.ru", "phone": "+70041605240"}
0005433126788	D3551F	1912 963793	IVAN ZAKHAROV	{"email": "zakharovi26091971@postgrespro.ru", "phone": "+70070706284"}
0005433126789	E99063	5169 563743	SERGEY NOVIKOV	{"email": "s-novikov-1985@postgrespro.ru", "phone": "+70070569649"}
0005433126790	E99063	3559 880495	LYUDMILA SOKOLOVA	{"email": "lyudmila_sokolova_1965@postgrespro.ru", "phone": "+70385316281"}
0005433126791	C3AF9B	6474 656114	ARTEM BARANOV	{"phone": "+70607606961"}
0005433126792	43A888	3321 802269	SERGEY KOZLOV	{"phone": "+70202534541"}
0005433126793	43A888	5396 035310	ROMAN NAZAROV	{"email": "r.nazarov.1966@postgrespro.ru", "phone": "+70353745128"}
0005433126794	DADA4A	7997 867388	EGOR SIDOROV	{"phone": "+70076149772"}
0005433126795	A3B4AD	0319 854993	ALEKSANDR MAKAROV	{"phone": "+70337709290"}
0005433126796	F5A335	8332 713990	ELLA RODIONOVA	{"email": "rodionovae_15081981@postgrespro.ru", "phone": "+70405659678"}
0005433126797	F5A335	2686 764398	ALEKSANDR MIRONOV	{"email": "a.mironov-26081973@postgrespro.ru", "phone": "+70896774780"}
0005433126798	E497D0	5192 024399	LARISA BELOVA	{"email": "belova_l-101978@postgrespro.ru", "phone": "+70071393292"}
0005433126799	E497D0	9719 570056	MARINA IVANOVA	{"email": "marina_ivanova081964@postgrespro.ru", "phone": "+70292021261"}
0005433126800	4D4DA2	8428 831401	ALEKSANDR MOROZOV	{"phone": "+70310381146"}
0005433126801	4D4DA2	7399 139021	KONSTANTIN PAVLOV	{"email": "pavlov.k-06121977@postgrespro.ru", "phone": "+70644558705"}
0005433126802	F7DD1C	4893 370009	SERGEY MARTYNOV	{"email": "martynov_sergey_011975@postgrespro.ru", "phone": "+70596603426"}
0005433126803	2E55EE	1389 194745	DMITRIY KUZMIN	{"email": "d_kuzmin08101970@postgrespro.ru", "phone": "+70452729694"}
0005433126804	7F5B5D	7330 090765	ALEKSEY KARPOV	{"phone": "+70603080703"}
0005433126805	47CC34	8603 524436	ASIYA GAVRILOVA	{"email": "gavrilova.a.021957@postgrespro.ru", "phone": "+70877494067"}
0005433126806	47CC34	7086 265801	ELENA NAZAROVA	{"email": "nazarovae-02021971@postgrespro.ru", "phone": "+70687630249"}
0005433126807	DDBFC1	6457 421194	OLGA PETROVA	{"email": "petrova-olga_22101980@postgrespro.ru", "phone": "+70567008412"}
0005433126808	DDBFC1	2669 276706	NADEZHDA DAVYDOVA	{"phone": "+70409063058"}
0005433126809	1AB7E8	0370 689678	IRINA OSIPOVA	{"email": "irina.osipova1962@postgrespro.ru", "phone": "+70985511220"}
0005433126810	1AB7E8	1021 104205	IRINA AFANASEVA	{"email": "afanasevai-111981@postgrespro.ru", "phone": "+70963195839"}
0005433126811	7B3B86	8420 538398	EKATERINA VLASOVA	{"phone": "+70504972133"}
0005433126812	32B2CF	6798 147193	EKATERINA KUZMINA	{"phone": "+70828150220"}
0005433126813	3C2421	1132 398948	MAKSIM BARANOV	{"email": "maksim.baranov.1961@postgrespro.ru", "phone": "+70899955651"}
0005433126814	04FB7C	0590 125564	NADEZHDA CHERNOVA	{"email": "n_chernova-061970@postgrespro.ru", "phone": "+70406013485"}
0005433126815	D46826	6511 088614	ALI BORISOV	{"email": "aliborisov-1970@postgrespro.ru", "phone": "+70979031674"}
0005433126816	046299	2653 634091	NINA STEPANOVA	{"phone": "+70578724655"}
0005433126817	046299	7516 250898	YULIYA MOROZOVA	{"email": "ymorozova.061963@postgrespro.ru", "phone": "+70592800942"}
0005433126818	7AB09F	9027 802792	ALEKSANDR DENISOV	{"phone": "+70139093228"}
0005433126819	7AB09F	0327 925929	NATALYA ANDREEVA	{"email": "andreeva.n_19091972@postgrespro.ru", "phone": "+70625766649"}
0005433126820	DDAB39	7999 726728	ANNA PETROVA	{"email": "anna-petrova-011975@postgrespro.ru", "phone": "+70294193054"}
0005433126821	EB8D45	8647 724107	EVGENIYA KUZNECOVA	{"phone": "+70752241814"}
0005433126822	66E000	3461 224505	SVETLANA EGOROVA	{"phone": "+70328326095"}
0005433126823	54F02C	9273 883688	IGOR ANDREEV	{"phone": "+70476845004"}
0005433126824	07935C	5402 525088	KSENIYA NIKOLAEVA	{"phone": "+70520430619"}
0005433126825	8FF30D	5746 765746	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev_081974@postgrespro.ru", "phone": "+70413208993"}
0005433126949	E15C43	5778 733252	LYUBOV PETROVA	{"phone": "+70284818606"}
0005433126826	8FF30D	6919 327680	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov_1975@postgrespro.ru", "phone": "+70784868231"}
0005433126827	1B1DFC	4715 275712	NIKOLAY PAVLOV	{"email": "pavlov_n_1977@postgrespro.ru", "phone": "+70805532888"}
0005433126828	1B1DFC	7827 573534	YURIY IVANOV	{"email": "ivanovyuriy-1971@postgrespro.ru", "phone": "+70443159325"}
0005433126829	8BE2B4	0405 461709	ANTONIDA MIRONOVA	{"email": "mironovaa_1965@postgrespro.ru", "phone": "+70998223258"}
0005433126830	213977	3142 502093	VALERIY IVANOV	{"email": "vivanov23071968@postgrespro.ru", "phone": "+70718222262"}
0005433126831	D6A659	2401 255493	ALEKSANDR ANTONOV	{"email": "antonov_aleksandr.1964@postgrespro.ru", "phone": "+70219163833"}
0005433126832	41F85A	1986 527329	NATALYA KONOVALOVA	{"phone": "+70215304250"}
0005433126833	41F85A	6714 302121	MIKHAIL ABRAMOV	{"phone": "+70572120666"}
0005433126834	41F85A	0283 291025	IVAN BORISOV	{"phone": "+70597017984"}
0005433126835	384D2A	1975 559109	EGOR NIKITIN	{"email": "e_nikitin_041978@postgrespro.ru", "phone": "+70241518801"}
0005433126836	280D39	4925 587452	ARTEM SCHERBAKOV	{"email": "scherbakov_a-28071974@postgrespro.ru", "phone": "+70910084183"}
0005433126837	C9E98F	8324 849202	VALERIYA NIKITINA	{"email": "nikitina-valeriya-20061975@postgrespro.ru", "phone": "+70653634079"}
0005433126838	C9E98F	0542 928508	OLGA YUDINA	{"phone": "+70437641507"}
0005433126839	9F9562	6563 659757	EVGENIY ORLOV	{"phone": "+70619469825"}
0005433126840	9F9562	6646 102539	ELIZAVETA GRISHINA	{"phone": "+70358439503"}
0005433126841	E98629	7760 316217	NATALYA ZAKHAROVA	{"phone": "+70968454163"}
0005433126842	461E2B	5546 061108	TATYANA MAKAROVA	{"phone": "+70996504392"}
0005433126843	4EB60C	7268 297668	NAIL KUZMIN	{"email": "kuzmin-n-071974@postgrespro.ru", "phone": "+70949357809"}
0005433126844	F75C7F	6552 957408	SERGEY BORISOV	{"email": "sergey-borisov-21111976@postgrespro.ru", "phone": "+70068688179"}
0005433126845	F75C7F	3859 822806	DARYA ILINA	{"email": "ilinad-16091971@postgrespro.ru", "phone": "+70091958921"}
0005433126846	8C3FA2	5445 026007	VITALIY SMIRNOV	{"phone": "+70372959448"}
0005433126847	8C3FA2	0743 548138	OLEG FEDOROV	{"email": "fedorov-o_1970@postgrespro.ru", "phone": "+70147525549"}
0005433126848	9DDD59	3734 085173	SVETLANA YAKOVLEVA	{"phone": "+70371425901"}
0005433126849	90D9C2	8136 690674	ANDREY CHERNOV	{"email": "a-chernov.1958@postgrespro.ru", "phone": "+70920038111"}
0005433126850	4992B8	9252 921497	VERA KUZNECOVA	{"phone": "+70499997354"}
0005433126851	4992B8	8381 878404	SERGEY TARASOV	{"email": "tarasov-sergey101968@postgrespro.ru", "phone": "+70208644374"}
0005433126852	746E96	1221 737106	ELENA FADEEVA	{"phone": "+70719964233"}
0005433126853	AEA115	4489 817799	TATYANA TIMOFEEVA	{"phone": "+70984371305"}
0005433126854	AEA115	7063 036807	IRINA PETROVA	{"email": "i_petrova26091969@postgrespro.ru", "phone": "+70579895334"}
0005433126855	A02B14	2074 331085	ALEKSANDR IVANOV	{"phone": "+70039723521"}
0005433126856	EDD28D	1604 774061	NATALYA KUDRYASHOVA	{"phone": "+70656395879"}
0005433126857	EDD28D	2252 117191	NATALYA VOROBEVA	{"email": "vorobevan_12101971@postgrespro.ru", "phone": "+70429702509"}
0005433126858	40F04B	3739 144446	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a.17101965@postgrespro.ru", "phone": "+70732832990"}
0005433126859	AC45B4	4735 535796	OLEG SOROKIN	{"email": "o-sorokin1971@postgrespro.ru", "phone": "+70317606326"}
0005433126860	310775	2314 727817	TATYANA FADEEVA	{"phone": "+70633432624"}
0005433126861	878A54	8439 598712	DARYA BELOVA	{"phone": "+70837610120"}
0005433126862	DB23C2	8268 348882	ELENA SCHERBAKOVA	{"phone": "+70910657413"}
0005433126863	F0E2A1	5257 524819	VERA MIRONOVA	{"phone": "+70061455651"}
0005433126864	EEC5D9	4608 922844	NIKOLAY MAKAROV	{"phone": "+70685117842"}
0005433126865	8800AE	1902 100976	OLGA TITOVA	{"email": "o_titova.1982@postgrespro.ru", "phone": "+70398131527"}
0005433126866	BF48B6	2720 915822	OLGA SOKOLOVA	{"phone": "+70057966664"}
0005433126867	EC0EBE	5033 588506	IRINA GAVRILOVA	{"email": "i.gavrilova1959@postgrespro.ru", "phone": "+70534431493"}
0005433126868	EC0EBE	5747 061935	ALEKSANDR RODIONOV	{"phone": "+70031059967"}
0005433126869	629EED	9100 722237	DARYA ZHURAVLEVA	{"phone": "+70406648339"}
0005433126870	629EED	4546 867916	DMITRIY NIKOLAEV	{"email": "d-nikolaev_101979@postgrespro.ru", "phone": "+70777198276"}
0005433126871	9E2CDC	9253 636853	LYUDMILA OSIPOVA	{"phone": "+70603313530"}
0005433126872	9E2CDC	9927 247753	ALBINA ANDREEVA	{"phone": "+70454233652"}
0005433126873	DE6638	2082 966173	EVGENIY VOLKOV	{"phone": "+70408242184"}
0005433126874	CD1749	1390 454192	NINA MAKAROVA	{"email": "makarovan1961@postgrespro.ru", "phone": "+70384954935"}
0005433126875	FD79FD	0554 871798	ROMAN SEMENOV	{"phone": "+70049936657"}
0005433126876	BC0ABF	5423 869190	TATYANA RODIONOVA	{"phone": "+70647956834"}
0005433126877	BC0ABF	5849 259876	ANDREY MOROZOV	{"phone": "+70001626213"}
0005433126878	F7842B	4323 696092	GENNADIY DENISOV	{"phone": "+70642687633"}
0005433126879	447725	8158 493778	IRINA KUZNECOVA	{"phone": "+70242063744"}
0005433126880	D5CB4E	4997 370226	NATALYA SOLOVEVA	{"phone": "+70363615115"}
0005433126881	D5CB4E	5827 506528	EVGENIYA MAKAROVA	{"email": "makarova_e01071972@postgrespro.ru", "phone": "+70366240010"}
0005433126882	E8E44A	4813 632673	NIKOLAY GAVRILOV	{"email": "gavrilov-nikolay_27021971@postgrespro.ru", "phone": "+70437119459"}
0005433126883	E8E44A	7894 082769	SERGEY ISAEV	{"phone": "+70501905168"}
0005433126884	E8E44A	3919 008686	ARTEM STEPANOV	{"email": "stepanov.artem121980@postgrespro.ru", "phone": "+70210754662"}
0005433126885	70786B	0350 050178	NATALYA ARKHIPOVA	{"email": "n_arkhipova.091967@postgrespro.ru", "phone": "+70434960625"}
0005433126886	4DDC9A	6821 800153	SERGEY NIKITIN	{"phone": "+70400435048"}
0005433126887	0B8162	3972 633063	OLGA SIDOROVA	{"phone": "+70567494613"}
0005433126888	249168	6702 845982	EKATERINA POLYAKOVA	{"phone": "+70336941473"}
0005433126889	AF0C05	9286 331220	ARINA MAKAROVA	{"email": "makarova.arina-041978@postgrespro.ru", "phone": "+70644798141"}
0005433126890	B74751	6243 859092	SERGEY VLASOV	{"email": "sergeyvlasov.1965@postgrespro.ru", "phone": "+70738443225"}
0005433126891	B74751	0251 663922	ALEKSANDR KUZMIN	{"phone": "+70388930489"}
0005433126892	F8151B	3288 051701	LIDIYA SERGEEVA	{"email": "lidiya_sergeeva-1958@postgrespro.ru", "phone": "+70386312265"}
0005433126893	805269	4499 915891	ANNA TIKHONOVA	{"phone": "+70015892784"}
0005433126894	805269	3455 666913	ELIZAVETA KUZNECOVA	{"phone": "+70329259698"}
0005433126895	805269	1282 277167	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr_25111980@postgrespro.ru", "phone": "+70875417259"}
0005433126896	007F37	5485 371192	TATYANA KARPOVA	{"email": "tatyana-karpova_1967@postgrespro.ru", "phone": "+70449121775"}
0005433126897	007F37	7995 602551	VALERIY KONOVALOV	{"phone": "+70472566407"}
0005433126898	007F37	2495 624373	DARYA DMITRIEVA	{"phone": "+70349017102"}
0005433126899	C2FC0E	0572 280075	AYRAT DENISOV	{"email": "denisov-ayrat.07051974@postgrespro.ru", "phone": "+70022415678"}
0005433126900	45FC97	6987 259667	ALEKSANDR BELOV	{"email": "belov.aleksandr-031975@postgrespro.ru", "phone": "+70044502665"}
0005433126901	4432A1	1616 799941	ANTONINA POPOVA	{"phone": "+70742375908"}
0005433126902	C3F733	5867 151917	ANNA FROLOVA	{"phone": "+70646707385"}
0005433126903	EA339A	0631 359334	VALENTINA FILIPPOVA	{"email": "v.filippova.1964@postgrespro.ru", "phone": "+70759103814"}
0005433126904	EA339A	4901 176290	VERA LUKYANOVA	{"email": "lukyanova_v_1972@postgrespro.ru", "phone": "+70789706558"}
0005433126905	239B5D	7613 054328	ALEKSEY KUZNECOV	{"phone": "+70839795983"}
0005433126906	239B5D	4685 546855	MATVEY SOKOLOV	{"phone": "+70058505443"}
0005433126907	C1B5CE	7771 025373	SERGEY KUZNECOV	{"email": "sergey-kuznecov-1980@postgrespro.ru", "phone": "+70429813790"}
0005433126908	DAFF60	9293 112813	OLGA VASILEVA	{"email": "vasileva_o.111975@postgrespro.ru", "phone": "+70617599619"}
0005433126909	58D380	4488 443717	ALEKSEY MELNIKOV	{"phone": "+70661374902"}
0005433126910	58D380	4473 058678	ELVIRA SOKOLOVA	{"email": "elvirasokolova1971@postgrespro.ru", "phone": "+70194798049"}
0005433126911	F07AED	2276 694178	MAKSIM SIDOROV	{"phone": "+70220724323"}
0005433126912	F07AED	5323 110757	ANNA LAZAREVA	{"phone": "+70992227853"}
0005433126913	49B41E	3499 065053	ANDREY MIRONOV	{"email": "mironov.a_1972@postgrespro.ru", "phone": "+70857911102"}
0005433126914	A6AA57	7565 197897	TATYANA ALEKSEEVA	{"phone": "+70013147977"}
0005433126915	DDC077	9686 994732	DMITRIY ZHUKOV	{"email": "dmitriy.zhukov_1980@postgrespro.ru", "phone": "+70209648219"}
0005433126916	34A4CA	4146 580949	SVETLANA SERGEEVA	{"email": "s.sergeeva-03091978@postgrespro.ru", "phone": "+70389988880"}
0005433126917	96BFA9	6669 952046	VALERIY SMIRNOV	{"phone": "+70633357101"}
0005433126918	535CDA	5547 716546	EKATERINA TARASOVA	{"phone": "+70342236928"}
0005433126919	B922B7	4504 655651	DMITRIY SMIRNOV	{"email": "dsmirnov121979@postgrespro.ru", "phone": "+70749931540"}
0005433126920	F8313B	8396 231275	OKSANA ALEKSEEVA	{"phone": "+70675895173"}
0005433126921	B267A9	0648 536621	IRINA OVCHINNIKOVA	{"phone": "+70084025125"}
0005433126922	572201	8458 977122	VERONIKA PAVLOVA	{"email": "vpavlova.101976@postgrespro.ru", "phone": "+70858602983"}
0005433126923	59DCF9	5152 010711	OLGA ILINA	{"phone": "+70472369510"}
0005433126924	B23521	3948 374991	GALINA GAVRILOVA	{"phone": "+70518401071"}
0005433126925	15701C	9836 693545	PAVEL KRASNOV	{"phone": "+70269851647"}
0005433126926	15701C	8385 240340	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir.1973@postgrespro.ru", "phone": "+70942641033"}
0005433126927	4826CD	1538 921131	OLGA VASILEVA	{"email": "olgavasileva-031974@postgrespro.ru", "phone": "+70615240869"}
0005433126928	DE48EF	3701 890674	ELVIRA ZOTOVA	{"phone": "+70050057002"}
0005433126929	DE48EF	4047 507388	NATALYA DENISOVA	{"email": "n.denisova25091978@postgrespro.ru", "phone": "+70631617631"}
0005433126930	591BDB	7483 610381	GENNADIY KUZMIN	{"email": "gennadiy_kuzmin.06021981@postgrespro.ru", "phone": "+70603223335"}
0005433126931	55237E	5968 313646	IRINA BELYAEVA	{"email": "belyaeva-irina.02111967@postgrespro.ru", "phone": "+70530841375"}
0005433126932	5C82B4	1671 534310	NINA NAZAROVA	{"phone": "+70671486107"}
0005433126933	5C82B4	0565 792144	ZHANNA YAKOVLEVA	{"email": "yakovleva_zhanna.1980@postgrespro.ru", "phone": "+70701462075"}
0005433126934	1AF814	8549 980672	TATYANA OVCHINNIKOVA	{"email": "t.ovchinnikova_15051979@postgrespro.ru", "phone": "+70911108892"}
0005433126935	764C1E	3558 909515	GALINA MOISEEVA	{"phone": "+70853497200"}
0005433126936	0C1E03	1367 727232	YURIY KOROLEV	{"email": "korolevy-06021976@postgrespro.ru", "phone": "+70659290355"}
0005433126937	0C1E03	7850 877957	NIKOLAY SHEVCHENKO	{"phone": "+70660090086"}
0005433126938	0C1E03	7023 592363	KARINA KARPOVA	{"email": "karinakarpova_1962@postgrespro.ru", "phone": "+70437112482"}
0005433126939	D4C328	4521 464995	DMITRIY KOZLOV	{"phone": "+70321533476"}
0005433126940	D4C328	6615 266102	IGOR TARASOV	{"email": "igor.tarasov.1974@postgrespro.ru", "phone": "+70930947251"}
0005433126941	FB087F	6212 766804	ALEKSANDR IVANOV	{"phone": "+70987883679"}
0005433126942	B774B2	0033 209949	ANDREY SMIRNOV	{"email": "andreysmirnov.061970@postgrespro.ru", "phone": "+70822959264"}
0005433126943	E6A3E4	6323 255593	EKATERINA AFANASEVA	{"phone": "+70565057639"}
0005433126944	64F039	2303 976123	OKSANA KOMAROVA	{"email": "o.komarova.25021973@postgrespro.ru", "phone": "+70400115679"}
0005433126945	64F039	3572 983548	DMITRIY KONOVALOV	{"email": "konovalovdmitriy-15121963@postgrespro.ru", "phone": "+70638228788"}
0005433126946	766FA5	1753 288410	MARIYA KOLESNIKOVA	{"email": "kolesnikovam.1967@postgrespro.ru", "phone": "+70050091653"}
0005433126947	83688B	3031 579979	YULIYA GAVRILOVA	{"phone": "+70277381102"}
0005433126948	83688B	3190 818742	NIKOLAY MOROZOV	{"email": "nikolaymorozov.1979@postgrespro.ru", "phone": "+70656988440"}
0005433126950	E15C43	4007 401287	TATYANA SMIRNOVA	{"phone": "+70706899421"}
0005433126951	E15C43	4553 804902	IRINA IVANOVA	{"phone": "+70447505747"}
0005433126952	15FAB1	7502 323983	NINA NAUMOVA	{"email": "naumovan-1970@postgrespro.ru", "phone": "+70124779803"}
0005433126953	B07565	7284 338863	GALINA EFIMOVA	{"email": "galina_efimova-1959@postgrespro.ru", "phone": "+70348398994"}
0005433126954	BBE67E	8005 547979	ANNA OSIPOVA	{"phone": "+70482791630"}
0005433126955	BBE67E	3661 140037	NINA FROLOVA	{"email": "frolova_nina-081976@postgrespro.ru", "phone": "+70066100232"}
0005433126956	0FA854	1173 773871	SERGEY FROLOV	{"email": "frolov-sergey_1966@postgrespro.ru", "phone": "+70493044823"}
0005433126957	99C1B2	7788 425904	DENIS FROLOV	{"email": "dfrolov1978@postgrespro.ru", "phone": "+70466276760"}
0005433126958	66FE92	6019 188185	ELENA ORLOVA	{"email": "orlova.e-10081966@postgrespro.ru", "phone": "+70073744617"}
0005433126959	B75FD9	4079 102770	NIKITA KOZLOV	{"email": "n_kozlov_01031969@postgrespro.ru", "phone": "+70326775917"}
0005433126960	B75FD9	7372 113939	VERONIKA KOROLEVA	{"email": "vkoroleva-1969@postgrespro.ru", "phone": "+70511493036"}
0005433126961	37B553	0937 514791	TATYANA KAZAKOVA	{"email": "kazakova-tatyana1969@postgrespro.ru", "phone": "+70103086923"}
0005433126962	3B0351	8909 908663	EGOR NIKOLAEV	{"email": "nikolaev_egor-101976@postgrespro.ru", "phone": "+70176329961"}
0005433126963	13B138	0124 365858	ALEKSEY MOROZOV	{"phone": "+70278093281"}
0005433126964	A72E79	2498 214687	MARIYA ZAYCEVA	{"email": "zayceva.m.1967@postgrespro.ru", "phone": "+70404919783"}
0005433126965	BD16F6	6390 953260	VLADIMIR KUZNECOV	{"email": "kuznecov-v1979@postgrespro.ru", "phone": "+70245941621"}
0005433126966	BD16F6	4738 080121	VALERIY KONOVALOV	{"phone": "+70466316287"}
0005433126967	D79D5A	8798 147036	PETR KULIKOV	{"phone": "+70612436829"}
0005433126968	76ED35	6764 705180	NADEZHDA PETROVA	{"email": "n.petrova-08101956@postgrespro.ru", "phone": "+70316744560"}
0005433126969	6BB0C2	2770 872721	MARGARITA FILATOVA	{"email": "m_filatova061961@postgrespro.ru", "phone": "+70556118859"}
0005433126970	6BB0C2	1956 604823	LILIYA YAKOVLEVA	{"phone": "+70924373250"}
0005433126971	CED9F7	1853 197905	VIKTOR KUZNECOV	{"email": "v_kuznecov08061967@postgrespro.ru", "phone": "+70979999648"}
0005433126972	5A99A2	6870 970353	LIDIYA ALEKSEEVA	{"email": "lidiya_alekseeva071967@postgrespro.ru", "phone": "+70940941500"}
0005433126973	5A99A2	5860 746187	DMITRIY MIKHAYLOV	{"phone": "+70565889501"}
0005433126974	87A865	7442 539650	IVAN FROLOV	{"email": "ivan-frolov17101980@postgrespro.ru", "phone": "+70163569531"}
0005433126975	DADA7E	7209 496078	GALINA SERGEEVA	{"phone": "+70854382642"}
0005433126976	E17A72	8570 971164	ALEKSANDR EGOROV	{"phone": "+70435852541"}
0005433126977	5D6F97	1591 804850	OKSANA NIKITINA	{"email": "nikitina-o_29011982@postgrespro.ru", "phone": "+70035925870"}
0005433126978	4394DD	3807 577518	DENIS ILIN	{"phone": "+70935596468"}
0005433126979	9246C7	1153 386087	ELMIRA IVANOVA	{"email": "ivanova.e.021976@postgrespro.ru", "phone": "+70035366001"}
0005433126980	C1F3B8	3603 327867	ELENA BELOVA	{"phone": "+70454131398"}
0005433126981	C1F3B8	8472 716008	EVDOKIYA ZAKHAROVA	{"email": "zakharova.e_16031968@postgrespro.ru", "phone": "+70672487626"}
0005433126982	1B6E32	2439 792509	ALEKSANDR SMIRNOV	{"phone": "+70779735225"}
0005433126983	5E9C16	8330 159322	KRISTINA CHERNOVA	{"email": "k_chernova-1976@postgrespro.ru", "phone": "+70938210875"}
0005433126984	5E9C16	0229 991916	DARYA VLASOVA	{"email": "vlasova_d_31071977@postgrespro.ru", "phone": "+70438534396"}
0005433126985	5E4595	6823 212440	ALEKSANDR MAKAROV	{"email": "a-makarov-10111969@postgrespro.ru", "phone": "+70378559709"}
0005433129198	C22CEA	6301 077036	SERGEY STEPANOV	{"phone": "+70011193344"}
0005433129199	C22CEA	1346 681134	ELENA RODIONOVA	{"email": "rodionovae10111967@postgrespro.ru", "phone": "+70635095066"}
0005433129200	5557C3	2462 701100	TATYANA MARTYNOVA	{"email": "tmartynova031970@postgrespro.ru", "phone": "+70955484264"}
0005433129201	513FF4	8766 532444	ALEKSANDRA KISELEVA	{"phone": "+70399086079"}
0005433129202	607ACD	7391 588437	KRISTINA NESTEROVA	{"phone": "+70409763411"}
0005433129203	BE45AC	6061 758086	ELENA OVCHINNIKOVA	{"email": "elena-ovchinnikova_111970@postgrespro.ru", "phone": "+70963952653"}
0005433129204	31D8AE	5780 367795	RUSLAN DENISOV	{"phone": "+70185255361"}
0005433129205	31D8AE	2128 305138	VIKTOR SOLOVEV	{"phone": "+70060199655"}
0005433129206	4C76C2	9337 263215	ELENA ERMAKOVA	{"email": "elenaermakova.021967@postgrespro.ru", "phone": "+70649418128"}
0005433129207	2D579A	7374 871181	IRINA FEDOROVA	{"email": "i.fedorova_25091976@postgrespro.ru", "phone": "+70352161902"}
0005433129208	2D579A	1129 464578	ALEKSANDR ISAEV	{"email": "aleksandrisaev_091978@postgrespro.ru", "phone": "+70536161621"}
0005433129209	CA17B5	0763 411930	TATYANA PAVLOVA	{"phone": "+70673421274"}
0005433129210	1918DF	4492 887480	LYUDMILA BOGDANOVA	{"phone": "+70382152234"}
0005433129211	BE8D89	5868 343516	ALEKSEY PETROV	{"email": "alekseypetrov-021962@postgrespro.ru", "phone": "+70672020605"}
0005433129212	8034A4	6848 597170	NINA ANTONOVA	{"email": "antonovanina.1973@postgrespro.ru", "phone": "+70452572162"}
0005433129213	29DE73	8632 755297	KAPITALINA SERGEEVA	{"email": "k.sergeeva_1984@postgrespro.ru", "phone": "+70166862211"}
0005433129214	D7EA88	6639 101137	VLADIMIR PAVLOV	{"email": "pavlov-v01051972@postgrespro.ru", "phone": "+70125913495"}
0005433129215	3E9A26	6036 301039	ANNA GORBUNOVA	{"email": "gorbunova-anna-1971@postgrespro.ru", "phone": "+70175521950"}
0005433129216	6D24DE	2624 050241	ALEKSANDR SMIRNOV	{"phone": "+70380418820"}
0005433129217	6D24DE	9648 619848	YURIY KOZLOV	{"phone": "+70069044381"}
0005433129218	F3FC30	8293 067965	DANIIL DENISOV	{"email": "denisov.d_101967@postgrespro.ru", "phone": "+70175619337"}
0005433129219	2051DD	4111 136665	DMITRIY MOISEEV	{"phone": "+70595209243"}
0005433129220	8311BB	3974 093949	ELENA DANILOVA	{"phone": "+70533669970"}
0005433129221	429C29	3435 672528	NIKITA SEMENOV	{"email": "n-semenov-1979@postgrespro.ru", "phone": "+70732061330"}
0005433129222	9D96F7	7790 008376	EKATERINA ZAKHAROVA	{"phone": "+70789208130"}
0005433129223	C2BDA5	0758 547807	OLEG MAKAROV	{"phone": "+70782885431"}
0005433129224	B48EE8	8675 766841	IVAN MOISEEV	{"email": "moiseev_ivan14051965@postgrespro.ru", "phone": "+70305470932"}
0005433129225	B48EE8	0701 289865	OLEG GORBUNOV	{"phone": "+70002124988"}
0005433129226	518DB9	4325 991849	VIKTOR MARTYNOV	{"email": "v.martynov-18111978@postgrespro.ru", "phone": "+70943447059"}
0005433129281	D41111	5997 701354	YURIY GUSEV	{"phone": "+70569431527"}
0005433129227	50E898	7548 536682	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-20041972@postgrespro.ru", "phone": "+70246538386"}
0005433129228	50E898	7590 723778	VASILIY SEMENOV	{"phone": "+70077090117"}
0005433129229	650A74	1653 274400	VALERIY KUZMIN	{"email": "valeriy.kuzmin.061979@postgrespro.ru", "phone": "+70768484916"}
0005433129230	C43E29	3831 626446	BORIS NOVIKOV	{"email": "novikov-b.051974@postgrespro.ru", "phone": "+70893586878"}
0005433129231	C43E29	7428 416972	ANDREY PETROV	{"email": "andrey-petrov.1983@postgrespro.ru", "phone": "+70253416491"}
0005433129232	DCB03D	6920 571270	SERGEY FILIPPOV	{"email": "filippov_s_1964@postgrespro.ru", "phone": "+70187603336"}
0005433129233	5FC3AF	6221 796214	TAISIYA MEDVEDEVA	{"phone": "+70053374506"}
0005433129234	5FA4E7	7019 711531	VALERIY MELNIKOV	{"email": "v-melnikov_1971@postgrespro.ru", "phone": "+70085787649"}
0005433129235	5FA4E7	4296 982498	SVETLANA FROLOVA	{"phone": "+70822072796"}
0005433129236	CEAB4A	2145 135445	OLEG ZAKHAROV	{"phone": "+70385704335"}
0005433129237	B19145	8270 181353	VALERIY KUZNECOV	{"email": "valeriy-kuznecov1966@postgrespro.ru", "phone": "+70974177175"}
0005433129238	06D126	3324 592337	MAKSIM MAKSIMOV	{"email": "maksim.maksimov16061969@postgrespro.ru", "phone": "+70960647609"}
0005433129239	7692A6	8597 082953	NADEZHDA MAKSIMOVA	{"phone": "+70254175946"}
0005433129240	7692A6	4836 482182	SERGEY ZHURAVLEV	{"email": "zhuravlevs.1960@postgrespro.ru", "phone": "+70185042373"}
0005433129241	FC2B00	2723 859621	POLINA EGOROVA	{"email": "egorova_polina.24021979@postgrespro.ru", "phone": "+70414770476"}
0005433129242	FC2B00	0029 540726	YAROSLAV SOROKIN	{"phone": "+70052538730"}
0005433129243	09A662	9473 887806	EVGENIY TIMOFEEV	{"phone": "+70525629519"}
0005433129244	00BE07	8843 737373	ALFIYA KOLESNIKOVA	{"email": "kolesnikova.a.05071969@postgrespro.ru", "phone": "+70927385151"}
0005433129245	00BE07	2234 543133	EVGENIYA KUDRYASHOVA	{"phone": "+70996610758"}
0005433129246	2B3EDD	2660 651168	NIKITA IVANOV	{"email": "ivanov-nikita12101968@postgrespro.ru", "phone": "+70469816726"}
0005433129247	B525FD	0541 503152	EKATERINA FILIPPOVA	{"email": "filippova.ekaterina_091973@postgrespro.ru", "phone": "+70246758331"}
0005433129248	B525FD	8571 338405	NINA VASILEVA	{"email": "n.vasileva-1973@postgrespro.ru", "phone": "+70079314173"}
0005433129249	3F7A5C	6148 523707	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana31081952@postgrespro.ru", "phone": "+70469561216"}
0005433129250	3F7A5C	1293 526914	DANIIL SAVELEV	{"phone": "+70661775800"}
0005433129251	3F7A5C	5228 379595	OLGA MALYSHEVA	{"email": "malysheva-olga-11121967@postgrespro.ru", "phone": "+70373322968"}
0005433129252	FCD56F	3005 003770	ANASTASIYA CHERNOVA	{"email": "a.chernova.21071997@postgrespro.ru", "phone": "+70204056048"}
0005433129253	FCD56F	5391 208106	YURIY GERASIMOV	{"email": "y_gerasimov-1961@postgrespro.ru", "phone": "+70688605376"}
0005433129254	EB7F8B	8532 177800	LYUDMILA ILINA	{"email": "lyudmila-ilina_051980@postgrespro.ru", "phone": "+70877566090"}
0005433129255	4E8728	6075 389744	DENIS NIKOLAEV	{"email": "d_nikolaev_11041971@postgrespro.ru", "phone": "+70859345044"}
0005433129256	04A8A6	7028 885778	SERGEY KUZNECOV	{"phone": "+70037424423"}
0005433129257	17B38A	5595 544251	ALEKSANDR KRASNOV	{"email": "krasnova27071978@postgrespro.ru", "phone": "+70905316045"}
0005433129258	BB7194	0976 889216	NIKOLAY MOROZOV	{"email": "nikolay-morozov.1975@postgrespro.ru", "phone": "+70302296147"}
0005433129259	BB7194	2259 193530	GALINA POPOVA	{"email": "popovagalina_111974@postgrespro.ru", "phone": "+70794195215"}
0005433129260	8E2A54	6561 582323	VLADIMIR VASILEV	{"email": "vasilev.vladimir-12061978@postgrespro.ru", "phone": "+70824884993"}
0005433129261	C0C6E4	3588 161014	SERGEY AFANASEV	{"email": "afanasev_s01111976@postgrespro.ru", "phone": "+70189985691"}
0005433129262	273004	9424 487427	SVETLANA KOROLEVA	{"phone": "+70783634498"}
0005433129263	D3F7C9	2416 599394	KONSTANTIN SCHERBAKOV	{"email": "konstantin.scherbakov09031982@postgrespro.ru", "phone": "+70603621501"}
0005433129264	EFE4A2	7950 688459	ANATOLIY BARANOV	{"email": "anatoliy_baranov-22071971@postgrespro.ru", "phone": "+70327014755"}
0005433129265	EFE4A2	8913 879456	PLATON ZAYCEV	{"phone": "+70636087832"}
0005433129266	A8A6D9	8079 837444	ANDREY ROMANOV	{"email": "andreyromanov-14061963@postgrespro.ru", "phone": "+70044359999"}
0005433129267	42488A	2856 999524	TATYANA ISAEVA	{"email": "isaeva_tatyana-1970@postgrespro.ru", "phone": "+70475738419"}
0005433129268	4E5077	7833 369841	TATYANA KUZNECOVA	{"email": "tkuznecova.101972@postgrespro.ru", "phone": "+70537602768"}
0005433129269	DA714B	8571 507369	PAVEL GORBUNOV	{"phone": "+70227504615"}
0005433129270	DA714B	4059 240832	ANTON SOROKIN	{"email": "anton.sorokin1970@postgrespro.ru", "phone": "+70145331323"}
0005433129271	16E92F	1763 933087	DARYA MAKAROVA	{"phone": "+70984437359"}
0005433129272	16E92F	0639 865113	LIDIYA STEPANOVA	{"phone": "+70223856025"}
0005433129273	578FD3	0236 809799	TATYANA RODIONOVA	{"email": "tatyanarodionova-101970@postgrespro.ru", "phone": "+70563262196"}
0005433129274	6DC4A4	2959 601429	GALINA LUKYANOVA	{"email": "lukyanova_galina-05011971@postgrespro.ru", "phone": "+70120697727"}
0005433129275	CAB514	8910 973408	ANATOLIY SERGEEV	{"phone": "+70949604090"}
0005433129276	CAB514	5675 844468	ELENA KOROLEVA	{"email": "koroleva_elena-1973@postgrespro.ru", "phone": "+70443322879"}
0005433129277	4B808D	5753 789470	ELIZAVETA IVANOVA	{"phone": "+70084886211"}
0005433129278	6B7F1A	2822 212810	DMITRIY TARASOV	{"email": "tarasov-d-101976@postgrespro.ru", "phone": "+70850971909"}
0005433129279	6B7F1A	1388 441462	ELENA IVANOVA	{"phone": "+70453262049"}
0005433129280	F736CE	1881 657191	ANNA GRISHINA	{"email": "a.grishina071974@postgrespro.ru", "phone": "+70943577305"}
0005433129282	12272E	1988 746629	ANTONINA ZAKHAROVA	{"phone": "+70551653391"}
0005433129283	12272E	6413 559875	OKSANA BOGDANOVA	{"email": "bogdanova.oksana-1978@postgrespro.ru", "phone": "+70058515250"}
0005433129284	4F6E3E	8542 768456	MATVEY ZAYCEV	{"phone": "+70360783187"}
0005433129285	1E6AD5	3920 619980	ELENA OVCHINNIKOVA	{"email": "ovchinnikova.elena.1959@postgrespro.ru", "phone": "+70280664704"}
0005433129286	1E6AD5	9586 810378	ILYA VLASOV	{"phone": "+70826561802"}
0005433129287	901D55	2727 560865	OLEG KUZNECOV	{"email": "o-kuznecov-23081975@postgrespro.ru", "phone": "+70090337720"}
0005433129288	901D55	3820 168867	NINA TARASOVA	{"email": "tarasovanina.1985@postgrespro.ru", "phone": "+70384682181"}
0005433129289	A21E45	3314 203213	SERGEY MAKSIMOV	{"email": "maksimov-sergey051971@postgrespro.ru", "phone": "+70939301832"}
0005433129290	85131C	4903 482143	ALEKSANDR FEDOTOV	{"email": "fedotov-aleksandr-101971@postgrespro.ru", "phone": "+70103309705"}
0005433129291	FB1F7B	2699 062570	VERA FOMINA	{"phone": "+70732190040"}
0005433129292	885F52	1339 850452	BORIS ROMANOV	{"email": "romanov-b_1972@postgrespro.ru", "phone": "+70259066995"}
0005433129293	885F52	7735 338750	EVGENIYA ZHUKOVA	{"phone": "+70904889556"}
0005433129294	885BE4	4545 390421	VALERIY VLASOV	{"phone": "+70411441965"}
0005433129295	9B8BF4	9671 883569	ILNAR KULIKOV	{"phone": "+70451968622"}
0005433129296	281EA4	5591 336698	MILANA DANILOVA	{"phone": "+70558063946"}
0005433129297	F99973	1423 691178	VALENTINA SMIRNOVA	{"email": "smirnovavalentina_051967@postgrespro.ru", "phone": "+70442158661"}
0005433129298	F99973	9421 002664	SVETLANA NOVIKOVA	{"email": "snovikova.1971@postgrespro.ru", "phone": "+70934646258"}
0005433129299	0B772A	3278 126003	ANNA POTAPOVA	{"email": "potapova.a-011984@postgrespro.ru", "phone": "+70989735032"}
0005433129300	0B772A	8817 523967	ANATOLIY ANTONOV	{"email": "antonov-a12081961@postgrespro.ru", "phone": "+70583366282"}
0005433129301	0B7EE7	4066 198486	RAFAEL DENISOV	{"phone": "+70870151646"}
0005433129302	0B7EE7	8068 675901	YURIY AFANASEV	{"phone": "+70338936423"}
0005433129303	5E908B	7160 744653	ANTONIDA POPOVA	{"phone": "+70834254920"}
0005433129304	2BEB19	6559 026303	VALENTINA ZAYCEVA	{"phone": "+70259039097"}
0005433129305	36B301	1842 930491	NINA TARASOVA	{"phone": "+70152657753"}
0005433129306	36B301	6677 223692	RUSLAN KUZNECOV	{"phone": "+70038318399"}
0005433129307	B84C5E	5583 209439	NADEZHDA BELOVA	{"phone": "+70240860601"}
0005433129308	B84C5E	1679 181569	MARIYA PETROVA	{"phone": "+70997597609"}
0005433129309	774B88	3285 366291	VALERIY SOKOLOV	{"phone": "+70694179795"}
0005433129310	774B88	7280 010618	DENIS STEPANOV	{"phone": "+70454962086"}
0005433129311	609889	7183 219018	ANNA KUZNECOVA	{"email": "kuznecova-anna_1982@postgrespro.ru", "phone": "+70055345400"}
0005433129312	609889	4607 342037	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov.14111980@postgrespro.ru", "phone": "+70428303482"}
0005433129313	0AD495	7013 666798	VALERIYA DAVYDOVA	{"email": "davydova-valeriya-061964@postgrespro.ru", "phone": "+70958357262"}
0005433129314	7E81FD	5909 190884	LYUDMILA RODIONOVA	{"email": "lyudmila.rodionova21071965@postgrespro.ru", "phone": "+70110205259"}
0005433129315	7E81FD	3021 664883	DARYA DMITRIEVA	{"phone": "+70961999684"}
0005433129316	CA5235	2239 268372	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev29101979@postgrespro.ru", "phone": "+70982857155"}
0005433129317	CA5235	9882 868347	TATYANA MIKHAYLOVA	{"email": "t-mikhaylova.1968@postgrespro.ru", "phone": "+70387766076"}
0005433129318	ACA9F6	5638 467418	ALEKSEY GUSEV	{"email": "aleksey.gusev101973@postgrespro.ru", "phone": "+70247115919"}
0005433129319	ACA9F6	9847 080570	ALEKSANDRA MOISEEVA	{"email": "aleksandra-moiseeva111971@postgrespro.ru", "phone": "+70096527809"}
0005433129320	ACA9F6	7639 437486	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov-121967@postgrespro.ru", "phone": "+70879397686"}
0005433129321	B6D80D	9494 579816	NATALYA ORLOVA	{"email": "orlovan071974@postgrespro.ru", "phone": "+70598968941"}
0005433129322	F22EBB	3094 972514	ANASTASIYA KISELEVA	{"email": "anastasiyakiseleva_051978@postgrespro.ru", "phone": "+70202739930"}
0005433129323	0D80F1	1171 096415	YAROSLAV AFANASEV	{"email": "y-afanasev_09051970@postgrespro.ru", "phone": "+70146624559"}
0005433129324	0D80F1	0865 743154	NATALYA NIKOLAEVA	{"phone": "+70430243667"}
0005433129325	6F8B3C	1042 159782	EVGENIY SOLOVEV	{"phone": "+70933827577"}
0005433129326	6F8B3C	9788 583762	IREK DAVYDOV	{"email": "irek.davydov-1972@postgrespro.ru", "phone": "+70198417622"}
0005433129327	6F8B3C	4445 808328	OLEG BARANOV	{"email": "obaranov-08011989@postgrespro.ru", "phone": "+70280519374"}
0005433129328	560ABE	2032 534866	LILIYA KOROLEVA	{"email": "liliya.koroleva_081975@postgrespro.ru", "phone": "+70553161519"}
0005433129329	560ABE	7543 952409	NINA BORISOVA	{"email": "borisova.nina.1975@postgrespro.ru", "phone": "+70507381168"}
0005433129330	91B691	2420 936858	YULIYA POPOVA	{"email": "y_popova_041971@postgrespro.ru", "phone": "+70739426305"}
0005433129331	91B691	5105 484205	TATYANA VOLKOVA	{"email": "volkova.tatyana17121970@postgrespro.ru", "phone": "+70724603320"}
0005433129332	91B691	8825 099831	ARTEM KUZNECOV	{"phone": "+70859718807"}
0005433129333	63F40C	2502 241571	VLADIMIR KUZNECOV	{"phone": "+70212963082"}
0005433129334	63F40C	8346 495052	PAVEL IVANOV	{"phone": "+70944076065"}
0005433129335	3F3977	6776 538873	NAILYA GAVRILOVA	{"email": "gavrilova_n30011973@postgrespro.ru", "phone": "+70299535852"}
0005433129336	3F3977	8172 866834	ALEKSANDR KUZMIN	{"email": "kuzmin-a-1976@postgrespro.ru", "phone": "+70273866985"}
0005433129337	470E49	6917 733771	DMITRIY ANDREEV	{"phone": "+70059067065"}
0005433129338	A1A684	8984 379697	ALEKSANDR POPOV	{"email": "aleksandr_popov1980@postgrespro.ru", "phone": "+70638732707"}
0005433129339	00D697	5103 373703	ELENA NIKOLAEVA	{"email": "elena.nikolaeva-1970@postgrespro.ru", "phone": "+70633417042"}
0005433129340	00D697	2356 727209	DARYA PAVLOVA	{"email": "pavlovadarya-1973@postgrespro.ru", "phone": "+70921491892"}
0005433129341	7873CB	7553 996903	ANTON TARASOV	{"phone": "+70046779953"}
0005433129342	6D2186	9752 087211	VALERIY SCHERBAKOV	{"email": "vscherbakov121969@postgrespro.ru", "phone": "+70932341368"}
0005433129343	6D2186	1446 180446	ANNA ANISIMOVA	{"phone": "+70509049283"}
0005433129344	6D2186	9763 881631	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.03011972@postgrespro.ru", "phone": "+70191550676"}
0005433129345	A2651E	7222 056005	DMITRIY ILIN	{"email": "dmitriy.ilin11071973@postgrespro.ru", "phone": "+70723756474"}
0005433129346	5E58E2	3856 792159	OLGA TARASOVA	{"email": "tarasovaolga_11051975@postgrespro.ru", "phone": "+70257959145"}
0005433129347	658D5F	6264 670151	OLGA CHERNOVA	{"phone": "+70775841173"}
0005433129348	7C9C77	2477 582587	ELENA KUZNECOVA	{"email": "elena_kuznecova.041975@postgrespro.ru", "phone": "+70477696202"}
0005433129349	49F159	3040 385478	ANZHELA FILIPPOVA	{"phone": "+70985731146"}
0005433129350	31D782	3008 795812	EKATERINA EGOROVA	{"phone": "+70426857031"}
0005433129351	31D782	6986 353326	EKATERINA PAVLOVA	{"email": "pavlova_e.15051964@postgrespro.ru", "phone": "+70962385161"}
0005433129352	8142A3	0576 628496	NINA PETROVA	{"phone": "+70603518152"}
0005433129353	E71BDC	9111 980444	KONSTANTIN YAKOVLEV	{"email": "k.yakovlev-03091971@postgrespro.ru", "phone": "+70125269249"}
0005433129354	E71BDC	8948 953316	ROSTISLAV ANTONOV	{"phone": "+70051870949"}
0005433129355	3D07CC	0808 326811	YANA MAKAROVA	{"email": "makarova-yana1981@postgrespro.ru", "phone": "+70476377018"}
0005433129356	3D07CC	3355 658108	IRINA BELYAEVA	{"email": "belyaeva_i.1970@postgrespro.ru", "phone": "+70120676573"}
0005433129357	7520F9	6316 651089	YURIY IVANOV	{"phone": "+70579668883"}
0005433129358	0CACE6	1385 284149	ALEKSEY ROMANOV	{"phone": "+70175373050"}
0005433129359	F52FD2	7739 609009	LYUDMILA ARKHIPOVA	{"email": "arkhipova.lyudmila12011975@postgrespro.ru", "phone": "+70343185444"}
0005433129360	F52FD2	4901 166326	EKATERINA ABRAMOVA	{"phone": "+70429039989"}
0005433129361	F52FD2	0302 625522	RAISA NOVIKOVA	{"phone": "+70364311854"}
0005433129362	AA7FA0	9979 100542	DARYA LUKYANOVA	{"email": "daryalukyanova.19041991@postgrespro.ru", "phone": "+70414108893"}
0005433129363	AA7FA0	5577 619717	YURIY SAVELEV	{"email": "savelevyuriy.1970@postgrespro.ru", "phone": "+70180941779"}
0005433129364	AA7FA0	3862 354070	YULIYA IVANOVA	{"email": "yuliya.ivanova.1978@postgrespro.ru", "phone": "+70358084814"}
0005433129365	C41918	0635 704296	NADEZHDA MAKSIMOVA	{"email": "maksimova.n.031965@postgrespro.ru", "phone": "+70570009153"}
0005433129366	906D8C	5351 115982	PRASKOVYA NESTEROVA	{"phone": "+70204224733"}
0005433129367	850CAD	9827 738637	MARIYA FROLOVA	{"phone": "+70258511981"}
0005433129368	60CBF9	9451 813974	EKATERINA KONDRATEVA	{"phone": "+70471700280"}
0005433129369	BD5940	6742 681912	VLADIMIR NOVIKOV	{"email": "novikov.v.1974@postgrespro.ru", "phone": "+70333227797"}
0005433129370	CF3148	7604 251262	MIKHAIL ABRAMOV	{"email": "mabramov.1974@postgrespro.ru", "phone": "+70227389039"}
0005433129371	DE8583	8669 752008	NADEZHDA MOROZOVA	{"email": "morozovan.031968@postgrespro.ru", "phone": "+70831257428"}
0005433129372	5E09AD	5332 509188	VALENTINA SOKOLOVA	{"email": "sokolova_v.1973@postgrespro.ru", "phone": "+70319740066"}
0005433129373	5E09AD	4692 648875	TATYANA KUZMINA	{"phone": "+70228182176"}
0005433129374	5E09AD	9943 563333	LARISA SOLOVEVA	{"phone": "+70962871291"}
0005433129375	2EDA07	9059 926655	TATYANA FOMINA	{"phone": "+70768882323"}
0005433129376	969CB6	9141 689966	NIKOLAY ORLOV	{"phone": "+70229006090"}
0005433129377	20C7BB	5951 004509	ANDREY KRASNOV	{"email": "a-krasnov1970@postgrespro.ru", "phone": "+70015392609"}
0005433129378	150C1C	1800 599546	POLINA KUZNECOVA	{"email": "kuznecova-polina16101964@postgrespro.ru", "phone": "+70692390506"}
0005433129379	150C1C	0334 354928	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov.25021979@postgrespro.ru", "phone": "+70059080247"}
0005433129380	79E2A1	3435 960515	DANIIL NIKOLAEV	{"email": "daniilnikolaev-1963@postgrespro.ru", "phone": "+70802865631"}
0005433129381	79E2A1	1869 365841	LARISA MEDVEDEVA	{"email": "medvedeval-1972@postgrespro.ru", "phone": "+70332759262"}
0005433129382	272A82	2741 094895	KARINA IVANOVA	{"email": "ivanova.k.041980@postgrespro.ru", "phone": "+70758582776"}
0005433129383	D65690	4105 810300	IRINA KUDRYASHOVA	{"email": "kudryashova_irina-1970@postgrespro.ru", "phone": "+70629901409"}
0005433129384	D65690	4908 729581	ALEKSANDRA FEDOROVA	{"phone": "+70450171280"}
0005433129385	688DBD	6095 044574	ALEKSEY MOROZOV	{"email": "aleksey-morozov091972@postgrespro.ru", "phone": "+70708621804"}
0005433129386	D2A49A	8765 385686	ZINAIDA ORLOVA	{"email": "z_orlova23121984@postgrespro.ru", "phone": "+70914210006"}
0005433129387	6DF6D0	8744 040686	VIKTOR NAUMOV	{"email": "naumovv-24121961@postgrespro.ru", "phone": "+70432156893"}
0005433129388	890928	3539 306729	VALENTINA POPOVA	{"email": "valentina_popova.26071972@postgrespro.ru", "phone": "+70436552812"}
0005433129389	9ED176	6556 552123	KRISTINA ALEKSEEVA	{"phone": "+70290122934"}
0005433129390	9ED176	6241 014488	YULIYA MAKAROVA	{"phone": "+70085151799"}
0005433129391	590936	1537 883801	LIDIYA TIKHONOVA	{"phone": "+70062024823"}
0005433129392	590936	1593 109785	VLADIMIR MEDVEDEV	{"email": "medvedevv.1984@postgrespro.ru", "phone": "+70450824783"}
0005433129393	60D7F3	3416 642796	GALINA IVANOVA	{"email": "ivanova_g.061966@postgrespro.ru", "phone": "+70399051599"}
0005433129394	60D7F3	4921 910356	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov1971@postgrespro.ru", "phone": "+70753765182"}
0005433129395	A23E02	7741 627378	ANASTASIYA VASILEVA	{"phone": "+70288025881"}
0005433129396	65E162	4334 311412	VALENTINA TARASOVA	{"email": "valentinatarasova-1970@postgrespro.ru", "phone": "+70903545787"}
0005433129397	439830	0581 071494	SVETLANA MEDVEDEVA	{"email": "smedvedeva_29111970@postgrespro.ru", "phone": "+70445139560"}
0005433129398	CDC33F	3422 536182	TATYANA AFANASEVA	{"email": "afanaseva.t-01021975@postgrespro.ru", "phone": "+70237491143"}
0005433129399	E1C6DD	3545 353100	EVGENIY GORBUNOV	{"email": "e-gorbunov.1975@postgrespro.ru", "phone": "+70396086030"}
0005433129400	494F6F	8654 224129	ANDREY BONDARENKO	{"phone": "+70888184623"}
0005433129401	494F6F	5781 271872	ANASTASIYA MOROZOVA	{"email": "anastasiya.morozova-07061969@postgrespro.ru", "phone": "+70396624675"}
0005433129402	C4E02B	7273 377698	GALINA SIDOROVA	{"phone": "+70827884781"}
0005433129403	7A99E2	5424 763748	SVETLANA DAVYDOVA	{"phone": "+70542540230"}
0005433129404	D3FA6E	0933 346983	OLGA GORBUNOVA	{"email": "gorbunova.olga011988@postgrespro.ru", "phone": "+70527210308"}
0005433129405	FB05C3	3559 047646	ELVIRA NIKOLAEVA	{"phone": "+70795425319"}
0005433129406	FB05C3	7965 882833	LARISA BORISOVA	{"email": "borisovalarisa-1975@postgrespro.ru", "phone": "+70539474398"}
0005433129407	ECB5E6	4731 329969	DANILA SMIRNOV	{"phone": "+70789021227"}
0005433129408	3D5529	0079 356422	ANTONINA VOLKOVA	{"email": "volkova_antonina_1965@postgrespro.ru", "phone": "+70652289642"}
0005433129409	3D5529	1002 309706	EKATERINA KOMAROVA	{"phone": "+70632275214"}
0005433129410	8AA2D0	2914 751285	VALENTINA FEDOROVA	{"email": "fedorova.v-051976@postgrespro.ru", "phone": "+70525413740"}
0005433129411	8AA2D0	9306 101177	RASHID YAKOVLEV	{"phone": "+70080599527"}
0005433129412	E09B85	4643 086416	VLADISLAV GERASIMOV	{"email": "vladislav-gerasimov-16101969@postgrespro.ru", "phone": "+70785180319"}
0005433129413	7BA6FE	7049 569028	SERGEY VASILEV	{"email": "sergeyvasilev1969@postgrespro.ru", "phone": "+70032175284"}
0005433131626	3B61F6	2770 444611	VALENTIN BELOV	{"phone": "+70507396548"}
0005433131627	B101DC	8892 811112	ELENA MASLOVA	{"phone": "+70472905855"}
0005433131628	353F18	4821 353261	ANASTASIYA MIRONOVA	{"phone": "+70256390255"}
0005433131629	E8F046	1071 733128	TAISIYA STEPANOVA	{"email": "taisiya-stepanova-1965@postgrespro.ru", "phone": "+70103644730"}
0005433131630	48FE51	9155 711130	MARINA DMITRIEVA	{"email": "dmitrieva-m.08071960@postgrespro.ru", "phone": "+70569301665"}
0005433131631	AEA8A2	9659 241849	MARIYA SOKOLOVA	{"email": "mariya.sokolova081970@postgrespro.ru", "phone": "+70136883142"}
0005433131632	4D3D7D	7378 830187	ALFIYA SEMENOVA	{"phone": "+70916132068"}
0005433131633	4D3D7D	6352 078243	PRASKOVYA FILATOVA	{"phone": "+70602571780"}
0005433131634	F88D39	0984 326306	NIKITA BELOV	{"phone": "+70952984387"}
0005433131635	073717	7924 451368	NIKOLAY MATVEEV	{"email": "nikolay_matveev021970@postgrespro.ru", "phone": "+70715697858"}
0005433131636	4D349A	3026 184350	ANATOLIY BARANOV	{"phone": "+70656278207"}
0005433131637	BEC463	5943 470651	OLGA DMITRIEVA	{"phone": "+70560580487"}
0005433131638	BEC463	1541 317590	LYUDMILA FEDOROVA	{"phone": "+70686827297"}
0005433131639	F13263	0923 491866	ANNA DMITRIEVA	{"phone": "+70181740081"}
0005433131640	2A0A61	1632 551643	KARINA ZOTOVA	{"phone": "+70956165646"}
0005433131641	2A0A61	1599 661959	ALEKSANDR VASILEV	{"email": "vasileva-1976@postgrespro.ru", "phone": "+70570610786"}
0005433131642	2A0A61	7649 797030	OLGA KUZMINA	{"email": "kuzminaolga.06021962@postgrespro.ru", "phone": "+70693169281"}
0005433131643	8B49D0	7080 998371	DAMIR STEPANOV	{"phone": "+70836161019"}
0005433131644	22865F	7201 432886	NATALYA POPOVA	{"phone": "+70992314646"}
0005433131645	EC26E4	8820 470780	RAISA POPOVA	{"email": "raisa_popova-051975@postgrespro.ru", "phone": "+70645796958"}
0005433131646	ABD1C4	3887 713030	ANDREY FEDOROV	{"email": "afedorov.1980@postgrespro.ru", "phone": "+70785978035"}
0005433131647	23F4BA	1601 692771	ALEVTINA ROMANOVA	{"email": "romanovaalevtina031976@postgrespro.ru", "phone": "+70649495655"}
0005433131648	23F4BA	8823 069873	EKATERINA MEDVEDEVA	{"email": "medvedeva-ekaterina-021974@postgrespro.ru", "phone": "+70682708244"}
0005433131649	5F3531	6542 258034	LYUBOV BORISOVA	{"phone": "+70099925533"}
0005433131650	5F3531	2124 143177	SVETLANA DAVYDOVA	{"email": "davydovasvetlana-071964@postgrespro.ru", "phone": "+70086415057"}
0005433131651	D59660	9784 356648	VLADIMIR TIKHONOV	{"phone": "+70940842180"}
0005433131652	D59660	7526 276802	MARINA KUZMINA	{"phone": "+70116599243"}
0005433131653	343733	3274 535814	NINA ANTONOVA	{"email": "antonova_n_1967@postgrespro.ru", "phone": "+70139483470"}
0005433131654	F7D9EA	5652 661834	VIKTOR ZHUKOV	{"email": "viktor.zhukov_1972@postgrespro.ru", "phone": "+70231804462"}
0005433131655	2FA876	6688 239443	LYUDMILA KUZMINA	{"phone": "+70916859682"}
0005433131656	2FA876	1903 131983	OLGA ROMANOVA	{"email": "oromanova-121976@postgrespro.ru", "phone": "+70026661424"}
0005433131657	E3EF31	1596 995299	YULIYA ALEKSEEVA	{"email": "yuliya_alekseeva-18121974@postgrespro.ru", "phone": "+70277947199"}
0005433131658	EB2ED3	7365 718499	NIKOLAY KARPOV	{"phone": "+70526955187"}
0005433131659	EB2ED3	0445 505397	NIKITA IVANOV	{"email": "ivanovn-31081975@postgrespro.ru", "phone": "+70495414216"}
0005433131660	A3E96C	9356 935486	YULIYA FROLOVA	{"email": "y.frolova1971@postgrespro.ru", "phone": "+70107821109"}
0005433131661	A3E96C	1280 293961	EKATERINA ZAYCEVA	{"email": "ezayceva.1971@postgrespro.ru", "phone": "+70240040974"}
0005433131662	A3E96C	3630 084013	EKATERINA ZAYCEVA	{"phone": "+70146052113"}
0005433131663	CDA1A3	2148 457830	TATYANA EGOROVA	{"email": "egorova.t051970@postgrespro.ru", "phone": "+70189508691"}
0005433131664	146D62	9683 132729	DENIS SEMENOV	{"phone": "+70713234611"}
0005433131665	146D62	4551 978427	ELENA KOROLEVA	{"phone": "+70977317811"}
0005433131666	AA3B53	3299 568357	VIKTOR FEDOROV	{"email": "fedorovviktor1964@postgrespro.ru", "phone": "+70103042615"}
0005433131667	322482	4056 380502	TATYANA FILATOVA	{"phone": "+70944987043"}
0005433131668	CD13DA	4978 500064	LARISA ABRAMOVA	{"email": "abramoval_1978@postgrespro.ru", "phone": "+70845137540"}
0005433131669	CD13DA	7038 178647	ANNA SMIRNOVA	{"email": "smirnova-a-31011974@postgrespro.ru", "phone": "+70056288775"}
0005433131670	EB2FC8	1024 111162	NIKOLAY NIKITIN	{"phone": "+70091420286"}
0005433131671	B1756C	7598 556959	ALEKSANDR IVANOV	{"email": "aleksandrivanov-08011965@postgrespro.ru", "phone": "+70496038785"}
0005433131672	45F000	7906 309899	TAMARA KALININA	{"phone": "+70725862663"}
0005433131673	45F000	9476 348074	EKATERINA YAKOVLEVA	{"email": "yakovleva.e.041977@postgrespro.ru", "phone": "+70632071039"}
0005433131674	B60217	1508 881477	NATALYA VASILEVA	{"email": "n.vasileva_1974@postgrespro.ru", "phone": "+70841744455"}
0005433131675	B60217	3230 864020	KIRILL IVANOV	{"email": "k_ivanov051975@postgrespro.ru", "phone": "+70760812764"}
0005433131676	B60217	0730 454764	NATALYA MARTYNOVA	{"email": "n-martynova.061977@postgrespro.ru", "phone": "+70559617608"}
0005433131677	AE0437	0025 516345	TATYANA LUKYANOVA	{"phone": "+70503042592"}
0005433131678	A30542	4880 988997	TATYANA LUKYANOVA	{"email": "tlukyanova-081979@postgrespro.ru", "phone": "+70618804737"}
0005433131679	A30542	6790 368812	RODION KRASNOV	{"email": "krasnov-r_111976@postgrespro.ru", "phone": "+70940246632"}
0005433131680	E72DFB	4170 903960	VALENTINA GORBUNOVA	{"email": "valentina_gorbunova19111975@postgrespro.ru", "phone": "+70212436680"}
0005433131681	ED8C9B	9786 803397	ALEKSANDR KOROLEV	{"phone": "+70939580914"}
0005433131682	ED8C9B	5569 292533	EVGENIYA SEMENOVA	{"email": "e_semenova.011976@postgrespro.ru", "phone": "+70865176815"}
0005433131683	ED8C9B	0558 800043	BORIS ROMANOV	{"phone": "+70230280071"}
0005433131684	3B35EA	1798 527936	NIKITA IVANOV	{"phone": "+70722550460"}
0005433131685	3B35EA	6094 788641	NADEZHDA MAKAROVA	{"email": "nadezhda_makarova-061964@postgrespro.ru", "phone": "+70120619509"}
0005433131686	3B35EA	5067 045790	VLADISLAV MAKSIMOV	{"phone": "+70057142000"}
0005433131687	6F4851	3509 939130	SERGEY KUZNECOV	{"phone": "+70052933891"}
0005433131688	6F4851	1412 255108	IRINA SIDOROVA	{"email": "sidorovai.07081968@postgrespro.ru", "phone": "+70610198955"}
0005433131689	8A177A	9593 999228	ANDREY ANDREEV	{"phone": "+70033325008"}
0005433131690	8A177A	5405 125943	VITALIY IVANOV	{"email": "vitaliyivanov_1969@postgrespro.ru", "phone": "+70926462487"}
0005433131691	128687	3443 156572	VIKTOR BORISOV	{"phone": "+70565614320"}
0005433131692	321BBE	1531 231121	IRINA POPOVA	{"email": "irinapopova1970@postgrespro.ru", "phone": "+70231856806"}
0005433131693	AAE344	6755 786514	TATYANA NESTEROVA	{"phone": "+70136558094"}
0005433131694	C81057	2461 752617	YULIYA MOISEEVA	{"email": "yuliya.moiseeva03021972@postgrespro.ru", "phone": "+70568337202"}
0005433131695	C81057	6744 974793	ALBERT GRIGOREV	{"email": "agrigorev.18051966@postgrespro.ru", "phone": "+70860113291"}
0005433131696	B8EDFB	5524 480100	LARISA SEMENOVA	{"phone": "+70964772098"}
0005433131697	16323D	0234 311107	VLADIMIR IVANOV	{"email": "ivanovvladimir_061972@postgrespro.ru", "phone": "+70087616620"}
0005433131698	853FD7	7300 265367	MARIYA ANTONOVA	{"phone": "+70136197564"}
0005433131699	853FD7	8913 933421	DIANA KUZMINA	{"phone": "+70976264733"}
0005433131700	D4C29D	3108 382938	ELENA AFANASEVA	{"email": "afanaseva_elena-01051966@postgrespro.ru", "phone": "+70789332690"}
0005433131701	C191EA	4247 858120	PETR TIKHONOV	{"email": "tikhonov_petr-051971@postgrespro.ru", "phone": "+70144852020"}
0005433131702	C191EA	7645 400190	ALEKSEY TARASOV	{"email": "tarasov.a-18081969@postgrespro.ru", "phone": "+70450401339"}
0005433131703	B3701B	4889 648566	DENIS KUDRYASHOV	{"email": "d.kudryashov-06011969@postgrespro.ru", "phone": "+70224060423"}
0005433131704	4A5EA9	7443 004046	VIKTOR PETROV	{"phone": "+70016975608"}
0005433131705	8F8F6B	1781 418705	VADIM KUZNECOV	{"email": "kuznecov_v081974@postgrespro.ru", "phone": "+70011350571"}
0005433131706	58724D	5415 113542	GALINA KAZAKOVA	{"phone": "+70491122150"}
0005433131707	EF9975	2082 471131	KSENIYA KUDRYASHOVA	{"email": "kseniyakudryashova-20111973@postgrespro.ru", "phone": "+70714612545"}
0005433131708	76AD30	3649 616560	ALEKSANDR KUZMIN	{"phone": "+70288256530"}
0005433131709	A1209C	3573 520798	IGOR AFANASEV	{"phone": "+70207542089"}
0005433131710	A1209C	1955 712167	SVETLANA KUZMINA	{"phone": "+70988635953"}
0005433131711	B6827F	8105 430901	SVETLANA IVANOVA	{"phone": "+70069652611"}
0005433131712	F9C480	2875 277755	SERGEY ZAYCEV	{"email": "zaycev-s_31071974@postgrespro.ru", "phone": "+70920639741"}
0005433131713	F9C480	3709 911367	VALENTINA MATVEEVA	{"email": "valentina-matveeva.031973@postgrespro.ru", "phone": "+70538306268"}
0005433131714	055F53	3717 440294	VLADIMIR KRASNOV	{"email": "krasnov-vladimir1977@postgrespro.ru", "phone": "+70156758060"}
0005433131715	99A6F7	9815 396228	ELIZAVETA MALYSHEVA	{"email": "emalysheva.11081970@postgrespro.ru", "phone": "+70885421588"}
0005433131716	86666D	0454 928471	MARIYA AFANASEVA	{"phone": "+70142382139"}
0005433131717	013BE6	1812 084621	NATALYA GERASIMOVA	{"email": "natalya.gerasimova.21011980@postgrespro.ru", "phone": "+70548419490"}
0005433131718	013BE6	4494 565780	KIRILL ALEKSANDROV	{"email": "k_aleksandrov_1975@postgrespro.ru", "phone": "+70372751333"}
0005433131719	013BE6	6711 368566	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov_091988@postgrespro.ru", "phone": "+70185139108"}
0005433131720	0AD855	8372 319700	ROMAN SERGEEV	{"phone": "+70875611563"}
0005433131721	0AD855	9642 368416	VLADIMIR POPOV	{"email": "popovvladimir-19121967@postgrespro.ru", "phone": "+70483850844"}
0005433131722	0AD855	6623 057982	DANIL VOROBEV	{"email": "vorobev.danil_121974@postgrespro.ru", "phone": "+70266781195"}
0005433131723	7B4096	9236 209680	YULIYA BELOVA	{"phone": "+70248710776"}
0005433131724	7B4096	4268 589872	PETR MELNIKOV	{"email": "melnikovpetr.021980@postgrespro.ru", "phone": "+70716196174"}
0005433134059	0BFAB8	3968 387827	ARTEM GORBUNOV	{"phone": "+70035353640"}
0005433131725	8D4193	3652 431851	DMITRIY NIKITIN	{"email": "dnikitin_111972@postgrespro.ru", "phone": "+70091877487"}
0005433131726	8D4193	8779 784597	YURIY KONOVALOV	{"email": "ykonovalov_041981@postgrespro.ru", "phone": "+70352040230"}
0005433131727	60E043	9307 299434	ANASTASIYA MOROZOVA	{"phone": "+70935091700"}
0005433131728	60E043	1383 395228	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr.021965@postgrespro.ru", "phone": "+70506484441"}
0005433131729	0B403D	8244 080723	VLADIMIR VOLKOV	{"phone": "+70753543542"}
0005433131730	544AC9	5176 838610	EKATERINA GAVRILOVA	{"phone": "+70220075614"}
0005433131731	1E114C	4919 085083	ALEKSEY ANDREEV	{"phone": "+70740832009"}
0005433131732	1E114C	3542 721949	FANIYA IVANOVA	{"phone": "+70897726933"}
0005433131733	E4D207	4627 761845	ROMAN FEDOROV	{"phone": "+70797003650"}
0005433131734	C2866F	2102 376151	EVGENIY ZHURAVLEV	{"email": "zhuravlev-evgeniy1967@postgrespro.ru", "phone": "+70010375269"}
0005433131735	D8DB65	3086 252369	SVETLANA PETROVA	{"phone": "+70465762332"}
0005433131736	D8DB65	7475 311503	ALEKSEY GERASIMOV	{"email": "gerasimova_1976@postgrespro.ru", "phone": "+70186432310"}
0005433131737	682D8A	4962 059262	ANZHELIKA KOZLOVA	{"phone": "+70152227507"}
0005433131738	682D8A	6961 796741	SERGEY MAKSIMOV	{"phone": "+70982907995"}
0005433131739	44A895	9353 216811	NATALYA FOMINA	{"phone": "+70287642497"}
0005433131740	27118E	0204 820348	ANDREY VOLKOV	{"email": "a_volkov-04051978@postgrespro.ru", "phone": "+70834052788"}
0005433131741	27118E	9740 475363	NIKOLAY KUZMIN	{"phone": "+70719821074"}
0005433131742	9F9CD6	2712 978123	DANIIL MOROZOV	{"email": "daniil_morozov-011978@postgrespro.ru", "phone": "+70259984878"}
0005433131743	A31484	0449 281341	OLGA TIKHONOVA	{"phone": "+70597638164"}
0005433131744	71BC22	6421 470261	ALEKSANDR NAZAROV	{"email": "a_nazarov15061974@postgrespro.ru", "phone": "+70568446051"}
0005433131745	024DE0	7273 750286	IVAN BORISOV	{"phone": "+70427006334"}
0005433131746	024DE0	8772 758712	KSENIYA NOVIKOVA	{"phone": "+70802036618"}
0005433131747	AC1579	5214 891481	ALEKSANDR EGOROV	{"email": "egorov.a-29081972@postgrespro.ru", "phone": "+70943051540"}
0005433131748	AC1579	1022 943680	SVETLANA PETROVA	{"phone": "+70065154850"}
0005433131749	1D9DEC	5378 911196	ARTEM GRIGOREV	{"phone": "+70381861083"}
0005433131750	656850	4265 656270	NIKOLAY KARPOV	{"phone": "+70855200440"}
0005433131751	73F151	2524 833350	ALEKSANDR ANDREEV	{"phone": "+70730416744"}
0005433131752	4A9602	5131 022939	LILIYA AFANASEVA	{"phone": "+70485131844"}
0005433131753	5857EE	6537 062909	OLEG VLASOV	{"email": "o_vlasov_03091975@postgrespro.ru", "phone": "+70631921775"}
0005433131754	44E336	2447 848189	SERGEY KOROLEV	{"phone": "+70593942153"}
0005433131755	44E336	8329 018920	INNA KOROLEVA	{"email": "koroleva-inna-19101975@postgrespro.ru", "phone": "+70456756906"}
0005433131756	44E336	4172 469673	SERGEY NOVIKOV	{"phone": "+70304908593"}
0005433131757	26C5DD	8151 046935	ALEKSANDRA KOROLEVA	{"phone": "+70376243419"}
0005433131758	2BAE4A	3262 428745	EKATERINA ZHUKOVA	{"phone": "+70042076638"}
0005433131759	2BAE4A	1881 977339	NATALYA KUZMINA	{"phone": "+70892275919"}
0005433131760	2BAE4A	6070 261867	VALENTINA MELNIKOVA	{"email": "v_melnikova.30061964@postgrespro.ru", "phone": "+70805433577"}
0005433131761	49C594	3369 287077	MARIYA NAZAROVA	{"email": "nazarova-m02051978@postgrespro.ru", "phone": "+70569938414"}
0005433131762	B8AD40	2433 734040	ALEKSANDR MOROZOV	{"phone": "+70127588694"}
0005433131763	47A2F0	6091 595333	YURIY TIKHONOV	{"phone": "+70435622588"}
0005433131764	F94B37	6408 304113	GALIYA NIKIFOROVA	{"email": "nikiforovagaliya-041982@postgrespro.ru", "phone": "+70928965528"}
0005433131765	F94B37	6644 478704	ANATOLIY MATVEEV	{"phone": "+70131110101"}
0005433131766	F6A4A8	6963 757810	YULIYA KARPOVA	{"email": "karpovayuliya.121974@postgrespro.ru", "phone": "+70305329842"}
0005433131767	F6A4A8	8556 588796	VLADIMIR MAKSIMOV	{"email": "maksimov.v.021972@postgrespro.ru", "phone": "+70851434298"}
0005433131768	BC39EC	8393 210820	LYUBOV MATVEEVA	{"email": "l-matveeva.1961@postgrespro.ru", "phone": "+70516562075"}
0005433131769	BC39EC	9090 461311	TATYANA ANDREEVA	{"phone": "+70608022045"}
0005433131770	9A4DB5	1139 609055	VALERIYA MARTYNOVA	{"phone": "+70313224236"}
0005433131771	14DE2D	2787 840110	ALEKSANDRA ABRAMOVA	{"email": "abramovaa-101977@postgrespro.ru", "phone": "+70746667333"}
0005433131772	1E2211	4642 180102	GENNADIY IVANOV	{"email": "g.ivanov1979@postgrespro.ru", "phone": "+70066755701"}
0005433131773	108A46	1155 844014	OLESYA ILINA	{"email": "ilina-olesya-071980@postgrespro.ru", "phone": "+70568558032"}
0005433131774	108A46	4009 289325	ANTON VOLKOV	{"email": "anton_volkov.07051969@postgrespro.ru", "phone": "+70822325763"}
0005433131775	108A46	0616 466132	DENIS GERASIMOV	{"phone": "+70358145457"}
0005433131776	6E7BD5	8237 299940	YULIYA GAVRILOVA	{"phone": "+70448737609"}
0005433131777	025CCE	3584 597757	TATYANA KAZAKOVA	{"email": "tkazakova_031971@postgrespro.ru", "phone": "+70681425883"}
0005433131778	121DEE	9093 438753	SERGEY EGOROV	{"phone": "+70335663272"}
0005433131779	35D3D0	5491 723482	OLGA SOKOLOVA	{"phone": "+70301355230"}
0005433131780	35D3D0	1260 901618	KRISTINA TIMOFEEVA	{"phone": "+70036818439"}
0005433131781	870625	3589 750097	OKSANA POPOVA	{"email": "popova-oksana.061967@postgrespro.ru", "phone": "+70801486946"}
0005433131782	029DB8	5417 809333	ANDREY BELOV	{"email": "a_belov_1966@postgrespro.ru", "phone": "+70382647214"}
0005433131783	1053E1	6585 607792	VALENTINA TARASOVA	{"phone": "+70245576252"}
0005433131784	5A04EB	2656 319808	FANIYA VASILEVA	{"email": "vasileva_f-16071978@postgrespro.ru", "phone": "+70054744023"}
0005433131785	5573C7	9707 852997	GRIGORIY KULIKOV	{"email": "grigoriykulikov01061975@postgrespro.ru", "phone": "+70246400394"}
0005433131786	141A72	3516 044779	YURIY GUSEV	{"email": "gusev.y_01031966@postgrespro.ru", "phone": "+70314871235"}
0005433131787	B2F820	0342 856228	OLGA NESTEROVA	{"email": "nesterovao.1976@postgrespro.ru", "phone": "+70908152134"}
0005433131788	0046CE	6748 456150	VITALIY FOMIN	{"email": "v_fomin_051973@postgrespro.ru", "phone": "+70105458773"}
0005433131789	90F8FA	7946 819570	ALEKSANDR IVANOV	{"email": "a-ivanov.031982@postgrespro.ru", "phone": "+70788108849"}
0005433131790	D6924A	8950 857165	ALEKSANDR TIKHONOV	{"email": "tikhonov-a1990@postgrespro.ru", "phone": "+70180976461"}
0005433131791	AC7242	2809 242077	LYUDMILA OSIPOVA	{"phone": "+70443395088"}
0005433131792	E73564	4555 224297	ALEKSANDR BELOV	{"phone": "+70879893126"}
0005433131793	730EB3	5386 091800	MARGARITA SOKOLOVA	{"email": "sokolova.m.03101969@postgrespro.ru", "phone": "+70753891232"}
0005433131794	6CB310	1022 857826	YULIYA SEMENOVA	{"email": "semenovayuliya-1965@postgrespro.ru", "phone": "+70101088062"}
0005433131795	07AA89	0696 220205	VERA NIKITINA	{"phone": "+70680521633"}
0005433131796	07AA89	7600 960068	VYACHESLAV POPOV	{"phone": "+70715352496"}
0005433131797	BC1FDA	6563 232359	IRINA POPOVA	{"phone": "+70132323403"}
0005433131798	10A924	8422 576280	ALEKSEY EGOROV	{"email": "a-egorov13011972@postgrespro.ru", "phone": "+70503717947"}
0005433131799	04780D	4263 786069	ANDREY MIRONOV	{"email": "mironov.andrey-1979@postgrespro.ru", "phone": "+70751467520"}
0005433131800	B8E6B2	6816 287113	VADIM KRASNOV	{"phone": "+70446320892"}
0005433131801	1CB005	3639 303765	EVGENIYA KUZNECOVA	{"phone": "+70480133999"}
0005433131802	0AC667	7654 602683	PETR VASILEV	{"email": "p.vasilev-1971@postgrespro.ru", "phone": "+70555008255"}
0005433131803	30F09F	5835 061508	RUSLAN KRASNOV	{"email": "krasnovr.091986@postgrespro.ru", "phone": "+70863916325"}
0005433131804	ADCCD8	2875 505364	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr.1971@postgrespro.ru", "phone": "+70734893297"}
0005433131805	ADCCD8	6106 450549	MARINA SIDOROVA	{"phone": "+70869239710"}
0005433131806	C2CCB3	1730 803749	TATYANA SOLOVEVA	{"phone": "+70018995474"}
0005433131807	C2CCB3	8064 580691	VALENTINA MAKAROVA	{"email": "makarovav.121974@postgrespro.ru", "phone": "+70577484222"}
0005433131808	F3F6BD	0038 727510	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov-011977@postgrespro.ru", "phone": "+70347641097"}
0005433131809	50D400	5816 331701	MIKHAIL ZAKHAROV	{"email": "zakharov.m.1979@postgrespro.ru", "phone": "+70520210295"}
0005433131810	50D400	1781 599808	RAVIL ANTONOV	{"email": "ravilantonov-1972@postgrespro.ru", "phone": "+70593851701"}
0005433131811	50D400	9020 977570	ELIZAVETA CHERNOVA	{"phone": "+70377534486"}
0005433131812	50D400	3932 124898	EVGENIY KAZAKOV	{"phone": "+70711713879"}
0005433131813	B94058	8495 470202	ELENA RODIONOVA	{"email": "elenarodionova1967@postgrespro.ru", "phone": "+70217483124"}
0005433131814	B94058	6553 746997	NIKOLAY MELNIKOV	{"phone": "+70830688776"}
0005433131815	4E35E9	0720 130500	EVGENIY MATVEEV	{"email": "e_matveev-061971@postgrespro.ru", "phone": "+70889063410"}
0005433131816	EE8AFD	6141 801564	VALERIY KUZNECOV	{"email": "valeriy-kuznecov.25111973@postgrespro.ru", "phone": "+70331105268"}
0005433131817	9EBEFA	5008 122072	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir-30121980@postgrespro.ru", "phone": "+70046231823"}
0005433131818	3113B5	0873 646811	LIDIYA IVANOVA	{"phone": "+70036558252"}
0005433131819	E7A1C2	6686 249618	ALEKSEY FEDOROV	{"phone": "+70388883189"}
0005433131820	AEC841	3641 736280	VALENTINA GORBUNOVA	{"phone": "+70003817102"}
0005433131821	615C75	1822 250950	YULIYA NAZAROVA	{"phone": "+70164036083"}
0005433131822	B90CD3	9100 662141	LYUDMILA KONDRATEVA	{"email": "kondrateva_l111962@postgrespro.ru", "phone": "+70999346057"}
0005433131823	B90CD3	7304 844151	ALEKSANDRA NAZAROVA	{"phone": "+70655505466"}
0005433131824	733F90	5466 755718	NADEZHDA ALEKSANDROVA	{"email": "nadezhda-aleksandrova101984@postgrespro.ru", "phone": "+70370787966"}
0005433131825	1B7C62	5861 097144	OKSANA SEMENOVA	{"email": "o_semenova19051970@postgrespro.ru", "phone": "+70021409203"}
0005433131826	1B7C62	6149 411812	NIKITA ALEKSEEV	{"email": "alekseev-n-1966@postgrespro.ru", "phone": "+70865831461"}
0005433131827	CD2BDD	9429 857981	OLGA SEMENOVA	{"email": "olgasemenova-15031974@postgrespro.ru", "phone": "+70278622164"}
0005433131828	CD2BDD	9880 055580	ALEKSANDR OSIPOV	{"phone": "+70447841909"}
0005433131829	CD2BDD	6848 107965	ANASTASIYA POLYAKOVA	{"email": "polyakova.anastasiya_101982@postgrespro.ru", "phone": "+70639144476"}
0005433131830	0E7BA3	2951 917600	TAMARA AKIMOVA	{"phone": "+70015987240"}
0005433131831	D64F93	7170 674231	SVETLANA KAZAKOVA	{"phone": "+70490149026"}
0005433131832	E55B29	7970 707752	ANNA KAZAKOVA	{"phone": "+70090070371"}
0005433131833	E55B29	1647 613148	OKSANA MELNIKOVA	{"phone": "+70312532703"}
0005433131834	CCA82D	0160 660111	ALEKSANDR KUDRYASHOV	{"phone": "+70944825133"}
0005433131835	6D77EA	0226 680154	NATALYA TITOVA	{"email": "titovan-19031987@postgrespro.ru", "phone": "+70888852166"}
0005433131836	C0AADA	9239 908544	MARIYA ALEKSEEVA	{"email": "m_alekseeva09081970@postgrespro.ru", "phone": "+70372862347"}
0005433131837	C0AADA	0626 045448	YULIYA NESTEROVA	{"email": "nesterova.y_021975@postgrespro.ru", "phone": "+70022591075"}
0005433131838	E29297	8573 716832	NATALYA CHERNOVA	{"email": "natalyachernova081972@postgrespro.ru", "phone": "+70791974291"}
0005433131839	A12A40	5445 365746	POLINA ANTONOVA	{"phone": "+70422101983"}
0005433131840	A12A40	2091 644993	MAKSIM ANTONOV	{"email": "antonov.m.10111972@postgrespro.ru", "phone": "+70449327921"}
0005433131841	69ADD6	1848 478906	IRINA ANDREEVA	{"email": "i_andreeva01011984@postgrespro.ru", "phone": "+70261531451"}
0005433131842	9F1F68	2927 823565	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova_anastasiya1972@postgrespro.ru", "phone": "+70036065321"}
0005433131843	9F1F68	4646 181979	GEORGIY BONDARENKO	{"phone": "+70436263553"}
0005433134056	82B5E6	2971 112238	ANATOLIY BARANOV	{"phone": "+70121490920"}
0005433134057	82C49D	9385 907604	VLADIMIR SEMENOV	{"phone": "+70350627292"}
0005433134058	5806A4	0348 260655	VLADISLAV KUZNECOV	{"phone": "+70704810329"}
0005433134060	EE7C99	6195 724022	IVAN VOLKOV	{"phone": "+70733475305"}
0005433134061	F275F4	8409 642235	EVGENIY KAZAKOV	{"email": "evgeniy.kazakov27041972@postgrespro.ru", "phone": "+70602455498"}
0005433134062	CC9A46	0107 170409	MAKSIM STEPANOV	{"email": "stepanov_maksim-29041967@postgrespro.ru", "phone": "+70499958538"}
0005433134063	C72013	7556 015995	ALEKSANDR SIDOROV	{"phone": "+70175487570"}
0005433134064	0DB13F	8427 590713	ALEKSANDR ROMANOV	{"phone": "+70028863583"}
0005433134065	611F7D	1646 390828	EKATERINA ALEKSANDROVA	{"email": "aleksandrova_e.121973@postgrespro.ru", "phone": "+70632272065"}
0005433134066	A45074	1536 347915	NATALYA SEMENOVA	{"email": "natalya.semenova.25101969@postgrespro.ru", "phone": "+70360658478"}
0005433134067	264C9C	3847 370862	VYACHESLAV IVANOV	{"email": "ivanovv_30011971@postgrespro.ru", "phone": "+70804730403"}
0005433134068	9EF43C	5647 824951	MIKHAIL KISELEV	{"email": "kiselevm02071970@postgrespro.ru", "phone": "+70826135339"}
0005433134069	CD27C6	7238 565001	LYUDMILA SCHERBAKOVA	{"email": "l_scherbakova.1980@postgrespro.ru", "phone": "+70183677650"}
0005433134070	73CA82	0189 946625	ANATOLIY SAVELEV	{"email": "saveleva_22071975@postgrespro.ru", "phone": "+70599528523"}
0005433134071	7461C3	4900 534262	TATYANA POPOVA	{"phone": "+70796972469"}
0005433134072	A7E8B4	1539 067504	MIKHAIL KOZLOV	{"phone": "+70086066285"}
0005433134073	DB652B	6535 344741	SERGEY ORLOV	{"email": "orlov_sergey.1960@postgrespro.ru", "phone": "+70486144370"}
0005433134074	555498	3686 071762	SVETLANA KUZNECOVA	{"email": "kuznecovasvetlana081962@postgrespro.ru", "phone": "+70282502988"}
0005433134075	555498	5084 703411	BOGDAN KOROLEV	{"phone": "+70366890226"}
0005433134076	940C0A	7172 157950	OLGA KONDRATEVA	{"phone": "+70229517878"}
0005433134077	940C0A	7642 389586	EVGENIY MOROZOV	{"phone": "+70471074558"}
0005433134078	06F985	2112 860045	MARIYA TARASOVA	{"phone": "+70771167468"}
0005433134079	08013F	6535 435158	OKSANA ANTONOVA	{"email": "antonova.o-1976@postgrespro.ru", "phone": "+70199639894"}
0005433134080	374F10	7456 192891	IVAN VLASOV	{"phone": "+70685161228"}
0005433134081	A939D0	8760 915369	ALEKSANDRA FEDOROVA	{"email": "a_fedorova1975@postgrespro.ru", "phone": "+70415071971"}
0005433134082	A55294	6231 128467	NATALIYA POPOVA	{"email": "popova-n-1980@postgrespro.ru", "phone": "+70585459038"}
0005433134083	A55294	2672 841802	ALBERT KAZAKOV	{"email": "akazakov_021975@postgrespro.ru", "phone": "+70139159496"}
0005433134084	095F1B	7296 553235	NINA SOKOLOVA	{"phone": "+70570834378"}
0005433134085	5B042F	7631 346950	LYUDMILA EGOROVA	{"phone": "+70719600613"}
0005433134086	151FB6	8035 174956	IRINA DANILOVA	{"phone": "+70301995009"}
0005433134087	151FB6	3318 116824	ANASTASIYA VOLKOVA	{"email": "volkova.anastasiya.1981@postgrespro.ru", "phone": "+70271505457"}
0005433134088	B8E744	4711 339349	NIKITA BARANOV	{"email": "nikitabaranov_10071978@postgrespro.ru", "phone": "+70011190953"}
0005433134089	C72459	8841 136144	ELENA MOROZOVA	{"phone": "+70801821355"}
0005433134090	C72459	7005 483073	SERGEY ANDREEV	{"phone": "+70950242718"}
0005433134091	77AD02	4841 128053	ALEKSANDRA ZAKHAROVA	{"email": "aleksandrazakharova-20031968@postgrespro.ru", "phone": "+70139501373"}
0005433134092	9D1B98	7878 003835	VALERIY ABRAMOV	{"email": "valeriy-abramov.19021982@postgrespro.ru", "phone": "+70239514927"}
0005433134093	9D1B98	2152 257155	VALERIY ABRAMOV	{"email": "abramovvaleriy.111979@postgrespro.ru", "phone": "+70775083788"}
0005433134094	9D1B98	2288 090516	KSENIYA ISAEVA	{"email": "isaevak21121980@postgrespro.ru", "phone": "+70304184011"}
0005433134095	47BCB6	7808 338048	SOFYA NAZAROVA	{"email": "sofya.nazarova-091973@postgrespro.ru", "phone": "+70703046595"}
0005433134096	47BCB6	6624 084410	LYUDMILA CHERNOVA	{"email": "chernova-lyudmila-061977@postgrespro.ru", "phone": "+70667871390"}
0005433134097	A16B4F	3057 331344	MARIYA TROFIMOVA	{"email": "trofimovam_031977@postgrespro.ru", "phone": "+70553039308"}
0005433134098	07AFD8	2724 417462	NATALYA DAVYDOVA	{"email": "ndavydova-24121971@postgrespro.ru", "phone": "+70754336351"}
0005433134099	691200	9628 990747	PAVEL BORISOV	{"phone": "+70688331889"}
0005433134100	E976B2	8325 936798	ARTUR POPOV	{"email": "popov.a-20101964@postgrespro.ru", "phone": "+70755968030"}
0005433134101	E976B2	3553 250143	VYACHESLAV MAKSIMOV	{"email": "maksimov_v.30121974@postgrespro.ru", "phone": "+70565551584"}
0005433134102	E976B2	3657 616286	LEONID YAKOVLEV	{"phone": "+70249235412"}
0005433134103	9ABE92	5273 592703	YURIY IVANOV	{"phone": "+70037814533"}
0005433134104	23B5A0	9370 710487	SVETLANA ANISIMOVA	{"phone": "+70126384734"}
0005433134105	23B5A0	2260 079766	ARSENIY NIKITIN	{"email": "arseniy-nikitin_041968@postgrespro.ru", "phone": "+70834070993"}
0005433134106	6A0EB7	4430 463525	LILIYA KOMAROVA	{"email": "liliya-komarova.1986@postgrespro.ru", "phone": "+70318975752"}
0005433134107	1D64D8	5423 499842	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov081969@postgrespro.ru", "phone": "+70278258026"}
0005433134108	9068A5	1624 859244	TATYANA BORISOVA	{"phone": "+70244019258"}
0005433134109	CAEE78	9947 993659	ANNA FROLOVA	{"email": "a_frolova1962@postgrespro.ru", "phone": "+70166573457"}
0005433134110	6AB60B	0700 012734	FEDOR ZHUKOV	{"phone": "+70314284022"}
0005433134111	E968DE	9863 825063	IVAN KUZNECOV	{"email": "ikuznecov.1965@postgrespro.ru", "phone": "+70648466363"}
0005433134112	7C5F65	0001 529159	IVAN ZAKHAROV	{"email": "zakharovivan-08101969@postgrespro.ru", "phone": "+70602780885"}
0005433134113	33E617	9185 946899	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-tatyana-121969@postgrespro.ru", "phone": "+70966421750"}
0005433134114	6008B6	2497 388046	OLEG IVANOV	{"phone": "+70389345147"}
0005433134115	79D529	3343 193169	YULIYA NIKITINA	{"phone": "+70168490984"}
0005433134116	79D529	7547 416236	MARINA ANISIMOVA	{"email": "anisimova.marina.1979@postgrespro.ru", "phone": "+70956121472"}
0005433134117	9B4B4B	6791 619924	MARIYA VLASOVA	{"email": "vlasova-mariya-1966@postgrespro.ru", "phone": "+70939003195"}
0005433134118	9B4B4B	2360 222989	VIKTOR PAVLOV	{"email": "viktor.pavlov.1970@postgrespro.ru", "phone": "+70292647609"}
0005433134119	213478	9186 780232	EVGENIY MARTYNOV	{"phone": "+70104696807"}
0005433134120	213478	1564 367081	ANATOLIY STEPANOV	{"email": "stepanov_a-051959@postgrespro.ru", "phone": "+70540896608"}
0005433134121	5A4B4B	4579 439804	IVAN KUZNECOV	{"phone": "+70422318438"}
0005433134122	7FA03C	5767 105082	ANTONIDA FOMINA	{"email": "fomina.antonida071970@postgrespro.ru", "phone": "+70420610442"}
0005433134123	65859A	4341 321644	EVGENIY MIKHAYLOV	{"email": "mikhaylov.e101962@postgrespro.ru", "phone": "+70328500681"}
0005433134124	18C1CD	8252 457844	ALEKSANDR SEMENOV	{"email": "semenov.a.1970@postgrespro.ru", "phone": "+70883713180"}
0005433134125	18C1CD	1901 893651	VLADIMIR FILIPPOV	{"phone": "+70450954656"}
0005433134126	8B2164	8214 884513	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.tatyana_1981@postgrespro.ru", "phone": "+70348021836"}
0005433134127	BF753F	3349 826887	ALEKSEY NOVIKOV	{"phone": "+70968763844"}
0005433134128	BF753F	4351 319839	SERGEY MATVEEV	{"email": "matveev_sergey1959@postgrespro.ru", "phone": "+70153272898"}
0005433134129	D5BDFD	0292 441069	TATYANA AFANASEVA	{"phone": "+70535697371"}
0005433134130	D5BDFD	5195 563961	ELENA ZHURAVLEVA	{"email": "zhuravleva.elena.01111968@postgrespro.ru", "phone": "+70825865502"}
0005433134131	3A77A8	8923 566985	ANTON IVANOV	{"phone": "+70250141495"}
0005433134132	A1E409	7372 184126	SERGEY ZAKHAROV	{"email": "zakharov-s.091977@postgrespro.ru", "phone": "+70950264797"}
0005433134133	1E37F7	7940 157958	ROMAN FROLOV	{"phone": "+70188852870"}
0005433134134	1E37F7	5197 354313	VLADIMIR ABRAMOV	{"phone": "+70803465238"}
0005433134135	2A21AB	1930 484899	INNA MIRONOVA	{"email": "innamironova-17081963@postgrespro.ru", "phone": "+70074065882"}
0005433134136	DCDEA2	5251 529879	PETR MELNIKOV	{"phone": "+70829660808"}
0005433134137	DCDEA2	9991 528751	LIDIYA ROMANOVA	{"email": "l.romanova-1983@postgrespro.ru", "phone": "+70306607645"}
0005433134138	CA0DC6	7292 190846	ARTUR ANTONOV	{"phone": "+70504332760"}
0005433134139	897786	8840 420909	ALEKSEY ALEKSEEV	{"email": "a-alekseev.071979@postgrespro.ru", "phone": "+70315246607"}
0005433134140	28CA45	0250 648781	ANATOLIY NIKOLAEV	{"phone": "+70947267231"}
0005433134141	B6991E	3604 377839	ZINAIDA SAVELEVA	{"email": "saveleva-zinaida1981@postgrespro.ru", "phone": "+70823707226"}
0005433134142	B6991E	6036 756640	STANISLAV KISELEV	{"email": "stanislav.kiselev_091976@postgrespro.ru", "phone": "+70009475986"}
0005433134143	B17969	5543 856435	REGINA NESTEROVA	{"phone": "+70753996232"}
0005433134144	B17969	9105 404386	LYUBOV KUZNECOVA	{"phone": "+70462016954"}
0005433134145	0EA7EB	9522 669280	VALENTINA BOGDANOVA	{"phone": "+70130537929"}
0005433134146	0EA7EB	8012 266917	ANDREY OSIPOV	{"phone": "+70713137688"}
0005433134147	617B36	0641 373306	ANDREY BORISOV	{"email": "borisov_a-011987@postgrespro.ru", "phone": "+70075071291"}
0005433134148	707A67	3294 179640	MARIYA VOLKOVA	{"email": "m.volkova_1978@postgrespro.ru", "phone": "+70771205891"}
0005433134149	707A67	5683 009980	EKATERINA ARKHIPOVA	{"email": "arkhipovaekaterina_1968@postgrespro.ru", "phone": "+70945715275"}
0005433134150	707A67	6793 488073	VIKTOR SOROKIN	{"email": "vsorokin-29031970@postgrespro.ru", "phone": "+70658392257"}
0005433134151	172A99	1312 613477	GENNADIY MIKHAYLOV	{"email": "mikhaylov-gennadiy_10011968@postgrespro.ru", "phone": "+70477719173"}
0005433134152	B00991	3861 549689	ROMAN FROLOV	{"phone": "+70344783414"}
0005433134153	610C96	7244 036504	ANASTASIYA TARASOVA	{"phone": "+70453867525"}
0005433134154	8FE767	8641 688755	MARIYA RODIONOVA	{"phone": "+70823742777"}
0005433134155	3BBB87	0494 678121	ALEKSANDR SERGEEV	{"phone": "+70292391604"}
0005433134156	F2D617	8819 271049	LYUBOV MIRONOVA	{"email": "lyubov-mironova-1976@postgrespro.ru", "phone": "+70548000704"}
0005433134157	879280	1281 042743	RUSLAN ANDREEV	{"phone": "+70382516566"}
0005433134158	C44663	1101 206497	VALENTINA KOMAROVA	{"email": "valentina.komarova.1961@postgrespro.ru", "phone": "+70170370718"}
0005433134159	9BE369	5061 849562	SHAMIL BELOV	{"phone": "+70132802521"}
0005433134160	6A7547	6169 177002	VALERIY GUSEV	{"phone": "+70790729858"}
0005433134161	D47629	3089 431192	VLADIMIR NOVIKOV	{"email": "vladimir-novikov_1978@postgrespro.ru", "phone": "+70243452647"}
0005433134162	39B4C7	3472 808122	SHAMIL ZHUKOV	{"email": "zhukovshamil_16061981@postgrespro.ru", "phone": "+70152728100"}
0005433134163	FF86CB	9614 992769	ANASTASIYA ALEKSEEVA	{"email": "alekseeva-anastasiya_051958@postgrespro.ru", "phone": "+70686449289"}
0005433134164	2B4352	7397 327100	NATALYA POPOVA	{"phone": "+70681635280"}
0005433134165	2B4352	9878 531995	LILIYA SOROKINA	{"email": "l-sorokina-02111975@postgrespro.ru", "phone": "+70912480144"}
0005433134166	BBE99C	0230 935387	SVETLANA SCHERBAKOVA	{"email": "svetlana.scherbakova29011982@postgrespro.ru", "phone": "+70524097097"}
0005433134167	BBE99C	6698 335717	MARIYA KUDRYASHOVA	{"phone": "+70405653956"}
0005433134168	2DEC8F	2118 396470	MIKHAIL SIDOROV	{"phone": "+70145979607"}
0005433134169	71131F	0686 619967	OLGA KONOVALOVA	{"email": "konovalova.olga071970@postgrespro.ru", "phone": "+70672371657"}
0005433134170	6EDBED	2602 857841	MIKHAIL IVANOV	{"email": "mivanov-041973@postgrespro.ru", "phone": "+70956127285"}
0005433134171	0F419B	3672 754696	ALEKSEY KONOVALOV	{"email": "aleksey_konovalov101980@postgrespro.ru", "phone": "+70141089817"}
0005433134172	0F419B	3230 507031	ANDREY NOVIKOV	{"email": "a_novikov1964@postgrespro.ru", "phone": "+70506561227"}
0005433134173	65D7B7	1607 551586	YURIY SCHERBAKOV	{"phone": "+70186231191"}
0005433134174	2A8237	7626 659372	NADEZHDA OSIPOVA	{"email": "nosipova_30061965@postgrespro.ru", "phone": "+70014216994"}
0005433134175	9706F4	5239 268384	VYACHESLAV MOISEEV	{"phone": "+70212259338"}
0005433134176	62BE33	7825 611983	EVGENIY FILIPPOV	{"phone": "+70148445297"}
0005433150883	C2FE53	9316 112082	IGOR PAVLOV	{"phone": "+70396602252"}
0005433134177	62BE33	3270 349954	GENNADIY KUZMIN	{"email": "gennadiy.kuzmin.24101975@postgrespro.ru", "phone": "+70688888212"}
0005433134178	53F047	0389 829335	ANNA ALEKSEEVA	{"email": "anna_alekseeva1963@postgrespro.ru", "phone": "+70866864587"}
0005433134179	539BB5	4736 973397	IVAN ROMANOV	{"phone": "+70641130554"}
0005433134180	844BAE	7104 078343	LIDIYA KISELEVA	{"email": "kiselevalidiya121976@postgrespro.ru", "phone": "+70623357325"}
0005433134181	844BAE	2673 284872	SERGEY POPOV	{"email": "popovsergey1969@postgrespro.ru", "phone": "+70327432544"}
0005433134182	69AAD6	3321 228104	KRISTINA IVANOVA	{"email": "ivanovak_30011975@postgrespro.ru", "phone": "+70517629421"}
0005433134183	69AAD6	1139 814700	VYACHESLAV DAVYDOV	{"email": "vdavydov28091974@postgrespro.ru", "phone": "+70546356133"}
0005433134184	20F48D	2352 997518	ALEKSANDR MELNIKOV	{"phone": "+70664227592"}
0005433134185	555B16	5157 753236	OLGA IVANOVA	{"phone": "+70104258528"}
0005433134186	ED7F36	7821 141416	NINEL POTAPOVA	{"email": "ninelpotapova_1974@postgrespro.ru", "phone": "+70282901029"}
0005433134187	ED7F36	3113 075661	ELENA ZOTOVA	{"phone": "+70879832300"}
0005433134188	96F9D6	2363 375520	NATALYA KUZNECOVA	{"email": "kuznecovanatalya03101980@postgrespro.ru", "phone": "+70006874766"}
0005433134189	2B592D	4611 732772	ILDAR KAZAKOV	{"email": "i_kazakov-121984@postgrespro.ru", "phone": "+70507173651"}
0005433134190	BF9E77	6527 039393	ALEKSEY IVANOV	{"phone": "+70807331435"}
0005433134191	D09099	4334 284926	IGOR ZAYCEV	{"email": "zaycev_igor_20061967@postgrespro.ru", "phone": "+70581652398"}
0005433134192	CAD558	8578 686324	NATALIYA ROMANOVA	{"phone": "+70816140274"}
0005433134193	91FBAD	9198 956572	NINA NAZAROVA	{"email": "nazarovan_1964@postgrespro.ru", "phone": "+70188165933"}
0005433134194	D78CEA	7251 273172	MIKHAIL POPOV	{"phone": "+70139925600"}
0005433134195	EE0117	2678 181349	PAVEL KOZLOV	{"phone": "+70100997413"}
0005433134196	EE0117	8577 827879	SVETLANA GAVRILOVA	{"phone": "+70521611509"}
0005433134197	EE0117	7719 338825	VYACHESLAV KOZLOV	{"email": "kozlov.v_08031973@postgrespro.ru", "phone": "+70614329720"}
0005433134198	CD87DE	3435 101850	OLGA IVANOVA	{"email": "o-ivanova_101963@postgrespro.ru", "phone": "+70706412656"}
0005433134199	1AC834	9285 347967	DENIS SOKOLOV	{"phone": "+70578748886"}
0005433134200	176270	7614 139224	IVAN IVANOV	{"email": "ivanovivan021976@postgrespro.ru", "phone": "+70000097150"}
0005433134201	176270	4722 833749	VALERIY ABRAMOV	{"email": "valeriy_abramov.02111970@postgrespro.ru", "phone": "+70039303762"}
0005433134202	2C43C3	3960 827917	ALEKSANDR KONOVALOV	{"phone": "+70977547335"}
0005433134203	F333E2	5490 599528	ILYA MATVEEV	{"phone": "+70327754033"}
0005433134204	F333E2	9357 813776	NIKOLAY SOLOVEV	{"email": "nikolaysolovev_1969@postgrespro.ru", "phone": "+70057375226"}
0005433134205	D4410E	5555 667839	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr1966@postgrespro.ru", "phone": "+70081668345"}
0005433134206	237F76	1695 643310	ANDREY DENISOV	{"phone": "+70706525973"}
0005433134207	EDB7DE	9446 739325	NINA DENISOVA	{"email": "nina_denisova_061983@postgrespro.ru", "phone": "+70149823740"}
0005433134208	EDB7DE	4634 770583	VIKTOR NIKOLAEV	{"phone": "+70119390805"}
0005433134209	EDB7DE	7018 433933	VLADIMIR SEMENOV	{"phone": "+70697346312"}
0005433134210	B92D0D	2471 714950	DMITRIY NIKOLAEV	{"phone": "+70140753428"}
0005433134211	B92D0D	1249 376217	SOFYA KOROLEVA	{"email": "koroleva-s_23021981@postgrespro.ru", "phone": "+70265544160"}
0005433134212	CE30A1	2985 508220	MARINA NIKIFOROVA	{"phone": "+70792156376"}
0005433134213	51DEDE	7273 957694	VALENTINA FEDOROVA	{"phone": "+70600516905"}
0005433134214	51DEDE	3536 791916	ALEKSANDR NAZAROV	{"email": "a_nazarov.31051971@postgrespro.ru", "phone": "+70368208981"}
0005433134215	D9BD0D	6491 275969	OLGA SAVELEVA	{"email": "olgasaveleva071969@postgrespro.ru", "phone": "+70907369293"}
0005433134216	33B923	0584 717909	EVGENIY VOROBEV	{"email": "evgeniy_vorobev-121984@postgrespro.ru", "phone": "+70368941810"}
0005433134217	33B923	8888 960882	NIKOLAY MEDVEDEV	{"phone": "+70315519625"}
0005433134218	33B923	5539 463831	SERGEY KONOVALOV	{"email": "s_konovalov1967@postgrespro.ru", "phone": "+70546917673"}
0005433134219	C41D24	9890 855690	NADEZHDA STEPANOVA	{"phone": "+70898214519"}
0005433134220	C41D24	3747 551476	SERAFIMA KOVALEVA	{"phone": "+70843786552"}
0005433134221	127856	3875 262013	ROMAN SERGEEV	{"email": "sergeevroman1963@postgrespro.ru", "phone": "+70149794173"}
0005433134222	8EBAD4	6426 404873	ARTUR EGOROV	{"email": "egorov_artur-1973@postgrespro.ru", "phone": "+70021979688"}
0005433134223	9B6DAA	1703 047460	VALERIY VOROBEV	{"email": "valeriyvorobev.1965@postgrespro.ru", "phone": "+70982034599"}
0005433134224	9B6DAA	5414 084637	RUSLAN TIKHONOV	{"phone": "+70441421113"}
0005433134225	D3B96E	4179 491314	LIDIYA CHERNOVA	{"phone": "+70767154720"}
0005433134226	700D31	0693 954374	OLGA NAZAROVA	{"phone": "+70691503888"}
0005433134227	EC355F	3318 680764	ANDREY FOMIN	{"phone": "+70130162700"}
0005433134228	EC355F	3278 920732	TATYANA ZAKHAROVA	{"phone": "+70833662581"}
0005433134229	EC355F	3316 932341	ALEKSANDR OSIPOV	{"phone": "+70855187279"}
0005433134230	4D3DBD	3326 929606	ELENA FILIPPOVA	{"phone": "+70130230958"}
0005433134231	32E1F1	7973 738447	OKSANA VASILEVA	{"email": "oksanavasileva.051976@postgrespro.ru", "phone": "+70715669781"}
0005433134232	32E1F1	2650 281938	IVAN TIKHONOV	{"email": "tikhonov.i-1972@postgrespro.ru", "phone": "+70828686957"}
0005433134233	25CF41	6632 082563	SERGEY STEPANOV	{"email": "sergeystepanov-1977@postgrespro.ru", "phone": "+70491962718"}
0005433134234	EE45D0	1682 050979	NATALYA MAKAROVA	{"email": "nmakarova.1967@postgrespro.ru", "phone": "+70040507738"}
0005433134235	EAD1CD	0759 132765	SERGEY PETROV	{"email": "s.petrov1971@postgrespro.ru", "phone": "+70463290032"}
0005433134236	EAD1CD	2622 175965	SABINA LEBEDEVA	{"email": "lebedevas.1965@postgrespro.ru", "phone": "+70000661340"}
0005433134237	128309	8628 770839	SERGEY ALEKSEEV	{"email": "sergey_alekseev-1970@postgrespro.ru", "phone": "+70693502603"}
0005433134238	83A8D1	2743 629631	YULIYA MOISEEVA	{"phone": "+70363867688"}
0005433134239	920DCB	5642 095381	VIKTOR MAKAROV	{"email": "v_makarov-04111970@postgrespro.ru", "phone": "+70285560222"}
0005433134240	C22D0B	7750 194910	NINA ZAYCEVA	{"phone": "+70037217799"}
0005433134241	C22D0B	8520 697711	ALISA MIKHAYLOVA	{"email": "mikhaylova.alisa_1972@postgrespro.ru", "phone": "+70142843017"}
0005433134242	A80316	4783 487072	NIKOLAY DAVYDOV	{"email": "davydov-nikolay.031971@postgrespro.ru", "phone": "+70508411825"}
0005433134243	3D217A	3874 367728	VYACHESLAV DENISOV	{"phone": "+70231510635"}
0005433134244	3D217A	3812 518607	ALINA VASILEVA	{"email": "vasileva_a_1987@postgrespro.ru", "phone": "+70675141595"}
0005433134245	40FCA4	0871 515300	NATALYA IVANOVA	{"email": "natalyaivanova.31101970@postgrespro.ru", "phone": "+70391434471"}
0005433134246	40FCA4	3686 088417	ANDREY SOROKIN	{"email": "sorokin.a.111971@postgrespro.ru", "phone": "+70165567128"}
0005433134247	0EB656	4502 056389	STEPAN KRASNOV	{"email": "s_krasnov-02041980@postgrespro.ru", "phone": "+70964455437"}
0005433134248	0EB656	3603 378636	ALEKSANDR DAVYDOV	{"email": "a_davydov_121972@postgrespro.ru", "phone": "+70774824602"}
0005433134249	87E6D4	5754 774746	NIKOLAY TARASOV	{"email": "n.tarasov.051982@postgrespro.ru", "phone": "+70251627503"}
0005433134250	18DD76	5532 631025	ALEKSANDR SMIRNOV	{"phone": "+70130203245"}
0005433134251	84B4EA	3019 499680	VALERIY FROLOV	{"email": "frolov_v071963@postgrespro.ru", "phone": "+70118971474"}
0005433134252	84B4EA	8170 832012	YURIY SOKOLOV	{"email": "sokolov_yuriy_081988@postgrespro.ru", "phone": "+70225132239"}
0005433134253	7FDC5D	0579 623108	DENIS KOROLEV	{"email": "korolevd.011976@postgrespro.ru", "phone": "+70323690114"}
0005433134254	DB6D3A	6006 772387	POLINA FADEEVA	{"phone": "+70953684837"}
0005433134255	D22393	0897 451164	GALINA GERASIMOVA	{"email": "gerasimova-galina30101972@postgrespro.ru", "phone": "+70752677441"}
0005433134256	D22393	8247 783076	YULIYA KARPOVA	{"email": "karpova_y-1973@postgrespro.ru", "phone": "+70325430724"}
0005433134257	CF399B	5280 169416	IVAN KONOVALOV	{"phone": "+70071786641"}
0005433134258	8EA5B5	3081 183862	TATYANA FROLOVA	{"phone": "+70797058278"}
0005433134259	466371	0257 383505	MAKSIM GORBUNOV	{"email": "maksim.gorbunov_081981@postgrespro.ru", "phone": "+70322726507"}
0005433134260	8819D5	9791 274756	RAISA MELNIKOVA	{"phone": "+70872476516"}
0005433134261	29B9E5	7604 625845	RAMIS KONOVALOV	{"email": "r-konovalov011968@postgrespro.ru", "phone": "+70995513664"}
0005433134262	06D7BF	1563 488980	LIDIYA MEDVEDEVA	{"email": "medvedeva_l_061979@postgrespro.ru", "phone": "+70248691194"}
0005433134263	188359	5677 146276	EGOR SIDOROV	{"phone": "+70190345570"}
0005433134264	878C2E	4987 611954	DARYA FILIPPOVA	{"email": "d-filippova.021971@postgrespro.ru", "phone": "+70561715373"}
0005433134265	9413F3	6330 171637	VALENTINA VASILEVA	{"phone": "+70603258844"}
0005433150794	6C08BA	4765 658519	IGOR GERASIMOV	{"email": "gerasimov.i_011963@postgrespro.ru", "phone": "+70134374226"}
0005433150795	1802E1	6472 708298	VERA RODIONOVA	{"phone": "+70109421240"}
0005433150796	1802E1	3533 202383	ALINA KUZNECOVA	{"phone": "+70565692872"}
0005433150797	82FB9E	6424 997834	FAINA IVANOVA	{"email": "fivanova-1969@postgrespro.ru", "phone": "+70554129099"}
0005433150798	FCD678	0774 661746	ALEKSANDR MOROZOV	{"phone": "+70177769623"}
0005433150799	FCD678	9875 767898	YULIYA KUZNECOVA	{"phone": "+70766981782"}
0005433150800	8C4EDB	1737 919115	VALENTINA ISAEVA	{"email": "valentinaisaeva.121971@postgrespro.ru", "phone": "+70937484175"}
0005433150801	A6E0E3	3356 879058	NINA SAVELEVA	{"phone": "+70111507853"}
0005433150802	A6E0E3	7364 509829	YURIY SERGEEV	{"phone": "+70592249992"}
0005433150803	F9BA0B	0577 425335	NATALYA KONOVALOVA	{"phone": "+70827603964"}
0005433150804	F9BA0B	2997 514088	VIKTOR ANTONOV	{"phone": "+70108429738"}
0005433150805	9B9C44	2699 510983	ALENA ANDREEVA	{"email": "alena-andreeva-111979@postgrespro.ru", "phone": "+70288883463"}
0005433150806	9B9C44	3359 367953	EGOR FEDOTOV	{"email": "fedotovegor.111976@postgrespro.ru", "phone": "+70402805505"}
0005433150807	4E2543	6857 191570	ALEKSANDRA SEMENOVA	{"email": "aleksandrasemenova.24021967@postgrespro.ru", "phone": "+70925462380"}
0005433150808	DE41B8	8437 237026	DANILA SERGEEV	{"email": "danila.sergeev-021978@postgrespro.ru", "phone": "+70904959678"}
0005433150809	0ABEC7	2842 178763	VIKTOR ANDREEV	{"email": "viktor_andreev.021979@postgrespro.ru", "phone": "+70494167912"}
0005433150810	866A14	8174 597509	VALERIYA AFANASEVA	{"phone": "+70750171641"}
0005433150811	660D06	9641 993448	INESSA MIRONOVA	{"email": "i_mironova1977@postgrespro.ru", "phone": "+70293570033"}
0005433150812	660D06	6116 269075	VERA KONOVALOVA	{"phone": "+70075435049"}
0005433150813	C5F89A	8494 178781	VLADIMIR FEDOROV	{"phone": "+70934320677"}
0005433150814	C5F89A	9565 933504	VYACHESLAV MELNIKOV	{"email": "v.melnikov_1978@postgrespro.ru", "phone": "+70660074069"}
0005433150815	94C048	9944 942535	LIDIYA RODIONOVA	{"email": "rodionova.l_1976@postgrespro.ru", "phone": "+70329928139"}
0005433150816	06A1F1	2921 439646	ALISA KOROLEVA	{"email": "koroleva-alisa_071973@postgrespro.ru", "phone": "+70440058569"}
0005433150817	0B0004	1813 009156	ALEKSANDR FOMIN	{"phone": "+70012314034"}
0005433150818	FC04ED	8361 370217	YANA KOZLOVA	{"email": "kozlova.yana19121983@postgrespro.ru", "phone": "+70015375733"}
0005433150819	9E91C6	4302 799283	SERGEY ANTONOV	{"email": "sergey.antonov_1961@postgrespro.ru", "phone": "+70560422590"}
0005433150820	9E91C6	4708 002034	ANDREY KUDRYASHOV	{"email": "kudryashovandrey.30041963@postgrespro.ru", "phone": "+70239823773"}
0005433150821	1AE283	5188 431589	NIKOLAY ALEKSEEV	{"email": "nikolay-alekseev-1974@postgrespro.ru", "phone": "+70100964888"}
0005433150822	F975C2	6138 922277	TATYANA FEDOROVA	{"phone": "+70451794257"}
0005433150823	983D8F	3668 881105	MARIYA NOVIKOVA	{"email": "novikova-mariya_061971@postgrespro.ru", "phone": "+70008189347"}
0005433150824	983D8F	4579 124782	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana011974@postgrespro.ru", "phone": "+70670765090"}
0005433150825	F07501	4277 371015	LYUDMILA DENISOVA	{"email": "l-denisova.1979@postgrespro.ru", "phone": "+70899279796"}
0005433150826	F07501	0101 291578	LYUDMILA MAKAROVA	{"phone": "+70270049846"}
0005433150827	E80112	4151 357837	DANILA MAKAROV	{"phone": "+70280255483"}
0005433150828	02DEC3	5673 626994	ANATOLIY FEDOROV	{"email": "fedorov-anatoliy_21101972@postgrespro.ru", "phone": "+70358013892"}
0005433150829	510559	3050 232552	VALENTINA NIKOLAEVA	{"email": "nikolaevav.061969@postgrespro.ru", "phone": "+70433216125"}
0005433150830	7839AB	7433 316187	ANNA KUZNECOVA	{"phone": "+70748885363"}
0005433150831	D75E26	1453 979391	VIKTORIYA NOVIKOVA	{"phone": "+70639367651"}
0005433150832	D05598	1610 832266	VASILIY STEPANOV	{"phone": "+70404405893"}
0005433150833	23D5B2	2232 788522	ANNA PETROVA	{"phone": "+70272687914"}
0005433150834	23D5B2	7108 461374	GENNADIY ANDREEV	{"phone": "+70783619161"}
0005433150835	D568BE	6873 059041	VLADIMIR VASILEV	{"email": "vasilevvladimir.031975@postgrespro.ru", "phone": "+70029326860"}
0005433150836	7BCEA7	4274 518939	ELENA ARKHIPOVA	{"email": "elena-arkhipova-121966@postgrespro.ru", "phone": "+70807197285"}
0005433150837	7BCEA7	0663 438339	KSENIYA GORBUNOVA	{"email": "gorbunova_k18031976@postgrespro.ru", "phone": "+70317168486"}
0005433150838	20BA7A	3987 066018	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr-07041962@postgrespro.ru", "phone": "+70637046836"}
0005433150839	3D3AB0	6022 007506	DMITRIY PETROV	{"phone": "+70949454256"}
0005433150840	8263AA	6615 150494	FEDOR POPOV	{"email": "fpopov_031979@postgrespro.ru", "phone": "+70578973947"}
0005433150841	8263AA	2419 340388	ANDREY ALEKSEEV	{"phone": "+70828728394"}
0005433150842	D60917	5308 686654	VALENTINA VLASOVA	{"phone": "+70839716653"}
0005433150843	D60917	2036 239179	DANIIL ANTONOV	{"email": "daniil_antonov-071975@postgrespro.ru", "phone": "+70744458191"}
0005433150844	030E2F	1381 463471	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov.04061970@postgrespro.ru", "phone": "+70173777227"}
0005433150845	09F626	0852 174218	ANDREY VASILEV	{"email": "andrey.vasilev29121983@postgrespro.ru", "phone": "+70987800322"}
0005433150846	C08809	6515 538987	ANATOLIY FOMIN	{"email": "fomin_anatoliy01101980@postgrespro.ru", "phone": "+70325453033"}
0005433150847	C08809	7905 793630	VALENTINA ALEKSEEVA	{"phone": "+70958511272"}
0005433150848	8E4B1D	4961 468141	EVGENIYA DAVYDOVA	{"email": "davydova-evgeniya1977@postgrespro.ru", "phone": "+70511851760"}
0005433150849	8E4B1D	6928 545012	DMITRIY SCHERBAKOV	{"phone": "+70375266175"}
0005433150850	4D6D6A	6553 537294	YANA ORLOVA	{"phone": "+70045686905"}
0005433150851	D951A7	3194 670320	DMITRIY ZAYCEV	{"email": "zaycev.dmitriy_051980@postgrespro.ru", "phone": "+70533183395"}
0005433150852	D636E4	8413 032617	ANATOLIY TIKHONOV	{"phone": "+70887034228"}
0005433150853	F9C4B4	6665 067441	NATALYA ALEKSEEVA	{"email": "n-alekseeva_21071973@postgrespro.ru", "phone": "+70129280382"}
0005433150854	E6FC6B	3866 400088	VLADISLAV MIKHAYLOV	{"phone": "+70808719022"}
0005433150855	D1984E	3958 144568	ANDREY ILIN	{"phone": "+70777043623"}
0005433150856	9528C2	9392 865117	IRINA FOMINA	{"phone": "+70988636139"}
0005433150857	B061F7	4420 513612	ALEKSANDR SERGEEV	{"phone": "+70127467127"}
0005433150858	2FFEAD	5156 153478	IRINA NIKOLAEVA	{"phone": "+70754505656"}
0005433150859	6B34E0	6979 145020	IVAN ZAKHAROV	{"phone": "+70204174075"}
0005433150860	6B34E0	0446 694502	DMITRIY MAKSIMOV	{"phone": "+70257347030"}
0005433150861	6B34E0	5311 817007	GALINA EFIMOVA	{"email": "g-efimova_06071972@postgrespro.ru", "phone": "+70303850116"}
0005433150862	A5E07B	6985 642093	VITALIY TIKHONOV	{"phone": "+70953024227"}
0005433150863	A5E07B	8598 072345	ALEKSANDR GRIGOREV	{"email": "a_grigorev-021977@postgrespro.ru", "phone": "+70993832624"}
0005433150864	8CBDA5	2474 265519	ANDREY MARTYNOV	{"email": "andreymartynov04101961@postgrespro.ru", "phone": "+70922660465"}
0005433150865	8CBDA5	3813 093927	LYUBOV IVANOVA	{"phone": "+70233432889"}
0005433150866	77C287	6045 471696	LYUDMILA FILATOVA	{"phone": "+70748964314"}
0005433150867	77C287	6229 845082	SERGEY BORISOV	{"email": "borisovs14051978@postgrespro.ru", "phone": "+70974179038"}
0005433150868	9B959F	2518 737155	LYUBOV PETROVA	{"email": "lyubov_petrova-20071971@postgrespro.ru", "phone": "+70714283223"}
0005433150869	9C9506	9509 762967	ROZALIYA ZOTOVA	{"email": "zotova_r_20021962@postgrespro.ru", "phone": "+70886329040"}
0005433150870	53C1CE	2751 513418	ANNA BELOVA	{"phone": "+70517856982"}
0005433150871	E03A99	9120 204440	SVETLANA KOZLOVA	{"email": "kozlova_s_24061968@postgrespro.ru", "phone": "+70730700731"}
0005433150872	E03A99	8853 402937	MARINA KOROLEVA	{"email": "koroleva-m021975@postgrespro.ru", "phone": "+70864142344"}
0005433150873	34D735	9107 308448	GALINA BORISOVA	{"email": "galina-borisova_29011969@postgrespro.ru", "phone": "+70225463018"}
0005433150874	5FFFB9	3730 121860	VENIAMIN IVANOV	{"email": "ivanov-veniamin-071972@postgrespro.ru", "phone": "+70199183204"}
0005433150875	5FFFB9	1857 162646	ALLA VASILEVA	{"phone": "+70590059000"}
0005433150876	2C4AB7	8723 831191	VYACHESLAV VASILEV	{"phone": "+70860853765"}
0005433150877	78C4E1	7458 382289	YULIYA SCHERBAKOVA	{"phone": "+70968000094"}
0005433150878	9E06A5	1955 296097	ALEKSANDRA KALININA	{"phone": "+70294577451"}
0005433150879	9E06A5	5495 534370	NIKOLAY BELOV	{"phone": "+70665082041"}
0005433150880	9E06A5	5050 544866	GENNADIY MOROZOV	{"email": "g.morozov.1975@postgrespro.ru", "phone": "+70791868531"}
0005433150881	5060B2	7190 156902	VITALIY SERGEEV	{"email": "sergeev-v_1975@postgrespro.ru", "phone": "+70331232232"}
0005433150882	5060B2	9671 888436	ANTON KOZLOV	{"email": "kozlov_a_121974@postgrespro.ru", "phone": "+70389605200"}
0005433150884	2C6241	5858 667663	ALEKSANDR FEDOTOV	{"phone": "+70985984327"}
0005433150885	2C6241	5219 670871	OLEG KUZNECOV	{"phone": "+70228696844"}
0005433150886	C8BD9C	3137 726063	ALEKSANDR STEPANOV	{"phone": "+70793043557"}
0005433150887	9304CD	0069 325631	VLADIMIR OSIPOV	{"email": "osipov.vladimir-121968@postgrespro.ru", "phone": "+70737562170"}
0005433150888	9304CD	7116 290447	ALEKSANDR TARASOV	{"phone": "+70300188317"}
0005433150889	4C261D	2389 362628	IRINA NIKOLAEVA	{"phone": "+70658097392"}
0005433150890	154423	1198 231648	IRINA GORBUNOVA	{"phone": "+70754214535"}
0005433150891	6653A3	6348 531327	LEONTIY TIKHONOV	{"email": "tikhonov-l_27111968@postgrespro.ru", "phone": "+70607181006"}
0005433150892	6653A3	0715 309734	PETR ANTONOV	{"phone": "+70884813843"}
0005433150893	EF7B73	6145 698185	ANASTASIYA CHERNOVA	{"email": "chernova-a_08031966@postgrespro.ru", "phone": "+70110241675"}
0005433150894	9CC053	3145 030764	FARID ISAEV	{"phone": "+70617925774"}
0005433150895	0012C1	9973 988225	ARKADIY MIKHAYLOV	{"email": "mikhaylov_arkadiy_1972@postgrespro.ru", "phone": "+70415038386"}
0005433150896	F0F2C0	2268 313028	NADEZHDA FEDOROVA	{"email": "fedorovan_23101967@postgrespro.ru", "phone": "+70460444725"}
0005433150897	B7C9C2	0414 652586	ANNA BELOVA	{"email": "belova_a.031976@postgrespro.ru", "phone": "+70659222306"}
0005433150898	B7C9C2	0885 386626	VITALIY MOISEEV	{"email": "moiseevv.111972@postgrespro.ru", "phone": "+70156993302"}
0005433150899	683CA4	2306 938268	ALEKSANDR SERGEEV	{"email": "sergeev.a_031968@postgrespro.ru", "phone": "+70268624332"}
0005433150900	8BB273	0845 517411	YULIYA KUZNECOVA	{"phone": "+70733926521"}
0005433150901	8BB273	5232 796140	MARIYA IVANOVA	{"phone": "+70186319272"}
0005433150902	D1EA71	6630 272565	MARINA IVANOVA	{"email": "ivanova-marina.1969@postgrespro.ru", "phone": "+70825329055"}
0005433150903	92E8E1	4655 286409	NIKITA BELOV	{"email": "n-belov.031978@postgrespro.ru", "phone": "+70052920933"}
0005433150904	92E8E1	9328 989037	LYUDMILA KULIKOVA	{"email": "kulikova.lyudmila061977@postgrespro.ru", "phone": "+70323784352"}
0005433150905	92E8E1	0893 919487	NIKOLAY EGOROV	{"phone": "+70457230078"}
0005433150906	626F75	1763 840319	VALENTINA NOVIKOVA	{"email": "novikova.valentina.071957@postgrespro.ru", "phone": "+70440749339"}
0005433150907	BB145F	4134 887569	PAVEL NIKOLAEV	{"email": "nikolaevpavel.071974@postgrespro.ru", "phone": "+70092758028"}
0005433150908	BB145F	4487 266435	YULIYA KONOVALOVA	{"email": "yuliya.konovalova-091974@postgrespro.ru", "phone": "+70098335526"}
0005433150909	94E536	0318 999366	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev061967@postgrespro.ru", "phone": "+70580861254"}
0005433150910	78B2F3	5802 558979	IRINA FROLOVA	{"email": "irina.frolova.1975@postgrespro.ru", "phone": "+70733407584"}
0005433150911	78B2F3	1965 693402	KONSTANTIN GORBUNOV	{"phone": "+70254260371"}
0005433150912	A4B76B	5343 926713	RAMIL SAVELEV	{"email": "savelev.r-16031964@postgrespro.ru", "phone": "+70347868893"}
0005433150913	097F50	5728 011774	LYUBOV SOLOVEVA	{"phone": "+70163725474"}
0005433150914	E1B2D9	4851 892851	TIMUR IVANOV	{"phone": "+70276326579"}
0005433150915	8406DC	9126 746331	VIKTORIYA KOLESNIKOVA	{"phone": "+70815353185"}
0005433150916	584839	6826 486919	OLGA EGOROVA	{"phone": "+70223548186"}
0005433150917	3C1732	6092 706832	VALERIY KUZNECOV	{"email": "valeriykuznecov.051972@postgrespro.ru", "phone": "+70460519686"}
0005433150918	3C1732	7594 988556	ROMAN SOROKIN	{"phone": "+70776482373"}
0005433150919	15479E	1427 713383	VASILIY MOROZOV	{"phone": "+70130039647"}
0005433150920	30409B	7605 281907	SVETLANA MAKAROVA	{"phone": "+70945048343"}
0005433150921	2A1B4B	1944 624677	TAMARA DENISOVA	{"phone": "+70860621694"}
0005433150922	3DBB75	4788 101294	ANNA OSIPOVA	{"phone": "+70956604052"}
0005433150923	A083E7	3617 202992	PAVEL MAKAROV	{"email": "p.makarov-27011972@postgrespro.ru", "phone": "+70442258974"}
0005433150924	856AC9	2797 406912	GALINA MALYSHEVA	{"phone": "+70142924776"}
0005433150925	856AC9	6412 403021	LARISA DMITRIEVA	{"email": "l.dmitrieva.071956@postgrespro.ru", "phone": "+70840864388"}
0005433150926	746528	1123 925302	ALEKSANDR BORISOV	{"phone": "+70833878647"}
0005433150927	746528	4513 310210	MARGARITA DANILOVA	{"email": "m-danilova_20111955@postgrespro.ru", "phone": "+70845808832"}
0005433150928	746528	5646 059619	VALENTINA SOROKINA	{"phone": "+70395235644"}
0005433150929	E6B600	8188 828132	TATYANA KOROLEVA	{"email": "tatyanakoroleva-10021971@postgrespro.ru", "phone": "+70352443355"}
0005433150930	1CCC00	4241 692589	ILYA KUZNECOV	{"phone": "+70388706938"}
0005433150931	751A6E	3180 753387	MARIYA NAUMOVA	{"phone": "+70475353492"}
0005433150932	751A6E	6032 014052	VIKTOR KUZNECOV	{"phone": "+70085291520"}
0005433150933	A54E30	4385 396640	ANNA CHERNOVA	{"phone": "+70979012346"}
0005433150934	6001CD	5331 144522	PETR IVANOV	{"email": "ivanov-p-061971@postgrespro.ru", "phone": "+70826298670"}
0005433150935	5BF3A5	2238 900096	SVYATOSLAV VASILEV	{"email": "svyatoslav-vasilev_1969@postgrespro.ru", "phone": "+70856068755"}
0005433150936	C39EA5	0511 215104	VYACHESLAV ANTONOV	{"phone": "+70681270339"}
0005433150937	C39EA5	8232 239756	ELENA IVANOVA	{"phone": "+70403397874"}
0005433150938	C39EA5	8693 120072	ALEKSANDR IVANOV	{"email": "ivanov_a.1975@postgrespro.ru", "phone": "+70096880192"}
0005433150939	C39EA5	0119 943824	MIKHAIL ORLOV	{"email": "orlov-m-1975@postgrespro.ru", "phone": "+70955291000"}
0005433150940	30F179	8955 942097	ALEKSANDRA VOLKOVA	{"phone": "+70021317425"}
0005433150941	30F179	3875 317485	IRINA FROLOVA	{"phone": "+70598446640"}
0005433150942	30F179	9839 911425	YURIY KISELEV	{"phone": "+70748419528"}
0005433150943	780206	5712 908273	VALENTINA MAKSIMOVA	{"email": "maksimova.v_25011975@postgrespro.ru", "phone": "+70017830220"}
0005433150944	780206	1227 162938	TATYANA PAVLOVA	{"email": "pavlovatatyana-23011975@postgrespro.ru", "phone": "+70344481750"}
0005433150945	FCE98B	2893 004543	ANDREY SOROKIN	{"email": "sorokin-andrey.1971@postgrespro.ru", "phone": "+70435854978"}
0005433150946	58FD81	7425 584788	PAVEL ZAKHAROV	{"email": "zakharov-p.14121975@postgrespro.ru", "phone": "+70806250494"}
0005433150947	0CBAEE	8371 610467	EKATERINA IVANOVA	{"email": "e.ivanova.12091961@postgrespro.ru", "phone": "+70575058852"}
0005433150948	FF8DDF	0037 447607	DANIIL DAVYDOV	{"phone": "+70709078383"}
0005433150949	C34AA5	5466 985083	IRINA MELNIKOVA	{"phone": "+70908502251"}
0005433150950	D765B4	0374 038487	VALERIY ISAEV	{"phone": "+70219925948"}
0005433150951	D765B4	3513 258833	PAVEL DMITRIEV	{"phone": "+70257796883"}
0005433150952	8042BD	8098 257924	ELENA MIKHAYLOVA	{"phone": "+70032781193"}
0005433150953	FEFF59	9514 605667	VERONIKA CHERNOVA	{"phone": "+70211776956"}
0005433150954	FEFF59	3965 580544	LIDIYA MOISEEVA	{"email": "moiseeva.l_31051968@postgrespro.ru", "phone": "+70673942234"}
0005433150955	48AE4A	5135 139459	NATALYA MELNIKOVA	{"phone": "+70539493225"}
0005433150956	48AE4A	8554 969673	NATALYA ANTONOVA	{"email": "antonova.natalya_31101970@postgrespro.ru", "phone": "+70659812155"}
0005433150957	16873B	5758 538853	LYUDMILA ZAYCEVA	{"email": "zayceva.lyudmila.111975@postgrespro.ru", "phone": "+70212604901"}
0005433150958	E83364	7723 352596	PETR MOROZOV	{"email": "morozov_petr-22071968@postgrespro.ru", "phone": "+70704461906"}
0005433150959	E83364	4222 493247	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay_031973@postgrespro.ru", "phone": "+70427131462"}
0005433150960	A0F992	2519 401848	IVAN PAVLOV	{"email": "pavlovivan_1969@postgrespro.ru", "phone": "+70621269953"}
0005433150961	A0F992	0515 168887	MARIYA FOMINA	{"phone": "+70740282487"}
0005433150962	8CE4C4	3705 206119	LYUBOV KUZMINA	{"email": "kuzmina.lyubov.091970@postgrespro.ru", "phone": "+70280388345"}
0005433150963	C49145	7061 085050	VADIM MOISEEV	{"email": "moiseev.vadim.061971@postgrespro.ru", "phone": "+70628523258"}
0005433150964	C49145	2345 333464	OKSANA LAZAREVA	{"email": "oksanalazareva011979@postgrespro.ru", "phone": "+70965249440"}
0005433150965	81A51F	3274 505154	NIKOLAY MELNIKOV	{"email": "nikolay_melnikov.1968@postgrespro.ru", "phone": "+70792957298"}
0005433150966	85717A	0468 918532	NINA NAZAROVA	{"email": "ninanazarova.1976@postgrespro.ru", "phone": "+70684190347"}
0005433150967	CE3B06	1173 046497	TATYANA NIKOLAEVA	{"email": "nikolaeva.t-15071960@postgrespro.ru", "phone": "+70717495988"}
0005433150968	3E07FF	7987 963704	TATYANA KONOVALOVA	{"email": "t.konovalova.1983@postgrespro.ru", "phone": "+70916225022"}
0005433150969	3E07FF	7143 173740	VERA KUZNECOVA	{"email": "vera.kuznecova-111973@postgrespro.ru", "phone": "+70050125473"}
0005433150970	BA847E	2779 326079	SVETLANA GAVRILOVA	{"phone": "+70784844795"}
0005433150971	BA6CF5	3970 836031	SERGEY FILIPPOV	{"email": "filippovsergey-121980@postgrespro.ru", "phone": "+70828281605"}
0005433150972	DFE758	6167 502254	VIKTOR KUZNECOV	{"email": "kuznecovviktor-09021971@postgrespro.ru", "phone": "+70186716602"}
0005433150973	9EBC1C	6778 643337	VLADIMIR VASILEV	{"phone": "+70246166707"}
0005433150974	9EBC1C	0818 926368	VALENTINA FILIPPOVA	{"phone": "+70130170838"}
0005433150975	9EBC1C	3968 437352	GALINA ALEKSEEVA	{"email": "galina-alekseeva_11011974@postgrespro.ru", "phone": "+70657307551"}
0005433150976	5D85D2	2060 910890	YULIYA IVANOVA	{"phone": "+70566020201"}
0005433150977	5E4F36	0874 075108	VALENTINA IVANOVA	{"email": "valentina.ivanova1966@postgrespro.ru", "phone": "+70877574747"}
0005433150978	3427E6	7484 471732	SERGEY DMITRIEV	{"phone": "+70365432412"}
0005433150979	9AF208	9924 211909	ALEKSANDR KUZNECOV	{"phone": "+70866093385"}
0005433150980	575930	8939 616268	ULYANA KOLESNIKOVA	{"email": "u-kolesnikova121973@postgrespro.ru", "phone": "+70497569780"}
0005433150981	575930	9906 742187	ALEKSANDR MOISEEV	{"email": "a_moiseev_021961@postgrespro.ru", "phone": "+70794362777"}
0005433150982	7FF794	1802 367915	VLADIMIR SERGEEV	{"email": "vladimir.sergeev071976@postgrespro.ru", "phone": "+70516564147"}
0005433150983	1436DA	5533 417174	SVETLANA POLYAKOVA	{"phone": "+70424938644"}
0005433150984	1436DA	0366 423910	MAKSIM IVANOV	{"email": "ivanov-m.021982@postgrespro.ru", "phone": "+70679577765"}
0005433150985	3163B0	9937 286131	VLADIMIR KOZLOV	{"email": "kozlov.v.08121969@postgrespro.ru", "phone": "+70906757917"}
0005433150986	3163B0	8320 154796	ARINA VASILEVA	{"email": "a_vasileva-1963@postgrespro.ru", "phone": "+70117446286"}
0005433150987	4965DE	4387 878652	LARISA ANDREEVA	{"email": "andreevalarisa.1969@postgrespro.ru", "phone": "+70881334008"}
0005433150988	D75AA6	4373 871675	SERGEY SMIRNOV	{"phone": "+70764270150"}
0005433150989	CDCAB8	6390 580805	ARINA TARASOVA	{"phone": "+70149573594"}
0005433150990	059727	8617 710062	EKATERINA ILINA	{"phone": "+70856475175"}
0005433150991	42E30E	9515 347880	ARTUR ALEKSANDROV	{"email": "aaleksandrov_021971@postgrespro.ru", "phone": "+70995081474"}
0005433150992	80D3B4	6217 914383	LYUBOV KRASNOVA	{"email": "l-krasnova1973@postgrespro.ru", "phone": "+70841729105"}
0005433150993	80D3B4	9041 820575	EVGENIY DMITRIEV	{"phone": "+70865465165"}
0005433150994	80D3B4	1538 939880	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov_17081980@postgrespro.ru", "phone": "+70494512939"}
0005433150995	99CC43	5427 732937	ELENA DANILOVA	{"email": "e-danilova1971@postgrespro.ru", "phone": "+70949130032"}
0005433150996	48D235	6199 406057	ANNA BOGDANOVA	{"email": "anna.bogdanova-18031975@postgrespro.ru", "phone": "+70250200006"}
0005433150997	F1CE1A	8502 238904	ELENA KUZNECOVA	{"phone": "+70698479986"}
0005433150998	1CBA0F	2493 076232	MARINA KONDRATEVA	{"phone": "+70602405379"}
0005433150999	1E9293	7253 492509	NAIL ANDREEV	{"email": "n_andreev-1969@postgrespro.ru", "phone": "+70754565338"}
0005433151000	7F0BA7	0531 538636	VIKTOR NAZAROV	{"phone": "+70295349586"}
0005433151001	7F0BA7	8495 696675	NINA ANISIMOVA	{"email": "nina-anisimova.21121975@postgrespro.ru", "phone": "+70241923375"}
0005433151002	599638	0580 816623	MARINA KOZLOVA	{"phone": "+70856768367"}
0005433151003	599638	9623 712719	ANDREY STEPANOV	{"email": "andrey-stepanov.041974@postgrespro.ru", "phone": "+70516882412"}
0005433151004	599638	6791 429815	DMITRIY FILIPPOV	{"email": "dfilippov_101980@postgrespro.ru", "phone": "+70637995795"}
0005433151005	837089	4966 386697	VITALIY KOZLOV	{"email": "vitaliykozlov-1960@postgrespro.ru", "phone": "+70241971626"}
0005433151006	6168D9	6889 096354	TATYANA MAKAROVA	{"email": "tatyana-makarova-24061951@postgrespro.ru", "phone": "+70415872109"}
0005433151007	6168D9	6780 078033	STEPAN GORBUNOV	{"phone": "+70815535471"}
0005433151008	6168D9	8796 209698	ANATOLIY BELOV	{"phone": "+70622833784"}
0005433151009	01BE56	7011 280753	RUSLAN YAKOVLEV	{"email": "ruslan-yakovlev.20051968@postgrespro.ru", "phone": "+70225042252"}
0005433151010	0CAE55	8106 500444	VASILIY ANTONOV	{"phone": "+70039434451"}
0005433151011	3871FA	7846 733942	YAROSLAV KAZAKOV	{"email": "kazakov.y.07081971@postgrespro.ru", "phone": "+70003776589"}
0005433151012	3871FA	2981 720506	ARTUR IVANOV	{"email": "ivanov-a1965@postgrespro.ru", "phone": "+70060939368"}
0005433151013	CBCEEC	0635 779809	NIKOLAY KUZMIN	{"email": "kuzminn_121957@postgrespro.ru", "phone": "+70996529294"}
0005433151014	63A502	8467 859811	IVAN NIKOLAEV	{"email": "i.nikolaev.26081967@postgrespro.ru", "phone": "+70564793635"}
0005433151015	63A502	6998 469030	SERGEY MOISEEV	{"phone": "+70408513308"}
0005433151184	1DC670	3202 057965	SERGEY KOZLOV	{"phone": "+70791678186"}
0005433151016	9E7810	2667 108157	MIKHAIL ROMANOV	{"email": "m_romanov.04071971@postgrespro.ru", "phone": "+70520329450"}
0005433151017	9599EC	9963 923852	INNA SOKOLOVA	{"email": "i-sokolova-02021976@postgrespro.ru", "phone": "+70202999098"}
0005433151018	9599EC	6964 570133	VYACHESLAV SMIRNOV	{"phone": "+70907453941"}
0005433151019	9599EC	4083 177154	NIKOLAY GERASIMOV	{"phone": "+70872416825"}
0005433151020	2A2A13	9791 854115	IRINA FOMINA	{"phone": "+70024598404"}
0005433151021	F33DBD	1668 068919	VENIAMIN YAKOVLEV	{"email": "yakovlev-v111971@postgrespro.ru", "phone": "+70379336970"}
0005433151022	8D766F	0189 034455	GENNADIY KUZMIN	{"phone": "+70755481205"}
0005433151023	BD4CFE	0342 650498	OLEG POPOV	{"phone": "+70955799540"}
0005433151024	9EB232	7236 654518	DMITRIY ORLOV	{"phone": "+70054594716"}
0005433151025	2FB322	2996 435859	PAVEL ABRAMOV	{"phone": "+70223041094"}
0005433151026	2FB322	7107 195646	ALEKSANDRA MASLOVA	{"email": "maslovaa091977@postgrespro.ru", "phone": "+70583057435"}
0005433151027	33CB5B	0582 588430	TATYANA DENISOVA	{"email": "denisova-t1978@postgrespro.ru", "phone": "+70915337896"}
0005433151028	35B999	5589 126808	NATALYA SCHERBAKOVA	{"email": "scherbakova_n.1976@postgrespro.ru", "phone": "+70413713172"}
0005433151029	E52D01	0162 839664	LYUDMILA DAVYDOVA	{"email": "lyudmila_davydova10011971@postgrespro.ru", "phone": "+70784616989"}
0005433151030	E52D01	0140 472277	KAMIL PETROV	{"email": "petrovkamil-04091980@postgrespro.ru", "phone": "+70905802498"}
0005433151031	9AC6D2	4871 579965	ALEKSANDR STEPANOV	{"phone": "+70419484627"}
0005433151032	6E1423	1557 287133	ILYA VLASOV	{"phone": "+70397243699"}
0005433151033	6E1423	7363 769144	GALINA NESTEROVA	{"phone": "+70882418952"}
0005433151034	795889	0525 170033	MARGARITA ANISIMOVA	{"email": "anisimova.m_27041987@postgrespro.ru", "phone": "+70685260226"}
0005433151035	FAC1D7	1353 958504	NATALIYA ANTONOVA	{"email": "antonova.n.10011965@postgrespro.ru", "phone": "+70782618367"}
0005433151036	E541B9	6561 968264	LARISA DAVYDOVA	{"phone": "+70862773621"}
0005433151037	34EE78	8100 613501	FEDOR MOISEEV	{"email": "moiseev-fedor.1978@postgrespro.ru", "phone": "+70136076433"}
0005433151038	34EE78	3968 612852	SOFYA SOROKINA	{"email": "sorokina-s02091970@postgrespro.ru", "phone": "+70272106734"}
0005433151039	8B1625	4959 741443	VLADIMIR PETROV	{"phone": "+70939257743"}
0005433151040	8E8B7F	3152 339768	PAVEL SOKOLOV	{"email": "pavel.sokolov.07081972@postgrespro.ru", "phone": "+70294679002"}
0005433151041	E72A00	5387 031745	ALEKSANDR ANDREEV	{"email": "a_andreev.031983@postgrespro.ru", "phone": "+70147728920"}
0005433151042	E72A00	9470 564032	ALEKSANDR CHERNOV	{"email": "aleksandrchernov-1988@postgrespro.ru", "phone": "+70242573379"}
0005433151043	E72A00	1673 234071	KONSTANTIN DMITRIEV	{"email": "konstantin_dmitriev1965@postgrespro.ru", "phone": "+70692947904"}
0005433151044	62971F	4825 196769	VLADIMIR AFANASEV	{"email": "afanasevvladimir1972@postgrespro.ru", "phone": "+70249977914"}
0005433151045	E1FB1B	1776 014747	NATALYA MAKAROVA	{"email": "makarovan031984@postgrespro.ru", "phone": "+70844759982"}
0005433151046	F86C5F	5350 940978	VALENTINA BELOVA	{"email": "belova-valentina_30071966@postgrespro.ru", "phone": "+70459754132"}
0005433151047	C66151	6144 913093	RAISA POTAPOVA	{"email": "potapova.raisa1961@postgrespro.ru", "phone": "+70169116908"}
0005433151048	C66151	3658 541439	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov.27011974@postgrespro.ru", "phone": "+70521114727"}
0005433151049	10FEA2	2812 562051	PAVEL MIRONOV	{"email": "mironov.p-1958@postgrespro.ru", "phone": "+70944509064"}
0005433151050	10FEA2	8169 535610	ALEKSANDR MOROZOV	{"email": "a_morozov.11081986@postgrespro.ru", "phone": "+70164742071"}
0005433151051	111A6B	8583 093249	VIKTOR MAKSIMOV	{"phone": "+70128754245"}
0005433151052	111A6B	3309 928868	IVAN KOROLEV	{"email": "ivan.korolev.1962@postgrespro.ru", "phone": "+70451322398"}
0005433151053	05B9BA	1836 981217	ALEKSEY ILIN	{"phone": "+70886099093"}
0005433151054	05B9BA	7335 622318	ALEKSANDRA KULIKOVA	{"phone": "+70694033130"}
0005433151055	61F22F	9733 655105	EKATERINA VOROBEVA	{"phone": "+70498745126"}
0005433151056	61F22F	2771 053500	GENNADIY DENISOV	{"phone": "+70819601047"}
0005433151057	61F22F	7896 081496	ALEKSANDR FOMIN	{"phone": "+70513040576"}
0005433151058	C202DB	6148 433886	ANTON DENISOV	{"phone": "+70550565115"}
0005433151059	C202DB	2292 939745	YULIYA ZHUKOVA	{"phone": "+70662005356"}
0005433151060	28056F	7436 689383	IGOR DENISOV	{"phone": "+70898350996"}
0005433151061	28056F	0419 179313	NATALYA ALEKSEEVA	{"phone": "+70194322914"}
0005433151062	975ACF	0148 499273	MARIYA ZAYCEVA	{"email": "mariya_zayceva.041975@postgrespro.ru", "phone": "+70018330585"}
0005433151063	0417ED	2847 494550	VALENTIN MELNIKOV	{"email": "v_melnikov.031969@postgrespro.ru", "phone": "+70882533212"}
0005433151064	29050E	4975 584084	VALENTIN BORISOV	{"email": "borisov.valentin.071972@postgrespro.ru", "phone": "+70561232793"}
0005433151065	0377E5	9802 928802	VERONIKA FROLOVA	{"email": "veronika-frolova_01061962@postgrespro.ru", "phone": "+70649646374"}
0005433151066	0377E5	3398 600522	MARIYA LEBEDEVA	{"email": "lebedevam_1979@postgrespro.ru", "phone": "+70101723008"}
0005433151067	2820D9	5151 269641	YURIY MIKHAYLOV	{"phone": "+70814482332"}
0005433151068	22BF06	6055 655672	YURIY ABRAMOV	{"phone": "+70056612507"}
0005433151069	C38DAB	1630 801159	SOFYA GORBUNOVA	{"email": "gorbunovasofya041981@postgrespro.ru", "phone": "+70858594335"}
0005433151070	F46666	9539 529570	KARINA PETROVA	{"email": "k.petrova_1969@postgrespro.ru", "phone": "+70579365293"}
0005433151071	F46666	3444 122370	DMITRIY CHERNOV	{"email": "chernov-d04041980@postgrespro.ru", "phone": "+70954566644"}
0005433151072	775157	7182 763393	SVETLANA MARTYNOVA	{"email": "s-martynova.12091976@postgrespro.ru", "phone": "+70336510816"}
0005433151073	B53AA9	1625 666737	ANDREY SOLOVEV	{"email": "a_solovev-02121958@postgrespro.ru", "phone": "+70409188156"}
0005433151074	B8A654	3873 759932	IRINA NOVIKOVA	{"email": "novikova_i-1976@postgrespro.ru", "phone": "+70883782497"}
0005433151075	FE760A	6198 007096	LYUBOV KUZNECOVA	{"email": "kuznecoval-11121970@postgrespro.ru", "phone": "+70035080710"}
0005433151076	FE760A	0564 207116	VALENTINA SOKOLOVA	{"email": "sokolovav.1979@postgrespro.ru", "phone": "+70989603979"}
0005433151077	D6F627	3082 962447	IRINA ANDREEVA	{"email": "andreeva_irina_041967@postgrespro.ru", "phone": "+70796013707"}
0005433151078	C96AC4	4645 124186	ELENA TARASOVA	{"phone": "+70068627021"}
0005433151079	F126FE	8325 974987	NADEZHDA KOLESNIKOVA	{"phone": "+70208066753"}
0005433151080	F126FE	4627 861898	SERGEY MARTYNOV	{"email": "martynov.s_091970@postgrespro.ru", "phone": "+70234831340"}
0005433151081	D521C6	8978 505769	DARYA FILIPPOVA	{"phone": "+70346948354"}
0005433151082	2B7F09	5992 177936	VYACHESLAV SEMENOV	{"phone": "+70168605035"}
0005433151083	2D51AB	8921 844961	PAVEL BARANOV	{"phone": "+70636837345"}
0005433151084	2D51AB	9227 049692	LARISA KAZAKOVA	{"email": "kazakova.larisa1976@postgrespro.ru", "phone": "+70141222197"}
0005433151085	A33830	8595 791120	INNA KUZMINA	{"phone": "+70900412155"}
0005433151086	A33830	3428 668900	OLGA ZHUKOVA	{"email": "zhukovao24021976@postgrespro.ru", "phone": "+70216058436"}
0005433151087	530894	6096 146973	ALEKSANDR IVANOV	{"phone": "+70888956213"}
0005433151088	530894	5767 575470	ALEKSANDRA KOROLEVA	{"phone": "+70965368746"}
0005433151089	530894	1373 265986	MATVEY KAZAKOV	{"email": "kazakovm.27031962@postgrespro.ru", "phone": "+70329274275"}
0005433151090	36E32F	9149 649150	MAKSIM STEPANOV	{"phone": "+70284925792"}
0005433151091	E87115	2934 460728	MARINA OSIPOVA	{"phone": "+70538016090"}
0005433151092	E87115	5308 843344	VLADIMIR KOZLOV	{"email": "kozlov.v_1978@postgrespro.ru", "phone": "+70926552029"}
0005433151093	098A2E	6778 419399	PETR TIKHONOV	{"email": "tikhonov-p-031980@postgrespro.ru", "phone": "+70941867935"}
0005433151094	53A4A1	9594 907939	MAKSIM KRASNOV	{"phone": "+70372779972"}
0005433151095	85D6CE	1147 699696	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr_1980@postgrespro.ru", "phone": "+70976733698"}
0005433151096	308292	2321 027573	ALBINA FROLOVA	{"email": "albina-frolova.1981@postgrespro.ru", "phone": "+70434420842"}
0005433151097	308292	9479 888306	BORIS GUSEV	{"phone": "+70770786490"}
0005433151098	B43394	2760 512340	NATALYA MIRONOVA	{"email": "mironovanatalya_03101971@postgrespro.ru", "phone": "+70494191615"}
0005433151099	B43394	0999 833636	NATALYA ISAEVA	{"email": "isaeva-natalya-081972@postgrespro.ru", "phone": "+70699990859"}
0005433151100	CBA7BA	0253 333207	VLADIMIR MARTYNOV	{"phone": "+70382412470"}
0005433151101	736783	3738 705142	RAVIL KUZMIN	{"email": "kuzminr-14031978@postgrespro.ru", "phone": "+70703099890"}
0005433151102	736783	5374 198799	LEV EGOROV	{"email": "egorovl_011965@postgrespro.ru", "phone": "+70323678637"}
0005433151103	5DD9E1	1946 283589	NADEZHDA MAKAROVA	{"email": "makarova-n.081976@postgrespro.ru", "phone": "+70901424604"}
0005433151104	DC2DF2	0989 773475	OLGA PETROVA	{"phone": "+70654072202"}
0005433151105	2E0828	1034 275688	DMITRIY BORISOV	{"email": "borisov_dmitriy1977@postgrespro.ru", "phone": "+70398314141"}
0005433151106	2E0828	9593 838205	NINA VOROBEVA	{"email": "vorobeva-n12121969@postgrespro.ru", "phone": "+70555363173"}
0005433151107	000735	0807 170434	LIDIYA RODIONOVA	{"email": "lrodionova-031956@postgrespro.ru", "phone": "+70067132917"}
0005433151108	2FC581	6834 175816	GALINA ZAKHAROVA	{"email": "zakharovagalina.081970@postgrespro.ru", "phone": "+70765979481"}
0005433151109	2FC581	0801 790618	LIDIYA PETROVA	{"phone": "+70803899145"}
0005433151110	81496A	5372 064184	LYUCIYA SOLOVEVA	{"email": "lyuciya.soloveva031977@postgrespro.ru", "phone": "+70832625985"}
0005433151111	B23B41	5280 853277	VALERIY KUZMIN	{"email": "v-kuzmin-1982@postgrespro.ru", "phone": "+70764321174"}
0005433151112	B40E3F	2835 476119	ANATOLIY MARTYNOV	{"email": "martynova.1967@postgrespro.ru", "phone": "+70932322704"}
0005433151113	B40E3F	4450 380043	KRISTINA KOMAROVA	{"email": "komarova-kristina081975@postgrespro.ru", "phone": "+70859038382"}
0005433151114	3CE257	2941 654796	LYUDMILA ARKHIPOVA	{"email": "arkhipova_l22081974@postgrespro.ru", "phone": "+70374918742"}
0005433151115	669882	9037 621994	ELENA IVANOVA	{"email": "ivanova.elena-07081965@postgrespro.ru", "phone": "+70177699365"}
0005433151116	669882	9753 142121	NIKOLAY CHERNOV	{"email": "chernov-n.101972@postgrespro.ru", "phone": "+70840250040"}
0005433151117	BDD47F	2089 218374	VIKTORIYA MAKSIMOVA	{"phone": "+70313839944"}
0005433151118	614DFC	2840 366134	ALEKSANDR FROLOV	{"phone": "+70887259943"}
0005433151119	296F1A	0548 902503	ALEKSANDR GORBUNOV	{"phone": "+70445082006"}
0005433151120	04EA5B	7501 148137	ARMEN ZAYCEV	{"email": "azaycev_01081979@postgrespro.ru", "phone": "+70142238911"}
0005433151121	04EA5B	1718 918329	SERGEY ZAKHAROV	{"phone": "+70201327341"}
0005433151122	04EA5B	4868 939037	VIKTOR ABRAMOV	{"email": "abramov-v.1967@postgrespro.ru", "phone": "+70180876452"}
0005433151123	2FAD51	1822 274470	STANISLAV KAZAKOV	{"email": "stanislavkazakov.01031975@postgrespro.ru", "phone": "+70447222827"}
0005433151124	6EC117	1861 605048	EKATERINA RODIONOVA	{"phone": "+70509665014"}
0005433151125	C3671A	5763 504665	NIKOLAY VLASOV	{"phone": "+70780181441"}
0005433151126	2334F9	4820 018100	VYACHESLAV ABRAMOV	{"phone": "+70952003190"}
0005433151127	2334F9	6674 215461	ELENA ILINA	{"email": "ilina_e.1971@postgrespro.ru", "phone": "+70716541510"}
0005433151128	41BDCD	6764 892148	YULIYA KONOVALOVA	{"email": "konovalova_yuliya-061969@postgrespro.ru", "phone": "+70628884919"}
0005433151129	41BDCD	5093 481212	KSENIYA ORLOVA	{"email": "kseniyaorlova.071983@postgrespro.ru", "phone": "+70988449463"}
0005433151130	B4E129	8025 910618	ANNA PETROVA	{"email": "petrovaanna-01091981@postgrespro.ru", "phone": "+70072009596"}
0005433151131	B4E129	9786 464003	VLADIMIR SOKOLOV	{"phone": "+70792710205"}
0005433151132	683127	7504 984318	IVAN AFANASEV	{"email": "afanasevivan-081972@postgrespro.ru", "phone": "+70076048862"}
0005433151133	051003	2891 207442	DARYA VOLKOVA	{"phone": "+70257153951"}
0005433151134	051003	5514 215915	VLADIMIR MELNIKOV	{"phone": "+70433796279"}
0005433151135	7DEE4E	0610 668564	ANNA ISAEVA	{"phone": "+70084793711"}
0005433151136	7DEE4E	9863 174515	EKATERINA ISAEVA	{"email": "isaeva_ekaterina-20061975@postgrespro.ru", "phone": "+70887540663"}
0005433151137	044FD8	1496 316196	TATYANA PAVLOVA	{"phone": "+70907679241"}
0005433151138	EC170F	0909 391186	YURIY KARPOV	{"phone": "+70285094394"}
0005433151139	17273D	0233 138363	VALENTINA NIKOLAEVA	{"phone": "+70416941906"}
0005433151140	4E9D63	4690 187372	ANNA TIMOFEEVA	{"email": "anna.timofeeva_1975@postgrespro.ru", "phone": "+70896766000"}
0005433151141	4E9D63	5954 548441	ELENA VASILEVA	{"email": "vasileva.elena.03031978@postgrespro.ru", "phone": "+70733652061"}
0005433151142	4E9D63	6251 542908	IGOR DENISOV	{"phone": "+70447817387"}
0005433151143	AF28A2	3276 000090	SERGEY AFANASEV	{"email": "s-afanasev_07091968@postgrespro.ru", "phone": "+70614718134"}
0005433151144	472A60	0512 861874	MIKHAIL SOROKIN	{"phone": "+70096041256"}
0005433151145	5C55FA	9753 933554	RUSLAN VASILEV	{"email": "vasilev_r-1972@postgrespro.ru", "phone": "+70347020597"}
0005433151146	5C55FA	5975 424321	POLINA YAKOVLEVA	{"phone": "+70566737105"}
0005433151147	7F7618	7569 533863	GALINA MIKHAYLOVA	{"email": "g_mikhaylova.071984@postgrespro.ru", "phone": "+70683374946"}
0005433151148	BD6775	5426 471360	SVETLANA KULIKOVA	{"phone": "+70959920922"}
0005433151149	326605	3251 886145	OLEG ISAEV	{"email": "o.isaev_1972@postgrespro.ru", "phone": "+70500563426"}
0005433151150	F384F6	2125 580118	MARINA ANTONOVA	{"phone": "+70185562085"}
0005433151151	AEE9F7	6735 223853	VLADIMIR FILIPPOV	{"email": "vladimir_filippov_1965@postgrespro.ru", "phone": "+70057477808"}
0005433151152	AEE9F7	5142 604752	NATALYA NESTEROVA	{"phone": "+70424329869"}
0005433151153	AEE9F7	1979 829513	OLGA KRASNOVA	{"phone": "+70498079972"}
0005433151154	046FD4	0460 115759	GALINA ABRAMOVA	{"phone": "+70651500546"}
0005433151155	046FD4	8231 209378	VYACHESLAV PAVLOV	{"email": "pavlov.vyacheslav1970@postgrespro.ru", "phone": "+70420523587"}
0005433151156	BE5397	8275 632601	SERGEY FROLOV	{"phone": "+70399419125"}
0005433151157	BE5397	6984 934142	NIKITA OSIPOV	{"phone": "+70110723224"}
0005433151158	52A940	1423 974781	MARINA MELNIKOVA	{"email": "melnikovamarina.061974@postgrespro.ru", "phone": "+70783805268"}
0005433151159	52A940	4292 071865	IREK SHEVCHENKO	{"phone": "+70341719014"}
0005433151160	CCAA76	4790 242772	ANNA FILATOVA	{"phone": "+70820387688"}
0005433151161	CCAA76	9751 165535	ROMAN KUDRYASHOV	{"phone": "+70613965496"}
0005433151162	F83BA4	5276 576859	MARIYA KOROLEVA	{"phone": "+70149228077"}
0005433151163	F83BA4	4265 351890	VYACHESLAV FOMIN	{"phone": "+70987854215"}
0005433151164	6ACCAC	8789 916343	NINA KUZMINA	{"email": "n.kuzmina_10121966@postgrespro.ru", "phone": "+70414332284"}
0005433151165	6ACCAC	3799 008519	ALEKSEY MARTYNOV	{"email": "a-martynov1962@postgrespro.ru", "phone": "+70069150064"}
0005433151166	BCCF3B	3365 037169	OLGA PETROVA	{"phone": "+70152671404"}
0005433151167	77D54D	9539 831528	YULIYA ZAKHAROVA	{"phone": "+70181254356"}
0005433151168	77D54D	9058 241368	ALEKSANDR POPOV	{"email": "popovaleksandr08071978@postgrespro.ru", "phone": "+70890001819"}
0005433151169	221B9F	5540 989141	KONSTANTIN ISAEV	{"email": "kisaev.1967@postgrespro.ru", "phone": "+70142500461"}
0005433151170	860527	3019 088265	ELVIRA GERASIMOVA	{"phone": "+70189551040"}
0005433151171	827686	2846 608253	SERGEY KUZMIN	{"email": "kuzmin_sergey_1976@postgrespro.ru", "phone": "+70727873468"}
0005433151172	3CB430	5284 866956	SERGEY AFANASEV	{"email": "afanasev-sergey1965@postgrespro.ru", "phone": "+70600307453"}
0005433151173	3CB430	9953 009597	MIKHAIL PAVLOV	{"email": "pavlovmikhail.031975@postgrespro.ru", "phone": "+70002119267"}
0005433151174	8B47F4	6452 403945	MARGARITA SOKOLOVA	{"email": "sokolovamargarita.05071969@postgrespro.ru", "phone": "+70271551931"}
0005433151175	7595C3	5330 475766	ALEKSEY ILIN	{"phone": "+70487013742"}
0005433151176	884E8A	0711 758814	KLAVDIYA MELNIKOVA	{"phone": "+70313644802"}
0005433151177	884E8A	1095 788173	IGOR DENISOV	{"email": "i_denisov-1970@postgrespro.ru", "phone": "+70912035160"}
0005433151178	F8B53D	5868 441079	ELENA TARASOVA	{"email": "tarasova_elena-24091972@postgrespro.ru", "phone": "+70034175554"}
0005433151179	9F41F8	4105 091834	VLADLEN GERASIMOV	{"email": "v_gerasimov-061981@postgrespro.ru", "phone": "+70989217413"}
0005433151180	061D5D	4473 648295	ANDREY TIMOFEEV	{"email": "timofeevandrey.1974@postgrespro.ru", "phone": "+70066261651"}
0005433151181	75C69D	8495 468118	ALEKSANDR MEDVEDEV	{"email": "aleksandr-medvedev_1969@postgrespro.ru", "phone": "+70945498835"}
0005433151182	769376	2640 590796	ANNA POPOVA	{"email": "popova.anna.081970@postgrespro.ru", "phone": "+70315451090"}
0005433151183	1DC670	4017 346002	VITALIY KUZNECOV	{"email": "vkuznecov-1968@postgrespro.ru", "phone": "+70530838524"}
0005433151185	689779	2316 683764	OLEG VOROBEV	{"phone": "+70704201873"}
0005433151186	D21AA4	3109 781862	ANDREY SERGEEV	{"phone": "+70779928349"}
0005433151187	88215B	2397 844728	ALEKSANDR KARPOV	{"email": "aleksandr-karpov-01041972@postgrespro.ru", "phone": "+70527542558"}
0005433151188	88215B	2284 791189	GUZEL STEPANOVA	{"phone": "+70227625446"}
0005433151189	88215B	1503 605863	VALENTINA MARTYNOVA	{"email": "valentina_martynova-10041973@postgrespro.ru", "phone": "+70534748735"}
0005433151190	F4AA37	8032 163841	NATALYA VOLKOVA	{"phone": "+70508112905"}
0005433151191	B89366	3391 123171	BORIS FEDOROV	{"email": "boris_fedorov1960@postgrespro.ru", "phone": "+70934144641"}
0005433151192	95A2CC	5145 305463	GALINA KUZMINA	{"phone": "+70526426638"}
0005433151193	A09EC2	7737 314821	LYUBOV NIKITINA	{"email": "nikitina-lyubov_1969@postgrespro.ru", "phone": "+70701966342"}
0005433151194	65D93D	3345 056032	SVETLANA BELYAEVA	{"email": "svetlanabelyaeva18031973@postgrespro.ru", "phone": "+70935996057"}
0005433151195	83A974	3486 582071	IRINA KALININA	{"email": "kalininairina.101975@postgrespro.ru", "phone": "+70454449582"}
0005433151196	83A974	9358 329393	NIKOLAY PETROV	{"phone": "+70749019748"}
0005433151197	9A1C83	8851 171124	ANATOLIY KISELEV	{"email": "kiselev_a_05041967@postgrespro.ru", "phone": "+70136456309"}
0005433151198	C883DC	7453 436031	SERGEY SAVELEV	{"phone": "+70749428325"}
0005433151199	C883DC	7296 096015	ANDREY SIDOROV	{"phone": "+70290673632"}
0005433151200	721543	9242 880842	OLGA TIKHONOVA	{"phone": "+70201589611"}
0005433151201	721543	2152 794654	MIKHAIL ABRAMOV	{"phone": "+70041848839"}
0005433151202	7EC6C4	0608 045918	OLEG IVANOV	{"email": "ivanovo-21091983@postgrespro.ru", "phone": "+70316260284"}
0005433151203	BBC6C6	0988 955030	PAVEL MOROZOV	{"phone": "+70097306063"}
0005433151204	BBC6C6	2251 780042	MARIYA SEMENOVA	{"phone": "+70974105794"}
0005433151205	851A54	1317 048587	TAMARA LUKYANOVA	{"phone": "+70097977738"}
0005433151206	E2C815	4228 043064	ELENA ROMANOVA	{"phone": "+70940271534"}
0005433151207	EA481E	4115 010547	ALEKSANDR KUDRYASHOV	{"phone": "+70789246462"}
0005433151208	8E8BC7	3064 074947	EVGENIY SOROKIN	{"phone": "+70946212433"}
0005433151209	8E8BC7	9797 193307	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana_02011980@postgrespro.ru", "phone": "+70779109216"}
0005433151210	E0808B	4657 482309	MAKSIM KUZNECOV	{"email": "maksimkuznecov-041975@postgrespro.ru", "phone": "+70971653404"}
0005433151211	E0808B	1029 585224	ANATOLIY SHEVCHENKO	{"phone": "+70793459267"}
0005433151212	6E553C	3443 802357	NATALYA IVANOVA	{"phone": "+70865297422"}
0005433151213	E6E026	1118 288746	DMITRIY KAZAKOV	{"email": "dmitriy-kazakov_1975@postgrespro.ru", "phone": "+70778016248"}
0005433151214	9A41BC	2521 236211	GENNADIY MELNIKOV	{"email": "gennadiy.melnikov.20121967@postgrespro.ru", "phone": "+70253056059"}
0005433151215	D68C67	3341 520149	ANDREY MOISEEV	{"email": "moiseev.andrey_1973@postgrespro.ru", "phone": "+70507074884"}
0005433151216	D68C67	3007 138462	EKATERINA IVANOVA	{"email": "ivanova.ekaterina_121973@postgrespro.ru", "phone": "+70887494399"}
0005433151217	B93DEA	9874 856085	LYUBOV MEDVEDEVA	{"email": "l.medvedeva.1963@postgrespro.ru", "phone": "+70528745935"}
0005433151218	B93DEA	6477 294724	VIKTOR POPOV	{"email": "popov.viktor_071975@postgrespro.ru", "phone": "+70993960328"}
0005433151219	10126B	0951 160955	KIRILL AFANASEV	{"email": "afanasev_k_121991@postgrespro.ru", "phone": "+70176590747"}
0005433151220	10126B	5723 601898	SVETLANA NESTEROVA	{"email": "nesterova.s-061966@postgrespro.ru", "phone": "+70956934591"}
0005433151221	EE41A0	1913 533564	ANNA KALININA	{"phone": "+70016065389"}
0005433151222	2840FA	0877 256394	IVAN SIDOROV	{"email": "sidorovi.03081971@postgrespro.ru", "phone": "+70651023630"}
0005433151223	E31BA9	8861 889809	VALENTINA ROMANOVA	{"email": "vromanova.1970@postgrespro.ru", "phone": "+70353353610"}
0005433151224	A54324	9978 554232	VIKTORIYA SOLOVEVA	{"phone": "+70620541825"}
0005433151225	B9C01D	5602 267653	GENNADIY SMIRNOV	{"phone": "+70831074135"}
0005433151226	26F47B	7748 616663	YAROSLAV PAVLOV	{"email": "yaroslav-pavlov-061968@postgrespro.ru", "phone": "+70730834452"}
0005433151227	97B9DB	3515 206573	OLEG SOLOVEV	{"phone": "+70708547981"}
0005433151228	B9EA80	4202 190968	IRINA NIKITINA	{"email": "irina.nikitina-12051970@postgrespro.ru", "phone": "+70104979390"}
0005433151229	B9EA80	6079 016731	MARIYA SCHERBAKOVA	{"phone": "+70814556775"}
0005433151230	F6A68B	0514 569258	GENNADIY MIRONOV	{"email": "mironov.g121957@postgrespro.ru", "phone": "+70882529807"}
0005433151231	403055	2936 089689	VLADIMIR KARPOV	{"email": "karpovvladimir_1985@postgrespro.ru", "phone": "+70980234781"}
0005433151232	45D317	2529 396411	IGOR IVANOV	{"email": "igorivanov30061980@postgrespro.ru", "phone": "+70342131032"}
0005433151233	637074	8844 052960	DMITRIY MAKAROV	{"email": "dmakarov_111984@postgrespro.ru", "phone": "+70755998913"}
0005433151234	637074	7406 801573	YURIY ZAYCEV	{"phone": "+70548267246"}
0005433151235	2AE3B8	6898 621592	VERA ZAYCEVA	{"email": "zayceva-vera1983@postgrespro.ru", "phone": "+70930932346"}
0005433151236	D26927	7334 346461	MARIYA BELOVA	{"email": "belova_mariya_011975@postgrespro.ru", "phone": "+70790924197"}
0005433151237	7E94BE	9128 381406	NATALYA NIKOLAEVA	{"email": "nikolaeva-n.18081961@postgrespro.ru", "phone": "+70697298153"}
0005433151238	7E94BE	6035 577826	RAISA TARASOVA	{"email": "rtarasova1968@postgrespro.ru", "phone": "+70840008520"}
0005433151239	915A48	7253 097561	KARINA IVANOVA	{"email": "ivanovakarina_051972@postgrespro.ru", "phone": "+70187423839"}
0005433151240	BFC56F	1571 526691	DIANA ZAYCEVA	{"email": "zayceva.d01111981@postgrespro.ru", "phone": "+70176850054"}
0005433151241	537CAD	4416 201843	EKATERINA KOROLEVA	{"email": "ekaterina-koroleva1977@postgrespro.ru", "phone": "+70486252459"}
0005433151242	537CAD	1108 046965	ANASTASIYA ZAYCEVA	{"email": "a.zayceva_011973@postgrespro.ru", "phone": "+70185760379"}
0005433151243	352BDA	4739 578323	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev111974@postgrespro.ru", "phone": "+70134804660"}
0005433151244	352BDA	0945 155140	NADEZHDA YAKOVLEVA	{"phone": "+70046310405"}
0005433151245	DDC7D1	9706 070264	ANGELINA NOVIKOVA	{"phone": "+70296850739"}
0005433151246	AFC61C	6143 374123	VERA KOZLOVA	{"phone": "+70844485739"}
0005433151247	29197A	3995 421014	VADIM SEMENOV	{"phone": "+70321742438"}
0005433151248	8E617D	8475 958410	OKSANA KOLESNIKOVA	{"email": "kolesnikova.o_12051987@postgrespro.ru", "phone": "+70985423267"}
0005433151249	BA2AD0	2313 036218	GENNADIY POPOV	{"phone": "+70228888786"}
0005433151250	BA2AD0	7206 033744	VIKTOR CHERNOV	{"email": "chernov-v_08091975@postgrespro.ru", "phone": "+70878869304"}
0005433151251	52C4EB	5188 546823	IRINA GERASIMOVA	{"email": "gerasimovairina011962@postgrespro.ru", "phone": "+70632016829"}
0005433151252	BC789A	0290 374751	GALINA LUKYANOVA	{"email": "g_lukyanova011972@postgrespro.ru", "phone": "+70654838111"}
0005433151253	91BB92	2314 026951	ELENA KALININA	{"phone": "+70505480767"}
0005433151254	91BB92	4808 828315	VADIM MAKAROV	{"email": "makarov-v.021979@postgrespro.ru", "phone": "+70659562124"}
0005433151255	FD4DEB	2372 901631	GENNADIY KUZMIN	{"email": "kuzmin_gennadiy.1979@postgrespro.ru", "phone": "+70677245615"}
0005433151256	FD4DEB	1670 267918	EVGENIY KUZMIN	{"email": "e_kuzmin_23081978@postgrespro.ru", "phone": "+70211513229"}
0005433151257	B962C3	8637 219808	VASILIY IVANOV	{"email": "ivanov-vasiliy1979@postgrespro.ru", "phone": "+70465117801"}
0005433151258	FB81B8	2468 936464	ANDREY IVANOV	{"email": "ivanov-a.26081964@postgrespro.ru", "phone": "+70137570529"}
0005433151259	31037E	2594 107522	NIKITA SOLOVEV	{"phone": "+70260646989"}
0005433151260	36F9BB	6522 351001	EGOR SCHERBAKOV	{"email": "egor_scherbakov-1962@postgrespro.ru", "phone": "+70371008083"}
0005433151261	6DC1CB	8897 803866	IVAN KULIKOV	{"phone": "+70056518203"}
0005433151262	6DC1CB	3893 074053	OLEG MARTYNOV	{"phone": "+70973938390"}
0005433151263	BE5BED	5958 357295	IRINA KONDRATEVA	{"phone": "+70941366623"}
0005433151264	BE5BED	7794 463123	NINA PAVLOVA	{"phone": "+70275192145"}
0005433151265	0D8214	3647 465730	VIKTORIYA VLASOVA	{"email": "viktoriya_vlasova_16111963@postgrespro.ru", "phone": "+70415949335"}
0005433151266	E3C751	4620 503502	PAVEL NAZAROV	{"email": "pavel.nazarov_28021965@postgrespro.ru", "phone": "+70159382511"}
0005433151267	F604D9	0923 213708	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy.061975@postgrespro.ru", "phone": "+70840489486"}
0005433151268	F604D9	0241 048372	SVETLANA FADEEVA	{"phone": "+70588646951"}
0005433151269	02562A	7675 945227	MARINA OSIPOVA	{"email": "osipova.marina.061974@postgrespro.ru", "phone": "+70389268135"}
0005433151270	F28171	6813 065486	EVGENIY PETROV	{"email": "e_petrov-1966@postgrespro.ru", "phone": "+70935579846"}
0005433151271	F28171	4556 315871	GALINA NAZAROVA	{"email": "nazarova_g_08091974@postgrespro.ru", "phone": "+70540298360"}
0005433151272	C56CCF	6692 113961	MARIYA SOKOLOVA	{"phone": "+70842899061"}
0005433151273	C56CCF	3826 582786	AZAT ANDREEV	{"phone": "+70050937154"}
0005433151274	C4F062	6670 476701	ANATOLIY MOISEEV	{"phone": "+70531567922"}
0005433151275	608046	0979 878552	ALEKSEY PAVLOV	{"phone": "+70205453402"}
0005433151276	608046	3144 024296	VLADLEN AFANASEV	{"phone": "+70640574162"}
0005433151277	A64211	9810 395943	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.081973@postgrespro.ru", "phone": "+70724531123"}
0005433151278	DC720D	1938 028865	ALEKSEY SAVELEV	{"phone": "+70806015665"}
0005433151279	4E23F6	2142 528543	ELENA GERASIMOVA	{"phone": "+70705701732"}
0005433151280	D0EBE4	9452 989405	DMITRIY YAKOVLEV	{"phone": "+70497264619"}
0005433151281	D0EBE4	3307 083364	PAVEL ANDREEV	{"phone": "+70880919702"}
0005433151282	A7C077	7963 978236	OLGA KARPOVA	{"email": "karpova-olga1983@postgrespro.ru", "phone": "+70765458670"}
0005433151283	2D52F1	9130 033203	GALINA FEDOROVA	{"phone": "+70303321450"}
0005433151284	2D52F1	3540 325433	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov_14111979@postgrespro.ru", "phone": "+70778658110"}
0005433151285	2D52F1	8228 575614	SERGEY FOMIN	{"email": "fomin-sergey111969@postgrespro.ru", "phone": "+70941072999"}
0005433151286	551B62	1871 563686	VLADIMIR ILIN	{"email": "vilin.1972@postgrespro.ru", "phone": "+70205260379"}
0005433151287	54400F	0950 107179	LARISA IVANOVA	{"phone": "+70281740184"}
0005433151288	809711	3205 351661	TATYANA FEDOROVA	{"email": "fedorova.t1972@postgrespro.ru", "phone": "+70737593598"}
0005433151289	FD78A6	4398 989225	ALINA VLASOVA	{"phone": "+70893698131"}
0005433151290	FD78A6	6429 759410	VIKTOR TARASOV	{"email": "viktor.tarasov-17051971@postgrespro.ru", "phone": "+70520290831"}
0005433151291	4DC591	2950 036359	ANNA GRISHINA	{"phone": "+70755503921"}
0005433151292	4F91F9	4265 088619	ALEKSANDRA PETROVA	{"email": "aleksandra.petrova1986@postgrespro.ru", "phone": "+70700337314"}
0005433151293	FA6E9D	6971 932835	NIKOLAY ANTONOV	{"email": "antonov_nikolay_1973@postgrespro.ru", "phone": "+70850532524"}
0005433151294	A82FDA	1133 527167	AMINA EFIMOVA	{"email": "efimova-a_091978@postgrespro.ru", "phone": "+70107205624"}
0005433151295	AB8147	4901 710600	VLADISLAV DENISOV	{"phone": "+70010293601"}
0005433151296	C2E3D2	7968 617570	VALERIY KOZLOV	{"email": "kozlov-valeriy.1985@postgrespro.ru", "phone": "+70535635987"}
0005433151297	C2E3D2	5909 606522	MARIYA GORBUNOVA	{"phone": "+70161859999"}
0005433151298	3BC21B	3754 198766	ANDREY ISAEV	{"email": "a-isaev1973@postgrespro.ru", "phone": "+70472288274"}
0005433151299	3BC21B	6677 865812	MADINA SEMENOVA	{"phone": "+70481890328"}
0005433151300	3BC21B	7386 077207	NIKOLAY STEPANOV	{"phone": "+70163002736"}
0005433151301	431B50	3998 845138	ALEKSEY NAZAROV	{"email": "a-nazarov26041974@postgrespro.ru", "phone": "+70498665562"}
0005433151302	BD4A44	1110 957827	IRINA KRASNOVA	{"email": "irina_krasnova-04041980@postgrespro.ru", "phone": "+70316432299"}
0005433151303	BD4A44	9794 731506	ILYA ZHUKOV	{"email": "ilya-zhukov051974@postgrespro.ru", "phone": "+70336879363"}
0005433151304	BD4A44	5871 163563	ANTON KUZNECOV	{"email": "kuznecovanton_1963@postgrespro.ru", "phone": "+70054744286"}
0005433151305	6A0135	6130 366996	GALINA POPOVA	{"phone": "+70389533334"}
0005433151306	5522A4	6792 191036	GALINA TIKHONOVA	{"phone": "+70564875976"}
0005433151307	24E44C	9820 681541	VIKTORIYA TIKHONOVA	{"phone": "+70556077798"}
0005433151308	24E44C	8800 674751	LYUDMILA YAKOVLEVA	{"email": "lyudmila_yakovleva-24021970@postgrespro.ru", "phone": "+70981589602"}
0005433151309	6D1A86	8401 376128	RAMIL FROLOV	{"email": "frolov.ramil041983@postgrespro.ru", "phone": "+70961688885"}
0005433151310	6E5881	6665 727775	OLGA TARASOVA	{"email": "otarasova.111971@postgrespro.ru", "phone": "+70848446502"}
0005433151311	C80009	5055 448682	VLADIMIR FILIPPOV	{"email": "v.filippov_061970@postgrespro.ru", "phone": "+70607131266"}
0005433151312	B144AB	1480 373244	TATYANA GERASIMOVA	{"phone": "+70708388011"}
0005433151313	5A5C07	5194 161396	ALENA ZHURAVLEVA	{"phone": "+70181704061"}
0005433151314	932BB3	2195 352675	SVETLANA SOROKINA	{"email": "s-sorokina_26061978@postgrespro.ru", "phone": "+70111642884"}
0005433151315	655EBA	9389 207615	GENNADIY KOZLOV	{"email": "kozlov_gennadiy_11061973@postgrespro.ru", "phone": "+70974281587"}
0005433151316	024EC0	5327 753284	VLADIMIR MIRONOV	{"phone": "+70538760511"}
0005433151317	024EC0	5129 670694	ANTON DMITRIEV	{"phone": "+70038160055"}
0005433151318	416EEA	3724 165037	EDUARD TIKHONOV	{"phone": "+70588446874"}
0005433151319	09A3B2	3968 252536	YULIYA MIKHAYLOVA	{"phone": "+70029252503"}
0005433151320	9ACB1C	7427 293355	VIKTORIYA OVCHINNIKOVA	{"email": "ovchinnikovaviktoriya_1969@postgrespro.ru", "phone": "+70267244667"}
0005433151321	4FB325	1016 206462	ALEKSANDR IVANOV	{"phone": "+70050087616"}
0005433151322	4FB325	5158 049384	KRISTINA DAVYDOVA	{"phone": "+70609605633"}
0005433151323	208866	3576 184969	OLEG NIKITIN	{"email": "nikitino02111975@postgrespro.ru", "phone": "+70927205581"}
0005433151324	C88A10	7730 834714	EVGENIYA FEDOROVA	{"phone": "+70355185228"}
0005433151325	C88A10	2690 085547	ELENA KUZNECOVA	{"email": "kuznecova-elena-121970@postgrespro.ru", "phone": "+70488023381"}
0005433151326	C88A10	7077 112889	ALFIYA VASILEVA	{"phone": "+70988207638"}
0005433151327	57B8C5	8542 986027	TATYANA ANDREEVA	{"email": "t_andreeva1964@postgrespro.ru", "phone": "+70262657513"}
0005433151328	57B8C5	3302 837249	EKATERINA NIKOLAEVA	{"email": "nikolaevaekaterina.12111975@postgrespro.ru", "phone": "+70369054373"}
0005433151329	EE342D	0369 487115	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev.021973@postgrespro.ru", "phone": "+70238483318"}
0005433151330	EE342D	8232 650194	RAMIL FEDOROV	{"email": "fedorovr1977@postgrespro.ru", "phone": "+70820021190"}
0005433151331	829BBF	3885 802890	ALEKSANDR POPOV	{"email": "aleksandrpopov_091978@postgrespro.ru", "phone": "+70659806031"}
0005433151332	38DE96	5244 711534	VASILIY MAKAROV	{"email": "vasiliy_makarov_01101980@postgrespro.ru", "phone": "+70930877762"}
0005433151333	F7F60A	5711 071376	GALINA DAVYDOVA	{"phone": "+70195449440"}
0005433151334	F7F60A	0653 422772	ZOYA KOVALEVA	{"phone": "+70339773321"}
0005433151335	85FA19	9657 281695	ANDREY SEMENOV	{"email": "andrey.semenov08051983@postgrespro.ru", "phone": "+70543013502"}
0005433151336	757B27	2759 757229	YULIYA BOGDANOVA	{"email": "y_bogdanova-1977@postgrespro.ru", "phone": "+70624415393"}
0005433151337	757B27	1967 447234	ANTONINA POPOVA	{"phone": "+70491803486"}
0005433151338	EEAFA7	2853 340171	VLADIMIR ISAEV	{"email": "isaev_v-011967@postgrespro.ru", "phone": "+70906915839"}
0005433151339	E7C5C6	1134 339179	YURIY NIKOLAEV	{"phone": "+70149241401"}
0005433151340	E7C5C6	8447 478829	LYUDMILA AKIMOVA	{"email": "l.akimova_071960@postgrespro.ru", "phone": "+70313523079"}
0005433151341	EC2DEC	8638 686826	VYACHESLAV TARASOV	{"email": "vyacheslav.tarasov.14101978@postgrespro.ru", "phone": "+70948414309"}
0005433151342	0EED89	2329 421592	PETR NIKOLAEV	{"phone": "+70169969018"}
0005433151343	8D158A	8866 619226	ANTONINA SOROKINA	{"phone": "+70231761483"}
0005433151344	8D158A	1977 436101	ALEKSEY ABRAMOV	{"phone": "+70600439615"}
0005433151345	8D158A	6390 631692	DENIS STEPANOV	{"email": "stepanovdenis-05041974@postgrespro.ru", "phone": "+70394113098"}
0005433151346	5357C7	6422 951941	MARINA GRISHINA	{"email": "grishinamarina.23011972@postgrespro.ru", "phone": "+70140637032"}
0005433151347	E5AA87	2172 766682	IRINA SEMENOVA	{"email": "i.semenova.1972@postgrespro.ru", "phone": "+70120718069"}
0005433151348	E5AA87	7545 584969	NIKITA KUZMIN	{"phone": "+70943498345"}
0005433151349	93010D	1640 342018	MAKSIM NIKITIN	{"phone": "+70853872697"}
0005433151350	0B32DB	1438 418903	OLGA SOLOVEVA	{"phone": "+70171679192"}
0005433151351	9AE92D	7301 205177	ILYA SHEVCHENKO	{"phone": "+70909446551"}
0005433151352	E2C427	2648 285866	SERGEY KUZNECOV	{"email": "kuznecov.sergey-1969@postgrespro.ru", "phone": "+70220017245"}
0005433151353	FB4635	2294 912649	VLADIMIR SOLOVEV	{"email": "vsolovev-051968@postgrespro.ru", "phone": "+70763236236"}
0005433151354	FB4635	0031 682306	IVAN VOLKOV	{"email": "i.volkov_031960@postgrespro.ru", "phone": "+70716861850"}
0005433151355	F1A88A	1900 046668	DANIIL MAKAROV	{"phone": "+70818702134"}
0005433151356	F1A88A	3660 005691	OLGA VASILEVA	{"email": "vasileva-olga061972@postgrespro.ru", "phone": "+70293477524"}
0005433151357	9E4F87	2789 255302	ALEKSANDRA NESTEROVA	{"email": "aleksandranesterova_01071969@postgrespro.ru", "phone": "+70478051210"}
0005433151358	7267E1	6637 005352	TATYANA ZAYCEVA	{"phone": "+70287185445"}
0005433151359	66E3C1	1212 122342	DARYA MIKHAYLOVA	{"phone": "+70314406923"}
0005433151360	3A8627	3691 952848	MIKHAIL PAVLOV	{"email": "pavlov_m_1976@postgrespro.ru", "phone": "+70205683064"}
0005433151361	ED0946	3374 446139	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova_14071971@postgrespro.ru", "phone": "+70391168265"}
0005433151362	3F5CA4	4965 093275	ANATOLIY KUZNECOV	{"email": "a_kuznecov1979@postgrespro.ru", "phone": "+70726006597"}
0005433151363	9E0277	4405 904030	PAVEL SMIRNOV	{"phone": "+70082683091"}
0005433151364	9E0277	4402 274791	ARTEM VASILEV	{"phone": "+70779662430"}
0005433151365	9E0277	5485 033777	MARIYA KUZMINA	{"email": "kuzminamariya.12121973@postgrespro.ru", "phone": "+70436127129"}
0005433151366	B5FA81	4656 018563	YURIY AFANASEV	{"phone": "+70173385441"}
0005433151367	060D20	5542 278135	EKATERINA ILINA	{"email": "ilina_e1976@postgrespro.ru", "phone": "+70079998750"}
0005433151368	FEC640	9501 071725	GALINA RYABOVA	{"phone": "+70337385883"}
0005433151369	FEC640	7280 074040	DMITRIY ABRAMOV	{"phone": "+70680711483"}
0005433151370	15FFD8	1385 367960	ALEKSEY YAKOVLEV	{"phone": "+70150029670"}
0005433151371	15FFD8	7876 726056	YURIY VOLKOV	{"phone": "+70494189715"}
0005433151372	E2F5E0	0482 865619	LIDIYA IVANOVA	{"phone": "+70300357534"}
0005433151373	204CA3	9547 773740	DMITRIY MIKHAYLOV	{"phone": "+70957554473"}
0005433151374	781830	0773 530497	OLGA SERGEEVA	{"email": "osergeeva-121967@postgrespro.ru", "phone": "+70743534685"}
0005433151375	C8C34E	4986 079760	ANATOLIY KARPOV	{"email": "a_karpov-091973@postgrespro.ru", "phone": "+70125872393"}
0005433151376	5E78E8	7933 304805	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev-1969@postgrespro.ru", "phone": "+70404717979"}
0005433151377	79CC32	2834 204966	NINA AFANASEVA	{"phone": "+70165028866"}
0005433151378	594630	6711 696135	ANNA ABRAMOVA	{"email": "abramova.a091968@postgrespro.ru", "phone": "+70968880683"}
0005433151379	A7064E	7300 001909	VIKTOR KONOVALOV	{"phone": "+70675733033"}
0005433151380	CAE3B7	6870 611051	EVGENIY ISAEV	{"phone": "+70288511263"}
0005433151381	9FC9AF	2621 013329	VALERIY DAVYDOV	{"email": "davydov-v-1965@postgrespro.ru", "phone": "+70606289564"}
0005433151382	9FC9AF	8110 675330	DANIIL ZAYCEV	{"email": "d.zaycev_1984@postgrespro.ru", "phone": "+70733358724"}
0005433151383	3467F6	7763 605147	ARTEM SOKOLOV	{"phone": "+70674799473"}
0005433151384	DE1E77	7530 403537	KONSTANTIN MARTYNOV	{"phone": "+70066714831"}
0005433151385	CCEB6A	5580 379304	YULIYA KOMAROVA	{"email": "komarova.yuliya_1979@postgrespro.ru", "phone": "+70139550248"}
0005433151386	547473	5878 266540	VYACHESLAV SERGEEV	{"phone": "+70309198034"}
0005433151387	7DECC0	0205 684630	MAKSIM ANDREEV	{"email": "andreev.m.1973@postgrespro.ru", "phone": "+70217900359"}
0005433151388	7DECC0	7890 001480	ANASTASIYA MIRONOVA	{"email": "mironova.a.22121967@postgrespro.ru", "phone": "+70431287546"}
0005433151389	FDA57E	4158 525688	VLADIMIR ANDREEV	{"email": "andreev_vladimir_021976@postgrespro.ru", "phone": "+70347896448"}
0005433151390	15C9BE	1697 844602	DANIIL SOLOVEV	{"email": "daniil-solovev-1978@postgrespro.ru", "phone": "+70055442214"}
0005433151391	CC049A	8874 986565	ALEKSANDR ORLOV	{"phone": "+70572416726"}
0005433151392	95A17B	2774 582868	KLAVDIYA SERGEEVA	{"email": "klavdiya-sergeeva071977@postgrespro.ru", "phone": "+70017471434"}
0005433151393	76126B	7148 203836	ANGELINA VOROBEVA	{"email": "avorobeva-111967@postgrespro.ru", "phone": "+70364091477"}
0005433151394	5E3DCA	2847 915374	ALEKSEY ALEKSEEV	{"phone": "+70637533109"}
0005433151395	018E6A	8106 494180	EVGENIY VOLKOV	{"email": "volkov.e-12041973@postgrespro.ru", "phone": "+70454731322"}
0005433151396	F6B90A	8356 580761	VLADIMIR YAKOVLEV	{"phone": "+70591134340"}
0005433151397	F16398	3679 912273	NIKOLAY VLASOV	{"phone": "+70937940269"}
0005433151398	F16398	7226 307044	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr-111974@postgrespro.ru", "phone": "+70340974463"}
0005433151399	F16398	0244 153526	OLEG MIRONOV	{"email": "mironov_oleg.22041973@postgrespro.ru", "phone": "+70019331051"}
0005433151400	0539C3	5987 618614	ELDAR GORBUNOV	{"phone": "+70607398361"}
0005433151401	0539C3	5030 167717	ANNA TARASOVA	{"phone": "+70360193104"}
0005433151402	4CBC6B	8621 937819	ELENA FOMINA	{"phone": "+70157125999"}
0005433151403	26A4C2	8477 690491	ALEKSANDR ZHUKOV	{"email": "zhukov-a.061963@postgrespro.ru", "phone": "+70095952826"}
0005433151404	BC5CBC	2414 046370	MARIYA RYABOVA	{"phone": "+70764482789"}
0005433151405	BC5CBC	2298 712022	NADEZHDA LUKYANOVA	{"email": "lukyanova-nadezhda_051976@postgrespro.ru", "phone": "+70919178722"}
0005433151406	0104AD	9643 153918	TAMARA EFIMOVA	{"phone": "+70743541210"}
0005433151407	318F65	2864 302767	ALEKSEY VASILEV	{"email": "vasilevaleksey.011976@postgrespro.ru", "phone": "+70167784096"}
0005433151408	253BA7	5981 691912	SVETLANA GAVRILOVA	{"email": "gavrilova-s18101972@postgrespro.ru", "phone": "+70610509718"}
0005433151409	B72F99	2928 458172	VLADIMIR IVANOV	{"email": "ivanov.v021968@postgrespro.ru", "phone": "+70760636575"}
0005433151410	B72F99	0575 611578	VYACHESLAV MIRONOV	{"email": "vyacheslav-mironov.11101976@postgrespro.ru", "phone": "+70819005288"}
0005433151411	5F9F75	1644 531881	TATYANA ANISIMOVA	{"phone": "+70237612217"}
0005433151412	82CB32	8045 913577	NATALYA RYABOVA	{"email": "n_ryabova-30111963@postgrespro.ru", "phone": "+70147913037"}
0005433151413	3932EE	8130 343302	NIKOLAY ROMANOV	{"email": "romanov_n.121975@postgrespro.ru", "phone": "+70587548369"}
0005433151414	3932EE	7298 434286	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev.06071973@postgrespro.ru", "phone": "+70700453471"}
0005433151415	DF77D7	9855 557705	ANDREY STEPANOV	{"email": "stepanov.andrey.121982@postgrespro.ru", "phone": "+70633916612"}
0005433151416	DF77D7	1168 106511	VALENTINA NIKITINA	{"email": "nikitina-v_111970@postgrespro.ru", "phone": "+70064835152"}
0005433151417	DF77D7	5490 152355	MIKHAIL KOROLEV	{"email": "korolevm_121977@postgrespro.ru", "phone": "+70160918250"}
0005433151418	F53889	1553 670701	NIKOLAY SMIRNOV	{"email": "smirnov.n-08101979@postgrespro.ru", "phone": "+70557176223"}
0005433151419	F53889	0521 424162	SERGEY IVANOV	{"email": "ivanov-sergey_24011967@postgrespro.ru", "phone": "+70879731279"}
0005433151420	45D4E4	2580 179555	MARIYA DENISOVA	{"email": "m.denisova.12061980@postgrespro.ru", "phone": "+70021425482"}
0005433151421	F48DB8	5344 085993	ROMAN ZHUKOV	{"phone": "+70962322585"}
0005433151422	20934C	8829 234356	ANTONINA NOVIKOVA	{"email": "antonina.novikova19021970@postgrespro.ru", "phone": "+70053607358"}
0005433151423	20934C	9496 079549	LILIYA KAZAKOVA	{"email": "kazakova_l_091967@postgrespro.ru", "phone": "+70993557036"}
0005433151424	20934C	1919 373992	ILYA KUZNECOV	{"email": "kuznecov.ilya_27111972@postgrespro.ru", "phone": "+70200765755"}
0005433151425	20934C	7101 961083	DMITRIY SIDOROV	{"phone": "+70885919145"}
0005433151426	A7A4DB	6883 882923	VLADIMIR FEDOTOV	{"email": "fedotov_vladimir_30031982@postgrespro.ru", "phone": "+70821221709"}
0005433151427	A7A4DB	2893 907801	NINA TARASOVA	{"email": "tarasovanina.1967@postgrespro.ru", "phone": "+70824187601"}
0005433151428	0339F4	8650 942715	ANZHELA MOROZOVA	{"email": "amorozova-09121980@postgrespro.ru", "phone": "+70258628502"}
0005433151429	41854F	9570 478303	ANATOLIY ALEKSEEV	{"email": "alekseeva1965@postgrespro.ru", "phone": "+70182192392"}
0005433151430	8BAA6C	8021 518672	NIKITA KUZNECOV	{"phone": "+70654554224"}
0005433151431	8BAA6C	7318 341755	VITALIY STEPANOV	{"email": "stepanov.vitaliy-1974@postgrespro.ru", "phone": "+70655083215"}
0005433151432	8BAA6C	2163 615359	VYACHESLAV KULIKOV	{"phone": "+70702649919"}
0005433151433	783398	9314 208257	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr.1982@postgrespro.ru", "phone": "+70315057362"}
0005433151434	D506D6	4174 510946	VASILIY PAVLOV	{"phone": "+70745175327"}
0005433151435	8C201E	0999 465464	TATYANA EGOROVA	{"email": "egorova-tatyana03041981@postgrespro.ru", "phone": "+70541044214"}
0005433151436	4C6A72	9522 112520	YAROSLAV KUZMIN	{"email": "yaroslav-kuzmin-1988@postgrespro.ru", "phone": "+70308074448"}
0005433151437	3EEF31	3699 377838	OLESYA PETROVA	{"phone": "+70312128407"}
0005433151438	3EEF31	3381 884221	NATALYA NIKIFOROVA	{"phone": "+70074711876"}
0005433151439	1941F5	7881 536229	ALEKSANDR SOROKIN	{"phone": "+70172430483"}
0005433151440	5DC448	9655 093500	RUSLAN PAVLOV	{"phone": "+70142142705"}
0005433151441	464101	0833 020323	EKATERINA BARANOVA	{"email": "baranova.ekaterina_1959@postgrespro.ru", "phone": "+70598303820"}
0005433151442	464101	8321 876670	ALEKSANDR VOLKOV	{"phone": "+70067288991"}
0005433151443	435113	3610 052472	KLAVDIYA ISAEVA	{"email": "isaeva.k.101969@postgrespro.ru", "phone": "+70039575200"}
0005433151444	435113	2809 623322	ALEKSANDR NAZAROV	{"email": "a-nazarov091976@postgrespro.ru", "phone": "+70746930577"}
0005433151445	B76BCF	2271 139207	PAVEL ABRAMOV	{"phone": "+70773166138"}
0005433151446	F5924B	6671 070694	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana051979@postgrespro.ru", "phone": "+70399712449"}
0005433151447	07671B	8716 644115	MARINA SOROKINA	{"email": "sorokina-m26071974@postgrespro.ru", "phone": "+70378284614"}
0005433151448	B55386	3531 209806	SVETLANA MEDVEDEVA	{"email": "medvedeva.s_30061971@postgrespro.ru", "phone": "+70273729257"}
0005433151449	87BCD5	6739 233051	SERGEY VASILEV	{"email": "vasilevsergey.16061976@postgrespro.ru", "phone": "+70362168185"}
0005433151450	B5BD69	8741 506540	VALERIY SOROKIN	{"email": "sorokin-valeriy_27031978@postgrespro.ru", "phone": "+70156468102"}
0005433151451	B5BD69	9185 325091	VIKTOR MOROZOV	{"email": "morozov_v-011970@postgrespro.ru", "phone": "+70658670131"}
0005433151452	41FBFC	6001 802786	YULIYA KUZNECOVA	{"phone": "+70925242257"}
0005433151453	3DE73E	2742 801691	PETR ANTONOV	{"phone": "+70998829072"}
0005433151454	BE3C88	3835 876900	ELENA VOLKOVA	{"phone": "+70356738986"}
0005433151455	EF89D5	1743 302668	ALEKSEY DAVYDOV	{"phone": "+70273199092"}
0005433151456	1F90EE	8082 199667	VLADIMIR KUDRYASHOV	{"phone": "+70810293133"}
0005433151457	F1B025	4380 064449	ANDREY YAKOVLEV	{"email": "andrey.yakovlev_1972@postgrespro.ru", "phone": "+70687591420"}
0005433151458	CD2BB0	5222 403700	MARINA ANDREEVA	{"phone": "+70392702343"}
0005433151459	159E41	5119 546968	LYUDMILA OSIPOVA	{"phone": "+70734564657"}
0005433151460	159E41	5060 195192	LIDIYA SCHERBAKOVA	{"email": "scherbakova.l-05021988@postgrespro.ru", "phone": "+70115601936"}
0005433151461	CA41DA	8364 787100	ANDREY RODIONOV	{"email": "rodionov_a031980@postgrespro.ru", "phone": "+70330676446"}
0005433151462	8172F7	2233 606830	KONSTANTIN FEDOTOV	{"phone": "+70486460363"}
0005433151963	197163	2826 310673	VARVARA TARASOVA	{"phone": "+70807050977"}
0005433151463	8172F7	6310 275226	NATALYA NIKOLAEVA	{"email": "nikolaeva-n-05101977@postgrespro.ru", "phone": "+70501671206"}
0005433151464	F20203	4861 737592	ELENA CHERNOVA	{"phone": "+70818095995"}
0005433151465	3C9BF5	9000 453686	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov-031965@postgrespro.ru", "phone": "+70175430384"}
0005433151466	1417F5	5931 439221	DANILA STEPANOV	{"phone": "+70224947903"}
0005433151467	FC8FF6	2121 772708	IRINA IVANOVA	{"email": "i_ivanova-011976@postgrespro.ru", "phone": "+70171628226"}
0005433151468	FC8FF6	6075 709457	ANDREY SIDOROV	{"phone": "+70064225153"}
0005433151469	36B4A0	1133 339785	ANNA DMITRIEVA	{"email": "dmitrieva_anna_27021974@postgrespro.ru", "phone": "+70347476934"}
0005433151470	C9F0EC	6569 170977	ILDAR DMITRIEV	{"email": "ildardmitriev-27011962@postgrespro.ru", "phone": "+70174018987"}
0005433151471	C9F0EC	8395 081434	SVETLANA ANTONOVA	{"email": "antonova-s1966@postgrespro.ru", "phone": "+70158287922"}
0005433151472	C9F0EC	8582 859681	VERA ROMANOVA	{"phone": "+70879505510"}
0005433151473	F69613	0103 985896	NATALYA ORLOVA	{"email": "n.orlova.021969@postgrespro.ru", "phone": "+70482134021"}
0005433151474	F69613	4217 395137	IRINA KOVALEVA	{"email": "irina-kovaleva-111968@postgrespro.ru", "phone": "+70701236283"}
0005433151475	DCC9A0	9300 805227	SVETLANA KUZNECOVA	{"phone": "+70436999066"}
0005433151476	DCC9A0	1412 837376	TATYANA MIRONOVA	{"phone": "+70701709809"}
0005433151477	075C9A	1331 877435	ALEKSANDRA FEDOROVA	{"phone": "+70521146637"}
0005433151478	EC7376	6614 572165	VLADIMIR IVANOV	{"email": "ivanov-v-1965@postgrespro.ru", "phone": "+70642073787"}
0005433151479	7AC4D6	4226 121004	LYUBOV KOLESNIKOVA	{"phone": "+70486239836"}
0005433151480	CF4241	5768 262319	NATALYA SEMENOVA	{"email": "n.semenova.15061969@postgrespro.ru", "phone": "+70304750249"}
0005433151481	CF4241	7204 431316	IGOR ZAKHAROV	{"phone": "+70207883956"}
0005433151482	2125E9	6201 100631	ELENA ZAKHAROVA	{"email": "zakharova-elena-041970@postgrespro.ru", "phone": "+70299425448"}
0005433151483	34069E	2357 147556	LYUDMILA POPOVA	{"email": "popovalyudmila19021972@postgrespro.ru", "phone": "+70323617026"}
0005433151484	34069E	7812 520051	TATYANA ZAKHAROVA	{"email": "t_zakharova_05071971@postgrespro.ru", "phone": "+70892526231"}
0005433151485	C889FD	0916 431693	SERGEY AFANASEV	{"email": "afanasev_s-04111975@postgrespro.ru", "phone": "+70439073402"}
0005433151486	C889FD	4323 129118	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov.1971@postgrespro.ru", "phone": "+70167623472"}
0005433151487	010E06	4174 733333	ALEKSANDR ROMANOV	{"phone": "+70389993095"}
0005433151488	54C5EA	2510 133715	EKATERINA EFIMOVA	{"email": "efimovaekaterina-1978@postgrespro.ru", "phone": "+70374410832"}
0005433151489	54C5EA	8820 714788	VLADIMIR SOKOLOV	{"email": "v_sokolov.1980@postgrespro.ru", "phone": "+70713741566"}
0005433151490	51F525	1864 311446	NIKOLAY NIKOLAEV	{"phone": "+70060334209"}
0005433151491	1EAF06	2326 749486	ANDREY DENISOV	{"email": "denisov.andrey-22101967@postgrespro.ru", "phone": "+70253421737"}
0005433151492	7DA80A	3948 888080	MARSEL ANDREEV	{"phone": "+70149966130"}
0005433151493	DE6A9F	2511 774325	MARIYA KUDRYASHOVA	{"phone": "+70063875890"}
0005433151494	74ABAA	4096 115993	ELENA VOLKOVA	{"email": "volkova_e.101975@postgrespro.ru", "phone": "+70345238173"}
0005433151495	74ABAA	6603 037182	ANDREY MIKHAYLOV	{"phone": "+70669853144"}
0005433151496	FC5358	9002 197916	ILDAR MAKAROV	{"email": "makarov_ildar.1979@postgrespro.ru", "phone": "+70917302690"}
0005433151497	3C62CC	9972 481712	ANNA GERASIMOVA	{"phone": "+70866850238"}
0005433151498	3C62CC	2848 776394	OKSANA MARTYNOVA	{"phone": "+70800382300"}
0005433151499	151DF0	8229 085257	MIKHAIL ANDREEV	{"phone": "+70426327845"}
0005433151500	05E055	6917 176020	OLGA MOISEEVA	{"phone": "+70938639486"}
0005433151501	C7C0C5	9879 812860	YAKOV KISELEV	{"email": "kiselev.y-081969@postgrespro.ru", "phone": "+70723147204"}
0005433151502	C7C0C5	4157 696805	DANILA ALEKSANDROV	{"email": "danilaaleksandrov031974@postgrespro.ru", "phone": "+70446531704"}
0005433151503	CA4FBE	5041 409627	ANNA MARTYNOVA	{"email": "martynovaa_021968@postgrespro.ru", "phone": "+70422500410"}
0005433151504	CA4FBE	6456 025107	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov.1978@postgrespro.ru", "phone": "+70501305469"}
0005433151505	4F3236	1246 074130	IVAN VOLKOV	{"email": "i_volkov.101972@postgrespro.ru", "phone": "+70019270740"}
0005433151506	63AE19	3436 639006	ALEFTINA LEBEDEVA	{"email": "aleftinalebedeva.11081972@postgrespro.ru", "phone": "+70995291131"}
0005433151507	E24987	7571 131652	TATYANA EGOROVA	{"phone": "+70009754511"}
0005433151508	1A800D	6998 401900	MARAT GERASIMOV	{"phone": "+70352372036"}
0005433151509	6879DF	9496 307645	DENIS TIMOFEEV	{"email": "denis-timofeev29011972@postgrespro.ru", "phone": "+70343566089"}
0005433151510	7A6C7B	7210 313843	ANNA KONOVALOVA	{"email": "konovalova.a_111970@postgrespro.ru", "phone": "+70491842791"}
0005433151511	62D90E	1487 452312	ANNA KOZLOVA	{"phone": "+70508826057"}
0005433151512	F87AC5	8878 626186	DMITRIY STEPANOV	{"phone": "+70173841681"}
0005433151513	9F6467	1112 829522	TATYANA MAKSIMOVA	{"email": "t.maksimova1972@postgrespro.ru", "phone": "+70349103060"}
0005433151514	9F6467	0083 889374	ILDUS NIKITIN	{"phone": "+70186882139"}
0005433151515	3C7DDB	8175 690987	EVGENIY KUZMIN	{"phone": "+70598034638"}
0005433151516	885614	4406 302533	VALERIY MAKAROV	{"phone": "+70235531045"}
0005433151517	885614	8602 977443	LYUDMILA BOGDANOVA	{"email": "l.bogdanova-03081974@postgrespro.ru", "phone": "+70967429002"}
0005433152074	FB12F7	5782 813136	ELENA ZHURAVLEVA	{"phone": "+70991493806"}
0005433151518	EF87AC	1766 459382	NIKITA SHEVCHENKO	{"email": "shevchenko.n.15011982@postgrespro.ru", "phone": "+70754638714"}
0005433151519	235159	8995 966439	OLEG KUZNECOV	{"email": "kuznecov.o_1957@postgrespro.ru", "phone": "+70331914498"}
0005433151520	9EC37B	8733 555643	NATALYA KAZAKOVA	{"email": "kazakova_n_041969@postgrespro.ru", "phone": "+70729820649"}
0005433151521	9EC37B	2449 307477	KLAVDIYA RYABOVA	{"email": "k_ryabova.1962@postgrespro.ru", "phone": "+70404647099"}
0005433151522	95264E	2621 466209	ANASTASIYA MEDVEDEVA	{"phone": "+70591301251"}
0005433151523	AC61FA	3187 645888	VLADIMIR MIKHAYLOV	{"phone": "+70163257994"}
0005433151524	DB5BA5	1947 447276	DMITRIY MIRONOV	{"email": "d-mironov.1988@postgrespro.ru", "phone": "+70352185539"}
0005433151525	1C0183	1179 585060	SERGEY FILIPPOV	{"email": "filippov-s-1985@postgrespro.ru", "phone": "+70984452008"}
0005433151526	91A795	6206 142230	NIKOLAY MATVEEV	{"email": "nikolay-matveev051974@postgrespro.ru", "phone": "+70118610518"}
0005433151527	21A204	6136 929558	ELENA BOGDANOVA	{"phone": "+70819082378"}
0005433151528	21AC35	0945 566073	NINA ISAEVA	{"email": "nisaeva1968@postgrespro.ru", "phone": "+70677749135"}
0005433151529	21AC35	6727 380278	LYUBOV AFANASEVA	{"phone": "+70903199795"}
0005433151530	01CD9D	4947 038182	NINA FILATOVA	{"email": "n-filatova-08031968@postgrespro.ru", "phone": "+70646736636"}
0005433151531	01CD9D	1237 242236	NIKOLAY MARTYNOV	{"phone": "+70775427873"}
0005433151532	F3E74C	7145 605953	VALERIYA NAZAROVA	{"phone": "+70459599889"}
0005433151533	0B7126	9964 150628	MARINA VLASOVA	{"phone": "+70230988861"}
0005433151534	BC52B0	2457 613686	OLESYA TROFIMOVA	{"email": "trofimova-o03041982@postgrespro.ru", "phone": "+70712354177"}
0005433151535	55DA3B	7919 428661	VLADISLAV BELOV	{"phone": "+70142635834"}
0005433151536	22B38B	9275 328962	SERGEY MOROZOV	{"email": "morozovsergey-111964@postgrespro.ru", "phone": "+70159448938"}
0005433151537	22B38B	8201 972918	BORIS SMIRNOV	{"phone": "+70705624228"}
0005433151538	22B38B	2715 042649	IRINA POTAPOVA	{"phone": "+70093727921"}
0005433151539	120DC1	3648 973375	GALINA GUSEVA	{"email": "g_guseva.011974@postgrespro.ru", "phone": "+70403023084"}
0005433151540	8E51AE	8237 712439	ALBINA KOROLEVA	{"phone": "+70463184485"}
0005433151541	53BB92	4552 343363	NIKOLAY PAVLOV	{"email": "npavlov_1966@postgrespro.ru", "phone": "+70958969524"}
0005433151542	53BB92	4416 257109	PAVEL DAVYDOV	{"phone": "+70903910610"}
0005433151543	53BB92	2296 233736	VLADIMIR MARTYNOV	{"phone": "+70381176499"}
0005433151544	F9011C	8028 084212	ALEKSANDR GAVRILOV	{"phone": "+70232640552"}
0005433151545	F9011C	4991 843870	NIKOLAY ANDREEV	{"email": "nikolay.andreev_061969@postgrespro.ru", "phone": "+70765195061"}
0005433151546	62C74B	8179 881746	ELENA EGOROVA	{"email": "elena_egorova-11051973@postgrespro.ru", "phone": "+70624198554"}
0005433151547	2D5F78	5248 145618	SERGEY KUDRYASHOV	{"phone": "+70646143328"}
0005433151548	87AF7A	9188 547707	TAISIYA ANDREEVA	{"phone": "+70417909862"}
0005433151549	9F66FB	7427 500152	LYUDMILA MASLOVA	{"email": "maslova_lyudmila.1980@postgrespro.ru", "phone": "+70756513248"}
0005433151550	9F66FB	4495 090911	MARIYA RYABOVA	{"email": "ryabova.mariya1967@postgrespro.ru", "phone": "+70762146465"}
0005433151551	3B8EDE	1069 030493	ELENA FILIPPOVA	{"phone": "+70286336588"}
0005433151552	3B8EDE	5502 987364	ALEKSANDR STEPANOV	{"email": "aleksandrstepanov.13011981@postgrespro.ru", "phone": "+70679762887"}
0005433151553	9D9D35	2894 635677	KSENIYA KULIKOVA	{"email": "kulikovak_061976@postgrespro.ru", "phone": "+70409565486"}
0005433151554	24A0CB	5622 531037	MARIYA ZAYCEVA	{"phone": "+70982544959"}
0005433151555	24A0CB	4542 199304	ALEKSANDR FOMIN	{"email": "fomin.aleksandr1969@postgrespro.ru", "phone": "+70840199185"}
0005433151556	3E1E6D	4285 455573	NINA MOROZOVA	{"email": "nina_morozova.22091970@postgrespro.ru", "phone": "+70110551687"}
0005433151557	3E1E6D	1739 866304	PAVEL IVANOV	{"phone": "+70667411987"}
0005433151558	3E1E6D	4731 381724	ILNUR MARTYNOV	{"email": "ilnurmartynov.09021959@postgrespro.ru", "phone": "+70631850915"}
0005433151559	1F3609	3080 759501	ZINAIDA NESTEROVA	{"phone": "+70112637637"}
0005433151560	19C922	3149 636039	NINA VLASOVA	{"phone": "+70892361753"}
0005433151561	1008A0	4655 504384	NATALYA SERGEEVA	{"email": "sergeevan_071971@postgrespro.ru", "phone": "+70743334036"}
0005433151562	1008A0	9900 968929	VIOLETTA MELNIKOVA	{"email": "melnikova-v-1977@postgrespro.ru", "phone": "+70673153583"}
0005433151563	65A687	0645 889972	ALEKSEY ANDREEV	{"phone": "+70424521860"}
0005433151564	65A687	6797 645021	DANIIL MAKAROV	{"phone": "+70518293049"}
0005433151565	B4216B	1504 957637	OKSANA VLASOVA	{"phone": "+70945163128"}
0005433151566	36BEAB	3816 832155	ANASTASIYA POPOVA	{"email": "popova-a22011980@postgrespro.ru", "phone": "+70768394243"}
0005433151567	36BEAB	4804 365136	NINA GRISHINA	{"email": "grishina_n-1958@postgrespro.ru", "phone": "+70187083475"}
0005433151568	281BB8	2085 551497	IVAN DAVYDOV	{"phone": "+70828060060"}
0005433151569	89FA42	7040 810636	YANA SOLOVEVA	{"phone": "+70654229528"}
0005433151570	4C8ED0	9841 562599	MAKSIM SCHERBAKOV	{"phone": "+70298196466"}
0005433151571	4C8ED0	2877 585564	ANNA DAVYDOVA	{"phone": "+70373565477"}
0005433151572	17E926	7059 315913	LYUDMILA MEDVEDEVA	{"phone": "+70612230856"}
0005433151573	17E926	1457 297663	YULIYA ZAYCEVA	{"email": "zaycevay-06071959@postgrespro.ru", "phone": "+70903712443"}
0005433151574	573D17	7031 198516	NADEZHDA BELYAEVA	{"phone": "+70977299273"}
0005433151575	573D17	9441 628576	VLADIMIR NOVIKOV	{"email": "novikovvladimir-1979@postgrespro.ru", "phone": "+70048334518"}
0005433151576	3B0FFD	2319 039565	TAGIR SOROKIN	{"phone": "+70632714433"}
0005433151577	3B0FFD	4457 636869	SNEZHANA LEBEDEVA	{"email": "snezhana-lebedeva.1981@postgrespro.ru", "phone": "+70880453671"}
0005433151578	A3BEE9	7479 706369	MATVEY ANDREEV	{"email": "andreev.matvey-1976@postgrespro.ru", "phone": "+70197250978"}
0005433151579	3C34B2	0766 389362	MARINA OVCHINNIKOVA	{"phone": "+70701258223"}
0005433151580	A177A4	9829 573225	VIKTOR KOZLOV	{"email": "vkozlov.24041979@postgrespro.ru", "phone": "+70842570398"}
0005433151581	A177A4	5263 114912	ANNA ILINA	{"email": "ilina_a.051957@postgrespro.ru", "phone": "+70726357640"}
0005433151582	3B2BCD	2943 955206	TAMARA SOKOLOVA	{"phone": "+70022867374"}
0005433151583	4755FA	4114 040121	NATALYA NIKIFOROVA	{"email": "nikiforovanatalya_1971@postgrespro.ru", "phone": "+70029878858"}
0005433151584	325E24	3950 744939	MARK KOZLOV	{"phone": "+70290510854"}
0005433151585	159720	0275 045950	ALEKSANDR KISELEV	{"email": "kiselev_a_1971@postgrespro.ru", "phone": "+70010041260"}
0005433151586	159720	7041 245697	GALINA TIKHONOVA	{"email": "tikhonova.galina.15091980@postgrespro.ru", "phone": "+70194162805"}
0005433151587	2132EF	9941 158665	LIDIYA KUZNECOVA	{"phone": "+70133499980"}
0005433151588	C8133B	7682 693805	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov-071971@postgrespro.ru", "phone": "+70524761863"}
0005433151589	07837E	4832 039405	ANTON ALEKSEEV	{"phone": "+70912644947"}
0005433151590	B17914	5555 181106	IVAN FILIPPOV	{"email": "filippov-ivan.1982@postgrespro.ru", "phone": "+70308771121"}
0005433151591	C0C5F5	7658 135656	NATALYA KRASNOVA	{"phone": "+70421258999"}
0005433151592	1D14E3	2580 072808	VLADIMIR BARANOV	{"email": "baranov_vladimir.071983@postgrespro.ru", "phone": "+70132258306"}
0005433151593	D90DBF	6922 952446	VERA KUDRYASHOVA	{"phone": "+70665421700"}
0005433151594	D90DBF	5574 280263	ELENA TARASOVA	{"email": "e-tarasova111968@postgrespro.ru", "phone": "+70732056472"}
0005433151595	1B9F52	8807 526857	IVAN ROMANOV	{"phone": "+70396834274"}
0005433151596	40A105	2423 186030	VALENTINA SAVELEVA	{"email": "saveleva-valentina_1977@postgrespro.ru", "phone": "+70671906572"}
0005433151597	4B2685	9568 412524	MARGARITA SIDOROVA	{"email": "sidorova-margarita-1956@postgrespro.ru", "phone": "+70779714666"}
0005433151598	44F8FF	7764 139327	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.a_1976@postgrespro.ru", "phone": "+70893965341"}
0005433151599	8074B0	5977 217163	KUZMA FROLOV	{"phone": "+70267784194"}
0005433151600	72F437	3788 909928	NIKITA NIKITIN	{"email": "nikita-nikitin.111966@postgrespro.ru", "phone": "+70776054621"}
0005433151601	72F437	1966 710668	EKATERINA EFREMOVA	{"email": "e-efremova_011971@postgrespro.ru", "phone": "+70727190884"}
0005433151602	50B7EE	0692 265371	ALEKSANDRA GRISHINA	{"email": "aleksandra.grishina.30111982@postgrespro.ru", "phone": "+70076470961"}
0005433151603	DA008D	5616 435765	LIDIYA ZAKHAROVA	{"email": "l-zakharova_1986@postgrespro.ru", "phone": "+70230432055"}
0005433151604	678060	6071 991129	ALEKSEY TIKHONOV	{"email": "tikhonovaleksey041961@postgrespro.ru", "phone": "+70267592120"}
0005433151605	678060	3011 011659	MARIYA VASILEVA	{"phone": "+70251695478"}
0005433151606	BFD237	2900 939851	OKSANA SOKOLOVA	{"phone": "+70598625375"}
0005433151607	450534	5649 952498	SERGEY EGOROV	{"phone": "+70327061379"}
0005433151608	01E7EE	4396 116271	EVGENIYA DENISOVA	{"email": "denisova.e_101968@postgrespro.ru", "phone": "+70047313769"}
0005433151609	844939	6086 230139	ALENA KOZLOVA	{"email": "alenakozlova.041966@postgrespro.ru", "phone": "+70430835374"}
0005433151610	844939	3355 298327	VERA SOKOLOVA	{"email": "sokolova_vera.1965@postgrespro.ru", "phone": "+70853459211"}
0005433151611	B8BCC1	9004 603621	OKSANA NIKOLAEVA	{"email": "nikolaeva.o_11121975@postgrespro.ru", "phone": "+70996709833"}
0005433151612	24D343	4978 507456	ALEKSANDR MEDVEDEV	{"email": "a-medvedev21021979@postgrespro.ru", "phone": "+70178333359"}
0005433151613	8CFE70	8323 338987	NADEZHDA KUDRYASHOVA	{"phone": "+70663554790"}
0005433151614	A4249D	8415 756532	NINA SAVELEVA	{"email": "n_saveleva.111969@postgrespro.ru", "phone": "+70243045520"}
0005433151615	A4249D	0625 087129	VASILISA EGOROVA	{"email": "egorova.vasilisa.071967@postgrespro.ru", "phone": "+70738589430"}
0005433151616	3163A3	3033 469435	OKSANA IVANOVA	{"phone": "+70624870529"}
0005433151617	3163A3	4747 819956	PAVEL KISELEV	{"email": "kiselev_pavel_101971@postgrespro.ru", "phone": "+70544751903"}
0005433151618	509E3E	1221 768407	LIDIYA SOROKINA	{"phone": "+70484680186"}
0005433151619	C45319	1367 344819	NADEZHDA VASILEVA	{"email": "n_vasileva-28061967@postgrespro.ru", "phone": "+70431636965"}
0005433151620	D17B9E	0535 290059	NATALYA MIRONOVA	{"email": "mironova_n1980@postgrespro.ru", "phone": "+70894429753"}
0005433151621	B7CE3A	4789 941466	RUSLAN KULIKOV	{"email": "kulikov-ruslan.1967@postgrespro.ru", "phone": "+70805538451"}
0005433151622	B7CE3A	9465 266161	VALENTINA SERGEEVA	{"phone": "+70517804477"}
0005433151623	AB745D	5256 405134	ALEKSANDRA TIKHONOVA	{"email": "aleksandratikhonova_091966@postgrespro.ru", "phone": "+70082022706"}
0005433151624	A1A76C	6249 813847	LIDIYA NIKITINA	{"phone": "+70540941008"}
0005433151625	DF89E8	2323 216443	DMITRIY MOROZOV	{"phone": "+70818112955"}
0005433151626	DF89E8	5884 354288	PAVEL POPOV	{"email": "p-popov.121958@postgrespro.ru", "phone": "+70000564778"}
0005433151627	316E5E	2384 592879	IRINA KUZNECOVA	{"phone": "+70879915989"}
0005433151628	33E446	7211 996927	KSENIYA NOVIKOVA	{"phone": "+70234893472"}
0005433151629	33E446	2967 498866	VITALIY KAZAKOV	{"phone": "+70157721519"}
0005433151630	920A81	1572 655981	ELENA KOLESNIKOVA	{"email": "elenakolesnikova-25031967@postgrespro.ru", "phone": "+70417716736"}
0005433151631	72267C	3984 883253	OLESYA KULIKOVA	{"phone": "+70047472109"}
0005433151632	72267C	9901 274274	RINAT ROMANOV	{"email": "rinat-romanov-1963@postgrespro.ru", "phone": "+70502240052"}
0005433151633	72267C	3409 654689	ALEKSEY MAKSIMOV	{"email": "maksimov-aleksey-1971@postgrespro.ru", "phone": "+70901060462"}
0005433151634	6504EC	0846 029596	ELENA PAVLOVA	{"email": "pavlovae_1984@postgrespro.ru", "phone": "+70034144968"}
0005433151635	BD566C	7293 583300	EVGENIY FEDOROV	{"email": "fedorov.evgeniy.08111969@postgrespro.ru", "phone": "+70244395831"}
0005433151636	03CBE5	1283 819083	ANDREY VOLKOV	{"phone": "+70735989377"}
0005433151637	03CBE5	8045 176013	POLINA MAKAROVA	{"phone": "+70228799021"}
0005433151638	080330	8091 667132	PETR KUDRYASHOV	{"email": "kudryashov-petr1979@postgrespro.ru", "phone": "+70943910598"}
0005433151639	C6488D	4895 483042	LYUDMILA SAVELEVA	{"phone": "+70598511371"}
0005433151640	57AC94	8726 674471	NATALYA KUZMINA	{"email": "kuzmina-natalya.1975@postgrespro.ru", "phone": "+70676330874"}
0005433151641	518984	7597 914720	MARINA ZHURAVLEVA	{"email": "zhuravlevam_111972@postgrespro.ru", "phone": "+70602436280"}
0005433151642	678D43	3782 866123	TATYANA MOROZOVA	{"phone": "+70996472513"}
0005433151643	B9C3A8	1096 287904	NIKITA GUSEV	{"email": "nikitagusev_18101974@postgrespro.ru", "phone": "+70162092235"}
0005433151644	B391BF	7638 585768	VIKTORIYA SEMENOVA	{"email": "semenova-v111977@postgrespro.ru", "phone": "+70309302805"}
0005433151645	72D475	2569 961864	NIKOLAY MOISEEV	{"phone": "+70858485906"}
0005433151646	61022E	6109 158177	LYUDMILA TIKHONOVA	{"phone": "+70841383183"}
0005433151647	E58223	6308 735571	ELIZAVETA RYABOVA	{"email": "ryabova-e-081972@postgrespro.ru", "phone": "+70186840172"}
0005433151648	D7DDC0	7690 304845	SVETLANA DMITRIEVA	{"email": "dmitrieva.s1968@postgrespro.ru", "phone": "+70275119695"}
0005433151649	63FBFB	7665 626498	OLGA KALININA	{"phone": "+70054524234"}
0005433151650	63FBFB	2261 149376	IRINA TARASOVA	{"email": "i.tarasova_121969@postgrespro.ru", "phone": "+70688011175"}
0005433151651	CF98AB	4556 444954	SERGEY NIKITIN	{"phone": "+70075992751"}
0005433151652	562630	1689 582107	DENIS ZHURAVLEV	{"phone": "+70406290524"}
0005433151653	4380D9	3337 548297	ELENA KAZAKOVA	{"phone": "+70166389942"}
0005433151654	5C5853	5022 562575	VERA PETROVA	{"email": "petrova.vera1969@postgrespro.ru", "phone": "+70103776221"}
0005433151655	5C5853	1938 461585	VITALIY MAKSIMOV	{"email": "maksimov.vitaliy.1971@postgrespro.ru", "phone": "+70043191056"}
0005433151656	01747F	4596 725755	ROSTISLAV POPOV	{"phone": "+70905150491"}
0005433151657	01747F	1162 212857	NATALYA ANTONOVA	{"phone": "+70437428845"}
0005433151658	065FF4	5160 811057	MARIYA KUZMINA	{"email": "mariyakuzmina-091977@postgrespro.ru", "phone": "+70774358513"}
0005433151659	065FF4	9407 121252	ELENA MAKAROVA	{"email": "makarovae18101962@postgrespro.ru", "phone": "+70883831896"}
0005433151660	F61143	0030 262558	EVGENIYA MELNIKOVA	{"phone": "+70749665754"}
0005433151661	2176C7	4301 081183	ARTEM ABRAMOV	{"email": "abramov.artem.13071974@postgrespro.ru", "phone": "+70636628534"}
0005433151662	5E2FBA	2209 435579	RUSTAM KONOVALOV	{"phone": "+70409574014"}
0005433151663	61F8EE	4449 592009	NATALYA MAKSIMOVA	{"phone": "+70895218446"}
0005433151664	61F8EE	2736 890386	KRISTINA GERASIMOVA	{"phone": "+70974611453"}
0005433151665	1108DA	0150 903967	RUSHANIYA MASLOVA	{"email": "rushaniya-maslova-1973@postgrespro.ru", "phone": "+70684159312"}
0005433151666	1108DA	9898 208222	ELENA ANDREEVA	{"phone": "+70776317171"}
0005433151667	1108DA	0739 382086	LYUDMILA MALYSHEVA	{"phone": "+70959320192"}
0005433151668	D37AA8	5908 144714	NIKITA KRASNOV	{"phone": "+70662391584"}
0005433151669	466A03	1336 042645	EVGENIY KUZNECOV	{"phone": "+70275196201"}
0005433151670	68DA3F	6122 254216	YULIYA ZHURAVLEVA	{"email": "yzhuravleva.23051977@postgrespro.ru", "phone": "+70314544556"}
0005433151671	0DB2A9	6023 410859	GALINA ILINA	{"email": "ilina_g-121976@postgrespro.ru", "phone": "+70773984767"}
0005433151672	0DB2A9	8082 842353	NIKOLAY KAZAKOV	{"phone": "+70239630072"}
0005433151673	9E7511	4735 692446	VADIM ISAEV	{"email": "isaev.vadim_07081970@postgrespro.ru", "phone": "+70631701383"}
0005433151674	8AAB3A	4887 044327	PAVEL VASILEV	{"email": "p.vasilev111976@postgrespro.ru", "phone": "+70692823806"}
0005433151675	DEE7B9	8263 348053	ELMIRA KUDRYASHOVA	{"email": "kudryashova_elmira.19061968@postgrespro.ru", "phone": "+70545140783"}
0005433151676	DEE7B9	2844 591363	VALENTINA TROFIMOVA	{"phone": "+70104318334"}
0005433151677	906388	2065 949136	ALENA KUZMINA	{"email": "alenakuzmina.041968@postgrespro.ru", "phone": "+70570262609"}
0005433151678	12DF84	3384 334480	TATYANA NOVIKOVA	{"email": "t.novikova_1979@postgrespro.ru", "phone": "+70070128775"}
0005433151679	88C666	5999 990252	TATYANA CHERNOVA	{"phone": "+70785664316"}
0005433151680	1180E0	9535 241144	DARYA ANTONOVA	{"phone": "+70842683063"}
0005433151681	1180E0	0863 210225	ELENA MIKHAYLOVA	{"phone": "+70022514770"}
0005433151682	1180E0	9603 945283	SERGEY IVANOV	{"email": "ivanovs_111966@postgrespro.ru", "phone": "+70424719166"}
0005433151683	3EB7CB	2255 008346	ELENA GAVRILOVA	{"phone": "+70351816694"}
0005433151684	0EB100	3960 151791	LYUBOV MOISEEVA	{"email": "moiseeva_lyubov.14061974@postgrespro.ru", "phone": "+70286518731"}
0005433151685	0EB100	1484 327853	ANNA TIKHONOVA	{"email": "a_tikhonova-1966@postgrespro.ru", "phone": "+70281749731"}
0005433151686	DF1200	1711 395607	ALEKSANDR SIDOROV	{"email": "sidorov.a-06091964@postgrespro.ru", "phone": "+70991787766"}
0005433151687	DF1200	5207 260392	ALEKSANDR TIKHONOV	{"email": "a-tikhonov1976@postgrespro.ru", "phone": "+70112029961"}
0005433151688	C6A47F	4187 268304	ALEKSEY VOROBEV	{"email": "a_vorobev09021969@postgrespro.ru", "phone": "+70097025846"}
0005433151689	50CE69	2226 345777	IRINA KONDRATEVA	{"email": "i-kondrateva101966@postgrespro.ru", "phone": "+70827658556"}
0005433151690	79ED8F	7226 196083	MARIYA MALYSHEVA	{"email": "mariya_malysheva_121967@postgrespro.ru", "phone": "+70242477978"}
0005433151691	6215CE	1545 553671	OLEG ILIN	{"phone": "+70393151011"}
0005433151692	5E5093	2356 464502	VLADIMIR VLASOV	{"email": "vladimirvlasov101965@postgrespro.ru", "phone": "+70075883202"}
0005433151693	5E5093	6288 016412	KIRILL KONOVALOV	{"phone": "+70377286488"}
0005433151694	5E5093	1935 385696	ANDREY DENISOV	{"email": "adenisov_17011970@postgrespro.ru", "phone": "+70253735820"}
0005433151695	404521	2879 437213	EVGENIY MEDVEDEV	{"phone": "+70182940685"}
0005433151696	A5931D	0636 572583	ALLA OSIPOVA	{"email": "osipova_a-01091959@postgrespro.ru", "phone": "+70130549108"}
0005433151697	6A975D	9644 033430	ARTEM YAKOVLEV	{"phone": "+70881950563"}
0005433151698	8B5967	4271 900449	ALEKSANDR FILIPPOV	{"phone": "+70876117384"}
0005433151699	DB5FF5	3694 765842	ALEKSANDR NIKITIN	{"phone": "+70064049063"}
0005433151700	DB5FF5	5208 487444	NADEZHDA AFANASEVA	{"email": "afanaseva_n101969@postgrespro.ru", "phone": "+70523058218"}
0005433151701	CB48CA	5213 749059	NADEZHDA MIRONOVA	{"email": "nadezhda_mironova05041969@postgrespro.ru", "phone": "+70983298414"}
0005433151702	430AA5	1395 514545	LEONID ZAKHAROV	{"phone": "+70996117202"}
0005433151703	E54662	7125 802609	KONSTANTIN ZHURAVLEV	{"email": "zhuravlev_k.07101973@postgrespro.ru", "phone": "+70511381457"}
0005433151704	3A5689	7549 612730	ELENA SAVELEVA	{"email": "e.saveleva_011974@postgrespro.ru", "phone": "+70948883497"}
0005433151705	C6B62B	4844 367495	EVGENIY TIKHONOV	{"email": "tikhonov.evgeniy.1977@postgrespro.ru", "phone": "+70650510699"}
0005433151706	C6B62B	1043 892934	EKATERINA MIRONOVA	{"email": "e.mironova041977@postgrespro.ru", "phone": "+70912427586"}
0005433151707	0EB5D9	3868 607501	RUSLAN MARTYNOV	{"phone": "+70755971248"}
0005433151708	AA25DE	9866 749322	DENIS DENISOV	{"email": "d_denisov1978@postgrespro.ru", "phone": "+70723971781"}
0005433151709	AA25DE	4892 912277	ANNA FILATOVA	{"email": "filatova-a_28011955@postgrespro.ru", "phone": "+70202850219"}
0005433151710	F57FA3	5028 953297	VITALIY RODIONOV	{"email": "v.rodionov011982@postgrespro.ru", "phone": "+70969502964"}
0005433151711	F57FA3	2783 921520	TATYANA IVANOVA	{"phone": "+70431722988"}
0005433151712	55CCA4	1785 551050	NIKOLAY ILIN	{"email": "n-ilin.121973@postgrespro.ru", "phone": "+70023113479"}
0005433151713	A69362	1650 223822	EVGENIY KUZMIN	{"email": "evgeniy_kuzmin_051970@postgrespro.ru", "phone": "+70914774863"}
0005433151714	784DD7	0950 511788	NADEZHDA KOZLOVA	{"email": "nadezhda_kozlova.071970@postgrespro.ru", "phone": "+70334720890"}
0005433151715	610E83	3468 613157	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov-1978@postgrespro.ru", "phone": "+70448309357"}
0005433151716	39106D	1411 039834	DANIIL FROLOV	{"email": "daniil-frolov_051972@postgrespro.ru", "phone": "+70011999529"}
0005433151717	39106D	2779 110549	OLEG SOKOLOV	{"phone": "+70333926395"}
0005433151718	429DA2	7449 317237	NATALYA MIKHAYLOVA	{"phone": "+70683190482"}
0005433151719	D86551	0143 193219	NATALYA GUSEVA	{"email": "gusevan-1976@postgrespro.ru", "phone": "+70915488253"}
0005433151720	043FB8	9694 698400	ALEKSEY GUSEV	{"phone": "+70373275036"}
0005433151721	7830C2	3659 536677	VALENTINA TIKHONOVA	{"email": "valentina-tikhonova-15121973@postgrespro.ru", "phone": "+70791405132"}
0005433151722	3E1205	4823 321810	TAMARA KOZLOVA	{"phone": "+70048908443"}
0005433151723	0EA07D	3229 412461	SERGEY ROMANOV	{"email": "romanov_s1984@postgrespro.ru", "phone": "+70008995773"}
0005433151724	B51C5B	3632 178623	VIKTOR KUZNECOV	{"phone": "+70028523772"}
0005433151725	8842A0	8319 267948	GALINA DENISOVA	{"phone": "+70294503020"}
0005433151726	9391A4	4616 162063	VALENTINA NIKITINA	{"email": "nikitina-v-121974@postgrespro.ru", "phone": "+70921962341"}
0005433151727	996F72	2443 459920	NATALYA ERMAKOVA	{"email": "n.ermakova-1974@postgrespro.ru", "phone": "+70439426164"}
0005433151728	51F1D0	9558 442661	MARIYA ANDREEVA	{"email": "andreeva-mariya.111979@postgrespro.ru", "phone": "+70985268740"}
0005433151729	8410B9	3042 532820	LYUBOV KOROLEVA	{"phone": "+70287986010"}
0005433151730	BB9632	9616 342927	ELENA KUZNECOVA	{"phone": "+70042866445"}
0005433151731	D2B333	3641 735868	IRINA ANDREEVA	{"email": "irina.andreeva-1971@postgrespro.ru", "phone": "+70103484906"}
0005433151732	D2B333	1826 254007	VLADIMIR MAKAROV	{"phone": "+70236346835"}
0005433151733	97F829	9659 138393	FEDOR STEPANOV	{"phone": "+70728002507"}
0005433151734	E8E1E9	7860 411542	STANISLAV IVANOV	{"email": "stanislav.ivanov.121975@postgrespro.ru", "phone": "+70338771932"}
0005433151735	2D92C8	4966 374048	NATALYA KAZAKOVA	{"phone": "+70736340944"}
0005433151736	6B862F	1693 713036	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.natalya-091971@postgrespro.ru", "phone": "+70735998675"}
0005433151737	53F120	8269 055018	MARIYA NIKIFOROVA	{"email": "mnikiforova-1982@postgrespro.ru", "phone": "+70630192656"}
0005433151738	53F120	7723 152481	EVGENIY SCHERBAKOV	{"email": "e_scherbakov23111977@postgrespro.ru", "phone": "+70227073223"}
0005433151739	53F120	7483 349978	TAMARA FROLOVA	{"email": "t_frolova-011975@postgrespro.ru", "phone": "+70529157435"}
0005433151740	4D8DA5	3358 785680	ALEKSANDR FROLOV	{"phone": "+70012161651"}
0005433151741	4D8DA5	9358 040953	SERGEY EGOROV	{"email": "egorovsergey01011971@postgrespro.ru", "phone": "+70557517157"}
0005433151742	1D396C	6286 311789	MIKHAIL ALEKSEEV	{"phone": "+70358098856"}
0005433151743	1D396C	1679 250936	MARIYA POTAPOVA	{"email": "potapovam-1971@postgrespro.ru", "phone": "+70386826134"}
0005433151744	4D8994	8878 047618	ANTONINA IVANOVA	{"email": "antonina_ivanova.091983@postgrespro.ru", "phone": "+70321373687"}
0005433151745	4D8994	5871 321047	VIKTORIYA PETROVA	{"phone": "+70155976975"}
0005433151746	81BE10	8215 715076	EKATERINA SOKOLOVA	{"email": "esokolova.1976@postgrespro.ru", "phone": "+70749055137"}
0005433151747	40A4AD	5938 918218	YULIYA MAKSIMOVA	{"phone": "+70322995431"}
0005433151748	CCE964	7152 830758	ELENA MAKAROVA	{"phone": "+70118215314"}
0005433151749	CCE964	5458 405106	VIKTORIYA DMITRIEVA	{"phone": "+70001309406"}
0005433151750	57918E	0943 551522	EKATERINA KOVALEVA	{"email": "kovaleva.ekaterina-041982@postgrespro.ru", "phone": "+70352476777"}
0005433151751	C17255	8799 769560	MIKHAIL SMIRNOV	{"phone": "+70307794921"}
0005433151752	E8D19C	2963 623552	ALSU NIKOLAEVA	{"email": "nikolaeva.alsu-021980@postgrespro.ru", "phone": "+70494768931"}
0005433151753	7387D0	6520 052657	LYUBOV LAZAREVA	{"email": "lyubovlazareva_1979@postgrespro.ru", "phone": "+70382261758"}
0005433151754	5BB068	9230 308226	ELENA ILINA	{"phone": "+70013708561"}
0005433151755	F87154	8005 054839	NATALYA ILINA	{"email": "ilina.n_041972@postgrespro.ru", "phone": "+70852035063"}
0005433151756	F87154	3553 211347	ANNA DAVYDOVA	{"phone": "+70767106990"}
0005433151757	3442C3	0266 946173	SVETLANA MAKAROVA	{"email": "svetlanamakarova.101960@postgrespro.ru", "phone": "+70884328934"}
0005433151758	3442C3	7243 059462	NIKOLAY MAKAROV	{"email": "n.makarov.021976@postgrespro.ru", "phone": "+70702489798"}
0005433151759	54ACE2	4403 086008	LARISA EFREMOVA	{"email": "larisaefremova_24061969@postgrespro.ru", "phone": "+70051104581"}
0005433151760	54ACE2	1110 722887	TAMARA PAVLOVA	{"email": "pavlova.t041957@postgrespro.ru", "phone": "+70999853841"}
0005433151761	7780A8	9141 781747	ELENA DANILOVA	{"phone": "+70229395925"}
0005433151762	AB789C	2159 475496	VLADIMIR RODIONOV	{"phone": "+70757841448"}
0005433151763	AB789C	7564 451380	DMITRIY IVANOV	{"email": "d_ivanov1979@postgrespro.ru", "phone": "+70666800348"}
0005433151764	C0C869	6935 995131	MIKHAIL PETROV	{"phone": "+70891895896"}
0005433151765	C0C869	7402 713955	LIDIYA GERASIMOVA	{"phone": "+70820052226"}
0005433151766	A0B392	5084 141363	EKATERINA EGOROVA	{"email": "egorova-e1973@postgrespro.ru", "phone": "+70101200315"}
0005433151767	A0B392	8414 944792	NIKOLAY FROLOV	{"email": "frolov-n.091970@postgrespro.ru", "phone": "+70521433022"}
0005433151768	5E508E	2079 204368	MAKSIM BARANOV	{"phone": "+70694585518"}
0005433151769	C9F230	6819 539910	ALEKSANDR MOISEEV	{"phone": "+70959562076"}
0005433151770	6F7663	7779 670333	PETR NAUMOV	{"email": "naumov.petr18101966@postgrespro.ru", "phone": "+70212966835"}
0005433151771	CFE92C	3225 706896	GRIGORIY MARTYNOV	{"email": "grigoriy.martynov_11061973@postgrespro.ru", "phone": "+70149898246"}
0005433151772	BB77C0	8141 058614	LIDIYA YAKOVLEVA	{"email": "yakovleva_lidiya-081970@postgrespro.ru", "phone": "+70285322215"}
0005433151773	319174	4275 702617	VASILIY VOLKOV	{"phone": "+70725970134"}
0005433151774	02EE8A	7128 899300	VIKTOR POPOV	{"phone": "+70840341799"}
0005433151775	DEA13B	9069 773714	EKATERINA SERGEEVA	{"email": "sergeevae-061972@postgrespro.ru", "phone": "+70201436877"}
0005433151776	20D9BC	1434 862554	TATYANA ANDREEVA	{"email": "t_andreeva04081972@postgrespro.ru", "phone": "+70301313806"}
0005433151777	5308EB	0932 378823	FEDOR KUZNECOV	{"email": "fedorkuznecov.031986@postgrespro.ru", "phone": "+70472786996"}
0005433151778	9A4F3D	6448 611733	SERGEY KOZLOV	{"phone": "+70979890681"}
0005433151779	4649B0	2619 197424	ALEKSANDR FOMIN	{"phone": "+70247692566"}
0005433151780	1610B7	8530 518850	ANDREY ABRAMOV	{"email": "abramov-a1975@postgrespro.ru", "phone": "+70181397690"}
0005433151781	3B9AF0	4699 254256	ANNA MARTYNOVA	{"email": "a_martynova121978@postgrespro.ru", "phone": "+70468635357"}
0005433151782	47A44D	1887 109608	MIKHAIL MOISEEV	{"email": "moiseev-m.26121968@postgrespro.ru", "phone": "+70256247342"}
0005433151783	54D0F0	1347 703354	GALINA ISAEVA	{"phone": "+70230986595"}
0005433151784	16FE18	7281 544885	EVGENIY ABRAMOV	{"email": "abramove_021976@postgrespro.ru", "phone": "+70553570384"}
0005433151785	5DA4BB	4042 280628	IGOR STEPANOV	{"email": "igor-stepanov021966@postgrespro.ru", "phone": "+70235093535"}
0005433151786	5DA4BB	3475 876639	ANDREY ALEKSEEV	{"phone": "+70453517102"}
0005433151787	CDF5F3	2716 133343	MILANA ANDREEVA	{"email": "m_andreeva-1980@postgrespro.ru", "phone": "+70722706711"}
0005433151788	F8FFFB	6893 318777	OLGA ROMANOVA	{"email": "romanova_o071966@postgrespro.ru", "phone": "+70677032909"}
0005433151789	F8FFFB	1450 126127	EVA VASILEVA	{"email": "e.vasileva-25021976@postgrespro.ru", "phone": "+70857570370"}
0005433151790	F8FFFB	6045 806815	SVETLANA PETROVA	{"phone": "+70113666657"}
0005433151791	747A86	4669 192560	ANNA NOVIKOVA	{"phone": "+70104591302"}
0005433151792	B39265	7108 833672	EKATERINA BOGDANOVA	{"email": "bogdanova-ekaterina-101968@postgrespro.ru", "phone": "+70131826043"}
0005433151793	B39265	4555 347879	VERA KOROLEVA	{"email": "koroleva.v.29091963@postgrespro.ru", "phone": "+70889197952"}
0005433151794	B39265	4778 199127	ANASTASIYA ZAYCEVA	{"phone": "+70043411666"}
0005433151795	B39265	1636 090874	DARYA ALEKSANDROVA	{"email": "aleksandrova-d.05051981@postgrespro.ru", "phone": "+70715031328"}
0005433151796	F2D223	1860 454951	OLGA GAVRILOVA	{"email": "olga_gavrilova.10081969@postgrespro.ru", "phone": "+70240464533"}
0005433151797	111B01	8029 175596	OLEG MAKSIMOV	{"email": "oleg_maksimov-1964@postgrespro.ru", "phone": "+70010480004"}
0005433151798	111B01	3005 795179	MARIYA SCHERBAKOVA	{"email": "scherbakovam_28011966@postgrespro.ru", "phone": "+70608498970"}
0005433151799	00CE91	0247 955143	DENIS IVANOV	{"email": "ivanovdenis1970@postgrespro.ru", "phone": "+70152690980"}
0005433151800	8061F4	1864 850282	YANA FOMINA	{"email": "fomina.yana1982@postgrespro.ru", "phone": "+70547086909"}
0005433151801	194950	3327 767094	ALEKSEY SCHERBAKOV	{"email": "scherbakov.a-101975@postgrespro.ru", "phone": "+70748725335"}
0005433151802	194950	5330 464049	EVGENIY ZAKHAROV	{"phone": "+70271021349"}
0005433151803	F67855	6895 123814	IRINA IVANOVA	{"phone": "+70064350013"}
0005433151804	F67855	1506 088024	ANATOLIY GRIGOREV	{"email": "grigorev.a1969@postgrespro.ru", "phone": "+70877730832"}
0005433151805	BB3422	8530 340267	VALENTINA NESTEROVA	{"email": "nesterovav-101965@postgrespro.ru", "phone": "+70379796796"}
0005433151806	187BA5	3670 580241	YULIYA KOZLOVA	{"email": "kozlova.y.051972@postgrespro.ru", "phone": "+70884020414"}
0005433151807	187BA5	0133 824053	EVGENIYA FROLOVA	{"phone": "+70792248301"}
0005433151808	164404	1522 867887	ELENA KULIKOVA	{"email": "elena-kulikova_16041972@postgrespro.ru", "phone": "+70861735886"}
0005433151809	B09C4D	9164 678559	ALINA LOGINOVA	{"email": "a-loginova.20071974@postgrespro.ru", "phone": "+70223419058"}
0005433151810	470DD7	1961 262571	PETR FEDOTOV	{"phone": "+70110118554"}
0005433151811	66E2D3	8591 098241	ALEKSEY SOROKIN	{"phone": "+70953486657"}
0005433151812	4A27AE	4741 105798	SERGEY KUDRYASHOV	{"phone": "+70354616876"}
0005433151813	BF4F78	4067 469461	EKATERINA GUSEVA	{"phone": "+70275941675"}
0005433151814	BF4F78	2522 418848	ELENA PETROVA	{"email": "petrovaelena_1965@postgrespro.ru", "phone": "+70558711377"}
0005433151815	739FBC	0226 665427	SVETLANA BELOVA	{"phone": "+70279714661"}
0005433151816	847C01	2732 830022	YURIY KAZAKOV	{"phone": "+70925297875"}
0005433151817	B9358B	6995 303089	SERGEY OSIPOV	{"email": "sergey_osipov-1988@postgrespro.ru", "phone": "+70389727075"}
0005433151818	0C0213	1191 694443	ANNA MIKHAYLOVA	{"email": "a.mikhaylova.07041965@postgrespro.ru", "phone": "+70332277145"}
0005433151819	870CFD	0501 331451	ELENA EFIMOVA	{"email": "eefimova-16031979@postgrespro.ru", "phone": "+70632705703"}
0005433151820	09A5E3	9336 598556	VLADIMIR MOROZOV	{"phone": "+70470986216"}
0005433151821	09A5E3	0246 310270	SERGEY VLASOV	{"phone": "+70230987983"}
0005433151822	E73F5A	9108 665848	OLGA IVANOVA	{"email": "ivanovao101969@postgrespro.ru", "phone": "+70867701186"}
0005433151823	E73F5A	6565 065814	SERGEY NOVIKOV	{"phone": "+70040439071"}
0005433151824	A48DE5	0000 612487	MIKHAIL GRIGOREV	{"phone": "+70703102669"}
0005433151825	CCA700	3568 098742	MIKHAIL DENISOV	{"email": "mikhail.denisov_1972@postgrespro.ru", "phone": "+70260321487"}
0005433151826	F8464B	6993 095012	STANISLAV MOROZOV	{"email": "morozov-stanislav-09031971@postgrespro.ru", "phone": "+70484027943"}
0005433151827	2A90A0	1021 704178	OLEG SCHERBAKOV	{"email": "scherbakovo_091976@postgrespro.ru", "phone": "+70701985906"}
0005433151828	BDC2B1	0960 723517	NADEZHDA ROMANOVA	{"email": "romanovanadezhda.23091970@postgrespro.ru", "phone": "+70029087450"}
0005433151829	D0E0D2	1788 829220	VLADIMIR IVANOV	{"email": "v-ivanov.031972@postgrespro.ru", "phone": "+70724572240"}
0005433151830	E6BA10	8359 608695	VLADIMIR ZHUKOV	{"phone": "+70608784896"}
0005433151831	488514	3283 302153	YURIY ROMANOV	{"email": "romanov_y.22121973@postgrespro.ru", "phone": "+70321580366"}
0005433151832	488514	7070 117489	VALENTINA NOVIKOVA	{"email": "v-novikova051974@postgrespro.ru", "phone": "+70428226751"}
0005433151833	23B99B	8331 656630	VIKTOR SMIRNOV	{"phone": "+70328420211"}
0005433151834	DB8717	2444 303153	IVAN TARASOV	{"email": "itarasov1970@postgrespro.ru", "phone": "+70156777207"}
0005433151835	383275	2287 649912	IGOR MOISEEV	{"email": "i_moiseev_091973@postgrespro.ru", "phone": "+70891596603"}
0005433151836	C4E7DD	5655 710659	VERA MAKAROVA	{"phone": "+70464429684"}
0005433151837	2967AB	3723 578627	LIDIYA YUDINA	{"email": "yudina_lidiya-011982@postgrespro.ru", "phone": "+70538768775"}
0005433151838	17A931	6907 791262	FAINA KULIKOVA	{"phone": "+70901123010"}
0005433151839	FE3576	5443 007006	ELENA ABRAMOVA	{"email": "e.abramova-031983@postgrespro.ru", "phone": "+70863503669"}
0005433151840	C8316F	4438 085974	ALEKSEY MOROZOV	{"email": "aleksey_morozov-1969@postgrespro.ru", "phone": "+70631348657"}
0005433151841	9C8740	5608 100626	RAMIS MARTYNOV	{"email": "r.martynov1976@postgrespro.ru", "phone": "+70566095478"}
0005433151842	2AD5AC	3198 734598	LARISA ABRAMOVA	{"email": "abramova_larisa1973@postgrespro.ru", "phone": "+70450721356"}
0005433151843	8BB932	3340 339935	ALEKSEY VOLKOV	{"phone": "+70772806193"}
0005433151844	1E74C9	8711 223172	ALEKSANDR FROLOV	{"email": "frolov_a.021973@postgrespro.ru", "phone": "+70947693944"}
0005433151845	27CAEA	4921 293488	VLADIMIR SEMENOV	{"email": "semenov_vladimir_101966@postgrespro.ru", "phone": "+70565101798"}
0005433151846	27CAEA	1123 289726	VASILIY PETROV	{"phone": "+70291470115"}
0005433151847	A894E6	9870 351690	ILYA SOLOVEV	{"phone": "+70492030857"}
0005433151848	88D57C	1783 379360	VALENTINA KONDRATEVA	{"phone": "+70843830540"}
0005433151849	E5AAE5	9154 842929	NINA KOVALEVA	{"email": "ninakovaleva_1973@postgrespro.ru", "phone": "+70488037519"}
0005433151850	E5AAE5	4887 901859	MIKHAIL ANDREEV	{"phone": "+70876519792"}
0005433151851	7502AB	2220 967923	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov.081980@postgrespro.ru", "phone": "+70772123288"}
0005433151852	E746F3	9649 665585	LIDIYA ROMANOVA	{"email": "lidiya-romanova-23091964@postgrespro.ru", "phone": "+70038276515"}
0005433151853	E746F3	1770 953752	PAVEL IVANOV	{"phone": "+70730588569"}
0005433151854	4EC44C	7712 641767	VLADIMIR BELOV	{"email": "belov-v.031973@postgrespro.ru", "phone": "+70949447583"}
0005433151855	3C4C7A	4772 520708	GALINA LAZAREVA	{"email": "g_lazareva.03031978@postgrespro.ru", "phone": "+70551632288"}
0005433151856	94331D	7568 090326	ALEKSEY PAVLOV	{"email": "pavlov_aleksey.11011966@postgrespro.ru", "phone": "+70316684946"}
0005433151857	801FE0	3857 005912	SVETLANA DANILOVA	{"email": "svetlana.danilova.091977@postgrespro.ru", "phone": "+70522750206"}
0005433151858	801FE0	6713 714519	ELENA TROFIMOVA	{"email": "trofimova.e-29081971@postgrespro.ru", "phone": "+70952130943"}
0005433151859	B7CC44	4165 912064	NIKOLAY OSIPOV	{"phone": "+70110398461"}
0005433151860	B7CC44	3354 734448	RIMMA MAKSIMOVA	{"phone": "+70732090056"}
0005433151861	120905	2861 184157	SERGEY TARASOV	{"email": "sergey-tarasov_1960@postgrespro.ru", "phone": "+70338446593"}
0005433151862	8D6350	6836 080135	YANA MEDVEDEVA	{"email": "yana.medvedeva081978@postgrespro.ru", "phone": "+70630588164"}
0005433151863	FD03A7	9002 096731	OLEG VOLKOV	{"phone": "+70706255484"}
0005433151864	F2F410	1536 927731	NATALYA RYABOVA	{"email": "ryabova_natalya_21051976@postgrespro.ru", "phone": "+70640956261"}
0005433151865	824B01	5432 067018	ZINAIDA KOLESNIKOVA	{"email": "kolesnikovazinaida.1969@postgrespro.ru", "phone": "+70201158225"}
0005433151866	D11599	5571 446314	ANASTASIYA DMITRIEVA	{"phone": "+70290479981"}
0005433151867	D11599	8705 823832	IGOR MOROZOV	{"phone": "+70655204748"}
0005433151868	86DC0C	6372 461589	ANDREY ZAYCEV	{"email": "andrey-zaycev-10031972@postgrespro.ru", "phone": "+70784356251"}
0005433151869	D90AED	9699 559084	EDUARD STEPANOV	{"email": "eduard-stepanov081983@postgrespro.ru", "phone": "+70850661995"}
0005433151870	CA849A	0122 017470	EVGENIY ROMANOV	{"phone": "+70383291429"}
0005433151871	F64D41	1959 957461	NIKOLAY VLASOV	{"email": "n-vlasov1970@postgrespro.ru", "phone": "+70190682804"}
0005433151872	C65FDC	5301 072373	YURIY SIDOROV	{"phone": "+70213995977"}
0005433151873	CC7505	4604 659794	RIMMA SEMENOVA	{"email": "semenova_r_01011975@postgrespro.ru", "phone": "+70527765131"}
0005433151874	CC7505	2924 333083	DANIIL PAVLOV	{"email": "pavlovdaniil1967@postgrespro.ru", "phone": "+70819053870"}
0005433151875	6A8911	1537 644692	MAKSIM MAKSIMOV	{"phone": "+70718839225"}
0005433151876	609B81	3948 532279	LYUBOV MIRONOVA	{"phone": "+70231758531"}
0005433151877	609B81	7658 430863	SVETLANA PAVLOVA	{"phone": "+70343522462"}
0005433151878	9BF315	5647 557352	EKATERINA NIKITINA	{"email": "enikitina11091968@postgrespro.ru", "phone": "+70401977853"}
0005433151879	9BF315	3314 404011	NINA NOVIKOVA	{"phone": "+70548287334"}
0005433151880	9FB801	3864 608087	PETR POPOV	{"phone": "+70922566108"}
0005433151881	566E06	8395 398639	NADEZHDA VLASOVA	{"phone": "+70626517804"}
0005433151882	EC7A3F	6316 431450	TATYANA SEMENOVA	{"phone": "+70094931718"}
0005433151883	EC7A3F	5228 358707	ANASTASIYA ZHUKOVA	{"phone": "+70973313102"}
0005433151884	FFE691	8706 772337	DARINA SOLOVEVA	{"email": "darina.soloveva-13081973@postgrespro.ru", "phone": "+70423877001"}
0005433151885	FFE691	2486 744602	ANNA ISAEVA	{"email": "isaevaa051961@postgrespro.ru", "phone": "+70417762628"}
0005433151886	3A9391	3289 312975	ELENA KUZNECOVA	{"phone": "+70443361641"}
0005433151887	3A9391	6532 899818	PETR NAZAROV	{"phone": "+70895505542"}
0005433151888	EC9874	3358 537940	ALINA KOZLOVA	{"email": "kozlova.alina_101971@postgrespro.ru", "phone": "+70746181077"}
0005433151889	BA7278	8738 068686	OLGA KUZMINA	{"email": "olga_kuzmina_1960@postgrespro.ru", "phone": "+70625393403"}
0005433151890	058E36	0759 951165	ALEKSEY BELOV	{"phone": "+70614422651"}
0005433151891	058E36	9296 390386	ALEKSANDR OSIPOV	{"phone": "+70897348081"}
0005433151892	9C6209	8057 889404	ANNA FADEEVA	{"phone": "+70559461406"}
0005433152012	1E6152	1514 456606	VALENTINA IVANOVA	{"phone": "+70433831176"}
0005433151893	9C6209	6750 286749	PAVEL GRIGOREV	{"email": "pavelgrigorev-1977@postgrespro.ru", "phone": "+70219022653"}
0005433151894	D1565A	6760 306184	ANATOLIY BORISOV	{"email": "aborisov041974@postgrespro.ru", "phone": "+70170414834"}
0005433151895	FECFBF	2119 195368	SVETLANA MATVEEVA	{"email": "svetlana-matveeva111968@postgrespro.ru", "phone": "+70529043282"}
0005433151896	C38DAE	5908 840225	RASHID ZAKHAROV	{"phone": "+70975880839"}
0005433151897	04377F	7006 598671	ALEKSEY SOKOLOV	{"email": "a_sokolov21011976@postgrespro.ru", "phone": "+70406356995"}
0005433151898	04377F	4897 153032	TAMARA DMITRIEVA	{"phone": "+70329470575"}
0005433151899	514481	9444 567935	MAKSIM KISELEV	{"phone": "+70072401364"}
0005433151900	B580B9	9263 364323	ANASTASIYA KALININA	{"email": "akalinina-111966@postgrespro.ru", "phone": "+70692883191"}
0005433151901	B580B9	6154 650399	ANTONINA MAKSIMOVA	{"email": "a-maksimova.071968@postgrespro.ru", "phone": "+70759844394"}
0005433151902	63257D	0485 527078	YURIY SEMENOV	{"email": "semenov.y_1972@postgrespro.ru", "phone": "+70601586839"}
0005433151903	6D82ED	0443 910172	VITALIY KULIKOV	{"phone": "+70320539960"}
0005433151904	CA4DE0	7612 989086	ELENA SOKOLOVA	{"email": "elenasokolova.1960@postgrespro.ru", "phone": "+70945087977"}
0005433151905	723B05	6887 837253	SERGEY KAZAKOV	{"email": "skazakov-081963@postgrespro.ru", "phone": "+70781394556"}
0005433151906	3F2214	3824 887324	ALEKSANDR ORLOV	{"email": "a.orlov.05091970@postgrespro.ru", "phone": "+70779783819"}
0005433151907	4D025F	8533 275773	ANDREY MARTYNOV	{"email": "andrey.martynov011979@postgrespro.ru", "phone": "+70092721960"}
0005433151908	FA2968	8090 105120	ELMIRA POPOVA	{"email": "elmira_popova.1966@postgrespro.ru", "phone": "+70154228451"}
0005433151909	FA2968	2161 609708	ILYA KUZNECOV	{"phone": "+70752835745"}
0005433151910	EE442C	6372 773623	SVETLANA MIRONOVA	{"email": "mironova.svetlana.1984@postgrespro.ru", "phone": "+70596349884"}
0005433151911	DD8025	1537 114615	MAKSIM EGOROV	{"email": "maksim-egorov_1972@postgrespro.ru", "phone": "+70375924902"}
0005433151912	AAAED8	7288 735013	ALEKSANDR ORLOV	{"phone": "+70095837625"}
0005433151913	AAAED8	3179 188935	EKATERINA STEPANOVA	{"phone": "+70327447095"}
0005433151914	AAD386	6766 029560	YURIY MIRONOV	{"phone": "+70545423639"}
0005433151915	F1A3B0	3049 764414	VLADIMIR POPOV	{"phone": "+70470983223"}
0005433151916	F1A3B0	8555 459515	EVGENIY NIKOLAEV	{"phone": "+70896503291"}
0005433151917	7D94DE	7159 527393	YURIY KUZMIN	{"email": "kuzmin-yuriy-061963@postgrespro.ru", "phone": "+70351598801"}
0005433151918	16CF75	7502 616434	DMITRIY ILIN	{"email": "dmitriyilin101974@postgrespro.ru", "phone": "+70904224580"}
0005433151919	16CF75	1139 511940	NATALYA KUZNECOVA	{"email": "nkuznecova091980@postgrespro.ru", "phone": "+70791396200"}
0005433151920	593AEB	1085 587915	VYACHESLAV KUZMIN	{"email": "vyacheslav_kuzmin081967@postgrespro.ru", "phone": "+70832101121"}
0005433151921	2FCE8A	7287 262352	OLGA LEBEDEVA	{"email": "o-lebedeva.1960@postgrespro.ru", "phone": "+70599717132"}
0005433151922	1C319C	4881 728581	SERGEY POPOV	{"phone": "+70909502088"}
0005433151923	B6ABFB	7998 871444	RADMIR DAVYDOV	{"email": "radmir-davydov-12031970@postgrespro.ru", "phone": "+70419073223"}
0005433151924	B6ABFB	1418 851390	ALEKSEY MAKSIMOV	{"phone": "+70954260044"}
0005433151925	38B6DA	9139 503337	KLAVDIYA PETROVA	{"phone": "+70128670447"}
0005433151926	38B6DA	0653 350132	MARIYA GAVRILOVA	{"email": "mariya-gavrilova061960@postgrespro.ru", "phone": "+70623231414"}
0005433151927	DF8F76	4357 237945	ALEKSANDR ORLOV	{"phone": "+70180619149"}
0005433151928	80FF4D	1688 491386	ALEKSANDRA VASILEVA	{"phone": "+70330812993"}
0005433151929	34EE5A	1557 901991	EVGENIY BELOV	{"email": "belov_evgeniy_081961@postgrespro.ru", "phone": "+70379592318"}
0005433151930	DA2682	2178 003619	YAKOV VASILEV	{"phone": "+70943759140"}
0005433151931	135F0F	9445 375680	DENIS ZAKHAROV	{"email": "d_zakharov_1960@postgrespro.ru", "phone": "+70387409978"}
0005433151932	135F0F	1996 843622	RUFINA ZAYCEVA	{"email": "rufinazayceva_1972@postgrespro.ru", "phone": "+70085990547"}
0005433151933	9E72CE	3498 913992	LYUBOV ALEKSEEVA	{"phone": "+70967428817"}
0005433151934	144F0C	0296 901911	ALEKSANDR PETROV	{"email": "petrova_1962@postgrespro.ru", "phone": "+70524064814"}
0005433151935	97C218	4963 553846	NIKOLAY SHEVCHENKO	{"email": "nikolay-shevchenko_091973@postgrespro.ru", "phone": "+70412849606"}
0005433151936	7A56F6	4057 671856	VALERIY IVANOV	{"phone": "+70648928172"}
0005433151937	B3FD77	9616 225836	SERGEY ORLOV	{"email": "sergey_orlov_1982@postgrespro.ru", "phone": "+70604672120"}
0005433151938	C42020	3022 257189	NATALIYA POPOVA	{"email": "popova-n1973@postgrespro.ru", "phone": "+70259151613"}
0005433151939	C42020	2686 438485	SERGEY SMIRNOV	{"phone": "+70242829341"}
0005433151940	FD2C8B	6446 787387	IRINA VOROBEVA	{"phone": "+70239793047"}
0005433151941	FD2C8B	1372 306426	NATALYA NAZAROVA	{"email": "nazarova.natalya.29061976@postgrespro.ru", "phone": "+70930955969"}
0005433151942	E62933	7473 059799	MAKSIM FEDOROV	{"phone": "+70741099017"}
0005433151943	0777E2	0938 104880	VLADIMIR ALEKSANDROV	{"phone": "+70940871209"}
0005433151944	5891E0	2499 598363	VLADIMIR TIKHONOV	{"email": "tikhonov.v.021979@postgrespro.ru", "phone": "+70844671550"}
0005433151945	5891E0	0798 664029	OLGA KOZLOVA	{"email": "kozlova_olga_25101974@postgrespro.ru", "phone": "+70899909655"}
0005433151946	E31ED2	1017 340701	ALEKSEY FROLOV	{"email": "frolov_a-18071976@postgrespro.ru", "phone": "+70095439896"}
0005433151947	7F9F4E	4546 163848	OKSANA KOZLOVA	{"phone": "+70393245621"}
0005433151948	7B0343	4567 241239	VLADIMIR NIKOLAEV	{"phone": "+70605157266"}
0005433151949	7B0343	7058 273196	SVETLANA POPOVA	{"email": "popova.svetlana-1978@postgrespro.ru", "phone": "+70724106563"}
0005433151950	BE8F4B	6719 008158	ELENA PETROVA	{"phone": "+70256487443"}
0005433151951	BB4CA4	6088 129078	NATALYA DMITRIEVA	{"email": "dmitrieva.natalya_30041955@postgrespro.ru", "phone": "+70837412239"}
0005433151952	CCCC94	0704 106510	SERGEY GRIGOREV	{"email": "grigorevsergey061968@postgrespro.ru", "phone": "+70872480124"}
0005433151953	A900FE	5337 795947	VYACHESLAV OSIPOV	{"email": "v-osipov_26051964@postgrespro.ru", "phone": "+70369083689"}
0005433151954	8E0FB5	3039 563180	VALENTINA LAZAREVA	{"phone": "+70398143494"}
0005433151955	D2D93E	0095 893852	DINA MAKSIMOVA	{"phone": "+70268674952"}
0005433151956	D2D93E	6923 196519	TATYANA MASLOVA	{"phone": "+70513375994"}
0005433151957	FB7D8A	1429 059968	YULIYA ZAYCEVA	{"phone": "+70276816764"}
0005433151958	5A0E4A	6538 414585	TATYANA ANDREEVA	{"email": "andreeva.t_061970@postgrespro.ru", "phone": "+70249731362"}
0005433151959	5A0E4A	8774 374629	ANNA ROMANOVA	{"email": "a_romanova.22011966@postgrespro.ru", "phone": "+70917095684"}
0005433151960	039D90	0559 613878	EKATERINA FADEEVA	{"phone": "+70967429384"}
0005433151961	A183C4	1713 857268	VLADIMIR SOROKIN	{"email": "sorokin.v1978@postgrespro.ru", "phone": "+70654512370"}
0005433151962	197163	1571 004909	VIKTOR BORISOV	{"phone": "+70927021901"}
0005433151964	197163	0954 139537	SVETLANA SAVELEVA	{"email": "svetlana-saveleva-18101965@postgrespro.ru", "phone": "+70994045356"}
0005433151965	61D7A2	0887 077709	LYUDMILA ERMAKOVA	{"email": "ermakova.l_1972@postgrespro.ru", "phone": "+70804471560"}
0005433151966	61D7A2	7284 121940	VLADIMIR ILIN	{"email": "vladimir.ilin_011970@postgrespro.ru", "phone": "+70027762684"}
0005433151967	59D57F	3067 527619	ANDREY GRIGOREV	{"email": "andrey-grigorev_1967@postgrespro.ru", "phone": "+70026605477"}
0005433151968	59D57F	2101 784144	SOFIYA BELYAEVA	{"email": "belyaevasofiya-051981@postgrespro.ru", "phone": "+70867908373"}
0005433151969	4CA3B8	9273 886246	TATYANA ZHUKOVA	{"phone": "+70579670684"}
0005433151970	903E8B	5237 630710	LIDIYA DMITRIEVA	{"phone": "+70530484484"}
0005433151971	EAECBF	9181 942709	SERGEY GORBUNOV	{"phone": "+70604522554"}
0005433151972	05E4C8	2224 492490	EVGENIYA SCHERBAKOVA	{"email": "escherbakova.15121977@postgrespro.ru", "phone": "+70567711934"}
0005433151973	DFC969	6176 044251	SVETLANA POLYAKOVA	{"email": "polyakova_svetlana081982@postgrespro.ru", "phone": "+70143319541"}
0005433151974	849ABD	5656 280557	PETR KARPOV	{"phone": "+70623787399"}
0005433151975	173894	9312 651485	ANTONINA LEBEDEVA	{"phone": "+70532538948"}
0005433151976	22CF96	9889 677688	ANASTASIYA BOGDANOVA	{"email": "a_bogdanova17081963@postgrespro.ru", "phone": "+70080234771"}
0005433151977	D5A31F	4196 254652	YULIYA TIKHONOVA	{"email": "tikhonova-y-1978@postgrespro.ru", "phone": "+70206189987"}
0005433151978	B8EA41	2658 867011	ALEKSANDR VOROBEV	{"email": "aleksandr.vorobev.1984@postgrespro.ru", "phone": "+70870200801"}
0005433151979	F6DD0B	0534 965842	LILIYA KRASNOVA	{"email": "l.krasnova021973@postgrespro.ru", "phone": "+70543348739"}
0005433151980	484754	4336 491967	EVGENIY ANTONOV	{"email": "evgeniy.antonov20021969@postgrespro.ru", "phone": "+70224023800"}
0005433151981	3A3589	8795 773362	TATYANA DENISOVA	{"email": "denisova_t.1955@postgrespro.ru", "phone": "+70714905113"}
0005433151982	3A3589	5889 986360	RAISA MARTYNOVA	{"phone": "+70554215599"}
0005433151983	508FB1	1408 881546	TATYANA GORBUNOVA	{"phone": "+70394897071"}
0005433151984	508FB1	6025 346725	ANDREY DMITRIEV	{"email": "andrey.dmitriev15061968@postgrespro.ru", "phone": "+70682400513"}
0005433151985	0C8F3A	1729 071303	LEV SOLOVEV	{"email": "solovev-l-06011973@postgrespro.ru", "phone": "+70625617012"}
0005433151986	9B8812	4712 675190	NIKITA GRIGOREV	{"phone": "+70078884269"}
0005433151987	F141A4	8256 871374	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir1974@postgrespro.ru", "phone": "+70897005928"}
0005433151988	2BB59B	0136 055244	NATALYA KOROLEVA	{"phone": "+70371672370"}
0005433151989	795929	2762 263269	SVETLANA SEMENOVA	{"phone": "+70495665967"}
0005433151990	AECF99	5213 084484	NATALYA ERMAKOVA	{"email": "natalya_ermakova_1973@postgrespro.ru", "phone": "+70786576020"}
0005433151991	5CA526	6747 489220	ALEKSEY NOVIKOV	{"email": "novikov.a_1985@postgrespro.ru", "phone": "+70229468184"}
0005433151992	DBF2E4	1750 948003	GALINA YAKOVLEVA	{"phone": "+70424141887"}
0005433151993	750876	6462 937684	EVGENIYA TIMOFEEVA	{"phone": "+70078805789"}
0005433151994	4DB18A	6404 421862	SERGEY BORISOV	{"phone": "+70193456931"}
0005433151995	4DB18A	3839 700342	DAMIR SIDOROV	{"email": "damir_sidorov1976@postgrespro.ru", "phone": "+70665412543"}
0005433151996	E70341	7609 907898	RUSLAN SERGEEV	{"phone": "+70567702445"}
0005433151997	A4C457	1705 303415	KSENIYA EGOROVA	{"email": "egorova_kseniya-051977@postgrespro.ru", "phone": "+70588115684"}
0005433151998	540CEC	1420 718217	OLEG RODIONOV	{"phone": "+70022802506"}
0005433151999	09C90C	1960 873544	NINA MARTYNOVA	{"phone": "+70576544406"}
0005433152000	F18DE4	9525 399338	VIKTOR PETROV	{"email": "petrovv081962@postgrespro.ru", "phone": "+70738987387"}
0005433152001	89454E	0255 132712	VITALIY NOVIKOV	{"email": "vitaliy.novikov_091968@postgrespro.ru", "phone": "+70943959064"}
0005433152002	C1BCC0	2013 792463	MIKHAIL EGOROV	{"phone": "+70563875204"}
0005433152003	064E93	6773 814992	ANNA FROLOVA	{"email": "anna_frolova-12031971@postgrespro.ru", "phone": "+70410842813"}
0005433152004	F9E857	4810 808245	YURIY MOISEEV	{"phone": "+70001441634"}
0005433152005	EC272D	2018 042732	SERGEY VLASOV	{"email": "sergey-vlasov.1970@postgrespro.ru", "phone": "+70855417728"}
0005433152006	EC272D	8373 101171	ALEKSEY MIRONOV	{"email": "mironov.aleksey-091985@postgrespro.ru", "phone": "+70056290891"}
0005433152007	E8C933	7227 559830	OLGA KOZLOVA	{"email": "okozlova-121967@postgrespro.ru", "phone": "+70099193794"}
0005433152008	D9F2D4	4746 856851	VLADIMIR DAVYDOV	{"phone": "+70225987502"}
0005433152009	EA2F80	3396 530104	EKATERINA SMIRNOVA	{"email": "e.smirnova_031974@postgrespro.ru", "phone": "+70478132276"}
0005433152010	F6597C	2610 516391	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova-04121964@postgrespro.ru", "phone": "+70923957794"}
0005433152011	1E6152	4872 988373	DMITRIY SMIRNOV	{"phone": "+70640858503"}
0005433152013	38146D	6348 689662	MAKSIM POPOV	{"phone": "+70939896456"}
0005433152014	2EE661	7227 426292	LILIYA FEDOROVA	{"email": "l-fedorova09091979@postgrespro.ru", "phone": "+70937736073"}
0005433152015	2EE661	8519 841983	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr_051969@postgrespro.ru", "phone": "+70060894990"}
0005433152016	35AC31	5118 850880	NATALYA MOROZOVA	{"phone": "+70127373040"}
0005433152017	1827A6	7871 723486	PETR SEMENOV	{"email": "semenovpetr.10031966@postgrespro.ru", "phone": "+70039957230"}
0005433152018	0733A4	4914 028145	OLGA KOROLEVA	{"phone": "+70295947167"}
0005433152075	FB12F7	4426 056217	TAISIYA VASILEVA	{"phone": "+70929159412"}
0005433152019	0733A4	9682 527820	ANNA POPOVA	{"email": "anna_popova-121967@postgrespro.ru", "phone": "+70533041859"}
0005433152020	0ECB8C	3899 577068	LIDIYA YAKOVLEVA	{"email": "yakovlevalidiya.1968@postgrespro.ru", "phone": "+70085625917"}
0005433152021	234320	4230 985319	EKATERINA POLYAKOVA	{"email": "e.polyakova_1990@postgrespro.ru", "phone": "+70010328463"}
0005433152022	FF25D0	2064 177041	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n.091967@postgrespro.ru", "phone": "+70788887738"}
0005433152023	9157D2	2931 303751	IGOR KONOVALOV	{"email": "konovalov_i.18111968@postgrespro.ru", "phone": "+70883346870"}
0005433152024	453C2C	3059 856625	NADEZHDA KAZAKOVA	{"phone": "+70652107588"}
0005433152025	BEA456	8809 254998	MARGARITA FILATOVA	{"phone": "+70493353994"}
0005433152026	7A849A	2575 304748	MIKHAIL DENISOV	{"email": "denisov_mikhail.11101970@postgrespro.ru", "phone": "+70302883426"}
0005433152027	7F5177	4354 056362	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova_101966@postgrespro.ru", "phone": "+70937997964"}
0005433152028	CEE2A9	0239 023292	EGOR VOLKOV	{"email": "egor.volkov1958@postgrespro.ru", "phone": "+70803806477"}
0005433152029	CEE2A9	7419 433328	IGOR KUZNECOV	{"email": "kuznecov-igor.101966@postgrespro.ru", "phone": "+70992506391"}
0005433152030	4B01A8	6606 090326	VALENTINA FEDOROVA	{"phone": "+70777827079"}
0005433152031	4B01A8	5350 035184	DMITRIY AFANASEV	{"email": "dmitriyafanasev04031967@postgrespro.ru", "phone": "+70092968750"}
0005433152032	90074F	4958 050162	LYUDMILA SERGEEVA	{"email": "lsergeeva-1969@postgrespro.ru", "phone": "+70665997585"}
0005433152033	B91C98	2383 021660	REGINA KUZNECOVA	{"email": "reginakuznecova06051963@postgrespro.ru", "phone": "+70481329987"}
0005433152034	A7ADB0	3534 392682	ALENA SMIRNOVA	{"email": "a-smirnova_01081976@postgrespro.ru", "phone": "+70898125162"}
0005433152035	A7ADB0	4334 812213	SERGEY MAKSIMOV	{"phone": "+70573472042"}
0005433152036	3E2689	7999 313171	LYUDMILA SOKOLOVA	{"phone": "+70073040527"}
0005433152037	844691	1286 813819	ELENA SOKOLOVA	{"phone": "+70136191171"}
0005433152038	5DCFEE	6149 466561	GRIGORIY ABRAMOV	{"phone": "+70036547293"}
0005433152039	4F3DDD	9190 218755	ANTON FEDOROV	{"email": "fedorov_a-21051977@postgrespro.ru", "phone": "+70412362090"}
0005433152040	3B12B4	9950 503747	EKATERINA SOROKINA	{"email": "sorokinaekaterina.1974@postgrespro.ru", "phone": "+70779391038"}
0005433152041	3B12B4	5914 807214	SVETLANA KISELEVA	{"email": "svetlanakiseleva-031972@postgrespro.ru", "phone": "+70256057173"}
0005433152042	85CD6B	6169 378461	TATYANA POTAPOVA	{"phone": "+70359808103"}
0005433152043	118372	1486 004683	NATALIYA LAZAREVA	{"phone": "+70982288943"}
0005433152044	235ADF	6363 125515	RUSLAN KARPOV	{"email": "r_karpov22041977@postgrespro.ru", "phone": "+70504765289"}
0005433152045	235ADF	7745 854939	MARIYA FROLOVA	{"phone": "+70737460321"}
0005433152046	235ADF	7519 174930	RAMIL FROLOV	{"email": "r_frolov-051975@postgrespro.ru", "phone": "+70105689917"}
0005433152047	E8CE8E	4520 924124	ALEKSEY VOLKOV	{"email": "volkova.1965@postgrespro.ru", "phone": "+70174252384"}
0005433152048	7EB295	7918 851596	MIKHAIL SERGEEV	{"phone": "+70268161648"}
0005433152049	524132	7812 314174	ALEKSANDR KUZNECOV	{"email": "a_kuznecov-021968@postgrespro.ru", "phone": "+70142692695"}
0005433152050	9235E6	8153 767820	VALENTINA IVANOVA	{"phone": "+70118414357"}
0005433152051	B2FF51	9148 578110	ELIZAVETA MAKAROVA	{"email": "e.makarova-12021974@postgrespro.ru", "phone": "+70636806170"}
0005433152052	B2FF51	4637 372195	ALEKSEY SHEVCHENKO	{"email": "shevchenko-aleksey.12091973@postgrespro.ru", "phone": "+70162229124"}
0005433152053	7C37A0	4802 086190	OKSANA SEMENOVA	{"email": "oksana_semenova.1970@postgrespro.ru", "phone": "+70178694327"}
0005433152054	7C37A0	3130 598251	SERGEY BARANOV	{"phone": "+70130128272"}
0005433152055	EF54BE	9140 408792	VADIM GORBUNOV	{"email": "vadim_gorbunov121970@postgrespro.ru", "phone": "+70122486407"}
0005433152056	EF54BE	7143 221391	ALEKSANDR KAZAKOV	{"phone": "+70221807737"}
0005433152057	B7CD8E	5409 272628	IVAN ANTONOV	{"phone": "+70982950786"}
0005433152058	B7CD8E	0941 072939	VASILIY POPOV	{"email": "vpopov_101961@postgrespro.ru", "phone": "+70406292974"}
0005433152059	FEAF79	4001 451534	GALINA MEDVEDEVA	{"phone": "+70496525208"}
0005433152060	A4A474	4211 799053	VLADIMIR SHEVCHENKO	{"email": "shevchenko_vladimir-06081970@postgrespro.ru", "phone": "+70896168771"}
0005433152061	5CA18D	2295 800813	DANILA ZAKHAROV	{"phone": "+70347360278"}
0005433152062	2D7E2E	9701 650288	ALEKSANDR NOVIKOV	{"email": "anovikov_23021972@postgrespro.ru", "phone": "+70855938520"}
0005433152063	B1FAA8	9433 292459	GENNADIY MAKAROV	{"email": "makarov_gennadiy-1966@postgrespro.ru", "phone": "+70460667296"}
0005433152064	7A7123	2505 489145	IVAN BORISOV	{"email": "ivan.borisov-1976@postgrespro.ru", "phone": "+70512608434"}
0005433152065	7A7123	9748 783362	ALEKSANDRA NIKITINA	{"phone": "+70362043432"}
0005433152066	50E9C1	8669 713265	RIMMA FILIPPOVA	{"email": "rimmafilippova_1972@postgrespro.ru", "phone": "+70050343875"}
0005433152067	1EE775	0155 799649	LYUDMILA SEMENOVA	{"phone": "+70499657564"}
0005433152068	1EE775	9505 691723	IRINA KUZNECOVA	{"email": "irina-kuznecova1962@postgrespro.ru", "phone": "+70311696367"}
0005433152069	449101	9350 670188	OLGA MAKSIMOVA	{"phone": "+70254165974"}
0005433152070	E3A5C0	0367 611340	RUSLAN BARANOV	{"phone": "+70912874388"}
0005433152071	68A5CA	2466 475882	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov.111990@postgrespro.ru", "phone": "+70611220791"}
0005433152072	35BB09	4477 599327	ALEKSANDR KULIKOV	{"email": "a.kulikov-07011987@postgrespro.ru", "phone": "+70994221275"}
0005433152073	35BB09	8569 557827	KRISTINA MOROZOVA	{"phone": "+70317502416"}
0005433152076	F2C7B3	4151 379761	EVGENIYA PAVLOVA	{"phone": "+70150500140"}
0005433152077	F2C7B3	3038 665761	SVETLANA MIRONOVA	{"phone": "+70532901706"}
0005433152078	816C48	5006 483670	YULIYA MAKSIMOVA	{"email": "y.maksimova_071971@postgrespro.ru", "phone": "+70218328236"}
0005433152079	0615C4	5079 409551	RENATA KOZLOVA	{"email": "r-kozlova-07041982@postgrespro.ru", "phone": "+70913944302"}
0005433152080	0615C4	8194 010577	VLADIMIR FILIPPOV	{"phone": "+70712885329"}
0005433152081	2F8203	0330 354961	VALENTINA ERMAKOVA	{"email": "ermakova_valentina.041966@postgrespro.ru", "phone": "+70551676460"}
0005433152082	66597E	8912 022898	ARKADIY KOZLOV	{"email": "kozlovarkadiy101967@postgrespro.ru", "phone": "+70133777988"}
0005433152083	F6F202	6677 309207	KIRA ANTONOVA	{"phone": "+70275880451"}
0005433152084	5EDAFB	4940 832920	NINA FILIPPOVA	{"email": "ninafilippova.1969@postgrespro.ru", "phone": "+70051062707"}
0005433152085	A0BA1F	3103 250604	VLADIMIR GUSEV	{"email": "gusev_v-101969@postgrespro.ru", "phone": "+70750085634"}
0005433152086	E6E6B8	2204 876460	IVAN ZHUKOV	{"email": "zhukovi1958@postgrespro.ru", "phone": "+70384869510"}
0005433152087	E6E6B8	5053 869163	TATYANA ANTONOVA	{"phone": "+70557434129"}
0005433152088	E6E6B8	1430 370554	ANDREY VOLKOV	{"email": "volkov.a_16051977@postgrespro.ru", "phone": "+70255076461"}
0005433152089	2F70D8	9820 014495	VYACHESLAV IVANOV	{"email": "ivanov-v1967@postgrespro.ru", "phone": "+70515781245"}
0005433152090	2F70D8	7243 551412	VALERIY KISELEV	{"phone": "+70406390480"}
0005433152091	2F70D8	1964 114408	IRINA PETROVA	{"email": "i.petrova-17081971@postgrespro.ru", "phone": "+70124363487"}
0005433152092	159F0D	7225 728977	ELENA KUZMINA	{"phone": "+70114518265"}
0005433152093	89C526	2022 004136	ALEKSANDR KUDRYASHOV	{"phone": "+70884139765"}
0005433152094	3F51B4	4641 623291	ELENA POPOVA	{"phone": "+70828058806"}
0005433152095	C4266C	4675 006473	RENAT MARTYNOV	{"email": "r.martynov07121976@postgrespro.ru", "phone": "+70281421279"}
0005433152096	C4266C	2509 860245	OLGA GORBUNOVA	{"phone": "+70057824532"}
0005433152097	BBE703	2122 053831	ALEKSANDR KUZNECOV	{"email": "kuznecova-101970@postgrespro.ru", "phone": "+70910053843"}
0005433152098	BBE703	6661 248146	ILYA ROMANOV	{"phone": "+70089533794"}
0005433152099	F4A102	2070 448406	OLGA DANILOVA	{"email": "odanilova_25081975@postgrespro.ru", "phone": "+70527263318"}
0005433152100	F624BD	8924 860237	ANNA BORISOVA	{"email": "a_borisova.25091971@postgrespro.ru", "phone": "+70284157675"}
0005433152101	5125C7	8233 386227	NIKITA ORLOV	{"email": "orlov-nikita_09011963@postgrespro.ru", "phone": "+70177313889"}
0005433152102	5125C7	7086 134105	KONSTANTIN MAKSIMOV	{"email": "k_maksimov-11051967@postgrespro.ru", "phone": "+70244308932"}
0005433152103	AC0E80	9437 814128	ANATOLIY KISELEV	{"email": "a_kiselev.071960@postgrespro.ru", "phone": "+70995770152"}
0005433152104	ED4BB1	7650 553383	YURIY FROLOV	{"phone": "+70262002533"}
0005433152105	ED4BB1	2049 572789	YULIYA SEMENOVA	{"email": "y_semenova-1967@postgrespro.ru", "phone": "+70362778859"}
0005433152106	8984D2	5424 119331	VLADIMIR MEDVEDEV	{"phone": "+70289857765"}
0005433152107	7984FA	3059 443735	ALEKSANDR KUZNECOV	{"phone": "+70086834394"}
0005433152108	7984FA	8450 533628	GALINA ANISIMOVA	{"phone": "+70896969075"}
0005433152109	18D0DA	0211 926663	OLGA ZAKHAROVA	{"email": "zakharova-olga.11101974@postgrespro.ru", "phone": "+70543054099"}
0005433152110	C16180	5433 119404	NIKOLAY MOROZOV	{"phone": "+70583669424"}
0005433152111	C16180	2280 397818	RAVZA NIKITINA	{"phone": "+70098486459"}
0005433152112	3EF242	4643 274922	NINA NESTEROVA	{"phone": "+70951829604"}
0005433152113	B76BA4	9624 000949	IRINA BORISOVA	{"email": "borisova_irina25091972@postgrespro.ru", "phone": "+70009295653"}
0005433152114	B76BA4	2414 204175	ILGIZ GUSEV	{"email": "ilgiz-gusev-28111985@postgrespro.ru", "phone": "+70021953225"}
0005433152115	D3E13F	6385 288370	VLADIMIR MOROZOV	{"phone": "+70327882500"}
0005433152116	D3E13F	6294 906994	LEONID EGOROV	{"phone": "+70350866899"}
0005433152117	6CAF5F	1527 927483	TATYANA STEPANOVA	{"email": "stepanovat_23121968@postgrespro.ru", "phone": "+70576757004"}
0005433152118	24C94E	8792 308774	ANNA KOZLOVA	{"email": "annakozlova-121971@postgrespro.ru", "phone": "+70511637726"}
0005433152119	3ED7F8	9865 824079	EKATERINA MATVEEVA	{"phone": "+70670650219"}
0005433152120	3ED7F8	3541 236113	IVAN ZAKHAROV	{"phone": "+70445989072"}
0005433152121	3ED7F8	1454 208237	REGINA EFIMOVA	{"phone": "+70354688579"}
0005433152122	85CF6F	7059 373116	NATALYA MAKAROVA	{"email": "n-makarova1972@postgrespro.ru", "phone": "+70388004420"}
0005433152123	3EE912	4307 481525	GENNADIY KULIKOV	{"email": "g.kulikov.1981@postgrespro.ru", "phone": "+70067409483"}
0005433152124	3EE912	7750 846718	YULIYA IVANOVA	{"email": "ivanova.y-1967@postgrespro.ru", "phone": "+70147719326"}
0005433152125	A7B69D	5939 022127	LYUBOV PAVLOVA	{"email": "pavlova.l08111976@postgrespro.ru", "phone": "+70594263399"}
0005433152126	14EE04	8634 102142	ZHANNA BELYAEVA	{"phone": "+70321964935"}
0005433152127	C9EDBA	8562 067506	SERGEY SOKOLOV	{"email": "sokolov.sergey.23021978@postgrespro.ru", "phone": "+70210821210"}
0005433152128	BE992B	7909 452368	IVAN ANDREEV	{"phone": "+70367741002"}
0005433152129	BE992B	4459 889696	DINARA MIKHAYLOVA	{"email": "mikhaylova.dinara_05061980@postgrespro.ru", "phone": "+70396114213"}
0005433152130	36ED07	5486 892799	MARIYA KOVALEVA	{"email": "kovaleva_mariya-1978@postgrespro.ru", "phone": "+70152517419"}
0005433152131	1672B5	2655 787627	ALEKSEY BORISOV	{"email": "borisov_a-011966@postgrespro.ru", "phone": "+70341039614"}
0005433152132	F2739A	0373 995293	LYUDMILA NAUMOVA	{"phone": "+70380901788"}
0005433152133	F2739A	1461 118415	ANATOLIY DENISOV	{"phone": "+70460941517"}
0005433152134	06ECF8	4604 056365	OKSANA OSIPOVA	{"phone": "+70539833313"}
0005433152135	7F5680	5093 515417	ELENA YAKOVLEVA	{"email": "elenayakovleva.1984@postgrespro.ru", "phone": "+70109202864"}
0005433152136	C0E4C6	6505 794550	ANDREY OSIPOV	{"phone": "+70317871855"}
0005433152137	A02D17	3867 865746	YULIYA SCHERBAKOVA	{"phone": "+70851237257"}
0005433152138	78EBCB	7298 146916	SERGEY NIKITIN	{"email": "sergey.nikitin_11061976@postgrespro.ru", "phone": "+70996526288"}
0005433152139	F513F5	6432 347217	ALEKSANDR EGOROV	{"email": "egorov-aleksandr091988@postgrespro.ru", "phone": "+70222117203"}
0005433152140	98A364	4493 181019	ALEKSANDR EGOROV	{"email": "egorov_a051966@postgrespro.ru", "phone": "+70458789682"}
0005433152141	6FD25F	1928 411561	VLADIMIR VASILEV	{"email": "vasilevv-101977@postgrespro.ru", "phone": "+70813951916"}
0005433152142	AA06DD	3089 613529	KIRILL ZHURAVLEV	{"phone": "+70585881630"}
0005433152143	CA5FE3	5991 815511	OLEG IVANOV	{"email": "o.ivanov-071967@postgrespro.ru", "phone": "+70213009588"}
0005433152144	3B4D43	6885 479494	ALEKSEY NAUMOV	{"phone": "+70770756558"}
0005433152145	E03077	8738 996852	VADIM SMIRNOV	{"phone": "+70429090653"}
0005433152146	E03077	6551 049797	MIKHAIL FEDOTOV	{"phone": "+70608947569"}
0005433152147	EF8279	2113 416947	NIKOLAY VLASOV	{"phone": "+70724170476"}
0005433152148	30AD30	2681 518164	VITALIY KAZAKOV	{"email": "kazakovvitaliy02031986@postgrespro.ru", "phone": "+70646562354"}
0005433152149	30AD30	1182 962657	EVGENIY VOLKOV	{"email": "volkov.evgeniy.1975@postgrespro.ru", "phone": "+70242409204"}
0005433152150	802264	7756 968649	ZINAIDA POLYAKOVA	{"phone": "+70708087721"}
0005433152151	802264	2155 228824	PAVEL NOVIKOV	{"email": "pavel-novikov24091972@postgrespro.ru", "phone": "+70511832421"}
0005433152152	802264	6599 578053	NATALIYA ANDREEVA	{"phone": "+70233618601"}
0005433152153	2D0980	7317 357957	LYUDMILA RODIONOVA	{"email": "lyudmila.rodionova.041965@postgrespro.ru", "phone": "+70669836111"}
0005433152154	55568A	7818 142936	ANTON CHERNOV	{"phone": "+70010151390"}
0005433152155	424B6F	2361 399455	NIKITA KUZNECOV	{"phone": "+70069900433"}
0005433152156	C89335	2923 264508	GENNADIY ANTONOV	{"email": "antonovg_121962@postgrespro.ru", "phone": "+70804961778"}
0005433152157	967BEE	4424 465259	NATALYA ZHURAVLEVA	{"email": "zhuravleva.n04091958@postgrespro.ru", "phone": "+70503406867"}
0005433152158	55AE76	5754 888874	TAMARA MATVEEVA	{"email": "t-matveeva1970@postgrespro.ru", "phone": "+70895777706"}
0005433152159	39D683	0292 814232	LILIYA MELNIKOVA	{"email": "melnikova-liliya041972@postgrespro.ru", "phone": "+70405639916"}
0005433152160	39D683	3948 410244	LYUBOV KISELEVA	{"phone": "+70103198759"}
0005433152161	1087C4	7779 194441	ARTEM MIRONOV	{"phone": "+70638110760"}
0005433152162	45E203	6449 801760	NIKITA ISAEV	{"phone": "+70486956738"}
0005433152163	AD90E9	5239 396369	VLADIMIR ZHUKOV	{"email": "vzhukov021969@postgrespro.ru", "phone": "+70131971139"}
0005433152164	AD90E9	6678 056629	NIKOLAY CHERNOV	{"email": "chernov-nikolay_1971@postgrespro.ru", "phone": "+70482706211"}
0005433152165	CC40E7	9129 995747	NINA KUZMINA	{"email": "nina_kuzmina.29071964@postgrespro.ru", "phone": "+70475904200"}
0005433152166	CC40E7	5960 007521	LYUDMILA BELOVA	{"phone": "+70522180936"}
0005433152167	A63192	3136 874970	MIKHAIL VASILEV	{"email": "mikhail-vasilev1968@postgrespro.ru", "phone": "+70281579239"}
0005433152168	BB67D2	8626 437211	YURIY KULIKOV	{"phone": "+70897238981"}
0005433152169	9CC84A	6560 269898	ALINA BOGDANOVA	{"email": "a-bogdanova-1965@postgrespro.ru", "phone": "+70446601375"}
0005433152170	CF7A43	8082 571017	LYUDMILA CHERNOVA	{"email": "l.chernova24031968@postgrespro.ru", "phone": "+70724380167"}
0005433152171	0CC93D	8497 957962	OLESYA ZAYCEVA	{"phone": "+70857676513"}
0005433152172	9E00CE	0955 767168	OLGA SIDOROVA	{"email": "olga_sidorova081979@postgrespro.ru", "phone": "+70191248244"}
0005433152173	9E00CE	0885 938848	VLADIMIR KUZNECOV	{"email": "kuznecovv111977@postgrespro.ru", "phone": "+70747369019"}
0005433152174	CE1439	8809 615302	ALEKSANDR NIKOLAEV	{"phone": "+70511568570"}
0005433152175	CE1439	6594 874639	NATALIYA SOROKINA	{"email": "n_sorokina-121978@postgrespro.ru", "phone": "+70190470770"}
0005433152176	CE1439	8080 074528	PELAGEYA MAKAROVA	{"email": "pelageya.makarova1978@postgrespro.ru", "phone": "+70109279002"}
0005433152177	688420	3803 606755	NINA ABRAMOVA	{"phone": "+70946623956"}
0005433152178	93351B	2831 062981	NATALYA POPOVA	{"phone": "+70712367137"}
0005433152179	93351B	8357 141111	TATYANA SOLOVEVA	{"phone": "+70095408691"}
0005433152180	9EC81D	1023 174893	OKSANA VASILEVA	{"phone": "+70957751499"}
0005433152181	5CA74B	6394 519334	SVETLANA KRASNOVA	{"phone": "+70548715658"}
0005433152182	8DA6A8	2098 397761	SERGEY MOISEEV	{"email": "moiseev_s_25041975@postgrespro.ru", "phone": "+70999868228"}
0005433152183	93DB50	7413 346310	VIKTOR MIKHAYLOV	{"email": "mikhaylov-v09081973@postgrespro.ru", "phone": "+70971476146"}
0005433152184	A8A0EA	4114 724489	NATALYA GORBUNOVA	{"email": "gorbunova-n_1970@postgrespro.ru", "phone": "+70517794663"}
0005433152185	C7A3AA	8332 856231	VYACHESLAV SOKOLOV	{"email": "sokolov-vyacheslav_1965@postgrespro.ru", "phone": "+70000391868"}
0005433152186	E3A56E	8380 159150	TATYANA POTAPOVA	{"phone": "+70984011153"}
0005433152187	8C0C4C	2327 356348	TAMARA KUZMINA	{"phone": "+70509871723"}
0005433152188	D93DA0	7966 552049	LYUDMILA LEBEDEVA	{"phone": "+70532752189"}
0005433152189	D93DA0	5080 956102	ANASTASIYA ZOTOVA	{"phone": "+70113979558"}
0005433152190	38ABD1	4976 593279	VENIAMIN SIDOROV	{"phone": "+70365327943"}
0005433152191	1EF29F	1412 262481	MARGARITA VASILEVA	{"phone": "+70466401878"}
0005433152192	1EF29F	2900 924342	LYUDMILA MAKAROVA	{"email": "makarovalyudmila-13041974@postgrespro.ru", "phone": "+70416695870"}
0005433152193	A84C6C	7563 511479	OLGA MAKSIMOVA	{"email": "o.maksimova_121980@postgrespro.ru", "phone": "+70266418587"}
0005433152194	A84C6C	5315 898029	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov1968@postgrespro.ru", "phone": "+70603068401"}
0005433152195	8D99A5	8711 284489	DARYA KARPOVA	{"email": "karpova_darya.1969@postgrespro.ru", "phone": "+70525137787"}
0005433152196	C5798A	7871 374486	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr-1971@postgrespro.ru", "phone": "+70845663204"}
0005433152197	3A5CFB	7011 010632	EVGENIY FOMIN	{"email": "fomin_e1965@postgrespro.ru", "phone": "+70130571690"}
0005433152198	4CD410	4960 496206	ELENA POPOVA	{"phone": "+70707427982"}
0005433152199	4CD410	1432 694336	ILYA FEDOROV	{"phone": "+70500994138"}
0005433152200	B2CF09	8507 519072	LYUDMILA FILATOVA	{"email": "l-filatova-071975@postgrespro.ru", "phone": "+70877905721"}
0005433152201	7BA92F	3784 039093	YURIY KISELEV	{"phone": "+70461185141"}
0005433152202	5DD3AE	8783 757685	IRINA FOMINA	{"email": "fomina-irina.1979@postgrespro.ru", "phone": "+70638955764"}
0005433152203	CB8F6B	8095 639093	EKATERINA FOMINA	{"phone": "+70434527857"}
0005433152204	CB8F6B	3605 139709	PAVEL CHERNOV	{"email": "chernov-pavel-1977@postgrespro.ru", "phone": "+70381844748"}
0005433152205	167FDD	1700 473254	VLADIMIR GAVRILOV	{"email": "v-gavrilov_101970@postgrespro.ru", "phone": "+70544311759"}
0005433152206	167FDD	9032 785253	DANILA SEMENOV	{"phone": "+70824476120"}
0005433152207	E6D85A	1338 016411	SERGEY FILIPPOV	{"email": "filippov.s091972@postgrespro.ru", "phone": "+70281916666"}
0005433152208	D9780B	6999 736490	IGOR KULIKOV	{"email": "igor-kulikov081969@postgrespro.ru", "phone": "+70099272131"}
0005433152209	D9780B	0399 857844	OLGA ZAKHAROVA	{"phone": "+70721046009"}
0005433152210	D9780B	6246 796228	ALEKSEY KRASNOV	{"email": "akrasnov1985@postgrespro.ru", "phone": "+70474614517"}
0005433152211	54DEAB	7908 192527	RAISA IVANOVA	{"phone": "+70345892417"}
0005433152212	F8C1FC	6947 207016	KLARA SCHERBAKOVA	{"email": "scherbakova.klara031974@postgrespro.ru", "phone": "+70416991017"}
0005433152213	CEA04C	7867 734384	ALEKSANDR ROMANOV	{"email": "romanov-a.26121980@postgrespro.ru", "phone": "+70762629954"}
0005433152214	CEA04C	4796 552849	TAMARA ISAEVA	{"email": "isaeva_t_30111962@postgrespro.ru", "phone": "+70139831114"}
0005433152215	CEA04C	0164 429679	ROMAN GUSEV	{"phone": "+70829664084"}
0005433152216	89725A	5500 164517	TATYANA ALEKSANDROVA	{"email": "taleksandrova_1986@postgrespro.ru", "phone": "+70893993677"}
0005433152217	89725A	4045 636109	YULIYA MAKAROVA	{"phone": "+70079809057"}
0005433152218	89725A	1176 500997	SVETLANA MAKAROVA	{"phone": "+70462446167"}
0005433152219	B87C92	2015 230225	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov_1973@postgrespro.ru", "phone": "+70144626756"}
0005433152220	78A519	3740 226314	VIKTOR MAKAROV	{"phone": "+70016413712"}
0005433152221	5F9C72	0894 460429	ANNA KUZNECOVA	{"email": "kuznecovaanna-09021973@postgrespro.ru", "phone": "+70470002410"}
0005433152222	A22F4F	1330 938049	SERGEY SEMENOV	{"email": "semenov_sergey051972@postgrespro.ru", "phone": "+70715186151"}
0005433152223	7E80EE	2866 993348	PAVEL GORBUNOV	{"phone": "+70907710229"}
0005433152224	076B6A	5672 686996	LYUDMILA NIKITINA	{"email": "lyudmila-nikitina1979@postgrespro.ru", "phone": "+70998993414"}
0005433152225	076B6A	3340 802110	MARINA ZAYCEVA	{"email": "zayceva_m_1974@postgrespro.ru", "phone": "+70852266957"}
0005433152226	139189	1799 146781	DMITRIY GUSEV	{"phone": "+70575923593"}
0005433152227	139189	4104 875302	ARMEN BARANOV	{"phone": "+70291222807"}
0005433152228	5C0E0F	7367 182185	PETR ZAKHAROV	{"phone": "+70484442936"}
0005433152229	3FDF6B	8068 434220	VLADIMIR BORISOV	{"phone": "+70159320871"}
0005433152230	81C37F	2494 637070	VIKTORIYA KOVALEVA	{"phone": "+70225037805"}
0005433152231	DD71D2	8737 154898	NURLAN YAKOVLEV	{"email": "yakovlev-nurlan-24111974@postgrespro.ru", "phone": "+70414838620"}
0005433152232	6BC906	1024 339632	VIKTORIYA IVANOVA	{"email": "ivanova.viktoriya_1976@postgrespro.ru", "phone": "+70194932359"}
0005433152233	9B5C6F	1881 780734	KSENIYA BORISOVA	{"email": "k.borisova091974@postgrespro.ru", "phone": "+70905947748"}
0005433152234	DC1894	7139 668937	MARAT AFANASEV	{"email": "m-afanasev-1983@postgrespro.ru", "phone": "+70562648059"}
0005433152235	8656B3	9882 973465	OLGA GUSEVA	{"email": "oguseva_081973@postgrespro.ru", "phone": "+70787585057"}
0005433152236	2B81BF	8892 974220	YULIYA IVANOVA	{"phone": "+70807898138"}
0005433152237	2B81BF	9582 016820	MAKSIM GERASIMOV	{"email": "gerasimovm-04041965@postgrespro.ru", "phone": "+70021331665"}
0005433152238	776204	9118 870989	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir021982@postgrespro.ru", "phone": "+70674550414"}
0005433152239	776204	7142 646268	RAISA BORISOVA	{"email": "raisaborisova.1985@postgrespro.ru", "phone": "+70531548891"}
0005433152240	437A32	6181 022438	ALEKSEY NIKOLAEV	{"email": "nikolaev_a-071974@postgrespro.ru", "phone": "+70196452510"}
0005433152241	437A32	2899 751833	NATALYA KUDRYASHOVA	{"phone": "+70033441185"}
0005433152242	EFD4F2	1273 380899	VIKTOR DMITRIEV	{"email": "dmitriev-viktor.011970@postgrespro.ru", "phone": "+70632562307"}
0005433152299	09977E	1966 896750	VLADIMIR RODIONOV	{"phone": "+70990511125"}
0005433152243	EFD4F2	8622 306629	NATALYA MASLOVA	{"email": "maslova_natalya.05061968@postgrespro.ru", "phone": "+70171249901"}
0005433152244	A7E075	5382 310791	ALEKSEY GUSEV	{"phone": "+70183274249"}
0005433152245	8B0397	3651 121139	TATYANA ZAYCEVA	{"email": "zayceva.t-16101954@postgrespro.ru", "phone": "+70062322642"}
0005433152246	8B0397	3961 436143	OLGA BORISOVA	{"email": "olgaborisova.1977@postgrespro.ru", "phone": "+70156354698"}
0005433152247	63BEE3	3705 378458	GALINA KUDRYASHOVA	{"email": "kudryashova_galina27031976@postgrespro.ru", "phone": "+70016801787"}
0005433152248	37BDA0	2733 187128	LYUBOV FEDOROVA	{"email": "fedorova-lyubov.011964@postgrespro.ru", "phone": "+70795148924"}
0005433152249	F7F21E	7650 584526	VALENTINA IVANOVA	{"phone": "+70715333249"}
0005433152250	F7F21E	9855 168037	GULNARA LAZAREVA	{"email": "lazareva-g15011961@postgrespro.ru", "phone": "+70656796417"}
0005433152251	F7F21E	2832 897824	YURIY SIDOROV	{"phone": "+70310193560"}
0005433152252	E5BDE1	1838 450904	ANDREY SAVELEV	{"email": "savelev_andrey_1963@postgrespro.ru", "phone": "+70282546146"}
0005433152253	E5BDE1	3008 407643	GENNADIY KOZLOV	{"email": "kozlov_gennadiy091970@postgrespro.ru", "phone": "+70819761118"}
0005433152254	62205C	4651 004629	MIKHAIL KISELEV	{"phone": "+70827314426"}
0005433152255	3F3394	6667 917111	ALEKSANDR EGOROV	{"email": "egorov.a.071984@postgrespro.ru", "phone": "+70364453561"}
0005433152256	3F3394	2980 097224	ANDREY BORISOV	{"email": "borisova081979@postgrespro.ru", "phone": "+70474060515"}
0005433152257	E7EA52	0172 751548	ANNA CHERNOVA	{"phone": "+70088875642"}
0005433152258	E7EA52	4925 522974	OLEG KUZNECOV	{"phone": "+70664339487"}
0005433152259	2C144A	6363 581665	ARSEN MAKAROV	{"phone": "+70939355727"}
0005433152260	1A2B9C	8555 247302	NAILYA BOGDANOVA	{"phone": "+70058492953"}
0005433152261	5D29C7	8272 569017	GALINA STEPANOVA	{"email": "galina_stepanova.101969@postgrespro.ru", "phone": "+70576388537"}
0005433152262	5D29C7	9121 135989	SERGEY SEMENOV	{"phone": "+70830091384"}
0005433152263	59DBCC	9040 378841	GALINA ABRAMOVA	{"phone": "+70732910933"}
0005433152264	FFA3DF	0085 817258	KRISTINA KOZLOVA	{"email": "kozlova-k-1970@postgrespro.ru", "phone": "+70648138676"}
0005433152265	6645BE	1109 631909	ANDREY ZAKHAROV	{"email": "zakharovandrey.26031985@postgrespro.ru", "phone": "+70500248414"}
0005433152266	3B0DD1	7717 996939	NINA KUZNECOVA	{"email": "kuznecovan_25061979@postgrespro.ru", "phone": "+70980919136"}
0005433152267	65AC52	6858 104499	NINA RYABOVA	{"email": "nina.ryabova_1968@postgrespro.ru", "phone": "+70465883660"}
0005433152268	AAF883	1283 846979	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy_1968@postgrespro.ru", "phone": "+70985450326"}
0005433152269	58DD48	4360 322979	DMITRIY FILIPPOV	{"email": "dfilippov.1957@postgrespro.ru", "phone": "+70292872526"}
0005433152270	58DD48	2924 120719	ALENA SMIRNOVA	{"phone": "+70991393846"}
0005433152271	58DD48	4747 342075	NATALYA VASILEVA	{"email": "natalya-vasileva1976@postgrespro.ru", "phone": "+70014883607"}
0005433152272	DBA8D1	5678 679911	ALEKSEY ANTONOV	{"email": "a-antonov_30051978@postgrespro.ru", "phone": "+70937706288"}
0005433152273	2FFCA1	5284 968799	ALEKSEY SOLOVEV	{"email": "alekseysolovev.25041968@postgrespro.ru", "phone": "+70497393152"}
0005433152274	2FFCA1	6942 083976	ELENA POPOVA	{"email": "popova-elena111985@postgrespro.ru", "phone": "+70518663636"}
0005433152275	225750	3979 307609	MIKHAIL BORISOV	{"email": "mikhail.borisov-021978@postgrespro.ru", "phone": "+70779281904"}
0005433152276	225750	2519 858215	LYUDMILA VOROBEVA	{"phone": "+70160800036"}
0005433152277	225750	5863 179113	IGOR BORISOV	{"email": "i-borisov-051974@postgrespro.ru", "phone": "+70441303367"}
0005433152278	9629DB	9128 146889	RAIS BELOV	{"phone": "+70904831636"}
0005433152279	9629DB	4845 246228	LYUDMILA BOGDANOVA	{"email": "bogdanoval-26061974@postgrespro.ru", "phone": "+70293486192"}
0005433152280	11CC96	7374 970765	SERGEY FEDOROV	{"email": "sergey.fedorov19071967@postgrespro.ru", "phone": "+70082426964"}
0005433152281	11CC96	3088 988662	ELENA KUZNECOVA	{"phone": "+70502084989"}
0005433152282	11CC96	8291 829985	NATALYA PAVLOVA	{"email": "natalyapavlova-1973@postgrespro.ru", "phone": "+70001304460"}
0005433152283	147AF2	9015 126826	VITALIY SOKOLOV	{"phone": "+70790201497"}
0005433152284	147AF2	9151 606139	DMITRIY SHEVCHENKO	{"phone": "+70747418205"}
0005433152285	DE4D83	7415 441481	VIKTOR KONOVALOV	{"phone": "+70063879662"}
0005433152286	E24226	4178 927336	IGOR SMIRNOV	{"email": "i.smirnov1975@postgrespro.ru", "phone": "+70010739662"}
0005433152287	E24226	7853 970068	ZHANNA FEDOROVA	{"email": "fedorovaz1968@postgrespro.ru", "phone": "+70994976201"}
0005433152288	CE1AE0	9106 059634	SERGEY ZAKHAROV	{"phone": "+70648412704"}
0005433152289	5D69B9	2116 000753	ALEKSEY IVANOV	{"email": "aivanov_1974@postgrespro.ru", "phone": "+70747010306"}
0005433152290	00FA5A	6782 787447	ALEKSANDR ISAEV	{"email": "aleksandr-isaev-021983@postgrespro.ru", "phone": "+70829129481"}
0005433152291	4F8A50	4234 895913	STANISLAV VOLKOV	{"email": "stanislav-volkov25051974@postgrespro.ru", "phone": "+70688370143"}
0005433152292	0D7C17	9849 568021	VLADIMIR KARPOV	{"phone": "+70885596818"}
0005433152293	152F3B	5248 979740	IGOR SOROKIN	{"email": "sorokin_i-031977@postgrespro.ru", "phone": "+70266622260"}
0005433152294	152F3B	4078 384848	ALEKSANDRA VLASOVA	{"phone": "+70660746563"}
0005433152295	3E2D89	9255 495826	NINA ZAKHAROVA	{"email": "n_zakharova1972@postgrespro.ru", "phone": "+70711917868"}
0005433152296	7BFAB4	7283 262065	ANNA VASILEVA	{"phone": "+70969431959"}
0005433152297	B4648D	3676 425543	YANA PETROVA	{"phone": "+70584706062"}
0005433152298	BE79F1	7441 187752	SEMEN KOZLOV	{"email": "kozlov_s071978@postgrespro.ru", "phone": "+70442258449"}
0005433152300	09977E	8853 195919	OLGA EGOROVA	{"email": "o-egorova_30091969@postgrespro.ru", "phone": "+70415432044"}
0005433152301	15CB02	8382 941301	MARINA ZAKHAROVA	{"email": "zakharova_m.1976@postgrespro.ru", "phone": "+70894285063"}
0005433152302	B05610	8197 181538	SVETLANA BORISOVA	{"email": "s_borisova.20071967@postgrespro.ru", "phone": "+70246830527"}
0005433152303	B05610	9381 893649	ALEKSANDR IVANOV	{"phone": "+70267459205"}
0005433152304	CAD464	0286 012162	POLINA FOMINA	{"email": "pfomina_041968@postgrespro.ru", "phone": "+70301938531"}
0005433152305	81ED0A	2701 251069	YURIY KOROLEV	{"email": "korolev-yuriy_1969@postgrespro.ru", "phone": "+70415419274"}
0005433152306	AACC76	0608 963594	PETR MAKAROV	{"phone": "+70934603700"}
0005433152307	4A6A14	4519 114434	OLESYA RODIONOVA	{"phone": "+70218018040"}
0005433152308	750CAA	2961 467456	SERGEY KOZLOV	{"phone": "+70271525491"}
0005433152309	750CAA	7610 004132	LIDIYA GERASIMOVA	{"phone": "+70942436142"}
0005433152310	3D9EF1	4150 582355	EVGENIY FEDOROV	{"phone": "+70137512786"}
0005433152311	3D9EF1	2358 463936	ANNA FADEEVA	{"phone": "+70167897896"}
0005433152312	BCCEA2	7255 462882	IRINA DAVYDOVA	{"email": "davydova.i_1972@postgrespro.ru", "phone": "+70706132763"}
0005433152313	196C2E	7257 242730	KONSTANTIN ZAYCEV	{"phone": "+70858413498"}
0005433152314	196C2E	0477 807363	NAILYA VASILEVA	{"phone": "+70406385971"}
0005433152315	42BA47	6685 656902	DENIS IVANOV	{"email": "denis_ivanov-111970@postgrespro.ru", "phone": "+70531880550"}
0005433152316	C61359	0567 268085	ALEKSEY NAUMOV	{"phone": "+70398831715"}
0005433152317	16F832	1008 578019	RAILYA ZAKHAROVA	{"phone": "+70609257076"}
0005433152318	16F832	0384 043288	VERA NAUMOVA	{"email": "v.naumova09081976@postgrespro.ru", "phone": "+70502411197"}
0005433152319	6DDF6A	7395 421817	TATYANA GORBUNOVA	{"phone": "+70326843931"}
0005433152320	6DDF6A	8523 200776	ALEKSEY NIKITIN	{"phone": "+70079749018"}
0005433152321	4D5D91	5813 324490	VITALIY PAVLOV	{"phone": "+70171468554"}
0005433152322	DE70FA	1070 440948	NATALIYA ROMANOVA	{"phone": "+70759002502"}
0005433152323	DE70FA	3346 413393	VALENTINA KUDRYASHOVA	{"email": "kudryashova.v-071972@postgrespro.ru", "phone": "+70145929333"}
0005433152324	C35BD5	6553 442208	PRASKOVYA ORLOVA	{"phone": "+70377730492"}
0005433152325	F6173B	6907 490752	MIKHAIL FROLOV	{"email": "mikhail.frolov_11041968@postgrespro.ru", "phone": "+70315824289"}
0005433152326	EAEA0B	9736 414612	KONSTANTIN KUDRYASHOV	{"email": "k.kudryashov-021977@postgrespro.ru", "phone": "+70116009668"}
0005433152327	8BD2BE	2949 752233	KSENIYA KUZMINA	{"email": "kuzmina.k06071979@postgrespro.ru", "phone": "+70064971824"}
0005433152328	8BD2BE	1819 428979	TATYANA ANDREEVA	{"phone": "+70799170331"}
0005433152329	F3A770	3824 440575	MAKSIM BARANOV	{"email": "baranov_maksim_05051969@postgrespro.ru", "phone": "+70688578916"}
0005433152330	DDA212	7429 990866	DMITRIY SERGEEV	{"email": "sergeev.d.28051978@postgrespro.ru", "phone": "+70565542154"}
0005433152331	53B549	6705 077264	LIDIYA KARPOVA	{"email": "lidiya_karpova1979@postgrespro.ru", "phone": "+70236954108"}
0005433152332	AA98EC	3266 791876	MARIYA VOLKOVA	{"email": "m.volkova101971@postgrespro.ru", "phone": "+70041408603"}
0005433152333	C38A20	6567 846757	EVGENIYA ZAYCEVA	{"phone": "+70158620692"}
0005433152334	C38A20	4647 899135	ALEKSANDR PETROV	{"phone": "+70123869741"}
0005433152335	BF03E2	2098 153164	VALENTINA ORLOVA	{"phone": "+70736990424"}
0005433152336	BF03E2	1684 257835	NATALYA MATVEEVA	{"email": "matveeva-n30071977@postgrespro.ru", "phone": "+70609589353"}
0005433152337	B0D907	9614 412331	VITALIY ANDREEV	{"phone": "+70188387444"}
0005433152338	25C759	4134 970304	NINA ORLOVA	{"email": "orlovan-031977@postgrespro.ru", "phone": "+70948163073"}
0005433152339	BFDDD0	1530 402287	ALEKSANDRA GAVRILOVA	{"email": "agavrilova_1969@postgrespro.ru", "phone": "+70650396933"}
0005433152340	761496	3844 856641	TATYANA CHERNOVA	{"email": "chernovatatyana.091986@postgrespro.ru", "phone": "+70449115266"}
0005433152341	761496	6301 564738	YULIYA KARPOVA	{"email": "yuliya-karpova-1969@postgrespro.ru", "phone": "+70295408941"}
0005433152342	B773AE	6607 120098	TATYANA SEMENOVA	{"email": "semenovat12011967@postgrespro.ru", "phone": "+70233367374"}
0005433152343	308533	7019 288170	ELIZAVETA GRISHINA	{"phone": "+70654625418"}
0005433152344	308533	7476 886469	YAROSLAV EGOROV	{"email": "yaroslavegorov-11041973@postgrespro.ru", "phone": "+70083942155"}
0005433152345	D4D32A	4562 420455	KSENIYA VLASOVA	{"phone": "+70256117284"}
0005433152346	D4D32A	6652 784577	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov_1983@postgrespro.ru", "phone": "+70066496303"}
0005433152347	203ECC	0897 571291	EKATERINA FROLOVA	{"email": "efrolova-1979@postgrespro.ru", "phone": "+70088222858"}
0005433152348	203ECC	2909 063332	DMITRIY SOROKIN	{"phone": "+70342926611"}
0005433152349	64FD66	4148 976534	ALEKSANDR POPOV	{"phone": "+70252118977"}
0005433152350	45A1C9	2735 950127	ARTEM DENISOV	{"email": "denisov.a.22011968@postgrespro.ru", "phone": "+70698567443"}
0005433152351	1C10F6	0517 223292	TATYANA LUKYANOVA	{"email": "tlukyanova-1966@postgrespro.ru", "phone": "+70309585239"}
0005433152352	EAF3A6	0779 715202	SVETLANA KOVALEVA	{"phone": "+70979707532"}
0005433152353	EAF3A6	5935 715486	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.v.011962@postgrespro.ru", "phone": "+70579124285"}
0005433152354	EAF3A6	9065 148249	ALEKSANDR KISELEV	{"email": "a_kiselev081966@postgrespro.ru", "phone": "+70020702911"}
0005433152355	027598	5419 499395	MARIYA EGOROVA	{"email": "egorova.mariya-031979@postgrespro.ru", "phone": "+70281706076"}
0005433152356	0305BF	1004 086260	NIKOLAY KUZNECOV	{"email": "kuznecov_n1967@postgrespro.ru", "phone": "+70045570188"}
0005433152357	4E1FC0	6825 123757	VASILIY SIDOROV	{"phone": "+70585456548"}
0005433152358	4E1FC0	7048 976242	ALEKSANDR KOZLOV	{"email": "a.kozlov1969@postgrespro.ru", "phone": "+70003338687"}
0005433152359	7B6F86	4393 485416	NINA NESTEROVA	{"phone": "+70972096478"}
0005433152360	5DB3CF	8261 994977	NINA FILATOVA	{"phone": "+70017998047"}
0005433152361	8EAD6C	0697 583257	OKSANA POLYAKOVA	{"email": "polyakova.o121956@postgrespro.ru", "phone": "+70303247483"}
0005433152362	A05A8D	7885 228717	TATYANA MAKSIMOVA	{"email": "maksimova.t-1968@postgrespro.ru", "phone": "+70215633943"}
0005433152363	C6E6B7	8233 147784	YULIYA SOLOVEVA	{"email": "soloveva-y.21081974@postgrespro.ru", "phone": "+70784457625"}
0005433152364	C6E6B7	4068 889461	IRINA NESTEROVA	{"email": "i-nesterova-1963@postgrespro.ru", "phone": "+70864572506"}
0005433152365	C64B42	9750 334091	NATALYA NAZAROVA	{"email": "nazarova_n_1972@postgrespro.ru", "phone": "+70515664743"}
0005433152366	88A1FF	0023 246825	VLADIMIR ALEKSEEV	{"email": "alekseevvladimir_1977@postgrespro.ru", "phone": "+70846622334"}
0005433152367	918A3D	1430 455338	SERGEY ROMANOV	{"phone": "+70483836937"}
0005433152368	F9BAF1	9244 993671	STEPAN MOISEEV	{"email": "moiseev.stepan_1957@postgrespro.ru", "phone": "+70335614503"}
0005433152369	0D1508	1084 730415	SERGEY KULIKOV	{"phone": "+70774499553"}
0005433152370	85EC2B	0661 058651	SERGEY BORISOV	{"phone": "+70426854156"}
0005433152371	D30B57	2177 692289	IRAIDA VOROBEVA	{"phone": "+70665082149"}
0005433152372	D30B57	7896 890365	ALINA MASLOVA	{"email": "alina_maslova.1975@postgrespro.ru", "phone": "+70562435456"}
0005433152373	D30B57	1530 393677	YURIY SOKOLOV	{"phone": "+70888544091"}
0005433152374	53CEA4	8001 573830	IRINA ZHURAVLEVA	{"email": "irina-zhuravleva.091971@postgrespro.ru", "phone": "+70337095664"}
0005433152375	015A0B	8589 371120	ALEKSANDR TARASOV	{"email": "a-tarasov-1977@postgrespro.ru", "phone": "+70887454443"}
0005433152376	B57154	5158 517193	MARIYA SEMENOVA	{"phone": "+70719237811"}
0005433152377	B0331B	8037 960081	VIKTOR SOKOLOV	{"email": "sokolov.viktor1974@postgrespro.ru", "phone": "+70256807734"}
0005433152378	ED004B	7060 593845	ALEKSANDR NOVIKOV	{"phone": "+70103787161"}
0005433152379	24F8D7	0357 393599	DAVID ZAKHAROV	{"email": "zakharov_david1988@postgrespro.ru", "phone": "+70390431887"}
0005433152380	13EBB8	3427 413161	POLINA ZAYCEVA	{"email": "polina.zayceva-1981@postgrespro.ru", "phone": "+70670987377"}
0005433152381	13EBB8	1132 740436	DARYA KUZMINA	{"email": "kuzminadarya_1976@postgrespro.ru", "phone": "+70182912262"}
0005433152382	040DEB	9223 117975	DENIS SOROKIN	{"email": "sorokin.d.1970@postgrespro.ru", "phone": "+70036045316"}
0005433152383	040DEB	5351 164714	LYUBOV RODIONOVA	{"email": "l-rodionova.1962@postgrespro.ru", "phone": "+70055294983"}
0005433152384	0462C4	0637 576486	TATYANA FILIPPOVA	{"phone": "+70650252136"}
0005433152385	29AEF0	5710 056663	NIKOLAY ROMANOV	{"phone": "+70728651215"}
0005433152386	29AEF0	2034 260527	MAKSIM GUSEV	{"phone": "+70017073976"}
0005433152387	93EBEA	3182 941860	IRINA ORLOVA	{"email": "orlova.irina-22051978@postgrespro.ru", "phone": "+70873117198"}
0005433152388	C9F9DD	0700 979354	RIMMA KUZNECOVA	{"email": "r-kuznecova.29111963@postgrespro.ru", "phone": "+70238780663"}
0005433152389	C9F9DD	0281 169472	ANDREY VOLKOV	{"email": "avolkov.08071970@postgrespro.ru", "phone": "+70854538101"}
0005433152390	C9F9DD	2590 748696	DANILA TARASOV	{"phone": "+70673228467"}
0005433152391	27DF80	6968 102548	NADEZHDA FEDOROVA	{"email": "nadezhda.fedorova.031964@postgrespro.ru", "phone": "+70545798365"}
0005433152392	27DF80	5016 282244	ALEKSANDR FOMIN	{"phone": "+70569631205"}
0005433152393	C75C30	0519 439203	NIKOLAY FROLOV	{"phone": "+70809662800"}
0005433152394	DFC727	9908 690206	VLADIMIR NOVIKOV	{"phone": "+70563967227"}
0005433152395	E1F21F	2921 316864	ANNA KOMAROVA	{"email": "komarova-a_1973@postgrespro.ru", "phone": "+70260339644"}
0005433152396	EC7BF4	3390 451373	VALENTINA BARANOVA	{"email": "v.baranova.15061969@postgrespro.ru", "phone": "+70833710102"}
0005433152397	89CB9A	8479 710918	ANTON ZAYCEV	{"email": "a-zaycev-22121983@postgrespro.ru", "phone": "+70794550385"}
0005433152398	33E25A	5138 725161	GALINA ARKHIPOVA	{"phone": "+70569765053"}
0005433152399	62721E	4994 732694	ARTEM VOROBEV	{"email": "a.vorobev_1972@postgrespro.ru", "phone": "+70973937410"}
0005433152400	E8CA87	5357 659524	YULIYA MATVEEVA	{"phone": "+70468248097"}
0005433152401	C0F4DD	2317 048057	OLESYA KUZNECOVA	{"phone": "+70306443007"}
0005433152402	8B1FA1	2801 847097	TATYANA SMIRNOVA	{"email": "smirnovat_1978@postgrespro.ru", "phone": "+70839989084"}
0005433152403	C6510C	8747 682972	KONSTANTIN STEPANOV	{"email": "stepanov.konstantin-111973@postgrespro.ru", "phone": "+70247372840"}
0005433152404	C6510C	4940 088344	IRINA MIRONOVA	{"email": "i.mironova23121961@postgrespro.ru", "phone": "+70804930579"}
0005433152405	C6510C	1430 643749	IRINA TIKHONOVA	{"email": "tikhonova_irina_111971@postgrespro.ru", "phone": "+70768903789"}
0005433152406	BC2A5D	0155 044082	IRINA NAZAROVA	{"email": "irina.nazarova-1976@postgrespro.ru", "phone": "+70554582022"}
0005433152407	79F712	6633 894577	ANASTASIYA VOLKOVA	{"email": "a-volkova1976@postgrespro.ru", "phone": "+70751739945"}
0005433152408	267868	4996 775899	OLGA LOGINOVA	{"phone": "+70764207647"}
0005433152409	AF8A7B	5210 305241	ILYA DMITRIEV	{"phone": "+70954836956"}
0005433152410	AF8A7B	8383 168249	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana-22071972@postgrespro.ru", "phone": "+70881939387"}
0005433152411	D2CE33	1688 511409	VLADIMIR IVANOV	{"phone": "+70116208906"}
0005433152412	B16D73	2836 893726	EVGENIY ILIN	{"email": "ilinevgeniy_101958@postgrespro.ru", "phone": "+70946039639"}
0005433152413	B16D73	1975 588183	EKATERINA ISAEVA	{"email": "isaeva.ekaterina_1971@postgrespro.ru", "phone": "+70607671817"}
0005433152414	87A13C	1336 859187	MARIYA NAZAROVA	{"phone": "+70575368935"}
0005433152415	4E60E6	6554 498987	ALEKSANDRA SEMENOVA	{"phone": "+70109075752"}
0005433152416	48C8D9	3951 802474	KLAVDIYA ROMANOVA	{"email": "k.romanova.031982@postgrespro.ru", "phone": "+70672941909"}
0005433152417	E5B1E6	6326 236066	PAVEL MAKSIMOV	{"phone": "+70079001959"}
0005433156597	297785	5753 245909	MARIYA DANILOVA	{"phone": "+70287399678"}
0005433156598	297785	6229 472576	ELENA DAVYDOVA	{"phone": "+70720418850"}
0005433156599	297785	2704 555376	ALEKSEY DENISOV	{"email": "a.denisov1954@postgrespro.ru", "phone": "+70199439100"}
0005433156600	889B5E	4187 149847	ANASTASIYA ANTONOVA	{"email": "antonova.a-20091959@postgrespro.ru", "phone": "+70667446847"}
0005433156601	889B5E	5625 863712	SERGEY NAUMOV	{"phone": "+70841348606"}
0005433156602	0D6B8D	2225 965148	YANA SEMENOVA	{"phone": "+70463520683"}
0005433156603	981CC9	8054 512972	ALEKSANDR TARASOV	{"email": "a.tarasov.1972@postgrespro.ru", "phone": "+70701260673"}
0005433156604	EE3CCF	7338 722064	ALINA ZHUKOVA	{"email": "zhukovaalina_1966@postgrespro.ru", "phone": "+70369391136"}
0005433156605	EE3CCF	1432 998767	ALEKSANDR FROLOV	{"email": "frolov_a-1966@postgrespro.ru", "phone": "+70977544561"}
0005433156606	92C619	9101 744572	NIKOLAY IVANOV	{"phone": "+70010491987"}
0005433156607	92C619	7170 084307	IVAN SEMENOV	{"phone": "+70452592966"}
0005433156608	204B4F	6370 713472	ELENA MAKAROVA	{"email": "elena-makarova-1988@postgrespro.ru", "phone": "+70101248385"}
0005433156669	CD12DF	6430 440925	RUSLAN MIRONOV	{"phone": "+70833826937"}
0005433156609	8777E8	6301 180015	MILANA KRASNOVA	{"email": "krasnova_milana-1975@postgrespro.ru", "phone": "+70655426054"}
0005433156610	B7DA9A	6074 473822	NIKOLAY CHERNOV	{"email": "chernov-nikolay-30071971@postgrespro.ru", "phone": "+70837768346"}
0005433156611	224961	1895 814285	DMITRIY STEPANOV	{"phone": "+70182736241"}
0005433156612	224961	9146 752026	LYUBOV AFANASEVA	{"email": "lyubov.afanaseva1969@postgrespro.ru", "phone": "+70808105174"}
0005433156613	FCF7AA	1123 164741	SVETLANA ANTONOVA	{"phone": "+70401078518"}
0005433156614	772C84	3756 542980	TATYANA KOLESNIKOVA	{"phone": "+70450957978"}
0005433156615	A21ECD	6899 018180	GALINA ANISIMOVA	{"email": "anisimova.g_011975@postgrespro.ru", "phone": "+70750155118"}
0005433156616	A21ECD	4840 851989	VERA BELOVA	{"phone": "+70683059272"}
0005433156617	1CB875	5493 754380	REGINA POPOVA	{"phone": "+70653098294"}
0005433156618	5EED7B	9622 323143	MARIYA LAZAREVA	{"email": "mariya.lazareva_1970@postgrespro.ru", "phone": "+70857508529"}
0005433156619	5EED7B	2460 575045	NIKITA MARTYNOV	{"phone": "+70277898262"}
0005433156620	169FAD	4270 288670	VALENTINA IVANOVA	{"phone": "+70202914278"}
0005433156621	078787	3659 232809	ANDREY MELNIKOV	{"email": "andrey.melnikov-091962@postgrespro.ru", "phone": "+70047237833"}
0005433156622	2BD6EE	1536 927265	DMITRIY KUZNECOV	{"phone": "+70788095494"}
0005433156623	4FDCD1	5641 331624	ANDREY ANTONOV	{"phone": "+70701873358"}
0005433156624	4FDCD1	0457 734184	ALEKSEY IVANOV	{"email": "aleksey-ivanov1965@postgrespro.ru", "phone": "+70560665175"}
0005433156625	88300B	1747 961073	NADEZHDA ALEKSEEVA	{"email": "alekseeva_nadezhda_1974@postgrespro.ru", "phone": "+70542582927"}
0005433156626	3B6F20	3982 964439	VASILIY FILIPPOV	{"phone": "+70918396684"}
0005433156627	5DDF98	1568 155769	TATYANA NIKITINA	{"email": "t_nikitina-091966@postgrespro.ru", "phone": "+70748306350"}
0005433156628	5DDF98	0735 690593	NATALYA MAKSIMOVA	{"email": "maksimova_n.041982@postgrespro.ru", "phone": "+70734439976"}
0005433156629	EF690A	4210 772876	ANATOLIY MIKHAYLOV	{"email": "mikhaylov-anatoliy_27011964@postgrespro.ru", "phone": "+70611461472"}
0005433156630	138D71	9043 302989	SERGEY BELOV	{"email": "sergey_belov-10051962@postgrespro.ru", "phone": "+70225756079"}
0005433156631	6D7170	8572 177433	YULIYA KUZMINA	{"email": "kuzmina.yuliya1974@postgrespro.ru", "phone": "+70759995153"}
0005433156632	1D24B0	2252 110905	ANDREY STEPANOV	{"email": "stepanovandrey-06111964@postgrespro.ru", "phone": "+70208157854"}
0005433156633	72B5EA	1992 795201	EKATERINA BARANOVA	{"email": "ekaterina.baranova-1971@postgrespro.ru", "phone": "+70932610102"}
0005433156634	72B5EA	4846 798615	DANIIL SMIRNOV	{"phone": "+70573128200"}
0005433156635	013AC1	4732 298547	NADEZHDA SERGEEVA	{"phone": "+70077689799"}
0005433156636	013AC1	9860 271326	SERGEY TIMOFEEV	{"phone": "+70978438902"}
0005433156637	256400	3932 474381	SERGEY MIKHAYLOV	{"phone": "+70053649356"}
0005433156638	256400	4866 238461	ANTON PAVLOV	{"phone": "+70004412711"}
0005433156639	EA18D9	3537 851766	NIKITA KONOVALOV	{"email": "n_konovalov101976@postgrespro.ru", "phone": "+70223318029"}
0005433156640	1C31F5	3865 449770	VALENTINA YUDINA	{"phone": "+70741555717"}
0005433156641	1C31F5	9603 689309	ALEKSEY KUZMIN	{"email": "kuzmina.021967@postgrespro.ru", "phone": "+70740457790"}
0005433156642	E6A3F9	2779 105814	LYUDMILA POPOVA	{"email": "popova-l_1967@postgrespro.ru", "phone": "+70993358432"}
0005433156643	E6A3F9	6434 404208	OLEG MIKHAYLOV	{"email": "mikhaylov.oleg-10071973@postgrespro.ru", "phone": "+70440764585"}
0005433156644	33BEA3	4792 329648	NATALYA LUKYANOVA	{"email": "n-lukyanova.09041978@postgrespro.ru", "phone": "+70057787298"}
0005433156645	3A496C	8043 516223	NATALYA FROLOVA	{"email": "frolovanatalya-1984@postgrespro.ru", "phone": "+70872362022"}
0005433156646	B9A5C9	2483 099488	MARIYA DMITRIEVA	{"email": "mdmitrieva101981@postgrespro.ru", "phone": "+70626407470"}
0005433156647	B9A5C9	6527 577241	DMITRIY VLASOV	{"email": "d-vlasov1975@postgrespro.ru", "phone": "+70934157379"}
0005433156648	4E23B3	7641 809622	ANNA FEDOROVA	{"phone": "+70134910569"}
0005433156649	2711B6	7963 503948	LYUDMILA NESTEROVA	{"phone": "+70362426204"}
0005433156650	2711B6	1593 886024	ILYA AFANASEV	{"email": "afanasev-i-25071959@postgrespro.ru", "phone": "+70594291316"}
0005433156651	BB13B6	8655 996602	EGOR SERGEEV	{"phone": "+70897543822"}
0005433156652	314D33	0246 475138	SERGEY MAKAROV	{"phone": "+70710588170"}
0005433156653	972105	7222 753588	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy.03071966@postgrespro.ru", "phone": "+70029793889"}
0005433156654	3DE6FE	0141 992842	ALEKSANDR ALEKSEEV	{"phone": "+70739326813"}
0005433156655	7D7633	7718 570673	ANDREY SEMENOV	{"email": "semenovandrey.071972@postgrespro.ru", "phone": "+70461518430"}
0005433156656	340F67	8617 427850	SANIYA KUZNECOVA	{"phone": "+70887047574"}
0005433156657	DA3C04	5672 819352	TATYANA NAZAROVA	{"phone": "+70115460948"}
0005433156658	824D71	6520 172960	ZOYA PAVLOVA	{"phone": "+70756604589"}
0005433156659	9DE83B	1020 627419	VIKTOR DMITRIEV	{"email": "v-dmitriev1980@postgrespro.ru", "phone": "+70763958359"}
0005433156660	E468AB	1883 293502	MAKSIM POPOV	{"email": "maksim.popov_1967@postgrespro.ru", "phone": "+70036895711"}
0005433156661	E468AB	5553 856162	ALEKSANDR KUZNECOV	{"phone": "+70030917872"}
0005433156662	2CC7D3	2733 608893	VALERIY POPOV	{"email": "vpopov_021971@postgrespro.ru", "phone": "+70703058730"}
0005433156663	21D0B9	7192 293249	ALEKSANDR NOVIKOV	{"phone": "+70655037325"}
0005433156664	832644	3037 831370	NIKITA FOMIN	{"email": "nikita.fomin.16061973@postgrespro.ru", "phone": "+70211797117"}
0005433156665	1CF6D2	4152 300967	SERGEY KISELEV	{"email": "s-kiselev-27051971@postgrespro.ru", "phone": "+70775269568"}
0005433156666	5DEC7D	7209 062178	ILNUR ALEKSEEV	{"phone": "+70752406957"}
0005433156667	937172	2249 682549	EGOR SEMENOV	{"phone": "+70743226813"}
0005433156668	90AE0B	7150 068137	SERGEY SEMENOV	{"email": "s_semenov-17111971@postgrespro.ru", "phone": "+70128211069"}
0005433156670	0AC7B3	3246 677640	DMITRIY MAKAROV	{"email": "dmitriymakarov-02011977@postgrespro.ru", "phone": "+70980725659"}
0005433156671	0AC7B3	6126 969620	ELENA ANTONOVA	{"email": "e.antonova.15101971@postgrespro.ru", "phone": "+70606647741"}
0005433156672	0AC7B3	9971 659580	ALEKSANDR KULIKOV	{"phone": "+70733210110"}
0005433156673	4CC757	7637 269196	IRINA SERGEEVA	{"email": "irinasergeeva-24011978@postgrespro.ru", "phone": "+70960484961"}
0005433156674	4CC757	1822 021427	EKATERINA NESTEROVA	{"phone": "+70701502095"}
0005433156675	CF8424	4924 607293	ALEKSANDR PAVLOV	{"phone": "+70951068408"}
0005433156676	BD5615	5093 060689	EKATERINA FEDOROVA	{"phone": "+70211023562"}
0005433156677	6DDBC0	1534 642999	VALENTINA TROFIMOVA	{"phone": "+70464542720"}
0005433156678	4064DC	1595 806240	MARIYA RYABOVA	{"phone": "+70315398878"}
0005433156679	1845F5	9388 661479	ANDREY ZAKHAROV	{"phone": "+70157848932"}
0005433156680	D1D1A2	2483 520972	NADEZHDA KOZLOVA	{"email": "kozlova.nadezhda_05081973@postgrespro.ru", "phone": "+70368916740"}
0005433156681	D1D1A2	6854 357945	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr-081984@postgrespro.ru", "phone": "+70831231404"}
0005433156682	3000E9	9394 255568	SVETLANA YUDINA	{"email": "yudina.svetlana-1988@postgrespro.ru", "phone": "+70000549242"}
0005433156683	CD5524	9050 753592	ALEKSANDR KOZLOV	{"phone": "+70068236668"}
0005433156684	CD5524	3532 076412	GEORGIY ANDREEV	{"phone": "+70863985246"}
0005433156685	3B87E8	3188 855492	MARINA FOMINA	{"phone": "+70718146183"}
0005433156686	B77630	9544 545431	ARTEM VLASOV	{"email": "artem_vlasov_1965@postgrespro.ru", "phone": "+70643146202"}
0005433156687	5B5895	1747 190268	ALEKSEY ZAKHAROV	{"email": "zakharov.a_121971@postgrespro.ru", "phone": "+70858438815"}
0005433156688	C18BB1	0033 655064	SVETLANA FILIPPOVA	{"email": "filippova.svetlana-051974@postgrespro.ru", "phone": "+70586483239"}
0005433156689	C18BB1	5290 521254	ARTUR KUZMIN	{"email": "kuzmin.a-031973@postgrespro.ru", "phone": "+70349214885"}
0005433156690	C07E66	1607 195421	VLADIMIR SOROKIN	{"phone": "+70417484824"}
0005433156691	96DE8E	0971 102665	OKSANA SMIRNOVA	{"phone": "+70189273576"}
0005433156692	2DED02	4818 120719	VADIM ZAKHAROV	{"email": "v-zakharov-121977@postgrespro.ru", "phone": "+70055987658"}
0005433156693	BC0573	4650 408128	TAMARA KARPOVA	{"email": "karpova_tamara.01041976@postgrespro.ru", "phone": "+70295347322"}
0005433156694	D3F456	6590 223501	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey.24081978@postgrespro.ru", "phone": "+70747586349"}
0005433156695	D3F456	3653 289099	EVGENIY ZAKHAROV	{"email": "ezakharov_14121968@postgrespro.ru", "phone": "+70828443760"}
0005433156696	80AF91	4726 468266	MIKHAIL VOLKOV	{"phone": "+70801818346"}
0005433156697	80AF91	7455 157432	OLESYA MARTYNOVA	{"email": "o-martynova101982@postgrespro.ru", "phone": "+70551718665"}
0005433156698	1218C2	9374 341932	NIKOLAY KUZNECOV	{"phone": "+70591912992"}
0005433156699	268CA3	6327 248130	EGOR FEDOROV	{"email": "efedorov-25011974@postgrespro.ru", "phone": "+70214760000"}
0005433156700	268CA3	1690 992992	GLEB BARANOV	{"email": "baranovgleb-23011972@postgrespro.ru", "phone": "+70218603275"}
0005433156701	84DE5B	2880 331245	ALENA NIKOLAEVA	{"phone": "+70693725721"}
0005433156702	E4DAE0	8654 341290	GALINA FROLOVA	{"phone": "+70391228205"}
0005433156703	E4DAE0	2558 065868	EVGENIY AFANASEV	{"phone": "+70132547586"}
0005433156704	8F9673	1746 742580	VLADIMIR VASILEV	{"phone": "+70120440566"}
0005433156705	8F9673	9069 854537	DANIL SERGEEV	{"email": "danil-sergeev.19021979@postgrespro.ru", "phone": "+70689152922"}
0005433156706	ED5DD9	3664 027359	MIKHAIL AFANASEV	{"phone": "+70274049071"}
0005433156707	7205EA	0631 692075	YULIYA MAKAROVA	{"email": "y.makarova_16071980@postgrespro.ru", "phone": "+70127129050"}
0005433156708	9E88D0	1749 226609	ANNA TITOVA	{"phone": "+70547354862"}
0005433156709	6FE3A3	6812 967227	VLADIMIR ZAYCEV	{"phone": "+70769727487"}
0005433156710	91F0B1	1662 510966	GALINA KOZLOVA	{"phone": "+70832650698"}
0005433156711	444C06	3208 996600	VIKTOR MIKHAYLOV	{"phone": "+70820599319"}
0005433156712	444C06	1285 004489	EGOR KOROLEV	{"email": "e.korolev_11101979@postgrespro.ru", "phone": "+70328811325"}
0005433156713	AEC6D4	9552 082110	ELENA PETROVA	{"email": "epetrova.01101980@postgrespro.ru", "phone": "+70272967512"}
0005433156714	B9F004	3789 577844	TATYANA ANTONOVA	{"phone": "+70442736594"}
0005433156715	854A89	0091 548420	VLADISLAV FEDOROV	{"email": "fedorov_vladislav06041977@postgrespro.ru", "phone": "+70069011417"}
0005433156716	75265C	5223 034935	ELENA LUKYANOVA	{"phone": "+70451634061"}
0005433156717	75265C	7278 915223	ELENA KUZMINA	{"email": "kuzmina_e_31071980@postgrespro.ru", "phone": "+70368213858"}
0005433156718	75265C	8191 189923	ANASTASIYA BOGDANOVA	{"email": "a.bogdanova31081982@postgrespro.ru", "phone": "+70183407722"}
0005433156719	75265C	4147 595469	EKATERINA ANTONOVA	{"phone": "+70972272235"}
0005433156720	150836	3322 446325	NATALYA POPOVA	{"phone": "+70272793645"}
0005433156721	150836	7130 980331	ALEKSANDR GRIGOREV	{"phone": "+70292974574"}
0005433156722	E01473	6740 351940	VALENTINA EFIMOVA	{"email": "efimova.valentina-15111974@postgrespro.ru", "phone": "+70481800203"}
0005433156723	A54091	8404 120526	ALEKSEY ALEKSEEV	{"phone": "+70829306872"}
0005433156724	A54091	2843 772457	ANDREY SIDOROV	{"phone": "+70698421583"}
0005433156725	5F319E	3443 390311	VLADIMIR YAKOVLEV	{"email": "v_yakovlev1960@postgrespro.ru", "phone": "+70399524482"}
0005433156726	9B3AC5	7074 695771	IRINA FILIPPOVA	{"email": "filippovairina_1970@postgrespro.ru", "phone": "+70104756458"}
0005433156727	379A09	7009 112100	RAVIL KRASNOV	{"phone": "+70733829536"}
0005433156728	379A09	8537 271561	VARVARA BARANOVA	{"email": "varvara.baranova_1979@postgrespro.ru", "phone": "+70815187565"}
0005433156729	845A4D	4268 469899	SERGEY SIDOROV	{"phone": "+70694791983"}
0005433156730	845A4D	6968 358739	MIKHAIL KULIKOV	{"email": "mikhail.kulikov-031963@postgrespro.ru", "phone": "+70879667904"}
0005433156731	A43901	0648 268147	GALINA LAZAREVA	{"email": "lazareva-galina_011968@postgrespro.ru", "phone": "+70753490080"}
0005433156732	A43901	1959 862737	RAFIK ZAKHAROV	{"email": "r_zakharov-011981@postgrespro.ru", "phone": "+70837204568"}
0005433156733	B1712C	2285 318061	ELENA MAKAROVA	{"email": "emakarova.071973@postgrespro.ru", "phone": "+70256632120"}
0005433156734	87BFD1	2355 919731	ALEKSANDR SIDOROV	{"phone": "+70727675552"}
0005433156735	87BFD1	3593 669121	ANTONINA POTAPOVA	{"email": "potapova.antonina.1974@postgrespro.ru", "phone": "+70616626096"}
0005433156736	85AD44	0087 912963	NATALYA YAKOVLEVA	{"email": "yakovleva_n.101981@postgrespro.ru", "phone": "+70028532096"}
0005433156737	12BAA9	4914 320025	GENNADIY ZAKHAROV	{"email": "gennadiy.zakharov_091971@postgrespro.ru", "phone": "+70968277092"}
0005433156738	12BAA9	1171 289166	VLADIMIR ABRAMOV	{"email": "abramov_vladimir101973@postgrespro.ru", "phone": "+70287885725"}
0005433156739	E8DF63	6769 503690	VALENTINA ZAKHAROVA	{"email": "v-zakharova-25041982@postgrespro.ru", "phone": "+70017039458"}
0005433156740	9809FC	9418 504896	MARIYA SERGEEVA	{"email": "sergeeva_mariya_1976@postgrespro.ru", "phone": "+70807208584"}
0005433156741	FA7952	0266 209043	LYUDMILA NAZAROVA	{"email": "nazarova-lyudmila.08121960@postgrespro.ru", "phone": "+70182295582"}
0005433156742	FA7952	1295 367892	VASILIY OSIPOV	{"phone": "+70420670842"}
0005433156743	077584	9605 634170	OLGA ILINA	{"email": "o.ilina_1966@postgrespro.ru", "phone": "+70155257832"}
0005433156744	69DC52	3755 994488	ALEKSEY SERGEEV	{"phone": "+70229565294"}
0005433156745	115142	9111 274463	ELENA KOZLOVA	{"phone": "+70856644300"}
0005433156746	AC5F07	8809 398970	LIDIYA ARKHIPOVA	{"phone": "+70098051414"}
0005433156747	AC5F07	7743 366616	VALENTINA NIKOLAEVA	{"phone": "+70999505680"}
0005433156748	D86A9E	4157 215969	ALENA LUKYANOVA	{"phone": "+70720651020"}
0005433156749	089815	7185 868207	ALEKSANDR KULIKOV	{"phone": "+70557858623"}
0005433156750	7F5EA4	6463 320077	IRINA MEDVEDEVA	{"email": "medvedevai05041969@postgrespro.ru", "phone": "+70374210467"}
0005433156751	7F5EA4	0356 078716	DENIS PAVLOV	{"phone": "+70330979640"}
0005433156752	7F5EA4	5492 068332	EKATERINA PETROVA	{"email": "ekaterina.petrova-021982@postgrespro.ru", "phone": "+70789082896"}
0005433156753	977E04	3641 275257	ALEKSANDR TIMOFEEV	{"phone": "+70177720787"}
0005433156754	977E04	5507 139347	ANGELINA MALYSHEVA	{"email": "a_malysheva.061957@postgrespro.ru", "phone": "+70235745064"}
0005433156755	D9BD03	7633 051136	IRINA FEDOROVA	{"phone": "+70120319324"}
0005433156756	E93347	6783 848779	ANDREY NIKITIN	{"email": "a.nikitin_01031970@postgrespro.ru", "phone": "+70787397083"}
0005433156757	E93347	6367 883542	TATYANA TARASOVA	{"email": "t_tarasova-1964@postgrespro.ru", "phone": "+70855815026"}
0005433156758	B468D5	0506 942391	ELENA BARANOVA	{"phone": "+70965846817"}
0005433156759	B468D5	3259 694596	LIDIYA PAVLOVA	{"email": "lidiya-pavlova041973@postgrespro.ru", "phone": "+70509097746"}
0005433156760	07A249	4952 185924	ELENA OVCHINNIKOVA	{"phone": "+70952269907"}
0005433156761	D64B58	1524 009132	VLADIMIR ORLOV	{"email": "vladimir.orlov-101971@postgrespro.ru", "phone": "+70551979306"}
0005433156762	D64B58	8049 490937	ALEKSEY STEPANOV	{"phone": "+70184939088"}
0005433156763	8E5BD4	7884 496634	VALERIY FROLOV	{"phone": "+70770723843"}
0005433156764	3E7FEE	5714 941289	FAINA ARKHIPOVA	{"phone": "+70520501705"}
0005433156765	3E7FEE	4192 017341	EVGENIY KUZNECOV	{"email": "evgeniy-kuznecov-121968@postgrespro.ru", "phone": "+70217079218"}
0005433156766	AFB716	8105 183300	ANGELINA ANDREEVA	{"phone": "+70169571510"}
0005433156767	AFB716	2123 454657	OLGA IVANOVA	{"email": "olga-ivanova_1967@postgrespro.ru", "phone": "+70747889776"}
0005433156768	0712D5	9102 620713	VLADIMIR NIKOLAEV	{"email": "nikolaev-v.1970@postgrespro.ru", "phone": "+70665488793"}
0005433156769	77D04C	7489 357694	VERA AKIMOVA	{"email": "v_akimova1972@postgrespro.ru", "phone": "+70315309420"}
0005433156770	30F6D2	5382 816563	SVETLANA POPOVA	{"email": "svetlana-popova-1974@postgrespro.ru", "phone": "+70588068295"}
0005433156771	D94742	2038 870233	EKATERINA STEPANOVA	{"email": "stepanovae-09021977@postgrespro.ru", "phone": "+70127897735"}
0005433156772	D94742	5251 830041	ARTEM FILIPPOV	{"phone": "+70338514110"}
0005433156773	8585CF	0562 232531	VALENTINA PAVLOVA	{"phone": "+70365528287"}
0005433156774	C0342C	5857 382456	SERGEY VOLKOV	{"email": "sergey.volkov.1973@postgrespro.ru", "phone": "+70445609060"}
0005433156775	A4D6FD	0504 075232	VERA VLASOVA	{"phone": "+70225300334"}
0005433156776	363BD3	8877 997535	VERA YUDINA	{"email": "yudinavera19081965@postgrespro.ru", "phone": "+70270379020"}
0005433156777	994429	7791 951368	ANVAR KOZLOV	{"phone": "+70900883558"}
0005433156778	D58EF7	3809 924611	RUSLAN GAVRILOV	{"phone": "+70797203602"}
0005433156779	D58EF7	7850 410916	LIDIYA BARANOVA	{"phone": "+70547670502"}
0005433156780	E4BBA6	2843 454377	IVAN SAVELEV	{"phone": "+70673278811"}
0005433156781	EA8D75	3583 083785	LYUDMILA FEDOROVA	{"phone": "+70703689128"}
0005433156782	EA8D75	5998 484500	NADEZHDA EGOROVA	{"phone": "+70699893627"}
0005433156783	22C9CD	9794 062198	ALEKSEY STEPANOV	{"email": "a-stepanov051976@postgrespro.ru", "phone": "+70773860573"}
0005433156784	22C9CD	0132 453272	MAKSIM SOROKIN	{"phone": "+70957401563"}
0005433156785	828B89	8689 155821	NADEZHDA FEDOROVA	{"email": "fedorovan.021975@postgrespro.ru", "phone": "+70572584121"}
0005433156786	828B89	8860 674935	ANDREY MELNIKOV	{"email": "andrey.melnikov101976@postgrespro.ru", "phone": "+70015565841"}
0005433156787	8411CA	9483 742711	AMINA ROMANOVA	{"phone": "+70875866360"}
0005433156788	665FE6	5222 391758	VASILIY SEMENOV	{"email": "vasiliy-semenov_1959@postgrespro.ru", "phone": "+70674687105"}
0005433156789	665FE6	0029 596267	VLADIMIR IVANOV	{"email": "vladimir-ivanov061977@postgrespro.ru", "phone": "+70900303308"}
0005433156790	9E7D0A	0718 229805	NIKOLAY SMIRNOV	{"email": "n-smirnov-1962@postgrespro.ru", "phone": "+70201957035"}
0005433156791	6CBD13	0904 453774	TATYANA MASLOVA	{"phone": "+70459008372"}
0005433156792	6CBD13	3835 239243	GALINA KONOVALOVA	{"phone": "+70505512805"}
0005433156793	B05363	1682 794352	DMITRIY FEDOROV	{"phone": "+70486775915"}
0005433156794	1BAD4A	1594 402384	EKATERINA BORISOVA	{"email": "borisovae1974@postgrespro.ru", "phone": "+70905849522"}
0005433156795	281B2F	1610 303558	TATYANA ERMAKOVA	{"email": "ermakova-t031978@postgrespro.ru", "phone": "+70634171098"}
0005433156796	1F09AB	0261 034685	EVGENIY FEDOROV	{"phone": "+70457031642"}
0005433156797	1F09AB	0238 471450	ANASTASIYA ERMAKOVA	{"email": "anastasiya-ermakova-071961@postgrespro.ru", "phone": "+70446057748"}
0005433156798	32016C	6040 592971	ELENA MAKAROVA	{"phone": "+70727498820"}
0005433156799	95FC21	3382 386946	DENIS BARANOV	{"email": "baranov-denis24041965@postgrespro.ru", "phone": "+70907241022"}
0005433156800	28B4C5	4692 689242	EVGENIY MAKSIMOV	{"email": "e.maksimov011980@postgrespro.ru", "phone": "+70348532194"}
0005433156801	01510F	1645 474285	NATALYA MAKSIMOVA	{"email": "natalya.maksimova.28101967@postgrespro.ru", "phone": "+70137080375"}
0005433156802	94C7AC	4176 826259	ELIZAVETA MELNIKOVA	{"phone": "+70355115398"}
0005433156803	7663C4	3265 670635	ALEKSEY SHEVCHENKO	{"email": "aleksey-shevchenko-1966@postgrespro.ru", "phone": "+70615062513"}
0005433156804	62E5E8	9555 315914	ANASTASIYA MAKSIMOVA	{"email": "a.maksimova18101973@postgrespro.ru", "phone": "+70897659643"}
0005433156805	A8FBBD	8638 033743	ARTEM SCHERBAKOV	{"phone": "+70010068091"}
0005433156806	716275	0241 909602	NINA ALEKSEEVA	{"email": "nina.alekseeva_1976@postgrespro.ru", "phone": "+70468047099"}
0005433156807	716275	3087 233980	ALEKSEY KARPOV	{"phone": "+70174164836"}
0005433156808	B49EED	5080 803516	DARYA SOLOVEVA	{"phone": "+70614308782"}
0005433156809	518100	3198 065268	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a.041976@postgrespro.ru", "phone": "+70044283269"}
0005433156810	518100	4225 606820	EKATERINA BOGDANOVA	{"phone": "+70369712471"}
0005433156811	518100	3853 835358	VALENTINA SOLOVEVA	{"email": "vsoloveva.1977@postgrespro.ru", "phone": "+70654616899"}
0005433156812	518100	5156 099092	ALEKSANDR BORISOV	{"phone": "+70839812959"}
0005433156813	F28304	1850 430817	MARGARITA MALYSHEVA	{"phone": "+70049603744"}
0005433156814	DECB7F	8020 347874	NATALYA POPOVA	{"email": "n-popova_02041977@postgrespro.ru", "phone": "+70041313040"}
0005433156815	DECB7F	9416 427127	ALBINA DAVYDOVA	{"phone": "+70967545646"}
0005433156816	1566FE	4283 911513	EVGENIY FEDOROV	{"email": "evgeniy-fedorov_1981@postgrespro.ru", "phone": "+70987147325"}
0005433156817	C13662	8505 864199	RAISA VOLKOVA	{"email": "raisavolkova_1982@postgrespro.ru", "phone": "+70386820324"}
0005433156818	C13662	5406 062928	NADEZHDA EGOROVA	{"email": "nadezhdaegorova_1964@postgrespro.ru", "phone": "+70634373911"}
0005433156819	28BB43	0035 812918	ANNA AFANASEVA	{"email": "aafanaseva-081979@postgrespro.ru", "phone": "+70969149374"}
0005433156820	B0F5E7	1635 539707	ANASTASIYA FROLOVA	{"email": "a-frolova_26121964@postgrespro.ru", "phone": "+70990519222"}
0005433156821	B0F5E7	5413 702414	ELENA NOVIKOVA	{"phone": "+70698380627"}
0005433156822	13F00C	3634 126883	ELENA FADEEVA	{"phone": "+70953082781"}
0005433156823	13F00C	5091 629890	DENIS BORISOV	{"phone": "+70897657065"}
0005433156824	5F7DE5	0374 605757	POLINA BARANOVA	{"email": "baranovap12111974@postgrespro.ru", "phone": "+70068436985"}
0005433156825	7DB747	9639 643277	LYUBOV ZAKHAROVA	{"email": "zakharova.lyubov061981@postgrespro.ru", "phone": "+70864407526"}
0005433156826	5E7DBC	8948 725964	OKSANA RYABOVA	{"email": "oksana.ryabova_23071977@postgrespro.ru", "phone": "+70683026720"}
0005433156827	D0525C	1223 685001	SERGEY SMIRNOV	{"phone": "+70726722052"}
0005433156828	F76AF0	3597 505995	VASILIY BELOV	{"phone": "+70010762680"}
0005433156829	9E0A1B	3348 360326	VYACHESLAV KUZNECOV	{"phone": "+70527465659"}
0005433156830	749951	5054 223685	YULIYA EGOROVA	{"phone": "+70101106201"}
0005433156831	749951	3922 923459	IRINA GAVRILOVA	{"phone": "+70566889414"}
0005433156832	3F2813	3865 644877	MARINA MIKHAYLOVA	{"phone": "+70318496251"}
0005433156833	38765B	6517 575504	ELENA DENISOVA	{"phone": "+70079969324"}
0005433156834	64DFEE	7575 968792	LYUDMILA MALYSHEVA	{"phone": "+70571213923"}
0005433156835	E2D77C	2968 059120	ROBERT STEPANOV	{"phone": "+70844056081"}
0005433156836	E2D77C	9413 994564	ALEKSANDR MIRONOV	{"phone": "+70776413490"}
0005433156837	87A907	8005 812652	ANATOLIY ZAKHAROV	{"phone": "+70761640595"}
0005433156838	FCD8D8	6165 407471	NINA LEBEDEVA	{"email": "ninalebedeva.07091955@postgrespro.ru", "phone": "+70113248012"}
0005433156839	49D5FF	2986 221973	TATYANA LOGINOVA	{"email": "tloginova.25051974@postgrespro.ru", "phone": "+70573248609"}
0005433156840	49D5FF	2074 821636	YURIY PETROV	{"phone": "+70205811363"}
0005433156841	992468	6434 176798	VASILIY MIKHAYLOV	{"email": "vmikhaylov-031964@postgrespro.ru", "phone": "+70683167506"}
0005433156842	1B6176	4537 760766	DENIS MOISEEV	{"email": "dmoiseev-1979@postgrespro.ru", "phone": "+70762673483"}
0005433156843	1B6176	7229 345053	ALENA TIKHONOVA	{"phone": "+70708421253"}
0005433156844	EE1590	2759 970218	NINA BELOVA	{"phone": "+70632370366"}
0005433156845	A00999	0553 799200	ALEKSANDR STEPANOV	{"phone": "+70090547775"}
0005433156846	A00999	1936 432736	VLADIMIR MATVEEV	{"phone": "+70684603886"}
0005433156847	36460A	8557 560413	VIKTOR FEDOROV	{"phone": "+70281409381"}
0005433156848	36460A	9459 009708	TAMARA NAUMOVA	{"phone": "+70113295816"}
0005433156849	459087	5954 294091	PELAGEYA ZAKHAROVA	{"phone": "+70781878555"}
0005433156850	F5A0E4	1713 770255	MIKHAIL NOVIKOV	{"email": "novikovm28011985@postgrespro.ru", "phone": "+70725957058"}
0005433156851	8512D3	1692 679557	ALEKSEY EGOROV	{"email": "aleksey-egorov.25071960@postgrespro.ru", "phone": "+70213144298"}
0005433156852	4532F5	5079 183334	VLADIMIR ANDREEV	{"email": "vladimir_andreev.1959@postgrespro.ru", "phone": "+70529132122"}
0005433156853	4054DE	1401 102145	NATALYA FILIPPOVA	{"email": "natalya_filippova.1982@postgrespro.ru", "phone": "+70749822506"}
0005433156854	1F8642	7546 576949	VALENTINA CHERNOVA	{"email": "chernova_valentina.18091978@postgrespro.ru", "phone": "+70212664256"}
0005433156855	1F8642	7029 523732	NIKOLAY NIKITIN	{"phone": "+70528211072"}
0005433156856	1F8642	2874 663169	MAKSIM GAVRILOV	{"email": "maksim-gavrilov.021978@postgrespro.ru", "phone": "+70353776219"}
0005433156857	428234	9745 207853	ALEKSANDR MAKSIMOV	{"phone": "+70604381289"}
0005433156858	428234	3769 998186	GALINA TITOVA	{"email": "titovag_031977@postgrespro.ru", "phone": "+70628687629"}
0005433156859	D0B5E9	9720 509475	MIKHAIL IVANOV	{"email": "m_ivanov1975@postgrespro.ru", "phone": "+70308841433"}
0005433156860	1F46EF	4268 436998	OLGA VOROBEVA	{"email": "o-vorobeva-091973@postgrespro.ru", "phone": "+70309785485"}
0005433156861	1F46EF	0736 452420	VYACHESLAV SERGEEV	{"email": "vyacheslav_sergeev.1967@postgrespro.ru", "phone": "+70602777651"}
0005433156862	15B6DF	2222 530949	MIKHAIL KOZLOV	{"phone": "+70538602028"}
0005433156863	3A8003	9831 935957	VLADIMIR VOLKOV	{"phone": "+70211086493"}
0005433156864	AA5E28	7782 774290	DMITRIY IVANOV	{"email": "ivanov-dmitriy_30041959@postgrespro.ru", "phone": "+70731148577"}
0005433156865	B3C5EA	2949 259233	NATALYA LUKYANOVA	{"email": "lukyanova_natalya041971@postgrespro.ru", "phone": "+70329787844"}
0005433156866	15A2C3	5062 574531	TATYANA FROLOVA	{"phone": "+70287248575"}
0005433156867	7F930A	6931 067024	MARIYA PETROVA	{"phone": "+70926956290"}
0005433156868	F8A66E	6411 922146	VALENTINA FOMINA	{"phone": "+70371584626"}
0005433156869	AB2583	9452 020858	LYUBOV KISELEVA	{"phone": "+70788737175"}
0005433156870	AB2583	3262 496164	NIKITA KONOVALOV	{"email": "nikita_konovalov-1976@postgrespro.ru", "phone": "+70478986718"}
0005433156871	227E27	4530 848415	RUSTYAM MIRONOV	{"email": "mironov.rustyam101973@postgrespro.ru", "phone": "+70796373631"}
0005433156872	97B621	8352 738966	OKSANA FOMINA	{"email": "fomina.oksana1962@postgrespro.ru", "phone": "+70165701961"}
0005433156873	97B621	4561 765493	KLAVDIYA ALEKSEEVA	{"email": "alekseeva_k.1970@postgrespro.ru", "phone": "+70765829163"}
0005433156874	C2AB28	5350 759199	VIKTOR IVANOV	{"phone": "+70926779034"}
0005433156875	C2AB28	3170 422342	VALERIYA ANTONOVA	{"phone": "+70298833279"}
0005433156876	E60579	2025 315930	FANIL MELNIKOV	{"email": "fmelnikov_24101970@postgrespro.ru", "phone": "+70591785637"}
0005433156877	A19B67	3340 453668	RAIL KISELEV	{"email": "kiselev_rail.06101971@postgrespro.ru", "phone": "+70952004056"}
0005433156878	D70A3C	0081 745223	ULYANA EGOROVA	{"email": "egorova_ulyana_11031975@postgrespro.ru", "phone": "+70546458427"}
0005433156879	451247	1837 530733	VASILIY IVANOV	{"email": "ivanovv.051979@postgrespro.ru", "phone": "+70192232321"}
0005433156880	B512C7	4089 643204	GENNADIY SEMENOV	{"phone": "+70637618790"}
0005433156881	F71E81	3850 712567	LARISA GORBUNOVA	{"email": "l-gorbunova.011964@postgrespro.ru", "phone": "+70739204183"}
0005433156882	F71E81	5503 972312	ANNA ZAKHAROVA	{"email": "a-zakharova.011976@postgrespro.ru", "phone": "+70166821359"}
0005433156883	0B9C38	2468 129893	LYUBOV AFANASEVA	{"email": "afanaseva.l.04031981@postgrespro.ru", "phone": "+70740785326"}
0005433156884	64D4C2	1658 676836	MARINA DAVYDOVA	{"email": "davydova_m-1971@postgrespro.ru", "phone": "+70124952392"}
0005433156885	1D9B5E	3251 379028	NIKOLAY GAVRILOV	{"email": "gavrilov_n.1972@postgrespro.ru", "phone": "+70133907533"}
0005433156886	1D9B5E	7805 264217	MAKSIM GORBUNOV	{"phone": "+70094820735"}
0005433156887	7AC36F	9623 667691	MARINA ARKHIPOVA	{"email": "arkhipova.m.23041967@postgrespro.ru", "phone": "+70866485832"}
0005433156888	7AC36F	4240 281175	VITALIY MELNIKOV	{"phone": "+70662943863"}
0005433156889	7AC36F	9751 440109	EKATERINA MIKHAYLOVA	{"email": "mikhaylova.ekaterina31121964@postgrespro.ru", "phone": "+70297381599"}
0005433156890	C2B11A	1202 859957	ALEKSANDR PETROV	{"phone": "+70399447363"}
0005433156891	3259AE	4834 915739	MARAT IVANOV	{"email": "ivanovmarat.30041971@postgrespro.ru", "phone": "+70271966236"}
0005433156892	A1958E	6864 877478	ILYA IVANOV	{"phone": "+70139688802"}
0005433156893	F4D47C	4142 365663	ALEKSEY ZHURAVLEV	{"email": "a_zhuravlev081963@postgrespro.ru", "phone": "+70471168789"}
0005433156894	1E9D75	3882 298905	NATALYA GUSEVA	{"phone": "+70370229518"}
0005433156895	1E9D75	5818 970660	ARINA MATVEEVA	{"phone": "+70106536379"}
0005433156896	59BFF5	4472 032327	KLAVDIYA NIKOLAEVA	{"email": "knikolaeva_20011978@postgrespro.ru", "phone": "+70655341252"}
0005433156897	D15A0F	7788 861202	TATYANA BORISOVA	{"phone": "+70541276466"}
0005433156898	D15A0F	2815 460439	NATALYA TIMOFEEVA	{"email": "natalya_timofeeva_23061970@postgrespro.ru", "phone": "+70652610465"}
0005433156899	729627	8352 315296	GALIYA VLASOVA	{"email": "galiyavlasova_11021973@postgrespro.ru", "phone": "+70187416818"}
0005433156900	3E5B9B	3917 777228	SARIYA CHERNOVA	{"email": "sariya.chernova.26011978@postgrespro.ru", "phone": "+70869176202"}
0005433156901	203A4F	9005 329216	EKATERINA GRISHINA	{"phone": "+70496864545"}
0005433156902	F88CBD	1177 035903	LIDIYA POTAPOVA	{"phone": "+70457206464"}
0005433156903	2524EA	4720 091453	ELENA MASLOVA	{"phone": "+70056113884"}
0005433156904	AB3F62	1230 046065	VALENTINA KOZLOVA	{"email": "kozlovav_19061986@postgrespro.ru", "phone": "+70046559547"}
0005433156905	842A7C	6203 297621	GENNADIY VOLKOV	{"email": "gennadiy-volkov.09031976@postgrespro.ru", "phone": "+70235890960"}
0005433156906	842A7C	5390 854548	OLGA MIRONOVA	{"phone": "+70779501488"}
0005433156907	842A7C	9022 276410	ROMAN SMIRNOV	{"email": "smirnov.roman-031961@postgrespro.ru", "phone": "+70559959298"}
0005433156908	E42C0E	7272 160939	IRINA PETROVA	{"email": "ipetrova_051976@postgrespro.ru", "phone": "+70667881940"}
0005433156909	9DEF1C	3713 470351	DMITRIY DAVYDOV	{"email": "dmitriy.davydov-1963@postgrespro.ru", "phone": "+70561549038"}
0005433156910	869199	8906 589394	NIKOLAY RODIONOV	{"phone": "+70863438628"}
0005433156911	DF59B0	2321 930538	ELENA LOGINOVA	{"phone": "+70046024694"}
0005433156912	8190D4	9306 115012	TATYANA IVANOVA	{"email": "tatyana_ivanova_051973@postgrespro.ru", "phone": "+70785833213"}
0005433156913	E37353	2745 283409	VALENTINA SAVELEVA	{"email": "saveleva-v.111974@postgrespro.ru", "phone": "+70089813234"}
0005433156914	E37353	6863 360074	SERGEY MOROZOV	{"email": "morozov.s.121959@postgrespro.ru", "phone": "+70110239328"}
0005433156915	518A01	4121 967139	ANNA KRASNOVA	{"email": "a_krasnova.021983@postgrespro.ru", "phone": "+70695947316"}
0005433156916	BD86EC	9567 893899	SERGEY MIKHAYLOV	{"email": "s-mikhaylov111970@postgrespro.ru", "phone": "+70615402968"}
0005433156917	BD86EC	5777 704360	MIKHAIL ROMANOV	{"email": "romanov-mikhail.021968@postgrespro.ru", "phone": "+70963387293"}
0005433156918	B4D62D	7447 284425	VALENTINA ZAKHAROVA	{"email": "valentina_zakharova101976@postgrespro.ru", "phone": "+70968128508"}
0005433156919	D07180	6701 159318	OLEG IVANOV	{"phone": "+70309177161"}
0005433156920	57D836	4164 944202	LILIYA FILIPPOVA	{"email": "filippova-liliya-111978@postgrespro.ru", "phone": "+70139578477"}
0005433156921	57D836	1113 428823	ANASTASIYA SEMENOVA	{"phone": "+70513756164"}
0005433156922	845773	5917 262655	ZOYA OSIPOVA	{"email": "osipova-zoya-111985@postgrespro.ru", "phone": "+70804969373"}
0005433156923	BBEC59	4731 370193	VLADIMIR SCHERBAKOV	{"email": "scherbakovv-20021971@postgrespro.ru", "phone": "+70569606140"}
0005433156924	106B4D	3961 043366	SERGEY POPOV	{"email": "popovs_26111984@postgrespro.ru", "phone": "+70456252312"}
0005433156925	7147C1	5985 200425	ANDREY GRIGOREV	{"email": "agrigorev-011970@postgrespro.ru", "phone": "+70720369974"}
0005433156926	F5CFFE	8975 901282	TATYANA VASILEVA	{"email": "tatyana.vasileva.051955@postgrespro.ru", "phone": "+70308241704"}
0005433156927	F5CFFE	1702 733557	VITALIY IVANOV	{"email": "v.ivanov_30081974@postgrespro.ru", "phone": "+70848309327"}
0005433156928	423F76	8371 339029	SERGEY NAUMOV	{"email": "naumov_sergey_1975@postgrespro.ru", "phone": "+70441297401"}
0005433156929	423F76	4165 544886	VIKTOR KUZMIN	{"phone": "+70636877926"}
0005433156930	8A2276	0319 795661	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_vladimir-09071981@postgrespro.ru", "phone": "+70668144936"}
0005433156931	B8676D	5762 146816	ELDAR SCHERBAKOV	{"email": "scherbakov-eldar-07081969@postgrespro.ru", "phone": "+70468200613"}
0005433156932	6379E5	5637 138284	KIRILL NIKOLAEV	{"email": "nikolaev_kirill.091974@postgrespro.ru", "phone": "+70107973260"}
0005433156933	E208BC	3790 859729	IRINA MELNIKOVA	{"phone": "+70281161967"}
0005433156934	FC101D	2945 836120	SERGEY TIKHONOV	{"email": "s.tikhonov14011973@postgrespro.ru", "phone": "+70321188638"}
0005433156935	3C3043	8120 852680	NINA NAZAROVA	{"phone": "+70730194330"}
0005433156936	3C3043	2623 182417	NATALYA KUZNECOVA	{"phone": "+70061423566"}
0005433156937	13ADDE	1208 911283	ELMIRA DAVYDOVA	{"email": "elmira-davydova_1975@postgrespro.ru", "phone": "+70081216417"}
0005433156938	DFB7D5	9700 939688	LYUBOV PAVLOVA	{"phone": "+70700278824"}
0005433156939	A51E71	9717 435575	GALINA MAKAROVA	{"phone": "+70310986260"}
0005433156940	ABDA1B	7066 667486	SVETLANA KOLESNIKOVA	{"email": "kolesnikova-svetlana1970@postgrespro.ru", "phone": "+70660029400"}
0005433156941	ABDA1B	2825 851602	TATYANA MAKAROVA	{"phone": "+70571491992"}
0005433156942	83F379	7483 486264	KIRILL NIKITIN	{"phone": "+70080208871"}
0005433156943	83F379	3414 069748	DMITRIY PAVLOV	{"phone": "+70046803381"}
0005433156944	1E68B9	1427 847373	ARTEM IVANOV	{"phone": "+70568159627"}
0005433156945	44D5D5	1721 182544	VLADIMIR MEDVEDEV	{"phone": "+70438621597"}
0005433156946	189676	3914 661449	NIKOLAY MOROZOV	{"email": "n_morozov09011975@postgrespro.ru", "phone": "+70326915721"}
0005433156947	F139E6	2729 048758	ALEKSANDR KONOVALOV	{"email": "konovalov_a051984@postgrespro.ru", "phone": "+70218380641"}
0005433156948	F139E6	8361 861655	IGOR SHEVCHENKO	{"phone": "+70476456874"}
0005433156949	389BF3	2836 082118	ANATOLIY MAKAROV	{"phone": "+70531737987"}
0005433156950	4FD55D	8295 030886	SERGEY TIKHONOV	{"email": "tikhonov.sergey-021980@postgrespro.ru", "phone": "+70552404809"}
0005433156951	4FD55D	6099 936395	IGOR MIKHAYLOV	{"phone": "+70139172177"}
0005433156952	483461	8503 520995	VALENTINA SIDOROVA	{"phone": "+70583083642"}
0005433156953	C78A17	9620 540916	SNEZHANA ZOTOVA	{"phone": "+70205213704"}
0005433156954	B996D8	2614 695495	TATYANA SAVELEVA	{"phone": "+70081056190"}
0005433156955	0F5496	2503 915287	TIMOFEY KUZNECOV	{"phone": "+70066287734"}
0005433156956	97CC32	6598 293052	VALENTINA KUDRYASHOVA	{"phone": "+70339420364"}
0005433156957	97CC32	5135 113118	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov18051983@postgrespro.ru", "phone": "+70850204725"}
0005433156958	3AC6D4	1603 731475	INNA YUDINA	{"phone": "+70504603234"}
0005433156959	3AC6D4	7923 132864	TATYANA KOROLEVA	{"email": "t.koroleva.101967@postgrespro.ru", "phone": "+70623940237"}
0005433156960	243CC8	4703 863070	ALEKSANDR FILIPPOV	{"phone": "+70507932113"}
0005433156961	FC669A	1635 681747	IRINA ANISIMOVA	{"phone": "+70539778347"}
0005433156962	7A91AF	4245 008990	LIDIYA MAKSIMOVA	{"phone": "+70655115883"}
0005433156963	3A9B50	8258 302350	VERA KALININA	{"email": "kalinina-vera.1978@postgrespro.ru", "phone": "+70838068038"}
0005433156964	8335A3	5714 744873	VERA ZHUKOVA	{"phone": "+70418231766"}
0005433156965	8335A3	2587 520493	OLGA KUZNECOVA	{"email": "kuznecovaolga.1957@postgrespro.ru", "phone": "+70483661974"}
0005433156966	20C321	7133 042868	NIKOLAY MAKSIMOV	{"phone": "+70219409051"}
0005433156967	654213	6950 918204	SERGEY ZAKHAROV	{"phone": "+70952760700"}
0005433156968	654213	0815 753055	GALINA ANDREEVA	{"email": "andreevagalina-121972@postgrespro.ru", "phone": "+70976815644"}
0005433156969	5BFA6B	2361 932091	ALEKSANDR DAVYDOV	{"email": "davydov_aleksandr-1955@postgrespro.ru", "phone": "+70104293716"}
0005433156970	5BFA6B	8728 789323	ALEKSEY SAVELEV	{"email": "alekseysavelev.1967@postgrespro.ru", "phone": "+70707051876"}
0005433158158	E43928	0219 599087	SERGEY FILIPPOV	{"phone": "+70269268914"}
0005433156971	1428AF	8287 419250	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev1976@postgrespro.ru", "phone": "+70180549168"}
0005433156972	F45B58	7472 900567	ALEKSANDR KUZNECOV	{"phone": "+70448322591"}
0005433156973	F45B58	9889 474692	OLEG SOLOVEV	{"phone": "+70071432295"}
0005433156974	53AFB6	0470 884690	GERMAN SIDOROV	{"email": "sidorov.german-071975@postgrespro.ru", "phone": "+70676449623"}
0005433156975	232193	6758 207101	ELENA FOMINA	{"phone": "+70165066948"}
0005433156976	AE11A5	2707 881631	POLINA SOLOVEVA	{"email": "psoloveva.091972@postgrespro.ru", "phone": "+70368909351"}
0005433156977	AE11A5	1186 153508	ALEKSEY KISELEV	{"phone": "+70011623028"}
0005433156978	20A056	7211 232951	KIRILL ZAYCEV	{"phone": "+70179557982"}
0005433156979	20A056	1183 071128	ANASTASIYA KOMAROVA	{"phone": "+70013890945"}
0005433156980	76AFBB	8666 656950	TATYANA TIKHONOVA	{"email": "tikhonova.tatyana19111969@postgrespro.ru", "phone": "+70330859412"}
0005433156981	76AFBB	5605 625378	ALLA GRISHINA	{"phone": "+70612435236"}
0005433156982	76AFBB	6430 664095	DMITRIY KRASNOV	{"phone": "+70570181632"}
0005433156983	1AF658	2901 907767	YURIY GERASIMOV	{"phone": "+70843852914"}
0005433156984	9B8EA0	6401 941907	ANDREY KUZMIN	{"email": "kuzmin.andrey01061967@postgrespro.ru", "phone": "+70198431907"}
0005433156985	512A59	4880 308939	NIKOLAY KUDRYASHOV	{"email": "nikolay_kudryashov-1970@postgrespro.ru", "phone": "+70105719549"}
0005433156986	218D2C	9007 032057	SERGEY SCHERBAKOV	{"email": "s_scherbakov_14071981@postgrespro.ru", "phone": "+70390584480"}
0005433156987	218D2C	8029 323863	LYUDMILA MIRONOVA	{"email": "mironoval_1976@postgrespro.ru", "phone": "+70900538140"}
0005433156988	38C8F1	0991 857389	ANDREY KARPOV	{"phone": "+70854769145"}
0005433156989	456EF4	3870 377385	VALENTINA TROFIMOVA	{"email": "trofimova.v-061970@postgrespro.ru", "phone": "+70043036382"}
0005433156990	29A2FF	9950 801970	RAISA KAZAKOVA	{"email": "raisakazakova.28081979@postgrespro.ru", "phone": "+70739936898"}
0005433156991	29A2FF	8363 708092	LEONID BELOV	{"email": "belov-l.1969@postgrespro.ru", "phone": "+70834758721"}
0005433156992	3CB470	1695 796118	EVGENIYA NESTEROVA	{"email": "nesterovaevgeniya_1962@postgrespro.ru", "phone": "+70809214324"}
0005433156993	3CB470	4975 737482	ANTON EGOROV	{"email": "egorova.16111974@postgrespro.ru", "phone": "+70389955468"}
0005433156994	0B65A0	1839 857941	FARID KOROLEV	{"phone": "+70587367358"}
0005433156995	7A40D0	0036 517323	ALEKSEY VASILEV	{"email": "vasilev_a_011972@postgrespro.ru", "phone": "+70726328681"}
0005433156996	6C98EE	1110 988531	EVGENIY KUZNECOV	{"phone": "+70132765948"}
0005433156997	18694B	9807 660076	VALENTINA IVANOVA	{"email": "valentinaivanova_1971@postgrespro.ru", "phone": "+70143844699"}
0005433156998	18694B	5760 860933	RUSLAN PAVLOV	{"email": "pavlovr.111962@postgrespro.ru", "phone": "+70326392543"}
0005433156999	1892C2	7737 070547	EKATERINA GUSEVA	{"phone": "+70086512611"}
0005433157000	1892C2	1869 378235	IGOR SHEVCHENKO	{"email": "i.shevchenko_041977@postgrespro.ru", "phone": "+70809985547"}
0005433157001	C7D0D4	9874 720202	EVGENIY CHERNOV	{"email": "chernov_e24091980@postgrespro.ru", "phone": "+70336436437"}
0005433157002	8423C3	1197 095921	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr03091968@postgrespro.ru", "phone": "+70981848361"}
0005433157003	90D2AE	1029 627872	ANNA FILIPPOVA	{"phone": "+70648632689"}
0005433157004	C50B46	1530 729157	GALINA LEBEDEVA	{"email": "lebedevagalina30081971@postgrespro.ru", "phone": "+70744948410"}
0005433157005	40C1A8	1381 593754	DMITRIY KISELEV	{"email": "kiselev_dmitriy.26011969@postgrespro.ru", "phone": "+70434614491"}
0005433157006	D344CF	9902 164556	LYUBOV ALEKSANDROVA	{"email": "l_aleksandrova.041966@postgrespro.ru", "phone": "+70674983006"}
0005433157007	D344CF	1959 781706	NADEZHDA SOKOLOVA	{"email": "nadezhda.sokolova-09031963@postgrespro.ru", "phone": "+70785871895"}
0005433157008	52F37A	2643 848643	DMITRIY SEMENOV	{"email": "dmitriy.semenov1966@postgrespro.ru", "phone": "+70852703604"}
0005433157009	52F37A	3397 034512	LIDIYA SMIRNOVA	{"email": "smirnovalidiya_101978@postgrespro.ru", "phone": "+70830955061"}
0005433157010	95F56F	6995 208116	EVGENIYA KRASNOVA	{"email": "krasnova-e.01021979@postgrespro.ru", "phone": "+70940511058"}
0005433157011	35D530	6282 672980	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.aleksandr21081966@postgrespro.ru", "phone": "+70793251679"}
0005433157012	847C8A	3524 044477	DAVID AFANASEV	{"email": "afanasev.david_20091967@postgrespro.ru", "phone": "+70179278784"}
0005433157013	E688B4	3255 366933	DARYA SERGEEVA	{"email": "darya_sergeeva17021975@postgrespro.ru", "phone": "+70518762595"}
0005433157014	E688B4	2319 803687	NATALYA GERASIMOVA	{"email": "n_gerasimova.1968@postgrespro.ru", "phone": "+70459964244"}
0005433157015	E688B4	2899 559144	IVAN ANTONOV	{"phone": "+70239314812"}
0005433157016	19E474	6484 872037	FEDOR DAVYDOV	{"phone": "+70639241011"}
0005433157017	3F3C8F	3080 418733	NATALYA SEMENOVA	{"email": "n.semenova-071969@postgrespro.ru", "phone": "+70697935142"}
0005433157018	3F3C8F	5142 238717	NIKOLAY DENISOV	{"email": "denisovnikolay-1962@postgrespro.ru", "phone": "+70865830743"}
0005433157019	E45B87	4896 128874	LYUDMILA ROMANOVA	{"email": "l-romanova021986@postgrespro.ru", "phone": "+70822387192"}
0005433157020	E45B87	5370 617794	NIKOLAY KUZNECOV	{"phone": "+70105490225"}
0005433157021	6C9948	1533 538895	SERGEY VOROBEV	{"phone": "+70512699123"}
0005433157022	6C9948	0911 367399	MARINA MIRONOVA	{"phone": "+70718441309"}
0005433158093	0D978B	3164 574236	MARINA FILATOVA	{"email": "filatova-marina.31081962@postgrespro.ru", "phone": "+70229229181"}
0005433158094	0D978B	5855 058193	VLADIMIR POPOV	{"phone": "+70058698505"}
0005433158095	7CC6C5	9600 747608	NADEZHDA FEDOROVA	{"phone": "+70625596582"}
0005433158096	17AA1B	6588 624027	ARINA SOROKINA	{"phone": "+70289463599"}
0005433158097	17AA1B	2738 603196	ANATOLIY KISELEV	{"phone": "+70649766845"}
0005433158098	3CC68B	1600 859008	VALENTINA SOKOLOVA	{"phone": "+70893652835"}
0005433158159	E43928	8750 888863	ANATOLIY NAZAROV	{"phone": "+70372126495"}
0005433158099	F7F9F5	2079 733846	VLADIMIR ROMANOV	{"email": "romanov.v-1976@postgrespro.ru", "phone": "+70764244139"}
0005433158100	F18C5A	8955 524842	VIKTOR MEDVEDEV	{"email": "medvedev_viktor-041977@postgrespro.ru", "phone": "+70927606792"}
0005433158101	92BABE	7406 713051	GEORGIY KULIKOV	{"phone": "+70508344416"}
0005433158102	92BABE	5215 978513	TATYANA STEPANOVA	{"email": "stepanova-t.061979@postgrespro.ru", "phone": "+70222550643"}
0005433158103	85BE5B	7542 659405	SVETLANA BARANOVA	{"email": "baranova-svetlana22071970@postgrespro.ru", "phone": "+70739496923"}
0005433158104	9FD333	7058 444128	GALINA FROLOVA	{"email": "galina.frolova.091979@postgrespro.ru", "phone": "+70691441987"}
0005433158105	9FD333	5469 788055	IVAN PETROV	{"email": "petrov.i_1965@postgrespro.ru", "phone": "+70761745729"}
0005433158106	C38E8C	3141 008635	ALEKSANDR ISAEV	{"email": "isaev_aleksandr101972@postgrespro.ru", "phone": "+70306595771"}
0005433158107	7B3AD0	5501 575336	SVETLANA ANDREEVA	{"phone": "+70332378981"}
0005433158108	7B3AD0	1481 783096	TAISIYA ZAKHAROVA	{"email": "tzakharova.13051973@postgrespro.ru", "phone": "+70122555894"}
0005433158109	88197E	9225 889440	TATYANA ZHURAVLEVA	{"phone": "+70121113248"}
0005433158110	36CDF5	9064 806502	MARGARITA FEDOROVA	{"email": "m_fedorova_02051977@postgrespro.ru", "phone": "+70646481365"}
0005433158111	36CDF5	2594 674454	DENIS ZAKHAROV	{"email": "zakharov_denis111952@postgrespro.ru", "phone": "+70544809281"}
0005433158112	1D7069	3319 673630	LYUCIYA NIKITINA	{"phone": "+70766548861"}
0005433158113	1D7069	3824 704447	ZHANNA AFANASEVA	{"phone": "+70106142780"}
0005433158114	2CFE38	7259 340321	NINA POPOVA	{"phone": "+70799640646"}
0005433158115	2CFE38	9910 967575	EVGENIY FILIPPOV	{"phone": "+70633151752"}
0005433158116	B01457	7028 122230	OLGA BELYAEVA	{"email": "belyaevao25011984@postgrespro.ru", "phone": "+70739484173"}
0005433158117	72F57A	3962 102240	EVGENIY SCHERBAKOV	{"email": "e_scherbakov02091972@postgrespro.ru", "phone": "+70159698579"}
0005433158118	A2026A	9683 530117	ARTEM MARTYNOV	{"phone": "+70829759335"}
0005433158119	A2D54B	7676 015512	ANNA LOGINOVA	{"phone": "+70243505403"}
0005433158120	D22BDE	0457 862220	FAIL AFANASEV	{"email": "failafanasev1969@postgrespro.ru", "phone": "+70687114914"}
0005433158121	42B80E	0325 345870	ELENA KOZLOVA	{"phone": "+70999571185"}
0005433158122	8B032F	4884 737146	NATALYA DAVYDOVA	{"email": "davydova.n.1969@postgrespro.ru", "phone": "+70517518392"}
0005433158123	679563	6510 468418	MILANA MOROZOVA	{"email": "morozova_milana.26091971@postgrespro.ru", "phone": "+70675043625"}
0005433158124	0393DE	4327 734052	GENNADIY SMIRNOV	{"email": "gennadiy_smirnov-1971@postgrespro.ru", "phone": "+70247301420"}
0005433158125	0393DE	8906 898454	DMITRIY TARASOV	{"email": "tarasov_d-11071980@postgrespro.ru", "phone": "+70243160488"}
0005433158126	9D8100	5114 995126	OLGA ZAYCEVA	{"email": "zaycevao-26071966@postgrespro.ru", "phone": "+70747156008"}
0005433158127	9D8100	1431 099622	RAMIL POPOV	{"email": "ramil.popov_24041963@postgrespro.ru", "phone": "+70263336018"}
0005433158128	34A808	0388 690067	EVGENIYA LOGINOVA	{"email": "loginova_evgeniya-051979@postgrespro.ru", "phone": "+70806982507"}
0005433158129	D27C7D	9419 123888	RUZALIYA ALEKSEEVA	{"email": "r_alekseeva-1969@postgrespro.ru", "phone": "+70982702837"}
0005433158130	D27C7D	3705 000214	EVGENIY SMIRNOV	{"email": "smirnove.121970@postgrespro.ru", "phone": "+70963349594"}
0005433158131	B0BE3D	6899 472990	SERGEY SERGEEV	{"email": "sergeev.s.22061976@postgrespro.ru", "phone": "+70107563694"}
0005433158132	B0BE3D	7853 009053	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr-071970@postgrespro.ru", "phone": "+70982710008"}
0005433158133	E17E1B	3346 673330	ANTON SIDOROV	{"email": "a_sidorov.051969@postgrespro.ru", "phone": "+70023944031"}
0005433158134	E17E1B	8062 167935	FANIL PAVLOV	{"email": "pavlov.fanil-1969@postgrespro.ru", "phone": "+70108269000"}
0005433158135	1903D5	1482 562509	VALERIY NIKOLAEV	{"email": "valeriy_nikolaev-16051966@postgrespro.ru", "phone": "+70224078133"}
0005433158136	329F07	8399 253219	BOGDAN NAUMOV	{"email": "b.naumov.1963@postgrespro.ru", "phone": "+70441422657"}
0005433158137	329F07	8357 513925	ALEKSANDR YAKOVLEV	{"email": "ayakovlev041973@postgrespro.ru", "phone": "+70361626354"}
0005433158138	332807	2381 829369	DMITRIY ORLOV	{"phone": "+70980688479"}
0005433158139	332807	7651 818207	IRINA KUZMINA	{"phone": "+70208715502"}
0005433158140	C18FFE	6548 101536	ZAKHAR MOROZOV	{"phone": "+70699457960"}
0005433158141	160D79	7870 995616	DMITRIY VOLKOV	{"email": "dmitriy.volkov-061970@postgrespro.ru", "phone": "+70755865654"}
0005433158142	857BAD	4998 844609	ROZA GAVRILOVA	{"email": "r_gavrilova1967@postgrespro.ru", "phone": "+70872481442"}
0005433158143	126E75	6571 241947	YURIY KARPOV	{"email": "ykarpov.081967@postgrespro.ru", "phone": "+70452430071"}
0005433158144	6A6A59	7699 512194	MIKHAIL KUZNECOV	{"email": "kuznecov_m-1966@postgrespro.ru", "phone": "+70239561833"}
0005433158145	6A6A59	3823 526251	LYUDMILA LUKYANOVA	{"phone": "+70282073743"}
0005433158146	CF504D	3389 841567	VALERIY GORBUNOV	{"phone": "+70855162567"}
0005433158147	38F325	5686 977481	MARINA BELYAEVA	{"phone": "+70298830015"}
0005433158148	38F325	5292 609697	VLADIMIR NIKITIN	{"phone": "+70230503682"}
0005433158149	72FE93	0272 977221	VITALIY RODIONOV	{"phone": "+70943021397"}
0005433158150	04810B	8864 707509	BORIS SEMENOV	{"phone": "+70580256367"}
0005433158151	DCE2D8	0512 372379	SERGEY DENISOV	{"phone": "+70033488026"}
0005433158152	1D06F8	9711 151256	VASILIY IVANOV	{"phone": "+70263029439"}
0005433158153	78C294	4899 265572	ALEKSANDR MELNIKOV	{"phone": "+70374930608"}
0005433158154	78C294	6466 901067	SVETLANA ORLOVA	{"phone": "+70847459467"}
0005433158155	660CB1	6568 134315	MARINA KOROLEVA	{"phone": "+70165975398"}
0005433158156	991E71	8221 069271	IRINA ABRAMOVA	{"email": "abramova-irina-061975@postgrespro.ru", "phone": "+70570604087"}
0005433158157	A4AA79	4654 614134	YULIYA KOVALEVA	{"phone": "+70265468448"}
0005433158160	FB94A4	0724 657301	MARINA NAZAROVA	{"email": "nazarova_m051967@postgrespro.ru", "phone": "+70195981735"}
0005433158161	FB94A4	9171 540803	OLGA ANTONOVA	{"email": "olgaantonova061962@postgrespro.ru", "phone": "+70969282196"}
0005433158162	FB94A4	3282 551438	ALEKSANDR ANDREEV	{"phone": "+70471195054"}
0005433158163	1C504F	8576 488343	ALEFTINA KUZNECOVA	{"email": "kuznecovaaleftina101980@postgrespro.ru", "phone": "+70028478119"}
0005433158164	06B8E3	2603 669431	VIKTOR MAKAROV	{"phone": "+70713716688"}
0005433158165	06B8E3	8831 994611	ILYA MAKAROV	{"email": "ilya.makarov_1977@postgrespro.ru", "phone": "+70036928128"}
0005433158166	1E43F0	5126 976968	IRINA EFREMOVA	{"phone": "+70105693522"}
0005433158167	870F80	5463 803110	ROMAN GRIGOREV	{"email": "romangrigorev.061980@postgrespro.ru", "phone": "+70106025223"}
0005433158168	6566CF	4907 366554	IVAN NAZAROV	{"email": "nazarov-ivan_1982@postgrespro.ru", "phone": "+70880876522"}
0005433158169	89E87F	6788 463676	ANDREY ALEKSANDROV	{"email": "a.aleksandrov.1954@postgrespro.ru", "phone": "+70916591168"}
0005433158170	8302F2	6924 112746	NATALYA SOKOLOVA	{"email": "n_sokolova101966@postgrespro.ru", "phone": "+70627042174"}
0005433158171	E05DBA	5700 264775	ALEKSEY POPOV	{"phone": "+70586053294"}
0005433158172	486EFC	8959 980694	ELENA ISAEVA	{"email": "isaeva.elena_051968@postgrespro.ru", "phone": "+70274958261"}
0005433158173	486EFC	2169 594414	PAVEL STEPANOV	{"email": "p.stepanov1969@postgrespro.ru", "phone": "+70328893641"}
0005433158174	31CF6D	1716 351214	NADEZHDA KOLESNIKOVA	{"email": "kolesnikova_nadezhda-041967@postgrespro.ru", "phone": "+70296212675"}
0005433158175	31CF6D	6908 676572	ILGIZ ORLOV	{"email": "ilgiz_orlov.1971@postgrespro.ru", "phone": "+70712287513"}
0005433158176	F52BEA	0647 167945	IVAN NAZAROV	{"email": "inazarov_1968@postgrespro.ru", "phone": "+70997198570"}
0005433158177	2E0850	5473 533966	ANATOLIY KULIKOV	{"phone": "+70841117112"}
0005433158178	7EFCD9	6048 088150	ALEKSANDR FOMIN	{"phone": "+70647610417"}
0005433158179	EB6DDC	4074 862040	ANATOLIY MELNIKOV	{"phone": "+70884156812"}
0005433158180	00E551	6053 546895	EKATERINA ZAYCEVA	{"phone": "+70982738567"}
0005433158181	00E551	9139 081494	SERGEY ZAKHAROV	{"email": "s_zakharov_02051972@postgrespro.ru", "phone": "+70324787281"}
0005433158182	E23501	7973 728608	ALEKSEY PAVLOV	{"phone": "+70452671206"}
0005433158183	717AD3	2513 914107	EVGENIY KUZNECOV	{"email": "evgeniykuznecov1963@postgrespro.ru", "phone": "+70433512580"}
0005433158184	C2D3B0	3389 096318	VLADIMIR IVANOV	{"email": "v-ivanov-021971@postgrespro.ru", "phone": "+70124589620"}
0005433158185	F97024	1687 822188	SERGEY PAVLOV	{"phone": "+70572824841"}
0005433158186	F97024	7230 362851	VLADIMIR SOKOLOV	{"phone": "+70836308205"}
0005433158187	3E1222	1373 453586	ARSENIY MIKHAYLOV	{"email": "mikhaylov_arseniy.081964@postgrespro.ru", "phone": "+70041917497"}
0005433158188	3E1222	6087 979504	IVAN BELOV	{"email": "belov.i_1973@postgrespro.ru", "phone": "+70068519338"}
0005433158189	52E413	7618 387067	ANDREY SERGEEV	{"phone": "+70246194188"}
0005433158190	85115F	0001 950156	ANATOLIY ROMANOV	{"email": "romanov_anatoliy.1968@postgrespro.ru", "phone": "+70492671661"}
0005433158191	F4534F	9824 587794	VERA KULIKOVA	{"phone": "+70019593024"}
0005433158192	9430C1	5842 265036	NIKOLAY GAVRILOV	{"phone": "+70404870311"}
0005433158193	9430C1	4890 932913	YURIY MARTYNOV	{"email": "yuriy_martynov.031969@postgrespro.ru", "phone": "+70277971284"}
0005433158194	9430C1	3801 357806	YULIYA IVANOVA	{"phone": "+70876280022"}
0005433158195	706983	8809 564217	ANASTASIYA GUSEVA	{"phone": "+70541182137"}
0005433158196	931266	8728 182843	MARIYA ALEKSANDROVA	{"phone": "+70748133909"}
0005433158197	FA7A5B	2149 732242	IRINA SOROKINA	{"phone": "+70355336205"}
0005433158198	BCA726	9022 411563	NATALYA KOZLOVA	{"phone": "+70533512982"}
0005433158199	B2FB7D	5008 102938	DMITRIY KUZMIN	{"email": "d.kuzmin-21021992@postgrespro.ru", "phone": "+70233560946"}
0005433158200	16DF0E	3231 792457	EVGENIY KUZNECOV	{"phone": "+70659780335"}
0005433158201	3828D5	8242 019474	NELYA MOROZOVA	{"phone": "+70053003312"}
0005433158202	AB4E34	9223 557023	AMINA KOROLEVA	{"email": "koroleva-a_021969@postgrespro.ru", "phone": "+70805018060"}
0005433158203	AB4E34	6946 340997	OLGA KISELEVA	{"phone": "+70209525201"}
0005433158204	220ADE	6607 444285	DARYA TIKHONOVA	{"email": "d.tikhonova_26051965@postgrespro.ru", "phone": "+70177652726"}
0005433158205	220ADE	5871 962766	POLINA MOROZOVA	{"email": "morozova.p_1981@postgrespro.ru", "phone": "+70595679612"}
0005433158206	FD609D	3832 883348	ELENA KUZNECOVA	{"phone": "+70105784028"}
0005433159274	D416AE	8459 778521	EVGENIY NAZAROV	{"phone": "+70051636176"}
0005433159275	EDECEC	0173 906306	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova-tamara_051978@postgrespro.ru", "phone": "+70093341080"}
0005433159276	EDECEC	8915 853686	OLGA ANDREEVA	{"email": "andreeva_olga19121977@postgrespro.ru", "phone": "+70300375003"}
0005433159277	5D7FFF	1881 180807	TATYANA PAVLOVA	{"email": "pavlova.t21051982@postgrespro.ru", "phone": "+70160882806"}
0005433159278	D82A8F	1312 510798	ALEKSEY GUSEV	{"email": "guseva.1969@postgrespro.ru", "phone": "+70925935448"}
0005433159279	273D2A	8077 857704	KIRILL ANDREEV	{"email": "kirillandreev.1973@postgrespro.ru", "phone": "+70161295017"}
0005433159280	273D2A	6590 002092	ANNA NAUMOVA	{"phone": "+70066564637"}
0005433159281	949B23	3455 219995	TATYANA SEMENOVA	{"email": "t.semenova.1966@postgrespro.ru", "phone": "+70230194139"}
0005433159282	16159A	8547 855917	OLGA ABRAMOVA	{"phone": "+70703220319"}
0005433159283	0A3128	4043 319910	VIKTORIYA KRASNOVA	{"email": "krasnova_v-1978@postgrespro.ru", "phone": "+70516297150"}
0005433159284	0A3128	7531 263300	ALEKSEY SMIRNOV	{"email": "asmirnov-26031973@postgrespro.ru", "phone": "+70777827269"}
0005433159285	0A3128	2857 177709	VALENTINA SERGEEVA	{"email": "sergeeva.valentina1973@postgrespro.ru", "phone": "+70772492635"}
0005433159345	699384	2861 911454	SERGEY SCHERBAKOV	{"phone": "+70917677401"}
0005433159286	7D58BA	2069 465796	MARIYA GORBUNOVA	{"email": "m-gorbunova-071974@postgrespro.ru", "phone": "+70713689458"}
0005433159287	5834C6	1147 876768	VLADIMIR MAKAROV	{"phone": "+70595453670"}
0005433159288	5834C6	9906 545419	ELENA ISAEVA	{"phone": "+70508918083"}
0005433159289	CE5E0E	2723 088981	DMITRIY VOLKOV	{"email": "d-volkov.061966@postgrespro.ru", "phone": "+70484580804"}
0005433159290	3E6270	1929 884047	MAKSIM KOROLEV	{"phone": "+70550399306"}
0005433159291	741183	1915 188360	MIKHAIL KUZNECOV	{"email": "kuznecovmikhail.24091971@postgrespro.ru", "phone": "+70338743424"}
0005433159292	ECA55A	9241 409740	MARIYA MIKHAYLOVA	{"phone": "+70578169917"}
0005433159293	1C1D2D	3565 080960	ARTEM FEDOTOV	{"phone": "+70201748756"}
0005433159294	1C1D2D	7312 415699	ANTONINA BELOVA	{"phone": "+70469821293"}
0005433159295	1C1D2D	0647 216630	EGOR IVANOV	{"phone": "+70242969898"}
0005433159296	2C0832	4862 059602	LEONID KULIKOV	{"email": "kulikovleonid-03061969@postgrespro.ru", "phone": "+70702967798"}
0005433159297	2C0832	0748 907640	GENNADIY MARTYNOV	{"phone": "+70075244081"}
0005433159298	41A19C	4415 136643	EGOR DAVYDOV	{"email": "egordavydov.23121973@postgrespro.ru", "phone": "+70454621928"}
0005433159299	2B2219	8298 133058	ROMAN AFANASEV	{"email": "romanafanasev-1962@postgrespro.ru", "phone": "+70326678533"}
0005433159300	2B2219	5954 112184	GALINA FILIPPOVA	{"email": "filippova.galina.1979@postgrespro.ru", "phone": "+70550789301"}
0005433159301	9B1872	2986 923019	YULIYA KOLESNIKOVA	{"phone": "+70032185162"}
0005433159302	D96151	3942 068048	DMITRIY DMITRIEV	{"email": "dmitriev_dmitriy-021972@postgrespro.ru", "phone": "+70978781414"}
0005433159303	D96151	0560 259478	VIKTOR AFANASEV	{"email": "viktor.afanasev_1965@postgrespro.ru", "phone": "+70886598992"}
0005433159304	5EC43E	3653 028008	ALEKSANDR MAKSIMOV	{"email": "maksimov-a_1980@postgrespro.ru", "phone": "+70513379233"}
0005433159305	675549	0183 880917	VIKTORIYA SEMENOVA	{"phone": "+70582544296"}
0005433159306	A3A5D5	5978 480571	ANDREY BORISOV	{"email": "borisovandrey-10111972@postgrespro.ru", "phone": "+70181949247"}
0005433159307	CC4328	0293 331134	ANATOLIY GORBUNOV	{"email": "agorbunov061969@postgrespro.ru", "phone": "+70009524966"}
0005433159308	0DC7F8	1385 148847	VLADIMIR KUZNECOV	{"phone": "+70559740932"}
0005433159309	0DC7F8	9772 711900	MARIYA LEBEDEVA	{"email": "mariya.lebedeva-1966@postgrespro.ru", "phone": "+70139393109"}
0005433159310	5292C8	3490 657425	SERGEY IVANOV	{"phone": "+70768037483"}
0005433159311	5292C8	4418 323822	IVAN KAZAKOV	{"email": "kazakov.i.22111977@postgrespro.ru", "phone": "+70022771499"}
0005433159312	8C69BD	3130 908901	MIKHAIL SAVELEV	{"email": "savelev-m.121977@postgrespro.ru", "phone": "+70948988633"}
0005433159313	8C69BD	6289 334484	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov_021966@postgrespro.ru", "phone": "+70897584831"}
0005433159314	C6D3CE	7702 018971	DMITRIY MAKAROV	{"phone": "+70705593158"}
0005433159315	C6D3CE	8466 999778	OLESYA POPOVA	{"email": "o.popova.031974@postgrespro.ru", "phone": "+70462771937"}
0005433159316	C6D3CE	0715 762686	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov_1963@postgrespro.ru", "phone": "+70296712693"}
0005433159317	95C4A7	1681 483812	GALINA FOMINA	{"email": "galina_fomina031961@postgrespro.ru", "phone": "+70253808984"}
0005433159318	95C4A7	6855 001551	YURIY NAUMOV	{"phone": "+70937825664"}
0005433159319	381E69	8088 174966	ANTONINA STEPANOVA	{"phone": "+70818134109"}
0005433159320	2D018D	6140 671402	IGOR POPOV	{"email": "popov-i_1978@postgrespro.ru", "phone": "+70038009301"}
0005433159321	2D018D	0455 950006	VIKTOR FEDOROV	{"email": "fedorovv13041985@postgrespro.ru", "phone": "+70806711889"}
0005433159322	B9EA3D	8317 253404	VLADIMIR MIKHAYLOV	{"phone": "+70667058046"}
0005433159323	B46B5C	7296 772567	RITA NIKITINA	{"phone": "+70826849776"}
0005433159324	DC1F55	0622 217453	YURIY ZHUKOV	{"email": "zhukov_y1971@postgrespro.ru", "phone": "+70430274227"}
0005433159325	FA0443	3660 123093	SERGEY FROLOV	{"phone": "+70355473989"}
0005433159326	CF2D2A	3347 799690	ANASTASIYA ISAEVA	{"email": "isaeva_anastasiya071967@postgrespro.ru", "phone": "+70584407586"}
0005433159327	CF2D2A	8034 095235	EVGENIYA PAVLOVA	{"email": "pavlova_e101977@postgrespro.ru", "phone": "+70560391031"}
0005433159328	B1ECCD	6055 339577	ALEKSANDR ISAEV	{"email": "aleksandr.isaev_1970@postgrespro.ru", "phone": "+70005090741"}
0005433159329	6C92F3	5068 627630	VLADIMIR MELNIKOV	{"phone": "+70823408158"}
0005433159330	AAE56C	6248 182959	SERGEY MAKAROV	{"phone": "+70456416632"}
0005433159331	AAE56C	2149 512088	ANASTASIYA NAZAROVA	{"phone": "+70384530230"}
0005433159332	AAE56C	3385 122582	RAISA IVANOVA	{"email": "r-ivanova_07031976@postgrespro.ru", "phone": "+70610239967"}
0005433159333	F1BEB5	4777 675899	ANTONINA VLASOVA	{"email": "vlasovaa_041962@postgrespro.ru", "phone": "+70590070548"}
0005433159334	F1BEB5	9092 143538	IRINA KUDRYASHOVA	{"email": "kudryashova_i021968@postgrespro.ru", "phone": "+70613223522"}
0005433159335	64D8C3	4455 897989	OLGA MAKSIMOVA	{"phone": "+70832606968"}
0005433159336	64D8C3	0670 206537	RUSLAN ABRAMOV	{"email": "abramovruslan26081969@postgrespro.ru", "phone": "+70717592670"}
0005433159337	5163BE	3121 215781	NADEZHDA SAVELEVA	{"phone": "+70052790863"}
0005433159338	8CE396	4218 356425	RAISA KUZNECOVA	{"email": "kuznecovaraisa.1969@postgrespro.ru", "phone": "+70518638664"}
0005433159339	6A162E	1395 098474	SOFIYA KUZMINA	{"email": "kuzmina.s31121983@postgrespro.ru", "phone": "+70745557307"}
0005433159340	DCE0E0	8249 201774	OLGA DMITRIEVA	{"phone": "+70222503320"}
0005433159341	2505B5	3372 732932	IRINA ISAEVA	{"email": "i-isaeva071971@postgrespro.ru", "phone": "+70027363529"}
0005433159342	5D6028	0395 270071	PETR KISELEV	{"phone": "+70805192813"}
0005433159343	5D6028	1701 986982	VITALIY IVANOV	{"phone": "+70889354604"}
0005433159344	699384	6135 405094	NATALYA MOROZOVA	{"email": "morozova_n.011955@postgrespro.ru", "phone": "+70826762101"}
0005433159346	699384	3108 387732	SERGEY ZAYCEV	{"email": "sergey.zaycev-111978@postgrespro.ru", "phone": "+70641568857"}
0005433159347	366EAD	5077 865305	OKSANA DANILOVA	{"email": "danilova-o1977@postgrespro.ru", "phone": "+70950058983"}
0005433159348	366EAD	0686 940142	OLEG KUZMIN	{"email": "kuzmin.oleg.23111968@postgrespro.ru", "phone": "+70773318083"}
0005433159349	53B001	8525 923080	KRISTINA ZAKHAROVA	{"email": "zakharova.k-16071975@postgrespro.ru", "phone": "+70410963951"}
0005433159350	EEEB17	4112 664396	VLADISLAV ALEKSANDROV	{"email": "aleksandrov_v_051977@postgrespro.ru", "phone": "+70599405336"}
0005433159351	32AF91	8910 015013	SVETLANA KOZLOVA	{"email": "kozlova.s.1973@postgrespro.ru", "phone": "+70161363616"}
0005433159352	B9EB40	0852 133829	NATALIYA GORBUNOVA	{"email": "gorbunova.nataliya-05101962@postgrespro.ru", "phone": "+70255708081"}
0005433159353	F8D7C5	8019 079432	GENNADIY KOZLOV	{"email": "kozlov_g15101973@postgrespro.ru", "phone": "+70011026538"}
0005433159354	AB9417	4686 037534	VLADISLAV POPOV	{"email": "popovvladislav-1975@postgrespro.ru", "phone": "+70954269563"}
0005433159355	AB9417	1842 160647	ARTEM ALEKSANDROV	{"email": "aleksandrov.a1969@postgrespro.ru", "phone": "+70352624345"}
0005433159356	133DD4	3184 250478	VALERIY PETROV	{"email": "valeriy-petrov29081969@postgrespro.ru", "phone": "+70783229591"}
0005433159357	A660EE	9391 527900	ANNA NIKITINA	{"email": "nikitina-a.061985@postgrespro.ru", "phone": "+70348767564"}
0005433159358	8CF45D	5873 307754	KIRILL FILIPPOV	{"phone": "+70944516500"}
0005433159359	C5B7E9	7713 517199	ELENA SCHERBAKOVA	{"email": "e_scherbakova_1974@postgrespro.ru", "phone": "+70841805033"}
0005433159360	67CF1D	4365 029358	OKSANA MAKAROVA	{"email": "makarova-oksana-1975@postgrespro.ru", "phone": "+70404854628"}
0005433159361	67CF1D	9858 615988	SERGEY PAVLOV	{"phone": "+70846480080"}
0005433159362	36D744	1603 510292	ANDREY KUZNECOV	{"email": "andreykuznecov_1972@postgrespro.ru", "phone": "+70352818148"}
0005433159363	DC97A2	4994 796990	ALEKSEY FEDOROV	{"email": "fedorov-aleksey_071975@postgrespro.ru", "phone": "+70201012086"}
0005433159364	5C0016	6447 631726	OLEG MIRONOV	{"email": "mironov.oleg.1968@postgrespro.ru", "phone": "+70477022450"}
0005433159365	570A08	6121 515478	TATYANA TARASOVA	{"email": "tarasova.tatyana101972@postgrespro.ru", "phone": "+70011996275"}
0005433159366	570A08	8451 919384	IVAN SHEVCHENKO	{"phone": "+70278888921"}
0005433159367	BE77DC	0818 749732	EVGENIYA ISAEVA	{"email": "isaeva-evgeniya-101961@postgrespro.ru", "phone": "+70342581781"}
0005433159368	15B04A	6029 124259	TAISIYA SEMENOVA	{"phone": "+70219823231"}
0005433159369	15B04A	4079 003504	MARIYA GAVRILOVA	{"phone": "+70806486978"}
0005433159370	CD6C8A	8651 796290	VALENTINA ANISIMOVA	{"phone": "+70343536021"}
0005433159371	2B5C0B	3135 690882	DARYA ABRAMOVA	{"email": "abramova.darya-14021976@postgrespro.ru", "phone": "+70084604729"}
0005433159372	2B5C0B	1644 603166	ALEKSEY PAVLOV	{"email": "aleksey_pavlov.041967@postgrespro.ru", "phone": "+70513887713"}
0005433159373	C975C7	9837 633358	OLEG ZAYCEV	{"phone": "+70314341990"}
0005433159374	EF9FF4	1600 265968	EVGENIY TIKHONOV	{"email": "evgeniy-tikhonov.24021972@postgrespro.ru", "phone": "+70588540484"}
0005433159375	EF9FF4	8073 060246	MARIYA BELOVA	{"phone": "+70076671246"}
0005433159376	C9CB09	4348 708826	LYUDMILA MAKAROVA	{"email": "makaroval16071978@postgrespro.ru", "phone": "+70361344638"}
0005433165670	8D0F2B	2935 941389	OLGA BOGDANOVA	{"email": "obogdanova.06061968@postgrespro.ru", "phone": "+70165022184"}
0005433165671	8D0F2B	6944 148718	ANATOLIY TIKHONOV	{"email": "tikhonov.anatoliy02071984@postgrespro.ru", "phone": "+70565002172"}
0005433165672	8D0F2B	8684 342548	NATALYA POPOVA	{"phone": "+70673993574"}
0005433165673	ABE7BA	9482 588900	DMITRIY MAKAROV	{"email": "makarov-d-1976@postgrespro.ru", "phone": "+70597873118"}
0005433165674	AC98A2	9506 407211	DARYA ISAEVA	{"email": "isaeva_d-1970@postgrespro.ru", "phone": "+70001813643"}
0005433165675	46831F	9342 922140	ANTONINA SAVELEVA	{"email": "a-saveleva.06071966@postgrespro.ru", "phone": "+70111666955"}
0005433165676	F76312	6256 496545	VIKTORIYA MAKSIMOVA	{"email": "v_maksimova1978@postgrespro.ru", "phone": "+70542115405"}
0005433165677	6BEE74	4246 663465	DARYA ALEKSANDROVA	{"phone": "+70723650103"}
0005433165678	6BEE74	2239 661026	GENNADIY TIMOFEEV	{"phone": "+70392337673"}
0005433165679	3A33A6	4932 501059	VYACHESLAV MOROZOV	{"phone": "+70269695162"}
0005433165680	3A33A6	0384 370570	VIKTOR SMIRNOV	{"email": "smirnov.viktor.1976@postgrespro.ru", "phone": "+70942418701"}
0005433165681	A30A68	5609 431234	NADEZHDA KOROLEVA	{"email": "koroleva.n.101967@postgrespro.ru", "phone": "+70781137980"}
0005433165682	A30A68	6408 335447	ALEKSEY DMITRIEV	{"email": "dmitrieva.13081968@postgrespro.ru", "phone": "+70296593966"}
0005433165683	A30A68	5154 570656	VALERIY OSIPOV	{"email": "valeriy_osipov-1972@postgrespro.ru", "phone": "+70001588638"}
0005433165684	C298E7	6990 518956	OLESYA NIKIFOROVA	{"phone": "+70874095588"}
0005433165685	C298E7	7559 024599	IRINA SEMENOVA	{"email": "irina.semenova081982@postgrespro.ru", "phone": "+70366816684"}
0005433165686	594825	3898 107612	GENNADIY SIDOROV	{"email": "gennadiysidorov_1977@postgrespro.ru", "phone": "+70692625412"}
0005433165687	594825	2975 360354	NIKOLAY ALEKSANDROV	{"email": "aleksandrovnikolay12091969@postgrespro.ru", "phone": "+70686865065"}
0005433165688	3FD2B1	5922 300376	TAMARA DAVYDOVA	{"email": "t-davydova-091985@postgrespro.ru", "phone": "+70336658672"}
0005433165689	B922B9	6698 731452	OLGA IVANOVA	{"email": "ivanova-o1973@postgrespro.ru", "phone": "+70435394798"}
0005433165690	B922B9	4252 973697	VYACHESLAV ZHURAVLEV	{"phone": "+70399008796"}
0005433165691	577C38	6969 363843	VALENTINA ZAKHAROVA	{"phone": "+70381011016"}
0005433165692	909FAA	6879 140105	ALINA IVANOVA	{"email": "a-ivanova_091974@postgrespro.ru", "phone": "+70109926549"}
0005433165693	97466D	7732 568685	IRAIDA SCHERBAKOVA	{"email": "scherbakova-iraida1963@postgrespro.ru", "phone": "+70514546939"}
0005433165694	77CA97	6802 029662	ZOYA ROMANOVA	{"phone": "+70342075631"}
0005433165695	11B6AE	3301 758059	OLGA RYABOVA	{"phone": "+70584844409"}
0005433165696	11B6AE	7952 483319	MAKSIM VASILEV	{"phone": "+70179724422"}
0005433165697	FD6AD9	6341 206461	MIKHAIL YAKOVLEV	{"phone": "+70527967890"}
0005433165698	974085	9653 913480	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr.121967@postgrespro.ru", "phone": "+70634676365"}
0005433165699	E7C251	9445 914985	IVAN ANTONOV	{"email": "i_antonov071971@postgrespro.ru", "phone": "+70118568084"}
0005433165700	729630	6127 146333	NIKOLAY SHEVCHENKO	{"email": "nshevchenko-23061971@postgrespro.ru", "phone": "+70182803670"}
0005433165701	729630	2046 569751	VALENTINA VLASOVA	{"email": "vlasova-v-09051968@postgrespro.ru", "phone": "+70077009167"}
0005433165702	1ED24B	6083 278737	ALEKSEY NOVIKOV	{"phone": "+70819272562"}
0005433165703	2C083B	1314 849997	INNA KONOVALOVA	{"phone": "+70563053610"}
0005433165704	6DCA00	6893 805159	ALEKSEY KUDRYASHOV	{"email": "kudryashova-1976@postgrespro.ru", "phone": "+70992764462"}
0005433165705	E66522	4758 598852	ANNA SAVELEVA	{"email": "a_saveleva.1964@postgrespro.ru", "phone": "+70748456247"}
0005433165706	8C18F1	3445 358953	TATYANA FOMINA	{"phone": "+70512435062"}
0005433165707	077126	9140 142003	ALEVTINA KUZNECOVA	{"email": "a-kuznecova.12021971@postgrespro.ru", "phone": "+70955237831"}
0005433165708	077126	3041 140711	MARINA NIKIFOROVA	{"email": "nikiforova.m06081970@postgrespro.ru", "phone": "+70795033598"}
0005433165709	2BABAC	4788 888954	LILIYA KUZNECOVA	{"phone": "+70970747888"}
0005433165710	62D934	9244 740534	NINA MAKAROVA	{"phone": "+70595920673"}
0005433165711	81247C	8925 355016	ALEKSANDR POPOV	{"phone": "+70336394779"}
0005433165712	14EBBB	2490 019614	ALEKSEY KAZAKOV	{"phone": "+70802147279"}
0005433165713	0C678D	4651 717586	TAMARA FROLOVA	{"email": "tamara.frolova_1964@postgrespro.ru", "phone": "+70802028743"}
0005433165714	856F81	7413 119122	VERA EFREMOVA	{"email": "efremovav.29011969@postgrespro.ru", "phone": "+70750178091"}
0005433165715	0CFB37	1602 580065	ARTEM KOROLEV	{"email": "a-korolev-1973@postgrespro.ru", "phone": "+70444084495"}
0005433165716	0CFB37	1126 434826	ANATOLIY IVANOV	{"phone": "+70611384332"}
0005433165717	4CDF27	9347 458405	ARTEM VOROBEV	{"email": "artem-vorobev13041972@postgrespro.ru", "phone": "+70732885368"}
0005433165718	9B9AEC	1892 008904	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana22081975@postgrespro.ru", "phone": "+70413361865"}
0005433165719	DC2090	3102 510303	NATALYA KONDRATEVA	{"email": "natalya_kondrateva24081973@postgrespro.ru", "phone": "+70575065735"}
0005433165720	B9A74B	8768 579326	ALEKSANDR MAKAROV	{"phone": "+70840928006"}
0005433165721	ED6872	1916 368923	ANDREY ANTONOV	{"email": "antonov_a_30081969@postgrespro.ru", "phone": "+70348908858"}
0005433165722	2F62CC	3354 386642	NADEZHDA MAKAROVA	{"phone": "+70873825139"}
0005433165723	40982C	2630 225432	DIANA NIKOLAEVA	{"email": "nikolaevad-1966@postgrespro.ru", "phone": "+70655802049"}
0005433165724	7DBDFC	7639 456110	YURIY GRIGOREV	{"phone": "+70140513137"}
0005433165725	7DBDFC	9522 532487	ALEKSANDR VOLKOV	{"phone": "+70151827301"}
0005433165726	5771CC	9850 010249	SHAMIL ANTONOV	{"email": "antonovs-1972@postgrespro.ru", "phone": "+70987076098"}
0005433165727	C72CA2	4809 381847	POLINA NAUMOVA	{"email": "naumova.polina.01121975@postgrespro.ru", "phone": "+70517911957"}
0005433165728	0F77EF	6518 652252	ELVIRA KUZNECOVA	{"email": "kuznecovae1985@postgrespro.ru", "phone": "+70660406974"}
0005433165729	581E8F	4599 473656	ALEKSANDR ALEKSANDROV	{"phone": "+70704470708"}
0005433165730	F33790	9854 743300	ALEKSEY KULIKOV	{"email": "aleksey-kulikov051962@postgrespro.ru", "phone": "+70706614347"}
0005433165731	0A9BC1	1269 527282	ALEKSEY KOROLEV	{"email": "alekseykorolev.13021960@postgrespro.ru", "phone": "+70446026004"}
0005433165732	A23C83	4004 349619	OLGA MOROZOVA	{"email": "olga.morozova-1965@postgrespro.ru", "phone": "+70365520803"}
0005433165733	3A861A	4777 834384	IGOR MAKAROV	{"phone": "+70707751895"}
0005433165734	A8B6A4	6517 318140	LYUDMILA FEDOROVA	{"email": "fedorova.l-1982@postgrespro.ru", "phone": "+70277691726"}
0005433165735	DE95D5	9479 769793	LYUDMILA ANDREEVA	{"phone": "+70229962614"}
0005433165736	E8A666	7200 689547	VERA MATVEEVA	{"email": "vera-matveeva.061980@postgrespro.ru", "phone": "+70390844463"}
0005433165737	3F8EBE	6888 013355	NIKITA FOMIN	{"phone": "+70996719828"}
0005433165738	3F8EBE	4835 643628	ANASTASIYA EFREMOVA	{"phone": "+70542233741"}
0005433165739	4BBCC3	6948 672574	VIKTOR ANDREEV	{"email": "viktorandreev_24081977@postgrespro.ru", "phone": "+70258651672"}
0005433165740	30DFBA	9845 187246	SERGEY ROMANOV	{"email": "s-romanov-1974@postgrespro.ru", "phone": "+70180372798"}
0005433165741	30DFBA	2697 713245	SULTAN MIKHAYLOV	{"email": "s-mikhaylov_011974@postgrespro.ru", "phone": "+70846985442"}
0005433165742	079AB3	8539 910647	ALINA STEPANOVA	{"phone": "+70321171215"}
0005433165743	1D8E5D	4121 995552	TATYANA TIKHONOVA	{"email": "tikhonova-t.1960@postgrespro.ru", "phone": "+70399718307"}
0005433165744	1D8E5D	6008 087959	DMITRIY MELNIKOV	{"email": "dmitriy-melnikov-1965@postgrespro.ru", "phone": "+70429001454"}
0005433165745	6800CF	4944 247263	SVETLANA ANTONOVA	{"email": "svetlana-antonova-07111966@postgrespro.ru", "phone": "+70420962335"}
0005433165746	6800CF	6464 272147	LIDIYA SMIRNOVA	{"email": "lidiya.smirnova.07041972@postgrespro.ru", "phone": "+70677418811"}
0005433165747	486F99	0677 126921	SVETLANA IVANOVA	{"email": "ivanovasvetlana-1966@postgrespro.ru", "phone": "+70631247302"}
0005433165748	F887FC	7130 417766	GALINA IVANOVA	{"phone": "+70773076856"}
0005433165749	F887FC	5906 736795	IGOR KRASNOV	{"phone": "+70605529501"}
0005433165750	B271BE	3828 895937	GALINA ANTONOVA	{"phone": "+70749046587"}
0005433165751	280F57	2734 504973	VYACHESLAV IVANOV	{"phone": "+70790680698"}
0005433165752	FE9BD9	9154 671256	IVAN MIRONOV	{"phone": "+70080264053"}
0005433165753	FE9BD9	7681 011537	ANNA PAVLOVA	{"email": "pavlova_anna_081959@postgrespro.ru", "phone": "+70622825869"}
0005433165754	722718	0236 466280	ALINA SOKOLOVA	{"email": "sokolovaa.041964@postgrespro.ru", "phone": "+70109113370"}
0005433165755	E78913	4665 869328	VALERIY ZAYCEV	{"email": "zaycevvaleriy.1954@postgrespro.ru", "phone": "+70585441340"}
0005433165756	E78913	9469 784201	KONSTANTIN POPOV	{"phone": "+70401347790"}
0005433165757	33F797	7785 982958	ALEKSEY ANTONOV	{"email": "antonov_aleksey.21031977@postgrespro.ru", "phone": "+70452804657"}
0005433165758	E516A3	0464 220099	TAMARA BOGDANOVA	{"email": "bogdanova-t_18111972@postgrespro.ru", "phone": "+70285142536"}
0005433165759	E15BFE	6369 928210	PAVEL KAZAKOV	{"phone": "+70147392114"}
0005433165760	08B9C5	5260 298126	OKSANA NOVIKOVA	{"email": "novikovao1978@postgrespro.ru", "phone": "+70844244924"}
0005433165761	35648C	2299 568195	IRINA ZAYCEVA	{"email": "zayceva_irina.1979@postgrespro.ru", "phone": "+70832603149"}
0005433165762	35648C	3906 048632	VLADISLAV IVANOV	{"email": "vladislav-ivanov_07111969@postgrespro.ru", "phone": "+70520244443"}
0005433165763	540005	1287 992183	ALINA VASILEVA	{"email": "vasilevaa1974@postgrespro.ru", "phone": "+70769629151"}
0005433165764	540005	1659 885822	VLADIMIR SHEVCHENKO	{"email": "vladimir-shevchenko_1956@postgrespro.ru", "phone": "+70493145689"}
0005433165765	540005	1942 498350	VLADIMIR GRIGOREV	{"phone": "+70365498289"}
0005433165766	92132E	0932 451718	TATYANA KOVALEVA	{"email": "kovalevatatyana-24071976@postgrespro.ru", "phone": "+70928693066"}
0005433165767	92132E	3823 620673	MIKHAIL GORBUNOV	{"email": "gorbunov-m011979@postgrespro.ru", "phone": "+70110549842"}
0005433165768	E67DC9	3767 883202	STEPAN SOROKIN	{"phone": "+70789778261"}
0005433165769	A17A08	4079 025536	VLADA YAKOVLEVA	{"phone": "+70203529680"}
0005433165770	A17A08	7560 093133	EDUARD SEMENOV	{"phone": "+70706863912"}
0005433165771	7A9F75	0604 911618	ELENA FADEEVA	{"email": "efadeeva.27091989@postgrespro.ru", "phone": "+70536951244"}
0005433165772	7A9F75	2461 977829	GALINA ANISIMOVA	{"email": "anisimova.g15031973@postgrespro.ru", "phone": "+70113134128"}
0005433165773	2B6ECF	0406 191159	SERGEY ZHURAVLEV	{"email": "s.zhuravlev-1971@postgrespro.ru", "phone": "+70619423612"}
0005433165774	2B3F8E	3679 424984	YURIY TARASOV	{"email": "y_tarasov_1946@postgrespro.ru", "phone": "+70037216176"}
0005433165775	2B3F8E	2357 874102	NATALYA LOGINOVA	{"phone": "+70448283046"}
0005433165776	6F06E3	0227 433226	VITALIY NOVIKOV	{"email": "novikovv_22071980@postgrespro.ru", "phone": "+70049510447"}
0005433165777	E50F2A	4229 969916	TAMARA FEDOROVA	{"phone": "+70927828446"}
0005433165778	6B7C4F	5545 818862	ALBINA ABRAMOVA	{"email": "abramova_albina.1978@postgrespro.ru", "phone": "+70278424756"}
0005433165779	6B7C4F	7994 536707	TATYANA EGOROVA	{"email": "t-egorova11031977@postgrespro.ru", "phone": "+70046337675"}
0005433165780	3CD0B2	0213 521134	RAFIK MATVEEV	{"phone": "+70962949221"}
0005433165781	3CD0B2	6483 947106	NADEZHDA SOKOLOVA	{"email": "nadezhda.sokolova-041979@postgrespro.ru", "phone": "+70312552656"}
0005433165782	459CC5	6562 204219	VIKTOR FROLOV	{"phone": "+70688073683"}
0005433165783	459CC5	1857 022883	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir-101959@postgrespro.ru", "phone": "+70411342377"}
0005433165784	7EFB75	7885 298653	SERGEY FILIPPOV	{"email": "filippov.sergey_011980@postgrespro.ru", "phone": "+70583125992"}
0005433165785	7EFB75	5656 355960	NADEZHDA KRASNOVA	{"email": "krasnova_nadezhda-1981@postgrespro.ru", "phone": "+70178478795"}
0005433165786	CB7183	7821 628092	GALINA DAVYDOVA	{"phone": "+70803989992"}
0005433165787	CB7183	2441 976346	ALEKSANDR PAVLOV	{"email": "pavlov_a_26041972@postgrespro.ru", "phone": "+70543667500"}
0005433165788	1575A5	8042 120572	ALEKSANDR POPOV	{"email": "popov_aleksandr.1976@postgrespro.ru", "phone": "+70632607283"}
0005433165789	1575A5	1502 870446	ALEKSANDR KOZLOV	{"email": "akozlov_1972@postgrespro.ru", "phone": "+70625397410"}
0005433165790	1575A5	5133 137152	MARIYA SCHERBAKOVA	{"phone": "+70332066294"}
0005433165791	F315ED	3283 614752	IRINA MIRONOVA	{"phone": "+70807473827"}
0005433165792	70EF5B	0739 856123	ALEKSANDRA POTAPOVA	{"phone": "+70799491498"}
0005433165793	C461B9	8993 579798	KARINA ANDREEVA	{"email": "k_andreeva-021974@postgrespro.ru", "phone": "+70255650314"}
0005433165794	382E97	5209 600438	ALLA ALEKSANDROVA	{"email": "aleksandrova_a-1963@postgrespro.ru", "phone": "+70483758108"}
0005433165795	382E97	4151 764494	LYUDMILA PAVLOVA	{"phone": "+70867979866"}
0005433165796	B944BD	0547 089464	TATYANA PETROVA	{"email": "t.petrova14071966@postgrespro.ru", "phone": "+70843206326"}
0005433165797	259149	1024 629864	ALEKSANDR KRASNOV	{"phone": "+70524935400"}
0005433165798	906A15	7013 255749	ANTONINA FROLOVA	{"phone": "+70344231069"}
0005433165799	D14652	1909 763636	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr.1966@postgrespro.ru", "phone": "+70451113930"}
0005433165800	D0A04B	2241 192230	YURIY PETROV	{"email": "ypetrov-01031977@postgrespro.ru", "phone": "+70762227914"}
0005433165801	B11DE4	6370 819614	DMITRIY MAKAROV	{"email": "makarovdmitriy.051963@postgrespro.ru", "phone": "+70858001903"}
0005433165802	B11DE4	8970 635054	ELENA BORISOVA	{"email": "borisovaelena051980@postgrespro.ru", "phone": "+70711491635"}
0005433165803	034602	5831 358306	ALEKSEY SEMENOV	{"email": "aleksey-semenov-081960@postgrespro.ru", "phone": "+70373443895"}
0005433165804	C18597	2950 337077	NINA KUZNECOVA	{"phone": "+70750792703"}
0005433165805	135CC5	2466 384425	LYUBOV VASILEVA	{"email": "l-vasileva011982@postgrespro.ru", "phone": "+70041320910"}
0005433165806	135CC5	4135 810352	LIDIYA KISELEVA	{"email": "lkiseleva_1968@postgrespro.ru", "phone": "+70686135931"}
0005433165807	D7A9D3	6102 324362	TATYANA OSIPOVA	{"email": "osipova_t.01061965@postgrespro.ru", "phone": "+70070144836"}
0005433165808	D7A9D3	7977 370090	YURIY FOMIN	{"phone": "+70951590513"}
0005433165809	D7A9D3	6208 962127	NADEZHDA MIKHAYLOVA	{"email": "mikhaylovanadezhda1980@postgrespro.ru", "phone": "+70486432154"}
0005433165810	2C74E3	5264 888679	EVGENIY SCHERBAKOV	{"email": "e_scherbakov.061968@postgrespro.ru", "phone": "+70701179538"}
0005433165811	F860E9	2729 819708	EVGENIY FROLOV	{"phone": "+70190275197"}
0005433165812	E70364	5447 412747	NINA KOMAROVA	{"email": "nina.komarova-1981@postgrespro.ru", "phone": "+70352929524"}
0005433165813	750181	3728 691603	ALEKSANDR RODIONOV	{"phone": "+70879221274"}
0005433165814	750181	9917 226752	ANASTASIYA FEDOROVA	{"phone": "+70934195849"}
0005433165815	CDBEB4	6830 546041	OLEG ZHUKOV	{"email": "olegzhukov22081967@postgrespro.ru", "phone": "+70369683799"}
0005433165816	B8D057	1866 099406	ILYA SOLOVEV	{"email": "solovev.ilya-1969@postgrespro.ru", "phone": "+70625576748"}
0005433165817	B8D057	8848 778825	ANDREY FILIPPOV	{"email": "filippov-a_1970@postgrespro.ru", "phone": "+70532777172"}
0005433165818	B8D057	9554 045606	MATVEY VLASOV	{"phone": "+70010271736"}
0005433165819	B8D057	3844 071133	ALEKSANDR EGOROV	{"email": "a_egorov-08091967@postgrespro.ru", "phone": "+70735509986"}
0005433165820	5805A7	1537 511957	IRINA MOISEEVA	{"email": "irina_moiseeva_1965@postgrespro.ru", "phone": "+70591786625"}
0005433165821	D99DA5	5513 049786	MIKHAIL KUDRYASHOV	{"email": "kudryashov-mikhail1963@postgrespro.ru", "phone": "+70661698313"}
0005433165822	841CF0	7029 117841	ARTEM ZAYCEV	{"phone": "+70968454217"}
0005433165823	841CF0	6584 327228	GENNADIY STEPANOV	{"email": "stepanov.gennadiy_041963@postgrespro.ru", "phone": "+70458944643"}
0005433165824	B221B8	1886 966358	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov-08061967@postgrespro.ru", "phone": "+70208746589"}
0005433165825	FCE691	4702 757842	VIKTORIYA CHERNOVA	{"phone": "+70096573528"}
0005433165826	B6C7D0	9865 806996	FARIT MOISEEV	{"phone": "+70467737692"}
0005433165827	4AE510	2386 120373	SOFIYA DAVYDOVA	{"phone": "+70135314376"}
0005433165828	4AE510	8907 671018	PAVEL BONDARENKO	{"email": "bondarenko_p-111972@postgrespro.ru", "phone": "+70687517726"}
0005433165829	E98BDF	0144 214662	YULIYA FEDOROVA	{"phone": "+70738729705"}
0005433165830	1A72E5	5683 436928	VALENTINA OSIPOVA	{"phone": "+70793892446"}
0005433165831	1A72E5	3246 536137	MARIYA KOZLOVA	{"email": "mariya.kozlova_10061968@postgrespro.ru", "phone": "+70984502509"}
0005433165832	82A2B8	6039 459479	GALINA SCHERBAKOVA	{"email": "g-scherbakova07051966@postgrespro.ru", "phone": "+70991213826"}
0005433165833	0947BC	8564 629039	DMITRIY KULIKOV	{"email": "kulikov.d.1979@postgrespro.ru", "phone": "+70359341178"}
0005433165834	0947BC	3553 822257	VALERIY PETROV	{"phone": "+70969723647"}
0005433165835	F7DDC4	3212 923242	IGOR IVANOV	{"phone": "+70011268223"}
0005433165836	F7DDC4	5147 519718	VIKTOR POPOV	{"email": "popovviktor-071973@postgrespro.ru", "phone": "+70441538011"}
0005433165837	F7A703	6548 936255	ANASTASIYA FROLOVA	{"email": "a.frolova.16081970@postgrespro.ru", "phone": "+70197395601"}
0005433165838	F7A703	6683 207636	ZAKHAR BARANOV	{"phone": "+70209274133"}
0005433165839	E3298E	9182 707229	ANDREY GERASIMOV	{"email": "andreygerasimov_1966@postgrespro.ru", "phone": "+70630194578"}
0005433165840	E3298E	4317 070660	NADEZHDA EFIMOVA	{"phone": "+70504709090"}
0005433165841	E3298E	6659 019702	EVGENIYA DAVYDOVA	{"email": "evgeniya_davydova_101979@postgrespro.ru", "phone": "+70144037340"}
0005433165842	B5C166	0622 089225	TATYANA MELNIKOVA	{"email": "melnikova.tatyana.1971@postgrespro.ru", "phone": "+70610587174"}
0005433165843	B5C166	4286 839468	MARIYA SIDOROVA	{"phone": "+70185909556"}
0005433165844	E6BC72	5803 845159	IRINA DMITRIEVA	{"phone": "+70664016772"}
0005433165845	B2457D	1420 943281	VIKTORIYA SIDOROVA	{"phone": "+70933373865"}
0005433165846	B2457D	3374 622849	IGOR NIKOLAEV	{"email": "nikolaev-i.071970@postgrespro.ru", "phone": "+70195107200"}
0005433165847	00FB45	9512 725398	DMITRIY SOKOLOV	{"email": "sokolov_d.1976@postgrespro.ru", "phone": "+70287418924"}
0005433165848	00FB45	6408 827906	NIKOLAY ZHURAVLEV	{"email": "zhuravlev_n1971@postgrespro.ru", "phone": "+70498606654"}
0005433165849	86DF39	9027 822762	VALENTINA GRISHINA	{"phone": "+70870070896"}
0005433165850	EB23C8	7778 735333	ALINA IVANOVA	{"email": "alina_ivanova1964@postgrespro.ru", "phone": "+70991622358"}
0005433165851	3C8CDB	0442 803729	LYUDMILA GAVRILOVA	{"email": "gavrilova.l_021981@postgrespro.ru", "phone": "+70649419282"}
0005433165852	2F4D9C	6214 126487	OLGA KUZMINA	{"phone": "+70906793594"}
0005433165853	CB8836	5553 359540	ALEKSEY IVANOV	{"phone": "+70037919368"}
0005433165854	61464E	2388 500662	LIDIYA FILIPPOVA	{"phone": "+70949469537"}
0005433165855	E2D574	7191 180445	ANDREY SOLOVEV	{"phone": "+70554788496"}
0005433165856	E2D574	8529 338093	DMITRIY SCHERBAKOV	{"email": "d-scherbakov.1979@postgrespro.ru", "phone": "+70786682970"}
0005433165857	5B69A5	1165 200871	FANIL ALEKSEEV	{"email": "alekseev.fanil021961@postgrespro.ru", "phone": "+70168484302"}
0005433165858	5B69A5	1071 333470	ALEKSANDR SEMENOV	{"phone": "+70308526249"}
0005433165859	3B93CA	1845 315481	KIRILL FOMIN	{"phone": "+70771097061"}
0005433165860	45C1CC	9668 214351	YULIYA ERMAKOVA	{"phone": "+70223996287"}
0005433165861	E28B48	3031 869962	GALINA FILATOVA	{"phone": "+70097638888"}
0005433165862	CDD9AF	6448 007623	ANNA NOVIKOVA	{"phone": "+70619610308"}
0005433165863	8807B5	1611 462880	ELENA MALYSHEVA	{"email": "malyshevaelena.1975@postgrespro.ru", "phone": "+70787418378"}
0005433165864	8807B5	6271 669668	ALEKSANDR ZHUKOV	{"phone": "+70051092467"}
0005433165865	E8299A	2746 584281	ANDREY FOMIN	{"phone": "+70145335550"}
0005433165866	E8299A	7379 226850	EKATERINA EGOROVA	{"email": "e_egorova-1962@postgrespro.ru", "phone": "+70897004792"}
0005433165867	6584C4	5339 825346	VALERIYA KUZNECOVA	{"email": "kuznecova_v111965@postgrespro.ru", "phone": "+70638503322"}
0005433165868	9FF161	2525 166281	NIKOLAY SIDOROV	{"phone": "+70846682488"}
0005433165869	9FF161	9592 369439	EKATERINA ZAKHAROVA	{"email": "zakharova-e.111970@postgrespro.ru", "phone": "+70418313491"}
0005433165870	CE8207	1119 870397	OLGA MAKSIMOVA	{"email": "maksimova.olga.1979@postgrespro.ru", "phone": "+70616859333"}
0005433165871	CE8207	1452 827677	ZOYA SOLOVEVA	{"phone": "+70539120338"}
0005433165872	ED04F1	8538 507142	GALINA ARKHIPOVA	{"phone": "+70408275108"}
0005433165873	6A3B6B	7199 505059	ANASTASIYA IVANOVA	{"phone": "+70208246768"}
0005433165874	67C25D	3767 374831	ANATOLIY NOVIKOV	{"email": "novikova.1982@postgrespro.ru", "phone": "+70665437783"}
0005433165875	67C25D	2222 496001	VALENTINA NIKOLAEVA	{"phone": "+70501150667"}
0005433165876	DA34D1	1842 222760	OLEG ISAEV	{"email": "isaev-oleg.061975@postgrespro.ru", "phone": "+70474878040"}
0005433165877	5CE7E3	8854 965876	MAKSIM MIRONOV	{"phone": "+70594595170"}
0005433165878	ED1E7E	1783 480538	ELENA KUZNECOVA	{"email": "e.kuznecova_15011963@postgrespro.ru", "phone": "+70659672905"}
0005433165879	0C7B67	0829 043180	ZOYA KONOVALOVA	{"email": "zoya_konovalova.1985@postgrespro.ru", "phone": "+70321927363"}
0005433165880	737022	9244 206662	MARIYA KUZNECOVA	{"email": "kuznecova.mariya081976@postgrespro.ru", "phone": "+70022319365"}
0005433165881	737022	9770 804995	ELENA KOZLOVA	{"phone": "+70722223480"}
0005433165882	4C9B96	6337 564204	EVGENIY MIKHAYLOV	{"email": "mikhaylove-021960@postgrespro.ru", "phone": "+70497807891"}
0005433165883	4C9B96	4290 784394	TATYANA SMIRNOVA	{"email": "smirnova-tatyana.16051976@postgrespro.ru", "phone": "+70438053518"}
0005433165884	F8615C	0463 800407	STANISLAV ABRAMOV	{"phone": "+70165916682"}
0005433165885	9E9CAE	6448 899911	ALEKSANDR POPOV	{"phone": "+70542900412"}
0005433165886	9622A3	6270 695697	OLGA POLYAKOVA	{"phone": "+70760346914"}
0005433165887	9622A3	6604 866509	ANDREY KONOVALOV	{"email": "a-konovalov1969@postgrespro.ru", "phone": "+70477308039"}
0005433165888	C822C9	0230 666229	VASILIY KONOVALOV	{"email": "vasiliy.konovalov.031974@postgrespro.ru", "phone": "+70633835875"}
0005433165889	640E56	6191 246938	ALEKSANDR IVANOV	{"email": "a-ivanov_1957@postgrespro.ru", "phone": "+70473768901"}
0005433165890	640E56	7529 664386	TATYANA KALININA	{"email": "t_kalinina_071975@postgrespro.ru", "phone": "+70779873575"}
0005433165891	B81B75	3951 448627	KIRILL MARTYNOV	{"phone": "+70826069081"}
0005433165892	169DDB	7742 100773	VADIM SEMENOV	{"email": "semenov_v_19101975@postgrespro.ru", "phone": "+70997220371"}
0005433165893	169DDB	9971 453452	FARIDA VASILEVA	{"phone": "+70595422155"}
0005433165894	7FE732	3382 502810	KIRILL KISELEV	{"phone": "+70736549054"}
0005433165895	05AB27	6468 161594	VLADIMIR BARANOV	{"phone": "+70624450712"}
0005433165896	194820	2482 301571	NADEZHDA KOZLOVA	{"phone": "+70624435930"}
0005433165897	1452AC	3748 417065	VASILIY VOLKOV	{"email": "v.volkov25101971@postgrespro.ru", "phone": "+70070024995"}
0005433165898	1452AC	7605 833050	VIKTOR NOVIKOV	{"email": "vnovikov-14021981@postgrespro.ru", "phone": "+70740845293"}
0005433165899	E06988	6002 439414	VERA SOKOLOVA	{"email": "sokolova-vera.081972@postgrespro.ru", "phone": "+70063819589"}
0005433165900	1A2B86	2354 860566	TATYANA VOLKOVA	{"phone": "+70885079884"}
0005433165901	3440B2	8449 778231	ARTEM OSIPOV	{"phone": "+70978446240"}
0005433165902	E3ACE9	7612 864428	EVGENIY SERGEEV	{"phone": "+70591782499"}
0005433165903	D3D7FA	9660 142534	EKATERINA ZOTOVA	{"email": "zotova.e-1977@postgrespro.ru", "phone": "+70837159189"}
0005433165904	9557A5	6694 666458	VYACHESLAV FEDOROV	{"phone": "+70826116923"}
0005433165905	9557A5	3442 027807	TATYANA FILATOVA	{"email": "filatova.tatyana_10011963@postgrespro.ru", "phone": "+70707023383"}
0005433165906	ADF292	3699 702014	NIKOLAY ZAYCEV	{"email": "zaycev.n.1971@postgrespro.ru", "phone": "+70821227089"}
0005433165907	ADF292	5912 926277	ANNA MAKAROVA	{"phone": "+70582340149"}
0005433165908	ADF292	4677 912018	IRINA KOZLOVA	{"phone": "+70122837757"}
0005433165909	9B1310	0100 165054	EKATERINA KOROLEVA	{"email": "e.koroleva-1973@postgrespro.ru", "phone": "+70965348303"}
0005433165910	9B1310	8279 298327	VALENTINA TIMOFEEVA	{"phone": "+70508746239"}
0005433165911	46296D	6270 493964	NIKOLAY ZHURAVLEV	{"email": "n.zhuravlev.121971@postgrespro.ru", "phone": "+70130821030"}
0005433165912	46296D	6789 270463	ANDREY ISAEV	{"phone": "+70397311848"}
0005433165913	2AEE97	8192 860727	VLADIMIR MATVEEV	{"email": "v_matveev_1973@postgrespro.ru", "phone": "+70735104482"}
0005433165914	2AEE97	0466 331709	RUSTAM KUDRYASHOV	{"email": "kudryashovr.101975@postgrespro.ru", "phone": "+70692465398"}
0005433165915	8ED300	1291 259134	NATALYA NOVIKOVA	{"phone": "+70435144449"}
0005433165916	8ED300	2793 053111	ALEKSANDR ZHUKOV	{"email": "zhukov.aleksandr_07031977@postgrespro.ru", "phone": "+70515668761"}
0005433165917	98B6E6	3234 065171	ARTEM NAZAROV	{"phone": "+70803542630"}
0005433165918	C9323A	7694 036933	RENAT VASILEV	{"phone": "+70928906647"}
0005433165919	D96D58	9313 274208	TATYANA SOKOLOVA	{"phone": "+70198198136"}
0005433165920	9BD112	9421 241153	ALEKSANDR PETROV	{"email": "aleksandrpetrov.1962@postgrespro.ru", "phone": "+70102529453"}
0005433165921	1190D5	4892 671550	SERGEY MATVEEV	{"phone": "+70212212782"}
0005433165922	337A68	0408 596190	NADEZHDA ANISIMOVA	{"email": "anisimova-n-1978@postgrespro.ru", "phone": "+70356850245"}
0005433165923	337A68	4976 110444	POLINA EFREMOVA	{"email": "p.efremova.071979@postgrespro.ru", "phone": "+70433685332"}
0005433165924	79268F	2283 487819	VERA DENISOVA	{"email": "denisova_vera.12111969@postgrespro.ru", "phone": "+70446507935"}
0005433165925	DD0ECC	0332 016799	VALERIY BORISOV	{"email": "valeriy.borisov.07121976@postgrespro.ru", "phone": "+70518108282"}
0005433165926	D90789	1085 096021	YULIYA FILIPPOVA	{"phone": "+70868243159"}
0005433165927	95C112	9772 474036	SOFYA FILIPPOVA	{"email": "s.filippova-021980@postgrespro.ru", "phone": "+70962408042"}
0005433165928	CABC03	5333 151477	ARTEM DAVYDOV	{"phone": "+70822766265"}
0005433165929	CABC03	5476 779472	NATALYA FILIPPOVA	{"email": "filippovan.081982@postgrespro.ru", "phone": "+70310784689"}
0005433165930	0E073B	9603 693703	MARINA KUDRYASHOVA	{"phone": "+70416981124"}
0005433165931	74330B	6164 777308	ALINA EGOROVA	{"phone": "+70322460924"}
0005433165932	679DC0	5145 500600	VALENTINA POTAPOVA	{"email": "potapovav-1979@postgrespro.ru", "phone": "+70102525316"}
0005433165933	53A72D	9674 053254	VALERIY FEDOROV	{"phone": "+70834858288"}
0005433165934	53A72D	4776 773942	IVAN MEDVEDEV	{"email": "ivan-medvedev1979@postgrespro.ru", "phone": "+70421048469"}
0005433165935	54B97F	8799 451509	KIRILL KUZNECOV	{"phone": "+70855496159"}
0005433165936	EF07E0	7109 889094	NINA ABRAMOVA	{"phone": "+70022605186"}
0005433165937	094A22	9676 710933	OLEG ORLOV	{"email": "oleg_orlov-101969@postgrespro.ru", "phone": "+70619322834"}
0005433165938	A468D7	8809 585174	LIDIYA SOKOLOVA	{"email": "sokolova_l.011967@postgrespro.ru", "phone": "+70178164078"}
0005433165939	A468D7	0645 877588	ALEKSANDR VLASOV	{"phone": "+70906065457"}
0005433165940	C66705	6639 838735	ANDREY SIDOROV	{"phone": "+70580221870"}
0005433165941	1E4DAA	2110 982838	POLINA SOKOLOVA	{"phone": "+70433602339"}
0005433165942	D02746	7935 275532	ANNA MARTYNOVA	{"phone": "+70214397497"}
0005433165943	5D40C8	9855 719818	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.051966@postgrespro.ru", "phone": "+70055815779"}
0005433165944	980DB4	0987 852842	OKSANA PETROVA	{"phone": "+70779570604"}
0005433165945	980DB4	7173 782990	FEDOR FILIPPOV	{"email": "filippov_f.29031965@postgrespro.ru", "phone": "+70241902968"}
0005433165946	B2D15B	3893 153874	DMITRIY MELNIKOV	{"email": "melnikovdmitriy-28061975@postgrespro.ru", "phone": "+70666564834"}
0005433165947	B2D15B	9450 901382	VASILIY NIKOLAEV	{"email": "v.nikolaev_1969@postgrespro.ru", "phone": "+70185164421"}
0005433165948	121A61	3628 099198	OKSANA BORISOVA	{"phone": "+70709054711"}
0005433165949	121A61	4551 612892	EGOR KOZLOV	{"email": "egor_kozlov_1976@postgrespro.ru", "phone": "+70764698988"}
0005433165950	1998A4	2667 768042	SVETLANA NESTEROVA	{"email": "nesterova_svetlana_041972@postgrespro.ru", "phone": "+70523934352"}
0005433165951	FE4B20	1948 201975	ANDREY VOLKOV	{"phone": "+70743518956"}
0005433165952	FE4B20	4509 034149	MIKHAIL NIKOLAEV	{"phone": "+70857404216"}
0005433165953	3E50A7	6101 092305	NINA ISAEVA	{"phone": "+70510128611"}
0005433165954	2CCE28	0082 509541	TATYANA SEMENOVA	{"phone": "+70541310062"}
0005433165955	8C366E	4716 469781	TATYANA FROLOVA	{"phone": "+70018385305"}
0005433165956	8C366E	8029 057864	NATALYA KOZLOVA	{"phone": "+70442934192"}
0005433165957	733707	3361 259808	MARIYA MOISEEVA	{"email": "moiseeva_m_25021983@postgrespro.ru", "phone": "+70251497106"}
0005433165958	85E196	4716 551454	KIRILL KOROLEV	{"email": "kirill.korolev-15031977@postgrespro.ru", "phone": "+70378743524"}
0005433165959	85E196	2313 867372	NATALYA EFIMOVA	{"phone": "+70530284142"}
0005433165960	20B6AE	6284 139959	SERGEY KUZNECOV	{"email": "kuznecov.sergey.041975@postgrespro.ru", "phone": "+70634829005"}
0005433165961	20B6AE	0606 451467	SOFYA ZAYCEVA	{"email": "sofyazayceva_1969@postgrespro.ru", "phone": "+70124209568"}
0005433165962	07BDF6	5683 690972	EKATERINA FADEEVA	{"phone": "+70061174089"}
0005433165963	5ADE22	2536 912878	NIKOLAY ANDREEV	{"email": "andreev.n-031970@postgrespro.ru", "phone": "+70848186436"}
0005433165964	B18AD1	7501 763917	LIDIYA ZHUKOVA	{"phone": "+70674443594"}
0005433165965	7C8C6C	1924 409151	LILIYA YAKOVLEVA	{"email": "l.yakovleva-041980@postgrespro.ru", "phone": "+70679000671"}
0005433165966	CC1E92	9804 794933	MIKHAIL BORISOV	{"email": "m-borisov_1978@postgrespro.ru", "phone": "+70528529287"}
0005433165967	CC1E92	2135 182023	KONSTANTIN PAVLOV	{"email": "pavlov_konstantin_1969@postgrespro.ru", "phone": "+70433370044"}
0005433165968	A1B351	0668 358976	PAVEL KISELEV	{"email": "kiselev_p_1982@postgrespro.ru", "phone": "+70378167105"}
0005433165969	448C8D	0026 862976	DANIIL BORISOV	{"email": "d.borisov.061980@postgrespro.ru", "phone": "+70645441549"}
0005433165970	97A109	2384 171622	SERGEY YAKOVLEV	{"email": "yakovlev_sergey.011973@postgrespro.ru", "phone": "+70101999336"}
0005433165971	B07F8E	2267 852499	ELENA NIKITINA	{"phone": "+70845526588"}
0005433165972	4A3451	9532 161786	ANNA NIKOLAEVA	{"phone": "+70276193070"}
0005433165973	64C634	2080 542192	DMITRIY DENISOV	{"email": "denisov_dmitriy_1971@postgrespro.ru", "phone": "+70194634517"}
0005433165974	473B4A	9610 626750	TATYANA SMIRNOVA	{"email": "t.smirnova-1969@postgrespro.ru", "phone": "+70479084856"}
0005433165975	49DB1B	1870 972230	KLAVDIYA FROLOVA	{"email": "kfrolova071977@postgrespro.ru", "phone": "+70763271764"}
0005433165976	49DB1B	2961 523261	YAKOV TARASOV	{"phone": "+70565012318"}
0005433165977	51A5DA	1505 410928	NATALYA LOGINOVA	{"phone": "+70082565889"}
0005433165978	51A5DA	9908 050474	SEMEN MEDVEDEV	{"phone": "+70587184664"}
0005433165979	C72895	5543 537815	ALEKSEY SCHERBAKOV	{"phone": "+70242563686"}
0005433165980	C72895	2871 275745	SVETLANA KALININA	{"phone": "+70127928324"}
0005433165981	8E3297	9296 517124	YULIYA LEBEDEVA	{"phone": "+70529636009"}
0005433165982	8E3297	9849 137100	SOFYA ILINA	{"phone": "+70356452053"}
0005433165983	CE917D	6228 032002	TAMARA SAVELEVA	{"phone": "+70825636744"}
0005433165984	503E33	4543 595569	ALEKSANDR KUZNECOV	{"email": "a_kuznecov121968@postgrespro.ru", "phone": "+70589135054"}
0005433165985	2BF6AE	6788 732346	ELENA FILIPPOVA	{"email": "e_filippova.12051971@postgrespro.ru", "phone": "+70691483761"}
0005433165986	E189DC	3188 394989	OLGA TIKHONOVA	{"phone": "+70944230255"}
0005433165987	E189DC	5384 745558	TIMUR AFANASEV	{"email": "timur_afanasev_1971@postgrespro.ru", "phone": "+70379717382"}
0005433165988	825441	5011 175538	MARINA SERGEEVA	{"email": "sergeeva.m23071970@postgrespro.ru", "phone": "+70773315217"}
0005433165989	70C6B3	7164 978312	KRISTINA IVANOVA	{"phone": "+70106804481"}
0005433165990	251D7F	8843 398781	MARINA ILINA	{"phone": "+70050691990"}
0005433165991	09C6D7	8389 668140	ILDAR TIKHONOV	{"phone": "+70009693212"}
0005433165992	13F11B	1319 089843	YURIY MEDVEDEV	{"phone": "+70411941386"}
0005433165993	2BBD06	8886 153251	ANDREY SOKOLOV	{"phone": "+70754654083"}
0005433165994	365F00	4427 207583	LYUDMILA KUZNECOVA	{"phone": "+70151426591"}
0005433165995	365F00	1544 207022	YULIYA DMITRIEVA	{"email": "dmitrieva_yuliya-1970@postgrespro.ru", "phone": "+70628199606"}
0005433165996	365F00	3798 695989	NIKOLAY ZAKHAROV	{"phone": "+70768991105"}
0005433165997	FB12DF	1738 119127	ANASTASIYA MASLOVA	{"email": "maslovaa.29101967@postgrespro.ru", "phone": "+70626890417"}
0005433165998	5ADC24	7160 042561	ANATOLIY SEMENOV	{"email": "a-semenov-1959@postgrespro.ru", "phone": "+70306532887"}
0005433165999	F91EC6	5348 870410	EVGENIY VASILEV	{"phone": "+70691584995"}
0005433166000	E31BD4	0144 599250	EKATERINA MATVEEVA	{"email": "ematveeva.24061971@postgrespro.ru", "phone": "+70976921347"}
0005433166001	6610BC	4172 886735	VASILIY IVANOV	{"email": "vivanov-03091970@postgrespro.ru", "phone": "+70245323101"}
0005433166002	6610BC	0031 419434	PAVEL ORLOV	{"email": "orlov_p_061972@postgrespro.ru", "phone": "+70670726588"}
0005433166003	AD2A37	4214 558594	NELLYA ZAKHAROVA	{"email": "zakharova.nellya.021967@postgrespro.ru", "phone": "+70332695229"}
0005433166004	A2CC36	0477 048368	KSENIYA FEDOROVA	{"email": "fedorova-kseniya21051964@postgrespro.ru", "phone": "+70471822736"}
0005433166005	F961D6	4238 600034	GALINA VASILEVA	{"phone": "+70530464031"}
0005433166006	53E8D9	3853 278914	YAROSLAV DENISOV	{"phone": "+70871480228"}
0005433166007	685A29	8423 726242	NIKOLAY ROMANOV	{"email": "romanov_nikolay08071962@postgrespro.ru", "phone": "+70464784772"}
0005433166008	685A29	2112 625119	OLGA NAUMOVA	{"phone": "+70196206491"}
0005433166009	686CD3	0857 332254	ALEKSEY FEDOTOV	{"email": "fedotov_a_1978@postgrespro.ru", "phone": "+70531958409"}
0005433166010	686CD3	7821 161480	YURIY BONDARENKO	{"phone": "+70034097402"}
0005433166011	7CBADC	9884 162222	KIRILL IVANOV	{"phone": "+70384974076"}
0005433166012	49B7D9	2780 354496	ANTONINA ANDREEVA	{"phone": "+70825357285"}
0005433166013	C34319	9909 425740	NURLAN SCHERBAKOV	{"email": "nscherbakov-091956@postgrespro.ru", "phone": "+70072691362"}
0005433166014	7C420E	2492 944201	EKATERINA GORBUNOVA	{"phone": "+70402705416"}
0005433166015	7C420E	6549 055905	YURIY STEPANOV	{"phone": "+70993871231"}
0005433166016	451386	8024 681660	GRIGORIY MATVEEV	{"phone": "+70286258054"}
0005433166017	451386	8605 402326	VLADIMIR MIKHAYLOV	{"phone": "+70152112968"}
0005433166018	A3765B	8689 526966	VALERIYA DAVYDOVA	{"phone": "+70871107550"}
0005433166019	A3765B	1588 191989	ANTONINA BELOVA	{"email": "antonina_belova1962@postgrespro.ru", "phone": "+70385041498"}
0005433166020	17AE6F	7824 192482	ALEKSEY KOZLOV	{"phone": "+70971321657"}
0005433166021	17AE6F	0425 742076	ALINA SOROKINA	{"phone": "+70524620560"}
0005433166022	17742A	1283 639107	VALENTINA AFANASEVA	{"email": "afanaseva.v_04041969@postgrespro.ru", "phone": "+70362251954"}
0005433166023	386842	7862 969735	YULIYA FROLOVA	{"email": "frolova.yuliya1980@postgrespro.ru", "phone": "+70606431060"}
0005433166024	386842	9554 823898	ALLA FROLOVA	{"email": "frolova.alla011966@postgrespro.ru", "phone": "+70694626217"}
0005433166025	0C3398	8402 152313	ROMAN SAVELEV	{"email": "savelevr_1980@postgrespro.ru", "phone": "+70367924401"}
0005433166026	F08F07	3283 631799	SERGEY MAKAROV	{"phone": "+70675682573"}
0005433166027	37083C	0733 711086	VENIAMIN KONOVALOV	{"email": "konovalovv_04041969@postgrespro.ru", "phone": "+70068611786"}
0005433166028	C599AE	3320 802623	LYUBOV SERGEEVA	{"phone": "+70232174272"}
0005433166029	1A2027	2137 870309	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko_041970@postgrespro.ru", "phone": "+70002524425"}
0005433166030	1A2027	7005 577101	NADEZHDA IVANOVA	{"email": "ivanova_n.011963@postgrespro.ru", "phone": "+70210162036"}
0005433166031	1A2027	9019 169448	DANIIL STEPANOV	{"email": "stepanov-d.1985@postgrespro.ru", "phone": "+70951160379"}
0005433166032	8E0C68	9349 063503	NATALYA SAVELEVA	{"email": "natalya.saveleva-1964@postgrespro.ru", "phone": "+70376153837"}
0005433166033	8E0C68	8503 681557	KSENIYA GAVRILOVA	{"email": "k.gavrilova1974@postgrespro.ru", "phone": "+70358344420"}
0005433166034	5A351A	1480 173221	EKATERINA EFIMOVA	{"email": "efimovae25031979@postgrespro.ru", "phone": "+70457213701"}
0005433166035	ACE5A9	8975 470478	ELIZAVETA ARKHIPOVA	{"phone": "+70625290364"}
0005433166036	ACE5A9	2308 623315	NATALYA FADEEVA	{"phone": "+70226923898"}
0005433166037	03491E	7925 419140	MIKHAIL GAVRILOV	{"phone": "+70667818733"}
0005433166038	03491E	0405 237714	ELENA TARASOVA	{"phone": "+70345192704"}
0005433166039	03491E	9035 395073	YURIY MIKHAYLOV	{"email": "mikhaylov-yuriy_1979@postgrespro.ru", "phone": "+70316735499"}
0005433166040	EF8A84	1555 458373	ANAIT NIKOLAEVA	{"email": "anait_nikolaeva-15101978@postgrespro.ru", "phone": "+70935115938"}
0005433166041	EF8A84	3339 578347	TATYANA SERGEEVA	{"email": "sergeeva.tatyana1973@postgrespro.ru", "phone": "+70672700720"}
0005433166042	A97B92	3331 598206	VLADIMIR ZAKHAROV	{"email": "zakharov-v-101970@postgrespro.ru", "phone": "+70447348453"}
0005433166043	B1FC15	1791 531205	MIKHAIL POPOV	{"email": "popov_mikhail_121974@postgrespro.ru", "phone": "+70191243536"}
0005433166044	A42ED2	4449 578273	LYUBOV KUZMINA	{"phone": "+70248046372"}
0005433166045	A42ED2	1052 296897	TAMARA TIMOFEEVA	{"phone": "+70766449923"}
0005433166046	CD75B2	1961 071806	ELENA NIKIFOROVA	{"email": "e_nikiforova-071969@postgrespro.ru", "phone": "+70465671364"}
0005433166047	CD75B2	1830 934237	OLGA PETROVA	{"email": "olga-petrova_1970@postgrespro.ru", "phone": "+70782655601"}
0005433166048	6D5F9C	4120 619318	ELENA SOROKINA	{"email": "sorokina_e.27091968@postgrespro.ru", "phone": "+70875958425"}
0005433166049	6682AF	5147 747792	VITALIY MIKHAYLOV	{"email": "v-mikhaylov_1963@postgrespro.ru", "phone": "+70695491493"}
0005433166050	4204B9	8775 764493	ALEKSANDR GUSEV	{"phone": "+70357819513"}
0005433166051	4204B9	7871 714116	ELENA KONDRATEVA	{"phone": "+70050783984"}
0005433166052	0C49C9	1509 427811	ALEKSANDR KOROLEV	{"email": "korolevaleksandr111960@postgrespro.ru", "phone": "+70225502914"}
0005433166053	BCD163	7505 372953	VLADIMIR KRASNOV	{"email": "krasnov.v02021975@postgrespro.ru", "phone": "+70037205724"}
0005433166054	5B4F68	3845 861616	SERGEY ZAKHAROV	{"phone": "+70710555689"}
0005433166055	ED2159	0281 913541	TAMARA DAVYDOVA	{"email": "davydova-tamara-10031974@postgrespro.ru", "phone": "+70281747030"}
0005433166056	5086D3	3620 454139	ALEKSANDR YAKOVLEV	{"phone": "+70899295953"}
0005433166057	C14D6D	3188 734845	ANDREY FEDOTOV	{"phone": "+70302350346"}
0005433166058	6851C6	8767 310744	SERGEY KUZNECOV	{"email": "kuznecov_s_1967@postgrespro.ru", "phone": "+70631678281"}
0005433166059	6851C6	4679 046380	ELENA GERASIMOVA	{"email": "gerasimova.e-03051985@postgrespro.ru", "phone": "+70220965015"}
0005433166060	6851C6	6150 907630	ZOYA ILINA	{"email": "ilina_zoya1966@postgrespro.ru", "phone": "+70037410321"}
0005433166061	314EF9	8978 198566	VIKTORIYA PAVLOVA	{"phone": "+70526739844"}
0005433166062	B00286	6361 044924	OLEG ZAYCEV	{"email": "oleg_zaycev-081967@postgrespro.ru", "phone": "+70594350146"}
0005433166063	C56090	8545 465885	EVGENIY GRIGOREV	{"email": "grigorev.e-1978@postgrespro.ru", "phone": "+70044351457"}
0005433166064	4878BD	6208 464717	NINA NESTEROVA	{"email": "nesterovanina-1975@postgrespro.ru", "phone": "+70820628646"}
0005433166065	4878BD	3215 546891	LYUDMILA PAVLOVA	{"email": "pavlova-lyudmila_23111966@postgrespro.ru", "phone": "+70904177323"}
0005433166066	4BB356	0842 981457	VLADIMIR FEDOROV	{"email": "fedorov.vladimir15061971@postgrespro.ru", "phone": "+70873866440"}
0005433166067	4BB356	5124 038918	OLEG ORLOV	{"phone": "+70712483784"}
0005433166068	8C0417	6329 813825	MAKSIM VASILEV	{"email": "maksim_vasilev_1977@postgrespro.ru", "phone": "+70009436878"}
0005433166069	82D747	9915 326958	EKATERINA FILIPPOVA	{"phone": "+70463754953"}
0005433166070	82D747	4308 419214	DMITRIY BARANOV	{"email": "d.baranov-031976@postgrespro.ru", "phone": "+70762348132"}
0005433166071	726210	7579 010666	MAKSIM SOKOLOV	{"phone": "+70599173645"}
0005433166072	726210	8472 480957	NIKITA EGOROV	{"phone": "+70512958356"}
0005433166073	D9F35A	5399 320319	ALEKSEY FROLOV	{"phone": "+70082702519"}
0005433166074	D32901	8470 207894	ILYA ZAKHAROV	{"phone": "+70789512478"}
0005433166075	4A5B2B	9994 569185	KLAVDIYA YAKOVLEVA	{"email": "yakovleva-k1974@postgrespro.ru", "phone": "+70679731462"}
0005433166076	4A5B2B	5526 088513	MIKHAIL KRASNOV	{"email": "krasnov.mikhail-1961@postgrespro.ru", "phone": "+70211371158"}
0005433166077	DA2D21	6581 605542	OLGA ROMANOVA	{"email": "romanovao.10091966@postgrespro.ru", "phone": "+70605044956"}
0005433166078	0EB38D	3016 601963	ALEKSANDR ISAEV	{"email": "a.isaev.1963@postgrespro.ru", "phone": "+70041138716"}
0005433166079	6BE5DE	6988 129488	DENIS SAVELEV	{"email": "savelev_d.1970@postgrespro.ru", "phone": "+70478555649"}
0005433166080	6BE5DE	7523 709783	NATALYA FEDOROVA	{"phone": "+70408505980"}
0005433166081	732462	6201 456989	MILANA SCHERBAKOVA	{"email": "m.scherbakova1970@postgrespro.ru", "phone": "+70671945802"}
0005433166082	732462	5739 510565	ARTUR ZAKHAROV	{"phone": "+70261303829"}
0005433166083	281874	3491 146883	ALEKSANDR SMIRNOV	{"email": "smirnova.081974@postgrespro.ru", "phone": "+70952258178"}
0005433166084	DF64EF	8082 851063	MIKHAIL ALEKSEEV	{"email": "alekseev_mikhail.1977@postgrespro.ru", "phone": "+70722903406"}
0005433166085	563BDE	0621 827548	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.031980@postgrespro.ru", "phone": "+70479131104"}
0005433166086	E51E5C	7642 356531	SVETLANA PETROVA	{"email": "petrova-svetlana1980@postgrespro.ru", "phone": "+70495099587"}
0005433166087	189B60	2178 408414	NATALYA GUSEVA	{"phone": "+70348307312"}
0005433166088	189B60	7931 251424	ANTONINA SOKOLOVA	{"email": "antonina.sokolova-081968@postgrespro.ru", "phone": "+70043801908"}
0005433166089	252C5E	0415 443210	YURIY ZHURAVLEV	{"email": "zhuravlev.y1963@postgrespro.ru", "phone": "+70004192576"}
0005433166090	FFC1D8	1013 653124	EVDOKIYA FROLOVA	{"phone": "+70851140928"}
0005433166091	DC5251	8474 742869	NATALYA EGOROVA	{"phone": "+70201957463"}
0005433166092	2022BE	1003 185656	VERA ILINA	{"phone": "+70983084216"}
0005433166093	17BCE7	9581 610024	MARINA GERASIMOVA	{"email": "gerasimovamarina_011978@postgrespro.ru", "phone": "+70244243593"}
0005433166094	5EECBE	9907 616346	DENIS IVANOV	{"email": "divanov.02121984@postgrespro.ru", "phone": "+70423631363"}
0005433166095	5CCDDC	8907 495720	NATALIYA DMITRIEVA	{"email": "ndmitrieva_11091969@postgrespro.ru", "phone": "+70534020974"}
0005433166096	5CCDDC	0838 918538	OLEG VOLKOV	{"phone": "+70927540643"}
0005433166097	5E15A2	0447 992597	ALEKSEY POPOV	{"email": "popov.aleksey-1978@postgrespro.ru", "phone": "+70757254113"}
0005433166098	FEF9BF	2408 755715	DAVID KOZLOV	{"phone": "+70796886979"}
0005433166099	14D389	4805 863282	KONSTANTIN KOZLOV	{"email": "konstantin-kozlov-30121973@postgrespro.ru", "phone": "+70961172404"}
0005433166100	63826D	6999 502448	IVAN SMIRNOV	{"email": "ivan_smirnov_19071967@postgrespro.ru", "phone": "+70722651344"}
0005433166101	A0CD9C	4455 013291	DANIIL ILIN	{"phone": "+70530683146"}
0005433166102	ABC199	6823 079873	ILYA KRASNOV	{"phone": "+70255926463"}
0005433166103	ABC199	8512 751669	LYUBOV MAKSIMOVA	{"email": "maksimova.lyubov27021972@postgrespro.ru", "phone": "+70041696204"}
0005433166104	30D318	3240 575596	NATALYA KOVALEVA	{"email": "n.kovaleva_1976@postgrespro.ru", "phone": "+70266199773"}
0005433166105	30D318	9933 363784	VALENTINA KUZNECOVA	{"phone": "+70864113920"}
0005433166106	30D318	7138 440812	ZINAIDA ILINA	{"phone": "+70822963512"}
0005433166107	86B72F	0381 691268	EVGENIY GUSEV	{"phone": "+70471591033"}
0005433166108	86B72F	4370 599681	ALEKSANDR KARPOV	{"email": "karpov-aleksandr_061968@postgrespro.ru", "phone": "+70408838357"}
0005433166109	FE40F3	8329 499827	IGOR GORBUNOV	{"email": "igor_gorbunov011972@postgrespro.ru", "phone": "+70228589057"}
0005433166110	FE40F3	2855 762717	ALEKSANDR KUZMIN	{"phone": "+70523610383"}
0005433166111	BAC0A2	5101 050171	YURIY GORBUNOV	{"phone": "+70197601478"}
0005433166112	D84850	6853 149676	EVGENIY OSIPOV	{"phone": "+70401872430"}
0005433166113	A395BD	9983 247454	EDUARD SIDOROV	{"email": "sidorov.eduard-1965@postgrespro.ru", "phone": "+70862414689"}
0005433166114	A395BD	8128 791398	VALENTINA TIKHONOVA	{"email": "valentina.tikhonova.29061975@postgrespro.ru", "phone": "+70601374758"}
0005433166115	5D2296	4784 487672	GALINA ZHURAVLEVA	{"phone": "+70376327063"}
0005433166116	3055F6	7211 013222	ZINAIDA POLYAKOVA	{"email": "zinaida_polyakova.071955@postgrespro.ru", "phone": "+70875765879"}
0005433166117	95F01B	8825 658974	ZINAIDA RODIONOVA	{"phone": "+70422999442"}
0005433166118	95F01B	2127 096318	GALINA TIMOFEEVA	{"email": "timofeevagalina.08061966@postgrespro.ru", "phone": "+70959599432"}
0005433166119	DB5039	0391 501272	MIKHAIL POPOV	{"email": "popov_mikhail_1978@postgrespro.ru", "phone": "+70445459918"}
0005433166120	19CE2B	2660 090267	SERGEY KRASNOV	{"email": "sergey-krasnov09041977@postgrespro.ru", "phone": "+70878059548"}
0005433166121	BD3831	1732 979154	IRINA NOVIKOVA	{"phone": "+70941245326"}
0005433166122	C49F48	1214 869010	ALEKSANDR DENISOV	{"email": "adenisov.1960@postgrespro.ru", "phone": "+70145816811"}
0005433166123	C49F48	3617 762266	FARIDA NESTEROVA	{"email": "farida_nesterova-22121971@postgrespro.ru", "phone": "+70728756019"}
0005433166124	C49F48	5222 505657	SERGEY KUZNECOV	{"phone": "+70380053576"}
0005433166125	F081A9	3525 888952	MIKHAIL FILIPPOV	{"phone": "+70717146290"}
0005433166126	2402E5	4019 588443	NATALYA SOLOVEVA	{"email": "solovevanatalya_101981@postgrespro.ru", "phone": "+70904658440"}
0005433166127	254A21	0614 986062	ANNA VASILEVA	{"email": "vasileva_a1981@postgrespro.ru", "phone": "+70351354066"}
0005433166128	62EF90	2294 478754	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov1978@postgrespro.ru", "phone": "+70078619206"}
0005433166129	FCD0F6	5523 376505	ALEKSANDR MEDVEDEV	{"email": "aleksandrmedvedev_091977@postgrespro.ru", "phone": "+70675200533"}
0005433166130	FCD0F6	2769 282293	ANATOLIY GUSEV	{"phone": "+70358453226"}
0005433166131	C43AC9	9091 071366	EDUARD IVANOV	{"email": "ivanoveduard01021961@postgrespro.ru", "phone": "+70917660900"}
0005433166132	C43AC9	7631 528574	MARIYA KISELEVA	{"email": "mariya_kiseleva_1979@postgrespro.ru", "phone": "+70254611100"}
0005433166133	647043	0190 801497	VIKTOR GAVRILOV	{"phone": "+70894379338"}
0005433166134	3D27E5	3228 268143	TAMARA MIRONOVA	{"email": "tamara.mironova1978@postgrespro.ru", "phone": "+70050705448"}
0005433166135	D222CD	6832 485419	RAFAEL SOROKIN	{"email": "rafael-sorokin-1965@postgrespro.ru", "phone": "+70577280840"}
0005433166136	D222CD	6570 431096	ALEKSANDR TARASOV	{"phone": "+70772205979"}
0005433166137	D222CD	6608 239361	NADEZHDA FADEEVA	{"email": "fadeeva.n_011974@postgrespro.ru", "phone": "+70519319469"}
0005433166138	6526FE	0109 089413	ELENA POTAPOVA	{"email": "potapovaelena-11071968@postgrespro.ru", "phone": "+70706317713"}
0005433166139	83973E	8698 901247	OLGA KUZNECOVA	{"phone": "+70243772840"}
0005433166140	418059	2748 651499	PRASKOVYA CHERNOVA	{"phone": "+70285430419"}
0005433166141	1EE21E	1878 347865	ANASTASIYA MAKSIMOVA	{"email": "maksimova_anastasiya.1973@postgrespro.ru", "phone": "+70506307524"}
0005433166142	65263B	4573 698924	LEONID OSIPOV	{"email": "osipov_leonid_1972@postgrespro.ru", "phone": "+70595760489"}
0005433166143	191828	7218 611949	ALEKSEY ORLOV	{"email": "aorlov1989@postgrespro.ru", "phone": "+70422346739"}
0005433166144	B41DD0	6673 369107	ALEKSANDR ORLOV	{"phone": "+70914879185"}
0005433166145	1AA42A	3936 779070	NADEZHDA BORISOVA	{"phone": "+70790600475"}
0005433166146	694955	5403 919610	VIKTORIYA NIKOLAEVA	{"email": "nikolaeva_viktoriya_071961@postgrespro.ru", "phone": "+70607024392"}
0005433166147	E8EB8F	7145 570841	OKSANA GAVRILOVA	{"phone": "+70405204526"}
0005433166148	50609E	3495 822122	NATALYA NAUMOVA	{"phone": "+70802946537"}
0005433166149	8827D9	1809 167127	SVETLANA SAVELEVA	{"email": "savelevasvetlana_1970@postgrespro.ru", "phone": "+70682386076"}
0005433166150	8E251E	4723 473004	DENIS RODIONOV	{"phone": "+70456690381"}
0005433166151	8E251E	5219 478494	ALEKSANDR ORLOV	{"phone": "+70271328387"}
0005433166152	B47237	0712 572323	ALFIYA ABRAMOVA	{"email": "a.abramova.011966@postgrespro.ru", "phone": "+70359588451"}
0005433166153	132C0C	7866 855228	ANNA NIKOLAEVA	{"phone": "+70752849496"}
0005433166154	B3795D	2914 532871	VALENTINA RODIONOVA	{"email": "rodionova_valentina01121966@postgrespro.ru", "phone": "+70208336107"}
0005433166155	DC96D8	8878 704617	LARISA ROMANOVA	{"email": "larisa-romanova_1978@postgrespro.ru", "phone": "+70222628558"}
0005433166156	87DC97	0032 230770	NIKOLAY ISAEV	{"phone": "+70938592146"}
0005433166157	056E72	7803 862412	ALEKSANDR PAVLOV	{"phone": "+70658111932"}
0005433166158	1536CC	2508 137862	LYUBOV KOZLOVA	{"email": "lyubov-kozlova.25091982@postgrespro.ru", "phone": "+70070624877"}
0005433166159	B92F94	9158 661472	KRISTINA KRASNOVA	{"phone": "+70663282673"}
0005433166160	03C773	2595 429713	ANNA NESTEROVA	{"email": "nesterova_anna111970@postgrespro.ru", "phone": "+70129841321"}
0005433166161	189665	3361 090286	ELENA KOVALEVA	{"email": "e-kovaleva031967@postgrespro.ru", "phone": "+70810635503"}
0005433166162	189665	9218 166905	ALEKSANDR KUZNECOV	{"phone": "+70900136284"}
0005433166163	64D7A3	3799 001149	NIKOLAY SIDOROV	{"email": "sidorovn051991@postgrespro.ru", "phone": "+70596233944"}
0005433166164	64D7A3	7277 812148	MAKSIM KRASNOV	{"email": "krasnovm_1969@postgrespro.ru", "phone": "+70081548069"}
0005433166165	59CAEA	1382 993147	NINA YAKOVLEVA	{"email": "nina-yakovleva29091969@postgrespro.ru", "phone": "+70610500534"}
0005433166166	59CAEA	6227 006022	MIKHAIL MELNIKOV	{"email": "m-melnikov1963@postgrespro.ru", "phone": "+70275231870"}
0005433166167	94621D	7251 761736	VENERA NIKITINA	{"email": "vnikitina_1976@postgrespro.ru", "phone": "+70626551005"}
0005433166168	CEE63A	3889 958834	YURIY MAKAROV	{"email": "makarov-y_121977@postgrespro.ru", "phone": "+70337577832"}
0005433166169	F21EF7	4173 970886	VLADIMIR SEMENOV	{"phone": "+70244265386"}
0005433166170	6B8DC0	2056 682335	YULIYA FROLOVA	{"phone": "+70812560045"}
0005433166171	183CD6	5745 523416	ALEKSEY EGOROV	{"phone": "+70171626123"}
0005433166172	183CD6	3108 274799	RINAT FILIPPOV	{"email": "rinat-filippov-13031972@postgrespro.ru", "phone": "+70084745504"}
0005433166173	E03C25	0211 699382	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey-111968@postgrespro.ru", "phone": "+70146545278"}
0005433166174	230964	2178 143440	SOFIYA MOROZOVA	{"phone": "+70831478602"}
0005433166175	1150B0	9199 191845	ANNA SERGEEVA	{"phone": "+70630027285"}
0005433166176	726279	9148 274508	ELENA NIKIFOROVA	{"email": "nikiforova_e_24071967@postgrespro.ru", "phone": "+70737075943"}
0005433166177	FE3140	9835 642874	VLADIMIR KOZLOV	{"phone": "+70305040392"}
0005433166178	FE3140	8105 066226	LYUDMILA OSIPOVA	{"email": "l.osipova.1968@postgrespro.ru", "phone": "+70714257484"}
0005433166179	C3EAA6	5230 368954	ALEKSANDR PETROV	{"email": "petrov-aleksandr_16081965@postgrespro.ru", "phone": "+70484361906"}
0005433166180	DFC7E0	9064 878652	ALEKSEY CHERNOV	{"email": "aleksey-chernov-1972@postgrespro.ru", "phone": "+70064495626"}
0005433166181	343779	9825 896959	VADIM GUSEV	{"email": "gusev-v-041963@postgrespro.ru", "phone": "+70719796877"}
0005433166182	C84E01	5234 987853	TATYANA MIKHAYLOVA	{"phone": "+70478854846"}
0005433166183	8CE95D	8126 005143	VALENTINA NIKITINA	{"email": "valentina_nikitina.10061981@postgrespro.ru", "phone": "+70723183321"}
0005433166184	8CE95D	6234 513387	GALINA YUDINA	{"email": "gyudina.30111968@postgrespro.ru", "phone": "+70491116261"}
0005433166185	0B93E4	1085 768928	NADEZHDA KOZLOVA	{"email": "kozlova_n_021971@postgrespro.ru", "phone": "+70951674488"}
0005433166186	0B93E4	7136 493127	SVETLANA BARANOVA	{"email": "baranova_s-071977@postgrespro.ru", "phone": "+70403422832"}
0005433166187	9A659B	6708 335016	ARTEM POPOV	{"phone": "+70163450935"}
0005433166188	9A659B	4461 835020	YURIY ANDREEV	{"phone": "+70541421119"}
0005433166189	9A659B	1998 216085	LYUBOV FROLOVA	{"email": "froloval_11041977@postgrespro.ru", "phone": "+70810591891"}
0005433166190	D3EC92	4739 339292	DARYA RODIONOVA	{"email": "d_rodionova_27061974@postgrespro.ru", "phone": "+70471162092"}
0005433166191	18EE4D	7226 886439	VLADIMIR BORISOV	{"email": "borisov-vladimir-061980@postgrespro.ru", "phone": "+70686063243"}
0005433166192	18EE4D	0770 021196	GALINA KUZNECOVA	{"phone": "+70541006394"}
0005433166193	F97B4A	1921 997973	YULIYA MAKAROVA	{"email": "y_makarova.061974@postgrespro.ru", "phone": "+70049811182"}
0005433166194	A55BCE	8747 901704	SVETLANA KOLESNIKOVA	{"email": "kolesnikova-s.03031975@postgrespro.ru", "phone": "+70600711332"}
0005433166195	E75228	9489 783095	ANDREY IVANOV	{"email": "andrey.ivanov1976@postgrespro.ru", "phone": "+70596051271"}
0005433166196	E75228	0634 288047	ALBINA IVANOVA	{"phone": "+70416708561"}
0005433166197	F2B6A3	6124 193822	LYUDMILA NIKIFOROVA	{"email": "l_nikiforova_17061959@postgrespro.ru", "phone": "+70498019800"}
0005433166198	F2B6A3	6595 672855	OLGA KOROLEVA	{"phone": "+70427195543"}
0005433166199	F2B6A3	4978 054516	SVETLANA KONOVALOVA	{"email": "konovalova_svetlana.01011968@postgrespro.ru", "phone": "+70034778596"}
0005433166200	F2B6A3	5080 299191	VLADISLAV KONOVALOV	{"email": "v-konovalov.1973@postgrespro.ru", "phone": "+70097508369"}
0005433166201	E5AEB7	3672 353837	MARIYA MAKAROVA	{"email": "mariya.makarova1983@postgrespro.ru", "phone": "+70856143010"}
0005433166202	E5AEB7	3851 525867	YURIY FROLOV	{"phone": "+70015725727"}
0005433166203	80C83B	0305 974224	ALEKSANDR NAZAROV	{"phone": "+70084716673"}
0005433166204	FF45D3	9984 604210	IGOR NIKOLAEV	{"phone": "+70565287266"}
0005433166205	FF45D3	9094 408104	LEONID TARASOV	{"phone": "+70534747644"}
0005433166206	AFB3BB	4641 279801	NIKITA IVANOV	{"email": "nikita.ivanov-041967@postgrespro.ru", "phone": "+70242934899"}
0005433166207	AFB3BB	0127 214662	MAKSIM STEPANOV	{"email": "stepanov.maksim051977@postgrespro.ru", "phone": "+70258119360"}
0005433166208	08CDE7	1059 618286	IRINA NIKOLAEVA	{"phone": "+70158973078"}
0005433166209	08CDE7	9260 107142	TATYANA MAKAROVA	{"email": "makarova_t-051983@postgrespro.ru", "phone": "+70343410509"}
0005433166210	1A5F33	8918 644451	NATALYA VLASOVA	{"email": "n-vlasova-1964@postgrespro.ru", "phone": "+70486355206"}
0005433166211	BDEA2C	5079 636280	MIKHAIL ISAEV	{"email": "m.isaev12031966@postgrespro.ru", "phone": "+70717998512"}
0005433166212	BDEA2C	2886 833047	MARAT STEPANOV	{"phone": "+70549571324"}
0005433166213	C52D2E	8316 822783	EKATERINA KISELEVA	{"phone": "+70653310785"}
0005433166214	3BA615	2517 681965	EVGENIY ALEKSEEV	{"email": "alekseev_evgeniy-21101981@postgrespro.ru", "phone": "+70888035694"}
0005433166215	3BA615	6886 614926	VALENTINA NIKITINA	{"phone": "+70148229610"}
0005433166216	629164	4243 377083	ALEKSANDR ORLOV	{"phone": "+70695237753"}
0005433166217	629164	8828 929670	VIKTOR MIKHAYLOV	{"email": "viktor_mikhaylov-121977@postgrespro.ru", "phone": "+70403099230"}
0005433166218	179B72	0405 533676	GALINA NAUMOVA	{"email": "naumova-g.01101974@postgrespro.ru", "phone": "+70443008456"}
0005433166219	179B72	9221 066560	ALEKSEY IVANOV	{"email": "aivanov30071963@postgrespro.ru", "phone": "+70306049485"}
0005433166220	179B72	0310 818545	ALEKSANDR SOKOLOV	{"phone": "+70810053870"}
0005433166221	39E353	4246 688677	ELENA ZAKHAROVA	{"email": "zakharova.elena_081981@postgrespro.ru", "phone": "+70680391739"}
0005433166222	1D0D56	6179 016098	IVAN SERGEEV	{"email": "ivan_sergeev1970@postgrespro.ru", "phone": "+70492407781"}
0005433166223	1D0D56	0824 110853	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr-121968@postgrespro.ru", "phone": "+70686660631"}
0005433166224	1D0D56	5706 718648	ARSENIY ILIN	{"email": "ilina.101973@postgrespro.ru", "phone": "+70105407424"}
0005433166225	23DD2A	4110 241626	ELENA MOROZOVA	{"phone": "+70155789872"}
0005433166226	23DD2A	2007 625214	VALERIYA ORLOVA	{"email": "orlova-valeriya_1988@postgrespro.ru", "phone": "+70085368627"}
0005433166227	19C2D7	6325 374721	ALEVTINA VASILEVA	{"email": "alevtina_vasileva07051978@postgrespro.ru", "phone": "+70251115859"}
0005433166228	19C2D7	2014 789174	PETR ROMANOV	{"email": "romanov_p091959@postgrespro.ru", "phone": "+70213568587"}
0005433166229	A5E716	3521 529878	TAMARA ANDREEVA	{"phone": "+70748179995"}
0005433166230	A5E716	9681 967240	VALERIYA SMIRNOVA	{"email": "vsmirnova.10071974@postgrespro.ru", "phone": "+70616927082"}
0005433166231	730F94	6686 804240	SERGEY POPOV	{"email": "s.popov-24041968@postgrespro.ru", "phone": "+70447534211"}
0005433166232	EA72FC	2242 885759	ELENA BELOVA	{"email": "e-belova.061971@postgrespro.ru", "phone": "+70915137380"}
0005433166233	26EDA5	7307 133418	ALEKSANDR IVANOV	{"email": "a-ivanov09061968@postgrespro.ru", "phone": "+70463296828"}
0005433166234	26EDA5	4900 531150	ALEKSANDR IVANOV	{"phone": "+70308318928"}
0005433166235	26EDA5	3749 700086	NIKOLAY CHERNOV	{"email": "chernov.n-22091978@postgrespro.ru", "phone": "+70722306477"}
0005433166236	B9D1FA	1867 872365	VLADIMIR ABRAMOV	{"email": "abramov.vladimir_011962@postgrespro.ru", "phone": "+70895355762"}
0005433166237	B9D1FA	0353 693249	VADIM FILIPPOV	{"phone": "+70995010838"}
0005433166238	B9D1FA	6819 834622	IRINA POPOVA	{"phone": "+70564885394"}
0005433166239	257E3F	7764 952807	ELVIRA LOGINOVA	{"email": "loginova_e-1970@postgrespro.ru", "phone": "+70614337404"}
0005433166240	9089BE	8538 470179	NADEZHDA ABRAMOVA	{"phone": "+70429063547"}
0005433166241	9089BE	8883 701886	NINA VASILEVA	{"phone": "+70446752503"}
0005433166242	9089BE	8670 695442	SVETLANA ISAEVA	{"phone": "+70625785070"}
0005433166243	22E5CB	4466 043337	SERGEY ALEKSEEV	{"phone": "+70182323012"}
0005433166244	3D43F7	2255 687325	MARIYA NAZAROVA	{"email": "nazarova-m_1956@postgrespro.ru", "phone": "+70954901007"}
0005433166245	3DA80A	0805 818314	ELENA ISAEVA	{"phone": "+70277789490"}
0005433166246	7D8EF5	1115 746886	LYUBOV MAKAROVA	{"email": "lyubov.makarova.071963@postgrespro.ru", "phone": "+70058419543"}
0005433166247	1CB300	5219 359760	YULIANA MAKSIMOVA	{"email": "maksimovay_19021975@postgrespro.ru", "phone": "+70547862437"}
0005433166248	2EF295	7940 267891	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana.1971@postgrespro.ru", "phone": "+70157643190"}
0005433166249	6EADF8	3182 536306	YURIY ZAYCEV	{"phone": "+70010050128"}
0005433166250	D5ADB7	8214 168126	SERGEY AFANASEV	{"phone": "+70894364691"}
0005433166251	D5ADB7	5186 531233	ANDREY MIKHAYLOV	{"email": "andrey_mikhaylov.1982@postgrespro.ru", "phone": "+70416221969"}
0005433166252	1E15C6	3478 640138	LYUDMILA TARASOVA	{"phone": "+70415542272"}
0005433166253	B19D32	8028 536917	ALEKSANDR GRIGOREV	{"phone": "+70948310661"}
0005433166254	E8EAA9	4769 705326	YURIY IVANOV	{"phone": "+70510713172"}
0005433166255	E8EAA9	0952 476131	ALINA FILIPPOVA	{"phone": "+70024808519"}
0005433166256	E8EAA9	5776 269549	NATALYA LOGINOVA	{"phone": "+70025948889"}
0005433166257	B62BD1	2643 765819	DMITRIY SERGEEV	{"email": "sergeev_d.011970@postgrespro.ru", "phone": "+70570900350"}
0005433166258	ACA18A	0141 276819	ALEKSANDRA DANILOVA	{"email": "a-danilova27011969@postgrespro.ru", "phone": "+70234599821"}
0005433166259	896CFB	4774 269285	LYUBOV KUZMINA	{"phone": "+70196232037"}
0005433166260	AA9691	6190 236009	YULIYA KUZNECOVA	{"email": "y_kuznecova_1974@postgrespro.ru", "phone": "+70093952436"}
0005433166261	AA9691	2276 191850	MAKSIM ORLOV	{"phone": "+70091573824"}
0005433166262	A4D61F	0359 364615	ANASTASIYA SERGEEVA	{"email": "sergeeva-a.25041971@postgrespro.ru", "phone": "+70932844681"}
0005433166263	F88C6A	8236 862122	ELENA DMITRIEVA	{"phone": "+70765211330"}
0005433166264	F88C6A	4457 838654	VIKTOR TIMOFEEV	{"email": "viktortimofeev-21011975@postgrespro.ru", "phone": "+70186367540"}
0005433166265	9406DA	0717 228057	SOFYA LEBEDEVA	{"email": "sofyalebedeva-31011963@postgrespro.ru", "phone": "+70922599366"}
0005433166266	43F173	4766 423753	RUSLAN VASILEV	{"email": "ruslan-vasilev-031974@postgrespro.ru", "phone": "+70973018323"}
0005433166267	32B765	8576 501026	VALENTINA GAVRILOVA	{"phone": "+70509023552"}
0005433166268	32B765	2873 329154	ANDREY KRASNOV	{"email": "a-krasnov09031976@postgrespro.ru", "phone": "+70024016882"}
0005433166269	F99064	7089 992755	TAMARA FILIPPOVA	{"email": "tfilippova071971@postgrespro.ru", "phone": "+70717416277"}
0005433166270	AF9BFF	0690 954680	ELENA STEPANOVA	{"email": "stepanovaelena051978@postgrespro.ru", "phone": "+70669093594"}
0005433166271	5840D3	2668 259475	ANASTASIYA ISAEVA	{"email": "a_isaeva.1967@postgrespro.ru", "phone": "+70791254961"}
0005433166272	C2349C	7410 627867	NATALYA KOZLOVA	{"phone": "+70388826794"}
0005433166273	C2349C	0860 527693	ALEKSANDR ZAYCEV	{"phone": "+70478933292"}
0005433166274	8DBEF8	2084 630203	GALINA ZAYCEVA	{"email": "zayceva_galina.1969@postgrespro.ru", "phone": "+70583902976"}
0005433166275	5E467F	6396 004268	NATALYA GERASIMOVA	{"email": "gerasimova.natalya-1970@postgrespro.ru", "phone": "+70302045637"}
0005433166276	BB73A3	6318 117800	NATALYA SOLOVEVA	{"email": "n.soloveva.20111969@postgrespro.ru", "phone": "+70903704322"}
0005433166277	8CBF3B	2904 252923	KONSTANTIN KONOVALOV	{"email": "konovalov.konstantin25121980@postgrespro.ru", "phone": "+70996272002"}
0005433166278	8CBF3B	5649 577649	ALEKSANDR KOZLOV	{"phone": "+70529156424"}
0005433166279	625471	0309 688203	ALEKSEY TIMOFEEV	{"phone": "+70069634988"}
0005433166280	041BF7	1614 093944	PETR GORBUNOV	{"phone": "+70302605217"}
0005433166281	A5A495	2075 150363	ZOYA LAZAREVA	{"phone": "+70377910924"}
0005433166282	DF5CFC	8137 313193	NADEZHDA FILATOVA	{"phone": "+70054739121"}
0005433166283	87597C	6037 171163	IVAN SOROKIN	{"email": "isorokin.09031983@postgrespro.ru", "phone": "+70165864955"}
0005433166284	B49372	5259 073689	NIKITA BELOV	{"phone": "+70976203779"}
0005433166285	B49372	6492 204265	YURIY NAZAROV	{"email": "yuriy.nazarov.071961@postgrespro.ru", "phone": "+70296025802"}
0005433166286	6306BB	3737 953054	GULNARA KOLESNIKOVA	{"phone": "+70496324886"}
0005433166287	CEC1E9	8897 198325	NATALYA SOROKINA	{"email": "sorokina_natalya1971@postgrespro.ru", "phone": "+70592631536"}
0005433166288	CE9435	2237 944066	ALEKSEY ALEKSEEV	{"email": "aleksey-alekseev.30031971@postgrespro.ru", "phone": "+70881872434"}
0005433166289	BF78D5	1221 003967	OLEG GORBUNOV	{"phone": "+70991779432"}
0005433168299	EEBD5C	5913 265642	VLADIMIR FEDOTOV	{"email": "vladimir_fedotov19061976@postgrespro.ru", "phone": "+70326285829"}
0005433168300	E02218	2898 760103	ELENA AFANASEVA	{"phone": "+70645229538"}
0005433168301	E02218	2752 087170	ZINAIDA ANISIMOVA	{"email": "zinaida_anisimova-03021964@postgrespro.ru", "phone": "+70442178818"}
0005433168302	502CDD	1012 017188	ALEKSANDR KISELEV	{"phone": "+70691283359"}
0005433168303	ACC0A7	5098 892444	KONSTANTIN TIKHONOV	{"phone": "+70794318237"}
0005433168304	94824A	3616 044583	VLADIMIR MELNIKOV	{"email": "vladimir-melnikov-051969@postgrespro.ru", "phone": "+70373783650"}
0005433168305	94824A	2347 038236	DARYA BELYAEVA	{"email": "belyaeva-d_111977@postgrespro.ru", "phone": "+70697952187"}
0005433168306	A736F7	9225 257919	VALERIYA VASILEVA	{"phone": "+70394783086"}
0005433168307	42DA79	2445 901188	IRINA VOLKOVA	{"email": "i_volkova1964@postgrespro.ru", "phone": "+70511340828"}
0005433168308	118B44	2863 472394	DARYA VOLKOVA	{"phone": "+70459017178"}
0005433168309	4D760D	0456 314215	TATYANA GUSEVA	{"email": "gusevat.091974@postgrespro.ru", "phone": "+70531062642"}
0005433168310	A49C31	7855 480187	VALENTINA BELOVA	{"email": "vbelova_16081965@postgrespro.ru", "phone": "+70709323830"}
0005433168311	515421	2710 454355	OLGA KOLESNIKOVA	{"email": "kolesnikova.olga.1973@postgrespro.ru", "phone": "+70403874515"}
0005433168312	A9B3A4	2124 279817	DMITRIY GUSEV	{"email": "dmitriy_gusev-041980@postgrespro.ru", "phone": "+70493190510"}
0005433168313	E249EA	4317 310946	VIKTOR MOISEEV	{"phone": "+70039230670"}
0005433168314	CD1F58	1443 179435	YULIYA ALEKSEEVA	{"email": "yalekseeva-101963@postgrespro.ru", "phone": "+70215483114"}
0005433168315	F3CA46	8976 468604	SERGEY MOROZOV	{"phone": "+70593474368"}
0005433168316	BF3837	9010 636529	ANTON SOROKIN	{"email": "a.sorokin.051957@postgrespro.ru", "phone": "+70021738881"}
0005433168317	C39863	2378 786660	ILYA TARASOV	{"email": "ilya_tarasov_1982@postgrespro.ru", "phone": "+70081178631"}
0005433168318	C39863	5682 408245	EKATERINA GUSEVA	{"phone": "+70505295906"}
0005433168319	F24C82	0768 087812	ANDREY IVANOV	{"email": "aivanov.17091969@postgrespro.ru", "phone": "+70969626641"}
0005433168320	ABB8CE	6814 704848	YURIY MATVEEV	{"email": "ymatveev101970@postgrespro.ru", "phone": "+70178593723"}
0005433168321	E4ADF4	9592 042203	ALEKSEY IVANOV	{"email": "a-ivanov_011975@postgrespro.ru", "phone": "+70966581106"}
0005433168322	E4ADF4	5029 483553	ILYA STEPANOV	{"phone": "+70803665342"}
0005433168323	B6A87B	9207 938239	VLADIMIR GRIGOREV	{"email": "grigorev.vladimir_03041983@postgrespro.ru", "phone": "+70947308289"}
0005433168324	B6A87B	5849 825133	YANA GUSEVA	{"phone": "+70187254926"}
0005433168325	B247AC	5757 105004	ASIYA ALEKSANDROVA	{"phone": "+70589652411"}
0005433168326	B247AC	8823 890971	VALENTINA IVANOVA	{"email": "v_ivanova111972@postgrespro.ru", "phone": "+70153079386"}
0005433168327	B247AC	2775 896922	EKATERINA KUZNECOVA	{"phone": "+70884326592"}
0005433168328	A54B26	6329 602821	OLESYA ZAYCEVA	{"email": "o_zayceva_25011982@postgrespro.ru", "phone": "+70149202771"}
0005433168329	99A70B	5069 172499	SOFYA VOROBEVA	{"phone": "+70819886757"}
0005433168330	07C369	4365 778826	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_1971@postgrespro.ru", "phone": "+70352700559"}
0005433168331	07C369	1563 952434	DANIIL ORLOV	{"phone": "+70045596763"}
0005433168332	7493EB	0145 247875	EVGENIY BARANOV	{"phone": "+70945710462"}
0005433168333	8B549B	6073 487938	SERGEY ZHUKOV	{"phone": "+70277558666"}
0005433168334	40EAF5	7472 047151	VLADIMIR FOMIN	{"phone": "+70898288947"}
0005433168335	BD93A6	7381 997432	PAVEL SAVELEV	{"phone": "+70795048280"}
0005433168336	BD93A6	9120 851766	LIDIYA KUZMINA	{"email": "l.kuzmina-1972@postgrespro.ru", "phone": "+70761872295"}
0005433168337	099B16	7798 566358	ANDREY IVANOV	{"email": "ivanov_a-011972@postgrespro.ru", "phone": "+70067697535"}
0005433168338	099B16	3479 020656	ANNA KRASNOVA	{"phone": "+70712963932"}
0005433168339	816497	7575 317426	NIKITA IVANOV	{"phone": "+70532697441"}
0005433168340	4F77E1	5742 877649	MARINA IVANOVA	{"phone": "+70257297626"}
0005433168341	FD33F1	1542 646555	PAVEL MAKAROV	{"email": "pavel-makarov_1966@postgrespro.ru", "phone": "+70290016011"}
0005433168342	8A74E6	7845 761326	ANATOLIY NAZAROV	{"phone": "+70787930202"}
0005433168343	8A74E6	7004 135632	SERGEY ANTONOV	{"email": "antonov.s-071962@postgrespro.ru", "phone": "+70276919175"}
0005433168344	700F26	9220 212406	VLADIMIR ALEKSEEV	{"email": "alekseev_v-1965@postgrespro.ru", "phone": "+70764619384"}
0005433168345	700F26	1100 017089	VALENTINA IVANOVA	{"email": "v-ivanova.13031964@postgrespro.ru", "phone": "+70024610245"}
0005433168346	700F26	6049 808887	GALINA LUKYANOVA	{"email": "g-lukyanova.121973@postgrespro.ru", "phone": "+70883972248"}
0005433168347	8CA7EF	4209 072251	MIKHAIL IVANOV	{"email": "ivanov-mikhail_1970@postgrespro.ru", "phone": "+70964791207"}
0005433168348	847441	5480 557963	SERGEY MEDVEDEV	{"phone": "+70957495439"}
0005433168349	61466F	4647 361194	VALENTINA ZHUKOVA	{"phone": "+70378821220"}
0005433168350	61466F	8678 460307	SERGEY DMITRIEV	{"email": "sergeydmitriev_111975@postgrespro.ru", "phone": "+70304297911"}
0005433168351	AA77F4	0375 226115	EGOR FROLOV	{"email": "efrolov-19041971@postgrespro.ru", "phone": "+70142770450"}
0005433168352	4A8EF1	4679 547634	ARINA NIKIFOROVA	{"email": "anikiforova_22091978@postgrespro.ru", "phone": "+70673818248"}
0005433168353	4A8EF1	7571 712015	OKSANA DAVYDOVA	{"phone": "+70673798673"}
0005433168354	6D1B15	9750 450442	SVETLANA VOLKOVA	{"phone": "+70169800660"}
0005433168355	6D1B15	6398 507593	VASILIY VASILEV	{"email": "vasilev.vasiliy1972@postgrespro.ru", "phone": "+70530910245"}
0005433168356	BB63EA	3357 738432	TATYANA BOGDANOVA	{"email": "bogdanova.t.26051976@postgrespro.ru", "phone": "+70757368779"}
0005433168357	5BE561	6354 332911	ZHANNA KOVALEVA	{"phone": "+70596962701"}
0005433168358	5BE561	6328 451929	ANASTASIYA STEPANOVA	{"phone": "+70413549848"}
0005433168359	EC4A3D	7390 483100	KRISTINA KUZNECOVA	{"email": "k.kuznecova-03111983@postgrespro.ru", "phone": "+70759242458"}
0005433168360	ABB82D	8021 366966	KRISTINA VOROBEVA	{"email": "vorobevakristina-1975@postgrespro.ru", "phone": "+70693164918"}
0005433168361	D7D644	7536 704991	OLEG ABRAMOV	{"phone": "+70860820614"}
0005433168362	10A22D	9009 949698	ROMAN MOROZOV	{"email": "roman.morozov1978@postgrespro.ru", "phone": "+70566306105"}
0005433168363	10A22D	2257 756643	FATIMA KUZMINA	{"email": "kuzmina-fatima23031983@postgrespro.ru", "phone": "+70813961825"}
0005433168364	3264E4	5121 069456	YULIYA MAKAROVA	{"phone": "+70169374999"}
0005433168365	8322C3	6932 564204	VALERIY NAZAROV	{"phone": "+70541856061"}
0005433168366	6657E5	7583 144103	DMITRIY VLASOV	{"phone": "+70321284823"}
0005433168367	2EF456	3229 465166	LYUDMILA VOROBEVA	{"email": "l.vorobeva_1976@postgrespro.ru", "phone": "+70957187648"}
0005433168368	2EF456	2397 071316	TAMARA PAVLOVA	{"phone": "+70486913536"}
0005433168369	E1FBF0	5488 901889	ALINA BELOVA	{"phone": "+70832199243"}
0005433168370	07AFC6	2126 181304	TAMARA DMITRIEVA	{"email": "dmitrievatamara1969@postgrespro.ru", "phone": "+70064222463"}
0005433168371	7FA9F4	1190 972768	LIDIYA IVANOVA	{"email": "ivanova-lidiya-071978@postgrespro.ru", "phone": "+70437656708"}
0005433168372	214D1A	2973 393404	NIKOLAY MAKAROV	{"email": "makarov-n-031975@postgrespro.ru", "phone": "+70187398089"}
0005433168373	0CDC32	6794 976079	IVAN POPOV	{"phone": "+70858461498"}
0005433168374	0CDC32	0221 509865	NATALYA GORBUNOVA	{"email": "gorbunova.natalya-051972@postgrespro.ru", "phone": "+70791266067"}
0005433168375	D9E0D9	7161 125801	SERGEY BONDARENKO	{"email": "bondarenkosergey-061981@postgrespro.ru", "phone": "+70252343669"}
0005433168376	93FDEF	4854 720268	IRINA KOROLEVA	{"email": "koroleva-i-02121979@postgrespro.ru", "phone": "+70694482424"}
0005433168377	93FDEF	0957 028168	NADEZHDA IVANOVA	{"phone": "+70381502793"}
0005433168378	93FDEF	0095 931416	NIKOLAY KULIKOV	{"email": "nikolay_kulikov_30091972@postgrespro.ru", "phone": "+70480335886"}
0005433168379	134DEA	9119 958796	ELENA OSIPOVA	{"phone": "+70980608259"}
0005433168380	134DEA	1706 822971	OLGA KUDRYASHOVA	{"email": "olga.kudryashova.011988@postgrespro.ru", "phone": "+70999321933"}
0005433168381	08B245	7286 936486	TATYANA CHERNOVA	{"email": "tatyanachernova.121971@postgrespro.ru", "phone": "+70665917884"}
0005433168382	8FAFE4	9554 242490	YURIY FEDOTOV	{"email": "yuriy.fedotov011960@postgrespro.ru", "phone": "+70074712276"}
0005433168383	8FAFE4	9179 735725	TATYANA AFANASEVA	{"email": "afanaseva.t-101982@postgrespro.ru", "phone": "+70006303658"}
0005433168384	495F1F	9480 220364	LIDIYA OSIPOVA	{"email": "osipoval_031976@postgrespro.ru", "phone": "+70263868105"}
0005433168385	495F1F	2758 592550	KAMILA MIKHAYLOVA	{"phone": "+70670153459"}
0005433168386	1C1277	0009 995712	OLEG KUDRYASHOV	{"phone": "+70757112304"}
0005433168387	340C63	2637 396269	NADEZHDA DAVYDOVA	{"email": "ndavydova1972@postgrespro.ru", "phone": "+70046681165"}
0005433168388	B55405	8806 434670	RUSLAN MAKAROV	{"phone": "+70749554073"}
0005433168389	97C7D0	4451 440802	ELENA NESTEROVA	{"phone": "+70023631696"}
0005433168390	97C7D0	0377 820912	ALEKSANDR DENISOV	{"phone": "+70841591287"}
0005433168391	97C7D0	3558 826483	TATYANA KOROLEVA	{"phone": "+70941759772"}
0005433168392	7D2EEC	4357 921491	SERGEY IVANOV	{"phone": "+70733075863"}
0005433168393	D3DB9F	7092 665070	LYUDMILA KULIKOVA	{"phone": "+70855586923"}
0005433168394	FCE32B	3807 441461	ALEKSANDR GERASIMOV	{"email": "a_gerasimov18081977@postgrespro.ru", "phone": "+70088827691"}
0005433168395	924370	5609 177126	IGOR GERASIMOV	{"email": "i.gerasimov-111978@postgrespro.ru", "phone": "+70147170040"}
0005433168396	82487F	2403 589174	YULIYA ANTONOVA	{"phone": "+70760877628"}
0005433168397	F469C1	8265 517169	KSENIYA ZHUKOVA	{"email": "kseniya.zhukova_1968@postgrespro.ru", "phone": "+70348945931"}
0005433168398	E18E51	8834 775543	VALENTINA TARASOVA	{"email": "tarasovav21101969@postgrespro.ru", "phone": "+70270782179"}
0005433168399	E18E51	7233 068697	KIRILL GERASIMOV	{"phone": "+70899609237"}
0005433168400	B8313F	3557 716530	ANNA SOKOLOVA	{"email": "sokolova_anna_01111975@postgrespro.ru", "phone": "+70216737466"}
0005433168401	1FD105	2440 351010	EVGENIY DAVYDOV	{"phone": "+70354134800"}
0005433168402	6A566B	3955 458284	VLADISLAV KULIKOV	{"phone": "+70254449690"}
0005433168403	7EAC16	0617 557624	MARIYA KOZLOVA	{"phone": "+70983103099"}
0005433168404	E77D4C	8415 034390	RUZALIYA GUSEVA	{"phone": "+70785579454"}
0005433168405	1B3ED9	0552 091230	VLADIMIR ANTONOV	{"email": "vantonov-07091978@postgrespro.ru", "phone": "+70734507863"}
0005433168406	1B3ED9	6088 246750	YURIY NIKITIN	{"phone": "+70859059934"}
0005433168407	3FA82D	5633 821862	VITALIY RODIONOV	{"phone": "+70075561510"}
0005433168408	7EC2E2	6294 468013	DMITRIY SMIRNOV	{"phone": "+70524485942"}
0005433168409	7EC2E2	2780 898762	LARISA KALININA	{"email": "l.kalinina_13021976@postgrespro.ru", "phone": "+70208391927"}
0005433168410	1E2EDE	5456 735842	SOFYA POPOVA	{"email": "popova.s.28091966@postgrespro.ru", "phone": "+70057423460"}
0005433168411	D819D6	5915 852395	EVDOKIYA KARPOVA	{"email": "evdokiya.karpova.1970@postgrespro.ru", "phone": "+70220724604"}
0005433168412	D819D6	9039 190152	NATALIYA BOGDANOVA	{"email": "nataliyabogdanova_111977@postgrespro.ru", "phone": "+70917065256"}
0005433168413	5341BE	6324 609884	ALEKSANDR SERGEEV	{"phone": "+70011960833"}
0005433168414	5341BE	4531 045282	ALEKSEY MAKSIMOV	{"email": "a.maksimov14091974@postgrespro.ru", "phone": "+70878692587"}
0005433168415	256F3D	0035 538346	VALENTINA KALININA	{"phone": "+70975467224"}
0005433168416	0F5EF9	1672 611673	DARYA POTAPOVA	{"email": "d_potapova.061986@postgrespro.ru", "phone": "+70848550813"}
0005433168417	FF4870	3180 186742	KSENIYA POPOVA	{"phone": "+70700906097"}
0005433168418	05BC58	8742 130897	LYUBOV BORISOVA	{"phone": "+70955530058"}
0005433168419	5D724B	8275 601299	FEDOR FEDOROV	{"phone": "+70526115924"}
0005433168420	5D724B	3362 555379	ALEKSANDR KUZNECOV	{"phone": "+70201487126"}
0005433168421	5D724B	5657 872533	IVAN POPOV	{"phone": "+70714001341"}
0005433168422	7C91BE	2306 153089	IRINA DANILOVA	{"phone": "+70617728386"}
0005433168423	7C91BE	7627 554210	PAVEL GERASIMOV	{"email": "gerasimov-p01101963@postgrespro.ru", "phone": "+70706132036"}
0005433168424	9F0749	4616 729812	LYUBOV KOZLOVA	{"phone": "+70503753223"}
0005433168425	3008C0	1228 613895	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila29101977@postgrespro.ru", "phone": "+70051823169"}
0005433168426	ABA7E9	1081 477291	VALERIYA MIKHAYLOVA	{"phone": "+70744929397"}
0005433168427	ABA7E9	2990 147253	KONSTANTIN ANDREEV	{"phone": "+70785045152"}
0005433168428	ABA7E9	0387 963521	LYUDMILA ZHUKOVA	{"email": "zhukova_lyudmila_1969@postgrespro.ru", "phone": "+70079854707"}
0005433168429	D98160	2428 741706	ELVIRA FILIPPOVA	{"phone": "+70237901847"}
0005433168430	62F75B	5565 125168	NIKOLAY CHERNOV	{"phone": "+70139242598"}
0005433168431	62F75B	8884 665701	OKSANA RODIONOVA	{"phone": "+70520845969"}
0005433168432	62F75B	1386 938301	VALENTINA SAVELEVA	{"phone": "+70699635405"}
0005433168433	64F2F6	9128 051749	NATALYA IVANOVA	{"email": "n_ivanova22071976@postgrespro.ru", "phone": "+70499381380"}
0005433168434	0394A1	8186 821482	LIDIYA BELYAEVA	{"email": "lidiya.belyaeva_1967@postgrespro.ru", "phone": "+70475583497"}
0005433168435	773DB3	0455 987867	VIKTOR IVANOV	{"phone": "+70924220086"}
0005433168436	CC67F9	3310 000462	NADEZHDA VASILEVA	{"email": "nadezhda-vasileva-1984@postgrespro.ru", "phone": "+70813328034"}
0005433168437	D21286	0103 429500	IRINA TARASOVA	{"phone": "+70441761224"}
0005433168438	005D11	0998 523573	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova061976@postgrespro.ru", "phone": "+70647016192"}
0005433168439	005D11	4129 055992	PAVEL SEMENOV	{"phone": "+70545412679"}
0005433168440	6060AC	1201 109835	TAMARA MALYSHEVA	{"email": "t-malysheva.011976@postgrespro.ru", "phone": "+70763815701"}
0005433168441	B828FD	6975 934799	ANNA KULIKOVA	{"email": "a_kulikova-011981@postgrespro.ru", "phone": "+70415144714"}
0005433168442	B828FD	1127 791990	VLADIMIR ANDREEV	{"email": "vladimir-andreev_051973@postgrespro.ru", "phone": "+70675080093"}
0005433168443	C253C7	4310 887093	VLADIMIR POPOV	{"phone": "+70182103393"}
0005433168444	C253C7	6665 760657	ANDREY KISELEV	{"email": "a.kiselev1982@postgrespro.ru", "phone": "+70158998413"}
0005433168445	CC5D83	1908 055724	KONSTANTIN EGOROV	{"phone": "+70268010115"}
0005433168446	555CAE	4743 576238	EVGENIY VLASOV	{"email": "vlasov-evgeniy1964@postgrespro.ru", "phone": "+70957700638"}
0005433168447	A4D8E1	6684 956867	RAFAEL KONOVALOV	{"phone": "+70157971851"}
0005433168448	1E6BF7	5277 143944	NIKOLAY GORBUNOV	{"phone": "+70337641904"}
0005433168449	5FB612	4077 659783	ALINA STEPANOVA	{"email": "stepanovaalina-051972@postgrespro.ru", "phone": "+70418185158"}
0005433168450	5FB612	9672 451796	IGOR KRASNOV	{"email": "igor_krasnov_011967@postgrespro.ru", "phone": "+70160517569"}
0005433168451	0E22AC	1827 761803	VYACHESLAV ZAYCEV	{"email": "zaycevvyacheslav-091976@postgrespro.ru", "phone": "+70597086638"}
0005433168452	14A73E	0354 977344	VALERIY IVANOV	{"email": "ivanov-v091983@postgrespro.ru", "phone": "+70015427754"}
0005433168453	1DA848	6529 581990	VLADIMIR GERASIMOV	{"phone": "+70284217178"}
0005433168454	1DA848	2734 963849	MIKHAIL VOROBEV	{"email": "vorobev.m-121971@postgrespro.ru", "phone": "+70989999734"}
0005433168455	83E3D2	6939 930181	GALINA KUZNECOVA	{"email": "galina_kuznecova-1971@postgrespro.ru", "phone": "+70721931054"}
0005433168456	83E3D2	3192 118597	LYUDMILA KOROLEVA	{"phone": "+70128223840"}
0005433168457	E3C128	6403 542133	ANASTASIYA STEPANOVA	{"phone": "+70416726511"}
0005433168458	E3C128	7777 034450	PAVEL SAVELEV	{"phone": "+70974013019"}
0005433168459	6773C2	7166 837491	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila_17051976@postgrespro.ru", "phone": "+70516927733"}
0005433168460	FD1145	6331 723486	NIKITA MIRONOV	{"email": "nikita.mironov.12061984@postgrespro.ru", "phone": "+70228005471"}
0005433168461	CAF2E1	7997 123070	ALEKSANDR IVANOV	{"phone": "+70316920667"}
0005433168462	0E5063	7989 535433	OLGA SOROKINA	{"email": "olga.sorokina_16061966@postgrespro.ru", "phone": "+70167757891"}
0005433168463	0073CF	2133 860824	IRINA SOLOVEVA	{"email": "i-soloveva_10121972@postgrespro.ru", "phone": "+70892710737"}
0005433168464	36F3D8	8765 927490	LIDIYA FOMINA	{"phone": "+70931166940"}
0005433168465	714C39	2955 462019	MARIYA MIKHAYLOVA	{"email": "mikhaylova_mariya-04101976@postgrespro.ru", "phone": "+70220297148"}
0005433168466	714C39	9005 930307	VALENTINA ZAYCEVA	{"email": "valentina.zayceva30081976@postgrespro.ru", "phone": "+70588953346"}
0005433168467	714C39	1549 668595	EVGENIY KUZMIN	{"phone": "+70748324310"}
0005433168468	E8A870	6468 986602	IVAN POPOV	{"email": "ivanpopov.051956@postgrespro.ru", "phone": "+70408259152"}
0005433168469	31203C	9938 483829	SHAVKAT ZAYCEV	{"phone": "+70778976331"}
0005433168470	D86229	3504 214505	OLGA MAKAROVA	{"email": "o_makarova-02081969@postgrespro.ru", "phone": "+70666720418"}
0005433168471	8D2D92	9397 034263	IRINA NIKOLAEVA	{"email": "irina-nikolaeva.20051980@postgrespro.ru", "phone": "+70398218415"}
0005433168472	BC1C44	6590 758627	IVAN IVANOV	{"phone": "+70400910893"}
0005433168473	132332	3679 020788	NIKOLAY KUZNECOV	{"phone": "+70529752960"}
0005433168474	27E0D4	2589 016440	LILIYA ILINA	{"phone": "+70295884588"}
0005433168475	BC6F87	6907 838461	EVDOKIYA SOKOLOVA	{"email": "sokolova-evdokiya.1975@postgrespro.ru", "phone": "+70174739752"}
0005433168476	B17093	8458 338481	OLGA FROLOVA	{"email": "frolova.olga021985@postgrespro.ru", "phone": "+70883186675"}
0005433168477	F2063E	6914 920151	ANASTASIYA PAVLOVA	{"phone": "+70680929688"}
0005433168478	A03B9A	8775 928438	EKATERINA FOMINA	{"email": "fomina.ekaterina-01051980@postgrespro.ru", "phone": "+70457110127"}
0005433168479	650EAC	0348 112752	EGOR MIRONOV	{"email": "mironov_e_081969@postgrespro.ru", "phone": "+70899234098"}
0005433168480	12CFE7	0664 106691	VIKTOR KAZAKOV	{"email": "v.kazakov27111976@postgrespro.ru", "phone": "+70229761575"}
0005433168481	878D3F	0484 428040	GALINA FILATOVA	{"phone": "+70395245532"}
0005433168482	D368D1	7469 047732	NATALYA MAKAROVA	{"phone": "+70153005450"}
0005433168483	8A04AA	3093 241964	SVETLANA SEMENOVA	{"phone": "+70084188698"}
0005433168484	C101D0	0950 080080	MIKHAIL BORISOV	{"email": "mikhail_borisov101978@postgrespro.ru", "phone": "+70444870651"}
0005433168485	C101D0	3245 383838	VLADIMIR KOROLEV	{"phone": "+70005666188"}
0005433168486	45C3B9	9896 895382	IVAN VOLKOV	{"phone": "+70977456479"}
0005433168487	45C3B9	9359 186206	VLADIMIR ANTONOV	{"phone": "+70531627834"}
0005433168488	16DB16	4795 002718	OLEG POPOV	{"phone": "+70673354645"}
0005433168489	F1C53B	3033 898480	NADEZHDA SIDOROVA	{"phone": "+70904064522"}
0005433168490	F1C53B	4696 994154	ANTON KRASNOV	{"email": "a.krasnov-10021972@postgrespro.ru", "phone": "+70056912561"}
0005433168491	F1C53B	5847 825480	TATYANA TIMOFEEVA	{"phone": "+70261888363"}
0005433168492	54F6B3	3278 985375	VLADIMIR MAKAROV	{"email": "makarov_v-021966@postgrespro.ru", "phone": "+70994664010"}
0005433168493	EB515E	2778 993205	ALEKSEY NAUMOV	{"phone": "+70808586286"}
0005433180769	3BFAB3	5936 307343	TATYANA SIDOROVA	{"phone": "+70844504328"}
0005433180648	157BB2	4913 160284	ANNA MIKHAYLOVA	{"phone": "+70781432829"}
0005433180649	2EA9B0	6038 275130	LYUDMILA PETROVA	{"email": "petrova.lyudmila081965@postgrespro.ru", "phone": "+70583202021"}
0005433180650	3620DE	2760 153675	GEORGIY VLASOV	{"phone": "+70013345945"}
0005433180651	3620DE	0080 872149	ARTEM ANTONOV	{"phone": "+70551423964"}
0005433180652	0DD6E7	1992 970779	VIKTORIYA ILINA	{"phone": "+70444096967"}
0005433180653	695E7F	3035 186786	GALINA VOROBEVA	{"phone": "+70244741359"}
0005433180654	695E7F	6728 280074	ALEKSEY ZAYCEV	{"email": "zayceva_1964@postgrespro.ru", "phone": "+70272632949"}
0005433180655	25AF19	0428 352732	NATALYA KUZNECOVA	{"email": "nkuznecova_1983@postgrespro.ru", "phone": "+70260650703"}
0005433180656	26F8C3	4193 276705	EKATERINA TIMOFEEVA	{"email": "e.timofeeva-061968@postgrespro.ru", "phone": "+70607537214"}
0005433180657	26F8C3	1463 160918	LYUDMILA EFIMOVA	{"email": "efimova-l_09121968@postgrespro.ru", "phone": "+70118214780"}
0005433180658	691745	8352 338085	DMITRIY ALEKSANDROV	{"email": "aleksandrov_dmitriy-1972@postgrespro.ru", "phone": "+70912347642"}
0005433180659	458C61	2221 110964	DMITRIY OSIPOV	{"email": "osipovdmitriy101977@postgrespro.ru", "phone": "+70967274463"}
0005433180660	F9156B	5920 417460	ANDREY KAZAKOV	{"phone": "+70584754725"}
0005433180661	2C991F	3465 993431	VYACHESLAV ANDREEV	{"email": "vyacheslav-andreev041966@postgrespro.ru", "phone": "+70591823710"}
0005433180662	0A1334	1731 264644	EKATERINA SOROKINA	{"phone": "+70788645977"}
0005433180663	2BEC73	0836 608278	SERGEY KOZLOV	{"email": "kozlov.sergey-1966@postgrespro.ru", "phone": "+70876297750"}
0005433180664	BA1A61	9509 661931	GLEB MAKAROV	{"phone": "+70428243953"}
0005433180665	BA1A61	7939 213209	SVETLANA KUZMINA	{"phone": "+70653055661"}
0005433180666	EFC9C7	6474 250919	NIKOLAY KUZMIN	{"email": "n_kuzmin1964@postgrespro.ru", "phone": "+70039281841"}
0005433180667	3FA8D3	2098 078323	SERGEY SEMENOV	{"email": "s-semenov.05071981@postgrespro.ru", "phone": "+70883654874"}
0005433180668	BE349D	6670 229668	ALEKSEY ANTONOV	{"phone": "+70883688820"}
0005433180669	BE6DC8	9381 567872	GEORGIY BONDARENKO	{"email": "bondarenko_georgiy-041972@postgrespro.ru", "phone": "+70806259595"}
0005433180670	BE6DC8	7200 681184	ALEKSANDRA FOMINA	{"email": "aleksandra.fomina.11061979@postgrespro.ru", "phone": "+70722909411"}
0005433180671	AC9B4F	5157 362447	NATALIYA KUZNECOVA	{"email": "n-kuznecova_29071966@postgrespro.ru", "phone": "+70850939274"}
0005433180672	51BF0B	8215 831863	ALEKSANDR SHEVCHENKO	{"phone": "+70816109535"}
0005433180673	100206	7782 931941	ILYA FROLOV	{"email": "frolov.ilya111966@postgrespro.ru", "phone": "+70702317303"}
0005433180674	7D390B	9514 892545	IRINA BELOVA	{"email": "irina-belova061978@postgrespro.ru", "phone": "+70362127111"}
0005433180675	47BCDA	6477 114381	ANASTASIYA KUZMINA	{"email": "kuzmina-a_1977@postgrespro.ru", "phone": "+70721747392"}
0005433180676	47BCDA	9370 451811	VIKTORIYA LOGINOVA	{"phone": "+70341614564"}
0005433180677	36F9B1	6403 966533	EVGENIYA FEDOROVA	{"email": "evgeniyafedorova-091962@postgrespro.ru", "phone": "+70479499845"}
0005433180678	CD684D	7014 013910	LYUDMILA KONDRATEVA	{"phone": "+70872427422"}
0005433180679	796B5A	9802 034194	NIKOLAY PAVLOV	{"email": "pavlov-nikolay061975@postgrespro.ru", "phone": "+70863321226"}
0005433180680	7CA8A0	0468 376970	MARINA ALEKSEEVA	{"phone": "+70977648958"}
0005433180681	7982CD	6314 639291	VLADIMIR ABRAMOV	{"phone": "+70025150662"}
0005433180682	8ACBEF	0465 530382	IVAN ALEKSEEV	{"phone": "+70050340491"}
0005433180683	748BAB	4596 543334	NIKOLAY KUZMIN	{"phone": "+70496574652"}
0005433180684	AC2780	0261 093318	LYUDMILA VOROBEVA	{"email": "lyudmila_vorobeva.1986@postgrespro.ru", "phone": "+70891904562"}
0005433180685	AC2780	3230 255960	YULIYA FEDOROVA	{"phone": "+70562660816"}
0005433180686	AC2780	8637 253551	ALEKSANDR KRASNOV	{"email": "krasnova13021965@postgrespro.ru", "phone": "+70862971381"}
0005433180687	AC55AA	3584 491620	RAFIS EGOROV	{"phone": "+70226458566"}
0005433180688	AC55AA	4771 269176	OLEG SERGEEV	{"phone": "+70968350306"}
0005433180689	AC55AA	8773 047591	ALEKSANDR FOMIN	{"email": "fominaleksandr_16091964@postgrespro.ru", "phone": "+70232523353"}
0005433180690	115D61	4474 505221	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev23081969@postgrespro.ru", "phone": "+70555198173"}
0005433180691	A58AE4	6244 639656	ELVIRA CHERNOVA	{"email": "elvirachernova_1984@postgrespro.ru", "phone": "+70479363190"}
0005433180692	A58AE4	1473 211255	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov.05021962@postgrespro.ru", "phone": "+70363836694"}
0005433180693	6EB967	2229 826130	MAKSIM GORBUNOV	{"phone": "+70208391264"}
0005433180694	94BFEA	9706 645776	SERGEY PETROV	{"phone": "+70805724819"}
0005433180695	94BFEA	1145 159805	VLADIMIR AFANASEV	{"phone": "+70283773057"}
0005433180696	4D50D3	4952 470476	SVYATOSLAV BORISOV	{"email": "svyatoslav_borisov_1961@postgrespro.ru", "phone": "+70242237686"}
0005433180697	4D50D3	6627 517587	ELIZAVETA PETROVA	{"email": "petrova.e011971@postgrespro.ru", "phone": "+70290617293"}
0005433180698	012430	4519 325348	NINA IVANOVA	{"email": "n.ivanova-30061974@postgrespro.ru", "phone": "+70279515423"}
0005433180699	012430	6907 933644	SVETLANA FEDOROVA	{"email": "s_fedorova.1971@postgrespro.ru", "phone": "+70270050570"}
0005433180700	012430	7494 914409	OKSANA SEMENOVA	{"email": "semenova-oksana_121977@postgrespro.ru", "phone": "+70465114871"}
0005433180701	37D7AF	5673 203410	GLEB SERGEEV	{"phone": "+70513150353"}
0005433180702	0DDA1E	1225 450135	OKSANA VOLKOVA	{"email": "ovolkova.1973@postgrespro.ru", "phone": "+70964291511"}
0005433180703	4F3658	6439 759718	GALINA KOZLOVA	{"phone": "+70872859731"}
0005433180704	4F3658	7153 116161	VLADIMIR CHERNOV	{"phone": "+70898635648"}
0005433180705	4671FB	4480 379374	DMITRIY ALEKSEEV	{"phone": "+70205391987"}
0005433180706	4671FB	2891 985555	ALEKSEY KUDRYASHOV	{"phone": "+70346031800"}
0005433180707	4671FB	8289 826417	VASILIY IVANOV	{"phone": "+70111581939"}
0005433180708	4671FB	4806 343364	NINA KUZNECOVA	{"email": "kuznecova-nina-061969@postgrespro.ru", "phone": "+70896774978"}
0005433180709	A62DFD	7627 946876	VLADIMIR SERGEEV	{"phone": "+70313613900"}
0005433180710	0F893B	2070 418077	ANDREY PETROV	{"email": "a-petrov-091962@postgrespro.ru", "phone": "+70054943616"}
0005433180711	862F49	3483 719045	DMITRIY NIKITIN	{"email": "dmitriy.nikitin22021976@postgrespro.ru", "phone": "+70145693520"}
0005433180712	6AC22A	5959 230561	VLADIMIR MATVEEV	{"email": "matveevvladimir_031975@postgrespro.ru", "phone": "+70269771669"}
0005433180713	6AC22A	5031 912091	MARINA KOZLOVA	{"email": "kozlova_marina11071971@postgrespro.ru", "phone": "+70036886640"}
0005433180714	4D10C4	4539 498605	ZULFIYA DANILOVA	{"phone": "+70376272543"}
0005433180715	223947	9628 405463	ELENA AFANASEVA	{"phone": "+70946459936"}
0005433180716	B728AC	4301 714304	ARINA ZHURAVLEVA	{"phone": "+70088073492"}
0005433180717	E826A7	9817 855960	DMITRIY CHERNOV	{"email": "chernovd1968@postgrespro.ru", "phone": "+70310695874"}
0005433180718	66C8FC	5217 092937	TATYANA ISAEVA	{"phone": "+70746199641"}
0005433180719	66C8FC	0059 853699	ROMAN PETROV	{"phone": "+70165792333"}
0005433180720	2745E1	9875 977957	NINA ERMAKOVA	{"email": "ermakovanina.28081969@postgrespro.ru", "phone": "+70667058619"}
0005433180721	2745E1	2161 695704	ANDREY TIMOFEEV	{"email": "timofeev_andrey-1972@postgrespro.ru", "phone": "+70193423096"}
0005433180722	985FF8	7838 900726	ANDREY ALEKSANDROV	{"email": "aleksandrovandrey03051974@postgrespro.ru", "phone": "+70912330723"}
0005433180723	523CF6	4218 364386	TATYANA FROLOVA	{"phone": "+70831801711"}
0005433180724	0D94A9	3442 095126	TATYANA VOLKOVA	{"email": "volkovat-20011981@postgrespro.ru", "phone": "+70018740529"}
0005433180725	0D94A9	4966 173923	YURIY IVANOV	{"phone": "+70683957582"}
0005433180726	518B30	8463 242234	NIKOLAY DAVYDOV	{"phone": "+70839236581"}
0005433180727	518B30	2334 262825	ALEKSANDR KAZAKOV	{"email": "kazakov.a.1968@postgrespro.ru", "phone": "+70575443359"}
0005433180728	467493	8018 503050	ALEKSEY EGOROV	{"phone": "+70969537304"}
0005433180729	467493	8368 223343	KAMIL ROMANOV	{"email": "romanov.kamil-1974@postgrespro.ru", "phone": "+70436441824"}
0005433180730	EC1916	1453 613044	VLADIMIR ZAYCEV	{"email": "zaycev.v-30071972@postgrespro.ru", "phone": "+70009913468"}
0005433180731	673F99	5807 828588	NATALYA KUZNECOVA	{"phone": "+70992319893"}
0005433180732	25A627	0335 116949	LYUBOV MAKSIMOVA	{"phone": "+70318356503"}
0005433180733	25A627	3158 982372	ALEKSEY ANDREEV	{"phone": "+70306433698"}
0005433180734	66F341	2850 815728	NATALYA RYABOVA	{"phone": "+70238011489"}
0005433180735	8260CA	1907 128047	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr-041969@postgrespro.ru", "phone": "+70093086453"}
0005433180736	E59161	9128 718284	MARIYA SERGEEVA	{"phone": "+70410030758"}
0005433180737	7DDC6B	9854 131722	ARTEM IVANOV	{"email": "ivanov.artem.071969@postgrespro.ru", "phone": "+70778930684"}
0005433180738	70F681	6819 324670	VLADISLAV VOLKOV	{"phone": "+70379877093"}
0005433180739	EAA6C3	0020 725370	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.11101964@postgrespro.ru", "phone": "+70739098319"}
0005433180740	EAA6C3	8536 727752	VLADIMIR MOISEEV	{"phone": "+70079319245"}
0005433180741	EAA6C3	5174 540890	DARYA GORBUNOVA	{"phone": "+70691845022"}
0005433180742	3E41C2	8450 146245	YULIYA TROFIMOVA	{"phone": "+70227143465"}
0005433180743	A62D5E	0335 952533	MARINA ANISIMOVA	{"phone": "+70094056965"}
0005433180744	8AB7F1	4726 067137	NIKOLAY KUZNECOV	{"phone": "+70951739079"}
0005433180745	8AB7F1	4547 810602	VLADIMIR KRASNOV	{"email": "krasnovv02011979@postgrespro.ru", "phone": "+70666003916"}
0005433180746	04CA7D	8492 239892	NADEZHDA LAZAREVA	{"email": "lazareva_nadezhda.111976@postgrespro.ru", "phone": "+70302061750"}
0005433180747	04CA7D	8772 871886	OLGA EFIMOVA	{"email": "efimova_o.1967@postgrespro.ru", "phone": "+70019097031"}
0005433180748	C2F696	3278 542875	LIDIYA BELYAEVA	{"email": "belyaeva_lidiya_1976@postgrespro.ru", "phone": "+70371600811"}
0005433180749	272EBC	3919 783727	VLADIMIR SIDOROV	{"email": "v.sidorov1970@postgrespro.ru", "phone": "+70456757452"}
0005433180750	272EBC	0550 713460	SNEZHANA TARASOVA	{"email": "tarasovas_27041969@postgrespro.ru", "phone": "+70533542937"}
0005433180751	D1CD3C	1133 205532	ZINAIDA MAKSIMOVA	{"phone": "+70816186932"}
0005433180752	C3B221	5223 773217	VALENTINA GUSEVA	{"phone": "+70406617084"}
0005433180753	C3B221	8403 284841	NADEZHDA POPOVA	{"email": "n-popova_1975@postgrespro.ru", "phone": "+70493361999"}
0005433180813	48F01E	3962 367112	ARINA KOROLEVA	{"phone": "+70578010334"}
0005433180754	8F69E6	3182 413039	KONSTANTIN MIKHAYLOV	{"email": "mikhaylov_k.04021975@postgrespro.ru", "phone": "+70024895149"}
0005433180755	C0631C	7694 442693	TATYANA DAVYDOVA	{"email": "t-davydova.1962@postgrespro.ru", "phone": "+70488187765"}
0005433180756	2B687B	7743 838434	OLGA KOROLEVA	{"phone": "+70941589830"}
0005433180757	2B687B	4596 665235	NIKOLAY MELNIKOV	{"phone": "+70517389021"}
0005433180758	8DDFD7	1591 049706	ALEKSEY MIKHAYLOV	{"phone": "+70830614688"}
0005433180759	8DDFD7	2951 273543	ELENA KUDRYASHOVA	{"email": "kudryashova_elena_1983@postgrespro.ru", "phone": "+70498717912"}
0005433180760	994636	5730 655066	POLINA GORBUNOVA	{"email": "gorbunova_polina_02081974@postgrespro.ru", "phone": "+70110919469"}
0005433180761	4D0CD9	5914 265976	SERGEY VOLKOV	{"email": "svolkov.041976@postgrespro.ru", "phone": "+70973051926"}
0005433180762	E4B520	4438 696814	DMITRIY KAZAKOV	{"email": "kazakov.dmitriy-01121967@postgrespro.ru", "phone": "+70127454375"}
0005433180763	E4B520	8960 290362	VASILIY MIKHAYLOV	{"email": "vasiliy.mikhaylov.1972@postgrespro.ru", "phone": "+70692344206"}
0005433180764	51995C	6333 108082	OLGA MAKAROVA	{"phone": "+70669653625"}
0005433180765	51995C	2590 688765	ALEKSANDR MELNIKOV	{"phone": "+70703528718"}
0005433180766	A200E1	2700 551808	VLADIMIR SMIRNOV	{"email": "v_smirnov-061962@postgrespro.ru", "phone": "+70352206514"}
0005433180767	2DB589	8205 686471	ALBERT BELOV	{"email": "belov-a-1964@postgrespro.ru", "phone": "+70160741349"}
0005433180768	FEEF02	7213 627709	ALENA BOGDANOVA	{"phone": "+70374205464"}
0005433180770	851934	9766 780194	IRINA GORBUNOVA	{"phone": "+70690166053"}
0005433180771	157F14	8236 693164	EVGENIY OSIPOV	{"phone": "+70979003912"}
0005433180772	157F14	5084 821839	VALENTIN SCHERBAKOV	{"email": "valentin.scherbakov051969@postgrespro.ru", "phone": "+70229562391"}
0005433180773	A833B6	1493 958178	NATALYA PETROVA	{"email": "petrova_natalya.111983@postgrespro.ru", "phone": "+70151712720"}
0005433180774	12AEC1	0665 297703	VLADIMIR ZHUKOV	{"email": "zhukovv-091977@postgrespro.ru", "phone": "+70780326892"}
0005433180775	E55F65	4980 002950	NIKOLAY ILIN	{"email": "ilinn-02101975@postgrespro.ru", "phone": "+70858276630"}
0005433180776	0CD122	7681 106831	ARTUR ANDREEV	{"phone": "+70048593194"}
0005433180777	4C0589	6945 373431	ALEKSANDR KOROLEV	{"email": "korolev-a_13071972@postgrespro.ru", "phone": "+70414665519"}
0005433180778	4C0589	6868 735859	MIKHAIL STEPANOV	{"phone": "+70871864731"}
0005433180779	D4621C	0840 259149	LYUDMILA GUSEVA	{"email": "l-guseva_16071971@postgrespro.ru", "phone": "+70880108693"}
0005433180780	D4621C	0172 501137	GENNADIY SHEVCHENKO	{"email": "g.shevchenko_121973@postgrespro.ru", "phone": "+70318649525"}
0005433180781	84151D	2600 737494	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr.16051967@postgrespro.ru", "phone": "+70580497375"}
0005433180782	A7FA06	0471 211439	TATYANA NESTEROVA	{"email": "nesterova_t-1980@postgrespro.ru", "phone": "+70193020612"}
0005433180783	A7FA06	5363 986530	SERGEY SOKOLOV	{"email": "sokolov.sergey1965@postgrespro.ru", "phone": "+70724581318"}
0005433180784	EF6CF8	8846 388242	OLGA ZAYCEVA	{"email": "ozayceva1964@postgrespro.ru", "phone": "+70340150091"}
0005433180785	37893E	5668 475544	ANNA ZOTOVA	{"phone": "+70932537299"}
0005433180786	37893E	2336 326996	SERGEY FROLOV	{"email": "s.frolov_031969@postgrespro.ru", "phone": "+70165779758"}
0005433180787	78731B	5744 427970	OLGA ABRAMOVA	{"phone": "+70976327782"}
0005433180788	CC4F36	0097 626950	DARYA ZAKHAROVA	{"email": "zakharova.d111978@postgrespro.ru", "phone": "+70650126115"}
0005433180789	3456BD	7873 890041	GENNADIY DMITRIEV	{"email": "g-dmitriev-1974@postgrespro.ru", "phone": "+70848540761"}
0005433180790	DE5C42	6430 513015	ALEKSANDR FROLOV	{"phone": "+70505457673"}
0005433180791	DE5C42	7410 879821	SERGEY SOLOVEV	{"email": "solovev.sergey-101977@postgrespro.ru", "phone": "+70086675197"}
0005433180792	B011D6	1087 757646	VLADIMIR KISELEV	{"phone": "+70124356065"}
0005433180793	9E52B2	7344 656145	OLGA VASILEVA	{"email": "olga_vasileva-26121977@postgrespro.ru", "phone": "+70617949235"}
0005433180794	9E52B2	1783 260683	MARGARITA MAKSIMOVA	{"phone": "+70515887889"}
0005433180795	11D39B	5462 190237	VIKTOR SHEVCHENKO	{"email": "shevchenko-viktor_19041973@postgrespro.ru", "phone": "+70731584455"}
0005433180796	11D39B	8515 857534	IVAN ZAKHAROV	{"phone": "+70399204135"}
0005433180797	D88882	3685 165473	ALEKSANDR MAKAROV	{"email": "a.makarov_27121983@postgrespro.ru", "phone": "+70017795937"}
0005433180798	A256DE	3880 654880	TATYANA KUZNECOVA	{"phone": "+70828276714"}
0005433180799	870BFB	2668 082043	MARINA SEMENOVA	{"email": "semenova.marina1968@postgrespro.ru", "phone": "+70459522616"}
0005433180800	CBD558	4206 791118	DANIIL NAZAROV	{"phone": "+70833764782"}
0005433180801	CBD558	8236 157318	YURIY SOKOLOV	{"email": "yuriy-sokolov.111970@postgrespro.ru", "phone": "+70355483027"}
0005433180802	B3DA2D	5329 037959	GRIGORIY YAKOVLEV	{"phone": "+70586218242"}
0005433180803	C35CCF	1764 912539	MARGARITA BORISOVA	{"email": "borisova_m081965@postgrespro.ru", "phone": "+70429612843"}
0005433180804	AD1386	4356 291040	NINA IVANOVA	{"email": "n-ivanova.081973@postgrespro.ru", "phone": "+70645135326"}
0005433180805	D1A9D8	9914 175615	ALEKSANDRA SCHERBAKOVA	{"phone": "+70699840663"}
0005433180806	D1A9D8	0498 932270	ALEKSEY ALEKSEEV	{"email": "alekseev.a-101980@postgrespro.ru", "phone": "+70493648828"}
0005433180807	D1A9D8	7961 292021	SERGEY BELOV	{"phone": "+70919114369"}
0005433180808	285AD9	8291 801592	ALEKSANDRA VOLKOVA	{"email": "volkovaaleksandra-21061959@postgrespro.ru", "phone": "+70866353866"}
0005433180809	285AD9	1232 501952	MARGARITA AFANASEVA	{"email": "afanaseva_margarita.101968@postgrespro.ru", "phone": "+70200192736"}
0005433180810	43C089	6696 507378	ANDREY TIMOFEEV	{"email": "timofeevandrey.1978@postgrespro.ru", "phone": "+70674488731"}
0005433180811	AF3679	8188 138663	RAISA MIKHAYLOVA	{"email": "mikhaylovaraisa_12041978@postgrespro.ru", "phone": "+70643839965"}
0005433180812	2BDD60	1817 705119	NINA PAVLOVA	{"email": "pavlovan_101961@postgrespro.ru", "phone": "+70062526614"}
0005433180814	111C51	3117 430542	NELLI KRASNOVA	{"phone": "+70215347072"}
0005433180815	E40E21	6273 626176	LYUDMILA FROLOVA	{"phone": "+70830661772"}
0005433180816	B508AB	9996 364318	EVGENIY FROLOV	{"email": "frolove-15021974@postgrespro.ru", "phone": "+70629247180"}
0005433180817	E9F9C0	5105 063289	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-111980@postgrespro.ru", "phone": "+70339558716"}
0005433180818	E9F9C0	1495 433377	OLESYA KOZLOVA	{"email": "kozlova-o-26061967@postgrespro.ru", "phone": "+70311140106"}
0005433180819	998301	5734 406625	MIKHAIL FEDOROV	{"email": "m-fedorov-081978@postgrespro.ru", "phone": "+70897823402"}
0005433180820	0A9BBF	5014 406895	NATALYA VOROBEVA	{"phone": "+70250954779"}
0005433180821	67F3E8	6315 342908	MARINA VOLKOVA	{"phone": "+70388147193"}
0005433180822	865317	6289 428630	OLGA MIKHAYLOVA	{"email": "o_mikhaylova_081976@postgrespro.ru", "phone": "+70891916812"}
0005433180823	865317	1631 023014	LARISA NIKOLAEVA	{"phone": "+70253454584"}
0005433180824	865317	1812 917862	IGOR GORBUNOV	{"email": "igor.gorbunov021981@postgrespro.ru", "phone": "+70729583960"}
0005433180825	BB4214	9754 764350	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev_16121973@postgrespro.ru", "phone": "+70946982412"}
0005433180826	BB4214	3965 617937	ANNA MAKSIMOVA	{"phone": "+70432579202"}
0005433180827	BB4214	9763 777598	SVETLANA KALININA	{"email": "kalinina_s30051968@postgrespro.ru", "phone": "+70074470248"}
0005433180828	DECA41	1580 119359	ELENA FROLOVA	{"phone": "+70863587928"}
0005433180829	004380	6043 714583	SERAFIM DAVYDOV	{"email": "s_davydov.08091962@postgrespro.ru", "phone": "+70256656784"}
0005433180830	A78F36	5955 330959	TATYANA KONDRATEVA	{"phone": "+70007769192"}
0005433180831	FE0286	6068 550992	NINA MATVEEVA	{"email": "matveeva.nina1989@postgrespro.ru", "phone": "+70812508870"}
0005433180832	52AAB5	1858 101922	EVGENIYA NESTEROVA	{"email": "enesterova_1981@postgrespro.ru", "phone": "+70322077613"}
0005433180833	1F18B2	6063 023383	SERGEY FROLOV	{"phone": "+70211007054"}
0005433180834	B19980	4265 925909	IVAN VOROBEV	{"phone": "+70747584521"}
0005433180835	B19980	3378 840618	NADEZHDA FEDOROVA	{"phone": "+70985578319"}
0005433180836	B9B897	7499 120744	ALEKSANDR ANDREEV	{"email": "andreevaleksandr-1978@postgrespro.ru", "phone": "+70095930620"}
0005433180837	B9B897	9281 873462	SERGEY PAVLOV	{"email": "s_pavlov_101976@postgrespro.ru", "phone": "+70684921686"}
0005433180838	D63B58	8332 683528	GALINA SOLOVEVA	{"email": "g.soloveva.1978@postgrespro.ru", "phone": "+70937392060"}
0005433180839	D63B58	3032 516985	VALENTINA AKIMOVA	{"phone": "+70587604425"}
0005433180840	78CECC	2847 705461	OLGA MIKHAYLOVA	{"email": "mikhaylova.o1974@postgrespro.ru", "phone": "+70460675102"}
0005433180841	78CECC	6347 483521	RAISA SEMENOVA	{"email": "semenovar-011978@postgrespro.ru", "phone": "+70052922502"}
0005433180842	96DF7A	0949 877485	TIMOFEY TARASOV	{"email": "tarasov.t-1962@postgrespro.ru", "phone": "+70873310118"}
0005433180843	683428	2372 446740	VALENTINA KUZNECOVA	{"email": "kuznecova_v1969@postgrespro.ru", "phone": "+70817794010"}
0005433180844	683428	2914 962909	NATALYA KUZNECOVA	{"email": "n-kuznecova-1977@postgrespro.ru", "phone": "+70866834020"}
0005433180845	4C6246	8041 314453	LYUBOV ERMAKOVA	{"phone": "+70071676333"}
0005433180846	8F7F3F	8584 489110	VALERIYA KUZNECOVA	{"phone": "+70011149272"}
0005433180847	258E18	6421 300858	ZINAIDA SMIRNOVA	{"phone": "+70912892126"}
0005433180848	53B0A9	8245 772922	ALEKSANDR SIDOROV	{"phone": "+70157700738"}
0005433180849	A1D4A1	7289 990823	ILYA VOROBEV	{"phone": "+70060585757"}
0005433180850	A1D4A1	6234 686874	VLADIMIR ILIN	{"email": "vilin.1970@postgrespro.ru", "phone": "+70053867691"}
0005433180851	B783D9	8469 078304	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr_28021973@postgrespro.ru", "phone": "+70838550358"}
0005433180852	B783D9	3016 689542	ELENA RODIONOVA	{"email": "rodionova.elena-041972@postgrespro.ru", "phone": "+70012302694"}
0005433180853	B783D9	6586 859168	OLEG NIKOLAEV	{"email": "nikolaev.oleg08021963@postgrespro.ru", "phone": "+70052680646"}
0005433180854	804407	8607 220489	PAVEL FROLOV	{"email": "frolov-p-121965@postgrespro.ru", "phone": "+70913036401"}
0005433180855	9AECCA	5389 257053	RIFAT SMIRNOV	{"email": "rifatsmirnov.1967@postgrespro.ru", "phone": "+70076659975"}
0005433180856	9AECCA	1559 506496	IRINA KUZNECOVA	{"phone": "+70515398046"}
0005433180857	697C87	3076 165855	ANDREY SMIRNOV	{"phone": "+70358467931"}
0005433180858	A6B8BE	1607 365709	GALINA NIKOLAEVA	{"phone": "+70449481262"}
0005433180859	8899AF	5132 620753	ANTONINA ZHUKOVA	{"email": "zhukovaa_031961@postgrespro.ru", "phone": "+70591401419"}
0005433180860	E011D0	7484 902852	LILIYA GERASIMOVA	{"email": "gerasimovaliliya041975@postgrespro.ru", "phone": "+70959394645"}
0005433180861	E011D0	2780 294750	ELENA BOGDANOVA	{"email": "elena-bogdanova_20071967@postgrespro.ru", "phone": "+70999684568"}
0005433180862	C32AC5	2220 659832	VENIAMIN KULIKOV	{"email": "kulikov-veniamin1976@postgrespro.ru", "phone": "+70557817196"}
0005433180863	C32AC5	0262 752171	NATALIYA FROLOVA	{"email": "nataliya-frolova.03031973@postgrespro.ru", "phone": "+70384368508"}
0005433180864	08FC45	2671 124953	YULIYA ALEKSEEVA	{"email": "alekseeva.y031976@postgrespro.ru", "phone": "+70226107891"}
0005433180865	08FC45	1142 569193	OLEG SMIRNOV	{"email": "smirnovoleg_1970@postgrespro.ru", "phone": "+70547200306"}
0005433180866	F8AC7B	5561 847900	ARMEN KUZNECOV	{"phone": "+70582440558"}
0005433180867	21E8CA	1031 965185	SVETLANA ZAYCEVA	{"email": "svetlana_zayceva_1972@postgrespro.ru", "phone": "+70156333275"}
0005433180868	21E8CA	8956 665840	EKATERINA MAKAROVA	{"email": "makarova_e.091970@postgrespro.ru", "phone": "+70724748814"}
0005433180869	FE4BF0	4242 215255	SERGEY STEPANOV	{"phone": "+70708282422"}
0005433180870	DBEFCB	3696 868365	ALEKSANDR MAKAROV	{"email": "amakarov-23021982@postgrespro.ru", "phone": "+70981597765"}
0005433180871	DDB687	3674 943719	GEVORG SOROKIN	{"phone": "+70307427037"}
0005433180872	4F8E8A	6830 825908	ALEKSEY KUZMIN	{"phone": "+70953858456"}
0005433180873	4F8E8A	9403 909768	VALENTINA LOGINOVA	{"phone": "+70002691137"}
0005433180874	E02E63	3853 115526	OLGA SEMENOVA	{"email": "osemenova-111973@postgrespro.ru", "phone": "+70061896060"}
0005433180875	59EA2C	1403 013476	KARINA BARANOVA	{"phone": "+70103206061"}
0005433180876	748426	7247 685285	ANATOLIY BORISOV	{"email": "borisov-a_111969@postgrespro.ru", "phone": "+70491920117"}
0005433180877	94E112	7066 043926	NIKOLAY NIKITIN	{"phone": "+70728835163"}
0005433180878	2B2410	4396 256262	VERA KUZMINA	{"phone": "+70574884174"}
0005433180879	BE7DAB	1433 684226	ZOYA MIRONOVA	{"phone": "+70346604596"}
0005433180880	3893D1	1233 775026	DENIS ALEKSANDROV	{"email": "daleksandrov-11021985@postgrespro.ru", "phone": "+70759581969"}
0005433180881	179C9F	7544 379226	ELENA GORBUNOVA	{"email": "elena-gorbunova_1977@postgrespro.ru", "phone": "+70895687803"}
0005433180882	179C9F	2500 963037	VALERIY GORBUNOV	{"email": "v.gorbunov-1969@postgrespro.ru", "phone": "+70831332713"}
0005433180883	CD8545	3146 239269	SVETLANA KUZNECOVA	{"phone": "+70564417423"}
0005433180884	114C61	0391 599338	LILIYA BARANOVA	{"email": "liliya_baranova_1973@postgrespro.ru", "phone": "+70464140991"}
0005433180885	EBC3EB	9372 967426	ALEKSEY MIRONOV	{"email": "a_mironov-20081977@postgrespro.ru", "phone": "+70526452920"}
0005433180886	F0CE4F	5325 164906	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1971@postgrespro.ru", "phone": "+70674030507"}
0005433180887	10FFFD	6363 732689	ANNA FILIPPOVA	{"phone": "+70074878347"}
0005433180888	150AE1	6098 222091	GENNADIY FILIPPOV	{"email": "filippov.gennadiy-24021957@postgrespro.ru", "phone": "+70545084335"}
0005433180889	8B545B	5476 494878	YURIY FEDOTOV	{"email": "fedotov.y1979@postgrespro.ru", "phone": "+70383644523"}
0005433180890	30BEB4	5508 150820	MARGARITA ABRAMOVA	{"email": "m-abramova.071960@postgrespro.ru", "phone": "+70747186779"}
0005433180891	E10A77	1965 005528	ARTEM MOROZOV	{"phone": "+70117937946"}
0005433180892	517B9C	0275 709861	ALBINA RODIONOVA	{"email": "a_rodionova26081974@postgrespro.ru", "phone": "+70478440607"}
0005433180893	1F0645	1785 581024	PAVEL MAKAROV	{"email": "makarov_pavel-121973@postgrespro.ru", "phone": "+70835121023"}
0005433180894	1F0645	7565 361367	NATALYA PETROVA	{"email": "petrova-natalya021983@postgrespro.ru", "phone": "+70332697913"}
0005433180895	0A802B	0227 882454	SERGEY DENISOV	{"email": "denisovsergey14041975@postgrespro.ru", "phone": "+70120223956"}
0005433180896	0A802B	1974 835712	ALEKSEY ZAKHAROV	{"phone": "+70854915948"}
0005433180897	3CC153	3637 367612	ELENA YAKOVLEVA	{"email": "elena.yakovleva031982@postgrespro.ru", "phone": "+70925152564"}
0005433180898	14D093	8257 862609	VLADIMIR ORLOV	{"phone": "+70023304823"}
0005433180899	14D093	5153 610791	ANNA IVANOVA	{"email": "ivanovaanna-09071990@postgrespro.ru", "phone": "+70291003899"}
0005433180900	39A330	3808 432485	ANASTASIYA FEDOROVA	{"phone": "+70349263396"}
0005433180901	39A330	0939 850777	ALEKSANDR ROMANOV	{"phone": "+70879201098"}
0005433180902	DD74B3	8002 266247	ILYA OSIPOV	{"email": "iosipov.061978@postgrespro.ru", "phone": "+70367166492"}
0005433180903	03EF8B	6915 657638	ANDREY DENISOV	{"email": "denisov-andrey-1966@postgrespro.ru", "phone": "+70842838717"}
0005433180904	C58CDF	4699 951596	KONSTANTIN NIKOLAEV	{"email": "k.nikolaev-1979@postgrespro.ru", "phone": "+70155037492"}
0005433180905	6CA8E6	9481 321442	KSENIYA STEPANOVA	{"email": "stepanovakseniya_1974@postgrespro.ru", "phone": "+70620253890"}
0005433180906	AF1FF0	1936 728388	MAKSIM KUZMIN	{"phone": "+70255015916"}
0005433180907	10CEB7	0649 382510	VYACHESLAV IVANOV	{"phone": "+70185883966"}
0005433180908	10CEB7	9224 696227	NIKOLAY FILIPPOV	{"phone": "+70488073066"}
0005433180909	C909AD	3639 601380	PAVEL FROLOV	{"email": "pavelfrolov-13031959@postgrespro.ru", "phone": "+70144706360"}
0005433180910	B3D3A6	8822 506097	TAISIYA MOISEEVA	{"phone": "+70178857678"}
0005433180911	676EF0	6778 005002	VALENTINA GERASIMOVA	{"phone": "+70353156787"}
0005433180912	676EF0	3459 226350	IRINA SMIRNOVA	{"email": "irina_smirnova.1972@postgrespro.ru", "phone": "+70491146635"}
0005433180913	78A3DE	3899 945865	LEONID IVANOV	{"phone": "+70887771952"}
0005433180914	78A3DE	4624 477433	VALERIY KRASNOV	{"email": "krasnov.v101967@postgrespro.ru", "phone": "+70416817726"}
0005433180915	FAE430	4247 895220	ALEKSANDR IVANOV	{"email": "a_ivanov_1961@postgrespro.ru", "phone": "+70372052024"}
0005433180916	9B33CC	5167 800933	ANASTASIYA EGOROVA	{"phone": "+70338113270"}
0005433180917	32469F	2673 210025	LYUBOV ZAYCEVA	{"email": "l-zayceva021967@postgrespro.ru", "phone": "+70463488105"}
0005433180918	32469F	2902 015612	ELENA EGOROVA	{"email": "e_egorova.1965@postgrespro.ru", "phone": "+70984925171"}
0005433180919	322FC5	9287 565140	VLADIMIR VOLKOV	{"phone": "+70210213230"}
0005433180920	4954FE	8822 790740	ALEKSANDR IVANOV	{"phone": "+70962598617"}
0005433180921	FDC157	8483 770983	ALEKSANDRA MOISEEVA	{"email": "aleksandra_moiseeva1974@postgrespro.ru", "phone": "+70619655296"}
0005433180922	E02329	1348 896849	SERGEY MARTYNOV	{"email": "s_martynov011970@postgrespro.ru", "phone": "+70973724530"}
0005433180923	365CF6	5872 790417	KIRILL FEDOROV	{"phone": "+70947548258"}
0005433180924	CD0286	8418 887044	VALENTINA GUSEVA	{"email": "vguseva-17071972@postgrespro.ru", "phone": "+70166792644"}
0005433180925	5C9F96	4326 015556	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.aleksandr15051973@postgrespro.ru", "phone": "+70277867039"}
0005433180926	7D90D7	7307 150731	VYACHESLAV VASILEV	{"phone": "+70611376289"}
0005433180927	ACF2CD	5888 276987	ARTEM KOROLEV	{"phone": "+70260344090"}
0005433180928	46EAB5	8873 522532	PAVEL IVANOV	{"phone": "+70844689014"}
0005433180929	46EAB5	6922 229264	LIDIYA AKIMOVA	{"email": "lidiyaakimova_021971@postgrespro.ru", "phone": "+70173162210"}
0005433180930	46EAB5	8031 449678	VADIM SERGEEV	{"email": "sergeevv.30041959@postgrespro.ru", "phone": "+70807731375"}
0005433180931	7DA768	3505 797600	TAMARA FILATOVA	{"phone": "+70499742677"}
0005433180932	7DA768	7164 841112	SERGEY POPOV	{"phone": "+70396268030"}
0005433180933	B3E5EF	1411 093845	ELIZAVETA KUZNECOVA	{"phone": "+70140317936"}
0005433180934	1AE71E	4835 682628	ANATOLIY SERGEEV	{"phone": "+70504203470"}
0005433180935	1AE71E	8867 447906	VLADIMIR KONOVALOV	{"email": "konovalov.v.1968@postgrespro.ru", "phone": "+70731898942"}
0005433180936	6F6992	2347 068866	ALEKSANDRA KONDRATEVA	{"email": "kondrateva_a_1990@postgrespro.ru", "phone": "+70366887998"}
0005433180937	6F6992	9774 519836	ELENA NAZAROVA	{"email": "elenanazarova.1970@postgrespro.ru", "phone": "+70488046729"}
0005433180938	3E9F2D	6458 853318	ZOYA CHERNOVA	{"phone": "+70763392638"}
0005433180939	A59EBB	1381 223356	NINA FOMINA	{"email": "fomina.n.20101969@postgrespro.ru", "phone": "+70921242336"}
0005433180940	A59EBB	8365 811113	VALERIY FROLOV	{"email": "valeriy-frolov.22021982@postgrespro.ru", "phone": "+70734668477"}
0005433180941	9F6579	8646 269495	YURIY ANDREEV	{"email": "andreev_y_051973@postgrespro.ru", "phone": "+70133987622"}
0005433180942	8A2C5A	8253 617577	EKATERINA KOROLEVA	{"phone": "+70782194027"}
0005433180943	3193A6	3644 831576	VYACHESLAV BARANOV	{"email": "v_baranov23101968@postgrespro.ru", "phone": "+70043576363"}
0005433180944	2E29F7	4899 186844	ALEKSEY BELOV	{"email": "belovaleksey111969@postgrespro.ru", "phone": "+70793056313"}
0005433180945	5BB97E	1657 767297	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr111979@postgrespro.ru", "phone": "+70918659663"}
0005433180946	5BB97E	9880 897362	ALEKSANDR SMIRNOV	{"email": "smirnov.a-071975@postgrespro.ru", "phone": "+70407335364"}
0005433180947	578735	3057 204248	TATYANA MAKSIMOVA	{"email": "tatyana_maksimova-091972@postgrespro.ru", "phone": "+70038643234"}
0005433180948	4C1BED	0755 291769	ARTEM TIKHONOV	{"email": "tikhonov-artem_111971@postgrespro.ru", "phone": "+70306494256"}
0005433180949	4C1BED	4907 657204	VLADIMIR FROLOV	{"email": "frolov.vladimir_1983@postgrespro.ru", "phone": "+70358211690"}
0005433180950	316847	4089 440753	OLGA POLYAKOVA	{"phone": "+70899416369"}
0005433180951	FD1592	1418 314045	NADEZHDA SERGEEVA	{"phone": "+70652649576"}
0005433180952	60D31C	6687 860905	ALEKSANDR SHEVCHENKO	{"email": "aleksandr-shevchenko_1961@postgrespro.ru", "phone": "+70049752659"}
0005433180953	60D31C	7865 111459	ANNA ANDREEVA	{"email": "andreeva.a.17121984@postgrespro.ru", "phone": "+70801991449"}
0005433180954	32B2C0	7916 915035	ROZA NIKOLAEVA	{"phone": "+70241012204"}
0005433180955	DE393C	2178 102353	IGOR SMIRNOV	{"email": "smirnov-igor-011980@postgrespro.ru", "phone": "+70347394660"}
0005433180956	C5AB58	2197 565990	VIKTOR ISAEV	{"phone": "+70746092677"}
0005433180957	238CB1	4943 146776	PAVEL MIRONOV	{"email": "mironov_pavel1973@postgrespro.ru", "phone": "+70222232878"}
0005433180958	A6DE6A	8366 710835	EKATERINA VASILEVA	{"phone": "+70809176999"}
0005433180959	A6DE6A	8265 753199	ELENA DENISOVA	{"email": "denisova.e_26011984@postgrespro.ru", "phone": "+70386607761"}
0005433180960	F5ED7A	3280 098753	GENNADIY SOKOLOV	{"email": "g_sokolov-051976@postgrespro.ru", "phone": "+70381356465"}
0005433180961	21BCAE	9731 970440	KONSTANTIN KUZNECOV	{"phone": "+70720277911"}
0005433180962	10F771	8284 258563	YURIY GERASIMOV	{"email": "gerasimov_y.121965@postgrespro.ru", "phone": "+70671891095"}
0005433180963	10F771	6286 859682	SVETLANA BELOVA	{"phone": "+70891850798"}
0005433180964	FD4F16	9451 986166	ANNA SIDOROVA	{"email": "asidorova.24021973@postgrespro.ru", "phone": "+70410984955"}
0005433180965	3F5B6D	9258 616413	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey.20091973@postgrespro.ru", "phone": "+70318046228"}
0005433180966	F987C9	2619 446794	VALERIY KOROLEV	{"email": "korolev_v-031975@postgrespro.ru", "phone": "+70507952963"}
0005433180967	F987C9	2389 749487	ALEKSANDR DENISOV	{"phone": "+70822422270"}
0005433180968	B200DC	9322 679835	NADEZHDA ORLOVA	{"phone": "+70734525340"}
0005433180969	B200DC	7568 803181	IVAN FOMIN	{"email": "i_fomin-1961@postgrespro.ru", "phone": "+70228525419"}
0005433180970	F070E8	3383 753788	DARYA PETROVA	{"email": "dpetrova.1967@postgrespro.ru", "phone": "+70456121692"}
0005433180971	F070E8	5133 077847	OLGA SERGEEVA	{"email": "o-sergeeva.031976@postgrespro.ru", "phone": "+70320589928"}
0005433180972	B7B678	1233 901272	VYACHESLAV SIDOROV	{"email": "sidorov-vyacheslav1978@postgrespro.ru", "phone": "+70567575436"}
0005433180973	DAA699	5864 741284	EGOR ZAYCEV	{"email": "e-zaycev_1978@postgrespro.ru", "phone": "+70224393000"}
0005433180974	DAA699	0903 244672	VITALIY FILIPPOV	{"email": "filippov.v_061982@postgrespro.ru", "phone": "+70127972966"}
0005433180975	D524A8	3356 009551	VASILIY PETROV	{"phone": "+70425016244"}
0005433180976	D524A8	4838 669956	ALEKSANDR NAZAROV	{"email": "nazarov.a.081975@postgrespro.ru", "phone": "+70055161415"}
0005433180977	AAD532	0858 844122	DMITRIY KRASNOV	{"phone": "+70943437068"}
0005433180978	0F183E	7349 075443	LIDIYA ISAEVA	{"email": "isaeva-lidiya_11051965@postgrespro.ru", "phone": "+70361707319"}
0005433180979	0F183E	8070 207660	GALINA BOGDANOVA	{"phone": "+70893797627"}
0005433180980	FE9C6D	5937 716361	NATALYA ISAEVA	{"phone": "+70438871053"}
0005433180981	107969	3021 264759	ELENA FEDOROVA	{"email": "elena-fedorova20051974@postgrespro.ru", "phone": "+70454982387"}
0005433180982	525399	5781 374006	VLADIMIR GORBUNOV	{"email": "vladimir_gorbunov091974@postgrespro.ru", "phone": "+70209247210"}
0005433180983	17B096	5836 918176	PETR BARANOV	{"email": "petrbaranov.17091978@postgrespro.ru", "phone": "+70616130392"}
0005433180984	17B096	9202 821191	DANIIL IVANOV	{"email": "daniil.ivanov.031982@postgrespro.ru", "phone": "+70243077332"}
0005433180985	9AF544	7884 004002	NELLYA NESTEROVA	{"email": "nesterova_nellya.1975@postgrespro.ru", "phone": "+70426226017"}
0005433180986	869535	0516 853312	DANILA NIKOLAEV	{"phone": "+70933278724"}
0005433180987	292AE0	6813 282037	VITALIY BORISOV	{"email": "v_borisov-21111968@postgrespro.ru", "phone": "+70942540389"}
0005433180988	63298C	3544 821300	IRINA KUZMINA	{"phone": "+70887954807"}
0005433180989	63298C	1122 733468	MAKSIM PETROV	{"phone": "+70071814973"}
0005433181161	F1E6B8	9670 306885	VLADIMIR ZHURAVLEV	{"phone": "+70591197839"}
0005433180990	BCFEAD	9167 819412	GALINA ISAEVA	{"email": "galina-isaeva_09081972@postgrespro.ru", "phone": "+70115100787"}
0005433180991	BCFEAD	8443 431045	NADEZHDA MIRONOVA	{"phone": "+70540543321"}
0005433180992	73C998	6780 046623	PAVEL SERGEEV	{"email": "pavel_sergeev_15021950@postgrespro.ru", "phone": "+70535482674"}
0005433180993	73C998	4946 748179	ALEKSANDR MOISEEV	{"email": "moiseev_a1978@postgrespro.ru", "phone": "+70263341186"}
0005433180994	911E1E	3642 015812	VLADIMIR PAVLOV	{"email": "vpavlov1968@postgrespro.ru", "phone": "+70333022084"}
0005433180995	AD0A81	4306 896198	ELENA AKIMOVA	{"email": "e.akimova.111975@postgrespro.ru", "phone": "+70401565471"}
0005433180996	AD0A81	5488 841922	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov09021970@postgrespro.ru", "phone": "+70472262022"}
0005433180997	53CE5A	1923 880312	MARGARITA NIKIFOROVA	{"phone": "+70445082757"}
0005433180998	53CE5A	2985 633993	ANDREY PAVLOV	{"phone": "+70977099900"}
0005433180999	20ED3F	6247 821873	STANISLAV KUZNECOV	{"email": "kuznecov_stanislav-031968@postgrespro.ru", "phone": "+70069917866"}
0005433181000	91CA0E	6937 444158	MARIYA ANTONOVA	{"phone": "+70596846985"}
0005433181001	349E22	1620 412050	SERGEY MOISEEV	{"email": "moiseev-s_111970@postgrespro.ru", "phone": "+70583551394"}
0005433181002	75D5A8	3505 747357	FARIT ANDREEV	{"email": "andreev.f.04071964@postgrespro.ru", "phone": "+70554145694"}
0005433181003	75D5A8	9544 671123	DENIS ALEKSEEV	{"phone": "+70224148152"}
0005433181004	FC9A3D	7914 559146	VALENTINA VOLKOVA	{"email": "volkovavalentina-09051968@postgrespro.ru", "phone": "+70826092483"}
0005433181005	FC9A3D	8159 230499	GULNARA PAVLOVA	{"phone": "+70362442049"}
0005433181006	224A7E	2356 713261	IGOR ZHURAVLEV	{"email": "i.zhuravlev-1971@postgrespro.ru", "phone": "+70447460053"}
0005433181007	8593C0	1086 079878	ELIZAVETA LEBEDEVA	{"phone": "+70774252349"}
0005433181008	BB999C	1265 119970	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov_1969@postgrespro.ru", "phone": "+70201440117"}
0005433181009	BB999C	2981 931680	VLADIMIR MAKSIMOV	{"email": "maksimovv.051962@postgrespro.ru", "phone": "+70920270059"}
0005433181010	BB999C	5196 028796	NATALYA KONOVALOVA	{"phone": "+70900081983"}
0005433181011	269FC4	6334 550765	ALEKSANDR MAKAROV	{"email": "a-makarov-041980@postgrespro.ru", "phone": "+70257841916"}
0005433181012	5AE4F1	3672 946465	VADIM SERGEEV	{"phone": "+70573533362"}
0005433181013	5AE4F1	6219 327766	EKATERINA MAKSIMOVA	{"email": "maksimova.ekaterina_12071963@postgrespro.ru", "phone": "+70561940861"}
0005433181014	8978F6	1132 326857	PAVEL FROLOV	{"email": "pfrolov1979@postgrespro.ru", "phone": "+70346251670"}
0005433181015	D67D36	1204 225291	YULIYA BELOVA	{"phone": "+70288586291"}
0005433181016	D67D36	9152 533860	YULIYA SOROKINA	{"email": "sorokinay_1968@postgrespro.ru", "phone": "+70785015285"}
0005433181017	2B6781	0950 382227	ANDREY VOLKOV	{"email": "andrey_volkov.15111971@postgrespro.ru", "phone": "+70847011031"}
0005433181018	C4ECB8	5570 755164	MARIYA KONDRATEVA	{"email": "kondrateva_mariya22101967@postgrespro.ru", "phone": "+70575058471"}
0005433181019	C4ECB8	0616 901460	IRINA NIKITINA	{"phone": "+70917587480"}
0005433181020	47B336	4298 396876	IGOR FOMIN	{"email": "igor_fomin_041977@postgrespro.ru", "phone": "+70323263141"}
0005433181021	4966B2	2278 566472	ALEKSEY DMITRIEV	{"email": "dmitriev-a1969@postgrespro.ru", "phone": "+70346610449"}
0005433181022	285F5F	1838 116197	NADEZHDA PAVLOVA	{"email": "pavlova-n021973@postgrespro.ru", "phone": "+70687631887"}
0005433181023	A7FACA	4801 968481	ROMAN POPOV	{"phone": "+70644075640"}
0005433181024	1FE6B7	5356 049016	SERGEY VASILEV	{"phone": "+70286748555"}
0005433181025	918FAA	1943 748040	GENNADIY FILIPPOV	{"email": "g-filippov.20121974@postgrespro.ru", "phone": "+70488002272"}
0005433181026	918FAA	4727 242816	EKATERINA POLYAKOVA	{"email": "polyakova_e.1977@postgrespro.ru", "phone": "+70397700162"}
0005433181027	D7C859	5308 320290	GRIGORIY ANDREEV	{"phone": "+70125633230"}
0005433181028	D7C859	9072 759408	ELENA SMIRNOVA	{"phone": "+70410496411"}
0005433181029	D7C859	9257 155281	EKATERINA KULIKOVA	{"phone": "+70898216650"}
0005433181030	202DDE	9198 450352	VERA KOROLEVA	{"email": "koroleva-vera_13111976@postgrespro.ru", "phone": "+70914160710"}
0005433181031	202DDE	6035 334728	NINA ILINA	{"email": "ilina-n_041968@postgrespro.ru", "phone": "+70025041723"}
0005433181032	2DFFC3	0636 872461	MAKAR FEDOROV	{"email": "fedorov-makar.071964@postgrespro.ru", "phone": "+70139356859"}
0005433181033	4DE8F4	9292 244236	ANDREY MIKHAYLOV	{"phone": "+70241827462"}
0005433181034	4DE8F4	2682 259698	ANNA CHERNOVA	{"phone": "+70531994717"}
0005433181035	621FC3	9571 758106	TATYANA ZHUKOVA	{"email": "t-zhukova1975@postgrespro.ru", "phone": "+70315739448"}
0005433181036	7D2494	5068 943303	ALEKSEY DENISOV	{"email": "aleksey_denisov121970@postgrespro.ru", "phone": "+70838927368"}
0005433181037	7D2494	7502 363910	TATYANA NESTEROVA	{"email": "t_nesterova-23011967@postgrespro.ru", "phone": "+70403165658"}
0005433181038	193E1F	0431 669274	GRIGORIY MEDVEDEV	{"email": "medvedev.grigoriy.061979@postgrespro.ru", "phone": "+70169137201"}
0005433181039	193E1F	2714 257769	ANTONINA KUZNECOVA	{"phone": "+70506278719"}
0005433181040	DAD1C4	8192 827875	ZOYA MOROZOVA	{"email": "morozovazoya-051977@postgrespro.ru", "phone": "+70678296807"}
0005433181041	DAD1C4	3509 861676	ANASTASIYA ZAKHAROVA	{"email": "zakharova-anastasiya-27061982@postgrespro.ru", "phone": "+70233666512"}
0005433181042	F22C23	0310 351454	RADIK GERASIMOV	{"phone": "+70358513216"}
0005433181043	202D4A	9370 116958	DARYA GORBUNOVA	{"phone": "+70107048222"}
0005433181044	ADA8D7	0658 105500	ALINA LEBEDEVA	{"phone": "+70127402172"}
0005433181045	ADA8D7	2819 763136	ILNUR YAKOVLEV	{"email": "ilnuryakovlev.23061974@postgrespro.ru", "phone": "+70733801163"}
0005433181046	A7E34D	6125 219125	DANIIL KONOVALOV	{"email": "d-konovalov111966@postgrespro.ru", "phone": "+70738869100"}
0005433181047	A7E34D	7860 514576	TAMARA KONDRATEVA	{"phone": "+70785570486"}
0005433181048	484AA5	5347 870398	LYUBOV GORBUNOVA	{"email": "lyubov-gorbunova-19091982@postgrespro.ru", "phone": "+70609848992"}
0005433181049	1A0151	2513 983757	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina081976@postgrespro.ru", "phone": "+70585708211"}
0005433181050	91D111	8621 503544	PAVEL PETROV	{"email": "petrov-p_1981@postgrespro.ru", "phone": "+70968986874"}
0005433181051	D0BA36	1002 775901	VLADIMIR ZAYCEV	{"phone": "+70523396062"}
0005433181052	D0BA36	6220 911834	LYUBOV POTAPOVA	{"email": "potapova-lyubov.121949@postgrespro.ru", "phone": "+70371754402"}
0005433181053	9D65CA	2702 238732	YULIYA DMITRIEVA	{"email": "dmitrieva_y-1976@postgrespro.ru", "phone": "+70679452476"}
0005433181054	D3D5FD	3707 321886	MIKHAIL SAVELEV	{"email": "mikhail.savelev.031975@postgrespro.ru", "phone": "+70698285470"}
0005433181055	47290E	6642 864296	LIDIYA KUZMINA	{"email": "kuzmina_lidiya_11041963@postgrespro.ru", "phone": "+70599891826"}
0005433181056	5C22FE	0643 975891	VALERIYA ZHURAVLEVA	{"email": "valeriya.zhuravleva.13041969@postgrespro.ru", "phone": "+70608195823"}
0005433181057	F0DB70	7344 729406	ALEKSANDRA MOROZOVA	{"email": "a-morozova-041966@postgrespro.ru", "phone": "+70068663160"}
0005433181058	F0DB70	9494 564807	EVGENIY IVANOV	{"email": "e_ivanov.23121967@postgrespro.ru", "phone": "+70425884511"}
0005433181059	A73E53	9147 541913	ALEKSANDR FOMIN	{"email": "fominaleksandr-05061975@postgrespro.ru", "phone": "+70817296082"}
0005433181060	861541	7215 315788	OKSANA GRISHINA	{"email": "ogrishina-041967@postgrespro.ru", "phone": "+70921861632"}
0005433181061	861541	9544 156408	VALENTIN KUZNECOV	{"phone": "+70218013101"}
0005433181062	33A836	5512 466683	PAVEL KULIKOV	{"phone": "+70306204838"}
0005433181063	33A836	3589 378161	ALEKSEY DENISOV	{"email": "denisov-aleksey.21111966@postgrespro.ru", "phone": "+70994067970"}
0005433181064	2434C5	5557 197082	SVETLANA KUZNECOVA	{"email": "kuznecova_s.041971@postgrespro.ru", "phone": "+70640019136"}
0005433181065	2AC8CE	0871 551079	NINA ABRAMOVA	{"email": "abramovan14061972@postgrespro.ru", "phone": "+70276786660"}
0005433181066	EA5455	4320 081469	IGOR YAKOVLEV	{"email": "igor_yakovlev.121972@postgrespro.ru", "phone": "+70529632052"}
0005433181067	A58585	4598 336058	NATALYA TARASOVA	{"email": "natalya-tarasova-11031971@postgrespro.ru", "phone": "+70563655264"}
0005433181068	A58585	5932 141177	YURIY SOROKIN	{"email": "yuriysorokin-30051978@postgrespro.ru", "phone": "+70586557020"}
0005433181069	26AB5B	9671 117392	SERGEY FROLOV	{"phone": "+70042662587"}
0005433181070	26AB5B	8880 103820	OLESYA SIDOROVA	{"email": "osidorova-121972@postgrespro.ru", "phone": "+70425071402"}
0005433181071	A19D50	3997 198905	IGOR FILIPPOV	{"phone": "+70516152054"}
0005433181072	426C68	5371 206550	ALEKSANDR MIRONOV	{"email": "a_mironov06031970@postgrespro.ru", "phone": "+70032428913"}
0005433181073	1A1F8E	6284 868753	EKATERINA FOMINA	{"phone": "+70249159341"}
0005433181074	1A1F8E	3926 193162	VASILIY DMITRIEV	{"email": "dmitrievv10011976@postgrespro.ru", "phone": "+70839549347"}
0005433181075	71282E	2227 100543	PETR IVANOV	{"email": "ivanov.petr-1970@postgrespro.ru", "phone": "+70184950555"}
0005433181076	2AA671	8741 819498	ANATOLIY VOROBEV	{"email": "a-vorobev061973@postgrespro.ru", "phone": "+70083900462"}
0005433181077	2AA671	7060 201571	ALEKSANDR NIKITIN	{"phone": "+70071687529"}
0005433181078	F96CF2	0549 824936	VLADIMIR BORISOV	{"email": "vladimir_borisov.041981@postgrespro.ru", "phone": "+70587001912"}
0005433181079	3E996B	3638 311654	IRINA KAZAKOVA	{"phone": "+70702578729"}
0005433181080	5ADC28	2678 567014	VLADIMIR SCHERBAKOV	{"phone": "+70825319231"}
0005433181081	801438	6773 434561	TATYANA IVANOVA	{"email": "t-ivanova-18011970@postgrespro.ru", "phone": "+70824244928"}
0005433181082	801438	5628 486457	ALEKSEY ALEKSEEV	{"email": "alekseeva.04021959@postgrespro.ru", "phone": "+70942192365"}
0005433181083	E45A31	1765 671641	ILGIZ NIKOLAEV	{"phone": "+70216891017"}
0005433181084	A86AD9	7738 805411	ALEKSEY ZAKHAROV	{"email": "a-zakharov-021977@postgrespro.ru", "phone": "+70582370053"}
0005433181085	F93E00	4986 899820	OLESYA MIRONOVA	{"phone": "+70159018065"}
0005433181086	F93E00	1450 263452	EGOR KUZNECOV	{"email": "kuznecov.egor-101979@postgrespro.ru", "phone": "+70365774905"}
0005433181087	EE3613	1386 517872	SERGEY FEDOTOV	{"phone": "+70030755294"}
0005433181088	B7ED4B	2877 570719	IGOR SHEVCHENKO	{"phone": "+70309007207"}
0005433181089	8BE219	5479 706346	ASKAR ALEKSANDROV	{"email": "aleksandrovaskar.051980@postgrespro.ru", "phone": "+70980057232"}
0005433181090	F179B1	0335 010873	PETR ZAKHAROV	{"phone": "+70063528500"}
0005433181091	F179B1	3092 423529	YURIY PETROV	{"email": "y.petrov-06081981@postgrespro.ru", "phone": "+70747218101"}
0005433181092	97DDBB	4626 627771	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov.091965@postgrespro.ru", "phone": "+70710586254"}
0005433181093	97DDBB	6823 222401	NATALYA KUZNECOVA	{"email": "natalya_kuznecova_051973@postgrespro.ru", "phone": "+70915598931"}
0005433181094	3D94CC	4323 088375	MAKSIM DAVYDOV	{"email": "maksim_davydov.011981@postgrespro.ru", "phone": "+70620639336"}
0005433181095	E97C47	8086 834569	VALERIYA RODIONOVA	{"phone": "+70150307483"}
0005433181096	3343F3	8223 253535	ROMAN DAVYDOV	{"email": "roman.davydov-1972@postgrespro.ru", "phone": "+70396843310"}
0005433181097	3343F3	3818 416181	ELENA KARPOVA	{"email": "karpovae121976@postgrespro.ru", "phone": "+70381523864"}
0005433181098	96A438	7472 478950	ROMAN STEPANOV	{"email": "stepanov.r-071968@postgrespro.ru", "phone": "+70850619159"}
0005433181099	0F58A2	7789 231964	GALINA KOROLEVA	{"email": "korolevag_06061961@postgrespro.ru", "phone": "+70270215979"}
0005433181100	135736	1514 937829	ROMAN BARANOV	{"email": "baranov.r-1972@postgrespro.ru", "phone": "+70190313079"}
0005433181101	E9F84C	6247 301380	MARIYA SOKOLOVA	{"email": "sokolova.m_06101972@postgrespro.ru", "phone": "+70528617364"}
0005433181102	C14AD3	6665 806601	VALENTINA FROLOVA	{"phone": "+70298754769"}
0005433181103	C14AD3	0033 988769	ANDREY CHERNOV	{"phone": "+70121763379"}
0005433181104	76D8B1	1600 305496	TIMUR KOROLEV	{"email": "timurkorolev.1967@postgrespro.ru", "phone": "+70227819935"}
0005433181105	76D8B1	5542 273655	EDUARD GRIGOREV	{"phone": "+70736822007"}
0005433181106	76D8B1	3978 633174	LARISA SAVELEVA	{"email": "saveleva-l031971@postgrespro.ru", "phone": "+70478966626"}
0005433181107	164A9E	8250 244738	SERGEY NIKOLAEV	{"email": "snikolaev121959@postgrespro.ru", "phone": "+70015343965"}
0005433181108	164A9E	3238 614202	OLEG YAKOVLEV	{"email": "yakovlev-o_1959@postgrespro.ru", "phone": "+70218075588"}
0005433181109	24F37D	2547 704816	GALINA KUZMINA	{"phone": "+70876557278"}
0005433181110	24F37D	1690 406583	EDUARD IVANOV	{"email": "e.ivanov_1960@postgrespro.ru", "phone": "+70530182241"}
0005433181111	24F37D	0867 548735	OLGA KARPOVA	{"phone": "+70425615167"}
0005433181112	47BDB1	3453 460957	MATVEY VLASOV	{"email": "matvey-vlasov.11051979@postgrespro.ru", "phone": "+70765883682"}
0005433181113	FE1A96	3673 292401	RAISA EFREMOVA	{"email": "r-efremova-1983@postgrespro.ru", "phone": "+70267960593"}
0005433181114	500285	1386 169946	DENIS NOVIKOV	{"email": "novikovdenis031971@postgrespro.ru", "phone": "+70820215437"}
0005433181115	240BFA	5001 437321	ELENA BORISOVA	{"phone": "+70061637317"}
0005433181116	240BFA	2017 124094	MARINA KUZMINA	{"email": "kuzmina_marina11011971@postgrespro.ru", "phone": "+70437250017"}
0005433181117	8DCF6C	8816 159612	VLADIMIR TARASOV	{"phone": "+70729108790"}
0005433181118	8DCF6C	0500 858727	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov_011975@postgrespro.ru", "phone": "+70100940897"}
0005433181119	8DCF6C	7323 014600	TAMARA KOMAROVA	{"phone": "+70106652874"}
0005433181120	2FA708	8887 965930	DANILA POPOV	{"email": "popov-danila_091975@postgrespro.ru", "phone": "+70909885269"}
0005433181121	CA8313	8055 032770	MARIYA RODIONOVA	{"phone": "+70949867287"}
0005433181122	7F1685	0705 802644	NIKOLAY BONDARENKO	{"email": "bondarenkon_081976@postgrespro.ru", "phone": "+70776883512"}
0005433181123	7F1685	3945 643123	TATYANA BORISOVA	{"email": "tatyana_borisova.1964@postgrespro.ru", "phone": "+70585867368"}
0005433181124	ADED46	5118 833415	SERGEY ZAKHAROV	{"email": "s_zakharov-081969@postgrespro.ru", "phone": "+70766553505"}
0005433181125	8CC26C	7443 279606	IRINA GRISHINA	{"phone": "+70882411699"}
0005433181126	8CC26C	0771 338121	ZOYA BARANOVA	{"email": "baranova.zoya041972@postgrespro.ru", "phone": "+70517480360"}
0005433181127	6C3129	6873 093935	YURIY TIMOFEEV	{"email": "ytimofeev_08051972@postgrespro.ru", "phone": "+70936629577"}
0005433181128	F977B1	1391 165503	VALENTIN DMITRIEV	{"email": "dmitriev.v24111973@postgrespro.ru", "phone": "+70086243854"}
0005433181129	F977B1	0839 446197	ALEKSEY ANTONOV	{"email": "aleksey.antonov-111980@postgrespro.ru", "phone": "+70756464278"}
0005433181130	1A5458	9400 007246	OKSANA GAVRILOVA	{"email": "gavrilova_o-091971@postgrespro.ru", "phone": "+70863310271"}
0005433181131	287A8A	0069 102698	NIKITA MIRONOV	{"email": "mironov.nikita15041968@postgrespro.ru", "phone": "+70019686311"}
0005433181132	287A8A	2530 655516	NINA POPOVA	{"email": "popova-nina_13061966@postgrespro.ru", "phone": "+70713222700"}
0005433181133	1DCBF4	8056 290824	ARTEM ZAKHAROV	{"phone": "+70282551762"}
0005433181134	0626CE	0433 686443	RUZALIYA KOROLEVA	{"phone": "+70289872360"}
0005433181135	0626CE	6154 080023	GENNADIY SCHERBAKOV	{"email": "g.scherbakov.13091977@postgrespro.ru", "phone": "+70099679194"}
0005433181136	E650D7	6126 788881	LYUDMILA SOKOLOVA	{"email": "sokolovalyudmila.081975@postgrespro.ru", "phone": "+70426605617"}
0005433181137	2272D0	9781 095959	ALLA PETROVA	{"email": "petrova-a_021977@postgrespro.ru", "phone": "+70987084821"}
0005433181138	2272D0	0906 008805	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev_25101972@postgrespro.ru", "phone": "+70393162305"}
0005433181139	12FF26	6797 077730	DANIIL FEDOTOV	{"email": "d-fedotov.17041969@postgrespro.ru", "phone": "+70665143054"}
0005433181140	77B93C	7716 534951	MARINA ANISIMOVA	{"email": "anisimova-marina-13081970@postgrespro.ru", "phone": "+70882692799"}
0005433181141	77B93C	4062 381637	IGOR PETROV	{"email": "petrovigor.21021967@postgrespro.ru", "phone": "+70709873001"}
0005433181142	55F3D5	1639 829788	YURIY PETROV	{"email": "petrov-yuriy-071969@postgrespro.ru", "phone": "+70053652092"}
0005433181143	86E96F	9903 787260	VASILIY NIKITIN	{"email": "nikitinv-02121982@postgrespro.ru", "phone": "+70726715672"}
0005433181144	86E96F	2224 963037	VLADIMIR SCHERBAKOV	{"email": "vscherbakov_15021973@postgrespro.ru", "phone": "+70656731058"}
0005433181145	6B97C1	8042 956762	LIDIYA TITOVA	{"phone": "+70853018890"}
0005433181146	5DEDF3	2756 616461	NINA VOROBEVA	{"phone": "+70798631100"}
0005433181147	93F2C2	7839 668210	LYUDMILA ZHURAVLEVA	{"phone": "+70876984638"}
0005433181148	0D2D28	9843 374133	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-1976@postgrespro.ru", "phone": "+70567548920"}
0005433181149	15C0FC	9038 165681	VALENTINA FEDOROVA	{"phone": "+70850923642"}
0005433181150	DC7E99	0771 154506	ELENA BORISOVA	{"email": "borisova.elena-1972@postgrespro.ru", "phone": "+70606289157"}
0005433181151	1D32D5	4333 721636	MARIYA FOMINA	{"email": "mariyafomina-121972@postgrespro.ru", "phone": "+70814348822"}
0005433181152	73B450	9019 213654	ANASTASIYA NESTEROVA	{"phone": "+70931814537"}
0005433181153	C2617F	9373 215729	IRAIDA KOROLEVA	{"email": "koroleva_i_15121968@postgrespro.ru", "phone": "+70872234040"}
0005433181154	C2617F	3777 349257	ANASTASIYA KUZNECOVA	{"phone": "+70178151162"}
0005433181155	C2617F	2527 463847	YURIY GAVRILOV	{"phone": "+70163542353"}
0005433181156	9AEF22	2034 419922	EVGENIY NOVIKOV	{"phone": "+70659211528"}
0005433181157	9AEF22	6004 011835	NINA SCHERBAKOVA	{"email": "nina.scherbakova.17091969@postgrespro.ru", "phone": "+70268388182"}
0005433181158	1C626D	5167 499805	DMITRIY IVANOV	{"email": "ivanov_dmitriy-1977@postgrespro.ru", "phone": "+70942455208"}
0005433181159	0E9C63	1368 565021	SERGEY MAKSIMOV	{"phone": "+70960738854"}
0005433181160	EC55CA	8760 811112	ANASTASIYA YAKOVLEVA	{"email": "yakovleva-anastasiya-071968@postgrespro.ru", "phone": "+70206544267"}
0005433181162	0DBECD	2531 152387	ANASTASIYA ZAKHAROVA	{"phone": "+70099367206"}
0005433181163	0DBECD	9242 822065	IRINA KOLESNIKOVA	{"phone": "+70294930794"}
0005433181164	7855B6	1286 749245	KONSTANTIN NAUMOV	{"phone": "+70787338853"}
0005433181165	53D066	1749 666240	LYUBOV KULIKOVA	{"email": "lyubovkulikova1975@postgrespro.ru", "phone": "+70307071659"}
0005433181166	53D066	6051 813159	DANILA ZAKHAROV	{"email": "zakharov.danila-1963@postgrespro.ru", "phone": "+70070936000"}
0005433181167	BC7A69	8449 891630	EKATERINA KUDRYASHOVA	{"email": "e.kudryashova.1966@postgrespro.ru", "phone": "+70718156625"}
0005433181168	C5EBB7	5780 632158	EMILIYA DAVYDOVA	{"email": "emiliya.davydova051967@postgrespro.ru", "phone": "+70020922184"}
0005433181169	172067	6837 564424	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev_011974@postgrespro.ru", "phone": "+70842352480"}
0005433181170	745946	5154 447427	ALEKSEY VOLKOV	{"email": "volkovaleksey_1960@postgrespro.ru", "phone": "+70466356259"}
0005433181171	11DA1C	9564 027289	ANNA FROLOVA	{"phone": "+70343661627"}
0005433181172	7E9EAC	0701 158647	KIRILL KUZNECOV	{"email": "kuznecov.kirill_1971@postgrespro.ru", "phone": "+70327706230"}
0005433181173	7E9EAC	8971 032955	SERGEY KUZNECOV	{"phone": "+70814124942"}
0005433181174	76F896	6840 755034	MARIYA KULIKOVA	{"phone": "+70220823398"}
0005433181175	5D112C	8631 622924	ALEKSEY VOROBEV	{"email": "vorobev.aleksey.091965@postgrespro.ru", "phone": "+70484723925"}
0005433181176	5D112C	6269 989278	IVAN MAKAROV	{"email": "makarov-i071978@postgrespro.ru", "phone": "+70771093771"}
0005433181177	5D112C	5484 244720	IRINA SMIRNOVA	{"email": "ismirnova_1984@postgrespro.ru", "phone": "+70233313126"}
0005433181178	81970B	0044 088102	ANNA TITOVA	{"phone": "+70361559727"}
0005433181179	B06F7E	7633 377999	GALINA NAZAROVA	{"email": "nazarova_g-21101969@postgrespro.ru", "phone": "+70043904589"}
0005433181180	2F3808	3457 025825	ANNA IVANOVA	{"email": "a_ivanova101982@postgrespro.ru", "phone": "+70865475692"}
0005433181181	2F3808	7478 687975	EKATERINA KISELEVA	{"email": "e_kiseleva_08061971@postgrespro.ru", "phone": "+70742600975"}
0005433181182	9C2EDD	1727 753807	TATYANA NOVIKOVA	{"phone": "+70408338219"}
0005433181183	9C2EDD	4464 828798	DENIS ZHURAVLEV	{"email": "zhuravlev-d-01091975@postgrespro.ru", "phone": "+70472282443"}
0005433181184	349620	5172 169226	EVGENIYA GORBUNOVA	{"email": "evgeniya-gorbunova-051974@postgrespro.ru", "phone": "+70748160166"}
0005433181185	349620	5245 088450	VITALIY MAKSIMOV	{"email": "vitaliy-maksimov-1972@postgrespro.ru", "phone": "+70646968919"}
0005433181186	DC689F	4968 033581	NADEZHDA NIKITINA	{"phone": "+70511679720"}
0005433181187	DC3FFC	5313 764256	ALEKSANDR SOKOLOV	{"phone": "+70243640926"}
0005433181188	CC0607	3994 917010	LYUBOV MIRONOVA	{"phone": "+70816019667"}
0005433181189	416976	8771 502362	TATYANA KUZMINA	{"email": "tatyana_kuzmina.22021972@postgrespro.ru", "phone": "+70004767519"}
0005433181190	5C64EE	5447 912480	SVETLANA LUKYANOVA	{"email": "lukyanova-svetlana081983@postgrespro.ru", "phone": "+70625368175"}
0005433181191	191B30	1604 254942	GALINA SERGEEVA	{"email": "sergeeva.g.29041972@postgrespro.ru", "phone": "+70745156643"}
0005433181192	CE10D5	1805 254041	VALERIY ABRAMOV	{"email": "abramov-v_1981@postgrespro.ru", "phone": "+70369163408"}
0005433181193	F412BD	9696 362971	YULIYA KUZMINA	{"phone": "+70635439765"}
0005433181194	494BC7	8262 004448	SERAFIMA FILIPPOVA	{"phone": "+70738580413"}
0005433181195	494BC7	6409 295140	SVETLANA BELYAEVA	{"phone": "+70220933071"}
0005433181196	494BC7	9482 450108	ARTEM OSIPOV	{"phone": "+70488699916"}
0005433181197	F9B13A	2491 735733	ANNA GUSEVA	{"phone": "+70902611369"}
0005433181198	F9B13A	2701 183032	TATYANA NESTEROVA	{"phone": "+70541711330"}
0005433181199	D3EE95	4097 839412	OLGA DENISOVA	{"phone": "+70893118682"}
0005433181200	2DB6A7	0571 763296	YANA KOZLOVA	{"phone": "+70510067949"}
0005433181201	2DB6A7	3554 667920	NATALYA NESTEROVA	{"email": "natalya_nesterova-28091971@postgrespro.ru", "phone": "+70393154694"}
0005433181202	CB7A89	3105 762017	VLADIMIR SOLOVEV	{"phone": "+70633933158"}
0005433181203	983400	2748 460902	ZINAIDA NIKIFOROVA	{"email": "nikiforova_z.081960@postgrespro.ru", "phone": "+70234863565"}
0005433181204	983400	1449 702294	ELENA KUZNECOVA	{"phone": "+70822158141"}
0005433181205	D3E6ED	7649 418914	OLGA SOKOLOVA	{"email": "o.sokolova1975@postgrespro.ru", "phone": "+70373479199"}
0005433181206	96C156	0346 549009	MIKHAIL KOROLEV	{"email": "korolevmikhail_1972@postgrespro.ru", "phone": "+70606943036"}
0005433181207	96C156	7750 739177	IRINA GORBUNOVA	{"email": "irina_gorbunova-1968@postgrespro.ru", "phone": "+70970458451"}
0005433181208	A98733	4476 781965	PAVEL NIKOLAEV	{"phone": "+70748828636"}
0005433181209	5EF876	8260 377094	EVGENIYA RODIONOVA	{"phone": "+70007524013"}
0005433181210	5EF876	0809 087913	ELINA BELYAEVA	{"email": "belyaeva_elina1980@postgrespro.ru", "phone": "+70923913311"}
0005433181211	ADD705	7315 118832	IGOR MOROZOV	{"phone": "+70992908098"}
0005433181212	ADD705	8513 115921	NATALYA ANTONOVA	{"phone": "+70650603294"}
0005433181213	912A23	7751 210809	TAMARA SOKOLOVA	{"email": "tamarasokolova061964@postgrespro.ru", "phone": "+70534056030"}
0005433181214	B8AE9B	9111 506668	VALERIY RODIONOV	{"phone": "+70006082405"}
0005433181215	B8AE9B	8233 928175	ANASTASIYA DENISOVA	{"email": "a-denisova.1970@postgrespro.ru", "phone": "+70325540159"}
0005433181216	2B492D	3868 014452	SERGEY NAUMOV	{"email": "snaumov.121969@postgrespro.ru", "phone": "+70917179431"}
0005433181217	C8F748	5496 843712	MARIYA GAVRILOVA	{"email": "gavrilova_mariya12121975@postgrespro.ru", "phone": "+70146913277"}
0005433181218	C8F748	0446 503384	VLADIMIR MEDVEDEV	{"phone": "+70457315340"}
0005433181219	7C00FE	7881 159452	ANATOLIY EGOROV	{"phone": "+70092409074"}
0005433181220	7C00FE	0941 395488	VLADIMIR SIDOROV	{"phone": "+70443486045"}
0005433181221	916C20	7783 449420	EKATERINA YUDINA	{"email": "yudina.e-081971@postgrespro.ru", "phone": "+70409375964"}
0005433181222	916C20	1507 331697	KRISTINA NIKOLAEVA	{"email": "k.nikolaeva1979@postgrespro.ru", "phone": "+70829829516"}
0005433181223	E9DFEC	8507 268965	ZUKHRA PETROVA	{"phone": "+70494075473"}
0005433181224	E9DFEC	4899 011033	SERGEY ZAKHAROV	{"email": "sergey.zakharov.1964@postgrespro.ru", "phone": "+70661893741"}
0005433181225	6E0AD7	3225 558140	BORIS PETROV	{"phone": "+70118538093"}
0005433181226	6E0AD7	5940 684326	TAISIYA GAVRILOVA	{"phone": "+70123780395"}
0005433181227	D73908	1977 043417	ELENA KOROLEVA	{"phone": "+70732234094"}
0005433181228	A50884	0281 025541	VYACHESLAV MATVEEV	{"phone": "+70704226843"}
0005433181229	6242A1	3687 305284	VALENTINA KUZNECOVA	{"email": "vkuznecova.1965@postgrespro.ru", "phone": "+70959444269"}
0005433181230	6242A1	7013 961298	VIKTORIYA IVANOVA	{"email": "vivanova-1967@postgrespro.ru", "phone": "+70533785966"}
0005433181231	5C1B32	0056 629104	SVETLANA ARKHIPOVA	{"email": "arkhipova-svetlana_071973@postgrespro.ru", "phone": "+70266645427"}
0005433181232	0FBC97	1585 314416	ALEKSEY KOZLOV	{"phone": "+70612711260"}
0005433181233	C33ACA	3650 465243	OLGA ERMAKOVA	{"email": "ermakova-olga_28121970@postgrespro.ru", "phone": "+70142970250"}
0005433181234	2BD245	8111 309631	TAMARA ZHURAVLEVA	{"email": "t.zhuravleva.01051974@postgrespro.ru", "phone": "+70697810367"}
0005433181235	DCDCE5	4686 672886	EVGENIYA BOGDANOVA	{"phone": "+70303378955"}
0005433181236	2A828C	3213 153364	KONSTANTIN ZAYCEV	{"email": "zaycev.konstantin-15111966@postgrespro.ru", "phone": "+70887894647"}
0005433181237	6C8E64	0238 596148	POLINA KUZMINA	{"email": "p_kuzmina-16031968@postgrespro.ru", "phone": "+70311646277"}
0005433181238	143007	0774 528523	AYRAT GORBUNOV	{"phone": "+70209093889"}
0005433181239	143007	4673 670051	ANASTASIYA NAUMOVA	{"email": "anastasiya_naumova.15061971@postgrespro.ru", "phone": "+70501215957"}
0005433181240	725655	5108 956053	OKSANA KRASNOVA	{"phone": "+70421532096"}
0005433181241	3458A6	9076 345609	IRINA MIRONOVA	{"email": "mironovairina.1971@postgrespro.ru", "phone": "+70190095119"}
0005433181242	D213E0	6661 608584	ALEKSANDR SIDOROV	{"phone": "+70381496152"}
0005433181243	872201	0336 889626	DMITRIY IVANOV	{"phone": "+70762669592"}
0005433181244	42B3C0	2441 628009	MIKHAIL YAKOVLEV	{"email": "myakovlev_1973@postgrespro.ru", "phone": "+70444654694"}
0005433181245	42B3C0	9974 860828	OLEG IVANOV	{"phone": "+70314423298"}
0005433181246	935E6C	9880 029932	ARTEM NOVIKOV	{"phone": "+70591663372"}
0005433181247	BC8862	3592 847824	ALLA GUSEVA	{"email": "guseva.a_1974@postgrespro.ru", "phone": "+70072494224"}
0005433181248	BC8862	6833 080084	VLADIMIR BORISOV	{"email": "borisov_vladimir.101966@postgrespro.ru", "phone": "+70560835310"}
0005433181249	A174AA	0196 736746	OLEG SEMENOV	{"phone": "+70374115421"}
0005433181250	3D65DA	6895 452612	OLESYA POPOVA	{"phone": "+70790542754"}
0005433181251	256B72	5942 088870	STANISLAV DAVYDOV	{"phone": "+70385829452"}
0005433181252	0A9C8E	1859 686181	GULNARA ILINA	{"email": "ilina_gulnara05081976@postgrespro.ru", "phone": "+70420608143"}
0005433181253	85216A	7040 508650	EKATERINA ALEKSEEVA	{"phone": "+70132017640"}
0005433181254	85216A	4149 191728	ALEKSANDR DAVYDOV	{"phone": "+70749827202"}
0005433181255	B4BCA9	7688 634648	EKATERINA KOMAROVA	{"email": "ekaterina.komarova-13071977@postgrespro.ru", "phone": "+70807033234"}
0005433181256	E13C3D	0684 468601	TATYANA IVANOVA	{"phone": "+70792865699"}
0005433181257	37C7EA	7805 741989	OLGA KULIKOVA	{"email": "kulikova.o-071975@postgrespro.ru", "phone": "+70643329799"}
0005433181258	394623	6556 930212	TIMUR SAVELEV	{"email": "t.savelev081961@postgrespro.ru", "phone": "+70713502903"}
0005433181259	BB6C4C	3219 591064	KLAVDIYA IVANOVA	{"phone": "+70817734346"}
0005433181260	2468B6	8251 953930	IRINA KUZNECOVA	{"email": "i-kuznecova-021984@postgrespro.ru", "phone": "+70250244416"}
0005433181261	E49168	4333 111056	VIKTOR KRASNOV	{"email": "krasnov_v_1976@postgrespro.ru", "phone": "+70129308234"}
0005433181262	E49168	9971 329792	IRINA LOGINOVA	{"email": "loginova_irina-1972@postgrespro.ru", "phone": "+70254872035"}
0005433181263	AE4EE3	0443 694142	YURIY ZHUKOV	{"email": "zhukov_yuriy_1976@postgrespro.ru", "phone": "+70266039098"}
0005433181264	DB9016	9836 453047	TATYANA ANTONOVA	{"phone": "+70451948495"}
0005433181265	AF56CB	9726 777268	SVETLANA VOROBEVA	{"phone": "+70821771896"}
0005433181266	AF56CB	6331 125884	KLAVDIYA FROLOVA	{"phone": "+70979161226"}
0005433181267	AF56CB	8436 696427	TATYANA SAVELEVA	{"phone": "+70575079349"}
0005433181268	60BB1F	1376 429951	ALEKSEY SCHERBAKOV	{"phone": "+70393655290"}
0005433181269	60BB1F	0515 576368	ROMAN EGOROV	{"phone": "+70732183935"}
0005433181270	60BB1F	8560 644624	OLGA SAVELEVA	{"phone": "+70804235193"}
0005433181271	2A455B	2459 387744	ALEKSANDRA MAKAROVA	{"email": "aleksandra.makarova.23101976@postgrespro.ru", "phone": "+70256545447"}
0005433181272	2A455B	6596 502330	KONSTANTIN PAVLOV	{"phone": "+70155975944"}
0005433181273	2A455B	2689 097563	RAISA EFREMOVA	{"phone": "+70214017749"}
0005433181274	9E0B2E	6987 535488	RIMA DANILOVA	{"email": "danilova_r.011970@postgrespro.ru", "phone": "+70692546153"}
0005433181275	9E0B2E	7161 778662	OLGA KOROLEVA	{"email": "koroleva.o.121966@postgrespro.ru", "phone": "+70739467590"}
0005433181276	28CF81	1775 353631	OKSANA POPOVA	{"phone": "+70659386546"}
0005433181277	4B4273	8221 144307	OLGA IVANOVA	{"phone": "+70800680133"}
0005433181278	4B4273	7833 525016	NIKOLAY ROMANOV	{"email": "nikolay-romanov.071970@postgrespro.ru", "phone": "+70617475804"}
0005433181279	86318E	2472 459072	ALEKSANDR YAKOVLEV	{"phone": "+70310315935"}
0005433181280	86318E	6515 449720	IGOR IVANOV	{"phone": "+70869419135"}
0005433181281	86318E	2248 150489	MARIYA ALEKSANDROVA	{"phone": "+70524229177"}
0005433181282	5E9DD3	2452 746607	ELIZAVETA LEBEDEVA	{"phone": "+70494863601"}
0005433181283	5E9DD3	3697 990993	TAMARA POPOVA	{"phone": "+70439331734"}
0005433181284	D0459B	7434 954693	SERGEY MIKHAYLOV	{"phone": "+70330872988"}
0005433181285	D0459B	6391 711000	TAMARA KOROLEVA	{"email": "tamara.koroleva_1982@postgrespro.ru", "phone": "+70664487343"}
0005433181286	C540E8	7802 395718	NINA NIKIFOROVA	{"phone": "+70445532360"}
0005433181287	7866C4	2279 992186	TATYANA KUZNECOVA	{"email": "t_kuznecova-08071967@postgrespro.ru", "phone": "+70634332891"}
0005433181288	7866C4	8270 694648	NADEZHDA VOROBEVA	{"phone": "+70590403466"}
0005433181289	CDF660	9560 592096	GALINA BELOVA	{"phone": "+70364177780"}
0005433181290	3271DC	8529 731300	KIRILL AFANASEV	{"phone": "+70928137047"}
0005433181291	3271DC	6446 653865	NATALYA SOKOLOVA	{"phone": "+70824037451"}
0005433181292	485427	1668 978195	VALENTINA CHERNOVA	{"email": "v_chernova_17091982@postgrespro.ru", "phone": "+70577215295"}
0005433181293	69A1EB	6871 239351	ELEONORA VASILEVA	{"email": "eleonora.vasileva-11011970@postgrespro.ru", "phone": "+70634611558"}
0005433181294	69A1EB	9103 986977	GALINA MARTYNOVA	{"phone": "+70822008253"}
0005433181295	69A1EB	4717 193014	VYACHESLAV KUDRYASHOV	{"email": "vyacheslav.kudryashov_061976@postgrespro.ru", "phone": "+70728899579"}
0005433181296	79BD9E	7383 231804	DMITRIY KULIKOV	{"phone": "+70980580128"}
0005433181297	9DF5B8	4221 048319	SERGEY SOLOVEV	{"email": "ssolovev-071983@postgrespro.ru", "phone": "+70053785682"}
0005433181298	57DB2D	4029 813639	SERGEY GUSEV	{"email": "sergey.gusev1967@postgrespro.ru", "phone": "+70865099853"}
0005433181299	BE75F3	5997 544845	VALENTINA DANILOVA	{"email": "vdanilova_031977@postgrespro.ru", "phone": "+70127850605"}
0005433181300	BE75F3	7120 785441	LYUBOV BARANOVA	{"email": "baranoval-11111971@postgrespro.ru", "phone": "+70382309646"}
0005433181301	C8326A	6277 177118	ANDREY BARANOV	{"email": "baranov-andrey_1964@postgrespro.ru", "phone": "+70341642267"}
0005433181302	FAC694	7317 002483	SERGEY KUZNECOV	{"email": "kuznecov_sergey.031968@postgrespro.ru", "phone": "+70955780434"}
0005433181303	BCDEE9	2669 394475	VLADIMIR RODIONOV	{"email": "rodionov-vladimir-1965@postgrespro.ru", "phone": "+70761207276"}
0005433181304	F0D0E4	1412 690628	ZINAIDA MELNIKOVA	{"email": "z.melnikova_29081964@postgrespro.ru", "phone": "+70951250719"}
0005433181305	0F75DB	0413 028526	VALERIY KUZNECOV	{"email": "kuznecovvaleriy051975@postgrespro.ru", "phone": "+70761486585"}
0005433181306	DB0547	1538 181571	TATYANA ERMAKOVA	{"email": "ermakova_tatyana_091977@postgrespro.ru", "phone": "+70049535609"}
0005433181307	4EBFDA	4849 752435	MAKSIM FILIPPOV	{"email": "maksim.filippov_071990@postgrespro.ru", "phone": "+70711111182"}
0005433181308	AE9064	8387 086520	EKATERINA SIDOROVA	{"email": "ekaterina_sidorova_081973@postgrespro.ru", "phone": "+70361359416"}
0005433181309	E996B6	8983 078804	OLGA VASILEVA	{"email": "vasilevaolga_071978@postgrespro.ru", "phone": "+70989968340"}
0005433181310	3AD7EE	1691 765828	ELENA KALININA	{"email": "elenakalinina_1969@postgrespro.ru", "phone": "+70922411889"}
0005433181311	3AD7EE	8716 063670	OLGA VASILEVA	{"email": "vasileva_olga-111974@postgrespro.ru", "phone": "+70168064622"}
0005433181312	8C7DB9	1136 270260	NATALYA VASILEVA	{"phone": "+70107404026"}
0005433181313	AAC50B	4344 571702	EKATERINA KAZAKOVA	{"email": "kazakovaekaterina_30091975@postgrespro.ru", "phone": "+70270869695"}
0005433181314	AAC50B	2360 918704	ANGELINA SOLOVEVA	{"phone": "+70855185605"}
0005433181315	2E0096	4353 945358	ANTONINA VLASOVA	{"phone": "+70576636173"}
0005433181316	2E0096	5307 871984	TAMARA KOZLOVA	{"email": "kozlova_t11041979@postgrespro.ru", "phone": "+70155959403"}
0005433181317	3E9D78	4448 467763	EVGENIYA GORBUNOVA	{"phone": "+70392967244"}
0005433181318	652271	2135 601480	ELIZAVETA IVANOVA	{"email": "eivanova.031973@postgrespro.ru", "phone": "+70340225900"}
0005433181319	3655EB	5348 456274	NIKOLAY TIKHONOV	{"phone": "+70037114443"}
0005433181320	3E5A4C	8816 829050	DMITRIY ZAYCEV	{"phone": "+70806125765"}
0005433181321	A7243D	7255 240833	ARTEM SOLOVEV	{"email": "artem.solovev-10071980@postgrespro.ru", "phone": "+70378765407"}
0005433181322	21F32C	6411 716943	PETR MARTYNOV	{"email": "martynov.petr_091975@postgrespro.ru", "phone": "+70187906322"}
0005433181379	E5C989	2222 359312	YURIY VOLKOV	{"phone": "+70188676918"}
0005433181323	1B19F5	5254 181353	MARIYA MEDVEDEVA	{"email": "mariya.medvedeva13021969@postgrespro.ru", "phone": "+70203335525"}
0005433181324	E20B56	2870 253552	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir-1973@postgrespro.ru", "phone": "+70619393548"}
0005433181325	6F8A9B	8162 310433	NIKOLAY CHERNOV	{"phone": "+70788643016"}
0005433181326	6417D3	8682 528536	IGNAT ZHUKOV	{"email": "zhukov_ignat021968@postgrespro.ru", "phone": "+70035932119"}
0005433181327	2960C5	7176 367522	LYUDMILA RYABOVA	{"phone": "+70880538539"}
0005433181328	2960C5	6442 441229	GALINA FILIPPOVA	{"email": "g.filippova-1971@postgrespro.ru", "phone": "+70754816237"}
0005433181329	5621B4	6156 527265	VLADIMIR POPOV	{"phone": "+70517070561"}
0005433181330	73C847	9633 302505	YULIYA VOLKOVA	{"phone": "+70159706259"}
0005433181331	73C847	9680 638114	SOFIYA MIRONOVA	{"email": "s_mironova31051971@postgrespro.ru", "phone": "+70568184896"}
0005433181332	73C847	2439 942202	YULIYA EGOROVA	{"phone": "+70620602712"}
0005433181333	A19DA5	4514 097633	TATYANA KULIKOVA	{"email": "kulikova-t_1971@postgrespro.ru", "phone": "+70014041175"}
0005433181334	A19DA5	9763 244946	MARIYA STEPANOVA	{"email": "mariyastepanova-20091975@postgrespro.ru", "phone": "+70873781004"}
0005433181335	9641D2	4668 759811	ALEKSEY SCHERBAKOV	{"phone": "+70307139402"}
0005433181336	9641D2	5489 176287	VLADIMIR KUZNECOV	{"phone": "+70509873201"}
0005433181337	9641D2	1517 016366	VLADIMIR BARANOV	{"email": "baranov-v-1963@postgrespro.ru", "phone": "+70704945530"}
0005433181338	66F43B	2608 783422	ALEKSANDRA KUZMINA	{"email": "akuzmina.1970@postgrespro.ru", "phone": "+70602486485"}
0005433181339	66F43B	6970 150777	FELIKS GERASIMOV	{"email": "f-gerasimov071973@postgrespro.ru", "phone": "+70997121876"}
0005433181340	626EF8	9272 060787	SOFYA NIKITINA	{"phone": "+70796966148"}
0005433181341	626EF8	5349 223153	ALEKSANDRA KOVALEVA	{"phone": "+70314712255"}
0005433181342	31D363	1423 420855	NADEZHDA KISELEVA	{"phone": "+70913400916"}
0005433181343	31D363	1938 288799	EVGENIY SOKOLOV	{"phone": "+70363507033"}
0005433181344	EE5182	0657 326025	LEONID MIKHAYLOV	{"phone": "+70794030704"}
0005433181345	EE5182	8381 363791	ALEKSEY SOKOLOV	{"email": "a.sokolov_061980@postgrespro.ru", "phone": "+70226447956"}
0005433181346	4F6A1B	9285 361438	KRISTINA ZAKHAROVA	{"email": "zakharovak24121977@postgrespro.ru", "phone": "+70767997190"}
0005433181347	2FE1D9	3915 407376	YURIY FEDOTOV	{"email": "yfedotov-1969@postgrespro.ru", "phone": "+70343164791"}
0005433181348	2FE1D9	2627 783248	NATALYA DMITRIEVA	{"email": "natalyadmitrieva1966@postgrespro.ru", "phone": "+70855596507"}
0005433181349	651586	7625 965790	ELENA KOROLEVA	{"phone": "+70542982408"}
0005433181350	FE7368	3211 898329	EKATERINA NAZAROVA	{"phone": "+70435110576"}
0005433181351	FE7368	7849 336603	NATALYA TITOVA	{"phone": "+70261501532"}
0005433181352	98BD0E	4205 597794	VALENTINA FILATOVA	{"phone": "+70833100819"}
0005433181353	D20555	2471 298435	ALFIYA MOROZOVA	{"phone": "+70974839677"}
0005433181354	F7C6A6	1313 343036	VLADIMIR IVANOV	{"email": "ivanov_vladimir_061960@postgrespro.ru", "phone": "+70550257378"}
0005433181355	87D7B0	7522 678048	EGOR SIDOROV	{"email": "esidorov041965@postgrespro.ru", "phone": "+70220578366"}
0005433181356	87D7B0	1359 245473	ANNA POTAPOVA	{"email": "potapovaanna1953@postgrespro.ru", "phone": "+70110742424"}
0005433181357	3834FC	9552 098215	ALEKSANDR POPOV	{"email": "popov_aleksandr_1986@postgrespro.ru", "phone": "+70341218373"}
0005433181358	3834FC	9015 632825	NATALYA SERGEEVA	{"email": "sergeevan-031968@postgrespro.ru", "phone": "+70219163924"}
0005433181359	7E6D81	9455 682324	ANTON VASILEV	{"phone": "+70881201333"}
0005433181360	7E6D81	0884 600674	SERGEY NOVIKOV	{"email": "sergey.novikov.021966@postgrespro.ru", "phone": "+70455243840"}
0005433181361	63E66B	6791 352010	LEONTIY SERGEEV	{"email": "l_sergeev-17031973@postgrespro.ru", "phone": "+70408888623"}
0005433181362	825401	5716 788681	LYUBOV SMIRNOVA	{"phone": "+70560882174"}
0005433181363	36902B	6507 504532	ROMAN STEPANOV	{"phone": "+70947425051"}
0005433181364	36902B	7401 123260	VALENTIN MOISEEV	{"email": "v.moiseev_27071959@postgrespro.ru", "phone": "+70388195000"}
0005433181365	98FC6F	5499 285378	ZINAIDA KISELEVA	{"email": "kiseleva-zinaida-1978@postgrespro.ru", "phone": "+70647178644"}
0005433181366	7FE547	4507 480697	ANATOLIY ILIN	{"email": "a_ilin_031976@postgrespro.ru", "phone": "+70401365108"}
0005433181367	7FE547	0725 079477	ARSEN KOZLOV	{"phone": "+70415630187"}
0005433181368	478EAF	4768 131872	ARTEM KARPOV	{"email": "a-karpov_20051970@postgrespro.ru", "phone": "+70995666603"}
0005433181369	36C82B	2897 484932	ALEKSANDR MAKAROV	{"phone": "+70926817910"}
0005433181370	FD7ED0	8763 318359	DMITRIY FROLOV	{"email": "dmitriyfrolov_041962@postgrespro.ru", "phone": "+70242156113"}
0005433181371	FD7ED0	1334 780551	MAKSIM KUZNECOV	{"phone": "+70870994684"}
0005433181372	31E3DC	2827 164958	NADEZHDA STEPANOVA	{"phone": "+70521932758"}
0005433181373	340F34	9448 307208	ALEKSEY CHERNOV	{"email": "alekseychernov.30051974@postgrespro.ru", "phone": "+70550521870"}
0005433181374	FB0E13	6548 458865	FANIL KAZAKOV	{"email": "f.kazakov_1967@postgrespro.ru", "phone": "+70276786754"}
0005433181375	8BB1F1	8636 622200	EKATERINA NIKOLAEVA	{"email": "ekaterina.nikolaeva.1959@postgrespro.ru", "phone": "+70670563524"}
0005433181376	8BB1F1	0214 462156	GALINA FOMINA	{"email": "galina-fomina_071969@postgrespro.ru", "phone": "+70809091913"}
0005433181377	8BB1F1	7337 163894	SVETLANA NIKITINA	{"phone": "+70303765756"}
0005433181378	BC60FD	0840 599649	ALEKSANDR NAZAROV	{"phone": "+70254282821"}
0005433181380	E5C989	8677 406541	VYACHESLAV SEMENOV	{"phone": "+70822968144"}
0005433181381	D17111	1800 819751	SVETLANA ZAYCEVA	{"email": "zaycevas1975@postgrespro.ru", "phone": "+70587757114"}
0005433181382	D17111	1324 879545	YAROSLAV ORLOV	{"email": "y.orlov111969@postgrespro.ru", "phone": "+70229898751"}
0005433181383	388F4C	4835 190778	ELENA BORISOVA	{"email": "elena_borisova22041966@postgrespro.ru", "phone": "+70015016939"}
0005433181384	9295B5	2871 509087	SVETLANA ORLOVA	{"email": "orlova.svetlana_081980@postgrespro.ru", "phone": "+70379261790"}
0005433181385	662BDA	3407 390175	ALIYA ZAKHAROVA	{"email": "a.zakharova1963@postgrespro.ru", "phone": "+70900539655"}
0005433181386	662BDA	9682 838409	SOFIYA LOGINOVA	{"phone": "+70554385637"}
0005433181387	29BFD6	9360 333673	EVGENIY PETROV	{"phone": "+70497413153"}
0005433181388	29BFD6	2525 176267	IRINA OSIPOVA	{"phone": "+70837060302"}
0005433181389	772A63	9604 763244	VLADIMIR FOMIN	{"phone": "+70347006726"}
0005433181390	DD0CB8	0594 839131	OLEG KARPOV	{"email": "oleg.karpov.1966@postgrespro.ru", "phone": "+70169920932"}
0005433181391	DD0CB8	2383 786342	ANASTASIYA MAKAROVA	{"phone": "+70085945393"}
0005433181392	BD24DB	3338 785690	ELENA BOGDANOVA	{"phone": "+70799981756"}
0005433181393	BD24DB	5518 321184	RUSLAN MIRONOV	{"phone": "+70941357245"}
0005433181394	898DAF	4497 187081	EVGENIY NAZAROV	{"email": "e-nazarov30081972@postgrespro.ru", "phone": "+70341093691"}
0005433181395	96DF9C	8124 558770	ELENA DMITRIEVA	{"email": "dmitrievae091968@postgrespro.ru", "phone": "+70032412735"}
0005433181396	EFC205	3498 931647	ANNA SOLOVEVA	{"phone": "+70488573348"}
0005433181397	EAB209	8095 430897	VALENTIN POPOV	{"phone": "+70963270105"}
0005433181398	EAB209	1441 244356	IVAN ANTONOV	{"phone": "+70429041412"}
0005433181399	B7D90F	6916 285746	ALBINA ANDREEVA	{"email": "albina.andreeva_07041983@postgrespro.ru", "phone": "+70244206194"}
0005433181400	B7D90F	7288 681289	EKATERINA DAVYDOVA	{"email": "e.davydova.1963@postgrespro.ru", "phone": "+70765440707"}
0005433181401	A61399	4867 602670	GALINA OVCHINNIKOVA	{"email": "g.ovchinnikova.24091967@postgrespro.ru", "phone": "+70632877866"}
0005433181402	101AEF	9899 632111	VLADIMIR VASILEV	{"email": "vasilev_vladimir-1975@postgrespro.ru", "phone": "+70537261794"}
0005433181403	7DE6EF	4939 548783	VLADIMIR GERASIMOV	{"phone": "+70064038617"}
0005433181404	AB1B05	8663 621693	PAVEL NIKOLAEV	{"phone": "+70775089741"}
0005433181405	AB1B05	7623 900521	SVETLANA KOZLOVA	{"phone": "+70599803740"}
0005433181406	AB1B05	4900 676091	MAKSIM BARANOV	{"phone": "+70184129697"}
0005433181407	6122E1	0109 703081	KSENIYA ANTONOVA	{"phone": "+70839561923"}
0005433181408	B895D3	0927 276660	VYACHESLAV ZHUKOV	{"email": "zhukovvyacheslav.1981@postgrespro.ru", "phone": "+70518917767"}
0005433181409	BDF9D6	5305 451760	SVETLANA MATVEEVA	{"phone": "+70361833299"}
0005433181410	31B5B4	4042 631088	ALIYA IVANOVA	{"phone": "+70903360612"}
0005433181411	166EE9	0633 430809	DMITRIY YAKOVLEV	{"email": "yakovlev-dmitriy-1972@postgrespro.ru", "phone": "+70320842834"}
0005433181412	02373C	5679 187788	RAVILYA MEDVEDEVA	{"phone": "+70860404448"}
0005433181413	02373C	8653 584243	TATYANA KUZMINA	{"email": "tkuzmina-16061968@postgrespro.ru", "phone": "+70054804721"}
0005433181414	D2EEDD	4030 542261	VLADIMIR MIRONOV	{"phone": "+70976393773"}
0005433181415	D2EEDD	5461 501262	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a091976@postgrespro.ru", "phone": "+70639634228"}
0005433181416	1B09DB	7514 107187	VLADIMIR DMITRIEV	{"phone": "+70410274682"}
0005433181417	1B09DB	7255 184796	ANNA NOVIKOVA	{"phone": "+70260040637"}
0005433181418	FB729A	7832 249843	NADEZHDA IVANOVA	{"email": "n.ivanova-091978@postgrespro.ru", "phone": "+70118744622"}
0005433181419	627534	0818 020081	OKSANA MELNIKOVA	{"email": "omelnikova071974@postgrespro.ru", "phone": "+70396835851"}
0005433181420	627534	6403 830422	OLGA GUSEVA	{"phone": "+70166306702"}
0005433181421	ECEC32	9244 648206	NIKOLAY SMIRNOV	{"email": "smirnovn.011961@postgrespro.ru", "phone": "+70089583090"}
0005433181422	ECEC32	9353 978762	NIKOLAY BORISOV	{"phone": "+70685312786"}
0005433181423	AC04B3	2203 575198	TATYANA IVANOVA	{"phone": "+70944019675"}
0005433181424	AC04B3	8534 693042	ALSU MOROZOVA	{"email": "alsu-morozova-091985@postgrespro.ru", "phone": "+70998527658"}
0005433181425	44A96F	3724 978001	YURIY YAKOVLEV	{"phone": "+70574542025"}
0005433181426	E3C4C6	3853 839714	DMITRIY FEDOTOV	{"email": "fedotov-dmitriy121974@postgrespro.ru", "phone": "+70409130808"}
0005433181427	FCF960	6248 374969	ANTON MEDVEDEV	{"email": "a_medvedev-1970@postgrespro.ru", "phone": "+70947703327"}
0005433181428	FCF960	5752 164404	YULIYA MOROZOVA	{"email": "morozova-y-11041978@postgrespro.ru", "phone": "+70217601669"}
0005433181429	0F61D1	7464 027722	OLGA IVANOVA	{"email": "ivanovaolga.21021970@postgrespro.ru", "phone": "+70408028265"}
0005433181430	0F61D1	9124 267752	ELENA ANTONOVA	{"email": "antonovae04041974@postgrespro.ru", "phone": "+70307784926"}
0005433181431	ADFDAF	4819 495261	GALINA GUSEVA	{"phone": "+70388007197"}
0005433181432	9F4BCA	4737 404370	IRINA DENISOVA	{"email": "irina_denisova_15041984@postgrespro.ru", "phone": "+70268036762"}
0005433181433	9F4BCA	5164 438088	GALINA MAKAROVA	{"email": "galinamakarova.24031965@postgrespro.ru", "phone": "+70049947629"}
0005433181434	AEE6CF	0619 990383	NATALYA SERGEEVA	{"phone": "+70282548885"}
0005433181435	7F59CA	6569 264493	VALENTINA ZAYCEVA	{"phone": "+70854159195"}
0005433181436	75F28B	6715 306447	ALEVTINA SMIRNOVA	{"phone": "+70423842514"}
0005433181437	92BCD9	5766 536567	ALEKSANDR ILIN	{"phone": "+70472608079"}
0005433181438	0DDEFC	4593 964053	ALEKSANDR SOLOVEV	{"email": "solovev_a.071967@postgrespro.ru", "phone": "+70307845695"}
0005433181439	5190FC	8289 210261	VLADIMIR GORBUNOV	{"email": "gorbunov.v101968@postgrespro.ru", "phone": "+70392762109"}
0005433181440	5190FC	2452 027742	YURIY BELOV	{"email": "belov.y1978@postgrespro.ru", "phone": "+70567927929"}
0005433181441	CFEE8F	8324 189967	OLGA SIDOROVA	{"phone": "+70362122881"}
0005433181442	275713	6022 853776	MARIYA MALYSHEVA	{"phone": "+70323556480"}
0005433181443	D0FB30	2593 077830	YULIYA SOKOLOVA	{"phone": "+70986624473"}
0005433181444	C260D0	7016 969337	MARIYA TARASOVA	{"phone": "+70544187087"}
0005433181445	23BAA2	2592 291783	OLESYA TIKHONOVA	{"email": "olesya-tikhonova_1978@postgrespro.ru", "phone": "+70457122976"}
0005433181446	23BAA2	3467 829418	ALEKSANDR SAVELEV	{"phone": "+70499755740"}
0005433181447	52118B	4222 576614	ANDREY TIKHONOV	{"phone": "+70486022445"}
0005433181448	23BA54	2447 283369	TAISIYA GAVRILOVA	{"email": "tgavrilova.1977@postgrespro.ru", "phone": "+70197685006"}
0005433181449	FF2459	2416 432988	ANDREY MAKAROV	{"email": "makarov-andrey-111973@postgrespro.ru", "phone": "+70454194766"}
0005433181450	F50C12	6927 082055	ALEKSEY KUZNECOV	{"email": "kuznecov.a.1963@postgrespro.ru", "phone": "+70839183909"}
0005433181451	F50C12	8057 327917	TATYANA VOROBEVA	{"email": "vorobevatatyana-07101974@postgrespro.ru", "phone": "+70084291703"}
0005433181452	70BDB3	2979 378730	VLADIMIR DAVYDOV	{"email": "davydov_v_041984@postgrespro.ru", "phone": "+70686242122"}
0005433181453	2C09AE	1630 599362	VALENTINA MOROZOVA	{"email": "morozova.valentina-28051970@postgrespro.ru", "phone": "+70798420067"}
0005433181454	EB953D	8360 188074	VLADIMIR BELOV	{"email": "belov.vladimir.1974@postgrespro.ru", "phone": "+70480900911"}
0005433181455	6D34A7	1899 840621	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir15031976@postgrespro.ru", "phone": "+70679149390"}
0005433181456	C243E5	6209 999806	NIKOLAY ZAYCEV	{"email": "nikolay.zaycev22081967@postgrespro.ru", "phone": "+70161525212"}
0005433181457	9DA486	1562 774299	VLADIMIR VOROBEV	{"phone": "+70584510500"}
0005433181458	BC50B3	4137 859016	OLGA NIKITINA	{"phone": "+70156519801"}
0005433181459	BC50B3	8298 694505	LYUDMILA KONDRATEVA	{"phone": "+70817764155"}
0005433181460	886327	3789 169240	TATYANA SOKOLOVA	{"phone": "+70871349039"}
0005433181461	14D976	3980 044860	ANASTASIYA BELOVA	{"email": "anastasiya-belova.1981@postgrespro.ru", "phone": "+70728165966"}
0005433181462	EEA576	3202 103077	LYUBOV GERASIMOVA	{"phone": "+70670886353"}
0005433181463	A4C3C9	2258 251075	ANNA ANTONOVA	{"phone": "+70430755121"}
0005433181464	55BD0A	4425 611306	VLADIMIR FILIPPOV	{"email": "filippov.v20071968@postgrespro.ru", "phone": "+70331267163"}
0005433181465	9017DC	5854 491742	ELENA TIMOFEEVA	{"email": "timofeeva.elena.09021973@postgrespro.ru", "phone": "+70460672803"}
0005433181466	9017DC	5033 971349	ANZHELIKA KONOVALOVA	{"email": "anzhelika-konovalova_121972@postgrespro.ru", "phone": "+70523853222"}
0005433181467	5D082C	2473 019303	VALENTINA SMIRNOVA	{"email": "smirnovavalentina-13111969@postgrespro.ru", "phone": "+70413345998"}
0005433181468	5D082C	0406 280648	ALEKSEY KARPOV	{"phone": "+70282047697"}
0005433181469	972079	6232 138633	NINA AFANASEVA	{"email": "afanaseva_n_1979@postgrespro.ru", "phone": "+70790504949"}
0005433181470	A74434	6910 022126	VERA TIMOFEEVA	{"phone": "+70126216173"}
0005433181471	737732	7752 752460	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov.02071972@postgrespro.ru", "phone": "+70396068350"}
0005433181472	E775BF	8993 681408	SERGEY NIKITIN	{"phone": "+70530812160"}
0005433181473	E775BF	9339 119713	OLGA KUDRYASHOVA	{"email": "kudryashovao.031982@postgrespro.ru", "phone": "+70533717873"}
0005433181474	4B68C3	6661 560227	VLADIMIR FEDOROV	{"phone": "+70829771427"}
0005433181475	4B68C3	1449 298935	ANTON SEMENOV	{"email": "semenovanton_16071973@postgrespro.ru", "phone": "+70076890925"}
0005433181476	4327AC	0647 568627	ROMAN KAZAKOV	{"phone": "+70842470770"}
0005433181477	6D2E77	7894 821491	VLADIMIR FEDOROV	{"email": "fedorov.vladimir14091984@postgrespro.ru", "phone": "+70046195415"}
0005433181478	FE1FF6	7732 561654	NATALYA ZAYCEVA	{"email": "zayceva-natalya-1971@postgrespro.ru", "phone": "+70206206138"}
0005433181479	F39240	3462 076410	ANATOLIY ANDREEV	{"phone": "+70284384525"}
0005433181480	F39240	6251 069396	YURIY VASILEV	{"email": "vasilevy-18011968@postgrespro.ru", "phone": "+70489265147"}
0005433181481	F39240	5654 573210	DMITRIY MATVEEV	{"phone": "+70843014675"}
0005433181482	A87552	9608 836916	GENNADIY SOKOLOV	{"phone": "+70987863862"}
0005433181483	2A7FCB	4185 044568	ZLATA BORISOVA	{"phone": "+70187187666"}
0005433181484	2A7FCB	9086 255650	ALEKSANDR POPOV	{"phone": "+70335674883"}
0005433181485	356DF7	0357 508029	IRINA BARANOVA	{"email": "baranova.irina-031997@postgrespro.ru", "phone": "+70236236488"}
0005433181486	D5E138	1265 752597	VERA KOZLOVA	{"email": "v.kozlova_111965@postgrespro.ru", "phone": "+70989713345"}
0005433181487	D5E138	9488 909867	VLADIMIR DENISOV	{"phone": "+70397920659"}
0005433181488	113574	9888 906792	OLGA ROMANOVA	{"email": "o-romanova.1969@postgrespro.ru", "phone": "+70118974334"}
0005433181489	B1CDED	3866 821880	VALERIYA FEDOROVA	{"email": "fedorova_valeriya_1968@postgrespro.ru", "phone": "+70388919994"}
0005433181490	0EE135	9902 175341	MARINA FADEEVA	{"phone": "+70283278920"}
0005433181658	A57E99	9135 196804	LYUDMILA ZHUKOVA	{"phone": "+70221357646"}
0005433181491	4FED85	2093 246680	DMITRIY ORLOV	{"email": "dmitriy-orlov.121968@postgrespro.ru", "phone": "+70618059625"}
0005433181492	E0AD67	3184 200777	ANDREY ILIN	{"phone": "+70029035980"}
0005433181493	E758E5	1754 823680	NADEZHDA MELNIKOVA	{"phone": "+70015226936"}
0005433181494	65B66B	7992 818314	STEPAN MARTYNOV	{"phone": "+70228675586"}
0005433181495	65B66B	5343 039667	ELENA FEDOROVA	{"phone": "+70729079354"}
0005433181496	A901D6	3346 858935	VALERIYA NIKOLAEVA	{"email": "valeriyanikolaeva1976@postgrespro.ru", "phone": "+70681342361"}
0005433181497	A901D6	4664 723214	ALEKSANDR NIKOLAEV	{"email": "nikolaeva.24051963@postgrespro.ru", "phone": "+70816294400"}
0005433181498	A2C9E2	1010 779846	KONSTANTIN TIMOFEEV	{"email": "ktimofeev.1966@postgrespro.ru", "phone": "+70490984908"}
0005433181499	4B7307	3904 145846	ALEKSEY PETROV	{"phone": "+70318619529"}
0005433181500	4B7307	2409 997176	ALEKSANDR NIKOLAEV	{"email": "nikolaev_aleksandr-1961@postgrespro.ru", "phone": "+70890125672"}
0005433181501	9216E0	8227 788079	VERONIKA KRASNOVA	{"email": "veronika_krasnova-101973@postgrespro.ru", "phone": "+70649398721"}
0005433181502	9216E0	3200 031179	OLEG GERASIMOV	{"email": "o_gerasimov.121979@postgrespro.ru", "phone": "+70894098881"}
0005433181503	9216E0	2694 421616	LYUDMILA ABRAMOVA	{"phone": "+70591997610"}
0005433181504	C156C9	1049 899139	VIKTOR SEMENOV	{"phone": "+70693838322"}
0005433181505	50CEF6	6521 416334	NAILYA VOLKOVA	{"email": "volkova.nailya_1973@postgrespro.ru", "phone": "+70795358816"}
0005433181506	9F57D9	8749 728020	VIKTOR BELOV	{"email": "v-belov_1977@postgrespro.ru", "phone": "+70123883539"}
0005433181507	4D7F7E	8343 972305	SERGEY MAKSIMOV	{"email": "s.maksimov02091966@postgrespro.ru", "phone": "+70326674326"}
0005433181508	F20762	3429 951627	MIKHAIL KUZNECOV	{"email": "m-kuznecov.28061966@postgrespro.ru", "phone": "+70075779160"}
0005433181509	D53CD6	6223 712146	ANDREY KUZNECOV	{"phone": "+70879087952"}
0005433181510	D53CD6	6779 479347	VALERIY GRIGOREV	{"email": "v_grigorev_1981@postgrespro.ru", "phone": "+70862212403"}
0005433181511	D735D4	8272 998258	TAMARA MOROZOVA	{"email": "t-morozova-1960@postgrespro.ru", "phone": "+70413331598"}
0005433181512	0847A6	4440 371031	SVETLANA NIKOLAEVA	{"email": "snikolaeva-1984@postgrespro.ru", "phone": "+70813777728"}
0005433181513	BD4A8C	9886 265409	NATALYA MOISEEVA	{"email": "moiseevan_1979@postgrespro.ru", "phone": "+70387251982"}
0005433181514	3EB396	0698 142204	EDUARD KUZMIN	{"email": "e.kuzmin.1964@postgrespro.ru", "phone": "+70698870741"}
0005433181515	F7EFB0	8831 773320	VIKTOR KOROLEV	{"phone": "+70788893141"}
0005433181516	B23B54	6577 648662	SVETLANA STEPANOVA	{"phone": "+70764426368"}
0005433181517	B23B54	0509 796580	ANASTASIYA MIRONOVA	{"email": "a_mironova-081976@postgrespro.ru", "phone": "+70651181186"}
0005433181518	B60D6B	5431 222981	NINA ZAKHAROVA	{"phone": "+70554579565"}
0005433181519	836FBC	7552 358615	NIKOLAY MOROZOV	{"email": "n-morozov04041969@postgrespro.ru", "phone": "+70567681078"}
0005433181520	836FBC	4201 607729	IVAN PETROV	{"phone": "+70388720688"}
0005433181521	55B6BE	3688 880003	ALEKSANDR VOLKOV	{"email": "a_volkov02071969@postgrespro.ru", "phone": "+70178085824"}
0005433181522	6C2E07	7169 751977	IRINA NIKITINA	{"phone": "+70916276033"}
0005433181523	6C2E07	2328 965956	ANVAR NIKOLAEV	{"phone": "+70004199454"}
0005433181524	7CEE09	6568 234762	LIDIYA KONDRATEVA	{"phone": "+70504575271"}
0005433181525	B0BE64	5188 793557	NATALYA MAKAROVA	{"phone": "+70076909667"}
0005433181526	4B47C3	8214 557001	YURIY OSIPOV	{"email": "osipovyuriy_081970@postgrespro.ru", "phone": "+70324799582"}
0005433181527	4B47C3	2511 051470	ALEKSANDRA KONDRATEVA	{"phone": "+70655633213"}
0005433181528	1706A3	3090 048037	IRINA POPOVA	{"phone": "+70462216801"}
0005433181529	1706A3	4378 209364	ANNA POPOVA	{"email": "a.popova_1976@postgrespro.ru", "phone": "+70626798086"}
0005433181530	959253	8283 306949	TATYANA KOLESNIKOVA	{"email": "kolesnikova-t071971@postgrespro.ru", "phone": "+70380076082"}
0005433181531	DF5960	7531 500955	SERGEY ALEKSEEV	{"phone": "+70532632388"}
0005433181532	A7EA88	0501 547593	IRINA ERMAKOVA	{"email": "irina.ermakova1967@postgrespro.ru", "phone": "+70293037565"}
0005433181533	58F45E	7635 041182	VYACHESLAV VASILEV	{"phone": "+70181897141"}
0005433181534	58F45E	2882 357640	NATALYA FEDOROVA	{"phone": "+70338932230"}
0005433181535	AD8A18	6708 903936	SERGEY FEDOROV	{"email": "sergey-fedorov11111976@postgrespro.ru", "phone": "+70661714649"}
0005433181536	AD8A18	5263 371934	ANDREY VOLKOV	{"email": "a-volkov_031974@postgrespro.ru", "phone": "+70736438034"}
0005433181537	C190B1	9021 242494	LYUBOV IVANOVA	{"email": "ivanoval121978@postgrespro.ru", "phone": "+70300376182"}
0005433181538	C190B1	7950 584486	NINA TIMOFEEVA	{"phone": "+70052030344"}
0005433181539	33BBB3	9413 617281	ZOYA ALEKSEEVA	{"email": "zoya_alekseeva_1973@postgrespro.ru", "phone": "+70488463424"}
0005433181540	33BBB3	7146 847431	ANNA SCHERBAKOVA	{"email": "a_scherbakova_061986@postgrespro.ru", "phone": "+70698801305"}
0005433181541	DB4FCD	0148 751036	LYUBOV OVCHINNIKOVA	{"email": "lyubov_ovchinnikova-14051973@postgrespro.ru", "phone": "+70835777395"}
0005433181542	5DF125	0122 908600	MARIYA KOLESNIKOVA	{"phone": "+70973164292"}
0005433181543	5DF125	0921 669370	YAROSLAV KUZNECOV	{"phone": "+70455865553"}
0005433181544	5DF125	3992 715589	LYUBOV NIKIFOROVA	{"email": "lyubovnikiforova_1973@postgrespro.ru", "phone": "+70162407032"}
0005433181545	2D524F	7679 074249	VLADIMIR MOROZOV	{"phone": "+70114702110"}
0005433181546	2D524F	5159 348260	VYACHESLAV FILIPPOV	{"phone": "+70098346908"}
0005433181547	4E4CD1	0345 217039	TATYANA KARPOVA	{"email": "karpova-tatyana_20031974@postgrespro.ru", "phone": "+70028217892"}
0005433181548	78D8DC	8520 458850	VALERIY KUZMIN	{"email": "valeriy-kuzmin-20111972@postgrespro.ru", "phone": "+70867217719"}
0005433181549	3090F1	7281 886732	IRINA TARASOVA	{"email": "tarasova-i_21051967@postgrespro.ru", "phone": "+70036793677"}
0005433181550	3090F1	1886 501990	PAVEL ANDREEV	{"phone": "+70471346105"}
0005433181551	7D0BE8	9055 489108	IRINA KAZAKOVA	{"email": "kazakova-irina111982@postgrespro.ru", "phone": "+70270617636"}
0005433181552	7D0BE8	3890 332480	OLGA NAZAROVA	{"email": "olga-nazarova.26011974@postgrespro.ru", "phone": "+70574582492"}
0005433181553	7D0BE8	7581 997212	GENNADIY KUZMIN	{"phone": "+70094966476"}
0005433181554	F3FEC4	1580 109489	SERGEY NOVIKOV	{"email": "sergey.novikov1977@postgrespro.ru", "phone": "+70917265237"}
0005433181555	19A4F9	5479 810788	NIKOLAY SOKOLOV	{"email": "nikolaysokolov_081970@postgrespro.ru", "phone": "+70138581974"}
0005433181556	19A4F9	0441 030196	EVDOKIYA GAVRILOVA	{"email": "egavrilova15111966@postgrespro.ru", "phone": "+70879808690"}
0005433181557	E91928	9857 018710	DMITRIY ZHURAVLEV	{"phone": "+70477677323"}
0005433181558	E91928	7325 694094	GALINA ZHUKOVA	{"phone": "+70381933917"}
0005433181559	07745B	4047 092213	OLEG ANDREEV	{"email": "andreevoleg_111966@postgrespro.ru", "phone": "+70301099400"}
0005433181560	B27799	7491 873535	NATALYA KISELEVA	{"phone": "+70680835490"}
0005433181561	BBD6C9	7028 687265	FANIS DAVYDOV	{"email": "fdavydov.121969@postgrespro.ru", "phone": "+70966059762"}
0005433181562	81FC0B	5801 542008	ALEKSANDR ZAKHAROV	{"phone": "+70660656517"}
0005433181563	81FC0B	5537 562885	SVETLANA FEDOROVA	{"phone": "+70753960922"}
0005433181564	57AF70	1272 352781	GALINA SIDOROVA	{"phone": "+70402421284"}
0005433181565	72FA3F	5515 335642	ANASTASIYA EFREMOVA	{"email": "efremova.anastasiya_1967@postgrespro.ru", "phone": "+70450007448"}
0005433181566	D6A98B	5367 685853	SERGEY ZHURAVLEV	{"phone": "+70444259633"}
0005433181567	D6A98B	9341 564172	LARISA DAVYDOVA	{"email": "larisa_davydova-1977@postgrespro.ru", "phone": "+70562402177"}
0005433181568	562F2D	0114 402105	LIDIYA ABRAMOVA	{"email": "abramova_l1974@postgrespro.ru", "phone": "+70599012791"}
0005433181569	69CE2A	0355 038003	ALEKSANDR EGOROV	{"email": "egorov.aleksandr061961@postgrespro.ru", "phone": "+70104601325"}
0005433181570	69CE2A	5936 127653	KRISTINA MARTYNOVA	{"phone": "+70351533810"}
0005433181571	2C4D0C	9788 326888	ALEKSANDR ALEKSANDROV	{"email": "aleksandr.aleksandrov.19091983@postgrespro.ru", "phone": "+70535948362"}
0005433181572	2C4D0C	9341 623583	SVETLANA ABRAMOVA	{"email": "s.abramova.13021974@postgrespro.ru", "phone": "+70175129831"}
0005433181573	2C4D0C	7248 493501	ALEVTINA KOVALEVA	{"email": "alevtina-kovaleva-1976@postgrespro.ru", "phone": "+70515985873"}
0005433181574	B752C1	4235 740110	ANNA PETROVA	{"email": "petrova_a-1970@postgrespro.ru", "phone": "+70806845803"}
0005433181575	B752C1	6523 598940	SERGEY SCHERBAKOV	{"phone": "+70873361124"}
0005433181576	695A3D	3876 629606	SERGEY FOMIN	{"email": "fomin.s121976@postgrespro.ru", "phone": "+70153433597"}
0005433181577	695A3D	6736 370748	ALINA ROMANOVA	{"phone": "+70625224925"}
0005433181578	03380D	8662 271778	VALERIY VASILEV	{"phone": "+70509577091"}
0005433181579	03380D	4566 670463	ASIYA MOROZOVA	{"email": "morozova-a.021968@postgrespro.ru", "phone": "+70495635185"}
0005433181638	6E1C87	7377 944748	VLADIMIR TIKHONOV	{"phone": "+70320479281"}
0005433181580	2C451D	7246 797992	IVAN TIKHONOV	{"email": "tikhonov_i-10111977@postgrespro.ru", "phone": "+70950923752"}
0005433181581	2C451D	2590 341927	LYUBOV ROMANOVA	{"email": "lyubov_romanova_1973@postgrespro.ru", "phone": "+70888575416"}
0005433181582	F0257F	7902 229177	TAMARA BORISOVA	{"email": "borisova-tamara-06091968@postgrespro.ru", "phone": "+70502422154"}
0005433181583	F0257F	7898 044420	LYUDMILA POPOVA	{"email": "lpopova081978@postgrespro.ru", "phone": "+70784534159"}
0005433181584	1EBCF6	6666 706591	ALLA GORBUNOVA	{"phone": "+70916008159"}
0005433181585	6DD88F	9346 248758	IVAN MIRONOV	{"phone": "+70158293044"}
0005433181586	741015	7943 040336	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.n.13061973@postgrespro.ru", "phone": "+70649747340"}
0005433181587	D87A47	6676 245447	VLADIMIR SERGEEV	{"email": "sergeevvladimir_111966@postgrespro.ru", "phone": "+70504670104"}
0005433181588	F76959	6426 998354	VALENTINA SOKOLOVA	{"email": "vsokolova.1961@postgrespro.ru", "phone": "+70465601496"}
0005433181589	F76959	1159 866401	NIKOLAY MAKAROV	{"phone": "+70983317266"}
0005433181590	D41C9B	6353 656818	ELIZAVETA NIKITINA	{"phone": "+70168604747"}
0005433181591	B89152	7883 707098	ELENA POLYAKOVA	{"email": "elena-polyakova-091962@postgrespro.ru", "phone": "+70474997827"}
0005433181592	B89152	4987 494245	EVGENIY KUZNECOV	{"email": "e-kuznecov_1968@postgrespro.ru", "phone": "+70160656627"}
0005433181593	420F6D	4309 348714	ELENA POPOVA	{"email": "popovaelena-26081966@postgrespro.ru", "phone": "+70563859791"}
0005433181594	42040A	2229 449750	NATALIYA GRISHINA	{"email": "n-grishina081980@postgrespro.ru", "phone": "+70953230931"}
0005433181595	371228	5850 854146	LARISA BARANOVA	{"phone": "+70427940290"}
0005433181596	22E8CE	2717 035182	LYUDMILA SERGEEVA	{"email": "l-sergeeva.121965@postgrespro.ru", "phone": "+70009358145"}
0005433181597	307DF4	9621 996656	SVETLANA NIKITINA	{"phone": "+70505082612"}
0005433181598	183958	7515 719345	VLADIMIR GUSEV	{"email": "vladimir.gusev_25081972@postgrespro.ru", "phone": "+70674244650"}
0005433181599	183958	4002 553491	ROMAN KUZMIN	{"email": "r_kuzmin.02031973@postgrespro.ru", "phone": "+70872491773"}
0005433181600	4C3B2F	5844 845892	NADEZHDA VASILEVA	{"email": "nadezhda.vasileva1977@postgrespro.ru", "phone": "+70841958168"}
0005433181601	EEFF2F	1145 764538	LYUBOV SOKOLOVA	{"email": "lyubov-sokolova1972@postgrespro.ru", "phone": "+70012547117"}
0005433181602	6764A5	6882 472733	EVGENIY POPOV	{"email": "popov.e22121976@postgrespro.ru", "phone": "+70188536581"}
0005433181603	6764A5	3047 801431	SNEZHANA YUDINA	{"email": "snezhanayudina.17101975@postgrespro.ru", "phone": "+70680400526"}
0005433181604	2E8266	6528 466930	ALEKSEY EGOROV	{"email": "aleksey_egorov-1959@postgrespro.ru", "phone": "+70778759733"}
0005433181605	2E8266	1694 781842	LYUBOV KOVALEVA	{"email": "lyubovkovaleva_1972@postgrespro.ru", "phone": "+70470416962"}
0005433181606	04DB2B	3596 750627	MAKSIM PETROV	{"email": "maksim.petrov.21061977@postgrespro.ru", "phone": "+70400033961"}
0005433181607	90276B	7342 481302	PETR KUZNECOV	{"email": "kuznecov.petr1965@postgrespro.ru", "phone": "+70633255460"}
0005433181608	E507A1	9244 527465	YULIYA POPOVA	{"email": "yuliyapopova_111992@postgrespro.ru", "phone": "+70167732867"}
0005433181609	E507A1	9417 062328	MARINA ALEKSEEVA	{"email": "marinaalekseeva_011970@postgrespro.ru", "phone": "+70329750602"}
0005433181610	E507A1	2446 223360	NATALYA OSIPOVA	{"email": "natalya.osipova-121971@postgrespro.ru", "phone": "+70299779071"}
0005433181611	885CE8	3196 185149	DMITRIY TIKHONOV	{"phone": "+70249620911"}
0005433181612	909561	4946 252305	DMITRIY KUZMIN	{"phone": "+70789980592"}
0005433181613	909561	5326 421059	ALEKSANDR ABRAMOV	{"phone": "+70253356531"}
0005433181614	FEC9FF	4768 214363	ELENA VLASOVA	{"email": "vlasova-e_091978@postgrespro.ru", "phone": "+70182045531"}
0005433181615	FEC9FF	7165 095622	RUSLAN BELOV	{"phone": "+70753800193"}
0005433181616	372DC7	9544 321660	OLEG CHERNOV	{"phone": "+70105425687"}
0005433181617	3C62B9	6411 777691	MIKHAIL IVANOV	{"phone": "+70468075863"}
0005433181618	3C62B9	4153 832595	ILDAR KULIKOV	{"phone": "+70917626502"}
0005433181619	104E3D	4511 689370	ANDREY ZHURAVLEV	{"phone": "+70165183194"}
0005433181620	5A7234	5886 051203	VLADIMIR PAVLOV	{"email": "pavlovv-091972@postgrespro.ru", "phone": "+70624369588"}
0005433181621	A81B40	3794 139875	DMITRIY PAVLOV	{"email": "dmitriy-pavlov-1970@postgrespro.ru", "phone": "+70012529196"}
0005433181622	8E5E2F	7694 644011	ALEKSANDRA KUZMINA	{"email": "aleksandra.kuzmina-121983@postgrespro.ru", "phone": "+70628508328"}
0005433181623	8E5E2F	4891 516313	DANILA TIKHONOV	{"email": "tikhonov.danila_041970@postgrespro.ru", "phone": "+70094641051"}
0005433181624	B68421	9252 188384	NADEZHDA MEDVEDEVA	{"email": "nadezhda.medvedeva_101978@postgrespro.ru", "phone": "+70182157896"}
0005433181625	815A49	9930 183508	EKATERINA NAZAROVA	{"phone": "+70696040498"}
0005433181626	FA8F15	3923 159743	ALEKSANDR ANDREEV	{"phone": "+70827189610"}
0005433181627	FA8F15	1929 405121	MARIYA BELOVA	{"phone": "+70952346831"}
0005433181628	F2B4A6	1788 376391	EVGENIY ROMANOV	{"email": "romanov_evgeniy-15051967@postgrespro.ru", "phone": "+70382387387"}
0005433181629	F761C3	3744 987582	NATALYA ERMAKOVA	{"phone": "+70604865179"}
0005433181630	34574A	8483 992683	VALENTINA GERASIMOVA	{"phone": "+70415845176"}
0005433181631	8CE59C	6157 380824	ANGELINA LAZAREVA	{"phone": "+70517977855"}
0005433181632	B61C25	6925 777963	ALEKSANDR KOZLOV	{"phone": "+70830006190"}
0005433181633	B61C25	5386 603248	ZOYA DENISOVA	{"phone": "+70639496126"}
0005433181634	736767	0766 059802	VALENTINA ROMANOVA	{"email": "romanova_valentina_20091981@postgrespro.ru", "phone": "+70823569635"}
0005433181635	736767	8550 190212	VSEVOLOD NIKOLAEV	{"email": "v-nikolaev-1975@postgrespro.ru", "phone": "+70640730558"}
0005433181636	03BB5E	4854 392424	PAVEL ZHURAVLEV	{"email": "zhuravlev.p1966@postgrespro.ru", "phone": "+70311031482"}
0005433181637	6E1C87	7685 704489	LIDIYA ROMANOVA	{"phone": "+70849667134"}
0005433181639	40D6E1	5283 664460	LYUBOV SERGEEVA	{"email": "sergeeval1978@postgrespro.ru", "phone": "+70596228154"}
0005433181640	40D6E1	8264 802758	ALEKSEY KULIKOV	{"phone": "+70912091838"}
0005433181641	D759C5	5141 070172	KIRILL IVANOV	{"email": "ivanov-k_061968@postgrespro.ru", "phone": "+70407554646"}
0005433181642	D759C5	7018 813991	LIDIYA VASILEVA	{"email": "vasileva.l031972@postgrespro.ru", "phone": "+70015231811"}
0005433181643	0DA355	4624 846800	VALENTINA BORISOVA	{"phone": "+70331581220"}
0005433181644	0DA355	5318 197841	IVAN IVANOV	{"phone": "+70100127319"}
0005433181645	8905A4	9646 937960	VALENTIN FEDOTOV	{"phone": "+70379877246"}
0005433181646	8905A4	5050 019789	MATVEY BORISOV	{"email": "mborisov29011958@postgrespro.ru", "phone": "+70795248659"}
0005433181647	59DE1E	5554 322593	MARGARITA ILINA	{"phone": "+70299577566"}
0005433181648	89D8C8	5915 781065	MARINA ZHUKOVA	{"email": "m_zhukova_1977@postgrespro.ru", "phone": "+70146797379"}
0005433181649	6AFC6A	8351 364471	YULIYA KOZLOVA	{"email": "ykozlova_1965@postgrespro.ru", "phone": "+70271540279"}
0005433181650	B07B84	3842 131428	NATALYA BORISOVA	{"phone": "+70539628195"}
0005433181651	6C8C14	4245 290207	YULIYA KUDRYASHOVA	{"email": "yuliyakudryashova111967@postgrespro.ru", "phone": "+70909979671"}
0005433181652	6C8C14	5545 853166	LEONTIY MATVEEV	{"phone": "+70575548100"}
0005433181653	CD54AD	9056 393087	GALINA NAZAROVA	{"phone": "+70077696766"}
0005433181654	CD54AD	7422 085018	EVGENIY KUZMIN	{"phone": "+70150568693"}
0005433181655	CD54AD	0673 503204	ANASTASIYA SEMENOVA	{"phone": "+70117748085"}
0005433181656	37FDAF	9750 879180	EKATERINA KUZNECOVA	{"email": "kuznecova_ekaterina-101980@postgrespro.ru", "phone": "+70576433867"}
0005433181657	A57E99	2036 647332	ARTEM KUZNECOV	{"email": "kuznecov-artem-1971@postgrespro.ru", "phone": "+70390870154"}
0005433181659	A371F2	6847 586386	RUSLAN NAZAROV	{"email": "nazarovruslan_20011967@postgrespro.ru", "phone": "+70638264157"}
0005433181660	C63512	4630 941408	SERGEY POPOV	{"email": "s_popov.111960@postgrespro.ru", "phone": "+70671706613"}
0005433181661	18F20A	0401 759941	ALEKSANDR KISELEV	{"email": "kiselevaleksandr1966@postgrespro.ru", "phone": "+70076300488"}
0005433181662	B1C531	7955 693249	SVETLANA NOVIKOVA	{"phone": "+70233611088"}
0005433181663	B1C531	0057 357922	NATALYA PETROVA	{"phone": "+70730044453"}
0005433181664	D20D65	6377 520064	OLGA YAKOVLEVA	{"email": "yakovleva.olga_121981@postgrespro.ru", "phone": "+70728509442"}
0005433181665	A58998	7657 967017	ARSEN IVANOV	{"email": "ivanov.a101973@postgrespro.ru", "phone": "+70061704445"}
0005433181666	C6DFEA	9755 100396	MARIYA KOVALEVA	{"email": "kovalevam20081975@postgrespro.ru", "phone": "+70759868847"}
0005433181667	C6DFEA	0855 014008	ALEKSANDR KULIKOV	{"email": "kulikov-a-04111979@postgrespro.ru", "phone": "+70821540037"}
0005433181668	872CE5	6654 020552	NINA MELNIKOVA	{"email": "nina_melnikova.1969@postgrespro.ru", "phone": "+70024463363"}
0005433181669	872CE5	3435 545012	ALISA MARTYNOVA	{"phone": "+70458706363"}
0005433181670	7410F6	5632 827421	ELENA SMIRNOVA	{"email": "esmirnova_1974@postgrespro.ru", "phone": "+70782614395"}
0005433181671	C1283A	8645 426622	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev_091958@postgrespro.ru", "phone": "+70281949310"}
0005433181672	A6AA86	8985 819178	NATALYA ANDREEVA	{"email": "andreeva-n-011979@postgrespro.ru", "phone": "+70965013791"}
0005433181673	A6AA86	4513 982722	EVGENIY DMITRIEV	{"phone": "+70097898592"}
0005433181674	6C99A3	7130 849002	DENIS KUZNECOV	{"email": "d-kuznecov1967@postgrespro.ru", "phone": "+70073895461"}
0005433181675	6C99A3	1475 332304	DARYA SOKOLOVA	{"email": "darya-sokolova13091978@postgrespro.ru", "phone": "+70939231256"}
0005433181676	DE9883	9401 963249	YULIYA FROLOVA	{"phone": "+70217415387"}
0005433181677	08C779	8342 073026	ARKADIY KUZMIN	{"email": "kuzmin_a-111987@postgrespro.ru", "phone": "+70749573732"}
0005433181678	08C779	2366 229485	VALENTINA ORLOVA	{"email": "orlova-valentina.1970@postgrespro.ru", "phone": "+70264883960"}
0005433181679	DD54F7	4491 108764	ELIZAVETA NIKITINA	{"email": "elizavetanikitina_1987@postgrespro.ru", "phone": "+70251519025"}
0005433181680	DD54F7	7578 416902	RAFIK ZAYCEV	{"email": "rzaycev-021961@postgrespro.ru", "phone": "+70012599255"}
0005433181681	8E6B26	3688 275597	PLATON KONOVALOV	{"email": "konovalov.platon_06121971@postgrespro.ru", "phone": "+70144571793"}
0005433181682	8E6B26	1330 563061	DARYA VASILEVA	{"email": "dvasileva.1984@postgrespro.ru", "phone": "+70802626057"}
0005433181683	519AC0	7475 419400	LEONID GORBUNOV	{"phone": "+70052329852"}
0005433181684	40BE7D	3590 603362	VIKTORIYA TARASOVA	{"phone": "+70329297202"}
0005433181685	F8A697	9252 398992	LYUBOV IVANOVA	{"email": "ivanova_lyubov-1978@postgrespro.ru", "phone": "+70118293605"}
0005433181686	FC3A2B	3545 638208	BORIS IVANOV	{"email": "boris_ivanov_041973@postgrespro.ru", "phone": "+70323684174"}
0005433181687	0A392A	6496 873549	EGOR PAVLOV	{"email": "pavlov.egor_1984@postgrespro.ru", "phone": "+70942435870"}
0005433181688	1F9FA7	3170 951114	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov.111971@postgrespro.ru", "phone": "+70598676081"}
0005433181689	EFA6E9	4527 962777	GULFIYA MOISEEVA	{"phone": "+70319635650"}
0005433181690	EFA6E9	4982 683466	VIKTOR KUZNECOV	{"phone": "+70731263909"}
0005433181691	D6CB0A	2955 526788	SERGEY PETROV	{"phone": "+70483422545"}
0005433181692	EE856C	2955 196813	MARIYA ABRAMOVA	{"email": "m.abramova-061966@postgrespro.ru", "phone": "+70350425184"}
0005433181693	E65277	9951 636748	OLGA IVANOVA	{"phone": "+70961929750"}
0005433181694	FA1CCB	1556 004951	VLADIMIR SERGEEV	{"phone": "+70671839508"}
0005433181695	79C0D0	5657 468952	OLEG IVANOV	{"email": "olegivanov-27071974@postgrespro.ru", "phone": "+70357076526"}
0005433181696	F0BE34	3159 507458	MIKHAIL ZAYCEV	{"email": "zaycevmikhail.09081982@postgrespro.ru", "phone": "+70940862808"}
0005433181697	F0BE34	6086 941312	ROZA LUKYANOVA	{"email": "rlukyanova.061971@postgrespro.ru", "phone": "+70906191220"}
0005433181698	764ECE	8164 826500	ALEKSANDR ANDREEV	{"phone": "+70519319672"}
0005433181699	764ECE	1539 160979	MARINA KISELEVA	{"phone": "+70964022480"}
0005433181700	3B2073	8119 938217	ELENA EFREMOVA	{"phone": "+70572195348"}
0005433181701	098EA3	0946 051081	NIKOLAY KOROLEV	{"email": "korolevn_1973@postgrespro.ru", "phone": "+70231662738"}
0005433181702	B063E3	8271 896948	OLGA ANDREEVA	{"email": "andreeva-olga_041970@postgrespro.ru", "phone": "+70821366405"}
0005433181703	B063E3	2566 134328	VLADIMIR GERASIMOV	{"phone": "+70148354434"}
0005433181704	6295FB	9855 367612	OLGA LUKYANOVA	{"email": "lukyanovao-05091959@postgrespro.ru", "phone": "+70602135555"}
0005433181705	6295FB	3191 246116	VADIM SCHERBAKOV	{"email": "vadimscherbakov091967@postgrespro.ru", "phone": "+70119607616"}
0005433181706	61CA3F	2308 111160	IGOR MAKSIMOV	{"email": "maksimov-igor.1975@postgrespro.ru", "phone": "+70955049865"}
0005433181707	61CA3F	9080 655610	ELIZAVETA KUZNECOVA	{"email": "elizavetakuznecova021973@postgrespro.ru", "phone": "+70332864229"}
0005433181708	BA80CE	7414 443528	ROMAN BELOV	{"email": "belov-r1966@postgrespro.ru", "phone": "+70535212368"}
0005433181709	BA80CE	3346 933603	VALENTIN CHERNOV	{"email": "chernovv-101964@postgrespro.ru", "phone": "+70605755764"}
0005433181710	93C863	4089 352833	TATYANA MAKAROVA	{"email": "makarova.t041976@postgrespro.ru", "phone": "+70614912985"}
0005433181711	5A0CD5	2450 530516	NIKOLAY SMIRNOV	{"email": "nikolay_smirnov11111962@postgrespro.ru", "phone": "+70192480051"}
0005433181712	B30DFA	9345 619935	ANFISA MAKSIMOVA	{"phone": "+70216256392"}
0005433181713	0387F1	0060 055723	VLADIMIR KAZAKOV	{"phone": "+70384514763"}
0005433181714	1D5F8A	9384 626703	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.n1960@postgrespro.ru", "phone": "+70004173493"}
0005433181715	E9F049	1588 812423	ALEKSANDR SMIRNOV	{"phone": "+70984987363"}
0005433181716	E2A798	5551 513565	EVGENIY KONOVALOV	{"phone": "+70337780100"}
0005433181717	E2A798	0965 195490	IGOR SHEVCHENKO	{"phone": "+70907381539"}
0005433181718	AD148E	5027 242219	IRAIDA TROFIMOVA	{"email": "trofimova-iraida-1976@postgrespro.ru", "phone": "+70080251783"}
0005433181719	10EF42	7970 906824	OLGA ISAEVA	{"email": "olga.isaeva1972@postgrespro.ru", "phone": "+70272198295"}
0005433181720	320CE5	3614 625605	TAMARA FOMINA	{"phone": "+70123714984"}
0005433181721	6FD6EE	5568 720309	OKSANA KOZLOVA	{"email": "kozlovao.011969@postgrespro.ru", "phone": "+70655260719"}
0005433181722	87F9A8	9127 843301	ANATOLIY FEDOROV	{"email": "fedorov_a_20041974@postgrespro.ru", "phone": "+70722718407"}
0005433181723	118582	5711 306972	ALEKSANDR MOISEEV	{"phone": "+70755771756"}
0005433181724	A81E65	3469 912527	ANNA VOLKOVA	{"email": "volkova.a-031979@postgrespro.ru", "phone": "+70196588290"}
0005433181725	8EED8B	2806 589205	NAIL MIRONOV	{"phone": "+70549952149"}
0005433181726	57180B	6382 965505	NATALIYA ANISIMOVA	{"phone": "+70194488979"}
0005433181727	6FB57A	1490 675117	MAKSIM GUSEV	{"phone": "+70196753059"}
0005433181728	EB8B42	1549 018787	YULIANA GRISHINA	{"email": "yuliana.grishina-1976@postgrespro.ru", "phone": "+70735514851"}
0005433181729	EB8B42	6901 698318	KLAVDIYA FOMINA	{"email": "k.fomina_081977@postgrespro.ru", "phone": "+70426842619"}
0005433181730	9DE8D6	0593 819850	OLGA LOGINOVA	{"email": "loginova.o_031975@postgrespro.ru", "phone": "+70679904881"}
0005433181731	7BFAD2	9636 070694	DENIS MIKHAYLOV	{"phone": "+70221381565"}
0005433181732	73E828	9978 194313	EVGENIYA GAVRILOVA	{"phone": "+70202323053"}
0005433181733	73E828	9180 643779	TATYANA POPOVA	{"email": "t_popova27101989@postgrespro.ru", "phone": "+70194639654"}
0005433181734	A023AC	8801 815364	KIRA NIKITINA	{"phone": "+70583477418"}
0005433181735	A023AC	5298 565852	NATALIYA ABRAMOVA	{"phone": "+70100881905"}
0005433181736	C847A7	4852 578277	ANDREY MAKAROV	{"email": "andrey_makarov_1968@postgrespro.ru", "phone": "+70073367273"}
0005433181737	BADA51	5839 809591	ELENA GORBUNOVA	{"phone": "+70470604420"}
0005433181738	47B62F	9052 864193	NIKOLAY SIDOROV	{"email": "nikolay_sidorov111966@postgrespro.ru", "phone": "+70327037268"}
0005433181739	34857C	8728 409058	TATYANA NAZAROVA	{"email": "nazarova_t_021968@postgrespro.ru", "phone": "+70045399770"}
0005433181740	4C49AF	9354 451516	YULIYA ZHURAVLEVA	{"phone": "+70547142104"}
0005433181741	87AF7D	5398 526161	SERGEY CHERNOV	{"email": "schernov_1972@postgrespro.ru", "phone": "+70036029907"}
0005433181742	2A283B	6675 587157	MARAT ZHUKOV	{"email": "zhukov.marat071970@postgrespro.ru", "phone": "+70557259795"}
0005433181743	100A44	4895 056038	VYACHESLAV IVANOV	{"phone": "+70468376645"}
0005433181744	2711F8	4473 548001	ARTUR PETROV	{"phone": "+70821837210"}
0005433181745	2711F8	5641 822612	MARIYA SMIRNOVA	{"email": "smirnova-m.30071971@postgrespro.ru", "phone": "+70896284957"}
0005433181746	CB5876	5061 258633	RAISA KRASNOVA	{"email": "r_krasnova1978@postgrespro.ru", "phone": "+70369541654"}
0005433181747	AFC89B	5054 225570	YURIY PETROV	{"phone": "+70663735723"}
0005433181748	905642	8897 020114	ALEKSANDR ZHUKOV	{"phone": "+70332138574"}
0005433181749	79DCBF	0502 235300	ANDREY SMIRNOV	{"phone": "+70722303020"}
0005433181750	913E6A	1423 718069	VITALIY MATVEEV	{"email": "vitaliymatveev.1968@postgrespro.ru", "phone": "+70334863244"}
0005433181751	C0E0D3	7188 306738	ANTON SIDOROV	{"phone": "+70458256489"}
0005433181752	C0E0D3	5027 624173	MIKHAIL ABRAMOV	{"email": "m_abramov-051975@postgrespro.ru", "phone": "+70086923604"}
0005433181753	5A83EF	8479 980007	ANNA DENISOVA	{"email": "anna_denisova.30011976@postgrespro.ru", "phone": "+70087604486"}
0005433181754	998512	6194 551841	VLADIMIR KUZNECOV	{"phone": "+70048515170"}
0005433181755	EC33E0	1899 318405	TATYANA ARKHIPOVA	{"email": "tarkhipova111966@postgrespro.ru", "phone": "+70104314059"}
0005433181756	EC0717	3006 441771	LYUDMILA NAZAROVA	{"phone": "+70513373784"}
0005433181757	3E08BC	5495 236151	DMITRIY NIKITIN	{"email": "d_nikitin_1954@postgrespro.ru", "phone": "+70170583118"}
0005433181758	471383	6517 180829	SVETLANA BELYAEVA	{"phone": "+70657214404"}
0005433181759	471383	4879 319706	VLADIMIR KULIKOV	{"email": "vladimirkulikov12071975@postgrespro.ru", "phone": "+70263408667"}
0005433181760	8DDC32	7377 210761	MIKHAIL MOISEEV	{"email": "mmoiseev.111957@postgrespro.ru", "phone": "+70117003166"}
0005433181761	543E77	4531 028982	IRINA POTAPOVA	{"email": "irinapotapova_23111963@postgrespro.ru", "phone": "+70549085425"}
0005433181762	543E77	1473 000210	ANNA ILINA	{"email": "anna.ilina_15101979@postgrespro.ru", "phone": "+70266377391"}
0005433181763	30C1CF	6000 093136	VLADIMIR KUZMIN	{"phone": "+70643308617"}
0005433181764	30C1CF	6653 228969	ANNA SERGEEVA	{"email": "sergeeva-anna.121973@postgrespro.ru", "phone": "+70012090495"}
0005433181765	933791	8337 633504	ALEKSANDR EGOROV	{"phone": "+70104874164"}
0005433181766	9ED071	8033 080858	VADIM MIRONOV	{"phone": "+70969537273"}
0005433181767	4C156B	8174 793570	EGOR ILIN	{"phone": "+70422327994"}
0005433181768	86ACA7	4195 874317	ALEKSANDRA POPOVA	{"phone": "+70043658702"}
0005433181769	E1268C	3536 970432	DMITRIY GUSEV	{"email": "gusev.d-1977@postgrespro.ru", "phone": "+70474429252"}
0005433181770	E1268C	1635 832526	VLADIMIR POPOV	{"phone": "+70909948476"}
0005433181771	108939	2537 834358	EVGENIY KUZNECOV	{"phone": "+70308017259"}
0005433181772	16897B	9547 800305	SERGEY GORBUNOV	{"email": "gorbunovs02041970@postgrespro.ru", "phone": "+70783310597"}
0005433181773	16897B	8274 881066	SERGEY MAKSIMOV	{"phone": "+70937349375"}
0005433181774	454197	5417 475271	ARTUR BORISOV	{"phone": "+70199546759"}
0005433181775	454197	4313 383352	ALEKSANDR CHERNOV	{"phone": "+70586828339"}
0005433181776	CA34C5	7333 183563	TATYANA IVANOVA	{"email": "ivanovat_17061976@postgrespro.ru", "phone": "+70358911960"}
0005433181777	2A1526	7532 111675	VALENTIN ILIN	{"email": "ilinv-1980@postgrespro.ru", "phone": "+70579830626"}
0005433181778	913C81	5322 570069	DENIS TIKHONOV	{"email": "denis.tikhonov-101979@postgrespro.ru", "phone": "+70799882727"}
0005433181779	CC6837	7521 102771	MARIYA MIKHAYLOVA	{"email": "mikhaylova_m.1986@postgrespro.ru", "phone": "+70133465593"}
0005433181780	1BE672	0354 557808	DANIIL MOISEEV	{"email": "daniil.moiseev29121970@postgrespro.ru", "phone": "+70029046370"}
0005433181781	1BE672	4334 589460	ALENA FADEEVA	{"phone": "+70832926084"}
0005433181782	9BE865	3696 505877	ALEKSANDRA ZAYCEVA	{"email": "aleksandra.zayceva101982@postgrespro.ru", "phone": "+70824701948"}
0005433181783	9BE865	9706 319637	ALEKSANDR CHERNOV	{"phone": "+70129058299"}
0005433181784	462780	7782 365458	VLADIMIR SOROKIN	{"email": "v.sorokin1977@postgrespro.ru", "phone": "+70788920993"}
0005433181785	C36612	1717 334953	SERGEY ABRAMOV	{"phone": "+70858396632"}
0005433181786	C36612	2363 362373	NADEZHDA MIRONOVA	{"email": "nadezhda.mironova.111965@postgrespro.ru", "phone": "+70851854587"}
0005433181787	C36612	6880 522377	VIKTOR ZAKHAROV	{"phone": "+70687853394"}
0005433181788	9BB347	5457 391605	VLADISLAV KUZMIN	{"phone": "+70206607423"}
0005433181789	FBD4EE	6525 004219	SERGEY DENISOV	{"email": "denisov_s021975@postgrespro.ru", "phone": "+70779518677"}
0005433181790	FBD4EE	1232 565728	YURIY KUZNECOV	{"phone": "+70872439800"}
0005433181791	FBD4EE	0684 911036	NIKOLAY MARTYNOV	{"email": "nikolay_martynov-081989@postgrespro.ru", "phone": "+70207068044"}
0005433181792	5627B7	2098 595778	VLADIMIR MAKSIMOV	{"phone": "+70057824802"}
0005433181793	5627B7	1470 795233	PAVEL TIMOFEEV	{"phone": "+70950687844"}
0005433181794	AD2C5D	6024 572734	OKSANA PETROVA	{"email": "petrova-o_081975@postgrespro.ru", "phone": "+70037414799"}
0005433181795	CCD65C	2516 122298	VITALIY FOMIN	{"email": "vitaliy-fomin.021954@postgrespro.ru", "phone": "+70971827905"}
0005433181796	A96B63	9265 489609	ALEKSANDR DMITRIEV	{"email": "dmitrieva.16081966@postgrespro.ru", "phone": "+70616475375"}
0005433181797	A96B63	9974 285818	DENIS IVANOV	{"email": "d.ivanov_1962@postgrespro.ru", "phone": "+70992300793"}
0005433181798	20B15F	6339 567685	YULIYA IVANOVA	{"phone": "+70640063275"}
0005433181799	20B15F	5363 229316	MARIYA KOZLOVA	{"phone": "+70356572620"}
0005433181800	20B15F	3218 453132	ANNA TARASOVA	{"phone": "+70349854874"}
0005433181801	5CB384	4495 581812	DMITRIY NAZAROV	{"phone": "+70942799080"}
0005433181802	5CB384	9850 484412	SERGEY NIKOLAEV	{"email": "sergey.nikolaev-20111986@postgrespro.ru", "phone": "+70574070896"}
0005433181803	E3E0C5	3022 361085	EKATERINA KOROLEVA	{"phone": "+70089221722"}
0005433181804	0049B5	1578 473995	ANTONINA VLASOVA	{"email": "vlasova_a1983@postgrespro.ru", "phone": "+70711317262"}
0005433181805	0049B5	8207 881057	NATALYA GORBUNOVA	{"email": "natalya-gorbunova051975@postgrespro.ru", "phone": "+70432150274"}
0005433181806	66C431	7070 977013	VYACHESLAV ROMANOV	{"email": "v.romanov_30031971@postgrespro.ru", "phone": "+70810233667"}
0005433181807	66C431	4236 267915	MARYAM MOISEEVA	{"phone": "+70444588874"}
0005433181808	732358	2817 157496	VALENTINA POPOVA	{"email": "popova_valentina_01051972@postgrespro.ru", "phone": "+70627215711"}
0005433181809	2E944C	0085 609727	NADIYA MELNIKOVA	{"email": "melnikova-n-04051977@postgrespro.ru", "phone": "+70152117069"}
0005433181810	2E944C	7786 011500	NIKITA KUZNECOV	{"email": "kuznecov-nikita-02041963@postgrespro.ru", "phone": "+70032348610"}
0005433181811	78A16F	1184 572502	NINA PETROVA	{"email": "petrova_n-1966@postgrespro.ru", "phone": "+70566176234"}
0005433181812	CD79CF	4363 908473	LIDIYA BARANOVA	{"phone": "+70123410687"}
0005433181813	CD79CF	4754 781181	LYUDMILA CHERNOVA	{"phone": "+70778897792"}
0005433181814	DA2A0A	7666 378560	VIKTOR POPOV	{"email": "popov.v07081979@postgrespro.ru", "phone": "+70202545069"}
0005433181815	BF01CD	8327 125036	YULIYA ZAYCEVA	{"email": "y_zayceva021983@postgrespro.ru", "phone": "+70801134576"}
0005433181816	A7FC8B	0175 714159	ELENA ANDREEVA	{"phone": "+70940891010"}
0005433181817	A7FC8B	2655 843480	ANNA SOROKINA	{"email": "a.sorokina1976@postgrespro.ru", "phone": "+70384891457"}
0005433181818	438A12	3415 108725	LARISA GUSEVA	{"phone": "+70019899342"}
0005433181819	8CAD1A	9629 083717	IGOR MOROZOV	{"email": "morozov_igor-18091975@postgrespro.ru", "phone": "+70248086161"}
0005433181820	76A739	7657 947876	LYUDMILA BELOVA	{"phone": "+70556974288"}
0005433181821	787C6A	4501 253647	VLADIMIR TIKHONOV	{"phone": "+70405494134"}
0005433181822	6DC16C	4103 822404	VALERIY KUZNECOV	{"phone": "+70310523086"}
0005433181823	6DC16C	5138 378845	VIKTOR SERGEEV	{"phone": "+70662892339"}
0005433181824	83694E	7462 354322	MAKSIM NIKITIN	{"email": "nikitin.maksim.1973@postgrespro.ru", "phone": "+70862263757"}
0005433181825	83694E	3488 984853	VERONIKA ROMANOVA	{"phone": "+70696444522"}
0005433181826	9E678E	1953 708750	ALEKSANDR VASILEV	{"phone": "+70115390834"}
0005433181827	9E678E	0888 929787	IGOR KULIKOV	{"email": "igor.kulikov-051974@postgrespro.ru", "phone": "+70685969498"}
0005433181828	3CC447	1587 838985	NIKOLAY ZHURAVLEV	{"phone": "+70874068179"}
0005433181829	3CC447	7173 536152	RUSLAN TIMOFEEV	{"email": "timofeev.r.11021973@postgrespro.ru", "phone": "+70934244975"}
0005433181830	B8F1EF	3146 516357	YULIYA MAKSIMOVA	{"email": "maksimova_yuliya101974@postgrespro.ru", "phone": "+70105113374"}
0005433181831	6EDCFE	2978 760266	NINA VASILEVA	{"email": "vasilevan1961@postgrespro.ru", "phone": "+70044113766"}
0005433181832	310EC4	5606 402951	VIKTORIYA LOGINOVA	{"phone": "+70735206951"}
0005433181833	310EC4	4003 410906	PETR KUZNECOV	{"email": "p_kuznecov-19031968@postgrespro.ru", "phone": "+70531611779"}
0005433181834	CB1193	6026 181536	NADEZHDA STEPANOVA	{"email": "stepanova-nadezhda_20011964@postgrespro.ru", "phone": "+70951912326"}
0005433181835	13E632	9347 715448	YULIYA VOLKOVA	{"email": "yuliya-volkova_1969@postgrespro.ru", "phone": "+70319069923"}
0005433181836	13E632	0887 720517	IRINA PETROVA	{"email": "petrova_irina.04011981@postgrespro.ru", "phone": "+70116273122"}
0005433181837	B7EA29	2725 907241	NADEZHDA KOROLEVA	{"phone": "+70977427152"}
0005433181838	4CE822	6243 721631	DMITRIY MEDVEDEV	{"email": "d_medvedev-041980@postgrespro.ru", "phone": "+70271635916"}
0005433181839	EE080E	4966 701549	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr_1970@postgrespro.ru", "phone": "+70500309650"}
0005433181840	0F1B16	5059 401138	NIKOLAY TIKHONOV	{"email": "n_tikhonov.091979@postgrespro.ru", "phone": "+70779164601"}
0005433181841	A3FAEE	0834 627246	ALEKSANDR SCHERBAKOV	{"phone": "+70134676708"}
0005433181842	A3FAEE	3496 051934	VLADIMIR FEDOROV	{"email": "fedorov.vladimir_07031970@postgrespro.ru", "phone": "+70424027632"}
0005433185968	C94E7A	5546 085386	ALEKSEY ZAYCEV	{"email": "a-zaycev.051968@postgrespro.ru", "phone": "+70773618528"}
0005433185969	652417	6329 834404	DMITRIY MOROZOV	{"phone": "+70243848876"}
0005433185970	B0F2DA	6109 162981	EKATERINA KRASNOVA	{"email": "e_krasnova.30031973@postgrespro.ru", "phone": "+70331650465"}
0005433185971	B13CDB	8702 125429	TATYANA KAZAKOVA	{"phone": "+70635040295"}
0005433185972	C0C6BD	3303 006941	SVETLANA MATVEEVA	{"email": "svetlana-matveeva14121973@postgrespro.ru", "phone": "+70433812028"}
0005433185973	C0C6BD	4717 203783	ELENA SOKOLOVA	{"phone": "+70073809397"}
0005433185974	C0C6BD	1057 931597	RUSTAM SMIRNOV	{"phone": "+70553594121"}
0005433185975	1770F8	9724 376760	GENNADIY MATVEEV	{"phone": "+70584714439"}
0005433185976	F49611	5534 752498	ALEKSEY ISAEV	{"email": "aleksey-isaev031953@postgrespro.ru", "phone": "+70287916088"}
0005433185977	3A0708	6045 569526	ANNA VOROBEVA	{"email": "vorobeva-anna_16101972@postgrespro.ru", "phone": "+70392027524"}
0005433185978	3A0708	0530 716428	IGOR FOMIN	{"phone": "+70283161472"}
0005433185979	73C7E0	5765 621728	EDUARD SOLOVEV	{"phone": "+70232873116"}
0005433185980	411006	8737 608469	LYUDMILA GERASIMOVA	{"phone": "+70797245218"}
0005433185981	411006	7745 046093	NIKOLAY BELOV	{"email": "belovn27111983@postgrespro.ru", "phone": "+70999396614"}
0005433185982	57179C	6374 123480	NINA TIKHONOVA	{"email": "tikhonovan_051977@postgrespro.ru", "phone": "+70872555856"}
0005433185983	57179C	5743 189293	EGOR ZAYCEV	{"phone": "+70538950307"}
0005433185984	57179C	4217 226059	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova-101964@postgrespro.ru", "phone": "+70815035843"}
0005433185985	88F205	3000 147950	ALEKSANDR SEMENOV	{"email": "semenovaleksandr.051975@postgrespro.ru", "phone": "+70556026394"}
0005433185986	88F205	6255 283323	EGOR BONDARENKO	{"email": "egor-bondarenko13091972@postgrespro.ru", "phone": "+70869338070"}
0005433185987	404E61	3905 826748	MIKHAIL SERGEEV	{"email": "sergeev_m.30091975@postgrespro.ru", "phone": "+70141841449"}
0005433185988	404E61	3528 718832	TATYANA KOROLEVA	{"email": "t-koroleva.031979@postgrespro.ru", "phone": "+70751084724"}
0005433185989	E71D28	6812 068875	VASILIY PETROV	{"email": "petrov_v.1975@postgrespro.ru", "phone": "+70370783837"}
0005433185990	30D035	9716 418530	KIRILL TIKHONOV	{"phone": "+70485381281"}
0005433185991	83A0B8	3922 769909	SERGEY ANTONOV	{"email": "sergey.antonov_01041981@postgrespro.ru", "phone": "+70489229515"}
0005433185992	123D71	6041 217624	IGOR ALEKSEEV	{"email": "alekseev_igor-091968@postgrespro.ru", "phone": "+70677628371"}
0005433185993	E13BE8	3293 777929	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya091979@postgrespro.ru", "phone": "+70990196163"}
0005433185994	E13BE8	4535 691647	ELENA ZHURAVLEVA	{"email": "zhuravleva_elena.061974@postgrespro.ru", "phone": "+70954951732"}
0005433185995	01E5DB	1718 460652	NADEZHDA TIMOFEEVA	{"email": "timofeeva.n.1970@postgrespro.ru", "phone": "+70134260934"}
0005433185996	97F918	9770 227397	LYUDMILA KISELEVA	{"email": "l.kiseleva.05051973@postgrespro.ru", "phone": "+70730863826"}
0005433185997	B2A80D	2385 739070	MARIYA VLASOVA	{"email": "vlasova_m22111975@postgrespro.ru", "phone": "+70638007163"}
0005433185998	B0F2BC	5614 800453	TATYANA OSIPOVA	{"email": "t-osipova-081981@postgrespro.ru", "phone": "+70826901635"}
0005433185999	B0F2BC	0119 205978	NATALIYA ZOTOVA	{"phone": "+70750624375"}
0005433186000	E45D10	8534 395127	RAMIL ZAKHAROV	{"email": "r.zakharov-1978@postgrespro.ru", "phone": "+70621529030"}
0005433186001	9C4A0E	3291 312731	LYUDMILA GAVRILOVA	{"phone": "+70106042436"}
0005433186002	0096E3	0254 342116	OLGA BOGDANOVA	{"email": "bogdanova.o_20021972@postgrespro.ru", "phone": "+70940174484"}
0005433186003	0096E3	6431 586506	IRINA ANISIMOVA	{"email": "i_anisimova121967@postgrespro.ru", "phone": "+70260305469"}
0005433186004	D0C5D3	4799 631359	ALEKSANDR VLASOV	{"email": "vlasov-a.071980@postgrespro.ru", "phone": "+70619896042"}
0005433186005	26E5BA	6834 133593	PETR ORLOV	{"email": "orlov-petr.20061968@postgrespro.ru", "phone": "+70997945727"}
0005433186006	B15F35	1724 182650	OKSANA DENISOVA	{"email": "oksana_denisova011975@postgrespro.ru", "phone": "+70327172824"}
0005433186007	B15F35	1700 213157	VALENTINA KONOVALOVA	{"email": "valentina.konovalova061973@postgrespro.ru", "phone": "+70527596484"}
0005433186008	40484C	1744 783856	EVGENIYA FILIPPOVA	{"email": "evgeniyafilippova.041973@postgrespro.ru", "phone": "+70615220864"}
0005433186009	2B5D6C	7467 566421	MARIYA IVANOVA	{"email": "ivanovamariya-1962@postgrespro.ru", "phone": "+70391076476"}
0005433186010	E2511C	6841 750440	LYUBOV GRISHINA	{"email": "l.grishina.051981@postgrespro.ru", "phone": "+70579579784"}
0005433186011	F6EB55	7593 053923	KSENIYA SERGEEVA	{"phone": "+70305792968"}
0005433186012	F64E76	8358 942506	SERGEY SOKOLOV	{"email": "sergey.sokolov.13051972@postgrespro.ru", "phone": "+70789417397"}
0005433186013	F64E76	7154 970419	IRINA STEPANOVA	{"email": "irina_stepanova.23071973@postgrespro.ru", "phone": "+70824291745"}
0005433186014	F64E76	5698 445076	RAMIL KUZNECOV	{"phone": "+70178415504"}
0005433186015	E5A777	7720 585784	ANNA KAZAKOVA	{"phone": "+70345480510"}
0005433186016	D689DE	2754 878859	PETR TARASOV	{"email": "ptarasov1970@postgrespro.ru", "phone": "+70155584317"}
0005433186017	D0CD89	4077 075056	LYUBOV VASILEVA	{"phone": "+70656350204"}
0005433186018	0995E6	9771 988136	TATYANA NIKOLAEVA	{"email": "t_nikolaeva-031974@postgrespro.ru", "phone": "+70423525748"}
0005433186019	50CA2B	4221 438833	ZOYA ARKHIPOVA	{"email": "arkhipovaz_1975@postgrespro.ru", "phone": "+70563762589"}
0005433186020	50CA2B	1668 576574	NIKOLAY ALEKSEEV	{"email": "alekseev_n1975@postgrespro.ru", "phone": "+70624211623"}
0005433186021	E5BB0F	0606 238363	OKSANA KUZNECOVA	{"phone": "+70200823381"}
0005433186022	EC6F90	5735 861413	IRINA POPOVA	{"email": "irina.popova.021970@postgrespro.ru", "phone": "+70314314103"}
0005433186023	EC6F90	3805 313024	ALEKSANDR MATVEEV	{"phone": "+70238804953"}
0005433186024	EC6F90	7159 129858	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail.1970@postgrespro.ru", "phone": "+70218485148"}
0005433186025	53E66F	1721 853001	VIKTOR SHEVCHENKO	{"phone": "+70855321197"}
0005433186026	53E66F	5944 239989	VALENTINA KULIKOVA	{"email": "kulikova_valentina041979@postgrespro.ru", "phone": "+70283464084"}
0005433186027	BF09EE	5712 642122	OLGA FROLOVA	{"phone": "+70988889611"}
0005433186028	B5B1BF	4369 744769	ALEKSANDR KAZAKOV	{"phone": "+70402363192"}
0005433186029	B5B1BF	5635 965738	SVETLANA SMIRNOVA	{"email": "smirnova-svetlana.071981@postgrespro.ru", "phone": "+70442982416"}
0005433186030	400E7D	0451 104850	ALEKSEY STEPANOV	{"phone": "+70860597012"}
0005433186031	400E7D	4864 839128	NATALYA KONOVALOVA	{"phone": "+70750841199"}
0005433186032	0B63F6	9449 246396	NATALYA SCHERBAKOVA	{"phone": "+70682023572"}
0005433186033	0B63F6	2188 875462	EVGENIYA GRISHINA	{"email": "grishina-evgeniya_1966@postgrespro.ru", "phone": "+70830543734"}
0005433186034	03C68C	9318 468510	STANISLAV STEPANOV	{"phone": "+70363331610"}
0005433186035	03C68C	8498 017923	ALINA KULIKOVA	{"email": "kulikova_alina_111971@postgrespro.ru", "phone": "+70823380893"}
0005433186036	80451F	7929 438086	TATYANA IVANOVA	{"email": "ivanova-tatyana.08061984@postgrespro.ru", "phone": "+70875720548"}
0005433186037	9700AE	0235 672740	NINA ROMANOVA	{"email": "romanovanina1958@postgrespro.ru", "phone": "+70823033112"}
0005433186038	9700AE	4007 634791	PAVEL ZAKHAROV	{"phone": "+70841537273"}
0005433186039	3F2DAA	9927 099096	RIMMA MAKSIMOVA	{"email": "r_maksimova-20071979@postgrespro.ru", "phone": "+70671993402"}
0005433186040	3F2DAA	2384 038933	NINA KONOVALOVA	{"email": "konovalova_nina-19011973@postgrespro.ru", "phone": "+70183605725"}
0005433186041	5A661C	7975 017661	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir.101988@postgrespro.ru", "phone": "+70024599629"}
0005433186042	DC893F	5737 260472	MAKSIM KISELEV	{"phone": "+70025383573"}
0005433186043	DC893F	3294 560057	MATRENA KOZLOVA	{"email": "kozlova.matrena-081978@postgrespro.ru", "phone": "+70974013723"}
0005433186044	3F3056	1162 602856	ALEKSEY SEMENOV	{"phone": "+70383431130"}
0005433186045	CB5CD7	4062 748824	VITALIY DMITRIEV	{"phone": "+70956899795"}
0005433186046	CB5CD7	7311 411382	TATYANA EFREMOVA	{"email": "tatyanaefremova_111983@postgrespro.ru", "phone": "+70806435863"}
0005433186047	D78E64	3053 133477	RUSLAN KARPOV	{"email": "karpovr-051982@postgrespro.ru", "phone": "+70747399658"}
0005433186048	364E63	1846 812755	ALEKSANDR KONOVALOV	{"phone": "+70108371478"}
0005433186049	A7296F	0823 170859	ALEKSEY IVANOV	{"email": "aivanov.031971@postgrespro.ru", "phone": "+70092802347"}
0005433186050	A7296F	3705 261574	MATRENA VOROBEVA	{"email": "m.vorobeva091975@postgrespro.ru", "phone": "+70007047612"}
0005433186051	D439E6	5302 219299	SERGEY KAZAKOV	{"phone": "+70198896171"}
0005433186052	7D2A8E	6219 492077	EVGENIYA ALEKSEEVA	{"email": "alekseeva.evgeniya-09091979@postgrespro.ru", "phone": "+70106630816"}
0005433186053	7D2A8E	4010 275322	ANDREY MIKHAYLOV	{"email": "andreymikhaylov-26071978@postgrespro.ru", "phone": "+70914955574"}
0005433186054	7D2A8E	0784 520740	LYUBOV KAZAKOVA	{"email": "kazakova.l_24031974@postgrespro.ru", "phone": "+70894620410"}
0005433186055	07609A	7320 816538	OLEG BELOV	{"email": "belov.oleg-1969@postgrespro.ru", "phone": "+70127313064"}
0005433186056	B68F04	0595 787223	IRINA BELOVA	{"email": "belova-i.1971@postgrespro.ru", "phone": "+70837486469"}
0005433186057	C8578E	6865 220616	OLGA KUZNECOVA	{"email": "kuznecova.o_021978@postgrespro.ru", "phone": "+70489674215"}
0005433186058	C8578E	4070 346540	ALEKSANDR BORISOV	{"phone": "+70287353975"}
0005433186059	1AB1DC	7673 649366	ALBINA LUKYANOVA	{"phone": "+70612888998"}
0005433186060	B46EDB	1168 399620	ANASTASIYA KOROLEVA	{"email": "akoroleva-30041975@postgrespro.ru", "phone": "+70881177831"}
0005433186061	C0366D	8601 217734	ALEKSANDR NIKITIN	{"email": "aleksandr-nikitin_121973@postgrespro.ru", "phone": "+70098061080"}
0005433186062	C0366D	6861 870302	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_1961@postgrespro.ru", "phone": "+70010979503"}
0005433186063	660F44	3275 794458	ZINAIDA ZOTOVA	{"phone": "+70910227197"}
0005433186064	660F44	2076 349096	IRINA MARTYNOVA	{"email": "martynovai_1973@postgrespro.ru", "phone": "+70259467426"}
0005433186065	0E4ACF	0246 709312	ALEKSEY ZHUKOV	{"email": "a_zhukov1969@postgrespro.ru", "phone": "+70688283488"}
0005433186066	18C4D7	6451 212342	ARTEM MOROZOV	{"phone": "+70004873424"}
0005433186067	38C38B	0726 000402	EVGENIY ALEKSANDROV	{"phone": "+70472277633"}
0005433186068	635DD0	8020 659857	ELENA KONDRATEVA	{"phone": "+70132492456"}
0005433186069	635DD0	6930 775386	ANNA DAVYDOVA	{"phone": "+70931839009"}
0005433186070	635DD0	7606 163878	SEMEN SEMENOV	{"email": "semenovs_041959@postgrespro.ru", "phone": "+70211339091"}
0005433186071	6EFB45	1105 785342	MARINA FEDOROVA	{"email": "marina-fedorova-10051982@postgrespro.ru", "phone": "+70331826185"}
0005433186072	A4A52B	4627 304362	MAKSIM ILIN	{"email": "ilin_maksim_03091976@postgrespro.ru", "phone": "+70545745427"}
0005433186073	162314	3584 315602	NIKOLAY MATVEEV	{"email": "matveev-nikolay-1977@postgrespro.ru", "phone": "+70209981098"}
0005433186074	E8C475	6390 022147	VLADIMIR FILIPPOV	{"email": "filippov.v.1969@postgrespro.ru", "phone": "+70282502511"}
0005433186075	547C41	0781 691084	OLEG SEMENOV	{"phone": "+70906872826"}
0005433186076	547C41	4221 331801	ZOYA FEDOROVA	{"email": "z-fedorova1967@postgrespro.ru", "phone": "+70998135240"}
0005433186077	B33158	4997 668795	RIMMA BOGDANOVA	{"email": "bogdanova_r011973@postgrespro.ru", "phone": "+70909731786"}
0005433186078	B33158	6241 964790	ALEKSANDR PAVLOV	{"email": "pavlov-a_1965@postgrespro.ru", "phone": "+70549741245"}
0005433186079	ABFF9F	6961 024623	TATYANA FROLOVA	{"phone": "+70528934905"}
0005433186080	9A02BA	8720 949178	ALENA KOLESNIKOVA	{"email": "alena-kolesnikova.28031976@postgrespro.ru", "phone": "+70049195590"}
0005433186081	124191	5283 783516	NINA VASILEVA	{"phone": "+70420918418"}
0005433186082	0E9F0C	5446 844133	ALEKSANDR FILIPPOV	{"email": "afilippov-051978@postgrespro.ru", "phone": "+70535243468"}
0005433186083	0E9F0C	6003 876742	LYUBOV CHERNOVA	{"phone": "+70785364929"}
0005433186084	500C59	3982 133343	TATYANA BELYAEVA	{"email": "belyaeva_tatyana-10041966@postgrespro.ru", "phone": "+70162490096"}
0005433186085	6158B4	8342 558541	TATYANA CHERNOVA	{"phone": "+70234759563"}
0005433186086	411EF4	5245 443808	AIDA DANILOVA	{"email": "danilova_aida22031968@postgrespro.ru", "phone": "+70364761967"}
0005433186087	411EF4	0063 316179	GALINA KONDRATEVA	{"email": "kondrateva.galina-061969@postgrespro.ru", "phone": "+70910340640"}
0005433186088	411EF4	2990 191237	SVETLANA EGOROVA	{"email": "svetlanaegorova1972@postgrespro.ru", "phone": "+70660671167"}
0005433186089	15D6DE	0894 588801	DENIS SCHERBAKOV	{"phone": "+70581779910"}
0005433186090	0D5AC8	3898 597906	MARIYA CHERNOVA	{"phone": "+70149394746"}
0005433186091	F1F664	2615 337948	VIKTOR BELOV	{"email": "viktor.belov_031968@postgrespro.ru", "phone": "+70222846140"}
0005433186092	D1BA89	0576 551659	EGOR NAZAROV	{"phone": "+70971655597"}
0005433186093	E25CE8	8947 913479	IRINA FEDOROVA	{"phone": "+70579503844"}
0005433186094	E25CE8	9690 633831	ROMAN SIDOROV	{"phone": "+70653074731"}
0005433186095	DBB0FB	2810 878546	YAN ZHURAVLEV	{"email": "zhuravlev_y-121973@postgrespro.ru", "phone": "+70706652927"}
0005433186096	050668	3522 250844	ALEKSANDR ISAEV	{"phone": "+70738408989"}
0005433186097	042D78	2703 443132	ALINA RODIONOVA	{"email": "rodionova_a.121972@postgrespro.ru", "phone": "+70319208890"}
0005433186098	A397F0	6674 751157	IVAN SCHERBAKOV	{"email": "scherbakov_ivan.091974@postgrespro.ru", "phone": "+70198003432"}
0005433186099	A397F0	9010 471317	VASILIY IVANOV	{"phone": "+70205836223"}
0005433186100	6492EA	9087 990282	RAFIK MIRONOV	{"phone": "+70420357203"}
0005433186101	2BD79C	4215 693957	GALINA KUZNECOVA	{"email": "galina.kuznecova-091974@postgrespro.ru", "phone": "+70054666858"}
0005433186102	1837D7	1897 459522	VALERIY KOZLOV	{"email": "valeriykozlov-04111976@postgrespro.ru", "phone": "+70709055727"}
0005433186103	173AF4	5216 417844	IRINA RYABOVA	{"email": "i_ryabova-1969@postgrespro.ru", "phone": "+70997283820"}
0005433186104	8A9B0E	4472 968316	VENIAMIN ALEKSEEV	{"phone": "+70777416287"}
0005433186105	8A9B0E	4018 012984	MARINA IVANOVA	{"phone": "+70957602530"}
0005433186106	35676F	0010 838400	TATYANA GORBUNOVA	{"phone": "+70581542067"}
0005433186107	35676F	9643 979394	NIKOLAY AFANASEV	{"phone": "+70534598410"}
0005433186108	259E10	4567 327374	ARTEM KUZMIN	{"email": "kuzminartem_1970@postgrespro.ru", "phone": "+70922026805"}
0005433186109	F6D988	6677 738857	NIKOLAY CHERNOV	{"email": "chernov.n_1960@postgrespro.ru", "phone": "+70743385874"}
0005433186110	F6D988	1078 686833	VERA VOLKOVA	{"email": "volkova_v-11101973@postgrespro.ru", "phone": "+70477592383"}
0005433186111	5F6C3A	0584 575518	OLGA GAVRILOVA	{"phone": "+70554903500"}
0005433186112	012F9D	8179 524381	MARIYA KUZNECOVA	{"email": "kuznecova_m1969@postgrespro.ru", "phone": "+70251859327"}
0005433186113	012F9D	8240 375221	DMITRIY GAVRILOV	{"email": "d.gavrilov_061974@postgrespro.ru", "phone": "+70159477352"}
0005433186114	EDE51A	6529 033413	MARINA SERGEEVA	{"email": "m_sergeeva-1979@postgrespro.ru", "phone": "+70789410030"}
0005433186115	EDE51A	3937 513651	LIDIYA DMITRIEVA	{"phone": "+70254657763"}
0005433186116	575015	1652 607894	NINA KALININA	{"phone": "+70319864331"}
0005433186117	C0DFE6	3587 162735	NINA GORBUNOVA	{"email": "gorbunovanina-04101973@postgrespro.ru", "phone": "+70918108728"}
0005433186178	4A8F13	8943 779328	YURIY ORLOV	{"phone": "+70138437621"}
0005433186118	C0DFE6	2978 315920	SVETLANA LUKYANOVA	{"email": "svetlana.lukyanova-1969@postgrespro.ru", "phone": "+70115847731"}
0005433186119	F7D231	6044 413805	DMITRIY EGOROV	{"phone": "+70055493284"}
0005433186120	F7D231	3125 805080	ELIZAVETA NIKITINA	{"email": "e.nikitina13011964@postgrespro.ru", "phone": "+70354636625"}
0005433186121	BDB27A	8966 726661	SERGEY ROMANOV	{"email": "romanov.sergey.031978@postgrespro.ru", "phone": "+70091746373"}
0005433186122	2AAAED	2760 498919	MIKHAIL PAVLOV	{"email": "pavlov_mikhail041984@postgrespro.ru", "phone": "+70187972471"}
0005433186123	2AAAED	9241 265800	DMITRIY NIKOLAEV	{"email": "dmitriy-nikolaev-1969@postgrespro.ru", "phone": "+70367246228"}
0005433186124	4972A1	3932 978661	ALEKSANDR MIKHAYLOV	{"phone": "+70701178887"}
0005433186125	49D98C	9075 246644	PAVEL GUSEV	{"phone": "+70490687508"}
0005433186126	5D2030	9884 910483	DANILA POPOV	{"email": "d_popov27081974@postgrespro.ru", "phone": "+70653164600"}
0005433186127	322DA2	6481 445237	ANASTASIYA KOVALEVA	{"email": "a.kovaleva1970@postgrespro.ru", "phone": "+70889822176"}
0005433186128	322DA2	8691 249930	NINA SIDOROVA	{"phone": "+70261305361"}
0005433186129	C13B2C	2656 827244	PAVEL VLASOV	{"email": "vlasov.pavel_031971@postgrespro.ru", "phone": "+70340852162"}
0005433186130	C13B2C	2782 648690	ALEVTINA NIKOLAEVA	{"email": "a.nikolaeva-041968@postgrespro.ru", "phone": "+70288354486"}
0005433186131	7A1D97	6903 951929	IGOR NIKITIN	{"phone": "+70686647648"}
0005433186132	234983	3598 461595	IRINA VOROBEVA	{"email": "irina-vorobeva_1971@postgrespro.ru", "phone": "+70364046048"}
0005433186133	5F5C93	2923 022786	KARINA IVANOVA	{"email": "karinaivanova.031984@postgrespro.ru", "phone": "+70465292304"}
0005433186134	5F5C93	0331 317608	ANASTASIYA CHERNOVA	{"phone": "+70847549748"}
0005433186135	A6E869	9614 821313	IRINA MIRONOVA	{"email": "irina-mironova.1975@postgrespro.ru", "phone": "+70296268358"}
0005433186136	D6B753	4638 511371	ANASTASIYA NOVIKOVA	{"phone": "+70759707122"}
0005433186137	D6B753	9401 081594	ALEKSANDR STEPANOV	{"phone": "+70454624576"}
0005433186138	D6B753	2220 455840	NADEZHDA NIKOLAEVA	{"email": "nadezhda_nikolaeva.1980@postgrespro.ru", "phone": "+70106153071"}
0005433186139	AA1906	6729 326064	KSENIYA ZHUKOVA	{"email": "kseniyazhukova101974@postgrespro.ru", "phone": "+70529658660"}
0005433186140	21AB56	0695 902785	VITALIY BELOV	{"phone": "+70683322671"}
0005433186141	21AB56	8082 263730	FEDOR ILIN	{"email": "f.ilin-121970@postgrespro.ru", "phone": "+70172523194"}
0005433186142	CB1751	3514 616352	ALEKSEY ILIN	{"phone": "+70755539975"}
0005433186143	CB1751	5038 510398	ELENA BARANOVA	{"email": "baranovae_1974@postgrespro.ru", "phone": "+70907493663"}
0005433186144	388F7D	5243 737332	ALEKSANDR BELOV	{"phone": "+70842394599"}
0005433186145	2758E9	8855 603805	LIDIYA KOMAROVA	{"phone": "+70404266545"}
0005433186146	90DDAC	5718 484339	YURIY KUZNECOV	{"phone": "+70535417605"}
0005433186147	90DDAC	8050 169022	VLADIMIR KARPOV	{"email": "karpov.vladimir-1967@postgrespro.ru", "phone": "+70192630039"}
0005433186148	372A48	5176 604147	ANTONINA TIKHONOVA	{"phone": "+70768518290"}
0005433186149	3A7B6B	8409 866460	ILYAS FEDOROV	{"email": "fedorov.ilyas1969@postgrespro.ru", "phone": "+70903070229"}
0005433186150	A58459	2939 627835	ELENA EFIMOVA	{"phone": "+70213611984"}
0005433186151	A58459	2233 930866	SERGEY KULIKOV	{"email": "sergey-kulikov1970@postgrespro.ru", "phone": "+70624827363"}
0005433186152	88B715	2465 532814	ALEKSANDR KULIKOV	{"email": "akulikov-1981@postgrespro.ru", "phone": "+70453670298"}
0005433186153	88B715	8038 971076	TATYANA AFANASEVA	{"phone": "+70745807140"}
0005433186154	653D50	6032 483246	LYUBOV LEBEDEVA	{"email": "lebedeva-lyubov.071970@postgrespro.ru", "phone": "+70773061564"}
0005433186155	83EAC3	9624 703210	NADEZHDA TARASOVA	{"email": "nadezhda-tarasova1978@postgrespro.ru", "phone": "+70277842874"}
0005433186156	E6AF95	8810 301437	LIDIYA CHERNOVA	{"phone": "+70690947728"}
0005433186157	225EC1	1589 287441	VLADIMIR TARASOV	{"email": "tarasov-v1965@postgrespro.ru", "phone": "+70989847913"}
0005433186158	70CE7E	2115 617575	DENIS IVANOV	{"phone": "+70130917016"}
0005433186159	2628B1	8374 603078	NIKOLAY FEDOROV	{"email": "nikolayfedorov071974@postgrespro.ru", "phone": "+70088102148"}
0005433186160	2628B1	5801 412128	ELIZAVETA STEPANOVA	{"phone": "+70691088562"}
0005433186161	2AE57F	4801 380060	NATALYA KOLESNIKOVA	{"phone": "+70875747240"}
0005433186162	BB0B37	6611 200330	TATYANA MALYSHEVA	{"phone": "+70631579074"}
0005433186163	60470F	4589 836581	ALEKSANDR TIKHONOV	{"phone": "+70256778934"}
0005433186164	8AD2DB	5369 018581	NATALYA GRISHINA	{"phone": "+70772813092"}
0005433186165	E9E60A	2738 082974	YURIY ANDREEV	{"email": "yandreev_20081975@postgrespro.ru", "phone": "+70900112835"}
0005433186166	E9E60A	4582 159719	DANIIL BORISOV	{"email": "daniil_borisov.1969@postgrespro.ru", "phone": "+70003046389"}
0005433186167	C687BA	9138 779153	SERGEY POPOV	{"phone": "+70507810357"}
0005433186168	C687BA	9818 907018	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov_011965@postgrespro.ru", "phone": "+70180534416"}
0005433186169	90D1E2	3860 237860	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay-061978@postgrespro.ru", "phone": "+70468122285"}
0005433186170	374064	1304 497116	DMITRIY ALEKSANDROV	{"phone": "+70518189990"}
0005433186171	374064	0695 471685	VLADIMIR GRIGOREV	{"phone": "+70702900791"}
0005433186172	8E389A	2336 614903	ALEKSANDR POPOV	{"email": "aleksandr-popov.17101984@postgrespro.ru", "phone": "+70904408920"}
0005433186173	D818E7	4455 221658	OLGA KONOVALOVA	{"phone": "+70741472257"}
0005433186174	D818E7	2533 155426	SERGEY FILIPPOV	{"phone": "+70255791701"}
0005433186175	D818E7	9353 609885	SVETLANA SCHERBAKOVA	{"email": "svetlana_scherbakova_041964@postgrespro.ru", "phone": "+70781988048"}
0005433186176	9AE962	5194 625217	VLADISLAV KAZAKOV	{"email": "kazakov.vladislav_1972@postgrespro.ru", "phone": "+70806400331"}
0005433186177	045FB1	6896 612510	IRINA MIRONOVA	{"phone": "+70674635251"}
0005433186179	13359B	9789 127022	ANASTASIYA KULIKOVA	{"email": "anastasiya-kulikova.111977@postgrespro.ru", "phone": "+70324348460"}
0005433186180	13359B	3528 416175	MARGARITA IVANOVA	{"email": "ivanova-margarita.10081976@postgrespro.ru", "phone": "+70444505260"}
0005433186181	339E21	6932 011985	MAKSIM KONOVALOV	{"email": "maksimkonovalov_091980@postgrespro.ru", "phone": "+70036836708"}
0005433186182	DF5008	7938 314074	ALEKSANDR TIKHONOV	{"email": "tikhonov.a_051977@postgrespro.ru", "phone": "+70963860113"}
0005433186183	56BBB2	6891 908728	IGOR KUDRYASHOV	{"phone": "+70213597729"}
0005433186184	3BE335	7879 800783	ELENA SIDOROVA	{"email": "sidorova.e21081973@postgrespro.ru", "phone": "+70826643378"}
0005433186185	F87D4D	8057 890406	PETR KOROLEV	{"phone": "+70938415078"}
0005433186186	4FC04D	4758 938356	VIKTOR MARTYNOV	{"email": "viktormartynov-051981@postgrespro.ru", "phone": "+70890002775"}
0005433186187	7DBC90	1258 682327	ANATOLIY IVANOV	{"phone": "+70522360551"}
0005433186188	FBEEBA	5633 800094	ZINAIDA STEPANOVA	{"email": "stepanova-zinaida-26021986@postgrespro.ru", "phone": "+70791802918"}
0005433186189	FBEEBA	5527 680091	MIKHAIL MEDVEDEV	{"email": "mmedvedev.041975@postgrespro.ru", "phone": "+70703118345"}
0005433186190	A3AA03	3638 135778	VYACHESLAV FOMIN	{"email": "v.fomin_16021981@postgrespro.ru", "phone": "+70571049376"}
0005433186191	408149	8568 786860	SERGEY MATVEEV	{"phone": "+70954325940"}
0005433186192	CCB6D1	6153 380956	NADEZHDA MATVEEVA	{"email": "nmatveeva_1974@postgrespro.ru", "phone": "+70193448710"}
0005433186193	361563	6880 304968	MARIYA LEBEDEVA	{"phone": "+70663200283"}
0005433186194	22E22A	3478 033390	ALEKSEY SOLOVEV	{"phone": "+70853843108"}
0005433186195	22E22A	3565 135587	ALEKSANDRA ALEKSEEVA	{"email": "a-alekseeva.13091973@postgrespro.ru", "phone": "+70089936919"}
0005433186196	924123	8150 570441	VLADIMIR NOVIKOV	{"phone": "+70936454046"}
0005433186197	924123	6885 736813	NIKITA BELOV	{"email": "belovn1966@postgrespro.ru", "phone": "+70578643768"}
0005433186198	8E4507	6199 937188	DMITRIY MIRONOV	{"email": "mironov-d_1971@postgrespro.ru", "phone": "+70197212126"}
0005433186199	9F32BD	9224 016100	VASILIY SCHERBAKOV	{"phone": "+70328371341"}
0005433186200	5163AA	7513 129233	EVGENIYA IVANOVA	{"phone": "+70349422452"}
0005433186201	5163AA	1406 941174	VALENTINA ZHUKOVA	{"email": "zhukova_valentina14041977@postgrespro.ru", "phone": "+70799160589"}
0005433186202	AA4116	1162 525296	VLADIMIR EGOROV	{"phone": "+70138020981"}
0005433186203	AA4116	7372 533985	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a.1973@postgrespro.ru", "phone": "+70596122196"}
0005433186204	3460D0	4796 925766	OLGA KOROLEVA	{"email": "olgakoroleva.091984@postgrespro.ru", "phone": "+70406462253"}
0005433186205	D05FF6	6766 466829	ELENA ARKHIPOVA	{"email": "elenaarkhipova-121966@postgrespro.ru", "phone": "+70724748230"}
0005433186206	4672C4	5455 102490	ARINA IVANOVA	{"phone": "+70307139863"}
0005433186207	4672C4	0646 233821	DARYA VOROBEVA	{"phone": "+70767301028"}
0005433186208	EAE60B	7278 422721	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir_19081976@postgrespro.ru", "phone": "+70443277347"}
0005433186209	1619A9	0257 147808	OLGA BORISOVA	{"email": "borisova.olga1964@postgrespro.ru", "phone": "+70112067421"}
0005433186210	3DA4AA	8132 494924	IRINA DAVYDOVA	{"email": "davydovairina-041980@postgrespro.ru", "phone": "+70761138723"}
0005433186211	52F54C	9815 395924	NIKOLAY KOZLOV	{"email": "kozlov-n20091977@postgrespro.ru", "phone": "+70377565960"}
0005433186212	52F54C	3487 328229	KRISTINA ZHURAVLEVA	{"email": "zhuravleva-kristina.1970@postgrespro.ru", "phone": "+70519077181"}
0005433186213	068056	0651 992427	SVETLANA MATVEEVA	{"phone": "+70010814417"}
0005433186214	068056	6382 604628	NATALYA OVCHINNIKOVA	{"phone": "+70577566215"}
0005433186215	5DA218	3292 639614	VIKTORIYA ZOTOVA	{"phone": "+70343299698"}
0005433186216	5DA218	9305 123832	ELENA MIKHAYLOVA	{"email": "elenamikhaylova1955@postgrespro.ru", "phone": "+70333150847"}
0005433186217	24EB6E	0225 120278	EGOR SMIRNOV	{"email": "e_smirnov041976@postgrespro.ru", "phone": "+70792271180"}
0005433186218	D08E45	6188 318404	GENNADIY KRASNOV	{"phone": "+70385488171"}
0005433186219	E151A3	0485 842205	OLEG KUZNECOV	{"email": "o_kuznecov-13021978@postgrespro.ru", "phone": "+70169135064"}
0005433186220	6FD0E0	4422 793111	ELENA KARPOVA	{"email": "elena.karpova-011965@postgrespro.ru", "phone": "+70486404147"}
0005433186221	E6CCB9	1119 164943	VALERIY ABRAMOV	{"email": "v_abramov.1973@postgrespro.ru", "phone": "+70464250342"}
0005433186222	506948	5745 262640	OLGA ZAYCEVA	{"email": "olga.zayceva-101966@postgrespro.ru", "phone": "+70858714764"}
0005433186223	476BCB	6287 630265	VLADIMIR BELOV	{"phone": "+70928758769"}
0005433186224	476BCB	2171 981785	ELENA OVCHINNIKOVA	{"phone": "+70921273536"}
0005433186225	841CCE	0685 903267	ELVIRA ALEKSEEVA	{"email": "e.alekseeva121966@postgrespro.ru", "phone": "+70774491553"}
0005433186226	F8A267	7159 833582	VADIM EGOROV	{"email": "egorov_v_1967@postgrespro.ru", "phone": "+70702064860"}
0005433186227	99265E	3038 098910	GENNADIY DMITRIEV	{"email": "gennadiy-dmitriev.03081965@postgrespro.ru", "phone": "+70152814638"}
0005433186228	D293C7	3538 332957	SERGEY MEDVEDEV	{"phone": "+70615395348"}
0005433186229	06BDB4	1862 529759	FATIMA MELNIKOVA	{"email": "melnikovaf-1980@postgrespro.ru", "phone": "+70826011512"}
0005433186230	217059	6680 805261	OLEG STEPANOV	{"phone": "+70973876874"}
0005433186231	8D3455	7859 310896	VLADISLAV NIKOLAEV	{"phone": "+70139468167"}
0005433186232	CD6D5B	3493 459272	EVGENIY BORISOV	{"email": "borisov_evgeniy_1977@postgrespro.ru", "phone": "+70361197693"}
0005433186233	CD6D5B	9165 686716	SERGEY NIKOLAEV	{"email": "snikolaev.1974@postgrespro.ru", "phone": "+70936127625"}
0005433186234	CD6D5B	1846 482560	OLGA FROLOVA	{"phone": "+70472050102"}
0005433186235	CD6D5B	2907 275615	MARINA KOROLEVA	{"email": "marinakoroleva-12071962@postgrespro.ru", "phone": "+70769669636"}
0005433186236	2C6BCD	2829 717032	ROMAN YAKOVLEV	{"email": "yakovlevr_111969@postgrespro.ru", "phone": "+70995383348"}
0005433186237	2C6BCD	9309 115742	TATYANA SERGEEVA	{"email": "tatyana_sergeeva.1968@postgrespro.ru", "phone": "+70292379550"}
0005433186238	BBB6D3	1225 671991	NIKOLAY ROMANOV	{"phone": "+70386703885"}
0005433186239	DAB299	8754 612549	GALINA IVANOVA	{"email": "ivanova.galina_071963@postgrespro.ru", "phone": "+70282144664"}
0005433186240	F02567	0301 260356	ALEKSANDR FROLOV	{"email": "frolov-a_1982@postgrespro.ru", "phone": "+70299549916"}
0005433186241	E2D848	7107 343213	TATYANA ANTONOVA	{"phone": "+70462636193"}
0005433186242	E2D848	8538 567455	NATALYA KUZNECOVA	{"email": "kuznecova.natalya_05091975@postgrespro.ru", "phone": "+70933826431"}
0005433186243	E2D848	4188 315191	ALEKSANDR DENISOV	{"phone": "+70813937138"}
0005433186244	2B708C	1703 414531	LYUDMILA PETROVA	{"email": "lyudmilapetrova_30091957@postgrespro.ru", "phone": "+70073439328"}
0005433186245	394254	6629 408053	VALENTINA SMIRNOVA	{"email": "v_smirnova24091971@postgrespro.ru", "phone": "+70966760503"}
0005433186246	394254	6161 566069	VALENTINA BARANOVA	{"email": "valentinabaranova.091976@postgrespro.ru", "phone": "+70419047223"}
0005433186247	F461AB	9503 202854	VLADIMIR PETROV	{"email": "petrov.v.08071972@postgrespro.ru", "phone": "+70372974429"}
0005433186248	9BC150	5997 659369	VLADIMIR NIKITIN	{"phone": "+70778612426"}
0005433186249	9106F3	9875 786608	VALERIY FOMIN	{"email": "valeriy_fomin_05061978@postgrespro.ru", "phone": "+70893405868"}
0005433186250	9106F3	5971 598631	IVAN MARTYNOV	{"phone": "+70786044655"}
0005433186251	9CC4D7	0919 068279	NATALYA KALININA	{"email": "kalinina_natalya_09051974@postgrespro.ru", "phone": "+70401770735"}
0005433186252	9CC4D7	2783 686796	ANNA KUZNECOVA	{"email": "akuznecova-081975@postgrespro.ru", "phone": "+70091579012"}
0005433186253	046EAC	1971 512182	LYUDMILA ZHURAVLEVA	{"phone": "+70628514177"}
0005433186254	999A54	2066 373164	DMITRIY SIDOROV	{"email": "d.sidorov.1965@postgrespro.ru", "phone": "+70808859989"}
0005433186255	1FFCE0	2638 250186	STEPAN KUZMIN	{"email": "kuzmin-stepan-1973@postgrespro.ru", "phone": "+70011281254"}
0005433186256	C1667C	3904 548546	MARK SOROKIN	{"phone": "+70348297247"}
0005433186257	C1667C	1966 681911	DMITRIY IVANOV	{"phone": "+70837989622"}
0005433186258	876231	6081 402926	VIKTOR KOZLOV	{"phone": "+70373933345"}
0005433186259	876231	7197 021402	OLGA FROLOVA	{"email": "frolova-o.1970@postgrespro.ru", "phone": "+70184950825"}
0005433186260	57B901	7145 525441	OLGA DANILOVA	{"phone": "+70738607025"}
0005433186261	F7D1B9	5821 308243	ILMIR BARANOV	{"phone": "+70872937522"}
0005433186262	F7D1B9	2189 089304	RADIK SIDOROV	{"phone": "+70949485479"}
0005433186263	395FF6	9477 636296	ALEKSANDR BARANOV	{"email": "baranov_a-011968@postgrespro.ru", "phone": "+70927035407"}
0005433186264	F4873E	5001 840669	ELINA EFREMOVA	{"phone": "+70193406041"}
0005433186265	998CCD	8172 178881	EDUARD VASILEV	{"phone": "+70097762528"}
0005433186266	583F9D	1365 828202	VALENTINA MATVEEVA	{"email": "v.matveeva031973@postgrespro.ru", "phone": "+70071123533"}
0005433186267	583F9D	5909 557890	VYACHESLAV KAZAKOV	{"email": "kazakovvyacheslav.121983@postgrespro.ru", "phone": "+70686212952"}
0005433186268	583F9D	6443 403407	VIKTOR ZAYCEV	{"phone": "+70265808208"}
0005433186269	B22FED	4181 253804	NATALYA EFIMOVA	{"phone": "+70347169920"}
0005433186270	B22FED	0706 977670	MARINA NIKOLAEVA	{"phone": "+70148020225"}
0005433186271	3F8BC5	2321 840808	ULYANA ERMAKOVA	{"phone": "+70604622187"}
0005433186272	3F8BC5	7846 726189	VALENTIN GORBUNOV	{"email": "gorbunov-v.091970@postgrespro.ru", "phone": "+70394763253"}
0005433186273	971C75	6472 486029	ANDREY MOISEEV	{"phone": "+70026233373"}
0005433186274	971C75	6624 371713	ANATOLIY KULIKOV	{"email": "kulikov_a.061979@postgrespro.ru", "phone": "+70617434405"}
0005433186275	F6FDB6	7760 465744	VIKTOR FOMIN	{"phone": "+70424891008"}
0005433186276	CB6552	0075 546691	DENIS NIKITIN	{"phone": "+70221320259"}
0005433186277	56369F	8890 377545	MARIYA GRISHINA	{"email": "grishinamariya_061984@postgrespro.ru", "phone": "+70889364517"}
0005433186278	56369F	1327 917228	EKATERINA KONDRATEVA	{"phone": "+70918831078"}
0005433186279	3E9E1F	9009 137586	VALENTINA ROMANOVA	{"email": "romanova.v_081975@postgrespro.ru", "phone": "+70014923860"}
0005433186280	3E9E1F	0383 187654	ROMAN BONDARENKO	{"phone": "+70302081421"}
0005433186281	C591E9	6134 308415	ZOYA SOROKINA	{"email": "z-sorokina_10041977@postgrespro.ru", "phone": "+70817925401"}
0005433186282	C591E9	6879 962087	RAISA IVANOVA	{"email": "ivanovar091966@postgrespro.ru", "phone": "+70148339643"}
0005433186283	58CA8E	7704 388770	VALERIY BELOV	{"phone": "+70699889008"}
0005433186284	B07C4E	0377 662144	DMITRIY VASILEV	{"phone": "+70686458265"}
0005433186285	E7F817	0045 470113	ALEKSANDR KOROLEV	{"phone": "+70011243783"}
0005433186286	E7F817	6143 574247	SVETLANA NOVIKOVA	{"email": "novikova-s18071979@postgrespro.ru", "phone": "+70804045500"}
0005433186287	E7F817	5695 550873	NATALYA DANILOVA	{"email": "danilova.n-07051975@postgrespro.ru", "phone": "+70806807672"}
0005433186288	74A97B	6525 526549	VALENTINA RODIONOVA	{"email": "valentina_rodionova.06031965@postgrespro.ru", "phone": "+70915403546"}
0005433186289	74A97B	6402 095507	DARYA KUZNECOVA	{"email": "d_kuznecova.1974@postgrespro.ru", "phone": "+70520507060"}
0005433186290	469D5A	5859 994593	EKATERINA YUDINA	{"email": "yudinae_07071974@postgrespro.ru", "phone": "+70344041243"}
0005433186291	A8D35C	1003 569914	SERGEY MOISEEV	{"email": "s_moiseev1971@postgrespro.ru", "phone": "+70923932236"}
0005433186292	BA8603	9713 639582	TATYANA MELNIKOVA	{"phone": "+70053033519"}
0005433186293	84FCB1	7069 528135	ALEKSEY POPOV	{"phone": "+70552742765"}
0005433186294	D5B50D	8126 335377	SERGEY FEDOTOV	{"phone": "+70025590588"}
0005433186295	F1F719	4672 043285	VIKTOR KOROLEV	{"email": "v_korolev-121966@postgrespro.ru", "phone": "+70075734873"}
0005433186296	791E5D	0475 609438	ANTON MIKHAYLOV	{"email": "a-mikhaylov.22091979@postgrespro.ru", "phone": "+70079231718"}
0005433186297	CF6283	3884 705946	OLEG TIKHONOV	{"phone": "+70498020946"}
0005433186298	CF6283	8851 722341	TATYANA KUZMINA	{"email": "tatyanakuzmina_05111980@postgrespro.ru", "phone": "+70139258662"}
0005433186299	8F82B9	7169 314973	KIRILL TARASOV	{"email": "kirill.tarasov_1990@postgrespro.ru", "phone": "+70960518868"}
0005433186300	E680A9	0121 956419	LARISA VLASOVA	{"email": "larisa-vlasova.07061990@postgrespro.ru", "phone": "+70951135547"}
0005433186301	56E7F9	4194 089235	ANASTASIYA ZOTOVA	{"phone": "+70541196103"}
0005433186302	07FD2B	0782 172120	ANTON VASILEV	{"phone": "+70881901765"}
0005433186303	07FD2B	5935 478194	OLESYA IVANOVA	{"phone": "+70666239763"}
0005433186304	C4F2A3	0798 659654	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov.1979@postgrespro.ru", "phone": "+70027207248"}
0005433186305	C4F2A3	6532 589725	MARINA DENISOVA	{"phone": "+70624424669"}
0005433186306	EE399F	5830 989648	OLEG VLASOV	{"phone": "+70085362526"}
0005433186307	EE399F	0549 405679	NIKOLAY SMIRNOV	{"email": "nsmirnov.06031964@postgrespro.ru", "phone": "+70400734168"}
0005433186308	4ED9B1	1573 082986	ELENA IVANOVA	{"phone": "+70491609216"}
0005433186309	F0F8F7	1715 432408	ELENA GRISHINA	{"email": "e-grishina-25051974@postgrespro.ru", "phone": "+70874508597"}
0005433186310	B79DE8	7378 987195	MARINA SERGEEVA	{"phone": "+70484954577"}
0005433186311	B79DE8	4045 920824	INNA KOLESNIKOVA	{"phone": "+70399801617"}
0005433186312	B79DE8	9007 880795	INESSA CHERNOVA	{"phone": "+70541848532"}
0005433186313	FD5E4B	8326 556551	VALERIY ISAEV	{"email": "isaevvaleriy031971@postgrespro.ru", "phone": "+70483986283"}
0005433186314	175213	6257 239055	ILYA SOKOLOV	{"email": "ilya_sokolov-081970@postgrespro.ru", "phone": "+70064401745"}
0005433186315	175213	2625 037278	EVDOKIYA VASILEVA	{"email": "vasileva.evdokiya28051965@postgrespro.ru", "phone": "+70205522795"}
0005433186316	08AA3B	6133 851189	NIKOLAY MATVEEV	{"phone": "+70227103532"}
0005433186317	08AA3B	6370 831692	GALINA KRASNOVA	{"email": "krasnovag_1979@postgrespro.ru", "phone": "+70275060340"}
0005433186318	0081CA	7795 995971	YURIY NOVIKOV	{"email": "novikov_y.061962@postgrespro.ru", "phone": "+70286638860"}
0005433186319	04E662	9838 139513	VERA OSIPOVA	{"email": "osipova-vera.011968@postgrespro.ru", "phone": "+70505729605"}
0005433186320	04E662	7479 631239	OLGA FADEEVA	{"email": "ofadeeva101970@postgrespro.ru", "phone": "+70851139397"}
0005433186321	04E662	9941 257732	MARINA SOLOVEVA	{"email": "marinasoloveva1977@postgrespro.ru", "phone": "+70447305385"}
0005433186322	073EF4	3757 904405	ANNA GAVRILOVA	{"phone": "+70527758136"}
0005433186323	62C284	4425 000367	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr_23011975@postgrespro.ru", "phone": "+70752138966"}
0005433186324	8747B3	8243 987514	NIKOLAY FEDOROV	{"email": "n_fedorov011972@postgrespro.ru", "phone": "+70485624184"}
0005433186325	B4578D	8319 409379	ALEKSANDR ZAKHAROV	{"phone": "+70753398645"}
0005433186326	BE6DF9	6537 892786	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.051969@postgrespro.ru", "phone": "+70276313996"}
0005433186327	FD25DC	0536 453247	EVGENIY VOLKOV	{"phone": "+70622999757"}
0005433186328	17809C	8062 661975	MARINA NESTEROVA	{"email": "nesterova.marina.1971@postgrespro.ru", "phone": "+70006075062"}
0005433186329	15B6BD	5040 821603	NINA ROMANOVA	{"phone": "+70034727952"}
0005433186330	F78A37	1666 350737	GERMAN VASILEV	{"phone": "+70170648506"}
0005433186331	F78A37	5713 766434	GALINA MIRONOVA	{"email": "g_mironova.20111970@postgrespro.ru", "phone": "+70117837623"}
0005433186332	20AF9E	4671 943988	MIKHAIL GORBUNOV	{"phone": "+70872855484"}
0005433186333	20AF9E	3652 992851	TATYANA SMIRNOVA	{"email": "tatyana_smirnova-14121969@postgrespro.ru", "phone": "+70500574354"}
0005433186334	A3CA42	7256 479711	LYUBOV ABRAMOVA	{"phone": "+70635265508"}
0005433186335	601DCF	2769 071952	SVETLANA GERASIMOVA	{"phone": "+70319381387"}
0005433186336	E56ACA	8340 593689	EKATERINA ZAYCEVA	{"email": "e-zayceva_1975@postgrespro.ru", "phone": "+70994454205"}
0005433186337	E56ACA	7694 469952	ALEKSEY GORBUNOV	{"email": "gorbunovaleksey.031973@postgrespro.ru", "phone": "+70169487650"}
0005433186338	5F981F	6347 719288	NINA MARTYNOVA	{"email": "n-martynova.02021967@postgrespro.ru", "phone": "+70884657031"}
0005433186339	8E8D3E	0151 797831	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov.1974@postgrespro.ru", "phone": "+70020607500"}
0005433186340	6D82DE	2472 724422	YURIY KOZLOV	{"phone": "+70083665859"}
0005433186341	6D82DE	2361 235072	RIMMA PAVLOVA	{"phone": "+70491487987"}
0005433186342	B7D83C	9305 954423	LIDIYA ARKHIPOVA	{"phone": "+70639934049"}
0005433186343	E1ADB2	9846 608313	RAMIL FEDOROV	{"phone": "+70361381565"}
0005433186344	BBAFA1	2727 775440	NATALYA BOGDANOVA	{"email": "natalya_bogdanova_03081976@postgrespro.ru", "phone": "+70450786591"}
0005433186345	BBAFA1	2467 339293	VIKTOR ILIN	{"phone": "+70754787729"}
0005433186346	6CB992	3731 954922	SERGEY GRIGOREV	{"email": "grigorevs.091957@postgrespro.ru", "phone": "+70046350074"}
0005433186347	6CB992	6027 701375	DINA ABRAMOVA	{"phone": "+70036191449"}
0005433186348	6CB992	4388 187488	NIKITA ROMANOV	{"email": "romanovn_1972@postgrespro.ru", "phone": "+70959797639"}
0005433186349	48480C	0727 627304	ANDREY SOLOVEV	{"email": "andrey-solovev_011973@postgrespro.ru", "phone": "+70009308747"}
0005433186350	F1EB4A	1763 557276	GENNADIY IVANOV	{"email": "g-ivanov.1977@postgrespro.ru", "phone": "+70526598190"}
0005433186351	7BAD2C	9345 067253	DANIIL KUDRYASHOV	{"email": "kudryashov.d011983@postgrespro.ru", "phone": "+70991121293"}
0005433186352	F028A2	4549 275848	YULIYA KOZLOVA	{"phone": "+70099102499"}
0005433186353	A1177B	1615 298910	ANASTASIYA SMIRNOVA	{"phone": "+70345294891"}
0005433186354	80B09A	2020 971330	BORIS MIRONOV	{"email": "boris.mironov1971@postgrespro.ru", "phone": "+70485680032"}
0005433186355	7DDCF3	7769 569395	MARINA ANDREEVA	{"email": "andreeva.m.071977@postgrespro.ru", "phone": "+70565134828"}
0005433186356	C84F33	5254 071310	SERGEY KUZNECOV	{"phone": "+70863070796"}
0005433193030	804A4E	6761 339573	NATALYA DENISOVA	{"phone": "+70553116625"}
0005433186357	C84F33	2953 990717	VASILIY IVANOV	{"email": "ivanov.vasiliy1982@postgrespro.ru", "phone": "+70223592393"}
0005433186358	21CC9B	9997 370991	OLGA KOVALEVA	{"email": "olga_kovaleva-051970@postgrespro.ru", "phone": "+70068061651"}
0005433186359	724303	3760 275911	IVAN TARASOV	{"email": "ivan.tarasov-1972@postgrespro.ru", "phone": "+70357242708"}
0005433186360	724303	0880 924903	NIKOLAY GUSEV	{"email": "n-gusev-21121965@postgrespro.ru", "phone": "+70927266537"}
0005433186361	1B76FB	3889 336769	YURIY BORISOV	{"phone": "+70968285414"}
0005433186362	1B76FB	2611 637923	GLEB NIKITIN	{"phone": "+70358380903"}
0005433186363	9C1F47	3102 158880	SVETLANA EGOROVA	{"email": "egorova.s031976@postgrespro.ru", "phone": "+70921006124"}
0005433186364	9C1F47	6308 910488	NINA SOROKINA	{"phone": "+70313766587"}
0005433186365	D4C304	2449 242324	LARISA GRISHINA	{"phone": "+70099202812"}
0005433186366	D4C304	1478 017518	ANATOLIY ILIN	{"email": "ilin-anatoliy.111979@postgrespro.ru", "phone": "+70381714909"}
0005433186367	D4C304	8890 924695	ALEKSEY VOLKOV	{"phone": "+70551876021"}
0005433186368	729922	4290 649417	VERA ALEKSANDROVA	{"phone": "+70943710166"}
0005433186369	4678F2	0387 214548	ALEKSANDR MOISEEV	{"phone": "+70712615812"}
0005433186370	43A27F	2087 169638	VYACHESLAV MARTYNOV	{"phone": "+70288590286"}
0005433186371	D2A360	8826 497691	ALEKSANDR SIDOROV	{"phone": "+70069129237"}
0005433186372	D2A360	4139 679283	ANDREY MEDVEDEV	{"phone": "+70642857366"}
0005433186373	BBC90D	3267 032619	ALEKSEY MELNIKOV	{"email": "melnikova_011983@postgrespro.ru", "phone": "+70820142137"}
0005433186374	BBC90D	0095 885253	ZOYA MAKSIMOVA	{"phone": "+70736975642"}
0005433186375	7D221F	2031 647901	NATALYA DMITRIEVA	{"email": "dmitrieva.natalya.031969@postgrespro.ru", "phone": "+70185982872"}
0005433192809	8F8D45	5284 674529	ANDREY VASILEV	{"phone": "+70547755013"}
0005433192810	8F8D45	4124 188653	ELZA KONOVALOVA	{"email": "e.konovalova.03041972@postgrespro.ru", "phone": "+70313652094"}
0005433192811	3A14C7	1583 970670	LEYLA MELNIKOVA	{"email": "melnikova_l.1970@postgrespro.ru", "phone": "+70127925240"}
0005433192812	749200	3539 065747	ANDREY ISAEV	{"email": "isaev-andrey11061977@postgrespro.ru", "phone": "+70099887812"}
0005433192813	35B9C5	8672 898912	IRINA POPOVA	{"email": "popovai_081972@postgrespro.ru", "phone": "+70399838829"}
0005433192814	35B9C5	4623 244741	EVGENIY SOROKIN	{"phone": "+70402882284"}
0005433192815	E36D32	7325 076819	RAISA SMIRNOVA	{"email": "smirnovar-1971@postgrespro.ru", "phone": "+70205956272"}
0005433192816	2C12C1	1175 801376	ELENA ILINA	{"phone": "+70074549670"}
0005433192817	2C12C1	0418 296388	NATALYA ZAKHAROVA	{"phone": "+70540693767"}
0005433192818	F8E437	6759 677040	ALINA SMIRNOVA	{"email": "smirnova.a.111980@postgrespro.ru", "phone": "+70872530231"}
0005433192819	C21ECE	6296 465372	VADIM NOVIKOV	{"phone": "+70014165158"}
0005433192820	723E5E	3384 913760	ANNA MATVEEVA	{"email": "a-matveeva-121969@postgrespro.ru", "phone": "+70551549750"}
0005433192821	D9CDF2	8863 231441	TATYANA KUZNECOVA	{"phone": "+70410599245"}
0005433192822	1139CD	7280 089829	YAROSLAV VOLKOV	{"phone": "+70815421616"}
0005433192823	9136BA	2398 807433	VIKTOR MELNIKOV	{"phone": "+70340416291"}
0005433192824	9136BA	8564 497063	MARINA NOVIKOVA	{"phone": "+70312154228"}
0005433192825	B77633	9990 320539	SERGEY POPOV	{"email": "popov.sergey-18101978@postgrespro.ru", "phone": "+70265488987"}
0005433192826	4695A8	5708 644659	IRINA KOROLEVA	{"email": "irina-koroleva.071968@postgrespro.ru", "phone": "+70390484814"}
0005433192827	322D14	5281 460554	ALEKSANDR IVANOV	{"phone": "+70462248054"}
0005433192828	0841A8	8700 195786	ANGELINA GAVRILOVA	{"email": "gavrilova.a_1967@postgrespro.ru", "phone": "+70115089551"}
0005433192829	0841A8	2091 196102	RAISA RYABOVA	{"email": "ryabova.r.051969@postgrespro.ru", "phone": "+70644453200"}
0005433192830	8804B6	4167 411252	ALEKSANDRA PETROVA	{"email": "a_petrova-041981@postgrespro.ru", "phone": "+70543772843"}
0005433192831	EAD697	0810 122995	SVETLANA GORBUNOVA	{"phone": "+70488924960"}
0005433192832	AA5CA9	9396 764404	NADEZHDA MELNIKOVA	{"phone": "+70349660116"}
0005433192833	AA5CA9	6235 910039	IRINA MARTYNOVA	{"email": "martynova.irina-24011977@postgrespro.ru", "phone": "+70460676500"}
0005433192834	44B7F7	2519 050562	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova_1971@postgrespro.ru", "phone": "+70615820053"}
0005433192835	2E686B	7462 659241	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov15101973@postgrespro.ru", "phone": "+70003376535"}
0005433192836	2E686B	9232 811025	SVETLANA VASILEVA	{"email": "svetlana.vasileva011979@postgrespro.ru", "phone": "+70809611695"}
0005433192837	2E686B	0606 086643	VLADIMIR VOLKOV	{"phone": "+70347444384"}
0005433192838	8DCACE	7603 003055	ANDREY SOROKIN	{"email": "sorokin_a1968@postgrespro.ru", "phone": "+70783491469"}
0005433192839	8DCACE	3709 040166	MARINA KOROLEVA	{"phone": "+70531202932"}
0005433192840	795F1B	4003 203444	ALMIRA NIKOLAEVA	{"email": "nikolaeva_a_29051977@postgrespro.ru", "phone": "+70709461293"}
0005433192841	01DCD6	9467 392958	NATALIYA NOVIKOVA	{"email": "novikova_n.12041974@postgrespro.ru", "phone": "+70035577806"}
0005433192842	AC1897	8902 202632	SERGEY KUZMIN	{"phone": "+70472235698"}
0005433192843	73DF69	1773 028137	DMITRIY GRIGOREV	{"email": "grigorev_dmitriy041966@postgrespro.ru", "phone": "+70631833412"}
0005433192844	50F8C1	6981 709028	ALEKSANDR AFANASEV	{"email": "a-afanasev071971@postgrespro.ru", "phone": "+70485940627"}
0005433192845	EFCAE5	1122 479148	YULIYA POPOVA	{"email": "popovay-23111967@postgrespro.ru", "phone": "+70300287422"}
0005433192846	E1EBAD	2272 505082	ANTON FROLOV	{"phone": "+70806463185"}
0005433192847	A06A9F	5425 571444	ALISA SOLOVEVA	{"email": "soloveva-a-1961@postgrespro.ru", "phone": "+70508393772"}
0005433192848	B57A8F	4993 552046	ZINAIDA VOLKOVA	{"phone": "+70966661098"}
0005433192849	0E7912	2699 866030	LYUBOV VASILEVA	{"phone": "+70820714796"}
0005433192850	ADC1D9	8109 455476	RUSTAM KUZNECOV	{"email": "r-kuznecov-101974@postgrespro.ru", "phone": "+70195231893"}
0005433192851	1F7449	2518 602513	SERGEY IVANOV	{"email": "ivanovsergey-091964@postgrespro.ru", "phone": "+70739166065"}
0005433192852	96C1EA	7286 085972	LYUBOV KONOVALOVA	{"phone": "+70329713107"}
0005433192853	96C1EA	4376 652715	ELVIRA NESTEROVA	{"phone": "+70059755905"}
0005433192854	9B764C	2757 312958	OKSANA PAVLOVA	{"email": "o-pavlova_021963@postgrespro.ru", "phone": "+70791267532"}
0005433192855	AD2855	3806 665965	SERGEY ILIN	{"email": "s_ilin_09091971@postgrespro.ru", "phone": "+70690497042"}
0005433192856	AD2855	5555 026905	ILDAR YAKOVLEV	{"email": "ildar-yakovlev-08011969@postgrespro.ru", "phone": "+70758352052"}
0005433192857	D34115	9504 004922	ELENA PETROVA	{"phone": "+70625763871"}
0005433192858	909D94	8761 511819	EGOR KUZMIN	{"phone": "+70618212961"}
0005433192859	909D94	9562 686689	SERGEY GORBUNOV	{"email": "gorbunovsergey.1972@postgrespro.ru", "phone": "+70846631494"}
0005433192860	909D94	1822 310626	RAISA CHERNOVA	{"phone": "+70488879988"}
0005433192861	F2BCE4	7279 592856	TATYANA VASILEVA	{"email": "tatyana_vasileva111962@postgrespro.ru", "phone": "+70922468994"}
0005433192862	D0E264	2329 980000	RUSLAN MIKHAYLOV	{"email": "mikhaylovr.101970@postgrespro.ru", "phone": "+70612723905"}
0005433192863	D0E264	8814 563019	ROMAN FROLOV	{"email": "r-frolov.051973@postgrespro.ru", "phone": "+70831182866"}
0005433192864	39BC46	8733 336664	VLADIMIR NIKITIN	{"phone": "+70103543648"}
0005433192865	A9682A	7985 540470	ALEKSEY BONDARENKO	{"phone": "+70588153559"}
0005433192866	44F711	9201 249733	SERGEY DMITRIEV	{"email": "dmitrievsergey-18051962@postgrespro.ru", "phone": "+70911772163"}
0005433192867	68952A	9163 465568	IRINA DANILOVA	{"email": "danilovai.31051961@postgrespro.ru", "phone": "+70344627387"}
0005433192868	68952A	0670 098874	IVAN PAVLOV	{"phone": "+70863305957"}
0005433192869	FFA952	0529 842619	ALEKSEY DMITRIEV	{"email": "a-dmitriev27071960@postgrespro.ru", "phone": "+70629104294"}
0005433192870	1FAB75	0124 775477	IRINA POTAPOVA	{"email": "potapova_irina11101984@postgrespro.ru", "phone": "+70086931292"}
0005433192871	1FAB75	3773 599184	VIKTORIYA BELOVA	{"phone": "+70342587665"}
0005433192872	9C17FF	9859 596699	GALINA GERASIMOVA	{"email": "g-gerasimova-12091974@postgrespro.ru", "phone": "+70488533942"}
0005433192873	70CE73	2995 499489	YANA VOROBEVA	{"phone": "+70069118486"}
0005433192986	FEA868	3480 879823	VALENTINA KARPOVA	{"phone": "+70904311581"}
0005433192874	4725D5	9749 066897	ALENA SAVELEVA	{"email": "saveleva-alena_16081967@postgrespro.ru", "phone": "+70764873357"}
0005433192875	4725D5	0184 847833	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey-1954@postgrespro.ru", "phone": "+70931182883"}
0005433192876	4A31B4	6341 952925	NATALYA MELNIKOVA	{"email": "melnikova_natalya021978@postgrespro.ru", "phone": "+70987865094"}
0005433192877	3C20E2	7830 289350	SVETLANA STEPANOVA	{"email": "stepanova.svetlana021971@postgrespro.ru", "phone": "+70276320626"}
0005433192878	B57F75	5145 174913	PAVEL ANDREEV	{"email": "p-andreev-13091969@postgrespro.ru", "phone": "+70542606042"}
0005433192879	A6BA7E	6983 661890	VALENTINA MALYSHEVA	{"email": "v-malysheva-1968@postgrespro.ru", "phone": "+70870256137"}
0005433192880	432FB1	9520 474579	ALEKSANDRA ROMANOVA	{"email": "aleksandra-romanova-1974@postgrespro.ru", "phone": "+70968056725"}
0005433192881	C6173B	8780 433412	LYUDMILA LEBEDEVA	{"email": "lyudmilalebedeva-1968@postgrespro.ru", "phone": "+70112490110"}
0005433192882	FA0475	7229 898084	ALENA RODIONOVA	{"email": "rodionovaalena_1963@postgrespro.ru", "phone": "+70911056098"}
0005433192883	FA0475	7252 295164	MARIYA OSIPOVA	{"phone": "+70417220751"}
0005433192884	72097B	3805 669960	NIKITA ORLOV	{"email": "orlov-nikita.03051979@postgrespro.ru", "phone": "+70556654495"}
0005433192885	72097B	0456 290751	LYUBOV POLYAKOVA	{"email": "lyubov.polyakova-1957@postgrespro.ru", "phone": "+70088792932"}
0005433192886	EA963C	2685 511753	ARINA SOKOLOVA	{"phone": "+70136297920"}
0005433192887	CBED55	1715 598833	BULAT SOKOLOV	{"email": "sokolovbulat121975@postgrespro.ru", "phone": "+70372079277"}
0005433192888	8EF510	5061 729236	KONSTANTIN ZHUKOV	{"email": "konstantin-zhukov_1972@postgrespro.ru", "phone": "+70695041200"}
0005433192889	8EF510	6853 177129	ANATOLIY CHERNOV	{"phone": "+70007652933"}
0005433192890	FA03A1	6652 719321	SVETLANA SEMENOVA	{"phone": "+70036561830"}
0005433192891	18729D	9992 085287	TAMARA LUKYANOVA	{"email": "lukyanovat_1980@postgrespro.ru", "phone": "+70873869964"}
0005433192892	18729D	5357 165296	ANATOLIY KARPOV	{"phone": "+70116548219"}
0005433192893	ACC8B9	3263 132306	ILONA POPOVA	{"phone": "+70827787640"}
0005433192894	ACC8B9	6879 438472	NINA AKIMOVA	{"phone": "+70208358268"}
0005433192895	49A825	1939 212835	IVAN ALEKSEEV	{"email": "i_alekseev10081983@postgrespro.ru", "phone": "+70675320759"}
0005433192896	49A825	5675 840598	KRISTINA SIDOROVA	{"phone": "+70396029076"}
0005433192897	49A825	6334 233319	MAKSIM SOKOLOV	{"email": "sokolov.maksim_01051970@postgrespro.ru", "phone": "+70620238192"}
0005433192898	8FA2F5	9507 580199	ANDREY ZAYCEV	{"email": "zaycevandrey.1994@postgrespro.ru", "phone": "+70233789949"}
0005433192899	8FA2F5	1151 987674	LEONID ORLOV	{"phone": "+70357133897"}
0005433192900	92D39D	4594 658175	EVGENIY ZAYCEV	{"email": "evgeniyzaycev_081976@postgrespro.ru", "phone": "+70982066484"}
0005433192901	D26256	4941 780077	DENIS SHEVCHENKO	{"email": "d_shevchenko_1952@postgrespro.ru", "phone": "+70063476072"}
0005433192902	D5014B	6152 120172	VLADIMIR FROLOV	{"email": "frolov.v.031984@postgrespro.ru", "phone": "+70225359116"}
0005433192903	08A3EC	1185 960811	LILIYA VOLKOVA	{"email": "l.volkova-04071974@postgrespro.ru", "phone": "+70461919023"}
0005433192904	163C22	4552 497003	OLGA POPOVA	{"phone": "+70880691358"}
0005433192905	1E3F09	5616 167708	VIKTOR MOISEEV	{"email": "viktor_moiseev20041979@postgrespro.ru", "phone": "+70846520246"}
0005433192906	2FC646	7928 376051	GALINA FEDOROVA	{"phone": "+70129225244"}
0005433192907	2FC646	8048 815281	ANTON NIKOLAEV	{"email": "nikolaevanton.111973@postgrespro.ru", "phone": "+70023118099"}
0005433192908	C9B8F0	2300 091361	VIKTORIYA LAZAREVA	{"phone": "+70051547279"}
0005433192909	9D9A28	8477 324921	NIKOLAY MIKHAYLOV	{"phone": "+70483702263"}
0005433192910	F5F584	8242 131909	ANATOLIY ISAEV	{"email": "anatoliy_isaev_091980@postgrespro.ru", "phone": "+70662591741"}
0005433192911	B46F60	4654 256464	SERGEY GAVRILOV	{"email": "gavrilov.s-30091970@postgrespro.ru", "phone": "+70537115868"}
0005433192912	D1251A	1722 412783	KLAVDIYA PETROVA	{"phone": "+70587917067"}
0005433192913	095E4D	7264 579508	ELENA MAKAROVA	{"phone": "+70326346780"}
0005433192914	095E4D	0035 241244	NATALYA ANISIMOVA	{"email": "anisimova-natalya_08071980@postgrespro.ru", "phone": "+70175474970"}
0005433192915	095E4D	7035 891883	NIKOLAY DENISOV	{"phone": "+70729673721"}
0005433192916	FBBEB9	8443 096488	LIDIYA SEMENOVA	{"phone": "+70667479556"}
0005433192917	000859	1729 880179	TATYANA TARASOVA	{"email": "tarasova-tatyana051978@postgrespro.ru", "phone": "+70924576384"}
0005433192918	000859	9221 608063	GALINA BORISOVA	{"phone": "+70112016470"}
0005433192919	000859	6404 918237	LYUDMILA KISELEVA	{"email": "kiseleva_lyudmila07111970@postgrespro.ru", "phone": "+70815104921"}
0005433192920	5D3449	6443 900514	ALEKSANDRA EGOROVA	{"phone": "+70641859676"}
0005433192921	5D3449	8987 776880	ALEKSANDRA NOVIKOVA	{"email": "a_novikova_1974@postgrespro.ru", "phone": "+70519903067"}
0005433192922	5D3449	1335 433648	NADEZHDA VOROBEVA	{"phone": "+70082383362"}
0005433192923	6A934C	9925 505441	DMITRIY IVANOV	{"phone": "+70499586030"}
0005433192924	D9948D	3916 840410	ANNA SEMENOVA	{"phone": "+70777851442"}
0005433192925	D9948D	0459 275552	DENIS PAVLOV	{"phone": "+70143417331"}
0005433192926	D9948D	8135 819351	DENIS VASILEV	{"phone": "+70827510869"}
0005433192927	544BE5	8729 432397	FEDOR TIMOFEEV	{"phone": "+70734705782"}
0005433192928	1833BF	6061 748199	TIMOFEY ILIN	{"email": "ilin-t_07071974@postgrespro.ru", "phone": "+70970922742"}
0005433192929	1833BF	8174 634089	ELENA MELNIKOVA	{"phone": "+70681861596"}
0005433192930	1833BF	9926 739251	ALEKSEY EGOROV	{"email": "egorova.101973@postgrespro.ru", "phone": "+70109617912"}
0005433192931	1833BF	2048 559316	EKATERINA ORLOVA	{"phone": "+70007303880"}
0005433192932	650C02	9498 221801	IRINA KARPOVA	{"phone": "+70413917183"}
0005433192933	69AC60	4671 411476	ELENA BELOVA	{"email": "belovae_021977@postgrespro.ru", "phone": "+70950201914"}
0005433192934	1A0BD2	6653 144658	ALEKSANDR GORBUNOV	{"email": "agorbunov28071977@postgrespro.ru", "phone": "+70093099319"}
0005433192935	EC0AB3	4594 462120	EVGENIY MOISEEV	{"email": "moiseev_e_10051971@postgrespro.ru", "phone": "+70690034293"}
0005433192936	EC0AB3	8156 787221	ALEKSANDR SMIRNOV	{"phone": "+70826610219"}
0005433192937	065838	0992 822194	ZINAIDA TROFIMOVA	{"email": "trofimovaz13101974@postgrespro.ru", "phone": "+70141610414"}
0005433192938	76A24E	9955 959805	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr1979@postgrespro.ru", "phone": "+70446349921"}
0005433192939	76A24E	1837 815020	ARTEM FEDOTOV	{"email": "fedotov_a_01021970@postgrespro.ru", "phone": "+70713888438"}
0005433192940	EDCC66	0948 524429	LYUDMILA FILIPPOVA	{"phone": "+70520094027"}
0005433192941	EDCC66	1020 556288	IGOR MAKAROV	{"email": "i_makarov_121982@postgrespro.ru", "phone": "+70530316726"}
0005433192942	B3DA36	7282 703805	ALLA KUDRYASHOVA	{"email": "alla-kudryashova.1966@postgrespro.ru", "phone": "+70691948371"}
0005433192943	48ABD1	2067 520812	ALEKSANDR STEPANOV	{"phone": "+70779964231"}
0005433192944	299762	7015 751636	LYUDMILA ALEKSEEVA	{"phone": "+70617710667"}
0005433192945	CFE3B9	8228 005690	DMITRIY MEDVEDEV	{"phone": "+70998818035"}
0005433192946	CFE3B9	9287 299629	TATYANA POPOVA	{"phone": "+70097612452"}
0005433192947	E47DFB	5854 674744	MARIYA NIKOLAEVA	{"email": "mnikolaeva.1983@postgrespro.ru", "phone": "+70972235428"}
0005433192948	E47DFB	6278 759064	IVAN STEPANOV	{"email": "i.stepanov-1975@postgrespro.ru", "phone": "+70828544496"}
0005433192949	D79F8E	6844 908043	VYACHESLAV NAUMOV	{"phone": "+70938932925"}
0005433192950	D79F8E	9635 934283	ANDREY NOVIKOV	{"email": "anovikov_29101968@postgrespro.ru", "phone": "+70293492221"}
0005433192951	0CD120	8134 668615	ALEKSEY SOROKIN	{"phone": "+70654360561"}
0005433192952	0CD120	0780 506552	SVETLANA ALEKSEEVA	{"email": "s_alekseeva_101969@postgrespro.ru", "phone": "+70604689890"}
0005433192953	A81CB2	1886 870967	EKATERINA NESTEROVA	{"email": "nesterovae.071977@postgrespro.ru", "phone": "+70241125103"}
0005433192954	A81CB2	8347 783233	OKSANA KALININA	{"phone": "+70408722716"}
0005433192955	DF41C8	9400 241600	SERGEY ZAKHAROV	{"phone": "+70051156173"}
0005433192956	ECBF52	6200 564379	SVETLANA BORISOVA	{"email": "svetlana-borisova_26041970@postgrespro.ru", "phone": "+70652665365"}
0005433192957	26A942	4530 292716	ADELINA ZAYCEVA	{"phone": "+70468880966"}
0005433192958	F9751A	0666 562263	LYUDMILA KOMAROVA	{"phone": "+70110717744"}
0005433192959	00B525	7243 158514	YULIYA KOZLOVA	{"email": "kozlova_yuliya-03121972@postgrespro.ru", "phone": "+70485329174"}
0005433192960	00B525	1864 728096	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov03101972@postgrespro.ru", "phone": "+70543382557"}
0005433192961	BD6224	9490 138692	VLADIMIR ANTONOV	{"phone": "+70412899037"}
0005433192962	4BEED8	0638 474067	YULIYA KULIKOVA	{"phone": "+70867102544"}
0005433192963	F3925D	5942 676937	NIKITA NIKOLAEV	{"email": "nikita.nikolaev_1967@postgrespro.ru", "phone": "+70714024389"}
0005433192964	F3925D	1206 795678	TATYANA FROLOVA	{"phone": "+70391259037"}
0005433192965	25014D	8403 483441	YURIY ZHURAVLEV	{"phone": "+70082367678"}
0005433192966	99CE40	9637 513781	ALEKSANDR VASILEV	{"email": "vasilev-a.29081979@postgrespro.ru", "phone": "+70461807347"}
0005433192967	2FBD79	1888 825628	KONSTANTIN MOROZOV	{"email": "konstantin.morozov_011972@postgrespro.ru", "phone": "+70999855811"}
0005433192968	0BA311	9342 432068	OLEG MATVEEV	{"phone": "+70330127572"}
0005433192969	4842DC	6916 642027	VIKTOR KARPOV	{"email": "karpov-v.091982@postgrespro.ru", "phone": "+70885311066"}
0005433192970	2DDFE9	2679 889416	GALINA POTAPOVA	{"phone": "+70242440079"}
0005433192971	766423	9813 023726	VALERIY BORISOV	{"email": "borisov_v_1972@postgrespro.ru", "phone": "+70401913706"}
0005433192972	766423	5981 032144	VLADIMIR KAZAKOV	{"email": "kazakov.v.16051971@postgrespro.ru", "phone": "+70760197831"}
0005433192973	58BB03	5700 658822	VALENTINA EGOROVA	{"email": "valentina-egorova.031975@postgrespro.ru", "phone": "+70109972579"}
0005433192974	8D584B	8759 194089	MARIYA ZAKHAROVA	{"phone": "+70281785685"}
0005433192975	2F5969	9138 502772	ANTONINA KOVALEVA	{"phone": "+70302729355"}
0005433192976	2F5969	4515 610029	TATYANA KONDRATEVA	{"email": "tatyana.kondrateva-1985@postgrespro.ru", "phone": "+70114270929"}
0005433192977	35F160	8260 819342	NATALYA ALEKSEEVA	{"phone": "+70688927718"}
0005433192978	1C693A	1033 811537	LIDIYA KOLESNIKOVA	{"phone": "+70795794810"}
0005433192979	7AACDD	1693 340506	KSENIYA KOZLOVA	{"email": "kozlova-kseniya-111979@postgrespro.ru", "phone": "+70184174508"}
0005433192980	E06061	0845 410765	SVETLANA KUZNECOVA	{"phone": "+70933826280"}
0005433192981	BE4441	2759 271813	LYUBOV KOMAROVA	{"phone": "+70968806674"}
0005433192982	BE4441	6872 868794	IGOR BORISOV	{"phone": "+70489093461"}
0005433192983	422CF5	4141 159370	EKATERINA TROFIMOVA	{"email": "trofimova-e.1979@postgrespro.ru", "phone": "+70465778085"}
0005433192984	2A5DB8	2140 913903	EGOR IVANOV	{"email": "egor.ivanov-1969@postgrespro.ru", "phone": "+70126018784"}
0005433192985	FEA868	9348 997558	OLEG KOZLOV	{"phone": "+70177572336"}
0005433192987	31CEFA	5287 137608	OLGA IVANOVA	{"email": "olgaivanova1976@postgrespro.ru", "phone": "+70866862527"}
0005433192988	977737	5685 951293	ALEKSANDR DMITRIEV	{"phone": "+70952923233"}
0005433192989	BA6ACD	9581 798028	NAIL ORLOV	{"phone": "+70835042562"}
0005433192990	F05A56	1830 806877	EVGENIY KUZNECOV	{"email": "kuznecov-e19081981@postgrespro.ru", "phone": "+70987700354"}
0005433192991	932EAA	4875 878980	PRASKOVYA FOMINA	{"email": "p_fomina-1981@postgrespro.ru", "phone": "+70145219816"}
0005433192992	8D245D	5081 974609	ALEKSANDR ANDREEV	{"email": "andreev_a-1977@postgrespro.ru", "phone": "+70799320213"}
0005433192993	8D245D	4991 910391	VALENTINA IVANOVA	{"phone": "+70428864072"}
0005433192994	5BB169	5050 956004	TATYANA MELNIKOVA	{"email": "tatyana_melnikova.051985@postgrespro.ru", "phone": "+70218161356"}
0005433192995	F49DCE	5010 612215	NIKOLAY SEMENOV	{"phone": "+70637522924"}
0005433192996	AE4C08	2940 611231	ALENA BOGDANOVA	{"email": "bogdanovaalena.121973@postgrespro.ru", "phone": "+70576275248"}
0005433192997	859D17	2710 677881	GALINA IVANOVA	{"phone": "+70987541129"}
0005433192998	859D17	0365 439334	ANNA POPOVA	{"phone": "+70359167272"}
0005433192999	D5BC0B	7656 509439	NINA FROLOVA	{"email": "frolovanina.091970@postgrespro.ru", "phone": "+70712429321"}
0005433193000	9B2E20	0942 226460	YURIY ANDREEV	{"phone": "+70303920165"}
0005433193001	6BE25A	2997 491640	EVGENIY IVANOV	{"phone": "+70131798655"}
0005433193002	6BE25A	1959 848873	VLADIMIR VOLKOV	{"phone": "+70371789197"}
0005433193003	E485B6	8616 710830	ALEKSEY MELNIKOV	{"phone": "+70610383656"}
0005433193004	4B438B	9754 853746	ALEKSANDR EGOROV	{"email": "egorov_aleksandr-20071978@postgrespro.ru", "phone": "+70550625512"}
0005433193005	4B438B	7182 052724	NIKOLAY VOLKOV	{"email": "nikolay-volkov_031968@postgrespro.ru", "phone": "+70176182560"}
0005433193006	F3F75A	3281 395578	NIKITA ABRAMOV	{"phone": "+70427649345"}
0005433193007	A437EF	3691 050252	NIKOLAY SOROKIN	{"email": "nsorokin1962@postgrespro.ru", "phone": "+70181159273"}
0005433193008	A437EF	9974 645724	MARINA KOZLOVA	{"email": "kozlovamarina14071967@postgrespro.ru", "phone": "+70389535434"}
0005433193009	BE021C	1236 399839	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova_t_051980@postgrespro.ru", "phone": "+70616495936"}
0005433193010	BE021C	8616 475615	ANDREY POPOV	{"phone": "+70479484577"}
0005433193011	BE3F24	5045 922048	IOSIF FEDOROV	{"email": "ifedorov-04041967@postgrespro.ru", "phone": "+70427825325"}
0005433193012	59AC5B	2614 986780	ALEKSANDR SMIRNOV	{"phone": "+70295117913"}
0005433193013	59AC5B	2710 797597	DMITRIY ABRAMOV	{"phone": "+70171907391"}
0005433193014	BF5266	5817 008524	RUSLAN PETROV	{"email": "petrov.ruslan1962@postgrespro.ru", "phone": "+70078291773"}
0005433193015	BF5266	7784 435759	OLGA SMIRNOVA	{"email": "olga-smirnova-23101971@postgrespro.ru", "phone": "+70498802909"}
0005433193016	12D244	3153 175894	SERGEY CHERNOV	{"email": "chernov.s_31071976@postgrespro.ru", "phone": "+70599183950"}
0005433193017	12D244	3548 229643	VLADIMIR MELNIKOV	{"phone": "+70452441174"}
0005433193018	FB83F7	9601 420178	LYUDMILA SOROKINA	{"phone": "+70708602866"}
0005433193019	ACD338	0000 226451	VLADIMIR SAVELEV	{"email": "v_savelev-24121969@postgrespro.ru", "phone": "+70553528956"}
0005433193020	6151A8	7853 912285	NIKOLAY SIDOROV	{"email": "sidorov.nikolay_09091967@postgrespro.ru", "phone": "+70615142486"}
0005433193021	F9689F	8969 243217	DARYA DENISOVA	{"email": "denisova.d-1971@postgrespro.ru", "phone": "+70248074969"}
0005433193022	8B8479	1417 465893	ALEKSANDR GRIGOREV	{"phone": "+70407766909"}
0005433193023	8D8598	2804 815350	NATALYA KONDRATEVA	{"phone": "+70278516958"}
0005433193024	0FB75B	7741 970617	ALEKSEY RODIONOV	{"email": "rodionov-a.101961@postgrespro.ru", "phone": "+70749067908"}
0005433193025	41D9BF	3158 138457	VYACHESLAV SIDOROV	{"phone": "+70117968099"}
0005433193026	28DFD2	3079 729683	ANDREY NIKITIN	{"email": "nikitina1968@postgrespro.ru", "phone": "+70624090691"}
0005433193027	638B67	4438 778580	VITALIY VLASOV	{"phone": "+70269559193"}
0005433193028	17CE32	7879 124919	GALINA MARTYNOVA	{"email": "galina_martynova111975@postgrespro.ru", "phone": "+70521344244"}
0005433193029	17CE32	6791 366119	ELENA ILINA	{"email": "ilina.e_031981@postgrespro.ru", "phone": "+70233907455"}
0005433193031	1E8AB1	3522 766680	ALEKSANDR PETROV	{"email": "aleksandr-petrov1975@postgrespro.ru", "phone": "+70519287036"}
0005433193032	03F8F9	7314 582995	VERA NIKOLAEVA	{"phone": "+70228139115"}
0005433193033	56CA44	0107 218851	ALEKSANDR MELNIKOV	{"email": "aleksandr_melnikov.1969@postgrespro.ru", "phone": "+70343884392"}
0005433193034	A8A3C6	6336 035541	ALEKSANDRA NAZAROVA	{"phone": "+70861274755"}
0005433193035	64AC9E	9767 744025	KSENIYA ZAKHAROVA	{"phone": "+70834555247"}
0005433193036	64AC9E	0481 362816	MIKHAIL KULIKOV	{"email": "kulikov_mikhail.041986@postgrespro.ru", "phone": "+70113564460"}
0005433193037	81269A	2075 470131	VLADIMIR KUZNECOV	{"phone": "+70242542401"}
0005433193038	81269A	1387 090096	MARK MOISEEV	{"phone": "+70294773256"}
0005433193039	5D9728	9934 546943	EKATERINA MELNIKOVA	{"email": "melnikova_e1967@postgrespro.ru", "phone": "+70890500194"}
0005433193040	5D9728	5253 102944	VLADISLAV AFANASEV	{"phone": "+70212186041"}
0005433193041	5D9728	6937 956841	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey09041977@postgrespro.ru", "phone": "+70661606196"}
0005433193042	EEFFCF	2113 413268	OLGA FILIPPOVA	{"email": "filippova_o-1975@postgrespro.ru", "phone": "+70637847052"}
0005433193043	922A13	4016 310500	KRISTINA SOLOVEVA	{"email": "kristina_soloveva16111979@postgrespro.ru", "phone": "+70618009740"}
0005433193044	B6E289	1878 143265	LARISA VOLKOVA	{"phone": "+70184366835"}
0005433193045	DD358C	8723 605442	EVGENIY ANDREEV	{"phone": "+70366657253"}
0005433193046	FA428E	8401 988212	IVAN KARPOV	{"email": "karpov.ivan-051967@postgrespro.ru", "phone": "+70160447046"}
0005433193047	4C07B5	1752 080307	LILIYA TARASOVA	{"email": "liliya.tarasova.1965@postgrespro.ru", "phone": "+70204874986"}
0005433193048	4C07B5	9590 486767	MARIANNA BARANOVA	{"phone": "+70294307869"}
0005433193049	99BE61	7722 096695	MIKHAIL STEPANOV	{"phone": "+70589086205"}
0005433193050	64D5B0	7806 135369	LYUBOV FROLOVA	{"phone": "+70954527619"}
0005433193051	64D5B0	0976 599817	SEMEN KOROLEV	{"phone": "+70143188266"}
0005433193052	6A5708	9001 051342	MARGARITA SEMENOVA	{"phone": "+70938778354"}
0005433193053	6A5708	3340 564572	ELENA BARANOVA	{"phone": "+70946825002"}
0005433193054	A3EAE3	5752 130597	MAKSIM KONOVALOV	{"phone": "+70034964984"}
0005433193055	A3EAE3	1802 708087	RUSLAN ZHURAVLEV	{"phone": "+70570161307"}
0005433193056	A3EAE3	7059 450346	GALINA LUKYANOVA	{"phone": "+70779612242"}
0005433193057	9B2564	4896 607406	NATALIYA KOROLEVA	{"phone": "+70517326550"}
0005433193058	F70123	3304 459440	ALFIYA SOLOVEVA	{"phone": "+70832463931"}
0005433193059	F70123	0954 152152	LYUDMILA EFIMOVA	{"email": "lyudmilaefimova14061962@postgrespro.ru", "phone": "+70998795922"}
0005433193060	89A91C	2221 507517	ANDREY ISAEV	{"phone": "+70109145526"}
0005433193061	C59842	2199 690446	NATALYA SEMENOVA	{"email": "natalyasemenova_1968@postgrespro.ru", "phone": "+70598960766"}
0005433193062	C59842	3508 387588	VYACHESLAV KISELEV	{"email": "vkiselev_041985@postgrespro.ru", "phone": "+70501012928"}
0005433193063	EF808B	8945 357744	VALENTINA IVANOVA	{"email": "v.ivanova_18011969@postgrespro.ru", "phone": "+70133587837"}
0005433193064	EF808B	6383 625337	VERA BELOVA	{"phone": "+70278013706"}
0005433193065	53A907	0946 017569	ALEKSANDR PETROV	{"phone": "+70674577381"}
0005433193066	53A907	1716 362183	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov.101966@postgrespro.ru", "phone": "+70623317276"}
0005433193067	DFB92C	5772 097980	OLEG POPOV	{"phone": "+70642193426"}
0005433193068	DFB92C	5240 726436	VALENTINA PETROVA	{"email": "vpetrova091970@postgrespro.ru", "phone": "+70392634059"}
0005433193069	AE7428	2951 916871	VIKTOR ALEKSANDROV	{"email": "aleksandrov-v011974@postgrespro.ru", "phone": "+70186886406"}
0005433193070	C7A9D7	0803 814383	OLGA KOROLEVA	{"phone": "+70373932378"}
0005433193071	8259D9	9264 224699	NATALYA GORBUNOVA	{"email": "gorbunova_n.061981@postgrespro.ru", "phone": "+70145488650"}
0005433193072	06CEB5	3834 965578	OLGA GORBUNOVA	{"phone": "+70848321166"}
0005433193073	06CEB5	6352 473703	NATALYA GRISHINA	{"email": "grishinan_01011971@postgrespro.ru", "phone": "+70376294221"}
0005433193074	483568	1045 563299	LYUBOV ZHURAVLEVA	{"phone": "+70075485421"}
0005433193075	FD4E06	7234 035700	ELENA KONOVALOVA	{"phone": "+70946497473"}
0005433193076	2C8EDE	5047 482261	ANNA MAKAROVA	{"phone": "+70515750337"}
0005433193077	694D99	0724 494132	SVETLANA NAZAROVA	{"phone": "+70387958963"}
0005433193078	505CFA	5850 874211	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey1972@postgrespro.ru", "phone": "+70156614078"}
0005433193079	505CFA	3264 565493	VIKTOR SHEVCHENKO	{"email": "v-shevchenko_021973@postgrespro.ru", "phone": "+70408457775"}
0005433193080	CB64DB	7847 992610	EKATERINA FILATOVA	{"phone": "+70406405123"}
0005433193081	CB64DB	8593 396341	MARIYA LAZAREVA	{"phone": "+70545789456"}
0005433193082	B821EF	5580 509227	MARINA ZAKHAROVA	{"email": "zakharova.m011980@postgrespro.ru", "phone": "+70107744614"}
0005433193083	6AF47E	7460 417482	EKATERINA MAKAROVA	{"phone": "+70020669012"}
0005433193084	D0151A	9177 383250	INNA SOROKINA	{"email": "sorokinai_09051965@postgrespro.ru", "phone": "+70542683241"}
0005433193085	04836E	9317 355186	ALEKSANDR VOROBEV	{"phone": "+70888328374"}
0005433193086	EA658B	0160 589088	LYUDMILA KOZLOVA	{"phone": "+70523167778"}
0005433193087	69F487	4563 928249	EVGENIY SIDOROV	{"phone": "+70042185193"}
0005433193088	9DD5E5	2108 921892	EGOR DAVYDOV	{"email": "e-davydov_23041957@postgrespro.ru", "phone": "+70990034979"}
0005433193089	4115E7	1688 693639	EVGENIY SOLOVEV	{"email": "solovev_evgeniy.18051979@postgrespro.ru", "phone": "+70021533892"}
0005433193090	4115E7	7122 699931	NATALYA KUZMINA	{"phone": "+70487961336"}
0005433193091	CA9CC8	5989 384551	NATALYA TIMOFEEVA	{"email": "n.timofeeva_1977@postgrespro.ru", "phone": "+70763347971"}
0005433193092	CA9CC8	2146 617367	DMITRIY FROLOV	{"phone": "+70506665110"}
0005433193093	CA9CC8	0379 444959	GALINA SEMENOVA	{"phone": "+70987067071"}
0005433193094	01482A	0005 760194	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov-01051970@postgrespro.ru", "phone": "+70724237777"}
0005433193095	73980A	1721 491466	ANDREY SCHERBAKOV	{"phone": "+70224841549"}
0005433193096	BF4D23	9932 723628	OLEG GERASIMOV	{"email": "ogerasimov.26021977@postgrespro.ru", "phone": "+70131867679"}
0005433193097	BF4D23	2693 282359	VITALIY MOROZOV	{"phone": "+70219812569"}
0005433193098	6480F1	4494 096752	SERGEY DENISOV	{"phone": "+70177000222"}
0005433193099	16AFE1	6756 814093	IRINA KUZNECOVA	{"email": "irina.kuznecova1984@postgrespro.ru", "phone": "+70130650922"}
0005433193100	16AFE1	2236 072952	KARINA ANDREEVA	{"phone": "+70378048506"}
0005433193101	A80610	5712 643678	MARGARITA SAVELEVA	{"email": "saveleva_margarita.011955@postgrespro.ru", "phone": "+70417608148"}
0005433193102	9E7890	4569 924169	DENIS IVANOV	{"phone": "+70750398629"}
0005433193103	029758	6211 952603	MIKHAIL DAVYDOV	{"email": "davydov.mikhail1971@postgrespro.ru", "phone": "+70571062836"}
0005433193104	3EE8BC	2984 927061	ANASTASIYA LOGINOVA	{"email": "anastasiya_loginova031980@postgrespro.ru", "phone": "+70959541965"}
0005433193105	3EE8BC	8524 378419	VERA PETROVA	{"phone": "+70169264512"}
0005433193106	F44AF8	5894 741797	OKSANA MOROZOVA	{"email": "o_morozova.101964@postgrespro.ru", "phone": "+70480340993"}
0005433193107	F44AF8	0218 679716	SVETLANA ROMANOVA	{"email": "s.romanova.29061976@postgrespro.ru", "phone": "+70616487820"}
0005433193108	F44AF8	5287 123766	VASILIY POPOV	{"email": "vpopov1966@postgrespro.ru", "phone": "+70426968659"}
0005433193109	F54AD5	3637 904589	ANNA MAKSIMOVA	{"phone": "+70054900215"}
0005433193110	F4E4EB	0139 023695	ALINA BORISOVA	{"email": "borisova_alina-1973@postgrespro.ru", "phone": "+70343680188"}
0005433193111	F4E4EB	0428 460239	MARIYA NOVIKOVA	{"email": "novikova-m061970@postgrespro.ru", "phone": "+70084691310"}
0005433193112	18F8A5	4891 271006	IBRAGIM BONDARENKO	{"phone": "+70253480737"}
0005433193113	18F8A5	5237 715303	MIKHAIL FEDOROV	{"email": "fedorov-mikhail26091970@postgrespro.ru", "phone": "+70398697717"}
0005433193114	B7F0E7	5092 751736	IVAN ZAYCEV	{"phone": "+70192866714"}
0005433193115	8E8BCF	4635 834880	EGOR GUSEV	{"phone": "+70012440894"}
0005433193116	974257	7399 943470	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy_1978@postgrespro.ru", "phone": "+70027588304"}
0005433193117	974257	4039 012105	SERGEY GORBUNOV	{"email": "gorbunov_sergey_071974@postgrespro.ru", "phone": "+70735140105"}
0005433193118	78D754	8859 883591	ANNA KUZNECOVA	{"phone": "+70932746523"}
0005433193119	A05731	3049 739034	PELAGEYA SERGEEVA	{"email": "sergeeva-p_1970@postgrespro.ru", "phone": "+70016229519"}
0005433193120	10F982	9105 699980	ALEKSANDR IVANOV	{"email": "ivanov-a.031978@postgrespro.ru", "phone": "+70524911733"}
0005433193121	10F982	3702 657678	NIKOLAY FROLOV	{"email": "nikolay.frolov.051973@postgrespro.ru", "phone": "+70169806181"}
0005433193122	C9006A	5073 619870	RAISA SEMENOVA	{"email": "semenova_raisa.011975@postgrespro.ru", "phone": "+70591060903"}
0005433193123	C9006A	5536 913180	VALENTINA PETROVA	{"phone": "+70341094591"}
0005433193124	B4862E	1195 983294	ANDREY ZAYCEV	{"email": "zaycev-andrey_16081975@postgrespro.ru", "phone": "+70873675163"}
0005433193125	BE1C2D	9852 059812	YURIY KARPOV	{"phone": "+70100155906"}
0005433193126	3D3FE2	2635 303368	KONSTANTIN PETROV	{"email": "k-petrov.02051966@postgrespro.ru", "phone": "+70180207662"}
0005433193127	BCD25A	2229 463554	ALEKSANDR ZHUKOV	{"email": "zhukov_a_121983@postgrespro.ru", "phone": "+70440032705"}
0005433193128	D64217	5653 072808	SERGEY FEDOROV	{"email": "fedorov.s_091973@postgrespro.ru", "phone": "+70918871728"}
0005433193129	7DD1F3	4700 033803	IRINA EFREMOVA	{"email": "i.efremova-16021969@postgrespro.ru", "phone": "+70048967492"}
0005433193130	BE90D8	7987 877202	LEONID POPOV	{"phone": "+70310078663"}
0005433193131	FE278C	1606 142068	SERGEY NIKITIN	{"phone": "+70103928261"}
0005433193132	FE278C	2540 399806	ALEKSEY KUZNECOV	{"phone": "+70337836678"}
0005433193133	8D72B9	4988 695356	MAKSIM ZHUKOV	{"phone": "+70664337557"}
0005433193134	496176	6251 852484	ALEKSEY BELOV	{"phone": "+70667915131"}
0005433193135	A7CD02	5627 092876	ARTUR KOZLOV	{"email": "kozlov-artur.30091970@postgrespro.ru", "phone": "+70834012385"}
0005433193136	A7CD02	7784 944623	IRINA RYABOVA	{"email": "irinaryabova12101979@postgrespro.ru", "phone": "+70481710062"}
0005433193137	A7CD02	1543 103173	EVGENIY SCHERBAKOV	{"phone": "+70301040024"}
0005433193138	C39BE1	1597 654399	VALERIY DENISOV	{"phone": "+70466085208"}
0005433193139	C39BE1	6554 952238	TATYANA FADEEVA	{"email": "fadeeva-tatyana.1978@postgrespro.ru", "phone": "+70265618052"}
0005433193140	1AC447	0094 474648	MARINA KOZLOVA	{"email": "kozlova_m.21081959@postgrespro.ru", "phone": "+70509174584"}
0005433193141	1AC447	3744 476281	ANDREY PAVLOV	{"email": "pavlov-andrey011977@postgrespro.ru", "phone": "+70828571000"}
0005433193142	3F7A38	7835 846276	KRISTINA VASILEVA	{"email": "k.vasileva_02121970@postgrespro.ru", "phone": "+70836426640"}
0005433193143	3F7A38	6838 420156	EVGENIY GERASIMOV	{"email": "evgeniy_gerasimov.111964@postgrespro.ru", "phone": "+70619094138"}
0005433193144	1A750E	7263 623056	ALEKSANDR PETROV	{"email": "petrov_a_1975@postgrespro.ru", "phone": "+70507316557"}
0005433193145	1A750E	7553 259071	ELENA ABRAMOVA	{"email": "elenaabramova-1964@postgrespro.ru", "phone": "+70086099862"}
0005433193146	4B8B19	4149 377937	ROMAN EGOROV	{"phone": "+70569075909"}
0005433193147	E8E91E	0714 218787	EKATERINA NAUMOVA	{"email": "e_naumova1979@postgrespro.ru", "phone": "+70886730866"}
0005433193148	792605	6796 174572	SVETLANA ANTONOVA	{"email": "s_antonova_021966@postgrespro.ru", "phone": "+70385325871"}
0005433193149	792605	5319 328368	OLGA PAVLOVA	{"phone": "+70257032654"}
0005433193150	F7B3CA	1462 666425	IGOR KUZNECOV	{"phone": "+70561349926"}
0005433193151	F7780C	8131 936588	MARINA KARPOVA	{"phone": "+70469114817"}
0005433193152	F4E0FF	1201 182440	DMITRIY ANTONOV	{"email": "dmitriy_antonov02011971@postgrespro.ru", "phone": "+70658662913"}
0005433193153	8F368A	2686 447561	VALENTINA KUZNECOVA	{"phone": "+70221331177"}
0005433193154	2CA69F	3679 548205	DMITRIY SEMENOV	{"email": "d_semenov_21071976@postgrespro.ru", "phone": "+70133983177"}
0005433193155	1318A8	1859 031019	PETR YAKOVLEV	{"phone": "+70083320399"}
0005433193156	1318A8	0864 022809	ELENA DAVYDOVA	{"email": "davydova_e1989@postgrespro.ru", "phone": "+70264507378"}
0005433193157	073F45	9697 474338	ANNA OSIPOVA	{"phone": "+70681582778"}
0005433193158	CB2342	8916 206988	ANDREY MIKHAYLOV	{"email": "mikhaylov-andrey1979@postgrespro.ru", "phone": "+70208978176"}
0005433193159	5FE413	2409 563878	ALEKSANDR CHERNOV	{"phone": "+70507760820"}
0005433193160	5FE413	2866 406848	SVETLANA FROLOVA	{"email": "sfrolova-011974@postgrespro.ru", "phone": "+70750754761"}
0005433193161	4F1B8E	5421 667379	GALINA SOKOLOVA	{"phone": "+70784788500"}
0005433193162	7B92F1	9924 961272	ALEKSANDRA MOROZOVA	{"email": "morozova.aleksandra-20111977@postgrespro.ru", "phone": "+70519722069"}
0005433193163	7B92F1	7953 843654	ALEKSANDR STEPANOV	{"email": "stepanov-a021976@postgrespro.ru", "phone": "+70553030861"}
0005433193164	2C10EB	1865 204416	ZOYA LEBEDEVA	{"email": "lebedevaz-1973@postgrespro.ru", "phone": "+70216199693"}
0005433193165	B2E088	1962 259502	ANTON PETROV	{"email": "a_petrov-1973@postgrespro.ru", "phone": "+70467218070"}
0005433193166	B2E088	1366 947459	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov.1966@postgrespro.ru", "phone": "+70761681666"}
0005433193167	E8251D	3371 406965	MILANA ALEKSEEVA	{"email": "alekseeva.milana.041973@postgrespro.ru", "phone": "+70214969043"}
0005433193168	EE46AD	7040 150381	LYUDMILA BELOVA	{"email": "belovalyudmila-1970@postgrespro.ru", "phone": "+70013093451"}
0005433193169	20AD03	1235 289203	VALENTINA NOVIKOVA	{"phone": "+70959349357"}
0005433193170	20AD03	8658 459356	PAVEL GORBUNOV	{"email": "pavel_gorbunov-1979@postgrespro.ru", "phone": "+70962926734"}
0005433193171	20AD03	1478 716316	NINA SIDOROVA	{"email": "sidorovan091974@postgrespro.ru", "phone": "+70378598518"}
0005433193172	088612	3611 301484	VALENTINA MALYSHEVA	{"email": "malyshevavalentina-071968@postgrespro.ru", "phone": "+70437031806"}
0005433193173	D0E5CF	0730 693009	VLADIMIR KISELEV	{"email": "vladimir-kiselev-021978@postgrespro.ru", "phone": "+70541304557"}
0005433193174	D0E5CF	4811 572828	GALINA VOLKOVA	{"email": "volkova.galina1962@postgrespro.ru", "phone": "+70210576162"}
0005433193175	63001A	4194 174434	SERGEY GORBUNOV	{"email": "s.gorbunov071968@postgrespro.ru", "phone": "+70104076560"}
0005433193176	63001A	9335 304083	ANGELINA VASILEVA	{"email": "angelina.vasileva091976@postgrespro.ru", "phone": "+70822882928"}
0005433193177	07997D	4963 473771	NIKOLAY BARANOV	{"email": "nikolay_baranov21061976@postgrespro.ru", "phone": "+70057536856"}
0005433193178	07997D	4634 584924	SERGEY MATVEEV	{"email": "matveev.s.06091974@postgrespro.ru", "phone": "+70656355433"}
0005433193179	1313C7	1311 043907	ELENA KONOVALOVA	{"email": "konovalovae_1970@postgrespro.ru", "phone": "+70549339425"}
0005433193180	CAF211	0347 543246	MIKHAIL DMITRIEV	{"email": "mdmitriev_04121978@postgrespro.ru", "phone": "+70070957727"}
0005433193181	CAF211	8412 197414	ALEKSANDR EGOROV	{"phone": "+70780623907"}
0005433193182	F5D227	4587 926411	PAVEL NAUMOV	{"email": "naumovpavel_26061960@postgrespro.ru", "phone": "+70521928280"}
0005433193183	968F38	8342 629079	VIKTOR ROMANOV	{"email": "viktorromanov121970@postgrespro.ru", "phone": "+70770662049"}
0005433193184	968F38	5757 708739	TATYANA MIKHAYLOVA	{"email": "tatyana.mikhaylova.1973@postgrespro.ru", "phone": "+70434343097"}
0005433193185	D6A722	6720 784340	DMITRIY SOLOVEV	{"email": "solovev_dmitriy.1979@postgrespro.ru", "phone": "+70784361537"}
0005433193186	4C2D1E	8839 067038	VLADIMIR MATVEEV	{"phone": "+70073729858"}
0005433193187	B0C1C7	9103 694857	GALINA MATVEEVA	{"phone": "+70653374443"}
0005433193188	C17733	1646 778546	IVAN BELOV	{"email": "belov_ivan-1970@postgrespro.ru", "phone": "+70759549292"}
0005433193189	C1DC93	9132 388776	DARYA NOVIKOVA	{"phone": "+70006572457"}
0005433193190	C1DC93	1024 644445	KIRILL ANDREEV	{"email": "andreev.k-03021978@postgrespro.ru", "phone": "+70734785708"}
0005433193191	497919	5898 922371	EKATERINA KALININA	{"email": "ekaterina-kalinina.13051970@postgrespro.ru", "phone": "+70828529585"}
0005433193192	45BB96	9576 196296	GALINA DAVYDOVA	{"email": "davydovag.111981@postgrespro.ru", "phone": "+70093802193"}
0005433193193	050AFA	4482 439473	ARINA NAZAROVA	{"phone": "+70336634330"}
0005433193194	5ACEB3	8758 826872	SVETLANA ZHURAVLEVA	{"email": "zhuravleva_svetlana.071967@postgrespro.ru", "phone": "+70340529876"}
0005433193195	5ACEB3	0005 814718	MARIYA GERASIMOVA	{"phone": "+70326195786"}
0005433193196	ED47AA	7903 232929	TATYANA SOROKINA	{"email": "sorokina.tatyana.121972@postgrespro.ru", "phone": "+70233516574"}
0005433193197	47EC5A	2695 437603	OLGA ROMANOVA	{"phone": "+70131603043"}
0005433193198	659A9E	9391 049374	MARIYA KUZNECOVA	{"email": "mariyakuznecova031966@postgrespro.ru", "phone": "+70459388724"}
0005433193199	659A9E	2719 347271	ANATOLIY SMIRNOV	{"email": "anatoliysmirnov.021971@postgrespro.ru", "phone": "+70915844010"}
0005433193200	B5DA49	6406 263791	LYUBOV BORISOVA	{"email": "lyubovborisova_19061973@postgrespro.ru", "phone": "+70328243613"}
0005433193201	B5DA49	1769 282713	MARINA SOROKINA	{"phone": "+70012470801"}
0005433193202	C5436C	5934 360818	NATALIYA OSIPOVA	{"email": "osipovan-071976@postgrespro.ru", "phone": "+70002221862"}
0005433193203	4E9316	1634 723706	NAIL IVANOV	{"email": "ivanov.n1973@postgrespro.ru", "phone": "+70395757636"}
0005433193204	4E9316	9036 328098	OLGA NIKITINA	{"email": "o_nikitina11071962@postgrespro.ru", "phone": "+70738308319"}
0005433193205	4E9316	7699 433629	MARINA LAZAREVA	{"phone": "+70277257970"}
0005433193206	DAEF2C	6436 461885	OLGA FILATOVA	{"phone": "+70205884001"}
0005433193207	763E01	1480 318142	LARISA NAZAROVA	{"phone": "+70447214551"}
0005433193208	730C1F	2005 785266	ANVAR MELNIKOV	{"email": "a-melnikov.14071980@postgrespro.ru", "phone": "+70012845337"}
0005433193209	500B2E	6936 558480	NIKOLAY SOKOLOV	{"email": "nikolay-sokolov_18031967@postgrespro.ru", "phone": "+70309989365"}
0005433193210	500B2E	3724 137512	ANASTASIYA BELYAEVA	{"email": "belyaeva.a_031979@postgrespro.ru", "phone": "+70934132615"}
0005433193211	B26731	7240 928972	PETR ISAEV	{"email": "isaev-petr_121969@postgrespro.ru", "phone": "+70708475745"}
0005433193212	B811C1	5778 464596	ANDREY DENISOV	{"phone": "+70269661460"}
0005433193213	B811C1	9506 786118	TATYANA AKIMOVA	{"email": "akimova-t_031973@postgrespro.ru", "phone": "+70086439063"}
0005433193214	812E5F	1084 602169	POLINA SOKOLOVA	{"email": "polina-sokolova-1961@postgrespro.ru", "phone": "+70746490609"}
0005433193215	DA5BDF	1230 506048	LIDIYA DAVYDOVA	{"email": "lidiya-davydova.091978@postgrespro.ru", "phone": "+70554045769"}
0005433193216	7AB839	7405 312726	GALINA KUDRYASHOVA	{"phone": "+70077401921"}
0005433193217	7AB839	1081 386916	TATYANA KOZLOVA	{"email": "t-kozlova.091975@postgrespro.ru", "phone": "+70904027999"}
0005433193218	DEBAF7	8651 695742	EVGENIY CHERNOV	{"phone": "+70275757723"}
0005433193219	DD3A8C	5601 697358	MARIYA SERGEEVA	{"email": "sergeeva.mariya_1971@postgrespro.ru", "phone": "+70293873238"}
0005433193220	5D2856	1598 331234	ALLA MAKAROVA	{"email": "makarova-a.051970@postgrespro.ru", "phone": "+70755690521"}
0005433193221	5D2856	6872 935513	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy-1972@postgrespro.ru", "phone": "+70378292422"}
0005433193222	B4031C	5642 272438	EKATERINA IVANOVA	{"email": "ivanova-ekaterina.021969@postgrespro.ru", "phone": "+70112635815"}
0005433193223	B4031C	6191 536362	ALEKSANDR DENISOV	{"email": "denisov.a_19091975@postgrespro.ru", "phone": "+70655084330"}
0005433193224	71C8B0	2701 616442	VALENTINA ISAEVA	{"phone": "+70483589263"}
0005433193225	71C8B0	5644 173513	MARINA NIKOLAEVA	{"email": "marina_nikolaeva.081980@postgrespro.ru", "phone": "+70454767920"}
0005433193226	D943B7	0472 273586	OLGA MELNIKOVA	{"email": "melnikovaolga-1964@postgrespro.ru", "phone": "+70911213208"}
0005433193227	E4F29C	4102 334400	ELENA TIKHONOVA	{"email": "tikhonovaelena-051971@postgrespro.ru", "phone": "+70503573989"}
0005433193228	A76E0A	5506 736916	ANDREY PETROV	{"email": "petrovandrey-041967@postgrespro.ru", "phone": "+70979649050"}
0005433193229	9A6BCF	2749 488390	VALENTINA RODIONOVA	{"phone": "+70790652984"}
0005433193230	9A6BCF	3632 433326	YURIY EGOROV	{"email": "egorov_yuriy-29041966@postgrespro.ru", "phone": "+70541593979"}
0005433193231	3FB70E	9997 068498	IVAN KONOVALOV	{"phone": "+70828871979"}
0005433193232	9465FE	4163 298765	OLESYA EFIMOVA	{"email": "efimova-o_051967@postgrespro.ru", "phone": "+70597919054"}
0005433193233	A97482	1638 816202	ANASTASIYA VLASOVA	{"email": "anastasiya_vlasova1959@postgrespro.ru", "phone": "+70828933500"}
0005433193234	DE3AE2	3920 547017	ZHANNA SOKOLOVA	{"email": "sokolova-zhanna.20121974@postgrespro.ru", "phone": "+70136472243"}
0005433193235	DE3AE2	9073 672509	MARINA KOMAROVA	{"phone": "+70501589143"}
0005433193236	DE3AE2	3884 605828	IGOR FILIPPOV	{"email": "filippov_i1971@postgrespro.ru", "phone": "+70003757275"}
0005433193237	5336F4	1746 320594	VADIM VASILEV	{"phone": "+70303494463"}
0005433193238	FF9429	9038 143887	VYACHESLAV BELOV	{"phone": "+70629238323"}
0005433193239	DABE57	7532 183060	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev-111982@postgrespro.ru", "phone": "+70126612008"}
0005433193240	D91CDB	9557 856965	NADEZHDA FROLOVA	{"phone": "+70327663258"}
0005433193241	D91CDB	7763 869682	IGOR FROLOV	{"email": "frolov.igor-27111962@postgrespro.ru", "phone": "+70245567238"}
0005433193242	D91CDB	1900 759307	ELENA VOLKOVA	{"phone": "+70291601708"}
0005433193243	2FDE99	4255 433077	ELENA KUZNECOVA	{"email": "kuznecova_elena_091972@postgrespro.ru", "phone": "+70432894037"}
0005433193244	2FDE99	7399 300548	ELENA ZAYCEVA	{"phone": "+70111939510"}
0005433193245	080BA0	3814 407188	SVETLANA BELYAEVA	{"email": "belyaeva-svetlana1971@postgrespro.ru", "phone": "+70981264788"}
0005433193246	BEF28F	3735 621537	OLEG KUZMIN	{"email": "oleg.kuzmin-1975@postgrespro.ru", "phone": "+70290675700"}
0005433193247	2935C3	5455 404490	OLEG VLASOV	{"phone": "+70847244451"}
0005433193248	7E5C32	2356 835896	YULIYA KUZNECOVA	{"email": "kuznecovay.081970@postgrespro.ru", "phone": "+70760712361"}
0005433193249	D76B89	2158 383811	VALERIYA VASILEVA	{"email": "vasilevav_1972@postgrespro.ru", "phone": "+70248361505"}
0005433193250	FFC98A	9730 405118	NATALIYA PETROVA	{"phone": "+70169290774"}
0005433193251	5669EB	4734 631099	SERGEY VASILEV	{"email": "vasilev-s_02041971@postgrespro.ru", "phone": "+70549074622"}
0005433193252	CA2DF8	6838 351798	GALINA GRISHINA	{"email": "grishinag.051975@postgrespro.ru", "phone": "+70123570517"}
0005433193253	518A64	7000 513721	NATALYA KOZLOVA	{"email": "natalya.kozlova021973@postgrespro.ru", "phone": "+70043256581"}
0005433193254	518A64	7593 631779	GRIGORIY OSIPOV	{"phone": "+70117655125"}
0005433193255	625733	0737 679199	NIKITA GORBUNOV	{"phone": "+70883955826"}
0005433193256	625733	6911 231509	MAKSIM RODIONOV	{"phone": "+70801895124"}
0005433193257	0BDBBA	0029 733420	ANDREY VOROBEV	{"phone": "+70976909725"}
0005433193258	71382C	6164 765716	ALEKSANDRA DANILOVA	{"phone": "+70691506333"}
0005433193259	72FDB4	0429 994062	IGOR PAVLOV	{"email": "igor_pavlov.031975@postgrespro.ru", "phone": "+70710047990"}
0005433193260	10E6DD	0573 502966	ANASTASIYA KOZLOVA	{"phone": "+70288170027"}
0005433193261	10E6DD	1736 961185	ANZHELA BOGDANOVA	{"email": "anzhela_bogdanova-011972@postgrespro.ru", "phone": "+70432469124"}
0005433193262	F8793D	1021 029601	NATALYA STEPANOVA	{"phone": "+70768849721"}
0005433193263	F8793D	9340 901138	TATYANA NIKOLAEVA	{"phone": "+70621606209"}
0005433193264	B003D5	9742 571305	TAMARA GERASIMOVA	{"email": "gerasimovat.081962@postgrespro.ru", "phone": "+70002646118"}
0005433193265	58C4D1	9698 056805	PAVEL BORISOV	{"email": "borisov_p-1968@postgrespro.ru", "phone": "+70931800127"}
0005433193266	217328	3685 201728	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov.011973@postgrespro.ru", "phone": "+70229429347"}
0005433193267	D1179C	8280 965773	OLGA MIKHAYLOVA	{"phone": "+70998074291"}
0005433193268	E56A6A	6827 397346	ALINA SMIRNOVA	{"email": "smirnova-alina-031962@postgrespro.ru", "phone": "+70290573593"}
0005433193269	E56A6A	7134 619379	NAIL VASILEV	{"phone": "+70973755778"}
0005433193270	E983A8	6621 556525	YULIYA TIKHONOVA	{"email": "tikhonova.yuliya-1967@postgrespro.ru", "phone": "+70089326484"}
0005433193271	E35188	4720 048324	ELENA PAVLOVA	{"phone": "+70442221517"}
0005433193272	E35188	0864 344303	GERMAN FROLOV	{"email": "frolovgerman05091976@postgrespro.ru", "phone": "+70005516328"}
0005433193273	A8AF6D	3717 098791	STEPAN BORISOV	{"email": "s_borisov061967@postgrespro.ru", "phone": "+70084628571"}
0005433193274	3F74D0	5997 332663	YURIY MOISEEV	{"email": "yuriymoiseev.1980@postgrespro.ru", "phone": "+70244811071"}
0005433193275	171A69	8587 575822	DANILA DMITRIEV	{"email": "dmitriev_d-10021967@postgrespro.ru", "phone": "+70201696391"}
0005433193276	171A69	5872 169080	RAUF RODIONOV	{"email": "rodionov.r-081982@postgrespro.ru", "phone": "+70562483394"}
0005433193277	171A69	1692 705991	TATYANA IVANOVA	{"email": "ivanova_tatyana.021983@postgrespro.ru", "phone": "+70841452064"}
0005433193278	0E98A2	8907 039964	LYUDMILA MIKHAYLOVA	{"phone": "+70451193228"}
0005433193279	FEABC2	0380 556765	SERGEY ZHURAVLEV	{"phone": "+70102723792"}
0005433193280	D4FBCB	8898 745698	VERONIKA MIKHAYLOVA	{"phone": "+70036045749"}
0005433193281	B07E42	5850 591026	ELIZAVETA DENISOVA	{"email": "elizaveta_denisova_011972@postgrespro.ru", "phone": "+70300632544"}
0005433193282	B07E42	4427 761182	ELENA ZHURAVLEVA	{"email": "zhuravleva_e_05021970@postgrespro.ru", "phone": "+70652595811"}
0005433193283	D116C7	7430 760550	VLADIMIR SMIRNOV	{"email": "vsmirnov1977@postgrespro.ru", "phone": "+70170631128"}
0005433193284	73A49B	5410 835256	KSENIYA MEDVEDEVA	{"email": "kmedvedeva041973@postgrespro.ru", "phone": "+70398279188"}
0005433193285	A32A09	2249 830136	LYUDMILA GRISHINA	{"phone": "+70087250692"}
0005433193286	1BA007	1819 398799	VALERIYA SEMENOVA	{"email": "semenova_valeriya_1961@postgrespro.ru", "phone": "+70240478163"}
0005433193287	E5B981	1103 856258	RAIL MOROZOV	{"email": "railmorozov_1971@postgrespro.ru", "phone": "+70449422184"}
0005433193288	E5B981	5423 864964	ALEKSANDR SOKOLOV	{"phone": "+70682285874"}
0005433193289	59270B	2174 594328	OLGA ABRAMOVA	{"phone": "+70044609701"}
0005433193290	59270B	8429 134848	ALSU PETROVA	{"email": "alsupetrova_1979@postgrespro.ru", "phone": "+70913089056"}
0005433193291	59270B	3744 098364	ANTONINA YUDINA	{"phone": "+70679862688"}
0005433193292	F05C66	7812 176637	ELENA MOROZOVA	{"phone": "+70758510265"}
0005433193293	8590D8	0668 185116	ANNA KARPOVA	{"email": "karpova.a16091973@postgrespro.ru", "phone": "+70001401917"}
0005433193294	8590D8	8644 139983	OKSANA FROLOVA	{"email": "oksana.frolova_03051978@postgrespro.ru", "phone": "+70879469668"}
0005433193295	651282	7284 457964	NATALYA SOROKINA	{"phone": "+70398097410"}
0005433193296	651282	2912 634934	TATYANA RYABOVA	{"email": "ryabova.tatyana1974@postgrespro.ru", "phone": "+70910060035"}
0005433193297	97F4FD	2498 138022	TATYANA MAKSIMOVA	{"email": "maksimova.tatyana-06021972@postgrespro.ru", "phone": "+70541387241"}
0005433193298	9C1529	8556 761929	GALINA PAVLOVA	{"phone": "+70475417222"}
0005433193299	9C1529	9424 263168	VLADIMIR ZHUKOV	{"email": "zhukovv-07031982@postgrespro.ru", "phone": "+70776641956"}
0005433193300	4F271F	6604 469779	VYACHESLAV NIKOLAEV	{"email": "vyacheslav_nikolaev29041960@postgrespro.ru", "phone": "+70056340075"}
0005433193301	4F271F	5193 754997	NIKOLAY VASILEV	{"phone": "+70814340433"}
0005433193302	45A97D	4699 278549	ALEKSANDR KOZLOV	{"phone": "+70462502287"}
0005433193303	45A97D	7393 247110	ELENA SEMENOVA	{"phone": "+70443895426"}
0005433193304	435EAB	3174 230546	KONSTANTIN PETROV	{"email": "kpetrov_1969@postgrespro.ru", "phone": "+70719567829"}
0005433193305	F41078	1959 392575	KLAVDIYA GAVRILOVA	{"phone": "+70593114852"}
0005433193306	6A6B87	7178 112924	MARINA CHERNOVA	{"email": "marina-chernova_1976@postgrespro.ru", "phone": "+70221968278"}
0005433193307	FD217C	9632 220494	SERGEY MAKAROV	{"email": "sergey.makarov_07061975@postgrespro.ru", "phone": "+70954428751"}
0005433193308	FD217C	5986 630144	GALINA KULIKOVA	{"phone": "+70918707908"}
0005433193309	EA7363	9297 829241	IRINA ROMANOVA	{"email": "romanova.irina1981@postgrespro.ru", "phone": "+70851749067"}
0005433193310	EA7363	2157 976941	MARK ROMANOV	{"email": "mark.romanov.14031970@postgrespro.ru", "phone": "+70573652413"}
0005433193311	C966FD	1729 938436	ALEKSANDR TIKHONOV	{"phone": "+70908333857"}
0005433193312	288C7F	4041 940392	TATYANA DMITRIEVA	{"phone": "+70427836709"}
0005433193313	657BD0	3512 150265	NINA MEDVEDEVA	{"email": "ninamedvedeva-071973@postgrespro.ru", "phone": "+70063606850"}
0005433193314	657BD0	2741 604699	ALEKSANDR KRASNOV	{"phone": "+70133269398"}
0005433193315	27DD1C	4304 649568	NATALYA PAVLOVA	{"phone": "+70819199562"}
0005433193316	27DD1C	4835 765460	VERA GRISHINA	{"phone": "+70494322830"}
0005433193317	556965	6778 610890	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina-111965@postgrespro.ru", "phone": "+70842314190"}
0005433193318	5CE201	6426 634994	NIKOLAY MEDVEDEV	{"email": "medvedev_nikolay-021961@postgrespro.ru", "phone": "+70208003635"}
0005433193319	BC0E36	8888 644025	ANDREY BORISOV	{"phone": "+70964318371"}
0005433193432	58E473	4205 406710	DARYA KOROLEVA	{"phone": "+70656950809"}
0005433193320	55A186	5666 398667	ELENA POPOVA	{"email": "elena.popova_041969@postgrespro.ru", "phone": "+70248084630"}
0005433193321	55A186	7532 645214	DMITRIY KOZLOV	{"email": "kozlov-d_1964@postgrespro.ru", "phone": "+70212607037"}
0005433193322	B17A93	4563 983267	LYUDMILA MASLOVA	{"phone": "+70971133684"}
0005433193323	A80DFF	9835 925770	TATYANA KUZNECOVA	{"phone": "+70306275689"}
0005433193324	E43F12	4723 768228	ANNA KOZLOVA	{"phone": "+70649210164"}
0005433193325	E43F12	0520 778330	ELENA KUZNECOVA	{"phone": "+70328695447"}
0005433193326	262ACA	8504 413356	IRINA DANILOVA	{"email": "i-danilova1975@postgrespro.ru", "phone": "+70429668589"}
0005433193327	C94BB7	6691 789266	YULIYA SAVELEVA	{"email": "saveleva.y_19121957@postgrespro.ru", "phone": "+70913127440"}
0005433193328	AC3D47	8779 151427	EVGENIY EGOROV	{"email": "egorov-e_1958@postgrespro.ru", "phone": "+70964205498"}
0005433193329	AC3D47	3334 586886	ANDREY MARTYNOV	{"phone": "+70914989092"}
0005433193330	57F1F2	7039 608729	ANDREY SEMENOV	{"email": "semenov_andrey_1985@postgrespro.ru", "phone": "+70051565332"}
0005433193331	05A5A9	1404 645262	SERGEY SOKOLOV	{"email": "sokolov.s.1987@postgrespro.ru", "phone": "+70073827196"}
0005433193332	05A5A9	3425 629295	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr.1983@postgrespro.ru", "phone": "+70946459544"}
0005433193333	06BAC2	1497 516164	EKATERINA IVANOVA	{"email": "ivanovae-04011976@postgrespro.ru", "phone": "+70954620582"}
0005433193334	4486F8	1996 584862	DANILA SERGEEV	{"phone": "+70434274890"}
0005433193335	328507	3126 533861	VITALIY MELNIKOV	{"email": "vitaliy.melnikov.1977@postgrespro.ru", "phone": "+70223429970"}
0005433193336	488DBB	5580 311875	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.01051969@postgrespro.ru", "phone": "+70512510599"}
0005433193337	488DBB	8305 222066	ZOYA MIRONOVA	{"email": "zmironova-051977@postgrespro.ru", "phone": "+70903284853"}
0005433193338	33E83F	3579 560232	ZLATA ZOTOVA	{"email": "zotova.zlata031977@postgrespro.ru", "phone": "+70005413238"}
0005433193339	A7DFEE	9981 596651	YULIYA STEPANOVA	{"phone": "+70762928107"}
0005433193340	ACDD06	4561 082121	VIKTORIYA RODIONOVA	{"phone": "+70015624100"}
0005433193341	4A5B15	3331 582027	ELENA MIKHAYLOVA	{"email": "emikhaylova-111967@postgrespro.ru", "phone": "+70976149901"}
0005433193342	DA329B	2615 749595	LIDIYA IVANOVA	{"email": "ivanoval_15011956@postgrespro.ru", "phone": "+70711681018"}
0005433193343	04BDED	0659 906205	NIKOLAY NAZAROV	{"phone": "+70576287528"}
0005433193344	81DF87	2789 831414	VLADIMIR PETROV	{"email": "v-petrov031967@postgrespro.ru", "phone": "+70630873896"}
0005433193345	81DF87	5391 827190	ELENA EFREMOVA	{"phone": "+70894060232"}
0005433193346	0B4E4A	9724 446863	ELENA LAZAREVA	{"email": "lazareva.e_07071973@postgrespro.ru", "phone": "+70566267668"}
0005433193347	1864F3	8814 246364	ANDREY IVANOV	{"phone": "+70845791613"}
0005433193348	1864F3	8829 358883	MARGARITA IVANOVA	{"phone": "+70164153616"}
0005433193349	2738C8	8459 146437	NATALYA GUSEVA	{"email": "guseva.n-101971@postgrespro.ru", "phone": "+70158643743"}
0005433193350	EACAD4	2118 049848	VYACHESLAV POPOV	{"phone": "+70940015641"}
0005433193351	67D3EF	9045 928332	GRIGORIY ROMANOV	{"phone": "+70505917550"}
0005433193352	67D3EF	8992 156281	KRISTINA KARPOVA	{"email": "karpovak-051973@postgrespro.ru", "phone": "+70720055455"}
0005433193353	53B330	1719 498437	DMITRIY KUZNECOV	{"phone": "+70978118174"}
0005433193354	71860B	0092 076172	IRINA POPOVA	{"email": "popova.irina-041970@postgrespro.ru", "phone": "+70849454288"}
0005433193355	B31235	2375 280996	DARYA GORBUNOVA	{"phone": "+70102230600"}
0005433193356	B31235	6213 663268	DMITRIY SMIRNOV	{"email": "smirnov.d-031974@postgrespro.ru", "phone": "+70654657971"}
0005433193357	EDB2CE	9474 703404	OLGA KUDRYASHOVA	{"email": "kudryashova.o-10071968@postgrespro.ru", "phone": "+70552222019"}
0005433193358	C59CE6	8249 416778	KRISTINA KOROLEVA	{"phone": "+70797948420"}
0005433193359	4EE7A3	6484 696091	SVETLANA POPOVA	{"phone": "+70380187978"}
0005433193360	4EE7A3	7639 243240	VALENTINA KUZNECOVA	{"email": "kuznecovav091974@postgrespro.ru", "phone": "+70541034461"}
0005433193361	5C64CE	3144 410130	NIKOLAY FOMIN	{"email": "fomin-n_19021977@postgrespro.ru", "phone": "+70050072932"}
0005433193362	5C64CE	5058 457461	NIKOLAY OSIPOV	{"phone": "+70692138562"}
0005433193363	A1333E	0642 514990	IRINA ORLOVA	{"email": "orlovai1967@postgrespro.ru", "phone": "+70914916131"}
0005433193364	A6D9CB	3702 012504	DMITRIY MOROZOV	{"email": "dmitriy.morozov_1975@postgrespro.ru", "phone": "+70271897310"}
0005433193365	7F7E87	6663 834439	GALINA NESTEROVA	{"email": "gnesterova-031967@postgrespro.ru", "phone": "+70775634548"}
0005433193366	20C623	6871 441004	ZINAIDA NIKITINA	{"phone": "+70585331121"}
0005433193367	E43199	6825 257697	ANDREY SOLOVEV	{"email": "solovev_andrey_091976@postgrespro.ru", "phone": "+70080348261"}
0005433193368	0D89FC	0031 852264	VALERIY NIKITIN	{"phone": "+70458480828"}
0005433193369	22EB2E	3146 427104	SERGEY SEMENOV	{"phone": "+70384342035"}
0005433193370	9DD39A	6801 421373	PETR KAZAKOV	{"phone": "+70697938088"}
0005433193371	9DD39A	3908 763533	DENIS ALEKSEEV	{"email": "denis.alekseev_1964@postgrespro.ru", "phone": "+70752547030"}
0005433193372	63714B	8740 987794	VALENTIN VOLKOV	{"email": "valentin-volkov.1977@postgrespro.ru", "phone": "+70638835816"}
0005433193373	63714B	6096 759020	DMITRIY VASILEV	{"phone": "+70820146785"}
0005433193374	BA3BE7	7750 201903	GALINA STEPANOVA	{"phone": "+70481666057"}
0005433193375	9A05EA	9327 774735	ARTEM NIKOLAEV	{"email": "nikolaev-a1970@postgrespro.ru", "phone": "+70452450299"}
0005433193376	EA5EF7	0046 140219	TATYANA KOROLEVA	{"email": "koroleva_t24101973@postgrespro.ru", "phone": "+70471006493"}
0005433193377	19CB25	9856 390547	DMITRIY KISELEV	{"phone": "+70065372823"}
0005433193378	19CB25	1252 317150	EKATERINA GAVRILOVA	{"email": "gavrilovaekaterina.101953@postgrespro.ru", "phone": "+70914371905"}
0005433193379	3473C8	3879 235718	ALEKSANDR FROLOV	{"phone": "+70427549207"}
0005433193380	3473C8	0312 896209	ANDREY KUZMIN	{"email": "kuzmin.andrey-12081965@postgrespro.ru", "phone": "+70469166700"}
0005433193381	8922E1	1079 700176	SERGEY NAZAROV	{"phone": "+70859204780"}
0005433193382	76AF9A	6523 825715	VADIM KAZAKOV	{"phone": "+70927263555"}
0005433193383	8EEABC	9963 508396	YULIYA NESTEROVA	{"email": "nesterova_yuliya_1970@postgrespro.ru", "phone": "+70647149825"}
0005433193384	8EEABC	7244 908988	ALEKSEY NIKITIN	{"email": "a_nikitin_1972@postgrespro.ru", "phone": "+70334349422"}
0005433193385	A0EAC3	1571 128238	SERGEY DENISOV	{"phone": "+70134765580"}
0005433193386	05F184	7664 813134	YULIYA MALYSHEVA	{"email": "y_malysheva1967@postgrespro.ru", "phone": "+70209072218"}
0005433193387	05F184	4794 866142	IRINA SERGEEVA	{"phone": "+70426070199"}
0005433193388	B9632F	6382 008728	SERGEY YAKOVLEV	{"phone": "+70109202146"}
0005433193389	B9632F	4046 704623	ALEKSANDR ANTONOV	{"email": "aleksandr-antonov21061961@postgrespro.ru", "phone": "+70656075563"}
0005433193390	F4E0F3	4876 826943	VALENTINA FEDOROVA	{"email": "fedorovavalentina021980@postgrespro.ru", "phone": "+70394523872"}
0005433193391	F4E0F3	3393 472550	VITALIY FROLOV	{"email": "v.frolov011979@postgrespro.ru", "phone": "+70516336721"}
0005433193392	C50AA3	5106 504425	ALFIYA MASLOVA	{"email": "a.maslova_18121970@postgrespro.ru", "phone": "+70014457056"}
0005433193393	C50AA3	3078 963620	ANDREY SMIRNOV	{"email": "andrey.smirnov_111971@postgrespro.ru", "phone": "+70620731278"}
0005433193394	FF66E0	6339 086167	SERGEY FOMIN	{"phone": "+70579022054"}
0005433193395	FF66E0	2229 315331	GALINA VOLKOVA	{"email": "volkovag_1971@postgrespro.ru", "phone": "+70322988966"}
0005433193396	121996	8483 174062	SVETLANA ISAEVA	{"email": "isaevasvetlana.031972@postgrespro.ru", "phone": "+70279054378"}
0005433193397	121996	9830 480318	YULIYA FADEEVA	{"phone": "+70542483243"}
0005433193398	7D88AE	7021 923800	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy041963@postgrespro.ru", "phone": "+70539728229"}
0005433193399	7D88AE	0608 792079	SERGEY SMIRNOV	{"email": "sergeysmirnov-1977@postgrespro.ru", "phone": "+70700753950"}
0005433193400	DDDB9D	6087 022193	NADEZHDA ROMANOVA	{"email": "nadezhdaromanova_15071971@postgrespro.ru", "phone": "+70331287313"}
0005433193401	F3953E	0499 065659	ANNA IVANOVA	{"email": "a.ivanova.11061968@postgrespro.ru", "phone": "+70002341422"}
0005433193402	50F354	4781 901462	ALEKSEY BELOV	{"email": "aleksey.belov.031977@postgrespro.ru", "phone": "+70793056608"}
0005433193403	84582F	0992 626920	TAMARA KRASNOVA	{"phone": "+70253017721"}
0005433193404	CD7972	5710 505855	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov_1977@postgrespro.ru", "phone": "+70204472977"}
0005433193405	67C171	1165 536207	KLAVDIYA MIRONOVA	{"phone": "+70432246424"}
0005433193406	67C171	8423 534887	OLESYA GUSEVA	{"phone": "+70963113568"}
0005433193407	FAB768	1227 642071	NATALYA MATVEEVA	{"phone": "+70336586619"}
0005433193408	A4AE8E	0791 770585	NADEZHDA DENISOVA	{"email": "denisovan_1963@postgrespro.ru", "phone": "+70685536460"}
0005433193409	2E2692	2770 775670	ANASTASIYA MIRONOVA	{"phone": "+70468343921"}
0005433193410	77DF32	2876 583708	ALEKSANDR NIKITIN	{"email": "nikitin.aleksandr1972@postgrespro.ru", "phone": "+70035296141"}
0005433193411	64629D	8717 837625	ALEKSEY OSIPOV	{"phone": "+70001775530"}
0005433193412	C33069	9588 628900	LYUDMILA NIKOLAEVA	{"email": "nikolaeva.l_08041958@postgrespro.ru", "phone": "+70034226505"}
0005433193413	C33069	8719 607809	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy061965@postgrespro.ru", "phone": "+70006087043"}
0005433193414	706C43	7638 227734	LIDIYA FOMINA	{"phone": "+70263567232"}
0005433193415	706C43	2991 475430	SERGEY BORISOV	{"phone": "+70548751684"}
0005433193416	1AA906	6124 567058	BORIS SMIRNOV	{"phone": "+70775485236"}
0005433193417	1AA906	9201 957347	VIKTOR GUSEV	{"email": "v_gusev05061987@postgrespro.ru", "phone": "+70842890770"}
0005433193418	75C94A	6950 700789	MAYYA POPOVA	{"email": "popovamayya_1966@postgrespro.ru", "phone": "+70157121592"}
0005433193419	75C94A	6449 691683	OLGA ROMANOVA	{"phone": "+70767434986"}
0005433193420	DF5365	4206 849517	KSENIYA POLYAKOVA	{"phone": "+70790024797"}
0005433193421	5CFEB0	4058 327229	RAVIL MOROZOV	{"email": "morozov_r.1968@postgrespro.ru", "phone": "+70063011373"}
0005433193422	6842C5	4770 226256	IRINA MATVEEVA	{"phone": "+70999083560"}
0005433193423	6842C5	8746 866746	SABINA VASILEVA	{"email": "s-vasileva.14061959@postgrespro.ru", "phone": "+70123627728"}
0005433193424	AE6A89	8341 278531	EKATERINA DANILOVA	{"phone": "+70834895510"}
0005433193425	FE0589	3420 599146	ANNA DANILOVA	{"phone": "+70233937776"}
0005433193426	EE6C93	8783 192153	KONSTANTIN MOROZOV	{"email": "morozov.k_091976@postgrespro.ru", "phone": "+70824083373"}
0005433193427	936573	1670 223643	ELENA NIKIFOROVA	{"email": "nikiforova.e_031975@postgrespro.ru", "phone": "+70004307726"}
0005433193428	12165C	4912 642478	NINA FADEEVA	{"phone": "+70762882952"}
0005433193429	12165C	8571 520185	IVAN MAKAROV	{"phone": "+70130833300"}
0005433193430	D77A55	1765 269001	ANATOLIY NAZAROV	{"phone": "+70207444586"}
0005433193431	FF2BEB	7357 586660	ILYA ORLOV	{"email": "i_orlov.1977@postgrespro.ru", "phone": "+70106885404"}
0005433193433	58E473	3562 307955	ILYA KOROLEV	{"phone": "+70210148155"}
0005433193434	30102E	9256 397972	ANATOLIY EGOROV	{"phone": "+70158654948"}
0005433193435	30102E	0256 558616	ALEKSANDR FOMIN	{"email": "aleksandr.fomin.19061971@postgrespro.ru", "phone": "+70516057809"}
0005433193436	161A05	2505 808792	VARVARA MALYSHEVA	{"phone": "+70888461477"}
0005433193437	5F44FD	4963 148610	MIKHAIL IVANOV	{"email": "ivanov-m.03111972@postgrespro.ru", "phone": "+70546372002"}
0005433193438	077315	8544 263781	EKATERINA KUZNECOVA	{"email": "kuznecova_e17011979@postgrespro.ru", "phone": "+70415474797"}
0005433193439	077315	0664 432773	VALERIY YAKOVLEV	{"email": "yakovlev-v.21101970@postgrespro.ru", "phone": "+70939109463"}
0005433193440	24A3AC	7666 925464	ANASTASIYA DANILOVA	{"email": "anastasiya.danilova.031966@postgrespro.ru", "phone": "+70078230646"}
0005433193441	24A3AC	5016 685848	ZINAIDA SOROKINA	{"email": "zinaida.sorokina-1981@postgrespro.ru", "phone": "+70611043461"}
0005433193442	699801	5346 753624	ANATOLIY MOROZOV	{"phone": "+70984624953"}
0005433193443	699801	9488 377596	GENNADIY VOLKOV	{"email": "volkov_gennadiy.07031987@postgrespro.ru", "phone": "+70184303495"}
0005433193444	DA7648	1692 896007	ALEKSANDRA PAVLOVA	{"email": "pavlova.a011978@postgrespro.ru", "phone": "+70125496294"}
0005433193445	DA7648	3332 282385	IRINA KUZNECOVA	{"email": "irina.kuznecova1965@postgrespro.ru", "phone": "+70686300567"}
0005433193446	440E81	1351 979999	IRINA SOLOVEVA	{"email": "irina_soloveva1969@postgrespro.ru", "phone": "+70038456357"}
0005433194817	77DDF7	2454 876615	SERGEY ROMANOV	{"phone": "+70068072400"}
0005433194818	5ADF7D	6879 019608	ALEVTINA SMIRNOVA	{"phone": "+70689947086"}
0005433194819	5ADF7D	7413 468480	SERGEY EGOROV	{"phone": "+70839802117"}
0005433194820	DA2198	7000 717374	RUSLAN PETROV	{"email": "petrovr.1967@postgrespro.ru", "phone": "+70471782289"}
0005433194821	B521CB	8610 578513	VLADIMIR BORISOV	{"phone": "+70602992615"}
0005433194822	A237BD	9658 850299	ANASTASIYA MAKAROVA	{"phone": "+70967271903"}
0005433194823	A237BD	9623 378407	LYUDMILA NIKIFOROVA	{"email": "lyudmila_nikiforova-1967@postgrespro.ru", "phone": "+70070679573"}
0005433194824	C12AF5	2480 426145	MARIYA ZAKHAROVA	{"email": "zakharovam1955@postgrespro.ru", "phone": "+70536962953"}
0005433194825	98015D	7842 724075	SERGEY ZAKHAROV	{"email": "sergey-zakharov.01031975@postgrespro.ru", "phone": "+70289009830"}
0005433194826	14C6B1	3532 360836	ELENA POPOVA	{"email": "popova_e28041967@postgrespro.ru", "phone": "+70701810543"}
0005433194827	9855C4	5834 182773	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov.111974@postgrespro.ru", "phone": "+70399922354"}
0005433194828	7C428F	2453 837844	DAMIR SCHERBAKOV	{"email": "damir_scherbakov_01111965@postgrespro.ru", "phone": "+70487467143"}
0005433194829	DB25F2	8770 650126	OKSANA MAKAROVA	{"email": "oksanamakarova17111979@postgrespro.ru", "phone": "+70066390555"}
0005433194830	DB25F2	0495 287813	MIKHAIL KRASNOV	{"email": "krasnov.mikhail101974@postgrespro.ru", "phone": "+70049392235"}
0005433194831	FE82AB	6859 000081	MARINA YUDINA	{"email": "marinayudina_08121967@postgrespro.ru", "phone": "+70123899311"}
0005433194832	83F42C	5252 429977	IRINA ZAYCEVA	{"email": "zayceva_i_10021977@postgrespro.ru", "phone": "+70387086839"}
0005433194833	4440FB	1091 354838	ANDREY ZHUKOV	{"phone": "+70312590712"}
0005433194834	959934	5497 718860	ANNA MAKAROVA	{"phone": "+70135981033"}
0005433194835	647E21	6887 810529	ALEKSANDR KUZNECOV	{"email": "kuznecov.a.14031964@postgrespro.ru", "phone": "+70207154279"}
0005433194836	C13886	1158 484308	OLGA SOROKINA	{"email": "o-sorokina.1978@postgrespro.ru", "phone": "+70608420181"}
0005433194837	921491	8518 239161	SERGEY MATVEEV	{"phone": "+70500537583"}
0005433194838	1279D6	2950 625016	EVGENIY KUZMIN	{"email": "e-kuzmin_24011967@postgrespro.ru", "phone": "+70781239407"}
0005433194839	573C52	1418 408910	VALENTINA SERGEEVA	{"email": "sergeeva.valentina_05041979@postgrespro.ru", "phone": "+70718441636"}
0005433194840	573C52	4587 430520	ANNA ABRAMOVA	{"phone": "+70133038702"}
0005433194841	035620	1292 053630	NIKOLAY FEDOTOV	{"email": "n.fedotov.1973@postgrespro.ru", "phone": "+70822987612"}
0005433194842	035620	3561 555443	OKSANA EGOROVA	{"phone": "+70226839226"}
0005433194843	F344B3	3652 483062	MARIYA KUZMINA	{"email": "kuzmina-m01121974@postgrespro.ru", "phone": "+70451176383"}
0005433194844	2648DA	4040 977305	TATYANA NAUMOVA	{"phone": "+70560319229"}
0005433194845	EC0E9D	7675 027953	ANDREY NIKOLAEV	{"email": "nikolaeva21111979@postgrespro.ru", "phone": "+70772554658"}
0005433194846	501F77	8204 297717	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr051972@postgrespro.ru", "phone": "+70976582848"}
0005433194847	475559	4620 556917	OLGA MOISEEVA	{"phone": "+70786425124"}
0005433194848	83A1E8	3926 712129	ALEKSANDRA MAKAROVA	{"email": "aleksandramakarova-14071967@postgrespro.ru", "phone": "+70121703238"}
0005433194849	83A1E8	3836 722847	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov.041982@postgrespro.ru", "phone": "+70688605241"}
0005433194850	83A1E8	7973 382011	RAISA NOVIKOVA	{"email": "novikova_r04041984@postgrespro.ru", "phone": "+70983252333"}
0005433194851	F51009	5746 486259	VALENTINA IVANOVA	{"email": "ivanova_v.22051979@postgrespro.ru", "phone": "+70974507833"}
0005433194852	C93A54	2732 027698	VALERIY OSIPOV	{"email": "osipov_valeriy1970@postgrespro.ru", "phone": "+70034151321"}
0005433194853	D4A1BF	1342 631215	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova_1968@postgrespro.ru", "phone": "+70814432810"}
0005433194854	D4A1BF	0635 475732	FEDOR TIMOFEEV	{"phone": "+70333518969"}
0005433194855	AD2303	4307 981979	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir.23061972@postgrespro.ru", "phone": "+70616862091"}
0005433194856	3FC7A5	2568 371542	EGOR KONOVALOV	{"email": "konovalov.egor-1976@postgrespro.ru", "phone": "+70457927293"}
0005433194857	05C4B0	3632 701968	IVAN SMIRNOV	{"email": "ivansmirnov31051975@postgrespro.ru", "phone": "+70270390392"}
0005433194858	C9C8E5	9808 772731	ALENA ALEKSEEVA	{"email": "alekseeva_a23051979@postgrespro.ru", "phone": "+70904077421"}
0005433194859	C9C8E5	8062 127800	ELENA MAKAROVA	{"email": "makarova-e-19011976@postgrespro.ru", "phone": "+70137267765"}
0005433194860	18EB4F	8518 880748	ALEKSANDRA TROFIMOVA	{"email": "a_trofimova121965@postgrespro.ru", "phone": "+70276454968"}
0005433194861	91BBCB	4725 239050	ALEKSANDR TIKHONOV	{"phone": "+70339359190"}
0005433194862	615BE1	1825 318169	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr_1974@postgrespro.ru", "phone": "+70973206670"}
0005433194863	615BE1	8092 615586	KSENIYA KRASNOVA	{"email": "krasnova_kseniya12021975@postgrespro.ru", "phone": "+70069617444"}
0005433194864	FE126E	2133 500945	FEDOR TIMOFEEV	{"email": "fedor-timofeev_081974@postgrespro.ru", "phone": "+70916637854"}
0005433194865	24AEF2	4225 932960	LYUDMILA ZHUKOVA	{"email": "lyudmila-zhukova_041977@postgrespro.ru", "phone": "+70974368478"}
0005433194866	24AEF2	7006 757279	YULIYA ILINA	{"phone": "+70782824004"}
0005433194867	7DBEA9	3924 308614	KSENIYA KAZAKOVA	{"email": "kazakova_kseniya05031977@postgrespro.ru", "phone": "+70874476236"}
0005433194868	EBE80F	2613 160182	MIKHAIL FEDOTOV	{"email": "mikhail_fedotov_12051975@postgrespro.ru", "phone": "+70871799134"}
0005433194869	EBE80F	7705 563027	SERGEY ILIN	{"email": "s-ilin-011969@postgrespro.ru", "phone": "+70177353351"}
0005433194870	F900A4	0112 439714	OLGA EGOROVA	{"phone": "+70176971628"}
0005433194871	D3C80B	7070 261542	IVAN SERGEEV	{"email": "i-sergeev05031961@postgrespro.ru", "phone": "+70509827268"}
0005433194872	D3C80B	3650 210247	LARISA DENISOVA	{"phone": "+70373803096"}
0005433194873	868790	2267 717860	ALEKSANDR EGOROV	{"phone": "+70157224998"}
0005433194874	868790	2552 917090	ZHANNA FILIPPOVA	{"email": "z.filippova.081964@postgrespro.ru", "phone": "+70926374273"}
0005433194875	868790	5115 962898	ANASTASIYA VLASOVA	{"phone": "+70964579238"}
0005433194876	28093C	2568 818203	ANNA EGOROVA	{"email": "egorova_a_101977@postgrespro.ru", "phone": "+70327472921"}
0005433194877	CA8035	4440 889279	EVGENIYA KOROLEVA	{"email": "korolevaevgeniya-1976@postgrespro.ru", "phone": "+70482213332"}
0005433194878	5BBC28	8417 019719	EVGENIY ORLOV	{"email": "orlov_evgeniy.111980@postgrespro.ru", "phone": "+70768807314"}
0005433194879	05EEE2	2008 170063	LYUDMILA IVANOVA	{"email": "ivanova-l_1973@postgrespro.ru", "phone": "+70720377884"}
0005433194880	05EEE2	3109 477424	VLADIMIR GORBUNOV	{"email": "vladimir.gorbunov_1976@postgrespro.ru", "phone": "+70776426928"}
0005433194881	CD007D	1600 902694	DMITRIY TIKHONOV	{"phone": "+70995321116"}
0005433194882	0FC431	5599 730045	ANATOLIY SEMENOV	{"phone": "+70432960137"}
0005433194883	8C5C06	0248 926408	NINA PAVLOVA	{"email": "nina_pavlova_01011980@postgrespro.ru", "phone": "+70824813923"}
0005433194884	8C5C06	8481 415405	ALEKSEY OSIPOV	{"email": "osipov.a_1969@postgrespro.ru", "phone": "+70114676053"}
0005433194885	B911F1	4527 040345	ANDREY ZAYCEV	{"email": "zayceva1976@postgrespro.ru", "phone": "+70996083310"}
0005433194886	BD8231	7932 635968	IRINA AFANASEVA	{"phone": "+70787913639"}
0005433194887	BD1705	5356 248821	DANIL ZAKHAROV	{"phone": "+70737714769"}
0005433194888	7111BC	9749 020349	VIKTOR GUSEV	{"email": "viktor_gusev_1974@postgrespro.ru", "phone": "+70737223753"}
0005433194889	7111BC	8712 337969	ANASTASIYA SERGEEVA	{"phone": "+70642399605"}
0005433194890	7111BC	5658 380781	OKSANA AFANASEVA	{"phone": "+70413021460"}
0005433194891	93800E	1100 522995	SERGEY SHEVCHENKO	{"phone": "+70226763298"}
0005433194892	74532A	8080 459351	ROMAN SERGEEV	{"phone": "+70588290202"}
0005433194893	74532A	9598 523089	LYUDMILA ZAYCEVA	{"phone": "+70701346062"}
0005433194894	0CD943	3197 268180	NATALYA GUSEVA	{"phone": "+70089569531"}
0005433194895	64243D	5076 593852	LYUBOV ZHUKOVA	{"phone": "+70435310592"}
0005433194896	AFAE56	9952 428203	ZINAIDA MARTYNOVA	{"email": "zmartynova-1981@postgrespro.ru", "phone": "+70212267437"}
0005433194897	AFAE56	4581 465467	NATALYA BELYAEVA	{"email": "belyaeva.n-1971@postgrespro.ru", "phone": "+70201349634"}
0005433194898	FE0B05	9566 448210	NINA FROLOVA	{"email": "nfrolova_07051965@postgrespro.ru", "phone": "+70456776809"}
0005433194899	3B515B	0015 518140	VLADIMIR MAKAROV	{"phone": "+70060025810"}
0005433194900	311B67	9971 751388	VALENTINA KRASNOVA	{"phone": "+70490638840"}
0005433194901	311B67	5752 175448	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva1975@postgrespro.ru", "phone": "+70311521449"}
0005433194902	311B67	4158 585789	SERGEY POPOV	{"phone": "+70144420436"}
0005433194903	2E280A	0323 974616	OLGA EGOROVA	{"phone": "+70765715779"}
0005433194904	A1A239	3368 352839	ALEKSANDRA DMITRIEVA	{"email": "dmitrievaaleksandra_1963@postgrespro.ru", "phone": "+70346213451"}
0005433194905	62AC5B	3582 322282	SVETLANA YAKOVLEVA	{"phone": "+70499475917"}
0005433194906	62AC5B	2995 441509	ROMAN SOLOVEV	{"email": "solovev.r-02041978@postgrespro.ru", "phone": "+70975926065"}
0005433194907	7169D2	8670 645280	LIDIYA TIMOFEEVA	{"phone": "+70137264155"}
0005433194908	0E2627	1185 937096	EVGENIY KUZNECOV	{"phone": "+70892172160"}
0005433194909	AE401D	0302 203629	NIKOLAY KOROLEV	{"email": "korolevn.1970@postgrespro.ru", "phone": "+70419446661"}
0005433194910	2AB4E6	4903 479076	BORIS SOKOLOV	{"phone": "+70939148654"}
0005433194911	EDE2CC	5504 491300	EVGENIY KULIKOV	{"email": "kulikov.e-31051975@postgrespro.ru", "phone": "+70852534360"}
0005433194912	3DAC36	5347 493713	ANATOLIY KUZMIN	{"phone": "+70776229840"}
0005433194913	896524	4780 599331	GRIGORIY KUZNECOV	{"phone": "+70287422614"}
0005433194914	92787E	5961 103883	GALINA PAVLOVA	{"email": "pavlova_galina1980@postgrespro.ru", "phone": "+70994859959"}
0005433194915	A6ABB5	3408 504196	ANNA EGOROVA	{"email": "a-egorova_24061965@postgrespro.ru", "phone": "+70591720342"}
0005433194916	A9097A	6085 992959	NIKOLAY ZHURAVLEV	{"email": "nzhuravlev-10121980@postgrespro.ru", "phone": "+70396767040"}
0005433194917	A9097A	1110 821757	VIKTOR KUZNECOV	{"phone": "+70481069808"}
0005433194918	CCC111	3391 328827	LYUBOV PAVLOVA	{"email": "lyubov_pavlova.1986@postgrespro.ru", "phone": "+70789538777"}
0005433194919	ABF532	4761 787716	NATALYA MALYSHEVA	{"phone": "+70131133774"}
0005433194920	ABF532	1887 744044	EVGENIY ORLOV	{"phone": "+70348909763"}
0005433194921	B4B6B9	9129 306980	SERGEY VASILEV	{"email": "vasilev_sergey.1962@postgrespro.ru", "phone": "+70581541733"}
0005433194922	00EE52	8786 880222	VLADIMIR KAZAKOV	{"phone": "+70784852405"}
0005433194923	0074B9	4916 969263	AZAT ZHUKOV	{"email": "zhukovazat-1968@postgrespro.ru", "phone": "+70102264888"}
0005433194924	0074B9	0350 717179	EKATERINA AKIMOVA	{"phone": "+70196128057"}
0005433194925	A757CE	4562 252132	VASILIY TARASOV	{"phone": "+70670357068"}
0005433194926	5B745B	8855 573305	VARVARA AFANASEVA	{"phone": "+70353929400"}
0005433194927	05699B	1402 410417	VIKTORIYA NAZAROVA	{"email": "viktoriya.nazarova.081964@postgrespro.ru", "phone": "+70374086670"}
0005433194928	E5B1EA	6480 439777	NINA VLASOVA	{"email": "nina_vlasova-081981@postgrespro.ru", "phone": "+70150432289"}
0005433194929	A6A7D5	1980 358760	ALEKSANDR KOZLOV	{"phone": "+70230748418"}
0005433194930	A6A7D5	5467 127834	ALEKSANDR NIKOLAEV	{"phone": "+70638894436"}
0005433194931	D9385B	4628 419538	LIDIYA NIKITINA	{"email": "nikitinal05051963@postgrespro.ru", "phone": "+70182528821"}
0005433194932	0064E3	1922 800854	SERGEY PETROV	{"email": "s-petrov091970@postgrespro.ru", "phone": "+70260892989"}
0005433194933	265281	6116 304635	VIKTOR SAVELEV	{"phone": "+70979626564"}
0005433194934	265281	8848 873485	NATALIYA ARKHIPOVA	{"email": "arkhipovan1970@postgrespro.ru", "phone": "+70999415304"}
0005433194935	F61F66	3219 919737	OLEG MOROZOV	{"phone": "+70612947283"}
0005433194936	6D7FBD	0792 069533	OLGA LAZAREVA	{"email": "lazareva_olga-071971@postgrespro.ru", "phone": "+70198133316"}
0005433194937	6D7FBD	9626 744499	IRINA MIKHAYLOVA	{"email": "i.mikhaylova-1977@postgrespro.ru", "phone": "+70829491776"}
0005433194938	6D7FBD	4206 235314	MARINA VOROBEVA	{"phone": "+70204671455"}
0005433194939	6D7FBD	4781 054503	YULIYA DENISOVA	{"email": "denisova_yuliya.1969@postgrespro.ru", "phone": "+70847155483"}
0005433194940	9B33FC	6620 725008	DENIS KRASNOV	{"email": "d-krasnov-1974@postgrespro.ru", "phone": "+70575153805"}
0005433194941	241AF9	1032 848632	SERGEY MOISEEV	{"phone": "+70473261575"}
0005433194942	241AF9	6075 584998	DMITRIY KAZAKOV	{"phone": "+70281077493"}
0005433194943	14779F	7600 501349	TATYANA ORLOVA	{"email": "t_orlova-081969@postgrespro.ru", "phone": "+70332845977"}
0005433194944	14779F	3881 947463	ANDREY AFANASEV	{"phone": "+70425533516"}
0005433194945	4E7374	0621 355107	LYUBOV NIKOLAEVA	{"email": "lyubov.nikolaeva08071966@postgrespro.ru", "phone": "+70944730371"}
0005433194946	4E7374	5102 619919	MAKSIM SHEVCHENKO	{"phone": "+70648295137"}
0005433194947	43E9FA	2183 380678	EGOR IVANOV	{"phone": "+70118614370"}
0005433194948	43E9FA	5663 568494	VADIM NAZAROV	{"email": "vadim.nazarov25041975@postgrespro.ru", "phone": "+70378556357"}
0005433194949	74529A	8380 383058	OLGA FILIPPOVA	{"email": "filippova.olga1974@postgrespro.ru", "phone": "+70170743063"}
0005433194950	CE6B00	9999 443424	LYUBOV KOMAROVA	{"email": "lkomarova.1961@postgrespro.ru", "phone": "+70985660489"}
0005433194951	2C7C24	1970 566913	EVGENIYA ERMAKOVA	{"email": "evgeniyaermakova-1971@postgrespro.ru", "phone": "+70492985543"}
0005433194952	EECA49	9982 673308	IVAN DENISOV	{"phone": "+70673919165"}
0005433194953	F40E01	9894 530878	IRINA SEMENOVA	{"email": "irinasemenova_1962@postgrespro.ru", "phone": "+70417681857"}
0005433194954	3FF292	5096 093226	GALINA ZAKHAROVA	{"phone": "+70700472165"}
0005433194955	CD3343	0337 344169	TAISIYA LOGINOVA	{"phone": "+70818564394"}
0005433194956	B7FB2C	0761 503793	SERGEY ALEKSEEV	{"phone": "+70337478910"}
0005433194957	B7FB2C	0328 763182	VLADIMIR VASILEV	{"phone": "+70837838541"}
0005433194958	AA4513	3192 980553	MARINA IVANOVA	{"phone": "+70163574612"}
0005433194959	ADE9EB	6338 289631	NIKOLAY PETROV	{"email": "nikolay_petrov_24091971@postgrespro.ru", "phone": "+70219955269"}
0005433194960	4D974A	1748 032188	ALEKSEY NAUMOV	{"phone": "+70720014143"}
0005433194961	ABA790	2313 772167	YURIY MATVEEV	{"phone": "+70091626198"}
0005433194962	5CC297	8509 090260	DARYA GRISHINA	{"phone": "+70849753269"}
0005433194963	362EB2	4281 431414	MARIYA MEDVEDEVA	{"email": "medvedevamariya-06011973@postgrespro.ru", "phone": "+70238995524"}
0005433194964	3AF2BB	0324 134223	IVAN MOROZOV	{"phone": "+70707080778"}
0005433194965	3AF2BB	8744 285354	ILYA NAZAROV	{"email": "nazarov-ilya-16071976@postgrespro.ru", "phone": "+70850921272"}
0005433194966	C4F9B0	8409 700680	ANNA PETROVA	{"phone": "+70655112759"}
0005433194967	28DBD1	6035 065179	SERGEY SIDOROV	{"email": "sidorov-sergey_031979@postgrespro.ru", "phone": "+70197326396"}
0005433194968	EAF1C2	9333 791693	ANDREY GUSEV	{"phone": "+70284913243"}
0005433194969	EAF1C2	3027 202486	ALEKSANDR ZHUKOV	{"phone": "+70464642190"}
0005433194970	38A1BA	7810 395884	VIKTORIYA KUDRYASHOVA	{"phone": "+70978733511"}
0005433194971	95341E	1296 288077	OLGA FEDOROVA	{"email": "fedorovaolga-1976@postgrespro.ru", "phone": "+70351464107"}
0005433194972	64D114	9459 752378	SVETLANA FROLOVA	{"email": "frolova.s-1970@postgrespro.ru", "phone": "+70400887782"}
0005433194973	A3497D	9947 937258	EKATERINA ZAKHAROVA	{"phone": "+70808593635"}
0005433194974	6636BF	3775 700699	TATYANA SERGEEVA	{"email": "sergeeva_t.071984@postgrespro.ru", "phone": "+70972836379"}
0005433194975	6E9615	8592 416342	PAVEL KAZAKOV	{"phone": "+70564577541"}
0005433194976	0C267C	5826 054122	OLGA SAVELEVA	{"phone": "+70609356434"}
0005433194977	FDBA92	3767 297191	GALINA FROLOVA	{"email": "frolova-galina.13061970@postgrespro.ru", "phone": "+70850833452"}
0005433194978	FDBA92	5690 427381	YURIY MOROZOV	{"phone": "+70086791705"}
0005433194979	91DC48	8664 094573	YULIYA RODIONOVA	{"email": "rodionova_y.21121970@postgrespro.ru", "phone": "+70365485990"}
0005433194980	91DC48	6728 190086	ELENA ROMANOVA	{"phone": "+70511297650"}
0005433194981	4D4C52	7109 901590	TATYANA BORISOVA	{"email": "tborisova031962@postgrespro.ru", "phone": "+70564495830"}
0005433194982	4D4C52	5695 821917	ANATOLIY STEPANOV	{"phone": "+70136671841"}
0005433194983	66A9B9	8154 349454	LIDIYA VASILEVA	{"phone": "+70645911687"}
0005433194984	91D932	8477 685978	YANA KONDRATEVA	{"phone": "+70324824505"}
0005433194985	91D932	5906 974917	ILYA KUZNECOV	{"email": "kuznecovilya_031968@postgrespro.ru", "phone": "+70403277995"}
0005433194986	E4C66E	2088 787967	OLEG MEDVEDEV	{"phone": "+70725954722"}
0005433194987	F4537B	3171 200051	VERONIKA SEMENOVA	{"email": "semenova_v-1974@postgrespro.ru", "phone": "+70447020863"}
0005433194988	F4537B	5562 805522	SABINA SMIRNOVA	{"email": "s-smirnova.091976@postgrespro.ru", "phone": "+70235335108"}
0005433194989	FFAF4D	9229 551956	MARINA DANILOVA	{"phone": "+70237774128"}
0005433194990	FFAF4D	4362 987834	ANTON ANTONOV	{"email": "a.antonov031972@postgrespro.ru", "phone": "+70234177878"}
0005433194991	D7F918	7792 526455	LIDIYA ILINA	{"email": "l-ilina-111973@postgrespro.ru", "phone": "+70307497266"}
0005433194992	966B9E	6979 166605	TATYANA MEDVEDEVA	{"phone": "+70731834768"}
0005433194993	739042	2632 126368	SERGEY IVANOV	{"phone": "+70968000093"}
0005433194994	FC5AFC	4078 384922	YURIY IVANOV	{"email": "ivanov_y28021977@postgrespro.ru", "phone": "+70840465709"}
0005433194995	38B877	0226 736998	NIKOLAY PETROV	{"phone": "+70020260111"}
0005433194996	23E40F	4566 217823	VLADIMIR IVANOV	{"phone": "+70256122071"}
0005433194997	3420D3	2916 226397	DANILA KRASNOV	{"email": "danilakrasnov1966@postgrespro.ru", "phone": "+70557814765"}
0005433194998	3420D3	6773 135517	EVGENIY KUZNECOV	{"email": "kuznecov.e-28061977@postgrespro.ru", "phone": "+70163638990"}
0005433194999	DEC9F9	3817 719948	NATALYA TIMOFEEVA	{"phone": "+70960607577"}
0005433195000	03C548	9112 802767	ANDREY FEDOROV	{"email": "fedorova_28011972@postgrespro.ru", "phone": "+70883921870"}
0005433195001	03C548	9344 053636	ALENA IVANOVA	{"phone": "+70993086960"}
0005433195002	49BDFB	9852 098010	NATALYA AKIMOVA	{"phone": "+70704255295"}
0005433195003	49BDFB	2349 501976	VALENTINA GAVRILOVA	{"phone": "+70698667118"}
0005433195004	AAD3E2	5214 268807	ANTONINA LEBEDEVA	{"email": "antonina_lebedeva-031967@postgrespro.ru", "phone": "+70332086055"}
0005433195005	3C3883	1913 671937	NINA KOLESNIKOVA	{"phone": "+70492564676"}
0005433195006	3C3883	9281 809323	VLADIMIR MAKAROV	{"email": "makarovvladimir-071970@postgrespro.ru", "phone": "+70447375061"}
0005433195007	0A72DE	7638 466701	ALEVTINA ORLOVA	{"phone": "+70302264588"}
0005433195008	C14F3B	3678 651680	VALENTINA POPOVA	{"email": "popovavalentina-12041973@postgrespro.ru", "phone": "+70916285964"}
0005433195009	C14F3B	1373 298172	LARISA MALYSHEVA	{"phone": "+70004693890"}
0005433195010	BA85BB	1185 064764	INNA FADEEVA	{"phone": "+70894784307"}
0005433195011	182A4A	4811 636870	VITALIY BONDARENKO	{"email": "bondarenkovitaliy-1965@postgrespro.ru", "phone": "+70900022850"}
0005433195012	50F30F	0902 770648	LYUDMILA LAZAREVA	{"phone": "+70296383945"}
0005433195013	50F30F	2996 782879	KIRILL PETROV	{"phone": "+70207645612"}
0005433195014	50F30F	8856 758247	ZAKHAR DMITRIEV	{"email": "dmitriev.zakhar.061966@postgrespro.ru", "phone": "+70808724432"}
0005433195015	C16461	8320 096098	ALENA FEDOROVA	{"phone": "+70330274123"}
0005433195016	5387BD	2940 267564	VYACHESLAV RODIONOV	{"phone": "+70656245684"}
0005433195017	8DBD07	7803 977435	ANDREY ZAKHAROV	{"phone": "+70600129067"}
0005433202102	D50BE6	5704 948966	ALENA PAVLOVA	{"phone": "+70703412866"}
0005433202103	690AA7	0215 578905	ELENA DAVYDOVA	{"phone": "+70253677455"}
0005433202104	A3D09A	8233 128482	EKATERINA KUZMINA	{"phone": "+70260804088"}
0005433202105	A3D09A	7232 797571	FEDOR KOZLOV	{"email": "kozlov_f021969@postgrespro.ru", "phone": "+70926482977"}
0005433202106	BEA082	3340 428167	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov_031986@postgrespro.ru", "phone": "+70347160791"}
0005433202107	BEA082	2060 697490	OLEG OSIPOV	{"email": "osipov-o.021966@postgrespro.ru", "phone": "+70410677014"}
0005433202108	6356B5	4816 700724	ALISA ANDREEVA	{"email": "andreeva.a_1966@postgrespro.ru", "phone": "+70363976384"}
0005433202109	A51454	8709 619926	TATYANA BOGDANOVA	{"phone": "+70501584581"}
0005433202110	2A0363	5238 830640	RAISA OSIPOVA	{"email": "osipova.r091959@postgrespro.ru", "phone": "+70064992566"}
0005433202111	2A0363	2876 963581	TATYANA ABRAMOVA	{"email": "t_abramova071978@postgrespro.ru", "phone": "+70793790541"}
0005433202112	0D7648	1576 155034	ARTEM ILIN	{"email": "ilin-a-081984@postgrespro.ru", "phone": "+70287693525"}
0005433202113	DEE401	9801 865680	ANNA SOKOLOVA	{"phone": "+70573067163"}
0005433202114	E962B0	5397 485953	LYUBOV MEDVEDEVA	{"email": "lyubovmedvedeva1969@postgrespro.ru", "phone": "+70691348497"}
0005433202115	1B6E98	9544 346252	PAVEL MAKSIMOV	{"email": "pmaksimov051960@postgrespro.ru", "phone": "+70107620027"}
0005433202116	3506B1	8957 919275	TATYANA ANDREEVA	{"email": "tatyanaandreeva16021967@postgrespro.ru", "phone": "+70376565828"}
0005433202117	44B885	3070 556456	EKATERINA DENISOVA	{"phone": "+70606028326"}
0005433202118	44B885	0451 765138	VLADISLAV STEPANOV	{"email": "stepanovv1965@postgrespro.ru", "phone": "+70660265917"}
0005433202119	E5B829	0508 214936	IRINA SIDOROVA	{"email": "i.sidorova.1977@postgrespro.ru", "phone": "+70669647722"}
0005433202120	2FEA81	9046 292229	ELENA LUKYANOVA	{"phone": "+70309281243"}
0005433202121	2FEA81	6235 977194	IVAN IVANOV	{"phone": "+70428175854"}
0005433202122	3035E8	2844 332011	PETR SMIRNOV	{"email": "smirnovp-051972@postgrespro.ru", "phone": "+70222783530"}
0005433202123	8357BB	9675 865904	ELVIRA PAVLOVA	{"email": "pavlova.elvira-1965@postgrespro.ru", "phone": "+70144949202"}
0005433202124	79AFBB	4727 089773	TATYANA LUKYANOVA	{"email": "lukyanova.t10081971@postgrespro.ru", "phone": "+70572631049"}
0005433202125	23D00B	4813 508617	LYUBOV SIDOROVA	{"phone": "+70212736097"}
0005433202126	23D00B	0524 316173	KLAVDIYA OSIPOVA	{"phone": "+70052711752"}
0005433202127	08F9AD	9925 033649	DMITRIY ABRAMOV	{"phone": "+70824395059"}
0005433202128	08F9AD	1102 947733	VADIM NIKITIN	{"phone": "+70946073129"}
0005433202129	196D30	5633 350352	ALEKSANDR MAKSIMOV	{"phone": "+70290152165"}
0005433202130	30A14E	5606 927596	KIRILL BONDARENKO	{"email": "k-bondarenko.031972@postgrespro.ru", "phone": "+70939611343"}
0005433202131	30A14E	9411 893358	ELENA IVANOVA	{"phone": "+70607009511"}
0005433202132	30A14E	8940 859756	SERGEY IVANOV	{"email": "ivanov.sergey061972@postgrespro.ru", "phone": "+70899629534"}
0005433202133	E63B7B	0694 285249	NADEZHDA MARTYNOVA	{"phone": "+70308688300"}
0005433202134	BF7EF5	4704 584064	NATALYA NESTEROVA	{"email": "natalya-nesterova-20041975@postgrespro.ru", "phone": "+70821183911"}
0005433202135	DF3968	4236 646006	OLGA OSIPOVA	{"email": "o.osipova_1963@postgrespro.ru", "phone": "+70437780565"}
0005433202136	98CCFB	3412 117013	ELENA DANILOVA	{"email": "danilovaelena.04091964@postgrespro.ru", "phone": "+70647297734"}
0005433202137	70F568	2897 908811	MARINA TARASOVA	{"phone": "+70487669251"}
0005433202138	70F568	6593 066662	LYUDMILA MOISEEVA	{"phone": "+70601197314"}
0005433202139	1D19AA	7493 246675	EDUARD ZAYCEV	{"phone": "+70378695610"}
0005433202140	1D19AA	6557 524337	ELENA SMIRNOVA	{"email": "elena-smirnova-1975@postgrespro.ru", "phone": "+70112219710"}
0005433202141	1BA6D8	1490 102515	MIKHAIL KUZNECOV	{"phone": "+70272009102"}
0005433202142	1BA6D8	9877 496517	NADEZHDA FROLOVA	{"email": "frolova.nadezhda_17071977@postgrespro.ru", "phone": "+70158438028"}
0005433202143	55CD8F	9964 073119	ROZALIYA KUZNECOVA	{"phone": "+70514220013"}
0005433202144	2AC25E	1682 653012	MARINA MOROZOVA	{"email": "morozovam011974@postgrespro.ru", "phone": "+70924820776"}
0005433202145	2AC25E	4067 935021	OLEG PETROV	{"email": "opetrov-1959@postgrespro.ru", "phone": "+70512877588"}
0005433202146	05F6DD	8532 318121	MILENA BARANOVA	{"phone": "+70681907397"}
0005433202147	EFB226	0581 280376	SERGEY FOMIN	{"phone": "+70776354756"}
0005433202148	EFB226	6626 390513	EVGENIY ZAKHAROV	{"phone": "+70527484883"}
0005433202149	174CC2	4832 043323	OKSANA IVANOVA	{"phone": "+70594419398"}
0005433202150	174CC2	2395 283702	TATYANA VLASOVA	{"phone": "+70499585470"}
0005433202151	B0299E	9297 533231	MIKHAIL ALEKSEEV	{"email": "malekseev.1968@postgrespro.ru", "phone": "+70500971087"}
0005433202152	B0299E	9825 955957	GALINA KRASNOVA	{"phone": "+70669054994"}
0005433202153	E7D0D4	2269 230902	PETR EGOROV	{"phone": "+70699164841"}
0005433202154	CE7010	4816 359431	MAKSIM KUZMIN	{"email": "kuzmin-maksim-1974@postgrespro.ru", "phone": "+70535258733"}
0005433202155	CE7010	1300 298523	VERA KUZNECOVA	{"email": "vkuznecova.081970@postgrespro.ru", "phone": "+70612433808"}
0005433202156	9BEF84	2185 365982	LYUDMILA SOROKINA	{"email": "lsorokina_18031983@postgrespro.ru", "phone": "+70044211249"}
0005433202157	54CF4B	6672 950055	NATALYA NIKITINA	{"phone": "+70636983909"}
0005433202158	AA0ABC	8809 223185	ALENA ABRAMOVA	{"email": "abramovaalena_19101974@postgrespro.ru", "phone": "+70625082766"}
0005433202159	D09A51	1674 793162	ANDREY DMITRIEV	{"phone": "+70118200852"}
0005433202160	D09A51	6186 483776	SVETLANA SAVELEVA	{"email": "svetlana.saveleva051967@postgrespro.ru", "phone": "+70090351294"}
0005433202161	B50C34	3477 308337	VALENTINA ANDREEVA	{"email": "v-andreeva031974@postgrespro.ru", "phone": "+70914911291"}
0005433202162	B50C34	6009 277468	VIKTORIYA POLYAKOVA	{"email": "polyakova.viktoriya021978@postgrespro.ru", "phone": "+70098280202"}
0005433202163	60D573	0653 482537	ELENA CHERNOVA	{"email": "chernova-elena111965@postgrespro.ru", "phone": "+70138395554"}
0005433202164	81984B	9711 012300	ALESYA LUKYANOVA	{"email": "alesyalukyanova_081967@postgrespro.ru", "phone": "+70411109728"}
0005433202165	40CC1D	8823 229330	ALEKSANDR SOLOVEV	{"email": "a_solovev.25031972@postgrespro.ru", "phone": "+70160883262"}
0005433202166	155C91	9337 500314	RAIL KISELEV	{"phone": "+70137755928"}
0005433202167	28119D	1202 188698	VERA KALININA	{"phone": "+70304564182"}
0005433202168	810A24	4919 471358	ALEKSANDR MAKAROV	{"email": "a_makarov_021970@postgrespro.ru", "phone": "+70564046162"}
0005433202169	DA5D19	5999 729215	ANNA NAZAROVA	{"phone": "+70462348158"}
0005433202170	850532	4432 257125	VLADIMIR AFANASEV	{"email": "afanasev-v13081964@postgrespro.ru", "phone": "+70664433374"}
0005433202171	932A2E	8429 682634	OLEG ZAKHAROV	{"phone": "+70369381416"}
0005433202172	E9AA2C	9130 216002	ALEKSANDR PETROV	{"email": "petrov.a.07041969@postgrespro.ru", "phone": "+70235965171"}
0005433202173	E7706D	6438 067815	ALEKSANDR MOROZOV	{"phone": "+70258594554"}
0005433202174	D10E2C	2593 312623	LIDIYA POTAPOVA	{"email": "lidiyapotapova_1974@postgrespro.ru", "phone": "+70606731570"}
0005433202175	EEE941	6642 751270	VALERIY SEMENOV	{"phone": "+70785228487"}
0005433202176	91197F	5010 627064	AMINA OVCHINNIKOVA	{"phone": "+70484781307"}
0005433202177	4B450E	0922 331846	OLGA DENISOVA	{"email": "denisova-olga1973@postgrespro.ru", "phone": "+70090084324"}
0005433202178	4B450E	0588 116983	OKSANA YUDINA	{"email": "yudina.oksana121968@postgrespro.ru", "phone": "+70045342330"}
0005433202179	691403	2128 168588	NADEZHDA MAKAROVA	{"phone": "+70115251268"}
0005433202180	691403	1049 205993	IVAN YAKOVLEV	{"phone": "+70162302988"}
0005433202181	F76515	9854 683218	VIKTORIYA KISELEVA	{"phone": "+70037469390"}
0005433202182	B89DB4	5964 905186	VALENTINA GORBUNOVA	{"email": "v_gorbunova.30101981@postgrespro.ru", "phone": "+70529479623"}
0005433202183	C3CAD4	2381 650972	ANATOLIY GERASIMOV	{"email": "anatoliy_gerasimov-11071972@postgrespro.ru", "phone": "+70907731029"}
0005433202184	A9753E	9240 334277	SVETLANA TITOVA	{"email": "titova_s-25011965@postgrespro.ru", "phone": "+70253161256"}
0005433202185	A9753E	9902 192710	NARIMAN KISELEV	{"phone": "+70959055222"}
0005433202186	7BACCA	0962 164226	VALENTINA SOKOLOVA	{"phone": "+70850150044"}
0005433202187	C9298B	5846 142080	REGINA SMIRNOVA	{"phone": "+70377462429"}
0005433202188	C9298B	3565 421549	ELENA ILINA	{"phone": "+70438390774"}
0005433202189	B1B42B	2088 643274	VLADIMIR MOISEEV	{"email": "moiseev.vladimir_1974@postgrespro.ru", "phone": "+70908462486"}
0005433202190	C46B8C	9936 114218	ALENA ZOTOVA	{"email": "a-zotova-1974@postgrespro.ru", "phone": "+70663633694"}
0005433202191	58D908	6066 828409	PAVEL SEMENOV	{"email": "psemenov_121979@postgrespro.ru", "phone": "+70611887352"}
0005433202192	1F4E99	8279 925239	SERGEY MELNIKOV	{"email": "s_melnikov-1980@postgrespro.ru", "phone": "+70934745642"}
0005433202193	1F4E99	6942 999930	RODION SOROKIN	{"phone": "+70396377233"}
0005433202194	243923	4517 597542	RUSTAM VLASOV	{"email": "r-vlasov_06041971@postgrespro.ru", "phone": "+70776500757"}
0005433202195	6E1554	4311 467739	MARIYA MOISEEVA	{"email": "mariya.moiseeva-26031977@postgrespro.ru", "phone": "+70830276675"}
0005433202196	54A07D	4486 321090	LYUDMILA PAVLOVA	{"phone": "+70850171087"}
0005433202197	54A07D	4793 393880	ILDAR STEPANOV	{"phone": "+70362506139"}
0005433202198	523786	2730 406520	SERGEY ZHURAVLEV	{"email": "zhuravlev-sergey_121966@postgrespro.ru", "phone": "+70246690618"}
0005433202199	66F798	0588 835812	DMITRIY FROLOV	{"phone": "+70052917544"}
0005433202200	66F798	0356 887368	ROMAN MIKHAYLOV	{"phone": "+70261297537"}
0005433202201	B9C1F6	9812 635052	ALEKSEY KOZLOV	{"phone": "+70153681521"}
0005433202202	0A5FFF	3216 290789	DENIS CHERNOV	{"email": "denis.chernov-1969@postgrespro.ru", "phone": "+70953156263"}
0005433202203	E01504	7462 714252	ALEKSANDRA GAVRILOVA	{"email": "a_gavrilova23071988@postgrespro.ru", "phone": "+70178761448"}
0005433202204	E01504	7111 747944	NIKOLAY DMITRIEV	{"phone": "+70426143248"}
0005433202205	E01504	5463 964440	ALEKSANDR DMITRIEV	{"phone": "+70932630851"}
0005433202206	8B77F2	7232 938627	MARIYA PAVLOVA	{"email": "pavlova_mariya.15031976@postgrespro.ru", "phone": "+70981341807"}
0005433202207	611835	6182 899041	ELENA SAVELEVA	{"email": "esaveleva-10121971@postgrespro.ru", "phone": "+70116184717"}
0005433202208	58534B	1573 502078	VLADIMIR FEDOTOV	{"email": "fedotovv.111975@postgrespro.ru", "phone": "+70777435016"}
0005433202209	FE922E	2656 470037	IVAN STEPANOV	{"email": "stepanov.i.1970@postgrespro.ru", "phone": "+70855416651"}
0005433202210	F06584	4723 632137	TATYANA FROLOVA	{"phone": "+70477712715"}
0005433202211	DDE2D3	7729 418832	NATALYA KOMAROVA	{"phone": "+70919878559"}
0005433202212	DDE2D3	2201 665821	ALEKSEY ANDREEV	{"email": "a_andreev1967@postgrespro.ru", "phone": "+70395017108"}
0005433202213	DDE2D3	2461 773687	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva_1966@postgrespro.ru", "phone": "+70764612353"}
0005433202214	6D397E	6407 337595	MARIYA LUKYANOVA	{"email": "lukyanova-m.041976@postgrespro.ru", "phone": "+70119868498"}
0005433202215	8F8341	4798 541558	MARIYA TITOVA	{"email": "titovam16011967@postgrespro.ru", "phone": "+70293630065"}
0005433202216	89808F	1493 067931	LIDIYA KOLESNIKOVA	{"email": "lidiya_kolesnikova_111975@postgrespro.ru", "phone": "+70424246919"}
0005433202217	5E370D	2472 927155	ALINA MAKAROVA	{"email": "alina_makarova_30101973@postgrespro.ru", "phone": "+70444320663"}
0005433202218	5E370D	8702 460469	ELENA ILINA	{"phone": "+70313254843"}
0005433202219	83AFB5	7339 378663	TATYANA ILINA	{"email": "tilina.1980@postgrespro.ru", "phone": "+70946428384"}
0005433202220	83AFB5	5955 120089	TATYANA FILIPPOVA	{"phone": "+70975707843"}
0005433202221	83AFB5	1541 421022	ALEKSANDR PETROV	{"phone": "+70185439126"}
0005433202222	1A50BA	5756 165557	MARINA SMIRNOVA	{"phone": "+70959525316"}
0005433202223	326F80	8820 119884	VALENTINA MATVEEVA	{"phone": "+70526944184"}
0005433202224	0CCA04	6163 291645	POLINA OVCHINNIKOVA	{"email": "polina.ovchinnikova1974@postgrespro.ru", "phone": "+70133337961"}
0005433202225	F0724E	7927 064042	NINA MAKSIMOVA	{"email": "n_maksimova.1971@postgrespro.ru", "phone": "+70997797571"}
0005433202226	8CA7CD	8169 557968	DENIS CHERNOV	{"email": "chernov.d091983@postgrespro.ru", "phone": "+70943949428"}
0005433202227	9F44D7	8036 539736	TATYANA KONDRATEVA	{"email": "kondrateva_t-061970@postgrespro.ru", "phone": "+70749814446"}
0005433202228	87CA39	1678 267409	NIKITA KOZLOV	{"email": "nikita_kozlov-101974@postgrespro.ru", "phone": "+70451529568"}
0005433202229	0A6F46	2044 937242	VALENTINA DANILOVA	{"email": "valentina.danilova-06051964@postgrespro.ru", "phone": "+70134971814"}
0005433202230	5CC15D	9959 300968	PRASKOVYA FROLOVA	{"email": "frolova-p1983@postgrespro.ru", "phone": "+70592034470"}
0005433202231	2913A3	4067 795923	IVAN KOROLEV	{"email": "korolevi_031967@postgrespro.ru", "phone": "+70554474771"}
0005433202232	5FA96B	8443 103036	MIKHAIL ALEKSEEV	{"email": "alekseev-m.071960@postgrespro.ru", "phone": "+70044414203"}
0005433202233	2C0341	4967 839523	VALENTINA YUDINA	{"phone": "+70432968817"}
0005433202234	13CA0A	5995 283984	MATVEY STEPANOV	{"phone": "+70447808657"}
0005433202235	CC58BC	0262 592593	ALEKSANDR DENISOV	{"email": "a-denisov06021963@postgrespro.ru", "phone": "+70945495071"}
0005433202236	5DE39F	0279 492793	MIKHAIL POPOV	{"email": "mikhail.popov.26111965@postgrespro.ru", "phone": "+70850845793"}
0005433202237	009B09	9535 006649	SERGEY OSIPOV	{"phone": "+70987677644"}
0005433202238	009B09	0404 313510	KRISTINA IVANOVA	{"phone": "+70541048485"}
0005433202239	ABEFB9	5979 726851	ALEKSANDR BORISOV	{"phone": "+70796405862"}
0005433202240	6E69A3	3522 834143	ALEKSEY TIKHONOV	{"email": "tikhonov-a.1974@postgrespro.ru", "phone": "+70476887576"}
0005433202241	B954FC	6359 613118	ALEKSEY SMIRNOV	{"phone": "+70953775221"}
0005433202242	354C09	3933 490453	ILYA FEDOTOV	{"email": "fedotovilya24111965@postgrespro.ru", "phone": "+70785220438"}
0005433202243	354C09	2216 961611	ALEKSANDR SOKOLOV	{"email": "sokolov-a30081987@postgrespro.ru", "phone": "+70180863703"}
0005433202244	69BD7A	8963 508421	ANNA GRISHINA	{"email": "grishina-a.1960@postgrespro.ru", "phone": "+70547739616"}
0005433202245	47D9F7	5990 918066	ZINAIDA TIKHONOVA	{"email": "zinaida_tikhonova.051972@postgrespro.ru", "phone": "+70390770107"}
0005433202246	752258	3421 727163	ALEKSANDRA EGOROVA	{"phone": "+70001558276"}
0005433202247	0770B8	4075 708393	NIKOLAY PAVLOV	{"email": "n.pavlov_061971@postgrespro.ru", "phone": "+70208745444"}
0005433202248	172B15	6961 573846	ELENA ROMANOVA	{"email": "romanova_e-17071966@postgrespro.ru", "phone": "+70417387451"}
0005433202249	9C7AB2	7711 664525	VASILIY KUZNECOV	{"email": "v-kuznecov.1969@postgrespro.ru", "phone": "+70563149998"}
0005433202250	9C7AB2	8236 261709	VALERIY BARANOV	{"email": "v-baranov_1970@postgrespro.ru", "phone": "+70567836730"}
0005433202251	9C7AB2	6251 695951	ANDREY KRASNOV	{"phone": "+70921450380"}
0005433202252	284F41	7801 709448	ELENA KAZAKOVA	{"phone": "+70627890458"}
0005433202253	1B2B9C	0718 719921	ALEKSANDR DENISOV	{"email": "aleksandr_denisov-1973@postgrespro.ru", "phone": "+70309961295"}
0005433202254	840F54	3063 633704	DARYA ANISIMOVA	{"phone": "+70187447733"}
0005433202255	840F54	5007 417161	EKATERINA IVANOVA	{"email": "ivanova.ekaterina_1970@postgrespro.ru", "phone": "+70800648266"}
0005433202256	840F54	2364 442033	MARIYA YUDINA	{"phone": "+70696747714"}
0005433202257	8C6316	5968 763400	NIKITA ORLOV	{"phone": "+70342677601"}
0005433202258	9AD4B3	0465 937643	LYUDMILA POPOVA	{"phone": "+70936625344"}
0005433202259	4A8B9C	5208 428152	SERGEY ALEKSANDROV	{"phone": "+70440693148"}
0005433202260	5DBAB3	6007 760841	ZINAIDA ABRAMOVA	{"phone": "+70165116705"}
0005433202261	8B11BA	5041 723852	LEONID VASILEV	{"email": "vasilevleonid-081972@postgrespro.ru", "phone": "+70670285281"}
0005433202262	4B6AA5	7327 811198	LYUBOV MELNIKOVA	{"phone": "+70474187914"}
0005433202263	4B6AA5	3576 481364	ANNA ZHUKOVA	{"email": "zhukova_anna.12021975@postgrespro.ru", "phone": "+70632764900"}
0005433202264	574934	0738 427048	ANNA FILATOVA	{"email": "filatova_anna-25081962@postgrespro.ru", "phone": "+70079405431"}
0005433202265	574934	4144 752782	GALINA KUDRYASHOVA	{"phone": "+70392763046"}
0005433202266	574934	1914 588414	ILDAR SOKOLOV	{"email": "ildar.sokolov13021979@postgrespro.ru", "phone": "+70422328106"}
0005433202267	CC5D4C	0256 844475	ALEKSEY OSIPOV	{"phone": "+70719971813"}
0005433202268	51C5E8	1313 410972	ANDREY IVANOV	{"email": "ivanov.a.071975@postgrespro.ru", "phone": "+70669464013"}
0005433202269	5B18C8	3874 964408	ILYA KUZMIN	{"email": "kuzmin.ilya18011977@postgrespro.ru", "phone": "+70551902285"}
0005433202270	5B18C8	0072 670553	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov_111974@postgrespro.ru", "phone": "+70671140802"}
0005433202271	91945A	7533 642871	NIKITA SERGEEV	{"phone": "+70257643902"}
0005433202272	91945A	9745 604437	IVAN MOISEEV	{"phone": "+70874007554"}
0005433202273	2BEEEB	8489 785291	MARIYA KUZNECOVA	{"email": "kuznecova_mariya_1977@postgrespro.ru", "phone": "+70234256404"}
0005433202274	54E24F	2294 887604	YULIYA BARANOVA	{"email": "baranova-yuliya.04101969@postgrespro.ru", "phone": "+70160505448"}
0005433202275	963F8E	8243 449471	VLADIMIR DMITRIEV	{"phone": "+70609770965"}
0005433202276	7EC825	0436 346269	MARIYA DAVYDOVA	{"email": "davydova-mariya.21041976@postgrespro.ru", "phone": "+70902385264"}
0005433202277	7EC825	8210 174740	RAUZA TROFIMOVA	{"email": "rauzatrofimova04091982@postgrespro.ru", "phone": "+70522478109"}
0005433202278	088677	7194 654622	GENNADIY SOLOVEV	{"email": "solovev.g.101966@postgrespro.ru", "phone": "+70177284190"}
0005433202279	088677	9960 799061	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova_1967@postgrespro.ru", "phone": "+70064901809"}
0005433202280	C78914	0607 699876	NIKOLAY OSIPOV	{"email": "nosipov.1960@postgrespro.ru", "phone": "+70564010615"}
0005433202281	17F93A	0335 578340	OLEG ALEKSEEV	{"email": "alekseev-oleg_28091965@postgrespro.ru", "phone": "+70584056655"}
0005433202282	8060E7	4316 694472	KARINA IVANOVA	{"email": "ivanova-karina.27121967@postgrespro.ru", "phone": "+70703127341"}
0005433202283	C254AE	0710 461228	IVAN IVANOV	{"email": "ivan.ivanov_1981@postgrespro.ru", "phone": "+70486194855"}
0005433202284	0877DB	3803 535564	MARIYA MALYSHEVA	{"email": "malysheva-m.1980@postgrespro.ru", "phone": "+70103093951"}
0005433202285	6B1420	6786 117440	ANTON AFANASEV	{"phone": "+70532294316"}
0005433202286	75D391	5095 077057	NIKOLAY POPOV	{"email": "nikolay-popov1963@postgrespro.ru", "phone": "+70007832284"}
0005433202287	000E3A	8390 123543	ALEKSANDRA NIKITINA	{"email": "nikitina.a.13121972@postgrespro.ru", "phone": "+70901779961"}
0005433202288	D2C80C	7749 530144	RAIL MOROZOV	{"email": "r.morozov_1967@postgrespro.ru", "phone": "+70645323455"}
0005433202289	4D376D	7145 232673	NIKOLAY ALEKSEEV	{"phone": "+70395861074"}
0005433202290	32C1EB	6850 586120	DENIS IVANOV	{"phone": "+70723765976"}
0005433202291	745E28	7121 457077	PETR SEMENOV	{"email": "semenov-petr-1980@postgrespro.ru", "phone": "+70283902241"}
0005433202292	874759	1810 478198	ANDREY BELOV	{"email": "belova091966@postgrespro.ru", "phone": "+70105628642"}
0005433202293	1673CC	3935 516709	KSENIYA DMITRIEVA	{"phone": "+70540764825"}
0005433202294	D89BE5	3226 459251	MARINA DANILOVA	{"email": "m-danilova.071977@postgrespro.ru", "phone": "+70897947517"}
0005433202295	D59D14	3561 646442	VYACHESLAV IVANOV	{"email": "ivanov.vyacheslav031982@postgrespro.ru", "phone": "+70123819656"}
0005433202296	BA431C	1392 318032	VLADISLAV SMIRNOV	{"phone": "+70344992072"}
0005433202297	BA431C	2951 046532	ROMAN EGOROV	{"phone": "+70463109345"}
0005433202298	9360AB	6330 208315	DMITRIY ZAKHAROV	{"phone": "+70620023771"}
0005433202299	0280D2	8396 058685	YULIYA FOMINA	{"phone": "+70917301549"}
0005433202300	1BF1F9	0151 076077	GALINA TITOVA	{"phone": "+70468072559"}
0005433202301	1BF1F9	7738 491353	OLGA BELOVA	{"phone": "+70100141589"}
0005433202302	E7A606	3788 452159	VALENTINA ZHUKOVA	{"phone": "+70336570204"}
0005433202303	2160FF	4748 178607	EKATERINA STEPANOVA	{"email": "e-stepanova041964@postgrespro.ru", "phone": "+70169552652"}
0005433202304	76AC7C	5679 520204	EVGENIYA ZHURAVLEVA	{"phone": "+70864537929"}
0005433202305	76AC7C	1991 755442	GALINA FROLOVA	{"email": "g.frolova-17041977@postgrespro.ru", "phone": "+70575693111"}
0005433202306	FD9C26	2897 205439	VLADIMIR RODIONOV	{"email": "rodionovv_1977@postgrespro.ru", "phone": "+70978837670"}
0005433202307	B2B41F	8806 773628	ALEKSANDR KRASNOV	{"phone": "+70575239591"}
0005433202308	D7D4E8	8924 034158	ILYA NIKOLAEV	{"email": "nikolaev.i_1967@postgrespro.ru", "phone": "+70105463156"}
0005433202309	C2D4CC	2025 221585	VYACHESLAV FROLOV	{"email": "frolov-vyacheslav.06101971@postgrespro.ru", "phone": "+70696161456"}
0005433202310	417C1F	6938 498511	SVETLANA ROMANOVA	{"phone": "+70490349456"}
0005433202311	67EA03	9254 100060	ANATOLIY FEDOROV	{"phone": "+70471543766"}
0005433202312	6783CC	3324 930977	IRAIDA MEDVEDEVA	{"phone": "+70570163765"}
0005433202313	AE7215	3810 174753	SERGEY PETROV	{"phone": "+70935252033"}
0005433202314	D264B5	9201 065871	VLADIMIR SEMENOV	{"email": "vladimir-semenov061967@postgrespro.ru", "phone": "+70142567256"}
0005433202315	D264B5	7628 004475	VLADIMIR VOROBEV	{"phone": "+70626877132"}
0005433202316	82E925	1365 910288	NATALYA MAKAROVA	{"email": "natalya_makarova.121972@postgrespro.ru", "phone": "+70999300269"}
0005433202317	82E925	7675 040750	ALEKSANDR MIRONOV	{"email": "a_mironov.1971@postgrespro.ru", "phone": "+70297595308"}
0005433202318	64F836	7573 780186	PAVEL ZAKHAROV	{"phone": "+70642747435"}
0005433202319	64F836	5170 344154	MAKSIM YAKOVLEV	{"email": "yakovlev_m1972@postgrespro.ru", "phone": "+70396056922"}
0005433202320	C57FC6	4569 781393	TATYANA KAZAKOVA	{"phone": "+70010445370"}
0005433202321	C57FC6	4787 656390	ARSENIY GERASIMOV	{"phone": "+70787949123"}
0005433202322	AF6ED7	3371 597334	ELMIRA SIDOROVA	{"phone": "+70947248499"}
0005433202323	622318	7577 297775	LYUBOV OSIPOVA	{"email": "osipoval_1967@postgrespro.ru", "phone": "+70876950925"}
0005433202324	161CB0	7771 608976	VLADIMIR SOROKIN	{"email": "sorokin.v.31031964@postgrespro.ru", "phone": "+70301925327"}
0005433202325	161CB0	0473 400266	LILIYA KOROLEVA	{"phone": "+70649954074"}
0005433202326	A1EFC4	5398 664585	MIKHAIL EGOROV	{"email": "mikhail-egorov1980@postgrespro.ru", "phone": "+70771784817"}
0005433202327	1B941E	1014 506917	NATALYA FILIPPOVA	{"email": "n_filippova041962@postgrespro.ru", "phone": "+70511511128"}
0005433202328	1B941E	0780 011999	NATALIYA NIKIFOROVA	{"email": "nikiforova_nataliya.01101969@postgrespro.ru", "phone": "+70031322229"}
0005433202329	DEC0B6	8084 582069	NADEZHDA SERGEEVA	{"phone": "+70489575262"}
0005433202330	E6AF48	2806 234970	LYUDMILA KOZLOVA	{"phone": "+70865305120"}
0005433202331	E6AF48	8799 819312	ANATOLIY GORBUNOV	{"email": "gorbunov_a_1961@postgrespro.ru", "phone": "+70112920738"}
0005433202332	FB9623	7509 845611	IREK AFANASEV	{"phone": "+70568698146"}
0005433202333	42A7B0	8476 544158	ALEKSANDRA SIDOROVA	{"phone": "+70663787631"}
0005433202334	6E9B49	9027 677055	YULIYA KOZLOVA	{"email": "kozlova-yuliya071977@postgrespro.ru", "phone": "+70392354254"}
0005433202335	AC3187	9502 783616	ANNA KOZLOVA	{"phone": "+70409767106"}
0005433202336	AC3187	1477 887147	MAKSIM IVANOV	{"email": "ivanov-maksim-19071968@postgrespro.ru", "phone": "+70815389253"}
0005433202337	24BC9F	9445 548001	SERGEY OSIPOV	{"email": "osipov.sergey1972@postgrespro.ru", "phone": "+70751136058"}
0005433202338	77AFD8	4713 817176	VALENTINA ZAYCEVA	{"email": "v.zayceva.041976@postgrespro.ru", "phone": "+70898899018"}
0005433202339	554E7D	0264 998312	ALEKSANDR POPOV	{"email": "popov.a_30081961@postgrespro.ru", "phone": "+70056793086"}
0005433202340	D2E22E	2296 903799	DANILA FILIPPOV	{"email": "dfilippov-041976@postgrespro.ru", "phone": "+70439836385"}
0005433202341	D2E22E	5000 652839	ANATOLIY SOROKIN	{"phone": "+70424148047"}
0005433202342	A14169	1953 744815	VIKTOR ZHUKOV	{"email": "zhukov.v-25041975@postgrespro.ru", "phone": "+70403446462"}
0005433202343	F23257	0030 325445	ALEKSEY NOVIKOV	{"email": "aleksey-novikov04101989@postgrespro.ru", "phone": "+70571919260"}
0005433202344	8167E9	2655 085655	VLADIMIR KUZNECOV	{"email": "kuznecov.v1969@postgrespro.ru", "phone": "+70891674795"}
0005433202345	8167E9	5753 552407	EVGENIY GAVRILOV	{"email": "gavrilov_e-1968@postgrespro.ru", "phone": "+70975563482"}
0005433202346	ECB198	4883 344835	ANASTASIYA KULIKOVA	{"phone": "+70436771428"}
0005433202347	470E92	8198 287429	TATYANA NAUMOVA	{"phone": "+70509955787"}
0005433202348	470E92	3594 232423	IRINA NIKOLAEVA	{"email": "nikolaeva.irina_1974@postgrespro.ru", "phone": "+70169713546"}
0005433202349	88C1A7	1361 975019	DANIIL POPOV	{"email": "daniilpopov-15091976@postgrespro.ru", "phone": "+70538578226"}
0005433202350	0F9E3B	7914 200609	EKATERINA NIKOLAEVA	{"phone": "+70846711747"}
0005433202351	0F9E3B	7494 572967	ALEKSEY FOMIN	{"phone": "+70763231972"}
0005433202352	A8985E	5618 991734	NATALYA EFIMOVA	{"phone": "+70140754705"}
0005433202353	152A8D	5672 967186	LYUBOV PETROVA	{"phone": "+70172019731"}
0005433202354	C3C084	4899 404515	YANA KOLESNIKOVA	{"phone": "+70658587513"}
0005433202355	36B79E	9240 177682	NIKITA VASILEV	{"email": "vasilevnikita_08101969@postgrespro.ru", "phone": "+70613449190"}
0005433202356	36B79E	0635 939903	EVGENIYA SOKOLOVA	{"email": "sokolovae.101976@postgrespro.ru", "phone": "+70476622493"}
0005433202357	D5EC99	1870 830574	MARIYA ZAKHAROVA	{"email": "zakharova-mariya08041956@postgrespro.ru", "phone": "+70902023248"}
0005433202358	FCF188	7293 699014	OLGA MALYSHEVA	{"email": "olga_malysheva01111960@postgrespro.ru", "phone": "+70633060803"}
0005433202359	394B41	9466 316766	ELENA MOROZOVA	{"email": "morozova.elena031979@postgrespro.ru", "phone": "+70128048922"}
0005433202360	BE8AC4	1128 764206	ALEKSANDR PAVLOV	{"phone": "+70036342175"}
0005433202361	BE8AC4	5187 199600	RAISA KOROLEVA	{"phone": "+70910401960"}
0005433202362	1B8606	4865 949728	NIKITA STEPANOV	{"email": "stepanovn_07121981@postgrespro.ru", "phone": "+70375365500"}
0005433202363	1B8606	5988 145005	NIKOLAY TIKHONOV	{"phone": "+70880063422"}
0005433202364	1B8606	3072 488105	ANDREY KUZNECOV	{"phone": "+70952320217"}
0005433202365	C8139F	5031 424920	ELIZAVETA IVANOVA	{"email": "elizaveta-ivanova_051974@postgrespro.ru", "phone": "+70840883998"}
0005433202366	452925	7943 549222	VALENTINA ALEKSEEVA	{"email": "valentinaalekseeva_14011975@postgrespro.ru", "phone": "+70809786994"}
0005433202367	808FE6	5486 701157	NATALYA FILIPPOVA	{"email": "filippova-n.1972@postgrespro.ru", "phone": "+70196560304"}
0005433202368	2DF374	5281 395990	DMITRIY SOROKIN	{"phone": "+70404337578"}
0005433202369	2DF374	0102 376477	IVAN ZAKHAROV	{"phone": "+70524983459"}
0005433202370	2DF374	7385 477019	LEONID SEMENOV	{"phone": "+70111822271"}
0005433202371	004980	1864 274605	ALI EGOROV	{"phone": "+70325406429"}
0005433202372	004980	9517 465174	DMITRIY BELOV	{"phone": "+70451601400"}
0005433202373	004980	4525 417561	SERGEY ABRAMOV	{"email": "abramovs_04121969@postgrespro.ru", "phone": "+70679916713"}
0005433202374	0EE08C	2353 471550	OLGA BARANOVA	{"email": "baranova-o041964@postgrespro.ru", "phone": "+70846408820"}
0005433202375	5BC6EC	8053 296365	ALEKSANDR PAVLOV	{"email": "pavlov-a_22041965@postgrespro.ru", "phone": "+70845740472"}
0005433202376	9C97E5	6511 590867	OKSANA KUZNECOVA	{"email": "oksana_kuznecova20091972@postgrespro.ru", "phone": "+70665146958"}
0005433202377	74CBC1	1264 699957	YULIYA PAVLOVA	{"phone": "+70693849352"}
0005433202378	F241A7	5573 720850	TAISA EGOROVA	{"email": "taisaegorova-061979@postgrespro.ru", "phone": "+70526184688"}
0005433202379	C77DD1	7430 914689	ARTEM KUZMIN	{"email": "kuzmin-a.08041965@postgrespro.ru", "phone": "+70510662638"}
0005433202380	C77DD1	6138 001426	OLEG IVANOV	{"email": "o_ivanov28061988@postgrespro.ru", "phone": "+70448565616"}
0005433202381	77BD78	4781 593473	ELENA TIKHONOVA	{"phone": "+70854120745"}
0005433202382	77BD78	8851 862463	VLADIMIR POPOV	{"phone": "+70249350100"}
0005433202383	D7EC84	8291 660141	EKATERINA MATVEEVA	{"email": "matveeva-e-13011981@postgrespro.ru", "phone": "+70699650485"}
0005433202384	312D8C	3085 172811	SERGEY BONDARENKO	{"phone": "+70237997344"}
0005433202385	312D8C	5905 900608	DANIIL GORBUNOV	{"email": "d-gorbunov-061971@postgrespro.ru", "phone": "+70789851172"}
0005433202386	BB8FAC	4506 261586	VITALIY KUZNECOV	{"phone": "+70356077751"}
0005433202387	C1EF87	0909 368474	ELENA STEPANOVA	{"phone": "+70850980919"}
0005433202388	C1EF87	6477 111840	TATYANA YUDINA	{"phone": "+70668640704"}
0005433202389	09DC09	1952 215644	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_v_22041964@postgrespro.ru", "phone": "+70761164017"}
0005433202390	748B20	3035 153085	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy-20081972@postgrespro.ru", "phone": "+70960100405"}
0005433202391	748B20	7863 078533	ALEKSANDRA STEPANOVA	{"email": "stepanova_aleksandra_1968@postgrespro.ru", "phone": "+70880369424"}
0005433202392	748B20	2280 922415	NINA DANILOVA	{"phone": "+70614310092"}
0005433202393	75835D	1832 632483	ALIYA ISAEVA	{"email": "isaeva_a.23091974@postgrespro.ru", "phone": "+70334746884"}
0005433202394	AF8D10	4256 480359	ANGELINA ZAKHAROVA	{"phone": "+70017775826"}
0005433202395	A1594D	2971 662833	SERGEY FEDOTOV	{"email": "fedotov_s-031965@postgrespro.ru", "phone": "+70250753488"}
0005433202396	58B5FF	0533 079951	LILIYA RODIONOVA	{"phone": "+70741596187"}
0005433202397	58B5FF	6756 929320	LIDIYA CHERNOVA	{"phone": "+70259654158"}
0005433202398	82D4BD	8500 624476	ALEKSANDR VASILEV	{"email": "a.vasilev.28031958@postgrespro.ru", "phone": "+70035680546"}
0005433202399	A2BDC8	5477 493480	OKSANA ILINA	{"email": "o_ilina-121970@postgrespro.ru", "phone": "+70481339113"}
0005433202400	A2BDC8	0595 566087	VLADISLAV SOKOLOV	{"phone": "+70712018054"}
0005433202401	BCFEDD	0496 126138	IGOR SMIRNOV	{"email": "igor.smirnov-20021983@postgrespro.ru", "phone": "+70875039270"}
0005433202402	2F6CC6	4701 393226	VLADIMIR IVANOV	{"phone": "+70520106038"}
0005433202403	259697	7249 401312	NIKITA OSIPOV	{"email": "osipovn_1974@postgrespro.ru", "phone": "+70720000660"}
0005433202404	259697	9301 148148	SVETLANA NESTEROVA	{"phone": "+70175638515"}
0005433202405	0AEB3A	7144 006710	ANDREY SOROKIN	{"email": "sorokin_a26091981@postgrespro.ru", "phone": "+70602694389"}
0005433202406	0AEB3A	9741 488553	NATALYA SEMENOVA	{"email": "semenova.n13101973@postgrespro.ru", "phone": "+70929554762"}
0005433202407	20542B	1606 073786	NIKOLAY KULIKOV	{"phone": "+70476207871"}
0005433202408	20542B	6977 170963	VALENTINA MOISEEVA	{"email": "valentinamoiseeva071976@postgrespro.ru", "phone": "+70287315730"}
0005433202409	33C81E	8512 449792	OLGA POPOVA	{"email": "olgapopova_1969@postgrespro.ru", "phone": "+70567652989"}
0005433202410	1C71D1	7747 190757	ELENA LOGINOVA	{"phone": "+70492135663"}
0005433202411	1C71D1	8129 726883	ANTONINA NIKOLAEVA	{"email": "antoninanikolaeva_02121965@postgrespro.ru", "phone": "+70321382008"}
0005433202412	C83CC6	7386 417301	IRINA NIKOLAEVA	{"phone": "+70379526311"}
0005433202413	D5E109	0436 916312	OLEG ZAKHAROV	{"phone": "+70107186064"}
0005433202414	C41DDF	0630 827450	ALEVTINA PETROVA	{"email": "petrova-alevtina.1970@postgrespro.ru", "phone": "+70068111855"}
0005433202415	C41DDF	1131 719971	EVGENIY KOZLOV	{"email": "kozlove1968@postgrespro.ru", "phone": "+70891841511"}
0005433202416	6D5F12	5294 062791	ANASTASIYA KUZMINA	{"phone": "+70994733856"}
0005433202417	0EE2FF	8094 024021	EKATERINA ALEKSANDROVA	{"phone": "+70242142030"}
0005433202418	0EE2FF	4229 497882	DMITRIY SOKOLOV	{"phone": "+70845427129"}
0005433202419	75700E	7558 045566	VYACHESLAV NIKOLAEV	{"phone": "+70706041514"}
0005433202420	0776F8	9803 877825	EVGENIY IVANOV	{"email": "e_ivanov_1971@postgrespro.ru", "phone": "+70746555137"}
0005433202421	2110C2	3076 153287	TAMARA TROFIMOVA	{"email": "ttrofimova.17041973@postgrespro.ru", "phone": "+70409189939"}
0005433202422	D4F197	2578 968966	OLGA SOKOLOVA	{"phone": "+70985985764"}
0005433202423	735575	1579 208017	OLGA IVANOVA	{"email": "olgaivanova-021975@postgrespro.ru", "phone": "+70014622201"}
0005433202424	52C118	1749 504539	ALEKSANDR BONDARENKO	{"phone": "+70500954332"}
0005433202425	52C118	6154 677805	ELINA VOLKOVA	{"email": "evolkova.051970@postgrespro.ru", "phone": "+70693514037"}
0005433202426	1E8350	7055 964539	TATYANA SMIRNOVA	{"phone": "+70846385930"}
0005433202427	4997D0	9520 601038	VLADIMIR POPOV	{"phone": "+70133061899"}
0005433202428	A53B01	8088 629957	MAKSIM IVANOV	{"email": "maksimivanov-05101967@postgrespro.ru", "phone": "+70054272982"}
0005433202429	A3D4E7	2292 207825	ZINAIDA BELYAEVA	{"phone": "+70569684249"}
0005433202430	A3D4E7	2430 049296	YANA KUZNECOVA	{"phone": "+70368324771"}
0005433202431	991480	5547 561341	RASHID ANDREEV	{"phone": "+70858320526"}
0005433202432	991480	1591 551329	VALENTINA MARTYNOVA	{"email": "vmartynova11041972@postgrespro.ru", "phone": "+70323197136"}
0005433202433	27226A	4266 419720	MARAT ILIN	{"phone": "+70812813392"}
0005433202434	27226A	8550 478047	SVETLANA EGOROVA	{"phone": "+70240515875"}
0005433202435	5DA3F1	9976 844551	IRINA FADEEVA	{"phone": "+70045308376"}
0005433202436	5DA3F1	7026 005838	MARIYA MEDVEDEVA	{"email": "medvedevam_011980@postgrespro.ru", "phone": "+70690219941"}
0005433202437	F764DD	0684 073742	ALEKSANDR MARTYNOV	{"phone": "+70549976375"}
0005433202438	05D1B8	3713 550116	SERGEY SMIRNOV	{"email": "smirnov.sergey13031968@postgrespro.ru", "phone": "+70548844080"}
0005433202439	192C4F	4258 639954	NIKOLAY SIDOROV	{"email": "sidorov_nikolay_1965@postgrespro.ru", "phone": "+70625546096"}
0005433202440	7F4498	4327 047181	NADEZHDA DENISOVA	{"email": "nadezhda_denisova-1993@postgrespro.ru", "phone": "+70679870345"}
0005433202441	FF663C	5954 291179	ALEKSANDRA LOGINOVA	{"email": "a.loginova1973@postgrespro.ru", "phone": "+70868884592"}
0005433202442	1F5706	8919 800379	SERGEY POPOV	{"phone": "+70365414430"}
0005433202443	B7B81E	1337 871391	NIKOLAY SEMENOV	{"email": "n.semenov_1968@postgrespro.ru", "phone": "+70529764853"}
0005433202444	B7B81E	7894 695382	ALEKSANDR ILIN	{"phone": "+70877566747"}
0005433202445	6FF121	1627 732547	MARIYA PAVLOVA	{"phone": "+70750155133"}
0005433202446	212219	8618 030263	RINAT ZHURAVLEV	{"email": "zhuravlev_r-071984@postgrespro.ru", "phone": "+70892322423"}
0005433202447	212219	8629 130149	TATYANA ISAEVA	{"phone": "+70261326421"}
0005433202448	07E66E	1044 506730	OLGA MOISEEVA	{"email": "moiseeva-olga10031972@postgrespro.ru", "phone": "+70279963179"}
0005433202449	07E66E	3587 864787	MAKSIM ORLOV	{"email": "orlov-m011954@postgrespro.ru", "phone": "+70736257176"}
0005433202450	07E66E	7799 092919	KLAVDIYA ISAEVA	{"email": "klavdiya.isaeva_1965@postgrespro.ru", "phone": "+70232334651"}
0005433202451	C50F40	0053 560117	YULIYA KONOVALOVA	{"phone": "+70201065386"}
0005433202452	228BD0	8296 326800	SERGEY ZAKHAROV	{"email": "zakharov.s-021973@postgrespro.ru", "phone": "+70087827670"}
0005433202453	EC253C	6937 845277	SVETLANA GAVRILOVA	{"email": "s-gavrilova.021979@postgrespro.ru", "phone": "+70468253540"}
0005433202454	8B3556	3993 469373	ALEKSANDR MAKSIMOV	{"phone": "+70909001613"}
0005433202455	8B3556	3549 160606	VASILIY PETROV	{"phone": "+70335862369"}
0005433202456	4418FD	4099 344447	KARINA VOLKOVA	{"email": "volkovakarina-071973@postgrespro.ru", "phone": "+70853954318"}
0005433202457	744D90	3089 045613	ANNA PAVLOVA	{"phone": "+70420938281"}
0005433202458	842845	7287 307142	EVGENIY ALEKSEEV	{"phone": "+70227533666"}
0005433202459	842845	4288 390249	ELENA ANTONOVA	{"email": "antonovaelena_091978@postgrespro.ru", "phone": "+70807894804"}
0005433202460	E544B5	4503 959036	OLGA PETROVA	{"phone": "+70418165188"}
0005433202461	E544B5	0083 892841	ANNA MOISEEVA	{"email": "moiseeva-anna-13101963@postgrespro.ru", "phone": "+70100129115"}
0005433202462	932AEA	0718 377270	DENIS GERASIMOV	{"email": "d.gerasimov-05011974@postgrespro.ru", "phone": "+70482961419"}
0005433202463	932AEA	8048 255237	LYUDMILA KOZLOVA	{"email": "lkozlova101973@postgrespro.ru", "phone": "+70246545052"}
0005433202464	8EC4EA	7742 899835	ANDREY CHERNOV	{"email": "chernov_andrey-1953@postgrespro.ru", "phone": "+70820547584"}
0005433202465	15A084	7268 599020	MARINA OVCHINNIKOVA	{"email": "movchinnikova-121976@postgrespro.ru", "phone": "+70795773191"}
0005433202466	15A084	1003 266816	NAILYA YUDINA	{"email": "nyudina-011982@postgrespro.ru", "phone": "+70498724495"}
0005433202467	B6296D	9907 235872	TAMARA KAZAKOVA	{"email": "kazakova.tamara-041975@postgrespro.ru", "phone": "+70500769010"}
0005433202468	F92F59	6452 803886	OLEG KOZLOV	{"phone": "+70708243887"}
0005433202469	950B4E	2113 198052	ALEKSANDR ZHURAVLEV	{"email": "azhuravlev-081976@postgrespro.ru", "phone": "+70762583546"}
0005433202470	950B4E	4770 298210	NATALYA SMIRNOVA	{"phone": "+70641326650"}
0005433202471	5CCC03	1419 226027	ELENA SEMENOVA	{"email": "elena.semenova.081965@postgrespro.ru", "phone": "+70383125908"}
0005433202472	50A840	1608 288493	ALEKSEY VOLKOV	{"phone": "+70830017812"}
0005433202473	CF6E27	0831 844045	VITALIY MOROZOV	{"phone": "+70530343524"}
0005433202474	CF6E27	7734 034168	VERA NIKITINA	{"email": "veranikitina-1956@postgrespro.ru", "phone": "+70924821279"}
0005433202475	E934B8	6643 849375	IVAN GAVRILOV	{"phone": "+70216542323"}
0005433202476	0777CD	3594 539923	MIKHAIL AFANASEV	{"email": "m-afanasev-111958@postgrespro.ru", "phone": "+70097599017"}
0005433202477	94C5AA	0494 331471	VLADISLAV FEDOROV	{"email": "fedorov-v-1965@postgrespro.ru", "phone": "+70080013727"}
0005433202478	C31A8B	1373 630459	NIKOLAY MIKHAYLOV	{"phone": "+70570289241"}
0005433202479	C52E41	2059 967370	VALENTIN ALEKSANDROV	{"phone": "+70183651373"}
0005433202480	C52E41	3760 819552	SERGEY DAVYDOV	{"phone": "+70755812719"}
0005433202481	DFCA8E	9624 406492	EVGENIY KUZNECOV	{"phone": "+70261272945"}
0005433202482	B7F845	5054 321212	ALIYA FILATOVA	{"phone": "+70569210401"}
0005433202483	B7F845	3384 611129	DMITRIY OSIPOV	{"phone": "+70341742727"}
0005433202484	DA113F	1479 995587	MARINA ERMAKOVA	{"phone": "+70982581785"}
0005433202485	DA113F	1754 074535	IRINA SCHERBAKOVA	{"email": "scherbakova_irina.19111974@postgrespro.ru", "phone": "+70562211752"}
0005433202486	DA113F	3186 112097	IVAN MAKSIMOV	{"phone": "+70057274133"}
0005433202487	57FC8B	3048 132076	EKATERINA AKIMOVA	{"email": "eakimova_1981@postgrespro.ru", "phone": "+70681277146"}
0005433202488	034DA1	4503 059876	VITALIY SEMENOV	{"phone": "+70303182429"}
0005433202489	034DA1	3230 855835	ALBINA KARPOVA	{"email": "a_karpova1977@postgrespro.ru", "phone": "+70534179416"}
0005433202490	454742	4281 884729	OLGA TITOVA	{"phone": "+70153767525"}
0005433202491	454742	3659 142065	DMITRIY GAVRILOV	{"email": "d_gavrilov24121964@postgrespro.ru", "phone": "+70663902666"}
0005433202492	6EBAAD	3335 130368	OLGA RYABOVA	{"phone": "+70756586286"}
0005433202493	6EBAAD	3614 397241	VLADIMIR ISAEV	{"phone": "+70479660366"}
0005433202494	7239CC	8861 333742	ALEKSANDR KISELEV	{"phone": "+70455713738"}
0005433202495	96C9B4	6180 201844	VIKTOR IVANOV	{"email": "v-ivanov011970@postgrespro.ru", "phone": "+70862489356"}
0005433202496	743A87	9078 894750	EVGENIYA ZAKHAROVA	{"phone": "+70898070290"}
0005433202497	A2E685	8097 660022	NONNA NIKITINA	{"email": "nonna_nikitina_1972@postgrespro.ru", "phone": "+70844223087"}
0005433202498	A2E685	9085 904462	VIKTORIYA DMITRIEVA	{"email": "dmitrieva_v1966@postgrespro.ru", "phone": "+70600398667"}
0005433202499	5108EB	1998 542806	EVGENIYA VOLKOVA	{"phone": "+70730301917"}
0005433202500	0190B4	1928 230002	TAMARA BORISOVA	{"email": "t_borisova-1969@postgrespro.ru", "phone": "+70948315915"}
0005433202501	FC81B0	7469 296096	MAKSIM IVANOV	{"phone": "+70241787236"}
0005433202502	FC81B0	8839 303651	VALENTINA CHERNOVA	{"phone": "+70088423207"}
0005433202503	8EBC48	3222 080324	VLADIMIR CHERNOV	{"email": "vladimirchernov07081965@postgrespro.ru", "phone": "+70994338575"}
0005433202504	8171D5	2841 759072	TAMARA MELNIKOVA	{"email": "tamara.melnikova-1974@postgrespro.ru", "phone": "+70186831754"}
0005433202505	8171D5	2930 436226	NATALYA LEBEDEVA	{"email": "natalya.lebedeva_07031965@postgrespro.ru", "phone": "+70431288992"}
0005433202506	D84955	3259 919889	OLGA MIKHAYLOVA	{"phone": "+70630175195"}
0005433202507	135956	5132 647880	ZINAIDA GERASIMOVA	{"phone": "+70644905094"}
0005433202508	CD56B5	2721 431858	INGA YAKOVLEVA	{"phone": "+70627052335"}
0005433202509	40DE63	9520 459518	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya-10021972@postgrespro.ru", "phone": "+70130243499"}
0005433202510	5ED9D7	5257 933766	NATALYA MAKSIMOVA	{"email": "maksimovanatalya-1972@postgrespro.ru", "phone": "+70505301477"}
0005433202511	5FAAA4	0435 977844	ELENA TITOVA	{"email": "etitova_1971@postgrespro.ru", "phone": "+70020149526"}
0005433202512	91C5BE	6034 616123	ALEKSANDR KARPOV	{"email": "karpovaleksandr07091969@postgrespro.ru", "phone": "+70094664540"}
0005433202513	C40867	6943 673271	ARKADIY SMIRNOV	{"phone": "+70620597940"}
0005433202514	709460	9040 981971	DMITRIY KUZNECOV	{"email": "kuznecov_d_06011962@postgrespro.ru", "phone": "+70902473755"}
0005433202515	709460	7029 622790	MARIYA STEPANOVA	{"phone": "+70942062545"}
0005433202516	58CDE0	6829 809744	VLADIMIR CHERNOV	{"email": "chernov_v_031965@postgrespro.ru", "phone": "+70175444674"}
0005433202517	DCCC67	4000 169443	IRINA NIKITINA	{"email": "nikitina-irina-071977@postgrespro.ru", "phone": "+70022981908"}
0005433202518	DCCC67	8500 143846	SERGEY AFANASEV	{"email": "afanasev.sergey1963@postgrespro.ru", "phone": "+70420226984"}
0005433202519	811241	4281 436307	LILIYA KOROLEVA	{"phone": "+70320161851"}
0005433202520	466D81	7634 113647	VALENTINA KARPOVA	{"email": "karpova.valentina_15011972@postgrespro.ru", "phone": "+70490696319"}
0005433202521	4B18C7	4731 821223	NIKOLAY KAZAKOV	{"phone": "+70468111870"}
0005433202522	5A23AD	1839 967617	DMITRIY NAZAROV	{"email": "dmitriy_nazarov1967@postgrespro.ru", "phone": "+70746582312"}
0005433202523	92F7CC	0864 271784	YURIY SERGEEV	{"email": "y_sergeev_031984@postgrespro.ru", "phone": "+70760190248"}
0005433202524	C85C25	6636 437749	ILYA KUDRYASHOV	{"phone": "+70259358779"}
0005433202525	C85C25	3904 628169	MAKSIM POPOV	{"email": "popov.maksim_05041983@postgrespro.ru", "phone": "+70069019364"}
0005433202526	CA5416	3880 467553	LARISA LAZAREVA	{"phone": "+70460359288"}
0005433202527	CA5416	0407 312880	VITALIY KUZNECOV	{"phone": "+70418619763"}
0005433202528	CA5416	8249 876121	NATALYA MOROZOVA	{"email": "morozova-n_061961@postgrespro.ru", "phone": "+70727278942"}
0005433202529	8CEC3D	5326 950446	ALEKSANDR KRASNOV	{"email": "krasnova121965@postgrespro.ru", "phone": "+70996888852"}
0005433202530	25F78B	2350 824606	NATALYA TARASOVA	{"phone": "+70995358598"}
0005433202531	25F78B	7969 619147	TAMARA NIKOLAEVA	{"email": "t.nikolaeva_121982@postgrespro.ru", "phone": "+70759469257"}
0005433202532	C71A49	7391 865570	YURIY KUZNECOV	{"phone": "+70357510620"}
0005433202533	C71A49	0151 613728	ALEKSEY ANDREEV	{"email": "andreev-aleksey.121960@postgrespro.ru", "phone": "+70790374816"}
0005433202534	5BF49B	6459 225728	KSENIYA TIMOFEEVA	{"email": "timofeeva.kseniya.1964@postgrespro.ru", "phone": "+70298135839"}
0005433202535	F58C6F	1347 752986	SERGEY SIDOROV	{"phone": "+70968933548"}
0005433202536	F58C6F	7819 366297	RINAT FOMIN	{"email": "fominr-1970@postgrespro.ru", "phone": "+70192059503"}
0005433202537	88F66F	8509 022098	ANATOLIY ZHURAVLEV	{"email": "a_zhuravlev.1964@postgrespro.ru", "phone": "+70095442701"}
0005433202538	4D4825	3164 868911	ALEKSANDR ZHUKOV	{"email": "a-zhukov.1969@postgrespro.ru", "phone": "+70080908153"}
0005433202539	4D4825	2147 348378	OLGA STEPANOVA	{"phone": "+70499620296"}
0005433202540	03D69C	7061 566393	KAMIL TARASOV	{"email": "tarasovkamil_15041981@postgrespro.ru", "phone": "+70691122885"}
0005433202541	5CD310	4511 976949	LYUDMILA ZHURAVLEVA	{"email": "lyudmilazhuravleva.011972@postgrespro.ru", "phone": "+70625317597"}
0005433202542	B4EF57	2994 299629	NATALYA MARTYNOVA	{"email": "natalya-martynova_1983@postgrespro.ru", "phone": "+70595048344"}
0005433202543	3A5ADC	9421 880070	SERGEY IVANOV	{"phone": "+70362601681"}
0005433202544	F3FDAB	3708 742964	LYUDMILA MELNIKOVA	{"phone": "+70557675719"}
0005433202545	A0BA1A	4712 372516	ALEKSANDR POPOV	{"email": "popova18121975@postgrespro.ru", "phone": "+70363906673"}
0005433202546	609AC0	1772 752846	OLGA NIKOLAEVA	{"phone": "+70364795745"}
0005433202547	609AC0	9344 005391	ELIZAVETA IVANOVA	{"phone": "+70098326830"}
0005433202548	803988	7769 270215	ALEKSANDR KISELEV	{"phone": "+70518539320"}
0005433202549	1A3FCA	4001 115021	VIKTOR STEPANOV	{"email": "stepanov.v_031968@postgrespro.ru", "phone": "+70076954337"}
0005433202550	DDD88E	3363 700345	YURIY MAKAROV	{"phone": "+70127949021"}
0005433202551	DDD88E	7711 913885	IGOR SOKOLOV	{"email": "sokolov.i_1980@postgrespro.ru", "phone": "+70320314609"}
0005433202552	9DD788	1419 055408	LARISA VLASOVA	{"email": "vlasova-larisa.04081969@postgrespro.ru", "phone": "+70127647175"}
0005433202553	43E280	7778 536788	ARTEM KAZAKOV	{"email": "artem_kazakov24101968@postgrespro.ru", "phone": "+70557900668"}
0005433202554	CE68A7	5550 028525	ALEKSEY NOVIKOV	{"email": "novikovaleksey_1974@postgrespro.ru", "phone": "+70849449604"}
0005433202555	1F506F	7611 052877	TATYANA KARPOVA	{"email": "karpova_tatyana091960@postgrespro.ru", "phone": "+70017406060"}
0005433202556	9EDE7D	7228 344758	NADEZHDA ROMANOVA	{"phone": "+70379807005"}
0005433202557	AC19BE	7731 867071	NIKOLAY RODIONOV	{"email": "nikolay-rodionov_19071968@postgrespro.ru", "phone": "+70632549489"}
0005433202558	78C535	4868 562468	TIMUR SEMENOV	{"email": "timur.semenov_25041985@postgrespro.ru", "phone": "+70210346958"}
0005433202559	184F0D	8897 501238	EKATERINA KUZNECOVA	{"phone": "+70202567329"}
0005433202560	184F0D	9397 466467	RASHIT PETROV	{"email": "rashit-petrov1974@postgrespro.ru", "phone": "+70708660490"}
0005433202561	7627FB	9995 662952	SERGEY SOROKIN	{"email": "s.sorokin.06051966@postgrespro.ru", "phone": "+70711289978"}
0005433202562	7627FB	4717 117852	TATYANA EFREMOVA	{"email": "t.efremova.10121977@postgrespro.ru", "phone": "+70039191152"}
0005433202563	03B647	3637 539239	OLGA ZHURAVLEVA	{"email": "zhuravleva-o26111964@postgrespro.ru", "phone": "+70535752391"}
0005433202564	03B647	5266 245269	VALENTIN NIKITIN	{"email": "valentin.nikitin.1961@postgrespro.ru", "phone": "+70771423436"}
0005433202565	8D4789	8569 123824	BORIS GUSEV	{"email": "gusev.b18041977@postgrespro.ru", "phone": "+70766397704"}
0005433202566	35CCF2	5399 897393	FEDOR BONDARENKO	{"phone": "+70223369354"}
0005433202567	35CCF2	3549 162800	ALENA SOROKINA	{"phone": "+70524359872"}
0005433202568	A183F7	7563 100075	VERA GAVRILOVA	{"phone": "+70276583383"}
0005433202569	A183F7	4481 896360	TATYANA POTAPOVA	{"phone": "+70351733975"}
0005433202570	BBB17F	9181 516485	ALEKSEY NIKOLAEV	{"email": "a.nikolaev_03111974@postgrespro.ru", "phone": "+70220900031"}
0005433202571	D51E92	2434 424159	ELIZAVETA ORLOVA	{"email": "orlova_elizaveta-071981@postgrespro.ru", "phone": "+70314087454"}
0005433202572	D51E92	4530 587504	GRIGORIY MIRONOV	{"email": "g-mironov081976@postgrespro.ru", "phone": "+70663059862"}
0005433202573	8A2882	9209 765881	TIMUR SOKOLOV	{"email": "timur_sokolov1976@postgrespro.ru", "phone": "+70002970057"}
0005433202574	60C13C	6457 933022	ILYA SCHERBAKOV	{"email": "scherbakov_i091985@postgrespro.ru", "phone": "+70116455470"}
0005433202575	60C13C	0238 166843	ANDREY ANDREEV	{"email": "andreev-a-14031966@postgrespro.ru", "phone": "+70245717259"}
0005433202576	E70975	6069 527857	PAVEL IVANOV	{"phone": "+70884022787"}
0005433202577	E70975	6113 309718	SERGEY KUZNECOV	{"email": "sergey_kuznecov-22041964@postgrespro.ru", "phone": "+70568122563"}
0005433202578	4E5308	8080 941412	RINAT SOLOVEV	{"email": "solovev-rinat_1975@postgrespro.ru", "phone": "+70115447320"}
0005433202579	3FF6AD	2960 921893	LYUDMILA DAVYDOVA	{"phone": "+70311298881"}
0005433202580	3FF6AD	7220 400261	DMITRIY FEDOROV	{"email": "fedorov-dmitriy-021983@postgrespro.ru", "phone": "+70719268740"}
0005433202581	3FF6AD	7477 849326	DMITRIY MATVEEV	{"phone": "+70360065782"}
0005433202582	39F5C3	4590 121310	LIDIYA EGOROVA	{"email": "egorova_lidiya051969@postgrespro.ru", "phone": "+70493124509"}
0005433202583	016B74	8695 227314	ANASTASIYA ZHUKOVA	{"email": "zhukova-a_1970@postgrespro.ru", "phone": "+70516901684"}
0005433202584	016B74	3029 871321	SERGEY IVANOV	{"phone": "+70413860374"}
0005433202585	BA5558	5271 129019	VALENTINA NOVIKOVA	{"email": "novikovav.25081969@postgrespro.ru", "phone": "+70957117427"}
0005433202586	4AEA12	1787 491216	NINA TARASOVA	{"email": "ntarasova.25021977@postgrespro.ru", "phone": "+70901124540"}
0005433202587	4AEA12	3277 399683	NIKOLAY SAVELEV	{"email": "savelev-nikolay111963@postgrespro.ru", "phone": "+70281867426"}
0005433202588	161003	2038 597774	ELENA KALININA	{"phone": "+70699189988"}
0005433202589	84DA3D	0642 639388	EKATERINA TIKHONOVA	{"email": "tikhonovaekaterina12061966@postgrespro.ru", "phone": "+70440500358"}
0005433202590	F23C73	0774 276568	PAVEL AFANASEV	{"phone": "+70070890698"}
0005433202591	1AF296	8699 523316	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev061954@postgrespro.ru", "phone": "+70473458664"}
0005433202592	A512AB	2603 894330	VLADIMIR FOMIN	{"email": "vfomin-1967@postgrespro.ru", "phone": "+70809835100"}
0005433202593	5BCD83	3635 362063	EKATERINA TITOVA	{"email": "ekaterina.titova10121970@postgrespro.ru", "phone": "+70499543083"}
0005433202705	9871A2	2775 513738	ELENA GRISHINA	{"phone": "+70047803745"}
0005433202594	5BCD83	0415 305616	VIKTORIYA KUDRYASHOVA	{"email": "v-kudryashova-1969@postgrespro.ru", "phone": "+70137449104"}
0005433202595	5BCD83	6605 039080	SVETLANA KOZLOVA	{"phone": "+70704839331"}
0005433202596	9795F0	5372 669559	DMITRIY OSIPOV	{"email": "osipov-d_17021974@postgrespro.ru", "phone": "+70927762976"}
0005433202597	FB733D	8507 792402	RUSTAM SHEVCHENKO	{"email": "rshevchenko-101971@postgrespro.ru", "phone": "+70308413599"}
0005433202598	FB733D	6521 230951	TATYANA VASILEVA	{"phone": "+70699209771"}
0005433202599	EDDF3F	6244 362424	ANTON MOROZOV	{"email": "morozov-a.26101975@postgrespro.ru", "phone": "+70767850820"}
0005433202600	EDDF3F	5906 419523	SVETLANA KOROLEVA	{"phone": "+70139706617"}
0005433202601	152624	4179 991318	EGOR TIKHONOV	{"email": "tikhonov.e-041974@postgrespro.ru", "phone": "+70475886209"}
0005433202602	152624	6479 426639	DANIL SHEVCHENKO	{"email": "shevchenko.d.16091972@postgrespro.ru", "phone": "+70252301875"}
0005433202603	EFAC54	2166 513745	NADEZHDA KARPOVA	{"phone": "+70768520394"}
0005433202604	EFAC54	0444 557869	YURIY DMITRIEV	{"phone": "+70136982356"}
0005433202605	9F9E7D	1815 117078	DMITRIY ORLOV	{"phone": "+70376941912"}
0005433202606	1702B6	5313 197000	YURIY SERGEEV	{"email": "sergeev.y011964@postgrespro.ru", "phone": "+70144489951"}
0005433202607	17B716	3046 912545	SERGEY FOMIN	{"phone": "+70409267846"}
0005433202608	8912AE	7422 763811	MARIYA KULIKOVA	{"email": "m.kulikova-1978@postgrespro.ru", "phone": "+70121934801"}
0005433202609	2A810A	5865 591014	ALEKSEY KUZNECOV	{"email": "alekseykuznecov021970@postgrespro.ru", "phone": "+70805724088"}
0005433202610	E62187	2486 329670	RAISA RYABOVA	{"phone": "+70583294208"}
0005433202611	EE663A	6520 621679	ELENA ZAKHAROVA	{"phone": "+70048727304"}
0005433202612	62ED69	4008 793773	OKSANA FILIPPOVA	{"email": "o.filippova.28101960@postgrespro.ru", "phone": "+70311399857"}
0005433202613	DDF5F7	1483 341358	ELENA KALININA	{"email": "kalininae.1969@postgrespro.ru", "phone": "+70023393675"}
0005433202614	DDF5F7	9351 588893	LYUDMILA LUKYANOVA	{"email": "lukyanova_l_061973@postgrespro.ru", "phone": "+70269456801"}
0005433202615	B54655	2576 220669	EVGENIY POPOV	{"phone": "+70966842254"}
0005433202616	B54655	7650 326016	IRINA KUZNECOVA	{"email": "kuznecova.i1969@postgrespro.ru", "phone": "+70207487048"}
0005433202617	F275B2	3965 052424	VASILIY SOROKIN	{"phone": "+70427710701"}
0005433202618	00DAED	5871 984940	ANDREY VOROBEV	{"phone": "+70662187473"}
0005433202619	1796DF	1029 160859	PAVEL SIDOROV	{"email": "sidorov-pavel1974@postgrespro.ru", "phone": "+70921986846"}
0005433202620	1796DF	4534 692430	VERA MAKAROVA	{"phone": "+70452838053"}
0005433202621	98E29D	0990 640366	EVGENIY PAVLOV	{"email": "evgeniy.pavlov.1967@postgrespro.ru", "phone": "+70121795615"}
0005433202622	E28189	7478 809949	IVAN MATVEEV	{"phone": "+70364104721"}
0005433202623	01390C	2379 872447	DANILA KUZNECOV	{"email": "danila_kuznecov_031971@postgrespro.ru", "phone": "+70937565343"}
0005433202624	01390C	7839 385500	OLGA VOLKOVA	{"email": "o_volkova_31081971@postgrespro.ru", "phone": "+70400608521"}
0005433202625	B12CF0	1812 027452	ANDREY YAKOVLEV	{"phone": "+70785233520"}
0005433202626	45BF28	6578 411577	TATYANA LEBEDEVA	{"email": "tatyana.lebedeva061958@postgrespro.ru", "phone": "+70035657735"}
0005433202627	45BF28	2331 352178	SERGEY PETROV	{"phone": "+70524582379"}
0005433202628	45BF28	2413 356549	SERGEY ISAEV	{"phone": "+70963285509"}
0005433202629	537C52	6138 765341	RUSLAN EGOROV	{"email": "r_egorov04071975@postgrespro.ru", "phone": "+70285529118"}
0005433202630	E87A61	7852 657730	INNA MIKHAYLOVA	{"email": "mikhaylovainna.10061972@postgrespro.ru", "phone": "+70097414220"}
0005433202631	E87A61	3215 777627	TAISIYA ANDREEVA	{"phone": "+70163739039"}
0005433202632	56739D	9874 297566	NINA PETROVA	{"phone": "+70655006646"}
0005433202633	7E3ED1	2330 847452	LIDIYA NIKIFOROVA	{"phone": "+70862186357"}
0005433202634	45FA46	1538 032495	NIKOLAY DAVYDOV	{"email": "davydov-nikolay.1970@postgrespro.ru", "phone": "+70899765441"}
0005433202635	45FA46	1428 694865	RAIS SCHERBAKOV	{"phone": "+70447462617"}
0005433202636	2DECB3	9544 000580	SVETLANA GERASIMOVA	{"phone": "+70622270458"}
0005433202637	0188D2	1596 771203	RUSTAM ZHURAVLEV	{"email": "zhuravlevr-26011968@postgrespro.ru", "phone": "+70004080006"}
0005433202638	7572FD	9610 866711	TATYANA SCHERBAKOVA	{"phone": "+70563815948"}
0005433202639	42AB54	0700 922105	VALENTINA ARKHIPOVA	{"email": "valentina_arkhipova-08081967@postgrespro.ru", "phone": "+70518853215"}
0005433202640	CCC9F2	3387 234539	VASILIY DAVYDOV	{"phone": "+70366524278"}
0005433202641	CCC9F2	5636 887264	SERGEY PAVLOV	{"email": "pavlovsergey22091980@postgrespro.ru", "phone": "+70822965231"}
0005433202642	A255DD	9853 918153	NATALYA PAVLOVA	{"phone": "+70111159446"}
0005433202643	8356BC	5762 362648	SVETLANA YAKOVLEVA	{"phone": "+70692287069"}
0005433202644	C01496	0332 903899	TATYANA OVCHINNIKOVA	{"phone": "+70173966668"}
0005433202645	EE4CF6	3386 139970	YURIY ANTONOV	{"phone": "+70754528664"}
0005433202646	A16C57	2394 810479	KONSTANTIN PETROV	{"phone": "+70747213788"}
0005433202647	A16C57	2460 340448	EKATERINA FOMINA	{"email": "e-fomina.15071970@postgrespro.ru", "phone": "+70445372058"}
0005433202648	C70BEB	7781 200846	IVAN NIKITIN	{"email": "inikitin.07051964@postgrespro.ru", "phone": "+70680557315"}
0005433202649	59F3F4	3637 517073	GRIGORIY ZAKHAROV	{"email": "grigoriy-zakharov.18111975@postgrespro.ru", "phone": "+70275309350"}
0005433202762	4995BF	2487 216613	SERGEY FOMIN	{"phone": "+70052309289"}
0005433202650	F8A2C4	9840 127751	BORIS KUZNECOV	{"email": "kuznecov_b.1967@postgrespro.ru", "phone": "+70347827277"}
0005433202651	F8A2C4	9227 991225	VLADIMIR FOMIN	{"phone": "+70406182904"}
0005433202652	F8A2C4	3828 551343	SERGEY TIMOFEEV	{"email": "timofeev-sergey.10041983@postgrespro.ru", "phone": "+70767530594"}
0005433202653	D845F8	7965 660452	ZINAIDA IVANOVA	{"email": "ivanova.zinaida-1971@postgrespro.ru", "phone": "+70773801659"}
0005433202654	3C1398	1707 551743	YULIYA NOVIKOVA	{"phone": "+70817561437"}
0005433202655	3C1398	6672 501007	VLADISLAV SOROKIN	{"phone": "+70533259957"}
0005433202656	5E5B34	1016 430295	OLGA POPOVA	{"email": "popova_olga1970@postgrespro.ru", "phone": "+70198816600"}
0005433202657	22121F	7086 945960	MARINA NESTEROVA	{"phone": "+70618350628"}
0005433202658	22121F	6267 643990	VIKTOR EGOROV	{"email": "v_egorov021974@postgrespro.ru", "phone": "+70727913722"}
0005433202659	22121F	2938 461346	VIKTORIYA NIKITINA	{"phone": "+70010717110"}
0005433202660	F8B1E0	0711 290784	KSENIYA ERMAKOVA	{"email": "kseniya.ermakova_1971@postgrespro.ru", "phone": "+70743900958"}
0005433202661	4DB182	3858 280846	MATVEY DAVYDOV	{"email": "mdavydov_27011985@postgrespro.ru", "phone": "+70207398687"}
0005433202662	F57D8D	6621 400839	TATYANA IVANOVA	{"email": "ivanova_t1979@postgrespro.ru", "phone": "+70909702063"}
0005433202663	8DCAC4	6709 517909	ALEKSANDR NIKOLAEV	{"phone": "+70594914057"}
0005433202664	77DF38	1078 888982	IRINA KUDRYASHOVA	{"email": "kudryashovai.061963@postgrespro.ru", "phone": "+70225542389"}
0005433202665	77DF38	6634 054606	SVETLANA NIKITINA	{"email": "nikitina-svetlana18021969@postgrespro.ru", "phone": "+70316079125"}
0005433202666	2AADB0	7015 515413	ELMIRA NIKOLAEVA	{"email": "nikolaeva_e.031977@postgrespro.ru", "phone": "+70561482465"}
0005433202667	9CD831	3467 152277	NATALYA ORLOVA	{"email": "natalyaorlova_25121972@postgrespro.ru", "phone": "+70944595620"}
0005433202668	BA5760	5065 849237	OLEG IVANOV	{"email": "ivanov.o.121973@postgrespro.ru", "phone": "+70960463229"}
0005433202669	03561D	1542 687492	ANNA ROMANOVA	{"email": "a.romanova-011976@postgrespro.ru", "phone": "+70344832738"}
0005433202670	92906D	6385 113196	BORIS MIKHAYLOV	{"email": "boris-mikhaylov-111976@postgrespro.ru", "phone": "+70600632708"}
0005433202671	92906D	3667 027241	ANNA MAKAROVA	{"email": "amakarova101978@postgrespro.ru", "phone": "+70878755415"}
0005433202672	0CAE47	8427 869103	MAKSIM ANDREEV	{"phone": "+70959892645"}
0005433202673	333AD8	3079 992457	DMITRIY KOZLOV	{"phone": "+70108007255"}
0005433202674	333AD8	8720 007876	VLADIMIR MIRONOV	{"email": "mironov.v-23051977@postgrespro.ru", "phone": "+70490693748"}
0005433202675	9041BD	6720 465496	ALEKSANDRA VOROBEVA	{"email": "vorobeva_a_1961@postgrespro.ru", "phone": "+70706147641"}
0005433202676	9041BD	7522 159820	IVAN KUZMIN	{"email": "ivan-kuzmin30091975@postgrespro.ru", "phone": "+70289094117"}
0005433202677	479277	3452 958649	ALEKSANDR ANDREEV	{"phone": "+70286137047"}
0005433202678	8CFA0F	0931 146683	DMITRIY KOROLEV	{"email": "korolev_d_081976@postgrespro.ru", "phone": "+70223319690"}
0005433202679	8CFA0F	3448 707099	DARYA MAKAROVA	{"phone": "+70800556380"}
0005433202680	22BB2D	6234 512863	NIKOLAY KUDRYASHOV	{"email": "n-kudryashov.17011972@postgrespro.ru", "phone": "+70353092589"}
0005433202681	A619A9	1800 654468	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey111975@postgrespro.ru", "phone": "+70761253098"}
0005433202682	007FD3	9459 777080	NINA ZHUKOVA	{"phone": "+70070591896"}
0005433202683	2FB3FA	2361 774169	VALENTINA MASLOVA	{"email": "vmaslova.081980@postgrespro.ru", "phone": "+70118873071"}
0005433202684	A8B9D0	6152 963662	IRINA VASILEVA	{"email": "ivasileva_08081974@postgrespro.ru", "phone": "+70846124978"}
0005433202685	A8B9D0	7131 585245	ANNA SOLOVEVA	{"email": "solovevaa_02101979@postgrespro.ru", "phone": "+70813551904"}
0005433202686	312568	2042 623313	ROMAN KULIKOV	{"phone": "+70582498314"}
0005433202687	713192	3950 896267	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr-041966@postgrespro.ru", "phone": "+70855723057"}
0005433202688	CA677E	2655 122489	VLADISLAV SERGEEV	{"email": "sergeev-v_1976@postgrespro.ru", "phone": "+70507470470"}
0005433202689	F2CDFC	3191 554674	VIKTOR NIKOLAEV	{"phone": "+70153552466"}
0005433202690	F2CDFC	2731 979478	ALEKSANDR ALEKSEEV	{"phone": "+70251687575"}
0005433202691	4DF5A5	3106 203443	YANA SOKOLOVA	{"email": "sokolova-yana.1969@postgrespro.ru", "phone": "+70026850225"}
0005433202692	92F009	3136 822011	MAKSIM ZHURAVLEV	{"phone": "+70867927446"}
0005433202693	BF26BA	5373 289673	VADIM SCHERBAKOV	{"phone": "+70199617424"}
0005433202694	61006E	5009 530413	GENNADIY ORLOV	{"phone": "+70275194091"}
0005433202695	3A2DFB	8258 407304	ILYA KUDRYASHOV	{"phone": "+70725053205"}
0005433202696	6F98FA	7498 510082	TATYANA FILIPPOVA	{"phone": "+70444923471"}
0005433202697	6F98FA	9973 682500	MARIYA OSIPOVA	{"email": "mariyaosipova_031958@postgrespro.ru", "phone": "+70188520964"}
0005433202698	6F98FA	8816 294329	LYUBOV NOVIKOVA	{"email": "lyubov-novikova-07041964@postgrespro.ru", "phone": "+70802543371"}
0005433202699	6F98FA	5829 984910	IVAN ANDREEV	{"email": "i.andreev-1972@postgrespro.ru", "phone": "+70986075272"}
0005433202700	57CEE7	5352 834451	OLGA SOLOVEVA	{"email": "osoloveva-1968@postgrespro.ru", "phone": "+70627520074"}
0005433202701	FE33C7	0125 196628	ALBINA ERMAKOVA	{"phone": "+70906527186"}
0005433202702	CF50E6	6559 495616	MARIYA DANILOVA	{"phone": "+70128477581"}
0005433202703	A2109D	4913 749287	NADEZHDA KUZNECOVA	{"phone": "+70567099395"}
0005433202704	73C129	8105 320876	IRINA GRISHINA	{"email": "grishina-i.1981@postgrespro.ru", "phone": "+70305700740"}
0005433202706	58125F	9150 443478	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov-25051972@postgrespro.ru", "phone": "+70160885439"}
0005433202707	2A6876	9851 944299	VLADIMIR GERASIMOV	{"phone": "+70667996246"}
0005433202708	226306	9898 133083	LILIYA PETROVA	{"phone": "+70212829149"}
0005433202709	69B654	4018 503787	RIMMA BELYAEVA	{"email": "r_belyaeva031966@postgrespro.ru", "phone": "+70551527160"}
0005433202710	4E44D7	5485 194511	VALENTINA KISELEVA	{"phone": "+70809552297"}
0005433202711	46A24F	7516 562734	NADEZHDA DENISOVA	{"phone": "+70081814820"}
0005433202712	42702B	5517 212080	OKSANA ALEKSEEVA	{"email": "alekseeva_o.06061966@postgrespro.ru", "phone": "+70644935153"}
0005433202713	860F9D	1428 130771	DMITRIY ANDREEV	{"phone": "+70770509494"}
0005433202714	B39313	8916 315607	MIKHAIL KOZLOV	{"email": "mikhail.kozlov-1993@postgrespro.ru", "phone": "+70912811936"}
0005433202715	E26461	5710 596052	TATYANA NIKIFOROVA	{"phone": "+70890052787"}
0005433202716	56FC85	7147 820023	MIKHAIL SOROKIN	{"email": "sorokin.mikhail-03031990@postgrespro.ru", "phone": "+70141326980"}
0005433202717	CDFBB2	2569 342003	ANASTASIYA KUZNECOVA	{"phone": "+70186674357"}
0005433202718	1C1866	2054 889180	SERGEY ZAKHAROV	{"phone": "+70231647680"}
0005433202719	1C1866	5946 168416	IVAN MAKAROV	{"phone": "+70319124435"}
0005433202720	96F677	6097 401357	IRINA KUZNECOVA	{"email": "i_kuznecova-051967@postgrespro.ru", "phone": "+70148463182"}
0005433202721	AC519B	0135 072492	YURIY IVANOV	{"phone": "+70331761301"}
0005433202722	AC519B	1019 995367	YURIY NOVIKOV	{"email": "ynovikov.021965@postgrespro.ru", "phone": "+70801130972"}
0005433202723	AC519B	9749 802939	VLADIMIR SOROKIN	{"email": "v_sorokin-07021973@postgrespro.ru", "phone": "+70825134005"}
0005433202724	DA6C14	0553 039621	OLGA MASLOVA	{"email": "omaslova_031980@postgrespro.ru", "phone": "+70269609190"}
0005433202725	DA6C14	9118 120151	NIKITA ZHUKOV	{"phone": "+70271850124"}
0005433202726	499874	1994 397798	ANASTASIYA FOMINA	{"email": "fomina_anastasiya_08111973@postgrespro.ru", "phone": "+70335679226"}
0005433202727	363FF0	6501 118030	FATIMA KISELEVA	{"phone": "+70357082901"}
0005433202728	766E57	5509 522286	IRINA YAKOVLEVA	{"phone": "+70433992299"}
0005433202729	6EF8C1	4167 359362	ANTONINA SCHERBAKOVA	{"email": "a.scherbakova-011976@postgrespro.ru", "phone": "+70710891975"}
0005433202730	B7CA05	6891 125551	DARYA TITOVA	{"email": "darya-titova_051979@postgrespro.ru", "phone": "+70613542007"}
0005433202731	9FECEA	5042 213316	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr-1974@postgrespro.ru", "phone": "+70593267093"}
0005433202732	515E50	3017 568501	NINA NESTEROVA	{"phone": "+70771439013"}
0005433202733	515E50	5139 441746	EKATERINA POPOVA	{"phone": "+70116392450"}
0005433202734	99704C	6234 304057	LYUDMILA MARTYNOVA	{"phone": "+70737345628"}
0005433202735	99704C	5898 306665	VIKTOR BELOV	{"email": "v_belov_05081971@postgrespro.ru", "phone": "+70763829969"}
0005433202736	DD0959	7398 265365	SVETLANA NESTEROVA	{"email": "nesterovas_1979@postgrespro.ru", "phone": "+70071122473"}
0005433202737	E97749	4412 233362	ANASTASIYA MASLOVA	{"phone": "+70641782929"}
0005433202738	E97749	6261 691914	SERGEY MATVEEV	{"email": "s.matveev.1969@postgrespro.ru", "phone": "+70623995045"}
0005433202739	3648AC	2050 080609	ARTEM STEPANOV	{"email": "stepanova101965@postgrespro.ru", "phone": "+70898750467"}
0005433202740	3648AC	8112 006232	TATYANA TIKHONOVA	{"email": "tatyana-tikhonova.1970@postgrespro.ru", "phone": "+70385762739"}
0005433202741	2D5961	3616 214770	TATYANA DAVYDOVA	{"email": "tatyana.davydova_03011973@postgrespro.ru", "phone": "+70008899780"}
0005433202742	BAF608	6111 994837	SERGEY TIMOFEEV	{"email": "timofeev.s-1969@postgrespro.ru", "phone": "+70182341675"}
0005433202743	7AEFB0	8802 185298	VALENTINA IVANOVA	{"email": "v.ivanova.15121979@postgrespro.ru", "phone": "+70827708577"}
0005433202744	7AEFB0	5965 526451	DIANA SOKOLOVA	{"email": "sokolovad-031989@postgrespro.ru", "phone": "+70286935863"}
0005433202745	E926F3	9584 488704	YURIY KOZLOV	{"email": "kozlov_y16111967@postgrespro.ru", "phone": "+70503529050"}
0005433202746	48CF48	5877 215179	TATYANA MAKAROVA	{"email": "t-makarova-051974@postgrespro.ru", "phone": "+70612850522"}
0005433202747	87C2ED	9591 031521	SOFYA SOKOLOVA	{"email": "sofya_sokolova07021977@postgrespro.ru", "phone": "+70075922991"}
0005433202748	87C2ED	0479 220598	POLINA MAKAROVA	{"email": "pmakarova15121964@postgrespro.ru", "phone": "+70489548864"}
0005433202749	842E9F	5611 805242	VALERIY DMITRIEV	{"phone": "+70974603186"}
0005433202750	4A8648	1043 042250	MARINA SEMENOVA	{"phone": "+70771910107"}
0005433202751	B7A23A	5716 187301	DMITRIY ANDREEV	{"phone": "+70313278622"}
0005433202752	DFDECD	4434 310891	TATYANA IVANOVA	{"phone": "+70914482273"}
0005433202753	D49822	2115 915960	TATYANA DANILOVA	{"email": "danilovat_1975@postgrespro.ru", "phone": "+70393015321"}
0005433202754	D49822	9814 402985	IRINA CHERNOVA	{"phone": "+70291578134"}
0005433202755	61E585	1382 961046	KIRILL ISAEV	{"phone": "+70744833404"}
0005433202756	B46276	4139 429821	GERMAN YAKOVLEV	{"email": "yakovlev_g-01071987@postgrespro.ru", "phone": "+70452514961"}
0005433202757	B46276	4291 047336	GALINA ORLOVA	{"phone": "+70872349702"}
0005433202758	914002	9475 458772	NIKOLAY ZAYCEV	{"phone": "+70029075231"}
0005433202759	64527D	2400 527294	NINA KUZNECOVA	{"email": "nina-kuznecova-051971@postgrespro.ru", "phone": "+70790010612"}
0005433202760	2537E0	1075 527402	MARIYA IVANOVA	{"email": "ivanova.m-17091977@postgrespro.ru", "phone": "+70952168209"}
0005433202761	C5663C	9844 254549	IRINA IVANOVA	{"phone": "+70014530516"}
0005433202763	4C62D5	2506 692378	LYUBOV ROMANOVA	{"phone": "+70919951178"}
0005433202764	1DA2DD	2933 063468	MARINA ZAKHAROVA	{"email": "marina-zakharova03061976@postgrespro.ru", "phone": "+70073492942"}
0005433202765	9E527E	5125 447684	KONSTANTIN TIKHONOV	{"phone": "+70403912437"}
0005433202766	9E527E	2325 419873	MIKHAIL SCHERBAKOV	{"phone": "+70327232119"}
0005433202767	9E527E	7156 447797	RUSTEM STEPANOV	{"phone": "+70097189029"}
0005433202768	50A862	8901 896166	ILYA DENISOV	{"email": "denisovilya.011974@postgrespro.ru", "phone": "+70157028620"}
0005433202769	50A862	9735 441873	POLINA ALEKSEEVA	{"email": "polinaalekseeva1979@postgrespro.ru", "phone": "+70875556238"}
0005433202770	50A862	0669 348895	IRINA KOROLEVA	{"phone": "+70458112386"}
0005433202771	CBC776	5824 042658	VYACHESLAV DENISOV	{"phone": "+70436850850"}
0005433202772	CBC776	9586 523044	SVETLANA FEDOROVA	{"email": "svetlana_fedorova-09051983@postgrespro.ru", "phone": "+70549904765"}
0005433202773	0F3D87	7184 318116	ALEKSANDR ANTONOV	{"email": "antonov_a_20041961@postgrespro.ru", "phone": "+70888463497"}
0005433202774	0E3366	5578 575589	GALINA ARKHIPOVA	{"email": "arkhipovag.061972@postgrespro.ru", "phone": "+70571762944"}
0005433202775	0E3366	7643 320290	VLADIMIR MAKAROV	{"email": "v_makarov_1970@postgrespro.ru", "phone": "+70991448522"}
0005433202776	7D0762	0814 178745	NIKOLAY POPOV	{"phone": "+70622189270"}
0005433202777	7D0762	5075 299367	VITALIY IVANOV	{"phone": "+70582520347"}
0005433202778	420FDE	4850 907331	DENIS KUZNECOV	{"email": "kuznecovd-1965@postgrespro.ru", "phone": "+70273386374"}
0005433202779	612A2E	8981 853396	LYUDMILA MATVEEVA	{"email": "l.matveeva.14031979@postgrespro.ru", "phone": "+70605286883"}
0005433202780	78FE66	7324 759326	MARIYA IVANOVA	{"email": "ivanova.mariya-08021966@postgrespro.ru", "phone": "+70295161792"}
0005433202781	78FE66	9815 245630	SERGEY ZHURAVLEV	{"email": "zhuravlev.s_1982@postgrespro.ru", "phone": "+70207081941"}
0005433202782	BA9797	9438 239047	NIKOLAY FOMIN	{"phone": "+70143786058"}
0005433202783	7AB09E	4466 591128	ALEKSANDR FROLOV	{"email": "aleksandr-frolov_1974@postgrespro.ru", "phone": "+70465855618"}
0005433202784	7AB09E	8584 887330	ELENA IVANOVA	{"email": "elenaivanova-1969@postgrespro.ru", "phone": "+70265695338"}
0005433202785	7AB09E	3659 063156	DAMIR KOZLOV	{"phone": "+70264894325"}
0005433202786	00EFE2	6881 130261	OLEG EGOROV	{"email": "oleg.egorov_22101976@postgrespro.ru", "phone": "+70165538440"}
0005433202787	00EFE2	7552 478835	TATYANA MAKSIMOVA	{"email": "maksimovat_26121954@postgrespro.ru", "phone": "+70794046585"}
0005433202788	1D8E80	7282 399687	PAVEL MATVEEV	{"email": "matveev.pavel_111986@postgrespro.ru", "phone": "+70714499540"}
0005433202789	467B0D	3852 397137	GALINA IVANOVA	{"email": "galina-ivanova_23111975@postgrespro.ru", "phone": "+70644150976"}
0005433202790	467B0D	4763 666848	SERGEY ALEKSANDROV	{"phone": "+70085606477"}
0005433202791	4BDA0D	1048 870349	OLEG BELOV	{"email": "oleg-belov-051984@postgrespro.ru", "phone": "+70453189046"}
0005433202792	4BDA0D	7430 298344	NIKOLAY POPOV	{"email": "popovnikolay-1965@postgrespro.ru", "phone": "+70222937439"}
0005433202793	4427D1	4232 740888	VALERIYA ZOTOVA	{"phone": "+70635745632"}
0005433202794	4427D1	9247 470995	IRINA STEPANOVA	{"email": "stepanovai-07071974@postgrespro.ru", "phone": "+70619705927"}
0005433202795	08D190	0578 847190	MAKSIM GORBUNOV	{"email": "gorbunov.m1975@postgrespro.ru", "phone": "+70676319969"}
0005433202796	64D165	3476 063836	TATYANA KONOVALOVA	{"email": "konovalova.t-041974@postgrespro.ru", "phone": "+70135944622"}
0005433202797	64D165	0362 930831	NIKOLAY FOMIN	{"phone": "+70177090989"}
0005433202798	C79C9D	0074 546711	VALENTINA ERMAKOVA	{"email": "vermakova-091960@postgrespro.ru", "phone": "+70162105364"}
0005433202799	C79C9D	6895 512530	VLADIMIR MATVEEV	{"email": "v_matveev-041973@postgrespro.ru", "phone": "+70961495678"}
0005433233080	B722D3	4385 933082	GALINA KRASNOVA	{"email": "g.krasnova_1979@postgrespro.ru", "phone": "+70064312857"}
0005433233081	B722D3	1153 009320	ELIZAVETA SERGEEVA	{"phone": "+70072821434"}
0005433233082	21C7BD	4842 074348	YURIY VASILEV	{"email": "vasilev_y-031973@postgrespro.ru", "phone": "+70646621445"}
0005433233083	21C7BD	2992 962999	ANNA LUKYANOVA	{"phone": "+70520794641"}
0005433233084	731475	6137 942834	TAMARA NAUMOVA	{"email": "naumova-tamara-17021978@postgrespro.ru", "phone": "+70100852700"}
0005433233085	731475	4645 883688	ELMIRA KUZNECOVA	{"phone": "+70744673894"}
0005433233086	96359F	2127 040775	VLADIMIR SHEVCHENKO	{"phone": "+70993247106"}
0005433233087	9F4B2F	5127 231900	ALEKSANDR BARANOV	{"email": "baranov_aleksandr16111968@postgrespro.ru", "phone": "+70422499656"}
0005433233088	3A03AD	8787 007943	MARINA ROMANOVA	{"phone": "+70058843078"}
0005433233089	3A03AD	7842 972835	LYUDMILA ISAEVA	{"email": "isaeva.l30081967@postgrespro.ru", "phone": "+70748160740"}
0005433233090	A276BA	0935 226480	ANTONINA LEBEDEVA	{"phone": "+70210993174"}
0005433233091	FFBC14	4575 707377	OLEG ABRAMOV	{"phone": "+70399360181"}
0005433233092	C988F5	9429 389462	ANNA GORBUNOVA	{"phone": "+70391529219"}
0005433233093	1A1E37	6667 355346	MARIYA MAKSIMOVA	{"phone": "+70576869269"}
0005433233094	1218B6	2361 581467	ZINAIDA NAZAROVA	{"email": "zinaida-nazarova.06081964@postgrespro.ru", "phone": "+70076247504"}
0005433233095	1218B6	3242 423038	SERGEY RODIONOV	{"phone": "+70942584443"}
0005433233096	9562AC	4913 481427	IVAN KAZAKOV	{"email": "kazakov.ivan-1971@postgrespro.ru", "phone": "+70333266214"}
0005433233097	CF4372	0948 011983	MARINA YUDINA	{"email": "m-yudina-081967@postgrespro.ru", "phone": "+70333595885"}
0005433233098	CF4372	0438 228620	ELENA KUZMINA	{"phone": "+70732265835"}
0005433233099	3622D7	4457 452919	IRINA TARASOVA	{"email": "tarasovai.11061950@postgrespro.ru", "phone": "+70411285600"}
0005433233100	3622D7	5919 512338	ANDREY KRASNOV	{"phone": "+70139145525"}
0005433233101	A92661	7269 006405	LYUBOV OSIPOVA	{"phone": "+70738906754"}
0005433233102	A92661	6554 971171	NIKOLAY MAKAROV	{"phone": "+70141698825"}
0005433233103	C11AB1	5176 439140	NIKITA NIKITIN	{"email": "nikita.nikitin_1977@postgrespro.ru", "phone": "+70843375125"}
0005433233104	5B3B1E	5117 214334	VYACHESLAV ORLOV	{"phone": "+70535366326"}
0005433233105	76F212	3672 682369	ANZHELA ABRAMOVA	{"email": "abramovaa_01011972@postgrespro.ru", "phone": "+70144901381"}
0005433233106	76F212	8648 341110	NATALYA MELNIKOVA	{"email": "n.melnikova071960@postgrespro.ru", "phone": "+70248104359"}
0005433233107	BE50E6	8236 458333	DARYA LUKYANOVA	{"email": "darya-lukyanova1978@postgrespro.ru", "phone": "+70766177509"}
0005433233108	61A923	6676 782239	ALIYA PAVLOVA	{"email": "pavlova_a15101962@postgrespro.ru", "phone": "+70912902957"}
0005433233109	61A923	2125 958586	ALEKSANDR NIKOLAEV	{"phone": "+70377647031"}
0005433233110	66A469	9626 335915	VERONIKA POPOVA	{"phone": "+70474360227"}
0005433233111	D38219	6013 118945	ELENA KONDRATEVA	{"email": "elena_kondrateva1975@postgrespro.ru", "phone": "+70313686443"}
0005433233112	D38219	1020 996656	OLGA LUKYANOVA	{"phone": "+70662652616"}
0005433233113	71407C	6223 192677	ARTEM MARTYNOV	{"phone": "+70076080285"}
0005433233114	71407C	5954 655259	ANDREY IVANOV	{"email": "andrey.ivanov_1968@postgrespro.ru", "phone": "+70608093347"}
0005433233115	E4BBD2	0506 198455	VALERIYA NIKOLAEVA	{"email": "valeriya_nikolaeva-1974@postgrespro.ru", "phone": "+70178732306"}
0005433233116	3B214B	3940 933335	ANTONINA MOROZOVA	{"phone": "+70938175001"}
0005433233117	6FA69B	9589 032976	BOGDAN SOROKIN	{"phone": "+70855348762"}
0005433233118	521454	2297 613580	SERGEY OSIPOV	{"email": "osipov.s_27081975@postgrespro.ru", "phone": "+70474796199"}
0005433233119	521454	9257 734506	STANISLAV KOZLOV	{"email": "stanislav_kozlov.081976@postgrespro.ru", "phone": "+70058967261"}
0005433233120	ABA0B0	4580 472396	NIKOLAY IVANOV	{"phone": "+70241209651"}
0005433233121	244CF7	9985 589834	DENIS MEDVEDEV	{"email": "d.medvedev091972@postgrespro.ru", "phone": "+70689591033"}
0005433233122	244CF7	1175 653336	DMITRIY MELNIKOV	{"phone": "+70674308665"}
0005433233123	E9AAB1	6598 549289	TATYANA KULIKOVA	{"phone": "+70395721929"}
0005433233124	E9AAB1	0255 880689	NIKOLAY ILIN	{"email": "n-ilin-25011972@postgrespro.ru", "phone": "+70496278061"}
0005433233125	E9AAB1	1126 702123	MIKHAIL KUDRYASHOV	{"phone": "+70556891525"}
0005433233126	E9AAB1	1940 340093	KSENIYA MIKHAYLOVA	{"email": "mikhaylova_k_1953@postgrespro.ru", "phone": "+70497950901"}
0005433233127	773D6F	7199 906864	YURIY DAVYDOV	{"phone": "+70028054863"}
0005433233128	1A4652	2621 841913	SERGEY ISAEV	{"phone": "+70603500843"}
0005433233129	BD48A8	5114 889331	ZOYA NIKITINA	{"email": "nikitinaz.22101967@postgrespro.ru", "phone": "+70796202984"}
0005433233130	90EA3E	1956 978546	ALEKSANDR ANDREEV	{"email": "andreev-a-07111972@postgrespro.ru", "phone": "+70036760713"}
0005433233131	90EA3E	2539 947965	ALEKSEY FROLOV	{"phone": "+70434988941"}
0005433233132	3BDAEA	8044 636366	PAVEL IVANOV	{"email": "p_ivanov_1959@postgrespro.ru", "phone": "+70855154570"}
0005433233133	3BDAEA	2478 424391	ANNA KUZMINA	{"email": "kuzminaanna-1973@postgrespro.ru", "phone": "+70669024834"}
0005433233134	3BDAEA	3493 769162	ANATOLIY ZAKHAROV	{"phone": "+70962437570"}
0005433233135	68750D	1325 432215	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev.13081965@postgrespro.ru", "phone": "+70196223554"}
0005433233136	AD9177	1394 885380	IRINA NESTEROVA	{"phone": "+70645013689"}
0005433233137	08E85B	3863 945475	GALINA SCHERBAKOVA	{"phone": "+70512587878"}
0005433233138	08E85B	9384 849621	MARINA MELNIKOVA	{"phone": "+70083110212"}
0005433233139	6FB427	6336 444746	VERA SMIRNOVA	{"phone": "+70594411744"}
0005433233140	885C3C	0103 204604	ALEKSEY NIKOLAEV	{"phone": "+70812277203"}
0005433233141	885C3C	0834 710157	OLGA VOLKOVA	{"email": "o.volkova_29091981@postgrespro.ru", "phone": "+70779359991"}
0005433233142	C0994C	7552 494460	VASILIY STEPANOV	{"phone": "+70926734391"}
0005433233143	3ED68E	9574 001889	VIKTOR SIDOROV	{"email": "v-sidorov-19091977@postgrespro.ru", "phone": "+70789249183"}
0005433233144	BF2656	1187 040145	YULIYA POPOVA	{"email": "y-popova-23061966@postgrespro.ru", "phone": "+70450257535"}
0005433233145	DB2204	4629 252045	ALEKSANDR ALEKSEEV	{"email": "aalekseev.101976@postgrespro.ru", "phone": "+70297657880"}
0005433233146	C71023	8452 159438	LYUBOV NIKOLAEVA	{"email": "lyubov-nikolaeva-25081972@postgrespro.ru", "phone": "+70048061146"}
0005433233147	EEC84B	2228 454366	VARVARA FILIPPOVA	{"email": "varvara_filippova.021983@postgrespro.ru", "phone": "+70993527485"}
0005433233148	98D73C	6994 555460	SERGEY ALEKSEEV	{"phone": "+70707292678"}
0005433233149	98D73C	7107 930503	DANIL STEPANOV	{"phone": "+70475034977"}
0005433233150	FB7C6C	6757 267941	NIKOLAY SHEVCHENKO	{"phone": "+70632549580"}
0005433233151	1F0D25	9456 375661	ALINA LEBEDEVA	{"email": "a.lebedeva-13041969@postgrespro.ru", "phone": "+70678450185"}
0005433233152	BA8517	3708 991204	KIRILL AFANASEV	{"email": "kirillafanasev1979@postgrespro.ru", "phone": "+70041990167"}
0005433233153	BA8517	4040 391406	ELENA MELNIKOVA	{"email": "melnikova_elena.1972@postgrespro.ru", "phone": "+70445716480"}
0005433233154	C9A186	4151 193532	OLEG POPOV	{"phone": "+70562035146"}
0005433233155	C9A186	7656 551968	KIRA GAVRILOVA	{"phone": "+70985879558"}
0005433233156	4445D9	7059 955572	YULIYA GUSEVA	{"email": "guseva.yuliya.11041972@postgrespro.ru", "phone": "+70423750890"}
0005433233157	178DEA	1855 697304	YULIYA GRISHINA	{"phone": "+70374627305"}
0005433233158	178DEA	9888 934283	VLADIMIR FEDOROV	{"phone": "+70495621661"}
0005433233159	419A20	8429 671565	TAISIYA GAVRILOVA	{"email": "gavrilova.taisiya.1971@postgrespro.ru", "phone": "+70823241290"}
0005433233160	419A20	7607 002276	MAKSIM MAKSIMOV	{"email": "maksimov-maksim-061977@postgrespro.ru", "phone": "+70001268351"}
0005433233161	7C5FA0	1650 946447	ALEKSEY VASILEV	{"email": "vasilev.a.26101963@postgrespro.ru", "phone": "+70105238176"}
0005433233162	5A5F26	2840 764874	ANDREY KOROLEV	{"phone": "+70005919696"}
0005433233163	6FECD6	2677 311071	GALINA YAKOVLEVA	{"phone": "+70520211860"}
0005433233164	D92A38	2437 360243	TAMARA KOROLEVA	{"phone": "+70448989354"}
0005433233165	D92A38	5574 780355	ZHANNA IVANOVA	{"email": "ivanova_zhanna-14101973@postgrespro.ru", "phone": "+70490599292"}
0005433233166	1EF25F	4898 576884	VLADIMIR ALEKSANDROV	{"email": "aleksandrovv-071966@postgrespro.ru", "phone": "+70338624977"}
0005433233167	1EF25F	4336 142879	LYUDMILA MEDVEDEVA	{"email": "medvedeva-lyudmila_14041964@postgrespro.ru", "phone": "+70183846865"}
0005433233168	86AD8C	8562 265829	MIKHAIL KUDRYASHOV	{"email": "kudryashov-mikhail.1972@postgrespro.ru", "phone": "+70245938100"}
0005433233169	7932CC	8394 843479	ANNA FILIPPOVA	{"email": "filippovaanna091974@postgrespro.ru", "phone": "+70407005951"}
0005433233170	7932CC	6822 337327	MARIYA BELYAEVA	{"phone": "+70488325942"}
0005433233171	EF466A	5780 273667	VIKTOR KUZMIN	{"email": "v.kuzmin.021975@postgrespro.ru", "phone": "+70146195981"}
0005433233172	6E8828	7512 822433	NELLYA KOLESNIKOVA	{"email": "kolesnikova_nellya1974@postgrespro.ru", "phone": "+70734822363"}
0005433233173	DBD721	7551 054852	GRIGORIY PETROV	{"phone": "+70529152421"}
0005433233174	DAD8D0	5903 763609	ALEKSANDR ZHUKOV	{"phone": "+70016592573"}
0005433233175	2D3BB8	4547 129164	SERGEY TIMOFEEV	{"email": "sergey-timofeev.1966@postgrespro.ru", "phone": "+70804430071"}
0005433233176	6B2C43	9504 662190	IRINA ERMAKOVA	{"phone": "+70555106099"}
0005433233177	DB8AAA	6603 663844	SOFYA SEMENOVA	{"phone": "+70630777856"}
0005433233178	E53B10	3121 033876	VLADA SOLOVEVA	{"phone": "+70834117340"}
0005433233179	85553F	2969 710623	DIANA KOMAROVA	{"email": "komarova_d_01101975@postgrespro.ru", "phone": "+70613331921"}
0005433233180	C2AD4E	9353 283138	VLADIMIR RODIONOV	{"phone": "+70870037346"}
0005433233181	A757F7	6570 979897	VLADIMIR SOLOVEV	{"phone": "+70647908410"}
0005433233182	C82A75	8217 327161	NATALIYA POPOVA	{"phone": "+70618246454"}
0005433233183	C82A75	3391 585069	IRINA MASLOVA	{"email": "maslova_irina_011991@postgrespro.ru", "phone": "+70265827736"}
0005433233184	E6838A	7985 555835	TAMARA NIKITINA	{"phone": "+70536427521"}
0005433233185	E89D85	6813 391444	EVGENIY SOKOLOV	{"email": "sokolov.evgeniy1977@postgrespro.ru", "phone": "+70120821269"}
0005433233186	B8C059	3153 231020	NADEZHDA ALEKSEEVA	{"email": "alekseeva-nadezhda.101978@postgrespro.ru", "phone": "+70780627058"}
0005433233187	595963	4088 580889	KIRILL SMIRNOV	{"email": "smirnovkirill-1963@postgrespro.ru", "phone": "+70928613610"}
0005433233188	9B3C78	9747 731013	EVGENIY IVANOV	{"phone": "+70968831416"}
0005433233189	9B3C78	5383 574761	PAVEL NOVIKOV	{"email": "p.novikov-1970@postgrespro.ru", "phone": "+70043282607"}
0005433233190	659D21	8175 584617	EVGENIY MEDVEDEV	{"email": "medvedev-e-091973@postgrespro.ru", "phone": "+70850157430"}
0005433233191	6B5E6B	1471 420108	TATYANA NIKOLAEVA	{"email": "t.nikolaeva.1980@postgrespro.ru", "phone": "+70889969031"}
0005433233192	419C8F	9726 323184	PELAGEYA KUZNECOVA	{"phone": "+70508978037"}
0005433233193	419C8F	4334 642198	TATYANA MAKAROVA	{"email": "tatyanamakarova1966@postgrespro.ru", "phone": "+70302858851"}
0005433233194	6DC69B	3593 175508	SERGEY KUZNECOV	{"email": "kuznecov.sergey-05021969@postgrespro.ru", "phone": "+70820148661"}
0005433233195	FB53CF	0865 451699	NINA SEMENOVA	{"email": "n.semenova28061966@postgrespro.ru", "phone": "+70017790327"}
0005433233196	DABCAE	2497 405420	NINA ZHURAVLEVA	{"email": "zhuravleva.nina.1969@postgrespro.ru", "phone": "+70042859009"}
0005433233197	B23651	9573 720749	VASILIY MATVEEV	{"phone": "+70632903194"}
0005433233198	A1DC23	9642 660292	MARINA SOKOLOVA	{"email": "sokolova.marina-29101975@postgrespro.ru", "phone": "+70542129246"}
0005433233199	AC2BD4	7343 677660	ANDREY FEDOTOV	{"email": "andrey.fedotov.1965@postgrespro.ru", "phone": "+70847130061"}
0005433233200	DCD135	6736 461219	NIKOLAY NAUMOV	{"email": "nikolaynaumov.1978@postgrespro.ru", "phone": "+70786425001"}
0005433233201	0DCA7E	8470 110865	ANGELINA BOGDANOVA	{"phone": "+70128098869"}
0005433233202	E92ECA	8672 412973	ILYA OSIPOV	{"email": "osipovilya.021963@postgrespro.ru", "phone": "+70842682767"}
0005433233203	DC09BA	8459 920515	ELENA ANDREEVA	{"email": "andreevaelena111968@postgrespro.ru", "phone": "+70753420229"}
0005433233204	901C98	2244 332844	LYUBOV NIKOLAEVA	{"email": "lyubov-nikolaeva_25041965@postgrespro.ru", "phone": "+70382358848"}
0005433233205	A67A0F	4356 690078	MAYYA AKIMOVA	{"phone": "+70847816772"}
0005433233206	072704	6949 514326	EKATERINA FROLOVA	{"email": "e.frolova.1980@postgrespro.ru", "phone": "+70394470140"}
0005433233207	5C12A6	3995 581712	OLGA ZHURAVLEVA	{"phone": "+70504433343"}
0005433233208	C562A5	4618 427601	ELENA POLYAKOVA	{"email": "e-polyakova_22121967@postgrespro.ru", "phone": "+70958322033"}
0005433233209	A84D3E	2717 627668	GALINA POLYAKOVA	{"phone": "+70477964772"}
0005433233210	122F35	1431 807943	ELENA KUZMINA	{"email": "kuzmina.e-1966@postgrespro.ru", "phone": "+70553997590"}
0005433233211	E04DF5	1753 594377	OKSANA KOZLOVA	{"phone": "+70358132749"}
0005433233212	E04DF5	8299 951725	LYUDMILA ROMANOVA	{"email": "romanova-l_051974@postgrespro.ru", "phone": "+70870723702"}
0005433233213	B54FC2	5775 288362	OLGA STEPANOVA	{"email": "stepanova.o021979@postgrespro.ru", "phone": "+70273430480"}
0005433233214	E2908D	4722 829274	ARINA KULIKOVA	{"phone": "+70999459768"}
0005433233215	AA1561	0166 791522	OLGA MALYSHEVA	{"phone": "+70715371277"}
0005433233216	4E5684	9948 720212	VASILIY KAZAKOV	{"email": "kazakov_v-1967@postgrespro.ru", "phone": "+70326301851"}
0005433233217	4E5684	7432 872732	SERGEY MIRONOV	{"email": "mironov-s.26121968@postgrespro.ru", "phone": "+70473286634"}
0005433233218	7D8216	4089 786480	OLGA VOLKOVA	{"phone": "+70791765564"}
0005433233219	7D8216	0950 651947	MARIYA SIDOROVA	{"phone": "+70079907580"}
0005433233220	B0DE37	5821 051116	VIKTORIYA IVANOVA	{"phone": "+70350151730"}
0005433233221	B0DE37	9789 074235	ALINA LAZAREVA	{"email": "lazareva_a-041973@postgrespro.ru", "phone": "+70175439648"}
0005433233222	B0DE37	1208 332980	YULIYA ANDREEVA	{"phone": "+70313748222"}
0005433233223	6AFF7D	4893 576467	IRINA TARASOVA	{"phone": "+70502102076"}
0005433233224	6AFF7D	9626 312177	NAILYA BORISOVA	{"phone": "+70746952915"}
0005433233225	3F786D	3703 634062	SVETLANA LAZAREVA	{"phone": "+70456736493"}
0005433233226	60E395	0417 908538	ROBERT ZAKHAROV	{"phone": "+70415211537"}
0005433233227	60E395	1357 868811	ANASTASIYA MAKSIMOVA	{"phone": "+70901632526"}
0005433233228	B3214F	6009 121634	ARTUR KUZNECOV	{"email": "kuznecov-artur-101968@postgrespro.ru", "phone": "+70755289584"}
0005433233229	B3214F	1603 400936	NIKOLAY IVANOV	{"phone": "+70265593419"}
0005433233230	5E3478	9438 167150	ROMAN ANTONOV	{"phone": "+70569401135"}
0005433233231	5E3478	7967 407579	SVETLANA SOROKINA	{"phone": "+70970681182"}
0005433233232	2ACCFB	8984 162308	YULIYA ANTONOVA	{"email": "antonova-y-051967@postgrespro.ru", "phone": "+70735318947"}
0005433233233	821A24	1440 352892	MAKSIM MOROZOV	{"email": "m_morozov-17061973@postgrespro.ru", "phone": "+70892358830"}
0005433233234	821A24	6112 410262	NATALYA KISELEVA	{"email": "kiseleva-n121965@postgrespro.ru", "phone": "+70609813990"}
0005433233235	A09B3D	4633 890430	LARISA FROLOVA	{"email": "frolova.larisa.121976@postgrespro.ru", "phone": "+70551768400"}
0005433233236	A82E29	9098 324280	NADEZHDA ANTONOVA	{"email": "nantonova1964@postgrespro.ru", "phone": "+70980508352"}
0005433233237	D6D103	6534 550219	EKATERINA ANDREEVA	{"email": "ekaterinaandreeva_06021969@postgrespro.ru", "phone": "+70359592888"}
0005433233238	49FB41	3749 768235	OLESYA RYABOVA	{"email": "olesya_ryabova11011980@postgrespro.ru", "phone": "+70440246726"}
0005433233239	5D49EA	3729 145308	IRINA EGOROVA	{"phone": "+70183326641"}
0005433233240	036143	1369 856894	VALERIY KARPOV	{"email": "karpovv.1969@postgrespro.ru", "phone": "+70459941700"}
0005433233241	036143	1526 470097	VALENTINA OSIPOVA	{"email": "osipova-valentina-1962@postgrespro.ru", "phone": "+70649920225"}
0005433233242	279615	9202 979289	IVAN SCHERBAKOV	{"phone": "+70875470306"}
0005433233243	42E360	5158 375476	VERA KUZNECOVA	{"phone": "+70193313405"}
0005433233244	68615E	9282 332454	OLEG MIKHAYLOV	{"email": "mikhaylov-o_031980@postgrespro.ru", "phone": "+70728331840"}
0005433233245	097E42	1111 171088	NIKOLAY POPOV	{"phone": "+70836305442"}
0005433233246	28CDDF	6215 904801	ANNA KOROLEVA	{"email": "anna-koroleva_071967@postgrespro.ru", "phone": "+70270024032"}
0005433233247	55171E	3217 013068	GENNADIY KUZMIN	{"phone": "+70900591256"}
0005433233248	7C97D5	0115 473473	MARIYA EFREMOVA	{"email": "mefremova-071979@postgrespro.ru", "phone": "+70858815325"}
0005433233249	6975AA	8823 654284	VALENTINA PAVLOVA	{"email": "v_pavlova17051984@postgrespro.ru", "phone": "+70664257712"}
0005433233250	6975AA	8489 089752	NADEZHDA IVANOVA	{"email": "nadezhdaivanova-061980@postgrespro.ru", "phone": "+70072836068"}
0005433233251	77F676	6145 108971	MARIYA MARTYNOVA	{"email": "martynova_m.101974@postgrespro.ru", "phone": "+70222445648"}
0005433233252	F6C661	6137 757580	STANISLAV ILIN	{"phone": "+70901714160"}
0005433233253	30B38E	8890 025950	SERGEY NAZAROV	{"phone": "+70660830461"}
0005433233254	9E8C82	0440 256248	ALEKSEY MIRONOV	{"phone": "+70809521621"}
0005433233255	9E8C82	5452 758537	ANDREY DAVYDOV	{"phone": "+70144717741"}
0005433233256	D4F83B	0261 959230	VIKTOR KUZNECOV	{"phone": "+70071694919"}
0005433233257	4CE7E6	6816 853745	MARIYA FROLOVA	{"email": "frolova.mariya-07021983@postgrespro.ru", "phone": "+70803875016"}
0005433233258	4CE7E6	4451 362054	SERGEY KULIKOV	{"phone": "+70736496723"}
0005433233259	C11A10	4285 969956	ANASTASIYA GUSEVA	{"email": "a_guseva_1974@postgrespro.ru", "phone": "+70520983181"}
0005433233260	D19C46	4073 658202	GALINA PAVLOVA	{"email": "pavlovagalina_101977@postgrespro.ru", "phone": "+70149382284"}
0005433233261	D19C46	0694 012389	ELENA IVANOVA	{"phone": "+70584364944"}
0005433233262	F87223	4477 928397	OLGA KOMAROVA	{"phone": "+70815419800"}
0005433233263	F87223	1323 333070	SVETLANA MOROZOVA	{"email": "morozovasvetlana.1973@postgrespro.ru", "phone": "+70904285145"}
0005433233264	F8C412	8515 864837	RAISA NIKITINA	{"email": "nikitina_raisa-1974@postgrespro.ru", "phone": "+70679481506"}
0005433233265	184AF0	7412 555421	DMITRIY KULIKOV	{"email": "kulikov_dmitriy_08111977@postgrespro.ru", "phone": "+70425206091"}
0005433233266	23FB21	7588 733976	ELENA NIKOLAEVA	{"phone": "+70885618145"}
0005433233267	F1C83E	5126 412342	OLGA PETROVA	{"email": "olgapetrova031980@postgrespro.ru", "phone": "+70723477101"}
0005433233268	E2F6FF	6094 823701	YULIYA FROLOVA	{"email": "frolova.y1970@postgrespro.ru", "phone": "+70015728571"}
0005433233269	08F111	8447 279069	ALEKSEY DENISOV	{"phone": "+70312028734"}
0005433233270	08F111	2811 948843	EKATERINA PETROVA	{"phone": "+70228960649"}
0005433233271	A8B6B4	2835 036120	IGOR SOROKIN	{"email": "igor-sorokin15041971@postgrespro.ru", "phone": "+70324309032"}
0005433233272	A8B6B4	2992 973918	VLADIMIR EGOROV	{"phone": "+70068604885"}
0005433233273	0F176A	2004 682981	ALENA POPOVA	{"phone": "+70645834586"}
0005433233274	A17E74	3555 522243	IRINA SIDOROVA	{"phone": "+70454288721"}
0005433233275	2D2548	8602 994217	OLGA SMIRNOVA	{"phone": "+70409545568"}
0005433233276	EEBBB8	6435 507085	ILYA IVANOV	{"phone": "+70523958776"}
0005433233277	428EF1	2989 832541	DENIS MAKAROV	{"phone": "+70477177198"}
0005433233278	51888F	2920 347535	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr_31031970@postgrespro.ru", "phone": "+70483647652"}
0005433233279	F56F01	2578 708599	TAMARA ARKHIPOVA	{"phone": "+70780719872"}
0005433233280	F56F01	5054 025527	NADEZHDA TITOVA	{"phone": "+70280151326"}
0005433233281	A9DC92	2470 307900	ALEKSEY AFANASEV	{"email": "afanasev.aleksey.1973@postgrespro.ru", "phone": "+70483722225"}
0005433233282	E99179	0250 693963	VIKTORIYA MOROZOVA	{"email": "morozova-v_1983@postgrespro.ru", "phone": "+70672250106"}
0005433233283	E99179	9774 743380	GRIGORIY MATVEEV	{"phone": "+70210874941"}
0005433233284	DC8206	2843 146281	ALEKSANDR ALEKSANDROV	{"phone": "+70412195969"}
0005433233285	409E8E	7852 272319	ARTEM AFANASEV	{"email": "artem.afanasev_071972@postgrespro.ru", "phone": "+70268132840"}
0005433233286	409E8E	1369 245895	MARIYA EFIMOVA	{"email": "mariyaefimova_121968@postgrespro.ru", "phone": "+70524444880"}
0005433233287	0FC03A	0612 981312	EGOR GAVRILOV	{"phone": "+70193846273"}
0005433233288	0AE568	6472 854404	RADIK KRASNOV	{"phone": "+70706555107"}
0005433233289	F37892	2782 744718	SERGEY FEDOROV	{"phone": "+70110794358"}
0005433233290	583D9F	7820 895430	STEPAN DMITRIEV	{"phone": "+70832512689"}
0005433233291	D5CE2A	1659 379934	VERONIKA TARASOVA	{"phone": "+70737808758"}
0005433233292	D5CE2A	0524 911148	LILIYA IVANOVA	{"email": "liliya.ivanova_1972@postgrespro.ru", "phone": "+70632362863"}
0005433233293	743FBC	4249 954341	NADEZHDA KUZNECOVA	{"phone": "+70538741956"}
0005433233294	F97D93	6470 148029	LYUBOV NAZAROVA	{"email": "lyubovnazarova1973@postgrespro.ru", "phone": "+70173794078"}
0005433233295	41B36D	4707 747655	VIKTORIYA YUDINA	{"phone": "+70790828379"}
0005433233296	F91DF5	6767 515659	VIKTOR SOROKIN	{"email": "sorokin-viktor-041975@postgrespro.ru", "phone": "+70130312862"}
0005433233297	4FD75B	0036 592173	LYUDMILA PETROVA	{"phone": "+70333194743"}
0005433233298	1CC7C1	5678 413888	VIKTOR VLASOV	{"email": "vlasov.v.011971@postgrespro.ru", "phone": "+70649263982"}
0005433233299	16D21A	4526 412116	ALEKSEY MIKHAYLOV	{"email": "aleksey-mikhaylov_25121980@postgrespro.ru", "phone": "+70041310455"}
0005433233300	470DA7	8569 421000	KIRILL KUZNECOV	{"phone": "+70857815855"}
0005433233301	470DA7	8079 405145	VLADIMIR VOROBEV	{"email": "vvorobev-26101982@postgrespro.ru", "phone": "+70818996166"}
0005433233302	6688A9	9851 659176	IVAN ROMANOV	{"email": "romanov.ivan-22011972@postgrespro.ru", "phone": "+70939342227"}
0005433233303	D1CE91	0091 323930	NIKOLAY NIKITIN	{"phone": "+70714687330"}
0005433233304	D1CE91	8821 518878	IGOR MELNIKOV	{"email": "melnikov-i.081973@postgrespro.ru", "phone": "+70949263781"}
0005433233305	D1CE91	5772 075437	TATYANA KOZLOVA	{"phone": "+70253942654"}
0005433233306	9BE27F	9713 650920	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova-anastasiya.091977@postgrespro.ru", "phone": "+70171266644"}
0005433233307	C84A73	9616 689759	TATYANA BORISOVA	{"email": "borisova-t_031971@postgrespro.ru", "phone": "+70297581562"}
0005433233308	1CB35E	7794 862672	MAKSIM ZHURAVLEV	{"phone": "+70793280785"}
0005433233309	26A710	0591 602398	NIKOLAY ALEKSEEV	{"email": "alekseev_n011975@postgrespro.ru", "phone": "+70278977032"}
0005433233310	B8A825	5455 266436	EKATERINA SOROKINA	{"phone": "+70601883490"}
0005433233311	B8A825	3733 088156	MIKHAIL KUZNECOV	{"phone": "+70097660827"}
0005433233312	32E6CA	8657 826260	TATYANA IVANOVA	{"email": "t-ivanova1961@postgrespro.ru", "phone": "+70197431968"}
0005433233313	A4B0B4	7118 878848	YULIYA SERGEEVA	{"email": "sergeeva.yuliya_1972@postgrespro.ru", "phone": "+70000484759"}
0005433233314	A4B0B4	6468 264937	ZLATA PETROVA	{"phone": "+70392188797"}
0005433233315	E3F286	5531 544408	VALENTIN MATVEEV	{"phone": "+70895692063"}
0005433233316	E295BF	8954 497572	ZOYA MAKAROVA	{"phone": "+70433718062"}
0005433233317	E295BF	1900 838106	MARIYA KOROLEVA	{"phone": "+70483114309"}
0005433233318	6B458F	1717 507272	SERGEY SERGEEV	{"phone": "+70254427353"}
0005433233319	AA1C1C	1127 754674	IRINA ORLOVA	{"phone": "+70827152211"}
0005433233320	AA1C1C	9874 658006	VIKTORIYA NIKITINA	{"email": "nikitinav.111972@postgrespro.ru", "phone": "+70466967923"}
0005433233321	64AC95	6644 491779	VERA ZHUKOVA	{"phone": "+70165690809"}
0005433233322	64AC95	1151 831002	VALENTINA PETROVA	{"email": "petrova_valentina16121967@postgrespro.ru", "phone": "+70158506571"}
0005433233323	64AC95	3142 159677	VALENTINA KONDRATEVA	{"email": "valentinakondrateva11111970@postgrespro.ru", "phone": "+70890246652"}
0005433233324	C4AAA3	6185 871063	ARTUR SEMENOV	{"email": "semenovartur1974@postgrespro.ru", "phone": "+70752247590"}
0005433233325	F3B1BE	6780 817368	ALEKSANDR SIDOROV	{"phone": "+70622633265"}
0005433233326	703CC8	5647 045276	TAMARA MIRONOVA	{"email": "mironova_t-15091973@postgrespro.ru", "phone": "+70271319954"}
0005433233327	001A9F	8416 965777	YURIY KISELEV	{"email": "kiselev-yuriy081962@postgrespro.ru", "phone": "+70364003530"}
0005433233328	81CC75	9546 969464	TIGRAN ZAKHAROV	{"email": "t_zakharov_13091968@postgrespro.ru", "phone": "+70402831016"}
0005433233329	81CC75	9156 380478	MARGARITA YAKOVLEVA	{"email": "yakovlevam-1968@postgrespro.ru", "phone": "+70534689556"}
0005433233330	0DF67C	9261 096012	LYUBOV MIKHAYLOVA	{"email": "mikhaylova_lyubov.071977@postgrespro.ru", "phone": "+70147561364"}
0005433233331	0DF67C	4162 014617	IVAN KUZNECOV	{"phone": "+70099514302"}
0005433233332	E21896	7949 169665	ELENA GRISHINA	{"phone": "+70853222902"}
0005433233333	5C4E33	3456 640063	LYUBOV TIKHONOVA	{"email": "l_tikhonova.1978@postgrespro.ru", "phone": "+70156185912"}
0005433233334	5C4E33	7998 020267	IVAN POPOV	{"email": "i-popov071969@postgrespro.ru", "phone": "+70864973190"}
0005433233335	50597C	0212 101201	ARTEM TARASOV	{"email": "tarasov-a_10051970@postgrespro.ru", "phone": "+70235816163"}
0005433233336	6E0899	9069 245805	LEONID OSIPOV	{"email": "osipov_leonid-1967@postgrespro.ru", "phone": "+70449502762"}
0005433233337	C0B859	9936 887125	VLADIMIR PETROV	{"email": "petrov-vladimir-021973@postgrespro.ru", "phone": "+70417919299"}
0005433233338	C0B859	4764 337069	OLGA ZHURAVLEVA	{"phone": "+70367352939"}
0005433233339	60FC07	1683 710807	LYUBOV KULIKOVA	{"email": "kulikova_l-071972@postgrespro.ru", "phone": "+70812041483"}
0005433233340	E9E518	1832 777499	NIKOLAY KAZAKOV	{"phone": "+70540796401"}
0005433233341	E9E518	1065 068065	ALEKSANDR RODIONOV	{"email": "rodionov.aleksandr1967@postgrespro.ru", "phone": "+70906728379"}
0005433233342	38D655	4558 609502	LYUDMILA KONOVALOVA	{"email": "lyudmila_konovalova.051972@postgrespro.ru", "phone": "+70421148512"}
0005433233343	38D655	5277 143146	PETR VASILEV	{"phone": "+70543916470"}
0005433233344	D92CB5	8186 725518	VYACHESLAV GAVRILOV	{"email": "vgavrilov1963@postgrespro.ru", "phone": "+70343670575"}
0005433233345	A4A19C	6265 423326	LYUBOV OSIPOVA	{"email": "osipova.lyubov.30011972@postgrespro.ru", "phone": "+70560193395"}
0005433233346	508A24	9881 567742	ANASTASIYA ALEKSANDROVA	{"email": "anastasiyaaleksandrova12091969@postgrespro.ru", "phone": "+70772225630"}
0005433233347	654095	4006 373780	ELIZAVETA VOROBEVA	{"email": "vorobevaelizaveta_06021970@postgrespro.ru", "phone": "+70747390511"}
0005433233348	DFFDEC	9746 609975	OLGA TIKHONOVA	{"email": "tikhonova.olga_071975@postgrespro.ru", "phone": "+70458327039"}
0005433233349	DFFDEC	0242 629066	MIKHAIL SCHERBAKOV	{"phone": "+70236186143"}
0005433233350	5A0D3E	7243 996685	EVGENIY PETROV	{"email": "petrove-10041962@postgrespro.ru", "phone": "+70587572081"}
0005433233351	5A0D3E	7482 742637	ALEKSANDR ORLOV	{"email": "orlov_a-22081969@postgrespro.ru", "phone": "+70876763560"}
0005433233352	4C1E7A	8124 510710	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail.1978@postgrespro.ru", "phone": "+70780303953"}
0005433233353	4C1E7A	0867 279910	ALEKSANDR GUSEV	{"email": "gusev_a_13031975@postgrespro.ru", "phone": "+70300257093"}
0005433233354	1B6F1E	7567 182630	SOFYA ANDREEVA	{"email": "andreeva_sofya1979@postgrespro.ru", "phone": "+70331601188"}
0005433233355	1B6F1E	4875 352722	ALBERT GERASIMOV	{"email": "gerasimov-albert091968@postgrespro.ru", "phone": "+70571270064"}
0005433233356	1B6F1E	0056 560106	LIDIYA ZAKHAROVA	{"phone": "+70806462676"}
0005433233357	85DD4B	4891 476194	DARINA ZAYCEVA	{"phone": "+70927812854"}
0005433233358	91EF50	0176 484683	ROMAN OSIPOV	{"email": "romanosipov-101979@postgrespro.ru", "phone": "+70995606277"}
0005433233359	5BBBFF	9718 530822	MARINA MOROZOVA	{"phone": "+70261292571"}
0005433233360	5BBBFF	9851 701776	DAMIR KUZNECOV	{"email": "kuznecov.damir.061976@postgrespro.ru", "phone": "+70757395448"}
0005433233361	90B4CA	2955 877304	ALEKSEY BONDARENKO	{"phone": "+70440329085"}
0005433233362	258EA4	1267 580691	YULIANA STEPANOVA	{"phone": "+70645609197"}
0005433233363	258EA4	7306 751650	NAILYA NIKIFOROVA	{"email": "nikiforova.n_25091974@postgrespro.ru", "phone": "+70264348241"}
0005433233364	528A39	0353 698847	EDUARD FEDOTOV	{"email": "fedotoveduard.26081962@postgrespro.ru", "phone": "+70025713820"}
0005433233365	AFB861	5618 207625	VLADISLAV PAVLOV	{"email": "pavlov-vladislav-111980@postgrespro.ru", "phone": "+70369013165"}
0005433233366	599194	5480 541737	TAMARA IVANOVA	{"email": "ivanova_t091970@postgrespro.ru", "phone": "+70503115000"}
0005433233367	A7C74B	2247 588172	ALEKSEY MARTYNOV	{"email": "martynova-02101971@postgrespro.ru", "phone": "+70772531243"}
0005433233368	A7C74B	8006 750776	SNEZHANA KUZNECOVA	{"email": "snezhana-kuznecova.021974@postgrespro.ru", "phone": "+70181642498"}
0005433233369	6F9EA9	4296 663390	MARINA KAZAKOVA	{"email": "kazakova-m-031976@postgrespro.ru", "phone": "+70691109503"}
0005433233370	C4CA21	9086 647591	MARIYA VOROBEVA	{"email": "vorobeva.mariya051971@postgrespro.ru", "phone": "+70190846402"}
0005433233371	44458F	0486 468178	ALEKSANDR BONDARENKO	{"phone": "+70440758214"}
0005433233372	44458F	8001 433369	OLEG NIKITIN	{"email": "nikitin-oleg27071985@postgrespro.ru", "phone": "+70347284234"}
0005433233373	44458F	7369 370177	SVETLANA ORLOVA	{"email": "svetlana-orlova.15101974@postgrespro.ru", "phone": "+70298023675"}
0005433233374	6E3511	1662 909822	ALEKSANDR DENISOV	{"phone": "+70102701113"}
0005433233596	2F3C48	5033 566677	DANIIL KOROLEV	{"phone": "+70184944751"}
0005433233375	CD57C5	2951 361741	VIKTOR KOZLOV	{"email": "kozlov.viktor1963@postgrespro.ru", "phone": "+70045165676"}
0005433233376	CD57C5	9656 292033	IRINA VASILEVA	{"email": "i-vasileva_1981@postgrespro.ru", "phone": "+70798152005"}
0005433233377	45B999	4127 747872	IGOR PETROV	{"phone": "+70453631420"}
0005433233378	45B999	1898 862434	GALINA SERGEEVA	{"phone": "+70404674651"}
0005433233379	BA1E59	9983 657995	NIKOLAY YAKOVLEV	{"phone": "+70346860279"}
0005433233380	2A4909	5276 799109	VASILIY KOZLOV	{"phone": "+70076802851"}
0005433233381	C75994	4497 502143	VIKTOR MIKHAYLOV	{"email": "viktor.mikhaylov.23031973@postgrespro.ru", "phone": "+70377132782"}
0005433233382	C75994	3789 917541	VITALIY SCHERBAKOV	{"email": "scherbakovv041972@postgrespro.ru", "phone": "+70205962742"}
0005433233383	822A2B	7863 008098	VLADIMIR KARPOV	{"phone": "+70551185263"}
0005433233384	5FD899	5519 000045	LYUBOV GRISHINA	{"phone": "+70185836138"}
0005433233385	5FD899	1158 812713	TATYANA FILATOVA	{"email": "tatyana-filatova_101981@postgrespro.ru", "phone": "+70261414670"}
0005433233386	A80CDB	1531 712774	ALINA KOZLOVA	{"phone": "+70551982103"}
0005433233387	C3B9F6	8511 718593	LYUDMILA VASILEVA	{"email": "l.vasileva_1976@postgrespro.ru", "phone": "+70599499634"}
0005433233388	5D6C12	0535 917076	SERGEY SOROKIN	{"phone": "+70716815372"}
0005433233389	C41433	2876 066521	RAFAEL KUZMIN	{"email": "kuzmin_r1965@postgrespro.ru", "phone": "+70118994545"}
0005433233390	C41433	2959 754060	ALBINA TIKHONOVA	{"email": "tikhonova_albina_051971@postgrespro.ru", "phone": "+70256576016"}
0005433233391	3DD52F	4263 167987	DENIS MIKHAYLOV	{"phone": "+70859982909"}
0005433233392	95130C	8941 030314	VIKTORIYA ZHURAVLEVA	{"phone": "+70734638945"}
0005433233393	8C476A	2033 204388	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva_1969@postgrespro.ru", "phone": "+70591627465"}
0005433233394	B7AFD4	4547 848084	ILDAR GORBUNOV	{"email": "gorbunov_i25061964@postgrespro.ru", "phone": "+70520540493"}
0005433233395	A63323	5828 643864	ALEKSANDR ANTONOV	{"phone": "+70445695679"}
0005433233396	F299B3	7367 028478	MIKHAIL KUZMIN	{"phone": "+70734085329"}
0005433233397	F299B3	7245 615741	LYUBOV VOLKOVA	{"phone": "+70759759937"}
0005433233398	71F147	6559 028185	ALEKSANDRA NOVIKOVA	{"email": "aleksandra-novikova-12111972@postgrespro.ru", "phone": "+70680381996"}
0005433233399	71F147	9988 070463	LIDIYA KUZNECOVA	{"email": "l-kuznecova.021970@postgrespro.ru", "phone": "+70890893765"}
0005433233400	71F147	5005 756340	SOFIYA DMITRIEVA	{"email": "s-dmitrieva.29041968@postgrespro.ru", "phone": "+70107430843"}
0005433233401	BB1136	1803 215407	RASUL ZHUKOV	{"email": "zhukovrasul_19091977@postgrespro.ru", "phone": "+70760002239"}
0005433233402	0EF501	4652 278650	NINA MAKSIMOVA	{"phone": "+70792456932"}
0005433233403	4A9D01	2373 787180	OLGA ZHURAVLEVA	{"email": "olgazhuravleva.071966@postgrespro.ru", "phone": "+70674923794"}
0005433233404	4A9D01	7231 411999	NATALYA VOLKOVA	{"email": "n.volkova_121966@postgrespro.ru", "phone": "+70375150894"}
0005433233405	501884	8255 652757	ALEKSANDR SOLOVEV	{"phone": "+70391392093"}
0005433233406	501884	0216 472831	NATALYA SOLOVEVA	{"phone": "+70692059138"}
0005433233407	8FF245	9949 684098	EVGENIY MIRONOV	{"phone": "+70197615079"}
0005433233408	8FF245	3910 884171	TATYANA SCHERBAKOVA	{"phone": "+70053840036"}
0005433233409	1846C1	3269 233421	ANASTASIYA PAVLOVA	{"phone": "+70654197620"}
0005433233410	1846C1	1068 903487	ELENA GORBUNOVA	{"email": "egorbunova-28051975@postgrespro.ru", "phone": "+70248808154"}
0005433233411	29D46B	0286 992165	VALERIY MAKAROV	{"phone": "+70545293687"}
0005433233412	4BC495	6184 527163	VYACHESLAV ANDREEV	{"email": "vyacheslav.andreev31051968@postgrespro.ru", "phone": "+70107865973"}
0005433233413	4BC495	1116 766343	SERGEY NIKOLAEV	{"email": "nikolaev_s1963@postgrespro.ru", "phone": "+70897068960"}
0005433233414	84E36E	0059 238744	VLADIMIR AFANASEV	{"email": "afanasev_v-021971@postgrespro.ru", "phone": "+70628736810"}
0005433233415	84E36E	3853 870201	NINA SOROKINA	{"email": "sorokina_n011973@postgrespro.ru", "phone": "+70621041769"}
0005433233416	659B80	5478 838126	NATALYA NIKOLAEVA	{"email": "nikolaevanatalya-081976@postgrespro.ru", "phone": "+70808503432"}
0005433233417	73A8A3	2754 688286	ALEKSEY ISAEV	{"email": "alekseyisaev.121973@postgrespro.ru", "phone": "+70303253092"}
0005433233418	024BB9	3779 491377	ALIK FROLOV	{"phone": "+70528291981"}
0005433233419	0A0073	3957 824635	MIKHAIL ORLOV	{"phone": "+70496138091"}
0005433233420	0A0073	0346 881923	SERGEY TIKHONOV	{"email": "sergey.tikhonov_27091978@postgrespro.ru", "phone": "+70878938945"}
0005433233421	8D20F3	9223 316886	FEDOR ZAYCEV	{"email": "zaycev-f1959@postgrespro.ru", "phone": "+70496934366"}
0005433233422	9AC6AE	2670 609060	VALERIYA VOROBEVA	{"phone": "+70081509474"}
0005433233423	A8D787	6548 921873	RAISA KOLESNIKOVA	{"email": "kolesnikovaraisa-031972@postgrespro.ru", "phone": "+70227272389"}
0005433233424	173907	5084 614055	SERGEY DMITRIEV	{"email": "sergeydmitriev-06071965@postgrespro.ru", "phone": "+70220678826"}
0005433233425	173907	0673 846585	NADEZHDA FOMINA	{"email": "fomina.nadezhda.1975@postgrespro.ru", "phone": "+70196502925"}
0005433233426	C64D38	8159 648699	ALEKSEY NIKOLAEV	{"phone": "+70149483318"}
0005433233427	FFD0DA	8201 331991	VALENTINA NIKITINA	{"email": "nikitina-valentina_1970@postgrespro.ru", "phone": "+70300026363"}
0005433233428	FFD0DA	1882 063929	VALENTINA GAVRILOVA	{"phone": "+70317250308"}
0005433233429	903A27	1609 398741	VALENTINA PAVLOVA	{"email": "pavlova.v081970@postgrespro.ru", "phone": "+70957206269"}
0005433233430	9FA8EE	9945 116263	ALEKSANDR MOISEEV	{"phone": "+70925990808"}
0005433233431	F0D0C1	7001 885102	EKATERINA ANTONOVA	{"email": "antonova.e-12111962@postgrespro.ru", "phone": "+70494367989"}
0005433233432	DF1B02	0396 531694	SERGEY AFANASEV	{"email": "sergey_afanasev_1973@postgrespro.ru", "phone": "+70976902161"}
0005433233433	DF1B02	3333 203796	GALINA PETROVA	{"email": "petrova-galina.06091973@postgrespro.ru", "phone": "+70501043010"}
0005433233434	0C9376	2953 283831	LADA SOKOLOVA	{"phone": "+70249838023"}
0005433233435	027457	8534 558040	ROMAN BELOV	{"phone": "+70557433756"}
0005433233436	D48E10	0223 278799	INNA ZHUKOVA	{"phone": "+70446058090"}
0005433233437	D6D84B	3408 730997	VIKTOR KAZAKOV	{"email": "kazakov-v_14101983@postgrespro.ru", "phone": "+70437641396"}
0005433233438	0A114E	5653 266675	ALEKSANDR CHERNOV	{"phone": "+70004063648"}
0005433233439	4A4F06	3022 838815	VIKTORIYA VOLKOVA	{"phone": "+70480397077"}
0005433233440	6F0706	8670 722959	OLESYA NIKIFOROVA	{"phone": "+70875356582"}
0005433233441	9CB4B0	6672 193808	EVGENIYA ALEKSANDROVA	{"phone": "+70621893831"}
0005433233442	AA5DA4	6139 829629	NIKOLAY ROMANOV	{"email": "nromanov-1968@postgrespro.ru", "phone": "+70521388132"}
0005433233443	935CE6	1360 928939	EKATERINA DMITRIEVA	{"phone": "+70736863641"}
0005433233444	E34D2A	4822 244494	IGOR MAKAROV	{"phone": "+70414546336"}
0005433233445	BBDAC7	6969 842936	SERGEY MEDVEDEV	{"phone": "+70780377632"}
0005433233446	E1135A	3351 744078	VALENTINA MIKHAYLOVA	{"phone": "+70604991282"}
0005433233447	6825D1	1733 072430	VALERIY VOLKOV	{"email": "volkov_valeriy-1969@postgrespro.ru", "phone": "+70597798860"}
0005433233448	337433	9725 619417	ROSTISLAV ZAKHAROV	{"phone": "+70486700739"}
0005433233449	20C6FF	3743 083267	ALEKSANDR IVANOV	{"phone": "+70364338975"}
0005433233450	20C6FF	0672 900912	DMITRIY MAKAROV	{"email": "dmakarov_12011971@postgrespro.ru", "phone": "+70387680853"}
0005433233451	7E6DBF	4952 849852	NATALYA KUDRYASHOVA	{"email": "kudryashova.natalya-1965@postgrespro.ru", "phone": "+70417482681"}
0005433233452	8EF376	2887 682743	MAKSIM TARASOV	{"email": "m_tarasov.1970@postgrespro.ru", "phone": "+70594215267"}
0005433233453	EB016F	7427 376292	DMITRIY IVANOV	{"phone": "+70880462152"}
0005433233454	EB016F	9177 592657	NATALYA MELNIKOVA	{"email": "n_melnikova_16061964@postgrespro.ru", "phone": "+70206031740"}
0005433233455	4DCFD5	9391 500426	VIKTORIYA MATVEEVA	{"email": "viktoriya-matveeva.1967@postgrespro.ru", "phone": "+70509573342"}
0005433233456	B98283	1738 003873	VALENTINA ZAYCEVA	{"email": "zayceva-v-29071984@postgrespro.ru", "phone": "+70806710136"}
0005433233457	245D76	7734 069187	TATYANA MELNIKOVA	{"email": "melnikova_tatyana-091970@postgrespro.ru", "phone": "+70182128647"}
0005433233458	06BDA8	1296 388499	TATYANA OVCHINNIKOVA	{"email": "t_ovchinnikova04111975@postgrespro.ru", "phone": "+70499458272"}
0005433233459	FCA13C	4198 757294	KSENIYA MOISEEVA	{"email": "moiseeva.kseniya_20011969@postgrespro.ru", "phone": "+70983697813"}
0005433233460	FCA13C	3984 124105	VADIM NAZAROV	{"email": "v.nazarov.16071976@postgrespro.ru", "phone": "+70996244075"}
0005433233461	62DC67	3023 525050	ANASTASIYA MELNIKOVA	{"email": "melnikova-anastasiya_071981@postgrespro.ru", "phone": "+70828471731"}
0005433233462	903014	0834 512104	NATALIYA POPOVA	{"email": "npopova.1967@postgrespro.ru", "phone": "+70581720115"}
0005433233463	F23C77	7746 295301	ELENA BORISOVA	{"email": "elena-borisova.04061977@postgrespro.ru", "phone": "+70833021848"}
0005433233464	F23C77	0826 201991	VYACHESLAV ABRAMOV	{"phone": "+70050791743"}
0005433233465	DD1BE6	2034 182084	IRINA MATVEEVA	{"email": "irina-matveeva1982@postgrespro.ru", "phone": "+70479308832"}
0005433233466	F10334	8007 050062	ALENA TARASOVA	{"email": "a_tarasova-1967@postgrespro.ru", "phone": "+70789988352"}
0005433233467	F10334	7392 048888	MARIYA SIDOROVA	{"phone": "+70287861369"}
0005433233468	C5D8E4	0659 479178	ALEKSANDR POPOV	{"phone": "+70974302822"}
0005433233469	C9E1C3	1280 699079	ANASTASIYA VOROBEVA	{"phone": "+70984674835"}
0005433233470	BB515E	3918 399407	VALENTINA FOMINA	{"phone": "+70105020993"}
0005433233471	DA67EA	4855 794658	ANASTASIYA EFREMOVA	{"phone": "+70584804368"}
0005433233472	DA67EA	9236 177779	ALEKSANDR BELOV	{"email": "a.belov.24011979@postgrespro.ru", "phone": "+70049126266"}
0005433233473	24D44A	5247 996603	ANATOLIY SOKOLOV	{"phone": "+70848997383"}
0005433233474	26F747	4306 007519	SALAVAT DAVYDOV	{"phone": "+70337819859"}
0005433233475	17F386	6185 898794	SERGEY GRIGOREV	{"email": "sergey-grigorev.021970@postgrespro.ru", "phone": "+70234729608"}
0005433233476	D6E043	1120 205162	LYUDMILA SCHERBAKOVA	{"email": "l_scherbakova_18101973@postgrespro.ru", "phone": "+70833199206"}
0005433233477	D04346	3512 263033	TATYANA ILINA	{"email": "ilinat.02051966@postgrespro.ru", "phone": "+70805781251"}
0005433233478	17666B	6278 623346	ALEKSANDRA MATVEEVA	{"phone": "+70511069851"}
0005433233479	B56C64	3395 803681	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko_1975@postgrespro.ru", "phone": "+70476794878"}
0005433233480	B56C64	7580 951634	IGOR IVANOV	{"email": "ivanov.i.06111972@postgrespro.ru", "phone": "+70533335990"}
0005433233481	358DF1	6157 061855	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov_11021966@postgrespro.ru", "phone": "+70724446442"}
0005433233482	DFFE4F	6827 134426	ANASTASIYA SAVELEVA	{"phone": "+70379511430"}
0005433233483	DFFE4F	8753 055622	SAMIRA MAKAROVA	{"email": "makarova_s_05091981@postgrespro.ru", "phone": "+70450298282"}
0005433233484	076DEE	7011 535377	SVETLANA VLASOVA	{"phone": "+70180920287"}
0005433233485	019E1D	5115 697196	EVGENIY SOROKIN	{"phone": "+70809207350"}
0005433233597	0EAC22	8298 708780	PETR ZHUKOV	{"phone": "+70806989582"}
0005433233486	23F535	8112 045942	LYUDMILA VOROBEVA	{"email": "vorobeva-l_1984@postgrespro.ru", "phone": "+70209938409"}
0005433233487	B47A50	5870 593951	VITALIY MIRONOV	{"phone": "+70998848403"}
0005433233488	8FB232	6668 161632	MARIYA AKIMOVA	{"phone": "+70731478357"}
0005433233489	E45BC0	1533 623339	SERGEY ANTONOV	{"phone": "+70373554369"}
0005433233490	E45BC0	6916 712098	VIKTORIYA AKIMOVA	{"phone": "+70277920881"}
0005433233491	AEC0CA	9008 335492	NIKOLAY VASILEV	{"phone": "+70963343600"}
0005433233492	C555F7	9573 593314	VSEVOLOD BONDARENKO	{"email": "bondarenko-v_25041973@postgrespro.ru", "phone": "+70481771597"}
0005433233493	1F7659	9760 504645	GALINA ABRAMOVA	{"phone": "+70654275948"}
0005433233494	1A7D37	2869 382684	OLEG ISAEV	{"email": "isaev-oleg-19081981@postgrespro.ru", "phone": "+70487308060"}
0005433233495	1A7D37	3238 007925	MARINA DAVYDOVA	{"email": "davydova.m-20121971@postgrespro.ru", "phone": "+70538804823"}
0005433233496	1342D7	0078 028138	STEPAN GUSEV	{"phone": "+70745356577"}
0005433233497	B58459	3294 404084	ALEKSEY EGOROV	{"email": "egorovaleksey041972@postgrespro.ru", "phone": "+70251861939"}
0005433233498	B58459	3743 350970	SERGEY YAKOVLEV	{"phone": "+70771549004"}
0005433233499	E946A6	5565 452246	NIKOLAY BONDARENKO	{"email": "n.bondarenko1966@postgrespro.ru", "phone": "+70664202674"}
0005433233500	E946A6	4293 606633	ANTONINA FEDOROVA	{"phone": "+70991142625"}
0005433233501	A59A1F	5436 948362	IGOR PETROV	{"phone": "+70820559089"}
0005433233502	A59A1F	1888 049986	SERGEY DAVYDOV	{"email": "davydov_sergey.12031969@postgrespro.ru", "phone": "+70559820317"}
0005433233503	387463	5286 646533	LEONID ROMANOV	{"email": "l_romanov.18051972@postgrespro.ru", "phone": "+70926337788"}
0005433233504	69265F	1821 730684	VITALIY SOKOLOV	{"phone": "+70706380056"}
0005433233505	69265F	1307 046978	VASILIY DAVYDOV	{"email": "vasiliy_davydov1975@postgrespro.ru", "phone": "+70174752996"}
0005433233506	D65614	6167 809972	NINA BOGDANOVA	{"email": "bogdanova.nina_111973@postgrespro.ru", "phone": "+70135163822"}
0005433233507	FB5235	3373 117977	ANTON MAKAROV	{"email": "makarov.anton031970@postgrespro.ru", "phone": "+70983378101"}
0005433233508	2C4645	8853 128205	ANASTASIYA KISELEVA	{"phone": "+70515496521"}
0005433233509	155318	1306 730564	MARK ALEKSEEV	{"phone": "+70125712467"}
0005433233510	155318	3348 733375	MIKHAIL GRIGOREV	{"phone": "+70668126975"}
0005433233511	8E1E8C	7147 115684	MARIYA ZAYCEVA	{"email": "zayceva-m_091971@postgrespro.ru", "phone": "+70754881279"}
0005433233512	8E1E8C	0618 792783	ALEKSANDR DMITRIEV	{"email": "admitriev-21041972@postgrespro.ru", "phone": "+70981811762"}
0005433233513	01C12D	1285 652179	SERGEY ISAEV	{"email": "isaev_sergey-09111965@postgrespro.ru", "phone": "+70669658360"}
0005433233514	6237FD	9971 629057	OLGA NIKOLAEVA	{"email": "nikolaeva-olga1988@postgrespro.ru", "phone": "+70568009379"}
0005433233515	6237FD	4221 051808	VIKTOR BELOV	{"email": "belovviktor.051980@postgrespro.ru", "phone": "+70921724382"}
0005433233516	6D392C	2975 605187	VALERIY SOKOLOV	{"phone": "+70609358857"}
0005433233517	BF3BFE	9969 035435	YAROSLAV TARASOV	{"email": "y.tarasov_07011985@postgrespro.ru", "phone": "+70280338799"}
0005433233518	B07019	4710 402530	KIRILL EGOROV	{"phone": "+70613306744"}
0005433233519	E82A47	4732 258220	VALENTINA MARTYNOVA	{"email": "valentina_martynova-011965@postgrespro.ru", "phone": "+70221154452"}
0005433233520	01C924	7741 526228	OLGA KOLESNIKOVA	{"phone": "+70196515136"}
0005433233521	D39DB9	0609 511782	EVGENIYA PAVLOVA	{"email": "epavlova051973@postgrespro.ru", "phone": "+70358030671"}
0005433233522	03E00E	1776 382400	OLEG MOROZOV	{"email": "oleg.morozov-1979@postgrespro.ru", "phone": "+70317717330"}
0005433233523	029BD4	2826 251573	EKATERINA DAVYDOVA	{"email": "ekaterina.davydova.1968@postgrespro.ru", "phone": "+70198475486"}
0005433233524	029BD4	3398 335520	ELENA CHERNOVA	{"email": "chernovaelena-1972@postgrespro.ru", "phone": "+70152065594"}
0005433233525	DE7789	9890 847007	MARIYA LUKYANOVA	{"email": "lukyanova.mariya041969@postgrespro.ru", "phone": "+70567914383"}
0005433233526	DE7789	6277 284642	LARISA GORBUNOVA	{"phone": "+70943865100"}
0005433233527	DE7789	1490 276370	YULIYA ANTONOVA	{"email": "antonova_yuliya.1965@postgrespro.ru", "phone": "+70196547719"}
0005433233528	E302D4	6054 870568	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.g_1972@postgrespro.ru", "phone": "+70494057111"}
0005433233529	5E651D	9096 001192	KRISTINA SCHERBAKOVA	{"phone": "+70853334660"}
0005433233530	B23474	1992 492935	VIKTORIYA CHERNOVA	{"email": "chernovav021973@postgrespro.ru", "phone": "+70133024416"}
0005433233531	B23474	4287 125223	ALEKSANDR NOVIKOV	{"email": "novikova1976@postgrespro.ru", "phone": "+70777414486"}
0005433233532	A10FD8	2733 040785	TAMARA IVANOVA	{"email": "t.ivanova-091969@postgrespro.ru", "phone": "+70844156189"}
0005433233533	109202	3543 279406	ALENA ANDREEVA	{"email": "alena-andreeva081970@postgrespro.ru", "phone": "+70303718753"}
0005433233534	0C2022	1221 932032	NATALYA CHERNOVA	{"phone": "+70746953277"}
0005433233535	1B87F9	7495 395046	ROMAN SMIRNOV	{"email": "smirnovr.16011988@postgrespro.ru", "phone": "+70074556905"}
0005433233536	DEAFBC	4188 348312	NIKOLAY SCHERBAKOV	{"phone": "+70915484029"}
0005433233537	0E0C5B	4690 831867	TATYANA KUZMINA	{"email": "kuzminatatyana.111971@postgrespro.ru", "phone": "+70434024739"}
0005433233538	C77DE7	7307 289818	ALEKSANDR TARASOV	{"phone": "+70302925261"}
0005433233539	92776D	1083 175853	ALEKSANDRA GRISHINA	{"email": "grishina_a-08091966@postgrespro.ru", "phone": "+70456313667"}
0005433233540	92776D	5306 175777	ELENA ROMANOVA	{"email": "romanova-e.17021971@postgrespro.ru", "phone": "+70299587369"}
0005433233541	D95F29	6212 383912	OLEG NAZAROV	{"email": "nazarov-o_27091959@postgrespro.ru", "phone": "+70314371829"}
0005433233542	D95F29	1322 305974	DMITRIY AFANASEV	{"phone": "+70825042086"}
0005433233543	D95F29	5707 714245	RAISA SOLOVEVA	{"email": "soloveva-r-091959@postgrespro.ru", "phone": "+70268784807"}
0005433233544	C75686	8176 327327	OLGA LEBEDEVA	{"phone": "+70105035098"}
0005433233545	9D4C85	4296 953133	KAMIL GRIGOREV	{"email": "k_grigorev_1976@postgrespro.ru", "phone": "+70713013526"}
0005433233546	4A5806	5163 335208	ANTONINA KUZNECOVA	{"email": "kuznecovaa-1974@postgrespro.ru", "phone": "+70917137764"}
0005433233547	79D5C6	1949 895284	ALSU MAKAROVA	{"phone": "+70467480443"}
0005433233548	5F8ABC	7860 244602	ALISA BORISOVA	{"phone": "+70756696260"}
0005433233549	01367A	9387 240119	ARTEM SOKOLOV	{"email": "a_sokolov-051973@postgrespro.ru", "phone": "+70179775706"}
0005433233550	6C84F9	5039 351278	EKATERINA GERASIMOVA	{"phone": "+70122538180"}
0005433233551	B0CE33	5129 469215	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr_21101972@postgrespro.ru", "phone": "+70867242237"}
0005433233552	F2FFB0	6567 301993	ILYA ISAEV	{"email": "ilya.isaev.1973@postgrespro.ru", "phone": "+70006223422"}
0005433233553	708271	5207 704546	LYUDMILA RYABOVA	{"phone": "+70730737105"}
0005433233554	3A58F8	7584 168486	SVETLANA MELNIKOVA	{"email": "svetlana_melnikova-121961@postgrespro.ru", "phone": "+70002817696"}
0005433233555	2057E7	9979 188670	ANATOLIY DENISOV	{"phone": "+70134178770"}
0005433233556	348F51	8684 472027	VIKTOR FOMIN	{"phone": "+70916348643"}
0005433233557	306C55	7405 364785	MIKHAIL NIKITIN	{"phone": "+70620186239"}
0005433233558	306C55	6405 387596	ANATOLIY NAZAROV	{"phone": "+70234047785"}
0005433233559	20968E	3894 681438	GENNADIY NIKOLAEV	{"email": "g-nikolaev-01041972@postgrespro.ru", "phone": "+70811309641"}
0005433233560	20968E	1367 509924	EVGENIYA NIKOLAEVA	{"email": "nikolaeva.evgeniya-19031981@postgrespro.ru", "phone": "+70691548979"}
0005433233561	889750	9301 521213	ARINA SEMENOVA	{"email": "semenova-arina_031988@postgrespro.ru", "phone": "+70138859812"}
0005433233562	889750	1513 789959	ALEKSANDR IVANOV	{"phone": "+70656415805"}
0005433233563	8D0F01	1868 404774	NIKOLAY NIKITIN	{"email": "n-nikitin_1972@postgrespro.ru", "phone": "+70021225874"}
0005433233564	8D0F01	6604 623708	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov_1969@postgrespro.ru", "phone": "+70628089343"}
0005433233565	5F244E	7815 486021	OKSANA KONOVALOVA	{"email": "konovalova.oksana1966@postgrespro.ru", "phone": "+70294253604"}
0005433233566	056967	7661 637748	MARIYA KUZNECOVA	{"email": "mariya-kuznecova.071975@postgrespro.ru", "phone": "+70972203846"}
0005433233567	056967	7750 901096	VASILIY TIKHONOV	{"phone": "+70115655106"}
0005433233568	937E61	8844 531988	SERGEY GORBUNOV	{"email": "s_gorbunov.031965@postgrespro.ru", "phone": "+70571006402"}
0005433233569	850AB4	9110 515992	EGOR EGOROV	{"email": "egorov.egor111967@postgrespro.ru", "phone": "+70954678054"}
0005433233570	850AB4	7334 201044	LARISA BARANOVA	{"email": "l-baranova_081982@postgrespro.ru", "phone": "+70121191948"}
0005433233571	D1F63E	1358 450321	ALENA AFANASEVA	{"email": "afanaseva_a.01051974@postgrespro.ru", "phone": "+70883937769"}
0005433233572	A88B38	7603 900404	EGOR ANDREEV	{"email": "andreev.e_1973@postgrespro.ru", "phone": "+70983445081"}
0005433233573	5EC26B	1112 965749	ARSENIY VOLKOV	{"phone": "+70829242996"}
0005433233574	5EC26B	9224 453827	SVETLANA POPOVA	{"email": "popova-svetlana_1978@postgrespro.ru", "phone": "+70677022129"}
0005433233575	FBE3AD	1800 410273	ALEKSANDR FEDOROV	{"phone": "+70906177122"}
0005433233576	FBE3AD	3389 969766	ALISHER GERASIMOV	{"email": "gerasimov.alisher.031977@postgrespro.ru", "phone": "+70959432083"}
0005433233577	FF11F3	9814 680753	OLEG GAVRILOV	{"email": "gavrilovo.101974@postgrespro.ru", "phone": "+70870209072"}
0005433233578	8836D8	6244 780127	OLGA NIKITINA	{"phone": "+70447824989"}
0005433233579	75ECDC	0743 020224	GALINA ZHURAVLEVA	{"email": "zhuravleva_galina.1966@postgrespro.ru", "phone": "+70487839693"}
0005433233580	C8A6CD	3492 386447	SVETLANA NIKITINA	{"email": "nikitinasvetlana_051980@postgrespro.ru", "phone": "+70159275483"}
0005433233581	C8A6CD	1880 442762	ALEKSANDR ISAEV	{"email": "isaev_a-051970@postgrespro.ru", "phone": "+70329627770"}
0005433233582	3A075C	3434 055130	ELIZAVETA KUZNECOVA	{"email": "ekuznecova.1973@postgrespro.ru", "phone": "+70305235076"}
0005433233583	3BBC6B	2838 911887	NIKOLAY ILIN	{"email": "ilin_nikolay_1960@postgrespro.ru", "phone": "+70729937842"}
0005433233584	675954	3630 746222	INNA ZAKHAROVA	{"email": "inna_zakharova1971@postgrespro.ru", "phone": "+70403883140"}
0005433233585	675954	9238 733567	NINA POPOVA	{"phone": "+70441891535"}
0005433233586	722B9F	1389 177357	YULIYA OSIPOVA	{"email": "yuliya-osipova.1984@postgrespro.ru", "phone": "+70730902875"}
0005433233587	3DB3BE	4146 573492	TATYANA KUZNECOVA	{"email": "kuznecovat_1974@postgrespro.ru", "phone": "+70640682334"}
0005433233588	871B4A	7050 504301	NELLI NAZAROVA	{"phone": "+70321699876"}
0005433233589	871B4A	1152 132891	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.galina031974@postgrespro.ru", "phone": "+70748552871"}
0005433233590	E7FFA8	2210 111743	ALEKSEY FOMIN	{"email": "a.fomin04111961@postgrespro.ru", "phone": "+70589435532"}
0005433233591	A0F996	9104 363927	ALEKSANDR KOZLOV	{"phone": "+70560351802"}
0005433233592	A0F996	2407 449777	LEV NIKITIN	{"phone": "+70668836896"}
0005433233593	87504B	9623 581411	NIKOLAY SHEVCHENKO	{"phone": "+70800426948"}
0005433233594	211945	3812 299330	VLADIMIR TIKHONOV	{"email": "tikhonov.vladimir_29011984@postgrespro.ru", "phone": "+70383471898"}
0005433233595	2F3C48	2056 027071	VLADIMIR ISAEV	{"email": "vladimir-isaev-04091977@postgrespro.ru", "phone": "+70492177398"}
0005433233598	0EAC22	0624 485319	NIKITA GRIGOREV	{"email": "grigorev.nikita-1978@postgrespro.ru", "phone": "+70575584015"}
0005433233599	8F24CF	1147 153291	ALEKSANDR KARPOV	{"email": "aleksandr_karpov-01121966@postgrespro.ru", "phone": "+70371237616"}
0005433233600	8F1630	8196 161472	ANTON KONOVALOV	{"email": "akonovalov-1964@postgrespro.ru", "phone": "+70097383120"}
0005433233601	8F1630	3804 633930	OLGA SCHERBAKOVA	{"email": "oscherbakova.061964@postgrespro.ru", "phone": "+70512413467"}
0005433233602	22818A	9970 043533	SERGEY KONOVALOV	{"email": "konovalov_sergey_24061968@postgrespro.ru", "phone": "+70229822168"}
0005433233603	7E2331	8214 661109	EVGENIYA ZAYCEVA	{"phone": "+70287041813"}
0005433233604	DEB425	0438 065998	LYUDMILA KUZNECOVA	{"phone": "+70105814567"}
0005433233605	DEB425	0685 371328	VERA ABRAMOVA	{"email": "vera.abramova1966@postgrespro.ru", "phone": "+70595201855"}
0005433233606	2F62FD	8402 978795	OLEG GUSEV	{"phone": "+70025258265"}
0005433233607	5B3B75	6246 318486	SERGEY ILIN	{"phone": "+70983332782"}
0005433233608	5B3B75	9813 950330	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya_02041972@postgrespro.ru", "phone": "+70906882140"}
0005433233609	5B3B75	1662 718296	FARIDA ZAKHAROVA	{"phone": "+70796406497"}
0005433233610	563153	1009 600674	ALEKSEY ANTONOV	{"email": "aantonov1973@postgrespro.ru", "phone": "+70615860980"}
0005433233611	563153	3638 141454	LYUDMILA ANTONOVA	{"email": "antonova_lyudmila_18031967@postgrespro.ru", "phone": "+70682460230"}
0005433233612	9F9A93	2024 181286	ANDREY FEDOROV	{"email": "fedorova-051977@postgrespro.ru", "phone": "+70081818648"}
0005433233613	7B9957	6242 956997	EKATERINA KONOVALOVA	{"phone": "+70591604975"}
0005433233614	86BE8F	4775 559718	NATALYA DENISOVA	{"phone": "+70894770837"}
0005433233615	3D9768	9714 543539	TAKHIR TIMOFEEV	{"email": "timofeev.takhir-1975@postgrespro.ru", "phone": "+70784262031"}
0005433233616	63B1E8	4721 900804	VALENTINA NIKITINA	{"email": "nikitina.valentina071958@postgrespro.ru", "phone": "+70359813984"}
0005433233617	ECF271	2231 441313	NATALYA NIKITINA	{"email": "natalya.nikitina_17031973@postgrespro.ru", "phone": "+70647753462"}
0005433233618	25C79B	5284 762398	GENNADIY FROLOV	{"phone": "+70886949131"}
0005433233619	25C79B	1634 057380	VALERIY ABRAMOV	{"phone": "+70841476797"}
0005433233620	25C79B	0124 025537	VERA POPOVA	{"email": "vpopova-10111975@postgrespro.ru", "phone": "+70860394011"}
0005433233621	9FFB73	7274 048822	KONSTANTIN TIKHONOV	{"phone": "+70787737217"}
0005433233622	FE1CDB	1214 511181	SERGEY SCHERBAKOV	{"phone": "+70375535999"}
0005433233623	004D0D	2577 153395	NINA SAVELEVA	{"email": "saveleva_nina_01081978@postgrespro.ru", "phone": "+70332705150"}
0005433233624	004D0D	4770 834250	VYACHESLAV STEPANOV	{"email": "stepanov.v.03051971@postgrespro.ru", "phone": "+70779728478"}
0005433233625	A0A2C4	5100 663102	GALINA SOLOVEVA	{"phone": "+70409583974"}
0005433233626	A0A2C4	1854 934174	ROMAN OSIPOV	{"email": "roman_osipov-1969@postgrespro.ru", "phone": "+70368669605"}
0005433233627	D1CD18	9953 566193	OLEG AFANASEV	{"email": "o_afanasev-1967@postgrespro.ru", "phone": "+70505682071"}
0005433233628	CF4450	0745 592799	RUSLAN GERASIMOV	{"phone": "+70404825860"}
0005433233629	A5C4F5	0849 180354	YULIYA MOROZOVA	{"email": "morozova-yuliya11031965@postgrespro.ru", "phone": "+70678617677"}
0005433233630	A5C4F5	3070 855239	VALERIYA VLASOVA	{"phone": "+70853837468"}
0005433233631	A5C4F5	2839 528061	ANDREY VASILEV	{"phone": "+70398291792"}
0005433233632	23CF78	0045 264222	ALBINA LOGINOVA	{"email": "aloginova-081972@postgrespro.ru", "phone": "+70723230611"}
0005433233633	0A6423	3850 788843	ANNA IVANOVA	{"email": "ivanova.anna18061973@postgrespro.ru", "phone": "+70953777921"}
0005433233634	231BC8	8984 381016	ANTONINA CHERNOVA	{"phone": "+70379418032"}
0005433233635	E4B82D	0160 981490	SERGEY NAUMOV	{"email": "s.naumov-1967@postgrespro.ru", "phone": "+70611092153"}
0005433233636	EC9EAA	8423 390192	IGOR DMITRIEV	{"phone": "+70885210076"}
0005433233637	1130FE	4196 809558	VLADIMIR ANTONOV	{"email": "antonov-vladimir-1970@postgrespro.ru", "phone": "+70864326366"}
0005433233638	A7DC06	9510 692536	GALINA ILINA	{"email": "ilinagalina.05121962@postgrespro.ru", "phone": "+70180006674"}
0005433233639	A7DC06	1164 206127	TATYANA NIKITINA	{"phone": "+70788679506"}
0005433233640	6CB95E	6508 541526	IRINA FILATOVA	{"email": "irina-filatova.09041973@postgrespro.ru", "phone": "+70481432498"}
0005433233641	7AADE1	4760 338918	ELENA SOROKINA	{"email": "elenasorokina_05091963@postgrespro.ru", "phone": "+70960363458"}
0005433233642	E0D7A8	2213 551845	IRINA POLYAKOVA	{"email": "ipolyakova.1966@postgrespro.ru", "phone": "+70824203815"}
0005433233643	E0D7A8	9069 406820	ARTEM NIKOLAEV	{"email": "nikolaev.artem_28091968@postgrespro.ru", "phone": "+70282747943"}
0005433233644	C461AA	5943 891390	SERGEY MATVEEV	{"phone": "+70676629945"}
0005433233645	C461AA	1152 103837	EVDOKIYA ZAKHAROVA	{"phone": "+70162675229"}
0005433233646	757592	5304 719847	VLADIMIR EGOROV	{"phone": "+70959523833"}
0005433233647	CAB00F	7811 262904	ZINAIDA POLYAKOVA	{"email": "polyakovazinaida-051971@postgrespro.ru", "phone": "+70668354797"}
0005433233648	C7865F	6290 436878	SERGEY SMIRNOV	{"phone": "+70486265524"}
0005433233649	D192FC	5703 772000	DMITRIY POPOV	{"email": "popov-d_061972@postgrespro.ru", "phone": "+70937453220"}
0005433233650	BF0225	2657 698457	ULYANA KONOVALOVA	{"phone": "+70985012062"}
0005433233651	BF0225	0270 890259	ANDREY FEDOROV	{"email": "andrey_fedorov1972@postgrespro.ru", "phone": "+70119127972"}
0005433233652	1A8A6C	2110 620168	MARINA LEBEDEVA	{"email": "lebedeva-m031966@postgrespro.ru", "phone": "+70490409005"}
0005433233653	8F6A1E	2662 131580	ELENA KOROLEVA	{"phone": "+70100112262"}
0005433233654	8F6A1E	2374 106735	IGOR POPOV	{"phone": "+70894246975"}
0005433233655	95581D	7611 439997	VALERIY POPOV	{"email": "v.popov31011978@postgrespro.ru", "phone": "+70139653302"}
0005433233656	95581D	0679 780831	SVETLANA IVANOVA	{"phone": "+70224280901"}
0005433233657	2BA6A0	8581 003925	STANISLAV SOKOLOV	{"email": "sokolov-s.1975@postgrespro.ru", "phone": "+70096294437"}
0005433233658	D52D35	0038 366781	ZINAIDA GERASIMOVA	{"email": "zinaida-gerasimova1981@postgrespro.ru", "phone": "+70393225748"}
0005433233659	D52D35	0908 959239	VLADIMIR BELOV	{"phone": "+70108744027"}
0005433233660	EF77E1	3602 310897	ALEKSANDR SAVELEV	{"phone": "+70001791631"}
0005433233661	00338E	9336 776637	VITALIY NIKOLAEV	{"phone": "+70375513804"}
0005433233662	9520FD	4512 078695	VALENTINA MIRONOVA	{"email": "mironova_v07121976@postgrespro.ru", "phone": "+70208529052"}
0005433233663	9520FD	3676 366198	OLEG SCHERBAKOV	{"email": "oleg_scherbakov-18091969@postgrespro.ru", "phone": "+70420193766"}
0005433233664	A6230B	9635 847887	NIKOLAY ZHUKOV	{"phone": "+70398726803"}
0005433233665	C3F95F	5590 215427	MIKHAIL PAVLOV	{"email": "m.pavlov.24111980@postgrespro.ru", "phone": "+70354288618"}
0005433233666	688A92	4906 167065	SERGEY SHEVCHENKO	{"email": "s-shevchenko_25011979@postgrespro.ru", "phone": "+70261746472"}
0005433233667	688A92	1212 869468	LYUBOV ROMANOVA	{"email": "l_romanova_021966@postgrespro.ru", "phone": "+70316994158"}
0005433233668	859DED	7500 552164	ALEKSEY ROMANOV	{"phone": "+70701879997"}
0005433233669	859DED	2873 286326	VALENTINA KUZNECOVA	{"phone": "+70592187650"}
0005433233670	D9977F	9656 341350	ELENA ORLOVA	{"email": "orlova_elena081970@postgrespro.ru", "phone": "+70884618583"}
0005433233671	0834D6	7276 925343	ALEKSEY BELOV	{"email": "belova-20101979@postgrespro.ru", "phone": "+70570010873"}
0005433233672	B62773	3080 473144	OLGA ZAKHAROVA	{"phone": "+70507531551"}
0005433233673	EB0D68	2433 366995	ALEKSEY FILIPPOV	{"email": "alekseyfilippov.1964@postgrespro.ru", "phone": "+70586333290"}
0005433233674	F109B3	9998 401582	TATYANA RYABOVA	{"email": "tatyana-ryabova.1968@postgrespro.ru", "phone": "+70184677622"}
0005433233675	F26FAE	8253 106189	ROMAN SAVELEV	{"email": "roman-savelev_071970@postgrespro.ru", "phone": "+70867646133"}
0005433233676	F26FAE	2307 815243	ALEKSANDR TARASOV	{"phone": "+70903178711"}
0005433233677	96BC91	5835 544418	SERGEY VOLKOV	{"email": "volkov.sergey14011976@postgrespro.ru", "phone": "+70770729817"}
0005433233678	D5940D	8323 057372	EKATERINA YAKOVLEVA	{"phone": "+70824063286"}
0005433233679	BF0909	3962 723270	OLGA AFANASEVA	{"phone": "+70136242318"}
0005433233680	8D0BE5	6355 269808	OLEG POPOV	{"phone": "+70598511258"}
0005433233681	8D0BE5	1717 763491	ALINA ANDREEVA	{"phone": "+70939610388"}
0005433233682	F0DC49	4763 180291	NATALYA PAVLOVA	{"email": "natalyapavlova1980@postgrespro.ru", "phone": "+70789520176"}
0005433233683	1F634B	6153 960842	DMITRIY TIKHONOV	{"email": "tikhonov_d-091966@postgrespro.ru", "phone": "+70543246605"}
0005433233684	D90B5E	7101 991550	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov.051978@postgrespro.ru", "phone": "+70516833494"}
0005433233685	51CC47	4270 171698	NATALYA ANISIMOVA	{"email": "anisimova.natalya1969@postgrespro.ru", "phone": "+70553616799"}
0005433233686	47A01D	3275 519044	ANNA MIKHAYLOVA	{"email": "a_mikhaylova021976@postgrespro.ru", "phone": "+70800482834"}
0005433233687	BA482D	7370 183804	TATYANA MELNIKOVA	{"phone": "+70863778923"}
0005433233688	BA482D	8012 959335	ANATOLIY ABRAMOV	{"phone": "+70314451268"}
0005433233689	582B33	0077 055812	ALEKSANDR CHERNOV	{"email": "aleksandrchernov021965@postgrespro.ru", "phone": "+70675657701"}
0005433233690	D37FAE	6328 067451	IRINA ZHURAVLEVA	{"phone": "+70499690493"}
0005433233691	6966B3	6288 835628	ALEKSEY TIKHONOV	{"email": "tikhonov_aleksey-1970@postgrespro.ru", "phone": "+70065519473"}
0005433233692	6966B3	0447 561698	VALENTINA IVANOVA	{"phone": "+70326952714"}
0005433233693	E2F14B	5089 515904	ELENA FILATOVA	{"email": "filatova-elena_1972@postgrespro.ru", "phone": "+70708132152"}
0005433233694	E2F14B	5055 969611	VIKTOR MOROZOV	{"phone": "+70498914590"}
0005433233695	DF149C	9187 058208	LYUDMILA PAVLOVA	{"email": "lyudmila-pavlova1982@postgrespro.ru", "phone": "+70718234296"}
0005433233696	DF149C	1568 172019	VASILIY STEPANOV	{"email": "v.stepanov31051972@postgrespro.ru", "phone": "+70472013189"}
0005433233697	5EE55D	8043 280145	SERGEY NIKOLAEV	{"email": "nikolaevs_021981@postgrespro.ru", "phone": "+70547439963"}
0005433233698	BF2FB6	1866 822787	GALINA IVANOVA	{"email": "ivanova_g.28061969@postgrespro.ru", "phone": "+70661031386"}
0005433233699	BF2FB6	0861 145824	SERGEY TIKHONOV	{"email": "tikhonov_sergey-031974@postgrespro.ru", "phone": "+70343954386"}
0005433233700	A0391E	7011 450389	NADEZHDA SOKOLOVA	{"email": "sokolova.nadezhda-30051967@postgrespro.ru", "phone": "+70260889541"}
0005433233701	A0391E	4288 980561	VLADIMIR GORBUNOV	{"email": "gorbunovv30091974@postgrespro.ru", "phone": "+70308311271"}
0005433233702	1697A1	7042 306523	EKATERINA SCHERBAKOVA	{"phone": "+70391892499"}
0005433233703	9849C9	3677 904042	YULIYA ARKHIPOVA	{"email": "arkhipova_y1967@postgrespro.ru", "phone": "+70076602663"}
0005433233704	A7F0D4	4168 102096	TATYANA KONDRATEVA	{"phone": "+70911894975"}
0005433233705	2AD055	5153 185483	SERGEY MIRONOV	{"phone": "+70852482591"}
0005433233706	F773E2	7727 608674	TATYANA KOLESNIKOVA	{"email": "kolesnikova-t26101966@postgrespro.ru", "phone": "+70372941668"}
0005433233707	38FD00	0146 505701	PAVEL NIKOLAEV	{"phone": "+70570059502"}
0005433233708	38FD00	8071 978047	ELENA DENISOVA	{"phone": "+70694703401"}
0005433233709	E0538B	5157 681644	VLADIMIR IVANOV	{"email": "vladimir-ivanov04051981@postgrespro.ru", "phone": "+70830496845"}
0005433233710	E0538B	4573 675815	NIKOLAY SERGEEV	{"email": "nikolay-sergeev_101970@postgrespro.ru", "phone": "+70127214706"}
0005433233711	19310D	5738 026394	SVETLANA MAKAROVA	{"phone": "+70242221803"}
0005433233712	85BC82	8150 934556	ALEKSANDR FROLOV	{"phone": "+70177872483"}
0005433233713	85BC82	2204 968960	OLGA MOROZOVA	{"email": "o-morozova.1966@postgrespro.ru", "phone": "+70577652031"}
0005433233714	9D7B37	5920 782889	DMITRIY SHEVCHENKO	{"email": "dmitriyshevchenko061976@postgrespro.ru", "phone": "+70877506003"}
0005433233715	53FC6F	0167 907666	STANISLAV GAVRILOV	{"email": "stanislav-gavrilov121973@postgrespro.ru", "phone": "+70686713889"}
0005433233716	53FC6F	7247 292351	IVAN IVANOV	{"email": "ivanov_i1966@postgrespro.ru", "phone": "+70702866188"}
0005433233717	30D84F	6123 227398	SERGEY KUZNECOV	{"phone": "+70215485933"}
0005433233718	950245	9872 046864	MARIYA MIKHAYLOVA	{"email": "mariya.mikhaylova_1973@postgrespro.ru", "phone": "+70483809835"}
0005433233719	CE7BEC	9496 816045	ALLA BELYAEVA	{"phone": "+70870547128"}
0005433233720	4A0329	2878 488493	TATYANA NIKITINA	{"email": "nikitina-tatyana-121969@postgrespro.ru", "phone": "+70849914263"}
0005433233721	FFCB52	8808 264361	LIDIYA BORISOVA	{"phone": "+70238611801"}
0005433233722	FFCB52	3528 104118	VALERIY SCHERBAKOV	{"email": "scherbakov.v.1979@postgrespro.ru", "phone": "+70613629581"}
0005433233723	FFCB52	7634 592549	VALERIY PAVLOV	{"email": "pavlovvaleriy.17061976@postgrespro.ru", "phone": "+70626405626"}
0005433233724	C04718	5412 502882	EVGENIYA MAKSIMOVA	{"email": "evgeniya_maksimova.1972@postgrespro.ru", "phone": "+70665371905"}
0005433233725	7F8AF9	2951 017107	OLGA SERGEEVA	{"email": "sergeevaolga_23031981@postgrespro.ru", "phone": "+70254511049"}
0005433233726	7F8AF9	9491 210502	ZOYA ILINA	{"phone": "+70656438847"}
0005433233727	7DF2B3	1703 836124	IGOR TIKHONOV	{"phone": "+70187646193"}
0005433233728	771CA6	0171 671482	IRINA MOISEEVA	{"phone": "+70822201288"}
0005433233729	2C6A22	0834 882411	SOFIYA MAKSIMOVA	{"email": "maksimovas1975@postgrespro.ru", "phone": "+70937133423"}
0005433233730	B9FC90	9806 107035	VLADIMIR KULIKOV	{"phone": "+70908341812"}
0005433233731	B9FC90	1330 109750	ELENA OVCHINNIKOVA	{"phone": "+70673913395"}
0005433233732	B9FC90	7934 921206	NATALYA LOGINOVA	{"email": "loginova_natalya071970@postgrespro.ru", "phone": "+70909514600"}
0005433233733	6D288D	9622 832180	OLEG SERGEEV	{"email": "oleg-sergeev-1967@postgrespro.ru", "phone": "+70699996548"}
0005433233734	51663B	0220 044979	KRISTINA GAVRILOVA	{"phone": "+70878644081"}
0005433233735	C01441	6621 888024	SERGEY IVANOV	{"email": "ivanovs_1967@postgrespro.ru", "phone": "+70268535672"}
0005433233736	760D4D	9414 717210	TATYANA EFIMOVA	{"phone": "+70698227336"}
0005433233737	FCEDE1	9505 055384	VARVARA AKIMOVA	{"phone": "+70393188712"}
0005433233738	A7E45F	9655 311221	IGOR CHERNOV	{"phone": "+70216084793"}
0005433233739	70D442	4626 968322	GALINA GRISHINA	{"phone": "+70724956014"}
0005433233740	70D442	1493 630295	OLGA TITOVA	{"phone": "+70340469891"}
0005433233741	F852A6	0207 223550	ANGELINA EFIMOVA	{"phone": "+70362774676"}
0005433233742	DF5059	1521 263075	MAKSIM BORISOV	{"phone": "+70800768523"}
0005433233743	235A00	3042 512382	VADIM SMIRNOV	{"email": "smirnovvadim.21021982@postgrespro.ru", "phone": "+70672755976"}
0005433233744	235A00	2033 841082	ANNA PAVLOVA	{"phone": "+70181523771"}
0005433233745	B669C4	2959 837631	YULIYA NOVIKOVA	{"email": "yuliya-novikova-09031968@postgrespro.ru", "phone": "+70560446933"}
0005433233746	5EB073	6475 152700	NATALYA DMITRIEVA	{"phone": "+70006377650"}
0005433233747	AC46A9	3214 882485	EKATERINA AFANASEVA	{"phone": "+70445206047"}
0005433233748	AC46A9	4252 255529	TAMARA YUDINA	{"email": "yudina_tamara_1965@postgrespro.ru", "phone": "+70860520022"}
0005433233749	2770BB	8134 322755	ANDREY FILIPPOV	{"email": "andrey_filippov-1965@postgrespro.ru", "phone": "+70006993706"}
0005433233750	574513	4984 307602	VLADIMIR NAZAROV	{"phone": "+70886162912"}
0005433233751	6BED82	0784 253973	ALEKSANDR GRIGOREV	{"phone": "+70356510720"}
0005433233752	12D4BD	2223 103083	GENNADIY ROMANOV	{"email": "romanov-g-23061975@postgrespro.ru", "phone": "+70075575049"}
0005433233753	910822	8748 434201	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr1973@postgrespro.ru", "phone": "+70817040606"}
0005433233754	910822	1806 107073	ZOYA SOKOLOVA	{"email": "zoya-sokolova1990@postgrespro.ru", "phone": "+70169147552"}
0005433233755	807C71	5054 978423	NATALYA KUZMINA	{"phone": "+70709065626"}
0005433233756	807C71	4051 896510	SERGEY POPOV	{"phone": "+70517330272"}
0005433233757	9CA372	3175 441040	NIKOLAY DMITRIEV	{"phone": "+70160510847"}
0005433233758	F82836	8100 064745	SERGEY BONDARENKO	{"email": "sergey_bondarenko_081964@postgrespro.ru", "phone": "+70213064976"}
0005433233759	3A2C0E	1129 088429	NATALYA ILINA	{"phone": "+70695177313"}
0005433233760	99DA69	5400 934853	LIDIYA YAKOVLEVA	{"phone": "+70271573442"}
0005433233761	99DA69	0156 641788	EKATERINA KOZLOVA	{"phone": "+70001190831"}
0005433233762	0ECF84	8053 756935	VLADIMIR VOLKOV	{"email": "vladimir-volkov.1977@postgrespro.ru", "phone": "+70078596934"}
0005433233763	CD10F4	2714 185215	VITALIY SEMENOV	{"phone": "+70394449908"}
0005433233764	BFBBDC	2456 837245	ALINA ANTONOVA	{"email": "alinaantonova-051973@postgrespro.ru", "phone": "+70126941040"}
0005433233765	5361CC	4200 783248	ANDREY KUZNECOV	{"phone": "+70856462719"}
0005433233766	22E2B8	5620 874644	NINA KOROLEVA	{"phone": "+70778495705"}
0005433233767	990608	3838 999643	NINA IVANOVA	{"email": "n_ivanova081979@postgrespro.ru", "phone": "+70543288144"}
0005433233768	990608	8460 713649	LYUDMILA PAVLOVA	{"phone": "+70654478221"}
0005433233769	556BE8	9729 078544	TATYANA KRASNOVA	{"email": "tatyana-krasnova1973@postgrespro.ru", "phone": "+70749518222"}
0005433233770	556BE8	7890 151111	OLGA KUDRYASHOVA	{"email": "kudryashovao.1991@postgrespro.ru", "phone": "+70707110007"}
0005433233771	A6DF97	9003 689516	TALGAT KUZNECOV	{"email": "kuznecovtalgat091974@postgrespro.ru", "phone": "+70693427853"}
0005433233772	A6DF97	4990 739178	ALEKSANDR KOZLOV	{"phone": "+70956572904"}
0005433233773	89796E	1998 647451	VASILIY SAVELEV	{"email": "savelev-vasiliy_1987@postgrespro.ru", "phone": "+70718895474"}
0005433233774	1AE7FB	4294 195330	EKATERINA OSIPOVA	{"email": "eosipova.09051970@postgrespro.ru", "phone": "+70403104608"}
0005433233775	4EE81C	4579 280543	LINAR SERGEEV	{"email": "linarsergeev-08121970@postgrespro.ru", "phone": "+70087259929"}
0005433233776	94B3BF	8560 543329	VLADIMIR ALEKSEEV	{"email": "vladimir_alekseev1969@postgrespro.ru", "phone": "+70111632672"}
0005433233777	94B3BF	0904 849094	ALEKSEY MIRONOV	{"email": "mironov.aleksey04061967@postgrespro.ru", "phone": "+70397719851"}
0005433233778	C824F3	5920 665078	EKATERINA KRASNOVA	{"phone": "+70806148712"}
0005433233779	C824F3	4983 620788	IGOR PAVLOV	{"email": "igor.pavlov-021973@postgrespro.ru", "phone": "+70251361514"}
0005433233780	75D3A6	5621 661893	YURIY SCHERBAKOV	{"phone": "+70237478613"}
0005433233781	2FB742	2081 901916	MARINA BARANOVA	{"phone": "+70001235240"}
0005433233782	4DD3C2	4902 476771	VIKTOR KOZLOV	{"email": "viktor.kozlov-1966@postgrespro.ru", "phone": "+70107837781"}
0005433233783	80E747	3747 757948	ALEKSANDR BONDARENKO	{"email": "bondarenko_a.081961@postgrespro.ru", "phone": "+70531055987"}
0005433233784	1DCA9D	0997 091100	ANDREY KULIKOV	{"email": "kulikova.02091968@postgrespro.ru", "phone": "+70606750159"}
0005433233785	1DCA9D	9121 936845	MARGARITA SEMENOVA	{"phone": "+70566449435"}
0005433233786	468636	1060 649923	ELENA GERASIMOVA	{"phone": "+70829187526"}
0005433233787	B0D805	0983 218735	ANNA FOMINA	{"phone": "+70327282147"}
0005433233788	C55577	1024 836491	ANNA FILIPPOVA	{"phone": "+70920841010"}
0005433233789	E582D2	0255 946653	NIKOLAY ZHUKOV	{"phone": "+70844980338"}
0005433233790	25DE64	6187 838945	SVETLANA MAKAROVA	{"email": "makarova-s.031969@postgrespro.ru", "phone": "+70740074143"}
0005433233791	25DE64	9266 083790	KIRILL ANDREEV	{"phone": "+70546401037"}
0005433233792	B594ED	7490 934217	ALEKSANDRA KOVALEVA	{"email": "a-kovaleva.1971@postgrespro.ru", "phone": "+70092727000"}
0005433233793	B594ED	1485 451844	ARTEM AFANASEV	{"phone": "+70368806792"}
0005433233794	FD3E0B	4870 309475	ARTEM GAVRILOV	{"phone": "+70958191557"}
0005433233795	FD3E0B	1928 929569	LYUBOV FOMINA	{"phone": "+70859738581"}
0005433233796	B981DF	1566 412825	LIDIYA ISAEVA	{"email": "lidiyaisaeva121965@postgrespro.ru", "phone": "+70266778066"}
0005433233797	B981DF	0150 096756	ARTEM NIKITIN	{"email": "anikitin1963@postgrespro.ru", "phone": "+70738574569"}
0005433233798	4A452B	0228 350373	VLADIMIR TIKHONOV	{"email": "v_tikhonov031971@postgrespro.ru", "phone": "+70190621212"}
0005433233799	82C5EC	3501 930565	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev-02011975@postgrespro.ru", "phone": "+70733242117"}
0005433233800	781455	3919 090686	VASILIY KUZMIN	{"email": "kuzmin_v.041966@postgrespro.ru", "phone": "+70024269805"}
0005433233801	AF343A	0299 605693	NIKOLAY MOROZOV	{"email": "nmorozov-1969@postgrespro.ru", "phone": "+70253909039"}
0005433233802	AF343A	7605 418478	ALSU ABRAMOVA	{"email": "alsu_abramova_1970@postgrespro.ru", "phone": "+70020580081"}
0005433233803	BBDA57	5405 106255	LYUDMILA NAUMOVA	{"phone": "+70078164924"}
0005433233804	BBDA57	8740 580875	OLGA NIKOLAEVA	{"email": "nikolaeva.o_091968@postgrespro.ru", "phone": "+70243606427"}
0005433233805	1060C2	6486 885539	VLADIMIR KOROLEV	{"phone": "+70514524727"}
0005433233806	1060C2	7610 430818	ANGELINA TARASOVA	{"email": "tarasova-a28091979@postgrespro.ru", "phone": "+70078903660"}
0005433233807	5C5F07	3703 091073	VLADIMIR VASILEV	{"phone": "+70639112200"}
0005433233808	CD8D85	1864 897685	ANTONINA KUZNECOVA	{"email": "kuznecova-antonina.1965@postgrespro.ru", "phone": "+70692857596"}
0005433233809	34DD08	7263 400575	TATYANA SMIRNOVA	{"phone": "+70519281395"}
0005433233810	7FC2E7	2347 511607	ALEKSANDR ZHURAVLEV	{"phone": "+70152078942"}
0005433233811	030CFE	0740 324095	MAKSIM RODIONOV	{"phone": "+70070544559"}
0005433233812	7701E9	2561 793923	SVETLANA AFANASEVA	{"phone": "+70062117285"}
0005433233813	E4E517	5355 016458	EVGENIY ILIN	{"email": "ilin_e_071963@postgrespro.ru", "phone": "+70786856038"}
0005433233814	E4E517	7588 737194	OLESYA MASLOVA	{"email": "omaslova_1971@postgrespro.ru", "phone": "+70404263439"}
0005433233815	7A5711	0325 346908	TATYANA TITOVA	{"email": "t-titova1971@postgrespro.ru", "phone": "+70145265230"}
0005433233816	2968C0	8912 668306	ALEKSANDR MELNIKOV	{"email": "a.melnikov.1965@postgrespro.ru", "phone": "+70903832268"}
0005433233817	7D3264	8538 504749	ANNA AFANASEVA	{"email": "afanaseva-anna021977@postgrespro.ru", "phone": "+70476595545"}
0005433233818	D05A31	4521 884305	VERA KOZLOVA	{"email": "kozlova.vera_1972@postgrespro.ru", "phone": "+70761930401"}
0005433233819	CDD9A2	7458 219757	ALEKSANDR VOROBEV	{"email": "vorobev.a.031965@postgrespro.ru", "phone": "+70217686743"}
0005433233820	64E51D	2826 113020	ANATOLIY BARANOV	{"phone": "+70661628291"}
0005433233821	02794C	8561 382794	PAVEL STEPANOV	{"email": "pavel.stepanov_19071970@postgrespro.ru", "phone": "+70615269050"}
0005433233822	02794C	5952 684754	EKATERINA KUZNECOVA	{"email": "ekuznecova28111976@postgrespro.ru", "phone": "+70525698408"}
0005433233823	E5F6FB	2419 365319	EVGENIY VOLKOV	{"email": "volkov-evgeniy.1990@postgrespro.ru", "phone": "+70501387465"}
0005433233824	E5F6FB	9985 083146	ARTEM YAKOVLEV	{"email": "a_yakovlev1970@postgrespro.ru", "phone": "+70487641055"}
0005433233825	A39AF7	0531 089938	OLGA POPOVA	{"email": "popovao_1983@postgrespro.ru", "phone": "+70843333173"}
0005433233826	A39AF7	7147 236733	ILYA KUZNECOV	{"phone": "+70236772681"}
0005433233827	4EFF60	0421 388673	OLEG STEPANOV	{"phone": "+70253022047"}
0005433233828	7BA01D	1736 792092	NATALIYA ZAYCEVA	{"email": "zayceva_n.06071973@postgrespro.ru", "phone": "+70932982101"}
0005433233829	7BA01D	3687 357486	ANTON ZHUKOV	{"email": "azhukov08081975@postgrespro.ru", "phone": "+70058165837"}
0005433233830	3BD41F	0441 334225	ANASTASIYA SCHERBAKOVA	{"phone": "+70405832136"}
0005433233831	1CDCEC	8197 556378	EKATERINA ALEKSANDROVA	{"email": "ekaterinaaleksandrova-091972@postgrespro.ru", "phone": "+70845615705"}
0005433233832	1CDCEC	3738 498421	ANTONINA RYABOVA	{"email": "a.ryabova-1966@postgrespro.ru", "phone": "+70390415171"}
0005433233833	24B300	3623 768850	VLADIMIR EGOROV	{"email": "v.egorov.1975@postgrespro.ru", "phone": "+70946429970"}
0005433233834	9F3E78	1281 740615	VALERIYA FEDOROVA	{"phone": "+70284892489"}
0005433233835	00FFAD	8989 715041	ZOYA KUZNECOVA	{"email": "zoya_kuznecova101963@postgrespro.ru", "phone": "+70079013489"}
0005433233836	407B46	5505 368552	ILSHAT DENISOV	{"email": "denisov_ilshat.1972@postgrespro.ru", "phone": "+70732619220"}
0005433233837	407B46	9418 631574	OLEG SOLOVEV	{"phone": "+70734134843"}
0005433233838	F3FDB8	0416 274027	LYUDMILA STEPANOVA	{"phone": "+70765396080"}
0005433233839	F3FDB8	8781 658991	SHAMIL TARASOV	{"email": "tarasov.shamil.1962@postgrespro.ru", "phone": "+70360671150"}
0005433233840	95232C	8478 652366	POLINA DENISOVA	{"email": "p_denisova.101977@postgrespro.ru", "phone": "+70603498901"}
0005433233841	71F2F5	1296 967137	SERGEY SCHERBAKOV	{"phone": "+70081826157"}
0005433233842	71F2F5	4696 115893	VIKTOR NOVIKOV	{"email": "novikov-viktor041976@postgrespro.ru", "phone": "+70637160026"}
0005433233843	343AE6	3803 038645	VIKTOR SERGEEV	{"phone": "+70972008668"}
0005433233844	A0C1DF	0334 178482	ANASTASIYA YAKOVLEVA	{"email": "yakovleva_a-22111975@postgrespro.ru", "phone": "+70629721400"}
0005433233845	A0C1DF	5017 855823	SERGEY KUZNECOV	{"email": "kuznecov.s.16121977@postgrespro.ru", "phone": "+70916244722"}
0005433233846	C347B5	6696 993484	LYUDMILA MIRONOVA	{"email": "mironova.l28041964@postgrespro.ru", "phone": "+70385921851"}
0005433233847	C347B5	2870 733062	ALEKSEY YAKOVLEV	{"phone": "+70612106042"}
0005433233848	C6F6A6	5256 147527	ALEKSANDR BORISOV	{"email": "aleksandrborisov021972@postgrespro.ru", "phone": "+70730284980"}
0005433233849	7FE834	7996 163924	ANTONINA SMIRNOVA	{"email": "a.smirnova061958@postgrespro.ru", "phone": "+70443420387"}
0005433233850	7FE834	6927 349881	VADIM KUZMIN	{"email": "vadim.kuzmin-101966@postgrespro.ru", "phone": "+70106479133"}
0005433233851	082E48	6868 720908	EKATERINA SAVELEVA	{"phone": "+70929204198"}
0005433233852	082E48	7110 100882	ZINAIDA SOKOLOVA	{"phone": "+70458567813"}
0005433233853	39EBA9	9023 538337	OLGA ZAYCEVA	{"email": "olga_zayceva1964@postgrespro.ru", "phone": "+70419777339"}
0005433233854	4600F6	3951 293379	ALEKSANDR MIRONOV	{"email": "mironova.03031975@postgrespro.ru", "phone": "+70961398397"}
0005433233855	4600F6	8999 720264	NIKOLAY MIRONOV	{"phone": "+70565562004"}
0005433233856	33284A	9089 699127	DMITRIY KUZNECOV	{"phone": "+70559975991"}
0005433233857	539216	8864 876239	TATYANA BOGDANOVA	{"email": "tatyana.bogdanova.121972@postgrespro.ru", "phone": "+70107959513"}
0005433233858	444B6D	2293 135386	FARID PETROV	{"phone": "+70542547359"}
0005433233859	9916FA	2311 573034	TAMARA MEDVEDEVA	{"email": "tamara-medvedeva-1967@postgrespro.ru", "phone": "+70406668482"}
0005433233860	9916FA	4595 752276	MARIYA PETROVA	{"email": "petrova_mariya02121982@postgrespro.ru", "phone": "+70494533787"}
0005433233861	360730	6574 228649	GENNADIY BARANOV	{"email": "baranovgennadiy041971@postgrespro.ru", "phone": "+70454474012"}
0005433233862	893EF6	9225 512395	ALEKSANDRA DMITRIEVA	{"phone": "+70057577522"}
0005433233863	893EF6	0802 453535	NINA KULIKOVA	{"email": "kulikova.n_1974@postgrespro.ru", "phone": "+70663929136"}
0005433233864	9EB3CD	2389 149886	ELENA SAVELEVA	{"phone": "+70006729431"}
0005433233865	9EB3CD	8224 346758	DMITRIY VOLKOV	{"phone": "+70202360487"}
0005433233866	96F72D	3742 753785	VERA DMITRIEVA	{"phone": "+70694643447"}
0005433233867	96F72D	8548 811274	ANNA NESTEROVA	{"email": "nesterova.anna_23031976@postgrespro.ru", "phone": "+70575364607"}
0005433233868	8904E0	0361 169383	NADEZHDA ERMAKOVA	{"email": "n_ermakova_041976@postgrespro.ru", "phone": "+70086460724"}
0005433233869	8904E0	4536 942064	ALEKSANDR POPOV	{"email": "popov.aleksandr12121968@postgrespro.ru", "phone": "+70084943317"}
0005433233870	5A4675	7061 951703	MAKSIM SCHERBAKOV	{"email": "scherbakov-maksim.081979@postgrespro.ru", "phone": "+70914427090"}
0005433233871	5A4675	1747 082503	SHAVKAT SMIRNOV	{"phone": "+70620914945"}
0005433233872	79A107	8849 861642	VYACHESLAV GAVRILOV	{"email": "vyacheslav-gavrilov_1972@postgrespro.ru", "phone": "+70972805804"}
0005433233873	D723D1	3703 978650	ANTONINA MEDVEDEVA	{"email": "antoninamedvedeva-1976@postgrespro.ru", "phone": "+70808445166"}
0005433233874	BAD79C	7791 771643	TAMARA TROFIMOVA	{"email": "t_trofimova_1978@postgrespro.ru", "phone": "+70682311091"}
0005433233875	208B12	2520 567542	NIKOLAY OSIPOV	{"email": "osipov.nikolay_05081970@postgrespro.ru", "phone": "+70194774972"}
0005433233876	45A293	2469 060280	VALENTINA TITOVA	{"email": "titova-valentina-061970@postgrespro.ru", "phone": "+70284116380"}
0005433233877	45A293	0157 107472	ANTONINA BELOVA	{"phone": "+70854111061"}
0005433233878	2877A2	3447 368324	ANATOLIY FEDOROV	{"email": "fedorov_a-1979@postgrespro.ru", "phone": "+70080667145"}
0005433233879	F8C319	9156 982177	ANZHELA RYABOVA	{"email": "ryabovaanzhela15051985@postgrespro.ru", "phone": "+70533334988"}
0005433233880	0EB1E9	3953 191450	ELENA ABRAMOVA	{"email": "abramova.elena_29031968@postgrespro.ru", "phone": "+70849763053"}
0005433233881	03973B	1474 862756	ALEKSANDR PAVLOV	{"phone": "+70945161764"}
0005433233882	03973B	7278 512717	IRINA KOZLOVA	{"phone": "+70285905422"}
0005433233883	4494C9	1028 792825	NINA SIDOROVA	{"phone": "+70796385665"}
0005433233884	18C43A	9682 493196	GALINA ZOTOVA	{"email": "zotova.galina_1969@postgrespro.ru", "phone": "+70997658087"}
0005433233885	3E9128	3074 533259	ROMAN VASILEV	{"email": "vasilevr_1971@postgrespro.ru", "phone": "+70986364897"}
0005433233886	20E879	1627 130624	RAISA KULIKOVA	{"email": "r-kulikova_091981@postgrespro.ru", "phone": "+70161982407"}
0005433233887	A71C91	2610 448948	DARYA NOVIKOVA	{"email": "novikova-d-081978@postgrespro.ru", "phone": "+70142363281"}
0005433233888	030BBE	0506 707612	LYUBOV PAVLOVA	{"phone": "+70545233554"}
0005433233889	4316FC	5107 842222	ALEKSANDRA MALYSHEVA	{"phone": "+70558936519"}
0005433233890	4316FC	0170 196909	ALENA BELYAEVA	{"phone": "+70825591939"}
0005433233891	C6B886	5972 401676	ANNA MAKAROVA	{"email": "makarova.a-051970@postgrespro.ru", "phone": "+70745691707"}
0005433233892	BB8D17	0395 286148	DMITRIY STEPANOV	{"phone": "+70859991447"}
0005433233893	041AA9	3338 545182	MARIYA NIKOLAEVA	{"phone": "+70657995117"}
0005433233894	49D433	0677 447627	GENNADIY KARPOV	{"phone": "+70427883614"}
0005433233895	FC10B8	4570 023054	GENNADIY ISAEV	{"email": "isaev-g-101958@postgrespro.ru", "phone": "+70872582393"}
0005433233896	9062EE	2246 605657	SVETLANA EFIMOVA	{"phone": "+70655922088"}
0005433233897	BEC168	7907 722222	MAKSIM MELNIKOV	{"email": "mmelnikov-051983@postgrespro.ru", "phone": "+70859387847"}
0005433233898	BEC168	3905 490071	NIKOLAY MOROZOV	{"email": "n.morozov.1971@postgrespro.ru", "phone": "+70407701969"}
0005433233899	EA0CBE	9573 469657	ANNA ZHURAVLEVA	{"email": "zhuravleva_anna_27011960@postgrespro.ru", "phone": "+70313225203"}
0005433233900	E1A74D	9471 129533	LYUDMILA NESTEROVA	{"phone": "+70739710039"}
0005433233901	E1A74D	2856 559391	ANASTASIYA PETROVA	{"email": "anastasiya-petrova_1972@postgrespro.ru", "phone": "+70184650755"}
0005433233902	E1A74D	7101 955848	LIDIYA LAZAREVA	{"email": "llazareva101972@postgrespro.ru", "phone": "+70919984737"}
0005433233903	E1A74D	0799 123868	VLADISLAV FEDOROV	{"phone": "+70833554168"}
0005433233904	2CCF0F	3059 344847	KLAVDIYA IVANOVA	{"phone": "+70153542727"}
0005433233905	2CCF0F	7760 747586	OLGA KUZNECOVA	{"email": "kuznecova_o071971@postgrespro.ru", "phone": "+70923985568"}
0005433233906	C1B05D	1520 413825	SERGEY NIKOLAEV	{"email": "nikolaevsergey-1974@postgrespro.ru", "phone": "+70296183009"}
0005433233907	B18D16	0265 682715	DMITRIY FROLOV	{"email": "frolov-d-04021961@postgrespro.ru", "phone": "+70905241692"}
0005433233908	2B05FC	3477 853308	VADIM ANDREEV	{"phone": "+70704156868"}
0005433233909	2B05FC	1752 691787	VITALIY ABRAMOV	{"phone": "+70168527088"}
0005433233910	EFA0BE	9054 437705	ANATOLIY MATVEEV	{"phone": "+70735226783"}
0005433233911	0D2003	1074 983416	ZINAIDA DENISOVA	{"email": "denisova_z03021978@postgrespro.ru", "phone": "+70754662346"}
0005433233912	00FF9D	2478 467972	VERA PAVLOVA	{"phone": "+70290843062"}
0005433233913	00FF9D	9734 845542	SVETLANA NOVIKOVA	{"email": "novikova_s1986@postgrespro.ru", "phone": "+70544767983"}
0005433233914	B54AC8	7938 152643	VALENTINA PAVLOVA	{"email": "pavlovav_16031979@postgrespro.ru", "phone": "+70135184528"}
0005433233915	FB93B5	8479 886019	TATYANA KISELEVA	{"phone": "+70915246611"}
0005433233916	FB93B5	9186 985930	ANDREY FEDOTOV	{"phone": "+70564323541"}
0005433233917	C455B1	7223 408603	ANDREY GUSEV	{"phone": "+70512198046"}
0005433233918	AD84B2	6251 992798	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov_1971@postgrespro.ru", "phone": "+70148334703"}
0005433233919	AD84B2	4184 920726	ALEKSEY VASILEV	{"email": "vasilev-a-1976@postgrespro.ru", "phone": "+70643880954"}
0005433233920	AD84B2	6610 751862	ANNA STEPANOVA	{"email": "stepanova.anna_1971@postgrespro.ru", "phone": "+70031602362"}
0005433233921	AD84B2	7922 334384	ELIZAVETA KULIKOVA	{"email": "elizaveta_kulikova_011979@postgrespro.ru", "phone": "+70918180117"}
0005433233922	39A3BA	1324 575015	OLGA IVANOVA	{"email": "olgaivanova_111977@postgrespro.ru", "phone": "+70918910990"}
0005433233923	39A3BA	0636 842042	DMITRIY GAVRILOV	{"email": "gavrilov_dmitriy_20071974@postgrespro.ru", "phone": "+70045173756"}
0005433233924	DE26C0	5938 079200	VLADIMIR MOROZOV	{"phone": "+70947063462"}
0005433233925	DE26C0	8510 571547	VLADIMIR KOZLOV	{"phone": "+70922791966"}
0005433233926	6F04DF	1467 535915	DARYA KUZNECOVA	{"email": "darya-kuznecova_111973@postgrespro.ru", "phone": "+70990741098"}
0005433233927	6F04DF	3238 554566	ALEKSANDR DMITRIEV	{"phone": "+70276841100"}
0005433233928	640724	0828 754631	VIKTOR ZAKHAROV	{"email": "viktor.zakharov_05011978@postgrespro.ru", "phone": "+70799802452"}
0005433233929	1284FE	9222 109414	OLGA TITOVA	{"email": "titova-olga_1982@postgrespro.ru", "phone": "+70713968253"}
0005433233930	1284FE	3200 804492	VIKTOR SERGEEV	{"phone": "+70825779895"}
0005433233931	C7EADA	8264 014221	RUSLAN TIKHONOV	{"email": "rtikhonov_21051973@postgrespro.ru", "phone": "+70706990428"}
0005433233932	C7EADA	2886 442520	OLGA YAKOVLEVA	{"phone": "+70595295626"}
0005433233933	E182A5	5089 736118	MARINA GUSEVA	{"email": "guseva-m-071973@postgrespro.ru", "phone": "+70398504303"}
0005433233934	4FB706	2569 064213	KLAVDIYA GUSEVA	{"email": "guseva-k-1958@postgrespro.ru", "phone": "+70543972289"}
0005433233935	3A7129	9058 156081	VLADIMIR ISAEV	{"email": "isaev_vladimir_1967@postgrespro.ru", "phone": "+70602852698"}
0005433233936	2557FD	2655 224185	EVGENIY BELOV	{"email": "evgeniy-belov_071979@postgrespro.ru", "phone": "+70019755929"}
0005433233937	2557FD	9133 433001	EVGENIY FOMIN	{"phone": "+70150024898"}
0005433233938	964CA8	1626 987619	EVGENIY FEDOROV	{"phone": "+70531947112"}
0005433233939	964CA8	3634 422748	NATALYA POPOVA	{"phone": "+70042773378"}
0005433233940	600EDD	6824 320732	MARIYA RODIONOVA	{"phone": "+70444983802"}
0005433233941	600EDD	9757 295821	EDGAR KOZLOV	{"phone": "+70135355931"}
0005433233942	7EEF4E	5303 072404	DMITRIY GAVRILOV	{"phone": "+70706652405"}
0005433233943	DC4C0F	5520 109281	ELENA RYABOVA	{"email": "ryabova_e1969@postgrespro.ru", "phone": "+70423174451"}
0005433233944	DC4C0F	4572 607567	VYACHESLAV ZAKHAROV	{"phone": "+70350837749"}
0005433233945	673920	4490 387416	NIKITA ROMANOV	{"email": "nikitaromanov.29031976@postgrespro.ru", "phone": "+70333879746"}
0005433233946	673920	6091 958409	ANASTASIYA KUZNECOVA	{"phone": "+70032030935"}
0005433233947	D7C529	0584 252138	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-031963@postgrespro.ru", "phone": "+70380223708"}
0005433233948	D7C529	5461 247621	MAKSIM GAVRILOV	{"phone": "+70835301805"}
0005433233949	2ED9F6	5569 256923	VALERIYA RODIONOVA	{"email": "vrodionova_111953@postgrespro.ru", "phone": "+70665614439"}
0005433233950	A2F5C5	0971 368026	MARINA RODIONOVA	{"phone": "+70457731230"}
0005433233951	A2F5C5	7355 764439	ALEKSANDR NAZAROV	{"phone": "+70614055240"}
0005433233952	869CA0	3279 030800	ANNA NIKITINA	{"email": "a.nikitina02081973@postgrespro.ru", "phone": "+70540139429"}
0005433233953	869CA0	7316 653973	MARAT ZAYCEV	{"phone": "+70994141652"}
0005433233954	10FDE7	4577 325792	ALEKSANDR TIMOFEEV	{"email": "timofeevaleksandr051970@postgrespro.ru", "phone": "+70238968549"}
0005433233955	CE87CB	5609 593733	ALEKSEY DMITRIEV	{"email": "a.dmitriev-1973@postgrespro.ru", "phone": "+70736824920"}
0005433233956	CE87CB	8178 993175	ROMAN KUZNECOV	{"phone": "+70534265665"}
0005433233957	FA5F7C	2984 180129	ALEKSEY NIKITIN	{"email": "aleksey_nikitin1966@postgrespro.ru", "phone": "+70526954767"}
0005433233958	FA5F7C	1747 837588	KHALIDA BOGDANOVA	{"phone": "+70334724039"}
0005433233959	FA5F7C	5011 463270	ELENA KISELEVA	{"phone": "+70831646407"}
0005433233960	08646E	3617 598133	TATYANA ANISIMOVA	{"email": "t.anisimova-09061975@postgrespro.ru", "phone": "+70080621758"}
0005433233961	4DBFEA	0661 602009	BOGDAN MEDVEDEV	{"phone": "+70231206020"}
0005433233962	4DBFEA	6213 715985	ANASTASIYA SERGEEVA	{"phone": "+70615865965"}
0005433233963	5466D1	6708 990819	MARIYA KOZLOVA	{"email": "kozlova.m.28021976@postgrespro.ru", "phone": "+70964892998"}
0005433233964	0C1D69	2710 003704	ALEKSANDR MATVEEV	{"email": "aleksandr.matveev-1982@postgrespro.ru", "phone": "+70794012522"}
0005433233965	0C1D69	3065 168363	ILYA KULIKOV	{"phone": "+70308702895"}
0005433233966	4999B7	0688 602069	DARYA BELYAEVA	{"email": "belyaevadarya-07031983@postgrespro.ru", "phone": "+70429412123"}
0005433233967	84FE9F	1146 382828	SVETLANA ANDREEVA	{"email": "andreevas1960@postgrespro.ru", "phone": "+70561005896"}
0005433233968	84FE9F	0881 081183	ARTEM SHEVCHENKO	{"email": "shevchenkoa1968@postgrespro.ru", "phone": "+70016714940"}
0005433233969	84FE9F	7106 403508	PAVEL NIKITIN	{"email": "nikitin_pavel.19041963@postgrespro.ru", "phone": "+70288529995"}
0005433233970	C14745	5272 343799	SERGEY MOROZOV	{"phone": "+70791411933"}
0005433233971	FB1496	9936 367891	FLYURA BORISOVA	{"email": "borisova_flyura_101960@postgrespro.ru", "phone": "+70516212582"}
0005433233972	D22600	8853 711922	NINA ZHUKOVA	{"email": "ninazhukova18051978@postgrespro.ru", "phone": "+70006693663"}
0005433233973	D22600	8391 727352	RAISA DANILOVA	{"email": "danilova.raisa.091966@postgrespro.ru", "phone": "+70737118436"}
0005433233974	46A94E	2230 717181	IVAN SIDOROV	{"phone": "+70183133634"}
0005433233975	46A94E	5583 442540	MARIYA KOROLEVA	{"phone": "+70226045536"}
0005433233976	B8C146	9666 545780	LYUBOV ILINA	{"email": "lyubov_ilina-1977@postgrespro.ru", "phone": "+70190334069"}
0005433233977	193A49	7902 169212	LYUBOV LEBEDEVA	{"email": "lebedeval-1981@postgrespro.ru", "phone": "+70803647302"}
0005433233978	FF876E	5345 623521	NATALYA IVANOVA	{"phone": "+70387330944"}
0005433233979	FF876E	1274 360038	YULIYA MIKHAYLOVA	{"phone": "+70948144887"}
0005433233980	36BB64	0646 147326	KIRILL FILIPPOV	{"email": "filippov.kirill.1971@postgrespro.ru", "phone": "+70115271457"}
0005433233981	0D53D4	7912 950189	ANDREY ANTONOV	{"email": "antonov-a.1963@postgrespro.ru", "phone": "+70698202853"}
0005433233982	0D53D4	5607 827347	SVETLANA KALININA	{"email": "kalininas.1977@postgrespro.ru", "phone": "+70768072496"}
0005433233983	9372C4	2513 519816	VIKTOR MAKSIMOV	{"email": "maksimov_viktor.1974@postgrespro.ru", "phone": "+70322974780"}
0005433233984	3BD536	4227 143565	ANTONINA SOROKINA	{"email": "sorokina.a-101977@postgrespro.ru", "phone": "+70187839299"}
0005433233985	5C2CF9	5075 357925	ALEKSANDR KISELEV	{"email": "kiseleva1976@postgrespro.ru", "phone": "+70102516538"}
0005433233986	2C3AE4	7219 765068	VALERIY KUZNECOV	{"phone": "+70345563183"}
0005433233987	122805	3939 266299	NATALYA ROMANOVA	{"phone": "+70462235074"}
0005433233988	7A8D97	2378 464022	OLESYA FROLOVA	{"email": "o.frolova-08061963@postgrespro.ru", "phone": "+70163482466"}
0005433233989	CBE683	3862 774028	ARINA CHERNOVA	{"phone": "+70083321060"}
0005433233990	9CE974	8835 162964	VALENTINA VOLKOVA	{"phone": "+70431519105"}
0005433233991	61BB3D	4517 050843	DANIIL NOVIKOV	{"phone": "+70236933461"}
0005433233992	5C3824	8293 428710	SVETLANA ANTONOVA	{"phone": "+70047830771"}
0005433233993	5C3824	9454 380766	NIKOLAY EGOROV	{"email": "nikolay_egorov.20091965@postgrespro.ru", "phone": "+70491139391"}
0005433233994	C65A5E	7588 098207	IRINA ABRAMOVA	{"phone": "+70633753541"}
0005433233995	5A9FEE	6078 139866	DANILA SERGEEV	{"email": "sergeev.danila101960@postgrespro.ru", "phone": "+70417078414"}
0005433233996	5A9FEE	9464 759359	MIKHAIL BORISOV	{"phone": "+70346888154"}
0005433233997	888FA9	6288 678759	ALBERT SOKOLOV	{"phone": "+70822960735"}
0005433233998	353932	8704 982471	NATALYA ZHURAVLEVA	{"email": "zhuravleva.n1972@postgrespro.ru", "phone": "+70472074021"}
0005433233999	C20385	0162 027691	VLADIMIR FROLOV	{"email": "vladimir_frolov081965@postgrespro.ru", "phone": "+70280567708"}
0005433234000	313A3B	3448 724846	SERGEY VLASOV	{"email": "vlasov.sergey-1969@postgrespro.ru", "phone": "+70853426449"}
0005433234001	BF6038	7274 640947	GENNADIY SMIRNOV	{"phone": "+70625001223"}
0005433234002	717A75	6100 525284	ANTONINA MEDVEDEVA	{"phone": "+70909913541"}
0005433234003	717A75	7176 610834	SOFYA ZOTOVA	{"email": "sofya.zotova.011987@postgrespro.ru", "phone": "+70529914516"}
0005433234004	717A75	1475 973003	ANATOLIY ALEKSEEV	{"phone": "+70443829044"}
0005433234005	6928E8	1749 569309	TATYANA FILIPPOVA	{"email": "filippova-t-091971@postgrespro.ru", "phone": "+70959789034"}
0005433234006	2D5549	5278 254771	NADEZHDA KUDRYASHOVA	{"phone": "+70719776379"}
0005433234007	922F08	2848 208383	POLINA ORLOVA	{"phone": "+70755843344"}
0005433234008	81C74F	2797 229553	VERA TIKHONOVA	{"email": "tikhonovavera21021977@postgrespro.ru", "phone": "+70602883602"}
0005433234009	81C74F	4571 732289	EVGENIY SCHERBAKOV	{"email": "evgeniy_scherbakov_1975@postgrespro.ru", "phone": "+70334362351"}
0005433234010	4DEC18	8915 762367	OLGA SOKOLOVA	{"phone": "+70484255381"}
0005433234011	4DEC18	2696 991401	IRINA DMITRIEVA	{"phone": "+70086503798"}
0005433234012	D6D717	5409 366289	VLADIMIR SCHERBAKOV	{"phone": "+70195361802"}
0005433234013	0E05D5	3280 373484	VYACHESLAV POPOV	{"phone": "+70487904810"}
0005433234014	D2D158	4677 678972	KIRILL PAVLOV	{"phone": "+70402178722"}
0005433234015	741252	3212 133216	DENIS KOZLOV	{"email": "d-kozlov-31121969@postgrespro.ru", "phone": "+70594528428"}
0005433234016	741252	2462 613250	ELDAR ZHUKOV	{"phone": "+70799568148"}
0005433234017	4A3F30	9804 833588	IRINA FROLOVA	{"phone": "+70042079867"}
0005433234018	4A3F30	8273 973195	DENIS SCHERBAKOV	{"email": "denis_scherbakov-011971@postgrespro.ru", "phone": "+70291499318"}
0005433234019	8EB283	5729 930984	NATALYA PETROVA	{"email": "petrova-n16081974@postgrespro.ru", "phone": "+70208226489"}
0005433234020	146AC7	7871 697099	ALEKSANDR PAVLOV	{"email": "apavlov.111975@postgrespro.ru", "phone": "+70747386182"}
0005433234021	1E8569	6908 872071	KSENIYA VASILEVA	{"email": "kseniya.vasileva_1959@postgrespro.ru", "phone": "+70293834350"}
0005433234022	DD8593	7762 349610	ANTON SOLOVEV	{"email": "anton-solovev-091982@postgrespro.ru", "phone": "+70569150847"}
0005433234023	8C9F63	7521 902996	VALENTINA KISELEVA	{"phone": "+70210503208"}
0005433234024	5A7E76	0309 895782	SERGEY MAKAROV	{"email": "sergeymakarov-1985@postgrespro.ru", "phone": "+70855579872"}
0005433234025	DF1047	8538 098498	MARIYA MIKHAYLOVA	{"phone": "+70049718606"}
0005433234026	DF1047	4056 946019	GENNADIY MIKHAYLOV	{"phone": "+70089536604"}
0005433234027	F4708A	7239 666363	DMITRIY YAKOVLEV	{"email": "yakovlev-d.031973@postgrespro.ru", "phone": "+70068962035"}
0005433234028	F4708A	8933 181663	YULIYA MIRONOVA	{"email": "mironova-yuliya_1970@postgrespro.ru", "phone": "+70233242315"}
0005433234029	026B7F	6043 527978	TATYANA KUZNECOVA	{"email": "kuznecova.t.031971@postgrespro.ru", "phone": "+70997139708"}
0005433234030	026B7F	1748 899308	VALENTINA IVANOVA	{"email": "ivanovavalentina081970@postgrespro.ru", "phone": "+70766292566"}
0005433234031	7560EF	6824 383354	SALAVAT IVANOV	{"email": "ivanov.s_081972@postgrespro.ru", "phone": "+70770066909"}
0005433234032	B7F4D6	1384 156157	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr-051981@postgrespro.ru", "phone": "+70987252197"}
0005433234033	ADF650	9982 534259	VLADISLAV IVANOV	{"email": "ivanov.v.29011958@postgrespro.ru", "phone": "+70859536619"}
0005433234034	980193	1974 648962	KSENIYA OSIPOVA	{"phone": "+70511632378"}
0005433234035	980193	3007 597292	ILYA ILIN	{"email": "ilinilya081978@postgrespro.ru", "phone": "+70715230805"}
0005433234036	6D5842	3210 915381	ALEKSANDR PAVLOV	{"phone": "+70911450464"}
0005433234037	E8A613	3485 618603	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-tatyana-26011958@postgrespro.ru", "phone": "+70808125900"}
0005433234038	E8A613	8140 192095	MAKSIM MAKAROV	{"phone": "+70380484644"}
0005433234039	6C36F9	5857 109532	VERA VOLKOVA	{"phone": "+70293786588"}
0005433234040	AE7CA1	8594 644162	ANNA FEDOROVA	{"phone": "+70374667602"}
0005433234041	AE7CA1	7755 219064	MARIYA ZAYCEVA	{"phone": "+70254104202"}
0005433234042	AE7CA1	7794 017465	ANDREY OSIPOV	{"phone": "+70438918989"}
0005433234043	19D018	2254 609076	ELENA ANDREEVA	{"phone": "+70742850004"}
0005433234044	49E457	7548 719096	ALEKSEY ALEKSEEV	{"phone": "+70344902809"}
0005433234045	84D616	8238 267218	DARYA SEMENOVA	{"phone": "+70260321339"}
0005433234046	84D616	7388 661251	NATALYA KOVALEVA	{"phone": "+70730298474"}
0005433234047	BD92F9	0895 776463	ALEKSANDR DAVYDOV	{"phone": "+70996708690"}
0005433234048	B31553	6833 346291	VASILIY ANTONOV	{"email": "antonov.vasiliy.13071962@postgrespro.ru", "phone": "+70800942839"}
0005433234049	721138	4840 042392	GALIYA DAVYDOVA	{"email": "davydova-galiya.12071971@postgrespro.ru", "phone": "+70374051435"}
0005433234050	303AD8	5738 287570	MARINA TARASOVA	{"email": "tarasovam-071968@postgrespro.ru", "phone": "+70494634718"}
0005433234051	303AD8	1532 949519	ALEKSANDR NIKOLAEV	{"phone": "+70462840115"}
0005433234052	EF40D8	4478 379811	DMITRIY FEDOROV	{"email": "dmitriy-fedorov1977@postgrespro.ru", "phone": "+70238359596"}
0005433234053	997ECC	7820 460182	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_121970@postgrespro.ru", "phone": "+70719533734"}
0005433234054	997ECC	8957 863447	ILYA SIDOROV	{"email": "sidorov_i-1975@postgrespro.ru", "phone": "+70706470708"}
0005433234055	40EFFE	8336 581439	MIKHAIL PETROV	{"email": "m.petrov-1975@postgrespro.ru", "phone": "+70791474288"}
0005433234056	38BC50	0456 735649	LYUBOV KULIKOVA	{"email": "l-kulikova021976@postgrespro.ru", "phone": "+70830541920"}
0005433234057	79B69D	8074 056490	OLGA SERGEEVA	{"phone": "+70226503628"}
0005433234058	E3364B	1292 243407	DMITRIY KUZNECOV	{"phone": "+70911183915"}
0005433234059	B68AD5	3243 844572	ANDREY PAVLOV	{"phone": "+70442242352"}
0005433234060	E1CCA1	3829 499002	ALEKSANDR ILIN	{"phone": "+70267045835"}
0005433234061	254EF4	5411 342799	DMITRIY MAKSIMOV	{"email": "maksimov-dmitriy.22031962@postgrespro.ru", "phone": "+70877510606"}
0005433234062	9BCEAC	6324 533378	TAISIYA NAZAROVA	{"phone": "+70913259012"}
0005433234063	52C13D	6771 406601	IRINA SEMENOVA	{"email": "i_semenova_1971@postgrespro.ru", "phone": "+70659756427"}
0005433234064	E1EA4C	2589 028797	MAKSIM TIKHONOV	{"phone": "+70708813565"}
0005433234065	9D617C	2266 848105	MARIYA NESTEROVA	{"email": "nesterovam.031972@postgrespro.ru", "phone": "+70818925343"}
0005433234066	77871D	8041 747390	NIKITA FEDOROV	{"phone": "+70137888050"}
0005433234067	F872B3	7909 910327	ANNA LAZAREVA	{"phone": "+70730090964"}
0005433234068	8E07D3	8735 085504	DENIS ISAEV	{"email": "denisisaev1978@postgrespro.ru", "phone": "+70178000239"}
0005433234069	B202FA	5691 491255	ALEKSANDR KOROLEV	{"phone": "+70010198067"}
0005433234070	0705FC	2694 060476	ANDREY VLASOV	{"phone": "+70382415309"}
0005433234071	9A3B8C	0024 225374	LIDIYA AFANASEVA	{"phone": "+70159101524"}
0005433234072	5FCA09	0981 872586	YULIYA EFIMOVA	{"email": "efimova.yuliya.1977@postgrespro.ru", "phone": "+70303909590"}
0005433234073	B4185B	9048 230249	EKATERINA STEPANOVA	{"phone": "+70939425706"}
0005433234074	EBBFE6	6951 425318	LARISA ALEKSEEVA	{"email": "alekseeva_l_07021969@postgrespro.ru", "phone": "+70280453864"}
0005433234075	7F8BE8	3543 878159	NATALYA SMIRNOVA	{"email": "n.smirnova_011972@postgrespro.ru", "phone": "+70430385822"}
0005433234076	7F8BE8	4281 740976	ELENA VOROBEVA	{"email": "e-vorobeva011974@postgrespro.ru", "phone": "+70041878014"}
0005433234077	D5C9E3	2051 012146	ROMAN ISAEV	{"phone": "+70656231020"}
0005433234078	97BA2D	1181 789176	OKSANA KUZNECOVA	{"email": "kuznecova-oksana-1978@postgrespro.ru", "phone": "+70359774754"}
0005433234079	1AB2E9	7731 185674	ANATOLIY MEDVEDEV	{"email": "medvedev.a.1970@postgrespro.ru", "phone": "+70980463389"}
0005433234080	33C43A	5701 098344	KSENIYA MOROZOVA	{"email": "morozovakseniya111973@postgrespro.ru", "phone": "+70036771273"}
0005433234081	FE85D2	1479 690848	NIKOLAY RODIONOV	{"email": "nikolay_rodionov08071975@postgrespro.ru", "phone": "+70916314186"}
0005433234082	FE85D2	2116 805349	VERONIKA BELOVA	{"email": "veronika.belova08051968@postgrespro.ru", "phone": "+70231078377"}
0005433234083	478350	3251 150544	EVGENIY KUZMIN	{"phone": "+70004722339"}
0005433234084	DF221E	0158 182313	ELENA SERGEEVA	{"email": "sergeevaelena-1977@postgrespro.ru", "phone": "+70688214097"}
0005433234085	B65832	0116 847714	VASILIY ALEKSEEV	{"email": "alekseevvasiliy-10091969@postgrespro.ru", "phone": "+70522660190"}
0005433234086	2D08BB	5852 611466	MIKHAIL ISAEV	{"email": "m.isaev.101975@postgrespro.ru", "phone": "+70609971385"}
0005433234087	104AEC	8741 557856	TATYANA ALEKSEEVA	{"email": "tatyana.alekseeva.1965@postgrespro.ru", "phone": "+70544764300"}
0005433234088	BEDF44	9390 774324	ELENA KUZNECOVA	{"email": "elena_kuznecova29011967@postgrespro.ru", "phone": "+70185108997"}
0005433234089	B9B80E	5929 391980	ALEKSANDR BONDARENKO	{"phone": "+70515211874"}
0005433234090	69D0EF	3362 184099	SERGEY YAKOVLEV	{"email": "yakovlev.s12091970@postgrespro.ru", "phone": "+70248686635"}
0005433234091	AC9EEA	4594 647992	ANASTASIYA KONOVALOVA	{"email": "konovalova-anastasiya-1970@postgrespro.ru", "phone": "+70737987799"}
0005433234092	AC9EEA	8769 462673	NIKOLAY MOISEEV	{"phone": "+70497779087"}
0005433234093	AC9EEA	1220 617794	ALEKSANDRA ALEKSANDROVA	{"email": "aaleksandrova091990@postgrespro.ru", "phone": "+70471597412"}
0005433234094	BBC72D	3387 831511	GEORGIY KAZAKOV	{"phone": "+70185459194"}
0005433234095	52DD51	1659 036184	DENIS KOZLOV	{"email": "d.kozlov_26021980@postgrespro.ru", "phone": "+70575519484"}
0005433234096	3E85F9	2481 355110	ELENA TITOVA	{"email": "e-titova_051979@postgrespro.ru", "phone": "+70477611181"}
0005433234097	D633DB	1345 650061	ANDREY ROMANOV	{"email": "a-romanov_051968@postgrespro.ru", "phone": "+70481394368"}
0005433234098	EAFF02	1421 000482	SVETLANA KOZLOVA	{"phone": "+70169461461"}
0005433234099	EAFF02	5273 388906	ZHANNA IVANOVA	{"phone": "+70807518634"}
0005433234100	C1EEAA	4203 594480	SERGEY CHERNOV	{"phone": "+70965339698"}
0005433234101	4D8E73	9214 596409	IGOR IVANOV	{"phone": "+70454760530"}
0005433234102	4D8E73	0861 352456	ALEKSANDR FILIPPOV	{"phone": "+70827578705"}
0005433234103	D216E4	3955 571307	NIKITA MAKAROV	{"email": "makarovnikita.1977@postgrespro.ru", "phone": "+70151730917"}
0005433234104	A82B4D	7519 604260	TATYANA OSIPOVA	{"phone": "+70744090095"}
0005433234105	A0184E	8010 935453	ELIZAVETA VOLKOVA	{"phone": "+70264945878"}
0005433234106	A0184E	1380 688373	RINAT BORISOV	{"phone": "+70648130967"}
0005433234107	F0AA94	5479 419889	ANDREY KUZNECOV	{"email": "kuznecova.051971@postgrespro.ru", "phone": "+70053361980"}
0005433234108	E04D98	2810 483085	VLADIMIR AFANASEV	{"email": "vladimir_afanasev_1969@postgrespro.ru", "phone": "+70826681962"}
0005433234109	4C21EB	3612 241753	MAKSIM FEDOTOV	{"phone": "+70694182625"}
0005433234110	4C21EB	5384 919050	YULIYA IVANOVA	{"email": "yuliya.ivanova.03071966@postgrespro.ru", "phone": "+70184681278"}
0005433234111	CC5A09	9067 150323	ARTEM MELNIKOV	{"email": "artem.melnikov_01071970@postgrespro.ru", "phone": "+70409489719"}
0005433234112	6A311A	9235 821646	TATYANA FILIPPOVA	{"phone": "+70281208614"}
0005433234113	A9710E	5932 227918	ILGIZ KAZAKOV	{"phone": "+70768605322"}
0005433234114	150BF2	3596 341072	OLGA MALYSHEVA	{"email": "malyshevao.1964@postgrespro.ru", "phone": "+70255763364"}
0005433234115	0131D9	1122 959251	ARTEM IVANOV	{"email": "ivanovartem.02021968@postgrespro.ru", "phone": "+70330266208"}
0005433234116	273D63	0271 510060	LYUDMILA ILINA	{"email": "lyudmilailina_15061969@postgrespro.ru", "phone": "+70158258107"}
0005433234117	273D63	7205 765840	VIKTOR KUZMIN	{"phone": "+70658269741"}
0005433234118	004B6A	8900 540439	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay-1964@postgrespro.ru", "phone": "+70458177685"}
0005433234119	10A8FB	2367 640013	RAISA KOZLOVA	{"phone": "+70989362621"}
0005433234120	10A8FB	2904 550012	IRINA MASLOVA	{"phone": "+70044102110"}
0005433234121	8F844A	2378 488734	YURIY NOVIKOV	{"email": "novikov.y-03041963@postgrespro.ru", "phone": "+70278107578"}
0005433234122	24DB77	5058 685888	VALENTINA LEBEDEVA	{"email": "v-lebedeva23071959@postgrespro.ru", "phone": "+70426669656"}
0005433234123	6B6BFC	7163 069992	SVETLANA PETROVA	{"email": "petrovasvetlana03121970@postgrespro.ru", "phone": "+70839571871"}
0005433234124	6B6BFC	2237 558981	ANATOLIY SOKOLOV	{"phone": "+70839506284"}
0005433234125	276029	9955 864048	NATALYA NIKIFOROVA	{"email": "n-nikiforova-1984@postgrespro.ru", "phone": "+70146194304"}
0005433234126	E5E805	3262 835967	TATYANA YAKOVLEVA	{"email": "yakovleva.tatyana1968@postgrespro.ru", "phone": "+70328398896"}
0005433234127	48AC51	9544 615020	VITALIY FILIPPOV	{"phone": "+70613720550"}
0005433234128	C08418	9505 841914	SERGEY PAVLOV	{"phone": "+70361352589"}
0005433234129	C640E5	6679 336593	VLADIMIR KUDRYASHOV	{"phone": "+70166152560"}
0005433234130	C640E5	9152 497681	NINA DENISOVA	{"phone": "+70540942558"}
0005433234131	68CFBE	1187 529942	KONSTANTIN IVANOV	{"email": "konstantinivanov_091967@postgrespro.ru", "phone": "+70575105631"}
0005433234132	2E3D72	9663 275190	EVGENIYA MIKHAYLOVA	{"email": "mikhaylova-evgeniya-031991@postgrespro.ru", "phone": "+70060807090"}
0005433234133	2E3D72	2332 559996	LILIYA FROLOVA	{"email": "frolovaliliya.1962@postgrespro.ru", "phone": "+70447040727"}
0005433234134	2E3D72	8907 849313	NADEZHDA NIKOLAEVA	{"email": "nadezhdanikolaeva111981@postgrespro.ru", "phone": "+70884954445"}
0005433234135	A73C2A	2836 315691	LYUBOV ZAYCEVA	{"email": "zayceva.l.1956@postgrespro.ru", "phone": "+70088041062"}
0005433234136	1951F3	6952 328598	VYACHESLAV GERASIMOV	{"email": "gerasimovvyacheslav.061968@postgrespro.ru", "phone": "+70431817174"}
0005433234137	1951F3	1273 188620	ANNA AFANASEVA	{"email": "afanaseva-a25111976@postgrespro.ru", "phone": "+70906155920"}
0005433234138	D41FC9	1736 121669	NINA IVANOVA	{"email": "nina-ivanova071967@postgrespro.ru", "phone": "+70429035458"}
0005433234139	23874A	0028 680798	TIMUR MAKSIMOV	{"phone": "+70845448264"}
0005433234140	D6649B	8877 033716	ALEKSEY IVANOV	{"phone": "+70861109817"}
0005433234141	D6649B	6010 065816	VADIM ZAKHAROV	{"email": "zakharov.v_1971@postgrespro.ru", "phone": "+70460043515"}
0005433234142	9BFF09	8664 633097	DMITRIY TIKHONOV	{"email": "tikhonov_d.21091974@postgrespro.ru", "phone": "+70760729037"}
0005433234143	4FF198	9895 199303	ALEKSANDR IVANOV	{"phone": "+70593842923"}
0005433234144	6303EC	5876 077588	ANNA POPOVA	{"email": "popova-a_18041972@postgrespro.ru", "phone": "+70481242025"}
0005433234145	0E9078	2495 260973	MIKHAIL DMITRIEV	{"email": "mikhail.dmitriev-26031970@postgrespro.ru", "phone": "+70495390742"}
0005433234146	BB7BDF	0577 668270	VALENTINA KUZNECOVA	{"email": "v-kuznecova_1967@postgrespro.ru", "phone": "+70082243240"}
0005433234147	EA43CB	1551 699234	MARIYA ALEKSEEVA	{"email": "alekseeva.mariya-1961@postgrespro.ru", "phone": "+70440847734"}
0005433234148	D602E7	7164 571036	IVAN SOKOLOV	{"phone": "+70515042645"}
0005433234149	03D58E	3722 770694	ROMAN KOZLOV	{"email": "r_kozlov-051984@postgrespro.ru", "phone": "+70152406240"}
0005433234150	BA9275	6949 249223	EKATERINA ISAEVA	{"email": "ekaterinaisaeva_1974@postgrespro.ru", "phone": "+70750616979"}
0005433234151	D78864	5708 302459	EKATERINA ABRAMOVA	{"email": "abramova_e021968@postgrespro.ru", "phone": "+70936449703"}
0005433234152	380398	5178 536246	SERGEY BELOV	{"phone": "+70846417818"}
0005433234153	01166A	2430 585487	OLGA SMIRNOVA	{"phone": "+70259879010"}
0005433234154	E8AE60	5280 042290	TATYANA MIKHAYLOVA	{"phone": "+70065422893"}
0005433234155	E8AE60	1091 225288	TIMUR MARTYNOV	{"phone": "+70489455846"}
0005433234156	BA6659	1732 549175	BORIS MIKHAYLOV	{"email": "mikhaylov_b.031964@postgrespro.ru", "phone": "+70633437673"}
0005433234157	6703D2	3558 357968	SVETLANA PAVLOVA	{"email": "pavlova.svetlana1964@postgrespro.ru", "phone": "+70401214289"}
0005433234158	6703D2	2739 166584	LYUDMILA POPOVA	{"email": "lyudmila.popova-121982@postgrespro.ru", "phone": "+70991981131"}
0005433234159	6703D2	0517 271544	LYUDMILA POPOVA	{"email": "lyudmila.popova.1966@postgrespro.ru", "phone": "+70919633218"}
0005433234160	5EB8C7	0384 158794	NIKOLAY VASILEV	{"email": "vasilev_nikolay_1975@postgrespro.ru", "phone": "+70886411034"}
0005433234161	BBE7AE	0918 909498	DMITRIY ZHURAVLEV	{"phone": "+70855209774"}
0005433234162	BBE7AE	7599 516046	MARIYA DAVYDOVA	{"phone": "+70568244559"}
0005433234163	BBE7AE	2241 224857	GALINA MELNIKOVA	{"email": "melnikova-g-1972@postgrespro.ru", "phone": "+70924244219"}
0005433234164	87E19C	7617 126948	VIKTOR FEDOROV	{"email": "fedorov.viktor051972@postgrespro.ru", "phone": "+70699304272"}
0005433234165	87E19C	6716 389146	ALEKSANDR GAVRILOV	{"phone": "+70168437118"}
0005433234166	AF4510	8912 115765	ALEKSEY MATVEEV	{"email": "matveevaleksey.101986@postgrespro.ru", "phone": "+70211210640"}
0005433234167	AF4510	1427 431486	IVAN ALEKSEEV	{"email": "ivanalekseev.09091964@postgrespro.ru", "phone": "+70822279647"}
0005433234168	894FCB	2773 372092	ELENA GRISHINA	{"email": "grishina.elena1970@postgrespro.ru", "phone": "+70481210027"}
0005433234169	67421F	2124 368074	DMITRIY IVANOV	{"email": "dmitriyivanov-041978@postgrespro.ru", "phone": "+70224245506"}
0005433234170	72EC61	4447 714037	VALENTINA AFANASEVA	{"email": "afanaseva.v_081977@postgrespro.ru", "phone": "+70432235280"}
0005433234171	E6522E	7242 876825	OLEG MAKSIMOV	{"phone": "+70665651292"}
0005433234172	E6522E	0177 791520	VENIAMIN MIKHAYLOV	{"phone": "+70514708473"}
0005433234173	3907F3	5719 516089	NATALYA KUZNECOVA	{"phone": "+70034678487"}
0005433234174	950D54	0697 917922	VALERIY SOROKIN	{"email": "sorokin.v.091971@postgrespro.ru", "phone": "+70190304576"}
0005433234175	950D54	8900 167321	GENNADIY RODIONOV	{"email": "g-rodionov-1981@postgrespro.ru", "phone": "+70226524064"}
0005433234176	EE6082	5560 729127	SERGEY FROLOV	{"email": "frolov_s-091977@postgrespro.ru", "phone": "+70829402501"}
0005433234177	EE6082	2320 139979	YURIY SCHERBAKOV	{"phone": "+70453769758"}
0005433234178	BD4577	0098 517859	ALEKSEY FOMIN	{"email": "a.fomin_04091973@postgrespro.ru", "phone": "+70573680963"}
0005433234179	6B9C9C	1061 845479	PETR FEDOROV	{"phone": "+70789534115"}
0005433234180	6B9C9C	4453 596519	GENNADIY MOISEEV	{"phone": "+70885034653"}
0005433234181	A518CF	1530 504153	NIKOLAY KUZMIN	{"email": "kuzminnikolay01081967@postgrespro.ru", "phone": "+70523822506"}
0005433234182	A518CF	0183 163656	ELENA KOVALEVA	{"phone": "+70669451712"}
0005433234183	E4C5FD	5242 049488	NATALYA IVANOVA	{"phone": "+70664809425"}
0005433234184	E4C5FD	1336 051509	STANISLAV GUSEV	{"email": "sgusev.1971@postgrespro.ru", "phone": "+70073151541"}
0005433234185	5A1BC2	7557 126540	GENNADIY KAZAKOV	{"email": "gennadiykazakov_1976@postgrespro.ru", "phone": "+70108299591"}
0005433234186	CA693C	7184 304662	DMITRIY OSIPOV	{"phone": "+70176973193"}
0005433234187	445D3D	1273 098089	VASILIY KUZNECOV	{"phone": "+70384706521"}
0005433234188	276539	1209 234513	ARTEM ILIN	{"email": "ilin.a-091974@postgrespro.ru", "phone": "+70139961622"}
0005433234189	5B24A6	1831 659836	DINA PETROVA	{"email": "petrova-dina-1969@postgrespro.ru", "phone": "+70726529875"}
0005433234190	5B24A6	2245 785903	NIKOLAY IVANOV	{"phone": "+70517859942"}
0005433234191	5B24A6	0561 960577	VLADIMIR KAZAKOV	{"phone": "+70630653279"}
0005433234192	6EEE68	1419 408330	NATALYA SEMENOVA	{"email": "natalyasemenova_1973@postgrespro.ru", "phone": "+70139282854"}
0005433234193	6EEE68	1015 110855	NIKOLAY TIKHONOV	{"email": "n.tikhonov.06121973@postgrespro.ru", "phone": "+70963512371"}
0005433234194	33C347	7352 251732	ZINAIDA TITOVA	{"email": "titovazinaida-051975@postgrespro.ru", "phone": "+70036005321"}
0005433234195	458F6D	9915 542942	LYUBOV MIKHAYLOVA	{"phone": "+70443086361"}
0005433234196	07BD45	3435 440587	ANNA SCHERBAKOVA	{"email": "anna_scherbakova-081975@postgrespro.ru", "phone": "+70387679495"}
0005433234197	07BD45	5517 322054	VALENTINA CHERNOVA	{"email": "chernova-valentina.10081970@postgrespro.ru", "phone": "+70231139648"}
0005433234198	5CBEC3	1676 342115	VIKTOR DMITRIEV	{"email": "dmitrievv_24111969@postgrespro.ru", "phone": "+70999092364"}
0005433234199	B7A992	8699 226776	TATYANA SMIRNOVA	{"phone": "+70671812903"}
0005433234200	14429D	4769 315221	YANA SOKOLOVA	{"phone": "+70572877737"}
0005433234201	E2877D	3597 898378	GLEB BORISOV	{"email": "borisov-gleb_17101974@postgrespro.ru", "phone": "+70061459084"}
0005433234202	CC5BF2	5818 363522	ANATOLIY KOROLEV	{"email": "korolev-a1974@postgrespro.ru", "phone": "+70097299654"}
0005433234203	57BE1E	7281 581334	NIKOLAY ROMANOV	{"email": "romanov.nikolay-1988@postgrespro.ru", "phone": "+70227123445"}
0005433234204	57BE1E	9432 684366	FEDOR KISELEV	{"email": "kiselev_f_031973@postgrespro.ru", "phone": "+70101737959"}
0005433234205	9AB4E5	1722 378438	VERA FILIPPOVA	{"email": "v.filippova12081970@postgrespro.ru", "phone": "+70655133375"}
0005433234206	9AB4E5	5891 142764	VLADIMIR ANTONOV	{"email": "vantonov011973@postgrespro.ru", "phone": "+70198817647"}
0005433234207	4E7CE2	1316 252481	VENIAMIN FEDOROV	{"email": "veniamin_fedorov.021970@postgrespro.ru", "phone": "+70086832773"}
0005433234208	4FA9E7	1715 529789	LYUBOV KISELEVA	{"email": "l.kiseleva.23041967@postgrespro.ru", "phone": "+70569598353"}
0005433234209	4D0DD0	0501 381147	ALEKSANDRA GRISHINA	{"phone": "+70253256232"}
0005433234210	2D393F	2505 604296	ALEKSANDR EGOROV	{"phone": "+70471548743"}
0005433234211	F884F7	2617 665106	NATALYA BORISOVA	{"email": "nborisova_081951@postgrespro.ru", "phone": "+70765809656"}
0005433234212	F884F7	9452 428647	NATALYA FILIPPOVA	{"email": "n.filippova-021973@postgrespro.ru", "phone": "+70510667360"}
0005433234213	CD8C67	1448 258808	ALEKSANDR FROLOV	{"phone": "+70554354496"}
0005433234214	F7C68F	4341 459476	EVGENIY SOKOLOV	{"phone": "+70036066462"}
0005433234215	F7C68F	5461 528814	VLADISLAV MAKAROV	{"email": "makarov_v.12111969@postgrespro.ru", "phone": "+70397856115"}
0005433234216	D4916E	9094 186642	MIKHAIL MIRONOV	{"email": "mironovmikhail091970@postgrespro.ru", "phone": "+70699728230"}
0005433234217	69FB9D	7764 944972	ALEKSEY GAVRILOV	{"phone": "+70752414336"}
0005433234218	69FB9D	3365 088458	VLADISLAV VOLKOV	{"email": "vvolkov08061976@postgrespro.ru", "phone": "+70424131740"}
0005433234219	7F532A	0939 365271	IGOR VOROBEV	{"phone": "+70391385088"}
0005433234220	7F532A	1824 959578	VALERIYA MALYSHEVA	{"phone": "+70233155890"}
0005433234221	82958A	2590 624188	ARTEM MELNIKOV	{"email": "amelnikov01011974@postgrespro.ru", "phone": "+70779435666"}
0005433234222	82958A	7068 834481	RENAT ROMANOV	{"phone": "+70753695130"}
0005433234223	BC37FF	4165 199408	ALEKSANDR TIMOFEEV	{"email": "timofeev-aleksandr.081964@postgrespro.ru", "phone": "+70298585968"}
0005433234224	0A26D7	5472 621008	NADEZHDA KOZLOVA	{"phone": "+70250073655"}
0005433234225	81407A	2064 305703	NINA PETROVA	{"email": "petrova-nina03061977@postgrespro.ru", "phone": "+70444865360"}
0005433234226	9CE2A6	9230 553312	LIDIYA MASLOVA	{"email": "maslova-lidiya_17081972@postgrespro.ru", "phone": "+70325266879"}
0005433234227	558DA2	5808 652549	ANTON ORLOV	{"phone": "+70446087505"}
0005433234228	B0538A	4265 797875	TAMARA MAKSIMOVA	{"phone": "+70752171845"}
0005433234229	2402B0	4857 973395	ANASTASIYA NIKITINA	{"email": "nikitinaanastasiya.1970@postgrespro.ru", "phone": "+70011212802"}
0005433234230	B86E10	6030 646654	SVETLANA DENISOVA	{"phone": "+70331785742"}
0005433234231	325232	3298 275241	YURIY GERASIMOV	{"phone": "+70219583859"}
0005433234232	5FAB8E	8540 716878	OLGA TIKHONOVA	{"phone": "+70908889641"}
0005433234233	7EB311	9384 514238	ELENA MAKAROVA	{"phone": "+70103309568"}
0005433234234	130E60	2265 553549	EKATERINA MOROZOVA	{"email": "ekaterina_morozova_18081973@postgrespro.ru", "phone": "+70057793769"}
0005433234235	CDC00A	6067 108654	ALEKSEY PETROV	{"email": "petrov.a-051968@postgrespro.ru", "phone": "+70890943147"}
0005433234236	8BA09A	1794 455077	ALIYA MIRONOVA	{"phone": "+70608462178"}
0005433234237	82C55C	9802 985339	GALINA MAKAROVA	{"email": "g-makarova_1985@postgrespro.ru", "phone": "+70375279639"}
0005433234238	353F23	0953 877939	GERMAN MIKHAYLOV	{"phone": "+70834041557"}
0005433234239	353F23	1369 894427	NATALYA KUZNECOVA	{"phone": "+70405096144"}
0005433234240	490228	0874 245058	LIDIYA ILINA	{"email": "ilina_l_1970@postgrespro.ru", "phone": "+70895408801"}
0005433234241	490228	1974 988151	ARKADIY YAKOVLEV	{"phone": "+70053277460"}
0005433234242	490228	1510 159694	SERGEY MEDVEDEV	{"phone": "+70905197264"}
0005433234243	00193F	1584 701423	SVETLANA GERASIMOVA	{"phone": "+70518388720"}
0005433234244	1EF3AE	6496 047073	NADEZHDA AFANASEVA	{"email": "afanaseva_nadezhda_041967@postgrespro.ru", "phone": "+70844770536"}
0005433234245	15E4CE	1291 317469	ELENA OVCHINNIKOVA	{"email": "e_ovchinnikova_1963@postgrespro.ru", "phone": "+70944860081"}
0005433234246	15E4CE	3431 797549	ROSTISLAV MAKAROV	{"phone": "+70148622839"}
0005433234247	31C953	0260 178583	ALEKSANDRA KUDRYASHOVA	{"phone": "+70103902885"}
0005433234248	5F8A58	3274 032186	NIKOLAY ANDREEV	{"email": "andreev.n.1966@postgrespro.ru", "phone": "+70496913244"}
0005433234249	5F8A58	1851 177344	YAROSLAV KOZLOV	{"phone": "+70987305511"}
0005433234250	51A4AC	5422 507867	VALENTINA PAVLOVA	{"email": "pavlova_v05101974@postgrespro.ru", "phone": "+70763857640"}
0005433234251	51A4AC	0365 004119	NATALYA IVANOVA	{"phone": "+70215796716"}
0005433234252	B64A54	8592 486524	VLADIMIR SIDOROV	{"phone": "+70021525605"}
0005433234253	27F45F	5991 058565	ALEKSANDRA ANDREEVA	{"email": "andreeva_a.061974@postgrespro.ru", "phone": "+70144951617"}
0005433234254	27F45F	3612 365043	VLADIMIR MIKHAYLOV	{"phone": "+70854904520"}
0005433234255	945BB1	2051 021660	YULIYA KUZNECOVA	{"email": "kuznecovay_30121977@postgrespro.ru", "phone": "+70256608306"}
0005433234256	A7EDDE	1574 592028	VERA AFANASEVA	{"phone": "+70924843045"}
0005433234257	94E0A5	0351 240577	RUSLAN PAVLOV	{"phone": "+70236289568"}
0005433234258	94E0A5	5959 965161	YURIY PETROV	{"phone": "+70143572242"}
0005433234259	6B73BE	3705 197668	OLGA ALEKSEEVA	{"phone": "+70750689597"}
0005433234260	4F4C50	0224 770376	OLESYA LOGINOVA	{"phone": "+70271380363"}
0005433234261	48341F	3963 722745	SOFYA KRASNOVA	{"phone": "+70676864446"}
0005433234262	48341F	9789 263886	NATALYA PETROVA	{"email": "npetrova16101976@postgrespro.ru", "phone": "+70895403527"}
0005433234263	7141C3	1357 138209	NATALYA ZAKHAROVA	{"email": "zakharova_n_14061965@postgrespro.ru", "phone": "+70820189356"}
0005433234264	7141C3	9209 494948	ALEKSANDR TARASOV	{"phone": "+70517835751"}
0005433234265	18CAFB	1445 663551	ANATOLIY KARPOV	{"phone": "+70661957301"}
0005433234266	A81FDE	6561 967270	KIRILL KUZMIN	{"email": "kuzmin.k.091973@postgrespro.ru", "phone": "+70439325287"}
0005433234267	B615C8	6140 920269	VASILIY KISELEV	{"phone": "+70850642609"}
0005433234268	E2D434	1804 503449	NATALYA RYABOVA	{"email": "ryabovanatalya-20031972@postgrespro.ru", "phone": "+70878455197"}
0005433234269	E2B101	0039 448125	TATYANA TIMOFEEVA	{"email": "tatyana.timofeeva-091963@postgrespro.ru", "phone": "+70381643989"}
0005433234270	E2B101	1489 626510	TATYANA ZHURAVLEVA	{"email": "zhuravlevat1980@postgrespro.ru", "phone": "+70098822270"}
0005433234271	A9C4D3	4552 708767	ALEKSANDR KUDRYASHOV	{"phone": "+70939937088"}
0005433234272	618E78	9555 174710	ILYA MOROZOV	{"phone": "+70956315934"}
0005433234273	6E462A	3024 513356	MARINA PETROVA	{"phone": "+70249485508"}
0005433234274	1E5655	3334 540769	ELENA FOMINA	{"phone": "+70088086544"}
0005433234275	1E5655	9929 473669	ANTON MIRONOV	{"email": "anton.mironov-061960@postgrespro.ru", "phone": "+70511088768"}
0005433234276	243E5D	1339 484469	VLADIMIR KOZLOV	{"email": "v.kozlov.111982@postgrespro.ru", "phone": "+70408689493"}
0005433234277	28F210	3257 634734	ELENA LEBEDEVA	{"phone": "+70644059620"}
0005433234278	26140A	4983 496405	ANTON GRIGOREV	{"email": "grigorev-anton1966@postgrespro.ru", "phone": "+70546189933"}
0005433234279	26140A	7560 348141	EVGENIY MOROZOV	{"email": "morozov_evgeniy04111971@postgrespro.ru", "phone": "+70066210996"}
0005433234280	67E59D	6920 553453	OLEG KARPOV	{"email": "oleg-karpov_1970@postgrespro.ru", "phone": "+70058832307"}
0005433234281	67E59D	4724 595866	GALINA PAVLOVA	{"email": "g_pavlova27031972@postgrespro.ru", "phone": "+70836936672"}
0005433234282	487E84	0922 291593	OLGA BELOVA	{"email": "olga.belova.07121972@postgrespro.ru", "phone": "+70915409123"}
0005433234283	4DE43C	7584 604181	GEORGIY KOROLEV	{"email": "korolev-georgiy.011974@postgrespro.ru", "phone": "+70565478791"}
0005433234284	4DE43C	3603 407073	KONSTANTIN PAVLOV	{"phone": "+70310574232"}
0005433234285	5EC040	8382 034154	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr1975@postgrespro.ru", "phone": "+70161132288"}
0005433234286	FA5FC4	9538 071424	KLAVDIYA SEMENOVA	{"phone": "+70259050279"}
0005433234287	475F9D	4484 402956	TATYANA MEDVEDEVA	{"email": "tatyana-medvedeva.1958@postgrespro.ru", "phone": "+70284775997"}
0005433234288	7F2DF5	2454 093931	ANTON BONDARENKO	{"phone": "+70284438759"}
0005433234289	B39E06	4192 599612	VALERIY SCHERBAKOV	{"phone": "+70199972448"}
0005433234290	B2D235	7122 212023	VALENTINA FEDOROVA	{"phone": "+70880694688"}
0005433234291	C1ECF8	5043 233268	VALENTINA KOROLEVA	{"phone": "+70184476342"}
0005433234292	C1ECF8	4136 902948	OLGA KUZMINA	{"phone": "+70018312481"}
0005433234293	1236F7	2911 235866	RAISA EFIMOVA	{"phone": "+70099096876"}
0005433234294	D5EE5A	6075 958077	LYUBOV KONOVALOVA	{"phone": "+70748685279"}
0005433234295	8C6B52	2886 714529	DMITRIY TARASOV	{"email": "tarasovd_30111988@postgrespro.ru", "phone": "+70440249373"}
0005433234296	0719C4	1401 901103	MARIYA KUZNECOVA	{"email": "mariya_kuznecova_08121974@postgrespro.ru", "phone": "+70606083240"}
0005433234297	0719C4	6580 648704	ILYA FROLOV	{"phone": "+70366456342"}
0005433234298	FD03DA	5497 983502	DINA ROMANOVA	{"phone": "+70927301489"}
0005433234299	FD03DA	1344 750063	NIKOLAY SOKOLOV	{"phone": "+70901557004"}
0005433234300	670513	1792 590603	SVETLANA BELOVA	{"email": "belovas_21071983@postgrespro.ru", "phone": "+70930712476"}
0005433234301	670513	1293 866558	BORIS ALEKSEEV	{"email": "b_alekseev_091962@postgrespro.ru", "phone": "+70935990448"}
0005433234302	2E8CF7	2731 572718	ALEKSANDR GERASIMOV	{"phone": "+70399057945"}
0005433234303	2E8CF7	3038 807686	OLGA SMIRNOVA	{"email": "smirnova_o-1971@postgrespro.ru", "phone": "+70203937589"}
0005433234304	9B8EA3	8375 765453	VALENTINA SAVELEVA	{"phone": "+70904007539"}
0005433234305	031D29	8437 110376	LIDIYA FROLOVA	{"phone": "+70773057573"}
0005433234306	031D29	8616 127522	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.a_1983@postgrespro.ru", "phone": "+70037388559"}
0005433234307	5505AE	6757 240068	YURIY SIDOROV	{"phone": "+70965291115"}
0005433234308	5B37A3	4428 844064	DARYA FILATOVA	{"email": "filatova.darya.071982@postgrespro.ru", "phone": "+70298420861"}
0005433234309	37D65E	4914 238879	EKATERINA MOROZOVA	{"email": "ekaterina.morozova-121968@postgrespro.ru", "phone": "+70651451292"}
0005433234310	37D65E	2961 921423	MARIYA ILINA	{"phone": "+70180249464"}
0005433234311	46B9F9	0782 654710	EVGENIYA ZAYCEVA	{"phone": "+70916523427"}
0005433234312	4943B1	8382 182205	SERGEY MEDVEDEV	{"phone": "+70740219478"}
0005433234313	1827C3	3780 836470	GALINA FILIPPOVA	{"email": "galinafilippova1969@postgrespro.ru", "phone": "+70249288688"}
0005433234314	ED1FE8	5199 726446	DARYA STEPANOVA	{"email": "stepanova-d-11071984@postgrespro.ru", "phone": "+70577922402"}
0005433234315	B87C3E	3117 600917	ANDREY TARASOV	{"email": "tarasov_a-101983@postgrespro.ru", "phone": "+70228195846"}
0005433234316	B87C3E	6932 356678	SVETLANA PETROVA	{"email": "petrova-svetlana.101977@postgrespro.ru", "phone": "+70832819986"}
0005433234317	3DD57F	6575 351402	DMITRIY SCHERBAKOV	{"email": "scherbakov.d_1971@postgrespro.ru", "phone": "+70699129403"}
0005433234318	3DD57F	1382 148427	ANDREY KOZLOV	{"email": "kozlova111971@postgrespro.ru", "phone": "+70132862537"}
0005433234319	0D33EE	2371 336885	DMITRIY ILIN	{"email": "d.ilin_111983@postgrespro.ru", "phone": "+70673325052"}
0005433234320	2C9BEE	1785 005105	LYUDMILA MAKAROVA	{"phone": "+70866940812"}
0005433234321	399AF3	2698 975808	PETR NOVIKOV	{"email": "pnovikov_21101979@postgrespro.ru", "phone": "+70359151534"}
0005433234322	66F775	3056 588343	VALERIYA EFREMOVA	{"phone": "+70508128733"}
0005433234323	66F775	5022 467650	YULIYA FILIPPOVA	{"phone": "+70900698706"}
0005433234324	52513A	7443 443735	ALEKSEY POPOV	{"phone": "+70455759103"}
0005433234325	209812	6535 352863	ANGELINA FILIPPOVA	{"email": "angelina-filippova101971@postgrespro.ru", "phone": "+70894412383"}
0005433234326	218B75	1535 596444	SVETLANA DMITRIEVA	{"phone": "+70684907861"}
0005433234327	CAB51E	6341 501804	ELENA DAVYDOVA	{"email": "davydovaelena_06051964@postgrespro.ru", "phone": "+70191354753"}
0005433234328	977627	1268 659506	SERGEY DENISOV	{"email": "denisov_s031976@postgrespro.ru", "phone": "+70192453958"}
0005433234329	10E2BA	6406 761791	LYUBOV LUKYANOVA	{"email": "l-lukyanova.071969@postgrespro.ru", "phone": "+70559844265"}
0005433234330	10E2BA	3206 413052	LYUDMILA SERGEEVA	{"email": "lsergeeva27011969@postgrespro.ru", "phone": "+70486846733"}
0005433234331	10E2BA	4065 213137	TATYANA MIKHAYLOVA	{"phone": "+70135883668"}
0005433234332	288B22	0850 017735	YULIYA NOVIKOVA	{"email": "yuliyanovikova.15111970@postgrespro.ru", "phone": "+70775105378"}
0005433234333	1FA885	9692 812303	ALEKSANDR PETROV	{"email": "petrov.aleksandr1982@postgrespro.ru", "phone": "+70657266583"}
0005433234334	1FA885	7358 901036	LIDIYA KARPOVA	{"email": "karpova_l_101970@postgrespro.ru", "phone": "+70810910019"}
0005433234335	B4D817	2570 760252	VALERIY ZAYCEV	{"phone": "+70790367945"}
0005433234336	B4D817	3974 460113	TATYANA FADEEVA	{"phone": "+70231598941"}
0005433234337	13A1CE	5572 238085	DMITRIY KUDRYASHOV	{"phone": "+70522079162"}
0005433234338	13A1CE	7037 998734	SVETLANA KUZNECOVA	{"phone": "+70149571741"}
0005433234339	589C37	0538 363791	ALEKSANDR SERGEEV	{"phone": "+70168999290"}
0005433234340	629BAF	0910 691498	OLGA POPOVA	{"email": "popova-o02041976@postgrespro.ru", "phone": "+70535926049"}
0005433234341	35D8F1	8874 597354	IRINA KUZMINA	{"email": "i.kuzmina.1958@postgrespro.ru", "phone": "+70884172035"}
0005433234342	7A4834	6091 505136	LIDIYA TITOVA	{"phone": "+70418579471"}
0005433234343	7A4834	6816 939818	ELIZAVETA LOGINOVA	{"email": "loginova-elizaveta-1982@postgrespro.ru", "phone": "+70520234505"}
0005433234344	96CB6F	4056 813888	IRINA RODIONOVA	{"phone": "+70326941908"}
0005433234345	16E269	0294 604943	RAFAEL ANDREEV	{"phone": "+70423458189"}
0005433234346	A33324	8973 309050	VLADIMIR KARPOV	{"email": "karpov-v-1967@postgrespro.ru", "phone": "+70211569579"}
0005433234347	344DE7	8789 998578	OLGA SERGEEVA	{"phone": "+70122629217"}
0005433234348	3D9B50	1521 694363	NIKOLAY FEDOTOV	{"email": "nikolay.fedotov.101970@postgrespro.ru", "phone": "+70157157540"}
0005433234349	3D9B50	7945 497326	DENIS KUZNECOV	{"email": "kuznecov_denis.10061982@postgrespro.ru", "phone": "+70386961919"}
0005433234350	92160E	2939 218658	VALENTINA ZAYCEVA	{"email": "valentina_zayceva_111974@postgrespro.ru", "phone": "+70068895318"}
0005433234351	4DAA15	4254 749375	NIKOLAY ANDREEV	{"phone": "+70950581848"}
0005433234352	4DAA15	4561 846243	VALENTINA YAKOVLEVA	{"email": "valentina.yakovleva.051972@postgrespro.ru", "phone": "+70808563124"}
0005433234353	29EBFD	9560 123293	ANDREY SOKOLOV	{"phone": "+70122698680"}
0005433234354	C17938	0224 739117	OLESYA EGOROVA	{"email": "o-egorova-21011980@postgrespro.ru", "phone": "+70550731563"}
0005433234355	C17938	4546 003444	VALENTINA KOROLEVA	{"phone": "+70438258282"}
0005433234356	8725DC	3308 601499	ALEKSANDR GAVRILOV	{"phone": "+70595840411"}
0005433234357	97731B	4422 295100	ROMAN POPOV	{"email": "popov-roman.23041975@postgrespro.ru", "phone": "+70607225780"}
0005433234358	087958	6994 201463	LYUDMILA CHERNOVA	{"email": "lyudmila-chernova_15011971@postgrespro.ru", "phone": "+70545110996"}
0005433234359	A871C1	3445 903130	MIKHAIL FEDOROV	{"email": "fedorovm-16071970@postgrespro.ru", "phone": "+70460600088"}
0005433234360	A871C1	0116 703878	NADEZHDA ANTONOVA	{"email": "nadezhdaantonova-01041963@postgrespro.ru", "phone": "+70009849090"}
0005433234361	9CE715	6205 347077	TATYANA MELNIKOVA	{"email": "t.melnikova.1971@postgrespro.ru", "phone": "+70004096073"}
0005433234362	432638	0575 787405	NIKOLAY KAZAKOV	{"email": "n.kazakov_031968@postgrespro.ru", "phone": "+70606747164"}
0005433234363	432638	3828 831802	ELIZAVETA NIKIFOROVA	{"email": "elizavetanikiforova06011976@postgrespro.ru", "phone": "+70517965233"}
0005433234364	07B5FD	5260 554477	NINA PAVLOVA	{"phone": "+70490769098"}
0005433234365	07B5FD	9542 907970	KIRILL KUZNECOV	{"phone": "+70797489871"}
0005433234366	4ADCAC	1936 931831	EKATERINA KOLESNIKOVA	{"phone": "+70131738818"}
0005433234367	D43319	1264 450737	VITALIY ROMANOV	{"phone": "+70587592819"}
0005433234368	E3BDF7	7950 189003	IGOR PETROV	{"email": "petrov-igor121966@postgrespro.ru", "phone": "+70262698117"}
0005433234369	E3BDF7	6256 121152	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr101974@postgrespro.ru", "phone": "+70613763418"}
0005433234370	E3BDF7	3041 928879	ALEKSANDRA KALININA	{"phone": "+70135294966"}
0005433234371	7FDE16	2505 611083	ILYA FROLOV	{"phone": "+70039974624"}
0005433234372	F646CC	9486 209762	TATYANA NOVIKOVA	{"phone": "+70053466773"}
0005433234373	BF2CD5	5193 610433	SVETLANA SOROKINA	{"phone": "+70890059735"}
0005433234374	37E063	8835 756063	VYACHESLAV ABRAMOV	{"phone": "+70765526153"}
0005433234375	37E063	4487 353581	MIKHAIL RODIONOV	{"phone": "+70405016027"}
0005433234376	6F3703	7287 277785	ELENA FROLOVA	{"email": "frolova-elena111966@postgrespro.ru", "phone": "+70758001613"}
0005433234377	302216	7100 936982	SERGEY MIKHAYLOV	{"phone": "+70159122829"}
0005433234378	302216	7165 743367	DENIS KUZMIN	{"email": "deniskuzmin041983@postgrespro.ru", "phone": "+70578066739"}
0005433234379	3945A9	3619 780520	ANDREY ZAYCEV	{"email": "azaycev_1970@postgrespro.ru", "phone": "+70974980958"}
0005433234380	6D9EE0	5373 627965	NADEZHDA FROLOVA	{"phone": "+70910182620"}
0005433234381	6D9EE0	7021 770666	NATALYA ZHURAVLEVA	{"email": "zhuravleva_n.07081966@postgrespro.ru", "phone": "+70046929415"}
0005433234382	6D9EE0	6715 555857	TAMARA BARANOVA	{"phone": "+70338659875"}
0005433234383	3504F8	1625 352170	TATYANA AKIMOVA	{"phone": "+70081916964"}
0005433234384	8A20A5	9143 687185	BORIS ISAEV	{"email": "b.isaev_091976@postgrespro.ru", "phone": "+70923345870"}
0005433234385	977FD4	2723 547076	MAKSIM PAVLOV	{"email": "pavlovm16051981@postgrespro.ru", "phone": "+70217505600"}
0005433234386	009AB8	3627 463337	EKATERINA ERMAKOVA	{"email": "eermakova06121967@postgrespro.ru", "phone": "+70544131398"}
0005433234387	29B505	5447 142325	NATALYA KOZLOVA	{"email": "kozlova.natalya.1974@postgrespro.ru", "phone": "+70870345171"}
0005433234388	B96249	8629 358922	ANDREY NAZAROV	{"email": "nazarov-a-061972@postgrespro.ru", "phone": "+70991376067"}
0005433234389	093853	5740 206145	ANATOLIY ALEKSEEV	{"phone": "+70662583650"}
0005433234390	093853	5145 918716	VALERIY NOVIKOV	{"email": "vnovikov1975@postgrespro.ru", "phone": "+70955784735"}
0005433234391	1FF1BC	1248 876821	MAKSIM ANDREEV	{"email": "andreev_m_1977@postgrespro.ru", "phone": "+70332153303"}
0005433234392	73C37F	5638 725172	GRIGORIY STEPANOV	{"phone": "+70555957473"}
0005433234393	836E0C	3485 790417	VALENTINA KUZNECOVA	{"phone": "+70176791620"}
0005433234394	836E0C	3771 061973	VALERIYA SOROKINA	{"phone": "+70452022150"}
0005433234395	D4DF0B	3249 963090	ALEKSEY NIKITIN	{"phone": "+70402807008"}
0005433234396	5EE87D	3191 218530	PAVEL ZAYCEV	{"email": "zaycev_pavel_16031983@postgrespro.ru", "phone": "+70196387287"}
0005433234397	2AA33C	0103 315804	ALEKSANDR IVANOV	{"email": "a_ivanov_18031982@postgrespro.ru", "phone": "+70509756967"}
0005433234398	2AA33C	2187 880404	OKSANA ZAYCEVA	{"phone": "+70564362054"}
0005433234399	8D3BD9	6853 478760	ELENA VOLKOVA	{"email": "e-volkova1963@postgrespro.ru", "phone": "+70694031913"}
0005433234400	86A886	4994 736205	TATYANA MOISEEVA	{"phone": "+70706813844"}
0005433234401	72E598	1169 283728	ANTONIDA SOLOVEVA	{"email": "a_soloveva-1980@postgrespro.ru", "phone": "+70501330110"}
0005433234402	72E598	0344 772069	MARIYA FADEEVA	{"phone": "+70566204024"}
0005433234403	2F8B7D	6491 535614	GALINA KOROLEVA	{"phone": "+70350045237"}
0005433234404	1F68B2	2045 185665	LYUBOV POPOVA	{"email": "popova.l_1973@postgrespro.ru", "phone": "+70584644499"}
0005433234405	8526FE	1234 707287	DANILA IVANOV	{"phone": "+70701247159"}
0005433234406	590BE0	0527 864142	ANATOLIY MIKHAYLOV	{"email": "anatoliy.mikhaylov.31121963@postgrespro.ru", "phone": "+70659864069"}
0005433234407	312768	3772 953158	VYACHESLAV YAKOVLEV	{"email": "yakovlev-vyacheslav_1975@postgrespro.ru", "phone": "+70148473696"}
0005433234408	399ECA	9623 236117	ARTEM IVANOV	{"email": "artem.ivanov_031974@postgrespro.ru", "phone": "+70189075116"}
0005433234409	EEB863	3672 321924	EVGENIY SIDOROV	{"email": "sidorov.evgeniy_1978@postgrespro.ru", "phone": "+70946961583"}
0005433234410	39E733	0154 652108	DENIS ZHUKOV	{"email": "zhukovdenis_031976@postgrespro.ru", "phone": "+70684425772"}
0005433234411	39E733	0127 007083	VARVARA GAVRILOVA	{"phone": "+70630033181"}
0005433234412	0C7F41	5204 844145	ALEKSANDR BORISOV	{"email": "a.borisov.1977@postgrespro.ru", "phone": "+70136291903"}
0005433234413	047E77	3836 991524	EVGENIY FEDOROV	{"email": "e_fedorov-1966@postgrespro.ru", "phone": "+70870716076"}
0005433234414	B6B1EC	9694 124998	MIKHAIL FILIPPOV	{"email": "mikhail-filippov.11041970@postgrespro.ru", "phone": "+70605821583"}
0005433234415	B4BCAC	7973 832418	EGOR VOLKOV	{"phone": "+70449904047"}
0005433234416	659F15	9718 960981	DARYA YAKOVLEVA	{"email": "yakovlevad_29121980@postgrespro.ru", "phone": "+70621958703"}
0005433234417	6861C9	2056 901050	GEORGIY BARANOV	{"email": "baranov_georgiy_1968@postgrespro.ru", "phone": "+70179039533"}
0005433234418	F82FCC	2388 178963	ALEKSANDR SOLOVEV	{"email": "solovev_a-021972@postgrespro.ru", "phone": "+70205842405"}
0005433234419	F82FCC	6234 946302	ARTEM VOLKOV	{"email": "artem-volkov18091965@postgrespro.ru", "phone": "+70744160297"}
0005433234420	2B4EDF	4327 447693	IVAN DMITRIEV	{"phone": "+70719721436"}
0005433234421	2B4EDF	5554 368320	ARSENIY PAVLOV	{"email": "pavlov_a_091955@postgrespro.ru", "phone": "+70957606305"}
0005433234422	0DCF2D	2306 206778	ANASTASIYA OVCHINNIKOVA	{"email": "anastasiya-ovchinnikova.101981@postgrespro.ru", "phone": "+70672435541"}
0005433234423	9CC9B3	2561 900414	VLADIMIR SOKOLOV	{"phone": "+70347542380"}
0005433234424	9CC9B3	0107 851219	NAIL MOISEEV	{"phone": "+70505222530"}
0005433234425	9CC9B3	9984 019715	SERGEY KUZNECOV	{"email": "skuznecov.071986@postgrespro.ru", "phone": "+70654797754"}
0005433234426	576343	8454 243704	DENIS VASILEV	{"phone": "+70190568608"}
0005433234427	0D21D6	6586 668179	VERA FOMINA	{"phone": "+70934575305"}
0005433234428	D567C8	8882 716723	DMITRIY FILIPPOV	{"email": "filippovdmitriy.1974@postgrespro.ru", "phone": "+70340515651"}
0005433234429	D567C8	5535 615197	SVETLANA ALEKSANDROVA	{"phone": "+70271314614"}
0005433234430	81044C	4248 524353	RINAT ALEKSANDROV	{"email": "r_aleksandrov_1968@postgrespro.ru", "phone": "+70473959145"}
0005433234431	81044C	9399 936173	IVAN AFANASEV	{"email": "afanasev_ivan_1973@postgrespro.ru", "phone": "+70674411562"}
0005433234432	D323CE	3342 311689	YURIY KUZNECOV	{"phone": "+70889510903"}
0005433234433	7E5E10	5145 507249	ALEKSEY DENISOV	{"phone": "+70723316227"}
0005433234434	46DF11	6066 239852	IRINA POLYAKOVA	{"email": "ipolyakova-1975@postgrespro.ru", "phone": "+70907513810"}
0005433234659	41A638	8142 587461	RUSLAN NAZAROV	{"phone": "+70290617304"}
0005433234435	46DF11	3513 003747	VALENTINA STEPANOVA	{"email": "stepanova-valentina.25021970@postgrespro.ru", "phone": "+70567486830"}
0005433234436	AF6054	7799 583012	PAVEL ALEKSEEV	{"email": "alekseev.p.1970@postgrespro.ru", "phone": "+70688889267"}
0005433234437	AF6054	3934 194791	VLADIMIR TARASOV	{"phone": "+70711337193"}
0005433234438	ED016F	7976 516139	ELENA ZOTOVA	{"phone": "+70624234409"}
0005433234439	254E9E	1341 993448	VLADIMIR YAKOVLEV	{"email": "v_yakovlev_19041964@postgrespro.ru", "phone": "+70778080317"}
0005433234440	754589	0258 217389	SERGEY DMITRIEV	{"email": "sergey.dmitriev1983@postgrespro.ru", "phone": "+70799308984"}
0005433234441	754589	5696 977336	IRINA ALEKSEEVA	{"email": "i_alekseeva1970@postgrespro.ru", "phone": "+70015803623"}
0005433234442	E48F0B	0649 009251	ALEKSEY VLASOV	{"email": "vlasov_a-1976@postgrespro.ru", "phone": "+70984911920"}
0005433234443	E48F0B	9859 264432	ANASTASIYA TIKHONOVA	{"phone": "+70694144560"}
0005433234444	790299	1516 164362	ANASTASIYA ZAKHAROVA	{"phone": "+70571892893"}
0005433234445	B5F780	7082 215646	LYUBOV GRISHINA	{"email": "lyubovgrishina.26121969@postgrespro.ru", "phone": "+70081443193"}
0005433234446	7E9F7B	5381 847144	EVGENIYA KOROLEVA	{"email": "koroleva_e1978@postgrespro.ru", "phone": "+70794627925"}
0005433234447	7E9F7B	3108 604142	IGOR ISAEV	{"email": "igor-isaev.1980@postgrespro.ru", "phone": "+70894052751"}
0005433234448	D9884E	0104 301810	GALINA DENISOVA	{"email": "denisova.g-13051969@postgrespro.ru", "phone": "+70764116707"}
0005433234449	D9884E	5961 503661	GULFIYA MARTYNOVA	{"email": "martynova.gulfiya_051972@postgrespro.ru", "phone": "+70199114362"}
0005433234450	131A1B	6621 934126	NATALIYA SCHERBAKOVA	{"phone": "+70929199244"}
0005433234451	826F37	3314 810185	DMITRIY SHEVCHENKO	{"phone": "+70898033271"}
0005433234452	826F37	5085 684855	ALEKSEY SEMENOV	{"email": "semenov_a1967@postgrespro.ru", "phone": "+70047141670"}
0005433234453	4E7A14	8209 008148	VLADIMIR MOROZOV	{"phone": "+70124985677"}
0005433234454	F63BD5	9777 537071	VENERA POPOVA	{"email": "v_popova_11051963@postgrespro.ru", "phone": "+70828023378"}
0005433234455	7591D5	8387 845356	VALERIY VOLKOV	{"phone": "+70340753905"}
0005433234456	E74B70	0957 316108	EVGENIYA ISAEVA	{"email": "isaeva_evgeniya-21101966@postgrespro.ru", "phone": "+70511149217"}
0005433234457	E260A7	8366 605353	LYUDMILA MIRONOVA	{"email": "mironova-l_20051967@postgrespro.ru", "phone": "+70522625186"}
0005433234458	AF9FCC	8088 872996	VLADISLAV KUZMIN	{"email": "vladislav.kuzmin_24061972@postgrespro.ru", "phone": "+70776867851"}
0005433234459	AF9FCC	5309 922600	PETR KUZNECOV	{"email": "kuznecov_petr1971@postgrespro.ru", "phone": "+70829934831"}
0005433234460	AF9FCC	5445 435637	VIKTOR SMIRNOV	{"email": "smirnov-v_101977@postgrespro.ru", "phone": "+70433260040"}
0005433234461	88DA69	1826 067980	GALINA NAUMOVA	{"email": "galina-naumova081984@postgrespro.ru", "phone": "+70193090903"}
0005433234462	88DA69	7336 320768	PAVEL KUZMIN	{"email": "kuzmin-pavel_1957@postgrespro.ru", "phone": "+70255169994"}
0005433234463	122D28	6161 264195	YAN KRASNOV	{"email": "krasnov-y-28061966@postgrespro.ru", "phone": "+70082207294"}
0005433234464	8782B7	4553 859508	ALINA KUZNECOVA	{"phone": "+70123914102"}
0005433234465	8782B7	1163 574895	ALENA MAKSIMOVA	{"email": "alenamaksimova-1976@postgrespro.ru", "phone": "+70649016709"}
0005433234466	28433B	6129 504017	MAKSIM IVANOV	{"email": "ivanov-maksim1980@postgrespro.ru", "phone": "+70066808652"}
0005433234467	28433B	9177 458136	DENIS MARTYNOV	{"email": "dmartynov.1971@postgrespro.ru", "phone": "+70348949199"}
0005433234468	87BA7F	4689 776577	NATALYA KOZLOVA	{"phone": "+70168659775"}
0005433234469	1A34B4	1982 388060	VIKTOR FILIPPOV	{"email": "filippov.viktor.021976@postgrespro.ru", "phone": "+70484150116"}
0005433234470	1A34B4	3879 189938	NATALIYA KUZNECOVA	{"email": "nataliyakuznecova-1969@postgrespro.ru", "phone": "+70992045961"}
0005433234471	59BA8D	1221 507074	NATALYA MOROZOVA	{"phone": "+70849909781"}
0005433234472	E4B560	2574 276789	REGINA ANISIMOVA	{"email": "reginaanisimova_1965@postgrespro.ru", "phone": "+70311094791"}
0005433234473	A9A15B	8363 842517	NATALYA SOROKINA	{"email": "sorokina.n.1969@postgrespro.ru", "phone": "+70412315241"}
0005433234474	E02895	6940 616036	LYUDMILA ZAYCEVA	{"phone": "+70358705520"}
0005433234475	E02895	8956 138948	DANILA NOVIKOV	{"email": "novikov-danila08111972@postgrespro.ru", "phone": "+70657270780"}
0005433234476	1222C3	1308 530261	NATALYA ZAYCEVA	{"email": "natalya_zayceva_071974@postgrespro.ru", "phone": "+70279921845"}
0005433234477	1AE7AD	0140 027955	VALERIY GORBUNOV	{"phone": "+70130331641"}
0005433234478	B35137	7321 208103	ARTEM VASILEV	{"email": "artem.vasilev-19121978@postgrespro.ru", "phone": "+70120030238"}
0005433234479	B35137	7772 986577	VLADIMIR ROMANOV	{"phone": "+70403057633"}
0005433234480	1787D6	6618 619306	FEDOR SHEVCHENKO	{"email": "shevchenkofedor_27011980@postgrespro.ru", "phone": "+70895928589"}
0005433234481	1787D6	1646 342444	YULIYA TROFIMOVA	{"email": "trofimova_y-29121968@postgrespro.ru", "phone": "+70447010082"}
0005433234482	1787D6	2511 660204	PETR BORISOV	{"phone": "+70990407278"}
0005433234483	B34B0A	9435 793639	ELENA GUSEVA	{"phone": "+70355504496"}
0005433234484	F2F06D	3627 058443	GEORGIY VASILEV	{"email": "georgiyvasilev_05021977@postgrespro.ru", "phone": "+70328186683"}
0005433234485	A93813	8652 426722	ALEKSEY SOROKIN	{"phone": "+70871217373"}
0005433234486	A93813	0708 964139	ELENA IVANOVA	{"phone": "+70114759341"}
0005433234487	A392CB	8708 678468	KIRILL ABRAMOV	{"email": "k_abramov.09011971@postgrespro.ru", "phone": "+70775372059"}
0005433234488	7D27A7	0014 327048	ANTON RODIONOV	{"phone": "+70331719394"}
0005433234489	7D27A7	4260 849938	TAMARA VLASOVA	{"email": "vlasova.t.061982@postgrespro.ru", "phone": "+70581393133"}
0005433234490	C0C0A1	0715 148519	NIKOLAY POPOV	{"email": "popovn111966@postgrespro.ru", "phone": "+70046218306"}
0005433234491	DBCFD2	3538 936902	PELAGEYA GUSEVA	{"phone": "+70219552393"}
0005433234492	B23729	1436 097491	LIDIYA MIRONOVA	{"phone": "+70189061940"}
0005433234493	3920ED	7817 638770	ALEKSANDR MAKAROV	{"phone": "+70677310842"}
0005433234494	CB0E04	1221 892963	IRINA FEDOROVA	{"email": "fedorova.irina19031975@postgrespro.ru", "phone": "+70709863312"}
0005433234495	51FC8B	4203 248194	ROMAN NIKOLAEV	{"phone": "+70510631356"}
0005433234496	D3C349	4850 135131	MIKHAIL MELNIKOV	{"phone": "+70145401651"}
0005433234497	EA471D	8095 708790	VALERIY MAKAROV	{"phone": "+70955279397"}
0005433234498	EA471D	5778 022840	SERGEY POPOV	{"email": "popov-sergey081971@postgrespro.ru", "phone": "+70932106596"}
0005433234499	C0540C	8688 573404	SERGEY POPOV	{"email": "popov-sergey_061968@postgrespro.ru", "phone": "+70046758704"}
0005433234500	C0540C	8650 235668	NADEZHDA ZAKHAROVA	{"phone": "+70360266927"}
0005433234501	C0540C	3137 849578	GAGIK FILIPPOV	{"email": "filippov-gagik_1974@postgrespro.ru", "phone": "+70177817244"}
0005433234502	C6DC5B	6100 587673	LARISA BORISOVA	{"email": "borisova.larisa-1961@postgrespro.ru", "phone": "+70437755963"}
0005433234503	C6DC5B	4617 850298	EVGENIYA NIKITINA	{"email": "nikitina_e-1968@postgrespro.ru", "phone": "+70533569407"}
0005433234504	9F64B4	5991 685457	ALBINA NAUMOVA	{"email": "a.naumova.26051972@postgrespro.ru", "phone": "+70732950898"}
0005433234505	55FC67	7849 538861	ANATOLIY ANDREEV	{"email": "anatoliy_andreev1973@postgrespro.ru", "phone": "+70466048802"}
0005433234506	511D87	8220 821856	ALINA NAZAROVA	{"email": "alina-nazarova_011977@postgrespro.ru", "phone": "+70228636799"}
0005433234507	511D87	2700 124948	EGOR BORISOV	{"phone": "+70345836789"}
0005433234508	DE54B7	3732 368132	LYUBOV SOLOVEVA	{"phone": "+70844412378"}
0005433234509	DE54B7	7839 555578	NATALYA MELNIKOVA	{"phone": "+70222102657"}
0005433234510	3239B1	6254 537516	ALEKSEY SOROKIN	{"phone": "+70419859172"}
0005433234511	3A60B8	4429 834786	MIKHAIL ALEKSANDROV	{"phone": "+70178298041"}
0005433234512	F84D3E	1002 776306	ILYA ALEKSEEV	{"email": "alekseev-i_1976@postgrespro.ru", "phone": "+70069756234"}
0005433234513	F84D3E	3623 544162	ELENA PETROVA	{"email": "elena_petrova011975@postgrespro.ru", "phone": "+70466538255"}
0005433234514	F84D3E	9512 814014	EVGENIY MATVEEV	{"email": "e-matveev.051978@postgrespro.ru", "phone": "+70786248929"}
0005433234515	F84D3E	7196 243136	VASILIY SCHERBAKOV	{"phone": "+70887384010"}
0005433234516	AE7E66	8061 702115	VIKTORIYA ROMANOVA	{"email": "romanova-viktoriya1970@postgrespro.ru", "phone": "+70891837758"}
0005433234517	BA5F36	1683 280187	POLINA PETROVA	{"email": "petrova-p-101962@postgrespro.ru", "phone": "+70211192577"}
0005433234518	CD2790	9734 092459	KARINA MIKHAYLOVA	{"email": "mikhaylova_karina29071974@postgrespro.ru", "phone": "+70165409775"}
0005433234519	CD2790	0323 150983	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev-10041967@postgrespro.ru", "phone": "+70159684657"}
0005433234520	94C6D4	6219 988038	NADEZHDA EFIMOVA	{"phone": "+70016017788"}
0005433234521	94C6D4	1957 805602	ELIZAVETA SOLOVEVA	{"phone": "+70930207111"}
0005433234522	84DA8C	3221 285892	VLADIMIR SCHERBAKOV	{"phone": "+70252457760"}
0005433234523	84DA8C	4554 803374	VALERIY IVANOV	{"phone": "+70620599349"}
0005433234524	B9D8F3	5590 034957	IRINA SOLOVEVA	{"phone": "+70076368027"}
0005433234525	B9D8F3	1913 145179	YURIY KUZNECOV	{"email": "kuznecov.yuriy-1977@postgrespro.ru", "phone": "+70827445017"}
0005433234526	18564E	1159 152450	NIKOLAY MELNIKOV	{"phone": "+70919452747"}
0005433234527	E90573	9338 857252	NIKITA ZHUKOV	{"email": "n-zhukov_1970@postgrespro.ru", "phone": "+70111466837"}
0005433234528	78B57E	2703 980406	NIKOLAY MIKHAYLOV	{"phone": "+70515388342"}
0005433234529	C07A6D	1961 942019	ARTEM VASILEV	{"phone": "+70312974779"}
0005433234530	B73251	7996 132975	ARTEM POPOV	{"email": "a-popov.021970@postgrespro.ru", "phone": "+70983198214"}
0005433234531	9B4D97	3441 993701	MIKHAIL GAVRILOV	{"phone": "+70386543845"}
0005433234532	AD5340	3081 334820	YULIYA SCHERBAKOVA	{"phone": "+70686963126"}
0005433234533	79FACE	8596 575471	LYUDMILA ZOTOVA	{"email": "zotovalyudmila-20031969@postgrespro.ru", "phone": "+70181357087"}
0005433234534	79FACE	3016 455389	PAVEL POPOV	{"email": "p.popov.10061982@postgrespro.ru", "phone": "+70204817117"}
0005433234535	726C05	0311 196818	VALENTIN BELOV	{"email": "valentin-belov.101965@postgrespro.ru", "phone": "+70899674201"}
0005433234536	726C05	9857 280871	BORIS ZAYCEV	{"email": "zaycev_b_111967@postgrespro.ru", "phone": "+70104027116"}
0005433234537	6F119A	8114 373155	PAVEL VASILEV	{"email": "vasilev-pavel_1970@postgrespro.ru", "phone": "+70341774647"}
0005433234538	B696E8	0679 195600	PAVEL BORISOV	{"email": "p_borisov.041985@postgrespro.ru", "phone": "+70203887450"}
0005433234539	D0863D	7946 069525	TATYANA ALEKSEEVA	{"email": "tatyana-alekseeva011975@postgrespro.ru", "phone": "+70252961184"}
0005433234540	36E103	8020 648510	DMITRIY ANTONOV	{"phone": "+70588236286"}
0005433234541	A1D33B	2540 055725	ALEKSANDR KUZNECOV	{"email": "akuznecov-061966@postgrespro.ru", "phone": "+70649959009"}
0005433234542	7DFFD8	0463 865413	SVETLANA KRASNOVA	{"email": "krasnova.s25101969@postgrespro.ru", "phone": "+70456252247"}
0005433234543	7DFFD8	5506 013271	ELENA MIRONOVA	{"phone": "+70061471907"}
0005433234544	E51EC2	3165 105609	ANNA SOKOLOVA	{"phone": "+70678371190"}
0005433234545	E51EC2	9109 961266	POLINA KONDRATEVA	{"phone": "+70820017973"}
0005433234546	5249BB	7164 922058	DANIIL TIMOFEEV	{"email": "daniiltimofeev-1973@postgrespro.ru", "phone": "+70673645953"}
0005433234547	6E22E6	3386 936199	YURIY SIDOROV	{"email": "yuriysidorov-1966@postgrespro.ru", "phone": "+70934917506"}
0005433234548	6E22E6	8904 537893	ARTEM ZAYCEV	{"email": "zayceva.111979@postgrespro.ru", "phone": "+70829103032"}
0005433234549	A9ED12	9217 063537	TATYANA KRASNOVA	{"phone": "+70729274600"}
0005433234550	148701	1127 338441	YURIY KUZMIN	{"phone": "+70549176371"}
0005433234551	148701	4713 257304	ANNA BORISOVA	{"email": "a-borisova101977@postgrespro.ru", "phone": "+70899586643"}
0005433234552	1A19F5	6777 020770	ELENA GAVRILOVA	{"email": "elenagavrilova011981@postgrespro.ru", "phone": "+70242372730"}
0005433234553	1A19F5	6087 237311	OLGA MIKHAYLOVA	{"email": "omikhaylova-1990@postgrespro.ru", "phone": "+70767602707"}
0005433234554	B84F12	5899 640151	NIKOLAY SERGEEV	{"phone": "+70913236324"}
0005433234555	B84F12	9505 947296	ALEVTINA FADEEVA	{"email": "afadeeva_1975@postgrespro.ru", "phone": "+70291360625"}
0005433234556	B84F12	4686 971403	VLADIMIR MEDVEDEV	{"email": "medvedevv04011987@postgrespro.ru", "phone": "+70291067130"}
0005433234557	676E27	5575 746415	TATYANA ZAKHAROVA	{"email": "zakharova_t-1972@postgrespro.ru", "phone": "+70198935393"}
0005433234558	DA4A71	4377 776672	LIDIYA KOROLEVA	{"email": "lidiya-koroleva-041976@postgrespro.ru", "phone": "+70141993398"}
0005433234559	1017F8	3332 337585	TAMARA SOROKINA	{"email": "tamara.sorokina.081967@postgrespro.ru", "phone": "+70308320760"}
0005433234560	CC7670	2925 476404	EVGENIY SIDOROV	{"phone": "+70759753446"}
0005433234561	AD7F81	7105 319562	TAMARA KRASNOVA	{"email": "t-krasnova-1973@postgrespro.ru", "phone": "+70736875685"}
0005433234562	CF9478	8970 184180	TATYANA NAZAROVA	{"email": "nazarova-t051983@postgrespro.ru", "phone": "+70621376355"}
0005433234563	F95251	5261 569528	ELIZAVETA ZAKHAROVA	{"phone": "+70859022946"}
0005433234564	E91E30	0470 763951	SERGEY KOZLOV	{"phone": "+70372429038"}
0005433234565	FC2057	5158 667930	NINA ZAYCEVA	{"email": "nina_zayceva1972@postgrespro.ru", "phone": "+70018870580"}
0005433234566	E65981	8941 669810	VIKTOR KOZLOV	{"phone": "+70790378124"}
0005433234567	AC041D	1998 675705	SVETLANA SEMENOVA	{"email": "svetlana-semenova.071976@postgrespro.ru", "phone": "+70332911472"}
0005433234568	A0CC47	7896 106528	ANATOLIY ROMANOV	{"email": "anatoliy_romanov29041977@postgrespro.ru", "phone": "+70533927891"}
0005433234569	AAC160	1378 620494	ALEKSANDR VASILEV	{"email": "vasilevaleksandr26011965@postgrespro.ru", "phone": "+70422986504"}
0005433234570	9BA610	5306 504826	EKATERINA GORBUNOVA	{"email": "gorbunova-ekaterina-1979@postgrespro.ru", "phone": "+70592818408"}
0005433234571	982D27	6587 529030	VERA NIKIFOROVA	{"phone": "+70554360855"}
0005433234572	982D27	1157 894837	VLADIMIR AFANASEV	{"phone": "+70696628649"}
0005433234573	478B03	4471 609277	ALBINA IVANOVA	{"phone": "+70295026443"}
0005433234574	51C93F	7952 821130	TATYANA KOROLEVA	{"phone": "+70165487421"}
0005433234575	6FE0FA	6189 443685	VIKTOR VOLKOV	{"phone": "+70286148718"}
0005433234576	D3DCA2	2838 841069	VALENTINA DENISOVA	{"phone": "+70782340360"}
0005433234577	1FFA7C	1299 219369	SERGEY IVANOV	{"email": "ivanov.s-14061969@postgrespro.ru", "phone": "+70349044682"}
0005433234578	EBEC09	7071 628906	MIKHAIL NIKITIN	{"phone": "+70456724853"}
0005433234579	EBEC09	4503 512695	EVGENIY GAVRILOV	{"email": "gavrilov.e_051985@postgrespro.ru", "phone": "+70998147997"}
0005433234580	24A663	1198 629782	ANATOLIY FEDOROV	{"phone": "+70056952818"}
0005433234581	EA24EF	1257 849624	MIKHAIL VOLKOV	{"email": "m-volkov_1963@postgrespro.ru", "phone": "+70216883804"}
0005433234582	7C5324	5827 201121	LARISA ZAKHAROVA	{"phone": "+70289521581"}
0005433234583	BE73B0	9710 007848	LIDIYA MAKAROVA	{"phone": "+70190488546"}
0005433234584	BE73B0	9147 437908	NATALYA OVCHINNIKOVA	{"phone": "+70391894937"}
0005433234585	C0C3D4	9618 653773	ALINA ANDREEVA	{"phone": "+70297187544"}
0005433234586	2F9443	7574 127504	PAVEL KARPOV	{"phone": "+70907730966"}
0005433234587	2F9443	3845 900971	VALENTINA POTAPOVA	{"email": "potapova_v.071967@postgrespro.ru", "phone": "+70787763432"}
0005433234588	8EA724	3672 968907	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov.26081974@postgrespro.ru", "phone": "+70898009148"}
0005433234589	8EA724	1122 898631	POLINA LEBEDEVA	{"phone": "+70835327446"}
0005433234590	17E036	8565 404890	ELENA TITOVA	{"phone": "+70601078721"}
0005433234591	2567FD	5288 296799	ANNA MAKSIMOVA	{"phone": "+70993511589"}
0005433234592	2567FD	0876 460695	VLADISLAV FOMIN	{"email": "vladislav.fomin_021975@postgrespro.ru", "phone": "+70062822652"}
0005433234593	C57C7A	2986 066008	IRINA IVANOVA	{"phone": "+70794830889"}
0005433234594	9D321F	3988 905940	VALENTINA KARPOVA	{"email": "karpova.valentina-13031964@postgrespro.ru", "phone": "+70712693339"}
0005433234595	9D321F	2004 442398	LYUBOV BELOVA	{"email": "l-belova26111978@postgrespro.ru", "phone": "+70448478098"}
0005433234596	99497F	0440 380387	KIRILL KOZLOV	{"phone": "+70988513416"}
0005433234597	1C9F14	2582 315925	VLADISLAV TARASOV	{"email": "tarasov.v-101975@postgrespro.ru", "phone": "+70934486066"}
0005433234598	1C9F14	3956 180471	FANIL KAZAKOV	{"phone": "+70427751705"}
0005433234599	406630	7666 988998	VIKTOR MIKHAYLOV	{"phone": "+70602690696"}
0005433234600	2EC61C	0254 482524	RAIL TIMOFEEV	{"phone": "+70276780811"}
0005433234601	0566BA	6221 198294	VLADIMIR NAZAROV	{"email": "vladimir-nazarov.20121969@postgrespro.ru", "phone": "+70036619246"}
0005433234602	0566BA	4340 616947	ANASTASIYA TIKHONOVA	{"email": "anastasiya-tikhonova.04071970@postgrespro.ru", "phone": "+70589263038"}
0005433234603	42CB8E	4778 470541	TATYANA NIKOLAEVA	{"phone": "+70840070390"}
0005433234604	42CB8E	9325 624149	SERGEY ANDREEV	{"phone": "+70290518324"}
0005433234605	9A27A1	4642 279697	NATALYA NIKOLAEVA	{"phone": "+70598900810"}
0005433234606	9A27A1	5205 577707	OLGA YUDINA	{"email": "oyudina.1968@postgrespro.ru", "phone": "+70373336649"}
0005433234607	FBEC72	6184 465340	MARIYA ZAKHAROVA	{"email": "zakharova_mariya.24031990@postgrespro.ru", "phone": "+70649783294"}
0005433234608	299090	7144 506561	DMITRIY TARASOV	{"phone": "+70989831153"}
0005433234609	6E9D29	3948 337271	NURIYA PETROVA	{"email": "n-petrova-17121976@postgrespro.ru", "phone": "+70891526518"}
0005433234610	378595	3720 046203	POLINA ZAKHAROVA	{"phone": "+70113882475"}
0005433234611	378595	5262 593535	OLGA NOVIKOVA	{"phone": "+70447711388"}
0005433234612	14D136	3490 617185	OLGA MASLOVA	{"email": "maslovao02101985@postgrespro.ru", "phone": "+70252902833"}
0005433234613	264ECC	4041 472698	SERGEY MAKAROV	{"phone": "+70053933325"}
0005433234614	264ECC	8595 556054	OLGA SOKOLOVA	{"phone": "+70269002984"}
0005433234615	F7AD8F	8203 500641	ALEKSANDR IVANOV	{"phone": "+70627775447"}
0005433234616	A01F45	7977 809722	ALEVTINA ANDREEVA	{"phone": "+70893345156"}
0005433234617	A01F45	0603 039511	VLADIMIR KOROLEV	{"email": "korolev-vladimir11061977@postgrespro.ru", "phone": "+70170429990"}
0005433234618	890CF7	5351 025239	GALINA BOGDANOVA	{"email": "galina_bogdanova.29101965@postgrespro.ru", "phone": "+70603144230"}
0005433234619	71CF1B	2749 268417	IRINA ZHURAVLEVA	{"email": "i_zhuravleva-051981@postgrespro.ru", "phone": "+70208443143"}
0005433234620	9BC910	7195 850739	NINA ROMANOVA	{"email": "nina_romanova071962@postgrespro.ru", "phone": "+70460101241"}
0005433234621	48390A	8964 049572	YANA FEDOROVA	{"phone": "+70163717965"}
0005433234622	1ECE8F	3997 608550	DANIIL KRASNOV	{"phone": "+70454056837"}
0005433234623	D306AD	4737 574330	SERGEY MEDVEDEV	{"email": "s.medvedev.10091977@postgrespro.ru", "phone": "+70472464774"}
0005433234624	5E3F05	8457 196099	LYUBOV ILINA	{"phone": "+70587550374"}
0005433234625	EB749D	6953 341182	VLADIMIR GERASIMOV	{"phone": "+70722078201"}
0005433234743	BFF504	0825 284409	ELENA NIKOLAEVA	{"phone": "+70384631535"}
0005433234626	96A4A3	6499 530963	NATALIYA KUZNECOVA	{"email": "nataliya-kuznecova-021968@postgrespro.ru", "phone": "+70339261726"}
0005433234627	16842C	7735 920062	ELENA KONDRATEVA	{"phone": "+70714383574"}
0005433234628	16842C	4517 745457	MARINA ORLOVA	{"phone": "+70787198400"}
0005433234629	778082	4189 504656	EVGENIY FOMIN	{"email": "e_fomin_1957@postgrespro.ru", "phone": "+70250706424"}
0005433234630	778082	2902 670497	SERGEY GUSEV	{"email": "sergey.gusev-121982@postgrespro.ru", "phone": "+70203721900"}
0005433234631	F585B5	0367 199039	YAROSLAV IVANOV	{"email": "y.ivanov-24051979@postgrespro.ru", "phone": "+70783212157"}
0005433234632	1F8277	5748 075854	ARSENIY GERASIMOV	{"email": "a_gerasimov_051974@postgrespro.ru", "phone": "+70782490368"}
0005433234633	1F8277	5596 120356	ELIZAVETA SOLOVEVA	{"phone": "+70089511133"}
0005433234634	1F8277	4844 577726	ANTON SHEVCHENKO	{"phone": "+70066129957"}
0005433234635	D95C06	1017 197783	DENIS DENISOV	{"email": "ddenisov_091967@postgrespro.ru", "phone": "+70825359999"}
0005433234636	268D8B	6281 893671	ILYA ZHURAVLEV	{"email": "zhuravlev_ilya.091976@postgrespro.ru", "phone": "+70045831869"}
0005433234637	268D8B	7435 442388	ALEKSANDR GERASIMOV	{"phone": "+70347410303"}
0005433234638	268D8B	2076 294034	IRINA KOMAROVA	{"email": "komarova_i-091974@postgrespro.ru", "phone": "+70165504429"}
0005433234639	F59F7C	8288 107414	ALEKSANDR POPOV	{"email": "apopov10121961@postgrespro.ru", "phone": "+70898888017"}
0005433234640	F59F7C	4262 413050	INNA VASILEVA	{"phone": "+70202523430"}
0005433234641	7429E1	6381 119013	ANNA MOROZOVA	{"phone": "+70169604734"}
0005433234642	B4BF23	9772 737894	VALERIY ZHURAVLEV	{"email": "v_zhuravlev_07061970@postgrespro.ru", "phone": "+70069477756"}
0005433234643	082D21	8183 004900	ALEKSANDR FEDOROV	{"phone": "+70530005668"}
0005433234644	082D21	3074 256685	RAISA VLASOVA	{"phone": "+70417468641"}
0005433234645	7F67F3	7156 205738	ANASTASIYA ARKHIPOVA	{"email": "arkhipova_anastasiya.041962@postgrespro.ru", "phone": "+70522116124"}
0005433234646	091D47	1539 721237	SERGEY IVANOV	{"phone": "+70244012057"}
0005433234647	091D47	7206 543183	VALENTINA KULIKOVA	{"phone": "+70471836525"}
0005433234648	7EAFBE	0361 422761	VIKTOR GUSEV	{"phone": "+70019502274"}
0005433234649	7EAFBE	6888 511270	ANNA VLASOVA	{"email": "a_vlasova.091970@postgrespro.ru", "phone": "+70357600599"}
0005433234650	7EAFBE	7196 288225	VLADIMIR STEPANOV	{"phone": "+70485224475"}
0005433234651	F9FF9A	1474 604605	IGOR BELOV	{"email": "igor-belov.1983@postgrespro.ru", "phone": "+70090779108"}
0005433234652	D53073	5401 919513	TATYANA NIKOLAEVA	{"phone": "+70634656107"}
0005433234653	9D14CA	1173 553813	LYUDMILA KUZNECOVA	{"email": "l-kuznecova-06051983@postgrespro.ru", "phone": "+70813784180"}
0005433234654	221122	4007 221446	VIKTOR GRIGOREV	{"email": "grigorevviktor13031976@postgrespro.ru", "phone": "+70077171870"}
0005433234655	221122	0845 719489	VARVARA MAKSIMOVA	{"phone": "+70946334509"}
0005433234656	221122	2851 143782	KONSTANTIN SERGEEV	{"phone": "+70742185011"}
0005433234657	328891	4257 058760	ALBINA FILATOVA	{"email": "a.filatova.081978@postgrespro.ru", "phone": "+70066824866"}
0005433234658	F79CDC	2630 562296	PETR KISELEV	{"phone": "+70044899506"}
0005433234660	41C3D8	2083 766719	ANDREY BORISOV	{"phone": "+70711957083"}
0005433234661	B4DDA5	0658 544827	ELENA ANTONOVA	{"email": "elena_antonova-12021970@postgrespro.ru", "phone": "+70901723660"}
0005433234662	B4DDA5	6941 604783	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_aleksandr_1969@postgrespro.ru", "phone": "+70946454447"}
0005433234663	0637D8	0266 597243	DIANA DAVYDOVA	{"email": "dianadavydova061976@postgrespro.ru", "phone": "+70591484672"}
0005433234664	0637D8	9823 037314	LYUDMILA FOMINA	{"email": "lyudmila.fomina-28021967@postgrespro.ru", "phone": "+70344917405"}
0005433234665	033CE2	2704 163723	SERGEY BONDARENKO	{"phone": "+70134370761"}
0005433234666	ADEEBF	6545 450306	NIKOLAY RODIONOV	{"phone": "+70118623499"}
0005433234667	89B052	2309 251976	OKSANA VOLKOVA	{"email": "volkova.oksana041975@postgrespro.ru", "phone": "+70171524093"}
0005433234668	8DED64	5828 508839	ELENA ILINA	{"email": "elena.ilina-1964@postgrespro.ru", "phone": "+70796400962"}
0005433234669	E72374	8834 506791	DMITRIY ANDREEV	{"email": "andreev.d29011969@postgrespro.ru", "phone": "+70277702085"}
0005433234670	C11B2C	2586 867616	ROMAN FEDOROV	{"email": "rfedorov.1967@postgrespro.ru", "phone": "+70289799629"}
0005433234671	C11B2C	4280 999757	SVETLANA SERGEEVA	{"phone": "+70119646044"}
0005433234672	55708C	0622 249793	YULIYA ABRAMOVA	{"email": "y-abramova.051974@postgrespro.ru", "phone": "+70413534479"}
0005433234673	55708C	2454 239708	RUSLAN FOMIN	{"phone": "+70852986604"}
0005433234674	E152A0	1611 145726	NADEZHDA VOLKOVA	{"phone": "+70816718884"}
0005433234675	CCC78A	8281 276207	ALISA MAKAROVA	{"phone": "+70875652329"}
0005433234676	CCC78A	3275 970502	VIKTOR BARANOV	{"email": "baranov-viktor07021979@postgrespro.ru", "phone": "+70987492418"}
0005433234677	D9CFAB	2062 446991	ELENA IVANOVA	{"phone": "+70104412197"}
0005433234678	B7CAB0	8307 310149	ELENA SOKOLOVA	{"phone": "+70622390216"}
0005433234679	E04221	1862 128433	OKSANA ALEKSANDROVA	{"email": "aleksandrovao27011975@postgrespro.ru", "phone": "+70149297531"}
0005433234680	B28CD8	4255 809220	SNEZHANA ZOTOVA	{"email": "zotovasnezhana.12051968@postgrespro.ru", "phone": "+70751214389"}
0005433234681	0C12AA	7913 917141	VERA STEPANOVA	{"email": "verastepanova_061982@postgrespro.ru", "phone": "+70944883302"}
0005433234682	845E1A	7809 764291	ALEKSEY SEMENOV	{"email": "aleksey_semenov_1969@postgrespro.ru", "phone": "+70327515673"}
0005433234683	1AB952	2898 358637	ARTEM DAVYDOV	{"email": "artem_davydov1973@postgrespro.ru", "phone": "+70330343464"}
0005433234684	0A99E7	6634 115706	DMITRIY TIMOFEEV	{"email": "timofeev_dmitriy_1972@postgrespro.ru", "phone": "+70606671209"}
0005433234685	0EA44C	1859 139133	ANDREY KOROLEV	{"phone": "+70203055707"}
0005433234744	950963	9930 332025	RUSLAN KONOVALOV	{"phone": "+70735182663"}
0005433234686	C34A7B	0343 878085	ALEKSANDR KOZLOV	{"email": "kozlov_a1971@postgrespro.ru", "phone": "+70038276129"}
0005433234687	C34A7B	1586 628038	ZINAIDA VLASOVA	{"email": "zvlasova.021964@postgrespro.ru", "phone": "+70777157040"}
0005433234688	92FF95	0505 094100	IRINA DANILOVA	{"phone": "+70056975024"}
0005433234689	71D662	6806 923644	GALINA MAKAROVA	{"email": "galina-makarova_021972@postgrespro.ru", "phone": "+70664921117"}
0005433234690	3566F3	2239 417036	TAMARA KUZNECOVA	{"phone": "+70144189136"}
0005433234691	3566F3	7283 413450	VIKTOR SERGEEV	{"phone": "+70350074665"}
0005433234692	09357B	6975 164371	VERA IVANOVA	{"email": "vera.ivanova16041971@postgrespro.ru", "phone": "+70792650123"}
0005433234693	25AE4D	2297 395917	ANVAR NIKOLAEV	{"email": "anvar_nikolaev-1972@postgrespro.ru", "phone": "+70614610775"}
0005433234694	25AE4D	9571 541270	ALEKSEY KUZNECOV	{"email": "a.kuznecov1977@postgrespro.ru", "phone": "+70700950705"}
0005433234695	80F384	1271 797944	VIKTORIYA GRISHINA	{"email": "viktoriya-grishina_121967@postgrespro.ru", "phone": "+70269610776"}
0005433234696	80F384	2672 105436	ANNA FROLOVA	{"email": "frolova_anna-1973@postgrespro.ru", "phone": "+70164822172"}
0005433234697	602AC5	1136 065497	SERGEY MEDVEDEV	{"email": "s-medvedev.01071974@postgrespro.ru", "phone": "+70930928167"}
0005433234698	0CE0DB	1989 302413	TAMARA KUZMINA	{"phone": "+70034454647"}
0005433234699	5B04E7	2956 735439	TATYANA KOROLEVA	{"email": "koroleva_t.1964@postgrespro.ru", "phone": "+70953036767"}
0005433234700	CA8F62	5888 137679	ALEKSANDR DMITRIEV	{"phone": "+70821451423"}
0005433234701	CA8F62	7049 802399	VIKTOR CHERNOV	{"email": "chernov-viktor_121970@postgrespro.ru", "phone": "+70413352238"}
0005433234702	CA8F62	1646 451292	TATYANA KOROLEVA	{"phone": "+70900460003"}
0005433234703	52A15D	5903 422428	ALENA KAZAKOVA	{"email": "akazakova-041977@postgrespro.ru", "phone": "+70554561883"}
0005433234704	52A15D	8153 354577	ELENA MAKAROVA	{"email": "emakarova.1976@postgrespro.ru", "phone": "+70980700907"}
0005433234705	7E5779	7838 799156	ALEKSEY VOLKOV	{"email": "volkovaleksey_031976@postgrespro.ru", "phone": "+70956485975"}
0005433234706	8B6824	9141 796344	ANDREY SERGEEV	{"phone": "+70813854308"}
0005433234707	67E21D	0653 611947	ANNA KUZNECOVA	{"email": "a-kuznecova.1969@postgrespro.ru", "phone": "+70077462001"}
0005433234708	67E21D	0768 405511	EVGENIY SOROKIN	{"phone": "+70652404766"}
0005433234709	F2A8A7	2458 538099	LYUDMILA TITOVA	{"email": "lyudmila.titova_1971@postgrespro.ru", "phone": "+70449838753"}
0005433234710	F2A8A7	7214 977367	VLADIMIR NIKITIN	{"email": "nikitin.vladimir-031967@postgrespro.ru", "phone": "+70167885933"}
0005433234711	201F0B	4754 528721	MARIYA MIRONOVA	{"email": "mironovamariya-1972@postgrespro.ru", "phone": "+70280292807"}
0005433234712	936DFB	4469 313671	NIKITA BORISOV	{"email": "borisovnikita.31081967@postgrespro.ru", "phone": "+70593700415"}
0005433234713	26905B	3726 754445	PAVEL TIKHONOV	{"phone": "+70275716698"}
0005433234714	6170B4	7343 502017	VLADIMIR ZAYCEV	{"email": "vladimir_zaycev.26111969@postgrespro.ru", "phone": "+70847654699"}
0005433234715	6170B4	7487 201935	ELVIRA FILIPPOVA	{"email": "elvira_filippova_08081966@postgrespro.ru", "phone": "+70858467003"}
0005433234716	FB070F	7714 900635	EVGENIY KUDRYASHOV	{"email": "e_kudryashov.1981@postgrespro.ru", "phone": "+70163986129"}
0005433234717	93D08C	4212 321914	ALEKSANDR RODIONOV	{"phone": "+70740452158"}
0005433234718	B77EDA	8527 539692	TAISIYA EFIMOVA	{"email": "efimova.t1971@postgrespro.ru", "phone": "+70634873413"}
0005433234719	D4B7DE	7883 346721	VIKTOR MAKAROV	{"email": "v_makarov1974@postgrespro.ru", "phone": "+70240549227"}
0005433234720	9C0984	8687 619431	MIKHAIL TARASOV	{"email": "mikhail-tarasov.1976@postgrespro.ru", "phone": "+70760725411"}
0005433234721	577753	8814 837010	ULYANA EGOROVA	{"email": "egorova-u.121978@postgrespro.ru", "phone": "+70042983259"}
0005433234722	5E9463	2745 972295	ALEKSEY GERASIMOV	{"phone": "+70104753110"}
0005433234723	46D775	2549 866782	FEDOR GERASIMOV	{"email": "gerasimov-fedor1959@postgrespro.ru", "phone": "+70042597209"}
0005433234724	3868D8	3431 210354	OKSANA FEDOROVA	{"email": "fedorova_oksana-081971@postgrespro.ru", "phone": "+70009676499"}
0005433234725	C95A3C	9028 257321	DMITRIY TIMOFEEV	{"phone": "+70948729823"}
0005433234726	C95A3C	4641 870517	GRIGORIY AFANASEV	{"phone": "+70233227325"}
0005433234727	F1FAE6	9454 398081	VIKTOR TIMOFEEV	{"email": "viktor-timofeev10061980@postgrespro.ru", "phone": "+70025465252"}
0005433234728	7B76D9	8529 355476	VALENTINA ILINA	{"email": "ilina-v.20081971@postgrespro.ru", "phone": "+70734049571"}
0005433234729	7B76D9	0171 653297	NIKOLAY MELNIKOV	{"email": "n_melnikov-051985@postgrespro.ru", "phone": "+70707094469"}
0005433234730	7B76D9	0199 335304	IRINA KUZNECOVA	{"email": "kuznecova-i1975@postgrespro.ru", "phone": "+70741487565"}
0005433234731	450B39	8472 042107	EKATERINA KOMAROVA	{"email": "ekaterina.komarova_11031995@postgrespro.ru", "phone": "+70836012099"}
0005433234732	450B39	0657 202641	ELENA POPOVA	{"phone": "+70186650030"}
0005433234733	450B39	4042 286720	ALEKSANDRA PETROVA	{"email": "petrova-a_031966@postgrespro.ru", "phone": "+70274511802"}
0005433234734	702557	3779 521873	ALEKSANDR SAVELEV	{"email": "savelev-aleksandr.05081978@postgrespro.ru", "phone": "+70858058752"}
0005433234735	77CBEB	1829 326571	ALEKSANDR PETROV	{"email": "petrov-a-19051964@postgrespro.ru", "phone": "+70043379832"}
0005433234736	77CBEB	2766 009172	VIKTORIYA OSIPOVA	{"email": "viktoriyaosipova-1973@postgrespro.ru", "phone": "+70630669179"}
0005433234737	9B6704	3400 628317	AZAT KUDRYASHOV	{"email": "kudryashova_1965@postgrespro.ru", "phone": "+70440622340"}
0005433234738	C91C5F	1060 223743	TATYANA NIKIFOROVA	{"phone": "+70945854570"}
0005433234739	4EFA0E	4854 662170	NATALYA KAZAKOVA	{"phone": "+70112364716"}
0005433234740	4EFA0E	6811 751091	OLGA MOROZOVA	{"phone": "+70705110753"}
0005433234741	2B0087	8088 039938	RUSTAM AFANASEV	{"email": "afanasev_r.081962@postgrespro.ru", "phone": "+70939991223"}
0005433234742	F667B3	4705 353906	VIKTOR MIRONOV	{"phone": "+70039850732"}
0005433234745	A10280	8266 640358	IGOR VASILEV	{"email": "i_vasilev_21011981@postgrespro.ru", "phone": "+70163448056"}
0005433234746	A10280	8553 226887	IRINA FEDOROVA	{"phone": "+70719629360"}
0005433234747	EECD64	9506 481724	SVETLANA MIKHAYLOVA	{"phone": "+70645089564"}
0005433234748	27582F	9108 900229	TATYANA KUZNECOVA	{"phone": "+70167552211"}
0005433234749	0115D5	0371 027265	ALEKSANDR PAVLOV	{"phone": "+70947559047"}
0005433234750	A0788E	4191 513095	GALINA KUZNECOVA	{"email": "kuznecovag_24031976@postgrespro.ru", "phone": "+70835671824"}
0005433234751	A0788E	7500 806392	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_31101978@postgrespro.ru", "phone": "+70999283291"}
0005433234752	050763	5354 498618	OLGA IVANOVA	{"phone": "+70076880513"}
0005433234753	050763	4874 929934	DARYA PETROVA	{"email": "petrova_darya_03111978@postgrespro.ru", "phone": "+70038671829"}
0005433234754	B2C3B4	3204 562904	VIKTOR IVANOV	{"email": "v.ivanov061975@postgrespro.ru", "phone": "+70420486246"}
0005433234755	F64B03	3446 756052	OLGA OSIPOVA	{"phone": "+70268564997"}
0005433234756	ECE8CD	7732 020858	ALEKSANDR MATVEEV	{"phone": "+70445058983"}
0005433234757	ECE8CD	1751 787991	TATYANA KOROLEVA	{"phone": "+70645675433"}
0005433234758	AACB7C	1797 826997	ELENA GORBUNOVA	{"email": "elenagorbunova1966@postgrespro.ru", "phone": "+70042195732"}
0005433234759	3F63C6	0302 451416	NATALYA IVANOVA	{"phone": "+70448706950"}
0005433234760	3F63C6	0415 958534	LYUDMILA MAKAROVA	{"email": "makaroval-1980@postgrespro.ru", "phone": "+70779537656"}
0005433234761	DE42A0	5971 355017	SVETLANA KISELEVA	{"email": "kiseleva-s1961@postgrespro.ru", "phone": "+70344551229"}
0005433234762	2B35FA	4865 279581	YULIYA BELOVA	{"email": "belova-yuliya1966@postgrespro.ru", "phone": "+70231594101"}
0005433234763	50DC81	9253 275732	LIDIYA OSIPOVA	{"phone": "+70676585314"}
0005433234764	CF408F	6527 945596	ALEVTINA ZHUKOVA	{"email": "a_zhukova_20051975@postgrespro.ru", "phone": "+70414203424"}
0005433234765	CF408F	2989 366220	ARINA IVANOVA	{"email": "ivanovaarina061963@postgrespro.ru", "phone": "+70893803690"}
0005433234766	8971B6	9702 933843	ARKADIY FEDOTOV	{"email": "arkadiy_fedotov-081971@postgrespro.ru", "phone": "+70276868149"}
0005433234767	8971B6	5230 066615	YURIY KOROLEV	{"phone": "+70007653877"}
0005433234768	9525CA	1887 335440	PAVEL ROMANOV	{"phone": "+70480489935"}
0005433234769	B2AFF7	7359 971169	VASILIY MIKHAYLOV	{"phone": "+70416978911"}
0005433234770	CC625D	4912 074016	ANATOLIY SMIRNOV	{"email": "smirnova_1975@postgrespro.ru", "phone": "+70671287579"}
0005433234771	746F85	9447 823016	DARYA NIKITINA	{"email": "d_nikitina1963@postgrespro.ru", "phone": "+70237940538"}
0005433234772	AF0BEE	9918 877335	ANATOLIY MAKAROV	{"email": "makarov-anatoliy_02121969@postgrespro.ru", "phone": "+70380589804"}
0005433234773	AF0BEE	7993 000979	IRINA EFREMOVA	{"phone": "+70059137195"}
0005433234774	7EB122	3581 780719	OLGA IVANOVA	{"email": "o_ivanova-27101975@postgrespro.ru", "phone": "+70915610121"}
0005433234775	7EB122	6346 465833	ALEKSANDR KUZNECOV	{"phone": "+70463302555"}
0005433234776	8D12E5	4667 491455	TAMARA ISAEVA	{"phone": "+70035807931"}
0005433234777	04CA86	9623 764884	VLADIMIR FOMIN	{"phone": "+70942140148"}
0005433234778	DD04B2	5208 690658	DARYA MARTYNOVA	{"phone": "+70057147241"}
0005433234779	DD04B2	8172 537185	ALEKSEY ILIN	{"email": "aleksey-ilin_101975@postgrespro.ru", "phone": "+70101874950"}
0005433234780	6EA87E	1821 667084	ANASTASIYA POPOVA	{"phone": "+70474994760"}
0005433234781	040B4B	3899 009204	VERONIKA AKIMOVA	{"phone": "+70485231074"}
0005433234782	D92C23	1817 480479	ANNA SERGEEVA	{"phone": "+70057593918"}
0005433234783	D92C23	0181 664096	ALEKSANDR SIDOROV	{"email": "a_sidorov-1968@postgrespro.ru", "phone": "+70483651984"}
0005433234784	EEF43B	4282 836679	SVETLANA GAVRILOVA	{"phone": "+70404211416"}
0005433234785	895A3B	8027 010794	ELENA POPOVA	{"phone": "+70494430771"}
0005433234786	F4FC1E	7358 727502	PETR ANTONOV	{"phone": "+70427884507"}
0005433234787	F4FC1E	5494 086097	OLGA OSIPOVA	{"email": "osipovao081972@postgrespro.ru", "phone": "+70198165425"}
0005433234788	F4FC1E	8957 595216	VLADIMIR KUZMIN	{"phone": "+70993764903"}
0005433234789	A8425E	7869 620192	ULYANA MOROZOVA	{"email": "morozovau_1966@postgrespro.ru", "phone": "+70264931808"}
0005433234790	A8425E	8695 275532	LILIYA FOMINA	{"phone": "+70319837267"}
0005433234791	A8425E	8810 989180	NINA PAVLOVA	{"phone": "+70677769014"}
0005433234792	2B0791	6864 849653	ANASTASIYA VASILEVA	{"email": "vasileva_anastasiya-021967@postgrespro.ru", "phone": "+70676700995"}
0005433234793	2B0791	1079 543551	ANDREY FILIPPOV	{"phone": "+70662497922"}
0005433234794	DC41C4	7861 729580	VALERIY KUZNECOV	{"email": "kuznecov-valeriy101979@postgrespro.ru", "phone": "+70250538623"}
0005433234795	DC41C4	6720 765728	VALERIY ORLOV	{"phone": "+70431677315"}
0005433234796	DC41C4	0213 006023	EVGENIY STEPANOV	{"email": "e.stepanov1970@postgrespro.ru", "phone": "+70061265193"}
0005433234797	558A4D	5020 906206	EVGENIYA KUDRYASHOVA	{"email": "kudryashova_evgeniya21111964@postgrespro.ru", "phone": "+70807558083"}
0005433234798	558A4D	5438 336086	NIKOLAY ANTONOV	{"phone": "+70317099899"}
0005433234799	D50C46	4207 779928	VENIAMIN ZHURAVLEV	{"email": "zhuravlev-veniamin.07111963@postgrespro.ru", "phone": "+70639650190"}
0005433234800	13D938	0996 235119	ELVIRA KARPOVA	{"email": "karpovaelvira1990@postgrespro.ru", "phone": "+70578888446"}
0005433234801	86DD2D	9818 843008	NINA TITOVA	{"phone": "+70421019482"}
0005433234802	86DD2D	2124 405317	TATYANA TIMOFEEVA	{"email": "timofeeva.t-21051973@postgrespro.ru", "phone": "+70170417738"}
0005433234803	5BDD30	2887 084037	TAMARA EGOROVA	{"phone": "+70065842376"}
0005433234804	DF9360	8795 753566	DENIS MOROZOV	{"phone": "+70714084669"}
0005433234805	488651	6217 222643	VLADIMIR AFANASEV	{"phone": "+70358118554"}
0005433234806	488651	3161 595604	VALENTINA POTAPOVA	{"phone": "+70349999321"}
0005433234807	61AAC1	4600 579100	TATYANA NESTEROVA	{"email": "nesterova-tatyana24051966@postgrespro.ru", "phone": "+70206005249"}
0005433234808	EB94A7	9644 322890	TATYANA POPOVA	{"email": "popova.t18031967@postgrespro.ru", "phone": "+70822825701"}
0005433234809	4CE735	4483 798381	LYUDMILA LAZAREVA	{"phone": "+70998664716"}
0005433234810	4CE735	3738 668456	NINA SIDOROVA	{"email": "sidorova_nina121964@postgrespro.ru", "phone": "+70383850146"}
0005433234811	785080	9374 071570	NATALYA BARANOVA	{"phone": "+70657250679"}
0005433234812	375640	0884 117175	MARIYA VASILEVA	{"email": "vasileva.mariya-17081977@postgrespro.ru", "phone": "+70670943391"}
0005433234813	375640	7140 980319	ALEKSEY ALEKSANDROV	{"email": "aleksey_aleksandrov_25011970@postgrespro.ru", "phone": "+70535392256"}
0005433234814	19939F	7477 172001	ALEKSEY VOROBEV	{"phone": "+70223700328"}
0005433234815	72D5B9	7276 884373	NATALYA MARTYNOVA	{"email": "natalya_martynova_05071971@postgrespro.ru", "phone": "+70173072650"}
0005433234816	7B0D72	9875 870635	ANATOLIY MAKAROV	{"phone": "+70200408251"}
0005433234817	7B0D72	7360 617067	TATYANA ZHUKOVA	{"email": "zhukova_t-06041973@postgrespro.ru", "phone": "+70528992158"}
0005433234818	944CD5	2052 752114	KSENIYA KOZLOVA	{"email": "k_kozlova1967@postgrespro.ru", "phone": "+70118073405"}
0005433234819	944CD5	0619 207851	LARISA SCHERBAKOVA	{"phone": "+70003480630"}
0005433234820	EE324F	6108 810957	ANNA AFANASEVA	{"phone": "+70885321958"}
0005433234821	EE324F	7884 769200	REGINA KUZNECOVA	{"email": "kuznecovar.15081978@postgrespro.ru", "phone": "+70678723410"}
0005433234822	EE324F	9853 267183	ALEVTINA KUZMINA	{"phone": "+70203359221"}
0005433234823	6B1393	9687 452019	ELENA KUZNECOVA	{"email": "elenakuznecova-30011967@postgrespro.ru", "phone": "+70077977809"}
0005433234824	77788A	2171 704870	EVGENIYA NAUMOVA	{"email": "naumova.evgeniya20111975@postgrespro.ru", "phone": "+70993018023"}
0005433234825	77788A	3113 558969	ALEKSANDR MAKAROV	{"phone": "+70728645091"}
0005433234826	087270	8016 933554	LYUBOV SERGEEVA	{"phone": "+70447753353"}
0005433234827	087270	1234 322767	VLADIMIR VOLKOV	{"phone": "+70325593086"}
0005433234828	3E7D28	5266 018728	NATALYA IVANOVA	{"email": "natalyaivanova_01071972@postgrespro.ru", "phone": "+70250789851"}
0005433234829	3E7D28	3744 413944	DMITRIY GERASIMOV	{"email": "dmitriy.gerasimov_1973@postgrespro.ru", "phone": "+70788789105"}
0005433234830	DA9E0F	9733 798617	YANA MAKAROVA	{"phone": "+70273478452"}
0005433234831	25AD78	3057 624467	MAKSIM MOISEEV	{"email": "moiseevm.121987@postgrespro.ru", "phone": "+70760025990"}
0005433234832	F59B1A	3274 918842	VALERIY GERASIMOV	{"phone": "+70610797134"}
0005433234833	730DFC	5836 735230	ILYA IVANOV	{"email": "i.ivanov_1968@postgrespro.ru", "phone": "+70896904614"}
0005433234834	730DFC	3206 912681	PETR FILIPPOV	{"email": "p-filippov18031985@postgrespro.ru", "phone": "+70353074132"}
0005433234835	730DFC	9561 209947	MIKHAIL ABRAMOV	{"phone": "+70623482678"}
0005433234836	07151D	8853 570991	ALEKSEY ANDREEV	{"email": "andreev-a.081974@postgrespro.ru", "phone": "+70232485186"}
0005433234837	6D74E5	0172 598068	EKATERINA MELNIKOVA	{"email": "ekaterina_melnikova19071980@postgrespro.ru", "phone": "+70331274779"}
0005433234838	6D74E5	9976 238076	ANDREY NIKOLAEV	{"phone": "+70358202637"}
0005433234839	3352C2	9272 957875	VALERIYA GERASIMOVA	{"phone": "+70691641876"}
0005433234840	3352C2	4425 499799	VIKTOR PETROV	{"email": "viktorpetrov_21091962@postgrespro.ru", "phone": "+70538698371"}
0005433234841	50214B	8231 951201	MARGARITA BORISOVA	{"phone": "+70653884696"}
0005433234842	0FBA75	6635 460228	OLGA DANILOVA	{"email": "olga_danilova_101968@postgrespro.ru", "phone": "+70967396078"}
0005433234843	0FBA75	1492 868768	GALINA ANTONOVA	{"phone": "+70483208652"}
0005433234844	A876D6	2128 618457	ANTONINA SIDOROVA	{"phone": "+70159536808"}
0005433234845	4EA510	9555 900531	TATYANA FILIPPOVA	{"phone": "+70425585309"}
0005433234846	E46D81	1259 742393	SVETLANA POPOVA	{"email": "s_popova_17061976@postgrespro.ru", "phone": "+70520464277"}
0005433234847	CC3974	7532 632833	OLGA ABRAMOVA	{"phone": "+70073245809"}
0005433234848	0F74EC	6903 774110	NADEZHDA BELOVA	{"phone": "+70591456588"}
0005433234849	896628	7408 314486	VLADIMIR MOISEEV	{"phone": "+70500285895"}
0005433234850	A09C33	1962 305112	MARIYA VASILEVA	{"email": "m-vasileva-07071959@postgrespro.ru", "phone": "+70556565849"}
0005433234851	CA3505	5279 301757	RENAT AFANASEV	{"email": "afanasev.renat-121958@postgrespro.ru", "phone": "+70396460913"}
0005433234852	CA3505	0016 194106	LYUDMILA SAVELEVA	{"email": "lyudmila_saveleva101967@postgrespro.ru", "phone": "+70991209508"}
0005433234853	C60EE2	1036 736575	VYACHESLAV BELOV	{"phone": "+70206861980"}
0005433234854	5F255F	3857 044078	ALEKSANDR FEDOROV	{"phone": "+70912636166"}
0005433234855	5F255F	9065 764725	ALEKSEY VOROBEV	{"email": "vorobevaleksey.031965@postgrespro.ru", "phone": "+70370235250"}
0005433234856	76C318	6760 296244	VALENTIN MIRONOV	{"phone": "+70506016983"}
0005433234857	76C318	3001 565025	ALEKSEY KONOVALOV	{"email": "konovalov_aleksey-1963@postgrespro.ru", "phone": "+70614155642"}
0005433234858	76C318	9326 580270	OLGA GERASIMOVA	{"phone": "+70068378221"}
0005433234859	D83650	5912 840633	ALEKSANDR DAVYDOV	{"phone": "+70062743563"}
0005433234860	D83650	1284 671268	ANNA ROMANOVA	{"email": "romanova_a.091976@postgrespro.ru", "phone": "+70966942451"}
0005433234861	D83650	7528 458946	VIKTORIYA KOZLOVA	{"email": "v-kozlova-101971@postgrespro.ru", "phone": "+70600488580"}
0005433234862	2D8174	1424 744160	ALENA AFANASEVA	{"phone": "+70430633792"}
0005433234863	F57BBB	7499 845862	ARTEM ALEKSEEV	{"email": "alekseev_artem1973@postgrespro.ru", "phone": "+70052635573"}
0005433234864	F57BBB	4480 047217	LARISA ORLOVA	{"phone": "+70726573763"}
0005433234865	D5D7D1	3816 355302	EVGENIY IVANOV	{"phone": "+70821588482"}
0005433234866	2BE915	8519 872781	NIKOLAY GAVRILOV	{"email": "gavrilov.n061981@postgrespro.ru", "phone": "+70544721535"}
0005433234867	2BE915	9121 628625	OLEG VOLKOV	{"phone": "+70798458330"}
0005433234868	992D2D	2138 631249	PAVEL PAVLOV	{"phone": "+70962032179"}
0005433234869	9E3FBC	8580 709839	LIDIYA LOGINOVA	{"email": "lidiya-loginova20011988@postgrespro.ru", "phone": "+70128973523"}
0005433234870	9E3FBC	3398 292655	KSENIYA MASLOVA	{"email": "maslovakseniya_1984@postgrespro.ru", "phone": "+70487368967"}
0005433234871	C96635	5986 042134	LYUDMILA MAKAROVA	{"email": "makarovalyudmila-02101967@postgrespro.ru", "phone": "+70194065801"}
0005433234872	C96635	8164 380421	VALERIY ALEKSANDROV	{"email": "v-aleksandrov_011964@postgrespro.ru", "phone": "+70048520554"}
0005433234873	423658	3076 598978	ELENA PETROVA	{"email": "petrovae_11111964@postgrespro.ru", "phone": "+70001082158"}
0005433234874	2A721E	0931 717932	VIKTOR VOROBEV	{"email": "viktor_vorobev-1969@postgrespro.ru", "phone": "+70905594892"}
0005433234875	C8AA02	9172 690602	MARINA GAVRILOVA	{"phone": "+70546449668"}
0005433234876	822D45	4675 926262	DMITRIY KUZNECOV	{"phone": "+70684527628"}
0005433234877	822D45	1464 390822	TATYANA ALEKSANDROVA	{"email": "aleksandrova.tatyana_011970@postgrespro.ru", "phone": "+70308303182"}
0005433234878	B14E66	7336 884558	ANDREY ILIN	{"email": "andrey-ilin_111974@postgrespro.ru", "phone": "+70073017047"}
0005433234879	F6FF4A	9738 919131	SERGEY SHEVCHENKO	{"email": "sergey_shevchenko_101971@postgrespro.ru", "phone": "+70771188216"}
0005433234880	F6FF4A	9310 362108	LIDIYA FEDOROVA	{"phone": "+70623852410"}
0005433234881	622310	3706 850888	DENIS SAVELEV	{"email": "denis_savelev-12041981@postgrespro.ru", "phone": "+70339884727"}
0005433234882	C02D9F	9033 099703	VALENTINA VASILEVA	{"email": "valentina.vasileva.09031988@postgrespro.ru", "phone": "+70792665608"}
0005433234883	50ECF4	5645 699203	ARINA CHERNOVA	{"phone": "+70324071505"}
0005433234884	50ECF4	2003 546752	PAVEL MOROZOV	{"phone": "+70427124772"}
0005433234885	79247E	1692 283902	ALEKSANDR DENISOV	{"phone": "+70325008162"}
0005433234886	355AA4	4219 252908	SERGEY VOLKOV	{"phone": "+70994323965"}
0005433234887	D7C920	1056 271362	MARINA MELNIKOVA	{"phone": "+70795372547"}
0005433234888	82C378	6212 035576	ALEKSANDR FILIPPOV	{"phone": "+70070574249"}
0005433234889	C0263B	6274 855943	ALEKSEY SAVELEV	{"email": "asavelev_1974@postgrespro.ru", "phone": "+70437198965"}
0005433234890	F1CDE3	5862 537885	NATALYA CHERNOVA	{"email": "natalya_chernova031974@postgrespro.ru", "phone": "+70962189426"}
0005433234891	F7283A	4826 099929	ZINAIDA NOVIKOVA	{"email": "novikova.zinaida_15121965@postgrespro.ru", "phone": "+70127943149"}
0005433234892	8E0848	1041 282126	OLGA NESTEROVA	{"email": "nesterovaolga091965@postgrespro.ru", "phone": "+70679714445"}
0005433234893	8E0848	9655 078680	NADEZHDA VASILEVA	{"phone": "+70859196090"}
0005433234894	D1DF0C	5561 601683	SERGEY KUZMIN	{"email": "s-kuzmin19041985@postgrespro.ru", "phone": "+70429986739"}
0005433234895	DEEA1C	5281 290099	VLADIMIR ORLOV	{"phone": "+70428445890"}
0005433234896	DEEA1C	4746 413256	OLEG YAKOVLEV	{"email": "oleg_yakovlev1983@postgrespro.ru", "phone": "+70580371137"}
0005433234897	5B5C87	6073 029328	RAISA NESTEROVA	{"phone": "+70182857091"}
0005433234898	BCB638	0561 516180	DMITRIY ROMANOV	{"phone": "+70106399966"}
0005433234899	7DD8B3	9287 535741	TATYANA KOZLOVA	{"email": "t.kozlova_1965@postgrespro.ru", "phone": "+70011952056"}
0005433234900	7DD8B3	2662 405680	ANASTASIYA POTAPOVA	{"email": "a.potapova-27081968@postgrespro.ru", "phone": "+70886643995"}
0005433234901	75080A	2668 090868	ELENA OVCHINNIKOVA	{"phone": "+70168984158"}
0005433234902	BBF0FC	3404 656895	IRINA FILATOVA	{"email": "filatovai_111984@postgrespro.ru", "phone": "+70502679662"}
0005433234903	62C62F	5981 860402	ANNA OSIPOVA	{"phone": "+70489576001"}
0005433234904	6DBE18	6297 553254	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov-031968@postgrespro.ru", "phone": "+70173123937"}
0005433234905	2B462D	1543 335187	SERGEY SMIRNOV	{"phone": "+70373078954"}
0005433234906	DFCDDA	7805 655071	VIKTOR MEDVEDEV	{"email": "v-medvedev.1980@postgrespro.ru", "phone": "+70108250964"}
0005433234907	BD49C8	2833 557692	VASILIY NAZAROV	{"email": "vasiliy_nazarov.17111974@postgrespro.ru", "phone": "+70881390261"}
0005433234908	95C74F	4111 695645	ALEKSANDR MIKHAYLOV	{"phone": "+70910580496"}
0005433234909	73D929	0394 523571	VERA PAVLOVA	{"email": "vpavlova.25061989@postgrespro.ru", "phone": "+70843092200"}
0005433234910	73D929	9319 172766	LEONID MAKAROV	{"phone": "+70401200721"}
0005433234911	1F0952	0142 270439	ELENA KOZLOVA	{"phone": "+70841567532"}
0005433234912	1F0952	0503 069195	ALEKSANDR FROLOV	{"email": "aleksandr.frolov_021959@postgrespro.ru", "phone": "+70344009867"}
0005433234913	1F0952	7700 154105	MARIYA ZAKHAROVA	{"phone": "+70377238645"}
0005433234914	C2135B	9577 595176	ANATOLIY SOLOVEV	{"email": "a_solovev051972@postgrespro.ru", "phone": "+70951561984"}
0005433234915	C2135B	7755 759875	ALEKSANDRA ILINA	{"phone": "+70477867379"}
0005433234916	C2135B	4529 513231	YULIYA MEDVEDEVA	{"email": "medvedeva.yuliya-12071984@postgrespro.ru", "phone": "+70673132646"}
0005433234917	05B0DE	4042 743027	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov.28101969@postgrespro.ru", "phone": "+70378178244"}
0005433234918	AEB4F0	5391 648873	ANATOLIY FEDOTOV	{"phone": "+70948480353"}
0005433234919	919433	1608 622756	DMITRIY KOZLOV	{"email": "dmitriy_kozlov1970@postgrespro.ru", "phone": "+70809533059"}
0005433234920	919433	6094 226916	STANISLAV KISELEV	{"email": "kiselevs1984@postgrespro.ru", "phone": "+70207314976"}
0005433234921	ECF703	1642 794912	ALEKSEY KISELEV	{"email": "kiseleva-09071964@postgrespro.ru", "phone": "+70635067544"}
0005433234922	843642	4109 750390	PAVEL SMIRNOV	{"phone": "+70144833934"}
0005433234923	887C88	6096 100770	ANASTASIYA EFREMOVA	{"email": "a_efremova.021983@postgrespro.ru", "phone": "+70252545578"}
0005433234924	1AD00B	1544 505902	KARINA VASILEVA	{"email": "vasileva.karina.16011966@postgrespro.ru", "phone": "+70829778512"}
0005433234925	B0F718	1768 639153	TAISIYA OVCHINNIKOVA	{"phone": "+70686963513"}
0005433234926	75EB98	1312 251757	MIKHAIL KUZMIN	{"phone": "+70006699457"}
0005433234927	EB4F35	1438 508935	SERGEY EGOROV	{"email": "sergey.egorov.1968@postgrespro.ru", "phone": "+70506870371"}
0005433234928	AF2666	1875 826475	ANDREY SCHERBAKOV	{"phone": "+70572442985"}
0005433234929	1A3E6D	2881 498744	EKATERINA LUKYANOVA	{"phone": "+70981694300"}
0005433234930	882975	3148 395573	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_v-1979@postgrespro.ru", "phone": "+70335223279"}
0005433234931	FB02CE	4594 756367	NADEZHDA POTAPOVA	{"email": "n.potapova_15071981@postgrespro.ru", "phone": "+70261039617"}
0005433234932	B7EC06	9718 051525	YURIY NAZAROV	{"email": "y-nazarov_1963@postgrespro.ru", "phone": "+70738050640"}
0005433234933	B7EC06	8740 950744	SOFIYA ANDREEVA	{"email": "andreeva-sofiya.12021966@postgrespro.ru", "phone": "+70493289299"}
0005433234934	2D633F	1841 016247	VLADIMIR DAVYDOV	{"email": "v_davydov_1977@postgrespro.ru", "phone": "+70044938423"}
0005433234935	2D633F	6360 474880	RUSLAN KRASNOV	{"email": "krasnov.r_1974@postgrespro.ru", "phone": "+70606051654"}
0005433234936	2C251D	8802 620216	ALENA VOROBEVA	{"phone": "+70431960875"}
0005433234937	E58AA6	7977 186568	ALEKSEY NOVIKOV	{"email": "a-novikov_1972@postgrespro.ru", "phone": "+70354322333"}
0005433234938	E58AA6	6440 405958	NATALYA TITOVA	{"email": "n-titova19121971@postgrespro.ru", "phone": "+70343744222"}
0005433234939	29B541	4672 817087	NATALYA NIKIFOROVA	{"phone": "+70011460367"}
0005433234940	9AF76D	9288 063874	VADIM ROMANOV	{"email": "romanov-vadim_02041979@postgrespro.ru", "phone": "+70681397453"}
0005433234941	9AF76D	1256 182986	SOFIYA ZOTOVA	{"email": "zotova_s_051972@postgrespro.ru", "phone": "+70030961181"}
0005433234942	0B725A	7919 526680	GALINA SERGEEVA	{"email": "galina.sergeeva-11031959@postgrespro.ru", "phone": "+70593026055"}
0005433234943	97F02F	2721 909436	VIKTOR MATVEEV	{"email": "viktor_matveev1975@postgrespro.ru", "phone": "+70785523163"}
0005433234944	97F02F	0692 688445	ELENA ANDREEVA	{"phone": "+70895022081"}
0005433234945	6FA8F6	7691 606264	ANATOLIY BORISOV	{"phone": "+70926608542"}
0005433234946	6FA8F6	4651 868494	NINA RYABOVA	{"phone": "+70157147352"}
0005433234947	6FA8F6	6976 036754	ANATOLIY NAUMOV	{"email": "a-naumov-22031974@postgrespro.ru", "phone": "+70004545408"}
0005433234948	EE5511	3119 600921	OLGA ZAKHAROVA	{"phone": "+70541517674"}
0005433234949	EE5511	9914 178189	ALBINA ORLOVA	{"phone": "+70145244973"}
0005433234950	EE5511	4235 760163	ANDREY IVANOV	{"email": "ivanovandrey-01061965@postgrespro.ru", "phone": "+70649547150"}
0005433234951	356B14	1876 708351	VIKTOR POPOV	{"email": "viktor.popov.02081960@postgrespro.ru", "phone": "+70571849001"}
0005433234952	0E4E02	9502 518265	ELENA IVANOVA	{"email": "ivanova.elena07081966@postgrespro.ru", "phone": "+70095319978"}
0005433234953	D6E902	1881 043451	VLADIMIR KUDRYASHOV	{"email": "vladimirkudryashov18081967@postgrespro.ru", "phone": "+70853422743"}
0005433234954	70BBB6	8398 369747	SOFIYA MATVEEVA	{"email": "matveeva_sofiya_051974@postgrespro.ru", "phone": "+70411564128"}
0005433234955	70BBB6	9628 368389	GALINA NOVIKOVA	{"email": "novikova.g.1971@postgrespro.ru", "phone": "+70184992560"}
0005433234956	BE3B23	0603 597794	EKATERINA PETROVA	{"email": "petrovaekaterina_28091965@postgrespro.ru", "phone": "+70759087288"}
0005433234957	6D12F6	0371 198606	ALEKSEY ALEKSEEV	{"phone": "+70239152345"}
0005433234958	B21B31	9681 578753	IRINA FILATOVA	{"phone": "+70127128009"}
0005433234959	44F169	6642 273036	ELENA KUZNECOVA	{"email": "elena_kuznecova-04091978@postgrespro.ru", "phone": "+70386675433"}
0005433234960	03023B	6882 859691	MARINA OSIPOVA	{"email": "osipova_m-1973@postgrespro.ru", "phone": "+70769207855"}
0005433234961	B9635F	2543 502598	ANDREY MIKHAYLOV	{"email": "amikhaylov_1969@postgrespro.ru", "phone": "+70839831494"}
0005433234962	5978C4	4571 412884	ALINA BELOVA	{"phone": "+70728987608"}
0005433234963	5978C4	3834 250421	LIDIYA KOZLOVA	{"email": "kozlova_l-041968@postgrespro.ru", "phone": "+70662176634"}
0005433234964	659B65	4968 254094	MIKHAIL MIRONOV	{"email": "mironov_mikhail.10031963@postgrespro.ru", "phone": "+70717070488"}
0005433234965	659B65	4323 216078	DIANA LEBEDEVA	{"email": "lebedeva.diana.021973@postgrespro.ru", "phone": "+70837444357"}
0005433234966	1021D2	7002 774927	NIKOLAY IVANOV	{"phone": "+70273702040"}
0005433234967	1021D2	2254 115337	TATYANA AFANASEVA	{"email": "t.afanaseva02101964@postgrespro.ru", "phone": "+70070480959"}
0005433234968	076F6F	9423 867407	VALERIY OSIPOV	{"email": "valeriyosipov.01011964@postgrespro.ru", "phone": "+70954981136"}
0005433234969	49B79F	6682 921165	IVAN NOVIKOV	{"email": "novikov_i-23121966@postgrespro.ru", "phone": "+70796410071"}
0005433234970	29446F	3465 679369	VALENTINA DAVYDOVA	{"phone": "+70526647683"}
0005433234971	84DD0C	8259 747772	ANASTASIYA SAVELEVA	{"email": "saveleva-anastasiya_071976@postgrespro.ru", "phone": "+70005034084"}
0005433234972	84DD0C	9706 949126	MARIYA MAKSIMOVA	{"email": "m.maksimova1985@postgrespro.ru", "phone": "+70919094772"}
0005433234973	2A2701	2042 528681	ALINA BORISOVA	{"email": "a-borisova_15061977@postgrespro.ru", "phone": "+70701365847"}
0005433234974	215D05	0088 460529	SEMEN SCHERBAKOV	{"email": "s_scherbakov_1952@postgrespro.ru", "phone": "+70820321285"}
0005433234975	215D05	2328 807995	VASILIY MOROZOV	{"phone": "+70924716094"}
0005433234976	CDFDBF	2591 521444	ALLA POLYAKOVA	{"phone": "+70607128978"}
0005433234977	B26488	5678 566640	IGOR PAVLOV	{"phone": "+70288143502"}
0005433234978	B4F031	8722 396727	MARIANNA KULIKOVA	{"email": "m_kulikova.01011983@postgrespro.ru", "phone": "+70169326041"}
0005433234979	6C27DF	2187 925923	LYUBOV VASILEVA	{"email": "vasilevalyubov26011968@postgrespro.ru", "phone": "+70116687293"}
0005433234980	E8FDB9	2894 501279	IGOR PETROV	{"email": "petrov_igor_011975@postgrespro.ru", "phone": "+70761869988"}
0005433234981	B9851A	8488 580073	DMITRIY KUZNECOV	{"email": "dmitriykuznecov-081956@postgrespro.ru", "phone": "+70588336394"}
0005433234982	B9851A	3693 914190	TAMARA VASILEVA	{"phone": "+70265707233"}
0005433234983	A75814	6742 582241	IVAN SCHERBAKOV	{"email": "scherbakov-ivan101977@postgrespro.ru", "phone": "+70653236542"}
0005433234984	EB5E0B	2178 170044	ANNA POTAPOVA	{"phone": "+70099266679"}
0005433234985	D73FC6	7076 716924	ELIZAVETA GERASIMOVA	{"email": "e-gerasimova-01011967@postgrespro.ru", "phone": "+70650317243"}
0005433234986	D73FC6	6339 769070	ZOYA BELOVA	{"email": "belovazoya091969@postgrespro.ru", "phone": "+70842114805"}
0005433234987	C7F0C4	9531 654448	VASILIY VOROBEV	{"phone": "+70969774098"}
0005433234988	9EADE2	5202 825659	SERGEY SMIRNOV	{"phone": "+70613678559"}
0005433234989	9EADE2	9538 010911	ALBERT FEDOTOV	{"email": "fedotov-albert101963@postgrespro.ru", "phone": "+70746186944"}
0005433234990	065215	3319 805543	VIKTOR ILIN	{"phone": "+70513486961"}
0005433234991	49BD91	0479 126217	KSENIYA AKIMOVA	{"phone": "+70117964788"}
0005433234992	AA34F5	0560 007587	ANNA POTAPOVA	{"email": "potapova-anna-1964@postgrespro.ru", "phone": "+70610362101"}
0005433234993	AA34F5	7636 766052	VLADIMIR KUZMIN	{"phone": "+70399298473"}
0005433234994	18259F	2897 634515	ANASTASIYA ZHURAVLEVA	{"email": "zhuravlevaanastasiya.30121978@postgrespro.ru", "phone": "+70624437907"}
0005433234995	7935A1	3751 936582	ALEKSANDR NIKITIN	{"email": "a_nikitin-1970@postgrespro.ru", "phone": "+70179236412"}
0005433234996	56EA2A	1348 318338	OLGA OSIPOVA	{"phone": "+70764721390"}
0005433234997	56EA2A	2579 332810	TAISIYA FADEEVA	{"phone": "+70406999455"}
0005433234998	5C43F0	7856 296305	NADEZHDA ZAKHAROVA	{"phone": "+70794555885"}
0005433234999	5C43F0	7414 823664	VIKTORIYA CHERNOVA	{"email": "chernova.v_1974@postgrespro.ru", "phone": "+70514188449"}
0005433235000	6C5AE6	3591 213943	TATYANA PETROVA	{"email": "tpetrova-31101981@postgrespro.ru", "phone": "+70372397520"}
0005433235001	D4087B	1218 078738	PAVEL PETROV	{"email": "petrov_p.24061965@postgrespro.ru", "phone": "+70542017579"}
0005433235002	836336	2346 457626	IGOR POPOV	{"email": "i-popov_071976@postgrespro.ru", "phone": "+70773237322"}
0005433235003	25083C	0186 272588	IVAN KUZNECOV	{"phone": "+70905476517"}
0005433235004	CB1D1E	4412 670220	VYACHESLAV BONDARENKO	{"phone": "+70762545097"}
0005433235005	C2E9B2	4220 246783	MAKSIM NIKOLAEV	{"email": "nikolaevm-25051969@postgrespro.ru", "phone": "+70838636043"}
0005433235006	34B85F	7727 245233	GALINA OSIPOVA	{"phone": "+70125141408"}
0005433235007	4432ED	8952 256727	OLGA BELOVA	{"email": "olga-belova24121974@postgrespro.ru", "phone": "+70507462795"}
0005433235008	4432ED	0213 490563	GALINA GUSEVA	{"phone": "+70017472862"}
0005433235009	00CD94	3428 258702	NATALYA VLASOVA	{"email": "vlasova.n081973@postgrespro.ru", "phone": "+70807580558"}
0005433235010	00CD94	7083 437947	VLADIMIR MOROZOV	{"phone": "+70195470356"}
0005433235011	5A89D8	4679 499074	VLADIMIR BORISOV	{"email": "v_borisov_27091976@postgrespro.ru", "phone": "+70209164082"}
0005433235012	5A89D8	8998 725943	NATALYA KOVALEVA	{"email": "kovaleva_n_1984@postgrespro.ru", "phone": "+70024709652"}
0005433235013	5A89D8	2524 778844	VIKTOR FILIPPOV	{"phone": "+70317100338"}
0005433235014	9404F6	0610 013463	NINA GRISHINA	{"email": "grishinanina-30011988@postgrespro.ru", "phone": "+70289469384"}
0005433235015	9404F6	2564 725768	VLADIMIR KUDRYASHOV	{"email": "kudryashov_vladimir_15101976@postgrespro.ru", "phone": "+70944808243"}
0005433235016	BDA709	3196 824041	VLADIMIR DAVYDOV	{"email": "vdavydov.011958@postgrespro.ru", "phone": "+70760623509"}
0005433235017	63C52F	8137 854107	KIRILL BARANOV	{"email": "baranov.kirill_09051986@postgrespro.ru", "phone": "+70163883770"}
0005433235018	63C52F	3040 019706	GRIGORIY CHERNOV	{"phone": "+70944008669"}
0005433235019	63C52F	1892 570698	STANISLAV MOISEEV	{"email": "moiseev_stanislav-05011966@postgrespro.ru", "phone": "+70882235879"}
0005433235020	762332	4675 172309	KSENIYA SMIRNOVA	{"phone": "+70298847417"}
0005433235021	762332	9835 727397	SVETLANA MAKAROVA	{"email": "s.makarova1973@postgrespro.ru", "phone": "+70676730092"}
0005433235022	0380D6	8474 670911	NINA STEPANOVA	{"phone": "+70926389682"}
0005433235023	0380D6	3378 354155	SVETLANA FADEEVA	{"phone": "+70210649222"}
0005433235024	AD93D4	6773 127565	VIKTORIYA ANDREEVA	{"email": "viktoriyaandreeva_1963@postgrespro.ru", "phone": "+70994162590"}
0005433235025	AD93D4	3374 299255	SERGEY BONDARENKO	{"phone": "+70239722198"}
0005433235026	CFFEEE	4950 161094	ALEKSEY SOROKIN	{"phone": "+70744855654"}
0005433235027	A84C20	3817 267333	GALINA GORBUNOVA	{"phone": "+70190645208"}
0005433235028	E46014	8732 625554	SVETLANA PETROVA	{"phone": "+70289561738"}
0005433235029	E46014	5275 311439	SVETLANA LOGINOVA	{"email": "loginova_s.06041978@postgrespro.ru", "phone": "+70814638442"}
0005433235030	1A68AA	1977 935594	ANDREY FOMIN	{"phone": "+70767574839"}
0005433235031	1A68AA	1664 008755	TATYANA ZAKHAROVA	{"email": "t.zakharova031974@postgrespro.ru", "phone": "+70691553052"}
0005433235032	841DF3	0667 235529	VALENTINA TIMOFEEVA	{"phone": "+70629181099"}
0005433235033	841DF3	1614 162247	NADEZHDA KUZNECOVA	{"email": "nadezhdakuznecova_08111971@postgrespro.ru", "phone": "+70725460179"}
0005433235034	6665F1	5479 894276	SERGEY BONDARENKO	{"email": "sbondarenko031976@postgrespro.ru", "phone": "+70828488815"}
0005433235035	118BE5	0087 851939	VITALIY BELOV	{"email": "belov.vitaliy21101964@postgrespro.ru", "phone": "+70699590865"}
0005433235036	27BD01	4823 094899	ANNA FEDOROVA	{"email": "a_fedorova_101976@postgrespro.ru", "phone": "+70543471420"}
0005433235037	27BD01	8023 851857	NAIL KUZNECOV	{"email": "n_kuznecov_06041977@postgrespro.ru", "phone": "+70730469234"}
0005433235038	78BBAD	7722 774872	ALENA NIKITINA	{"email": "nikitina.alena1983@postgrespro.ru", "phone": "+70536372259"}
0005433235039	7BFABD	7869 051121	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila_14051965@postgrespro.ru", "phone": "+70242916812"}
0005433235040	7BFABD	4478 000982	SERGEY PAVLOV	{"phone": "+70223524784"}
0005433235041	447CB5	7457 135429	ALEKSEY FOMIN	{"phone": "+70399957124"}
0005433235042	30B3EF	7835 072933	GULNAZ TIMOFEEVA	{"email": "g-timofeeva.1973@postgrespro.ru", "phone": "+70414328339"}
0005433235043	30B3EF	4384 055065	NATALYA MOROZOVA	{"email": "morozovan1978@postgrespro.ru", "phone": "+70874749331"}
0005433235044	9E4CD2	4189 953717	VIKTORIYA IVANOVA	{"email": "ivanova_v071982@postgrespro.ru", "phone": "+70176282842"}
0005433235045	87BA18	0864 773538	ANATOLIY NIKITIN	{"phone": "+70332621326"}
0005433235046	AEAB3F	8607 975524	TATYANA MAKAROVA	{"phone": "+70958907526"}
0005433235047	AEAB3F	2852 167136	NADEZHDA STEPANOVA	{"email": "stepanovan1979@postgrespro.ru", "phone": "+70650160574"}
0005433235048	6C3894	9774 623559	FEDOR MARTYNOV	{"phone": "+70739637616"}
0005433235049	F6DA45	8536 902849	TATYANA LAZAREVA	{"email": "lazareva_t_30091974@postgrespro.ru", "phone": "+70886063116"}
0005433235050	4F208D	6464 674000	OLGA STEPANOVA	{"email": "stepanovao.1982@postgrespro.ru", "phone": "+70057886609"}
0005433235051	AEFF92	7704 479477	SERGEY NIKOLAEV	{"email": "sergey-nikolaev.021983@postgrespro.ru", "phone": "+70647197373"}
0005433235052	780657	7913 346266	MARINA TROFIMOVA	{"email": "trofimova_m-011968@postgrespro.ru", "phone": "+70693763492"}
0005433235053	58B1CB	4588 059787	TIMOFEY ANDREEV	{"email": "andreev.t.03111968@postgrespro.ru", "phone": "+70286907154"}
0005433235054	90DBBD	3570 014099	ANTONINA IVANOVA	{"phone": "+70229220889"}
0005433235055	1CDA0F	0186 397359	OLGA ZOTOVA	{"email": "olga_zotova.16101966@postgrespro.ru", "phone": "+70851616583"}
0005433235056	1CDA0F	7034 620950	ELENA YUDINA	{"email": "elenayudina-1964@postgrespro.ru", "phone": "+70400686777"}
0005433235057	5284B0	4671 402814	SVETLANA GERASIMOVA	{"phone": "+70385531050"}
0005433235058	5284B0	7793 742158	ANDREY DAVYDOV	{"phone": "+70386424480"}
0005433235059	235A31	6076 092336	EVGENIY SEMENOV	{"email": "e-semenov.31081960@postgrespro.ru", "phone": "+70872155695"}
0005433235060	95C23C	6894 409835	YURIY ZAYCEV	{"email": "zaycev_y091972@postgrespro.ru", "phone": "+70771528800"}
0005433235061	007EE9	4210 050280	YURIY GERASIMOV	{"email": "yuriy-gerasimov-1968@postgrespro.ru", "phone": "+70443563574"}
0005433235062	C9783B	0241 602157	OLESYA VASILEVA	{"email": "olesya_vasileva_1966@postgrespro.ru", "phone": "+70918864617"}
0005433235063	C9783B	8417 815384	VERA DAVYDOVA	{"email": "davydovavera_1977@postgrespro.ru", "phone": "+70397465567"}
0005433235064	BFEB40	6046 164937	TATYANA KUZMINA	{"email": "kuzmina.t_1971@postgrespro.ru", "phone": "+70148668132"}
0005433235065	BFEB40	6665 370969	OLGA POPOVA	{"email": "opopova-061967@postgrespro.ru", "phone": "+70522355882"}
0005433235066	241686	1672 901653	ALEKSEY MAKSIMOV	{"email": "alekseymaksimov-011976@postgrespro.ru", "phone": "+70298303034"}
0005433235067	4AE707	4593 551602	VIKTOR IVANOV	{"email": "ivanov.v.081969@postgrespro.ru", "phone": "+70895543432"}
0005433235068	4AE707	6856 105999	IRAIDA YUDINA	{"email": "i-yudina02041976@postgrespro.ru", "phone": "+70300336164"}
0005433235069	0FC8A8	2116 093279	ANATOLIY BORISOV	{"phone": "+70632900950"}
0005433235070	0FC8A8	7924 874122	OLGA PETROVA	{"phone": "+70470367050"}
0005433235071	0FC8A8	8247 027319	ROMAN KUZNECOV	{"email": "rkuznecov03101968@postgrespro.ru", "phone": "+70874914971"}
0005433235072	FF36EA	1965 071735	EVGENIYA FROLOVA	{"phone": "+70030956834"}
0005433235073	6A3157	7144 252699	DARYA BELOVA	{"phone": "+70302447408"}
0005433235074	E9F4AE	8169 726361	MARINA GERASIMOVA	{"phone": "+70830990113"}
0005433235075	AD186A	4418 112501	ZINAIDA MARTYNOVA	{"phone": "+70854128858"}
0005433235076	25228B	3828 450859	OLGA EFIMOVA	{"phone": "+70622005397"}
0005433235077	25228B	0777 633364	YULIYA POTAPOVA	{"email": "potapova_yuliya101969@postgrespro.ru", "phone": "+70392707404"}
0005433235078	7C0E7B	4993 558415	SERGEY SOKOLOV	{"phone": "+70085460166"}
0005433235079	071548	8072 166464	ALEKSANDR FROLOV	{"email": "a.frolov.06041972@postgrespro.ru", "phone": "+70911627185"}
0005433235080	7DCF58	1614 293812	ALEKSEY ANTONOV	{"phone": "+70566434406"}
0005433235081	EDE8EE	1144 099052	NATALIYA KUZNECOVA	{"phone": "+70487369661"}
0005433235082	3DAD0F	7396 205184	EVGENIY MATVEEV	{"phone": "+70394691186"}
0005433235083	3DAD0F	7211 153945	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr.1977@postgrespro.ru", "phone": "+70994586326"}
0005433235084	5FC3F7	9246 267865	ROMAN POPOV	{"email": "popovr-25051971@postgrespro.ru", "phone": "+70409236582"}
0005433235085	5FC3F7	1261 047008	TATYANA STEPANOVA	{"phone": "+70329777574"}
0005433235086	41C547	2516 356425	ALEKSANDR KARPOV	{"email": "karpov_a.121964@postgrespro.ru", "phone": "+70446169196"}
0005433235087	CD4C66	4021 967242	ANISA OVCHINNIKOVA	{"phone": "+70986677757"}
0005433235088	CD4C66	9537 752995	VLADIMIR SOLOVEV	{"phone": "+70683741908"}
0005433235089	E5E101	8306 836066	MARIYA NESTEROVA	{"phone": "+70458828269"}
0005433235090	78A2B1	7274 145662	IVAN SCHERBAKOV	{"phone": "+70744197962"}
0005433235091	78A2B1	7167 481827	RAISA FOMINA	{"phone": "+70528743935"}
0005433235092	78A2B1	5280 642605	ALEKSEY STEPANOV	{"phone": "+70811590330"}
0005433235093	8EBD83	3630 518596	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev1981@postgrespro.ru", "phone": "+70923058606"}
0005433235094	6DC4CC	5026 975058	OLGA ROMANOVA	{"phone": "+70814994976"}
0005433235095	60170D	6318 980495	NADEZHDA KUZMINA	{"email": "n.kuzmina-27121962@postgrespro.ru", "phone": "+70132076224"}
0005433235096	A334E4	0155 205011	ANATOLIY GERASIMOV	{"phone": "+70700812118"}
0005433235097	A334E4	0570 656035	ALEKSANDR FROLOV	{"phone": "+70949854818"}
0005433235098	A334E4	9550 348787	ANASTASIYA KARPOVA	{"email": "karpova.a111971@postgrespro.ru", "phone": "+70440460204"}
0005433235099	A947B5	9988 465196	OLGA ANDREEVA	{"email": "andreeva.o15071979@postgrespro.ru", "phone": "+70738518361"}
0005433235100	7EC783	3900 532651	SANIYA SAVELEVA	{"email": "saveleva-s011993@postgrespro.ru", "phone": "+70574756587"}
0005433235101	D6016C	9295 964482	SVETLANA DMITRIEVA	{"email": "dmitrieva_svetlana1963@postgrespro.ru", "phone": "+70157193385"}
0005433235102	40FFF7	8645 012487	IGOR FILIPPOV	{"email": "filippov.i_1983@postgrespro.ru", "phone": "+70187111327"}
0005433235103	9E4852	1885 215810	ALEKSANDR MELNIKOV	{"email": "melnikova_01051965@postgrespro.ru", "phone": "+70281421754"}
0005433235104	375C0D	5726 906444	VASILIY MAKAROV	{"phone": "+70044547587"}
0005433235105	4E909A	8514 900086	YURIY RODIONOV	{"phone": "+70071727818"}
0005433235106	88B1C1	9557 281208	ANNA KULIKOVA	{"email": "kulikova.a.1973@postgrespro.ru", "phone": "+70410435447"}
0005433235107	88B1C1	8780 008999	ANDREY SERGEEV	{"email": "sergeev.a.04011966@postgrespro.ru", "phone": "+70028124274"}
0005433235108	B1A297	6292 312639	ANDREY TIKHONOV	{"phone": "+70705315339"}
0005433235109	7E23C3	0502 298039	LYUDMILA DMITRIEVA	{"phone": "+70721240441"}
0005433235110	7E23C3	2560 141992	OKSANA NOVIKOVA	{"email": "o_novikova_11031969@postgrespro.ru", "phone": "+70982319202"}
0005433235111	01AFC3	2011 751321	ALEKSANDR FROLOV	{"email": "aleksandrfrolov-22061979@postgrespro.ru", "phone": "+70280205936"}
0005433235112	01AFC3	3149 494201	SVETLANA TARASOVA	{"phone": "+70518952467"}
0005433235113	64BD9D	9836 439941	NIKOLAY IVANOV	{"email": "n.ivanov.091977@postgrespro.ru", "phone": "+70239299611"}
0005433235114	64BD9D	7503 852047	ALEKSANDR TARASOV	{"phone": "+70744161610"}
0005433235115	D30B13	8661 054618	MARIYA PAVLOVA	{"email": "pavlova.mariya-021977@postgrespro.ru", "phone": "+70444008401"}
0005433235116	00885A	3512 674755	MARINA SOKOLOVA	{"email": "msokolova-13061970@postgrespro.ru", "phone": "+70257077829"}
0005433235117	8406E0	1227 606586	SVETLANA ORLOVA	{"phone": "+70317442741"}
0005433235118	E7AA10	5755 813963	EKATERINA ZAKHAROVA	{"phone": "+70528050014"}
0005433235119	E7AA10	5413 016267	EVGENIY NIKOLAEV	{"phone": "+70297365840"}
0005433235120	299851	7517 148336	DMITRIY NAUMOV	{"phone": "+70029217057"}
0005433235121	3653C6	3696 282222	SERGEY SERGEEV	{"phone": "+70703806418"}
0005433235122	EADE18	7341 555856	MARINA IVANOVA	{"email": "ivanova_m29061972@postgrespro.ru", "phone": "+70016368841"}
0005433235123	FA5A92	0288 832651	VALENTINA KUZNECOVA	{"email": "vkuznecova_101967@postgrespro.ru", "phone": "+70961979426"}
0005433235124	254B38	4406 017453	ELENA SEMENOVA	{"phone": "+70289110633"}
0005433235125	CD35E8	6240 323298	VARVARA EGOROVA	{"phone": "+70880304016"}
0005433235126	6072F8	6596 441067	DMITRIY BONDARENKO	{"phone": "+70001913589"}
0005433235127	24669C	8781 862883	VLADIMIR IVANOV	{"email": "vivanov1968@postgrespro.ru", "phone": "+70420504061"}
0005433235128	6E6C17	9338 996079	VALENTINA MOROZOVA	{"email": "valentina.morozova-1970@postgrespro.ru", "phone": "+70337579197"}
0005433235129	6E6C17	1775 963651	MAKSIM BELOV	{"phone": "+70944868874"}
0005433235130	2F42B8	5603 901146	SVETLANA SEMENOVA	{"email": "semenovas_1964@postgrespro.ru", "phone": "+70159269846"}
0005433235131	2F42B8	1380 750963	ALEKSANDR FEDOTOV	{"email": "fedotov_a_1983@postgrespro.ru", "phone": "+70752759952"}
0005433235132	540017	1959 041428	ANDREY ABRAMOV	{"email": "aabramov-011986@postgrespro.ru", "phone": "+70487368312"}
0005433235133	300CF1	7127 825161	MARK DENISOV	{"email": "mark.denisov1975@postgrespro.ru", "phone": "+70687853124"}
0005433235134	300CF1	3559 221211	ANDREY FEDOROV	{"email": "fedorovandrey081984@postgrespro.ru", "phone": "+70020523763"}
0005433235135	E835A2	5066 210892	PAVEL SMIRNOV	{"phone": "+70670042842"}
0005433235136	E835A2	9170 492703	VADIM TIKHONOV	{"phone": "+70878842631"}
0005433235137	D7B076	0617 356932	OLGA BOGDANOVA	{"phone": "+70068417640"}
0005433235138	D7B076	5495 087555	TATYANA KUZMINA	{"email": "kuzminat_041982@postgrespro.ru", "phone": "+70953940060"}
0005433235139	D6D44B	9164 033919	SVETLANA SOKOLOVA	{"phone": "+70822063147"}
0005433235140	44CA07	4083 228395	SERGEY NAZAROV	{"email": "sergey_nazarov-011966@postgrespro.ru", "phone": "+70835343331"}
0005433235141	44CA07	1845 147045	EVGENIYA KOROLEVA	{"phone": "+70947941916"}
0005433235142	FEFD38	5149 837340	IGOR ORLOV	{"email": "orlovigor.1972@postgrespro.ru", "phone": "+70957739752"}
0005433235143	FEFD38	6846 744424	ALEKSEY FILIPPOV	{"email": "alekseyfilippov1970@postgrespro.ru", "phone": "+70491392541"}
0005433235144	F12D3F	5405 644063	GALINA ANDREEVA	{"email": "galinaandreeva1970@postgrespro.ru", "phone": "+70125810390"}
0005433235145	5A1148	3230 867874	SERGEY FOMIN	{"email": "fomin.s_15121966@postgrespro.ru", "phone": "+70183517050"}
0005433235146	D09FDC	8132 899997	NIKOLAY GRIGOREV	{"phone": "+70357755502"}
0005433235147	DB3583	7569 854675	LIDIYA VLASOVA	{"phone": "+70003119416"}
0005433235148	F54A29	6835 963533	DMITRIY POPOV	{"email": "popov-dmitriy29051976@postgrespro.ru", "phone": "+70813995547"}
0005433235149	F54A29	8890 195548	SERGEY PETROV	{"phone": "+70881374987"}
0005433235150	E2EBB6	5063 012512	VLADIMIR PETROV	{"email": "petrovv.111971@postgrespro.ru", "phone": "+70096873533"}
0005433235151	E2EBB6	8680 390197	TATYANA KOMAROVA	{"phone": "+70827585179"}
0005433235152	893CEE	8353 473577	DMITRIY MELNIKOV	{"email": "dmitriy_melnikov-21081966@postgrespro.ru", "phone": "+70633827939"}
0005433235153	BB9FF5	6332 760171	OLGA RYABOVA	{"email": "oryabova.061979@postgrespro.ru", "phone": "+70268556825"}
0005433235154	AC99AC	2867 557158	ELENA PETROVA	{"phone": "+70725453548"}
0005433235155	6656C4	6462 458117	VYACHESLAV SIDOROV	{"email": "sidorov-vyacheslav.031971@postgrespro.ru", "phone": "+70176614341"}
0005433235156	6656C4	7607 300067	SVETLANA ANTONOVA	{"phone": "+70048643974"}
0005433235157	CFB786	8596 927368	TATYANA ZAYCEVA	{"phone": "+70334025673"}
0005433235158	4D9015	2826 203249	FARIDA MELNIKOVA	{"email": "fmelnikova1971@postgrespro.ru", "phone": "+70857175030"}
0005433235159	EB32A1	9055 780633	SVETLANA KUZNECOVA	{"email": "svetlana.kuznecova-1964@postgrespro.ru", "phone": "+70200014355"}
0005433235160	EB32A1	4409 796203	ELENA SOLOVEVA	{"email": "solovevae_111974@postgrespro.ru", "phone": "+70742137602"}
0005433235161	37F1E4	8504 773772	MARIYA MALYSHEVA	{"phone": "+70435069230"}
0005433235162	E0CFED	3381 446713	VIKTOR OSIPOV	{"email": "v_osipov1960@postgrespro.ru", "phone": "+70205280505"}
0005433235163	E0CFED	8944 699180	DENIS FEDOTOV	{"phone": "+70269027519"}
0005433235164	B85646	9478 654696	NATALYA PETROVA	{"email": "n-petrova_041979@postgrespro.ru", "phone": "+70823054013"}
0005433235165	BF8603	1115 387702	IRINA VOLKOVA	{"email": "volkova-irina.06021973@postgrespro.ru", "phone": "+70875733873"}
0005433235166	963728	1165 344108	OKSANA NIKOLAEVA	{"email": "nikolaeva-oksana011973@postgrespro.ru", "phone": "+70390728996"}
0005433235167	963728	1138 522649	BORIS ALEKSEEV	{"email": "alekseev_b-1970@postgrespro.ru", "phone": "+70419741191"}
0005433235168	8485A3	2298 616727	SERGEY KOROLEV	{"email": "skorolev_1972@postgrespro.ru", "phone": "+70502473399"}
0005433235169	EF2359	5246 316667	IGOR NOVIKOV	{"phone": "+70207309442"}
0005433235170	EF2359	8439 295772	ALEKSANDR KUZNECOV	{"phone": "+70602643857"}
0005433235171	EF2359	7370 750091	TATYANA MARTYNOVA	{"email": "t-martynova051968@postgrespro.ru", "phone": "+70952447588"}
0005433235172	4E664B	7525 313613	EVGENIYA NAUMOVA	{"email": "evgeniya-naumova_03051971@postgrespro.ru", "phone": "+70041251407"}
0005433235173	22E66D	3139 372031	TATYANA FILATOVA	{"phone": "+70959183497"}
0005433235174	281EE0	2739 827066	OLESYA YAKOVLEVA	{"phone": "+70512356577"}
0005433235175	0F5FCB	7942 764850	ZINAIDA YUDINA	{"email": "yudina.z081975@postgrespro.ru", "phone": "+70374234518"}
0005433235176	AA0674	3886 036379	TATYANA KOMAROVA	{"phone": "+70578710502"}
0005433235177	AA0674	6727 681140	NADEZHDA TARASOVA	{"email": "tarasova-n1970@postgrespro.ru", "phone": "+70635968217"}
0005433235178	F61CE5	6628 109191	OLGA BELYAEVA	{"phone": "+70238463633"}
0005433235179	F61CE5	7299 835314	DARYA MATVEEVA	{"phone": "+70326259604"}
0005433235180	F61CE5	3333 676193	VYACHESLAV NIKITIN	{"email": "v-nikitin_061980@postgrespro.ru", "phone": "+70410366898"}
0005433235181	8E4CFF	3794 700143	DARYA VLASOVA	{"phone": "+70559514319"}
0005433235182	8E4CFF	3725 025637	IVAN MAKAROV	{"phone": "+70087441836"}
0005433235183	5090E9	9065 231527	VALENTINA KUZNECOVA	{"phone": "+70752440074"}
0005433235184	925103	4414 836088	ALSU SMIRNOVA	{"email": "smirnova_alsu.1974@postgrespro.ru", "phone": "+70802374897"}
0005433235185	F2B5A5	4914 716087	MAKSIM ANDREEV	{"email": "maksim_andreev_1965@postgrespro.ru", "phone": "+70473253123"}
0005433235186	F2B5A5	0243 973442	MIKHAIL FOMIN	{"phone": "+70908879968"}
0005433235187	CFFE7C	9141 723150	NATALYA ORLOVA	{"phone": "+70998480814"}
0005433235188	AC73E6	4607 083162	KONSTANTIN POPOV	{"email": "popov_k.1982@postgrespro.ru", "phone": "+70768622679"}
0005433235189	664874	2537 071507	SERGEY BELOV	{"email": "belov_sergey.13021971@postgrespro.ru", "phone": "+70772068802"}
0005433235190	5F3FDB	6920 771978	VENIAMIN NIKITIN	{"phone": "+70634937606"}
0005433235191	AA80AD	7273 685337	SVETLANA IVANOVA	{"email": "ivanova_svetlana.06041975@postgrespro.ru", "phone": "+70038000040"}
0005433235192	AA80AD	6922 922493	ALEKSANDR VASILEV	{"email": "a-vasilev.061966@postgrespro.ru", "phone": "+70141153101"}
0005433235193	EDEFD1	9507 343777	ANDREY MEDVEDEV	{"phone": "+70616235403"}
0005433235194	EDEFD1	5022 814365	YURIY IVANOV	{"email": "yuriyivanov111974@postgrespro.ru", "phone": "+70295388461"}
0005433235195	EDEFD1	7984 393452	NADEZHDA FOMINA	{"phone": "+70776697643"}
0005433235196	1F7CAB	2571 518324	SERGEY IVANOV	{"phone": "+70978440502"}
0005433235197	1F7CAB	4946 084763	BOGDAN MOROZOV	{"phone": "+70749220724"}
0005433235198	1F7CAB	1700 543178	MARIYA DANILOVA	{"email": "danilovam01071972@postgrespro.ru", "phone": "+70538613012"}
0005433235199	1E9F30	1265 664840	PETR ALEKSANDROV	{"phone": "+70962222503"}
0005433235200	9E2755	9123 685928	LIDIYA MIRONOVA	{"phone": "+70542526472"}
0005433235201	3810A9	9512 436500	MIKHAIL DAVYDOV	{"phone": "+70653947400"}
0005433235202	3810A9	6902 919085	MARIYA ERMAKOVA	{"phone": "+70667109674"}
0005433235203	FF5FC6	3309 963795	ANDREY STEPANOV	{"email": "stepanov.andrey-22101985@postgrespro.ru", "phone": "+70104979002"}
0005433235204	64BA22	4661 262522	DENIS OSIPOV	{"email": "denisosipov_1957@postgrespro.ru", "phone": "+70827677042"}
0005433235205	4F932E	3608 917821	MIKHAIL MAKAROV	{"email": "mmakarov-1971@postgrespro.ru", "phone": "+70585636315"}
0005433235206	CCD00B	2606 627063	SERGEY SOKOLOV	{"phone": "+70167068910"}
0005433235207	500011	5778 677964	NIKOLAY MAKSIMOV	{"phone": "+70732750665"}
0005433235208	500011	6506 028993	NATALYA NESTEROVA	{"email": "natalya-nesterova-25121982@postgrespro.ru", "phone": "+70827934755"}
0005433235209	6E241E	0904 830139	ALEKSEY IVANOV	{"email": "aleksey-ivanov_1974@postgrespro.ru", "phone": "+70933199217"}
0005433235210	5AB061	1450 724364	SVETLANA POLYAKOVA	{"email": "polyakova.s-23011982@postgrespro.ru", "phone": "+70003423941"}
0005433235211	B95CBD	5174 147384	VASILIY KUZMIN	{"phone": "+70153645351"}
0005433235212	D5EC2C	7140 345116	OLEG ANTONOV	{"phone": "+70138369280"}
0005433235213	975F0A	7521 602322	ALEKSANDR KARPOV	{"email": "karpov.a_1969@postgrespro.ru", "phone": "+70644973184"}
0005433235214	7A66E8	4255 023041	VITALIY NAUMOV	{"phone": "+70293188296"}
0005433235215	6B6CC8	8518 883310	LYUDMILA ANTONOVA	{"email": "antonova.l.06061970@postgrespro.ru", "phone": "+70013889386"}
0005433235216	E5A4F4	1230 756945	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrova-elizaveta.1967@postgrespro.ru", "phone": "+70218897807"}
0005433235217	E5A4F4	4697 712462	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov_1971@postgrespro.ru", "phone": "+70345896206"}
0005433235218	863BB7	1338 902068	ILGIZ DAVYDOV	{"phone": "+70771346932"}
0005433235219	7FAF47	0104 180963	VASILIY DENISOV	{"phone": "+70225038841"}
0005433235220	7FAF47	8156 540682	YAROSLAV VOROBEV	{"phone": "+70340643174"}
0005433235221	72AEA3	4356 866337	ANASTASIYA GERASIMOVA	{"phone": "+70731954402"}
0005433235222	03387D	8279 890156	ANNA AFANASEVA	{"email": "afanaseva.a_041966@postgrespro.ru", "phone": "+70877429403"}
0005433235223	975920	4601 378600	SERGEY SOLOVEV	{"email": "s_solovev06091976@postgrespro.ru", "phone": "+70071659890"}
0005433235224	975920	9663 703176	POLINA OVCHINNIKOVA	{"phone": "+70779726350"}
0005433235225	D7C12C	3624 979140	ERIK VASILEV	{"phone": "+70196247337"}
0005433235226	BDE763	2496 264419	SERGEY DENISOV	{"phone": "+70495199961"}
0005433235227	BDE763	2024 512000	NATALYA KARPOVA	{"email": "natalyakarpova-041966@postgrespro.ru", "phone": "+70545801041"}
0005433235228	B477E8	4143 633059	NIKOLAY KAZAKOV	{"phone": "+70030581140"}
0005433235229	83BC8A	6647 711954	SVETLANA VASILEVA	{"email": "vasileva.s.1977@postgrespro.ru", "phone": "+70481851511"}
0005433235230	6B9231	9130 082621	KSENIYA ALEKSANDROVA	{"email": "aleksandrova-k-101970@postgrespro.ru", "phone": "+70727772419"}
0005433235231	F3DF43	1660 967845	LIDIYA FILIPPOVA	{"phone": "+70239746448"}
0005433235232	35CA4D	3112 376418	SVETLANA ZAYCEVA	{"phone": "+70599746191"}
0005433235233	C5A492	2028 088838	ALEKSANDR FROLOV	{"phone": "+70752375659"}
0005433235234	0BEC02	3455 187673	DMITRIY DAVYDOV	{"email": "davydov_d_1978@postgrespro.ru", "phone": "+70967950591"}
0005433235235	42BD33	1363 371796	ALI KUZNECOV	{"phone": "+70514064606"}
0005433235236	4EB90A	3539 212106	ALEKSANDR KISELEV	{"phone": "+70211419759"}
0005433235237	02EB27	3032 556601	FEDOR MIRONOV	{"phone": "+70446333833"}
0005433235238	990FB7	6768 269688	MARIYA ZHUKOVA	{"phone": "+70130919525"}
0005433235239	990FB7	1430 155297	VIKTOR KUDRYASHOV	{"email": "vkudryashov-17081971@postgrespro.ru", "phone": "+70807276256"}
0005433235240	990FB7	5219 416082	ALEKSEY TARASOV	{"email": "tarasov-a.021976@postgrespro.ru", "phone": "+70320064300"}
0005433235241	990FB7	8837 311561	ELENA IVANOVA	{"phone": "+70428339458"}
0005433235242	62DDDC	0789 978432	TAMARA VASILEVA	{"phone": "+70237635008"}
0005433235243	279C68	5984 846744	ALEKSANDR VOLKOV	{"phone": "+70187812626"}
0005433235244	69C68A	7414 287082	MARINA PETROVA	{"email": "marinapetrova.101968@postgrespro.ru", "phone": "+70407604482"}
0005433235245	69C68A	6518 705166	VYACHESLAV TIKHONOV	{"email": "v_tikhonov.081980@postgrespro.ru", "phone": "+70197673182"}
0005433235246	771730	1317 403532	ANDREY DAVYDOV	{"phone": "+70669819661"}
0005433235247	771730	6074 555772	EVGENIY VOROBEV	{"email": "evorobev-011975@postgrespro.ru", "phone": "+70857720938"}
0005433235248	73C80F	8578 355041	STANISLAV GUSEV	{"email": "stanislav_gusev.30011972@postgrespro.ru", "phone": "+70988502286"}
0005433235249	BD567B	4406 085766	DARYA MAKAROVA	{"email": "d_makarova-041975@postgrespro.ru", "phone": "+70018589217"}
0005433235250	55268F	9563 792280	MAKSIM RODIONOV	{"email": "maksim_rodionov1984@postgrespro.ru", "phone": "+70933358238"}
0005433235251	88DD82	5095 095420	VALENTIN STEPANOV	{"phone": "+70651239436"}
0005433235252	0980D9	9572 310656	VALENTINA KUZNECOVA	{"phone": "+70651535848"}
0005433235253	0980D9	6694 709957	EMIL SOLOVEV	{"email": "solovev_emil1978@postgrespro.ru", "phone": "+70534882875"}
0005433235254	836784	2216 156318	IVAN KUZNECOV	{"email": "ivan.kuznecov.121971@postgrespro.ru", "phone": "+70027575273"}
0005433235255	5B8F6C	6970 074329	RIMA MOISEEVA	{"phone": "+70405403715"}
0005433235256	5E6FF5	5003 328478	SERGEY BORISOV	{"phone": "+70517642820"}
0005433235257	5E6FF5	3183 122285	NIKOLAY SOROKIN	{"phone": "+70468209693"}
0005433235258	5E6FF5	8372 041607	NATALYA ORLOVA	{"email": "n-orlova-10021970@postgrespro.ru", "phone": "+70342132741"}
0005433235259	DF0CB0	1111 367784	TATYANA ANDREEVA	{"email": "tandreeva28031970@postgrespro.ru", "phone": "+70413688523"}
0005433235260	A3D456	3985 374466	ELENA NESTEROVA	{"phone": "+70532693437"}
0005433235261	839079	8105 592666	MIKHAIL DAVYDOV	{"phone": "+70378962741"}
0005433235262	3A7E60	2033 066748	SVETLANA KONOVALOVA	{"email": "konovalovasvetlana091968@postgrespro.ru", "phone": "+70223003596"}
0005433235263	D16A7F	7688 283147	RAISA MATVEEVA	{"email": "matveeva-r.1969@postgrespro.ru", "phone": "+70368833330"}
0005433235264	FC2A63	5120 835229	TAMARA LEBEDEVA	{"email": "tamara-lebedeva.081974@postgrespro.ru", "phone": "+70635000375"}
0005433235265	FC2A63	2407 392897	DARYA KOROLEVA	{"email": "koroleva-d101977@postgrespro.ru", "phone": "+70626138190"}
0005433235266	5AC9DD	6690 749954	RIMMA BOGDANOVA	{"email": "bogdanovar011973@postgrespro.ru", "phone": "+70236960916"}
0005433235267	850F54	7282 618624	ANTONINA POTAPOVA	{"phone": "+70378479004"}
0005433235268	17996C	9157 304067	ROMAN FEDOTOV	{"email": "fedotovroman1973@postgrespro.ru", "phone": "+70279873421"}
0005433235269	BE4249	9305 624161	NIKOLAY MOROZOV	{"phone": "+70506708101"}
0005433235270	CD8195	0776 145781	SERGEY EGOROV	{"phone": "+70158909688"}
0005433235271	CD8195	2240 635262	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov-26031963@postgrespro.ru", "phone": "+70642156862"}
0005433235272	C7863D	9118 259351	NATALYA LOGINOVA	{"email": "natalya_loginova_17101970@postgrespro.ru", "phone": "+70457474703"}
0005433235273	C7863D	4424 065298	OLGA KAZAKOVA	{"email": "o-kazakova.01051972@postgrespro.ru", "phone": "+70788642578"}
0005433235274	094940	9943 698864	ALEKSANDRA MOROZOVA	{"phone": "+70791787831"}
0005433235275	094940	5510 611785	STANISLAV KUZMIN	{"phone": "+70192387661"}
0005433235276	D25CEA	0631 220077	TATYANA KARPOVA	{"phone": "+70947838817"}
0005433235277	D25CEA	3993 507935	NINA MALYSHEVA	{"email": "malysheva_nina-1968@postgrespro.ru", "phone": "+70754350122"}
0005433235278	799927	0445 595080	YULIYA ZOTOVA	{"email": "yzotova071969@postgrespro.ru", "phone": "+70364635666"}
0005433235279	324BBE	9992 537789	TATYANA MELNIKOVA	{"email": "tmelnikova.10051953@postgrespro.ru", "phone": "+70137094466"}
0005433235280	3DBE5F	3778 640797	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey_031966@postgrespro.ru", "phone": "+70803597128"}
0005433235281	B21E74	8751 484214	ZOYA TIMOFEEVA	{"email": "zoyatimofeeva1965@postgrespro.ru", "phone": "+70340906050"}
0005433235282	E2ECC7	2081 332829	TATYANA ZAKHAROVA	{"email": "zakharovat-1958@postgrespro.ru", "phone": "+70957557536"}
0005433235283	7C8A70	7510 785977	VLADIMIR BORISOV	{"phone": "+70911197987"}
0005433235284	14089A	2747 657364	FILIPP ZHURAVLEV	{"phone": "+70459895376"}
0005433235285	81E6FD	8877 377039	STANISLAV PETROV	{"phone": "+70542411154"}
0005433235286	81E6FD	8343 208227	MARGARITA YUDINA	{"phone": "+70608565156"}
0005433235287	FAF167	4474 519073	OLGA AFANASEVA	{"phone": "+70907726687"}
0005433235288	FAF167	3907 508302	NIKOLAY NAUMOV	{"email": "n_naumov1970@postgrespro.ru", "phone": "+70805625760"}
0005433235289	FAF167	3820 851648	VLADIMIR FILIPPOV	{"email": "filippov-vladimir_1970@postgrespro.ru", "phone": "+70606398697"}
0005433235290	BD723F	1698 146095	VASILIY NIKITIN	{"email": "vasiliy-nikitin.121973@postgrespro.ru", "phone": "+70750787656"}
0005433235291	A06DAB	6971 376607	ALEKSANDR SCHERBAKOV	{"phone": "+70995841925"}
0005433235292	DDA252	1691 213313	ANASTASIYA ZHURAVLEVA	{"email": "a.zhuravleva.071968@postgrespro.ru", "phone": "+70471272908"}
0005433235293	DED114	6740 702102	NIKOLAY ANTONOV	{"email": "antonov.nikolay031977@postgrespro.ru", "phone": "+70048252693"}
0005433235294	58A4DF	1386 561928	DARINA KOMAROVA	{"email": "darina-komarova07121983@postgrespro.ru", "phone": "+70394929877"}
0005433235295	2863EC	5658 496572	MARIYA MOROZOVA	{"phone": "+70826190932"}
0005433235296	0398E5	2543 247243	VALENTINA SERGEEVA	{"email": "sergeeva.valentina1976@postgrespro.ru", "phone": "+70095915476"}
0005433235297	35EBF2	0612 233301	YURIY IVANOV	{"phone": "+70822769795"}
0005433235298	2746D1	7803 814041	LYUBOV SIDOROVA	{"email": "sidorova.l_1973@postgrespro.ru", "phone": "+70797407769"}
0005433235299	49CA98	3072 534702	SERGEY MIRONOV	{"phone": "+70996277301"}
0005433235300	409162	6487 722837	MARINA SOROKINA	{"email": "m-sorokina1972@postgrespro.ru", "phone": "+70241396118"}
0005433235301	409162	0666 182992	OLGA ZOTOVA	{"phone": "+70395595840"}
0005433235302	AAB0CA	0717 509677	VALENTINA KUZMINA	{"email": "kuzmina-valentina091963@postgrespro.ru", "phone": "+70110115775"}
0005433235303	89F2CE	9144 570681	ARTEM SOKOLOV	{"phone": "+70339977141"}
0005433235304	C0DE9A	2537 033707	NATALYA YAKOVLEVA	{"phone": "+70327852099"}
0005433235305	236D31	0835 650502	GALINA ANDREEVA	{"email": "galinaandreeva-021966@postgrespro.ru", "phone": "+70171035087"}
0005433235306	E23D00	1232 658556	ILYA TIMOFEEV	{"email": "i.timofeev.1963@postgrespro.ru", "phone": "+70515968978"}
0005433235307	012C31	8789 973053	EKATERINA VOLKOVA	{"phone": "+70886502722"}
0005433235308	012C31	8545 706415	ALEKSANDR BORISOV	{"email": "borisova-061978@postgrespro.ru", "phone": "+70674860627"}
0005433235309	638C67	6618 193014	ANNA VOLKOVA	{"phone": "+70543033384"}
0005433235310	638C67	3774 148834	VIKTORIYA MAKSIMOVA	{"phone": "+70488713444"}
0005433235311	FBC06D	2854 552801	OLGA FILIPPOVA	{"email": "filippova-olga_04081966@postgrespro.ru", "phone": "+70085228237"}
0005433235312	FBC06D	5727 094403	DENIS ALEKSANDROV	{"phone": "+70938839482"}
0005433235313	3F27F7	1221 185293	VIKTOR KONOVALOV	{"email": "konovalovv-071978@postgrespro.ru", "phone": "+70737580906"}
0005433235314	3F27F7	4581 059594	VALENTINA MOISEEVA	{"email": "valentina_moiseeva.021967@postgrespro.ru", "phone": "+70985109839"}
0005433235315	CF839A	6580 424762	OLGA PETROVA	{"phone": "+70305748623"}
0005433235316	A899FF	4985 076858	ELENA VASILEVA	{"phone": "+70982016377"}
0005433235317	A899FF	9400 399061	ELENA TARASOVA	{"email": "tarasova_elena021977@postgrespro.ru", "phone": "+70744556554"}
0005433235318	87BAFE	2786 117177	VALENTINA GUSEVA	{"email": "guseva-valentina.1975@postgrespro.ru", "phone": "+70249830467"}
0005433235319	7E0E1A	2867 937167	ANTONINA EGOROVA	{"phone": "+70999660884"}
0005433235320	7E0E1A	3959 725353	PAVEL SOROKIN	{"email": "sorokin.p.1975@postgrespro.ru", "phone": "+70552686726"}
0005433235321	8560F7	0177 445375	IGOR ANDREEV	{"email": "igor.andreev.021974@postgrespro.ru", "phone": "+70502936878"}
0005433235322	8560F7	4473 464887	VLADIMIR NAZAROV	{"phone": "+70407132042"}
0005433235323	8560F7	8943 028154	NADEZHDA IVANOVA	{"email": "ivanovan1978@postgrespro.ru", "phone": "+70515387637"}
0005433235324	570916	0968 534570	PAVEL SMIRNOV	{"email": "p-smirnov_22041967@postgrespro.ru", "phone": "+70913082645"}
0005433235325	CC0AFE	3707 298269	ELVIRA EGOROVA	{"email": "elvira_egorova.1975@postgrespro.ru", "phone": "+70405770600"}
0005433235326	EC0B64	8105 858057	OLGA ANTONOVA	{"phone": "+70767394232"}
0005433235327	A1B276	7902 020094	GALINA VOROBEVA	{"phone": "+70612000379"}
0005433235328	78D3C8	6458 583933	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov-15061975@postgrespro.ru", "phone": "+70442300076"}
0005433235329	FDDBFD	3170 751678	NATALIYA POPOVA	{"phone": "+70540222956"}
0005433235330	CD4104	8063 954539	VIKTOR TARASOV	{"phone": "+70111154536"}
0005433235331	CD4104	6880 808721	ELIZAVETA IVANOVA	{"phone": "+70963870711"}
0005433235332	07559A	3326 982645	YURIY KRASNOV	{"email": "ykrasnov-1974@postgrespro.ru", "phone": "+70660261701"}
0005433235333	A7CDAE	0321 296906	ANATOLIY MAKAROV	{"email": "makarov.anatoliy_121982@postgrespro.ru", "phone": "+70317411822"}
0005433235334	A7CDAE	5009 489835	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr.1967@postgrespro.ru", "phone": "+70713126718"}
0005433235335	79A8CE	8041 370970	DINA ARKHIPOVA	{"email": "arkhipovadina061986@postgrespro.ru", "phone": "+70333497405"}
0005433235336	79A8CE	9886 767880	VIKTOR SMIRNOV	{"email": "smirnov-viktor_081978@postgrespro.ru", "phone": "+70262309167"}
0005433235337	F15E3D	9389 847449	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov-011983@postgrespro.ru", "phone": "+70043231732"}
0005433235338	EBD8BD	8001 745076	KLAVDIYA CHERNOVA	{"phone": "+70753956863"}
0005433235339	EBD8BD	0329 418782	OLGA OSIPOVA	{"phone": "+70433747393"}
0005433235340	6389B2	6678 860744	ANDREY KRASNOV	{"phone": "+70371467178"}
0005433235341	E6E179	7654 783785	ALINA KISELEVA	{"phone": "+70988893173"}
0005433235342	79F44F	5511 181016	TIMOFEY MATVEEV	{"email": "tmatveev_081979@postgrespro.ru", "phone": "+70144855250"}
0005433235343	79F44F	5290 440320	SERGEY DMITRIEV	{"phone": "+70072892615"}
0005433235344	BDC8A8	1818 537747	ULYANA KUDRYASHOVA	{"phone": "+70367234973"}
0005433235345	8B9B48	5915 220045	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova-25061985@postgrespro.ru", "phone": "+70859381118"}
0005433235346	8B9B48	1067 224744	SERGEY POPOV	{"email": "sergey.popov1967@postgrespro.ru", "phone": "+70163016082"}
0005433235347	8C75E6	6004 803351	YANINA STEPANOVA	{"phone": "+70218578391"}
0005433235348	B258EC	4098 115480	IVAN ZAYCEV	{"phone": "+70213101878"}
0005433235349	94A272	8869 413015	MARAT BELOV	{"email": "m.belov_22051973@postgrespro.ru", "phone": "+70281437429"}
0005433235350	94A272	2548 154241	ALMIRA ZAKHAROVA	{"email": "zakharova-almira-1974@postgrespro.ru", "phone": "+70627585358"}
0005433235351	F69E54	4485 578316	NATALYA NIKIFOROVA	{"email": "nikiforova_n_1973@postgrespro.ru", "phone": "+70486613147"}
0005433235352	9AB5D0	3159 752601	ALEKSANDR NOVIKOV	{"phone": "+70496022547"}
0005433235353	EC76B1	1074 937426	YULIYA KOROLEVA	{"phone": "+70596882548"}
0005433235354	B3BC4B	6744 041881	MARIYA TROFIMOVA	{"email": "m_trofimova_1976@postgrespro.ru", "phone": "+70766658882"}
0005433235355	417C93	5269 215354	RAILYA MOISEEVA	{"email": "r_moiseeva121973@postgrespro.ru", "phone": "+70892928960"}
0005433235356	1AEEBA	3958 846665	TATYANA FROLOVA	{"phone": "+70177081298"}
0005433235357	C3B85B	7959 772852	OLGA KOZLOVA	{"email": "kozlova.o.1969@postgrespro.ru", "phone": "+70569857383"}
0005433235358	3D9BE8	9997 592623	IGOR ZAKHAROV	{"phone": "+70880516969"}
0005433235359	3D9BE8	5014 317412	TATYANA SERGEEVA	{"phone": "+70521011405"}
0005433235360	2A72C4	9614 925190	LYUBOV BARANOVA	{"phone": "+70734636364"}
0005433235361	195B44	4818 854412	SABINA KRASNOVA	{"email": "krasnova_sabina-25091971@postgrespro.ru", "phone": "+70859031632"}
0005433235362	C2DAD1	3067 898501	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr_1979@postgrespro.ru", "phone": "+70464811922"}
0005433235363	723FC3	4716 581494	ALEKSEY SERGEEV	{"email": "a-sergeev07041971@postgrespro.ru", "phone": "+70095652992"}
0005433235364	2EAB27	6072 935047	ARTEM IVANOV	{"email": "ivanov-a-30071968@postgrespro.ru", "phone": "+70627467815"}
0005433235365	2EAB27	0299 434782	SERGEY SIDOROV	{"phone": "+70317747470"}
0005433235366	B81E5A	9353 944831	DMITRIY MAKAROV	{"email": "makarov_d.101986@postgrespro.ru", "phone": "+70175601113"}
0005433235367	3E45AF	6718 976658	MIKHAIL MAKAROV	{"phone": "+70453446633"}
0005433235368	53C614	5271 206547	SANIYA PETROVA	{"email": "petrova.saniya.1984@postgrespro.ru", "phone": "+70349062407"}
0005433235369	53C614	2572 199416	NIKOLAY MIKHAYLOV	{"phone": "+70220077461"}
0005433235370	F64680	6312 311010	ALEKSEY RODIONOV	{"email": "a_rodionov-27041978@postgrespro.ru", "phone": "+70106373051"}
0005433235371	8CB3F2	9461 074041	ANASTASIYA KARPOVA	{"phone": "+70306319023"}
0005433235372	8CB3F2	7022 729698	NATALYA ANTONOVA	{"email": "natalya.antonova_13111967@postgrespro.ru", "phone": "+70964925258"}
0005433235373	D0D5DB	7931 163538	IGOR SEMENOV	{"email": "i-semenov121969@postgrespro.ru", "phone": "+70096399533"}
0005433235374	D0D5DB	9876 000884	MARINA ALEKSANDROVA	{"email": "aleksandrova-m-1974@postgrespro.ru", "phone": "+70770417510"}
0005433235375	FD7A1E	8280 449422	NIKITA BORISOV	{"phone": "+70399941375"}
0005433235376	64CB26	6600 536195	YAKOV SMIRNOV	{"phone": "+70530716796"}
0005433235377	2C446E	5860 847583	NADEZHDA EGOROVA	{"email": "egorova_n31121979@postgrespro.ru", "phone": "+70640137835"}
0005433235378	2C446E	3741 779335	VYACHESLAV TIKHONOV	{"email": "tikhonovvyacheslav_1986@postgrespro.ru", "phone": "+70100627690"}
0005433235379	2C446E	0648 062129	LYUBOV DANILOVA	{"email": "danilova_l.121977@postgrespro.ru", "phone": "+70389538343"}
0005433235380	09AF54	5011 558014	VALERIY VOLKOV	{"email": "valeriy.volkov_1983@postgrespro.ru", "phone": "+70957475290"}
0005433235381	9AD3B0	3183 246311	EVGENIY ANTONOV	{"email": "evgeniy_antonov.021976@postgrespro.ru", "phone": "+70674765510"}
0005433235382	9AD3B0	5339 779095	VLADIMIR MIKHAYLOV	{"phone": "+70089649276"}
0005433235383	06A7B5	1420 412185	DMITRIY MIKHAYLOV	{"email": "dmitriymikhaylov1976@postgrespro.ru", "phone": "+70002434726"}
0005433235384	3D6AD0	6700 579168	NADEZHDA ZAYCEVA	{"email": "n-zayceva_1965@postgrespro.ru", "phone": "+70054638990"}
0005433235385	3D6AD0	0645 186721	YULIYA NIKOLAEVA	{"phone": "+70043781186"}
0005433235386	CFF3E9	3826 041907	MARINA KUZNECOVA	{"phone": "+70468122111"}
0005433235387	9E0D8A	0066 966451	VALENTIN GUSEV	{"phone": "+70775527999"}
0005433235388	9E0D8A	2951 404313	SERGEY SOLOVEV	{"email": "sergey_solovev_1964@postgrespro.ru", "phone": "+70079915812"}
0005433235389	F5CC40	5347 228298	GALINA NAZAROVA	{"email": "nazarova_g-1974@postgrespro.ru", "phone": "+70261814004"}
0005433235390	F5CC40	9489 355828	ALEKSEY FROLOV	{"phone": "+70559287528"}
0005433235391	5EFDF2	4211 847950	NATALIYA MAKAROVA	{"email": "nataliya_makarova.07091973@postgrespro.ru", "phone": "+70613387364"}
0005433235392	5EFDF2	2761 767008	SVETLANA MELNIKOVA	{"phone": "+70135080466"}
0005433235393	E85267	8988 073348	PAVEL NIKOLAEV	{"phone": "+70186453343"}
0005433235394	AA6E2A	8564 708419	VALENTINA EGOROVA	{"phone": "+70975099378"}
0005433235395	709700	0481 006000	IRINA MEDVEDEVA	{"phone": "+70949526216"}
0005433235396	67778D	3573 010751	MARIYA KUZMINA	{"phone": "+70117796678"}
0005433235397	08976A	5175 038686	VALENTINA EFREMOVA	{"phone": "+70187119889"}
0005433235398	08976A	7802 895781	NIKOLAY ZAKHAROV	{"email": "nikolay-zakharov1972@postgrespro.ru", "phone": "+70846187315"}
0005433235399	DDCC87	6791 232865	VALERIYA KRASNOVA	{"phone": "+70887409178"}
0005433235400	7EE34D	6049 175035	VIKTORIYA FILIPPOVA	{"phone": "+70604443705"}
0005433235401	847C89	5783 412439	GENNADIY POPOV	{"phone": "+70361506235"}
0005433235402	18CB3D	0331 988720	SERGEY MAKSIMOV	{"email": "smaksimov051974@postgrespro.ru", "phone": "+70307487026"}
0005433235403	534960	5038 182360	NINA DAVYDOVA	{"email": "davydovanina_1965@postgrespro.ru", "phone": "+70448879870"}
0005433235404	9E6DC6	4436 457120	MARIYA ROMANOVA	{"email": "romanova_m-021978@postgrespro.ru", "phone": "+70428985911"}
0005433235405	C78150	0157 955116	VLADIMIR ZHURAVLEV	{"phone": "+70452104997"}
0005433235406	9AC14C	2095 028156	VALERIY DAVYDOV	{"email": "davydovvaleriy-081973@postgrespro.ru", "phone": "+70890781851"}
0005433235407	5A5F88	2676 509876	MAKAR MIKHAYLOV	{"email": "mikhaylovmakar091962@postgrespro.ru", "phone": "+70534583858"}
0005433235408	44B912	9737 881142	NATALYA PETROVA	{"email": "petrova.natalya.1981@postgrespro.ru", "phone": "+70676632788"}
0005433235409	3E2B1F	1341 770112	ALEKSANDR SMIRNOV	{"phone": "+70504682014"}
0005433235410	368B73	1041 149221	VLADIMIR ROMANOV	{"email": "v_romanov02041981@postgrespro.ru", "phone": "+70856230243"}
0005433235411	2F2473	2910 801230	SERGEY KOROLEV	{"email": "sergey_korolev.1962@postgrespro.ru", "phone": "+70033375320"}
0005433235412	5E8BCC	5108 620809	DENIS BELOV	{"phone": "+70640804790"}
0005433235413	10805E	5378 420094	POLINA MASLOVA	{"email": "maslova-p_1973@postgrespro.ru", "phone": "+70890843237"}
0005433235414	10805E	1487 409851	OLGA EFIMOVA	{"phone": "+70769721109"}
0005433235415	C386D6	9132 364738	VALERIYA NIKITINA	{"phone": "+70093726234"}
0005433235416	91A8BC	1275 845253	VIKTOR SMIRNOV	{"phone": "+70552026659"}
0005433235417	91A8BC	2858 054192	DMITRIY KULIKOV	{"email": "kulikovd_27021982@postgrespro.ru", "phone": "+70903615071"}
0005433235418	614460	5454 267004	ANASTASIYA VLASOVA	{"email": "vlasova_anastasiya-1973@postgrespro.ru", "phone": "+70663895609"}
0005433235419	614460	6898 717925	OLESYA ABRAMOVA	{"phone": "+70430186385"}
0005433235420	062938	9899 661841	PAVEL SCHERBAKOV	{"phone": "+70517960028"}
0005433235421	D2F8E8	4165 602651	SERGEY MIKHAYLOV	{"email": "mikhaylov.sergey-1970@postgrespro.ru", "phone": "+70500464977"}
0005433235422	2F6011	5867 829369	POLINA KOROLEVA	{"phone": "+70096045062"}
0005433235423	3BF546	3309 510942	NIKOLAY KUDRYASHOV	{"phone": "+70909212929"}
0005433235424	DB8481	5074 313355	OLEG FEDOROV	{"email": "fedorovo_1987@postgrespro.ru", "phone": "+70184257601"}
0005433235425	DB8481	8009 098908	ILYA BELOV	{"phone": "+70408503951"}
0005433235426	B19BE2	5291 952262	ALINA YAKOVLEVA	{"phone": "+70150608863"}
0005433235427	99CB60	2206 716808	NIKOLAY BELOV	{"phone": "+70451646092"}
0005433235428	99CB60	3769 591576	IRINA NAZAROVA	{"phone": "+70790540377"}
0005433235429	99CB60	3477 535772	NIKOLAY NAZAROV	{"email": "nazarov-nikolay.08041968@postgrespro.ru", "phone": "+70399942291"}
0005433235430	965E30	1934 098385	ALEKSANDR SOLOVEV	{"phone": "+70225772639"}
0005433235431	C07374	2197 086499	ARTEMIY ZAKHAROV	{"email": "zakharov.a_091974@postgrespro.ru", "phone": "+70092267175"}
0005433235432	83C533	2831 365268	MARIYA ORLOVA	{"email": "orlova_m-121978@postgrespro.ru", "phone": "+70517996603"}
0005433235433	83C533	1190 118440	OLGA MAKAROVA	{"phone": "+70899290614"}
0005433235434	B73F3F	8175 412679	MARIYA GERASIMOVA	{"phone": "+70618714101"}
0005433235435	B73F3F	8955 863168	NATALYA MELNIKOVA	{"email": "melnikovan_121973@postgrespro.ru", "phone": "+70994696832"}
0005433235436	B73F3F	7193 844930	MIKHAIL NIKITIN	{"email": "mnikitin_031972@postgrespro.ru", "phone": "+70830541040"}
0005433235437	47E594	2708 524869	ALINA SEMENOVA	{"phone": "+70621280075"}
0005433235438	921EAF	2532 198504	DMITRIY PAVLOV	{"email": "dmitriypavlov-1959@postgrespro.ru", "phone": "+70591893963"}
0005433235439	694AA2	3432 693468	ALEKSANDR KAZAKOV	{"email": "kazakova.071973@postgrespro.ru", "phone": "+70874222553"}
0005433235440	003623	7973 265798	YULIYA POPOVA	{"email": "popovayuliya1969@postgrespro.ru", "phone": "+70323101798"}
0005433235441	003623	9133 712688	NINA MIRONOVA	{"email": "nina_mironova_10091969@postgrespro.ru", "phone": "+70363280636"}
0005433235442	632C4B	0873 138375	VALENTINA VOLKOVA	{"phone": "+70340931877"}
0005433235443	632C4B	1839 871950	YULIYA SOROKINA	{"phone": "+70852148242"}
0005433235444	4F46E8	7567 985970	ANDREY KUZNECOV	{"email": "a-kuznecov_31071966@postgrespro.ru", "phone": "+70011812360"}
0005433235445	0BB4AE	4289 004179	DMITRIY ISAEV	{"phone": "+70949605405"}
0005433235446	0BB4AE	4664 926184	GENNADIY PETROV	{"email": "petrovgennadiy1963@postgrespro.ru", "phone": "+70972051492"}
0005433235447	75C517	9327 828778	IVAN KRASNOV	{"email": "ivan_krasnov06091965@postgrespro.ru", "phone": "+70660069100"}
0005433235448	A1FA07	4720 124653	ILYA ZAKHAROV	{"phone": "+70444131534"}
0005433235449	8A6E33	3809 979867	VASILIY VOLKOV	{"email": "volkovvasiliy_031972@postgrespro.ru", "phone": "+70975802114"}
0005433235450	6BE95D	5820 755721	IVAN AFANASEV	{"phone": "+70243987964"}
0005433235451	2C1090	4002 174282	ELENA AFANASEVA	{"phone": "+70623705930"}
0005433235452	781E40	0568 138911	EKATERINA KOVALEVA	{"email": "kovalevaekaterina_1971@postgrespro.ru", "phone": "+70737074814"}
0005433235453	3C2A80	0105 152881	VLADISLAV VLASOV	{"email": "vladislav_vlasov.17111979@postgrespro.ru", "phone": "+70831801722"}
0005433235454	4AAC43	1122 050031	DARYA IVANOVA	{"email": "ivanova.darya23081969@postgrespro.ru", "phone": "+70873099090"}
0005433235455	4AAC43	0015 980547	ANATOLIY ZAKHAROV	{"phone": "+70972296301"}
0005433235456	9040AA	6229 773125	VLADIMIR TARASOV	{"email": "tarasov_v_021964@postgrespro.ru", "phone": "+70609105249"}
0005433235457	78660E	3070 618169	DMITRIY BORISOV	{"email": "borisov_dmitriy-1973@postgrespro.ru", "phone": "+70783777606"}
0005433235458	309DD2	6309 935756	IGOR VOLKOV	{"email": "volkov.igor.021976@postgrespro.ru", "phone": "+70319299072"}
0005433235459	592FA7	9820 800154	ALEKSEY NIKITIN	{"email": "a.nikitin-28091968@postgrespro.ru", "phone": "+70494971227"}
0005433235460	8346D2	4080 345789	NIKITA CHERNOV	{"phone": "+70715154260"}
0005433235461	8346D2	4004 057079	YURIY OSIPOV	{"email": "osipov_y-041974@postgrespro.ru", "phone": "+70225118358"}
0005433235462	E269BE	0195 142160	OLEG PAVLOV	{"email": "pavlov_o_091967@postgrespro.ru", "phone": "+70663317419"}
0005433235585	07BD46	9536 036552	YURIY VOLKOV	{"phone": "+70242770641"}
0005433235463	5C6FB0	2500 864250	TATYANA LAZAREVA	{"email": "tatyana-lazareva.1967@postgrespro.ru", "phone": "+70633414202"}
0005433235464	5C6FB0	0985 812790	ANDREY SEMENOV	{"phone": "+70792526033"}
0005433235465	180715	3033 729752	EVGENIY FILIPPOV	{"phone": "+70600701453"}
0005433235466	CA62DE	8196 031516	VALENTINA KARPOVA	{"phone": "+70695466555"}
0005433235467	97B5D9	9509 992128	LARISA BORISOVA	{"phone": "+70890205760"}
0005433235468	97B5D9	7448 818514	VERA NIKITINA	{"phone": "+70518968203"}
0005433235469	3735FC	6079 040746	VALENTIN SCHERBAKOV	{"phone": "+70228072575"}
0005433235470	869FC9	5398 597754	IVAN SIDOROV	{"email": "i.sidorov.121961@postgrespro.ru", "phone": "+70643253762"}
0005433235471	5D55E0	2028 749177	ELENA MAKAROVA	{"email": "e.makarova-101977@postgrespro.ru", "phone": "+70756304606"}
0005433235472	5D55E0	9344 361968	MARINA ALEKSEEVA	{"email": "alekseeva-m011975@postgrespro.ru", "phone": "+70829804414"}
0005433235473	3B732B	3411 449887	ELENA KUZMINA	{"email": "e_kuzmina-071970@postgrespro.ru", "phone": "+70246440338"}
0005433235474	C72517	3256 306923	NIKOLAY TIKHONOV	{"email": "n.tikhonov.1980@postgrespro.ru", "phone": "+70374996205"}
0005433235475	09639F	9421 104979	NATALYA MIRONOVA	{"phone": "+70711537748"}
0005433235476	BFB0A0	5205 217280	ARTEM VASILEV	{"email": "a-vasilev.16061971@postgrespro.ru", "phone": "+70870056770"}
0005433235477	1C8052	6099 121099	VIKTOR MIRONOV	{"email": "mironovviktor081970@postgrespro.ru", "phone": "+70056114964"}
0005433235478	D6D0DA	9484 769881	IRINA KUZNECOVA	{"email": "irina_kuznecova1979@postgrespro.ru", "phone": "+70245444518"}
0005433235479	654EC6	3766 124786	GALINA ANDREEVA	{"phone": "+70516769678"}
0005433235480	FBBA92	9716 975114	VALERIY ABRAMOV	{"email": "valeriy.abramov25061962@postgrespro.ru", "phone": "+70561905281"}
0005433235481	B32C1C	8487 221828	NINA KARPOVA	{"email": "karpova-nina-1964@postgrespro.ru", "phone": "+70456062879"}
0005433235482	913D41	4985 831358	VLADIMIR ZAYCEV	{"phone": "+70967157925"}
0005433235483	913D41	8815 883594	SVETLANA TIKHONOVA	{"email": "tikhonova-s.011959@postgrespro.ru", "phone": "+70685018260"}
0005433235484	269A9F	1483 282954	ANDREY OSIPOV	{"email": "osipov_andrey-1969@postgrespro.ru", "phone": "+70753377907"}
0005433235485	269A9F	5535 681821	NATALYA STEPANOVA	{"phone": "+70726656030"}
0005433235486	DF7834	8627 013399	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov081966@postgrespro.ru", "phone": "+70206164537"}
0005433235487	5E3D63	7611 564057	ALEKSANDR KOZLOV	{"phone": "+70343342890"}
0005433235488	5E3D63	2158 283789	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.15121968@postgrespro.ru", "phone": "+70558784742"}
0005433235489	A1860F	9715 171895	GALINA ROMANOVA	{"email": "romanova.g28051968@postgrespro.ru", "phone": "+70334615640"}
0005433235490	745738	8007 551471	IRINA POPOVA	{"email": "irina_popova-15091971@postgrespro.ru", "phone": "+70332124188"}
0005433235491	AD2933	3157 649373	VLADIMIR VASILEV	{"phone": "+70671075967"}
0005433235492	AD2933	8387 237227	YURIY POPOV	{"email": "popov_y1974@postgrespro.ru", "phone": "+70873613532"}
0005433235493	01096D	9822 849977	EVGENIY KISELEV	{"phone": "+70995173257"}
0005433235494	EEF755	0340 751576	ARTEM KOROLEV	{"email": "korolevartem_19061977@postgrespro.ru", "phone": "+70391403323"}
0005433235495	042707	7772 840668	MIKHAIL KOZLOV	{"phone": "+70326492618"}
0005433235496	6C3E05	1194 253492	VLADIMIR PETROV	{"phone": "+70096940274"}
0005433235497	E4E020	4030 604065	ARTEM SERGEEV	{"phone": "+70609789614"}
0005433235498	E4E020	4186 838175	ZINAIDA ANDREEVA	{"phone": "+70064865583"}
0005433235499	3AB710	9523 362728	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova28011983@postgrespro.ru", "phone": "+70248623641"}
0005433235500	D86872	9001 180217	LILIYA MOROZOVA	{"email": "l_morozova1966@postgrespro.ru", "phone": "+70414006668"}
0005433235501	D86872	6829 398957	INESSA GAVRILOVA	{"phone": "+70289758097"}
0005433235502	CA7239	1283 866955	MAKSIM NAUMOV	{"email": "m.naumov_1979@postgrespro.ru", "phone": "+70134436162"}
0005433235503	8E4BB7	0790 264986	PAVEL SCHERBAKOV	{"phone": "+70947033922"}
0005433235504	2870B1	3142 427446	EVGENIYA KUZNECOVA	{"email": "kuznecova.e_26031970@postgrespro.ru", "phone": "+70429524962"}
0005433235505	2870B1	5631 421414	OLGA MEDVEDEVA	{"email": "medvedeva_olga20091977@postgrespro.ru", "phone": "+70367382043"}
0005433235506	4079F7	7787 889038	PETR ZAKHAROV	{"email": "zakharov_p1985@postgrespro.ru", "phone": "+70575695977"}
0005433235507	90318C	5001 818879	EVGENIYA EFIMOVA	{"email": "efimova.e091977@postgrespro.ru", "phone": "+70137496893"}
0005433235508	90318C	3739 289452	VALERIY SIDOROV	{"email": "valeriy.sidorov_011982@postgrespro.ru", "phone": "+70643786755"}
0005433235509	C60518	8615 831314	YULIYA PAVLOVA	{"email": "y-pavlova-071983@postgrespro.ru", "phone": "+70064072686"}
0005433235510	FE8790	2817 997849	SERGEY IVANOV	{"email": "ivanovsergey.1969@postgrespro.ru", "phone": "+70062045235"}
0005433235511	FE8790	7250 932059	NINA GAVRILOVA	{"phone": "+70075209481"}
0005433235512	9122AE	2957 840031	ALEKSANDR KUZNECOV	{"email": "akuznecov_011967@postgrespro.ru", "phone": "+70153034583"}
0005433235513	4DBEAC	6122 529645	OLGA ROMANOVA	{"email": "o_romanova-1971@postgrespro.ru", "phone": "+70320397356"}
0005433235514	A1F1DF	3454 123621	GENNADIY SOLOVEV	{"phone": "+70823680272"}
0005433235515	A1F1DF	3819 489843	NATALYA IVANOVA	{"email": "ivanova-n071970@postgrespro.ru", "phone": "+70015458597"}
0005433235516	4A64F9	3214 353757	ALEKSANDR ABRAMOV	{"phone": "+70472972157"}
0005433235517	4A64F9	7169 203440	ALEKSEY KRASNOV	{"phone": "+70081884256"}
0005433235518	4A64F9	8280 861375	ALEKSANDR MEDVEDEV	{"email": "a-medvedev-1961@postgrespro.ru", "phone": "+70523416468"}
0005433235519	F466A4	0967 113512	ALEKSANDR TARASOV	{"phone": "+70808711917"}
0005433235520	F466A4	7711 757804	ANATOLIY VASILEV	{"email": "vasilev.anatoliy-081973@postgrespro.ru", "phone": "+70600977418"}
0005433235521	3F0047	0129 138952	EVGENIY FEDOTOV	{"email": "e.fedotov031970@postgrespro.ru", "phone": "+70751816537"}
0005433235522	96D22B	8304 111044	IRINA OVCHINNIKOVA	{"email": "irinaovchinnikova-26041979@postgrespro.ru", "phone": "+70494277219"}
0005433235523	6AFEEA	0570 600602	NINA POPOVA	{"email": "popova_n.1965@postgrespro.ru", "phone": "+70614867267"}
0005433235524	6AFEEA	7101 003974	GALINA MEDVEDEVA	{"phone": "+70171083023"}
0005433235525	6AFEEA	0272 114409	PETR MAKAROV	{"phone": "+70686075808"}
0005433235526	251FD1	1084 667716	TATYANA ORLOVA	{"email": "orlovatatyana.08111966@postgrespro.ru", "phone": "+70021541592"}
0005433235527	D9A921	1343 226860	IGOR IVANOV	{"phone": "+70361331831"}
0005433235528	D9A921	2018 983731	SERGEY GERASIMOV	{"phone": "+70653913851"}
0005433235529	D9A921	4498 855977	MARIYA NIKITINA	{"email": "nikitina-mariya.1961@postgrespro.ru", "phone": "+70863398038"}
0005433235530	B71B2D	1858 165039	RAISA POPOVA	{"email": "rpopova-1980@postgrespro.ru", "phone": "+70239380492"}
0005433235531	795093	0291 951333	ALEKSANDR KUZMIN	{"phone": "+70508293888"}
0005433235532	795093	3865 337528	YURIY SMIRNOV	{"email": "smirnov_y-061979@postgrespro.ru", "phone": "+70925314502"}
0005433235533	5C6158	5606 184843	ANDREY CHERNOV	{"phone": "+70360627732"}
0005433235534	5C6158	1348 662874	EVGENIY BORISOV	{"phone": "+70981889220"}
0005433235535	9985C6	8718 754704	YULIYA KISELEVA	{"phone": "+70020594154"}
0005433235536	9985C6	8618 159178	OKSANA NIKITINA	{"phone": "+70127984490"}
0005433235537	DDA94A	7529 127569	EVGENIYA MELNIKOVA	{"email": "evgeniya.melnikova.14111972@postgrespro.ru", "phone": "+70991668660"}
0005433235538	934087	4036 799518	VALERIYA BELYAEVA	{"phone": "+70738800391"}
0005433235539	D7165E	4234 412702	IRINA STEPANOVA	{"phone": "+70288432233"}
0005433235540	AB8834	6413 917909	DMITRIY DMITRIEV	{"email": "dmitriydmitriev_051969@postgrespro.ru", "phone": "+70799424356"}
0005433235541	AB8834	2966 089327	MIKHAIL FOMIN	{"phone": "+70799511276"}
0005433235542	00B7E6	9937 695847	YULIYA KOZLOVA	{"phone": "+70146799196"}
0005433235543	EC7D0A	2108 699348	KIRA KAZAKOVA	{"phone": "+70264041559"}
0005433235544	8E83CF	6290 168040	ALEKSANDR SMIRNOV	{"phone": "+70877557317"}
0005433235545	AB483C	2056 000408	VALENTINA NAZAROVA	{"email": "nazarova-v-1990@postgrespro.ru", "phone": "+70008709609"}
0005433235546	AB483C	8983 081554	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov-071981@postgrespro.ru", "phone": "+70408121484"}
0005433235547	6F9D8F	0602 987486	MARIYA MARTYNOVA	{"email": "m.martynova-22061980@postgrespro.ru", "phone": "+70785979506"}
0005433235548	9D0F2E	6611 759272	LARISA ZAKHAROVA	{"phone": "+70866267122"}
0005433235549	9D0F2E	0029 038343	ALEKSANDR ALEKSEEV	{"phone": "+70783304978"}
0005433235550	09EB55	5681 485085	EGOR PETROV	{"email": "e_petrov-01041972@postgrespro.ru", "phone": "+70281048205"}
0005433235551	6EF600	6325 161870	ALBINA NIKITINA	{"phone": "+70627318136"}
0005433235552	6EF600	6093 180238	SERGEY KAZAKOV	{"email": "kazakovsergey.051992@postgrespro.ru", "phone": "+70374045188"}
0005433235553	6EF600	6109 428499	SERGEY MIRONOV	{"phone": "+70142346624"}
0005433235554	85555C	3760 103439	ELENA LEBEDEVA	{"email": "lebedeva_elena_1977@postgrespro.ru", "phone": "+70558802929"}
0005433235555	2B7936	6765 691993	LIDIYA MAKAROVA	{"email": "makarova-l121970@postgrespro.ru", "phone": "+70074563234"}
0005433235556	5FA18B	7389 900424	ELENA PAVLOVA	{"email": "epavlova_1991@postgrespro.ru", "phone": "+70524567450"}
0005433235557	CF0A8C	1418 371340	SERGEY KUZMIN	{"email": "kuzmin.sergey_051988@postgrespro.ru", "phone": "+70698904051"}
0005433235558	DD2A2B	2647 612740	TATYANA SEMENOVA	{"phone": "+70875185584"}
0005433235559	DD2A2B	1562 835033	OLGA KOZLOVA	{"email": "okozlova1969@postgrespro.ru", "phone": "+70025535123"}
0005433235560	7BB23C	3901 407170	ALEKSANDRA MIRONOVA	{"phone": "+70399404559"}
0005433235561	3AB714	1489 800911	SERGEY GORBUNOV	{"email": "sergeygorbunov-13111972@postgrespro.ru", "phone": "+70019246327"}
0005433235562	436F8E	4318 724346	GENNADIY ISAEV	{"phone": "+70235371246"}
0005433235563	436F8E	7754 510993	LIDIYA MATVEEVA	{"email": "matveeva-lidiya_121972@postgrespro.ru", "phone": "+70617601771"}
0005433235564	E26F01	3167 861079	VERA IVANOVA	{"phone": "+70076154226"}
0005433235565	F43E11	9364 636870	ELENA NIKOLAEVA	{"phone": "+70302934165"}
0005433235566	F43E11	2866 549948	NURIYA ANDREEVA	{"phone": "+70990878396"}
0005433235567	F43E11	9729 517425	ELENA KOROLEVA	{"phone": "+70209671544"}
0005433235568	BBE674	2212 684313	ROMAN KUZNECOV	{"phone": "+70744792128"}
0005433235569	065E54	7250 345810	KIRILL MATVEEV	{"phone": "+70044220142"}
0005433235570	065E54	9225 285271	SERGEY BONDARENKO	{"phone": "+70277150291"}
0005433235571	065E54	2560 006450	MARIYA KRASNOVA	{"email": "m.krasnova_1966@postgrespro.ru", "phone": "+70076965313"}
0005433235572	E23A58	2656 677558	IRINA FILATOVA	{"email": "irina.filatova1966@postgrespro.ru", "phone": "+70915748439"}
0005433235573	E23A58	6817 144929	VIKTORIYA IVANOVA	{"email": "ivanova.v_021966@postgrespro.ru", "phone": "+70882793888"}
0005433235574	E23A58	1664 443241	ALEKSANDR KISELEV	{"phone": "+70263048061"}
0005433235575	D8D976	7465 680250	OLGA DMITRIEVA	{"phone": "+70997512384"}
0005433235576	6AACB4	1593 184506	IRINA DENISOVA	{"email": "i-denisova.08111976@postgrespro.ru", "phone": "+70952106835"}
0005433235577	923386	3391 427195	ALEKSEY CHERNOV	{"phone": "+70967190285"}
0005433235578	1FD11D	4886 206076	TATYANA MOISEEVA	{"phone": "+70824658396"}
0005433235579	FF234A	7855 590455	ANTONINA MAKAROVA	{"phone": "+70330137965"}
0005433235580	FF234A	7607 850687	ANNA STEPANOVA	{"phone": "+70672535888"}
0005433235581	AB9DCF	5770 844442	VIKTORIYA DENISOVA	{"phone": "+70683547404"}
0005433235582	7FE4AA	1143 053259	NIKOLAY ZAYCEV	{"email": "n-zaycev-021961@postgrespro.ru", "phone": "+70944366407"}
0005433235583	712BAE	2382 789223	TIMUR FOMIN	{"phone": "+70318007833"}
0005433235584	EEDD55	7797 030939	ANGELINA KOVALEVA	{"email": "kovaleva-angelina-1974@postgrespro.ru", "phone": "+70500039087"}
0005433235586	07BD46	3344 739169	BORIS ZAKHAROV	{"email": "zakharov.b_01071976@postgrespro.ru", "phone": "+70732267672"}
0005433235587	E7200C	7595 512475	OLGA MEDVEDEVA	{"phone": "+70797657320"}
0005433235588	E7200C	7224 528316	LYUDMILA IVANOVA	{"email": "ivanovalyudmila_1983@postgrespro.ru", "phone": "+70303866843"}
0005433235589	C835C3	2145 632323	IRINA VOROBEVA	{"email": "vorobeva.i021968@postgrespro.ru", "phone": "+70349200863"}
0005433235590	C835C3	7291 710049	VLADIMIR GERASIMOV	{"email": "gerasimov-vladimir1973@postgrespro.ru", "phone": "+70984657780"}
0005433235591	814C3D	4916 687732	VERA PAVLOVA	{"email": "vera_pavlova_071971@postgrespro.ru", "phone": "+70975043690"}
0005433235592	C90678	2774 442268	EGOR PAVLOV	{"email": "egor_pavlov.051975@postgrespro.ru", "phone": "+70711121363"}
0005433235593	792044	9781 589553	RIMMA OSIPOVA	{"email": "rosipova-071983@postgrespro.ru", "phone": "+70090333095"}
0005433235594	A25EB2	6969 942790	VLADIMIR ROMANOV	{"phone": "+70664769687"}
0005433235595	A25EB2	6105 592163	KIRILL YAKOVLEV	{"phone": "+70351500180"}
0005433235596	F9CFD1	4661 538055	TATYANA NAZAROVA	{"phone": "+70756054534"}
0005433235597	849B26	7287 147462	YANA MOISEEVA	{"email": "yana.moiseeva_23021974@postgrespro.ru", "phone": "+70990169498"}
0005433235598	DE003D	4424 856763	TAMARA OSIPOVA	{"phone": "+70335578909"}
0005433235599	C2B0CE	7633 297437	ALEKSANDR GAVRILOV	{"phone": "+70245255863"}
0005433235600	442D83	0187 278818	ALEKSEY NAZAROV	{"email": "nazarov.aleksey-01051974@postgrespro.ru", "phone": "+70285683343"}
0005433235601	724356	9832 862604	ALEKSEY BORISOV	{"phone": "+70017800870"}
0005433235602	CDA6DC	6977 474064	TATYANA KULIKOVA	{"email": "tatyana.kulikova1974@postgrespro.ru", "phone": "+70839701773"}
0005433235603	A60A5D	6402 751378	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy.081978@postgrespro.ru", "phone": "+70049292235"}
0005433235604	A60A5D	4851 829042	OLEG SIDOROV	{"email": "oleg.sidorov-081974@postgrespro.ru", "phone": "+70131707405"}
0005433235605	A60A5D	7911 973972	MARINA PAVLOVA	{"phone": "+70333879261"}
0005433235606	C2370C	0760 263409	ALEKSANDR NOVIKOV	{"phone": "+70530204744"}
0005433235607	C2370C	1952 574518	GEORGIY AFANASEV	{"phone": "+70172330894"}
0005433235608	C2370C	7394 505946	SERGEY KAZAKOV	{"email": "s-kazakov25021975@postgrespro.ru", "phone": "+70711588283"}
0005433235609	0C869B	7086 197805	VITALIY FROLOV	{"phone": "+70977586097"}
0005433235610	BB4D85	1396 704905	VIKTOR YAKOVLEV	{"email": "v.yakovlev-101979@postgrespro.ru", "phone": "+70548692697"}
0005433235611	8598F2	5602 884939	MARIYA ABRAMOVA	{"email": "abramova_mariya_041966@postgrespro.ru", "phone": "+70251659509"}
0005433235612	EE768F	1435 672070	NINA ISAEVA	{"phone": "+70539979362"}
0005433235613	765ADB	3785 996256	ARTEM KUZNECOV	{"phone": "+70785105261"}
0005433235614	6C1415	7271 740897	ALEKSANDRA KUDRYASHOVA	{"email": "kudryashovaaleksandra071976@postgrespro.ru", "phone": "+70405874956"}
0005433235615	E2F15A	8922 164931	RASIM ROMANOV	{"phone": "+70627644688"}
0005433235616	E2F15A	1695 328880	DMITRIY POPOV	{"phone": "+70198750658"}
0005433235617	8428B2	6886 414440	MARIYA GAVRILOVA	{"phone": "+70491893911"}
0005433235618	8428B2	1252 838959	ZINAIDA KUZNECOVA	{"phone": "+70830578229"}
0005433235619	3E5482	5468 118827	ALEKSANDR AFANASEV	{"phone": "+70841348460"}
0005433235620	589AD0	0431 734300	ELENA FEDOROVA	{"email": "elena_fedorova-081963@postgrespro.ru", "phone": "+70676100393"}
0005433235621	589AD0	5632 797588	VERA DENISOVA	{"email": "denisovavera-041967@postgrespro.ru", "phone": "+70833608141"}
0005433235622	452999	4622 566909	SERGEY VASILEV	{"email": "sergey-vasilev_1963@postgrespro.ru", "phone": "+70525158810"}
0005433235623	5BAB2C	1119 854323	VLADISLAV NIKOLAEV	{"email": "vnikolaev.111980@postgrespro.ru", "phone": "+70290045660"}
0005433235624	E7CE0D	6074 208771	STANISLAV ORLOV	{"email": "orlovs-1969@postgrespro.ru", "phone": "+70746161207"}
0005433235625	3A9F3D	7837 220014	ZINAIDA VOLKOVA	{"email": "zinaida_volkova01061960@postgrespro.ru", "phone": "+70104562892"}
0005433235626	598934	9322 507944	VLADIMIR KULIKOV	{"phone": "+70905503151"}
0005433235627	598934	8845 890552	ARTEM GUSEV	{"email": "artem.gusev_1978@postgrespro.ru", "phone": "+70536590787"}
0005433235628	BEA714	2831 242794	EVGENIY SCHERBAKOV	{"phone": "+70434468093"}
0005433235629	BEA714	0168 191280	EVGENIY STEPANOV	{"email": "stepanov_evgeniy-121975@postgrespro.ru", "phone": "+70566467099"}
0005433235630	221C03	3236 709435	NIKOLAY GORBUNOV	{"phone": "+70832461287"}
0005433235631	AFA6BF	5293 281764	IRINA VOROBEVA	{"email": "irina.vorobeva-021975@postgrespro.ru", "phone": "+70482656872"}
0005433235632	7D8863	5145 987333	SERGEY SMIRNOV	{"phone": "+70372594654"}
0005433235633	6BFCA6	1782 058786	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr25121984@postgrespro.ru", "phone": "+70671741462"}
0005433235634	A00B70	9049 129910	SERGEY MARTYNOV	{"phone": "+70455695036"}
0005433235635	5739F1	1833 089903	VALENTINA SOLOVEVA	{"phone": "+70572796434"}
0005433235636	5739F1	9532 368084	AMINA KUZMINA	{"phone": "+70599492358"}
0005433235637	25578A	9225 051660	NIKOLAY EGOROV	{"email": "egorov_nikolay.25101982@postgrespro.ru", "phone": "+70105631859"}
0005433235638	B9E35D	9525 975143	LARISA NIKITINA	{"email": "lnikitina-071978@postgrespro.ru", "phone": "+70965868780"}
0005433235639	B9E35D	4775 992103	NATALYA POPOVA	{"phone": "+70069245987"}
0005433235640	49852C	2870 854403	ALEKSEY SCHERBAKOV	{"email": "aleksey-scherbakov.031974@postgrespro.ru", "phone": "+70177016195"}
0005433235641	49852C	1140 260176	NATALIYA ORLOVA	{"email": "orlovanataliya.101971@postgrespro.ru", "phone": "+70344345717"}
0005433235642	E0A71A	3645 299541	DMITRIY BORISOV	{"phone": "+70018009188"}
0005433235643	EBB873	6687 023484	IRINA MIKHAYLOVA	{"phone": "+70938861479"}
0005433235644	3426C6	1347 310185	ALEKSANDR BONDARENKO	{"phone": "+70364787323"}
0005433235645	0F1B67	5769 621184	NATALYA ISAEVA	{"phone": "+70961352591"}
0005433235646	793545	0408 766445	ANATOLIY MARTYNOV	{"phone": "+70720660217"}
0005433235647	C3410F	7061 368765	REGINA KARPOVA	{"email": "regina.karpova-12021977@postgrespro.ru", "phone": "+70234067568"}
0005433235648	C3410F	0756 384229	OLGA IVANOVA	{"phone": "+70545866321"}
0005433235649	B7D6E1	0517 800089	MARIYA SAVELEVA	{"phone": "+70439903325"}
0005433235650	94CC2C	9060 784612	ALEKSEY ZAYCEV	{"phone": "+70940682624"}
0005433235651	8178F6	4050 363146	OLGA KOROLEVA	{"email": "o-koroleva-24091980@postgrespro.ru", "phone": "+70229448371"}
0005433235652	D3FD8F	1932 877493	MARINA POPOVA	{"email": "m_popova-051965@postgrespro.ru", "phone": "+70186256096"}
0005433235653	D3FD8F	8596 741929	ANDREY POPOV	{"phone": "+70338170094"}
0005433235654	8E1D75	0319 059135	GALINA POPOVA	{"phone": "+70578957005"}
0005433235655	2AA1AE	4818 561396	KSENIYA PAVLOVA	{"email": "kseniyapavlova-051969@postgrespro.ru", "phone": "+70955688019"}
0005433235656	01B776	6245 767278	DMITRIY NAUMOV	{"email": "naumov_d_1960@postgrespro.ru", "phone": "+70856926367"}
0005433235657	386D3E	3509 230627	ALEKSEY KOZLOV	{"email": "a-kozlov_22061963@postgrespro.ru", "phone": "+70746531750"}
0005433235658	386D3E	7025 230674	DENIS NAUMOV	{"phone": "+70601117227"}
0005433235659	8F8427	5827 887051	IVAN PETROV	{"phone": "+70103161237"}
0005433235660	8F8427	8459 993467	DANILA KISELEV	{"phone": "+70583472476"}
0005433235661	7ECEE4	7747 982451	VLADIMIR ORLOV	{"phone": "+70675304363"}
0005433235662	7ECEE4	8702 962305	NIKOLAY KONOVALOV	{"phone": "+70871320483"}
0005433235663	24586F	8010 509496	NINA SCHERBAKOVA	{"email": "nina-scherbakova19121963@postgrespro.ru", "phone": "+70294559179"}
0005433235664	E1C36A	3006 680646	ALEKSEY GUSEV	{"email": "gusev_aleksey-10071980@postgrespro.ru", "phone": "+70091322574"}
0005433235665	E1C36A	7991 883427	YURIY TIKHONOV	{"email": "tikhonov_yuriy_021971@postgrespro.ru", "phone": "+70087644157"}
0005433235666	B2AD61	6215 258725	TATYANA KUZNECOVA	{"phone": "+70442953829"}
0005433235667	1752AF	9631 522437	SVETLANA MIRONOVA	{"phone": "+70175302981"}
0005433235668	345092	0849 535156	FATYMA MEDVEDEVA	{"phone": "+70968813355"}
0005433235669	345092	5423 546504	YAN GAVRILOV	{"email": "gavrilov-y-18121981@postgrespro.ru", "phone": "+70924685177"}
0005433235670	3230AB	7109 065439	ANATOLIY TARASOV	{"phone": "+70561132074"}
0005433235671	965574	0470 281568	SERGEY BONDARENKO	{"phone": "+70810597937"}
0005433235672	965574	3631 555993	LIDIYA KUZNECOVA	{"email": "kuznecova_l-1977@postgrespro.ru", "phone": "+70687462193"}
0005433235673	18E72E	1106 517843	MAKSIM IVANOV	{"phone": "+70729240069"}
0005433235674	F1EBCC	6212 400069	PAVEL FEDOROV	{"phone": "+70398732580"}
0005433235675	37AE5C	5904 914569	ALEKSANDR STEPANOV	{"phone": "+70646739889"}
0005433235676	37AE5C	5396 596163	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov.021967@postgrespro.ru", "phone": "+70486251649"}
0005433235677	4285F0	9611 114082	ALEKSEY MAKAROV	{"email": "aleksey_makarov-22061963@postgrespro.ru", "phone": "+70172695567"}
0005433235678	0406F0	9654 078611	ALEKSANDR FILIPPOV	{"email": "filippov_a091968@postgrespro.ru", "phone": "+70534030595"}
0005433235679	0406F0	2073 840637	NATALYA AKIMOVA	{"email": "akimova.n031971@postgrespro.ru", "phone": "+70647335590"}
0005433235680	84BEE4	1752 433847	LIDIYA AKIMOVA	{"phone": "+70432858994"}
0005433235681	DAA860	1169 021981	ALEKSANDR SAVELEV	{"email": "aleksandr_savelev_061975@postgrespro.ru", "phone": "+70648592009"}
0005433235682	DAA860	5736 363480	OKSANA TITOVA	{"email": "o.titova.17011975@postgrespro.ru", "phone": "+70332215533"}
0005433235683	09E79E	1940 809397	RAISA ABRAMOVA	{"phone": "+70698446386"}
0005433235684	09E79E	8186 261031	ILYA DENISOV	{"email": "ilyadenisov081970@postgrespro.ru", "phone": "+70048958377"}
0005433235685	09E79E	3000 480351	ALEKSEY KUZNECOV	{"phone": "+70989509448"}
0005433235686	A1569D	0018 395833	SERGEY IVANOV	{"email": "sergey_ivanov05081979@postgrespro.ru", "phone": "+70866546704"}
0005433235687	6C8AFF	5787 003919	OKSANA ANTONOVA	{"email": "o-antonova10031979@postgrespro.ru", "phone": "+70241383895"}
0005433235688	9ADFA5	9211 627501	ALEKSANDR ABRAMOV	{"phone": "+70628239459"}
0005433235689	9ADFA5	4166 651733	VIKTOR ILIN	{"email": "ilinviktor_15031973@postgrespro.ru", "phone": "+70353868157"}
0005433235690	11D00F	2386 009713	MIKHAIL EGOROV	{"email": "mikhail-egorov-1955@postgrespro.ru", "phone": "+70364158916"}
0005433235691	7DBAA6	0880 070638	DIANA BORISOVA	{"email": "diana-borisova20051968@postgrespro.ru", "phone": "+70654398289"}
0005433235692	79C12A	9687 521419	NATALYA SIDOROVA	{"phone": "+70281593641"}
0005433235693	79C12A	6459 396885	EVGENIY NAZAROV	{"phone": "+70069721299"}
0005433235694	A2F67A	1091 577259	NADEZHDA FILATOVA	{"email": "nadezhda-filatova-04051983@postgrespro.ru", "phone": "+70581475383"}
0005433235695	A2F67A	9050 401052	DARYA VASILEVA	{"phone": "+70595966170"}
0005433235696	A2F67A	9161 664781	RAILYA VASILEVA	{"email": "vasileva-railya11111969@postgrespro.ru", "phone": "+70173510291"}
0005433235697	4D153B	5938 410561	VLADISLAV IVANOV	{"email": "ivanov-vladislav10071975@postgrespro.ru", "phone": "+70810490759"}
0005433235698	4D153B	3868 429110	ANNA ILINA	{"phone": "+70287615032"}
0005433235699	525F16	1524 456734	VITALIY IVANOV	{"phone": "+70457920203"}
0005433235700	FA0996	5088 249136	NATALIYA YUDINA	{"phone": "+70574677161"}
0005433235701	FA0996	3701 290602	DIANA ALEKSEEVA	{"email": "alekseeva.diana1979@postgrespro.ru", "phone": "+70903644862"}
0005433235702	4D8B2C	4492 921269	NATALYA VASILEVA	{"email": "n.vasileva-1965@postgrespro.ru", "phone": "+70458602794"}
0005433235703	B0702C	7319 583735	IRINA VOLKOVA	{"phone": "+70344466958"}
0005433235704	B0702C	1574 746729	ELENA ORLOVA	{"phone": "+70446516497"}
0005433235705	625CC7	8264 902277	EKATERINA FILATOVA	{"phone": "+70691809780"}
0005433235706	29A3D9	9748 699348	PETR DMITRIEV	{"phone": "+70298852191"}
0005433235707	B08E0A	2474 470745	LIDIYA ANTONOVA	{"email": "l-antonova.04021975@postgrespro.ru", "phone": "+70004755523"}
0005433235708	2E286B	4189 430415	POLINA KONOVALOVA	{"email": "konovalova-p.081975@postgrespro.ru", "phone": "+70585277226"}
0005433235709	BEE3E8	5983 220467	YULIYA FILATOVA	{"phone": "+70973883409"}
0005433235710	0E39D4	4190 010932	ALENA ZHUKOVA	{"email": "zhukova.alena.1958@postgrespro.ru", "phone": "+70635453366"}
0005433235711	155D90	1490 997589	OLGA NESTEROVA	{"email": "olga_nesterova031977@postgrespro.ru", "phone": "+70609523599"}
0005433235712	155D90	9193 340122	SHAMIL POPOV	{"email": "popov.s.1964@postgrespro.ru", "phone": "+70204461026"}
0005433235713	BC79F9	3959 214417	MIKHAIL NAZAROV	{"email": "mikhail-nazarov121972@postgrespro.ru", "phone": "+70060488359"}
0005433235714	BC79F9	6278 226845	NATALYA VLASOVA	{"phone": "+70837246158"}
0005433235715	203FE5	9013 720720	ALEKSEY BELOV	{"phone": "+70276050169"}
0005433235716	D7274C	6679 090417	ALEKSANDR SCHERBAKOV	{"phone": "+70468996886"}
0005433235717	D7274C	4774 591036	NIKOLAY GAVRILOV	{"phone": "+70513109013"}
0005433235718	C501CE	2518 832126	ROMAN ZAYCEV	{"email": "roman.zaycev1969@postgrespro.ru", "phone": "+70160879037"}
0005433235719	2BC232	5452 055928	DARYA KOVALEVA	{"email": "kovaleva.darya-091967@postgrespro.ru", "phone": "+70266457130"}
0005433235720	0C00ED	2726 201297	ANZHELA NESTEROVA	{"phone": "+70941992201"}
0005433235721	0A5219	5300 230396	ELENA MEDVEDEVA	{"email": "e_medvedeva.011971@postgrespro.ru", "phone": "+70102099690"}
0005433235722	D690BA	6624 027761	VASILIY FEDOROV	{"phone": "+70846847556"}
0005433235723	A263FC	9565 407240	ALEKSANDR NIKITIN	{"email": "nikitin_a-12081974@postgrespro.ru", "phone": "+70406412469"}
0005433235724	610379	5908 931375	VLADIMIR NAZAROV	{"email": "nazarovv-20041968@postgrespro.ru", "phone": "+70088900734"}
0005433235725	610379	2741 670223	LIDIYA FEDOROVA	{"email": "fedorovalidiya_17101976@postgrespro.ru", "phone": "+70717163238"}
0005433235726	610379	9049 727247	SEMEN IVANOV	{"email": "ivanov.semen-17021977@postgrespro.ru", "phone": "+70576523653"}
0005433235727	B2D34A	9679 194972	VALERIYA ORLOVA	{"email": "v.orlova12061969@postgrespro.ru", "phone": "+70073934815"}
0005433235728	B70284	8758 965195	NINA KARPOVA	{"email": "karpova.nina-1977@postgrespro.ru", "phone": "+70060213201"}
0005433235729	66AF7C	4898 975886	ALEKSEY ORLOV	{"email": "aleksey-orlov_051974@postgrespro.ru", "phone": "+70007877774"}
0005433235730	1DD136	1219 600472	VLADIMIR KOROLEV	{"email": "korolev-v08051968@postgrespro.ru", "phone": "+70856589804"}
0005433235731	AAB0DA	5864 765823	ALEKSANDR NIKITIN	{"email": "a_nikitin.19121962@postgrespro.ru", "phone": "+70784568268"}
0005433235732	5CC3F0	8359 961120	RAFAIL MATVEEV	{"email": "rafail_matveev_041970@postgrespro.ru", "phone": "+70838616560"}
0005433235733	5CC3F0	4272 419694	IRINA IVANOVA	{"email": "ivanova_irina-22061963@postgrespro.ru", "phone": "+70834370659"}
0005433235734	B37A2F	4664 097562	ALFIYA SOKOLOVA	{"phone": "+70268867406"}
0005433235735	1CCC23	6210 443114	RAISA IVANOVA	{"phone": "+70474182904"}
0005433235736	1CCC23	4050 498011	ANNA LOGINOVA	{"phone": "+70902184570"}
0005433235737	1CCC23	4979 998852	OLEG SERGEEV	{"email": "osergeev-19101975@postgrespro.ru", "phone": "+70661872178"}
0005433235738	269B11	7136 741349	GALINA ILINA	{"email": "ilina.galina-1976@postgrespro.ru", "phone": "+70252993265"}
0005433235739	7F0A37	1380 312426	ELENA KUZNECOVA	{"phone": "+70815755165"}
0005433235740	2EF32E	2867 367397	OLGA MAKAROVA	{"email": "olga-makarova1975@postgrespro.ru", "phone": "+70982354078"}
0005433235741	2EF32E	9771 394788	FAINA KISELEVA	{"phone": "+70143839080"}
0005433235742	2EF32E	6404 489594	MARAT SIDOROV	{"email": "sidorovm1980@postgrespro.ru", "phone": "+70449666919"}
0005433235743	BAFAC2	2186 832583	TAISIYA KOMAROVA	{"email": "t-komarova071965@postgrespro.ru", "phone": "+70820771196"}
0005433235744	D6D8ED	5221 748426	NIKOLAY NOVIKOV	{"phone": "+70101132814"}
0005433235745	D6D8ED	6592 378418	ANASTASIYA ANISIMOVA	{"phone": "+70913332397"}
0005433235746	43781A	0184 106450	ELENA NIKIFOROVA	{"email": "e_nikiforova.111968@postgrespro.ru", "phone": "+70614741235"}
0005433235747	2B61DA	1192 358242	DMITRIY VASILEV	{"phone": "+70289504558"}
0005433235748	48874C	8565 610617	SERGEY STEPANOV	{"phone": "+70115500353"}
0005433235749	81933F	2271 474642	ALEKSANDR ILIN	{"email": "ilin.aleksandr.051967@postgrespro.ru", "phone": "+70943067462"}
0005433235750	249F39	3879 160024	MARINA POTAPOVA	{"phone": "+70465553871"}
0005433235751	11F333	1043 338093	ALEKSANDR PETROV	{"phone": "+70427902932"}
0005433235752	0B51AD	3174 675065	IRINA ANDREEVA	{"email": "i.andreeva14021977@postgrespro.ru", "phone": "+70294519791"}
0005433235753	0B51AD	4843 201253	ROMAN KISELEV	{"email": "kiselevroman_02121965@postgrespro.ru", "phone": "+70212223206"}
0005433235754	5E7281	0143 330929	GALINA MELNIKOVA	{"email": "g-melnikova_091972@postgrespro.ru", "phone": "+70019167774"}
0005433235755	5E7281	8163 137025	EKATERINA SOROKINA	{"email": "sorokina-e07091974@postgrespro.ru", "phone": "+70657098698"}
0005433235756	BCE795	0956 586539	NADEZHDA ANDREEVA	{"phone": "+70994577999"}
0005433235757	4B3377	2733 022908	VERA VOLKOVA	{"email": "vvolkova.071971@postgrespro.ru", "phone": "+70427333332"}
0005433235758	A353D0	6821 157663	SAMIR KUZNECOV	{"phone": "+70078863083"}
0005433235759	D5F928	8087 200714	EVGENIY ANDREEV	{"email": "andreev_e011982@postgrespro.ru", "phone": "+70184444052"}
0005433235760	D5F928	1707 889040	YULIYA MOROZOVA	{"email": "y.morozova_1970@postgrespro.ru", "phone": "+70264068167"}
0005433235761	23041B	2176 826467	ANASTASIYA VOLKOVA	{"phone": "+70016001926"}
0005433235762	23041B	6582 863469	INNA MEDVEDEVA	{"email": "imedvedeva-25041971@postgrespro.ru", "phone": "+70125746948"}
0005433235763	30E131	1414 949205	OLGA POPOVA	{"phone": "+70124195948"}
0005433235764	BEC5B2	7662 308594	VIKTOR STEPANOV	{"phone": "+70737987331"}
0005433235765	BEC5B2	5813 774851	NIKOLAY PETROV	{"phone": "+70997999587"}
0005433235766	BEBE0F	4175 935791	VIKTOR IVANOV	{"phone": "+70796352910"}
0005433235829	8A85FB	9674 645832	TATYANA MIKHAYLOVA	{"phone": "+70744987155"}
0005433235767	BEBE0F	3493 358248	PAVEL NOVIKOV	{"email": "pavel_novikov-121967@postgrespro.ru", "phone": "+70590229494"}
0005433235768	E8DE7E	2810 042202	TATYANA ANISIMOVA	{"email": "tanisimova.041976@postgrespro.ru", "phone": "+70173524400"}
0005433235769	7FE98B	6467 703476	ARKADIY FEDOROV	{"email": "afedorov.06111971@postgrespro.ru", "phone": "+70356260083"}
0005433235770	7FE98B	2901 986316	VASILIY GAVRILOV	{"email": "gavrilov_v061972@postgrespro.ru", "phone": "+70125493623"}
0005433235771	5DE503	7601 215682	YURIY SCHERBAKOV	{"phone": "+70231302723"}
0005433235772	8FF9AB	8883 161737	VALENTIN PAVLOV	{"phone": "+70392739188"}
0005433235773	78D6FC	7559 445051	NADEZHDA ZHUKOVA	{"phone": "+70915531097"}
0005433235774	1FAB00	9186 971483	ELENA KOZLOVA	{"phone": "+70211642019"}
0005433235775	B7539D	6234 268347	ANDREY TIKHONOV	{"phone": "+70379889367"}
0005433235776	2AF728	3842 459091	DARYA EGOROVA	{"email": "d_egorova_01061974@postgrespro.ru", "phone": "+70701772557"}
0005433235777	AD0C37	4150 831132	DMITRIY MATVEEV	{"phone": "+70266613810"}
0005433235778	AD0C37	8841 830810	YULIYA DAVYDOVA	{"email": "davydovayuliya_27071977@postgrespro.ru", "phone": "+70395538364"}
0005433235779	2097C2	1287 382127	EVGENIY KUZNECOV	{"email": "e-kuznecov031976@postgrespro.ru", "phone": "+70492533334"}
0005433235780	2097C2	4240 051291	RUSTAM MAKAROV	{"email": "makarovrustam01081966@postgrespro.ru", "phone": "+70164498394"}
0005433235781	F2DBCF	6253 857065	ANDREY DAVYDOV	{"phone": "+70720857529"}
0005433235782	F2DBCF	3590 277594	SOFIYA VASILEVA	{"email": "svasileva-111965@postgrespro.ru", "phone": "+70588681416"}
0005433235783	2B7F9F	8606 318379	KLAVDIYA ISAEVA	{"email": "isaeva-klavdiya_101972@postgrespro.ru", "phone": "+70949303068"}
0005433235784	2B7F9F	3950 307440	EVGENIY BONDARENKO	{"email": "bondarenko-evgeniy_16101970@postgrespro.ru", "phone": "+70389110820"}
0005433235785	FB50C4	6573 929722	VLADIMIR ANDREEV	{"email": "andreev-v-1969@postgrespro.ru", "phone": "+70067408320"}
0005433235786	8C9F10	9699 330436	ALEKSANDR SCHERBAKOV	{"phone": "+70933644901"}
0005433235787	BAF21B	1046 475247	ELENA TARASOVA	{"email": "tarasova-elena.1969@postgrespro.ru", "phone": "+70675864113"}
0005433235788	17DA50	1434 458412	KSENIYA FEDOROVA	{"phone": "+70646434449"}
0005433235789	17DA50	8944 007937	VLADISLAV VOLKOV	{"email": "v.volkov.23071963@postgrespro.ru", "phone": "+70652825607"}
0005433235790	2F66D8	6308 531483	VASILIY ZAKHAROV	{"phone": "+70184565835"}
0005433235791	BDA229	0241 891202	ANASTASIYA FEDOROVA	{"email": "a_fedorova-1977@postgrespro.ru", "phone": "+70906132215"}
0005433235792	BDA229	8856 114717	EVA DENISOVA	{"phone": "+70401816358"}
0005433235793	B0E043	9995 838245	OLEG ZAKHAROV	{"email": "o_zakharov-091970@postgrespro.ru", "phone": "+70556097823"}
0005433235794	D05F43	0889 985341	EKATERINA YUDINA	{"email": "e_yudina-08031980@postgrespro.ru", "phone": "+70747420793"}
0005433235795	D05F43	1868 630597	IGOR ROMANOV	{"phone": "+70638769142"}
0005433235796	887349	3171 277257	OLGA POPOVA	{"phone": "+70092608525"}
0005433235797	A6A130	3961 211553	NINA TROFIMOVA	{"email": "ntrofimova-14041973@postgrespro.ru", "phone": "+70260890756"}
0005433235798	C5B690	2294 993629	DMITRIY IVANOV	{"phone": "+70538185503"}
0005433235799	64A1BB	3823 159487	MIKHAIL MIRONOV	{"phone": "+70668236723"}
0005433235800	DA4E91	2514 823612	NATALYA FEDOROVA	{"phone": "+70976855715"}
0005433235801	DA4E91	6773 929644	ANVAR MAKAROV	{"phone": "+70705489409"}
0005433235802	42A53C	3585 376398	DENIS ALEKSEEV	{"email": "alekseev_d.011967@postgrespro.ru", "phone": "+70999273496"}
0005433235803	FFAAB0	0457 353604	YULIYA SEMENOVA	{"phone": "+70625833418"}
0005433235804	3BB961	0571 318555	MARIYA IVANOVA	{"phone": "+70689191682"}
0005433235805	B3431E	4510 698024	TATYANA ROMANOVA	{"phone": "+70195842128"}
0005433235806	361DA8	2006 405436	LYUBOV ZAKHAROVA	{"email": "lyubov.zakharova13021966@postgrespro.ru", "phone": "+70803999865"}
0005433235807	4613F3	8375 560761	ALEKSANDR PETROV	{"phone": "+70870875786"}
0005433235808	08724A	2315 037552	SULTAN KUDRYASHOV	{"phone": "+70815601073"}
0005433235809	08724A	7713 043429	GALINA BELOVA	{"email": "belova-g-1970@postgrespro.ru", "phone": "+70805051480"}
0005433235810	2151A1	2162 053919	IRINA LEBEDEVA	{"phone": "+70046373591"}
0005433235811	9FB682	6431 584413	SVETLANA KOROLEVA	{"phone": "+70330051313"}
0005433235812	9FB682	0332 733208	TATYANA KRASNOVA	{"phone": "+70430142139"}
0005433235813	E7E682	4117 186974	EVGENIY KOZLOV	{"email": "kozlov_evgeniy-29031974@postgrespro.ru", "phone": "+70975897895"}
0005433235814	E9FEC9	6547 412348	ALEKSANDR ABRAMOV	{"phone": "+70281128552"}
0005433235815	9F152B	7713 758833	ALEKSEY EGOROV	{"email": "egorov_aleksey_1967@postgrespro.ru", "phone": "+70164739909"}
0005433235816	9F152B	7027 930612	LYUDMILA YUDINA	{"email": "yudina-l13051976@postgrespro.ru", "phone": "+70516739181"}
0005433235817	9F152B	4608 427337	IRINA BORISOVA	{"phone": "+70544242190"}
0005433235818	9F152B	0531 115097	RAISA ISAEVA	{"email": "isaeva_r1970@postgrespro.ru", "phone": "+70888199641"}
0005433235819	19FEA1	0319 782242	MARIYA ANTONOVA	{"phone": "+70714515865"}
0005433235820	7A80D6	9262 215471	ILYA NIKOLAEV	{"phone": "+70910583882"}
0005433235821	9E9EA3	8439 509460	DARYA MOISEEVA	{"phone": "+70453533218"}
0005433235822	DD1F2B	3501 280573	VLADIMIR POPOV	{"phone": "+70244693223"}
0005433235823	DD1F2B	2679 252724	ALEKSANDR KISELEV	{"phone": "+70328944201"}
0005433235824	B756F7	0569 260027	MARIYA BORISOVA	{"email": "m-borisova04101973@postgrespro.ru", "phone": "+70410494961"}
0005433235825	2D8456	5077 718866	DANIIL SOKOLOV	{"phone": "+70145612536"}
0005433235826	2D8456	7496 754185	TATYANA ORLOVA	{"phone": "+70545067593"}
0005433235827	486205	0982 568274	ANNA KRASNOVA	{"email": "krasnova-anna-27101984@postgrespro.ru", "phone": "+70717245583"}
0005433235828	486205	3205 976169	ALEKSANDR GUSEV	{"email": "aleksandr-gusev031981@postgrespro.ru", "phone": "+70536191191"}
0005433235830	8A85FB	5608 063585	YULIYA KUZNECOVA	{"phone": "+70749291810"}
0005433235831	D860B7	8534 203778	SVETLANA MIRONOVA	{"email": "s_mironova071979@postgrespro.ru", "phone": "+70871587599"}
0005433235832	9F977A	1632 358579	DMITRIY KONOVALOV	{"email": "dmitriy.konovalov-051960@postgrespro.ru", "phone": "+70197009429"}
0005433235833	9F977A	5162 475733	VIKTOR SOROKIN	{"phone": "+70907695037"}
0005433235834	2B3B6E	9893 536962	RUSLAN KAZAKOV	{"email": "kazakov-ruslan1974@postgrespro.ru", "phone": "+70277483250"}
0005433235835	74D8D3	3220 558472	SEMEN PAVLOV	{"email": "semen-pavlov_1966@postgrespro.ru", "phone": "+70050371751"}
0005433235836	D2E422	1982 097034	ELENA SERGEEVA	{"phone": "+70159049924"}
0005433235837	9BAADB	3919 988429	ILYA FILIPPOV	{"phone": "+70177888673"}
0005433235838	30874A	2680 586478	YULIYA KULIKOVA	{"phone": "+70487900480"}
0005433235839	47A950	9707 463533	ALEKSANDR SCHERBAKOV	{"phone": "+70261217046"}
0005433235840	357063	3429 340424	VITALIY NOVIKOV	{"email": "v.novikov.28011969@postgrespro.ru", "phone": "+70944105331"}
0005433235841	357063	8131 757288	VALERIY BORISOV	{"phone": "+70159388419"}
0005433235842	28BAAD	8100 061021	OLGA PAVLOVA	{"email": "o.pavlova_28101974@postgrespro.ru", "phone": "+70654022317"}
0005433235843	6BFF6B	1458 599400	MARIYA IVANOVA	{"email": "m-ivanova101971@postgrespro.ru", "phone": "+70662709930"}
0005433235844	4D60B6	9398 407477	GALINA VASILEVA	{"phone": "+70664486892"}
0005433235845	EE9686	4824 573217	ANDREY MAKAROV	{"email": "makarov_a_1972@postgrespro.ru", "phone": "+70588502947"}
0005433235846	BE208A	8416 219951	KONSTANTIN FEDOROV	{"email": "k-fedorov_1974@postgrespro.ru", "phone": "+70959232525"}
0005433235847	92A01E	4799 989602	VADIM FROLOV	{"email": "frolov.vadim10111965@postgrespro.ru", "phone": "+70507095387"}
0005433235848	4DE094	5566 234201	NATALYA ZAKHAROVA	{"email": "zakharova.natalya.26091967@postgrespro.ru", "phone": "+70353472106"}
0005433235849	4DE094	3777 396329	SERGEY TARASOV	{"email": "sergey-tarasov07111965@postgrespro.ru", "phone": "+70650887915"}
0005433235850	4FA5DE	1893 745619	INGA ZAKHAROVA	{"email": "zakharova.i-1986@postgrespro.ru", "phone": "+70183709009"}
0005433235851	81AA41	5059 912068	TATYANA KAZAKOVA	{"phone": "+70536024115"}
0005433235852	9296A0	2170 484496	OLEG SAVELEV	{"email": "oleg.savelev_051978@postgrespro.ru", "phone": "+70646867327"}
0005433235853	FDAAD6	5567 763804	SERGEY NIKITIN	{"phone": "+70349714601"}
0005433235854	E1EFCC	1776 394311	NATALIYA VASILEVA	{"phone": "+70801335957"}
0005433235855	D24DF2	1950 651236	MARIYA YAKOVLEVA	{"phone": "+70021808135"}
0005433235856	422156	0309 860184	PETR SCHERBAKOV	{"phone": "+70304981305"}
0005433235857	422156	3107 575638	ALEKSANDR MATVEEV	{"email": "matveev_a_1968@postgrespro.ru", "phone": "+70397631563"}
0005433235858	422156	8490 794895	ALEKSANDR FEDOROV	{"phone": "+70093262989"}
0005433235859	486134	9778 769519	ALEKSANDR IVANOV	{"phone": "+70234761226"}
0005433235860	486134	6945 545355	NINA MOROZOVA	{"phone": "+70352441364"}
0005433235861	0D5C69	4973 602313	TATYANA BOGDANOVA	{"email": "bogdanova.t111971@postgrespro.ru", "phone": "+70750629573"}
0005433235862	A03DF7	5134 869094	MAKSIM MOISEEV	{"email": "mmoiseev_031974@postgrespro.ru", "phone": "+70125507620"}
0005433235863	B2D7A5	4292 687361	SERGEY ZAKHAROV	{"email": "sergey_zakharov-1970@postgrespro.ru", "phone": "+70823764601"}
0005433235864	77D16C	2247 012116	NINA NIKITINA	{"email": "n_nikitina1970@postgrespro.ru", "phone": "+70495758862"}
0005433235865	863704	5376 034112	ANDREY KOROLEV	{"phone": "+70604073006"}
0005433235866	863704	2462 709242	NIKOLAY NIKOLAEV	{"phone": "+70133557280"}
0005433235867	3D5AF9	9741 563284	DAVID KOROLEV	{"email": "d-korolev.1975@postgrespro.ru", "phone": "+70287321712"}
0005433235868	3D5AF9	0887 026492	LILIYA KOZLOVA	{"phone": "+70344879935"}
0005433235869	BB3B8B	0233 813144	GRIGORIY MAKAROV	{"phone": "+70103409365"}
0005433235870	52D0B3	3820 726051	NATALIYA SERGEEVA	{"email": "nsergeeva_03121980@postgrespro.ru", "phone": "+70617122678"}
0005433235871	23CDEA	3247 181404	MARIYA KOLESNIKOVA	{"phone": "+70654425821"}
0005433235872	23CDEA	1948 336293	GENNADIY RODIONOV	{"email": "rodionov_gennadiy1973@postgrespro.ru", "phone": "+70234033929"}
0005433235873	EBE229	8125 033026	NIKOLAY SMIRNOV	{"phone": "+70541903970"}
0005433235874	36D4DC	7132 258218	VLADIMIR SOKOLOV	{"email": "sokolovvladimir_1970@postgrespro.ru", "phone": "+70156304822"}
0005433235875	3BA8B4	9182 767183	IVAN DAVYDOV	{"email": "davydov_ivan_18111972@postgrespro.ru", "phone": "+70570930672"}
0005433235876	09F130	5112 379722	ILYA DMITRIEV	{"email": "ilya.dmitriev.091967@postgrespro.ru", "phone": "+70920635284"}
0005433235877	B447AD	3959 643225	DMITRIY FROLOV	{"email": "d_frolov_1971@postgrespro.ru", "phone": "+70735275267"}
0005433235878	407137	5918 298795	VERA NAZAROVA	{"email": "nazarova_vera_1973@postgrespro.ru", "phone": "+70782248903"}
0005433235879	D6951E	6465 715426	ANTON BONDARENKO	{"email": "bondarenko-anton1972@postgrespro.ru", "phone": "+70318977565"}
0005433235880	5AA298	3974 888580	VLADISLAV ISAEV	{"phone": "+70299591244"}
0005433235881	5AA298	9677 646564	YULIYA SEMENOVA	{"phone": "+70520776658"}
0005433235882	5C23B9	6629 225918	ANASTASIYA KAZAKOVA	{"email": "a-kazakova-101960@postgrespro.ru", "phone": "+70784737104"}
0005433235883	5C23B9	4015 943383	GALINA ZOTOVA	{"email": "galina.zotova-02021976@postgrespro.ru", "phone": "+70923895614"}
0005433235884	3C6880	9225 491987	LYUBOV ILINA	{"phone": "+70821516743"}
0005433235885	A99764	8466 842916	MARIYA MOROZOVA	{"email": "morozova_mariya1972@postgrespro.ru", "phone": "+70669823810"}
0005433235886	632A79	7862 710950	GALINA MOROZOVA	{"email": "galina.morozova081966@postgrespro.ru", "phone": "+70308953033"}
0005433235887	1C0553	9143 647065	NATALIYA POPOVA	{"email": "npopova.041985@postgrespro.ru", "phone": "+70808236252"}
0005433235888	A7ABBA	8798 057863	OLEG IVANOV	{"phone": "+70276300411"}
0005433235889	85145C	7834 974223	EVGENIY NAZAROV	{"email": "e-nazarov1971@postgrespro.ru", "phone": "+70913383852"}
0005433235890	85145C	0591 513617	NADEZHDA KUZMINA	{"email": "kuzmina.n.28081981@postgrespro.ru", "phone": "+70985709014"}
0005433235891	85145C	6397 449728	ANDREY BORISOV	{"email": "borisova12061966@postgrespro.ru", "phone": "+70953702886"}
0005433235892	D8823A	3606 656735	MARIYA ZAKHAROVA	{"phone": "+70756607331"}
0005433235893	D8823A	8116 303020	ALEKSANDR SCHERBAKOV	{"phone": "+70691250379"}
0005433235894	03B97D	4758 883318	VALERIYA BORISOVA	{"email": "valeriya-borisova.1967@postgrespro.ru", "phone": "+70165314433"}
0005433235895	BD153C	0225 361079	NADEZHDA EGOROVA	{"phone": "+70735822805"}
0005433235896	9017FD	6085 490227	ALEKSANDR KAZAKOV	{"email": "a_kazakov-1970@postgrespro.ru", "phone": "+70403703149"}
0005433235897	9017FD	6257 704492	GALINA ILINA	{"phone": "+70676910589"}
0005433235898	1FFB85	8503 977267	YURIY EGOROV	{"phone": "+70285649632"}
0005433235899	ED68D3	5336 334423	SERGEY PETROV	{"phone": "+70311256191"}
0005433235900	761E34	7631 154604	YULIYA MASLOVA	{"email": "maslova.y_01121970@postgrespro.ru", "phone": "+70020117028"}
0005433235901	761E34	8681 383617	TATYANA RYABOVA	{"email": "ryabovatatyana-04051977@postgrespro.ru", "phone": "+70508075191"}
0005433235902	7B6972	6962 716289	NADEZHDA DENISOVA	{"email": "denisova.n.011958@postgrespro.ru", "phone": "+70241969202"}
0005433235903	7B6972	7202 103163	VERA FOMINA	{"email": "v_fomina1964@postgrespro.ru", "phone": "+70971696904"}
0005433235904	7B6972	6358 491637	ALENA MAKSIMOVA	{"email": "maksimova.a17011969@postgrespro.ru", "phone": "+70793925259"}
0005433235905	846B30	2813 790804	POLINA MIKHAYLOVA	{"email": "pmikhaylova-1970@postgrespro.ru", "phone": "+70223121487"}
0005433235906	3C2109	0246 123143	SERGEY IVANOV	{"email": "sergey-ivanov19021983@postgrespro.ru", "phone": "+70079500195"}
0005433235907	33A36B	5725 316967	TATYANA ALEKSANDROVA	{"phone": "+70032093532"}
0005433235908	BE19D2	5452 491149	LIDIYA BORISOVA	{"email": "borisovalidiya1975@postgrespro.ru", "phone": "+70498933424"}
0005433235909	EE76A8	7639 475984	NADEZHDA KOZLOVA	{"phone": "+70218288063"}
0005433235910	C75A32	5088 545408	SERGEY IVANOV	{"phone": "+70057111200"}
0005433235911	666C97	8276 861733	TATYANA KOROLEVA	{"phone": "+70997112480"}
0005433235912	6EDF10	0070 979494	SERGEY NAZAROV	{"email": "nazarov_s.021982@postgrespro.ru", "phone": "+70161398787"}
0005433235913	17FE52	9570 188093	SERGEY NAUMOV	{"email": "naumov.sergey-101969@postgrespro.ru", "phone": "+70830287495"}
0005433235914	17FE52	3374 091621	RINAT KISELEV	{"phone": "+70247264986"}
0005433235915	17FE52	7267 466994	LARISA MASLOVA	{"phone": "+70452524661"}
0005433235916	E5690D	4152 059500	NINA ALEKSANDROVA	{"email": "aleksandrovanina.121965@postgrespro.ru", "phone": "+70048454957"}
0005433235917	F92967	2280 183585	ANNA TROFIMOVA	{"email": "trofimovaa.28071961@postgrespro.ru", "phone": "+70127723458"}
0005433235918	707A31	9923 758922	KSENIYA NAUMOVA	{"phone": "+70342247842"}
0005433235919	707A31	2876 927701	NIKOLAY CHERNOV	{"phone": "+70907283026"}
0005433235920	4F9802	1467 923978	ANNA ZHURAVLEVA	{"email": "zhuravleva.anna-1973@postgrespro.ru", "phone": "+70239979675"}
0005433235921	78D4B0	3367 635523	NINA GAVRILOVA	{"email": "nina-gavrilova-1969@postgrespro.ru", "phone": "+70667398825"}
0005433235922	78D4B0	9126 903206	MAKSIM POPOV	{"phone": "+70755948367"}
0005433235923	09C202	8182 026358	OLGA ALEKSANDROVA	{"email": "olga-aleksandrova061974@postgrespro.ru", "phone": "+70643000166"}
0005433235924	DBA612	8005 852256	ALEKSANDR OSIPOV	{"email": "a_osipov1978@postgrespro.ru", "phone": "+70333411727"}
0005433235925	DFE8ED	3016 627421	VYACHESLAV KUDRYASHOV	{"email": "kudryashov-v_1979@postgrespro.ru", "phone": "+70809555794"}
0005433235926	A0EBB2	0470 450810	TATYANA LAZAREVA	{"email": "lazareva_tatyana.1967@postgrespro.ru", "phone": "+70747396139"}
0005433235927	182985	1560 810571	ARTEM ZAYCEV	{"email": "zaycev-artem_1972@postgrespro.ru", "phone": "+70825452523"}
0005433235928	182985	3767 584447	TATYANA FEDOROVA	{"phone": "+70537114368"}
0005433235929	FBDBAE	1273 347973	ALEKSANDR OSIPOV	{"phone": "+70471562807"}
0005433235930	C54851	4697 680880	SERGEY IVANOV	{"phone": "+70547337756"}
0005433235931	03C5D0	4142 073907	LARISA EGOROVA	{"email": "larisa-egorova_091966@postgrespro.ru", "phone": "+70916079980"}
0005433235932	71F6D4	6576 971057	ALEKSANDR VASILEV	{"phone": "+70988552033"}
0005433235933	71F6D4	6829 515477	TAMARA GUSEVA	{"phone": "+70318815121"}
0005433235934	3D0482	4854 514199	ALEKSANDR SOROKIN	{"phone": "+70165813232"}
0005433235935	3EAC13	7896 336358	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir_1975@postgrespro.ru", "phone": "+70677358710"}
0005433235936	53DBE3	5230 730232	GENNADIY ORLOV	{"email": "orlov-g-081974@postgrespro.ru", "phone": "+70007338499"}
0005433235937	1EBDD5	7338 649039	LYUBOV KULIKOVA	{"email": "lyubov-kulikova.021958@postgrespro.ru", "phone": "+70941531165"}
0005433235938	38B2A3	1133 950755	PAVEL TARASOV	{"phone": "+70288046802"}
0005433235939	38B2A3	2012 194703	NATALYA ZAKHAROVA	{"email": "n-zakharova-031975@postgrespro.ru", "phone": "+70799987960"}
0005433235940	38B2A3	7670 623726	ALEKSEY CHERNOV	{"email": "chernov_aleksey_061983@postgrespro.ru", "phone": "+70242778113"}
0005433235941	97F9A5	5301 188717	NATALYA BELOVA	{"email": "natalya.belova.09101981@postgrespro.ru", "phone": "+70985871377"}
0005433235942	97F9A5	4472 789855	ALEKSANDR ISAEV	{"phone": "+70022080968"}
0005433235943	1F65C0	0348 032372	IGOR GAVRILOV	{"email": "igor.gavrilov.091965@postgrespro.ru", "phone": "+70504595261"}
0005433235944	C41FD6	1821 711842	ANASTASIYA LEBEDEVA	{"phone": "+70549537418"}
0005433235945	457E12	7076 890124	GENNADIY MATVEEV	{"email": "matveev_gennadiy011958@postgrespro.ru", "phone": "+70127909972"}
0005433235946	C679C7	2382 342239	EVELINA NIKOLAEVA	{"email": "nikolaevaevelina_061975@postgrespro.ru", "phone": "+70121144109"}
0005433235947	64E7FD	9529 028670	SVETLANA ARKHIPOVA	{"email": "arkhipova_s071963@postgrespro.ru", "phone": "+70924094689"}
0005433235948	B4E638	8877 299484	TATYANA VOLKOVA	{"phone": "+70060999581"}
0005433235949	D83573	5948 018113	ALEKSANDR BORISOV	{"email": "borisova091965@postgrespro.ru", "phone": "+70884410074"}
0005433235950	697458	4759 399525	VASILIY VOLKOV	{"phone": "+70162230500"}
0005433235951	683624	2517 704237	KRISTINA ANDREEVA	{"email": "k_andreeva.1973@postgrespro.ru", "phone": "+70736814732"}
0005433235952	683624	7295 087806	ALEKSEY KOZLOV	{"phone": "+70526452579"}
0005433235953	992FBB	1082 623170	ELENA MIKHAYLOVA	{"phone": "+70321769660"}
0005433235954	992FBB	6505 625818	EGOR SCHERBAKOV	{"email": "e_scherbakov-01071973@postgrespro.ru", "phone": "+70590318558"}
0005433235955	B6B566	6636 222023	VIKTORIYA KAZAKOVA	{"email": "viktoriya.kazakova.22121976@postgrespro.ru", "phone": "+70086586470"}
0005433235956	C8F786	4398 249342	EDUARD OSIPOV	{"email": "osipoveduard.111971@postgrespro.ru", "phone": "+70596626866"}
0005433235957	E1C9E6	4452 843129	GALINA ERMAKOVA	{"phone": "+70673730525"}
0005433235958	E1C9E6	2249 474103	KONSTANTIN IVANOV	{"email": "ivanov_k1974@postgrespro.ru", "phone": "+70185807427"}
0005433235959	7B7141	7679 908537	MILENA GUSEVA	{"email": "gusevam18011973@postgrespro.ru", "phone": "+70466927880"}
0005433235960	7B7141	9678 161509	OLESYA KULIKOVA	{"phone": "+70928419206"}
0005433235961	7B7141	0915 500746	ALEKSANDRA MALYSHEVA	{"phone": "+70107092028"}
0005433235962	8D3043	2279 505003	LIDIYA MIRONOVA	{"email": "mironova_lidiya24021975@postgrespro.ru", "phone": "+70722330140"}
0005433235963	A0A49B	7756 922010	VIKTOR SOROKIN	{"phone": "+70858312446"}
0005433235964	A0A49B	1180 193407	IRINA SEMENOVA	{"phone": "+70707384554"}
0005433235965	7AEDDB	1316 624435	YURIY ROMANOV	{"email": "yuriy.romanov.01071979@postgrespro.ru", "phone": "+70837073018"}
0005433235966	BF7FBA	1300 292964	RODION BONDARENKO	{"email": "bondarenko.r.1960@postgrespro.ru", "phone": "+70855029493"}
0005433235967	A46725	0994 318575	NATALYA KOROLEVA	{"email": "koroleva_natalya.051967@postgrespro.ru", "phone": "+70973606666"}
0005433235968	2A2CB4	9221 733407	VIKTOR FEDOTOV	{"phone": "+70685128707"}
0005433235969	4896DB	5769 832663	MARIYA TROFIMOVA	{"email": "mariya.trofimova-05051972@postgrespro.ru", "phone": "+70517678451"}
0005433235970	4896DB	6023 030564	ALEKSEY ANDREEV	{"email": "andreev-a_24011967@postgrespro.ru", "phone": "+70279461059"}
0005433235971	9DB5C8	2053 158939	ALEKSANDR DENISOV	{"phone": "+70585087561"}
0005433235972	B6D58D	5134 921162	IRINA KUDRYASHOVA	{"phone": "+70270310643"}
0005433235973	14E146	9407 134693	SERGEY AFANASEV	{"email": "afanasevs-29051969@postgrespro.ru", "phone": "+70164808491"}
0005433235974	F76549	8117 812480	EKATERINA KUZMINA	{"email": "ekaterina-kuzmina_12081971@postgrespro.ru", "phone": "+70662588326"}
0005433235975	CBC223	7611 530077	RAMIL MIRONOV	{"phone": "+70710769457"}
0005433235976	9CDC12	3221 991083	VERA SERGEEVA	{"email": "verasergeeva.06051973@postgrespro.ru", "phone": "+70730060808"}
0005433235977	9CDC12	8738 601312	ALEKSANDR NAZAROV	{"phone": "+70015029633"}
0005433235978	B246DD	1897 794601	TAKHIR VASILEV	{"phone": "+70567390659"}
0005433235979	B246DD	5341 319719	SERGEY KRASNOV	{"email": "sergeykrasnov-28071975@postgrespro.ru", "phone": "+70436178911"}
0005433235980	DECF2B	3404 705525	SERGEY FILIPPOV	{"phone": "+70854590667"}
0005433235981	1D8730	3005 618029	ELENA PAVLOVA	{"email": "e.pavlova101980@postgrespro.ru", "phone": "+70002261473"}
0005433235982	1D8730	8706 805161	SERGEY NAUMOV	{"email": "sergey_naumov_061977@postgrespro.ru", "phone": "+70341847180"}
0005433235983	2CD645	3623 151405	SERGEY VLASOV	{"email": "s-vlasov.20051971@postgrespro.ru", "phone": "+70858605729"}
0005433235984	6AB443	4445 669988	ALEKSEY KONOVALOV	{"email": "aleksey-konovalov12121963@postgrespro.ru", "phone": "+70790347946"}
0005433235985	302B22	3038 488486	ALBINA TIMOFEEVA	{"phone": "+70004335582"}
0005433235986	E559A2	2883 884998	YULIYA SOKOLOVA	{"phone": "+70621711346"}
0005433235987	E559A2	1434 162704	ELENA EGOROVA	{"phone": "+70876042588"}
0005433235988	765633	8103 600306	DMITRIY ILIN	{"email": "ilin.d-041979@postgrespro.ru", "phone": "+70049012401"}
0005433235989	765633	0309 441665	IRINA NAUMOVA	{"email": "naumova.irina-12011979@postgrespro.ru", "phone": "+70619528127"}
0005433235990	C1F449	4295 505355	DMITRIY ZAKHAROV	{"email": "d-zakharov_111976@postgrespro.ru", "phone": "+70524336449"}
0005433235991	29A375	6122 080301	FEDOR BORISOV	{"email": "borisovfedor_08091964@postgrespro.ru", "phone": "+70046897455"}
0005433235992	29A375	7864 933941	VALERIY KAZAKOV	{"phone": "+70509025207"}
0005433235993	29A375	8652 581557	TATYANA PAVLOVA	{"email": "pavlova_tatyana-041985@postgrespro.ru", "phone": "+70675943213"}
0005433235994	24F646	7334 992020	VIKTORIYA TROFIMOVA	{"email": "v-trofimova_1970@postgrespro.ru", "phone": "+70319573183"}
0005433235995	24F646	8869 332120	ALEKSANDR MAKSIMOV	{"email": "amaksimov_06051963@postgrespro.ru", "phone": "+70465937109"}
0005433235996	1D29B2	5855 306629	ALEKSANDR FROLOV	{"phone": "+70572608659"}
0005433235997	1D29B2	5949 787286	PETR ABRAMOV	{"phone": "+70177921012"}
0005433235998	9BD16B	4430 284347	NATALYA ZAYCEVA	{"email": "zayceva_natalya-23011961@postgrespro.ru", "phone": "+70473346433"}
0005433235999	6B7123	2786 008804	ELENA MAKAROVA	{"phone": "+70258057661"}
0005433236000	8972D3	2299 760522	KONSTANTIN IVANOV	{"phone": "+70450267956"}
0005433236001	A1536E	3247 068814	ALEKSANDRA NAZAROVA	{"phone": "+70396959342"}
0005433236002	B59AA4	0669 445466	VERONIKA ALEKSANDROVA	{"email": "aleksandrova.v.1973@postgrespro.ru", "phone": "+70163365366"}
0005433236003	B59AA4	8151 751517	ALEKSANDR NOVIKOV	{"phone": "+70220929663"}
0005433236004	DEE66C	2237 188877	GENNADIY SHEVCHENKO	{"phone": "+70924940022"}
0005433236005	6D96A4	0507 224884	ELENA MEDVEDEVA	{"phone": "+70094395255"}
0005433236006	A0E62F	2495 917200	OKSANA ANTONOVA	{"email": "antonova-oksana-30091976@postgrespro.ru", "phone": "+70430597940"}
0005433236007	1D5DDF	1623 124140	ALEKSANDR KONOVALOV	{"phone": "+70840449352"}
0005433236008	45D45F	7243 083981	LYUDMILA FILIPPOVA	{"email": "filippova-lyudmila.031971@postgrespro.ru", "phone": "+70742398888"}
0005433236009	BC58A3	9668 893922	ALEKSANDR ABRAMOV	{"email": "abramovaleksandr-1969@postgrespro.ru", "phone": "+70301768751"}
0005433236010	C85584	7788 217077	IRINA BELOVA	{"phone": "+70494135596"}
0005433236011	C85584	7094 348227	NATALYA PETROVA	{"phone": "+70449229638"}
0005433236012	4AB65A	5762 544347	TAMARA ISAEVA	{"phone": "+70551489560"}
0005433236013	4AB65A	1256 336219	NIKOLAY MAKAROV	{"email": "makarov_n10051962@postgrespro.ru", "phone": "+70891545216"}
0005433236014	4AB65A	4443 066518	SERGEY KOROLEV	{"email": "skorolev.1983@postgrespro.ru", "phone": "+70790545862"}
0005433236015	2AE439	6927 864295	BORIS KAZAKOV	{"email": "bkazakov.081971@postgrespro.ru", "phone": "+70692265822"}
0005433236016	0E192E	2301 384791	NIKITA KOROLEV	{"email": "nkorolev-1969@postgrespro.ru", "phone": "+70776478154"}
0005433236017	0E192E	8642 266403	SERGEY IVANOV	{"phone": "+70105303024"}
0005433236018	8FEE47	3494 922815	NATALYA IVANOVA	{"email": "ivanova.n17011969@postgrespro.ru", "phone": "+70208173601"}
0005433236019	8FEE47	6773 280273	ALEKSANDR DAVYDOV	{"phone": "+70404121449"}
0005433236020	CBDFEF	9358 619448	EVGENIY STEPANOV	{"email": "stepanov_evgeniy-061973@postgrespro.ru", "phone": "+70258804506"}
0005433236021	CBDFEF	1349 145379	NATALIYA YAKOVLEVA	{"email": "yakovlevanataliya_051971@postgrespro.ru", "phone": "+70520694418"}
0005433236022	EBB5CB	2865 801726	NADEZHDA TIKHONOVA	{"email": "tikhonovanadezhda1970@postgrespro.ru", "phone": "+70866932553"}
0005433236023	943684	1296 407282	IGOR SCHERBAKOV	{"email": "scherbakov.igor1977@postgrespro.ru", "phone": "+70278480310"}
0005433236024	E17F87	2457 653547	VALERIY NAZAROV	{"email": "nazarov_v1972@postgrespro.ru", "phone": "+70346620041"}
0005433236025	E17F87	3716 836683	ALEKSANDR IVANOV	{"phone": "+70841014043"}
0005433236026	C83FF0	3193 627156	ANATOLIY ANDREEV	{"email": "andreev_anatoliy.011977@postgrespro.ru", "phone": "+70973628829"}
0005433236027	C83FF0	6001 077188	AMINA PETROVA	{"email": "apetrova.16121977@postgrespro.ru", "phone": "+70089241170"}
0005433236028	C83FF0	9815 193587	NADIYA NOVIKOVA	{"email": "nadiyanovikova.101976@postgrespro.ru", "phone": "+70879827774"}
0005433236029	44E56C	0586 444004	DMITRIY VLASOV	{"phone": "+70846923240"}
0005433236030	44E56C	7699 648030	ROMAN EGOROV	{"email": "egorov_r_011982@postgrespro.ru", "phone": "+70451665152"}
0005433236031	EF2F95	9250 794209	ANTON MAKAROV	{"email": "a_makarov1973@postgrespro.ru", "phone": "+70358565689"}
0005433236032	CC5D82	3619 475657	OLEG SAVELEV	{"email": "oleg_savelev_1970@postgrespro.ru", "phone": "+70707977842"}
0005433236033	CC5D82	0674 098875	KLAVDIYA LEBEDEVA	{"email": "lebedevaklavdiya1964@postgrespro.ru", "phone": "+70174781009"}
0005433236034	AEABDD	9139 378653	VLADIMIR BONDARENKO	{"email": "vladimir.bondarenko-24021976@postgrespro.ru", "phone": "+70014453624"}
0005433236035	374992	6379 334914	NATALYA GRISHINA	{"email": "grishinan_111974@postgrespro.ru", "phone": "+70269434034"}
0005433236036	17DC3B	8004 611097	TIMOFEY POPOV	{"email": "popovtimofey011975@postgrespro.ru", "phone": "+70205638170"}
0005433236037	BA8769	0383 336460	LARISA TITOVA	{"phone": "+70352610325"}
0005433236038	BA8769	6846 877920	ANNA ROMANOVA	{"phone": "+70031880585"}
0005433236039	A8F216	3327 002513	ANATOLIY KUZMIN	{"email": "kuzmin.a_10071974@postgrespro.ru", "phone": "+70376615501"}
0005433236040	3D8E3D	4083 802865	VALENTINA ZHUKOVA	{"email": "v-zhukova02061977@postgrespro.ru", "phone": "+70695938144"}
0005433236041	3D8E3D	7100 137621	YURIY MOROZOV	{"email": "y-morozov-021975@postgrespro.ru", "phone": "+70448187388"}
0005433236042	3D8E3D	6324 926450	VALENTINA EGOROVA	{"phone": "+70811310001"}
0005433236043	C1D310	1001 181888	EVGENIYA ANDREEVA	{"email": "eandreeva.1970@postgrespro.ru", "phone": "+70399864553"}
0005433236044	8325FB	0077 282696	VLADIMIR MAKAROV	{"phone": "+70062349827"}
0005433236045	1A53AF	7352 118677	DENIS FILIPPOV	{"email": "filippov-denis.06111972@postgrespro.ru", "phone": "+70130150355"}
0005433236046	1A53AF	4478 223285	ALEKSANDR DENISOV	{"phone": "+70941393934"}
0005433236047	61818A	5905 841178	VALENTINA FOMINA	{"email": "fomina-v_26061979@postgrespro.ru", "phone": "+70506971515"}
0005433236048	74F536	6537 219838	ANASTASIYA FADEEVA	{"phone": "+70345495113"}
0005433236049	F96080	7023 875918	EVGENIY TARASOV	{"phone": "+70698268912"}
0005433236050	F96080	7988 056497	GALINA DANILOVA	{"phone": "+70102390570"}
0005433236051	88FD0C	8919 020695	SVETLANA STEPANOVA	{"email": "svetlana-stepanova09031971@postgrespro.ru", "phone": "+70563422700"}
0005433236052	E066B8	8147 784021	YULIYA NESTEROVA	{"phone": "+70566656380"}
0005433236053	2796C1	3060 876495	IVAN FEDOROV	{"phone": "+70204435421"}
0005433236054	22E768	5766 691134	SERGEY DMITRIEV	{"email": "sergey.dmitriev_06091976@postgrespro.ru", "phone": "+70122533316"}
0005433236055	22E768	3824 014339	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov.031971@postgrespro.ru", "phone": "+70133934592"}
0005433236056	22E768	2972 832458	ZAKHAR MOISEEV	{"phone": "+70251587445"}
0005433236057	DB35A2	1279 316563	ELENA STEPANOVA	{"phone": "+70384329485"}
0005433236058	2943B7	2515 614884	ANDREY MELNIKOV	{"email": "melnikov_a26091974@postgrespro.ru", "phone": "+70186173922"}
0005433236059	99CFE4	0276 057502	DENIS EGOROV	{"phone": "+70734671473"}
0005433236060	99CFE4	2115 968598	SERGEY SEMENOV	{"phone": "+70190289254"}
0005433236061	4F4D44	4582 875120	ELENA ANDREEVA	{"email": "andreeva.elena-111971@postgrespro.ru", "phone": "+70967869609"}
0005433236062	4F4D44	2952 732627	VYACHESLAV VASILEV	{"phone": "+70920021712"}
0005433236063	4F4D44	6698 663211	DAMIR MOROZOV	{"phone": "+70878057786"}
0005433236064	469E8A	9174 308057	YULIYA MIKHAYLOVA	{"email": "mikhaylova_y1961@postgrespro.ru", "phone": "+70514532989"}
0005433236065	C764AA	5952 322282	YULIYA KUZMINA	{"email": "yuliya.kuzmina_1977@postgrespro.ru", "phone": "+70510833110"}
0005433236066	C764AA	2041 014182	VADIM IVANOV	{"phone": "+70851251595"}
0005433236067	50A0A6	7572 759461	YURIY IVANOV	{"phone": "+70283887162"}
0005433236068	9B75D2	1845 902239	EDUARD MIKHAYLOV	{"email": "mikhaylov_e10061976@postgrespro.ru", "phone": "+70603298982"}
0005433250975	2E0937	4657 332935	GALINA MALYSHEVA	{"phone": "+70697529617"}
0005433250927	55B62F	5027 987999	LYUBOV ZAYCEVA	{"email": "zayceva-lyubov.10041975@postgrespro.ru", "phone": "+70100913374"}
0005433250928	38C237	7494 407597	EVGENIY VLASOV	{"phone": "+70344171521"}
0005433250929	90C6C7	4051 442576	OLGA EGOROVA	{"email": "olga.egorova-081984@postgrespro.ru", "phone": "+70299915088"}
0005433250930	FC0092	1010 523584	ALEKSEY SERGEEV	{"phone": "+70393742227"}
0005433250931	FC0092	5768 226188	POLINA FROLOVA	{"email": "p_frolova_1984@postgrespro.ru", "phone": "+70393676145"}
0005433250932	84F01F	1813 626645	RAISA VOLKOVA	{"phone": "+70126050805"}
0005433250933	99FF62	8151 526747	SERGEY ALEKSEEV	{"email": "alekseev.sergey_29051978@postgrespro.ru", "phone": "+70403711320"}
0005433250934	99FF62	9807 505229	NIKOLAY NIKITIN	{"email": "nikitin-n-1971@postgrespro.ru", "phone": "+70393069771"}
0005433250935	7DC1E5	9208 628688	YANA SIDOROVA	{"phone": "+70815009988"}
0005433250936	504640	9766 866728	IGOR GORBUNOV	{"phone": "+70098611094"}
0005433250937	F86F67	3934 432665	ANDREY SEMENOV	{"email": "semenova_16121962@postgrespro.ru", "phone": "+70323317224"}
0005433250938	0878B4	5307 426011	NADEZHDA KOROLEVA	{"email": "n-koroleva_1968@postgrespro.ru", "phone": "+70478792144"}
0005433250939	0878B4	2841 806176	ANATOLIY KUZNECOV	{"phone": "+70417076467"}
0005433250940	31AC12	1018 394303	EVGENIY DAVYDOV	{"email": "davydov-e_101972@postgrespro.ru", "phone": "+70940576706"}
0005433250941	41D854	9943 845932	DMITRIY NIKITIN	{"phone": "+70202018664"}
0005433250942	2CDECC	5173 426037	LARISA ARKHIPOVA	{"phone": "+70437918340"}
0005433250943	89E3B2	6366 266788	TATYANA ANDREEVA	{"email": "andreeva-t1971@postgrespro.ru", "phone": "+70884516409"}
0005433250944	B3BED5	0588 561578	SERGEY EGOROV	{"phone": "+70268085208"}
0005433250945	C29994	4271 970153	VLADIMIR ALEKSEEV	{"phone": "+70515533348"}
0005433250946	C29994	5393 834930	ANNA STEPANOVA	{"email": "anna_stepanova_29071982@postgrespro.ru", "phone": "+70880159389"}
0005433250947	0F9DE8	2379 987326	VIKTOR ALEKSANDROV	{"email": "aleksandrov-viktor-1976@postgrespro.ru", "phone": "+70459435125"}
0005433250948	DDBAE0	4542 101755	DMITRIY DENISOV	{"email": "denisov_dmitriy_18101968@postgrespro.ru", "phone": "+70564852374"}
0005433250949	EBD5CA	1019 279708	YURIY KOROLEV	{"phone": "+70049252058"}
0005433250950	EBD5CA	2061 604456	ELENA SOKOLOVA	{"phone": "+70167848818"}
0005433250951	CC6C27	3219 664237	ADELINA MOISEEVA	{"email": "adelina_moiseeva.1972@postgrespro.ru", "phone": "+70959667998"}
0005433250952	CAD490	1799 271827	ALEKSANDR SCHERBAKOV	{"phone": "+70003388013"}
0005433250953	CAD490	1011 814449	TATYANA LOGINOVA	{"email": "loginova-t-031979@postgrespro.ru", "phone": "+70366789974"}
0005433250954	CAD490	9291 670794	LYUBOV KUZMINA	{"phone": "+70723638977"}
0005433250955	B89A97	9343 429179	SERGEY KUZNECOV	{"phone": "+70388743402"}
0005433250956	B89A97	4724 251047	VERA ZAKHAROVA	{"email": "v_zakharova_1960@postgrespro.ru", "phone": "+70829612011"}
0005433250957	3BD4D0	7181 799531	VALERIY MAKAROV	{"email": "makarov-v_1982@postgrespro.ru", "phone": "+70853275551"}
0005433250958	2C507E	9579 846850	VIKTOR MOROZOV	{"phone": "+70619866087"}
0005433250959	448336	3764 492368	ANNA IVANOVA	{"phone": "+70632136950"}
0005433250960	E7505F	6352 947192	IVAN EGOROV	{"email": "ivan.egorov_16031961@postgrespro.ru", "phone": "+70595618988"}
0005433250961	E7505F	7475 886653	NATALYA ILINA	{"email": "ilina.natalya-101967@postgrespro.ru", "phone": "+70496107253"}
0005433250962	5774F8	8061 658314	TAMARA RODIONOVA	{"email": "rodionova_t_051963@postgrespro.ru", "phone": "+70028829775"}
0005433250963	8705B8	0782 062955	PELAGEYA MARTYNOVA	{"email": "martynovap-021978@postgrespro.ru", "phone": "+70927938436"}
0005433250964	8705B8	5063 826654	VALENTINA ZAKHAROVA	{"phone": "+70995374575"}
0005433250965	075011	5910 215053	ALLA MAKAROVA	{"phone": "+70896893980"}
0005433250966	CE0DBA	6176 729775	SERGEY GERASIMOV	{"phone": "+70064562497"}
0005433250967	5FC5B0	4854 240579	ANDREY KUZNECOV	{"email": "andrey.kuznecov_091970@postgrespro.ru", "phone": "+70735580726"}
0005433250968	FDF077	6919 976077	VADIM NOVIKOV	{"phone": "+70449078608"}
0005433250969	4717F6	9913 172286	ANNA VOLKOVA	{"email": "anna.volkova-1972@postgrespro.ru", "phone": "+70289618303"}
0005433250970	4717F6	2614 806409	MARGARITA POPOVA	{"phone": "+70096403161"}
0005433250971	8FD606	2738 667101	VIKTOR GRIGOREV	{"phone": "+70444003484"}
0005433250972	8FD606	2530 053156	ANASTASIYA NESTEROVA	{"email": "anastasiya-nesterova1978@postgrespro.ru", "phone": "+70948935416"}
0005433250973	1B45D3	9108 241694	ANASTASIYA FEDOROVA	{"email": "afedorova-1963@postgrespro.ru", "phone": "+70577975749"}
0005433250974	1B45D3	4679 094744	ANNA KAZAKOVA	{"phone": "+70277846022"}
0005433250976	79C67D	2019 084640	ALEKSANDR GERASIMOV	{"phone": "+70765626020"}
0005433250977	89F5FA	7532 900176	LYUDMILA IVANOVA	{"phone": "+70438373830"}
0005433250978	89F5FA	9052 447096	MIKHAIL STEPANOV	{"email": "stepanovmikhail.1969@postgrespro.ru", "phone": "+70207626689"}
0005433250979	A4DD63	4419 431471	GALINA KOMAROVA	{"phone": "+70595865451"}
0005433250980	D342D8	6474 271056	ANASTASIYA OSIPOVA	{"email": "anastasiyaosipova_1973@postgrespro.ru", "phone": "+70400858883"}
0005433250981	D342D8	5100 455866	ALEKSEY SIDOROV	{"phone": "+70428924363"}
0005433250982	55B257	8450 662907	TATYANA DAVYDOVA	{"phone": "+70433037959"}
0005433250983	398DB1	8090 598093	ALEKSANDR FILIPPOV	{"phone": "+70312529926"}
0005433250984	5A7B25	8178 550092	VYACHESLAV KUZNECOV	{"phone": "+70047257961"}
0005433250985	5A7B25	3353 558065	NADEZHDA KALININA	{"email": "nkalinina121971@postgrespro.ru", "phone": "+70718616253"}
0005433250986	C1A445	9625 060925	VALENTINA SMIRNOVA	{"phone": "+70534622390"}
0005433250987	3D4A7D	7209 903395	SVETLANA SERGEEVA	{"email": "svetlana.sergeeva1970@postgrespro.ru", "phone": "+70670338371"}
0005433250988	250760	1179 977821	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda_011978@postgrespro.ru", "phone": "+70883557979"}
0005433250989	DFE717	3794 915600	MARINA OSIPOVA	{"phone": "+70450502471"}
0005433250990	B5CCD8	1060 869813	ZLATA DANILOVA	{"email": "danilova_z1988@postgrespro.ru", "phone": "+70519886950"}
0005433250991	B5CCD8	4808 315387	ROMAN RODIONOV	{"email": "rodionov_r25011968@postgrespro.ru", "phone": "+70392353149"}
0005433250992	C13287	0560 973556	TATYANA IVANOVA	{"email": "tatyana_ivanova1971@postgrespro.ru", "phone": "+70010456258"}
0005433250993	23338A	9999 148022	ZAKHAR KUZMIN	{"phone": "+70105098683"}
0005433250994	881AE1	9660 472214	ROMAN FEDOTOV	{"phone": "+70493300966"}
0005433250995	920BFD	1943 707946	NATALYA PAVLOVA	{"email": "natalya_pavlova_1968@postgrespro.ru", "phone": "+70011025342"}
0005433250996	8387BB	8987 944421	ANDREY VOLKOV	{"email": "volkov_a07091976@postgrespro.ru", "phone": "+70911891391"}
0005433250997	5A2F49	1831 887060	ALEKSANDR NIKITIN	{"email": "nikitin.a_30121973@postgrespro.ru", "phone": "+70824791214"}
0005433250998	346D04	4884 050881	ANASTASIYA ZAYCEVA	{"email": "anastasiya_zayceva1962@postgrespro.ru", "phone": "+70886492014"}
0005433250999	346D04	6483 290995	DMITRIY ISAEV	{"phone": "+70104410582"}
0005433251000	715FBB	5162 995863	BORIS PETROV	{"email": "bpetrov_16061976@postgrespro.ru", "phone": "+70796192775"}
0005433251001	715FBB	4603 695209	VERA ZAKHAROVA	{"phone": "+70527988386"}
0005433251002	8B1A0B	8089 351657	MAKSIM NAUMOV	{"phone": "+70732470791"}
0005433251003	8B1A0B	9932 433053	ALEKSEY ALEKSANDROV	{"email": "aleksey-aleksandrov.1980@postgrespro.ru", "phone": "+70436265700"}
0005433251004	8B1A0B	8624 478091	LYUBOV ANTONOVA	{"phone": "+70469892765"}
0005433251005	8A6E24	7820 544689	OLGA BELYAEVA	{"email": "o_belyaeva-111963@postgrespro.ru", "phone": "+70467302688"}
0005433251006	D903F3	0011 005438	SVETLANA BORISOVA	{"phone": "+70777200141"}
0005433251007	95FB5C	2350 858855	LYUBOV KUZNECOVA	{"phone": "+70784713759"}
0005433251008	95FB5C	4060 847918	MARGARITA VASILEVA	{"phone": "+70245176598"}
0005433251009	B46F1E	1826 744555	ARTEM MATVEEV	{"email": "matveev_a_1980@postgrespro.ru", "phone": "+70662384949"}
0005433251010	B46F1E	2716 644418	ELENA KOLESNIKOVA	{"phone": "+70779897518"}
0005433251011	CCA905	4270 273284	INGA KONDRATEVA	{"email": "i.kondrateva.061980@postgrespro.ru", "phone": "+70325556793"}
0005433251012	CCA905	3449 310281	EVGENIY KAZAKOV	{"phone": "+70033193323"}
0005433251013	CCA905	6743 461683	IRINA POLYAKOVA	{"phone": "+70039850936"}
0005433251014	B2FE1C	2924 385624	EKATERINA PAVLOVA	{"phone": "+70882681933"}
0005433251015	4A80D1	3382 277233	NIKITA MARTYNOV	{"email": "nikita_martynov041975@postgrespro.ru", "phone": "+70932471905"}
0005433251016	4A80D1	8784 963440	MIKHAIL PAVLOV	{"email": "mikhail.pavlov19121967@postgrespro.ru", "phone": "+70769174060"}
0005433251017	857D8B	8122 071396	ANATOLIY SERGEEV	{"email": "sergeev_anatoliy081980@postgrespro.ru", "phone": "+70733309957"}
0005433251018	508762	1700 731419	EKATERINA SCHERBAKOVA	{"phone": "+70852484910"}
0005433251019	70F979	8431 017525	ALEKSANDRA DAVYDOVA	{"email": "davydovaaleksandra-06021970@postgrespro.ru", "phone": "+70300923442"}
0005433251020	F867CB	4194 925477	ELENA ALEKSEEVA	{"email": "e_alekseeva041964@postgrespro.ru", "phone": "+70888783285"}
0005433251021	F867CB	7914 302407	ALEKSANDR MOROZOV	{"email": "morozovaleksandr22091965@postgrespro.ru", "phone": "+70451934080"}
0005433251022	F7DE8C	3082 557598	ALEKSANDR YAKOVLEV	{"phone": "+70138642610"}
0005433251023	F510DD	5001 050621	PAVEL KARPOV	{"email": "pavel-karpov_02021972@postgrespro.ru", "phone": "+70071121488"}
0005433251024	F510DD	1312 342503	NINA TIMOFEEVA	{"email": "timofeeva-n_1979@postgrespro.ru", "phone": "+70919750657"}
0005433251025	16A848	6716 991910	VALENTINA OSIPOVA	{"email": "v-osipova_1975@postgrespro.ru", "phone": "+70487252474"}
0005433251026	16A848	5683 869275	SERGEY AFANASEV	{"email": "afanasev.s_29051973@postgrespro.ru", "phone": "+70759792602"}
0005433251027	16A848	1546 150073	ANNA DANILOVA	{"email": "a_danilova-121987@postgrespro.ru", "phone": "+70828507340"}
0005433251028	16A848	0244 537041	MAKSIM CHERNOV	{"email": "chernovmaksim09041968@postgrespro.ru", "phone": "+70091087612"}
0005433251029	F587E8	0311 765528	NATALYA NESTEROVA	{"phone": "+70616354708"}
0005433251030	F587E8	1894 960353	ALEKSANDR KUZNECOV	{"phone": "+70403465092"}
0005433251031	C08D42	5437 793188	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov021976@postgrespro.ru", "phone": "+70028736129"}
0005433251032	69E1EB	3802 537184	NATALYA NAUMOVA	{"email": "natalyanaumova-24101964@postgrespro.ru", "phone": "+70823755959"}
0005433251033	5E42C8	7366 095937	ILYA MAKAROV	{"phone": "+70552200977"}
0005433251034	CCD5D2	8160 772922	TATYANA TITOVA	{"phone": "+70620347797"}
0005433251035	CCD5D2	9577 234948	ANNA FILIPPOVA	{"phone": "+70332344108"}
0005433251036	759C29	8413 051595	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev_071965@postgrespro.ru", "phone": "+70037251793"}
0005433251037	759C29	1132 934250	YURIY IVANOV	{"phone": "+70546682351"}
0005433251038	26E400	6959 884925	ANNA ANTONOVA	{"email": "antonovaanna021985@postgrespro.ru", "phone": "+70066571696"}
0005433251039	D7124E	3468 964815	ANATOLIY KOROLEV	{"email": "korolev-anatoliy-1974@postgrespro.ru", "phone": "+70270644861"}
0005433251040	8E7821	1828 907345	SERGEY ZAYCEV	{"phone": "+70219264523"}
0005433251041	8E7821	2304 336145	ILYA FROLOV	{"email": "i_frolov021961@postgrespro.ru", "phone": "+70709610059"}
0005433251042	5E4297	4581 235342	KSENIYA DMITRIEVA	{"phone": "+70525971593"}
0005433251043	95C591	7028 929340	ZINAIDA KOROLEVA	{"email": "korolevaz_1964@postgrespro.ru", "phone": "+70199951914"}
0005433251044	58B0E4	7361 254676	ALEKSANDR KUZMIN	{"email": "kuzmin.a.30061971@postgrespro.ru", "phone": "+70169204036"}
0005433251045	58B0E4	8040 520334	ANNA SEMENOVA	{"phone": "+70817323656"}
0005433251046	C47F83	6248 067002	TAMARA NIKITINA	{"email": "t.nikitina.1968@postgrespro.ru", "phone": "+70378648636"}
0005433251047	A13D45	0347 113033	DANILA SOKOLOV	{"email": "sokolovdanila_11071967@postgrespro.ru", "phone": "+70305499082"}
0005433251048	A13D45	8695 369855	ZINAIDA TROFIMOVA	{"email": "zinaida_trofimova-031973@postgrespro.ru", "phone": "+70745370442"}
0005433251049	DAB610	8976 435208	EDUARD TIKHONOV	{"phone": "+70403768141"}
0005433251050	3471A2	3604 392907	ALENA FEDOROVA	{"phone": "+70328953199"}
0005433251051	79B1F9	4228 605883	VITALIY SOROKIN	{"email": "sorokin-v-1970@postgrespro.ru", "phone": "+70191380358"}
0005433251052	01482D	2540 555869	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr.1974@postgrespro.ru", "phone": "+70923628767"}
0005433251053	FD0CD5	6060 983962	ALEKSEY KUDRYASHOV	{"email": "a_kudryashov-1965@postgrespro.ru", "phone": "+70651471725"}
0005433251054	2046F2	4968 704943	DINARA KUDRYASHOVA	{"email": "dinara.kudryashova_121971@postgrespro.ru", "phone": "+70459515692"}
0005433251055	BCC013	3489 468983	GENNADIY GERASIMOV	{"phone": "+70868760282"}
0005433251056	BCC013	9815 297840	EKATERINA SEMENOVA	{"email": "semenovaekaterina-071976@postgrespro.ru", "phone": "+70948012482"}
0005433251057	AD421D	6378 735042	YULIYA KAZAKOVA	{"phone": "+70532319896"}
0005433251058	9DE267	0602 459137	VALERIY SERGEEV	{"email": "v_sergeev1974@postgrespro.ru", "phone": "+70658086818"}
0005433251059	A59F53	4672 019258	DARYA SMIRNOVA	{"email": "smirnova.darya-1973@postgrespro.ru", "phone": "+70965651357"}
0005433251060	41535F	9398 974666	TATYANA DAVYDOVA	{"phone": "+70219953126"}
0005433251061	748936	0900 772136	ALEKSANDR ZAKHAROV	{"phone": "+70011055309"}
0005433251062	A11743	6442 928351	MARIYA FILATOVA	{"phone": "+70647558712"}
0005433251063	586A9F	2809 087095	MARINA MATVEEVA	{"email": "marina_matveeva_091978@postgrespro.ru", "phone": "+70232629255"}
0005433251064	8AAE33	4779 783739	VALENTINA MAKAROVA	{"phone": "+70668431872"}
0005433251065	6BE51D	1959 947178	DARYA ZOTOVA	{"phone": "+70710932839"}
0005433251066	6BE51D	8980 903215	VLADIMIR ABRAMOV	{"email": "abramov-v-051961@postgrespro.ru", "phone": "+70320936389"}
0005433251067	D9F334	8413 083575	OLGA KAZAKOVA	{"email": "kazakova_olga111970@postgrespro.ru", "phone": "+70670703521"}
0005433251068	D9F334	5239 083046	VIKTOR YAKOVLEV	{"email": "yakovlev_viktor_1977@postgrespro.ru", "phone": "+70188329979"}
0005433251069	AD1B1D	4964 483528	OLGA GORBUNOVA	{"email": "olga_gorbunova.071974@postgrespro.ru", "phone": "+70645280365"}
0005433251070	AD1B1D	4064 178235	ALBINA CHERNOVA	{"email": "albina.chernova_29011969@postgrespro.ru", "phone": "+70652557817"}
0005433251071	985F5E	5223 682121	VLADIMIR IVANOV	{"email": "v_ivanov09101971@postgrespro.ru", "phone": "+70184394539"}
0005433251072	8585BE	9889 357238	VALERIY PAVLOV	{"phone": "+70017755331"}
0005433251073	C75C97	0432 131639	EVGENIY MAKAROV	{"email": "evgeniy-makarov31051962@postgrespro.ru", "phone": "+70695182576"}
0005433251074	43CF81	2981 546152	LILIYA MATVEEVA	{"email": "liliyamatveeva_1976@postgrespro.ru", "phone": "+70188975786"}
0005433251075	BBB3D2	9502 645999	OKSANA KARPOVA	{"phone": "+70592849615"}
0005433251076	BBB3D2	8966 754048	ALINA KULIKOVA	{"email": "alinakulikova.27111980@postgrespro.ru", "phone": "+70588858990"}
0005433251077	C4EE55	1804 178829	ARTEM MIKHAYLOV	{"email": "amikhaylov_081969@postgrespro.ru", "phone": "+70894608553"}
0005433251078	06CFD5	3830 094667	MARIYA NESTEROVA	{"email": "nesterovam.1972@postgrespro.ru", "phone": "+70156132178"}
0005433251079	06CFD5	3685 844284	NATALYA PETROVA	{"email": "natalya_petrova-021974@postgrespro.ru", "phone": "+70667070023"}
0005433251080	D7E4F3	3039 393603	ALEKSEY KUZMIN	{"phone": "+70018877447"}
0005433251081	D7E4F3	0395 477630	VIKTOR GRIGOREV	{"email": "v_grigorev1966@postgrespro.ru", "phone": "+70565865541"}
0005433251082	D7E4F3	2310 768263	IGOR SOKOLOV	{"phone": "+70071518641"}
0005433251083	C09FC7	1791 184206	SERGEY BORISOV	{"phone": "+70957349419"}
0005433251084	2E426B	6026 254549	SAVELIY IVANOV	{"phone": "+70621108195"}
0005433251085	4E017A	0922 508929	DARYA AFANASEVA	{"phone": "+70344853634"}
0005433251086	4F44DB	6366 551934	SEMEN POPOV	{"email": "popov-semen-111959@postgrespro.ru", "phone": "+70370173419"}
0005433251087	4F44DB	0117 177791	IGOR SEMENOV	{"phone": "+70855154295"}
0005433251088	4F44DB	4941 337557	ZOYA KRASNOVA	{"email": "zkrasnova.28111962@postgrespro.ru", "phone": "+70438067096"}
0005433251089	D01CAB	5321 599647	VALERIY ALEKSEEV	{"phone": "+70998273599"}
0005433251090	D01CAB	9012 896383	VYACHESLAV FROLOV	{"phone": "+70527985461"}
0005433251091	AFBA34	6439 617528	SERGEY SMIRNOV	{"email": "sergey.smirnov_1967@postgrespro.ru", "phone": "+70883415815"}
0005433251092	4D4CEA	2449 688472	DENIS EGOROV	{"email": "d.egorov-1963@postgrespro.ru", "phone": "+70025485888"}
0005433251093	1EC53F	7585 339667	RUSLAN SHEVCHENKO	{"phone": "+70287563339"}
0005433251094	54155F	5185 499043	YURIY KONOVALOV	{"email": "konovalov_y-1970@postgrespro.ru", "phone": "+70703513393"}
0005433251095	71E730	3689 454475	YULIYA POTAPOVA	{"email": "potapova.yuliya.15051976@postgrespro.ru", "phone": "+70518316380"}
0005433251096	71E730	5197 389850	EVGENIY ISAEV	{"email": "e-isaev.091973@postgrespro.ru", "phone": "+70872394519"}
0005433251097	17BAD0	4600 422613	VIKTOR FROLOV	{"email": "viktor.frolov-1966@postgrespro.ru", "phone": "+70050113708"}
0005433251098	462461	8921 583228	ALEKSANDR STEPANOV	{"phone": "+70067676859"}
0005433251099	0D8367	6792 928151	RUSLAN DENISOV	{"email": "r-denisov.23021979@postgrespro.ru", "phone": "+70982158817"}
0005433251100	0D8367	3969 433432	ANASTASIYA ISAEVA	{"email": "isaeva.a_061972@postgrespro.ru", "phone": "+70536833289"}
0005433251101	0D8367	9016 678516	EGOR KUZMIN	{"email": "kuzminegor-1969@postgrespro.ru", "phone": "+70991079007"}
0005433251102	E6E98A	6210 599112	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir-021976@postgrespro.ru", "phone": "+70202976337"}
0005433251103	70283D	8133 811648	VIKTORIYA YAKOVLEVA	{"phone": "+70194135542"}
0005433251104	70283D	6134 415505	VLADIMIR SERGEEV	{"phone": "+70250805276"}
0005433251105	43948D	7164 097750	LYUBOV VOROBEVA	{"phone": "+70388915396"}
0005433251106	B46C2E	3529 814724	TATYANA DENISOVA	{"phone": "+70808018887"}
0005433251107	2040EC	1439 147219	ELENA FROLOVA	{"email": "frolova-elena051960@postgrespro.ru", "phone": "+70195391174"}
0005433251108	2040EC	2558 779153	EKATERINA PETROVA	{"phone": "+70399625826"}
0005433251109	968FF5	4410 600591	YANA YAKOVLEVA	{"email": "yakovleva.yana_061971@postgrespro.ru", "phone": "+70872179776"}
0005433251110	D191C9	9588 289393	SERGEY MELNIKOV	{"email": "melnikov-s1971@postgrespro.ru", "phone": "+70380619991"}
0005433251111	D191C9	9429 448792	VIKTORIYA FROLOVA	{"email": "v_frolova_021981@postgrespro.ru", "phone": "+70000811064"}
0005433251112	A54676	3612 857939	NATALIYA GERASIMOVA	{"email": "gerasimova_nataliya_091974@postgrespro.ru", "phone": "+70895401605"}
0005433251113	A54676	1488 945508	VIKTORIYA MALYSHEVA	{"phone": "+70002173941"}
0005433251114	1B7010	6809 259014	DARYA ZHURAVLEVA	{"phone": "+70828359949"}
0005433251115	1B7010	2012 447410	LYUBOV TIMOFEEVA	{"email": "lyubov_timofeeva041971@postgrespro.ru", "phone": "+70797364971"}
0005433251116	0FB279	3637 208822	EVGENIY ZHUKOV	{"email": "zhukovevgeniy16111970@postgrespro.ru", "phone": "+70976420446"}
0005433251117	0FB279	8220 568244	ELENA FADEEVA	{"email": "fadeevae_10011967@postgrespro.ru", "phone": "+70366996899"}
0005433251118	8AE65C	0087 503147	ALEKSANDRA KISELEVA	{"email": "aleksandrakiseleva.041953@postgrespro.ru", "phone": "+70132516213"}
0005433251119	8AE65C	7022 526026	IVAN KUDRYASHOV	{"email": "i_kudryashov24031969@postgrespro.ru", "phone": "+70707988367"}
0005433251120	DD07C9	8457 936055	VLADIMIR MIKHAYLOV	{"phone": "+70929229803"}
0005433251121	72E864	7243 642091	IRINA NOVIKOVA	{"phone": "+70028767000"}
0005433251122	2DA469	6738 469721	NADEZHDA VASILEVA	{"email": "vasilevan1964@postgrespro.ru", "phone": "+70472785730"}
0005433251123	76E4D2	7239 880628	MAKSIM KARPOV	{"email": "m-karpov-1972@postgrespro.ru", "phone": "+70254826286"}
0005433251124	6F38C4	9606 039738	VALERIY SOKOLOV	{"phone": "+70030404191"}
0005433251125	6F38C4	0379 171651	EVGENIYA ISAEVA	{"phone": "+70331135852"}
0005433251126	6F38C4	9118 604434	SERGEY KRASNOV	{"phone": "+70454301874"}
0005433251127	2E1453	5058 807599	ALMIRA DMITRIEVA	{"phone": "+70840444549"}
0005433251128	9E3BB4	8959 756090	SVETLANA FROLOVA	{"email": "frolova.s.29031977@postgrespro.ru", "phone": "+70287598823"}
0005433251129	1350A2	7895 330725	YURIY KOZLOV	{"email": "ykozlov-011975@postgrespro.ru", "phone": "+70868203815"}
0005433251130	1350A2	8452 809191	GALINA FADEEVA	{"phone": "+70919283059"}
0005433251131	EF9966	3015 318729	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya-081968@postgrespro.ru", "phone": "+70555305886"}
0005433251132	C9037F	0610 076872	PETR YAKOVLEV	{"phone": "+70993377058"}
0005433251133	C9037F	2537 935135	IRAIDA KUZNECOVA	{"phone": "+70615689529"}
0005433251134	10BD2F	9852 819697	ANTONINA FEDOROVA	{"phone": "+70869256440"}
0005433251135	2A7295	2918 544133	YURIY KRASNOV	{"email": "krasnov-y_1975@postgrespro.ru", "phone": "+70627227060"}
0005433251136	2A7295	3196 409473	ALEKSEY FILIPPOV	{"email": "filippova-10011962@postgrespro.ru", "phone": "+70586616576"}
0005433251137	A53BE9	4054 240662	ELENA KRASNOVA	{"email": "e-krasnova-1963@postgrespro.ru", "phone": "+70211034559"}
0005433251138	DF189D	4299 822718	KSENIYA ANDREEVA	{"phone": "+70507687784"}
0005433251139	5C2C00	8502 027654	ANATOLIY GERASIMOV	{"phone": "+70787879492"}
0005433251140	A9421B	3660 239746	ALEKSEY CHERNOV	{"email": "chernovaleksey-071972@postgrespro.ru", "phone": "+70130186263"}
0005433251141	77ADC9	6051 646221	VLADIMIR ILIN	{"email": "ilin-v-031975@postgrespro.ru", "phone": "+70814062929"}
0005433251142	8FE1C6	6441 540110	KIRILL FEDOROV	{"phone": "+70172688533"}
0005433251143	8FE1C6	8831 708620	VALENTINA KONOVALOVA	{"email": "konovalova.v.1975@postgrespro.ru", "phone": "+70060689132"}
0005433251144	51CF2F	2201 751796	NIKOLAY GUSEV	{"email": "n_gusev011976@postgrespro.ru", "phone": "+70059622877"}
0005433251145	51CF2F	8499 301270	ANTONINA LUKYANOVA	{"phone": "+70471006131"}
0005433251146	B3B21C	2337 034732	LYUDMILA ZAYCEVA	{"phone": "+70751482786"}
0005433251147	999ED6	5904 348838	PAVEL RODIONOV	{"phone": "+70886538218"}
0005433251148	999ED6	5072 588651	NIKOLAY OSIPOV	{"email": "osipov_n_04121969@postgrespro.ru", "phone": "+70731286601"}
0005433251149	E1F7CA	9918 822525	VLADIMIR ANDREEV	{"email": "andreev.v-26011970@postgrespro.ru", "phone": "+70869830575"}
0005433251150	021E5B	7239 157230	KARINA SOROKINA	{"email": "sorokinakarina041969@postgrespro.ru", "phone": "+70647891269"}
0005433251151	4A21DE	4447 356687	VIKTOR BELOV	{"phone": "+70363799628"}
0005433251152	4A21DE	0699 205486	NIKOLAY VLASOV	{"email": "vlasov.nikolay-14091965@postgrespro.ru", "phone": "+70960987833"}
0005433251153	AC1C40	3391 543233	NIKOLAY BORISOV	{"phone": "+70915124271"}
0005433251154	AC1C40	6094 845913	GALINA KUZNECOVA	{"email": "kuznecova_g_21071970@postgrespro.ru", "phone": "+70715172112"}
0005433251155	34D860	7701 177801	EVGENIY ZHUKOV	{"email": "zhukov-evgeniy1969@postgrespro.ru", "phone": "+70515425663"}
0005433251156	34D860	8428 136295	VLADISLAV ILIN	{"email": "ilin_vladislav.071979@postgrespro.ru", "phone": "+70528878575"}
0005433251157	663446	6428 379781	RAISA ANISIMOVA	{"phone": "+70607142274"}
0005433251158	3D49F6	1849 013884	ALEKSEY NAUMOV	{"email": "naumov-aleksey_121974@postgrespro.ru", "phone": "+70682897771"}
0005433251159	505D0B	4764 986400	ALEKSANDR ZAKHAROV	{"email": "zakharov_a_20051970@postgrespro.ru", "phone": "+70606020153"}
0005433251160	A885E9	9479 179551	ELENA VASILEVA	{"phone": "+70327360628"}
0005433251161	6FCF07	2777 982851	VIKTORIYA DENISOVA	{"email": "v_denisova041973@postgrespro.ru", "phone": "+70988977114"}
0005433251162	BC4981	5342 154265	NATALYA ZAKHAROVA	{"phone": "+70844141634"}
0005433251163	BC4981	0151 245124	LYUBOV SERGEEVA	{"phone": "+70751119943"}
0005433251164	B722AD	8032 393545	OLGA LEBEDEVA	{"phone": "+70009487365"}
0005433251165	B722AD	4738 080117	DMITRIY SCHERBAKOV	{"email": "scherbakovd_1974@postgrespro.ru", "phone": "+70544491683"}
0005433251166	A89977	1117 502277	VLADIMIR PETROV	{"phone": "+70283118243"}
0005433251167	9EE01F	1769 336171	KLAVDIYA PETROVA	{"email": "petrovak.121968@postgrespro.ru", "phone": "+70635079341"}
0005433251168	53BED9	0304 257507	OKSANA GUSEVA	{"email": "oksana.guseva.1973@postgrespro.ru", "phone": "+70299819435"}
0005433251169	53BED9	9851 628654	VYACHESLAV CHERNOV	{"email": "chernov_v.1970@postgrespro.ru", "phone": "+70459276290"}
0005433251170	CB3A84	0489 518708	LYUDMILA MALYSHEVA	{"phone": "+70488581401"}
0005433251171	CB3A84	8012 246274	SERGEY NAZAROV	{"email": "sergey-nazarov_1965@postgrespro.ru", "phone": "+70690242817"}
0005433251172	5225FC	8404 861072	IRINA TITOVA	{"phone": "+70767625326"}
0005433251173	B64CF3	2979 950780	TATYANA VASILEVA	{"email": "vasilevat081974@postgrespro.ru", "phone": "+70297394967"}
0005433251174	B64CF3	4545 109971	PETR ORLOV	{"email": "petr_orlov-1958@postgrespro.ru", "phone": "+70916641272"}
0005433251175	49AD7E	9165 254001	MARIYA NESTEROVA	{"phone": "+70958794853"}
0005433251176	49AD7E	3872 962427	VERONIKA SIDOROVA	{"email": "vsidorova.21011964@postgrespro.ru", "phone": "+70379883238"}
0005433251177	8CED86	9424 694639	NIKITA VOLKOV	{"email": "volkovnikita1970@postgrespro.ru", "phone": "+70606111599"}
0005433251178	8CED86	5877 853427	VALERIY NIKITIN	{"phone": "+70467529670"}
0005433251179	249469	6789 454421	EVGENIY ABRAMOV	{"phone": "+70586655810"}
0005433251180	5B931F	4064 753543	MARINA SMIRNOVA	{"email": "smirnova.marina_1971@postgrespro.ru", "phone": "+70674628224"}
0005433251181	5B931F	8748 104325	NIKITA ALEKSEEV	{"email": "n.alekseev.1971@postgrespro.ru", "phone": "+70509387216"}
0005433251182	5B931F	0310 368338	EKATERINA CHERNOVA	{"email": "echernova_091976@postgrespro.ru", "phone": "+70961805666"}
0005433251183	5B931F	3161 001714	IVAN DAVYDOV	{"email": "idavydov.18021967@postgrespro.ru", "phone": "+70129336777"}
0005433251184	08F83C	4103 570014	VALENTINA LOGINOVA	{"phone": "+70637954166"}
0005433251185	901ECF	2196 423190	ALEKSANDR EGOROV	{"email": "egorov_aleksandr07121974@postgrespro.ru", "phone": "+70045764056"}
0005433251186	901ECF	8739 879968	OLGA KOZLOVA	{"phone": "+70420193012"}
0005433251187	2ADAF7	4057 042488	ELENA KAZAKOVA	{"email": "kazakova-e_031966@postgrespro.ru", "phone": "+70247802932"}
0005433251188	2ADAF7	4170 084880	ANNA IVANOVA	{"email": "ivanova-a-1965@postgrespro.ru", "phone": "+70063208533"}
0005433251189	2ADAF7	1893 958545	OLGA NAUMOVA	{"phone": "+70132590213"}
0005433251190	610516	7182 559601	SERGEY SAVELEV	{"phone": "+70314738739"}
0005433251191	0E9FEC	2375 026265	VIKTOR YAKOVLEV	{"phone": "+70576273169"}
0005433251192	C64221	9240 677269	VLADISLAV MELNIKOV	{"email": "vladislav_melnikov.091967@postgrespro.ru", "phone": "+70464179300"}
0005433251193	C64221	1038 854944	OLGA SOROKINA	{"phone": "+70435566398"}
0005433251194	5B6DF6	5120 050881	NATALYA KARPOVA	{"email": "n_karpova.1973@postgrespro.ru", "phone": "+70537133417"}
0005433251195	4E154E	3823 817662	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev-1970@postgrespro.ru", "phone": "+70239657338"}
0005433251196	4E154E	8266 051778	LYUDMILA VOLKOVA	{"phone": "+70160844197"}
0005433251197	37944E	3267 641908	EVGENIY NAUMOV	{"email": "evgeniy_naumov_1968@postgrespro.ru", "phone": "+70676158816"}
0005433251198	37944E	4940 712511	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov05041977@postgrespro.ru", "phone": "+70262351444"}
0005433251199	37944E	6039 624922	TATYANA IVANOVA	{"email": "ivanova_tatyana.20071969@postgrespro.ru", "phone": "+70296159422"}
0005433251200	877135	2821 594824	NIKOLAY OSIPOV	{"email": "nikolayosipov.121989@postgrespro.ru", "phone": "+70709386443"}
0005433251201	C6CB5B	0815 637006	LYUBOV KUZNECOVA	{"email": "l_kuznecova-17101968@postgrespro.ru", "phone": "+70904981993"}
0005433251202	C6CB5B	7036 370777	OLGA ZOTOVA	{"email": "zotova-o_13051966@postgrespro.ru", "phone": "+70331349190"}
0005433251203	AD7C35	7304 422063	PELAGEYA ZHURAVLEVA	{"phone": "+70349507558"}
0005433251204	FBA9E2	1885 266417	NATALYA VOLKOVA	{"email": "natalyavolkova_1968@postgrespro.ru", "phone": "+70862427334"}
0005433251205	56B446	8782 525146	IVAN NAUMOV	{"email": "inaumov_28011977@postgrespro.ru", "phone": "+70130397632"}
0005433251206	56B446	8285 503625	ALEKSANDR ZAYCEV	{"phone": "+70900255841"}
0005433251207	99F25D	4370 279834	LEONID MAKSIMOV	{"email": "maksimov.l.021970@postgrespro.ru", "phone": "+70241042575"}
0005433251208	9AD01D	4408 549313	VLADIMIR SIDOROV	{"phone": "+70014279310"}
0005433251209	9A0EE7	2975 608283	ALEKSEY GERASIMOV	{"phone": "+70305519472"}
0005433251210	9A0EE7	8353 840222	YULIYA EFREMOVA	{"email": "efremova_y_1971@postgrespro.ru", "phone": "+70434773765"}
0005433251211	9A0EE7	5718 250611	EVGENIYA LAZAREVA	{"email": "evgeniya.lazareva_23121967@postgrespro.ru", "phone": "+70416528954"}
0005433251212	99A76A	3403 056710	NATALYA PAVLOVA	{"phone": "+70222288399"}
0005433251213	C32D5D	2787 684382	ALEKSANDR FROLOV	{"phone": "+70597320072"}
0005433251214	C32D5D	9126 873975	GLEB KAZAKOV	{"phone": "+70948237724"}
0005433251215	6CB7CA	5730 682365	OKSANA YAKOVLEVA	{"email": "oksana.yakovleva.1959@postgrespro.ru", "phone": "+70615826548"}
0005433251216	3C4CBC	0106 353829	ALEKSANDR IVANOV	{"phone": "+70005426049"}
0005433251217	3C4CBC	6426 341014	VALENTINA SAVELEVA	{"email": "v_saveleva-12121968@postgrespro.ru", "phone": "+70951143688"}
0005433251218	6064BB	0209 369965	MARIYA NAZAROVA	{"email": "mnazarova05021969@postgrespro.ru", "phone": "+70476473571"}
0005433251219	6064BB	3113 038469	OLEG IVANOV	{"email": "o-ivanov.30051967@postgrespro.ru", "phone": "+70689819439"}
0005433251220	091143	9981 111950	ALEKSEY FROLOV	{"phone": "+70497338628"}
0005433251221	091143	9374 118797	STANISLAV KUZNECOV	{"email": "stanislavkuznecov_091970@postgrespro.ru", "phone": "+70550862954"}
0005433251222	4FB4C1	5449 914267	IVAN TARASOV	{"phone": "+70066066818"}
0005433251223	489681	7927 493471	ELIZAVETA YAKOVLEVA	{"phone": "+70775408290"}
0005433251224	489681	9642 554931	NIKOLAY KOROLEV	{"phone": "+70145617589"}
0005433251225	841B6E	1312 197888	GALINA NAZAROVA	{"email": "g_nazarova_1986@postgrespro.ru", "phone": "+70656884900"}
0005433251226	553242	8170 440432	LIDIYA VOLKOVA	{"email": "lidiya_volkova.1975@postgrespro.ru", "phone": "+70710390340"}
0005433251227	553242	1522 659627	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.20041957@postgrespro.ru", "phone": "+70059019952"}
0005433251228	838D30	3079 254437	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-111973@postgrespro.ru", "phone": "+70567250861"}
0005433251229	255A8F	9573 952941	VLADIMIR SCHERBAKOV	{"email": "vladimir_scherbakov-1970@postgrespro.ru", "phone": "+70808240598"}
0005433251230	255A8F	9362 866315	SERGEY KISELEV	{"email": "kiselevsergey_1980@postgrespro.ru", "phone": "+70554374073"}
0005433251231	55845B	2826 097902	MARIYA FILIPPOVA	{"phone": "+70143927365"}
0005433251232	7C5D90	8784 054695	ALEKSANDR ROMANOV	{"phone": "+70362734690"}
0005433251233	4B7462	9603 042067	TAMARA STEPANOVA	{"phone": "+70244796636"}
0005433251234	4B7462	3657 555988	VALENTIN ABRAMOV	{"phone": "+70213928893"}
0005433251235	38F2E8	7965 502054	LYUBOV MOROZOVA	{"phone": "+70352275765"}
0005433251236	ABE715	8471 970927	ELENA KISELEVA	{"email": "kiseleva.e.30101977@postgrespro.ru", "phone": "+70011303572"}
0005433251237	ABE715	0564 776288	PAVEL MOROZOV	{"email": "morozovp-1978@postgrespro.ru", "phone": "+70033641493"}
0005433251238	43887D	9255 174029	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov_071986@postgrespro.ru", "phone": "+70005224278"}
0005433251239	E18093	0559 738473	ARTEM KUZMIN	{"email": "a-kuzmin_051970@postgrespro.ru", "phone": "+70682769461"}
0005433251240	E18093	6552 092082	VIKTOR CHERNOV	{"phone": "+70494478461"}
0005433251241	E18093	8272 682769	SVETLANA NAUMOVA	{"email": "s-naumova.1959@postgrespro.ru", "phone": "+70403756860"}
0005433251242	D36DB2	3016 931243	VIKTOR KOZLOV	{"email": "kozlov.v14081972@postgrespro.ru", "phone": "+70454697939"}
0005433251243	0F9E7F	8882 513860	RAFAEL GERASIMOV	{"email": "gerasimovr.1964@postgrespro.ru", "phone": "+70088583244"}
0005433251244	AA33CF	3379 845957	MAYA TIKHONOVA	{"email": "tikhonova_maya_121985@postgrespro.ru", "phone": "+70873050982"}
0005433251245	F1FC0C	0587 843721	IVAN DENISOV	{"phone": "+70128393065"}
0005433251246	F1FC0C	7463 892406	VERONIKA TIKHONOVA	{"email": "tikhonova-veronika.1967@postgrespro.ru", "phone": "+70043840232"}
0005433251247	206282	8087 659747	ANDREY DMITRIEV	{"email": "dmitrievandrey1962@postgrespro.ru", "phone": "+70222027575"}
0005433251248	9E8E7C	0380 919747	BORIS BORISOV	{"email": "borisovb.05031968@postgrespro.ru", "phone": "+70171435708"}
0005433251249	BD4478	5711 940036	SERGEY MIRONOV	{"email": "sergey.mironov.081973@postgrespro.ru", "phone": "+70130758726"}
0005433251250	67B2B5	2419 354984	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov_041969@postgrespro.ru", "phone": "+70311560255"}
0005433251251	080ED4	2090 264094	VERA KUDRYASHOVA	{"phone": "+70694364396"}
0005433251252	080ED4	2361 715209	ANATOLIY GRIGOREV	{"phone": "+70056162827"}
0005433251253	FB669E	2188 496927	ANDREY TARASOV	{"phone": "+70838544412"}
0005433251254	7BDEBD	5352 211224	SERGEY MIKHAYLOV	{"email": "mikhaylov.s.17021970@postgrespro.ru", "phone": "+70041824849"}
0005433251255	7BDEBD	5526 231662	ANDREY FILIPPOV	{"phone": "+70734478066"}
0005433251256	7BDEBD	4716 633546	IVAN BORISOV	{"phone": "+70041930908"}
0005433251257	5BAA5F	6531 580466	NATALYA ANISIMOVA	{"email": "anisimova-natalya_1973@postgrespro.ru", "phone": "+70890006311"}
0005433251258	67713F	4768 634446	RUSTAM KARPOV	{"phone": "+70967134524"}
0005433251259	67713F	5613 661638	ELENA ANDREEVA	{"phone": "+70553628054"}
0005433251260	583002	8235 629449	YURIY BONDARENKO	{"phone": "+70433393172"}
0005433251261	9F8CD3	0332 828122	TATYANA GAVRILOVA	{"email": "gavrilova-tatyana-021973@postgrespro.ru", "phone": "+70359062756"}
0005433251262	9F8CD3	7149 874072	ALEKSANDR DMITRIEV	{"email": "admitriev.28121962@postgrespro.ru", "phone": "+70035303191"}
0005433251263	178AB2	3453 304689	EVGENIY SIDOROV	{"email": "evgeniy-sidorov-121968@postgrespro.ru", "phone": "+70765633062"}
0005433251264	B298F8	9306 864669	IRINA MASLOVA	{"phone": "+70853865328"}
0005433251265	D548BC	2597 652182	ROMAN ORLOV	{"phone": "+70793960205"}
0005433251266	D548BC	2180 030752	SERGEY IVANOV	{"phone": "+70673751988"}
0005433251267	D548BC	0792 923260	VERA LEBEDEVA	{"email": "lebedeva_vera.031970@postgrespro.ru", "phone": "+70702293230"}
0005433251268	914803	5435 381159	TATYANA GORBUNOVA	{"phone": "+70664700777"}
0005433251269	E8C840	4417 652332	ALEKSEY BARANOV	{"phone": "+70339693926"}
0005433251270	E8C840	0777 628824	VALENTINA MEDVEDEVA	{"email": "medvedeva_v-1965@postgrespro.ru", "phone": "+70970264179"}
0005433251271	9942A7	0088 134433	MARYAM KUZNECOVA	{"phone": "+70445292915"}
0005433251272	48CF5D	4779 991435	ANNA POLYAKOVA	{"email": "polyakova_a-09051972@postgrespro.ru", "phone": "+70491911279"}
0005433251273	1CC154	9937 072376	ANASTASIYA KAZAKOVA	{"email": "kazakova-anastasiya031978@postgrespro.ru", "phone": "+70938958222"}
0005433251274	777E84	3152 965398	SVETLANA DAVYDOVA	{"phone": "+70376567292"}
0005433251275	343C71	1831 768942	MARINA ZHURAVLEVA	{"phone": "+70242518334"}
0005433251276	01B12E	7879 748391	EVGENIYA DENISOVA	{"phone": "+70327777893"}
0005433251277	01B12E	5020 935844	TATYANA BELOVA	{"phone": "+70913038017"}
0005433251278	01B12E	9638 782398	ELENA KUZMINA	{"email": "elena.kuzmina021975@postgrespro.ru", "phone": "+70591686338"}
0005433251279	AC02A4	2961 706242	ALEKSEY VLASOV	{"email": "aleksey_vlasov_121968@postgrespro.ru", "phone": "+70442018923"}
0005433251280	AC02A4	1636 609045	ALEKSANDR IVANOV	{"phone": "+70645832651"}
0005433251281	609B69	7154 297903	NINA ABRAMOVA	{"phone": "+70403661238"}
0005433251282	C5815D	3136 630455	NINA IVANOVA	{"email": "ivanova.nina.081979@postgrespro.ru", "phone": "+70079453863"}
0005433251283	EEFF9E	1111 417074	VIKTOR STEPANOV	{"phone": "+70087864006"}
0005433251284	C4A923	1284 686899	ANNA IVANOVA	{"email": "ivanova-anna1969@postgrespro.ru", "phone": "+70237969237"}
0005433251285	79E819	7443 980851	VYACHESLAV SAVELEV	{"phone": "+70164377411"}
0005433251286	79E819	6181 401362	VIKTOR CHERNOV	{"email": "chernov-v_1974@postgrespro.ru", "phone": "+70919826072"}
0005433251287	F11C56	0680 428324	VALENTINA ALEKSANDROVA	{"email": "valentina_aleksandrova.1976@postgrespro.ru", "phone": "+70475150655"}
0005433251288	F78C96	8902 744467	ALEKSANDR POPOV	{"phone": "+70128278013"}
0005433251289	4BD884	9102 271683	ALEKSEY KARPOV	{"phone": "+70182885092"}
0005433251290	15651B	5075 337637	YULIYA ANTONOVA	{"email": "antonova.yuliya_03011976@postgrespro.ru", "phone": "+70766409884"}
0005433251291	85690D	1758 345957	OLGA KOVALEVA	{"email": "kovaleva.olga1975@postgrespro.ru", "phone": "+70171326446"}
0005433251292	C3A0CE	3449 315769	PETR MIKHAYLOV	{"phone": "+70491338239"}
0005433251293	C3A0CE	9819 550166	VALENTINA LUKYANOVA	{"email": "valentina.lukyanova-081969@postgrespro.ru", "phone": "+70284029622"}
0005433251294	103278	9031 325339	IGOR SHEVCHENKO	{"email": "shevchenko.i_011959@postgrespro.ru", "phone": "+70731451103"}
0005433251295	103278	8992 285331	VALENTINA ANTONOVA	{"phone": "+70300426475"}
0005433251296	59B8A3	7099 052143	LYUDMILA ROMANOVA	{"email": "l.romanova_1970@postgrespro.ru", "phone": "+70398346550"}
0005433251297	59B8A3	8629 240294	ARSENIY ORLOV	{"email": "arseniyorlov.031969@postgrespro.ru", "phone": "+70077149226"}
0005433251298	9A9F48	8160 621629	NADEZHDA IVANOVA	{"phone": "+70918285664"}
0005433251299	BE1265	9347 582777	NATALYA MAKAROVA	{"email": "makarovanatalya_1979@postgrespro.ru", "phone": "+70487222718"}
0005433251300	FC88A7	1870 466607	ANASTASIYA SMIRNOVA	{"phone": "+70486389111"}
0005433251301	F684CC	5457 878606	ELENA ALEKSANDROVA	{"phone": "+70645661801"}
0005433251302	9C7FB6	3928 912281	YULIYA KUZNECOVA	{"email": "kuznecovayuliya_04011969@postgrespro.ru", "phone": "+70870228794"}
0005433251303	D9BB5C	4958 270130	ALEKSEY KISELEV	{"email": "kiselevaleksey_1976@postgrespro.ru", "phone": "+70097489592"}
0005433251304	AF8FB4	1369 500152	GALINA POTAPOVA	{"email": "potapovagalina25081967@postgrespro.ru", "phone": "+70105069885"}
0005433251305	AF8FB4	1052 415154	VALERIY KAZAKOV	{"phone": "+70914687547"}
0005433251306	968943	2149 612349	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr.081965@postgrespro.ru", "phone": "+70455240050"}
0005433251307	968943	4509 583316	SAID ZAKHAROV	{"email": "zakharovs-031968@postgrespro.ru", "phone": "+70878235670"}
0005433251308	079BC4	1490 778548	VARVARA NOVIKOVA	{"phone": "+70565103787"}
0005433251309	079BC4	3249 980031	ALEKSANDR ROMANOV	{"phone": "+70060582779"}
0005433251310	A32F55	1415 986640	TATYANA MOROZOVA	{"email": "tatyanamorozova.04121987@postgrespro.ru", "phone": "+70328609399"}
0005433251311	D00B0B	2989 717492	ARSENIY IVANOV	{"email": "arseniy.ivanov.1963@postgrespro.ru", "phone": "+70731001867"}
0005433251312	D00B0B	7772 769960	SERGEY EGOROV	{"phone": "+70819976524"}
0005433251313	6E4484	9766 415717	PETR ROMANOV	{"phone": "+70742183160"}
0005433251314	6E4484	7571 460873	VIKTOR MOROZOV	{"email": "morozov.viktor_061976@postgrespro.ru", "phone": "+70445592920"}
0005433251315	1A78E8	3307 869394	VALENTINA NESTEROVA	{"email": "vnesterova23071957@postgrespro.ru", "phone": "+70296347530"}
0005433251316	297199	2479 504582	NATALYA ROMANOVA	{"email": "romanova_natalya-1973@postgrespro.ru", "phone": "+70742602371"}
0005433251317	BFB505	3476 047299	ANATOLIY VOLKOV	{"email": "volkov-anatoliy-051974@postgrespro.ru", "phone": "+70716815627"}
0005433251318	BFB505	2203 394634	VIKTOR SOKOLOV	{"email": "sokolov_viktor1973@postgrespro.ru", "phone": "+70254358883"}
0005433251319	8FD2A0	2256 905566	ALEKSANDRA IVANOVA	{"phone": "+70638407562"}
0005433251320	7B8B06	0871 944587	ALEKSEY KUZMIN	{"phone": "+70059246598"}
0005433251321	5975F9	2642 012194	MARIYA VASILEVA	{"phone": "+70358671276"}
0005433251322	4DB15A	7255 937660	DAMIR PAVLOV	{"email": "pavlov_d.1971@postgrespro.ru", "phone": "+70832681959"}
0005433251323	4DB15A	8295 786786	ALEKSANDR PAVLOV	{"phone": "+70373862968"}
0005433251324	B77E37	8828 346651	MATVEY KOROLEV	{"phone": "+70403299219"}
0005433251325	B77E37	4903 482070	SEMEN RODIONOV	{"phone": "+70654340555"}
0005433251326	3A212D	1620 845892	MARINA LUKYANOVA	{"phone": "+70509219432"}
0005433251327	F78E3A	9328 154862	EVGENIY PETROV	{"email": "e_petrov_111968@postgrespro.ru", "phone": "+70253645159"}
0005433251328	A05050	9986 736804	SOFIYA NIKOLAEVA	{"phone": "+70375411890"}
0005433251329	A05050	0812 980423	VERA NAZAROVA	{"email": "v_nazarova-071960@postgrespro.ru", "phone": "+70092061877"}
0005433251330	208E8E	9032 587557	KHALIDA ZAKHAROVA	{"email": "khalida_zakharova_1982@postgrespro.ru", "phone": "+70761584629"}
0005433251331	37A6ED	6297 640114	GALINA GORBUNOVA	{"phone": "+70557048220"}
0005433251332	B51C3B	1643 781220	ALEKSEY PETROV	{"email": "petrov-a_1972@postgrespro.ru", "phone": "+70349824384"}
0005433251333	77E56B	0812 226159	MIKHAIL MELNIKOV	{"email": "melnikov.m_20051977@postgrespro.ru", "phone": "+70804834793"}
0005433251334	22967C	8316 749635	GALINA EGOROVA	{"email": "egorova_galina-071977@postgrespro.ru", "phone": "+70196161813"}
0005433251335	22967C	8032 589964	OLGA ZAYCEVA	{"phone": "+70549412413"}
0005433251336	FEA442	7011 686373	MARIYA LOGINOVA	{"email": "mariya_loginova-061978@postgrespro.ru", "phone": "+70262549905"}
0005433251337	341C5F	9704 198992	ALEKSEY SAVELEV	{"email": "aleksey-savelev_24011976@postgrespro.ru", "phone": "+70130879212"}
0005433251338	681727	8699 350945	SERGEY FEDOROV	{"email": "fedorov.sergey-121976@postgrespro.ru", "phone": "+70640836722"}
0005433251339	6E006F	3101 500159	NATALYA DANILOVA	{"phone": "+70529483072"}
0005433251340	C7C8EF	4087 839419	KONSTANTIN DMITRIEV	{"email": "dmitrievk-031972@postgrespro.ru", "phone": "+70237635792"}
0005433251341	3162F5	4357 285142	LEONID POPOV	{"email": "l-popov-1964@postgrespro.ru", "phone": "+70953785377"}
0005433251342	765F18	1366 170138	KSENIYA KISELEVA	{"phone": "+70764118635"}
0005433251343	B646DE	7387 297636	VALERIY BARANOV	{"phone": "+70588103000"}
0005433251344	429EE4	3489 609017	TAISIYA BELOVA	{"email": "belova.taisiya-06021980@postgrespro.ru", "phone": "+70467448993"}
0005433251345	181B07	1521 481671	NADEZHDA KUZNECOVA	{"phone": "+70741641842"}
0005433251346	DD2184	6089 527372	TATYANA KOROLEVA	{"email": "tatyana_koroleva.091974@postgrespro.ru", "phone": "+70256296982"}
0005433251347	DD2184	9708 069640	RUSLAN FOMIN	{"email": "fominruslan-1968@postgrespro.ru", "phone": "+70574254779"}
0005433251348	1394FA	4668 706847	ELENA AFANASEVA	{"phone": "+70716456562"}
0005433251349	1394FA	2683 463100	ANATOLIY MAKSIMOV	{"phone": "+70398206472"}
0005433251350	63D18F	9212 246492	PAVEL SERGEEV	{"email": "p.sergeev-01011977@postgrespro.ru", "phone": "+70315994350"}
0005433251351	8FBC2E	5002 973113	ANDREY TARASOV	{"phone": "+70158623182"}
0005433251352	E294B2	1035 506290	EVDOKIYA EGOROVA	{"email": "e.egorova.1975@postgrespro.ru", "phone": "+70772636439"}
0005433251353	008CB6	6134 484333	OLGA MARTYNOVA	{"email": "olga-martynova101975@postgrespro.ru", "phone": "+70633414186"}
0005433251354	24EA0C	3992 169058	NATALYA MAKAROVA	{"phone": "+70629166881"}
0005433251355	84DB48	2192 592044	TAMARA KOROLEVA	{"phone": "+70407821054"}
0005433251356	84DB48	7035 163942	YURIY GERASIMOV	{"phone": "+70542669454"}
0005433251357	00F9FB	1595 463832	IGOR IVANOV	{"email": "igor_ivanov061976@postgrespro.ru", "phone": "+70877208694"}
0005433251358	00F9FB	0413 659623	ALFIYA VASILEVA	{"phone": "+70357524127"}
0005433251359	00F9FB	1308 266752	ALENA TIKHONOVA	{"email": "alena_tikhonova.1971@postgrespro.ru", "phone": "+70100263833"}
0005433251360	E53FB6	0621 284417	SERGEY ANDREEV	{"email": "s-andreev.091972@postgrespro.ru", "phone": "+70206620131"}
0005433251361	E53FB6	3453 923981	MARINA GAVRILOVA	{"email": "m-gavrilova.031975@postgrespro.ru", "phone": "+70794400527"}
0005433251362	2C8D83	6259 390460	DMITRIY IVANOV	{"phone": "+70328020736"}
0005433251363	2C8D83	4808 399928	VLADIMIR KRASNOV	{"phone": "+70010162335"}
0005433251364	F2B26C	1119 939841	KONSTANTIN BONDARENKO	{"email": "konstantin_bondarenko.1975@postgrespro.ru", "phone": "+70499808354"}
0005433251365	ACBD28	0490 154172	SVETLANA KUZMINA	{"phone": "+70430212217"}
0005433251366	A60F68	7638 975744	SERGEY SERGEEV	{"email": "s-sergeev_16071973@postgrespro.ru", "phone": "+70186408401"}
0005433251367	8C2A46	7254 243508	NATALYA KULIKOVA	{"email": "kulikovanatalya-051984@postgrespro.ru", "phone": "+70898684891"}
0005433251368	C39388	3354 335643	LARISA ROMANOVA	{"phone": "+70574194723"}
0005433251369	C39388	6062 632269	ALEKSANDR KISELEV	{"email": "a.kiselev-04061973@postgrespro.ru", "phone": "+70276037344"}
0005433251370	C39388	0375 214834	PAVEL PAVLOV	{"email": "ppavlov.071979@postgrespro.ru", "phone": "+70522802977"}
0005433251371	80B0E8	9520 933229	ANDREY AFANASEV	{"phone": "+70158598633"}
0005433251372	38EAB3	9421 946555	NATALYA STEPANOVA	{"phone": "+70903118639"}
0005433251373	38EAB3	9751 309143	TATYANA SCHERBAKOVA	{"email": "tatyanascherbakova1970@postgrespro.ru", "phone": "+70743862050"}
0005433251374	30997E	3124 740207	DMITRIY SIDOROV	{"email": "dmitriy-sidorov041981@postgrespro.ru", "phone": "+70077099812"}
0005433251375	30997E	2859 844796	LARISA IVANOVA	{"phone": "+70842001239"}
0005433251376	104321	9044 234082	SERGEY SOROKIN	{"phone": "+70537207764"}
0005433251377	21812B	7350 220922	VALENTINA RYABOVA	{"phone": "+70653619197"}
0005433251378	36B3AF	6151 003705	NIKOLAY ANTONOV	{"email": "n_antonov111967@postgrespro.ru", "phone": "+70715147626"}
0005433251379	D86D7D	6485 656640	OLGA FOMINA	{"phone": "+70622630483"}
0005433251380	2D9692	3178 138085	SERGEY STEPANOV	{"email": "stepanov_sergey.071968@postgrespro.ru", "phone": "+70726164014"}
0005433251381	30793D	3880 543289	IRINA SIDOROVA	{"phone": "+70209672561"}
0005433251382	CC57FC	3291 089109	IRINA MAKAROVA	{"phone": "+70550143680"}
0005433251383	CC57FC	3194 244857	SERGEY ZHURAVLEV	{"phone": "+70701782414"}
0005433251384	1CA416	1004 507199	YURIY NOVIKOV	{"email": "novikov-yuriy.1973@postgrespro.ru", "phone": "+70918744984"}
0005433251385	467F36	7860 158850	DIANA MIRONOVA	{"email": "diana.mironova101970@postgrespro.ru", "phone": "+70205878747"}
0005433251386	C85DBF	5300 114828	OLGA SERGEEVA	{"phone": "+70017577609"}
0005433251387	1E09D7	5063 598121	IGOR YAKOVLEV	{"email": "i.yakovlev_1970@postgrespro.ru", "phone": "+70107201010"}
0005433251388	1E09D7	5286 610181	SVETLANA YAKOVLEVA	{"email": "yakovlevasvetlana.25041977@postgrespro.ru", "phone": "+70853549642"}
0005433251389	050BCC	3479 863802	MARIYA SMIRNOVA	{"email": "smirnovamariya05041966@postgrespro.ru", "phone": "+70931046135"}
0005433251390	050BCC	6143 001405	SERGEY KONOVALOV	{"email": "konovalov_sergey.1958@postgrespro.ru", "phone": "+70477170922"}
0005433251391	1B426D	3165 436264	LIDIYA LEBEDEVA	{"phone": "+70082438242"}
0005433251392	D69BC4	7579 918734	OKSANA LAZAREVA	{"email": "o.lazareva.111964@postgrespro.ru", "phone": "+70960867826"}
0005433251393	955F0A	6007 396490	ALEKSEY MAKSIMOV	{"email": "a.maksimov021970@postgrespro.ru", "phone": "+70180718380"}
0005433251394	B7DAE4	8902 503083	TATYANA IVANOVA	{"phone": "+70557207102"}
0005433251395	49D1B0	3656 071765	IRINA KOLESNIKOVA	{"phone": "+70507123959"}
0005433251396	83074F	3658 274156	DENIS STEPANOV	{"phone": "+70671030687"}
0005433251397	350BC8	7224 928352	ELVIRA TROFIMOVA	{"phone": "+70036106242"}
0005433251398	1742DA	5971 818476	OLGA MAKAROVA	{"email": "o_makarova-011971@postgrespro.ru", "phone": "+70453309448"}
0005433251399	914E5F	5511 959537	NIKOLAY SIDOROV	{"email": "sidorovnikolay.30101958@postgrespro.ru", "phone": "+70892719241"}
0005433251400	914E5F	8969 617886	MARINA MELNIKOVA	{"email": "m.melnikova1977@postgrespro.ru", "phone": "+70027933784"}
0005433251401	C7DAD4	2203 522541	IRINA KUZNECOVA	{"phone": "+70975534345"}
0005433251519	D0EB41	9611 278657	NIKOLAY POPOV	{"phone": "+70891678544"}
0005433251402	C7DAD4	0866 572597	VIKTOR KAZAKOV	{"email": "kazakov.v-17011977@postgrespro.ru", "phone": "+70435480835"}
0005433251403	459E1A	0786 552145	VALERIY PAVLOV	{"phone": "+70092046373"}
0005433251404	459E1A	2916 472298	ELENA SEMENOVA	{"email": "elena-semenova1985@postgrespro.ru", "phone": "+70124420425"}
0005433251405	70DA15	2207 290921	DMITRIY ZHURAVLEV	{"phone": "+70084184503"}
0005433251406	0C2D2F	5059 570565	VYACHESLAV ROMANOV	{"email": "v_romanov-08061971@postgrespro.ru", "phone": "+70773424794"}
0005433251407	0FE41A	5780 545056	SVETLANA AFANASEVA	{"email": "afanasevas101968@postgrespro.ru", "phone": "+70844679244"}
0005433251408	0FE41A	3385 158641	ANNA IVANOVA	{"phone": "+70652899857"}
0005433251409	583D72	2109 854924	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-061976@postgrespro.ru", "phone": "+70422339517"}
0005433251410	750D29	4434 872540	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a_01071970@postgrespro.ru", "phone": "+70799777516"}
0005433251411	C68413	5531 934586	VALERIY KULIKOV	{"email": "v_kulikov_061986@postgrespro.ru", "phone": "+70727938855"}
0005433251412	46FD5E	3510 583467	NINA KONOVALOVA	{"email": "nina-konovalova-13081971@postgrespro.ru", "phone": "+70142514882"}
0005433251413	46FD5E	7819 091375	ALEKSEY VASILEV	{"email": "a.vasilev.051977@postgrespro.ru", "phone": "+70442535095"}
0005433251414	2A7176	9485 853680	ANASTASIYA KOROLEVA	{"email": "akoroleva_1972@postgrespro.ru", "phone": "+70727635428"}
0005433251415	E84ECB	1074 589100	VLADISLAV VASILEV	{"email": "vvasilev-04101974@postgrespro.ru", "phone": "+70806141430"}
0005433251416	AE55BF	7267 573882	NIKITA AFANASEV	{"phone": "+70331778102"}
0005433251417	FB03DA	8825 064990	ANNA ZHUKOVA	{"email": "zhukova-a-02121976@postgrespro.ru", "phone": "+70953298695"}
0005433251418	EE9913	9023 644406	IGOR ZAYCEV	{"email": "i_zaycev31101973@postgrespro.ru", "phone": "+70925758597"}
0005433251419	1EE2A0	2683 796350	ILSHAT KUZNECOV	{"email": "ilshat-kuznecov.1970@postgrespro.ru", "phone": "+70919713062"}
0005433251420	3F85CD	9174 046721	EVGENIY GUSEV	{"phone": "+70264399003"}
0005433251421	454EBF	9306 773246	NADEZHDA POPOVA	{"phone": "+70830864949"}
0005433251533	D9A584	8379 903775	ANNA ZHURAVLEVA	{"phone": "+70329588413"}
0005433251422	872582	8962 497885	VYACHESLAV FEDOROV	{"email": "v_fedorov-01111967@postgrespro.ru", "phone": "+70238378130"}
0005433251423	92D7D1	2338 300698	YANA ZHURAVLEVA	{"phone": "+70398706415"}
0005433251424	4A932F	8066 031004	LIDIYA TARASOVA	{"email": "tarasova_l.121966@postgrespro.ru", "phone": "+70408601076"}
0005433251425	418582	1259 827472	SVETLANA ERMAKOVA	{"phone": "+70591554999"}
0005433251426	241E32	3034 227054	ALEKSANDR ORLOV	{"email": "a.orlov-061968@postgrespro.ru", "phone": "+70090501225"}
0005433251427	FAB00E	8892 103456	VLADIMIR ANDREEV	{"phone": "+70973750275"}
0005433251428	56965C	0590 659133	VERA EFREMOVA	{"email": "efremova.v1984@postgrespro.ru", "phone": "+70353924141"}
0005433251429	710AB4	9261 478433	ANNA MAKAROVA	{"email": "makarova_a.1979@postgrespro.ru", "phone": "+70528474174"}
0005433251430	710AB4	6836 727376	YURIY GORBUNOV	{"phone": "+70668254905"}
0005433251431	C35CDF	7713 385505	ANDREY EGOROV	{"email": "a-egorov1980@postgrespro.ru", "phone": "+70034776419"}
0005433251432	C35CDF	7365 971669	VLADIMIR KARPOV	{"email": "v-karpov_1982@postgrespro.ru", "phone": "+70140703239"}
0005433251433	AD865A	8404 749500	SOFYA MARTYNOVA	{"phone": "+70830831112"}
0005433251434	EBD0BB	4010 535084	IRINA IVANOVA	{"email": "ivanova_irina.1961@postgrespro.ru", "phone": "+70854414526"}
0005433251435	EBD0BB	7035 968156	ZOYA VLASOVA	{"email": "z_vlasova12011972@postgrespro.ru", "phone": "+70517163983"}
0005433251436	AF07BC	2476 088390	NIKITA PAVLOV	{"email": "pavlovn1987@postgrespro.ru", "phone": "+70680602329"}
0005433251437	86848A	6222 422189	IRAIDA PETROVA	{"phone": "+70715578833"}
0005433251438	6C81A2	1995 575985	LIDIYA YUDINA	{"phone": "+70881355685"}
0005433251439	7B898B	4807 672759	TATYANA FROLOVA	{"phone": "+70902692106"}
0005433251440	ED3A17	2467 321391	EVGENIYA EGOROVA	{"email": "egorova_e_061961@postgrespro.ru", "phone": "+70798127318"}
0005433251441	FE643C	0689 722074	IRAIDA NIKOLAEVA	{"email": "nikolaeva-iraida02071969@postgrespro.ru", "phone": "+70374358792"}
0005433251442	FE643C	5592 481326	ALINA SMIRNOVA	{"phone": "+70239292642"}
0005433251443	FE643C	4630 538754	VALERIY STEPANOV	{"email": "valeriy_stepanov011968@postgrespro.ru", "phone": "+70430701617"}
0005433251444	3799DA	9655 976852	IRINA TIKHONOVA	{"phone": "+70565672812"}
0005433251445	9E1ED7	7358 781877	VASILIY KUZMIN	{"phone": "+70880740896"}
0005433251446	795242	6614 166262	SERGEY NIKOLAEV	{"phone": "+70621308832"}
0005433251447	CA33AE	3774 991770	EVGENIY PAVLOV	{"email": "pavlov_evgeniy.31031979@postgrespro.ru", "phone": "+70021220414"}
0005433251448	01132E	9804 338181	EKATERINA KOVALEVA	{"email": "e-kovaleva20081973@postgrespro.ru", "phone": "+70580049684"}
0005433251449	1D1A8A	2244 068506	VLADIMIR GRIGOREV	{"email": "grigorevvladimir.041970@postgrespro.ru", "phone": "+70961199752"}
0005433251450	46866F	7941 076427	DARYA FILIPPOVA	{"email": "filippovadarya.04101967@postgrespro.ru", "phone": "+70442296696"}
0005433251451	F6E873	9718 862694	VALERIY POPOV	{"email": "popov-v-121973@postgrespro.ru", "phone": "+70665945039"}
0005433251452	606D77	3325 388989	OLGA ANISIMOVA	{"phone": "+70592737699"}
0005433251453	EE3DDF	2027 565136	MARIYA ZHUKOVA	{"phone": "+70027417668"}
0005433251454	EE3DDF	1613 130956	LARISA KRASNOVA	{"phone": "+70866554692"}
0005433251455	BCE272	1240 436397	KIRILL NAZAROV	{"email": "nazarovkirill-27121977@postgrespro.ru", "phone": "+70254825293"}
0005433251456	BCE272	5174 520943	ANNA VLASOVA	{"email": "anna_vlasova011971@postgrespro.ru", "phone": "+70096092833"}
0005433251457	3FC82C	6809 389754	VLADIMIR SAVELEV	{"phone": "+70269904949"}
0005433251458	2EE48C	1704 054747	MARGARITA SOROKINA	{"phone": "+70043943627"}
0005433251459	2EE48C	3502 595331	ALEKSANDR BORISOV	{"email": "a.borisov_111970@postgrespro.ru", "phone": "+70991491089"}
0005433251460	B0FCCE	6366 754329	VERA YAKOVLEVA	{"email": "yakovlevavera.1976@postgrespro.ru", "phone": "+70626850580"}
0005433251461	E5FE01	9794 014758	DMITRIY ZAKHAROV	{"phone": "+70666111033"}
0005433251462	E5FE01	0539 073910	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.101983@postgrespro.ru", "phone": "+70873799138"}
0005433251463	052E9C	6835 091157	LYUBOV EGOROVA	{"email": "egorovalyubov20011967@postgrespro.ru", "phone": "+70094410462"}
0005433251464	4ACAB8	9681 812105	EVGENIY MIKHAYLOV	{"phone": "+70754298769"}
0005433251465	9A1345	0275 895054	ANTONIDA SOROKINA	{"email": "a.sorokina.12031972@postgrespro.ru", "phone": "+70641753570"}
0005433251466	701022	3771 439688	ALEKSEY NOVIKOV	{"email": "aleksey_novikov-1962@postgrespro.ru", "phone": "+70605670614"}
0005433251467	E9A0D8	7965 295188	ALEKSANDR POPOV	{"phone": "+70770154451"}
0005433251468	E9A0D8	9649 015098	OLGA ISAEVA	{"phone": "+70467035547"}
0005433251469	E9A0D8	2911 957856	NIKOLAY KAZAKOV	{"phone": "+70941982525"}
0005433251470	E9A0D8	3556 199766	YURIY FILIPPOV	{"email": "yfilippov.10071973@postgrespro.ru", "phone": "+70402515786"}
0005433251471	959F80	5156 617225	ARSENIY ZHURAVLEV	{"email": "arseniy_zhuravlev_081969@postgrespro.ru", "phone": "+70865740254"}
0005433251472	959F80	7662 571148	VLADISLAV SIDOROV	{"email": "vladislav-sidorov_16101978@postgrespro.ru", "phone": "+70215773714"}
0005433251473	3C5E83	8081 187457	VLADISLAV GRIGOREV	{"phone": "+70670400327"}
0005433251474	3C5E83	2644 620741	NINA KARPOVA	{"email": "karpova-n_13011967@postgrespro.ru", "phone": "+70741274187"}
0005433251475	3C5E83	1657 195132	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya-1963@postgrespro.ru", "phone": "+70640355629"}
0005433251476	937A1A	3306 003153	DMITRIY SOKOLOV	{"email": "sokolov.d10051973@postgrespro.ru", "phone": "+70123840067"}
0005433251590	1AE39D	4302 662910	ALEKSEY YAKOVLEV	{"phone": "+70988015509"}
0005433251477	937A1A	6533 571161	ELENA KOZLOVA	{"email": "e_kozlova-31101973@postgrespro.ru", "phone": "+70323269684"}
0005433251478	7EE937	1522 303844	VERA ANDREEVA	{"phone": "+70974169971"}
0005433251479	7EE937	5777 272144	OLGA IVANOVA	{"email": "ivanova.olga-29071977@postgrespro.ru", "phone": "+70156309695"}
0005433251480	0E25A8	7116 726860	ILYA NOVIKOV	{"email": "novikov.i091975@postgrespro.ru", "phone": "+70246654482"}
0005433251481	0D53EA	2141 610051	ELENA ZAYCEVA	{"email": "ezayceva.15111966@postgrespro.ru", "phone": "+70030328708"}
0005433251482	6A4345	9380 977291	ALEKSEY ABRAMOV	{"email": "aleksey.abramov-111973@postgrespro.ru", "phone": "+70269566690"}
0005433251483	6A4345	9747 600271	MIKHAIL KUZNECOV	{"phone": "+70384655538"}
0005433251484	F54936	1073 759128	KSENIYA KALININA	{"phone": "+70042452814"}
0005433251485	45B230	4592 977700	IGOR KUDRYASHOV	{"phone": "+70592142754"}
0005433251486	2ACB6D	2640 469467	MAKSIM EGOROV	{"email": "maksimegorov_21051963@postgrespro.ru", "phone": "+70497374268"}
0005433251487	F00D4E	2152 038528	OLGA MARTYNOVA	{"email": "o_martynova.14051973@postgrespro.ru", "phone": "+70122276287"}
0005433251488	5F2338	3136 038112	VLADIMIR ROMANOV	{"email": "vladimirromanov-121979@postgrespro.ru", "phone": "+70772933193"}
0005433251489	5F2338	1772 604519	GALINA KUZNECOVA	{"email": "kuznecova-galina.101977@postgrespro.ru", "phone": "+70387427940"}
0005433251490	FE6040	8203 613295	ALEKSANDR ZAYCEV	{"phone": "+70297738747"}
0005433251491	227E2F	7283 155843	ALLA NOVIKOVA	{"email": "novikova.a_03121965@postgrespro.ru", "phone": "+70955359490"}
0005433251492	05931C	7891 193161	LEONID SCHERBAKOV	{"phone": "+70461131362"}
0005433251493	05931C	3707 888588	KIRILL RODIONOV	{"email": "k-rodionov_1978@postgrespro.ru", "phone": "+70697197200"}
0005433251494	F492D9	1589 897109	SVETLANA MALYSHEVA	{"email": "svetlana.malysheva1967@postgrespro.ru", "phone": "+70836676982"}
0005433251495	F492D9	8593 673628	ELENA IVANOVA	{"phone": "+70853002500"}
0005433251496	599B22	9212 684518	SVETLANA NAZAROVA	{"phone": "+70422531806"}
0005433251497	01FE5C	8074 106760	VALENTINA GORBUNOVA	{"phone": "+70100853481"}
0005433251498	EBF77D	6144 802618	KRISTINA PETROVA	{"phone": "+70774359131"}
0005433251499	62D1B7	2413 090205	ANDREY GAVRILOV	{"phone": "+70565235577"}
0005433251500	E266A6	7193 889481	SERGEY FEDOROV	{"phone": "+70986216719"}
0005433251501	9BABBF	6503 760934	NIKOLAY VASILEV	{"email": "nikolay.vasilev_1972@postgrespro.ru", "phone": "+70302749769"}
0005433251502	9BABBF	6763 425964	OLGA PAVLOVA	{"phone": "+70817296356"}
0005433251503	5991E4	1799 193929	ALEKSANDR ZHUKOV	{"email": "zhukov-a-16041971@postgrespro.ru", "phone": "+70327502663"}
0005433251504	690A57	3568 422928	MIKHAIL PETROV	{"email": "mikhail.petrov031965@postgrespro.ru", "phone": "+70111454346"}
0005433251505	868D62	5410 353632	ELENA SAVELEVA	{"phone": "+70940979591"}
0005433251506	061C18	7043 737812	NATALYA SAVELEVA	{"email": "natalya.saveleva-121973@postgrespro.ru", "phone": "+70319184348"}
0005433251507	5D1C1A	9347 501175	LYUBOV GUSEVA	{"email": "lyubovguseva041972@postgrespro.ru", "phone": "+70144599614"}
0005433251508	C539F9	5161 451417	ILYA KOZLOV	{"phone": "+70559027218"}
0005433251509	A3E21A	1329 861874	VADIM BARANOV	{"phone": "+70655707701"}
0005433251510	072CFF	0512 368043	NINA TARASOVA	{"phone": "+70974335075"}
0005433251511	072CFF	3199 457644	LYUDMILA KAZAKOVA	{"email": "l.kazakova_111972@postgrespro.ru", "phone": "+70941010810"}
0005433251512	7051B0	3193 970916	SERGEY KRASNOV	{"email": "krasnov-s1974@postgrespro.ru", "phone": "+70573573010"}
0005433251513	C2A9B1	4431 273329	RUSLAN TIKHONOV	{"phone": "+70950568890"}
0005433251514	C0A366	6583 182497	MARIYA MOISEEVA	{"phone": "+70533047303"}
0005433251515	A87CD3	9987 998340	IGOR BONDARENKO	{"email": "bondarenko-igor_041972@postgrespro.ru", "phone": "+70685637603"}
0005433251516	A87CD3	1807 390980	NIKITA ROMANOV	{"phone": "+70186651240"}
0005433251517	4BA965	3053 876988	GALINA TITOVA	{"phone": "+70141134482"}
0005433251518	1C69E9	0908 135791	IVAN NOVIKOV	{"email": "novikov.ivan_09071959@postgrespro.ru", "phone": "+70502147020"}
0005433251520	D0EB41	1288 415249	MARINA BORISOVA	{"email": "borisova.m30091978@postgrespro.ru", "phone": "+70853156605"}
0005433251521	D0EB41	8049 857810	NATALYA FILATOVA	{"email": "filatovan.07041971@postgrespro.ru", "phone": "+70944982766"}
0005433251522	3135F4	3062 917881	ANASTASIYA IVANOVA	{"phone": "+70782549406"}
0005433251523	9FBBD9	5756 686360	DIANA KUZNECOVA	{"email": "d-kuznecova_1978@postgrespro.ru", "phone": "+70268623911"}
0005433251524	E1E7B5	9010 188943	LARISA SOLOVEVA	{"email": "larisasoloveva_30111973@postgrespro.ru", "phone": "+70103252470"}
0005433251525	9B2037	2692 687575	OLGA TIKHONOVA	{"phone": "+70110838773"}
0005433251526	B6E3DE	8951 602358	ALEKSANDR BORISOV	{"phone": "+70362018580"}
0005433251527	B6E3DE	5929 371670	TATYANA GUSEVA	{"email": "guseva_tatyana-081972@postgrespro.ru", "phone": "+70479177455"}
0005433251528	B7A097	6369 603274	OKSANA BELOVA	{"email": "oksana_belova.22011974@postgrespro.ru", "phone": "+70716434171"}
0005433251529	B7A097	2765 061861	LYUDMILA KOROLEVA	{"email": "koroleva-lyudmila_13061969@postgrespro.ru", "phone": "+70460203615"}
0005433251530	1E3FF5	5822 065196	ALEKSANDR KUZNECOV	{"phone": "+70426045875"}
0005433251531	3E6666	9810 820618	OLGA MELNIKOVA	{"phone": "+70749032277"}
0005433251532	BA7D9F	3305 781199	GALINA KOROLEVA	{"phone": "+70864572050"}
0005433251534	EFBE25	7891 229640	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-06061970@postgrespro.ru", "phone": "+70789359061"}
0005433251535	01EC53	9252 915661	GALIYA GUSEVA	{"email": "gguseva_011974@postgrespro.ru", "phone": "+70684168167"}
0005433251536	EEFB32	1898 779147	LYUDMILA SCHERBAKOVA	{"email": "scherbakova-lyudmila1987@postgrespro.ru", "phone": "+70983247102"}
0005433251537	1DBBA4	1586 368872	ALENA MOROZOVA	{"phone": "+70448316876"}
0005433251538	1DBBA4	4602 321801	EVGENIY KOROLEV	{"phone": "+70302033112"}
0005433251539	E0C7AE	9488 877418	ELENA BELYAEVA	{"email": "belyaevaelena.011977@postgrespro.ru", "phone": "+70623698090"}
0005433251540	CDFE1F	3513 917020	OLEG RODIONOV	{"phone": "+70412328911"}
0005433251541	2391E9	8510 792328	ALEKSANDR ALEKSEEV	{"phone": "+70726869639"}
0005433251542	0121E4	9826 124256	ALEKSANDR MAKSIMOV	{"phone": "+70681276516"}
0005433251543	6132C1	8704 592576	EKATERINA FEDOROVA	{"phone": "+70249043473"}
0005433251544	75B340	7647 429079	GALINA EFIMOVA	{"phone": "+70573389973"}
0005433251545	F4DDFC	3893 826512	IGOR KONOVALOV	{"email": "i.konovalov.081969@postgrespro.ru", "phone": "+70840054107"}
0005433251546	4FE384	8846 898963	TATYANA VOLKOVA	{"email": "t.volkova-29011961@postgrespro.ru", "phone": "+70865815169"}
0005433251547	79BF6C	8887 534644	ANNA ARKHIPOVA	{"email": "arkhipova.a11041983@postgrespro.ru", "phone": "+70409281424"}
0005433251548	DD609E	4671 754437	NIKOLAY SERGEEV	{"phone": "+70555281652"}
0005433251549	B837CD	1802 700178	OLGA KUZNECOVA	{"phone": "+70301274252"}
0005433251550	13DB35	6056 002141	VADIM STEPANOV	{"email": "v_stepanov_1962@postgrespro.ru", "phone": "+70326660919"}
0005433251551	13DB35	2164 745945	VERONIKA POPOVA	{"phone": "+70520230409"}
0005433251552	182DFE	7323 491690	LYUBOV SMIRNOVA	{"phone": "+70666011512"}
0005433251553	B0DFBF	3518 964360	ALEKSEY ANDREEV	{"phone": "+70457773043"}
0005433251554	F10A49	2762 364203	NADEZHDA NAZAROVA	{"phone": "+70496618401"}
0005433251555	73D575	2933 532449	ALBINA KALININA	{"email": "kalinina_albina.041970@postgrespro.ru", "phone": "+70809213938"}
0005433251556	84A9A8	8902 298835	MARIYA MAKAROVA	{"email": "m.makarova.1982@postgrespro.ru", "phone": "+70831214640"}
0005433251557	D901C1	0103 844268	VASILIY BARANOV	{"email": "v.baranov.031984@postgrespro.ru", "phone": "+70550679112"}
0005433251558	D901C1	9036 895658	GALINA VOLKOVA	{"phone": "+70004691717"}
0005433251559	D901C1	0323 230423	ALEKSEY NAUMOV	{"phone": "+70717680133"}
0005433251560	CCB689	4889 543322	ALEKSEY NOVIKOV	{"email": "aleksey_novikov_1966@postgrespro.ru", "phone": "+70342354051"}
0005433251561	1D247A	5263 890623	VYACHESLAV ZAKHAROV	{"email": "vyacheslav.zakharov_23121975@postgrespro.ru", "phone": "+70878644458"}
0005433251562	C7FB7F	3735 219941	VIKTORIYA KUDRYASHOVA	{"email": "v-kudryashova-29011971@postgrespro.ru", "phone": "+70735632580"}
0005433251563	007225	5845 054646	ALEKSANDR VOLKOV	{"phone": "+70528724773"}
0005433251564	4145B3	1131 906120	ALEKSANDR SMIRNOV	{"email": "asmirnov-1977@postgrespro.ru", "phone": "+70735546748"}
0005433251565	AEE36C	7176 793308	NIKITA KRASNOV	{"email": "nikita-krasnov-021985@postgrespro.ru", "phone": "+70096380151"}
0005433251566	150E2F	7043 517668	ALEKSANDR MEDVEDEV	{"email": "a-medvedev.1988@postgrespro.ru", "phone": "+70406845954"}
0005433251567	F74A96	0843 845452	SERGEY NAZAROV	{"phone": "+70129250800"}
0005433251568	F74A96	4881 141514	ANTONINA GERASIMOVA	{"email": "gerasimova.antonina_1966@postgrespro.ru", "phone": "+70414905704"}
0005433251569	2EA9DB	8596 049890	ALEKSANDR FEDOROV	{"phone": "+70220328003"}
0005433251570	2EA9DB	3063 549089	ANATOLIY FEDOTOV	{"email": "fedotov.anatoliy-23031961@postgrespro.ru", "phone": "+70501073792"}
0005433251571	53368F	8945 549131	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy1966@postgrespro.ru", "phone": "+70711148506"}
0005433251572	FC5616	1760 332612	VALENTINA MALYSHEVA	{"email": "malysheva.valentina26121980@postgrespro.ru", "phone": "+70022610728"}
0005433251573	119F26	1005 756523	EVGENIY IVANOV	{"phone": "+70862517248"}
0005433251574	119F26	3200 404873	DENIS STEPANOV	{"phone": "+70402202930"}
0005433251575	C0E841	7081 819015	LYUDMILA ANDREEVA	{"email": "l.andreeva03111967@postgrespro.ru", "phone": "+70040703609"}
0005433251576	C0E841	4220 865536	ARINA TIMOFEEVA	{"phone": "+70282367970"}
0005433251577	7F2660	1033 921726	VALERIY SMIRNOV	{"email": "vsmirnov041969@postgrespro.ru", "phone": "+70687724412"}
0005433251578	C6EED8	2579 210540	NATALYA PAVLOVA	{"email": "pavlova-n_1979@postgrespro.ru", "phone": "+70727639546"}
0005433251579	41F9CA	0527 408042	PAVEL GUSEV	{"phone": "+70309744851"}
0005433251939	ECD222	3241 966451	DANIIL SEMENOV	{"phone": "+70752553942"}
0005433251580	41F9CA	1778 131329	VLADIMIR VASILEV	{"email": "vasilev_vladimir011971@postgrespro.ru", "phone": "+70646010786"}
0005433251581	41F9CA	8982 770591	LYUDMILA POPOVA	{"phone": "+70718663207"}
0005433251582	2A2874	5588 577692	NIKOLAY KUZNECOV	{"email": "nikolaykuznecov-1971@postgrespro.ru", "phone": "+70393015872"}
0005433251583	46598B	8057 602061	ALEKSANDR ISAEV	{"phone": "+70168434294"}
0005433251584	E2D672	2509 095218	GALINA BELYAEVA	{"email": "g_belyaeva_1971@postgrespro.ru", "phone": "+70544221335"}
0005433251585	E2D672	3639 094050	DMITRIY NAZAROV	{"email": "nazarov_d-18081968@postgrespro.ru", "phone": "+70922283753"}
0005433251586	256026	5246 757087	ANASTASIYA KRASNOVA	{"phone": "+70676563334"}
0005433251587	256026	3876 497773	MAKSIM KOZLOV	{"email": "maksim.kozlov.1966@postgrespro.ru", "phone": "+70041766731"}
0005433251588	256026	7238 994666	ALEKSEY KULIKOV	{"email": "kulikov_aleksey_121981@postgrespro.ru", "phone": "+70569826341"}
0005433251589	B34C24	4057 801779	VIKTOR GRIGOREV	{"phone": "+70415529209"}
0005433251591	917A30	7421 590374	YURIY AFANASEV	{"phone": "+70178529448"}
0005433251592	C6C024	2034 611012	ALEKSANDR STEPANOV	{"phone": "+70203269632"}
0005433251593	C6C024	6260 403411	ANTON ZAKHAROV	{"phone": "+70971480331"}
0005433251594	C6C024	4778 003965	IRINA NOVIKOVA	{"phone": "+70268347756"}
0005433251595	937082	5249 425052	EVGENIY SAVELEV	{"email": "evgeniysavelev-071963@postgrespro.ru", "phone": "+70227575559"}
0005433251596	DC9946	7289 843839	ALEKSANDR ROMANOV	{"phone": "+70800918283"}
0005433251597	389F0B	3948 585949	SERGEY ZHUKOV	{"email": "zhukov.sergey.21011975@postgrespro.ru", "phone": "+70014079735"}
0005433251598	982696	1450 751447	ANDREY IVANOV	{"email": "ivanov-andrey_28021977@postgrespro.ru", "phone": "+70758868564"}
0005433251599	9D6CB8	0445 010212	DENIS FROLOV	{"email": "frolovd-25051978@postgrespro.ru", "phone": "+70612769636"}
0005433251600	9D6CB8	3238 095654	NINA CHERNOVA	{"phone": "+70276090612"}
0005433251601	242074	9471 222899	PAVEL KUZMIN	{"phone": "+70587859067"}
0005433251602	46244E	9948 735364	TAISIYA ISAEVA	{"phone": "+70017574251"}
0005433251603	3AB7D4	3007 371514	EVGENIYA ROMANOVA	{"phone": "+70044575890"}
0005433251604	E7F616	3176 198319	IVAN ZAYCEV	{"phone": "+70259995817"}
0005433251605	AB0D99	2668 757001	KLAVDIYA TARASOVA	{"phone": "+70761450123"}
0005433251606	AB0D99	8216 759053	VLADIMIR NAZAROV	{"phone": "+70201004922"}
0005433251607	79F5A5	7746 367396	MARIYA CHERNOVA	{"email": "chernova_m13051975@postgrespro.ru", "phone": "+70149227043"}
0005433251608	79F5A5	3030 685564	NATALYA PETROVA	{"email": "petrova_n_09041977@postgrespro.ru", "phone": "+70939055817"}
0005433251609	EC8382	1757 326642	NIKOLAY GAVRILOV	{"email": "gavrilov.n_1968@postgrespro.ru", "phone": "+70558281605"}
0005433251610	EC8382	2098 407044	ALFIYA GERASIMOVA	{"phone": "+70109860855"}
0005433251611	7D9F9B	3830 189040	ALEKSEY ANDREEV	{"email": "andreev.a01051975@postgrespro.ru", "phone": "+70212589215"}
0005433251612	C38B51	7257 025058	RASHIT AFANASEV	{"phone": "+70826910435"}
0005433251613	4EA590	8761 431322	ANATOLIY MEDVEDEV	{"email": "medvedev-anatoliy.061970@postgrespro.ru", "phone": "+70699605442"}
0005433251614	311F7A	8321 110835	ELIZAVETA NIKOLAEVA	{"email": "nikolaevaelizaveta_091988@postgrespro.ru", "phone": "+70897630385"}
0005433251615	311F7A	3469 137792	TAMARA VOROBEVA	{"phone": "+70269712040"}
0005433251616	649948	1975 929873	ELENA SAVELEVA	{"email": "saveleva_e1972@postgrespro.ru", "phone": "+70669879930"}
0005433251617	1CC710	3515 141793	VADIM KUDRYASHOV	{"phone": "+70001018061"}
0005433251618	1CC710	9622 318535	VLADIMIR SEMENOV	{"email": "vladimir.semenov1970@postgrespro.ru", "phone": "+70387444460"}
0005433251619	6BD4D5	4374 435125	YURIY KRASNOV	{"email": "krasnov_yuriy091961@postgrespro.ru", "phone": "+70432200470"}
0005433251620	0E56B8	4720 064195	LYUDMILA TIMOFEEVA	{"email": "timofeeva.lyudmila13011969@postgrespro.ru", "phone": "+70165074235"}
0005433251621	6E028F	9445 814639	ANASTASIYA GRISHINA	{"phone": "+70449597123"}
0005433251622	515390	2436 128395	ELENA NESTEROVA	{"phone": "+70643935444"}
0005433251623	515390	0191 920575	GENNADIY TIMOFEEV	{"phone": "+70192225323"}
0005433251624	B00115	6267 305831	ANATOLIY FEDOTOV	{"phone": "+70714025701"}
0005433251625	B00115	2221 491531	OLGA AKIMOVA	{"phone": "+70480692621"}
0005433251626	BF4CF2	6227 618887	EVGENIY DMITRIEV	{"phone": "+70597511589"}
0005433251627	7CAD5D	8603 399928	ALEKSANDR BELOV	{"phone": "+70776768154"}
0005433251628	18A6ED	1004 144856	VIKTOR NIKITIN	{"email": "v-nikitin_01101966@postgrespro.ru", "phone": "+70947447198"}
0005433251629	18A6ED	3418 443508	VALERIY DAVYDOV	{"phone": "+70981188628"}
0005433251630	047936	9526 066909	MARINA KRASNOVA	{"phone": "+70452096901"}
0005433251631	34AF73	1331 312458	SOFYA ILINA	{"phone": "+70000355972"}
0005433251632	311F4E	6689 112140	NATALYA KARPOVA	{"phone": "+70221566037"}
0005433251633	311F4E	8325 102444	DMITRIY SEMENOV	{"phone": "+70955593322"}
0005433251634	311F4E	0222 954174	YULIYA ZAYCEVA	{"phone": "+70711146201"}
0005433251635	C10817	8214 952206	TATYANA ZAKHAROVA	{"email": "zakharova_t_21051969@postgrespro.ru", "phone": "+70541688523"}
0005433251636	43E270	1773 548519	VLADIMIR ANDREEV	{"phone": "+70141146747"}
0005433251637	929C60	3967 263174	VLADIMIR KISELEV	{"email": "vladimirkiselev.05121975@postgrespro.ru", "phone": "+70826198020"}
0005433251638	397301	8181 852630	DIANA BELYAEVA	{"email": "d_belyaeva101957@postgrespro.ru", "phone": "+70105914278"}
0005433251639	1BC728	8860 424571	ANDREY ABRAMOV	{"email": "andrey_abramov.071985@postgrespro.ru", "phone": "+70024096363"}
0005433251640	1BC728	0806 841944	ALEKSEY SOKOLOV	{"email": "sokolov.a.091984@postgrespro.ru", "phone": "+70028093842"}
0005433251641	FAC263	8776 745866	FARIT MELNIKOV	{"phone": "+70850472985"}
0005433251642	97CD30	9362 811739	GALIYA NAZAROVA	{"email": "nazarova_g-29041973@postgrespro.ru", "phone": "+70872821265"}
0005433251643	97CD30	7465 768557	LILIYA PAVLOVA	{"email": "pavlova-liliya081967@postgrespro.ru", "phone": "+70173289557"}
0005433251644	8AFD9E	9594 082648	FANIS SMIRNOV	{"email": "f.smirnov.071972@postgrespro.ru", "phone": "+70148883036"}
0005433251645	8AFD9E	6518 568070	PAVEL ILIN	{"phone": "+70824528471"}
0005433251646	E2F14D	2732 195126	VITALIY ABRAMOV	{"email": "abramov.v_041981@postgrespro.ru", "phone": "+70518435277"}
0005433251647	FD873A	5622 023260	YULIYA FOMINA	{"email": "y_fomina.041982@postgrespro.ru", "phone": "+70029449967"}
0005433251648	FD873A	5421 979370	IGOR MELNIKOV	{"phone": "+70114701713"}
0005433251649	BA616A	8746 836649	SVETLANA IVANOVA	{"email": "sivanova-111975@postgrespro.ru", "phone": "+70462731061"}
0005433251650	BA616A	3053 941509	ELENA EGOROVA	{"phone": "+70980458141"}
0005433251651	377743	4151 820568	IGOR SOLOVEV	{"phone": "+70404397799"}
0005433251652	377743	9823 675624	TAMARA FILATOVA	{"email": "tamarafilatova-011969@postgrespro.ru", "phone": "+70084919571"}
0005433251653	377743	1534 162452	ANDREY ORLOV	{"email": "a-orlov-1975@postgrespro.ru", "phone": "+70333654799"}
0005433251654	3D2002	7775 777496	ALEKSEY GORBUNOV	{"email": "gorbunov-aleksey.24061971@postgrespro.ru", "phone": "+70797908557"}
0005433251655	63CF7C	4171 552766	NIKITA VASILEV	{"phone": "+70434025620"}
0005433251656	A5E712	1295 691316	MARINA FADEEVA	{"phone": "+70048000594"}
0005433251657	A5E712	5211 700446	IVAN MELNIKOV	{"email": "ivanmelnikov_09081974@postgrespro.ru", "phone": "+70018108006"}
0005433251658	A5E712	4677 519665	VALERIY KOROLEV	{"email": "korolev_v.12011961@postgrespro.ru", "phone": "+70249173489"}
0005433251659	A5E712	2330 102980	VLADIMIR SMIRNOV	{"email": "v.smirnov08121974@postgrespro.ru", "phone": "+70114779802"}
0005433251660	65347B	3112 239033	ANATOLIY NIKOLAEV	{"email": "nikolaev_anatoliy_05101984@postgrespro.ru", "phone": "+70189368910"}
0005433251661	65347B	7814 419195	VITALIY KRASNOV	{"email": "vitaliy_krasnov.1964@postgrespro.ru", "phone": "+70183442774"}
0005433251662	D6D9AF	3927 873536	RAMIL BELOV	{"phone": "+70562373344"}
0005433251663	9BD6E9	3332 060365	TATYANA VOLKOVA	{"phone": "+70556171590"}
0005433251664	0E83A3	2870 731788	ANASTASIYA STEPANOVA	{"email": "stepanovaanastasiya.1973@postgrespro.ru", "phone": "+70638118441"}
0005433251665	12E543	1936 446610	ANDREY FROLOV	{"phone": "+70823588317"}
0005433251666	12E543	1259 558991	EKATERINA DAVYDOVA	{"email": "davydova_e.101970@postgrespro.ru", "phone": "+70741661987"}
0005433251667	B844A8	3325 804892	VERA FROLOVA	{"phone": "+70914417648"}
0005433251668	B844A8	9189 862008	ANGELINA KAZAKOVA	{"phone": "+70374042429"}
0005433251669	49CF24	8195 216837	EVGENIY KOZLOV	{"email": "e_kozlov.1975@postgrespro.ru", "phone": "+70911424550"}
0005433251670	49CF24	6317 545826	MARINA SCHERBAKOVA	{"email": "marina-scherbakova-01071985@postgrespro.ru", "phone": "+70147540037"}
0005433251671	707DEC	0174 240095	VLADISLAV MAKAROV	{"email": "vladislav_makarov_24061969@postgrespro.ru", "phone": "+70420843122"}
0005433251672	AA81A7	3468 580684	ALEKSEY MIKHAYLOV	{"phone": "+70948505726"}
0005433251673	AA81A7	8836 139764	NATALYA SIDOROVA	{"email": "sidorovan_1966@postgrespro.ru", "phone": "+70500740634"}
0005433251674	3F0E11	0046 986549	ANDREY NIKOLAEV	{"email": "nikolaev_a.21111975@postgrespro.ru", "phone": "+70292329866"}
0005433251675	14B833	8157 030439	PAVEL NIKOLAEV	{"email": "pavel.nikolaev.081981@postgrespro.ru", "phone": "+70147837786"}
0005433251676	14B833	3414 785769	ALEKSANDR KAZAKOV	{"email": "akazakov-071975@postgrespro.ru", "phone": "+70849787216"}
0005433251677	A9E523	5609 757150	LARISA BELOVA	{"phone": "+70830417656"}
0005433251678	A9E523	5863 124001	ELENA NAZAROVA	{"email": "elena.nazarova-041966@postgrespro.ru", "phone": "+70511418253"}
0005433251679	AA1586	9825 943325	VLADIMIR MEDVEDEV	{"phone": "+70902672991"}
0005433251680	B9427F	0516 235373	TATYANA BELOVA	{"phone": "+70095061636"}
0005433251681	B9427F	2289 307883	LIDIYA PETROVA	{"email": "lidiyapetrova.13041964@postgrespro.ru", "phone": "+70118765396"}
0005433251682	C0C6E0	1801 412624	MATVEY GERASIMOV	{"phone": "+70872402047"}
0005433251683	C0C6E0	7834 366317	VLADIMIR STEPANOV	{"phone": "+70928127621"}
0005433251684	4A5420	7743 201804	ELENA KOZLOVA	{"email": "ekozlova.01041980@postgrespro.ru", "phone": "+70232374105"}
0005433251685	F6E97C	8314 662036	GALINA TITOVA	{"email": "titova.galina-1960@postgrespro.ru", "phone": "+70875607099"}
0005433251686	118E0A	1221 336946	VIKTORIYA FEDOROVA	{"phone": "+70833777586"}
0005433251687	F60D22	7858 563366	DARYA NAUMOVA	{"phone": "+70544969439"}
0005433251688	F60D22	3228 631912	TAMARA KOROLEVA	{"phone": "+70386836259"}
0005433251689	FEFECD	7026 616532	ALEKSANDR ILIN	{"phone": "+70497695216"}
0005433251690	98E0BC	8556 112225	VALENTINA KOROLEVA	{"email": "koroleva_valentina_1975@postgrespro.ru", "phone": "+70323031754"}
0005433251691	98E0BC	4019 160384	TATYANA MEDVEDEVA	{"email": "medvedeva-tatyana-1967@postgrespro.ru", "phone": "+70304655556"}
0005433251692	E366C8	9449 586103	NINA MIKHAYLOVA	{"email": "mikhaylova.nina.011972@postgrespro.ru", "phone": "+70737785543"}
0005433251693	E366C8	0958 417835	VIKTOR FROLOV	{"phone": "+70017984687"}
0005433251694	E366C8	4572 256651	NIKOLAY ROMANOV	{"email": "romanov_nikolay.1970@postgrespro.ru", "phone": "+70889273699"}
0005433251695	E366C8	6184 211725	ANASTASIYA POPOVA	{"phone": "+70474803604"}
0005433251696	F943C5	4916 364137	ALEKSEY ZAKHAROV	{"email": "zakharova-011962@postgrespro.ru", "phone": "+70793492138"}
0005433251697	4CC75F	4040 748048	DANIL KUDRYASHOV	{"email": "danil_kudryashov071969@postgrespro.ru", "phone": "+70814416076"}
0005433251698	FF7D7A	1572 958325	NATALYA KOZLOVA	{"email": "natalyakozlova28091951@postgrespro.ru", "phone": "+70722869530"}
0005433251699	FF7D7A	7552 797700	IVAN MAKAROV	{"phone": "+70433379591"}
0005433251700	FF7D7A	1677 621690	DENIS DAVYDOV	{"email": "davydovdenis1957@postgrespro.ru", "phone": "+70826322637"}
0005433251940	C7AE29	3030 769613	SERGEY ISAEV	{"phone": "+70734462537"}
0005433251701	B8A384	5934 203245	ALEKSEY ZHURAVLEV	{"email": "zhuravlev-aleksey121965@postgrespro.ru", "phone": "+70526689483"}
0005433251702	53C350	7270 385195	ALEKSEY ORLOV	{"email": "orlova021975@postgrespro.ru", "phone": "+70215487050"}
0005433251760	27FB42	2786 093712	LYUDMILA LAZAREVA	{"phone": "+70221879035"}
0005433251703	53C350	0372 069807	TAISIYA ALEKSEEVA	{"email": "taisiyaalekseeva-101967@postgrespro.ru", "phone": "+70857213125"}
0005433251704	53C350	3907 226107	NADEZHDA ERMAKOVA	{"email": "nadezhda-ermakova.1975@postgrespro.ru", "phone": "+70371074488"}
0005433251705	1CCFBA	2344 979562	VIKTORIYA ZHURAVLEVA	{"phone": "+70321130706"}
0005433251706	1CCFBA	8714 867763	RUSTAM NOVIKOV	{"email": "novikov.rustam081959@postgrespro.ru", "phone": "+70654926752"}
0005433251707	1CCFBA	2973 682160	ILONA IVANOVA	{"email": "ilona_ivanova04081970@postgrespro.ru", "phone": "+70562431533"}
0005433251708	A95383	7782 407026	NINA MAKAROVA	{"email": "makarova.n_031971@postgrespro.ru", "phone": "+70164066326"}
0005433251709	A95383	8063 929828	ALEKSANDR SERGEEV	{"phone": "+70635497316"}
0005433251710	201268	6720 969204	VIKTORIYA STEPANOVA	{"phone": "+70671916437"}
0005433251711	201268	4163 908960	MARINA DENISOVA	{"email": "denisova_marina.071968@postgrespro.ru", "phone": "+70513974430"}
0005433251712	C9EB5A	9371 317748	TATYANA FROLOVA	{"email": "frolovatatyana-071964@postgrespro.ru", "phone": "+70282379497"}
0005433251713	C9EB5A	5521 051951	YULIYA TIMOFEEVA	{"email": "yuliya_timofeeva1980@postgrespro.ru", "phone": "+70638951723"}
0005433251714	BE8A2E	5050 193646	ALEKSANDR ABRAMOV	{"email": "abramov.a-101971@postgrespro.ru", "phone": "+70251825501"}
0005433251715	21D7D6	1734 599393	EVGENIY GUSEV	{"phone": "+70041752179"}
0005433251716	F899B0	0393 925557	ANNA NAUMOVA	{"phone": "+70650360242"}
0005433251717	F899B0	9820 348626	VALENTINA VOROBEVA	{"phone": "+70282109643"}
0005433251718	5692A5	8878 599540	ZINAIDA VLASOVA	{"phone": "+70373357174"}
0005433251719	83A670	9300 805827	IVAN PETROV	{"email": "petrovi21121968@postgrespro.ru", "phone": "+70760719626"}
0005433251720	83A670	8419 867807	GALINA NIKITINA	{"email": "galinanikitina.24091968@postgrespro.ru", "phone": "+70578154464"}
0005433251721	E96214	6845 306658	EVDOKIYA VASILEVA	{"email": "evdokiya_vasileva01071965@postgrespro.ru", "phone": "+70309954578"}
0005433251722	32C3F9	8565 865647	DARYA LOGINOVA	{"phone": "+70028335595"}
0005433251723	CF02D0	6465 517930	OLGA BELOVA	{"email": "belova.olga-1966@postgrespro.ru", "phone": "+70280031719"}
0005433251724	E14222	8069 760809	NIKITA TARASOV	{"email": "tarasov_n1969@postgrespro.ru", "phone": "+70411247989"}
0005433251725	4EB3C3	5840 874306	VALERIY ROMANOV	{"phone": "+70226517688"}
0005433251726	4EB3C3	5313 998976	ALEKSEY NIKITIN	{"email": "anikitin.1965@postgrespro.ru", "phone": "+70139986782"}
0005433251727	8883D3	4067 030222	MARIYA BELOVA	{"phone": "+70861888977"}
0005433251728	8883D3	1564 764174	IVAN KOROLEV	{"phone": "+70559469130"}
0005433251729	AB739C	7312 429842	VLADIMIR PAVLOV	{"phone": "+70157099876"}
0005433251730	3AE407	2476 565091	VLADIMIR SCHERBAKOV	{"phone": "+70156383055"}
0005433251731	D37B31	7339 009470	NIKOLAY KOZLOV	{"email": "kozlov_n-071974@postgrespro.ru", "phone": "+70852041417"}
0005433251732	D37B31	4664 603417	TATYANA ALEKSANDROVA	{"phone": "+70868056147"}
0005433251733	14D409	7159 768113	EKATERINA KONOVALOVA	{"phone": "+70723715217"}
0005433251734	ED1A65	2636 686253	SVETLANA POLYAKOVA	{"email": "polyakovasvetlana-1971@postgrespro.ru", "phone": "+70099787695"}
0005433251735	229A08	7297 913483	SERGEY ZAYCEV	{"email": "s-zaycev.1973@postgrespro.ru", "phone": "+70512828993"}
0005433251736	C384F2	9867 920264	VASILIY NAUMOV	{"email": "naumovv1967@postgrespro.ru", "phone": "+70653738827"}
0005433251737	16728F	1236 138808	DMITRIY VASILEV	{"phone": "+70401176416"}
0005433251738	2835D9	4646 390214	DIANA MARTYNOVA	{"phone": "+70386201784"}
0005433251739	623BA0	4791 044283	ELENA VASILEVA	{"email": "elena-vasileva_031981@postgrespro.ru", "phone": "+70099021510"}
0005433251740	623BA0	4017 794839	LYUDMILA FOMINA	{"phone": "+70712234240"}
0005433251741	623BA0	9442 398660	TIMUR SERGEEV	{"email": "sergeev_timur-17051975@postgrespro.ru", "phone": "+70208934044"}
0005433251742	9F39E9	5119 261601	ELENA OVCHINNIKOVA	{"phone": "+70794185891"}
0005433251743	9F39E9	6242 794259	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev_1971@postgrespro.ru", "phone": "+70905207188"}
0005433251744	E54C3B	2974 093340	OLEG SOROKIN	{"phone": "+70674085236"}
0005433251745	1E3D39	7545 876309	EVGENIY KONOVALOV	{"email": "konovalov_e-20011968@postgrespro.ru", "phone": "+70033170209"}
0005433251746	DBEE14	3868 214701	ANNA FOMINA	{"email": "fominaanna05101970@postgrespro.ru", "phone": "+70431029470"}
0005433251747	AD47FF	6078 057228	ANNA VLASOVA	{"phone": "+70305695009"}
0005433251748	AD47FF	8605 952161	IRINA NIKIFOROVA	{"phone": "+70799257395"}
0005433251749	9E07D0	4946 842110	ANDREY NIKITIN	{"email": "nikitin.a_061985@postgrespro.ru", "phone": "+70994793413"}
0005433251750	E2C66C	1178 384212	IGOR PETROV	{"phone": "+70161979706"}
0005433251751	9F5F9C	7986 126454	DARYA LEBEDEVA	{"email": "d.lebedeva-051977@postgrespro.ru", "phone": "+70528151241"}
0005433251752	3A32A3	4007 331602	ANATOLIY ALEKSANDROV	{"phone": "+70441233224"}
0005433251753	3A32A3	6178 978156	YURIY NIKITIN	{"email": "nikitin_y.1972@postgrespro.ru", "phone": "+70842595082"}
0005433251754	3A32A3	2256 967539	NATALYA PAVLOVA	{"phone": "+70340576734"}
0005433251755	4051B3	1968 542222	ALEKSEY NIKOLAEV	{"phone": "+70873061794"}
0005433251756	9B21F7	8671 871513	ANASTASIYA KISELEVA	{"phone": "+70542490333"}
0005433251757	ACFBA1	8653 868229	VLADIMIR PAVLOV	{"phone": "+70640855342"}
0005433251758	27FB42	1886 412991	ELENA MAKAROVA	{"phone": "+70217932787"}
0005433251759	27FB42	8803 960050	ALEKSANDR FROLOV	{"phone": "+70095371522"}
0005433251761	F30187	1377 302312	NATALYA SAVELEVA	{"phone": "+70110167152"}
0005433251762	589B24	7935 154558	ILYA KONOVALOV	{"email": "konovalov-i25061967@postgrespro.ru", "phone": "+70272912318"}
0005433251763	7F43F0	3695 934066	VLADISLAV KUZNECOV	{"phone": "+70705079289"}
0005433251764	649E2E	6134 397837	OLGA SAVELEVA	{"email": "savelevao.30031972@postgrespro.ru", "phone": "+70753250640"}
0005433251765	649E2E	3396 845874	VLADIMIR SOKOLOV	{"email": "v-sokolov_121976@postgrespro.ru", "phone": "+70196678510"}
0005433251766	051D60	5450 493999	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr-12061968@postgrespro.ru", "phone": "+70887405594"}
0005433251767	051D60	6595 453902	LARISA EFREMOVA	{"email": "efremova.larisa01031969@postgrespro.ru", "phone": "+70975833086"}
0005433251768	43F2E4	6427 933198	VLADIMIR NIKOLAEV	{"email": "nikolaevv.08051971@postgrespro.ru", "phone": "+70556937568"}
0005433251769	43F2E4	4376 341190	DMITRIY OSIPOV	{"phone": "+70358589181"}
0005433251770	CADEF7	2881 085514	EKATERINA MELNIKOVA	{"email": "melnikova_ekaterina.121975@postgrespro.ru", "phone": "+70163398517"}
0005433251771	CADEF7	6389 609740	FARIDA KONDRATEVA	{"phone": "+70199187815"}
0005433251772	897F90	2112 388259	ANDREY ANDREEV	{"email": "a_andreev_16091980@postgrespro.ru", "phone": "+70826445216"}
0005433251773	7F9524	5972 550350	OLESYA SOKOLOVA	{"email": "sokolova-olesya-1963@postgrespro.ru", "phone": "+70101969800"}
0005433251774	FBE0EB	9885 351401	ALEFTINA SAVELEVA	{"email": "a_saveleva_13081967@postgrespro.ru", "phone": "+70148468548"}
0005433251775	9F78F3	5444 154239	SVYATOSLAV TIKHONOV	{"email": "s.tikhonov121976@postgrespro.ru", "phone": "+70551225287"}
0005433251776	9F78F3	1671 125730	ILYA KULIKOV	{"email": "kulikov_ilya.101982@postgrespro.ru", "phone": "+70133307794"}
0005433251777	6D78B4	0844 748559	GEORGIY IVANOV	{"email": "ivanov-georgiy_111976@postgrespro.ru", "phone": "+70206314757"}
0005433251778	7E9B19	4850 178739	ANATOLIY MEDVEDEV	{"email": "medvedeva.111974@postgrespro.ru", "phone": "+70015263973"}
0005433251779	7E9B19	5804 881148	STEPAN KUZNECOV	{"email": "kuznecov_s04101986@postgrespro.ru", "phone": "+70792604849"}
0005433251780	BFE6A3	7917 091088	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov.011980@postgrespro.ru", "phone": "+70434220520"}
0005433251781	BFE6A3	7800 194291	ANTON POPOV	{"email": "anton_popov_1965@postgrespro.ru", "phone": "+70187451354"}
0005433251782	CD0276	3792 625542	NINA KUZNECOVA	{"email": "nina-kuznecova_101965@postgrespro.ru", "phone": "+70839132510"}
0005433251783	CAF0AD	4656 555055	MIKHAIL MOISEEV	{"phone": "+70845466261"}
0005433251784	04AE07	2288 534314	VALENTINA GUSEVA	{"email": "guseva.valentina1972@postgrespro.ru", "phone": "+70626806792"}
0005433251785	04AE07	9893 800449	ANTONINA SIDOROVA	{"phone": "+70758709489"}
0005433251786	7CB8B4	6926 841211	LILIYA IVANOVA	{"phone": "+70442678282"}
0005433251787	117D5C	7770 173588	NADEZHDA POPOVA	{"email": "nadezhda.popova.061972@postgrespro.ru", "phone": "+70964619023"}
0005433251788	3E15BC	2018 005726	VIKTORIYA KUZNECOVA	{"email": "viktoriya_kuznecova-021973@postgrespro.ru", "phone": "+70737435600"}
0005433251789	9E8DA5	5067 596742	EVDOKIYA ZAYCEVA	{"email": "e.zayceva-021963@postgrespro.ru", "phone": "+70939600677"}
0005433251790	D7181F	8617 763080	DMITRIY OSIPOV	{"email": "osipov.d_12081974@postgrespro.ru", "phone": "+70637860891"}
0005433251791	D7181F	8301 722137	ALEKSEY MAKAROV	{"phone": "+70216224733"}
0005433251792	D89294	4496 822610	IRINA YUDINA	{"email": "yudina.i.071974@postgrespro.ru", "phone": "+70050626390"}
0005433251793	7A8C60	1997 865059	NELLI GUSEVA	{"phone": "+70225580633"}
0005433251794	7A8C60	1777 123725	ALEKSANDR EGOROV	{"phone": "+70080721179"}
0005433251795	7A8C60	4561 925609	NIKOLAY KUDRYASHOV	{"phone": "+70465323560"}
0005433251796	968415	5978 723815	IRINA NIKIFOROVA	{"email": "nikiforova_i_07101974@postgrespro.ru", "phone": "+70529029492"}
0005433251797	968415	1097 271573	SERGEY KUZNECOV	{"email": "s_kuznecov_1974@postgrespro.ru", "phone": "+70480518638"}
0005433251798	ED2884	8175 335902	NIKOLAY POPOV	{"phone": "+70731647356"}
0005433251799	ED2884	7035 141424	MIKHAIL POPOV	{"email": "popovm_14071976@postgrespro.ru", "phone": "+70370849631"}
0005433251800	ED2884	6657 991116	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr.1965@postgrespro.ru", "phone": "+70294579327"}
0005433251801	63DEC8	5024 848068	OLGA KAZAKOVA	{"phone": "+70142097488"}
0005433251802	63DEC8	0793 513993	VALERIY AFANASEV	{"email": "afanasevvaleriy_021969@postgrespro.ru", "phone": "+70880718511"}
0005433251803	2873D6	1312 838933	SERGEY MEDVEDEV	{"email": "sergeymedvedev-1980@postgrespro.ru", "phone": "+70599907029"}
0005433251804	5952D9	9209 615771	LYUBOV ZAKHAROVA	{"phone": "+70532457683"}
0005433251805	5952D9	8313 186365	LYUBOV IVANOVA	{"phone": "+70038916880"}
0005433251806	5952D9	9176 137823	IRINA VASILEVA	{"phone": "+70306812645"}
0005433251807	B0D344	6026 437981	LARISA IVANOVA	{"phone": "+70671549867"}
0005433251808	9AD3DA	2608 335835	TAGIR MIRONOV	{"phone": "+70500496140"}
0005433251809	462928	4859 337575	YAROSLAV PAVLOV	{"email": "pavlovy22011976@postgrespro.ru", "phone": "+70413738336"}
0005433251810	E6C3A8	1061 718544	LYUDMILA ANISIMOVA	{"phone": "+70202736951"}
0005433251811	44336E	7167 123838	VALENTINA MELNIKOVA	{"email": "melnikovavalentina-12011990@postgrespro.ru", "phone": "+70574808234"}
0005433251812	691A51	2092 672286	ANATOLIY ALEKSEEV	{"email": "alekseev_anatoliy-1976@postgrespro.ru", "phone": "+70563448958"}
0005433251813	B1D72C	1091 096037	VLADIMIR FROLOV	{"email": "v_frolov1970@postgrespro.ru", "phone": "+70373593802"}
0005433251814	9D47B5	7543 940243	ANNA TIKHONOVA	{"phone": "+70730729696"}
0005433251815	CCAC42	5601 042051	SERGEY BORISOV	{"phone": "+70222759027"}
0005433251816	25CF5D	5346 759853	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-101979@postgrespro.ru", "phone": "+70139346389"}
0005433251817	D94DC6	1839 535372	VLADISLAV MIRONOV	{"phone": "+70867977406"}
0005433251818	7EB9D6	5813 000100	ANNA MEDVEDEVA	{"phone": "+70489492605"}
0005433251819	7EB9D6	8400 989903	ARTUR PETROV	{"email": "artur_petrov_1989@postgrespro.ru", "phone": "+70636191264"}
0005433251820	F9E6C7	6308 470295	OLGA BELOVA	{"email": "belova-olga.1971@postgrespro.ru", "phone": "+70402953814"}
0005433251821	B6507F	3391 460588	VALENTINA EGOROVA	{"phone": "+70042992964"}
0005433251822	BDEFA7	8508 370644	NINA MAKSIMOVA	{"phone": "+70070071359"}
0005433251823	BDEFA7	5867 081334	VASILIY IVANOV	{"phone": "+70042273017"}
0005433251824	2C497D	5600 794634	EGOR RODIONOV	{"phone": "+70204604287"}
0005433251825	2C497D	4802 049031	ROZA ZOTOVA	{"email": "r_zotova_041964@postgrespro.ru", "phone": "+70419052766"}
0005433251826	27A150	2800 824038	DAMIR AFANASEV	{"phone": "+70913416700"}
0005433251827	F6E7A1	8595 259421	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov_051972@postgrespro.ru", "phone": "+70855520355"}
0005433251828	F6E7A1	9703 703988	OKSANA SMIRNOVA	{"email": "smirnovao-011980@postgrespro.ru", "phone": "+70979666699"}
0005433251829	E82C02	8529 950812	VYACHESLAV MIKHAYLOV	{"phone": "+70341602221"}
0005433251830	0C3B31	4394 451443	ARTEM GERASIMOV	{"email": "gerasimov_artem1977@postgrespro.ru", "phone": "+70695641718"}
0005433251831	B803FA	3204 733272	LIDIYA ZAYCEVA	{"email": "zayceva-lidiya-1970@postgrespro.ru", "phone": "+70947810699"}
0005433251832	D12BD3	1010 633660	ALEKSEY STEPANOV	{"email": "aleksey_stepanov_16071989@postgrespro.ru", "phone": "+70091311631"}
0005433251833	2CFDAE	9001 903112	VERA KOLESNIKOVA	{"phone": "+70826240707"}
0005433251834	2CFDAE	4665 128918	RUSHANIYA YAKOVLEVA	{"phone": "+70594971944"}
0005433251835	583A76	7338 810785	ANTONINA PAVLOVA	{"email": "apavlova-1978@postgrespro.ru", "phone": "+70857398968"}
0005433251836	583A76	3784 302898	ELIZAVETA ZHURAVLEVA	{"phone": "+70991483151"}
0005433251837	4D8F92	6946 113932	OLGA OSIPOVA	{"email": "olga-osipova-04081969@postgrespro.ru", "phone": "+70251606546"}
0005433251838	8CE953	8566 388934	ILYA KUZMIN	{"email": "kuzminilya_24051965@postgrespro.ru", "phone": "+70156561141"}
0005433251839	08A0DB	6303 098223	NATALYA LAZAREVA	{"phone": "+70258304702"}
0005433251840	7B5301	3953 872589	LYUBOV SOLOVEVA	{"email": "l-soloveva.16031973@postgrespro.ru", "phone": "+70210442726"}
0005433251841	02131B	7386 357667	ELENA SOLOVEVA	{"email": "esoloveva-1970@postgrespro.ru", "phone": "+70225283642"}
0005433251842	C76F3D	4661 716391	VLADIMIR KUZNECOV	{"phone": "+70815404534"}
0005433251843	C76F3D	8668 527494	EVGENIY SOROKIN	{"email": "evgeniy_sorokin-26101961@postgrespro.ru", "phone": "+70182821540"}
0005433251844	AB4B8A	4190 386745	ALENA STEPANOVA	{"phone": "+70440632804"}
0005433251845	AB4B8A	9012 599627	VALERIY KAZAKOV	{"phone": "+70090302415"}
0005433251846	629726	1227 972546	ANATOLIY KUZNECOV	{"phone": "+70441810896"}
0005433251847	69FD22	1863 560194	LEONID EGOROV	{"phone": "+70685067407"}
0005433251848	07F128	5525 776715	SERGEY ZAYCEV	{"email": "zaycev-s30121972@postgrespro.ru", "phone": "+70879320400"}
0005433251849	07F128	2821 633635	MATVEY KUZNECOV	{"phone": "+70014872259"}
0005433251850	779629	0306 065717	ALEKSANDRA MAKAROVA	{"email": "makarova_aleksandra_1964@postgrespro.ru", "phone": "+70543072789"}
0005433251851	779629	3459 579095	DMITRIY TARASOV	{"email": "tarasov.d_1976@postgrespro.ru", "phone": "+70035504514"}
0005433251852	779629	2146 454118	VLADIMIR POPOV	{"phone": "+70423046089"}
0005433251853	27CE6D	9875 707475	NADEZHDA POTAPOVA	{"email": "potapova-n1981@postgrespro.ru", "phone": "+70020571778"}
0005433251854	313C6E	1948 680735	ALEKSANDR NOVIKOV	{"phone": "+70136063047"}
0005433251855	FC2F46	5654 349481	IGOR NOVIKOV	{"phone": "+70036805946"}
0005433251856	0762DF	8319 068739	IRINA FADEEVA	{"email": "irinafadeeva-09111974@postgrespro.ru", "phone": "+70850418129"}
0005433251857	FF35CB	9931 468225	ANNA MAKAROVA	{"email": "makarovaanna_091976@postgrespro.ru", "phone": "+70806145197"}
0005433251858	FF35CB	5021 152910	ELENA FILIPPOVA	{"phone": "+70327698963"}
0005433251859	377A9D	5882 007504	DAVID DAVYDOV	{"email": "david-davydov-061979@postgrespro.ru", "phone": "+70563454597"}
0005433251860	225CB5	9334 872755	MAKAR SHEVCHENKO	{"phone": "+70637530716"}
0005433251861	385E2F	6560 019814	ELENA SAVELEVA	{"email": "saveleva.elena-081987@postgrespro.ru", "phone": "+70281620567"}
0005433251862	385E2F	2850 731974	NIKOLAY ABRAMOV	{"phone": "+70594641818"}
0005433251863	A30A87	1716 454339	TATYANA YAKOVLEVA	{"phone": "+70431170559"}
0005433251864	EB4805	0466 101625	SERGEY STEPANOV	{"phone": "+70239336122"}
0005433251865	EB4805	6940 496070	EVGENIYA SERGEEVA	{"phone": "+70832948402"}
0005433251866	2504DA	6272 125939	LYUDMILA TARASOVA	{"phone": "+70959926732"}
0005433251867	2504DA	0994 179019	NATALYA KOLESNIKOVA	{"email": "kolesnikova.n.091965@postgrespro.ru", "phone": "+70130133938"}
0005433251868	2504DA	5853 103410	OLGA KALININA	{"phone": "+70662406346"}
0005433251869	E21B2B	8619 448023	VIKTOR ANDREEV	{"email": "andreev.viktor.1979@postgrespro.ru", "phone": "+70436832177"}
0005433251870	E21B2B	2405 210807	DINARA SERGEEVA	{"phone": "+70102671667"}
0005433251871	933646	9696 825425	RINAT NAZAROV	{"email": "nazarov_rinat.061965@postgrespro.ru", "phone": "+70097163545"}
0005433251872	933646	5387 167491	NIKITA POPOV	{"phone": "+70724016837"}
0005433251873	933646	7542 618738	MIKHAIL CHERNOV	{"email": "chernov_mikhail_041975@postgrespro.ru", "phone": "+70767705364"}
0005433251874	E6F11B	0873 632289	VERA ZHUKOVA	{"email": "vera_zhukova061970@postgrespro.ru", "phone": "+70954579413"}
0005433251875	CFECAC	5742 768238	TAMARA KUZNECOVA	{"phone": "+70930393178"}
0005433251876	B395EE	3069 515310	OLGA KOMAROVA	{"email": "komarova_olga.081979@postgrespro.ru", "phone": "+70250563153"}
0005433251877	B395EE	6102 152903	ELENA AFANASEVA	{"email": "elena-afanaseva1977@postgrespro.ru", "phone": "+70190456177"}
0005433251878	CACB6F	1494 686116	ALEKSANDR TARASOV	{"phone": "+70089133039"}
0005433251879	A9209E	3111 409855	LEONID DENISOV	{"phone": "+70080907756"}
0005433251880	FEEA0E	5649 184277	MARINA STEPANOVA	{"email": "mstepanova.031971@postgrespro.ru", "phone": "+70160935867"}
0005433251881	0786FB	0450 533672	ANNA KUZNECOVA	{"email": "anna-kuznecova111960@postgrespro.ru", "phone": "+70449435145"}
0005433251882	585CBC	5918 644630	PELAGEYA KUZMINA	{"email": "kuzmina-p1971@postgrespro.ru", "phone": "+70612062438"}
0005433251883	6BDFF4	2493 825884	ILYA KRASNOV	{"phone": "+70786370820"}
0005433251884	6BDFF4	9004 686556	RUSLAN NIKOLAEV	{"phone": "+70250677074"}
0005433251885	6BDFF4	5217 830966	RAISA KUZNECOVA	{"email": "r_kuznecova_22021982@postgrespro.ru", "phone": "+70762441458"}
0005433251886	AD36DD	7906 404520	IRINA NIKITINA	{"email": "nikitina-i.01041961@postgrespro.ru", "phone": "+70646644518"}
0005433251887	A407FA	3174 556936	LYUBOV KONOVALOVA	{"email": "konovaloval_03111967@postgrespro.ru", "phone": "+70881812397"}
0005433251888	A407FA	2151 346813	DENIS KAZAKOV	{"phone": "+70041783264"}
0005433251889	AB1318	7397 924850	YURIY DAVYDOV	{"phone": "+70545352956"}
0005433251890	AB1318	9416 322383	ALEKSEY KULIKOV	{"email": "kulikov.a-02061970@postgrespro.ru", "phone": "+70404378147"}
0005433251891	2A4836	2181 831073	NINA KUZNECOVA	{"phone": "+70136538609"}
0005433251892	1AA217	5463 070029	OLEG KRASNOV	{"email": "krasnov_o_15021966@postgrespro.ru", "phone": "+70092575631"}
0005433251893	1AA217	3552 872672	ELENA MAKAROVA	{"email": "elenamakarova03051966@postgrespro.ru", "phone": "+70912369242"}
0005433251894	4BB88C	6714 111866	TATYANA ALEKSANDROVA	{"email": "aleksandrova.tatyana10021962@postgrespro.ru", "phone": "+70304415326"}
0005433251895	4BB88C	3038 037835	RIMMA ORLOVA	{"email": "rimma_orlova.1985@postgrespro.ru", "phone": "+70944388500"}
0005433251896	E509F2	5703 960493	LYUDMILA KOVALEVA	{"email": "l_kovaleva-101968@postgrespro.ru", "phone": "+70288574675"}
0005433251897	AA7FF1	0377 722631	NIKOLAY IVANOV	{"email": "ivanov.n061968@postgrespro.ru", "phone": "+70079633426"}
0005433251898	AA7FF1	7936 452889	ALEKSANDR ZAKHAROV	{"phone": "+70485225789"}
0005433251899	07471B	3046 289128	MARIYA SCHERBAKOVA	{"phone": "+70659579896"}
0005433251900	153FA0	0421 655902	OLEG BARANOV	{"email": "o-baranov1973@postgrespro.ru", "phone": "+70991055090"}
0005433251901	153FA0	9495 356323	VLADIMIR SMIRNOV	{"phone": "+70289571047"}
0005433251902	0F7E50	6625 706653	VIKTOR MAKSIMOV	{"email": "maksimov-v1967@postgrespro.ru", "phone": "+70128106060"}
0005433251903	9D7825	8709 217535	RAVIL STEPANOV	{"email": "stepanovravil-14051980@postgrespro.ru", "phone": "+70260346479"}
0005433251904	33E9B0	0146 819608	SERGEY GERASIMOV	{"email": "sergey-gerasimov_011975@postgrespro.ru", "phone": "+70159653535"}
0005433251905	45C3C3	3765 792843	LYUDMILA FOMINA	{"email": "lyudmila-fomina_27121957@postgrespro.ru", "phone": "+70928169768"}
0005433251906	45C3C3	2265 789342	VALENTINA TIKHONOVA	{"phone": "+70117533388"}
0005433251907	5542B2	3605 250160	NIKOLAY DENISOV	{"phone": "+70439915627"}
0005433251908	5542B2	2063 862067	VIKTOR PAVLOV	{"phone": "+70543300874"}
0005433251909	4C403C	9207 277714	SERGEY VLASOV	{"email": "vlasov-sergey-1972@postgrespro.ru", "phone": "+70350898233"}
0005433251910	4C403C	4989 744544	DMITRIY KUDRYASHOV	{"email": "d-kudryashov_041975@postgrespro.ru", "phone": "+70922023911"}
0005433251911	4C403C	9317 248496	VALENTINA SERGEEVA	{"phone": "+70366802460"}
0005433251912	C0A638	6449 751336	SERGEY EGOROV	{"email": "egorov-sergey_26051980@postgrespro.ru", "phone": "+70100966601"}
0005433251913	1574B8	9695 051024	VERA STEPANOVA	{"email": "v_stepanova.091981@postgrespro.ru", "phone": "+70789272697"}
0005433251914	53B750	0392 398805	SERGEY KUZNECOV	{"phone": "+70759532847"}
0005433251915	9C0A0A	1771 178361	SVETLANA BARANOVA	{"email": "s.baranova-101974@postgrespro.ru", "phone": "+70803879932"}
0005433251916	13CAC3	1097 042140	IRINA IVANOVA	{"email": "ivanova.irina-101972@postgrespro.ru", "phone": "+70087943853"}
0005433251917	13CAC3	9525 619879	IRINA MELNIKOVA	{"email": "melnikova-irina_011981@postgrespro.ru", "phone": "+70444836663"}
0005433251918	06B3B6	0178 838483	RUSTAM AFANASEV	{"email": "afanasevrustam.26111964@postgrespro.ru", "phone": "+70721332364"}
0005433251919	500509	7060 361113	IVAN AFANASEV	{"phone": "+70408530938"}
0005433251920	500509	8099 961190	ALEKSANDR KONOVALOV	{"email": "konovalov_aleksandr14021972@postgrespro.ru", "phone": "+70236199833"}
0005433251921	08DF51	4986 245884	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana041973@postgrespro.ru", "phone": "+70401184330"}
0005433251922	3864A9	4042 081122	NATALYA KOZLOVA	{"email": "kozlovanatalya1966@postgrespro.ru", "phone": "+70270275241"}
0005433251923	3864A9	2738 461980	SERGEY FEDOTOV	{"email": "sergeyfedotov-19111979@postgrespro.ru", "phone": "+70933266568"}
0005433251924	82F2B6	5349 427148	ANNA FILIPPOVA	{"email": "anna-filippova.031963@postgrespro.ru", "phone": "+70315120020"}
0005433251925	D6C388	4892 668457	KARINA ERMAKOVA	{"phone": "+70623256654"}
0005433251926	B6E93E	4675 389847	ZULFIYA KAZAKOVA	{"email": "zkazakova_1983@postgrespro.ru", "phone": "+70155275781"}
0005433251927	B6E93E	2266 278372	EVGENIYA NESTEROVA	{"email": "e.nesterova16071965@postgrespro.ru", "phone": "+70254827421"}
0005433251928	5CB023	5525 711048	MARINA KOLESNIKOVA	{"phone": "+70667959703"}
0005433251929	5CB023	1784 217534	YULIYA ERMAKOVA	{"phone": "+70061071540"}
0005433251930	9C4B72	5146 654004	ANDREY NIKOLAEV	{"email": "anikolaev.24101975@postgrespro.ru", "phone": "+70881321431"}
0005433251931	9C4B72	3931 598545	NIKOLAY BONDARENKO	{"email": "bondarenkon_061960@postgrespro.ru", "phone": "+70419131263"}
0005433251932	33A3A0	6642 606852	EKATERINA BELOVA	{"phone": "+70093612365"}
0005433251933	D037FF	3785 175810	EVGENIY IVANOV	{"email": "e.ivanov_1958@postgrespro.ru", "phone": "+70486510692"}
0005433251934	D037FF	8627 070987	ALEKSANDR POPOV	{"phone": "+70726255971"}
0005433251935	DFA508	9923 065737	ELVIRA ANDREEVA	{"phone": "+70486618101"}
0005433251936	20DCA1	7298 505143	ANTON VASILEV	{"email": "vasilevanton.1968@postgrespro.ru", "phone": "+70313898973"}
0005433251937	20DCA1	5125 930350	LIDIYA KALININA	{"phone": "+70260842419"}
0005433251938	E8A2AB	1636 219293	KLAVDIYA IVANOVA	{"email": "klavdiyaivanova.03081963@postgrespro.ru", "phone": "+70388498900"}
0005433251941	330C27	3184 257555	NINA KISELEVA	{"phone": "+70580164087"}
0005433251942	330C27	6417 861265	DENIS TARASOV	{"email": "tarasov_denis_1967@postgrespro.ru", "phone": "+70530083878"}
0005433251943	ADC70E	4401 884462	ZOYA IVANOVA	{"phone": "+70515256404"}
0005433251944	1379BB	7632 038956	TATYANA TARASOVA	{"email": "tarasovat-1966@postgrespro.ru", "phone": "+70657148215"}
0005433251945	D0CE17	0097 718111	IVAN FILIPPOV	{"phone": "+70359453775"}
0005433251946	A832F1	8202 832540	SVETLANA MAKAROVA	{"email": "makarova-s-29111983@postgrespro.ru", "phone": "+70320579072"}
0005433251947	F6D356	6447 401751	LIDIYA ZHURAVLEVA	{"phone": "+70070796187"}
0005433251948	AEBF2A	8256 501696	GALINA KULIKOVA	{"email": "g_kulikova_15071975@postgrespro.ru", "phone": "+70382131429"}
0005433251949	9CF4F0	7522 732086	ANASTASIYA PAVLOVA	{"email": "pavlova.a_1976@postgrespro.ru", "phone": "+70618484385"}
0005433251950	139652	7191 969847	ANVAR AFANASEV	{"email": "anvar_afanasev.1986@postgrespro.ru", "phone": "+70068397405"}
0005433251951	EF9AA7	7973 034528	TATYANA ARKHIPOVA	{"phone": "+70867480248"}
0005433251952	EF9AA7	8012 431438	NATALYA IVANOVA	{"email": "n-ivanova061971@postgrespro.ru", "phone": "+70574193333"}
0005433251953	BE036B	7888 785561	RUSTEM SOLOVEV	{"phone": "+70988751175"}
0005433251954	78F25B	6083 963590	ELENA MARTYNOVA	{"phone": "+70164524534"}
0005433251955	D2A7F6	0384 475515	SERGEY VLASOV	{"phone": "+70992542412"}
0005433251956	4CAB5D	1722 046305	LILIYA VOROBEVA	{"phone": "+70139133580"}
0005433251957	CC46D0	3667 646371	VALENTINA KULIKOVA	{"phone": "+70763549050"}
0005433251958	4B5F37	1406 887198	ARTUR PETROV	{"email": "petrov.a-31101977@postgrespro.ru", "phone": "+70840689974"}
0005433251959	91411D	0762 751439	EKATERINA EGOROVA	{"email": "e.egorova_1981@postgrespro.ru", "phone": "+70440593935"}
0005433251960	490623	3334 218443	ALEKSANDRA ZHUKOVA	{"email": "zhukova_a_031972@postgrespro.ru", "phone": "+70071177098"}
0005433251961	C7420B	2878 946664	ANNA MAKSIMOVA	{"phone": "+70786786674"}
0005433251962	C7420B	4342 627770	VLADIMIR KISELEV	{"phone": "+70620809448"}
0005433251963	3A28A5	2423 275080	ALEKSANDR KAZAKOV	{"email": "kazakov-a-01061967@postgrespro.ru", "phone": "+70755830125"}
0005433251964	3A28A5	1649 634405	VALENTINA KAZAKOVA	{"phone": "+70412327291"}
0005433251965	73D5DE	4175 761298	VIKTORIYA POTAPOVA	{"email": "viktoriyapotapova081972@postgrespro.ru", "phone": "+70089846692"}
0005433251966	9F1E37	8017 952467	MARIYA VASILEVA	{"phone": "+70670972855"}
0005433251967	31A854	0741 396543	YULIYA EFREMOVA	{"email": "y.efremova_20081974@postgrespro.ru", "phone": "+70916300075"}
0005433251968	A1FA96	6143 888460	VITALIY DMITRIEV	{"email": "dmitriev_vitaliy_20121986@postgrespro.ru", "phone": "+70550259101"}
0005433251969	CE5E5A	5168 963487	DMITRIY PETROV	{"phone": "+70885246931"}
0005433251970	CE5E5A	1312 409345	ELIZAVETA SMIRNOVA	{"email": "smirnovaelizaveta1964@postgrespro.ru", "phone": "+70649057358"}
0005433251971	80D9B5	4070 805343	ANNA PETROVA	{"email": "a_petrova.1978@postgrespro.ru", "phone": "+70920791982"}
0005433251972	217FF5	2392 693022	EVGENIY FILIPPOV	{"phone": "+70561905608"}
0005433251973	217FF5	9779 816663	EVGENIY KAZAKOV	{"email": "kazakovevgeniy-101959@postgrespro.ru", "phone": "+70403384293"}
0005433251974	520D10	2661 717475	ANDREY MOROZOV	{"phone": "+70528897831"}
0005433251975	C77937	5119 101801	RAMIL ALEKSEEV	{"email": "r-alekseev1962@postgrespro.ru", "phone": "+70283873681"}
0005433251976	D486B0	2171 222306	NIKOLAY BORISOV	{"phone": "+70516622755"}
0005433251977	657DA1	7915 158696	ANTONINA MOROZOVA	{"email": "morozova.antonina-011969@postgrespro.ru", "phone": "+70621011624"}
0005433251978	657DA1	1282 676288	ALEKSEY NAZAROV	{"email": "nazarov.a_1974@postgrespro.ru", "phone": "+70013329710"}
0005433251979	73956F	2115 770432	NELYA POTAPOVA	{"email": "nelya-potapova_071980@postgrespro.ru", "phone": "+70976338786"}
0005433251980	E7F362	4583 583220	TAMARA FILATOVA	{"phone": "+70452923470"}
0005433251981	104628	9533 350165	OLGA KUZNECOVA	{"email": "kuznecova.olga09101966@postgrespro.ru", "phone": "+70230986116"}
0005433251982	28079E	6482 784966	KSENIYA KISELEVA	{"phone": "+70651800609"}
0005433251983	42E6F8	9350 945408	ELENA SIDOROVA	{"phone": "+70597712413"}
0005433252097	147215	9309 905543	SERGEY BORISOV	{"phone": "+70574563295"}
0005433251984	42E6F8	0970 657614	SERGEY ALEKSEEV	{"email": "s_alekseev.011977@postgrespro.ru", "phone": "+70804197723"}
0005433251985	42E6F8	1900 664958	NIKOLAY KUZNECOV	{"phone": "+70446027499"}
0005433251986	72F482	3875 649040	IRINA BARANOVA	{"phone": "+70915569758"}
0005433251987	163C28	5712 251528	EMIL BONDARENKO	{"phone": "+70602766121"}
0005433251988	239F7A	5304 077478	ANVAR KUZNECOV	{"phone": "+70884611186"}
0005433251989	839C4B	8914 444474	MARIYA SOLOVEVA	{"phone": "+70059729428"}
0005433251990	31476E	1141 971222	YURIY MAKAROV	{"email": "makarovyuriy_1962@postgrespro.ru", "phone": "+70190378017"}
0005433251991	0CAA05	2058 194882	SERGEY PETROV	{"phone": "+70692252898"}
0005433251992	C11721	9480 595227	OLEG KUZMIN	{"email": "okuzmin-1969@postgrespro.ru", "phone": "+70676898679"}
0005433251993	C11721	4498 346612	ALEKSEY FEDOROV	{"phone": "+70464060682"}
0005433251994	B8116F	4882 067940	ANNA SOLOVEVA	{"email": "soloveva-anna.1968@postgrespro.ru", "phone": "+70289842215"}
0005433251995	B8116F	1707 559744	LYUBOV VASILEVA	{"phone": "+70887992380"}
0005433251996	16366C	4197 617132	VITALIY DAVYDOV	{"email": "vitaliydavydov-1967@postgrespro.ru", "phone": "+70145626270"}
0005433251997	BC1DC5	4009 189634	IVAN BELOV	{"phone": "+70055906895"}
0005433251998	BC1DC5	4531 044361	ARTEM AFANASEV	{"phone": "+70661386594"}
0005433251999	3B5ADB	6038 597669	NATALYA LAZAREVA	{"phone": "+70267701277"}
0005433252000	E53786	7253 814638	DMITRIY BELOV	{"phone": "+70735701793"}
0005433252001	F68F0A	1655 988811	VALERIY BONDARENKO	{"email": "v_bondarenko.19061978@postgrespro.ru", "phone": "+70708370001"}
0005433252002	6F0545	6756 492209	NATALYA NOVIKOVA	{"phone": "+70947925925"}
0005433252003	B0248C	4958 870341	SERGEY SOLOVEV	{"email": "s_solovev.1962@postgrespro.ru", "phone": "+70300224133"}
0005433252004	408AB3	1849 601785	RIMMA KOLESNIKOVA	{"email": "rimma_kolesnikova-1973@postgrespro.ru", "phone": "+70142274684"}
0005433252005	963767	3465 900616	LIDIYA OSIPOVA	{"phone": "+70498067029"}
0005433252006	811AF2	3030 782871	EKATERINA SOLOVEVA	{"email": "esoloveva.20011966@postgrespro.ru", "phone": "+70619431706"}
0005433252007	811AF2	6842 334769	TAMARA TARASOVA	{"email": "t_tarasova.021973@postgrespro.ru", "phone": "+70865433771"}
0005433252008	A35681	8627 416647	PAVEL POPOV	{"email": "popov-p-081972@postgrespro.ru", "phone": "+70119096275"}
0005433252009	18EDDE	6906 982579	NIKOLAY MEDVEDEV	{"phone": "+70295443724"}
0005433252010	18EDDE	0801 311601	NIKITA STEPANOV	{"email": "stepanovnikita01081953@postgrespro.ru", "phone": "+70432904113"}
0005433252011	15011D	9568 466993	ALEKSANDRA ISAEVA	{"phone": "+70310503950"}
0005433252012	2072AA	9081 124137	YULIYA BORISOVA	{"phone": "+70470886267"}
0005433252013	2072AA	0667 105160	VLADIMIR GERASIMOV	{"email": "gerasimov.vladimir_1970@postgrespro.ru", "phone": "+70262710759"}
0005433252014	2072AA	2703 887119	ANNA POTAPOVA	{"phone": "+70550319062"}
0005433252015	362CF1	6898 865727	SERGEY CHERNOV	{"phone": "+70020795505"}
0005433252016	362CF1	4920 988267	ANTON GORBUNOV	{"phone": "+70458105782"}
0005433252017	F3BA56	1268 471842	ELENA YUDINA	{"phone": "+70789608712"}
0005433252018	E80913	5861 330496	EVGENIYA BORISOVA	{"phone": "+70163183615"}
0005433252019	A5A03C	2579 078349	VIOLETTA ARKHIPOVA	{"phone": "+70140521474"}
0005433252020	D2EBE8	6285 205424	NINA GRISHINA	{"phone": "+70375984063"}
0005433252021	DAAC2E	8172 272829	ANASTASIYA MIRONOVA	{"phone": "+70669903531"}
0005433252022	207111	7048 964792	EGOR GUSEV	{"email": "gusev-e_01061965@postgrespro.ru", "phone": "+70596027806"}
0005433252023	855464	7865 456155	EVDOKIYA POLYAKOVA	{"email": "polyakova_evdokiya-1970@postgrespro.ru", "phone": "+70465523603"}
0005433252024	5777B1	4942 297948	DMITRIY ZAYCEV	{"email": "dmitriy-zaycev_1973@postgrespro.ru", "phone": "+70273360845"}
0005433252025	811CF2	7282 972306	SVETLANA NESTEROVA	{"phone": "+70181744259"}
0005433252026	FEF4A0	3988 351480	NADEZHDA FILIPPOVA	{"email": "nadezhdafilippova-05101970@postgrespro.ru", "phone": "+70677763727"}
0005433252027	A21A5B	5143 995245	EVGENIY OSIPOV	{"phone": "+70921906318"}
0005433252028	B11181	1849 825060	ANASTASIYA TIMOFEEVA	{"email": "timofeevaanastasiya.12031975@postgrespro.ru", "phone": "+70705162742"}
0005433252029	0B3F72	4323 033079	OLGA GUSEVA	{"email": "olgaguseva22121974@postgrespro.ru", "phone": "+70401258505"}
0005433252030	52C29E	9755 474258	OLGA FILIPPOVA	{"phone": "+70285372563"}
0005433252031	52C29E	1334 200298	DMITRIY KOROLEV	{"email": "korolev_d-23091986@postgrespro.ru", "phone": "+70717620463"}
0005433252032	9E7E0D	1876 692975	PAVEL SHEVCHENKO	{"email": "shevchenko-p061977@postgrespro.ru", "phone": "+70550463493"}
0005433252033	B0C03E	9383 870495	NIKOLAY MATVEEV	{"email": "matveev-nikolay1983@postgrespro.ru", "phone": "+70733613576"}
0005433252034	0CC78B	0879 488371	ANASTASIYA LOGINOVA	{"phone": "+70309722277"}
0005433252035	DBA123	2981 679109	VALERIY SEMENOV	{"email": "semenov-valeriy_1981@postgrespro.ru", "phone": "+70101627958"}
0005433252036	A1E527	0648 196229	ALEKSANDR KRASNOV	{"phone": "+70047132189"}
0005433252037	A1E527	5455 878610	VLADIMIR KOROLEV	{"phone": "+70124133116"}
0005433252038	A1E527	0639 899224	ANNA SERGEEVA	{"email": "anna_sergeeva.1971@postgrespro.ru", "phone": "+70616820001"}
0005433252039	08387C	7228 304645	PETR ZAYCEV	{"phone": "+70312535082"}
0005433252040	08387C	6529 131914	TATYANA KUDRYASHOVA	{"phone": "+70481463042"}
0005433252041	951A70	5996 868166	VLADIMIR VOROBEV	{"email": "vorobev-vladimir-1976@postgrespro.ru", "phone": "+70240573029"}
0005433252042	951A70	8900 725957	VALENTINA KUZNECOVA	{"phone": "+70580438458"}
0005433252043	E43115	4600 094950	VLADIMIR VOLKOV	{"email": "volkov_v-081984@postgrespro.ru", "phone": "+70854532953"}
0005433252044	E43115	8290 696588	ALEKSANDRA AFANASEVA	{"phone": "+70535786520"}
0005433252045	7B748B	3889 543427	IRINA KOMAROVA	{"phone": "+70886956217"}
0005433252046	76788D	1853 202768	ANDREY SOKOLOV	{"email": "sokolov_andrey091973@postgrespro.ru", "phone": "+70630801603"}
0005433252047	76788D	6877 980480	IRINA KULIKOVA	{"email": "irina-kulikova-15011968@postgrespro.ru", "phone": "+70614326066"}
0005433252048	EF4319	8326 482700	GENNADIY NIKOLAEV	{"phone": "+70298618299"}
0005433252049	312F20	2592 541654	ARTEMIY NOVIKOV	{"phone": "+70248589090"}
0005433252050	312F20	0076 834274	MAKSIM SHEVCHENKO	{"phone": "+70040485208"}
0005433252051	312F20	1968 910011	LARISA ABRAMOVA	{"email": "l.abramova-121962@postgrespro.ru", "phone": "+70075225207"}
0005433252052	A0F0B4	2146 866607	SERGEY MAKAROV	{"email": "makarov-sergey091976@postgrespro.ru", "phone": "+70727825434"}
0005433252053	0C0C2A	7107 045664	VALENTIN EGOROV	{"phone": "+70043081535"}
0005433252054	CA6974	5779 944309	MARIYA KONOVALOVA	{"email": "konovalova_m-061983@postgrespro.ru", "phone": "+70378842435"}
0005433252055	3F1DF6	0416 222267	TATYANA GAVRILOVA	{"email": "gavrilova-tatyana.1967@postgrespro.ru", "phone": "+70707635561"}
0005433252056	3F1DF6	7967 635099	OLGA LUKYANOVA	{"phone": "+70093552511"}
0005433252057	3F1DF6	9732 304707	BOGDAN NIKOLAEV	{"email": "b.nikolaev.111972@postgrespro.ru", "phone": "+70420763947"}
0005433252058	AC31B5	1067 255162	NADEZHDA TIKHONOVA	{"phone": "+70825715647"}
0005433252059	303859	0347 132985	GLEB IVANOV	{"email": "ivanovg11011976@postgrespro.ru", "phone": "+70467602983"}
0005433252060	B4AE78	8273 940991	ALEKSANDRA BELOVA	{"email": "belova.aleksandra101975@postgrespro.ru", "phone": "+70594200388"}
0005433252061	874489	3935 399936	GALINA FEDOROVA	{"phone": "+70361009139"}
0005433252243	02DC60	3503 219714	IGOR PAVLOV	{"phone": "+70350379007"}
0005433252062	874489	9397 019610	SEMEN KUZNECOV	{"email": "kuznecov_semen-011965@postgrespro.ru", "phone": "+70668503570"}
0005433252063	837837	4743 726806	NATALYA MAKAROVA	{"phone": "+70346359805"}
0005433252064	AD67D0	6776 401820	EKATERINA MIRONOVA	{"phone": "+70606898222"}
0005433252065	AD67D0	7009 245531	ANDREY BARANOV	{"email": "baranov-a03071966@postgrespro.ru", "phone": "+70710412492"}
0005433252066	12EE13	7508 687538	DARYA SERGEEVA	{"phone": "+70313567454"}
0005433252067	8F799D	7605 897947	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin-17121973@postgrespro.ru", "phone": "+70295428180"}
0005433252068	8F799D	4079 977657	ELENA GRISHINA	{"email": "egrishina.19081966@postgrespro.ru", "phone": "+70319334568"}
0005433252069	45CFBA	3659 539530	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr_121971@postgrespro.ru", "phone": "+70436849605"}
0005433252070	2A7548	2948 318322	KLAVDIYA MELNIKOVA	{"email": "melnikova-klavdiya.28081972@postgrespro.ru", "phone": "+70388950695"}
0005433252071	2A7548	8178 767579	ANNA KOVALEVA	{"email": "kovaleva-a_11111980@postgrespro.ru", "phone": "+70684989516"}
0005433252072	20912C	6704 826595	ANGELINA KOROLEVA	{"email": "koroleva_a-10101975@postgrespro.ru", "phone": "+70303705386"}
0005433252073	23FC3A	3056 024027	ANNA BELOVA	{"email": "a_belova.30121970@postgrespro.ru", "phone": "+70693375503"}
0005433252074	41C684	8321 500443	MARIYA DMITRIEVA	{"email": "dmitrieva-mariya1983@postgrespro.ru", "phone": "+70829022889"}
0005433252075	6F9525	5084 103377	MARGARITA BOGDANOVA	{"phone": "+70797991794"}
0005433252076	1A8091	3223 474154	VALENTINA KUZNECOVA	{"phone": "+70999191931"}
0005433252077	CCFD09	5237 387325	GALINA SEMENOVA	{"phone": "+70140851912"}
0005433252078	E362CD	2081 679607	RAISA TIKHONOVA	{"email": "raisa_tikhonova.1972@postgrespro.ru", "phone": "+70179919216"}
0005433252079	6DA217	8139 100271	ALEKSEY SAVELEV	{"email": "aleksey_savelev011970@postgrespro.ru", "phone": "+70291093996"}
0005433252080	94BDB9	0990 839860	MAKSIM ANTONOV	{"email": "m.antonov_1980@postgrespro.ru", "phone": "+70745593453"}
0005433252081	6F6D2A	8707 511467	GALINA ANDREEVA	{"email": "andreeva_galina041964@postgrespro.ru", "phone": "+70699164980"}
0005433252082	6F6D2A	5363 207862	MARINA ROMANOVA	{"phone": "+70614256231"}
0005433252083	1DDA1F	5697 761010	DMITRIY KUZNECOV	{"email": "dkuznecov_1980@postgrespro.ru", "phone": "+70991169940"}
0005433252084	1DDA1F	2950 284602	ANATOLIY TIKHONOV	{"phone": "+70223024043"}
0005433252085	09B156	0347 793255	NADEZHDA NIKIFOROVA	{"email": "n.nikiforova_11021985@postgrespro.ru", "phone": "+70673781815"}
0005433252086	E7C429	7189 214927	MARAT YAKOVLEV	{"phone": "+70933680434"}
0005433252087	69F832	2238 766953	IRINA MARTYNOVA	{"phone": "+70970337353"}
0005433252088	69F832	3340 044377	LYUBOV FEDOROVA	{"email": "fedorova-lyubov-031976@postgrespro.ru", "phone": "+70974335864"}
0005433252089	AB70EE	4778 804043	ANNA EGOROVA	{"phone": "+70618228108"}
0005433252090	5434C2	4948 246597	VIKTOR MOISEEV	{"phone": "+70939088781"}
0005433252091	5434C2	6821 129209	MIKHAIL ABRAMOV	{"email": "m.abramov21041969@postgrespro.ru", "phone": "+70557238519"}
0005433252092	BD9D04	1040 047006	ANDREY NIKITIN	{"phone": "+70991243438"}
0005433252093	86CC37	5224 850488	EVGENIY IVANOV	{"phone": "+70128041610"}
0005433252094	9300AC	4743 297845	YAROSLAV VASILEV	{"phone": "+70130094296"}
0005433252095	9300AC	3157 521543	EVGENIYA ZHUKOVA	{"email": "zhukova-e_111968@postgrespro.ru", "phone": "+70452884472"}
0005433252096	6453DD	5555 233405	ALEVTINA ANTONOVA	{"phone": "+70657197564"}
0005433252098	512EA1	7167 806422	VIKTOR PETROV	{"phone": "+70233731819"}
0005433252099	512EA1	1400 927492	KARINA PETROVA	{"email": "karina-petrova-06061969@postgrespro.ru", "phone": "+70136069321"}
0005433252100	EAD9A3	8118 451635	TATYANA ORLOVA	{"phone": "+70569244083"}
0005433252101	FF913C	5014 733528	GRIGORIY GAVRILOV	{"email": "ggavrilov-1983@postgrespro.ru", "phone": "+70316324148"}
0005433252102	EDBA77	3140 021779	NIKITA AFANASEV	{"email": "afanasev.nikita_091978@postgrespro.ru", "phone": "+70825586342"}
0005433252103	EDBA77	3226 959029	MARIYA ROMANOVA	{"phone": "+70459080022"}
0005433252104	1CC8C3	8072 185001	IGOR NIKITIN	{"email": "i.nikitin-03051981@postgrespro.ru", "phone": "+70968412575"}
0005433252105	1CC8C3	6258 829012	IGOR TIMOFEEV	{"phone": "+70135174435"}
0005433252106	93168F	4550 216559	VLADISLAV KOROLEV	{"email": "v.korolev071969@postgrespro.ru", "phone": "+70306902801"}
0005433252107	93168F	7746 580430	TATYANA DMITRIEVA	{"phone": "+70545090938"}
0005433252108	B3AB30	9154 786544	ALEKSANDRA MOROZOVA	{"phone": "+70622011989"}
0005433252109	B3AB30	1652 271934	DMITRIY MAKSIMOV	{"phone": "+70904591578"}
0005433252110	3F014C	6265 401040	LYUDMILA POLYAKOVA	{"email": "lpolyakova_03121977@postgrespro.ru", "phone": "+70620970214"}
0005433252111	3F014C	4080 382801	ANNA KOLESNIKOVA	{"phone": "+70661448785"}
0005433252112	9E2D55	6976 346384	OLGA SIDOROVA	{"email": "sidorova-olga_08121974@postgrespro.ru", "phone": "+70182697296"}
0005433252113	9E2D55	8475 188539	NINA DMITRIEVA	{"phone": "+70020994887"}
0005433252114	E436AA	0030 078611	ANNA KOVALEVA	{"email": "anna_kovaleva-1972@postgrespro.ru", "phone": "+70527560612"}
0005433252115	CA95DC	0726 217002	GALINA SOKOLOVA	{"phone": "+70747005281"}
0005433252116	CA95DC	5006 003729	SERGEY ALEKSANDROV	{"email": "aleksandrov_s19061965@postgrespro.ru", "phone": "+70765943477"}
0005433252117	690717	0016 004208	VALERIYA IVANOVA	{"email": "ivanovav-26011971@postgrespro.ru", "phone": "+70973777499"}
0005433252118	8E9974	2484 614392	LYUBOV SERGEEVA	{"phone": "+70111243132"}
0005433252119	EB890C	7851 635504	VASILIY PETROV	{"email": "v_petrov_041967@postgrespro.ru", "phone": "+70251048300"}
0005433252120	A7C028	8966 370106	MARINA RYABOVA	{"phone": "+70337633284"}
0005433252121	C484C6	3432 024116	NATALYA AKIMOVA	{"phone": "+70371822892"}
0005433252122	DD674A	5220 384286	RAFIS POPOV	{"email": "popov-rafis.03031973@postgrespro.ru", "phone": "+70787889195"}
0005433252123	DD674A	6860 445812	ELENA BARANOVA	{"email": "elenabaranova021967@postgrespro.ru", "phone": "+70204552265"}
0005433252124	7B1A79	1453 559077	NINA KOROLEVA	{"email": "koroleva.n031977@postgrespro.ru", "phone": "+70032372081"}
0005433252125	15E092	0399 909424	DARINA ZAYCEVA	{"email": "zaycevad-071978@postgrespro.ru", "phone": "+70222235394"}
0005433252126	24A4D0	3145 672475	NINA EFIMOVA	{"email": "nina.efimova_041967@postgrespro.ru", "phone": "+70524863560"}
0005433252127	24A4D0	3929 595235	ANASTASIYA STEPANOVA	{"phone": "+70778921660"}
0005433252128	24A4D0	3449 355729	NATALIYA TIKHONOVA	{"phone": "+70962012709"}
0005433252129	7676C3	6392 856372	NATALYA PETROVA	{"email": "natalya.petrova25031972@postgrespro.ru", "phone": "+70489834578"}
0005433252130	BA4639	4573 183646	VSEVOLOD SOKOLOV	{"phone": "+70984310701"}
0005433252131	9E02CC	7997 967987	VITALIY IVANOV	{"email": "ivanov_v-12031974@postgrespro.ru", "phone": "+70063927578"}
0005433252132	66CF32	3169 572508	ANTON BONDARENKO	{"email": "anton_bondarenko-061970@postgrespro.ru", "phone": "+70740954827"}
0005433252133	229DF7	7033 647773	ALEKSANDR KRASNOV	{"phone": "+70840644989"}
0005433252134	D5D315	9629 880558	IGOR GUSEV	{"email": "igor.gusev27111972@postgrespro.ru", "phone": "+70295792410"}
0005433252135	2FD49C	5517 353230	VIKTOR MELNIKOV	{"phone": "+70498335009"}
0005433252136	2FD49C	2800 569656	ANDREY VASILEV	{"email": "vasilev_a1963@postgrespro.ru", "phone": "+70921506615"}
0005433252137	5E1CD2	2061 321345	GALINA IVANOVA	{"email": "galina.ivanova12011967@postgrespro.ru", "phone": "+70566016700"}
0005433252138	78A7C5	8092 497294	IRINA SERGEEVA	{"phone": "+70216043522"}
0005433252139	78A7C5	1780 145559	MARINA CHERNOVA	{"email": "marina.chernova-041975@postgrespro.ru", "phone": "+70771354278"}
0005433252140	3EFE28	3861 383426	IVAN MAKSIMOV	{"email": "maksimov.i.1988@postgrespro.ru", "phone": "+70012100100"}
0005433252141	3EFE28	6207 385424	VALENTINA OSIPOVA	{"email": "valentina-osipova_081967@postgrespro.ru", "phone": "+70609076778"}
0005433252142	8FBAA6	6148 781051	SERGEY GRIGOREV	{"phone": "+70892110350"}
0005433252143	5C9CEE	6305 719581	LIDIYA POPOVA	{"phone": "+70244668643"}
0005433252144	5C9CEE	4775 658610	VALENTINA KUZMINA	{"phone": "+70180603677"}
0005433252145	23F843	2262 490893	IVAN MARTYNOV	{"email": "martynov.i-091965@postgrespro.ru", "phone": "+70873143802"}
0005433252146	F8416C	8860 787421	ELENA MELNIKOVA	{"email": "melnikova_elena.17041981@postgrespro.ru", "phone": "+70680341451"}
0005433252147	F8416C	5399 067403	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev22101962@postgrespro.ru", "phone": "+70847703571"}
0005433252148	4C7602	2608 424276	YURIY GRIGOREV	{"email": "grigorev.y.081972@postgrespro.ru", "phone": "+70531576954"}
0005433252149	4C7602	9858 309802	PAVEL MARTYNOV	{"phone": "+70308413700"}
0005433252150	4C7602	5506 117275	VIKTOR NIKITIN	{"email": "viktor.nikitin1976@postgrespro.ru", "phone": "+70099252234"}
0005433252151	3C8AD4	9299 813839	SOFYA FEDOROVA	{"email": "fedorova_s.17011980@postgrespro.ru", "phone": "+70797650574"}
0005433252152	3C8AD4	0400 091745	OLGA POPOVA	{"phone": "+70143771417"}
0005433252153	81991D	0289 633025	SERGEY KUZNECOV	{"phone": "+70867005532"}
0005433252154	5CFC8C	3216 320717	ANASTASIYA ANISIMOVA	{"email": "anisimova_a.1963@postgrespro.ru", "phone": "+70492322431"}
0005433252155	5CFC8C	9851 653021	DARYA KOZLOVA	{"email": "kozlova-darya_1971@postgrespro.ru", "phone": "+70723383233"}
0005433252156	8C7987	5140 174132	DMITRIY SAVELEV	{"phone": "+70019603045"}
0005433252157	8C7987	8115 473983	VLADIMIR SERGEEV	{"phone": "+70671873010"}
0005433252158	6E7F19	7262 749454	ANGELINA GERASIMOVA	{"email": "a_gerasimova-111981@postgrespro.ru", "phone": "+70362240674"}
0005433252159	F34620	1042 663005	VLADIMIR TIKHONOV	{"phone": "+70097639336"}
0005433252160	FCF566	9992 774485	NIKITA FEDOROV	{"phone": "+70377618568"}
0005433252161	9AF1F0	4280 218730	SNEZHANA MAKAROVA	{"email": "makarovas.021974@postgrespro.ru", "phone": "+70824514072"}
0005433252162	DD5758	1436 573776	LYUDMILA KUZNECOVA	{"email": "kuznecoval06111978@postgrespro.ru", "phone": "+70944819701"}
0005433252163	DD5758	0773 422499	MAKSIM ORLOV	{"email": "orlov.m041975@postgrespro.ru", "phone": "+70844203521"}
0005433252164	01A8B4	5591 046187	SERGEY PAVLOV	{"email": "pavlov-s30071963@postgrespro.ru", "phone": "+70174421781"}
0005433252165	D723D4	0425 509689	TIMUR KONOVALOV	{"phone": "+70338439334"}
0005433252166	7614AE	0085 150352	IVAN RODIONOV	{"phone": "+70553713183"}
0005433252167	19CD67	3149 722300	VALERIY MIRONOV	{"email": "mironovvaleriy061981@postgrespro.ru", "phone": "+70847482372"}
0005433252168	6AF7D2	5067 565488	SERGEY MATVEEV	{"phone": "+70048297684"}
0005433252169	08DFFB	5895 424912	DMITRIY ABRAMOV	{"phone": "+70804377543"}
0005433252170	6F7300	2103 437576	VYACHESLAV PETROV	{"phone": "+70688883828"}
0005433252171	BDD4DB	6409 687959	RAMIL ALEKSANDROV	{"phone": "+70435559680"}
0005433252172	8DF12F	5336 033712	VSEVOLOD ZHUKOV	{"email": "vzhukov_11121973@postgrespro.ru", "phone": "+70216118640"}
0005433252173	BB06E4	9426 138515	ALEKSANDR POPOV	{"email": "a-popov_1983@postgrespro.ru", "phone": "+70528158869"}
0005433252174	45F1E8	6041 620977	SVETLANA CHERNOVA	{"phone": "+70042161620"}
0005433252175	F31D52	4487 954137	ALEKSANDRA POPOVA	{"email": "aleksandra.popova1965@postgrespro.ru", "phone": "+70131817403"}
0005433252176	75AA5B	6877 750789	GENNADIY KUDRYASHOV	{"phone": "+70186546533"}
0005433252177	8DFF0E	6811 989405	ELENA MELNIKOVA	{"phone": "+70797195589"}
0005433252178	478BB7	8026 141491	VERA FEDOROVA	{"email": "fedorova.vera.091966@postgrespro.ru", "phone": "+70904406304"}
0005433252179	5EA5F2	7498 812237	SERGEY ZAKHAROV	{"email": "zakharov.sergey.09091976@postgrespro.ru", "phone": "+70251431537"}
0005433252180	5EA5F2	3740 584625	ALINA KUZNECOVA	{"email": "alina.kuznecova-1964@postgrespro.ru", "phone": "+70780351442"}
0005433252181	ED18AA	1500 566616	ROMAN KUDRYASHOV	{"phone": "+70814315075"}
0005433252182	5E41B0	1328 976477	RAFAIL SOKOLOV	{"email": "sokolov.rafail.101976@postgrespro.ru", "phone": "+70830621319"}
0005433252183	6CF545	0156 327615	ANTONINA EGOROVA	{"phone": "+70322058499"}
0005433252184	6CF545	5727 122808	ALEKSEY SERGEEV	{"phone": "+70624280686"}
0005433252185	6CF545	7622 337805	OLGA AFANASEVA	{"email": "o_afanaseva1970@postgrespro.ru", "phone": "+70990624250"}
0005433252186	99C818	0766 537595	SERGEY NIKITIN	{"phone": "+70943167490"}
0005433252187	99C818	6782 863216	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova1973@postgrespro.ru", "phone": "+70549319704"}
0005433252188	160BE3	9538 265215	EKATERINA FADEEVA	{"phone": "+70664100249"}
0005433252189	A9DFA0	1936 344532	PAVEL IVANOV	{"email": "p_ivanov-021971@postgrespro.ru", "phone": "+70057140268"}
0005433252190	E195CD	9011 213758	ANNA STEPANOVA	{"email": "a.stepanova-1973@postgrespro.ru", "phone": "+70812971441"}
0005433252191	A3A09E	8492 611851	NINA TARASOVA	{"email": "tarasova.nina101977@postgrespro.ru", "phone": "+70206619906"}
0005433252192	CF93DE	8912 833216	EVGENIY SMIRNOV	{"phone": "+70054533215"}
0005433252193	CF93DE	0202 076122	ELENA CHERNOVA	{"phone": "+70584035439"}
0005433252194	D6ACE2	8436 658430	VALERIY PETROV	{"email": "petrov.v.091972@postgrespro.ru", "phone": "+70231091784"}
0005433252195	2B34AA	7298 362163	ILNUR MOROZOV	{"email": "morozov.ilnur1979@postgrespro.ru", "phone": "+70987918883"}
0005433252196	2B34AA	3326 038388	ANNA KARPOVA	{"phone": "+70197544529"}
0005433252197	2B34AA	7960 590145	VALERIY KUZNECOV	{"email": "kuznecovvaleriy.1994@postgrespro.ru", "phone": "+70045072772"}
0005433252198	CE384B	7093 217321	KONSTANTIN MAKAROV	{"phone": "+70911239462"}
0005433252199	CC634C	5543 761806	ALEKSANDRA ILINA	{"email": "ilina-aleksandra_1989@postgrespro.ru", "phone": "+70801914795"}
0005433252200	CC634C	5424 793956	ALEKSANDR KUDRYASHOV	{"email": "aleksandrkudryashov1966@postgrespro.ru", "phone": "+70909525233"}
0005433252201	88FC28	5015 340860	DARYA MATVEEVA	{"phone": "+70780635245"}
0005433252202	EC6F76	6764 876439	ELINA SMIRNOVA	{"email": "smirnovae-29101976@postgrespro.ru", "phone": "+70869996556"}
0005433252203	F1AF22	0509 287688	OLEG EGOROV	{"email": "egorovo_30121970@postgrespro.ru", "phone": "+70976678991"}
0005433252204	25A40D	5999 436279	SVETLANA SOKOLOVA	{"phone": "+70755776155"}
0005433252205	25A40D	7250 627327	NIKITA KOZLOV	{"email": "kozlovn.031976@postgrespro.ru", "phone": "+70696158674"}
0005433252206	322332	1982 549756	SERGEY FROLOV	{"phone": "+70544798515"}
0005433252207	322332	8111 092659	ANATOLIY NIKOLAEV	{"email": "nikolaev-anatoliy_18081965@postgrespro.ru", "phone": "+70219056545"}
0005433252208	BCFFBF	1035 593703	VERA KAZAKOVA	{"phone": "+70913628755"}
0005433252209	BCFFBF	9950 661723	ALEKSANDR KUZMIN	{"email": "akuzmin.1967@postgrespro.ru", "phone": "+70897269519"}
0005433252210	F09600	3174 194487	SERGEY MELNIKOV	{"phone": "+70175518837"}
0005433252211	72C50D	8357 143877	OLGA BORISOVA	{"phone": "+70435679221"}
0005433252212	92669E	5831 379959	ANNA BORISOVA	{"email": "anna-borisova-13091980@postgrespro.ru", "phone": "+70342572767"}
0005433252213	0AD164	7942 003745	VLADIMIR KUZMIN	{"phone": "+70794839922"}
0005433252214	C95882	6234 609243	OLEG ROMANOV	{"email": "o-romanov-061964@postgrespro.ru", "phone": "+70388513375"}
0005433252215	302B51	2770 213767	ANATOLIY KOZLOV	{"phone": "+70268259957"}
0005433252216	302B51	4532 271254	VALENTINA KOMAROVA	{"email": "komarova-v051972@postgrespro.ru", "phone": "+70382536490"}
0005433252217	35792F	3587 425381	NADEZHDA MAKAROVA	{"email": "nadezhdamakarova_1968@postgrespro.ru", "phone": "+70568619769"}
0005433252218	41FBAB	3973 378272	ALEKSEY SHEVCHENKO	{"phone": "+70920987089"}
0005433252219	FCDF18	0601 518223	ANASTASIYA OVCHINNIKOVA	{"phone": "+70292189077"}
0005433252220	76D0B5	1938 845808	IGOR SOROKIN	{"phone": "+70764544646"}
0005433252221	76D0B5	3101 689028	ANASTASIYA POPOVA	{"email": "popova.a-1977@postgrespro.ru", "phone": "+70317993131"}
0005433252222	441A6F	1258 114990	MATVEY PAVLOV	{"phone": "+70605706684"}
0005433252223	2BC749	4110 904226	NINA KULIKOVA	{"phone": "+70687123380"}
0005433252224	266BFD	6285 890588	NIKOLAY POPOV	{"phone": "+70693782305"}
0005433252225	266BFD	9388 978020	ZINAIDA KISELEVA	{"email": "zinaida.kiseleva_1975@postgrespro.ru", "phone": "+70857755914"}
0005433252226	FE9761	2657 752659	FILIPP SOLOVEV	{"email": "solovev-f_121964@postgrespro.ru", "phone": "+70833577467"}
0005433252227	B35845	4361 278038	ILGIZ BELOV	{"phone": "+70389503417"}
0005433252228	5CB31A	5707 453683	NATALYA FROLOVA	{"phone": "+70098591321"}
0005433252229	EEBE92	4211 554791	NATALYA PAVLOVA	{"phone": "+70101073520"}
0005433252230	38C3B0	9157 309625	ALEKSEY KUZNECOV	{"phone": "+70839365718"}
0005433252231	38C3B0	9404 415678	IRINA DAVYDOVA	{"email": "davydovairina-1979@postgrespro.ru", "phone": "+70292251220"}
0005433252232	792A4E	1919 103840	KSENIYA BORISOVA	{"email": "borisova.kseniya.111973@postgrespro.ru", "phone": "+70549388800"}
0005433252233	CAFCE7	8310 063549	DMITRIY NIKITIN	{"phone": "+70129254064"}
0005433252234	502B97	4069 271089	SVETLANA FROLOVA	{"email": "svetlanafrolova1969@postgrespro.ru", "phone": "+70881242900"}
0005433252235	090DFF	3995 742673	YURIY NAZAROV	{"email": "nazarov.y-30051975@postgrespro.ru", "phone": "+70106822210"}
0005433252236	83CA19	8021 339727	VADIM ZAYCEV	{"email": "v-zaycev-12101981@postgrespro.ru", "phone": "+70035320781"}
0005433252237	214A57	2572 949179	SERGEY SIDOROV	{"phone": "+70632181581"}
0005433252238	9D5B95	4178 190831	ULYANA VOLKOVA	{"phone": "+70274503052"}
0005433252239	405804	1488 705007	VALENTINA CHERNOVA	{"phone": "+70753741125"}
0005433252240	405804	1124 101886	LYUDMILA MAKAROVA	{"phone": "+70842022108"}
0005433252241	3A4AD7	7276 535420	ANASTASIYA ISAEVA	{"email": "anastasiya.isaeva_1976@postgrespro.ru", "phone": "+70116726513"}
0005433252242	A8E568	9445 861418	SERGEY MAKAROV	{"email": "makarov-sergey.10021976@postgrespro.ru", "phone": "+70534310116"}
0005433252244	18C43B	7863 784296	ARTUR IVANOV	{"email": "artur_ivanov1967@postgrespro.ru", "phone": "+70916797013"}
0005433252245	34CB7A	4731 489800	ANDREY KOZLOV	{"email": "a.kozlov-03041974@postgrespro.ru", "phone": "+70806193597"}
0005433252246	5812A9	2228 140030	ELVIRA DENISOVA	{"email": "e_denisova.121981@postgrespro.ru", "phone": "+70359753516"}
0005433252247	BAE015	4907 246117	ANDREY MAKAROV	{"email": "makarov.andrey15081978@postgrespro.ru", "phone": "+70773813123"}
0005433252248	257AF5	7316 411591	ANTON NIKOLAEV	{"email": "a-nikolaev_1986@postgrespro.ru", "phone": "+70185150539"}
0005433252249	539D09	9923 998847	ANDREY NIKITIN	{"phone": "+70503582448"}
0005433252250	3DBDCB	5032 956668	MARIYA SEMENOVA	{"phone": "+70313634843"}
0005433252251	3DBDCB	4024 707538	TATYANA SIDOROVA	{"phone": "+70694823917"}
0005433252252	ED8C78	2392 101440	YULIYA MAKAROVA	{"email": "makarova-yuliya031972@postgrespro.ru", "phone": "+70108992295"}
0005433252253	09421C	8782 952354	NADEZHDA MAKAROVA	{"phone": "+70394738058"}
0005433252254	80CED7	5003 053179	SERGEY ZHUKOV	{"phone": "+70173208476"}
0005433252255	C9A56B	1183 041766	VYACHESLAV VLASOV	{"email": "v-vlasov-011982@postgrespro.ru", "phone": "+70496148606"}
0005433252256	51DF4A	3641 903611	KIRILL NAUMOV	{"phone": "+70024926109"}
0005433252257	51DF4A	4213 597570	ALEKSANDR ZHURAVLEV	{"phone": "+70063731696"}
0005433252258	DA92C6	0863 391417	IRINA KUDRYASHOVA	{"email": "irinakudryashova11101982@postgrespro.ru", "phone": "+70020874895"}
0005433252259	DA92C6	3359 221377	KSENIYA ALEKSANDROVA	{"phone": "+70586527885"}
0005433252260	AA86F3	9789 956014	SERGEY PETROV	{"email": "petrovsergey.30091963@postgrespro.ru", "phone": "+70674437865"}
0005433252261	6B10FA	6494 409782	MAKSIM SCHERBAKOV	{"phone": "+70756180510"}
0005433252262	05AE59	0224 662193	VERA LOGINOVA	{"phone": "+70707488990"}
0005433252263	AF1829	0111 827021	ZULFIYA KOMAROVA	{"email": "komarova_z_1962@postgrespro.ru", "phone": "+70037941324"}
0005433252264	AF1829	6650 613407	MARIYA KOROLEVA	{"email": "mariyakoroleva_25041960@postgrespro.ru", "phone": "+70566104616"}
0005433252265	E61C01	1842 132081	GALINA GUSEVA	{"email": "g-guseva071970@postgrespro.ru", "phone": "+70126694525"}
0005433252266	E61C01	4081 454244	MARINA SEMENOVA	{"email": "m.semenova1973@postgrespro.ru", "phone": "+70789099777"}
0005433252267	E61C01	6318 083178	DAMIR IVANOV	{"email": "d-ivanov-07031969@postgrespro.ru", "phone": "+70891640866"}
0005433252268	C563F3	6946 752440	ALEKSEY KOZLOV	{"phone": "+70345039446"}
0005433252269	5B9F2B	3526 468563	TATYANA MATVEEVA	{"phone": "+70504859256"}
0005433252270	0377E4	7446 430767	NATALYA KARPOVA	{"email": "natalya_karpova.1973@postgrespro.ru", "phone": "+70106102001"}
0005433252271	A07EAD	8759 573241	EVGENIY POPOV	{"email": "e-popov31031963@postgrespro.ru", "phone": "+70267321894"}
0005433252272	A07EAD	7527 761453	PRASKOVYA AFANASEVA	{"phone": "+70867806641"}
0005433252273	1A079F	6774 457716	GALINA FILATOVA	{"phone": "+70554988297"}
0005433252274	693DF8	4424 704401	IRINA ROMANOVA	{"email": "romanovai1965@postgrespro.ru", "phone": "+70263549987"}
0005433252275	E07EB4	5140 445317	ALEKSANDR BELOV	{"phone": "+70958927153"}
0005433252276	E07EB4	7955 102302	LIDIYA DMITRIEVA	{"phone": "+70767272011"}
0005433252277	E07EB4	0284 090866	ALEKSANDR KARPOV	{"phone": "+70895908321"}
0005433252278	876B2D	9114 278387	NADEZHDA TITOVA	{"email": "nadezhda.titova-04051979@postgrespro.ru", "phone": "+70764004829"}
0005433252279	876B2D	6531 068769	VALENTIN GORBUNOV	{"email": "gorbunov.v_1973@postgrespro.ru", "phone": "+70335983938"}
0005433252280	E49F24	4461 052206	TATYANA YUDINA	{"phone": "+70147592970"}
0005433252281	5408D7	5607 365006	ILYA BELOV	{"phone": "+70071556347"}
0005433252282	4FA14C	4898 576471	ALEKSEY ANDREEV	{"email": "andreevaleksey-111971@postgrespro.ru", "phone": "+70528139287"}
0005433252283	ADEF33	0195 249218	VYACHESLAV PETROV	{"phone": "+70362550001"}
0005433252284	D9D477	7082 660078	ARKADIY KUZMIN	{"phone": "+70091930934"}
0005433252285	EF2A19	4593 706776	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr_24121965@postgrespro.ru", "phone": "+70200320109"}
0005433252286	70204C	1245 571944	NIKOLAY EGOROV	{"email": "egorov-n.011969@postgrespro.ru", "phone": "+70961279696"}
0005433252287	8DC440	9409 733666	ALEKSANDR POPOV	{"phone": "+70271423421"}
0005433252288	6BFEF4	5742 288358	VLADIMIR NIKITIN	{"email": "vnikitin.101974@postgrespro.ru", "phone": "+70165720062"}
0005433252289	FF37D7	9323 124114	RUFINA SERGEEVA	{"email": "sergeevar27091977@postgrespro.ru", "phone": "+70989141006"}
0005433252290	FF37D7	2651 053494	OLEG KUZMIN	{"phone": "+70475038937"}
0005433252291	135C52	5121 817536	ALFIYA TARASOVA	{"email": "alfiya-tarasova.1966@postgrespro.ru", "phone": "+70150920896"}
0005433252292	3B042A	4305 727847	TATYANA FADEEVA	{"email": "fadeevat_071970@postgrespro.ru", "phone": "+70038353195"}
0005433252293	75FE95	1089 446824	MARIYA TITOVA	{"email": "titova.mariya_1973@postgrespro.ru", "phone": "+70937423547"}
0005433252294	1B498A	3487 921196	OLGA YAKOVLEVA	{"email": "yakovleva_olga_091978@postgrespro.ru", "phone": "+70498744486"}
0005433252295	1B498A	9242 677452	ALEKSANDR FOMIN	{"email": "fomin.a-1956@postgrespro.ru", "phone": "+70569122193"}
0005433252296	58B66C	2336 655395	VLADIMIR KAZAKOV	{"phone": "+70302808020"}
0005433252297	CF49DC	9490 191628	NADEZHDA SAVELEVA	{"phone": "+70649812654"}
0005433252298	FEADDC	3331 538959	LARISA BELOVA	{"phone": "+70294622711"}
0005433252299	FEADDC	2941 121872	GENNADIY FROLOV	{"phone": "+70914455992"}
0005433252300	82CBD8	0112 652979	ALEKSANDR PAVLOV	{"phone": "+70699118845"}
0005433252301	82CBD8	0456 065326	DMITRIY SOROKIN	{"email": "dmitriy_sorokin-1979@postgrespro.ru", "phone": "+70219704631"}
0005433252302	82CBD8	8862 745254	VLADIMIR KUZNECOV	{"email": "kuznecov_v-30051968@postgrespro.ru", "phone": "+70924750883"}
0005433252303	4D04DD	5466 289012	BORIS ROMANOV	{"email": "romanov_boris_1962@postgrespro.ru", "phone": "+70243168429"}
0005433252304	490683	1227 803441	MIKHAIL STEPANOV	{"email": "mikhail-stepanov-19021967@postgrespro.ru", "phone": "+70913826610"}
0005433252305	D4C806	8777 504247	ALENA MELNIKOVA	{"email": "alena-melnikova.071977@postgrespro.ru", "phone": "+70953921169"}
0005433252306	7323CF	8969 934890	RUMIYA YAKOVLEVA	{"email": "r-yakovleva101963@postgrespro.ru", "phone": "+70819422685"}
0005433252307	7323CF	6328 543391	LYUBOV KOVALEVA	{"email": "kovaleval06121971@postgrespro.ru", "phone": "+70862401558"}
0005433252308	1AB394	3398 924087	IVAN SEMENOV	{"email": "i.semenov-1966@postgrespro.ru", "phone": "+70696354895"}
0005433252309	36CFEC	2118 337531	NIKOLAY MOROZOV	{"email": "morozov_nikolay.1970@postgrespro.ru", "phone": "+70441694187"}
0005433252310	36CFEC	2415 596610	VALENTINA IVANOVA	{"email": "ivanova.v_061971@postgrespro.ru", "phone": "+70337155205"}
0005433252311	E7D4B1	5391 947323	NIKITA GERASIMOV	{"email": "nikita.gerasimov.051969@postgrespro.ru", "phone": "+70934201853"}
0005433252312	DA1480	5523 091567	YURIY ZAKHAROV	{"email": "zakharovyuriy.1971@postgrespro.ru", "phone": "+70848145415"}
0005433252313	83EA60	6036 252440	ALEKSANDR FOMIN	{"phone": "+70718605808"}
0005433252314	ED34BA	9460 999207	ELENA DMITRIEVA	{"email": "elena_dmitrieva_18011975@postgrespro.ru", "phone": "+70167370739"}
0005433252315	C162E7	3426 221953	MARINA KAZAKOVA	{"email": "kazakovamarina29091973@postgrespro.ru", "phone": "+70038499864"}
0005433252316	DEFD1C	3027 643143	ELENA MELNIKOVA	{"email": "elena.melnikova111963@postgrespro.ru", "phone": "+70690880675"}
0005433252317	DBB1E5	5545 902221	OKSANA ABRAMOVA	{"email": "oksana_abramova-19051980@postgrespro.ru", "phone": "+70335779542"}
0005433252318	DBB1E5	8014 686249	GLEB KOROLEV	{"phone": "+70593467308"}
0005433252319	DC2E23	8498 444526	VLADIMIR NOVIKOV	{"email": "v_novikov.061974@postgrespro.ru", "phone": "+70956026206"}
0005433252320	305655	8055 499762	TATYANA SAVELEVA	{"phone": "+70984676833"}
0005433252321	968A6C	1100 899849	VLADIMIR KOZLOV	{"email": "kozlov-v.091979@postgrespro.ru", "phone": "+70099706853"}
0005433252322	7BE84A	5522 172770	MARIYA KRASNOVA	{"phone": "+70768049786"}
0005433252323	6D2EF0	7601 632099	SVETLANA SERGEEVA	{"email": "s_sergeeva.101956@postgrespro.ru", "phone": "+70776660751"}
0005433252324	B68F85	5345 865583	EKATERINA ZAKHAROVA	{"email": "e-zakharova24091973@postgrespro.ru", "phone": "+70786997673"}
0005433252325	B68F85	5748 218060	GALINA KUZNECOVA	{"email": "gkuznecova041974@postgrespro.ru", "phone": "+70783906381"}
0005433252326	16062C	0587 289110	VALENTINA LAZAREVA	{"phone": "+70982829520"}
0005433252327	D3ED1B	4777 313183	VIKTOR KRASNOV	{"phone": "+70194700638"}
0005433252328	03CC0D	9380 017888	TATYANA GAVRILOVA	{"email": "gavrilova_t051965@postgrespro.ru", "phone": "+70422971538"}
0005433252329	850AD7	6659 988024	ALEKSANDR ABRAMOV	{"phone": "+70215821423"}
0005433252330	E14155	8683 911445	IRINA VASILEVA	{"email": "irina_vasileva_071973@postgrespro.ru", "phone": "+70591449368"}
0005433252331	C31C62	7468 794316	ILYA MAKAROV	{"phone": "+70531588132"}
0005433252332	702D33	8874 035148	ANASTASIYA KRASNOVA	{"email": "krasnova_a-01121975@postgrespro.ru", "phone": "+70549652115"}
0005433252333	4A8520	2137 506297	ELENA NESTEROVA	{"phone": "+70954451119"}
0005433252334	4A8520	2910 534600	SERGEY ZAKHAROV	{"phone": "+70171476971"}
0005433252335	64F920	7397 907778	DMITRIY ZHUKOV	{"email": "d_zhukov_1967@postgrespro.ru", "phone": "+70143738975"}
0005433252336	567914	0868 994479	DARYA ZHUKOVA	{"phone": "+70160586746"}
0005433252337	D5DC32	6249 954189	VLADIMIR NAUMOV	{"phone": "+70843192497"}
0005433252338	E6296A	7808 264731	DMITRIY EGOROV	{"phone": "+70647836037"}
0005433252339	664D53	5501 946328	ARTEM NOVIKOV	{"email": "a_novikov_051973@postgrespro.ru", "phone": "+70713320178"}
0005433252340	2B8B75	4724 179069	KONSTANTIN MELNIKOV	{"email": "konstantin.melnikov-08081967@postgrespro.ru", "phone": "+70205141546"}
0005433252341	5094B4	6059 585471	TATYANA ISAEVA	{"phone": "+70036785049"}
0005433252342	5094B4	7404 406564	ANNA ZHUKOVA	{"email": "zhukovaa08111967@postgrespro.ru", "phone": "+70892133976"}
0005433252343	5094B4	0350 180657	ALEKSANDR KUDRYASHOV	{"phone": "+70702217376"}
0005433252344	053519	2225 828571	ALEKSANDR EGOROV	{"email": "aleksandr.egorov.08081987@postgrespro.ru", "phone": "+70490874909"}
0005433252345	77E2FF	0810 146483	MATVEY ZHURAVLEV	{"phone": "+70530610258"}
0005433252346	77E2FF	3462 045577	YULIYA KRASNOVA	{"phone": "+70242463118"}
0005433252347	B97828	9904 419537	TIMUR SEMENOV	{"phone": "+70288887798"}
0005433252348	6BF566	8412 174944	LYUDMILA ROMANOVA	{"phone": "+70206406474"}
0005433252349	6BF566	9967 627724	ALEKSEY NIKOLAEV	{"phone": "+70289611918"}
0005433252350	1A244C	0065 084410	DINA SOROKINA	{"phone": "+70000244028"}
0005433252351	790E82	6028 385717	OLGA GORBUNOVA	{"phone": "+70657042193"}
0005433252352	790E82	1451 077981	VALENTINA YAKOVLEVA	{"phone": "+70077194908"}
0005433252353	73B693	4112 344201	IGOR TARASOV	{"email": "tarasov-i.021970@postgrespro.ru", "phone": "+70333273956"}
0005433252354	35AEA4	1654 582763	IRINA POPOVA	{"email": "i_popova_1964@postgrespro.ru", "phone": "+70476404085"}
0005433252355	4C60F1	6845 883026	TAMARA KOROLEVA	{"email": "korolevat.101982@postgrespro.ru", "phone": "+70476235728"}
0005433252356	23C712	9910 470876	OLESYA TIKHONOVA	{"email": "olesya.tikhonova29031974@postgrespro.ru", "phone": "+70102764519"}
0005433252357	6F1C2E	8166 965944	KSENIYA KUZNECOVA	{"email": "kseniya-kuznecova-02051975@postgrespro.ru", "phone": "+70998635366"}
0005433252358	6DF0BC	7753 636908	TATYANA ANTONOVA	{"phone": "+70640680286"}
0005433252359	6DF0BC	1207 555670	ANNA SERGEEVA	{"email": "a_sergeeva-011972@postgrespro.ru", "phone": "+70183436590"}
0005433252360	96615A	0334 505603	ALBERT STEPANOV	{"phone": "+70265326924"}
0005433252361	11558F	0703 192260	VYACHESLAV EGOROV	{"phone": "+70090423314"}
0005433252362	6FCE93	4828 816645	SERGEY KUZNECOV	{"email": "kuznecov.s_1968@postgrespro.ru", "phone": "+70439043130"}
0005433252363	4B7784	7339 682108	VITALIY YAKOVLEV	{"email": "vitaliy-yakovlev-1974@postgrespro.ru", "phone": "+70897891387"}
0005433252364	4B7784	4953 011180	YULIYA NIKITINA	{"phone": "+70238664681"}
0005433252365	387B01	9799 816687	SERGEY BARANOV	{"email": "baranov-sergey_101979@postgrespro.ru", "phone": "+70075958471"}
0005433252366	7BC34B	5049 958199	MARIYA SCHERBAKOVA	{"phone": "+70620380691"}
0005433252367	93F81B	4311 994997	IRINA MOISEEVA	{"phone": "+70153372410"}
0005433252368	93F81B	5965 230878	VIKTOR PETROV	{"phone": "+70619033435"}
0005433252369	93F81B	9050 912917	MAKSIM VOLKOV	{"phone": "+70717762599"}
0005433252370	69B830	0666 286084	ELENA SIDOROVA	{"phone": "+70211193358"}
0005433252371	0DB56E	7577 494715	YURIY SEMENOV	{"email": "y.semenov-15041971@postgrespro.ru", "phone": "+70765105716"}
0005433252372	FD2095	4022 228141	IGOR GORBUNOV	{"phone": "+70008972920"}
0005433252373	2D367E	0493 671786	SERGEY ROMANOV	{"phone": "+70903819366"}
0005433252374	2D367E	9736 615319	GERMAN ILIN	{"email": "g_ilin-031966@postgrespro.ru", "phone": "+70447167448"}
0005433252375	829AD7	0011 967687	PETR IVANOV	{"email": "p_ivanov-1975@postgrespro.ru", "phone": "+70230919301"}
0005433252376	F8B301	9393 267091	DANIIL AFANASEV	{"email": "daniilafanasev-1976@postgrespro.ru", "phone": "+70295564751"}
0005433252377	F8B301	2894 025780	DENIS ILIN	{"phone": "+70082559343"}
0005433252378	931EE3	9263 886763	SVETLANA NIKOLAEVA	{"email": "snikolaeva1975@postgrespro.ru", "phone": "+70666748574"}
0005433252379	931EE3	7617 219672	TAISIYA NIKITINA	{"phone": "+70223600597"}
0005433252380	BB68CC	6789 181733	VALERIY ILIN	{"email": "ilin_valeriy20021961@postgrespro.ru", "phone": "+70705330682"}
0005433252381	3F566D	9459 840863	RUSLAN SERGEEV	{"phone": "+70449616012"}
0005433252382	3F566D	5918 895423	YULIYA VLASOVA	{"email": "vlasova.y_16101980@postgrespro.ru", "phone": "+70024678669"}
0005433252383	642098	5135 991710	VALERIY DMITRIEV	{"email": "dmitriev_v-1956@postgrespro.ru", "phone": "+70429245314"}
0005433252384	642098	8546 253385	ANDREY IVANOV	{"email": "ivanov.andrey13021966@postgrespro.ru", "phone": "+70411652965"}
0005433252385	F1BDD4	1705 669975	VYACHESLAV GAVRILOV	{"phone": "+70157330134"}
0005433252386	A9398C	6046 167516	VLADIMIR SMIRNOV	{"email": "smirnovvladimir28031985@postgrespro.ru", "phone": "+70220423422"}
0005433252387	A27CEE	0060 454691	LYUDMILA FILATOVA	{"email": "filatova-lyudmila.081976@postgrespro.ru", "phone": "+70693320415"}
0005433255021	864739	9068 194815	VLADIMIR MIRONOV	{"phone": "+70445305357"}
0005433255022	85ECD6	7856 061723	ANATOLIY GORBUNOV	{"email": "anatoliy_gorbunov-14091970@postgrespro.ru", "phone": "+70419161386"}
0005433255023	85ECD6	4624 465057	OLGA KONDRATEVA	{"email": "kondrateva-o.18081966@postgrespro.ru", "phone": "+70932035386"}
0005433255024	C6CCF4	8418 573219	VLADIMIR KUZNECOV	{"email": "kuznecov.v_08021971@postgrespro.ru", "phone": "+70781515889"}
0005433255025	C6CCF4	1416 349386	VALENTINA NIKITINA	{"phone": "+70232256250"}
0005433255026	ABACFE	0805 982996	KIRILL FILIPPOV	{"email": "kirillfilippov-1969@postgrespro.ru", "phone": "+70056414188"}
0005433255027	ABACFE	7169 766569	DANIIL IVANOV	{"phone": "+70738444353"}
0005433255028	51422B	5347 239966	EVGENIY KAZAKOV	{"phone": "+70711900008"}
0005433255029	362067	1050 400713	ALEKSANDR GUSEV	{"email": "aleksandrgusev.1973@postgrespro.ru", "phone": "+70391872353"}
0005433255030	533114	9339 181391	ALEKSEY KUZNECOV	{"email": "kuznecov.a.26031978@postgrespro.ru", "phone": "+70341271531"}
0005433255031	533114	8406 820132	ALENA SERGEEVA	{"email": "sergeeva.a_08021976@postgrespro.ru", "phone": "+70715483970"}
0005433255032	E12C95	3922 167072	YULIYA ZHUKOVA	{"email": "y.zhukova1970@postgrespro.ru", "phone": "+70237268222"}
0005433255033	0384A6	9131 734963	GALINA BELYAEVA	{"email": "g.belyaeva051975@postgrespro.ru", "phone": "+70784721615"}
0005433255034	0384A6	4730 128765	DARYA GERASIMOVA	{"email": "daryagerasimova_011973@postgrespro.ru", "phone": "+70226493770"}
0005433255035	891CCF	2904 261859	TATYANA NIKOLAEVA	{"email": "nikolaeva_t.01021970@postgrespro.ru", "phone": "+70347219683"}
0005433255036	E92D47	5949 507244	EVGENIY KUZNECOV	{"email": "kuznecov_e_01011976@postgrespro.ru", "phone": "+70037632373"}
0005433255037	FE01C5	2668 940558	ALEKSANDR ALEKSEEV	{"phone": "+70653086156"}
0005433255038	75F15C	5612 841187	IRINA VASILEVA	{"email": "irina-vasileva1960@postgrespro.ru", "phone": "+70117066074"}
0005433255039	D3AAF4	9195 295895	ALEKSEY KRASNOV	{"email": "akrasnov-15041956@postgrespro.ru", "phone": "+70464352476"}
0005433255040	D3AAF4	8192 497240	VALENTINA POTAPOVA	{"phone": "+70938448485"}
0005433255041	FE2586	5065 762983	GRIGORIY RODIONOV	{"phone": "+70949856471"}
0005433255042	FE2586	4689 250851	VALENTINA NAZAROVA	{"email": "valentina-nazarova_081975@postgrespro.ru", "phone": "+70542014104"}
0005433255043	D51773	8558 349277	LIDIYA PAVLOVA	{"phone": "+70783882669"}
0005433255044	E8E63A	2833 323637	NINA MASLOVA	{"phone": "+70172856958"}
0005433255045	F79597	0492 903642	NATALIYA FEDOROVA	{"phone": "+70645444687"}
0005433255046	F79597	1426 222192	DARYA KOZLOVA	{"email": "kozlovadarya091966@postgrespro.ru", "phone": "+70751114085"}
0005433255047	8A0FC1	8568 164858	OLGA ZAYCEVA	{"email": "zayceva_o28041961@postgrespro.ru", "phone": "+70040738556"}
0005433255048	E16FA4	3075 656558	ROMAN SAVELEV	{"phone": "+70519373009"}
0005433255049	08F456	3602 858208	ALEKSANDR ROMANOV	{"email": "a.romanov11091972@postgrespro.ru", "phone": "+70687491654"}
0005433255050	08F456	7638 313684	NIKOLAY ZAKHAROV	{"email": "zakharov-nikolay041972@postgrespro.ru", "phone": "+70594984394"}
0005433255051	021CD5	3193 521637	DMITRIY SERGEEV	{"email": "dmitriy-sergeev_1971@postgrespro.ru", "phone": "+70163020782"}
0005433255052	F3ACA5	9127 354383	YULIYA SOKOLOVA	{"email": "sokolovayuliya.121968@postgrespro.ru", "phone": "+70671359886"}
0005433255053	F3ACA5	4843 833138	MARIYA KUZNECOVA	{"phone": "+70679011649"}
0005433255054	DEF022	1315 628141	ELENA ANDREEVA	{"email": "andreeva-elena.1977@postgrespro.ru", "phone": "+70020781288"}
0005433255055	DEF022	3202 269830	SERGEY ANDREEV	{"email": "sergey_andreev_09071974@postgrespro.ru", "phone": "+70302036912"}
0005433255056	9B5F9D	4347 803477	DMITRIY KAZAKOV	{"phone": "+70676567314"}
0005433255057	29F373	1614 612936	PAVEL DENISOV	{"phone": "+70103668933"}
0005433255058	5936AE	4825 646137	TAMARA MAKSIMOVA	{"email": "maksimova.tamara1972@postgrespro.ru", "phone": "+70949897262"}
0005433255059	6A8CCF	1981 539600	ZINAIDA PETROVA	{"email": "z_petrova_17111965@postgrespro.ru", "phone": "+70109893551"}
0005433255060	FF2243	4381 745425	SERGEY NAZAROV	{"email": "sergeynazarov.23031971@postgrespro.ru", "phone": "+70267634334"}
0005433255061	D30F01	2861 803751	VITALIY MAKSIMOV	{"phone": "+70603379244"}
0005433255062	D30F01	3020 000723	LEONID VLASOV	{"phone": "+70177213009"}
0005433255063	D69434	6885 681903	EVGENIYA EFREMOVA	{"email": "efremova.evgeniya081969@postgrespro.ru", "phone": "+70712210144"}
0005433255064	3EADE7	1326 907564	EVGENIYA ANDREEVA	{"phone": "+70325739887"}
0005433255065	3EADE7	3513 231922	LYUDMILA BELYAEVA	{"email": "belyaeva_lyudmila.28071972@postgrespro.ru", "phone": "+70923187834"}
0005433255066	1A7DD4	0223 073225	SERGEY SCHERBAKOV	{"phone": "+70627178010"}
0005433255067	1A7DD4	3968 536261	ELENA MATVEEVA	{"email": "matveeva.elena-091982@postgrespro.ru", "phone": "+70141852780"}
0005433255068	1A7DD4	0421 037656	VLADIMIR ILIN	{"email": "ilin_vladimir.11071971@postgrespro.ru", "phone": "+70013990591"}
0005433255069	901115	5841 754176	ANDREY BONDARENKO	{"phone": "+70680659045"}
0005433255070	F6A361	1539 296981	ELENA MIKHAYLOVA	{"phone": "+70341908582"}
0005433255071	F6A361	1738 714017	ANNA SAVELEVA	{"email": "a_saveleva_021978@postgrespro.ru", "phone": "+70834719223"}
0005433255072	CEDFAC	3965 256711	NADEZHDA OSIPOVA	{"email": "nosipova121977@postgrespro.ru", "phone": "+70615459278"}
0005433255073	CA1085	7843 854152	NATALYA KUZNECOVA	{"phone": "+70372784808"}
0005433255074	CA1085	3929 955012	MARIYA ZAKHAROVA	{"email": "zakharova.mariya03101969@postgrespro.ru", "phone": "+70552062748"}
0005433255075	7528FB	8405 259495	ELIZAVETA NIKOLAEVA	{"email": "nikolaeva-e.1975@postgrespro.ru", "phone": "+70780536281"}
0005433255076	737D24	6732 127739	STANISLAV MELNIKOV	{"phone": "+70736512269"}
0005433255077	7255AB	8486 267534	ROZALIYA MAKAROVA	{"phone": "+70247725680"}
0005433255078	40E6DE	9443 960231	VIKTOR KRASNOV	{"email": "viktor.krasnov.09051979@postgrespro.ru", "phone": "+70842869927"}
0005433255079	05AFE6	5935 468294	SERGEY FOMIN	{"email": "fominsergey_07091969@postgrespro.ru", "phone": "+70310031246"}
0005433255080	E7B87E	7824 287738	VALENTINA ANTONOVA	{"email": "antonova.valentina_121974@postgrespro.ru", "phone": "+70345688038"}
0005433255081	E7B87E	4244 872792	TAMARA GORBUNOVA	{"phone": "+70275935649"}
0005433255082	E7B87E	6571 792598	GENNADIY SMIRNOV	{"phone": "+70759533258"}
0005433255083	E7B87E	1441 278306	TATYANA GORBUNOVA	{"phone": "+70775690608"}
0005433255084	58C5EC	4332 768239	ELENA MELNIKOVA	{"email": "elena-melnikova12061976@postgrespro.ru", "phone": "+70703298162"}
0005433255085	34742B	1931 656813	GALINA ALEKSANDROVA	{"email": "galeksandrova29071976@postgrespro.ru", "phone": "+70238764694"}
0005433255086	34742B	4112 260684	ELENA EFIMOVA	{"phone": "+70825927359"}
0005433255087	E5353A	5937 307608	VLADISLAV SOKOLOV	{"email": "sokolov.vladislav-101974@postgrespro.ru", "phone": "+70211123077"}
0005433255088	C4167A	6752 251388	NIKITA SOROKIN	{"phone": "+70989789650"}
0005433255089	2446FD	3798 725099	ZINAIDA FOMINA	{"email": "zinaida.fomina-021972@postgrespro.ru", "phone": "+70813465966"}
0005433255090	0870B2	1660 979843	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-031968@postgrespro.ru", "phone": "+70982507143"}
0005433255091	0870B2	6119 013776	VALENTINA ZHUKOVA	{"email": "valentina.zhukova.031969@postgrespro.ru", "phone": "+70635775144"}
0005433255092	0870B2	1908 242504	KSENIYA KARPOVA	{"email": "k-karpova_1963@postgrespro.ru", "phone": "+70808479320"}
0005433255093	003673	2305 419791	ANTON TIKHONOV	{"email": "anton.tikhonov-1968@postgrespro.ru", "phone": "+70182905729"}
0005433255094	003673	2796 831118	GALINA KRASNOVA	{"phone": "+70644253824"}
0005433255095	003673	2731 391150	VALENTINA KUZNECOVA	{"email": "vkuznecova07111967@postgrespro.ru", "phone": "+70513051655"}
0005433255096	003673	9083 474057	ALEKSANDR BORISOV	{"phone": "+70062374313"}
0005433255097	1FD932	1829 159496	GALINA KUZNECOVA	{"phone": "+70940877927"}
0005433255098	1FD932	8686 628043	GALINA TITOVA	{"email": "titova_g-1965@postgrespro.ru", "phone": "+70633742484"}
0005433255099	7037CE	8230 116113	OKSANA BARANOVA	{"phone": "+70175231452"}
0005433255100	9B95EB	8149 365918	VLADIMIR ANTONOV	{"phone": "+70308994819"}
0005433255101	370732	1513 217316	ALEKSEY FROLOV	{"email": "frolovaleksey-26061974@postgrespro.ru", "phone": "+70069955037"}
0005433255102	C731EA	5036 796304	OLGA SMIRNOVA	{"email": "smirnovao.1980@postgrespro.ru", "phone": "+70374729003"}
0005433255103	AB3571	4478 542907	TAISIYA SERGEEVA	{"email": "sergeevataisiya_14111976@postgrespro.ru", "phone": "+70699021350"}
0005433255104	AB3571	2687 144945	ANFISA SERGEEVA	{"phone": "+70004173708"}
0005433255105	137E2A	9853 108977	OLGA ARKHIPOVA	{"email": "olga-arkhipova06061967@postgrespro.ru", "phone": "+70019915814"}
0005433255106	1C2C5A	8461 242212	IRINA IVANOVA	{"phone": "+70011714570"}
0005433255107	AD43F1	6785 080535	VLADIMIR TARASOV	{"phone": "+70934837931"}
0005433255108	E55DD3	0117 391067	VALENTINA MOISEEVA	{"phone": "+70403682837"}
0005433255109	E55DD3	1247 790166	DMITRIY KUZNECOV	{"phone": "+70946358326"}
0005433255110	9DFCDE	5501 192104	ELENA MALYSHEVA	{"phone": "+70518518605"}
0005433255111	72EE3E	6079 309221	ILYAS GAVRILOV	{"phone": "+70014845068"}
0005433255112	A56D35	6977 471531	OLGA VOROBEVA	{"email": "olga.vorobeva_051978@postgrespro.ru", "phone": "+70177425686"}
0005433255113	A56D35	6617 818257	VIKTOR YAKOVLEV	{"email": "yakovlev_viktor-1978@postgrespro.ru", "phone": "+70191602380"}
0005433256451	849ADE	5177 334154	TAMARA MELNIKOVA	{"phone": "+70415511962"}
0005433255114	620B65	1500 219359	VLADIMIR SMIRNOV	{"email": "smirnov.v061967@postgrespro.ru", "phone": "+70354918642"}
0005433255115	A0B6A3	7627 019423	ANATOLIY KUZNECOV	{"email": "akuznecov.011975@postgrespro.ru", "phone": "+70830489436"}
0005433255116	D76B9B	4347 132072	OLGA KUZNECOVA	{"email": "olga_kuznecova.1956@postgrespro.ru", "phone": "+70981870443"}
0005433255117	D76B9B	5022 055203	OLGA FILIPPOVA	{"email": "o-filippova.011984@postgrespro.ru", "phone": "+70296835229"}
0005433255118	72ED6A	1806 921491	VIKTOR IVANOV	{"email": "ivanov_v.081983@postgrespro.ru", "phone": "+70484805528"}
0005433255119	72ED6A	3009 585255	VALERIY FEDOROV	{"phone": "+70086693429"}
0005433255120	1FAEAD	0895 136973	VLADIMIR MIKHAYLOV	{"phone": "+70143162595"}
0005433255121	1FAEAD	4968 747533	ROMAN POPOV	{"phone": "+70186154224"}
0005433255122	68E253	0455 414954	ELENA FILIPPOVA	{"phone": "+70691830924"}
0005433255123	39F66C	3555 684152	VLADISLAV AFANASEV	{"email": "v_afanasev_1978@postgrespro.ru", "phone": "+70882637513"}
0005433255124	39F66C	2214 177529	TAMARA FOMINA	{"phone": "+70712973574"}
0005433255125	C3F163	3898 760100	MARIYA GAVRILOVA	{"email": "gavrilova-m-011961@postgrespro.ru", "phone": "+70191746098"}
0005433255126	70711D	2892 666570	YURIY KISELEV	{"phone": "+70320951384"}
0005433255127	36047D	7844 059274	SERGEY SERGEEV	{"phone": "+70652545324"}
0005433255128	36047D	4283 698310	IRINA IVANOVA	{"email": "i.ivanova_1973@postgrespro.ru", "phone": "+70069812748"}
0005433255129	36047D	6833 935225	STANISLAV FEDOTOV	{"email": "sfedotov.011969@postgrespro.ru", "phone": "+70686536549"}
0005433255130	B73D70	6487 581736	LILIYA STEPANOVA	{"email": "liliya-stepanova29061977@postgrespro.ru", "phone": "+70151849282"}
0005433255131	B73D70	8603 527972	SERGEY GERASIMOV	{"phone": "+70845098530"}
0005433255132	8A8081	2793 199680	OLGA ZHUKOVA	{"email": "zhukovaolga-07091968@postgrespro.ru", "phone": "+70028618237"}
0005433255133	288D11	6774 686608	OLGA ZAKHAROVA	{"email": "zakharovao-1972@postgrespro.ru", "phone": "+70476855380"}
0005433255134	6A60E4	0867 528184	ANDREY PETROV	{"email": "petrovandrey-041980@postgrespro.ru", "phone": "+70548757578"}
0005433255135	A52824	3357 127739	VLADIMIR STEPANOV	{"email": "stepanov-vladimir07011959@postgrespro.ru", "phone": "+70452232543"}
0005433255136	65F1A5	0539 547491	ALEKSEY ZAYCEV	{"email": "a-zaycev-071966@postgrespro.ru", "phone": "+70727798963"}
0005433255137	65F1A5	6847 219774	DINARA SIDOROVA	{"email": "dinarasidorova17101974@postgrespro.ru", "phone": "+70303625899"}
0005433255138	DB3A0C	5268 446031	EKATERINA IVANOVA	{"phone": "+70225413834"}
0005433255139	B4DBEC	4436 462187	SERGEY ANTONOV	{"phone": "+70909224550"}
0005433255140	E7B119	0938 107368	GALIYA NAUMOVA	{"phone": "+70121872395"}
0005433255141	E7B119	0978 353095	VYACHESLAV NOVIKOV	{"email": "vyacheslav_novikov-1974@postgrespro.ru", "phone": "+70825199936"}
0005433255142	74B67B	7046 288304	SERGEY NOVIKOV	{"phone": "+70836729448"}
0005433255143	FAE578	5934 334316	ALEKSANDR ZAYCEV	{"phone": "+70487921601"}
0005433255144	FAE578	8298 040552	ANDREY FROLOV	{"email": "a.frolov021974@postgrespro.ru", "phone": "+70355779974"}
0005433255145	FAE578	6306 776141	EVGENIYA LUKYANOVA	{"phone": "+70987102014"}
0005433255146	E8FA32	9984 617445	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.s.051973@postgrespro.ru", "phone": "+70033408843"}
0005433255147	87ABE8	7897 828705	VASILIY PAVLOV	{"phone": "+70114184960"}
0005433255148	844151	2872 778986	NADEZHDA ZAYCEVA	{"email": "zaycevan.101975@postgrespro.ru", "phone": "+70138955001"}
0005433255149	844151	2410 596329	IRINA OSIPOVA	{"email": "irina-osipova_071981@postgrespro.ru", "phone": "+70666839423"}
0005433255150	90C5F8	3597 660813	DENIS ROMANOV	{"phone": "+70725489652"}
0005433255151	0C109C	0411 344967	ALEKSANDR TARASOV	{"email": "a_tarasov-31101967@postgrespro.ru", "phone": "+70874534151"}
0005433255152	0C109C	9297 702277	TATYANA MIRONOVA	{"email": "t.mironova_091977@postgrespro.ru", "phone": "+70876476384"}
0005433255153	B7C808	4145 727390	GALINA KUZNECOVA	{"email": "kuznecova.galina.051980@postgrespro.ru", "phone": "+70684821569"}
0005433255154	B90C39	2926 617187	ANNA MIKHAYLOVA	{"email": "mikhaylova-a.26071964@postgrespro.ru", "phone": "+70683871728"}
0005433255155	F40D56	3223 216379	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr_1972@postgrespro.ru", "phone": "+70383811372"}
0005433255156	718281	6308 540574	IRINA IVANOVA	{"email": "ivanova.irina081974@postgrespro.ru", "phone": "+70541848313"}
0005433255157	30E243	3037 744239	NATALYA GUSEVA	{"email": "guseva_natalya.1980@postgrespro.ru", "phone": "+70069642686"}
0005433255158	CF6335	7096 156093	RUZALIYA BOGDANOVA	{"email": "bogdanova.r_091974@postgrespro.ru", "phone": "+70366410671"}
0005433255159	4879EC	4330 464678	MARAT MELNIKOV	{"email": "melnikov.marat-14091974@postgrespro.ru", "phone": "+70161328486"}
0005433255160	482BCA	1902 595492	VIKTOR NOVIKOV	{"phone": "+70888691758"}
0005433255161	482BCA	9622 980832	PAVEL EGOROV	{"email": "pavel_egorov041963@postgrespro.ru", "phone": "+70847505315"}
0005433255162	482BCA	9986 368088	MIKHAIL ZHUKOV	{"phone": "+70499992241"}
0005433255163	8EF7A4	3075 890862	MIKHAIL GUSEV	{"email": "mikhail_gusev-1969@postgrespro.ru", "phone": "+70100649304"}
0005433255164	6EEC57	1995 241910	ALEKSEY EGOROV	{"email": "aleksey-egorov071969@postgrespro.ru", "phone": "+70246037095"}
0005433255165	6EEC57	9263 859512	INNA MARTYNOVA	{"phone": "+70761934793"}
0005433255166	0D769B	4366 765781	VITALIY ZAKHAROV	{"phone": "+70564711108"}
0005433255167	68CE8B	2945 065027	LYUDMILA GUSEVA	{"email": "gusevalyudmila-1972@postgrespro.ru", "phone": "+70567858727"}
0005433255168	533238	8228 147366	YULIYA NIKITINA	{"email": "nikitina-yuliya-25061963@postgrespro.ru", "phone": "+70380323042"}
0005433255169	079920	9120 241356	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr-021972@postgrespro.ru", "phone": "+70944566877"}
0005433255170	7B19E6	0385 275922	IVAN KUDRYASHOV	{"email": "ivan.kudryashov.081973@postgrespro.ru", "phone": "+70457955407"}
0005433261466	70A9B8	1415 217948	SOFYA AFANASEVA	{"phone": "+70993872705"}
0005433255171	FBB36A	8122 645185	ALEKSEY KAZAKOV	{"email": "kazakov_a_07011977@postgrespro.ru", "phone": "+70736401438"}
0005433255172	56A453	1947 357978	EKATERINA KULIKOVA	{"email": "kulikova_e.1969@postgrespro.ru", "phone": "+70319388929"}
0005433255173	56A453	1557 144887	NATALYA NOVIKOVA	{"email": "novikova_natalya-081978@postgrespro.ru", "phone": "+70263036973"}
0005433255174	425CD6	3723 267956	VALENTINA KOMAROVA	{"email": "vkomarova-121969@postgrespro.ru", "phone": "+70059178186"}
0005433255175	80E2E8	8109 267576	ELENA STEPANOVA	{"email": "elenastepanova1978@postgrespro.ru", "phone": "+70620290273"}
0005433255176	ED1A0A	7876 623456	SERGEY SIDOROV	{"phone": "+70561813897"}
0005433255177	98E04E	6550 066181	VLADIMIR GAVRILOV	{"phone": "+70741498158"}
0005433255178	7F039B	2081 493848	VLADIMIR VASILEV	{"phone": "+70568695157"}
0005433255179	1994E3	3355 860835	RAISA KUZMINA	{"email": "kuzmina_raisa.03061968@postgrespro.ru", "phone": "+70659818835"}
0005433255180	1994E3	1689 231943	KONSTANTIN SOLOVEV	{"phone": "+70261961064"}
0005433255181	F58886	1018 148697	EKATERINA PETROVA	{"email": "ekaterina-petrova-031973@postgrespro.ru", "phone": "+70439728225"}
0005433255182	A129E1	5038 106469	VALENTINA KOROLEVA	{"phone": "+70063326814"}
0005433255183	A129E1	5330 924194	NIKOLAY MAKSIMOV	{"email": "n_maksimov051971@postgrespro.ru", "phone": "+70635014105"}
0005433255184	FC4D66	1042 492408	PAVEL TIKHONOV	{"email": "tikhonov_pavel.18051983@postgrespro.ru", "phone": "+70136401191"}
0005433255185	0A30F6	4266 864602	YULIYA ANTONOVA	{"email": "yuliya-antonova_22121967@postgrespro.ru", "phone": "+70869247651"}
0005433255186	0A30F6	2173 977263	IVAN ROMANOV	{"email": "iromanov-011971@postgrespro.ru", "phone": "+70875602359"}
0005433255187	0A30F6	8354 516420	OLGA IVANOVA	{"phone": "+70152520788"}
0005433255188	0A30F6	3857 204513	OLESYA KUZNECOVA	{"phone": "+70626428751"}
0005433255189	B514A1	0919 359402	TATYANA SAVELEVA	{"phone": "+70900475179"}
0005433255190	0FB563	8202 799343	SERGEY KRASNOV	{"phone": "+70757061168"}
0005433255191	355EAF	9677 652439	RAISA ANDREEVA	{"phone": "+70135883073"}
0005433255192	648AD2	4123 373046	VLADIMIR SCHERBAKOV	{"phone": "+70588303319"}
0005433255193	92E4C0	8497 033808	DMITRIY SHEVCHENKO	{"phone": "+70213621532"}
0005433255194	338DEA	0691 028291	VALENTINA DAVYDOVA	{"phone": "+70068599215"}
0005433255195	338DEA	9865 123340	KIRILL KOROLEV	{"phone": "+70717167531"}
0005433255196	B6C75A	1825 356148	IRINA NIKOLAEVA	{"email": "irina-nikolaeva-1976@postgrespro.ru", "phone": "+70508666482"}
0005433255197	B6C75A	3919 637874	VERA BOGDANOVA	{"phone": "+70270344605"}
0005433255198	BF0B94	0863 633433	ANATOLIY SOROKIN	{"phone": "+70457389219"}
0005433255199	ABD08A	3540 960911	LYUDMILA KONDRATEVA	{"phone": "+70812465024"}
0005433255200	ABD08A	5908 202474	PLATON NOVIKOV	{"phone": "+70812831246"}
0005433255201	47CF3A	5485 651995	OLGA NIKOLAEVA	{"email": "o-nikolaeva-031968@postgrespro.ru", "phone": "+70562873074"}
0005433255202	D9CE3C	1975 094825	ANASTASIYA SOKOLOVA	{"email": "sokolova-anastasiya-08021987@postgrespro.ru", "phone": "+70897034722"}
0005433255203	D9CE3C	7303 808193	ALEKSANDR SIDOROV	{"email": "sidorov-a041972@postgrespro.ru", "phone": "+70799550417"}
0005433255204	0646C6	0918 271883	TATYANA VOROBEVA	{"email": "vorobeva.tatyana051973@postgrespro.ru", "phone": "+70078459175"}
0005433255205	465646	5239 899201	DMITRIY SERGEEV	{"email": "d-sergeev-15061970@postgrespro.ru", "phone": "+70164343517"}
0005433255206	B35CE9	1893 869307	VALENTINA SAVELEVA	{"email": "saveleva-v_19071973@postgrespro.ru", "phone": "+70778341296"}
0005433255207	B35CE9	6304 664565	GENNADIY ANDREEV	{"email": "gandreev_021980@postgrespro.ru", "phone": "+70427460783"}
0005433255208	FBF2F8	9522 531446	LEONID BARANOV	{"phone": "+70422785210"}
0005433255209	BC1922	8578 326976	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy1960@postgrespro.ru", "phone": "+70331829671"}
0005433255210	AF888B	9372 375795	OLEG FROLOV	{"email": "frolov_o_1981@postgrespro.ru", "phone": "+70780901693"}
0005433255211	928FFB	5219 628201	RAMILYA LAZAREVA	{"email": "lazarevar-16101969@postgrespro.ru", "phone": "+70228712393"}
0005433255212	9D3F74	7977 382165	DINARA GORBUNOVA	{"email": "gorbunova_d-23031973@postgrespro.ru", "phone": "+70209637397"}
0005433255213	871D5C	5342 278956	VIKTOR BORISOV	{"email": "v.borisov1972@postgrespro.ru", "phone": "+70757300049"}
0005433255214	50747E	6035 043339	VERA DANILOVA	{"email": "danilova-vera-011984@postgrespro.ru", "phone": "+70050914629"}
0005433255215	FFB35C	7480 061648	ALEKSANDR MELNIKOV	{"phone": "+70704688081"}
0005433255216	CD0A71	1235 302416	ANNA ZOTOVA	{"phone": "+70204040658"}
0005433255217	FAA295	4048 101738	ALEKSANDR OSIPOV	{"phone": "+70473918755"}
0005433255218	0A75AE	7767 470997	OLGA MATVEEVA	{"email": "matveeva-olga16091975@postgrespro.ru", "phone": "+70725482940"}
0005433255219	5633A7	2486 192304	NAIL PETROV	{"email": "petrovnail-24011963@postgrespro.ru", "phone": "+70403825924"}
0005433255220	F66B1A	3233 231841	ANNA VOLKOVA	{"email": "volkovaa111972@postgrespro.ru", "phone": "+70452415110"}
0005433255221	E5ADB7	0769 569551	EKATERINA ROMANOVA	{"phone": "+70328908848"}
0005433255222	805413	2122 675999	VADIM GUSEV	{"email": "gusev-v1962@postgrespro.ru", "phone": "+70523954715"}
0005433255223	50EE35	4393 510787	GALINA POLYAKOVA	{"email": "polyakova-galina28081971@postgrespro.ru", "phone": "+70613373207"}
0005433255224	130881	7140 685121	MAKSIM ANDREEV	{"phone": "+70552625415"}
0005433255225	130881	5673 767643	ALEKSANDRA MAKAROVA	{"phone": "+70632547562"}
0005433255226	130881	4923 471561	LILIYA PETROVA	{"phone": "+70641341134"}
0005433255227	130881	0356 321669	ALEKSEY KOZLOV	{"phone": "+70602735823"}
0005433255228	553CCA	8695 456913	VALENTINA ALEKSEEVA	{"phone": "+70883754456"}
0005433255229	D23C0F	4020 921279	RAUF ABRAMOV	{"email": "r-abramov-101968@postgrespro.ru", "phone": "+70426515522"}
0005433255230	9B62DC	9249 721285	MAKSIM ROMANOV	{"email": "maksim.romanov.03101986@postgrespro.ru", "phone": "+70718102563"}
0005433255231	9B62DC	8303 880467	MARIYA NESTEROVA	{"email": "nesterovamariya_1977@postgrespro.ru", "phone": "+70470282576"}
0005433255232	9B62DC	3862 538875	ALINA STEPANOVA	{"phone": "+70980588659"}
0005433255233	D4D973	7538 160641	ROMAN GUSEV	{"phone": "+70133631542"}
0005433255234	F850CA	0170 470007	TAMARA EGOROVA	{"email": "egorova.tamara.051977@postgrespro.ru", "phone": "+70645815560"}
0005433255235	F850CA	1204 356094	GALINA KUZNECOVA	{"phone": "+70081736745"}
0005433255236	1D76EE	0275 399336	IRINA MOROZOVA	{"phone": "+70578239829"}
0005433255237	D9E9E0	0161 227782	VLADIMIR TARASOV	{"phone": "+70590166910"}
0005433255238	D9E9E0	2181 331061	KARINA LOGINOVA	{"email": "loginova-k-031961@postgrespro.ru", "phone": "+70211311440"}
0005433255239	D542B9	3834 729804	YULIYA IVANOVA	{"phone": "+70789782587"}
0005433255240	68B97D	9520 361683	VLADIMIR NOVIKOV	{"email": "v.novikov_09121970@postgrespro.ru", "phone": "+70088181422"}
0005433255241	ECC3F9	3134 773117	VERA NAZAROVA	{"email": "nazarova.vera.081972@postgrespro.ru", "phone": "+70792648368"}
0005433255242	ED9C9F	8602 259389	ANTONIDA PAVLOVA	{"email": "pavlova_antonida.27081964@postgrespro.ru", "phone": "+70688857570"}
0005433255243	ED9C9F	4504 754592	DMITRIY SMIRNOV	{"phone": "+70109295928"}
0005433255244	9042F7	1986 272051	DARYA TARASOVA	{"phone": "+70381116737"}
0005433255245	06CD6A	9868 404383	GALINA NAZAROVA	{"phone": "+70865014905"}
0005433255246	06CD6A	1066 110633	LYUDMILA KOROLEVA	{"phone": "+70139972668"}
0005433255247	EEDD23	8066 841365	IRINA ROMANOVA	{"phone": "+70640323063"}
0005433255248	EEDD23	4216 978966	OLGA POPOVA	{"phone": "+70996859804"}
0005433255249	52546C	4704 337514	SVETLANA KOROLEVA	{"email": "s-koroleva1970@postgrespro.ru", "phone": "+70397948958"}
0005433255250	09B673	5084 708881	DARYA YAKOVLEVA	{"email": "yakovleva.darya101988@postgrespro.ru", "phone": "+70021723529"}
0005433255251	CD4957	4608 690288	ILYA ZHURAVLEV	{"phone": "+70616598689"}
0005433255252	066A68	2125 806239	ELMIRA GRISHINA	{"email": "grishina_elmira.091965@postgrespro.ru", "phone": "+70609936931"}
0005433255253	615677	7913 296339	GALINA MASLOVA	{"email": "galina_maslova1973@postgrespro.ru", "phone": "+70474496748"}
0005433255254	B6BED2	3397 383825	EVDOKIYA SAVELEVA	{"phone": "+70176745722"}
0005433255255	6CF466	0746 185243	RAILYA SAVELEVA	{"email": "savelevar_1974@postgrespro.ru", "phone": "+70840160935"}
0005433255256	6CF466	5219 487555	YAN KISELEV	{"phone": "+70479001647"}
0005433255257	050F0B	7972 505378	LILIYA KOZLOVA	{"email": "kozlova_liliya.101967@postgrespro.ru", "phone": "+70154314050"}
0005433255258	050F0B	2840 699839	FEDOR KONOVALOV	{"phone": "+70489459813"}
0005433255259	050F0B	2976 609437	PETR BARANOV	{"email": "p_baranov1979@postgrespro.ru", "phone": "+70567908744"}
0005433255260	1B036E	2871 946564	LYUDMILA MOISEEVA	{"phone": "+70682072076"}
0005433255261	7B9DF3	5649 701724	IRINA KAZAKOVA	{"email": "kazakova.irina_17111965@postgrespro.ru", "phone": "+70615612862"}
0005433255262	2AF22F	3227 831946	VLADIMIR GRIGOREV	{"phone": "+70686227616"}
0005433255263	0CFA5C	6955 475685	OLGA DMITRIEVA	{"phone": "+70080532425"}
0005433255264	FFD76F	7886 133437	IRINA KOZLOVA	{"email": "kozlova-i.05051969@postgrespro.ru", "phone": "+70390310779"}
0005433255265	E98366	8891 614661	NINA KISELEVA	{"email": "nina.kiseleva_05121978@postgrespro.ru", "phone": "+70210019417"}
0005433255266	3911FD	8662 841474	OLGA EGOROVA	{"email": "olga_egorova-1969@postgrespro.ru", "phone": "+70052458996"}
0005433255267	CF34CF	6936 377419	NINA ROMANOVA	{"email": "romanovanina.28061959@postgrespro.ru", "phone": "+70486734992"}
0005433255268	A2F571	0688 642508	IVAN ZAKHAROV	{"email": "zakharovivan_1959@postgrespro.ru", "phone": "+70774807976"}
0005433255269	A2F571	0143 492730	VALENTINA FOMINA	{"phone": "+70792274849"}
0005433255270	F3232F	3725 058737	VERA KULIKOVA	{"email": "kulikova-vera_041973@postgrespro.ru", "phone": "+70114554274"}
0005433255271	D37A8B	0624 277536	VALENTINA NESTEROVA	{"phone": "+70173510870"}
0005433255272	ED8ACB	5778 259125	ANASTASIYA CHERNOVA	{"phone": "+70927201594"}
0005433255273	ED8ACB	8098 748014	LYUBOV DENISOVA	{"phone": "+70277141940"}
0005433255274	31831B	4811 571481	SVETLANA BARANOVA	{"email": "baranovasvetlana-081963@postgrespro.ru", "phone": "+70487607787"}
0005433255275	31831B	0322 883316	LIDIYA NIKITINA	{"phone": "+70447795872"}
0005433255276	B5B5E8	9353 374539	ANATOLIY POPOV	{"email": "a-popov_101973@postgrespro.ru", "phone": "+70249098700"}
0005433255277	B5B5E8	0102 199492	OLESYA GERASIMOVA	{"email": "o_gerasimova_021979@postgrespro.ru", "phone": "+70124166877"}
0005433255278	B5B5E8	5996 521628	YURIY KUZMIN	{"email": "y-kuzmin-09081970@postgrespro.ru", "phone": "+70587270690"}
0005433255279	083DBC	6413 774234	SVETLANA KARPOVA	{"phone": "+70768294243"}
0005433256381	0A21B1	7320 790423	NATALYA MIKHAYLOVA	{"phone": "+70359374316"}
0005433256382	0A21B1	4679 875399	VALENTIN ABRAMOV	{"email": "v.abramov1969@postgrespro.ru", "phone": "+70013376412"}
0005433256383	9AD004	3815 070612	NADEZHDA FROLOVA	{"phone": "+70628671727"}
0005433256384	9AD004	3874 119642	VLADIMIR KISELEV	{"phone": "+70162394464"}
0005433256385	537B17	7959 071661	EGOR NAUMOV	{"email": "e-naumov1973@postgrespro.ru", "phone": "+70999803395"}
0005433256386	26F44B	9748 405039	LARISA SIDOROVA	{"email": "l.sidorova18091974@postgrespro.ru", "phone": "+70822531369"}
0005433256387	23672D	3487 159842	OLGA ISAEVA	{"phone": "+70326287992"}
0005433256388	781064	3543 368791	LYUDMILA FILATOVA	{"phone": "+70817322037"}
0005433256389	CC2C01	1134 228081	DMITRIY ALEKSEEV	{"phone": "+70538639286"}
0005433256390	CC2C01	5141 362879	ALEKSEY PETROV	{"email": "petrov.a1986@postgrespro.ru", "phone": "+70010200805"}
0005433256391	52B941	1584 406716	IVAN ALEKSEEV	{"email": "ivan.alekseev_31031972@postgrespro.ru", "phone": "+70873879300"}
0005433256392	A34ACF	6031 181270	MARIYA SOKOLOVA	{"phone": "+70597545652"}
0005433256393	CFBCCF	5022 985898	VALENTINA FEDOROVA	{"email": "valentina.fedorova101970@postgrespro.ru", "phone": "+70592686994"}
0005433256394	CFBCCF	4215 963858	POLINA ZAKHAROVA	{"phone": "+70353799057"}
0005433256395	EC2103	9043 242315	YURIY MATVEEV	{"email": "y_matveev.1968@postgrespro.ru", "phone": "+70616430592"}
0005433256396	F4AB65	1277 221807	RAISA IVANOVA	{"email": "ivanovaraisa-01061980@postgrespro.ru", "phone": "+70374692413"}
0005433256397	F4AB65	7494 288607	OLGA ZOTOVA	{"phone": "+70384809220"}
0005433256398	F4AB65	5556 091212	LILIYA KOROLEVA	{"phone": "+70112038806"}
0005433256399	0776C2	2090 263357	SERGEY ANDREEV	{"email": "sergey_andreev.15031971@postgrespro.ru", "phone": "+70446453984"}
0005433256400	0776C2	6667 266107	DMITRIY ALEKSEEV	{"email": "dmitriyalekseev.31121973@postgrespro.ru", "phone": "+70916658711"}
0005433256401	56E637	9573 349789	SERGEY KUZMIN	{"phone": "+70340232561"}
0005433256402	54CA10	6555 221695	PAVEL ROMANOV	{"email": "pavel_romanov.091966@postgrespro.ru", "phone": "+70524231178"}
0005433256403	F3E82E	2405 131910	ALEVTINA GORBUNOVA	{"phone": "+70437671716"}
0005433256404	F3E82E	7968 263314	ALINA YAKOVLEVA	{"email": "yakovleva.alina24041971@postgrespro.ru", "phone": "+70689590385"}
0005433256405	640BF8	7494 913824	ARTEM OSIPOV	{"phone": "+70724613247"}
0005433256406	1DC426	5729 870405	ANASTASIYA DAVYDOVA	{"email": "davydova.anastasiya_26101973@postgrespro.ru", "phone": "+70406800041"}
0005433256407	1DC426	0511 704003	OLGA NIKOLAEVA	{"email": "olga_nikolaeva011990@postgrespro.ru", "phone": "+70298454867"}
0005433256408	4037EA	6156 539878	LIDIYA MOROZOVA	{"email": "l_morozova_021969@postgrespro.ru", "phone": "+70728935753"}
0005433256409	4037EA	3252 003727	MAKSIM FEDOROV	{"phone": "+70434046483"}
0005433256410	FC0C73	1786 540286	VERA FILIPPOVA	{"email": "filippova-vera22111977@postgrespro.ru", "phone": "+70640406180"}
0005433256411	439D8F	5021 315371	LYUDMILA NAUMOVA	{"email": "naumova-l.091972@postgrespro.ru", "phone": "+70691343460"}
0005433256412	69438E	1181 459035	ANATOLIY ALEKSANDROV	{"phone": "+70280321136"}
0005433256413	69438E	8152 853245	MARIYA MOISEEVA	{"email": "m-moiseeva_12071972@postgrespro.ru", "phone": "+70484210631"}
0005433256414	336E7B	6846 056392	ELENA GERASIMOVA	{"phone": "+70977498419"}
0005433256415	C1810D	8715 972458	NIKOLAY TARASOV	{"email": "nikolay.tarasov.011978@postgrespro.ru", "phone": "+70558762943"}
0005433256416	B389D8	5608 252859	VIKTOR FROLOV	{"email": "frolov_viktor05021979@postgrespro.ru", "phone": "+70956906529"}
0005433256417	64A9FF	3733 199556	SERGEY SOKOLOV	{"email": "sokolov.s-1970@postgrespro.ru", "phone": "+70324008811"}
0005433256418	09CF2F	0261 530371	ARINA ABRAMOVA	{"email": "arina.abramova1964@postgrespro.ru", "phone": "+70960257968"}
0005433256419	09CF2F	5723 882742	NATALYA BOGDANOVA	{"email": "bogdanova_natalya-1970@postgrespro.ru", "phone": "+70501420328"}
0005433256420	003CF9	7166 871047	VLADIMIR KUZMIN	{"phone": "+70847631048"}
0005433256421	55536F	8960 481794	IGOR ALEKSANDROV	{"phone": "+70313289589"}
0005433256422	55536F	1078 878731	NIKOLAY STEPANOV	{"email": "nstepanov-1976@postgrespro.ru", "phone": "+70263365070"}
0005433256423	553B95	4270 738284	EKATERINA POLYAKOVA	{"email": "polyakova-e051971@postgrespro.ru", "phone": "+70405752077"}
0005433256424	85AE58	1016 148734	EVGENIY AFANASEV	{"email": "e-afanasev.1975@postgrespro.ru", "phone": "+70306423714"}
0005433256425	9937B7	3076 073438	DENIS ANDREEV	{"email": "denisandreev-15091968@postgrespro.ru", "phone": "+70646686147"}
0005433256426	1AC473	3539 232846	ARTEM MOROZOV	{"email": "artemmorozov101973@postgrespro.ru", "phone": "+70135505248"}
0005433256427	6E764D	2008 141144	NINA BELOVA	{"email": "belova.n.1963@postgrespro.ru", "phone": "+70831158755"}
0005433256428	1CFFBE	6706 450794	RUMIYA POLYAKOVA	{"phone": "+70091562734"}
0005433256429	1CFFBE	7279 256080	ELENA FILIPPOVA	{"phone": "+70158484535"}
0005433256430	F6CD51	1507 794731	NINA ZHURAVLEVA	{"email": "zhuravlevan_011981@postgrespro.ru", "phone": "+70620687701"}
0005433256431	1C5CC0	6404 775411	MARINA ORLOVA	{"email": "m.orlova031973@postgrespro.ru", "phone": "+70486932483"}
0005433256432	5D54A1	6133 657552	RAISA DENISOVA	{"phone": "+70508251920"}
0005433256433	91ADD7	6017 561317	SERGEY SEMENOV	{"phone": "+70464586073"}
0005433256434	91ADD7	7493 527340	ANNA NIKOLAEVA	{"phone": "+70076296388"}
0005433256435	91ADD7	3228 694430	GENNADIY SOKOLOV	{"email": "sokolovgennadiy.091970@postgrespro.ru", "phone": "+70087187691"}
0005433256436	E6E6FA	5473 489468	VALENTINA TARASOVA	{"email": "valentina.tarasova-09041964@postgrespro.ru", "phone": "+70016490043"}
0005433256437	999857	9821 209911	NATALYA ALEKSANDROVA	{"phone": "+70888835015"}
0005433256438	FB8975	5695 551793	VLADIMIR FROLOV	{"email": "frolov.vladimir_031973@postgrespro.ru", "phone": "+70319048204"}
0005433256439	FB8975	2568 399721	MARGARITA KONOVALOVA	{"email": "konovalova_margarita111968@postgrespro.ru", "phone": "+70419924000"}
0005433256440	5F3EF8	8178 383613	LYUDMILA SCHERBAKOVA	{"email": "lyudmila.scherbakova-1969@postgrespro.ru", "phone": "+70076250987"}
0005433256441	5F3EF8	3090 382352	YURIY KULIKOV	{"phone": "+70129076827"}
0005433256442	36EED0	2977 989407	OLGA SOKOLOVA	{"phone": "+70578483333"}
0005433256443	36EED0	3234 504207	LYUBOV ILINA	{"email": "lyubov-ilina-26041983@postgrespro.ru", "phone": "+70272408114"}
0005433256444	F92565	9816 610956	LYUDMILA ANDREEVA	{"phone": "+70540847491"}
0005433256445	929AC3	2393 224347	SERGEY MATVEEV	{"email": "matveevsergey1978@postgrespro.ru", "phone": "+70194265776"}
0005433256446	929AC3	1534 407930	ALEKSEY SEMENOV	{"email": "a_semenov_071972@postgrespro.ru", "phone": "+70169829636"}
0005433256447	929AC3	7824 165074	ANATOLIY KAZAKOV	{"email": "akazakov-1980@postgrespro.ru", "phone": "+70925909908"}
0005433256448	CC6817	0839 301709	ALENA ANISIMOVA	{"phone": "+70143199793"}
0005433256449	CC6817	5979 995720	PAVEL BONDARENKO	{"email": "bondarenkop1973@postgrespro.ru", "phone": "+70248735057"}
0005433256450	024730	3256 762431	LIDIYA NESTEROVA	{"email": "nesterova.l-1970@postgrespro.ru", "phone": "+70444070846"}
0005433256452	73D2AF	1596 353448	LYUDMILA KOROLEVA	{"email": "l.koroleva.1979@postgrespro.ru", "phone": "+70064905353"}
0005433256453	09A5C2	0757 184980	GALINA NAZAROVA	{"phone": "+70660498579"}
0005433256454	09A5C2	4961 323501	ANDREY KUDRYASHOV	{"email": "andrey.kudryashov_1976@postgrespro.ru", "phone": "+70166229088"}
0005433256455	1E382F	2366 780468	VALENTINA SOKOLOVA	{"email": "v-sokolova.24121972@postgrespro.ru", "phone": "+70258537971"}
0005433256456	EBA799	9625 500527	PETR FROLOV	{"phone": "+70526468277"}
0005433256457	A707F0	9826 645081	TATYANA SOKOLOVA	{"email": "t_sokolova_1960@postgrespro.ru", "phone": "+70625599720"}
0005433256458	A707F0	2509 778288	ANATOLIY KOZLOV	{"phone": "+70875363067"}
0005433256459	A707F0	0757 709795	OLGA SEMENOVA	{"phone": "+70274757618"}
0005433256460	DB46D8	8835 457163	NIKOLAY IVANOV	{"phone": "+70292438927"}
0005433256461	DB46D8	0701 194647	ZOYA BELOVA	{"phone": "+70949797180"}
0005433256462	0620BD	4130 939227	SOFYA KUZNECOVA	{"email": "sofya.kuznecova_1983@postgrespro.ru", "phone": "+70863643371"}
0005433256463	728221	9454 243899	ANDREY VASILEV	{"phone": "+70717545892"}
0005433256464	728221	1620 914901	NIKOLAY KARPOV	{"email": "n.karpov.091987@postgrespro.ru", "phone": "+70977436915"}
0005433256465	93B855	6841 658710	MIKHAIL OSIPOV	{"email": "mikhail_osipov.1989@postgrespro.ru", "phone": "+70099689602"}
0005433256466	826D48	8246 159938	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov-1981@postgrespro.ru", "phone": "+70998789782"}
0005433256467	AF2A08	5567 389586	ALEKSANDRA SOROKINA	{"email": "sorokina-a091976@postgrespro.ru", "phone": "+70703572002"}
0005433256468	706EFD	0818 005407	OLGA POPOVA	{"phone": "+70216923921"}
0005433256469	C8C180	6784 833041	ROZA KAZAKOVA	{"phone": "+70243540166"}
0005433256470	C8C180	4334 356072	VALERIY DENISOV	{"email": "valeriydenisov.111975@postgrespro.ru", "phone": "+70927546774"}
0005433256471	C8C180	1844 445229	VITALIY ZHURAVLEV	{"phone": "+70033281397"}
0005433256472	245B5D	2107 298463	MARIYA GRISHINA	{"phone": "+70790468903"}
0005433256473	89E781	2680 117886	DIANA ZAYCEVA	{"phone": "+70704379558"}
0005433256474	89E781	7734 392568	ARINA ILINA	{"email": "ilina_a27041976@postgrespro.ru", "phone": "+70201065970"}
0005433256475	CACE02	0713 155465	ILDAR VASILEV	{"email": "ivasilev1979@postgrespro.ru", "phone": "+70986924543"}
0005433256476	CACE02	2674 420324	RAZIYA GRISHINA	{"email": "raziya_grishina.061974@postgrespro.ru", "phone": "+70642149909"}
0005433256477	5FC09A	0673 989179	GALINA KONOVALOVA	{"email": "konovalova_galina_091974@postgrespro.ru", "phone": "+70916317019"}
0005433256478	5FC09A	2012 074107	SERGEY IVANOV	{"phone": "+70804816397"}
0005433256479	82DFDD	0583 092477	EVGENIYA KAZAKOVA	{"phone": "+70712594718"}
0005433256480	026A73	0513 365241	NINA TROFIMOVA	{"phone": "+70801285289"}
0005433256481	9455F0	0270 785231	FEDOR AFANASEV	{"phone": "+70899801919"}
0005433256482	0B692D	9833 275688	VLADIMIR PETROV	{"phone": "+70098478916"}
0005433256483	0B692D	6138 905558	POLINA RODIONOVA	{"phone": "+70141947032"}
0005433256484	88BA53	5605 487727	NADEZHDA ZAYCEVA	{"email": "nadezhda_zayceva.1969@postgrespro.ru", "phone": "+70463346026"}
0005433256485	7236A4	8650 052850	ZINAIDA GORBUNOVA	{"phone": "+70033105630"}
0005433256486	7236A4	6043 116458	ALEKSEY RODIONOV	{"email": "rodionov.a.1975@postgrespro.ru", "phone": "+70873525591"}
0005433256487	7236A4	1510 078473	EVGENIY KUDRYASHOV	{"phone": "+70577269051"}
0005433256488	EB88DA	3655 307411	NADEZHDA BOGDANOVA	{"phone": "+70655525936"}
0005433256489	9E2D34	8750 557927	EDUARD MAKSIMOV	{"email": "maksimov.eduard_091977@postgrespro.ru", "phone": "+70422567262"}
0005433256490	0A9636	8352 677513	NIKOLAY MATVEEV	{"email": "matveev_nikolay_021970@postgrespro.ru", "phone": "+70128092988"}
0005433256491	84C078	4370 384035	TATYANA ANTONOVA	{"email": "tantonova.22081974@postgrespro.ru", "phone": "+70579733198"}
0005433256492	5D60AE	7236 795586	ALEKSEY POPOV	{"email": "a-popov.081971@postgrespro.ru", "phone": "+70968145507"}
0005433256493	5D60AE	2003 818765	RINAT GRIGOREV	{"phone": "+70386349887"}
0005433256494	5D60AE	7155 060925	ANDREY FEDOTOV	{"email": "andrey_fedotov.1958@postgrespro.ru", "phone": "+70143494048"}
0005433256495	A79D70	5707 707028	LIDIYA TARASOVA	{"email": "tarasova.lidiya_011974@postgrespro.ru", "phone": "+70471906417"}
0005433261388	481351	6235 528520	ALEKSEY IVANOV	{"email": "ivanov-aleksey10031971@postgrespro.ru", "phone": "+70026717283"}
0005433261389	481351	5817 531047	OLEG MIRONOV	{"email": "oleg.mironov081978@postgrespro.ru", "phone": "+70811565846"}
0005433261390	77B892	7997 217727	EVGENIY SOLOVEV	{"phone": "+70056536200"}
0005433261391	77B892	9807 549180	EKATERINA KAZAKOVA	{"phone": "+70594437667"}
0005433261392	79EE9C	4510 375596	ALEKSANDR PETROV	{"email": "aleksandrpetrov22091985@postgrespro.ru", "phone": "+70824776951"}
0005433261393	79EE9C	7575 469337	ALEKSEY BELOV	{"phone": "+70203513199"}
0005433261394	4D84D5	9755 035556	NATALIYA ALEKSEEVA	{"email": "alekseeva.nataliya_14061970@postgrespro.ru", "phone": "+70085030308"}
0005433261395	0E2BC5	2840 031832	MIKHAIL SOLOVEV	{"phone": "+70483591734"}
0005433261396	0E2BC5	7695 587511	EKATERINA BORISOVA	{"email": "ekaterina_borisova021979@postgrespro.ru", "phone": "+70286792151"}
0005433261397	12FB23	4040 407430	NIKOLAY NOVIKOV	{"email": "nnovikov.1984@postgrespro.ru", "phone": "+70802374142"}
0005433261398	67C6B8	6552 638524	LYUDMILA IVANOVA	{"phone": "+70868339043"}
0005433261399	67C6B8	6073 383858	OLGA KONOVALOVA	{"phone": "+70816026613"}
0005433261400	2AEA06	4961 227431	ANDREY NIKITIN	{"phone": "+70190038105"}
0005433261401	F5662E	7222 838600	MARIYA MAKAROVA	{"phone": "+70184560870"}
0005433261402	F5662E	4366 046621	EKATERINA RYABOVA	{"email": "ryabovaekaterina11091962@postgrespro.ru", "phone": "+70761034686"}
0005433261403	20EA0E	7371 215307	EVGENIY MEDVEDEV	{"phone": "+70327605233"}
0005433261404	20EA0E	0432 003609	MARINA ISAEVA	{"email": "m-isaeva1960@postgrespro.ru", "phone": "+70903760127"}
0005433261405	4206A0	2861 938908	NINA SIDOROVA	{"email": "nsidorova.11091963@postgrespro.ru", "phone": "+70722113616"}
0005433261406	32FC0E	0749 469561	MARINA OVCHINNIKOVA	{"email": "marina_ovchinnikova_1968@postgrespro.ru", "phone": "+70653714144"}
0005433261407	B33FCD	9737 818756	ALEKSANDR SEMENOV	{"phone": "+70536476091"}
0005433261408	99F667	2366 701506	EVDOKIYA ARKHIPOVA	{"phone": "+70421176714"}
0005433261409	E6AC49	7399 394156	VALERIY ZAKHAROV	{"email": "zakharovvaleriy.041966@postgrespro.ru", "phone": "+70277192863"}
0005433261410	16AF7D	9576 542644	KSENIYA SERGEEVA	{"email": "sergeeva_kseniya051971@postgrespro.ru", "phone": "+70073096848"}
0005433261468	881E18	3592 924048	SERGEY NAUMOV	{"phone": "+70454643524"}
0005433261411	799FCB	6698 591046	VALENTINA KUZNECOVA	{"email": "valentina.kuznecova.091969@postgrespro.ru", "phone": "+70850354960"}
0005433261412	CCCA47	9452 681666	SVETLANA FEDOROVA	{"email": "fedorovas1963@postgrespro.ru", "phone": "+70727695464"}
0005433261413	08B800	5476 152344	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr_1971@postgrespro.ru", "phone": "+70488145697"}
0005433261414	BCB326	9846 238909	DMITRIY KISELEV	{"email": "d_kiselev.111974@postgrespro.ru", "phone": "+70293334261"}
0005433261415	D286AA	8510 696213	GALINA BORISOVA	{"phone": "+70291909331"}
0005433261416	5CE210	1717 237055	LADA MELNIKOVA	{"phone": "+70026675609"}
0005433261417	867819	0908 136458	ANNA YAKOVLEVA	{"phone": "+70762400879"}
0005433261418	867819	1017 690078	VERONIKA PETROVA	{"email": "petrova_v_1970@postgrespro.ru", "phone": "+70833700561"}
0005433261419	3EA695	2474 334854	NATALYA ERMAKOVA	{"phone": "+70133229742"}
0005433261420	3EA695	4994 148008	OLGA ZHURAVLEVA	{"email": "zhuravleva_o02091978@postgrespro.ru", "phone": "+70004603009"}
0005433261421	1D6AD6	3375 853270	ELVIRA SIDOROVA	{"email": "e-sidorova_07051974@postgrespro.ru", "phone": "+70677057900"}
0005433261422	1D6AD6	6940 149571	NATALYA ZHURAVLEVA	{"phone": "+70657807516"}
0005433261423	56407B	1794 402914	MARIYA POLYAKOVA	{"email": "mariya.polyakova-1970@postgrespro.ru", "phone": "+70857666299"}
0005433261424	1EAEA4	7183 325328	DMITRIY KUZNECOV	{"phone": "+70090288016"}
0005433261425	1EAEA4	3967 460308	IVAN GAVRILOV	{"phone": "+70383436864"}
0005433261426	C0244F	4577 449186	ALEKSEY VOLKOV	{"email": "aleksey-volkov.1973@postgrespro.ru", "phone": "+70145811889"}
0005433261427	B4F421	7126 883572	ELENA ROMANOVA	{"phone": "+70054080100"}
0005433261428	B4F421	5750 763871	RUSLAN PETROV	{"phone": "+70048195387"}
0005433261429	B4F421	5821 427660	PETR DMITRIEV	{"phone": "+70055024510"}
0005433261430	CB1657	7994 089139	ALEKSANDR ZAKHAROV	{"email": "zakharova.02101978@postgrespro.ru", "phone": "+70817349868"}
0005433261431	13863B	8923 124162	ANATOLIY KRASNOV	{"phone": "+70698953781"}
0005433261432	AF761B	8782 613897	PAVEL ALEKSANDROV	{"phone": "+70520175632"}
0005433261433	F55E97	4698 788680	NATALYA BORISOVA	{"email": "borisova.n.1978@postgrespro.ru", "phone": "+70936325967"}
0005433261434	F55E97	2568 570053	ELENA IVANOVA	{"phone": "+70496401966"}
0005433261435	298E74	5699 517433	NIKITA SOKOLOV	{"email": "sokolov.nikita_1965@postgrespro.ru", "phone": "+70211693542"}
0005433261436	298E74	8401 389271	VLADIMIR POPOV	{"email": "vpopov_1989@postgrespro.ru", "phone": "+70410349426"}
0005433261437	1E1377	1556 278884	MILANA FEDOROVA	{"email": "fedorova-m_041978@postgrespro.ru", "phone": "+70296030756"}
0005433261438	4E29A8	3400 875863	LYUDMILA GERASIMOVA	{"phone": "+70039727552"}
0005433261439	6A454E	4255 055696	TATYANA TROFIMOVA	{"phone": "+70925071513"}
0005433261440	6A454E	5249 621790	ANTONINA FEDOROVA	{"phone": "+70018278139"}
0005433261441	D02FCB	8858 838903	MILANA PETROVA	{"phone": "+70490684187"}
0005433261442	D02FCB	2404 715209	VYACHESLAV FOMIN	{"email": "fominvyacheslav1980@postgrespro.ru", "phone": "+70177274703"}
0005433261443	ADECAE	6854 762726	ANNA SERGEEVA	{"email": "sergeevaa1966@postgrespro.ru", "phone": "+70847097381"}
0005433261444	ADECAE	0280 577647	ANASTASIYA GERASIMOVA	{"phone": "+70335954134"}
0005433261445	361598	1419 535890	OLGA GUSEVA	{"phone": "+70046687678"}
0005433261446	233BA3	7968 150585	YURIY MEDVEDEV	{"email": "y-medvedev.13081974@postgrespro.ru", "phone": "+70102341502"}
0005433261447	3F6CDA	9308 398960	DENIS SEMENOV	{"email": "denissemenov121975@postgrespro.ru", "phone": "+70220788309"}
0005433261448	3F6CDA	9756 307049	IRINA MOROZOVA	{"phone": "+70517601388"}
0005433261449	68DBA6	2866 408758	KIRA MASLOVA	{"phone": "+70327900555"}
0005433261450	ECDCAE	6579 773005	KLAVDIYA MAKAROVA	{"email": "makarova-klavdiya-25041969@postgrespro.ru", "phone": "+70511027304"}
0005433261451	ECDCAE	9376 307304	TAMARA SEMENOVA	{"phone": "+70231285851"}
0005433261452	8B39F9	0930 259164	IRINA IVANOVA	{"email": "ivanova.i_18101967@postgrespro.ru", "phone": "+70367142641"}
0005433261453	AD3982	1998 093010	DZHAMILYA POPOVA	{"phone": "+70294015971"}
0005433261454	AD3982	3063 629021	YURIY FEDOTOV	{"email": "fedotov-yuriy.26041968@postgrespro.ru", "phone": "+70584342663"}
0005433261455	0A9884	8579 708443	VENERA DANILOVA	{"phone": "+70405560907"}
0005433261456	5DF465	1252 545580	ALEKSANDR ORLOV	{"phone": "+70593036783"}
0005433261457	5DF465	7503 144820	NINA SMIRNOVA	{"phone": "+70327297673"}
0005433261458	FD8E67	2808 346640	ELENA CHERNOVA	{"phone": "+70787384430"}
0005433261459	0B3AFB	4532 582817	YULIYA PETROVA	{"email": "yuliya.petrova1983@postgrespro.ru", "phone": "+70795023056"}
0005433261460	71FE56	2634 698462	TATYANA BELYAEVA	{"email": "tatyanabelyaeva_1971@postgrespro.ru", "phone": "+70465929623"}
0005433261461	71FE56	2786 500976	ANTONINA VOLKOVA	{"phone": "+70040077314"}
0005433261462	C04DDA	5123 811401	ELMIRA GORBUNOVA	{"phone": "+70538796554"}
0005433261463	C04DDA	4628 092924	OLGA IVANOVA	{"email": "olga.ivanova1977@postgrespro.ru", "phone": "+70887038275"}
0005433261464	D27F82	0664 029484	TAMARA IVANOVA	{"phone": "+70632063316"}
0005433261465	4427D9	6519 348886	KHALIDA KISELEVA	{"phone": "+70946056396"}
0005433261467	686494	6955 354814	ANTONINA MIRONOVA	{"phone": "+70288483005"}
0005433261469	881E18	3174 395602	ELENA ANISIMOVA	{"email": "anisimovaelena-061961@postgrespro.ru", "phone": "+70570536263"}
0005433261470	75B9B0	7281 032086	ELIZAVETA SERGEEVA	{"phone": "+70186106474"}
0005433261471	009063	5080 167320	BORIS OSIPOV	{"email": "b.osipov101981@postgrespro.ru", "phone": "+70986870694"}
0005433261472	009063	1940 169036	IGOR CHERNOV	{"phone": "+70826202102"}
0005433261473	009063	8709 712501	MARIYA VOROBEVA	{"email": "mvorobeva_1967@postgrespro.ru", "phone": "+70823198461"}
0005433261474	6DAE00	7746 574804	MAKSIM KULIKOV	{"phone": "+70732382285"}
0005433261475	A46F08	9255 378777	NADEZHDA CHERNOVA	{"phone": "+70972992813"}
0005433261476	A46F08	6100 722864	EVGENIYA POPOVA	{"phone": "+70614624517"}
0005433261477	997C62	0217 733913	EDUARD KOZLOV	{"email": "kozlov-e-02121959@postgrespro.ru", "phone": "+70958108924"}
0005433261478	958D84	3311 812499	PAVEL ZHURAVLEV	{"email": "p.zhuravlev-1977@postgrespro.ru", "phone": "+70615948382"}
0005433261479	958D84	2124 385437	KIRILL OSIPOV	{"email": "osipov_kirill.23091979@postgrespro.ru", "phone": "+70360907291"}
0005433261480	3243A5	6151 950777	TATYANA KONDRATEVA	{"phone": "+70615866301"}
0005433261481	95442D	3847 563432	DMITRIY SCHERBAKOV	{"email": "scherbakov-d.031967@postgrespro.ru", "phone": "+70981273174"}
0005433261482	39E3CC	7205 520988	TATYANA IVANOVA	{"phone": "+70022278472"}
0005433261483	F4C9A2	2897 017863	MAKSIM ORLOV	{"phone": "+70187509077"}
0005433261484	0D8E4F	4916 123577	ALEKSEY SERGEEV	{"phone": "+70775169092"}
0005433261485	7862F2	5104 814392	SOFYA MEDVEDEVA	{"email": "medvedevas07101977@postgrespro.ru", "phone": "+70091175474"}
0005433261486	3ADF25	7088 565456	ANTON MOROZOV	{"phone": "+70055060358"}
0005433261487	B5E88E	7608 381944	VLADIMIR BELOV	{"email": "v-belov-03081972@postgrespro.ru", "phone": "+70265692467"}
0005433261488	0C693A	4584 418921	ILYA SEMENOV	{"phone": "+70750639353"}
0005433261489	5093E5	3740 720324	SERGEY TIMOFEEV	{"email": "timofeev_sergey091973@postgrespro.ru", "phone": "+70961485315"}
0005433261490	EBCC1B	5243 230490	KRISTINA ABRAMOVA	{"email": "abramovak_1982@postgrespro.ru", "phone": "+70469828964"}
0005433261491	EBCC1B	2299 792494	NIKOLAY SOROKIN	{"phone": "+70870362516"}
0005433261492	51E564	3329 308161	MARIYA KAZAKOVA	{"email": "kazakova.mariya-061977@postgrespro.ru", "phone": "+70114382323"}
0005433261493	8CF944	1318 275277	MIKHAIL MIKHAYLOV	{"phone": "+70540843883"}
0005433261494	8CF944	2220 127678	SERGEY KUZNECOV	{"phone": "+70650907850"}
0005433261495	FC7315	3188 254244	TATYANA DENISOVA	{"email": "denisova.tatyana.021978@postgrespro.ru", "phone": "+70696351011"}
0005433261496	FC7315	9834 622984	LIDIYA EGOROVA	{"phone": "+70849623620"}
0005433261497	FC7315	7616 196156	MARIYA KOZLOVA	{"phone": "+70647261834"}
0005433261498	BDF037	8435 237746	GENNADIY ZAKHAROV	{"phone": "+70228200793"}
0005433261499	6B23C7	1403 073721	VERA MOISEEVA	{"email": "moiseeva.vera-071970@postgrespro.ru", "phone": "+70791261442"}
0005433261500	6B23C7	4613 673731	NATALYA SOLOVEVA	{"email": "solovevanatalya-25041978@postgrespro.ru", "phone": "+70834809482"}
0005433261501	6B23C7	0392 491936	NINA PETROVA	{"email": "npetrova02011970@postgrespro.ru", "phone": "+70352445740"}
0005433261502	7CBD3C	4155 414483	DENIS KUZNECOV	{"email": "deniskuznecov.1974@postgrespro.ru", "phone": "+70950904962"}
0005433261503	7CBD3C	0455 559622	OLEG EGOROV	{"email": "oleg-egorov12051964@postgrespro.ru", "phone": "+70526894300"}
0005433261504	028FFA	4315 876224	EVGENIY TIKHONOV	{"email": "evgeniy.tikhonov.02071971@postgrespro.ru", "phone": "+70464981137"}
0005433261505	314FFB	6347 931735	ALEKSEY ABRAMOV	{"phone": "+70288821742"}
0005433261506	AB518A	3146 724190	SERGEY VASILEV	{"email": "sergey.vasilev-20061975@postgrespro.ru", "phone": "+70222282723"}
0005433261507	D9EBB3	9156 765177	LINAR KUZMIN	{"phone": "+70040177325"}
0005433261508	B33A4F	3071 129763	SERGEY IVANOV	{"phone": "+70446187841"}
0005433261509	EFDE97	7168 249615	YURIY ALEKSANDROV	{"email": "aleksandrovy_041973@postgrespro.ru", "phone": "+70396667450"}
0005433261510	EFDE97	7383 636747	IGOR POPOV	{"email": "popov.i021963@postgrespro.ru", "phone": "+70659257381"}
0005433261511	4CEB12	2412 106546	ALEKSANDR IVANOV	{"phone": "+70246568642"}
0005433261512	4CEB12	7766 876755	ANASTASIYA YUDINA	{"email": "yudina.anastasiya_1964@postgrespro.ru", "phone": "+70260188414"}
0005433261513	4CEB12	2499 800891	POLINA SERGEEVA	{"phone": "+70220082150"}
0005433261514	112D2B	7187 432464	ANTONINA MATVEEVA	{"phone": "+70386455717"}
0005433261515	AAB9D4	3350 494351	GRIGORIY POPOV	{"email": "grigoriy.popov_23111973@postgrespro.ru", "phone": "+70323510189"}
0005433261516	60FE44	9289 057308	IRINA BORISOVA	{"email": "irina_borisova041962@postgrespro.ru", "phone": "+70758338194"}
0005433261517	60FE44	0930 941040	VLADIMIR NIKITIN	{"phone": "+70940997115"}
0005433261518	64E42D	3354 295647	ANNA ZHURAVLEVA	{"email": "zhuravleva_a1969@postgrespro.ru", "phone": "+70021620314"}
0005433261519	B424A3	1737 904514	YULIYA TIKHONOVA	{"email": "yuliya_tikhonova17061973@postgrespro.ru", "phone": "+70309884821"}
0005433261520	2FF077	8212 234533	RAISA NAZAROVA	{"email": "nazarovar.021973@postgrespro.ru", "phone": "+70395309640"}
0005433261521	3A9E8E	2337 934005	OLESYA RODIONOVA	{"phone": "+70764204311"}
0005433261522	3A9E8E	2031 254132	ALIYA BORISOVA	{"email": "aborisova-04031966@postgrespro.ru", "phone": "+70020035326"}
0005433261523	013F92	2414 946658	SERGEY TARASOV	{"email": "tarasov_s121967@postgrespro.ru", "phone": "+70599259650"}
0005433261524	D0A339	9359 756401	VALENTIN KUZNECOV	{"email": "v.kuznecov091969@postgrespro.ru", "phone": "+70551308717"}
0005433261525	123888	9558 435536	DANILA GAVRILOV	{"phone": "+70975711511"}
0005433261526	396706	4607 048592	NADEZHDA ABRAMOVA	{"phone": "+70119984674"}
0005433261527	078F2C	2148 728394	ELENA YUDINA	{"email": "elena_yudina.23101971@postgrespro.ru", "phone": "+70277939232"}
0005433261528	078F2C	7884 698755	RAVILYA MELNIKOVA	{"email": "ravilya.melnikova-051973@postgrespro.ru", "phone": "+70516045526"}
0005433261529	078F2C	5299 618036	YANA MATVEEVA	{"phone": "+70045982227"}
0005433261530	078F2C	0191 065442	NATALYA ANTONOVA	{"phone": "+70463850638"}
0005433261531	DA3FCF	9664 295795	ANNA KOLESNIKOVA	{"email": "anna_kolesnikova081971@postgrespro.ru", "phone": "+70873893102"}
0005433261532	7D9DD9	2663 149413	LYUBOV IVANOVA	{"email": "ivanova_l-1975@postgrespro.ru", "phone": "+70690487828"}
0005433261533	A6D4FD	4226 920729	ALEKSEY TIMOFEEV	{"phone": "+70955881317"}
0005433261534	4083CA	5747 625346	KSENIYA LEBEDEVA	{"email": "lebedeva_kseniya1964@postgrespro.ru", "phone": "+70634751987"}
0005433261535	4083CA	8851 982256	MARIYA KOLESNIKOVA	{"phone": "+70943978633"}
0005433261536	A7E22D	6410 461275	LYUBOV ALEKSANDROVA	{"phone": "+70208404910"}
0005433261537	A76CA2	5425 269837	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov081974@postgrespro.ru", "phone": "+70619882013"}
0005433261538	5324BD	1685 311250	VASILIY PAVLOV	{"phone": "+70055492466"}
0005433261539	F6274B	8291 907917	EVGENIYA VLASOVA	{"email": "vlasovae1981@postgrespro.ru", "phone": "+70631809594"}
0005433261540	5AB66F	1289 893944	ALEKSANDR DAVYDOV	{"email": "davydov-a-1963@postgrespro.ru", "phone": "+70882943590"}
0005433261541	5AB66F	2232 923108	ANDREY KULIKOV	{"email": "andrey.kulikov1972@postgrespro.ru", "phone": "+70824031146"}
0005433261542	8588AE	3420 433451	ALEKSEY MOISEEV	{"email": "moiseev-a101968@postgrespro.ru", "phone": "+70305907919"}
0005433261543	2B7427	9056 642132	EKATERINA ANTONOVA	{"phone": "+70413218794"}
0005433261544	2B7427	6848 823539	VIKTOR FEDOROV	{"phone": "+70894967591"}
0005433261545	2B7427	3375 686458	GEORGIY SERGEEV	{"email": "g.sergeev_1966@postgrespro.ru", "phone": "+70276631637"}
0005433261546	E4BF6C	4164 404601	GALINA POPOVA	{"phone": "+70600643942"}
0005433261547	54ADFA	2517 064495	SVETLANA FILATOVA	{"phone": "+70274541206"}
0005433261548	F36645	5728 729475	ALENA ERMAKOVA	{"email": "alenaermakova_1980@postgrespro.ru", "phone": "+70499146876"}
0005433261549	F97A5A	6257 670600	NATALYA BOGDANOVA	{"email": "bogdanova_natalya_101970@postgrespro.ru", "phone": "+70410822929"}
0005433261550	073D78	0371 399843	LEONID ROMANOV	{"phone": "+70337072602"}
0005433261551	073D78	2598 568575	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva.22101978@postgrespro.ru", "phone": "+70270575697"}
0005433261552	255AA7	4002 326001	MARIYA SIDOROVA	{"phone": "+70771058146"}
0005433261553	255AA7	4680 263797	MARIYA TIMOFEEVA	{"phone": "+70458707563"}
0005433261554	C52982	0123 358185	ANATOLIY KUZNECOV	{"email": "a-kuznecov.1969@postgrespro.ru", "phone": "+70703454387"}
0005433261555	985836	1636 317501	OLEG MEDVEDEV	{"email": "o.medvedev12121977@postgrespro.ru", "phone": "+70262381430"}
0005433261556	E08E06	0502 526415	ANDREY MOROZOV	{"email": "morozov_a-1987@postgrespro.ru", "phone": "+70512583407"}
0005433261557	E08E06	2323 032036	ALEKSANDR IVANOV	{"phone": "+70862561798"}
0005433261558	00E576	4441 939266	VALENTINA KUDRYASHOVA	{"phone": "+70386096167"}
0005433261559	DEC2E3	7301 159281	RAISA IVANOVA	{"email": "ivanova_r05031966@postgrespro.ru", "phone": "+70046927012"}
0005433261560	DEC2E3	2257 723578	DANIIL PETROV	{"phone": "+70371666515"}
0005433261561	B9FAF9	4965 134370	VLADIMIR SOLOVEV	{"phone": "+70709524904"}
0005433261562	3EACAC	8889 938517	NIKITA FILIPPOV	{"email": "filippovnikita.1960@postgrespro.ru", "phone": "+70064686434"}
0005433261563	742F4E	4482 551703	YULIYA SAVELEVA	{"email": "y-saveleva_041991@postgrespro.ru", "phone": "+70017520527"}
0005433261564	742F4E	1392 796571	VIKTOR SMIRNOV	{"phone": "+70905652981"}
0005433261565	3888B5	0970 308111	ELENA OSIPOVA	{"phone": "+70220411534"}
0005433261566	3888B5	1310 249544	ELENA VASILEVA	{"email": "elena-vasileva_28091956@postgrespro.ru", "phone": "+70743810886"}
0005433261567	663420	0349 796372	NIKOLAY EGOROV	{"phone": "+70482274815"}
0005433261568	663420	6515 762509	MARIYA ABRAMOVA	{"email": "mabramova_1976@postgrespro.ru", "phone": "+70570497595"}
0005433261569	4DA2DE	2799 054953	VIKTOR GUSEV	{"email": "gusev-viktor14051973@postgrespro.ru", "phone": "+70070267574"}
0005433261570	4DA2DE	2852 341530	KRISTINA ZHURAVLEVA	{"email": "k_zhuravleva_01021971@postgrespro.ru", "phone": "+70697187843"}
0005433261571	7D11A1	7842 252286	ANATOLIY SEMENOV	{"phone": "+70974777500"}
0005433261572	88925F	0760 761952	LYUBOV ILINA	{"phone": "+70403507424"}
0005433261573	FC7E2D	6576 678150	MARIYA KOZLOVA	{"phone": "+70698215545"}
0005433261574	EDD35E	2961 143209	SERGEY PAVLOV	{"email": "pavlov-s-12091984@postgrespro.ru", "phone": "+70358444618"}
0005433261575	EDD35E	8634 310539	NATALYA ZHUKOVA	{"email": "zhukova.natalya051979@postgrespro.ru", "phone": "+70510041818"}
0005433261576	7B0FF1	1551 956911	GALINA KOMAROVA	{"phone": "+70869066735"}
0005433261577	6D6328	2205 002774	ALEKSEY ABRAMOV	{"email": "alekseyabramov-24061981@postgrespro.ru", "phone": "+70930012935"}
0005433261578	8BDE52	7401 957808	SERGEY BARANOV	{"email": "baranovs1966@postgrespro.ru", "phone": "+70946624974"}
0005433261579	6D7C6E	3627 647858	LYUDMILA KOROLEVA	{"phone": "+70424875046"}
0005433261580	2EE4E8	5209 638979	TATYANA DAVYDOVA	{"email": "tatyana_davydova-20021961@postgrespro.ru", "phone": "+70844497866"}
0005433261581	4D6CDA	6676 293425	NADEZHDA EFREMOVA	{"email": "efremova_n_091981@postgrespro.ru", "phone": "+70133505949"}
0005433261582	4D6CDA	3677 273114	ALEKSANDR ANDREEV	{"phone": "+70955099272"}
0005433261583	4D6CDA	9763 297424	ANDREY VASILEV	{"phone": "+70945745451"}
0005433261584	7094B7	4639 211771	TATYANA ZAYCEVA	{"email": "tatyana_zayceva-18111977@postgrespro.ru", "phone": "+70663590541"}
0005433261585	001628	8851 708232	YURIY DMITRIEV	{"email": "dmitrievy-1972@postgrespro.ru", "phone": "+70199458406"}
0005433261586	001628	3252 199938	MARIYA IVANOVA	{"email": "mariya_ivanova1971@postgrespro.ru", "phone": "+70732640005"}
0005433261587	001628	7046 338860	NATALYA MAKAROVA	{"phone": "+70823641631"}
0005433261588	A76492	3561 741651	IGOR NIKOLAEV	{"phone": "+70774624628"}
0005433261589	A76492	2940 583587	ALLA SCHERBAKOVA	{"email": "a.scherbakova01061966@postgrespro.ru", "phone": "+70952866113"}
0005433261590	3490A0	1664 402073	NIKOLAY ANDREEV	{"phone": "+70600054567"}
0005433261591	2246FF	9860 377002	PAVEL POPOV	{"email": "pavel.popov_29061965@postgrespro.ru", "phone": "+70978981358"}
0005433261592	058DDD	9576 947200	ALEKSEY KULIKOV	{"phone": "+70202291448"}
0005433261593	EBBA0B	0393 211700	ANASTASIYA ARKHIPOVA	{"phone": "+70313302787"}
0005433261594	FBE3A5	9122 321698	VLADIMIR CHERNOV	{"phone": "+70096550496"}
0005433261595	4CAEA0	2807 012690	ANDREY FILIPPOV	{"phone": "+70185523817"}
0005433261596	6DAEAD	9875 896282	IVAN BORISOV	{"phone": "+70857435563"}
0005433261597	E6AC23	7115 559634	OLGA MASLOVA	{"email": "o-maslova_041971@postgrespro.ru", "phone": "+70649529555"}
0005433261598	6C7A3E	3352 301312	MAKAR BARANOV	{"email": "baranov-m-1964@postgrespro.ru", "phone": "+70504101964"}
0005433261599	51E4DF	9070 372598	NADEZHDA SAVELEVA	{"email": "nadezhda_saveleva.26021970@postgrespro.ru", "phone": "+70091352732"}
0005433261600	51E4DF	9829 775236	KIRILL SMIRNOV	{"phone": "+70934741647"}
0005433261601	3E1423	5979 875726	RAISA PETROVA	{"phone": "+70735629426"}
0005433261602	3E1423	2234 965342	EGOR MATVEEV	{"email": "e_matveev1965@postgrespro.ru", "phone": "+70786294262"}
0005433261603	2501A3	4806 529991	VITALIY NIKOLAEV	{"email": "nikolaev_vitaliy_091980@postgrespro.ru", "phone": "+70961215284"}
0005433261604	7B198A	4261 235765	EGOR EGOROV	{"email": "egorov-e.071978@postgrespro.ru", "phone": "+70019080116"}
0005433261605	7B198A	8793 968352	ALEKSANDR SEMENOV	{"phone": "+70488887150"}
0005433261606	52A2C3	3311 412597	VASILIY BORISOV	{"email": "v.borisov-081969@postgrespro.ru", "phone": "+70577810011"}
0005433261607	52A2C3	2740 096214	ALEKSEY KAZAKOV	{"phone": "+70334310654"}
0005433261608	E3CB0C	1978 503236	SERGEY MAKAROV	{"email": "s_makarov.1973@postgrespro.ru", "phone": "+70096191863"}
0005433261609	0DC077	1566 972071	NIKITA PAVLOV	{"email": "pavlovnikita_1976@postgrespro.ru", "phone": "+70545634878"}
0005433261610	ECECD6	2602 054313	BORIS STEPANOV	{"phone": "+70851890876"}
0005433261611	ECECD6	2739 057053	VALENTIN KONOVALOV	{"email": "konovalov_valentin_22121969@postgrespro.ru", "phone": "+70201163953"}
0005433261612	C04EED	5327 228582	VALENTINA FROLOVA	{"phone": "+70233104421"}
0005433261613	1AAF9A	5193 910803	MIKHAIL SHEVCHENKO	{"phone": "+70292136126"}
0005433261614	1AAF9A	7753 655770	ULYANA NESTEROVA	{"phone": "+70761452723"}
0005433261615	EF06ED	4235 158323	SERGEY ZHUKOV	{"phone": "+70620452078"}
0005433261616	08FE19	9797 017541	NADEZHDA ANDREEVA	{"email": "andreevan01021978@postgrespro.ru", "phone": "+70497206753"}
0005433261617	75CC0C	5426 284745	ALEKSEY KOROLEV	{"email": "korolev.aleksey.29111977@postgrespro.ru", "phone": "+70380496460"}
0005433261618	EFDF57	0626 146635	ANNA FOMINA	{"phone": "+70160319679"}
0005433261619	85D86E	6875 691278	MIKHAIL FOMIN	{"email": "mikhailfomin.1963@postgrespro.ru", "phone": "+70693746786"}
0005433261620	F4BED9	9116 626591	FAINA MOROZOVA	{"email": "morozova_f_1971@postgrespro.ru", "phone": "+70593768784"}
0005433261621	459575	2240 990208	TATYANA KONOVALOVA	{"phone": "+70900329374"}
0005433261622	459575	9749 092610	IRINA FEDOROVA	{"email": "fedorova-i_1977@postgrespro.ru", "phone": "+70037800549"}
0005433261623	3D17F6	8858 730767	VLADIMIR SAVELEV	{"email": "vladimir_savelev-1965@postgrespro.ru", "phone": "+70513443321"}
0005433261624	C9CEB7	5372 591944	DMITRIY SEMENOV	{"phone": "+70616706338"}
0005433261625	E35BCE	6328 754228	LYUDMILA KUZNECOVA	{"email": "kuznecoval_07031965@postgrespro.ru", "phone": "+70761754556"}
0005433261626	E35BCE	0460 323603	ALEKSANDRA TIKHONOVA	{"email": "tikhonova.aleksandra031976@postgrespro.ru", "phone": "+70562546905"}
0005433261627	BB1DE1	4489 873028	ALEKSEY KUZMIN	{"phone": "+70933513193"}
0005433261628	9EB531	6553 337379	ALEKSEY ANDREEV	{"email": "andreev.aleksey_16111972@postgrespro.ru", "phone": "+70873505433"}
0005433261629	9EB531	2356 058458	VIKTORIYA GERASIMOVA	{"email": "viktoriyagerasimova.1973@postgrespro.ru", "phone": "+70309844519"}
0005433261630	9E0968	1580 418146	KLAVDIYA SEMENOVA	{"phone": "+70769986193"}
0005433261631	9E0968	4147 555450	IRINA SOROKINA	{"email": "sorokinai-081976@postgrespro.ru", "phone": "+70463964496"}
0005433261632	9E0968	3602 792254	MAKSIM ABRAMOV	{"email": "maksimabramov.10041975@postgrespro.ru", "phone": "+70775808437"}
0005433261633	4D2482	1505 458061	TAMARA SMIRNOVA	{"phone": "+70047496459"}
0005433261634	6C5E98	0199 983353	LYUBOV KUDRYASHOVA	{"email": "kudryashovalyubov.021982@postgrespro.ru", "phone": "+70076390440"}
0005433261635	9C24A4	3067 996637	ANGELINA KONDRATEVA	{"phone": "+70245281489"}
0005433261636	9C24A4	2493 341411	LYUBOV PETROVA	{"phone": "+70205233684"}
0005433261637	963671	2924 883511	SERGEY STEPANOV	{"email": "sergey.stepanov_15111973@postgrespro.ru", "phone": "+70334416430"}
0005433261638	E158FD	6317 187916	YAKOV CHERNOV	{"phone": "+70150859114"}
0005433261639	ABF030	0982 155026	VLADIMIR ANDREEV	{"email": "vladimir-andreev_23111973@postgrespro.ru", "phone": "+70576728376"}
0005433261640	BE0AFE	8768 006275	ANASTASIYA GUSEVA	{"phone": "+70411268996"}
0005433261641	BE0AFE	7481 660525	TATYANA KOROLEVA	{"phone": "+70685282592"}
0005433261642	42BB53	8793 522052	ANDREY TARASOV	{"phone": "+70533283362"}
0005433261643	C023E2	7589 774824	DMITRIY FROLOV	{"phone": "+70890353684"}
0005433261644	6E2724	5078 970413	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova_031977@postgrespro.ru", "phone": "+70653069822"}
0005433261645	9684ED	8771 870796	ALBINA ALEKSANDROVA	{"email": "a_aleksandrova_15061971@postgrespro.ru", "phone": "+70235786571"}
0005433261646	7F1EAC	1013 193711	VARVARA NAUMOVA	{"email": "naumovav.16091976@postgrespro.ru", "phone": "+70817974831"}
0005433261647	913F89	3404 273698	YAROSLAV MOROZOV	{"email": "morozov.y-1973@postgrespro.ru", "phone": "+70029804588"}
0005433261648	30F573	8528 917307	EKATERINA SERGEEVA	{"email": "e.sergeeva_31101966@postgrespro.ru", "phone": "+70996003397"}
0005433261649	3EF9B9	5585 020764	MARINA VLASOVA	{"phone": "+70086827394"}
0005433261650	D7FD2E	7710 490282	ANASTASIYA POPOVA	{"phone": "+70297523144"}
0005433261651	DDE4DA	2479 833898	PAVEL OSIPOV	{"email": "pavelosipov-1978@postgrespro.ru", "phone": "+70040331384"}
0005433261652	33EC42	6141 215015	OLGA ANTONOVA	{"phone": "+70050761979"}
0005433261653	D46EF5	4833 330207	LIDIYA IVANOVA	{"phone": "+70477455388"}
0005433261654	D46EF5	8093 479624	NATALYA KAZAKOVA	{"email": "n.kazakova.27051967@postgrespro.ru", "phone": "+70678246886"}
0005433261655	B8FC25	2591 752940	ANNA KUZNECOVA	{"phone": "+70757568294"}
0005433261656	2DB7A1	9065 670933	TATYANA AKIMOVA	{"email": "akimovat-1977@postgrespro.ru", "phone": "+70251443178"}
0005433261657	5A17C6	4166 895473	VYACHESLAV PETROV	{"phone": "+70955387480"}
0005433261658	07299E	1924 401896	ANASTASIYA GRISHINA	{"email": "grishina-anastasiya1975@postgrespro.ru", "phone": "+70289744386"}
0005433261659	07299E	6110 125699	VLADISLAV KOZLOV	{"phone": "+70574345790"}
0005433261660	642081	1275 605168	ELENA IVANOVA	{"email": "elenaivanova-15081971@postgrespro.ru", "phone": "+70560883313"}
0005433261661	4A59BA	9169 275506	GEORGIY CHERNOV	{"email": "g_chernov22111979@postgrespro.ru", "phone": "+70666482956"}
0005433261662	0C88D7	9662 745606	ALEKSANDR ALEKSANDROV	{"phone": "+70272387596"}
0005433261663	0C88D7	8842 330917	RAISA CHERNOVA	{"email": "chernova-raisa1976@postgrespro.ru", "phone": "+70444667131"}
0005433261664	DEE2F6	3190 509642	NATALYA ZAKHAROVA	{"email": "zakharova_natalya_25121981@postgrespro.ru", "phone": "+70736397755"}
0005433261665	DEE2F6	2843 113613	VENIAMIN PAVLOV	{"email": "pavlovveniamin.10101974@postgrespro.ru", "phone": "+70224786041"}
0005433261666	1595F4	4353 856976	EGOR EGOROV	{"phone": "+70538531369"}
0005433261667	750383	2409 334474	OLGA NOVIKOVA	{"email": "olga_novikova_02031971@postgrespro.ru", "phone": "+70674059292"}
0005433261668	750383	1652 614922	ANNA NESTEROVA	{"phone": "+70926080282"}
0005433261669	94139E	2803 886851	TATYANA GORBUNOVA	{"phone": "+70260905642"}
0005433261670	DF3192	5294 341981	KLAVDIYA MARTYNOVA	{"email": "k-martynova1978@postgrespro.ru", "phone": "+70660434414"}
0005433261671	DF3192	4056 198599	GALINA EFREMOVA	{"phone": "+70182207982"}
0005433261672	8787BD	4790 122321	MARGARITA KOROLEVA	{"email": "koroleva.margarita_16091975@postgrespro.ru", "phone": "+70027953881"}
0005433261673	DD6FEE	8258 085424	RAVIL KOZLOV	{"phone": "+70049494553"}
0005433261674	F6C1D0	9371 230177	ARTEM MELNIKOV	{"phone": "+70970698455"}
0005433261675	76557B	1610 859676	VLADIMIR DAVYDOV	{"email": "davydov_v-081977@postgrespro.ru", "phone": "+70894327780"}
0005433261676	76557B	3273 981192	EGOR SCHERBAKOV	{"email": "e.scherbakov-1967@postgrespro.ru", "phone": "+70179595608"}
0005433261677	76557B	2256 973083	NADEZHDA KOZLOVA	{"phone": "+70813190584"}
0005433261678	125A59	1489 989585	VALERIY MATVEEV	{"phone": "+70406726514"}
0005433261679	5FC967	0981 227571	EVGENIY SHEVCHENKO	{"email": "shevchenko.e1969@postgrespro.ru", "phone": "+70953296326"}
0005433261680	5FC967	7700 372290	OLESYA TARASOVA	{"email": "olesyatarasova1970@postgrespro.ru", "phone": "+70599645449"}
0005433261681	2CA376	1612 170366	ANDREY ZAKHAROV	{"email": "andrey.zakharov_101976@postgrespro.ru", "phone": "+70075216616"}
0005433261682	2CA376	2819 987868	ALEKSANDR KULIKOV	{"email": "a.kulikov-21071976@postgrespro.ru", "phone": "+70215456937"}
0005433261683	9871BA	5274 334388	ANASTASIYA EFREMOVA	{"email": "aefremova-1977@postgrespro.ru", "phone": "+70174680428"}
0005433261684	9871BA	7228 689017	TATYANA NESTEROVA	{"phone": "+70401978781"}
0005433261685	8A79E6	3837 505524	MARINA KUZNECOVA	{"email": "m.kuznecova-05061963@postgrespro.ru", "phone": "+70168038997"}
0005433261686	8A79E6	1266 548696	ANATOLIY PETROV	{"email": "petrov_anatoliy.22071978@postgrespro.ru", "phone": "+70456685513"}
0005433261687	08CA1E	8092 281278	PETR KUDRYASHOV	{"email": "pkudryashov071985@postgrespro.ru", "phone": "+70893211823"}
0005433261688	08CA1E	1017 699209	IRINA SIDOROVA	{"email": "sidorova_i_091972@postgrespro.ru", "phone": "+70058045503"}
0005433261689	C9412E	6259 506626	STEPAN FEDOROV	{"phone": "+70838829640"}
0005433261690	BE66FC	5537 553626	PAVEL PETROV	{"email": "petrov_pavel101980@postgrespro.ru", "phone": "+70006676327"}
0005433261691	BE66FC	2114 626625	ANNA KULIKOVA	{"phone": "+70072761893"}
0005433261692	801BC8	0634 510341	NINA IVANOVA	{"email": "ivanovanina_1972@postgrespro.ru", "phone": "+70607569282"}
0005433261693	801BC8	3500 322986	NADEZHDA NIKOLAEVA	{"email": "n-nikolaeva.051976@postgrespro.ru", "phone": "+70918477863"}
0005433261694	696BC0	2881 616448	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr_19041958@postgrespro.ru", "phone": "+70570414631"}
0005433261695	FF5665	8848 783994	ANASTASIYA MELNIKOVA	{"phone": "+70867597840"}
0005433261696	4D1BE3	3174 296621	NATALYA FOMINA	{"email": "fomina-natalya.28081964@postgrespro.ru", "phone": "+70515989764"}
0005433261697	DD8589	7807 847468	OLGA KUDRYASHOVA	{"email": "kudryashova-olga.031977@postgrespro.ru", "phone": "+70834717393"}
0005433261698	75FB33	0277 482970	VALERIY YAKOVLEV	{"email": "v.yakovlev.16021968@postgrespro.ru", "phone": "+70168908123"}
0005433261699	75FB33	4486 913701	ANATOLIY IVANOV	{"phone": "+70132347609"}
0005433261700	61D904	1306 115462	ALEKSANDR CHERNOV	{"phone": "+70289986235"}
0005433261701	CD2107	6058 221068	MARIYA ANDREEVA	{"phone": "+70447878144"}
0005433261702	CD2107	0155 309218	VLADIMIR KOZLOV	{"email": "kozlov.v_041973@postgrespro.ru", "phone": "+70869150282"}
0005433261703	6F21A2	8462 341346	TATYANA ALEKSANDROVA	{"email": "tatyana_aleksandrova-22041981@postgrespro.ru", "phone": "+70572413250"}
0005433261704	E41D7E	4653 260388	ARTUR KOROLEV	{"email": "korolev-artur_11051970@postgrespro.ru", "phone": "+70430846673"}
0005433261705	734567	4700 236033	ELENA KOVALEVA	{"phone": "+70547194125"}
0005433261826	23F237	7227 998771	DMITRIY ZAYCEV	{"phone": "+70073276340"}
0005433261706	316ED6	5048 217080	PETR DENISOV	{"email": "denisovp_121965@postgrespro.ru", "phone": "+70066683799"}
0005433261707	316ED6	6521 131669	DMITRIY RODIONOV	{"email": "rodionovdmitriy.26091969@postgrespro.ru", "phone": "+70822344589"}
0005433261708	015956	4882 001366	TATYANA NIKOLAEVA	{"email": "nikolaeva-t_31051962@postgrespro.ru", "phone": "+70490067434"}
0005433261709	67525A	5094 961589	RAISA ISAEVA	{"email": "isaevaraisa_08091964@postgrespro.ru", "phone": "+70300231555"}
0005433261710	67525A	5771 969370	SERGEY SERGEEV	{"email": "s_sergeev-09081967@postgrespro.ru", "phone": "+70483032417"}
0005433261711	D295BC	6199 945239	NINA SOROKINA	{"email": "n.sorokina-091976@postgrespro.ru", "phone": "+70437764469"}
0005433261712	D295BC	4629 778501	KIRILL KOROLEV	{"email": "korolev-k_1974@postgrespro.ru", "phone": "+70206161676"}
0005433261713	906A3D	1646 904217	SERGEY TARASOV	{"phone": "+70282461679"}
0005433261714	17FF30	9918 798676	VALENTINA PAVLOVA	{"phone": "+70633909396"}
0005433261715	17FF30	6921 237040	RAISA ERMAKOVA	{"email": "raisa.ermakova.16041972@postgrespro.ru", "phone": "+70953367196"}
0005433261716	031125	4522 078090	LARISA MALYSHEVA	{"email": "malysheva_larisa_1979@postgrespro.ru", "phone": "+70799877663"}
0005433261717	777481	4392 498613	BORIS RODIONOV	{"phone": "+70800520520"}
0005433261718	38B4CA	2800 535625	ANTONINA POTAPOVA	{"phone": "+70422646495"}
0005433261719	38B4CA	1228 373014	NATALYA TIKHONOVA	{"phone": "+70231105815"}
0005433261720	38B4CA	2578 862414	ANASTASIYA MOISEEVA	{"phone": "+70422224721"}
0005433261721	B43648	7744 226894	VLADIMIR SOROKIN	{"email": "sorokin-v-1978@postgrespro.ru", "phone": "+70941831507"}
0005433261722	B43648	4710 220241	MARIYA KISELEVA	{"email": "m_kiseleva_08121978@postgrespro.ru", "phone": "+70892136981"}
0005433261723	315E4A	4254 077995	ANATOLIY VOROBEV	{"phone": "+70303531820"}
0005433261724	AFD8B3	1049 021801	EVGENIYA POTAPOVA	{"email": "potapova.e.101961@postgrespro.ru", "phone": "+70536428670"}
0005433261725	A53103	0362 084534	ALEKSANDR NOVIKOV	{"phone": "+70294867278"}
0005433261726	B64B58	8172 982500	SVETLANA DMITRIEVA	{"phone": "+70828481963"}
0005433261727	B64B58	4482 601186	ALEKSANDR SOROKIN	{"phone": "+70453312924"}
0005433261728	B64B58	7616 685917	GALINA NIKITINA	{"email": "nikitina-galina_05091975@postgrespro.ru", "phone": "+70796591417"}
0005433261729	9FD575	1101 899634	DARYA MOISEEVA	{"phone": "+70397952133"}
0005433261730	9FD575	0389 919299	SERGEY ANTONOV	{"email": "santonov_061974@postgrespro.ru", "phone": "+70241401326"}
0005433261731	2F1D6F	2961 240721	LIDIYA ANDREEVA	{"email": "l_andreeva-1958@postgrespro.ru", "phone": "+70870506439"}
0005433261732	6F2827	0323 337771	GENNADIY PETROV	{"phone": "+70294557747"}
0005433261733	4CF004	9492 333249	MARIYA STEPANOVA	{"phone": "+70881352646"}
0005433261734	6B423E	0886 906465	EMILIYA FILIPPOVA	{"phone": "+70805194848"}
0005433261735	B1E2C3	9336 119032	EKATERINA OSIPOVA	{"phone": "+70088048971"}
0005433261736	6C7416	8038 799441	LYUBOV STEPANOVA	{"email": "stepanova_l-05031975@postgrespro.ru", "phone": "+70852515447"}
0005433261737	EEF569	7182 379116	MARINA FILIPPOVA	{"phone": "+70189629930"}
0005433261738	858305	6691 595184	KLAVDIYA ZAYCEVA	{"email": "klavdiya.zayceva_1978@postgrespro.ru", "phone": "+70414384698"}
0005433261739	EFA1BA	6819 338262	MIKHAIL VLASOV	{"email": "vlasov.mikhail-12111971@postgrespro.ru", "phone": "+70286881047"}
0005433261740	EFA1BA	7455 421914	TATYANA TIMOFEEVA	{"phone": "+70616218399"}
0005433261741	1EAF24	4866 241490	EKATERINA LAZAREVA	{"phone": "+70556257278"}
0005433261742	1EAF24	7196 348514	LYUBOV ALEKSANDROVA	{"email": "l.aleksandrova.041986@postgrespro.ru", "phone": "+70292498849"}
0005433261743	EF0DD0	9762 162284	PETR ALEKSEEV	{"email": "palekseev_051975@postgrespro.ru", "phone": "+70042528858"}
0005433261744	EF0DD0	0823 205932	LILIYA EGOROVA	{"email": "liliya-egorova-1978@postgrespro.ru", "phone": "+70484194793"}
0005433261745	3F0384	8673 129276	FARID FEDOROV	{"phone": "+70150594321"}
0005433261746	9FF44F	4466 120906	ALEKSANDR IVANOV	{"email": "aleksandrivanov1977@postgrespro.ru", "phone": "+70896591339"}
0005433261747	663CDC	7947 348256	ALEKSANDRA ABRAMOVA	{"email": "abramova_aleksandra.07051982@postgrespro.ru", "phone": "+70737088401"}
0005433261748	663CDC	5287 341589	ALEKSANDR MAKAROV	{"email": "amakarov-011973@postgrespro.ru", "phone": "+70898353465"}
0005433261749	663CDC	4508 170492	OLGA MOROZOVA	{"email": "morozovaolga_04091984@postgrespro.ru", "phone": "+70375846193"}
0005433261750	34E38C	2340 690618	DMITRIY PETROV	{"phone": "+70731425452"}
0005433261751	34A769	4795 180349	SERGEY FROLOV	{"email": "frolov-s_12071971@postgrespro.ru", "phone": "+70438807966"}
0005433261752	FE3CBE	3635 620013	GALINA DANILOVA	{"email": "g.danilova.1970@postgrespro.ru", "phone": "+70383507289"}
0005433261753	FE3CBE	4665 830644	NINA DMITRIEVA	{"phone": "+70028763145"}
0005433261754	847419	9378 892947	LYUBOV MAKAROVA	{"phone": "+70272742032"}
0005433261755	847419	8722 942295	EVGENIY SMIRNOV	{"phone": "+70537444537"}
0005433261756	847419	7761 586326	RAISA VASILEVA	{"email": "raisavasileva1974@postgrespro.ru", "phone": "+70990808790"}
0005433261757	7D6B6A	5904 017598	SVETLANA DANILOVA	{"phone": "+70404453922"}
0005433261758	ACBDD7	6616 787060	OLGA DMITRIEVA	{"email": "o_dmitrieva18091979@postgrespro.ru", "phone": "+70900250166"}
0005433261759	9BC6C8	8160 641334	EGOR OSIPOV	{"phone": "+70193421039"}
0005433261760	9BC6C8	7934 220037	LYUBOV MAKAROVA	{"phone": "+70198087097"}
0005433261761	E8F543	3508 531737	POLINA ZAKHAROVA	{"phone": "+70788767438"}
0005433261762	29D9D9	8727 060587	FEDOR GRIGOREV	{"phone": "+70128944971"}
0005433261763	13C354	4167 794503	OLGA ALEKSEEVA	{"phone": "+70000201329"}
0005433261764	8534FA	3955 682148	YANA YAKOVLEVA	{"phone": "+70338822625"}
0005433261765	8534FA	3242 553773	OLGA KRASNOVA	{"phone": "+70689760395"}
0005433261827	83B227	9021 924997	YULIYA ANDREEVA	{"phone": "+70648404007"}
0005433261766	94CE41	9641 128383	ALEKSANDR ISAEV	{"email": "aisaev.1964@postgrespro.ru", "phone": "+70883245778"}
0005433261767	E517B0	1634 404577	DMITRIY KULIKOV	{"email": "dmitriykulikov-1974@postgrespro.ru", "phone": "+70970574545"}
0005433261768	6566DC	7082 083384	NIKITA TARASOV	{"phone": "+70110914680"}
0005433261769	5E08CF	0334 849232	NATALYA GORBUNOVA	{"phone": "+70533950898"}
0005433261770	DE6C59	3281 284451	SERGEY MEDVEDEV	{"phone": "+70501215795"}
0005433261771	DE6C59	4368 971329	ROMAN KAZAKOV	{"email": "kazakov_roman-1973@postgrespro.ru", "phone": "+70758959221"}
0005433261772	5E6096	5353 112394	VIKTOR ZAYCEV	{"email": "zaycevviktor.021967@postgrespro.ru", "phone": "+70335974456"}
0005433261773	A7C4D7	9031 924518	IRINA EFREMOVA	{"email": "iefremova1966@postgrespro.ru", "phone": "+70484166401"}
0005433261774	43CD6C	3434 655181	ALEKSEY NIKOLAEV	{"phone": "+70110679230"}
0005433261775	43CD6C	1778 830499	IGOR KAZAKOV	{"phone": "+70693238547"}
0005433261776	A3AB52	5737 950098	NATALYA SEMENOVA	{"email": "semenova_n_091975@postgrespro.ru", "phone": "+70029829419"}
0005433261777	A3AB52	9918 022995	VALENTINA NIKITINA	{"phone": "+70665194126"}
0005433261778	D7F97A	4741 607062	VERA VOROBEVA	{"email": "vorobeva_v.011972@postgrespro.ru", "phone": "+70367103863"}
0005433261779	D7F97A	1307 119954	SVETLANA KARPOVA	{"email": "karpova.s.10101981@postgrespro.ru", "phone": "+70792502413"}
0005433261780	466231	7261 630567	YULIYA POLYAKOVA	{"phone": "+70128685129"}
0005433261781	466231	0567 901444	TATYANA SAVELEVA	{"phone": "+70670743649"}
0005433261782	A86FED	6317 584578	PAVEL ZAKHAROV	{"email": "pavelzakharov-1970@postgrespro.ru", "phone": "+70777736360"}
0005433261783	A86FED	0340 011000	GRIGORIY POPOV	{"email": "popov_grigoriy-111961@postgrespro.ru", "phone": "+70004420343"}
0005433261784	9B57D9	8015 085964	IGOR FEDOTOV	{"email": "fedotovi-1978@postgrespro.ru", "phone": "+70451010843"}
0005433261785	2ABCAA	4012 224923	LILIYA KUZNECOVA	{"email": "kuznecova.liliya-21101968@postgrespro.ru", "phone": "+70191282034"}
0005433261786	2ABCAA	0040 625478	RENAT POPOV	{"email": "r-popov-011976@postgrespro.ru", "phone": "+70824822069"}
0005433261787	3E0CA3	4852 667562	IRINA KOROLEVA	{"phone": "+70268512017"}
0005433261788	11648C	2797 529480	MIKHAIL MOROZOV	{"phone": "+70738580499"}
0005433261789	11648C	8881 333754	EVGENIYA IVANOVA	{"email": "ivanova-e-1977@postgrespro.ru", "phone": "+70938765477"}
0005433261790	C0BD73	0136 991827	ELENA MELNIKOVA	{"email": "e.melnikova.101974@postgrespro.ru", "phone": "+70305465513"}
0005433261791	C0BD73	4189 476805	INNA KOZLOVA	{"email": "kozlova.i.081977@postgrespro.ru", "phone": "+70091653871"}
0005433261792	062C5A	5925 986880	EVDOKIYA SOKOLOVA	{"email": "evdokiya.sokolova22051976@postgrespro.ru", "phone": "+70739185146"}
0005433261793	4FDFB6	6252 869921	ROMAN BELOV	{"phone": "+70452823365"}
0005433261794	3D9BA9	9340 489076	VALENTINA RYABOVA	{"phone": "+70488227345"}
0005433261795	297843	8031 228862	VADIM GERASIMOV	{"email": "v.gerasimov_1968@postgrespro.ru", "phone": "+70468946014"}
0005433261796	25BF27	4672 194613	VASILIY VOLKOV	{"phone": "+70147308944"}
0005433261797	25BF27	7857 131480	VLADISLAV BORISOV	{"email": "vborisov_24031968@postgrespro.ru", "phone": "+70929852834"}
0005433261798	B9A887	4618 619584	ALEKSANDR IVANOV	{"email": "ivanova_061975@postgrespro.ru", "phone": "+70654425311"}
0005433261799	A35984	0979 533656	LYUBOV POTAPOVA	{"phone": "+70742757901"}
0005433261800	0AD997	0341 824326	LARISA POPOVA	{"phone": "+70269415062"}
0005433261801	FE84BB	2915 821960	ELINA MIKHAYLOVA	{"email": "elina_mikhaylova_031969@postgrespro.ru", "phone": "+70864655263"}
0005433261802	E2C088	2102 327247	ALENA IVANOVA	{"phone": "+70404932510"}
0005433261803	EC1946	8394 159805	RAFAEL MIRONOV	{"phone": "+70053529428"}
0005433261804	4D508E	7543 430839	VLADIMIR VASILEV	{"phone": "+70960039982"}
0005433261805	4D508E	8195 973637	DMITRIY ILIN	{"phone": "+70760061722"}
0005433261806	AD9B76	5094 903799	PETR KOROLEV	{"phone": "+70062137448"}
0005433261807	17B283	1725 996840	VALENTINA BOGDANOVA	{"phone": "+70246998968"}
0005433261808	B8D523	0158 451407	VERA EFREMOVA	{"phone": "+70630576469"}
0005433261809	F7E7F9	3936 822636	NAILYA NESTEROVA	{"phone": "+70311084559"}
0005433261810	F7E7F9	4035 281236	LYUDMILA TIKHONOVA	{"email": "tikhonova.l_101967@postgrespro.ru", "phone": "+70157436481"}
0005433261811	F7E7F9	2305 876074	NIKOLAY FOMIN	{"phone": "+70697986411"}
0005433261812	3BDF4B	2011 098339	MAKSIM SOLOVEV	{"phone": "+70647539375"}
0005433261813	539AD9	1169 880489	ADELINA NAZAROVA	{"email": "nazarova.adelina_101979@postgrespro.ru", "phone": "+70328230154"}
0005433261814	719E1C	8479 978048	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr_031973@postgrespro.ru", "phone": "+70042375636"}
0005433261815	719E1C	5283 619997	VLADIMIR MOROZOV	{"email": "morozov-v_31071975@postgrespro.ru", "phone": "+70500640856"}
0005433261816	8F256B	5221 047016	OKSANA DENISOVA	{"email": "odenisova1970@postgrespro.ru", "phone": "+70450898778"}
0005433261817	6C6BBE	1610 923849	OLGA IVANOVA	{"email": "olga_ivanova-24121967@postgrespro.ru", "phone": "+70968029666"}
0005433261818	D498DA	8629 855897	SERGEY PAVLOV	{"email": "sergey_pavlov.101972@postgrespro.ru", "phone": "+70883744448"}
0005433261819	D498DA	7661 280640	MARIYA KUZNECOVA	{"phone": "+70115558146"}
0005433261820	8483A9	5907 705820	NATALYA ZHURAVLEVA	{"email": "zhuravleva-natalya041974@postgrespro.ru", "phone": "+70911204623"}
0005433261821	24C376	9377 162126	ALEKSANDRA EGOROVA	{"email": "aleksandra_egorova_121962@postgrespro.ru", "phone": "+70035037188"}
0005433261822	8F732C	1124 577462	ELENA TIKHONOVA	{"email": "tikhonovaelena_1976@postgrespro.ru", "phone": "+70604819437"}
0005433261823	AB0C51	6948 653461	ANNA BELOVA	{"phone": "+70564516416"}
0005433261824	AB0C51	9197 175890	ANNA GORBUNOVA	{"email": "anna-gorbunova-081967@postgrespro.ru", "phone": "+70691971821"}
0005433261825	C0EC52	7824 135236	GALINA MEDVEDEVA	{"email": "medvedeva-galina_1978@postgrespro.ru", "phone": "+70072982607"}
0005433261828	A4BCB8	8344 831941	ALEKSANDR VLASOV	{"phone": "+70562804452"}
0005433261829	F94A26	4119 525487	OLGA FADEEVA	{"phone": "+70809156427"}
0005433261830	F94A26	7669 016227	VLADLEN VASILEV	{"email": "vasilevv_1970@postgrespro.ru", "phone": "+70559056762"}
0005433261831	E08E02	2298 592240	ALEKSEY MOROZOV	{"email": "morozovaleksey.1968@postgrespro.ru", "phone": "+70671169751"}
0005433261832	A1B40A	6315 883142	SERGEY MAKAROV	{"phone": "+70826098671"}
0005433261833	7ED33F	7436 944087	POLINA ZAKHAROVA	{"email": "p.zakharova_011962@postgrespro.ru", "phone": "+70187649664"}
0005433261834	EE0C5F	3721 622137	OLGA NAZAROVA	{"email": "nazarova-o091976@postgrespro.ru", "phone": "+70889256289"}
0005433261835	8B60F6	7441 137654	PETR IVANOV	{"email": "p-ivanov.19021967@postgrespro.ru", "phone": "+70393306021"}
0005433261836	91956F	1976 409429	PETR ABRAMOV	{"email": "petr_abramov-1972@postgrespro.ru", "phone": "+70030378963"}
0005433261837	91956F	7124 061941	TATYANA VOROBEVA	{"phone": "+70313922533"}
0005433261838	8D7BA0	4975 887579	ELENA EFIMOVA	{"email": "efimova-e1968@postgrespro.ru", "phone": "+70379945391"}
0005433261839	F00849	5055 817521	ALEKSANDR ABRAMOV	{"phone": "+70474070127"}
0005433261840	6BBBA2	4733 443097	DMITRIY SAVELEV	{"email": "savelev_dmitriy_011962@postgrespro.ru", "phone": "+70325870645"}
0005433261841	9899A5	7163 944369	SERGEY KOZLOV	{"email": "sergey-kozlov-1971@postgrespro.ru", "phone": "+70966549186"}
0005433261842	9899A5	9960 039423	ANDREY NOVIKOV	{"email": "a.novikov-041974@postgrespro.ru", "phone": "+70560466888"}
0005433261843	2BBECA	0770 197761	ARTEM VLASOV	{"phone": "+70589638798"}
0005433261844	2BBECA	8739 809944	VALENTINA MIKHAYLOVA	{"email": "valentina-mikhaylova-23071983@postgrespro.ru", "phone": "+70821172405"}
0005433261845	2EAD42	9335 971359	ALEKSANDR SEMENOV	{"email": "semenovaleksandr_011973@postgrespro.ru", "phone": "+70044421933"}
0005433261846	BBA837	5020 493983	RUSTAM TARASOV	{"email": "r-tarasov-1975@postgrespro.ru", "phone": "+70628814008"}
0005433261847	26D3BA	6860 288821	IVAN VOROBEV	{"phone": "+70354547509"}
0005433261848	26D3BA	1419 702445	ZAKHAR SOROKIN	{"phone": "+70736355103"}
0005433261849	79CAF4	7373 331096	ZAKHAR PAVLOV	{"email": "z.pavlov_1980@postgrespro.ru", "phone": "+70262214155"}
0005433261850	A214AC	7506 163975	OLESYA FROLOVA	{"phone": "+70660899126"}
0005433261851	A214AC	8615 662150	GEORGIY ZAKHAROV	{"phone": "+70846445706"}
0005433261852	88E9B3	3095 168910	ZHANNA MIKHAYLOVA	{"email": "zhanna.mikhaylova.1973@postgrespro.ru", "phone": "+70142852893"}
0005433261853	3C9193	5880 447803	TATYANA YAKOVLEVA	{"phone": "+70615136258"}
0005433261854	3C9193	6265 901630	KRISTINA GUSEVA	{"phone": "+70423753306"}
0005433261855	3C9193	6971 765816	ANDREY AFANASEV	{"email": "afanasevandrey-30031974@postgrespro.ru", "phone": "+70682411603"}
0005433261856	044D0B	5236 820415	OLGA LEBEDEVA	{"phone": "+70790788932"}
0005433261857	305716	4049 409445	ALEFTINA NIKOLAEVA	{"phone": "+70197402244"}
0005433261858	305716	1003 053661	ALEKSANDRA KUZNECOVA	{"email": "kuznecova-aleksandra.1969@postgrespro.ru", "phone": "+70120085536"}
0005433261859	1907B6	0630 497111	ANASTASIYA YAKOVLEVA	{"phone": "+70350018814"}
0005433261860	1907B6	1967 153891	EVGENIYA POPOVA	{"phone": "+70203840679"}
0005433261861	20B574	2022 351026	YURIY BONDARENKO	{"email": "yuriybondarenko.1975@postgrespro.ru", "phone": "+70055850358"}
0005433261862	79A932	5595 102215	VIKTORIYA ISAEVA	{"phone": "+70009796144"}
0005433261863	0179C8	7153 632730	ALEKSEY BELOV	{"email": "belov.aleksey_28121968@postgrespro.ru", "phone": "+70068945924"}
0005433261864	0179C8	5641 639157	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr-1968@postgrespro.ru", "phone": "+70321027768"}
0005433261865	674C36	4728 228801	ALEFTINA ZAYCEVA	{"phone": "+70510909683"}
0005433261866	4C15FF	9496 963769	NATALYA ANISIMOVA	{"phone": "+70455197283"}
0005433261867	4C15FF	5701 149840	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey-05051975@postgrespro.ru", "phone": "+70855240600"}
0005433261868	4108D8	1753 870964	SERGEY ZHUKOV	{"phone": "+70456999636"}
0005433261869	0877AF	5801 982549	LARISA ORLOVA	{"email": "larisaorlova-121967@postgrespro.ru", "phone": "+70443520151"}
0005433261870	0877AF	6418 977108	VYACHESLAV SEMENOV	{"phone": "+70246808088"}
0005433261871	5AA6AB	6324 743191	ELENA GERASIMOVA	{"phone": "+70732065766"}
0005433261872	E3658C	0073 390083	VIKTOR ISAEV	{"email": "isaevviktor1978@postgrespro.ru", "phone": "+70820121465"}
0005433261873	E3658C	5639 556171	ANATOLIY FROLOV	{"phone": "+70256303794"}
0005433261874	3C7380	6182 465466	VIKTORIYA POTAPOVA	{"email": "v-potapova.1979@postgrespro.ru", "phone": "+70299935690"}
0005433261875	71DBBA	3296 724914	DARYA MAKSIMOVA	{"email": "d_maksimova-1971@postgrespro.ru", "phone": "+70900990861"}
0005433261876	9EF44C	5004 453497	ANDREY SOROKIN	{"phone": "+70838816839"}
0005433261877	6CBB25	0058 349662	EVGENIY EGOROV	{"phone": "+70286154484"}
0005433261878	FD2A89	9573 572588	VLADIMIR IVANOV	{"phone": "+70457467344"}
0005433261879	DAFE1E	5228 585042	GENNADIY STEPANOV	{"email": "stepanov-g-101971@postgrespro.ru", "phone": "+70080479081"}
0005433261880	C93BE9	5811 884955	YULIYA AFANASEVA	{"email": "yafanaseva_041985@postgrespro.ru", "phone": "+70918457615"}
0005433261881	310E96	2699 129488	VITALIY AFANASEV	{"email": "afanasev_vitaliy.08121973@postgrespro.ru", "phone": "+70603123416"}
0005433261882	310E96	9863 572497	PAVEL SHEVCHENKO	{"phone": "+70992117358"}
0005433261883	C6CD77	6618 312672	TATYANA SERGEEVA	{"phone": "+70346354581"}
0005433261884	78B689	6205 154451	ANASTASIYA TIKHONOVA	{"phone": "+70163947079"}
0005433261885	9A36C9	8127 251177	VLADIMIR SOROKIN	{"phone": "+70384154286"}
0005433261886	9A36C9	3756 660289	NATALYA ANTONOVA	{"email": "antonovan-05071990@postgrespro.ru", "phone": "+70378291864"}
0005433261887	BBE589	3914 529914	MARINA SOLOVEVA	{"email": "m-soloveva_1976@postgrespro.ru", "phone": "+70774331679"}
0005433262009	4CF62D	6914 741310	NADEZHDA BARANOVA	{"phone": "+70976554802"}
0005433261888	A3802B	3934 613500	ALLA MOROZOVA	{"email": "morozovaalla-26051973@postgrespro.ru", "phone": "+70044710511"}
0005433261889	DDEB22	9066 172691	ALEKSEY MARTYNOV	{"phone": "+70259006870"}
0005433261890	38DA6C	0329 492176	ALFIYA KUZNECOVA	{"email": "alfiyakuznecova_16081958@postgrespro.ru", "phone": "+70752649697"}
0005433261891	A7577F	3392 576363	MIKHAIL VOLKOV	{"email": "volkov.mikhail041967@postgrespro.ru", "phone": "+70857382861"}
0005433261892	44887D	1846 316142	ALEKSANDRA POPOVA	{"email": "popova-aleksandra-031996@postgrespro.ru", "phone": "+70280190884"}
0005433261893	CAFDEE	1258 672792	VASILIY TARASOV	{"phone": "+70331192922"}
0005433261894	C36DB8	1603 876233	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr.26041960@postgrespro.ru", "phone": "+70537868147"}
0005433261895	5FCF35	5341 724982	OLESYA BARANOVA	{"phone": "+70604996703"}
0005433261896	788C2F	4780 921400	LARISA KUZNECOVA	{"email": "kuznecova.l.12111980@postgrespro.ru", "phone": "+70135222698"}
0005433261897	E04E5A	8678 923549	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov_1977@postgrespro.ru", "phone": "+70589701542"}
0005433261898	4DF707	4669 248404	GALINA DENISOVA	{"phone": "+70561003410"}
0005433261899	EB68D5	8262 242583	YURIY SOLOVEV	{"phone": "+70950810497"}
0005433261900	95763C	7813 373705	SERGEY MATVEEV	{"phone": "+70114606611"}
0005433261901	10EE39	7711 091678	GALINA STEPANOVA	{"email": "galinastepanova-111969@postgrespro.ru", "phone": "+70622002737"}
0005433261902	10EE39	5047 334480	MARINA GUSEVA	{"phone": "+70741203981"}
0005433261903	ADF6CB	6902 547091	VADIM SCHERBAKOV	{"phone": "+70872069628"}
0005433261904	7BC7ED	2966 890019	MIKHAIL EGOROV	{"phone": "+70734467788"}
0005433261905	0016AD	4726 057000	VALENTINA KOZLOVA	{"email": "v_kozlova-22101976@postgrespro.ru", "phone": "+70607402038"}
0005433261906	0016AD	7400 712440	DMITRIY GORBUNOV	{"phone": "+70911703975"}
0005433261907	CD8CDA	3447 639732	VALERIY MAKAROV	{"email": "makarov-valeriy.041965@postgrespro.ru", "phone": "+70581111966"}
0005433261908	CD8CDA	4474 389984	EVGENIY ALEKSEEV	{"phone": "+70218298601"}
0005433261909	BAA4ED	1803 447546	VLADISLAV ORLOV	{"email": "vladislav.orlov28021965@postgrespro.ru", "phone": "+70467989447"}
0005433261910	1466CB	2926 774873	ELENA OVCHINNIKOVA	{"phone": "+70944491453"}
0005433261911	768930	5693 024601	TATYANA ANISIMOVA	{"phone": "+70220785712"}
0005433261912	768930	9115 299157	SVETLANA KUZMINA	{"email": "kuzmina_svetlana_1961@postgrespro.ru", "phone": "+70063884435"}
0005433261913	82116F	4207 870204	MARIYA MAKSIMOVA	{"email": "m-maksimova.08071978@postgrespro.ru", "phone": "+70766615912"}
0005433261914	AEBD5B	1669 132345	ANDREY KOZLOV	{"email": "akozlov-021976@postgrespro.ru", "phone": "+70226500116"}
0005433261915	79C075	7451 605192	ALEKSEY BARANOV	{"phone": "+70184949697"}
0005433261916	79C075	9325 764731	EVGENIY MAKAROV	{"email": "e.makarov20041965@postgrespro.ru", "phone": "+70266506157"}
0005433261917	ED4DE1	6375 374362	YURIY KOROLEV	{"email": "yuriy.korolev-1972@postgrespro.ru", "phone": "+70627873952"}
0005433261918	69B084	2933 063854	KSENIYA MIKHAYLOVA	{"email": "kseniya_mikhaylova-1962@postgrespro.ru", "phone": "+70134396484"}
0005433261919	69B084	5131 838126	TATYANA FROLOVA	{"phone": "+70205786559"}
0005433261920	69B084	5876 766706	IRINA TIKHONOVA	{"email": "i_tikhonova_031962@postgrespro.ru", "phone": "+70129443041"}
0005433261921	69B084	4744 647441	NIKOLAY IVANOV	{"phone": "+70802571384"}
0005433261922	76655D	3559 342061	EVGENIY GRIGOREV	{"phone": "+70399457341"}
0005433261923	0AD8B5	4714 214013	ROMAN NOVIKOV	{"email": "r-novikov.111981@postgrespro.ru", "phone": "+70797689106"}
0005433261924	53D9B4	2088 418663	IGOR PAVLOV	{"email": "pavlov_i.1977@postgrespro.ru", "phone": "+70475426792"}
0005433261925	943565	0358 462556	TATYANA IVANOVA	{"phone": "+70517367121"}
0005433261926	943565	0523 068464	KONSTANTIN IVANOV	{"email": "ivanovkonstantin1972@postgrespro.ru", "phone": "+70132438139"}
0005433261927	8FFF1E	1173 730181	RAFAIL MIKHAYLOV	{"phone": "+70422209209"}
0005433261928	8FFF1E	7963 363563	PETR VOLKOV	{"email": "volkov_p.081971@postgrespro.ru", "phone": "+70668334506"}
0005433261929	EEE8ED	8814 962111	MARAT MAKAROV	{"phone": "+70379777077"}
0005433261930	D633F2	3442 094262	VERA LAZAREVA	{"phone": "+70382266276"}
0005433261931	99FC9A	1394 137422	VLADIMIR MIRONOV	{"email": "mironov-v-081971@postgrespro.ru", "phone": "+70463166236"}
0005433261932	B88D16	1525 490881	OLGA PAVLOVA	{"email": "pavlova.olga-021962@postgrespro.ru", "phone": "+70290009015"}
0005433261933	1BC235	5984 671106	ELLA MEDVEDEVA	{"email": "medvedeva_e021972@postgrespro.ru", "phone": "+70534803357"}
0005433261934	1BC235	8427 314966	TATYANA ZAKHAROVA	{"email": "tzakharova_081976@postgrespro.ru", "phone": "+70162725797"}
0005433261935	9CD10B	5699 376291	NATALYA BELYAEVA	{"email": "belyaeva-natalya22071964@postgrespro.ru", "phone": "+70773068725"}
0005433261936	9E207B	9923 460081	SVETLANA NIKITINA	{"phone": "+70695634933"}
0005433261937	CBBDE5	4453 653623	IRINA STEPANOVA	{"phone": "+70561492227"}
0005433261938	A50047	1015 605445	VALENTINA TIKHONOVA	{"email": "v.tikhonova_28051986@postgrespro.ru", "phone": "+70703874023"}
0005433261939	A50047	2700 304809	KARINA POLYAKOVA	{"phone": "+70856148027"}
0005433261940	A50047	1745 004655	EKATERINA KOZLOVA	{"email": "kozlova_e-1976@postgrespro.ru", "phone": "+70902007605"}
0005433261941	2D5391	9201 519152	ALEKSANDRA ILINA	{"phone": "+70328224624"}
0005433261942	2D5391	0088 527649	VLADIMIR SOROKIN	{"email": "vladimir-sorokin_1968@postgrespro.ru", "phone": "+70742483920"}
0005433261943	7F06D0	0665 479711	OKSANA SEMENOVA	{"phone": "+70024384518"}
0005433261944	4FE7AB	7520 349482	VALENTINA MAKSIMOVA	{"phone": "+70662502505"}
0005433261945	4FE7AB	4945 793151	ANATOLIY CHERNOV	{"phone": "+70315628048"}
0005433261946	4FE7AB	6559 719598	DMITRIY MATVEEV	{"phone": "+70956696279"}
0005433261947	0C74BD	0225 577834	EKATERINA STEPANOVA	{"email": "e.stepanova-10121971@postgrespro.ru", "phone": "+70572487918"}
0005433261948	0C74BD	9920 588803	VLADIMIR VASILEV	{"email": "vasilev-v-03101969@postgrespro.ru", "phone": "+70075525383"}
0005433261949	0C74BD	6254 962329	SVETLANA KONOVALOVA	{"email": "konovalova.s19061968@postgrespro.ru", "phone": "+70932759238"}
0005433261950	DECC77	3932 629825	ALEKSEY PAVLOV	{"phone": "+70476898245"}
0005433261951	F63958	3997 819641	ANDREY BELOV	{"email": "andrey-belov_05121977@postgrespro.ru", "phone": "+70549389274"}
0005433261952	409906	7941 819267	NATALYA AKIMOVA	{"phone": "+70017038040"}
0005433261953	409906	3390 101847	OLEG SHEVCHENKO	{"email": "shevchenko-oleg.051974@postgrespro.ru", "phone": "+70260243499"}
0005433261954	3668C4	2392 784957	NATALYA IVANOVA	{"email": "ivanova_natalya.30111964@postgrespro.ru", "phone": "+70494010471"}
0005433261955	609180	9803 316560	SERGEY KUZNECOV	{"phone": "+70971357613"}
0005433261956	17C6F8	8749 486989	STANISLAV KULIKOV	{"email": "s-kulikov_031969@postgrespro.ru", "phone": "+70341823061"}
0005433261957	17C6F8	9984 516093	ILYA MARTYNOV	{"email": "martynov_ilya01091966@postgrespro.ru", "phone": "+70381469447"}
0005433261958	561C7F	4921 457920	ALEKSANDR FEDOROV	{"phone": "+70479401220"}
0005433261959	B789DB	9883 817945	DANIL EGOROV	{"phone": "+70316282802"}
0005433261960	B789DB	0902 542931	VLADIMIR RODIONOV	{"phone": "+70574983583"}
0005433261961	E8F850	6635 265258	AMIR EGOROV	{"phone": "+70212489286"}
0005433261962	E8F850	3765 172639	NIKOLAY SCHERBAKOV	{"phone": "+70707724837"}
0005433261963	E8F850	9302 160175	GALINA KISELEVA	{"email": "galina_kiseleva101970@postgrespro.ru", "phone": "+70677465445"}
0005433261964	AC5376	3294 375298	ALEKSEY GORBUNOV	{"phone": "+70384425205"}
0005433261965	C5F2AD	5300 588295	VLADIMIR GAVRILOV	{"phone": "+70458896507"}
0005433261966	B5C9FB	3812 192380	OLGA GORBUNOVA	{"email": "olgagorbunova-19041975@postgrespro.ru", "phone": "+70627787928"}
0005433261967	0EB752	6704 871140	NADEZHDA LEBEDEVA	{"phone": "+70986864548"}
0005433261968	0EB752	2753 721389	ANNA SERGEEVA	{"email": "annasergeeva1958@postgrespro.ru", "phone": "+70949497650"}
0005433261969	3EE566	7777 495981	ELENA FILIPPOVA	{"email": "filippovae_111968@postgrespro.ru", "phone": "+70272581176"}
0005433261970	3EE566	3735 728262	YULIYA SERGEEVA	{"email": "y-sergeeva24011968@postgrespro.ru", "phone": "+70396671468"}
0005433261971	3EE566	1129 681398	KONSTANTIN BONDARENKO	{"phone": "+70208392880"}
0005433261972	2FD7DB	1596 174511	ALEKSEY SEMENOV	{"email": "semenov_a-1972@postgrespro.ru", "phone": "+70521481376"}
0005433261973	2FD7DB	8198 761934	IGOR CHERNOV	{"email": "chernov_igor-1970@postgrespro.ru", "phone": "+70052075990"}
0005433261974	ACBC43	6779 604787	VITALIY ZAYCEV	{"phone": "+70447471990"}
0005433261975	ACBC43	1487 464876	SOFYA EGOROVA	{"phone": "+70987110709"}
0005433261976	808401	2751 140117	ALEKSEY AFANASEV	{"email": "a-afanasev-091969@postgrespro.ru", "phone": "+70499053077"}
0005433261977	C3F9E1	0319 692168	NIKITA ALEKSEEV	{"email": "nikita.alekseev.041974@postgrespro.ru", "phone": "+70296806593"}
0005433261978	C3F9E1	9839 926532	NATALYA EFIMOVA	{"phone": "+70652676297"}
0005433261979	C24D18	9765 354978	OLGA STEPANOVA	{"email": "o-stepanova1957@postgrespro.ru", "phone": "+70481324290"}
0005433261980	C24D18	7844 595571	TAMARA KAZAKOVA	{"phone": "+70165261748"}
0005433261981	29A503	2042 201458	SERGEY MATVEEV	{"email": "sergey-matveev_1974@postgrespro.ru", "phone": "+70971482494"}
0005433261982	5DAD90	5653 723890	GLEB GORBUNOV	{"email": "gorbunov-gleb.31071970@postgrespro.ru", "phone": "+70300684027"}
0005433261983	5DAD90	1388 358265	DARYA KUZNECOVA	{"phone": "+70364563525"}
0005433261984	0916E5	4406 428843	OLGA KUZNECOVA	{"email": "olga-kuznecova07091976@postgrespro.ru", "phone": "+70525700181"}
0005433261985	E4FEB7	7379 558012	VLADIMIR KOZLOV	{"email": "kozlov-v121967@postgrespro.ru", "phone": "+70338286139"}
0005433261986	5AB7E4	0841 155297	VENIAMIN SIDOROV	{"phone": "+70715610873"}
0005433261987	AB6FE1	0491 337248	EVGENIYA GERASIMOVA	{"phone": "+70561531773"}
0005433261988	EA8FFB	5647 258554	TATYANA SMIRNOVA	{"phone": "+70974955269"}
0005433261989	EA8FFB	8937 942025	SVETLANA MOROZOVA	{"email": "morozovas.27111971@postgrespro.ru", "phone": "+70958051293"}
0005433261990	7788F7	9252 549316	LARISA PAVLOVA	{"email": "larisapavlova071968@postgrespro.ru", "phone": "+70491099010"}
0005433261991	3CC27F	9734 439275	IGOR ISAEV	{"phone": "+70542648661"}
0005433261992	FCB3E9	6812 733472	MAKSIM ISAEV	{"phone": "+70725437794"}
0005433261993	DF88C3	3062 518085	MIKHAIL KOZLOV	{"phone": "+70951323508"}
0005433261994	DF88C3	0174 961967	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr-1974@postgrespro.ru", "phone": "+70984422628"}
0005433261995	EB0BDB	7919 005038	TATYANA MELNIKOVA	{"email": "melnikova-t-1976@postgrespro.ru", "phone": "+70114782937"}
0005433261996	B03D6E	3082 687279	DENIS MAKAROV	{"email": "makarov.denis-021968@postgrespro.ru", "phone": "+70662488133"}
0005433261997	68E7EE	9783 188711	VLADIMIR SOROKIN	{"email": "vladimir-sorokin_011974@postgrespro.ru", "phone": "+70399114064"}
0005433261998	68E7EE	6272 140312	YURIY KUZNECOV	{"email": "y.kuznecov1974@postgrespro.ru", "phone": "+70927853004"}
0005433261999	567747	9718 858869	LIDIYA VOLKOVA	{"email": "volkova.lidiya_1966@postgrespro.ru", "phone": "+70942938308"}
0005433262000	567747	2493 925009	VERA DMITRIEVA	{"phone": "+70292181106"}
0005433262001	7EF3C7	3998 418069	EKATERINA KOMAROVA	{"phone": "+70383020335"}
0005433262002	589873	9539 305770	PETR AFANASEV	{"phone": "+70118889549"}
0005433262003	589873	6220 778743	SVETLANA BORISOVA	{"phone": "+70429650868"}
0005433262004	67793D	6822 092608	TATYANA ANTONOVA	{"phone": "+70735956692"}
0005433262005	366523	3073 844727	ALEKSEY ABRAMOV	{"phone": "+70939909669"}
0005433262006	B09521	2460 113064	ANATOLIY MELNIKOV	{"email": "a.melnikov-04011976@postgrespro.ru", "phone": "+70920256459"}
0005433262007	88F2C8	9558 889627	OLGA KARPOVA	{"phone": "+70624953868"}
0005433262008	4CF62D	3072 785404	EVGENIYA PETROVA	{"phone": "+70311480206"}
0005433262010	66D4D6	4698 943637	GENNADIY IVANOV	{"email": "gennadiy.ivanov20091973@postgrespro.ru", "phone": "+70988460822"}
0005433262011	66D4D6	3024 484250	POLINA ISAEVA	{"email": "polina.isaeva041977@postgrespro.ru", "phone": "+70294766057"}
0005433262012	D9709B	1773 748149	SVETLANA ABRAMOVA	{"email": "abramovas_041973@postgrespro.ru", "phone": "+70276882440"}
0005433262013	AB6739	3024 871279	OLGA EGOROVA	{"phone": "+70561298002"}
0005433262014	F474AD	6854 575509	NATALYA CHERNOVA	{"email": "natalya_chernova1971@postgrespro.ru", "phone": "+70277424535"}
0005433262015	140DCF	6350 356151	TAMARA KUZNECOVA	{"email": "kuznecovat-16081983@postgrespro.ru", "phone": "+70058875749"}
0005433262016	140DCF	5294 436314	ANNA KOZLOVA	{"phone": "+70758055055"}
0005433262017	170A90	7541 083243	ZOYA MIKHAYLOVA	{"phone": "+70838665059"}
0005433262018	480AEF	4227 604796	MARINA ANTONOVA	{"phone": "+70758029340"}
0005433262019	480AEF	4058 869623	ANATOLIY NIKITIN	{"email": "nikitinanatoliy_1974@postgrespro.ru", "phone": "+70341442880"}
0005433262020	B3BEAB	0833 003221	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov1968@postgrespro.ru", "phone": "+70961418166"}
0005433262021	BC9A15	7607 437755	ANASTASIYA ALEKSEEVA	{"phone": "+70037462893"}
0005433262022	D2C644	1046 215395	YULIYA RODIONOVA	{"phone": "+70400555742"}
0005433262023	98FACB	9428 402881	VADIM FOMIN	{"phone": "+70117109870"}
0005433262024	98FACB	4083 315182	VLADIMIR BORISOV	{"email": "borisovv.1984@postgrespro.ru", "phone": "+70557716885"}
0005433262025	98FACB	9610 462644	MARIYA EGOROVA	{"phone": "+70282095479"}
0005433262026	2D3D96	4533 646515	ANATOLIY VOLKOV	{"phone": "+70983250514"}
0005433262027	181E30	5613 882625	NADEZHDA EFIMOVA	{"email": "efimova_n.041984@postgrespro.ru", "phone": "+70858684539"}
0005433262028	1F5702	6963 810642	VADIM GORBUNOV	{"email": "v-gorbunov-061963@postgrespro.ru", "phone": "+70087978492"}
0005433262029	4C1460	3910 137039	MARIYA NAZAROVA	{"email": "mariya.nazarova1970@postgrespro.ru", "phone": "+70574353357"}
0005433262030	6FE580	3619 947269	ANDREY SERGEEV	{"phone": "+70256732538"}
0005433262031	6FE580	3085 217033	ZHANNA DANILOVA	{"phone": "+70724461046"}
0005433262032	E35611	4353 645719	VLADIMIR KOROLEV	{"email": "korolevvladimir16051988@postgrespro.ru", "phone": "+70510711187"}
0005433262033	E35611	6534 849100	NATALIYA POPOVA	{"email": "popova-n_051974@postgrespro.ru", "phone": "+70403815951"}
0005433262034	335C22	7523 105254	ELENA ZOTOVA	{"email": "elenazotova-101963@postgrespro.ru", "phone": "+70193409377"}
0005433262035	F87A52	5620 012425	NATALYA NESTEROVA	{"phone": "+70352010284"}
0005433262036	8B1999	6023 763484	KONSTANTIN OSIPOV	{"phone": "+70422457252"}
0005433262037	C908E9	5078 879907	ANDREY ALEKSANDROV	{"phone": "+70085906136"}
0005433262038	F641E2	0605 358593	ELENA KOVALEVA	{"email": "e-kovaleva_061963@postgrespro.ru", "phone": "+70587621422"}
0005433262039	F641E2	3574 669771	SVETLANA YUDINA	{"email": "yudina_s1985@postgrespro.ru", "phone": "+70030475357"}
0005433262040	F03AFA	4552 904088	IGOR KUZMIN	{"phone": "+70848988015"}
0005433262041	BFE8A5	3168 492702	VIKTORIYA IVANOVA	{"email": "v.ivanova-101979@postgrespro.ru", "phone": "+70439038412"}
0005433262042	BFE8A5	9222 297776	YURIY ZHUKOV	{"phone": "+70584517454"}
0005433262043	BFE8A5	2844 054558	ARTUR MOISEEV	{"email": "amoiseev_23081971@postgrespro.ru", "phone": "+70928340373"}
0005433262044	8EA75F	9188 934349	ALEKSEY NAZAROV	{"email": "nazarov-aleksey_101962@postgrespro.ru", "phone": "+70826664825"}
0005433262045	8EA75F	7763 421343	VLADIMIR VOLKOV	{"phone": "+70370207185"}
0005433262046	0E26A6	0999 467139	ARTEM POPOV	{"phone": "+70807510112"}
0005433262047	0E26A6	0840 931558	NINA KARPOVA	{"email": "nina-karpova-09091974@postgrespro.ru", "phone": "+70388371380"}
0005433262048	492D92	2663 521185	ALEKSANDRA PETROVA	{"phone": "+70665334233"}
0005433262049	492D92	0839 118786	PAVEL EGOROV	{"phone": "+70988276033"}
0005433262050	F1190B	0547 877733	ANASTASIYA KRASNOVA	{"phone": "+70109513931"}
0005433262051	E50B7E	1776 687375	VLADIMIR STEPANOV	{"email": "vladimir-stepanov1976@postgrespro.ru", "phone": "+70424543105"}
0005433262052	9EBC45	8806 516724	VASILIY CHERNOV	{"email": "vchernov111971@postgrespro.ru", "phone": "+70084003369"}
0005433262053	9EBC45	5150 207848	ANATOLIY ZAKHAROV	{"email": "zakharov_a-1975@postgrespro.ru", "phone": "+70235772794"}
0005433262054	44AF31	1741 136673	TIMUR KOZLOV	{"email": "kozlovtimur.1979@postgrespro.ru", "phone": "+70251376930"}
0005433262055	45F3E6	7935 600023	TATYANA LEBEDEVA	{"email": "lebedeva_tatyana_13121966@postgrespro.ru", "phone": "+70082213864"}
0005433262056	540DA1	9880 965026	VERA PAVLOVA	{"email": "v_pavlova_121980@postgrespro.ru", "phone": "+70795600195"}
0005433262057	540DA1	2898 531795	VLADIMIR KARPOV	{"email": "v.karpov071969@postgrespro.ru", "phone": "+70738581556"}
0005433262058	58B6C7	0524 816792	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr.061977@postgrespro.ru", "phone": "+70827609261"}
0005433262059	4A655B	5619 765318	MARIYA BORISOVA	{"phone": "+70473353945"}
0005433262060	4A655B	3838 820607	ELENA KAZAKOVA	{"email": "e_kazakova101974@postgrespro.ru", "phone": "+70328810158"}
0005433262061	BE72DE	9129 671227	LIDIYA GAVRILOVA	{"phone": "+70967205453"}
0005433262062	4D8AAF	7141 585397	RUSLAN GAVRILOV	{"email": "gavrilov_r-041974@postgrespro.ru", "phone": "+70448367795"}
0005433262063	5DDE8E	7678 266375	SERGEY ZAYCEV	{"email": "sergey.zaycev.05081969@postgrespro.ru", "phone": "+70228425472"}
0005433262064	5DDE8E	0651 936564	YULIYA DAVYDOVA	{"email": "davydova-yuliya_12041974@postgrespro.ru", "phone": "+70191056201"}
0005433266556	DA6E58	8905 579374	IGOR ANTONOV	{"email": "igor.antonov_11111967@postgrespro.ru", "phone": "+70135682579"}
0005433266557	736CB1	0069 296631	ELIZAVETA PETROVA	{"email": "petrovaelizaveta_1972@postgrespro.ru", "phone": "+70330634098"}
0005433266558	73D95E	6881 233743	ANATOLIY BONDARENKO	{"email": "a.bondarenko12041968@postgrespro.ru", "phone": "+70345332721"}
0005433266559	7E7C23	6350 377789	YULIYA CHERNOVA	{"phone": "+70377223469"}
0005433266560	7E7C23	3931 259072	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya_08031973@postgrespro.ru", "phone": "+70133529979"}
0005433266561	129F87	0703 337448	TATYANA NIKITINA	{"email": "nikitinat27121975@postgrespro.ru", "phone": "+70764114307"}
0005433266562	F628D2	1686 854543	ALENA DANILOVA	{"phone": "+70920787673"}
0005433266563	F628D2	3208 739745	EVGENIY IVANOV	{"email": "e-ivanov_1967@postgrespro.ru", "phone": "+70956186162"}
0005433266564	9BC27A	2606 386253	LYUDMILA ZOTOVA	{"email": "lyudmila-zotova.041980@postgrespro.ru", "phone": "+70167813545"}
0005433266565	AE243C	4884 930467	ALEKSEY MAKAROV	{"phone": "+70606628749"}
0005433266566	AE243C	1588 884021	LILIYA NIKOLAEVA	{"phone": "+70688004923"}
0005433266567	23B3E1	9899 401254	ANNA KRASNOVA	{"phone": "+70848671535"}
0005433266568	2691AC	9288 004202	RASHID ABRAMOV	{"email": "r.abramov_18081976@postgrespro.ru", "phone": "+70516347088"}
0005433266569	2691AC	2483 315666	VLADIMIR GERASIMOV	{"phone": "+70180246346"}
0005433266570	560EE5	1182 389866	IRINA SIDOROVA	{"email": "sidorovairina-27051966@postgrespro.ru", "phone": "+70740721319"}
0005433266571	F20835	5938 668000	DANILA GUSEV	{"email": "gusev.danila.121969@postgrespro.ru", "phone": "+70846846910"}
0005433266572	98F2D1	5725 567812	NADEZHDA KULIKOVA	{"phone": "+70479969090"}
0005433266573	98F2D1	6827 617162	ANATOLIY MIKHAYLOV	{"phone": "+70332018536"}
0005433266574	296BD8	0462 723834	SERGEY KUDRYASHOV	{"phone": "+70552765387"}
0005433266575	47D662	9203 489761	VLADISLAV KUZNECOV	{"email": "v-kuznecov.041965@postgrespro.ru", "phone": "+70916404515"}
0005433266576	47D662	1626 310865	VLADIMIR KUZNECOV	{"phone": "+70601549557"}
0005433266577	07F118	1544 562214	EVGENIY IVANOV	{"phone": "+70632714957"}
0005433266578	CF5A4A	7796 002385	KHASAN KOZLOV	{"email": "khasan.kozlov_071973@postgrespro.ru", "phone": "+70645111729"}
0005433266579	0CED47	6088 935670	ANNA GUSEVA	{"email": "guseva.a111960@postgrespro.ru", "phone": "+70347641877"}
0005433266580	0CED47	0572 182868	MIKHAIL ALEKSEEV	{"phone": "+70400862466"}
0005433266581	08080E	5910 280799	GEORGIY MIRONOV	{"email": "mironov.georgiy.021973@postgrespro.ru", "phone": "+70806350323"}
0005433266582	08080E	9971 025931	VASILIY NOVIKOV	{"phone": "+70478885025"}
0005433266583	08080E	8330 134235	ELIZAVETA SMIRNOVA	{"email": "smirnova_e_18081986@postgrespro.ru", "phone": "+70778208987"}
0005433266584	5B8F3B	5677 433045	SOFYA VOLKOVA	{"email": "sofyavolkova_081971@postgrespro.ru", "phone": "+70492241813"}
0005433266585	FD2ED4	1987 611554	POLINA KONOVALOVA	{"email": "polinakonovalova-1978@postgrespro.ru", "phone": "+70779197969"}
0005433266586	467079	7189 640504	MARIYA SOROKINA	{"email": "mariya_sorokina-1970@postgrespro.ru", "phone": "+70720828353"}
0005433266587	F42B7D	4526 070998	VIKTORIYA NOVIKOVA	{"email": "novikovaviktoriya.1981@postgrespro.ru", "phone": "+70992605445"}
0005433266588	D46B57	9922 968491	IRINA KOROLEVA	{"phone": "+70503700197"}
0005433266589	CBD8DC	6001 306929	ELIZAVETA GUSEVA	{"email": "eguseva-091972@postgrespro.ru", "phone": "+70685526176"}
0005433266590	0A90A0	3852 670872	NADEZHDA ANDREEVA	{"phone": "+70254800902"}
0005433266591	0A90A0	2500 970898	ALEKSEY SHEVCHENKO	{"email": "alekseyshevchenko_1969@postgrespro.ru", "phone": "+70713008404"}
0005433266592	372F9F	4368 091460	ROMAN KUDRYASHOV	{"phone": "+70675769686"}
0005433266593	35B88F	0496 329968	GALINA GAVRILOVA	{"email": "gavrilova.g-17101978@postgrespro.ru", "phone": "+70181122225"}
0005433266594	72B1F7	6059 577380	ANASTASIYA GORBUNOVA	{"phone": "+70571316479"}
0005433266595	C3BF99	7955 249857	ROMAN KISELEV	{"phone": "+70236627188"}
0005433266596	57A8EB	3467 006327	ZINAIDA ANDREEVA	{"phone": "+70215160199"}
0005433266597	3CA31B	9987 217269	ANZHELA VASILEVA	{"phone": "+70616101258"}
0005433266598	19FD61	2456 209652	SVETLANA ZAYCEVA	{"phone": "+70419368754"}
0005433266599	BAE258	0071 736961	ALEKSANDR SOKOLOV	{"phone": "+70391161672"}
0005433266600	BAE258	9554 444487	EVGENIY TIKHONOV	{"phone": "+70441493596"}
0005433266601	BBB064	8840 595258	OLEG KUZNECOV	{"email": "kuznecov.o.1967@postgrespro.ru", "phone": "+70347587694"}
0005433266602	2ACA4E	6776 474174	DENIS SHEVCHENKO	{"phone": "+70128374068"}
0005433266603	A1F437	9172 922626	ILYA ROMANOV	{"email": "romanovi.09111963@postgrespro.ru", "phone": "+70979603986"}
0005433266604	9ED337	5159 477772	ALBERT VOLKOV	{"email": "albert.volkov_1966@postgrespro.ru", "phone": "+70651763639"}
0005433266605	9ED337	3142 000288	PAVEL KAZAKOV	{"email": "kazakov-p18021964@postgrespro.ru", "phone": "+70082587668"}
0005433266606	953A9D	7660 498917	NADEZHDA SOROKINA	{"phone": "+70980935831"}
0005433266607	953A9D	6480 769201	NINA MIRONOVA	{"phone": "+70250294384"}
0005433266608	0540C1	4701 849668	VLADIMIR KUZNECOV	{"phone": "+70527409927"}
0005433266609	EB8417	5908 708773	GALINA BELYAEVA	{"email": "belyaeva.galina.1975@postgrespro.ru", "phone": "+70133755860"}
0005433266610	C94DEE	1992 619420	ANATOLIY PETROV	{"phone": "+70769642701"}
0005433266611	C94DEE	1069 108551	GALINA IVANOVA	{"phone": "+70066297821"}
0005433266612	0F9DFE	8414 242224	VLADIMIR KUZNECOV	{"email": "kuznecov_v_08111962@postgrespro.ru", "phone": "+70195351410"}
0005433266613	0F9DFE	4816 434307	ANASTASIYA VASILEVA	{"phone": "+70438545973"}
0005433266614	6BE297	1573 064981	VASILIY IVANOV	{"email": "v-ivanov1967@postgrespro.ru", "phone": "+70522285777"}
0005433266615	6BE297	5123 618998	GALINA POLYAKOVA	{"phone": "+70749157111"}
0005433266616	A70BBF	5629 067719	PAVEL KISELEV	{"email": "p_kiselev29031988@postgrespro.ru", "phone": "+70323141369"}
0005433266617	D0470A	2439 994018	TATYANA SEMENOVA	{"email": "t-semenova121974@postgrespro.ru", "phone": "+70979026155"}
0005433266618	73EC3A	8396 236120	MARIYA NAZAROVA	{"email": "mariya-nazarova.011974@postgrespro.ru", "phone": "+70679120310"}
0005433266619	3AD37C	9771 587230	ALEKSEY KARPOV	{"email": "karpova031984@postgrespro.ru", "phone": "+70347143085"}
0005433266620	B5B958	2476 423608	ALEKSANDRA ABRAMOVA	{"email": "a.abramova-22071967@postgrespro.ru", "phone": "+70589441162"}
0005433266621	32443D	4945 277643	ELENA VOLKOVA	{"email": "e_volkova_31051974@postgrespro.ru", "phone": "+70302749537"}
0005433266622	33E5DC	6775 072659	SVETLANA MOROZOVA	{"phone": "+70822711783"}
0005433266623	33E5DC	1493 867337	VLADIMIR RODIONOV	{"phone": "+70641982787"}
0005433266624	A6FED3	2795 968625	ALEKSANDRA NOVIKOVA	{"email": "aleksandra-novikova_081977@postgrespro.ru", "phone": "+70230763630"}
0005433266625	21F9A6	8134 760516	LYUBOV KOMAROVA	{"email": "komarovalyubov_121971@postgrespro.ru", "phone": "+70659041078"}
0005433266626	21F9A6	8899 170304	SNEZHANA NIKOLAEVA	{"email": "nikolaeva-s05071962@postgrespro.ru", "phone": "+70892565978"}
0005433266627	815031	9127 364976	IGOR NAUMOV	{"email": "i_naumov-121982@postgrespro.ru", "phone": "+70559776274"}
0005433266628	E25BFC	7341 768494	VALENTINA OSIPOVA	{"email": "osipova_valentina.031966@postgrespro.ru", "phone": "+70876418662"}
0005433266629	E25BFC	5696 646536	RAFAIL GERASIMOV	{"phone": "+70909224890"}
0005433266630	9CED01	5331 180519	NINA VOLKOVA	{"email": "volkovan_1969@postgrespro.ru", "phone": "+70705296029"}
0005433266631	163699	4772 056388	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov.02021976@postgrespro.ru", "phone": "+70128918189"}
0005433266632	163699	1922 221110	MIKHAIL BORISOV	{"phone": "+70681590751"}
0005433266633	D9FEC3	0951 645173	NATALYA VOROBEVA	{"phone": "+70123170390"}
0005433266634	D9FEC3	3300 403285	NURLAN ALEKSANDROV	{"phone": "+70798251849"}
0005433266635	049069	2181 984673	EVGENIYA IVANOVA	{"phone": "+70643827652"}
0005433266636	049069	0125 284842	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr.031960@postgrespro.ru", "phone": "+70070929256"}
0005433266637	049069	5356 112023	ARTEM TIKHONOV	{"phone": "+70117265790"}
0005433266638	2EBC3D	9423 962698	ELENA KUZNECOVA	{"phone": "+70596615638"}
0005433266639	3F577E	5774 244735	ALEKSANDR SEMENOV	{"email": "a-semenov_061967@postgrespro.ru", "phone": "+70007604836"}
0005433266640	6B060A	0215 257306	MIKHAIL ALEKSANDROV	{"phone": "+70291226675"}
0005433266641	00B629	5037 132071	PAVEL SERGEEV	{"email": "pavel-sergeev-011969@postgrespro.ru", "phone": "+70360861889"}
0005433266642	22F948	0316 420403	IRINA CHERNOVA	{"email": "chernova-irina.12071974@postgrespro.ru", "phone": "+70343486736"}
0005433266643	EFA1B1	2794 667046	VADIM SAVELEV	{"email": "v-savelev_1980@postgrespro.ru", "phone": "+70164847369"}
0005433266644	EFA1B1	0093 914179	TATYANA SERGEEVA	{"phone": "+70882760538"}
0005433266645	BF747B	9846 240103	LYUDMILA FADEEVA	{"phone": "+70636863428"}
0005433266646	A6448D	0017 238622	NINA MALYSHEVA	{"email": "nmalysheva.101973@postgrespro.ru", "phone": "+70918271506"}
0005433266647	44C6D0	4798 012816	VIKTORIYA TIKHONOVA	{"email": "tikhonovav1958@postgrespro.ru", "phone": "+70878658381"}
0005433266648	04652D	0111 365733	VIKTORIYA NESTEROVA	{"email": "viktoriya-nesterova.1957@postgrespro.ru", "phone": "+70361237534"}
0005433266649	04652D	3694 671532	IVAN SOROKIN	{"phone": "+70192836519"}
0005433266650	C4977B	5109 130002	ALEKSANDR KOZLOV	{"email": "kozlov.a_26081971@postgrespro.ru", "phone": "+70838099457"}
0005433266651	6EB446	4775 129908	NATALYA MALYSHEVA	{"email": "natalya-malysheva_101976@postgrespro.ru", "phone": "+70625916094"}
0005433266652	6EB446	9705 013192	NINA ZAKHAROVA	{"phone": "+70999856672"}
0005433266653	27F015	5029 972021	MARINA STEPANOVA	{"email": "stepanova_marina.1984@postgrespro.ru", "phone": "+70638524903"}
0005433266654	B2E953	8715 697295	EKATERINA VASILEVA	{"email": "e_vasileva-021978@postgrespro.ru", "phone": "+70511838645"}
0005433266655	06D592	3239 029558	ALEKSEY MELNIKOV	{"phone": "+70523478926"}
0005433266656	16FE09	7753 326859	NIKOLAY GUSEV	{"phone": "+70458739546"}
0005433266657	E18A0B	5931 478016	GALINA PETROVA	{"phone": "+70772620066"}
0005433266658	ABB476	8948 966413	VIKTORIYA VASILEVA	{"email": "vasileva_viktoriya.09081994@postgrespro.ru", "phone": "+70645358056"}
0005433266659	6CDF16	1297 881132	OLGA POPOVA	{"email": "o.popova.021971@postgrespro.ru", "phone": "+70797832186"}
0005433266660	620EEA	1213 233642	LYUDMILA ZAYCEVA	{"email": "lyudmilazayceva_1965@postgrespro.ru", "phone": "+70331950027"}
0005433266661	AE9544	0675 539718	TATYANA MEDVEDEVA	{"email": "tatyana.medvedeva-1985@postgrespro.ru", "phone": "+70417762991"}
0005433266662	52D883	1249 293753	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.1971@postgrespro.ru", "phone": "+70172616999"}
0005433266663	EEE036	6675 162526	ANDREY PETROV	{"email": "a.petrov.1973@postgrespro.ru", "phone": "+70099876064"}
0005433266664	EEE036	3123 993137	RAISA KONOVALOVA	{"phone": "+70764853289"}
0005433266665	032080	6571 285972	YURIY SMIRNOV	{"email": "smirnov-yuriy.091975@postgrespro.ru", "phone": "+70615682540"}
0005433266666	19939A	5996 623783	ALEKSANDRA YAKOVLEVA	{"phone": "+70353425425"}
0005433266667	94B817	4774 571635	TAMARA VOROBEVA	{"phone": "+70849482044"}
0005433266668	94B817	0869 082365	VLADIMIR CHERNOV	{"phone": "+70729887904"}
0005433266669	94B817	8179 012188	NIKOLAY CHERNOV	{"email": "nikolay-chernov-1980@postgrespro.ru", "phone": "+70410269352"}
0005433266670	519BEA	9924 630465	ELENA SEMENOVA	{"phone": "+70640531299"}
0005433266671	519BEA	6401 019578	EVGENIY DENISOV	{"phone": "+70128927688"}
0005433266672	519BEA	4297 289874	ALEKSANDR NAZAROV	{"email": "nazarov_a_06101978@postgrespro.ru", "phone": "+70242928724"}
0005433266673	706319	5422 381212	ALEKSEY SAVELEV	{"email": "savelev_aleksey101972@postgrespro.ru", "phone": "+70531732262"}
0005433266674	279A49	3233 636802	ANATOLIY TIMOFEEV	{"email": "a-timofeev.011972@postgrespro.ru", "phone": "+70958338029"}
0005433266675	5BEBCC	2600 865724	NIKITA PETROV	{"email": "nikita_petrov.111976@postgrespro.ru", "phone": "+70137491533"}
0005433266676	6BD7CE	4930 821110	VALENTINA SERGEEVA	{"phone": "+70496944226"}
0005433266677	D5E767	2379 454089	OLGA ANISIMOVA	{"email": "olga-anisimova_101967@postgrespro.ru", "phone": "+70707518670"}
0005433266742	410CD9	9235 316421	SVETLANA MOISEEVA	{"phone": "+70119520400"}
0005433266678	1B1A39	4832 051741	OLEG IVANOV	{"email": "o-ivanov-1957@postgrespro.ru", "phone": "+70230225382"}
0005433266679	19DB62	6505 080537	NINA LAZAREVA	{"email": "lazarevanina_081974@postgrespro.ru", "phone": "+70067075083"}
0005433266680	19DB62	2908 740520	ANASTASIYA ZHUKOVA	{"phone": "+70256339421"}
0005433266681	71B111	7365 360721	SERGEY GAVRILOV	{"phone": "+70042450775"}
0005433266682	3E652C	3703 635298	MARIYA TARASOVA	{"phone": "+70234129785"}
0005433266683	00C199	3430 261350	ANDREY MOROZOV	{"email": "morozova.21031972@postgrespro.ru", "phone": "+70978309173"}
0005433266684	435C63	4630 164258	NATALYA KALININA	{"phone": "+70747374579"}
0005433266685	F460BD	2234 047733	EKATERINA MIKHAYLOVA	{"email": "ekaterina-mikhaylova.101958@postgrespro.ru", "phone": "+70331979301"}
0005433266686	69CE74	8876 058660	ALEKSEY SHEVCHENKO	{"phone": "+70327552119"}
0005433266687	F0CE73	8210 807429	ANNA DAVYDOVA	{"email": "davydova-anna.021970@postgrespro.ru", "phone": "+70601841870"}
0005433266688	167D6F	4489 004995	EVGENIY ANDREEV	{"email": "andreevevgeniy041968@postgrespro.ru", "phone": "+70850534658"}
0005433266689	167D6F	3320 697630	ELENA NAUMOVA	{"email": "elenanaumova_1966@postgrespro.ru", "phone": "+70875361636"}
0005433266690	0ADB38	8799 681438	YURIY ZAKHAROV	{"email": "zakharov-y.1966@postgrespro.ru", "phone": "+70233256566"}
0005433266691	0ADB38	9637 401441	ANDREY YAKOVLEV	{"phone": "+70064386718"}
0005433266692	2E177B	6327 033722	DMITRIY TIKHONOV	{"phone": "+70523517164"}
0005433266693	BD9316	8332 697599	MARINA KUZNECOVA	{"email": "marina-kuznecova.20111968@postgrespro.ru", "phone": "+70475937472"}
0005433266694	BD9316	6747 705369	VLADISLAV ZAYCEV	{"email": "vladislav.zaycev_1961@postgrespro.ru", "phone": "+70004813467"}
0005433266695	57C743	5932 324280	EKATERINA PETROVA	{"phone": "+70043149078"}
0005433266696	57C743	4911 184748	SERGEY KULIKOV	{"phone": "+70657528228"}
0005433266697	862BA8	8181 637527	ALEKSEY ALEKSEEV	{"phone": "+70529627250"}
0005433266698	48AE95	4532 749476	KIRILL ZHURAVLEV	{"phone": "+70297285250"}
0005433266699	48AE95	1043 582120	ELENA POPOVA	{"phone": "+70823683924"}
0005433266700	48AE95	7005 780005	OLGA MOROZOVA	{"phone": "+70963689827"}
0005433266701	23A7C6	2352 486945	ELENA NIKITINA	{"email": "nikitinae-041971@postgrespro.ru", "phone": "+70210707235"}
0005433266702	15BC0E	0347 985045	LIDIYA ABRAMOVA	{"phone": "+70206848220"}
0005433266703	FA66ED	0428 681201	ANATOLIY KOROLEV	{"phone": "+70008768409"}
0005433266704	64632B	7827 331775	TATYANA KARPOVA	{"email": "karpovat1973@postgrespro.ru", "phone": "+70504996328"}
0005433266705	64632B	3877 929206	NIKOLAY IVANOV	{"email": "ivanov.nikolay.1969@postgrespro.ru", "phone": "+70764505227"}
0005433266706	FB5115	4307 355871	INNA POPOVA	{"email": "popova-i-081976@postgrespro.ru", "phone": "+70575932899"}
0005433266707	0A7048	7869 563695	PELAGEYA FOMINA	{"email": "pelageya.fomina07031977@postgrespro.ru", "phone": "+70178148958"}
0005433266708	94C8B5	1122 492386	POLINA YAKOVLEVA	{"phone": "+70067187800"}
0005433266709	42B726	6293 677562	VASILIY BELOV	{"phone": "+70865991816"}
0005433266710	9A4893	9396 446776	KAMIL VLASOV	{"email": "vlasov.k021970@postgrespro.ru", "phone": "+70012097113"}
0005433266711	9A4893	9457 470243	NATALYA ROMANOVA	{"phone": "+70653843480"}
0005433266712	D67065	4321 262143	ELINA KOMAROVA	{"phone": "+70632217354"}
0005433266713	F4A43F	6857 195105	ANNA KUZMINA	{"phone": "+70795948966"}
0005433266714	F4A43F	2655 911652	ELENA MAKAROVA	{"phone": "+70965319218"}
0005433266715	3DF06F	0534 804438	LYUBOV KOZLOVA	{"phone": "+70567776869"}
0005433266716	AF79D7	2455 851128	TIMOFEY MOISEEV	{"phone": "+70457325331"}
0005433266717	AF79D7	0063 909599	ANTONINA AKIMOVA	{"phone": "+70904817620"}
0005433266718	49500D	3679 398085	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.nikolay_05041978@postgrespro.ru", "phone": "+70342180688"}
0005433266719	49500D	1269 099598	RIM POPOV	{"phone": "+70003759374"}
0005433266720	94D062	0798 027870	NADIYA GORBUNOVA	{"phone": "+70435564622"}
0005433266721	94D062	6842 795519	LIDIYA POTAPOVA	{"phone": "+70026002761"}
0005433266722	94D062	6759 544096	ANDREY MAKSIMOV	{"phone": "+70415903511"}
0005433266723	94D062	7124 298876	PETR KOROLEV	{"email": "korolevp.1981@postgrespro.ru", "phone": "+70215899525"}
0005433266724	739C4A	0318 954426	SERGEY ANDREEV	{"phone": "+70445184030"}
0005433266725	56A84B	0684 179967	IBRAGIM POPOV	{"phone": "+70389671416"}
0005433266726	56A84B	2946 340827	ALEKSANDR MOROZOV	{"phone": "+70325505239"}
0005433266727	372942	7933 163995	VALENTINA ISAEVA	{"phone": "+70131776925"}
0005433266728	372942	1553 590237	IVAN IVANOV	{"phone": "+70474877495"}
0005433266729	BE30F0	9676 662981	DENIS FROLOV	{"phone": "+70195468340"}
0005433266730	376E42	3591 798208	SVETLANA LAZAREVA	{"phone": "+70665017632"}
0005433266731	0567FD	2088 121066	MAKSIM VOLKOV	{"email": "volkovm-20101970@postgrespro.ru", "phone": "+70968293873"}
0005433266732	8A8CC8	4959 721627	LIDIYA KRASNOVA	{"phone": "+70237472829"}
0005433266733	8A8CC8	4877 346622	DANIL FOMIN	{"phone": "+70359051354"}
0005433266734	5B27B3	1087 232007	ANASTASIYA KRASNOVA	{"email": "krasnova_anastasiya_09121976@postgrespro.ru", "phone": "+70513388993"}
0005433266735	9DD816	3495 039259	ALLA GERASIMOVA	{"email": "gerasimova_a.18011968@postgrespro.ru", "phone": "+70850523860"}
0005433266736	D96F3A	3562 401850	EKATERINA FILATOVA	{"phone": "+70496098098"}
0005433266737	4DA3BA	8016 366522	OLGA LAZAREVA	{"phone": "+70904655698"}
0005433266738	4DA3BA	7861 777039	MIKHAIL KONOVALOV	{"email": "m-konovalov01081961@postgrespro.ru", "phone": "+70027052210"}
0005433266739	8703FB	6514 758645	IGOR SERGEEV	{"email": "sergeev_igor.1985@postgrespro.ru", "phone": "+70602500763"}
0005433266740	DD5B93	5140 126952	EKATERINA MOROZOVA	{"email": "morozovae_031979@postgrespro.ru", "phone": "+70902912057"}
0005433266741	DD5B93	0204 563665	LARISA ALEKSANDROVA	{"phone": "+70488793687"}
0005433266743	1CD54B	3087 050753	VLADISLAV TIKHONOV	{"email": "tikhonovvladislav.29101966@postgrespro.ru", "phone": "+70565333467"}
0005433266744	1CD54B	6240 910643	ROMAN SIDOROV	{"phone": "+70538603503"}
0005433266745	E286EE	5651 723881	VLADIMIR TIKHONOV	{"phone": "+70974161952"}
0005433266746	3A6633	0446 259990	ANTONINA FOMINA	{"email": "antonina-fomina-041970@postgrespro.ru", "phone": "+70364509297"}
0005433266747	7344CF	6033 621441	DINARA ZAKHAROVA	{"phone": "+70275454468"}
0005433266748	925F74	3190 866642	GALINA AKIMOVA	{"email": "akimovag111969@postgrespro.ru", "phone": "+70537344215"}
0005433266749	B2F532	9684 272324	VALERIY KUZNECOV	{"email": "valeriy.kuznecov091973@postgrespro.ru", "phone": "+70028368591"}
0005433266750	C089B1	7837 773855	ELIZAVETA YUDINA	{"email": "elizaveta.yudina-011973@postgrespro.ru", "phone": "+70457056066"}
0005433266751	00C9B6	2260 715023	MARAT TARASOV	{"email": "marattarasov.02031970@postgrespro.ru", "phone": "+70740896112"}
0005433266752	522973	3101 222561	NADEZHDA SOKOLOVA	{"phone": "+70438913761"}
0005433266753	18DAB4	3520 234913	LYUBOV FOMINA	{"email": "l_fomina-03011977@postgrespro.ru", "phone": "+70447415744"}
0005433266754	87962C	9854 567777	ZINAIDA SIDOROVA	{"phone": "+70172480105"}
0005433266755	F54415	3318 450244	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr_03111965@postgrespro.ru", "phone": "+70247825457"}
0005433266756	5D85F5	7884 032100	MARIYA FROLOVA	{"phone": "+70808491178"}
0005433266757	F7C8B6	8200 013911	ALEKSANDR POPOV	{"phone": "+70785255044"}
0005433266758	F7C8B6	0400 234846	VALENTINA TITOVA	{"phone": "+70106410550"}
0005433266759	F7C8B6	1793 794745	EVGENIY MEDVEDEV	{"phone": "+70773242903"}
0005433266760	590D3D	5347 738617	ANTON NAUMOV	{"phone": "+70919524617"}
0005433266761	CBEF6A	8616 070317	MARINA NOVIKOVA	{"email": "novikovamarina.06041968@postgrespro.ru", "phone": "+70733691368"}
0005433266762	70E769	0883 640503	ALEKSEY KUZNECOV	{"phone": "+70637011361"}
0005433266763	C896E2	9951 791731	ILONA OSIPOVA	{"email": "osipova_ilona.1981@postgrespro.ru", "phone": "+70693193504"}
0005433266764	5EEBAC	5707 942538	ALEKSANDR SOLOVEV	{"email": "solovev.a121986@postgrespro.ru", "phone": "+70379340052"}
0005433266765	5EEBAC	9470 861461	LIDIYA NOVIKOVA	{"email": "novikoval1980@postgrespro.ru", "phone": "+70860151862"}
0005433266766	08020C	6385 265759	VIKTOR MOROZOV	{"email": "morozov-v_111976@postgrespro.ru", "phone": "+70698925218"}
0005433266767	08020C	9006 532109	ROSTISLAV PETROV	{"phone": "+70588789493"}
0005433266768	08020C	5447 846214	REGINA MOROZOVA	{"email": "rmorozova.041971@postgrespro.ru", "phone": "+70199666580"}
0005433266769	5FBD4A	3450 858287	DMITRIY KOZLOV	{"phone": "+70902476411"}
0005433266770	08A66B	1030 103505	ALINA IVANOVA	{"phone": "+70878386607"}
0005433266771	8A17E3	5255 488910	MARINA FEDOROVA	{"phone": "+70687135807"}
0005433266772	8A17E3	8122 061781	YURIY KUZNECOV	{"phone": "+70808085731"}
0005433266773	4BAEE6	1777 478652	MARIANNA ABRAMOVA	{"email": "abramova-marianna1982@postgrespro.ru", "phone": "+70188869350"}
0005433266774	603E33	8814 797155	ALEKSEY ANTONOV	{"email": "antonova-1969@postgrespro.ru", "phone": "+70842613656"}
0005433266775	52AF3F	7949 607877	ANASTASIYA PETROVA	{"phone": "+70435904865"}
0005433266776	CEAF22	1077 779959	ANDREY DAVYDOV	{"email": "andrey-davydov-051966@postgrespro.ru", "phone": "+70983695151"}
0005433266777	CEAF22	7254 990700	ANNA EGOROVA	{"phone": "+70898515584"}
0005433266778	D8C1F1	2028 605995	IVAN FEDOTOV	{"email": "i-fedotov15051980@postgrespro.ru", "phone": "+70919551319"}
0005433266779	D8C1F1	7186 448924	OLEG FEDOROV	{"phone": "+70417326273"}
0005433266780	81F5CB	7551 216328	ALEKSANDRA ABRAMOVA	{"phone": "+70369036882"}
0005433266781	81F5CB	3355 749665	TATYANA MOROZOVA	{"email": "t.morozova.021965@postgrespro.ru", "phone": "+70835675684"}
0005433266782	FE53F9	9219 175259	SERGEY ROMANOV	{"email": "romanovsergey071976@postgrespro.ru", "phone": "+70063556663"}
0005433266783	4F9CF1	3493 968808	PETR KOZLOV	{"email": "petr-kozlov_091981@postgrespro.ru", "phone": "+70639826824"}
0005433266784	4144CF	3350 020072	MAKSIM IVANOV	{"phone": "+70094208464"}
0005433266785	C3FD45	0829 792264	EKATERINA VLASOVA	{"phone": "+70893522789"}
0005433266786	A5658E	0744 691282	ANTONINA GUSEVA	{"phone": "+70218196267"}
0005433266787	AE69F6	0168 379056	TATYANA SOROKINA	{"phone": "+70040826278"}
0005433266788	C2627B	1828 749701	VALENTINA EGOROVA	{"email": "valentinaegorova-17121967@postgrespro.ru", "phone": "+70666511342"}
0005433266789	C2627B	3159 608507	OLEG ALEKSANDROV	{"email": "o_aleksandrov-1974@postgrespro.ru", "phone": "+70548023296"}
0005433266790	C2627B	7677 388449	RAISA TITOVA	{"phone": "+70943850591"}
0005433266791	7322EA	8580 697278	VIKTORIYA YAKOVLEVA	{"phone": "+70628584312"}
0005433266792	8A0C86	8538 694906	NADEZHDA POPOVA	{"phone": "+70663167123"}
0005433266793	F4431A	6537 425858	ALEKSEY ABRAMOV	{"email": "abramov_a1977@postgrespro.ru", "phone": "+70656345137"}
0005433266794	EA74D2	7664 217464	TAMARA GAVRILOVA	{"phone": "+70292901152"}
0005433266795	7AFECF	6703 790866	SVETLANA KOMAROVA	{"email": "komarova.s-061973@postgrespro.ru", "phone": "+70159835259"}
0005433266796	75BE6B	0785 872946	ALEKSANDR EGOROV	{"email": "egorov_aleksandr06101968@postgrespro.ru", "phone": "+70551812465"}
0005433266797	3CC725	6689 777119	LARISA ROMANOVA	{"email": "romanoval.17091965@postgrespro.ru", "phone": "+70103856214"}
0005433266798	2331C9	0700 577798	ALEKSANDR PETROV	{"email": "petrov-aleksandr1956@postgrespro.ru", "phone": "+70495330529"}
0005433266799	2331C9	6119 593542	OLGA KARPOVA	{"email": "karpova_o-041976@postgrespro.ru", "phone": "+70929694200"}
0005433266800	21507E	3755 511612	BORIS VASILEV	{"phone": "+70445963979"}
0005433266801	8B09DF	2869 628449	OLGA VLASOVA	{"phone": "+70385949362"}
0005433266802	57A00E	0463 793336	LILIYA NAUMOVA	{"phone": "+70179136141"}
0005433266803	57A00E	8841 773582	ANTON GORBUNOV	{"phone": "+70396066648"}
0005433266804	9E4352	1967 434579	NINA CHERNOVA	{"email": "chernova.n-031966@postgrespro.ru", "phone": "+70977503764"}
0005433266805	07BEB8	7201 306682	ALEKSANDR NOVIKOV	{"phone": "+70015503231"}
0005433266806	07BEB8	4280 659165	MIKHAIL GAVRILOV	{"phone": "+70276186080"}
0005433266807	6DD944	8391 967378	ALLA KUZNECOVA	{"email": "allakuznecova-19031976@postgrespro.ru", "phone": "+70934848796"}
0005433266808	6DD944	8288 561331	TAMARA VOROBEVA	{"email": "tvorobeva_30031960@postgrespro.ru", "phone": "+70310027303"}
0005433266809	9ACBEF	9428 960745	IRINA FILIPPOVA	{"email": "filippova.i.011974@postgrespro.ru", "phone": "+70125782631"}
0005433266810	102D5E	1282 348899	TAMARA FILATOVA	{"email": "filatova-tamara.1964@postgrespro.ru", "phone": "+70525897737"}
0005433266811	7734BF	1463 088553	VYACHESLAV SERGEEV	{"email": "vyacheslav-sergeev.1965@postgrespro.ru", "phone": "+70144267311"}
0005433266812	AE52B3	0569 429501	LYUBOV DMITRIEVA	{"email": "lyubov.dmitrieva-1967@postgrespro.ru", "phone": "+70308656601"}
0005433266813	59BB82	2066 821281	NURIYA VOLKOVA	{"phone": "+70671702562"}
0005433266814	59BB82	7363 584243	VALENTINA DENISOVA	{"email": "valentina-denisova-1967@postgrespro.ru", "phone": "+70409334954"}
0005433266815	4D7BA8	2918 443893	YULIYA NIKOLAEVA	{"phone": "+70337070235"}
0005433266816	4D7BA8	4533 238152	PAVEL KUZNECOV	{"email": "kuznecovp.1986@postgrespro.ru", "phone": "+70168726373"}
0005433266817	4D7BA8	6837 485759	NADEZHDA GAVRILOVA	{"email": "nadezhdagavrilova-081976@postgrespro.ru", "phone": "+70665839482"}
0005433266818	292E44	4229 597268	NADEZHDA NESTEROVA	{"phone": "+70008772012"}
0005433266819	292E44	8483 204653	EVGENIY ANTONOV	{"email": "antonov-evgeniy_09031959@postgrespro.ru", "phone": "+70897541350"}
0005433266820	A2586A	6258 610453	ANNA BARANOVA	{"phone": "+70426634438"}
0005433266821	A2586A	4035 325719	YULIYA ANISIMOVA	{"phone": "+70389942488"}
0005433266822	A2586A	3099 633759	IRINA GORBUNOVA	{"phone": "+70721010566"}
0005433266823	A2586A	5190 000710	TATYANA PAVLOVA	{"phone": "+70374162956"}
0005433266824	61D100	1586 426517	ANTON ZAKHAROV	{"email": "a-zakharov.1962@postgrespro.ru", "phone": "+70875666489"}
0005433266825	95E428	6866 263165	GALINA ROMANOVA	{"phone": "+70407840768"}
0005433266826	95E428	3529 242305	NIKOLAY FOMIN	{"phone": "+70405476554"}
0005433266827	7ADBD9	5734 035094	VYACHESLAV KOZLOV	{"phone": "+70583626148"}
0005433266828	580871	7933 073854	YULIYA NAZAROVA	{"phone": "+70910631352"}
0005433266829	580871	4445 838693	ANNA PETROVA	{"email": "a.petrova-021970@postgrespro.ru", "phone": "+70489501767"}
0005433266830	EA2A4D	4623 078126	TATYANA FOMINA	{"phone": "+70946236924"}
0005433266831	1924EF	6417 849624	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr.091967@postgrespro.ru", "phone": "+70018523177"}
0005433266832	600144	3426 126091	TATYANA MAKAROVA	{"phone": "+70045750464"}
0005433266833	784E90	4865 393100	EGOR FOMIN	{"phone": "+70864823035"}
0005433266834	B95447	8616 919776	MARINA SCHERBAKOVA	{"email": "scherbakovam-071966@postgrespro.ru", "phone": "+70288380236"}
0005433266835	0E9924	9286 667905	OLGA NIKOLAEVA	{"email": "onikolaeva.22061969@postgrespro.ru", "phone": "+70021722496"}
0005433266836	0E9924	4486 448181	ANASTASIYA ALEKSEEVA	{"email": "alekseeva_anastasiya-031988@postgrespro.ru", "phone": "+70586782643"}
0005433266837	DD0ADE	6406 039630	OLGA DMITRIEVA	{"phone": "+70118887358"}
0005433266838	E0C5BF	0407 354197	SVETLANA SMIRNOVA	{"email": "smirnova-svetlana_26031963@postgrespro.ru", "phone": "+70028692694"}
0005433266839	E0C5BF	3906 291566	ALEVTINA ANDREEVA	{"phone": "+70984732236"}
0005433266840	BC6FA4	5965 870322	EKATERINA MAKSIMOVA	{"email": "ekaterina.maksimova-1965@postgrespro.ru", "phone": "+70774334882"}
0005433266841	5D0F22	7671 947293	ANTONINA NAUMOVA	{"email": "naumova.a_1980@postgrespro.ru", "phone": "+70577645721"}
0005433266842	5D0F22	7092 670222	SERGEY GUSEV	{"phone": "+70076376516"}
0005433266843	8B1C24	4599 831968	OLGA KAZAKOVA	{"phone": "+70641422006"}
0005433266844	8B1C24	2920 267745	YULIYA KOROLEVA	{"email": "yuliyakoroleva101980@postgrespro.ru", "phone": "+70968980396"}
0005433266845	8B1C24	9187 311182	MARIYA PETROVA	{"email": "mpetrova071963@postgrespro.ru", "phone": "+70914282559"}
0005433266846	344F18	6682 842875	ELENA ANDREEVA	{"phone": "+70558899561"}
0005433266847	3A2B1B	7421 233521	ANGELINA YAKOVLEVA	{"phone": "+70829415204"}
0005433266848	355F80	4128 672973	ANDREY BELOV	{"email": "belov-andrey1975@postgrespro.ru", "phone": "+70238912851"}
0005433266849	355F80	1549 511814	ANNA KOZLOVA	{"phone": "+70440057597"}
0005433266850	0D9B3E	7203 485535	ANASTASIYA CHERNOVA	{"email": "chernova-a.051974@postgrespro.ru", "phone": "+70530516453"}
0005433266851	0449F1	1366 559365	VASILIY FOMIN	{"phone": "+70261236632"}
0005433266852	0449F1	8607 753994	GRIGORIY SIDOROV	{"phone": "+70737538790"}
0005433266853	B98EA5	5029 327528	NATALIYA VOLKOVA	{"email": "n.volkova11071972@postgrespro.ru", "phone": "+70823330267"}
0005433266854	ECE90E	0492 123704	EVGENIY IVANOV	{"email": "ivanovevgeniy.1974@postgrespro.ru", "phone": "+70602040139"}
0005433266855	ECE90E	5455 486577	ALEKSANDR FROLOV	{"email": "aleksandr_frolov-1972@postgrespro.ru", "phone": "+70449725449"}
0005433266856	49C3D5	9118 464702	TAMARA POPOVA	{"phone": "+70277032575"}
0005433266857	49C3D5	6824 568488	TATYANA EGOROVA	{"phone": "+70021061244"}
0005433266858	489ABB	9560 757689	OLGA ANTONOVA	{"phone": "+70589652397"}
0005433266859	489ABB	0419 344845	VLADIMIR FILIPPOV	{"phone": "+70430393638"}
0005433266860	A7CF1F	0660 493146	VIKTOR IVANOV	{"phone": "+70815346336"}
0005433266861	A7CF1F	4606 914801	DMITRIY MOROZOV	{"phone": "+70645786075"}
0005433266862	FBC0F0	1976 344076	SERGEY VASILEV	{"phone": "+70848973341"}
0005433266863	FBC0F0	6332 369328	VLADISLAV SHEVCHENKO	{"phone": "+70262430094"}
0005433266864	7F3801	6900 633265	ALINA POTAPOVA	{"phone": "+70177787108"}
0005433266865	6F8F53	9026 163605	ANNA EFREMOVA	{"phone": "+70963676341"}
0005433266866	B50C3B	8006 814528	OLGA SIDOROVA	{"phone": "+70181198295"}
0005433266867	A64FDC	1724 779525	DMITRIY DMITRIEV	{"email": "dmitriev.d_051970@postgrespro.ru", "phone": "+70087925018"}
0005433266868	F319D2	4895 154599	EKATERINA ZOTOVA	{"phone": "+70116056289"}
0005433266869	8B4C0D	4132 046278	SERGEY MEDVEDEV	{"phone": "+70069982248"}
0005433266870	8E95CA	4217 412106	TATYANA POPOVA	{"email": "popova-t12051980@postgrespro.ru", "phone": "+70838455216"}
0005433266871	FEE842	4616 120611	LYUBOV FILATOVA	{"phone": "+70544155915"}
0005433266872	B4419C	3708 290491	RUMIYA ZHURAVLEVA	{"phone": "+70878322705"}
0005433266873	B4419C	5320 252092	ALEKSEY ALEKSEEV	{"phone": "+70481638733"}
0005433266874	B4419C	1920 942007	ALEKSANDR ROMANOV	{"phone": "+70751784025"}
0005433266875	004A14	8341 737322	ALISA DENISOVA	{"phone": "+70618613535"}
0005433266876	004A14	8171 383794	SVETLANA SEMENOVA	{"email": "ssemenova-08071973@postgrespro.ru", "phone": "+70257275776"}
0005433266877	807FBF	4130 736499	DMITRIY VOROBEV	{"email": "dmitriy-vorobev-1966@postgrespro.ru", "phone": "+70418281547"}
0005433266878	D80393	8951 491290	ELIZAVETA TARASOVA	{"phone": "+70779861834"}
0005433266879	D80393	3597 964892	MARIYA SMIRNOVA	{"phone": "+70725528606"}
0005433266880	CE79AF	0623 471641	ULYANA SEMENOVA	{"email": "semenova-u_10081971@postgrespro.ru", "phone": "+70131370831"}
0005433266881	CE79AF	0819 856245	EVGENIY SOROKIN	{"phone": "+70109823302"}
0005433266882	CE329F	4693 393128	DMITRIY OSIPOV	{"email": "osipovdmitriy041966@postgrespro.ru", "phone": "+70053101706"}
0005433266883	59179F	2167 577523	NIKOLAY SOKOLOV	{"email": "n_sokolov_20041976@postgrespro.ru", "phone": "+70803172847"}
0005433266884	44F748	3534 630319	VITALIY SOLOVEV	{"email": "vitaliy.solovev.1978@postgrespro.ru", "phone": "+70162885269"}
0005433266885	8A8D11	1960 604332	ALEKSEY PETROV	{"email": "aleksey-petrov_1967@postgrespro.ru", "phone": "+70385222667"}
0005433266886	8A8D11	8742 670136	DMITRIY VOROBEV	{"email": "vorobev.dmitriy.10061976@postgrespro.ru", "phone": "+70989667147"}
0005433266887	8A8D11	9093 431358	ALEKSANDR KRASNOV	{"phone": "+70331889307"}
0005433266888	AC78E9	6249 322427	LYUBOV DENISOVA	{"phone": "+70629369625"}
0005433266889	AC78E9	8602 099889	VLADIMIR IVANOV	{"phone": "+70205217819"}
0005433266890	F89515	3957 673039	VALENTINA MOISEEVA	{"email": "v-moiseeva-04101973@postgrespro.ru", "phone": "+70760882622"}
0005433266891	F89515	0580 280181	ELENA SMIRNOVA	{"email": "smirnova_e_1971@postgrespro.ru", "phone": "+70767715302"}
0005433266892	1F5CEC	6916 396849	LEV NIKITIN	{"phone": "+70007999914"}
0005433266893	E54444	2690 871156	TATYANA ZAKHAROVA	{"phone": "+70652245710"}
0005433266894	2FD532	0124 975085	IVAN ZHUKOV	{"email": "ivan-zhukov-1970@postgrespro.ru", "phone": "+70394498979"}
0005433266895	D917B2	3226 248296	IGOR SCHERBAKOV	{"email": "scherbakovigor021980@postgrespro.ru", "phone": "+70375366902"}
0005433266896	E9FB0F	3974 936510	NADEZHDA BELOVA	{"email": "nadezhdabelova_021972@postgrespro.ru", "phone": "+70164534837"}
0005433266897	A3D5F1	2278 459669	NADEZHDA ROMANOVA	{"email": "nromanova041970@postgrespro.ru", "phone": "+70138142320"}
0005433266898	ACEE2D	5330 745221	LIDIYA NIKITINA	{"email": "nikitina_l-28031962@postgrespro.ru", "phone": "+70038271264"}
0005433266899	340FC3	7366 097700	VLADISLAV VASILEV	{"phone": "+70292402881"}
0005433266900	FD8583	3220 964494	DMITRIY MOISEEV	{"email": "dmitriy_moiseev.1973@postgrespro.ru", "phone": "+70864776108"}
0005433266901	F03EB5	2087 530859	GALINA PETROVA	{"email": "petrova_g.041965@postgrespro.ru", "phone": "+70294630544"}
0005433266902	F03EB5	9791 474354	YURIY IVANOV	{"phone": "+70472769471"}
0005433266903	9D63C7	6597 576406	ANDREY MIKHAYLOV	{"email": "a-mikhaylov091962@postgrespro.ru", "phone": "+70465837788"}
0005433266904	9D63C7	3618 265547	DARYA BORISOVA	{"email": "borisova.darya1979@postgrespro.ru", "phone": "+70752672478"}
0005433266905	E0D379	9988 683349	GALINA KAZAKOVA	{"phone": "+70021031187"}
0005433266906	E0D379	1151 058543	SERGEY TIMOFEEV	{"phone": "+70947304470"}
0005433266907	27EC4A	8477 031059	ROZALIYA NAZAROVA	{"phone": "+70810435574"}
0005433266908	CC18D2	2948 424466	SVETLANA AKIMOVA	{"email": "akimovas-121970@postgrespro.ru", "phone": "+70173909414"}
0005433266909	846CFB	6597 183182	LYUDMILA ZAKHAROVA	{"phone": "+70130854355"}
0005433266910	6C34B7	4716 802616	PETR SEMENOV	{"phone": "+70706442321"}
0005433266911	15B3E9	1491 265973	NATALYA ALEKSANDROVA	{"email": "natalya.aleksandrova.041972@postgrespro.ru", "phone": "+70696818382"}
0005433266912	93B318	6306 846041	ELENA DAVYDOVA	{"email": "davydova-e.091981@postgrespro.ru", "phone": "+70235702716"}
0005433266913	93B318	2070 861991	NADEZHDA NAZAROVA	{"email": "nadezhda.nazarova-1969@postgrespro.ru", "phone": "+70711225559"}
0005433266914	6B927D	8782 448627	LYUDMILA MATVEEVA	{"email": "l_matveeva_1982@postgrespro.ru", "phone": "+70817863563"}
0005433266915	F9D489	7101 159434	TATYANA SOROKINA	{"email": "tatyana.sorokina_111972@postgrespro.ru", "phone": "+70957116610"}
0005433266916	599C17	7328 812076	SERGEY KUZNECOV	{"phone": "+70936629136"}
0005433266917	8C1598	5514 080256	EVGENIY DMITRIEV	{"phone": "+70650964053"}
0005433266918	A865BF	3478 479441	ROMAN VASILEV	{"email": "rvasilev_1971@postgrespro.ru", "phone": "+70083781712"}
0005433266919	679414	1084 651531	GEORGIY NOVIKOV	{"email": "georgiynovikov-1966@postgrespro.ru", "phone": "+70571726003"}
0005433266920	679414	6105 439260	VERA KOVALEVA	{"phone": "+70436454709"}
0005433266921	E0942F	7954 850622	IRINA KUZMINA	{"phone": "+70295791823"}
0005433266922	CFD6C5	4194 063773	VERA KOROLEVA	{"email": "koroleva_vera.1971@postgrespro.ru", "phone": "+70763476860"}
0005433266923	CFD6C5	0919 481399	LIDIYA SEMENOVA	{"email": "lidiya.semenova031975@postgrespro.ru", "phone": "+70900404314"}
0005433266924	E962CF	1804 237800	TAMARA POLYAKOVA	{"phone": "+70757018514"}
0005433266925	57DA94	7743 319645	MIKHAIL NAZAROV	{"phone": "+70526783204"}
0005433266926	57DA94	2558 127640	IRINA KOROLEVA	{"phone": "+70694545486"}
0005433266927	B896E7	0319 141917	VLADIMIR ILIN	{"phone": "+70965342060"}
0005433266928	B896E7	1469 326752	NADEZHDA DMITRIEVA	{"phone": "+70559598956"}
0005433266929	425776	2467 301177	VLADIMIR EGOROV	{"email": "egorov-v031976@postgrespro.ru", "phone": "+70044832392"}
0005433266930	164ED4	7209 845825	ILNUR KUZMIN	{"phone": "+70746089458"}
0005433266931	2B8B73	0234 336781	OLGA IVANOVA	{"email": "o_ivanova.021976@postgrespro.ru", "phone": "+70856587051"}
0005433266932	2B8B73	1513 224358	VLADIMIR OSIPOV	{"phone": "+70614693721"}
0005433266933	0BBAE9	9868 544461	SVETLANA POLYAKOVA	{"email": "spolyakova22061980@postgrespro.ru", "phone": "+70567806327"}
0005433266934	0BBAE9	2100 717340	EVGENIY YAKOVLEV	{"email": "eyakovlev.17061979@postgrespro.ru", "phone": "+70311196453"}
0005433266935	725BC3	7468 368550	ANNA IVANOVA	{"phone": "+70380769937"}
0005433266936	725BC3	7627 964400	LYUBOV MELNIKOVA	{"phone": "+70082706401"}
0005433266937	EA569C	8630 609575	ANATOLIY IVANOV	{"email": "ivanov-anatoliy-121974@postgrespro.ru", "phone": "+70650823536"}
0005433266938	AAA49C	6480 319723	DANIL MAKSIMOV	{"phone": "+70752394104"}
0005433266939	70A0F9	6782 557108	SVETLANA ISAEVA	{"phone": "+70566292739"}
0005433266940	70A0F9	1391 081465	ALEKSEY MEDVEDEV	{"phone": "+70729145848"}
0005433266941	3E544F	7994 941811	DENIS SERGEEV	{"email": "sergeev_denis_061969@postgrespro.ru", "phone": "+70290059560"}
0005433266942	A3C76C	9466 372416	LYUBOV NAZAROVA	{"phone": "+70481223908"}
0005433266943	D413DA	9973 253841	OLGA SMIRNOVA	{"email": "smirnova_o-09051968@postgrespro.ru", "phone": "+70698300799"}
0005433266944	D413DA	0235 560655	VLADIMIR ALEKSANDROV	{"email": "vladimiraleksandrov-021974@postgrespro.ru", "phone": "+70189048487"}
0005433266945	0FF41A	1007 847697	PETR ORLOV	{"phone": "+70792759900"}
0005433266946	BD5C7E	1529 473453	ZINAIDA SOKOLOVA	{"email": "zinaida.sokolova.1967@postgrespro.ru", "phone": "+70765875997"}
0005433266947	BD5C7E	8267 272660	VIKTOR ANDREEV	{"phone": "+70738266768"}
0005433266948	51B799	6215 539252	ANDREY BELOV	{"email": "belova1975@postgrespro.ru", "phone": "+70938642262"}
0005433266949	51B799	3735 274280	TATYANA VASILEVA	{"phone": "+70548756699"}
0005433266950	0BD7A3	0500 862264	ROMAN FEDOTOV	{"email": "roman-fedotov_11061968@postgrespro.ru", "phone": "+70944339728"}
0005433266951	36FF66	7687 127344	GALINA POPOVA	{"email": "galinapopova1963@postgrespro.ru", "phone": "+70954018059"}
0005433266952	51BD4B	8247 125433	VALENTINA GUSEVA	{"email": "vguseva_031973@postgrespro.ru", "phone": "+70077034914"}
0005433266953	51BD4B	3129 775233	VALENTINA PETROVA	{"email": "petrova-v-101977@postgrespro.ru", "phone": "+70006852262"}
0005433266954	51BD4B	3080 851705	YURIY NIKITIN	{"email": "nikitin-yuriy.1974@postgrespro.ru", "phone": "+70025625073"}
0005433266955	FFA56A	3594 958338	ANTON SMIRNOV	{"email": "a.smirnov-021981@postgrespro.ru", "phone": "+70641726838"}
0005433266956	FFA56A	3001 833975	LEONID NAZAROV	{"phone": "+70143975549"}
0005433266957	FFA56A	8433 565389	NINA LAZAREVA	{"email": "ninalazareva-041971@postgrespro.ru", "phone": "+70391251418"}
0005433266958	2303F6	6761 529603	IVAN MIKHAYLOV	{"phone": "+70089961115"}
0005433266959	5E68E0	7473 430850	VYACHESLAV KAZAKOV	{"email": "kazakov_v_1964@postgrespro.ru", "phone": "+70304986604"}
0005433266960	7F6285	4411 296881	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov_041971@postgrespro.ru", "phone": "+70302970981"}
0005433266961	41152A	9832 778597	ALEKSANDR NOVIKOV	{"phone": "+70436452703"}
0005433266962	41152A	2853 956549	OKSANA ZAKHAROVA	{"phone": "+70655387848"}
0005433266963	6738E1	3540 197527	STEPAN PAVLOV	{"email": "pavlov_s1976@postgrespro.ru", "phone": "+70956938207"}
0005433266964	6738E1	1235 461495	VLADIMIR FROLOV	{"phone": "+70103004146"}
0005433266965	6738E1	4732 151799	DARYA EFIMOVA	{"phone": "+70595092972"}
0005433266966	6738E1	0500 959735	GALINA GERASIMOVA	{"email": "gerasimova_galina-031976@postgrespro.ru", "phone": "+70898900249"}
0005433266967	AC358A	1004 499284	ANATOLIY IVANOV	{"phone": "+70413731668"}
0005433266968	C4E448	3466 961191	IRINA RODIONOVA	{"email": "irodionova-011978@postgrespro.ru", "phone": "+70709354522"}
0005433266969	C6AF21	4130 071172	ALEKSANDR PETROV	{"email": "petrovaleksandr_02121980@postgrespro.ru", "phone": "+70191750594"}
0005433266970	0EB1AB	2578 671611	SVETLANA AFANASEVA	{"phone": "+70324171261"}
0005433266971	79FF3C	4953 662254	VERA TITOVA	{"email": "vtitova.021964@postgrespro.ru", "phone": "+70045456385"}
0005433266972	F5C2F6	3597 487761	POLINA ROMANOVA	{"email": "romanova-p.27111967@postgrespro.ru", "phone": "+70407278832"}
0005433266973	FB7A2B	6117 313319	YURIY SCHERBAKOV	{"email": "y-scherbakov.20101985@postgrespro.ru", "phone": "+70815131130"}
0005433266974	1EEF8A	4345 085938	ALEKSEY NIKOLAEV	{"email": "aleksey-nikolaev_1969@postgrespro.ru", "phone": "+70271783721"}
0005433266975	327350	8742 208335	ALEKSANDRA EGOROVA	{"email": "aleksandra-egorova021959@postgrespro.ru", "phone": "+70504362525"}
0005433266976	235CFB	3181 999526	ANDREY SHEVCHENKO	{"phone": "+70568668060"}
0005433266977	235CFB	7316 087172	DMITRIY SIDOROV	{"email": "sidorovdmitriy_1985@postgrespro.ru", "phone": "+70893828756"}
0005433266978	235CFB	7711 748286	ALEKSANDR MIRONOV	{"phone": "+70937865481"}
0005433266979	DEA109	6868 722800	LARISA MATVEEVA	{"email": "l_matveeva.071967@postgrespro.ru", "phone": "+70195864077"}
0005433266980	D58D8F	8911 613418	MARINA POPOVA	{"email": "popova-marina.011976@postgrespro.ru", "phone": "+70098769254"}
0005433266981	F879FF	7552 610285	VASILIY ISAEV	{"email": "isaevv.28011975@postgrespro.ru", "phone": "+70924687044"}
0005433266982	A499ED	5251 889629	ELIZAVETA PETROVA	{"email": "petrova_elizaveta-041970@postgrespro.ru", "phone": "+70030624674"}
0005433266983	635DB9	5162 482575	MIKHAIL POPOV	{"phone": "+70292121872"}
0005433266984	236315	6237 756865	LEONID PAVLOV	{"email": "leonid_pavlov071976@postgrespro.ru", "phone": "+70593367113"}
0005433266985	832F6D	4890 588066	OKSANA TARASOVA	{"email": "o-tarasova-1973@postgrespro.ru", "phone": "+70765269232"}
0005433266986	6F85D6	6693 088038	PETR FILIPPOV	{"email": "filippov_p1972@postgrespro.ru", "phone": "+70467545056"}
0005433266987	369D00	4040 814532	ILYA PETROV	{"phone": "+70329615101"}
0005433266988	7AAF91	3653 445154	MARIYA POLYAKOVA	{"email": "polyakovamariya-10011967@postgrespro.ru", "phone": "+70799689421"}
0005433266989	1B1595	9310 123805	ALEKSEY MAKSIMOV	{"email": "maksimov-aleksey-10091973@postgrespro.ru", "phone": "+70306760506"}
0005433266990	50E4D9	1529 959652	NATALYA NESTEROVA	{"phone": "+70596020879"}
0005433266991	E0ED8F	2380 862655	TATYANA DENISOVA	{"email": "t_denisova.081980@postgrespro.ru", "phone": "+70565751258"}
0005433266992	1DE496	7511 744245	NATALYA SOKOLOVA	{"phone": "+70784160131"}
0005433269619	74A459	5615 439323	VLADIMIR STEPANOV	{"email": "vstepanov-031981@postgrespro.ru", "phone": "+70648235393"}
0005433269620	D591BA	0761 674207	ANNA GERASIMOVA	{"email": "gerasimova-anna061973@postgrespro.ru", "phone": "+70959060727"}
0005433269621	121A31	5851 115044	EKATERINA NAUMOVA	{"email": "naumova.ekaterina-121968@postgrespro.ru", "phone": "+70850697119"}
0005433269622	7E9830	9468 568576	NATALYA LOGINOVA	{"email": "loginovanatalya-1955@postgrespro.ru", "phone": "+70497255514"}
0005433269623	868F00	4533 070685	YULIYA VOROBEVA	{"phone": "+70482373801"}
0005433269624	B01C75	9994 306036	ARSENIY CHERNOV	{"phone": "+70115314448"}
0005433269625	418C28	3799 261881	YURIY SOLOVEV	{"email": "ysolovev_1974@postgrespro.ru", "phone": "+70873543589"}
0005433269626	35E972	8780 220921	ALEKSEY PETROV	{"phone": "+70912548077"}
0005433269627	34D5F0	5894 520174	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr1978@postgrespro.ru", "phone": "+70993736804"}
0005433269628	FF61A2	2054 807241	ALINA NIKOLAEVA	{"email": "nikolaevaa-05051972@postgrespro.ru", "phone": "+70008182810"}
0005433269629	8748D4	1594 938163	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov_01081971@postgrespro.ru", "phone": "+70349251645"}
0005433269630	CC1946	1185 468816	IRINA GERASIMOVA	{"email": "gerasimova_irina.1969@postgrespro.ru", "phone": "+70266692077"}
0005433269631	279422	6566 340579	ZOYA FROLOVA	{"phone": "+70184527498"}
0005433269632	F4F9BF	7354 987979	ALEKSANDR SERGEEV	{"phone": "+70534455332"}
0005433269633	93CB06	2711 787981	DENIS PAVLOV	{"phone": "+70274491409"}
0005433269634	93CB06	7050 538442	SERGEY MIRONOV	{"email": "s.mironov061972@postgrespro.ru", "phone": "+70144651400"}
0005433269635	5D5D10	5546 992297	SOFIYA KULIKOVA	{"phone": "+70278359632"}
0005433269636	3770A6	2366 821212	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov_03121975@postgrespro.ru", "phone": "+70127173847"}
0005433269637	0CB706	3576 058003	ALBINA IVANOVA	{"phone": "+70030264867"}
0005433269638	0CB706	5877 546495	IGOR ILIN	{"email": "i-ilin_1962@postgrespro.ru", "phone": "+70016818712"}
0005433269639	0CB706	1488 974319	LYUDMILA KOZLOVA	{"phone": "+70971146699"}
0005433269640	9AE3AB	3996 223335	EKATERINA MALYSHEVA	{"phone": "+70292576319"}
0005433269641	9AE3AB	4535 613986	LIDIYA VOLKOVA	{"phone": "+70579509366"}
0005433269642	9AE3AB	3549 034882	STANISLAV TARASOV	{"phone": "+70852412608"}
0005433269643	1E3325	7679 710704	MIKHAIL ALEKSEEV	{"email": "mikhail_alekseev.1981@postgrespro.ru", "phone": "+70148355541"}
0005433269644	7AE109	9174 288214	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey.30111970@postgrespro.ru", "phone": "+70049753804"}
0005433269645	985761	5126 368078	ALEKSANDR SIDOROV	{"email": "sidorov.a1966@postgrespro.ru", "phone": "+70405259685"}
0005433269646	1E930A	2859 371725	NATALYA MATVEEVA	{"phone": "+70458606011"}
0005433269647	D22200	2645 068729	IGOR ZAYCEV	{"phone": "+70374459101"}
0005433269648	DD2F15	7473 545704	PAVEL VASILEV	{"phone": "+70335830458"}
0005433269649	8A669E	0790 427213	ILYA AFANASEV	{"phone": "+70146458845"}
0005433269650	1BFDF9	4910 216827	OLGA GORBUNOVA	{"email": "gorbunova_o.121968@postgrespro.ru", "phone": "+70801281287"}
0005433269651	9BFE93	8605 195878	NADEZHDA KUZMINA	{"phone": "+70546596949"}
0005433269652	85BAD0	4187 437042	OLEG NOVIKOV	{"email": "novikovoleg19101967@postgrespro.ru", "phone": "+70016880512"}
0005433269653	9D7C48	3032 612675	MAKSIM ANTONOV	{"email": "maksim.antonov_061963@postgrespro.ru", "phone": "+70253916222"}
0005433269654	5183F2	6496 681064	VADIM KISELEV	{"phone": "+70195459564"}
0005433269655	2481A4	6082 598342	YURIY GAVRILOV	{"email": "gavrilovy.101964@postgrespro.ru", "phone": "+70181708602"}
0005433269656	2481A4	6169 352227	DARYA IVANOVA	{"email": "divanova_09081982@postgrespro.ru", "phone": "+70678042134"}
0005433269657	CED487	0478 499897	MARIYA FILATOVA	{"phone": "+70294347396"}
0005433269658	ABEB0F	4482 038379	OLGA MARTYNOVA	{"phone": "+70073144552"}
0005433269659	ABEB0F	2131 352022	FEDOR MIKHAYLOV	{"email": "mikhaylovf_1984@postgrespro.ru", "phone": "+70510724714"}
0005433269660	ABEB0F	2956 661858	NINA DMITRIEVA	{"phone": "+70477879727"}
0005433269661	8CCAAE	5121 402802	ANDREY MIRONOV	{"email": "mironov.a-15091965@postgrespro.ru", "phone": "+70559335847"}
0005433269662	8CCAAE	6817 006481	ALEKSANDR KISELEV	{"email": "kiselevaleksandr1980@postgrespro.ru", "phone": "+70213775864"}
0005433269663	36B993	4301 637145	NATALYA ABRAMOVA	{"email": "abramovanatalya_31031974@postgrespro.ru", "phone": "+70718249098"}
0005433269664	805BFC	0972 480339	MIKHAIL VOLKOV	{"email": "volkov-mikhail-081976@postgrespro.ru", "phone": "+70796703767"}
0005433269665	847669	5705 852874	GALINA SMIRNOVA	{"email": "smirnova.galina_11081974@postgrespro.ru", "phone": "+70423403711"}
0005433269666	4291FE	9759 713919	VASILIY KRASNOV	{"email": "krasnov_vasiliy_091975@postgrespro.ru", "phone": "+70610637597"}
0005433269667	36D316	4629 787409	VALENTINA FILATOVA	{"phone": "+70211627086"}
0005433269668	36D316	2703 603599	IGOR ANTONOV	{"phone": "+70700021418"}
0005433269669	5A5534	4186 243315	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila.17011971@postgrespro.ru", "phone": "+70872047083"}
0005433269670	5A5534	6998 421009	YURIY DENISOV	{"phone": "+70809269280"}
0005433269671	F5944C	9514 853066	YULIYA FROLOVA	{"email": "yuliyafrolova.15011972@postgrespro.ru", "phone": "+70529626801"}
0005433269672	F5944C	3340 281925	AMIR KUZMIN	{"phone": "+70490438166"}
0005433269673	8C5941	6379 964251	NINA TARASOVA	{"email": "nina-tarasova-01111973@postgrespro.ru", "phone": "+70705827073"}
0005433269674	8C5941	7716 899942	ZINAIDA TARASOVA	{"phone": "+70032852784"}
0005433269675	5316FE	7613 336884	NATALYA STEPANOVA	{"email": "stepanova-n-1968@postgrespro.ru", "phone": "+70875612610"}
0005433269676	2A0C55	1245 316230	SERGEY IVANOV	{"phone": "+70809038144"}
0005433269677	2A0C55	3435 904728	ALEKSEY NOVIKOV	{"email": "aleksey_novikov07011978@postgrespro.ru", "phone": "+70230647600"}
0005433269678	A08BF2	6719 592694	KLAVDIYA ZAKHAROVA	{"email": "k.zakharova02091978@postgrespro.ru", "phone": "+70637258457"}
0005433269679	A08BF2	4991 851671	YURIY MIKHAYLOV	{"phone": "+70908279385"}
0005433269680	837D7B	7994 329962	DANIIL BELOV	{"email": "belov_daniil-01061967@postgrespro.ru", "phone": "+70209505164"}
0005433269681	CA207A	7631 243618	KSENIYA KULIKOVA	{"phone": "+70401177505"}
0005433269682	096A4F	1355 827959	OLGA TROFIMOVA	{"phone": "+70160220188"}
0005433269683	096A4F	3297 955190	ANASTASIYA KISELEVA	{"phone": "+70150309921"}
0005433269684	AF9085	5893 385496	NATALIYA OSIPOVA	{"email": "osipova_n23041975@postgrespro.ru", "phone": "+70625616386"}
0005433269685	3E8278	6479 822461	STANISLAV FEDOROV	{"phone": "+70746905308"}
0005433269686	26B059	2986 951878	ANTONINA NIKITINA	{"email": "antonina_nikitina.031964@postgrespro.ru", "phone": "+70396911669"}
0005433269687	28A2A8	3959 456634	SERGEY STEPANOV	{"email": "sergey_stepanov-1968@postgrespro.ru", "phone": "+70764900067"}
0005433269688	28A2A8	0341 090767	VALENTINA FOMINA	{"email": "fomina.v_22101968@postgrespro.ru", "phone": "+70791147118"}
0005433269689	0B36A3	2477 274291	VIKTORIYA SMIRNOVA	{"phone": "+70879750129"}
0005433269690	A36529	8094 750830	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy22101974@postgrespro.ru", "phone": "+70630319236"}
0005433269803	6A8E6C	9772 034889	ALEKSEY GAVRILOV	{"phone": "+70851408835"}
0005433269691	EB03CF	1678 840140	VALENTINA VLASOVA	{"email": "vlasovavalentina111971@postgrespro.ru", "phone": "+70612984099"}
0005433269692	F932CE	1281 980899	ELENA AKIMOVA	{"phone": "+70175236642"}
0005433269693	53132D	8210 859750	VLADIMIR KULIKOV	{"email": "vladimir-kulikov-13011971@postgrespro.ru", "phone": "+70456933336"}
0005433269694	53132D	9346 507454	VALENTINA KONOVALOVA	{"email": "konovalovavalentina.04021972@postgrespro.ru", "phone": "+70026567993"}
0005433269695	0A64AB	9424 700431	ELENA OSIPOVA	{"email": "elena_osipova041966@postgrespro.ru", "phone": "+70940430024"}
0005433269696	0A64AB	4907 975070	OLGA NIKOLAEVA	{"email": "o.nikolaeva.071970@postgrespro.ru", "phone": "+70908632143"}
0005433269697	B2B83F	0051 353574	ANDREY KRASNOV	{"phone": "+70035061603"}
0005433269698	1A3CC8	6485 911366	MARIYA GRISHINA	{"phone": "+70934688366"}
0005433269699	1A3CC8	8015 779186	VLADIMIR MOROZOV	{"phone": "+70427996253"}
0005433269700	1EAF98	0550 053494	SERGEY BARANOV	{"email": "baranov-s.1977@postgrespro.ru", "phone": "+70176307217"}
0005433269701	45D30D	8328 949113	SERGEY NIKITIN	{"phone": "+70396240389"}
0005433269702	45D30D	2339 781327	LYUBOV NAUMOVA	{"email": "lyubov.naumova1977@postgrespro.ru", "phone": "+70957093510"}
0005433269703	749042	5495 173123	ALEKSANDR MAKAROV	{"email": "a_makarov121988@postgrespro.ru", "phone": "+70270786415"}
0005433269704	02996A	7993 162073	BOGDAN MARTYNOV	{"phone": "+70582693823"}
0005433269705	02996A	1597 931315	VLADIMIR KONOVALOV	{"email": "konovalov_vladimir_1974@postgrespro.ru", "phone": "+70076107863"}
0005433269706	471D08	6250 018366	KIRILL SERGEEV	{"email": "kirillsergeev1968@postgrespro.ru", "phone": "+70140211453"}
0005433269707	F7B51A	5831 552497	ELENA IVANOVA	{"email": "eivanova.031978@postgrespro.ru", "phone": "+70399619247"}
0005433269708	F7B51A	2996 791292	DMITRIY GUSEV	{"email": "gusevd.081979@postgrespro.ru", "phone": "+70167722727"}
0005433269709	91BA9E	4511 633243	TAMARA MIRONOVA	{"phone": "+70056801466"}
0005433269710	91BA9E	7634 558697	SVETLANA NOVIKOVA	{"email": "novikova_svetlana1970@postgrespro.ru", "phone": "+70957258697"}
0005433269711	5013B9	9807 905214	VYACHESLAV DAVYDOV	{"email": "v_davydov_111982@postgrespro.ru", "phone": "+70824571074"}
0005433269712	5013B9	7099 071632	NIKOLAY IVANOV	{"phone": "+70306372405"}
0005433269713	88E409	2152 862507	ALENA VOROBEVA	{"email": "vorobeva.alena16011972@postgrespro.ru", "phone": "+70405333301"}
0005433269714	88E409	6602 007112	VLADISLAV KAZAKOV	{"phone": "+70361548704"}
0005433269715	038CDB	5611 212649	SERGEY ZHURAVLEV	{"email": "sergey-zhuravlev_07051971@postgrespro.ru", "phone": "+70113006778"}
0005433269716	03670E	0248 808295	EKATERINA KOROLEVA	{"phone": "+70113905282"}
0005433269717	7458D1	3883 507530	NAIL FOMIN	{"email": "nailfomin-02111987@postgrespro.ru", "phone": "+70587690052"}
0005433269718	C12569	4714 018624	LYUBOV MARTYNOVA	{"phone": "+70938573572"}
0005433269719	C12569	1243 010699	SERGEY KUZNECOV	{"email": "s.kuznecov_1964@postgrespro.ru", "phone": "+70292337391"}
0005433269720	E61038	3062 001934	ANDREY GORBUNOV	{"email": "gorbunova-1959@postgrespro.ru", "phone": "+70559384367"}
0005433269721	E61038	8869 160085	LARISA SERGEEVA	{"email": "sergeeva.larisa.1972@postgrespro.ru", "phone": "+70035222724"}
0005433269722	0C1EDA	3599 968040	TATYANA GORBUNOVA	{"email": "t-gorbunova-061971@postgrespro.ru", "phone": "+70664943950"}
0005433269723	49C0C2	0510 762079	NINA NAZAROVA	{"email": "nazarova.n-1983@postgrespro.ru", "phone": "+70875061206"}
0005433269724	49C0C2	3699 751228	NIKOLAY PETROV	{"phone": "+70393434458"}
0005433269725	0EC159	5132 419903	VYACHESLAV KISELEV	{"phone": "+70196765047"}
0005433269726	1E0A98	3858 094667	LIDIYA NIKITINA	{"phone": "+70974551819"}
0005433269727	2E8655	2068 095445	RAISA FILIPPOVA	{"email": "r.filippova-14091963@postgrespro.ru", "phone": "+70785640176"}
0005433269728	722E96	4731 838006	LYUDMILA KONOVALOVA	{"email": "konovaloval_09041972@postgrespro.ru", "phone": "+70782023744"}
0005433269729	722E96	6126 636569	VLADISLAV MOISEEV	{"email": "v-moiseev07121970@postgrespro.ru", "phone": "+70429601116"}
0005433269730	159987	9518 819062	NADEZHDA KAZAKOVA	{"email": "n.kazakova-1968@postgrespro.ru", "phone": "+70904214608"}
0005433269731	40A78E	2796 182636	MAKSIM SIDOROV	{"email": "maksim-sidorov12091960@postgrespro.ru", "phone": "+70102724536"}
0005433269732	86FCA7	9608 019797	LEONID ALEKSEEV	{"email": "alekseev_leonid071972@postgrespro.ru", "phone": "+70069974708"}
0005433269733	8547C4	3659 939319	SVETLANA AKIMOVA	{"phone": "+70658005307"}
0005433269734	B7E167	6565 617147	VALERIY SERGEEV	{"email": "valeriy_sergeev-031970@postgrespro.ru", "phone": "+70963590449"}
0005433269735	DE833C	4703 361407	SERGEY VOLKOV	{"phone": "+70217033287"}
0005433269736	EE210F	3507 756854	ELENA KUZNECOVA	{"email": "ekuznecova.041978@postgrespro.ru", "phone": "+70175575696"}
0005433269737	F56E40	3056 922312	ALEKSEY DENISOV	{"phone": "+70192600508"}
0005433269738	1C9191	8861 815411	ANATOLIY KUZNECOV	{"phone": "+70855999980"}
0005433269739	AE9522	6479 596334	VALERIY ALEKSANDROV	{"email": "aleksandrov-valeriy111959@postgrespro.ru", "phone": "+70256484583"}
0005433269740	581009	8463 915602	PAVEL BELOV	{"email": "p_belov.1975@postgrespro.ru", "phone": "+70083005890"}
0005433269741	230BA8	1475 478730	DMITRIY SOROKIN	{"email": "dmitriy.sorokin-1956@postgrespro.ru", "phone": "+70838770483"}
0005433269742	7BE859	6544 058058	RUSTAM KAZAKOV	{"email": "kazakov_r-22091968@postgrespro.ru", "phone": "+70211339060"}
0005433269743	7BE859	2444 329014	ANTON MIRONOV	{"email": "amironov_011970@postgrespro.ru", "phone": "+70189890228"}
0005433269744	318E41	4405 001037	OLEG KRASNOV	{"email": "krasnov.oleg.111987@postgrespro.ru", "phone": "+70345558744"}
0005433269745	65BEF4	8634 384095	ALEKSEY MAKAROV	{"phone": "+70138882201"}
0005433269746	0FD5D4	1678 994388	SVETLANA PETROVA	{"email": "s-petrova1987@postgrespro.ru", "phone": "+70002768177"}
0005433269747	834B33	4312 498980	VASILIY VOLKOV	{"phone": "+70722900399"}
0005433269748	618EEA	1909 038086	ZOYA ANTONOVA	{"phone": "+70121736324"}
0005433269749	1D92B3	5953 852671	TAISIYA NIKITINA	{"email": "nikitina.t1975@postgrespro.ru", "phone": "+70512655807"}
0005433269750	5C68D7	5961 121752	ANASTASIYA MIRONOVA	{"phone": "+70624420389"}
0005433269751	50159A	8691 491135	ALEKSANDR KOZLOV	{"phone": "+70811148754"}
0005433269752	A155C4	8023 314914	EVGENIYA FADEEVA	{"phone": "+70035130269"}
0005433269753	6E6C15	1447 523630	VITALIY FEDOTOV	{"phone": "+70958237331"}
0005433269754	58EAE3	4302 279056	ARTEM KUZNECOV	{"email": "akuznecov121960@postgrespro.ru", "phone": "+70651069990"}
0005433269755	58EAE3	7565 715925	ALBINA KOROLEVA	{"email": "koroleva-albina-1974@postgrespro.ru", "phone": "+70208046351"}
0005433269756	02D3C3	9206 968153	VASILIY STEPANOV	{"phone": "+70726942992"}
0005433269757	61031C	4177 575752	YURIY TIKHONOV	{"phone": "+70225738647"}
0005433269758	8A7061	0358 360180	DARYA POTAPOVA	{"email": "potapovadarya.091981@postgrespro.ru", "phone": "+70161106112"}
0005433269759	06F96C	1324 669232	VALENTIN ANDREEV	{"email": "v-andreev_17071960@postgrespro.ru", "phone": "+70857882687"}
0005433269760	5CD1DB	4847 945570	STANISLAV DAVYDOV	{"phone": "+70902599504"}
0005433269761	DB691D	1632 897756	MARIYA KULIKOVA	{"phone": "+70257826945"}
0005433269762	A06D1B	4035 777134	TATYANA TARASOVA	{"phone": "+70317685840"}
0005433269763	2C1B93	4303 350390	ELENA DAVYDOVA	{"email": "elenadavydova1969@postgrespro.ru", "phone": "+70733818993"}
0005433269764	FDF0DC	2782 981441	ALEKSEY GAVRILOV	{"phone": "+70553767301"}
0005433269765	FDF0DC	6451 927678	EVGENIYA MALYSHEVA	{"email": "e.malysheva-10091973@postgrespro.ru", "phone": "+70457113303"}
0005433269766	BFC807	9033 381580	MIKHAIL NOVIKOV	{"email": "novikov.m.01041974@postgrespro.ru", "phone": "+70572391662"}
0005433269767	9FB64F	0944 725705	TAMARA KOLESNIKOVA	{"email": "kolesnikova-t_1981@postgrespro.ru", "phone": "+70119309645"}
0005433269768	BB81BE	5794 321632	SERGEY YAKOVLEV	{"phone": "+70387437479"}
0005433269769	8268D4	7530 677288	YULIYA FEDOROVA	{"email": "yuliya-fedorova.021986@postgrespro.ru", "phone": "+70745572744"}
0005433269770	C7E54F	7071 280176	MARIYA PETROVA	{"email": "mpetrova_1975@postgrespro.ru", "phone": "+70855879471"}
0005433269771	C7E54F	1349 490693	TATYANA ZAYCEVA	{"email": "tatyana.zayceva_1969@postgrespro.ru", "phone": "+70737410735"}
0005433269772	398451	5328 097438	OLGA KUZNECOVA	{"email": "o.kuznecova_12021974@postgrespro.ru", "phone": "+70397046927"}
0005433269773	398451	0607 954008	NATALYA GAVRILOVA	{"email": "ngavrilova.1967@postgrespro.ru", "phone": "+70815560621"}
0005433269774	C7D50D	7053 764620	IRINA TROFIMOVA	{"phone": "+70230628847"}
0005433269775	C7D50D	3810 004519	EVGENIY SCHERBAKOV	{"email": "escherbakov_011969@postgrespro.ru", "phone": "+70762511751"}
0005433269776	8D64AE	0271 736411	ALEKSEY PETROV	{"email": "alekseypetrov.20011972@postgrespro.ru", "phone": "+70448689152"}
0005433269777	C6488B	0646 904271	NADEZHDA SOLOVEVA	{"phone": "+70271361107"}
0005433269778	52CF3E	5465 675629	RITA NIKOLAEVA	{"phone": "+70130410177"}
0005433269779	4AC82D	5182 183036	ARTEM MOISEEV	{"phone": "+70222457728"}
0005433269780	67B6C6	5750 769260	ALEKSANDR SMIRNOV	{"phone": "+70870603588"}
0005433269781	A8AE90	2266 030804	EDUARD NOVIKOV	{"email": "e.novikov_041964@postgrespro.ru", "phone": "+70966197451"}
0005433269782	A8AE90	8201 303752	ELENA EGOROVA	{"email": "elena.egorova061972@postgrespro.ru", "phone": "+70636635563"}
0005433269783	61827D	9582 255538	VITALIY ZHURAVLEV	{"phone": "+70877316541"}
0005433269784	D14052	1935 009965	VLADISLAV PETROV	{"phone": "+70479974108"}
0005433269785	FED0AA	5487 753861	ALEKSEY NOVIKOV	{"email": "novikova_021974@postgrespro.ru", "phone": "+70658268399"}
0005433269786	FED0AA	3185 000294	ANDREY SHEVCHENKO	{"phone": "+70113895309"}
0005433269787	FED0AA	3690 715024	ILYA ABRAMOV	{"phone": "+70188549491"}
0005433269788	B11E0E	0074 394965	NINA KOVALEVA	{"phone": "+70952417821"}
0005433269789	B11E0E	0582 995432	ALEKSEY SMIRNOV	{"phone": "+70678092951"}
0005433269790	736469	5580 074340	MAKSIM FROLOV	{"phone": "+70709224964"}
0005433269791	6C0F91	5506 753596	IRINA TITOVA	{"email": "titova-irina-121968@postgrespro.ru", "phone": "+70057520604"}
0005433269792	6C0F91	3998 284150	RAISA NIKIFOROVA	{"email": "nikiforovar.27091976@postgrespro.ru", "phone": "+70641831742"}
0005433269793	E7BBFA	3146 701892	YULIYA MELNIKOVA	{"email": "melnikova.yuliya.01091966@postgrespro.ru", "phone": "+70154246029"}
0005433269794	668D02	9971 126194	YURIY PAVLOV	{"phone": "+70721349566"}
0005433269795	668D02	9832 265810	OLGA FADEEVA	{"phone": "+70129982986"}
0005433269796	668D02	0483 711976	SERGEY BONDARENKO	{"email": "bondarenko-s.061975@postgrespro.ru", "phone": "+70975959044"}
0005433269797	A5A6D0	1886 130373	OKSANA MOROZOVA	{"phone": "+70861178964"}
0005433269798	241EDF	0860 256513	ALEKSANDR BONDARENKO	{"phone": "+70660617908"}
0005433269799	241EDF	7335 812434	GALINA MIRONOVA	{"email": "galina_mironova-1971@postgrespro.ru", "phone": "+70199386349"}
0005433269800	D97B38	3219 066733	IRINA IVANOVA	{"email": "iivanova-1965@postgrespro.ru", "phone": "+70261738188"}
0005433269801	8D5A0D	8835 277592	MARIYA KUZNECOVA	{"phone": "+70547980996"}
0005433269802	F440F9	3823 916538	ANNA FOMINA	{"phone": "+70909179243"}
0005433269804	6A8E6C	7212 813959	ILGIZ KUZNECOV	{"phone": "+70935558671"}
0005433269805	CCB6FE	5339 801753	EKATERINA ALEKSEEVA	{"phone": "+70413990924"}
0005433269806	CCB6FE	0281 725829	OLGA MAKAROVA	{"email": "makarova_o1979@postgrespro.ru", "phone": "+70746961025"}
0005433269807	48057F	5082 170048	SVETLANA GORBUNOVA	{"email": "gorbunova-s.05041972@postgrespro.ru", "phone": "+70080305437"}
0005433269808	C9B4E8	2938 490161	VLADIMIR MIKHAYLOV	{"email": "mikhaylovv07091972@postgrespro.ru", "phone": "+70464874750"}
0005433269809	17CA7B	2360 181007	OLESYA MATVEEVA	{"email": "matveeva_olesya.20101965@postgrespro.ru", "phone": "+70527010359"}
0005433269810	17CA7B	8160 934697	DMITRIY POPOV	{"email": "dmitriy_popov.1983@postgrespro.ru", "phone": "+70858015667"}
0005433269811	8C469A	0226 081347	IVAN ILIN	{"email": "iilin-23051972@postgrespro.ru", "phone": "+70849419285"}
0005433269812	DFD4C1	2194 993196	ANATOLIY GORBUNOV	{"phone": "+70332069126"}
0005433269813	5931BC	5628 421865	ALEKSANDR SHEVCHENKO	{"phone": "+70104919926"}
0005433269814	2A5EA9	3411 748696	GALINA MELNIKOVA	{"phone": "+70976896572"}
0005433269815	152E7A	8215 221887	VLADIMIR FEDOROV	{"phone": "+70001132303"}
0005433269816	9DC010	8832 936215	MARINA GUSEVA	{"email": "guseva.m1975@postgrespro.ru", "phone": "+70374339860"}
0005433269817	1043D3	5877 764432	NIKITA MIRONOV	{"email": "nikitamironov-071967@postgrespro.ru", "phone": "+70044527578"}
0005433269818	6A2889	2351 696307	SVETLANA SEMENOVA	{"phone": "+70810573045"}
0005433269819	335D87	4518 535183	VIKTOR GAVRILOV	{"phone": "+70172613519"}
0005433269820	F84BED	3493 828160	KRISTINA AFANASEVA	{"email": "afanasevak1962@postgrespro.ru", "phone": "+70834869550"}
0005433269821	F84BED	6134 586402	NIKOLAY ZHUKOV	{"phone": "+70332320167"}
0005433269822	FDC238	0820 386668	ROMAN KUZNECOV	{"email": "r_kuznecov.22121965@postgrespro.ru", "phone": "+70062552782"}
0005433269823	FDC238	4934 967755	OKSANA NIKOLAEVA	{"phone": "+70029947639"}
0005433269824	1BBC22	9278 244500	GENNADIY PETROV	{"phone": "+70300920206"}
0005433269825	A1AF03	4285 547566	ALEKSANDR KUZMIN	{"phone": "+70625218638"}
0005433269826	73B104	1434 621386	ALEKSANDR MATVEEV	{"email": "aleksandrmatveev-1966@postgrespro.ru", "phone": "+70954784199"}
0005433269827	F4AA1D	0874 073139	IRINA KUDRYASHOVA	{"email": "kudryashova-i.081979@postgrespro.ru", "phone": "+70381964524"}
0005433269828	459513	2720 953904	ILDAR EGOROV	{"email": "i_egorov1980@postgrespro.ru", "phone": "+70819954244"}
0005433269829	459513	9080 222406	PELAGEYA KUZMINA	{"email": "pelageya-kuzmina-1971@postgrespro.ru", "phone": "+70134266999"}
0005433269830	D415D5	2273 347360	VALERIYA ZHURAVLEVA	{"email": "valeriyazhuravleva-051978@postgrespro.ru", "phone": "+70079297458"}
0005433269831	4AB511	3783 929100	OLESYA TIMOFEEVA	{"email": "timofeeva-o.12041976@postgrespro.ru", "phone": "+70420204002"}
0005433269832	4AB511	3875 347634	VASILIY SOLOVEV	{"email": "solovev_vasiliy-1970@postgrespro.ru", "phone": "+70464941400"}
0005433269833	299434	9779 207660	PAVEL KUZNECOV	{"email": "kuznecov.p041977@postgrespro.ru", "phone": "+70827118055"}
0005433269834	22D565	3711 493334	ANNA VASILEVA	{"email": "anna.vasileva_19031965@postgrespro.ru", "phone": "+70109847062"}
0005433269835	22D565	3073 807852	PAVEL MIKHAYLOV	{"email": "mikhaylov.p29101970@postgrespro.ru", "phone": "+70821189775"}
0005433269836	5FA6FD	0116 969449	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr.1972@postgrespro.ru", "phone": "+70590166870"}
0005433269837	5FA6FD	3331 927789	TATYANA LEBEDEVA	{"email": "tatyana-lebedeva-1979@postgrespro.ru", "phone": "+70628217414"}
0005433269838	1F65BD	1768 940561	ALEKSANDR KOROLEV	{"phone": "+70925955168"}
0005433269839	1F65BD	5170 980793	NATALYA SOROKINA	{"email": "sorokina_natalya-05051975@postgrespro.ru", "phone": "+70958989682"}
0005433269840	C1B59F	3774 702804	EKATERINA KOVALEVA	{"email": "e_kovaleva091981@postgrespro.ru", "phone": "+70807833293"}
0005433269841	51DCB0	1216 970663	ROMAN MATVEEV	{"email": "matveev.roman-22021978@postgrespro.ru", "phone": "+70441408502"}
0005433269842	667537	1606 096599	DMITRIY BELOV	{"email": "dmitriy-belov_1972@postgrespro.ru", "phone": "+70319916178"}
0005433269843	667537	6373 861256	SERGEY SMIRNOV	{"email": "smirnovsergey_031977@postgrespro.ru", "phone": "+70739060007"}
0005433269844	10F51D	1886 111554	VALERIYA LAZAREVA	{"email": "lazareva-v-1973@postgrespro.ru", "phone": "+70954339996"}
0005433269845	10F51D	3392 798268	FARIDA KRASNOVA	{"phone": "+70167554524"}
0005433269846	2D1AED	8131 530034	NATALYA ZHURAVLEVA	{"email": "zhuravleva_natalya-14091971@postgrespro.ru", "phone": "+70033611435"}
0005433269847	2D1AED	4856 254978	NADEZHDA VASILEVA	{"phone": "+70768641128"}
0005433269848	AE4124	2499 577627	DARYA OSIPOVA	{"phone": "+70344529743"}
0005433269849	BA11CB	5996 093417	SOFYA KULIKOVA	{"phone": "+70500033813"}
0005433269850	BA11CB	6097 638211	ANATOLIY KAZAKOV	{"phone": "+70758806530"}
0005433269851	BA11CB	1648 468627	EVGENIY MIKHAYLOV	{"phone": "+70977818942"}
0005433269852	1D78C4	0829 933756	TATYANA IVANOVA	{"email": "ivanova_tatyana-041968@postgrespro.ru", "phone": "+70485561797"}
0005433269853	E539D8	9028 023722	POLINA STEPANOVA	{"phone": "+70492056339"}
0005433269854	9346D5	9596 395723	NIKOLAY MELNIKOV	{"phone": "+70912105352"}
0005433269855	D5717B	7323 230189	VLADIMIR MOROZOV	{"email": "morozovvladimir30091980@postgrespro.ru", "phone": "+70642634470"}
0005433269856	2B0443	0804 449761	ALEKSEY YAKOVLEV	{"phone": "+70972222037"}
0005433269857	2B0443	3905 228882	MIKHAIL KAZAKOV	{"email": "kazakov.m_1975@postgrespro.ru", "phone": "+70411812011"}
0005433269858	2B0443	2797 590943	ANNA CHERNOVA	{"phone": "+70164864905"}
0005433269859	7C0874	4203 682890	DMITRIY IVANOV	{"phone": "+70321669818"}
0005433269860	333B25	9965 784632	ANDREY ISAEV	{"phone": "+70688190428"}
0005433269861	C855A8	3390 139699	NADEZHDA PAVLOVA	{"email": "n-pavlova16051968@postgrespro.ru", "phone": "+70855892872"}
0005433269862	C855A8	7998 833565	LARISA FROLOVA	{"email": "larisa_frolova-041971@postgrespro.ru", "phone": "+70028358147"}
0005433269863	C855A8	8289 204036	OLGA MARTYNOVA	{"phone": "+70356377310"}
0005433269864	502380	0880 926665	LYUDMILA SCHERBAKOVA	{"email": "scherbakoval.17041954@postgrespro.ru", "phone": "+70125773376"}
0005433269865	C6C97C	8758 774739	OLGA EGOROVA	{"phone": "+70603622905"}
0005433269866	D399C7	7176 129066	MAKSIM MIKHAYLOV	{"email": "m-mikhaylov1980@postgrespro.ru", "phone": "+70556014514"}
0005433269867	120205	0223 921747	ANDREY ANTONOV	{"phone": "+70553966111"}
0005433269868	C867AA	1415 227115	ELENA KUZNECOVA	{"email": "elenakuznecova1976@postgrespro.ru", "phone": "+70222555033"}
0005433269869	C867AA	0342 605552	TAISIYA FEDOROVA	{"phone": "+70910155219"}
0005433269870	27AA0C	2043 588627	YURIY BARANOV	{"email": "yuriy.baranov.031969@postgrespro.ru", "phone": "+70252735802"}
0005433269871	8A4E8C	5738 178161	VASILIY CHERNOV	{"phone": "+70731598894"}
0005433269872	FF84C4	8625 827534	OKSANA BORISOVA	{"phone": "+70846961258"}
0005433269873	FF84C4	6061 529087	NIKOLAY KRASNOV	{"phone": "+70480974168"}
0005433269874	DBBEC3	2598 827142	VALERIYA EFIMOVA	{"phone": "+70576888965"}
0005433269875	2DF4C4	7647 007491	ALISA KUZNECOVA	{"phone": "+70839120485"}
0005433269876	2DF4C4	1951 930308	ANNA AKIMOVA	{"email": "a_akimova23071974@postgrespro.ru", "phone": "+70329999895"}
0005433269877	62AC34	2672 405374	ANTONINA NESTEROVA	{"phone": "+70265740778"}
0005433269878	277916	7014 412019	ALEKSANDR GAVRILOV	{"email": "a_gavrilov1967@postgrespro.ru", "phone": "+70398144710"}
0005433269879	277916	4650 283207	VALENTINA POTAPOVA	{"email": "vpotapova.011976@postgrespro.ru", "phone": "+70917007681"}
0005433284877	AB441B	5760 056354	ALEKSANDR SCHERBAKOV	{"phone": "+70083084963"}
0005433284769	6BF118	6773 610390	ANASTASIYA MAKSIMOVA	{"phone": "+70358535672"}
0005433284770	A92E73	0757 331632	ILDAR ZAYCEV	{"email": "zaycev.i_051972@postgrespro.ru", "phone": "+70306861443"}
0005433284771	ED0400	2623 163204	GEORGIY MAKSIMOV	{"email": "maksimov.georgiy.05091976@postgrespro.ru", "phone": "+70994667335"}
0005433284772	C275E2	4665 214314	VLADIMIR KOZLOV	{"phone": "+70130803621"}
0005433284773	E50176	7614 180926	ANASTASIYA KOMAROVA	{"phone": "+70271506904"}
0005433284774	E02C9A	4091 993051	LYUDMILA ERMAKOVA	{"email": "l_ermakova.1968@postgrespro.ru", "phone": "+70862719659"}
0005433284775	E02C9A	8872 147125	EVGENIY MELNIKOV	{"phone": "+70137094074"}
0005433284776	827ADE	7170 534123	VIKTOR KRASNOV	{"phone": "+70547812488"}
0005433284777	C95515	5299 529298	OLGA NIKOLAEVA	{"email": "onikolaeva1965@postgrespro.ru", "phone": "+70649611298"}
0005433284778	87D5C8	2410 074792	VASILIY MOROZOV	{"phone": "+70295718811"}
0005433284779	87D5C8	5335 110761	ELENA ZHUKOVA	{"email": "e-zhukova_101979@postgrespro.ru", "phone": "+70937831083"}
0005433284780	BB976D	0968 463566	ALEKSEY ALEKSANDROV	{"phone": "+70676772710"}
0005433284781	BB976D	7228 238164	VLADIMIR PAVLOV	{"email": "pavlov.vladimir15071978@postgrespro.ru", "phone": "+70979518219"}
0005433284782	063525	0617 484939	VIOLETTA KISELEVA	{"email": "v-kiseleva1974@postgrespro.ru", "phone": "+70408817363"}
0005433284783	063525	9475 952680	GALINA IVANOVA	{"email": "ivanova_g_041974@postgrespro.ru", "phone": "+70225855911"}
0005433284784	1D9942	4959 688646	VALENTINA ALEKSEEVA	{"phone": "+70621391069"}
0005433284785	0A9464	3016 001180	DIANA ZOTOVA	{"phone": "+70588633403"}
0005433284786	C90940	6423 481771	OKSANA NESTEROVA	{"phone": "+70880790423"}
0005433284787	54DA9B	0733 602686	NINA KUZNECOVA	{"email": "n_kuznecova-1978@postgrespro.ru", "phone": "+70101046407"}
0005433284788	D35809	7199 144178	DMITRIY SOKOLOV	{"phone": "+70089281227"}
0005433284789	73355A	7618 345080	ALEKSEY BORISOV	{"phone": "+70246495111"}
0005433284790	53A2BB	6884 811139	GUZEL KOROLEVA	{"phone": "+70327655751"}
0005433284791	560B9B	9235 626527	DARYA KONDRATEVA	{"phone": "+70594203096"}
0005433284792	DC27B0	5036 252038	VITALIY VASILEV	{"email": "vasilev_v-08011976@postgrespro.ru", "phone": "+70494726273"}
0005433284793	889D8B	0812 228519	RAILYA VOLKOVA	{"email": "railya-volkova_05111972@postgrespro.ru", "phone": "+70773230581"}
0005433284794	889D8B	1991 947568	VIKTOR ANDREEV	{"email": "andreev-viktor16021970@postgrespro.ru", "phone": "+70449882222"}
0005433284795	096EF7	9092 185647	LYUDMILA NIKITINA	{"phone": "+70616529708"}
0005433284796	096EF7	3374 999780	ROMAN VASILEV	{"phone": "+70277748182"}
0005433284797	420FFF	1886 160956	LYUDMILA LEBEDEVA	{"email": "l_lebedeva_18041977@postgrespro.ru", "phone": "+70344227423"}
0005433284798	B1045A	7464 709432	ANASTASIYA CHERNOVA	{"email": "achernova-1960@postgrespro.ru", "phone": "+70931484797"}
0005433284799	083C00	2375 585817	EKATERINA NIKOLAEVA	{"phone": "+70398337277"}
0005433284800	083C00	5332 285789	ALEKSANDR KOZLOV	{"phone": "+70570509411"}
0005433284801	F3175A	4323 313009	VENERA SCHERBAKOVA	{"phone": "+70812911816"}
0005433284802	F3175A	3102 557260	EKATERINA OSIPOVA	{"phone": "+70084839146"}
0005433284803	3F0030	0652 309517	IGOR KOZLOV	{"email": "i_kozlov-1973@postgrespro.ru", "phone": "+70928467767"}
0005433284804	3F0030	2620 222921	ANATOLIY VASILEV	{"phone": "+70087487271"}
0005433284805	68C777	0710 580014	DANIL MAKAROV	{"email": "makarov.d_12011972@postgrespro.ru", "phone": "+70705773470"}
0005433284806	CA5E55	4162 698246	ARTEM NAUMOV	{"email": "artem_naumov051968@postgrespro.ru", "phone": "+70851733248"}
0005433284807	2DF893	4349 219347	NIKOLAY VASILEV	{"email": "n_vasilev_071972@postgrespro.ru", "phone": "+70327272052"}
0005433284808	2DF893	7835 799419	MARIYA ALEKSEEVA	{"email": "malekseeva.17111973@postgrespro.ru", "phone": "+70384290009"}
0005433284809	38568B	5021 885165	GLEB SEMENOV	{"email": "gleb_semenov-1969@postgrespro.ru", "phone": "+70517045981"}
0005433284810	70AC15	1319 050804	SERGEY NIKITIN	{"email": "sergey.nikitin.24071965@postgrespro.ru", "phone": "+70511377459"}
0005433284811	70AC15	4915 830935	NATALYA SOKOLOVA	{"phone": "+70753130011"}
0005433284812	05C1D6	7741 260561	VASILIY NOVIKOV	{"email": "vnovikov_071963@postgrespro.ru", "phone": "+70535829600"}
0005433284813	05C1D6	4517 796431	MIKHAIL KAZAKOV	{"email": "kazakov-m.101970@postgrespro.ru", "phone": "+70744904033"}
0005433284814	76AF45	3851 996843	ALEKSANDR EGOROV	{"phone": "+70224452484"}
0005433284815	684BC9	9083 042298	LYUBOV MAKAROVA	{"email": "makarova_l.19031969@postgrespro.ru", "phone": "+70300078289"}
0005433284816	74F313	8631 190105	OLGA AFANASEVA	{"email": "afanaseva-olga1979@postgrespro.ru", "phone": "+70518592187"}
0005433284817	74F313	2151 575826	ANATOLIY GERASIMOV	{"email": "gerasimov_a.121979@postgrespro.ru", "phone": "+70666972334"}
0005433284818	607FAA	5481 529109	DARYA ROMANOVA	{"phone": "+70667682373"}
0005433284819	607FAA	8427 304046	ANNA RODIONOVA	{"phone": "+70095647839"}
0005433284820	26EE2C	7791 213362	PAVEL MATVEEV	{"email": "matveev.pavel1976@postgrespro.ru", "phone": "+70658082787"}
0005433284821	B6A8D7	6962 187033	ALEKSANDR ISAEV	{"email": "isaev_a.111961@postgrespro.ru", "phone": "+70942709487"}
0005433284822	B6A8D7	5214 535909	PAVEL KRASNOV	{"email": "pavel_krasnov25031973@postgrespro.ru", "phone": "+70610669462"}
0005433284823	CF4AD7	1696 873044	SAMVEL IVANOV	{"email": "samvel-ivanov-31081979@postgrespro.ru", "phone": "+70827043826"}
0005433284824	CF4AD7	5029 824946	ANTON DENISOV	{"email": "anton.denisov_1967@postgrespro.ru", "phone": "+70307761673"}
0005433284825	AB2B25	7254 384477	ANTONINA KONDRATEVA	{"email": "kondratevaantonina_031977@postgrespro.ru", "phone": "+70210431867"}
0005433284826	E638E1	7019 966377	VALENTINA POPOVA	{"phone": "+70460432424"}
0005433284827	E638E1	9288 358982	TATYANA BORISOVA	{"phone": "+70331912458"}
0005433284828	5440A9	0619 507614	ALEKSANDR BORISOV	{"email": "borisov-a17011973@postgrespro.ru", "phone": "+70622941183"}
0005433284829	042BD9	4159 208585	VALERIYA FILIPPOVA	{"phone": "+70504417672"}
0005433284830	B92ED2	9976 880097	MATRENA ZOTOVA	{"email": "matrenazotova-14011968@postgrespro.ru", "phone": "+70228038146"}
0005433284831	B92ED2	6196 436605	YURIY KUZNECOV	{"email": "yuriy.kuznecov18061972@postgrespro.ru", "phone": "+70974381790"}
0005433284832	175117	9167 391395	ELENA POTAPOVA	{"phone": "+70391381337"}
0005433284833	175117	2371 051903	VALENTINA ANDREEVA	{"email": "valentina_andreeva_081964@postgrespro.ru", "phone": "+70122447374"}
0005433284834	FB8250	9185 453167	VALENTINA TROFIMOVA	{"phone": "+70340209714"}
0005433284835	FB8250	0077 502706	GEORGIY VOLKOV	{"email": "volkov_georgiy.1976@postgrespro.ru", "phone": "+70480352515"}
0005433284836	B51545	1415 336791	ELENA POPOVA	{"email": "elena.popova_1969@postgrespro.ru", "phone": "+70094631373"}
0005433284837	2C09F2	2306 226802	MIKHAIL SAVELEV	{"email": "mikhail.savelev_1971@postgrespro.ru", "phone": "+70219308520"}
0005433284838	513CF4	5588 747312	GRIGORIY ORLOV	{"email": "orlovg-1972@postgrespro.ru", "phone": "+70601790060"}
0005433284839	6992D3	9872 502640	OLGA MASLOVA	{"phone": "+70270421765"}
0005433284840	E9377C	7183 965807	EKATERINA ANTONOVA	{"email": "ekaterina-antonova111967@postgrespro.ru", "phone": "+70272137673"}
0005433284841	E9377C	7258 244076	EVGENIYA POTAPOVA	{"email": "e.potapova_051967@postgrespro.ru", "phone": "+70165072808"}
0005433284842	D9679D	8832 728904	ALEKSANDR SMIRNOV	{"email": "smirnova.18071969@postgrespro.ru", "phone": "+70011835254"}
0005433284843	57DCA8	3383 884423	DARYA EGOROVA	{"email": "egorova-darya.1979@postgrespro.ru", "phone": "+70154184649"}
0005433284844	57DCA8	7755 179572	ALEKSEY MIKHAYLOV	{"phone": "+70297223273"}
0005433284845	B8D814	6616 957747	NIKOLAY MARTYNOV	{"phone": "+70916854045"}
0005433284846	F3E27F	6674 196029	OLGA TROFIMOVA	{"phone": "+70014997814"}
0005433284847	F3E27F	8274 591639	VALENTINA ZOTOVA	{"email": "valentina.zotova_111965@postgrespro.ru", "phone": "+70810269041"}
0005433284848	F3E27F	2571 138849	ARTEM SHEVCHENKO	{"phone": "+70787351098"}
0005433284849	7C5906	7456 831241	ELENA KOROLEVA	{"email": "koroleva.e14091974@postgrespro.ru", "phone": "+70600291868"}
0005433284850	DD65BF	4131 765240	ANDREY GRIGOREV	{"phone": "+70911398129"}
0005433284851	DD65BF	8443 749367	NATALYA ROMANOVA	{"email": "romanova_natalya-071971@postgrespro.ru", "phone": "+70680691576"}
0005433284852	DDA85E	5124 644481	IRINA SMIRNOVA	{"email": "smirnova-i_111972@postgrespro.ru", "phone": "+70260715701"}
0005433284853	38834F	7330 738774	EKATERINA KOZLOVA	{"phone": "+70555242687"}
0005433284854	38834F	4775 563823	ALEKSANDR STEPANOV	{"email": "a.stepanov1971@postgrespro.ru", "phone": "+70444259410"}
0005433284855	F67B6C	7359 934973	NIKOLAY KOROLEV	{"phone": "+70051926448"}
0005433284856	DEB014	7662 856401	SERGEY KUZNECOV	{"email": "sergeykuznecov.031976@postgrespro.ru", "phone": "+70700861812"}
0005433284857	EF9B26	4425 554821	IGOR MARTYNOV	{"email": "martynov_igor-1976@postgrespro.ru", "phone": "+70802474226"}
0005433284858	6C3BFD	6722 629551	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov1949@postgrespro.ru", "phone": "+70866133092"}
0005433284859	CC0054	8503 944100	LYUDMILA SOKOLOVA	{"email": "lsokolova.101973@postgrespro.ru", "phone": "+70503503386"}
0005433284860	8BAF47	6938 872366	ALEKSANDR ALEKSANDROV	{"phone": "+70208501432"}
0005433284861	AB9AFB	7750 164060	ALEKSANDRA DAVYDOVA	{"email": "davydova_aleksandra.1980@postgrespro.ru", "phone": "+70682352188"}
0005433284862	1440A7	0312 662088	LYUDMILA PAVLOVA	{"email": "pavlova_l051973@postgrespro.ru", "phone": "+70046161066"}
0005433284863	1440A7	4757 363648	TAMARA SOLOVEVA	{"email": "tamarasoloveva-30011968@postgrespro.ru", "phone": "+70589604980"}
0005433284864	1440A7	5898 857478	ANDREY IVANOV	{"email": "ivanova05091967@postgrespro.ru", "phone": "+70826064390"}
0005433284865	4A550D	6618 732756	MIKHAIL POPOV	{"phone": "+70947160977"}
0005433284866	D4C8BE	2975 086814	ANDREY KUZMIN	{"phone": "+70494205758"}
0005433284867	841148	5040 766644	SVETLANA POPOVA	{"email": "svetlana.popova.1974@postgrespro.ru", "phone": "+70025621862"}
0005433284868	841148	9875 553270	NIKOLAY VASILEV	{"phone": "+70023004758"}
0005433284869	841148	4166 840858	TATYANA KUDRYASHOVA	{"email": "t_kudryashova-07101963@postgrespro.ru", "phone": "+70595423662"}
0005433284870	367155	5095 521116	ANASTASIYA VOROBEVA	{"email": "anastasiya.vorobeva-101966@postgrespro.ru", "phone": "+70594250821"}
0005433284871	08E1B5	5494 708386	MARIYA EFREMOVA	{"email": "mariyaefremova-14021973@postgrespro.ru", "phone": "+70291980394"}
0005433284872	021D32	3657 578634	VLADIMIR KUDRYASHOV	{"email": "kudryashovv.041965@postgrespro.ru", "phone": "+70028586132"}
0005433284873	3D0279	0937 888196	LYUBOV GERASIMOVA	{"email": "gerasimoval_19021964@postgrespro.ru", "phone": "+70833834716"}
0005433284874	FCE2FB	5684 748219	OKSANA KUZMINA	{"email": "kuzmina.oksana-031974@postgrespro.ru", "phone": "+70382649101"}
0005433284875	567F97	2379 369156	VIKTOR VASILEV	{"phone": "+70273311642"}
0005433284876	55EABF	6032 274614	MARINA SERGEEVA	{"email": "sergeeva-m-031964@postgrespro.ru", "phone": "+70890720367"}
0005433284878	AB441B	7538 356696	IRINA BORISOVA	{"phone": "+70351919499"}
0005433284879	8241D1	1818 488801	RISHAT ZAYCEV	{"email": "zaycevrishat01101962@postgrespro.ru", "phone": "+70913282826"}
0005433284880	B30EA8	9326 094570	LYUDMILA SOKOLOVA	{"email": "sokolovalyudmila-25041981@postgrespro.ru", "phone": "+70969855438"}
0005433284881	B30EA8	1429 760657	TATYANA NIKOLAEVA	{"phone": "+70578986275"}
0005433284882	DCAD01	3507 304588	ALEKSANDRA SEMENOVA	{"email": "aleksandra_semenova021967@postgrespro.ru", "phone": "+70142444033"}
0005433284883	6B997F	6480 519253	DMITRIY BORISOV	{"email": "d.borisov-1961@postgrespro.ru", "phone": "+70706653576"}
0005433284884	05EC0C	6778 324232	NATALIYA KONOVALOVA	{"phone": "+70525095971"}
0005433284885	597E79	8330 768290	VERA DENISOVA	{"email": "denisovavera_091983@postgrespro.ru", "phone": "+70861121276"}
0005433284886	30F04F	8537 949675	DMITRIY FROLOV	{"phone": "+70669904226"}
0005433284887	4CF21F	9079 465393	ALEKSANDR EGOROV	{"phone": "+70128486203"}
0005433284888	1C6A7A	5696 377632	VERA AKIMOVA	{"phone": "+70987859832"}
0005433284889	431AB0	6389 101793	GENNADIY STEPANOV	{"phone": "+70248854473"}
0005433284890	4A6AB6	0821 016240	NADEZHDA ZHURAVLEVA	{"email": "nadezhda-zhuravleva_09111968@postgrespro.ru", "phone": "+70105671148"}
0005433284891	4A6AB6	8055 525973	YURIY MIKHAYLOV	{"phone": "+70871006977"}
0005433284892	4A6AB6	4001 012820	ANNA KUZNECOVA	{"email": "anna-kuznecova.1965@postgrespro.ru", "phone": "+70778357063"}
0005433284893	4239EE	1195 458057	MARIYA STEPANOVA	{"phone": "+70937550065"}
0005433284894	BC19BB	1980 075273	ELENA SOLOVEVA	{"phone": "+70070066432"}
0005433284895	BC19BB	1007 673986	OLGA SCHERBAKOVA	{"email": "scherbakova-o1981@postgrespro.ru", "phone": "+70485659132"}
0005433284896	DE11FD	4609 899582	ELENA KOLESNIKOVA	{"email": "kolesnikova.e.10121978@postgrespro.ru", "phone": "+70797932050"}
0005433284897	F1753B	9179 841846	ANTONINA KOROLEVA	{"phone": "+70747031785"}
0005433284898	F1753B	8644 526820	NATALYA TIMOFEEVA	{"phone": "+70445840393"}
0005433284899	6E9EC1	1928 688000	EKATERINA DANILOVA	{"email": "edanilova101969@postgrespro.ru", "phone": "+70971914362"}
0005433284900	4A745F	6906 147866	SERGEY KULIKOV	{"email": "kulikov.s-21081969@postgrespro.ru", "phone": "+70035893425"}
0005433284901	4A745F	4260 846995	VALENTINA ZHURAVLEVA	{"phone": "+70657090892"}
0005433284902	B9246D	2904 741081	KLAVDIYA NIKOLAEVA	{"email": "klavdiyanikolaeva021973@postgrespro.ru", "phone": "+70080979956"}
0005433284903	BD77EE	5917 067594	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr-23101969@postgrespro.ru", "phone": "+70634154448"}
0005433284904	CE97BB	9950 769201	ANATOLIY POPOV	{"email": "popov-a-111975@postgrespro.ru", "phone": "+70474733779"}
0005433284905	CE97BB	0733 843096	ELENA RODIONOVA	{"email": "rodionova.elena_1976@postgrespro.ru", "phone": "+70120417632"}
0005433284906	6F6BFE	9635 690921	ANVAR IVANOV	{"phone": "+70312286848"}
0005433284907	6F6BFE	8171 602718	REGINA GRISHINA	{"email": "regina_grishina-111970@postgrespro.ru", "phone": "+70545176998"}
0005433284908	AB4A8C	5455 599306	VIKTOR NOVIKOV	{"email": "viktor_novikov_1967@postgrespro.ru", "phone": "+70040460761"}
0005433284909	AB4A8C	5665 944813	DMITRIY MOISEEV	{"phone": "+70121811695"}
0005433284910	0F18C5	2884 165071	ANGELINA VOLKOVA	{"email": "volkova.angelina_25121966@postgrespro.ru", "phone": "+70600541022"}
0005433284911	9EC63E	8217 792795	VITALIY FOMIN	{"email": "vitaliy-fomin051966@postgrespro.ru", "phone": "+70741958434"}
0005433284912	9EC63E	1976 527836	LYUDMILA KALININA	{"phone": "+70428399149"}
0005433284913	9EC63E	6275 278271	DENIS PETROV	{"email": "dpetrov.1961@postgrespro.ru", "phone": "+70084424829"}
0005433284914	124432	4367 603159	LYUBOV MAKAROVA	{"email": "lyubov_makarova11021967@postgrespro.ru", "phone": "+70577185092"}
0005433284915	B402A0	7156 369160	VLADIMIR GUSEV	{"phone": "+70748360145"}
0005433284916	783BB7	6496 571432	ANDREY MAKSIMOV	{"phone": "+70687336009"}
0005433284917	C96026	7360 417121	VIKTOR GORBUNOV	{"phone": "+70701808869"}
0005433284918	2A7638	3858 786100	YAKOV MARTYNOV	{"email": "y.martynov-20061975@postgrespro.ru", "phone": "+70677451895"}
0005433284919	F08024	0104 033671	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr.25121977@postgrespro.ru", "phone": "+70122908899"}
0005433284920	C49A65	5623 836583	ELENA NIKOLAEVA	{"phone": "+70455722037"}
0005433284921	C49A65	1873 771036	DENIS NIKOLAEV	{"email": "denisnikolaev_28061970@postgrespro.ru", "phone": "+70945326934"}
0005433284922	C49A65	3142 265812	EVGENIY ZAYCEV	{"email": "zaycev_e-1971@postgrespro.ru", "phone": "+70835947782"}
0005433284923	21A743	7734 508976	PAVEL VOROBEV	{"email": "vorobev_p-12091973@postgrespro.ru", "phone": "+70322351483"}
0005433284924	21A743	6049 143194	ELENA FOMINA	{"phone": "+70642345591"}
0005433284925	21A743	9224 281717	ELENA FEDOROVA	{"phone": "+70044396783"}
0005433284926	D8AEE4	2593 867208	ZINAIDA MEDVEDEVA	{"phone": "+70960672615"}
0005433284927	D8AEE4	4157 353093	OLGA NESTEROVA	{"email": "nesterova_o-31071975@postgrespro.ru", "phone": "+70744836867"}
0005433284928	C7F814	2192 020456	ANATOLIY ISAEV	{"email": "isaeva_09121983@postgrespro.ru", "phone": "+70755536728"}
0005433284929	A2ECC6	8645 714235	ALLA VOROBEVA	{"phone": "+70298437385"}
0005433284930	4D66C0	2197 409322	OLEG FILIPPOV	{"phone": "+70428025149"}
0005433284931	290604	1691 254404	DMITRIY MATVEEV	{"phone": "+70461065366"}
0005433284932	290604	1557 076979	NATALYA MAKSIMOVA	{"email": "n-maksimova-051965@postgrespro.ru", "phone": "+70886597523"}
0005433284933	637D8A	1958 117582	YURIY MIKHAYLOV	{"phone": "+70932333917"}
0005433284934	DE7AAF	4553 934781	VLADISLAV KULIKOV	{"email": "kulikovvladislav.1970@postgrespro.ru", "phone": "+70895860620"}
0005433284935	2EE3F5	9021 987329	NIKOLAY KUZMIN	{"email": "kuzmin.n-10101952@postgrespro.ru", "phone": "+70209546413"}
0005433284936	34D883	7506 097115	MARINA KOLESNIKOVA	{"email": "marina.kolesnikova27051971@postgrespro.ru", "phone": "+70642281272"}
0005433284937	13F2BF	9920 346290	ALEKSEY SOLOVEV	{"email": "aleksey_solovev10071977@postgrespro.ru", "phone": "+70449191478"}
0005433284938	90A5E9	0270 439805	NIKITA EGOROV	{"phone": "+70688451038"}
0005433284939	90A5E9	7475 147324	ALEKSANDR SOLOVEV	{"phone": "+70107336420"}
0005433284940	E0C830	6639 896855	ANDREY SERGEEV	{"phone": "+70364045963"}
0005433284941	434ADC	5504 269328	ELENA POTAPOVA	{"email": "elenapotapova1964@postgrespro.ru", "phone": "+70329589719"}
0005433284942	C7DE93	3414 830650	YANA ANDREEVA	{"phone": "+70266238744"}
0005433284943	A9BFA1	8337 518644	VYACHESLAV SOROKIN	{"phone": "+70554180299"}
0005433284944	360AD4	4189 439928	ALEKSANDR SOKOLOV	{"phone": "+70339345445"}
0005433284945	360AD4	2956 647607	KRISTINA SIDOROVA	{"email": "sidorova_k-25111963@postgrespro.ru", "phone": "+70151316244"}
0005433284946	62380D	7597 569383	AZAT EGOROV	{"email": "a_egorov24101964@postgrespro.ru", "phone": "+70070053233"}
0005433284947	72A26E	8760 798729	EVGENIY GRIGOREV	{"phone": "+70788370433"}
0005433284948	A106C7	5780 408807	ALEKSANDR MAKAROV	{"phone": "+70643399414"}
0005433284949	BEFE02	0389 493586	KRISTINA RYABOVA	{"email": "ryabova.kristina101986@postgrespro.ru", "phone": "+70718341794"}
0005433284950	BEFE02	8990 005417	VLADIMIR KOZLOV	{"email": "kozlov.vladimir_1973@postgrespro.ru", "phone": "+70029184142"}
0005433284951	799533	6978 630011	ALEKSANDR MAKAROV	{"phone": "+70596822320"}
0005433284952	E82D0C	3481 551701	ALEKSANDR DAVYDOV	{"email": "davydov_aleksandr-071973@postgrespro.ru", "phone": "+70688388442"}
0005433284953	F6C7D2	8557 828359	IRINA KOVALEVA	{"phone": "+70282795078"}
0005433284954	089FA8	2253 770918	IVAN MOISEEV	{"email": "i.moiseev.021983@postgrespro.ru", "phone": "+70107023319"}
0005433284955	1F0057	8793 390274	DMITRIY ORLOV	{"phone": "+70160482964"}
0005433284956	1F0057	2969 705932	ALEKSANDR FOMIN	{"email": "fomin_a19011968@postgrespro.ru", "phone": "+70009754312"}
0005433284957	7020D0	7815 672449	LYUDMILA PETROVA	{"phone": "+70286073808"}
0005433284958	960BD3	7831 771379	IRINA PAVLOVA	{"phone": "+70582462278"}
0005433284959	A3D7EF	6628 156777	ALEKSANDR VLASOV	{"phone": "+70317570277"}
0005433284960	A3D7EF	2631 994520	LIDIYA SERGEEVA	{"email": "sergeeva-l-041961@postgrespro.ru", "phone": "+70216027686"}
0005433284961	554BF0	3473 899057	VASILIY GUSEV	{"phone": "+70940246552"}
0005433284962	EA7190	4642 551423	KONSTANTIN MIRONOV	{"email": "mironovkonstantin_1974@postgrespro.ru", "phone": "+70243463617"}
0005433284963	7735EC	4067 686978	VLADISLAV POPOV	{"email": "popov_vladislav04051975@postgrespro.ru", "phone": "+70996537627"}
0005433284964	14AD14	0094 572085	NIKOLAY BORISOV	{"email": "n.borisov1968@postgrespro.ru", "phone": "+70109103030"}
0005433284965	F6F754	3155 356674	ANNA STEPANOVA	{"phone": "+70945247628"}
0005433284966	8DEA81	5924 111533	ROMAN ALEKSANDROV	{"phone": "+70371085410"}
0005433284967	8DEA81	4835 376275	VASILIY EGOROV	{"phone": "+70159413880"}
0005433284968	C9EA78	4172 355995	GALINA MAKAROVA	{"email": "makarovagalina.05071976@postgrespro.ru", "phone": "+70045593641"}
0005433284969	729555	1732 346600	DMITRIY KUZNECOV	{"phone": "+70658823605"}
0005433284970	5D2526	6163 126823	ALEKSANDR KUDRYASHOV	{"email": "aleksandr.kudryashov-31031969@postgrespro.ru", "phone": "+70233548082"}
0005433284971	5D2526	7114 440424	RUSLAN BARANOV	{"email": "baranov_r-14041983@postgrespro.ru", "phone": "+70489940992"}
0005433284972	5D2526	1609 649868	LYUBOV SEMENOVA	{"email": "semenovalyubov-1982@postgrespro.ru", "phone": "+70036030012"}
0005433284973	04C3D5	7582 763831	LEONID SEMENOV	{"phone": "+70055776726"}
0005433284974	E7325B	9287 236766	IVAN RODIONOV	{"phone": "+70219049604"}
0005433284975	8AA8BF	7457 880390	ALEKSANDR POPOV	{"phone": "+70604520519"}
0005433284976	0223C9	9962 931866	GALINA KAZAKOVA	{"phone": "+70176832240"}
0005433284977	0223C9	6566 832251	NIKOLAY NIKOLAEV	{"email": "nikolay-nikolaev031978@postgrespro.ru", "phone": "+70908562990"}
0005433284978	94903B	3231 039796	IRINA ROMANOVA	{"email": "romanova-i.1971@postgrespro.ru", "phone": "+70620839763"}
0005433284979	94903B	0092 677402	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov-1961@postgrespro.ru", "phone": "+70875610638"}
0005433284980	6C2371	1320 676521	OLEG ALEKSANDROV	{"phone": "+70147971704"}
0005433284981	E7CD3D	7960 329164	NATALYA VOLKOVA	{"email": "natalya_volkova26081973@postgrespro.ru", "phone": "+70034480495"}
0005433284982	C623D3	1464 143445	TATYANA TROFIMOVA	{"phone": "+70340566807"}
0005433284983	958039	6266 426047	NATALYA KAZAKOVA	{"phone": "+70396832157"}
0005433284984	7B3003	4427 364278	ILYA EGOROV	{"phone": "+70449298168"}
0005433284985	8B69D6	3252 473466	OLESYA ZHUKOVA	{"email": "zhukova.o.17061988@postgrespro.ru", "phone": "+70324567637"}
0005433284986	EDED42	8187 118478	SERGEY KAZAKOV	{"email": "sergeykazakov_111963@postgrespro.ru", "phone": "+70212398934"}
0005433284987	652ABB	7284 811077	TATYANA ISAEVA	{"phone": "+70482952297"}
0005433284988	652ABB	7866 907350	KLAVDIYA PAVLOVA	{"phone": "+70143422777"}
0005433284989	C7BCD3	8016 222319	TATYANA SOLOVEVA	{"email": "tsoloveva.21011977@postgrespro.ru", "phone": "+70855721320"}
0005433284990	C7BCD3	5643 962657	NATALYA SOLOVEVA	{"phone": "+70891151292"}
0005433284991	B601F3	1385 192076	NIKITA MARTYNOV	{"phone": "+70763504916"}
0005433284992	64472F	1377 296109	ROMAN ABRAMOV	{"phone": "+70509078190"}
0005433284993	77705F	9602 498585	ANNA IVANOVA	{"phone": "+70250818825"}
0005433284994	E4F33E	0442 372998	GRIGORIY VASILEV	{"phone": "+70062207956"}
0005433284995	8DD3F3	0630 542383	VALERIY SEMENOV	{"email": "semenov-v_101966@postgrespro.ru", "phone": "+70695044263"}
0005433284996	E3B853	3960 633235	ANNA MATVEEVA	{"email": "anna.matveeva_06031977@postgrespro.ru", "phone": "+70926012817"}
0005433284997	C00860	2578 154298	VERA SMIRNOVA	{"email": "smirnova.vera_011973@postgrespro.ru", "phone": "+70099826572"}
0005433284998	C00860	0178 651932	DANIIL ANTONOV	{"email": "d.antonov-071978@postgrespro.ru", "phone": "+70250269782"}
0005433284999	6D4B7D	3848 590501	VLADIMIR OSIPOV	{"phone": "+70338370074"}
0005433285000	FB3DA3	0436 932901	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey-121975@postgrespro.ru", "phone": "+70516358392"}
0005433285001	2F7D11	5482 089271	VALERIY KISELEV	{"phone": "+70257716542"}
0005433285002	2F7D11	3358 261556	NINA MIKHAYLOVA	{"phone": "+70320962887"}
0005433285003	F4838E	1067 148380	SERGEY DAVYDOV	{"phone": "+70494070859"}
0005433285004	8506C2	5472 251004	SVETLANA VOLKOVA	{"email": "s.volkova23121969@postgrespro.ru", "phone": "+70709507363"}
0005433285005	8506C2	9349 034778	LYUDMILA OVCHINNIKOVA	{"phone": "+70651069875"}
0005433285006	83DD44	0319 933410	ILYA FILIPPOV	{"email": "ilya.filippov.071971@postgrespro.ru", "phone": "+70156801091"}
0005433285007	AE5BB3	0071 400290	SERGEY POPOV	{"phone": "+70048250120"}
0005433285008	A2A6AF	2354 848369	RITA AKIMOVA	{"phone": "+70093556909"}
0005433285009	60EA2D	4202 245473	MARIYA KUZNECOVA	{"phone": "+70615836578"}
0005433285010	CCE933	9702 664136	ANDREY SHEVCHENKO	{"email": "andreyshevchenko.17031972@postgrespro.ru", "phone": "+70656059266"}
0005433285011	C429E5	5647 741034	NIKOLAY IVANOV	{"phone": "+70808894988"}
0005433285012	8EFB61	3252 160930	VLADIMIR SEMENOV	{"email": "v.semenov-071970@postgrespro.ru", "phone": "+70015044673"}
0005433285013	ECAE38	0978 520798	TAMARA MAKSIMOVA	{"phone": "+70550804440"}
0005433285014	540E35	2506 493298	NATALYA ZHURAVLEVA	{"email": "n-zhuravleva_22051978@postgrespro.ru", "phone": "+70985502351"}
0005433285015	540E35	6541 810717	VALENTINA KISELEVA	{"email": "vkiseleva.18021970@postgrespro.ru", "phone": "+70379090660"}
0005433285016	B8F5E2	5738 870147	LIDIYA KONDRATEVA	{"phone": "+70612952729"}
0005433285017	16398B	8553 972338	DARYA EGOROVA	{"phone": "+70920002352"}
0005433285018	A022D1	0652 109104	SERGEY KOROLEV	{"phone": "+70126130655"}
0005433285019	CDFF30	8352 571809	EKATERINA KUZNECOVA	{"phone": "+70780665215"}
0005433285020	CDFF30	9110 519434	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-011967@postgrespro.ru", "phone": "+70777970415"}
0005433285021	2188B9	8597 770645	NATALYA OVCHINNIKOVA	{"phone": "+70707510737"}
0005433285022	2188B9	8308 442102	MIKHAIL SCHERBAKOV	{"phone": "+70643854228"}
0005433285023	EAE4F8	8764 446261	EVGENIY MIRONOV	{"email": "mironov_e28111962@postgrespro.ru", "phone": "+70968239090"}
0005433285024	74FB99	5918 713295	VALENTINA GERASIMOVA	{"phone": "+70001873697"}
0005433285025	146992	2639 869510	EKATERINA SEMENOVA	{"email": "e-semenova-1962@postgrespro.ru", "phone": "+70318316132"}
0005433285026	EA3B86	4879 265507	LARISA KUZNECOVA	{"phone": "+70841279816"}
0005433285027	2512CF	3470 724690	YULIYA IVANOVA	{"phone": "+70700354146"}
0005433285028	FD3C4F	7469 887418	ANASTASIYA PETROVA	{"phone": "+70700389249"}
0005433285029	C1EA33	6597 106939	ILYA ZAYCEV	{"email": "i-zaycev_041959@postgrespro.ru", "phone": "+70610415050"}
0005433285030	79C95F	0852 185568	ELENA LOGINOVA	{"email": "loginovae.091971@postgrespro.ru", "phone": "+70830656269"}
0005433285031	6DE7C7	0134 270379	VALENTINA IVANOVA	{"email": "v-ivanova_041968@postgrespro.ru", "phone": "+70613435191"}
0005433285032	AA3872	4576 878502	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev.091965@postgrespro.ru", "phone": "+70797934557"}
0005433285033	F465BD	6944 423103	MARIYA KONOVALOVA	{"email": "mariya_konovalova1960@postgrespro.ru", "phone": "+70600281487"}
0005433285034	0F088F	8556 146061	VALENTINA POPOVA	{"email": "v.popova1977@postgrespro.ru", "phone": "+70277431091"}
0005433285035	F23717	6561 580400	OLEG FROLOV	{"phone": "+70889391477"}
0005433285036	F23717	7121 207995	ALISA RODIONOVA	{"email": "rodionova_alisa.011980@postgrespro.ru", "phone": "+70810199168"}
0005433285037	0D1D03	6616 051634	ANASTASIYA ALEKSEEVA	{"email": "alekseeva_a.071978@postgrespro.ru", "phone": "+70533949964"}
0005433285038	03A61B	0498 656716	ARTEM TIMOFEEV	{"phone": "+70940548214"}
0005433285039	18E593	5736 757649	MAKSIM KOZLOV	{"email": "kozlov.maksim-081964@postgrespro.ru", "phone": "+70365017212"}
0005433285040	18E593	9564 092767	NATALYA KUZMINA	{"phone": "+70065002231"}
0005433285041	18E593	3375 169761	TAMARA IVANOVA	{"email": "t.ivanova30041969@postgrespro.ru", "phone": "+70390169810"}
0005433285042	77856A	3815 432768	ALEKSANDR PETROV	{"phone": "+70470564506"}
0005433285043	9E03AD	7350 605902	ELENA KUZMINA	{"phone": "+70263191620"}
0005433285044	26C112	2350 936037	ALEKSANDRA MARTYNOVA	{"email": "martynovaaleksandra-071971@postgrespro.ru", "phone": "+70167059323"}
0005433285045	938AC3	4192 338722	SERGEY IVANOV	{"email": "ivanov.s-08071973@postgrespro.ru", "phone": "+70046622768"}
0005433285101	4AA6D4	6197 927903	LEONID SMIRNOV	{"phone": "+70333432184"}
0005433285046	938AC3	9642 083096	DMITRIY KONOVALOV	{"email": "dmitriy-konovalov-041983@postgrespro.ru", "phone": "+70847914931"}
0005433285047	5FB224	9857 391821	IGOR ILIN	{"email": "ilin-igor_1983@postgrespro.ru", "phone": "+70973607661"}
0005433285048	08F363	3056 617643	KSENIYA YAKOVLEVA	{"email": "yakovleva.k_1966@postgrespro.ru", "phone": "+70650257820"}
0005433285049	08F363	3145 398674	ELENA POPOVA	{"email": "popova.elena29051971@postgrespro.ru", "phone": "+70699081853"}
0005433285050	65FD96	9113 537314	LYUBOV ORLOVA	{"email": "orloval-09121964@postgrespro.ru", "phone": "+70426726820"}
0005433285051	65FD96	9836 264070	NATALYA KOMAROVA	{"email": "komarova.natalya_1975@postgrespro.ru", "phone": "+70014801597"}
0005433285052	2D1CE9	8962 199295	ARINA ZAYCEVA	{"email": "a_zayceva1969@postgrespro.ru", "phone": "+70091085192"}
0005433285053	2D1CE9	5431 049036	ALBINA ARKHIPOVA	{"email": "arkhipova.albina-1966@postgrespro.ru", "phone": "+70060888512"}
0005433285054	89D8AC	0740 443983	ANDREY IVANOV	{"email": "andrey_ivanov-07031973@postgrespro.ru", "phone": "+70546632356"}
0005433285055	89D8AC	2582 484974	OLEG ISAEV	{"email": "o.isaev-011965@postgrespro.ru", "phone": "+70943986755"}
0005433285056	04FAF2	5515 020602	ANATOLIY PETROV	{"phone": "+70949358780"}
0005433285057	AF951F	4948 528290	ELIZAVETA GUSEVA	{"email": "gusevae_1979@postgrespro.ru", "phone": "+70644577270"}
0005433285058	AF951F	7256 758432	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr.03071980@postgrespro.ru", "phone": "+70773933611"}
0005433285059	FD3B46	2126 806795	PETR NIKOLAEV	{"phone": "+70318054126"}
0005433285060	1382EB	8016 328819	VALENTINA EGOROVA	{"phone": "+70924471740"}
0005433285061	1382EB	8337 413589	ALEKSANDR SMIRNOV	{"phone": "+70686939066"}
0005433285062	1382EB	4489 086237	VLADISLAV STEPANOV	{"email": "vladislav_stepanov-061970@postgrespro.ru", "phone": "+70753808145"}
0005433285063	934288	6233 303582	VIKTORIYA CHERNOVA	{"email": "chernova-viktoriya1966@postgrespro.ru", "phone": "+70324054582"}
0005433285064	934288	0877 826312	SERGEY MOROZOV	{"email": "sergey.morozov.121985@postgrespro.ru", "phone": "+70375666979"}
0005433285065	7158F6	0749 491898	TAMARA STEPANOVA	{"email": "tstepanova-08071977@postgrespro.ru", "phone": "+70866087570"}
0005433285066	3A8DD5	7806 242526	NAILYA LEBEDEVA	{"email": "nlebedeva.19051961@postgrespro.ru", "phone": "+70154216809"}
0005433285067	CBAE72	0654 968324	LYUBOV FILIPPOVA	{"email": "filippova.lyubov-07061953@postgrespro.ru", "phone": "+70892217098"}
0005433285068	CBAE72	2516 904634	LYUDMILA EFREMOVA	{"email": "lefremova-03031974@postgrespro.ru", "phone": "+70653524285"}
0005433285069	A9AFA0	4310 242228	EVGENIY NAZAROV	{"phone": "+70812409769"}
0005433285070	586976	1297 007953	EKATERINA SIDOROVA	{"phone": "+70997383575"}
0005433285071	E1EE69	9572 150919	ALEKSANDRA KARPOVA	{"email": "a_karpova.15101967@postgrespro.ru", "phone": "+70190308511"}
0005433285072	E1EE69	0504 578674	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov-1970@postgrespro.ru", "phone": "+70021077490"}
0005433285073	8D5E10	8327 451732	MARIYA NIKITINA	{"email": "mariya_nikitina1970@postgrespro.ru", "phone": "+70485573086"}
0005433285074	AA87A5	5691 436575	DMITRIY BELOV	{"phone": "+70386504494"}
0005433285075	AA87A5	8925 587003	VLADIMIR OSIPOV	{"phone": "+70121644641"}
0005433285076	FAF070	3300 022734	ANASTASIYA NAZAROVA	{"email": "a.nazarova.031980@postgrespro.ru", "phone": "+70796964999"}
0005433285077	A17C05	9645 231285	OLEG MATVEEV	{"phone": "+70822789370"}
0005433285078	40DC91	1053 599221	ALEKSANDR MOROZOV	{"email": "morozov-a.1974@postgrespro.ru", "phone": "+70072154099"}
0005433285079	40DC91	2175 056240	IRINA GUSEVA	{"email": "i-guseva06111980@postgrespro.ru", "phone": "+70778418050"}
0005433285080	AEFD64	1779 056774	GLEB DAVYDOV	{"phone": "+70120515176"}
0005433285081	A0938D	4800 867549	LYUBOV BORISOVA	{"email": "l_borisova121974@postgrespro.ru", "phone": "+70027533374"}
0005433285082	75D831	1128 534372	ALEKSANDRA IVANOVA	{"email": "ivanova_aleksandra06071974@postgrespro.ru", "phone": "+70486394654"}
0005433285083	75D831	7612 008587	IGOR NAUMOV	{"email": "igor_naumov-21021966@postgrespro.ru", "phone": "+70523400606"}
0005433285084	78EFB9	0472 099934	ELENA TIKHONOVA	{"email": "tikhonova_elena.091960@postgrespro.ru", "phone": "+70984122217"}
0005433285085	53C535	4840 449724	RODION CHERNOV	{"phone": "+70247793143"}
0005433285086	74A617	7515 215759	ANDREY ZAKHAROV	{"phone": "+70805751986"}
0005433285087	C33CE9	7593 291990	VALENTIN ZHURAVLEV	{"phone": "+70936727108"}
0005433285088	ABD92E	0995 700332	DENIS KULIKOV	{"email": "denis-kulikov.1975@postgrespro.ru", "phone": "+70214912450"}
0005433285089	ABD92E	5612 102456	SERGEY MAKSIMOV	{"phone": "+70440098842"}
0005433285090	3ABB37	6284 327752	MIKHAIL ILIN	{"phone": "+70587953998"}
0005433285091	3ABB37	9338 276437	NINA SERGEEVA	{"phone": "+70977489943"}
0005433285092	9A910E	5648 731361	ALEKSEY PETROV	{"phone": "+70698197176"}
0005433285093	9A910E	6346 071431	NATALYA ROMANOVA	{"phone": "+70528530570"}
0005433285094	3F9A08	5659 458041	OLEG GORBUNOV	{"phone": "+70612760671"}
0005433285095	3F9A08	6667 047550	IGOR VASILEV	{"phone": "+70480121227"}
0005433285096	AD66D0	7222 121722	YURIY MAKAROV	{"email": "y_makarov-1980@postgrespro.ru", "phone": "+70480064631"}
0005433285097	9AA5A2	2843 043871	SVETLANA IVANOVA	{"email": "ivanovasvetlana15121977@postgrespro.ru", "phone": "+70193222418"}
0005433285098	EE063B	4498 553475	NATALYA AFANASEVA	{"email": "afanaseva_natalya.031976@postgrespro.ru", "phone": "+70475046823"}
0005433285099	4AA6D4	8618 133202	VITALIY ALEKSEEV	{"phone": "+70844298399"}
0005433285100	4AA6D4	3107 643462	ANNA DMITRIEVA	{"phone": "+70174325766"}
0005433285102	FCE74C	7744 970264	VADIM TIKHONOV	{"email": "tikhonov.vadim.091968@postgrespro.ru", "phone": "+70109782896"}
0005433285103	5A5985	3692 523700	IGOR GAVRILOV	{"email": "gavrilovigor19081978@postgrespro.ru", "phone": "+70809605681"}
0005433285104	5A5985	7846 130800	OKSANA NIKOLAEVA	{"email": "o_nikolaeva-03031961@postgrespro.ru", "phone": "+70010176251"}
0005433285105	5A5985	4949 014462	LYUDMILA IVANOVA	{"phone": "+70969244409"}
0005433285106	6B876D	2500 580291	KONSTANTIN ALEKSEEV	{"email": "k_alekseev_1970@postgrespro.ru", "phone": "+70530397678"}
0005433285107	2A1223	0160 089906	ALEKSANDRA ZAKHAROVA	{"phone": "+70085694559"}
0005433285108	2A1223	1822 017084	YURIY STEPANOV	{"phone": "+70970205855"}
0005433285109	2A1223	1670 454648	LYUBOV SOKOLOVA	{"phone": "+70180925901"}
0005433285110	8C6F2B	3067 725283	NURLAN KULIKOV	{"email": "kulikov-n1968@postgrespro.ru", "phone": "+70671256362"}
0005433285111	F34015	9196 897449	GULFIYA NOVIKOVA	{"phone": "+70567779111"}
0005433285112	B11DA6	8395 307996	SVETLANA BELOVA	{"phone": "+70721188921"}
0005433285113	EB0583	4432 482445	EKATERINA ALEKSEEVA	{"phone": "+70877696315"}
0005433285114	6BFD8A	5418 602880	ARTEM FEDOTOV	{"phone": "+70523765950"}
0005433285115	A6BC87	1375 623183	LYUBOV IVANOVA	{"phone": "+70644680318"}
0005433285116	93D329	5946 187317	OLGA EGOROVA	{"email": "egorovaolga-1964@postgrespro.ru", "phone": "+70747383222"}
0005433285117	93D329	5434 205247	ELENA TIKHONOVA	{"email": "e-tikhonova_15111953@postgrespro.ru", "phone": "+70861154921"}
0005433285118	13793A	8597 219695	VLADIMIR BONDARENKO	{"email": "bondarenko.vladimir.041973@postgrespro.ru", "phone": "+70625230957"}
0005433285119	F4D18A	7493 905800	VIKTOR FROLOV	{"phone": "+70363659709"}
0005433285120	18D0E4	3503 694916	POLINA FADEEVA	{"email": "polina_fadeeva1988@postgrespro.ru", "phone": "+70897898264"}
0005433285121	18D0E4	5627 529343	NATALIYA NIKOLAEVA	{"email": "nnikolaeva1972@postgrespro.ru", "phone": "+70573973950"}
0005433285122	BCF60F	0932 662910	DARYA GERASIMOVA	{"phone": "+70311485477"}
0005433285123	D259C7	8780 118679	VALENTINA DMITRIEVA	{"email": "valentina.dmitrieva.1979@postgrespro.ru", "phone": "+70705564871"}
0005433285124	D259C7	5571 133952	ALEKSANDRA KULIKOVA	{"phone": "+70901010029"}
0005433285125	D259C7	2440 510181	ALEKSANDR ZHUKOV	{"phone": "+70346160810"}
0005433285126	07EF26	0222 754425	ANDREY FILIPPOV	{"email": "andrey.filippov-25041973@postgrespro.ru", "phone": "+70642813302"}
0005433285127	A7EFA9	8423 989794	TATYANA GUSEVA	{"phone": "+70488058315"}
0005433285128	AC75E7	4941 392021	VLADIMIR POPOV	{"phone": "+70066727169"}
0005433285129	16F75E	0093 861894	LIDIYA SERGEEVA	{"email": "sergeeva-l-121977@postgrespro.ru", "phone": "+70833023556"}
0005433285130	38B9EA	6571 653259	RAISA FILIPPOVA	{"email": "filippova.raisa-14051959@postgrespro.ru", "phone": "+70805769641"}
0005433285131	AC48A3	4478 185181	VALERIY SHEVCHENKO	{"email": "v.shevchenko_1971@postgrespro.ru", "phone": "+70172103730"}
0005433285132	A27247	4760 316155	ALLA EGOROVA	{"phone": "+70997515066"}
0005433285133	A27247	0014 350161	VERA NOVIKOVA	{"phone": "+70208142467"}
0005433285134	B44474	8962 924983	DMITRIY TIKHONOV	{"phone": "+70707553176"}
0005433285135	F41084	6504 548957	VALENTINA ABRAMOVA	{"email": "abramova.v_14021971@postgrespro.ru", "phone": "+70232113885"}
0005433285136	F41084	0818 209885	EKATERINA SEMENOVA	{"email": "ekaterinasemenova-1959@postgrespro.ru", "phone": "+70276749032"}
0005433285137	82FC4E	1874 170767	ELENA IVANOVA	{"phone": "+70521675520"}
0005433285138	221764	3036 238548	PAVEL VOLKOV	{"email": "volkov_pavel-09101969@postgrespro.ru", "phone": "+70767932176"}
0005433285139	221764	1842 672658	OLEG KUZNECOV	{"phone": "+70487866809"}
0005433285140	6A6DCD	4968 241303	MAKSIM MIRONOV	{"phone": "+70609361124"}
0005433285141	6A6DCD	7549 273607	ANNA SOLOVEVA	{"email": "solovevaanna-031981@postgrespro.ru", "phone": "+70306195229"}
0005433285142	973EE0	4713 278325	EVGENIY GUSEV	{"phone": "+70397063334"}
0005433285143	CAF15C	5287 683953	VADIM AFANASEV	{"email": "vadimafanasev_101969@postgrespro.ru", "phone": "+70063704736"}
0005433285144	CAF15C	2966 518809	MARINA PETROVA	{"email": "petrova_marina.04091966@postgrespro.ru", "phone": "+70816055651"}
0005433285145	025112	0790 525175	VLADIMIR MOROZOV	{"phone": "+70998544823"}
0005433285146	85A12E	9126 196674	NATALYA NIKITINA	{"phone": "+70935284577"}
0005433285147	D4546C	1009 449972	VALERIYA NAZAROVA	{"email": "valeriya-nazarova-27091965@postgrespro.ru", "phone": "+70536899580"}
0005433285148	CED459	2869 901892	ANNA KUZNECOVA	{"email": "kuznecovaanna_1971@postgrespro.ru", "phone": "+70877199300"}
0005433285149	C188EA	0539 376081	NIKOLAY KAZAKOV	{"email": "kazakov-n.1982@postgrespro.ru", "phone": "+70643311687"}
0005433285150	791E9C	4865 630203	NINA SERGEEVA	{"phone": "+70574142633"}
0005433285151	E9EA83	8237 299797	EVGENIY POPOV	{"email": "popov-evgeniy1975@postgrespro.ru", "phone": "+70791189166"}
0005433285152	865FCF	4044 512618	SOFYA SERGEEVA	{"phone": "+70462514219"}
0005433285153	ACE360	2588 394724	LYUDMILA KUZMINA	{"phone": "+70400607727"}
0005433285154	ACE360	4412 635405	ALEKSANDR SOKOLOV	{"email": "a_sokolov1968@postgrespro.ru", "phone": "+70511801683"}
0005433285155	18096F	9666 677490	DENIS PETROV	{"phone": "+70563092129"}
0005433285156	37F44C	6726 262177	ALEKSANDR CHERNOV	{"email": "chernov-a031978@postgrespro.ru", "phone": "+70521155179"}
0005433285157	28BDBD	0001 520095	LYUDMILA SMIRNOVA	{"phone": "+70644091727"}
0005433285158	D7BA1A	6089 229697	VALENTINA EFIMOVA	{"email": "v.efimova-101970@postgrespro.ru", "phone": "+70112125960"}
0005433285159	3364D4	9466 962009	DARYA GERASIMOVA	{"email": "d_gerasimova-1972@postgrespro.ru", "phone": "+70559970808"}
0005433285160	85D55D	4683 414040	LYUDMILA SOLOVEVA	{"phone": "+70521592517"}
0005433285161	DC325F	0330 460792	VALENTINA KOZLOVA	{"phone": "+70157554805"}
0005433285162	DC325F	8046 952042	NIKITA FILIPPOV	{"phone": "+70827866311"}
0005433285163	7C4FB9	4685 510953	VIKTOR BORISOV	{"email": "borisovv_16121970@postgrespro.ru", "phone": "+70045445523"}
0005433285164	7C4FB9	7876 532405	ELMIRA ANDREEVA	{"phone": "+70653111152"}
0005433285165	F840E5	5027 036071	ELENA MATVEEVA	{"phone": "+70402810854"}
0005433285166	F840E5	2275 543578	GALINA SOROKINA	{"email": "g_sorokina-13031964@postgrespro.ru", "phone": "+70565415633"}
0005433285167	817A01	8491 845658	SERGEY NAZAROV	{"email": "nazarovs-03101973@postgrespro.ru", "phone": "+70561310465"}
0005433285168	817A01	8046 366897	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov-1973@postgrespro.ru", "phone": "+70092059650"}
0005433285169	3CA173	4694 042306	ELENA NOVIKOVA	{"email": "novikova-elena.091973@postgrespro.ru", "phone": "+70407485542"}
0005433285170	510B5F	0960 611500	TATYANA FROLOVA	{"email": "frolovatatyana-27091975@postgrespro.ru", "phone": "+70437520793"}
0005433285171	510B5F	1941 088966	ANDREY NAZAROV	{"phone": "+70619691603"}
0005433285172	161740	5364 657901	OLESYA SOROKINA	{"email": "sorokina_olesya021978@postgrespro.ru", "phone": "+70923433032"}
0005433285173	161740	7818 617049	SERGEY AFANASEV	{"email": "afanasev_s_121969@postgrespro.ru", "phone": "+70178390599"}
0005433285174	C84C89	0676 193185	ALSU FROLOVA	{"email": "alsu_frolova041974@postgrespro.ru", "phone": "+70659659824"}
0005433285175	EE2287	8284 536551	EVGENIY IVANOV	{"phone": "+70757083940"}
0005433285176	EE2287	6618 843504	OLGA YUDINA	{"email": "olga_yudina.121981@postgrespro.ru", "phone": "+70775813861"}
0005433285177	EE2287	6864 303788	MARIYA DENISOVA	{"phone": "+70774980035"}
0005433285178	4E78C1	8826 205383	VIKTOR MIKHAYLOV	{"email": "mikhaylovv1972@postgrespro.ru", "phone": "+70067913433"}
0005433285179	5805AE	7358 193475	ANASTASIYA KRASNOVA	{"email": "krasnova-a_16121965@postgrespro.ru", "phone": "+70016190337"}
0005433285180	C0B752	9341 803720	EKATERINA LUKYANOVA	{"email": "lukyanova-e_10031982@postgrespro.ru", "phone": "+70925504019"}
0005433285181	FD8CC8	6227 481860	ELENA TROFIMOVA	{"phone": "+70749047372"}
0005433285182	B9A673	5769 301926	LYUBOV SERGEEVA	{"phone": "+70755020425"}
0005433285183	B9A673	3561 356723	RUSLAN EGOROV	{"phone": "+70764480245"}
0005433285184	9908B2	8113 745601	KONSTANTIN IVANOV	{"phone": "+70982454799"}
0005433285185	9908B2	3276 870060	DMITRIY ZAKHAROV	{"phone": "+70293643293"}
0005433285186	1C9DD4	8158 874708	VLADIMIR MIRONOV	{"phone": "+70515235672"}
0005433285187	2E2687	5099 035306	DIANA ZHUKOVA	{"phone": "+70220686299"}
0005433285188	2E2687	3553 433752	NINA IVANOVA	{"phone": "+70107479268"}
0005433285189	708ED6	4811 052391	VLADIMIR KUZNECOV	{"email": "kuznecov_v_1965@postgrespro.ru", "phone": "+70232641666"}
0005433285190	08F84D	2396 872403	GERMAN MAKAROV	{"email": "makarov-g_1966@postgrespro.ru", "phone": "+70598481470"}
0005433285191	08F84D	6174 048634	EVGENIY KAZAKOV	{"phone": "+70567741391"}
0005433285192	6DEDC9	8384 940955	ZARINA KOMAROVA	{"email": "z-komarova_071975@postgrespro.ru", "phone": "+70165330552"}
0005433285193	E472DB	3640 405887	VALENTINA SMIRNOVA	{"phone": "+70794345433"}
0005433285194	E472DB	2828 131504	ZOYA MAKSIMOVA	{"email": "zoya.maksimova-1982@postgrespro.ru", "phone": "+70196365827"}
0005433285195	68184D	4991 930317	DENIS ZAYCEV	{"phone": "+70216551343"}
0005433285196	68184D	4597 526928	SERGEY KAZAKOV	{"phone": "+70088454590"}
0005433285197	0F60C4	2354 807334	SERGEY POPOV	{"email": "spopov-021964@postgrespro.ru", "phone": "+70719012876"}
0005433285198	942BBF	4178 420852	SERGEY NIKITIN	{"email": "sergeynikitin1976@postgrespro.ru", "phone": "+70065378395"}
0005433285199	91DD2C	1999 417411	VALENTINA ORLOVA	{"email": "valentina_orlova06071960@postgrespro.ru", "phone": "+70184642911"}
0005433285200	53B2B4	8422 971840	DMITRIY KRASNOV	{"phone": "+70556614029"}
0005433285201	48FA02	0012 213073	DMITRIY ALEKSEEV	{"phone": "+70935670491"}
0005433285202	ED3359	5578 980396	VIKTOR PAVLOV	{"email": "pavlov-viktor111968@postgrespro.ru", "phone": "+70050542774"}
0005433285203	ED3359	8734 080764	NATALYA FEDOROVA	{"phone": "+70112388853"}
0005433285204	99A52C	6285 513373	ANASTASIYA ZHURAVLEVA	{"email": "a_zhuravleva-1962@postgrespro.ru", "phone": "+70737091596"}
0005433285205	38C551	9359 733801	MARGARITA ZHUKOVA	{"email": "zhukovamargarita1980@postgrespro.ru", "phone": "+70690392108"}
0005433285206	A240CC	9740 815047	IGOR ABRAMOV	{"phone": "+70180515995"}
0005433285207	A240CC	4118 000939	NADEZHDA SCHERBAKOVA	{"email": "scherbakova.n-121972@postgrespro.ru", "phone": "+70679220594"}
0005433285208	BE416B	1585 759624	GENNADIY VASILEV	{"email": "vasilevg-1967@postgrespro.ru", "phone": "+70491700640"}
0005433285209	AD51FF	5840 312366	SVETLANA ZAYCEVA	{"phone": "+70280945318"}
0005433285210	3F289C	1971 223658	SVETLANA ALEKSANDROVA	{"phone": "+70580005439"}
0005433285211	3F289C	1804 128363	VALENTINA TIKHONOVA	{"email": "vtikhonova.1970@postgrespro.ru", "phone": "+70219158306"}
0005433285212	72C7E9	2526 728524	ELENA BELOVA	{"email": "belovaelena1975@postgrespro.ru", "phone": "+70462896048"}
0005433285213	72C7E9	5186 743321	VERA SOKOLOVA	{"email": "v-sokolova1974@postgrespro.ru", "phone": "+70565059494"}
0005433285214	5056DF	1951 542433	ALEKSANDR POPOV	{"phone": "+70284584893"}
0005433285215	A8B080	2775 727956	ANGELINA IVANOVA	{"phone": "+70122324408"}
0005433285216	976CDE	9971 867791	IVAN ZHUKOV	{"email": "izhukov091971@postgrespro.ru", "phone": "+70365434473"}
0005433285217	4B042D	3431 515192	DIANA NESTEROVA	{"email": "d-nesterova-111963@postgrespro.ru", "phone": "+70241945241"}
0005433285218	4B042D	3486 720852	SERGEY PAVLOV	{"phone": "+70722041820"}
0005433285219	8D40B5	2071 921700	DMITRIY ZHURAVLEV	{"phone": "+70740563963"}
0005433285220	D878DA	1953 828829	NIKOLAY MIKHAYLOV	{"phone": "+70461731375"}
0005433285221	E62DF5	8882 582281	YULIYA KOLESNIKOVA	{"phone": "+70517366496"}
0005433285222	E892F0	9348 093878	DENIS PETROV	{"email": "petrov.denis1972@postgrespro.ru", "phone": "+70889995829"}
0005433285223	D9CF7F	7932 116390	TATYANA SAVELEVA	{"email": "saveleva-tatyana-1978@postgrespro.ru", "phone": "+70815555648"}
0005433285224	8D0552	9529 639179	MAKSIM MAKAROV	{"email": "makarov_m.011983@postgrespro.ru", "phone": "+70712973705"}
0005433285225	CDD806	8819 074776	YURIY SEMENOV	{"email": "ysemenov_1961@postgrespro.ru", "phone": "+70132610738"}
0005433285226	CDD806	8615 750379	DENIS SERGEEV	{"phone": "+70799713176"}
0005433285227	D86B0A	7694 614373	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana.14111987@postgrespro.ru", "phone": "+70031144916"}
0005433285228	9B18ED	8447 479707	KIRILL STEPANOV	{"phone": "+70546710567"}
0005433285229	9B18ED	2264 942140	VASILIY FEDOTOV	{"email": "v_fedotov-24061972@postgrespro.ru", "phone": "+70506692224"}
0005433285230	B123A2	6875 736565	VIKTORIYA ANDREEVA	{"phone": "+70162707567"}
0005433285231	B123A2	0347 898036	ELIZAVETA SMIRNOVA	{"phone": "+70005841966"}
0005433285232	94A2DF	1395 922531	EVGENIYA ABRAMOVA	{"phone": "+70329693277"}
0005433285233	5B7707	1611 214672	ARTEM YAKOVLEV	{"phone": "+70809342126"}
0005433285234	EFABD0	1927 878933	RAISA ORLOVA	{"phone": "+70022314155"}
0005433285235	5641C8	5614 051284	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov051971@postgrespro.ru", "phone": "+70912708247"}
0005433285236	030BC2	7452 421790	DAMIR NAZAROV	{"phone": "+70984814657"}
0005433285237	119CE1	7278 785627	VITALIY ILIN	{"email": "ilin_v.1979@postgrespro.ru", "phone": "+70208297247"}
0005433285238	434580	4427 784084	SVETLANA BARANOVA	{"email": "baranova.s1973@postgrespro.ru", "phone": "+70065754157"}
0005433285239	E60078	7432 686523	ALEKSEY POPOV	{"phone": "+70958902019"}
0005433285240	F22E13	6620 406523	LYUDMILA MAKAROVA	{"email": "lyudmila-makarova_1971@postgrespro.ru", "phone": "+70127979862"}
0005433285241	2E2239	5267 844775	NATALYA ZAKHAROVA	{"email": "zakharova-natalya1961@postgrespro.ru", "phone": "+70215621007"}
0005433285242	AD2F3A	0585 046246	EVGENIYA ALEKSANDROVA	{"email": "e.aleksandrova-1983@postgrespro.ru", "phone": "+70383102307"}
0005433285243	7FE906	6503 799736	NINA BELYAEVA	{"phone": "+70276830922"}
0005433285244	E594E7	1235 317797	IRAIDA GORBUNOVA	{"email": "gorbunova_iraida.091968@postgrespro.ru", "phone": "+70828538375"}
0005433285245	1D98E6	9153 310483	DENIS NIKITIN	{"email": "nikitin_denis_051973@postgrespro.ru", "phone": "+70887080486"}
0005433285246	D41B27	8614 488248	TIMOFEY ALEKSEEV	{"email": "alekseevtimofey24051983@postgrespro.ru", "phone": "+70441703467"}
0005433285247	D41B27	1665 057532	MARIYA PAVLOVA	{"email": "pavlova-mariya_1972@postgrespro.ru", "phone": "+70875179383"}
0005433285248	158CAE	9736 439136	LIDIYA SEMENOVA	{"phone": "+70577674888"}
0005433285249	B525E4	2870 175639	ANNA GAVRILOVA	{"phone": "+70005163467"}
0005433285250	3A0CF0	1930 342949	NATALIYA MASLOVA	{"email": "nataliya_maslova-24081961@postgrespro.ru", "phone": "+70033340986"}
0005433285251	FEFD0F	5104 296717	ANASTASIYA TARASOVA	{"email": "tarasovaanastasiya.1970@postgrespro.ru", "phone": "+70787105714"}
0005433285252	FEFD0F	6529 601102	EVGENIY MOROZOV	{"phone": "+70226082967"}
0005433285253	0C8818	1677 056190	EVGENIY TARASOV	{"phone": "+70340572652"}
0005433285254	E71798	6450 842954	ELENA LAZAREVA	{"email": "lazarevae-29111970@postgrespro.ru", "phone": "+70999325969"}
0005433285255	E71798	0499 054492	PAVEL POPOV	{"phone": "+70104349416"}
0005433285256	F516BB	5101 866705	MARIYA FILIPPOVA	{"email": "filippova_mariya.07021973@postgrespro.ru", "phone": "+70610695866"}
0005433285257	F516BB	8751 924813	SVETLANA KOROLEVA	{"phone": "+70370112838"}
0005433285258	4E2887	4845 769199	SERGEY BARANOV	{"phone": "+70722798725"}
0005433285259	BADEDA	5054 811243	ELENA TIMOFEEVA	{"phone": "+70107865578"}
0005433285260	30B4C4	0417 568228	EVGENIY GAVRILOV	{"email": "evgeniy.gavrilov.1973@postgrespro.ru", "phone": "+70538391972"}
0005433285261	2C5C43	9079 684859	NINA TROFIMOVA	{"phone": "+70526993812"}
0005433285262	E35FEC	5748 470761	VIKTOR GERASIMOV	{"phone": "+70850336828"}
0005433285263	E35FEC	2299 285469	OLGA ZAYCEVA	{"phone": "+70987500004"}
0005433285264	6DCF2C	5038 874835	MIKHAIL PAVLOV	{"email": "pavlov.m.08011979@postgrespro.ru", "phone": "+70969745180"}
0005433285265	6DCF2C	2680 092627	GALINA ALEKSANDROVA	{"phone": "+70684493429"}
0005433285266	E2F2C5	7182 942436	ANGELINA KOROLEVA	{"email": "angelinakoroleva_19061978@postgrespro.ru", "phone": "+70974424774"}
0005433285267	634157	0576 539628	YULIYA ZHUKOVA	{"phone": "+70424218959"}
0005433285268	47C121	3927 876752	MARIYA GAVRILOVA	{"email": "gavrilovamariya04011972@postgrespro.ru", "phone": "+70814301249"}
0005433285269	3CA366	3630 845407	ALEKSEY FEDOTOV	{"phone": "+70492198062"}
0005433285270	AD81B9	0360 556893	SVETLANA NIKOLAEVA	{"phone": "+70060067691"}
0005433285271	2C99EC	1012 474952	VALENTINA RODIONOVA	{"email": "rodionova.v13061963@postgrespro.ru", "phone": "+70524998285"}
0005433285272	635934	2815 420655	ELENA ROMANOVA	{"phone": "+70074501300"}
0005433285273	1AEFB6	6383 064917	OLGA STEPANOVA	{"email": "stepanovao011982@postgrespro.ru", "phone": "+70163053060"}
0005433285274	B4FCEF	6465 970847	NIKOLAY IVANOV	{"phone": "+70935058999"}
0005433285275	0C78CC	6255 731917	DMITRIY BELOV	{"email": "belovd_1978@postgrespro.ru", "phone": "+70669214324"}
0005433285276	A3C044	1182 122429	VYACHESLAV MEDVEDEV	{"email": "medvedev.v.1968@postgrespro.ru", "phone": "+70401509903"}
0005433285277	198E1D	9781 356171	EVGENIY GAVRILOV	{"phone": "+70601587889"}
0005433285278	8EF998	3840 061637	OLGA FADEEVA	{"phone": "+70914718068"}
0005433285279	8EF998	9897 088459	LYUBOV ALEKSANDROVA	{"phone": "+70056889560"}
0005433285280	9A976A	8514 220678	VLADIMIR KUZMIN	{"phone": "+70243418372"}
0005433285281	46D98C	4052 581675	IRINA KUZNECOVA	{"phone": "+70195874235"}
0005433285282	46D98C	1647 080180	PAVEL CHERNOV	{"phone": "+70093423108"}
0005433285283	43A5B0	2139 134434	ANDREY MAKAROV	{"phone": "+70288215537"}
0005433285284	43A5B0	8025 343890	ARINA DANILOVA	{"phone": "+70694768237"}
0005433285285	43A5B0	3435 816327	ANASTASIYA ALEKSANDROVA	{"phone": "+70385598436"}
0005433285286	173A5D	8239 585413	MAKSIM KUZMIN	{"email": "maksimkuzmin_091970@postgrespro.ru", "phone": "+70545642835"}
0005433285287	EEC15D	5764 075223	ANNA KULIKOVA	{"email": "kulikova-anna_091973@postgrespro.ru", "phone": "+70034421503"}
0005433285288	EEC15D	5760 197201	DENIS NAUMOV	{"phone": "+70378044754"}
0005433285289	65844D	8793 180882	LYUDMILA NIKOLAEVA	{"phone": "+70902722034"}
0005433285290	600BAF	7488 471536	OLGA VLASOVA	{"email": "o.vlasova.1969@postgrespro.ru", "phone": "+70076991983"}
0005433285291	CD9DE0	7359 554389	NINA NESTEROVA	{"phone": "+70735803914"}
0005433285292	0A2330	5760 171011	VLADIMIR VOLKOV	{"email": "volkovvladimir_111967@postgrespro.ru", "phone": "+70880405164"}
0005433285293	0A2330	3892 018513	SERGEY KONOVALOV	{"email": "sergey-konovalov-06061959@postgrespro.ru", "phone": "+70739471893"}
0005433285294	0A2330	1614 034122	PETR BONDARENKO	{"phone": "+70450366257"}
0005433285295	37EF47	1688 728880	OLGA DMITRIEVA	{"phone": "+70074606238"}
0005433285296	37EF47	2391 686522	NATALYA DAVYDOVA	{"phone": "+70693889931"}
0005433285297	C0EEDC	3604 298315	TAMARA AFANASEVA	{"email": "afanaseva-t_1981@postgrespro.ru", "phone": "+70137462805"}
0005433285298	D1611D	9651 507102	ALEKSEY SOKOLOV	{"phone": "+70221520559"}
0005433285299	BB0CFE	0558 071045	SVETLANA MAKAROVA	{"phone": "+70052368967"}
0005433285300	66E089	0809 141585	VALENTINA TARASOVA	{"email": "tarasova-valentina-28081970@postgrespro.ru", "phone": "+70053082863"}
0005433285301	6115B9	3521 900563	ARTEM MEDVEDEV	{"email": "medvedev.artem.081967@postgrespro.ru", "phone": "+70546869011"}
0005433285302	1E125A	7218 821833	ANASTASIYA KAZAKOVA	{"phone": "+70744621968"}
0005433285303	811A2D	4031 302860	EKATERINA SMIRNOVA	{"email": "e_smirnova.24111970@postgrespro.ru", "phone": "+70727694729"}
0005433285304	65D1A1	1133 964187	NIKOLAY DENISOV	{"email": "denisov_nikolay-03051961@postgrespro.ru", "phone": "+70728221742"}
0005433285305	65D1A1	2427 027636	DMITRIY MELNIKOV	{"email": "d-melnikov.051976@postgrespro.ru", "phone": "+70623273788"}
0005433285306	A019DD	5151 191337	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr1976@postgrespro.ru", "phone": "+70076569671"}
0005433285307	A019DD	6692 657785	ALEKSEY TIKHONOV	{"email": "atikhonov-13081965@postgrespro.ru", "phone": "+70413449023"}
0005433285308	589DC1	5852 064381	DANILA KUZNECOV	{"email": "d-kuznecov.1967@postgrespro.ru", "phone": "+70541644702"}
0005433285309	932359	4509 006711	ALEKSANDR RODIONOV	{"phone": "+70333977908"}
0005433285310	932359	5972 277934	IGOR NAUMOV	{"phone": "+70214790081"}
0005433285311	932359	3402 932794	OLEG TIKHONOV	{"phone": "+70947220104"}
0005433285312	692698	3477 882445	SVETLANA VOROBEVA	{"phone": "+70109905771"}
0005433285313	1BA573	5698 401586	ELENA ANDREEVA	{"email": "e.andreeva_071973@postgrespro.ru", "phone": "+70317389049"}
0005433285314	7F313D	8379 439025	SERGEY ANDREEV	{"email": "s_andreev_20041976@postgrespro.ru", "phone": "+70442473199"}
0005433285315	5B9918	8990 174158	DMITRIY KOROLEV	{"phone": "+70609160500"}
0005433285316	5B9918	1646 914281	POLINA BORISOVA	{"phone": "+70156751566"}
0005433285317	5B9918	3140 129470	VLADIMIR EGOROV	{"email": "egorov-v.1984@postgrespro.ru", "phone": "+70374583161"}
0005433285318	D62A49	2958 388707	EVGENIY MEDVEDEV	{"email": "medvedev-evgeniy.121975@postgrespro.ru", "phone": "+70686023410"}
0005433285319	5E6DD3	1287 499416	NIKOLAY SHEVCHENKO	{"email": "shevchenko.nikolay1971@postgrespro.ru", "phone": "+70799387720"}
0005433285320	5E6DD3	0452 918541	ALEKSANDR BORISOV	{"email": "aleksandr_borisov.26111962@postgrespro.ru", "phone": "+70162409942"}
0005433285321	4E32DC	8313 720425	IRINA MAKAROVA	{"email": "i-makarova.1976@postgrespro.ru", "phone": "+70594788999"}
0005433285322	932A1B	4558 696925	IRINA BELOVA	{"phone": "+70487248611"}
0005433285323	111AA9	1062 510845	IRINA GORBUNOVA	{"email": "i_gorbunova.021983@postgrespro.ru", "phone": "+70611024603"}
0005433285324	899C15	5250 705141	ALINA TIMOFEEVA	{"phone": "+70461552713"}
0005433285325	7CA726	2156 729633	SERGEY SERGEEV	{"email": "sergey-sergeev_111976@postgrespro.ru", "phone": "+70302584552"}
0005433285326	056B88	6442 484187	ANATOLIY SIDOROV	{"email": "asidorov.1973@postgrespro.ru", "phone": "+70335497100"}
0005433285327	FA4EC5	6829 661863	MARINA KOROLEVA	{"phone": "+70822125619"}
0005433285328	FA4EC5	3978 266947	LILIYA MALYSHEVA	{"phone": "+70716340033"}
0005433285329	A38F98	9000 906296	ELENA IVANOVA	{"email": "ivanova-e.17021975@postgrespro.ru", "phone": "+70719628043"}
0005433285330	A38F98	3602 462107	VLADIMIR GUSEV	{"phone": "+70134447486"}
0005433285331	64A8F0	7241 556661	OLGA ILINA	{"phone": "+70477074116"}
0005433285332	622E04	1587 815836	DMITRIY MATVEEV	{"email": "dmitriy_matveev29061965@postgrespro.ru", "phone": "+70113112142"}
0005433285333	622E04	7838 844213	LYUBOV SOKOLOVA	{"phone": "+70647814726"}
0005433285334	570A73	1485 474377	TATYANA MAKAROVA	{"email": "makarova-tatyana_111963@postgrespro.ru", "phone": "+70916722863"}
0005433285335	86C64A	1131 995644	ANASTASIYA IVANOVA	{"email": "ivanova-a.021978@postgrespro.ru", "phone": "+70914121723"}
0005433285336	4B94E3	3581 834918	YURIY KUZMIN	{"phone": "+70683816303"}
0005433285337	494D36	6016 135391	DARYA MIKHAYLOVA	{"phone": "+70849522988"}
0005433285338	C041D5	6890 096596	ALEKSEY MOISEEV	{"email": "moiseev_aleksey.27121962@postgrespro.ru", "phone": "+70544032709"}
0005433285339	B57C6A	5787 299798	ALEKSANDR ILIN	{"email": "ilin-a-101960@postgrespro.ru", "phone": "+70654017558"}
0005433285340	B57C6A	3305 467537	EKATERINA ZHURAVLEVA	{"phone": "+70561788761"}
0005433285341	DDABD8	1062 495556	VERA GORBUNOVA	{"phone": "+70994025978"}
0005433285342	DF3375	3555 397914	ILSHAT BELOV	{"email": "belov-i-1970@postgrespro.ru", "phone": "+70015447858"}
0005433285343	5BC668	1231 188109	ALEKSEY MARTYNOV	{"phone": "+70852776315"}
0005433285344	6697ED	8333 103127	NIKOLAY SMIRNOV	{"phone": "+70340904773"}
0005433285345	9E844F	3510 227230	NIKOLAY SIDOROV	{"email": "nikolay-sidorov.1968@postgrespro.ru", "phone": "+70094725326"}
0005433285346	9E844F	4150 126836	PETR GRIGOREV	{"phone": "+70147050496"}
0005433285347	9E844F	6866 204231	ELENA CHERNOVA	{"phone": "+70552150479"}
0005433285348	7DD4B8	1198 805504	LYUDMILA NAZAROVA	{"email": "lnazarova_021961@postgrespro.ru", "phone": "+70792297218"}
0005433285349	7DD4B8	7155 510592	DANIIL GAVRILOV	{"phone": "+70051995210"}
0005433285350	A936F1	5699 530873	TATYANA ZHUKOVA	{"phone": "+70201734042"}
0005433285351	C05BC2	9667 827942	GENNADIY ZHURAVLEV	{"email": "zhuravlev_g21061972@postgrespro.ru", "phone": "+70366256693"}
0005433285352	C05BC2	2958 292286	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev1976@postgrespro.ru", "phone": "+70959712086"}
0005433285353	9FAFDA	0755 441714	NATALYA ILINA	{"phone": "+70471657156"}
0005433285354	9FAFDA	0505 011714	ALINA KISELEVA	{"email": "kiseleva.a.28071967@postgrespro.ru", "phone": "+70789585638"}
0005433285355	E4B019	5383 889486	ARTEM SCHERBAKOV	{"phone": "+70726920401"}
0005433285356	E4B019	2265 489046	OLGA MAKSIMOVA	{"phone": "+70532079389"}
0005433285357	A0F11E	2923 331532	LYUDMILA SOKOLOVA	{"phone": "+70244191813"}
0005433285358	A0F11E	8720 130208	EDUARD IVANOV	{"email": "ivanov-eduard-15041975@postgrespro.ru", "phone": "+70366109690"}
0005433285359	FBAC5E	5675 162395	NIKOLAY ISAEV	{"phone": "+70888831179"}
0005433285360	FBAC5E	9994 947059	MIKHAIL ANDREEV	{"phone": "+70274679591"}
0005433285361	353DA2	0140 716140	OLGA MAKSIMOVA	{"phone": "+70746093900"}
0005433285362	353DA2	6625 177705	ROZA VOLKOVA	{"email": "roza.volkova-03061957@postgrespro.ru", "phone": "+70619358395"}
0005433285363	5E4E2D	0837 912573	NATALYA KARPOVA	{"email": "karpova-natalya_021979@postgrespro.ru", "phone": "+70479628515"}
0005433285364	5E4E2D	6810 444204	MARINA ANTONOVA	{"phone": "+70349980085"}
0005433285365	C58B18	8805 872746	NADEZHDA TIKHONOVA	{"email": "ntikhonova021976@postgrespro.ru", "phone": "+70906767673"}
0005433285366	3D186F	8323 889336	VLADIMIR CHERNOV	{"phone": "+70893030360"}
0005433285367	87398D	5409 718262	SERGEY BORISOV	{"phone": "+70845516908"}
0005433285368	11B508	8520 472205	TIMUR MAKSIMOV	{"email": "maksimovt_041976@postgrespro.ru", "phone": "+70671301484"}
0005433285369	FB3639	8715 541124	ALEKSANDR FEDOROV	{"phone": "+70603814416"}
0005433285370	89E186	4013 886259	EDUARD RODIONOV	{"email": "e.rodionov.041969@postgrespro.ru", "phone": "+70124070133"}
0005433285371	2F6DCD	5370 333984	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay15101968@postgrespro.ru", "phone": "+70563820311"}
0005433285372	E9C74D	0396 373504	VLADIMIR FROLOV	{"phone": "+70979018585"}
0005433285373	CC25D9	9135 184034	SOFYA NOVIKOVA	{"email": "s_novikova.1979@postgrespro.ru", "phone": "+70372991668"}
0005433285374	CC25D9	1456 752565	VIKTOR MIRONOV	{"email": "v-mironov17111970@postgrespro.ru", "phone": "+70113708865"}
0005433285375	CC25D9	7443 639204	ANASTASIYA MELNIKOVA	{"email": "melnikova_a.061963@postgrespro.ru", "phone": "+70683217580"}
0005433285376	C6E049	4749 550584	GALINA ANISIMOVA	{"email": "g-anisimova_1971@postgrespro.ru", "phone": "+70407497225"}
0005433285377	850BF2	0521 920791	ALEKSANDR ANDREEV	{"phone": "+70176551571"}
0005433285378	850BF2	5925 962519	VALENTINA IVANOVA	{"phone": "+70928198546"}
0005433285379	850BF2	5161 996185	ELIZAVETA POPOVA	{"email": "popova_e_05011972@postgrespro.ru", "phone": "+70709895514"}
0005433285380	5E160C	0778 775914	GALINA STEPANOVA	{"email": "g_stepanova101972@postgrespro.ru", "phone": "+70508417429"}
0005433285381	5E160C	5201 461732	SOFIYA BELOVA	{"email": "s-belova_19031965@postgrespro.ru", "phone": "+70947625470"}
0005433285382	71A8C4	3881 529546	YULIYA ALEKSEEVA	{"email": "alekseevay_1972@postgrespro.ru", "phone": "+70934609361"}
0005433285383	549FE2	1805 385030	GRIGORIY VOLKOV	{"email": "g_volkov.051983@postgrespro.ru", "phone": "+70626033210"}
0005433285384	CCF5E3	1334 732487	BORIS SMIRNOV	{"email": "b_smirnov-121976@postgrespro.ru", "phone": "+70340386673"}
0005433285385	00E8AA	0967 236607	KSENIYA MIRONOVA	{"email": "kseniya-mironova_24091966@postgrespro.ru", "phone": "+70058025187"}
0005433285386	32F475	4275 493901	VASILIY TARASOV	{"email": "vtarasov-1969@postgrespro.ru", "phone": "+70366158328"}
0005433285387	B3B626	3601 984093	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev-1975@postgrespro.ru", "phone": "+70790164679"}
0005433285388	B3B626	1293 673847	ALEKSEY FROLOV	{"email": "frolov_aleksey-111966@postgrespro.ru", "phone": "+70321474300"}
0005433285389	B3B626	6663 121852	MIKHAIL STEPANOV	{"phone": "+70762568804"}
0005433285390	E439B0	1730 287762	NINA PETROVA	{"email": "n-petrova02061972@postgrespro.ru", "phone": "+70578014518"}
0005433285391	E439B0	2593 336348	NINA NAZAROVA	{"phone": "+70699267735"}
0005433285392	494E99	5306 024816	ANDREY AFANASEV	{"email": "aafanasev1965@postgrespro.ru", "phone": "+70880026633"}
0005433285393	5E0300	5733 918535	YURIY TIKHONOV	{"email": "yuriytikhonov.091973@postgrespro.ru", "phone": "+70792766190"}
0005433285394	21C8CF	8494 801670	SVETLANA ZAKHAROVA	{"phone": "+70275799198"}
0005433285395	21C8CF	2418 602207	MARIYA EGOROVA	{"email": "mariya-egorova1978@postgrespro.ru", "phone": "+70093928876"}
0005433285396	21971A	8990 932638	EVGENIY FROLOV	{"phone": "+70885860712"}
0005433285397	21971A	2355 673305	ANDREY KUDRYASHOV	{"email": "kudryashov-andrey15121971@postgrespro.ru", "phone": "+70469176632"}
0005433285398	077BB7	3280 007382	ALEKSANDR SCHERBAKOV	{"email": "scherbakova.16041971@postgrespro.ru", "phone": "+70077705323"}
0005433285399	077BB7	1134 266146	DINA LAZAREVA	{"phone": "+70034993665"}
0005433285400	0568C3	5419 085095	EVGENIY STEPANOV	{"phone": "+70313008316"}
0005433285401	0568C3	0602 167993	ALEKSANDR ISAEV	{"phone": "+70278881758"}
0005433285402	4EE253	8737 653018	ELENA KONOVALOVA	{"email": "konovalova-elena.12121959@postgrespro.ru", "phone": "+70539376092"}
0005433285403	CB0532	2587 729162	LIDIYA AFANASEVA	{"email": "l_afanaseva.02031973@postgrespro.ru", "phone": "+70552884888"}
0005433285404	CB0532	4262 719688	MIKHAIL KOZLOV	{"phone": "+70513216908"}
0005433285405	3696D5	1594 061397	ANNA MAKSIMOVA	{"email": "maksimovaa1975@postgrespro.ru", "phone": "+70666420561"}
0005433285406	0835EE	3890 214750	YULIYA MALYSHEVA	{"email": "malysheva-yuliya-03021976@postgrespro.ru", "phone": "+70789033297"}
0005433285407	063591	4641 296845	NINA ZAKHAROVA	{"phone": "+70049626174"}
0005433285408	ECCAE4	2753 395713	ALEKSANDR BORISOV	{"phone": "+70387594186"}
0005433285409	DE9C0E	3211 553200	VALENTINA KULIKOVA	{"email": "kulikova-v.051975@postgrespro.ru", "phone": "+70674888882"}
0005433285410	42E45A	3115 615945	SVETLANA BARANOVA	{"email": "baranova-svetlana-1971@postgrespro.ru", "phone": "+70015101854"}
0005433285411	42E45A	8061 296424	IVAN KULIKOV	{"phone": "+70970900737"}
0005433285412	42E45A	8249 170768	VLADIMIR POPOV	{"phone": "+70860329490"}
0005433285413	2936F2	5481 192279	ALEKSEY KRASNOV	{"email": "aleksey_krasnov21011969@postgrespro.ru", "phone": "+70809212570"}
0005433285414	0ADEC7	4675 024633	NADEZHDA STEPANOVA	{"email": "nadezhdastepanova.25111980@postgrespro.ru", "phone": "+70109520321"}
0005433285415	29F998	0943 067504	TATYANA BOGDANOVA	{"phone": "+70517755945"}
0005433285416	78D2E6	9091 520635	DANILA STEPANOV	{"email": "stepanov_danila.1959@postgrespro.ru", "phone": "+70488823495"}
0005433285417	1D3436	2479 589112	ALBINA VOLKOVA	{"phone": "+70372410070"}
0005433285418	6435D8	3771 696351	VIKTOR MATVEEV	{"email": "viktor_matveev-03071970@postgrespro.ru", "phone": "+70958979076"}
0005433285419	547A06	6159 881372	ALEKSANDR NOVIKOV	{"phone": "+70104711550"}
0005433285420	547A06	0659 719810	ARINA SIDOROVA	{"email": "sidorovaa.1968@postgrespro.ru", "phone": "+70540653737"}
0005433285421	3562AC	8899 012370	MARIYA POPOVA	{"email": "popova-mariya-1963@postgrespro.ru", "phone": "+70461401035"}
0005433285422	60DD37	9065 649246	SERGEY FOMIN	{"phone": "+70628724472"}
0005433285423	60DD37	7741 782744	MARIYA LAZAREVA	{"phone": "+70866070603"}
0005433285424	F4E47A	5423 884001	SVETLANA VLASOVA	{"phone": "+70241988221"}
0005433285425	F4E47A	9807 401525	ANTONINA IVANOVA	{"phone": "+70030575556"}
0005433285426	F4E47A	9929 990878	RUSTAM ALEKSANDROV	{"phone": "+70311250412"}
0005433285427	B9E03B	1497 880132	MIKHAIL ABRAMOV	{"phone": "+70129810712"}
0005433285428	B9E03B	6937 451650	ILYA MAKSIMOV	{"email": "imaksimov_061962@postgrespro.ru", "phone": "+70601785625"}
0005433285429	B9E03B	2336 208109	IRINA MOISEEVA	{"phone": "+70288177138"}
0005433285430	B70F88	4724 118553	IRINA LEBEDEVA	{"email": "ilebedeva.1977@postgrespro.ru", "phone": "+70568696067"}
0005433285431	29884E	4659 149920	ARTEMIY EGOROV	{"phone": "+70940984425"}
0005433285432	A61EEE	5320 132532	EVGENIY PETROV	{"email": "petrov-evgeniy.071960@postgrespro.ru", "phone": "+70927777235"}
0005433285433	1C6898	3784 373884	VALERIY GAVRILOV	{"phone": "+70654454537"}
0005433285434	FEDDE8	8482 541871	NIKOLAY MELNIKOV	{"phone": "+70959288496"}
0005433285435	C071EE	2010 055599	ALEKSANDRA SOROKINA	{"phone": "+70596647688"}
0005433285436	C071EE	0618 477038	ANATOLIY FEDOROV	{"email": "anatoliy-fedorov.12041955@postgrespro.ru", "phone": "+70090500478"}
0005433285437	213A01	0566 945986	KARINA SOROKINA	{"email": "k_sorokina28021969@postgrespro.ru", "phone": "+70697828669"}
0005433285438	317DB3	8734 518206	ALEKSEY ZAKHAROV	{"phone": "+70457919332"}
0005433285439	317DB3	2014 456769	LEV MEDVEDEV	{"phone": "+70222395338"}
0005433285440	CD3553	6398 830932	OLGA ANISIMOVA	{"email": "anisimova-olga_30041967@postgrespro.ru", "phone": "+70125038677"}
0005433285441	CD3553	0979 354885	EKATERINA YUDINA	{"email": "ekaterina.yudina-1976@postgrespro.ru", "phone": "+70427760019"}
0005433285442	CD3553	5993 936093	ANASTASIYA AKIMOVA	{"phone": "+70295371191"}
0005433285443	81DF7C	7726 573077	VALENTINA SOLOVEVA	{"phone": "+70413440595"}
0005433285444	012190	9391 462410	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov14031972@postgrespro.ru", "phone": "+70411667190"}
0005433285445	012190	5732 170969	ANDREY OSIPOV	{"email": "a.osipov-121967@postgrespro.ru", "phone": "+70125124417"}
0005433285446	68C759	4945 455941	KLARA AFANASEVA	{"email": "klaraafanaseva091967@postgrespro.ru", "phone": "+70514275526"}
0005433285447	82DC10	4545 714948	ARTEM MAKAROV	{"email": "makarov-artem_1969@postgrespro.ru", "phone": "+70558422666"}
0005433285448	82DC10	7688 884930	ANDREY EGOROV	{"email": "andrey-egorov_30031965@postgrespro.ru", "phone": "+70282897922"}
0005433285449	A4612A	2648 803719	IRINA GORBUNOVA	{"email": "gorbunovai.17081976@postgrespro.ru", "phone": "+70342221868"}
0005433285450	A4612A	3910 111610	RAMIL RODIONOV	{"email": "ramilrodionov_1962@postgrespro.ru", "phone": "+70343292703"}
0005433285451	4F3EB5	0566 850949	TAISIYA EGOROVA	{"email": "t.egorova_1970@postgrespro.ru", "phone": "+70584381107"}
0005433285452	E530AB	7685 599897	NATALYA SERGEEVA	{"email": "sergeeva-n-1981@postgrespro.ru", "phone": "+70381773121"}
0005433285453	67189C	1654 145836	ALEKSANDRA GAVRILOVA	{"phone": "+70903202525"}
0005433285454	FA50E1	1379 182914	SVETLANA EGOROVA	{"email": "s.egorova.121967@postgrespro.ru", "phone": "+70124046066"}
0005433285455	FA50E1	4332 782952	ANATOLIY MOROZOV	{"email": "amorozov_031969@postgrespro.ru", "phone": "+70318310209"}
0005433285456	AC3017	5789 849805	SERGEY MATVEEV	{"email": "sergey.matveev28111967@postgrespro.ru", "phone": "+70719745798"}
0005433285457	AC3017	5147 486509	OLGA NIKITINA	{"phone": "+70051517279"}
0005433285458	F4F7E9	6021 342441	ARTEMIY MEDVEDEV	{"phone": "+70457530789"}
0005433285459	A7E27D	5487 459350	MAKSIM POPOV	{"phone": "+70731252888"}
0005433285460	8601F7	3403 743500	DANIIL FOMIN	{"phone": "+70221585280"}
0005433285461	17D39B	1300 628914	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov_11111977@postgrespro.ru", "phone": "+70023511211"}
0005433285462	17D39B	8535 694434	NIKITA SOROKIN	{"email": "nikita_sorokin_071964@postgrespro.ru", "phone": "+70149576589"}
0005433285463	A8023C	2578 806920	ALEKSANDR ZAYCEV	{"phone": "+70405989823"}
0005433285464	4DFCE7	6034 157097	DMITRIY BELOV	{"phone": "+70191047026"}
0005433285465	4DFCE7	5949 303777	VYACHESLAV SOLOVEV	{"email": "vyacheslav.solovev.1980@postgrespro.ru", "phone": "+70900538276"}
0005433285466	4DFCE7	6443 362874	DMITRIY NAZAROV	{"phone": "+70250566899"}
0005433285467	90A6DE	7046 066916	KAMIL ILIN	{"email": "ilin-kamil_24041977@postgrespro.ru", "phone": "+70174629892"}
0005433285468	90A6DE	3861 849619	ELENA KUZNECOVA	{"phone": "+70199139492"}
0005433285469	4EA83E	7918 191535	YURIY MELNIKOV	{"phone": "+70232768422"}
0005433285470	5DF02B	4117 357151	SERGEY DENISOV	{"phone": "+70535633875"}
0005433285471	AFBB42	8014 070417	VLADIMIR PETROV	{"email": "v-petrov-03091977@postgrespro.ru", "phone": "+70689946339"}
0005433285472	B4CA4C	6870 713353	GENNADIY KULIKOV	{"email": "g.kulikov_021965@postgrespro.ru", "phone": "+70953279388"}
0005433285473	E964E4	1120 863183	EKATERINA LOGINOVA	{"email": "loginova.e-1980@postgrespro.ru", "phone": "+70013002078"}
0005433285474	E964E4	7625 955153	VLADIMIR FROLOV	{"email": "frolov.v_1978@postgrespro.ru", "phone": "+70709264068"}
0005433285475	213A89	4316 586412	NIKOLAY SERGEEV	{"phone": "+70967598000"}
0005433285476	213A89	6813 203864	EKATERINA FROLOVA	{"email": "ekaterinafrolova-071979@postgrespro.ru", "phone": "+70209372203"}
0005433285477	2ECBC9	4554 263587	ANNA PETROVA	{"phone": "+70591348890"}
0005433285478	0B2EBD	1870 644704	IGOR MOROZOV	{"phone": "+70914794171"}
0005433285479	0B2EBD	7269 672863	SERGEY STEPANOV	{"phone": "+70804859033"}
0005433285480	CC6971	9585 211992	RITA ROMANOVA	{"email": "romanova.rita_28071971@postgrespro.ru", "phone": "+70424690309"}
0005433285481	CC6971	8933 127825	SERGEY SERGEEV	{"email": "sergey_sergeev.1981@postgrespro.ru", "phone": "+70239619467"}
0005433285482	CC6971	8559 357984	MAKSIM TARASOV	{"phone": "+70397792073"}
0005433285483	B4656E	7854 046700	SERGEY KUZNECOV	{"email": "kuznecov-s_23101975@postgrespro.ru", "phone": "+70473655599"}
0005433285484	B4656E	2462 504445	VASILIY PETROV	{"phone": "+70119718278"}
0005433285485	DC95BE	0062 834237	RAFAIL MOROZOV	{"phone": "+70277623620"}
0005433285486	DC95BE	3003 276388	VLADIMIR KAZAKOV	{"email": "kazakov.vladimir.071972@postgrespro.ru", "phone": "+70544867828"}
0005433285487	DC95BE	5559 826111	EKATERINA MEDVEDEVA	{"phone": "+70062148755"}
0005433285488	9C1966	8944 401408	SVETLANA SAVELEVA	{"phone": "+70910641113"}
0005433285489	A06F51	0935 307786	MARGARITA GAVRILOVA	{"phone": "+70663157720"}
0005433285490	F24C8C	1737 877492	ZINAIDA KUZNECOVA	{"phone": "+70322259212"}
0005433285491	F24C8C	0356 699025	LYUDMILA IVANOVA	{"email": "ivanova_l1977@postgrespro.ru", "phone": "+70804846930"}
0005433285492	DADAAE	2404 104001	SERGEY MARTYNOV	{"email": "sergey_martynov_1971@postgrespro.ru", "phone": "+70931535561"}
0005433285493	DADAAE	2496 101793	NADEZHDA BORISOVA	{"phone": "+70127652140"}
0005433285494	DADAAE	0179 013234	TATYANA NESTEROVA	{"phone": "+70999499781"}
0005433285495	F735EC	1057 077387	VYACHESLAV NOVIKOV	{"email": "novikov.vyacheslav-1965@postgrespro.ru", "phone": "+70778487770"}
0005433285496	F735EC	8645 421627	VALENTINA VASILEVA	{"phone": "+70479084347"}
0005433285497	F735EC	9729 321413	VERA NIKITINA	{"phone": "+70768017015"}
0005433285498	9B5481	2832 466931	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.26091971@postgrespro.ru", "phone": "+70431469135"}
0005433285499	9B5481	2298 393384	MIKHAIL YAKOVLEV	{"phone": "+70422107441"}
0005433285500	E58832	2851 215169	MIKHAIL VLASOV	{"phone": "+70938876256"}
0005433285501	EA81F3	8202 599684	TATYANA FADEEVA	{"email": "fadeeva.tatyana_1966@postgrespro.ru", "phone": "+70740561391"}
0005433285502	EA81F3	2028 898549	OLGA IVANOVA	{"email": "o.ivanova-1966@postgrespro.ru", "phone": "+70936745920"}
0005433285503	EA81F3	3928 170766	SVETLANA FOMINA	{"email": "sfomina08061968@postgrespro.ru", "phone": "+70354313969"}
0005433285504	8BE96C	8803 560931	YULIYA MOISEEVA	{"phone": "+70353287113"}
0005433285505	86533A	7175 511376	ELENA KISELEVA	{"email": "elena-kiseleva1973@postgrespro.ru", "phone": "+70072491720"}
0005433285506	2210A2	9948 029003	POLINA FEDOROVA	{"phone": "+70703533051"}
0005433285507	BB0B42	4172 661694	NINA GAVRILOVA	{"email": "n-gavrilova1973@postgrespro.ru", "phone": "+70269862897"}
0005433285508	BB0B42	1470 434811	ALEKSANDR PETROV	{"phone": "+70127241136"}
0005433285509	8B8E48	4203 700903	NATALYA KOLESNIKOVA	{"email": "kolesnikova_natalya_14051977@postgrespro.ru", "phone": "+70453345178"}
0005433285510	697C09	8280 419600	OLGA MAKSIMOVA	{"email": "maksimovao.1973@postgrespro.ru", "phone": "+70626152721"}
0005433285511	96EF41	7529 697970	LYUBOV KAZAKOVA	{"email": "lyubov_kazakova.081974@postgrespro.ru", "phone": "+70278054038"}
0005433285512	96EF41	4419 785736	YURIY ZAKHAROV	{"email": "yuriy-zakharov.1971@postgrespro.ru", "phone": "+70950984881"}
0005433285513	A0D2E7	4922 161151	PETR KUZMIN	{"email": "kuzmin_petr.1983@postgrespro.ru", "phone": "+70404311501"}
0005433285514	2CC314	4086 666856	OLGA NOVIKOVA	{"email": "olganovikova121969@postgrespro.ru", "phone": "+70143004581"}
0005433285515	F9EA5F	8125 482401	VIKTOR STEPANOV	{"phone": "+70350058658"}
0005433285516	354612	8544 103110	LYUDMILA MARTYNOVA	{"phone": "+70055811918"}
0005433285517	354612	6472 495363	SERGEY POPOV	{"phone": "+70007891915"}
0005433285518	FACEEA	8416 749661	MARINA ZAKHAROVA	{"phone": "+70936912484"}
0005433285519	A2331E	3992 261144	MARINA NIKOLAEVA	{"email": "nikolaeva_m_09041971@postgrespro.ru", "phone": "+70403758307"}
0005433285520	A2331E	4052 741999	VERA FADEEVA	{"phone": "+70457126470"}
0005433285521	BD64AC	2516 515509	ELENA POPOVA	{"email": "popovaelena_01051976@postgrespro.ru", "phone": "+70691329951"}
0005433285522	DB0564	7836 003618	ZINAIDA MIRONOVA	{"phone": "+70925778274"}
0005433285523	DB0564	7324 883997	EVGENIY STEPANOV	{"email": "stepanov.e061964@postgrespro.ru", "phone": "+70452887662"}
0005433285524	22B707	4841 098275	IRINA MIKHAYLOVA	{"phone": "+70762171593"}
0005433285525	22B707	4312 769297	VLADIMIR FEDOTOV	{"email": "fedotov-vladimir_1971@postgrespro.ru", "phone": "+70992508747"}
0005433285526	7834E9	1828 574846	NATALYA TARASOVA	{"phone": "+70927986127"}
0005433285527	EBAAC0	7844 703586	VLADIMIR TIMOFEEV	{"email": "timofeevv.1964@postgrespro.ru", "phone": "+70687401564"}
0005433285528	EBAAC0	3125 343666	EKATERINA NAZAROVA	{"email": "ekaterina-nazarova_23101975@postgrespro.ru", "phone": "+70838920068"}
0005433285529	EBAAC0	3035 857166	NADEZHDA ZHUKOVA	{"phone": "+70721811293"}
0005433285530	E15C0E	6071 772187	ZHANNA ANISIMOVA	{"phone": "+70242669454"}
0005433285531	E15C0E	8710 902238	LIDIYA LAZAREVA	{"email": "lazareva.lidiya041968@postgrespro.ru", "phone": "+70977140127"}
0005433285532	117578	8799 333463	ANTONINA SEMENOVA	{"email": "a-semenova17061971@postgrespro.ru", "phone": "+70923601362"}
0005433285533	117578	1221 503873	OKSANA TIKHONOVA	{"email": "tikhonovao05071967@postgrespro.ru", "phone": "+70632140255"}
0005433285534	64B837	4448 576342	RAIL BARANOV	{"email": "r.baranov.14121968@postgrespro.ru", "phone": "+70699453758"}
0005433285535	64B837	7863 768197	IRINA CHERNOVA	{"phone": "+70642807546"}
0005433285536	64B837	8610 326555	GALINA IVANOVA	{"phone": "+70434127103"}
0005433285537	B17AD9	1583 518554	YULIYA SOKOLOVA	{"email": "y-sokolova_1978@postgrespro.ru", "phone": "+70652521917"}
0005433285538	B17AD9	0176 940096	YURIY IVANOV	{"email": "yivanov_08071958@postgrespro.ru", "phone": "+70443925181"}
0005433285539	973E8A	4286 264391	MARINA PETROVA	{"phone": "+70464841844"}
0005433285540	973E8A	5890 487300	ANNA ANISIMOVA	{"phone": "+70521941352"}
0005433285541	A2D0BD	3063 225029	ALEKSANDR DENISOV	{"phone": "+70406579723"}
0005433285542	54EC7F	1716 986047	YURIY POPOV	{"phone": "+70198955158"}
0005433285543	E2EF6C	3378 420795	NIKOLAY VASILEV	{"email": "vasilevnikolay_1968@postgrespro.ru", "phone": "+70782554325"}
0005433285544	05CDF3	4308 705223	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_1971@postgrespro.ru", "phone": "+70995398924"}
0005433285545	C4B7F6	2397 748099	TATYANA KULIKOVA	{"email": "tatyana-kulikova.1968@postgrespro.ru", "phone": "+70752359557"}
0005433285546	F2D796	1303 910482	IRINA KOZLOVA	{"email": "i.kozlova.011979@postgrespro.ru", "phone": "+70016822611"}
0005433285547	BE98DA	6958 700659	ANASTASIYA FILIPPOVA	{"phone": "+70461656477"}
0005433285548	424B1C	1352 829434	ALEKSANDR BELOV	{"email": "belov_aleksandr1968@postgrespro.ru", "phone": "+70032301883"}
0005433285549	054EF1	4443 238103	TATYANA ERMAKOVA	{"email": "tatyana.ermakova071968@postgrespro.ru", "phone": "+70770165760"}
0005433285550	054EF1	9859 684965	NURIYA ERMAKOVA	{"email": "ermakova_n.1961@postgrespro.ru", "phone": "+70538420763"}
0005433285551	F6C843	8535 257502	NIKOLAY POPOV	{"phone": "+70072697885"}
0005433285552	F6C843	3027 123613	ALEKSANDR GUSEV	{"phone": "+70092867303"}
0005433285553	2EEBB2	5988 723202	ANATOLIY KUZMIN	{"phone": "+70135756538"}
0005433285554	0B42AE	6618 514258	RAISA TIKHONOVA	{"phone": "+70720536538"}
0005433285555	4C6B3D	7262 982575	VERA MAKSIMOVA	{"phone": "+70674009507"}
0005433285556	C62E7C	0920 928658	RUSTAM SIDOROV	{"phone": "+70321899564"}
0005433285557	B2114E	5691 475611	GALINA RYABOVA	{"phone": "+70463043254"}
0005433285558	8A74EC	5704 779265	ANNA KUZNECOVA	{"phone": "+70726670069"}
0005433285559	2F8848	3856 774617	EVGENIY POPOV	{"email": "e.popov091967@postgrespro.ru", "phone": "+70061169291"}
0005433285560	759D48	2097 604229	EKATERINA ERMAKOVA	{"phone": "+70702732397"}
0005433285561	F5315D	9183 008426	GALINA OSIPOVA	{"phone": "+70241367637"}
0005433285562	F5315D	6358 519220	GENNADIY VASILEV	{"phone": "+70934767187"}
0005433285563	7DF321	0531 892028	ALEKSANDR KOZLOV	{"phone": "+70686704752"}
0005433285564	7DF321	1579 097289	IVAN MARTYNOV	{"email": "martynov.i_19111974@postgrespro.ru", "phone": "+70176658160"}
0005433285565	0C043A	3822 568616	ARTEM ORLOV	{"phone": "+70910692734"}
0005433285566	26B2DD	9312 541375	TATYANA TARASOVA	{"email": "tatyana_tarasova09071978@postgrespro.ru", "phone": "+70526887902"}
0005433285567	B90BFD	8580 859174	MAYYA NOVIKOVA	{"phone": "+70766463744"}
0005433285568	B90BFD	6187 521484	TATYANA KULIKOVA	{"phone": "+70376693409"}
0005433285569	460B53	2823 171910	SOFIYA ZAYCEVA	{"email": "zayceva-s-051974@postgrespro.ru", "phone": "+70206578935"}
0005433285570	D38B85	8956 326008	LIDIYA ISAEVA	{"phone": "+70809901599"}
0005433285571	B6A394	2330 358288	DANILA KUZNECOV	{"phone": "+70187439539"}
0005433285572	495EDF	2526 626431	YAROSLAV SIDOROV	{"email": "sidorov-y_051962@postgrespro.ru", "phone": "+70198400581"}
0005433285573	8D6E41	4749 915107	ANNA ZOTOVA	{"phone": "+70935432573"}
0005433285574	7D8F12	8806 670135	IRINA FILIPPOVA	{"email": "i-filippova.081980@postgrespro.ru", "phone": "+70047160385"}
0005433285575	72A3AE	9558 076861	NADEZHDA NESTEROVA	{"phone": "+70780632007"}
0005433285576	B185D7	0290 127069	ANNA POPOVA	{"phone": "+70759638802"}
0005433285577	84CC96	7098 745293	YULIYA ZAKHAROVA	{"email": "y-zakharova021969@postgrespro.ru", "phone": "+70127636346"}
0005433285578	84CC96	5502 050424	VALENTINA BELOVA	{"email": "belovav1957@postgrespro.ru", "phone": "+70928017948"}
0005433285579	1D35E6	1286 658237	ALEKSANDRA KOROLEVA	{"email": "koroleva_aleksandra-01071964@postgrespro.ru", "phone": "+70943871509"}
0005433285580	904DA6	4705 088716	MARIYA STEPANOVA	{"email": "mariya.stepanova-111973@postgrespro.ru", "phone": "+70535253077"}
0005433285581	E75F5A	6932 562592	ANASTASIYA GERASIMOVA	{"email": "gerasimova-anastasiya_1976@postgrespro.ru", "phone": "+70433644655"}
0005433285582	BF4DCC	1291 617625	VLADISLAV KULIKOV	{"email": "kulikovvladislav021968@postgrespro.ru", "phone": "+70057538602"}
0005433285583	BF4DCC	1094 858044	LARISA MEDVEDEVA	{"email": "medvedeva_l.1965@postgrespro.ru", "phone": "+70752482690"}
0005433285584	8F96AB	6099 680377	MIKHAIL IVANOV	{"phone": "+70545823905"}
0005433285585	202E27	2121 984765	SOFIYA IVANOVA	{"phone": "+70702543044"}
0005433285586	314BC7	9643 262355	ANDREY KUDRYASHOV	{"phone": "+70971468179"}
0005433285587	9B0BE9	4325 669014	YULIYA PAVLOVA	{"email": "yuliya.pavlova_04111975@postgrespro.ru", "phone": "+70059181442"}
0005433285588	6AE0F6	1489 163996	ELENA RYABOVA	{"phone": "+70293829844"}
0005433285589	6AE0F6	3731 984369	VLADIMIR KULIKOV	{"phone": "+70066493143"}
0005433285590	E37932	3273 939965	SVETLANA LOGINOVA	{"phone": "+70017792291"}
0005433285591	93AEC7	4197 250037	VLADIMIR MAKSIMOV	{"email": "v.maksimov1963@postgrespro.ru", "phone": "+70139264996"}
0005433285592	55E8D1	4085 885023	SERGEY DMITRIEV	{"email": "sdmitriev_13081977@postgrespro.ru", "phone": "+70571994197"}
0005433285593	55E8D1	1142 882973	EKATERINA MARTYNOVA	{"email": "e_martynova31031978@postgrespro.ru", "phone": "+70466389503"}
0005433285594	378A49	4063 690815	SERGEY GERASIMOV	{"phone": "+70284180234"}
0005433285595	378A49	3214 213068	NADIYA POPOVA	{"email": "n_popova_29061968@postgrespro.ru", "phone": "+70045249552"}
0005433285596	3ECEF3	9851 526307	YULIYA FEDOROVA	{"email": "yfedorova_011981@postgrespro.ru", "phone": "+70642358190"}
0005433285597	3ECEF3	2630 471179	ANDREY MOISEEV	{"phone": "+70448830858"}
0005433285598	3ECEF3	0885 719427	EKATERINA BORISOVA	{"email": "borisovaekaterina_23021964@postgrespro.ru", "phone": "+70086079415"}
0005433285599	393A3D	6926 325099	INNA ROMANOVA	{"email": "romanova.inna_1965@postgrespro.ru", "phone": "+70407240346"}
0005433285600	393A3D	0514 163508	MARIYA MAKSIMOVA	{"phone": "+70076590637"}
0005433285601	142710	7817 474641	ANGELINA MAKAROVA	{"email": "makarova.angelina011983@postgrespro.ru", "phone": "+70976583761"}
0005433285602	5F2491	8581 590310	ALEKSANDR POPOV	{"email": "popovaleksandr.27081969@postgrespro.ru", "phone": "+70214806472"}
0005433285603	15A3DF	3865 986383	KSENIYA FROLOVA	{"email": "k_frolova_121973@postgrespro.ru", "phone": "+70201577229"}
0005433285604	93F3A6	7439 302536	ALEKSEY KONOVALOV	{"email": "konovalova1971@postgrespro.ru", "phone": "+70449113882"}
0005433285605	24AF70	9488 725471	IGOR EGOROV	{"email": "egorov-igor_10071972@postgrespro.ru", "phone": "+70335169723"}
0005433285606	24AF70	4305 797095	RUSLAN SIDOROV	{"phone": "+70055611241"}
0005433285607	646150	4072 520763	NADEZHDA AKIMOVA	{"phone": "+70720360037"}
0005433285608	CC140D	1476 399635	NADEZHDA RYABOVA	{"email": "ryabova_nadezhda01041971@postgrespro.ru", "phone": "+70953895595"}
0005433285609	793E80	4844 445918	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr091971@postgrespro.ru", "phone": "+70400442527"}
0005433285610	972395	6413 463804	ILYA SMIRNOV	{"email": "smirnov_ilya-31031969@postgrespro.ru", "phone": "+70271679569"}
0005433285611	972395	8903 623475	ANASTASIYA ZAKHAROVA	{"email": "zakharova.a.1963@postgrespro.ru", "phone": "+70138240683"}
0005433285612	972395	8815 943760	SERGEY VOLKOV	{"phone": "+70301610420"}
0005433285613	D551AF	0157 461559	ROZA POLYAKOVA	{"email": "r.polyakova1976@postgrespro.ru", "phone": "+70074838260"}
0005433285614	7D6B1A	9814 045810	ALEKSANDR ORLOV	{"phone": "+70335853088"}
0005433285615	7D6B1A	6526 462164	VIKTOR POPOV	{"phone": "+70232268230"}
0005433285616	8F6920	8564 377956	LYUDMILA ISAEVA	{"email": "l-isaeva26121971@postgrespro.ru", "phone": "+70398903801"}
0005433285617	7D47B6	5410 199745	ZHANNA ANTONOVA	{"phone": "+70566619933"}
0005433285618	7D47B6	2148 914136	ALLA PETROVA	{"phone": "+70618408391"}
0005433285619	F83853	2090 089065	MARINA ROMANOVA	{"phone": "+70220865311"}
0005433285620	E60DA4	7384 184922	ELENA OVCHINNIKOVA	{"email": "ovchinnikova_elena1973@postgrespro.ru", "phone": "+70644456339"}
0005433285621	E60DA4	1360 249816	ILYA ZAKHAROV	{"phone": "+70966840450"}
0005433285622	4DEDF9	4138 662214	VLADIMIR ZAYCEV	{"phone": "+70589166032"}
0005433285623	4DEDF9	6048 092518	VIKTOR KRASNOV	{"email": "viktor_krasnov-22101989@postgrespro.ru", "phone": "+70375880808"}
0005433285624	4DEDF9	3358 904072	YURIY KRASNOV	{"email": "yuriy.krasnov1969@postgrespro.ru", "phone": "+70335927989"}
0005433285625	AD7906	2327 463470	ANDREY STEPANOV	{"phone": "+70859622557"}
0005433285626	AD7906	5271 099238	NATALYA MARTYNOVA	{"phone": "+70501008746"}
0005433285627	B06D6D	5965 723285	ELENA SMIRNOVA	{"phone": "+70580730609"}
0005433285628	0D4C12	4048 927476	ALENA SOKOLOVA	{"phone": "+70942039916"}
0005433285629	0D4C12	6104 584867	NADEZHDA TARASOVA	{"email": "n-tarasova-1970@postgrespro.ru", "phone": "+70149507581"}
0005433285630	A428DC	7619 163572	FATIMA ALEKSEEVA	{"email": "f_alekseeva_041971@postgrespro.ru", "phone": "+70564863409"}
0005433285631	F501F5	4890 672999	NIKOLAY ALEKSEEV	{"email": "alekseev_nikolay1969@postgrespro.ru", "phone": "+70068056814"}
0005433285632	7B511A	0385 380153	TATYANA SIDOROVA	{"email": "t.sidorova1985@postgrespro.ru", "phone": "+70615076398"}
0005433285633	7B511A	9080 366846	MARINA ANISIMOVA	{"phone": "+70874000048"}
0005433285634	FF994A	9623 408845	ANDREY ANTONOV	{"phone": "+70403272391"}
0005433285635	A3E86E	7532 690560	EVGENIY OSIPOV	{"phone": "+70450258218"}
0005433285636	A3E86E	5622 287182	ANATOLIY SAVELEV	{"phone": "+70213155014"}
0005433285637	454989	9229 790583	VIKTORIYA YAKOVLEVA	{"email": "viktoriya.yakovleva-1972@postgrespro.ru", "phone": "+70511745350"}
0005433285638	454989	4061 002714	VADIM BARANOV	{"phone": "+70184333679"}
0005433285639	206C6E	6148 961667	ZINAIDA TARASOVA	{"email": "zinaida-tarasova.091970@postgrespro.ru", "phone": "+70779638702"}
0005433285640	67AA62	4696 574165	PAVEL KAZAKOV	{"email": "kazakovp1984@postgrespro.ru", "phone": "+70865497014"}
0005433285641	67AA62	6935 101225	VALENTIN ANDREEV	{"phone": "+70488789163"}
0005433285642	F67EAF	5416 643093	MARIYA ALEKSANDROVA	{"phone": "+70284325328"}
0005433285643	327998	6354 397159	VLADIMIR SMIRNOV	{"phone": "+70638806592"}
0005433285644	FBBB04	9670 660811	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr11081971@postgrespro.ru", "phone": "+70826248046"}
0005433285645	FBBB04	5191 169450	ANNA TIKHONOVA	{"email": "tikhonovaanna-081968@postgrespro.ru", "phone": "+70306077059"}
0005433285646	E8012D	4944 792336	IVAN SIDOROV	{"phone": "+70076080178"}
0005433285647	46B3B8	5428 268043	DARYA KONOVALOVA	{"email": "d_konovalova05061973@postgrespro.ru", "phone": "+70897760437"}
0005433285648	620A15	9746 013026	VLADIMIR SERGEEV	{"phone": "+70503605030"}
0005433285649	620A15	6478 280720	IRINA CHERNOVA	{"email": "ichernova051963@postgrespro.ru", "phone": "+70995205866"}
0005433285650	7D05CF	9079 134751	MARIYA KOVALEVA	{"phone": "+70572298758"}
0005433285651	34EF06	3621 825388	ALEKSEY KUZMIN	{"email": "kuzmin.aleksey.111970@postgrespro.ru", "phone": "+70259370629"}
0005433285652	192049	3739 175808	ALEKSANDR EGOROV	{"phone": "+70044175747"}
0005433285653	A63CF4	0588 924712	MARINA KOROLEVA	{"email": "m.koroleva1968@postgrespro.ru", "phone": "+70230769505"}
0005433285654	15A469	1463 151489	GLEB MATVEEV	{"email": "matveev.g.02041980@postgrespro.ru", "phone": "+70357770982"}
0005433285655	BBF0C1	8328 867629	NADEZHDA PETROVA	{"phone": "+70544930486"}
0005433285656	E203EF	7672 097693	VERA MIKHAYLOVA	{"phone": "+70561190026"}
0005433285657	EE33BD	2093 263273	VLADIMIR BORISOV	{"email": "v_borisov.1978@postgrespro.ru", "phone": "+70137600063"}
0005433285658	50A3DF	2426 153773	PETR SMIRNOV	{"phone": "+70038013600"}
0005433285659	EFB826	0179 265337	VLADIMIR KONOVALOV	{"email": "konovalov-v_19031973@postgrespro.ru", "phone": "+70604057798"}
0005433285660	EFB826	9230 523982	NATALYA STEPANOVA	{"email": "n_stepanova-18081966@postgrespro.ru", "phone": "+70779304681"}
0005433285661	762912	3866 302752	TATYANA IVANOVA	{"email": "ivanova-t_08021968@postgrespro.ru", "phone": "+70285788868"}
0005433285662	A55F73	1334 070701	ALEKSANDRA ALEKSEEVA	{"email": "aleksandra-alekseeva071978@postgrespro.ru", "phone": "+70981842360"}
0005433285663	A55F73	0212 806179	NATALYA KUZMINA	{"phone": "+70961789588"}
0005433285664	76B781	1339 844114	GALINA NAUMOVA	{"email": "naumova-galina-1968@postgrespro.ru", "phone": "+70652441254"}
0005433285665	7FD2BE	9194 039675	ELENA KUZNECOVA	{"phone": "+70866266969"}
0005433285666	22110E	0730 950802	SERGEY IVANOV	{"email": "ivanov-sergey121966@postgrespro.ru", "phone": "+70556542996"}
0005433285667	52D690	2963 408946	TATYANA FROLOVA	{"phone": "+70344551186"}
0005433285668	A861BB	4543 387758	VLADISLAV KRASNOV	{"email": "krasnovv_041982@postgrespro.ru", "phone": "+70638989817"}
0005433285669	B87F22	6438 039880	VITALIY BARANOV	{"phone": "+70951366482"}
0005433285670	5CFC77	0590 925675	NIKOLAY EGOROV	{"email": "negorov_25111966@postgrespro.ru", "phone": "+70939160449"}
0005433285671	31FA48	4920 283399	KONSTANTIN SEMENOV	{"phone": "+70788350341"}
0005433285672	BA248A	6599 887099	ANTONINA MEDVEDEVA	{"email": "medvedeva_a-1961@postgrespro.ru", "phone": "+70315856696"}
0005433285673	43F7A7	9560 154735	OKSANA BORISOVA	{"email": "borisova.oksana.27071967@postgrespro.ru", "phone": "+70269797118"}
0005433285674	0DE599	5932 399108	ANTONINA EFREMOVA	{"email": "antonina-efremova1969@postgrespro.ru", "phone": "+70735303614"}
0005433285675	79B5D1	4796 889130	VERA ANTONOVA	{"email": "antonovav021982@postgrespro.ru", "phone": "+70935640602"}
0005433285676	ED495C	3220 209180	OLEG EGOROV	{"phone": "+70610746086"}
0005433285677	308618	3135 912479	TATYANA RYABOVA	{"email": "ryabova_tatyana_30101967@postgrespro.ru", "phone": "+70679682492"}
0005433285678	7FAE3D	0288 772403	VIKTORIYA ILINA	{"phone": "+70160829582"}
0005433285679	21F512	6477 288834	KRISTINA SOKOLOVA	{"email": "sokolovakristina.21101976@postgrespro.ru", "phone": "+70968819578"}
0005433285680	FEFDE8	0175 803861	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev.17081984@postgrespro.ru", "phone": "+70464834115"}
0005433285681	FEFDE8	3439 373955	SVETLANA DMITRIEVA	{"email": "dmitrieva.svetlana121973@postgrespro.ru", "phone": "+70726516961"}
0005433285682	5B06EB	0135 033441	NATALYA SOLOVEVA	{"phone": "+70537464627"}
0005433285683	5B06EB	1588 715580	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr.111969@postgrespro.ru", "phone": "+70345422957"}
0005433285684	6CB66A	1491 920754	ALEKSEY NIKITIN	{"phone": "+70856685940"}
0005433285685	6C1A46	8415 295844	ANASTASIYA MIRONOVA	{"email": "a-mironova_1971@postgrespro.ru", "phone": "+70686082446"}
0005433285686	6C1A46	1135 841709	ELENA ZAYCEVA	{"email": "e_zayceva121977@postgrespro.ru", "phone": "+70030947274"}
0005433285687	86A57E	2624 404344	YANA SERGEEVA	{"phone": "+70567783451"}
0005433285688	674E09	0558 210361	VLADIMIR PETROV	{"phone": "+70063264227"}
0005433285689	674E09	7821 582128	VALENTINA FADEEVA	{"phone": "+70124624045"}
0005433285690	21828C	3628 493218	YURIY ROMANOV	{"phone": "+70230381778"}
0005433285691	0289DE	3834 435320	PETR SCHERBAKOV	{"phone": "+70372133667"}
0005433285692	0289DE	2821 532069	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr071982@postgrespro.ru", "phone": "+70740860363"}
0005433285693	0289DE	9009 602491	YULIYA ROMANOVA	{"phone": "+70217721462"}
0005433285694	2E8CDF	2746 380070	TATYANA MARTYNOVA	{"email": "martynova.tatyana_1971@postgrespro.ru", "phone": "+70097405015"}
0005433285695	4A27B4	4774 654691	SEMEN KUZNECOV	{"email": "semen-kuznecov-1968@postgrespro.ru", "phone": "+70499506771"}
0005433285696	4A27B4	1217 166835	DMITRIY TARASOV	{"phone": "+70896991197"}
0005433285697	B76C4F	0435 822106	MARIYA MOISEEVA	{"phone": "+70232146222"}
0005433285698	0C3240	6903 319431	ANDREY FEDOROV	{"phone": "+70846854937"}
0005433285699	ECE9EB	9781 191774	VYACHESLAV ROMANOV	{"phone": "+70083879610"}
0005433285700	ECE9EB	4244 828158	VLADIMIR DENISOV	{"email": "v_denisov_11061969@postgrespro.ru", "phone": "+70510688926"}
0005433285701	04A02E	7419 898605	ANDREY GUSEV	{"email": "gusev.andrey-24011970@postgrespro.ru", "phone": "+70981691151"}
0005433285702	04A02E	7441 438208	ILGIZ SMIRNOV	{"phone": "+70015249224"}
0005433285703	17858B	0292 751538	ELENA EGOROVA	{"phone": "+70794562002"}
0005433285704	0AB1F2	6807 786743	NIKOLAY DAVYDOV	{"phone": "+70615285123"}
0005433285705	8F7F95	8100 738127	ARTEM DAVYDOV	{"phone": "+70389826203"}
0005433285706	8F7F95	5841 351969	IVAN DMITRIEV	{"email": "dmitriev-i.101976@postgrespro.ru", "phone": "+70301664893"}
0005433285707	8F7F95	8691 193727	ANDREY CHERNOV	{"phone": "+70219307884"}
0005433285708	62B5A0	5273 827786	VIKTOR SHEVCHENKO	{"phone": "+70831762102"}
0005433285709	62B5A0	2095 988374	VIKTOR CHERNOV	{"phone": "+70577577061"}
0005433285710	8BE40A	6789 510344	MARIYA SMIRNOVA	{"phone": "+70648028360"}
0005433285711	14A95F	9563 397810	MAKSIM ZHURAVLEV	{"email": "zhuravlevmaksim_19061965@postgrespro.ru", "phone": "+70788834961"}
0005433285712	5C3996	4100 789142	ELENA ANDREEVA	{"email": "andreevaelena.12041970@postgrespro.ru", "phone": "+70986722081"}
0005433285713	42DAB3	8394 048199	EVGENIYA MAKSIMOVA	{"email": "maksimova-e.041968@postgrespro.ru", "phone": "+70231487664"}
0005433285714	61623C	1591 531227	OLGA KUZNECOVA	{"email": "okuznecova-1967@postgrespro.ru", "phone": "+70744404114"}
0005433285715	61623C	1417 539524	GALINA KOVALEVA	{"email": "kovaleva.galina.1973@postgrespro.ru", "phone": "+70178502139"}
0005433285716	61623C	3396 274118	PETR POPOV	{"phone": "+70118976549"}
0005433285717	24F019	6109 964547	SERGEY KULIKOV	{"phone": "+70842935726"}
0005433285718	DCD975	6618 635893	SERGEY SMIRNOV	{"email": "smirnovs01021966@postgrespro.ru", "phone": "+70417827707"}
0005433285719	DCD975	4458 268747	VITALIY IVANOV	{"phone": "+70317756033"}
0005433285720	C2EB89	2105 565110	VALERIY ALEKSANDROV	{"email": "valeriyaleksandrov1977@postgrespro.ru", "phone": "+70801181750"}
0005433285721	990642	6184 830304	EVGENIY KRASNOV	{"email": "evgeniy.krasnov.1968@postgrespro.ru", "phone": "+70055164478"}
0005433285722	9844DD	0085 716494	SVETLANA KARPOVA	{"phone": "+70166728101"}
0005433285723	4C4731	8348 967172	NATALYA VASILEVA	{"email": "vasileva.n_031967@postgrespro.ru", "phone": "+70086283073"}
0005433285724	799E42	1259 210647	ANTONINA POLYAKOVA	{"phone": "+70498902841"}
0005433285725	15ACFE	2370 624331	MARIYA NESTEROVA	{"phone": "+70065635487"}
0005433285726	37AA42	3032 387449	KONSTANTIN FOMIN	{"email": "fomink-051961@postgrespro.ru", "phone": "+70893621476"}
0005433285727	48A35B	8291 358513	VALERIY GUSEV	{"phone": "+70138990311"}
0005433285728	EFBDCE	3370 156884	OKSANA LOGINOVA	{"phone": "+70588676607"}
0005433285729	2C9E81	0357 053655	OLGA MAKSIMOVA	{"phone": "+70622552204"}
0005433285730	2B6228	6633 418325	MARIYA ANDREEVA	{"phone": "+70587282498"}
0005433285731	B59B26	9626 547186	EVGENIY PAVLOV	{"email": "pavlov-evgeniy071971@postgrespro.ru", "phone": "+70538872163"}
0005433285732	F74A18	5857 714129	VLADIMIR ISAEV	{"phone": "+70624114107"}
0005433285733	F74A18	6577 556131	NIKOLAY SEMENOV	{"phone": "+70592120258"}
0005433285734	F74A18	0652 808733	LARISA KOZLOVA	{"email": "l-kozlova021979@postgrespro.ru", "phone": "+70508316993"}
0005433285735	B92208	0838 040332	LYUDMILA TIKHONOVA	{"email": "tikhonovalyudmila.081974@postgrespro.ru", "phone": "+70263329632"}
0005433285736	B92208	7971 930933	ALBINA IVANOVA	{"email": "albina-ivanova-1961@postgrespro.ru", "phone": "+70865763854"}
0005433285737	B22FEC	0295 272704	YURIY KUZMIN	{"email": "yuriy-kuzmin-011990@postgrespro.ru", "phone": "+70187472999"}
0005433285738	DE78E3	1184 522540	IGOR FOMIN	{"email": "fomin.igor.17011979@postgrespro.ru", "phone": "+70131223341"}
0005433285739	016061	3219 056163	VLADIMIR MOISEEV	{"email": "moiseevv_1973@postgrespro.ru", "phone": "+70267888053"}
0005433285740	894F8C	3215 421584	LARISA BARANOVA	{"email": "l.baranova.1964@postgrespro.ru", "phone": "+70303720216"}
0005433285741	2E0A06	3996 323562	DANIIL TIKHONOV	{"email": "tikhonov.d_16091970@postgrespro.ru", "phone": "+70574245740"}
0005433285742	2E0A06	5755 681727	ELENA TIMOFEEVA	{"phone": "+70782242998"}
0005433285743	C4B059	8205 069423	ELENA SMIRNOVA	{"email": "smirnova_e-14111985@postgrespro.ru", "phone": "+70279361867"}
0005433285744	35A3A5	2142 245443	IRINA MATVEEVA	{"email": "matveeva_i_021979@postgrespro.ru", "phone": "+70090744099"}
0005433285745	B285F7	3171 368844	EKATERINA RODIONOVA	{"email": "e_rodionova_1971@postgrespro.ru", "phone": "+70333012368"}
0005433285746	129845	1494 744543	NATALYA OVCHINNIKOVA	{"phone": "+70538666950"}
0005433285747	129845	1680 071373	OLGA ZAKHAROVA	{"phone": "+70771185996"}
0005433285748	9EE8F0	1003 754002	YULIYA MELNIKOVA	{"email": "melnikovay-02031970@postgrespro.ru", "phone": "+70339798077"}
0005433285749	F87CE3	2315 833459	NIKOLAY KOZLOV	{"email": "kozlov_nikolay121970@postgrespro.ru", "phone": "+70545590488"}
0005433285750	46A96B	1234 877851	YULIYA LUKYANOVA	{"email": "lukyanova-yuliya-1970@postgrespro.ru", "phone": "+70777235678"}
0005433285751	46A96B	7395 369037	TAMARA NESTEROVA	{"email": "nesterova_t1974@postgrespro.ru", "phone": "+70138188354"}
0005433285752	D236E6	8112 717854	KRISTINA BELYAEVA	{"phone": "+70599200400"}
0005433285753	EECF9F	6146 396883	ANDREY ORLOV	{"email": "orlova_17081968@postgrespro.ru", "phone": "+70048806502"}
0005433285754	DC2A2F	1245 468996	ELENA GORBUNOVA	{"email": "gorbunovae-1979@postgrespro.ru", "phone": "+70018133725"}
0005433285755	E5D457	9180 856239	NIKOLAY KUZNECOV	{"email": "nikolaykuznecov-051965@postgrespro.ru", "phone": "+70322032419"}
0005433285756	8FABD1	0724 342788	TATYANA LAZAREVA	{"email": "t_lazareva_031977@postgrespro.ru", "phone": "+70319992356"}
0005433285757	087A90	1155 212601	REGINA PETROVA	{"email": "r.petrova16031967@postgrespro.ru", "phone": "+70293610255"}
0005433285758	087A90	0726 693997	OLGA OVCHINNIKOVA	{"phone": "+70621871437"}
0005433285759	087A90	6550 098221	NINA TIKHONOVA	{"phone": "+70749679892"}
0005433285760	46382E	3626 363574	SVETLANA SOKOLOVA	{"phone": "+70589050863"}
0005433285761	0282D4	1789 859586	ALEKSANDR IVANOV	{"email": "ivanov.a.11121964@postgrespro.ru", "phone": "+70785937924"}
0005433285762	0282D4	1321 511587	NATALYA MOROZOVA	{"email": "morozova.n_071965@postgrespro.ru", "phone": "+70143621570"}
0005433285763	7388F2	4646 598754	VIKTORIYA SMIRNOVA	{"email": "smirnovav.071963@postgrespro.ru", "phone": "+70885011193"}
0005433285764	3D8F42	6086 653786	ANNA VASILEVA	{"phone": "+70555709164"}
0005433285765	F446A2	2766 313012	LYUBOV BORISOVA	{"phone": "+70289756266"}
0005433285766	F446A2	8549 465786	ALEKSANDR VASILEV	{"phone": "+70562881534"}
0005433285767	DAFD5A	7207 069674	YURIY KARPOV	{"phone": "+70540736950"}
0005433285768	266552	7163 303148	ANNA KULIKOVA	{"phone": "+70118119753"}
0005433285769	520EB8	6458 253551	RAISA RYABOVA	{"phone": "+70746524703"}
0005433285770	520EB8	8767 365198	EVGENIYA LOGINOVA	{"email": "evgeniya-loginova_1965@postgrespro.ru", "phone": "+70249670899"}
0005433285771	B53B41	6067 390719	ANNA TIKHONOVA	{"phone": "+70114286974"}
0005433285772	B4AC9D	7077 090698	VERA VOROBEVA	{"phone": "+70914154333"}
0005433285773	C4B4DF	4728 892639	DMITRIY MOROZOV	{"phone": "+70670378289"}
0005433285774	F93335	8624 989880	VLADIMIR MELNIKOV	{"phone": "+70363470133"}
0005433285775	274E84	8401 613449	VALENTINA BELYAEVA	{"phone": "+70273256768"}
0005433285776	1DDCC0	7485 873881	VIKTOR EGOROV	{"email": "viktor-egorov.1974@postgrespro.ru", "phone": "+70457656244"}
0005433285777	1A9FF2	2247 911733	NADEZHDA ANTONOVA	{"email": "nadezhda.antonova051978@postgrespro.ru", "phone": "+70826114781"}
0005433285778	1A9FF2	3409 583129	DMITRIY MELNIKOV	{"phone": "+70483562120"}
0005433285779	51343D	7914 919597	LIDIYA SOKOLOVA	{"email": "l_sokolova-081975@postgrespro.ru", "phone": "+70484691251"}
0005433285780	A5CAD9	5175 343147	ELENA TARASOVA	{"phone": "+70627105395"}
0005433285781	8502EE	7852 435287	KRISTINA OSIPOVA	{"phone": "+70831788698"}
0005433285782	92B6FC	0323 972977	PETR SIDOROV	{"email": "sidorov.p-26101970@postgrespro.ru", "phone": "+70326597544"}
0005433285783	BF1887	7881 906787	ELIZAVETA SERGEEVA	{"email": "esergeeva.02041971@postgrespro.ru", "phone": "+70435852866"}
0005433285784	6EA100	5032 811394	MARIYA NAZAROVA	{"email": "m-nazarova-031974@postgrespro.ru", "phone": "+70756295850"}
0005433285785	83B144	9770 832153	LYUDMILA GUSEVA	{"email": "lyudmila-guseva_021977@postgrespro.ru", "phone": "+70040020908"}
0005433285786	A44EB2	5553 670338	NIKOLAY KUZNECOV	{"email": "n-kuznecov-06091965@postgrespro.ru", "phone": "+70164022049"}
0005433285787	F7ED01	6453 017695	VLADIMIR STEPANOV	{"email": "stepanov_vladimir121984@postgrespro.ru", "phone": "+70048268104"}
0005433285788	F7ED01	7493 470873	VIKTOR TIKHONOV	{"email": "v-tikhonov-29011971@postgrespro.ru", "phone": "+70916893697"}
0005433285789	AF47D2	9345 735173	TATYANA ZOTOVA	{"phone": "+70080283817"}
0005433285790	AF47D2	1468 110058	KARINA MAKSIMOVA	{"phone": "+70129372527"}
0005433285791	1738DF	2502 418774	OKSANA ANTONOVA	{"email": "oksana_antonova_021965@postgrespro.ru", "phone": "+70502061775"}
0005433285792	9078A3	1820 278881	VIKTOR PETROV	{"phone": "+70811024170"}
0005433285793	E6C2A2	5347 699848	NATALYA TARASOVA	{"phone": "+70552672548"}
0005433285794	E6C2A2	3850 324890	PAVEL FROLOV	{"phone": "+70859025519"}
0005433285795	644CEB	8287 402383	VIKTOR GERASIMOV	{"email": "v-gerasimov.1981@postgrespro.ru", "phone": "+70006645963"}
0005433285796	73F399	9548 661655	ANTONINA AKIMOVA	{"email": "akimovaantonina-081965@postgrespro.ru", "phone": "+70758424487"}
0005433285797	53F4FF	7621 810611	ALEKSANDR ORLOV	{"phone": "+70989900935"}
0005433285798	53F4FF	6618 227974	OLGA MEDVEDEVA	{"phone": "+70758315720"}
0005433285799	53F4FF	7370 758934	PAVEL MELNIKOV	{"email": "p_melnikov_20031977@postgrespro.ru", "phone": "+70170399847"}
0005433285800	3AC929	1608 793300	NURIYA TIKHONOVA	{"email": "nuriya_tikhonova-16041974@postgrespro.ru", "phone": "+70963068046"}
0005433285801	3DF3A4	3451 057621	IVAN KRASNOV	{"email": "krasnov-i1968@postgrespro.ru", "phone": "+70326050524"}
0005433285802	BFB69A	9099 173340	ALEKSANDR NIKITIN	{"email": "anikitin-031974@postgrespro.ru", "phone": "+70019377729"}
0005433285803	0CE498	0841 613126	KONSTANTIN CHERNOV	{"email": "chernov_k1980@postgrespro.ru", "phone": "+70264667634"}
0005433285804	0CE498	4217 835816	ANASTASIYA DAVYDOVA	{"email": "a-davydova.1973@postgrespro.ru", "phone": "+70924158848"}
0005433285805	AA310D	6372 929366	ULYANA BOGDANOVA	{"phone": "+70843201596"}
0005433285806	D1FB78	6723 038014	NINA ZHUKOVA	{"email": "zhukova_n-071973@postgrespro.ru", "phone": "+70557781009"}
0005433285807	D1FB78	9705 531106	LYUDMILA POPOVA	{"phone": "+70369404550"}
0005433285808	67577C	7974 138723	VITALIY ILIN	{"email": "ilin_v1970@postgrespro.ru", "phone": "+70099352290"}
0005433285809	44E127	3332 139456	ANASTASIYA TARASOVA	{"phone": "+70806666695"}
0005433285810	09DFDA	1995 682169	ANTONINA KALININA	{"email": "antoninakalinina.25021983@postgrespro.ru", "phone": "+70965128604"}
0005433285811	09DFDA	9589 527585	VITALIY VLASOV	{"phone": "+70331042975"}
0005433285812	09DFDA	9701 605951	NATALYA OSIPOVA	{"phone": "+70420482154"}
0005433285813	F81D43	0573 943410	ANNA FROLOVA	{"phone": "+70021921770"}
0005433285814	F81D43	4142 107597	MARIYA MAKAROVA	{"phone": "+70595416997"}
0005433285815	CD96F3	1865 894536	SERGEY FOMIN	{"phone": "+70321202936"}
0005433285816	CD96F3	1231 870734	VALERIYA NESTEROVA	{"phone": "+70611752811"}
0005433285817	00ECAB	0557 755439	LYUDMILA KUZNECOVA	{"email": "lyudmila-kuznecova.03061980@postgrespro.ru", "phone": "+70759737998"}
0005433285818	C949E2	4280 854496	VYACHESLAV GUSEV	{"email": "v-gusev_04121979@postgrespro.ru", "phone": "+70436930097"}
0005433285819	D8477F	9371 702107	SERGEY IVANOV	{"phone": "+70645711754"}
0005433285820	D8477F	4947 818264	ANDREY ZHUKOV	{"phone": "+70297084529"}
0005433285821	FAA549	5397 914930	ANNA SEMENOVA	{"email": "semenovaa1972@postgrespro.ru", "phone": "+70575041232"}
0005433285822	D3220E	0095 797867	ILMIRA KUZMINA	{"email": "ilmira_kuzmina_061974@postgrespro.ru", "phone": "+70081216322"}
0005433285823	81A07B	6695 657067	ANASTASIYA SMIRNOVA	{"email": "smirnova.a_08121975@postgrespro.ru", "phone": "+70549387181"}
0005433285824	9A93A1	6362 665636	KIRILL SIDOROV	{"email": "kirill.sidorov081971@postgrespro.ru", "phone": "+70652224037"}
0005433285825	897667	5853 452145	VIKTOR KUZNECOV	{"phone": "+70561751967"}
0005433285826	34CE20	0073 018862	TAMARA VASILEVA	{"email": "tamaravasileva.101974@postgrespro.ru", "phone": "+70502193828"}
0005433285827	27AC0B	8204 412944	DMITRIY DENISOV	{"email": "denisov-dmitriy-1975@postgrespro.ru", "phone": "+70783561095"}
0005433285828	82C0EE	0149 558032	VIKTOR EGOROV	{"email": "v-egorov.1978@postgrespro.ru", "phone": "+70559994202"}
0005433285829	82C0EE	3253 288931	LYUDMILA PETROVA	{"phone": "+70423734369"}
0005433285830	0EE8DA	3159 765215	VALENTINA NIKOLAEVA	{"phone": "+70964194255"}
0005433285831	0EE8DA	5880 567969	IGOR KUDRYASHOV	{"email": "kudryashov.i-1970@postgrespro.ru", "phone": "+70103538093"}
0005433285832	48EA08	0078 501817	ANNA ZHUKOVA	{"email": "zhukova.anna-12111975@postgrespro.ru", "phone": "+70689785543"}
0005433285833	8E8CED	5951 062014	ZINAIDA SOLOVEVA	{"phone": "+70472660168"}
0005433285834	C51CA2	0184 633034	ANNA ANTONOVA	{"email": "a_antonova-1973@postgrespro.ru", "phone": "+70368941834"}
0005433285835	FC73F7	9687 582409	YULIYA MIRONOVA	{"email": "mironova.yuliya-12031967@postgrespro.ru", "phone": "+70316323211"}
0005433285836	853ABC	9039 865687	IGOR POPOV	{"email": "i-popov021973@postgrespro.ru", "phone": "+70228978510"}
0005433285837	853ABC	9466 203533	LYUDMILA MIKHAYLOVA	{"email": "lyudmila.mikhaylova_1977@postgrespro.ru", "phone": "+70399754913"}
0005433285838	C7B634	8875 043050	ANNA NIKIFOROVA	{"phone": "+70104887370"}
0005433285839	C7B634	6552 009625	ZHANNA ZHURAVLEVA	{"phone": "+70640324558"}
0005433285840	A1B1A6	0321 725279	DENIS NIKITIN	{"phone": "+70435909790"}
0005433285841	3A097B	4466 702320	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr-1969@postgrespro.ru", "phone": "+70348785221"}
0005433285842	4800AD	3342 623103	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr.14051979@postgrespro.ru", "phone": "+70015208190"}
0005433285843	4C4878	9208 839934	ANATOLIY AFANASEV	{"phone": "+70568505495"}
0005433285844	E0D4F6	4857 720418	YURIY ZAYCEV	{"email": "zaycev-y.1963@postgrespro.ru", "phone": "+70631021232"}
0005433285845	E0D4F6	6705 513324	ANNA SMIRNOVA	{"email": "anna.smirnova_07091965@postgrespro.ru", "phone": "+70673592763"}
0005433285846	E0D4F6	0008 666435	IGOR KONOVALOV	{"phone": "+70703732778"}
0005433285847	D5B4EE	4914 604395	EKATERINA KUZNECOVA	{"phone": "+70496083982"}
0005433285848	DFB2D8	4741 535248	ELENA KOZLOVA	{"phone": "+70574613595"}
0005433285849	45B405	8252 892905	ANATOLIY NAZAROV	{"phone": "+70890969341"}
0005433285850	F4F4D0	4041 518854	DARYA KOZLOVA	{"email": "kozlova_d-021957@postgrespro.ru", "phone": "+70027523406"}
0005433285851	D043F4	2415 264332	ELENA ZOTOVA	{"email": "elenazotova17121971@postgrespro.ru", "phone": "+70625888682"}
0005433285852	DADDDD	0624 212252	ALEKSEY ALEKSEEV	{"email": "alekseev.a.1972@postgrespro.ru", "phone": "+70450617121"}
0005433285853	547DF7	6761 067707	DMITRIY IVANOV	{"phone": "+70915891337"}
0005433285854	547DF7	5955 342990	ALEKSANDR BELOV	{"email": "aleksandr.belov-101972@postgrespro.ru", "phone": "+70408447186"}
0005433285855	619C23	6336 555467	IVAN PETROV	{"phone": "+70904511562"}
0005433285856	2ABBE1	6514 819106	PAVEL ALEKSEEV	{"phone": "+70314872122"}
0005433285857	589FB6	3669 385115	SVETLANA CHERNOVA	{"email": "s_chernova_111968@postgrespro.ru", "phone": "+70778423849"}
0005433285858	F0EAA6	2231 382560	TAMARA MOROZOVA	{"phone": "+70736013883"}
0005433285859	CD18A4	0404 587854	SERGEY SAVELEV	{"phone": "+70226001674"}
0005433285860	DB22BD	4044 132313	NATALYA ZAYCEVA	{"email": "nzayceva-1965@postgrespro.ru", "phone": "+70403737343"}
0005433285861	FB22BE	1867 836144	TATYANA IVANOVA	{"email": "ivanova-tatyana_1967@postgrespro.ru", "phone": "+70231330786"}
0005433285862	C15925	0524 888658	IRINA DMITRIEVA	{"phone": "+70829770641"}
0005433285863	C15925	3411 572811	NATALIYA TARASOVA	{"email": "ntarasova_061973@postgrespro.ru", "phone": "+70393423498"}
0005433285864	0A8F3E	5147 294770	VYACHESLAV KUZMIN	{"phone": "+70317727504"}
0005433285865	6AF053	5133 458875	ALEKSEY KAZAKOV	{"email": "kazakova19101969@postgrespro.ru", "phone": "+70950008006"}
0005433285866	3D8358	8314 221980	VASILIY STEPANOV	{"phone": "+70589525623"}
0005433285867	3D8358	0024 539508	VIOLETTA EGOROVA	{"phone": "+70854356393"}
0005433285868	5DC6E0	7522 544037	ELENA KUZNECOVA	{"phone": "+70577291688"}
0005433285869	5DC6E0	5669 004983	OLEG FEDOROV	{"email": "fedorov_o_13091969@postgrespro.ru", "phone": "+70179263232"}
0005433285870	53DC3A	7407 331636	EVGENIY GAVRILOV	{"email": "evgeniy-gavrilov.111978@postgrespro.ru", "phone": "+70168849894"}
0005433285871	53DC3A	4262 973464	ALEKSEY SOROKIN	{"email": "sorokin_aleksey111977@postgrespro.ru", "phone": "+70408911854"}
0005433285872	53DC3A	1948 346472	TATYANA MATVEEVA	{"phone": "+70601244856"}
0005433285873	C8224C	6449 597894	NADEZHDA DAVYDOVA	{"phone": "+70806303921"}
0005433285874	1A47AC	7750 554125	LYUDMILA IVANOVA	{"phone": "+70131457440"}
0005433285875	07E5F8	6159 698001	NATALYA MIRONOVA	{"email": "natalya.mironova-04101972@postgrespro.ru", "phone": "+70503893269"}
0005433285876	913627	8389 310015	ALEKSANDR ZAKHAROV	{"email": "azakharov.29091974@postgrespro.ru", "phone": "+70070499036"}
0005433285877	EFE922	1902 634530	VALERIY EGOROV	{"email": "egorov.v-1972@postgrespro.ru", "phone": "+70018715865"}
0005433285878	223C95	9162 047550	PRASKOVYA VASILEVA	{"email": "praskovya-vasileva05121955@postgrespro.ru", "phone": "+70201065571"}
0005433285879	F536FA	7192 464885	YULIYA ZAKHAROVA	{"email": "yzakharova.1967@postgrespro.ru", "phone": "+70274073795"}
0005433285880	7936D7	5162 381891	ALEKSANDR MELNIKOV	{"phone": "+70968362505"}
0005433285881	7936D7	4943 004725	SERGEY RODIONOV	{"email": "rodionov_s-011973@postgrespro.ru", "phone": "+70153106966"}
0005433285882	67FC97	3433 823151	NIKITA SOROKIN	{"phone": "+70301697167"}
0005433285883	DD9942	3515 395377	ANATOLIY SOLOVEV	{"phone": "+70905516952"}
0005433285884	DD9942	9327 816038	TATYANA SOLOVEVA	{"phone": "+70294282130"}
0005433285885	4E2A25	5357 399253	MAKSIM MIRONOV	{"phone": "+70056559443"}
0005433285886	499FE8	0625 075339	SERGEY SIDOROV	{"phone": "+70727839945"}
0005433285887	4BFAE9	4274 649875	ELENA IVANOVA	{"email": "eivanova.071969@postgrespro.ru", "phone": "+70711927835"}
0005433285888	169F01	0426 020137	IRINA GRISHINA	{"email": "grishinairina_1964@postgrespro.ru", "phone": "+70503277391"}
0005433285889	F07F47	5199 509810	ALEKSANDR NAUMOV	{"email": "naumov_aleksandr1976@postgrespro.ru", "phone": "+70978928728"}
0005433285890	95DD83	8366 617356	SERGEY MOROZOV	{"phone": "+70618918585"}
0005433285891	AA2E0C	1489 791356	OLESYA GERASIMOVA	{"email": "o-gerasimova-071974@postgrespro.ru", "phone": "+70986798499"}
0005433285892	11CE17	3536 383128	ALEKSEY KUZMIN	{"email": "kuzmin_a1970@postgrespro.ru", "phone": "+70594831205"}
0005433285893	11CE17	6696 160047	ALEKSANDR IVANOV	{"phone": "+70019609983"}
0005433285894	11CE17	3632 647935	SERGEY IVANOV	{"phone": "+70792465154"}
0005433285895	58CC64	3757 235789	ALEKSEY CHERNOV	{"email": "chernovaleksey_031977@postgrespro.ru", "phone": "+70629001435"}
0005433285896	ED7A82	0476 436138	LYUBOV LEBEDEVA	{"email": "lebedevalyubov_1978@postgrespro.ru", "phone": "+70438805193"}
0005433285897	238A66	2747 121578	RAISA KONOVALOVA	{"email": "konovalova.r_1981@postgrespro.ru", "phone": "+70748198330"}
0005433285898	7D7155	0829 753430	MIKHAIL EGOROV	{"email": "megorov.1968@postgrespro.ru", "phone": "+70951299494"}
0005433285899	7D7155	5781 122070	RAFAEL FROLOV	{"phone": "+70740873039"}
0005433285900	5FCE05	6041 560494	GAGIK STEPANOV	{"phone": "+70437918000"}
0005433285901	FC8EA7	2381 519632	TATYANA ERMAKOVA	{"phone": "+70168504703"}
0005433285902	DC8828	9043 085428	LYUBOV FROLOVA	{"phone": "+70344474639"}
0005433285903	DC8828	1423 885661	VASILIY KAZAKOV	{"phone": "+70287022724"}
0005433285904	04E79D	8979 540464	VERA KONOVALOVA	{"email": "v_konovalova.1975@postgrespro.ru", "phone": "+70065374212"}
0005433285905	2D09AC	0242 944135	EVGENIY NIKOLAEV	{"phone": "+70248996392"}
0005433285906	2D09AC	5447 968324	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova1965@postgrespro.ru", "phone": "+70423166458"}
0005433285907	9D1A0F	2373 502100	KAMILLA IVANOVA	{"email": "ivanova_kamilla16051975@postgrespro.ru", "phone": "+70607539002"}
0005433285908	3D6C88	9641 063421	NIKITA STEPANOV	{"email": "nikita.stepanov.011973@postgrespro.ru", "phone": "+70516342594"}
0005433285909	CC993F	0413 263997	OKSANA VLASOVA	{"phone": "+70028458158"}
0005433285910	CC993F	7021 366963	VIKTOR ZAKHAROV	{"email": "viktorzakharov1976@postgrespro.ru", "phone": "+70493486871"}
0005433285911	9DCC1F	0544 637348	VADIM KOZLOV	{"email": "vadimkozlov121976@postgrespro.ru", "phone": "+70603200939"}
0005433285912	74E7D7	0590 909525	IRINA KUZMINA	{"phone": "+70201443880"}
0005433285913	74E7D7	9751 946362	NATALYA CHERNOVA	{"email": "chernova_natalya20041977@postgrespro.ru", "phone": "+70345954088"}
0005433285914	3DD094	5691 505305	PETR YAKOVLEV	{"phone": "+70443627077"}
0005433285915	C9263B	5183 079739	YURIY KUZNECOV	{"email": "kuznecov_yuriy_1977@postgrespro.ru", "phone": "+70108234033"}
0005433285916	C9263B	6924 059625	VALERIY POPOV	{"email": "popov.v061969@postgrespro.ru", "phone": "+70321479956"}
0005433285917	AEE574	0675 571872	NINA RODIONOVA	{"email": "rodionova.nina.101974@postgrespro.ru", "phone": "+70055744103"}
0005433285918	69823A	1858 613065	ELENA NIKIFOROVA	{"email": "elena-nikiforova26121958@postgrespro.ru", "phone": "+70922424721"}
0005433285919	69823A	1378 494700	TATYANA MELNIKOVA	{"phone": "+70420033475"}
0005433285920	416638	1633 499921	TAMARA MIRONOVA	{"phone": "+70494072849"}
0005433285921	416638	7638 678583	ANATOLIY TIMOFEEV	{"phone": "+70878764024"}
0005433285922	F1A14E	2852 026125	SVETLANA KOZLOVA	{"email": "svetlanakozlova-17091981@postgrespro.ru", "phone": "+70458265746"}
0005433285923	F1A14E	8605 867373	GALINA OSIPOVA	{"email": "osipovag.12031970@postgrespro.ru", "phone": "+70831995448"}
0005433285924	1B0197	4093 250616	SVETLANA ZAYCEVA	{"email": "zayceva.s.17081978@postgrespro.ru", "phone": "+70961449511"}
0005433285925	1B0197	6156 131333	ALEKSEY NIKOLAEV	{"email": "aleksey.nikolaev1966@postgrespro.ru", "phone": "+70065826050"}
0005433285926	F5D354	4490 136623	ANDREY SAVELEV	{"phone": "+70969742265"}
0005433285927	34D380	2643 888960	NATALIYA DENISOVA	{"phone": "+70140199260"}
0005433285928	84527D	2367 042864	STANISLAV KONOVALOV	{"phone": "+70802190596"}
0005433285929	05F82A	0927 863986	RIFAT MAKAROV	{"email": "makarovrifat1975@postgrespro.ru", "phone": "+70703009069"}
0005433285930	05F82A	1882 489040	LILIYA KONOVALOVA	{"email": "liliya_konovalova.071975@postgrespro.ru", "phone": "+70263756534"}
0005433285931	05F82A	4711 635075	ALEKSANDR ISAEV	{"email": "aleksandrisaev-051974@postgrespro.ru", "phone": "+70546737977"}
0005433285932	27A53B	8730 184604	ANDREY SOKOLOV	{"phone": "+70998341729"}
0005433285933	27A53B	0509 061527	ALEKSANDR PETROV	{"email": "petrov.aleksandr.1976@postgrespro.ru", "phone": "+70380896946"}
0005433285934	27A53B	6419 302107	YANA EFIMOVA	{"phone": "+70807163167"}
0005433285935	F8760D	5602 201083	VLADIMIR BORISOV	{"phone": "+70316512759"}
0005433285936	9743E0	1654 941379	SVETLANA OSIPOVA	{"phone": "+70704392799"}
0005433285937	11E756	8635 119489	MARIYA NAUMOVA	{"email": "naumova-mariya_02021983@postgrespro.ru", "phone": "+70474051040"}
0005433285938	FB14DF	2396 181977	ZOYA IVANOVA	{"email": "zivanova_27071969@postgrespro.ru", "phone": "+70087530314"}
0005433285939	BDDF0D	0556 885356	ILNAR STEPANOV	{"email": "istepanov_1975@postgrespro.ru", "phone": "+70024858838"}
0005433285940	BDDF0D	0442 948958	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov_20101977@postgrespro.ru", "phone": "+70707256855"}
0005433285941	B64154	5079 296352	VIKTOR FEDOTOV	{"phone": "+70245143870"}
0005433285942	9996D9	8925 518155	IGOR MOROZOV	{"phone": "+70799103394"}
0005433285943	E0C1F1	8381 978102	LARISA NESTEROVA	{"email": "l.nesterova.1965@postgrespro.ru", "phone": "+70187330465"}
0005433285944	980572	5646 864024	NIKOLAY SOROKIN	{"email": "nikolay.sorokin_1968@postgrespro.ru", "phone": "+70007949557"}
0005433285945	17CE7C	3063 420737	OLGA CHERNOVA	{"email": "chernovao_101969@postgrespro.ru", "phone": "+70580366077"}
0005433285946	1AF088	2465 046279	VYACHESLAV NAZAROV	{"phone": "+70483049241"}
0005433285947	F481A9	8221 414213	VALERIY CHERNOV	{"email": "v-chernov19041980@postgrespro.ru", "phone": "+70009476465"}
0005433285948	B7881C	5123 959927	NINA MOROZOVA	{"phone": "+70981595739"}
0005433285949	9B6032	8031 765122	NIKITA SOKOLOV	{"email": "nikita.sokolov_01031973@postgrespro.ru", "phone": "+70935661810"}
0005433285950	9B6032	3456 818094	ANNA BARANOVA	{"email": "baranova.anna061975@postgrespro.ru", "phone": "+70603718867"}
0005433285951	7C1B32	7743 694304	MARINA MIRONOVA	{"email": "mironova.marina-01071971@postgrespro.ru", "phone": "+70922824856"}
0005433285952	12A95A	0071 287447	VLADIMIR POPOV	{"phone": "+70485855440"}
0005433285953	12A95A	9435 407104	ELIZAVETA SCHERBAKOVA	{"phone": "+70259467124"}
0005433285954	7FFFB5	9042 600977	GENNADIY FEDOTOV	{"email": "g_fedotov1971@postgrespro.ru", "phone": "+70740885839"}
0005433285955	484D3B	4600 929515	TATYANA TIKHONOVA	{"phone": "+70895698244"}
0005433285956	70A01B	9159 546260	NIKOLAY MIKHAYLOV	{"phone": "+70970938185"}
0005433285957	70A01B	8715 893065	OLGA MAKAROVA	{"email": "makarovao021965@postgrespro.ru", "phone": "+70858128320"}
0005433285958	AC69D3	9375 810387	NADEZHDA SMIRNOVA	{"email": "nadezhda-smirnova.29101980@postgrespro.ru", "phone": "+70121574680"}
0005433285959	9FEDBB	0352 381431	DMITRIY AFANASEV	{"email": "dmitriyafanasev.1956@postgrespro.ru", "phone": "+70504649369"}
0005433285960	87E79E	6473 439260	ANATOLIY SOKOLOV	{"email": "sokolov-anatoliy-1958@postgrespro.ru", "phone": "+70505182741"}
0005433285961	3A261D	6540 043062	ARTUR FOMIN	{"phone": "+70005787692"}
0005433285962	65EAB6	6308 123557	SERGEY GRIGOREV	{"email": "grigorev_s_1981@postgrespro.ru", "phone": "+70636112800"}
0005433285963	B75EF7	7159 688565	KSENIYA BORISOVA	{"phone": "+70103702670"}
0005433285964	B75EF7	5102 075453	DENIS PETROV	{"phone": "+70464889281"}
0005433285965	03C8A2	2575 339616	ANASTASIYA MOROZOVA	{"phone": "+70746365663"}
0005433285966	5317C1	1789 812152	ELENA MIRONOVA	{"email": "mironova.elena_101968@postgrespro.ru", "phone": "+70786042495"}
0005433285967	269158	1535 980582	NAIL IVANOV	{"phone": "+70716719533"}
0005433285968	157E48	2202 937773	TATYANA ABRAMOVA	{"phone": "+70443672918"}
0005433285969	768E75	3698 918811	ROMAN KUZNECOV	{"email": "roman.kuznecov.101966@postgrespro.ru", "phone": "+70818389327"}
0005433285970	37FD98	4239 997120	ALENA ISAEVA	{"email": "isaeva-a-1976@postgrespro.ru", "phone": "+70938668941"}
0005433285971	37FD98	8272 813205	LIDIYA IVANOVA	{"email": "ivanova_l_1966@postgrespro.ru", "phone": "+70441221186"}
0005433285972	AA153F	9045 512831	ALEKSANDR POPOV	{"email": "popov_a-011966@postgrespro.ru", "phone": "+70693712007"}
0005433285973	AA153F	5121 856693	EKATERINA PETROVA	{"email": "petrova-ekaterina_06101974@postgrespro.ru", "phone": "+70550568220"}
0005433285974	5AEAFF	9230 080463	DMITRIY AFANASEV	{"email": "afanasev.d-13041969@postgrespro.ru", "phone": "+70979692028"}
0005433285975	7F0C09	2089 039860	IGOR MARTYNOV	{"email": "igor.martynov-021973@postgrespro.ru", "phone": "+70501580219"}
0005433285976	0775F4	9026 348552	NADEZHDA IVANOVA	{"phone": "+70044109475"}
0005433285977	0775F4	7109 412582	DMITRIY TARASOV	{"email": "tarasovd-01041974@postgrespro.ru", "phone": "+70392506757"}
0005433285978	FE3314	0896 041925	ALEKSEY PAVLOV	{"phone": "+70950327628"}
0005433285979	624BD1	5517 040412	ALEKSANDR DENISOV	{"email": "denisov_aleksandr-20021967@postgrespro.ru", "phone": "+70154713225"}
0005433285980	624BD1	8826 686266	LIDIYA LAZAREVA	{"phone": "+70861008951"}
0005433285981	624BD1	4030 272407	ROMAN GAVRILOV	{"phone": "+70806236049"}
0005433285982	CE451E	7442 273422	ELENA STEPANOVA	{"email": "stepanova-e_121963@postgrespro.ru", "phone": "+70757200346"}
0005433285983	1DEC2D	9922 791219	IRINA ALEKSEEVA	{"email": "alekseeva.i.24071985@postgrespro.ru", "phone": "+70957505164"}
0005433285984	E993B7	8772 865770	SERGEY NIKITIN	{"phone": "+70676161557"}
0005433285985	E993B7	6208 377461	TATYANA IVANOVA	{"phone": "+70761714298"}
0005433285986	49A340	2481 373694	VYACHESLAV NIKITIN	{"email": "nikitin-vyacheslav.061978@postgrespro.ru", "phone": "+70508669766"}
0005433285987	49A340	2029 366837	ELENA ZAKHAROVA	{"phone": "+70304306477"}
0005433285988	EA0E6E	8741 637536	VLADIMIR SOROKIN	{"phone": "+70721614857"}
0005433285989	11553E	1015 385862	VALENTINA YAKOVLEVA	{"phone": "+70930619800"}
0005433285990	11553E	7975 365798	GALINA KISELEVA	{"email": "kiseleva-g011967@postgrespro.ru", "phone": "+70169328564"}
0005433285991	E3AC8F	3218 291273	NATALYA NESTEROVA	{"email": "natalyanesterova.081975@postgrespro.ru", "phone": "+70952868680"}
0005433285992	622DF8	4387 821594	STEPAN KISELEV	{"phone": "+70283553831"}
0005433285993	9C4F0B	5886 805337	VLADIMIR FROLOV	{"email": "frolovvladimir.1969@postgrespro.ru", "phone": "+70519688069"}
0005433285994	83B96E	1962 011631	MARIYA VOLKOVA	{"phone": "+70096977515"}
0005433285995	93BBEC	2664 604057	OLGA POLYAKOVA	{"phone": "+70891078676"}
0005433285996	B967DE	3699 201119	VALENTINA ORLOVA	{"phone": "+70476501895"}
0005433285997	3EE8B4	5035 395742	MARIYA VOROBEVA	{"email": "m.vorobeva-071973@postgrespro.ru", "phone": "+70504396900"}
0005433285998	A91FDD	0034 450141	EKATERINA NAZAROVA	{"phone": "+70797733859"}
0005433285999	1068B5	5925 126786	KSENIYA TARASOVA	{"email": "k-tarasova.1981@postgrespro.ru", "phone": "+70733563865"}
0005433286000	33E90B	1789 604189	PETR MOROZOV	{"phone": "+70071997114"}
0005433286001	A1B16B	9145 350997	SERGEY FOMIN	{"email": "fomin_s_15071979@postgrespro.ru", "phone": "+70993900963"}
0005433286002	A1B16B	8675 290947	SERGEY KUZMIN	{"email": "kuzmin.sergey_30011978@postgrespro.ru", "phone": "+70680767614"}
0005433286003	253CF4	7410 728053	ZHANNA VOLKOVA	{"email": "z-volkova.1965@postgrespro.ru", "phone": "+70053513545"}
0005433286004	253CF4	0051 354301	MARGARITA NESTEROVA	{"phone": "+70451861632"}
0005433286005	0C4809	8271 703002	MARYAM VOLKOVA	{"phone": "+70920337249"}
0005433286006	D0EF21	4766 971289	ARTEM VASILEV	{"phone": "+70494012025"}
0005433286007	D0EF21	9460 442474	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov.071972@postgrespro.ru", "phone": "+70739847080"}
0005433286008	55D1CA	1099 843383	DMITRIY MAKAROV	{"phone": "+70992563418"}
0005433286009	E6EB10	0939 448691	ALEKSANDR BONDARENKO	{"email": "bondarenkoaleksandr.091964@postgrespro.ru", "phone": "+70854892957"}
0005433286010	E6EB10	5312 780843	VLADIMIR POPOV	{"email": "v-popov_051974@postgrespro.ru", "phone": "+70915841507"}
0005433286011	D92C98	5638 056088	OLGA POTAPOVA	{"email": "potapovao-091970@postgrespro.ru", "phone": "+70839515542"}
0005433286012	55CC29	8729 379520	ALEKSANDR BARANOV	{"email": "baranov.a_22031976@postgrespro.ru", "phone": "+70485129803"}
0005433286013	55CC29	3060 739715	YURIY TIKHONOV	{"email": "tikhonov-yuriy.051974@postgrespro.ru", "phone": "+70025188934"}
0005433286014	CEA65F	0178 850921	ALEKSANDR SOROKIN	{"email": "sorokin.a_19121961@postgrespro.ru", "phone": "+70974447128"}
0005433286015	41ECF2	4619 711453	SEMEN VOLKOV	{"phone": "+70173668162"}
0005433286016	6B5670	3546 816876	OLGA KONOVALOVA	{"email": "olga.konovalova1967@postgrespro.ru", "phone": "+70373368877"}
0005433286017	B123D8	1703 404349	RUSLAN ZHUKOV	{"email": "zhukov.r121975@postgrespro.ru", "phone": "+70687727954"}
0005433286018	B123D8	0036 227358	OKSANA STEPANOVA	{"phone": "+70876188815"}
0005433286019	D19414	2960 305436	IRINA PETROVA	{"email": "i-petrova-031982@postgrespro.ru", "phone": "+70326097835"}
0005433286020	D19414	5225 766017	MARGARITA ROMANOVA	{"email": "romanovamargarita.06061968@postgrespro.ru", "phone": "+70279403007"}
0005433286021	321071	8284 494811	LIDIYA DANILOVA	{"email": "lidiya-danilova-18011976@postgrespro.ru", "phone": "+70196422946"}
0005433286022	F6F2D9	5445 800191	ANDREY NIKITIN	{"email": "nikitin.andrey07101976@postgrespro.ru", "phone": "+70278554511"}
0005433286023	3A2226	0193 622931	VLADIMIR BONDARENKO	{"email": "vladimir_bondarenko-14111955@postgrespro.ru", "phone": "+70683327494"}
0005433286024	A0BF60	1530 272617	INESSA KOLESNIKOVA	{"phone": "+70017549370"}
0005433286025	D30DCD	4480 908983	ALBINA EGOROVA	{"email": "a.egorova_1980@postgrespro.ru", "phone": "+70160222414"}
0005433286026	D30DCD	5310 096188	YULIYA KOLESNIKOVA	{"phone": "+70708699313"}
0005433286027	82FC84	7801 012100	SERGEY TARASOV	{"phone": "+70941831731"}
0005433286028	DD4199	6867 214566	ULYANA BELYAEVA	{"phone": "+70076191126"}
0005433286029	C512F2	8774 885229	NINA VOLKOVA	{"email": "volkova.n-091987@postgrespro.ru", "phone": "+70999860614"}
0005433286030	C512F2	3174 422986	NIKOLAY VOROBEV	{"email": "nikolayvorobev-031955@postgrespro.ru", "phone": "+70807575792"}
0005433286031	D83FD0	2620 037228	VIKTORIYA KONOVALOVA	{"phone": "+70350853817"}
0005433286032	D83FD0	4233 479952	MARIYA SMIRNOVA	{"email": "smirnova-m.101969@postgrespro.ru", "phone": "+70243377707"}
0005433286033	A0F6CE	6106 354117	VALENTIN OSIPOV	{"email": "v-osipov-22071977@postgrespro.ru", "phone": "+70974789804"}
0005433286034	337A61	1301 860665	ALEKSEY EGOROV	{"phone": "+70439559245"}
0005433286035	90EE1E	6428 155133	OLGA STEPANOVA	{"email": "olga-stepanova.041965@postgrespro.ru", "phone": "+70560293349"}
0005433286036	90EE1E	4784 118511	ANNA ANDREEVA	{"phone": "+70321957857"}
0005433286037	90EE1E	3569 202256	OLGA YAKOVLEVA	{"email": "oyakovleva09041982@postgrespro.ru", "phone": "+70531035558"}
0005433286038	7C855B	9183 019254	MIKHAIL MIKHAYLOV	{"phone": "+70895431466"}
0005433286039	7C855B	7125 380199	NATALIYA DMITRIEVA	{"email": "dmitrieva.n.051970@postgrespro.ru", "phone": "+70885945806"}
0005433286040	8DBC05	6412 400776	STEPAN SOROKIN	{"phone": "+70850099876"}
0005433286041	A598EF	6647 304460	PETR KULIKOV	{"email": "kulikov.petr-041963@postgrespro.ru", "phone": "+70058344003"}
0005433286042	660349	9132 141144	DMITRIY MAKAROV	{"email": "dmitriy.makarov.02111970@postgrespro.ru", "phone": "+70645674421"}
0005433286043	002ACE	7227 998401	NADEZHDA KAZAKOVA	{"email": "kazakova_nadezhda.1970@postgrespro.ru", "phone": "+70001063476"}
0005433286044	23260B	1433 034356	NATALYA CHERNOVA	{"email": "chernova-natalya-031985@postgrespro.ru", "phone": "+70124555883"}
0005433286045	885BF7	0564 839522	ANDREY KUZNECOV	{"email": "kuznecov.andrey1975@postgrespro.ru", "phone": "+70115690586"}
0005433286046	B48A67	7887 928676	SOFIYA ABRAMOVA	{"phone": "+70781817685"}
0005433286047	59B13C	3882 203328	VALENTINA MAKAROVA	{"phone": "+70501603851"}
0005433286048	EDBB3E	9127 017189	YULIYA GRISHINA	{"phone": "+70866863970"}
0005433286049	EDBB3E	0741 272353	ALEKSANDR SHEVCHENKO	{"phone": "+70056941839"}
0005433286050	4D0347	1542 730184	MIKHAIL KUZNECOV	{"phone": "+70008353000"}
0005433286051	87B140	9042 309114	DMITRIY PETROV	{"email": "petrovd.1978@postgrespro.ru", "phone": "+70255467464"}
0005433286052	87B140	3671 404928	TAMARA POPOVA	{"phone": "+70568447879"}
0005433286053	E55900	1645 869433	NINA LUKYANOVA	{"phone": "+70309467624"}
0005433286054	7860BA	3150 882687	TATYANA KRASNOVA	{"phone": "+70826738351"}
0005433286055	7860BA	2080 203282	ANDREY MIRONOV	{"email": "mironova.08021992@postgrespro.ru", "phone": "+70831438879"}
0005433286056	39FE55	9217 648726	DENIS EGOROV	{"phone": "+70523140684"}
0005433286057	12F328	4422 125097	NIKOLAY KAZAKOV	{"email": "kazakov.nikolay.031968@postgrespro.ru", "phone": "+70217723090"}
0005433286058	BAA55C	0685 620246	LEONTIY SHEVCHENKO	{"phone": "+70671043846"}
0005433286059	835BFA	2639 894510	VLADIMIR EGOROV	{"phone": "+70951429990"}
0005433286060	835BFA	1908 440389	MATVEY GRIGOREV	{"email": "grigorev-matvey_051977@postgrespro.ru", "phone": "+70948682415"}
0005433286061	F84330	4827 647169	DMITRIY TIKHONOV	{"email": "d-tikhonov.071965@postgrespro.ru", "phone": "+70964707921"}
0005433286062	EB1ACF	0881 017564	VLADIMIR AFANASEV	{"phone": "+70827415167"}
0005433286063	596652	5068 476590	ZINAIDA PETROVA	{"phone": "+70137647318"}
0005433286064	1B0D9D	8523 926638	TATYANA FEDOROVA	{"phone": "+70764685956"}
0005433286065	37F971	2048 282851	ANATOLIY GRIGOREV	{"email": "grigorevanatoliy.061961@postgrespro.ru", "phone": "+70905762598"}
0005433286066	37F971	1930 500816	ELENA KUZNECOVA	{"phone": "+70262858913"}
0005433286067	0CEF1A	3433 688534	NIKOLAY SAVELEV	{"email": "nsavelev_1982@postgrespro.ru", "phone": "+70793358211"}
0005433286068	1A3D17	8053 719952	ALEKSANDR ZAKHAROV	{"email": "zakharov-a-08111975@postgrespro.ru", "phone": "+70411420273"}
0005433286069	1A3D17	8776 411441	NATALYA GERASIMOVA	{"phone": "+70815348761"}
0005433286070	8111C4	2820 501676	VLADA VASILEVA	{"email": "vlada-vasileva-19111979@postgrespro.ru", "phone": "+70358401841"}
0005433286071	48E38D	4225 494587	NATALYA NOVIKOVA	{"email": "natalya.novikova.1969@postgrespro.ru", "phone": "+70199376125"}
0005433286072	26CFBF	6098 606020	SERGEY NIKITIN	{"email": "sergeynikitin-1975@postgrespro.ru", "phone": "+70055327184"}
0005433286073	F9B8D4	0083 479395	ARTUR SIDOROV	{"email": "artur.sidorov-1965@postgrespro.ru", "phone": "+70724931620"}
0005433286074	F9B8D4	8802 639955	TATYANA SAVELEVA	{"phone": "+70030500579"}
0005433286075	71A023	6386 918422	LILIYA GAVRILOVA	{"email": "gavrilova.liliya_1974@postgrespro.ru", "phone": "+70125771495"}
0005433286076	71A023	4149 286493	SERGEY KUZNECOV	{"phone": "+70862835703"}
0005433286077	B30DD7	1967 134476	GALINA KUZNECOVA	{"phone": "+70984636533"}
0005433286078	956A0D	8273 953873	NATALIYA NESTEROVA	{"email": "nesterova-n1971@postgrespro.ru", "phone": "+70813075663"}
0005433286079	02241A	1893 278106	VALERIY MAKAROV	{"phone": "+70941415145"}
0005433286080	2E6A2B	6595 001412	MARINA KULIKOVA	{"email": "kulikova_m-24051978@postgrespro.ru", "phone": "+70838592420"}
0005433286081	2E6A2B	1426 802098	SVETLANA ANDREEVA	{"email": "svetlana.andreeva041965@postgrespro.ru", "phone": "+70923698724"}
0005433286082	855AFB	1540 353699	DARYA TIMOFEEVA	{"email": "darya.timofeeva-101983@postgrespro.ru", "phone": "+70339176265"}
0005433286083	0502F1	1198 439099	ZAKHAR KULIKOV	{"phone": "+70121719769"}
0005433286084	A6BD07	1543 993746	ARTEM PETROV	{"email": "petrov-artem1964@postgrespro.ru", "phone": "+70847287218"}
0005433286085	3622EC	8583 005623	ELENA EGOROVA	{"email": "elena.egorova-1969@postgrespro.ru", "phone": "+70686537523"}
0005433286086	B2F23C	3718 993785	GENNADIY MAKSIMOV	{"phone": "+70842822980"}
0005433286087	3D6C4C	8663 193779	MIKHAIL IVANOV	{"phone": "+70367544086"}
0005433286088	3D6C4C	5690 810268	VERA FADEEVA	{"phone": "+70575072214"}
0005433286089	BD9E32	7925 573569	IVAN SIDOROV	{"email": "sidorov.ivan-121959@postgrespro.ru", "phone": "+70202784525"}
0005433286090	827EA8	9085 874386	GENNADIY MAKAROV	{"phone": "+70427316783"}
0005433286091	7050BA	5727 064189	VERA LUKYANOVA	{"email": "lukyanova-vera_16081969@postgrespro.ru", "phone": "+70551912386"}
0005433286092	13C7AD	0625 169925	ALEKSANDR VASILEV	{"phone": "+70319555108"}
0005433286093	13C7AD	6296 962226	OLGA MALYSHEVA	{"email": "olga_malysheva.25021976@postgrespro.ru", "phone": "+70703530061"}
0005433286094	15506B	8230 441387	EVGENIYA GAVRILOVA	{"email": "gavrilovae.08021976@postgrespro.ru", "phone": "+70799344128"}
0005433286095	30DFC0	7037 702435	EKATERINA KOROLEVA	{"phone": "+70072037974"}
0005433286096	30DFC0	0089 699624	ROMAN PAVLOV	{"email": "pavlovroman-021978@postgrespro.ru", "phone": "+70264063844"}
0005433286097	942F0D	0908 614589	VYACHESLAV SERGEEV	{"email": "vyacheslav-sergeev-1967@postgrespro.ru", "phone": "+70615438264"}
0005433286098	C4A0D3	0777 686241	STANISLAV SMIRNOV	{"phone": "+70673579697"}
0005433286099	C4A0D3	9855 165217	NIKITA KOROLEV	{"email": "n-korolev_121975@postgrespro.ru", "phone": "+70476506215"}
0005433286100	7ECFF8	7149 330538	NATALYA DANILOVA	{"phone": "+70461990100"}
0005433286101	BF903F	7066 257556	YURIY KUZMIN	{"email": "kuzmin.yuriy.28051969@postgrespro.ru", "phone": "+70711412487"}
0005433286102	BF903F	9726 052369	POLINA VOLKOVA	{"email": "p_volkova.04041971@postgrespro.ru", "phone": "+70336159721"}
0005433286103	4FF89C	0778 525176	ANATOLIY AFANASEV	{"phone": "+70623992622"}
0005433286104	4FF89C	4201 564367	VIKTOR ABRAMOV	{"email": "viktorabramov_20121971@postgrespro.ru", "phone": "+70796277799"}
0005433286105	4FF89C	7991 163978	MAKSIM OSIPOV	{"phone": "+70942401952"}
0005433286106	184B7E	2330 864667	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina-1964@postgrespro.ru", "phone": "+70593547705"}
0005433286107	942F7D	1277 061745	OKSANA VOLKOVA	{"email": "volkova.oksana.24051980@postgrespro.ru", "phone": "+70658257219"}
0005433286108	6C4411	0773 111469	ALEKSANDR KISELEV	{"email": "kiseleva.1974@postgrespro.ru", "phone": "+70961243332"}
0005433286109	1B8ED6	6756 818719	ELENA ALEKSEEVA	{"email": "ealekseeva.071956@postgrespro.ru", "phone": "+70050215131"}
0005433286110	44622A	2844 921335	MIKHAIL MATVEEV	{"phone": "+70935316104"}
0005433286111	C07F88	1869 956549	LYUDMILA ORLOVA	{"email": "l.orlova-011975@postgrespro.ru", "phone": "+70347903326"}
0005433286112	C7F67D	9147 144415	OLEG BELOV	{"phone": "+70971428186"}
0005433286113	C7F67D	7085 120609	MARINA BELOVA	{"email": "marina-belova.1971@postgrespro.ru", "phone": "+70739169606"}
0005433286114	C7F67D	2142 985168	NATALYA IVANOVA	{"email": "n.ivanova_021973@postgrespro.ru", "phone": "+70221858964"}
0005433286115	639556	2929 773067	VLADIMIR DAVYDOV	{"email": "vladimirdavydov-1974@postgrespro.ru", "phone": "+70064718982"}
0005433286116	4B4F28	1189 570357	ANNA POPOVA	{"phone": "+70357483061"}
0005433286117	C95700	8704 321041	VYACHESLAV ZAKHAROV	{"phone": "+70790343026"}
0005433286118	C95700	9334 893461	ANNA GRISHINA	{"phone": "+70833127294"}
0005433286119	C95700	6449 566327	DENIS PETROV	{"phone": "+70446141580"}
0005433286120	10D54F	5321 134607	ALEVTINA ANTONOVA	{"phone": "+70268597370"}
0005433286121	70F260	2332 658331	EVGENIY KUZNECOV	{"phone": "+70723882358"}
0005433286122	486043	4275 192460	DANIIL PAVLOV	{"email": "daniil_pavlov1965@postgrespro.ru", "phone": "+70545515909"}
0005433286123	F1227D	8215 246328	LYUBOV MAKSIMOVA	{"email": "maksimova_l051966@postgrespro.ru", "phone": "+70686554601"}
0005433286124	345A92	2209 425930	ANNA STEPANOVA	{"phone": "+70990741886"}
0005433286125	D9114D	3855 976341	NIKOLAY ALEKSANDROV	{"email": "naleksandrov_061974@postgrespro.ru", "phone": "+70474769346"}
0005433286126	D9114D	9298 688423	PAVEL MIRONOV	{"email": "p.mironov.18091982@postgrespro.ru", "phone": "+70501586923"}
0005433286127	29F954	2949 615947	OLGA NIKOLAEVA	{"phone": "+70233409281"}
0005433286128	E9C7C4	4789 750249	DMITRIY BARANOV	{"phone": "+70872929291"}
0005433286129	B746AF	6289 179384	VLADIMIR KUZNECOV	{"phone": "+70413727811"}
0005433286130	CE0DBE	4104 465056	ELENA MALYSHEVA	{"email": "malysheva.e-1977@postgrespro.ru", "phone": "+70171227925"}
0005433286131	7D2894	5816 794445	VALENTINA AFANASEVA	{"phone": "+70065926825"}
0005433286132	5741E7	5992 284002	PETR DMITRIEV	{"email": "dmitrievpetr_11021979@postgrespro.ru", "phone": "+70938943259"}
0005433286133	5F6C61	0857 182079	SERGEY SOROKIN	{"phone": "+70690989937"}
0005433286134	5F6C61	2508 545926	TATYANA NIKIFOROVA	{"email": "nikiforovatatyana-111980@postgrespro.ru", "phone": "+70805190189"}
0005433286135	DA9FD2	7983 641290	ALEKSANDRA IVANOVA	{"phone": "+70139104545"}
0005433286136	DA9FD2	7631 127056	ANATOLIY SIDOROV	{"email": "sidorov-anatoliy1975@postgrespro.ru", "phone": "+70688058764"}
0005433286137	5424EC	8511 935694	ANDREY KUZNECOV	{"phone": "+70719106126"}
0005433286138	5424EC	0510 660995	GALINA KUZMINA	{"phone": "+70829475390"}
0005433286139	E637A5	4083 266942	MARINA OSIPOVA	{"phone": "+70941350944"}
0005433286140	0A7388	7273 670774	SERGEY PAVLOV	{"email": "pavlov.s-101971@postgrespro.ru", "phone": "+70815658130"}
0005433286141	0A7388	8144 587518	MARINA DMITRIEVA	{"email": "dmitrievam_031965@postgrespro.ru", "phone": "+70449075643"}
0005433286142	876FD0	9974 604038	NADEZHDA KRASNOVA	{"email": "nadezhda-krasnova_101976@postgrespro.ru", "phone": "+70872640857"}
0005433286143	68C611	5987 575151	SVETLANA ROMANOVA	{"email": "romanova_svetlana.1975@postgrespro.ru", "phone": "+70761469486"}
0005433286144	E38170	4917 575788	KLAVDIYA KARPOVA	{"phone": "+70570067891"}
0005433286145	97548B	5016 896268	ELENA NAUMOVA	{"email": "naumova.e.1968@postgrespro.ru", "phone": "+70604779521"}
0005433286146	50BB27	6358 804084	MARINA PAVLOVA	{"phone": "+70654032085"}
0005433286147	6E1C68	0329 265882	MAKSIM KUZNECOV	{"email": "kuznecovm-1975@postgrespro.ru", "phone": "+70157819552"}
0005433286148	CC2CC1	2981 750038	IRINA STEPANOVA	{"email": "stepanova_i_1957@postgrespro.ru", "phone": "+70657123357"}
0005433286149	CC2CC1	9388 444355	LYUDMILA STEPANOVA	{"email": "stepanoval-101975@postgrespro.ru", "phone": "+70785850964"}
0005433286150	CC2CC1	3977 302974	ALEKSANDR STEPANOV	{"email": "stepanov.a1969@postgrespro.ru", "phone": "+70252812199"}
0005433286151	2C14E8	6851 956462	SERGEY RODIONOV	{"phone": "+70516748450"}
0005433286152	2C14E8	5388 286156	KLAVDIYA ALEKSANDROVA	{"phone": "+70883848943"}
0005433286153	A54710	9322 881082	ELIZAVETA MASLOVA	{"email": "e.maslova1960@postgrespro.ru", "phone": "+70714291032"}
0005433286154	267BB8	0946 629347	POLINA IVANOVA	{"phone": "+70373878186"}
0005433286155	EAD768	3285 761576	ANTON SHEVCHENKO	{"email": "shevchenko-anton_1980@postgrespro.ru", "phone": "+70656069907"}
0005433286156	6C6193	9972 227663	VLADIMIR FEDOROV	{"phone": "+70136928197"}
0005433286157	E36771	7059 536035	EKATERINA BELOVA	{"email": "ekaterina-belova041979@postgrespro.ru", "phone": "+70390663684"}
0005433286158	3790E3	6625 095348	IGOR MAKAROV	{"phone": "+70483126194"}
0005433286159	7883F3	1160 498864	ILYA SCHERBAKOV	{"email": "scherbakov-ilya_01091975@postgrespro.ru", "phone": "+70274230464"}
0005433286160	CCB154	0695 117873	RAISA ANDREEVA	{"email": "andreeva_r.24071971@postgrespro.ru", "phone": "+70541566854"}
0005433286161	C7CBA7	5757 961809	ALEKSANDR MEDVEDEV	{"email": "aleksandrmedvedev.061985@postgrespro.ru", "phone": "+70841762074"}
0005433286162	BCA67E	5613 487196	VYACHESLAV OSIPOV	{"email": "vyacheslav.osipov1959@postgrespro.ru", "phone": "+70418467621"}
0005433286163	743993	8579 825277	KIRILL PETROV	{"phone": "+70157147489"}
0005433286164	70A933	6979 328112	MIKHAIL DMITRIEV	{"email": "mdmitriev-1980@postgrespro.ru", "phone": "+70921021620"}
0005433286165	70A933	3867 805044	YURIY FILIPPOV	{"email": "filippovyuriy_1976@postgrespro.ru", "phone": "+70834487323"}
0005433286166	98275E	1687 273406	LARISA MALYSHEVA	{"email": "l-malysheva-101970@postgrespro.ru", "phone": "+70571571670"}
0005433286167	7DC117	0403 125268	ALEVTINA SOROKINA	{"email": "a_sorokina-061981@postgrespro.ru", "phone": "+70738991998"}
0005433286168	7DC117	8414 399339	GALINA NIKITINA	{"phone": "+70231921800"}
0005433286169	4A39C7	9124 013237	SVETLANA KOZLOVA	{"email": "skozlova_03061966@postgrespro.ru", "phone": "+70610066257"}
0005433286170	4A39C7	5537 998011	MARINA ANISIMOVA	{"phone": "+70837777428"}
0005433286171	7CDC52	7157 335872	FEDOR FROLOV	{"email": "frolovfedor.1965@postgrespro.ru", "phone": "+70054062616"}
0005433286172	1D52CD	6328 874152	ANTON BELOV	{"email": "belov_anton-31081966@postgrespro.ru", "phone": "+70588414174"}
0005433286173	C6BE22	0135 278504	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin.1969@postgrespro.ru", "phone": "+70569901249"}
0005433286174	C6BE22	4296 198140	TATYANA SOROKINA	{"email": "sorokina.t1962@postgrespro.ru", "phone": "+70565340860"}
0005433286175	C6BE22	8449 372525	VLADIMIR VASILEV	{"email": "vasilev_vladimir_021974@postgrespro.ru", "phone": "+70353200784"}
0005433286176	9DF4AC	1562 172451	IRINA NOVIKOVA	{"email": "novikova-i_051959@postgrespro.ru", "phone": "+70742356623"}
0005433286177	D5FC77	5809 963609	LYUBOV ALEKSANDROVA	{"email": "lyubov.aleksandrova-081964@postgrespro.ru", "phone": "+70117026350"}
0005433286178	C4A3A6	3686 461002	SERGEY SAVELEV	{"email": "savelev-sergey1973@postgrespro.ru", "phone": "+70020339425"}
0005433286179	C4A3A6	8426 542365	GLEB PETROV	{"email": "glebpetrov041966@postgrespro.ru", "phone": "+70466244658"}
0005433286180	BF892E	7605 321402	SEMEN MAKSIMOV	{"email": "maksimov-semen1982@postgrespro.ru", "phone": "+70724282442"}
0005433286181	31DA34	7845 855400	SVETLANA SOLOVEVA	{"phone": "+70055568169"}
0005433286182	31DA34	9681 590201	LIDIYA ROMANOVA	{"phone": "+70901694779"}
0005433286183	BA4478	2352 310135	DAVID FROLOV	{"phone": "+70236176274"}
0005433286184	BA4478	4162 429809	PELAGEYA PAVLOVA	{"phone": "+70640971338"}
0005433286185	BA4478	5314 030390	SERGEY KUZNECOV	{"email": "s_kuznecov.01051974@postgrespro.ru", "phone": "+70808315058"}
0005433286186	33FB21	4212 476082	YULIYA VOLKOVA	{"email": "volkova_yuliya_071974@postgrespro.ru", "phone": "+70372379935"}
0005433286187	33FB21	6403 390216	MARIYA ALEKSEEVA	{"email": "mariya-alekseeva.041973@postgrespro.ru", "phone": "+70291174829"}
0005433286188	D291FB	1009 832489	YURIY MAKAROV	{"email": "yuriymakarov-22101966@postgrespro.ru", "phone": "+70418682180"}
0005433286189	D291FB	7080 919223	SERGEY MIKHAYLOV	{"phone": "+70271197843"}
0005433286190	D291FB	9828 925112	OLESYA ANTONOVA	{"phone": "+70282676391"}
0005433286191	665D85	8523 742344	ALEKSANDR ISAEV	{"phone": "+70967021076"}
0005433286192	F4728D	0599 365039	YULIYA KUZNECOVA	{"phone": "+70656605781"}
0005433286193	F4728D	4144 308419	DMITRIY SHEVCHENKO	{"phone": "+70328872326"}
0005433286194	6CC2A2	8032 169980	NATALYA ANISIMOVA	{"email": "anisimova-n_121971@postgrespro.ru", "phone": "+70317659628"}
0005433286195	3ACEDC	9889 331833	DMITRIY KUZNECOV	{"email": "kuznecovd-17011974@postgrespro.ru", "phone": "+70501897812"}
0005433286196	D6A06E	2842 024524	GALINA YAKOVLEVA	{"email": "yakovlevagalina-1969@postgrespro.ru", "phone": "+70229530794"}
0005433286197	155DD2	7818 352823	RAISA SOROKINA	{"email": "sorokina.raisa_12091968@postgrespro.ru", "phone": "+70366998602"}
0005433286198	80107F	3187 563215	VLADIMIR MIRONOV	{"phone": "+70279961562"}
0005433286199	DFC856	7402 141948	MIKHAIL SEMENOV	{"email": "semenovmikhail_121975@postgrespro.ru", "phone": "+70737177453"}
0005433286200	B305A1	6568 146966	MARINA POPOVA	{"phone": "+70389882773"}
0005433286201	395009	2308 112976	VLADIMIR KOZLOV	{"email": "v.kozlov.021971@postgrespro.ru", "phone": "+70346904363"}
0005433286202	53ADDA	4519 909604	ELENA POLYAKOVA	{"email": "polyakova_elena.01091984@postgrespro.ru", "phone": "+70982759290"}
0005433286203	14510D	4332 944420	VITALIY NIKOLAEV	{"email": "vitaliynikolaev_081974@postgrespro.ru", "phone": "+70715691832"}
0005433286204	D99E3E	6943 798936	TAISA KAZAKOVA	{"phone": "+70340036871"}
0005433286205	0C8CD3	4053 999220	ZINAIDA MAKSIMOVA	{"email": "z_maksimova1974@postgrespro.ru", "phone": "+70064007386"}
0005433286206	0C8CD3	3462 533078	IVAN MAKAROV	{"email": "makarov_ivan.1967@postgrespro.ru", "phone": "+70301327369"}
0005433286207	A70B99	3817 766091	EVGENIY IVANOV	{"phone": "+70366190289"}
0005433286208	A70B99	4890 788893	TATYANA EFIMOVA	{"phone": "+70935385584"}
0005433286209	F16EDD	3586 935295	NATALYA PETROVA	{"phone": "+70259324404"}
0005433286210	6552D1	5437 894515	ELIZAVETA BELOVA	{"phone": "+70987903852"}
0005433286211	DC011C	1113 491514	OLGA AFANASEVA	{"phone": "+70643110736"}
0005433286212	2D2293	6789 912805	GALINA TARASOVA	{"phone": "+70056434957"}
0005433286213	E098B4	0018 280590	YULIYA ZOTOVA	{"email": "zotova.y071982@postgrespro.ru", "phone": "+70159147503"}
0005433286214	20E04B	2183 522061	ALEKSEY KARPOV	{"email": "aleksey-karpov13061969@postgrespro.ru", "phone": "+70394335538"}
0005433286215	F1C5AE	5221 730381	PAVEL NIKITIN	{"phone": "+70724421212"}
0005433286216	F1C5AE	6622 682106	IRINA ZAKHAROVA	{"phone": "+70154555420"}
0005433286217	89153A	1835 406298	ALEKSANDR NIKITIN	{"phone": "+70686760286"}
0005433286218	FB3ECE	0456 444245	VERA SOKOLOVA	{"email": "v-sokolova_18101976@postgrespro.ru", "phone": "+70920275743"}
0005433286219	92DF99	7955 539841	VALERIY VOLKOV	{"phone": "+70921135386"}
0005433286220	64B340	9553 135271	ANDREY FROLOV	{"phone": "+70822591210"}
0005433286221	64B340	1274 223912	DMITRIY SOROKIN	{"email": "dmitriy-sorokin.1961@postgrespro.ru", "phone": "+70343729480"}
0005433286222	5D5994	8544 242070	NATALYA NOVIKOVA	{"phone": "+70491964958"}
0005433286223	EE8DB5	2553 180809	NADEZHDA LAZAREVA	{"email": "n_lazareva.24091975@postgrespro.ru", "phone": "+70590034362"}
0005433286224	BFDB4D	5474 442483	VIKTOR BELOV	{"email": "belov.viktor-051968@postgrespro.ru", "phone": "+70005263492"}
0005433286225	91017E	9650 700237	MARINA KUZNECOVA	{"phone": "+70449314500"}
0005433286226	91017E	6421 074310	EVGENIY TIKHONOV	{"phone": "+70387893794"}
0005433286227	91017E	4680 685588	NIKOLAY ZAYCEV	{"email": "n-zaycev-011978@postgrespro.ru", "phone": "+70168244565"}
0005433286228	3A05A6	5016 001830	VERA LOGINOVA	{"phone": "+70368691040"}
0005433286229	62181A	5446 363882	EKATERINA FILIPPOVA	{"email": "e.filippova.1972@postgrespro.ru", "phone": "+70525887529"}
0005433289725	F9CAC7	8064 241583	DMITRIY SMIRNOV	{"phone": "+70208052783"}
0005433289726	F9CAC7	0746 202080	DARYA NAZAROVA	{"email": "darya.nazarova-1977@postgrespro.ru", "phone": "+70166633768"}
0005433289727	A2D650	2978 532714	LYUBOV BELYAEVA	{"phone": "+70720450768"}
0005433289728	2909E4	6356 846496	SERGEY AFANASEV	{"phone": "+70489096225"}
0005433289729	2909E4	0129 994566	ARTEM AFANASEV	{"phone": "+70737249253"}
0005433289730	2909E4	6831 500377	MARINA FEDOROVA	{"phone": "+70200634754"}
0005433289731	A6E43D	7671 697054	OLEG MAKAROV	{"email": "o.makarov13021973@postgrespro.ru", "phone": "+70068344304"}
0005433289732	A6E43D	7600 821823	ALEKSANDR SOKOLOV	{"phone": "+70711576706"}
0005433289733	28EA32	5645 994868	GRIGORIY ZAYCEV	{"phone": "+70156159864"}
0005433289734	28EA32	6139 174053	ROMAN NIKOLAEV	{"phone": "+70471201616"}
0005433289735	E2BD8B	1740 620754	ANNA TITOVA	{"phone": "+70862484355"}
0005433289736	E2BD8B	7161 183864	LARISA ANISIMOVA	{"email": "anisimovalarisa.101964@postgrespro.ru", "phone": "+70613782950"}
0005433289737	D4660C	2144 166017	VLADIMIR ZHURAVLEV	{"phone": "+70795094896"}
0005433289738	F873FB	0786 675823	IRINA FILIPPOVA	{"phone": "+70297665169"}
0005433289739	6231A4	6611 586841	OLGA DAVYDOVA	{"email": "odavydova_031987@postgrespro.ru", "phone": "+70636634107"}
0005433289740	3038D2	6725 635443	LYUDMILA MATVEEVA	{"phone": "+70562125553"}
0005433289741	3038D2	3414 136200	VADIM MELNIKOV	{"email": "vadimmelnikov.1981@postgrespro.ru", "phone": "+70652887970"}
0005433289742	06D0B1	8712 271582	OKSANA MATVEEVA	{"phone": "+70055438512"}
0005433289743	391F02	9240 031892	NADEZHDA KOZLOVA	{"phone": "+70550484857"}
0005433289744	391F02	9616 895084	KIRILL DAVYDOV	{"phone": "+70636475424"}
0005433289745	C2F86A	7078 892453	ELENA BARANOVA	{"email": "baranova_elena.1970@postgrespro.ru", "phone": "+70741139685"}
0005433289746	B3F661	3845 609641	IVAN NIKOLAEV	{"email": "nikolaev_ivan.08011978@postgrespro.ru", "phone": "+70968045490"}
0005433289747	61C89D	7625 740733	ANDREY STEPANOV	{"email": "andrey.stepanov_03051967@postgrespro.ru", "phone": "+70033071613"}
0005433289748	BA430A	5298 115852	IGOR VOLKOV	{"phone": "+70732879217"}
0005433289749	8B8B69	5439 711867	TATYANA KOZLOVA	{"email": "t-kozlova.27031975@postgrespro.ru", "phone": "+70880744743"}
0005433289750	FAE19B	7249 444543	GALIYA GORBUNOVA	{"phone": "+70455350032"}
0005433289751	809915	6871 424431	TATYANA VLASOVA	{"phone": "+70042762524"}
0005433289752	3DC149	7611 916890	GUZEL TITOVA	{"phone": "+70972165563"}
0005433289753	A79A34	6328 502576	GALINA AKIMOVA	{"email": "akimovag14031994@postgrespro.ru", "phone": "+70770784219"}
0005433289754	970EC5	4176 795490	IRINA POTAPOVA	{"email": "irina_potapova_031963@postgrespro.ru", "phone": "+70461577048"}
0005433289755	8A802B	1406 476509	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov.1964@postgrespro.ru", "phone": "+70846992515"}
0005433289756	23785F	1882 832275	VERA KALININA	{"phone": "+70417621720"}
0005433289757	F2CCFF	9034 751376	NATALYA DMITRIEVA	{"phone": "+70003381674"}
0005433289758	F2CCFF	1324 654379	NATALIYA ANDREEVA	{"email": "andreeva-n-15121954@postgrespro.ru", "phone": "+70043155594"}
0005433289759	444079	8423 930535	MARYAM OVCHINNIKOVA	{"email": "maryamovchinnikova_1968@postgrespro.ru", "phone": "+70463433268"}
0005433289760	444079	8757 808551	VLADIMIR SERGEEV	{"phone": "+70678085812"}
0005433289761	444079	5139 991742	TATYANA NIKOLAEVA	{"phone": "+70784418068"}
0005433289762	F6FEB7	2252 254504	IVAN DMITRIEV	{"email": "dmitriev_ivan_19121975@postgrespro.ru", "phone": "+70156108534"}
0005433289763	F6FEB7	1446 519264	TATYANA KOLESNIKOVA	{"phone": "+70704069555"}
0005433289764	7D602C	0516 039785	ALFIYA NOVIKOVA	{"email": "novikova.alfiya.1965@postgrespro.ru", "phone": "+70648537112"}
0005433289765	7D602C	4423 226375	OLGA FILIPPOVA	{"phone": "+70062431786"}
0005433289766	722D00	8817 859694	VIKTOR GRIGOREV	{"email": "viktor_grigorev_041970@postgrespro.ru", "phone": "+70001264372"}
0005433289767	722D00	1677 180539	EVGENIY VOLKOV	{"phone": "+70957679547"}
0005433289768	E0A6E2	1774 374820	ALEKSEY MAKSIMOV	{"phone": "+70518239880"}
0005433289769	5B9F0B	4589 985899	ANASTASIYA ANDREEVA	{"phone": "+70711156232"}
0005433289770	5B9F0B	2042 362187	ELENA ROMANOVA	{"phone": "+70669585707"}
0005433289771	214665	0311 816073	ALLA MARTYNOVA	{"email": "martynova.a-031983@postgrespro.ru", "phone": "+70533365836"}
0005433289772	214665	6590 244333	LILIYA YAKOVLEVA	{"email": "l-yakovleva.06121976@postgrespro.ru", "phone": "+70779999001"}
0005433289773	FC62B1	7084 676745	ANNA KISELEVA	{"phone": "+70640711249"}
0005433289774	04B27E	2016 522373	OLGA MIKHAYLOVA	{"phone": "+70502508596"}
0005433289775	04B27E	4478 122199	YULIYA BELOVA	{"phone": "+70267304211"}
0005433289776	8AC699	8426 646717	VLADISLAV SEMENOV	{"phone": "+70938219294"}
0005433289777	8AC699	1562 454252	ILYA POPOV	{"phone": "+70256968134"}
0005433289778	153F0B	2781 500334	ALEKSANDR NOVIKOV	{"phone": "+70051673188"}
0005433289779	041E4D	2175 134693	KIRILL DMITRIEV	{"email": "dmitriev.kirill_22051978@postgrespro.ru", "phone": "+70290716842"}
0005433289780	8D847D	1982 489152	SERGEY FEDOTOV	{"email": "fedotov.sergey_011966@postgrespro.ru", "phone": "+70973722196"}
0005433289781	8D847D	7961 874433	DARYA FROLOVA	{"email": "frolovadarya_041985@postgrespro.ru", "phone": "+70655413141"}
0005433289782	23792F	2015 708143	LYUBOV EGOROVA	{"email": "egorova-l-081980@postgrespro.ru", "phone": "+70503317398"}
0005433289783	23792F	4319 590150	IRINA MAKAROVA	{"phone": "+70793228086"}
0005433289784	23792F	3870 181495	NIKOLAY OSIPOV	{"email": "osipov-nikolay22011975@postgrespro.ru", "phone": "+70692485305"}
0005433289785	23792F	4455 401456	EGOR EGOROV	{"phone": "+70335246006"}
0005433289786	09D275	8903 498426	VLADIMIR KOZLOV	{"phone": "+70718761327"}
0005433289787	83F680	0697 314547	NIKOLAY DAVYDOV	{"phone": "+70378956867"}
0005433289788	83F680	7166 454699	MARINA MARTYNOVA	{"email": "martynova.marina-011977@postgrespro.ru", "phone": "+70006549087"}
0005433289789	A09E39	8991 204562	ALEKSANDR AFANASEV	{"phone": "+70827329984"}
0005433289790	A09E39	0664 689535	MARGARITA MOROZOVA	{"phone": "+70493135986"}
0005433289791	34A983	7336 127374	VLADIMIR KULIKOV	{"email": "vladimir-kulikov-111971@postgrespro.ru", "phone": "+70560294575"}
0005433289792	34A983	0168 542574	VALERIY POPOV	{"email": "v-popov-24081963@postgrespro.ru", "phone": "+70797918706"}
0005433289793	CEDE89	1264 204230	SVETLANA IVANOVA	{"phone": "+70134319696"}
0005433289794	CEDE89	5265 635628	NIKITA ANTONOV	{"email": "antonovnikita121979@postgrespro.ru", "phone": "+70114666505"}
0005433289795	A0633B	8661 024519	ALEKSANDR DENISOV	{"email": "a_denisov_021964@postgrespro.ru", "phone": "+70912782660"}
0005433289796	A0633B	2421 191660	ALEKSANDR NIKITIN	{"email": "a_nikitin.081974@postgrespro.ru", "phone": "+70355043943"}
0005433289797	A16216	1814 878796	DMITRIY KOROLEV	{"phone": "+70904746951"}
0005433289798	042609	4882 904405	SVETLANA IVANOVA	{"phone": "+70012744785"}
0005433289799	B52DBF	2712 086975	OLEG BELOV	{"email": "oleg_belov-19031970@postgrespro.ru", "phone": "+70690138663"}
0005433289800	B52DBF	2999 686814	SVETLANA SOROKINA	{"phone": "+70690149517"}
0005433289801	C3BC55	6067 649570	SERGEY ABRAMOV	{"email": "sergeyabramov_021962@postgrespro.ru", "phone": "+70195835529"}
0005433289802	CA6931	5094 483967	VIKTOR KONOVALOV	{"phone": "+70078386507"}
0005433289803	CA6931	0401 495946	ANATOLIY MAKAROV	{"email": "makarov-a_051978@postgrespro.ru", "phone": "+70569742264"}
0005433289804	192C5E	0232 732824	NELLI EGOROVA	{"email": "egorova-n_02091966@postgrespro.ru", "phone": "+70186573205"}
0005433289805	192C5E	2691 377326	ALISA ORLOVA	{"email": "alisa.orlova.111975@postgrespro.ru", "phone": "+70336143264"}
0005433289806	192C5E	3193 959492	TATYANA ZAYCEVA	{"email": "zayceva-tatyana1969@postgrespro.ru", "phone": "+70809908029"}
0005433289807	192C5E	6095 238686	DENIS GRIGOREV	{"phone": "+70125310682"}
0005433289808	10EE73	5836 324387	ELENA NESTEROVA	{"phone": "+70170423395"}
0005433289809	D0C205	3162 936789	ARSENIY TIKHONOV	{"phone": "+70045054945"}
0005433289810	D0C205	0754 426407	MARGARITA VOLKOVA	{"phone": "+70387104934"}
0005433289811	7CF580	0292 850910	ALEKSANDRA ERMAKOVA	{"email": "ermakova_a.121970@postgrespro.ru", "phone": "+70363969390"}
0005433289812	7CF580	6595 395814	ROZA SIDOROVA	{"email": "roza-sidorova_1979@postgrespro.ru", "phone": "+70612022792"}
0005433289813	F8801D	7403 524060	NATALYA SAVELEVA	{"email": "natalyasaveleva-051980@postgrespro.ru", "phone": "+70491753661"}
0005433289814	8342D0	4686 637515	ALISHER KARPOV	{"phone": "+70046682982"}
0005433289815	BFF55D	3484 265153	DARYA PAVLOVA	{"phone": "+70085960325"}
0005433289816	63F190	7947 113788	ALEKSEY KOZLOV	{"email": "kozlov.aleksey-101976@postgrespro.ru", "phone": "+70321896104"}
0005433289817	F3B54C	1189 574779	MAKSIM ANDREEV	{"phone": "+70295383052"}
0005433289818	EF7B7F	8968 008531	ALEKSEY SAVELEV	{"email": "a.savelev_17021973@postgrespro.ru", "phone": "+70222878494"}
0005433289819	5A8FD6	0801 899887	SVETLANA KUZMINA	{"phone": "+70163382457"}
0005433289820	5192C8	3126 806329	ANASTASIYA IVANOVA	{"phone": "+70877962279"}
0005433289821	BD7C30	8392 140500	ANATOLIY TIMOFEEV	{"email": "anatoliy_timofeev-031970@postgrespro.ru", "phone": "+70414896298"}
0005433289822	1A6D66	3566 703662	IVAN FILIPPOV	{"email": "i-filippov1966@postgrespro.ru", "phone": "+70490308161"}
0005433289823	AFD905	0598 289380	LYUDMILA CHERNOVA	{"phone": "+70459804098"}
0005433289824	AFD905	8896 315379	ALEKSANDR NAZAROV	{"email": "nazarov_a.12021976@postgrespro.ru", "phone": "+70462320046"}
0005433289825	5DA62D	7599 891618	LYUBOV SOROKINA	{"phone": "+70471076170"}
0005433289826	5DA62D	8133 717190	ANATOLIY FROLOV	{"phone": "+70776741769"}
0005433289827	D417A0	3005 125522	PETR SOKOLOV	{"email": "petr-sokolov_021970@postgrespro.ru", "phone": "+70453820690"}
0005433289828	26F11C	9712 244151	YULIYA ZAYCEVA	{"phone": "+70610225019"}
0005433289829	26F11C	4772 183776	GENNADIY ILIN	{"email": "ilin-g041971@postgrespro.ru", "phone": "+70690252691"}
0005433289830	032101	4655 848871	NADEZHDA LEBEDEVA	{"email": "lebedeva_nadezhda-111971@postgrespro.ru", "phone": "+70571346865"}
0005433289831	032101	9080 563402	SERGEY PETROV	{"email": "petrov.s-1981@postgrespro.ru", "phone": "+70085252629"}
0005433289832	A13474	3958 651732	ALEKSEY KONOVALOV	{"email": "alekseykonovalov-27041983@postgrespro.ru", "phone": "+70182643625"}
0005433289833	642E7A	6943 822489	DENIS VLASOV	{"phone": "+70111705456"}
0005433289834	642E7A	1917 626697	VALERIY SOROKIN	{"phone": "+70363368795"}
0005433289835	E2CC09	3542 589628	LYUDMILA POPOVA	{"email": "popova.l_081970@postgrespro.ru", "phone": "+70871445138"}
0005433289836	E2CC09	6473 495469	VERA FEDOROVA	{"email": "fedorova-vera_1974@postgrespro.ru", "phone": "+70954129188"}
0005433289837	E2CC09	5140 788762	SERGEY MIRONOV	{"email": "sergey_mironov-1971@postgrespro.ru", "phone": "+70436861846"}
0005433289838	2ECD8D	7206 679585	ELENA MATVEEVA	{"email": "e.matveeva_1957@postgrespro.ru", "phone": "+70038362425"}
0005433289839	66817B	7509 859732	ILYA SCHERBAKOV	{"email": "scherbakov.ilya1971@postgrespro.ru", "phone": "+70346251296"}
0005433289840	66817B	4650 250080	VERA FEDOROVA	{"email": "fedorova_vera_111974@postgrespro.ru", "phone": "+70523346034"}
0005433289841	EB59F8	2036 899464	NIKOLAY TIKHONOV	{"phone": "+70484302523"}
0005433289842	48D270	4136 107018	GENNADIY ZHUKOV	{"email": "g_zhukov-021974@postgrespro.ru", "phone": "+70474348256"}
0005433289843	48D270	6195 972635	DAVID KUZNECOV	{"phone": "+70628884808"}
0005433289844	EF939C	3924 594209	EKATERINA NESTEROVA	{"phone": "+70482358945"}
0005433289845	EF939C	5184 761980	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir.1967@postgrespro.ru", "phone": "+70390059594"}
0005433289846	295D06	4113 714536	ANASTASIYA PETROVA	{"phone": "+70536842929"}
0005433289847	7A641A	7259 525370	MAKSIM KUZNECOV	{"phone": "+70761824918"}
0005433289848	A2CF3A	9282 606111	SVETLANA BOGDANOVA	{"email": "s.bogdanova1964@postgrespro.ru", "phone": "+70459959740"}
0005433289849	6019E6	0300 666709	ANATOLIY KUZNECOV	{"phone": "+70900489420"}
0005433289850	6BCBA8	0052 506130	ALEKSEY IVANOV	{"email": "aleksey_ivanov-1971@postgrespro.ru", "phone": "+70164220769"}
0005433289851	4016E6	3004 004454	NADEZHDA BELYAEVA	{"email": "nadezhda_belyaeva-06101975@postgrespro.ru", "phone": "+70264265659"}
0005433289852	05585A	3300 979044	ELENA PETROVA	{"phone": "+70970487630"}
0005433289853	5D160B	6779 301949	ANDREY KONOVALOV	{"email": "andrey_konovalov_07061967@postgrespro.ru", "phone": "+70089224895"}
0005433289854	42574E	7650 071387	EKATERINA DENISOVA	{"phone": "+70057782631"}
0005433289855	42574E	1792 781112	GAGIK FEDOTOV	{"email": "fedotov.gagik-26101968@postgrespro.ru", "phone": "+70264562881"}
0005433289856	42574E	2505 796141	STANISLAV KUZNECOV	{"email": "skuznecov_02121967@postgrespro.ru", "phone": "+70317083894"}
0005433289857	F7902F	6953 175237	OLEG VOROBEV	{"email": "vorobev_o-1966@postgrespro.ru", "phone": "+70996055008"}
0005433289858	F7902F	7878 823752	VLADISLAV ALEKSANDROV	{"email": "vladislav_aleksandrov-1973@postgrespro.ru", "phone": "+70574828945"}
0005433289859	A532F0	2035 935732	NIKOLAY FEDOTOV	{"email": "fedotov.n111966@postgrespro.ru", "phone": "+70543549404"}
0005433289860	DE3E78	5926 182528	VASILIY NIKITIN	{"email": "vasiliynikitin21021984@postgrespro.ru", "phone": "+70565525580"}
0005433289861	DE3E78	5858 880849	NATALYA MIKHAYLOVA	{"email": "natalya-mikhaylova_091975@postgrespro.ru", "phone": "+70800116914"}
0005433289862	673D52	0162 389051	TAMARA DMITRIEVA	{"email": "dmitrieva.tamara.1975@postgrespro.ru", "phone": "+70798385965"}
0005433289863	673D52	3055 878933	OLGA GORBUNOVA	{"phone": "+70044403153"}
0005433289864	8B17D2	3003 912178	SERGEY SOROKIN	{"email": "sorokin-s-25041964@postgrespro.ru", "phone": "+70072720277"}
0005433289865	100CE4	7977 544588	IRINA KUZNECOVA	{"email": "irinakuznecova121976@postgrespro.ru", "phone": "+70117099484"}
0005433289866	C9F3A0	1551 907736	SVETLANA MAKAROVA	{"email": "makarova.svetlana061984@postgrespro.ru", "phone": "+70607637352"}
0005433289867	C9F3A0	2580 712409	IVAN NOVIKOV	{"email": "ivannovikov.041983@postgrespro.ru", "phone": "+70915476587"}
0005433289868	C9F3A0	9637 948566	ALMIRA YAKOVLEVA	{"phone": "+70356806979"}
0005433289869	4A2890	0671 196060	TAMARA TIMOFEEVA	{"email": "t.timofeeva1969@postgrespro.ru", "phone": "+70648228531"}
0005433289870	0B90BB	5521 504560	VLADIMIR NOVIKOV	{"email": "novikovv_021975@postgrespro.ru", "phone": "+70982435540"}
0005433289871	B26BFC	5877 045290	ELENA GUSEVA	{"phone": "+70969443691"}
0005433289872	B26BFC	2056 210352	MARGARITA PETROVA	{"phone": "+70590703383"}
0005433289873	E904C9	1674 252321	VERA BORISOVA	{"phone": "+70705379196"}
0005433289874	4B917E	6595 329594	NATALYA KOZLOVA	{"email": "kozlova_n.121961@postgrespro.ru", "phone": "+70185225304"}
0005433289875	0A748D	8393 781659	VIKTOR SMIRNOV	{"phone": "+70520306921"}
0005433289876	0A748D	3753 933999	LEONID FOMIN	{"email": "l-fomin.1973@postgrespro.ru", "phone": "+70418744602"}
0005433289877	DE0E02	0490 900918	OLGA SIDOROVA	{"email": "sidorova-o.1964@postgrespro.ru", "phone": "+70226646023"}
0005433289878	DE0E02	9336 603158	RADIK GRIGOREV	{"email": "r_grigorev05121963@postgrespro.ru", "phone": "+70695658721"}
0005433289879	AC82F2	8219 415807	ALEKSANDR GERASIMOV	{"email": "gerasimov_aleksandr-1963@postgrespro.ru", "phone": "+70680924932"}
0005433289880	AC82F2	3686 898796	ELENA ANTONOVA	{"phone": "+70817802818"}
0005433289881	FE3364	2710 848992	ANATOLIY EGOROV	{"phone": "+70142390879"}
0005433289882	1A3C9F	7093 728155	VERA KUZNECOVA	{"phone": "+70417863946"}
0005433289883	1A3C9F	7705 562089	MIKHAIL IVANOV	{"phone": "+70192625016"}
0005433289884	048861	8035 472198	EVGENIYA MELNIKOVA	{"phone": "+70203283791"}
0005433289885	048861	3570 163683	IRINA FEDOROVA	{"email": "irina.fedorova-1984@postgrespro.ru", "phone": "+70033635337"}
0005433289886	BED374	9337 343101	YURIY NIKOLAEV	{"phone": "+70778611918"}
0005433289887	615323	3276 737985	MIKHAIL ZHUKOV	{"phone": "+70481474190"}
0005433289888	65A402	1704 845976	VLADIMIR NIKOLAEV	{"phone": "+70797991646"}
0005433289889	07DEF8	5794 488118	RUSLAN VOROBEV	{"phone": "+70420468267"}
0005433289890	F28F77	2464 697566	SERGEY SOROKIN	{"email": "sergeysorokin-011979@postgrespro.ru", "phone": "+70891643178"}
0005433289891	F28F77	8292 299621	VIKTOR VOLKOV	{"email": "volkov_viktor.1972@postgrespro.ru", "phone": "+70060873127"}
0005433289892	451B1E	5269 726881	ANNA EGOROVA	{"phone": "+70607787782"}
0005433289893	22B1F3	6938 130457	BULAT TIKHONOV	{"phone": "+70524336351"}
0005433289894	22B1F3	3724 557952	OKSANA MIRONOVA	{"phone": "+70551152262"}
0005433289895	EDAE33	7522 694735	RIMMA ERMAKOVA	{"phone": "+70895901279"}
0005433289896	85EE4F	3595 308861	IVAN KUZNECOV	{"email": "i.kuznecov_23041962@postgrespro.ru", "phone": "+70113819833"}
0005433289897	AC9999	3110 596740	LILIYA RODIONOVA	{"email": "liliyarodionova_1968@postgrespro.ru", "phone": "+70572363651"}
0005433289898	2BAA87	6924 106299	NINA VOROBEVA	{"phone": "+70688271513"}
0005433289899	2BAA87	7513 402011	IRINA FEDOROVA	{"email": "fedorova_irina-05091971@postgrespro.ru", "phone": "+70158215530"}
0005433289900	2BAA87	4934 667047	MARIYA KARPOVA	{"phone": "+70361190379"}
0005433289901	6C8037	5427 979560	LYUDMILA FILIPPOVA	{"phone": "+70830641523"}
0005433289902	B0CF2B	2487 937771	ALEKSANDR ALEKSEEV	{"phone": "+70949109354"}
0005433289903	B0CF2B	5643 741544	ALEKSANDR KUZMIN	{"phone": "+70395830962"}
0005433289904	4A0ED1	4865 833286	SERGEY KUZNECOV	{"email": "kuznecovsergey_03091967@postgrespro.ru", "phone": "+70919497730"}
0005433289905	4A0ED1	5226 622380	ALEKSANDR ZAYCEV	{"phone": "+70936824542"}
0005433289906	2DEE96	7553 449793	RAMILYA KUZNECOVA	{"email": "kuznecova-ramilya.061978@postgrespro.ru", "phone": "+70517516086"}
0005433289907	41A672	4775 918271	RUSTEM ZAYCEV	{"email": "rustem_zaycev-1975@postgrespro.ru", "phone": "+70397525300"}
0005433289908	CBA521	8192 343927	SERGEY KARPOV	{"phone": "+70583354636"}
0005433289909	879CB4	1643 835771	ALEKSANDR VOROBEV	{"phone": "+70092150475"}
0005433289910	879CB4	5870 976521	ANTON SHEVCHENKO	{"email": "a-shevchenko_121972@postgrespro.ru", "phone": "+70663238003"}
0005433289911	42C992	7646 132604	VIKTOR VOLKOV	{"phone": "+70419820278"}
0005433289912	42C992	0186 434814	ANASTASIYA PAVLOVA	{"phone": "+70283782844"}
0005433289913	70BBC2	9386 784838	ELENA TIMOFEEVA	{"phone": "+70495169099"}
0005433289914	E060F2	9542 639899	AYRAT ZAKHAROV	{"email": "zakharov.ayrat17021975@postgrespro.ru", "phone": "+70687905567"}
0005433289915	412B74	9855 656630	SERGEY IVANOV	{"phone": "+70631793020"}
0005433289916	412B74	4161 168238	VLADIMIR TARASOV	{"phone": "+70344976142"}
0005433289917	5CF1A1	5420 844534	NARIMAN KRASNOV	{"phone": "+70639648824"}
0005433289918	437AD1	1614 878076	NATALYA KONDRATEVA	{"email": "n.kondrateva1970@postgrespro.ru", "phone": "+70728811525"}
0005433289919	437AD1	2557 753206	TATYANA SCHERBAKOVA	{"phone": "+70457743323"}
0005433289920	F25E3B	4007 756500	SAMIRA KISELEVA	{"phone": "+70686237453"}
0005433289921	AAAC42	1755 061672	MARIYA KOROLEVA	{"email": "mkoroleva021968@postgrespro.ru", "phone": "+70788237056"}
0005433289922	AAAC42	1650 223903	ROSTISLAV MAKAROV	{"email": "r_makarov-24031961@postgrespro.ru", "phone": "+70972334991"}
0005433289923	661F8F	7590 687088	MARIYA KUZNECOVA	{"phone": "+70513723298"}
0005433289924	80F787	8051 628484	SVETLANA ROMANOVA	{"email": "sromanova09101970@postgrespro.ru", "phone": "+70064741354"}
0005433289925	66ED74	6559 551849	SERGEY KRASNOV	{"phone": "+70401027939"}
0005433289926	AEBCF2	7738 768194	LYUBOV SMIRNOVA	{"email": "smirnova-lyubov.08121959@postgrespro.ru", "phone": "+70495646833"}
0005433289927	53FD16	1534 620594	TATYANA VOLKOVA	{"phone": "+70889210876"}
0005433289928	56B1F8	6376 596990	RUSLAN ROMANOV	{"phone": "+70537038699"}
0005433289929	AF02F4	6932 656592	ANTON MAKAROV	{"email": "makarova_1969@postgrespro.ru", "phone": "+70906242477"}
0005433289930	AF02F4	9000 042984	VALENTINA KISELEVA	{"phone": "+70333154134"}
0005433289931	24D4BF	6169 127273	MARIYA KUZMINA	{"phone": "+70504538647"}
0005433289932	097A4D	4697 610387	ELIZAVETA PAVLOVA	{"phone": "+70510358019"}
0005433289933	56F664	3857 609782	NINA MALYSHEVA	{"phone": "+70708054994"}
0005433289934	F75D0E	1519 278973	NIKOLAY MOROZOV	{"email": "n_morozov.1964@postgrespro.ru", "phone": "+70661828987"}
0005433289935	8E3AB3	0503 924431	NIKOLAY VOLKOV	{"email": "volkov.n.1969@postgrespro.ru", "phone": "+70588918911"}
0005433289936	A6D441	7078 200879	TATYANA NAZAROVA	{"phone": "+70046200272"}
0005433289937	B4CBD6	1816 930520	KSENIYA NAZAROVA	{"email": "nazarova.kseniya.011972@postgrespro.ru", "phone": "+70209384139"}
0005433289938	FD2772	5658 977763	IGOR NIKITIN	{"email": "nikitin_igor-21091975@postgrespro.ru", "phone": "+70456728286"}
0005433289939	366947	6519 761978	ANNA KUZMINA	{"email": "kuzmina-a_011975@postgrespro.ru", "phone": "+70587304064"}
0005433289940	366947	6881 036645	MAKSIM MARTYNOV	{"phone": "+70478038407"}
0005433289941	9041D3	8438 221575	MARINA MATVEEVA	{"email": "marina_matveeva_1960@postgrespro.ru", "phone": "+70177550620"}
0005433289942	9041D3	6891 529661	LIDIYA IVANOVA	{"phone": "+70660524804"}
0005433289943	9A6E2F	2596 456131	YULIYA NIKIFOROVA	{"email": "nikiforovayuliya.16081964@postgrespro.ru", "phone": "+70988026011"}
0005433289944	6FF6D6	5582 613692	VLADISLAV MATVEEV	{"phone": "+70218403314"}
0005433289945	8F5A74	8105 812876	OKSANA NIKOLAEVA	{"email": "nikolaeva-oksana-1968@postgrespro.ru", "phone": "+70609477591"}
0005433289946	BAD53A	0535 383775	VLADISLAV BARANOV	{"email": "v.baranov-011972@postgrespro.ru", "phone": "+70733346426"}
0005433289947	BAD53A	5344 112805	SVETLANA ZAYCEVA	{"email": "zaycevasvetlana1965@postgrespro.ru", "phone": "+70303050170"}
0005433289948	406C69	6544 901168	ROMAN KRASNOV	{"email": "krasnov.r-28111960@postgrespro.ru", "phone": "+70117777243"}
0005433289949	F37833	9248 371556	OKSANA PAVLOVA	{"email": "oksana.pavlova1976@postgrespro.ru", "phone": "+70192585315"}
0005433289950	F37833	3876 176820	LILIYA DAVYDOVA	{"email": "davydova-liliya18111975@postgrespro.ru", "phone": "+70187791621"}
0005433289951	8A76AF	3283 121172	VIKTORIYA MALYSHEVA	{"email": "malysheva-v-1973@postgrespro.ru", "phone": "+70194067065"}
0005433289952	A810D1	6241 530708	SERGEY VASILEV	{"phone": "+70140392420"}
0005433289953	F38261	4557 656171	OLEG FROLOV	{"email": "frolovo_05091962@postgrespro.ru", "phone": "+70312759953"}
0005433289954	C3B463	3591 700092	SERGEY FROLOV	{"email": "s-frolov-1968@postgrespro.ru", "phone": "+70043283846"}
0005433289955	C3B463	9967 619007	IGOR VOLKOV	{"phone": "+70166271303"}
0005433289956	D186EB	7352 871161	YULIYA IVANOVA	{"email": "ivanova_y-1975@postgrespro.ru", "phone": "+70100548119"}
0005433289957	D186EB	1489 368590	IRINA ANDREEVA	{"email": "i.andreeva-1970@postgrespro.ru", "phone": "+70831047031"}
0005433289958	E43BE3	7878 029034	NINA MOROZOVA	{"phone": "+70295706256"}
0005433289959	3E5774	0737 429199	TATYANA KUDRYASHOVA	{"email": "kudryashovat.121966@postgrespro.ru", "phone": "+70974476748"}
0005433289960	549D1B	4646 809661	IGOR KUDRYASHOV	{"email": "igorkudryashov-1972@postgrespro.ru", "phone": "+70076077767"}
0005433289961	7A44B7	3833 495038	VLADIMIR ALEKSEEV	{"phone": "+70238889126"}
0005433289962	A97B26	5984 428643	VITALIY GORBUNOV	{"phone": "+70429543287"}
0005433289963	FF1110	0442 861063	VALERIY VOROBEV	{"email": "vorobevv.17091966@postgrespro.ru", "phone": "+70088423922"}
0005433289964	3E0C0C	7824 460806	VALERIY FOMIN	{"phone": "+70033255885"}
0005433289965	63F339	5069 927946	GALINA KUDRYASHOVA	{"email": "kudryashova-g.091970@postgrespro.ru", "phone": "+70683996718"}
0005433289966	63F339	0182 105710	TATYANA MIKHAYLOVA	{"email": "mikhaylovat-1978@postgrespro.ru", "phone": "+70925671360"}
0005433289967	005C0D	9322 614901	ALEKSEY ZAYCEV	{"email": "zaycev_a_1960@postgrespro.ru", "phone": "+70103856459"}
0005433289968	75AAD4	3973 870782	LYUDMILA EGOROVA	{"phone": "+70854817190"}
0005433289969	75AAD4	1680 344945	MAKSIM MELNIKOV	{"phone": "+70813254241"}
0005433289970	2BFAA9	4686 712548	OLGA BORISOVA	{"email": "borisovaolga_1980@postgrespro.ru", "phone": "+70011530690"}
0005433289971	2BFAA9	6197 770979	IGOR SERGEEV	{"phone": "+70857940002"}
0005433289972	ECFA43	6798 903562	ALEKSANDR PAVLOV	{"phone": "+70209533157"}
0005433289973	ECFA43	5024 446323	ANDREY SEMENOV	{"email": "semenov.a.30111980@postgrespro.ru", "phone": "+70873670931"}
0005433289974	777CAC	4709 256164	KRISTINA KOZLOVA	{"email": "kozlova-k-10081969@postgrespro.ru", "phone": "+70350913376"}
0005433289975	9CDCD0	9209 674924	SVETLANA ANISIMOVA	{"email": "anisimova.svetlana-1987@postgrespro.ru", "phone": "+70667076224"}
0005433289976	0C11AA	7594 264470	LYUDMILA STEPANOVA	{"email": "stepanova-l.02091968@postgrespro.ru", "phone": "+70799261855"}
0005433289977	BEBF69	2909 012887	VALERIY ROMANOV	{"email": "valeriyromanov.1974@postgrespro.ru", "phone": "+70090348964"}
0005433289978	E2B707	9970 803657	REGINA MALYSHEVA	{"email": "regina.malysheva.1979@postgrespro.ru", "phone": "+70048334716"}
0005433289979	B57A7F	1573 254043	NIKOLAY SHEVCHENKO	{"phone": "+70549310960"}
0005433289980	1EBA73	3453 433039	EVGENIY KRASNOV	{"phone": "+70369281450"}
0005433289981	9BD5E2	0036 739476	ANATOLIY KUZNECOV	{"phone": "+70595687954"}
0005433289982	1A19BA	0470 990964	RAISA KOZLOVA	{"email": "kozlova.r_121968@postgrespro.ru", "phone": "+70193579914"}
0005433289983	61FB15	4213 690653	VIKTOR SHEVCHENKO	{"phone": "+70082926805"}
0005433289984	61FB15	2783 148949	LYUBOV ERMAKOVA	{"phone": "+70884243157"}
0005433289985	6F6F6F	1926 663299	EGOR FILIPPOV	{"phone": "+70044333753"}
0005433289986	7FF540	0170 585322	SOFIYA FROLOVA	{"email": "frolova-s.1977@postgrespro.ru", "phone": "+70161432584"}
0005433289987	7FF540	3417 350089	IVAN IVANOV	{"email": "i.ivanov.1978@postgrespro.ru", "phone": "+70365033307"}
0005433289988	635375	4870 009493	KLAVDIYA SAVELEVA	{"email": "saveleva_klavdiya.18111976@postgrespro.ru", "phone": "+70992922643"}
0005433289989	635375	5337 864040	SERGEY TIMOFEEV	{"email": "sergey-timofeev.1973@postgrespro.ru", "phone": "+70522544133"}
0005433289990	19F529	7401 525893	OLEG NAZAROV	{"email": "nazarov-oleg_1961@postgrespro.ru", "phone": "+70033227666"}
0005433289991	EF6CD0	7319 454432	DENIS CHERNOV	{"email": "denischernov_1979@postgrespro.ru", "phone": "+70927756469"}
0005433289992	513AC2	0533 328361	VERA FROLOVA	{"email": "vera-frolova21081978@postgrespro.ru", "phone": "+70583294690"}
0005433289993	513AC2	1892 190786	SERGEY ANTONOV	{"email": "antonovsergey_23031968@postgrespro.ru", "phone": "+70458048360"}
0005433289994	30CE7A	2265 049440	OLGA PETROVA	{"phone": "+70994184894"}
0005433289995	3DF031	0286 065494	VLADIMIR MAKAROV	{"email": "v_makarov_091984@postgrespro.ru", "phone": "+70087780521"}
0005433289996	57DD54	0781 373221	MARIYA OSIPOVA	{"phone": "+70102855493"}
0005433289997	74EC34	0679 722153	TAMARA MEDVEDEVA	{"email": "tmedvedeva1974@postgrespro.ru", "phone": "+70859741291"}
0005433289998	74EC34	7132 582708	PAVEL NIKITIN	{"email": "pavelnikitin_1975@postgrespro.ru", "phone": "+70297569707"}
0005433289999	1A25EA	2100 201412	YURIY MIRONOV	{"email": "y.mironov_1978@postgrespro.ru", "phone": "+70455464175"}
0005433290000	1A25EA	2749 096750	PAVEL KUZMIN	{"phone": "+70260004540"}
0005433290001	88B147	2085 579556	IVAN VOLKOV	{"email": "volkov_ivan.15061975@postgrespro.ru", "phone": "+70211458586"}
0005433290002	88B147	7120 288503	ANASTASIYA GORBUNOVA	{"email": "a_gorbunova.1966@postgrespro.ru", "phone": "+70599163675"}
0005433290003	88B147	9056 672089	BORIS SEMENOV	{"email": "borissemenov.15031978@postgrespro.ru", "phone": "+70463168812"}
0005433290004	23D5C3	8204 732552	ANATOLIY POPOV	{"phone": "+70029913212"}
0005433290005	23D5C3	5563 346680	YULIYA FILIPPOVA	{"phone": "+70581233250"}
0005433290006	A54964	0542 538155	NATALYA SMIRNOVA	{"phone": "+70684556825"}
0005433290007	41371E	8866 315634	NINA TIMOFEEVA	{"phone": "+70032709825"}
0005433290008	41371E	6623 553856	ANDREY ALEKSEEV	{"phone": "+70991633411"}
0005433290009	66BD77	6524 570879	VIKTOR SAVELEV	{"phone": "+70511942045"}
0005433290010	0480F4	8389 906872	MAKSIM SERGEEV	{"phone": "+70023822194"}
0005433290011	0480F4	9784 058065	NIKOLAY PAVLOV	{"phone": "+70396483292"}
0005433290012	C248CC	0096 478521	DENIS PAVLOV	{"email": "pavlov.d.051966@postgrespro.ru", "phone": "+70827673950"}
0005433290013	C248CC	7738 063660	SERGEY ALEKSEEV	{"email": "s_alekseev-1983@postgrespro.ru", "phone": "+70209710362"}
0005433290014	2A1645	0738 649895	BORIS KRASNOV	{"phone": "+70649277292"}
0005433290015	5E60D0	6282 822621	OLGA TROFIMOVA	{"phone": "+70318915508"}
0005433290016	A96C33	5526 617340	ALEKSANDR ORLOV	{"phone": "+70345260989"}
0005433290017	8CE617	7120 809500	ROMAN ZAYCEV	{"email": "zaycev-r-1972@postgrespro.ru", "phone": "+70945768589"}
0005433290018	8CE617	5236 145041	LIDIYA IVANOVA	{"phone": "+70528318882"}
0005433290019	FE2DEA	5452 059525	EKATERINA GORBUNOVA	{"phone": "+70530235155"}
0005433290020	FE2DEA	9358 534357	VIKTOR SERGEEV	{"email": "sergeev.viktor02111967@postgrespro.ru", "phone": "+70659670150"}
0005433290021	473C70	6033 134626	STEPAN KARPOV	{"email": "karpov-s-1969@postgrespro.ru", "phone": "+70114812405"}
0005433290022	473C70	8791 100995	RINAT TIKHONOV	{"email": "rinat_tikhonov-1962@postgrespro.ru", "phone": "+70959937676"}
0005433290023	8ACED9	2818 159430	VALERIY MEDVEDEV	{"phone": "+70139844632"}
0005433290024	454188	8247 772379	VALENTINA KUDRYASHOVA	{"email": "valentinakudryashova_1968@postgrespro.ru", "phone": "+70782438083"}
0005433290025	9CC94B	8827 851322	SERGEY VASILEV	{"email": "vasilev.sergey.121971@postgrespro.ru", "phone": "+70191478178"}
0005433290026	7050E0	9337 361497	NINA ROMANOVA	{"email": "n.romanova.011973@postgrespro.ru", "phone": "+70532579997"}
0005433290027	7050E0	2370 578530	SERGEY TARASOV	{"phone": "+70047423802"}
0005433290028	0AC0C0	7247 710836	LYUBOV SCHERBAKOVA	{"phone": "+70027651804"}
0005433290029	0AC0C0	3522 472780	ILYA SEMENOV	{"email": "i-semenov-071981@postgrespro.ru", "phone": "+70417742028"}
0005433290030	0AC0C0	7471 347274	NATALIYA VOROBEVA	{"phone": "+70092456437"}
0005433290031	FA559A	0678 502035	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey.121974@postgrespro.ru", "phone": "+70624777667"}
0005433290032	69976C	8127 186971	SERGEY STEPANOV	{"phone": "+70182694576"}
0005433290033	69976C	7008 920439	ALEKSANDR FROLOV	{"email": "frolov.a-30041966@postgrespro.ru", "phone": "+70944546000"}
0005433290034	C0B350	5776 103552	SERGEY VASILEV	{"phone": "+70340989620"}
0005433290035	8B16C9	1794 385253	IRINA SOLOVEVA	{"phone": "+70753562740"}
0005433290036	BC9F41	6650 806646	ELENA ZAKHAROVA	{"email": "zakharova.elena.21061968@postgrespro.ru", "phone": "+70766496183"}
0005433290037	7B034C	0247 973718	ZARINA IVANOVA	{"email": "ivanova.z.1978@postgrespro.ru", "phone": "+70492609334"}
0005433290038	7B034C	3849 696456	DAMIR ROMANOV	{"phone": "+70627081567"}
0005433290039	9CE3F9	9660 936393	ALEKSANDR MELNIKOV	{"email": "melnikova1974@postgrespro.ru", "phone": "+70679451096"}
0005433290040	62BA20	3547 738122	ANDREY ANDREEV	{"email": "aandreev31031972@postgrespro.ru", "phone": "+70021645343"}
0005433290041	519E47	9566 858632	IVAN MARTYNOV	{"phone": "+70883881945"}
0005433290042	BB4F94	5121 770162	ISLAM SEMENOV	{"email": "semenov_i.041967@postgrespro.ru", "phone": "+70787777963"}
0005433290043	BB4F94	6711 234924	NATALYA AFANASEVA	{"phone": "+70297313900"}
0005433290044	ED39D9	0727 867639	NIKOLAY IVANOV	{"email": "ivanov-nikolay_1971@postgrespro.ru", "phone": "+70864818637"}
0005433290045	592544	8258 069608	NATALIYA NESTEROVA	{"email": "n_nesterova_101966@postgrespro.ru", "phone": "+70752379549"}
0005433290046	A7F9D3	1784 134367	SVETLANA MATVEEVA	{"phone": "+70647745735"}
0005433290047	187812	1928 727853	DENIS TIMOFEEV	{"phone": "+70544717256"}
0005433290048	187812	5292 257508	NADEZHDA BORISOVA	{"phone": "+70661912027"}
0005433290049	87B970	9864 064320	SERGEY VASILEV	{"phone": "+70450208638"}
0005433290050	079EDF	2984 803659	ANASTASIYA CHERNOVA	{"email": "chernova.a.03051965@postgrespro.ru", "phone": "+70576139031"}
0005433290051	64B879	1459 190587	ELVINA GERASIMOVA	{"phone": "+70336795105"}
0005433290052	B9A2D8	9860 791505	LUIZA MELNIKOVA	{"phone": "+70221177815"}
0005433290053	89D476	4999 364558	GALINA KUZNECOVA	{"email": "g-kuznecova021980@postgrespro.ru", "phone": "+70591347777"}
0005433290054	557804	4247 398579	ANZHELA RODIONOVA	{"email": "rodionova_anzhela_051979@postgrespro.ru", "phone": "+70202042124"}
0005433290055	C25AC6	4860 171419	NADEZHDA FILATOVA	{"email": "nadezhda_filatova-1972@postgrespro.ru", "phone": "+70359429516"}
0005433290056	A6FDE8	9317 113588	EVGENIY ZAYCEV	{"email": "e-zaycev_04011975@postgrespro.ru", "phone": "+70899785610"}
0005433290057	DDB90D	8491 612722	VALENTINA PETROVA	{"phone": "+70120961488"}
0005433290058	DDB90D	0821 365693	GALINA SMIRNOVA	{"phone": "+70679342056"}
0005433290059	722BD9	8242 379227	LYUDMILA KISELEVA	{"email": "lyudmila_kiseleva-051969@postgrespro.ru", "phone": "+70430982440"}
0005433290060	FC4643	5376 030758	PAVEL MOISEEV	{"email": "moiseev.pavel_1965@postgrespro.ru", "phone": "+70006584302"}
0005433290061	406433	6307 527886	ELIZAVETA BELOVA	{"email": "belova-e031969@postgrespro.ru", "phone": "+70706103191"}
0005433290062	74A78B	4596 008414	MARIYA BOGDANOVA	{"email": "bogdanova_mariya031980@postgrespro.ru", "phone": "+70308691129"}
0005433290063	63C54C	6254 992040	NIKOLAY CHERNOV	{"phone": "+70468849159"}
0005433290064	63C54C	8268 905580	OLGA NAZAROVA	{"email": "onazarova.1971@postgrespro.ru", "phone": "+70030140647"}
0005433290065	A33486	0964 926820	YURIY NAZAROV	{"phone": "+70354453416"}
0005433290066	6B5C5A	6392 984004	RAISA VOROBEVA	{"phone": "+70534106184"}
0005433290067	B68CD8	9215 044415	TATYANA POPOVA	{"phone": "+70748280906"}
0005433293142	73DE2E	9823 177607	LIDIYA NOVIKOVA	{"phone": "+70704501017"}
0005433293143	30689E	6300 106917	ANASTASIYA DANILOVA	{"phone": "+70884943397"}
0005433293144	F140F6	8314 896402	VALENTIN GERASIMOV	{"email": "gerasimovvalentin_1983@postgrespro.ru", "phone": "+70132943240"}
0005433293145	F140F6	9637 296741	GALINA PETROVA	{"phone": "+70141163398"}
0005433293146	758BE1	4744 062630	NATALYA VLASOVA	{"phone": "+70515109939"}
0005433293147	758BE1	5822 627568	VIKTOR ORLOV	{"phone": "+70610838327"}
0005433293148	7B687A	0038 692195	DMITRIY PETROV	{"email": "d_petrov_1966@postgrespro.ru", "phone": "+70727693250"}
0005433293149	7B687A	3374 735334	FANIYA LUKYANOVA	{"phone": "+70826957554"}
0005433293150	4B1175	2457 219051	FANIYA IVANOVA	{"email": "f.ivanova.19071965@postgrespro.ru", "phone": "+70393953116"}
0005433293151	87DB29	2305 360296	IGOR OSIPOV	{"phone": "+70664553022"}
0005433293152	889D0B	5429 472810	ARTEM MAKSIMOV	{"email": "a.maksimov-061979@postgrespro.ru", "phone": "+70256351120"}
0005433293153	7A8452	0445 192382	IVAN ANDREEV	{"email": "andreev-ivan_1983@postgrespro.ru", "phone": "+70780729414"}
0005433293154	F0A88A	3926 546671	EVGENIY SEMENOV	{"phone": "+70007807157"}
0005433293155	209B31	2423 252297	VALENTINA NIKOLAEVA	{"phone": "+70523098963"}
0005433293156	88D1EA	0893 097323	ULYANA SEMENOVA	{"email": "semenovaulyana.101979@postgrespro.ru", "phone": "+70701505964"}
0005433293157	421680	3155 613373	YULIYA NIKOLAEVA	{"phone": "+70570519247"}
0005433293158	8B0192	6866 474348	YULIYA GUSEVA	{"phone": "+70186925809"}
0005433293159	25A3E2	0840 056798	ANDREY GUSEV	{"phone": "+70711798147"}
0005433293160	414853	6114 427041	OKSANA MELNIKOVA	{"email": "melnikovaoksana061963@postgrespro.ru", "phone": "+70118230974"}
0005433293161	906D79	3386 273114	NIKOLAY KOROLEV	{"email": "korolev.n-21091981@postgrespro.ru", "phone": "+70371339386"}
0005433293162	906D79	6635 395185	VALENTINA ZAKHAROVA	{"email": "zakharova-v21111969@postgrespro.ru", "phone": "+70788442759"}
0005433293163	906D79	4223 460825	ANATOLIY GORBUNOV	{"phone": "+70127811911"}
0005433293164	A87512	8811 486322	KSENIYA DANILOVA	{"email": "k-danilova_031969@postgrespro.ru", "phone": "+70090235353"}
0005433293165	3FF361	1399 133150	NIKOLAY BARANOV	{"phone": "+70001129811"}
0005433293166	3FF361	7744 569908	VASILIY MIKHAYLOV	{"email": "vasiliy-mikhaylov-1975@postgrespro.ru", "phone": "+70355708815"}
0005433293167	3FF361	4257 962663	TATYANA FILATOVA	{"email": "filatova.t-1963@postgrespro.ru", "phone": "+70385205138"}
0005433293168	8134A9	6661 618186	NINA AKIMOVA	{"phone": "+70848057831"}
0005433293169	8134A9	7298 346875	YURIY SOROKIN	{"phone": "+70259034458"}
0005433293170	3D44BC	4398 757166	ANDREY EGOROV	{"phone": "+70658728178"}
0005433293171	4F1C3B	4677 986063	VALERIY VASILEV	{"email": "valeriy.vasilev_27091969@postgrespro.ru", "phone": "+70610329378"}
0005433293172	FB1651	2506 837238	GALINA IVANOVA	{"email": "ivanova-galina071972@postgrespro.ru", "phone": "+70140494986"}
0005433293173	16BDDE	1501 574642	IRINA POLYAKOVA	{"phone": "+70102755503"}
0005433293174	FDC594	9739 565419	LYUBOV PAVLOVA	{"phone": "+70140898565"}
0005433293175	2A8AFE	7163 295555	IVAN VOROBEV	{"email": "vorobev_i_101981@postgrespro.ru", "phone": "+70049205058"}
0005433293176	2A8AFE	5943 544361	TATYANA RODIONOVA	{"phone": "+70690579167"}
0005433293177	2A8AFE	6645 031409	IVAN MELNIKOV	{"phone": "+70481834215"}
0005433293178	68B566	9238 742322	DMITRIY DAVYDOV	{"email": "davydov-d_071983@postgrespro.ru", "phone": "+70290852574"}
0005433293179	68B566	5740 479779	ARTEM SCHERBAKOV	{"email": "scherbakova.021971@postgrespro.ru", "phone": "+70709276356"}
0005433293180	FB1EC1	3103 363196	GALINA KARPOVA	{"email": "galina.karpova-1967@postgrespro.ru", "phone": "+70439255620"}
0005433293181	D075FA	9464 236624	NIKITA POPOV	{"phone": "+70275401329"}
0005433293182	D075FA	7376 729898	DARYA ORLOVA	{"phone": "+70804829807"}
0005433293183	89C732	1094 188757	RAMIL ZAYCEV	{"email": "ramil-zaycev.17061964@postgrespro.ru", "phone": "+70158130760"}
0005433293184	89C732	1837 029223	VASILIY KUZNECOV	{"email": "vasiliykuznecov-26111963@postgrespro.ru", "phone": "+70734431953"}
0005433293185	7620F2	5784 818377	ALEKSANDR TARASOV	{"email": "tarasovaleksandr081967@postgrespro.ru", "phone": "+70720144605"}
0005433293186	06152A	7242 878171	NATALYA ROMANOVA	{"email": "natalya.romanova-1987@postgrespro.ru", "phone": "+70639533018"}
0005433293187	B26D13	8216 359319	SVETLANA TROFIMOVA	{"email": "s.trofimova1970@postgrespro.ru", "phone": "+70152815619"}
0005433293188	76187C	1971 404541	KONSTANTIN VOROBEV	{"email": "k-vorobev_031975@postgrespro.ru", "phone": "+70687726296"}
0005433293189	76187C	1956 354357	SERGEY POPOV	{"phone": "+70530233542"}
0005433293190	AD886E	5215 946865	ANDREY MOISEEV	{"email": "moiseev.a.061976@postgrespro.ru", "phone": "+70965102145"}
0005433293191	AD886E	8880 711470	ANDREY SMIRNOV	{"phone": "+70183192525"}
0005433293192	FFDC55	0149 538961	TATYANA SOKOLOVA	{"email": "sokolova-tatyana.121971@postgrespro.ru", "phone": "+70595180733"}
0005433293193	D74A5F	3186 768313	MARGARITA MOROZOVA	{"email": "m-morozova.29081963@postgrespro.ru", "phone": "+70090336818"}
0005433293194	B22788	1831 048313	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova071977@postgrespro.ru", "phone": "+70977848159"}
0005433293195	B22788	3458 584726	LEONID KULIKOV	{"phone": "+70261822267"}
0005433293196	1E7021	0987 522067	YURIY SCHERBAKOV	{"email": "scherbakov_y.1968@postgrespro.ru", "phone": "+70066603836"}
0005433293197	1E7021	9472 575085	EKATERINA MOROZOVA	{"email": "e-morozova-091966@postgrespro.ru", "phone": "+70042721901"}
0005433293198	52D67B	3163 800153	DANIIL BORISOV	{"email": "d-borisov_1977@postgrespro.ru", "phone": "+70701685365"}
0005433293199	6A6F97	7885 767775	ELENA YAKOVLEVA	{"phone": "+70829550725"}
0005433293200	C5DDEE	7994 445690	SVETLANA FEDOROVA	{"phone": "+70791932905"}
0005433293201	29CC86	4903 342639	NATALYA KUZNECOVA	{"phone": "+70155183297"}
0005433293202	64F7FF	9393 808728	RAVIL IVANOV	{"email": "ivanov_r-101986@postgrespro.ru", "phone": "+70028595460"}
0005433293203	BD73BE	2307 612149	DANILA BARANOV	{"email": "baranov.d-26021968@postgrespro.ru", "phone": "+70145417808"}
0005433293204	BD73BE	5265 108589	NATALYA STEPANOVA	{"email": "n-stepanova-071974@postgrespro.ru", "phone": "+70168358454"}
0005433293205	0E755B	7235 371174	OLESYA NESTEROVA	{"email": "o.nesterova07081976@postgrespro.ru", "phone": "+70142613742"}
0005433293206	9B839B	0012 211052	NINA LAZAREVA	{"phone": "+70790818921"}
0005433293207	48394E	7794 593724	TAMARA TIKHONOVA	{"phone": "+70720017993"}
0005433293208	6353E2	9223 084669	EVGENIY IVANOV	{"phone": "+70083915900"}
0005433293209	117875	2338 513115	NINA KUDRYASHOVA	{"email": "kudryashova_n_07101959@postgrespro.ru", "phone": "+70248203672"}
0005433293210	4113B8	5486 967202	OLGA FILIPPOVA	{"email": "filippovao.08111980@postgrespro.ru", "phone": "+70578139652"}
0005433293211	AD7C9F	2397 321529	ALBERT ANTONOV	{"email": "a-antonov-22041981@postgrespro.ru", "phone": "+70082856302"}
0005433293212	2A6DD5	7533 909373	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov_21041973@postgrespro.ru", "phone": "+70360262008"}
0005433293213	88A16F	5860 696010	GALINA GERASIMOVA	{"phone": "+70457171815"}
0005433293214	34F76F	8448 120373	DANIIL ANDREEV	{"email": "andreev.d091971@postgrespro.ru", "phone": "+70225259884"}
0005433293215	34F76F	1694 841596	SNEZHANA DENISOVA	{"phone": "+70540628489"}
0005433293216	34F76F	9172 163463	ELENA NIKOLAEVA	{"phone": "+70437977377"}
0005433293217	43D61F	3303 009673	ANASTASIYA KOZLOVA	{"email": "akozlova1964@postgrespro.ru", "phone": "+70614226168"}
0005433293218	43D61F	4493 765885	TATYANA KONDRATEVA	{"phone": "+70558757243"}
0005433293219	B55C7C	3677 754680	ROMAN KAZAKOV	{"phone": "+70616222817"}
0005433293220	E0F1FC	4875 295304	ELENA ZAKHAROVA	{"email": "zakharova_e-1974@postgrespro.ru", "phone": "+70321632029"}
0005433293221	E0F1FC	5669 618766	MARIYA BARANOVA	{"email": "mariya-baranova_26081965@postgrespro.ru", "phone": "+70862019812"}
0005433293222	FBB4DC	2221 324985	VLADIMIR NOVIKOV	{"phone": "+70997384063"}
0005433293223	FBB4DC	6863 454193	DANIL VASILEV	{"phone": "+70204512750"}
0005433293224	446A41	3979 305924	YURIY MATVEEV	{"phone": "+70921858974"}
0005433293225	BDE301	3314 982575	ROBERT KUDRYASHOV	{"email": "robert_kudryashov_1963@postgrespro.ru", "phone": "+70272412800"}
0005433293226	FCF98E	4051 456716	SVETLANA KUZNECOVA	{"phone": "+70519187420"}
0005433293227	064D47	7008 893820	ALEKSANDR KUZMIN	{"phone": "+70354476978"}
0005433293228	4F7285	6891 064616	RAVIL MEDVEDEV	{"email": "r-medvedev1975@postgrespro.ru", "phone": "+70865731396"}
0005433293229	4F7285	0005 301453	YULIYA ALEKSEEVA	{"email": "yuliya_alekseeva101973@postgrespro.ru", "phone": "+70719641292"}
0005433293230	BD63A2	7131 559160	ANDREY SHEVCHENKO	{"email": "shevchenko_a_1971@postgrespro.ru", "phone": "+70864308081"}
0005433293231	92DEAC	0059 405517	ALEKSANDR SOLOVEV	{"phone": "+70406637811"}
0005433293232	3FDEBA	7790 733436	KSENIYA MOISEEVA	{"email": "moiseeva.k-1976@postgrespro.ru", "phone": "+70599032254"}
0005433293292	215655	4439 279943	ALEKSANDR BELOV	{"phone": "+70898729278"}
0005433293233	3FDEBA	4842 506838	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr_071970@postgrespro.ru", "phone": "+70467519999"}
0005433293234	3FDEBA	8250 801979	PETR KUZNECOV	{"phone": "+70027465910"}
0005433293235	3FDEBA	6372 842740	ALEKSANDR VOLKOV	{"phone": "+70042585143"}
0005433293236	A4BB0E	3273 691130	NIKOLAY PAVLOV	{"email": "n_pavlov-091963@postgrespro.ru", "phone": "+70128097710"}
0005433293237	133F09	9386 160698	VALENTINA EFREMOVA	{"email": "valentinaefremova121975@postgrespro.ru", "phone": "+70446584042"}
0005433293238	133F09	2084 370047	NIKOLAY SIDOROV	{"phone": "+70449912089"}
0005433293239	3CAB84	0275 452670	EVDOKIYA NOVIKOVA	{"email": "novikova.evdokiya1975@postgrespro.ru", "phone": "+70023174511"}
0005433293240	CFADCC	4610 494375	SERGEY EGOROV	{"email": "egorov-sergey-1977@postgrespro.ru", "phone": "+70974676613"}
0005433293241	8D52AF	1015 695726	TATYANA MIKHAYLOVA	{"phone": "+70649630346"}
0005433293242	CB10D1	7400 555086	KONSTANTIN POPOV	{"phone": "+70757327508"}
0005433293243	AFEC5E	7051 170353	LILIYA DMITRIEVA	{"email": "l.dmitrieva_121979@postgrespro.ru", "phone": "+70904071439"}
0005433293244	9DAB97	1362 054799	DMITRIY ALEKSANDROV	{"email": "dmitriyaleksandrov-111980@postgrespro.ru", "phone": "+70245949472"}
0005433293245	AA01DB	4633 248131	OLGA ORLOVA	{"email": "orlova.olga.03041965@postgrespro.ru", "phone": "+70525575236"}
0005433293246	DCCCF8	9602 006006	DARYA MIRONOVA	{"email": "mironova.d_09051970@postgrespro.ru", "phone": "+70220625872"}
0005433293247	DCCCF8	2472 795710	VITALIY GORBUNOV	{"phone": "+70881147208"}
0005433293248	FBB102	7511 718339	TATYANA ANTONOVA	{"email": "tatyanaantonova-091968@postgrespro.ru", "phone": "+70231558930"}
0005433293249	72A18E	9488 454345	EKATERINA FROLOVA	{"phone": "+70161366017"}
0005433293250	72A18E	9766 864820	POLINA IVANOVA	{"email": "polinaivanova_041984@postgrespro.ru", "phone": "+70366285064"}
0005433293251	CEEE49	5947 906155	VALENTINA GORBUNOVA	{"email": "gorbunova_v_011971@postgrespro.ru", "phone": "+70764569747"}
0005433293252	3CC886	0366 383878	VIKTOR ISAEV	{"email": "isaev.viktor.1979@postgrespro.ru", "phone": "+70524920210"}
0005433293253	3CC886	9454 312462	VERA MIRONOVA	{"phone": "+70710650859"}
0005433293254	4AAA88	9205 547454	SERGEY ZHUKOV	{"phone": "+70653411996"}
0005433293255	4AAA88	8640 633965	TATYANA VOLKOVA	{"email": "tatyana_volkova-061965@postgrespro.ru", "phone": "+70411062117"}
0005433293256	48F944	2265 430769	MIKHAIL OSIPOV	{"phone": "+70313627827"}
0005433293257	10FD1E	5726 090149	IVAN NAZAROV	{"email": "nazarov.ivan09051980@postgrespro.ru", "phone": "+70637728505"}
0005433293258	BCD916	0022 669555	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova_21021960@postgrespro.ru", "phone": "+70718974137"}
0005433293259	8F56F6	3993 786435	VYACHESLAV FROLOV	{"email": "frolovv.031964@postgrespro.ru", "phone": "+70219300028"}
0005433293260	8F56F6	1197 642963	POLINA ILINA	{"phone": "+70281480359"}
0005433293261	642840	3963 019317	ANNA ANISIMOVA	{"phone": "+70392966712"}
0005433293262	21C8FE	5616 796764	LYUBOV MELNIKOVA	{"email": "l.melnikova_1985@postgrespro.ru", "phone": "+70438742550"}
0005433293263	21C8FE	2193 035206	OLGA PAVLOVA	{"phone": "+70849588680"}
0005433293264	79A218	8660 589432	ALEKSEY NAZAROV	{"phone": "+70290421238"}
0005433293265	65F7B4	8185 087508	TATYANA EGOROVA	{"email": "tatyana_egorova_16061971@postgrespro.ru", "phone": "+70805327625"}
0005433293266	84AC60	5555 896305	VLADIMIR ZHURAVLEV	{"email": "vladimir-zhuravlev29091968@postgrespro.ru", "phone": "+70110655692"}
0005433293267	84AC60	3689 283827	GALINA MEDVEDEVA	{"email": "g-medvedeva_041969@postgrespro.ru", "phone": "+70824477351"}
0005433293268	B18C1E	4968 075881	ELENA SOKOLOVA	{"email": "elena.sokolova_1967@postgrespro.ru", "phone": "+70294299732"}
0005433293269	C66F18	3462 236782	ALEKSANDR POPOV	{"phone": "+70867146873"}
0005433293270	168D4E	0289 369101	NADEZHDA TIMOFEEVA	{"email": "n_timofeeva1975@postgrespro.ru", "phone": "+70766662936"}
0005433293271	E92F16	6855 183654	ANZHELIKA KOZLOVA	{"email": "anzhelika-kozlova.29011972@postgrespro.ru", "phone": "+70286338954"}
0005433293272	E92F16	4568 874265	MIKHAIL EGOROV	{"phone": "+70842137350"}
0005433293273	6B6FBA	4186 016266	NINA KARPOVA	{"phone": "+70003905446"}
0005433293274	6B6FBA	0149 312183	ELENA DAVYDOVA	{"email": "davydovae1978@postgrespro.ru", "phone": "+70572987716"}
0005433293275	510078	0415 165821	VERA BORISOVA	{"phone": "+70717161145"}
0005433293276	DE1E8C	4839 071088	ALEKSEY FOMIN	{"email": "fomin-a-12071973@postgrespro.ru", "phone": "+70998980371"}
0005433293277	DE1E8C	9835 813097	LYUBOV ROMANOVA	{"email": "l.romanova_051965@postgrespro.ru", "phone": "+70104867746"}
0005433293278	608A24	5016 500868	ALEKSEY YAKOVLEV	{"email": "yakovlev-aleksey-1970@postgrespro.ru", "phone": "+70702025635"}
0005433293279	D11227	3749 901548	SVETLANA MAKAROVA	{"email": "s-makarova_031984@postgrespro.ru", "phone": "+70918131713"}
0005433293280	D11227	4053 835234	ANATOLIY GERASIMOV	{"email": "a.gerasimov_1984@postgrespro.ru", "phone": "+70331126944"}
0005433293281	4AB9F4	6917 883617	SERGEY PETROV	{"email": "s-petrov_1979@postgrespro.ru", "phone": "+70507494961"}
0005433293282	D60F3E	9219 503058	DMITRIY PAVLOV	{"phone": "+70099603066"}
0005433293283	DAFBEA	9828 482818	VLADIMIR PAVLOV	{"email": "pavlovv_06041970@postgrespro.ru", "phone": "+70863440125"}
0005433293284	DAFBEA	0709 642926	OLGA STEPANOVA	{"email": "o.stepanova1971@postgrespro.ru", "phone": "+70745521611"}
0005433293285	DAFBEA	4269 119114	SVETLANA FADEEVA	{"email": "s_fadeeva1967@postgrespro.ru", "phone": "+70135742257"}
0005433293286	0682B4	4841 145552	ALEKSANDRA POPOVA	{"phone": "+70070092326"}
0005433293287	C69136	1655 960129	NATALYA EGOROVA	{"phone": "+70637370130"}
0005433293288	C69136	1960 128830	IRINA LEBEDEVA	{"phone": "+70082779079"}
0005433293289	90A7D9	3229 325048	KIRILL KULIKOV	{"email": "kirillkulikov.061971@postgrespro.ru", "phone": "+70842089224"}
0005433293290	90A7D9	0608 999536	VALERIY IVANOV	{"phone": "+70976221146"}
0005433293291	215655	2611 289872	YURIY KISELEV	{"phone": "+70382020666"}
0005433293293	B335E3	4837 270380	VALENTINA PAVLOVA	{"email": "pavlova.valentina.15071976@postgrespro.ru", "phone": "+70207379034"}
0005433293294	B335E3	1583 102937	TAMARA ERMAKOVA	{"phone": "+70558619190"}
0005433293295	4C7D4B	7706 118555	RINAT GORBUNOV	{"phone": "+70872923831"}
0005433293296	4C7D4B	1452 346547	RUSLAN NIKITIN	{"phone": "+70528973825"}
0005433293297	517860	5213 177610	ANATOLIY BORISOV	{"phone": "+70019435301"}
0005433293298	517860	9881 850775	ELENA LAZAREVA	{"email": "e.lazareva.09041980@postgrespro.ru", "phone": "+70732338775"}
0005433293299	04865F	4172 190981	EVGENIY PETROV	{"email": "epetrov121972@postgrespro.ru", "phone": "+70014714906"}
0005433293300	04865F	5390 159465	NURLAN KRASNOV	{"email": "nurlan_krasnov-111979@postgrespro.ru", "phone": "+70177359787"}
0005433293301	04B892	4905 090473	OLEG MARTYNOV	{"email": "o-martynov-111971@postgrespro.ru", "phone": "+70673446732"}
0005433293302	B29327	2117 644650	IGOR CHERNOV	{"phone": "+70104975015"}
0005433293303	15F589	8561 652190	ALINA KOROLEVA	{"phone": "+70874706087"}
0005433293304	15F589	2047 200677	LYUBOV KAZAKOVA	{"email": "kazakovalyubov061975@postgrespro.ru", "phone": "+70683742497"}
0005433293305	15F589	1723 366384	OLESYA GRISHINA	{"phone": "+70039102737"}
0005433293306	575815	2188 462769	ANATOLIY PETROV	{"phone": "+70312687306"}
0005433293307	A81035	8975 382910	OLGA SAVELEVA	{"phone": "+70954451437"}
0005433293308	5E98FB	3050 691459	ALENA GUSEVA	{"phone": "+70511835528"}
0005433293309	1B055C	8911 903385	SERGEY FEDOROV	{"email": "s-fedorov.27051986@postgrespro.ru", "phone": "+70681791749"}
0005433293310	1B055C	1587 036743	GERMAN PETROV	{"email": "german.petrov.081975@postgrespro.ru", "phone": "+70678056993"}
0005433293311	1B055C	6074 678397	TATYANA MALYSHEVA	{"email": "malysheva-tatyana_15101980@postgrespro.ru", "phone": "+70895152484"}
0005433293312	7F85AE	9892 321548	DMITRIY VLASOV	{"email": "vlasovdmitriy.01111969@postgrespro.ru", "phone": "+70077439720"}
0005433293313	7F85AE	0862 450742	PETR OSIPOV	{"email": "p-osipov.081973@postgrespro.ru", "phone": "+70407583997"}
0005433293314	19E096	7329 108338	EVGENIY IVANOV	{"phone": "+70116253353"}
0005433293315	19E096	3153 496017	NIKOLAY ISAEV	{"email": "isaev-nikolay.011980@postgrespro.ru", "phone": "+70085268093"}
0005433293316	E26DC7	8909 577507	MARIYA VOLKOVA	{"email": "volkovam1993@postgrespro.ru", "phone": "+70955923567"}
0005433293317	E26DC7	1289 042476	MIKHAIL SCHERBAKOV	{"phone": "+70463646728"}
0005433293318	906E1F	6677 935677	ALEKSANDR VOLKOV	{"phone": "+70346706054"}
0005433293319	906E1F	3289 741192	VLADIMIR NIKOLAEV	{"phone": "+70860386221"}
0005433293320	B8B9F0	1991 730101	VALENTINA SCHERBAKOVA	{"email": "scherbakovavalentina.011988@postgrespro.ru", "phone": "+70204932554"}
0005433293321	65EBEF	9118 763675	VLADIMIR SHEVCHENKO	{"phone": "+70013004496"}
0005433293322	B27EC3	7376 716046	ARKADIY ALEKSEEV	{"phone": "+70985271969"}
0005433293323	B27EC3	7486 560539	YURIY IVANOV	{"email": "ivanov.y-081972@postgrespro.ru", "phone": "+70823774517"}
0005433293324	08C04F	0619 323464	PAVEL KOZLOV	{"phone": "+70545648584"}
0005433293325	08C04F	2115 904888	MARINA ERMAKOVA	{"email": "m_ermakova.1983@postgrespro.ru", "phone": "+70265893441"}
0005433293326	D0E69B	0609 632303	ELIZAVETA VOLKOVA	{"email": "elizaveta-volkova-07091981@postgrespro.ru", "phone": "+70851074589"}
0005433293327	D0E69B	5173 291912	IGOR FEDOROV	{"email": "fedorov_i-13031977@postgrespro.ru", "phone": "+70225229937"}
0005433293328	7F5252	9586 945695	IRINA PAVLOVA	{"email": "pavlovai.25121964@postgrespro.ru", "phone": "+70885088449"}
0005433293329	7F5252	7086 276512	VALENTINA NESTEROVA	{"phone": "+70759848348"}
0005433293330	1E666C	7264 826630	ALINA YUDINA	{"email": "a_yudina24101962@postgrespro.ru", "phone": "+70725487504"}
0005433293331	83EFBA	6103 171528	SVETLANA MOROZOVA	{"email": "morozova.s031974@postgrespro.ru", "phone": "+70028172317"}
0005433293332	83EFBA	6325 502869	SERGEY BARANOV	{"phone": "+70775796759"}
0005433293333	ADF131	7647 003279	LYUDMILA ALEKSEEVA	{"phone": "+70773967425"}
0005433293334	ADF131	1302 045995	VALENTIN GERASIMOV	{"email": "gerasimov_valentin-061965@postgrespro.ru", "phone": "+70489073169"}
0005433293335	ADF131	4242 848784	ANGELINA SAVELEVA	{"email": "a_saveleva31051971@postgrespro.ru", "phone": "+70739100053"}
0005433293336	305DBC	3253 984608	SERGEY ANTONOV	{"phone": "+70853179247"}
0005433293337	C6DEE8	2275 321471	YANA VOROBEVA	{"phone": "+70995395520"}
0005433293338	1E4525	5248 831910	ALEKSANDR POPOV	{"email": "popov_a-18031973@postgrespro.ru", "phone": "+70980365672"}
0005433293339	F13674	2656 581659	EVGENIY VOLKOV	{"email": "evgeniy-volkov.111969@postgrespro.ru", "phone": "+70355343202"}
0005433293340	F13674	7434 953463	TATYANA NESTEROVA	{"email": "nesterova_tatyana-23021973@postgrespro.ru", "phone": "+70295900326"}
0005433293341	E3098C	1381 655048	SERGEY KONOVALOV	{"email": "skonovalov121985@postgrespro.ru", "phone": "+70507262174"}
0005433293342	F40DC0	7243 935694	ALEKSANDRA KUDRYASHOVA	{"email": "aleksandrakudryashova_1972@postgrespro.ru", "phone": "+70195580228"}
0005433293343	7DE6B4	9678 223861	DMITRIY VOROBEV	{"email": "vorobev_dmitriy_051981@postgrespro.ru", "phone": "+70080992307"}
0005433293344	7DE6B4	6491 705777	ANDREY ORLOV	{"email": "orlovandrey.1975@postgrespro.ru", "phone": "+70987543995"}
0005433293345	6B9EB3	6439 558078	ELENA DENISOVA	{"phone": "+70590128538"}
0005433293346	52152F	0331 550322	TATYANA MOISEEVA	{"email": "moiseevat.1972@postgrespro.ru", "phone": "+70705022761"}
0005433293347	693888	7961 697414	NATALIYA VASILEVA	{"phone": "+70155060717"}
0005433293348	C015DB	7537 197844	SERGEY MOISEEV	{"phone": "+70690222311"}
0005433293349	1AB15E	5900 887282	OLGA EFIMOVA	{"phone": "+70950733207"}
0005433293350	57230E	9425 013067	LARISA RODIONOVA	{"email": "rodionova-larisa10021977@postgrespro.ru", "phone": "+70910257966"}
0005433293351	57230E	1791 739688	ALEKSEY POPOV	{"email": "a_popov.27091976@postgrespro.ru", "phone": "+70569888975"}
0005433293352	CA019F	4661 860092	ANDREY DENISOV	{"phone": "+70914786703"}
0005433293353	CA019F	8863 146235	KSENIYA KOLESNIKOVA	{"email": "k-kolesnikova_20071975@postgrespro.ru", "phone": "+70641126481"}
0005433293354	07B225	3034 391404	ANNA BELYAEVA	{"phone": "+70716603741"}
0005433293355	9B73B4	3130 351932	NIKITA ISAEV	{"email": "nikita.isaev_13091984@postgrespro.ru", "phone": "+70195108802"}
0005433293356	9B73B4	3948 430727	ANATOLIY MEDVEDEV	{"phone": "+70290000263"}
0005433293357	ADA81F	8500 092791	NATALYA DENISOVA	{"phone": "+70395348179"}
0005433293358	ADA81F	1793 770762	ALEKSANDR PAVLOV	{"email": "pavlova_01031963@postgrespro.ru", "phone": "+70637531277"}
0005433293359	BF2F7B	1752 030118	DARYA VOROBEVA	{"email": "vorobevadarya.17081977@postgrespro.ru", "phone": "+70484232958"}
0005433293360	D1A242	4115 223336	OLGA SERGEEVA	{"email": "o.sergeeva19101966@postgrespro.ru", "phone": "+70044618348"}
0005433293361	D1A242	9336 530385	BORIS SIDOROV	{"phone": "+70355866696"}
0005433293362	183996	4055 627600	IRINA ROMANOVA	{"email": "irinaromanova-1973@postgrespro.ru", "phone": "+70398500442"}
0005433293363	183996	0111 513052	LARISA SMIRNOVA	{"email": "larisa-smirnova-26031966@postgrespro.ru", "phone": "+70549828243"}
0005433293364	8D0298	7105 739735	VLADIMIR MAKAROV	{"email": "makarov-v-011980@postgrespro.ru", "phone": "+70331769865"}
0005433293365	E128BE	1170 287673	SERGEY VLASOV	{"email": "s-vlasov.26081972@postgrespro.ru", "phone": "+70273807479"}
0005433293366	AB734D	1061 039080	NATALYA POPOVA	{"phone": "+70321338695"}
0005433293367	AB734D	5966 008280	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov021977@postgrespro.ru", "phone": "+70874784040"}
0005433293368	E001A3	3707 951743	ANDREY ABRAMOV	{"phone": "+70917274239"}
0005433293369	C09DF5	2209 713210	IRINA SAVELEVA	{"email": "irina_saveleva12011957@postgrespro.ru", "phone": "+70234263207"}
0005433293370	C09DF5	9752 619680	RAISA ARKHIPOVA	{"phone": "+70894645532"}
0005433293371	2AE0E3	8771 447051	NATALYA SERGEEVA	{"email": "natalya-sergeeva.1970@postgrespro.ru", "phone": "+70732115030"}
0005433293372	2AE0E3	2024 329576	DMITRIY KUDRYASHOV	{"phone": "+70269099708"}
0005433293373	A4A0FF	5411 141651	EKATERINA ZHURAVLEVA	{"email": "ekaterina-zhuravleva011969@postgrespro.ru", "phone": "+70646191125"}
0005433293374	E32312	7797 452132	INNA MIKHAYLOVA	{"email": "mikhaylova.i_07011976@postgrespro.ru", "phone": "+70661915863"}
0005433293375	9E2BE1	7730 126523	TATYANA TIMOFEEVA	{"phone": "+70585795800"}
0005433293376	7CB83B	5788 157006	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir_05081976@postgrespro.ru", "phone": "+70916433934"}
0005433293377	7CB83B	4186 394117	MIKHAIL SEMENOV	{"email": "semenov.mikhail.021978@postgrespro.ru", "phone": "+70049508527"}
0005433293378	7790F7	9594 406786	NATALYA GAVRILOVA	{"email": "n_gavrilova16021977@postgrespro.ru", "phone": "+70827046187"}
0005433293379	60214C	7177 595526	TATYANA ANDREEVA	{"phone": "+70179876461"}
0005433293380	60214C	0366 897129	ARINA YAKOVLEVA	{"email": "arina.yakovleva_31121968@postgrespro.ru", "phone": "+70462615406"}
0005433293381	60214C	9391 796303	VYACHESLAV NIKITIN	{"email": "vyacheslav_nikitin_1965@postgrespro.ru", "phone": "+70382505863"}
0005433293382	FE0CBC	3637 287120	ALEKSANDR RODIONOV	{"email": "rodionovaleksandr.1960@postgrespro.ru", "phone": "+70253956431"}
0005433293383	FE0CBC	3212 499205	ALEKSANDR KARPOV	{"phone": "+70562952959"}
0005433293384	A79E2E	6582 370243	SVETLANA FEDOROVA	{"email": "fedorovasvetlana121966@postgrespro.ru", "phone": "+70632712606"}
0005433293385	F68328	4720 451404	ALEKSANDR KUZMIN	{"phone": "+70490555581"}
0005433293386	B1AFDF	7158 416014	OLGA TARASOVA	{"phone": "+70353829546"}
0005433293387	74A8A3	0404 153245	NADIYA KAZAKOVA	{"email": "kazakovanadiya.04041968@postgrespro.ru", "phone": "+70557634535"}
0005433293388	74A8A3	9978 968921	TATYANA KUDRYASHOVA	{"email": "kudryashova.tatyana.16121979@postgrespro.ru", "phone": "+70452266717"}
0005433293389	03C791	5376 683705	NINA VOROBEVA	{"phone": "+70795035634"}
0005433293390	03C791	8161 390116	EVGENIY AFANASEV	{"email": "eafanasev-28091971@postgrespro.ru", "phone": "+70945287100"}
0005433293391	7594C7	6231 564453	VYACHESLAV EGOROV	{"email": "egorov.v.1965@postgrespro.ru", "phone": "+70533376695"}
0005433293392	AE0FA4	0374 674771	VALERIY STEPANOV	{"email": "valeriy.stepanov18061970@postgrespro.ru", "phone": "+70171914092"}
0005433293393	AE0FA4	8455 662076	OLEG VASILEV	{"email": "ovasilev1963@postgrespro.ru", "phone": "+70301302131"}
0005433293394	23D331	0193 564748	LYUDMILA SAVELEVA	{"email": "lyudmila.saveleva-1965@postgrespro.ru", "phone": "+70425795555"}
0005433293395	23D331	5654 970299	OLESYA KRASNOVA	{"phone": "+70124122744"}
0005433293396	818767	6277 386483	DMITRIY BARANOV	{"phone": "+70048693407"}
0005433293397	B233A4	9363 583505	NIKOLAY ZAKHAROV	{"email": "zakharov.n06031977@postgrespro.ru", "phone": "+70518411647"}
0005433293398	9610FB	2305 318995	MARINA SOROKINA	{"email": "marina.sorokina.021970@postgrespro.ru", "phone": "+70232029230"}
0005433293399	9610FB	3449 882713	SERGEY SEMENOV	{"phone": "+70667958166"}
0005433293400	ADBDC4	7588 400599	VIKTORIYA KUZNECOVA	{"email": "kuznecovav30121971@postgrespro.ru", "phone": "+70351756161"}
0005433293401	8ED13E	3249 880269	ANDREY ALEKSANDROV	{"email": "aleksandrov-andrey.1971@postgrespro.ru", "phone": "+70056183782"}
0005433293402	A9C0CC	0325 344612	IVAN MAKAROV	{"email": "ivan-makarov30101962@postgrespro.ru", "phone": "+70587847369"}
0005433293403	56E6DC	3893 361505	NIKOLAY SEMENOV	{"email": "nikolaysemenov_1973@postgrespro.ru", "phone": "+70037257730"}
0005433293404	731B9B	4639 415509	VITALIY SMIRNOV	{"email": "vitaliy.smirnov.08041965@postgrespro.ru", "phone": "+70388097529"}
0005433293405	CFF1AF	6389 539923	SOFYA PETROVA	{"phone": "+70151282879"}
0005433293406	63F766	8003 343036	ANATOLIY NOVIKOV	{"email": "anatoliy.novikov-1962@postgrespro.ru", "phone": "+70819838539"}
0005433293407	45F2EB	3731 854662	IRINA RODIONOVA	{"phone": "+70218120399"}
0005433293408	2BEE35	4825 107300	VLADIMIR SOROKIN	{"email": "sorokin_v08061972@postgrespro.ru", "phone": "+70306177628"}
0005433341399	8B9578	1477 184878	MARIYA ALEKSEEVA	{"phone": "+70147425809"}
0005433293409	6939B7	0562 487423	ELENA PETROVA	{"email": "petrova_e.09111976@postgrespro.ru", "phone": "+70182016945"}
0005433293410	D4EDFD	9557 638644	VLADIMIR FILIPPOV	{"email": "vladimir-filippov1967@postgrespro.ru", "phone": "+70150931226"}
0005433293411	8AD998	1132 416402	OLGA NOVIKOVA	{"phone": "+70558764020"}
0005433293412	4C51E0	9048 727153	VALERIY BONDARENKO	{"phone": "+70380317353"}
0005433293413	4C51E0	3034 634487	PETR IVANOV	{"email": "petr_ivanov16071968@postgrespro.ru", "phone": "+70201926515"}
0005433293414	FFE5EF	6743 166001	ALEKSANDR MAKSIMOV	{"phone": "+70048357449"}
0005433293415	6F63A6	2671 234480	ALEKSANDR KARPOV	{"email": "a.karpov.1975@postgrespro.ru", "phone": "+70637204382"}
0005433293416	6F63A6	1546 553066	MARGARITA STEPANOVA	{"email": "stepanovamargarita28121977@postgrespro.ru", "phone": "+70599148197"}
0005433293417	6F63A6	4494 173191	ALEKSANDR ANDREEV	{"email": "andreevaleksandr-1979@postgrespro.ru", "phone": "+70905463632"}
0005433293418	D1DE8D	5958 108702	LYUBOV NIKITINA	{"email": "lyubov_nikitina1963@postgrespro.ru", "phone": "+70959452371"}
0005433293419	DC7953	6461 706117	ALEKSEY RODIONOV	{"phone": "+70256083524"}
0005433293420	FB26BF	9983 472924	IRINA GORBUNOVA	{"phone": "+70189352065"}
0005433293421	CF8934	0990 825393	TAMARA BELOVA	{"phone": "+70727696860"}
0005433293422	4C76E4	2818 782717	TAMARA CHERNOVA	{"email": "chernova.t1964@postgrespro.ru", "phone": "+70009330209"}
0005433293423	177FD1	6919 615801	VITALIY ANTONOV	{"email": "antonov_vitaliy_1963@postgrespro.ru", "phone": "+70084519350"}
0005433293424	177FD1	8673 683130	DANILA KUZNECOV	{"email": "danila_kuznecov.10111974@postgrespro.ru", "phone": "+70400885083"}
0005433293425	756ED9	8484 582043	SVETLANA KULIKOVA	{"phone": "+70897749727"}
0005433293426	CBA67F	1514 437648	NELLI TARASOVA	{"email": "n_tarasova-1975@postgrespro.ru", "phone": "+70617255755"}
0005433293427	E524A7	6178 145741	ANDREY ANDREEV	{"email": "andreev_andrey04021975@postgrespro.ru", "phone": "+70379824418"}
0005433293428	2F5DE8	9848 530862	GALINA PETROVA	{"phone": "+70694274438"}
0005433293429	121A0F	8259 411591	VALERIYA CHERNOVA	{"email": "valeriyachernova1965@postgrespro.ru", "phone": "+70735314780"}
0005433293430	9A13C5	3624 361086	NATALYA ALEKSEEVA	{"phone": "+70106775925"}
0005433293431	9A13C5	6368 149939	ARTEM ROMANOV	{"email": "romanov-artem12051967@postgrespro.ru", "phone": "+70041842142"}
0005433293432	270380	1309 472292	KARINA ANDREEVA	{"email": "karinaandreeva_041977@postgrespro.ru", "phone": "+70009822033"}
0005433293433	625482	8001 213888	MIKHAIL FEDOROV	{"phone": "+70575085593"}
0005433293434	BCF0E1	0446 920908	ALEKSANDR BELOV	{"email": "belov.a28021976@postgrespro.ru", "phone": "+70848885379"}
0005433293435	3D0FB3	4904 850716	ANTON POPOV	{"email": "popov.anton_21121975@postgrespro.ru", "phone": "+70347748659"}
0005433293436	6B336B	4321 744161	VIKTOR FROLOV	{"phone": "+70814433421"}
0005433293437	BAFA31	0451 082095	ALFIYA FILATOVA	{"phone": "+70208375953"}
0005433293438	42F0EA	2798 837521	LYUBOV TIMOFEEVA	{"email": "timofeeva_lyubov_1974@postgrespro.ru", "phone": "+70780242517"}
0005433293439	9B1CA4	3388 561975	TATYANA VLASOVA	{"email": "vlasova_tatyana_1968@postgrespro.ru", "phone": "+70430098747"}
0005433293440	81E9C7	3149 447657	TATYANA VLASOVA	{"phone": "+70167754445"}
0005433293441	81E9C7	7247 184858	ALLA SEMENOVA	{"phone": "+70896821537"}
0005433293442	8C00C3	7033 356565	OLGA BELOVA	{"phone": "+70791452879"}
0005433293443	7A3E96	9866 241246	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr1965@postgrespro.ru", "phone": "+70622533751"}
0005433293444	798B21	1929 469822	DMITRIY VASILEV	{"phone": "+70282627217"}
0005433341469	9006AC	1297 569792	NATALYA BOGDANOVA	{"phone": "+70387560146"}
0005433341378	2F6502	0050 575032	ALEKSANDR PETROV	{"email": "petrov-a.12101980@postgrespro.ru", "phone": "+70994799806"}
0005433341379	2F6502	8296 276128	NIKOLAY MELNIKOV	{"phone": "+70978063896"}
0005433341380	6DE4FD	1388 156266	VLADIMIR SAVELEV	{"phone": "+70273904951"}
0005433341381	6DE4FD	9040 716541	VIKTOR GUSEV	{"email": "gusev_v021975@postgrespro.ru", "phone": "+70770452820"}
0005433341382	1D760A	2383 152682	IRINA POLYAKOVA	{"email": "i_polyakova-1984@postgrespro.ru", "phone": "+70238522374"}
0005433341383	1D760A	7512 919413	VALERIY MOROZOV	{"phone": "+70011618181"}
0005433341384	A9E30D	8202 745570	VLADIMIR IVANOV	{"email": "vladimirivanov_1970@postgrespro.ru", "phone": "+70365946031"}
0005433341385	9F7DEE	2120 918193	VLADIMIR PAVLOV	{"email": "pavlov_v_22031971@postgrespro.ru", "phone": "+70816185702"}
0005433341386	29EE25	6906 443132	YURIY KUZNECOV	{"email": "ykuznecov.1963@postgrespro.ru", "phone": "+70836200563"}
0005433341387	29EE25	6028 083756	INNA IVANOVA	{"email": "inna-ivanova-051970@postgrespro.ru", "phone": "+70878965591"}
0005433341388	AFA556	3550 557262	VALERIY POPOV	{"email": "valeriypopov.1972@postgrespro.ru", "phone": "+70380723308"}
0005433341389	F82A4A	8086 633344	SERGEY SOLOVEV	{"email": "s-solovev1979@postgrespro.ru", "phone": "+70015645408"}
0005433341390	F82A4A	7304 270621	IRINA MEDVEDEVA	{"phone": "+70267118548"}
0005433341391	D08B9B	1311 318884	NIKITA BONDARENKO	{"email": "n-bondarenko-121968@postgrespro.ru", "phone": "+70752480370"}
0005433341392	1F0D69	6364 176787	NIKOLAY IVANOV	{"email": "nikolay.ivanov_071963@postgrespro.ru", "phone": "+70899817987"}
0005433341393	1F0D69	1763 583639	NATALYA PAVLOVA	{"email": "n_pavlova041985@postgrespro.ru", "phone": "+70529110667"}
0005433341394	1F0D69	8553 530149	DMITRIY MAKAROV	{"email": "d.makarov_091973@postgrespro.ru", "phone": "+70895374213"}
0005433341395	170D43	9704 220398	TATYANA MASLOVA	{"email": "maslova_tatyana_19041967@postgrespro.ru", "phone": "+70045010702"}
0005433341396	C66313	1514 480196	IVAN FEDOROV	{"email": "fedorov.i-1975@postgrespro.ru", "phone": "+70623124864"}
0005433341397	0C7F3E	2553 742147	ANNA NIKIFOROVA	{"email": "nikiforova-anna-1975@postgrespro.ru", "phone": "+70655033032"}
0005433341398	0C7F3E	9168 947723	VLADIMIR MOISEEV	{"phone": "+70366334343"}
0005433341400	E5CDD9	9099 750837	NATALYA KULIKOVA	{"phone": "+70691116172"}
0005433341401	892E05	6533 265005	SOFIYA KONDRATEVA	{"phone": "+70344288792"}
0005433341402	C8FDA2	5015 397757	ALINA GAVRILOVA	{"phone": "+70992809043"}
0005433341403	8A4525	4227 211177	OLGA RODIONOVA	{"phone": "+70982413899"}
0005433341404	F64B85	8923 820556	ALEKSANDR PETROV	{"phone": "+70152890616"}
0005433341405	CA0639	8857 159003	YURIY MEDVEDEV	{"phone": "+70810111363"}
0005433341406	CA0639	3151 666657	TATYANA EGOROVA	{"email": "t-egorova-041968@postgrespro.ru", "phone": "+70435095954"}
0005433341407	D457E6	4854 755796	MIKHAIL ABRAMOV	{"phone": "+70875175413"}
0005433341408	10FB80	9020 735016	POLINA DMITRIEVA	{"phone": "+70229742669"}
0005433341409	10FB80	0474 357502	EGOR SMIRNOV	{"email": "smirnov.egor_08101966@postgrespro.ru", "phone": "+70035634611"}
0005433341410	10FB80	2398 524677	VASILIY IVANOV	{"email": "v-ivanov-1966@postgrespro.ru", "phone": "+70270092629"}
0005433341411	B6F5FD	8606 342767	ALEKSANDR MAKSIMOV	{"email": "maksimova.08051970@postgrespro.ru", "phone": "+70299662476"}
0005433341412	3F3949	8564 078639	VLADIMIR VASILEV	{"phone": "+70830691414"}
0005433341413	D584A2	4829 868212	OLGA SIDOROVA	{"email": "sidorovao.101982@postgrespro.ru", "phone": "+70574453620"}
0005433341414	B1DF14	5194 232834	ALEKSANDR DENISOV	{"email": "a-denisov-17011978@postgrespro.ru", "phone": "+70638027196"}
0005433341415	47C5FC	8663 675362	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov_09041962@postgrespro.ru", "phone": "+70594283536"}
0005433341416	7EEC53	8973 916617	DENIS ORLOV	{"phone": "+70398998123"}
0005433341417	07BF15	1887 966323	NIKOLAY POPOV	{"email": "popov.nikolay051966@postgrespro.ru", "phone": "+70111505608"}
0005433341418	4F2844	9122 137077	NIKOLAY SEMENOV	{"email": "n_semenov_021987@postgrespro.ru", "phone": "+70183700460"}
0005433341419	058761	4542 547437	MARIYA MIRONOVA	{"phone": "+70417802028"}
0005433341420	058761	2534 914042	FARID KARPOV	{"email": "f.karpov_08041982@postgrespro.ru", "phone": "+70547773655"}
0005433341421	5C4428	6390 599420	GENNADIY MOISEEV	{"phone": "+70114808253"}
0005433341422	5C4428	3119 416363	ANNA MALYSHEVA	{"email": "amalysheva-021979@postgrespro.ru", "phone": "+70558244517"}
0005433341423	5C4428	3287 233667	FATYMA KUZNECOVA	{"phone": "+70496023632"}
0005433341424	C28BB7	9982 641392	GULFIYA KUZNECOVA	{"phone": "+70194346491"}
0005433341425	C28BB7	3988 444010	DMITRIY SEMENOV	{"email": "semenov-dmitriy.101980@postgrespro.ru", "phone": "+70562378774"}
0005433341426	628B38	1011 881628	ALEKSANDR BARANOV	{"email": "aleksandrbaranov-1956@postgrespro.ru", "phone": "+70932595334"}
0005433341427	628B38	1412 480100	ELENA PETROVA	{"email": "elena-petrova.04091975@postgrespro.ru", "phone": "+70084680659"}
0005433341428	78B38A	5972 184562	ALEKSEY FILIPPOV	{"email": "aleksey.filippov-031972@postgrespro.ru", "phone": "+70086622891"}
0005433341429	78B38A	8042 541888	SVETLANA FOMINA	{"phone": "+70407695904"}
0005433341430	111106	8293 442986	EKATERINA FILIPPOVA	{"email": "filippova_e_1968@postgrespro.ru", "phone": "+70446252004"}
0005433341431	56EE0B	4027 145008	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova-1973@postgrespro.ru", "phone": "+70643484510"}
0005433341432	0FC96C	1016 726944	VLADIMIR BORISOV	{"email": "borisov-vladimir-071980@postgrespro.ru", "phone": "+70375971632"}
0005433341433	81684D	5630 662173	LIDIYA KAZAKOVA	{"email": "kazakova_lidiya-28121970@postgrespro.ru", "phone": "+70627129806"}
0005433341434	81684D	8746 498247	FAIL GUSEV	{"phone": "+70393824342"}
0005433341435	1655DE	2355 422438	ANTON MELNIKOV	{"phone": "+70145126469"}
0005433341436	1655DE	1785 982949	GENNADIY MOROZOV	{"phone": "+70983253606"}
0005433341437	B57EFF	6260 183429	NADEZHDA RODIONOVA	{"email": "rodionovan021966@postgrespro.ru", "phone": "+70308377514"}
0005433341438	9E1D19	2003 861160	ANTON MEDVEDEV	{"phone": "+70328166167"}
0005433341439	3BC95B	2332 313217	SERGEY EGOROV	{"phone": "+70069114943"}
0005433341440	F3B158	7967 989439	VITALIY MAKAROV	{"email": "vitaliymakarov.25071979@postgrespro.ru", "phone": "+70252158837"}
0005433341441	037912	3667 968477	RAMIL VLASOV	{"email": "vlasov_r031963@postgrespro.ru", "phone": "+70659600174"}
0005433341442	036B6E	4705 973320	AYRAT SIDOROV	{"phone": "+70837442772"}
0005433341443	3EE601	9097 032383	STEPAN SERGEEV	{"email": "sergeevstepan_101976@postgrespro.ru", "phone": "+70442248725"}
0005433341444	BC4FFB	8335 917305	KONSTANTIN PAVLOV	{"email": "konstantin_pavlov.26021980@postgrespro.ru", "phone": "+70409883802"}
0005433341445	BC4FFB	5377 189540	NIKOLAY SOROKIN	{"email": "nsorokin1975@postgrespro.ru", "phone": "+70915866827"}
0005433341446	EAA15E	5803 475602	ANDREY MIKHAYLOV	{"phone": "+70649871562"}
0005433341447	EAA15E	4780 618246	EVGENIYA KAZAKOVA	{"email": "evgeniya_kazakova.10051980@postgrespro.ru", "phone": "+70923017812"}
0005433341448	1176C7	7040 665701	ALEKSANDR ZHURAVLEV	{"phone": "+70078178602"}
0005433341449	1176C7	8391 408273	ANDREY STEPANOV	{"email": "stepanovandrey081973@postgrespro.ru", "phone": "+70988879365"}
0005433341450	B97B7A	1159 766083	SVETLANA MAKAROVA	{"email": "makarova_s.041976@postgrespro.ru", "phone": "+70138383665"}
0005433341451	B97B7A	1183 236827	BOGDAN GRIGOREV	{"phone": "+70390240614"}
0005433341452	0F5263	1825 579554	LYUBOV ANTONOVA	{"phone": "+70183339231"}
0005433341453	0F5263	3619 828820	SVETLANA KAZAKOVA	{"phone": "+70323254346"}
0005433341454	7A392D	2785 592651	YURIY TIKHONOV	{"phone": "+70219165835"}
0005433341455	2D260E	3356 720630	TATYANA ISAEVA	{"phone": "+70000042194"}
0005433341456	47D2BF	3561 304169	ALEKSANDR ZAYCEV	{"email": "a.zaycev091970@postgrespro.ru", "phone": "+70872950266"}
0005433341457	26CEAA	8122 824162	KRISTINA FROLOVA	{"email": "frolova_kristina_17081972@postgrespro.ru", "phone": "+70407873653"}
0005433341458	652848	1633 635650	ILYA MAKAROV	{"phone": "+70270711513"}
0005433341459	652848	6162 553472	TATYANA MIRONOVA	{"email": "t-mironova_1968@postgrespro.ru", "phone": "+70388376176"}
0005433341460	9E5742	1852 205632	ANDREY POPOV	{"email": "popov_andrey.1974@postgrespro.ru", "phone": "+70134595704"}
0005433341461	267D06	8344 616298	ELENA ANTONOVA	{"phone": "+70668693028"}
0005433341462	548236	4677 059191	YURIY PETROV	{"phone": "+70154168602"}
0005433341463	EADE7E	4583 058556	EVGENIY SCHERBAKOV	{"phone": "+70336281551"}
0005433341464	EADE7E	4461 075022	SERGEY ZAKHAROV	{"phone": "+70436687199"}
0005433341465	4364F4	1367 218419	SERGEY VOLKOV	{"phone": "+70759938850"}
0005433341466	4364F4	3240 821046	NADEZHDA ROMANOVA	{"email": "nadezhda.romanova1971@postgrespro.ru", "phone": "+70367829523"}
0005433341467	1D86C7	8761 304979	ALEKSANDR FOMIN	{"phone": "+70150129010"}
0005433341468	1D86C7	3288 653370	DANIIL ILIN	{"email": "daniililin_1975@postgrespro.ru", "phone": "+70499456191"}
0005433341470	9006AC	6202 816810	GENNADIY ZHURAVLEV	{"email": "g_zhuravlev_06121975@postgrespro.ru", "phone": "+70875461943"}
0005433341471	0085F5	6697 017135	ALEKSEY VASILEV	{"phone": "+70840186643"}
0005433341472	8639B7	7424 183176	OLEG GORBUNOV	{"phone": "+70415613031"}
0005433341473	989935	6425 980466	EKATERINA VASILEVA	{"email": "vasileva-e01021976@postgrespro.ru", "phone": "+70207624599"}
0005433341474	3EA25E	8619 747473	NADEZHDA KUZMINA	{"phone": "+70778626350"}
0005433341475	3EA25E	4011 876138	ALEKSANDR TIKHONOV	{"phone": "+70547624803"}
0005433341476	2576DC	7302 609236	ELENA MASLOVA	{"phone": "+70691223123"}
0005433341477	02660A	9902 879515	ANATOLIY VOROBEV	{"email": "vorobev.a.1969@postgrespro.ru", "phone": "+70672480250"}
0005433341478	879E39	0888 208318	LIDIYA BOGDANOVA	{"phone": "+70143209212"}
0005433341479	570459	2412 735362	NONNA PAVLOVA	{"email": "npavlova.121956@postgrespro.ru", "phone": "+70498164128"}
0005433341480	2BCD70	5450 455565	VIKTORIYA SOLOVEVA	{"email": "solovevav_041970@postgrespro.ru", "phone": "+70282763419"}
0005433341481	2BCD70	3301 036094	DMITRIY SIDOROV	{"email": "dmitriy-sidorov-071974@postgrespro.ru", "phone": "+70790909794"}
0005433341482	E89151	6949 379056	SERGEY ANTONOV	{"phone": "+70830929108"}
0005433341483	E89151	6391 788111	VALENTINA KOVALEVA	{"email": "v-kovaleva.011972@postgrespro.ru", "phone": "+70843231633"}
0005433341484	D87A14	6334 128418	LYUDMILA EGOROVA	{"phone": "+70701546019"}
0005433341485	D87A14	2161 017745	DMITRIY MIRONOV	{"email": "dmitriy.mironov05071976@postgrespro.ru", "phone": "+70697413180"}
0005433341486	56CE1D	5306 063761	KSENIYA NIKOLAEVA	{"phone": "+70900036294"}
0005433341487	C982BD	0327 005968	EKATERINA KAZAKOVA	{"phone": "+70634251501"}
0005433341488	93D41F	8134 028577	ALENA KARPOVA	{"phone": "+70076877428"}
0005433341489	FD4242	0048 518592	LYUBOV MIKHAYLOVA	{"email": "mikhaylova.l_15021979@postgrespro.ru", "phone": "+70033957344"}
0005433341490	FD4242	9109 306298	NATALYA AKIMOVA	{"phone": "+70274648369"}
0005433341491	E01C2A	9241 772085	ELMIRA ZAYCEVA	{"email": "zayceva-elmira22061968@postgrespro.ru", "phone": "+70134174489"}
0005433341492	1858B4	3838 037855	TATYANA SOKOLOVA	{"email": "tatyanasokolova02111970@postgrespro.ru", "phone": "+70941803170"}
0005433341493	7ED13B	6695 685616	FARIDA SCHERBAKOVA	{"email": "farida.scherbakova.17041970@postgrespro.ru", "phone": "+70761468198"}
0005433341494	0BB711	9917 283064	ALEKSANDR ZHUKOV	{"phone": "+70399821004"}
0005433341495	0BB711	3649 238449	ELENA ILINA	{"phone": "+70116196187"}
0005433341496	0BB711	3352 623543	VLADISLAV TIKHONOV	{"email": "tikhonov_vladislav021949@postgrespro.ru", "phone": "+70893619080"}
0005433341497	D1C111	1104 325757	VLADIMIR PAVLOV	{"email": "pavlov_v.021979@postgrespro.ru", "phone": "+70879272630"}
0005433341498	D1C111	5209 693344	OLGA GRISHINA	{"email": "grishina-o011970@postgrespro.ru", "phone": "+70357636549"}
0005433341499	371DD3	7226 965411	IRINA KULIKOVA	{"phone": "+70107840581"}
0005433341500	E7BF52	2146 188093	OLGA SIDOROVA	{"phone": "+70424032129"}
0005433341501	F8A6B8	3042 049721	ANDREY DENISOV	{"email": "denisov.andrey-1968@postgrespro.ru", "phone": "+70530137388"}
0005433341502	F8A6B8	6831 011880	KSENIYA ALEKSANDROVA	{"email": "kseniyaaleksandrova-1969@postgrespro.ru", "phone": "+70600330799"}
0005433341503	E79179	7309 664475	SVETLANA NIKITINA	{"email": "s.nikitina07071967@postgrespro.ru", "phone": "+70470092988"}
0005433341504	E79179	7390 772795	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov-111967@postgrespro.ru", "phone": "+70831373539"}
0005433341505	683B2A	9240 198982	VASILIY NIKOLAEV	{"email": "nikolaevvasiliy_021970@postgrespro.ru", "phone": "+70232578456"}
0005433341506	65020D	5095 127671	ANATOLIY ANDREEV	{"email": "andreevanatoliy_101968@postgrespro.ru", "phone": "+70831358429"}
0005433341507	65020D	2662 480814	ANASTASIYA MALYSHEVA	{"phone": "+70473416214"}
0005433341508	993E20	3146 068519	ZAKHAR ANTONOV	{"phone": "+70375578745"}
0005433341509	A42E80	7387 791569	ALEKSEY KARPOV	{"email": "a.karpov1977@postgrespro.ru", "phone": "+70966600092"}
0005433341510	86493B	8995 114109	SERGEY ROMANOV	{"phone": "+70043964986"}
0005433341511	C6273A	7626 921210	ANNA YUDINA	{"email": "yudinaanna11031963@postgrespro.ru", "phone": "+70852237372"}
0005433341512	C6273A	6487 099107	TATYANA DAVYDOVA	{"phone": "+70427729226"}
0005433341513	6312ED	2760 800771	ALINA ALEKSANDROVA	{"email": "aleksandrova_alina.17111977@postgrespro.ru", "phone": "+70350840348"}
0005433341514	5B8BEB	4561 366072	TATYANA SEMENOVA	{"email": "tatyanasemenova.08031981@postgrespro.ru", "phone": "+70058250434"}
0005433341515	5B8BEB	3407 630210	VYACHESLAV ALEKSEEV	{"email": "vyacheslavalekseev-071971@postgrespro.ru", "phone": "+70035695090"}
0005433341516	071F85	6883 014945	VASILIY NIKOLAEV	{"email": "vasiliynikolaev19101976@postgrespro.ru", "phone": "+70220575811"}
0005433341517	071F85	7036 696133	ANNA OVCHINNIKOVA	{"email": "a.ovchinnikova.011973@postgrespro.ru", "phone": "+70808530291"}
0005433341518	FAE9E2	3821 904879	INNA AFANASEVA	{"email": "innaafanaseva-1967@postgrespro.ru", "phone": "+70213069051"}
0005433341519	521526	8984 978185	YULIYA BARANOVA	{"phone": "+70130820880"}
0005433341520	521526	7046 226424	VLADIMIR FEDOROV	{"email": "fedorov_vladimir_1971@postgrespro.ru", "phone": "+70902033933"}
0005433341521	230395	1262 443695	NATALYA FROLOVA	{"email": "frolova_natalya011968@postgrespro.ru", "phone": "+70160722815"}
0005433341522	A292F3	7453 275322	DMITRIY ALEKSEEV	{"phone": "+70575169833"}
0005433341523	D6CFD9	1804 363288	EKATERINA NOVIKOVA	{"email": "ekaterinanovikova-16021973@postgrespro.ru", "phone": "+70969917340"}
0005433341524	D6CFD9	3905 048239	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey.16031977@postgrespro.ru", "phone": "+70095832786"}
0005433341525	72236E	1354 084111	NATALYA VOLKOVA	{"email": "n.volkova-21101976@postgrespro.ru", "phone": "+70329818978"}
0005433341526	5FDA1F	3339 793978	ELENA VLASOVA	{"email": "e.vlasova17121971@postgrespro.ru", "phone": "+70592639735"}
0005433341527	B15063	4599 700597	EVGENIY DAVYDOV	{"email": "davydove.05111961@postgrespro.ru", "phone": "+70816863723"}
0005433341528	0AB457	9748 241428	YURIY MATVEEV	{"phone": "+70047968079"}
0005433341529	0AB457	8841 454717	MIKHAIL ZAKHAROV	{"phone": "+70622311261"}
0005433341530	F68BEF	5899 810874	SVETLANA IVANOVA	{"email": "svetlana-ivanova-1985@postgrespro.ru", "phone": "+70820954400"}
0005433341531	F68BEF	6806 594119	ANASTASIYA MELNIKOVA	{"phone": "+70998935526"}
0005433341532	A31D2B	9401 827513	ANATOLIY SMIRNOV	{"email": "smirnov-anatoliy.031970@postgrespro.ru", "phone": "+70356580193"}
0005433341533	7B9153	5963 144877	ANASTASIYA ISAEVA	{"phone": "+70898300061"}
0005433341534	A9B1F2	9554 055746	OLGA MOROZOVA	{"email": "o.morozova091980@postgrespro.ru", "phone": "+70473556631"}
0005433341535	9929CB	9680 795087	VASILIY IVANOV	{"email": "ivanovv081976@postgrespro.ru", "phone": "+70344050011"}
0005433341536	91D77F	1958 671182	FANIL VASILEV	{"phone": "+70714815637"}
0005433341537	91D77F	3467 084437	MAKSIM MAKAROV	{"phone": "+70191509290"}
0005433341538	C61538	9204 250077	PAVEL GRIGOREV	{"phone": "+70615291721"}
0005433341539	0370DF	6042 400827	VALENTINA FILATOVA	{"phone": "+70204528612"}
0005433341540	067479	3725 276581	VYACHESLAV GORBUNOV	{"phone": "+70866414420"}
0005433341541	067479	7119 085282	VLADIMIR KUZNECOV	{"phone": "+70961455311"}
0005433341542	F62AAE	9539 466520	ALEKSANDR PAVLOV	{"phone": "+70110259661"}
0005433341543	F62AAE	3171 348448	OLEG SOLOVEV	{"email": "oleg-solovev_071974@postgrespro.ru", "phone": "+70387083953"}
0005433341544	DCDC8B	3867 748736	GENNADIY MATVEEV	{"email": "gennadiy-matveev.091973@postgrespro.ru", "phone": "+70036628279"}
0005433341545	DCDC8B	2448 867231	VLADIMIR ALEKSEEV	{"phone": "+70551733712"}
0005433341546	528E9E	5015 020737	LIDIYA TIKHONOVA	{"phone": "+70498083673"}
0005433341547	528E9E	4190 999211	DENIS ABRAMOV	{"email": "denis.abramov14101977@postgrespro.ru", "phone": "+70668404291"}
0005433341548	74DC64	4662 614244	MAKSIM KOROLEV	{"phone": "+70204837359"}
0005433341549	4EC1DB	5269 071821	SERGEY MAKAROV	{"email": "sergey_makarov-1989@postgrespro.ru", "phone": "+70231291522"}
0005433341550	C8B835	2258 310856	VALENTINA KONDRATEVA	{"phone": "+70828844973"}
0005433341551	412868	3507 903694	ALEKSANDR MAKSIMOV	{"phone": "+70927519842"}
0005433341552	412868	1604 460234	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov-021967@postgrespro.ru", "phone": "+70292630414"}
0005433341553	10D3C6	6762 369423	GALINA VOROBEVA	{"phone": "+70744772432"}
0005433341554	10D3C6	3302 544439	LIDIYA LAZAREVA	{"email": "l-lazareva051960@postgrespro.ru", "phone": "+70805314174"}
0005433341555	7DFF52	7989 983540	ANTONINA FROLOVA	{"email": "frolova.a.03121967@postgrespro.ru", "phone": "+70596322171"}
0005433341556	7DFF52	6825 913880	LYUBOV TIMOFEEVA	{"phone": "+70581650818"}
0005433341557	7DFF52	6285 924675	YURIY MEDVEDEV	{"email": "yuriy-medvedev-1974@postgrespro.ru", "phone": "+70843115062"}
0005433341558	144BC8	0247 711625	KSENIYA LAZAREVA	{"phone": "+70323603789"}
0005433341559	3530BF	6601 146236	SERGEY KISELEV	{"email": "kiselevsergey.091967@postgrespro.ru", "phone": "+70598094145"}
0005433341560	1DE6AF	2809 153529	VERA KUZNECOVA	{"email": "kuznecova.v.1977@postgrespro.ru", "phone": "+70927341308"}
0005433341561	B7F3E3	3447 352879	ELENA BELOVA	{"phone": "+70694905869"}
0005433341562	52829B	3905 970070	ARTEM NIKITIN	{"email": "a.nikitin-021980@postgrespro.ru", "phone": "+70543750733"}
0005433341563	52829B	2701 199538	DMITRIY MIKHAYLOV	{"email": "mikhaylov.dmitriy_27061971@postgrespro.ru", "phone": "+70715996065"}
0005433341564	EA39DB	4011 396265	OKSANA ERMAKOVA	{"email": "ermakova-oksana_071972@postgrespro.ru", "phone": "+70007851561"}
0005433341565	5695DD	0086 304201	LARISA TIKHONOVA	{"phone": "+70039476852"}
0005433341566	F6F88C	0463 691358	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina1970@postgrespro.ru", "phone": "+70280976179"}
0005433341567	6A8305	8453 613978	EVGENIY TIMOFEEV	{"email": "timofeevevgeniy_061970@postgrespro.ru", "phone": "+70172390162"}
0005433341568	6A8305	3394 368027	MARIYA SOLOVEVA	{"email": "mariya.soloveva-011977@postgrespro.ru", "phone": "+70328896670"}
0005433341569	8B65D4	6317 353851	LYUBOV IVANOVA	{"email": "ivanova_l111978@postgrespro.ru", "phone": "+70935992543"}
0005433341570	8B65D4	7760 273312	VIKTORIYA ABRAMOVA	{"email": "abramovaviktoriya_031979@postgrespro.ru", "phone": "+70998870167"}
0005433341571	8F6266	5974 826363	ANGELINA IVANOVA	{"phone": "+70190120708"}
0005433341572	D558E7	0238 224129	INNA MASLOVA	{"phone": "+70809501449"}
0005433341573	23D006	1373 124323	ALINA MIRONOVA	{"phone": "+70738254926"}
0005433341574	AB2626	2104 190762	DMITRIY TARASOV	{"email": "tarasov-d_04111981@postgrespro.ru", "phone": "+70822282260"}
0005433341575	9B9EC2	1958 222234	SERGEY SCHERBAKOV	{"phone": "+70729206592"}
0005433341576	9B9EC2	2641 911726	ANNA FEDOROVA	{"phone": "+70523321491"}
0005433341577	957273	4200 109970	KSENIYA MOROZOVA	{"email": "kseniya-morozova-021974@postgrespro.ru", "phone": "+70829522328"}
0005433341578	957273	3991 269767	KIRILL DMITRIEV	{"email": "dmitriev_kirill04051971@postgrespro.ru", "phone": "+70939149068"}
0005433341579	EA8837	9216 994320	VASILIY IVANOV	{"phone": "+70570950778"}
0005433341580	C6A243	6736 746913	KONSTANTIN MAKSIMOV	{"email": "maksimovkonstantin.27041972@postgrespro.ru", "phone": "+70176208435"}
0005433341581	EB4C58	5895 286138	SERGEY EGOROV	{"email": "sergeyegorov-1967@postgrespro.ru", "phone": "+70457915895"}
0005433341582	EB4C58	8452 940218	ROMAN AFANASEV	{"phone": "+70263630594"}
0005433341583	DC8C41	9874 482421	VASILIY CHERNOV	{"email": "chernov.vasiliy.1967@postgrespro.ru", "phone": "+70733669841"}
0005433341584	CAECB4	4931 908556	DARYA KAZAKOVA	{"phone": "+70936102438"}
0005433341585	CAECB4	1276 059859	LYUDMILA POTAPOVA	{"email": "l-potapova.21041963@postgrespro.ru", "phone": "+70271606463"}
0005433341586	9FBAA2	7001 523465	ROZA ANDREEVA	{"phone": "+70431442774"}
0005433341587	CD3B9C	5456 961641	GALINA KISELEVA	{"phone": "+70803275837"}
0005433341588	6AD103	0894 269851	NATALYA ORLOVA	{"email": "orlova.natalya-081961@postgrespro.ru", "phone": "+70473999818"}
0005433341589	A5812C	5763 380488	ALEKSANDR IVANOV	{"email": "ivanov_a091973@postgrespro.ru", "phone": "+70008904349"}
0005433341590	5A5A8D	5922 774526	KSENIYA AFANASEVA	{"phone": "+70772677042"}
0005433341591	8465EB	1584 793296	OKSANA MATVEEVA	{"email": "matveeva.o.111973@postgrespro.ru", "phone": "+70247396962"}
0005433341592	DA066A	2447 072872	OLGA KULIKOVA	{"email": "olga_kulikova1976@postgrespro.ru", "phone": "+70697469905"}
0005433341593	C965E3	0318 250504	DANIL MAKSIMOV	{"phone": "+70092955073"}
0005433341594	C965E3	6813 185570	ROMAN ALEKSANDROV	{"email": "aleksandrovroman24091970@postgrespro.ru", "phone": "+70073882089"}
0005433341595	172812	1013 210424	RUSLAN SCHERBAKOV	{"phone": "+70429441039"}
0005433341596	2F9FED	2644 004586	VALERIY BARANOV	{"email": "baranovv-021963@postgrespro.ru", "phone": "+70922705283"}
0005433341597	BD9EF0	9364 036543	YULIYA NIKOLAEVA	{"phone": "+70981740517"}
0005433341598	BD9EF0	9568 667354	SERGEY ZAYCEV	{"email": "zaycev_sergey.22021972@postgrespro.ru", "phone": "+70111644661"}
0005433341599	0C948B	7615 144828	SVETLANA PAVLOVA	{"phone": "+70051059625"}
0005433341600	0C948B	3038 063206	VIKTOR ISAEV	{"phone": "+70253999888"}
0005433341601	A9A818	4405 795702	NATALYA ZAKHAROVA	{"email": "n_zakharova_101962@postgrespro.ru", "phone": "+70988346998"}
0005433341602	1B3AD4	1300 227363	IRINA VASILEVA	{"email": "irinavasileva02011970@postgrespro.ru", "phone": "+70828199015"}
0005433341603	937F17	6969 674656	ANDREY BORISOV	{"phone": "+70717276924"}
0005433341604	4B03C4	5817 182146	ANNA POPOVA	{"phone": "+70308252092"}
0005433341605	4B03C4	8762 323366	EVGENIY SOROKIN	{"phone": "+70384845545"}
0005433341606	0C3C0C	6407 378591	VLADIMIR IVANOV	{"phone": "+70544452562"}
0005433341607	02A20D	5134 382024	NAIL KUZMIN	{"email": "nail-kuzmin-08051972@postgrespro.ru", "phone": "+70803404597"}
0005433341608	F08076	9982 851474	GENNADIY NIKOLAEV	{"phone": "+70023085376"}
0005433341609	B34A23	6044 638855	ALEKSANDR SERGEEV	{"phone": "+70958436249"}
0005433341610	B34A23	3642 118663	NINA GAVRILOVA	{"email": "gavrilovan.13081975@postgrespro.ru", "phone": "+70803023370"}
0005433341611	07DA5A	1112 974109	VITALIY SOROKIN	{"email": "vitaliy_sorokin.081979@postgrespro.ru", "phone": "+70197265396"}
0005433341612	4548D0	9979 398388	NIKITA KUZMIN	{"phone": "+70030208005"}
0005433341613	64CD61	2760 786821	EKATERINA MOROZOVA	{"email": "morozovae-101973@postgrespro.ru", "phone": "+70996672846"}
0005433341614	64CD61	0832 159577	SERGEY VASILEV	{"phone": "+70440425271"}
0005433341615	E8DB46	7827 465735	NATALYA SOROKINA	{"email": "sorokina.n-061977@postgrespro.ru", "phone": "+70414172999"}
0005433341616	2E9F3B	0407 062733	ALLA DMITRIEVA	{"email": "dmitrieva_a_1969@postgrespro.ru", "phone": "+70184102379"}
0005433341617	2E9F3B	9521 234616	SERGEY ALEKSEEV	{"email": "alekseev_sergey-1974@postgrespro.ru", "phone": "+70452522957"}
0005433341618	91C083	4338 629294	IRINA KONDRATEVA	{"email": "kondrateva_irina.111975@postgrespro.ru", "phone": "+70588333853"}
0005433341619	91C083	6657 749691	ELENA KAZAKOVA	{"email": "kazakova.e091981@postgrespro.ru", "phone": "+70793801615"}
0005433341620	03A4FB	4686 458813	NELLI FEDOROVA	{"phone": "+70026193555"}
0005433341621	D35FEF	7466 541057	VLADIMIR ISAEV	{"phone": "+70278358441"}
0005433341622	D35FEF	7070 125435	OLGA BELYAEVA	{"phone": "+70752096659"}
0005433341623	2DF1B8	6865 859150	VLADIMIR KARPOV	{"phone": "+70398056612"}
0005433341624	DAA599	8270 342798	SVETLANA IVANOVA	{"email": "s-ivanova02121976@postgrespro.ru", "phone": "+70599875944"}
0005433341625	DAA599	6563 064507	NIKOLAY FEDOROV	{"phone": "+70304417346"}
0005433341626	A20DB8	5380 717135	ANASTASIYA GAVRILOVA	{"phone": "+70293454397"}
0005433341627	8A3045	1589 438056	LYUBOV SERGEEVA	{"email": "lyubov.sergeeva1985@postgrespro.ru", "phone": "+70579474857"}
0005433341628	8A3045	8550 748220	NINA KULIKOVA	{"phone": "+70721774980"}
0005433341629	8A3045	0711 029929	ALEKSEY SEMENOV	{"email": "a.semenov.011976@postgrespro.ru", "phone": "+70982365624"}
0005433341630	339AF3	7357 986193	ANASTASIYA KULIKOVA	{"email": "a-kulikova-12041974@postgrespro.ru", "phone": "+70481983138"}
0005433341631	95AD6D	1038 324345	LYUBOV VASILEVA	{"phone": "+70253382741"}
0005433341632	95AD6D	3117 440154	ARTEM KUZNECOV	{"email": "kuznecovartem_1976@postgrespro.ru", "phone": "+70004604257"}
0005433341633	08E94D	7343 571035	EVGENIY ROMANOV	{"email": "e.romanov.011961@postgrespro.ru", "phone": "+70079588407"}
0005433341634	5D8B28	0998 449606	TATYANA MIKHAYLOVA	{"phone": "+70139926314"}
0005433341635	AA0481	1928 897218	ALESYA ALEKSEEVA	{"email": "a_alekseeva_1966@postgrespro.ru", "phone": "+70277323936"}
0005433341636	0359EA	2110 716920	EVGENIYA SEMENOVA	{"email": "semenova-e_1969@postgrespro.ru", "phone": "+70512055625"}
0005433341637	0359EA	6643 268194	TATYANA POPOVA	{"email": "t.popova14041963@postgrespro.ru", "phone": "+70072532528"}
0005433341638	B3AB9F	5103 124060	VALENTIN BORISOV	{"phone": "+70262985997"}
0005433341639	B3AB9F	9697 327838	YULIYA MAKAROVA	{"phone": "+70073038468"}
0005433341640	157679	4503 304622	FEDOR PAVLOV	{"email": "f.pavlov.16101973@postgrespro.ru", "phone": "+70267902175"}
0005433341641	B4D7C2	9018 573217	MARIYA NAZAROVA	{"email": "mariyanazarova_1976@postgrespro.ru", "phone": "+70676787255"}
0005433341642	C26878	9478 315059	NATALIYA GRISHINA	{"phone": "+70864302302"}
0005433341643	9AFC4A	8428 968342	MIKHAIL KOZLOV	{"email": "mikhail.kozlov_03101965@postgrespro.ru", "phone": "+70715414300"}
0005433341644	A2B51F	7346 598716	DMITRIY BORISOV	{"phone": "+70541953688"}
0005433341645	A2B51F	9927 113437	SERGEY KOZLOV	{"email": "kozlovs_031972@postgrespro.ru", "phone": "+70524808071"}
0005433341646	5AB299	7370 430572	YULIYA SCHERBAKOVA	{"email": "yuliya_scherbakova.05101980@postgrespro.ru", "phone": "+70669429305"}
0005433341647	5AB299	3393 808190	ELENA PAVLOVA	{"email": "e.pavlova.031974@postgrespro.ru", "phone": "+70814391266"}
0005433341648	BBCA74	6437 158962	GALINA BORISOVA	{"email": "g_borisova-25081976@postgrespro.ru", "phone": "+70422980526"}
0005433341649	A0F8E0	4841 892812	IGOR MOISEEV	{"phone": "+70551296156"}
0005433341650	A0F8E0	2354 894055	ALEKSEY NIKITIN	{"phone": "+70198608680"}
0005433341651	E55752	7571 668633	ALEKSANDRA ANDREEVA	{"phone": "+70999656784"}
0005433341652	DD78EA	8098 624433	ALEKSANDR POPOV	{"phone": "+70684138354"}
0005433341653	4248F9	6930 711447	SERGEY ZAKHAROV	{"phone": "+70470384543"}
0005433341654	C445BA	0783 715626	VITALIY OSIPOV	{"phone": "+70479877700"}
0005433341655	868DE6	5836 666489	MAKSIM IVANOV	{"email": "m.ivanov.10041967@postgrespro.ru", "phone": "+70211687446"}
0005433341656	D679DD	6389 477320	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr_091972@postgrespro.ru", "phone": "+70974197607"}
0005433341657	13D8AB	0964 481332	IGOR KUZNECOV	{"phone": "+70895286221"}
0005433341658	13D8AB	9996 471979	NIKITA NIKOLAEV	{"phone": "+70742252171"}
0005433341659	440BDE	8696 883022	SERGEY POPOV	{"phone": "+70249085331"}
0005433341660	440BDE	2349 628390	YURIY MOROZOV	{"email": "morozov.yuriy1979@postgrespro.ru", "phone": "+70533713592"}
0005433341661	3E5F4C	8238 060751	NATALYA VOROBEVA	{"phone": "+70460291198"}
0005433341662	400210	5822 437281	DMITRIY FOMIN	{"email": "fomin_d03061977@postgrespro.ru", "phone": "+70831483583"}
0005433341663	D2E1A8	0261 813782	ELENA POLYAKOVA	{"phone": "+70527089084"}
0005433341664	1B86EC	6464 232770	VITALIY TIKHONOV	{"phone": "+70439751037"}
0005433341665	1B86EC	4723 351991	IVAN SOROKIN	{"email": "ivan.sorokin1968@postgrespro.ru", "phone": "+70357058464"}
0005433341666	C0D671	9650 482567	IGOR ANDREEV	{"phone": "+70148706395"}
0005433341667	4E004C	3813 107490	EVGENIY IVANOV	{"email": "evgeniy_ivanov.03041973@postgrespro.ru", "phone": "+70602647170"}
0005433341668	AB324A	1241 084934	ALEKSANDRA SEMENOVA	{"phone": "+70220794622"}
0005433341669	6E3AFF	8382 119028	OLGA KUZMINA	{"email": "olgakuzmina.071967@postgrespro.ru", "phone": "+70587626254"}
0005433341670	004DF7	0868 235903	ALENA SOROKINA	{"email": "sorokina_alena.16051973@postgrespro.ru", "phone": "+70063275008"}
0005433341671	339EFC	4521 318263	MAKSIM KUZMIN	{"phone": "+70489379425"}
0005433341672	1C4AB0	6315 162611	GALINA OSIPOVA	{"email": "g.osipova.1964@postgrespro.ru", "phone": "+70570220529"}
0005433341673	E78A86	5725 615849	ADELINA BELYAEVA	{"phone": "+70677010410"}
0005433341674	3FCB1F	8908 086601	RAISA GAVRILOVA	{"phone": "+70066723126"}
0005433341675	2345AE	2651 059066	VERA MIRONOVA	{"email": "v.mironova-091982@postgrespro.ru", "phone": "+70824377492"}
0005433341676	00BF4F	1542 799266	MIKHAIL SHEVCHENKO	{"email": "mikhailshevchenko_1987@postgrespro.ru", "phone": "+70343441904"}
0005433341677	00BF4F	1548 872257	NATALYA KUZMINA	{"email": "kuzmina.natalya.1977@postgrespro.ru", "phone": "+70605998195"}
0005433341678	606053	4177 687884	NATALYA OVCHINNIKOVA	{"phone": "+70531149880"}
0005433341679	AA25C9	4616 650047	ALEKSEY KUZMIN	{"email": "akuzmin-20041971@postgrespro.ru", "phone": "+70938480255"}
0005433341680	21C619	5373 652615	ANDREY VASILEV	{"phone": "+70739898710"}
0005433341681	21C619	0071 259880	ANTONINA GRISHINA	{"phone": "+70791468174"}
0005433341682	1D18B9	8004 016671	VLADIMIR SOLOVEV	{"email": "vladimir.solovev_01121971@postgrespro.ru", "phone": "+70145762314"}
0005433341683	3F852B	0998 138632	VIKTORIYA STEPANOVA	{"email": "stepanova.viktoriya.1968@postgrespro.ru", "phone": "+70028994528"}
0005433341684	B3C596	0944 360197	NIKOLAY SIDOROV	{"phone": "+70558026255"}
0005433341685	249DD9	3097 498809	ANASTASIYA ORLOVA	{"phone": "+70420800777"}
0005433341686	249DD9	6041 794849	VYACHESLAV FILIPPOV	{"phone": "+70595572654"}
0005433341687	8294BA	2329 895036	OLGA VASILEVA	{"phone": "+70079453295"}
0005433341688	8294BA	1499 318833	EVGENIY STEPANOV	{"email": "stepanovevgeniy.11031978@postgrespro.ru", "phone": "+70038509937"}
0005433341689	C3870E	0397 244358	OLGA FROLOVA	{"email": "olga-frolova081968@postgrespro.ru", "phone": "+70971834524"}
0005433341690	C3870E	9184 331291	VLADIMIR GAVRILOV	{"phone": "+70826155286"}
0005433341691	350B3C	4591 805281	ROMAN SOKOLOV	{"email": "romansokolov.19011973@postgrespro.ru", "phone": "+70629109984"}
0005433341692	350B3C	7791 325356	ANASTASIYA NIKITINA	{"email": "anastasiya.nikitina_031967@postgrespro.ru", "phone": "+70813365477"}
0005433341693	350B3C	4601 241610	ZOYA SERGEEVA	{"phone": "+70295634195"}
0005433341694	C86096	5154 212704	VALERIYA POTAPOVA	{"email": "potapova.v091968@postgrespro.ru", "phone": "+70524591376"}
0005433341695	C86096	0066 535865	ARTEM IVANOV	{"email": "artem.ivanov101973@postgrespro.ru", "phone": "+70158557266"}
0005433341696	989791	9994 802023	DIANA DENISOVA	{"email": "denisova_d09021977@postgrespro.ru", "phone": "+70286102345"}
0005433341697	989791	7232 320135	NATALYA VASILEVA	{"email": "vasileva.natalya-1970@postgrespro.ru", "phone": "+70319480432"}
0005433341698	79B6A7	6881 064493	EVGENIY ALEKSANDROV	{"email": "evgeniy.aleksandrov1986@postgrespro.ru", "phone": "+70068387746"}
0005433341699	5D1443	8977 431601	VASILIY KUZNECOV	{"phone": "+70705760678"}
0005433341700	5D1443	3184 505800	ALEKSEY ILIN	{"email": "ilin_aleksey.081982@postgrespro.ru", "phone": "+70980712834"}
0005433341701	042A93	0790 027414	ANATOLIY KUZNECOV	{"email": "a.kuznecov.1972@postgrespro.ru", "phone": "+70183206645"}
0005433341702	2E1F30	0716 922098	ELENA TROFIMOVA	{"phone": "+70609145622"}
0005433341703	195B35	9983 600365	PETR OSIPOV	{"email": "posipov_01051973@postgrespro.ru", "phone": "+70622603438"}
0005433341704	195B35	2619 999696	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov.091977@postgrespro.ru", "phone": "+70717770103"}
0005433341705	2222B5	4467 245106	LEV FOMIN	{"phone": "+70246629797"}
0005433341706	2222B5	1911 414813	INNA KOLESNIKOVA	{"phone": "+70866458254"}
0005433341707	FACA69	7353 479700	ANASTASIYA KOVALEVA	{"phone": "+70856694121"}
0005433341708	C792A7	5965 487889	GENNADIY KAZAKOV	{"email": "g-kazakov_22111976@postgrespro.ru", "phone": "+70226656103"}
0005433341709	E1DC37	6683 082005	SERGEY KONOVALOV	{"email": "sergey.konovalov071977@postgrespro.ru", "phone": "+70940116266"}
0005433341710	EAFEFA	2581 130880	NADEZHDA SOROKINA	{"email": "sorokina-nadezhda12051976@postgrespro.ru", "phone": "+70536571997"}
0005433341711	7C158F	9358 128193	RAISA PAVLOVA	{"phone": "+70268631662"}
0005433341712	7C158F	7779 508171	SERGEY TIKHONOV	{"email": "stikhonov_27071982@postgrespro.ru", "phone": "+70910142942"}
0005433341713	77B527	2535 310838	ANATOLIY TIKHONOV	{"email": "tikhonov_anatoliy_011972@postgrespro.ru", "phone": "+70063227208"}
0005433341714	77B527	6421 298431	LILIYA NOVIKOVA	{"email": "l-novikova.1973@postgrespro.ru", "phone": "+70520393678"}
0005433341715	DAED27	1539 180697	VLADIMIR ZAKHAROV	{"phone": "+70928470355"}
0005433341716	AB219E	1277 606570	RUSTAM FILIPPOV	{"phone": "+70436338489"}
0005433341717	C9C94D	1590 658258	ANATOLIY YAKOVLEV	{"email": "yakovlev_anatoliy_27101954@postgrespro.ru", "phone": "+70345884386"}
0005433341718	4CF251	4463 288855	ELENA GRISHINA	{"email": "grishina-e.1975@postgrespro.ru", "phone": "+70555574282"}
0005433341719	401140	6470 038408	NATALYA MASLOVA	{"email": "maslova_natalya.071972@postgrespro.ru", "phone": "+70871423834"}
0005433341720	401140	1818 143862	VIKTOR FEDOROV	{"email": "viktorfedorov-1968@postgrespro.ru", "phone": "+70690796853"}
0005433341721	59D05B	9763 193340	OLGA EGOROVA	{"phone": "+70547489570"}
0005433341722	9F13BD	0440 399783	LYUBOV GERASIMOVA	{"email": "gerasimova_lyubov_101975@postgrespro.ru", "phone": "+70864655529"}
0005433341723	9F13BD	0235 558309	ALEKSEY CHERNOV	{"phone": "+70805466911"}
0005433341724	11DF22	5048 110119	ANNA MIKHAYLOVA	{"phone": "+70648214967"}
0005433341725	11DF22	4058 122894	YULIYA SOLOVEVA	{"phone": "+70590260128"}
0005433341726	A409E7	4302 485206	OLGA VASILEVA	{"email": "vasileva-olga-051969@postgrespro.ru", "phone": "+70968960950"}
0005433341727	1F5A84	8319 800655	IGOR ZAKHAROV	{"phone": "+70638499089"}
0005433341728	1F5A84	7488 457046	ALEKSANDR PETROV	{"email": "a_petrov_27091962@postgrespro.ru", "phone": "+70583784170"}
0005433341729	F07631	1531 838865	ELMIRA ZAKHAROVA	{"phone": "+70005806606"}
0005433341730	0FE2A2	5252 838755	LARISA KUZNECOVA	{"email": "kuznecova_larisa_1962@postgrespro.ru", "phone": "+70461031388"}
0005433341731	BF6A42	6321 464478	NIKOLAY CHERNOV	{"phone": "+70622376093"}
0005433341732	680FB5	1079 831526	OLGA MAKAROVA	{"phone": "+70893698543"}
0005433341733	26199C	2088 853472	MATVEY FILIPPOV	{"email": "filippov.matvey111976@postgrespro.ru", "phone": "+70845600843"}
0005433341734	2BFBBC	5838 292923	LYUDMILA ILINA	{"phone": "+70812029384"}
0005433341735	78BB68	3725 944373	LYUDMILA TITOVA	{"email": "titova_l.121976@postgrespro.ru", "phone": "+70277841128"}
0005433341736	78BB68	0049 606600	IRINA KONDRATEVA	{"phone": "+70246145886"}
0005433341737	E56F4E	9031 905877	ANZHELA KUZMINA	{"phone": "+70465023852"}
0005433341738	521C09	9237 564510	SVETLANA TROFIMOVA	{"email": "trofimovas_1960@postgrespro.ru", "phone": "+70911140489"}
0005433341739	6E1D50	1028 674291	SERGEY SCHERBAKOV	{"email": "scherbakov-s_091982@postgrespro.ru", "phone": "+70951974905"}
0005433341740	6E1D50	3608 714814	SERGEY GAVRILOV	{"phone": "+70797893478"}
0005433341741	E5E0AF	5198 486183	SVETLANA PETROVA	{"phone": "+70953424025"}
0005433341742	E5E0AF	6932 574264	SVETLANA POLYAKOVA	{"email": "spolyakova1958@postgrespro.ru", "phone": "+70012933683"}
0005433341743	A2B20E	5314 692226	MARINA NIKOLAEVA	{"phone": "+70783679457"}
0005433341744	20B317	4854 368339	DAVID EGOROV	{"phone": "+70253806132"}
0005433341745	20B317	2288 475279	VLADIMIR GAVRILOV	{"email": "v-gavrilov.15101970@postgrespro.ru", "phone": "+70282668524"}
0005433341746	20B317	4022 966754	YURIY DAVYDOV	{"email": "yuriy.davydov09051973@postgrespro.ru", "phone": "+70162927474"}
0005433341747	BB336D	8988 278362	VITALIY YAKOVLEV	{"phone": "+70254553339"}
0005433341748	BB336D	8962 156213	KONSTANTIN DMITRIEV	{"phone": "+70192999866"}
0005433341749	F0D99B	7446 533365	IRINA ORLOVA	{"email": "i_orlova.15031972@postgrespro.ru", "phone": "+70614552593"}
0005433341750	FC2793	9162 576812	SOFYA MIRONOVA	{"email": "sofyamironova_29011977@postgrespro.ru", "phone": "+70644445435"}
0005433341751	05927B	6064 294509	VALENTINA TIMOFEEVA	{"phone": "+70543635520"}
0005433341752	05927B	4394 331072	MAYA KARPOVA	{"email": "m_karpova-14071970@postgrespro.ru", "phone": "+70141949609"}
0005433341753	37A7D7	8441 516006	VIKTORIYA KOROLEVA	{"email": "koroleva-v15111979@postgrespro.ru", "phone": "+70258744883"}
0005433341754	42A11A	2272 730250	FAINA GERASIMOVA	{"phone": "+70753209344"}
0005433341755	42A11A	4371 382569	ANDREY MIKHAYLOV	{"phone": "+70864481078"}
0005433341756	4677D0	4394 211271	GALIYA NIKOLAEVA	{"email": "nikolaeva-g.19111978@postgrespro.ru", "phone": "+70928712426"}
0005433341757	DE147D	1249 011776	VALERIYA PETROVA	{"email": "petrova-valeriya_011970@postgrespro.ru", "phone": "+70404876072"}
0005433341758	CFA33C	4928 957708	DMITRIY FEDOROV	{"phone": "+70515509698"}
0005433341759	575F91	6820 912949	TATYANA PAVLOVA	{"phone": "+70790202356"}
0005433341760	504E3D	2068 197555	ALEKSEY ILIN	{"email": "ilin-aleksey1988@postgrespro.ru", "phone": "+70684222824"}
0005433341761	4D3D2A	9102 108881	PAVEL STEPANOV	{"email": "pavelstepanov_051969@postgrespro.ru", "phone": "+70714840273"}
0005433341762	4D3D2A	1540 664333	ANTONINA FROLOVA	{"phone": "+70459108387"}
0005433341763	4D3D2A	0045 227168	ALEKSANDR KRASNOV	{"email": "a.krasnov091973@postgrespro.ru", "phone": "+70276828721"}
0005433341764	A2DAE2	8096 887414	OLEG KOZLOV	{"phone": "+70759341432"}
0005433341765	078B62	1413 057675	SVETLANA EFREMOVA	{"phone": "+70174267304"}
0005433341766	078B62	5014 414469	NINA MELNIKOVA	{"phone": "+70961126078"}
0005433341767	383736	5694 606180	EKATERINA FEDOROVA	{"phone": "+70792522433"}
0005433341768	B73117	2695 635210	NATALYA ZAKHAROVA	{"phone": "+70499697683"}
0005433341769	BA331C	6532 429265	MARIYA DENISOVA	{"email": "denisova-m1957@postgrespro.ru", "phone": "+70925667555"}
0005433341770	BA331C	8415 972371	ELENA SAVELEVA	{"email": "e-saveleva.111969@postgrespro.ru", "phone": "+70007412089"}
0005433341771	BA331C	0900 698192	NATALYA SMIRNOVA	{"phone": "+70727499226"}
0005433341772	4044B4	7556 632627	ANDREY PETROV	{"email": "a_petrov24031970@postgrespro.ru", "phone": "+70423337616"}
0005433341773	7633FE	0869 263012	ANDREY IVANOV	{"email": "a_ivanov-1973@postgrespro.ru", "phone": "+70977894395"}
0005433341774	7633FE	2880 499807	PAVEL KUZNECOV	{"email": "pavel_kuznecov_16121957@postgrespro.ru", "phone": "+70747008983"}
0005433341775	ACD26A	8546 040184	ROMAN SCHERBAKOV	{"email": "rscherbakov.111960@postgrespro.ru", "phone": "+70951550736"}
0005433341776	C997F8	0348 430623	TATYANA ABRAMOVA	{"email": "abramova-tatyana-24041964@postgrespro.ru", "phone": "+70146799042"}
0005433341777	4B717D	2523 842073	VYACHESLAV ORLOV	{"phone": "+70982532767"}
0005433341778	C43EE4	0325 181853	ARINA IVANOVA	{"phone": "+70991567480"}
0005433341779	60FF1A	7058 734921	ANATOLIY NIKOLAEV	{"phone": "+70957696052"}
0005433341780	3C454C	0401 156894	GALINA KISELEVA	{"phone": "+70909123549"}
0005433341781	CCF7F7	3441 086372	ANNA SOROKINA	{"email": "annasorokina30051972@postgrespro.ru", "phone": "+70139328822"}
0005433341782	679E9B	2348 783746	TATYANA ABRAMOVA	{"email": "abramovat_011961@postgrespro.ru", "phone": "+70873164464"}
0005433341783	6D560B	1540 154013	YANA DANILOVA	{"phone": "+70802345348"}
0005433341784	6D560B	6773 281581	IRINA TIKHONOVA	{"phone": "+70024950900"}
0005433341785	8DD3FF	8097 583950	ARTEM KUZNECOV	{"phone": "+70116369027"}
0005433341786	8DD3FF	6572 226131	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev.041968@postgrespro.ru", "phone": "+70077962057"}
0005433341787	E6FEFD	2125 878641	NINA LUKYANOVA	{"email": "nlukyanova_071982@postgrespro.ru", "phone": "+70088874973"}
0005433341788	3E7823	1986 024163	VLADIMIR SIDOROV	{"email": "vladimir_sidorov_1979@postgrespro.ru", "phone": "+70772236004"}
0005433341789	92F83F	6954 286486	VLADIMIR PAVLOV	{"email": "v.pavlov_021977@postgrespro.ru", "phone": "+70078372049"}
0005433341790	D9C485	4224 228314	ARTUR SAVELEV	{"email": "a.savelev.121974@postgrespro.ru", "phone": "+70028475613"}
0005433341791	D4259B	8089 917943	TATYANA IVANOVA	{"phone": "+70220385164"}
0005433341792	D4259B	3273 813036	ALBINA POPOVA	{"email": "a.popova-061985@postgrespro.ru", "phone": "+70295973169"}
0005433341793	D4259B	9538 427490	VLADIMIR ANDREEV	{"email": "vladimir-andreev_051975@postgrespro.ru", "phone": "+70018046834"}
0005433341794	B64E37	2926 593035	IRINA DAVYDOVA	{"phone": "+70929745883"}
0005433341795	B64E37	2674 364957	VIKTORIYA MIRONOVA	{"email": "mironova_viktoriya1960@postgrespro.ru", "phone": "+70621479897"}
0005433341796	A8F683	1795 444538	ARTEM ZAYCEV	{"email": "zaycev_a.1971@postgrespro.ru", "phone": "+70965668181"}
0005433341797	8A7727	8682 660584	YULIYA ERMAKOVA	{"email": "yuliyaermakova_1961@postgrespro.ru", "phone": "+70419763964"}
0005433341798	3B0B53	4459 023094	VALENTINA BORISOVA	{"phone": "+70938873074"}
0005433341799	3B0B53	8586 476581	ANATOLIY POPOV	{"phone": "+70376245476"}
0005433341800	E69FD0	7784 834698	EVGENIYA KARPOVA	{"email": "karpovaevgeniya-101990@postgrespro.ru", "phone": "+70570703308"}
0005433341801	63199D	9669 330083	SVETLANA SOROKINA	{"phone": "+70705954610"}
0005433341802	63199D	5351 364731	MARINA ABRAMOVA	{"email": "mabramova_1970@postgrespro.ru", "phone": "+70098897597"}
0005433341803	41CA23	3900 610725	VALERIYA ILINA	{"email": "ilina-valeriya061969@postgrespro.ru", "phone": "+70305943824"}
0005433341804	9E318E	1335 697074	IGOR SEMENOV	{"email": "i_semenov.1972@postgrespro.ru", "phone": "+70618555501"}
0005433341805	36EFCA	0655 517278	NIKOLAY BELOV	{"phone": "+70230429461"}
0005433341806	EB80DE	4094 078699	DAVID ANDREEV	{"email": "david-andreev1968@postgrespro.ru", "phone": "+70350170750"}
0005433341807	59D909	3713 394787	TATYANA DANILOVA	{"email": "t.danilova04081974@postgrespro.ru", "phone": "+70751667188"}
0005433341808	59D909	3187 685727	SERGEY KRASNOV	{"email": "krasnov.s-28031963@postgrespro.ru", "phone": "+70272029322"}
0005433341809	41F67E	7871 146913	DMITRIY FEDOROV	{"email": "dmitriyfedorov_031981@postgrespro.ru", "phone": "+70773631626"}
0005433341810	46C028	4047 758712	ALBINA BARANOVA	{"email": "baranova.albina1970@postgrespro.ru", "phone": "+70433458909"}
0005433341811	B9594B	5501 752753	EVGENIY OSIPOV	{"phone": "+70993295669"}
0005433341812	BA8C17	7340 960439	YULIYA STEPANOVA	{"phone": "+70755263236"}
0005433341813	C3E441	0784 738977	KRISTINA EFREMOVA	{"phone": "+70714040407"}
0005433341814	E0FA30	1181 134328	VALENTIN MIRONOV	{"email": "mironov-v.101966@postgrespro.ru", "phone": "+70196596579"}
0005433341815	940C75	8448 675925	RIMMA MOROZOVA	{"email": "morozova_r-1964@postgrespro.ru", "phone": "+70627885651"}
0005433341816	4A40CD	8591 588646	SERGEY VOLKOV	{"phone": "+70409818098"}
0005433341817	4A40CD	3204 542988	SVETLANA SCHERBAKOVA	{"phone": "+70809573467"}
0005433341818	E1BF54	1701 773898	ANZHELA SOLOVEVA	{"phone": "+70643700127"}
0005433341819	D95D8B	5472 354396	TAMARA KUZNECOVA	{"email": "t-kuznecova.1974@postgrespro.ru", "phone": "+70111392560"}
0005433341820	D95D8B	4306 490885	VLADIMIR DMITRIEV	{"email": "v-dmitriev_111975@postgrespro.ru", "phone": "+70250334171"}
0005433341821	50DBF7	8039 526497	OLGA STEPANOVA	{"phone": "+70979790335"}
0005433341822	71503A	4811 027728	ANDREY SAVELEV	{"phone": "+70167730553"}
0005433341823	79A886	4308 715544	VYACHESLAV SEMENOV	{"email": "semenovv-1967@postgrespro.ru", "phone": "+70261056437"}
0005433341824	79A886	7094 855470	GALINA KOVALEVA	{"email": "kovaleva.galina041987@postgrespro.ru", "phone": "+70654592987"}
0005433341825	0804A6	5910 556413	ALEKSEY PETROV	{"email": "petrov-a.021969@postgrespro.ru", "phone": "+70621308529"}
0005433341826	D0A48A	9701 123170	ALEKSEY SOKOLOV	{"email": "sokolov-a-15101969@postgrespro.ru", "phone": "+70783150477"}
0005433341827	BBE065	7060 448829	EVA SMIRNOVA	{"phone": "+70119038726"}
0005433341828	BBE065	9890 677103	OLGA ORLOVA	{"email": "olga_orlova.22071974@postgrespro.ru", "phone": "+70187572031"}
0005433341829	6DA295	4918 835823	OLGA ANDREEVA	{"email": "andreeva-o.1966@postgrespro.ru", "phone": "+70753228534"}
0005433341830	ACEFAE	0919 750821	NADEZHDA ABRAMOVA	{"phone": "+70766193330"}
0005433341831	66F952	4928 856287	VYACHESLAV ILIN	{"email": "ilin-v041967@postgrespro.ru", "phone": "+70593036602"}
0005433341832	3C13F2	4616 258587	INNA KUZNECOVA	{"phone": "+70791019647"}
0005433341833	3C13F2	8260 391287	ELENA VOLKOVA	{"email": "volkovae-1973@postgrespro.ru", "phone": "+70445241117"}
0005433341834	C024EB	6481 293116	VALENTINA MIKHAYLOVA	{"phone": "+70895914925"}
0005433341835	5708E1	3665 459892	MATVEY TIKHONOV	{"email": "m-tikhonov.1974@postgrespro.ru", "phone": "+70308591438"}
0005433341836	5708E1	6611 573228	LARISA ANDREEVA	{"phone": "+70125139612"}
0005433341837	BDDD9C	8510 320217	ALEKSANDR SEMENOV	{"email": "semenov.a.011975@postgrespro.ru", "phone": "+70545605955"}
0005433341838	BDDD9C	7808 577619	VIKTOR BORISOV	{"email": "borisov-viktor_041980@postgrespro.ru", "phone": "+70296000438"}
0005433341839	BDDD9C	0333 358176	YURIY MELNIKOV	{"email": "yuriy.melnikov.19051963@postgrespro.ru", "phone": "+70500311852"}
0005433341840	BF3666	4708 267036	MARAT MAKAROV	{"email": "m.makarov021974@postgrespro.ru", "phone": "+70483606493"}
0005433341841	BF3666	7811 028841	NIKOLAY NIKOLAEV	{"email": "nikolaynikolaev.1972@postgrespro.ru", "phone": "+70991627742"}
0005433341842	C0F7F4	6082 535387	FARIDA RODIONOVA	{"email": "farida-rodionova_121981@postgrespro.ru", "phone": "+70065024350"}
0005433341843	C0F7F4	9153 270490	VALENTIN NIKOLAEV	{"phone": "+70481050554"}
0005433341844	D6E20C	6979 837748	VIKTOR SIDOROV	{"email": "v-sidorov1972@postgrespro.ru", "phone": "+70647081431"}
0005433341845	D6E20C	3824 489656	LYUDMILA VLASOVA	{"email": "lyudmila.vlasova_011969@postgrespro.ru", "phone": "+70751602387"}
0005433341846	809DC1	7073 866349	OLEG IVANOV	{"email": "ivanov-o.22071980@postgrespro.ru", "phone": "+70169721181"}
0005433341847	809DC1	3886 134275	NADEZHDA KARPOVA	{"phone": "+70751727445"}
0005433341848	809DC1	8061 543512	VENIAMIN KULIKOV	{"email": "kulikov_v_13111973@postgrespro.ru", "phone": "+70895419781"}
0005433341849	45B204	2579 222401	LYUBOV SOKOLOVA	{"email": "sokolova.l1976@postgrespro.ru", "phone": "+70755140810"}
0005433341850	1E47B6	1086 503506	ANASTASIYA MELNIKOVA	{"email": "melnikova-anastasiya13081959@postgrespro.ru", "phone": "+70693042185"}
0005433341851	1E47B6	5065 288030	VALERIY GORBUNOV	{"phone": "+70356270842"}
0005433341852	0715F1	5824 088654	ANDREY ISAEV	{"phone": "+70529671033"}
0005433341853	F4C673	9970 298405	VALENTINA NESTEROVA	{"phone": "+70472940276"}
0005433341854	F4C673	0606 750749	VYACHESLAV DENISOV	{"phone": "+70246588585"}
0005433341855	062298	7732 452440	VIKTOR KUZMIN	{"phone": "+70780959575"}
0005433341856	062298	6139 460081	FLYURA LUKYANOVA	{"email": "lukyanovaf-081970@postgrespro.ru", "phone": "+70394429555"}
0005433341857	243D4D	3849 975565	GALINA VASILEVA	{"email": "galina_vasileva-09021961@postgrespro.ru", "phone": "+70294503455"}
0005433341858	3771AF	6345 623678	ANATOLIY SAVELEV	{"email": "anatoliy.savelev_1972@postgrespro.ru", "phone": "+70008040301"}
0005433341859	3771AF	5069 400711	EVGENIY ZAYCEV	{"phone": "+70169088910"}
0005433341860	9C059E	8110 225504	ALEKSANDR OSIPOV	{"email": "aosipov.101978@postgrespro.ru", "phone": "+70038411053"}
0005433341861	579BE4	3894 376844	KONSTANTIN MEDVEDEV	{"email": "medvedevkonstantin_1970@postgrespro.ru", "phone": "+70667974140"}
0005433341862	FC8F18	4998 245140	NINA SERGEEVA	{"email": "sergeeva_n-051980@postgrespro.ru", "phone": "+70435073136"}
0005433341863	472E38	7872 314783	EDUARD IVANOV	{"phone": "+70927374950"}
0005433341864	697D4B	4322 005840	ANDREY IVANOV	{"email": "ivanov-andrey_27021972@postgrespro.ru", "phone": "+70346249179"}
0005433341865	BB5E7A	6055 565839	EVGENIY SMIRNOV	{"email": "smirnov-evgeniy031970@postgrespro.ru", "phone": "+70825162630"}
0005433341866	169768	1723 611156	ALEKSEY ISAEV	{"email": "a.isaev.06011968@postgrespro.ru", "phone": "+70551418215"}
0005433341867	AA9272	2588 269205	VLADIMIR NIKOLAEV	{"phone": "+70666029357"}
0005433341868	E5E5BE	1649 109936	ALEKSANDR TIKHONOV	{"email": "a-tikhonov_121966@postgrespro.ru", "phone": "+70187250740"}
0005433341869	E57406	9324 251680	ANASTASIYA KUZMINA	{"email": "a.kuzmina29091964@postgrespro.ru", "phone": "+70264304880"}
0005433341870	64071B	1954 884543	OLGA OSIPOVA	{"phone": "+70710084419"}
0005433341871	0684A1	9018 242266	NIKITA VOLKOV	{"phone": "+70058645178"}
0005433341872	0684A1	6774 719659	EVGENIY SEMENOV	{"email": "semenov_evgeniy.011971@postgrespro.ru", "phone": "+70912258035"}
0005433341873	97CBAD	1585 776211	IGOR VASILEV	{"email": "igor-vasilev.06091971@postgrespro.ru", "phone": "+70054294854"}
0005433341874	3E7E8D	6369 232597	ALEKSANDR POPOV	{"email": "a.popov_29101974@postgrespro.ru", "phone": "+70076756017"}
0005433341875	3E7E8D	4647 446657	LYUDMILA NIKIFOROVA	{"email": "nikiforoval-1970@postgrespro.ru", "phone": "+70286259760"}
0005433341876	8EB3B7	5831 328832	VITALIY POPOV	{"email": "popov_v-041972@postgrespro.ru", "phone": "+70692967390"}
0005433341877	82239D	8195 404234	VLADIMIR SAVELEV	{"phone": "+70930566924"}
0005433341878	AED8E0	9350 516385	VYACHESLAV FEDOTOV	{"phone": "+70746787121"}
0005433341879	B25987	4409 717238	ALEKSEY NOVIKOV	{"email": "aleksey_novikov-081972@postgrespro.ru", "phone": "+70191462958"}
0005433341880	D05EB2	6019 342988	ALEKSANDR MAKSIMOV	{"phone": "+70318802435"}
0005433341881	CE4A1D	5463 883789	KSENIYA POLYAKOVA	{"email": "k_polyakova-08081969@postgrespro.ru", "phone": "+70343823775"}
0005433341882	CE4A1D	4940 234880	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov061962@postgrespro.ru", "phone": "+70939477735"}
0005433341883	CE4A1D	3654 793895	AIDA DAVYDOVA	{"phone": "+70685530603"}
0005433341884	D4E61E	0699 634876	DARYA MAKAROVA	{"email": "makarovadarya031980@postgrespro.ru", "phone": "+70776706716"}
0005433341885	812D32	6563 059567	YURIY SIDOROV	{"email": "sidorov_y_11061969@postgrespro.ru", "phone": "+70753604313"}
0005433341886	812D32	8715 544527	VLADIMIR GERASIMOV	{"phone": "+70475233880"}
0005433341887	812D32	8773 174533	VADIM KAZAKOV	{"email": "vadimkazakov.28071966@postgrespro.ru", "phone": "+70539921673"}
0005433341888	DE8701	6486 859562	RUSLAN KUZMIN	{"phone": "+70276803696"}
0005433341889	028447	0799 835659	ALEKSEY PETROV	{"phone": "+70102458676"}
0005433341890	31FE60	4766 657350	LIDIYA DENISOVA	{"email": "lidiyadenisova_28041982@postgrespro.ru", "phone": "+70837082844"}
0005433341891	31FE60	6710 021197	VYACHESLAV FILIPPOV	{"phone": "+70071514584"}
0005433341892	31FE60	3329 854162	GALINA KUZNECOVA	{"email": "kuznecova-galina1969@postgrespro.ru", "phone": "+70490618659"}
0005433341893	16B20B	5054 805299	NATALYA ERMAKOVA	{"email": "nermakova11121974@postgrespro.ru", "phone": "+70154531899"}
0005433341894	F82620	7547 324469	ELENA ROMANOVA	{"phone": "+70993875937"}
0005433341895	5BBDD6	3759 461753	NIKITA NOVIKOV	{"email": "novikov-n.1979@postgrespro.ru", "phone": "+70260488429"}
0005433341896	9FD5D5	3284 229119	TATYANA ZHUKOVA	{"phone": "+70207427563"}
0005433341897	9FD5D5	7456 195913	NATALYA DENISOVA	{"phone": "+70269021999"}
0005433341898	BA287C	5469 307298	IRINA POPOVA	{"phone": "+70000789551"}
0005433341899	905AB7	7077 710930	LYAYSAN DAVYDOVA	{"email": "lyaysan.davydova.1970@postgrespro.ru", "phone": "+70073337656"}
0005433341900	8D860A	1931 594440	KRISTINA YAKOVLEVA	{"phone": "+70662980983"}
0005433341901	D5B7F9	3911 303154	DENIS BONDARENKO	{"email": "bondarenko_d1963@postgrespro.ru", "phone": "+70970005335"}
0005433341902	05B788	0006 716642	SERGEY MAKAROV	{"email": "s.makarov-1978@postgrespro.ru", "phone": "+70190359471"}
0005433341903	2F1ADA	4914 448787	LYUDMILA MARTYNOVA	{"email": "martynova-l051973@postgrespro.ru", "phone": "+70449459180"}
0005433341904	A048FE	6414 169038	ELENA SOKOLOVA	{"email": "e.sokolova05051979@postgrespro.ru", "phone": "+70160769528"}
0005433341905	A048FE	5854 962934	MARINA MIKHAYLOVA	{"email": "mikhaylovam-1962@postgrespro.ru", "phone": "+70477706810"}
0005433341906	1C2083	6490 799122	VLADIMIR ROMANOV	{"phone": "+70159684681"}
0005433341907	1C2083	8743 958571	KONSTANTIN EGOROV	{"phone": "+70670313750"}
0005433341908	3388BF	2212 357157	YANA GUSEVA	{"email": "guseva.y_08071976@postgrespro.ru", "phone": "+70345006116"}
0005433341909	3388BF	0348 829693	NIKOLAY KAZAKOV	{"phone": "+70794432135"}
0005433341910	3388BF	0378 025062	ELENA NIKOLAEVA	{"email": "elena-nikolaeva.031976@postgrespro.ru", "phone": "+70664315992"}
0005433341911	864879	9362 904552	ALEKSANDR VLASOV	{"phone": "+70462519757"}
0005433341912	864879	9847 520402	TATYANA RYABOVA	{"email": "ryabova_tatyana26011976@postgrespro.ru", "phone": "+70702734110"}
0005433341913	864879	6198 291886	LYUBOV KUDRYASHOVA	{"email": "l_kudryashova111967@postgrespro.ru", "phone": "+70484993295"}
0005433341914	CC4299	6882 918392	NIKITA ANTONOV	{"phone": "+70939148426"}
0005433341915	7CDC64	3359 774373	ANDREY CHERNOV	{"phone": "+70584355390"}
0005433341916	B7B97B	3036 331513	SOFYA SIDOROVA	{"phone": "+70688477680"}
0005433341917	97DD29	3879 104915	OLGA OSIPOVA	{"email": "o.osipova_04061975@postgrespro.ru", "phone": "+70417750697"}
0005433341918	0CDB36	2496 292898	OLGA KULIKOVA	{"phone": "+70985463081"}
0005433341919	875BEB	8708 001028	NATALYA AKIMOVA	{"email": "n_akimova-1959@postgrespro.ru", "phone": "+70612100162"}
0005433341920	D06EED	2519 665723	POLINA KUZNECOVA	{"email": "kuznecovap1977@postgrespro.ru", "phone": "+70227082616"}
0005433341921	D06EED	6982 168754	ALINA MIRONOVA	{"phone": "+70297439793"}
0005433341922	9E68EF	5879 363839	VIKTORIYA MAKSIMOVA	{"email": "maksimova-v1970@postgrespro.ru", "phone": "+70422568363"}
0005433341923	9E68EF	0980 356044	VALENTINA IVANOVA	{"phone": "+70869544991"}
0005433341924	87914D	1299 479703	MARIYA MALYSHEVA	{"email": "mariya-malysheva.121958@postgrespro.ru", "phone": "+70151562535"}
0005433341925	322784	2957 325667	DENIS KULIKOV	{"phone": "+70150609418"}
0005433341926	322784	6038 441377	MAKSIM NOVIKOV	{"email": "m.novikov-30121978@postgrespro.ru", "phone": "+70022029012"}
0005433341927	322784	9900 129204	ALEKSANDR ZAYCEV	{"phone": "+70240427245"}
0005433341928	82A473	8010 941141	MARIYA ALEKSEEVA	{"email": "alekseeva-m.091963@postgrespro.ru", "phone": "+70178681959"}
0005433341929	AF8B40	8001 052390	ANTON YAKOVLEV	{"phone": "+70074806206"}
0005433341930	8A007D	7095 118452	MARINA GORBUNOVA	{"phone": "+70756334125"}
0005433341931	ED27D6	1943 768019	VALERIYA ZHURAVLEVA	{"email": "zhuravleva_valeriya.011962@postgrespro.ru", "phone": "+70334688396"}
0005433341932	ED27D6	5668 157091	ANNA KUZNECOVA	{"phone": "+70442723764"}
0005433341933	ED27D6	0612 109987	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a_09051969@postgrespro.ru", "phone": "+70912485961"}
0005433341934	A3003B	6446 395136	ALEKSEY DAVYDOV	{"phone": "+70821598925"}
0005433341935	A3003B	3619 444914	ALEKSEY ZHUKOV	{"email": "zhukov-aleksey011981@postgrespro.ru", "phone": "+70386338036"}
0005433341936	267FD2	2109 652228	VALENTINA KOROLEVA	{"phone": "+70754169492"}
0005433341937	267FD2	0763 397419	LARISA VASILEVA	{"email": "vasilevalarisa.1980@postgrespro.ru", "phone": "+70602632940"}
0005433341938	95A324	2873 217643	GALINA MELNIKOVA	{"email": "g.melnikova021977@postgrespro.ru", "phone": "+70860906896"}
0005433341939	08973E	1264 484393	OLGA FROLOVA	{"phone": "+70509328496"}
0005433341940	E78F81	9073 831404	MARIYA VLASOVA	{"phone": "+70269195428"}
0005433341941	563490	6821 183803	IRINA MAKSIMOVA	{"phone": "+70327794171"}
0005433341942	563490	9133 675918	NIKOLAY VOROBEV	{"email": "nikolayvorobev-061961@postgrespro.ru", "phone": "+70547691330"}
0005433341943	6E5966	6543 063024	MIKHAIL AFANASEV	{"email": "afanasevmikhail_041966@postgrespro.ru", "phone": "+70712693609"}
0005433341944	C1F7DA	0670 630465	ALEKSANDR DMITRIEV	{"phone": "+70408434117"}
0005433341945	226461	9007 243657	ALEKSANDR BELOV	{"email": "belovaleksandr071971@postgrespro.ru", "phone": "+70017745228"}
0005433341946	226461	8639 371270	VIKTOR MARTYNOV	{"email": "viktor-martynov-12091967@postgrespro.ru", "phone": "+70732094148"}
0005433341947	88A1CC	0328 886205	KONSTANTIN KONOVALOV	{"phone": "+70981623314"}
0005433341948	4143BA	9537 072366	VERONIKA TIMOFEEVA	{"email": "v.timofeeva25011972@postgrespro.ru", "phone": "+70290223556"}
0005433341949	EDC2C9	7643 890861	SERGEY OSIPOV	{"email": "osipovsergey071971@postgrespro.ru", "phone": "+70352166372"}
0005433341950	8A4BFA	6796 924900	VITALIY BORISOV	{"email": "borisov_v_011975@postgrespro.ru", "phone": "+70975299406"}
0005433341951	8A4BFA	9500 989366	EVGENIY ANDREEV	{"phone": "+70229087871"}
0005433341952	A95E53	6468 257383	SERGEY KARPOV	{"email": "karpov.sergey.1961@postgrespro.ru", "phone": "+70437576457"}
0005433341953	9EF130	6763 769604	NATALYA KOVALEVA	{"email": "natalya.kovaleva19031980@postgrespro.ru", "phone": "+70035889068"}
0005433341954	9EF130	7566 605616	SERGEY SOROKIN	{"phone": "+70615297122"}
0005433341955	884B6F	9600 906392	ZLATA NESTEROVA	{"email": "zlata.nesterova_1961@postgrespro.ru", "phone": "+70771975409"}
0005433341956	2C7F6C	8643 112660	VLADIMIR IVANOV	{"email": "vladimirivanov07091962@postgrespro.ru", "phone": "+70616107980"}
0005433341957	A93107	2653 139365	NIKITA KARPOV	{"email": "n.karpov_061978@postgrespro.ru", "phone": "+70179822925"}
0005433341958	29D9D0	5879 063492	EVGENIYA IVANOVA	{"email": "ivanova_e_07051970@postgrespro.ru", "phone": "+70198052035"}
0005433341959	1FF27C	9536 680326	VLADIMIR PAVLOV	{"phone": "+70790645472"}
0005433341960	85EAD1	9828 268604	SVETLANA KOZLOVA	{"email": "s_kozlova_1969@postgrespro.ru", "phone": "+70299109066"}
0005433341961	F293D5	7699 736089	LIDIYA KUDRYASHOVA	{"email": "l.kudryashova-17041979@postgrespro.ru", "phone": "+70920479806"}
0005433341962	F293D5	7842 133585	LYUDMILA VASILEVA	{"email": "lyudmilavasileva.30081967@postgrespro.ru", "phone": "+70158328751"}
0005433341963	23056E	6096 141116	MATVEY FEDOTOV	{"phone": "+70619106830"}
0005433341964	A9BEC7	8597 671966	MARINA KUZMINA	{"email": "kuzmina_m-16101973@postgrespro.ru", "phone": "+70832010183"}
0005433341965	55AACE	7253 943894	IGOR BORISOV	{"email": "borisov_igor-25071979@postgrespro.ru", "phone": "+70911892929"}
0005433341966	55AACE	2671 215164	FATIMA SOROKINA	{"email": "sorokina.fatima_1969@postgrespro.ru", "phone": "+70228616657"}
0005433341967	92DC3C	8377 437497	LYUBOV MAKAROVA	{"email": "lyubov_makarova1981@postgrespro.ru", "phone": "+70630756246"}
0005433341968	92DC3C	5663 392842	VIKTOR KAZAKOV	{"phone": "+70537886547"}
0005433341969	7D7C0C	4504 180424	ALEKSEY MELNIKOV	{"email": "melnikov-aleksey_10021980@postgrespro.ru", "phone": "+70733916462"}
0005433341970	01E3C3	7870 984488	ALEKSEY BORISOV	{"email": "a-borisov.13011972@postgrespro.ru", "phone": "+70306255856"}
0005433341971	F51457	2816 202454	LYUDMILA ANISIMOVA	{"phone": "+70460034210"}
0005433341972	1D15CC	2919 874083	MAKSIM NOVIKOV	{"phone": "+70247684702"}
0005433341973	E109C7	7218 763949	VLADIMIR KUZNECOV	{"phone": "+70397140299"}
0005433341974	711E88	5680 515862	LYUBOV OSIPOVA	{"phone": "+70496960491"}
0005433341975	872741	1876 652357	ELENA GAVRILOVA	{"phone": "+70091934681"}
0005433341976	872741	5082 774793	ZINAIDA MOROZOVA	{"email": "zinaida.morozova_1986@postgrespro.ru", "phone": "+70988874500"}
0005433341977	872741	8151 217098	SVETLANA KUZMINA	{"email": "kuzminas_121961@postgrespro.ru", "phone": "+70020249174"}
0005433341978	54A012	4073 833242	YURIY SCHERBAKOV	{"phone": "+70714499928"}
0005433341979	54A012	8555 577989	ELIZAVETA DMITRIEVA	{"email": "dmitrievaelizaveta081978@postgrespro.ru", "phone": "+70458187643"}
0005433341980	54A012	2277 400287	ROMAN SMIRNOV	{"phone": "+70467757577"}
0005433341981	5AF812	2484 566645	ALEKSEY KUZNECOV	{"phone": "+70317431460"}
0005433341982	D02883	2020 819540	ANDREY NIKITIN	{"email": "nikitina.121971@postgrespro.ru", "phone": "+70261433959"}
0005433341983	39E3DB	5022 501944	PAVEL TARASOV	{"email": "p-tarasov1960@postgrespro.ru", "phone": "+70805803295"}
0005433341984	6FD9DA	1247 208820	IRINA IVANOVA	{"phone": "+70009390479"}
0005433341985	F1D341	7443 673525	PELAGEYA SMIRNOVA	{"phone": "+70121043224"}
0005433341986	AA3033	7944 277333	DMITRIY IVANOV	{"phone": "+70250843213"}
0005433341987	67C1F8	8312 299798	MARIYA MAKAROVA	{"email": "m.makarova1980@postgrespro.ru", "phone": "+70175913055"}
0005433341988	A88DEF	2062 468642	ANNA FROLOVA	{"email": "afrolova.121967@postgrespro.ru", "phone": "+70496632034"}
0005433341989	716A0F	3322 939599	LYUBOV MOROZOVA	{"email": "morozova-lyubov27071972@postgrespro.ru", "phone": "+70105333406"}
0005433341990	716A0F	1415 459291	ALEKSANDR CHERNOV	{"email": "chernov_a_121978@postgrespro.ru", "phone": "+70253970360"}
0005433341991	716A0F	8787 850300	VLADIMIR TIKHONOV	{"email": "v.tikhonov111976@postgrespro.ru", "phone": "+70519100863"}
0005433341992	7D8204	5908 712628	LYUBOV LAZAREVA	{"phone": "+70576194061"}
0005433341993	80C474	9620 119607	GLEB IVANOV	{"email": "ivanov-gleb.071967@postgrespro.ru", "phone": "+70346289808"}
0005433341994	2781A0	6941 708060	LYUDMILA KULIKOVA	{"phone": "+70614136371"}
0005433341995	A62142	1442 199600	EKATERINA IVANOVA	{"phone": "+70479353179"}
0005433341996	508E88	5747 787327	RAVIL TARASOV	{"phone": "+70293792337"}
0005433341997	508E88	5813 332873	OLGA VASILEVA	{"email": "vasileva.o04111970@postgrespro.ru", "phone": "+70555666558"}
0005433341998	E19708	1969 613530	OLGA POLYAKOVA	{"email": "polyakova_olga-27061970@postgrespro.ru", "phone": "+70954552532"}
0005433341999	586E5F	0723 412807	ANDREY SOROKIN	{"phone": "+70831348238"}
0005433342000	586E5F	1220 820156	NINA FILATOVA	{"email": "nina-filatova.051967@postgrespro.ru", "phone": "+70413290855"}
0005433342001	BED296	8140 956777	TATYANA NESTEROVA	{"phone": "+70994411201"}
0005433342002	BED296	3794 599897	GALINA POPOVA	{"email": "popovag1965@postgrespro.ru", "phone": "+70478254936"}
0005433342003	9D00A8	6409 595965	VIKTORIYA MIKHAYLOVA	{"phone": "+70415120281"}
0005433342004	B8FF16	1219 456690	MARGARITA FROLOVA	{"phone": "+70252629839"}
0005433342005	CBE4E9	0141 212673	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.aleksandr_1980@postgrespro.ru", "phone": "+70250056714"}
0005433342006	C0B7C9	0017 758178	ARTUR PETROV	{"email": "petrovartur.1977@postgrespro.ru", "phone": "+70025373457"}
0005433342007	C0B7C9	8227 484888	SVETLANA NIKOLAEVA	{"phone": "+70479645360"}
0005433342008	0EA749	0041 425042	ALEKSEY FOMIN	{"phone": "+70802628803"}
0005433342009	0EA749	0917 912836	ALEKSANDR KISELEV	{"phone": "+70661673350"}
0005433342010	0EA749	4842 326248	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir101975@postgrespro.ru", "phone": "+70319469453"}
0005433342011	D86A75	3168 490653	ANASTASIYA SERGEEVA	{"email": "anastasiyasergeeva.01111976@postgrespro.ru", "phone": "+70326281527"}
0005433342012	D86A75	8451 316494	ELENA PETROVA	{"email": "elenapetrova_1981@postgrespro.ru", "phone": "+70832230450"}
0005433342013	7D15EB	1227 709387	TIGRAN SOKOLOV	{"email": "sokolov-t_021974@postgrespro.ru", "phone": "+70393291398"}
0005433342014	7D15EB	7985 134117	GALINA CHERNOVA	{"email": "chernovagalina.1979@postgrespro.ru", "phone": "+70284669068"}
0005433342015	DBEB01	3330 520592	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-aleksandr_21061971@postgrespro.ru", "phone": "+70393743704"}
0005433342016	96165F	0990 299251	KSENIYA KUZNECOVA	{"email": "kuznecovak_11121967@postgrespro.ru", "phone": "+70519753444"}
0005433342017	A85E0B	4569 270075	VLADIMIR KUZNECOV	{"phone": "+70180711487"}
0005433342018	A85E0B	2540 471045	VALENTINA ZAYCEVA	{"email": "valentina-zayceva011973@postgrespro.ru", "phone": "+70423598392"}
0005433342019	A85E0B	3014 515266	ANDREY SEMENOV	{"email": "andrey_semenov-04021974@postgrespro.ru", "phone": "+70703056132"}
0005433342020	1B8F5C	2398 169895	OLGA ANDREEVA	{"email": "o_andreeva121966@postgrespro.ru", "phone": "+70630967494"}
0005433342021	5F9045	6046 437732	ANNA BELYAEVA	{"email": "belyaevaanna-24021969@postgrespro.ru", "phone": "+70398261203"}
0005433342022	899EF2	4819 246854	LYUDMILA VOROBEVA	{"phone": "+70001802372"}
0005433342023	899EF2	3726 637371	NADEZHDA IVANOVA	{"phone": "+70541933255"}
0005433342024	11DCE6	0217 366701	YAROSLAV MELNIKOV	{"email": "yaroslav.melnikov_1973@postgrespro.ru", "phone": "+70603730259"}
0005433342025	C064C6	8788 749509	SOFIYA TIKHONOVA	{"phone": "+70718583674"}
0005433342026	E62544	9672 745442	OKSANA KUZNECOVA	{"phone": "+70207000076"}
0005433342027	25CBA8	3603 984238	NINA KUZMINA	{"email": "kuzmina_n.16051980@postgrespro.ru", "phone": "+70793712484"}
0005433342028	6B7967	6804 255211	TATYANA VOROBEVA	{"phone": "+70778304437"}
0005433342029	0A2F73	5554 674941	ANDREY GERASIMOV	{"phone": "+70530199396"}
0005433342030	899AE0	0128 052887	DMITRIY NAZAROV	{"phone": "+70371835896"}
0005433342031	187510	9346 793496	EGOR RODIONOV	{"email": "e-rodionov.20091961@postgrespro.ru", "phone": "+70118902748"}
0005433342639	86C7FF	3762 610290	ALEKSEY NAZAROV	{"phone": "+70322838082"}
0005433342032	9299A8	2710 897218	YURIY FROLOV	{"email": "y_frolov05091983@postgrespro.ru", "phone": "+70443406436"}
0005433342033	9299A8	1907 700623	ALISHER DMITRIEV	{"phone": "+70559434616"}
0005433342034	9299A8	4660 006318	ANDREY ZHUKOV	{"phone": "+70026075008"}
0005433342035	1C15D3	3801 807403	ALENA EGOROVA	{"email": "alena.egorova17071978@postgrespro.ru", "phone": "+70269174677"}
0005433342036	982640	4470 137263	ALEKSEY VASILEV	{"email": "vasilev_aleksey061971@postgrespro.ru", "phone": "+70034388503"}
0005433342037	31248C	6625 283567	TAMARA MOROZOVA	{"email": "tamara.morozova22071957@postgrespro.ru", "phone": "+70905352257"}
0005433342038	B8F936	2492 561901	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva.061978@postgrespro.ru", "phone": "+70116009849"}
0005433342039	B8F936	9157 770537	LILIYA KONOVALOVA	{"phone": "+70100259611"}
0005433342040	680BDC	6600 528863	ARINA CHERNOVA	{"email": "arina_chernova_22041962@postgrespro.ru", "phone": "+70269155564"}
0005433342041	9356AE	3610 017615	ALEKSANDR FILIPPOV	{"phone": "+70100629049"}
0005433342042	9356AE	2647 318997	ELENA SAVELEVA	{"email": "saveleva_e_051977@postgrespro.ru", "phone": "+70651950110"}
0005433342043	7DC29C	0418 278167	ANATOLIY ZAKHAROV	{"phone": "+70559872545"}
0005433342044	AE8643	6736 927042	VALENTINA KULIKOVA	{"phone": "+70834086106"}
0005433342045	AE8643	8758 203545	DENIS SOLOVEV	{"phone": "+70696231130"}
0005433342046	569D9E	9801 521001	VALERIY MOROZOV	{"email": "v-morozov101979@postgrespro.ru", "phone": "+70574097636"}
0005433342047	53FC3C	7420 782635	ALEKSANDRA FILIPPOVA	{"email": "a.filippova03021970@postgrespro.ru", "phone": "+70878016849"}
0005433342048	4598D2	5680 759192	EVGENIY MOISEEV	{"phone": "+70975078210"}
0005433342049	4598D2	6279 289088	VARVARA SMIRNOVA	{"phone": "+70485116339"}
0005433342050	813F03	9032 885114	ELENA ERMAKOVA	{"phone": "+70695682812"}
0005433342051	813F03	1794 297560	IVAN ANTONOV	{"email": "iantonov-041966@postgrespro.ru", "phone": "+70429866025"}
0005433342052	6FDFCB	8035 779980	ELENA FILIPPOVA	{"phone": "+70743283235"}
0005433342053	FF01D2	8031 100074	ALEKSEY KAZAKOV	{"email": "kazakovaleksey_081972@postgrespro.ru", "phone": "+70171049284"}
0005433342054	FF01D2	7152 223522	VADIM NOVIKOV	{"email": "novikov_v061968@postgrespro.ru", "phone": "+70734200146"}
0005433342055	29369A	6445 378309	IRINA DENISOVA	{"email": "irina-denisova1987@postgrespro.ru", "phone": "+70578446436"}
0005433342056	5A4286	0069 156937	ANASTASIYA KOZLOVA	{"email": "kozlovaanastasiya-14041977@postgrespro.ru", "phone": "+70811330609"}
0005433342057	5A4286	4400 500734	GENNADIY ABRAMOV	{"email": "abramov-gennadiy27101973@postgrespro.ru", "phone": "+70891607483"}
0005433342058	848FE5	7624 232598	VLADIMIR NIKITIN	{"email": "nikitin_vladimir-091981@postgrespro.ru", "phone": "+70927792012"}
0005433342059	1A71FF	0386 941407	TATYANA VASILEVA	{"phone": "+70508467036"}
0005433342060	CDEF20	2330 022920	DMITRIY NAZAROV	{"email": "d.nazarov1969@postgrespro.ru", "phone": "+70225993654"}
0005433342061	CDEF20	1388 527988	ANATOLIY CHERNOV	{"phone": "+70298148825"}
0005433342062	0080FD	3397 477074	ALEKSANDR ANDREEV	{"phone": "+70038094809"}
0005433342063	D15E68	3679 336082	RUSTEM BELOV	{"email": "rbelov_1974@postgrespro.ru", "phone": "+70141938946"}
0005433342064	D4A310	8993 753260	VLADIMIR KUZNECOV	{"phone": "+70027173499"}
0005433342065	E998AA	3427 483544	VALENTINA KALININA	{"email": "kalininavalentina1975@postgrespro.ru", "phone": "+70938085309"}
0005433342066	3EF827	8323 702767	STANISLAV SOROKIN	{"email": "s-sorokin.1973@postgrespro.ru", "phone": "+70738109349"}
0005433342067	F91F94	9388 947868	ARTEM ZHURAVLEV	{"email": "zhuravleva-1976@postgrespro.ru", "phone": "+70601822355"}
0005433342068	5DB544	5813 184006	DANIL SEMENOV	{"email": "danil_semenov_1971@postgrespro.ru", "phone": "+70357847029"}
0005433342069	30CB57	8660 085540	ALEKSANDRA NIKITINA	{"email": "a_nikitina-071980@postgrespro.ru", "phone": "+70148724876"}
0005433342070	2B747B	9342 645303	LYUBOV NAUMOVA	{"email": "l.naumova-06031978@postgrespro.ru", "phone": "+70067015391"}
0005433342071	8BF04E	4702 184247	VIKTOR MIKHAYLOV	{"email": "v_mikhaylov.081978@postgrespro.ru", "phone": "+70316407047"}
0005433342072	642B74	4116 729600	YURIY MOROZOV	{"phone": "+70795445491"}
0005433342073	F3E9EE	1176 806625	KONSTANTIN KOZLOV	{"phone": "+70176193421"}
0005433342074	F40310	0251 050813	ROMAN KRASNOV	{"phone": "+70484762599"}
0005433342075	52D428	2631 821341	GENNADIY VOLKOV	{"phone": "+70400130684"}
0005433342076	2852AB	8794 799016	IVAN KONOVALOV	{"email": "konovalov.i.29011981@postgrespro.ru", "phone": "+70685992447"}
0005433342077	BE6CC0	6546 234663	ANNA MAKSIMOVA	{"email": "annamaksimova_031979@postgrespro.ru", "phone": "+70512154386"}
0005433342078	869579	7847 383037	OLGA IVANOVA	{"email": "oivanova_111978@postgrespro.ru", "phone": "+70977046435"}
0005433342079	0301D5	9069 710227	ALEKSANDR KUZMIN	{"email": "kuzmina.1984@postgrespro.ru", "phone": "+70054658572"}
0005433342080	0301D5	0733 863196	ANNA KISELEVA	{"phone": "+70075042592"}
0005433342081	0301D5	3373 173339	GENNADIY KOROLEV	{"email": "gennadiy-korolev-21121964@postgrespro.ru", "phone": "+70558870694"}
0005433342082	A7E9C5	8778 358783	MARGARITA KOROLEVA	{"phone": "+70991981851"}
0005433342083	D441B7	4184 463917	ALEKSANDRA BARANOVA	{"email": "aleksandrabaranova.11021978@postgrespro.ru", "phone": "+70300704770"}
0005433342084	C530C9	6499 680199	ALEKSANDR NAZAROV	{"email": "a-nazarov-1983@postgrespro.ru", "phone": "+70232836575"}
0005433342085	C530C9	7699 225704	NIKOLAY KRASNOV	{"phone": "+70600827088"}
0005433342086	6835DF	0182 424026	ANATOLIY SCHERBAKOV	{"phone": "+70971672790"}
0005433342087	6835DF	9531 780489	SVETLANA OVCHINNIKOVA	{"phone": "+70752782671"}
0005433342088	AFD01C	9886 221898	VALENTINA PETROVA	{"email": "petrova.v_031979@postgrespro.ru", "phone": "+70453443940"}
0005433342089	FB461A	3811 844042	IRINA MATVEEVA	{"email": "matveeva-irina.09051985@postgrespro.ru", "phone": "+70769660894"}
0005433342090	FB461A	7110 512319	VITALIY MIRONOV	{"email": "mironovv04061975@postgrespro.ru", "phone": "+70526754922"}
0005433342091	5C0763	1517 368109	ARTEM FOMIN	{"email": "fomin.artem.20041974@postgrespro.ru", "phone": "+70980095348"}
0005433342092	5C0763	3679 308613	ALEKSANDR CHERNOV	{"email": "chernova-081963@postgrespro.ru", "phone": "+70612145233"}
0005433342093	BC3D13	5019 256264	VERA SMIRNOVA	{"phone": "+70027525366"}
0005433342094	AC0C98	2675 465638	LYUBOV ABRAMOVA	{"email": "labramova.1984@postgrespro.ru", "phone": "+70980895740"}
0005433342095	AC0C98	9296 873590	NIKOLAY IVANOV	{"email": "n.ivanov_11021966@postgrespro.ru", "phone": "+70671000840"}
0005433342096	B6DCC9	1048 881133	SVETLANA POPOVA	{"email": "popova-svetlana.071972@postgrespro.ru", "phone": "+70039052457"}
0005433342097	EEB6E7	4048 744237	ANTONINA MAKAROVA	{"phone": "+70479488390"}
0005433342098	EEB6E7	5597 690875	DARYA MOISEEVA	{"email": "moiseeva_d.121986@postgrespro.ru", "phone": "+70659370877"}
0005433342099	01CBB7	3890 920275	VALENTINA ROMANOVA	{"email": "vromanova-1971@postgrespro.ru", "phone": "+70598077792"}
0005433342100	CB80FF	4602 799984	SVETLANA ANDREEVA	{"phone": "+70162575404"}
0005433342101	0E265E	1795 681913	NATALYA KRASNOVA	{"phone": "+70999657301"}
0005433342102	000352	0376 023393	RUZALIYA KOROLEVA	{"phone": "+70879819855"}
0005433342103	000352	2080 204434	LYUDMILA TIKHONOVA	{"phone": "+70460049676"}
0005433342104	3CAA42	2060 520512	ALEKSANDR ZAYCEV	{"phone": "+70961560972"}
0005433342105	ACF9D6	9042 792338	GALINA MAKAROVA	{"email": "g.makarova-24051983@postgrespro.ru", "phone": "+70136664870"}
0005433342106	9CCF29	8222 306583	ANNA ORLOVA	{"phone": "+70310789778"}
0005433342107	9CCF29	7883 508687	LYUDMILA KOZLOVA	{"email": "kozlova-l1968@postgrespro.ru", "phone": "+70358293118"}
0005433342108	4E33D5	7006 234411	SVETLANA ALEKSEEVA	{"email": "alekseeva.s.26101975@postgrespro.ru", "phone": "+70110434861"}
0005433342109	3222B1	7866 002779	ALEKSANDR GUSEV	{"phone": "+70546956864"}
0005433342110	EA75F2	6469 538047	SERGEY KUZNECOV	{"phone": "+70928719963"}
0005433342111	D55D5C	6340 212636	NATALYA POPOVA	{"email": "popova-n-081982@postgrespro.ru", "phone": "+70046227678"}
0005433342112	9438D0	9200 531395	SVETLANA RYABOVA	{"phone": "+70606488664"}
0005433342113	54B826	1358 585287	NATALYA VASILEVA	{"email": "vasileva.natalya12101982@postgrespro.ru", "phone": "+70350043073"}
0005433342114	54B826	8456 758615	DARYA KUDRYASHOVA	{"email": "darya-kudryashova.02021958@postgrespro.ru", "phone": "+70707235404"}
0005433342115	A1EAAC	1209 030062	ELENA BELOVA	{"phone": "+70250405636"}
0005433342116	1F3910	3558 126303	DMITRIY SERGEEV	{"email": "sergeev_dmitriy_041987@postgrespro.ru", "phone": "+70043790345"}
0005433342117	44AD9B	0843 992140	ANNA PETROVA	{"phone": "+70745708176"}
0005433342118	A72996	7050 407312	VLADIMIR GUSEV	{"phone": "+70614968079"}
0005433342119	D50ED7	4077 457247	GALINA CHERNOVA	{"phone": "+70101182629"}
0005433342120	E8E53C	0011 715468	ROMAN NAUMOV	{"phone": "+70232712464"}
0005433342121	219623	2542 229285	EVGENIY VASILEV	{"email": "vasilevevgeniy.1972@postgrespro.ru", "phone": "+70122325801"}
0005433342122	219623	9536 075773	SVETLANA ROMANOVA	{"email": "romanova.svetlana-1959@postgrespro.ru", "phone": "+70409903617"}
0005433342123	65A269	3302 477244	VALENTIN RODIONOV	{"email": "rodionov.valentin_09051979@postgrespro.ru", "phone": "+70973639068"}
0005433342124	986FD0	6334 924429	EVGENIY SMIRNOV	{"email": "smirnov.e-091963@postgrespro.ru", "phone": "+70607303767"}
0005433342125	052054	0013 759051	MARIYA NAZAROVA	{"phone": "+70699216328"}
0005433342126	D6D879	8537 473629	YURIY VLASOV	{"phone": "+70940311147"}
0005433342127	D6D879	9623 012060	NATALIYA EFREMOVA	{"email": "n.efremova_1973@postgrespro.ru", "phone": "+70497551487"}
0005433342128	0C9185	0644 790430	GALINA KUZNECOVA	{"email": "kuznecova.galina-04021976@postgrespro.ru", "phone": "+70972519260"}
0005433342129	CAB029	4924 256277	IRINA MOROZOVA	{"phone": "+70291437733"}
0005433342130	CAB029	4568 106044	VLADIMIR PAVLOV	{"phone": "+70147679696"}
0005433342131	11AA3F	4264 470276	IVAN DAVYDOV	{"email": "i.davydov-1971@postgrespro.ru", "phone": "+70261803610"}
0005433342132	5E4EF8	4677 690260	NINA ORLOVA	{"email": "norlova-021976@postgrespro.ru", "phone": "+70741242706"}
0005433342133	30FAEB	0576 911100	ELENA VASILEVA	{"email": "e_vasileva-031984@postgrespro.ru", "phone": "+70481886322"}
0005433342134	D377FE	6400 656562	VLADIMIR SIDOROV	{"email": "sidorov_vladimir1961@postgrespro.ru", "phone": "+70185196154"}
0005433342135	D377FE	6616 061859	ZOYA OSIPOVA	{"email": "z-osipova.081971@postgrespro.ru", "phone": "+70005869564"}
0005433342136	7EB10B	4990 581202	TATYANA IVANOVA	{"phone": "+70941591051"}
0005433342137	7EB10B	8092 560603	VLADIMIR KONOVALOV	{"email": "v_konovalov101976@postgrespro.ru", "phone": "+70437446148"}
0005433342138	895823	2057 062831	LYUBOV TROFIMOVA	{"phone": "+70634217257"}
0005433342139	58C80C	6830 121688	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey.02091972@postgrespro.ru", "phone": "+70363932438"}
0005433342140	FC31BB	2700 266556	OKSANA MOISEEVA	{"email": "moiseeva.o_1977@postgrespro.ru", "phone": "+70874491893"}
0005433342141	C5A0D2	2360 977385	OLGA DAVYDOVA	{"email": "olgadavydova26061971@postgrespro.ru", "phone": "+70867539256"}
0005433342142	F0C521	1822 012410	VITALIY ANDREEV	{"phone": "+70741015006"}
0005433342143	8DECD8	6876 676377	ALINA NAUMOVA	{"email": "naumova_alina051975@postgrespro.ru", "phone": "+70378471893"}
0005433342144	911C78	4149 674218	GALINA POPOVA	{"phone": "+70133982054"}
0005433342145	911C78	7153 280467	OLEG YAKOVLEV	{"email": "yakovlev-o1968@postgrespro.ru", "phone": "+70091468154"}
0005433342146	520109	8066 553526	VYACHESLAV ZHURAVLEV	{"email": "vyacheslav-zhuravlev1975@postgrespro.ru", "phone": "+70382546677"}
0005433342147	520109	7718 927781	DMITRIY FEDOROV	{"phone": "+70217234932"}
0005433342148	72DF60	3191 186374	TATYANA KONDRATEVA	{"email": "kondrateva_tatyana-29011962@postgrespro.ru", "phone": "+70058466113"}
0005433342149	2E5083	2603 791701	SERGEY FROLOV	{"email": "frolov_s031974@postgrespro.ru", "phone": "+70166228691"}
0005433342150	06C8AA	1328 697467	SERGEY KUZNECOV	{"email": "kuznecovs1974@postgrespro.ru", "phone": "+70471402087"}
0005433342151	32EBF7	6809 248189	EVGENIY PETROV	{"phone": "+70417878098"}
0005433342152	32EBF7	4516 025855	SERGEY SERGEEV	{"email": "sergeev.s-021969@postgrespro.ru", "phone": "+70406627280"}
0005433342153	7DC8F0	2299 412393	VIKTOR SOROKIN	{"email": "viktor.sorokin.1977@postgrespro.ru", "phone": "+70624005224"}
0005433342154	7DC8F0	6744 053018	NIKOLAY STEPANOV	{"email": "nikolay.stepanov_1971@postgrespro.ru", "phone": "+70560992846"}
0005433342155	7EBE91	0715 848157	ILYA BORISOV	{"email": "i.borisov-061972@postgrespro.ru", "phone": "+70924222334"}
0005433342156	6515C9	8020 621227	VERA BORISOVA	{"email": "vera.borisova_031975@postgrespro.ru", "phone": "+70948616329"}
0005433342157	EC826E	6270 924680	KLAVDIYA MOISEEVA	{"email": "moiseevak25061980@postgrespro.ru", "phone": "+70850464676"}
0005433342158	202646	3763 964490	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila23111974@postgrespro.ru", "phone": "+70043517667"}
0005433342159	02B51A	2976 230343	RAISA KISELEVA	{"email": "kiselevaraisa.1984@postgrespro.ru", "phone": "+70338232072"}
0005433342160	E7C16B	5998 310733	VALENTINA FEDOROVA	{"phone": "+70651388174"}
0005433342161	E7C16B	4769 525942	IGOR GUSEV	{"email": "gusevigor1973@postgrespro.ru", "phone": "+70156081587"}
0005433342162	F60E1D	7761 919722	MATVEY SAVELEV	{"email": "matveysavelev-01091979@postgrespro.ru", "phone": "+70610695598"}
0005433342163	F60E1D	0943 937351	ELENA DAVYDOVA	{"phone": "+70460643629"}
0005433342164	F60E1D	3226 210501	VIKTORIYA NAZAROVA	{"email": "nazarova_viktoriya.1964@postgrespro.ru", "phone": "+70350756190"}
0005433342165	88C6E9	8793 391024	LIYA KUZMINA	{"email": "liyakuzmina1963@postgrespro.ru", "phone": "+70212884876"}
0005433342166	CCFFCF	7861 878325	ALEKSANDRA KUZMINA	{"phone": "+70556251026"}
0005433342167	A8F3CB	1810 094017	ANATOLIY ISAEV	{"email": "isaev-a.1976@postgrespro.ru", "phone": "+70387215881"}
0005433342229	A537A0	0208 528639	DMITRIY TIKHONOV	{"phone": "+70340929782"}
0005433342168	708A13	0566 007571	ALEKSANDR KOZLOV	{"email": "a_kozlov011975@postgrespro.ru", "phone": "+70299905310"}
0005433342169	708A13	2971 201076	VIKTOR ROMANOV	{"email": "viktor_romanov-101972@postgrespro.ru", "phone": "+70018790466"}
0005433342170	708A13	3889 230721	MATVEY TARASOV	{"email": "matveytarasov22021975@postgrespro.ru", "phone": "+70681187094"}
0005433342171	DD38F1	1504 981436	SERGEY MIKHAYLOV	{"email": "mikhaylov-s-1969@postgrespro.ru", "phone": "+70647670878"}
0005433342172	30236A	9903 616052	OKSANA BELYAEVA	{"email": "oksana-belyaeva-031973@postgrespro.ru", "phone": "+70145543355"}
0005433342173	30236A	1091 358260	EVELINA KARPOVA	{"email": "e.karpova_18111964@postgrespro.ru", "phone": "+70100723474"}
0005433342174	BB62AC	1923 949918	VALENTINA CHERNOVA	{"phone": "+70907151120"}
0005433342175	8CAC79	6272 566542	NIKITA NOVIKOV	{"email": "novikov.n051971@postgrespro.ru", "phone": "+70444617369"}
0005433342176	EF5DED	0224 162855	YURIY MIKHAYLOV	{"phone": "+70811254827"}
0005433342177	EF5DED	0814 985123	VLADIMIR MARTYNOV	{"email": "vladimirmartynov_1980@postgrespro.ru", "phone": "+70025680474"}
0005433342178	A2BD19	7274 397371	VASILIY ALEKSANDROV	{"phone": "+70690373649"}
0005433342179	A2BD19	4402 069070	OLEG DAVYDOV	{"phone": "+70509393296"}
0005433342180	7E922A	5046 314383	ANNA OVCHINNIKOVA	{"phone": "+70071669104"}
0005433342181	7E922A	3463 343871	ANTON KRASNOV	{"email": "a.krasnov041969@postgrespro.ru", "phone": "+70618615193"}
0005433342182	021FF4	1902 970927	PAVEL RODIONOV	{"phone": "+70677418778"}
0005433342183	028377	3956 407517	NATALYA KOROLEVA	{"phone": "+70862708720"}
0005433342184	B03D97	0299 029924	KARINA KISELEVA	{"email": "kiseleva.k_061971@postgrespro.ru", "phone": "+70559252582"}
0005433342185	0E8573	6644 628798	VLADIMIR FEDOROV	{"phone": "+70180406519"}
0005433342186	549B84	1763 297959	VIKTOR ZHURAVLEV	{"phone": "+70938193527"}
0005433342187	8C3254	3350 446898	LYUDMILA KOROLEVA	{"phone": "+70280396327"}
0005433342188	3A674F	1634 251856	MARIYA BELOVA	{"phone": "+70442643969"}
0005433342189	3A674F	6717 012477	ANDREY VASILEV	{"phone": "+70834983171"}
0005433342190	B7829B	8016 540522	ALEKSEY PAVLOV	{"phone": "+70183337328"}
0005433342191	B7829B	9007 761176	IRINA SOLOVEVA	{"email": "soloveva-i_061985@postgrespro.ru", "phone": "+70429557307"}
0005433342192	E1A8F0	3722 535308	GALINA MAKAROVA	{"email": "galina-makarova-1980@postgrespro.ru", "phone": "+70792979476"}
0005433342193	DE8186	4407 683318	MARIYA NIKITINA	{"email": "nikitina_mariya-30121964@postgrespro.ru", "phone": "+70014794843"}
0005433342194	DE8186	9744 124701	KHASAN FROLOV	{"phone": "+70137276305"}
0005433342195	5DBBB7	4210 281414	ALEKSANDR IVANOV	{"phone": "+70593908651"}
0005433342196	D280F0	4977 501109	NATALYA KOLESNIKOVA	{"email": "kolesnikova_n_041971@postgrespro.ru", "phone": "+70934897720"}
0005433342197	BD38E0	9251 064436	GENNADIY NAUMOV	{"phone": "+70087971764"}
0005433342198	0BB867	7757 311829	NIKOLAY IVANOV	{"email": "nikolayivanov061976@postgrespro.ru", "phone": "+70149102721"}
0005433342199	F13171	5539 212219	MAKSIM MAKAROV	{"phone": "+70420534557"}
0005433342200	908F4D	8462 138632	EKATERINA KOROLEVA	{"phone": "+70468088299"}
0005433342201	908F4D	4039 564450	MARIYA SOROKINA	{"phone": "+70218484269"}
0005433342202	4C222E	7611 682659	DINA BORISOVA	{"phone": "+70124623475"}
0005433342203	4C222E	9851 980390	EVGENIY MATVEEV	{"phone": "+70690161327"}
0005433342204	78A3DA	3175 524190	IVAN IVANOV	{"phone": "+70174881277"}
0005433342205	329ED3	0235 805772	SERGEY IVANOV	{"email": "s.ivanov14011971@postgrespro.ru", "phone": "+70554880623"}
0005433342206	0C368F	9331 117018	TATYANA KOROLEVA	{"phone": "+70505219543"}
0005433342207	57A672	3939 039892	VLADISLAV ROMANOV	{"phone": "+70040433220"}
0005433342208	57A672	8644 054428	MARINA NESTEROVA	{"phone": "+70951318147"}
0005433342209	DD8534	7961 514912	MARIYA NIKITINA	{"email": "nikitina.m-15011971@postgrespro.ru", "phone": "+70575339865"}
0005433342210	DD8534	0523 158573	IRINA IVANOVA	{"phone": "+70755315950"}
0005433342211	DB5613	3379 159646	ZOYA KOLESNIKOVA	{"email": "kolesnikovaz.1983@postgrespro.ru", "phone": "+70103437383"}
0005433342212	DB5613	5045 740306	VYACHESLAV VASILEV	{"email": "vasilevvyacheslav.1979@postgrespro.ru", "phone": "+70754598170"}
0005433342213	77C2BD	0060 914160	NINA IVANOVA	{"email": "nina_ivanova_031969@postgrespro.ru", "phone": "+70174190411"}
0005433342214	1F71BD	8171 806534	LILIYA VOLKOVA	{"email": "volkoval1978@postgrespro.ru", "phone": "+70013359467"}
0005433342215	6E94E2	7497 757793	OLGA ZAKHAROVA	{"email": "zakharova.olga061973@postgrespro.ru", "phone": "+70868388797"}
0005433342216	6E94E2	3930 875807	ELIZAVETA MASLOVA	{"phone": "+70051874840"}
0005433342217	D6CC87	9709 734241	NATALYA KUDRYASHOVA	{"email": "natalyakudryashova_061971@postgrespro.ru", "phone": "+70892378067"}
0005433342218	AC9CC8	7729 107278	DMITRIY VOLKOV	{"phone": "+70916638186"}
0005433342219	AC9CC8	7279 590701	DARYA POPOVA	{"email": "popova-darya_1971@postgrespro.ru", "phone": "+70454916219"}
0005433342220	B26CB6	7917 431749	ALIK KAZAKOV	{"phone": "+70686792402"}
0005433342221	962392	5601 164899	PAVEL BELOV	{"email": "pavel.belov.08121962@postgrespro.ru", "phone": "+70009278837"}
0005433342222	962392	1684 980792	ROMAN GAVRILOV	{"email": "gavrilov.roman031981@postgrespro.ru", "phone": "+70147933666"}
0005433342223	C15A5B	0284 468622	SVETLANA ANISIMOVA	{"email": "anisimova.s_081973@postgrespro.ru", "phone": "+70907225357"}
0005433342224	2329C6	9155 782058	EKATERINA FILATOVA	{"phone": "+70616241050"}
0005433342225	BFE33E	4423 819100	RAISA NOVIKOVA	{"email": "novikova.r-101984@postgrespro.ru", "phone": "+70369625979"}
0005433342226	4D8F48	5924 700342	NATALYA SERGEEVA	{"email": "natalya-sergeeva-1961@postgrespro.ru", "phone": "+70335064074"}
0005433342227	A1D9A8	6780 184119	VSEVOLOD MAKAROV	{"email": "vsevolodmakarov_03081983@postgrespro.ru", "phone": "+70504648040"}
0005433342228	A537A0	3192 108139	ELIZAVETA SOKOLOVA	{"phone": "+70791626290"}
0005433342230	A537A0	6543 048894	DAVID IVANOV	{"email": "ivanovd25061979@postgrespro.ru", "phone": "+70037865513"}
0005433342231	CA3CAF	2207 587162	GENNADIY MIKHAYLOV	{"email": "gennadiy.mikhaylov.26121965@postgrespro.ru", "phone": "+70240568255"}
0005433342232	A793B4	1795 729848	NELLI KOVALEVA	{"phone": "+70846855248"}
0005433342233	B4E760	1741 030566	SERGEY FOMIN	{"phone": "+70267278975"}
0005433342234	B4E760	5674 408927	SVETLANA TARASOVA	{"phone": "+70378096663"}
0005433342235	B4E760	1113 758813	POLINA ALEKSEEVA	{"email": "alekseeva-polina_31031981@postgrespro.ru", "phone": "+70955512391"}
0005433342236	128BBA	0190 173192	IRINA SIDOROVA	{"email": "sidorovairina-121984@postgrespro.ru", "phone": "+70839682258"}
0005433342237	032BB7	2060 773360	LYUDMILA SERGEEVA	{"email": "sergeeva_lyudmila-071967@postgrespro.ru", "phone": "+70665068039"}
0005433342238	032BB7	6324 855684	NATALYA FILIPPOVA	{"phone": "+70178213177"}
0005433342239	705997	3369 598995	POLINA VOLKOVA	{"email": "volkova_polina061972@postgrespro.ru", "phone": "+70941976389"}
0005433342240	705997	6666 346951	MAKSIM MOISEEV	{"email": "moiseev-m_1970@postgrespro.ru", "phone": "+70146074855"}
0005433342241	5ABC62	2827 843824	RASIM BARANOV	{"email": "baranovr.121972@postgrespro.ru", "phone": "+70509563599"}
0005433342242	601AA8	5248 372035	ALEKSEY POPOV	{"phone": "+70708601783"}
0005433342243	601AA8	7538 283429	YANA MOROZOVA	{"email": "morozova_yana1965@postgrespro.ru", "phone": "+70198239487"}
0005433342244	4141A0	4527 964788	IRINA MOROZOVA	{"email": "i.morozova_021970@postgrespro.ru", "phone": "+70043179908"}
0005433342245	4141A0	6314 500941	MARINA SAVELEVA	{"email": "m_saveleva_1975@postgrespro.ru", "phone": "+70170854791"}
0005433342246	3261D7	4028 538362	NADEZHDA MAKSIMOVA	{"phone": "+70518760285"}
0005433342247	DACB9D	2382 324985	ALEKSANDR POPOV	{"email": "aleksandr.popov_11081969@postgrespro.ru", "phone": "+70973011588"}
0005433342248	3B1AA2	2913 889327	EVGENIYA VASILEVA	{"phone": "+70453826160"}
0005433342249	3B1AA2	0202 408041	YULIYA ARKHIPOVA	{"email": "arkhipovay-061965@postgrespro.ru", "phone": "+70501968583"}
0005433342250	38D623	5984 138233	GALINA KAZAKOVA	{"email": "galina-kazakova071971@postgrespro.ru", "phone": "+70276700837"}
0005433342251	38D623	3969 055018	RASHIT IVANOV	{"email": "rashit.ivanov1970@postgrespro.ru", "phone": "+70880387912"}
0005433342252	7318B0	5111 409914	OLEG DAVYDOV	{"email": "davydov-oleg.03041969@postgrespro.ru", "phone": "+70289292192"}
0005433342253	7318B0	7241 908270	ILYA SMIRNOV	{"phone": "+70545968440"}
0005433342254	4B55FC	3100 128980	PAVEL IVANOV	{"email": "ivanov_pavel.011967@postgrespro.ru", "phone": "+70759054664"}
0005433342255	0F9217	8299 118361	VALENTINA LOGINOVA	{"email": "loginova_valentina-18071963@postgrespro.ru", "phone": "+70609589639"}
0005433342256	0F9217	6936 925264	RAMIL KOZLOV	{"phone": "+70618052014"}
0005433342257	0F9217	2641 294496	NATALIYA YAKOVLEVA	{"phone": "+70252735060"}
0005433342258	357CE7	8467 242047	YULIYA NOVIKOVA	{"email": "novikova-yuliya-111974@postgrespro.ru", "phone": "+70661376972"}
0005433342259	243C19	2092 897084	LIDIYA KUZMINA	{"email": "lidiya.kuzmina_111965@postgrespro.ru", "phone": "+70588963103"}
0005433342260	7CC4D0	1179 265989	ILYA PETROV	{"email": "ilyapetrov_1979@postgrespro.ru", "phone": "+70730387129"}
0005433342261	1C93CE	0051 537240	NINA MEDVEDEVA	{"phone": "+70385061720"}
0005433342262	013D07	2411 800920	VLADIMIR ZHURAVLEV	{"email": "zhuravlevv.17071967@postgrespro.ru", "phone": "+70537805357"}
0005433342263	013D07	5119 405284	OLESYA FILATOVA	{"phone": "+70893929845"}
0005433342264	013D07	5223 402977	MAYYA ISAEVA	{"email": "m_isaeva-1962@postgrespro.ru", "phone": "+70605804002"}
0005433342265	BE5A74	4837 718683	TATYANA PAVLOVA	{"email": "tatyana.pavlova091965@postgrespro.ru", "phone": "+70270029940"}
0005433342266	08C4EA	7802 056873	VERA BARANOVA	{"email": "vera_baranova1969@postgrespro.ru", "phone": "+70539009100"}
0005433342267	08C4EA	4382 046432	VALERIY DENISOV	{"email": "denisovvaleriy.15021958@postgrespro.ru", "phone": "+70566432863"}
0005433342268	08C4EA	1725 923861	DENIS ABRAMOV	{"phone": "+70147968839"}
0005433342269	8A763B	7066 857811	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev.081967@postgrespro.ru", "phone": "+70146988389"}
0005433342270	E83366	3180 441508	ELENA MASLOVA	{"email": "e_maslova1973@postgrespro.ru", "phone": "+70168398502"}
0005433342271	A8580C	0137 948162	VIKTOR MAKAROV	{"phone": "+70525753325"}
0005433342272	6718F8	4325 468038	VALENTINA BELOVA	{"email": "valentinabelova.071968@postgrespro.ru", "phone": "+70419273681"}
0005433342273	BAFE62	2620 064218	ARTEM ORLOV	{"email": "orlov_artem-1972@postgrespro.ru", "phone": "+70390519400"}
0005433342274	BAFE62	3977 924215	VLADIMIR MELNIKOV	{"phone": "+70491930887"}
0005433342275	D82819	6157 217718	DINA ILINA	{"email": "d_ilina.011968@postgrespro.ru", "phone": "+70341865659"}
0005433342276	6B1FDE	9979 763371	ELIZAVETA SCHERBAKOVA	{"phone": "+70805972359"}
0005433342277	18F09F	3758 679365	SERGEY MATVEEV	{"phone": "+70233610271"}
0005433342278	0E36DF	8572 492956	MIKHAIL GAVRILOV	{"email": "gavrilov_m-1964@postgrespro.ru", "phone": "+70011568173"}
0005433342279	BF9F2D	6284 256462	EKATERINA KONOVALOVA	{"email": "ekaterina.konovalova_1974@postgrespro.ru", "phone": "+70689626623"}
0005433342280	359816	6128 297994	ZINAIDA FILIPPOVA	{"email": "z_filippova1977@postgrespro.ru", "phone": "+70441770471"}
0005433342281	E77C94	9381 245124	ANTONINA IVANOVA	{"phone": "+70619072078"}
0005433342282	4EC46E	2482 015840	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev_06101978@postgrespro.ru", "phone": "+70825410356"}
0005433342283	3C74C4	5272 462804	VLADIMIR MOISEEV	{"phone": "+70216725102"}
0005433342284	3C74C4	3774 617515	MIKHAIL ILIN	{"phone": "+70962076569"}
0005433342285	8E7DA5	9102 296063	SERGEY BELOV	{"email": "sergey_belov26121976@postgrespro.ru", "phone": "+70415662707"}
0005433342286	D8294D	0126 976495	ANNA POPOVA	{"email": "a_popova11081968@postgrespro.ru", "phone": "+70170211947"}
0005433342287	90823D	7567 360991	EVGENIY SAVELEV	{"phone": "+70459512240"}
0005433342288	90823D	7470 986096	MARIYA ISAEVA	{"phone": "+70705763968"}
0005433342289	223843	0792 247798	SVETLANA KUDRYASHOVA	{"phone": "+70570302468"}
0005433342290	CD52B9	5720 020803	GALINA NOVIKOVA	{"email": "novikova.g_051970@postgrespro.ru", "phone": "+70260862678"}
0005433342291	5415B3	7692 033520	VIKTOR NIKITIN	{"email": "nikitin_v28041973@postgrespro.ru", "phone": "+70911769966"}
0005433342292	2CC292	0035 793531	LYUDMILA IVANOVA	{"phone": "+70341339026"}
0005433342293	2CC292	5130 099979	ALEKSANDR MARTYNOV	{"email": "amartynov-28101978@postgrespro.ru", "phone": "+70497333282"}
0005433342294	63CFEC	8239 646470	PETR RODIONOV	{"email": "prodionov_03071975@postgrespro.ru", "phone": "+70380964548"}
0005433342295	05C7B7	1188 582189	GALINA VOROBEVA	{"phone": "+70061070925"}
0005433342296	8C5357	2923 614194	NINA EGOROVA	{"phone": "+70857498606"}
0005433342297	8C5357	6398 452261	ANTONINA MIKHAYLOVA	{"phone": "+70660283360"}
0005433342298	8C5357	9200 817666	EKATERINA NIKOLAEVA	{"phone": "+70695481193"}
0005433342299	39848B	6697 696283	LARISA MASLOVA	{"email": "maslova-larisa.1975@postgrespro.ru", "phone": "+70795271078"}
0005433342300	39848B	8626 820901	FARID TARASOV	{"email": "tarasovf-03051969@postgrespro.ru", "phone": "+70003266209"}
0005433342301	8F5C23	7054 796864	NINA NESTEROVA	{"email": "nesterovan.071974@postgrespro.ru", "phone": "+70122626910"}
0005433342302	0092B6	2911 988587	SERGEY IVANOV	{"email": "ivanovsergey-021979@postgrespro.ru", "phone": "+70128330579"}
0005433342303	33BA32	3244 767738	OLEG SCHERBAKOV	{"phone": "+70064615405"}
0005433342304	418E43	1257 253006	ALEKSANDR MATVEEV	{"phone": "+70519552722"}
0005433342305	418E43	7668 662325	VALERIY MIRONOV	{"email": "mironov-v_101976@postgrespro.ru", "phone": "+70266981218"}
0005433342306	418E43	8191 705467	SERGEY ANTONOV	{"email": "s-antonov_1964@postgrespro.ru", "phone": "+70971177635"}
0005433342307	988FF2	6897 262317	PAVEL IVANOV	{"email": "p.ivanov1976@postgrespro.ru", "phone": "+70331472185"}
0005433342308	6F5DE6	1682 144762	VARVARA NESTEROVA	{"email": "varvara-nesterova-18031967@postgrespro.ru", "phone": "+70921153141"}
0005433342640	86C7FF	4865 398702	LYUDMILA MAKSIMOVA	{"phone": "+70355306085"}
0005433342309	D158B1	5251 350002	IOSIF DAVYDOV	{"email": "iosif_davydov-1973@postgrespro.ru", "phone": "+70663414506"}
0005433342310	913740	3374 263827	ANDREY AFANASEV	{"email": "afanasev.andrey_1985@postgrespro.ru", "phone": "+70095211893"}
0005433342311	29F30F	0644 040698	ANASTASIYA FROLOVA	{"phone": "+70510796400"}
0005433342312	FF04AF	5516 546805	NATALYA VOROBEVA	{"email": "vorobevanatalya1976@postgrespro.ru", "phone": "+70621633929"}
0005433342313	52CE64	6845 644153	ANTONINA IVANOVA	{"phone": "+70509646698"}
0005433342314	2F3F37	3615 953977	NINA BARANOVA	{"phone": "+70891401243"}
0005433342315	9AA2AD	1848 675232	OLGA OVCHINNIKOVA	{"email": "ovchinnikova-olga-111966@postgrespro.ru", "phone": "+70761306074"}
0005433342316	D6DD22	0024 432471	MIKHAIL ZHUKOV	{"email": "mikhail_zhukov-021967@postgrespro.ru", "phone": "+70296437104"}
0005433342317	D6DD22	0739 240245	NADEZHDA MATVEEVA	{"email": "nadezhda.matveeva_1975@postgrespro.ru", "phone": "+70105220055"}
0005433342318	78A3B1	7602 255729	SERGEY ILIN	{"phone": "+70258366125"}
0005433342319	78A3B1	1893 424494	MARIYA ARKHIPOVA	{"phone": "+70999089138"}
0005433342320	78A3B1	6518 777591	ANDREY SEMENOV	{"email": "semenov-andrey031974@postgrespro.ru", "phone": "+70693772139"}
0005433342321	9879B4	9374 295874	SVETLANA POPOVA	{"phone": "+70968428487"}
0005433342322	867554	2653 016653	ALEKSEY KUZMIN	{"email": "akuzmin_28101962@postgrespro.ru", "phone": "+70245794534"}
0005433342323	E8C2F5	3302 810969	VIKTOR TIMOFEEV	{"phone": "+70374442523"}
0005433342324	CB84BA	4335 589057	OLEG VASILEV	{"phone": "+70325758949"}
0005433342325	BFFB88	3290 650676	VALENTINA DMITRIEVA	{"phone": "+70743232427"}
0005433342326	7DCDE0	1801 650172	IRINA MOROZOVA	{"phone": "+70310582213"}
0005433342327	7DCDE0	1759 310791	DARYA SOKOLOVA	{"phone": "+70875814835"}
0005433342328	869427	1105 197546	SERAFIMA KOZLOVA	{"phone": "+70867743109"}
0005433342329	869427	0842 570171	DMITRIY FEDOTOV	{"phone": "+70399336518"}
0005433342330	324846	0337 628452	ALEKSANDR NAZAROV	{"phone": "+70458537737"}
0005433342331	0C916B	2007 084070	MARIYA GORBUNOVA	{"email": "gorbunova.mariya.1981@postgrespro.ru", "phone": "+70974749309"}
0005433342332	0C916B	4345 396028	VADIM VOROBEV	{"phone": "+70540809471"}
0005433342333	C8B28E	2355 206040	ELENA ALEKSANDROVA	{"email": "elena_aleksandrova.11111971@postgrespro.ru", "phone": "+70733003385"}
0005433342334	5F1159	6376 505685	POLINA SMIRNOVA	{"email": "psmirnova-1965@postgrespro.ru", "phone": "+70652049440"}
0005433342335	9E6326	4985 784793	SVETLANA NOVIKOVA	{"phone": "+70650092256"}
0005433342336	177C6B	5841 477697	MARINA ZHUKOVA	{"phone": "+70213997368"}
0005433342337	D2D040	6232 060394	ALEKSANDR STEPANOV	{"phone": "+70865308776"}
0005433342338	D3BC11	2133 746136	DMITRIY GERASIMOV	{"phone": "+70242948717"}
0005433342339	D3BC11	1477 420537	ANNA STEPANOVA	{"phone": "+70871230047"}
0005433342340	022F77	1014 175467	ELENA LOGINOVA	{"email": "e.loginova101969@postgrespro.ru", "phone": "+70965462823"}
0005433342341	0B70D2	4411 410888	NAIL IVANOV	{"phone": "+70933085374"}
0005433342342	332794	8211 010977	SERGEY MAKAROV	{"email": "sergeymakarov_12051969@postgrespro.ru", "phone": "+70469184522"}
0005433342343	82B9D3	9178 995500	ALEKSEY CHERNOV	{"phone": "+70580039570"}
0005433342344	0965CD	2945 780420	DENIS ZAKHAROV	{"email": "denis-zakharov_02091974@postgrespro.ru", "phone": "+70861094763"}
0005433342345	0965CD	3960 857405	ANDREY MOROZOV	{"email": "andreymorozov.07021980@postgrespro.ru", "phone": "+70382246443"}
0005433342346	191BCC	4325 216954	ALBINA AFANASEVA	{"email": "albinaafanaseva011981@postgrespro.ru", "phone": "+70929309918"}
0005433342347	191BCC	8190 004275	SERGEY MIKHAYLOV	{"phone": "+70602200980"}
0005433342348	144F93	7284 749901	IVAN BORISOV	{"email": "borisovivan.071972@postgrespro.ru", "phone": "+70655175830"}
0005433342349	144F93	1545 184456	VALENTINA KUDRYASHOVA	{"email": "vkudryashova04011973@postgrespro.ru", "phone": "+70276883937"}
0005433342350	D139FF	1469 585160	IRINA FEDOROVA	{"email": "irina.fedorova_15031969@postgrespro.ru", "phone": "+70853354582"}
0005433342351	D139FF	9093 259623	RINAT AFANASEV	{"phone": "+70103355294"}
0005433342352	D139FF	7728 310960	EVGENIYA CHERNOVA	{"phone": "+70100103902"}
0005433342353	21423C	3894 867122	LYUDMILA SMIRNOVA	{"email": "smirnova_lyudmila.1992@postgrespro.ru", "phone": "+70102828881"}
0005433342354	37C43B	8511 741139	KONSTANTIN VASILEV	{"email": "vasilev.konstantin-08091981@postgrespro.ru", "phone": "+70425816058"}
0005433342355	143D24	4350 471873	EKATERINA TIMOFEEVA	{"email": "e-timofeeva_19071971@postgrespro.ru", "phone": "+70085990378"}
0005433342356	143D24	9447 736632	NINA KOROLEVA	{"phone": "+70888900729"}
0005433342357	1FDA8C	9678 973413	EKATERINA KOROLEVA	{"phone": "+70649539357"}
0005433342358	1F454A	5096 489067	LYUDMILA NAZAROVA	{"phone": "+70505242408"}
0005433342359	1F454A	3940 034280	ALI SOROKIN	{"email": "a.sorokin.13031972@postgrespro.ru", "phone": "+70088978586"}
0005433342360	1F454A	1803 674107	ALINA FILATOVA	{"phone": "+70632516496"}
0005433342361	828EE2	7142 565016	ANTONINA STEPANOVA	{"email": "stepanova_a_1967@postgrespro.ru", "phone": "+70831872582"}
0005433342362	20855E	2958 856401	ANNA NAUMOVA	{"email": "a.naumova1979@postgrespro.ru", "phone": "+70666946294"}
0005433342363	20855E	7138 731039	ANTONINA NAZAROVA	{"email": "nazarova_antonina1973@postgrespro.ru", "phone": "+70010542911"}
0005433342364	68BD21	9684 639190	ANASTASIYA ISAEVA	{"email": "isaevaa071967@postgrespro.ru", "phone": "+70340655610"}
0005433342365	1CFC0D	6646 646515	VIKTOR KUZNECOV	{"email": "viktorkuznecov1965@postgrespro.ru", "phone": "+70022097623"}
0005433342366	CDF067	3564 267617	ALENA KUZMINA	{"email": "alena.kuzmina_17021977@postgrespro.ru", "phone": "+70341196195"}
0005433342367	A5648E	7514 764351	ANNA DENISOVA	{"phone": "+70095444256"}
0005433342368	A5648E	9271 274378	MARIANNA SIDOROVA	{"email": "mariannasidorova.1969@postgrespro.ru", "phone": "+70998862694"}
0005433342369	238954	5390 980641	SERGEY SOKOLOV	{"email": "sokolov_s.13041966@postgrespro.ru", "phone": "+70814026965"}
0005433342370	238954	0352 639489	VLADIMIR SEMENOV	{"email": "vsemenov041963@postgrespro.ru", "phone": "+70607033686"}
0005433342371	343643	9032 048911	DENIS KUZNECOV	{"email": "denis.kuznecov1972@postgrespro.ru", "phone": "+70127976126"}
0005433342372	3610D8	3746 878481	ALEKSEY ANDREEV	{"phone": "+70537311974"}
0005433342373	3FA7E1	2509 959994	RAVIL IVANOV	{"email": "ravil_ivanov_041967@postgrespro.ru", "phone": "+70037653723"}
0005433342374	3FA7E1	2974 962787	DENIS KUZNECOV	{"phone": "+70089873324"}
0005433342375	F139CF	4330 300609	EKATERINA NESTEROVA	{"phone": "+70342730536"}
0005433342376	25A201	6856 192305	ANASTASIYA KOMAROVA	{"email": "a.komarova.1965@postgrespro.ru", "phone": "+70560457840"}
0005433342377	B0E83D	2022 672922	VIKTOR NAUMOV	{"phone": "+70369768339"}
0005433342378	B3AE7A	4779 035697	SERGEY KULIKOV	{"email": "kulikovsergey29031984@postgrespro.ru", "phone": "+70922991524"}
0005433342379	4FAB86	6010 552279	KONSTANTIN NOVIKOV	{"email": "k_novikov-01071978@postgrespro.ru", "phone": "+70553525350"}
0005433342380	596623	3169 400583	FEDOR MARTYNOV	{"email": "martynov_fedor_1977@postgrespro.ru", "phone": "+70920046690"}
0005433342381	3E1FBE	0948 986817	NIKITA ALEKSEEV	{"email": "n.alekseev-1971@postgrespro.ru", "phone": "+70128015759"}
0005433342382	104D4A	5435 271230	NADEZHDA LUKYANOVA	{"email": "nadezhda-lukyanova.021981@postgrespro.ru", "phone": "+70237658856"}
0005433342383	65790B	1471 976819	TATYANA SAVELEVA	{"email": "t_saveleva.17031966@postgrespro.ru", "phone": "+70880998010"}
0005433342384	65790B	4392 512405	PAVEL SMIRNOV	{"email": "smirnov-p.10071976@postgrespro.ru", "phone": "+70965146075"}
0005433342385	D2888F	0719 078765	ANATOLIY IVANOV	{"email": "anatoliy-ivanov1968@postgrespro.ru", "phone": "+70932747328"}
0005433342386	0CF747	9254 771240	NIKOLAY ANTONOV	{"phone": "+70336455954"}
0005433342387	0CF747	7974 129988	ANASTASIYA SEMENOVA	{"phone": "+70544651141"}
0005433342388	F8B74B	7813 629462	OLGA LUKYANOVA	{"email": "lukyanova.o1971@postgrespro.ru", "phone": "+70389999908"}
0005433342389	D2FAD2	6559 777552	ALEKSANDR VOROBEV	{"email": "a-vorobev24071973@postgrespro.ru", "phone": "+70970636880"}
0005433342390	6790EB	1252 255553	TATYANA ANTONOVA	{"email": "antonova.t.08011976@postgrespro.ru", "phone": "+70187209906"}
0005433342391	6790EB	5895 492813	ALEKSANDR ZAYCEV	{"email": "a_zaycev.13121975@postgrespro.ru", "phone": "+70839732428"}
0005433342392	AF1DF7	7501 142270	MARINA ORLOVA	{"phone": "+70339308479"}
0005433342393	E253AB	1275 373955	ANASTASIYA TIMOFEEVA	{"email": "timofeeva_anastasiya031974@postgrespro.ru", "phone": "+70782393877"}
0005433342394	79C84A	7731 308525	GALINA FROLOVA	{"email": "g_frolova24071973@postgrespro.ru", "phone": "+70918432484"}
0005433342395	F72632	2098 005127	ALLA ZAKHAROVA	{"phone": "+70272234207"}
0005433342396	1CD202	9331 911098	TAMARA VLASOVA	{"email": "tvlasova-05091969@postgrespro.ru", "phone": "+70185271132"}
0005433342397	1CD202	8886 241192	VLADISLAV ZAKHAROV	{"phone": "+70201130949"}
0005433342398	1CD202	8704 839989	TATYANA YAKOVLEVA	{"phone": "+70537153167"}
0005433342399	698D52	8148 371029	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-1972@postgrespro.ru", "phone": "+70617198308"}
0005433342400	6CF16B	5692 959188	ELENA NIKIFOROVA	{"email": "elena-nikiforova_101960@postgrespro.ru", "phone": "+70244298428"}
0005433342401	A87BE2	3476 290273	NADEZHDA IVANOVA	{"email": "ivanovanadezhda-21121967@postgrespro.ru", "phone": "+70182388902"}
0005433342402	A87BE2	1874 171759	ALEKSEY SEMENOV	{"email": "semenov.a-05051978@postgrespro.ru", "phone": "+70609329245"}
0005433342403	B1CCCB	1654 695725	NATALYA POPOVA	{"email": "natalya-popova13101965@postgrespro.ru", "phone": "+70349869251"}
0005433342404	C345CB	0595 233551	YULIYA FILATOVA	{"email": "y.filatova.25101977@postgrespro.ru", "phone": "+70049825004"}
0005433342405	280B2F	1612 219719	BORIS MELNIKOV	{"phone": "+70942641375"}
0005433342406	B871C8	2605 149880	ANDREY PETROV	{"phone": "+70028822310"}
0005433342407	B871C8	9663 552746	ANASTASIYA GRISHINA	{"phone": "+70881326101"}
0005433342408	47D77A	2010 368690	VITALIY FEDOROV	{"phone": "+70773017394"}
0005433342409	47D77A	3411 083169	YULIYA NESTEROVA	{"phone": "+70685836539"}
0005433342410	59ADA2	0902 898796	VLADIMIR ORLOV	{"email": "orlov.vladimir.121958@postgrespro.ru", "phone": "+70825018978"}
0005433342411	84EB3D	5689 073734	LARISA GAVRILOVA	{"email": "larisagavrilova.061976@postgrespro.ru", "phone": "+70634539357"}
0005433342412	E84E1E	5926 243046	OLGA BELYAEVA	{"email": "olgabelyaeva_121972@postgrespro.ru", "phone": "+70156946668"}
0005433342413	E84E1E	0431 805592	DANIIL MIKHAYLOV	{"email": "daniil_mikhaylov-061973@postgrespro.ru", "phone": "+70237329936"}
0005433342414	39A31E	0019 640272	YURIY KRASNOV	{"email": "krasnovyuriy_091978@postgrespro.ru", "phone": "+70046204555"}
0005433342415	39A31E	5903 881607	LYUDMILA PAVLOVA	{"email": "pavloval091981@postgrespro.ru", "phone": "+70837825183"}
0005433342416	11FCE3	9883 982296	NATALYA KRASNOVA	{"email": "krasnova.natalya.1971@postgrespro.ru", "phone": "+70323805480"}
0005433342417	09E9CA	6000 668181	ALEKSEY VASILEV	{"phone": "+70520824768"}
0005433342418	D07952	9852 719007	OLESYA LAZAREVA	{"phone": "+70258952943"}
0005433342752	135275	0126 131888	VALERIYA PAVLOVA	{"phone": "+70470935387"}
0005433342419	DB0B5E	6350 781120	ANASTASIYA ERMAKOVA	{"email": "a_ermakova.121968@postgrespro.ru", "phone": "+70542815683"}
0005433342420	02C8EC	3765 108281	SERGEY KUZNECOV	{"email": "kuznecov.s.071983@postgrespro.ru", "phone": "+70684575912"}
0005433342421	02C8EC	6578 789220	VIKTORIYA KONOVALOVA	{"email": "konovalova-viktoriya021972@postgrespro.ru", "phone": "+70157498069"}
0005433342422	D48F9D	9408 863350	DMITRIY CHERNOV	{"phone": "+70483027046"}
0005433342423	D48F9D	9652 992262	ALEKSANDR IVANOV	{"phone": "+70861210156"}
0005433342424	1F081C	5155 015262	TATYANA KUZNECOVA	{"email": "t_kuznecova-17121971@postgrespro.ru", "phone": "+70600658861"}
0005433342425	1F081C	1997 131297	TAISIYA EFIMOVA	{"email": "t-efimova.1976@postgrespro.ru", "phone": "+70169515954"}
0005433342426	1F081C	2117 213123	EVGENIY GRIGOREV	{"email": "e-grigorev-101975@postgrespro.ru", "phone": "+70043656307"}
0005433342427	3ABAC7	0581 839165	EVGENIY ZHUKOV	{"phone": "+70637052783"}
0005433342428	3ABAC7	6597 411184	VLADIMIR BONDARENKO	{"email": "v-bondarenko-051971@postgrespro.ru", "phone": "+70183198197"}
0005433342429	0F00F3	3119 264399	ELENA VOLKOVA	{"email": "elena.volkova-1970@postgrespro.ru", "phone": "+70154605423"}
0005433342430	0F00F3	8707 629228	EVGENIY BELOV	{"phone": "+70261947167"}
0005433342431	96E3BA	5492 178231	ALEKSANDR STEPANOV	{"phone": "+70400647430"}
0005433342432	42F58F	3542 524457	SERGEY MOISEEV	{"email": "moiseev_sergey-1977@postgrespro.ru", "phone": "+70361340460"}
0005433342433	4DD3E6	3798 219494	EKATERINA FILIPPOVA	{"email": "efilippova_1977@postgrespro.ru", "phone": "+70574994108"}
0005433342434	053042	0978 291226	GRIGORIY IVANOV	{"email": "g.ivanov.081973@postgrespro.ru", "phone": "+70934420061"}
0005433342435	053042	0150 807085	EVGENIY SIDOROV	{"phone": "+70421034843"}
0005433342436	B0F1DE	0731 758368	NONNA POPOVA	{"email": "popovanonna.1972@postgrespro.ru", "phone": "+70875765983"}
0005433342437	B0F1DE	5329 892694	VIKTOR SIDOROV	{"phone": "+70926716479"}
0005433342438	7C4937	9869 297602	GALINA IVANOVA	{"email": "galina-ivanova.031985@postgrespro.ru", "phone": "+70377231077"}
0005433342439	7C4937	8878 843541	VENIAMIN TARASOV	{"phone": "+70329418610"}
0005433342440	194A0B	4886 201547	VLADIMIR YAKOVLEV	{"email": "vladimiryakovlev.031984@postgrespro.ru", "phone": "+70070728688"}
0005433342441	D0408A	5640 198561	YULIYA RODIONOVA	{"email": "y-rodionova-051971@postgrespro.ru", "phone": "+70654193456"}
0005433342442	D0408A	2348 657944	RUSTEM KOROLEV	{"phone": "+70160858785"}
0005433342443	D0408A	6124 994097	VALERIY MIKHAYLOV	{"email": "valeriymikhaylov_1974@postgrespro.ru", "phone": "+70743871627"}
0005433342444	1C62DA	6059 485180	DINARA MOISEEVA	{"email": "moiseeva-dinara_091966@postgrespro.ru", "phone": "+70742832682"}
0005433342445	133472	6954 644773	ANNA MATVEEVA	{"phone": "+70032810947"}
0005433342446	133472	2915 147520	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy041959@postgrespro.ru", "phone": "+70772655449"}
0005433342447	FDB920	8181 783183	DARYA VASILEVA	{"email": "d-vasileva.30111970@postgrespro.ru", "phone": "+70349183647"}
0005433342448	FDB920	1760 173899	ALEKSANDR POPOV	{"email": "popovaleksandr.03061979@postgrespro.ru", "phone": "+70887101243"}
0005433342449	D4A86E	0823 347823	KONSTANTIN KOROLEV	{"phone": "+70524882925"}
0005433342450	859108	5728 508514	ALEKSANDRA ORLOVA	{"phone": "+70542815465"}
0005433342451	859108	2386 531155	NIKOLAY SERGEEV	{"email": "nikolay.sergeev-19051973@postgrespro.ru", "phone": "+70781275670"}
0005433342452	325DA0	1385 319350	ANDREY MAKAROV	{"email": "makarov-a.03021963@postgrespro.ru", "phone": "+70026454709"}
0005433342453	325DA0	8809 333548	IRINA SAVELEVA	{"email": "saveleva_irina071977@postgrespro.ru", "phone": "+70168955574"}
0005433342454	3180B4	8215 003383	OLEG MATVEEV	{"email": "matveevo_1959@postgrespro.ru", "phone": "+70863589997"}
0005433342455	DD4191	4768 274006	TATYANA LUKYANOVA	{"email": "lukyanova_t-04031970@postgrespro.ru", "phone": "+70368563156"}
0005433342456	DD4191	4276 019049	VIKTOR YAKOVLEV	{"email": "yakovlev_v1969@postgrespro.ru", "phone": "+70343338863"}
0005433342457	F2255F	3691 136537	OLEG SIDOROV	{"phone": "+70656962425"}
0005433342458	7D1E56	7980 658609	PETR BELOV	{"email": "p-belov-07101970@postgrespro.ru", "phone": "+70325770833"}
0005433342459	1A0555	9443 944579	EGOR IVANOV	{"phone": "+70182547810"}
0005433342460	041D21	5577 609507	DENIS GRIGOREV	{"email": "denis-grigorev_1971@postgrespro.ru", "phone": "+70037069699"}
0005433342461	041D21	5133 361519	IRINA ZHURAVLEVA	{"phone": "+70541294138"}
0005433342462	546C05	9139 668429	IVAN SOKOLOV	{"email": "sokolov-i_1970@postgrespro.ru", "phone": "+70782058554"}
0005433342463	AE5612	4376 632928	ALEKSANDR SHEVCHENKO	{"phone": "+70397182332"}
0005433342464	BD4637	0866 268603	ROMAN ALEKSEEV	{"phone": "+70766738193"}
0005433342465	20342A	4266 929481	EKATERINA FROLOVA	{"email": "e_frolova-1966@postgrespro.ru", "phone": "+70766409771"}
0005433342466	5E6D7D	8657 212315	OLGA ROMANOVA	{"email": "olga.romanova-061982@postgrespro.ru", "phone": "+70695214862"}
0005433342467	711EDC	2051 456922	NATALYA MELNIKOVA	{"phone": "+70035658607"}
0005433342468	711EDC	9121 983483	NATALYA PAVLOVA	{"email": "pavlovanatalya-121966@postgrespro.ru", "phone": "+70672283231"}
0005433342469	C1D65D	4314 419632	ALEKSEY MIRONOV	{"phone": "+70111751002"}
0005433342470	5E2D97	5692 956373	BOGDAN NIKOLAEV	{"email": "b-nikolaev-31071975@postgrespro.ru", "phone": "+70101274399"}
0005433342471	5E2D97	4664 169768	MAKSIM KOZLOV	{"email": "m_kozlov.31071962@postgrespro.ru", "phone": "+70802246825"}
0005433342472	FEA630	3179 118827	RUSLAN SAVELEV	{"email": "rsavelev_1971@postgrespro.ru", "phone": "+70542169612"}
0005433342473	125F3C	9620 508553	NINA MOROZOVA	{"phone": "+70042580676"}
0005433342474	125F3C	9209 423765	SOFIYA ANDREEVA	{"email": "andreeva.sofiya011970@postgrespro.ru", "phone": "+70622707963"}
0005433342475	A6D3C7	8480 062784	OLGA DMITRIEVA	{"phone": "+70793311514"}
0005433342476	AF5F80	7635 495653	LYUDMILA ALEKSEEVA	{"phone": "+70468493995"}
0005433342477	1F2ACC	5186 172565	NINA DENISOVA	{"email": "denisova-nina.29121975@postgrespro.ru", "phone": "+70565614877"}
0005433342478	689310	9923 199875	ELENA MAKSIMOVA	{"email": "maksimova-e.15051969@postgrespro.ru", "phone": "+70589195985"}
0005433342479	BD28F6	6753 494953	EVGENIY SOROKIN	{"phone": "+70500675628"}
0005433342480	BD28F6	9100 198111	YULIYA RYABOVA	{"email": "yuliyaryabova_1963@postgrespro.ru", "phone": "+70714943472"}
0005433342481	A11046	8755 383111	ANDREY KUZNECOV	{"email": "kuznecov-andrey1965@postgrespro.ru", "phone": "+70445662905"}
0005433342482	7E7436	5673 381992	NATALIYA OVCHINNIKOVA	{"phone": "+70478754417"}
0005433342483	654D12	4811 214406	OLGA POPOVA	{"phone": "+70277903779"}
0005433342484	654D12	2064 200784	EKATERINA SAVELEVA	{"phone": "+70528834310"}
0005433342485	5A5197	7836 895640	ARTEM VASILEV	{"email": "vasilev_artem_1980@postgrespro.ru", "phone": "+70153142919"}
0005433342486	5A5197	1821 748127	ALENA IVANOVA	{"phone": "+70540346691"}
0005433342487	772BB8	6467 170692	NATALYA PAVLOVA	{"phone": "+70271025129"}
0005433342488	772BB8	8701 131251	MARIYA KULIKOVA	{"email": "kulikovamariya.1970@postgrespro.ru", "phone": "+70090275331"}
0005433342489	D9F901	7699 422957	PAVEL NIKOLAEV	{"email": "nikolaevpavel25101980@postgrespro.ru", "phone": "+70308313378"}
0005433342490	396519	5820 292236	TAMARA SIDOROVA	{"email": "tamara.sidorova.1971@postgrespro.ru", "phone": "+70423819510"}
0005433342491	396519	4202 689741	RAISA SOROKINA	{"email": "sorokinaraisa_091961@postgrespro.ru", "phone": "+70915008997"}
0005433342492	634738	2240 940800	ZOYA POPOVA	{"phone": "+70426863882"}
0005433342493	7257A6	2813 896727	IRINA PAVLOVA	{"phone": "+70201574283"}
0005433342494	B56976	3716 703373	GRIGORIY ZAKHAROV	{"email": "zakharovgrigoriy-1978@postgrespro.ru", "phone": "+70198418085"}
0005433342495	B56976	1657 205121	YURIY PETROV	{"phone": "+70919534601"}
0005433342496	ECB110	5282 551853	VYACHESLAV KRASNOV	{"email": "v-krasnov-081980@postgrespro.ru", "phone": "+70846293058"}
0005433342497	ECB110	2865 745891	VALENTINA KOROLEVA	{"email": "valentinakoroleva.111971@postgrespro.ru", "phone": "+70940124541"}
0005433342498	196F66	3100 118182	OLGA NIKITINA	{"email": "nikitina.olga-1971@postgrespro.ru", "phone": "+70586831702"}
0005433342499	5C700D	2028 290669	VLADIMIR BELOV	{"email": "vbelov071969@postgrespro.ru", "phone": "+70780348060"}
0005433342500	1B4019	7248 567444	DMITRIY NIKITIN	{"email": "dnikitin-09101989@postgrespro.ru", "phone": "+70339241163"}
0005433342501	4253E1	3933 769096	ALEKSANDR RODIONOV	{"email": "a_rodionov1966@postgrespro.ru", "phone": "+70551509905"}
0005433342502	480120	2945 052999	VLADIMIR RODIONOV	{"phone": "+70507475730"}
0005433342503	480120	4699 229767	MIKHAIL SIDOROV	{"email": "msidorov_1974@postgrespro.ru", "phone": "+70129684296"}
0005433342504	0FC360	5386 262610	SERGEY KOROLEV	{"email": "korolevs_1977@postgrespro.ru", "phone": "+70327613894"}
0005433342505	75D106	0298 842930	ANATOLIY SCHERBAKOV	{"email": "a.scherbakov.071982@postgrespro.ru", "phone": "+70375191996"}
0005433342506	85DBD7	1116 195016	OLGA SAVELEVA	{"email": "savelevao.1967@postgrespro.ru", "phone": "+70651813178"}
0005433342507	85DBD7	4759 473441	ELENA KUZNECOVA	{"phone": "+70442561722"}
0005433342508	85DBD7	3360 159974	DMITRIY MAKAROV	{"email": "d.makarov.16031977@postgrespro.ru", "phone": "+70667332330"}
0005433342509	23B639	0207 998360	IVAN BELOV	{"phone": "+70614582641"}
0005433342510	1250B1	2754 811636	ALEKSEY SMIRNOV	{"email": "asmirnov_011974@postgrespro.ru", "phone": "+70942597517"}
0005433342511	1250B1	5806 374084	RAFAIL SERGEEV	{"email": "sergeev_rafail.091980@postgrespro.ru", "phone": "+70374681113"}
0005433342512	C9D5CD	9743 632112	MAKSIM IVANOV	{"phone": "+70482890179"}
0005433342513	9F05AA	2017 948449	TATYANA AKIMOVA	{"phone": "+70185251637"}
0005433342514	009EF9	5142 219952	MARINA BORISOVA	{"phone": "+70819005092"}
0005433342515	009EF9	9767 542486	ALEKSANDR KUZMIN	{"phone": "+70564028909"}
0005433342516	6C81C0	5817 800825	DMITRIY SCHERBAKOV	{"email": "scherbakovdmitriy1973@postgrespro.ru", "phone": "+70598158023"}
0005433342517	47D554	4764 319961	VYACHESLAV MEDVEDEV	{"email": "vyacheslav-medvedev02121970@postgrespro.ru", "phone": "+70715466673"}
0005433342518	DA0858	9345 183897	ANATOLIY BONDARENKO	{"phone": "+70600031848"}
0005433342519	83C50F	8748 505618	NATALYA GORBUNOVA	{"email": "gorbunova.n.1980@postgrespro.ru", "phone": "+70350766296"}
0005433342520	CCC387	0618 897750	NADEZHDA SERGEEVA	{"email": "n_sergeeva.18081972@postgrespro.ru", "phone": "+70779783225"}
0005433342521	CCC387	5835 767034	EKATERINA TARASOVA	{"phone": "+70898386199"}
0005433342522	223C24	8299 759761	EKATERINA OVCHINNIKOVA	{"email": "ovchinnikova-e-28011977@postgrespro.ru", "phone": "+70474940177"}
0005433342523	7566AD	7192 118176	DARYA DAVYDOVA	{"phone": "+70793149642"}
0005433342524	5DD859	9659 309690	SERGEY KOZLOV	{"email": "s_kozlov.1972@postgrespro.ru", "phone": "+70981873899"}
0005433342525	5DD859	5229 786182	RUFINA PETROVA	{"email": "rpetrova_31071972@postgrespro.ru", "phone": "+70514906069"}
0005433342526	FBD67C	7881 628451	YURIY CHERNOV	{"email": "yuriychernov_071971@postgrespro.ru", "phone": "+70944579380"}
0005433342527	FBD67C	4969 137876	DMITRIY MOROZOV	{"email": "morozov_d_1971@postgrespro.ru", "phone": "+70391603584"}
0005433342528	713DCE	1846 950877	RAIL NOVIKOV	{"email": "rnovikov_1958@postgrespro.ru", "phone": "+70458111710"}
0005433342529	713DCE	9781 523369	OLGA MAKAROVA	{"email": "olga.makarova-14081973@postgrespro.ru", "phone": "+70320149019"}
0005433342530	6D5CD3	6636 333092	ELENA KUZMINA	{"email": "kuzminae_18031968@postgrespro.ru", "phone": "+70951010254"}
0005433342531	0CDD2D	5517 388455	MARIYA KOZLOVA	{"email": "kozlova_mariya_011968@postgrespro.ru", "phone": "+70814930723"}
0005433342532	9FDA95	4411 757821	DMITRIY BELOV	{"phone": "+70937110176"}
0005433342533	9FDA95	9938 711371	RAISA NESTEROVA	{"email": "raisanesterova.11081967@postgrespro.ru", "phone": "+70417687364"}
0005433342534	051D1B	0234 664750	SVETLANA ZHURAVLEVA	{"email": "s-zhuravleva.111979@postgrespro.ru", "phone": "+70062219582"}
0005433342535	FF7251	3644 805202	ALEKSEY MIKHAYLOV	{"email": "mikhaylova-021977@postgrespro.ru", "phone": "+70811188205"}
0005433342536	F126CB	5797 322253	SVETLANA KOROLEVA	{"email": "s_koroleva-1960@postgrespro.ru", "phone": "+70297613056"}
0005433342537	F126CB	0435 080535	ANISA POPOVA	{"email": "popova-anisa.1973@postgrespro.ru", "phone": "+70718116279"}
0005433342538	B30F7C	9590 959943	EVGENIYA LAZAREVA	{"email": "lazareva-evgeniya-111979@postgrespro.ru", "phone": "+70384862301"}
0005433342539	D0AF4B	5929 560254	MIKHAIL KOZLOV	{"phone": "+70511704655"}
0005433342540	487BF9	1686 436417	ANASTASIYA STEPANOVA	{"email": "stepanovaanastasiya.1981@postgrespro.ru", "phone": "+70415313616"}
0005433342541	D0B8E4	8981 120938	GALINA POLYAKOVA	{"email": "galina.polyakova031966@postgrespro.ru", "phone": "+70529580757"}
0005433342542	D0B8E4	4253 465518	SERGEY PETROV	{"email": "sergeypetrov19091974@postgrespro.ru", "phone": "+70292976619"}
0005433342543	D0B8E4	7766 940364	SERGEY SHEVCHENKO	{"email": "shevchenkosergey121978@postgrespro.ru", "phone": "+70355630294"}
0005433342544	D0B8E4	1304 358317	SVETLANA VOLKOVA	{"phone": "+70202404463"}
0005433342545	15261E	0954 213965	EKATERINA LEBEDEVA	{"email": "lebedevaekaterina-08061979@postgrespro.ru", "phone": "+70074252658"}
0005433342546	15261E	6598 843832	PETR FEDOTOV	{"phone": "+70471109714"}
0005433342547	CB14A2	6294 665819	LYUDMILA KULIKOVA	{"email": "kulikoval03111972@postgrespro.ru", "phone": "+70600645819"}
0005433342548	7D6BD9	9003 482289	YURIY BARANOV	{"phone": "+70919732698"}
0005433342549	7D6BD9	6903 659975	OLGA EFIMOVA	{"phone": "+70592487179"}
0005433342550	98EDF0	9276 251396	STANISLAV MATVEEV	{"phone": "+70650516682"}
0005433342551	ACF348	7449 747143	YULIYA TARASOVA	{"email": "tarasova-y.10071968@postgrespro.ru", "phone": "+70163472334"}
0005433342552	ACB004	0099 406116	LILIYA PETROVA	{"phone": "+70238404970"}
0005433342553	ACB004	1140 329335	RINAT ANDREEV	{"phone": "+70089663418"}
0005433342554	DB969F	0117 845995	MAKSIM VOROBEV	{"phone": "+70851496416"}
0005433342555	54E703	0503 496235	ANATOLIY KISELEV	{"email": "anatoliy_kiselev.121967@postgrespro.ru", "phone": "+70486361323"}
0005433342556	54E703	2064 642704	VITALIY VOLKOV	{"phone": "+70938466999"}
0005433342557	04C1CB	4294 950232	NINA FOMINA	{"phone": "+70378369930"}
0005433342558	CD23D1	4906 296181	ALEKSEY KUZNECOV	{"phone": "+70922366522"}
0005433342559	E1986D	4833 834997	ALEKSEY FROLOV	{"phone": "+70626292648"}
0005433342560	08D9BF	5776 536531	STEPAN ANDREEV	{"phone": "+70104322489"}
0005433342561	08D9BF	1020 242323	ALEKSEY MAKAROV	{"phone": "+70756176626"}
0005433342562	B85BD0	6688 443296	LYUDMILA NIKIFOROVA	{"email": "nikiforovalyudmila_1966@postgrespro.ru", "phone": "+70951779309"}
0005433342563	033D6B	1302 392175	RAVILYA KRASNOVA	{"email": "krasnova.r.12011975@postgrespro.ru", "phone": "+70528267128"}
0005433342564	F0BE07	3882 868294	NIKITA KUZNECOV	{"phone": "+70858786534"}
0005433342565	DA0B9A	8120 692301	ALEKSEY SAVELEV	{"phone": "+70343442559"}
0005433342566	B6B311	1054 577880	YULIYA ALEKSEEVA	{"email": "alekseevay_19081976@postgrespro.ru", "phone": "+70751230435"}
0005433342567	B6B311	7978 182870	DANIIL FROLOV	{"email": "daniil.frolov-1973@postgrespro.ru", "phone": "+70656289653"}
0005433342568	B6B311	5579 336605	ANZHELIKA IVANOVA	{"phone": "+70551523127"}
0005433342569	BE5E19	9241 697817	ALEKSANDRA NIKOLAEVA	{"email": "nikolaeva-a-09041982@postgrespro.ru", "phone": "+70061005957"}
0005433342570	36F812	8604 783457	IRINA FEDOROVA	{"phone": "+70351157091"}
0005433342571	6DD4B5	7782 997543	ANASTASIYA STEPANOVA	{"phone": "+70707044234"}
0005433342572	187076	2542 765193	ANNA ANDREEVA	{"phone": "+70820766076"}
0005433342573	187076	1857 187279	NIKITA OSIPOV	{"email": "osipov.nikita.1977@postgrespro.ru", "phone": "+70020688064"}
0005433342574	6F2D8C	0941 019645	TATYANA CHERNOVA	{"phone": "+70260494830"}
0005433342575	72D9D8	0679 778255	PETR MARTYNOV	{"email": "pmartynov29121976@postgrespro.ru", "phone": "+70867192907"}
0005433342576	2AB7BA	3409 895631	VIKTORIYA KISELEVA	{"phone": "+70692254221"}
0005433342577	7B9B12	3247 470596	KLAVDIYA NESTEROVA	{"email": "nesterova.k.081972@postgrespro.ru", "phone": "+70457708706"}
0005433342578	0730E3	0873 211559	GENNADIY MAKAROV	{"email": "makarov-g-1965@postgrespro.ru", "phone": "+70847040235"}
0005433342579	0730E3	6754 970952	GALINA PETROVA	{"phone": "+70640782517"}
0005433342580	FA4525	9550 760923	VALENTINA IVANOVA	{"email": "vivanova-09051969@postgrespro.ru", "phone": "+70099552577"}
0005433342581	480F0E	5219 300665	LYUDMILA SMIRNOVA	{"email": "lyudmilasmirnova-21051984@postgrespro.ru", "phone": "+70830167111"}
0005433342582	A3CEB6	1067 874580	MAKSIM MEDVEDEV	{"email": "maksim_medvedev_20111965@postgrespro.ru", "phone": "+70914554057"}
0005433342583	0B88E3	9964 119114	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr1965@postgrespro.ru", "phone": "+70598307935"}
0005433342753	135275	5857 815060	SERGEY MOISEEV	{"phone": "+70763686331"}
0005433342584	2BED93	4506 323595	ELENA IVANOVA	{"email": "elena_ivanova.121979@postgrespro.ru", "phone": "+70218485041"}
0005433342585	06ADFA	9498 132772	ELENA POLYAKOVA	{"email": "elena.polyakova1973@postgrespro.ru", "phone": "+70134930490"}
0005433342586	3B17C2	9332 220218	SERGEY BARANOV	{"email": "sergey-baranov1965@postgrespro.ru", "phone": "+70760877248"}
0005433342587	3B17C2	5186 561310	ELENA ERMAKOVA	{"email": "elenaermakova.14081970@postgrespro.ru", "phone": "+70610431074"}
0005433342588	DBE54E	0528 975951	SERGEY IVANOV	{"email": "sergey_ivanov.29071979@postgrespro.ru", "phone": "+70046318897"}
0005433342589	DBE54E	1729 389090	DMITRIY ZHURAVLEV	{"email": "dmitriyzhuravlev.091979@postgrespro.ru", "phone": "+70872163539"}
0005433342590	1A891A	8810 920705	ROMAN GAVRILOV	{"phone": "+70862233811"}
0005433342591	D11CD4	0806 391665	YURIY MAKAROV	{"phone": "+70545850872"}
0005433342592	B1B998	1710 604322	YULIYA SERGEEVA	{"email": "sergeevay.1979@postgrespro.ru", "phone": "+70187324027"}
0005433342593	312012	7540 913399	IVAN GUSEV	{"email": "gusev.i-1978@postgrespro.ru", "phone": "+70052618279"}
0005433342594	312012	7238 351663	RUSLAN BONDARENKO	{"email": "bondarenko-r1960@postgrespro.ru", "phone": "+70322847213"}
0005433342595	29463B	4812 020721	ANDREY AFANASEV	{"phone": "+70266237294"}
0005433342596	16559E	8244 323850	YURIY PETROV	{"email": "petrov.y22061980@postgrespro.ru", "phone": "+70739525781"}
0005433342597	31CDC1	2268 785432	NIKITA BORISOV	{"phone": "+70561877507"}
0005433342598	2D4EB8	0467 723977	YULIYA SIDOROVA	{"phone": "+70839189129"}
0005433342599	C33412	0317 378687	GALINA KAZAKOVA	{"phone": "+70166188879"}
0005433342600	AD9784	5068 229331	MIKHAIL VOLKOV	{"email": "mikhail_volkov29111972@postgrespro.ru", "phone": "+70776795906"}
0005433342601	03F7F8	4418 304293	EKATERINA KONOVALOVA	{"email": "konovalova_ekaterina03101969@postgrespro.ru", "phone": "+70814700270"}
0005433342602	336CBF	6877 346355	SVETLANA FILIPPOVA	{"email": "s.filippova_1963@postgrespro.ru", "phone": "+70812269721"}
0005433342603	336CBF	3843 775840	RIMMA NAZAROVA	{"email": "r_nazarova_26021976@postgrespro.ru", "phone": "+70311555879"}
0005433342604	E2EAAF	2573 565254	MARGARITA PETROVA	{"email": "m_petrova-1962@postgrespro.ru", "phone": "+70567933904"}
0005433342605	EA42BC	4337 598170	IGOR GUSEV	{"email": "gusevigor_1966@postgrespro.ru", "phone": "+70216309611"}
0005433342606	F2B07B	8111 094167	ALEKSANDR MARTYNOV	{"email": "martynov-aleksandr_111968@postgrespro.ru", "phone": "+70835458211"}
0005433342607	D0633A	4672 983364	VALERIY ISAEV	{"email": "isaev_v-031977@postgrespro.ru", "phone": "+70117839601"}
0005433342608	D0633A	4698 286856	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr.26121965@postgrespro.ru", "phone": "+70670912186"}
0005433342609	C8D862	9179 345279	VIKTOR VLASOV	{"phone": "+70876312731"}
0005433342610	C5277F	3835 745828	KSENIYA FROLOVA	{"phone": "+70166151737"}
0005433342611	C5277F	2292 494058	IGOR MOROZOV	{"email": "morozovi_1971@postgrespro.ru", "phone": "+70789105246"}
0005433342612	C5277F	6382 943124	ALEKSANDRA FILIPPOVA	{"phone": "+70226973574"}
0005433342613	38290A	5098 732715	SERGEY FOMIN	{"email": "sergey.fomin-06011960@postgrespro.ru", "phone": "+70025353083"}
0005433342614	38290A	5610 034724	MARINA EGOROVA	{"email": "egorova-m16081975@postgrespro.ru", "phone": "+70899925592"}
0005433342615	4352D5	6396 160509	VERA DANILOVA	{"phone": "+70196144406"}
0005433342616	4352D5	3135 076209	KUZMA YAKOVLEV	{"phone": "+70088317916"}
0005433342617	4352D5	1202 978206	MARIYA ORLOVA	{"email": "mariya.orlova-1958@postgrespro.ru", "phone": "+70068039032"}
0005433342618	5AF7A1	7133 819447	ALEKSANDR TARASOV	{"email": "tarasovaleksandr-24051975@postgrespro.ru", "phone": "+70078793282"}
0005433342619	5AF7A1	5619 536429	GALINA ZAYCEVA	{"email": "zaycevagalina_1964@postgrespro.ru", "phone": "+70207323348"}
0005433342620	0A2652	8704 491752	ALEKSANDR MOISEEV	{"phone": "+70616293709"}
0005433342621	E02B57	8236 416142	VALENTINA MATVEEVA	{"email": "v.matveeva_011983@postgrespro.ru", "phone": "+70010693933"}
0005433342622	75DBDD	5755 301738	RAMIS NIKITIN	{"email": "ramis-nikitin1967@postgrespro.ru", "phone": "+70565496071"}
0005433342623	926D69	0928 740262	GEORGIY FEDOTOV	{"phone": "+70910897848"}
0005433342624	6FD563	3853 022383	EVGENIYA POLYAKOVA	{"email": "e.polyakova30121986@postgrespro.ru", "phone": "+70288913721"}
0005433342625	B92CDF	9541 977464	GENNADIY PETROV	{"email": "petrov_g.16081966@postgrespro.ru", "phone": "+70958211006"}
0005433342626	B92CDF	1123 579868	ALEKSANDR ZHURAVLEV	{"phone": "+70988311431"}
0005433342627	B92CDF	4924 105164	OLGA MEDVEDEVA	{"phone": "+70225422058"}
0005433342628	81468B	6529 388611	KARINA ANISIMOVA	{"phone": "+70545292791"}
0005433342629	81468B	1766 137862	VYACHESLAV TIKHONOV	{"email": "tikhonov_v_021979@postgrespro.ru", "phone": "+70022855979"}
0005433342630	68A3D5	0661 181047	OLESYA EFREMOVA	{"email": "o.efremova.1971@postgrespro.ru", "phone": "+70704246287"}
0005433342631	68A3D5	7365 057084	RINAT NAZAROV	{"phone": "+70880830619"}
0005433342632	BF19E4	0975 911169	TATYANA LAZAREVA	{"email": "tatyanalazareva_1973@postgrespro.ru", "phone": "+70705593361"}
0005433342633	BF19E4	3157 173273	ANDREY KOROLEV	{"phone": "+70637362349"}
0005433342634	BF19E4	6323 128909	VIKTOR ZHUKOV	{"email": "viktor.zhukov-04071979@postgrespro.ru", "phone": "+70091051483"}
0005433342635	E9A8CD	5177 702546	NATALIYA KUZNECOVA	{"phone": "+70546828388"}
0005433342636	E9A8CD	2880 658957	ALFIYA KOZLOVA	{"phone": "+70549247204"}
0005433342637	DA0C26	0452 720491	NADEZHDA POLYAKOVA	{"phone": "+70980440794"}
0005433342638	D12B6F	9201 149691	VASILIY VOROBEV	{"phone": "+70638165096"}
0005433342641	2CFC07	5666 487779	EKATERINA SMIRNOVA	{"email": "smirnova-e.21031970@postgrespro.ru", "phone": "+70561284103"}
0005433342642	09D4BB	5590 925362	VIKTOR NOVIKOV	{"phone": "+70699083770"}
0005433342643	F74CFC	1381 919176	ALENA CHERNOVA	{"phone": "+70799017455"}
0005433342644	F74CFC	0124 122292	MAKSIM PETROV	{"email": "petrov.maksim.1989@postgrespro.ru", "phone": "+70178197515"}
0005433342645	6F5806	1185 020687	NINA VASILEVA	{"email": "n_vasileva_1964@postgrespro.ru", "phone": "+70721414152"}
0005433342646	3FEBD3	6278 819403	GENNADIY PAVLOV	{"phone": "+70803942837"}
0005433342647	9A14BF	6607 669571	NINA VOLKOVA	{"phone": "+70436408389"}
0005433342648	E6E1CD	2281 733948	IRINA KAZAKOVA	{"email": "irina_kazakova.111962@postgrespro.ru", "phone": "+70533465593"}
0005433342649	007FFF	7147 626260	EVGENIY KONOVALOV	{"phone": "+70857195797"}
0005433342650	376FCE	4835 633037	MIKHAIL ZAKHAROV	{"email": "zakharovmikhail-23041968@postgrespro.ru", "phone": "+70217064555"}
0005433342651	E858C6	1284 913289	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov-1975@postgrespro.ru", "phone": "+70409996170"}
0005433342652	258524	6246 990616	GENNADIY POPOV	{"email": "popov-gennadiy.1973@postgrespro.ru", "phone": "+70504319346"}
0005433342653	2E1ABD	0367 533919	GENNADIY STEPANOV	{"email": "g_stepanov.031976@postgrespro.ru", "phone": "+70767419294"}
0005433342654	2E1ABD	0201 859784	MARGARITA AKIMOVA	{"phone": "+70009274025"}
0005433342655	3DAF35	5209 377431	ANTONINA GERASIMOVA	{"email": "gerasimova_antonina-071976@postgrespro.ru", "phone": "+70720716944"}
0005433342656	5FEF7A	2567 804805	ELENA KARPOVA	{"email": "elena_karpova1965@postgrespro.ru", "phone": "+70660247920"}
0005433342657	5FEF7A	4275 585539	MARSEL KAZAKOV	{"email": "kazakov.m.111967@postgrespro.ru", "phone": "+70067461068"}
0005433342658	24020D	8704 212728	ARTEM VASILEV	{"phone": "+70959061359"}
0005433342659	48EB4B	8896 427289	NIKITA MAKAROV	{"email": "n.makarov-041970@postgrespro.ru", "phone": "+70079610863"}
0005433342660	0E1980	6290 540045	ANDREY TARASOV	{"phone": "+70692853880"}
0005433342661	9350FA	4731 951918	OKSANA KAZAKOVA	{"phone": "+70017718307"}
0005433342662	AD3710	3054 570132	VITALIY NAZAROV	{"phone": "+70958702881"}
0005433342663	12FA8C	8723 943745	ROMAN MIKHAYLOV	{"email": "mikhaylov_r.08061970@postgrespro.ru", "phone": "+70318776781"}
0005433342664	12FA8C	5605 402139	SVETLANA BELOVA	{"phone": "+70460585973"}
0005433342665	084AE7	9257 547863	VLADIMIR NIKOLAEV	{"phone": "+70967196724"}
0005433342666	084AE7	2898 686955	MIKHAIL MOISEEV	{"phone": "+70101821010"}
0005433342667	C22D2E	5187 112626	EVGENIY KAZAKOV	{"email": "evgeniykazakov-01081977@postgrespro.ru", "phone": "+70799111184"}
0005433342668	1AE430	5009 854543	VLADIMIR MOISEEV	{"phone": "+70803051276"}
0005433342669	3F6704	2102 102676	LYUBOV NAUMOVA	{"email": "lyubov.naumova11041967@postgrespro.ru", "phone": "+70315099756"}
0005433342670	F9426D	4932 231232	DMITRIY YAKOVLEV	{"phone": "+70649677134"}
0005433342671	C44181	0354 544575	ANZHELA MAKAROVA	{"email": "makarovaa23091978@postgrespro.ru", "phone": "+70457210672"}
0005433342672	3E2D2F	0544 867188	ELENA MAKSIMOVA	{"phone": "+70437413748"}
0005433342673	BF6955	9355 547200	VLADIMIR POPOV	{"email": "vpopov_04071963@postgrespro.ru", "phone": "+70658052169"}
0005433342674	9702A9	6102 162884	GALINA IVANOVA	{"email": "galina-ivanova-1970@postgrespro.ru", "phone": "+70114920966"}
0005433342675	9702A9	6909 663302	RUSLAN PETROV	{"phone": "+70727728587"}
0005433342676	AE1C8F	3924 828669	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov121968@postgrespro.ru", "phone": "+70664108251"}
0005433342677	58078C	2636 013407	RAFIS SHEVCHENKO	{"email": "shevchenko-r_021974@postgrespro.ru", "phone": "+70185038834"}
0005433342678	58078C	9459 176437	DMITRIY ALEKSEEV	{"email": "alekseev-dmitriy_051972@postgrespro.ru", "phone": "+70782849889"}
0005433342679	AC6E60	0822 546003	SVETLANA MALYSHEVA	{"email": "malysheva_svetlana10051970@postgrespro.ru", "phone": "+70929825859"}
0005433342680	54B885	9127 667738	VERA MOROZOVA	{"email": "morozovavera.01081961@postgrespro.ru", "phone": "+70552408555"}
0005433342681	A4EA6C	2921 938385	ANDREY KRASNOV	{"email": "andreykrasnov_26101967@postgrespro.ru", "phone": "+70855038548"}
0005433342682	7938AF	6921 590946	ALEKSANDR NAZAROV	{"email": "nazarov_a-17021973@postgrespro.ru", "phone": "+70674653714"}
0005433342683	7938AF	6858 107511	ELENA ALEKSANDROVA	{"phone": "+70349492571"}
0005433342684	DDD6F6	3821 308314	EKATERINA ROMANOVA	{"phone": "+70719574053"}
0005433342685	DDD6F6	0958 268059	ALEKSANDR DENISOV	{"phone": "+70717776211"}
0005433342686	DDD6F6	0951 225788	ZLATA KOMAROVA	{"phone": "+70129603646"}
0005433342687	ADB268	2906 081062	ALEFTINA IVANOVA	{"phone": "+70994060640"}
0005433342688	ADB268	0188 617574	STANISLAV NIKOLAEV	{"email": "nikolaev_s_081964@postgrespro.ru", "phone": "+70441891225"}
0005433342689	ADB268	3346 246572	ALEKSEY KARPOV	{"phone": "+70210230756"}
0005433342690	9E1649	3521 826116	MARIYA GAVRILOVA	{"phone": "+70152649050"}
0005433342691	9E1649	5782 383080	EGOR PETROV	{"email": "e_petrov-081973@postgrespro.ru", "phone": "+70808160963"}
0005433342692	377C83	6596 189458	VLADIMIR YAKOVLEV	{"phone": "+70730966535"}
0005433342693	377C83	5547 333530	MARINA KRASNOVA	{"email": "m.krasnova.1981@postgrespro.ru", "phone": "+70448746417"}
0005433342694	908FB3	5024 762961	SVETLANA FROLOVA	{"phone": "+70343924662"}
0005433342695	FD11CC	7304 842040	VERA KULIKOVA	{"phone": "+70662724133"}
0005433342696	D21E0F	5327 210211	SVETLANA NOVIKOVA	{"email": "s.novikova-25091965@postgrespro.ru", "phone": "+70150889825"}
0005433342697	8183D6	3965 825655	NINA AKIMOVA	{"email": "akimova_nina_1968@postgrespro.ru", "phone": "+70427895611"}
0005433342698	7458B0	1039 517768	VIKTORIYA MAKAROVA	{"email": "makarovaviktoriya_051969@postgrespro.ru", "phone": "+70527399790"}
0005433342699	7458B0	9037 762198	GALINA POTAPOVA	{"email": "g_potapova.111977@postgrespro.ru", "phone": "+70360414451"}
0005433342700	07588F	1926 440525	MARIYA ILINA	{"email": "ilina.mariya.031979@postgrespro.ru", "phone": "+70331065308"}
0005433342701	BBECF7	3125 752983	YURIY ABRAMOV	{"phone": "+70848275807"}
0005433342702	45BE09	0180 163432	MARIYA VOLKOVA	{"phone": "+70727453199"}
0005433342703	1D4604	7318 467208	IRINA KUZNECOVA	{"email": "i.kuznecova-1968@postgrespro.ru", "phone": "+70053306002"}
0005433342704	1D4604	2745 556741	DMITRIY KOROLEV	{"phone": "+70537899060"}
0005433342705	B87679	9408 895264	EVDOKIYA MAKSIMOVA	{"email": "e-maksimova051970@postgrespro.ru", "phone": "+70465359337"}
0005433342706	83FF13	4040 139830	ELENA IVANOVA	{"email": "ivanova.e.101979@postgrespro.ru", "phone": "+70192261506"}
0005433342707	56FDF1	4880 891452	PETR KUZNECOV	{"email": "petr-kuznecov111972@postgrespro.ru", "phone": "+70956203908"}
0005433342708	E8B1E1	2732 222911	ALEKSANDR MOISEEV	{"email": "moiseev_a.01081969@postgrespro.ru", "phone": "+70811548257"}
0005433342709	E92D4C	5324 954660	ALEKSEY POPOV	{"email": "a-popov.09041972@postgrespro.ru", "phone": "+70466632170"}
0005433342710	E92D4C	3661 781938	VYACHESLAV ROMANOV	{"email": "romanov-vyacheslav29041972@postgrespro.ru", "phone": "+70814077974"}
0005433342711	E92D4C	9559 307995	LYUDMILA SOLOVEVA	{"email": "l.soloveva_071954@postgrespro.ru", "phone": "+70904305369"}
0005433342712	74F54C	7855 765300	KIRILL EGOROV	{"phone": "+70782828148"}
0005433342713	9F1A25	7382 727964	VASILIY ZAKHAROV	{"email": "v-zakharov_02051975@postgrespro.ru", "phone": "+70331985429"}
0005433342714	9F1A25	9121 493693	NATALYA VOLKOVA	{"phone": "+70707987483"}
0005433342715	DD6228	8420 630271	YULIYA CHERNOVA	{"email": "yuliya.chernova-081958@postgrespro.ru", "phone": "+70803694294"}
0005433342716	DD6228	4245 435291	ALEKSEY FEDOROV	{"phone": "+70669913959"}
0005433342717	26B652	9189 039421	NATALYA DENISOVA	{"email": "n-denisova_29031978@postgrespro.ru", "phone": "+70461473462"}
0005433342718	1CD4B0	3035 132395	VALENTINA SOROKINA	{"email": "v.sorokina_05051987@postgrespro.ru", "phone": "+70503641086"}
0005433342719	477A48	5586 562536	ALEKSEY ABRAMOV	{"phone": "+70686849240"}
0005433342720	ECB6FA	9610 114201	TATYANA DANILOVA	{"phone": "+70524769401"}
0005433342721	ECB6FA	6219 876320	NIKOLAY PAVLOV	{"phone": "+70704545266"}
0005433342722	5E7224	3547 246165	NINA SEMENOVA	{"email": "semenova-n_081974@postgrespro.ru", "phone": "+70767225799"}
0005433342723	CDE986	5885 913930	KHASAN POPOV	{"email": "popov_khasan1971@postgrespro.ru", "phone": "+70107158591"}
0005433342724	CDE986	0238 909238	RAFAIL MAKSIMOV	{"phone": "+70557719036"}
0005433342725	61153E	0295 768148	ELENA ERMAKOVA	{"phone": "+70856552430"}
0005433342726	61153E	4802 715029	ANTON DMITRIEV	{"phone": "+70204553163"}
0005433342727	68A358	9312 066661	GALINA KONDRATEVA	{"email": "galina-kondrateva.1974@postgrespro.ru", "phone": "+70046538324"}
0005433342728	0AAFB7	2111 535308	LILIYA PAVLOVA	{"email": "liliya-pavlova_071969@postgrespro.ru", "phone": "+70868654308"}
0005433342729	0AAFB7	7036 876973	AYRAT MOISEEV	{"phone": "+70940746712"}
0005433342730	956E30	3716 252115	ANATOLIY GORBUNOV	{"phone": "+70144816022"}
0005433342731	956E30	3939 977637	NADEZHDA SERGEEVA	{"email": "n_sergeeva31121982@postgrespro.ru", "phone": "+70490481895"}
0005433342732	A1EFF7	0306 934733	ALEKSANDR FROLOV	{"phone": "+70646584745"}
0005433342733	A1EFF7	9698 823624	OLESYA BELOVA	{"email": "belova_olesya-121977@postgrespro.ru", "phone": "+70175809027"}
0005433342734	A1EFF7	3079 742575	MARINA ISAEVA	{"phone": "+70809887293"}
0005433342735	0F5C14	5512 838666	ALEKSANDR ROMANOV	{"phone": "+70015149271"}
0005433342736	689436	9657 957374	ALEKSEY ZHURAVLEV	{"phone": "+70424430510"}
0005433342737	689436	6375 991549	SVETLANA MIKHAYLOVA	{"email": "svetlana_mikhaylova1961@postgrespro.ru", "phone": "+70684935012"}
0005433342738	C7F3B8	1817 494951	ANASTASIYA FILATOVA	{"email": "filatovaanastasiya1979@postgrespro.ru", "phone": "+70859870181"}
0005433342739	C7F3B8	9778 481127	MARINA DAVYDOVA	{"email": "davydovamarina101971@postgrespro.ru", "phone": "+70840148990"}
0005433342740	10066B	0807 089726	VLADIMIR KOZLOV	{"email": "kozlov.vladimir061980@postgrespro.ru", "phone": "+70174838044"}
0005433342741	0F9EB2	8271 394618	ELENA ALEKSEEVA	{"email": "e.alekseeva.1979@postgrespro.ru", "phone": "+70489182252"}
0005433342742	0F9EB2	7286 492142	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir.121967@postgrespro.ru", "phone": "+70419715330"}
0005433342743	A96101	6484 698356	ARTUR KARPOV	{"email": "karpov_artur011968@postgrespro.ru", "phone": "+70393969311"}
0005433342744	3EA1E7	0758 684188	EVGENIY GRIGOREV	{"email": "evgeniygrigorev_1977@postgrespro.ru", "phone": "+70659059228"}
0005433342745	C8F2F0	1736 501392	NATALYA OSIPOVA	{"email": "natalya.osipova-03111966@postgrespro.ru", "phone": "+70414651831"}
0005433342746	665FBB	6026 430126	IGOR ZAYCEV	{"email": "igor.zaycev-1977@postgrespro.ru", "phone": "+70551559967"}
0005433342747	7BBB5F	1796 677640	NATALYA NIKITINA	{"phone": "+70529701762"}
0005433342748	A92BBD	8416 374093	NATALYA NAZAROVA	{"phone": "+70846783435"}
0005433342749	A92BBD	4561 187597	ANNA KULIKOVA	{"phone": "+70397957562"}
0005433342750	9A9C0A	7130 014822	NIKOLAY ZHURAVLEV	{"phone": "+70898170483"}
0005433342751	7FEA6D	3804 397038	RAISA VOROBEVA	{"email": "vorobeva.raisa_1971@postgrespro.ru", "phone": "+70424323167"}
0005433342754	3E829C	3103 355696	MAKSIM FROLOV	{"phone": "+70095554010"}
0005433342755	BCBE67	2262 366573	ANNA KOVALEVA	{"email": "kovaleva-anna_111971@postgrespro.ru", "phone": "+70350012538"}
0005433342756	BCBE67	1109 991217	VERA ANDREEVA	{"phone": "+70352856450"}
0005433342757	BCBE67	3434 885910	VIKTOR ZAKHAROV	{"phone": "+70759969334"}
0005433342758	791FE2	6261 576458	YURIY BARANOV	{"phone": "+70226408258"}
0005433342759	791FE2	4083 255404	ANATOLIY ANTONOV	{"email": "antonov_a_02011966@postgrespro.ru", "phone": "+70875145672"}
0005433342760	A76FC2	6964 830290	MARK AFANASEV	{"email": "afanasev-mark041973@postgrespro.ru", "phone": "+70747440023"}
0005433342761	67A83E	7456 274744	NADEZHDA ZHURAVLEVA	{"email": "n_zhuravleva-061972@postgrespro.ru", "phone": "+70863044650"}
0005433342762	0C814A	0518 303964	ELENA MATVEEVA	{"email": "ematveeva-20101971@postgrespro.ru", "phone": "+70606732654"}
0005433342763	0C814A	1363 631104	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir-11011974@postgrespro.ru", "phone": "+70886668950"}
0005433342764	0C814A	1492 803875	OLGA OSIPOVA	{"email": "osipova-o.031980@postgrespro.ru", "phone": "+70754377295"}
0005433342765	ADEDDC	4313 750277	SERGEY SEMENOV	{"phone": "+70617497871"}
0005433342766	BB652F	2414 545813	VYACHESLAV KUZMIN	{"phone": "+70107406268"}
0005433342767	BB652F	9230 133252	OLGA ANISIMOVA	{"phone": "+70755196099"}
0005433342768	BB652F	9572 292212	TAISIYA MOISEEVA	{"email": "taisiyamoiseeva_11091967@postgrespro.ru", "phone": "+70866997857"}
0005433342769	85E41B	2219 284557	SERGEY KUZNECOV	{"phone": "+70275504149"}
0005433342770	68B1DD	5112 165693	ARTEM ISAEV	{"phone": "+70065504266"}
0005433342771	C739BA	9839 682618	IRINA GAVRILOVA	{"phone": "+70780142375"}
0005433342772	15D012	6574 815284	NIKOLAY ZHUKOV	{"phone": "+70599294948"}
0005433342773	26302A	2463 572394	ANASTASIYA EFIMOVA	{"email": "efimova_a-1977@postgrespro.ru", "phone": "+70939282808"}
0005433342774	B28BBF	1776 758296	GALINA NAZAROVA	{"phone": "+70652975263"}
0005433342775	C6698E	9871 582515	OLGA CHERNOVA	{"email": "ochernova_1976@postgrespro.ru", "phone": "+70502308472"}
0005433342776	C6698E	3707 148768	ALEKSANDRA KUZMINA	{"phone": "+70857934328"}
0005433342777	CEEC43	9567 119534	MARIYA IVANOVA	{"phone": "+70538217167"}
0005433342778	CEEC43	4377 394430	VALENTINA KUZMINA	{"email": "v_kuzmina16041975@postgrespro.ru", "phone": "+70540131355"}
0005433342779	469C0B	0544 741143	DARYA YAKOVLEVA	{"email": "darya-yakovleva-1968@postgrespro.ru", "phone": "+70912251308"}
0005433342780	8B13C9	9297 989885	SERGEY POPOV	{"email": "s_popov1977@postgrespro.ru", "phone": "+70553521917"}
0005433342781	8B13C9	8505 790138	RAISA NOVIKOVA	{"phone": "+70731206184"}
0005433342782	A6D2A8	3843 175948	ALISA CHERNOVA	{"phone": "+70258834547"}
0005433342783	4077FB	3559 959709	EKATERINA ZAKHAROVA	{"phone": "+70227729555"}
0005433342784	73DB57	7036 829162	MAKSIM POPOV	{"phone": "+70962018315"}
0005433342785	865B71	3538 280490	VALENTINA OSIPOVA	{"phone": "+70890138193"}
0005433342786	2A9847	2730 493302	ANTONINA ANTONOVA	{"phone": "+70134387290"}
0005433342787	F66A33	7722 193461	VLADIMIR SERGEEV	{"email": "vladimir_sergeev-27111971@postgrespro.ru", "phone": "+70487328645"}
0005433342788	9DDCE0	5210 114752	SERGEY SOROKIN	{"phone": "+70815963770"}
0005433342789	9DDCE0	9784 535033	NIKOLAY KISELEV	{"phone": "+70962247383"}
0005433342790	669F62	6412 385028	VASILIY KULIKOV	{"phone": "+70762561482"}
0005433342791	7010AA	9486 923921	VALERIY ZAKHAROV	{"email": "valeriyzakharov.24031968@postgrespro.ru", "phone": "+70118900047"}
0005433342792	D64DB8	3816 067022	VALENTINA ZOTOVA	{"email": "zotova_valentina14111965@postgrespro.ru", "phone": "+70756696517"}
0005433342793	E91D01	8999 743304	NIKOLAY IVANOV	{"email": "ivanov.n_19021977@postgrespro.ru", "phone": "+70836211115"}
0005433342794	90037C	8919 653301	VALERIY KONOVALOV	{"phone": "+70948135135"}
0005433342795	EC12A4	0006 769614	ZOYA BOGDANOVA	{"email": "bogdanova.z.071972@postgrespro.ru", "phone": "+70140783925"}
0005433342796	EC12A4	9711 951133	ANTON MIKHAYLOV	{"email": "anton.mikhaylov1978@postgrespro.ru", "phone": "+70690414143"}
0005433342797	704A1C	2417 532124	ANATOLIY MAKSIMOV	{"phone": "+70477674634"}
0005433342798	704A1C	0045 997339	ALEKSEY SCHERBAKOV	{"email": "a_scherbakov15061971@postgrespro.ru", "phone": "+70017011002"}
0005433342799	B9C581	6183 352572	SERGEY DAVYDOV	{"phone": "+70576690375"}
0005433342800	8DF216	0168 766694	IRINA VLASOVA	{"email": "irina_vlasova-061977@postgrespro.ru", "phone": "+70716198940"}
0005433342801	8DF216	7703 040129	VLADIMIR POPOV	{"email": "vladimir.popov.11071978@postgrespro.ru", "phone": "+70663064056"}
0005433342802	865BEE	6648 889823	RENAT PETROV	{"phone": "+70267453341"}
0005433342803	0D188E	2298 748599	OLGA POPOVA	{"phone": "+70974955133"}
0005433342804	0D188E	0648 487964	MARINA BORISOVA	{"email": "mborisova-101971@postgrespro.ru", "phone": "+70763987549"}
0005433342805	8171CE	6138 936682	GENNADIY KOZLOV	{"phone": "+70012808518"}
0005433342806	8171CE	6180 899954	IRINA ISAEVA	{"email": "isaeva.i_1972@postgrespro.ru", "phone": "+70198391573"}
0005433342807	3EB36B	0987 573747	RUSLAN NIKITIN	{"email": "nikitin_ruslan.16071973@postgrespro.ru", "phone": "+70713870524"}
0005433342808	459515	0875 584427	PETR GAVRILOV	{"email": "p-gavrilov-1964@postgrespro.ru", "phone": "+70963506037"}
0005433342809	459515	8752 898656	NONNA MIRONOVA	{"email": "mironova-nonna-10051959@postgrespro.ru", "phone": "+70797188076"}
0005433342810	459515	0235 212153	STANISLAV SMIRNOV	{"email": "smirnov_stanislav_1977@postgrespro.ru", "phone": "+70120596970"}
0005433342811	459515	4673 421590	ELENA SMIRNOVA	{"email": "e-smirnova_081974@postgrespro.ru", "phone": "+70546744765"}
0005433342812	CE5377	1955 489315	VIKTOR VLASOV	{"email": "vlasov-viktor-26091973@postgrespro.ru", "phone": "+70466253127"}
0005433342813	A1D243	3098 214148	YURIY FROLOV	{"email": "frolov_yuriy_121970@postgrespro.ru", "phone": "+70740307391"}
0005433342814	9D2123	9855 987572	IVAN KAZAKOV	{"email": "kazakovi-1968@postgrespro.ru", "phone": "+70798901488"}
0005433342815	0D9264	5052 618370	ANATOLIY MELNIKOV	{"email": "melnikov_anatoliy1970@postgrespro.ru", "phone": "+70301405593"}
0005433342816	493BD6	2599 941480	DMITRIY MIRONOV	{"email": "d-mironov.1963@postgrespro.ru", "phone": "+70953904500"}
0005433342817	493BD6	7122 297877	NATALYA CHERNOVA	{"phone": "+70790993254"}
0005433342818	4D61A9	5149 550947	ANASTASIYA CHERNOVA	{"phone": "+70953381311"}
0005433342819	4D61A9	5663 541034	SVETLANA KOZLOVA	{"phone": "+70219103622"}
0005433342820	763AC4	0952 205211	ALEKSANDR FEDOTOV	{"email": "fedotov-a-31071979@postgrespro.ru", "phone": "+70946358218"}
0005433342821	763AC4	7978 103081	OLGA BELYAEVA	{"email": "belyaeva-o1973@postgrespro.ru", "phone": "+70313163012"}
0005433342822	C49704	1089 853141	ANDREY MELNIKOV	{"email": "melnikov.a1957@postgrespro.ru", "phone": "+70755311669"}
0005433342823	B694F0	3969 848375	ZULFIYA ORLOVA	{"email": "zulfiyaorlova1972@postgrespro.ru", "phone": "+70318295471"}
0005433342824	6760FD	8208 696913	VERA IVANOVA	{"phone": "+70964109190"}
0005433342825	E8DD6E	9834 286517	MARINA EFREMOVA	{"email": "efremova-m_1965@postgrespro.ru", "phone": "+70282772575"}
0005433342826	E8DD6E	4306 650049	TATYANA DANILOVA	{"email": "tatyana-danilova101966@postgrespro.ru", "phone": "+70227790527"}
0005433342827	B4CC8F	9998 507477	RISHAT VOLKOV	{"email": "rishat-volkov_1976@postgrespro.ru", "phone": "+70522988963"}
0005433342828	B4CC8F	8528 851446	EMMA OVCHINNIKOVA	{"phone": "+70422386213"}
0005433342829	58648B	3078 576129	NATALYA ORLOVA	{"email": "natalyaorlova.011979@postgrespro.ru", "phone": "+70853222029"}
0005433342830	D3E9E3	0465 529728	MARIYA ERMAKOVA	{"phone": "+70457975736"}
0005433342831	99ACD8	7424 788842	ELIZAVETA GAVRILOVA	{"email": "gavrilova.elizaveta_18081971@postgrespro.ru", "phone": "+70316730662"}
0005433342832	FDB614	5250 011598	KLIM SHEVCHENKO	{"email": "shevchenkok101982@postgrespro.ru", "phone": "+70671404460"}
0005433342833	5EB70A	7321 438764	OLGA MASLOVA	{"phone": "+70691434744"}
0005433342834	5EB70A	6641 907845	VLADIMIR BORISOV	{"phone": "+70765876513"}
0005433342835	5EB70A	5866 743335	LYUDMILA IVANOVA	{"phone": "+70740784337"}
0005433342836	F5AB11	2582 732076	EVGENIY PAVLOV	{"phone": "+70792632070"}
0005433342837	F5AB11	6875 815600	LYUDMILA ANISIMOVA	{"phone": "+70153146806"}
0005433342838	6A70AE	7225 073850	GALINA IVANOVA	{"email": "ivanova_g-1974@postgrespro.ru", "phone": "+70242286071"}
0005433342839	6A70AE	2041 668640	TATYANA SERGEEVA	{"email": "t-sergeeva.111987@postgrespro.ru", "phone": "+70564591944"}
0005433342840	6A70AE	2673 245790	NIKITA SOLOVEV	{"phone": "+70524507733"}
0005433342841	056AD3	6804 046629	RAISA SMIRNOVA	{"email": "r-smirnova_1980@postgrespro.ru", "phone": "+70786943461"}
0005433342842	55787C	1974 494903	ANTON EGOROV	{"phone": "+70952068448"}
0005433342843	55787C	3554 646392	VIKTOR ABRAMOV	{"phone": "+70394714842"}
0005433342844	55787C	0930 153252	NATALYA OSIPOVA	{"email": "osipova.natalya_04111981@postgrespro.ru", "phone": "+70021288933"}
0005433342845	299B49	4812 537915	VALENTINA DMITRIEVA	{"email": "valentina_dmitrieva_02041970@postgrespro.ru", "phone": "+70679625579"}
0005433342846	766573	1345 577701	TATYANA EFREMOVA	{"email": "tefremova.1968@postgrespro.ru", "phone": "+70480036917"}
0005433342847	766573	7500 884462	MAKSIM KOZLOV	{"email": "kozlov_maksim.091973@postgrespro.ru", "phone": "+70400177656"}
0005433342848	67A38B	7400 083127	YAROSLAV ANDREEV	{"phone": "+70945528298"}
0005433342849	15CB67	4006 398133	EKATERINA IVANOVA	{"phone": "+70382675072"}
0005433342850	3DB992	8860 536269	VIKTOR MEDVEDEV	{"email": "v_medvedev-1965@postgrespro.ru", "phone": "+70585683754"}
0005433342851	C31702	8781 672790	ANATOLIY SOKOLOV	{"email": "sokolovanatoliy1977@postgrespro.ru", "phone": "+70403915817"}
0005433342852	C31702	7377 347038	GALINA BOGDANOVA	{"email": "galina-bogdanova061974@postgrespro.ru", "phone": "+70462243758"}
0005433342853	D4E014	2334 336272	SERGEY VASILEV	{"phone": "+70452168147"}
0005433342854	00A179	7316 681200	VIKTOR ORLOV	{"email": "v.orlov-1963@postgrespro.ru", "phone": "+70518151972"}
0005433342855	77D1D4	5107 011362	SERGEY SCHERBAKOV	{"phone": "+70796781453"}
0005433342856	173487	8669 495325	TATYANA KUDRYASHOVA	{"email": "tatyana_kudryashova_1975@postgrespro.ru", "phone": "+70817999542"}
0005433342857	48EC7A	9515 425253	IVAN DENISOV	{"phone": "+70410951388"}
0005433342858	48EC7A	3746 591814	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr_071975@postgrespro.ru", "phone": "+70791196166"}
0005433342859	48EC7A	0186 069236	RUSTAM NIKITIN	{"phone": "+70974920322"}
0005433342860	2CFB71	0044 060818	NATALYA KONDRATEVA	{"phone": "+70505772143"}
0005433342861	00F98C	0895 996303	VALENTIN KRASNOV	{"email": "krasnov_v1970@postgrespro.ru", "phone": "+70629200172"}
0005433342862	00F98C	7423 888490	ELENA STEPANOVA	{"phone": "+70643217731"}
0005433342863	4AE531	8850 999063	VLADIMIR NAZAROV	{"phone": "+70038908512"}
0005433342864	4AE531	9689 994476	ILYA TIKHONOV	{"phone": "+70284450129"}
0005433342865	DFC69A	7320 595797	LARISA ZAKHAROVA	{"phone": "+70509748686"}
0005433342866	EA4281	3021 396365	ANDREY KRASNOV	{"phone": "+70394556379"}
0005433342867	F39456	9533 241019	EVGENIY SOROKIN	{"email": "sorokin.evgeniy1976@postgrespro.ru", "phone": "+70278380470"}
0005433342868	1049C9	8043 255913	MARIYA BELOVA	{"email": "mariya.belova-19081969@postgrespro.ru", "phone": "+70757264155"}
0005433342869	4846F2	7319 826644	MARINA MAKAROVA	{"phone": "+70875968114"}
0005433342870	4846F2	4675 699141	ANDREY ZAYCEV	{"email": "zaycevandrey-06041970@postgrespro.ru", "phone": "+70684676690"}
0005433342871	C8C420	5726 561733	ANASTASIYA RODIONOVA	{"phone": "+70667700018"}
0005433342872	37C883	4524 078124	YULIANA PAVLOVA	{"email": "pavlova_y-1970@postgrespro.ru", "phone": "+70556522725"}
0005433342873	E1A522	7386 610871	RAISA MAKAROVA	{"email": "makarova_raisa.28061965@postgrespro.ru", "phone": "+70285515717"}
0005433342874	E1A522	4721 725069	ALEKSANDR DMITRIEV	{"email": "aleksandrdmitriev-1980@postgrespro.ru", "phone": "+70384447781"}
0005433342875	09C519	7656 106695	TATYANA VOLKOVA	{"email": "volkova.tatyana1979@postgrespro.ru", "phone": "+70829500475"}
0005433342876	9323C0	9025 883236	TAMARA NESTEROVA	{"phone": "+70517525521"}
0005433342877	9323C0	4330 492544	ELENA GUSEVA	{"phone": "+70273536301"}
0005433342878	DD763E	3743 020248	TATYANA GORBUNOVA	{"email": "t.gorbunova-1957@postgrespro.ru", "phone": "+70973025702"}
0005433342879	E049D5	1721 050839	VITALIY KUZNECOV	{"phone": "+70708887331"}
0005433342880	E049D5	1393 798375	TATYANA NIKOLAEVA	{"email": "tnikolaeva011963@postgrespro.ru", "phone": "+70502099380"}
0005433342881	721997	9731 825441	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.051972@postgrespro.ru", "phone": "+70883140671"}
0005433342882	721997	8483 870574	VALERIY FROLOV	{"phone": "+70738836158"}
0005433342883	5D3582	7746 945515	ANNA KONOVALOVA	{"email": "konovalova_a.31051965@postgrespro.ru", "phone": "+70243726953"}
0005433342884	B4DA43	2940 690885	IRINA SERGEEVA	{"phone": "+70778736796"}
0005433342885	B4DA43	7298 275848	NATALYA ORLOVA	{"email": "orlova-n.01101969@postgrespro.ru", "phone": "+70828170039"}
0005433342886	536798	8339 148490	VALENTINA SCHERBAKOVA	{"email": "scherbakova_v071987@postgrespro.ru", "phone": "+70959758857"}
0005433342887	541D58	3117 062482	ELENA MIRONOVA	{"phone": "+70337124109"}
0005433342888	4E575B	2101 892703	TATYANA ILINA	{"email": "t.ilina-121967@postgrespro.ru", "phone": "+70632779032"}
0005433342889	4E575B	9438 204047	ALEKSANDR SCHERBAKOV	{"phone": "+70709673276"}
0005433342890	069732	5424 586020	GALINA BOGDANOVA	{"phone": "+70531551400"}
0005433342891	FCAE63	1975 055473	IRINA GUSEVA	{"phone": "+70840283773"}
0005433342892	FCAE63	9641 532621	LYUDMILA ANDREEVA	{"email": "l-andreeva07101963@postgrespro.ru", "phone": "+70234966214"}
0005433342893	4FF0A7	3918 351021	TAISIYA MARTYNOVA	{"phone": "+70234977734"}
0005433342894	4FF0A7	2988 775180	TATYANA RODIONOVA	{"phone": "+70504794247"}
0005433342895	B83C96	1540 863486	NIKOLAY SOROKIN	{"email": "sorokin.n.011966@postgrespro.ru", "phone": "+70434790487"}
0005433342896	B83C96	6890 905174	NATALIYA KUZMINA	{"phone": "+70653308954"}
0005433342897	4CA39C	2860 164237	NIKITA KONOVALOV	{"email": "n-konovalov-03011969@postgrespro.ru", "phone": "+70627295667"}
0005433342898	51D4AE	7531 918964	OLGA EGOROVA	{"email": "olga-egorova.081969@postgrespro.ru", "phone": "+70458550609"}
0005433342899	589A0D	2503 234266	VLADIMIR SIDOROV	{"phone": "+70944253789"}
0005433342900	54E677	2572 993353	LYUDMILA IVANOVA	{"email": "l-ivanova_051973@postgrespro.ru", "phone": "+70658737567"}
0005433342901	54E677	7703 109404	ALEKSANDR NAZAROV	{"phone": "+70421131105"}
0005433342902	C731C5	3152 119101	LYUDMILA ORLOVA	{"email": "orloval-031978@postgrespro.ru", "phone": "+70922030541"}
0005433342903	B96B26	7573 522205	ELENA FILIPPOVA	{"email": "e.filippova-041969@postgrespro.ru", "phone": "+70574928829"}
0005433342904	B96B26	0138 720535	NATALYA NIKOLAEVA	{"phone": "+70407179521"}
0005433342905	7238CC	1634 586657	ANATOLIY ALEKSEEV	{"phone": "+70377395178"}
0005433342906	7238CC	6345 096535	YULIYA ROMANOVA	{"email": "y-romanova_28111975@postgrespro.ru", "phone": "+70565871288"}
0005433342907	7238CC	9317 496696	IRINA POPOVA	{"email": "i-popova.061980@postgrespro.ru", "phone": "+70884278674"}
0005433342908	6A7634	2248 946184	MAKSIM FROLOV	{"email": "frolov-m_021985@postgrespro.ru", "phone": "+70319207672"}
0005433342909	6A7634	3303 182295	ANDREY ZAKHAROV	{"email": "zakharov-a-26011981@postgrespro.ru", "phone": "+70355101922"}
0005433342910	A0FFB1	5305 175704	ARTEM ANDREEV	{"email": "artem-andreev_11011974@postgrespro.ru", "phone": "+70532576758"}
0005433342911	C8D434	8935 336617	VIKTOR MOROZOV	{"email": "morozovv18071970@postgrespro.ru", "phone": "+70358241812"}
0005433342912	6BC720	4203 620497	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova.l.13061966@postgrespro.ru", "phone": "+70080969708"}
0005433342913	6BC720	9327 160014	ALEKSANDR ZHUKOV	{"email": "zhukov-a-041972@postgrespro.ru", "phone": "+70263500758"}
0005433342914	7BB0D4	2604 908613	OLGA KOLESNIKOVA	{"phone": "+70489162183"}
0005433342915	969D6B	7177 068607	ANASTASIYA ANISIMOVA	{"phone": "+70515748644"}
0005433342916	969D6B	2958 251026	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir.29031965@postgrespro.ru", "phone": "+70607169242"}
0005433342917	969D6B	5703 319429	YULIYA GORBUNOVA	{"email": "yuliyagorbunova-23121963@postgrespro.ru", "phone": "+70009206543"}
0005433342918	56B29B	6935 027399	ANASTASIYA IVANOVA	{"phone": "+70730182950"}
0005433342919	56B29B	2566 347838	ANNA ROMANOVA	{"phone": "+70024505260"}
0005433342920	56B29B	5151 050149	RAISA BELOVA	{"phone": "+70316084525"}
0005433342921	6C914C	5555 444322	DENIS PAVLOV	{"phone": "+70892753428"}
0005433342922	4D0B4B	8419 190801	VIKTOR SOKOLOV	{"email": "sokolov-viktor-1981@postgrespro.ru", "phone": "+70397630034"}
0005433342923	5E6B0A	9106 567781	ANNA KOROLEVA	{"phone": "+70128121643"}
0005433342924	985C02	3696 766197	OKSANA NAZAROVA	{"email": "nazarovaoksana-18041982@postgrespro.ru", "phone": "+70570001388"}
0005433342925	985C02	9446 037841	MARINA GUSEVA	{"phone": "+70806046090"}
0005433342926	778AC1	7626 360756	NIKITA ANDREEV	{"email": "andreev_n.011966@postgrespro.ru", "phone": "+70189411118"}
0005433342927	D9F9C5	7713 807875	MARIYA KOLESNIKOVA	{"phone": "+70864159276"}
0005433342928	AA1B58	2590 106763	SERGEY KULIKOV	{"phone": "+70340498002"}
0005433342929	AA1B58	1092 418245	GALINA MASLOVA	{"email": "maslova.galina.07041968@postgrespro.ru", "phone": "+70044872321"}
0005433342930	F6193A	9068 646433	SERGEY EGOROV	{"email": "egorov.sergey.19081975@postgrespro.ru", "phone": "+70037557102"}
0005433342931	A90742	0241 660710	NADEZHDA BELOVA	{"email": "n.belova-011959@postgrespro.ru", "phone": "+70554782232"}
0005433342932	4F335B	8668 287270	ARTEM AFANASEV	{"email": "a.afanasev25051969@postgrespro.ru", "phone": "+70661448936"}
0005433342933	DBD93F	6612 845479	LIDIYA TROFIMOVA	{"phone": "+70943359563"}
0005433342934	056DD8	0956 397138	NADEZHDA PETROVA	{"phone": "+70488667940"}
0005433342935	29D7F4	3087 473056	KSENIYA SAVELEVA	{"email": "kseniyasaveleva031961@postgrespro.ru", "phone": "+70610402740"}
0005433342936	24CC14	5146 817550	IGOR BARANOV	{"email": "baranov.igor_111962@postgrespro.ru", "phone": "+70917429079"}
0005433342937	F5E0BF	8284 447462	REGINA KOROLEVA	{"email": "koroleva-r-031973@postgrespro.ru", "phone": "+70453483680"}
0005433342938	70D902	5963 043724	ELENA PAVLOVA	{"phone": "+70528166125"}
0005433342939	30EE44	6474 188841	MIKHAIL POPOV	{"email": "popovmikhail1986@postgrespro.ru", "phone": "+70771447292"}
0005433342940	30EE44	9471 928974	IGOR SOLOVEV	{"email": "solovev-igor1966@postgrespro.ru", "phone": "+70077592620"}
0005433342941	CD6644	9108 136104	NIKOLAY VOLKOV	{"email": "volkovn.1959@postgrespro.ru", "phone": "+70953160435"}
0005433342942	DB7ED4	6973 640223	DMITRIY KUZNECOV	{"phone": "+70696772283"}
0005433342943	8378C0	7472 290928	LIDIYA SEMENOVA	{"phone": "+70480749773"}
0005433342944	EDEB48	0476 528762	YULIYA KONOVALOVA	{"email": "y.konovalova.1972@postgrespro.ru", "phone": "+70379322220"}
0005433342945	EDEB48	3368 603434	SERGEY KUZNECOV	{"email": "s.kuznecov081977@postgrespro.ru", "phone": "+70478153424"}
0005433342946	882D23	5673 887341	VIKTOR DENISOV	{"email": "viktor.denisov_1979@postgrespro.ru", "phone": "+70596937957"}
0005433342947	A59D40	5051 536884	VALENTINA SIDOROVA	{"phone": "+70181003644"}
0005433342948	A59D40	1803 763643	ALEKSANDR KUZNECOV	{"phone": "+70768250874"}
0005433342949	A59D40	0658 615034	KSENIYA RODIONOVA	{"phone": "+70585797145"}
0005433342950	1BF1E9	0722 196230	ANNA IVANOVA	{"email": "a_ivanova-061967@postgrespro.ru", "phone": "+70697001786"}
0005433342951	E4E418	4050 798980	GALINA YUDINA	{"phone": "+70772448026"}
0005433342952	E4E418	2475 936808	SVETLANA IVANOVA	{"email": "svetlanaivanova-1970@postgrespro.ru", "phone": "+70799395578"}
0005433342953	E63842	8829 600345	ALEKSANDR NIKITIN	{"phone": "+70153536425"}
0005433342954	5F52E6	7022 554467	IRINA IVANOVA	{"email": "irina.ivanova.121967@postgrespro.ru", "phone": "+70556626032"}
0005433342955	DD4A91	5580 998252	OLGA SERGEEVA	{"email": "osergeeva.1972@postgrespro.ru", "phone": "+70393874578"}
0005433342956	1373BF	6062 301266	OLGA SEMENOVA	{"phone": "+70904751277"}
0005433342957	1373BF	5658 044708	ALEKSANDR MATVEEV	{"email": "matveevaleksandr.1969@postgrespro.ru", "phone": "+70483390536"}
0005433342958	EBD456	7149 192649	VLADISLAV MELNIKOV	{"phone": "+70753059286"}
0005433342959	91E4C6	7242 022557	VADIM DMITRIEV	{"email": "dmitriev_vadim-1973@postgrespro.ru", "phone": "+70187529804"}
0005433342960	91E4C6	6034 335453	ANDREY ZAKHAROV	{"phone": "+70366178673"}
0005433342961	914026	0416 181041	YULIYA PAVLOVA	{"email": "ypavlova091971@postgrespro.ru", "phone": "+70427717774"}
0005433342962	CC653D	9992 483908	NADEZHDA FEDOROVA	{"phone": "+70862765810"}
0005433342963	0F1072	6131 034801	IVAN DAVYDOV	{"phone": "+70737021667"}
0005433342964	0F1072	5186 744089	VIKTOR STEPANOV	{"email": "stepanov.v1964@postgrespro.ru", "phone": "+70345713754"}
0005433342965	A95CB6	3301 161966	ELENA RYABOVA	{"email": "ryabovaelena-061978@postgrespro.ru", "phone": "+70212436470"}
0005433342966	A95CB6	8626 554267	VERA VLASOVA	{"phone": "+70036399099"}
0005433342967	A95CB6	5990 341993	DARYA VOROBEVA	{"phone": "+70093070863"}
0005433342968	DD35AC	8209 445481	IRINA KONOVALOVA	{"email": "konovalova_i.1981@postgrespro.ru", "phone": "+70665839932"}
0005433342969	538444	1741 790564	EVGENIYA OVCHINNIKOVA	{"phone": "+70485729374"}
0005433342970	538444	4318 172163	EVGENIY SEMENOV	{"phone": "+70588994623"}
0005433343082	5047D7	4448 770593	VIKTOR SOROKIN	{"phone": "+70115073602"}
0005433342971	6535E2	7249 731058	DMITRIY KOROLEV	{"email": "korolev.d28011977@postgrespro.ru", "phone": "+70592135105"}
0005433342972	6535E2	2026 731279	ALEKSANDR KOZLOV	{"phone": "+70794727386"}
0005433342973	E5A006	8965 798775	GALINA MEDVEDEVA	{"email": "medvedeva_g-30081972@postgrespro.ru", "phone": "+70634525383"}
0005433342974	E5A006	1188 849092	TAMARA GAVRILOVA	{"email": "gavrilova_tamara_1968@postgrespro.ru", "phone": "+70370545832"}
0005433342975	040C55	0995 854817	ELENA GERASIMOVA	{"email": "gerasimova-elena-07041976@postgrespro.ru", "phone": "+70818146349"}
0005433342976	F35750	0474 405157	ALEKSANDR IVANOV	{"phone": "+70282884461"}
0005433342977	58E62E	0861 083086	EVGENIY YAKOVLEV	{"email": "evgeniy_yakovlev28081966@postgrespro.ru", "phone": "+70721708316"}
0005433342978	C28D85	2406 615338	SVETLANA NAZAROVA	{"email": "nazarova-svetlana_041970@postgrespro.ru", "phone": "+70641757941"}
0005433342979	C28D85	2919 073229	VIKTOR BONDARENKO	{"phone": "+70982219726"}
0005433342980	C28D85	0562 326096	TAMARA KUZNECOVA	{"email": "t_kuznecova.20091980@postgrespro.ru", "phone": "+70941125495"}
0005433342981	72C81D	9247 361628	NADEZHDA FOMINA	{"phone": "+70799498559"}
0005433342982	704E5A	8820 172830	OLEG YAKOVLEV	{"email": "olegyakovlev-051978@postgrespro.ru", "phone": "+70977185262"}
0005433342983	4D790C	3057 328606	MAKSIM SOROKIN	{"email": "maksim-sorokin121978@postgrespro.ru", "phone": "+70376897424"}
0005433342984	4D790C	1486 711558	SVETLANA GAVRILOVA	{"email": "gavrilovas_041967@postgrespro.ru", "phone": "+70597194297"}
0005433342985	8E7AA5	2793 450172	YANA KUZNECOVA	{"email": "kuznecovay_09101971@postgrespro.ru", "phone": "+70834056627"}
0005433342986	8E7AA5	1255 531549	GENNADIY DAVYDOV	{"phone": "+70023785381"}
0005433342987	93C8A0	5570 758442	IRINA ISAEVA	{"email": "irinaisaeva_1965@postgrespro.ru", "phone": "+70300580464"}
0005433342988	93C8A0	7586 726750	ANDREY ALEKSEEV	{"email": "alekseev_andrey-1973@postgrespro.ru", "phone": "+70345900982"}
0005433342989	CA6BA7	3589 768813	ALEKSANDR MAKSIMOV	{"phone": "+70212585427"}
0005433342990	3EE23C	5213 666184	ALEKSEY SOKOLOV	{"phone": "+70864574639"}
0005433342991	F62A52	8900 699843	ANDREY ANTONOV	{"phone": "+70051997739"}
0005433342992	F62A52	8496 495213	YANA KOROLEVA	{"email": "y-koroleva1969@postgrespro.ru", "phone": "+70111158298"}
0005433342993	883E80	1150 093562	VERONIKA ISAEVA	{"email": "veronika-isaeva.10091973@postgrespro.ru", "phone": "+70092114076"}
0005433342994	883E80	7281 949068	PETR SAVELEV	{"email": "p_savelev091965@postgrespro.ru", "phone": "+70876627187"}
0005433342995	F4A949	7250 406932	LYUBOV YAKOVLEVA	{"email": "lyakovleva-11111973@postgrespro.ru", "phone": "+70294446938"}
0005433342996	4CB6B3	9367 206881	NATALIYA ISAEVA	{"email": "nataliya_isaeva-1969@postgrespro.ru", "phone": "+70470368899"}
0005433342997	BDB050	9944 078434	TATYANA SOROKINA	{"phone": "+70547129440"}
0005433342998	F01DDC	2791 533444	VIKTOR TIKHONOV	{"phone": "+70325579609"}
0005433342999	D18DDE	5258 764022	LARISA RYABOVA	{"phone": "+70469752334"}
0005433343000	F8B40F	9612 759209	VITALIY TIKHONOV	{"phone": "+70682217211"}
0005433343001	73778B	2023 860095	YULIYA MIKHAYLOVA	{"phone": "+70587013750"}
0005433343002	CD1E5D	5137 825729	TATYANA BELOVA	{"phone": "+70294046703"}
0005433343003	CD1E5D	7880 827362	ILYA SERGEEV	{"phone": "+70868846488"}
0005433343004	254431	4305 614023	ILYA ANDREEV	{"phone": "+70417775628"}
0005433343005	4595A7	7012 996711	ALEKSANDR MAKSIMOV	{"email": "maksimov-a_01011980@postgrespro.ru", "phone": "+70482134105"}
0005433343006	6445FF	8877 167207	VERA ROMANOVA	{"email": "vera-romanova-1970@postgrespro.ru", "phone": "+70430721706"}
0005433343007	144BAE	7271 429241	VALENTINA FROLOVA	{"email": "frolovavalentina07071964@postgrespro.ru", "phone": "+70394560020"}
0005433343008	144BAE	1230 064652	ZHANNA RYABOVA	{"email": "z.ryabova_1982@postgrespro.ru", "phone": "+70174941590"}
0005433343009	FCF260	3735 738006	SVETLANA POPOVA	{"phone": "+70010890218"}
0005433343010	051288	8769 564915	ANASTASIYA KOVALEVA	{"email": "kovalevaanastasiya_13021971@postgrespro.ru", "phone": "+70073880500"}
0005433343011	051288	5250 849634	SERGEY MIRONOV	{"email": "mironov_s_1966@postgrespro.ru", "phone": "+70563810415"}
0005433343012	B4CD97	3193 652870	FARID KUZNECOV	{"email": "f_kuznecov.071976@postgrespro.ru", "phone": "+70770924931"}
0005433343013	ECFE34	5413 176467	VALENTINA GRISHINA	{"email": "v-grishina_1964@postgrespro.ru", "phone": "+70653115035"}
0005433343014	ECFE34	5835 201603	VASILIY SOKOLOV	{"email": "sokolov_v1977@postgrespro.ru", "phone": "+70880407221"}
0005433343015	DBB362	8996 670253	ILYA MIKHAYLOV	{"phone": "+70128462860"}
0005433343016	9C8774	9672 050554	VERONIKA BORISOVA	{"email": "borisovaveronika_18091973@postgrespro.ru", "phone": "+70550280733"}
0005433343017	E5C992	8413 922801	MAKSIM VOLKOV	{"email": "volkov_m06101979@postgrespro.ru", "phone": "+70079492761"}
0005433343018	79D481	4952 602919	ALEKSEY NAZAROV	{"email": "nazarovaleksey-041974@postgrespro.ru", "phone": "+70696618148"}
0005433343019	A25255	8299 089831	VITALIY PETROV	{"email": "vitaliy-petrov_1964@postgrespro.ru", "phone": "+70243053640"}
0005433343020	A25255	4359 978239	VITALIY VOLKOV	{"phone": "+70603593052"}
0005433343021	CCAE7E	8596 593689	VLADIMIR NOVIKOV	{"phone": "+70760122671"}
0005433343022	CCAE7E	4483 717053	VALENTIN FEDOTOV	{"email": "fedotov-valentin_091964@postgrespro.ru", "phone": "+70443982110"}
0005433343023	8BA9A7	7154 119004	TAISIYA KUZNECOVA	{"email": "kuznecova.t_1978@postgrespro.ru", "phone": "+70569689244"}
0005433343024	8BA9A7	0398 799102	NINA MIKHAYLOVA	{"phone": "+70359018400"}
0005433343025	DE5378	3770 773215	ANNA SERGEEVA	{"phone": "+70532576675"}
0005433343026	E385D2	4355 371468	NAILYA FILIPPOVA	{"email": "n-filippova1988@postgrespro.ru", "phone": "+70047717784"}
0005433343027	6EC5ED	3457 224180	NATALYA IVANOVA	{"email": "ivanova_natalya.19101971@postgrespro.ru", "phone": "+70959891745"}
0005433343028	6EC5ED	5207 761793	MIKHAIL NIKOLAEV	{"phone": "+70324832539"}
0005433343029	D5F2B4	8502 255227	DARYA KALININA	{"email": "darya_kalinina_20091972@postgrespro.ru", "phone": "+70275878315"}
0005433343030	69F89A	7105 430027	RUSTAM ABRAMOV	{"email": "abramov.rustam-1967@postgrespro.ru", "phone": "+70689220341"}
0005433343031	74AF0D	7170 214207	LYUBOV KOVALEVA	{"phone": "+70366432040"}
0005433343032	74AF0D	5642 075774	DANIYA KAZAKOVA	{"email": "kazakova.d111973@postgrespro.ru", "phone": "+70095405376"}
0005433343033	74AF0D	6629 540835	NATALYA KOZLOVA	{"email": "kozlova.n1969@postgrespro.ru", "phone": "+70210475193"}
0005433343034	950FA4	3248 154599	NINA KOZLOVA	{"email": "nina_kozlova_031973@postgrespro.ru", "phone": "+70595561494"}
0005433343035	5883B3	0181 731448	SVETLANA IVANOVA	{"phone": "+70069239763"}
0005433343036	B1C4AC	7978 661288	EKATERINA KALININA	{"phone": "+70484497335"}
0005433343037	82E0E6	3974 483250	ELENA TIKHONOVA	{"phone": "+70098252484"}
0005433343038	22F15F	6962 444428	ANTONINA VOLKOVA	{"email": "a.volkova091978@postgrespro.ru", "phone": "+70422832814"}
0005433343039	5C2C1D	8582 338561	ALEKSEY KUZNECOV	{"email": "a_kuznecov18021964@postgrespro.ru", "phone": "+70931892714"}
0005433343040	A369DA	2687 184481	DMITRIY ZAKHAROV	{"email": "d-zakharov.24101970@postgrespro.ru", "phone": "+70162945030"}
0005433343041	A369DA	2538 472257	ALEKSEY SCHERBAKOV	{"phone": "+70616186526"}
0005433343042	E66C7B	4959 251335	VYACHESLAV ORLOV	{"email": "orlov_v-1979@postgrespro.ru", "phone": "+70361304850"}
0005433343043	E66C7B	5911 285049	NINA SCHERBAKOVA	{"email": "n-scherbakova_28041965@postgrespro.ru", "phone": "+70624707937"}
0005433343044	CBF2E8	8822 121048	IVAN NIKOLAEV	{"phone": "+70627910652"}
0005433343045	CBF2E8	7660 397428	GALINA KALININA	{"phone": "+70061129370"}
0005433343046	CC46CA	2037 981766	GALINA GERASIMOVA	{"email": "gerasimova.galina-071963@postgrespro.ru", "phone": "+70202661604"}
0005433343047	CC46CA	2895 437922	DENIS VASILEV	{"email": "denisvasilev.121971@postgrespro.ru", "phone": "+70978677302"}
0005433343048	442083	9817 432539	ARTEM VOLKOV	{"phone": "+70224476726"}
0005433343049	D5D06E	8368 217213	NATALYA ZOTOVA	{"phone": "+70281550335"}
0005433343050	D5D06E	1365 396238	TATYANA FEDOROVA	{"email": "tfedorova.011971@postgrespro.ru", "phone": "+70782944819"}
0005433343051	835D56	6339 852101	KSENIYA NOVIKOVA	{"phone": "+70703404420"}
0005433343052	770673	5461 967324	MARIYA KOROLEVA	{"email": "mariya.koroleva031968@postgrespro.ru", "phone": "+70682656885"}
0005433343053	770673	5120 843323	ANATOLIY KULIKOV	{"email": "kulikov-a.1974@postgrespro.ru", "phone": "+70566018307"}
0005433343054	1B11F5	3622 441230	VIKTOR ORLOV	{"email": "viktororlov.12111963@postgrespro.ru", "phone": "+70892096940"}
0005433343055	3F7461	0551 112740	NATALYA FILIPPOVA	{"phone": "+70603697462"}
0005433343056	3F7461	5395 708201	ALEKSANDR FEDOTOV	{"email": "fedotov.a.25101980@postgrespro.ru", "phone": "+70162111930"}
0005433343057	AE8177	7911 873090	ILDAR ANDREEV	{"email": "ildar_andreev_1973@postgrespro.ru", "phone": "+70591164226"}
0005433343058	AE8177	3159 400762	VASILIY RODIONOV	{"email": "vasiliy-rodionov.021973@postgrespro.ru", "phone": "+70864360052"}
0005433343059	3B9403	4862 710094	ELENA LAZAREVA	{"phone": "+70413910059"}
0005433343060	DE00A3	8389 319651	NIKOLAY KUZMIN	{"phone": "+70270771509"}
0005433343061	314D99	5808 160266	YULIYA GORBUNOVA	{"phone": "+70788319495"}
0005433343062	314D99	5264 296372	ROMAN ALEKSEEV	{"phone": "+70441618596"}
0005433343063	F5695B	9053 152700	ALEKSEY KULIKOV	{"phone": "+70848446120"}
0005433343064	F5695B	7852 061732	TATYANA IVANOVA	{"phone": "+70012658453"}
0005433343065	C74AE1	7619 389606	VALENTINA ZOTOVA	{"email": "valentina_zotova_121993@postgrespro.ru", "phone": "+70909962834"}
0005433343066	C61320	0501 005413	LEONID ZHUKOV	{"email": "zhukovleonid1964@postgrespro.ru", "phone": "+70012446614"}
0005433343067	19DD3F	5090 762056	ALBERT SIDOROV	{"phone": "+70009501036"}
0005433343068	06E5D4	9226 559885	YULIYA SOROKINA	{"phone": "+70668970418"}
0005433343069	2C9FFC	7175 129697	YURIY DMITRIEV	{"phone": "+70368039756"}
0005433343070	B30439	7835 050341	ALEKSANDR FEDOTOV	{"phone": "+70715066601"}
0005433343071	CA0CBA	3206 800652	DMITRIY SEMENOV	{"phone": "+70815524020"}
0005433343072	CA0CBA	3197 785450	YURIY SIDOROV	{"phone": "+70068423236"}
0005433343073	DE0CF9	8365 659903	VLADIMIR EGOROV	{"phone": "+70563080647"}
0005433343074	BA7E22	6352 873613	SABINA MOROZOVA	{"phone": "+70846042179"}
0005433343075	BA7E22	7489 396625	TATYANA KUZMINA	{"email": "kuzmina-tatyana_09051977@postgrespro.ru", "phone": "+70129224728"}
0005433343076	D97A59	7021 017334	ANDREY GUSEV	{"email": "andrey_gusev081967@postgrespro.ru", "phone": "+70970321303"}
0005433343077	D97A59	0597 582111	ALEKSANDRA KUDRYASHOVA	{"email": "kudryashova_a1964@postgrespro.ru", "phone": "+70833950681"}
0005433343078	549C64	6347 284357	ALLA NOVIKOVA	{"email": "allanovikova_1960@postgrespro.ru", "phone": "+70237970468"}
0005433343079	549C64	7694 323013	GALINA MARTYNOVA	{"email": "martynova_galina.091973@postgrespro.ru", "phone": "+70537029448"}
0005433343080	AEEC46	7979 570098	ANASTASIYA TROFIMOVA	{"email": "trofimovaa_29051965@postgrespro.ru", "phone": "+70936552989"}
0005433343081	BB19A8	5078 516474	VIKTORIYA SOKOLOVA	{"phone": "+70738881518"}
0005433343083	5047D7	0269 218690	ALEKSEY DAVYDOV	{"email": "davydovaleksey061977@postgrespro.ru", "phone": "+70335646354"}
0005433343084	16B1B2	4508 593651	FEDOR FILIPPOV	{"email": "f_filippov_071964@postgrespro.ru", "phone": "+70085873268"}
0005433343085	580A37	0784 029702	ANATOLIY MOROZOV	{"phone": "+70868673509"}
0005433343086	3F17DB	6621 679769	ANNA FEDOROVA	{"email": "fedorova-anna1975@postgrespro.ru", "phone": "+70451064179"}
0005433343087	3F17DB	1404 136325	MARAT GUSEV	{"email": "gusev-m15081973@postgrespro.ru", "phone": "+70267737051"}
0005433343088	62602A	9874 034004	YURIY KRASNOV	{"phone": "+70021518203"}
0005433343089	A21220	1738 912901	ALEKSEY MELNIKOV	{"phone": "+70037211037"}
0005433343090	A21220	3011 229089	ANDREY KULIKOV	{"phone": "+70417643421"}
0005433343091	6EEF8E	7301 750869	GALINA ZAYCEVA	{"email": "galina.zayceva-07111982@postgrespro.ru", "phone": "+70766615396"}
0005433343092	FE6BC3	4240 148844	DMITRIY VOROBEV	{"email": "vorobevdmitriy.051977@postgrespro.ru", "phone": "+70580786808"}
0005433343093	6AD283	0485 187325	VIKTOR TARASOV	{"email": "viktor.tarasov-1980@postgrespro.ru", "phone": "+70452626635"}
0005433343094	939037	9848 549331	NIKOLAY ZAKHAROV	{"email": "nikolay.zakharov_28111980@postgrespro.ru", "phone": "+70870637222"}
0005433343095	2527AB	8592 805471	ALEKSANDR SMIRNOV	{"phone": "+70790392589"}
0005433343096	C403AA	8607 475614	ALEKSEY FEDOROV	{"phone": "+70671033189"}
0005433343097	C403AA	8879 462191	NIKOLAY POPOV	{"phone": "+70612274400"}
0005433343098	C403AA	0957 309215	MIKHAIL SCHERBAKOV	{"email": "m_scherbakov_1963@postgrespro.ru", "phone": "+70452391918"}
0005433343099	B84D28	9185 293585	ELENA GERASIMOVA	{"email": "gerasimova_elena.121981@postgrespro.ru", "phone": "+70067911240"}
0005433343100	7A97B3	4780 341320	TAMARA SOKOLOVA	{"email": "tsokolova.081972@postgrespro.ru", "phone": "+70393281623"}
0005433343101	417130	1425 474185	NADEZHDA KOROLEVA	{"email": "nadezhda-koroleva-011975@postgrespro.ru", "phone": "+70555072013"}
0005433343102	3BB7D6	0746 881644	VALERIY NIKOLAEV	{"email": "v_nikolaev1965@postgrespro.ru", "phone": "+70407721726"}
0005433343103	3BB7D6	9897 623846	MARGARITA DAVYDOVA	{"phone": "+70486636462"}
0005433343104	5B96FB	3272 098980	MIKHAIL MAKAROV	{"phone": "+70297411439"}
0005433343105	5B96FB	7497 796134	ALMIRA ANDREEVA	{"email": "almiraandreeva.1961@postgrespro.ru", "phone": "+70121124547"}
0005433343106	5B96FB	6679 266316	VIKTOR TIKHONOV	{"email": "tikhonov.v-1966@postgrespro.ru", "phone": "+70162437032"}
0005433343107	F2287A	1957 003236	YULIYA TIKHONOVA	{"phone": "+70073418316"}
0005433343108	F2287A	9181 916282	VALENTINA MAKSIMOVA	{"phone": "+70047875116"}
0005433343109	B360AF	1188 150447	ALEKSANDR TIKHONOV	{"phone": "+70896685528"}
0005433343110	B360AF	1220 813636	LYUDMILA VOLKOVA	{"phone": "+70616302943"}
0005433343111	F976C5	8040 403685	SVETLANA TITOVA	{"email": "titova_s.10081973@postgrespro.ru", "phone": "+70487488813"}
0005433343112	C85140	0839 029996	ANTONINA NIKITINA	{"email": "antonina_nikitina_061979@postgrespro.ru", "phone": "+70814894019"}
0005433343113	C85140	2394 648381	VALENTINA ZAKHAROVA	{"phone": "+70985653636"}
0005433343114	5CBEBA	7134 486650	EKATERINA ANTONOVA	{"email": "antonova-ekaterina.101973@postgrespro.ru", "phone": "+70817495420"}
0005433343115	042CB0	5744 183862	SVETLANA KARPOVA	{"phone": "+70944502997"}
0005433343116	042CB0	2126 723849	NIKOLAY PAVLOV	{"phone": "+70435518143"}
0005433343117	D23772	8699 027578	LYUBOV NOVIKOVA	{"phone": "+70599552126"}
0005433343118	C7EF04	5817 566681	BULAT DMITRIEV	{"email": "bulatdmitriev_31101962@postgrespro.ru", "phone": "+70355865396"}
0005433343119	F4E3FE	3936 532102	REGINA KALININA	{"email": "r.kalinina.04071980@postgrespro.ru", "phone": "+70900619038"}
0005433343120	F4E3FE	3746 785396	ANNA SEMENOVA	{"email": "anna_semenova.071976@postgrespro.ru", "phone": "+70781104390"}
0005433343121	A6A62D	1038 300145	ALEKSEY SOLOVEV	{"email": "solovev.aleksey_061968@postgrespro.ru", "phone": "+70905933799"}
0005433343122	DE5D61	2108 832448	ALEKSANDR RODIONOV	{"email": "rodionov.aleksandr_15091971@postgrespro.ru", "phone": "+70457082000"}
0005433343123	DE5D61	9737 197231	NADEZHDA KONOVALOVA	{"email": "n-konovalova-1973@postgrespro.ru", "phone": "+70093342374"}
0005433343124	C7F63E	9720 279907	VADIM ABRAMOV	{"phone": "+70065881952"}
0005433343125	618F66	5381 071861	ANATOLIY VASILEV	{"phone": "+70029469302"}
0005433343126	618F66	3183 626638	ALEKSANDR MIRONOV	{"phone": "+70349913520"}
0005433343127	FA5C0C	8256 198222	NIKOLAY VOROBEV	{"phone": "+70227528972"}
0005433343128	265D29	3099 376596	LARISA SOLOVEVA	{"phone": "+70007648230"}
0005433343129	56EB69	0553 184888	SERGEY YAKOVLEV	{"phone": "+70561559645"}
0005433343130	14D565	4717 235491	LIDIYA KARPOVA	{"phone": "+70573407314"}
0005433343131	50923E	6690 398387	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov_041977@postgrespro.ru", "phone": "+70712373613"}
0005433343132	9F9122	8010 246162	ANDREY OSIPOV	{"email": "andrey.osipov_04061971@postgrespro.ru", "phone": "+70871323136"}
0005433343133	F9960B	3525 305300	NINA POTAPOVA	{"phone": "+70631699495"}
0005433343134	CEEE1A	4818 808344	DMITRIY VOROBEV	{"email": "vorobev-d.13031973@postgrespro.ru", "phone": "+70083212840"}
0005433343135	CEEE1A	7783 381457	ANATOLIY SHEVCHENKO	{"email": "ashevchenko011964@postgrespro.ru", "phone": "+70215117525"}
0005433343136	5151BC	9914 266366	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v051967@postgrespro.ru", "phone": "+70794353777"}
0005433343137	2B9DA2	5390 817882	ALEKSANDRA FILIPPOVA	{"phone": "+70861273911"}
0005433343138	B7BF5E	2677 231387	ARTUR PETROV	{"phone": "+70469377008"}
0005433343139	6657AC	8114 625155	MARINA ORLOVA	{"phone": "+70270600457"}
0005433343140	FC4B99	7670 266459	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova.lyudmila-021968@postgrespro.ru", "phone": "+70724412979"}
0005433343141	FC4B99	1500 769593	ALEKSEY ZHURAVLEV	{"phone": "+70640534446"}
0005433343142	AB9E8B	0416 303883	DARYA STEPANOVA	{"phone": "+70033410363"}
0005433343143	AB9E8B	2467 183758	NADEZHDA ORLOVA	{"email": "orlova-nadezhda_101977@postgrespro.ru", "phone": "+70612720003"}
0005433343144	A75CE3	6758 226245	OLGA FEDOROVA	{"phone": "+70783053151"}
0005433343145	5E2E69	5933 170598	VALERIY SERGEEV	{"email": "valeriysergeev-27121971@postgrespro.ru", "phone": "+70810638616"}
0005433343146	78DA8A	4902 377709	ARTUR FEDOROV	{"phone": "+70967823503"}
0005433343147	E0E3CB	6513 410561	VLADIMIR DMITRIEV	{"phone": "+70501429205"}
0005433343148	F52AD2	1815 885648	SERGEY DMITRIEV	{"phone": "+70106977533"}
0005433343149	F52AD2	2191 352784	VALENTINA MAKSIMOVA	{"email": "v-maksimova-1970@postgrespro.ru", "phone": "+70867225259"}
0005433343150	08A2F6	3319 355922	ALEKSANDR ZAYCEV	{"email": "a_zaycev041972@postgrespro.ru", "phone": "+70955387112"}
0005433343151	08A2F6	3190 267980	MARINA IVANOVA	{"email": "ivanova.marina_1969@postgrespro.ru", "phone": "+70165485216"}
0005433343152	3ADAEC	9906 364628	PAVEL NAZAROV	{"email": "pavel-nazarov1980@postgrespro.ru", "phone": "+70032434198"}
0005433343153	210890	9273 648621	ALEKSANDRA KONOVALOVA	{"email": "a_konovalova-1980@postgrespro.ru", "phone": "+70324378491"}
0005433343154	54EB43	6424 470656	TATYANA KULIKOVA	{"phone": "+70479766806"}
0005433343155	B70376	3077 358688	VALERIY KONOVALOV	{"email": "konovalov-v_08121969@postgrespro.ru", "phone": "+70992035004"}
0005433343156	50E872	6344 336882	SERGEY SIDOROV	{"email": "ssidorov-1975@postgrespro.ru", "phone": "+70302949182"}
0005433343157	AD2340	6466 973543	IRINA VLASOVA	{"email": "i_vlasova.1979@postgrespro.ru", "phone": "+70499551338"}
0005433343158	1CF9B3	1010 894445	VALENTINA ANDREEVA	{"phone": "+70653625513"}
0005433343159	9745C1	9596 286365	VIKTORIYA STEPANOVA	{"email": "vstepanova1966@postgrespro.ru", "phone": "+70985945085"}
0005433343160	9E1B3B	3561 507702	STANISLAV POPOV	{"phone": "+70143030590"}
0005433343161	B0CEBE	3447 834733	NATALYA LUKYANOVA	{"phone": "+70168618675"}
0005433343162	07258E	2168 165085	ELENA KONOVALOVA	{"phone": "+70936843111"}
0005433343163	A6D416	5424 147180	GALINA GORBUNOVA	{"email": "gorbunova.g.081968@postgrespro.ru", "phone": "+70986452265"}
0005433343164	F121DF	6049 746408	FATIMA NIKITINA	{"phone": "+70360435280"}
0005433343165	F2A391	1751 225854	ELENA FEDOROVA	{"phone": "+70075336870"}
0005433343166	E49F03	0105 634085	OLGA SEMENOVA	{"phone": "+70090899754"}
0005433343167	E49F03	1798 827183	ANATOLIY TIMOFEEV	{"email": "anatoliy.timofeev.051982@postgrespro.ru", "phone": "+70203549610"}
0005433343168	1B301B	9795 460309	GALINA KUDRYASHOVA	{"phone": "+70650252820"}
0005433343169	021758	3834 573859	EVDOKIYA IVANOVA	{"email": "ivanova.evdokiya1966@postgrespro.ru", "phone": "+70539852136"}
0005433343170	A7FEAB	5610 503293	TATYANA KUZNECOVA	{"email": "t_kuznecova1979@postgrespro.ru", "phone": "+70361699962"}
0005433343171	A7FEAB	5054 274289	ARTEM SIDOROV	{"phone": "+70897797843"}
0005433343172	F7E4A2	2660 419089	SVETLANA KONOVALOVA	{"email": "s-konovalova_07111974@postgrespro.ru", "phone": "+70256636119"}
0005433343173	F7E4A2	5082 222468	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov-101966@postgrespro.ru", "phone": "+70326498725"}
0005433343174	7AE2DB	8025 224656	VLADIMIR TARASOV	{"phone": "+70610468391"}
0005433343175	7AE2DB	4978 418101	ELENA SOKOLOVA	{"phone": "+70366468851"}
0005433343176	CC10ED	6758 874774	ALEKSEY VOLKOV	{"email": "volkov.a011965@postgrespro.ru", "phone": "+70098658401"}
0005433343177	C39DFB	3377 325110	NATALYA ZAKHAROVA	{"email": "natalya.zakharova.1970@postgrespro.ru", "phone": "+70635196465"}
0005433343178	C017D0	5752 192411	ANATOLIY SCHERBAKOV	{"email": "ascherbakov121967@postgrespro.ru", "phone": "+70065723946"}
0005433343179	C017D0	9663 864640	ELIZAVETA ZHURAVLEVA	{"phone": "+70572904158"}
0005433343180	F58358	4526 616944	ALBERT VOLKOV	{"phone": "+70801616380"}
0005433343181	3C5BA8	5194 240438	ANNA SOKOLOVA	{"email": "sokolova-a1971@postgrespro.ru", "phone": "+70063442405"}
0005433343182	5745AA	8599 583146	ADELINA KUZMINA	{"phone": "+70974785463"}
0005433343183	495E61	2053 167312	RENAT KUDRYASHOV	{"phone": "+70933503575"}
0005433343184	C31025	9483 774909	MARINA OSIPOVA	{"email": "marinaosipova.16011981@postgrespro.ru", "phone": "+70700173510"}
0005433343185	BBF3EA	8210 761621	SVETLANA KOZLOVA	{"email": "svetlanakozlova_051968@postgrespro.ru", "phone": "+70763939555"}
0005433343186	BBF3EA	7347 116997	VIKTORIYA KUZNECOVA	{"email": "viktoriya.kuznecova.041982@postgrespro.ru", "phone": "+70111546809"}
0005433343187	024EE6	4632 945366	ANNA MALYSHEVA	{"email": "annamalysheva.1968@postgrespro.ru", "phone": "+70122906759"}
0005433343188	024EE6	5433 886331	YULIYA ANISIMOVA	{"email": "yuliya-anisimova101964@postgrespro.ru", "phone": "+70139121480"}
0005433343189	DF113A	3783 517204	OKSANA SOROKINA	{"email": "sorokina.o.1963@postgrespro.ru", "phone": "+70402978381"}
0005433343190	9B17AE	1703 094317	ALESYA ALEKSANDROVA	{"email": "aleksandrovaa-1968@postgrespro.ru", "phone": "+70551516457"}
0005433343191	9B17AE	3652 948048	SERGEY KARPOV	{"email": "karpov-s-041979@postgrespro.ru", "phone": "+70562238479"}
0005433343192	5DFAE6	9717 592827	TATYANA NIKOLAEVA	{"phone": "+70424951258"}
0005433343193	8A672F	7236 219300	ANZHELIKA PETROVA	{"email": "petrova_anzhelika.051967@postgrespro.ru", "phone": "+70234155278"}
0005433343194	8A672F	4315 786510	GALINA FEDOROVA	{"phone": "+70621136528"}
0005433343195	28635E	2803 738560	KONSTANTIN GRIGOREV	{"email": "k-grigorev03091978@postgrespro.ru", "phone": "+70835281933"}
0005433343196	28635E	2195 880087	ANNA SOKOLOVA	{"phone": "+70248575449"}
0005433343197	3FE3EE	7866 277095	YULIYA MELNIKOVA	{"phone": "+70479438811"}
0005433343198	7D81C8	9307 567895	VALERIY IVANOV	{"email": "v.ivanov_121965@postgrespro.ru", "phone": "+70313688025"}
0005433343199	7D81C8	8732 980598	TATYANA DAVYDOVA	{"email": "davydovat.1975@postgrespro.ru", "phone": "+70412611070"}
0005433343200	7D81C8	2685 013695	TATYANA PETROVA	{"phone": "+70082942501"}
0005433343201	7B9DC2	4206 170882	ARTUR ABRAMOV	{"email": "abramov_a_10121972@postgrespro.ru", "phone": "+70065858637"}
0005433343202	D34469	0144 210093	MARIYA ANTONOVA	{"phone": "+70127189295"}
0005433343203	7CAD91	6487 694559	ROMAN KRASNOV	{"email": "romankrasnov1973@postgrespro.ru", "phone": "+70855960107"}
0005433343204	A45C5C	6131 423703	NIKOLAY MARTYNOV	{"phone": "+70082533569"}
0005433343205	65861A	2212 356696	DENIS SOLOVEV	{"email": "solovev-denis_01081971@postgrespro.ru", "phone": "+70042553365"}
0005433343206	7D2750	1431 525445	OKSANA NAZAROVA	{"phone": "+70104985645"}
0005433343207	7D2750	8789 425367	VALERIY ZAKHAROV	{"email": "valeriy-zakharov031976@postgrespro.ru", "phone": "+70174156564"}
0005433343208	ADC189	9432 414497	NIKOLAY DENISOV	{"phone": "+70402449380"}
0005433343209	ABDAFC	1138 239804	DMITRIY SOLOVEV	{"email": "solovev.dmitriy-04051965@postgrespro.ru", "phone": "+70338694238"}
0005433343210	ABDAFC	3664 898275	SVETLANA ROMANOVA	{"email": "svetlana-romanova071970@postgrespro.ru", "phone": "+70466165680"}
0005433343211	146478	6623 047360	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr_21061974@postgrespro.ru", "phone": "+70801032667"}
0005433343212	146478	5331 743797	DMITRIY YAKOVLEV	{"phone": "+70420546941"}
0005433343213	499184	0092 687925	VIKTOR SHEVCHENKO	{"email": "shevchenko.viktor_1970@postgrespro.ru", "phone": "+70782328524"}
0005433343214	9C53B6	2830 234251	OKSANA ALEKSEEVA	{"phone": "+70248660622"}
0005433343215	097D98	4797 088856	PAVEL MELNIKOV	{"phone": "+70405149335"}
0005433343216	A698B3	5730 495880	ANDREY NAUMOV	{"phone": "+70214208020"}
0005433343217	AA4CA7	3140 610959	ALEKSANDR NAZAROV	{"phone": "+70322409141"}
0005433343218	7D6DD7	1668 754783	SERGEY STEPANOV	{"phone": "+70272473881"}
0005433343219	7019C9	1630 975285	SVETLANA MOROZOVA	{"email": "s_morozova.061971@postgrespro.ru", "phone": "+70409019713"}
0005433343220	FAAB62	0478 252724	VALERIY SMIRNOV	{"email": "smirnov-v.28011968@postgrespro.ru", "phone": "+70445911891"}
0005433343221	9F4A91	3758 357067	ANASTASIYA OSIPOVA	{"phone": "+70198148013"}
0005433343222	F70E71	1821 229022	VALERIY BONDARENKO	{"email": "bondarenkov011974@postgrespro.ru", "phone": "+70254280249"}
0005433343223	90CE14	2641 192020	EKATERINA OSIPOVA	{"phone": "+70745283043"}
0005433343224	A42F14	2646 234325	EVGENIY PETROV	{"phone": "+70110695542"}
0005433343225	A42F14	1845 161774	YURIY GUSEV	{"email": "gusev-yuriy_1976@postgrespro.ru", "phone": "+70238701221"}
0005433343226	475645	3826 680929	NIKOLAY ABRAMOV	{"phone": "+70934240023"}
0005433343227	AA0F63	1511 583489	NINA POPOVA	{"phone": "+70717275515"}
0005433343228	1D9CD4	2021 501357	ALEKSANDR MELNIKOV	{"phone": "+70972922137"}
0005433343229	1D9CD4	3035 958044	NINA ZHUKOVA	{"phone": "+70422628946"}
0005433343230	1D9CD4	4824 387920	ANDREY POPOV	{"phone": "+70477389088"}
0005433343231	D530C1	4871 365130	LIDIYA ABRAMOVA	{"email": "l.abramova_30071974@postgrespro.ru", "phone": "+70906000138"}
0005433343232	14EAF1	2148 193489	PETR KOROLEV	{"email": "korolevpetr-17031975@postgrespro.ru", "phone": "+70435373148"}
0005433343233	14EAF1	8634 631143	MARIYA ANTONOVA	{"email": "mariya_antonova13101973@postgrespro.ru", "phone": "+70760785411"}
0005433343234	897004	7771 437226	OLGA SOLOVEVA	{"email": "olga.soloveva11061970@postgrespro.ru", "phone": "+70222992508"}
0005433343235	897004	0262 069573	ALEKSANDR KUZNECOV	{"email": "kuznecova.25011973@postgrespro.ru", "phone": "+70207140896"}
0005433343236	897004	4986 438818	VYACHESLAV SCHERBAKOV	{"phone": "+70940852975"}
0005433343237	70821D	0855 895281	ARTEM VLASOV	{"email": "artemvlasov1968@postgrespro.ru", "phone": "+70949545175"}
0005433343238	70821D	9077 238308	VLADIMIR KARPOV	{"phone": "+70598374882"}
0005433343239	616522	8495 119355	ALEKSEY NIKITIN	{"phone": "+70983142859"}
0005433343240	ADED0A	1492 015153	TATYANA TROFIMOVA	{"email": "t-trofimova_29081973@postgrespro.ru", "phone": "+70071948538"}
0005433343241	ADED0A	8517 461041	VLADIMIR TARASOV	{"email": "vladimir_tarasov-1984@postgrespro.ru", "phone": "+70839693504"}
0005433343242	258A7E	2675 920081	IVAN KARPOV	{"phone": "+70775043355"}
0005433343243	E489A2	2802 411743	MARIANNA VASILEVA	{"phone": "+70756017079"}
0005433343244	84AE13	1527 008369	ANNA KUZMINA	{"phone": "+70009705102"}
0005433343245	95CB19	2068 722824	EKATERINA BORISOVA	{"email": "borisovaekaterina-071966@postgrespro.ru", "phone": "+70452513667"}
0005433343246	7F2573	4891 236726	NIKOLAY VOROBEV	{"phone": "+70923399576"}
0005433343247	7F2573	5237 483571	MAKSIM GAVRILOV	{"email": "maksim_gavrilov09071973@postgrespro.ru", "phone": "+70100667079"}
0005433343248	E902A7	0567 210739	VIKTOR GRIGOREV	{"phone": "+70628954190"}
0005433343249	E902A7	6132 593503	VLADIMIR DAVYDOV	{"email": "davydov.vladimir021969@postgrespro.ru", "phone": "+70769851135"}
0005433343250	80C255	2026 416747	VALENTINA LOGINOVA	{"phone": "+70777203151"}
0005433343251	394B38	3890 597972	EKATERINA SCHERBAKOVA	{"phone": "+70687845706"}
0005433343252	8F9A37	6530 296960	VALERIY IVANOV	{"phone": "+70892371319"}
0005433343253	643DD8	7190 476833	TATYANA IVANOVA	{"phone": "+70277265843"}
0005433343254	69020B	5876 704982	ROMAN ZAKHAROV	{"phone": "+70337512284"}
0005433343255	69020B	0538 095608	EKATERINA EGOROVA	{"email": "egorovae-081979@postgrespro.ru", "phone": "+70147444497"}
0005433343256	8E4427	2912 407810	NINA POTAPOVA	{"email": "potapovanina1972@postgrespro.ru", "phone": "+70581987870"}
0005433343257	8E4427	7880 038557	ANTONINA LOGINOVA	{"phone": "+70983713714"}
0005433343258	C29C5D	8846 403901	TATYANA BOGDANOVA	{"email": "tatyanabogdanova_1961@postgrespro.ru", "phone": "+70253952499"}
0005433343259	C10FF5	4980 335687	VITALIY SIDOROV	{"email": "v.sidorov_041967@postgrespro.ru", "phone": "+70962684284"}
0005433343260	6C115A	9538 738307	TATYANA KUZNECOVA	{"phone": "+70758286474"}
0005433343261	4E2263	8764 042934	LYUDMILA NAZAROVA	{"phone": "+70302451903"}
0005433343262	692385	1456 382704	SERGEY TIKHONOV	{"email": "stikhonov-101966@postgrespro.ru", "phone": "+70794242695"}
0005433343263	E37005	2067 117849	IGOR KARPOV	{"phone": "+70645548504"}
0005433343264	1FAEA8	4704 576558	MARIYA DMITRIEVA	{"phone": "+70839979469"}
0005433343265	1FAEA8	7182 039310	TATYANA SMIRNOVA	{"email": "tatyana_smirnova.1979@postgrespro.ru", "phone": "+70631964059"}
0005433343266	1FAEA8	6150 761557	YULIYA LAZAREVA	{"email": "y.lazareva_01011973@postgrespro.ru", "phone": "+70391261163"}
0005433343267	736B50	5173 020162	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_1977@postgrespro.ru", "phone": "+70305652149"}
0005433343268	47DDC9	1205 994166	TATYANA IVANOVA	{"email": "t.ivanova061970@postgrespro.ru", "phone": "+70373846029"}
0005433343269	D9743F	7919 302826	VERA VOLKOVA	{"phone": "+70698213963"}
0005433343270	481F4F	0197 126281	ANDREY FEDOTOV	{"phone": "+70137624948"}
0005433343271	187EF9	6889 829212	LYUDMILA ANISIMOVA	{"email": "anisimova.lyudmila-27051970@postgrespro.ru", "phone": "+70202963678"}
0005433343272	5B18C5	3362 588593	DENIS FEDOTOV	{"email": "fedotovdenis.1962@postgrespro.ru", "phone": "+70057229081"}
0005433343273	2AE0D6	6358 884198	MARINA FOMINA	{"email": "mfomina-1969@postgrespro.ru", "phone": "+70195491480"}
0005433343274	A124FF	9774 895670	ARTEM KONOVALOV	{"phone": "+70553014744"}
0005433343275	F9A86F	4339 550844	OLEG STEPANOV	{"email": "oleg_stepanov041974@postgrespro.ru", "phone": "+70455474658"}
0005433343276	F9A86F	8087 745279	NELLYA SEMENOVA	{"phone": "+70213135249"}
0005433343277	9748C8	4608 360227	ARSENIY GERASIMOV	{"email": "a-gerasimov.1973@postgrespro.ru", "phone": "+70743192989"}
0005433343278	637B2D	9861 153415	ANNA FROLOVA	{"phone": "+70743510204"}
0005433343279	637B2D	4176 088909	DMITRIY ZHUKOV	{"email": "dmitriy.zhukov_1981@postgrespro.ru", "phone": "+70226642693"}
0005433343280	60A4D9	0380 499174	ELENA FROLOVA	{"phone": "+70389922595"}
0005433343281	60A4D9	7649 907094	VLADIMIR DMITRIEV	{"phone": "+70235391759"}
0005433343282	BC6268	9923 262719	ANNA POPOVA	{"phone": "+70065337054"}
0005433343283	BC6268	1629 633893	ELENA STEPANOVA	{"email": "stepanova_e091982@postgrespro.ru", "phone": "+70109398833"}
0005433343284	26F020	7425 016955	VADIM NAZAROV	{"phone": "+70799312915"}
0005433343285	DAD8FD	6226 308258	NIKOLAY TIKHONOV	{"email": "tikhonov.nikolay-14061978@postgrespro.ru", "phone": "+70198254443"}
0005433343286	4252B6	2297 964424	SERGEY BORISOV	{"email": "sergeyborisov-01031975@postgrespro.ru", "phone": "+70308018427"}
0005433343287	7A62F8	5492 820088	VASILIY VOLKOV	{"phone": "+70194690619"}
0005433343288	C35E5D	4120 801849	TATYANA SIDOROVA	{"email": "sidorova_t-06051970@postgrespro.ru", "phone": "+70243113223"}
0005433343289	617130	6558 761882	NINA FILIPPOVA	{"email": "n_filippova1982@postgrespro.ru", "phone": "+70291976603"}
0005433343290	617130	6229 885092	PAVEL NOVIKOV	{"email": "pnovikov1970@postgrespro.ru", "phone": "+70774047670"}
0005433343291	1735C7	9743 510898	ELENA VOLKOVA	{"email": "elena_volkova_121973@postgrespro.ru", "phone": "+70852176929"}
0005433343292	1735C7	8815 727567	DENIS IVANOV	{"email": "divanov.19051974@postgrespro.ru", "phone": "+70398809213"}
0005433343293	E85AF1	3965 947048	VLADIMIR PETROV	{"phone": "+70967640478"}
0005433343294	E85AF1	9383 930810	TATYANA KUZMINA	{"email": "kuzmina-t-1967@postgrespro.ru", "phone": "+70946604592"}
0005433343295	2EA8F2	4597 367976	VIKTORIYA TARASOVA	{"email": "tarasova_v-091972@postgrespro.ru", "phone": "+70886055320"}
0005433343296	D92FEF	9256 989665	VLADIMIR KULIKOV	{"phone": "+70338477060"}
0005433343297	1F1AC7	8145 671669	ANDREY NIKITIN	{"phone": "+70156891428"}
0005433343298	8D3D84	6985 076396	IVAN SCHERBAKOV	{"email": "scherbakov.i.021989@postgrespro.ru", "phone": "+70533508337"}
0005433343299	8D3D84	5314 001889	RAZIYA KUZNECOVA	{"email": "kuznecova.r_051976@postgrespro.ru", "phone": "+70396206041"}
0005433343300	258D2C	3463 949419	NIKOLAY ABRAMOV	{"phone": "+70993382535"}
0005433343301	258D2C	9367 648396	LARISA DANILOVA	{"phone": "+70534219147"}
0005433343302	F08E18	8630 280197	NADEZHDA YUDINA	{"email": "yudina_n-1970@postgrespro.ru", "phone": "+70826497352"}
0005433343303	6D1866	1139 867485	VLADIMIR KUZMIN	{"phone": "+70456832070"}
0005433343304	1C38B6	0949 816614	ALEKSANDRA YUDINA	{"email": "aleksandrayudina_1973@postgrespro.ru", "phone": "+70761655480"}
0005433343305	3CE930	5903 131973	SERGEY VASILEV	{"email": "vasilev-sergey_10051968@postgrespro.ru", "phone": "+70293057549"}
0005433343306	E3E560	1595 003994	BOGDAN IVANOV	{"phone": "+70908019159"}
0005433343307	027C8D	2542 978531	TATYANA NAUMOVA	{"phone": "+70186853529"}
0005433343308	63CCE9	9911 728752	ALEKSEY OSIPOV	{"phone": "+70949747217"}
0005433343309	63CCE9	2616 249515	LIDIYA FILIPPOVA	{"phone": "+70082160282"}
0005433343310	29452D	6878 769959	POLINA TROFIMOVA	{"email": "polina_trofimova091966@postgrespro.ru", "phone": "+70513342093"}
0005433343311	60D101	1895 007308	ALEKSANDR SEMENOV	{"phone": "+70914234884"}
0005433343312	60D101	3505 532109	ALEKSANDR TIKHONOV	{"phone": "+70167911510"}
0005433343313	04578F	6910 164868	ELMIRA NIKOLAEVA	{"phone": "+70582752692"}
0005433343314	A6EC79	5478 351722	NATALYA FILATOVA	{"phone": "+70167108529"}
0005433343315	838BD4	7030 512765	VITALIY POPOV	{"email": "vpopov31011976@postgrespro.ru", "phone": "+70163913122"}
0005433343316	5AA92E	8045 941693	EKATERINA SERGEEVA	{"phone": "+70547380140"}
0005433343317	5AA92E	4566 781947	NINA FILIPPOVA	{"email": "filippova-nina-091972@postgrespro.ru", "phone": "+70967549449"}
0005433343318	255B2E	1091 411274	ALEKSANDRA NOVIKOVA	{"email": "anovikova1973@postgrespro.ru", "phone": "+70220548046"}
0005433343319	255B2E	7296 913062	ELVIRA IVANOVA	{"phone": "+70450253162"}
0005433343320	4534B9	0634 531057	GRIGORIY KAZAKOV	{"email": "kazakov.g.18121978@postgrespro.ru", "phone": "+70203748632"}
0005433343321	4534B9	6228 024651	EKATERINA FILATOVA	{"phone": "+70023136789"}
0005433343322	4534B9	6757 956475	MARINA GUSEVA	{"phone": "+70200365305"}
0005433343323	C1A4CE	5655 627985	KIRILL KOZLOV	{"phone": "+70458277880"}
0005433343324	E0E23E	4665 284478	SERGEY MAKAROV	{"email": "makarov-s16081975@postgrespro.ru", "phone": "+70802474998"}
0005433343325	A606BE	5713 250537	TATYANA MAKSIMOVA	{"email": "tatyanamaksimova_08051965@postgrespro.ru", "phone": "+70476675135"}
0005433343326	A324AB	1411 519057	TAMARA MAKAROVA	{"phone": "+70050888101"}
0005433343327	8FF990	0902 789818	GALINA LUKYANOVA	{"phone": "+70404435943"}
0005433343328	1E9163	3324 958343	ZOYA YAKOVLEVA	{"phone": "+70204997866"}
0005433343329	7FA424	0249 212560	SERGEY SOROKIN	{"phone": "+70830104428"}
0005433343330	7FA424	4606 292472	EKATERINA STEPANOVA	{"phone": "+70875710248"}
0005433343331	E451F8	5401 657736	OKSANA ZAYCEVA	{"email": "zayceva_o_011978@postgrespro.ru", "phone": "+70705753758"}
0005433343332	E451F8	6477 742753	IGOR ISAEV	{"phone": "+70077436665"}
0005433343333	E451F8	1727 870368	IGOR KUZNECOV	{"phone": "+70285199946"}
0005433343334	DACD99	1712 014523	ANDREY ANTONOV	{"email": "antonova_111976@postgrespro.ru", "phone": "+70518919690"}
0005433343335	DACD99	5916 115645	OLEG TARASOV	{"email": "o-tarasov_101978@postgrespro.ru", "phone": "+70205593950"}
0005433343336	A3ABAD	9278 271977	VIKTOR TIMOFEEV	{"phone": "+70100093970"}
0005433343337	971CE0	2571 970649	PETR NIKITIN	{"phone": "+70388427344"}
0005433343338	A8EB32	6928 019680	ARTEM GORBUNOV	{"email": "gorbunov.a14061971@postgrespro.ru", "phone": "+70627586577"}
0005433343339	A8EB32	0633 721338	OLGA ERMAKOVA	{"phone": "+70164833710"}
0005433343340	1D9992	2541 402074	ELENA EFIMOVA	{"phone": "+70655776622"}
0005433343341	1D9992	6817 921865	VITALIY SOLOVEV	{"email": "v_solovev_121973@postgrespro.ru", "phone": "+70022029789"}
0005433343342	5F6BC2	9657 305097	SVETLANA PAVLOVA	{"email": "pavlova-svetlana_04031971@postgrespro.ru", "phone": "+70823723027"}
0005433343343	94F536	2825 114555	ALEKSANDRA EFIMOVA	{"email": "aefimova1969@postgrespro.ru", "phone": "+70432967859"}
0005433343344	94F536	4502 851491	TATYANA EFIMOVA	{"email": "t.efimova-1968@postgrespro.ru", "phone": "+70888088786"}
0005433343345	B694DC	9010 405793	OLGA SOKOLOVA	{"email": "sokolova-olga.1969@postgrespro.ru", "phone": "+70122675703"}
0005433343346	D1481C	7644 199535	ARTEM KUZNECOV	{"phone": "+70741280709"}
0005433343347	517FD3	2448 504253	ELENA FILATOVA	{"email": "elena.filatova_121965@postgrespro.ru", "phone": "+70235295410"}
0005433343348	30B1DE	9054 783410	SVETLANA GRISHINA	{"email": "grishina_svetlana-1970@postgrespro.ru", "phone": "+70656732342"}
0005433343349	30B1DE	1054 085287	NIKOLAY ROMANOV	{"email": "romanovnikolay_1955@postgrespro.ru", "phone": "+70849115543"}
0005433343350	C54999	2192 477070	ELENA DENISOVA	{"email": "e_denisova1963@postgrespro.ru", "phone": "+70575718154"}
0005433343351	7EA3AA	8325 973522	EKATERINA POPOVA	{"email": "e_popova.1968@postgrespro.ru", "phone": "+70863186048"}
0005433343352	C1F52E	5422 189780	EKATERINA IVANOVA	{"email": "ivanovaekaterina1972@postgrespro.ru", "phone": "+70970570736"}
0005433343353	C1F52E	5717 819387	ALISA SCHERBAKOVA	{"phone": "+70989178974"}
0005433343354	AFF871	6710 642635	ALEKSANDR FOMIN	{"phone": "+70674215493"}
0005433343355	AFF871	0980 248416	DENIS ALEKSANDROV	{"phone": "+70423785110"}
0005433343356	02B38F	6734 188309	ZOYA BORISOVA	{"email": "borisova-z081968@postgrespro.ru", "phone": "+70129953640"}
0005433343357	D79A8D	6358 388634	VIKTORIYA KONOVALOVA	{"phone": "+70307889201"}
0005433343538	518EC1	6352 160645	OLGA GORBUNOVA	{"phone": "+70455801854"}
0005433343358	8A1565	4405 183727	NATALYA FOMINA	{"email": "n_fomina.081962@postgrespro.ru", "phone": "+70480814683"}
0005433343359	B34C9B	2479 639461	NIKOLAY SOLOVEV	{"phone": "+70267969473"}
0005433343360	7FA634	5005 776892	TATYANA KUZMINA	{"phone": "+70443382943"}
0005433343361	3CCF95	4857 511085	NATALYA SERGEEVA	{"phone": "+70861744623"}
0005433343362	3CCF95	0368 947105	VALENTINA KULIKOVA	{"phone": "+70840003630"}
0005433343363	158A38	7557 512441	MARIYA KAZAKOVA	{"phone": "+70010421129"}
0005433343364	1F003B	0529 175586	MARIYA VASILEVA	{"email": "mariya_vasileva-1975@postgrespro.ru", "phone": "+70684529317"}
0005433343365	1F003B	7012 968751	EVGENIY KONOVALOV	{"email": "e-konovalov-101970@postgrespro.ru", "phone": "+70678418894"}
0005433343366	3F7B0E	4952 519074	OLEG SOLOVEV	{"email": "o-solovev_1962@postgrespro.ru", "phone": "+70460311825"}
0005433343367	3F7B0E	4193 693637	VALERIY ROMANOV	{"phone": "+70990504864"}
0005433343368	4AECE5	5466 026245	KONSTANTIN ALEKSANDROV	{"phone": "+70991836914"}
0005433343369	F70D9B	0603 740686	MARIANNA AFANASEVA	{"phone": "+70694238747"}
0005433343370	F70D9B	6004 652265	EKATERINA MOROZOVA	{"phone": "+70835034263"}
0005433343371	F70D9B	6642 623429	DMITRIY CHERNOV	{"email": "dmitriy_chernov.15091979@postgrespro.ru", "phone": "+70075981419"}
0005433343372	61D7F8	2331 422216	OKSANA POPOVA	{"email": "oksana_popova-20091963@postgrespro.ru", "phone": "+70276783741"}
0005433343373	61D7F8	8658 345983	VALENTINA SOLOVEVA	{"phone": "+70723983036"}
0005433343374	1089C2	6323 312346	DARYA VOROBEVA	{"email": "darya_vorobeva-1978@postgrespro.ru", "phone": "+70393752813"}
0005433343375	3D82A5	4742 730986	DARYA MATVEEVA	{"phone": "+70605034547"}
0005433343376	7CC66F	0019 600181	ANDREY EGOROV	{"email": "andrey-egorov-22081961@postgrespro.ru", "phone": "+70371374496"}
0005433343377	7CC66F	9453 458599	YURIY PAVLOV	{"phone": "+70378262186"}
0005433343378	480E5E	2497 452953	ALEKSEY EGOROV	{"phone": "+70814448207"}
0005433343379	480E5E	4618 737687	LYUDMILA MAKSIMOVA	{"email": "maksimovalyudmila-031976@postgrespro.ru", "phone": "+70423213074"}
0005433343380	8A2326	9811 000441	PAVEL ZAYCEV	{"phone": "+70975360083"}
0005433343381	8C142D	0418 536271	ARTEM VOLKOV	{"phone": "+70076697757"}
0005433343382	1DF382	4778 387983	LADA POPOVA	{"email": "popova.l-17011966@postgrespro.ru", "phone": "+70960648649"}
0005433343383	C39C6B	9450 918260	IVAN KOZLOV	{"email": "kozlov-i26041969@postgrespro.ru", "phone": "+70282282876"}
0005433343384	2F8E85	7779 666118	VASILIY POPOV	{"phone": "+70755473561"}
0005433343385	A0733D	7469 857963	GALINA YAKOVLEVA	{"email": "yakovleva.galina-22041975@postgrespro.ru", "phone": "+70919246879"}
0005433343386	A0733D	9651 778807	VITALIY NAZAROV	{"email": "nazarov.v.18011969@postgrespro.ru", "phone": "+70210158816"}
0005433343387	00597A	1509 570962	LIDIYA KARPOVA	{"email": "karpova.l.1980@postgrespro.ru", "phone": "+70822322237"}
0005433343388	00597A	5593 719475	EKATERINA VOLKOVA	{"email": "volkova_ekaterina_25111969@postgrespro.ru", "phone": "+70434670738"}
0005433343389	F16F5E	0007 380094	NATALYA KRASNOVA	{"phone": "+70289395807"}
0005433343390	F16F5E	2855 839528	NATALYA KUZNECOVA	{"phone": "+70745290017"}
0005433343391	AE868E	1755 167064	SERGEY NIKOLAEV	{"email": "nikolaevsergey031973@postgrespro.ru", "phone": "+70876134041"}
0005433343392	AE868E	9203 606054	TATYANA GUSEVA	{"email": "guseva_tatyana-10121976@postgrespro.ru", "phone": "+70327088590"}
0005433343393	AE868E	7508 953370	SERGEY KOZLOV	{"phone": "+70413462252"}
0005433343394	EACA44	0821 775423	EVGENIY BONDARENKO	{"email": "evgeniy_bondarenko_03071967@postgrespro.ru", "phone": "+70389004844"}
0005433343395	EACA44	0712 081437	ANATOLIY BELOV	{"email": "a-belov-12121972@postgrespro.ru", "phone": "+70216956909"}
0005433343396	130B92	6907 978541	VYACHESLAV EGOROV	{"email": "egorovvyacheslav_1971@postgrespro.ru", "phone": "+70896836825"}
0005433343397	8BC386	1617 976090	NIKOLAY BORISOV	{"phone": "+70075265336"}
0005433343398	1175CF	4567 873132	YULIYA VOLKOVA	{"email": "volkova_yuliya.1970@postgrespro.ru", "phone": "+70182857025"}
0005433343399	1175CF	8798 300374	PAVEL MAKSIMOV	{"email": "p-maksimov.1985@postgrespro.ru", "phone": "+70788777019"}
0005433343400	2DD805	9935 054231	DMITRIY MOROZOV	{"email": "dmitriy.morozov021977@postgrespro.ru", "phone": "+70597827249"}
0005433343401	5FB88B	5913 136776	ALEKSANDR VOLKOV	{"phone": "+70257037606"}
0005433343402	40374F	0209 420620	VALENTINA GORBUNOVA	{"phone": "+70715542320"}
0005433343403	40374F	9635 216901	NINA STEPANOVA	{"phone": "+70179002102"}
0005433343404	85FFF2	5744 494878	VALENTIN DENISOV	{"email": "valentindenisov-1976@postgrespro.ru", "phone": "+70497028862"}
0005433343405	DD69C6	6587 836329	ANNA ANDREEVA	{"phone": "+70876915700"}
0005433343406	DD69C6	0485 101185	LIDIYA SAVELEVA	{"phone": "+70528010489"}
0005433343407	E4EE86	3795 931355	TATYANA KOMAROVA	{"phone": "+70774185121"}
0005433343408	E4EE86	0761 356544	ALEKSANDR VOROBEV	{"phone": "+70446302371"}
0005433343409	C3DB77	0736 560841	IRINA IVANOVA	{"email": "ivanova_irina011985@postgrespro.ru", "phone": "+70267045620"}
0005433343410	3C2D8B	3599 432862	OLGA IVANOVA	{"email": "ivanova.o24101967@postgrespro.ru", "phone": "+70670840606"}
0005433343411	3C2D8B	3466 729249	VYACHESLAV STEPANOV	{"email": "stepanov-vyacheslav-091970@postgrespro.ru", "phone": "+70655681306"}
0005433343412	3C2D8B	9082 447898	NADEZHDA OSIPOVA	{"phone": "+70397902265"}
0005433343413	07CCE8	3654 844391	DINARA IVANOVA	{"phone": "+70276941348"}
0005433343414	95F8AB	2076 735668	ILYA POPOV	{"email": "ilyapopov.021967@postgrespro.ru", "phone": "+70309955342"}
0005433343415	95F8AB	4308 727872	ILYA MEDVEDEV	{"email": "ilyamedvedev_061965@postgrespro.ru", "phone": "+70039046872"}
0005433343416	D72939	2736 320079	EKATERINA MEDVEDEVA	{"email": "ekaterinamedvedeva1973@postgrespro.ru", "phone": "+70117961040"}
0005433343417	D72939	3914 735061	TATYANA MIRONOVA	{"phone": "+70309890207"}
0005433343597	747DAF	7467 677709	LARISA KONOVALOVA	{"phone": "+70758985159"}
0005433343418	D72939	3405 449528	SNEZHANA ALEKSANDROVA	{"email": "aleksandrovas-19021965@postgrespro.ru", "phone": "+70236488298"}
0005433343419	A97C6E	0524 919618	EVGENIY SEMENOV	{"phone": "+70774986019"}
0005433343420	35A861	9691 645393	ELENA KUZNECOVA	{"email": "kuznecova.elena20081975@postgrespro.ru", "phone": "+70155922696"}
0005433343421	BC0DBD	8335 529510	ANDREY FILIPPOV	{"phone": "+70473475640"}
0005433343422	203819	5916 419024	VALENTINA IVANOVA	{"email": "ivanova.valentina_121972@postgrespro.ru", "phone": "+70448901775"}
0005433343423	3CBA5A	0371 199709	GALINA KARPOVA	{"phone": "+70484175557"}
0005433343424	3CBA5A	2235 274447	GALINA MIRONOVA	{"email": "g.mironova_24081972@postgrespro.ru", "phone": "+70271007687"}
0005433343481	2A0C81	3792 730493	DIANA POPOVA	{"phone": "+70672797568"}
0005433343425	3CBA5A	4577 665914	SERGEY PAVLOV	{"email": "s.pavlov_19041974@postgrespro.ru", "phone": "+70432361471"}
0005433343426	0BBE11	9234 997513	NATALYA EGOROVA	{"phone": "+70770771406"}
0005433343427	0BBE11	8272 848210	NADEZHDA ANDREEVA	{"phone": "+70290605402"}
0005433343428	61EE3B	6558 767688	ZOYA KUZNECOVA	{"phone": "+70849757625"}
0005433343429	61EE3B	2427 805229	GULNAZ KOLESNIKOVA	{"phone": "+70887858087"}
0005433343430	5CF88B	7835 482302	SERGEY VOLKOV	{"phone": "+70651061211"}
0005433343431	65F1E1	2013 850020	NATALYA KARPOVA	{"email": "karpova_natalya16021971@postgrespro.ru", "phone": "+70196550785"}
0005433343432	65F1E1	0727 056553	RAISA KOZLOVA	{"email": "r.kozlova_24091974@postgrespro.ru", "phone": "+70167888062"}
0005433343433	12EB6D	7176 745911	ELENA ARKHIPOVA	{"email": "elenaarkhipova06061981@postgrespro.ru", "phone": "+70540966753"}
0005433343434	D0AA7C	7178 462573	IRINA SERGEEVA	{"phone": "+70867540209"}
0005433343435	D0AA7C	7333 447845	GALINA EGOROVA	{"phone": "+70389423852"}
0005433343436	D0AA7C	2325 925956	NATALYA GERASIMOVA	{"email": "natalya-gerasimova_26071970@postgrespro.ru", "phone": "+70023044240"}
0005433343437	945FC3	6777 928048	VERA TARASOVA	{"phone": "+70797328829"}
0005433343438	945FC3	9266 018485	OKSANA ANDREEVA	{"phone": "+70780718602"}
0005433343439	6FCCF4	7845 502309	NINA IVANOVA	{"phone": "+70575760614"}
0005433343440	E5881D	1242 991690	EVGENIY DMITRIEV	{"phone": "+70313278781"}
0005433343441	E5881D	8139 257098	VLADIMIR NIKOLAEV	{"email": "vnikolaev_111977@postgrespro.ru", "phone": "+70335647330"}
0005433343442	1FD4A3	9836 096458	VALERIY PETROV	{"phone": "+70296627716"}
0005433343443	1FD4A3	9023 344743	VIKTOR OSIPOV	{"email": "viktorosipov1980@postgrespro.ru", "phone": "+70779797053"}
0005433343444	138889	3298 907474	ANNA KUZNECOVA	{"phone": "+70371332332"}
0005433343445	65B33B	7051 890312	VIKTORIYA ORLOVA	{"phone": "+70375843698"}
0005433343446	65B33B	1122 617997	OLGA SERGEEVA	{"phone": "+70681456953"}
0005433343447	D468F7	7249 522338	SVETLANA ANTONOVA	{"email": "antonova_s_23111970@postgrespro.ru", "phone": "+70322366925"}
0005433343448	64A616	4877 292720	OLEG BORISOV	{"phone": "+70633531692"}
0005433343449	64A616	8075 113415	ALEKSEY FROLOV	{"phone": "+70692730746"}
0005433343450	F759F4	4849 299055	NIKOLAY IVANOV	{"email": "ivanov.n111976@postgrespro.ru", "phone": "+70774324432"}
0005433343451	3FE980	1976 833055	VASILIY SOROKIN	{"email": "sorokin.v.1979@postgrespro.ru", "phone": "+70559030279"}
0005433343452	1E8C70	7843 244321	MAKAR CHERNOV	{"email": "makar_chernov_041976@postgrespro.ru", "phone": "+70135006871"}
0005433343453	1E8C70	3078 043769	NINA TIKHONOVA	{"phone": "+70840154878"}
0005433343454	1E8C70	1012 297097	VALENTINA FADEEVA	{"phone": "+70814343481"}
0005433343455	748356	0741 011239	ILYA EGOROV	{"phone": "+70505307139"}
0005433343456	748356	2463 431694	DMITRIY GERASIMOV	{"phone": "+70589267759"}
0005433343457	25656B	2728 168099	ALEKSEY VASILEV	{"email": "avasilev_28031974@postgrespro.ru", "phone": "+70065164473"}
0005433343458	25656B	5336 170470	VALENTINA NESTEROVA	{"email": "nesterova.v-111975@postgrespro.ru", "phone": "+70609773831"}
0005433343459	BF5B03	8049 403431	NINA VLASOVA	{"phone": "+70135164911"}
0005433343460	BF5B03	0675 905221	ANNA PETROVA	{"email": "a_petrova-13111971@postgrespro.ru", "phone": "+70412026281"}
0005433343461	3FB0AC	9806 369546	GALINA BELOVA	{"phone": "+70089095110"}
0005433343462	3FB0AC	3064 590843	KSENIYA KOZLOVA	{"email": "kseniyakozlova-03061967@postgrespro.ru", "phone": "+70686363841"}
0005433343463	01BDA6	0206 693217	KONSTANTIN KUZNECOV	{"email": "k.kuznecov.1962@postgrespro.ru", "phone": "+70195748254"}
0005433343464	ED4563	8476 417681	MARIYA LEBEDEVA	{"email": "mariya-lebedeva011977@postgrespro.ru", "phone": "+70112745864"}
0005433343465	ED4563	9975 228732	NATALYA GERASIMOVA	{"phone": "+70037985977"}
0005433343466	24111F	0577 123231	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr_11101963@postgrespro.ru", "phone": "+70912339561"}
0005433343467	3D070E	2568 504710	LEONID MEDVEDEV	{"email": "lmedvedev121983@postgrespro.ru", "phone": "+70049113897"}
0005433343468	7FB97C	4801 630539	SVETLANA RODIONOVA	{"email": "s.rodionova_13051975@postgrespro.ru", "phone": "+70576327623"}
0005433343469	64620A	2806 287552	IGOR MIRONOV	{"email": "igor-mironov_031979@postgrespro.ru", "phone": "+70033634067"}
0005433343470	64620A	4829 405648	TATYANA PAVLOVA	{"phone": "+70644642009"}
0005433343471	332DA9	0490 524880	DMITRIY ANDREEV	{"email": "andreevdmitriy_28071975@postgrespro.ru", "phone": "+70154887263"}
0005433343472	7C1B1A	1487 546447	RIMMA VASILEVA	{"phone": "+70528010128"}
0005433343473	7C1B1A	5364 462917	EVGENIY KUZNECOV	{"email": "ekuznecov1972@postgrespro.ru", "phone": "+70734166205"}
0005433343474	9707CA	0704 763878	IRINA EFREMOVA	{"email": "efremovai.01091970@postgrespro.ru", "phone": "+70899115344"}
0005433343475	73342A	8612 864099	NATALYA MAKSIMOVA	{"email": "n-maksimova-121973@postgrespro.ru", "phone": "+70325196129"}
0005433343476	73342A	0230 863161	DMITRIY ZHUKOV	{"email": "zhukov-dmitriy.1959@postgrespro.ru", "phone": "+70795186347"}
0005433343477	291EB6	9402 602851	EKATERINA GORBUNOVA	{"phone": "+70748342706"}
0005433343478	B96311	0004 806839	IVAN SERGEEV	{"email": "sergeev-ivan-07021971@postgrespro.ru", "phone": "+70028361705"}
0005433343479	9753AC	6859 885388	NINA RYABOVA	{"phone": "+70585650333"}
0005433343480	BCC583	3870 833328	MARIYA IVANOVA	{"email": "ivanovam_1967@postgrespro.ru", "phone": "+70261918462"}
0005433343482	2A0C81	5260 539871	VALERIY KUZNECOV	{"email": "kuznecov.v_31011976@postgrespro.ru", "phone": "+70576103924"}
0005433343483	F38F63	6533 418250	YURIY SERGEEV	{"phone": "+70495701890"}
0005433343484	B5224E	4902 545854	VLADIMIR POPOV	{"email": "popov.v_1970@postgrespro.ru", "phone": "+70936794129"}
0005433343485	8331C8	0298 854066	ANTON DAVYDOV	{"email": "anton-davydov.051972@postgrespro.ru", "phone": "+70437358191"}
0005433343486	8331C8	8036 222897	OLGA VOLKOVA	{"email": "volkovao.1968@postgrespro.ru", "phone": "+70800358139"}
0005433343487	8331C8	9884 749816	ELENA ERMAKOVA	{"phone": "+70099186943"}
0005433343488	E2DD93	1245 304971	ARINA ORLOVA	{"phone": "+70533263105"}
0005433343489	5A562F	5520 545390	ALEKSEY KUZNECOV	{"email": "kuznecov-a091976@postgrespro.ru", "phone": "+70737364044"}
0005433343490	439BCF	7545 838952	ANGELINA ILINA	{"phone": "+70711994330"}
0005433343491	439BCF	6299 964111	VALENTINA MAKAROVA	{"email": "valentina.makarova_04111969@postgrespro.ru", "phone": "+70414694028"}
0005433343492	40D2EC	8031 346511	OLEG PETROV	{"phone": "+70961106700"}
0005433343493	40D2EC	0862 223962	YULIANA PETROVA	{"email": "y_petrova.1972@postgrespro.ru", "phone": "+70748705493"}
0005433343494	3E8083	8179 843275	ELENA SOKOLOVA	{"email": "sokolova.e.1975@postgrespro.ru", "phone": "+70195837234"}
0005433343495	3E8083	6367 193063	MARIYA ANDREEVA	{"phone": "+70103396621"}
0005433343496	AE3B76	9557 911771	LIDIYA VOLKOVA	{"phone": "+70793991433"}
0005433343497	AE3B76	7557 812233	VALERIY KUZNECOV	{"phone": "+70780796312"}
0005433343498	7BDFF1	9566 747405	VALERIYA ALEKSEEVA	{"email": "alekseeva-v-081954@postgrespro.ru", "phone": "+70112220758"}
0005433343499	7BDFF1	5401 863256	IGOR YAKOVLEV	{"email": "igor-yakovlev041960@postgrespro.ru", "phone": "+70988851932"}
0005433343500	7DA799	4913 059147	ALEKSANDRA ZHUKOVA	{"email": "aleksandrazhukova1973@postgrespro.ru", "phone": "+70103823918"}
0005433343501	0F4FBB	9663 338579	DARYA ANISIMOVA	{"email": "anisimova_darya_121961@postgrespro.ru", "phone": "+70077907915"}
0005433343502	0F4FBB	7282 391273	ALEKSANDR SMIRNOV	{"phone": "+70264450930"}
0005433343503	72C48B	0382 902512	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy071974@postgrespro.ru", "phone": "+70714260673"}
0005433343504	C62B63	3728 484329	PAVEL PAVLOV	{"email": "pavlov.p_1980@postgrespro.ru", "phone": "+70609654891"}
0005433343505	C62B63	1754 787520	ANDREY GUSEV	{"phone": "+70116076312"}
0005433343506	C62B63	2862 388215	YURIY KUDRYASHOV	{"email": "kudryashovyuriy-041970@postgrespro.ru", "phone": "+70584702530"}
0005433343507	634A6E	8132 335625	MIKHAIL GAVRILOV	{"email": "mikhail.gavrilov.1973@postgrespro.ru", "phone": "+70650879393"}
0005433343508	2A3606	3588 780603	OLGA MAKAROVA	{"phone": "+70494525498"}
0005433343509	AAB079	7388 977885	ALEKSANDR GERASIMOV	{"email": "gerasimovaleksandr-14081974@postgrespro.ru", "phone": "+70402998274"}
0005433343510	AAB079	6371 455990	IRINA ANDREEVA	{"email": "andreeva.i-041973@postgrespro.ru", "phone": "+70561337642"}
0005433343511	926455	9149 285780	GALINA KUZNECOVA	{"phone": "+70543833058"}
0005433343512	C0C4FE	3566 217480	EKATERINA SOKOLOVA	{"email": "sokolova.e-07121972@postgrespro.ru", "phone": "+70069189500"}
0005433343513	F82EC4	3128 548337	VALENTINA VOLKOVA	{"phone": "+70301753491"}
0005433343514	F82EC4	4936 753406	ZINAIDA KONOVALOVA	{"email": "konovalova.zinaida_1970@postgrespro.ru", "phone": "+70577086316"}
0005433343515	342BD2	1880 118646	ANATOLIY FILIPPOV	{"phone": "+70067225252"}
0005433343516	552C04	0634 655120	PAVEL IVANOV	{"phone": "+70455314671"}
0005433343517	6F03AF	8048 757459	TATYANA IVANOVA	{"phone": "+70620320957"}
0005433343518	6F03AF	5763 589915	IRINA PAVLOVA	{"email": "irina.pavlova-10081974@postgrespro.ru", "phone": "+70407271184"}
0005433343519	BC7CA1	6800 989254	YAROSLAV NIKOLAEV	{"email": "yaroslav_nikolaev-06041968@postgrespro.ru", "phone": "+70004729108"}
0005433343520	BC7CA1	2542 873267	ZINAIDA STEPANOVA	{"phone": "+70027392132"}
0005433343521	B6567C	6885 327449	IRINA VOROBEVA	{"phone": "+70550244057"}
0005433343522	B6567C	1149 512018	RUSLAN KULIKOV	{"phone": "+70658263450"}
0005433343523	B76112	9523 495492	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.a011975@postgrespro.ru", "phone": "+70722059650"}
0005433343524	B76112	0134 542076	KONSTANTIN KAZAKOV	{"email": "konstantinkazakov-081988@postgrespro.ru", "phone": "+70714680973"}
0005433343525	B5DB63	5490 030761	YURIY SCHERBAKOV	{"email": "scherbakov-y.26011985@postgrespro.ru", "phone": "+70014171456"}
0005433343526	B5DB63	4014 553900	VALENTINA KUZNECOVA	{"phone": "+70544754640"}
0005433343527	02916C	1693 809928	NADEZHDA BORISOVA	{"phone": "+70752448379"}
0005433343528	E6BFEA	8116 388462	YANA ZAKHAROVA	{"email": "zakharova.y-1962@postgrespro.ru", "phone": "+70980894103"}
0005433343529	045A32	2359 174953	VIKTOR POPOV	{"email": "popov_viktor.14011972@postgrespro.ru", "phone": "+70740848552"}
0005433343530	DA757D	8842 753109	LIDIYA KOZLOVA	{"phone": "+70943029154"}
0005433343531	9FEFFE	8146 052007	KRISTINA MAKAROVA	{"email": "makarovak_1967@postgrespro.ru", "phone": "+70386220322"}
0005433343532	E2CA4C	7142 748792	VIKTOR MARTYNOV	{"email": "martynov-viktor1980@postgrespro.ru", "phone": "+70645247595"}
0005433343533	D3E015	2864 490998	BORIS BORISOV	{"phone": "+70674810362"}
0005433343534	B8B8B0	0988 217348	GALINA MARTYNOVA	{"email": "galina-martynova-021978@postgrespro.ru", "phone": "+70313470074"}
0005433343535	40DA2D	2800 923169	VLADIMIR FOMIN	{"phone": "+70255425256"}
0005433343536	40DA2D	2345 123311	VYACHESLAV FEDOROV	{"phone": "+70936282312"}
0005433343537	40DA2D	1700 636240	NADEZHDA FOMINA	{"email": "fomina_nadezhda_021970@postgrespro.ru", "phone": "+70027992056"}
0005433343539	FA47D8	4387 596478	YURIY KISELEV	{"email": "y-kiselev-1971@postgrespro.ru", "phone": "+70440699314"}
0005433343540	CFA848	2042 116888	IRINA BORISOVA	{"email": "borisova_irina-091970@postgrespro.ru", "phone": "+70882017513"}
0005433343541	F5C89B	0773 477106	ALEKSANDR NAUMOV	{"phone": "+70034187882"}
0005433343542	F5C89B	6606 082969	SERGEY GERASIMOV	{"email": "s.gerasimov.1978@postgrespro.ru", "phone": "+70881776301"}
0005433343543	E88C84	9809 202496	NIKOLAY BELOV	{"phone": "+70381393221"}
0005433343544	E88C84	5133 175435	EVGENIY STEPANOV	{"email": "stepanov.e.1968@postgrespro.ru", "phone": "+70971845898"}
0005433343545	99F3ED	3004 423988	NIKITA FROLOV	{"phone": "+70968601820"}
0005433343546	99F3ED	4589 402235	LYUDMILA GUSEVA	{"phone": "+70680930538"}
0005433343547	7B6F10	3865 056171	DMITRIY NOVIKOV	{"phone": "+70903041329"}
0005433343548	7B6F10	2470 345867	LYUBOV VOROBEVA	{"email": "vorobeva-l_1983@postgrespro.ru", "phone": "+70043125413"}
0005433343549	A854B2	3930 909004	TATYANA TITOVA	{"email": "titovatatyana1972@postgrespro.ru", "phone": "+70080936494"}
0005433343550	A854B2	5783 679275	DARYA ZHUKOVA	{"phone": "+70433008531"}
0005433343551	73EBF0	7146 210664	NINA ANISIMOVA	{"phone": "+70779911385"}
0005433343552	F774AC	3994 876056	NATALYA MALYSHEVA	{"email": "n-malysheva.15111978@postgrespro.ru", "phone": "+70007963719"}
0005433343553	17C256	9300 299102	OLGA OSIPOVA	{"email": "osipovao12051974@postgrespro.ru", "phone": "+70202781567"}
0005433343554	5538DF	6559 561537	ANDREY TIKHONOV	{"email": "tikhonovandrey.1969@postgrespro.ru", "phone": "+70642092195"}
0005433343555	5538DF	7201 461331	NADEZHDA SEMENOVA	{"phone": "+70444836561"}
0005433343556	904F83	0219 820237	GALINA EFIMOVA	{"email": "galina.efimova-1975@postgrespro.ru", "phone": "+70053809193"}
0005433343557	990768	5199 033729	ANDREY STEPANOV	{"phone": "+70887229153"}
0005433343558	FFAD23	1504 686515	RAVIL KUZNECOV	{"email": "kuznecov_ravil_091966@postgrespro.ru", "phone": "+70386654412"}
0005433343559	FFAD23	8904 982243	VALENTINA FEDOROVA	{"email": "valentinafedorova-1987@postgrespro.ru", "phone": "+70040251064"}
0005433343560	FFAD23	0848 475620	MARGARITA KAZAKOVA	{"email": "kazakovamargarita-10061964@postgrespro.ru", "phone": "+70324936513"}
0005433343561	92A810	4092 099845	VIKTOR TARASOV	{"email": "tarasov_viktor-111971@postgrespro.ru", "phone": "+70205542754"}
0005433343562	811FCE	3982 587052	SVETLANA PETROVA	{"email": "petrovas.1969@postgrespro.ru", "phone": "+70500129756"}
0005433343563	811FCE	0505 383176	ALEKSEY SOKOLOV	{"phone": "+70979378029"}
0005433343564	811FCE	5070 464030	ALEKSANDR MOROZOV	{"email": "a_morozov-05061973@postgrespro.ru", "phone": "+70382963773"}
0005433343565	0624EC	8767 058029	NIKOLAY PETROV	{"phone": "+70468344227"}
0005433343566	74F38A	8032 217078	IVAN ANTONOV	{"email": "ivan.antonov-1971@postgrespro.ru", "phone": "+70530105934"}
0005433343567	C1062C	6317 083384	TAMARA SOLOVEVA	{"phone": "+70587652079"}
0005433343568	274845	6416 343680	ANASTASIYA ALEKSEEVA	{"email": "alekseeva-anastasiya_1973@postgrespro.ru", "phone": "+70847710637"}
0005433343569	8E48D5	0666 073472	VALENTINA KOZLOVA	{"email": "kozlova.valentina.121968@postgrespro.ru", "phone": "+70837884052"}
0005433343570	F5327B	7447 590218	DMITRIY OSIPOV	{"email": "d.osipov_1961@postgrespro.ru", "phone": "+70392565853"}
0005433343571	C05251	9712 361087	ALEKSANDR FOMIN	{"phone": "+70297747016"}
0005433343572	F8586F	0286 404396	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir04031959@postgrespro.ru", "phone": "+70778005012"}
0005433343573	659C74	9499 695183	NATALIYA NAZAROVA	{"email": "nataliya-nazarova-031974@postgrespro.ru", "phone": "+70187067165"}
0005433343574	D62AD3	0413 042956	SERGEY VOROBEV	{"phone": "+70016074126"}
0005433343575	BD3C8D	4483 387694	VADIM STEPANOV	{"email": "v.stepanov-1972@postgrespro.ru", "phone": "+70201142931"}
0005433343576	49C23B	1588 848801	GALINA ABRAMOVA	{"email": "abramova-g_1967@postgrespro.ru", "phone": "+70601548223"}
0005433343577	49C23B	1796 863224	MARINA KOZLOVA	{"email": "marina-kozlova_26021977@postgrespro.ru", "phone": "+70597803522"}
0005433343578	C3C600	0525 021142	ALEKSANDR POPOV	{"email": "popov_aleksandr1967@postgrespro.ru", "phone": "+70865091075"}
0005433343579	2FE6D0	1948 372454	IRINA PETROVA	{"phone": "+70844063078"}
0005433343580	A47407	0432 422623	KONSTANTIN KONOVALOV	{"phone": "+70173667610"}
0005433343581	3F84E8	7502 600357	VLADIMIR BARANOV	{"email": "v-baranov_30101976@postgrespro.ru", "phone": "+70367114498"}
0005433343582	09776E	0910 784587	SERGEY VASILEV	{"email": "vasilevsergey-051968@postgrespro.ru", "phone": "+70969163391"}
0005433343583	09776E	7044 033552	OKSANA POLYAKOVA	{"email": "polyakova_oksana-011981@postgrespro.ru", "phone": "+70315135096"}
0005433343584	CB9457	3239 712472	NINA KUZNECOVA	{"phone": "+70338922238"}
0005433343585	0266EF	8390 903517	TAISIYA SOKOLOVA	{"email": "t_sokolova_01081977@postgrespro.ru", "phone": "+70785605994"}
0005433343586	84222A	2309 144290	ZHANNA MIKHAYLOVA	{"email": "zmikhaylova-1971@postgrespro.ru", "phone": "+70774583969"}
0005433343587	84222A	8936 331890	ALEKSANDR IVANOV	{"phone": "+70457389122"}
0005433343588	E0014F	8643 391970	YAROSLAV PAVLOV	{"phone": "+70742537748"}
0005433343589	146466	9953 088082	NIKOLAY SCHERBAKOV	{"email": "nikolay-scherbakov1969@postgrespro.ru", "phone": "+70278332582"}
0005433343590	F1C449	6532 823606	SERGEY MIKHAYLOV	{"email": "s.mikhaylov.061971@postgrespro.ru", "phone": "+70014628724"}
0005433343591	ECAD56	5831 311122	RAMILYA SMIRNOVA	{"phone": "+70312897339"}
0005433343592	8A63DE	7839 583907	VALENTINA BORISOVA	{"email": "borisova-valentina.14091962@postgrespro.ru", "phone": "+70805200530"}
0005433343593	8A63DE	9668 377166	IRINA PAVLOVA	{"email": "irina.pavlova_1975@postgrespro.ru", "phone": "+70128852703"}
0005433343594	0A99D2	2844 999303	ALEKSANDR SEMENOV	{"phone": "+70217376532"}
0005433343595	FA9F14	3199 453639	VIKTOR DMITRIEV	{"email": "dmitrievviktor.1968@postgrespro.ru", "phone": "+70345701709"}
0005433343596	2A7A44	1821 163748	NIKITA ISAEV	{"phone": "+70647681481"}
0005433343598	EA64B4	0493 326841	MIKHAIL MELNIKOV	{"email": "m-melnikov-031963@postgrespro.ru", "phone": "+70216399325"}
0005433343599	3A5CAD	1817 216531	RUFIYA KUZNECOVA	{"email": "r-kuznecova_081971@postgrespro.ru", "phone": "+70834441810"}
0005433343600	39064C	6430 071484	EMILIYA IVANOVA	{"phone": "+70423534532"}
0005433343601	39064C	6641 659228	NINA EGOROVA	{"email": "egorova_n.18061973@postgrespro.ru", "phone": "+70214200186"}
0005433343602	B719AE	7002 437557	NIKOLAY SOROKIN	{"email": "sorokinnikolay_14081964@postgrespro.ru", "phone": "+70013347046"}
0005433343603	65A374	6850 791052	NATALYA ZHUKOVA	{"email": "n_zhukova-041978@postgrespro.ru", "phone": "+70120185776"}
0005433343604	C275EB	1263 662824	ELENA KOZLOVA	{"phone": "+70969314847"}
0005433343605	C275EB	4767 466833	ELIZAVETA NIKITINA	{"email": "nikitina-elizaveta-011975@postgrespro.ru", "phone": "+70167722221"}
0005433343606	47F837	8254 032248	NATALYA NIKITINA	{"phone": "+70570885965"}
0005433343607	0791BC	7042 164832	RIMA BELOVA	{"email": "r-belova-17051969@postgrespro.ru", "phone": "+70396890267"}
0005433343608	19F32A	7783 506180	RAMIL GERASIMOV	{"email": "r-gerasimov1973@postgrespro.ru", "phone": "+70417300434"}
0005433343609	6F8CD9	1600 999523	KIRILL MELNIKOV	{"phone": "+70295259519"}
0005433343610	79C744	0852 373333	LARISA KUZNECOVA	{"email": "kuznecova-larisa041977@postgrespro.ru", "phone": "+70765674877"}
0005433343611	79C744	1488 016369	EDUARD KUZMIN	{"phone": "+70259891243"}
0005433343612	FD2039	4817 770570	VLADIMIR KRASNOV	{"phone": "+70331058061"}
0005433343613	17E442	7011 867015	VIKTOR POPOV	{"email": "popov.viktor14051977@postgrespro.ru", "phone": "+70527939876"}
0005433343614	05394F	9787 706367	TATYANA BARANOVA	{"phone": "+70396009332"}
0005433343615	8E2CB4	8520 901951	ARTEM ILIN	{"email": "artem_ilin_07071976@postgrespro.ru", "phone": "+70101577477"}
0005433343616	8E2CB4	1102 717745	ALEKSEY KOROLEV	{"email": "akorolev.26071965@postgrespro.ru", "phone": "+70518156142"}
0005433343617	E90A93	7673 387183	SVETLANA ALEKSEEVA	{"phone": "+70538187548"}
0005433343618	E90A93	9207 936468	EKATERINA SOROKINA	{"phone": "+70991480175"}
0005433343619	E94B1E	5513 650819	ELENA PETROVA	{"email": "elena-petrova031978@postgrespro.ru", "phone": "+70868236853"}
0005433343620	4A5E7F	6621 547915	SERGEY BORISOV	{"phone": "+70394772753"}
0005433343621	4A5E7F	0300 565427	ROZA FILATOVA	{"email": "filatova-r_1968@postgrespro.ru", "phone": "+70662272105"}
0005433343622	945941	6563 726210	SERGEY SEMENOV	{"phone": "+70067603170"}
0005433343623	945941	0411 259615	EVGENIY IVANOV	{"phone": "+70130082187"}
0005433343624	945941	9261 386083	LYUBOV LUKYANOVA	{"email": "lyubovlukyanova-04071980@postgrespro.ru", "phone": "+70351129495"}
0005433343625	8EDFBE	4049 411719	KIRILL MARTYNOV	{"email": "martynovkirill-03021980@postgrespro.ru", "phone": "+70702724483"}
0005433343626	CEE20C	1796 166500	VALENTINA MALYSHEVA	{"email": "v_malysheva.041971@postgrespro.ru", "phone": "+70240808137"}
0005433343627	58B8F9	5002 456812	VALENTINA KARPOVA	{"email": "karpova-valentina.041977@postgrespro.ru", "phone": "+70054362773"}
0005433343628	58B8F9	4083 229747	VYACHESLAV ILIN	{"phone": "+70055406013"}
0005433343629	6C1CA4	8211 002698	TAMARA FROLOVA	{"email": "frolovatamara-061968@postgrespro.ru", "phone": "+70964708368"}
0005433343630	30C47A	3869 900365	NIKOLAY BARANOV	{"phone": "+70576255330"}
0005433343631	32E938	4655 763227	DMITRIY FOMIN	{"phone": "+70038569516"}
0005433343632	6A9E92	2674 036042	SERGEY KOZLOV	{"phone": "+70183929650"}
0005433343633	6A9E92	4794 696467	OKSANA ZAYCEVA	{"email": "zayceva-o071973@postgrespro.ru", "phone": "+70026247534"}
0005433343634	1B3A34	9697 561035	DMITRIY ROMANOV	{"email": "dmitriyromanov-02011977@postgrespro.ru", "phone": "+70297962319"}
0005433343635	E29DBC	4373 313917	ALEKSANDR ZAKHAROV	{"phone": "+70126852856"}
0005433343636	E29DBC	9212 983044	NINA KARPOVA	{"phone": "+70464469574"}
0005433343637	E29DBC	5497 527774	YURIY VASILEV	{"email": "yuriyvasilev-091958@postgrespro.ru", "phone": "+70681906595"}
0005433343638	5CB967	8729 280394	ALEKSEY SIDOROV	{"email": "sidorov_aleksey10011970@postgrespro.ru", "phone": "+70187910681"}
0005433343639	3C2AA5	1766 396572	GALINA IVANOVA	{"email": "givanova_25011980@postgrespro.ru", "phone": "+70843113760"}
0005433343640	A61D84	7287 559687	ALENA KUZNECOVA	{"email": "alena-kuznecova.07071981@postgrespro.ru", "phone": "+70683401496"}
0005433343641	B910C5	3553 228619	KSENIYA KUZNECOVA	{"phone": "+70383599297"}
0005433343697	0A3BDF	6085 484564	OLEG SOLOVEV	{"phone": "+70316426810"}
0005433343642	D09F0C	7951 933481	GENNADIY STEPANOV	{"email": "stepanov.gennadiy-011981@postgrespro.ru", "phone": "+70993935476"}
0005433343643	9222CF	3580 299260	NATALYA NESTEROVA	{"email": "nnesterova_041965@postgrespro.ru", "phone": "+70348732264"}
0005433343644	1E4617	2717 601812	POLINA FOMINA	{"email": "pfomina_051968@postgrespro.ru", "phone": "+70529399372"}
0005433343645	692A5C	8254 852628	ALEKSEY ZAYCEV	{"phone": "+70580509057"}
0005433343646	692A5C	9932 013007	YULIYA ZAKHAROVA	{"phone": "+70675140849"}
0005433343647	09F127	7965 722607	ELENA ZAKHAROVA	{"phone": "+70804196532"}
0005433343648	935DB7	8140 225818	IRINA ABRAMOVA	{"phone": "+70884503428"}
0005433343649	9A4DA3	0006 755199	SVETLANA MALYSHEVA	{"email": "malysheva_svetlana_051975@postgrespro.ru", "phone": "+70477498033"}
0005433343650	4F3816	8479 386134	ALINA IVANOVA	{"phone": "+70934698203"}
0005433343651	DAF528	0967 947920	POLINA NOVIKOVA	{"phone": "+70192154988"}
0005433343652	00A94E	2876 718895	OLGA SOKOLOVA	{"phone": "+70076007065"}
0005433343653	CF282D	4877 235792	KHALIDA ANISIMOVA	{"email": "khalidaanisimova-1975@postgrespro.ru", "phone": "+70958489984"}
0005433343654	CF282D	0574 802493	VIKTOR GRIGOREV	{"phone": "+70207275994"}
0005433343655	C44DD8	1674 348692	VLADIMIR KUDRYASHOV	{"phone": "+70867913266"}
0005433343656	54CDBF	2561 634899	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev-1975@postgrespro.ru", "phone": "+70564133315"}
0005433343657	1B304F	1333 472778	LYUBOV LOGINOVA	{"phone": "+70950229131"}
0005433343658	CF1F62	9886 004342	VYACHESLAV KUZMIN	{"phone": "+70365714621"}
0005433343659	CF1F62	1245 513562	VLADIMIR GERASIMOV	{"email": "gerasimov.v-1972@postgrespro.ru", "phone": "+70439553187"}
0005433343660	F28D14	4638 558455	ANASTASIYA FILATOVA	{"email": "filatovaanastasiya_111972@postgrespro.ru", "phone": "+70985472465"}
0005433343661	F28D14	4023 822150	EKATERINA ILINA	{"phone": "+70699286785"}
0005433343662	F28D14	7212 657636	GALINA MALYSHEVA	{"email": "galina.malysheva_28091968@postgrespro.ru", "phone": "+70449120999"}
0005433343663	DEFA24	2678 545375	KRISTINA SOKOLOVA	{"phone": "+70058917786"}
0005433343664	DEFA24	4353 016825	VALERIYA ARKHIPOVA	{"phone": "+70755146276"}
0005433343665	EC1EAA	7689 255880	LARISA FILATOVA	{"email": "larisa.filatova-09041971@postgrespro.ru", "phone": "+70380720150"}
0005433343666	8C3364	9378 705447	SVETLANA ROMANOVA	{"email": "romanova-svetlana.1971@postgrespro.ru", "phone": "+70394282809"}
0005433343667	F89A53	2414 834071	VASILIY ISAEV	{"email": "isaevvasiliy.17111976@postgrespro.ru", "phone": "+70066520919"}
0005433343668	5067AB	0537 687632	FARIDA NOVIKOVA	{"email": "novikova.f.081965@postgrespro.ru", "phone": "+70744101365"}
0005433343669	324CAD	7871 483223	TATYANA KUDRYASHOVA	{"phone": "+70240573465"}
0005433343670	324CAD	4850 658720	ANDREY ROMANOV	{"phone": "+70605850178"}
0005433343671	9D160F	7867 701467	ZINAIDA AKIMOVA	{"email": "z_akimova-1970@postgrespro.ru", "phone": "+70127634478"}
0005433343672	9D160F	8194 391469	GENNADIY VOLKOV	{"email": "volkov_g_1969@postgrespro.ru", "phone": "+70699075360"}
0005433343673	0DE44E	9156 945386	SVETLANA TIMOFEEVA	{"email": "stimofeeva.1972@postgrespro.ru", "phone": "+70158119864"}
0005433343674	AFAF99	1735 611616	NATALYA ZHUKOVA	{"phone": "+70795043597"}
0005433343675	2ED1F3	8694 607666	ALEKSEY PETROV	{"email": "petrov-aleksey_21011973@postgrespro.ru", "phone": "+70544082267"}
0005433343676	2526AA	5053 223947	IVAN KUZMIN	{"email": "kuzmini1970@postgrespro.ru", "phone": "+70955011694"}
0005433343677	09F6C9	6816 715827	RAISA SERGEEVA	{"phone": "+70942948643"}
0005433343678	09F6C9	4224 997458	ALEKSANDR KUDRYASHOV	{"email": "aleksandr_kudryashov-12061972@postgrespro.ru", "phone": "+70307989359"}
0005433343679	C18EBF	8213 556730	NADEZHDA KALININA	{"phone": "+70212305081"}
0005433343680	9D5335	6495 546182	ANTON AFANASEV	{"email": "afanasevanton.091980@postgrespro.ru", "phone": "+70927820795"}
0005433343681	490EB2	3348 280644	VIKTORIYA LEBEDEVA	{"email": "lebedeva.viktoriya_1969@postgrespro.ru", "phone": "+70865916647"}
0005433343682	490EB2	6135 430187	IVAN ZAKHAROV	{"phone": "+70783453386"}
0005433343683	ABFF1C	1485 938059	VLADIMIR MEDVEDEV	{"email": "v.medvedev01101963@postgrespro.ru", "phone": "+70589986380"}
0005433343684	7E0A9C	9173 187444	LEONID GAVRILOV	{"email": "gavrilov-leonid-081966@postgrespro.ru", "phone": "+70627834497"}
0005433343685	E97A18	4174 779519	KSENIYA KAZAKOVA	{"phone": "+70637678387"}
0005433343686	E97A18	8994 164321	IVAN ZAKHAROV	{"email": "zakharovivan-1969@postgrespro.ru", "phone": "+70582656702"}
0005433343687	EC3884	8297 825330	ALEKSANDR MATVEEV	{"email": "a.matveev1972@postgrespro.ru", "phone": "+70343284544"}
0005433343688	EC3884	9942 113712	EKATERINA FROLOVA	{"phone": "+70210759277"}
0005433343689	EC3884	1425 962960	EKATERINA AFANASEVA	{"phone": "+70018359200"}
0005433343690	D06BCA	5915 838364	ALENA KUDRYASHOVA	{"phone": "+70563980042"}
0005433343691	9EC4CB	5321 624709	TAISIYA KAZAKOVA	{"email": "taisiya_kazakova17091969@postgrespro.ru", "phone": "+70380822300"}
0005433343692	44509C	7338 080577	YURIY ROMANOV	{"phone": "+70945432095"}
0005433343693	46E414	6434 121924	VALENTINA SIDOROVA	{"email": "valentina-sidorova_1969@postgrespro.ru", "phone": "+70700727319"}
0005433343694	6C3810	3390 419809	IVAN VASILEV	{"email": "vasilev.i1972@postgrespro.ru", "phone": "+70830479698"}
0005433343695	6C3810	3078 565759	ARTUR AFANASEV	{"email": "afanasev_a011977@postgrespro.ru", "phone": "+70407248180"}
0005433343696	C7EDB8	4381 321669	ALEKSEY MEDVEDEV	{"email": "medvedev_a.041973@postgrespro.ru", "phone": "+70577121220"}
0005433343698	EA66E1	8061 161643	VALENTINA SEMENOVA	{"email": "valentina.semenova_1971@postgrespro.ru", "phone": "+70656061230"}
0005433343699	5A0441	9095 728474	MARK ABRAMOV	{"phone": "+70141353121"}
0005433343700	35B9B8	7527 954741	LYUDMILA NAZAROVA	{"email": "lyudmilanazarova_1985@postgrespro.ru", "phone": "+70808221470"}
0005433343701	2E6191	0377 198596	ANDREY VOLKOV	{"phone": "+70572517361"}
0005433343702	2E6191	1088 996444	ANTONINA MALYSHEVA	{"email": "malyshevaantonina.111980@postgrespro.ru", "phone": "+70881725302"}
0005433343703	60CCF8	6367 658951	MARINA MATVEEVA	{"phone": "+70148570898"}
0005433343704	60CCF8	7705 365871	ANATOLIY YAKOVLEV	{"email": "a_yakovlev.1970@postgrespro.ru", "phone": "+70957065631"}
0005433343705	1C1B70	8643 225699	VLADIMIR ZAYCEV	{"email": "zaycev.vladimir.13061965@postgrespro.ru", "phone": "+70911697747"}
0005433343706	37B5DC	1361 249968	DMITRIY SEMENOV	{"phone": "+70324063521"}
0005433343707	7AC807	5701 743552	GALINA NESTEROVA	{"email": "nesterovag061971@postgrespro.ru", "phone": "+70776775197"}
0005433343708	7AC807	6477 582710	ALEKSANDR ZAKHAROV	{"email": "zakharov.a-1981@postgrespro.ru", "phone": "+70961428198"}
0005433343709	7AC807	2489 257179	DMITRIY SERGEEV	{"phone": "+70684009318"}
0005433343710	E9C3D6	0079 429936	VALERIY ILIN	{"phone": "+70683379688"}
0005433343711	D65044	8846 381488	EKATERINA IVANOVA	{"email": "e-ivanova061971@postgrespro.ru", "phone": "+70199037205"}
0005433343712	993DA9	8473 784442	GENNADIY SOKOLOV	{"phone": "+70989453236"}
0005433343713	F8B5D4	2949 351317	VLADISLAV POPOV	{"email": "vladislavpopov101971@postgrespro.ru", "phone": "+70930151214"}
0005433343714	A2A626	9772 017281	DENIS NIKOLAEV	{"phone": "+70172294310"}
0005433343715	83C398	2535 371482	LIDIYA KOZLOVA	{"phone": "+70714837249"}
0005433343716	B1DE17	2040 581389	MIKHAIL BORISOV	{"email": "borisov.m28011971@postgrespro.ru", "phone": "+70177210170"}
0005433343717	C4532F	5814 855849	YULIYA ZHUKOVA	{"phone": "+70077740973"}
0005433343718	2DCBDC	7092 819843	ALEKSEY KONOVALOV	{"phone": "+70164022212"}
0005433343719	53DCE3	0322 308294	LIDIYA GRISHINA	{"phone": "+70603875666"}
0005433343720	2925EA	9233 194195	ANASTASIYA PAVLOVA	{"email": "pavlova.anastasiya_12041980@postgrespro.ru", "phone": "+70088842663"}
0005433343721	2925EA	3956 292492	VLADIMIR EGOROV	{"email": "egorov_v.1973@postgrespro.ru", "phone": "+70909077446"}
0005433343722	0B3BA5	8496 571063	IVAN IVANOV	{"phone": "+70644978065"}
0005433343723	0B3BA5	9031 908651	EKATERINA ISAEVA	{"phone": "+70312261687"}
0005433343724	8E2D70	7397 121222	OLGA KOZLOVA	{"phone": "+70608507744"}
0005433343725	218C46	7160 349925	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev.1976@postgrespro.ru", "phone": "+70126375181"}
0005433343726	218C46	1272 104125	OLGA GERASIMOVA	{"email": "olga.gerasimova_121971@postgrespro.ru", "phone": "+70319270468"}
0005433343727	218C46	0434 264938	KLAVDIYA TIKHONOVA	{"email": "tikhonovak1974@postgrespro.ru", "phone": "+70542552098"}
0005433343728	4C265A	6831 770595	TATYANA SMIRNOVA	{"email": "tsmirnova-1968@postgrespro.ru", "phone": "+70642827068"}
0005433343729	4C265A	8245 671260	NATALYA CHERNOVA	{"email": "n-chernova.1984@postgrespro.ru", "phone": "+70623573992"}
0005433343730	D3B3A9	6651 802545	LYUBOV VOROBEVA	{"phone": "+70110089598"}
0005433343731	F32D3E	4739 910135	PAVEL BORISOV	{"email": "borisov.pavel-21051970@postgrespro.ru", "phone": "+70345112952"}
0005433343732	F32D3E	9471 613672	VLADIMIR ROMANOV	{"phone": "+70231018604"}
0005433343733	72EC29	2833 064591	GALINA KUZNECOVA	{"phone": "+70552791033"}
0005433343734	0711A0	3245 594673	ALEKSANDR NAUMOV	{"phone": "+70030925351"}
0005433343735	CABFED	4100 815092	VALENTINA VOROBEVA	{"phone": "+70070376368"}
0005433343736	063053	6967 014292	ANATOLIY FROLOV	{"email": "frolov.a.071974@postgrespro.ru", "phone": "+70266812870"}
0005433343737	063053	7133 853671	ANASTASIYA KUZNECOVA	{"phone": "+70465311203"}
0005433343738	2F739D	1169 136739	VALERIYA KUZMINA	{"email": "v_kuzmina031968@postgrespro.ru", "phone": "+70501016193"}
0005433343739	A49122	1810 189656	DMITRIY DAVYDOV	{"email": "davydov_d-12021969@postgrespro.ru", "phone": "+70888443037"}
0005433343740	D4B49E	8211 610425	SERGEY VOLKOV	{"phone": "+70493239646"}
0005433343741	BF10E6	5577 676573	LYUDMILA EFIMOVA	{"phone": "+70025369589"}
0005433343742	BF10E6	0951 921326	ARTEM GAVRILOV	{"email": "artem.gavrilov_1967@postgrespro.ru", "phone": "+70410292805"}
0005433343743	895A08	9808 290025	SHAMIL ANTONOV	{"email": "antonovs_1957@postgrespro.ru", "phone": "+70203213490"}
0005433343744	3A7A18	9368 229012	OLEG POPOV	{"email": "o-popov_021981@postgrespro.ru", "phone": "+70137543564"}
0005433343745	3FD3E9	5172 975216	MAKSIM SAVELEV	{"email": "maksim-savelev1971@postgrespro.ru", "phone": "+70995686636"}
0005433343746	E51023	7342 256748	ALEKSEY SOROKIN	{"email": "sorokin.a041971@postgrespro.ru", "phone": "+70586665216"}
0005433343747	E51023	5414 976561	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev1971@postgrespro.ru", "phone": "+70115108015"}
0005433343748	09466C	4132 777576	ANDREY NIKOLAEV	{"phone": "+70041612894"}
0005433343749	8C1D38	0051 784298	ALEVTINA KRASNOVA	{"email": "alevtinakrasnova_011979@postgrespro.ru", "phone": "+70238660954"}
0005433343750	8C1D38	3594 266640	RASHIT TIKHONOV	{"phone": "+70727720675"}
0005433343751	7CA09B	5235 977843	VIKTOR BARANOV	{"email": "v_baranov08071970@postgrespro.ru", "phone": "+70939590305"}
0005433343752	87D129	8902 136008	VLADIMIR MAKAROV	{"email": "makarov_vladimir_031968@postgrespro.ru", "phone": "+70793399173"}
0005433343753	87D129	4376 107535	VALENTINA FILIPPOVA	{"phone": "+70082561647"}
0005433343754	87D129	8780 354436	IRINA SMIRNOVA	{"phone": "+70705472272"}
0005433343755	8FD843	7795 068798	NIKOLAY GORBUNOV	{"email": "gorbunov-n-10081961@postgrespro.ru", "phone": "+70733023271"}
0005433343756	1B8EDF	6908 090487	VLADIMIR KUZMIN	{"email": "vladimir.kuzmin011968@postgrespro.ru", "phone": "+70913932004"}
0005433343757	4E0342	0153 364752	MARIYA KUZMINA	{"email": "mariya.kuzmina_1964@postgrespro.ru", "phone": "+70583126119"}
0005433343758	E010C8	6181 210731	ARTEM AFANASEV	{"email": "artemafanasev.1963@postgrespro.ru", "phone": "+70511599903"}
0005433343759	B1F515	0525 780561	EKATERINA MOROZOVA	{"phone": "+70760887422"}
0005433343760	842956	7726 277615	ANNA VLASOVA	{"email": "vlasova-a_1981@postgrespro.ru", "phone": "+70440710007"}
0005433343761	0B3A43	4808 423467	NIKOLAY IVANOV	{"phone": "+70686956089"}
0005433343762	AB5F6C	4392 644494	INESSA PETROVA	{"email": "i-petrova_03081985@postgrespro.ru", "phone": "+70352225023"}
0005433343763	CF81D3	8019 827927	VALENTINA ERMAKOVA	{"phone": "+70304174724"}
0005433343764	708C7C	8529 320964	GENNADIY ZAKHAROV	{"email": "g_zakharov.1982@postgrespro.ru", "phone": "+70414587043"}
0005433343765	7D86ED	6252 608695	ANASTASIYA GAVRILOVA	{"email": "gavrilova-a-1961@postgrespro.ru", "phone": "+70194241441"}
0005433343766	FA09AB	6314 914991	STANISLAV KRASNOV	{"phone": "+70109483357"}
0005433343767	6DAB17	5362 899937	NIKOLAY GAVRILOV	{"phone": "+70467583925"}
0005433343768	6DAB17	3694 811276	YURIY MOROZOV	{"phone": "+70809345304"}
0005433343769	6DAB17	1206 740633	MIKHAIL ISAEV	{"phone": "+70105408551"}
0005433343770	7453A6	5529 611519	ALEKSANDR EGOROV	{"phone": "+70073754998"}
0005433343771	029D1A	8834 435875	TAMARA KUZNECOVA	{"phone": "+70060941865"}
0005433343772	5FDD31	2109 275259	ANDREY SMIRNOV	{"phone": "+70156904907"}
0005433343773	A99B8C	7086 910887	VIKTOR FILIPPOV	{"phone": "+70355703687"}
0005433343774	DAC79A	8530 907403	DMITRIY ANTONOV	{"email": "antonov.d_20051970@postgrespro.ru", "phone": "+70004817775"}
0005433343775	736A47	1274 072430	TATYANA FEDOROVA	{"email": "fedorovat-04031976@postgrespro.ru", "phone": "+70735307331"}
0005433343776	736A47	6092 385998	MARINA KOVALEVA	{"phone": "+70533287178"}
0005433343777	BB2C06	1903 489880	SVETLANA KARPOVA	{"phone": "+70172554808"}
0005433343778	3DA0D5	0826 441795	ALEKSANDR MAKSIMOV	{"email": "maksimova051972@postgrespro.ru", "phone": "+70646478417"}
0005433343779	7ACAE6	6418 768144	ELENA VOROBEVA	{"email": "e_vorobeva.23071972@postgrespro.ru", "phone": "+70570485447"}
0005433343780	C8CF84	5629 772843	ALENA BORISOVA	{"phone": "+70719996915"}
0005433343781	C8CF84	8976 803891	OLEG MARTYNOV	{"email": "o-martynov1971@postgrespro.ru", "phone": "+70416957053"}
0005433343782	E877EB	0780 472900	EVGENIYA KOROLEVA	{"phone": "+70478910299"}
0005433343783	4C0FE4	2390 490728	NATALYA PETROVA	{"phone": "+70475583721"}
0005433343784	4C0FE4	8823 071237	LARISA RODIONOVA	{"phone": "+70815359280"}
0005433343785	16F326	3387 998377	IVAN MAKAROV	{"phone": "+70544956635"}
0005433343786	16F326	1650 688788	IRINA NIKITINA	{"email": "nikitina_i-1979@postgrespro.ru", "phone": "+70719102805"}
0005433343787	1267AE	1708 347838	EVGENIYA VOLKOVA	{"email": "evgeniyavolkova_1972@postgrespro.ru", "phone": "+70692412294"}
0005433343788	1267AE	7318 932953	IRINA NIKOLAEVA	{"phone": "+70763685158"}
0005433343789	43EA4C	0812 449960	DMITRIY DAVYDOV	{"phone": "+70219332424"}
0005433343790	7E8C38	4421 275107	INGA MALYSHEVA	{"email": "inga.malysheva_1983@postgrespro.ru", "phone": "+70381733097"}
0005433343791	7E8C38	3527 930106	VALENTINA FROLOVA	{"phone": "+70552816583"}
0005433343792	85E118	9010 588287	ANATOLIY MAKAROV	{"email": "makarova-1968@postgrespro.ru", "phone": "+70097648094"}
0005433343793	E2B922	3783 697265	ANDREY ZAKHAROV	{"phone": "+70412850064"}
0005433343794	E2B922	2464 093231	IGOR MEDVEDEV	{"email": "igor-medvedev_1974@postgrespro.ru", "phone": "+70321906296"}
0005433343795	E2B922	5019 736215	IVAN BARANOV	{"phone": "+70452475346"}
0005433343796	B9855C	6260 444792	ANATOLIY MAKSIMOV	{"email": "a_maksimov-091977@postgrespro.ru", "phone": "+70255484969"}
0005433343797	B9855C	3216 427060	EKATERINA MAKAROVA	{"email": "e_makarova-15081982@postgrespro.ru", "phone": "+70531645834"}
0005433343798	0D9379	0556 912004	ANATOLIY SOROKIN	{"email": "anatoliysorokin_1981@postgrespro.ru", "phone": "+70286515323"}
0005433343799	13F711	2601 164275	LYUDMILA EGOROVA	{"phone": "+70578741963"}
0005433343800	13F711	8618 808394	VALENTINA DMITRIEVA	{"email": "v_dmitrieva_20081968@postgrespro.ru", "phone": "+70307413211"}
0005433343801	ABA596	7663 522517	NATALYA OSIPOVA	{"phone": "+70114552857"}
0005433343802	C28CD0	6575 492244	VASILIY KAZAKOV	{"email": "vasiliy-kazakov_1987@postgrespro.ru", "phone": "+70757273088"}
0005433343803	C28CD0	3520 282673	TATYANA SOLOVEVA	{"phone": "+70824260370"}
0005433343804	54ED30	3366 649408	ALEKSANDR ISAEV	{"phone": "+70652332125"}
0005433343805	9EF035	4121 914950	LYUBOV MAKAROVA	{"email": "makarova_lyubov.011975@postgrespro.ru", "phone": "+70818164212"}
0005433343806	9EF035	6289 473489	RAISA SERGEEVA	{"email": "sergeeva_raisa_1974@postgrespro.ru", "phone": "+70309918490"}
0005433343807	8D45BC	3091 816463	ANDREY DMITRIEV	{"email": "dmitriev_andrey_011977@postgrespro.ru", "phone": "+70679976958"}
0005433343808	8ECBB9	3693 092244	ALEKSEY SOROKIN	{"email": "sorokin-aleksey071977@postgrespro.ru", "phone": "+70283606422"}
0005433343809	047A33	9489 943064	ELENA KOMAROVA	{"email": "komarova_e_1988@postgrespro.ru", "phone": "+70937982496"}
0005433343810	BABD95	7958 356801	YULIYA KRASNOVA	{"phone": "+70986627479"}
0005433343811	00C252	0973 918465	NATALYA GUSEVA	{"email": "gusevanatalya.111973@postgrespro.ru", "phone": "+70797272629"}
0005433343812	F8D1F5	2358 260791	TAISIYA YAKOVLEVA	{"phone": "+70786590452"}
0005433343813	05940A	6894 807822	YURIY NIKITIN	{"email": "yuriy_nikitin.051973@postgrespro.ru", "phone": "+70459160414"}
0005433343814	05940A	8754 355082	LYUDMILA SAVELEVA	{"phone": "+70175730553"}
0005433343815	8CE232	6446 061242	GALINA KULIKOVA	{"email": "g-kulikova-17031977@postgrespro.ru", "phone": "+70353003314"}
0005433343816	88FC45	4938 839087	SERGEY GERASIMOV	{"phone": "+70459289909"}
0005433343817	A0FB6D	5064 031720	SVETLANA KISELEVA	{"phone": "+70711124402"}
0005433343818	8C00F7	9704 492554	LYUDMILA ILINA	{"email": "ilina_lyudmila25091978@postgrespro.ru", "phone": "+70807970990"}
0005433343819	1643F8	5450 181923	MIKHAIL ZAYCEV	{"email": "zaycevmikhail1970@postgrespro.ru", "phone": "+70122990853"}
0005433343820	4B54F5	0359 103429	NIKOLAY ANDREEV	{"email": "n-andreev_1966@postgrespro.ru", "phone": "+70214060742"}
0005433343821	FA2BBB	9468 679725	SERGEY TIMOFEEV	{"email": "timofeevs16101969@postgrespro.ru", "phone": "+70788992212"}
0005433343822	FA2BBB	6431 466265	EVGENIY VOROBEV	{"email": "vorobev_e.25021974@postgrespro.ru", "phone": "+70437559755"}
0005433343823	FA2BBB	2969 153192	VALENTINA KULIKOVA	{"phone": "+70205459027"}
0005433343824	93EE95	7842 445802	VITALIY KISELEV	{"email": "v-kiselev.031972@postgrespro.ru", "phone": "+70750448293"}
0005433343825	4FBEBA	9234 940335	ELENA TIKHONOVA	{"phone": "+70760411458"}
0005433343826	4FBEBA	8223 405067	GALINA GERASIMOVA	{"email": "ggerasimova-031968@postgrespro.ru", "phone": "+70579447277"}
0005433343827	EC22A9	2271 389103	SERGEY TIKHONOV	{"phone": "+70988991348"}
0005433343828	D8B01B	2518 050924	ARTUR FROLOV	{"phone": "+70754179514"}
0005433343829	84CC3B	3908 581251	ANDREY MIKHAYLOV	{"phone": "+70731612843"}
0005433343830	F353CE	4620 029731	ELENA OVCHINNIKOVA	{"email": "ovchinnikova-elena101967@postgrespro.ru", "phone": "+70361049100"}
0005433343831	F353CE	2269 221908	OLGA PAVLOVA	{"email": "pavlova_olga_21021975@postgrespro.ru", "phone": "+70302490987"}
0005433343832	4E9C9C	7228 165324	GEORGIY FEDOROV	{"email": "g-fedorov-1971@postgrespro.ru", "phone": "+70704414052"}
0005433343833	4E9C9C	5023 092762	ELENA SCHERBAKOVA	{"email": "scherbakova.elena011969@postgrespro.ru", "phone": "+70862356396"}
0005433343834	20F027	3999 194501	ANDREY IVANOV	{"phone": "+70472885653"}
0005433343835	F5EEFE	2305 751268	TATYANA EGOROVA	{"phone": "+70744666160"}
0005433343836	B9BB47	6176 501834	ALEKSANDR MOROZOV	{"email": "a.morozov-121974@postgrespro.ru", "phone": "+70082936245"}
0005433343837	B7E4F0	5415 178606	NATALYA SCHERBAKOVA	{"email": "n_scherbakova_1981@postgrespro.ru", "phone": "+70786799042"}
0005433343838	B7E4F0	3655 616898	POLINA OVCHINNIKOVA	{"phone": "+70992305257"}
0005433343839	4ED4D7	9895 562337	YULIYA POPOVA	{"phone": "+70237921135"}
0005433343840	2B1032	4466 059857	NATALYA NAZAROVA	{"email": "natalya_nazarova16121973@postgrespro.ru", "phone": "+70931536787"}
0005433343841	4A2A1D	3725 872183	PAVEL FEDOTOV	{"phone": "+70682118485"}
0005433343842	4A2A1D	0130 268974	VERA STEPANOVA	{"phone": "+70985357973"}
0005433343843	369FEA	8415 068729	TATYANA ZHUKOVA	{"email": "t-zhukova24081975@postgrespro.ru", "phone": "+70221043157"}
0005433343844	369FEA	9181 836911	LIDIYA MALYSHEVA	{"email": "l-malysheva10061957@postgrespro.ru", "phone": "+70174551198"}
0005433343845	84CCA2	5396 991069	EVGENIYA OSIPOVA	{"email": "eosipova-1988@postgrespro.ru", "phone": "+70470256214"}
0005433343846	84CCA2	7784 714516	LYUBOV AFANASEVA	{"phone": "+70795322162"}
0005433343847	DE7E97	1840 981959	ELENA KUZNECOVA	{"phone": "+70608522348"}
0005433343848	2FB6F8	3627 748334	RAISA ILINA	{"phone": "+70647164215"}
0005433343849	3F55A1	9360 856386	ANATOLIY OSIPOV	{"phone": "+70071886938"}
0005433343850	3F55A1	8643 196021	ANNA KOMAROVA	{"email": "anna_komarova1979@postgrespro.ru", "phone": "+70011321911"}
0005433343851	C9F666	9999 806521	ALEKSANDRA ALEKSEEVA	{"phone": "+70400157510"}
0005433343852	4610C1	2225 393050	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov_091977@postgrespro.ru", "phone": "+70818053322"}
0005433343853	62EB7B	4008 603981	KRISTINA MATVEEVA	{"email": "kristinamatveeva-20091980@postgrespro.ru", "phone": "+70419490822"}
0005433343854	62EB7B	1293 628812	FARIDA AFANASEVA	{"email": "faridaafanaseva-051970@postgrespro.ru", "phone": "+70408345799"}
0005433343855	CFDFCB	1087 926770	OLGA GRISHINA	{"phone": "+70522852795"}
0005433343856	AA3D2B	0761 479146	EVGENIY BORISOV	{"email": "e_borisov27061978@postgrespro.ru", "phone": "+70448516257"}
0005433343857	FCFB5D	7211 557198	MARIYA BORISOVA	{"phone": "+70330310534"}
0005433343858	7E2169	0490 420726	DANIIL MATVEEV	{"email": "d-matveev-17061970@postgrespro.ru", "phone": "+70025840934"}
0005433343859	C005A1	1898 683124	VALENTINA VLASOVA	{"email": "valentina-vlasova_021962@postgrespro.ru", "phone": "+70802907440"}
0005433343860	A9AE8D	8012 022680	DMITRIY KISELEV	{"email": "kiselev-dmitriy-1971@postgrespro.ru", "phone": "+70976361549"}
0005433343861	A9AE8D	6739 191878	YURIY TARASOV	{"email": "tarasov.yuriy.1978@postgrespro.ru", "phone": "+70002679958"}
0005433343862	49219D	8745 411429	MAKSIM VASILEV	{"phone": "+70351502052"}
0005433343863	DDFE68	2685 708388	DANIIL EGOROV	{"email": "daniil-egorov_1980@postgrespro.ru", "phone": "+70328170540"}
0005433343864	DDFE68	0757 682724	DMITRIY SAVELEV	{"email": "savelev-d_121980@postgrespro.ru", "phone": "+70967303521"}
0005433343865	B7F095	4753 741995	VALERIY KUZNECOV	{"phone": "+70351909447"}
0005433343866	6A90C8	3477 680695	YULIYA ISAEVA	{"email": "isaeva.yuliya.031966@postgrespro.ru", "phone": "+70991097312"}
0005433343867	1E30C0	4552 643024	ANASTASIYA FADEEVA	{"phone": "+70700464505"}
0005433343868	1E30C0	1558 353845	OLGA EFIMOVA	{"phone": "+70326289577"}
0005433343869	1E30C0	7504 725673	NATALYA KALININA	{"email": "n_kalinina.1979@postgrespro.ru", "phone": "+70300509626"}
0005433343870	1B6003	6902 498211	GALINA ZAKHAROVA	{"email": "galina.zakharova011967@postgrespro.ru", "phone": "+70417906134"}
0005433343871	A91B52	4784 037085	SERGEY NIKOLAEV	{"email": "nikolaev-sergey.081972@postgrespro.ru", "phone": "+70905994730"}
0005433343872	D8E326	1325 163401	IVAN TIKHONOV	{"phone": "+70478381818"}
0005433343873	BB999E	2558 929880	ALEKSEY PAVLOV	{"email": "apavlov.16071971@postgrespro.ru", "phone": "+70075244877"}
0005433343874	B50644	1087 340002	ELENA FEDOROVA	{"email": "fedorova_e-031967@postgrespro.ru", "phone": "+70502646827"}
0005433343875	E1FBF2	8295 507496	SERGEY ZAKHAROV	{"phone": "+70662465285"}
0005433343876	E1FBF2	9573 746772	FEDOR KUZNECOV	{"phone": "+70663002828"}
0005433343877	6648F5	2649 525497	SVETLANA SOROKINA	{"email": "s_sorokina.1972@postgrespro.ru", "phone": "+70889740105"}
0005433343878	5D0EDD	2307 922176	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr031968@postgrespro.ru", "phone": "+70212611475"}
0005433343879	323BCF	4095 437507	MAKSIM DENISOV	{"phone": "+70172341051"}
0005433343880	323BCF	3809 374401	IVAN SOLOVEV	{"email": "solovev_ivan.19061971@postgrespro.ru", "phone": "+70385472360"}
0005433343881	323BCF	5175 017501	VALENTINA KOZLOVA	{"phone": "+70435907377"}
0005433343882	4B19DB	9335 037503	ALEKSANDR SOROKIN	{"email": "sorokin_a1976@postgrespro.ru", "phone": "+70995672669"}
0005433343883	2F62D5	5455 533706	ANASTASIYA NIKOLAEVA	{"phone": "+70745178988"}
0005433343884	D87362	8016 820944	ROMAN MAKAROV	{"phone": "+70787510662"}
0005433343885	D87362	9936 351137	DARYA MAKAROVA	{"email": "daryamakarova-011977@postgrespro.ru", "phone": "+70939801571"}
0005433343886	C9D768	6999 735015	EVGENIY FILIPPOV	{"email": "filippov-evgeniy-02051973@postgrespro.ru", "phone": "+70948046243"}
0005433343887	EE4A33	8871 459259	MIKHAIL POPOV	{"phone": "+70463916153"}
0005433343888	68B62F	8088 221798	ILYAS CHERNOV	{"email": "chernov-i-11071970@postgrespro.ru", "phone": "+70435037599"}
0005433343889	4F30B4	4894 338667	VLADIMIR TIMOFEEV	{"phone": "+70433419844"}
0005433343890	4F30B4	9349 949996	GALINA PETROVA	{"email": "galinapetrova.23061984@postgrespro.ru", "phone": "+70462356032"}
0005433343891	BA5CC2	8016 931537	ALEKSANDR KISELEV	{"phone": "+70153890675"}
0005433343892	F59968	9276 568575	LIDIYA BORISOVA	{"phone": "+70302014824"}
0005433343893	F4C188	7471 618513	NATALYA IVANOVA	{"email": "ivanova_natalya-1980@postgrespro.ru", "phone": "+70722107071"}
0005433343894	F4C188	8368 679331	DIANA OSIPOVA	{"email": "diana_osipova-061961@postgrespro.ru", "phone": "+70189108345"}
0005433343895	1CA55D	2861 323409	IGOR ALEKSANDROV	{"phone": "+70570477413"}
0005433343896	2F18E5	4190 376880	TATYANA FOMINA	{"phone": "+70900214648"}
0005433343897	2F18E5	2187 416683	ANDREY NIKOLAEV	{"phone": "+70869939300"}
0005433343898	F60401	9043 284895	DMITRIY ROMANOV	{"phone": "+70618838360"}
0005433343899	3D097C	5168 846289	PAVEL SHEVCHENKO	{"email": "shevchenko_p.031982@postgrespro.ru", "phone": "+70636969926"}
0005433343900	80CAA1	0235 705209	ALESYA TIKHONOVA	{"email": "tikhonova_a_031972@postgrespro.ru", "phone": "+70826014666"}
0005433343901	1E3A75	0423 523281	VLADIMIR SAVELEV	{"phone": "+70492747609"}
0005433343902	EBD51E	4102 932371	ILYA TARASOV	{"email": "tarasov.ilya_20081972@postgrespro.ru", "phone": "+70524134389"}
0005433343903	0BAA60	9972 863304	VASILIY KUZNECOV	{"email": "kuznecov_vasiliy.1973@postgrespro.ru", "phone": "+70345494081"}
0005433343904	600043	9571 083905	IRINA KUZNECOVA	{"phone": "+70128807953"}
0005433343905	22214F	3096 231634	YULIYA SIDOROVA	{"email": "yuliya-sidorova-01121966@postgrespro.ru", "phone": "+70388900852"}
0005433343906	3AFF78	7144 273425	LIDIYA NESTEROVA	{"phone": "+70075442060"}
0005433343907	3AFF78	8335 235458	GALINA DAVYDOVA	{"email": "davydovag_031967@postgrespro.ru", "phone": "+70890916344"}
0005433343908	3AFF78	2538 271346	LARISA DANILOVA	{"phone": "+70865027842"}
0005433343909	215C98	0239 619825	POLINA NOVIKOVA	{"phone": "+70548073469"}
0005433343910	215C98	3705 336086	OLEG NIKOLAEV	{"email": "nikolaev.o_011969@postgrespro.ru", "phone": "+70987272553"}
0005433343911	0C1DE6	1344 765739	SERGEY KOZLOV	{"phone": "+70402868220"}
0005433343912	0C1DE6	4460 182007	NATALYA KUZNECOVA	{"phone": "+70662903673"}
0005433343913	74B6E2	3549 161434	LYUDMILA ANTONOVA	{"email": "lyudmila_antonova_03091958@postgrespro.ru", "phone": "+70787891987"}
0005433343914	74B6E2	5249 577905	SERGEY KISELEV	{"phone": "+70336323008"}
0005433343915	7A7395	5889 697516	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr061973@postgrespro.ru", "phone": "+70330984675"}
0005433343916	E719F6	3699 919248	OLGA POPOVA	{"phone": "+70015889912"}
0005433343917	D7A502	0773 213617	MARGARITA EGOROVA	{"phone": "+70505645023"}
0005433343918	A6DE37	7273 681711	STANISLAV GAVRILOV	{"email": "gavrilov-s-121980@postgrespro.ru", "phone": "+70231801964"}
0005433343919	7C229C	9621 572470	NATALYA BORISOVA	{"phone": "+70473867196"}
0005433343920	BBFCAE	8465 094578	OLGA ORLOVA	{"phone": "+70523761918"}
0005433343921	A21F63	5811 782879	SERGEY KUDRYASHOV	{"phone": "+70271901771"}
0005433344035	4D8725	9301 814551	LEV VASILEV	{"phone": "+70130012018"}
0005433343922	DABB8F	0640 904419	NINA MIRONOVA	{"email": "nina-mironova-1969@postgrespro.ru", "phone": "+70414165472"}
0005433343923	DABB8F	2057 913368	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov121978@postgrespro.ru", "phone": "+70905782149"}
0005433343924	883604	9749 069736	SERGEY NOVIKOV	{"phone": "+70002905296"}
0005433343925	C8FAB2	9474 224542	ALEKSANDRA SERGEEVA	{"phone": "+70647334747"}
0005433343926	C8FAB2	5391 724215	ANNA LOGINOVA	{"email": "loginova_a_101980@postgrespro.ru", "phone": "+70099329331"}
0005433343927	3D484B	3858 501834	ALEKSANDR ZHUKOV	{"email": "azhukov.05021974@postgrespro.ru", "phone": "+70840957236"}
0005433343928	3D484B	8393 539631	KRISTINA POTAPOVA	{"email": "potapovak1982@postgrespro.ru", "phone": "+70256780565"}
0005433343929	8CE6E0	6509 310589	MIKHAIL NOVIKOV	{"email": "mikhail.novikov.1980@postgrespro.ru", "phone": "+70922953397"}
0005433343930	8CE6E0	2639 190642	LYUBOV ZAYCEVA	{"phone": "+70355948842"}
0005433343931	A04CD3	5239 647152	TATYANA OVCHINNIKOVA	{"phone": "+70097629742"}
0005433343932	485832	0402 640582	DMITRIY KUZMIN	{"email": "dmitriy.kuzmin1978@postgrespro.ru", "phone": "+70428629746"}
0005433343933	2D79ED	5638 501813	TATYANA GAVRILOVA	{"phone": "+70020312468"}
0005433343934	3294F7	5955 226588	NADEZHDA IVANOVA	{"phone": "+70534321355"}
0005433343935	7014B2	8272 605713	MAKSIM NIKOLAEV	{"phone": "+70375829523"}
0005433343936	49ECF7	5513 390542	EKATERINA YUDINA	{"phone": "+70400450582"}
0005433343937	49ECF7	0026 415229	ANATOLIY SERGEEV	{"phone": "+70819250009"}
0005433343938	6F62AA	3473 217485	ELIZAVETA MOROZOVA	{"email": "morozova.elizaveta_081964@postgrespro.ru", "phone": "+70809997736"}
0005433343939	17E422	5036 098730	YULIYA POLYAKOVA	{"phone": "+70522119022"}
0005433343940	68A838	3282 542804	MARIYA KUZNECOVA	{"phone": "+70329986415"}
0005433343941	68A838	2100 160154	OLEG EGOROV	{"email": "egorov.oleg-1975@postgrespro.ru", "phone": "+70159804593"}
0005433343942	AF024F	8126 244395	TAMARA ZHURAVLEVA	{"email": "zhuravleva.t.051981@postgrespro.ru", "phone": "+70287324687"}
0005433343943	89F2AA	8285 139821	OLGA STEPANOVA	{"phone": "+70460585316"}
0005433343944	89F2AA	7216 577557	MIKHAIL DENISOV	{"phone": "+70346389930"}
0005433343945	5BE61C	1839 378582	EKATERINA BARANOVA	{"phone": "+70731030168"}
0005433343946	5BE61C	3452 053179	SERGEY GORBUNOV	{"phone": "+70222947749"}
0005433343947	5BE61C	5327 774272	VADIM PETROV	{"phone": "+70054727638"}
0005433343948	AADE15	8386 825987	GALINA MOROZOVA	{"phone": "+70643513755"}
0005433343949	9E7109	2839 800107	NADEZHDA IVANOVA	{"phone": "+70456662184"}
0005433343950	9E7109	9868 579466	MARINA YAKOVLEVA	{"phone": "+70043876965"}
0005433343951	435B90	9457 727915	VADIM BONDARENKO	{"phone": "+70999645852"}
0005433343952	435B90	1006 537525	TATYANA VOROBEVA	{"phone": "+70156772853"}
0005433343953	435B90	0756 487631	SERGEY SOLOVEV	{"phone": "+70459854391"}
0005433343954	3CCB4C	8600 316428	NIKOLAY VLASOV	{"email": "nikolay_vlasov.22031977@postgrespro.ru", "phone": "+70466188410"}
0005433343955	3CCB4C	8473 950317	LIDIYA KOZLOVA	{"phone": "+70077447134"}
0005433343956	6D9C7C	0284 431244	ALEKSANDR PETROV	{"email": "petrov.aleksandr_18031969@postgrespro.ru", "phone": "+70925148634"}
0005433343957	6F5FA1	1422 631410	MAKSIM PETROV	{"email": "petrov_maksim.081981@postgrespro.ru", "phone": "+70385690957"}
0005433343958	6F5FA1	1052 335582	ALEKSANDR SMIRNOV	{"phone": "+70149846031"}
0005433344079	7245E6	5423 723305	YURIY IVANOV	{"phone": "+70695721834"}
0005433343959	BA6A9B	4272 607038	ALEKSANDR SOLOVEV	{"email": "a-solovev-1971@postgrespro.ru", "phone": "+70038270139"}
0005433343960	BA6A9B	1443 421218	ALIYA IVANOVA	{"email": "a_ivanova.26071980@postgrespro.ru", "phone": "+70437173119"}
0005433343961	BA6A9B	9444 471764	GRIGORIY FILIPPOV	{"email": "filippov.g_1983@postgrespro.ru", "phone": "+70505086685"}
0005433343962	B0306F	5967 576978	LARISA MAKAROVA	{"phone": "+70436665989"}
0005433343963	B0306F	9787 062247	ARTEM SMIRNOV	{"email": "smirnov.artem-16111964@postgrespro.ru", "phone": "+70382870499"}
0005433343964	DEEE0B	0634 923322	NATALYA KARPOVA	{"phone": "+70485247439"}
0005433343965	DEEE0B	2034 669094	VIKTOR IVANOV	{"email": "ivanovv.071991@postgrespro.ru", "phone": "+70981634467"}
0005433343966	DEEE0B	9559 141788	VIKTORIYA NESTEROVA	{"phone": "+70916292553"}
0005433343967	F005D8	6875 328891	OKSANA NAUMOVA	{"phone": "+70396567078"}
0005433343968	C1F091	6356 492047	OLGA IVANOVA	{"email": "ivanovao.27031963@postgrespro.ru", "phone": "+70873403299"}
0005433343969	C1F091	0853 668913	EDUARD PETROV	{"phone": "+70625527316"}
0005433343970	1FA910	7125 939971	ELENA GUSEVA	{"email": "guseva-elena15021967@postgrespro.ru", "phone": "+70615673083"}
0005433343971	D30153	4977 375919	ALEKSANDR SEMENOV	{"phone": "+70860084816"}
0005433343972	26183A	7386 866225	YURIY SMIRNOV	{"email": "smirnov-y_1973@postgrespro.ru", "phone": "+70426966993"}
0005433343973	26183A	8166 528775	LYUBOV MAKAROVA	{"phone": "+70543163353"}
0005433343974	913FC0	7732 930981	ARINA ANDREEVA	{"phone": "+70294516961"}
0005433343975	D59253	6955 414329	ROMAN AFANASEV	{"email": "afanasev-r-20101961@postgrespro.ru", "phone": "+70223179317"}
0005433343976	2BE5B9	4157 507307	SERGEY BONDARENKO	{"phone": "+70055864512"}
0005433343977	C9269F	2633 310134	ALEKSEY TIMOFEEV	{"email": "a.timofeev.10061978@postgrespro.ru", "phone": "+70999177527"}
0005433343978	8FE333	6633 157792	ALEKSANDR SEMENOV	{"phone": "+70173966274"}
0005433343979	8FE333	1430 967431	ILYA VOLKOV	{"email": "ilya-volkov1968@postgrespro.ru", "phone": "+70165439231"}
0005433343980	A3EC82	8821 693835	VIKTOR PAVLOV	{"email": "viktor.pavlov.19021976@postgrespro.ru", "phone": "+70925741214"}
0005433343981	A3EC82	8302 104709	TATYANA VLASOVA	{"phone": "+70961183998"}
0005433343982	7E468E	9816 082041	OLGA MASLOVA	{"email": "maslova_o-1974@postgrespro.ru", "phone": "+70506520259"}
0005433343983	B9237F	7755 801702	ANDREY PAVLOV	{"email": "pavlovandrey09031974@postgrespro.ru", "phone": "+70688618131"}
0005433343984	007232	3759 287825	RAVILYA FROLOVA	{"email": "frolova_ravilya1973@postgrespro.ru", "phone": "+70305156035"}
0005433343985	007232	0123 670843	ANNA TIMOFEEVA	{"email": "a-timofeeva_12081972@postgrespro.ru", "phone": "+70892030945"}
0005433343986	3A57FC	6675 590156	LIDIYA KONOVALOVA	{"email": "lidiya_konovalova-25071980@postgrespro.ru", "phone": "+70996969362"}
0005433343987	A31D15	7870 336879	ANASTASIYA POLYAKOVA	{"phone": "+70334335807"}
0005433343988	F26D26	1281 553844	DANIL SCHERBAKOV	{"email": "scherbakov.danil-021975@postgrespro.ru", "phone": "+70076482321"}
0005433343989	F26D26	1666 689788	ALEKSANDR KUZNECOV	{"phone": "+70562396029"}
0005433343990	F26D26	5879 840108	ALBINA KOROLEVA	{"email": "a-koroleva.1967@postgrespro.ru", "phone": "+70234079563"}
0005433343991	0CCFFB	2602 105363	VALENTINA FILIPPOVA	{"phone": "+70150159015"}
0005433343992	77BCF4	7253 736571	ELENA SERGEEVA	{"phone": "+70379796615"}
0005433343993	77BCF4	7376 440098	MARIYA IVANOVA	{"phone": "+70966998820"}
0005433343994	EF0ED4	9364 382627	EVGENIY ANDREEV	{"email": "andreev.e_011979@postgrespro.ru", "phone": "+70715198802"}
0005433343995	EF0ED4	4159 144540	SERGEY ZAKHAROV	{"email": "s-zakharov-08121975@postgrespro.ru", "phone": "+70178733786"}
0005433343996	C14012	4502 210728	BORIS KARPOV	{"email": "boris-karpov1968@postgrespro.ru", "phone": "+70460351504"}
0005433343997	FBA0E2	4802 986549	OLGA FOMINA	{"phone": "+70142384136"}
0005433343998	235103	3603 604581	ALEKSANDRA EFREMOVA	{"phone": "+70656291398"}
0005433343999	235103	1219 416289	SERGEY GUSEV	{"phone": "+70100670199"}
0005433344000	3E430E	4762 346325	SERGEY VOROBEV	{"phone": "+70869859085"}
0005433344001	3DAB8A	3395 326509	DENIS ANDREEV	{"phone": "+70596113643"}
0005433344002	9D0DF2	6131 356822	ALEKSEY SAVELEV	{"email": "savelevaleksey.1971@postgrespro.ru", "phone": "+70988143776"}
0005433344003	9D0DF2	6500 777883	EVGENIYA CHERNOVA	{"email": "e_chernova-1982@postgrespro.ru", "phone": "+70804277570"}
0005433344004	9D0DF2	6418 602575	ARTEM ZAKHAROV	{"email": "artemzakharov.041972@postgrespro.ru", "phone": "+70982316154"}
0005433344005	608BD6	0827 862983	OLEG BORISOV	{"phone": "+70211370441"}
0005433344006	608BD6	1075 787019	KARINA IVANOVA	{"email": "ivanova-k-15121972@postgrespro.ru", "phone": "+70993809908"}
0005433344007	2A3F0A	3288 547432	ELENA PAVLOVA	{"email": "pavlova_elena_091971@postgrespro.ru", "phone": "+70901527273"}
0005433344008	2A3F0A	2605 951416	SERGEY PETROV	{"email": "s-petrov061973@postgrespro.ru", "phone": "+70848192392"}
0005433344009	2A3F0A	2727 256799	NATALYA POLYAKOVA	{"phone": "+70926792912"}
0005433344010	2A3F0A	1351 481887	VALERIY KRASNOV	{"phone": "+70619058470"}
0005433344011	409B75	9120 627112	NATALIYA KOLESNIKOVA	{"email": "kolesnikova_nataliya1969@postgrespro.ru", "phone": "+70165388311"}
0005433344012	409B75	6275 427713	ALEKSANDR KONOVALOV	{"email": "konovalov_aleksandr-1988@postgrespro.ru", "phone": "+70129655177"}
0005433344013	EC4C24	5088 928675	NIKOLAY IVANOV	{"phone": "+70018244179"}
0005433344014	12CB0E	7660 649808	ELENA ZHUKOVA	{"email": "e.zhukova.031972@postgrespro.ru", "phone": "+70766333937"}
0005433344015	D91A32	2598 191407	NIKITA NAZAROV	{"phone": "+70335949376"}
0005433344016	2CD62A	1736 678375	VALENTINA KUDRYASHOVA	{"phone": "+70535479975"}
0005433344017	2CD62A	8684 252194	VIKTORIYA AKIMOVA	{"email": "akimova.v.111970@postgrespro.ru", "phone": "+70672260014"}
0005433344018	8281FB	7307 702248	NINA IVANOVA	{"email": "ivanova-n.16021969@postgrespro.ru", "phone": "+70565476175"}
0005433344019	6CCCD7	6987 620275	VYACHESLAV NAZAROV	{"email": "v-nazarov02021970@postgrespro.ru", "phone": "+70741723495"}
0005433344020	486185	7333 784905	NIKOLAY MAKAROV	{"email": "n-makarov091972@postgrespro.ru", "phone": "+70029434287"}
0005433344021	9A74CF	6105 772217	LYUDMILA KUZNECOVA	{"phone": "+70706731285"}
0005433344022	9A74CF	7493 675392	VALENTINA SOROKINA	{"email": "valentina-sorokina1961@postgrespro.ru", "phone": "+70726655623"}
0005433344023	CB8057	2695 240174	LYUBOV KUZNECOVA	{"email": "kuznecova_l101975@postgrespro.ru", "phone": "+70772192788"}
0005433344024	C0EAAD	0010 066402	ROMAN FILIPPOV	{"email": "filippov.r1977@postgrespro.ru", "phone": "+70319100105"}
0005433344025	C0EAAD	0989 627274	DARYA MAKAROVA	{"email": "darya_makarova1969@postgrespro.ru", "phone": "+70350270101"}
0005433344026	43F084	2963 584681	IRINA VOROBEVA	{"phone": "+70589714584"}
0005433344027	43F084	1993 930978	ALEKSEY KUZNECOV	{"phone": "+70051261309"}
0005433344028	885760	2652 586050	EKATERINA POPOVA	{"email": "e-popova-1986@postgrespro.ru", "phone": "+70947068321"}
0005433344029	6DE462	2035 439315	VERA KALININA	{"email": "kalinina-vera-25101974@postgrespro.ru", "phone": "+70910132718"}
0005433344030	6DE462	7750 633779	NINA MALYSHEVA	{"phone": "+70364005736"}
0005433344031	1CFE03	1102 241225	ALEKSEY KUZNECOV	{"phone": "+70239706888"}
0005433344032	CF36D7	0896 887749	LYUBOV SOKOLOVA	{"phone": "+70024963956"}
0005433344033	CF36D7	0949 262579	TATYANA ROMANOVA	{"email": "tatyana.romanova-021973@postgrespro.ru", "phone": "+70483313088"}
0005433344034	4D8725	6279 141044	GALINA MEDVEDEVA	{"email": "medvedeva-galina_02041968@postgrespro.ru", "phone": "+70549121396"}
0005433344036	4D8725	1404 039096	ELIZAVETA TARASOVA	{"phone": "+70890881723"}
0005433344037	34BA06	4981 752709	ELENA NOVIKOVA	{"email": "novikovaelena-101972@postgrespro.ru", "phone": "+70716608881"}
0005433344038	F2DF5F	3741 663148	ARTEM SAVELEV	{"email": "artem.savelev101971@postgrespro.ru", "phone": "+70156019611"}
0005433344039	8CE066	9026 422538	OLGA SOLOVEVA	{"phone": "+70925372998"}
0005433344040	61E821	1584 785560	OLGA TARASOVA	{"email": "o_tarasova-24011963@postgrespro.ru", "phone": "+70861240695"}
0005433344041	30B56A	0142 773597	FLYURA NIKITINA	{"email": "nikitina.flyura-1976@postgrespro.ru", "phone": "+70478200052"}
0005433344042	30B56A	5468 848431	ANNA GORBUNOVA	{"email": "a-gorbunova.12021971@postgrespro.ru", "phone": "+70693789346"}
0005433344043	8CCB98	3478 832579	NATALYA CHERNOVA	{"email": "n.chernova.051963@postgrespro.ru", "phone": "+70198229561"}
0005433344044	8CCB98	6346 583869	SERGEY ALEKSEEV	{"email": "salekseev-1967@postgrespro.ru", "phone": "+70690896541"}
0005433344045	C9A8A4	8301 911548	ANATOLIY KAZAKOV	{"email": "kazakov.anatoliy02111976@postgrespro.ru", "phone": "+70105721502"}
0005433344046	DC7728	1428 969725	MARGARITA KOVALEVA	{"phone": "+70460717870"}
0005433344047	84575B	4923 737294	ALEKSANDR BORISOV	{"email": "aborisov.111965@postgrespro.ru", "phone": "+70824804313"}
0005433344048	84575B	2796 762909	LILIYA ZAYCEVA	{"phone": "+70610756515"}
0005433344049	545DBA	5046 836866	LYUDMILA LAZAREVA	{"email": "llazareva-101984@postgrespro.ru", "phone": "+70110561059"}
0005433344050	545DBA	5107 289216	DIANA GUSEVA	{"email": "dguseva.15051965@postgrespro.ru", "phone": "+70704996012"}
0005433344051	520B93	9777 553465	VYACHESLAV SHEVCHENKO	{"email": "vyacheslavshevchenko_071973@postgrespro.ru", "phone": "+70588034891"}
0005433344052	520B93	9018 939012	VERONIKA KULIKOVA	{"email": "v.kulikova-1974@postgrespro.ru", "phone": "+70427806443"}
0005433344053	520B93	2937 077597	NINA MOROZOVA	{"email": "nina-morozova-1968@postgrespro.ru", "phone": "+70104418426"}
0005433344054	863531	5398 237411	OLGA SOKOLOVA	{"phone": "+70167470170"}
0005433344055	863531	1488 385710	IRINA NIKITINA	{"email": "nikitinai1966@postgrespro.ru", "phone": "+70649751900"}
0005433344056	863531	0836 878817	KSENIYA SOLOVEVA	{"phone": "+70275634440"}
0005433344057	E1834F	8456 338836	DMITRIY CHERNOV	{"email": "d-chernov10091976@postgrespro.ru", "phone": "+70842636917"}
0005433344058	E5F6B3	7382 126109	ALENA KUZNECOVA	{"phone": "+70020200119"}
0005433344059	BF1049	4880 185643	EKATERINA MAKAROVA	{"phone": "+70704593939"}
0005433344060	65488D	2410 997082	ALEKSEY SERGEEV	{"phone": "+70625972497"}
0005433344061	341843	1934 959314	MIKHAIL KARPOV	{"email": "karpov.m.1964@postgrespro.ru", "phone": "+70761921172"}
0005433344062	341843	7988 616368	DMITRIY SEMENOV	{"phone": "+70973598257"}
0005433344063	DA44C3	2870 976730	DMITRIY VOROBEV	{"email": "d_vorobev07091977@postgrespro.ru", "phone": "+70231125945"}
0005433344064	DA44C3	6076 298105	NATALIYA ERMAKOVA	{"phone": "+70622764897"}
0005433344065	23BDAD	1315 935102	ELIZAVETA MAKAROVA	{"phone": "+70295347524"}
0005433344066	8D6395	8853 573948	IRINA NAUMOVA	{"email": "naumova_irina_12081981@postgrespro.ru", "phone": "+70810134548"}
0005433344067	822E96	2004 063219	OLEG KUZNECOV	{"phone": "+70817152902"}
0005433344068	78578D	2511 604336	LYUDMILA SOROKINA	{"email": "sorokina.l_1976@postgrespro.ru", "phone": "+70458095302"}
0005433344069	78578D	6050 635379	LYUBOV ZHUKOVA	{"email": "zhukovalyubov_1967@postgrespro.ru", "phone": "+70702921905"}
0005433344070	65C1C6	0040 987739	NATALYA LAZAREVA	{"phone": "+70732765484"}
0005433344071	65C1C6	6108 520266	OLGA EFIMOVA	{"phone": "+70445279981"}
0005433344072	35D5FD	0109 622519	PAVEL EGOROV	{"email": "egorovpavel-091975@postgrespro.ru", "phone": "+70694633730"}
0005433344073	A29B83	7822 828108	VALENTINA FOMINA	{"email": "vfomina1967@postgrespro.ru", "phone": "+70308219571"}
0005433344074	309C45	7122 636641	MARIYA BELYAEVA	{"phone": "+70646018442"}
0005433344075	04A4B0	5005 401747	TATYANA BELOVA	{"email": "belova_t-1968@postgrespro.ru", "phone": "+70924741277"}
0005433344076	539A7D	8441 317514	NATALYA ILINA	{"phone": "+70135709667"}
0005433344077	71C156	0259 582475	PELAGEYA AKIMOVA	{"email": "akimovapelageya_26071966@postgrespro.ru", "phone": "+70105785930"}
0005433344078	60BBB6	0397 664899	NINA PETROVA	{"email": "petrova_nina-02041980@postgrespro.ru", "phone": "+70099139533"}
0005433344080	7245E6	9401 107537	EVGENIY GUSEV	{"phone": "+70790773632"}
0005433344081	24DE4B	6931 902952	ELENA VASILEVA	{"phone": "+70212406720"}
0005433344082	425417	2772 984601	ELENA BORISOVA	{"email": "elena.borisova_121959@postgrespro.ru", "phone": "+70445817036"}
0005433344083	79BF2B	4908 214086	IRINA VLASOVA	{"phone": "+70765203985"}
0005433344084	AF9CB5	5691 683075	DANIL ILIN	{"phone": "+70203338151"}
0005433344085	BA0A27	7160 560913	EVGENIY ZHUKOV	{"phone": "+70109835315"}
0005433344086	07ABA1	4946 332366	DANILA IVANOV	{"email": "d_ivanov.01111984@postgrespro.ru", "phone": "+70848451034"}
0005433344087	479366	2071 665860	VERA SERGEEVA	{"phone": "+70550917080"}
0005433344088	479366	3268 029282	ANDREY VOROBEV	{"phone": "+70051132627"}
0005433344089	479366	5273 712908	TATYANA KUZMINA	{"phone": "+70967165689"}
0005433344090	C61C73	1278 522931	VALERIY DAVYDOV	{"phone": "+70967472343"}
0005433344091	413391	1585 854921	YURIY ANDREEV	{"email": "andreev-y12081970@postgrespro.ru", "phone": "+70877201943"}
0005433344092	351B07	0451 987879	NADEZHDA NIKITINA	{"phone": "+70612067217"}
0005433344093	351B07	5108 918734	VLADIMIR MAKSIMOV	{"email": "maksimov_vladimir_1975@postgrespro.ru", "phone": "+70320998530"}
0005433344094	210A70	3463 028814	SVETLANA KISELEVA	{"phone": "+70585787649"}
0005433344095	D3DC6B	6464 048605	ANATOLIY MAKAROV	{"email": "makarovanatoliy.1968@postgrespro.ru", "phone": "+70740811094"}
0005433344096	B104E1	0963 107114	NATALYA GUSEVA	{"email": "guseva-n-061977@postgrespro.ru", "phone": "+70749996776"}
0005433344097	CC9DAE	3810 061130	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov.1976@postgrespro.ru", "phone": "+70416440639"}
0005433344098	BD31F2	0179 272277	VASILIY MARTYNOV	{"email": "vasiliy_martynov.071965@postgrespro.ru", "phone": "+70170113337"}
0005433344099	400402	0142 227938	DMITRIY MIRONOV	{"phone": "+70840171239"}
0005433344100	77CE09	3770 815386	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov-1961@postgrespro.ru", "phone": "+70020174644"}
0005433344101	77CE09	7081 394718	TATYANA ZHURAVLEVA	{"phone": "+70840409156"}
0005433344102	DBC586	4873 624436	STANISLAV MELNIKOV	{"email": "s-melnikov.11101980@postgrespro.ru", "phone": "+70737995166"}
0005433344103	E0BB75	8241 934136	LYUBOV SEMENOVA	{"email": "lyubovsemenova-1975@postgrespro.ru", "phone": "+70727802604"}
0005433344104	A9C2A3	4776 493519	SERGEY VASILEV	{"email": "s.vasilev.1978@postgrespro.ru", "phone": "+70733751459"}
0005433344105	A9C2A3	0919 624856	OLGA NIKITINA	{"email": "olganikitina021972@postgrespro.ru", "phone": "+70516885417"}
0005433344106	A9C2A3	7423 742794	LILIYA SAVELEVA	{"email": "saveleva.l_1974@postgrespro.ru", "phone": "+70684552576"}
0005433344107	FB2D50	0651 207266	IVAN DENISOV	{"email": "denisov-ivan.31121963@postgrespro.ru", "phone": "+70585025368"}
0005433344108	FB2D50	0123 147350	EVGENIY ABRAMOV	{"email": "abramov_e.1961@postgrespro.ru", "phone": "+70992821900"}
0005433344109	FB2D50	4257 083427	KIRILL KUZNECOV	{"email": "kkuznecov_1987@postgrespro.ru", "phone": "+70017200620"}
0005433344110	E699D7	5967 982315	TATYANA ILINA	{"phone": "+70759920701"}
0005433344111	0C2B1A	5543 740211	EVELINA KAZAKOVA	{"phone": "+70815977944"}
0005433344112	51B608	8192 451492	NIKITA KARPOV	{"phone": "+70326953228"}
0005433344113	8DF732	1335 107212	LARISA LUKYANOVA	{"email": "lukyanova-l_1972@postgrespro.ru", "phone": "+70519863592"}
0005433344114	8DF732	6895 411968	VALERIYA NAZAROVA	{"email": "v.nazarova1975@postgrespro.ru", "phone": "+70713902760"}
0005433344115	0D1390	5527 626359	TATYANA MELNIKOVA	{"email": "t-melnikova_1989@postgrespro.ru", "phone": "+70494665581"}
0005433344116	8788B4	7332 251336	IRINA FOMINA	{"phone": "+70563599121"}
0005433344117	8788B4	9347 050829	DMITRIY MIKHAYLOV	{"phone": "+70695075786"}
0005433344118	143E25	4583 556576	TIMUR ISAEV	{"phone": "+70505753125"}
0005433344119	143E25	1150 543997	VALENTINA SMIRNOVA	{"email": "valentina-smirnova.111972@postgrespro.ru", "phone": "+70813130922"}
0005433344120	8B6F86	6908 383224	VALENTIN MEDVEDEV	{"email": "valentin-medvedev-1974@postgrespro.ru", "phone": "+70456129385"}
0005433344121	4D3052	0967 421742	ALEKSANDR KOZLOV	{"phone": "+70307615612"}
0005433344122	4D3052	8020 645778	OKSANA BORISOVA	{"phone": "+70654175129"}
0005433344123	80C230	3692 051218	GALINA DAVYDOVA	{"email": "davydova-galina_11121974@postgrespro.ru", "phone": "+70805010832"}
0005433344124	80C230	4016 726824	VALENTINA BELYAEVA	{"phone": "+70553944503"}
0005433344125	196677	1278 724003	ELENA ERMAKOVA	{"email": "ermakova_e10081971@postgrespro.ru", "phone": "+70588586155"}
0005433344126	BDA8AC	8278 849894	IRINA GRISHINA	{"phone": "+70603093881"}
0005433344127	2F9677	3390 541171	ARINA KRASNOVA	{"email": "krasnova-a121975@postgrespro.ru", "phone": "+70511245466"}
0005433344128	455B4E	1895 206616	LYUDMILA YAKOVLEVA	{"phone": "+70046661314"}
0005433344129	455B4E	2777 650155	LYUDMILA KUZNECOVA	{"phone": "+70529786196"}
0005433344130	4234B2	3724 311874	ANZHELIKA BORISOVA	{"phone": "+70882440949"}
0005433344131	7DA08A	4890 343059	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov-061967@postgrespro.ru", "phone": "+70159591545"}
0005433344132	D4F653	4312 287644	MARIYA MARTYNOVA	{"email": "mariyamartynova1980@postgrespro.ru", "phone": "+70914696046"}
0005433344133	233305	3472 173250	VALERIY SOROKIN	{"phone": "+70971274133"}
0005433344134	8F3B1C	0938 089762	MIKHAIL SOROKIN	{"email": "mikhailsorokin23121984@postgrespro.ru", "phone": "+70906661958"}
0005433344135	45BB74	6502 568856	NIKOLAY GUSEV	{"email": "n_gusev071969@postgrespro.ru", "phone": "+70064633121"}
0005433344136	45BB74	3085 339616	ALEKSEY STEPANOV	{"email": "stepanov.a.1973@postgrespro.ru", "phone": "+70246029471"}
0005433344137	D00DEA	6863 581505	IBRAGIM AFANASEV	{"phone": "+70930714801"}
0005433344138	D00DEA	3302 943240	ALEKSEY SHEVCHENKO	{"phone": "+70206705892"}
0005433344139	8EF4E2	4316 880244	PAVEL ZAYCEV	{"email": "pavelzaycev_011975@postgrespro.ru", "phone": "+70661710091"}
0005433344140	4E5EE9	2015 262807	ANASTASIYA ZAKHAROVA	{"phone": "+70705290422"}
0005433344141	4E5EE9	5983 276630	NIKOLAY OSIPOV	{"phone": "+70306465311"}
0005433344142	4E5EE9	2456 828883	NATALYA NAZAROVA	{"email": "natalyanazarova081977@postgrespro.ru", "phone": "+70568046636"}
0005433344143	10F959	6769 537110	LIDIYA KONOVALOVA	{"email": "konovalova_l011971@postgrespro.ru", "phone": "+70897154212"}
0005433344144	10F959	3350 363124	ARTEM ZAYCEV	{"phone": "+70118057845"}
0005433344145	10F959	6384 395294	NATALYA LAZAREVA	{"email": "n_lazareva-17101962@postgrespro.ru", "phone": "+70176226346"}
0005433344146	3DAF87	6356 790584	SERGEY DMITRIEV	{"phone": "+70264429394"}
0005433344147	D83B7D	1140 134777	GEORGIY FILIPPOV	{"email": "gfilippov.02081974@postgrespro.ru", "phone": "+70933820737"}
0005433344148	7F2534	6658 658634	EVDOKIYA ZHUKOVA	{"email": "evdokiya.zhukova16021976@postgrespro.ru", "phone": "+70113526295"}
0005433344149	7F2534	2040 159997	ZINAIDA MALYSHEVA	{"email": "z.malysheva-121966@postgrespro.ru", "phone": "+70592803908"}
0005433344150	7F2534	9888 934603	NATALYA POPOVA	{"email": "n-popova15051978@postgrespro.ru", "phone": "+70019792354"}
0005433344151	3FB1FC	8056 942925	VENIAMIN STEPANOV	{"phone": "+70922368459"}
0005433344152	188340	4783 801360	GENNADIY MOROZOV	{"email": "morozov-gennadiy.021987@postgrespro.ru", "phone": "+70875727434"}
0005433344208	CE07B2	8561 607252	VITALIY SOKOLOV	{"phone": "+70184635757"}
0005433344153	188340	9124 999936	IRINA MAKAROVA	{"email": "irina_makarova1969@postgrespro.ru", "phone": "+70352917145"}
0005433344154	29DD74	1290 188174	ANASTASIYA SIDOROVA	{"email": "anastasiya_sidorova-16121968@postgrespro.ru", "phone": "+70702793831"}
0005433344155	29DD74	3456 437542	NIKOLAY SCHERBAKOV	{"email": "scherbakovn_03031970@postgrespro.ru", "phone": "+70520115237"}
0005433344156	E604F3	1919 976201	LYUDMILA PETROVA	{"email": "lyudmilapetrova1969@postgrespro.ru", "phone": "+70842613439"}
0005433344157	E604F3	1618 741538	NINA TIMOFEEVA	{"phone": "+70399948050"}
0005433344158	E604F3	5380 260432	TATYANA ERMAKOVA	{"phone": "+70965347653"}
0005433344159	A3623C	7775 892389	GALINA FADEEVA	{"email": "galina.fadeeva_011970@postgrespro.ru", "phone": "+70799153144"}
0005433344160	0BD625	4958 632879	OLGA MARTYNOVA	{"email": "martynovaolga_081968@postgrespro.ru", "phone": "+70610375223"}
0005433344161	0BD625	0708 831775	ALEKSANDR KOROLEV	{"email": "a.korolev.1974@postgrespro.ru", "phone": "+70057936651"}
0005433344162	13BB3A	6196 876528	VALENTINA TITOVA	{"phone": "+70312579974"}
0005433344163	13BB3A	3156 059820	MIKHAIL ZAYCEV	{"phone": "+70985071460"}
0005433344164	86477B	7645 504261	YURIY IVANOV	{"email": "ivanov.yuriy081974@postgrespro.ru", "phone": "+70255263597"}
0005433344165	F864DB	7209 028082	GEORGIY ABRAMOV	{"phone": "+70509095456"}
0005433344166	1B5130	7499 019524	ANDREY TIKHONOV	{"phone": "+70144494867"}
0005433344167	D8BBD9	5698 717496	EKATERINA VOLKOVA	{"email": "e_volkova041978@postgrespro.ru", "phone": "+70216572673"}
0005433344168	D8BBD9	5324 315848	MARIYA MARTYNOVA	{"phone": "+70358262266"}
0005433344169	D8BBD9	7586 227347	DMITRIY CHERNOV	{"email": "chernov.dmitriy-081978@postgrespro.ru", "phone": "+70773717827"}
0005433344170	9293CE	5972 646460	ALEKSANDR DENISOV	{"phone": "+70188469310"}
0005433344171	09CA39	7836 507293	LIDIYA GAVRILOVA	{"phone": "+70661964972"}
0005433344172	09CA39	9535 613835	VASILISA TARASOVA	{"email": "tarasovav011974@postgrespro.ru", "phone": "+70075639388"}
0005433344173	F55879	5936 507658	YURIY MIKHAYLOV	{"phone": "+70232740349"}
0005433344174	02F02D	9586 809710	ALEKSEY SMIRNOV	{"email": "smirnov-aleksey.071973@postgrespro.ru", "phone": "+70619642558"}
0005433344175	02F02D	2357 210362	IRINA ORLOVA	{"phone": "+70415706452"}
0005433344176	02F02D	0299 806097	ALEKSANDR FILIPPOV	{"email": "filippov_aleksandr_1974@postgrespro.ru", "phone": "+70127143349"}
0005433344177	EEF981	4171 014504	ROMAN IVANOV	{"phone": "+70444778226"}
0005433344178	8AC116	3310 290788	GEORGIY OSIPOV	{"phone": "+70950286818"}
0005433344179	975972	5344 836981	VALENTINA TARASOVA	{"email": "valentina.tarasova-25091972@postgrespro.ru", "phone": "+70299560628"}
0005433344180	975972	1750 538146	TATYANA ANISIMOVA	{"email": "tatyanaanisimova.31011971@postgrespro.ru", "phone": "+70135203402"}
0005433344181	43294A	0026 332922	ANASTASIYA YUDINA	{"phone": "+70797038192"}
0005433344182	B83820	9203 245645	ANASTASIYA ILINA	{"phone": "+70186649993"}
0005433344183	B83820	7588 699873	NIKOLAY DMITRIEV	{"email": "nikolaydmitriev_03111971@postgrespro.ru", "phone": "+70784143769"}
0005433344184	3DCB3D	1328 957017	ALENA MOROZOVA	{"email": "morozovaalena.15031971@postgrespro.ru", "phone": "+70502954439"}
0005433344185	AAD2E5	6703 253140	ZLATA SCHERBAKOVA	{"phone": "+70498069921"}
0005433344186	84F50B	5864 399678	INNA FILIPPOVA	{"email": "innafilippova_1977@postgrespro.ru", "phone": "+70286968221"}
0005433344187	84F50B	3077 736923	MAKSIM KUZMIN	{"phone": "+70644608902"}
0005433344188	89E169	8167 290896	LARISA DAVYDOVA	{"email": "ldavydova.1971@postgrespro.ru", "phone": "+70794088534"}
0005433344189	89E169	8909 491509	ROMAN FROLOV	{"phone": "+70748140427"}
0005433344190	775AE8	1020 402411	ALEKSANDR MAKAROV	{"phone": "+70114593534"}
0005433344191	5E217B	0612 784592	ANASTASIYA MIRONOVA	{"email": "mironova.a-24011972@postgrespro.ru", "phone": "+70596780495"}
0005433344192	56B28A	2862 624655	DENIS MEDVEDEV	{"email": "medvedev.denis1975@postgrespro.ru", "phone": "+70998396055"}
0005433344193	0458B0	9268 889708	TATYANA RODIONOVA	{"email": "rodionovatatyana.1956@postgrespro.ru", "phone": "+70825854667"}
0005433344194	0C444A	6411 934726	MAYYA SEMENOVA	{"phone": "+70640248905"}
0005433344195	D35DCA	1965 865762	LYUDMILA KOROLEVA	{"email": "koroleva_lyudmila-1959@postgrespro.ru", "phone": "+70524588942"}
0005433344196	D35DCA	5771 837710	DMITRIY FEDOTOV	{"email": "dmitriy-fedotov_20011979@postgrespro.ru", "phone": "+70348052365"}
0005433344197	F45721	4257 060231	ALEKSANDR IVANOV	{"email": "aivanov_02041969@postgrespro.ru", "phone": "+70864243028"}
0005433344198	CED2BC	7194 321007	GEORGIY POPOV	{"email": "popov_georgiy.14011961@postgrespro.ru", "phone": "+70744158301"}
0005433344199	B45310	2477 508065	IRINA EGOROVA	{"email": "i-egorova1987@postgrespro.ru", "phone": "+70085370970"}
0005433344200	FC8030	5805 241401	ALEKSEY ISAEV	{"email": "isaev.a.021975@postgrespro.ru", "phone": "+70524413084"}
0005433344201	2445B5	9450 210113	VERA TIKHONOVA	{"email": "tikhonova-v_1978@postgrespro.ru", "phone": "+70963790079"}
0005433344202	0545B8	7650 105806	ELIZAVETA AFANASEVA	{"email": "e_afanaseva29091976@postgrespro.ru", "phone": "+70526927454"}
0005433344203	322CB2	8463 601395	DIANA DMITRIEVA	{"phone": "+70650446457"}
0005433344204	322CB2	4155 633368	DZHAMILYA KOZLOVA	{"phone": "+70275668418"}
0005433344205	7AA279	2043 095406	EKATERINA ZHUKOVA	{"phone": "+70360316779"}
0005433344206	29BCDF	4233 242409	VITALIY ANTONOV	{"email": "vitaliy_antonov-031966@postgrespro.ru", "phone": "+70233679202"}
0005433344207	F8A695	9569 437342	SERGEY NIKOLAEV	{"email": "s_nikolaev_1977@postgrespro.ru", "phone": "+70348478927"}
0005433344209	CE07B2	7140 873768	MATVEY POPOV	{"email": "matvey_popov-22031958@postgrespro.ru", "phone": "+70120395327"}
0005433344210	750148	4356 899496	ELENA LEBEDEVA	{"email": "e.lebedeva-19041982@postgrespro.ru", "phone": "+70416557831"}
0005433344211	D6A9BD	3783 603589	DARYA TARASOVA	{"phone": "+70229667272"}
0005433344212	B7821B	6099 661610	ALEKSEY VOLKOV	{"phone": "+70458618493"}
0005433344213	871C31	6016 697198	MARGARITA IVANOVA	{"phone": "+70925523574"}
0005433344214	F72509	2714 569015	ALEKSANDR KRASNOV	{"email": "a-krasnov1976@postgrespro.ru", "phone": "+70191267306"}
0005433344215	F53706	9692 800316	EKATERINA VASILEVA	{"email": "e-vasileva-011982@postgrespro.ru", "phone": "+70627458119"}
0005433344216	281A7A	1521 050968	NATALYA ZAYCEVA	{"phone": "+70320540543"}
0005433344217	7A8D17	4052 299768	OLGA VOLKOVA	{"phone": "+70556962453"}
0005433344218	C9D5DD	2608 487777	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov_051978@postgrespro.ru", "phone": "+70193599470"}
0005433344219	C9D5DD	7418 330861	ANNA GAVRILOVA	{"email": "a.gavrilova-041975@postgrespro.ru", "phone": "+70251424046"}
0005433344220	082A24	4243 151036	TATYANA ARKHIPOVA	{"email": "arkhipova.t-1977@postgrespro.ru", "phone": "+70891580236"}
0005433344221	082A24	2279 490212	YULIYA FADEEVA	{"phone": "+70746401567"}
0005433344222	8926A3	9491 815508	ALEKSANDRA GERASIMOVA	{"email": "gerasimova-a_1965@postgrespro.ru", "phone": "+70554171777"}
0005433344223	4F3424	6008 763032	NADEZHDA FEDOROVA	{"email": "fedorovanadezhda04061976@postgrespro.ru", "phone": "+70569306012"}
0005433344224	4F3424	5564 204213	YAROSLAV SHEVCHENKO	{"email": "shevchenko.yaroslav-1969@postgrespro.ru", "phone": "+70256212810"}
0005433344225	4F3424	1034 307785	VALENTINA BOGDANOVA	{"email": "valentinabogdanova.1979@postgrespro.ru", "phone": "+70702987734"}
0005433344226	B7993E	8994 983055	VASILIY KUZMIN	{"phone": "+70548303678"}
0005433344227	9F34B8	2379 554048	YURIY SOROKIN	{"email": "y_sorokin-111960@postgrespro.ru", "phone": "+70385448541"}
0005433344228	9F34B8	2095 401187	ANDREY SEMENOV	{"phone": "+70477203225"}
0005433344229	1A88C0	7940 017067	IRINA SIDOROVA	{"email": "i-sidorova-1967@postgrespro.ru", "phone": "+70461971943"}
0005433344230	57F664	1891 872165	ALEKSANDR IVANOV	{"email": "a_ivanov-05061973@postgrespro.ru", "phone": "+70476385524"}
0005433344231	57F664	1268 389914	PETR NAZAROV	{"email": "nazarov_petr_051954@postgrespro.ru", "phone": "+70384794181"}
0005433344232	A9B8D3	6600 369560	NATALYA ZAKHAROVA	{"phone": "+70918818001"}
0005433344233	00CAF5	6674 530470	NIKITA GRIGOREV	{"email": "grigorev-nikita_1974@postgrespro.ru", "phone": "+70595632171"}
0005433344234	F3D518	2145 944301	ANTONINA RODIONOVA	{"email": "a.rodionova-091972@postgrespro.ru", "phone": "+70668176242"}
0005433344235	F3D518	8969 385675	KLAVDIYA ABRAMOVA	{"phone": "+70717282721"}
0005433344236	F3D518	5012 496580	NATALYA SMIRNOVA	{"phone": "+70474000963"}
0005433344237	1C561C	9622 529379	TATYANA ZOTOVA	{"email": "tzotova.11101975@postgrespro.ru", "phone": "+70040171191"}
0005433344238	3F43F0	2835 084425	LEONID KOZLOV	{"email": "l.kozlov_04101971@postgrespro.ru", "phone": "+70916967582"}
0005433344239	6054B2	2637 283096	TATYANA RODIONOVA	{"email": "t.rodionova.1971@postgrespro.ru", "phone": "+70329949530"}
0005433344240	6054B2	8287 599776	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr_031976@postgrespro.ru", "phone": "+70318167821"}
0005433344241	FB76C2	6862 967195	VALENTINA ROMANOVA	{"email": "romanovav11071967@postgrespro.ru", "phone": "+70700469875"}
0005433344242	FB76C2	4990 820796	YURIY SMIRNOV	{"phone": "+70998013297"}
0005433344243	FB76C2	1073 665781	OLGA KISELEVA	{"email": "olga_kiseleva-051969@postgrespro.ru", "phone": "+70203695383"}
0005433344244	DFBAD2	7064 688676	VALERIYA DANILOVA	{"phone": "+70009756438"}
0005433344245	DFBAD2	4463 303654	ALEKSANDR MIKHAYLOV	{"phone": "+70939454797"}
0005433344246	8B59CE	6943 525874	ALEKSANDR KISELEV	{"email": "kiseleva.30081975@postgrespro.ru", "phone": "+70180543242"}
0005433344247	8B59CE	4995 672749	ALEKSEY KULIKOV	{"email": "aleksey-kulikov-05031973@postgrespro.ru", "phone": "+70882369814"}
0005433344248	348C07	7813 842948	ANNA SCHERBAKOVA	{"email": "a_scherbakova1982@postgrespro.ru", "phone": "+70312261574"}
0005433344249	C3DAD4	0210 779091	ZINAIDA SAVELEVA	{"email": "saveleva.z_1980@postgrespro.ru", "phone": "+70636672752"}
0005433344250	C3DAD4	6200 218984	ELENA GUSEVA	{"email": "guseva-elena081977@postgrespro.ru", "phone": "+70432161713"}
0005433344251	746A9C	1790 914519	EVGENIYA KULIKOVA	{"phone": "+70152065682"}
0005433344252	746A9C	7856 958845	ARTEM TIKHONOV	{"email": "a.tikhonov.31031969@postgrespro.ru", "phone": "+70746311240"}
0005433344253	500183	9323 432722	OLGA VOLKOVA	{"phone": "+70222585307"}
0005433344254	6B29DE	8802 000676	ALISA MIKHAYLOVA	{"email": "amikhaylova_121986@postgrespro.ru", "phone": "+70658927151"}
0005433344255	1F88FD	4861 865222	OLEG GERASIMOV	{"phone": "+70824255170"}
0005433344256	90BF20	7920 467204	ILYA ZAYCEV	{"phone": "+70980383110"}
0005433344257	90BF20	9069 211038	IGOR BONDARENKO	{"email": "igor.bondarenko.17101976@postgrespro.ru", "phone": "+70618268209"}
0005433344258	CC062E	1002 409164	EVGENIY NAUMOV	{"phone": "+70867900317"}
0005433344259	CC062E	9764 089857	ANASTASIYA PAVLOVA	{"email": "anastasiyapavlova-051976@postgrespro.ru", "phone": "+70108514429"}
0005433344260	925E12	2734 755822	TATYANA BOGDANOVA	{"phone": "+70347881361"}
0005433344261	A477FC	9782 987608	IGOR KUDRYASHOV	{"email": "kudryashov_igor1970@postgrespro.ru", "phone": "+70891655761"}
0005433344262	A477FC	9665 730854	MARINA SEMENOVA	{"phone": "+70257984743"}
0005433344263	A477FC	9785 143590	IVAN ZAKHAROV	{"phone": "+70353110732"}
0005433344264	6F1AD3	7232 449279	ALEKSANDR TIMOFEEV	{"phone": "+70120338753"}
0005433344265	9D534E	4883 662985	ALEKSEY KUZMIN	{"email": "a.kuzmin_08031978@postgrespro.ru", "phone": "+70699387943"}
0005433344266	F89471	4088 943127	ANDREY MIRONOV	{"phone": "+70155392957"}
0005433344267	3DF012	8740 539349	ANTON SIDOROV	{"phone": "+70644961700"}
0005433344268	3DF012	7015 539871	ULYANA PETROVA	{"phone": "+70793370502"}
0005433344269	3D3A56	5402 716504	VLADIMIR MIKHAYLOV	{"phone": "+70212068028"}
0005433344270	FD1537	4324 485981	EGOR PETROV	{"email": "e-petrov041976@postgrespro.ru", "phone": "+70309962415"}
0005433344271	FD1537	6311 741374	PETR FOMIN	{"email": "p_fomin.121967@postgrespro.ru", "phone": "+70065864986"}
0005433344272	E50D54	4936 250378	ARSENIY SOKOLOV	{"email": "sokolov_a031977@postgrespro.ru", "phone": "+70813431150"}
0005433344273	A4C0DD	5848 742282	ALEKSANDR VASILEV	{"phone": "+70355720265"}
0005433344274	E9F7F9	6108 441402	GENNADIY SERGEEV	{"email": "sergeev-gennadiy-091968@postgrespro.ru", "phone": "+70941462599"}
0005433344275	9123BC	2709 141383	LIDIYA ROMANOVA	{"email": "lidiya.romanova.1975@postgrespro.ru", "phone": "+70398864227"}
0005433344276	9123BC	3623 392222	NIKOLAY MEDVEDEV	{"email": "nikolay_medvedev-1990@postgrespro.ru", "phone": "+70605760819"}
0005433344277	903B21	6889 474172	EVGENIY EGOROV	{"phone": "+70209299264"}
0005433344278	903B21	5111 245890	DMITRIY ILIN	{"email": "ilin.dmitriy_1969@postgrespro.ru", "phone": "+70598310134"}
0005433344279	F8585E	1197 052265	SERGEY FROLOV	{"email": "sfrolov.30011967@postgrespro.ru", "phone": "+70533219783"}
0005433344280	F8585E	2368 921396	MAKSIM IVANOV	{"email": "maksim_ivanov.011972@postgrespro.ru", "phone": "+70448584341"}
0005433344281	85F877	7873 589785	SVETLANA MOROZOVA	{"email": "morozovasvetlana_1963@postgrespro.ru", "phone": "+70738072389"}
0005433344282	648FD7	3167 515301	GALINA GUSEVA	{"phone": "+70998546998"}
0005433344283	AD6AA4	7975 220870	OLGA POTAPOVA	{"phone": "+70482838359"}
0005433344284	51017D	8234 209672	OLEG MOISEEV	{"phone": "+70986750795"}
0005433344285	899B48	9471 322372	VYACHESLAV BORISOV	{"phone": "+70262557040"}
0005433344286	D8B26C	8347 256432	YANA KARPOVA	{"phone": "+70241206548"}
0005433344287	D8B26C	7466 760587	SERGEY VLASOV	{"phone": "+70928469256"}
0005433344288	D8B26C	7797 747955	DARYA NAZAROVA	{"email": "nazarova_darya_1977@postgrespro.ru", "phone": "+70805228034"}
0005433344289	77BFEA	1607 230083	OLEG VASILEV	{"phone": "+70515113268"}
0005433344290	77BFEA	1296 138034	IRAIDA POPOVA	{"email": "popova_iraida.1979@postgrespro.ru", "phone": "+70995400875"}
0005433344291	5DE13D	7001 698974	NADEZHDA ANISIMOVA	{"phone": "+70919478286"}
0005433344292	D8B594	5988 359257	ALEKSEY NAZAROV	{"phone": "+70150058755"}
0005433344293	D8B594	4342 696531	NIKOLAY SOKOLOV	{"email": "nikolay-sokolov_031974@postgrespro.ru", "phone": "+70372970153"}
0005433344294	459336	1999 338870	VERA IVANOVA	{"email": "ivanovavera_011977@postgrespro.ru", "phone": "+70538421796"}
0005433344295	459336	6975 142053	EVGENIYA KULIKOVA	{"phone": "+70705698283"}
0005433344296	033DCE	9210 672347	ELENA FEDOROVA	{"phone": "+70425017981"}
0005433344297	5642D7	0444 751277	DANIIL NOVIKOV	{"phone": "+70187509704"}
0005433344298	5642D7	9616 384718	PETR PAVLOV	{"email": "pavlovp_1966@postgrespro.ru", "phone": "+70118498010"}
0005433344299	FB15A5	7932 366088	YURIY KUZMIN	{"phone": "+70811161034"}
0005433344300	FB15A5	4217 962718	ANNA MATVEEVA	{"phone": "+70412905917"}
0005433344301	2CC3E7	9760 761473	RAISA DMITRIEVA	{"phone": "+70574277942"}
0005433344302	2CC3E7	0537 548336	ANNA KUZNECOVA	{"phone": "+70753365245"}
0005433344303	088325	9220 844737	ANASTASIYA FEDOROVA	{"phone": "+70428295615"}
0005433344304	F7EDB9	7169 315236	NIKOLAY GORBUNOV	{"phone": "+70332280155"}
0005433344305	9BDB0F	3757 784858	VALERIY ZAKHAROV	{"email": "valeriy-zakharov.1981@postgrespro.ru", "phone": "+70084351630"}
0005433344306	9BDB0F	0441 540937	OLGA VOROBEVA	{"phone": "+70257046596"}
0005433344307	9BDB0F	0868 161866	MARIYA BORISOVA	{"phone": "+70333314143"}
0005433344308	134A45	1056 417453	LIDIYA EFREMOVA	{"email": "efremoval.121972@postgrespro.ru", "phone": "+70095255624"}
0005433344309	BF76F6	0919 895933	POLINA EGOROVA	{"email": "p-egorova011962@postgrespro.ru", "phone": "+70635034111"}
0005433344310	BF76F6	5466 812543	ALEKSANDR ZHURAVLEV	{"phone": "+70240413735"}
0005433344311	0F86B8	4533 071140	ALEKSANDR KRASNOV	{"email": "aleksandr-krasnov-071965@postgrespro.ru", "phone": "+70243406700"}
0005433344312	0F86B8	0090 034021	MAKSIM BELOV	{"phone": "+70224000877"}
0005433344313	626B87	0047 563472	ZOYA SIDOROVA	{"email": "zoya_sidorova-1971@postgrespro.ru", "phone": "+70494442797"}
0005433344314	4BD04A	1075 756608	SERGEY KOZLOV	{"email": "kozlov.s_1984@postgrespro.ru", "phone": "+70783059400"}
0005433344315	988302	2657 810738	ELENA NIKOLAEVA	{"email": "enikolaeva-25051974@postgrespro.ru", "phone": "+70803773946"}
0005433344316	D28C41	5523 135081	ELENA RODIONOVA	{"email": "rodionova-elena-041969@postgrespro.ru", "phone": "+70026696705"}
0005433344317	823433	1777 088960	IRINA SEMENOVA	{"email": "irina.semenova-1969@postgrespro.ru", "phone": "+70824770131"}
0005433344318	FE339B	9605 527597	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov.1968@postgrespro.ru", "phone": "+70121261322"}
0005433344319	75F36A	9319 439859	VERA GRISHINA	{"phone": "+70374199429"}
0005433344320	75F36A	4928 070973	NATALYA KISELEVA	{"email": "kiselevan_14071968@postgrespro.ru", "phone": "+70371460220"}
0005433344321	910597	3372 427973	TAMARA NIKIFOROVA	{"phone": "+70263730918"}
0005433344322	19853B	8280 844596	TATYANA NIKIFOROVA	{"phone": "+70473099317"}
0005433344323	A9574D	7996 748099	TATYANA MOISEEVA	{"email": "t.moiseeva051965@postgrespro.ru", "phone": "+70796709339"}
0005433344324	C64056	8054 044047	VLADIMIR VASILEV	{"email": "v_vasilev.17041970@postgrespro.ru", "phone": "+70009366543"}
0005433344325	31A36E	1673 128962	ELENA DANILOVA	{"phone": "+70515977014"}
0005433344326	31A36E	8003 078575	SERAFIMA PAVLOVA	{"email": "s_pavlova_1971@postgrespro.ru", "phone": "+70270351395"}
0005433344327	E6ACF8	7366 242350	NIKITA AFANASEV	{"email": "afanasev.n.14061973@postgrespro.ru", "phone": "+70644210361"}
0005433344328	E6ACF8	8587 564419	ANZHELA MIKHAYLOVA	{"email": "anzhela.mikhaylova_24071968@postgrespro.ru", "phone": "+70371172188"}
0005433344329	7E8481	7281 118785	VERA MATVEEVA	{"email": "veramatveeva23041965@postgrespro.ru", "phone": "+70389426791"}
0005433344330	38AE06	4475 327238	DANILA ILIN	{"email": "ilin.danila_031969@postgrespro.ru", "phone": "+70464540316"}
0005433344331	240174	1619 164554	OLGA DANILOVA	{"phone": "+70432204715"}
0005433344332	0592C3	0628 112617	LILIYA ANDREEVA	{"email": "liliya-andreeva_29041986@postgrespro.ru", "phone": "+70299117622"}
0005433344333	0592C3	5642 879633	ANDREY VOLKOV	{"phone": "+70667102752"}
0005433344334	0592C3	5085 562777	LILIYA GUSEVA	{"email": "guseva.liliya-12031982@postgrespro.ru", "phone": "+70794476251"}
0005433344335	FBE40B	3770 955725	OLEG FILIPPOV	{"email": "o-filippov-1971@postgrespro.ru", "phone": "+70219004219"}
0005433344336	8CAB1C	0234 434402	NIKOLAY ROMANOV	{"email": "romanov.n.1978@postgrespro.ru", "phone": "+70924418814"}
0005433344337	081009	6810 778499	NINA FROLOVA	{"email": "n-frolova.041973@postgrespro.ru", "phone": "+70298454981"}
0005433344338	23294F	6904 404627	NIKOLAY KONOVALOV	{"phone": "+70396665813"}
0005433344339	00FC3D	1927 499687	NATALYA NIKITINA	{"email": "nikitina_n.1970@postgrespro.ru", "phone": "+70109510469"}
0005433344340	AAE019	0195 812041	SERGEY KUZMIN	{"phone": "+70858963608"}
0005433344341	AAE019	6515 686910	TATYANA ALEKSEEVA	{"email": "t-alekseeva_1963@postgrespro.ru", "phone": "+70635112077"}
0005433344342	178E2F	9420 207175	TATYANA YUDINA	{"email": "yudina_tatyana09021974@postgrespro.ru", "phone": "+70661756777"}
0005433344343	178E2F	6889 760766	ANASTASIYA KOROLEVA	{"email": "koroleva_a1970@postgrespro.ru", "phone": "+70977304438"}
0005433344344	5F5720	7491 933675	ILMIR VASILEV	{"email": "vasilev.ilmir.1976@postgrespro.ru", "phone": "+70280667627"}
0005433344345	8C8F91	6005 650141	SERGEY PETROV	{"phone": "+70989023138"}
0005433344346	B00430	7091 227447	OLGA KUZNECOVA	{"email": "kuznecova_o31011975@postgrespro.ru", "phone": "+70299099096"}
0005433344347	B00430	3785 087983	NATALYA VOLKOVA	{"email": "volkova-n-051980@postgrespro.ru", "phone": "+70437010689"}
0005433344348	F72B69	3268 067236	OLEG YAKOVLEV	{"email": "yakovlevoleg09051976@postgrespro.ru", "phone": "+70971805425"}
0005433344349	603790	3168 104451	ANDREY GRIGOREV	{"email": "grigorev.andrey.011975@postgrespro.ru", "phone": "+70369432588"}
0005433344350	603790	0219 669625	EKATERINA KUZNECOVA	{"email": "e_kuznecova-101967@postgrespro.ru", "phone": "+70618224193"}
0005433344351	9382B4	7987 717904	SVETLANA ROMANOVA	{"phone": "+70120032604"}
0005433344352	9FDAB8	6299 920066	ANDREY VLASOV	{"email": "andreyvlasov_1985@postgrespro.ru", "phone": "+70960173368"}
0005433344353	D40B24	1358 508607	VYACHESLAV PAVLOV	{"email": "v-pavlov.041970@postgrespro.ru", "phone": "+70327523436"}
0005433344354	D40B24	7109 185306	RAISA ROMANOVA	{"email": "rromanova1967@postgrespro.ru", "phone": "+70551653502"}
0005433344355	B20669	3187 055391	MARIYA MELNIKOVA	{"email": "mariya_melnikova-1969@postgrespro.ru", "phone": "+70919270866"}
0005433344356	62097F	7744 029095	SERGEY NIKITIN	{"phone": "+70314028387"}
0005433344357	62097F	2866 313917	ELENA TITOVA	{"phone": "+70207860362"}
0005433344358	62097F	1744 823919	ELIZAVETA VLASOVA	{"phone": "+70759292197"}
0005433344359	FD5F26	5005 921563	IGOR ORLOV	{"email": "orlov_igor.1973@postgrespro.ru", "phone": "+70146316461"}
0005433344360	FD5F26	0621 160018	MARINA EGOROVA	{"email": "m_egorova.19021963@postgrespro.ru", "phone": "+70841870036"}
0005433344361	8ABB84	8047 852601	MARIYA KONDRATEVA	{"email": "kondrateva.m-101973@postgrespro.ru", "phone": "+70826731669"}
0005433344362	640F93	8441 067576	YULIYA POPOVA	{"phone": "+70777443335"}
0005433344363	F08411	5406 171686	LYUDMILA MAKSIMOVA	{"email": "maksimovalyudmila18091961@postgrespro.ru", "phone": "+70016498159"}
0005433344364	1E2ED1	5428 399311	ANATOLIY SEMENOV	{"phone": "+70977288127"}
0005433344365	14E9EA	7307 620384	IGOR GAVRILOV	{"email": "igavrilov-1970@postgrespro.ru", "phone": "+70138991734"}
0005433344366	14E9EA	4850 385340	DENIS STEPANOV	{"phone": "+70641517235"}
0005433344367	FEC965	9420 266826	NATALYA ANDREEVA	{"phone": "+70402735944"}
0005433344368	058C97	6559 072165	ELENA KONDRATEVA	{"email": "kondrateva_elena_1981@postgrespro.ru", "phone": "+70950890431"}
0005433344369	96187B	6461 657174	NIKITA GORBUNOV	{"phone": "+70374571822"}
0005433344370	6C1246	7273 614141	MAKSIM ILIN	{"email": "ilin_maksim-011970@postgrespro.ru", "phone": "+70125397868"}
0005433344371	6C1246	0202 572616	ANASTASIYA FILATOVA	{"email": "a_filatova.13111964@postgrespro.ru", "phone": "+70741376780"}
0005433344372	19C566	2491 718009	ANDREY MOROZOV	{"phone": "+70997034077"}
0005433344373	19C566	7424 597265	DENIS PETROV	{"email": "d.petrov11091968@postgrespro.ru", "phone": "+70536039178"}
0005433344374	19C566	9317 204570	NINA SAVELEVA	{"phone": "+70491395905"}
0005433344375	DBAD6A	4182 192653	ALEKSANDR KOROLEV	{"email": "aleksandrkorolev-31051971@postgrespro.ru", "phone": "+70318416382"}
0005433344376	DBAD6A	0105 011909	VITALIY VOLKOV	{"email": "volkov_vitaliy11091977@postgrespro.ru", "phone": "+70870886418"}
0005433344377	2C046F	7223 745612	IRINA MAKAROVA	{"phone": "+70329970276"}
0005433344378	2C046F	6033 737260	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr.111970@postgrespro.ru", "phone": "+70026117521"}
0005433344379	414D91	4670 210283	SVETLANA KOZLOVA	{"email": "kozlova.s_03021962@postgrespro.ru", "phone": "+70328826737"}
0005433344380	414D91	3156 079263	ANNA BORISOVA	{"email": "anna.borisova.1967@postgrespro.ru", "phone": "+70475637356"}
0005433344381	414D91	9060 234772	ANDREY FEDOTOV	{"phone": "+70768885912"}
0005433344382	746183	6333 897380	VADIM KOROLEV	{"phone": "+70338351779"}
0005433344383	2018FD	4046 559745	YURIY GAVRILOV	{"email": "gavrilov-y-1971@postgrespro.ru", "phone": "+70255089839"}
0005433344384	5B4B24	0433 472006	ILYA IVANOV	{"email": "ivanov_i_111975@postgrespro.ru", "phone": "+70675435705"}
0005433344385	5B4B24	5394 553183	DMITRIY TIMOFEEV	{"email": "timofeev-dmitriy-1971@postgrespro.ru", "phone": "+70148675311"}
0005433344386	C3ED1A	5126 346370	ZOYA IVANOVA	{"email": "z-ivanova1967@postgrespro.ru", "phone": "+70307817553"}
0005433344387	19769D	8397 497557	NIKOLAY IVANOV	{"email": "ivanovnikolay-16071966@postgrespro.ru", "phone": "+70958123888"}
0005433344388	1F8FBC	6636 072601	ANDREY PETROV	{"email": "andrey_petrov-11091966@postgrespro.ru", "phone": "+70558750057"}
0005433344389	2FDE8F	5330 581042	TAMARA NIKIFOROVA	{"phone": "+70211277241"}
0005433344390	ECA6C0	2870 331026	SERGEY VOLKOV	{"phone": "+70444631038"}
0005433344391	ECA6C0	6290 378834	ELENA MATVEEVA	{"phone": "+70306280376"}
0005433344392	B995B6	1116 879056	SERGEY DENISOV	{"phone": "+70002911266"}
0005433344393	2B7F1F	4608 838891	ELENA KOROLEVA	{"email": "koroleva-elena-11031975@postgrespro.ru", "phone": "+70458864342"}
0005433344394	1BB24F	7205 032784	MAKSIM SMIRNOV	{"phone": "+70085930024"}
0005433344395	1BB24F	2608 011342	VASILIY POPOV	{"email": "popov-vasiliy-041981@postgrespro.ru", "phone": "+70718323368"}
0005433344396	F7EF58	7921 260021	ALLA KALININA	{"phone": "+70584115701"}
0005433344397	F7EF58	4179 483378	EVGENIYA KONOVALOVA	{"phone": "+70773484472"}
0005433344398	37C2BB	6794 787048	MARIYA LEBEDEVA	{"phone": "+70172234709"}
0005433344399	0EF798	1304 461893	DARYA VASILEVA	{"email": "d_vasileva.30071978@postgrespro.ru", "phone": "+70700394502"}
0005433344400	C5BAB2	2061 481994	IRINA ALEKSEEVA	{"phone": "+70261167062"}
0005433344401	7B6D7B	4282 568641	VALENTINA NAUMOVA	{"phone": "+70279540014"}
0005433344402	8AF30B	5473 444043	NADEZHDA MOROZOVA	{"email": "nadezhda.morozova_1974@postgrespro.ru", "phone": "+70749052404"}
0005433344403	71ACE6	1124 642866	OLGA KUZNECOVA	{"phone": "+70562762806"}
0005433344404	3AD067	1605 320617	VLADIMIR ANTONOV	{"phone": "+70414948033"}
0005433344405	D2137E	7522 842618	ALLA POTAPOVA	{"email": "potapovaa_1974@postgrespro.ru", "phone": "+70372456842"}
0005433344406	DC30F8	0335 838635	GALINA PAVLOVA	{"phone": "+70851275943"}
0005433344407	DC30F8	6547 598834	MARIYA CHERNOVA	{"email": "mchernova.091966@postgrespro.ru", "phone": "+70422109957"}
0005433344408	DBB777	8845 679844	KONSTANTIN IVANOV	{"email": "k-ivanov_111971@postgrespro.ru", "phone": "+70518631204"}
0005433344409	3AA4C5	0432 854394	ALEKSANDR ZAKHAROV	{"email": "zakharov.a_14101975@postgrespro.ru", "phone": "+70193260956"}
0005433344410	91426F	9672 135328	LIDIYA ANISIMOVA	{"email": "anisimova_lidiya-1981@postgrespro.ru", "phone": "+70258359176"}
0005433344411	65DC72	8464 763214	GLEB SIDOROV	{"phone": "+70712437264"}
0005433344412	956A24	9689 116720	NIKOLAY NAUMOV	{"phone": "+70853812750"}
0005433344413	78BB08	3845 102269	ALBERT SOROKIN	{"email": "sorokin_a1972@postgrespro.ru", "phone": "+70055104665"}
0005433344414	118012	5275 626429	DMITRIY ANTONOV	{"phone": "+70903682945"}
0005433344415	B7E126	9696 659197	EKATERINA SOKOLOVA	{"email": "sokolovae_1987@postgrespro.ru", "phone": "+70125769133"}
0005433344416	F8E18B	4912 711652	TATYANA ZAKHAROVA	{"email": "zakharova.tatyana_20121969@postgrespro.ru", "phone": "+70907195760"}
0005433344417	F9AFE4	0516 302608	KONSTANTIN MELNIKOV	{"email": "melnikov_k-091975@postgrespro.ru", "phone": "+70332610039"}
0005433344418	C4C166	2240 864076	VLADIMIR SOROKIN	{"email": "sorokin.vladimir-1956@postgrespro.ru", "phone": "+70376886300"}
0005433344419	89166D	3484 705948	TATYANA FADEEVA	{"phone": "+70653284577"}
0005433344420	E5A084	7069 573550	ELENA BOGDANOVA	{"email": "bogdanovaelena.26111968@postgrespro.ru", "phone": "+70033514055"}
0005433344421	169D32	1486 970934	ARTEM GERASIMOV	{"email": "gerasimov-a-07011972@postgrespro.ru", "phone": "+70795103798"}
0005433344422	169D32	1068 584405	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.011971@postgrespro.ru", "phone": "+70879096106"}
0005433344423	47BF27	0532 557206	OLGA DENISOVA	{"email": "denisova-olga_1985@postgrespro.ru", "phone": "+70406142828"}
0005433344424	958A22	6398 093514	DARYA FROLOVA	{"phone": "+70981250400"}
0005433344425	958A22	7058 943615	EVGENIY OSIPOV	{"phone": "+70737924523"}
0005433344426	DD225A	7027 025179	VERA PETROVA	{"email": "verapetrova1970@postgrespro.ru", "phone": "+70818610972"}
0005433344427	283A58	7298 153983	YURIY DMITRIEV	{"email": "ydmitriev_21011971@postgrespro.ru", "phone": "+70646065922"}
0005433344428	0EB4BC	2560 798297	NATALYA GUSEVA	{"email": "n.guseva.1986@postgrespro.ru", "phone": "+70096112019"}
0005433344429	490914	5577 610795	TATYANA KUZNECOVA	{"email": "t_kuznecova-031978@postgrespro.ru", "phone": "+70886054336"}
0005433344430	8231C9	6429 337715	NIKOLAY TIMOFEEV	{"email": "nikolay-timofeev_011975@postgrespro.ru", "phone": "+70087656633"}
0005433344431	8231C9	0619 448764	EGOR BELOV	{"phone": "+70890034616"}
0005433344432	8231C9	0694 643846	NINA EGOROVA	{"email": "n.egorova061973@postgrespro.ru", "phone": "+70959550417"}
0005433344433	F0A08A	0057 323726	ANATOLIY SOROKIN	{"phone": "+70380311032"}
0005433344434	49FEFF	8291 134928	ANNA STEPANOVA	{"phone": "+70773455830"}
0005433344435	49FEFF	4614 787690	ALEKSEY ANDREEV	{"email": "andreev.aleksey.111988@postgrespro.ru", "phone": "+70398339191"}
0005433344436	49FEFF	3584 481866	OLESYA LUKYANOVA	{"email": "olesya_lukyanova-011961@postgrespro.ru", "phone": "+70325756904"}
0005433344437	FEB583	2186 659173	ANTONINA KRASNOVA	{"phone": "+70086777113"}
0005433344438	B0DB11	5970 057472	NINA ISAEVA	{"email": "isaeva-n.25101960@postgrespro.ru", "phone": "+70486022502"}
0005433344439	5DF173	5489 335788	IVAN ILIN	{"email": "ilini-28021959@postgrespro.ru", "phone": "+70670945185"}
0005433344440	0E3043	5593 661620	TATYANA DAVYDOVA	{"email": "davydovatatyana.1966@postgrespro.ru", "phone": "+70509569200"}
0005433344441	0E3043	7299 620446	LYUBOV GUSEVA	{"email": "gusevalyubov1966@postgrespro.ru", "phone": "+70329081045"}
0005433344442	DAAF5F	9040 842560	ANATOLIY VOROBEV	{"email": "anatoliy_vorobev-111973@postgrespro.ru", "phone": "+70909524817"}
0005433344443	B41030	5945 579708	EKATERINA ROMANOVA	{"email": "romanova.ekaterina26071971@postgrespro.ru", "phone": "+70848204759"}
0005433344444	B41030	3003 082433	ALEKSANDR TIKHONOV	{"phone": "+70177954212"}
0005433344445	7B167A	8765 447942	MARIYA SIDOROVA	{"phone": "+70998676926"}
0005433344446	580FC9	7836 622772	NATALIYA VASILEVA	{"email": "vasileva.n-061973@postgrespro.ru", "phone": "+70621700786"}
0005433344447	86F0DA	5589 978372	ELENA KUZNECOVA	{"email": "kuznecova-e061964@postgrespro.ru", "phone": "+70421494133"}
0005433344448	67E248	2250 957375	VLADIMIR NIKITIN	{"phone": "+70745484603"}
0005433344449	B0051A	4534 720675	DARYA FEDOROVA	{"phone": "+70545135522"}
0005433344450	3817E2	9830 289573	ALEKSANDR ZHURAVLEV	{"phone": "+70693981229"}
0005433344451	6EE827	4902 992992	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana_1975@postgrespro.ru", "phone": "+70767214613"}
0005433344452	6EE827	2790 008207	ALEKSANDR KRASNOV	{"email": "a-krasnov_071964@postgrespro.ru", "phone": "+70885242645"}
0005433344453	58E2EA	7931 768481	GALINA SEMENOVA	{"email": "g.semenova_071964@postgrespro.ru", "phone": "+70081226880"}
0005433344454	58E2EA	6716 494631	MAKSIM MEDVEDEV	{"phone": "+70212298778"}
0005433344455	5F78BF	0705 989558	ANASTASIYA NIKIFOROVA	{"phone": "+70621003483"}
0005433344456	5F78BF	4190 607946	NIKOLAY VASILEV	{"phone": "+70992443324"}
0005433344457	E38CE0	8070 868922	MARINA ZAYCEVA	{"phone": "+70195555156"}
0005433344458	E38CE0	8853 007583	ALEKSANDRA PETROVA	{"phone": "+70273309796"}
0005433344459	1D9DA1	0282 003322	NINA IVANOVA	{"email": "ivanova_nina.1966@postgrespro.ru", "phone": "+70666966152"}
0005433344460	A9029B	3083 422343	ANATOLIY TIMOFEEV	{"email": "anatoliy-timofeev1965@postgrespro.ru", "phone": "+70092961327"}
0005433344461	D0E011	2061 605961	ILYA SOROKIN	{"email": "sorokini.071979@postgrespro.ru", "phone": "+70578529710"}
0005433344462	78E6D8	3831 126920	SERGEY BARANOV	{"phone": "+70819464562"}
0005433344463	2898FC	6621 081799	ALEKSEY FEDOROV	{"email": "fedorov-aleksey_06061973@postgrespro.ru", "phone": "+70486689566"}
0005433344464	2898FC	1052 807746	TATYANA KAZAKOVA	{"email": "tkazakova.26011974@postgrespro.ru", "phone": "+70020070933"}
0005433344465	2898FC	5196 480157	ELIZAVETA PAVLOVA	{"email": "pavlova.elizaveta_031981@postgrespro.ru", "phone": "+70816526680"}
0005433344466	21D97B	6476 411650	VLADIMIR STEPANOV	{"email": "vladimir.stepanov1989@postgrespro.ru", "phone": "+70307792374"}
0005433344467	2A4E97	3189 689726	ZINAIDA STEPANOVA	{"phone": "+70179805970"}
0005433344468	ED94BB	8153 030252	NADEZHDA GRISHINA	{"phone": "+70141069314"}
0005433344469	C9DBD1	3522 442933	DANIIL NIKOLAEV	{"email": "d_nikolaev.101976@postgrespro.ru", "phone": "+70226135267"}
0005433344470	C9DBD1	7786 126129	IVAN MOROZOV	{"email": "i_morozov-1978@postgrespro.ru", "phone": "+70014665290"}
0005433344471	B46FD3	2675 608954	ALEKSANDR ANDREEV	{"phone": "+70198569627"}
0005433344472	B46FD3	7472 258903	KRISTINA MOROZOVA	{"phone": "+70798502043"}
0005433344473	B67452	0779 524841	KONSTANTIN SAVELEV	{"email": "savelevkonstantin.011967@postgrespro.ru", "phone": "+70314409105"}
0005433344474	B67452	3509 282300	YURIY ISAEV	{"phone": "+70905821937"}
0005433344475	668003	5064 766081	SERGEY FILIPPOV	{"phone": "+70207052633"}
0005433344476	64D8CA	4442 824819	NATALYA ALEKSEEVA	{"phone": "+70363829010"}
0005433344477	876544	0669 825936	OLGA DAVYDOVA	{"phone": "+70477265905"}
0005433344478	876544	6236 410496	MIKHAIL KUZNECOV	{"phone": "+70322950491"}
0005433344479	866AA3	6681 793672	VLADIMIR BELOV	{"phone": "+70775288829"}
0005433344480	866AA3	1339 045657	ANTONINA SAVELEVA	{"email": "antonina.saveleva_29081958@postgrespro.ru", "phone": "+70132271662"}
0005433344481	866AA3	8119 062070	VASILIY EGOROV	{"email": "v_egorov14101969@postgrespro.ru", "phone": "+70116767298"}
0005433344482	1BDB23	8800 386110	KIRILL STEPANOV	{"email": "stepanovk-1967@postgrespro.ru", "phone": "+70252684212"}
0005433344483	1BDB23	5218 924571	OLGA ZAKHAROVA	{"email": "ozakharova_1970@postgrespro.ru", "phone": "+70119834214"}
0005433344484	05AF8C	0537 513495	VITALIY BORISOV	{"email": "vborisov1970@postgrespro.ru", "phone": "+70191098072"}
0005433344485	05AF8C	2267 852046	DMITRIY KRASNOV	{"email": "d.krasnov1964@postgrespro.ru", "phone": "+70801563314"}
0005433344486	8A4CDC	4847 377664	SERGEY DAVYDOV	{"phone": "+70320408929"}
0005433344487	1063ED	3718 947206	RENATA NESTEROVA	{"email": "r_nesterova_101966@postgrespro.ru", "phone": "+70127938953"}
0005433344488	E711AF	0402 235312	OLGA MAKAROVA	{"email": "makarovao.031983@postgrespro.ru", "phone": "+70577475332"}
0005433344489	E711AF	4836 803033	LYUBOV ROMANOVA	{"email": "lyubov-romanova1970@postgrespro.ru", "phone": "+70434784962"}
0005433344490	064FD1	8054 639910	EGOR SCHERBAKOV	{"phone": "+70597023242"}
0005433344491	234EDA	6401 682651	GUZEL KUZNECOVA	{"phone": "+70432086834"}
0005433344492	92A711	3938 646770	NATALYA POPOVA	{"phone": "+70467255294"}
0005433344493	3C83EF	2577 306555	NINA SIDOROVA	{"email": "n_sidorova_12121975@postgrespro.ru", "phone": "+70500759569"}
0005433344494	3C83EF	9225 538832	VALERIY PAVLOV	{"phone": "+70496958706"}
0005433344495	E0A3E4	0849 900277	LARISA SERGEEVA	{"phone": "+70450049710"}
0005433344496	B8606B	4089 044015	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr_10011974@postgrespro.ru", "phone": "+70270934234"}
0005433344497	3E0BD5	1107 576065	NIKOLAY RODIONOV	{"phone": "+70344823759"}
0005433344498	3E0BD5	3348 759092	SERGEY KUZNECOV	{"phone": "+70204889273"}
0005433344499	EAAB01	8460 177842	NINA OVCHINNIKOVA	{"email": "nina.ovchinnikova.071973@postgrespro.ru", "phone": "+70265861040"}
0005433344500	EAAB01	0478 697628	VLADIMIR GERASIMOV	{"phone": "+70764599598"}
0005433344501	888D67	5269 529295	ELENA OVCHINNIKOVA	{"phone": "+70454042091"}
0005433344502	E49580	1710 287779	VLADIMIR KAZAKOV	{"phone": "+70749880342"}
0005433344503	F8A053	5107 995803	STEPAN MOISEEV	{"email": "s-moiseev_041972@postgrespro.ru", "phone": "+70948209365"}
0005433344504	EC9944	9513 379048	PETR ROMANOV	{"phone": "+70532662600"}
0005433344505	EC9944	0315 683303	ALEKSEY BARANOV	{"email": "aleksey.baranov-18051962@postgrespro.ru", "phone": "+70867755808"}
0005433344506	EC9944	6264 786865	EVGENIY SMIRNOV	{"phone": "+70407986584"}
0005433344507	F3191D	3045 765969	KARINA ISAEVA	{"email": "isaeva_k_101966@postgrespro.ru", "phone": "+70088260098"}
0005433344508	423EA0	1928 430989	VALENTINA KOZLOVA	{"phone": "+70633981119"}
0005433344509	9C2794	8852 443252	VASILIY ROMANOV	{"phone": "+70670942322"}
0005433344510	5616E7	2317 124797	VALENTIN VLASOV	{"email": "vlasov_valentin12101973@postgrespro.ru", "phone": "+70400171918"}
0005433344511	18735E	9843 475958	SERGEY SMIRNOV	{"phone": "+70880848244"}
0005433344512	181BF7	0075 431815	NINA SOROKINA	{"email": "ninasorokina_16041974@postgrespro.ru", "phone": "+70656675499"}
0005433344513	DDEFDC	0890 535768	MARIYA BELOVA	{"phone": "+70025660912"}
0005433344514	88D847	0463 318272	VLADIMIR PETROV	{"email": "petrov-v.021980@postgrespro.ru", "phone": "+70873153299"}
0005433344515	221D0E	3963 677280	DZHAMILYA GRISHINA	{"phone": "+70195996387"}
0005433344516	221D0E	5318 551973	EVGENIYA VOLKOVA	{"email": "e.volkova03071973@postgrespro.ru", "phone": "+70657079878"}
0005433344517	7077E1	2595 842299	VASILIY KONOVALOV	{"phone": "+70685109415"}
0005433344518	CE56E1	1811 332016	ALISA KOLESNIKOVA	{"phone": "+70098069358"}
0005433344519	F39CF4	0506 000842	KRISTINA NESTEROVA	{"phone": "+70953822621"}
0005433344520	F39CF4	3755 035938	SERGEY SIDOROV	{"phone": "+70795418307"}
0005433344521	0F778B	3450 339180	LARISA VOROBEVA	{"phone": "+70342294632"}
0005433344522	DEF39E	1370 679250	ANASTASIYA KUDRYASHOVA	{"email": "a-kudryashova.111980@postgrespro.ru", "phone": "+70404501807"}
0005433344523	DEF39E	9437 051163	VERONIKA KUZMINA	{"phone": "+70660931736"}
0005433344524	3B991C	4174 685939	VALENTIN VOROBEV	{"phone": "+70663260480"}
0005433344525	9C1842	4049 559039	SVETLANA VOLKOVA	{"phone": "+70940846508"}
0005433344526	F222D8	0240 321484	ALEKSANDR IVANOV	{"phone": "+70889356852"}
0005433344527	F66167	4507 268274	IRINA ANDREEVA	{"email": "andreeva-irina-1986@postgrespro.ru", "phone": "+70540737684"}
0005433344528	F66167	8585 449906	ANATOLIY NOVIKOV	{"phone": "+70666783824"}
0005433344529	27F40B	7535 931504	SERGEY STEPANOV	{"email": "sstepanov_1976@postgrespro.ru", "phone": "+70712758660"}
0005433344530	27F40B	4307 954955	EVGENIY NIKOLAEV	{"email": "e_nikolaev_19081973@postgrespro.ru", "phone": "+70091966606"}
0005433344531	D17F44	8275 855896	VALERIY KAZAKOV	{"email": "v-kazakov.101978@postgrespro.ru", "phone": "+70848998284"}
0005433344532	14B398	0673 978621	VLADIMIR MAKAROV	{"phone": "+70548425934"}
0005433344533	14B398	2085 143727	ALEKSEY KOZLOV	{"email": "kozlovaleksey-081983@postgrespro.ru", "phone": "+70223183968"}
0005433344534	C9C3D0	0529 575395	OLGA KUZMINA	{"email": "olga_kuzmina.1965@postgrespro.ru", "phone": "+70770529260"}
0005433344535	C9C3D0	3928 413649	TATYANA RODIONOVA	{"phone": "+70711766954"}
0005433344536	D4A32F	3306 803482	OKSANA DAVYDOVA	{"email": "davydovaoksana.12061961@postgrespro.ru", "phone": "+70085750449"}
0005433344537	D4A32F	2869 871436	PETR ABRAMOV	{"email": "pabramov.031959@postgrespro.ru", "phone": "+70473370338"}
0005433344538	D1118A	1266 824899	LYUBOV SIDOROVA	{"phone": "+70494361314"}
0005433344539	D1118A	2157 647405	ANASTASIYA GUSEVA	{"phone": "+70874654365"}
0005433344540	519CCD	5801 745071	VLADIMIR IVANOV	{"email": "v-ivanov.011962@postgrespro.ru", "phone": "+70263023564"}
0005433344541	A93B88	1187 086020	VITALIY POPOV	{"email": "vitaliypopov_11111964@postgrespro.ru", "phone": "+70987065362"}
0005433344542	A7C224	1365 051785	LIDIYA BOGDANOVA	{"phone": "+70508871409"}
0005433344543	A7C224	0816 592702	NIKITA DAVYDOV	{"phone": "+70471909701"}
0005433344544	687AC6	0336 582077	NATALYA EGOROVA	{"phone": "+70849885969"}
0005433344545	687AC6	8357 983799	VLADIMIR KOZLOV	{"email": "v-kozlov_1987@postgrespro.ru", "phone": "+70508846738"}
0005433344546	DB316B	0925 415039	ALEKSEY VOROBEV	{"email": "vorobev.a021977@postgrespro.ru", "phone": "+70425453146"}
0005433344547	B629D5	0924 111739	NIKOLAY ZHUKOV	{"email": "n-zhukov-06071968@postgrespro.ru", "phone": "+70774826320"}
0005433344548	B629D5	5375 716203	ELENA IVANOVA	{"phone": "+70623410628"}
0005433344549	9566C6	9788 357652	SVETLANA KONOVALOVA	{"phone": "+70465634252"}
0005433344550	AE3C69	4812 269496	NATALIYA NIKOLAEVA	{"email": "n-nikolaeva_1966@postgrespro.ru", "phone": "+70899908758"}
0005433344551	AE3C69	1033 755831	VASILIY OSIPOV	{"email": "osipovv_071968@postgrespro.ru", "phone": "+70385971338"}
0005433344552	D0A33D	7223 303247	NATALYA FROLOVA	{"phone": "+70826944111"}
0005433344553	A0F9C9	9559 497814	SERGEY SMIRNOV	{"email": "s-smirnov_1960@postgrespro.ru", "phone": "+70098758141"}
0005433344554	A0F9C9	3922 446356	LYUDMILA SOROKINA	{"phone": "+70715707868"}
0005433344555	7F21CE	3165 564575	DANIL MEDVEDEV	{"email": "medvedev_d1984@postgrespro.ru", "phone": "+70756639741"}
0005433344556	8C8231	0092 752001	SNEZHANA MAKSIMOVA	{"phone": "+70161713313"}
0005433344557	8C8231	2815 655138	TATYANA ZHURAVLEVA	{"email": "zhuravlevatatyana_28011971@postgrespro.ru", "phone": "+70506688972"}
0005433344558	C29FF7	2986 553692	SERGEY NIKITIN	{"email": "s-nikitin_02091975@postgrespro.ru", "phone": "+70435648723"}
0005433344559	B7633F	9701 122683	ALEKSANDR MAKSIMOV	{"phone": "+70844827524"}
0005433344560	F8BCE4	4864 002697	YULIYA MELNIKOVA	{"phone": "+70070332838"}
0005433344561	F8BCE4	8771 166704	ALEKSANDR ZHURAVLEV	{"email": "a_zhuravlev011969@postgrespro.ru", "phone": "+70707583819"}
0005433344562	F8BCE4	2561 373104	ASKHAT MAKAROV	{"email": "makarovaskhat_1965@postgrespro.ru", "phone": "+70801189771"}
0005433344563	47573F	2877 346166	GALINA NAZAROVA	{"email": "nazarova.galina1971@postgrespro.ru", "phone": "+70463216951"}
0005433344564	47573F	0835 663512	DMITRIY IVANOV	{"email": "dmitriy.ivanov_071977@postgrespro.ru", "phone": "+70404329972"}
0005433344565	280847	0592 432792	ALEKSANDR ANDREEV	{"phone": "+70144253425"}
0005433344566	B72EBB	1667 917324	NATALYA LEBEDEVA	{"phone": "+70386963429"}
0005433344567	A259A0	9411 225174	GENNADIY IVANOV	{"email": "ivanovgennadiy.07061975@postgrespro.ru", "phone": "+70554965489"}
0005433344568	0F1B73	6997 949810	LYUBOV GAVRILOVA	{"phone": "+70255559989"}
0005433344569	67259D	5831 565353	ALEKSANDR FEDOTOV	{"email": "a_fedotov_20091973@postgrespro.ru", "phone": "+70069298797"}
0005433344570	1949EE	6651 807108	LIDIYA STEPANOVA	{"email": "lidiya-stepanova-1967@postgrespro.ru", "phone": "+70365336642"}
0005433344571	632780	6450 042414	VERA EFIMOVA	{"email": "v-efimova091975@postgrespro.ru", "phone": "+70178874058"}
0005433344572	632780	4775 198517	YURIY SMIRNOV	{"email": "smirnovy.06031965@postgrespro.ru", "phone": "+70321286658"}
0005433344573	CAB8C5	0207 525023	OLEG VLASOV	{"email": "vlasov_oleg061974@postgrespro.ru", "phone": "+70885072010"}
0005433344574	DA0434	4470 996304	VLADIMIR KULIKOV	{"phone": "+70510630671"}
0005433344575	03BB11	9120 484129	MAKSIM BARANOV	{"phone": "+70684475545"}
0005433344576	03BB11	8447 148228	SERGEY KOZLOV	{"email": "sergey_kozlov.1964@postgrespro.ru", "phone": "+70603264399"}
0005433344577	03BB11	3770 128973	MAKSIM FEDOTOV	{"email": "fedotovm.1968@postgrespro.ru", "phone": "+70042440174"}
0005433344578	3FABD2	4171 347583	ALEKSANDR ABRAMOV	{"phone": "+70067802831"}
0005433344579	902C1F	8106 986733	ELENA FILIPPOVA	{"phone": "+70964405870"}
0005433344580	902C1F	7963 743155	ALEKSANDR FOMIN	{"email": "aleksandrfomin.09111965@postgrespro.ru", "phone": "+70653943742"}
0005433344581	902C1F	2190 589564	VIKTOR VASILEV	{"email": "vasilev_viktor1977@postgrespro.ru", "phone": "+70099355366"}
0005433344582	0C09A7	9221 887756	ANATOLIY ZAYCEV	{"email": "a.zaycev_1976@postgrespro.ru", "phone": "+70090639491"}
0005433344583	0C09A7	8274 354739	MAKSIM VOROBEV	{"email": "vorobev-m-17051962@postgrespro.ru", "phone": "+70495804027"}
0005433344584	57DC68	8013 729965	SERGEY POPOV	{"email": "popovsergey25011979@postgrespro.ru", "phone": "+70927461324"}
0005433344585	0BFC46	8570 179118	LYUBOV ISAEVA	{"email": "l-isaeva-04061970@postgrespro.ru", "phone": "+70358446345"}
0005433344586	9779F4	7347 015576	ELIZAVETA IVANOVA	{"email": "elizavetaivanova.1980@postgrespro.ru", "phone": "+70210926124"}
0005433344587	9779F4	3391 848890	OLEG SOKOLOV	{"email": "sokolovoleg011979@postgrespro.ru", "phone": "+70996884514"}
0005433344588	BD8200	9710 722558	NIKITA PETROV	{"phone": "+70984196979"}
0005433344589	DA419A	7764 349982	RAMIL FROLOV	{"phone": "+70632722173"}
0005433344590	DA419A	1569 591707	GALINA MARTYNOVA	{"email": "martynova_g.1971@postgrespro.ru", "phone": "+70161487367"}
0005433344591	DA419A	9972 392057	ZOYA BORISOVA	{"phone": "+70558981388"}
0005433344592	4C48B8	7186 126004	ANASTASIYA KONOVALOVA	{"phone": "+70826810055"}
0005433344593	41F324	3794 241627	EVDOKIYA MAKAROVA	{"phone": "+70980579962"}
0005433344594	C9A0BD	1527 325177	VALENTINA ANDREEVA	{"email": "v-andreeva-02081968@postgrespro.ru", "phone": "+70377260413"}
0005433344595	967457	2508 673022	VALENTINA NESTEROVA	{"phone": "+70791817281"}
0005433344596	38B24E	3376 264746	LYUBOV KUDRYASHOVA	{"phone": "+70783852141"}
0005433344597	FB4C60	9870 885711	ILYA YAKOVLEV	{"phone": "+70519692857"}
0005433344598	F0FD3E	8482 511628	NADEZHDA NESTEROVA	{"phone": "+70346974072"}
0005433344599	7C6A01	4706 613817	VLADIMIR DAVYDOV	{"email": "vladimir.davydov14031978@postgrespro.ru", "phone": "+70978631005"}
0005433344600	7C6A01	8482 539967	PAVEL OSIPOV	{"email": "osipov-p.1981@postgrespro.ru", "phone": "+70364537407"}
0005433344601	46B0F2	5279 166724	TATYANA STEPANOVA	{"email": "tatyana.stepanova.1972@postgrespro.ru", "phone": "+70699078758"}
0005433344602	46B0F2	7518 430343	KSENIYA ORLOVA	{"email": "k_orlova041966@postgrespro.ru", "phone": "+70585420475"}
0005433344603	46B0F2	9326 636427	INNA ERMAKOVA	{"email": "ermakova.i08031976@postgrespro.ru", "phone": "+70107787492"}
0005433344604	94FD1E	4744 057359	ZHANNA POPOVA	{"email": "popova-zhanna_1966@postgrespro.ru", "phone": "+70306373300"}
0005433344605	54128D	6471 509585	RISHAT MAKAROV	{"email": "rishat_makarov_061981@postgrespro.ru", "phone": "+70571237571"}
0005433344606	7130B7	9940 683402	GALINA KOROLEVA	{"phone": "+70209421975"}
0005433344607	7130B7	6922 920603	ALBINA NIKITINA	{"email": "a.nikitina_23051968@postgrespro.ru", "phone": "+70056222760"}
0005433344608	C6AC38	4697 245235	ILYA ZAKHAROV	{"phone": "+70884708973"}
0005433344609	C6AC38	4064 869582	ANASTASIYA GERASIMOVA	{"email": "gerasimova_a-12091974@postgrespro.ru", "phone": "+70600173994"}
0005433344610	85E935	4847 205057	LYUDMILA VLASOVA	{"email": "vlasoval-1978@postgrespro.ru", "phone": "+70371576293"}
0005433344611	55A82E	3215 393330	VIKTOR VOROBEV	{"phone": "+70476030820"}
0005433344612	A9713F	2164 130124	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_svetlana.021963@postgrespro.ru", "phone": "+70838571568"}
0005433344613	CC32AA	0739 807067	RAISA SOLOVEVA	{"phone": "+70206939222"}
0005433344614	571A18	9076 347241	DMITRIY SMIRNOV	{"phone": "+70127309406"}
0005433344615	571A18	9318 940528	NATALYA GAVRILOVA	{"phone": "+70501439529"}
0005433344616	582BA5	9391 591837	SVETLANA RODIONOVA	{"email": "s_rodionova_04111974@postgrespro.ru", "phone": "+70519137724"}
0005433344617	582BA5	6208 965711	MARIYA KRASNOVA	{"email": "krasnova-m-071971@postgrespro.ru", "phone": "+70681326170"}
0005433344618	2AB285	9960 715477	SVETLANA KULIKOVA	{"email": "kulikova-svetlana23051972@postgrespro.ru", "phone": "+70996464269"}
0005433344619	928C13	3600 000682	PAVEL DMITRIEV	{"phone": "+70098979245"}
0005433344620	BCAE60	5440 158401	ARTEM BORISOV	{"phone": "+70077067799"}
0005433344621	8730AE	5834 611991	TATYANA VASILEVA	{"email": "vasileva.tatyana_10081971@postgrespro.ru", "phone": "+70858443757"}
0005433344622	24F4AB	8187 739210	NINA CHERNOVA	{"phone": "+70081712264"}
0005433344623	23AF70	1760 428719	TATYANA ZHURAVLEVA	{"phone": "+70560001485"}
0005433344624	D69793	6718 951107	ALEKSANDR GORBUNOV	{"email": "gorbunov.a04121960@postgrespro.ru", "phone": "+70916550865"}
0005433344625	CCF7F2	2719 320976	VLADISLAV FILIPPOV	{"phone": "+70085782456"}
0005433344626	CCF7F2	8197 561453	VADIM SIDOROV	{"email": "vadim.sidorov-021972@postgrespro.ru", "phone": "+70575955846"}
0005433344627	CCF7F2	8815 594291	PAVEL KRASNOV	{"email": "krasnov.p_15011974@postgrespro.ru", "phone": "+70323776113"}
0005433344628	CCF7F2	4240 636995	VALENTIN STEPANOV	{"phone": "+70202817882"}
0005433344629	5F4E6D	8230 385855	VLADIMIR ALEKSEEV	{"phone": "+70087927851"}
0005433344630	5F4E6D	8744 570033	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_041965@postgrespro.ru", "phone": "+70570948469"}
0005433344631	5F4E6D	7093 737604	ILYA ILIN	{"phone": "+70620229546"}
0005433344632	E5A932	1793 752714	ANTONINA KUDRYASHOVA	{"phone": "+70590256183"}
0005433344633	5299AC	8611 784456	ELENA CHERNOVA	{"email": "elena.chernova-031971@postgrespro.ru", "phone": "+70755367736"}
0005433344634	72F7EE	3754 444085	NIKOLAY ZHUKOV	{"phone": "+70427712541"}
0005433344635	82CC2A	8104 730999	SVETLANA KOZLOVA	{"email": "svetlana-kozlova-1979@postgrespro.ru", "phone": "+70386414361"}
0005433344636	2AFFAD	9045 097937	ALEKSEY SEMENOV	{"email": "semenova.18101978@postgrespro.ru", "phone": "+70121310710"}
0005433344637	70F4C1	6661 805413	VLADIMIR KUZNECOV	{"phone": "+70236003813"}
0005433344638	1DF97B	4384 049067	LYUDMILA GAVRILOVA	{"email": "lyudmila-gavrilova_1961@postgrespro.ru", "phone": "+70913380202"}
0005433344639	097078	8090 408468	EVGENIY MARTYNOV	{"phone": "+70471539386"}
0005433344640	083DFB	6570 318784	YULIYA KARPOVA	{"phone": "+70106148456"}
0005433344641	083DFB	0023 493883	VALENTINA KUZNECOVA	{"phone": "+70110222941"}
0005433344642	F56309	2587 369389	VALERIY VASILEV	{"email": "valeriy-vasilev-1972@postgrespro.ru", "phone": "+70297756174"}
0005433344643	F56309	7323 584574	GALINA IVANOVA	{"email": "ivanova_g_011988@postgrespro.ru", "phone": "+70639233120"}
0005433344644	F56309	4950 787046	EKATERINA FILATOVA	{"email": "filatova-ekaterina.03071970@postgrespro.ru", "phone": "+70817564846"}
0005433344645	588FA0	7995 868183	DANILA KISELEV	{"email": "kiselev-d_1980@postgrespro.ru", "phone": "+70838192957"}
0005433344646	CD030E	8972 796044	SVETLANA LUKYANOVA	{"email": "s.lukyanova-1964@postgrespro.ru", "phone": "+70305043279"}
0005433344647	5D1905	9985 831005	OLEG MATVEEV	{"phone": "+70031674548"}
0005433344648	2D0205	8550 955359	LYUDMILA LEBEDEVA	{"email": "lebedeva.l1961@postgrespro.ru", "phone": "+70772292478"}
0005433344649	2D0205	6444 442219	KSENIYA MATVEEVA	{"email": "kseniya-matveeva_1970@postgrespro.ru", "phone": "+70269980836"}
0005433344650	76F941	1408 274784	NATALYA NAUMOVA	{"phone": "+70017375505"}
0005433344651	CA24AF	6640 449142	VALENTINA KULIKOVA	{"email": "kulikova-v-111973@postgrespro.ru", "phone": "+70450654891"}
0005433344652	22D1C8	9632 852345	IRINA NAUMOVA	{"email": "naumova.i-1978@postgrespro.ru", "phone": "+70707156499"}
0005433344653	CCD361	5682 322795	MARIYA ANTONOVA	{"phone": "+70650565602"}
0005433344654	226275	5364 740838	VLADIMIR IVANOV	{"email": "v-ivanov-021978@postgrespro.ru", "phone": "+70321696867"}
0005433344655	8F177F	9565 578633	TAMARA LEBEDEVA	{"phone": "+70326168782"}
0005433344656	1F9FD0	9892 769026	SANIYA MELNIKOVA	{"email": "melnikova.saniya-23081968@postgrespro.ru", "phone": "+70783056675"}
0005433344657	3C27D3	1885 391581	ANDREY POPOV	{"phone": "+70178757211"}
0005433344658	B951EC	8347 572909	RENAT PAVLOV	{"phone": "+70013067704"}
0005433344659	3E5E5C	6195 214437	ALEKSANDR SIDOROV	{"phone": "+70027865504"}
0005433344660	C91150	6179 722519	ANTON AFANASEV	{"email": "afanasev_anton.091971@postgrespro.ru", "phone": "+70523516298"}
0005433344661	AD66BD	3966 516564	NIKOLAY NAZAROV	{"phone": "+70991729919"}
0005433344662	96E0F7	5545 689495	DARYA GUSEVA	{"phone": "+70469014471"}
0005433344663	61EE9A	0467 158131	RIMMA ISAEVA	{"phone": "+70642481276"}
0005433344664	3E01AB	0600 163054	ANASTASIYA MAKAROVA	{"phone": "+70763981976"}
0005433344665	569637	4989 996846	IRINA SOKOLOVA	{"phone": "+70441419337"}
0005433344666	569637	2770 517318	ELENA KUZNECOVA	{"phone": "+70111234281"}
0005433344667	7B2D54	1535 649219	SERGEY NAUMOV	{"phone": "+70153235162"}
0005433344668	67939B	9951 257284	ILYA ALEKSEEV	{"phone": "+70374038635"}
0005433344669	D3EE98	4618 885059	DMITRIY DMITRIEV	{"phone": "+70675419004"}
0005433344670	50E318	2372 897231	NATALYA SOROKINA	{"email": "n_sorokina.22051969@postgrespro.ru", "phone": "+70579596887"}
0005433344671	ECE0F4	3855 877017	YURIY MOROZOV	{"phone": "+70338690241"}
0005433344672	FB952E	0794 891287	SVETLANA ANTONOVA	{"email": "svetlanaantonova121971@postgrespro.ru", "phone": "+70932964889"}
0005433344673	FB952E	1932 817268	NIKOLAY BONDARENKO	{"phone": "+70107478979"}
0005433344674	923E76	2785 550975	TAMARA ERMAKOVA	{"phone": "+70425564426"}
0005433344675	A97759	2097 441710	SERGEY DAVYDOV	{"email": "davydov_sergey_05081963@postgrespro.ru", "phone": "+70098372141"}
0005433344676	A97759	8425 730594	SERGEY NOVIKOV	{"phone": "+70709718418"}
0005433344677	9011F3	6509 804808	NIKOLAY EGOROV	{"phone": "+70432251850"}
0005433344678	9011F3	7517 918252	IVAN ZHURAVLEV	{"email": "zhuravlev-ivan-09061961@postgrespro.ru", "phone": "+70017643371"}
0005433344679	9011F3	4730 764391	TAMARA DMITRIEVA	{"phone": "+70816820586"}
0005433344680	CD7A33	0147 653423	ALEKSANDR KUDRYASHOV	{"email": "a_kudryashov061973@postgrespro.ru", "phone": "+70894024122"}
0005433344681	F87D23	1437 021492	SVETLANA TIKHONOVA	{"email": "svetlana_tikhonova-1962@postgrespro.ru", "phone": "+70601410885"}
0005433344682	F87D23	6607 812123	RAFIK KONOVALOV	{"email": "konovalovrafik1990@postgrespro.ru", "phone": "+70799146042"}
0005433344683	875CCD	7334 783457	TATYANA SOROKINA	{"phone": "+70635815407"}
0005433344684	1481EE	8157 839696	ALEKSANDRA OSIPOVA	{"email": "a-osipova.101972@postgrespro.ru", "phone": "+70047159083"}
0005433344685	535E82	1873 484745	NINA ORLOVA	{"phone": "+70252805267"}
0005433344686	60E9AC	2989 884324	VIKTOR POPOV	{"email": "viktor_popov-03101975@postgrespro.ru", "phone": "+70446706229"}
0005433344687	48EC45	7228 911407	OLGA ZHUKOVA	{"phone": "+70612575571"}
0005433344688	48EC45	3914 030199	DENIS PETROV	{"phone": "+70121032991"}
0005433344689	A35273	6862 124653	TATYANA ANISIMOVA	{"email": "t-anisimova-1969@postgrespro.ru", "phone": "+70356467580"}
0005433344690	08CBF1	3681 149496	YAROSLAV ABRAMOV	{"phone": "+70150704212"}
0005433344691	08CBF1	6311 414752	GALINA GERASIMOVA	{"email": "gerasimovagalina-111977@postgrespro.ru", "phone": "+70986998921"}
0005433344692	6AD193	8642 445319	NINA TARASOVA	{"email": "tarasova_nina.14091972@postgrespro.ru", "phone": "+70808028639"}
0005433344693	4D94A4	1077 782306	LIDIYA ROMANOVA	{"phone": "+70089514069"}
0005433344694	B3B5E8	9632 370063	NATALYA TARASOVA	{"email": "tarasova_natalya061961@postgrespro.ru", "phone": "+70862040234"}
0005433344695	721F2E	1380 252339	DMITRIY PAVLOV	{"email": "pavlovd.1969@postgrespro.ru", "phone": "+70550039779"}
0005433344696	4303F6	2317 339779	GENNADIY MELNIKOV	{"email": "gennadiy_melnikov_09061974@postgrespro.ru", "phone": "+70102337450"}
0005433344697	4303F6	1058 289208	LYUBOV PAVLOVA	{"phone": "+70194983462"}
0005433344698	B6AC6A	6614 966687	SVETLANA GRISHINA	{"email": "grishina_svetlana_1959@postgrespro.ru", "phone": "+70237254769"}
0005433344699	ECAE92	0915 016133	TATYANA MAKAROVA	{"email": "makarovat.051976@postgrespro.ru", "phone": "+70518186240"}
0005433344700	ECAE92	4899 233730	OLGA KOROLEVA	{"phone": "+70167707592"}
0005433344701	ECAE92	7116 354697	MIKHAIL NIKOLAEV	{"phone": "+70465974260"}
0005433344702	E697B9	3692 698882	NINA EGOROVA	{"email": "negorova-1974@postgrespro.ru", "phone": "+70738450682"}
0005433344703	BE6612	7528 594191	ALEKSANDR KULIKOV	{"phone": "+70847000666"}
0005433344704	89E7DF	2909 790455	YURIY ZAKHAROV	{"phone": "+70965968344"}
0005433344705	478A78	6638 980058	VERONIKA ZHURAVLEVA	{"phone": "+70928422519"}
0005433344706	8960F8	9038 930996	MAKSIM GERASIMOV	{"email": "m_gerasimov-02091969@postgrespro.ru", "phone": "+70172070585"}
0005433344707	8960F8	4483 727505	IRINA KISELEVA	{"phone": "+70497067017"}
0005433344708	51A97B	3380 084435	NIKOLAY IVANOV	{"email": "nikolay.ivanov091983@postgrespro.ru", "phone": "+70885331388"}
0005433344709	B99952	6312 522415	NIKOLAY DMITRIEV	{"phone": "+70180139068"}
0005433344710	32D555	4084 117080	RENAT ANDREEV	{"email": "r.andreev_121971@postgrespro.ru", "phone": "+70136392732"}
0005433344711	9D23C9	8890 197125	IRINA DANILOVA	{"email": "danilovai.02051971@postgrespro.ru", "phone": "+70802854717"}
0005433344712	C4106D	6559 429043	VALENTINA TITOVA	{"email": "titova-valentina-1956@postgrespro.ru", "phone": "+70028978995"}
0005433344713	BA9614	8145 776107	ANNA NOVIKOVA	{"email": "novikovaanna04081962@postgrespro.ru", "phone": "+70304266364"}
0005433344714	AFC168	2023 453881	ALEKSANDR KOZLOV	{"email": "kozlov-a111981@postgrespro.ru", "phone": "+70435837336"}
0005433344715	DC5E39	8796 643511	ELENA ILINA	{"phone": "+70822381814"}
0005433344716	DC5E39	9703 285331	ANDREY SOLOVEV	{"email": "solovev.andrey05091983@postgrespro.ru", "phone": "+70511058610"}
0005433344717	6DC2B0	6984 025913	IGOR SEMENOV	{"email": "semenov.i-1970@postgrespro.ru", "phone": "+70575287667"}
0005433344718	9BD39C	4050 259337	ANZHELIKA GERASIMOVA	{"email": "anzhelikagerasimova1978@postgrespro.ru", "phone": "+70285588630"}
0005433344719	9BD39C	6488 074785	VALENTINA NOVIKOVA	{"phone": "+70714449316"}
0005433344720	E117B7	4105 366058	IRINA KOROLEVA	{"email": "irina.koroleva_16011982@postgrespro.ru", "phone": "+70069156724"}
0005433344721	03C55A	1315 211299	EVGENIY TARASOV	{"email": "e-tarasov_101961@postgrespro.ru", "phone": "+70587286700"}
0005433344722	FE35AC	7236 204287	TATYANA KOROLEVA	{"email": "t-koroleva_071957@postgrespro.ru", "phone": "+70993708513"}
0005433344723	FE35AC	4975 120145	OLGA FEDOROVA	{"email": "fedorova_o.10071970@postgrespro.ru", "phone": "+70594433485"}
0005433344724	5A29BF	8684 542051	NATALYA BARANOVA	{"email": "baranova_natalya041971@postgrespro.ru", "phone": "+70382679473"}
0005433344725	8E628C	2098 240206	TATYANA ANDREEVA	{"phone": "+70745474139"}
0005433344726	353FF7	1444 108977	VERA NAUMOVA	{"phone": "+70063530151"}
0005433344727	E922D8	8806 246165	VIKTORIYA NIKIFOROVA	{"phone": "+70870271141"}
0005433344728	85F2A9	5350 067374	IRINA IVANOVA	{"email": "ivanovai01081975@postgrespro.ru", "phone": "+70854079598"}
0005433344729	5438CE	2541 855519	ALLA SMIRNOVA	{"email": "smirnovaalla21031978@postgrespro.ru", "phone": "+70464383261"}
0005433344730	5438CE	8071 542053	TATYANA KULIKOVA	{"email": "tatyana-kulikova_061978@postgrespro.ru", "phone": "+70008184501"}
0005433344731	784CFF	7370 990718	SERGEY MAKSIMOV	{"phone": "+70733428531"}
0005433344732	47C149	1917 930394	YAROSLAV BELOV	{"email": "belov-yaroslav_21081977@postgrespro.ru", "phone": "+70919368349"}
0005433344733	694A7A	3142 535245	ZINAIDA ZOTOVA	{"phone": "+70557130157"}
0005433344734	BB935D	5465 067419	MAKSIM KONOVALOV	{"email": "maksim-konovalov091975@postgrespro.ru", "phone": "+70137385559"}
0005433344735	E2F623	4619 640702	VADIM MEDVEDEV	{"email": "vadim.medvedev_121970@postgrespro.ru", "phone": "+70108378567"}
0005433344736	E2F623	7114 922195	ANDREY IVANOV	{"email": "andreyivanov.19011968@postgrespro.ru", "phone": "+70725515170"}
0005433344737	4E760A	8408 431117	EVGENIY KUZNECOV	{"phone": "+70066172982"}
0005433344738	14F272	2380 095169	SOFIYA MAKAROVA	{"email": "makarova-s.25071973@postgrespro.ru", "phone": "+70385216839"}
0005433344739	9CAA6B	6995 524371	LYUDMILA PAVLOVA	{"phone": "+70091623085"}
0005433344740	AFFA52	0321 472324	NINA IVANOVA	{"email": "ivanova_nina-081959@postgrespro.ru", "phone": "+70589169168"}
0005433344741	AFFA52	4160 703528	LIDIYA DAVYDOVA	{"email": "davydova-l.1976@postgrespro.ru", "phone": "+70673124520"}
0005433344742	AFFA52	0598 785338	DMITRIY SHEVCHENKO	{"phone": "+70752208732"}
0005433344743	07F7EF	5642 328419	VALENTINA FROLOVA	{"email": "frolova_valentina_23051971@postgrespro.ru", "phone": "+70051481852"}
0005433344744	B3F180	4044 603704	NIKOLAY VOLKOV	{"phone": "+70828720941"}
0005433344745	A8E3B2	4814 824887	DMITRIY SHEVCHENKO	{"email": "shevchenko.d-21021976@postgrespro.ru", "phone": "+70429698395"}
0005433344746	A8E3B2	0233 417047	MARGARITA MEDVEDEVA	{"phone": "+70917349554"}
0005433344747	A8E3B2	1990 489971	KRISTINA ZAKHAROVA	{"email": "k_zakharova1963@postgrespro.ru", "phone": "+70766899923"}
0005433344748	9AF406	6094 047516	SERGEY EGOROV	{"email": "egorov-s-1969@postgrespro.ru", "phone": "+70832128794"}
0005433344749	B5C082	4864 661057	ALEKSEY EGOROV	{"email": "aleksey-egorov.1972@postgrespro.ru", "phone": "+70464541149"}
0005433344750	F2E4E1	0596 641871	SEMEN DENISOV	{"phone": "+70947142144"}
0005433344751	27D17E	8954 831425	ROMAN SOLOVEV	{"email": "solovevr_28111969@postgrespro.ru", "phone": "+70781850056"}
0005433344752	091DA7	9607 338562	VLADIMIR VASILEV	{"phone": "+70899106256"}
0005433344753	091DA7	1025 638211	ROMAN POPOV	{"phone": "+70591828011"}
0005433344754	091DA7	6612 465792	IRINA GRISHINA	{"phone": "+70714785908"}
0005433344755	DE568E	5433 589244	IGOR GERASIMOV	{"phone": "+70722780633"}
0005433344756	DE568E	0800 548975	IGOR GORBUNOV	{"email": "gorbunov-igor.011975@postgrespro.ru", "phone": "+70258613589"}
0005433344757	58341F	2004 380350	VALERIY MELNIKOV	{"phone": "+70105782012"}
0005433344758	F27A26	7935 888350	ELENA OSIPOVA	{"phone": "+70925706025"}
0005433344759	76F554	1467 763730	NIKOLAY POPOV	{"email": "nikolay_popov-12081967@postgrespro.ru", "phone": "+70392431512"}
0005433344760	313CDD	1424 836828	YULIYA ALEKSANDROVA	{"email": "y_aleksandrova-1966@postgrespro.ru", "phone": "+70364467833"}
0005433344761	313CDD	2558 927947	LEONID NAUMOV	{"email": "naumovleonid-23051961@postgrespro.ru", "phone": "+70784838295"}
0005433344762	A1FB66	3430 874612	EKATERINA PETROVA	{"email": "e.petrova.1978@postgrespro.ru", "phone": "+70738433717"}
0005433344763	941DEA	9452 838637	SERGEY BELOV	{"phone": "+70586687589"}
0005433344764	941DEA	1678 794313	TATYANA SERGEEVA	{"phone": "+70324363207"}
0005433344765	957069	0952 187824	NADEZHDA FILATOVA	{"email": "filatova-n-021982@postgrespro.ru", "phone": "+70987491378"}
0005433344766	957069	0568 239814	ELENA MALYSHEVA	{"email": "elena-malysheva051990@postgrespro.ru", "phone": "+70582462853"}
0005433344767	6F3897	3541 095663	PAVEL NIKITIN	{"email": "p-nikitin_1971@postgrespro.ru", "phone": "+70002804479"}
0005433344768	AB3D7B	2724 493680	VALENTINA ERMAKOVA	{"email": "valentina-ermakova-26051973@postgrespro.ru", "phone": "+70433310794"}
0005433344769	19E5C2	6691 520532	OLEG TARASOV	{"email": "tarasov-oleg-24041970@postgrespro.ru", "phone": "+70163298018"}
0005433344770	19E5C2	0085 825812	SERGEY SMIRNOV	{"email": "ssmirnov.17021981@postgrespro.ru", "phone": "+70552893730"}
0005433344771	19E5C2	6676 029532	ALEKSEY FILIPPOV	{"phone": "+70368927684"}
0005433344772	DDFCC8	4616 006678	INNA BELOVA	{"email": "belova-inna-06031970@postgrespro.ru", "phone": "+70475662208"}
0005433344773	262D38	2935 900088	ALEKSANDRA VLASOVA	{"phone": "+70924260198"}
0005433344774	262D38	4569 515213	VERA VLASOVA	{"email": "vlasova.vera-1971@postgrespro.ru", "phone": "+70453920762"}
0005433344775	7BDDB5	4631 001203	ANTON ANDREEV	{"email": "andreevanton-071973@postgrespro.ru", "phone": "+70946590895"}
0005433344776	7BDDB5	3641 837134	LYUDMILA IVANOVA	{"email": "l-ivanova_031972@postgrespro.ru", "phone": "+70380021686"}
0005433344777	DB0261	1666 061677	GEORGIY SOROKIN	{"email": "gsorokin-05051970@postgrespro.ru", "phone": "+70590222596"}
0005433344778	3986C4	7000 915291	NINA PAVLOVA	{"phone": "+70099949466"}
0005433344779	3986C4	6505 117887	ELENA RYABOVA	{"phone": "+70094272197"}
0005433344780	1D33A6	8774 045453	VIKTOR ORLOV	{"email": "viktororlov-071974@postgrespro.ru", "phone": "+70113737882"}
0005433344781	1D33A6	1990 521069	ALEKSANDR NAUMOV	{"email": "naumov_a-18111969@postgrespro.ru", "phone": "+70505367173"}
0005433344782	5F605A	5097 847880	ANTON VLASOV	{"email": "a_vlasov08071960@postgrespro.ru", "phone": "+70972719695"}
0005433344783	7B75D3	5539 905517	SERGEY MARTYNOV	{"email": "sergey-martynov_1963@postgrespro.ru", "phone": "+70703304848"}
0005433344784	C6F757	8970 118951	SERGEY MOISEEV	{"email": "moiseevsergey_081983@postgrespro.ru", "phone": "+70803177142"}
0005433344785	252E5A	4066 805997	DMITRIY SOROKIN	{"phone": "+70951615250"}
0005433344786	B34D88	5558 966683	GALINA OSIPOVA	{"email": "osipovag.021966@postgrespro.ru", "phone": "+70432934609"}
0005433344787	B34D88	8903 262257	NIKOLAY ORLOV	{"phone": "+70632654684"}
0005433344788	E9DC19	2969 272171	NATALYA KONDRATEVA	{"phone": "+70203613456"}
0005433344789	6677CC	4371 331356	VALERIY KUZNECOV	{"phone": "+70447968297"}
0005433344790	3D660A	0763 755644	EVGENIY PAVLOV	{"email": "pavlovevgeniy091977@postgrespro.ru", "phone": "+70884208531"}
0005433344791	3FBF8F	7165 654104	TATYANA VOROBEVA	{"phone": "+70972308109"}
0005433344792	25E4B4	6053 964454	TAISIYA KRASNOVA	{"email": "krasnova_taisiya-091967@postgrespro.ru", "phone": "+70345234685"}
0005433344793	1019F2	7170 658397	ELENA ZOTOVA	{"email": "e-zotova-1972@postgrespro.ru", "phone": "+70388694016"}
0005433344794	44417A	3803 137952	SERGEY ANTONOV	{"email": "santonov.071975@postgrespro.ru", "phone": "+70084239746"}
0005433344795	8D261E	2709 490890	VITALIY FEDOROV	{"phone": "+70669494404"}
0005433344796	5EA0A2	4056 693476	LYUBOV SOROKINA	{"email": "lyubov_sorokina.1978@postgrespro.ru", "phone": "+70279059834"}
0005433344797	5EA0A2	2379 595920	YULIYA IVANOVA	{"phone": "+70103218643"}
0005433344798	897481	6280 500099	LYUBOV SAVELEVA	{"phone": "+70599306513"}
0005433344799	4DDFEB	3586 851086	ANASTASIYA NOVIKOVA	{"phone": "+70836967215"}
0005433344800	4DDFEB	5329 279967	ALEKSEY TARASOV	{"email": "a-tarasov-21041969@postgrespro.ru", "phone": "+70130605372"}
0005433344801	DE602D	1482 672338	ALEKSANDR KRASNOV	{"email": "krasnov-aleksandr16101971@postgrespro.ru", "phone": "+70975114930"}
0005433344802	DE602D	2676 409289	ANTONINA IVANOVA	{"phone": "+70107528666"}
0005433344803	090F57	6094 889405	NATALIYA KUZMINA	{"phone": "+70587370140"}
0005433344804	25908C	0275 568384	TATYANA NIKIFOROVA	{"phone": "+70888606779"}
0005433344805	EC4E81	3736 272387	ANASTASIYA NOVIKOVA	{"phone": "+70005212879"}
0005433344806	4237D6	9090 777082	TATYANA KONDRATEVA	{"phone": "+70065686856"}
0005433344807	B2DAD7	6158 709128	ALEKSANDR MOISEEV	{"email": "a_moiseev-30061971@postgrespro.ru", "phone": "+70540113093"}
0005433344808	B2DAD7	4538 501202	ALEKSANDRA KOMAROVA	{"phone": "+70175091829"}
0005433344809	4102D8	5047 407591	YULIYA FOMINA	{"email": "yuliya_fomina_1959@postgrespro.ru", "phone": "+70723293403"}
0005433344810	22A73D	8334 118272	ANNA EGOROVA	{"phone": "+70118669407"}
0005433344811	22A73D	1575 701628	VALENTIN KOZLOV	{"phone": "+70351475567"}
0005433344812	8D0CA9	9267 889267	NATALYA ANDREEVA	{"email": "natalyaandreeva_051962@postgrespro.ru", "phone": "+70231244051"}
0005433344813	8D0CA9	1258 691401	VLADIMIR MARTYNOV	{"phone": "+70915922714"}
0005433344814	01570F	6605 260173	OLGA KRASNOVA	{"phone": "+70136178892"}
0005433344815	F5982D	7154 357638	SERGEY CHERNOV	{"email": "sergeychernov.061973@postgrespro.ru", "phone": "+70592121415"}
0005433344816	221A69	6507 765234	MATVEY SOROKIN	{"email": "m.sorokin_1972@postgrespro.ru", "phone": "+70427143965"}
0005433344817	08C6BA	3262 453835	YULIYA POTAPOVA	{"email": "potapova_y.1970@postgrespro.ru", "phone": "+70739827478"}
0005433344818	4113E4	4499 030088	VLADIMIR ANDREEV	{"phone": "+70372121309"}
0005433344819	4113E4	0410 326495	KONSTANTIN KRASNOV	{"email": "krasnovkonstantin.081989@postgrespro.ru", "phone": "+70342559878"}
0005433344820	6CB8AA	9392 176905	OLGA MELNIKOVA	{"phone": "+70966006276"}
0005433344821	07818D	4158 910728	ARINA KONOVALOVA	{"email": "konovalova_a_071987@postgrespro.ru", "phone": "+70583289231"}
0005433344822	6984FD	2460 100555	SVETLANA LAZAREVA	{"phone": "+70138813090"}
0005433344823	6984FD	1842 515253	GALINA POTAPOVA	{"email": "potapovagalina041953@postgrespro.ru", "phone": "+70148499565"}
0005433344824	6984FD	2877 613770	YURIY KUZMIN	{"email": "ykuzmin04031977@postgrespro.ru", "phone": "+70422196963"}
0005433344825	DBD53D	5089 321495	ELENA SERGEEVA	{"email": "elena-sergeeva-061972@postgrespro.ru", "phone": "+70130496103"}
0005433344826	F51838	9103 202676	KLAVDIYA ROMANOVA	{"email": "k-romanova12081969@postgrespro.ru", "phone": "+70915497931"}
0005433344827	D82547	4396 632486	NATALYA GUSEVA	{"email": "gusevanatalya.29081972@postgrespro.ru", "phone": "+70129170294"}
0005433344828	61FB17	6720 679654	VLADIMIR MELNIKOV	{"email": "v-melnikov_1972@postgrespro.ru", "phone": "+70516751304"}
0005433344829	9CBE98	9937 277547	MARYAM KOROLEVA	{"phone": "+70034598689"}
0005433344830	9CBE98	2375 769572	IVAN KUZMIN	{"phone": "+70805071224"}
0005433344831	9CBE98	5534 605996	VALERIY IVANOV	{"phone": "+70457370091"}
0005433344832	B66373	7162 102692	RAIS KONOVALOV	{"email": "konovalov.rais-05041968@postgrespro.ru", "phone": "+70100566523"}
0005433344833	B66373	0040 831062	DMITRIY VOLKOV	{"phone": "+70883126009"}
0005433344834	8ED81C	4361 386298	ALEKSANDR ANTONOV	{"phone": "+70126864787"}
0005433344835	C664A0	4288 675099	SERGEY GORBUNOV	{"phone": "+70575119523"}
0005433344836	1FF1F9	0022 489942	ALLA BOGDANOVA	{"email": "allabogdanova.041969@postgrespro.ru", "phone": "+70791000693"}
0005433344837	1FF1F9	8023 237422	MIKHAIL MOROZOV	{"email": "morozov-m.1972@postgrespro.ru", "phone": "+70339396390"}
0005433344838	BA7B9F	0881 943249	NIKOLAY IVANOV	{"email": "nivanov_121968@postgrespro.ru", "phone": "+70944425680"}
0005433344839	2B3241	8289 913738	NADEZHDA SOROKINA	{"phone": "+70142322885"}
0005433344840	1117FD	9951 712433	EGOR KAZAKOV	{"email": "egorkazakov.15011980@postgrespro.ru", "phone": "+70728890898"}
0005433344841	ED1CCD	1821 676116	IVAN KUZNECOV	{"email": "i_kuznecov.07091974@postgrespro.ru", "phone": "+70461534471"}
0005433344842	ED1CCD	2476 275355	ALEKSANDR KAZAKOV	{"email": "kazakov.a.1970@postgrespro.ru", "phone": "+70286902691"}
0005433344843	ED1CCD	4343 416721	OLGA MEDVEDEVA	{"email": "medvedevao.09021969@postgrespro.ru", "phone": "+70233380256"}
0005433344844	E33E67	0592 025824	ANATOLIY KOZLOV	{"phone": "+70626386263"}
0005433344845	06035A	2599 705917	SERGEY DMITRIEV	{"phone": "+70421603936"}
0005433344846	06035A	9912 795297	DMITRIY KOROLEV	{"email": "dmitriy_korolev1980@postgrespro.ru", "phone": "+70004494752"}
0005433344847	0FBD92	9985 159644	ANDREY SHEVCHENKO	{"phone": "+70761411908"}
0005433344848	505E06	6295 570310	LYUDMILA TITOVA	{"email": "titova_lyudmila1970@postgrespro.ru", "phone": "+70413656206"}
0005433344849	505E06	3124 465218	VIKTORIYA KUZNECOVA	{"phone": "+70920669362"}
0005433344850	2032E4	8135 620278	MIKHAIL DMITRIEV	{"phone": "+70346128548"}
0005433344851	C6FE29	1645 063211	MIKHAIL NIKITIN	{"phone": "+70905396805"}
0005433344852	C6FE29	3305 527310	ALLA ALEKSANDROVA	{"email": "a-aleksandrova.08091971@postgrespro.ru", "phone": "+70210205619"}
0005433344853	048D52	7541 748582	ELENA FROLOVA	{"email": "e_frolova-16091963@postgrespro.ru", "phone": "+70217587574"}
0005433344854	FBA8D2	3220 360064	NIKOLAY MAKSIMOV	{"phone": "+70028895833"}
0005433344855	FBA8D2	1854 885471	ANNA FADEEVA	{"phone": "+70836421231"}
0005433344856	ABADA2	4989 307038	IRINA PAVLOVA	{"email": "i-pavlova.11021973@postgrespro.ru", "phone": "+70540181334"}
0005433344857	ABADA2	6977 089418	YULIYA KISELEVA	{"email": "kiselevay061976@postgrespro.ru", "phone": "+70681773252"}
0005433344858	BD0AD9	5536 261824	ARTEM ALEKSEEV	{"email": "artemalekseev-121970@postgrespro.ru", "phone": "+70767938082"}
0005433344859	EF58F5	2452 138923	OLGA TIMOFEEVA	{"phone": "+70435203899"}
0005433344860	EF58F5	6494 680035	TATYANA KULIKOVA	{"phone": "+70148943234"}
0005433344861	EF58F5	1665 841403	EVGENIY ILIN	{"phone": "+70393536491"}
0005433344862	881505	6405 413612	LIDIYA POLYAKOVA	{"phone": "+70167432658"}
0005433344863	8C6C9C	0375 117554	VLADIMIR KAZAKOV	{"phone": "+70464215950"}
0005433344864	AB8ED4	2697 309201	MARIYA GORBUNOVA	{"phone": "+70767649669"}
0005433344865	216E1B	9037 753429	SVETLANA MIRONOVA	{"phone": "+70873278619"}
0005433344866	EBA557	3157 878951	ROZA MAKAROVA	{"phone": "+70845145164"}
0005433344867	EBA557	5135 366632	ANDREY NIKOLAEV	{"email": "andrey_nikolaev-05111979@postgrespro.ru", "phone": "+70093521135"}
0005433344868	414FC9	2065 703766	VALERIY BARANOV	{"email": "baranov_valeriy_121981@postgrespro.ru", "phone": "+70218649838"}
0005433344869	414FC9	1978 199875	MARINA EGOROVA	{"phone": "+70538365288"}
0005433344870	414FC9	0330 044027	VLADIMIR BORISOV	{"email": "borisov-vladimir091962@postgrespro.ru", "phone": "+70957019766"}
0005433344871	414FC9	4921 882050	LYUBOV BOGDANOVA	{"phone": "+70055509567"}
0005433344872	414FC9	9645 128442	EKATERINA LEBEDEVA	{"phone": "+70471254684"}
0005433344873	886C74	8765 730733	MARIYA MASLOVA	{"email": "mariyamaslova.27101969@postgrespro.ru", "phone": "+70372140963"}
0005433344874	886C74	4565 792687	GALINA KONOVALOVA	{"phone": "+70509698707"}
0005433344875	886C74	5549 806370	DMITRIY DMITRIEV	{"phone": "+70672994389"}
0005433344876	D23EB3	4149 466687	EKATERINA POPOVA	{"email": "e-popova031970@postgrespro.ru", "phone": "+70486183219"}
0005433344877	D23EB3	2525 286241	YULIYA IVANOVA	{"email": "ivanovayuliya03111980@postgrespro.ru", "phone": "+70690582682"}
0005433344878	9D645F	9246 287475	ALEKSANDR KRASNOV	{"email": "a-krasnov-1986@postgrespro.ru", "phone": "+70874673342"}
0005433344990	C6A0FD	3071 957098	ELENA ROMANOVA	{"phone": "+70516358286"}
0005433344879	9D645F	0134 616283	MIKHAIL ANDREEV	{"email": "andreev_mikhail-011987@postgrespro.ru", "phone": "+70926916653"}
0005433344880	9D645F	5714 428237	ALEKSANDR ROMANOV	{"email": "a.romanov-1970@postgrespro.ru", "phone": "+70868671259"}
0005433344881	B0ADC1	0001 605073	ALEKSANDR TARASOV	{"phone": "+70269974588"}
0005433344882	B0ADC1	1576 000106	STANISLAV SOKOLOV	{"email": "stanislav-sokolov051971@postgrespro.ru", "phone": "+70425581194"}
0005433344883	AB3E4D	4795 688722	ALEKSANDR MARTYNOV	{"email": "a_martynov.1969@postgrespro.ru", "phone": "+70112555851"}
0005433344884	AB3E4D	1211 360095	ALEKSANDR SERGEEV	{"phone": "+70203577811"}
0005433344885	AB3E4D	8454 488699	TATYANA KAZAKOVA	{"email": "tatyana-kazakova.1974@postgrespro.ru", "phone": "+70517458898"}
0005433344886	9ECDE9	5434 512598	NINA OVCHINNIKOVA	{"email": "ovchinnikova.nina-07071973@postgrespro.ru", "phone": "+70806885171"}
0005433344887	0EA23F	5564 439628	LYUDMILA NIKOLAEVA	{"phone": "+70590707250"}
0005433344888	CFDEF3	8609 698028	VERA SERGEEVA	{"email": "vera_sergeeva_1972@postgrespro.ru", "phone": "+70455410539"}
0005433344889	6EBE0A	2034 461815	SERGEY STEPANOV	{"phone": "+70659860995"}
0005433344890	928EB4	6206 977480	OLGA GAVRILOVA	{"email": "gavrilovaolga_1970@postgrespro.ru", "phone": "+70329947160"}
0005433344891	928EB4	5219 644513	IRINA LEBEDEVA	{"phone": "+70834017347"}
0005433344892	F97A13	7758 796448	YULIYA SMIRNOVA	{"phone": "+70776447340"}
0005433344893	69136C	9381 063520	SVETLANA ANISIMOVA	{"email": "anisimova-s.05021970@postgrespro.ru", "phone": "+70918774834"}
0005433344894	69136C	7332 190109	NIKOLAY DENISOV	{"email": "nikolaydenisov-26091961@postgrespro.ru", "phone": "+70998465664"}
0005433344895	A7DE9A	9551 923189	SERGEY ALEKSANDROV	{"email": "aleksandrov.s-011987@postgrespro.ru", "phone": "+70987325391"}
0005433344896	E1B708	8590 856134	SERGEY SMIRNOV	{"email": "smirnov-s1979@postgrespro.ru", "phone": "+70635570042"}
0005433344897	E1B708	7213 015943	MARIYA KUZMINA	{"email": "kuzminam-29111975@postgrespro.ru", "phone": "+70384000290"}
0005433344898	349880	0774 424084	KONSTANTIN AFANASEV	{"email": "afanasev-k031975@postgrespro.ru", "phone": "+70370042530"}
0005433344899	FD54B1	7290 599277	LYUBOV ABRAMOVA	{"phone": "+70877346646"}
0005433344900	E50085	6482 174651	NADEZHDA ARKHIPOVA	{"email": "n_arkhipova_07051972@postgrespro.ru", "phone": "+70359159868"}
0005433344901	B5BC1B	5594 650031	VADIM GERASIMOV	{"phone": "+70322971126"}
0005433344902	829CD5	4574 116374	GLEB MARTYNOV	{"email": "martynov_gleb-25081980@postgrespro.ru", "phone": "+70054045688"}
0005433344903	0317B7	7096 919620	MIKHAIL DMITRIEV	{"phone": "+70321740967"}
0005433344904	7C0CE6	2697 548837	YURIY PETROV	{"email": "y_petrov1977@postgrespro.ru", "phone": "+70777704425"}
0005433344905	5DBCF1	0529 695601	ELENA SIDOROVA	{"phone": "+70113997756"}
0005433344906	CF56D0	1794 936424	NATALIYA KUZNECOVA	{"email": "kuznecova-nataliya.1972@postgrespro.ru", "phone": "+70330749283"}
0005433344907	931205	4905 054942	MAKSIM DAVYDOV	{"phone": "+70573362627"}
0005433344908	EDE758	7028 822996	VIKTOR ALEKSEEV	{"phone": "+70885450423"}
0005433344909	B062CE	4125 789138	OLEG KARPOV	{"phone": "+70526506944"}
0005433344910	7FBB34	9461 447212	EKATERINA PETROVA	{"phone": "+70277309302"}
0005433344911	7FBB34	0193 318788	ANDREY SAVELEV	{"phone": "+70432900778"}
0005433344912	72BBDD	5470 103789	TIMOFEY SOROKIN	{"email": "sorokintimofey.081958@postgrespro.ru", "phone": "+70458350628"}
0005433344913	F7C5CF	9004 727847	MAKSIM BELOV	{"email": "maksim.belov_061974@postgrespro.ru", "phone": "+70435602844"}
0005433344914	F361AC	5822 054258	RAISA DAVYDOVA	{"email": "davydova_r-071973@postgrespro.ru", "phone": "+70077500113"}
0005433344915	11FA8C	4894 640362	LARISA POPOVA	{"email": "popova_l_1970@postgrespro.ru", "phone": "+70736672998"}
0005433344916	CAB6ED	2664 599707	VERA SMIRNOVA	{"phone": "+70022084865"}
0005433344917	CC8F60	7748 487038	SERGEY MOROZOV	{"email": "smorozov-25111960@postgrespro.ru", "phone": "+70622707143"}
0005433344918	FEA579	7294 167404	ANTON MOROZOV	{"email": "morozov.anton-1965@postgrespro.ru", "phone": "+70959189256"}
0005433344919	FEA579	6624 873397	YULIYA GUSEVA	{"phone": "+70090178752"}
0005433344920	B59079	5118 809366	TATYANA KOVALEVA	{"email": "tkovaleva_121974@postgrespro.ru", "phone": "+70154368520"}
0005433344921	B59079	0953 394389	SERGEY ROMANOV	{"email": "sergey-romanov.09011986@postgrespro.ru", "phone": "+70002672749"}
0005433344922	B59079	6791 327511	ANATOLIY VOROBEV	{"email": "vorobev-a.1965@postgrespro.ru", "phone": "+70815385754"}
0005433344923	B16AA8	6431 428045	SERGEY DAVYDOV	{"email": "s.davydov.01091964@postgrespro.ru", "phone": "+70338785142"}
0005433344924	B16AA8	0842 259660	NATALYA DENISOVA	{"email": "denisova-n041975@postgrespro.ru", "phone": "+70586330163"}
0005433344925	AA458D	3557 877607	VLADIMIR CHERNOV	{"phone": "+70230691540"}
0005433344926	DA0C37	3121 815204	YULIYA TIMOFEEVA	{"phone": "+70475267949"}
0005433344927	DA0C37	9225 543962	ALEKSANDR BORISOV	{"phone": "+70194383737"}
0005433344928	2987CF	5146 724117	ANAIT FEDOROVA	{"email": "a.fedorova-041965@postgrespro.ru", "phone": "+70223558481"}
0005433344929	D2C339	1648 334188	OLGA KARPOVA	{"phone": "+70964797349"}
0005433344930	D2C339	7796 260705	NURIYA VOLKOVA	{"email": "nuriya-volkova-1970@postgrespro.ru", "phone": "+70621823199"}
0005433344931	D2C339	6549 495071	ELENA TIKHONOVA	{"phone": "+70473119247"}
0005433344932	D2C339	6747 825552	VYACHESLAV STEPANOV	{"phone": "+70045142687"}
0005433344933	7E247F	6695 359652	VLADISLAV DMITRIEV	{"email": "v-dmitriev061975@postgrespro.ru", "phone": "+70866424917"}
0005433344934	84A34D	9101 998865	YULIYA ALEKSEEVA	{"email": "alekseeva_y_1962@postgrespro.ru", "phone": "+70341756846"}
0005433344935	84A34D	7775 866367	ANATOLIY VLASOV	{"email": "anatoliy-vlasov051976@postgrespro.ru", "phone": "+70192536405"}
0005433344936	0824A7	6661 812061	YANA MIRONOVA	{"phone": "+70904476265"}
0005433344937	A5C52C	7599 448079	TATYANA SEMENOVA	{"email": "t-semenova041976@postgrespro.ru", "phone": "+70655875795"}
0005433344938	9B72C6	1218 176756	GENNADIY FEDOTOV	{"email": "gennadiy_fedotov-1958@postgrespro.ru", "phone": "+70684991375"}
0005433344939	A012A0	2350 234207	ARTEM KOZLOV	{"phone": "+70250084705"}
0005433344940	A012A0	5360 564238	TATYANA AFANASEVA	{"email": "tatyana_afanaseva-1983@postgrespro.ru", "phone": "+70545673290"}
0005433344941	936EAE	9237 355839	ANASTASIYA STEPANOVA	{"phone": "+70341944716"}
0005433344942	8EDFFD	8205 022676	GALINA EGOROVA	{"email": "g_egorova_1969@postgrespro.ru", "phone": "+70709424267"}
0005433344943	C1ADF3	3491 778262	TATYANA SAVELEVA	{"phone": "+70672609942"}
0005433344944	C1ADF3	3029 669803	VALENTINA SOKOLOVA	{"phone": "+70725760719"}
0005433344945	2696F0	9359 497589	SERGEY GERASIMOV	{"email": "gerasimov.sergey1971@postgrespro.ru", "phone": "+70424783278"}
0005433344946	B4A8D9	0103 255112	SOFYA KUZMINA	{"email": "s_kuzmina-17051961@postgrespro.ru", "phone": "+70155732271"}
0005433344947	AF0957	6038 943674	ARTUR ZHURAVLEV	{"phone": "+70004969198"}
0005433344948	21DCBD	3580 628636	KIRA ZHUKOVA	{"email": "kira-zhukova_091970@postgrespro.ru", "phone": "+70912400287"}
0005433344949	6E67A9	4931 533623	TAMARA GORBUNOVA	{"email": "gorbunova.t.21021972@postgrespro.ru", "phone": "+70400900303"}
0005433344950	809819	3963 765841	MARGARITA NAUMOVA	{"phone": "+70133508881"}
0005433344951	809819	2377 391401	ALEKSANDR SHEVCHENKO	{"phone": "+70405050089"}
0005433344952	9D63B0	0481 258509	ILYA SAVELEV	{"email": "isavelev011956@postgrespro.ru", "phone": "+70441562404"}
0005433344953	0D1769	6149 713359	VALERIY STEPANOV	{"email": "stepanov.v-1974@postgrespro.ru", "phone": "+70572838438"}
0005433344954	C10D59	3554 609688	IRINA AKIMOVA	{"phone": "+70576983524"}
0005433344955	9DC58D	9130 741977	MARINA EGOROVA	{"email": "marina.egorova_28101985@postgrespro.ru", "phone": "+70212160563"}
0005433344956	BB3015	7087 630140	DMITRIY SCHERBAKOV	{"phone": "+70210898707"}
0005433344957	76E718	9649 736328	NATALIYA NIKOLAEVA	{"email": "n_nikolaeva.061967@postgrespro.ru", "phone": "+70279494992"}
0005433344958	76E718	7307 020758	TATYANA MAKSIMOVA	{"phone": "+70045200816"}
0005433344959	384319	0674 425675	EKATERINA PAVLOVA	{"email": "pavlova-e_011971@postgrespro.ru", "phone": "+70982991728"}
0005433344960	B7A318	6247 101266	KSENIYA KOROLEVA	{"email": "k_koroleva-1967@postgrespro.ru", "phone": "+70082623145"}
0005433344961	B7A318	5594 832276	DARYA KUDRYASHOVA	{"phone": "+70373221705"}
0005433344962	EAFD9F	1066 057784	SVETLANA POPOVA	{"email": "s_popova-1964@postgrespro.ru", "phone": "+70700905395"}
0005433344963	EAFD9F	3780 192945	ANDREY GRIGOREV	{"email": "andrey-grigorev031961@postgrespro.ru", "phone": "+70129798305"}
0005433344964	DB95AD	1206 674150	SERGEY TIMOFEEV	{"phone": "+70565173317"}
0005433344965	DB95AD	9661 544920	MARIYA FEDOROVA	{"email": "mfedorova051974@postgrespro.ru", "phone": "+70000042678"}
0005433344966	8BAC83	4908 459338	LYUBOV GRISHINA	{"phone": "+70821239614"}
0005433344967	B1E3B4	7441 290778	GALINA BORISOVA	{"phone": "+70039417764"}
0005433344968	D9FAD0	5048 687678	OLEG VASILEV	{"phone": "+70115418771"}
0005433344969	5A4DD0	9778 855233	NATALYA PAVLOVA	{"phone": "+70366058845"}
0005433344970	5A4DD0	7005 482368	NATALYA TIKHONOVA	{"email": "n-tikhonova.22011979@postgrespro.ru", "phone": "+70955371874"}
0005433344971	B1FDD4	1596 057497	EKATERINA AKIMOVA	{"email": "akimovaekaterina_10061977@postgrespro.ru", "phone": "+70133438729"}
0005433344972	0D7C31	7561 374651	ROMAN SOKOLOV	{"email": "sokolov-roman-1959@postgrespro.ru", "phone": "+70531890239"}
0005433344973	FB42CA	4326 159698	DMITRIY BARANOV	{"phone": "+70007381509"}
0005433344974	C811E3	0381 617942	ELENA FILIPPOVA	{"phone": "+70075873300"}
0005433344975	C811E3	2467 402856	PAVEL ZAYCEV	{"email": "zaycev-p.10061963@postgrespro.ru", "phone": "+70278484113"}
0005433344976	4473F4	1407 203728	NADEZHDA FROLOVA	{"phone": "+70975982928"}
0005433344977	469FB1	0528 798448	GALINA MAKAROVA	{"phone": "+70841702271"}
0005433344978	30761D	3142 558573	OLGA OSIPOVA	{"email": "osipovaolga_1978@postgrespro.ru", "phone": "+70634956906"}
0005433344979	106740	7368 283022	ZOYA ANISIMOVA	{"phone": "+70381800698"}
0005433344980	F0C812	3127 248497	ALEKSANDR SMIRNOV	{"phone": "+70753647887"}
0005433344981	A0A332	3127 272903	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova.14121968@postgrespro.ru", "phone": "+70364603138"}
0005433344982	AF14F3	0956 610324	ANATOLIY GERASIMOV	{"email": "gerasimovanatoliy_1966@postgrespro.ru", "phone": "+70933110269"}
0005433344983	1C564E	2119 773588	MARIYA KUZNECOVA	{"email": "mariya-kuznecova-071982@postgrespro.ru", "phone": "+70698873620"}
0005433344984	360675	1216 996666	SERGEY PAVLOV	{"phone": "+70907755625"}
0005433344985	049047	1694 340609	EKATERINA SOROKINA	{"phone": "+70101239135"}
0005433344986	049047	7655 915201	IGOR PAVLOV	{"phone": "+70299157246"}
0005433344987	682A75	8150 635155	VLADIMIR SOLOVEV	{"email": "solovev-v_1975@postgrespro.ru", "phone": "+70516774219"}
0005433344988	CEF504	9920 726900	ELENA KUZNECOVA	{"phone": "+70140056981"}
0005433344989	944FF7	1286 226817	LYUDMILA POPOVA	{"email": "l-popova1969@postgrespro.ru", "phone": "+70526489191"}
0005433344991	527D9E	8427 106699	DENIS ZAKHAROV	{"email": "dzakharov_1975@postgrespro.ru", "phone": "+70860567460"}
0005433344992	527D9E	2399 169367	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir_1971@postgrespro.ru", "phone": "+70975800027"}
0005433344993	DD9A4A	8116 406965	ILYA NIKOLAEV	{"phone": "+70560605401"}
0005433344994	DD9A4A	1597 253304	ALEKSEY BARANOV	{"phone": "+70654132333"}
0005433344995	DD9A4A	0799 408329	MIKHAIL DMITRIEV	{"phone": "+70283893667"}
0005433344996	02CC4C	3214 698898	NINA ALEKSANDROVA	{"phone": "+70880244672"}
0005433344997	02CC4C	2627 860990	PAVEL VASILEV	{"phone": "+70709421658"}
0005433344998	00F691	9213 897887	TAMARA BELOVA	{"email": "belova.t-1975@postgrespro.ru", "phone": "+70815599662"}
0005433344999	74680A	4069 149243	GALINA ZHUKOVA	{"email": "zhukova_g_061967@postgrespro.ru", "phone": "+70531046972"}
0005433345000	443E14	8338 241313	ALEKSANDR GUSEV	{"email": "a-gusev-1975@postgrespro.ru", "phone": "+70317689827"}
0005433345001	443E14	8508 725967	NINA SMIRNOVA	{"email": "n_smirnova_1967@postgrespro.ru", "phone": "+70310038123"}
0005433345002	21C6DF	8248 607784	VIKTOR SCHERBAKOV	{"phone": "+70778230533"}
0005433345003	21C6DF	3758 383316	VLADIMIR GAVRILOV	{"email": "v-gavrilov081973@postgrespro.ru", "phone": "+70331425206"}
0005433345004	21C6DF	8956 412478	NATALYA KOZLOVA	{"email": "kozlova-n.01071968@postgrespro.ru", "phone": "+70914867153"}
0005433345005	2DDB0D	4526 799233	NINA MALYSHEVA	{"email": "malyshevanina1970@postgrespro.ru", "phone": "+70188255721"}
0005433345006	C304A9	7736 505218	MIKHAIL ZAKHAROV	{"phone": "+70314305198"}
0005433345007	C304A9	9533 924535	NATALYA ANTONOVA	{"email": "natalya_antonova.051969@postgrespro.ru", "phone": "+70858633995"}
0005433345008	CCDEC3	8420 530904	VALENTIN OSIPOV	{"phone": "+70700154932"}
0005433345009	87FCD5	6723 642483	VIKTOR VASILEV	{"email": "v-vasilev111966@postgrespro.ru", "phone": "+70136364746"}
0005433345010	E79A4F	1499 530351	MARINA BORISOVA	{"phone": "+70744407539"}
0005433345011	E79A4F	0745 739226	ANATOLIY SEMENOV	{"email": "semenov.anatoliy.111972@postgrespro.ru", "phone": "+70896658248"}
0005433345012	8F0342	8450 864668	YURIY SIDOROV	{"phone": "+70165921810"}
0005433345013	7EC0A5	9591 879717	SERGEY SERGEEV	{"email": "sergeevs1961@postgrespro.ru", "phone": "+70104011081"}
0005433345014	84093D	6609 345836	NADEZHDA KUZNECOVA	{"phone": "+70625552788"}
0005433345015	DED1C9	1469 953019	TATYANA MATVEEVA	{"email": "matveeva_t17071975@postgrespro.ru", "phone": "+70388491755"}
0005433345016	EFC692	2459 903736	IRINA SEMENOVA	{"email": "i_semenova_1975@postgrespro.ru", "phone": "+70961607099"}
0005433345017	EFC692	3140 228946	ILNAR MELNIKOV	{"email": "melnikov_ilnar1966@postgrespro.ru", "phone": "+70083955981"}
0005433345018	B744B6	7410 567998	KONSTANTIN ROMANOV	{"phone": "+70321108907"}
0005433345019	B3F4B3	7031 095242	NIKOLAY KISELEV	{"phone": "+70322876291"}
0005433345020	64FC48	1831 301148	YURIY OSIPOV	{"phone": "+70047549001"}
0005433345021	64FC48	3520 092004	IGOR VOROBEV	{"email": "i-vorobev081963@postgrespro.ru", "phone": "+70356459566"}
0005433345022	FA1DAC	5430 542507	VIKTOR MIRONOV	{"phone": "+70856712285"}
0005433345023	FA1DAC	2654 224352	VLADIMIR KUZNECOV	{"phone": "+70985450437"}
0005433345024	F60AEB	5087 159725	DMITRIY MOROZOV	{"email": "morozov.d1971@postgrespro.ru", "phone": "+70888704762"}
0005433345025	F020AE	5191 091670	ANASTASIYA MOROZOVA	{"phone": "+70152852881"}
0005433345026	203A27	3939 012361	TATYANA ZHUKOVA	{"email": "zhukova.t081972@postgrespro.ru", "phone": "+70069481075"}
0005433345027	614C56	1429 673121	EGOR KRASNOV	{"email": "egorkrasnov091969@postgrespro.ru", "phone": "+70659416028"}
0005433345028	1B8C00	3790 934542	YULIYA KRASNOVA	{"phone": "+70544587026"}
0005433345029	7E637B	2715 020608	LYUBOV MIKHAYLOVA	{"email": "mikhaylova-l_1959@postgrespro.ru", "phone": "+70431997685"}
0005433345030	7E637B	4861 359422	OKSANA TITOVA	{"email": "oksanatitova-29011972@postgrespro.ru", "phone": "+70081322629"}
0005433345031	7E637B	7791 791509	SERGEY ROMANOV	{"phone": "+70512579098"}
0005433345032	B99932	6991 475923	VALERIY ORLOV	{"email": "valeriyorlov081965@postgrespro.ru", "phone": "+70309739613"}
0005433345033	1B3740	6405 528977	SERGEY ANTONOV	{"phone": "+70652954893"}
0005433345034	A44760	2099 610473	TATYANA ZAKHAROVA	{"email": "zakharova-t_101969@postgrespro.ru", "phone": "+70651011374"}
0005433345035	4F6840	0321 698620	ALEKSANDR POPOV	{"email": "aleksandrpopov.03111983@postgrespro.ru", "phone": "+70878566112"}
0005433345036	4F6840	4066 984280	VIKTOR KRASNOV	{"phone": "+70771491413"}
0005433345037	BEF01A	9984 016802	IGOR GORBUNOV	{"email": "gorbunov_i-101975@postgrespro.ru", "phone": "+70069671905"}
0005433345038	600B76	5403 271497	VLADIMIR SEMENOV	{"phone": "+70120893865"}
0005433345039	190E1C	7683 653506	NATALYA BORISOVA	{"email": "n-borisova1971@postgrespro.ru", "phone": "+70680938452"}
0005433345040	53DB26	0486 090818	OLEG KISELEV	{"phone": "+70468188456"}
0005433345041	3186FC	5157 558486	MAKSIM CHERNOV	{"phone": "+70188796257"}
0005433345042	2BCE30	5120 880431	ALEKSANDR POPOV	{"email": "a.popov17041971@postgrespro.ru", "phone": "+70877740462"}
0005433345043	72C32D	6563 285850	ALEKSANDR NAZAROV	{"email": "anazarov.1971@postgrespro.ru", "phone": "+70598007103"}
0005433345044	56E623	0936 813180	ALEKSEY KONOVALOV	{"email": "konovalov_aleksey-25101972@postgrespro.ru", "phone": "+70096302995"}
0005433345045	56E623	6103 728447	ALEKSANDR VLASOV	{"email": "avlasov_011980@postgrespro.ru", "phone": "+70691137483"}
0005433345046	17A968	4136 699114	ALENA KOZLOVA	{"email": "alena.kozlova.1976@postgrespro.ru", "phone": "+70602464200"}
0005433345047	8554DD	4619 958721	NIKITA PAVLOV	{"email": "nikita-pavlov-1981@postgrespro.ru", "phone": "+70509815019"}
0005433345048	8554DD	6095 530880	EVGENIY SMIRNOV	{"email": "smirnove.04041960@postgrespro.ru", "phone": "+70566036623"}
0005433345049	74C375	8317 314556	OLGA PAVLOVA	{"email": "pavlova.o-1959@postgrespro.ru", "phone": "+70853284926"}
0005433345050	74C375	0498 720022	MARINA ILINA	{"phone": "+70119002140"}
0005433345051	412DBB	3188 042203	NADEZHDA NIKITINA	{"email": "nadezhda.nikitina041968@postgrespro.ru", "phone": "+70004696970"}
0005433345052	1D4DE7	9685 516050	RUSLAN SCHERBAKOV	{"email": "scherbakov-ruslan.24011977@postgrespro.ru", "phone": "+70085814783"}
0005433345053	AF7E0D	8224 482654	NADEZHDA KOROLEVA	{"email": "koroleva_n_061971@postgrespro.ru", "phone": "+70164393961"}
0005433345054	DA5E2F	3390 149740	EKATERINA SMIRNOVA	{"email": "ekaterina.smirnova.02061969@postgrespro.ru", "phone": "+70185722982"}
0005433345055	DA5E2F	1880 132456	EVGENIY NIKOLAEV	{"phone": "+70307093007"}
0005433345056	CBC6EA	6263 611225	ILDAR IVANOV	{"email": "ivanovi23071965@postgrespro.ru", "phone": "+70496318903"}
0005433345057	831B5D	3665 492773	VIKTOR MOISEEV	{"phone": "+70535606744"}
0005433345058	B094C1	0188 165232	ALIK IVANOV	{"email": "a.ivanov24011963@postgrespro.ru", "phone": "+70188512395"}
0005433345059	6C50EE	7541 925242	ALEKSEY KONOVALOV	{"phone": "+70872001293"}
0005433345060	FEA456	7101 966440	ANASTASIYA TIKHONOVA	{"phone": "+70032365956"}
0005433345061	A4F511	1057 401997	SVETLANA GAVRILOVA	{"phone": "+70443525232"}
0005433345062	B8C8E7	0470 606641	ROMAN VASILEV	{"phone": "+70850564525"}
0005433345063	B8C8E7	0088 823239	IRINA LOGINOVA	{"phone": "+70573905811"}
0005433345064	E0EEF7	8523 038756	VLADIMIR KONOVALOV	{"phone": "+70859169577"}
0005433345065	E0EEF7	3503 604806	IGOR ALEKSANDROV	{"email": "igor_aleksandrov1972@postgrespro.ru", "phone": "+70592329646"}
0005433345066	071D0C	3980 863285	ALEKSANDR ABRAMOV	{"email": "abramov.a24071972@postgrespro.ru", "phone": "+70282580885"}
0005433345067	7DE892	7117 330039	ALEKSANDR ZHUKOV	{"phone": "+70752833915"}
0005433345068	62B1C5	3591 500796	RISHAT BELOV	{"email": "belov_r_08111965@postgrespro.ru", "phone": "+70238289712"}
0005433345069	62B1C5	7934 788572	NINA MEDVEDEVA	{"email": "medvedevan021970@postgrespro.ru", "phone": "+70263170883"}
0005433345070	208144	8153 179753	MARIYA IVANOVA	{"email": "ivanova-m1970@postgrespro.ru", "phone": "+70828139159"}
0005433345071	AA272B	3861 087133	OLGA MALYSHEVA	{"email": "olga_malysheva-081977@postgrespro.ru", "phone": "+70290892816"}
0005433345072	87F024	4147 372749	NIKOLAY NIKITIN	{"phone": "+70554724605"}
0005433345073	87F024	8188 898841	TATYANA MOISEEVA	{"phone": "+70887082673"}
0005433345074	032115	2672 918575	VASILIY GUSEV	{"phone": "+70499104106"}
0005433345075	398ACD	3682 989193	ALEKSEY IVANOV	{"email": "ivanov-a-10121977@postgrespro.ru", "phone": "+70331131388"}
0005433345076	A2B89E	8627 694704	GUZEL SOROKINA	{"email": "sorokinag-1968@postgrespro.ru", "phone": "+70416441332"}
0005433345077	A84E9B	7624 630705	KRISTINA MIKHAYLOVA	{"phone": "+70264744711"}
0005433345078	6A45C5	8841 448339	ANATOLIY FOMIN	{"email": "anatoliy_fomin_091977@postgrespro.ru", "phone": "+70228844447"}
0005433345079	1129EE	9128 615980	VLADIMIR IVANOV	{"email": "ivanov_vladimir.081963@postgrespro.ru", "phone": "+70340280304"}
0005433345080	7D6E83	2048 878454	TIGRAN KULIKOV	{"phone": "+70992315708"}
0005433345081	019C74	7952 621425	NIKOLAY KUZMIN	{"email": "n_kuzmin-1968@postgrespro.ru", "phone": "+70103612184"}
0005433345082	EE82F9	4866 784878	TATYANA SIDOROVA	{"phone": "+70970534801"}
0005433345083	222ABA	7919 695464	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev.1974@postgrespro.ru", "phone": "+70005140314"}
0005433345084	7DE5AC	6734 706976	VLADIMIR VOLKOV	{"phone": "+70152584699"}
0005433345085	78F04E	0125 454253	NATALYA TROFIMOVA	{"email": "natalya.trofimova_1962@postgrespro.ru", "phone": "+70790769773"}
0005433345086	78F04E	4149 490055	ELENA NOVIKOVA	{"phone": "+70768149572"}
0005433345087	5FA6E9	6765 866324	ALEKSANDR PETROV	{"email": "a.petrov_1977@postgrespro.ru", "phone": "+70869232148"}
0005433345088	8A81C0	9541 382710	VLADIMIR ALEKSEEV	{"phone": "+70034449568"}
0005433345089	FBE7D1	8026 794042	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova.011976@postgrespro.ru", "phone": "+70126637502"}
0005433345090	43D97A	2874 368603	YULIYA POPOVA	{"phone": "+70420238036"}
0005433345091	E4479C	9305 763538	NATALYA VOLKOVA	{"email": "natalya_volkova_1959@postgrespro.ru", "phone": "+70603571832"}
0005433345092	942AD1	5583 270194	ARINA KRASNOVA	{"email": "krasnova.a_29051985@postgrespro.ru", "phone": "+70862863519"}
0005433345093	F4BB7D	7366 171068	NATALYA KONOVALOVA	{"phone": "+70243873075"}
0005433345094	6CC5C4	1722 190869	VALENTINA ALEKSEEVA	{"email": "valentinaalekseeva061980@postgrespro.ru", "phone": "+70920365184"}
0005433345095	086CAC	1392 814164	SVETLANA KULIKOVA	{"email": "kulikova_svetlana1966@postgrespro.ru", "phone": "+70640907667"}
0005433345096	989AFF	7820 633161	DANIL NIKOLAEV	{"phone": "+70469701202"}
0005433345097	989AFF	7366 389697	ELENA KUZMINA	{"phone": "+70988206152"}
0005433345154	599E8E	5959 891531	TATYANA SEMENOVA	{"phone": "+70926238724"}
0005433345098	1C5B77	4019 134492	PAVEL VASILEV	{"email": "p-vasilev.1970@postgrespro.ru", "phone": "+70855017662"}
0005433345099	00AEFF	7332 012873	LIDIYA EGOROVA	{"email": "egorovalidiya15081958@postgrespro.ru", "phone": "+70293529346"}
0005433345100	018843	6836 489433	GALINA SIDOROVA	{"phone": "+70660114579"}
0005433345101	018843	7793 699787	NADEZHDA YUDINA	{"phone": "+70688005129"}
0005433345102	C010B5	5048 242501	IVAN FILIPPOV	{"phone": "+70631038087"}
0005433345103	0C4E8C	3341 139280	IRINA ABRAMOVA	{"phone": "+70149685074"}
0005433345104	0C4E8C	5258 871896	YANA FROLOVA	{"phone": "+70097851569"}
0005433345105	22F88E	7199 776917	EVGENIY FEDOROV	{"email": "fedorov_e.071963@postgrespro.ru", "phone": "+70271697644"}
0005433345106	22F88E	2756 464097	OLEG IVANOV	{"email": "oleg.ivanov_061972@postgrespro.ru", "phone": "+70410465372"}
0005433345107	0174D0	3980 311984	DENIS FEDOROV	{"email": "fedorovd1963@postgrespro.ru", "phone": "+70899696455"}
0005433345108	0174D0	4257 507159	ELENA KUZNECOVA	{"phone": "+70361843442"}
0005433345109	0174D0	2943 822238	ALEKSANDR MOISEEV	{"phone": "+70206351144"}
0005433345110	F005A0	5309 804985	DMITRIY SERGEEV	{"phone": "+70826587453"}
0005433345111	73CE02	9903 847906	ALSU DAVYDOVA	{"phone": "+70664622780"}
0005433345112	2783EA	1001 194548	PAVEL MELNIKOV	{"phone": "+70904805062"}
0005433345113	2783EA	7237 622890	YURIY SCHERBAKOV	{"email": "y_scherbakov_1967@postgrespro.ru", "phone": "+70093068652"}
0005433345114	2783EA	8421 496971	SVETLANA MEDVEDEVA	{"phone": "+70641337087"}
0005433345115	2783EA	0502 719472	ANATOLIY MIKHAYLOV	{"email": "a-mikhaylov17031972@postgrespro.ru", "phone": "+70190423935"}
0005433345116	2933BF	3384 063172	ELIZAVETA PETROVA	{"email": "petrova.elizaveta.08111980@postgrespro.ru", "phone": "+70868915068"}
0005433345117	2933BF	2196 240689	RAVIL MATVEEV	{"email": "ravil_matveev-1967@postgrespro.ru", "phone": "+70192346651"}
0005433345118	2933BF	2617 182844	VITALIY SAVELEV	{"phone": "+70585700826"}
0005433345119	05F26C	9568 331849	NADEZHDA ANDREEVA	{"phone": "+70096006338"}
0005433345120	05F26C	2514 657203	EVGENIY SCHERBAKOV	{"phone": "+70137486027"}
0005433345121	0A255C	1187 068606	NATALYA KUZNECOVA	{"phone": "+70870438526"}
0005433345122	0A255C	5209 566329	TATYANA MARTYNOVA	{"email": "tatyana.martynova1965@postgrespro.ru", "phone": "+70749010383"}
0005433345123	0A255C	6625 519488	PAVEL KOZLOV	{"email": "kozlov_pavel-121965@postgrespro.ru", "phone": "+70472136758"}
0005433345124	7AB8C5	9109 651214	NIKOLAY TIKHONOV	{"phone": "+70551674921"}
0005433345125	BB8634	5160 965398	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev.021968@postgrespro.ru", "phone": "+70186365328"}
0005433345126	BB8634	5314 755467	SERGEY PETROV	{"email": "petrov_s.01111968@postgrespro.ru", "phone": "+70415202812"}
0005433345127	033B40	0859 773522	VALENTINA ILINA	{"email": "ilina_v091973@postgrespro.ru", "phone": "+70259121223"}
0005433345128	1D7401	3799 409494	NIKOLAY MAKAROV	{"phone": "+70870877817"}
0005433345129	1D7401	2883 236628	VLADISLAV KOZLOV	{"email": "v-kozlov_05101972@postgrespro.ru", "phone": "+70212045084"}
0005433345130	6A97A8	8426 329368	VITALIY VASILEV	{"phone": "+70330955837"}
0005433345131	6A97A8	7253 213145	GRIGORIY FEDOROV	{"email": "fedorov_g07021984@postgrespro.ru", "phone": "+70705352479"}
0005433345132	6F72C2	3789 199778	SVETLANA KOROLEVA	{"email": "korolevasvetlana_24051976@postgrespro.ru", "phone": "+70424262287"}
0005433345133	6F72C2	3931 415074	YULIYA PAVLOVA	{"email": "pavlova_yuliya-03091969@postgrespro.ru", "phone": "+70680890681"}
0005433345134	17DB8B	0019 987167	LYUDMILA CHERNOVA	{"phone": "+70609903449"}
0005433345135	C89476	0665 664549	IVAN GORBUNOV	{"phone": "+70599372799"}
0005433345136	5F61D3	6916 446965	LIDIYA ANDREEVA	{"email": "l-andreeva1963@postgrespro.ru", "phone": "+70714230535"}
0005433345137	7262C1	4739 315209	ELENA SCHERBAKOVA	{"phone": "+70585572594"}
0005433345138	7262C1	3553 496383	ALEKSANDR STEPANOV	{"email": "a-stepanov-09091968@postgrespro.ru", "phone": "+70076950906"}
0005433345139	AC4376	0457 613593	VALENTINA FILIPPOVA	{"email": "filippova-valentina.1967@postgrespro.ru", "phone": "+70059823420"}
0005433345140	AC4376	4601 715382	SERGEY SEMENOV	{"email": "s.semenov_1969@postgrespro.ru", "phone": "+70368815313"}
0005433345141	B97925	8088 727677	VALENTINA EGOROVA	{"phone": "+70687963939"}
0005433345142	B97925	1959 200936	YURIY KAZAKOV	{"email": "yuriy-kazakov_1971@postgrespro.ru", "phone": "+70485386364"}
0005433345143	44B41B	0117 186296	ALEKSANDR POPOV	{"email": "popov-aleksandr.01071968@postgrespro.ru", "phone": "+70965077524"}
0005433345144	AB1485	6910 512206	ARTEM ZHURAVLEV	{"phone": "+70281980372"}
0005433345145	D1FF74	5521 810487	VLADIMIR MOISEEV	{"email": "vladimir-moiseev.1976@postgrespro.ru", "phone": "+70797226690"}
0005433345146	D1FF74	3357 804813	DMITRIY RODIONOV	{"email": "dmitriy-rodionov-051980@postgrespro.ru", "phone": "+70675433360"}
0005433345147	2CF870	6495 856430	EKATERINA ZAKHAROVA	{"email": "zakharova.e03011977@postgrespro.ru", "phone": "+70940545018"}
0005433345148	E695FE	9517 498545	VALENTINA TIKHONOVA	{"phone": "+70164172034"}
0005433345149	E695FE	2255 406055	EGOR FOMIN	{"email": "fomin.e1969@postgrespro.ru", "phone": "+70185761423"}
0005433345150	E695FE	4258 816917	SERGEY KUZMIN	{"phone": "+70409143234"}
0005433345151	BDF0F0	9642 241944	DMITRIY KOZLOV	{"phone": "+70667932392"}
0005433345152	8803CF	4408 809963	VALENTINA FILIPPOVA	{"phone": "+70799337906"}
0005433345153	40C243	6419 618971	SERGEY ZAKHAROV	{"phone": "+70542361412"}
0005433345155	7552FC	9194 080375	SVETLANA IVANOVA	{"phone": "+70634956644"}
0005433345156	A4CAF6	2537 188966	IGOR MARTYNOV	{"email": "igor_martynov-17071970@postgrespro.ru", "phone": "+70548660886"}
0005433345157	3029E3	5579 233479	VERONIKA ORLOVA	{"email": "veronikaorlova.19111956@postgrespro.ru", "phone": "+70046930583"}
0005433345158	BF1312	3502 432235	ELENA DAVYDOVA	{"email": "davydova.e1974@postgrespro.ru", "phone": "+70174616085"}
0005433345159	C2E876	7688 500989	ALEKSANDR ALEKSANDROV	{"phone": "+70940363707"}
0005433345160	B052D2	6675 257099	ANZHELIKA TARASOVA	{"phone": "+70092393643"}
0005433345161	5054F4	6330 516173	VIKTOR MAKAROV	{"email": "makarov-v-1968@postgrespro.ru", "phone": "+70263372705"}
0005433345162	3E5764	9014 518820	DMITRIY VASILEV	{"phone": "+70017620504"}
0005433345163	81F936	1763 177287	LYUDMILA PETROVA	{"phone": "+70844187784"}
0005433345164	2FA870	8050 915368	SALAVAT PETROV	{"email": "salavatpetrov.1985@postgrespro.ru", "phone": "+70443293028"}
0005433345165	2FA870	6912 936346	ELENA KULIKOVA	{"email": "ekulikova.1981@postgrespro.ru", "phone": "+70590336444"}
0005433345166	82C306	8160 667759	ALEKSANDR SOKOLOV	{"phone": "+70864322582"}
0005433345167	95DE6F	7771 534609	NATALYA YAKOVLEVA	{"phone": "+70128522864"}
0005433345168	95DE6F	8456 392185	SERGEY KARPOV	{"phone": "+70384664475"}
0005433345169	95DE6F	8621 017661	VLADIMIR YAKOVLEV	{"email": "yakovlev-vladimir.051967@postgrespro.ru", "phone": "+70206452174"}
0005433345170	1CFDAC	2295 731704	NATALYA AKIMOVA	{"phone": "+70929526901"}
0005433345171	2DBD97	9600 243163	POLINA TARASOVA	{"email": "polina-tarasova_091981@postgrespro.ru", "phone": "+70529436170"}
0005433345172	2DBD97	4631 436724	ANTON POPOV	{"phone": "+70271665074"}
0005433345173	B3C7A7	2164 999890	VLADIMIR ORLOV	{"email": "vorlov1965@postgrespro.ru", "phone": "+70710880255"}
0005433345174	4085AB	7929 653323	ALEKSANDRA ABRAMOVA	{"email": "abramova-aleksandra.1966@postgrespro.ru", "phone": "+70679578359"}
0005433345175	6EE134	5942 046473	KIRILL SOROKIN	{"email": "sorokin-kirill.111973@postgrespro.ru", "phone": "+70828485788"}
0005433345176	6EE134	1361 667939	MAKSIM MATVEEV	{"phone": "+70870429569"}
0005433345177	A37786	2361 732811	EVGENIY SIDOROV	{"email": "evgeniy_sidorov_28011974@postgrespro.ru", "phone": "+70997821517"}
0005433345178	A37786	0706 393539	TATYANA KOLESNIKOVA	{"phone": "+70841369187"}
0005433345179	A37786	2984 869747	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy20071968@postgrespro.ru", "phone": "+70246436956"}
0005433345180	37958C	2960 158359	IRINA KUDRYASHOVA	{"phone": "+70772637962"}
0005433345181	62EAB3	6701 434997	ANNA KULIKOVA	{"email": "kulikova_a.14031964@postgrespro.ru", "phone": "+70897816176"}
0005433345182	1D6891	5728 179499	TATYANA VOLKOVA	{"email": "tatyana.volkova.19091972@postgrespro.ru", "phone": "+70018635445"}
0005433345183	C56DAD	7779 191036	ANASTASIYA IVANOVA	{"email": "aivanova-08101980@postgrespro.ru", "phone": "+70523118456"}
0005433345184	C56DAD	5763 110884	NIKITA DMITRIEV	{"email": "dmitrievn101959@postgrespro.ru", "phone": "+70597748853"}
0005433345185	063FFF	4719 401567	TATYANA MEDVEDEVA	{"email": "tmedvedeva.081977@postgrespro.ru", "phone": "+70657202629"}
0005433345186	122C47	3747 146420	ELENA SOKOLOVA	{"email": "elena-sokolova-121973@postgrespro.ru", "phone": "+70575042084"}
0005433345187	86E60D	9460 829428	NATALYA KARPOVA	{"phone": "+70354245320"}
0005433345188	4AD1C4	4692 614889	RAFAEL KARPOV	{"phone": "+70442077340"}
0005433345189	4AD1C4	6368 323561	OKSANA GERASIMOVA	{"phone": "+70007409166"}
0005433345190	4AD1C4	7030 685949	MAKSIM ORLOV	{"email": "m.orlov1976@postgrespro.ru", "phone": "+70581882858"}
0005433345191	BC2EE2	9146 038929	DIANA NIKITINA	{"email": "nikitina_d.13061965@postgrespro.ru", "phone": "+70734112387"}
0005433345192	746D27	3115 537246	ALEKSANDR ZHURAVLEV	{"phone": "+70834863094"}
0005433345193	18EE17	2712 451945	IVAN KISELEV	{"phone": "+70153248058"}
0005433345194	F6E7BC	9062 976208	SERGEY GRIGOREV	{"phone": "+70235203231"}
0005433345195	F6E7BC	5038 539512	OKSANA TITOVA	{"email": "titova.o.02081978@postgrespro.ru", "phone": "+70220785562"}
0005433345196	157C86	4055 664651	YULIYA LEBEDEVA	{"email": "ylebedeva.31031964@postgrespro.ru", "phone": "+70843215559"}
0005433345197	156C9A	3676 514792	PETR GORBUNOV	{"email": "pgorbunov_02091963@postgrespro.ru", "phone": "+70013831267"}
0005433345198	156C9A	6887 849936	NATALYA KONDRATEVA	{"email": "natalya_kondrateva-031980@postgrespro.ru", "phone": "+70661781720"}
0005433345199	31CBFB	9817 067863	ALEKSEY MELNIKOV	{"email": "a_melnikov_071973@postgrespro.ru", "phone": "+70140580093"}
0005433345200	06358C	7381 293226	GALINA MAKAROVA	{"email": "makarova.g011976@postgrespro.ru", "phone": "+70472992650"}
0005433345201	74A1C5	8768 841041	VASILIY PAVLOV	{"email": "pavlov_v021958@postgrespro.ru", "phone": "+70792545996"}
0005433345202	74A1C5	4641 486539	VITALIY ISAEV	{"email": "v_isaev-22091979@postgrespro.ru", "phone": "+70747046957"}
0005433345203	45B8C1	0812 461385	PETR VOROBEV	{"email": "petrvorobev.111973@postgrespro.ru", "phone": "+70030327514"}
0005433345204	88885F	5648 711496	TAMARA EFIMOVA	{"phone": "+70717409486"}
0005433345205	88885F	4989 078971	ZAKHAR SCHERBAKOV	{"phone": "+70293759788"}
0005433345206	6012BB	4325 711543	SERGEY ROMANOV	{"email": "romanov.sergey_031969@postgrespro.ru", "phone": "+70156546606"}
0005433345207	6012BB	0089 726017	BORIS STEPANOV	{"phone": "+70934437594"}
0005433345208	1EED69	2175 945314	ANDREY RODIONOV	{"phone": "+70383053482"}
0005433345209	67811B	6343 359270	VITALIY PAVLOV	{"email": "pavlovv-071977@postgrespro.ru", "phone": "+70904402440"}
0005433345210	4F5116	2602 755182	ALEKSANDRA ZHURAVLEVA	{"phone": "+70903289421"}
0005433345211	4F5116	1806 106683	MARIYA EFIMOVA	{"email": "mariya-efimova031981@postgrespro.ru", "phone": "+70323741885"}
0005433345212	0AF6C5	5920 150125	MIKHAIL KUZMIN	{"phone": "+70826792389"}
0005433345213	3D0FAD	5720 260616	EKATERINA RODIONOVA	{"email": "erodionova-25051979@postgrespro.ru", "phone": "+70885643885"}
0005433345214	48FAE2	5763 468416	ALEKSEY ILIN	{"phone": "+70906589067"}
0005433345215	17E1A8	4849 026338	SERGEY DENISOV	{"email": "denisov.sergey1977@postgrespro.ru", "phone": "+70722014233"}
0005433345216	17E1A8	7327 533062	VALENTINA STEPANOVA	{"phone": "+70930932545"}
0005433345217	0CC279	7493 639703	ANDREY PETROV	{"phone": "+70193613417"}
0005433345218	0CC279	2287 608967	ANTON SAVELEV	{"email": "a_savelev_051974@postgrespro.ru", "phone": "+70871396552"}
0005433345219	EE9669	2450 933586	VITALIY MOISEEV	{"phone": "+70571290065"}
0005433345220	EE9669	5742 835968	INESSA SAVELEVA	{"email": "inessa_saveleva.1990@postgrespro.ru", "phone": "+70221627667"}
0005433345221	AF37A2	3603 736321	DMITRIY CHERNOV	{"email": "d_chernov30101973@postgrespro.ru", "phone": "+70855561058"}
0005433345222	8ABCA6	0654 770702	ILYA GRIGOREV	{"phone": "+70797694779"}
0005433345223	A5DA22	7610 097982	NIKOLAY OSIPOV	{"email": "osipov_n-14091966@postgrespro.ru", "phone": "+70497105613"}
0005433345224	1E7F16	4489 676149	ZINAIDA ILINA	{"phone": "+70040122092"}
0005433345225	D55651	5324 410431	VLADIMIR VOROBEV	{"email": "vorobevvladimir11041975@postgrespro.ru", "phone": "+70483475196"}
0005433345226	1BF9C9	5655 787188	DMITRIY OSIPOV	{"phone": "+70340669472"}
0005433345227	B2853B	6585 501590	VLADIMIR POPOV	{"phone": "+70257621106"}
0005433345228	B2853B	7836 620621	EVGENIY ANDREEV	{"phone": "+70675547122"}
0005433345229	4F6ED3	2964 315696	KLAVDIYA TARASOVA	{"phone": "+70206928475"}
0005433345230	4FDBE5	8608 060345	NADEZHDA KOROLEVA	{"email": "koroleva_n1974@postgrespro.ru", "phone": "+70811057256"}
0005433345231	A9572E	4930 843825	MARINA KISELEVA	{"phone": "+70334663512"}
0005433345232	98B10B	1200 448889	MIKHAIL SMIRNOV	{"phone": "+70085122599"}
0005433345233	CB9C86	0740 371747	MARINA MOISEEVA	{"phone": "+70104631446"}
0005433345234	CB9C86	9877 821094	VLADIMIR SIDOROV	{"phone": "+70321199928"}
0005433345235	B5B39A	9756 897030	IRINA DMITRIEVA	{"phone": "+70777385279"}
0005433345236	9BADE0	9235 775872	SVETLANA FILIPPOVA	{"phone": "+70708000883"}
0005433345237	284536	3006 875408	VIKTORIYA NESTEROVA	{"email": "viktoriya.nesterova061966@postgrespro.ru", "phone": "+70885349085"}
0005433345238	B384C1	1654 607966	VLADIMIR SOLOVEV	{"phone": "+70111079331"}
0005433345239	7D89B1	4809 142534	EVGENIY BARANOV	{"email": "e.baranov-17071968@postgrespro.ru", "phone": "+70777938243"}
0005433345240	D4355B	8830 783534	DMITRIY ALEKSANDROV	{"email": "aleksandrov_dmitriy.111980@postgrespro.ru", "phone": "+70745496997"}
0005433345241	D4355B	4541 768940	LIDIYA POPOVA	{"email": "popova_l-17061963@postgrespro.ru", "phone": "+70803485907"}
0005433345242	EBD648	5551 064685	OLGA MELNIKOVA	{"email": "melnikovao.041979@postgrespro.ru", "phone": "+70115322556"}
0005433345243	EFEBB9	5927 054136	ROMAN VOROBEV	{"phone": "+70599944156"}
0005433345244	609844	6812 682611	EVGENIY KUDRYASHOV	{"email": "ekudryashov.1977@postgrespro.ru", "phone": "+70358648069"}
0005433345245	609844	8266 947411	MIKHAIL POPOV	{"email": "popov_m-01031973@postgrespro.ru", "phone": "+70264913975"}
0005433345246	1862B8	9181 682732	RAISA RYABOVA	{"email": "ryabova_r1963@postgrespro.ru", "phone": "+70005465478"}
0005433345247	85029F	9329 607136	ANATOLIY DENISOV	{"email": "denisov-anatoliy1981@postgrespro.ru", "phone": "+70786590219"}
0005433345248	85029F	4655 823583	VLADIMIR POPOV	{"phone": "+70907582602"}
0005433345249	16AAA6	3949 977468	VALENTINA KULIKOVA	{"email": "valentina-kulikova.081979@postgrespro.ru", "phone": "+70096127916"}
0005433345250	6B1DD9	9373 309410	ANATOLIY MATVEEV	{"email": "matveev-anatoliy-02071966@postgrespro.ru", "phone": "+70392367876"}
0005433345251	6B1DD9	5810 810508	OLGA SOKOLOVA	{"phone": "+70802409053"}
0005433345252	552C75	1717 896215	ALEKSEY NIKOLAEV	{"phone": "+70227471020"}
0005433345253	552C75	3709 476611	VERA SOROKINA	{"phone": "+70519851502"}
0005433345254	3BCBBE	6477 085043	VITALIY ZAKHAROV	{"phone": "+70008120245"}
0005433345255	1B5E05	9395 613173	ANATOLIY TIKHONOV	{"phone": "+70106833859"}
0005433345256	2BFFEF	7772 648635	PETR NAUMOV	{"email": "naumovp-081968@postgrespro.ru", "phone": "+70411837044"}
0005433345257	FBEDE6	0967 362811	ARTUR MOROZOV	{"phone": "+70018027638"}
0005433345258	FBEDE6	7639 618652	MIKHAIL FEDOROV	{"phone": "+70602389525"}
0005433345259	3590C1	0506 377562	TATYANA NESTEROVA	{"email": "nesterovat1970@postgrespro.ru", "phone": "+70766372743"}
0005433345260	6D5A5A	4994 139428	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev061980@postgrespro.ru", "phone": "+70626704766"}
0005433345261	32C648	4634 858888	ALEKSANDR BARANOV	{"email": "baranov_aleksandr-051977@postgrespro.ru", "phone": "+70429934789"}
0005433345262	591825	6973 422879	ALEKSEY NOVIKOV	{"email": "novikova.1959@postgrespro.ru", "phone": "+70301920258"}
0005433345263	7B4706	5095 665086	NATALYA YAKOVLEVA	{"email": "yakovleva.natalya1967@postgrespro.ru", "phone": "+70202270490"}
0005433345264	F7B7EC	3964 385750	ANASTASIYA BARANOVA	{"email": "baranova_a_19091966@postgrespro.ru", "phone": "+70687151576"}
0005433345265	F7B7EC	9102 240442	OLGA NIKITINA	{"phone": "+70730322178"}
0005433345266	83A06A	2212 328731	SERGEY PAVLOV	{"email": "pavlov-s_121972@postgrespro.ru", "phone": "+70129943428"}
0005433345267	7AD44F	8144 935555	VASILIY KOZLOV	{"phone": "+70329385353"}
0005433345268	7AD44F	1137 547978	SERGEY TARASOV	{"email": "starasov_03061979@postgrespro.ru", "phone": "+70477818297"}
0005433345269	7AD44F	7036 957682	STANISLAV POPOV	{"phone": "+70236680679"}
0005433345270	3D1A09	2762 474082	VYACHESLAV KISELEV	{"email": "v_kiselev-061979@postgrespro.ru", "phone": "+70679252131"}
0005433345271	3D1A09	2057 680444	DENIS ISAEV	{"email": "d-isaev.11041977@postgrespro.ru", "phone": "+70938165500"}
0005433345272	A4C468	5445 309780	VALERIY KARPOV	{"email": "karpov-v-1958@postgrespro.ru", "phone": "+70536420031"}
0005433345273	A03429	5653 259543	ANDREY PETROV	{"email": "andrey-petrov.15021978@postgrespro.ru", "phone": "+70347749064"}
0005433345274	A03429	5021 367246	NIKOLAY MAKAROV	{"email": "nmakarov_101971@postgrespro.ru", "phone": "+70821898570"}
0005433345275	3AC0A7	6422 263504	ANTON MAKAROV	{"email": "anton.makarov021982@postgrespro.ru", "phone": "+70695084189"}
0005433345276	3AC0A7	1411 941573	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_11071976@postgrespro.ru", "phone": "+70435432151"}
0005433345277	32505D	3063 452919	MIKHAIL EGOROV	{"email": "egorov-m.1970@postgrespro.ru", "phone": "+70811520908"}
0005433345278	7662B8	9153 649531	SERGEY DAVYDOV	{"phone": "+70502588209"}
0005433345279	3A15CA	9285 539322	DMITRIY MAKSIMOV	{"phone": "+70592423947"}
0005433345280	1122B5	7956 419463	VENIAMIN EGOROV	{"email": "egorov.v_101984@postgrespro.ru", "phone": "+70261072627"}
0005433345281	E5D55E	1574 350506	ALEKSANDR NOVIKOV	{"phone": "+70058893296"}
0005433345282	E5D55E	0385 177553	ALLA EFREMOVA	{"email": "a.efremova-041969@postgrespro.ru", "phone": "+70379446390"}
0005433345283	1C74F2	9233 519514	VLADIMIR SAVELEV	{"phone": "+70755049028"}
0005433345284	22F39A	2066 842642	GALINA POPOVA	{"phone": "+70810364464"}
0005433345285	22F39A	3680 914096	DARYA GUSEVA	{"phone": "+70283965947"}
0005433345286	2E1963	4737 828678	DAVID IVANOV	{"phone": "+70907804651"}
0005433345287	93E59B	9808 011137	DENIS KUZNECOV	{"phone": "+70800675504"}
0005433345288	93E59B	3908 203844	ANNA OSIPOVA	{"email": "aosipova.1961@postgrespro.ru", "phone": "+70878904326"}
0005433345289	3B3308	2020 902040	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov-1969@postgrespro.ru", "phone": "+70952694839"}
0005433345290	3B3308	7201 054801	NATALYA EGOROVA	{"phone": "+70666534392"}
0005433345291	DBA07F	8010 197151	MARIYA TIKHONOVA	{"phone": "+70242440028"}
0005433345292	E3C422	5382 155996	ALEKSANDR GRIGOREV	{"email": "grigorev_a06071965@postgrespro.ru", "phone": "+70849829807"}
0005433345293	AB7E2E	1988 434413	EVGENIY NIKITIN	{"phone": "+70027457499"}
0005433345294	5D1C6B	4505 255663	GALINA GERASIMOVA	{"phone": "+70587481795"}
0005433345295	5D1C6B	2460 722050	GENNADIY KONOVALOV	{"email": "konovalov.g111971@postgrespro.ru", "phone": "+70885393001"}
0005433345296	9620CB	3573 071261	PETR BONDARENKO	{"email": "bondarenkopetr_16121963@postgrespro.ru", "phone": "+70885916877"}
0005433345297	36A797	5517 524423	NADEZHDA KOMAROVA	{"phone": "+70273247739"}
0005433345298	264E92	5093 947155	NATALYA KOROLEVA	{"phone": "+70826985723"}
0005433345299	F55952	0816 225319	OLEG IVANOV	{"email": "ivanov-o.121960@postgrespro.ru", "phone": "+70313216131"}
0005433345300	860678	3123 276401	VIKTOR SOROKIN	{"email": "vsorokin_091971@postgrespro.ru", "phone": "+70916602767"}
0005433345301	B24B23	7835 586375	SVETLANA MELNIKOVA	{"email": "s_melnikova_02011967@postgrespro.ru", "phone": "+70547866285"}
0005433345302	B24B23	6877 263292	ANTONINA TIKHONOVA	{"email": "tikhonova-antonina-1989@postgrespro.ru", "phone": "+70775348983"}
0005433345303	49719E	7163 587132	TATYANA KOVALEVA	{"phone": "+70927274781"}
0005433345304	49719E	6233 015688	IRINA KOVALEVA	{"email": "i.kovaleva_1972@postgrespro.ru", "phone": "+70893622213"}
0005433345305	F4D20E	1406 324139	VLADIMIR NOVIKOV	{"phone": "+70181900865"}
0005433345306	776E19	9736 919143	ALEKSANDR ZAKHAROV	{"email": "zakharova-06071970@postgrespro.ru", "phone": "+70617672438"}
0005433345307	776E19	6779 435917	YURIY CHERNOV	{"phone": "+70681460965"}
0005433345308	439D95	6324 031073	VASILIY STEPANOV	{"phone": "+70191360797"}
0005433345309	439D95	8309 321579	SERGEY RODIONOV	{"email": "rodionov_sergey_071975@postgrespro.ru", "phone": "+70485896958"}
0005433345310	5D5B17	3595 635015	ANNA IVANOVA	{"email": "annaivanova-11031974@postgrespro.ru", "phone": "+70686685013"}
0005433345311	255661	3995 216334	ALEKSANDRA EGOROVA	{"email": "aleksandra_egorova_031964@postgrespro.ru", "phone": "+70468917509"}
0005433345312	84DA03	8397 951730	NIKITA IVANOV	{"email": "nikita.ivanov_051976@postgrespro.ru", "phone": "+70442401689"}
0005433345313	84DA03	2971 206174	ELENA KOMAROVA	{"email": "elena-komarova-1969@postgrespro.ru", "phone": "+70664520263"}
0005433345314	B46270	6503 423088	LYUDMILA NIKIFOROVA	{"email": "nikiforoval_05121965@postgrespro.ru", "phone": "+70160829042"}
0005433345315	B46270	4332 662310	ANTON FEDOTOV	{"email": "anton.fedotov-30041969@postgrespro.ru", "phone": "+70831841735"}
0005433345316	6279A4	3856 691362	EKATERINA FROLOVA	{"phone": "+70755054631"}
0005433345317	6279A4	4752 744547	MARINA SMIRNOVA	{"email": "smirnova.m071961@postgrespro.ru", "phone": "+70110557842"}
0005433345318	F13B91	8670 672182	IRINA KOZLOVA	{"email": "i.kozlova-1982@postgrespro.ru", "phone": "+70340946420"}
0005433345319	F13B91	8950 377968	EKATERINA ZAKHAROVA	{"email": "ezakharova.20091969@postgrespro.ru", "phone": "+70906163956"}
0005433345320	6862AE	1070 214692	VALERIY NAUMOV	{"email": "vnaumov23121965@postgrespro.ru", "phone": "+70347115694"}
0005433345321	54108E	2779 021012	VERONIKA STEPANOVA	{"phone": "+70129812397"}
0005433345322	C1B0AD	9975 601289	MARIYA STEPANOVA	{"email": "stepanovam1968@postgrespro.ru", "phone": "+70047705367"}
0005433345323	53D121	7191 194685	ANZHELIKA MAKSIMOVA	{"phone": "+70170285048"}
0005433345324	64A1F1	9928 268616	ALEKSANDR IVANOV	{"phone": "+70667109226"}
0005433345325	9D928D	5604 114732	TATYANA KUZNECOVA	{"phone": "+70359803321"}
0005433345547	7370E1	0658 626101	ALEKSANDR NIKOLAEV	{"phone": "+70603755991"}
0005433345326	9D928D	5308 412521	VLADIMIR FILIPPOV	{"email": "v-filippov10111976@postgrespro.ru", "phone": "+70025003322"}
0005433345327	7EF84C	9241 978974	TATYANA CHERNOVA	{"email": "chernovatatyana_28071971@postgrespro.ru", "phone": "+70999135511"}
0005433345328	54E280	9323 397564	STANISLAV KARPOV	{"phone": "+70369539152"}
0005433345329	F3197C	2620 684586	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_g021971@postgrespro.ru", "phone": "+70624987217"}
0005433345330	774D60	5347 463656	NIKOLAY IVANOV	{"email": "n.ivanov.1960@postgrespro.ru", "phone": "+70512701974"}
0005433345331	752688	4694 658419	MARINA IVANOVA	{"email": "marina.ivanova1972@postgrespro.ru", "phone": "+70399573271"}
0005433345332	E11DCF	1361 575540	MARIYA VASILEVA	{"phone": "+70040920902"}
0005433345333	2E2AE7	0410 927596	OLGA KUZMINA	{"phone": "+70608938207"}
0005433345334	9E6959	7540 721311	SERGEY YAKOVLEV	{"email": "syakovlev-06021978@postgrespro.ru", "phone": "+70471529125"}
0005433345335	5A8EA4	3506 164175	LYUDMILA SMIRNOVA	{"phone": "+70272740088"}
0005433345336	700952	4063 232082	MARIYA ZAYCEVA	{"email": "mzayceva_27041967@postgrespro.ru", "phone": "+70805845248"}
0005433345337	700952	5928 137858	MAKSIM GRIGOREV	{"phone": "+70687313517"}
0005433345338	65499D	9650 207131	ALEKSEY ROMANOV	{"phone": "+70889684222"}
0005433345339	F549C4	2333 992310	TATYANA RODIONOVA	{"email": "rodionovat101968@postgrespro.ru", "phone": "+70215092410"}
0005433345340	FD503B	1414 474561	MIKHAIL ANDREEV	{"phone": "+70907857410"}
0005433345341	FD503B	5771 170060	IRINA MELNIKOVA	{"phone": "+70012225879"}
0005433345342	C6A224	9119 516630	RINAT DAVYDOV	{"phone": "+70892220446"}
0005433345343	EC0FDB	6018 598476	IVAN PAVLOV	{"email": "i_pavlov.25081968@postgrespro.ru", "phone": "+70453256459"}
0005433345344	DD0A53	1763 465678	ANATOLIY BONDARENKO	{"phone": "+70090682314"}
0005433345345	1E16D7	5925 661423	ANNA NESTEROVA	{"phone": "+70842505850"}
0005433345346	6EABC6	8631 609641	SVETLANA FOMINA	{"email": "svetlana.fomina.16011982@postgrespro.ru", "phone": "+70618735487"}
0005433345347	E4FEA5	0409 712336	KSENIYA STEPANOVA	{"email": "stepanova.k.121969@postgrespro.ru", "phone": "+70235784122"}
0005433345348	E4FEA5	3198 686489	YULIYA ILINA	{"phone": "+70829878937"}
0005433345349	FC4539	3916 908989	NATALYA LAZAREVA	{"phone": "+70637993484"}
0005433345350	FD1483	1225 635022	NIKOLAY KULIKOV	{"phone": "+70410187931"}
0005433345351	FD1483	5271 713920	MIKHAIL FEDOROV	{"email": "mikhail-fedorov1968@postgrespro.ru", "phone": "+70620371133"}
0005433345352	FD1483	3222 763421	POLINA SERGEEVA	{"email": "sergeeva_polina.1965@postgrespro.ru", "phone": "+70450021192"}
0005433345353	A315EA	3516 176874	OLESYA GAVRILOVA	{"email": "gavrilova_o_051970@postgrespro.ru", "phone": "+70647383717"}
0005433345354	A315EA	0427 704748	ANVAR SOLOVEV	{"phone": "+70384649787"}
0005433345355	67FD34	3440 884086	ANNA DMITRIEVA	{"email": "dmitrieva_anna031979@postgrespro.ru", "phone": "+70856842884"}
0005433345356	67FD34	6156 555172	LYUBOV KUZMINA	{"email": "kuzmina.l_081976@postgrespro.ru", "phone": "+70830062911"}
0005433345357	090F3B	5635 153419	PETR SMIRNOV	{"email": "smirnov.p.31031975@postgrespro.ru", "phone": "+70355014243"}
0005433345358	90A269	9811 343262	AYRAT ILIN	{"email": "ilin_a.1974@postgrespro.ru", "phone": "+70400468110"}
0005433345359	FD6E2A	0250 492664	VLADIMIR MAKAROV	{"email": "vladimir_makarov.1967@postgrespro.ru", "phone": "+70333184122"}
0005433345360	FAC8D9	4782 668770	ALLA KRASNOVA	{"phone": "+70684985221"}
0005433345361	FAC8D9	0877 574300	EKATERINA ABRAMOVA	{"email": "e-abramova1983@postgrespro.ru", "phone": "+70703324420"}
0005433345362	1C4A11	3812 534147	YURIY GORBUNOV	{"phone": "+70108369172"}
0005433345363	1C4A11	2807 731200	SVETLANA KONDRATEVA	{"phone": "+70545489905"}
0005433345364	133D4A	6075 205450	SVETLANA EFREMOVA	{"phone": "+70041075914"}
0005433345365	BF5AF2	5250 265850	OLEG STEPANOV	{"email": "stepanovoleg.031961@postgrespro.ru", "phone": "+70258618231"}
0005433345366	AF91EE	3780 481704	ELENA ANDREEVA	{"email": "andreeva.e.12111974@postgrespro.ru", "phone": "+70279923507"}
0005433345367	B37AFB	1526 262492	NATALYA MAKAROVA	{"email": "natalya.makarova.061985@postgrespro.ru", "phone": "+70203316791"}
0005433345368	69D243	0717 099540	MIKHAIL ALEKSANDROV	{"email": "m.aleksandrov1966@postgrespro.ru", "phone": "+70727244006"}
0005433345369	C3FA36	5376 769318	SERGEY GUSEV	{"phone": "+70199833743"}
0005433345370	C3FA36	8109 710389	MARIYA KOROLEVA	{"email": "mkoroleva081960@postgrespro.ru", "phone": "+70635368795"}
0005433345371	502691	2454 579235	MARAT MATVEEV	{"email": "marat_matveev.06011980@postgrespro.ru", "phone": "+70710095044"}
0005433345372	1C457D	5785 856431	ALEKSEY SOLOVEV	{"phone": "+70043158854"}
0005433345373	C4FABC	0150 766227	MARIYA KUZNECOVA	{"email": "kuznecova_mariya_121969@postgrespro.ru", "phone": "+70582514741"}
0005433345374	6E9711	5887 937881	TIMOFEY ALEKSEEV	{"email": "alekseevt_091984@postgrespro.ru", "phone": "+70620878898"}
0005433345375	6E9711	3248 579729	IRINA MELNIKOVA	{"phone": "+70606627554"}
0005433345376	8F4540	3116 177593	SERGEY NAZAROV	{"email": "nazarov_sergey-111971@postgrespro.ru", "phone": "+70244592492"}
0005433345377	65FBC2	6958 831157	VLADIMIR VOLKOV	{"phone": "+70474614123"}
0005433345378	7F1E6F	1495 011257	ANDREY MARTYNOV	{"phone": "+70459159087"}
0005433345379	960FC8	2289 342700	ELENA KRASNOVA	{"email": "krasnova.e031973@postgrespro.ru", "phone": "+70747672028"}
0005433345380	B61752	3549 432300	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov-1966@postgrespro.ru", "phone": "+70417081716"}
0005433345381	8C2210	3915 072964	OLGA YUDINA	{"phone": "+70860887199"}
0005433345382	0D3FD9	1231 294577	SERGEY FOMIN	{"email": "sfomin-23041968@postgrespro.ru", "phone": "+70518389337"}
0005433345383	F4981C	4674 324309	MIKHAIL NIKITIN	{"email": "m_nikitin_091957@postgrespro.ru", "phone": "+70275436779"}
0005433345384	105072	0389 379861	IRINA BARANOVA	{"phone": "+70251682321"}
0005433345385	F129F5	3872 008604	TATYANA MOISEEVA	{"phone": "+70032412690"}
0005433345386	F129F5	6298 034221	DMITRIY MARTYNOV	{"phone": "+70321183041"}
0005433345387	F129F5	4943 951758	MARIYA BARANOVA	{"phone": "+70740499452"}
0005433345388	105961	5438 487589	SVETLANA SIDOROVA	{"phone": "+70204007664"}
0005433345389	54D6C5	6190 558382	YULIYA SERGEEVA	{"email": "y_sergeeva.1974@postgrespro.ru", "phone": "+70451619139"}
0005433345390	20DBCF	6616 321932	VALERIY KUZNECOV	{"email": "kuznecovvaleriy03011976@postgrespro.ru", "phone": "+70775751293"}
0005433345391	9538F6	7951 105778	LYUDMILA SOLOVEVA	{"phone": "+70521704422"}
0005433345392	A42F0D	7582 446926	NADEZHDA IVANOVA	{"email": "ivanovan071970@postgrespro.ru", "phone": "+70873732869"}
0005433345393	A42F0D	6530 436333	DMITRIY ZHURAVLEV	{"phone": "+70268732254"}
0005433345394	12583F	7537 741583	VIOLETTA ABRAMOVA	{"email": "violetta_abramova.21121969@postgrespro.ru", "phone": "+70755241525"}
0005433345395	BE05E4	8185 058350	ANDREY SCHERBAKOV	{"email": "scherbakov-a.18041970@postgrespro.ru", "phone": "+70344145141"}
0005433345396	0E565E	4730 311068	EKATERINA FROLOVA	{"phone": "+70912361053"}
0005433345397	AADE51	7828 838153	EVGENIY AFANASEV	{"email": "evgeniy_afanasev071969@postgrespro.ru", "phone": "+70780788946"}
0005433345398	A93132	7402 952426	LYUDMILA ANDREEVA	{"email": "andreeva.l051962@postgrespro.ru", "phone": "+70567167903"}
0005433345399	A93132	5496 337848	MARINA OSIPOVA	{"email": "marina-osipova05021977@postgrespro.ru", "phone": "+70551081762"}
0005433345400	9FFB59	9233 740431	ALEKSEY IVANOV	{"email": "a-ivanov-08041971@postgrespro.ru", "phone": "+70544615443"}
0005433345401	ADB290	7886 730120	ANATOLIY PAVLOV	{"email": "pavlov-a.021972@postgrespro.ru", "phone": "+70193521362"}
0005433345402	5B99A5	2562 782690	NIKOLAY MELNIKOV	{"email": "n.melnikov_1970@postgrespro.ru", "phone": "+70605859505"}
0005433345403	D6E9E1	3098 767495	MARINA ZAYCEVA	{"email": "marina_zayceva.11111968@postgrespro.ru", "phone": "+70811318919"}
0005433345404	D6E9E1	7230 763815	EVDOKIYA KUDRYASHOVA	{"email": "kudryashova_evdokiya-1970@postgrespro.ru", "phone": "+70506736864"}
0005433345405	4A08AC	4492 791898	ALEKSEY KULIKOV	{"email": "akulikov_021968@postgrespro.ru", "phone": "+70485399037"}
0005433345406	C3747E	0399 307740	DENIS MOISEEV	{"email": "moiseev-denis.11041978@postgrespro.ru", "phone": "+70094407004"}
0005433345407	C3747E	3488 386636	DMITRIY ANDREEV	{"phone": "+70154519914"}
0005433345408	083473	1889 650714	IRINA PETROVA	{"email": "petrova.irina30031969@postgrespro.ru", "phone": "+70011815511"}
0005433345409	083473	2375 773794	DMITRIY MAKSIMOV	{"email": "maksimov-dmitriy.16051971@postgrespro.ru", "phone": "+70938054707"}
0005433345410	083473	4102 525245	INNA KARPOVA	{"email": "i.karpova_121974@postgrespro.ru", "phone": "+70330964856"}
0005433345411	CA5FAE	9162 413991	VLADISLAV ZHUKOV	{"phone": "+70171050322"}
0005433345412	1E67B0	2824 547187	ARTEM MOROZOV	{"email": "morozov-a.121956@postgrespro.ru", "phone": "+70112729197"}
0005433345413	52A064	9727 097492	SVETLANA MIRONOVA	{"phone": "+70212388511"}
0005433345414	52A064	0728 199377	ALEKSANDR KUZMIN	{"phone": "+70393502975"}
0005433345415	AC8950	7433 670369	SEMEN MAKAROV	{"email": "makarov_semen_1971@postgrespro.ru", "phone": "+70215713170"}
0005433345416	AC8950	9138 733679	ALEKSEY STEPANOV	{"phone": "+70218035793"}
0005433345417	D927D5	6423 600682	IRINA ABRAMOVA	{"email": "irina-abramova_1996@postgrespro.ru", "phone": "+70744523774"}
0005433345418	7C6184	2653 726261	OLGA FROLOVA	{"email": "frolova.olga.27111969@postgrespro.ru", "phone": "+70925834812"}
0005433345419	369273	2231 144472	VLADIMIR OSIPOV	{"email": "osipov_vladimir_12041973@postgrespro.ru", "phone": "+70062803592"}
0005433345420	369273	6617 551353	ELENA KUZMINA	{"email": "elena_kuzmina.1979@postgrespro.ru", "phone": "+70448170383"}
0005433345421	369273	3380 959542	SVETLANA MASLOVA	{"email": "svetlana-maslova_25081981@postgrespro.ru", "phone": "+70737617786"}
0005433345422	5A70B9	3207 798555	NINA ANDREEVA	{"email": "andreeva.nina021970@postgrespro.ru", "phone": "+70161154210"}
0005433345423	23E19E	3353 378124	ALEKSANDR DAVYDOV	{"phone": "+70472716584"}
0005433345424	6D7268	8638 050117	ANNA BORISOVA	{"email": "borisova.a_111978@postgrespro.ru", "phone": "+70932845274"}
0005433345425	36F2B5	7091 180898	OLEG VOROBEV	{"phone": "+70907117323"}
0005433345426	36F2B5	7978 297045	NATALYA MEDVEDEVA	{"email": "medvedeva.n-18121966@postgrespro.ru", "phone": "+70592809846"}
0005433345427	75CDA5	7532 819606	SERGEY VASILEV	{"email": "s-vasilev.091970@postgrespro.ru", "phone": "+70101060042"}
0005433345428	75CDA5	4823 845747	YULIYA LEBEDEVA	{"email": "lebedeva_yuliya_07011967@postgrespro.ru", "phone": "+70155431436"}
0005433345429	6568D1	6509 487423	NIKOLAY VOLKOV	{"phone": "+70624977650"}
0005433345430	F0D61F	1280 749143	YULIYA KOVALEVA	{"email": "ykovaleva111977@postgrespro.ru", "phone": "+70674765080"}
0005433345431	F0D61F	7353 878091	YURIY SAVELEV	{"email": "y-savelev_1976@postgrespro.ru", "phone": "+70161685953"}
0005433345488	31DD1B	6385 421627	NATALYA SMIRNOVA	{"phone": "+70120368244"}
0005433345432	24FF13	4513 157180	SERGEY MOROZOV	{"email": "morozov-sergey.1962@postgrespro.ru", "phone": "+70299392048"}
0005433345433	24FF13	3219 591745	ANATOLIY MEDVEDEV	{"email": "anatoliy-medvedev-29071970@postgrespro.ru", "phone": "+70855476409"}
0005433345434	EBD8BC	8224 640657	VIKTORIYA MAKAROVA	{"email": "viktoriya.makarova_1973@postgrespro.ru", "phone": "+70185056926"}
0005433345435	51BBB0	3396 372139	MAKSIM EGOROV	{"email": "megorov.061976@postgrespro.ru", "phone": "+70052094115"}
0005433345436	44398A	8185 649091	ANDREY KULIKOV	{"email": "akulikov_031955@postgrespro.ru", "phone": "+70827606203"}
0005433345437	44398A	8152 509248	ANASTASIYA SOKOLOVA	{"phone": "+70164584223"}
0005433345438	CCFC1F	1002 128865	OKSANA IVANOVA	{"email": "ivanova_oksana.091977@postgrespro.ru", "phone": "+70183266973"}
0005433345439	CCFC1F	6693 709711	NINA KAZAKOVA	{"email": "kazakova-nina_21081966@postgrespro.ru", "phone": "+70339719470"}
0005433345440	CE5FBF	2759 758189	ALEKSANDR KUZNECOV	{"phone": "+70651685740"}
0005433345441	BDC70E	1161 217510	OLGA KULIKOVA	{"phone": "+70858925672"}
0005433345442	B85A57	1386 543823	RAISA ALEKSANDROVA	{"phone": "+70704771164"}
0005433345443	D8EEE1	3647 499616	EVGENIYA LAZAREVA	{"email": "lazareva_e.24111978@postgrespro.ru", "phone": "+70228483191"}
0005433345444	D8EEE1	5398 076869	VERA IVANOVA	{"email": "vera-ivanova_1981@postgrespro.ru", "phone": "+70758295595"}
0005433345445	D8EEE1	0738 110112	ALEKSEY ROMANOV	{"email": "romanov.aleksey-29041977@postgrespro.ru", "phone": "+70500998276"}
0005433345446	812B1C	4812 226785	NADEZHDA TIKHONOVA	{"email": "ntikhonova.17061977@postgrespro.ru", "phone": "+70199800502"}
0005433345447	49442F	9629 810096	OLGA PAVLOVA	{"email": "pavlovaolga-041969@postgrespro.ru", "phone": "+70733405384"}
0005433345448	5695C5	2724 349249	NATALYA ORLOVA	{"email": "orlovan-1972@postgrespro.ru", "phone": "+70869683718"}
0005433345449	C0F149	4506 578090	ILYA STEPANOV	{"email": "ilya-stepanov.1974@postgrespro.ru", "phone": "+70121559845"}
0005433345450	C11105	7517 112797	EVDOKIYA BORISOVA	{"phone": "+70502606774"}
0005433345451	C11105	8373 478154	YURIY STEPANOV	{"phone": "+70832568851"}
0005433345452	19A8DE	4207 690484	VERA KUZMINA	{"email": "v.kuzmina21081974@postgrespro.ru", "phone": "+70193658242"}
0005433345453	17562E	8036 592837	ANDREY ANTONOV	{"email": "antonova051971@postgrespro.ru", "phone": "+70590668909"}
0005433345454	475657	6088 140948	GALINA POPOVA	{"email": "g_popova.22031962@postgrespro.ru", "phone": "+70510588442"}
0005433345455	475657	4844 361116	EKATERINA MAKAROVA	{"email": "makarova-e_25041965@postgrespro.ru", "phone": "+70363091568"}
0005433345456	11A0F3	3727 422013	GALINA ZHURAVLEVA	{"phone": "+70192377810"}
0005433345457	1884F9	9374 363390	GULNARA KRASNOVA	{"email": "gulnarakrasnova-1977@postgrespro.ru", "phone": "+70473397749"}
0005433345458	05F2D5	3282 001283	MARINA ALEKSEEVA	{"phone": "+70860532985"}
0005433345459	32FFFF	9597 749681	ALEKSANDR FEDOROV	{"phone": "+70562641536"}
0005433345460	6E2928	4326 416699	OLEG ROMANOV	{"email": "o.romanov_17011974@postgrespro.ru", "phone": "+70355757484"}
0005433345461	424006	6703 775026	ELENA DAVYDOVA	{"phone": "+70854389308"}
0005433345462	D065EF	3161 586358	ARTEM ORLOV	{"phone": "+70946358929"}
0005433345463	D065EF	1734 249570	NADEZHDA MELNIKOVA	{"email": "melnikova-nadezhda.01091975@postgrespro.ru", "phone": "+70133781311"}
0005433345464	48A6CA	3278 491829	GALINA FADEEVA	{"email": "g-fadeeva.17121975@postgrespro.ru", "phone": "+70392541499"}
0005433345465	48A6CA	4516 214876	DMITRIY GERASIMOV	{"phone": "+70287819262"}
0005433345466	BD0446	8875 444269	PETR ABRAMOV	{"email": "petr_abramov1973@postgrespro.ru", "phone": "+70362033479"}
0005433345467	5DC67C	9091 042134	DMITRIY ZAKHAROV	{"phone": "+70136520177"}
0005433345468	88C8A3	5656 036217	LYUDMILA DENISOVA	{"phone": "+70474366610"}
0005433345469	1B4E20	6132 484029	ALEKSEY VASILEV	{"phone": "+70398642871"}
0005433345470	1B4E20	6457 066558	RITA IVANOVA	{"email": "ivanova-rita.25121962@postgrespro.ru", "phone": "+70151478794"}
0005433345471	B4F104	1844 697619	VALENTINA DMITRIEVA	{"phone": "+70855560383"}
0005433345472	3B812C	7277 821436	SERGEY SERGEEV	{"phone": "+70678097738"}
0005433345473	3B812C	5909 733762	TATYANA NAZAROVA	{"phone": "+70317125609"}
0005433345474	46CEBA	7476 158392	NIKOLAY MOISEEV	{"email": "n-moiseev.111973@postgrespro.ru", "phone": "+70218643061"}
0005433345475	46CEBA	2276 754417	IRINA SCHERBAKOVA	{"phone": "+70220331246"}
0005433345476	DDA620	2431 320619	OLGA MELNIKOVA	{"phone": "+70274846189"}
0005433345477	10A54C	8449 850027	ILNUR ZHURAVLEV	{"phone": "+70441836893"}
0005433345478	8B8297	7705 861771	NINA MOROZOVA	{"email": "nina_morozova-08081970@postgrespro.ru", "phone": "+70636748948"}
0005433345479	8B8297	8506 665604	MARIYA VOLKOVA	{"email": "volkova_m_1972@postgrespro.ru", "phone": "+70816885596"}
0005433345480	1ED652	3004 234854	YULIYA ZAKHAROVA	{"phone": "+70117261068"}
0005433345481	AD4A86	8217 597590	ALEKSANDR VOLKOV	{"phone": "+70709107622"}
0005433345482	66B6BA	4185 485499	SERGEY MIKHAYLOV	{"email": "mikhaylov_s.021969@postgrespro.ru", "phone": "+70305696156"}
0005433345483	66B6BA	9059 701425	VIKTOR IVANOV	{"email": "v-ivanov.27021968@postgrespro.ru", "phone": "+70985161874"}
0005433345484	66B6BA	1287 783872	OLGA MIKHAYLOVA	{"email": "mikhaylova.o_04041967@postgrespro.ru", "phone": "+70682407033"}
0005433345485	6EB145	9645 891897	MARIYA ILINA	{"email": "mariya-ilina.07111967@postgrespro.ru", "phone": "+70985716381"}
0005433345486	6EB145	2932 372324	GENNADIY SCHERBAKOV	{"email": "g-scherbakov-1981@postgrespro.ru", "phone": "+70248926126"}
0005433345487	757F8A	3640 655702	LYUBOV KOZLOVA	{"email": "kozlovalyubov.12061963@postgrespro.ru", "phone": "+70693339956"}
0005433345489	AF1D56	8378 566762	ANNA FEDOROVA	{"phone": "+70328606577"}
0005433345490	161331	7548 703164	ALEKSANDR POPOV	{"email": "popov_a-061967@postgrespro.ru", "phone": "+70766312787"}
0005433345491	24C153	2847 144523	ALEKSANDR AFANASEV	{"email": "a-afanasev-1969@postgrespro.ru", "phone": "+70132981410"}
0005433345492	DF5D4E	9080 070830	VIKTORIYA MOISEEVA	{"email": "viktoriya.moiseeva.1973@postgrespro.ru", "phone": "+70009616884"}
0005433345493	BD9E26	4995 119499	VASILIY KAZAKOV	{"email": "vasiliy_kazakov_1971@postgrespro.ru", "phone": "+70295539954"}
0005433345494	BD9E26	4650 246955	TATYANA ANTONOVA	{"phone": "+70339791056"}
0005433345495	7AEC8E	5777 119438	ALEKSEY KRASNOV	{"email": "krasnova_011974@postgrespro.ru", "phone": "+70767308079"}
0005433345496	7AEC8E	1206 365679	ELENA VOLKOVA	{"email": "volkova.elena.07051978@postgrespro.ru", "phone": "+70383904206"}
0005433345497	D63075	8472 625630	MIKHAIL ANDREEV	{"email": "andreev_mikhail_01061963@postgrespro.ru", "phone": "+70590342343"}
0005433345498	D63075	9213 271513	TATYANA BELOVA	{"email": "belova.t-1976@postgrespro.ru", "phone": "+70153803671"}
0005433345499	BB7568	2981 596323	ZINAIDA ALEKSANDROVA	{"phone": "+70747647996"}
0005433345500	BB7568	7598 252069	LARISA POLYAKOVA	{"email": "polyakova_larisa1977@postgrespro.ru", "phone": "+70888086964"}
0005433345501	4C3CEE	4559 392833	SOFYA MIKHAYLOVA	{"phone": "+70373872947"}
0005433345502	54A23B	8008 869637	EMMA MOROZOVA	{"email": "morozova.e-051973@postgrespro.ru", "phone": "+70704822456"}
0005433345503	54A23B	1687 395594	EKATERINA NESTEROVA	{"email": "nesterova.ekaterina-19061972@postgrespro.ru", "phone": "+70084337687"}
0005433345504	3E09BE	4933 840973	NATALYA KOMAROVA	{"email": "n-komarova.1968@postgrespro.ru", "phone": "+70044896244"}
0005433345505	3E09BE	9843 750258	ANNA SIDOROVA	{"email": "sidorovaanna21121970@postgrespro.ru", "phone": "+70586063362"}
0005433345868	986042	4440 733518	MATRENA MAKAROVA	{"phone": "+70073928896"}
0005433345506	4EF693	1559 338239	VITALIY BORISOV	{"email": "borisov-v-02021965@postgrespro.ru", "phone": "+70842709523"}
0005433345507	4EF693	8745 846926	SVETLANA ZHUKOVA	{"email": "svetlana_zhukova_09111960@postgrespro.ru", "phone": "+70862874684"}
0005433345508	4EF693	4626 188102	IGOR ZHURAVLEV	{"phone": "+70074829712"}
0005433345509	3E62FF	4457 355285	YULIYA ZAYCEVA	{"phone": "+70066374553"}
0005433345510	CDEC25	4440 608279	IRINA IVANOVA	{"phone": "+70034243080"}
0005433345511	37831F	6777 893095	OLGA MIRONOVA	{"email": "olgamironova.111965@postgrespro.ru", "phone": "+70893106006"}
0005433345512	B7BFD5	9135 425618	DMITRIY SIDOROV	{"email": "dmitriy.sidorov.26071972@postgrespro.ru", "phone": "+70039086037"}
0005433345513	19C87A	2380 648730	EKATERINA POPOVA	{"phone": "+70973729260"}
0005433345514	557115	6470 197564	KONSTANTIN CHERNOV	{"phone": "+70673108017"}
0005433345515	6B139E	3487 187652	ANATOLIY IVANOV	{"email": "ivanov_anatoliy-11091960@postgrespro.ru", "phone": "+70113734892"}
0005433345516	8CA99A	2879 154651	LYUDMILA NAUMOVA	{"email": "lnaumova-1970@postgrespro.ru", "phone": "+70673411784"}
0005433345517	B01BF2	1264 391979	MARGARITA SMIRNOVA	{"email": "smirnova.margarita_1958@postgrespro.ru", "phone": "+70042261188"}
0005433345518	B01BF2	6722 204447	RUSTEM FILIPPOV	{"email": "r-filippov_091977@postgrespro.ru", "phone": "+70916840765"}
0005433345519	6C6629	6750 568815	NIKOLAY NAZAROV	{"phone": "+70447032010"}
0005433345520	7AB9D4	7768 589329	ANATOLIY MAKAROV	{"phone": "+70907243671"}
0005433345521	7A88F3	6780 321992	NATALYA MALYSHEVA	{"email": "natalya-malysheva1978@postgrespro.ru", "phone": "+70971130388"}
0005433345522	7A88F3	1427 600375	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov_1972@postgrespro.ru", "phone": "+70705672438"}
0005433345523	7A88F3	4652 461128	ANDREY SHEVCHENKO	{"email": "a_shevchenko071975@postgrespro.ru", "phone": "+70652695221"}
0005433345524	B02DEE	5236 995511	OLGA POPOVA	{"phone": "+70039796315"}
0005433345525	B02DEE	2386 069143	EVGENIY STEPANOV	{"email": "stepanov_evgeniy_071983@postgrespro.ru", "phone": "+70920696490"}
0005433345526	AB9641	9129 348849	MARIYA POPOVA	{"phone": "+70361165024"}
0005433345527	EF7659	7050 155788	LYUBOV FEDOROVA	{"email": "fedoroval_02121958@postgrespro.ru", "phone": "+70912811174"}
0005433345528	EDC475	8155 480322	VALENTIN KUZNECOV	{"email": "v.kuznecov_081966@postgrespro.ru", "phone": "+70097776789"}
0005433345529	0E4508	8756 647318	ELENA SOROKINA	{"phone": "+70948198580"}
0005433345530	316941	8738 155316	IVAN SEMENOV	{"email": "semenov_ivan-071968@postgrespro.ru", "phone": "+70229635055"}
0005433345531	8AFEB3	0447 183557	MARIYA LUKYANOVA	{"phone": "+70588862308"}
0005433345532	8AFEB3	3956 260450	OLGA VLASOVA	{"phone": "+70554798633"}
0005433345533	9A6DC4	7090 312646	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin-051975@postgrespro.ru", "phone": "+70604576558"}
0005433345534	0F50FD	1097 779293	ALINA ZHUKOVA	{"phone": "+70496116712"}
0005433345535	0F50FD	3719 549432	EKATERINA FOMINA	{"phone": "+70913515146"}
0005433345536	04D171	1333 992117	VLADIMIR MELNIKOV	{"phone": "+70579860159"}
0005433345537	F3B3FC	0470 130453	SERGEY DENISOV	{"email": "denisov.s_1970@postgrespro.ru", "phone": "+70023138847"}
0005433345538	D68618	2632 561136	ALEKSANDR RODIONOV	{"phone": "+70830353932"}
0005433345539	617F24	4237 886594	SERGEY ZHURAVLEV	{"email": "zhuravlev.sergey1977@postgrespro.ru", "phone": "+70132521655"}
0005433345540	6104C3	3283 426028	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr.06071962@postgrespro.ru", "phone": "+70325271530"}
0005433345541	92C171	9782 614823	KSENIYA BELYAEVA	{"phone": "+70546002370"}
0005433345542	2F7E62	2266 252702	ELENA DAVYDOVA	{"email": "edavydova_1984@postgrespro.ru", "phone": "+70486810621"}
0005433345543	647296	3937 403201	MIKHAIL DENISOV	{"email": "mikhail_denisov_1985@postgrespro.ru", "phone": "+70115066115"}
0005433345544	823A55	9534 267679	VALENTIN ABRAMOV	{"email": "vabramov-011979@postgrespro.ru", "phone": "+70045953654"}
0005433345545	4B1393	2710 854571	OLESYA ANDREEVA	{"phone": "+70462231827"}
0005433345546	4B1393	1526 695073	ARTEM EGOROV	{"email": "egorov.artem_30031966@postgrespro.ru", "phone": "+70139803117"}
0005433345548	7370E1	2814 908473	BORIS KUZNECOV	{"phone": "+70330556803"}
0005433345549	041452	4732 046118	OKSANA MOROZOVA	{"email": "morozova_oksana1967@postgrespro.ru", "phone": "+70366625219"}
0005433345550	F1B321	6427 103548	SERGEY NOVIKOV	{"email": "novikov-s.14041981@postgrespro.ru", "phone": "+70396723867"}
0005433345551	3AC021	8507 600219	ANASTASIYA MARTYNOVA	{"phone": "+70127585401"}
0005433345552	7E0A56	3338 822456	ELENA KULIKOVA	{"phone": "+70916882402"}
0005433345553	7E0A56	7594 806018	ANNA GAVRILOVA	{"phone": "+70971166112"}
0005433345554	3D2809	8637 301871	DANILA IVANOV	{"email": "ivanov.danila.1966@postgrespro.ru", "phone": "+70228883852"}
0005433345555	7FF0E2	1735 578441	VITALIY SAVELEV	{"email": "savelev.v_031981@postgrespro.ru", "phone": "+70465449216"}
0005433345556	C5A878	0601 476832	MARIYA ANDREEVA	{"email": "andreeva_m_25101966@postgrespro.ru", "phone": "+70204510185"}
0005433345557	C5A878	7758 745554	SERGEY SAVELEV	{"phone": "+70440559529"}
0005433345558	7E94CA	6002 494649	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov_101969@postgrespro.ru", "phone": "+70174455934"}
0005433345559	A803B9	7264 407505	ANATOLIY IVANOV	{"phone": "+70510871820"}
0005433345560	33B9D4	1822 312400	VALENTINA EFREMOVA	{"phone": "+70868182527"}
0005433345561	E23D8C	5398 380623	VALERIY ZAKHAROV	{"phone": "+70195543689"}
0005433345562	24596D	0219 161780	ZAKHAR ORLOV	{"email": "zakhar_orlov-111972@postgrespro.ru", "phone": "+70319984254"}
0005433345563	24596D	3264 111579	VLADIMIR KUZNECOV	{"email": "kuznecov-v_031974@postgrespro.ru", "phone": "+70285214675"}
0005433345564	24596D	0691 919243	NIKOLAY KRASNOV	{"phone": "+70417293414"}
0005433345565	6828E1	5109 367138	GALINA IVANOVA	{"phone": "+70049137277"}
0005433345566	6828E1	3629 197681	VASILIY EGOROV	{"email": "vasiliy-egorov1971@postgrespro.ru", "phone": "+70708916704"}
0005433345567	AB478E	6578 418803	SVETLANA ERMAKOVA	{"email": "s.ermakova-1979@postgrespro.ru", "phone": "+70427964373"}
0005433345568	D57322	4350 642302	TATYANA DENISOVA	{"phone": "+70276790788"}
0005433345569	4E7AD5	6937 217238	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-1988@postgrespro.ru", "phone": "+70191793130"}
0005433345570	4E7AD5	5207 515017	SERGEY PETROV	{"phone": "+70632955357"}
0005433345571	5583A6	4195 028538	TATYANA SOLOVEVA	{"email": "tatyanasoloveva_1971@postgrespro.ru", "phone": "+70331641360"}
0005433345572	1F0185	7269 320907	VALENTINA KOVALEVA	{"email": "valentina-kovaleva-1976@postgrespro.ru", "phone": "+70360635979"}
0005433345573	6A6A7B	3792 379013	SERGEY KISELEV	{"phone": "+70951427876"}
0005433345574	6A6A7B	4755 914059	ELDAR BELOV	{"phone": "+70537201105"}
0005433345575	6A6A7B	5558 673903	OLEG MIKHAYLOV	{"email": "mikhaylov_o.02091966@postgrespro.ru", "phone": "+70459358634"}
0005433345576	6A6A7B	6757 957772	DARYA SERGEEVA	{"phone": "+70499483147"}
0005433345577	62C38F	3671 271093	OLGA NIKIFOROVA	{"email": "nikiforovaolga_041977@postgrespro.ru", "phone": "+70673927333"}
0005433345578	E17690	0857 403027	DMITRIY FOMIN	{"phone": "+70316880253"}
0005433345579	D13F61	4521 071265	PAVEL KOZLOV	{"email": "p-kozlov-10021978@postgrespro.ru", "phone": "+70673258700"}
0005433345580	D13F61	3286 385404	SERAFIMA KOMAROVA	{"phone": "+70692176416"}
0005433345581	D13F61	6053 283994	GALINA KARPOVA	{"email": "karpova.g1980@postgrespro.ru", "phone": "+70464855610"}
0005433345582	D23217	5157 487583	VLADIMIR ZHUKOV	{"phone": "+70391507968"}
0005433345583	D23217	9020 749583	OLGA CHERNOVA	{"phone": "+70705895881"}
0005433345584	B8287E	4640 580135	ALEKSEY SOROKIN	{"phone": "+70471166397"}
0005433345585	CE9E96	3141 134501	MIKHAIL KOROLEV	{"email": "korolev_m.121957@postgrespro.ru", "phone": "+70618412811"}
0005433345586	CE9E96	5622 035424	TATYANA SAVELEVA	{"email": "t.saveleva-1971@postgrespro.ru", "phone": "+70331144614"}
0005433345587	C833B5	1799 645845	GALINA YUDINA	{"phone": "+70319463721"}
0005433345588	E88679	2300 274577	LYUBOV RODIONOVA	{"email": "lyubovrodionova-18011979@postgrespro.ru", "phone": "+70924765326"}
0005433345589	E88679	5004 930030	NINA OVCHINNIKOVA	{"phone": "+70459214922"}
0005433345590	254407	0525 276068	ALEKSEY PETROV	{"phone": "+70945697024"}
0005433345591	0ECEA1	3173 061121	ANNA DAVYDOVA	{"email": "davydova.anna13011969@postgrespro.ru", "phone": "+70218710294"}
0005433345592	677A19	0671 170846	LYUBOV FOMINA	{"phone": "+70278465304"}
0005433345593	5AB238	0462 750375	LYUDMILA YAKOVLEVA	{"email": "yakovleva.l1970@postgrespro.ru", "phone": "+70269834201"}
0005433345594	6D0365	6922 632729	MILANA SAVELEVA	{"email": "milana-saveleva_011958@postgrespro.ru", "phone": "+70290643080"}
0005433345595	6D0365	4109 093988	DENIS BORISOV	{"phone": "+70893025462"}
0005433345596	6D0365	5919 898968	VALENTINA NIKIFOROVA	{"phone": "+70406967931"}
0005433345597	6160F0	5231 649872	DMITRIY ZAKHAROV	{"phone": "+70131687266"}
0005433345598	C64BDF	9452 957563	VLADIMIR STEPANOV	{"email": "stepanov.vladimir.1975@postgrespro.ru", "phone": "+70546602566"}
0005433345599	C64BDF	8578 421979	VLADIMIR BORISOV	{"email": "vladimir.borisov011964@postgrespro.ru", "phone": "+70626800967"}
0005433345600	2D7130	4926 182890	SERGEY ZAKHAROV	{"phone": "+70234068939"}
0005433345601	2D7130	4820 898744	MAKSIM VOLKOV	{"email": "volkovmaksim.15101968@postgrespro.ru", "phone": "+70005086724"}
0005433345602	186303	9566 310534	ALEKSEY PETROV	{"email": "petrov_aleksey-30071973@postgrespro.ru", "phone": "+70716941827"}
0005433345603	186303	3956 274839	KLAVDIYA MAKAROVA	{"phone": "+70791277942"}
0005433345604	997757	1196 008091	ANDREY YAKOVLEV	{"email": "a.yakovlev-121971@postgrespro.ru", "phone": "+70508189606"}
0005433345605	9F77AD	3289 851155	ANATOLIY GERASIMOV	{"email": "a.gerasimov-22111967@postgrespro.ru", "phone": "+70451852798"}
0005433345606	36B735	1412 666629	MIKHAIL ANTONOV	{"phone": "+70434476616"}
0005433345607	C27402	2778 783129	VALENTINA BARANOVA	{"phone": "+70210712498"}
0005433345608	C27402	5876 993445	SERGEY BARANOV	{"phone": "+70101635677"}
0005433345609	C27402	1921 040198	LYUDMILA MOROZOVA	{"phone": "+70899912735"}
0005433345610	A4552D	0446 593075	NATALYA IVANOVA	{"phone": "+70319981515"}
0005433345611	F1250E	0437 697309	NATALIYA MAKAROVA	{"phone": "+70102665671"}
0005433345612	BACF16	9095 505720	DMITRIY POPOV	{"phone": "+70314960464"}
0005433345613	BACF16	8962 769883	NIKOLAY POPOV	{"phone": "+70729948060"}
0005433345614	2CBE34	7022 583875	ALEKSEY DENISOV	{"email": "denisov-a26101971@postgrespro.ru", "phone": "+70548070985"}
0005433345615	2CBE34	4652 080742	ALEKSEY KAZAKOV	{"email": "kazakov_aleksey_06061975@postgrespro.ru", "phone": "+70322602440"}
0005433345616	55FC5C	4414 992098	ROMAN FROLOV	{"email": "frolov-r-1970@postgrespro.ru", "phone": "+70287226604"}
0005433345617	B4C9EB	5470 146683	ALLA VLASOVA	{"email": "vlasovaalla1980@postgrespro.ru", "phone": "+70684242061"}
0005433345618	B4C9EB	8491 782197	VLADIMIR ZHURAVLEV	{"phone": "+70340307807"}
0005433345619	4ED219	4752 983938	ALINA KOZLOVA	{"email": "kozlovaalina031974@postgrespro.ru", "phone": "+70554196453"}
0005433345620	4ED219	9484 458344	SERGEY NIKITIN	{"email": "nikitin-sergey.07061977@postgrespro.ru", "phone": "+70429454551"}
0005433345621	4ED219	5500 190514	ANDREY VLASOV	{"email": "vlasova-101964@postgrespro.ru", "phone": "+70711361783"}
0005433345622	194562	6096 401757	STANISLAV BORISOV	{"phone": "+70455230058"}
0005433345623	A2FB26	5886 842542	LYUBOV SOROKINA	{"phone": "+70924665790"}
0005433345624	A2FB26	7560 505091	VYACHESLAV KOZLOV	{"phone": "+70569083231"}
0005433345625	795E65	2057 916943	ALEKSANDRA SEMENOVA	{"phone": "+70938752016"}
0005433345626	402F1E	1431 143626	ALEKSANDR MAKSIMOV	{"phone": "+70105179099"}
0005433345627	402F1E	5304 047936	MIKHAIL FEDOROV	{"email": "mikhailfedorov_17021972@postgrespro.ru", "phone": "+70290100215"}
0005433345628	CB3351	4922 703478	SERGEY ZHUKOV	{"email": "zhukovs111968@postgrespro.ru", "phone": "+70062138659"}
0005433345629	0F8C7E	0961 423158	ANASTASIYA FADEEVA	{"phone": "+70896959128"}
0005433345630	D2C8A5	7267 097869	NINA BELOVA	{"phone": "+70301469494"}
0005433345631	D2C8A5	0605 622589	VALERIY ZHURAVLEV	{"email": "zhuravlevv.031974@postgrespro.ru", "phone": "+70670406853"}
0005433345632	C90AD9	9679 010725	NATALYA MIRONOVA	{"email": "natalya_mironova_061971@postgrespro.ru", "phone": "+70471756002"}
0005433345633	C90AD9	7943 093947	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev_09041974@postgrespro.ru", "phone": "+70032943707"}
0005433345634	636C83	0724 913249	NATALYA PETROVA	{"phone": "+70942846064"}
0005433345635	A6A9DF	5396 518672	KRISTINA KOLESNIKOVA	{"email": "kolesnikova_kristina_12021972@postgrespro.ru", "phone": "+70608860125"}
0005433345636	2FAE72	0107 466652	ANNA PETROVA	{"email": "petrova_a-1969@postgrespro.ru", "phone": "+70011228092"}
0005433345637	2FAE72	6689 064935	VIKTOR MEDVEDEV	{"email": "v_medvedev-071967@postgrespro.ru", "phone": "+70550586367"}
0005433345638	E1B7DD	7833 159030	NATALIYA GAVRILOVA	{"email": "ngavrilova-05101970@postgrespro.ru", "phone": "+70231671933"}
0005433345639	0B443F	8888 803399	LYUDMILA EGOROVA	{"phone": "+70452386663"}
0005433345640	284303	6594 947978	MARINA ANTONOVA	{"email": "antonovam.24031975@postgrespro.ru", "phone": "+70634438145"}
0005433345641	284303	8119 713801	INNA DENISOVA	{"phone": "+70325037988"}
0005433345642	8FDBDC	2115 098720	ANNA IVANOVA	{"email": "anna_ivanova_1977@postgrespro.ru", "phone": "+70772782526"}
0005433345643	953456	0586 782997	LYUDMILA ANISIMOVA	{"phone": "+70337722233"}
0005433345644	1048C5	9830 746078	ANASTASIYA NIKOLAEVA	{"email": "nikolaeva_anastasiya-14061972@postgrespro.ru", "phone": "+70430538429"}
0005433345645	EB2714	4527 434030	ANNA SCHERBAKOVA	{"email": "a_scherbakova-031980@postgrespro.ru", "phone": "+70022600734"}
0005433345646	EB2714	6917 457668	SERGEY FROLOV	{"phone": "+70472500498"}
0005433345647	019D76	1247 702680	VADIM MIKHAYLOV	{"phone": "+70454774832"}
0005433345648	EA5C92	3242 259093	GENNADIY MOROZOV	{"email": "morozov-gennadiy-1960@postgrespro.ru", "phone": "+70708105913"}
0005433345649	772644	2708 830381	OLEG SHEVCHENKO	{"email": "shevchenko-o.23021960@postgrespro.ru", "phone": "+70258426384"}
0005433345650	D45FA4	8545 665956	SERGEY MIKHAYLOV	{"email": "sergey.mikhaylov28101976@postgrespro.ru", "phone": "+70391739203"}
0005433345651	B62E88	0974 225344	ELENA ZHUKOVA	{"email": "zhukova_elena-1968@postgrespro.ru", "phone": "+70251884396"}
0005433345652	E75895	5250 968749	MAKAR KAZAKOV	{"email": "kazakovmakar06041970@postgrespro.ru", "phone": "+70114155063"}
0005433345653	E75895	0227 274480	IGOR ZAKHAROV	{"phone": "+70175717661"}
0005433345654	BAE72A	5708 867738	ZOYA SIDOROVA	{"phone": "+70516213467"}
0005433345655	D5B124	8081 695464	MIKHAIL POPOV	{"email": "m_popov_041969@postgrespro.ru", "phone": "+70773440380"}
0005433345656	07AEA9	0728 314960	MAKSIM IVANOV	{"email": "maksimivanov.14031976@postgrespro.ru", "phone": "+70753736372"}
0005433345657	F6BD3A	9215 645585	VLADIMIR ROMANOV	{"email": "v-romanov-11021968@postgrespro.ru", "phone": "+70835653460"}
0005433345658	A76D6D	0439 013089	ALEKSANDR SMIRNOV	{"email": "smirnova-1972@postgrespro.ru", "phone": "+70947345863"}
0005433345659	316750	2303 455698	SERGEY ROMANOV	{"phone": "+70197700523"}
0005433345660	316750	3874 298500	SERGEY NAZAROV	{"phone": "+70565341868"}
0005433345661	B92C9E	0908 047509	VALENTIN GORBUNOV	{"email": "gorbunovvalentin.031972@postgrespro.ru", "phone": "+70202448382"}
0005433345662	B92C9E	1343 163165	DIANA SERGEEVA	{"email": "d.sergeeva_1970@postgrespro.ru", "phone": "+70576319100"}
0005433345663	C507DF	7223 747810	LILIYA OSIPOVA	{"email": "osipova.l1967@postgrespro.ru", "phone": "+70653249568"}
0005433345664	C507DF	4485 453810	DENIS PAVLOV	{"email": "dpavlov1982@postgrespro.ru", "phone": "+70318229864"}
0005433345665	85CA9F	4498 414433	VIKTOR DMITRIEV	{"phone": "+70811031987"}
0005433345666	85CA9F	4163 547498	DMITRIY IVANOV	{"email": "ivanov_dmitriy1965@postgrespro.ru", "phone": "+70094433386"}
0005433345667	A96F8D	6480 387119	ALEKSANDR FEDOROV	{"phone": "+70817634161"}
0005433345668	58935C	4897 732538	VIKTOR MAKAROV	{"phone": "+70762702100"}
0005433345669	FF139B	8444 081752	MAKSIM SOROKIN	{"phone": "+70495053231"}
0005433345670	FF139B	2436 424915	YULIYA PAVLOVA	{"email": "pavlova-yuliya-061966@postgrespro.ru", "phone": "+70140302279"}
0005433345671	256464	7025 850231	ALEKSANDR NOVIKOV	{"phone": "+70938690587"}
0005433345672	256464	4696 504668	STEPAN YAKOVLEV	{"email": "s.yakovlev-1964@postgrespro.ru", "phone": "+70128184060"}
0005433345673	6737F5	8901 762282	SERGEY KARPOV	{"email": "sergey_karpov-1960@postgrespro.ru", "phone": "+70183323006"}
0005433345674	3C1FDC	2333 791839	DANIIL ANTONOV	{"phone": "+70322297906"}
0005433345675	3C1FDC	7003 339818	IRINA ROMANOVA	{"email": "i-romanova-1975@postgrespro.ru", "phone": "+70459740110"}
0005433345676	30D209	6079 437814	DMITRIY GAVRILOV	{"phone": "+70549669599"}
0005433345677	E3EB10	3545 357606	NAIL KUZMIN	{"phone": "+70664205345"}
0005433345678	9DF9EF	4866 034160	EVGENIYA EGOROVA	{"phone": "+70743811832"}
0005433345679	A4FCE4	0044 479732	OLGA MELNIKOVA	{"email": "melnikovaolga-04081970@postgrespro.ru", "phone": "+70404472596"}
0005433345680	32297B	4017 335423	NATALYA SAVELEVA	{"phone": "+70110993219"}
0005433345681	D19A65	1390 950981	ALEKSEY BONDARENKO	{"phone": "+70513054359"}
0005433345682	D19A65	6199 788270	ALEKSEY ZAKHAROV	{"phone": "+70064745812"}
0005433345683	914EEC	0744 522611	NIKOLAY IVANOV	{"email": "ivanov-nikolay-1965@postgrespro.ru", "phone": "+70127975621"}
0005433345684	28056A	8516 509463	YURIY SOKOLOV	{"email": "sokolov-yuriy.071976@postgrespro.ru", "phone": "+70911721135"}
0005433345685	661032	2259 613759	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev.011978@postgrespro.ru", "phone": "+70530456992"}
0005433345686	18EB80	5581 777110	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov13121975@postgrespro.ru", "phone": "+70425855232"}
0005433345687	18EB80	5706 128344	YURIY BORISOV	{"email": "borisov.y.1970@postgrespro.ru", "phone": "+70226195410"}
0005433345688	EC6B0A	0700 154645	SVETLANA TIMOFEEVA	{"phone": "+70225916276"}
0005433345689	8C0532	3632 261348	LYUDMILA PETROVA	{"email": "petrova_l_091973@postgrespro.ru", "phone": "+70602090610"}
0005433345690	8C0532	0490 597942	OLGA FILIPPOVA	{"email": "filippovaolga-1975@postgrespro.ru", "phone": "+70149370611"}
0005433345691	6A675B	6061 249621	VLADIMIR DMITRIEV	{"email": "v.dmitriev_1984@postgrespro.ru", "phone": "+70883720962"}
0005433345692	D01585	2401 465699	SERGEY KRASNOV	{"email": "krasnovsergey-061973@postgrespro.ru", "phone": "+70410002147"}
0005433345693	D01585	7000 764232	ANATOLIY ILIN	{"phone": "+70152813478"}
0005433345694	BC5D43	5352 002921	MIKHAIL SCHERBAKOV	{"phone": "+70041992118"}
0005433345695	934975	0522 489870	NIKOLAY KUZNECOV	{"phone": "+70550784785"}
0005433345696	934975	1733 694133	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr_041973@postgrespro.ru", "phone": "+70166405774"}
0005433345697	F43EB6	8739 970724	ALEKSEY EGOROV	{"email": "a.egorov031969@postgrespro.ru", "phone": "+70087389040"}
0005433345698	6FCDE7	0724 846024	OLGA KRASNOVA	{"phone": "+70670017242"}
0005433345699	6FCDE7	5896 646075	NINA FEDOROVA	{"email": "nina_fedorova031980@postgrespro.ru", "phone": "+70981079108"}
0005433345700	AD149F	4555 501268	YULIYA KUZNECOVA	{"phone": "+70233494698"}
0005433345701	BA87C2	2302 203026	TATYANA KONDRATEVA	{"phone": "+70880064617"}
0005433345702	7024DB	5608 915698	MIKHAIL ZAKHAROV	{"email": "zakharov.mikhail.1968@postgrespro.ru", "phone": "+70388375493"}
0005433345703	CC1A80	4009 958459	DMITRIY GRIGOREV	{"email": "grigorev.d071962@postgrespro.ru", "phone": "+70764895910"}
0005433345704	E8A1AA	8037 620663	ANNA IVANOVA	{"phone": "+70059164327"}
0005433345705	26B819	8314 324527	ELENA KARPOVA	{"email": "e.karpova.1964@postgrespro.ru", "phone": "+70094824890"}
0005433345706	AEA5CC	6986 277833	BORIS ISAEV	{"phone": "+70313312312"}
0005433345707	AD7921	0648 267240	NADEZHDA IVANOVA	{"phone": "+70891178746"}
0005433345708	824E6C	2172 561248	VLADIMIR NAZAROV	{"phone": "+70419630249"}
0005433345709	E010E6	9483 839828	GALINA STEPANOVA	{"phone": "+70443091474"}
0005433345710	F4EA64	3711 378962	YURIY ALEKSANDROV	{"phone": "+70015091084"}
0005433345711	F4EA64	0443 744433	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov_1982@postgrespro.ru", "phone": "+70721606471"}
0005433345712	F4EA64	0643 749101	NADEZHDA RYABOVA	{"email": "n.ryabova06121968@postgrespro.ru", "phone": "+70008198623"}
0005433345713	920B5D	1133 737882	MARIYA KUZNECOVA	{"phone": "+70693220197"}
0005433345714	920B5D	2371 389902	ALEKSANDR KISELEV	{"phone": "+70234566850"}
0005433345715	54E18B	9044 852536	MAKSIM SHEVCHENKO	{"email": "shevchenko.m_18061965@postgrespro.ru", "phone": "+70034950148"}
0005433345716	16ACB9	8327 189773	SERGEY MIKHAYLOV	{"phone": "+70730447790"}
0005433345717	16ACB9	8537 420105	DMITRIY PAVLOV	{"email": "pavlov-dmitriy15051978@postgrespro.ru", "phone": "+70927558642"}
0005433345718	A7A48D	9286 296770	ELENA ALEKSANDROVA	{"phone": "+70496036854"}
0005433345719	9B6BAB	3144 331606	LYUBOV DANILOVA	{"phone": "+70765775510"}
0005433345720	E52EE7	1043 315442	ALEKSANDR SMIRNOV	{"phone": "+70606941644"}
0005433345721	50CA6B	7983 940122	ALEKSANDR SAVELEV	{"email": "asavelev.26101976@postgrespro.ru", "phone": "+70014586238"}
0005433345722	1A08A9	0586 535110	LIDIYA SEMENOVA	{"phone": "+70584533454"}
0005433345723	8A369C	7386 965841	OLGA FILIPPOVA	{"email": "filippovao_03071970@postgrespro.ru", "phone": "+70213885139"}
0005433345724	8A369C	1440 591602	LYUBOV NIKITINA	{"phone": "+70193549657"}
0005433345725	624564	8572 704139	ALMIRA KUZMINA	{"email": "kuzminaalmira-15111976@postgrespro.ru", "phone": "+70567402684"}
0005433345726	89B975	6834 162415	VADIM VOLKOV	{"phone": "+70786937142"}
0005433345727	89B975	1294 200626	EKATERINA KUZNECOVA	{"email": "e.kuznecova-091970@postgrespro.ru", "phone": "+70074473827"}
0005433345728	828282	8832 463165	ALENA MARTYNOVA	{"phone": "+70779318283"}
0005433345729	828282	5994 221200	ANASTASIYA KULIKOVA	{"phone": "+70765338952"}
0005433345730	8C33D3	9274 165705	OLGA NESTEROVA	{"phone": "+70092381893"}
0005433345731	31E4C1	4683 697143	VLADISLAV KUDRYASHOV	{"email": "v-kudryashov.021966@postgrespro.ru", "phone": "+70600608834"}
0005433345732	6FB206	5233 200392	YURIY SMIRNOV	{"phone": "+70015435644"}
0005433345733	6FB206	2934 034046	PAVEL BONDARENKO	{"email": "bondarenkopavel-1977@postgrespro.ru", "phone": "+70029546304"}
0005433345734	B46CF4	6807 381315	TATYANA KISELEVA	{"phone": "+70780494176"}
0005433345735	1F6B32	7237 500201	ELENA SOROKINA	{"phone": "+70696466943"}
0005433345736	CAB2D4	8296 856545	MIKHAIL SOKOLOV	{"phone": "+70066970874"}
0005433345737	FBA77B	4199 627762	OLGA NIKIFOROVA	{"email": "olga.nikiforova051976@postgrespro.ru", "phone": "+70115351820"}
0005433345738	FBA77B	6862 595090	IVAN VOROBEV	{"phone": "+70109760262"}
0005433345739	056241	7649 194654	YURIY POPOV	{"email": "popov-yuriy1978@postgrespro.ru", "phone": "+70155486275"}
0005433345740	CA34C7	7666 951291	MAKSIM OSIPOV	{"email": "osipov.m.021968@postgrespro.ru", "phone": "+70972428311"}
0005433345741	C247E2	9220 775368	ALEKSANDR ANDREEV	{"phone": "+70117543916"}
0005433345742	C247E2	3985 638379	TATYANA NIKIFOROVA	{"email": "nikiforova-tatyana23101979@postgrespro.ru", "phone": "+70238082730"}
0005433345743	19489A	1734 758189	NINA SOKOLOVA	{"email": "n_sokolova-1972@postgrespro.ru", "phone": "+70195281280"}
0005433345744	19489A	1344 150157	ANDREY ILIN	{"email": "a.ilin-06021971@postgrespro.ru", "phone": "+70758087368"}
0005433345745	A753E7	4281 793136	YULIYA PETROVA	{"email": "petrova_yuliya1970@postgrespro.ru", "phone": "+70615723786"}
0005433345746	17EC25	9309 336919	ANDREY BONDARENKO	{"phone": "+70203148666"}
0005433345747	17EC25	3626 362813	LARISA PETROVA	{"email": "petroval081975@postgrespro.ru", "phone": "+70344979318"}
0005433345748	A41870	3981 862587	TATYANA PAVLOVA	{"phone": "+70988353403"}
0005433345749	A41870	6582 435108	MIKHAIL OSIPOV	{"email": "m.osipov-051967@postgrespro.ru", "phone": "+70178292971"}
0005433345750	6FB7AB	5225 370851	ELENA MAKAROVA	{"email": "e.makarova101981@postgrespro.ru", "phone": "+70906666106"}
0005433345751	27DD87	5756 345011	MARIYA SMIRNOVA	{"email": "smirnovamariya.04091963@postgrespro.ru", "phone": "+70687767002"}
0005433345752	0B471D	1803 451904	ALEKSANDRA YAKOVLEVA	{"email": "aleksandra_yakovleva.18081972@postgrespro.ru", "phone": "+70921623453"}
0005433345753	0B471D	5766 220498	ANATOLIY EGOROV	{"email": "egorov.a.061969@postgrespro.ru", "phone": "+70640817719"}
0005433345754	1B05D6	3394 370361	VITALIY MATVEEV	{"phone": "+70191623020"}
0005433345755	1B05D6	7203 944499	VALENTINA YAKOVLEVA	{"email": "yakovlevavalentina031960@postgrespro.ru", "phone": "+70048732732"}
0005433345756	BAC086	5822 390111	EGOR BORISOV	{"email": "borisovegor-20061973@postgrespro.ru", "phone": "+70713085028"}
0005433345757	BCB67E	6079 390785	VALENTINA MOROZOVA	{"email": "valentina.morozova.021974@postgrespro.ru", "phone": "+70678067827"}
0005433345758	BCB67E	4303 142102	SERGEY BONDARENKO	{"email": "bondarenkosergey1978@postgrespro.ru", "phone": "+70555297253"}
0005433345759	85825D	6636 312380	ALEKSEY GUSEV	{"email": "agusev-011963@postgrespro.ru", "phone": "+70563146712"}
0005433345760	85825D	1784 068890	EVGENIY SOLOVEV	{"phone": "+70149725415"}
0005433345761	B8509D	7591 894598	GALINA RYABOVA	{"phone": "+70623678986"}
0005433345762	3A44FD	1022 192327	ELENA NIKITINA	{"phone": "+70716977660"}
0005433345763	D1A4AD	4869 103907	GALINA TIKHONOVA	{"phone": "+70535613051"}
0005433345764	0F5468	6396 091774	DMITRIY NIKOLAEV	{"phone": "+70163789187"}
0005433345765	0F5468	9252 501528	OLEG GRIGOREV	{"phone": "+70390466499"}
0005433345766	003D63	3241 361675	SVETLANA ANDREEVA	{"email": "svetlana_andreeva.041957@postgrespro.ru", "phone": "+70872435597"}
0005433345767	B455DC	8880 097904	SERGEY NOVIKOV	{"email": "sergeynovikov_121969@postgrespro.ru", "phone": "+70380531733"}
0005433345768	B455DC	2352 231649	KRISTINA IVANOVA	{"email": "kristina.ivanova1959@postgrespro.ru", "phone": "+70900119061"}
0005433345769	0307E6	1777 943408	VLADIMIR ZHURAVLEV	{"phone": "+70051597243"}
0005433345770	0307E6	3829 898274	ALEKSANDR RODIONOV	{"email": "a.rodionov.13111979@postgrespro.ru", "phone": "+70756619361"}
0005433345771	2F5755	5153 312438	YURIY GAVRILOV	{"phone": "+70813387698"}
0005433345772	2F5755	3701 290219	NATALYA MATVEEVA	{"phone": "+70533792375"}
0005433345773	270CB6	7478 643736	OLGA KUZNECOVA	{"email": "o-kuznecova-1975@postgrespro.ru", "phone": "+70832275447"}
0005433345774	270CB6	0520 050201	VLADIMIR KUZMIN	{"email": "vkuzmin011963@postgrespro.ru", "phone": "+70774314284"}
0005433345775	208752	2837 609598	VENIAMIN SCHERBAKOV	{"phone": "+70868659380"}
0005433345776	95EAFE	3264 308199	ALENA KUZNECOVA	{"phone": "+70654276622"}
0005433345777	104173	1593 592219	ELENA GORBUNOVA	{"email": "gorbunova-elena-101974@postgrespro.ru", "phone": "+70715278654"}
0005433345778	104173	9754 332797	ALEKSANDR ZAKHAROV	{"email": "a_zakharov-1976@postgrespro.ru", "phone": "+70372745958"}
0005433345779	8A58F8	7005 318058	MIKHAIL MATVEEV	{"email": "m.matveev_1976@postgrespro.ru", "phone": "+70151645030"}
0005433345780	F55B24	4270 602055	DMITRIY MEDVEDEV	{"phone": "+70620033172"}
0005433345781	278857	9005 398113	ANDREY FROLOV	{"email": "afrolov-051970@postgrespro.ru", "phone": "+70669091645"}
0005433345782	35892E	0069 458012	EVGENIY EGOROV	{"phone": "+70651891283"}
0005433345783	DD84B9	6918 149230	ANDREY KUZMIN	{"email": "andrey.kuzmin031974@postgrespro.ru", "phone": "+70159419055"}
0005433345784	4CCBA8	0686 200025	IGOR SCHERBAKOV	{"email": "scherbakov.igor-1977@postgrespro.ru", "phone": "+70646004637"}
0005433345785	764BE3	2717 088302	DANILA ZHURAVLEV	{"phone": "+70557766270"}
0005433345786	764BE3	7130 254060	MARIYA MALYSHEVA	{"phone": "+70656756901"}
0005433345787	3AA151	8891 496730	VLADIMIR ANDREEV	{"phone": "+70470820193"}
0005433345788	781CEC	7520 437510	ALEKSANDR BORISOV	{"email": "a-borisov_071965@postgrespro.ru", "phone": "+70342521293"}
0005433345789	DE1183	9241 386388	ANASTASIYA NAZAROVA	{"email": "nazarova-anastasiya.011967@postgrespro.ru", "phone": "+70783324499"}
0005433345790	C94470	7604 617971	SERGEY KUDRYASHOV	{"phone": "+70981621107"}
0005433345791	2D0F7D	0761 492285	NATALIYA MOROZOVA	{"phone": "+70569429740"}
0005433345792	43A03C	1153 003315	LYUBOV BORISOVA	{"phone": "+70540232573"}
0005433345793	3A436D	1709 588431	KONSTANTIN NAUMOV	{"email": "naumov_k23121972@postgrespro.ru", "phone": "+70821270949"}
0005433345794	205C76	4263 914603	POLINA MALYSHEVA	{"phone": "+70203305581"}
0005433345795	EF87BB	6816 013071	ALEKSEY ALEKSEEV	{"phone": "+70005218406"}
0005433345796	CE46CB	1256 521173	EVGENIY VLASOV	{"phone": "+70646231874"}
0005433345797	ED5DEE	8106 818041	VALENTINA DAVYDOVA	{"phone": "+70399499933"}
0005433345798	06D7F0	4904 111052	ANDREY IVANOV	{"email": "a-ivanov17061973@postgrespro.ru", "phone": "+70425597390"}
0005433345799	62DC99	2850 858423	FANIYA KUZNECOVA	{"phone": "+70537019397"}
0005433345800	AF6ACA	3358 152435	MARIYA MALYSHEVA	{"email": "malysheva_m011978@postgrespro.ru", "phone": "+70252571300"}
0005433345801	85CE0C	8417 183141	ALEKSEY ANTONOV	{"email": "antonov_aleksey1974@postgrespro.ru", "phone": "+70085909858"}
0005433345802	B6F404	6739 228602	KONSTANTIN ANTONOV	{"email": "antonov-k1990@postgrespro.ru", "phone": "+70894020904"}
0005433345803	1A2DBA	0972 218802	MIKHAIL SOROKIN	{"phone": "+70375282382"}
0005433345804	48E8FF	9266 826853	LIYA FADEEVA	{"email": "fadeevaliya1976@postgrespro.ru", "phone": "+70007610896"}
0005433345805	48E8FF	1670 772525	TATYANA KOROLEVA	{"phone": "+70808274486"}
0005433345806	888323	3780 936547	VLADIMIR MIRONOV	{"email": "mironovvladimir.1963@postgrespro.ru", "phone": "+70504733198"}
0005433345807	888323	2551 914778	NINA SMIRNOVA	{"email": "n-smirnova-1961@postgrespro.ru", "phone": "+70433191290"}
0005433345808	4E2C76	7022 392592	GENNADIY GRIGOREV	{"email": "grigorev.gennadiy-041975@postgrespro.ru", "phone": "+70017207511"}
0005433345809	79A615	3568 986881	SERGEY SOLOVEV	{"email": "s-solovev-26111964@postgrespro.ru", "phone": "+70732802885"}
0005433345810	50A2A6	1656 779688	MATVEY NAZAROV	{"email": "nazarov-matvey_1970@postgrespro.ru", "phone": "+70070764326"}
0005433345811	2E16D7	9076 371127	EVGENIY FROLOV	{"phone": "+70012842516"}
0005433345812	2E16D7	0974 114519	SVYATOSLAV MAKAROV	{"phone": "+70264376318"}
0005433345813	DB46FB	9371 370302	ALEKSEY IVANOV	{"email": "aleksey-ivanov-23041974@postgrespro.ru", "phone": "+70045310606"}
0005433345814	C15890	7405 926240	VASILIY KUZMIN	{"phone": "+70053684910"}
0005433345815	C15890	4987 903514	ALEKSEY KRASNOV	{"email": "krasnov-aleksey-121975@postgrespro.ru", "phone": "+70322447581"}
0005433345816	A999CA	3747 534956	ZINAIDA RYABOVA	{"email": "z-ryabova_091973@postgrespro.ru", "phone": "+70755226453"}
0005433345817	A999CA	6063 315287	ILMIRA BORISOVA	{"email": "i.borisova.041974@postgrespro.ru", "phone": "+70365093007"}
0005433345818	06C154	4256 708775	KSENIYA MAKAROVA	{"email": "makarova.k121978@postgrespro.ru", "phone": "+70925533514"}
0005433345819	06C154	6444 725356	EKATERINA ABRAMOVA	{"phone": "+70740973465"}
0005433345820	06C154	4192 551241	NIKOLAY VOROBEV	{"email": "vorobevn1971@postgrespro.ru", "phone": "+70660745888"}
0005433345821	AB3072	7176 358842	SERGEY IVANOV	{"phone": "+70261746725"}
0005433345822	AB3072	1974 014283	LYUDMILA BELOVA	{"phone": "+70937961749"}
0005433345823	EABB82	2824 813520	VALENTINA KUZMINA	{"email": "valentina_kuzmina17011966@postgrespro.ru", "phone": "+70787131542"}
0005433345824	D3324D	6666 794379	NIKOLAY BORISOV	{"email": "nikolay_borisov_071975@postgrespro.ru", "phone": "+70530910485"}
0005433345825	D3324D	5883 753093	SERGEY MAKAROV	{"phone": "+70476301448"}
0005433345826	09A031	3498 385918	NATALYA RYABOVA	{"email": "ryabovanatalya-21031977@postgrespro.ru", "phone": "+70677001497"}
0005433345827	848FAC	0331 301316	RAISA MARTYNOVA	{"email": "raisa_martynova.1966@postgrespro.ru", "phone": "+70429518786"}
0005433345828	844EF3	3023 519032	OKSANA POPOVA	{"email": "o.popova.1975@postgrespro.ru", "phone": "+70175963660"}
0005433345829	D01508	5235 792841	IVAN SERGEEV	{"phone": "+70758517806"}
0005433345830	D01508	5617 722262	VLADIMIR KULIKOV	{"phone": "+70802144080"}
0005433345831	0841CA	1758 906714	VLADIMIR VOROBEV	{"phone": "+70860336587"}
0005433345832	C1B219	0320 613459	VADIM VOROBEV	{"email": "vorobev-vadim.17101988@postgrespro.ru", "phone": "+70466486503"}
0005433345833	C1B219	6039 903883	ANDREY ROMANOV	{"email": "romanov_andrey_011972@postgrespro.ru", "phone": "+70997516874"}
0005433345834	479F9D	3512 424049	MARINA BORISOVA	{"email": "borisovam-1970@postgrespro.ru", "phone": "+70397970948"}
0005433345835	1F18C3	0395 004047	GRIGORIY GORBUNOV	{"email": "gorbunovgrigoriy-26111973@postgrespro.ru", "phone": "+70400807749"}
0005433345836	9F3465	9583 507774	MARIYA GRISHINA	{"phone": "+70159688937"}
0005433345837	C7258F	8105 089406	NADEZHDA POLYAKOVA	{"phone": "+70269024600"}
0005433345838	0F38C7	7854 222357	ALISA ROMANOVA	{"email": "romanovaa04111962@postgrespro.ru", "phone": "+70348001467"}
0005433345839	4DA312	5340 910753	ZINAIDA AKIMOVA	{"email": "zinaidaakimova-21081982@postgrespro.ru", "phone": "+70794683791"}
0005433345840	03A365	3337 432128	SERGEY ZAYCEV	{"phone": "+70641553965"}
0005433345841	914657	5426 227728	LYUBOV NIKOLAEVA	{"phone": "+70881296840"}
0005433345842	CBC3F4	6542 324870	VLADISLAV KUZNECOV	{"email": "vladislav-kuznecov.061968@postgrespro.ru", "phone": "+70496115955"}
0005433345843	B346EE	5526 037671	VALERIY SIDOROV	{"email": "sidorov.v_041962@postgrespro.ru", "phone": "+70989416622"}
0005433345844	B346EE	3361 761845	EKATERINA FROLOVA	{"phone": "+70109832451"}
0005433345845	EA3A0C	7460 005201	SERGEY BORISOV	{"email": "s.borisov_1966@postgrespro.ru", "phone": "+70399339530"}
0005433345846	0D8757	6328 278194	ALEKSANDR BARANOV	{"phone": "+70107147339"}
0005433345847	E9A97C	3834 439979	SVETLANA NAUMOVA	{"phone": "+70490614820"}
0005433345848	34A6DD	0165 037854	OLGA FILIPPOVA	{"phone": "+70868597705"}
0005433345849	C93273	7260 595803	VALENTIN ROMANOV	{"email": "romanov_valentin-24031972@postgrespro.ru", "phone": "+70108052349"}
0005433345850	E480F1	0333 138232	LYUBOV PETROVA	{"phone": "+70223692561"}
0005433345851	E480F1	6353 714125	ELENA PETROVA	{"email": "petrova_e.101974@postgrespro.ru", "phone": "+70117044044"}
0005433345852	6E94EF	7487 310727	TATYANA VASILEVA	{"email": "t_vasileva.1980@postgrespro.ru", "phone": "+70893094690"}
0005433345853	3A7B10	0852 548334	POLINA VOROBEVA	{"phone": "+70912638016"}
0005433345854	3A7B10	0794 936372	LYUBOV POTAPOVA	{"email": "lyubov-potapova-31051981@postgrespro.ru", "phone": "+70066977059"}
0005433345855	07B253	3779 902709	OLESYA ZHURAVLEVA	{"email": "o_zhuravleva011970@postgrespro.ru", "phone": "+70521171300"}
0005433345856	4B5F53	3981 878972	ARTUR MOROZOV	{"email": "artur-morozov-1966@postgrespro.ru", "phone": "+70791322323"}
0005433345857	4B5F53	5642 601561	IRINA STEPANOVA	{"phone": "+70570390065"}
0005433345858	D0A882	1220 348422	RAISA RYABOVA	{"email": "raisa_ryabova041977@postgrespro.ru", "phone": "+70648809624"}
0005433345859	657490	3159 435495	PETR MATVEEV	{"email": "matveev-p-1977@postgrespro.ru", "phone": "+70985839495"}
0005433345860	5FE048	2163 008209	VLADISLAV IVANOV	{"email": "ivanov-v-1956@postgrespro.ru", "phone": "+70268521126"}
0005433345861	5FE048	0853 812420	TATYANA ZOTOVA	{"phone": "+70802232074"}
0005433345862	66CE37	0496 650442	SVETLANA MOISEEVA	{"email": "svetlana.moiseeva.09101969@postgrespro.ru", "phone": "+70730118661"}
0005433345863	66CE37	3684 045425	VARVARA MEDVEDEVA	{"email": "medvedeva_v_14031970@postgrespro.ru", "phone": "+70232817397"}
0005433345864	C47378	4809 394948	VLADIMIR SERGEEV	{"phone": "+70949654095"}
0005433345865	2F6EC4	2198 574190	VIKTORIYA GRISHINA	{"email": "grishinaviktoriya-28021979@postgrespro.ru", "phone": "+70296349229"}
0005433345866	C6D13A	1981 295600	STEPAN NOVIKOV	{"phone": "+70387810432"}
0005433345867	EF7844	7193 332494	OKSANA FEDOROVA	{"email": "fedorova.oksana.1973@postgrespro.ru", "phone": "+70213895852"}
0005433345869	986042	6559 231490	EVGENIYA KAZAKOVA	{"phone": "+70749506506"}
0005433345870	AE743F	4041 408881	FARID KOZLOV	{"email": "kozlovfarid041973@postgrespro.ru", "phone": "+70178942456"}
0005433345871	AE743F	1189 084136	MAKSIM KUZNECOV	{"email": "kuznecov.maksim.061970@postgrespro.ru", "phone": "+70675927113"}
0005433345872	AE743F	4259 936984	NATALYA TITOVA	{"email": "titova-natalya1982@postgrespro.ru", "phone": "+70942046034"}
0005433345873	ECDBFA	6801 667648	SERGEY MIKHAYLOV	{"phone": "+70320026318"}
0005433345874	ECDBFA	0601 189370	NINA ALEKSANDROVA	{"email": "aleksandrova_nina031969@postgrespro.ru", "phone": "+70175027124"}
0005433345875	EC3BAC	9147 112135	TATYANA IVANOVA	{"email": "ivanova.tatyana08121981@postgrespro.ru", "phone": "+70378955397"}
0005433345876	EC3BAC	5686 666317	EVGENIYA MALYSHEVA	{"email": "evgeniya.malysheva_1971@postgrespro.ru", "phone": "+70603585903"}
0005433345877	5100DD	1457 527464	ALEKSEY GAVRILOV	{"email": "a_gavrilov1969@postgrespro.ru", "phone": "+70610974591"}
0005433345878	06B088	3748 653891	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr.13011971@postgrespro.ru", "phone": "+70104751327"}
0005433345879	C3DE0E	0709 557270	NADEZHDA DENISOVA	{"phone": "+70345917831"}
0005433345880	3F88E8	0643 532174	MARINA KUZNECOVA	{"email": "marina-kuznecova.101970@postgrespro.ru", "phone": "+70781789065"}
0005433345881	3F88E8	6926 889861	ELENA ANDREEVA	{"phone": "+70631294018"}
0005433345882	008205	0009 907810	LIDIYA KOZLOVA	{"phone": "+70684163626"}
0005433345883	379333	9478 154919	INGA SEMENOVA	{"phone": "+70865795420"}
0005433345884	379333	7936 267276	ANTON POPOV	{"email": "popova.1963@postgrespro.ru", "phone": "+70698560790"}
0005433345885	942C39	5233 617037	ALEKSEY SOROKIN	{"email": "aleksey-sorokin.10041972@postgrespro.ru", "phone": "+70819437397"}
0005433345886	0F26D1	9541 687761	ALEKSANDR KUZNECOV	{"email": "akuznecov1970@postgrespro.ru", "phone": "+70250780996"}
0005433345887	3CF0F2	8308 301827	VALERIY KISELEV	{"phone": "+70498913879"}
0005433345888	6AFA4F	4776 541564	MARYAM MIRONOVA	{"phone": "+70610060766"}
0005433345889	6AFA4F	8829 585878	VENIAMIN GUSEV	{"phone": "+70753265425"}
0005433345890	6AFA4F	9342 444080	VIKTOR FROLOV	{"phone": "+70443243983"}
0005433345891	03CD69	1960 051634	SVETLANA MARTYNOVA	{"email": "svetlana_martynova_091979@postgrespro.ru", "phone": "+70573053241"}
0005433345892	8DED31	8791 716039	VIKTOR NIKOLAEV	{"phone": "+70157811961"}
0005433345893	8DED31	7799 401402	MIKHAIL NIKITIN	{"email": "nikitin.mikhail-081971@postgrespro.ru", "phone": "+70316436494"}
0005433345894	8E6B79	1801 242273	SERGEY FEDOTOV	{"email": "fedotov-sergey-1967@postgrespro.ru", "phone": "+70274438183"}
0005433345895	527F15	3210 732954	ALEKSANDR POPOV	{"phone": "+70406716904"}
0005433345896	2476DA	6766 453445	IGOR VASILEV	{"email": "vasilev_igor091969@postgrespro.ru", "phone": "+70429578012"}
0005433345897	069A06	3937 428729	TATYANA KOZLOVA	{"email": "kozlova_t-19101965@postgrespro.ru", "phone": "+70662726666"}
0005433345898	B78B0F	2120 460990	PAVEL KONOVALOV	{"email": "konovalov_p-04071963@postgrespro.ru", "phone": "+70787147433"}
0005433345899	741CF0	0585 626721	SVETLANA KOZLOVA	{"email": "kozlova_svetlana.011976@postgrespro.ru", "phone": "+70233843560"}
0005433345900	741CF0	5370 971571	KONSTANTIN ZAKHAROV	{"phone": "+70759257391"}
0005433345901	61A2FC	1314 054967	VIKTOR FILIPPOV	{"phone": "+70618645928"}
0005433345902	EAE94F	8547 420841	ALEKSANDR POPOV	{"email": "popova_14031961@postgrespro.ru", "phone": "+70771989217"}
0005433345903	EAE94F	0822 051480	PETR BORISOV	{"email": "p_borisov1959@postgrespro.ru", "phone": "+70088594781"}
0005433345904	6563E5	6424 779172	NATALYA MAKSIMOVA	{"email": "natalya-maksimova1963@postgrespro.ru", "phone": "+70925501684"}
0005433345905	667630	2024 692684	EKATERINA TIMOFEEVA	{"email": "ekaterina_timofeeva_08011977@postgrespro.ru", "phone": "+70325853656"}
0005433345906	9F1233	0081 513201	RINAT ZHUKOV	{"email": "rinat-zhukov.1977@postgrespro.ru", "phone": "+70300288718"}
0005433345907	E864F3	5012 586220	GENNADIY PAVLOV	{"phone": "+70584214366"}
0005433345908	2AC9BC	6275 008829	ANTON KOROLEV	{"phone": "+70486668522"}
0005433345909	9EBFC5	4830 383215	VLADIMIR ZAKHAROV	{"phone": "+70384467334"}
0005433345910	670407	0917 254910	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr-1965@postgrespro.ru", "phone": "+70755556913"}
0005433345911	B31E95	0703 984337	EDUARD NIKOLAEV	{"phone": "+70238073923"}
0005433345912	B31E95	2016 405038	VALERIY NIKOLAEV	{"phone": "+70463569544"}
0005433345913	D8E6AF	0935 310466	ALEKSANDR ANTONOV	{"email": "antonovaleksandr.111972@postgrespro.ru", "phone": "+70023462809"}
0005433345914	BA937B	0210 182861	ROMAN STEPANOV	{"email": "stepanov.r.27051970@postgrespro.ru", "phone": "+70180832098"}
0005433345915	34601F	1550 713749	ALSU SEMENOVA	{"email": "alsu.semenova1967@postgrespro.ru", "phone": "+70620651383"}
0005433345916	BBD020	5100 429892	ANDREY YAKOVLEV	{"email": "yakovleva.1963@postgrespro.ru", "phone": "+70407779679"}
0005433345917	BBD020	1921 422474	SERGEY CHERNOV	{"email": "chernov_s.25011975@postgrespro.ru", "phone": "+70049834263"}
0005433345918	315D78	5176 842491	LYUDMILA BELYAEVA	{"email": "belyaeval1970@postgrespro.ru", "phone": "+70880520873"}
0005433345919	814E28	2151 474218	MIKHAIL EGOROV	{"phone": "+70726265517"}
0005433345920	814E28	0059 155870	TAMARA DMITRIEVA	{"phone": "+70063830997"}
0005433345921	014A87	6670 198870	LYUDMILA PETROVA	{"email": "lyudmila_petrova_1983@postgrespro.ru", "phone": "+70286513001"}
0005433345922	C40770	4682 951772	ALINA MARTYNOVA	{"email": "alina.martynova-02091973@postgrespro.ru", "phone": "+70485227510"}
0005433345923	CA8213	4281 669482	NATALYA VOLKOVA	{"phone": "+70000986477"}
0005433345924	CA8213	8792 897239	ELENA SMIRNOVA	{"phone": "+70700417157"}
0005433345925	CA8213	3330 454933	TATYANA LEBEDEVA	{"email": "lebedeva_tatyana.09101963@postgrespro.ru", "phone": "+70437395767"}
0005433345926	D4A89A	8743 596392	LYUBOV SEMENOVA	{"phone": "+70306064293"}
0005433345927	2266A5	5675 561609	VIKTOR GERASIMOV	{"phone": "+70089011615"}
0005433345928	4CE620	0100 765971	RUSLAN BELOV	{"email": "r.belov_16101970@postgrespro.ru", "phone": "+70796739827"}
0005433345929	514A0C	0029 872121	MIKHAIL MOROZOV	{"email": "morozov_m-081973@postgrespro.ru", "phone": "+70320602328"}
0005433345930	185B25	3484 980374	ALEKSANDR SMIRNOV	{"email": "smirnov-aleksandr_051976@postgrespro.ru", "phone": "+70977815617"}
0005433345931	185B25	1909 143522	ANASTASIYA KOVALEVA	{"phone": "+70147243921"}
0005433345932	05F308	6778 577654	NIKITA BONDARENKO	{"email": "n_bondarenko091976@postgrespro.ru", "phone": "+70065655393"}
0005433345933	05F308	8714 858401	ALEKSANDRA NESTEROVA	{"email": "nesterova.aleksandra.02091969@postgrespro.ru", "phone": "+70418581728"}
0005433345934	42C128	6421 319605	SVETLANA VLASOVA	{"email": "vlasovasvetlana031979@postgrespro.ru", "phone": "+70772735428"}
0005433345935	1014AB	4538 197043	GALINA ILINA	{"phone": "+70198784781"}
0005433345936	1014AB	4423 771105	MARIYA EGOROVA	{"email": "egorovamariya-09011970@postgrespro.ru", "phone": "+70577445117"}
0005433345937	81B776	6966 973599	SERGEY BONDARENKO	{"phone": "+70635974253"}
0005433345938	81B776	7082 403394	MARIYA KISELEVA	{"email": "kiselevam.121979@postgrespro.ru", "phone": "+70952490988"}
0005433345939	16A6BA	8047 866978	NATALYA FADEEVA	{"email": "fadeevan_011972@postgrespro.ru", "phone": "+70151327718"}
0005433345940	66265D	2370 456948	MADINA EGOROVA	{"phone": "+70617231728"}
0005433345941	98F3B2	8750 043935	TATYANA BELYAEVA	{"email": "belyaevat1971@postgrespro.ru", "phone": "+70952636344"}
0005433345942	DCA870	2069 522631	ALEKSANDRA ABRAMOVA	{"phone": "+70159088311"}
0005433345943	DCA870	4646 726931	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov.1968@postgrespro.ru", "phone": "+70631518094"}
0005433345944	E06F74	4866 466528	VLADIMIR AFANASEV	{"email": "afanasev_vladimir29011961@postgrespro.ru", "phone": "+70131584710"}
0005433345945	621A7F	0268 951902	ANDREY MAKAROV	{"phone": "+70482106749"}
0005433345946	3317F5	0584 488632	PETR GORBUNOV	{"email": "p-gorbunov.061974@postgrespro.ru", "phone": "+70267378653"}
0005433345947	EB4580	9128 531345	ALEKSEY FILIPPOV	{"email": "filippov_aleksey1970@postgrespro.ru", "phone": "+70657200006"}
0005433345948	AB6580	4877 326283	NIKOLAY NIKOLAEV	{"email": "nikolaev.n091964@postgrespro.ru", "phone": "+70269326618"}
0005433345949	F2552E	1638 690224	NINA MAKSIMOVA	{"email": "nmaksimova1981@postgrespro.ru", "phone": "+70771139299"}
0005433345950	F2552E	9704 713123	ELENA NIKIFOROVA	{"phone": "+70221445116"}
0005433345951	99D9A7	4924 523923	NATALYA VOLKOVA	{"phone": "+70085558042"}
0005433345952	7B8E04	0016 680062	VLADIMIR MELNIKOV	{"phone": "+70809760572"}
0005433345953	A4AC96	0939 364579	IVAN TARASOV	{"phone": "+70893795428"}
0005433345954	5C53D0	9891 128794	ALEKSANDR MELNIKOV	{"phone": "+70114377783"}
0005433345955	A2CBDC	0047 947321	TAMARA ERMAKOVA	{"phone": "+70940872868"}
0005433345956	CCE92F	1073 397633	DMITRIY ANDREEV	{"email": "andreev_d101974@postgrespro.ru", "phone": "+70305204699"}
0005433345957	985D2A	2903 967255	IGOR NAUMOV	{"email": "igornaumov.21011981@postgrespro.ru", "phone": "+70937978023"}
0005433345958	DCBDE2	7691 881668	VALENTINA KISELEVA	{"phone": "+70998446309"}
0005433345959	0B52BD	5919 397428	OLGA VASILEVA	{"phone": "+70717964988"}
0005433345960	0B52BD	2752 352008	ALEKSANDR KRASNOV	{"phone": "+70662683019"}
0005433345961	0290BA	9433 621782	MARIYA ANISIMOVA	{"email": "anisimovam-011970@postgrespro.ru", "phone": "+70855974837"}
0005433345962	131CDE	2764 638644	LEONID KUZNECOV	{"phone": "+70726907531"}
0005433345963	131CDE	0133 744138	SERGEY STEPANOV	{"email": "stepanov.sergey_1973@postgrespro.ru", "phone": "+70269796381"}
0005433345964	3A0838	0932 580936	TAMARA SIDOROVA	{"phone": "+70987800598"}
0005433345965	D341D5	7447 892210	KONSTANTIN PETROV	{"email": "konstantin.petrov_01071965@postgrespro.ru", "phone": "+70249923893"}
0005433345966	931767	4216 345287	NATALYA LUKYANOVA	{"phone": "+70799906721"}
0005433345967	931767	7761 672300	OLGA FEDOROVA	{"phone": "+70787939033"}
0005433345968	D4B156	6197 929379	OLGA KONDRATEVA	{"phone": "+70448496577"}
0005433345969	3100C7	6927 501731	IVAN SOKOLOV	{"email": "sokolov_ivan1967@postgrespro.ru", "phone": "+70063961162"}
0005433345970	3100C7	4337 237516	ALEKSANDR IVANOV	{"phone": "+70389904732"}
0005433345971	BB6D56	9414 866351	NADEZHDA VASILEVA	{"email": "nadezhda_vasileva091985@postgrespro.ru", "phone": "+70479236506"}
0005433345972	BB6D56	4480 396073	TATYANA SOKOLOVA	{"email": "t.sokolova-23121978@postgrespro.ru", "phone": "+70848974037"}
0005433345973	B29A60	5884 001452	ANNA STEPANOVA	{"email": "astepanova-111974@postgrespro.ru", "phone": "+70059802811"}
0005433345974	CB4A77	2177 085660	EKATERINA GAVRILOVA	{"email": "e-gavrilova_031973@postgrespro.ru", "phone": "+70633273204"}
0005433345975	AE7247	8925 875678	ALEKSEY POPOV	{"phone": "+70287704910"}
0005433345976	AE7247	0328 113812	ANASTASIYA STEPANOVA	{"email": "stepanovaa.121964@postgrespro.ru", "phone": "+70076763088"}
0005433345977	D3B5C0	9922 370561	SVETLANA SOROKINA	{"email": "sorokina_s_071977@postgrespro.ru", "phone": "+70742502367"}
0005433345978	7563F5	9120 775793	PAVEL EGOROV	{"phone": "+70613136338"}
0005433345979	5222AE	2021 480796	EKATERINA DAVYDOVA	{"email": "ekaterina-davydova_13061986@postgrespro.ru", "phone": "+70898586772"}
0005433345980	855665	3673 646656	ELIZAVETA MIKHAYLOVA	{"phone": "+70717826295"}
0005433345981	855665	2416 782029	ALIYA MOROZOVA	{"phone": "+70302815434"}
0005433345982	FB8868	6781 488466	SERGEY SOROKIN	{"phone": "+70319940147"}
0005433345983	FB8868	7116 252033	FAINA ABRAMOVA	{"email": "faina.abramova-081966@postgrespro.ru", "phone": "+70172943902"}
0005433345984	59DF40	9884 726868	ANASTASIYA PAVLOVA	{"phone": "+70048332986"}
0005433345985	B36957	8062 327423	VLADISLAV ALEKSEEV	{"email": "alekseevv.17081973@postgrespro.ru", "phone": "+70315588875"}
0005433345986	9F58E2	8541 316757	SERGEY STEPANOV	{"phone": "+70982610259"}
0005433345987	59FD88	1325 851008	SVETLANA FADEEVA	{"phone": "+70171970584"}
0005433345988	F8322C	9988 409016	YURIY SOKOLOV	{"email": "yuriy-sokolov_1970@postgrespro.ru", "phone": "+70526148048"}
0005433345989	C68889	1572 885199	ANDREY EGOROV	{"email": "egorov-andrey_1970@postgrespro.ru", "phone": "+70392907569"}
0005433345990	BFAC06	3283 042436	ALINA CHERNOVA	{"email": "alina-chernova031975@postgrespro.ru", "phone": "+70415993732"}
0005433345991	9A15FC	5079 592599	DENIS ABRAMOV	{"email": "d_abramov-1970@postgrespro.ru", "phone": "+70532552342"}
0005433345992	9A15FC	1758 063287	EKATERINA CHERNOVA	{"phone": "+70739163694"}
0005433345993	0B87D9	4730 573522	VALENTINA LEBEDEVA	{"phone": "+70303787415"}
0005433345994	AA36D8	8920 590187	VLADISLAV IVANOV	{"email": "v-ivanov.1980@postgrespro.ru", "phone": "+70001843972"}
0005433345995	AA36D8	1837 640033	TIMUR KUZNECOV	{"email": "kuznecov_t_111961@postgrespro.ru", "phone": "+70435311612"}
0005433345996	7B0E65	9593 460835	RINAT KOZLOV	{"email": "kozlov_r021981@postgrespro.ru", "phone": "+70560648341"}
0005433345997	7B0E65	4990 921333	MIKHAIL IVANOV	{"phone": "+70738761356"}
0005433345998	37F23C	7876 590595	ANASTASIYA MARTYNOVA	{"phone": "+70989538893"}
0005433345999	37F23C	4173 135623	ANNA NOVIKOVA	{"email": "novikova-anna_011977@postgrespro.ru", "phone": "+70731600154"}
0005433346000	AE491A	3057 473761	ELENA GAVRILOVA	{"phone": "+70510926136"}
0005433346001	2F03D8	0933 427597	ALEKSANDR SMIRNOV	{"phone": "+70291249359"}
0005433346002	84974D	2519 209611	KONSTANTIN POPOV	{"phone": "+70858103597"}
0005433346003	58257C	3218 271792	NADEZHDA ZAKHAROVA	{"email": "zakharova_nadezhda-16011975@postgrespro.ru", "phone": "+70397305308"}
0005433346004	58257C	5396 900166	MIKHAIL BARANOV	{"email": "baranovm.071980@postgrespro.ru", "phone": "+70906725481"}
0005433346005	58257C	9668 459684	MARINA ZHURAVLEVA	{"phone": "+70137153668"}
0005433346006	B179AD	2937 186068	VASILIY FROLOV	{"phone": "+70386348900"}
0005433346007	C00567	7452 208229	ALEKSANDR IVANOV	{"phone": "+70573743772"}
0005433346008	E67691	2724 094844	ALEKSANDR NOVIKOV	{"email": "anovikov-26091975@postgrespro.ru", "phone": "+70121345712"}
0005433346009	98DEE3	6220 445873	VLADIMIR ZAYCEV	{"phone": "+70681696731"}
0005433346010	98DEE3	4658 436329	LYUBOV ZHURAVLEVA	{"phone": "+70540674136"}
0005433346011	AA1F75	5163 312736	VLADIMIR NOVIKOV	{"phone": "+70346536308"}
0005433346012	AA1F75	6618 986186	NAILYA LAZAREVA	{"phone": "+70620695379"}
0005433346013	A3A4E1	3164 086315	NIKOLAY BONDARENKO	{"email": "nbondarenko.1975@postgrespro.ru", "phone": "+70792071674"}
0005433346014	A3A4E1	0837 152304	ANATOLIY SOLOVEV	{"phone": "+70954155300"}
0005433346015	937858	5150 100837	IRINA BARANOVA	{"email": "irinabaranova-08021981@postgrespro.ru", "phone": "+70018707327"}
0005433346016	937858	1025 737160	ALEKSANDR MEDVEDEV	{"phone": "+70329558488"}
0005433346017	1006E4	7532 085383	NIKOLAY BARANOV	{"email": "nikolay.baranov_01081977@postgrespro.ru", "phone": "+70888717960"}
0005433346018	236245	7071 058450	DMITRIY EGOROV	{"phone": "+70915453002"}
0005433346019	236245	4847 188159	ALEKSEY ANTONOV	{"phone": "+70388953126"}
0005433346020	E445AE	7607 288844	MARINA GRISHINA	{"email": "marina_grishina.121970@postgrespro.ru", "phone": "+70309515330"}
0005433346021	6FEE21	4869 144306	RINAT KOZLOV	{"email": "r.kozlov-1968@postgrespro.ru", "phone": "+70726632056"}
0005433346022	6FEE21	9317 795096	YURIY STEPANOV	{"email": "stepanovyuriy05081969@postgrespro.ru", "phone": "+70482296057"}
0005433346023	7028E0	7625 556821	VLADIMIR FEDOROV	{"email": "v.fedorov011982@postgrespro.ru", "phone": "+70512268718"}
0005433346024	64ED80	4038 013007	VIKTOR NIKITIN	{"email": "nikitin.v03051969@postgrespro.ru", "phone": "+70794508020"}
0005433346025	64ED80	5797 418899	GALINA KOROLEVA	{"email": "koroleva-g_091975@postgrespro.ru", "phone": "+70651452758"}
0005433346026	F04472	5698 544368	ANTON BONDARENKO	{"email": "bondarenkoa_1968@postgrespro.ru", "phone": "+70149579743"}
0005433346027	CE98A0	0588 235350	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana.031974@postgrespro.ru", "phone": "+70535709075"}
0005433346028	737233	4916 409228	RAISA KUZNECOVA	{"phone": "+70437726370"}
0005433346029	737233	1355 852722	SERGEY MEDVEDEV	{"phone": "+70465230593"}
0005433346030	65FE23	3493 328557	OLGA NOVIKOVA	{"phone": "+70847038265"}
0005433346031	65FE23	9972 130729	ALEKSEY MIKHAYLOV	{"phone": "+70382245190"}
0005433346032	A8AF8D	0911 100957	NATALIYA EFREMOVA	{"phone": "+70265450423"}
0005433346033	A8AF8D	2918 302090	ROMAN SMIRNOV	{"email": "smirnov_r.07051975@postgrespro.ru", "phone": "+70563350045"}
0005433346034	D7792D	1172 077324	YURIY KUZNECOV	{"phone": "+70079703382"}
0005433346035	05B12F	3692 926238	OLGA ZOTOVA	{"email": "olgazotova19011972@postgrespro.ru", "phone": "+70143443792"}
0005433346036	8336E1	4794 514174	SVETLANA EGOROVA	{"email": "s_egorova_1959@postgrespro.ru", "phone": "+70938317073"}
0005433346037	8336E1	3900 305128	SERGEY MOISEEV	{"email": "moiseev_sergey_16071959@postgrespro.ru", "phone": "+70939987007"}
0005433346038	746C6E	9910 422517	ANNA OSIPOVA	{"email": "anna.osipova.1962@postgrespro.ru", "phone": "+70110137732"}
0005433346039	5BB5A8	3115 001850	ALEKSANDRA EFREMOVA	{"email": "aleksandra_efremova081977@postgrespro.ru", "phone": "+70076587523"}
0005433346040	5BB5A8	6068 650191	ANTONINA SOROKINA	{"phone": "+70653258292"}
0005433346041	5BB5A8	5561 542780	IRINA VLASOVA	{"email": "i_vlasova-10071975@postgrespro.ru", "phone": "+70537525709"}
0005433346042	57EED4	3048 520844	ALEKSANDR ORLOV	{"phone": "+70920760504"}
0005433346043	57EED4	2501 077961	YULIYA NESTEROVA	{"email": "yuliya.nesterova.1974@postgrespro.ru", "phone": "+70618312509"}
0005433346044	63747C	2578 397552	ELENA ANISIMOVA	{"phone": "+70521725767"}
0005433346045	CCCD9E	9738 262985	IRINA ZAKHAROVA	{"email": "zakharovairina111974@postgrespro.ru", "phone": "+70872838420"}
0005433346046	978124	3496 735952	DENIS SOLOVEV	{"phone": "+70723455712"}
0005433346047	35AD3A	9873 645881	SVETLANA STEPANOVA	{"email": "stepanovas_01041975@postgrespro.ru", "phone": "+70500576593"}
0005433346048	F65D08	3242 181884	PETR DAVYDOV	{"email": "p_davydov.20111963@postgrespro.ru", "phone": "+70611513699"}
0005433346049	8477E5	9334 556109	MIKHAIL PETROV	{"email": "m.petrov1979@postgrespro.ru", "phone": "+70569600510"}
0005433346050	BDAF70	5995 865289	MARIYA ILINA	{"email": "ilinam.23071965@postgrespro.ru", "phone": "+70541918884"}
0005433346051	EC4191	9542 805630	TATYANA KULIKOVA	{"email": "kulikovat_1977@postgrespro.ru", "phone": "+70199214632"}
0005433346052	EC4191	1112 993947	TATYANA RODIONOVA	{"phone": "+70625490278"}
0005433346053	B0DF34	0259 344245	TAMARA LAZAREVA	{"phone": "+70103995828"}
0005433346054	B0DF34	2846 079584	YULIYA SAVELEVA	{"email": "y_saveleva.24011969@postgrespro.ru", "phone": "+70877221606"}
0005433346055	B0DF34	4520 958771	MARINA NESTEROVA	{"phone": "+70636668572"}
0005433346056	F2E6D6	9515 050455	IRINA TIKHONOVA	{"email": "tikhonova.i-1970@postgrespro.ru", "phone": "+70740988055"}
0005433346057	D77538	4690 195530	IVAN GORBUNOV	{"email": "gorbunovivan_061973@postgrespro.ru", "phone": "+70116440119"}
0005433346058	46DBAE	5212 214106	ALEKSANDR YAKOVLEV	{"phone": "+70266855488"}
0005433346059	B2FB1D	0901 107329	IRINA SERGEEVA	{"email": "i.sergeeva-081966@postgrespro.ru", "phone": "+70822518392"}
0005433346060	B2FB1D	8733 492624	EVGENIYA POPOVA	{"phone": "+70070427692"}
0005433346061	F3EA13	2099 135648	VYACHESLAV NAUMOV	{"email": "naumov.v.14111973@postgrespro.ru", "phone": "+70039562086"}
0005433346062	939ACA	7365 187401	VLADIMIR DMITRIEV	{"phone": "+70862018777"}
0005433346063	939ACA	7640 257224	ANNA SMIRNOVA	{"phone": "+70730981344"}
0005433346064	939ACA	3854 845750	TATYANA GORBUNOVA	{"phone": "+70978562291"}
0005433346065	E45A81	0953 644444	STANISLAV PETROV	{"phone": "+70909572816"}
0005433346066	E45A81	9475 916519	ELENA ZAKHAROVA	{"email": "elena_zakharova-021976@postgrespro.ru", "phone": "+70156553398"}
0005433346067	D6B522	5176 583945	SERGEY SERGEEV	{"phone": "+70487701728"}
0005433346068	824DDB	6418 521855	MARAT IVANOV	{"email": "m_ivanov_25071964@postgrespro.ru", "phone": "+70572170385"}
0005433346069	73468B	8763 316427	GULNARA TIKHONOVA	{"email": "tikhonova-g-1961@postgrespro.ru", "phone": "+70723927708"}
0005433346070	47A659	8984 086393	ZINAIDA NIKITINA	{"email": "nikitina-z121973@postgrespro.ru", "phone": "+70447389424"}
0005433346071	47A659	9274 052888	RAISA ALEKSEEVA	{"phone": "+70790752925"}
0005433346072	C6102D	6825 764701	LILIYA YAKOVLEVA	{"email": "yakovleva_l1969@postgrespro.ru", "phone": "+70085794395"}
0005433346073	C6102D	3710 322717	PETR CHERNOV	{"email": "p_chernov-1969@postgrespro.ru", "phone": "+70919415071"}
0005433346074	C6102D	0422 366820	VLADIMIR GUSEV	{"email": "gusev.vladimir-061976@postgrespro.ru", "phone": "+70344519295"}
0005433346075	B23BB8	1944 461174	OLGA VASILEVA	{"email": "vasileva-olga_1965@postgrespro.ru", "phone": "+70322135442"}
0005433346076	C17989	9614 918814	VIKTOR SOROKIN	{"email": "sorokin.viktor17081968@postgrespro.ru", "phone": "+70878533394"}
0005433346077	C17989	8076 044999	VYACHESLAV MIKHAYLOV	{"phone": "+70856257141"}
0005433346078	82E71B	3658 098056	VLADISLAV VASILEV	{"phone": "+70587673322"}
0005433346079	82E71B	2846 211694	MIKHAIL PETROV	{"email": "m-petrov.1964@postgrespro.ru", "phone": "+70181367150"}
0005433346080	BFB49A	0121 405171	NADEZHDA ZAKHAROVA	{"email": "zakharovanadezhda.03041974@postgrespro.ru", "phone": "+70542946959"}
0005433346081	BFB49A	3845 628778	TATYANA BOGDANOVA	{"email": "bogdanovat-05051961@postgrespro.ru", "phone": "+70562197283"}
0005433346082	556A3B	4433 924958	VALENTINA NAUMOVA	{"email": "valentina.naumova-091979@postgrespro.ru", "phone": "+70913157844"}
0005433346083	72C46A	5035 671115	ELENA MEDVEDEVA	{"phone": "+70284783336"}
0005433346084	E0D62D	5650 161552	IRINA PAVLOVA	{"phone": "+70099706625"}
0005433346085	F34E6B	7037 265436	NATALIYA IVANOVA	{"email": "n_ivanova-1974@postgrespro.ru", "phone": "+70774836032"}
0005433346086	B18CEF	1490 348364	ELENA PETROVA	{"email": "elena-petrova_021968@postgrespro.ru", "phone": "+70246871233"}
0005433346087	B18CEF	1318 722456	IRINA VASILEVA	{"email": "vasileva-i-1970@postgrespro.ru", "phone": "+70933798504"}
0005433346088	7E9D48	2707 234661	VERA POPOVA	{"email": "popova_vera-1969@postgrespro.ru", "phone": "+70904400216"}
0005433346089	7E9D48	0465 670241	VLADIMIR BORISOV	{"email": "borisov.vladimir_1968@postgrespro.ru", "phone": "+70536968353"}
0005433346090	7E9D48	5334 959503	VLADIMIR ORLOV	{"phone": "+70686846982"}
0005433346091	CA2981	0979 642274	LEV FILIPPOV	{"email": "levfilippov-04061967@postgrespro.ru", "phone": "+70977088421"}
0005433346092	CA2981	8481 257005	LYUDMILA ARKHIPOVA	{"email": "arkhipovalyudmila_10111969@postgrespro.ru", "phone": "+70163227013"}
0005433348887	A07231	1708 869474	ELENA POPOVA	{"phone": "+70508808514"}
0005433348888	30701C	9448 295940	BOGDAN SMIRNOV	{"email": "b-smirnov.29081975@postgrespro.ru", "phone": "+70612217862"}
0005433348889	B99174	8384 857217	SVETLANA KOZLOVA	{"phone": "+70577038699"}
0005433348890	965645	4023 456934	TATYANA ZHURAVLEVA	{"phone": "+70666975300"}
0005433348891	70A1BE	8446 542955	ZAKHAR MIRONOV	{"email": "mironov-zakhar.041970@postgrespro.ru", "phone": "+70698450760"}
0005433348892	4ECE03	1943 137223	ALEVTINA EGOROVA	{"email": "egorova-a.061981@postgrespro.ru", "phone": "+70658362748"}
0005433348893	F536A8	7886 541186	NATALIYA KUZNECOVA	{"email": "kuznecova.n-1968@postgrespro.ru", "phone": "+70698543531"}
0005433348894	6AADF2	7771 066342	NINA KUZNECOVA	{"phone": "+70871350043"}
0005433348895	7102CA	2385 668105	NURIYA AFANASEVA	{"phone": "+70332299075"}
0005433348896	11E780	5716 697656	TATYANA PETROVA	{"phone": "+70641757948"}
0005433348897	A9F2FB	7228 408805	NIKOLAY MIKHAYLOV	{"phone": "+70635531641"}
0005433348898	FA661C	8490 829171	FEDOR NIKITIN	{"phone": "+70854414448"}
0005433348899	A1A4A8	5142 239931	ROMAN ZAKHAROV	{"email": "zakharov_r_041980@postgrespro.ru", "phone": "+70552998949"}
0005433348900	BC8116	1625 321900	ALEKSANDR BARANOV	{"phone": "+70716402316"}
0005433348901	DA2DFA	8493 156164	TATYANA SERGEEVA	{"email": "sergeevatatyana-03041970@postgrespro.ru", "phone": "+70338702244"}
0005433348902	5EFA42	9303 387975	ELENA SCHERBAKOVA	{"phone": "+70884007506"}
0005433348903	4AF7B7	1642 604123	DMITRIY ZAKHAROV	{"phone": "+70732589563"}
0005433348904	A3340C	1639 942026	TATYANA BORISOVA	{"phone": "+70298070916"}
0005433348905	A3340C	9842 312375	KONSTANTIN NOVIKOV	{"phone": "+70803203702"}
0005433348906	257DCA	6283 474089	SERGEY KRASNOV	{"phone": "+70449491058"}
0005433348907	8C4EEF	3784 638369	IVAN FILIPPOV	{"email": "ifilippov_1975@postgrespro.ru", "phone": "+70446044056"}
0005433348908	0ADFE1	8866 165991	IRINA MOROZOVA	{"email": "morozova-irina-1972@postgrespro.ru", "phone": "+70322457623"}
0005433348909	57F5D2	8247 142150	DMITRIY FOMIN	{"phone": "+70479755971"}
0005433348910	F7F5CA	6077 588336	EKATERINA KUZNECOVA	{"email": "kuznecovae-28111970@postgrespro.ru", "phone": "+70847206380"}
0005433348911	F7F5CA	7580 147878	TATYANA GRISHINA	{"email": "grishina_t_091965@postgrespro.ru", "phone": "+70968033948"}
0005433348912	A2452E	3758 826373	GALINA KOZLOVA	{"phone": "+70772343051"}
0005433348913	AFC527	1833 751426	NATALYA DANILOVA	{"phone": "+70949296441"}
0005433348914	94C316	1288 890471	VERA ILINA	{"email": "v.ilina_01031973@postgrespro.ru", "phone": "+70948653451"}
0005433348915	94C316	1092 438253	ANDREY RODIONOV	{"phone": "+70424312918"}
0005433348916	FD71B2	1654 238750	ANNA KUDRYASHOVA	{"phone": "+70818456373"}
0005433348917	58838A	7556 634183	VALENTINA EFIMOVA	{"phone": "+70934958021"}
0005433348918	D21A9E	1562 777673	ALEKSEY VOLKOV	{"phone": "+70661392820"}
0005433348919	A36FA2	4688 266964	YURIY FEDOROV	{"email": "fedorov_y05011977@postgrespro.ru", "phone": "+70103031889"}
0005433348920	A36FA2	3621 163263	LYUDMILA BARANOVA	{"phone": "+70603719241"}
0005433348921	0861B1	0855 341358	VLADIMIR NIKITIN	{"email": "nikitin-v_1978@postgrespro.ru", "phone": "+70717667217"}
0005433348922	81B487	5110 486990	OLGA SAVELEVA	{"email": "saveleva_o.041963@postgrespro.ru", "phone": "+70401969282"}
0005433348923	D335D8	8219 285449	VIKTORIYA KOMAROVA	{"phone": "+70156013144"}
0005433348924	4C69CB	6795 687240	LIDIYA POPOVA	{"phone": "+70659434069"}
0005433348925	1A0E67	9137 503827	PAVEL KOZLOV	{"email": "kozlov-p_051972@postgrespro.ru", "phone": "+70838027494"}
0005433348926	76D085	4311 796849	ELENA SMIRNOVA	{"email": "smirnova-e061986@postgrespro.ru", "phone": "+70108435284"}
0005433348927	76D085	2156 635106	NIKOLAY VOLKOV	{"email": "volkov-nikolay_101977@postgrespro.ru", "phone": "+70555564377"}
0005433348928	1E7594	4001 392925	LILIYA SIDOROVA	{"phone": "+70962311272"}
0005433348929	BE85AB	6711 673878	VALENTINA POLYAKOVA	{"phone": "+70114386655"}
0005433348930	4AA37A	4373 110585	KSENIYA ANDREEVA	{"email": "andreeva.k.12081981@postgrespro.ru", "phone": "+70455667672"}
0005433348931	37F674	1040 182768	TATYANA FROLOVA	{"phone": "+70708315738"}
0005433348932	6F843A	3307 036860	ALEKSANDR IVANOV	{"email": "a_ivanov_04031970@postgrespro.ru", "phone": "+70652021882"}
0005433348933	6F843A	7023 425387	NINA MAKAROVA	{"phone": "+70335922855"}
0005433348934	E308CF	6163 962436	ANNA GAVRILOVA	{"email": "a_gavrilova.28051983@postgrespro.ru", "phone": "+70967622462"}
0005433348935	0A45CE	6489 011890	EVGENIYA SIDOROVA	{"phone": "+70749062519"}
0005433348936	457B8F	9067 941498	ARTEM KOZLOV	{"email": "akozlov_20041967@postgrespro.ru", "phone": "+70536689251"}
0005433348937	457B8F	3702 275427	EKATERINA KOROLEVA	{"phone": "+70137260555"}
0005433348938	A3725F	6773 011665	YULIYA LUKYANOVA	{"phone": "+70341518777"}
0005433348939	009D9C	8133 550698	ANNA MARTYNOVA	{"email": "martynova-anna-1976@postgrespro.ru", "phone": "+70123949091"}
0005433348940	009D9C	9366 877891	LIDIYA SMIRNOVA	{"phone": "+70773362852"}
0005433348941	009D9C	4502 206921	VLADIMIR GRIGOREV	{"phone": "+70923754783"}
0005433348942	F924AA	7802 185849	NINA VASILEVA	{"phone": "+70177507998"}
0005433348943	83A6C7	8977 829953	YURIY MARTYNOV	{"email": "martynov_yuriy_1971@postgrespro.ru", "phone": "+70114040596"}
0005433348944	38D80B	8881 035223	VIKTOR DENISOV	{"phone": "+70158127122"}
0005433348945	1AD2C0	5979 136782	NIKOLAY VLASOV	{"phone": "+70114245934"}
0005433348946	1AD2C0	5037 688237	EKATERINA TIMOFEEVA	{"phone": "+70067255219"}
0005433348947	C799B4	7089 657234	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir27021960@postgrespro.ru", "phone": "+70676308042"}
0005433348948	22650E	6804 809638	IVAN STEPANOV	{"phone": "+70434166404"}
0005433348949	22650E	3845 755010	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr1971@postgrespro.ru", "phone": "+70088264542"}
0005433348950	4C66E3	2025 535506	NINA KOZLOVA	{"phone": "+70883596540"}
0005433348951	4CAF0B	3865 049373	VIKTOR MOISEEV	{"phone": "+70481488292"}
0005433348952	25E506	5790 684679	LYUBOV SOROKINA	{"phone": "+70713380508"}
0005433348953	FE3AC5	8070 815470	KONSTANTIN SAVELEV	{"email": "konstantin.savelev13011967@postgrespro.ru", "phone": "+70293597525"}
0005433348954	1DBD02	7074 061760	OKSANA KOROLEVA	{"email": "o_koroleva_1970@postgrespro.ru", "phone": "+70466653257"}
0005433348955	9229D4	8760 082576	VIKTORIYA YAKOVLEVA	{"phone": "+70275053514"}
0005433348956	9229D4	1885 392715	DIANA KUZMINA	{"email": "dianakuzmina.31031964@postgrespro.ru", "phone": "+70369048339"}
0005433348957	8E0C83	4361 319192	DENIS SCHERBAKOV	{"email": "d.scherbakov.17121988@postgrespro.ru", "phone": "+70247854096"}
0005433348958	E87407	8674 241215	NATALYA OSIPOVA	{"phone": "+70099569380"}
0005433348959	AE6773	4836 120215	NIKOLAY GRIGOREV	{"email": "grigorev_nikolay-29051969@postgrespro.ru", "phone": "+70052100329"}
0005433348960	4FD1EF	6979 645634	VENERA SOROKINA	{"email": "sorokinavenera-06041973@postgrespro.ru", "phone": "+70450948483"}
0005433348961	4FD1EF	6251 752587	DIANA KAZAKOVA	{"phone": "+70261373302"}
0005433348962	DF23F3	0547 660009	SERGEY GORBUNOV	{"phone": "+70322127591"}
0005433348963	DF23F3	5017 033824	MARINA SMIRNOVA	{"email": "smirnova-m_1990@postgrespro.ru", "phone": "+70215157007"}
0005433348964	3B79B7	5657 646823	MAKSIM ALEKSEEV	{"email": "alekseev_m101968@postgrespro.ru", "phone": "+70834398692"}
0005433348965	BE3DC5	4114 999070	DANIIL PETROV	{"email": "daniil.petrov.18031971@postgrespro.ru", "phone": "+70493194663"}
0005433348966	BE3DC5	8315 910987	ALEKSEY DMITRIEV	{"email": "a_dmitriev1970@postgrespro.ru", "phone": "+70345570427"}
0005433348967	E1A337	7994 531862	LYUDMILA DAVYDOVA	{"email": "l.davydova15021971@postgrespro.ru", "phone": "+70120407849"}
0005433348968	EC127B	5939 497109	NIKITA KUZMIN	{"email": "nikita-kuzmin.28121964@postgrespro.ru", "phone": "+70290412416"}
0005433348969	EC127B	9067 097437	GALINA KONOVALOVA	{"email": "galina.konovalova-041982@postgrespro.ru", "phone": "+70054323082"}
0005433348970	271257	2645 775438	RAISA DANILOVA	{"phone": "+70184900081"}
0005433348971	980103	4177 147719	NIKITA KOROLEV	{"email": "nikita.korolev1962@postgrespro.ru", "phone": "+70133560103"}
0005433348972	C36648	1120 537811	TAISIYA POPOVA	{"email": "t.popova_011981@postgrespro.ru", "phone": "+70315865994"}
0005433348973	22B80D	5253 774862	OLGA KONOVALOVA	{"phone": "+70782578888"}
0005433348974	A75E6F	0485 572192	OLGA KUZNECOVA	{"email": "kuznecova-olga1968@postgrespro.ru", "phone": "+70651562474"}
0005433348975	024DE4	4639 499776	NAIL FEDOROV	{"phone": "+70124677556"}
0005433348976	024DE4	7892 426897	NATALYA SMIRNOVA	{"phone": "+70225222324"}
0005433348977	BA6312	3402 013152	VLADIMIR BORISOV	{"email": "borisovv-11121978@postgrespro.ru", "phone": "+70004333553"}
0005433348978	BA6312	1489 611984	OLGA FILATOVA	{"email": "o-filatova-08021970@postgrespro.ru", "phone": "+70585928753"}
0005433348979	39C296	6753 343634	NATALYA SOLOVEVA	{"email": "soloveva-natalya_101980@postgrespro.ru", "phone": "+70008032908"}
0005433348980	E71642	1663 368666	OLGA CHERNOVA	{"phone": "+70214152916"}
0005433348981	E71642	4111 474813	IVAN IVANOV	{"email": "ivanovivan.1970@postgrespro.ru", "phone": "+70126839878"}
0005433348982	219DBB	8382 359922	VLADIMIR VLASOV	{"email": "vvlasov_101966@postgrespro.ru", "phone": "+70262453268"}
0005433348983	219DBB	2127 600334	YULIYA NAZAROVA	{"email": "yuliya.nazarova-101960@postgrespro.ru", "phone": "+70185111902"}
0005433348984	219DBB	7018 149523	ANDREY TIKHONOV	{"email": "andrey.tikhonov-071977@postgrespro.ru", "phone": "+70073965944"}
0005433348985	63A9BA	2411 042850	RASHID STEPANOV	{"email": "rashidstepanov27101976@postgrespro.ru", "phone": "+70052378222"}
0005433348986	63A9BA	4541 914960	SERGEY SCHERBAKOV	{"email": "s.scherbakov031965@postgrespro.ru", "phone": "+70218979610"}
0005433348987	A24EE1	4968 341506	ANNA FILIPPOVA	{"email": "filippova_a.1963@postgrespro.ru", "phone": "+70407599542"}
0005433348988	A24EE1	6047 992677	ALEKSANDR TIKHONOV	{"email": "tikhonov-aleksandr061977@postgrespro.ru", "phone": "+70790262329"}
0005433348989	780245	3191 830459	IVAN IVANOV	{"phone": "+70579152160"}
0005433348990	0DD417	8802 265449	SERGEY IVANOV	{"phone": "+70389113307"}
0005433348991	09DAFD	4733 199382	SERGEY SCHERBAKOV	{"phone": "+70630809400"}
0005433348992	09DAFD	4973 346213	MARIYA ZAYCEVA	{"email": "zaycevamariya.1972@postgrespro.ru", "phone": "+70021622233"}
0005433348993	4F3E5F	8439 469936	SHAMIL KOZLOV	{"email": "shamil_kozlov_1965@postgrespro.ru", "phone": "+70552494521"}
0005433348994	A683FA	9612 981989	ALEKSANDR ALEKSEEV	{"email": "aleksandr-alekseev091975@postgrespro.ru", "phone": "+70068832971"}
0005433348995	965BBE	6950 506749	ANASTASIYA BELOVA	{"email": "belova-anastasiya-1978@postgrespro.ru", "phone": "+70135233597"}
0005433348996	2349A1	7760 188806	ELENA KOZLOVA	{"phone": "+70158434720"}
0005433348997	B1EDA1	0453 178101	ALEKSANDR ROMANOV	{"phone": "+70948594079"}
0005433348998	B1EDA1	4688 918876	PAVEL PAVLOV	{"phone": "+70626104981"}
0005433348999	D882EE	9819 934086	OLESYA KUDRYASHOVA	{"phone": "+70152648411"}
0005433349000	05E203	2118 456769	YURIY KAZAKOV	{"phone": "+70414085560"}
0005433349001	05E203	9279 188752	VYACHESLAV KULIKOV	{"phone": "+70719254780"}
0005433349002	848B6E	4133 221036	ELENA NAUMOVA	{"email": "e.naumova.041964@postgrespro.ru", "phone": "+70230800565"}
0005433349003	7A35DA	8118 919042	DMITRIY SIDOROV	{"email": "sidorov-d-021966@postgrespro.ru", "phone": "+70605028934"}
0005433349004	2538F6	1424 421357	MARIYA POPOVA	{"email": "popova_m_021976@postgrespro.ru", "phone": "+70400081319"}
0005433349005	2538F6	0126 040559	ARTEM SOROKIN	{"email": "a-sorokin.111976@postgrespro.ru", "phone": "+70228377258"}
0005433349006	969ACC	6964 105721	MARINA ROMANOVA	{"phone": "+70967432506"}
0005433349007	2F2AF8	1858 448724	KRISTINA MEDVEDEVA	{"email": "medvedeva_k_19011970@postgrespro.ru", "phone": "+70738145763"}
0005433349008	2F2AF8	6845 897307	DARYA SOROKINA	{"email": "sorokinadarya_041980@postgrespro.ru", "phone": "+70852578547"}
0005433349009	DAAC68	5956 819725	LYUDMILA VOLKOVA	{"email": "l.volkova.071980@postgrespro.ru", "phone": "+70632814669"}
0005433349010	DAAC68	6868 443264	GALINA KRASNOVA	{"email": "gkrasnova.1966@postgrespro.ru", "phone": "+70754769521"}
0005433349011	DAAC68	9473 902735	ANDREY BORISOV	{"phone": "+70301898082"}
0005433349012	B00F6D	8323 693111	VALENTINA LEBEDEVA	{"phone": "+70269164126"}
0005433349013	B00F6D	2787 819706	SVETLANA SERGEEVA	{"phone": "+70939183914"}
0005433349014	FB1BDE	5554 874842	MARAT STEPANOV	{"phone": "+70860116762"}
0005433349015	4787D6	0649 817585	ROMAN MEDVEDEV	{"phone": "+70984526253"}
0005433349016	D29DAF	7288 465267	SERGEY PAVLOV	{"email": "spavlov_26011974@postgrespro.ru", "phone": "+70187929717"}
0005433349017	E08D88	6637 403320	ANTON ABRAMOV	{"phone": "+70622709360"}
0005433349018	FC3D78	3330 583599	SERGEY GERASIMOV	{"email": "gerasimov.s1971@postgrespro.ru", "phone": "+70056172692"}
0005433349019	2F40E6	6336 966716	OLGA RODIONOVA	{"email": "orodionova-30051973@postgrespro.ru", "phone": "+70024507016"}
0005433349020	2F40E6	8681 926683	ALEKSANDRA SCHERBAKOVA	{"phone": "+70593174848"}
0005433349021	48B449	6630 005713	DMITRIY KUZNECOV	{"phone": "+70904940935"}
0005433349022	828F7E	5950 289624	EVGENIY IVANOV	{"email": "e_ivanov.11071981@postgrespro.ru", "phone": "+70404387269"}
0005433349023	84C402	4495 514384	RUSLAN ZAKHAROV	{"phone": "+70577865614"}
0005433349024	77F0EF	6259 731170	PAVEL BARANOV	{"phone": "+70730619622"}
0005433349025	984255	9018 287094	MARAT POPOV	{"phone": "+70394386706"}
0005433349026	984255	4032 842723	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr.1976@postgrespro.ru", "phone": "+70395508587"}
0005433349027	2D2C66	0829 504764	MARIYA TITOVA	{"email": "mtitova_1983@postgrespro.ru", "phone": "+70583425092"}
0005433349028	2D2C66	3772 478553	KIRILL ALEKSEEV	{"email": "kirill.alekseev081974@postgrespro.ru", "phone": "+70415412079"}
0005433349029	0A3233	2849 103148	ANTONINA KUZNECOVA	{"phone": "+70028026913"}
0005433349030	7DE981	6970 885687	MARIYA MELNIKOVA	{"phone": "+70354600775"}
0005433349031	7DE981	6540 121794	ELENA GORBUNOVA	{"email": "gorbunova.elena.1964@postgrespro.ru", "phone": "+70073088546"}
0005433349032	BF997F	9089 849279	OLGA MATVEEVA	{"email": "matveevaolga_1965@postgrespro.ru", "phone": "+70290817885"}
0005433349033	23BBE0	7892 238088	SAMVEL BORISOV	{"email": "samvel.borisov061973@postgrespro.ru", "phone": "+70966621624"}
0005433349034	0EFD20	2583 832432	DANIIL MATVEEV	{"phone": "+70923963370"}
0005433349035	F3018E	0381 236750	RAFAIL NAZAROV	{"phone": "+70575914257"}
0005433349036	EAF465	1692 550058	EKATERINA MAKSIMOVA	{"phone": "+70934079442"}
0005433349037	EAF465	9061 204555	VLADIMIR SOROKIN	{"email": "sorokinv.15121972@postgrespro.ru", "phone": "+70947199666"}
0005433349038	EF9FC0	9627 358410	OKSANA SMIRNOVA	{"phone": "+70099413208"}
0005433349039	157043	2432 078978	ANDREY VASILEV	{"phone": "+70307602498"}
0005433349040	675082	1255 582888	IRINA KARPOVA	{"email": "karpova_irina1977@postgrespro.ru", "phone": "+70828108691"}
0005433349041	675082	9768 112398	ANATOLIY OSIPOV	{"phone": "+70272377900"}
0005433349042	A49D64	7677 881026	VYACHESLAV ZHUKOV	{"phone": "+70655704934"}
0005433349043	C1A596	5661 779233	OLEG SOLOVEV	{"email": "oleg.solovev.031975@postgrespro.ru", "phone": "+70766076846"}
0005433349044	0561E3	9152 541426	ILMIRA MELNIKOVA	{"email": "melnikova-ilmira.1963@postgrespro.ru", "phone": "+70917479141"}
0005433349045	0561E3	5364 950188	EGOR SEMENOV	{"email": "semenov_egor-1975@postgrespro.ru", "phone": "+70316842130"}
0005433349046	B6309F	2289 417594	STEPAN KUZMIN	{"phone": "+70379718816"}
0005433349047	856B82	1725 377964	LEV MAKAROV	{"phone": "+70697930696"}
0005433349048	FC7089	7998 778709	ALEKSEY KRASNOV	{"email": "krasnova.06031969@postgrespro.ru", "phone": "+70003231563"}
0005433349049	3F16A8	8518 630899	DMITRIY PAVLOV	{"email": "pavlovd_1977@postgrespro.ru", "phone": "+70761877940"}
0005433349050	902CA2	3624 906478	SERGEY ROMANOV	{"phone": "+70956154754"}
0005433349051	3400E6	7523 735988	ANNA IVANOVA	{"phone": "+70126407342"}
0005433349052	3400E6	9398 581738	ANASTASIYA KUDRYASHOVA	{"phone": "+70320651362"}
0005433349053	2D75B6	3601 997495	NIKITA BELOV	{"phone": "+70525630650"}
0005433349054	C9A4B2	1580 809334	ANDREY YAKOVLEV	{"phone": "+70553239288"}
0005433349055	D1934D	1539 417187	NATALYA CHERNOVA	{"phone": "+70377398387"}
0005433349056	6B6293	7976 918164	NATALIYA ZHURAVLEVA	{"email": "zhuravleva.nataliya-23081975@postgrespro.ru", "phone": "+70556841645"}
0005433349057	277A55	7209 612038	LYUDMILA OSIPOVA	{"phone": "+70292230231"}
0005433349058	1E1C3E	0310 538344	MIKHAIL MELNIKOV	{"phone": "+70856753551"}
0005433349059	1E1C3E	6008 429042	MIKHAIL GERASIMOV	{"phone": "+70765443155"}
0005433349060	384727	1691 361149	SERGEY OSIPOV	{"phone": "+70918528613"}
0005433349061	7D5B4B	4492 848828	TAGIR POPOV	{"email": "popov-t_1976@postgrespro.ru", "phone": "+70370419042"}
0005433349062	7D5B4B	0623 419316	DMITRIY SAVELEV	{"phone": "+70012285068"}
0005433349063	7D5B4B	2512 179093	LYUDMILA VASILEVA	{"email": "vasilevalyudmila_111963@postgrespro.ru", "phone": "+70134713509"}
0005433349064	6E5347	5708 433864	ANDREY NOVIKOV	{"email": "novikov_a_1975@postgrespro.ru", "phone": "+70207656101"}
0005433349065	6E5347	1448 191289	VALENTIN MOISEEV	{"email": "v-moiseev.1976@postgrespro.ru", "phone": "+70020324360"}
0005433349066	4AA674	8829 592062	ANDREY NAZAROV	{"phone": "+70761375374"}
0005433349067	4AA674	0466 253070	EVGENIY GAVRILOV	{"phone": "+70411798599"}
0005433349068	5D3FB6	2789 027373	OKSANA DMITRIEVA	{"phone": "+70949922968"}
0005433349069	407047	7405 214248	ALEKSEY NIKITIN	{"email": "nikitina-1982@postgrespro.ru", "phone": "+70334736072"}
0005433349070	407047	0284 978252	SVETLANA KOZLOVA	{"phone": "+70510086473"}
0005433349071	3F668D	3624 086712	NIKOLAY FEDOROV	{"email": "fedorovn-121966@postgrespro.ru", "phone": "+70871513017"}
0005433349072	3F668D	5420 059416	TATYANA ERMAKOVA	{"phone": "+70057649868"}
0005433349073	C389EC	0157 014376	VLADIMIR IVANOV	{"email": "vladimirivanov101964@postgrespro.ru", "phone": "+70477457259"}
0005433349074	DA87CF	8267 073448	IVAN TIMOFEEV	{"phone": "+70706815110"}
0005433349075	7611A7	1981 026772	ANASTASIYA NESTEROVA	{"email": "nesterova_anastasiya111975@postgrespro.ru", "phone": "+70219183647"}
0005433349076	7611A7	0795 108590	NADEZHDA ZAKHAROVA	{"email": "zakharovan1973@postgrespro.ru", "phone": "+70372314495"}
0005433349077	84E47E	1147 395265	ANASTASIYA LAZAREVA	{"email": "anastasiyalazareva_1975@postgrespro.ru", "phone": "+70196087429"}
0005433349078	84E47E	7884 578153	DANIL NOVIKOV	{"email": "novikov_d.091979@postgrespro.ru", "phone": "+70494256500"}
0005433349079	0B4D49	7335 745435	DARYA FILATOVA	{"email": "dfilatova.081978@postgrespro.ru", "phone": "+70634499140"}
0005433349080	0B4D49	6309 271056	SERGEY GERASIMOV	{"email": "gerasimovsergey.051980@postgrespro.ru", "phone": "+70483854368"}
0005433349081	62DFB2	1038 302419	LIDIYA KOROLEVA	{"email": "lidiyakoroleva.06031965@postgrespro.ru", "phone": "+70450396492"}
0005433349082	62DFB2	1473 210764	VASILIY PETROV	{"phone": "+70249037844"}
0005433349083	62E1D1	7876 247460	MARINA DAVYDOVA	{"phone": "+70883460002"}
0005433349084	62E1D1	4792 818573	OKSANA KOMAROVA	{"email": "komarovao-091969@postgrespro.ru", "phone": "+70841493538"}
0005433349085	F54BC7	0448 167743	NINA MOROZOVA	{"phone": "+70000467038"}
0005433349086	486A30	6555 640278	IGOR KRASNOV	{"phone": "+70531415031"}
0005433349087	354509	9828 233724	KONSTANTIN KRASNOV	{"email": "konstantin.krasnov-101972@postgrespro.ru", "phone": "+70740189800"}
0005433349088	08BB19	2794 253359	NINA DANILOVA	{"email": "danilova-nina081960@postgrespro.ru", "phone": "+70529808132"}
0005433349089	194729	0709 197530	OLEG SCHERBAKOV	{"phone": "+70210848763"}
0005433349090	42B65C	2112 172446	VIKTOR KOROLEV	{"email": "vkorolev_081958@postgrespro.ru", "phone": "+70039136046"}
0005433349091	85E745	4423 076219	GRIGORIY ALEKSEEV	{"phone": "+70168942745"}
0005433349092	49E75C	5962 584681	LYUDMILA MIRONOVA	{"email": "lmironova.15011974@postgrespro.ru", "phone": "+70634045723"}
0005433349093	E9E117	4082 170952	ANNA POTAPOVA	{"phone": "+70431827384"}
0005433349094	7BFE7F	4467 190580	YULIYA MAKAROVA	{"email": "makarova_y_30011969@postgrespro.ru", "phone": "+70707126265"}
0005433349095	F6A3B2	3117 012530	MAKSIM KOZLOV	{"phone": "+70908369391"}
0005433349096	A81CC2	7525 189250	VALENTINA KOROLEVA	{"email": "koroleva.valentina-1962@postgrespro.ru", "phone": "+70779146220"}
0005433349097	A81CC2	2746 911886	VYACHESLAV KUZMIN	{"phone": "+70408637172"}
0005433349098	BBB3BF	5434 525497	ARTEM SEMENOV	{"email": "semenova.05071966@postgrespro.ru", "phone": "+70616120457"}
0005433349099	51AFD6	9832 394313	ADELINA CHERNOVA	{"email": "adelina_chernova041972@postgrespro.ru", "phone": "+70537037190"}
0005433349100	B39C99	3745 757329	VLADIMIR VASILEV	{"phone": "+70392889475"}
0005433349101	47AA03	8135 550500	MAKSIM GORBUNOV	{"email": "m-gorbunov081972@postgrespro.ru", "phone": "+70849266279"}
0005433349102	9A550F	2209 487776	KSENIYA EGOROVA	{"email": "egorova.k_051971@postgrespro.ru", "phone": "+70190266281"}
0005433349103	2BDBD2	9667 343430	ALEKSANDR ANTONOV	{"phone": "+70437645757"}
0005433349104	A09893	7092 714548	DANIL BORISOV	{"email": "borisov-d_1963@postgrespro.ru", "phone": "+70269894521"}
0005433349105	DFDBF4	0401 572680	NIKITA MELNIKOV	{"phone": "+70068712442"}
0005433349106	FE74AA	4980 347248	IVAN TIKHONOV	{"email": "ivan-tikhonov.1972@postgrespro.ru", "phone": "+70559186712"}
0005433349107	2BC8CF	1169 372233	GALINA POPOVA	{"email": "popova-galina-07061969@postgrespro.ru", "phone": "+70905481220"}
0005433349108	E226FC	2004 912220	NIKITA SOLOVEV	{"phone": "+70301793504"}
0005433349109	3A15D1	5426 657275	MARIYA MIKHAYLOVA	{"phone": "+70104954248"}
0005433349110	ABF409	6504 808241	IGOR BELOV	{"email": "igor.belov01061971@postgrespro.ru", "phone": "+70411960241"}
0005433349111	23EA14	9797 687578	RAMIS SOROKIN	{"email": "ramis-sorokin051978@postgrespro.ru", "phone": "+70212782599"}
0005433349112	77536B	6016 833337	ANDREY OSIPOV	{"email": "osipov_a_1968@postgrespro.ru", "phone": "+70189793985"}
0005433349113	979B20	5051 819358	ILYA PAVLOV	{"phone": "+70951770986"}
0005433349114	979B20	7109 445454	VLADIMIR SHEVCHENKO	{"phone": "+70034810769"}
0005433349115	FBBC3A	9245 783361	EKATERINA KUDRYASHOVA	{"email": "ekaterina_kudryashova.1983@postgrespro.ru", "phone": "+70520303885"}
0005433349116	D548B7	2248 611029	ANDREY MOISEEV	{"email": "moiseev.andrey1981@postgrespro.ru", "phone": "+70648776500"}
0005433349117	465315	2771 204600	TAMARA RODIONOVA	{"email": "tamara.rodionova_1972@postgrespro.ru", "phone": "+70287993950"}
0005433349118	C8B27F	7053 572053	MARIYA EGOROVA	{"email": "mariya.egorova_011978@postgrespro.ru", "phone": "+70342354921"}
0005433349119	675EB8	3073 310658	VLADIMIR SOROKIN	{"phone": "+70030171665"}
0005433349120	675EB8	6724 379967	TATYANA GORBUNOVA	{"email": "gorbunova-tatyana-011960@postgrespro.ru", "phone": "+70086843810"}
0005433349121	9A961D	2300 043365	OLGA IVANOVA	{"phone": "+70254434417"}
0005433349122	9A6972	6266 436157	PELAGEYA VOROBEVA	{"email": "p.vorobeva_29081976@postgrespro.ru", "phone": "+70419355038"}
0005433349123	D7C899	5480 967476	ELENA BORISOVA	{"phone": "+70961640597"}
0005433349124	F81854	9809 928448	ELIZAVETA KUZNECOVA	{"email": "kuznecova-e-101973@postgrespro.ru", "phone": "+70543698538"}
0005433349125	69EBDA	1951 256467	LYUDMILA ZHUKOVA	{"email": "lzhukova.08071975@postgrespro.ru", "phone": "+70559667872"}
0005433349126	C4837C	7134 127436	LEV KOZLOV	{"phone": "+70330178002"}
0005433349127	C4837C	7412 320054	SERGEY ORLOV	{"phone": "+70101925676"}
0005433349128	63A03A	3454 735291	GALINA MELNIKOVA	{"email": "galina.melnikova_23071983@postgrespro.ru", "phone": "+70935411175"}
0005433349129	AA2E0B	2270 619542	GALINA KOROLEVA	{"phone": "+70523675293"}
0005433349130	D4F41A	5780 808346	PETR DAVYDOV	{"email": "petr-davydov_1971@postgrespro.ru", "phone": "+70678547420"}
0005433349131	9C545C	5408 396952	LYUBOV ILINA	{"email": "ilina_lyubov_1973@postgrespro.ru", "phone": "+70220521132"}
0005433349132	983970	5525 849131	IGOR MOROZOV	{"phone": "+70279958483"}
0005433349133	83E74D	1082 013356	GALIYA SMIRNOVA	{"email": "smirnova-g26071970@postgrespro.ru", "phone": "+70562208804"}
0005433349134	4961C9	7435 817566	VYACHESLAV YAKOVLEV	{"phone": "+70112024115"}
0005433349135	E5D951	4923 797092	LYUDMILA KAZAKOVA	{"phone": "+70310953149"}
0005433349136	66B767	9250 645305	LYUBOV KISELEVA	{"phone": "+70795143332"}
0005433349137	7CD3D8	9155 418078	TATYANA KUZMINA	{"phone": "+70670721173"}
0005433349138	3EBE98	7963 166747	SVETLANA BORISOVA	{"phone": "+70670269698"}
0005433349139	7A8B17	7218 638888	EVGENIY ALEKSANDROV	{"email": "aleksandrove071972@postgrespro.ru", "phone": "+70284773038"}
0005433349140	881404	7021 888258	KRISTINA ERMAKOVA	{"email": "kristinaermakova011974@postgrespro.ru", "phone": "+70868431389"}
0005433349141	881404	9671 777210	ELENA ABRAMOVA	{"email": "elena-abramova-051974@postgrespro.ru", "phone": "+70926411003"}
0005433367373	52557D	8001 053695	YULIYA IVANOVA	{"phone": "+70023320409"}
0005433349142	ACA877	3955 959418	ANNA SIDOROVA	{"email": "anna-sidorova-041973@postgrespro.ru", "phone": "+70253894425"}
0005433349143	3D3C14	3118 613880	RAILYA ILINA	{"phone": "+70037768298"}
0005433349144	3D3C14	5623 690878	KONSTANTIN KRASNOV	{"email": "konstantinkrasnov_1965@postgrespro.ru", "phone": "+70307002327"}
0005433349145	EAC848	1023 425665	VLADISLAV FEDOROV	{"email": "fedorov.v_1983@postgrespro.ru", "phone": "+70175378922"}
0005433349146	877F71	4525 013018	EKATERINA SMIRNOVA	{"phone": "+70457881008"}
0005433349147	877F71	3445 248591	IRINA MAKAROVA	{"phone": "+70404106241"}
0005433349148	877F71	3027 984021	RIMMA ZAKHAROVA	{"email": "zakharova.r1970@postgrespro.ru", "phone": "+70666187497"}
0005433349149	55B06E	5169 898707	VYACHESLAV IVANOV	{"phone": "+70458432152"}
0005433349150	55B06E	9744 642228	VLADIMIR NOVIKOV	{"phone": "+70517077182"}
0005433349151	FE5D35	9890 965912	LILIYA VLASOVA	{"email": "vlasova-liliya081974@postgrespro.ru", "phone": "+70874966775"}
0005433349152	886417	3278 562468	GALINA KOROLEVA	{"phone": "+70923390678"}
0005433349153	0947A8	7845 323931	YULIYA ANDREEVA	{"phone": "+70153424458"}
0005433349154	AAE874	5608 669155	VALENTINA ARKHIPOVA	{"phone": "+70202182277"}
0005433349155	18E1C6	5534 184171	ALEKSEY IVANOV	{"email": "ivanov.a.021963@postgrespro.ru", "phone": "+70070422152"}
0005433349156	D8C762	5293 808587	ELEONORA MASLOVA	{"phone": "+70557864116"}
0005433349157	D8C762	7489 577484	PETR SMIRNOV	{"email": "smirnovpetr-1966@postgrespro.ru", "phone": "+70845166631"}
0005433349158	D8C762	0385 985458	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov-011972@postgrespro.ru", "phone": "+70581613513"}
0005433349159	1CF837	6469 126333	PRASKOVYA MALYSHEVA	{"phone": "+70897847945"}
0005433349160	1CF837	7920 837640	KIRILL MAKAROV	{"phone": "+70536535730"}
0005433349161	ACA583	5847 825495	VLADIMIR ORLOV	{"phone": "+70601093456"}
0005433349162	716647	2258 812415	SERGEY RODIONOV	{"email": "sergey.rodionov_28031979@postgrespro.ru", "phone": "+70285276833"}
0005433349163	00C3B3	3670 854440	OLGA ZHURAVLEVA	{"email": "zhuravleva-olga-16041980@postgrespro.ru", "phone": "+70870685096"}
0005433349164	00C3B3	2695 812083	ELENA MOROZOVA	{"phone": "+70581960725"}
0005433349165	00C3B3	5149 442610	VLADIMIR BORISOV	{"email": "vladimir-borisov041983@postgrespro.ru", "phone": "+70208085691"}
0005433349166	067092	6652 927222	TAMARA SMIRNOVA	{"phone": "+70187690784"}
0005433349167	067092	3463 531592	OLGA ORLOVA	{"email": "o.orlova1974@postgrespro.ru", "phone": "+70605089017"}
0005433367233	1B7609	6797 970398	MARIYA POTAPOVA	{"phone": "+70170934318"}
0005433367218	909948	1878 145790	YULIYA KARPOVA	{"email": "ykarpova_101974@postgrespro.ru", "phone": "+70607867790"}
0005433367219	37F94E	4173 903379	TATYANA IVANOVA	{"phone": "+70509962777"}
0005433367220	3D0251	4204 919597	EKATERINA KALININA	{"phone": "+70694874475"}
0005433367221	ADFA5D	8055 616622	ELENA KUZNECOVA	{"email": "elena-kuznecova.1972@postgrespro.ru", "phone": "+70823903460"}
0005433367222	8B5916	6932 898770	SVETLANA MOISEEVA	{"phone": "+70860580698"}
0005433367223	7DBA29	4484 742838	PAVEL ZAYCEV	{"email": "zaycev_p_04101968@postgrespro.ru", "phone": "+70785197435"}
0005433367224	A4731D	3264 296353	OLGA MASLOVA	{"phone": "+70879201043"}
0005433367225	C419C8	3808 088528	VITALIY SCHERBAKOV	{"email": "vitaliy_scherbakov_1973@postgrespro.ru", "phone": "+70414074687"}
0005433367226	C419C8	1274 167123	EKATERINA KOVALEVA	{"email": "kovaleva.ekaterina-1972@postgrespro.ru", "phone": "+70671497209"}
0005433367227	54F99F	8488 539594	NIKOLAY KUZNECOV	{"phone": "+70673636164"}
0005433367228	0EF678	9905 773345	ANASTASIYA MATVEEVA	{"email": "matveeva_anastasiya-24091974@postgrespro.ru", "phone": "+70625287816"}
0005433367229	1B61B6	5932 904584	ANASTASIYA KALININA	{"phone": "+70326679956"}
0005433367230	7AD3E2	2662 394555	VALERIY BONDARENKO	{"phone": "+70275884215"}
0005433367231	7AD3E2	5439 013617	ANDREY EGOROV	{"phone": "+70177254271"}
0005433367232	F15E16	5779 777133	YURIY SMIRNOV	{"email": "smirnovyuriy_1974@postgrespro.ru", "phone": "+70430821777"}
0005433367234	BC73DB	0612 407768	MARINA KUZMINA	{"email": "marina_kuzmina091965@postgrespro.ru", "phone": "+70647844134"}
0005433367235	3AED0A	2695 029618	TATYANA MOROZOVA	{"phone": "+70865624926"}
0005433367236	3AED0A	6932 778733	SOFIYA NESTEROVA	{"email": "sofiyanesterova071980@postgrespro.ru", "phone": "+70494665011"}
0005433367237	21C937	9779 388055	NIKITA SIDOROV	{"phone": "+70281803477"}
0005433367238	157DFE	4950 088400	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr_07081966@postgrespro.ru", "phone": "+70853639074"}
0005433367239	157DFE	4344 292247	VASILIY GRIGOREV	{"email": "grigorevv_101970@postgrespro.ru", "phone": "+70621174946"}
0005433367240	1A3F6A	9831 004239	YULIYA NOVIKOVA	{"email": "novikova.yuliya-26061960@postgrespro.ru", "phone": "+70502310075"}
0005433367241	9DABAD	3691 485654	MATVEY GAVRILOV	{"phone": "+70056853882"}
0005433367242	52B6A8	2348 612362	ANNA PAVLOVA	{"email": "pavlova.a1960@postgrespro.ru", "phone": "+70997432792"}
0005433367243	11E284	0281 542143	TATYANA KUZNECOVA	{"email": "t_kuznecova1976@postgrespro.ru", "phone": "+70297964213"}
0005433367244	989F68	5102 899977	EGOR SEMENOV	{"phone": "+70661145024"}
0005433367245	DF855A	8430 630402	DANIYA TIMOFEEVA	{"email": "timofeeva_d-021974@postgrespro.ru", "phone": "+70329542737"}
0005433367246	88169A	7986 254007	TATYANA NIKITINA	{"email": "nikitina_t_021971@postgrespro.ru", "phone": "+70487858054"}
0005433367247	8C74B0	9191 435304	SERGEY GORBUNOV	{"phone": "+70507108729"}
0005433367248	8C74B0	6571 145297	VERA MOROZOVA	{"email": "veramorozova111979@postgrespro.ru", "phone": "+70906774190"}
0005433367249	5B1C5B	6486 723999	ARTEM KUZMIN	{"email": "artem_kuzmin091961@postgrespro.ru", "phone": "+70179618917"}
0005433367250	5B1C5B	4642 334462	ANDREY KULIKOV	{"email": "kulikov_a_15091972@postgrespro.ru", "phone": "+70672285188"}
0005433367251	3CA4AE	5350 708652	IVAN PAVLOV	{"phone": "+70870768652"}
0005433367252	D2CBF9	8174 042058	LYUDMILA RODIONOVA	{"email": "lyudmila-rodionova_041973@postgrespro.ru", "phone": "+70725667584"}
0005433367253	86D73C	8239 551980	ANTONINA KUZNECOVA	{"email": "a-kuznecova_1988@postgrespro.ru", "phone": "+70470304219"}
0005433367254	420647	8555 814530	TATYANA NIKOLAEVA	{"email": "nikolaeva_t041978@postgrespro.ru", "phone": "+70578085744"}
0005433367255	F06572	8004 545466	SERGEY SEMENOV	{"phone": "+70722902146"}
0005433367256	FD30FF	9502 849207	SVETLANA PAVLOVA	{"phone": "+70844362383"}
0005433367257	FD30FF	6272 553944	GALINA ZHURAVLEVA	{"phone": "+70099811974"}
0005433367258	FD30FF	4275 067114	ALENA KUDRYASHOVA	{"phone": "+70268741290"}
0005433367259	EC3DAE	5605 307692	IRINA FILATOVA	{"phone": "+70355232823"}
0005433367260	B89E44	0301 190353	IRINA SERGEEVA	{"phone": "+70866179626"}
0005433367261	B89E44	0248 881532	VARVARA SMIRNOVA	{"email": "smirnova_v-121961@postgrespro.ru", "phone": "+70444764997"}
0005433367262	164174	9602 691319	ANASTASIYA BELYAEVA	{"email": "belyaeva.anastasiya_1977@postgrespro.ru", "phone": "+70070723170"}
0005433367263	C5EB96	1243 187387	ANNA KOZLOVA	{"email": "kozlova.anna-011970@postgrespro.ru", "phone": "+70965231754"}
0005433367264	FD84FF	6404 770168	VIKTOR KUZNECOV	{"phone": "+70664738673"}
0005433367265	6571E3	2163 594401	GALINA KULIKOVA	{"phone": "+70332696610"}
0005433367266	1E4F72	3716 706288	ANATOLIY POPOV	{"phone": "+70520433235"}
0005433367267	E6F12D	7394 076788	ILYA IVANOV	{"phone": "+70458370317"}
0005433367268	5C7338	1100 974011	ILYA SIDOROV	{"phone": "+70184088999"}
0005433367269	5C7338	7272 820465	IVAN KUZMIN	{"phone": "+70449376786"}
0005433367270	A9355B	1014 654324	VLADISLAV ABRAMOV	{"email": "vladislav_abramov-11121981@postgrespro.ru", "phone": "+70916228211"}
0005433367271	A3E40A	7474 020385	EKATERINA DMITRIEVA	{"email": "ekaterina-dmitrieva.051984@postgrespro.ru", "phone": "+70461705341"}
0005433367272	C169ED	1440 723460	MARGARITA YAKOVLEVA	{"phone": "+70620212735"}
0005433367273	C169ED	8999 817303	VALENTINA TIKHONOVA	{"phone": "+70761175877"}
0005433367274	C169ED	7756 888998	VALENTIN KRASNOV	{"phone": "+70375420371"}
0005433367275	7D9A12	1774 716617	NADEZHDA GRISHINA	{"email": "grishina-n-29071974@postgrespro.ru", "phone": "+70570449943"}
0005433367276	42C2B9	8478 816099	EVGENIYA MELNIKOVA	{"phone": "+70025506346"}
0005433367277	FBDB9D	1270 955352	ELENA EFIMOVA	{"email": "elena.efimova.081967@postgrespro.ru", "phone": "+70909954209"}
0005433367278	F023E2	0362 488493	VALENTIN GORBUNOV	{"email": "gorbunov-valentin1981@postgrespro.ru", "phone": "+70083962678"}
0005433367279	F023E2	5256 720271	ALEKSANDR ZAYCEV	{"email": "a-zaycev_121955@postgrespro.ru", "phone": "+70599029501"}
0005433367280	2F8A6D	7040 523553	KONSTANTIN RODIONOV	{"email": "rodionov-k121977@postgrespro.ru", "phone": "+70017280899"}
0005433367281	92922B	8045 157868	NIKOLAY ANTONOV	{"email": "n_antonov10031964@postgrespro.ru", "phone": "+70756842136"}
0005433367282	65C436	9299 280232	DANIIL OSIPOV	{"phone": "+70418065080"}
0005433367283	D52829	7894 573733	ALEKSANDR ZHUKOV	{"email": "zhukova-14011989@postgrespro.ru", "phone": "+70157936479"}
0005433367284	EF1C62	6475 485402	GLEB ALEKSEEV	{"phone": "+70077341291"}
0005433367285	D84A18	3449 965871	ANASTASIYA LAZAREVA	{"phone": "+70371174104"}
0005433367286	C204CA	0733 144335	ARTEM KUZMIN	{"email": "kuzmin_a-19081969@postgrespro.ru", "phone": "+70447168447"}
0005433367287	5334C9	5513 006065	DIANA KUDRYASHOVA	{"phone": "+70575344575"}
0005433367288	8EC65A	7895 158713	ZINAIDA DENISOVA	{"phone": "+70460657011"}
0005433367289	1BF7F1	6905 983832	SERGEY BONDARENKO	{"phone": "+70297332105"}
0005433367290	1BF7F1	9858 726000	NINA IVANOVA	{"email": "nivanova-26011980@postgrespro.ru", "phone": "+70780283236"}
0005433367291	3B5A96	5592 182057	VIKTORIYA AFANASEVA	{"email": "afanaseva-viktoriya-1975@postgrespro.ru", "phone": "+70527113511"}
0005433367292	EF7E62	2151 833304	ALEKSEY FOMIN	{"email": "fomin_a_1968@postgrespro.ru", "phone": "+70844835678"}
0005433367293	EF7E62	7120 494262	IRAIDA TROFIMOVA	{"phone": "+70624946428"}
0005433367294	31C4ED	9652 271187	ELENA ZOTOVA	{"phone": "+70378884049"}
0005433367295	194835	6916 008681	ALEKSEY ANDREEV	{"phone": "+70329128398"}
0005433367296	A9B370	2942 391795	IGOR EGOROV	{"phone": "+70190395078"}
0005433367297	4ED061	8514 122653	NATALYA KUZNECOVA	{"phone": "+70151817343"}
0005433367298	607626	9973 221042	VIKTOR BARANOV	{"email": "baranovviktor1978@postgrespro.ru", "phone": "+70528327173"}
0005433367299	607626	0175 903787	VALENTIN KUZNECOV	{"phone": "+70857450898"}
0005433367300	36DECE	5472 983833	SERGEY FOMIN	{"email": "s_fomin_01051969@postgrespro.ru", "phone": "+70195255209"}
0005433367301	36DECE	1996 067576	VALENTINA MIKHAYLOVA	{"email": "valentinamikhaylova051974@postgrespro.ru", "phone": "+70155400724"}
0005433367302	3A318E	5002 615098	ALEKSEY IVANOV	{"phone": "+70068789830"}
0005433367303	025558	1637 390781	ANASTASIYA VASILEVA	{"email": "anastasiya_vasileva.081974@postgrespro.ru", "phone": "+70111160311"}
0005433367304	025558	4594 238855	IVAN KULIKOV	{"phone": "+70353751467"}
0005433367305	E30F45	1686 181178	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.1964@postgrespro.ru", "phone": "+70804711002"}
0005433367306	19A9C6	7265 045803	KSENIYA KISELEVA	{"phone": "+70674995390"}
0005433367307	710036	3626 037853	MARINA LAZAREVA	{"phone": "+70857987945"}
0005433367308	710036	2388 717637	DMITRIY NAUMOV	{"email": "dmitriy_naumov-25041973@postgrespro.ru", "phone": "+70506341885"}
0005433367309	EA53A7	4145 840658	VYACHESLAV SHEVCHENKO	{"email": "v_shevchenko-14091969@postgrespro.ru", "phone": "+70786971992"}
0005433367310	879561	6282 314795	ZINAIDA IVANOVA	{"phone": "+70076697225"}
0005433367311	9E0076	0211 665033	ALINA ZAKHAROVA	{"email": "a-zakharova_101974@postgrespro.ru", "phone": "+70984813859"}
0005433367312	9E0076	5362 791837	OLEG KOROLEV	{"email": "oleg.korolev.13061972@postgrespro.ru", "phone": "+70728303735"}
0005433367313	F6D88A	0671 441353	ANATOLIY MIKHAYLOV	{"email": "mikhaylova-1988@postgrespro.ru", "phone": "+70423908388"}
0005433367314	0439CB	3162 002014	ANNA NAZAROVA	{"email": "nazarova_anna.27031974@postgrespro.ru", "phone": "+70000636579"}
0005433367315	F2DE51	8044 576962	NATALYA KOROLEVA	{"phone": "+70528548848"}
0005433367316	0804C3	6889 059050	MARIYA MAKAROVA	{"phone": "+70889619410"}
0005433367317	3A5B03	7348 899505	EVGENIY SCHERBAKOV	{"phone": "+70147137248"}
0005433367318	E4E141	7440 190900	MARIYA MAKAROVA	{"email": "mariya.makarova_05051984@postgrespro.ru", "phone": "+70381106252"}
0005433367319	561782	5016 196898	LYUBOV MAKSIMOVA	{"phone": "+70645688537"}
0005433367320	917823	3448 915958	VYACHESLAV VOROBEV	{"phone": "+70897609778"}
0005433367321	917823	0935 923327	TATYANA MIRONOVA	{"email": "tatyanamironova_1974@postgrespro.ru", "phone": "+70144295907"}
0005433367322	917823	6253 424871	ARTEM GUSEV	{"phone": "+70618099064"}
0005433367323	ED70E4	4256 029153	ANTONINA ILINA	{"phone": "+70536842294"}
0005433367324	917A36	8495 291418	VLADIMIR OSIPOV	{"email": "vosipov_05071962@postgrespro.ru", "phone": "+70340819823"}
0005433367325	279F0C	9299 767822	ALEKSANDR DMITRIEV	{"phone": "+70083709093"}
0005433367326	279F0C	3402 994594	NADEZHDA MIRONOVA	{"email": "nadezhda.mironova-101965@postgrespro.ru", "phone": "+70705128000"}
0005433367327	6EA7E8	9640 616209	ALEKSANDRA LOGINOVA	{"email": "loginova_aleksandra_26051964@postgrespro.ru", "phone": "+70221273476"}
0005433367328	6EA7E8	7270 418026	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr_121972@postgrespro.ru", "phone": "+70076397780"}
0005433367329	EB029A	1389 518199	ALEKSEY NAUMOV	{"email": "naumovaleksey_1976@postgrespro.ru", "phone": "+70559365398"}
0005433367330	C686E6	4845 709365	ILYA VASILEV	{"email": "i.vasilev_021974@postgrespro.ru", "phone": "+70982691286"}
0005433367331	C686E6	8573 133642	GEORGIY KUZNECOV	{"phone": "+70996295241"}
0005433367332	BC0A49	7203 753707	ANNA NIKOLAEVA	{"email": "anna-nikolaeva-111959@postgrespro.ru", "phone": "+70981132683"}
0005433367333	6D75F2	9284 439511	GALINA FROLOVA	{"phone": "+70452024090"}
0005433367334	C02655	0513 055916	ALEKSEY SERGEEV	{"phone": "+70051168084"}
0005433367335	C02655	5312 617460	ANDREY EGOROV	{"phone": "+70041489649"}
0005433367336	C02655	0905 998984	LEONID STEPANOV	{"email": "leonidstepanov_021979@postgrespro.ru", "phone": "+70720177581"}
0005433367337	902327	5914 853967	LIDIYA EFREMOVA	{"phone": "+70050555420"}
0005433367338	A184F4	5565 113868	ALEKSANDR MIRONOV	{"email": "mironovaleksandr-091968@postgrespro.ru", "phone": "+70593062392"}
0005433367339	A184F4	0596 718916	SERGEY POPOV	{"phone": "+70705446551"}
0005433367340	7C4259	3276 644304	LUIZA FROLOVA	{"phone": "+70333787774"}
0005433367341	C48F65	7334 264173	TAMARA ILINA	{"phone": "+70441106834"}
0005433367342	282697	3067 049286	KIRILL VOROBEV	{"phone": "+70279932882"}
0005433367343	0E9FCE	3468 011924	NIKOLAY MOROZOV	{"phone": "+70079860952"}
0005433367344	0E9FCE	8602 666003	SERGEY MIKHAYLOV	{"phone": "+70815732108"}
0005433367345	E80503	5516 220533	TAMARA ZAYCEVA	{"email": "zayceva_t1968@postgrespro.ru", "phone": "+70531961802"}
0005433367401	5ED25F	6527 052829	ALEKSANDR NOVIKOV	{"phone": "+70943372684"}
0005433367346	B42764	9377 088416	ELENA SERGEEVA	{"email": "sergeevaelena07071976@postgrespro.ru", "phone": "+70592187530"}
0005433367347	B42764	5758 768588	DMITRIY NIKITIN	{"email": "nikitin_dmitriy.071972@postgrespro.ru", "phone": "+70763700036"}
0005433367348	38981B	0291 902227	LYUDMILA NIKOLAEVA	{"phone": "+70961533923"}
0005433367349	38981B	4938 485287	VITALIY SOROKIN	{"phone": "+70710585727"}
0005433367350	27C907	9459 058774	IRINA TITOVA	{"phone": "+70596080095"}
0005433367351	2E963B	9433 451837	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_1975@postgrespro.ru", "phone": "+70429048353"}
0005433367352	77B97A	5057 974223	LARISA ALEKSANDROVA	{"email": "larisa_aleksandrova-081969@postgrespro.ru", "phone": "+70943335420"}
0005433367353	614C17	9467 597301	ALEKSANDR SOLOVEV	{"email": "soloveva.09031976@postgrespro.ru", "phone": "+70653843274"}
0005433367354	7478D0	2853 375454	IGOR KUZNECOV	{"email": "i-kuznecov-14121964@postgrespro.ru", "phone": "+70862656922"}
0005433367355	7478D0	6159 454432	VERA ZHURAVLEVA	{"phone": "+70509574691"}
0005433367356	CDB000	9178 785741	TAMARA LAZAREVA	{"email": "tamara.lazareva.31011974@postgrespro.ru", "phone": "+70173179441"}
0005433367357	6210CD	6446 757847	ALEKSANDR DAVYDOV	{"phone": "+70293971414"}
0005433367358	AC6442	9282 550194	YURIY VOLKOV	{"email": "volkov_yuriy.101969@postgrespro.ru", "phone": "+70219444641"}
0005433367359	DD5FAE	5200 124763	INNA MALYSHEVA	{"phone": "+70192326494"}
0005433367360	04D403	9079 160184	TAMARA KAZAKOVA	{"phone": "+70449461635"}
0005433367361	0886EE	2534 944994	EDUARD KISELEV	{"phone": "+70436079474"}
0005433367362	0886EE	4329 294560	VITALIY KRASNOV	{"email": "vitaliy.krasnov_1974@postgrespro.ru", "phone": "+70107507051"}
0005433367363	4E056B	7131 984423	EKATERINA NOVIKOVA	{"phone": "+70273605963"}
0005433367364	4E056B	4748 697712	KSENIYA KOROLEVA	{"email": "kseniya.koroleva1974@postgrespro.ru", "phone": "+70823431515"}
0005433367365	CF3351	5545 264451	PETR BARANOV	{"email": "baranov_p.011968@postgrespro.ru", "phone": "+70147548396"}
0005433367366	DA968F	3392 781215	STANISLAV IVANOV	{"email": "stanislavivanov_031973@postgrespro.ru", "phone": "+70309211472"}
0005433367367	DA968F	1168 490063	VIKTOR MIRONOV	{"email": "viktor_mironov111976@postgrespro.ru", "phone": "+70936445751"}
0005433367368	C48021	0753 714561	ELENA TIMOFEEVA	{"phone": "+70372217165"}
0005433367369	4236E7	1289 434726	MAKSIM FROLOV	{"email": "mfrolov-091968@postgrespro.ru", "phone": "+70071927755"}
0005433367370	7CE9A5	0190 148271	SERGEY RODIONOV	{"phone": "+70992286662"}
0005433367371	7CE9A5	0329 811385	OKSANA POPOVA	{"email": "popova-o-071965@postgrespro.ru", "phone": "+70948108536"}
0005433367372	F78A46	3818 737018	BORIS GAVRILOV	{"email": "gavrilovb.031961@postgrespro.ru", "phone": "+70803852329"}
0005433367374	52557D	0186 270783	GRIGORIY KISELEV	{"email": "grigoriykiselev_1977@postgrespro.ru", "phone": "+70883328979"}
0005433367375	42390D	4898 754008	NINA DMITRIEVA	{"email": "dmitrievanina_1961@postgrespro.ru", "phone": "+70424398669"}
0005433367376	42390D	1921 506597	VERA PAVLOVA	{"phone": "+70481806146"}
0005433367377	7B96E3	1151 961724	VALENTIN NIKOLAEV	{"phone": "+70928123242"}
0005433367378	7B96E3	0351 140896	GEORGIY VLASOV	{"phone": "+70946178095"}
0005433367379	10588C	2258 575004	VIKTOR VOLKOV	{"email": "viktor-volkov_09101987@postgrespro.ru", "phone": "+70127092266"}
0005433367380	D3F94D	0108 940596	NATALYA KUZNECOVA	{"email": "nkuznecova.101965@postgrespro.ru", "phone": "+70805013994"}
0005433367381	3AE661	3936 112275	ELIZAVETA NIKITINA	{"email": "e-nikitina.13111982@postgrespro.ru", "phone": "+70882996024"}
0005433367382	532B19	0266 012986	KLAVDIYA FADEEVA	{"email": "klavdiya.fadeeva.16041976@postgrespro.ru", "phone": "+70561374317"}
0005433367383	C11C0E	5307 704379	VYACHESLAV SIDOROV	{"email": "sidorov_v_081975@postgrespro.ru", "phone": "+70101812691"}
0005433367384	1222AC	1818 761951	SERGEY ISAEV	{"phone": "+70998474599"}
0005433367385	CC75DE	6078 884981	DMITRIY CHERNOV	{"email": "chernov.dmitriy-30101978@postgrespro.ru", "phone": "+70896180536"}
0005433367386	3C6A18	8213 548467	STEPAN ZAKHAROV	{"phone": "+70702250619"}
0005433367387	47D6E2	0795 415909	GALINA MARTYNOVA	{"email": "galina_martynova.091968@postgrespro.ru", "phone": "+70791013535"}
0005433367388	B5EF7E	9333 674769	PAVEL PETROV	{"email": "petrov.p121970@postgrespro.ru", "phone": "+70841658717"}
0005433367389	321A49	8464 644350	LIDIYA SAVELEVA	{"email": "lidiya-saveleva-1975@postgrespro.ru", "phone": "+70997531575"}
0005433367390	DBE845	8015 626067	VIKTORIYA ZHURAVLEVA	{"phone": "+70546272717"}
0005433367391	A81A1C	6389 564306	ZOYA KOVALEVA	{"email": "zoya.kovaleva_1972@postgrespro.ru", "phone": "+70520696625"}
0005433367392	A81A1C	7589 560539	MARGARITA DENISOVA	{"email": "mdenisova_1981@postgrespro.ru", "phone": "+70321588055"}
0005433367393	A81A1C	3525 465444	NATALYA KOZLOVA	{"email": "kozlova_natalya-1970@postgrespro.ru", "phone": "+70084249159"}
0005433367394	0F1BFC	1203 125748	ANDREY IVANOV	{"email": "ivanov-andrey01041971@postgrespro.ru", "phone": "+70369194264"}
0005433367395	12324C	0260 748043	VLADIMIR NIKITIN	{"email": "vnikitin_31011959@postgrespro.ru", "phone": "+70398667106"}
0005433367396	EE5F08	5491 718149	MAKSIM FROLOV	{"email": "m_frolov_30071976@postgrespro.ru", "phone": "+70597310636"}
0005433367397	E3B45B	4586 605450	VALERIYA KUZMINA	{"email": "kuzmina.v-1973@postgrespro.ru", "phone": "+70271434119"}
0005433367398	624DAD	8563 029234	ELENA KUDRYASHOVA	{"phone": "+70174814345"}
0005433367399	5E507D	4212 417459	ZOYA ZOTOVA	{"email": "zotova-z-03061974@postgrespro.ru", "phone": "+70016177615"}
0005433367400	634828	1563 347031	ALEKSEY FEDOROV	{"phone": "+70900312318"}
0005433367402	39075B	1966 752565	ILMIR NIKITIN	{"email": "nikitin-i.1970@postgrespro.ru", "phone": "+70458842103"}
0005433367403	20075D	1263 902037	YAROSLAV IVANOV	{"email": "ivanovyaroslav.15061969@postgrespro.ru", "phone": "+70355133220"}
0005433367404	D58D05	4906 178419	ELENA SOKOLOVA	{"email": "elena.sokolova-071968@postgrespro.ru", "phone": "+70983761980"}
0005433367405	F647FF	2861 064652	ALEKSANDRA VOROBEVA	{"phone": "+70593937514"}
0005433367406	70DE23	3939 321017	SARIYA TIKHONOVA	{"phone": "+70946088899"}
0005433367407	8653B3	3565 858484	NIKOLAY KOROLEV	{"email": "n_korolev.23041979@postgrespro.ru", "phone": "+70842705197"}
0005433367408	8653B3	2288 497196	VYACHESLAV SAVELEV	{"email": "savelevvyacheslav-1980@postgrespro.ru", "phone": "+70476967290"}
0005433367409	8653B3	5372 729104	MARINA ZHUKOVA	{"email": "marina.zhukova_1972@postgrespro.ru", "phone": "+70371870939"}
0005433367410	FCB6EF	1525 042400	ALLA ZAKHAROVA	{"email": "azakharova111959@postgrespro.ru", "phone": "+70005362888"}
0005433367411	FCB6EF	1220 483349	GALINA KUDRYASHOVA	{"email": "g.kudryashova_021980@postgrespro.ru", "phone": "+70557301632"}
0005433367412	D0EEFA	9979 227512	ALEVTINA DMITRIEVA	{"email": "dmitrieva_a_05051967@postgrespro.ru", "phone": "+70070741190"}
0005433367413	B8BA8D	0380 038061	KIRILL KRASNOV	{"email": "krasnov-kirill09121964@postgrespro.ru", "phone": "+70916903655"}
0005433367414	B8BA8D	0603 280997	VADIM IVANOV	{"email": "ivanovv-1969@postgrespro.ru", "phone": "+70282014041"}
0005433367415	E0D2D7	3250 437523	NADEZHDA MIKHAYLOVA	{"phone": "+70620838335"}
0005433367416	83E211	6611 268741	MARIYA FILIPPOVA	{"phone": "+70208832796"}
0005433367417	E19692	9011 777873	KLAVDIYA LEBEDEVA	{"phone": "+70012122072"}
0005433367418	E19692	2956 416514	POLINA PAVLOVA	{"email": "pavlovapolina_20101962@postgrespro.ru", "phone": "+70114711765"}
0005433367419	E19692	1467 950276	ELENA ZAKHAROVA	{"email": "zakharova_elena_12021980@postgrespro.ru", "phone": "+70566405319"}
0005433367420	4C4BD2	3834 128114	DMITRIY POPOV	{"email": "dmitriypopov_22031965@postgrespro.ru", "phone": "+70837286803"}
0005433367421	E2DB51	7561 582780	VLADIMIR BONDARENKO	{"email": "v.bondarenko1960@postgrespro.ru", "phone": "+70433084967"}
0005433367422	D505D9	4388 266742	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr_071977@postgrespro.ru", "phone": "+70887737896"}
0005433367423	913F2D	0545 473820	BORIS NIKOLAEV	{"phone": "+70715370890"}
0005433367424	913F2D	6060 238772	ANNA TARASOVA	{"phone": "+70265044197"}
0005433367425	64D449	2891 780546	VALENTINA GUSEVA	{"phone": "+70123390215"}
0005433367426	64D449	9237 506583	VASILIY TARASOV	{"email": "vasiliy-tarasov071971@postgrespro.ru", "phone": "+70459931814"}
0005433367427	5258E6	7352 526993	ANDREY FEDOROV	{"email": "andrey-fedorov_05021974@postgrespro.ru", "phone": "+70309010867"}
0005433367428	AB5FCB	3553 024973	ANATOLIY MIRONOV	{"phone": "+70108601199"}
0005433367429	3BB801	5496 405460	VERA NESTEROVA	{"email": "v.nesterova-29031973@postgrespro.ru", "phone": "+70542689818"}
0005433367430	3BB801	5220 031981	ANATOLIY DENISOV	{"phone": "+70311082647"}
0005433367431	839C9C	2267 929771	OKSANA GRISHINA	{"phone": "+70740619995"}
0005433367432	839C9C	5919 229976	ALEKSANDR PETROV	{"email": "petrov.aleksandr.1972@postgrespro.ru", "phone": "+70471146065"}
0005433367433	839C9C	1164 360939	IRINA VASILEVA	{"email": "ivasileva.25021975@postgrespro.ru", "phone": "+70200482749"}
0005433367434	81CCC3	8569 068793	EDUARD FROLOV	{"phone": "+70056657968"}
0005433367435	8F0095	5669 324784	LYUDMILA CHERNOVA	{"phone": "+70257005988"}
0005433367436	94D5EB	4761 933341	LYUDMILA MAKAROVA	{"phone": "+70217388130"}
0005433367437	94D5EB	8678 905258	ANASTASIYA BARANOVA	{"phone": "+70044632237"}
0005433367438	C3AA3A	6489 777191	ANDREY KUZNECOV	{"phone": "+70218384625"}
0005433367439	C3AA3A	5874 789653	ANDREY BORISOV	{"phone": "+70520553920"}
0005433367440	C3AA3A	1646 923745	ALEKSANDR KONOVALOV	{"email": "akonovalov_24021964@postgrespro.ru", "phone": "+70397854524"}
0005433367441	36BDEA	6284 549385	ALEKSEY FOMIN	{"phone": "+70764265203"}
0005433367442	36BDEA	4943 826372	VIKTOR ILIN	{"phone": "+70902888304"}
0005433367443	056B6C	7029 482008	MARIYA TIMOFEEVA	{"email": "mariyatimofeeva111976@postgrespro.ru", "phone": "+70747435070"}
0005433367444	C4CD09	0193 068702	ALEKSEY KUZNECOV	{"email": "kuznecova_1979@postgrespro.ru", "phone": "+70552968699"}
0005433367445	5FD3E3	2273 042481	SVETLANA DAVYDOVA	{"email": "davydova_s_021972@postgrespro.ru", "phone": "+70334487727"}
0005433367446	4E0906	3554 365064	LYUDMILA VLASOVA	{"email": "lyudmilavlasova_29081974@postgrespro.ru", "phone": "+70565920854"}
0005433367447	D81FB5	6902 064993	VLADISLAV STEPANOV	{"email": "v_stepanov1973@postgrespro.ru", "phone": "+70134010968"}
0005433367448	81ED6B	5261 029156	YANA KUZNECOVA	{"phone": "+70676637873"}
0005433367449	81ED6B	7887 151353	DARYA DAVYDOVA	{"phone": "+70469413659"}
0005433367450	81ED6B	2548 348827	VADIM KAZAKOV	{"phone": "+70073305240"}
0005433367451	81ED6B	0024 971460	LYUBOV IVANOVA	{"phone": "+70948895880"}
0005433367452	81ED6B	0717 664763	SERGEY POPOV	{"phone": "+70546276526"}
0005433367453	AA0F2E	6043 589576	SVETLANA SCHERBAKOVA	{"phone": "+70529627103"}
0005433367454	AA0F2E	2719 150795	RIMMA VOROBEVA	{"email": "vorobeva-rimma-031973@postgrespro.ru", "phone": "+70140056574"}
0005433367455	DB5DBD	6324 230922	IVAN NAZAROV	{"email": "ivan-nazarov-081971@postgrespro.ru", "phone": "+70037809596"}
0005433367456	FD6F45	3453 015294	EKATERINA FOMINA	{"email": "efomina_1978@postgrespro.ru", "phone": "+70746504074"}
0005433367457	150C25	3105 751904	DMITRIY ZAYCEV	{"phone": "+70116742934"}
0005433367458	83121D	0799 748610	TATYANA ZAYCEVA	{"phone": "+70403605460"}
0005433367459	83121D	1704 644351	ANNA KAZAKOVA	{"phone": "+70768419731"}
0005433367460	B84AB7	1835 714364	NATALYA KRASNOVA	{"email": "krasnova-n_011969@postgrespro.ru", "phone": "+70801166063"}
0005433367461	B84AB7	0866 623708	OLGA SIDOROVA	{"email": "sidorova.olga_121972@postgrespro.ru", "phone": "+70209551761"}
0005433367462	B84AB7	0875 909118	DANIIL DAVYDOV	{"phone": "+70992902856"}
0005433367463	4AF333	6456 547790	OLGA NIKOLAEVA	{"email": "olga-nikolaeva.111968@postgrespro.ru", "phone": "+70435632990"}
0005433367464	4AF333	2093 119930	NADEZHDA MIKHAYLOVA	{"phone": "+70241106224"}
0005433367465	2701C0	0982 691037	NIKOLAY FEDOTOV	{"email": "nfedotov-29081964@postgrespro.ru", "phone": "+70621296928"}
0005433367466	506F32	7864 914556	NATALYA KOROLEVA	{"phone": "+70269801064"}
0005433367467	114C2A	3766 478660	OLESYA BORISOVA	{"email": "borisova-olesya.27111960@postgrespro.ru", "phone": "+70456219853"}
0005433367468	6EB57A	1927 879318	VALENTINA POPOVA	{"phone": "+70821614524"}
0005433367469	1CE479	1870 515728	OLEG SCHERBAKOV	{"email": "scherbakov-oleg.07101969@postgrespro.ru", "phone": "+70172271177"}
0005433367470	6F41D5	2351 584440	KRISTINA RODIONOVA	{"phone": "+70522011682"}
0005433367471	961EE7	2164 501639	RIMMA MAKAROVA	{"email": "makarova_r_05011963@postgrespro.ru", "phone": "+70430130743"}
0005433367472	961EE7	0966 872935	EGOR KUZNECOV	{"phone": "+70621519520"}
0005433367473	987C0E	6009 960859	LARISA ALEKSANDROVA	{"phone": "+70673278579"}
0005433367474	987C0E	5897 291681	SVETLANA PETROVA	{"phone": "+70591471899"}
0005433367475	1F837C	5264 916796	GALINA SERGEEVA	{"phone": "+70247328166"}
0005433367476	1F837C	8086 982872	ELENA ZAKHAROVA	{"phone": "+70594936529"}
0005433367477	8685C1	8707 235427	SERGEY MOROZOV	{"phone": "+70277639946"}
0005433367478	52AE31	4825 844344	LYUDMILA MELNIKOVA	{"phone": "+70810752378"}
0005433367479	52AE31	6806 077166	VIKTOR MOROZOV	{"email": "viktor_morozov-011972@postgrespro.ru", "phone": "+70093157723"}
0005433367480	CC685B	8780 883106	RAISA SIDOROVA	{"email": "sidorova_r-06031985@postgrespro.ru", "phone": "+70800976398"}
0005433367481	097647	4086 026790	ARKADIY ORLOV	{"email": "arkadiyorlov.21021973@postgrespro.ru", "phone": "+70341303231"}
0005433367482	22E1D0	3366 302446	ILYA PETROV	{"email": "petrov-i.04101974@postgrespro.ru", "phone": "+70608434783"}
0005433367483	1D2DB3	2828 960360	ANTON TIKHONOV	{"phone": "+70863684826"}
0005433367484	A3713E	5797 543387	VLADIMIR SERGEEV	{"phone": "+70828446419"}
0005433367485	A3713E	2950 446908	SERGEY NAZAROV	{"email": "sergey-nazarov.041971@postgrespro.ru", "phone": "+70450723300"}
0005433367486	27C17C	0893 118461	LYUBOV SAVELEVA	{"email": "lsaveleva1982@postgrespro.ru", "phone": "+70552452918"}
0005433367487	C80220	2920 235722	ULYANA TARASOVA	{"email": "ulyanatarasova-22031970@postgrespro.ru", "phone": "+70759735511"}
0005433367488	7FE4B0	1470 888623	EVGENIY ALEKSEEV	{"email": "alekseev.evgeniy-051970@postgrespro.ru", "phone": "+70912265611"}
0005433367489	F7AF5E	8297 928941	ANATOLIY POPOV	{"email": "popov.anatoliy_28071966@postgrespro.ru", "phone": "+70052398366"}
0005433367490	F7AF5E	2573 192400	ALEKSEY TIMOFEEV	{"phone": "+70046160530"}
0005433367491	F7AF5E	8344 133928	VIOLETTA LEBEDEVA	{"phone": "+70314622447"}
0005433367492	62F3AD	9278 229559	MARIYA POLYAKOVA	{"email": "polyakova_mariya-051975@postgrespro.ru", "phone": "+70398132187"}
0005433367493	A6184F	3834 021477	VLADIMIR KAZAKOV	{"email": "kazakov_v_121968@postgrespro.ru", "phone": "+70800318967"}
0005433367494	110FA9	4415 899265	NATALYA LEBEDEVA	{"phone": "+70997147281"}
0005433367495	D9C6F9	4429 378261	ULYANA SMIRNOVA	{"phone": "+70663252795"}
0005433367496	D9C6F9	0634 962577	KSENIYA MOISEEVA	{"email": "moiseeva-k111979@postgrespro.ru", "phone": "+70480234048"}
0005433367497	6EAC9B	0472 963589	VIKTORIYA MOROZOVA	{"email": "viktoriya.morozova.25091975@postgrespro.ru", "phone": "+70816008382"}
0005433367498	C72EB6	2320 467421	ANTONINA MOISEEVA	{"phone": "+70406979558"}
0005433367499	C72EB6	8216 845047	ANNA IVANOVA	{"email": "ivanova_a-1968@postgrespro.ru", "phone": "+70712829515"}
0005433367500	F6838C	7163 111101	MIKHAIL MARTYNOV	{"phone": "+70878638204"}
0005433367501	785422	8800 268224	IRINA SOKOLOVA	{"email": "irina-sokolova_24041963@postgrespro.ru", "phone": "+70443807889"}
0005433367502	785422	7231 150506	VLADIMIR KUZNECOV	{"phone": "+70480214516"}
0005433367503	09E7D3	2187 141803	NINA LUKYANOVA	{"email": "nlukyanova.25111971@postgrespro.ru", "phone": "+70678347140"}
0005433367504	09E7D3	7222 965467	ALEKSANDR ZAYCEV	{"phone": "+70124988609"}
0005433367505	DE4CAA	6256 104748	LYUBOV SOROKINA	{"email": "sorokinal041974@postgrespro.ru", "phone": "+70751079454"}
0005433367506	DE4CAA	5608 054155	VLADIMIR SOKOLOV	{"email": "sokolov-v_1963@postgrespro.ru", "phone": "+70369001882"}
0005433367507	5A2F81	7925 488602	ROMAN KUZMIN	{"email": "romankuzmin-101983@postgrespro.ru", "phone": "+70928117024"}
0005433367508	584ED3	4300 377750	SERGEY DAVYDOV	{"email": "s-davydov1972@postgrespro.ru", "phone": "+70484212395"}
0005433367509	584ED3	3406 829657	LYUDMILA NAZAROVA	{"email": "lnazarova29011970@postgrespro.ru", "phone": "+70034954674"}
0005433367510	935CC3	1112 631216	PAVEL ANDREEV	{"email": "andreev_pavel-1969@postgrespro.ru", "phone": "+70127141336"}
0005433367511	935CC3	5191 750600	TATYANA ROMANOVA	{"email": "t_romanova_1978@postgrespro.ru", "phone": "+70762886278"}
0005433367512	1B59F2	9984 051947	TAMARA KISELEVA	{"phone": "+70723855342"}
0005433367513	274F8A	4949 912930	DMITRIY NOVIKOV	{"email": "novikov-d.031976@postgrespro.ru", "phone": "+70229084891"}
0005433367514	274F8A	4543 922987	MARINA LEBEDEVA	{"email": "lebedeva_m061969@postgrespro.ru", "phone": "+70908809117"}
0005433367515	657CE6	3049 873800	VALERIY DMITRIEV	{"email": "valeriy_dmitriev-14111971@postgrespro.ru", "phone": "+70376028576"}
0005433367516	440FF5	6760 996594	EKATERINA KOZLOVA	{"email": "ekaterina_kozlova_06051968@postgrespro.ru", "phone": "+70543880982"}
0005433367517	B4CCD2	1628 098842	EKATERINA MELNIKOVA	{"phone": "+70798777144"}
0005433367518	3B1CDF	9395 385097	GALINA DAVYDOVA	{"email": "galinadavydova.17101967@postgrespro.ru", "phone": "+70059290858"}
0005433367519	694560	7945 777704	EDUARD FEDOROV	{"email": "e_fedorov1963@postgrespro.ru", "phone": "+70387382090"}
0005433367520	FD3071	7515 173292	VASILIY ZAKHAROV	{"email": "v-zakharov_021975@postgrespro.ru", "phone": "+70233322365"}
0005433367521	FD3071	8753 969410	IGOR VLASOV	{"phone": "+70176910224"}
0005433367522	FD3071	0371 459923	LARISA ZAKHAROVA	{"email": "zakharoval-02061969@postgrespro.ru", "phone": "+70710934657"}
0005433367523	FBE69F	7952 654515	MATVEY ANDREEV	{"email": "matveyandreev.02011979@postgrespro.ru", "phone": "+70096313827"}
0005433367524	D6229D	3126 609425	TATYANA PAVLOVA	{"email": "pavlova_tatyana18111958@postgrespro.ru", "phone": "+70240011260"}
0005433367525	E482E1	7004 225856	IVAN SEMENOV	{"phone": "+70393647306"}
0005433367526	45FCE8	1112 094386	NADEZHDA NAUMOVA	{"email": "n-naumova-041959@postgrespro.ru", "phone": "+70245756488"}
0005433367527	ECBF69	6786 429313	ALEKSANDR KONOVALOV	{"phone": "+70666769111"}
0005433367528	90010D	3823 641838	IGOR SHEVCHENKO	{"email": "ishevchenko_24101988@postgrespro.ru", "phone": "+70064712293"}
0005433367529	2E7C25	5188 340916	RUSLAN ROMANOV	{"phone": "+70088015161"}
0005433367530	14FA7E	1040 659713	VASILIY SCHERBAKOV	{"email": "v-scherbakov081974@postgrespro.ru", "phone": "+70025683966"}
0005433367531	40CEAC	2850 330541	NIKOLAY IVANOV	{"phone": "+70713090539"}
0005433367532	DBB1CC	7759 578523	YULIYA SMIRNOVA	{"email": "y-smirnova-031973@postgrespro.ru", "phone": "+70685834901"}
0005433367533	DBB1CC	9189 179746	NIKOLAY PAVLOV	{"email": "nikolay.pavlov021970@postgrespro.ru", "phone": "+70356228691"}
0005433367534	92B0F3	0319 168420	GENNADIY NAZAROV	{"phone": "+70399050480"}
0005433367535	D06DD1	1381 329968	LIDIYA KUZNECOVA	{"email": "kuznecoval.11051971@postgrespro.ru", "phone": "+70346189514"}
0005433367536	DE7CD1	0314 609885	VLADIMIR IVANOV	{"phone": "+70977504001"}
0005433367537	DE7CD1	1780 441577	VIKTOR ISAEV	{"email": "isaev.v_21051974@postgrespro.ru", "phone": "+70353965319"}
0005433367538	8DF41F	2238 872785	IVAN MELNIKOV	{"phone": "+70843899107"}
0005433367539	8DF41F	2844 745765	OLGA KUZNECOVA	{"email": "olga.kuznecova.031973@postgrespro.ru", "phone": "+70476517578"}
0005433367540	662F20	8522 641715	NIKOLAY FROLOV	{"phone": "+70760351215"}
0005433367541	013EAE	3681 785892	ANATOLIY BARANOV	{"email": "baranova_011977@postgrespro.ru", "phone": "+70040546663"}
0005433367542	AA38FC	3421 146517	VASILIY SOKOLOV	{"phone": "+70502980000"}
0005433367543	B0F3C9	1203 140685	EKATERINA TROFIMOVA	{"phone": "+70570361949"}
0005433367544	9764CB	7179 704227	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila031989@postgrespro.ru", "phone": "+70318417625"}
0005433367545	6F0960	0543 585646	ARTEM POPOV	{"phone": "+70216291599"}
0005433367546	6F0960	9511 453703	MARIYA KONOVALOVA	{"phone": "+70480976983"}
0005433367547	6F0960	9599 024331	MARINA BORISOVA	{"email": "borisova.m_11071977@postgrespro.ru", "phone": "+70437508541"}
0005433367548	03E890	9238 180132	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev021967@postgrespro.ru", "phone": "+70878148937"}
0005433367549	1750ED	1388 950240	ALFIYA VOROBEVA	{"email": "a-vorobeva_031972@postgrespro.ru", "phone": "+70994871748"}
0005433367550	1750ED	6679 684618	DARYA PAVLOVA	{"email": "pavlova.d.28011970@postgrespro.ru", "phone": "+70761237945"}
0005433367551	1750ED	0680 814870	YULIYA ZAYCEVA	{"email": "zayceva-y-1959@postgrespro.ru", "phone": "+70673746958"}
0005433367552	CB48F1	9132 009731	MARINA KOZLOVA	{"phone": "+70340917305"}
0005433367553	CB48F1	2330 293128	ROMAN MOROZOV	{"email": "rmorozov-1975@postgrespro.ru", "phone": "+70002800973"}
0005433367554	BC27E2	9992 162627	LYUBOV FILIPPOVA	{"email": "filippoval_111971@postgrespro.ru", "phone": "+70676852617"}
0005433367555	BC27E2	9461 051856	LIDIYA SERGEEVA	{"phone": "+70385435353"}
0005433367556	FBE414	8211 160762	SVETLANA FILIPPOVA	{"phone": "+70700876472"}
0005433367557	9F37E6	6507 942728	VIKTOR KUZNECOV	{"email": "kuznecov.v091975@postgrespro.ru", "phone": "+70426306324"}
0005433367558	9F37E6	4646 483685	MARTA KONOVALOVA	{"email": "konovalova_marta1974@postgrespro.ru", "phone": "+70667053793"}
0005433367559	9F37E6	0751 821360	GALINA NAZAROVA	{"phone": "+70651955129"}
0005433367560	DB0380	1155 454240	ROZA POTAPOVA	{"email": "potapova_roza-1976@postgrespro.ru", "phone": "+70072607998"}
0005433367561	16980D	7117 509471	SERGEY SCHERBAKOV	{"phone": "+70313964267"}
0005433367562	16980D	3726 868110	ELIZAVETA GAVRILOVA	{"email": "gavrilovae.1981@postgrespro.ru", "phone": "+70755701543"}
0005433367563	9A86F4	2707 893176	ZINAIDA KOROLEVA	{"phone": "+70204613100"}
0005433367564	BD6A0E	0986 614516	LEV VOLKOV	{"email": "l.volkov1982@postgrespro.ru", "phone": "+70205690923"}
0005433367565	A7535A	9442 519423	ELVIRA IVANOVA	{"email": "ivanova_e.25091964@postgrespro.ru", "phone": "+70020792765"}
0005433367566	F122B0	5049 639952	VLADIMIR KUZNECOV	{"phone": "+70549786063"}
0005433367567	F122B0	2721 427257	EVGENIY VASILEV	{"email": "vasilevevgeniy101974@postgrespro.ru", "phone": "+70205115573"}
0005433367568	420AC4	9778 140979	DMITRIY ALEKSANDROV	{"email": "aleksandrov-dmitriy091970@postgrespro.ru", "phone": "+70316430864"}
0005433367569	B5E1FE	7292 500492	TATYANA DANILOVA	{"email": "danilovat.1976@postgrespro.ru", "phone": "+70221580682"}
0005433367570	4E013D	0876 508170	SVETLANA MAKSIMOVA	{"phone": "+70530299262"}
0005433367571	EAFC58	5039 555361	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_1976@postgrespro.ru", "phone": "+70178911871"}
0005433367572	EAFC58	5434 440149	GALINA BORISOVA	{"phone": "+70986437381"}
0005433367573	289F35	4828 741163	LYUDMILA ZAYCEVA	{"phone": "+70904113252"}
0005433367574	3E9036	4177 209864	ANTONINA IVANOVA	{"phone": "+70922224877"}
0005433367575	6643AB	6751 441079	OLGA ZHURAVLEVA	{"email": "olga-zhuravleva.011964@postgrespro.ru", "phone": "+70084115226"}
0005433367576	91B9DD	0111 526554	EVGENIY SEMENOV	{"phone": "+70389133694"}
0005433367577	5A5748	4319 144446	ANTON SERGEEV	{"email": "sergeev-anton1974@postgrespro.ru", "phone": "+70906061568"}
0005433367578	5A5748	3141 380397	OLEG KOZLOV	{"phone": "+70611436930"}
0005433367579	B96DF7	7650 169147	LYUBOV KISELEVA	{"phone": "+70507152351"}
0005433367580	7B4DEC	0426 308416	VALENTINA DANILOVA	{"phone": "+70176043581"}
0005433367581	7B4DEC	7572 654838	BORIS FEDOROV	{"email": "fedorov.boris051968@postgrespro.ru", "phone": "+70347118788"}
0005433367582	7B4DEC	0949 326699	DMITRIY MARTYNOV	{"email": "martynovdmitriy.1979@postgrespro.ru", "phone": "+70839470973"}
0005433367583	5F6968	6779 451156	VALENTINA IVANOVA	{"email": "valentina.ivanova111976@postgrespro.ru", "phone": "+70690662484"}
0005433367584	486228	6724 035613	VLADIMIR VOLKOV	{"phone": "+70946428923"}
0005433367585	0F983A	5828 366593	SVETLANA KUZMINA	{"phone": "+70288524769"}
0005433367586	2A94C1	2482 968857	VITALIY SIDOROV	{"email": "vitaliy_sidorov.021964@postgrespro.ru", "phone": "+70369969593"}
0005433367587	6F4ABA	5792 704806	VALENTINA KARPOVA	{"email": "v-karpova-15061977@postgrespro.ru", "phone": "+70231361458"}
0005433367588	149352	6488 178081	ELENA SERGEEVA	{"email": "elenasergeeva_1970@postgrespro.ru", "phone": "+70922690928"}
0005433367589	149352	2331 747453	ALEKSANDR ORLOV	{"phone": "+70161639302"}
0005433367590	66182C	5655 175531	MARINA FEDOROVA	{"email": "fedorova-marina111976@postgrespro.ru", "phone": "+70909943007"}
0005433367591	E2FB8A	1103 234446	KRISTINA KUZNECOVA	{"phone": "+70072390807"}
0005433367592	E2FB8A	1805 280312	ALEKSANDR IVANOV	{"phone": "+70278159693"}
0005433367593	4D66C3	7757 338815	YULIYA KOROLEVA	{"phone": "+70791253549"}
0005433367594	4D66C3	5208 424162	YULIYA MEDVEDEVA	{"email": "medvedevay1967@postgrespro.ru", "phone": "+70314502136"}
0005433367595	4D66C3	1294 634203	ALENA SMIRNOVA	{"phone": "+70273076749"}
0005433367596	168366	0317 863735	GALINA SERGEEVA	{"phone": "+70589987047"}
0005433367597	168366	9049 199345	ANTON DAVYDOV	{"phone": "+70019544239"}
0005433367598	168366	6587 513830	VLADIMIR KAZAKOV	{"email": "kazakov-vladimir1976@postgrespro.ru", "phone": "+70380668510"}
0005433367599	C50BD2	0348 443541	NATALYA SERGEEVA	{"phone": "+70702766635"}
0005433367600	C50BD2	8575 739663	LIDIYA STEPANOVA	{"phone": "+70100271091"}
0005433367601	C50BD2	4065 700969	SERGEY FROLOV	{"email": "frolov-sergey-121974@postgrespro.ru", "phone": "+70586295184"}
0005433367602	80E9E9	8090 376322	VYACHESLAV TIKHONOV	{"phone": "+70977181223"}
0005433367603	F8FAB3	3429 773510	MARINA DANILOVA	{"phone": "+70885367423"}
0005433367604	E9357C	5284 488204	YULIYA ARKHIPOVA	{"email": "yuliya.arkhipova_1968@postgrespro.ru", "phone": "+70861895231"}
0005433367605	E9357C	1568 880903	MIKHAIL SMIRNOV	{"email": "smirnov_m.12101962@postgrespro.ru", "phone": "+70819159411"}
0005433367606	86E984	2765 495341	GENNADIY BARANOV	{"phone": "+70960860602"}
0005433367607	86E984	9063 180899	TATYANA SOKOLOVA	{"email": "tsokolova.01101968@postgrespro.ru", "phone": "+70395881701"}
0005433367608	E64FA1	5349 087170	ALEKSANDR ZAKHAROV	{"phone": "+70181592629"}
0005433367609	E64FA1	8319 371348	ELENA SIDOROVA	{"email": "sidorovaelena.1975@postgrespro.ru", "phone": "+70035610434"}
0005433367610	E64FA1	7845 475293	DANILA BORISOV	{"email": "borisov_danila071962@postgrespro.ru", "phone": "+70822776159"}
0005433367611	122140	2362 182598	DENIS SMIRNOV	{"email": "smirnovd-011977@postgrespro.ru", "phone": "+70352907595"}
0005433367612	014EC4	3466 342839	OLEG KARPOV	{"email": "karpov.oleg.1983@postgrespro.ru", "phone": "+70551609627"}
0005433367613	826792	3423 805555	SERGEY SCHERBAKOV	{"email": "sergeyscherbakov.26091962@postgrespro.ru", "phone": "+70561952643"}
0005433367614	A59057	4043 714623	LIDIYA SEMENOVA	{"email": "lidiya_semenova.1961@postgrespro.ru", "phone": "+70759463088"}
0005433367615	A59057	6115 655789	MARINA ALEKSEEVA	{"phone": "+70107036547"}
0005433367616	A57B40	9099 921615	SERGEY NAZAROV	{"email": "nazarov_s1965@postgrespro.ru", "phone": "+70510144100"}
0005433367617	6897CB	9592 230923	OKSANA SCHERBAKOVA	{"phone": "+70613429209"}
0005433367618	6897CB	7561 482665	ANNA EGOROVA	{"email": "a-egorova1964@postgrespro.ru", "phone": "+70154204677"}
0005433367619	CF3EB4	2264 251291	ANNA IVANOVA	{"phone": "+70995503122"}
0005433367620	4B52B5	1929 822847	LYUDMILA VASILEVA	{"email": "vasileva.l.021974@postgrespro.ru", "phone": "+70676276699"}
0005433367621	4B52B5	2796 053983	EKATERINA MOROZOVA	{"phone": "+70065498826"}
0005433367622	59AB01	4179 878275	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_041975@postgrespro.ru", "phone": "+70004002445"}
0005433367623	9A80BF	4095 250147	ALFIYA KOVALEVA	{"email": "kovaleva-alfiya28121967@postgrespro.ru", "phone": "+70195978524"}
0005433367624	9A80BF	6208 027652	SERGEY VOLKOV	{"email": "s.volkov28121972@postgrespro.ru", "phone": "+70848972569"}
0005433367625	8335EB	0608 134690	BORIS BELOV	{"phone": "+70722965071"}
0005433367626	8335EB	2527 255985	POLINA ALEKSEEVA	{"email": "p_alekseeva1973@postgrespro.ru", "phone": "+70450925311"}
0005433367627	A7A964	4253 060252	MAKSIM MOROZOV	{"email": "morozov_m.1978@postgrespro.ru", "phone": "+70768254291"}
0005433367628	97F8C7	7718 497692	MARINA SEMENOVA	{"email": "marina_semenova_09011968@postgrespro.ru", "phone": "+70392464983"}
0005433367629	904C5D	5958 752994	VITALIY SEMENOV	{"phone": "+70329910646"}
0005433367630	224925	7947 484185	ANDREY GAVRILOV	{"email": "gavrilov-andrey-111964@postgrespro.ru", "phone": "+70348080881"}
0005433367631	185B7D	5996 155282	LIDIYA MARTYNOVA	{"phone": "+70528828619"}
0005433367632	185B7D	5489 810786	TATYANA ZHURAVLEVA	{"email": "t.zhuravleva_091969@postgrespro.ru", "phone": "+70154479408"}
0005433367633	FF58CA	1109 475731	ALEKSANDR EGOROV	{"phone": "+70289039174"}
0005433367634	020D58	4112 305847	DANIIL NAZAROV	{"email": "nazarov_d-1969@postgrespro.ru", "phone": "+70062052851"}
0005433367635	020D58	0205 980816	TATYANA NIKITINA	{"phone": "+70424784745"}
0005433367636	4A37B2	8159 299960	ELENA MOROZOVA	{"email": "morozova_e_21091967@postgrespro.ru", "phone": "+70719174755"}
0005433367637	4FD388	0342 793670	KSENIYA OVCHINNIKOVA	{"email": "k_ovchinnikova.09091979@postgrespro.ru", "phone": "+70124233214"}
0005433367638	E1A727	1845 489471	SERGEY PETROV	{"email": "petrovs.1977@postgrespro.ru", "phone": "+70466534391"}
0005433367639	662964	2591 048603	ZINAIDA MAKSIMOVA	{"phone": "+70216762083"}
0005433367640	9153C7	6363 807135	MIKHAIL IVANOV	{"phone": "+70629044949"}
0005433367641	BA3DB7	3522 465358	KRISTINA SOROKINA	{"email": "sorokinak021978@postgrespro.ru", "phone": "+70412579457"}
0005433367642	52F477	0704 738701	POLINA POPOVA	{"phone": "+70000304013"}
0005433367643	410B19	5299 875638	SVETLANA BOGDANOVA	{"phone": "+70762409424"}
0005433367644	7C6396	3467 866666	YURIY NIKOLAEV	{"email": "nikolaevy.1970@postgrespro.ru", "phone": "+70427682505"}
0005433367645	1BC786	6400 764937	VYACHESLAV GUSEV	{"phone": "+70393530022"}
0005433367646	24DDA4	9339 444925	IRINA FILIPPOVA	{"email": "irinafilippova-101978@postgrespro.ru", "phone": "+70693008380"}
0005433367647	CE4604	9633 254761	OKSANA STEPANOVA	{"email": "stepanova_oksana1975@postgrespro.ru", "phone": "+70971685150"}
0005433367648	CE4604	6068 435469	ALEKSANDRA GERASIMOVA	{"phone": "+70509560412"}
0005433367649	EFB2EE	7022 525322	ELENA ZHUKOVA	{"email": "zhukovaelena.30071973@postgrespro.ru", "phone": "+70082739602"}
0005433367650	75BCDC	6474 395643	ANDREY KUDRYASHOV	{"email": "kudryashov-a.051972@postgrespro.ru", "phone": "+70354306927"}
0005433367651	AF5CEE	0967 440272	OKSANA EGOROVA	{"email": "egorova.oksana.071978@postgrespro.ru", "phone": "+70733330128"}
0005433367652	446018	5476 433181	VLADIMIR BONDARENKO	{"phone": "+70781207187"}
0005433367653	74A286	8416 216557	ELENA KUZNECOVA	{"email": "e-kuznecova-111964@postgrespro.ru", "phone": "+70749425410"}
0005433367654	74A286	2144 117542	VALENTINA STEPANOVA	{"email": "v-stepanova-10011979@postgrespro.ru", "phone": "+70338529903"}
0005433367655	74A286	9545 511918	NIKOLAY NAUMOV	{"phone": "+70674165477"}
0005433367656	28358A	3113 183684	NIKOLAY KUZNECOV	{"phone": "+70980375603"}
0005433367657	CBBBAB	4069 877448	ARTEM ZAYCEV	{"email": "a-zaycev-21121960@postgrespro.ru", "phone": "+70549877631"}
0005433367658	AE5703	2948 896671	ALEKSANDR FROLOV	{"phone": "+70955521486"}
0005433367659	A1645A	3870 876367	VALENTIN SAVELEV	{"phone": "+70237349916"}
0005433367660	A445CF	3888 166220	ANTONINA ZAKHAROVA	{"email": "zakharovaa021971@postgrespro.ru", "phone": "+70891294162"}
0005433367661	A445CF	2522 203131	VIKTOR SHEVCHENKO	{"email": "shevchenko_v081971@postgrespro.ru", "phone": "+70012305198"}
0005433367662	E1F6C4	2839 065268	RINAT MEDVEDEV	{"email": "rinat-medvedev1968@postgrespro.ru", "phone": "+70679531078"}
0005433367663	E1F6C4	8897 675910	NATALYA SERGEEVA	{"email": "sergeeva-natalya_071983@postgrespro.ru", "phone": "+70427938882"}
0005433367664	5DE149	6611 597423	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov.01031981@postgrespro.ru", "phone": "+70470111339"}
0005433367665	50480A	4532 214059	VALENTINA VOLKOVA	{"email": "volkova-valentina21061978@postgrespro.ru", "phone": "+70216216137"}
0005433367666	50480A	7526 816242	ANASTASIYA TIMOFEEVA	{"email": "anastasiyatimofeeva.26061983@postgrespro.ru", "phone": "+70060700606"}
0005433367667	50480A	9146 148534	SERGEY MOROZOV	{"email": "smorozov_1969@postgrespro.ru", "phone": "+70163390272"}
0005433367668	1728E0	9014 570621	ANDREY ZAKHAROV	{"email": "zakharov-a.021963@postgrespro.ru", "phone": "+70816367782"}
0005433367851	AD0771	3717 110556	ANNA IVANOVA	{"phone": "+70883666712"}
0005433367669	1728E0	7058 328943	PETR MAKAROV	{"email": "petr-makarov_06011970@postgrespro.ru", "phone": "+70128642383"}
0005433367670	1728E0	7316 716894	GALINA MOROZOVA	{"email": "morozova-galina-16051973@postgrespro.ru", "phone": "+70522098457"}
0005433367671	119077	5603 584220	TATYANA ROMANOVA	{"phone": "+70871111702"}
0005433367672	BE7DCC	8017 797311	ELENA FEDOROVA	{"phone": "+70726578230"}
0005433367673	BE7DCC	7625 031003	TAMARA NIKIFOROVA	{"phone": "+70040572360"}
0005433367674	08AEEB	4478 175520	DANIL FILIPPOV	{"phone": "+70619290249"}
0005433367675	83BEA6	7976 220343	ROMAN SHEVCHENKO	{"email": "shevchenko.r.1973@postgrespro.ru", "phone": "+70419122926"}
0005433367676	83BEA6	0036 388635	OLGA SERGEEVA	{"phone": "+70468723814"}
0005433367677	83BEA6	3889 154134	VLADIMIR MATVEEV	{"email": "vladimirmatveev-09051979@postgrespro.ru", "phone": "+70366761844"}
0005433367678	83BEA6	6151 696941	VIKTOR IVANOV	{"phone": "+70595762544"}
0005433367679	589CB1	5589 051417	ALEKSANDRA SIDOROVA	{"phone": "+70196133023"}
0005433367680	18756D	1435 710380	KLAVDIYA CHERNOVA	{"phone": "+70936559157"}
0005433367681	18756D	7901 683761	ANATOLIY ORLOV	{"email": "orlov.anatoliy.1975@postgrespro.ru", "phone": "+70270001359"}
0005433367682	F7DDCA	5727 592045	DMITRIY FROLOV	{"email": "dmitriyfrolov1965@postgrespro.ru", "phone": "+70931984678"}
0005433367683	F7DDCA	1426 621895	OLGA FILIPPOVA	{"phone": "+70356563764"}
0005433367684	BA6C56	8769 004263	ALEKSANDRA GAVRILOVA	{"email": "aleksandra_gavrilova_1965@postgrespro.ru", "phone": "+70194732178"}
0005433367685	BA6C56	0222 426486	ELENA ZAKHAROVA	{"email": "zakharova-e1990@postgrespro.ru", "phone": "+70076929341"}
0005433367686	AAC8CB	4619 761792	ALEKSANDR IVANOV	{"phone": "+70881485573"}
0005433367687	6BB8B1	7255 732389	OLGA KOROLEVA	{"email": "o.koroleva_1959@postgrespro.ru", "phone": "+70625034644"}
0005433367688	6BB8B1	4222 977995	ELENA ROMANOVA	{"email": "e_romanova19041983@postgrespro.ru", "phone": "+70417195384"}
0005433367689	B7EA1E	8013 981784	YAROSLAV MAKSIMOV	{"email": "yaroslav.maksimov-1969@postgrespro.ru", "phone": "+70256930060"}
0005433367690	3CD1CC	6270 331629	NINA PETROVA	{"email": "nina_petrova-17091976@postgrespro.ru", "phone": "+70908897286"}
0005433367691	DE67E2	8556 150661	DARYA KOLESNIKOVA	{"phone": "+70345096860"}
0005433367692	A90F38	7330 397076	ANNA KUZMINA	{"phone": "+70189777928"}
0005433367693	A90F38	3807 942682	ALEKSANDRA FEDOROVA	{"phone": "+70215675492"}
0005433367694	A90F38	5476 552598	ALEKSANDR DMITRIEV	{"email": "a-dmitriev.17061982@postgrespro.ru", "phone": "+70068023701"}
0005433367695	25CBC8	5852 848397	EKATERINA KONOVALOVA	{"email": "e-konovalova_021972@postgrespro.ru", "phone": "+70281196897"}
0005433367696	25CBC8	9910 153660	TATYANA MAKSIMOVA	{"email": "maksimova-tatyana-1960@postgrespro.ru", "phone": "+70074889295"}
0005433367697	010A40	1401 311402	NADEZHDA KONDRATEVA	{"email": "kondrateva_nadezhda-1977@postgrespro.ru", "phone": "+70727180480"}
0005433367698	C16607	1118 471998	SVETLANA NOVIKOVA	{"phone": "+70487627982"}
0005433367699	E11212	9602 343730	ANDREY YAKOVLEV	{"phone": "+70999993854"}
0005433367700	1DD142	2206 824644	LILIYA VOROBEVA	{"email": "liliya-vorobeva_14081961@postgrespro.ru", "phone": "+70727614908"}
0005433367701	16B279	4144 360261	DMITRIY VASILEV	{"phone": "+70932876948"}
0005433367702	16B279	4221 073341	SERGEY MAKSIMOV	{"phone": "+70690050771"}
0005433367703	F44E3F	1080 742101	GRIGORIY MATVEEV	{"email": "grigoriy.matveev.1979@postgrespro.ru", "phone": "+70806628105"}
0005433367704	907335	0183 256277	NADEZHDA BORISOVA	{"email": "borisova.n-25071979@postgrespro.ru", "phone": "+70638489314"}
0005433367705	907335	6704 603493	TATYANA EFREMOVA	{"phone": "+70497815719"}
0005433367706	907335	8570 394271	ALEKSEY SIDOROV	{"phone": "+70037387616"}
0005433367707	AEC382	2330 426593	LYUDMILA MEDVEDEVA	{"email": "lmedvedeva_081976@postgrespro.ru", "phone": "+70728927890"}
0005433367708	E7AED5	7900 114367	ARTEM SMIRNOV	{"phone": "+70147746343"}
0005433367709	28C8B6	5755 428158	ZINAIDA DENISOVA	{"phone": "+70407215903"}
0005433367710	D84E66	4340 381845	ALLA CHERNOVA	{"email": "a.chernova_18051974@postgrespro.ru", "phone": "+70823479478"}
0005433367711	AB771E	3040 686219	MIKHAIL MEDVEDEV	{"phone": "+70457526925"}
0005433367712	AB771E	3803 246963	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov22101979@postgrespro.ru", "phone": "+70671234110"}
0005433367713	9492AA	8804 479339	ELENA GORBUNOVA	{"phone": "+70720345046"}
0005433367714	4EC16E	9754 903601	IRINA NIKIFOROVA	{"phone": "+70611780038"}
0005433367715	8F0BC2	6483 289257	NATALYA KISELEVA	{"email": "n-kiseleva-011973@postgrespro.ru", "phone": "+70657298611"}
0005433367716	8F0BC2	6431 217117	SERGEY IVANOV	{"phone": "+70170226678"}
0005433367717	BC0224	3357 839028	NIKOLAY GORBUNOV	{"email": "nikolaygorbunov1974@postgrespro.ru", "phone": "+70827643092"}
0005433367718	BC0224	4242 438078	LIDIYA EFREMOVA	{"email": "efremovalidiya-071983@postgrespro.ru", "phone": "+70658011005"}
0005433367719	15434F	3071 652362	OLGA DENISOVA	{"phone": "+70316654543"}
0005433367720	962592	1835 149297	VALERIYA KUZMINA	{"email": "v.kuzmina_1967@postgrespro.ru", "phone": "+70789646163"}
0005433367721	3C9649	9487 720117	MAKSIM ALEKSANDROV	{"phone": "+70696590505"}
0005433367722	3C9649	0488 670006	NATALYA ROMANOVA	{"email": "n_romanova.10111976@postgrespro.ru", "phone": "+70666463774"}
0005433367723	58E1E4	7738 526246	ARINA SMIRNOVA	{"phone": "+70667789830"}
0005433367724	A75521	9779 462131	VLADIMIR KUZNECOV	{"phone": "+70292894622"}
0005433367725	E490CB	2592 227691	ALEKSEY EGOROV	{"phone": "+70494804359"}
0005433367726	7F7D0D	0793 090582	PAVEL MAKSIMOV	{"email": "pavel_maksimov_23111970@postgrespro.ru", "phone": "+70319493098"}
0005433367727	7F7D0D	9135 849809	GALINA KOZLOVA	{"email": "gkozlova051957@postgrespro.ru", "phone": "+70112830541"}
0005433367728	B323EA	8809 550742	ZOYA KOZLOVA	{"phone": "+70071839041"}
0005433367852	BC7776	3078 138165	SERGEY KUZMIN	{"phone": "+70507604069"}
0005433367729	6534E6	5013 533376	LYUDMILA MAKAROVA	{"email": "l.makarova051976@postgrespro.ru", "phone": "+70745849140"}
0005433367730	9467F7	6444 099353	NINA BOGDANOVA	{"phone": "+70972791093"}
0005433367731	907ABD	9727 401007	IGOR VOLKOV	{"phone": "+70971364249"}
0005433367732	907ABD	1309 529323	LYUBOV NIKITINA	{"phone": "+70971439234"}
0005433367733	907ABD	1819 005591	NADEZHDA PETROVA	{"phone": "+70363976125"}
0005433367734	B7B4E1	8926 369513	KIRILL NIKOLAEV	{"phone": "+70391060978"}
0005433367735	5659FC	7310 472746	SERGEY MIKHAYLOV	{"email": "s.mikhaylov_06121963@postgrespro.ru", "phone": "+70348459446"}
0005433367736	C45AEE	6559 754203	ALEKSANDR KISELEV	{"phone": "+70084534312"}
0005433367737	C45AEE	7481 857538	VYACHESLAV SIDOROV	{"phone": "+70198920726"}
0005433367738	311EC5	4360 782940	YAROSLAV SMIRNOV	{"email": "yaroslav-smirnov10051979@postgrespro.ru", "phone": "+70977248290"}
0005433367739	11ADF0	1978 109422	NIKOLAY MOISEEV	{"phone": "+70410672356"}
0005433367740	11ADF0	3660 627339	NINA KOLESNIKOVA	{"email": "kolesnikova.nina011983@postgrespro.ru", "phone": "+70028017607"}
0005433367741	B0D879	6041 647732	DARYA KUZNECOVA	{"email": "darya_kuznecova121971@postgrespro.ru", "phone": "+70600858813"}
0005433367742	52D734	9579 700201	TAISIYA ABRAMOVA	{"phone": "+70834540603"}
0005433367743	52D734	4098 373115	ALEKSANDR BELOV	{"email": "belov_a_1967@postgrespro.ru", "phone": "+70068341189"}
0005433367744	425E3E	9859 061460	VERA NIKITINA	{"email": "nikitina_vera.09021964@postgrespro.ru", "phone": "+70032116439"}
0005433367745	425E3E	6288 756478	GENNADIY EGOROV	{"phone": "+70342771317"}
0005433367746	76909A	7132 713348	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr-1978@postgrespro.ru", "phone": "+70245727482"}
0005433367747	76909A	8080 180118	VADIM IVANOV	{"email": "ivanov-vadim_11081981@postgrespro.ru", "phone": "+70293740163"}
0005433367748	17EE16	4175 190611	KRISTINA ZAKHAROVA	{"email": "zakharovakristina_03051968@postgrespro.ru", "phone": "+70473840425"}
0005433367749	17EE16	2319 429621	MAKSIM MAKAROV	{"phone": "+70626405625"}
0005433367750	17EE16	2144 029372	IRINA ZHUKOVA	{"email": "zhukova_irina20081970@postgrespro.ru", "phone": "+70631955148"}
0005433367751	2AA22A	8426 891879	IRINA POTAPOVA	{"email": "potapovai.1978@postgrespro.ru", "phone": "+70233046845"}
0005433367752	D74033	6282 453964	MIKHAIL DENISOV	{"email": "denisov-mikhail_18051973@postgrespro.ru", "phone": "+70230913576"}
0005433367753	0CCF12	7347 107826	OLGA ZAKHAROVA	{"phone": "+70457026831"}
0005433367754	3E37BD	9743 519665	EVGENIYA YAKOVLEVA	{"phone": "+70081668473"}
0005433367755	3E37BD	7890 363361	ROMAN ZHUKOV	{"phone": "+70378139443"}
0005433367756	BA041B	6732 320560	MIKHAIL IVANOV	{"email": "ivanov-m23081980@postgrespro.ru", "phone": "+70588902576"}
0005433367757	9E2DD1	1387 276778	MARINA KUZNECOVA	{"phone": "+70161937454"}
0005433367758	59E26B	7836 011784	LEONID TIKHONOV	{"email": "ltikhonov-04051966@postgrespro.ru", "phone": "+70048344511"}
0005433367759	0FCD32	8692 692788	ALBINA IVANOVA	{"email": "ivanova.a.041968@postgrespro.ru", "phone": "+70679967288"}
0005433367760	0FCD32	8389 335259	ZLATA TROFIMOVA	{"phone": "+70550629250"}
0005433367761	F42EDB	7515 695626	SAID SMIRNOV	{"phone": "+70523096322"}
0005433367762	927405	9219 230074	MARIYA ARKHIPOVA	{"phone": "+70704249186"}
0005433367763	766B6F	4058 141490	ALEKSANDRA FOMINA	{"phone": "+70308126492"}
0005433367764	09CEAD	7103 589741	OKSANA KULIKOVA	{"phone": "+70837617411"}
0005433367765	7080DF	3523 810663	YURIY KUZNECOV	{"email": "yuriy.kuznecov.21081967@postgrespro.ru", "phone": "+70881720252"}
0005433367766	7080DF	8803 247845	YURIY CHERNOV	{"phone": "+70099525952"}
0005433367767	96B5B3	9997 238680	ALEKSANDR SMIRNOV	{"phone": "+70410810380"}
0005433367768	96B5B3	8072 844251	PAVEL KUZNECOV	{"email": "kuznecovp-121976@postgrespro.ru", "phone": "+70120168826"}
0005433367769	B891F6	0231 980815	ANNA KALININA	{"phone": "+70304826621"}
0005433367770	66940A	0061 335134	EVGENIYA BARANOVA	{"email": "ebaranova051963@postgrespro.ru", "phone": "+70492039105"}
0005433367771	AC9973	3233 300262	EKATERINA GERASIMOVA	{"phone": "+70319738481"}
0005433367772	AC9973	3754 461540	VERONIKA MARTYNOVA	{"email": "v-martynova_1976@postgrespro.ru", "phone": "+70264484810"}
0005433367773	D6FBEC	2687 045212	POLINA TROFIMOVA	{"email": "p_trofimova-111984@postgrespro.ru", "phone": "+70031113526"}
0005433367774	279904	8467 509571	MIKHAIL DMITRIEV	{"phone": "+70137094978"}
0005433367775	42000D	4075 285639	SEMEN KUZNECOV	{"phone": "+70055807310"}
0005433367776	42000D	7263 019182	NIKOLAY MIRONOV	{"phone": "+70442456973"}
0005433367777	895007	6204 702730	MARINA PETROVA	{"phone": "+70854711020"}
0005433367778	895007	7659 859154	ALEKSANDR CHERNOV	{"email": "chernov.a.1984@postgrespro.ru", "phone": "+70134018822"}
0005433367779	4F7828	1839 369805	DMITRIY ILIN	{"phone": "+70895364138"}
0005433367780	485351	0552 816252	YULIYA POPOVA	{"email": "popova.y.29031973@postgrespro.ru", "phone": "+70418588164"}
0005433367781	8D4E55	5429 043544	IGOR POPOV	{"phone": "+70718835462"}
0005433367782	03F981	5629 414657	EKATERINA NESTEROVA	{"phone": "+70489226126"}
0005433367783	03F981	9982 892263	ANZHELIKA VOROBEVA	{"email": "a-vorobeva.1974@postgrespro.ru", "phone": "+70777537979"}
0005433367784	03F981	5302 838215	ELENA ORLOVA	{"phone": "+70720448184"}
0005433367785	539132	2124 960182	TAMARA MOROZOVA	{"email": "t_morozova-091981@postgrespro.ru", "phone": "+70806994830"}
0005433367786	D9ECBC	2358 319140	GALINA KONDRATEVA	{"phone": "+70827424791"}
0005433367787	0EDE03	2093 697379	SEMEN PETROV	{"phone": "+70227748574"}
0005433367788	3E3A50	3561 835936	EKATERINA ANDREEVA	{"phone": "+70209979447"}
0005433367789	88D839	3469 412632	VALENTINA ERMAKOVA	{"phone": "+70779624324"}
0005433367790	746C9D	0174 379849	VASILIY KULIKOV	{"phone": "+70324809649"}
0005433367791	0B4A29	6279 714193	ALEKSANDR FROLOV	{"phone": "+70351904174"}
0005433367792	BCCA65	2558 601043	ALEKSANDRA ZAKHAROVA	{"email": "a_zakharova011967@postgrespro.ru", "phone": "+70106063945"}
0005433367793	BCCA65	1370 384651	TATYANA VOLKOVA	{"phone": "+70196224914"}
0005433367794	FFCB5E	9021 190250	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylovaa-1993@postgrespro.ru", "phone": "+70344172238"}
0005433367795	1BF648	7045 357170	VALENTINA NAZAROVA	{"email": "vnazarova-1987@postgrespro.ru", "phone": "+70146218715"}
0005433367796	D87344	1599 891860	NATALYA MOROZOVA	{"phone": "+70981156554"}
0005433367797	62BE2B	6788 009692	SERGEY POPOV	{"phone": "+70540933655"}
0005433367798	638391	0675 327741	ELENA YAKOVLEVA	{"phone": "+70093894363"}
0005433367799	25926E	2322 005174	VITALIY FILIPPOV	{"email": "v-filippov21081967@postgrespro.ru", "phone": "+70693843959"}
0005433367800	FD9250	3242 988436	OLGA KAZAKOVA	{"phone": "+70473076369"}
0005433367801	3ED851	4102 124892	ALEKSEY SCHERBAKOV	{"email": "scherbakova18111968@postgrespro.ru", "phone": "+70542054701"}
0005433367802	51B58A	3705 203492	VLADIMIR MEDVEDEV	{"email": "medvedev_vladimir-14031974@postgrespro.ru", "phone": "+70897443159"}
0005433367803	EBD707	7560 189966	IBRAGIM NOVIKOV	{"email": "novikovibragim-071975@postgrespro.ru", "phone": "+70775491343"}
0005433367804	291B1B	3970 062925	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov19061977@postgrespro.ru", "phone": "+70698041317"}
0005433367805	291B1B	0376 368242	MARINA ZAKHAROVA	{"email": "zakharova-marina.1976@postgrespro.ru", "phone": "+70690985153"}
0005433367806	1D1F26	1921 047499	ELENA DANILOVA	{"phone": "+70199197024"}
0005433367807	71F9A9	1467 866301	ROMAN PAVLOV	{"email": "romanpavlov26031977@postgrespro.ru", "phone": "+70013300324"}
0005433367808	71F9A9	4728 026604	VITALIY SERGEEV	{"phone": "+70803567244"}
0005433367809	0CDBA4	4513 416720	ALEKSANDR ABRAMOV	{"email": "abramov.a-09051973@postgrespro.ru", "phone": "+70619465223"}
0005433367810	0CDBA4	6249 470765	ALENA KULIKOVA	{"phone": "+70901377565"}
0005433367811	4BF836	9079 163165	MARINA FILIPPOVA	{"email": "filippova_marina1964@postgrespro.ru", "phone": "+70742785091"}
0005433367812	4BF836	0601 165123	IVAN MEDVEDEV	{"phone": "+70028290703"}
0005433367813	4BF836	2713 103973	NINA EFIMOVA	{"email": "n.efimova_031967@postgrespro.ru", "phone": "+70968108715"}
0005433367814	C9673C	5132 149804	VLADIMIR PAVLOV	{"email": "pavlov-vladimir-071968@postgrespro.ru", "phone": "+70275508411"}
0005433367815	C9673C	7716 682991	EVGENIY BORISOV	{"phone": "+70548048107"}
0005433367816	C9673C	5096 313711	GALINA ANDREEVA	{"email": "andreeva-galina14121972@postgrespro.ru", "phone": "+70493759373"}
0005433367817	EB689D	8071 198112	LIDIYA ZOTOVA	{"email": "zotova-lidiya_1958@postgrespro.ru", "phone": "+70467731202"}
0005433367818	EB689D	8802 804704	SERGEY SOROKIN	{"email": "sergeysorokin121986@postgrespro.ru", "phone": "+70293061417"}
0005433367819	475AEB	4060 668458	PETR FROLOV	{"phone": "+70866203961"}
0005433367820	084EEA	2584 503589	SERGEY TARASOV	{"email": "s_tarasov.071966@postgrespro.ru", "phone": "+70974681019"}
0005433367821	8D105C	8203 125138	IRINA TARASOVA	{"email": "tarasova_i.101982@postgrespro.ru", "phone": "+70375908309"}
0005433367822	8D105C	8641 446524	VLADIMIR DMITRIEV	{"phone": "+70187160291"}
0005433367823	D80ABE	0272 090091	VALENTINA PAVLOVA	{"email": "pavlova_valentina1987@postgrespro.ru", "phone": "+70629381910"}
0005433367824	9A3F1F	2405 027994	PAVEL SMIRNOV	{"phone": "+70224689386"}
0005433367825	D36E1A	8718 160853	VIKTOR BORISOV	{"email": "vborisov1966@postgrespro.ru", "phone": "+70146453723"}
0005433367826	5C3F20	4522 499011	SOFYA MIKHAYLOVA	{"email": "mikhaylovasofya06051969@postgrespro.ru", "phone": "+70920141812"}
0005433367827	17D521	1438 507287	ALEKSANDR SOROKIN	{"phone": "+70630433792"}
0005433367828	883BD3	2701 194875	SERGEY IVANOV	{"phone": "+70857426730"}
0005433367829	883BD3	8965 845538	LYUBOV POPOVA	{"email": "lyubov.popova.061965@postgrespro.ru", "phone": "+70841036031"}
0005433367830	555CC8	7038 085516	OLGA KRASNOVA	{"phone": "+70895872228"}
0005433367831	33AD59	1694 332097	TATYANA EGOROVA	{"phone": "+70414688376"}
0005433367832	89EBF7	8665 993958	LYUBOV ERMAKOVA	{"phone": "+70500612853"}
0005433367833	F1444A	4343 868514	ALEKSANDR VASILEV	{"phone": "+70168335916"}
0005433367834	F7E07E	8643 253398	TATYANA BELOVA	{"phone": "+70931156531"}
0005433367835	F7E07E	9154 079811	EGOR KUZNECOV	{"email": "kuznecov.e12051974@postgrespro.ru", "phone": "+70799854105"}
0005433367836	4B44FF	6623 704438	MARINA KUZMINA	{"email": "kuzmina_marina-17081976@postgrespro.ru", "phone": "+70177976677"}
0005433367837	FD0A93	7840 662887	IGOR MOROZOV	{"phone": "+70762403909"}
0005433367838	543F95	7685 176666	ANDREY MATVEEV	{"email": "matveev.andrey-011983@postgrespro.ru", "phone": "+70124145379"}
0005433367839	C20853	9966 064483	VASILIY ORLOV	{"email": "vasiliy.orlov121975@postgrespro.ru", "phone": "+70286677345"}
0005433367840	48B86D	6153 808982	VLADISLAV DENISOV	{"phone": "+70069407201"}
0005433367841	DE5426	8915 589504	RAIS FROLOV	{"email": "frolov-r01011977@postgrespro.ru", "phone": "+70496395740"}
0005433367842	DE5426	4917 502137	IGOR MATVEEV	{"email": "matveev-i071971@postgrespro.ru", "phone": "+70853079484"}
0005433367843	789BB1	1671 245451	IVAN ZAYCEV	{"email": "zaycev-ivan-1971@postgrespro.ru", "phone": "+70359164342"}
0005433367844	F37B7B	5166 809780	ALENA MOISEEVA	{"email": "alena-moiseeva-1971@postgrespro.ru", "phone": "+70310030543"}
0005433367845	3D739E	5990 490756	VLADISLAV SMIRNOV	{"email": "smirnov_vladislav041973@postgrespro.ru", "phone": "+70325287943"}
0005433367846	0F0281	7305 281996	FEDOR ANDREEV	{"phone": "+70763951288"}
0005433367847	0F0281	9602 027327	VYACHESLAV KUZMIN	{"phone": "+70237560498"}
0005433367848	AF44DA	4230 812899	OKSANA ZAKHAROVA	{"email": "ozakharova1972@postgrespro.ru", "phone": "+70233470127"}
0005433367849	814AAB	9654 370749	MARIYA ROMANOVA	{"email": "m_romanova10051966@postgrespro.ru", "phone": "+70428143961"}
0005433367850	814AAB	8540 245014	VASILIY SOROKIN	{"phone": "+70825029518"}
0005433367853	BC7776	1854 657510	FEDOR KUZNECOV	{"email": "kuznecov_fedor.05121957@postgrespro.ru", "phone": "+70349338959"}
0005433367854	1901BA	9344 165301	ANTON POPOV	{"email": "popova.111979@postgrespro.ru", "phone": "+70259223542"}
0005433367855	D7688D	5146 056644	ALEKSANDR ROMANOV	{"email": "aleksandrromanov1976@postgrespro.ru", "phone": "+70873148504"}
0005433367856	D7688D	4517 804232	NATALYA VLASOVA	{"phone": "+70997472246"}
0005433367857	C02FE0	4766 377045	TATYANA ANTONOVA	{"email": "t_antonova-08041976@postgrespro.ru", "phone": "+70798690828"}
0005433367858	C831F4	7920 428184	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya_1970@postgrespro.ru", "phone": "+70353191891"}
0005433367859	9FAED1	7153 203990	DANIIL FILIPPOV	{"phone": "+70465814701"}
0005433367860	74E6F4	7846 358920	LYUBOV KISELEVA	{"phone": "+70597813074"}
0005433367861	74E6F4	3616 416153	TATYANA POTAPOVA	{"phone": "+70752204921"}
0005433367862	D593F8	0179 909788	NIKOLAY PETROV	{"email": "npetrov23051968@postgrespro.ru", "phone": "+70566793920"}
0005433367863	4E1B64	1121 591962	ELIZAVETA KOROLEVA	{"email": "e-koroleva021986@postgrespro.ru", "phone": "+70372863416"}
0005433367864	4E1B64	3714 747325	VLADIMIR KUZMIN	{"phone": "+70723151074"}
0005433367865	0B97A1	4549 122330	DENIS FILIPPOV	{"email": "d.filippov-041968@postgrespro.ru", "phone": "+70731857746"}
0005433367866	D632EE	0003 688147	OLGA IVANOVA	{"phone": "+70836364621"}
0005433367867	00E6CC	5251 843236	MATVEY ISAEV	{"email": "matvey_isaev-08091974@postgrespro.ru", "phone": "+70924823280"}
0005433367868	39A696	4864 783708	ELENA NIKIFOROVA	{"email": "elena-nikiforova.10051967@postgrespro.ru", "phone": "+70282103061"}
0005433367869	67819A	7120 419147	VLADIMIR GRIGOREV	{"phone": "+70897065651"}
0005433367870	2848E5	7078 035197	LYUBOV SOROKINA	{"phone": "+70836383744"}
0005433367871	419724	7266 510595	VITALIY RODIONOV	{"email": "v_rodionov.061978@postgrespro.ru", "phone": "+70827061293"}
0005433367872	419724	0947 945503	GALINA FROLOVA	{"email": "galina-frolova111975@postgrespro.ru", "phone": "+70357553715"}
0005433367873	F379BD	3894 518598	DANIL PETROV	{"phone": "+70337764620"}
0005433367874	9DBE51	0406 458359	OKSANA KAZAKOVA	{"email": "oksana-kazakova-121975@postgrespro.ru", "phone": "+70723244262"}
0005433367875	9A258E	0119 513390	NIKOLAY IVANOV	{"email": "nivanov.1975@postgrespro.ru", "phone": "+70633129938"}
0005433367876	E16390	7536 681657	NINA KRASNOVA	{"email": "ninakrasnova-1984@postgrespro.ru", "phone": "+70642005459"}
0005433367877	53C931	3354 855308	GEORGIY FEDOTOV	{"phone": "+70847093379"}
0005433367878	56DEDA	6666 861597	GYUZEL LAZAREVA	{"email": "lazareva_gyuzel.1986@postgrespro.ru", "phone": "+70432290674"}
0005433367879	56DEDA	6196 020407	NINA VOLKOVA	{"phone": "+70314771037"}
0005433367880	A5E0F8	3740 150619	EGOR MIRONOV	{"email": "egor_mironov-041980@postgrespro.ru", "phone": "+70953656655"}
0005433367881	A5E0F8	9495 184932	MARINA RYABOVA	{"email": "ryabova_marina.061975@postgrespro.ru", "phone": "+70944374935"}
0005433367882	A001F5	3048 502270	ALEKSANDR KUZNECOV	{"email": "kuznecova-1981@postgrespro.ru", "phone": "+70129397628"}
0005433367883	E83C74	3334 432227	VLADIMIR NIKITIN	{"email": "vladimir_nikitin.1968@postgrespro.ru", "phone": "+70936922297"}
0005433367884	9C68A6	8463 444059	ANTON NIKOLAEV	{"phone": "+70332551940"}
0005433367885	679E31	2843 308883	NIKOLAY FROLOV	{"phone": "+70550089180"}
0005433367886	548C55	6259 805968	VITALIY SMIRNOV	{"phone": "+70569044212"}
0005433367887	548C55	4510 432221	VLADISLAV SAVELEV	{"phone": "+70585092417"}
0005433367888	93F7C1	6963 886598	VALERIY KUZMIN	{"email": "kuzmin.valeriy.021961@postgrespro.ru", "phone": "+70609263938"}
0005433367889	93F7C1	4062 154732	VLADIMIR DAVYDOV	{"email": "davydov.vladimir09051961@postgrespro.ru", "phone": "+70311178534"}
0005433367890	C23718	9621 597661	VALENTINA NIKIFOROVA	{"phone": "+70903292011"}
0005433367891	C23718	6788 906675	NIKOLAY ZHUKOV	{"phone": "+70998355881"}
0005433367892	92A65C	1143 823215	MIKHAIL DAVYDOV	{"email": "m-davydov04081967@postgrespro.ru", "phone": "+70020625664"}
0005433367893	646BD9	1031 840446	VLADIMIR KUDRYASHOV	{"email": "kudryashov_v.121975@postgrespro.ru", "phone": "+70849781864"}
0005433367894	DD5B22	4687 452306	SERGEY OSIPOV	{"email": "sergey.osipov_1983@postgrespro.ru", "phone": "+70338736210"}
0005433367895	DCFD2F	9446 746272	NIKITA IVANOV	{"email": "nikitaivanov-24101977@postgrespro.ru", "phone": "+70640485429"}
0005433367896	DCFD2F	9249 671351	MIKHAIL MOISEEV	{"phone": "+70207754983"}
0005433367897	DCFD2F	8087 850881	ALEKSANDR FEDOROV	{"email": "a.fedorov_16051976@postgrespro.ru", "phone": "+70204648709"}
0005433367898	03FE47	6159 846225	MARINA KAZAKOVA	{"phone": "+70048057130"}
0005433367899	03FE47	9759 213779	MARIYA KUZMINA	{"phone": "+70242138389"}
0005433367900	03FE47	7665 954608	ANATOLIY ABRAMOV	{"phone": "+70231829206"}
0005433367901	03FE47	1022 940928	DMITRIY KONOVALOV	{"email": "konovalovd-1975@postgrespro.ru", "phone": "+70692517181"}
0005433367902	60AD20	6416 036867	OLGA KULIKOVA	{"email": "olga.kulikova.18021978@postgrespro.ru", "phone": "+70851140546"}
0005433367903	7579FA	6863 969077	MAKSIM NIKOLAEV	{"email": "m.nikolaev-071979@postgrespro.ru", "phone": "+70054518413"}
0005433367904	7C6D5A	2276 080977	NATALYA POTAPOVA	{"email": "npotapova101973@postgrespro.ru", "phone": "+70436213445"}
0005433367905	00E28A	8907 312552	ANDREY DENISOV	{"email": "adenisov-1989@postgrespro.ru", "phone": "+70626090030"}
0005433367906	FA75A8	6776 424103	VERA MASLOVA	{"email": "maslova_v-081978@postgrespro.ru", "phone": "+70197388448"}
0005433367907	8AF859	1494 439940	NIKITA GAVRILOV	{"email": "ngavrilov_101970@postgrespro.ru", "phone": "+70869470918"}
0005433367908	1031DF	6221 619454	VALENTINA LAZAREVA	{"phone": "+70794312304"}
0005433367909	32E597	6573 647559	NIKOLAY NAZAROV	{"phone": "+70393000195"}
0005433367910	32E597	4474 152573	GALINA KUZNECOVA	{"email": "galina_kuznecova02011976@postgrespro.ru", "phone": "+70747518354"}
0005433368213	EEB089	1799 565183	ALEKSANDR MELNIKOV	{"phone": "+70498905011"}
0005433367911	13B1FB	8051 502466	EKATERINA ROMANOVA	{"email": "e_romanova051966@postgrespro.ru", "phone": "+70806468434"}
0005433367912	13B1FB	7989 450988	VERA YUDINA	{"email": "verayudina_1962@postgrespro.ru", "phone": "+70000334321"}
0005433367913	812E7A	1512 492118	NIKOLAY SOROKIN	{"email": "nikolay_sorokin-24071974@postgrespro.ru", "phone": "+70684758183"}
0005433367914	65E091	4186 902422	NINA VOROBEVA	{"phone": "+70104778417"}
0005433367915	65E091	5258 516162	NIKOLAY SIDOROV	{"phone": "+70512798816"}
0005433367916	859348	7723 092030	ANATOLIY BORISOV	{"phone": "+70432834802"}
0005433367917	859348	1541 584667	DARYA SCHERBAKOVA	{"phone": "+70656721332"}
0005433367918	D9EE5F	2071 151133	ALBERT KUZMIN	{"email": "kuzminalbert-16011983@postgrespro.ru", "phone": "+70195659269"}
0005433367919	76F012	7850 154040	VIKTORIYA FEDOROVA	{"email": "fedorova-viktoriya-1971@postgrespro.ru", "phone": "+70970804096"}
0005433367920	5D8B16	3231 465912	NIKITA SEMENOV	{"email": "nsemenov.1972@postgrespro.ru", "phone": "+70253973522"}
0005433367921	5D8B16	4294 948213	ANATOLIY TIKHONOV	{"email": "a.tikhonov_1972@postgrespro.ru", "phone": "+70163666875"}
0005433367922	62AF8B	6496 973562	VYACHESLAV GAVRILOV	{"email": "v-gavrilov041960@postgrespro.ru", "phone": "+70655516621"}
0005433367923	E0178D	2686 498456	NIKITA SOROKIN	{"phone": "+70517238259"}
0005433367924	DF8E9B	9921 191574	EDUARD TIKHONOV	{"phone": "+70216241500"}
0005433367925	4B6576	4012 813157	VIKTOR SMIRNOV	{"email": "vsmirnov_1981@postgrespro.ru", "phone": "+70419635288"}
0005433367926	4B6576	3791 632348	NATALYA VLASOVA	{"email": "vlasova.n1977@postgrespro.ru", "phone": "+70065608748"}
0005433367927	08DD74	3852 202112	NADEZHDA GORBUNOVA	{"email": "gorbunova_nadezhda1975@postgrespro.ru", "phone": "+70808458595"}
0005433367928	576015	2572 580765	IGOR KUZMIN	{"phone": "+70203842892"}
0005433367929	26F992	4821 341659	ELENA YUDINA	{"email": "eyudina_1978@postgrespro.ru", "phone": "+70910353537"}
0005433367930	26F992	2731 711689	YULIYA KUZNECOVA	{"email": "kuznecovay-1971@postgrespro.ru", "phone": "+70012918118"}
0005433367931	26F992	4854 537103	YULIYA ILINA	{"email": "yuliyailina-051979@postgrespro.ru", "phone": "+70053125429"}
0005433367932	1BDAE3	7484 103293	ANATOLIY BELOV	{"email": "belov-anatoliy1968@postgrespro.ru", "phone": "+70834087265"}
0005433367933	1BDAE3	3978 911483	ALEKSANDR BARANOV	{"phone": "+70420115126"}
0005433367934	A82D1A	6705 142197	NADEZHDA SOROKINA	{"email": "sorokina.n1974@postgrespro.ru", "phone": "+70267262358"}
0005433367935	0BA356	6435 211580	ALEKSANDRA ROMANOVA	{"email": "romanova_aleksandra061980@postgrespro.ru", "phone": "+70122472945"}
0005433367936	D6C001	0252 940350	ANASTASIYA MAKAROVA	{"phone": "+70820815015"}
0005433367937	D6C001	1807 542614	RAISA PETROVA	{"phone": "+70856354493"}
0005433367938	3C72DA	0448 244119	BORIS VASILEV	{"phone": "+70586863184"}
0005433367939	22B0AC	0996 205422	EVGENIY KOROLEV	{"phone": "+70995704901"}
0005433367940	282F7B	1269 731545	ALEKSEY SOKOLOV	{"email": "aleksey-sokolov1966@postgrespro.ru", "phone": "+70555414852"}
0005433367941	0FEFF6	3635 186843	MIKHAIL PAVLOV	{"phone": "+70023669515"}
0005433367942	72E2FD	5407 350343	VIKTOR VASILEV	{"email": "viktor-vasilev_051973@postgrespro.ru", "phone": "+70851433082"}
0005433367943	72E2FD	7041 361852	OLGA DENISOVA	{"phone": "+70677937609"}
0005433367944	D3A5D3	8627 545252	SERGEY ROMANOV	{"phone": "+70978200264"}
0005433367945	AA8633	2317 585079	DARYA SMIRNOVA	{"phone": "+70153406044"}
0005433367946	2A8447	8104 195596	SERGEY MARTYNOV	{"email": "martynov_s-051977@postgrespro.ru", "phone": "+70494987834"}
0005433367947	5B8AC5	6649 348170	VALENTINA TIKHONOVA	{"email": "valentina-tikhonova.1972@postgrespro.ru", "phone": "+70592116220"}
0005433367948	7688DC	0094 861126	VIKTOR KUZNECOV	{"email": "kuznecovviktor.061978@postgrespro.ru", "phone": "+70143629449"}
0005433367949	DED002	4536 218191	EVGENIY RODIONOV	{"phone": "+70841997450"}
0005433367950	E065C4	7170 397606	ELIZAVETA LEBEDEVA	{"phone": "+70441213029"}
0005433367951	E065C4	4069 479952	SVETLANA FADEEVA	{"phone": "+70591321972"}
0005433367952	544757	1807 200225	ARTEMIY IVANOV	{"email": "a.ivanov12121972@postgrespro.ru", "phone": "+70994778669"}
0005433367953	544757	9046 603047	IRINA ANTONOVA	{"phone": "+70477345639"}
0005433367954	369A47	7891 615303	ANATOLIY SMIRNOV	{"email": "asmirnov-19081966@postgrespro.ru", "phone": "+70823150165"}
0005433367955	369A47	0433 033542	RUSTAM KUZNECOV	{"email": "rustam.kuznecov111985@postgrespro.ru", "phone": "+70829886755"}
0005433367956	A6CCB7	1463 770658	LYUBOV EGOROVA	{"email": "egorova-lyubov.041981@postgrespro.ru", "phone": "+70981852149"}
0005433367957	A6CCB7	6710 728671	ALEKSANDR SMIRNOV	{"phone": "+70687700300"}
0005433367958	4F6034	1500 736674	SVETLANA KUZMINA	{"email": "svetlana-kuzmina071964@postgrespro.ru", "phone": "+70424973392"}
0005433367959	4F6034	8931 199765	LYUDMILA MOISEEVA	{"phone": "+70422293184"}
0005433367960	E8F736	7468 403904	ELENA GAVRILOVA	{"phone": "+70906064834"}
0005433367961	301472	1621 478971	NIKITA KULIKOV	{"email": "nkulikov-1983@postgrespro.ru", "phone": "+70866905954"}
0005433367962	E6FF2E	5339 286020	ALEKSANDRA BELOVA	{"phone": "+70078901775"}
0005433367963	E6FF2E	8628 882583	MARIYA SOROKINA	{"email": "sorokina.mariya_26011968@postgrespro.ru", "phone": "+70140822018"}
0005433367964	8432FE	9917 735046	SERGEY BORISOV	{"email": "borisov.sergey.071960@postgrespro.ru", "phone": "+70562190693"}
0005433367965	3E3E9E	5890 744417	LYUDMILA TARASOVA	{"email": "tarasova-l_1973@postgrespro.ru", "phone": "+70886918009"}
0005433367966	B9AD74	5866 672668	ELIZAVETA KISELEVA	{"phone": "+70687359603"}
0005433367967	B9AD74	1593 655161	NINA SCHERBAKOVA	{"email": "nina-scherbakova-05071965@postgrespro.ru", "phone": "+70376108982"}
0005433367968	C6399E	4995 482399	VALENTINA IVANOVA	{"phone": "+70462969117"}
0005433367969	C6399E	0309 953442	NINA ZAKHAROVA	{"phone": "+70675278084"}
0005433367970	862474	3632 796600	VLADIMIR ZHUKOV	{"email": "zhukov-vladimir.30111968@postgrespro.ru", "phone": "+70515984241"}
0005433367971	862474	2877 943100	EVGENIY ZAKHAROV	{"email": "e-zakharov_071969@postgrespro.ru", "phone": "+70107404612"}
0005433367972	862474	7324 168983	NIKOLAY VLASOV	{"phone": "+70801873882"}
0005433367973	2F8545	4953 867458	STANISLAV TARASOV	{"phone": "+70129288532"}
0005433367974	269B43	3469 212879	ANASTASIYA SERGEEVA	{"phone": "+70826687858"}
0005433367975	B5444C	8346 001959	VIKTORIYA EFIMOVA	{"phone": "+70341903430"}
0005433367976	B5444C	1534 501194	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev1975@postgrespro.ru", "phone": "+70000779567"}
0005433367977	F5B182	7895 560034	LARISA MAKSIMOVA	{"email": "lmaksimova111970@postgrespro.ru", "phone": "+70382488982"}
0005433367978	42B6E6	0920 411396	NADEZHDA KOMAROVA	{"phone": "+70254424605"}
0005433367979	42B6E6	3795 856122	OKSANA NAUMOVA	{"email": "naumova_oksana.1981@postgrespro.ru", "phone": "+70412562669"}
0005433367980	C5DE03	9847 295290	MARIANNA DENISOVA	{"phone": "+70280420533"}
0005433367981	C5DE03	6913 676747	VALERIY YAKOVLEV	{"phone": "+70492541603"}
0005433367982	5F5E9D	5920 593525	GENNADIY KUZNECOV	{"phone": "+70388489926"}
0005433367983	4C1A76	9013 049676	NIKITA NIKITIN	{"email": "n-nikitin.05061977@postgrespro.ru", "phone": "+70741949541"}
0005433367984	AB630A	4662 967388	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir.111976@postgrespro.ru", "phone": "+70024825812"}
0005433367985	FD0077	3150 498289	SERGEY BONDARENKO	{"email": "s_bondarenko_121972@postgrespro.ru", "phone": "+70596220120"}
0005433367986	FD0077	3969 616979	DMITRIY POPOV	{"email": "dpopov.051976@postgrespro.ru", "phone": "+70156382497"}
0005433367987	05B289	5705 109479	VIKTOR DMITRIEV	{"phone": "+70201849070"}
0005433367988	16A1AC	8094 211170	ELENA VASILEVA	{"phone": "+70041510134"}
0005433367989	0D3D6B	9049 515063	SERGEY GERASIMOV	{"email": "sergey_gerasimov_1973@postgrespro.ru", "phone": "+70012778961"}
0005433367990	EC4FCD	1657 199863	DMITRIY KAZAKOV	{"phone": "+70987590703"}
0005433367991	6C64B9	3900 939113	OKSANA ZOTOVA	{"email": "zotova-oksana-031960@postgrespro.ru", "phone": "+70985250875"}
0005433367992	740702	3034 615712	ANNA EGOROVA	{"email": "egorovaa-081977@postgrespro.ru", "phone": "+70672566798"}
0005433367993	740702	7410 543202	SVETLANA LEBEDEVA	{"phone": "+70156872252"}
0005433367994	740702	2352 224138	ALEKSEY FROLOV	{"email": "aleksey_frolov_28121971@postgrespro.ru", "phone": "+70059888540"}
0005433367995	728A7F	8290 968109	ALEKSANDRA ZAKHAROVA	{"email": "a.zakharova_26031979@postgrespro.ru", "phone": "+70925333574"}
0005433367996	728A7F	7230 303085	LYUDMILA STEPANOVA	{"phone": "+70400753691"}
0005433367997	EF38FD	7859 823133	VLADIMIR KUZNECOV	{"email": "v_kuznecov051972@postgrespro.ru", "phone": "+70852899828"}
0005433367998	EF38FD	6077 499193	VALERIYA RYABOVA	{"phone": "+70832990810"}
0005433367999	7EFA32	4169 757446	ANNA MATVEEVA	{"email": "matveeva-anna_1980@postgrespro.ru", "phone": "+70820265667"}
0005433368000	2180E8	0923 396033	IRAIDA ALEKSEEVA	{"email": "iraida-alekseeva03091961@postgrespro.ru", "phone": "+70980273370"}
0005433368001	2180E8	7382 779100	DENIS IVANOV	{"email": "d-ivanov.1968@postgrespro.ru", "phone": "+70996782900"}
0005433368002	E7B3C4	5510 658647	NATALYA TIMOFEEVA	{"email": "natalya-timofeeva-1970@postgrespro.ru", "phone": "+70519029166"}
0005433368003	0EB524	9778 458475	ANATOLIY SAVELEV	{"email": "savelevanatoliy-1971@postgrespro.ru", "phone": "+70401269015"}
0005433368004	B9A0F7	9374 633666	ANDREY GUSEV	{"phone": "+70581362785"}
0005433368005	8B8F7F	0876 067522	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov.04091967@postgrespro.ru", "phone": "+70866273342"}
0005433368006	8B8F7F	3063 107715	ELENA KUZMINA	{"phone": "+70971975748"}
0005433368007	A13FC4	2526 974523	LYUBOV KOLESNIKOVA	{"phone": "+70909859490"}
0005433368008	BF9A55	0493 710164	ANTON PETROV	{"phone": "+70671153763"}
0005433368009	0A422B	6762 607480	ZINAIDA MOROZOVA	{"phone": "+70583007213"}
0005433368010	850098	4113 359380	DANILA YAKOVLEV	{"email": "yakovlevd10111974@postgrespro.ru", "phone": "+70109939256"}
0005433368011	850098	7570 075913	ELENA AFANASEVA	{"email": "elena-afanaseva091966@postgrespro.ru", "phone": "+70609013159"}
0005433368012	850098	2990 167738	NATALYA GERASIMOVA	{"email": "natalya_gerasimova.1965@postgrespro.ru", "phone": "+70758918575"}
0005433368069	5F2865	9467 396235	LYUDMILA FILATOVA	{"phone": "+70902173219"}
0005433368013	C99A14	9742 242874	ZINAIDA OVCHINNIKOVA	{"email": "z-ovchinnikova.28041983@postgrespro.ru", "phone": "+70487678460"}
0005433368014	1D6E65	0196 180596	NADEZHDA PAVLOVA	{"phone": "+70927280739"}
0005433368015	019C42	8041 254920	YULIYA GAVRILOVA	{"phone": "+70484641799"}
0005433368016	A749B8	3636 141101	NATALYA SOKOLOVA	{"phone": "+70886889009"}
0005433368017	1A2194	2885 965463	LIDIYA ZOTOVA	{"phone": "+70963307601"}
0005433368018	1F50F7	0723 231525	OLGA ALEKSEEVA	{"phone": "+70423561360"}
0005433368019	1F50F7	7507 672529	ALEKSANDR SCHERBAKOV	{"phone": "+70308792412"}
0005433368020	222A1B	7736 595466	NATALYA MAKSIMOVA	{"phone": "+70307751965"}
0005433368021	931AA3	3676 638023	SERGEY NAUMOV	{"phone": "+70562590348"}
0005433368022	6CB4B5	0185 581660	ALEKSEY SHEVCHENKO	{"phone": "+70839972603"}
0005433368023	95E822	7256 018026	ARTEM KUZNECOV	{"email": "kuznecov_artem-1964@postgrespro.ru", "phone": "+70245447558"}
0005433368024	95E822	7764 091222	NIKOLAY FROLOV	{"email": "frolov_n1970@postgrespro.ru", "phone": "+70326404414"}
0005433368025	95E822	7558 325127	VLADIMIR KISELEV	{"phone": "+70590418456"}
0005433368026	90123B	1345 832620	YULIYA OSIPOVA	{"email": "yuliya_osipova_101972@postgrespro.ru", "phone": "+70202046355"}
0005433368027	74A38E	2233 643443	ALIYA GORBUNOVA	{"phone": "+70436929394"}
0005433368028	F28B81	4740 624342	IGOR MAKSIMOV	{"email": "maksimov_igor.09101971@postgrespro.ru", "phone": "+70401257319"}
0005433368029	BE6D47	3903 254978	OLGA KUZNECOVA	{"email": "olga-kuznecova-1969@postgrespro.ru", "phone": "+70793882339"}
0005433368030	000A1E	7557 499406	BOGDAN FROLOV	{"phone": "+70024440347"}
0005433368031	000A1E	3842 830647	ALEKSANDR ZAYCEV	{"email": "zayceva111969@postgrespro.ru", "phone": "+70551882589"}
0005433368032	010B76	8958 629665	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.aleksandr07061954@postgrespro.ru", "phone": "+70893994361"}
0005433368033	010B76	6824 512633	SERGEY SOKOLOV	{"email": "sergey_sokolov_29061965@postgrespro.ru", "phone": "+70124042399"}
0005433368034	1AE052	3816 630363	LIDIYA IVANOVA	{"phone": "+70732112317"}
0005433368035	6A2F50	9739 251127	SVETLANA MAKSIMOVA	{"phone": "+70656415281"}
0005433368036	702435	7494 986620	PETR PETROV	{"email": "petr-petrov1971@postgrespro.ru", "phone": "+70128694514"}
0005433368037	182385	2395 529252	RUSHANIYA SOROKINA	{"phone": "+70884439759"}
0005433368038	42FA3D	0310 906112	SERGEY POPOV	{"email": "popovs-05111971@postgrespro.ru", "phone": "+70037624406"}
0005433368039	42FA3D	1336 497675	ANDREY SOLOVEV	{"phone": "+70304081175"}
0005433368040	E44708	9300 162245	ALEKSANDR POPOV	{"phone": "+70274530519"}
0005433368041	8FD651	0240 451054	OLGA ZOTOVA	{"email": "o-zotova-081972@postgrespro.ru", "phone": "+70598843998"}
0005433368042	C1744A	0715 028475	ANDREY KUZMIN	{"email": "andreykuzmin_091965@postgrespro.ru", "phone": "+70173165122"}
0005433368043	C1744A	1896 134621	VLADIMIR ANDREEV	{"phone": "+70507948832"}
0005433368044	181A13	2531 924501	OLGA FADEEVA	{"phone": "+70605095684"}
0005433368045	D8B2DE	9905 235427	ANDREY KUZNECOV	{"email": "a-kuznecov-061974@postgrespro.ru", "phone": "+70480531856"}
0005433368046	61EEA8	3659 060472	PRASKOVYA NIKIFOROVA	{"email": "nikiforova_p_1969@postgrespro.ru", "phone": "+70046708831"}
0005433368047	C4E05B	6231 722184	PETR SERGEEV	{"email": "p_sergeev.19061977@postgrespro.ru", "phone": "+70736356879"}
0005433368048	CD8F2F	8234 188292	ANDREY MEDVEDEV	{"email": "medvedev-andrey061979@postgrespro.ru", "phone": "+70826207929"}
0005433368049	CD8F2F	6945 515858	VALENTINA MASLOVA	{"email": "valentina_maslova1962@postgrespro.ru", "phone": "+70894706786"}
0005433368050	349044	5690 782463	EVGENIY KUZNECOV	{"phone": "+70953760774"}
0005433368051	349044	3284 863586	MARIYA GORBUNOVA	{"email": "gorbunova-mariya19101961@postgrespro.ru", "phone": "+70545426889"}
0005433368052	44173B	3121 626601	TATYANA KUZNECOVA	{"email": "t-kuznecova-08011966@postgrespro.ru", "phone": "+70827621165"}
0005433368053	44173B	2223 218653	NINA NIKITINA	{"email": "nina_nikitina051979@postgrespro.ru", "phone": "+70899985894"}
0005433368054	B1DB65	9556 586199	TAISA LAZAREVA	{"email": "t_lazareva-1970@postgrespro.ru", "phone": "+70278409409"}
0005433368055	830169	6761 657635	ALEKSANDR SMIRNOV	{"phone": "+70437798426"}
0005433368056	824CF2	6198 627886	PETR ANTONOV	{"email": "petr-antonov.1982@postgrespro.ru", "phone": "+70290475734"}
0005433368057	1EEBE5	2015 520993	VITALIY SEMENOV	{"email": "vitaliy.semenov-1973@postgrespro.ru", "phone": "+70749013252"}
0005433368058	E1AEC7	8724 946194	LIDIYA MASLOVA	{"phone": "+70043887008"}
0005433368059	8F9070	7796 956671	NIKOLAY SEMENOV	{"email": "semenov.n-04081977@postgrespro.ru", "phone": "+70106861460"}
0005433368060	8F9070	0667 278677	VIKTOR FROLOV	{"email": "viktor_frolov.1958@postgrespro.ru", "phone": "+70867771996"}
0005433368061	805F87	5456 437781	ALEKSANDR EGOROV	{"email": "aleksandregorov-1964@postgrespro.ru", "phone": "+70217290811"}
0005433368062	DDF090	7673 610483	NIKOLAY IVANOV	{"email": "nivanov-1975@postgrespro.ru", "phone": "+70979091526"}
0005433368063	95971D	9689 704965	KIRILL ZAYCEV	{"phone": "+70586810424"}
0005433368064	1B9FF2	2237 433081	ROMAN ANDREEV	{"phone": "+70465005164"}
0005433368065	1B9FF2	9466 747379	TATYANA KOMAROVA	{"email": "komarova-t1968@postgrespro.ru", "phone": "+70662008713"}
0005433368066	77F4A6	1329 091213	VALENTINA KUZNECOVA	{"phone": "+70363480954"}
0005433368067	DEF694	4961 659870	NATALYA NAZAROVA	{"email": "nazarova-n-1970@postgrespro.ru", "phone": "+70648236921"}
0005433368068	2582F4	6330 607653	ANNA EGOROVA	{"email": "a.egorova-081963@postgrespro.ru", "phone": "+70574390164"}
0005433368070	5F2865	7753 215499	IRINA VOLKOVA	{"email": "volkova-irina.23031975@postgrespro.ru", "phone": "+70979840727"}
0005433368071	0E2938	8841 807281	IRINA BELOVA	{"email": "i.belova_02121971@postgrespro.ru", "phone": "+70429863965"}
0005433368072	0E2938	0368 754369	ALINA RYABOVA	{"phone": "+70971135486"}
0005433368073	F55972	4149 874523	ANNA SOROKINA	{"phone": "+70506545596"}
0005433368074	70C14D	8182 630913	OLGA POTAPOVA	{"phone": "+70858414288"}
0005433368075	71BE6E	8521 862665	OKSANA AKIMOVA	{"email": "o-akimova.051975@postgrespro.ru", "phone": "+70532716768"}
0005433368076	0EAA85	0050 775420	LIDIYA BOGDANOVA	{"email": "bogdanova_l-1971@postgrespro.ru", "phone": "+70666130489"}
0005433368077	86C587	3304 584174	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v_1969@postgrespro.ru", "phone": "+70733366662"}
0005433368078	424FF7	4455 997013	RASHID ZAKHAROV	{"email": "rashid-zakharov_1971@postgrespro.ru", "phone": "+70996892491"}
0005433368079	424FF7	5360 698325	VIKTORIYA BARANOVA	{"email": "baranova-v1972@postgrespro.ru", "phone": "+70369401875"}
0005433368080	B82EB9	2899 165432	VLADIMIR NIKITIN	{"phone": "+70717326509"}
0005433368081	5DA537	4889 367597	SERGEY ORLOV	{"email": "orlov-sergey.051977@postgrespro.ru", "phone": "+70053867914"}
0005433368082	1408DB	4481 551385	YULIYA VASILEVA	{"phone": "+70662979445"}
0005433368083	7A076C	9062 608816	EKATERINA AKIMOVA	{"phone": "+70510740372"}
0005433368084	98E9B0	0104 669400	ALEKSANDR KOZLOV	{"email": "a_kozlov.30081971@postgrespro.ru", "phone": "+70234230950"}
0005433368085	98E9B0	6778 885901	RAISA FOMINA	{"phone": "+70449688617"}
0005433368086	DA9472	1086 176309	NIKOLAY NAUMOV	{"email": "naumovn.1967@postgrespro.ru", "phone": "+70679704372"}
0005433368087	704FA0	9817 347056	NIKOLAY KOZLOV	{"phone": "+70008482096"}
0005433368088	704FA0	4734 596143	ANASTASIYA KOZLOVA	{"email": "kozlova_anastasiya.24041985@postgrespro.ru", "phone": "+70589642322"}
0005433368089	88DA3B	9730 097778	IGOR TIKHONOV	{"phone": "+70383537575"}
0005433368090	88DA3B	9382 074298	YURIY KAZAKOV	{"email": "kazakov_yuriy-1982@postgrespro.ru", "phone": "+70112737262"}
0005433368091	46683B	7237 423971	FEDOR TIKHONOV	{"phone": "+70074251044"}
0005433368092	46683B	4900 584025	ELENA GAVRILOVA	{"email": "egavrilova1972@postgrespro.ru", "phone": "+70893800018"}
0005433368093	ED62D6	3936 775050	ALBINA SIDOROVA	{"email": "albina-sidorova-1977@postgrespro.ru", "phone": "+70015630699"}
0005433368094	9BD40E	5897 527627	DMITRIY KISELEV	{"phone": "+70035132924"}
0005433368095	9BD40E	4675 042985	ANDREY MEDVEDEV	{"phone": "+70554573583"}
0005433368096	5B3DFE	6780 795762	ANASTASIYA EGOROVA	{"phone": "+70731532606"}
0005433368097	5B3DFE	3915 696108	NIKOLAY PETROV	{"phone": "+70107022180"}
0005433368098	5B3DFE	1796 219839	PAVEL VOLKOV	{"phone": "+70758400358"}
0005433368099	E554CD	8115 451684	VLADIMIR BORISOV	{"phone": "+70775271330"}
0005433368100	E127FC	7658 851916	IGOR SCHERBAKOV	{"email": "i-scherbakov-011966@postgrespro.ru", "phone": "+70464288611"}
0005433368101	E127FC	6737 468814	OLEG PETROV	{"phone": "+70812848199"}
0005433368102	E127FC	5663 457479	ALEKSANDR RODIONOV	{"email": "arodionov-19031982@postgrespro.ru", "phone": "+70029727127"}
0005433368103	5B9A62	1850 888963	NIKOLAY VASILEV	{"email": "nvasilev031967@postgrespro.ru", "phone": "+70012469989"}
0005433368104	7F1B21	9202 959721	ANNA KUZNECOVA	{"phone": "+70395414754"}
0005433368105	AA63B9	4020 358103	NADEZHDA FROLOVA	{"phone": "+70512739366"}
0005433368106	DE40CF	5413 501170	SVETLANA KOMAROVA	{"email": "s.komarova.051968@postgrespro.ru", "phone": "+70732328555"}
0005433368107	40F255	4992 656677	ALLA ZOTOVA	{"phone": "+70516742495"}
0005433368108	B8AEA4	0750 841269	GALINA BELOVA	{"email": "belova.galina1974@postgrespro.ru", "phone": "+70662735851"}
0005433368109	C16C48	9916 290290	DANIL POPOV	{"email": "d.popov_011980@postgrespro.ru", "phone": "+70181920340"}
0005433368110	48F305	6606 890364	GEORGIY PAVLOV	{"phone": "+70911489611"}
0005433368111	18F3C4	1608 812109	IGOR KAZAKOV	{"phone": "+70071880873"}
0005433368112	18F3C4	0526 642750	GEORGIY SIDOROV	{"email": "sidorov.georgiy_041974@postgrespro.ru", "phone": "+70480880468"}
0005433368113	18F3C4	4546 869927	GALINA KONOVALOVA	{"phone": "+70689845235"}
0005433368114	8C13C6	6812 973585	ALEKSANDRA BELOVA	{"email": "aleksandra.belova-25121974@postgrespro.ru", "phone": "+70255492493"}
0005433368115	D74EAE	1590 053351	EDUARD STEPANOV	{"email": "e_stepanov-1961@postgrespro.ru", "phone": "+70695982386"}
0005433368116	C59F0B	0714 933795	ANDREY ZAYCEV	{"phone": "+70258180575"}
0005433368117	C59F0B	7408 929327	ANASTASIYA KISELEVA	{"email": "a_kiseleva_071976@postgrespro.ru", "phone": "+70368478946"}
0005433368118	C59F0B	3363 727602	TATYANA EFIMOVA	{"phone": "+70013141220"}
0005433368119	89F3F7	1503 030969	LEV OSIPOV	{"email": "lev-osipov.1980@postgrespro.ru", "phone": "+70108846417"}
0005433368120	456959	5816 475603	RENAT GAVRILOV	{"phone": "+70743419344"}
0005433368121	D2D21F	4092 137831	VALERIY MIRONOV	{"email": "v_mironov1970@postgrespro.ru", "phone": "+70399971926"}
0005433368122	CB1DF2	1467 004228	ARTEM BONDARENKO	{"email": "bondarenko.a_1983@postgrespro.ru", "phone": "+70759808051"}
0005433368123	CB1DF2	1533 427664	SERAFIMA TITOVA	{"phone": "+70394392452"}
0005433368124	CB1DF2	1188 324404	IRINA MALYSHEVA	{"phone": "+70735850419"}
0005433368125	4CB2A6	6734 745898	ANATOLIY BARANOV	{"phone": "+70548733081"}
0005433368126	5FB9BF	8752 366927	ALLA KRASNOVA	{"phone": "+70214898698"}
0005433368127	5FB9BF	4184 839930	MARINA AKIMOVA	{"email": "m.akimova1984@postgrespro.ru", "phone": "+70004528734"}
0005433368128	987680	0586 782140	EVGENIY IVANOV	{"email": "ivanovevgeniy.1976@postgrespro.ru", "phone": "+70347264521"}
0005433368129	F708EF	5167 663611	EKATERINA ARKHIPOVA	{"phone": "+70244977697"}
0005433368130	2E2DD1	0177 124418	PAVEL NIKOLAEV	{"phone": "+70182312351"}
0005433368131	DFBC1F	0534 700798	NADEZHDA SOROKINA	{"email": "n.sorokina1976@postgrespro.ru", "phone": "+70917330680"}
0005433368132	D47D75	8540 680915	VADIM SERGEEV	{"email": "v_sergeev021970@postgrespro.ru", "phone": "+70921152787"}
0005433368133	DAD112	4901 358795	KONSTANTIN SEMENOV	{"phone": "+70300573625"}
0005433368134	A36F0F	3533 467565	ANDREY IVANOV	{"phone": "+70703667327"}
0005433368135	9BFBF3	7732 330786	VLADIMIR KARPOV	{"phone": "+70908641424"}
0005433368136	9BFBF3	4300 287434	ELIZAVETA KISELEVA	{"email": "kiseleva.e14091974@postgrespro.ru", "phone": "+70794753403"}
0005433368137	1321E0	3663 622281	IGOR IVANOV	{"email": "ivanovigor_12031969@postgrespro.ru", "phone": "+70012436103"}
0005433368138	1321E0	3116 887899	GALINA ZAKHAROVA	{"phone": "+70454330093"}
0005433368139	1321E0	3795 978333	LILIYA VASILEVA	{"email": "l_vasileva_061964@postgrespro.ru", "phone": "+70450875850"}
0005433368140	CF6765	0399 089769	LYUDMILA KONOVALOVA	{"email": "lyudmila-konovalova1973@postgrespro.ru", "phone": "+70001547343"}
0005433368141	06173A	5431 765509	ARTEM BELOV	{"phone": "+70386965351"}
0005433368142	BB1D34	9960 429302	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov04011979@postgrespro.ru", "phone": "+70282722176"}
0005433368143	7D6DF2	8071 018448	ANAIT OSIPOVA	{"phone": "+70509440039"}
0005433368144	711E15	2877 225724	SERGEY ISAEV	{"email": "sergeyisaev-071969@postgrespro.ru", "phone": "+70557555279"}
0005433368145	F07053	1854 968360	NADEZHDA PETROVA	{"phone": "+70892213087"}
0005433368146	F07053	8980 233520	NINA MIRONOVA	{"email": "nina.mironova_1972@postgrespro.ru", "phone": "+70357290361"}
0005433368147	C93805	0903 839438	VASILIY NIKITIN	{"phone": "+70467319065"}
0005433368148	C11E4A	3008 673661	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov111978@postgrespro.ru", "phone": "+70187847055"}
0005433368149	8C93CF	1692 506054	YURIY MOROZOV	{"email": "yuriy-morozov_1974@postgrespro.ru", "phone": "+70770756212"}
0005433368150	053817	4966 875468	YURIY MELNIKOV	{"email": "yuriy-melnikov021972@postgrespro.ru", "phone": "+70306206582"}
0005433368151	053817	2079 380675	SOFIYA BARANOVA	{"phone": "+70692274320"}
0005433368152	3605EA	6462 347364	ANATOLIY KOROLEV	{"email": "anatoliykorolev_1966@postgrespro.ru", "phone": "+70880333627"}
0005433368153	553D71	7639 431833	ARTEM ANDREEV	{"phone": "+70232241518"}
0005433368154	33678F	5276 133329	ALEKSANDR ZHURAVLEV	{"email": "a.zhuravlev_10031969@postgrespro.ru", "phone": "+70976111105"}
0005433368155	E4B622	0767 444596	MARIYA ZAKHAROVA	{"phone": "+70714107654"}
0005433368156	29130B	3429 722766	MARIYA BOGDANOVA	{"email": "bogdanovam.101972@postgrespro.ru", "phone": "+70210996389"}
0005433368157	73F6AE	5649 957522	ALEKSANDR BELOV	{"email": "belov.aleksandr-121962@postgrespro.ru", "phone": "+70656210515"}
0005433368158	73F6AE	4672 836019	LYUBOV KISELEVA	{"phone": "+70495659521"}
0005433368159	ACDD91	8543 418813	ARTUR MAKSIMOV	{"phone": "+70811693236"}
0005433368160	BB7F70	6985 558313	SERGEY TIMOFEEV	{"email": "timofeev.sergey091975@postgrespro.ru", "phone": "+70932768439"}
0005433368161	BB7F70	7650 021035	VALERIY BELOV	{"phone": "+70038360263"}
0005433368162	76B75C	8493 376712	MARINA PETROVA	{"phone": "+70093543614"}
0005433368163	707B28	5772 622510	ARTEM SMIRNOV	{"phone": "+70994201057"}
0005433368164	707B28	3112 951327	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov_1968@postgrespro.ru", "phone": "+70768305593"}
0005433368165	CE329E	9035 776966	IRINA PETROVA	{"email": "i.petrova_14061977@postgrespro.ru", "phone": "+70353388824"}
0005433368166	CE329E	2028 752079	LYUBOV KISELEVA	{"phone": "+70441127770"}
0005433368167	807E88	4194 758743	IVAN DAVYDOV	{"phone": "+70639501822"}
0005433368168	807E88	8386 738447	VITALIY PETROV	{"phone": "+70877558594"}
0005433368169	08A925	5650 911920	ILYA PAVLOV	{"email": "pavlov-ilya.1972@postgrespro.ru", "phone": "+70844008518"}
0005433368170	08A925	3047 244646	IRINA OVCHINNIKOVA	{"phone": "+70356011716"}
0005433368171	7FEC2E	4468 337552	NADEZHDA OVCHINNIKOVA	{"phone": "+70602524884"}
0005433368172	B766CD	9360 589305	SERGEY ORLOV	{"email": "s-orlov24091965@postgrespro.ru", "phone": "+70517772231"}
0005433368173	9B4B41	3302 548397	VITALIY GAVRILOV	{"phone": "+70332956728"}
0005433368174	210AF2	6738 276771	SERGEY SOKOLOV	{"email": "sokolov.s121977@postgrespro.ru", "phone": "+70421117126"}
0005433368175	B4F657	8409 020559	DENIS NIKITIN	{"phone": "+70771193878"}
0005433368176	B4F657	6076 643557	OLGA SMIRNOVA	{"phone": "+70158340297"}
0005433368177	21FB5A	7956 703086	NIKOLAY BARANOV	{"email": "nikolay-baranov.03071974@postgrespro.ru", "phone": "+70323697820"}
0005433368178	E4D162	3084 588668	ANNA ILINA	{"phone": "+70835338559"}
0005433368179	2E51F1	5717 738409	ANASTASIYA POPOVA	{"phone": "+70649381236"}
0005433368180	C1A5CF	4690 600143	IRINA IVANOVA	{"phone": "+70136186692"}
0005433368181	C1A5CF	5036 445035	LARISA POPOVA	{"email": "l-popova.1978@postgrespro.ru", "phone": "+70755394676"}
0005433368182	78BAA9	2608 150724	TAMARA KOVALEVA	{"phone": "+70692512708"}
0005433368183	C30C4A	9717 448895	ALEKSEY PETROV	{"phone": "+70225090326"}
0005433368184	ECF4CD	4275 045272	YULIYA MIKHAYLOVA	{"phone": "+70960905029"}
0005433368185	2E1B68	6035 283903	AZAT KAZAKOV	{"email": "azat-kazakov.1979@postgrespro.ru", "phone": "+70027208068"}
0005433368186	80418F	9336 798081	VSEVOLOD ANDREEV	{"email": "andreevvsevolod.071960@postgrespro.ru", "phone": "+70519089236"}
0005433368187	23EB11	6078 827813	ALEKSANDR PETROV	{"phone": "+70220132574"}
0005433368188	23EB11	6796 887116	NIKOLAY DMITRIEV	{"email": "dmitriev.nikolay071982@postgrespro.ru", "phone": "+70106907841"}
0005433368189	25FF08	8029 640110	IGOR KUZNECOV	{"email": "kuznecov_igor_121965@postgrespro.ru", "phone": "+70764073284"}
0005433368190	25FF08	1083 118471	LYUDMILA KAZAKOVA	{"email": "lyudmilakazakova.11121972@postgrespro.ru", "phone": "+70436558602"}
0005433368191	F88485	0828 533794	RUSLAN SMIRNOV	{"phone": "+70738837025"}
0005433368192	94E9F8	2988 119401	ELENA NAZAROVA	{"email": "nazarova_e-13111966@postgrespro.ru", "phone": "+70085990340"}
0005433368193	29C4FA	4537 866210	VERA BELYAEVA	{"email": "belyaeva.vera121972@postgrespro.ru", "phone": "+70074460153"}
0005433368194	89546C	1827 175147	LYUBOV ZAYCEVA	{"email": "lyubov_zayceva1976@postgrespro.ru", "phone": "+70874377612"}
0005433368195	312514	2157 905448	TATYANA ANDREEVA	{"phone": "+70450676852"}
0005433368196	F0FD73	5492 523209	IRINA MARTYNOVA	{"email": "martynova_i.1972@postgrespro.ru", "phone": "+70930164898"}
0005433368197	0F2BD9	4900 515016	GALINA NIKIFOROVA	{"email": "nikiforovagalina_081982@postgrespro.ru", "phone": "+70444117457"}
0005433368198	0F2BD9	1398 550980	SERGEY FEDOROV	{"email": "s_fedorov_10011969@postgrespro.ru", "phone": "+70653687179"}
0005433368199	105B4A	1003 782514	FLYURA ROMANOVA	{"phone": "+70294584584"}
0005433368200	3BDB82	5798 901923	ANATOLIY SEMENOV	{"phone": "+70280439916"}
0005433368201	621DBA	7682 450466	VERA MAKAROVA	{"email": "makarovav.31071975@postgrespro.ru", "phone": "+70872041469"}
0005433368202	621DBA	4644 565848	NIKITA FILIPPOV	{"email": "filippov.n.23091976@postgrespro.ru", "phone": "+70956290030"}
0005433368203	91D67E	2654 057896	DENIS NAZAROV	{"phone": "+70350253012"}
0005433368204	0D7E82	7925 868744	YULIYA EGOROVA	{"email": "egorovayuliya.101964@postgrespro.ru", "phone": "+70237043748"}
0005433368205	AB7954	4397 686131	ALEKSANDR SEMENOV	{"phone": "+70780091673"}
0005433368206	457DC4	1523 129323	NATALIYA AKIMOVA	{"phone": "+70099248287"}
0005433368207	7DF652	7625 310154	KRISTINA MELNIKOVA	{"phone": "+70341131061"}
0005433368208	7DF652	3977 374715	ALEKSEY SOROKIN	{"phone": "+70339942230"}
0005433368209	4AA0D0	6114 885023	EKATERINA NOVIKOVA	{"phone": "+70517760334"}
0005433368210	4AA0D0	3737 275548	EVGENIY KONOVALOV	{"email": "e_konovalov1967@postgrespro.ru", "phone": "+70518768047"}
0005433368211	D08370	0709 384296	ANTON NIKITIN	{"email": "nikitinanton_18061965@postgrespro.ru", "phone": "+70997132515"}
0005433368212	A8849D	1038 542534	ALEKSEY GRIGOREV	{"email": "a_grigorev.101970@postgrespro.ru", "phone": "+70162073757"}
0005433368214	5A3261	2647 868444	MARINA MELNIKOVA	{"phone": "+70960851984"}
0005433368215	5A3261	3619 942514	ANDREY ROMANOV	{"phone": "+70468863669"}
0005433368216	93B62A	9114 385463	ALEKSANDR MARTYNOV	{"phone": "+70204224831"}
0005433368217	7332FC	1900 961440	NATALYA AFANASEVA	{"email": "n-afanaseva.1974@postgrespro.ru", "phone": "+70180798531"}
0005433368218	07D1DC	1301 509930	EKATERINA BARANOVA	{"phone": "+70482240278"}
0005433368219	8E024E	9689 668792	EVGENIY NIKITIN	{"email": "nikitinevgeniy-05121976@postgrespro.ru", "phone": "+70577883020"}
0005433368220	DB5FF3	6840 539634	IVAN SIDOROV	{"email": "sidorov-i.071969@postgrespro.ru", "phone": "+70174757321"}
0005433368221	D5A03B	8272 521096	ELENA BELOVA	{"phone": "+70675006014"}
0005433368222	D5A03B	2724 336521	FARIDA AKIMOVA	{"phone": "+70865311794"}
0005433368223	D5A03B	0970 686016	OLGA DAVYDOVA	{"email": "o_davydova-12111957@postgrespro.ru", "phone": "+70113792192"}
0005433368224	F20E0D	0529 815289	ALEKSANDRA KUZMINA	{"email": "aleksandra.kuzmina-1973@postgrespro.ru", "phone": "+70375785751"}
0005433368225	EA1F6A	4511 889728	NADEZHDA OVCHINNIKOVA	{"phone": "+70795596582"}
0005433368226	EA1F6A	1433 925630	SVETLANA KUZNECOVA	{"phone": "+70731403611"}
0005433368227	788255	7936 709958	ALEKSANDR BONDARENKO	{"phone": "+70580627862"}
0005433368228	0B8E70	0530 236154	RUSLAN SOKOLOV	{"phone": "+70789089837"}
0005433368229	C4EFDA	8638 302938	MARINA FROLOVA	{"phone": "+70150721527"}
0005433368230	7E38D7	5583 626900	ANASTASIYA ZAKHAROVA	{"phone": "+70142111767"}
0005433368231	7E38D7	3611 841418	ZOYA FILATOVA	{"phone": "+70041557928"}
0005433368232	E687C6	5190 863742	VALENTIN KISELEV	{"phone": "+70869748902"}
0005433368233	4225B9	7925 920727	VLADIMIR ROMANOV	{"email": "romanov_v.05121972@postgrespro.ru", "phone": "+70369123037"}
0005433368234	4225B9	8842 037004	VALERIY ZAKHAROV	{"phone": "+70247530968"}
0005433368235	DC3BAC	9649 983996	ELENA SOKOLOVA	{"email": "elena-sokolova.1969@postgrespro.ru", "phone": "+70075118109"}
0005433368236	DC3BAC	0806 525258	NAILYA ZAKHAROVA	{"phone": "+70778719251"}
0005433368237	7B8465	3172 780084	ILNUR GRIGOREV	{"email": "grigorevi_1973@postgrespro.ru", "phone": "+70477873591"}
0005433368238	E12E53	2351 168091	IRINA MARTYNOVA	{"email": "irina-martynova-061972@postgrespro.ru", "phone": "+70767060387"}
0005433368239	F1FAC0	0790 400658	VITALIY GORBUNOV	{"phone": "+70087103693"}
0005433368240	F1FAC0	9758 536977	DINARA MOISEEVA	{"phone": "+70175604668"}
0005433368241	494813	4067 287054	ANATOLIY MELNIKOV	{"email": "melnikova.06111973@postgrespro.ru", "phone": "+70664699943"}
0005433368242	BC2D00	5317 443047	VASILIY KISELEV	{"email": "kiselev.v031969@postgrespro.ru", "phone": "+70100618308"}
0005433368243	2C27EA	7425 329593	NATALYA ISAEVA	{"phone": "+70924370650"}
0005433368244	2C27EA	7396 899797	ALEKSANDRA POPOVA	{"phone": "+70284461184"}
0005433368245	FB9980	0647 510054	YURIY NAZAROV	{"email": "nazarov_yuriy_1968@postgrespro.ru", "phone": "+70862198164"}
0005433368246	FB9980	4490 062442	VYACHESLAV FOMIN	{"email": "v-fomin.24031973@postgrespro.ru", "phone": "+70136902856"}
0005433368247	A73C75	6112 117981	NINA VOROBEVA	{"phone": "+70753882933"}
0005433368248	810204	1352 288607	ELENA EGOROVA	{"email": "egorova_elena_30071979@postgrespro.ru", "phone": "+70098240096"}
0005433368249	1EDFF7	6090 654482	ALEKSANDR MAKAROV	{"email": "makarova_1975@postgrespro.ru", "phone": "+70262771657"}
0005433368250	2E6910	6945 269696	DENIS MAKAROV	{"email": "denis_makarov_23091967@postgrespro.ru", "phone": "+70588861766"}
0005433368251	4F1BFA	9225 978977	VIKTORIYA TROFIMOVA	{"phone": "+70850675979"}
0005433368252	4F1BFA	9753 759199	SVETLANA FROLOVA	{"email": "frolova_svetlana13031968@postgrespro.ru", "phone": "+70884756068"}
0005433368253	2308D5	7772 480755	ALENA MAKAROVA	{"email": "makarova.alena1971@postgrespro.ru", "phone": "+70541504365"}
0005433368254	10516E	7460 117207	IGOR PETROV	{"email": "petrov_igor15111977@postgrespro.ru", "phone": "+70663770098"}
0005433368255	FB6B6C	8183 945716	NIKOLAY FILIPPOV	{"email": "nikolay.filippov-1966@postgrespro.ru", "phone": "+70944258359"}
0005433368256	FB6B6C	9009 653404	KSENIYA NAZAROVA	{"phone": "+70908397658"}
0005433368257	13927A	6437 234350	YURIY VASILEV	{"email": "vasilev.y.1965@postgrespro.ru", "phone": "+70442404590"}
0005433368258	13927A	2881 119407	ZINAIDA POTAPOVA	{"phone": "+70591871190"}
0005433368259	CF446C	6268 557579	VALENTIN IVANOV	{"email": "valentinivanov.071962@postgrespro.ru", "phone": "+70323493194"}
0005433368260	CF446C	4127 261351	ALEKSANDR PAVLOV	{"phone": "+70070905431"}
0005433368261	A17784	2377 473543	EVGENIY RODIONOV	{"email": "e-rodionov121966@postgrespro.ru", "phone": "+70591810211"}
0005433368262	3E97AD	2930 859511	NADEZHDA VASILEVA	{"email": "n.vasileva.081972@postgrespro.ru", "phone": "+70945696575"}
0005433368263	3E97AD	7886 892362	EVGENIY NIKITIN	{"phone": "+70651154123"}
0005433368264	62F898	4168 830115	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana_121980@postgrespro.ru", "phone": "+70745952890"}
0005433368265	62F898	3246 869828	NATALYA SEMENOVA	{"email": "natalya_semenova19081974@postgrespro.ru", "phone": "+70263189120"}
0005433368266	DCCE3F	9849 076104	TATYANA TIMOFEEVA	{"email": "timofeevatatyana1976@postgrespro.ru", "phone": "+70043568975"}
0005433368267	DCCE3F	0635 724325	DANIIL NIKOLAEV	{"email": "dnikolaev.1973@postgrespro.ru", "phone": "+70393646877"}
0005433368268	2B737F	0279 916324	NIKITA PAVLOV	{"email": "nikita_pavlov_1973@postgrespro.ru", "phone": "+70518826235"}
0005433368269	2B737F	5179 641282	IVAN FEDOROV	{"email": "ivan-fedorov.061974@postgrespro.ru", "phone": "+70735861114"}
0005433368270	329578	4605 368934	ALEKSANDR ROMANOV	{"phone": "+70344112492"}
0005433368271	329578	7085 559432	NINA GAVRILOVA	{"phone": "+70851543440"}
0005433368272	329578	4623 329412	OLGA KUZNECOVA	{"phone": "+70949994449"}
0005433368273	8301ED	7900 637792	OLEG DAVYDOV	{"phone": "+70176732530"}
0005433368274	8301ED	7558 984382	IRINA LAZAREVA	{"phone": "+70403610317"}
0005433368275	704C28	4176 777550	ALEKSANDR BARANOV	{"phone": "+70544549869"}
0005433368276	704C28	1918 310482	PAVEL NOVIKOV	{"phone": "+70260666890"}
0005433368277	974E06	6355 353022	SVETLANA SERGEEVA	{"email": "s-sergeeva101972@postgrespro.ru", "phone": "+70654747876"}
0005433368278	983F93	4624 152978	OKSANA NESTEROVA	{"phone": "+70598338177"}
0005433368279	983F93	5764 354948	SVETLANA ABRAMOVA	{"email": "s_abramova-011970@postgrespro.ru", "phone": "+70052359746"}
0005433368280	DD7767	6938 989258	ALEKSEY BELOV	{"email": "abelov.07071987@postgrespro.ru", "phone": "+70809323082"}
0005433368281	DD7767	4548 885131	MAKSIM RODIONOV	{"phone": "+70939390705"}
0005433368282	8D5029	7519 190276	OLGA ISAEVA	{"email": "oisaeva-22081975@postgrespro.ru", "phone": "+70671001833"}
0005433368283	8D5029	1006 109708	TATYANA MASLOVA	{"phone": "+70419872019"}
0005433368284	323034	2398 485229	IRINA POPOVA	{"phone": "+70451235410"}
0005433368285	8DB94A	3440 611340	ALEKSANDRA SAVELEVA	{"email": "asaveleva09071964@postgrespro.ru", "phone": "+70864718434"}
0005433368286	1F6AA2	3268 469390	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov07091976@postgrespro.ru", "phone": "+70181605900"}
0005433368287	1F6AA2	7412 264590	ALEKSANDR ABRAMOV	{"email": "abramov-a.1970@postgrespro.ru", "phone": "+70928247314"}
0005433368288	8AC612	8953 144269	ALEKSANDR ANDREEV	{"email": "andreeva121977@postgrespro.ru", "phone": "+70811758183"}
0005433368289	0240EF	3290 903083	EVGENIY SOROKIN	{"phone": "+70164710524"}
0005433368290	819970	7068 211189	TAISIYA POPOVA	{"phone": "+70682511973"}
0005433368291	819970	5690 637718	MARINA BOGDANOVA	{"email": "bogdanova.marina1984@postgrespro.ru", "phone": "+70060480942"}
0005433368292	75F957	4314 702519	GRIGORIY ANTONOV	{"phone": "+70378456265"}
0005433368293	75F957	6229 852200	ALBINA SOROKINA	{"email": "sorokina_albina_25101974@postgrespro.ru", "phone": "+70425119143"}
0005433368294	C3441E	6826 983658	OLGA BOGDANOVA	{"phone": "+70345941358"}
0005433368295	C3441E	4445 635623	EVGENIY SCHERBAKOV	{"email": "evgeniy-scherbakov31101966@postgrespro.ru", "phone": "+70458920362"}
0005433368296	86017B	6583 816026	ANATOLIY PAVLOV	{"email": "a_pavlov-03121973@postgrespro.ru", "phone": "+70645704454"}
0005433368297	81907A	5353 978657	LIDIYA PETROVA	{"email": "lpetrova041980@postgrespro.ru", "phone": "+70017630596"}
0005433368298	81907A	3212 470029	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev-28121966@postgrespro.ru", "phone": "+70813891397"}
0005433368299	7431E3	4725 531933	NADEZHDA KUZMINA	{"phone": "+70994400573"}
0005433368300	26AA82	0069 643857	VLADIMIR STEPANOV	{"phone": "+70646601022"}
0005433368301	26AA82	6480 702733	FEDOR KUZNECOV	{"phone": "+70993147021"}
0005433368302	A80996	8662 021522	ANATOLIY YAKOVLEV	{"phone": "+70543912561"}
0005433368303	A80996	6945 713966	NATALIYA KALININA	{"email": "kalinina_n30121970@postgrespro.ru", "phone": "+70708044055"}
0005433368304	A80996	5967 153552	YURIY MIKHAYLOV	{"email": "mikhaylov.yuriy.13081983@postgrespro.ru", "phone": "+70317751488"}
0005433368305	0395AA	9610 583300	ROZA RODIONOVA	{"email": "rodionova-r_15061979@postgrespro.ru", "phone": "+70137490214"}
0005433368306	E9A870	3163 738889	VITALIY KOROLEV	{"email": "vkorolev-21101965@postgrespro.ru", "phone": "+70568237121"}
0005433368307	8049B2	9586 414783	ANDREY DAVYDOV	{"phone": "+70565324291"}
0005433368308	7B5595	0152 960359	VLADIMIR KOZLOV	{"email": "kozlov-vladimir.1969@postgrespro.ru", "phone": "+70795562532"}
0005433368309	6CCE79	8439 946659	NATALYA ISAEVA	{"email": "natalya-isaeva011964@postgrespro.ru", "phone": "+70576195476"}
0005433368310	337065	0481 795042	LYUDMILA BELYAEVA	{"email": "belyaeval_1965@postgrespro.ru", "phone": "+70665601532"}
0005433368311	50B196	0807 888306	SERGEY BELOV	{"phone": "+70044080536"}
0005433368312	B5E171	8964 724612	OLGA SOKOLOVA	{"phone": "+70616246895"}
0005433368313	B5E171	9778 672104	KLAVDIYA KOROLEVA	{"email": "klavdiya-koroleva121980@postgrespro.ru", "phone": "+70842134742"}
0005433368314	5EE3AA	3141 247492	LIDIYA ILINA	{"phone": "+70645789096"}
0005433368315	A7C730	4958 019063	TATYANA YAKOVLEVA	{"phone": "+70341805868"}
0005433368316	0A11AD	8567 969079	IVAN OSIPOV	{"phone": "+70327389848"}
0005433368317	B4741F	4888 731702	VALENTIN MIRONOV	{"phone": "+70422182340"}
0005433368318	8CB0B6	5960 104084	ZINAIDA CHERNOVA	{"phone": "+70206632575"}
0005433368319	C321A4	3071 037081	MIKHAIL FILIPPOV	{"phone": "+70712950662"}
0005433368320	29E125	6994 850461	SERGEY IVANOV	{"email": "ivanov.s.1973@postgrespro.ru", "phone": "+70793731235"}
0005433368321	F9744F	1155 509946	VALENTINA NIKITINA	{"email": "v-nikitina.091962@postgrespro.ru", "phone": "+70177226045"}
0005433368322	F9744F	0968 620906	TATYANA RODIONOVA	{"email": "tatyana_rodionova.1972@postgrespro.ru", "phone": "+70596912065"}
0005433368323	88C31F	6964 106671	YULIYA IVANOVA	{"email": "yuliya_ivanova011972@postgrespro.ru", "phone": "+70995632132"}
0005433368324	D994A2	6755 944723	STANISLAV SCHERBAKOV	{"phone": "+70321895134"}
0005433368325	819467	6930 414816	ALENA GERASIMOVA	{"phone": "+70444645225"}
0005433368326	819467	8666 473567	OLEG GAVRILOV	{"phone": "+70072197468"}
0005433368327	5C10D1	6021 637421	KONSTANTIN ANTONOV	{"phone": "+70964645220"}
0005433368328	5C10D1	7391 476012	TATYANA ISAEVA	{"email": "isaeva.t.06011975@postgrespro.ru", "phone": "+70784129835"}
0005433368329	54B9D8	6301 639667	ZHANNA MATVEEVA	{"email": "z-matveeva-1974@postgrespro.ru", "phone": "+70735629617"}
0005433368330	BFF6DA	3173 620147	GALINA ZAKHAROVA	{"email": "galina_zakharova.1972@postgrespro.ru", "phone": "+70793766469"}
0005433368331	BFF6DA	7651 069500	YURIY ZHURAVLEV	{"phone": "+70361053895"}
0005433368332	F7DE12	8731 579649	DMITRIY PAVLOV	{"phone": "+70209684795"}
0005433368333	B4E3B8	5513 882461	RADIK IVANOV	{"phone": "+70550816131"}
0005433368334	F01BE9	6282 476627	DANIIL ZAYCEV	{"email": "zaycev-d_28021973@postgrespro.ru", "phone": "+70714682648"}
0005433368335	893AE5	7211 005960	NINA SAVELEVA	{"email": "saveleva-nina-1965@postgrespro.ru", "phone": "+70021777522"}
0005433368336	893AE5	1343 640992	ALBINA STEPANOVA	{"phone": "+70017819904"}
0005433368337	CF77C5	7560 968127	NADEZHDA IVANOVA	{"email": "ivanovan17101971@postgrespro.ru", "phone": "+70550374305"}
0005433368338	C2F221	3683 489843	ROMAN PAVLOV	{"phone": "+70996637221"}
0005433368339	CDC310	2884 547476	NATALYA ZAKHAROVA	{"phone": "+70568766840"}
0005433368340	747D67	2352 384470	OLGA TIKHONOVA	{"email": "tikhonovao.041968@postgrespro.ru", "phone": "+70385048519"}
0005433368341	747D67	1511 077853	TATYANA IVANOVA	{"phone": "+70934863477"}
0005433368342	747D67	4328 898645	LYUDMILA SOKOLOVA	{"phone": "+70489608601"}
0005433368343	57BCF5	4884 616003	OLEG POPOV	{"phone": "+70679028565"}
0005433368344	57BCF5	0596 856499	ANASTASIYA IVANOVA	{"email": "a_ivanova-02071975@postgrespro.ru", "phone": "+70595698019"}
0005433368345	BA01BA	4070 600747	SERGEY GUSEV	{"phone": "+70868193538"}
0005433368346	9DE178	9386 300654	NATALYA MAKAROVA	{"email": "makarovan1973@postgrespro.ru", "phone": "+70192408941"}
0005433368347	064D2E	9377 826911	DMITRIY SERGEEV	{"email": "sergeevd_1976@postgrespro.ru", "phone": "+70300825970"}
0005433368348	58E038	4786 639128	YURIY MATVEEV	{"email": "matveev_yuriy1961@postgrespro.ru", "phone": "+70974006496"}
0005433368349	58E038	0073 340384	LYUDMILA NESTEROVA	{"phone": "+70374807503"}
0005433368350	ECD410	0439 982607	TATYANA MASLOVA	{"email": "t.maslova-031975@postgrespro.ru", "phone": "+70245697500"}
0005433368351	CA6DB5	5773 257075	KLAVDIYA KALININA	{"email": "klavdiya.kalinina18121968@postgrespro.ru", "phone": "+70074230774"}
0005433368352	53AF19	5870 248308	ANNA KOROLEVA	{"phone": "+70285674155"}
0005433368353	4B86E2	6422 872056	NATALYA MELNIKOVA	{"email": "natalyamelnikova.081970@postgrespro.ru", "phone": "+70448424340"}
0005433368354	BAE279	6324 760695	TAMARA AKIMOVA	{"phone": "+70395907773"}
0005433368355	71C66E	9986 294252	RAISA FEDOROVA	{"email": "raisa_fedorova.121981@postgrespro.ru", "phone": "+70979530838"}
0005433368356	E851FD	4005 171787	EKATERINA ZHUKOVA	{"email": "ekaterina-zhukova-051969@postgrespro.ru", "phone": "+70097288855"}
0005433368357	17C92D	4824 310035	DMITRIY ZAYCEV	{"email": "zaycev.d.021975@postgrespro.ru", "phone": "+70315838598"}
0005433368358	AF091F	1005 856863	ANNA KISELEVA	{"phone": "+70456205470"}
0005433368359	AF091F	8136 363616	VALENTINA DAVYDOVA	{"email": "vdavydova-101978@postgrespro.ru", "phone": "+70682074892"}
0005433368360	AF091F	7866 126897	ALEKSANDR POPOV	{"email": "aleksandr-popov.1974@postgrespro.ru", "phone": "+70941364707"}
0005433368361	AA3811	3068 091998	IVAN RODIONOV	{"phone": "+70271199923"}
0005433368362	2C224E	3294 003037	ANNA ALEKSANDROVA	{"email": "anna.aleksandrova-23031977@postgrespro.ru", "phone": "+70148021916"}
0005433368363	2C224E	8251 887712	VLADIMIR NAZAROV	{"phone": "+70098508660"}
0005433368364	D39FD7	6930 045315	LARISA ALEKSANDROVA	{"phone": "+70883545855"}
0005433368365	D39FD7	5608 205425	YULIYA NAZAROVA	{"email": "yuliyanazarova-051977@postgrespro.ru", "phone": "+70132210044"}
0005433368366	F7B230	1817 263985	DMITRIY KUZNECOV	{"email": "dmitriykuznecov.21031977@postgrespro.ru", "phone": "+70000345358"}
0005433368367	F7B230	6986 282933	LYUBOV OSIPOVA	{"phone": "+70724828252"}
0005433368368	FB51F3	2612 339123	ALEKSANDR GRIGOREV	{"phone": "+70492636159"}
0005433368369	FB51F3	5660 817379	ANATOLIY NIKITIN	{"email": "a-nikitin081957@postgrespro.ru", "phone": "+70859299093"}
0005433368370	B797DC	7095 038565	DMITRIY SMIRNOV	{"phone": "+70490336877"}
0005433368371	B797DC	8114 831033	VALENTIN ANTONOV	{"phone": "+70220372308"}
0005433368372	11EB2A	5439 998815	DANILA MAKAROV	{"email": "d-makarov.1971@postgrespro.ru", "phone": "+70675255372"}
0005433368373	11EB2A	4717 746898	GULNARA ZHUKOVA	{"email": "gzhukova-111969@postgrespro.ru", "phone": "+70862539397"}
0005433368374	1E0E57	0537 614734	TATYANA NAZAROVA	{"email": "nazarova.t081985@postgrespro.ru", "phone": "+70076706602"}
0005433368375	941E97	9430 220730	YANA ROMANOVA	{"phone": "+70749674136"}
0005433368376	560812	2537 680134	ALEKSEY PAVLOV	{"email": "pavlov-aleksey011980@postgrespro.ru", "phone": "+70489903187"}
0005433368377	560812	6569 224708	FEDOR SERGEEV	{"phone": "+70535621608"}
0005433368378	9D7644	1758 453630	OLEG MELNIKOV	{"email": "melnikov-oleg1971@postgrespro.ru", "phone": "+70640218950"}
0005433368379	9D7644	9192 545558	VERA FILATOVA	{"phone": "+70652183413"}
0005433368380	351EB0	4736 702377	KIRILL KRASNOV	{"phone": "+70177601670"}
0005433368381	1DE2E3	4370 995124	DMITRIY GORBUNOV	{"phone": "+70508108882"}
0005433368382	1DE2E3	5237 564294	LYUBOV IVANOVA	{"email": "l_ivanova_18021981@postgrespro.ru", "phone": "+70262832876"}
0005433368383	1DE2E3	4523 439433	VALENTINA ABRAMOVA	{"email": "valentinaabramova.1971@postgrespro.ru", "phone": "+70648776593"}
0005433368384	1DE2E3	0641 762603	OLESYA VOLKOVA	{"email": "o-volkova_1962@postgrespro.ru", "phone": "+70233769959"}
0005433368385	CB10FC	3365 520030	TATYANA PETROVA	{"email": "tatyanapetrova021966@postgrespro.ru", "phone": "+70014453530"}
0005433368386	BE1535	4838 323849	LYUDMILA FROLOVA	{"email": "frolova_lyudmila_1970@postgrespro.ru", "phone": "+70386252625"}
0005433368387	BE1535	2304 137593	ALEKSEY KOZLOV	{"phone": "+70807131213"}
0005433368388	534205	1234 968656	NATALYA MIKHAYLOVA	{"phone": "+70965602474"}
0005433368389	A1B362	3096 012023	ILYA MATVEEV	{"email": "matveev.ilya12071976@postgrespro.ru", "phone": "+70363736146"}
0005433368390	A1B834	6045 873930	VASILIY STEPANOV	{"email": "stepanov_v.14051968@postgrespro.ru", "phone": "+70319148701"}
0005433368391	9B13B5	9754 244880	ANATOLIY IVANOV	{"email": "a.ivanov04081972@postgrespro.ru", "phone": "+70317013861"}
0005433368392	DF159D	6519 033341	OLEG ANDREEV	{"email": "andreev_o-091973@postgrespro.ru", "phone": "+70426548369"}
0005433368393	D6DEB3	8781 069274	VIKTORIYA NESTEROVA	{"email": "viktoriya_nesterova021979@postgrespro.ru", "phone": "+70095198587"}
0005433368394	FCF483	1747 421334	GALINA YAKOVLEVA	{"phone": "+70760668244"}
0005433368453	DFE5AF	4950 012058	LILIYA AKIMOVA	{"phone": "+70333520856"}
0005433368395	FCF483	4699 368121	VITALIY KUZMIN	{"email": "kuzmin.vitaliy-11101980@postgrespro.ru", "phone": "+70234937058"}
0005433368396	3C9E29	3958 984187	NINA MEDVEDEVA	{"phone": "+70271546645"}
0005433368397	3C9E29	0519 795591	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov_22071982@postgrespro.ru", "phone": "+70571973620"}
0005433368398	9A9D84	0928 162070	DENIS GRIGOREV	{"email": "dgrigorev_071970@postgrespro.ru", "phone": "+70985387714"}
0005433368399	F9F5B2	7743 323998	OKSANA IVANOVA	{"phone": "+70602875348"}
0005433368400	A6AC0B	0209 312039	ALEKSANDR SEMENOV	{"email": "semenova-02071980@postgrespro.ru", "phone": "+70088304692"}
0005433368401	A6AC0B	6238 813094	SERGEY AFANASEV	{"email": "afanasev_sergey1982@postgrespro.ru", "phone": "+70404861788"}
0005433368402	A6AC0B	7179 770732	SERGEY PETROV	{"phone": "+70749081012"}
0005433368403	F0B774	5741 961924	VIKTOR PETROV	{"phone": "+70409273461"}
0005433368404	93F07E	5985 985160	ANASTASIYA NESTEROVA	{"email": "anastasiya_nesterova.1964@postgrespro.ru", "phone": "+70970216353"}
0005433368405	91FEF5	1796 444336	ALEKSANDR VASILEV	{"email": "aleksandrvasilev011975@postgrespro.ru", "phone": "+70814685303"}
0005433368406	91FEF5	3035 754626	SERGEY IVANOV	{"email": "ivanov.s24021980@postgrespro.ru", "phone": "+70882683064"}
0005433368407	B86846	7995 159908	GENNADIY ANDREEV	{"email": "andreev.g_08081965@postgrespro.ru", "phone": "+70301984282"}
0005433368408	6D5AC0	8486 794245	DMITRIY ROMANOV	{"phone": "+70495012324"}
0005433368409	3F3A3E	6974 610781	DENIS VLASOV	{"email": "vlasov.denis_091961@postgrespro.ru", "phone": "+70740132175"}
0005433368410	1FF4D6	2431 733966	LIDIYA BELOVA	{"phone": "+70200224725"}
0005433368411	50521A	4454 092943	IRINA TITOVA	{"email": "titova-irina_081959@postgrespro.ru", "phone": "+70391189721"}
0005433368412	662FC2	6242 501355	VARVARA KUZNECOVA	{"phone": "+70445940489"}
0005433368413	DACB3F	8957 688285	LYUDMILA KARPOVA	{"phone": "+70667012439"}
0005433368414	39016E	4177 714142	RASHID EGOROV	{"email": "egorov-rashid1979@postgrespro.ru", "phone": "+70994752414"}
0005433368415	39016E	4761 072990	EKATERINA PETROVA	{"email": "ekaterinapetrova-1974@postgrespro.ru", "phone": "+70849506605"}
0005433368416	39016E	9558 587678	NATALIYA DAVYDOVA	{"phone": "+70161552726"}
0005433368417	91C98E	1125 279617	STANISLAV VLASOV	{"phone": "+70838896239"}
0005433368418	91C98E	1707 274592	EKATERINA BARANOVA	{"email": "baranova_e.03041982@postgrespro.ru", "phone": "+70966765490"}
0005433368419	A3E982	7337 488352	ELENA MIKHAYLOVA	{"email": "elena_mikhaylova_051962@postgrespro.ru", "phone": "+70354375826"}
0005433368420	668E8E	6059 746048	ELENA ABRAMOVA	{"phone": "+70790492637"}
0005433368421	896484	8694 731759	ILYA TIMOFEEV	{"phone": "+70442282563"}
0005433368422	7B909A	1757 380968	ARTEM ROMANOV	{"phone": "+70838657639"}
0005433368423	7B909A	9852 187008	ELENA KUZNECOVA	{"email": "e_kuznecova_111970@postgrespro.ru", "phone": "+70587219710"}
0005433368424	63053C	1844 629500	VIKTOR ORLOV	{"phone": "+70060253432"}
0005433368425	16F2EB	9014 267910	TATYANA ZAKHAROVA	{"email": "t.zakharova111974@postgrespro.ru", "phone": "+70017347785"}
0005433368426	FF3888	3030 188580	YURIY KUZNECOV	{"phone": "+70251106392"}
0005433368427	FF3888	3448 053916	ANDREY PETROV	{"phone": "+70923449319"}
0005433368428	B93CB7	1889 051439	SOFYA FOMINA	{"email": "s-fomina_29081976@postgrespro.ru", "phone": "+70679277678"}
0005433368429	D6E3E1	4644 752716	FATIMA LEBEDEVA	{"email": "lebedevaf28121979@postgrespro.ru", "phone": "+70104026845"}
0005433368430	F4309B	3517 648623	KONSTANTIN MAKSIMOV	{"phone": "+70893281052"}
0005433368431	095B7B	1105 559261	GALINA ZOTOVA	{"phone": "+70340855412"}
0005433368432	6FD7D8	0612 338473	VIKTOR MIRONOV	{"phone": "+70618345770"}
0005433368433	6FD7D8	6048 728167	ELENA ISAEVA	{"email": "isaeva_elena21101970@postgrespro.ru", "phone": "+70378099751"}
0005433368434	1AAA8D	4116 800928	LEONID TARASOV	{"phone": "+70866016254"}
0005433368435	C5C354	8884 461496	SERGEY NIKOLAEV	{"email": "nikolaev_s031975@postgrespro.ru", "phone": "+70387842035"}
0005433368436	3004C1	2380 813007	SERGEY OSIPOV	{"email": "osipov-sergey_021977@postgrespro.ru", "phone": "+70138112359"}
0005433368437	3004C1	4465 528197	EVGENIY BORISOV	{"email": "borisov-e1969@postgrespro.ru", "phone": "+70639274491"}
0005433368438	C9FEBF	2576 038577	MARINA ILINA	{"email": "m_ilina-11071968@postgrespro.ru", "phone": "+70804736359"}
0005433368439	107CD1	7321 630626	IGOR PAVLOV	{"email": "igor-pavlov_1971@postgrespro.ru", "phone": "+70189673678"}
0005433368440	A53ED4	9519 738490	ALIYA DAVYDOVA	{"email": "davydova_aliya.101974@postgrespro.ru", "phone": "+70488438052"}
0005433368441	A53ED4	9345 353857	VLADIMIR IVANOV	{"email": "vivanov061984@postgrespro.ru", "phone": "+70629552527"}
0005433368442	619262	1583 393979	SERGEY KULIKOV	{"email": "sergeykulikov-20011973@postgrespro.ru", "phone": "+70442958639"}
0005433368443	619262	2767 149353	MIKHAIL KUZNECOV	{"email": "kuznecov-m_101976@postgrespro.ru", "phone": "+70563746448"}
0005433368444	9019C4	3743 434074	LADA IVANOVA	{"email": "l-ivanova.23021968@postgrespro.ru", "phone": "+70391677335"}
0005433368445	EB6ACD	9542 932779	EDUARD PAVLOV	{"phone": "+70123492367"}
0005433368446	EB6ACD	0608 194277	VLADIMIR SCHERBAKOV	{"email": "vladimir_scherbakov.15101966@postgrespro.ru", "phone": "+70218552999"}
0005433368447	B743EA	1077 482516	ELENA VASILEVA	{"email": "e-vasileva071987@postgrespro.ru", "phone": "+70720512574"}
0005433368448	033372	6577 191236	TATYANA DMITRIEVA	{"email": "tdmitrieva29111966@postgrespro.ru", "phone": "+70930121750"}
0005433368449	033372	4293 010231	VLADIMIR KUZNECOV	{"email": "v.kuznecov-051970@postgrespro.ru", "phone": "+70888850667"}
0005433368450	1D90AF	4561 016349	SVETLANA SERGEEVA	{"email": "s_sergeeva1963@postgrespro.ru", "phone": "+70083651770"}
0005433368451	1D90AF	6732 288673	VLADIMIR BARANOV	{"email": "v-baranov-071969@postgrespro.ru", "phone": "+70234008326"}
0005433368452	82995F	0899 904017	NIKOLAY VOLKOV	{"email": "nikolay.volkov-011980@postgrespro.ru", "phone": "+70447663240"}
0005433368454	D97212	7965 395261	LYUBOV ANDREEVA	{"email": "andreeva_l.1988@postgrespro.ru", "phone": "+70608409860"}
0005433368455	D97212	7547 772469	SVETLANA KULIKOVA	{"phone": "+70520800767"}
0005433368456	D97212	2917 429652	OLEG ZHURAVLEV	{"phone": "+70192340521"}
0005433368457	88085E	2697 250313	OLGA GORBUNOVA	{"phone": "+70953688386"}
0005433368458	88085E	6380 312360	LYUBOV VASILEVA	{"email": "vasileva_l.1976@postgrespro.ru", "phone": "+70111087731"}
0005433368459	554CD3	2328 098353	IVAN KISELEV	{"phone": "+70774117633"}
0005433368460	9DC995	5540 789609	MIKHAIL VOROBEV	{"phone": "+70830784206"}
0005433368461	154AF2	7571 080093	YURIY FROLOV	{"phone": "+70869660113"}
0005433368462	154AF2	9864 880870	OLGA CHERNOVA	{"email": "chernovaolga.17091980@postgrespro.ru", "phone": "+70646205975"}
0005433368463	50FBC2	7914 502533	NIKOLAY MOROZOV	{"phone": "+70800637959"}
0005433368464	1A2412	5903 425163	VLADISLAV NAZAROV	{"phone": "+70994978661"}
0005433368465	AD4ECD	4096 532434	PETR KUZNECOV	{"email": "petr-kuznecov.101976@postgrespro.ru", "phone": "+70685070377"}
0005433368466	7F79BC	9520 380599	TATYANA ZAYCEVA	{"email": "tzayceva-1981@postgrespro.ru", "phone": "+70874063773"}
0005433368467	7F79BC	8134 235806	ANATOLIY KRASNOV	{"email": "akrasnov-1982@postgrespro.ru", "phone": "+70820722290"}
0005433368468	51E7CF	4851 440762	SERGEY ALEKSANDROV	{"phone": "+70486999393"}
0005433368469	CE7CBC	9605 291329	DENIS ROMANOV	{"email": "denis_romanov-30111986@postgrespro.ru", "phone": "+70981254563"}
0005433368470	CCD60B	0540 383774	EVGENIYA CHERNOVA	{"phone": "+70948874318"}
0005433368471	CCD60B	8016 330309	IRINA ZAKHAROVA	{"email": "irinazakharova_26021975@postgrespro.ru", "phone": "+70038011117"}
0005433368472	27A166	8851 396854	ANTONINA BORISOVA	{"email": "a_borisova.1975@postgrespro.ru", "phone": "+70826738133"}
0005433368473	FD7991	6396 484174	PAVEL VASILEV	{"phone": "+70683176349"}
0005433368474	7B4A40	1276 359782	MARINA KOZLOVA	{"phone": "+70020015008"}
0005433368475	44423B	0354 512213	ALEKSEY ROMANOV	{"email": "aleksey.romanov.101962@postgrespro.ru", "phone": "+70514831116"}
0005433368476	44423B	9346 064074	OLGA ALEKSEEVA	{"phone": "+70982572414"}
0005433368477	99A33D	6335 707007	SERGEY NAZAROV	{"phone": "+70816781221"}
0005433368478	CC8674	4676 482037	DENIS ANDREEV	{"email": "andreev_d.091958@postgrespro.ru", "phone": "+70098614512"}
0005433368479	E358DD	9473 010294	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov_1980@postgrespro.ru", "phone": "+70417186155"}
0005433368480	E358DD	3599 946628	VIKTOR SOROKIN	{"phone": "+70476053230"}
0005433368481	8BB813	0432 195947	RUSLAN GAVRILOV	{"email": "gavrilov.ruslan-071973@postgrespro.ru", "phone": "+70361721620"}
0005433368482	1DA10E	8532 015181	TATYANA SAVELEVA	{"phone": "+70517254711"}
0005433368483	1DA10E	1592 826808	LYUDMILA YUDINA	{"email": "lyudmilayudina_20121979@postgrespro.ru", "phone": "+70583404940"}
0005433368484	BB4BD5	5420 143615	KONSTANTIN ZAKHAROV	{"email": "k_zakharov-1972@postgrespro.ru", "phone": "+70875911790"}
0005433368485	BB4BD5	0835 255744	IRINA MOROZOVA	{"email": "i.morozova-1972@postgrespro.ru", "phone": "+70092303335"}
0005433368486	BB4BD5	3439 514930	VERA BARANOVA	{"email": "v_baranova1980@postgrespro.ru", "phone": "+70948442846"}
0005433368487	62A8DC	2827 669751	ROMAN SOKOLOV	{"phone": "+70082443167"}
0005433368488	62A8DC	4901 365917	RAISA DENISOVA	{"email": "raisa.denisova.041969@postgrespro.ru", "phone": "+70524023123"}
0005433368489	4552DB	0700 509623	GALINA IVANOVA	{"email": "ivanova_galina_011968@postgrespro.ru", "phone": "+70261298024"}
0005433368490	4552DB	6006 905125	EGOR GRIGOREV	{"email": "egor.grigorev_101977@postgrespro.ru", "phone": "+70156114321"}
0005433368491	4552DB	2567 304030	GALINA KOVALEVA	{"phone": "+70238951669"}
0005433368492	15CCC2	2506 397061	VARVARA BELOVA	{"email": "belova-varvara081982@postgrespro.ru", "phone": "+70646361676"}
0005433368493	B6F171	5315 449166	ANASTASIYA LOGINOVA	{"email": "loginovaa091978@postgrespro.ru", "phone": "+70209675567"}
0005433368494	B6F171	2793 819184	TATYANA MIKHAYLOVA	{"phone": "+70566238311"}
0005433368495	CA8DAE	8070 215063	ANZHELA GUSEVA	{"email": "guseva-anzhela-11071967@postgrespro.ru", "phone": "+70171545541"}
0005433368496	14CFBB	7452 548289	NINA ANDREEVA	{"email": "andreevanina.17051967@postgrespro.ru", "phone": "+70905077168"}
0005433368497	75E077	1592 468534	MARIYA TROFIMOVA	{"phone": "+70667633754"}
0005433368498	DB4846	4796 450508	IGOR FEDOROV	{"phone": "+70138122252"}
0005433368499	DB4846	7315 768363	ALEKSANDR POPOV	{"email": "popov_a_12091981@postgrespro.ru", "phone": "+70873559459"}
0005433368500	05D331	2395 025778	ELENA IVANOVA	{"phone": "+70303929593"}
0005433368501	861BB9	9619 613485	OLEG NIKITIN	{"email": "o-nikitin_05011973@postgrespro.ru", "phone": "+70815759384"}
0005433368502	861BB9	5878 104381	YULIYA MASLOVA	{"phone": "+70780947662"}
0005433368503	C001EE	5868 607884	OLGA KRASNOVA	{"phone": "+70076786664"}
0005433368504	FCDA26	6184 779367	ALENA KONDRATEVA	{"phone": "+70520704809"}
0005433368505	FCDA26	8889 178654	OLGA KOZLOVA	{"email": "kozlova-o.081972@postgrespro.ru", "phone": "+70204597146"}
0005433368506	F57600	3004 681241	NIKOLAY MEDVEDEV	{"phone": "+70666937540"}
0005433368507	5FADFC	9833 784785	DANIIL ZHUKOV	{"email": "daniilzhukov.021958@postgrespro.ru", "phone": "+70002186086"}
0005433368508	5FADFC	4617 509613	VLADIMIR POPOV	{"phone": "+70000013065"}
0005433368509	376939	1507 566694	ELENA PAVLOVA	{"email": "pavlova-elena.031967@postgrespro.ru", "phone": "+70562818320"}
0005433368510	376939	5313 686037	GALINA NESTEROVA	{"email": "nesterova.g.011983@postgrespro.ru", "phone": "+70997845281"}
0005433368511	376939	6983 371856	LYUDMILA KAZAKOVA	{"email": "kazakoval_1973@postgrespro.ru", "phone": "+70221327458"}
0005433368512	F7DCA9	1466 275968	NIKOLAY MIRONOV	{"email": "nikolay_mironov.1964@postgrespro.ru", "phone": "+70746367304"}
0005433368513	1ACE6C	1677 224851	MARIYA NIKIFOROVA	{"phone": "+70528048577"}
0005433368514	FB3D1A	7290 259356	KIRILL KUDRYASHOV	{"phone": "+70697515613"}
0005433368515	658A8C	9892 367957	OKSANA MEDVEDEVA	{"email": "o.medvedeva_07031963@postgrespro.ru", "phone": "+70359395647"}
0005433368516	04E359	7661 957775	SERGEY BELOV	{"email": "belovsergey.111974@postgrespro.ru", "phone": "+70147385580"}
0005433368517	DD9966	7676 181139	DANIL ZAKHAROV	{"email": "d-zakharov_111979@postgrespro.ru", "phone": "+70194050086"}
0005433368518	077DDE	5948 819683	ZINAIDA FEDOROVA	{"email": "zinaida-fedorova1977@postgrespro.ru", "phone": "+70949300289"}
0005433368519	7CCF62	4359 690409	DMITRIY KONOVALOV	{"phone": "+70913848619"}
0005433368520	7CCF62	0550 530702	ALEKSEY SERGEEV	{"email": "sergeev-aleksey.091975@postgrespro.ru", "phone": "+70323981628"}
0005433368521	7CCF62	7442 715726	ANATOLIY SMIRNOV	{"email": "smirnova_121974@postgrespro.ru", "phone": "+70201803329"}
0005433368633	7B012C	5885 156428	ANASTASIYA KOMAROVA	{"phone": "+70773489077"}
0005433368522	AC9A22	9674 145155	VERA NIKITINA	{"email": "nikitina.vera_071974@postgrespro.ru", "phone": "+70847874966"}
0005433368523	AC9A22	3572 762237	MAKSIM KUZNECOV	{"phone": "+70435310717"}
0005433368524	6778F8	3672 733336	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikova.anastasiya_04061974@postgrespro.ru", "phone": "+70057869801"}
0005433368525	6778F8	4046 222366	VALENTINA MASLOVA	{"email": "maslova_v101974@postgrespro.ru", "phone": "+70305610006"}
0005433368526	6778F8	7431 418595	ALEKSANDR NAUMOV	{"phone": "+70783600059"}
0005433368527	6A3A46	6191 210003	NIKOLAY MAKAROV	{"email": "makarov_nikolay.021968@postgrespro.ru", "phone": "+70150192833"}
0005433368528	B75B5C	7913 126459	ALEKSEY ZAKHAROV	{"email": "zakharov-a-28121974@postgrespro.ru", "phone": "+70126251553"}
0005433368529	936AA1	6495 010161	KONSTANTIN FROLOV	{"phone": "+70392956498"}
0005433368530	030FF8	3117 220301	ANNA KISELEVA	{"phone": "+70676323218"}
0005433368531	030FF8	3866 557513	ALEKSANDR CHERNOV	{"phone": "+70577387125"}
0005433368532	0B94E0	4874 550849	OKSANA MARTYNOVA	{"phone": "+70906346083"}
0005433368533	0B94E0	0044 999521	VIKTORIYA KOZLOVA	{"email": "v_kozlova-101980@postgrespro.ru", "phone": "+70665169515"}
0005433368534	A431D2	1758 340221	GALINA POPOVA	{"email": "galinapopova051975@postgrespro.ru", "phone": "+70148934360"}
0005433368535	9DD02F	0124 722856	ALEKSANDR SOKOLOV	{"phone": "+70715593018"}
0005433368536	2EFEED	1220 158812	VASILIY POPOV	{"phone": "+70066156616"}
0005433368537	729B6D	4958 296002	ALEKSANDR SOLOVEV	{"phone": "+70472718204"}
0005433368538	78C018	6716 151643	TAMARA KUZNECOVA	{"email": "tkuznecova28121976@postgrespro.ru", "phone": "+70592939707"}
0005433368539	78C018	1571 101211	ILYA GRIGOREV	{"email": "grigorev-i091959@postgrespro.ru", "phone": "+70068456154"}
0005433368540	81C71D	3442 928194	VLADIMIR SAVELEV	{"email": "savelev_vladimir_26091970@postgrespro.ru", "phone": "+70954674732"}
0005433368541	81C71D	5181 618416	RADMIR KUZNECOV	{"phone": "+70236203874"}
0005433368542	D503F5	1700 946425	LIDIYA SOLOVEVA	{"email": "soloveva-lidiya.061980@postgrespro.ru", "phone": "+70736548049"}
0005433368543	7F5D36	4028 113823	ALEKSANDR PETROV	{"phone": "+70475779494"}
0005433368544	7F5D36	2506 932749	OLGA IVANOVA	{"email": "o_ivanova_29121958@postgrespro.ru", "phone": "+70669908607"}
0005433368545	B556F8	8999 826863	PELAGEYA VOROBEVA	{"phone": "+70881033258"}
0005433368546	B556F8	4103 732879	NATALIYA BELOVA	{"email": "belova-n_18031969@postgrespro.ru", "phone": "+70763598961"}
0005433368547	B556F8	3312 530567	OKSANA VLASOVA	{"email": "oksana.vlasova_081982@postgrespro.ru", "phone": "+70146617328"}
0005433368548	0899E5	5270 340742	ALLA KOLESNIKOVA	{"email": "a-kolesnikova.111985@postgrespro.ru", "phone": "+70938609903"}
0005433368549	0B4EEC	0414 720342	EVGENIYA KONOVALOVA	{"phone": "+70383365979"}
0005433368550	0BC4C6	5971 900922	TATYANA SOROKINA	{"email": "sorokina.tatyana.121976@postgrespro.ru", "phone": "+70506477366"}
0005433368551	1853EA	5105 461945	VLADIMIR MIRONOV	{"email": "mironov_vladimir_041978@postgrespro.ru", "phone": "+70358289588"}
0005433368552	B57A10	9309 882718	LIDIYA KALININA	{"email": "kalinina_l23101976@postgrespro.ru", "phone": "+70139113596"}
0005433368553	468FF7	6689 310580	KSENIYA MOISEEVA	{"email": "moiseevakseniya.011989@postgrespro.ru", "phone": "+70286921437"}
0005433368554	E12C8E	0431 375594	ANNA KOVALEVA	{"phone": "+70446684062"}
0005433368555	F1C68F	9207 184370	SVETLANA OVCHINNIKOVA	{"email": "sovchinnikova041974@postgrespro.ru", "phone": "+70725012348"}
0005433368556	F1C68F	2254 759643	NINA TIKHONOVA	{"phone": "+70345089980"}
0005433368557	BEE64C	7177 295767	ANATOLIY ROMANOV	{"phone": "+70251193140"}
0005433368558	A7FCCD	6778 364398	SVETLANA BARANOVA	{"email": "sbaranova-08041986@postgrespro.ru", "phone": "+70988384599"}
0005433368559	37B297	2243 046850	MARIYA KONDRATEVA	{"phone": "+70349421345"}
0005433368560	37B297	6194 573947	ANNA SOKOLOVA	{"email": "annasokolova.23011973@postgrespro.ru", "phone": "+70263120158"}
0005433368561	66BA45	3921 159453	DAMIR PAVLOV	{"email": "d.pavlov.01021980@postgrespro.ru", "phone": "+70133452925"}
0005433368562	C7F226	9799 044758	DMITRIY OSIPOV	{"email": "osipov-dmitriy_051966@postgrespro.ru", "phone": "+70022566003"}
0005433368563	F49716	1089 049689	IVAN SEMENOV	{"phone": "+70655623170"}
0005433368564	AD1541	1996 003518	ANNA ARKHIPOVA	{"phone": "+70295641899"}
0005433368565	6D6365	9762 118157	MARIYA MALYSHEVA	{"email": "malysheva.mariya.1980@postgrespro.ru", "phone": "+70531289716"}
0005433368566	C16616	3199 474875	ILYA KUZNECOV	{"email": "ikuznecov-1973@postgrespro.ru", "phone": "+70369882745"}
0005433368567	C16616	9006 843941	VLADIMIR SEMENOV	{"phone": "+70862765964"}
0005433368568	D9FF6E	3375 789736	OLGA ILINA	{"phone": "+70149063164"}
0005433368569	165FC5	4023 683368	MARIYA FEDOROVA	{"email": "fedorova_m_17031973@postgrespro.ru", "phone": "+70609744160"}
0005433368570	A4C394	9059 431742	IVAN KUZMIN	{"email": "kuzmin-i_071980@postgrespro.ru", "phone": "+70379141322"}
0005433368571	A4C394	5363 558993	SERGEY SERGEEV	{"email": "sergeev-s_16021973@postgrespro.ru", "phone": "+70154339374"}
0005433368572	5796AD	5715 408174	VITALIY SHEVCHENKO	{"phone": "+70671338710"}
0005433368573	B3B42B	6226 716233	ANNA KOZLOVA	{"phone": "+70150319465"}
0005433368574	903E11	0407 520916	EKATERINA SCHERBAKOVA	{"phone": "+70171859851"}
0005433368742	45C3A0	3617 517549	VLADIMIR SOROKIN	{"phone": "+70489082717"}
0005433368575	BDB2AA	3596 583450	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1983@postgrespro.ru", "phone": "+70095172601"}
0005433368576	BDB2AA	0555 236304	ANATOLIY PETROV	{"email": "anatoliypetrov_21031978@postgrespro.ru", "phone": "+70891401217"}
0005433368577	93506C	6206 523437	EKATERINA ANISIMOVA	{"email": "anisimova.ekaterina01051966@postgrespro.ru", "phone": "+70165883845"}
0005433368578	6D1AA4	1921 897950	VIKTOR SCHERBAKOV	{"phone": "+70843971821"}
0005433368579	6D1AA4	7187 191478	GALINA MELNIKOVA	{"phone": "+70971576547"}
0005433368580	E4B51E	8121 355089	NADEZHDA VASILEVA	{"email": "nvasileva.17101968@postgrespro.ru", "phone": "+70417261883"}
0005433368581	4358FD	5184 419134	VLADIMIR POPOV	{"phone": "+70858011378"}
0005433368582	6B8D8F	4026 205752	OLEG IVANOV	{"email": "oleg_ivanov-1973@postgrespro.ru", "phone": "+70325718104"}
0005433368583	F7F8C1	5465 551813	ZINAIDA ERMAKOVA	{"email": "z_ermakova.16081976@postgrespro.ru", "phone": "+70139636170"}
0005433368584	3C9333	4507 491689	DARYA POTAPOVA	{"phone": "+70182662197"}
0005433368585	ADC219	8664 846011	ALEKSEY MOROZOV	{"phone": "+70810064663"}
0005433368586	8F6F7B	1675 030216	ANDREY FEDOROV	{"phone": "+70382894796"}
0005433368587	8F6F7B	7553 078608	ANATOLIY ABRAMOV	{"phone": "+70848523829"}
0005433368588	49FEA9	9234 730985	TAISIYA POPOVA	{"email": "popova.t-1973@postgrespro.ru", "phone": "+70869045102"}
0005433368589	B36192	6193 510520	VALENTINA DANILOVA	{"phone": "+70243368979"}
0005433368590	B36192	7511 364106	MARINA STEPANOVA	{"phone": "+70444961495"}
0005433368591	490EB4	1036 787674	ANASTASIYA SAVELEVA	{"phone": "+70655493209"}
0005433368592	490EB4	3054 070596	ANASTASIYA IVANOVA	{"email": "aivanova.071963@postgrespro.ru", "phone": "+70456489540"}
0005433368593	32B325	8499 826440	OLGA MELNIKOVA	{"phone": "+70734967676"}
0005433368594	E38432	9434 447540	VALENTINA DENISOVA	{"email": "v.denisova.041963@postgrespro.ru", "phone": "+70479934820"}
0005433368595	E38432	1081 753909	ALEKSANDR ABRAMOV	{"email": "abramova-02061968@postgrespro.ru", "phone": "+70193096237"}
0005433368596	C0B15A	7136 592326	GALINA KUZMINA	{"phone": "+70640957669"}
0005433368597	3F6EA1	1138 531600	IRINA KUZNECOVA	{"email": "irina-kuznecova.10011982@postgrespro.ru", "phone": "+70537313550"}
0005433368598	1C86BD	5623 992199	ELENA SOKOLOVA	{"email": "e.sokolova-24071976@postgrespro.ru", "phone": "+70882417302"}
0005433368599	1C86BD	5597 468669	NATALYA EGOROVA	{"email": "natalya-egorova.011975@postgrespro.ru", "phone": "+70353323738"}
0005433368600	0CC0C2	3575 597604	POLINA POLYAKOVA	{"phone": "+70030296556"}
0005433368601	BB21F7	4620 859526	ALEKSANDR BORISOV	{"email": "a_borisov1975@postgrespro.ru", "phone": "+70033144294"}
0005433368602	01D4A8	4545 189072	IGOR KRASNOV	{"email": "ikrasnov-061981@postgrespro.ru", "phone": "+70077595510"}
0005433368603	E341D1	3796 063442	PETR SCHERBAKOV	{"phone": "+70601802006"}
0005433368604	E341D1	5007 071387	DANIIL MATVEEV	{"phone": "+70769539834"}
0005433368605	691F99	7200 685089	VALENTINA ILINA	{"email": "valentina.ilina.1970@postgrespro.ru", "phone": "+70515257391"}
0005433368606	910E73	6528 539997	TATYANA DENISOVA	{"phone": "+70364980238"}
0005433368607	6D5221	3562 867228	GALINA GERASIMOVA	{"phone": "+70858503442"}
0005433368608	6D5221	8187 658415	ANNA MALYSHEVA	{"email": "annamalysheva.031971@postgrespro.ru", "phone": "+70593928965"}
0005433368609	438BA3	0741 853027	VALENTINA KALININA	{"email": "kalinina_v-06091973@postgrespro.ru", "phone": "+70523390142"}
0005433368610	438BA3	4520 848002	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey-22021980@postgrespro.ru", "phone": "+70021737530"}
0005433368611	438BA3	0152 548914	NINA KOLESNIKOVA	{"phone": "+70575254556"}
0005433368612	99100C	3847 226809	VYACHESLAV PAVLOV	{"email": "vyacheslav_pavlov1960@postgrespro.ru", "phone": "+70162634971"}
0005433368613	01A1E6	0238 739976	SERGEY TARASOV	{"phone": "+70502799540"}
0005433368614	4C54AC	2370 789826	RAISA VASILEVA	{"email": "vasilevar1975@postgrespro.ru", "phone": "+70159265899"}
0005433368615	4C54AC	7258 768767	NADEZHDA VASILEVA	{"email": "vasilevan.15101978@postgrespro.ru", "phone": "+70384346913"}
0005433368616	F7BA6B	1415 898505	MARGARITA AKIMOVA	{"phone": "+70943358104"}
0005433368617	F7BA6B	3821 404194	ANDREY KUZNECOV	{"phone": "+70549420461"}
0005433368618	F7BA6B	8727 867363	VALENTINA KUDRYASHOVA	{"phone": "+70884325637"}
0005433368619	AC0FCF	4895 521498	ELEONORA TIMOFEEVA	{"phone": "+70379586519"}
0005433368620	4E447C	5978 268141	ALEKSANDR BORISOV	{"email": "aborisov26061978@postgrespro.ru", "phone": "+70884727830"}
0005433368621	4E447C	9784 655502	YURIY PETROV	{"email": "yuriypetrov.1981@postgrespro.ru", "phone": "+70717860498"}
0005433368622	40B786	0886 006666	GEORGIY MATVEEV	{"email": "matveev_g.1969@postgrespro.ru", "phone": "+70732179275"}
0005433368623	0F3E13	9229 914198	ELENA KUDRYASHOVA	{"email": "kudryashovae_25031963@postgrespro.ru", "phone": "+70935891292"}
0005433368624	E23E1F	1937 205400	YURIY IVANOV	{"phone": "+70112246830"}
0005433368625	E23E1F	4310 675973	EVGENIY SEMENOV	{"email": "evgeniy_semenov-1959@postgrespro.ru", "phone": "+70625580276"}
0005433368626	662CC8	8652 793138	KARINA KUZNECOVA	{"email": "karina.kuznecova_021971@postgrespro.ru", "phone": "+70856471979"}
0005433368627	B99A71	5628 379829	ANNA EFREMOVA	{"phone": "+70941548128"}
0005433368628	5FD7D6	3321 535259	TATYANA MEDVEDEVA	{"phone": "+70570428239"}
0005433368629	5FD7D6	0726 738557	MARIYA DAVYDOVA	{"email": "davydova-m.30041977@postgrespro.ru", "phone": "+70277161807"}
0005433368630	87BAB4	9992 596821	KSENIYA KALININA	{"email": "kseniya_kalinina.04121973@postgrespro.ru", "phone": "+70316177606"}
0005433368631	87BAB4	3808 850998	EKATERINA MIKHAYLOVA	{"email": "mikhaylovaekaterina_21101970@postgrespro.ru", "phone": "+70945770744"}
0005433368632	7B012C	6443 919539	LYUDMILA YUDINA	{"email": "yudinalyudmila.061984@postgrespro.ru", "phone": "+70735557757"}
0005433368634	448041	4427 950077	ALEKSEY MOROZOV	{"email": "morozov_aleksey091981@postgrespro.ru", "phone": "+70832314255"}
0005433368635	448041	6969 144621	EKATERINA MARTYNOVA	{"email": "ekaterina.martynova_101970@postgrespro.ru", "phone": "+70016482641"}
0005433368636	9AD5A4	0025 511366	EKATERINA VOLKOVA	{"phone": "+70063371422"}
0005433368637	9AD5A4	8443 813127	KIRILL VLASOV	{"email": "kvlasov-1972@postgrespro.ru", "phone": "+70560757867"}
0005433368638	9AD5A4	8019 323235	NIKOLAY ANDREEV	{"email": "nandreev-1982@postgrespro.ru", "phone": "+70962483475"}
0005433368639	B33F00	5760 885591	OLEG SOROKIN	{"email": "sorokin_oleg_061974@postgrespro.ru", "phone": "+70049107395"}
0005433368640	1BB379	4860 628954	ANASTASIYA SOLOVEVA	{"phone": "+70823726985"}
0005433368641	AABA70	1435 895927	LIDIYA VOLKOVA	{"email": "lidiyavolkova_30081969@postgrespro.ru", "phone": "+70996938865"}
0005433368642	E500DB	2730 483965	GENNADIY KUZMIN	{"phone": "+70397359124"}
0005433368643	C925A7	1419 299134	ALEKSANDR KUZNECOV	{"phone": "+70212316095"}
0005433368644	C925A7	1232 227889	RIMMA NESTEROVA	{"email": "r.nesterova1975@postgrespro.ru", "phone": "+70287069340"}
0005433368645	31F252	7444 816908	ALEKSANDR NIKOLAEV	{"phone": "+70875103877"}
0005433368646	422248	6203 284192	ALEKSANDR SOKOLOV	{"phone": "+70056483463"}
0005433368647	2C6F2F	1508 053835	DENIS MAKSIMOV	{"email": "maksimov-d_021976@postgrespro.ru", "phone": "+70813368325"}
0005433368648	2C6F2F	3752 206909	ALISA KRASNOVA	{"email": "krasnova-alisa_031974@postgrespro.ru", "phone": "+70708248474"}
0005433368649	CC82BB	9426 124167	TATYANA SEMENOVA	{"email": "t.semenova1982@postgrespro.ru", "phone": "+70328880705"}
0005433368650	CC82BB	2921 948132	DARYA FADEEVA	{"phone": "+70066289975"}
0005433368651	14A4A7	1069 972133	ANNA FILIPPOVA	{"email": "annafilippova-051979@postgrespro.ru", "phone": "+70701615076"}
0005433368652	4B82D1	5900 669821	VLADIMIR ZAYCEV	{"phone": "+70048826700"}
0005433368653	4B82D1	2769 968849	IRINA CHERNOVA	{"phone": "+70801126194"}
0005433368654	B0C695	8531 414996	LYUDMILA TIMOFEEVA	{"email": "l_timofeeva_021978@postgrespro.ru", "phone": "+70969629918"}
0005433368655	E4AA59	6359 214150	SVETLANA IVANOVA	{"email": "s_ivanova28121976@postgrespro.ru", "phone": "+70649861329"}
0005433368656	E4AA59	4762 299269	ELINA ARKHIPOVA	{"email": "e-arkhipova1979@postgrespro.ru", "phone": "+70248816613"}
0005433368657	085169	1425 554541	VASILIY KOROLEV	{"email": "korolev_vasiliy-1961@postgrespro.ru", "phone": "+70919159364"}
0005433368658	085169	1922 188393	IVAN PETROV	{"email": "ivan-petrov_1968@postgrespro.ru", "phone": "+70489003026"}
0005433368659	085169	7202 776786	VLADIMIR ISAEV	{"phone": "+70649245013"}
0005433368660	58674D	0813 298248	KIRILL BORISOV	{"phone": "+70407398706"}
0005433368661	58674D	9817 874860	ELENA KOROLEVA	{"phone": "+70623676538"}
0005433368662	666090	7842 919921	ALEKSEY SEMENOV	{"email": "asemenov-1976@postgrespro.ru", "phone": "+70525487610"}
0005433368663	8FF880	5359 350319	SERGEY FEDOROV	{"phone": "+70991884433"}
0005433368664	81C8A0	2690 332893	VALENTINA SMIRNOVA	{"phone": "+70784925064"}
0005433368665	7A3101	6656 908998	OLGA NIKITINA	{"email": "olga_nikitina-1969@postgrespro.ru", "phone": "+70099531159"}
0005433368666	EAFB17	9396 480428	ANTONINA KUZNECOVA	{"phone": "+70389052078"}
0005433368667	EAFB17	0379 761600	TATYANA SOKOLOVA	{"phone": "+70401448553"}
0005433368668	EAFB17	9099 793418	NINA TARASOVA	{"email": "tarasova_nina.091969@postgrespro.ru", "phone": "+70751723513"}
0005433368669	9F8922	2015 458319	LYUBOV KOZLOVA	{"email": "lyubov_kozlova_021970@postgrespro.ru", "phone": "+70319518207"}
0005433368670	01690B	9116 445969	DARYA POLYAKOVA	{"phone": "+70221623301"}
0005433368671	F124F2	4995 777375	LIDIYA NAUMOVA	{"email": "lidiyanaumova121973@postgrespro.ru", "phone": "+70986710669"}
0005433368672	F124F2	6083 385951	MAKSIM GAVRILOV	{"email": "m.gavrilov121965@postgrespro.ru", "phone": "+70330928354"}
0005433368673	C6F1E0	2655 753089	MARGARITA SOROKINA	{"phone": "+70250915690"}
0005433368674	C6F1E0	7973 548620	ALEKSEY STEPANOV	{"phone": "+70796073277"}
0005433368675	E81E3A	6993 300912	ELENA PETROVA	{"email": "elenapetrova-1975@postgrespro.ru", "phone": "+70019319047"}
0005433368676	B4C6C1	6943 956163	DANIIL POPOV	{"email": "popov.daniil.14051977@postgrespro.ru", "phone": "+70407111086"}
0005433368677	B4C6C1	0989 964710	MARK EGOROV	{"phone": "+70927259435"}
0005433368678	5C64B5	5570 822645	NATALIYA GERASIMOVA	{"phone": "+70205660530"}
0005433368679	D7DBD9	0282 775214	POLINA MARTYNOVA	{"email": "polinamartynova1968@postgrespro.ru", "phone": "+70058894344"}
0005433368680	180EC9	2821 619583	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr-15081965@postgrespro.ru", "phone": "+70189551641"}
0005433368681	180EC9	6363 092223	ALEKSEY NIKOLAEV	{"phone": "+70067789447"}
0005433368682	46EAAC	4273 022622	TATYANA KISELEVA	{"phone": "+70378479187"}
0005433368683	C0A1D1	6509 550644	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov1969@postgrespro.ru", "phone": "+70873207009"}
0005433368684	C0A1D1	5662 407715	NADEZHDA ABRAMOVA	{"email": "abramovanadezhda.1970@postgrespro.ru", "phone": "+70953695504"}
0005433368685	417C59	8667 487694	NATALYA DENISOVA	{"email": "natalyadenisova_1964@postgrespro.ru", "phone": "+70836504701"}
0005433368686	85AE84	0242 100181	LILIYA SERGEEVA	{"phone": "+70530820486"}
0005433368687	0743AB	2102 085675	MARIYA KULIKOVA	{"email": "kulikova-m.1967@postgrespro.ru", "phone": "+70075955719"}
0005433368688	0743AB	5587 359960	LIDIYA KOROLEVA	{"email": "korolevalidiya_1968@postgrespro.ru", "phone": "+70150433111"}
0005433368689	E4EA7D	7964 636505	FLYURA BARANOVA	{"phone": "+70420862783"}
0005433368690	640859	9710 700678	EVGENIYA TITOVA	{"email": "e.titova08071979@postgrespro.ru", "phone": "+70504138662"}
0005433368691	396D6C	9501 135799	RAISA ABRAMOVA	{"email": "raisa.abramova_1972@postgrespro.ru", "phone": "+70109371082"}
0005433368692	4AC3CE	5061 455396	MARIYA SEMENOVA	{"phone": "+70725781837"}
0005433368693	4AC3CE	3777 209309	ANDREY MATVEEV	{"phone": "+70876963237"}
0005433368694	E77623	2581 699475	VASILIY KRASNOV	{"phone": "+70502976691"}
0005433368695	E77623	4761 116619	NIKOLAY POPOV	{"email": "nikolay.popov-1978@postgrespro.ru", "phone": "+70614004801"}
0005433368696	E77623	4043 503415	NIKOLAY GAVRILOV	{"phone": "+70569629627"}
0005433368697	C2070A	9946 833020	ALEKSANDR MOROZOV	{"phone": "+70023469727"}
0005433368698	602B21	9044 106878	PAVEL NIKOLAEV	{"email": "nikolaev-pavel-1972@postgrespro.ru", "phone": "+70043733906"}
0005433368699	AF8BCE	2772 644507	YURIY KRASNOV	{"email": "y_krasnov-05061969@postgrespro.ru", "phone": "+70940047405"}
0005433368700	AF8BCE	7361 550764	SERGEY MIRONOV	{"email": "mironov_s-28091970@postgrespro.ru", "phone": "+70649110682"}
0005433368701	F29A54	4126 846446	DARYA TIKHONOVA	{"email": "tikhonova.darya.101979@postgrespro.ru", "phone": "+70561963959"}
0005433368702	F29A54	4006 300208	ELENA MIRONOVA	{"email": "mironova-elena-081965@postgrespro.ru", "phone": "+70565586798"}
0005433368703	7FB3CB	0763 099706	ANNA MAKAROVA	{"email": "makarova-a-12021981@postgrespro.ru", "phone": "+70681103026"}
0005433368704	044561	6149 989680	TATYANA GAVRILOVA	{"email": "gavrilovat_1978@postgrespro.ru", "phone": "+70883666121"}
0005433368705	D4556C	7132 474098	MARIYA ALEKSEEVA	{"email": "alekseeva-mariya-03071975@postgrespro.ru", "phone": "+70516708912"}
0005433368706	D4556C	9231 131341	SVETLANA SIDOROVA	{"email": "sidorova.svetlana_1976@postgrespro.ru", "phone": "+70515964397"}
0005433368707	D4556C	3420 352237	IGOR DENISOV	{"email": "denisov-i1976@postgrespro.ru", "phone": "+70365853355"}
0005433368708	D46861	0688 821716	NATALYA MIKHAYLOVA	{"email": "mikhaylova-natalya10111968@postgrespro.ru", "phone": "+70644783194"}
0005433368709	D46861	6693 061851	IRINA FADEEVA	{"email": "fadeevai_1963@postgrespro.ru", "phone": "+70710430741"}
0005433368710	F38413	7542 071615	IRINA ISAEVA	{"phone": "+70003104594"}
0005433368711	B496B6	3079 438502	RUSLAN MIKHAYLOV	{"email": "ruslanmikhaylov1978@postgrespro.ru", "phone": "+70391982687"}
0005433368712	35BD6C	4371 556563	ANATOLIY DENISOV	{"email": "a_denisov-021953@postgrespro.ru", "phone": "+70246777294"}
0005433368713	307656	3930 889467	RADMIR SAVELEV	{"phone": "+70583990252"}
0005433368714	B1B8A6	5578 228642	VIKTOR CHERNOV	{"phone": "+70643929922"}
0005433368715	EB2927	6613 404729	ELENA KUZNECOVA	{"phone": "+70723676950"}
0005433368716	94B58B	8692 892352	ALEKSANDR IVANOV	{"email": "a.ivanov-1973@postgrespro.ru", "phone": "+70053297894"}
0005433368717	94B58B	5917 945744	TAMARA KOLESNIKOVA	{"email": "kolesnikova.tamara_1985@postgrespro.ru", "phone": "+70917479515"}
0005433368718	A24EA2	1998 317694	MARINA VASILEVA	{"phone": "+70443829750"}
0005433368719	5A706A	2285 489750	SERGEY SCHERBAKOV	{"email": "scherbakov-s.061982@postgrespro.ru", "phone": "+70053585938"}
0005433368720	C6FA4C	6373 554971	ROZA BORISOVA	{"phone": "+70087269329"}
0005433368721	C6FA4C	7672 552406	SVETLANA AFANASEVA	{"email": "svetlana.afanaseva-03121968@postgrespro.ru", "phone": "+70714974778"}
0005433368722	C6FA4C	9402 862054	VALENTINA GORBUNOVA	{"email": "gorbunova_valentina_071978@postgrespro.ru", "phone": "+70847844633"}
0005433368723	C03C6F	9937 595150	RINAT SOKOLOV	{"phone": "+70827725054"}
0005433368724	C63C54	9200 516007	DANIIL MELNIKOV	{"phone": "+70014711762"}
0005433368725	E1E87F	1726 410692	TAMARA KARPOVA	{"phone": "+70849322814"}
0005433368726	3776C4	8633 492897	KSENIYA BELYAEVA	{"email": "kseniyabelyaeva_1974@postgrespro.ru", "phone": "+70490105542"}
0005433368727	A59416	0136 663202	ANASTASIYA SERGEEVA	{"phone": "+70657694372"}
0005433368728	A59416	2693 041239	NIKITA BARANOV	{"email": "baranov.n.1978@postgrespro.ru", "phone": "+70952065858"}
0005433368729	6D550B	8355 995156	VASILISA KAZAKOVA	{"phone": "+70344621827"}
0005433368730	BFCAB3	6575 209447	NIKOLAY GAVRILOV	{"phone": "+70296520927"}
0005433368731	AD10E3	1056 966752	RAMILYA BARANOVA	{"phone": "+70762935204"}
0005433368732	7D3D56	5154 340693	ANASTASIYA RYABOVA	{"email": "ryabova_anastasiya.26081980@postgrespro.ru", "phone": "+70507510435"}
0005433368733	D42E60	0782 178168	IRINA POPOVA	{"email": "popovairina21091967@postgrespro.ru", "phone": "+70114035176"}
0005433368734	6DDED0	7417 509219	ALEKSANDR IVANOV	{"phone": "+70994863111"}
0005433368735	72AAD4	2714 640829	ARTEM SERGEEV	{"phone": "+70382447129"}
0005433368736	72AAD4	9323 794112	ALEKSEY NOVIKOV	{"email": "a_novikov1958@postgrespro.ru", "phone": "+70884352704"}
0005433368737	AB6E0A	9791 944472	GALINA MOROZOVA	{"phone": "+70383921690"}
0005433368738	6D023D	6739 105238	KLAVDIYA TIKHONOVA	{"email": "tikhonovaklavdiya011968@postgrespro.ru", "phone": "+70174354121"}
0005433368739	D5A6D6	4242 480846	VITALIY MATVEEV	{"email": "vitaliymatveev1974@postgrespro.ru", "phone": "+70240190838"}
0005433368740	477EA0	9267 103035	ANTONINA MIRONOVA	{"phone": "+70423877091"}
0005433368741	C54489	1474 774770	IRINA OSIPOVA	{"phone": "+70256025291"}
0005433368743	45C3A0	7243 419162	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov1977@postgrespro.ru", "phone": "+70928294897"}
0005433368744	008191	3650 653746	ALEKSANDR PETROV	{"email": "petrov.aleksandr.28091972@postgrespro.ru", "phone": "+70744500111"}
0005433368745	77E3DE	0876 761550	NATALYA STEPANOVA	{"phone": "+70845185135"}
0005433368746	77E3DE	5910 765783	POLINA MELNIKOVA	{"email": "melnikova.p-081968@postgrespro.ru", "phone": "+70760773210"}
0005433368747	77E3DE	6631 995426	VASILIY KUZNECOV	{"email": "vasiliy_kuznecov-26011964@postgrespro.ru", "phone": "+70974437834"}
0005433368748	77E3DE	6271 114300	IVAN NOVIKOV	{"email": "ivan-novikov_061974@postgrespro.ru", "phone": "+70521856807"}
0005433368749	E3C663	1387 719142	EKATERINA ROMANOVA	{"phone": "+70054740543"}
0005433368750	51E9C3	8756 874593	ALINA OSIPOVA	{"email": "osipova_alina.1978@postgrespro.ru", "phone": "+70914569004"}
0005433368751	51E9C3	2661 649024	NINA ZAKHAROVA	{"email": "nina-zakharova_1972@postgrespro.ru", "phone": "+70511020874"}
0005433368752	DE03F9	0666 820754	OLGA ALEKSEEVA	{"phone": "+70947625200"}
0005433368753	DE03F9	0069 642810	KHALIDA ORLOVA	{"phone": "+70540129401"}
0005433368754	73F655	5107 256374	RUSLAN PAVLOV	{"email": "ruslan-pavlov-041979@postgrespro.ru", "phone": "+70180762886"}
0005433368755	C787AB	2714 720758	PELAGEYA ZHUKOVA	{"email": "p_zhukova-1977@postgrespro.ru", "phone": "+70420810861"}
0005433368756	C787AB	8033 944328	VITALIY NOVIKOV	{"email": "novikovvitaliy-1982@postgrespro.ru", "phone": "+70767440560"}
0005433368757	30649D	7825 729990	GALINA BORISOVA	{"phone": "+70450414690"}
0005433368758	B33113	1471 758601	IRINA KOZLOVA	{"phone": "+70061091837"}
0005433368759	9BAEC5	0681 854319	EKATERINA OSIPOVA	{"phone": "+70760971065"}
0005433368760	9BAEC5	9590 482534	RUSLAN POPOV	{"email": "ruslan_popov.1965@postgrespro.ru", "phone": "+70705743912"}
0005433368761	2A3DDF	5633 112998	DENIS SOLOVEV	{"email": "denis_solovev051971@postgrespro.ru", "phone": "+70029461232"}
0005433368762	CABC45	7203 907664	ELENA NAUMOVA	{"phone": "+70945825825"}
0005433368763	CBE0C9	7003 154728	EVGENIY NAZAROV	{"email": "nazarovevgeniy.051963@postgrespro.ru", "phone": "+70112169459"}
0005433368764	CBE0C9	3972 031253	ALEKSANDR SIDOROV	{"phone": "+70889986567"}
0005433368765	49A8D5	5362 568164	YURIY KUDRYASHOV	{"phone": "+70113241306"}
0005433368766	7CCAD7	0050 067717	ALEKSANDR POPOV	{"email": "popovaleksandr_061979@postgrespro.ru", "phone": "+70313529215"}
0005433368767	7CCAD7	5722 367398	VIKTOR ZAYCEV	{"email": "zaycev.viktor_1979@postgrespro.ru", "phone": "+70593562964"}
0005433368768	E7BD88	2143 243970	VIKTORIYA PAVLOVA	{"email": "pavlova.viktoriya-041974@postgrespro.ru", "phone": "+70235188083"}
0005433368769	913B51	7695 677263	PETR ANTONOV	{"phone": "+70107482191"}
0005433368770	36692F	2292 982128	VLADIMIR MIRONOV	{"phone": "+70653806602"}
0005433368771	36692F	3447 199117	VERA DMITRIEVA	{"email": "v_dmitrieva081967@postgrespro.ru", "phone": "+70681071510"}
0005433368772	CB609D	9873 140605	LYUDMILA MOROZOVA	{"email": "morozoval1975@postgrespro.ru", "phone": "+70531692096"}
0005433368773	CB609D	0839 811746	KAMILLA IVANOVA	{"phone": "+70467010528"}
0005433368774	224D8A	1962 513043	ELENA LUKYANOVA	{"phone": "+70097153517"}
0005433368775	C8542E	9902 711190	ELENA MARTYNOVA	{"email": "e_martynova-061975@postgrespro.ru", "phone": "+70382701268"}
0005433368776	CB1E96	2384 648995	MARIYA RYABOVA	{"email": "ryabova-m.06011968@postgrespro.ru", "phone": "+70231324979"}
0005433368777	CB1E96	6930 485405	EKATERINA GORBUNOVA	{"phone": "+70498794354"}
0005433368778	F430A5	2700 172734	ALEVTINA KALININA	{"phone": "+70845670845"}
0005433368779	F430A5	7936 114520	LYUDMILA RYABOVA	{"phone": "+70349379009"}
0005433368780	776598	5342 132257	LYUBOV SERGEEVA	{"email": "lyubov_sergeeva_051969@postgrespro.ru", "phone": "+70438454903"}
0005433368781	E0C2A3	7532 745073	ELENA SAVELEVA	{"phone": "+70462093300"}
0005433368782	E0C2A3	3634 235550	DMITRIY GERASIMOV	{"email": "gerasimov_dmitriy-15111974@postgrespro.ru", "phone": "+70216472732"}
0005433368783	8E59A7	2660 536462	LARISA KONOVALOVA	{"phone": "+70185383227"}
0005433368784	79E11C	1723 344733	OLGA KUZNECOVA	{"phone": "+70690323060"}
0005433368785	79E11C	3594 643784	DIANA NESTEROVA	{"email": "nesterovadiana.101969@postgrespro.ru", "phone": "+70968895769"}
0005433368786	0345C3	4864 766911	KRISTINA SOLOVEVA	{"email": "ksoloveva.13041983@postgrespro.ru", "phone": "+70678840580"}
0005433368787	FDC18A	9917 696276	LYUDMILA ANISIMOVA	{"email": "l-anisimova_31081964@postgrespro.ru", "phone": "+70335241094"}
0005433368788	93E38C	1271 810206	ALFIYA SOLOVEVA	{"phone": "+70327183705"}
0005433368789	633FC0	8809 910199	ANDREY MAKAROV	{"email": "makarov-a14121967@postgrespro.ru", "phone": "+70757341502"}
0005433368790	FC81E8	5237 652532	VERONIKA OSIPOVA	{"email": "osipova_v_1971@postgrespro.ru", "phone": "+70401599328"}
0005433368791	8E3895	3459 238903	ANASTASIYA KRASNOVA	{"phone": "+70942858637"}
0005433368792	8E3895	8462 888894	ANNA NIKIFOROVA	{"phone": "+70582968930"}
0005433368793	2ABBAE	7305 311783	SERGEY KUZNECOV	{"email": "kuznecov-s011979@postgrespro.ru", "phone": "+70010874948"}
0005433368794	341318	8067 059022	VASILIY NIKOLAEV	{"email": "v_nikolaev.15091969@postgrespro.ru", "phone": "+70818666604"}
0005433368795	341318	9461 511308	DMITRIY MAKAROV	{"phone": "+70786262136"}
0005433368796	4B1006	4541 695323	ROZA NESTEROVA	{"phone": "+70945996401"}
0005433368797	5353A5	0390 648128	VALENTINA SAVELEVA	{"email": "saveleva-v_1971@postgrespro.ru", "phone": "+70114238273"}
0005433368798	049829	8711 064662	NIKOLAY FEDOROV	{"phone": "+70634638719"}
0005433368799	37CCA4	2054 005566	EKATERINA BORISOVA	{"phone": "+70538267887"}
0005433368800	AAB3E3	2482 578846	ANDREY SEMENOV	{"email": "semenovandrey.051991@postgrespro.ru", "phone": "+70476442184"}
0005433368801	AAB3E3	9842 080304	ELENA IVANOVA	{"email": "e.ivanova_13011969@postgrespro.ru", "phone": "+70969536370"}
0005433368802	256BEA	1743 649674	VLADIMIR MAKAROV	{"email": "makarov_v-101972@postgrespro.ru", "phone": "+70232652508"}
0005433368803	E164E7	2577 281843	IVAN STEPANOV	{"email": "ivan.stepanov.26011965@postgrespro.ru", "phone": "+70991021504"}
0005433368804	E59725	0477 690964	FEDOR DMITRIEV	{"phone": "+70142517187"}
0005433368805	EEE1D9	9898 221020	LIDIYA CHERNOVA	{"phone": "+70578462597"}
0005433368806	F16A4F	0070 094416	OKSANA NAZAROVA	{"email": "nazarova.o_031969@postgrespro.ru", "phone": "+70961729123"}
0005433368807	F16A4F	6520 537500	VADIM TIKHONOV	{"email": "vadim_tikhonov-11031984@postgrespro.ru", "phone": "+70961345847"}
0005433368808	F16A4F	8790 241854	VLADIMIR MOROZOV	{"email": "vmorozov02111976@postgrespro.ru", "phone": "+70237332553"}
0005433368809	D255BD	7069 582909	VLADIMIR ROMANOV	{"phone": "+70937109377"}
0005433368810	46B3B2	8848 101850	MAKSIM ANTONOV	{"phone": "+70397576250"}
0005433368811	873130	9882 887840	NINA ZAYCEVA	{"email": "n_zayceva-14071971@postgrespro.ru", "phone": "+70087364248"}
0005433368812	10F791	1479 303366	RAISA MALYSHEVA	{"email": "raisamalysheva.09051975@postgrespro.ru", "phone": "+70526115752"}
0005433368813	867410	2515 703893	EKATERINA YAKOVLEVA	{"email": "e.yakovleva1969@postgrespro.ru", "phone": "+70715759119"}
0005433368814	949CF5	9287 919171	VADIM KULIKOV	{"email": "kulikovvadim03101970@postgrespro.ru", "phone": "+70776579849"}
0005433368815	949CF5	0171 376980	EKATERINA MATVEEVA	{"email": "matveeva_e.1969@postgrespro.ru", "phone": "+70917542297"}
0005433368816	3E4535	3003 261261	EVGENIY TARASOV	{"email": "tarasov-e28121967@postgrespro.ru", "phone": "+70294764799"}
0005433368817	3E4535	9757 309544	PETR AFANASEV	{"email": "afanasevp_1958@postgrespro.ru", "phone": "+70290643527"}
0005433368818	AF6F50	8121 191283	DENIS FILIPPOV	{"email": "filippov_denis.27091974@postgrespro.ru", "phone": "+70895548003"}
0005433368819	4F9B67	1759 627384	YANA POTAPOVA	{"phone": "+70653905484"}
0005433368820	4F9B67	4217 104046	ALEKSEY FROLOV	{"email": "frolov.a1975@postgrespro.ru", "phone": "+70593317592"}
0005433368821	D39DEF	8534 307610	SVETLANA MAKAROVA	{"phone": "+70878137200"}
0005433368822	D39DEF	4771 297087	EDGAR SEMENOV	{"email": "semenov-edgar-091967@postgrespro.ru", "phone": "+70666969337"}
0005433368823	B3F520	1893 684958	MARIYA MIRONOVA	{"email": "m.mironova_031972@postgrespro.ru", "phone": "+70797427999"}
0005433368824	51020B	4340 207918	ANASTASIYA KUDRYASHOVA	{"email": "kudryashovaa_1974@postgrespro.ru", "phone": "+70918801144"}
0005433368825	00D03D	1518 933055	RUSLAN MELNIKOV	{"email": "melnikov_ruslan-1964@postgrespro.ru", "phone": "+70313055371"}
0005433368826	AD81F8	1214 792987	IRINA SOLOVEVA	{"email": "soloveva_i-071975@postgrespro.ru", "phone": "+70355772801"}
0005433368827	3A5876	9384 868815	TATYANA FEDOROVA	{"email": "fedorovatatyana1966@postgrespro.ru", "phone": "+70712644276"}
0005433368828	2A1D1F	1492 954000	DAVID ROMANOV	{"phone": "+70833875136"}
0005433368829	C3D143	6562 809259	ALEKSEY MOROZOV	{"email": "alekseymorozov.051973@postgrespro.ru", "phone": "+70179515047"}
0005433368830	F72215	0118 948707	OLGA IVANOVA	{"phone": "+70374405561"}
0005433368831	F72215	3551 651162	MARIYA KALININA	{"email": "kalinina_m.111970@postgrespro.ru", "phone": "+70997063155"}
0005433368832	751655	9314 844716	LYUDMILA SMIRNOVA	{"phone": "+70376613729"}
0005433368833	65292B	2681 451484	ALEKSANDR ISAEV	{"email": "isaev.a.071975@postgrespro.ru", "phone": "+70223260432"}
0005433368834	65292B	0678 942933	VALERIY YAKOVLEV	{"email": "valeriy_yakovlev-1962@postgrespro.ru", "phone": "+70554071497"}
0005433368835	0253BE	7712 827442	ANDREY KULIKOV	{"phone": "+70928267661"}
0005433368836	0253BE	8391 929217	VYACHESLAV BELOV	{"email": "belovvyacheslav.30111976@postgrespro.ru", "phone": "+70492302840"}
0005433368837	0253BE	0915 837956	GENNADIY IVANOV	{"email": "gennadiy_ivanov.25111963@postgrespro.ru", "phone": "+70246093213"}
0005433368838	95A3B9	9356 325556	ELENA BORISOVA	{"email": "borisovaelena.1965@postgrespro.ru", "phone": "+70484027819"}
0005433368839	E40F9A	3402 730154	ALEKSEY ANDREEV	{"phone": "+70639648564"}
0005433368840	BC083F	7208 175759	VIKTOR ILIN	{"email": "viktorilin-09071978@postgrespro.ru", "phone": "+70146248745"}
0005433368841	6C78D0	0525 992321	ANDREY ALEKSEEV	{"email": "alekseev-andrey.071970@postgrespro.ru", "phone": "+70347420845"}
0005433368842	EF7219	7596 547417	VLADIMIR VLASOV	{"email": "vladimir-vlasov09061967@postgrespro.ru", "phone": "+70829435314"}
0005433368843	3F3114	8215 017224	MARINA EFIMOVA	{"email": "efimovam_1978@postgrespro.ru", "phone": "+70966786534"}
0005433368844	C390E0	6853 450678	ANTON NIKOLAEV	{"email": "anikolaev121972@postgrespro.ru", "phone": "+70699919769"}
0005433368845	BF8D86	3625 348836	ALEKSANDRA NIKITINA	{"phone": "+70522355837"}
0005433368846	BF8D86	1637 039427	TATYANA IVANOVA	{"email": "t_ivanova-28101968@postgrespro.ru", "phone": "+70295340900"}
0005433368847	BF8D86	3279 154517	YULIYA MASLOVA	{"phone": "+70478251156"}
0005433368848	7AB339	8859 686255	SERGEY NOVIKOV	{"phone": "+70338698110"}
0005433368849	A9934F	8988 277453	MARIYA BARANOVA	{"phone": "+70742826528"}
0005433368850	A143F4	0180 253256	ZINAIDA PAVLOVA	{"email": "pavlova-zinaida_16041967@postgrespro.ru", "phone": "+70904919558"}
0005433368851	A143F4	9039 983954	ANDREY VASILEV	{"email": "andrey.vasilev_03011973@postgrespro.ru", "phone": "+70969710227"}
0005433368852	85D151	7694 283930	GALINA ISAEVA	{"email": "gisaeva.03021975@postgrespro.ru", "phone": "+70265356263"}
0005433368853	85D151	9986 636237	TAGIR FEDOTOV	{"email": "fedotovtagir_01071975@postgrespro.ru", "phone": "+70739712542"}
0005433368854	45251D	1663 910876	BORIS FROLOV	{"email": "frolov-b-081972@postgrespro.ru", "phone": "+70143649710"}
0005433368855	BAA3D8	7142 897083	DENIS NIKOLAEV	{"email": "denisnikolaev.121978@postgrespro.ru", "phone": "+70899813279"}
0005433368856	7E5BA4	5174 703658	ALEKSANDR MEDVEDEV	{"email": "aleksandr.medvedev.071976@postgrespro.ru", "phone": "+70531170636"}
0005433368857	6523F5	8627 854852	OLGA IVANOVA	{"phone": "+70235470753"}
0005433368858	6523F5	3037 779112	ARTEM ILIN	{"phone": "+70621535935"}
0005433368859	2704A6	0972 410881	NADEZHDA DMITRIEVA	{"email": "dmitrieva-nadezhda-061970@postgrespro.ru", "phone": "+70052125637"}
0005433368860	2704A6	6685 670368	VYACHESLAV NAZAROV	{"email": "nazarov.vyacheslav.03051970@postgrespro.ru", "phone": "+70096409019"}
0005433368861	CA03D6	0369 092004	YULIYA POPOVA	{"phone": "+70597915627"}
0005433368862	CA03D6	4032 654897	ALEKSANDR KRASNOV	{"phone": "+70014466376"}
0005433368863	A45F8D	8194 443616	IVAN NAZAROV	{"email": "nazarov.i-29011963@postgrespro.ru", "phone": "+70311336059"}
0005433368864	8B34B0	0161 038996	VALENTINA KONDRATEVA	{"phone": "+70734550596"}
0005433368865	8B34B0	8865 250988	MARIYA YAKOVLEVA	{"email": "yakovleva.mariya_1967@postgrespro.ru", "phone": "+70666898148"}
0005433368866	312AFA	0202 157976	VITALIY DMITRIEV	{"email": "dmitrievvitaliy-13051971@postgrespro.ru", "phone": "+70857037710"}
0005433368867	7603DD	7887 774509	EKATERINA ANISIMOVA	{"phone": "+70881641847"}
0005433368868	030EA2	0681 629357	VADIM KONOVALOV	{"email": "konovalov_vadim.041978@postgrespro.ru", "phone": "+70996659959"}
0005433368869	BB2AE3	1049 830760	ALEKSANDR ROMANOV	{"email": "romanov-a-25051975@postgrespro.ru", "phone": "+70453229166"}
0005433368870	D2E834	6760 929636	VALERIY NAUMOV	{"phone": "+70863766030"}
0005433368871	4BE94F	4030 652727	ZINAIDA VASILEVA	{"phone": "+70122084475"}
0005433368872	5BF0BB	2886 154155	VYACHESLAV MAKSIMOV	{"email": "maksimov_vyacheslav-1975@postgrespro.ru", "phone": "+70662857034"}
0005433368873	059037	5897 816781	MIKHAIL YAKOVLEV	{"email": "yakovlev-m-1965@postgrespro.ru", "phone": "+70939364809"}
0005433368874	52ED0B	5817 709082	ANDREY YAKOVLEV	{"email": "a-yakovlev_03111968@postgrespro.ru", "phone": "+70028837360"}
0005433368875	52ED0B	8666 683051	IRINA PETROVA	{"email": "irina_petrova-03041965@postgrespro.ru", "phone": "+70473821528"}
0005433368876	1E5EBD	5511 755009	TATYANA VOLKOVA	{"email": "tatyana-volkova.17101966@postgrespro.ru", "phone": "+70513194527"}
0005433368877	02B2D8	1047 264029	NINA FROLOVA	{"email": "frolova_nina.051978@postgrespro.ru", "phone": "+70399447132"}
0005433368878	02B2D8	9876 999181	NIKOLAY BORISOV	{"email": "nikolay.borisov.03121973@postgrespro.ru", "phone": "+70441647384"}
0005433368879	FAD776	6592 097877	GALINA KUZMINA	{"phone": "+70990297496"}
0005433368880	32CC70	3796 143989	ALEKSANDR KUZMIN	{"phone": "+70470838534"}
0005433368881	2B3F97	3295 580078	SERGEY MAKSIMOV	{"email": "maksimovsergey-061982@postgrespro.ru", "phone": "+70365875474"}
0005433368882	9D7F57	1329 044910	ALEKSEY VOROBEV	{"email": "avorobev_121969@postgrespro.ru", "phone": "+70355502716"}
0005433368883	3962BD	2907 981989	VLADIMIR MOROZOV	{"phone": "+70241333247"}
0005433368884	2F8F5F	4317 183849	ALEKSANDR NIKOLAEV	{"phone": "+70949266230"}
0005433368885	2F8F5F	9231 327100	VLADIMIR ISAEV	{"email": "v.isaev_121977@postgrespro.ru", "phone": "+70482192903"}
0005433368886	2F8F5F	3985 309467	YULIYA KAZAKOVA	{"email": "kazakova_y111963@postgrespro.ru", "phone": "+70563715422"}
0005433368887	E0779F	8913 815544	MAKSIM SMIRNOV	{"phone": "+70898354973"}
0005433368888	362808	3397 607505	ALENA MALYSHEVA	{"phone": "+70388133006"}
0005433368889	33AFCA	2249 380202	PETR CHERNOV	{"email": "chernov_petr-081984@postgrespro.ru", "phone": "+70874769410"}
0005433368890	549208	0909 148856	NINA BORISOVA	{"phone": "+70335355998"}
0005433368891	D8B93C	7698 257236	SERGEY PETROV	{"phone": "+70783563726"}
0005433368892	2B005B	0182 769621	MAKSIM TIKHONOV	{"phone": "+70209037004"}
0005433368893	A012A7	1550 638014	VLADIMIR FEDOROV	{"email": "vladimir-fedorov_1960@postgrespro.ru", "phone": "+70541082395"}
0005433368894	A012A7	7548 374828	KONSTANTIN OSIPOV	{"phone": "+70036762839"}
0005433368895	70DD85	7520 420157	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-03031969@postgrespro.ru", "phone": "+70807957448"}
0005433368896	70DD85	4491 400160	ANNA LAZAREVA	{"phone": "+70700918864"}
0005433368897	BE377F	2013 443842	DMITRIY PAVLOV	{"phone": "+70792672750"}
0005433368898	AAEA73	2399 338023	ELENA STEPANOVA	{"phone": "+70357930975"}
0005433368899	39E0F3	2139 512280	NATALYA NIKOLAEVA	{"phone": "+70272636066"}
0005433368900	2A7AA7	6656 212062	MIKHAIL AFANASEV	{"email": "mafanasev121966@postgrespro.ru", "phone": "+70996570035"}
0005433368901	2A7AA7	9086 584104	ANDREY ORLOV	{"phone": "+70777586348"}
0005433368902	40FA2E	0093 558018	TATYANA TITOVA	{"phone": "+70901935897"}
0005433368903	A1DF25	7299 159170	MIKHAIL ISAEV	{"phone": "+70340313969"}
0005433368904	A1DF25	3790 971969	PAVEL GERASIMOV	{"email": "gerasimov-p.02061977@postgrespro.ru", "phone": "+70173207866"}
0005433368905	089B7B	3632 438440	ALEKSANDR POPOV	{"phone": "+70276593856"}
0005433368906	EABC8B	1661 877524	TATYANA VASILEVA	{"phone": "+70675722654"}
0005433368907	F40733	6100 453894	MAKSIM KUZNECOV	{"phone": "+70131892664"}
0005433368908	7360FC	0408 772977	ANTONINA SOKOLOVA	{"email": "antonina-sokolova-15111974@postgrespro.ru", "phone": "+70765827020"}
0005433368909	734EC2	2077 311833	OKSANA PAVLOVA	{"email": "pavlova.o061966@postgrespro.ru", "phone": "+70389549869"}
0005433368910	27F0EE	2689 005360	NINA ANTONOVA	{"phone": "+70025179491"}
0005433368911	A12391	9015 691116	LILIYA BELOVA	{"phone": "+70566137669"}
0005433368912	071BB8	3112 440488	ALEKSANDR TARASOV	{"phone": "+70893618722"}
0005433368913	071BB8	3102 470590	ALEKSANDR EGOROV	{"phone": "+70200104422"}
0005433368914	071BB8	5986 262997	SERGEY POPOV	{"phone": "+70417806469"}
0005433368915	68B304	4051 843307	MARAT IVANOV	{"email": "ivanovm04101974@postgrespro.ru", "phone": "+70863769109"}
0005433368916	A90B06	2064 695228	ELENA PAVLOVA	{"email": "elenapavlova-041981@postgrespro.ru", "phone": "+70892688794"}
0005433368917	EE80EB	5292 225695	SERGEY PAVLOV	{"email": "pavlov.s-081972@postgrespro.ru", "phone": "+70677453745"}
0005433368918	F4820B	0451 896732	VALENTINA POPOVA	{"phone": "+70788883143"}
0005433368919	F4820B	1104 085769	POLINA BORISOVA	{"email": "polinaborisova1970@postgrespro.ru", "phone": "+70256009580"}
0005433368920	41C87A	0796 255577	VALERIY KAZAKOV	{"phone": "+70168397578"}
0005433368921	1439CC	2087 568631	ZHANNA KUZNECOVA	{"phone": "+70288138140"}
0005433368922	1439CC	3937 657513	ALEKSANDR KUZNECOV	{"phone": "+70661712676"}
0005433368923	C9D4C1	3295 083931	ILYA KULIKOV	{"phone": "+70037789363"}
0005433368924	124609	1494 922254	ILYA GRIGOREV	{"email": "grigorev-ilya19061975@postgrespro.ru", "phone": "+70101597933"}
0005433368925	7E8329	6372 561372	ELENA KULIKOVA	{"email": "kulikova_elena-1971@postgrespro.ru", "phone": "+70772358098"}
0005433368926	7E8329	0303 093431	ALEKSANDR MAKAROV	{"phone": "+70940949962"}
0005433368927	DD5120	2288 301444	LYUBOV KOROLEVA	{"email": "lkoroleva-10011960@postgrespro.ru", "phone": "+70905000578"}
0005433368928	DD5120	5674 721694	LILIYA CHERNOVA	{"email": "chernova_l.31051979@postgrespro.ru", "phone": "+70858342406"}
0005433368929	DD5120	3702 550570	EVGENIY MAKAROV	{"phone": "+70324326418"}
0005433368930	B0B14C	0273 747373	YURIY POPOV	{"email": "popov-yuriy_12011968@postgrespro.ru", "phone": "+70569268629"}
0005433368931	B0B14C	0366 545339	ANNA TARASOVA	{"phone": "+70576756517"}
0005433368932	54FE41	4122 347383	YULIYA POPOVA	{"phone": "+70430445557"}
0005433368933	07C5BF	1445 277989	YULIYA IVANOVA	{"phone": "+70952757659"}
0005433368934	CB5C57	4297 338360	PETR ZAYCEV	{"email": "petr.zaycev_1980@postgrespro.ru", "phone": "+70473554728"}
0005433368935	D7773F	3384 049474	ELENA KONOVALOVA	{"email": "konovalova-e-1969@postgrespro.ru", "phone": "+70778869273"}
0005433368936	D7773F	7023 962717	SAVELIY MIRONOV	{"phone": "+70964460323"}
0005433368937	71E281	7586 212591	NIKOLAY ANDREEV	{"phone": "+70821833865"}
0005433368938	AD74A3	5131 953615	NURIYA KONDRATEVA	{"phone": "+70064883385"}
0005433368939	06DBDC	4781 362347	TATYANA KONDRATEVA	{"phone": "+70031284218"}
0005433368940	06DBDC	3844 475434	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr-1973@postgrespro.ru", "phone": "+70999414476"}
0005433368941	06DBDC	4352 921745	ANDREY BELOV	{"email": "andrey_belov.1983@postgrespro.ru", "phone": "+70906645681"}
0005433368942	B2558A	1161 621584	FARIT MATVEEV	{"phone": "+70230170278"}
0005433368943	0C9993	3660 277113	ALLA KRASNOVA	{"phone": "+70695855201"}
0005433368944	504166	5006 603501	DENIS RODIONOV	{"email": "rodionov.d08051982@postgrespro.ru", "phone": "+70548246422"}
0005433368945	D82EE9	0006 173343	VYACHESLAV POPOV	{"email": "popov-v_1967@postgrespro.ru", "phone": "+70733557201"}
0005433368946	8BF44D	7525 752453	DMITRIY MEDVEDEV	{"phone": "+70451060026"}
0005433368947	4D5589	7815 807812	VYACHESLAV IVANOV	{"email": "v_ivanov24101965@postgrespro.ru", "phone": "+70081023528"}
0005433368948	B438E5	6453 249421	KLAVDIYA NIKIFOROVA	{"email": "k-nikiforova-061967@postgrespro.ru", "phone": "+70626304767"}
0005433368949	91154B	4677 477462	YURIY MIRONOV	{"phone": "+70695548092"}
0005433368950	91154B	1260 884702	DMITRIY VASILEV	{"email": "vasilevd-1972@postgrespro.ru", "phone": "+70624154845"}
0005433368951	885F0D	2152 636630	VALENTINA TIMOFEEVA	{"phone": "+70912232343"}
0005433368952	BFC969	9744 514341	ALFIYA NIKOLAEVA	{"phone": "+70609121095"}
0005433368953	BFC969	5336 656033	ALEKSANDR FEDOTOV	{"phone": "+70481169706"}
0005433368954	48CDC2	0363 897116	VLADIMIR PAVLOV	{"phone": "+70686589013"}
0005433368955	48CDC2	4383 412441	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr-1966@postgrespro.ru", "phone": "+70435754644"}
0005433368956	48CDC2	8296 925670	OKSANA EFIMOVA	{"email": "o_efimova041952@postgrespro.ru", "phone": "+70117661085"}
0005433368957	695B07	2625 321673	MAKSIM VASILEV	{"email": "mvasilev.101982@postgrespro.ru", "phone": "+70237874017"}
0005433368958	695B07	0033 509691	DANIIL VOROBEV	{"email": "vorobevd1964@postgrespro.ru", "phone": "+70682160715"}
0005433368959	F76D93	7558 307247	NADEZHDA IVANOVA	{"email": "nadezhda_ivanova-031971@postgrespro.ru", "phone": "+70046793613"}
0005433368960	704DFA	5449 744664	ALEKSANDR ILIN	{"phone": "+70746413518"}
0005433368961	9D5B30	6117 126175	NATALYA IVANOVA	{"phone": "+70935815054"}
0005433368962	9D5B30	2869 262878	OLEG CHERNOV	{"phone": "+70708448837"}
0005433368963	CBD54B	7791 378976	ANDREY TIMOFEEV	{"email": "andrey_timofeev_101976@postgrespro.ru", "phone": "+70221146554"}
0005433368964	33291E	6199 340320	VALENTINA PETROVA	{"phone": "+70492350393"}
0005433368965	670751	1665 638756	EKATERINA SOKOLOVA	{"phone": "+70600946954"}
0005433368966	41D7B6	3606 689838	GRIGORIY DMITRIEV	{"phone": "+70226742401"}
0005433368967	71DCE4	1010 971245	ALEKSANDR EGOROV	{"phone": "+70462911523"}
0005433368968	71DCE4	0901 418238	LYUBOV GUSEVA	{"phone": "+70337619687"}
0005433368969	821E35	9896 555205	RAFAIL KUZNECOV	{"phone": "+70452858663"}
0005433368970	6A3FE7	3765 477737	EVGENIY BARANOV	{"phone": "+70379933322"}
0005433368971	3817E5	8293 165450	PAVEL SOROKIN	{"phone": "+70074440974"}
0005433368972	3817E5	0306 575174	TATYANA MAKSIMOVA	{"email": "t_maksimova121962@postgrespro.ru", "phone": "+70041208585"}
0005433368973	04C718	8842 491957	ANTON MIKHAYLOV	{"phone": "+70988210189"}
0005433368974	A5717C	2856 259882	TAMARA GRISHINA	{"phone": "+70167036776"}
0005433368975	A21495	4485 584281	VLADIMIR PETROV	{"email": "petrov_v-071970@postgrespro.ru", "phone": "+70001674821"}
0005433368976	1D4CBA	2166 501674	LIDIYA POPOVA	{"email": "l_popova.07041972@postgrespro.ru", "phone": "+70343722932"}
0005433368977	F7A31B	9757 496966	TATYANA GUSEVA	{"email": "tatyana-guseva-25011961@postgrespro.ru", "phone": "+70444304365"}
0005433368978	F7A31B	1091 078806	VIKTOR ANDREEV	{"email": "andreev_viktor_1962@postgrespro.ru", "phone": "+70868462304"}
0005433368979	7CCC2A	9575 351120	ALEKSANDR ZAYCEV	{"email": "zaycevaleksandr121977@postgrespro.ru", "phone": "+70373732945"}
0005433368980	CAC9F3	1633 033734	VALENTINA GAVRILOVA	{"email": "v.gavrilova-22081984@postgrespro.ru", "phone": "+70926172555"}
0005433368981	AD4E7B	6006 153211	VASILIY GRIGOREV	{"email": "grigorevv_25091972@postgrespro.ru", "phone": "+70196482611"}
0005433368982	AD4E7B	6674 848646	ALEKSANDR FROLOV	{"email": "aleksandrfrolov_1980@postgrespro.ru", "phone": "+70151422641"}
0005433373374	2F18F4	2081 189991	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko.081968@postgrespro.ru", "phone": "+70799891931"}
0005433373375	BDA091	6083 924697	EVGENIY POPOV	{"email": "epopov-1978@postgrespro.ru", "phone": "+70628587809"}
0005433373376	57CD50	3080 758018	DMITRIY BONDARENKO	{"phone": "+70568214649"}
0005433373377	054554	0150 045073	ANASTASIYA OSIPOVA	{"email": "osipova-a.041976@postgrespro.ru", "phone": "+70142249984"}
0005433373378	054554	9052 492365	LYUCIYA ORLOVA	{"email": "lyuciyaorlova.21011967@postgrespro.ru", "phone": "+70375827626"}
0005433373379	25E8F8	6839 459666	VALENTINA FEDOROVA	{"phone": "+70617380416"}
0005433373380	894A14	7108 898138	TATYANA MAKAROVA	{"email": "makarova_t_11101966@postgrespro.ru", "phone": "+70841831172"}
0005433373381	894A14	7988 133590	ANNA OVCHINNIKOVA	{"email": "ovchinnikova.anna.18111985@postgrespro.ru", "phone": "+70499243822"}
0005433373382	69BD56	3572 505602	LILIYA FILIPPOVA	{"phone": "+70318319540"}
0005433373383	46A100	0254 381977	ANATOLIY SAVELEV	{"email": "a.savelev091971@postgrespro.ru", "phone": "+70379596827"}
0005433373384	46A100	1999 115736	ALEKSANDR MIKHAYLOV	{"phone": "+70981819821"}
0005433373385	F8B7CA	2153 712817	FARIDA KUZNECOVA	{"phone": "+70966460628"}
0005433373386	B78D4E	3494 918664	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova-07021966@postgrespro.ru", "phone": "+70495403625"}
0005433373387	B78D4E	7178 450484	IRINA VLASOVA	{"phone": "+70313220151"}
0005433373388	E77598	2238 025176	SERGEY VLASOV	{"email": "sergey-vlasov_1978@postgrespro.ru", "phone": "+70022844021"}
0005433373389	E77598	7635 160347	MARIYA SOROKINA	{"email": "msorokina-1972@postgrespro.ru", "phone": "+70140446293"}
0005433373390	E77598	5778 703622	LYUBOV ORLOVA	{"phone": "+70473773842"}
0005433373391	CD2DF9	8518 683642	ANDREY NAZAROV	{"email": "andreynazarov_22061979@postgrespro.ru", "phone": "+70362695852"}
0005433373392	92BD51	4483 740659	GALINA ERMAKOVA	{"phone": "+70390009459"}
0005433373393	31F35B	3242 058282	IGOR KUZNECOV	{"phone": "+70136210659"}
0005433373394	C87A06	9396 203014	GALINA ZOTOVA	{"email": "zotova-galina_101970@postgrespro.ru", "phone": "+70300673616"}
0005433373395	C87A06	7544 524457	RIMA BELOVA	{"email": "belova_rima09071968@postgrespro.ru", "phone": "+70797497641"}
0005433373396	C87A06	4626 187983	MARINA GUSEVA	{"phone": "+70246399349"}
0005433373397	C7ED74	3122 529146	VASILIY SIDOROV	{"phone": "+70088325111"}
0005433373398	FA1DA5	5050 350181	DMITRIY VASILEV	{"phone": "+70652792148"}
0005433373399	C9DF37	1997 912993	LYUBOV MELNIKOVA	{"email": "melnikovalyubov07051973@postgrespro.ru", "phone": "+70456098963"}
0005433373400	C9DF37	1955 480179	MARIYA SOROKINA	{"email": "sorokina.m-1979@postgrespro.ru", "phone": "+70631877688"}
0005433373401	F59DE6	1749 975676	ALEKSANDR KONOVALOV	{"email": "konovalov-a_10051968@postgrespro.ru", "phone": "+70171841946"}
0005433373402	F59DE6	2934 868281	ROZALIYA ZOTOVA	{"phone": "+70676426437"}
0005433373403	ED93B0	7476 173388	LIDIYA ANDREEVA	{"phone": "+70918823684"}
0005433373404	ED93B0	7774 434447	ELENA EFIMOVA	{"email": "efimovaelena1967@postgrespro.ru", "phone": "+70922583479"}
0005433373405	F1E504	9752 076400	GENNADIY BORISOV	{"email": "borisovg021969@postgrespro.ru", "phone": "+70313200501"}
0005433373406	F1E504	1409 769956	ALEKSANDR PETROV	{"phone": "+70998545128"}
0005433373407	897F08	5399 637364	YURIY IVANOV	{"email": "yuriy.ivanov.07041974@postgrespro.ru", "phone": "+70663636206"}
0005433373408	897F08	9052 521760	EVGENIY KUZNECOV	{"email": "e-kuznecov-1967@postgrespro.ru", "phone": "+70602934870"}
0005433373409	97A4C4	2559 368488	ILYA PETROV	{"email": "petrov_i-081971@postgrespro.ru", "phone": "+70828571286"}
0005433373410	97A4C4	7131 635753	IGOR ANTONOV	{"phone": "+70739299866"}
0005433373411	2E6D89	7584 091556	RUSTEM KAZAKOV	{"email": "kazakov-r091977@postgrespro.ru", "phone": "+70253764537"}
0005433373412	5B7A6A	3702 382116	VALERIY SOKOLOV	{"phone": "+70608394056"}
0005433373413	B63FB9	1719 510084	EKATERINA SMIRNOVA	{"email": "smirnovaekaterina-14011954@postgrespro.ru", "phone": "+70544380695"}
0005433373414	B02FFC	5873 918393	SERGEY VASILEV	{"phone": "+70067469214"}
0005433373415	516629	7413 764690	RUSLAN VOROBEV	{"email": "r-vorobev.1975@postgrespro.ru", "phone": "+70012085336"}
0005433373416	BE354B	6755 518260	SERGEY VASILEV	{"phone": "+70676466633"}
0005433373417	26064E	6320 050757	EVGENIY FOMIN	{"phone": "+70144905958"}
0005433373418	978D88	7684 830679	DMITRIY ZAKHAROV	{"email": "zakharov_d_01121968@postgrespro.ru", "phone": "+70567911140"}
0005433373419	0A1855	2750 707849	ANASTASIYA BOGDANOVA	{"email": "bogdanovaanastasiya-05081957@postgrespro.ru", "phone": "+70088233052"}
0005433373420	74129A	3639 572934	VASILIY ROMANOV	{"email": "romanovv_031976@postgrespro.ru", "phone": "+70808407133"}
0005433373421	A40E2A	2735 818496	SERGEY ANTONOV	{"phone": "+70963304701"}
0005433373422	66CB8A	3894 319418	ALENA DENISOVA	{"phone": "+70959565493"}
0005433373423	9485F1	1448 535022	MARIYA ANDREEVA	{"phone": "+70108393042"}
0005433373424	9485F1	3337 870626	ANNA TROFIMOVA	{"phone": "+70595046758"}
0005433373425	9485F1	1584 537342	KIRILL GERASIMOV	{"email": "kirill.gerasimov-071966@postgrespro.ru", "phone": "+70140930695"}
0005433373426	4FDA5C	7944 669659	NADEZHDA STEPANOVA	{"phone": "+70493512641"}
0005433373427	BC2768	1872 315153	ALINA KUDRYASHOVA	{"phone": "+70718865558"}
0005433373428	2C2AE0	5985 045496	LYUDMILA TROFIMOVA	{"phone": "+70522356568"}
0005433373429	1F4466	0959 840592	NATALYA MOROZOVA	{"phone": "+70042971758"}
0005433373430	C6A398	4080 680514	VALERIY ORLOV	{"email": "orlov-v-1981@postgrespro.ru", "phone": "+70655582071"}
0005433373431	C6A398	4158 355922	SVETLANA KISELEVA	{"phone": "+70054403322"}
0005433373432	CE3E34	9272 990190	ALEKSANDR NOVIKOV	{"phone": "+70896644825"}
0005433373433	CFF4A1	1409 126638	NADEZHDA ZHUKOVA	{"email": "zhukova.n.061982@postgrespro.ru", "phone": "+70799279871"}
0005433373434	CFF4A1	6011 692277	IVAN GUSEV	{"email": "gusev_ivan_1973@postgrespro.ru", "phone": "+70176869747"}
0005433373435	94C716	9311 388306	ANDREY KUDRYASHOV	{"email": "andreykudryashov.16081970@postgrespro.ru", "phone": "+70243673855"}
0005433373436	BF1968	3671 664980	SERGEY SMIRNOV	{"email": "smirnovsergey1972@postgrespro.ru", "phone": "+70069966718"}
0005433373437	BF1968	6976 411673	OLGA ABRAMOVA	{"phone": "+70480836175"}
0005433373438	94A721	4860 119683	EVGENIYA ZHURAVLEVA	{"phone": "+70333744611"}
0005433373439	6CA1A4	6709 163302	ANNA ZAKHAROVA	{"phone": "+70884822367"}
0005433373440	22F3B1	9413 467265	ZHANNA PAVLOVA	{"email": "zpavlova.30091975@postgrespro.ru", "phone": "+70765361542"}
0005433373441	BF3B76	5219 613907	IRINA FOMINA	{"phone": "+70418380766"}
0005433373442	555E6E	6835 970248	ARSENIY BORISOV	{"email": "borisov.arseniy.1984@postgrespro.ru", "phone": "+70536195433"}
0005433373443	9DFD4B	9991 929299	VALENTIN KOZLOV	{"phone": "+70712942586"}
0005433373444	93A120	4599 029340	SERGEY IVANOV	{"email": "s_ivanov_10051969@postgrespro.ru", "phone": "+70172298548"}
0005433373445	D159D6	7253 343547	NATALYA EGOROVA	{"phone": "+70479363300"}
0005433373446	3070B7	3306 109341	EKATERINA IVANOVA	{"phone": "+70308423560"}
0005433373447	86A943	8746 093660	VLADIMIR KULIKOV	{"email": "v-kulikov1982@postgrespro.ru", "phone": "+70208738618"}
0005433373448	9B6095	5505 756986	MARIYA ANTONOVA	{"phone": "+70410867552"}
0005433373449	314EB5	4564 067383	OLGA BOGDANOVA	{"phone": "+70131564328"}
0005433373450	314EB5	0235 487782	NIKOLAY MIRONOV	{"email": "nmironov-11051983@postgrespro.ru", "phone": "+70460506119"}
0005433373451	CC138D	0704 036784	ELENA EFREMOVA	{"phone": "+70604603329"}
0005433373452	BAAD89	5101 171761	SVETLANA SOLOVEVA	{"email": "soloveva-s-1974@postgrespro.ru", "phone": "+70384692364"}
0005433373453	DD0424	0729 450980	YULIYA NAUMOVA	{"email": "ynaumova.1970@postgrespro.ru", "phone": "+70444002320"}
0005433373454	9B2067	9008 045767	NINA FROLOVA	{"phone": "+70939624586"}
0005433373455	943FBA	8731 283364	NIKOLAY RODIONOV	{"email": "rodionov.nikolay31101971@postgrespro.ru", "phone": "+70091198225"}
0005433373456	7DC3DE	8236 923753	ALEKSANDR CHERNOV	{"email": "chernovaleksandr-121985@postgrespro.ru", "phone": "+70461643339"}
0005433373457	31CC9E	7627 087357	ALENA MIKHAYLOVA	{"phone": "+70212418423"}
0005433373458	C48853	8257 126677	KSENIYA BARANOVA	{"email": "baranova.kseniya-051970@postgrespro.ru", "phone": "+70420928093"}
0005433373459	D9F9E1	2120 533065	YULIYA IVANOVA	{"email": "yivanova03081977@postgrespro.ru", "phone": "+70775936390"}
0005433373460	D9F9E1	1319 332055	NATALYA DENISOVA	{"phone": "+70121233654"}
0005433373461	D9F9E1	3830 209918	ILGIZ SERGEEV	{"email": "i_sergeev1980@postgrespro.ru", "phone": "+70082792508"}
0005433373462	8D0B4D	7077 381493	SVETLANA VLASOVA	{"email": "svetlanavlasova101972@postgrespro.ru", "phone": "+70307092428"}
0005433373463	3EFBCA	3181 939875	SERGEY SOLOVEV	{"phone": "+70559284634"}
0005433373464	3EFBCA	8839 452065	DMITRIY KOROLEV	{"phone": "+70169498167"}
0005433373465	1DA781	7941 975569	RUSLAN ANTONOV	{"email": "r_antonov-041975@postgrespro.ru", "phone": "+70137621256"}
0005433373466	5A4924	3845 618114	MARIYA TIMOFEEVA	{"email": "mariya.timofeeva_1958@postgrespro.ru", "phone": "+70756963834"}
0005433373467	5A4924	9024 596245	ZINAIDA LUKYANOVA	{"phone": "+70803048998"}
0005433373468	A9BC5C	4568 243606	VERONIKA MEDVEDEVA	{"phone": "+70775178912"}
0005433373469	A9BC5C	4005 398377	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr.22041973@postgrespro.ru", "phone": "+70125439670"}
0005433373470	D7B9A1	8388 931090	VENERA GORBUNOVA	{"email": "vgorbunova-1974@postgrespro.ru", "phone": "+70686097660"}
0005433373471	ED7795	7270 976968	STANISLAV FOMIN	{"email": "fomin_s_061977@postgrespro.ru", "phone": "+70572142050"}
0005433373472	C9BCCB	4933 716108	ANZHELA MAKAROVA	{"email": "makarova-anzhela-021975@postgrespro.ru", "phone": "+70877186449"}
0005433373473	E6C03D	9976 503631	VASILIY KOZLOV	{"phone": "+70778410380"}
0005433373474	79BA99	7486 514260	ALENA PETROVA	{"email": "alena.petrova.011979@postgrespro.ru", "phone": "+70057899414"}
0005433373475	2D493B	3843 941670	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy02041971@postgrespro.ru", "phone": "+70348636138"}
0005433373476	2D493B	7179 083628	ANTONINA POPOVA	{"email": "antoninapopova-1981@postgrespro.ru", "phone": "+70332719972"}
0005433373477	01090C	7060 227770	LARISA ZAKHAROVA	{"phone": "+70845743687"}
0005433373478	F0AD5C	3366 883853	NATALYA MELNIKOVA	{"phone": "+70455908106"}
0005433373479	3CC2BD	0183 040743	TATYANA GERASIMOVA	{"phone": "+70865285091"}
0005433373480	6DC11F	1266 457787	SAMVEL NOVIKOV	{"phone": "+70758516281"}
0005433373481	2BD20F	6864 372710	ELENA AKIMOVA	{"email": "e_akimova_091961@postgrespro.ru", "phone": "+70033332237"}
0005433373482	2BD20F	7977 678632	VALENTINA OSIPOVA	{"email": "valentinaosipova_011980@postgrespro.ru", "phone": "+70766163765"}
0005433373483	2BD20F	3297 962323	NELLI IVANOVA	{"phone": "+70270666452"}
0005433373484	899954	4523 845633	TATYANA KONDRATEVA	{"email": "t-kondrateva_1971@postgrespro.ru", "phone": "+70697210837"}
0005433373485	A0BB23	6681 792330	ILYA NOVIKOV	{"phone": "+70617506446"}
0005433373486	8794E1	4840 364077	ALEKSANDR TIMOFEEV	{"phone": "+70285412533"}
0005433373487	66553F	5217 816938	TATYANA PETROVA	{"email": "t_petrova.12061974@postgrespro.ru", "phone": "+70728819676"}
0005433373488	AD9EB7	0120 110524	ELENA KUZNECOVA	{"phone": "+70265572968"}
0005433373489	AD9EB7	8229 862020	ANNA ANDREEVA	{"phone": "+70610321525"}
0005433373490	82B0DF	6062 668141	NINA MALYSHEVA	{"phone": "+70931515529"}
0005433373491	DC5361	5225 377602	SVETLANA TIKHONOVA	{"email": "svetlana.tikhonova_21081972@postgrespro.ru", "phone": "+70827137991"}
0005433373492	DC5361	8046 159096	TATYANA SERGEEVA	{"email": "tatyana_sergeeva.05121972@postgrespro.ru", "phone": "+70558736302"}
0005433373493	349DF7	1232 371859	GALINA SERGEEVA	{"email": "sergeevagalina24051967@postgrespro.ru", "phone": "+70085463185"}
0005433373494	684C40	5045 627379	NINA FEDOROVA	{"email": "n.fedorova-29071977@postgrespro.ru", "phone": "+70820075745"}
0005433373495	D60B33	5190 182274	MATRENA MATVEEVA	{"phone": "+70492417586"}
0005433373496	E2348B	5730 556121	ZINAIDA TIKHONOVA	{"phone": "+70507943260"}
0005433373497	08CBC3	6014 576784	MAKSIM VLASOV	{"email": "vlasov-m.1974@postgrespro.ru", "phone": "+70393933208"}
0005433373498	08CBC3	1749 462818	LYUBOV VOLKOVA	{"email": "volkova_lyubov-29041978@postgrespro.ru", "phone": "+70457129735"}
0005433373499	08CBC3	5631 558579	KIRILL ISAEV	{"email": "k_isaev091966@postgrespro.ru", "phone": "+70955279581"}
0005433373500	AF86AD	9216 548342	ANATOLIY GAVRILOV	{"phone": "+70393702720"}
0005433373501	AF86AD	9670 172024	NIKOLAY MAKAROV	{"phone": "+70092370555"}
0005433373502	AE794D	2039 939311	LYUBOV SIDOROVA	{"email": "sidorova.l_1981@postgrespro.ru", "phone": "+70308278225"}
0005433373503	AE794D	2731 582755	IVAN KUZNECOV	{"email": "ivankuznecov-1972@postgrespro.ru", "phone": "+70051510341"}
0005433373504	25676B	2378 864089	ELENA TIKHONOVA	{"phone": "+70662184026"}
0005433373505	9DC860	1212 933745	ZHANNA ROMANOVA	{"phone": "+70997498507"}
0005433373506	99D9AF	4449 908258	ZOYA FOMINA	{"phone": "+70061683215"}
0005433373507	D48CFC	5431 938117	ALEKSANDR SMIRNOV	{"phone": "+70781521423"}
0005433373508	D48CFC	1618 456694	ELISEY GRIGOREV	{"email": "egrigorev_031963@postgrespro.ru", "phone": "+70651263364"}
0005433373509	91047F	5747 510429	IGOR BORISOV	{"phone": "+70838758423"}
0005433373510	A98BE2	2654 345533	SERGEY TIMOFEEV	{"email": "s-timofeev_1962@postgrespro.ru", "phone": "+70441931391"}
0005433373511	1A482D	8913 014912	ANTONINA MOROZOVA	{"email": "morozova-antonina_1962@postgrespro.ru", "phone": "+70208921769"}
0005433373512	222CEB	9263 708053	MARINA MOROZOVA	{"phone": "+70447746237"}
0005433373513	222CEB	3958 616419	ANDREY ISAEV	{"email": "isaev.andrey1969@postgrespro.ru", "phone": "+70888727502"}
0005433373514	657F67	6465 773048	VERA GAVRILOVA	{"email": "gavrilovav.30051964@postgrespro.ru", "phone": "+70037034200"}
0005433373515	657F67	1073 841316	ELENA ZHURAVLEVA	{"phone": "+70447938088"}
0005433373516	2FA688	1993 164007	VASILIY FEDOROV	{"phone": "+70972092128"}
0005433373517	0F76EE	6762 205862	NATALIYA IVANOVA	{"phone": "+70355810259"}
0005433373518	F4F1BA	9680 124431	VLADIMIR MATVEEV	{"phone": "+70012187508"}
0005433373519	0E414C	7890 012223	VERA ZAYCEVA	{"email": "zayceva_vera_041968@postgrespro.ru", "phone": "+70812739944"}
0005433373520	5A52FD	3163 171367	VERA RYABOVA	{"phone": "+70387953435"}
0005433373521	5A52FD	6199 036900	MIKHAIL KULIKOV	{"email": "mkulikov051969@postgrespro.ru", "phone": "+70848367991"}
0005433373522	A6DF4C	6261 339661	EKATERINA VOLKOVA	{"email": "evolkova1965@postgrespro.ru", "phone": "+70071058168"}
0005433373523	11A1B7	7830 021169	LYUDMILA KUZNECOVA	{"phone": "+70403998081"}
0005433373524	E4F8CC	4897 536066	MARINA MOISEEVA	{"email": "moiseevam.29051977@postgrespro.ru", "phone": "+70141683498"}
0005433373525	D74197	0589 665590	MAKSIM SERGEEV	{"phone": "+70571233222"}
0005433373526	996D09	0082 483178	RENAT SIDOROV	{"phone": "+70941961122"}
0005433373527	996D09	7185 133069	VLADISLAV SOLOVEV	{"phone": "+70777423485"}
0005433373528	996D09	0075 166076	TATYANA POPOVA	{"email": "tatyanapopova121964@postgrespro.ru", "phone": "+70370282439"}
0005433373529	31BAD9	8410 558487	TATYANA SMIRNOVA	{"phone": "+70942272294"}
0005433373530	2375C6	7226 824002	MARIYA DMITRIEVA	{"phone": "+70458966186"}
0005433373531	CA02CC	2384 427671	NIKOLAY MIRONOV	{"phone": "+70001819180"}
0005433373532	FF5B0A	5505 355394	VITALIY ILIN	{"email": "ilin_vitaliy1985@postgrespro.ru", "phone": "+70511770956"}
0005433373533	B46C58	1675 909528	MARIYA POPOVA	{"phone": "+70487564601"}
0005433373534	B46C58	1548 892252	ANNA SOKOLOVA	{"phone": "+70537126095"}
0005433373535	D5414D	7033 309590	ROMAN IVANOV	{"phone": "+70057206027"}
0005433373536	2A36C8	5529 738217	VLADIMIR EGOROV	{"phone": "+70572575836"}
0005433373537	2A36C8	2906 207050	OLGA ZAYCEVA	{"phone": "+70053689834"}
0005433373538	313952	2136 062721	DARYA MIRONOVA	{"phone": "+70353077510"}
0005433373539	313952	3924 188638	ALEKSANDR VLASOV	{"email": "aleksandrvlasov1961@postgrespro.ru", "phone": "+70635059686"}
0005433373540	9081A1	5748 851743	NATALIYA ZHUKOVA	{"phone": "+70468942639"}
0005433373541	19069D	5106 767811	ANGELINA CHERNOVA	{"phone": "+70639144133"}
0005433373542	F73D05	7273 567477	DENIS VOLKOV	{"email": "volkov.denis-011969@postgrespro.ru", "phone": "+70735475466"}
0005433373543	DAB502	9781 564258	GALINA ROMANOVA	{"phone": "+70290698645"}
0005433373544	DAB502	1252 348334	RIMMA KUZNECOVA	{"phone": "+70600808572"}
0005433373545	ECEA01	4197 869266	ANDREY STEPANOV	{"phone": "+70303594361"}
0005433373546	63A2F6	0131 716927	VALENTINA KUZNECOVA	{"phone": "+70730169208"}
0005433373547	39FF63	4155 868732	GENNADIY FILIPPOV	{"email": "filippov-g1967@postgrespro.ru", "phone": "+70748271870"}
0005433373548	39FF63	1485 101020	OLEG PAVLOV	{"email": "oleg_pavlov-29071973@postgrespro.ru", "phone": "+70059808062"}
0005433373549	56D833	3079 577373	DANILA CHERNOV	{"email": "chernovd_081984@postgrespro.ru", "phone": "+70168272968"}
0005433373550	56D833	9725 894835	OLEG IVANOV	{"email": "ivanov.oleg111971@postgrespro.ru", "phone": "+70744004116"}
0005433373551	EEB1E1	6207 143655	VALENTINA KOZLOVA	{"email": "v-kozlova02041969@postgrespro.ru", "phone": "+70838868966"}
0005433373552	1EF4C7	1643 994171	SVETLANA ANDREEVA	{"email": "andreeva.svetlana-101963@postgrespro.ru", "phone": "+70024552842"}
0005433373553	59CD52	5168 201952	VLADIMIR FROLOV	{"email": "frolov_v_1974@postgrespro.ru", "phone": "+70586189467"}
0005433373554	BBE1C4	8069 074311	NADEZHDA NIKOLAEVA	{"phone": "+70725961294"}
0005433373555	86B7B5	6228 803905	LYUDMILA ZAKHAROVA	{"phone": "+70173470956"}
0005433373556	5E980E	1555 641900	IRINA GUSEVA	{"email": "guseva_i_15051972@postgrespro.ru", "phone": "+70088942395"}
0005433373557	5E980E	6069 959940	SERGEY MOISEEV	{"email": "smoiseev-1971@postgrespro.ru", "phone": "+70121207973"}
0005433373558	AA0939	5558 378590	ALEKSEY BORISOV	{"phone": "+70228033121"}
0005433373559	11EBBB	6514 700332	OLESYA FADEEVA	{"email": "olesyafadeeva08011975@postgrespro.ru", "phone": "+70997013884"}
0005433373560	11EBBB	1549 016888	ALEVTINA LUKYANOVA	{"phone": "+70184867390"}
0005433373561	D63259	9438 812634	YULIYA NOVIKOVA	{"email": "y_novikova1972@postgrespro.ru", "phone": "+70454902226"}
0005433373562	9C0C3E	9453 468849	ANNA ROMANOVA	{"email": "anna_romanova-1972@postgrespro.ru", "phone": "+70104990490"}
0005433373620	4AE8EC	1670 444801	ELENA ZAKHAROVA	{"phone": "+70006096775"}
0005433373563	9C0C3E	9219 476075	VASILIY YAKOVLEV	{"email": "yakovlev.v071989@postgrespro.ru", "phone": "+70537292237"}
0005433373564	A01917	7125 195258	VLADISLAV KISELEV	{"phone": "+70242796342"}
0005433373565	A01917	5849 992691	MARINA NAZAROVA	{"email": "marina-nazarova_1976@postgrespro.ru", "phone": "+70075932586"}
0005433373566	057818	5061 185732	SVETLANA ABRAMOVA	{"email": "abramova.s20121971@postgrespro.ru", "phone": "+70972554542"}
0005433373567	057818	0113 968396	VIKTOR MARTYNOV	{"email": "v_martynov_1965@postgrespro.ru", "phone": "+70100943001"}
0005433373568	5600E5	9894 021067	NATALYA MOROZOVA	{"email": "natalya-morozova.08091975@postgrespro.ru", "phone": "+70517730935"}
0005433373569	5600E5	7825 310842	LYUDMILA ROMANOVA	{"email": "romanova-lyudmila.061973@postgrespro.ru", "phone": "+70296461288"}
0005433373570	5600E5	4041 844769	ALENA SOKOLOVA	{"email": "alena-sokolova_1976@postgrespro.ru", "phone": "+70986455247"}
0005433373571	5600E5	4836 861369	EKATERINA FEDOROVA	{"email": "ekaterinafedorova.16031969@postgrespro.ru", "phone": "+70683840832"}
0005433373572	1D7425	2528 378899	EVDOKIYA ALEKSEEVA	{"phone": "+70970542535"}
0005433373573	1D7425	3121 112859	RAISA NIKOLAEVA	{"email": "nikolaeva-raisa_28021973@postgrespro.ru", "phone": "+70472696540"}
0005433373574	1D7425	9097 823590	MAKSIM VASILEV	{"phone": "+70217327944"}
0005433373575	5CBC49	8375 111627	PAVEL MIRONOV	{"phone": "+70841052277"}
0005433373576	5C7C3A	4332 942325	LYUDMILA VASILEVA	{"email": "l_vasileva10031976@postgrespro.ru", "phone": "+70130113651"}
0005433373577	5C7C3A	5260 163405	SERGEY KULIKOV	{"phone": "+70520575226"}
0005433373578	EC60E6	1816 977347	VALENTINA POLYAKOVA	{"email": "polyakova-valentina1969@postgrespro.ru", "phone": "+70866751809"}
0005433373579	EC60E6	6901 348078	EVGENIY EGOROV	{"email": "egorovevgeniy16061977@postgrespro.ru", "phone": "+70031965443"}
0005433373580	76E0BC	3764 383397	RENATA KULIKOVA	{"email": "r_kulikova.19101960@postgrespro.ru", "phone": "+70161862387"}
0005433373581	76E0BC	1232 106267	SERGEY KUZNECOV	{"email": "kuznecovs1968@postgrespro.ru", "phone": "+70418599237"}
0005433373582	50F6D2	8027 253762	MARINA ALEKSEEVA	{"email": "alekseevamarina_1983@postgrespro.ru", "phone": "+70874908572"}
0005433373583	0B7A79	2480 708726	DMITRIY SHEVCHENKO	{"email": "shevchenko_dmitriy1972@postgrespro.ru", "phone": "+70507312896"}
0005433373584	36542E	6542 328895	EVGENIY DMITRIEV	{"email": "edmitriev1960@postgrespro.ru", "phone": "+70453287291"}
0005433373585	7CE576	7111 048181	DMITRIY IVANOV	{"phone": "+70801239124"}
0005433373586	F3A096	7183 221466	ANDREY SAVELEV	{"email": "savelev.a1980@postgrespro.ru", "phone": "+70254917285"}
0005433373587	F3A096	4991 214155	VLADIMIR PETROV	{"email": "vladimir.petrov-1963@postgrespro.ru", "phone": "+70234157515"}
0005433373588	75FB8E	5582 301466	DMITRIY FILIPPOV	{"email": "dmitriy-filippov-1969@postgrespro.ru", "phone": "+70283278980"}
0005433373589	75FB8E	2376 641367	DARYA NIKOLAEVA	{"phone": "+70144885595"}
0005433373590	B61401	7992 629809	ALEKSEY VOLKOV	{"email": "volkov.a_1974@postgrespro.ru", "phone": "+70831317676"}
0005433373591	B61401	2324 502006	ALEKSEY ISAEV	{"email": "isaev-aleksey_23101970@postgrespro.ru", "phone": "+70231276578"}
0005433373592	2D140D	5947 069308	NIKITA BELOV	{"phone": "+70270390133"}
0005433373593	8BEF01	8282 660290	ANATOLIY POPOV	{"phone": "+70799211062"}
0005433373594	8BEF01	5751 327863	ZINAIDA MEDVEDEVA	{"email": "z.medvedeva08041978@postgrespro.ru", "phone": "+70040370113"}
0005433373595	D4B7B9	1194 322233	ANNA KUZMINA	{"email": "kuzmina-anna-1964@postgrespro.ru", "phone": "+70421015824"}
0005433373596	375D9D	2233 295869	NIKOLAY PETROV	{"phone": "+70682338910"}
0005433373597	50AB4B	4768 430536	DARYA KUZNECOVA	{"email": "darya_kuznecova-1978@postgrespro.ru", "phone": "+70714664917"}
0005433373598	50AB4B	3450 418750	ANNA MIRONOVA	{"phone": "+70778843664"}
0005433373599	00BB3B	5075 669517	YURIY DMITRIEV	{"email": "dmitrievy.1980@postgrespro.ru", "phone": "+70335650313"}
0005433373600	7FED0C	0346 244732	YULIYA IVANOVA	{"phone": "+70957430403"}
0005433373601	1B0E6F	5379 456301	OLGA KRASNOVA	{"email": "krasnova-olga1972@postgrespro.ru", "phone": "+70671120612"}
0005433373602	7D1CDE	3737 025738	ARTEM VASILEV	{"email": "vasilev.artem011980@postgrespro.ru", "phone": "+70654056908"}
0005433373603	253D9A	9165 213624	ELENA SEMENOVA	{"phone": "+70675970666"}
0005433373604	253D9A	5088 141617	DMITRIY MIKHAYLOV	{"email": "dmikhaylov.1979@postgrespro.ru", "phone": "+70295884999"}
0005433373605	B25471	4469 278599	EVGENIY SIDOROV	{"email": "sidorov.evgeniy20031966@postgrespro.ru", "phone": "+70033284962"}
0005433373606	3076DC	8822 426329	VALENTINA ORLOVA	{"email": "orlova_v24121965@postgrespro.ru", "phone": "+70910364000"}
0005433373607	648E79	8289 592611	DMITRIY SOROKIN	{"email": "sorokin_dmitriy17081981@postgrespro.ru", "phone": "+70146517497"}
0005433373608	648E79	0284 552602	EVGENIY SOROKIN	{"phone": "+70744917255"}
0005433373609	D92FDF	7499 849863	SERGEY PAVLOV	{"email": "s_pavlov1963@postgrespro.ru", "phone": "+70773984117"}
0005433373610	D92FDF	0648 494151	ELENA SAVELEVA	{"phone": "+70727414641"}
0005433373611	7C9B99	9612 179297	DMITRIY EGOROV	{"email": "egorov.d_01111975@postgrespro.ru", "phone": "+70232578045"}
0005433373612	712D3F	7788 260057	PETR PETROV	{"phone": "+70912929147"}
0005433373613	712D3F	4918 547917	SERGEY PETROV	{"email": "s-petrov1976@postgrespro.ru", "phone": "+70756050340"}
0005433373614	B0CA17	9386 838108	VLADIMIR IVANOV	{"email": "v.ivanov21111971@postgrespro.ru", "phone": "+70983479094"}
0005433373615	B0CA17	5453 720243	MARINA KUZNECOVA	{"email": "marina-kuznecova-1982@postgrespro.ru", "phone": "+70220843111"}
0005433373616	B0CA17	4971 476584	DENIS MEDVEDEV	{"email": "d_medvedev.03031968@postgrespro.ru", "phone": "+70532381558"}
0005433373617	B0CA17	1180 660545	ALEKSANDR DMITRIEV	{"email": "a.dmitriev_1977@postgrespro.ru", "phone": "+70025132090"}
0005433373618	496D60	4437 799995	OLGA IVANOVA	{"email": "ivanova_o.031966@postgrespro.ru", "phone": "+70723190100"}
0005433373619	C936C7	1669 353675	POLINA KOROLEVA	{"phone": "+70057336609"}
0005433373621	A781E2	5150 125889	MARIYA ZAKHAROVA	{"phone": "+70493372644"}
0005433373622	6E6F6D	7256 637689	INNA KISELEVA	{"email": "kiseleva_i.101976@postgrespro.ru", "phone": "+70032498818"}
0005433373623	7F3C63	8591 145358	LYUDMILA SCHERBAKOVA	{"phone": "+70305908317"}
0005433373624	B1DF06	0105 509093	VALERIY KUZNECOV	{"phone": "+70136657175"}
0005433373625	8B9304	5864 680532	ELENA IVANOVA	{"email": "ivanova-e10021979@postgrespro.ru", "phone": "+70004469156"}
0005433373626	8B9304	6113 105870	NATALYA KONOVALOVA	{"phone": "+70760713329"}
0005433373627	8B9304	5922 170096	EVGENIYA KOZLOVA	{"email": "kozlova_e-061966@postgrespro.ru", "phone": "+70025377773"}
0005433373628	00462F	4555 249143	KONSTANTIN MIKHAYLOV	{"phone": "+70179472399"}
0005433373629	E0A000	2382 240457	MIKHAIL ZHURAVLEV	{"email": "zhuravlev-m-071966@postgrespro.ru", "phone": "+70810415117"}
0005433373630	D56C24	9416 714682	ANGELINA KOZLOVA	{"email": "angelina-kozlova-1966@postgrespro.ru", "phone": "+70128505044"}
0005433373631	D56C24	6920 790647	EKATERINA SERGEEVA	{"phone": "+70527133936"}
0005433373632	16535C	6412 701081	GALINA MELNIKOVA	{"email": "melnikova_g19031968@postgrespro.ru", "phone": "+70909080058"}
0005433373633	16535C	5169 943225	ELENA AKIMOVA	{"email": "e-akimova.091973@postgrespro.ru", "phone": "+70653679067"}
0005433373634	6C9461	7324 691098	NADEZHDA EGOROVA	{"phone": "+70043381628"}
0005433373635	6C9461	3579 598782	GENNADIY DENISOV	{"email": "gennadiy_denisov.1976@postgrespro.ru", "phone": "+70503925110"}
0005433373636	6C9461	9028 951112	GALINA BOGDANOVA	{"phone": "+70269658286"}
0005433373637	808427	9803 939504	ALEKSANDR FEDOROV	{"phone": "+70342933537"}
0005433373638	FA09B2	5080 519698	TAMARA SAVELEVA	{"email": "savelevatamara.1974@postgrespro.ru", "phone": "+70794374326"}
0005433373639	FA09B2	7837 912860	VITALIY MIKHAYLOV	{"phone": "+70079189407"}
0005433373640	5CFB57	2483 786354	YULIYA LAZAREVA	{"email": "lazareva.yuliya-20061960@postgrespro.ru", "phone": "+70450926295"}
0005433373641	5CFB57	9099 761681	ALEKSEY IVANOV	{"email": "ivanov_aleksey1963@postgrespro.ru", "phone": "+70829385048"}
0005433373642	4C608E	1761 444634	ZLATA FADEEVA	{"phone": "+70194764617"}
0005433373643	19F99C	1023 775434	VALERIY SHEVCHENKO	{"email": "shevchenko-v_041972@postgrespro.ru", "phone": "+70948245851"}
0005433373644	41A00C	4904 947267	VALENTINA KOZLOVA	{"phone": "+70946435332"}
0005433373645	2846A6	6286 248940	VALENTINA SOROKINA	{"phone": "+70403064961"}
0005433373646	2846A6	5651 516017	SERGEY IVANOV	{"phone": "+70049601345"}
0005433373647	50CF6D	0087 204927	DENIS SCHERBAKOV	{"phone": "+70537410152"}
0005433373648	B8C338	0010 052047	VALENTINA SMIRNOVA	{"email": "smirnova_valentina1969@postgrespro.ru", "phone": "+70373690964"}
0005433373649	DE65D4	7693 170974	ELENA SERGEEVA	{"email": "sergeevae_101974@postgrespro.ru", "phone": "+70273896781"}
0005433373650	DE65D4	1015 015463	VALENTINA FROLOVA	{"phone": "+70011333074"}
0005433373651	DA5891	1030 454523	DENIS DAVYDOV	{"email": "ddavydov.041967@postgrespro.ru", "phone": "+70342383219"}
0005433373652	DA5891	1869 788284	ANDREY SAVELEV	{"phone": "+70522781991"}
0005433373653	50FEFC	5254 402403	MAKSIM ABRAMOV	{"email": "m-abramov_03071969@postgrespro.ru", "phone": "+70021006863"}
0005433373654	375365	2775 335253	EVGENIY KUZMIN	{"email": "kuzmin-e-101984@postgrespro.ru", "phone": "+70141372495"}
0005433373655	563239	2276 252704	ARINA KOVALEVA	{"phone": "+70721007104"}
0005433373656	E6A908	4460 054106	LYUDMILA KUZNECOVA	{"phone": "+70261898028"}
0005433373657	B91968	0518 968238	IVAN ZAYCEV	{"phone": "+70519750810"}
0005433373658	264D0B	3955 693853	TATYANA ORLOVA	{"email": "t.orlova.14111970@postgrespro.ru", "phone": "+70466833654"}
0005433373659	C95F19	9107 954567	OLGA MIRONOVA	{"phone": "+70426861591"}
0005433373660	6A3DAD	4560 688399	NINA ANTONOVA	{"phone": "+70397956089"}
0005433373661	D9FAD3	8899 245209	GEORGIY IVANOV	{"phone": "+70310280717"}
0005433373662	201511	6764 083769	NATALYA FROLOVA	{"phone": "+70886835835"}
0005433373663	1D7D56	3367 083218	KSENIYA MIKHAYLOVA	{"phone": "+70826388884"}
0005433373664	5AE11C	6023 813596	ANATOLIY KAZAKOV	{"phone": "+70882933659"}
0005433373665	AB2B17	5514 055177	ANTON MAKAROV	{"phone": "+70370400763"}
0005433373666	E655ED	0513 338113	SHAMIL IVANOV	{"phone": "+70553637232"}
0005433373667	E655ED	8874 840986	NADEZHDA OVCHINNIKOVA	{"email": "nadezhda-ovchinnikova22091971@postgrespro.ru", "phone": "+70480495977"}
0005433373668	A6FDD7	7425 637337	NIKOLAY VOLKOV	{"email": "volkov.n.24111984@postgrespro.ru", "phone": "+70665906237"}
0005433373669	A6FDD7	6241 898485	VASILIY STEPANOV	{"email": "v_stepanov.01101954@postgrespro.ru", "phone": "+70402896057"}
0005433373670	11F98F	7052 117332	VALENTINA MALYSHEVA	{"email": "valentina-malysheva_111980@postgrespro.ru", "phone": "+70964706970"}
0005433373671	11F98F	9641 306386	MARGARITA NIKITINA	{"email": "margarita_nikitina1959@postgrespro.ru", "phone": "+70685066926"}
0005433373672	11F98F	3138 828705	ALEKSANDRA ZAKHAROVA	{"phone": "+70122298915"}
0005433373673	3130B5	7942 280021	MAKSIM DMITRIEV	{"email": "dmitriev-maksim121969@postgrespro.ru", "phone": "+70239047604"}
0005433373674	E3AF23	0772 761884	ZOYA KUZNECOVA	{"email": "zoya_kuznecova091970@postgrespro.ru", "phone": "+70709894111"}
0005433373675	A5805D	3884 126223	VLADIMIR CHERNOV	{"email": "chernov.v_1961@postgrespro.ru", "phone": "+70330220182"}
0005433373676	8E7EC4	9312 927206	ANDREY KUZNECOV	{"email": "kuznecov_andrey-051973@postgrespro.ru", "phone": "+70842888288"}
0005433373677	8E7EC4	4782 640013	VYACHESLAV ALEKSANDROV	{"email": "vyacheslav_aleksandrov061978@postgrespro.ru", "phone": "+70046021308"}
0005433373678	7C6985	2908 180557	ALEKSANDRA ZOTOVA	{"phone": "+70333215443"}
0005433373679	7C6985	0304 239233	EKATERINA FROLOVA	{"email": "frolova.ekaterina1967@postgrespro.ru", "phone": "+70164132379"}
0005433373680	7C6985	1513 629174	LIDIYA MAKAROVA	{"email": "makaroval_1967@postgrespro.ru", "phone": "+70527277578"}
0005433373681	1A263B	5459 089786	TATYANA KOVALEVA	{"phone": "+70051333350"}
0005433373682	1A263B	1906 000443	RAISA VASILEVA	{"email": "r.vasileva-051966@postgrespro.ru", "phone": "+70115484864"}
0005433373683	1A263B	8848 830630	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov.1964@postgrespro.ru", "phone": "+70691261469"}
0005433373684	4137B7	4339 955945	ILYA PAVLOV	{"email": "pavlov_ilya.011975@postgrespro.ru", "phone": "+70738152482"}
0005433373685	8A48D8	4170 230744	IVAN FROLOV	{"email": "ivan_frolov-1966@postgrespro.ru", "phone": "+70317044061"}
0005433373686	8A48D8	5369 030246	LIDIYA SOKOLOVA	{"email": "sokolova_l22021978@postgrespro.ru", "phone": "+70354839714"}
0005433373687	D0F247	0921 931074	ANNA PAVLOVA	{"phone": "+70739556179"}
0005433373688	D0F247	7060 975161	NIKOLAY ZAYCEV	{"phone": "+70581670900"}
0005433373689	3B079F	7631 550491	SERGEY KAZAKOV	{"phone": "+70611424886"}
0005433373690	5608F9	9448 578641	ANATOLIY IVANOV	{"email": "a-ivanov-101977@postgrespro.ru", "phone": "+70481366834"}
0005433373691	BCC93F	8333 787011	VLADIMIR AFANASEV	{"email": "afanasev-v_1977@postgrespro.ru", "phone": "+70641240775"}
0005433373692	044B99	7334 493144	SERGEY SEMENOV	{"phone": "+70558760068"}
0005433373693	044B99	1338 172031	LEONID PETROV	{"email": "petrov_leonid-091962@postgrespro.ru", "phone": "+70375316365"}
0005433373694	D0D71D	2300 929605	MARIYA TIKHONOVA	{"email": "tikhonova-mariya.02081971@postgrespro.ru", "phone": "+70952490726"}
0005433373695	D0D71D	4961 273045	TATYANA AFANASEVA	{"email": "t.afanaseva.011968@postgrespro.ru", "phone": "+70970892564"}
0005433373696	1A6E98	2674 892603	DMITRIY FILIPPOV	{"email": "filippovd031976@postgrespro.ru", "phone": "+70838400848"}
0005433373697	3A08C9	8490 645256	VALERIY SEMENOV	{"email": "vsemenov-1977@postgrespro.ru", "phone": "+70143380590"}
0005433373698	3A08C9	5787 862451	ELENA MOROZOVA	{"email": "morozova-e-121983@postgrespro.ru", "phone": "+70597385339"}
0005433373699	67A68F	6156 752694	NATALIYA ISAEVA	{"email": "isaeva.nataliya08011972@postgrespro.ru", "phone": "+70903091745"}
0005433373700	40447A	8344 114114	VIKTOR ANTONOV	{"email": "v_antonov.15111973@postgrespro.ru", "phone": "+70501250954"}
0005433373701	40447A	8557 299275	ANATOLIY FROLOV	{"phone": "+70253409164"}
0005433373702	B34E7F	2073 722534	OKSANA KISELEVA	{"phone": "+70089984272"}
0005433373703	63BA3A	7913 116889	MIKHAIL FILIPPOV	{"phone": "+70192817898"}
0005433373704	03DE51	9216 515257	ELENA ZAYCEVA	{"email": "elena.zayceva.14041970@postgrespro.ru", "phone": "+70651430617"}
0005433373705	03DE51	2448 257385	VERA KONDRATEVA	{"phone": "+70639131736"}
0005433373706	0124F1	7681 701674	VALERIY ROMANOV	{"phone": "+70677628396"}
0005433373707	B9CF21	7825 950029	VASILIY PETROV	{"phone": "+70234453174"}
0005433373708	44716D	2337 224720	FEDOR KULIKOV	{"email": "kulikov.fedor.101973@postgrespro.ru", "phone": "+70977190888"}
0005433373709	B9C7C6	9931 392312	VLADIMIR FROLOV	{"email": "frolov_v_29111969@postgrespro.ru", "phone": "+70591243512"}
0005433373710	B9C7C6	3821 166039	MIKHAIL BORISOV	{"email": "borisov.m_011981@postgrespro.ru", "phone": "+70934387817"}
0005433373711	B9C7C6	6994 586270	DMITRIY ROMANOV	{"email": "d.romanov1972@postgrespro.ru", "phone": "+70591942108"}
0005433373712	605A6E	3322 737322	ANATOLIY PETROV	{"phone": "+70353406619"}
0005433373713	56E949	6876 270361	NINA MAKAROVA	{"email": "n-makarova-04101977@postgrespro.ru", "phone": "+70301195567"}
0005433373714	D04C6A	4253 705888	ALEKSEY IVANOV	{"phone": "+70015108439"}
0005433373715	4F4710	8943 044922	IRINA SEMENOVA	{"phone": "+70766469423"}
0005433373716	8B211E	4879 861245	NINA NOVIKOVA	{"phone": "+70957329701"}
0005433373717	8B211E	5838 168005	SERGEY KARPOV	{"email": "karpov.s-121990@postgrespro.ru", "phone": "+70748571632"}
0005433373718	8B211E	9286 132046	IGOR ROMANOV	{"phone": "+70890992321"}
0005433373719	D6D89F	3023 749407	GULNARA KUZNECOVA	{"email": "g_kuznecova.05051979@postgrespro.ru", "phone": "+70999787374"}
0005433373720	F4AF24	7547 069951	OLGA KARPOVA	{"email": "karpova.olga-24061978@postgrespro.ru", "phone": "+70282888335"}
0005433373721	8FF668	8307 428722	MARIYA PAVLOVA	{"email": "pavlovamariya-29121962@postgrespro.ru", "phone": "+70125741961"}
0005433373722	A66046	7295 205514	GALINA MAKSIMOVA	{"phone": "+70459075693"}
0005433373723	BA698D	8908 455566	TIMOFEY KULIKOV	{"phone": "+70602298979"}
0005433373724	684BA5	2711 352320	VLADIMIR KUZNECOV	{"phone": "+70586042777"}
0005433373725	684BA5	5338 391072	GALINA TITOVA	{"email": "g_titova_1981@postgrespro.ru", "phone": "+70357688359"}
0005433373726	9515AB	5411 454123	ELENA KUZNECOVA	{"email": "elena-kuznecova1972@postgrespro.ru", "phone": "+70848460155"}
0005433373727	57222B	0070 064204	MIKHAIL FEDOROV	{"phone": "+70509682786"}
0005433373728	57222B	7566 478854	LIDIYA PAVLOVA	{"phone": "+70523697272"}
0005433373729	B0A20F	3847 444418	ALEKSEY POPOV	{"email": "popov.a_10081967@postgrespro.ru", "phone": "+70206826482"}
0005433373730	B41F95	8404 264465	OKSANA BELOVA	{"phone": "+70416027522"}
0005433373731	B41F95	3436 541857	IVAN FEDOROV	{"email": "fedorov.ivan-14081972@postgrespro.ru", "phone": "+70621034229"}
0005433373732	B41F95	7092 318634	EVGENIY MELNIKOV	{"phone": "+70787364467"}
0005433373733	B63202	7989 060531	NADEZHDA KISELEVA	{"phone": "+70430499828"}
0005433373734	B63202	3886 958026	VIKTORIYA KRASNOVA	{"phone": "+70149691811"}
0005433373735	32570D	6751 963978	VIKTOR KUZNECOV	{"phone": "+70252971441"}
0005433373736	340D37	7675 942987	ARTEM VOLKOV	{"email": "volkov.a_1982@postgrespro.ru", "phone": "+70146785964"}
0005433373737	340D37	1587 832485	TATYANA VOLKOVA	{"email": "volkova_t-1967@postgrespro.ru", "phone": "+70045057753"}
0005433373738	765F1B	7909 258485	ILDAR VASILEV	{"phone": "+70518123138"}
0005433373739	650594	9383 508528	ALEKSEY IVANOV	{"email": "ivanovaleksey_121981@postgrespro.ru", "phone": "+70737233396"}
0005433373740	650594	4066 977045	VLADIMIR MOROZOV	{"email": "morozovvladimir.20071968@postgrespro.ru", "phone": "+70130654439"}
0005433373741	650594	1005 070795	MARGARITA KONOVALOVA	{"email": "margaritakonovalova1969@postgrespro.ru", "phone": "+70138426920"}
0005433373742	DD131E	9587 858113	IGOR PETROV	{"phone": "+70454569871"}
0005433373743	76E899	8404 842050	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev-1967@postgrespro.ru", "phone": "+70681721937"}
0005433373744	AA604A	8091 284085	YURIY BORISOV	{"email": "borisov_y-1976@postgrespro.ru", "phone": "+70532731570"}
0005433373745	F9F077	8936 705280	IVAN VOLKOV	{"email": "ivan_volkov-10061966@postgrespro.ru", "phone": "+70861006361"}
0005433373746	69A251	5931 077752	ANNA MAKAROVA	{"email": "makarova-a.011967@postgrespro.ru", "phone": "+70341193750"}
0005433373747	69A251	7705 870907	ELIZAVETA SOKOLOVA	{"email": "sokolova_e_1980@postgrespro.ru", "phone": "+70941137373"}
0005433373748	8CE9A6	3592 665827	ALEKSEY RODIONOV	{"phone": "+70998917369"}
0005433373749	610E4B	2342 902040	DANIL GORBUNOV	{"email": "gorbunovdanil-071970@postgrespro.ru", "phone": "+70786489246"}
0005433373750	610E4B	8897 934009	YULIYA KONOVALOVA	{"phone": "+70019842864"}
0005433373751	1A1928	7470 924252	KONSTANTIN MOROZOV	{"phone": "+70637616287"}
0005433373752	2CCED6	4810 311533	NATALYA ALEKSANDROVA	{"email": "aleksandrovan15061975@postgrespro.ru", "phone": "+70382967265"}
0005433373753	2CCED6	8543 228456	NIKOLAY SOROKIN	{"email": "sorokinnikolay_1957@postgrespro.ru", "phone": "+70632720211"}
0005433373754	A8C9C2	8071 693996	ROMAN SIDOROV	{"email": "roman_sidorov-051978@postgrespro.ru", "phone": "+70215649123"}
0005433373755	A8C9C2	3089 407856	MARGARITA NIKIFOROVA	{"email": "m_nikiforova081974@postgrespro.ru", "phone": "+70557425469"}
0005433373756	955DD0	6806 415999	VALERIY ABRAMOV	{"phone": "+70482526336"}
0005433373757	955DD0	1079 508113	LYUDMILA KUDRYASHOVA	{"email": "kudryashova.lyudmila1969@postgrespro.ru", "phone": "+70789783604"}
0005433373758	602EEC	5664 840800	VITALIY PETROV	{"email": "petrovvitaliy.111962@postgrespro.ru", "phone": "+70424829433"}
0005433373759	A0CDAC	8423 308437	EVGENIYA ABRAMOVA	{"phone": "+70372919530"}
0005433373760	D3F5FE	2704 901949	VYACHESLAV BORISOV	{"phone": "+70961508316"}
0005433373761	1CADEB	9720 883039	ALEKSEY ISAEV	{"email": "isaev.aleksey-29111969@postgrespro.ru", "phone": "+70233636874"}
0005433373762	FBBBD0	3694 453947	ELIZAVETA VASILEVA	{"phone": "+70644233662"}
0005433373763	701FCC	1750 811463	DARYA ILINA	{"email": "ilina_d.1957@postgrespro.ru", "phone": "+70641161341"}
0005433373764	335B5A	4696 182307	VASILIY MAKSIMOV	{"email": "v_maksimov.03091969@postgrespro.ru", "phone": "+70316795785"}
0005433373765	335B5A	8521 500160	VIKTOR ANDREEV	{"phone": "+70321530587"}
0005433373766	CD3245	4055 541445	ALEKSANDR BARANOV	{"email": "baranov_aleksandr-071981@postgrespro.ru", "phone": "+70862920852"}
0005433373767	CD3245	9148 495223	VLADIMIR MIKHAYLOV	{"phone": "+70344878024"}
0005433373768	0EDE89	5327 555498	MIKHAIL GERASIMOV	{"phone": "+70964728640"}
0005433373769	93AC44	8230 173337	AYRAT IVANOV	{"email": "ivanov.ayrat.081982@postgrespro.ru", "phone": "+70516136542"}
0005433373770	FD63CB	5942 559452	ALEKSANDR VLASOV	{"email": "avlasov-101974@postgrespro.ru", "phone": "+70023897271"}
0005433373771	FD63CB	6713 817879	PAVEL GRIGOREV	{"email": "p_grigorev.26101976@postgrespro.ru", "phone": "+70347456098"}
0005433373772	F8DC2F	5476 734006	TAISIYA LEBEDEVA	{"phone": "+70654022395"}
0005433373773	F8DC2F	9735 008773	YURIY KUZMIN	{"email": "y_kuzmin.1968@postgrespro.ru", "phone": "+70770780350"}
0005433373774	A308C4	6713 779751	TATYANA ALEKSANDROVA	{"phone": "+70652159276"}
0005433373775	A308C4	3991 609229	IVAN ISAEV	{"phone": "+70889346252"}
0005433373776	5C893B	0766 165746	EVDOKIYA KULIKOVA	{"phone": "+70927838381"}
0005433373777	17C74E	4768 921445	ALEKSEY KONOVALOV	{"email": "aleksey.konovalov_061968@postgrespro.ru", "phone": "+70253648514"}
0005433373778	046C4A	3670 086549	KRISTINA IVANOVA	{"phone": "+70592319406"}
0005433373779	046C4A	4614 615841	OLGA NESTEROVA	{"email": "nesterovaolga_061966@postgrespro.ru", "phone": "+70624612325"}
0005433373780	BA7E2C	8303 002712	DENIS BELOV	{"email": "belov_denis_071969@postgrespro.ru", "phone": "+70839985576"}
0005433373781	BA7E2C	2416 324016	VLADIMIR KOZLOV	{"phone": "+70863745846"}
0005433373782	1D21E5	2236 236866	ALEKSANDR GAVRILOV	{"phone": "+70646299665"}
0005433373783	D33474	6631 396044	VIKTOR KARPOV	{"phone": "+70023238501"}
0005433373784	4DEB99	1869 462420	NELLI NIKOLAEVA	{"email": "nikolaevanelli_1968@postgrespro.ru", "phone": "+70228934906"}
0005433373785	03F585	9818 226842	VALENTINA POPOVA	{"email": "v.popova_011966@postgrespro.ru", "phone": "+70344175019"}
0005433373786	03F585	8797 199954	ANNA KAZAKOVA	{"email": "akazakova_20101974@postgrespro.ru", "phone": "+70987108823"}
0005433373787	948EC8	6023 056507	VIKTOR DAVYDOV	{"phone": "+70124958553"}
0005433373788	748708	2647 410030	EKATERINA MALYSHEVA	{"email": "e_malysheva-051979@postgrespro.ru", "phone": "+70322132833"}
0005433373789	F48A4D	9306 737186	DARYA PETROVA	{"email": "petrovad-07051965@postgrespro.ru", "phone": "+70038578939"}
0005433373790	65B2E9	4775 563608	IRINA ZHUKOVA	{"phone": "+70299997642"}
0005433373791	65B2E9	1243 451062	NIKOLAY PAVLOV	{"email": "nikolay-pavlov.1971@postgrespro.ru", "phone": "+70399992848"}
0005433373792	00CD91	4494 193250	TATYANA VOLKOVA	{"email": "volkovat-1981@postgrespro.ru", "phone": "+70922290204"}
0005433373793	7EAADC	5070 805459	KONSTANTIN SCHERBAKOV	{"phone": "+70542689323"}
0005433373794	7EAADC	2850 534260	EKATERINA VLASOVA	{"email": "ekaterina-vlasova-28091988@postgrespro.ru", "phone": "+70766654170"}
0005433373795	8EB701	6151 009125	LYUBOV OSIPOVA	{"email": "lyubov_osipova.1970@postgrespro.ru", "phone": "+70958926191"}
0005433373796	2E3177	5796 282330	ANDREY POPOV	{"email": "apopov-29091972@postgrespro.ru", "phone": "+70993387906"}
0005433373797	75EE18	6567 057289	ANDREY SEMENOV	{"email": "semenov.andrey_1972@postgrespro.ru", "phone": "+70445346864"}
0005433373798	75EE18	4241 024169	VASILIY BARANOV	{"phone": "+70442723187"}
0005433373799	7D2446	5799 160963	ALENA GRISHINA	{"email": "alena_grishina.071971@postgrespro.ru", "phone": "+70184435564"}
0005433373800	60FE6E	9513 247257	ANTON DENISOV	{"email": "adenisov19011978@postgrespro.ru", "phone": "+70717278273"}
0005433373801	F00A3B	5311 380530	GEORGIY MIRONOV	{"phone": "+70356539324"}
0005433373802	81EC13	9381 526489	RUSLAN KUZNECOV	{"email": "r.kuznecov-02071976@postgrespro.ru", "phone": "+70483606210"}
0005433373803	81EC13	0540 377319	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova_a_1973@postgrespro.ru", "phone": "+70334074649"}
0005433373804	BBD3D2	7452 714509	ELVIRA IVANOVA	{"email": "ivanova_elvira-011981@postgrespro.ru", "phone": "+70670465993"}
0005433373805	77961E	4107 971088	SERGEY KUDRYASHOV	{"phone": "+70911881643"}
0005433373806	77961E	9099 128446	TATYANA IVANOVA	{"email": "t_ivanova-081972@postgrespro.ru", "phone": "+70674911649"}
0005433397178	3FDF6D	8561 093285	VLADIMIR SMIRNOV	{"phone": "+70250910170"}
0005433397179	40A7EE	8197 779980	LYUDMILA ERMAKOVA	{"email": "ermakova-l_1970@postgrespro.ru", "phone": "+70205073017"}
0005433397180	631539	0524 764745	EVGENIY SOROKIN	{"phone": "+70857436865"}
0005433397181	004486	1995 806294	ANDREY ZHUKOV	{"phone": "+70311592642"}
0005433397182	C9096D	4269 460802	NAILYA KOZLOVA	{"phone": "+70388983734"}
0005433397183	D60581	4289 260668	VLADIMIR KUZMIN	{"email": "kuzmin_v_011971@postgrespro.ru", "phone": "+70206393428"}
0005433397184	BA7C7D	7061 664758	VLADIMIR KUZMIN	{"phone": "+70439630550"}
0005433397185	BA7C7D	6669 368738	ALEKSANDR SIDOROV	{"email": "sidorov-a-02101973@postgrespro.ru", "phone": "+70667331837"}
0005433397186	64C1A8	2275 602689	ZOYA ZHUKOVA	{"phone": "+70895397836"}
0005433397187	8258A8	7553 434622	KRISTINA KONDRATEVA	{"email": "kondrateva_kristina_04071966@postgrespro.ru", "phone": "+70768038720"}
0005433397188	8258A8	5130 816476	ANASTASIYA IVANOVA	{"email": "anastasiya-ivanova_011974@postgrespro.ru", "phone": "+70617883951"}
0005433397189	B8A51A	1861 192266	ELENA VOROBEVA	{"phone": "+70436571344"}
0005433397190	E1A8DF	9008 751589	VALENTIN POPOV	{"phone": "+70446954111"}
0005433397191	DE3B59	1829 212703	NATALYA NESTEROVA	{"email": "nesterova.n-28061979@postgrespro.ru", "phone": "+70892098439"}
0005433397192	35B160	4590 626782	EKATERINA KOROLEVA	{"email": "ekaterina-koroleva041974@postgrespro.ru", "phone": "+70723605549"}
0005433397193	35B160	1389 176034	VALENTIN KUZNECOV	{"email": "v.kuznecov-111973@postgrespro.ru", "phone": "+70990071802"}
0005433397194	299784	5191 755451	VLADIMIR PETROV	{"phone": "+70942073697"}
0005433397195	6596FE	3505 696624	MIKHAIL VOROBEV	{"email": "mvorobev.111962@postgrespro.ru", "phone": "+70762768855"}
0005433397196	DB013C	5046 227232	MIKHAIL FILIPPOV	{"phone": "+70638486389"}
0005433397197	9320C6	2451 785265	ALEKSANDR KUZNECOV	{"phone": "+70169629576"}
0005433397198	C93AA0	0849 417413	SERGEY GAVRILOV	{"email": "sergey-gavrilov-14011973@postgrespro.ru", "phone": "+70971938590"}
0005433397199	390983	3136 655136	ZINAIDA KOROLEVA	{"phone": "+70403301727"}
0005433397200	D71009	1706 002683	MIKHAIL IVANOV	{"phone": "+70914112691"}
0005433397201	CFEEF3	7089 721982	VIKTORIYA STEPANOVA	{"phone": "+70419685509"}
0005433397202	CFEEF3	2660 937872	EKATERINA ALEKSEEVA	{"email": "alekseeva_ekaterina-02031979@postgrespro.ru", "phone": "+70828077106"}
0005433397203	43BA8E	6348 774666	VITALIY SOKOLOV	{"phone": "+70435174339"}
0005433397204	396702	1161 512295	RISHAT POPOV	{"phone": "+70021586800"}
0005433397205	990A87	8787 992258	TATYANA ISAEVA	{"email": "t_isaeva101980@postgrespro.ru", "phone": "+70003998247"}
0005433397206	990A87	3292 547520	NINA KUDRYASHOVA	{"email": "nina.kudryashova_06111976@postgrespro.ru", "phone": "+70857750919"}
0005433397207	81001D	4806 565912	SOFIYA EFIMOVA	{"email": "sefimova.021971@postgrespro.ru", "phone": "+70680687401"}
0005433397208	81001D	6792 724083	RAISA PETROVA	{"email": "raisa-petrova.1987@postgrespro.ru", "phone": "+70390536249"}
0005433397209	645D85	1514 978376	IRINA FADEEVA	{"email": "i_fadeeva-22091969@postgrespro.ru", "phone": "+70493503086"}
0005433397210	F03E1E	1600 580824	ROMAN DENISOV	{"email": "denisovroman21041969@postgrespro.ru", "phone": "+70978627896"}
0005433397211	F03E1E	3508 927730	SERGEY DAVYDOV	{"email": "davydov_sergey_25081962@postgrespro.ru", "phone": "+70010056780"}
0005433397212	F03E1E	7627 231780	EVGENIY POPOV	{"email": "popov_e_25011969@postgrespro.ru", "phone": "+70075148093"}
0005433397213	B459AC	4436 695732	EVDOKIYA YAKOVLEVA	{"email": "evdokiya-yakovleva_1985@postgrespro.ru", "phone": "+70474161747"}
0005433397214	B459AC	9206 150452	ARTEM ZAKHAROV	{"email": "zakharov_artem_1967@postgrespro.ru", "phone": "+70793312939"}
0005433397215	B459AC	0298 152419	ALBERT FILIPPOV	{"email": "filippova.071981@postgrespro.ru", "phone": "+70144837353"}
0005433397216	4C1895	0800 570868	DMITRIY NIKOLAEV	{"phone": "+70654255323"}
0005433397217	1C4E9F	5788 933012	VASILIY VOLKOV	{"email": "volkov_vasiliy1968@postgrespro.ru", "phone": "+70208002646"}
0005433397218	F99A25	3671 603264	MARIYA FROLOVA	{"email": "frolovam.22041981@postgrespro.ru", "phone": "+70854137845"}
0005433397219	E7E3D8	1867 128469	FARIDA ISAEVA	{"phone": "+70058564723"}
0005433397330	226387	1114 510932	ANNA KOZLOVA	{"phone": "+70080880861"}
0005433397220	905D5F	7734 630605	IRINA NESTEROVA	{"email": "nesterovairina.051973@postgrespro.ru", "phone": "+70890203352"}
0005433397221	905D5F	5535 191693	ZOYA PAVLOVA	{"phone": "+70073170397"}
0005433397222	905D5F	7295 614623	VLADA KISELEVA	{"email": "vkiseleva.1972@postgrespro.ru", "phone": "+70371436623"}
0005433397223	E0B889	4584 870513	ELENA KOROLEVA	{"phone": "+70010913269"}
0005433397224	0EE115	2655 971991	MARGARITA SCHERBAKOVA	{"email": "margarita_scherbakova1983@postgrespro.ru", "phone": "+70592983375"}
0005433397225	AD5C9B	9881 303074	TATYANA KOZLOVA	{"email": "kozlova_tatyana_1969@postgrespro.ru", "phone": "+70170827769"}
0005433397226	AD5C9B	1967 654945	SERGEY AFANASEV	{"email": "afanasev_s06051972@postgrespro.ru", "phone": "+70981265547"}
0005433397227	98F8AC	2966 773534	DMITRIY IVANOV	{"email": "d.ivanov-30041974@postgrespro.ru", "phone": "+70756225091"}
0005433397228	98F8AC	3941 196766	RAVIL ABRAMOV	{"phone": "+70000257648"}
0005433397229	AC72F7	4249 029311	ALEKSEY NIKITIN	{"email": "a_nikitin22081963@postgrespro.ru", "phone": "+70355394543"}
0005433397230	95FD41	5301 366465	ANNA FILATOVA	{"phone": "+70598874172"}
0005433397231	7F9810	8191 266899	DMITRIY BONDARENKO	{"email": "d.bondarenko-121979@postgrespro.ru", "phone": "+70652520511"}
0005433397232	7F9810	6291 275522	ALEKSANDR ORLOV	{"email": "aleksandr_orlov_051969@postgrespro.ru", "phone": "+70154253185"}
0005433397233	7F9810	2811 736233	IGOR TIMOFEEV	{"phone": "+70919709991"}
0005433397234	2975D4	9559 865228	VIKTOR FROLOV	{"phone": "+70039445699"}
0005433397235	21FD25	5029 033853	YANA SMIRNOVA	{"phone": "+70637018218"}
0005433397236	DAD1FA	2309 245304	NATALYA SAVELEVA	{"email": "savelevan041975@postgrespro.ru", "phone": "+70150245295"}
0005433397237	744B8A	3882 969352	LYUBOV SMIRNOVA	{"email": "smirnovalyubov.031984@postgrespro.ru", "phone": "+70261038314"}
0005433397238	3A9B6B	8128 149056	LARISA MASLOVA	{"email": "larisamaslova1962@postgrespro.ru", "phone": "+70271877609"}
0005433397239	4342C0	5702 549103	TAISIYA DMITRIEVA	{"email": "dmitrieva-t_01041968@postgrespro.ru", "phone": "+70163545495"}
0005433397240	CD4251	2296 158298	SVETLANA LOGINOVA	{"email": "svetlanaloginova1965@postgrespro.ru", "phone": "+70349788546"}
0005433397241	0AFD7C	8122 957077	VALERIY BELOV	{"email": "belovv-091973@postgrespro.ru", "phone": "+70385319967"}
0005433397242	12D85E	2246 966144	TAMARA NIKOLAEVA	{"email": "nikolaeva_tamara091972@postgrespro.ru", "phone": "+70294068458"}
0005433397243	F35E1E	4544 169105	YULIYA GAVRILOVA	{"email": "y-gavrilova1973@postgrespro.ru", "phone": "+70034570721"}
0005433397244	D85D13	9646 065492	TATYANA SIDOROVA	{"email": "sidorovat_06111961@postgrespro.ru", "phone": "+70842490009"}
0005433397245	632429	6268 070160	VALENTINA BOGDANOVA	{"phone": "+70617899964"}
0005433397246	6C5E3C	9172 266825	LIDIYA IVANOVA	{"phone": "+70703333438"}
0005433397247	9F5B8D	6583 774027	YULIYA BORISOVA	{"phone": "+70983672239"}
0005433397248	CD6B24	7572 548160	DMITRIY KUZMIN	{"phone": "+70582488764"}
0005433397249	39C796	0487 422575	DMITRIY VOLKOV	{"email": "dmitriyvolkov_02061975@postgrespro.ru", "phone": "+70503475188"}
0005433397250	51A14C	2906 180731	VIKTORIYA DANILOVA	{"email": "vdanilova_1982@postgrespro.ru", "phone": "+70386649613"}
0005433397251	51A14C	3880 543741	MIKHAIL IVANOV	{"email": "ivanov-m.11021969@postgrespro.ru", "phone": "+70924918212"}
0005433397252	429FBE	1100 616981	SERGEY VLASOV	{"email": "s_vlasov.071974@postgrespro.ru", "phone": "+70841086637"}
0005433397253	59757C	8432 312211	TATYANA GERASIMOVA	{"phone": "+70593793135"}
0005433397254	794233	9536 254786	KSENIYA POTAPOVA	{"phone": "+70583336067"}
0005433397255	A7A77A	8292 316494	ALEKSANDR SOLOVEV	{"phone": "+70654739404"}
0005433397256	75F7FA	3318 226447	EKATERINA KONDRATEVA	{"email": "kondrateva.e.27091973@postgrespro.ru", "phone": "+70873422854"}
0005433397257	D7AFE9	1690 194037	OKSANA IVANOVA	{"email": "oksana.ivanova-29011969@postgrespro.ru", "phone": "+70475049258"}
0005433397258	01AFC9	0800 938137	SERGEY ANDREEV	{"email": "sergey_andreev_041972@postgrespro.ru", "phone": "+70607480150"}
0005433397259	E39177	2388 721704	ALEKSANDR ANDREEV	{"email": "andreeva_071980@postgrespro.ru", "phone": "+70554709362"}
0005433397260	DDB34E	5524 027757	ALEKSANDRA SEMENOVA	{"email": "semenova.aleksandra-121980@postgrespro.ru", "phone": "+70948701853"}
0005433397261	E55297	1208 555962	SERGEY STEPANOV	{"phone": "+70313928897"}
0005433397262	B03321	6743 227373	VERA SMIRNOVA	{"phone": "+70019760797"}
0005433397263	B03321	8858 486310	NELLI BARANOVA	{"email": "baranova_n1972@postgrespro.ru", "phone": "+70915579677"}
0005433397264	B03321	6406 140931	ANVAR DENISOV	{"phone": "+70098000074"}
0005433397265	EE6F1E	5608 425031	RIMMA VOROBEVA	{"phone": "+70315413957"}
0005433397266	EE6F1E	5767 963105	IRINA EGOROVA	{"email": "irinaegorova-1969@postgrespro.ru", "phone": "+70716255906"}
0005433397267	B1A43B	5376 844161	KIRILL DAVYDOV	{"phone": "+70765229184"}
0005433397268	585EB7	9275 829974	EKATERINA ZAYCEVA	{"email": "ekaterina_zayceva_051974@postgrespro.ru", "phone": "+70692479510"}
0005433397269	372D59	8800 910352	NATALYA MIKHAYLOVA	{"email": "mikhaylova_n_03081967@postgrespro.ru", "phone": "+70232632721"}
0005433397270	DDCE63	4527 194456	DMITRIY GERASIMOV	{"email": "gerasimov-d.25011965@postgrespro.ru", "phone": "+70263328585"}
0005433397271	CCE2B6	6138 305788	ANDREY KAZAKOV	{"email": "kazakov-a.101982@postgrespro.ru", "phone": "+70428343883"}
0005433397272	CCE2B6	0924 567699	TAMARA PETROVA	{"phone": "+70407402621"}
0005433397273	7788BB	5091 845848	YANA MAKAROVA	{"email": "makarovayana.1985@postgrespro.ru", "phone": "+70549346251"}
0005433397274	BF789E	3686 883668	NIKOLAY IVANOV	{"email": "ivanovnikolay.06011973@postgrespro.ru", "phone": "+70145811207"}
0005433397275	BF789E	7570 887076	ZINAIDA EGOROVA	{"email": "egorovaz_24091982@postgrespro.ru", "phone": "+70377026550"}
0005433397276	BF789E	8565 085181	ANDREY GUSEV	{"phone": "+70717320011"}
0005433397277	F222B4	9603 010091	ARTEM VOROBEV	{"phone": "+70522962366"}
0005433397278	A0E32D	6829 669491	ANNA ISAEVA	{"email": "annaisaeva-1979@postgrespro.ru", "phone": "+70709763929"}
0005433397279	A0E32D	1199 928235	ARTEM RODIONOV	{"phone": "+70337710259"}
0005433397280	431A39	6411 128933	NATALYA ANISIMOVA	{"email": "natalya-anisimova_1982@postgrespro.ru", "phone": "+70859355721"}
0005433397281	431A39	8684 764019	ALEKSEY FROLOV	{"email": "frolov.a.24021980@postgrespro.ru", "phone": "+70664308109"}
0005433397282	23A07D	6833 302775	DMITRIY NIKOLAEV	{"email": "d.nikolaev041978@postgrespro.ru", "phone": "+70664729937"}
0005433397283	A3337A	5000 793577	NADEZHDA MALYSHEVA	{"email": "n.malysheva01061976@postgrespro.ru", "phone": "+70920876632"}
0005433397284	A3337A	2122 496331	ANNA MOROZOVA	{"email": "morozova-anna-111971@postgrespro.ru", "phone": "+70811995523"}
0005433397285	0E5AA3	5072 399775	VLADIMIR ANTONOV	{"email": "vladimir_antonov.08021971@postgrespro.ru", "phone": "+70897000430"}
0005433397286	439B47	8095 707484	GRIGORIY NIKITIN	{"email": "g_nikitin_1965@postgrespro.ru", "phone": "+70498962457"}
0005433397287	8E064A	6866 673870	VIKTOR IVANOV	{"phone": "+70164172538"}
0005433397288	8E064A	1993 878087	MARGARITA KOVALEVA	{"phone": "+70121250570"}
0005433397289	DFA167	6024 714994	GALINA EFIMOVA	{"email": "galinaefimova25091980@postgrespro.ru", "phone": "+70499308602"}
0005433397290	E1CB29	9724 640024	LYUDMILA KUZNECOVA	{"phone": "+70157308860"}
0005433397291	DAD5AC	7729 658266	RAMILYA ISAEVA	{"phone": "+70720943509"}
0005433397292	DAD5AC	0647 413866	ELENA BARANOVA	{"phone": "+70148096457"}
0005433397293	9F6D56	4257 702512	LYUBOV AFANASEVA	{"phone": "+70941840722"}
0005433397294	76E6E0	4505 366987	OLGA KOROLEVA	{"email": "olga_koroleva_021969@postgrespro.ru", "phone": "+70595606883"}
0005433397295	76E6E0	1117 001546	SERGEY SEMENOV	{"email": "semenov_s.04101981@postgrespro.ru", "phone": "+70704236921"}
0005433397296	7716F5	9822 793935	IVAN YAKOVLEV	{"email": "i.yakovlev1968@postgrespro.ru", "phone": "+70340131826"}
0005433397297	7716F5	7195 351727	ANNA ORLOVA	{"email": "orlova_anna1961@postgrespro.ru", "phone": "+70242358939"}
0005433397298	1BA556	9767 645176	NATALYA KUZNECOVA	{"email": "kuznecova_n.26111974@postgrespro.ru", "phone": "+70661544533"}
0005433397299	1BA556	3427 093110	ANNA ZOTOVA	{"email": "zotova.a_10111965@postgrespro.ru", "phone": "+70377491248"}
0005433397300	B7D723	5490 510661	VLADIMIR DMITRIEV	{"email": "vladimir-dmitriev_02101965@postgrespro.ru", "phone": "+70534474507"}
0005433397301	B7D723	6726 481449	MARIYA POPOVA	{"email": "m.popova-03061968@postgrespro.ru", "phone": "+70139807711"}
0005433397302	DE9F64	2973 531772	VLADIMIR KOZLOV	{"email": "vkozlov_081973@postgrespro.ru", "phone": "+70433485831"}
0005433397303	2A3552	6812 159388	IRINA TITOVA	{"email": "irina-titova_071974@postgrespro.ru", "phone": "+70333184380"}
0005433397304	9E77B7	1269 321992	ANDREY SOROKIN	{"email": "sorokin_a-1969@postgrespro.ru", "phone": "+70327916252"}
0005433397305	9E77B7	3519 498771	ALEKSANDRA LAZAREVA	{"phone": "+70499529563"}
0005433397306	9E77B7	5508 632626	ALBERT IVANOV	{"email": "ivanov_a-031964@postgrespro.ru", "phone": "+70138915502"}
0005433397307	9E77B7	3182 168186	TATYANA YUDINA	{"email": "yudina-tatyana1977@postgrespro.ru", "phone": "+70971616905"}
0005433397308	AA40AD	7660 259689	ALEKSEY MAKAROV	{"email": "makarova.1971@postgrespro.ru", "phone": "+70708334950"}
0005433397309	76E3FE	5535 941299	ANNA KALININA	{"email": "a-kalinina-091975@postgrespro.ru", "phone": "+70788119080"}
0005433397310	338CB5	8927 661014	SERGEY DAVYDOV	{"email": "davydovs_1976@postgrespro.ru", "phone": "+70270807337"}
0005433397311	A0F566	1810 533241	IVAN SAVELEV	{"phone": "+70683365524"}
0005433397312	A0F566	2552 413255	KLAVDIYA IVANOVA	{"phone": "+70335044282"}
0005433397313	D21A8E	6056 060125	VALENTINA TROFIMOVA	{"email": "trofimova-valentina.09061968@postgrespro.ru", "phone": "+70108127528"}
0005433397314	C79DC5	8058 580597	DARYA ANTONOVA	{"email": "antonova-darya.091969@postgrespro.ru", "phone": "+70109841049"}
0005433397315	C79DC5	5212 196079	PAVEL MOROZOV	{"phone": "+70593845934"}
0005433397316	C79DC5	4886 740394	VALENTINA VASILEVA	{"email": "vasileva_valentina-081973@postgrespro.ru", "phone": "+70729210843"}
0005433397317	E48677	1805 284050	NIKOLAY POPOV	{"email": "nikolay_popov-1979@postgrespro.ru", "phone": "+70572525165"}
0005433397318	E48677	7209 597700	LYUBOV IVANOVA	{"email": "l.ivanova.121979@postgrespro.ru", "phone": "+70428403517"}
0005433397319	980999	2417 998213	SERGEY IVANOV	{"email": "ivanov_sergey.061973@postgrespro.ru", "phone": "+70814061533"}
0005433397320	1317BB	7940 529323	ALEKSEY KUZNECOV	{"phone": "+70801542503"}
0005433397321	464078	4079 461491	DENIS ALEKSANDROV	{"phone": "+70544655803"}
0005433397322	464078	8407 888111	DMITRIY GUSEV	{"phone": "+70397236731"}
0005433397323	9F1EE3	0116 197269	OKSANA PAVLOVA	{"email": "pavlova.oksana02101974@postgrespro.ru", "phone": "+70400501699"}
0005433397324	CF4C52	5585 542557	ANTON GUSEV	{"email": "agusev02121968@postgrespro.ru", "phone": "+70845605495"}
0005433397325	35E95D	3825 815579	GENNADIY FILIPPOV	{"email": "g-filippov_26071978@postgrespro.ru", "phone": "+70806233246"}
0005433397326	35E95D	6489 314157	ALEKSANDR ZHUKOV	{"phone": "+70115100167"}
0005433397327	BBEA82	2280 445521	ANASTASIYA EFREMOVA	{"email": "aefremova_01071970@postgrespro.ru", "phone": "+70113537956"}
0005433397328	8A0DE8	3041 370244	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaanastasiya011969@postgrespro.ru", "phone": "+70810787376"}
0005433397329	8A0DE8	4046 272372	ELENA RYABOVA	{"phone": "+70040218530"}
0005433397331	B495FC	1822 143920	MIKHAIL MOROZOV	{"phone": "+70608641730"}
0005433397332	B495FC	3343 428007	DMITRIY SCHERBAKOV	{"email": "dmitriyscherbakov.1987@postgrespro.ru", "phone": "+70960225481"}
0005433397333	C4C05F	9684 344284	SVETLANA YAKOVLEVA	{"email": "yakovleva-svetlana_121971@postgrespro.ru", "phone": "+70642767776"}
0005433397334	F29FDD	3818 548746	ANDREY KUZNECOV	{"email": "akuznecov011970@postgrespro.ru", "phone": "+70969218453"}
0005433397335	F29FDD	2255 738298	VIKTOR PETROV	{"email": "petrovviktor-1966@postgrespro.ru", "phone": "+70854823923"}
0005433397336	F29FDD	2946 146154	OLEG DAVYDOV	{"phone": "+70762998851"}
0005433397337	42AA6E	4000 976645	VYACHESLAV ISAEV	{"email": "v_isaev_1977@postgrespro.ru", "phone": "+70393075063"}
0005433397338	207879	3040 963013	SVETLANA YAKOVLEVA	{"email": "yakovlevas_23061966@postgrespro.ru", "phone": "+70150847867"}
0005433397339	207879	2618 690825	TAISIYA KUZNECOVA	{"email": "taisiya-kuznecova1971@postgrespro.ru", "phone": "+70294827377"}
0005433397340	346671	7808 560646	NIKITA KUZMIN	{"phone": "+70253547084"}
0005433397341	346671	8547 043373	ELENA MOISEEVA	{"phone": "+70914916364"}
0005433397342	6C961B	9970 814756	ALBINA ERMAKOVA	{"email": "albinaermakova.061989@postgrespro.ru", "phone": "+70521541256"}
0005433397343	3B4416	2687 600914	GUZEL KALININA	{"phone": "+70552258298"}
0005433397344	3B2F6C	8968 280094	OLEG SERGEEV	{"email": "o-sergeev-081979@postgrespro.ru", "phone": "+70211412797"}
0005433397345	39CED7	7221 111061	ROMAN MOROZOV	{"phone": "+70074187979"}
0005433397346	39CED7	9545 330841	STANISLAV ANDREEV	{"email": "andreevstanislav-111973@postgrespro.ru", "phone": "+70186577167"}
0005433397347	38D1F7	1291 969419	VLADIMIR KUZNECOV	{"email": "v_kuznecov101963@postgrespro.ru", "phone": "+70273993384"}
0005433397348	38D1F7	8509 426171	SERGEY SAVELEV	{"email": "s_savelev25041960@postgrespro.ru", "phone": "+70470168150"}
0005433397349	A500EF	4667 425384	GALINA MALYSHEVA	{"email": "malysheva_galina_091974@postgrespro.ru", "phone": "+70298880476"}
0005433397350	A413F8	8221 697624	NATALYA GUSEVA	{"email": "guseva-natalya.07101967@postgrespro.ru", "phone": "+70346383021"}
0005433397351	4FE5FD	2487 750262	ALEKSANDRA EGOROVA	{"phone": "+70897369798"}
0005433397352	4FE5FD	4121 057824	SVETLANA MIRONOVA	{"email": "mironova.s_1967@postgrespro.ru", "phone": "+70723120929"}
0005433397353	00FEC5	1802 642880	DIANA PETROVA	{"email": "petrovadiana1975@postgrespro.ru", "phone": "+70810865586"}
0005433397354	4CADBF	7371 009135	KONSTANTIN KUZNECOV	{"phone": "+70602431407"}
0005433397355	A95B21	8900 379778	YURIY PAVLOV	{"email": "pavlov-y.1972@postgrespro.ru", "phone": "+70467729771"}
0005433397356	FDD6DF	2313 439765	OKSANA KUZMINA	{"phone": "+70890722336"}
0005433397357	FDD6DF	1647 202430	ELENA YUDINA	{"email": "elenayudina_1985@postgrespro.ru", "phone": "+70432648263"}
0005433397358	3B00C2	7138 195681	LEONID MELNIKOV	{"phone": "+70481667249"}
0005433397359	9AAF56	9010 749571	EVGENIY BELOV	{"email": "belov.e_24061973@postgrespro.ru", "phone": "+70485940917"}
0005433397360	2D59CC	5288 943535	NADEZHDA MAKSIMOVA	{"email": "n-maksimova-17011979@postgrespro.ru", "phone": "+70472302734"}
0005433397361	BD4DA7	3992 807642	ELENA SEMENOVA	{"email": "e_semenova_021970@postgrespro.ru", "phone": "+70904061754"}
0005433397362	28CB70	1499 482656	VLADIMIR POPOV	{"phone": "+70952583120"}
0005433397363	28CB70	1980 748304	VLADIMIR KUZNECOV	{"email": "v_kuznecov-051984@postgrespro.ru", "phone": "+70301026952"}
0005433397364	7B291F	6886 855337	ELVIRA PETROVA	{"phone": "+70935746464"}
0005433397365	7B291F	6352 126137	ALENA VASILEVA	{"phone": "+70180080524"}
0005433397366	EB8B58	7299 176596	VALENTINA AFANASEVA	{"email": "afanaseva_v1978@postgrespro.ru", "phone": "+70711923897"}
0005433397367	8A9D50	5374 724836	MARIYA BELOVA	{"email": "belova.mariya.12081982@postgrespro.ru", "phone": "+70715513758"}
0005433397368	AAA668	7318 421939	VERONIKA DENISOVA	{"email": "v-denisova.021975@postgrespro.ru", "phone": "+70697922142"}
0005433397369	AAA668	5970 200040	LIDIYA YUDINA	{"email": "lidiya_yudina_15081978@postgrespro.ru", "phone": "+70660287365"}
0005433397370	AAA668	8948 692314	ARINA ANISIMOVA	{"phone": "+70967646218"}
0005433397371	C094EE	1693 483090	VALERIY ANDREEV	{"phone": "+70355124692"}
0005433397372	C094EE	9499 277533	SERGEY TIKHONOV	{"email": "tikhonov.sergey.1965@postgrespro.ru", "phone": "+70601092231"}
0005433397373	C094EE	8698 908425	KIRILL BORISOV	{"phone": "+70000003722"}
0005433397374	D6F161	8898 579276	VLADIMIR NIKOLAEV	{"phone": "+70729822223"}
0005433397375	D6F161	4521 157266	ROMAN MELNIKOV	{"email": "roman_melnikov-30061981@postgrespro.ru", "phone": "+70017790231"}
0005433397376	23C3EA	5121 814863	VYACHESLAV GAVRILOV	{"email": "vyacheslav.gavrilov-041977@postgrespro.ru", "phone": "+70919036348"}
0005433397377	23C3EA	3462 225052	LYUBOV MELNIKOVA	{"email": "l.melnikova-01051972@postgrespro.ru", "phone": "+70773689148"}
0005433397378	23C3EA	5534 174578	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova-1976@postgrespro.ru", "phone": "+70669164253"}
0005433397379	EA975F	0444 872315	ALEKSEY SMIRNOV	{"phone": "+70524655562"}
0005433397380	4301B9	2645 906139	EKATERINA POPOVA	{"email": "popova_e.26011973@postgrespro.ru", "phone": "+70499569335"}
0005433397381	988126	9501 569718	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir.1962@postgrespro.ru", "phone": "+70897099014"}
0005433397382	0C183B	9333 591774	ARSENIY FEDOTOV	{"phone": "+70633053250"}
0005433397383	3BB23B	9351 948725	ARTEM SCHERBAKOV	{"email": "scherbakov-artem.24081968@postgrespro.ru", "phone": "+70374190706"}
0005433397384	E08090	1971 892380	LARISA STEPANOVA	{"email": "stepanova.larisa10021968@postgrespro.ru", "phone": "+70213446663"}
0005433397442	E056E8	9721 092177	MARINA FOMINA	{"phone": "+70616908454"}
0005433397385	E08090	3236 583357	DMITRIY POPOV	{"email": "dmitriypopov.13021977@postgrespro.ru", "phone": "+70649770464"}
0005433397386	E08090	0588 339084	VIKTORIYA KUZMINA	{"phone": "+70144197021"}
0005433397387	D99B47	3806 548104	KIRILL VOLKOV	{"phone": "+70960455336"}
0005433397388	D99B47	5556 314745	DMITRIY KOZLOV	{"phone": "+70541026352"}
0005433397389	AF58CA	1237 739435	ALEKSANDR MOROZOV	{"phone": "+70680933825"}
0005433397390	43895F	3644 097593	PAVEL KULIKOV	{"phone": "+70712419900"}
0005433397391	D5699B	5371 747542	EKATERINA CHERNOVA	{"email": "e-chernova.23051976@postgrespro.ru", "phone": "+70799848310"}
0005433397392	38536E	8242 083852	ANNA FILIPPOVA	{"email": "filippova-anna-031973@postgrespro.ru", "phone": "+70987685795"}
0005433397393	38536E	1075 660407	DMITRIY ZHURAVLEV	{"email": "zhuravlevd-1968@postgrespro.ru", "phone": "+70124290511"}
0005433397394	5ED0FA	1529 260346	ANDREY TARASOV	{"phone": "+70435464571"}
0005433397395	5ED0FA	1860 107671	DARYA SIDOROVA	{"phone": "+70555679618"}
0005433397396	C7ACFE	7694 824100	IVAN PETROV	{"phone": "+70802129661"}
0005433397397	C7ACFE	2216 217337	ANDREY SMIRNOV	{"email": "smirnov.a091968@postgrespro.ru", "phone": "+70060172506"}
0005433397398	49E58D	8426 584604	VALENTIN NIKITIN	{"phone": "+70954169175"}
0005433397399	B636C1	3302 548506	EKATERINA LEBEDEVA	{"phone": "+70861083279"}
0005433397400	B636C1	0280 944911	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr011960@postgrespro.ru", "phone": "+70753541526"}
0005433397401	A54B2D	2241 844285	GALINA KUZMINA	{"phone": "+70626808154"}
0005433397402	A54B2D	4072 540934	ZLATA NESTEROVA	{"phone": "+70717286509"}
0005433397403	C8E8DA	9436 727436	ANNA RODIONOVA	{"phone": "+70340466696"}
0005433397404	9C2CA9	8438 122081	OLGA KOLESNIKOVA	{"phone": "+70894636577"}
0005433397405	23212B	2051 069885	EKATERINA OSIPOVA	{"email": "e.osipova-1973@postgrespro.ru", "phone": "+70662017456"}
0005433397406	272812	5844 485362	LARISA MASLOVA	{"phone": "+70308283202"}
0005433397407	4A3186	9599 917106	MARIYA TARASOVA	{"email": "tarasova_m-09011965@postgrespro.ru", "phone": "+70439845051"}
0005433397408	4A3186	8733 394173	NINA DENISOVA	{"email": "denisova-nina_1975@postgrespro.ru", "phone": "+70277506090"}
0005433397409	AB821E	9517 312571	GEORGIY TIMOFEEV	{"email": "georgiy-timofeev_1957@postgrespro.ru", "phone": "+70830362250"}
0005433397410	571CF4	0578 605262	GENNADIY BORISOV	{"email": "borisov_g-04101955@postgrespro.ru", "phone": "+70620922447"}
0005433397411	779EA7	7986 103817	VIKTOR CHERNOV	{"phone": "+70634753796"}
0005433397412	E802AE	6940 203112	ANDREY KARPOV	{"phone": "+70112384685"}
0005433397413	1BF74C	5563 522770	SVETLANA ANDREEVA	{"email": "svetlana-andreeva02101965@postgrespro.ru", "phone": "+70006040017"}
0005433397414	12BCB6	8615 547642	ALBINA VLASOVA	{"phone": "+70479627486"}
0005433397415	12BCB6	4569 859885	VIKTOR NAZAROV	{"email": "nazarov.v_19111965@postgrespro.ru", "phone": "+70252612733"}
0005433397416	540293	9091 507513	NATALYA YUDINA	{"phone": "+70957324084"}
0005433397417	FB89F0	3152 405875	MARIYA PAVLOVA	{"phone": "+70548453965"}
0005433397418	FB89F0	5903 605105	ANATOLIY KUZNECOV	{"phone": "+70402385662"}
0005433397419	52DC0C	5555 245576	ANATOLIY MOISEEV	{"phone": "+70433079103"}
0005433397420	52DC0C	7578 896398	ANDREY POPOV	{"phone": "+70581408306"}
0005433397421	7AFE8B	8222 424481	DANIIL ROMANOV	{"email": "romanov.daniil.1968@postgrespro.ru", "phone": "+70835075517"}
0005433397422	7AFE8B	4803 522192	NATALYA TIMOFEEVA	{"phone": "+70791091731"}
0005433397423	DBCB25	1910 297093	PETR IVANOV	{"phone": "+70395715288"}
0005433397424	DBCB25	3313 499556	MARIYA SIDOROVA	{"email": "sidorova_m27071980@postgrespro.ru", "phone": "+70293567086"}
0005433397425	CC3429	4129 210906	MAKSIM KRASNOV	{"email": "mkrasnov.051977@postgrespro.ru", "phone": "+70367551092"}
0005433397426	316DB2	3321 917721	MARINA IVANOVA	{"phone": "+70586405732"}
0005433397427	316DB2	1989 103490	SERGEY ANTONOV	{"phone": "+70447677499"}
0005433397428	070057	2829 268196	ALEKSANDR SMIRNOV	{"phone": "+70793342320"}
0005433397429	E4BF08	7173 546532	PAVEL EGOROV	{"email": "egorovp-041974@postgrespro.ru", "phone": "+70406240861"}
0005433397430	C7F117	1812 130041	ANDREY KONOVALOV	{"phone": "+70444486007"}
0005433397431	C7F117	8086 697535	MIKHAIL MIKHAYLOV	{"phone": "+70937699265"}
0005433397432	E8C133	0855 131350	IGOR STEPANOV	{"email": "igor-stepanov_1974@postgrespro.ru", "phone": "+70464663177"}
0005433397433	624478	1796 530143	SERGEY VOLKOV	{"phone": "+70933239537"}
0005433397434	624478	1630 738872	RINAT MOROZOV	{"email": "morozov_r_01021978@postgrespro.ru", "phone": "+70277076069"}
0005433397435	624478	3801 493265	LEONID SERGEEV	{"email": "sergeev_l-1974@postgrespro.ru", "phone": "+70766109080"}
0005433397436	7AB57A	6776 494231	MAKSIM IVANOV	{"email": "ivanov_maksim_1956@postgrespro.ru", "phone": "+70336340943"}
0005433397437	7AB57A	6236 579073	GENNADIY NAUMOV	{"phone": "+70199810271"}
0005433397438	CE73E2	1558 403442	OKSANA SOLOVEVA	{"email": "oksana-soloveva.1980@postgrespro.ru", "phone": "+70766595810"}
0005433397439	705B5D	0299 437037	NIKOLAY PAVLOV	{"phone": "+70423002767"}
0005433397440	705B5D	4749 604387	EKATERINA KARPOVA	{"email": "karpovaekaterina_17121969@postgrespro.ru", "phone": "+70366324141"}
0005433397441	6C62C3	9976 465233	VLADIMIR VASILEV	{"email": "vasilev-v-31051970@postgrespro.ru", "phone": "+70967863708"}
0005433397443	A58E27	1933 631732	KSENIYA VOROBEVA	{"email": "vorobeva.kseniya_1971@postgrespro.ru", "phone": "+70947197114"}
0005433397444	9EDDA6	5417 664847	YURIY KUZMIN	{"email": "yuriy.kuzmin_031966@postgrespro.ru", "phone": "+70277296496"}
0005433397445	93077F	6741 615742	TATYANA LOGINOVA	{"email": "tatyana_loginova.1966@postgrespro.ru", "phone": "+70121767116"}
0005433397446	93077F	2253 884541	NATALYA MELNIKOVA	{"email": "n_melnikova-1962@postgrespro.ru", "phone": "+70823118136"}
0005433397447	AC3F1E	6426 496760	NIKOLAY MELNIKOV	{"email": "nikolay.melnikov1970@postgrespro.ru", "phone": "+70828092604"}
0005433397448	5CED7E	2556 167733	KIRA KUZNECOVA	{"email": "kuznecova_kira.101982@postgrespro.ru", "phone": "+70948543747"}
0005433397449	FFEA76	2618 147859	OLGA ILINA	{"email": "ilina.olga.27011966@postgrespro.ru", "phone": "+70506557064"}
0005433397450	CFAD3A	8188 463874	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_051975@postgrespro.ru", "phone": "+70203429665"}
0005433397451	755AD6	5188 789381	LYUDMILA ZAYCEVA	{"email": "zayceva-lyudmila1975@postgrespro.ru", "phone": "+70525636003"}
0005433397452	14A5C6	7752 962132	DZHAMILYA KOZLOVA	{"email": "kozlova-dzhamilya.21091976@postgrespro.ru", "phone": "+70787461538"}
0005433397453	5F50BD	7991 170330	SVETLANA ZHURAVLEVA	{"email": "zhuravleva_s_24011971@postgrespro.ru", "phone": "+70652092478"}
0005433397454	8EB73A	9809 040298	MARIYA KOLESNIKOVA	{"email": "mkolesnikova-01061976@postgrespro.ru", "phone": "+70971709830"}
0005433397455	E56DB9	1189 599578	EVGENIY ZHURAVLEV	{"phone": "+70522024152"}
0005433397456	85BB8E	0179 964201	IVAN DAVYDOV	{"email": "ivandavydov-16051974@postgrespro.ru", "phone": "+70580235181"}
0005433397457	BC8786	4347 442687	PETR KRASNOV	{"email": "p_krasnov-1966@postgrespro.ru", "phone": "+70675354694"}
0005433397458	9E7157	6853 457107	ANASTASIYA STEPANOVA	{"phone": "+70430010390"}
0005433397459	0EC821	6446 512379	SERGEY SOKOLOV	{"email": "sokolov_sergey_26121967@postgrespro.ru", "phone": "+70205943433"}
0005433397460	7BDF49	4152 096116	DARYA IVANOVA	{"email": "darya.ivanova1981@postgrespro.ru", "phone": "+70433163755"}
0005433397461	7BDF49	7642 256928	IRINA BOGDANOVA	{"phone": "+70618616634"}
0005433397462	80AD18	2522 006934	VALENTINA BORISOVA	{"email": "v_borisova1977@postgrespro.ru", "phone": "+70824353004"}
0005433397463	B86000	7472 510787	TATYANA FILIPPOVA	{"phone": "+70388306435"}
0005433397464	B86000	8170 047373	IRINA KONOVALOVA	{"email": "ikonovalova_22011953@postgrespro.ru", "phone": "+70727169682"}
0005433397465	2890F2	7620 177525	MARIYA NIKITINA	{"email": "nikitina.m_1967@postgrespro.ru", "phone": "+70853673127"}
0005433397466	2890F2	2862 394492	ELEONORA CHERNOVA	{"email": "e_chernova_111976@postgrespro.ru", "phone": "+70577437530"}
0005433397467	11E276	2191 146928	SERGEY VASILEV	{"phone": "+70387244650"}
0005433397468	2BD3AB	2289 737484	VALENTINA FOMINA	{"phone": "+70544035674"}
0005433397469	EA7B22	6223 620274	INNA KUZMINA	{"phone": "+70958372660"}
0005433397470	6E7F2F	7548 811606	ILNAR TIMOFEEV	{"phone": "+70593932821"}
0005433397471	6E7F2F	5167 480479	EGOR ZHUKOV	{"phone": "+70256624891"}
0005433397472	19C4C9	2004 046668	DANIIL MIRONOV	{"phone": "+70420586709"}
0005433397473	2E1D65	7543 628874	IVAN MIRONOV	{"phone": "+70870254165"}
0005433397474	E1CE36	0706 841857	VIKTORIYA TIKHONOVA	{"email": "tikhonovaviktoriya_1976@postgrespro.ru", "phone": "+70324566742"}
0005433397475	5CF3E6	0091 463595	VLADIMIR BORISOV	{"phone": "+70614717778"}
0005433397476	C3B5A5	2522 979139	VADIM IVANOV	{"phone": "+70764191662"}
0005433397477	47AC39	9258 233946	VALENTINA NAUMOVA	{"email": "v_naumova_24101968@postgrespro.ru", "phone": "+70012017660"}
0005433397478	C357C2	1704 899100	IRINA EGOROVA	{"email": "irina_egorova.051971@postgrespro.ru", "phone": "+70960332603"}
0005433397479	C29833	9823 021625	PAVEL KOZLOV	{"email": "pavel_kozlov091975@postgrespro.ru", "phone": "+70093003431"}
0005433397480	A77061	7170 951515	TAKHIR KUZMIN	{"phone": "+70789729288"}
0005433397481	7B94FA	9354 307671	KSENIYA SERGEEVA	{"phone": "+70521333738"}
0005433397482	735438	0267 659674	NATALYA SERGEEVA	{"email": "sergeeva-natalya-101972@postgrespro.ru", "phone": "+70081173915"}
0005433397483	A609B2	6280 428457	NADEZHDA MAKSIMOVA	{"phone": "+70779064993"}
0005433397484	06263E	3699 691066	ALEKSANDR NIKITIN	{"email": "nikitina_17041958@postgrespro.ru", "phone": "+70032414001"}
0005433397485	DB70E3	5455 268300	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana051969@postgrespro.ru", "phone": "+70943192484"}
0005433397486	40FB87	5518 933372	NADEZHDA PAVLOVA	{"email": "pavlova_nadezhda-14081965@postgrespro.ru", "phone": "+70618056074"}
0005433397487	BD5937	7450 550880	DIANA OSIPOVA	{"phone": "+70806279199"}
0005433397488	D3BE0B	1233 985076	ALEKSANDRA ORLOVA	{"email": "orlova_a_121971@postgrespro.ru", "phone": "+70610964127"}
0005433397489	4AAD2A	3722 432997	NINA ZAKHAROVA	{"email": "nina-zakharova11111962@postgrespro.ru", "phone": "+70949107788"}
0005433397490	4AAD2A	0748 271561	PAVEL BARANOV	{"email": "baranov.pavel_28011965@postgrespro.ru", "phone": "+70734093629"}
0005433397491	DF95A8	0285 611768	ANDREY MIKHAYLOV	{"phone": "+70619479507"}
0005433397492	B2E8E0	9463 416548	KARINA OSIPOVA	{"phone": "+70770428572"}
0005433397493	B2E8E0	0368 061148	VALENTIN YAKOVLEV	{"email": "valentin_yakovlev-111979@postgrespro.ru", "phone": "+70137822651"}
0005433397494	BB33FC	5682 919532	VALERIYA YAKOVLEVA	{"email": "yakovlevav04101961@postgrespro.ru", "phone": "+70445077275"}
0005433397495	925F26	8710 778601	TAMARA NIKOLAEVA	{"email": "tamara_nikolaeva.031978@postgrespro.ru", "phone": "+70793181874"}
0005433397496	B240EE	9833 971829	ANATOLIY CHERNOV	{"email": "chernov_a_081977@postgrespro.ru", "phone": "+70408456523"}
0005433397497	DF963E	4157 882075	LYUDMILA AKIMOVA	{"email": "lyudmilaakimova111988@postgrespro.ru", "phone": "+70013413297"}
0005433397498	DF963E	4219 781671	NADEZHDA ILINA	{"phone": "+70014063496"}
0005433397499	1C8162	7399 833214	MIKHAIL ANDREEV	{"email": "andreev-mikhail_22061974@postgrespro.ru", "phone": "+70495471203"}
0005433397500	93AE6B	1300 138216	OLEG MOROZOV	{"email": "morozov_oleg_1983@postgrespro.ru", "phone": "+70685075908"}
0005433397501	BA06DF	8374 561839	IRINA VLASOVA	{"email": "vlasova.irina_121979@postgrespro.ru", "phone": "+70821561853"}
0005433397502	BA06DF	4885 451473	ROMAN KUZNECOV	{"phone": "+70897059965"}
0005433397503	6CC3AF	5401 464834	ALEKSANDR NOVIKOV	{"phone": "+70664932746"}
0005433397504	1C10BC	2505 969445	ELENA CHERNOVA	{"email": "elena-chernova.111982@postgrespro.ru", "phone": "+70149711669"}
0005433397505	1C10BC	2749 469897	INNA MAKAROVA	{"phone": "+70641931145"}
0005433397506	B37368	8379 327327	VALERIY NIKITIN	{"email": "v-nikitin-24091981@postgrespro.ru", "phone": "+70298484935"}
0005433397507	D03CEB	3859 882020	EVDOKIYA ZHURAVLEVA	{"email": "ezhuravleva_011966@postgrespro.ru", "phone": "+70771325242"}
0005433397508	444A90	5814 566348	ALENA FROLOVA	{"email": "frolova_alena_1979@postgrespro.ru", "phone": "+70724465449"}
0005433397509	95F008	7100 364061	RINAT ROMANOV	{"email": "romanov.rinat.1973@postgrespro.ru", "phone": "+70978343186"}
0005433397510	22DFA2	4672 853247	VALERIY MARTYNOV	{"phone": "+70270935576"}
0005433397511	22DFA2	7632 028088	YURIY GAVRILOV	{"phone": "+70281823396"}
0005433397512	3EE4D5	0007 032614	KARINA KISELEVA	{"phone": "+70799769027"}
0005433397513	428714	7272 669235	SVETLANA FEDOROVA	{"email": "svetlana-fedorova-1979@postgrespro.ru", "phone": "+70209833024"}
0005433397514	428714	3475 898156	ALBERT TIKHONOV	{"email": "tikhonov_a_041968@postgrespro.ru", "phone": "+70823810398"}
0005433397515	7E03B5	5858 351710	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr.31051981@postgrespro.ru", "phone": "+70621043098"}
0005433397516	7E03B5	1467 768506	IRINA ANDREEVA	{"phone": "+70424892536"}
0005433397517	9A2A7C	0960 789927	TATYANA MOISEEVA	{"email": "moiseevatatyana-15071977@postgrespro.ru", "phone": "+70797082522"}
0005433397518	9A2A7C	8806 351073	VLADISLAV MEDVEDEV	{"email": "v_medvedev121975@postgrespro.ru", "phone": "+70272561319"}
0005433397519	0388CD	0673 327771	ELENA KOROLEVA	{"phone": "+70236751253"}
0005433397520	E920A4	0177 150491	ANATOLIY KRASNOV	{"phone": "+70648811141"}
0005433397521	E920A4	4931 085572	VITALIY MOROZOV	{"phone": "+70546433902"}
0005433397522	E920A4	6719 458493	ANTONINA SAVELEVA	{"phone": "+70992912957"}
0005433397523	BCCBDA	1998 555850	ARTEM FEDOTOV	{"phone": "+70132963685"}
0005433397524	B95473	9594 923472	ALEKSANDR MAKAROV	{"phone": "+70484466781"}
0005433397525	B95473	6937 796041	IVAN GRIGOREV	{"phone": "+70820880873"}
0005433397526	7D9F38	7049 303142	OLGA NAUMOVA	{"email": "naumovao_041968@postgrespro.ru", "phone": "+70690224472"}
0005433397527	0AD862	3502 443047	VLADIMIR ZAYCEV	{"phone": "+70350224638"}
0005433397528	0CC5C8	8476 911997	VYACHESLAV FEDOTOV	{"email": "vyacheslav_fedotov09011970@postgrespro.ru", "phone": "+70767050597"}
0005433397529	1299DC	0394 364072	YURIY SCHERBAKOV	{"email": "y.scherbakov_17111980@postgrespro.ru", "phone": "+70420137417"}
0005433397530	17BD29	0684 264348	TAMARA KOROLEVA	{"phone": "+70410504045"}
0005433397531	17BD29	6560 788147	VLADISLAV GUSEV	{"phone": "+70220225751"}
0005433397532	73FCA5	2964 129029	VLADIMIR ROMANOV	{"email": "vromanov_1961@postgrespro.ru", "phone": "+70303098895"}
0005433397533	CD256E	6655 548228	SVETLANA BELOVA	{"email": "s_belova101970@postgrespro.ru", "phone": "+70961848589"}
0005433397534	CD256E	3669 653548	VALERIY SCHERBAKOV	{"phone": "+70356847585"}
0005433397535	343F51	2289 445085	OLGA KUZNECOVA	{"phone": "+70435175034"}
0005433397536	B86D46	7404 161225	NADEZHDA KUZNECOVA	{"phone": "+70773718449"}
0005433397537	B86D46	2977 209111	YANA BORISOVA	{"phone": "+70099135027"}
0005433397538	FAD802	1603 693605	ALEKSEY DMITRIEV	{"email": "dmitriev.aleksey14011960@postgrespro.ru", "phone": "+70279187499"}
0005433397539	FD06E1	7378 562615	VITALIY ZAKHAROV	{"email": "v-zakharov.24071972@postgrespro.ru", "phone": "+70263298552"}
0005433397540	FD06E1	5973 786113	ALEKSANDRA KUZNECOVA	{"email": "kuznecova_aleksandra_051981@postgrespro.ru", "phone": "+70678570672"}
0005433397541	6A58D3	7905 079678	RAMIL BORISOV	{"phone": "+70345876168"}
0005433397542	428424	5108 536459	AIDA ZAKHAROVA	{"phone": "+70679483483"}
0005433397543	9F5AFD	0614 721950	MAKSIM RODIONOV	{"email": "rodionov-maksim-26011980@postgrespro.ru", "phone": "+70237267353"}
0005433397600	3F435B	7148 899932	VSEVOLOD BORISOV	{"phone": "+70796117178"}
0005433397544	71B200	2923 783340	EVGENIYA KOZLOVA	{"email": "kozlovaevgeniya-18031971@postgrespro.ru", "phone": "+70379460421"}
0005433397545	BA6571	9442 842407	NINA DANILOVA	{"email": "danilovan.071966@postgrespro.ru", "phone": "+70025106481"}
0005433397546	7F8CDF	1096 065084	TATYANA AFANASEVA	{"email": "afanaseva-t1958@postgrespro.ru", "phone": "+70112571210"}
0005433397547	4373EC	8820 566064	ALEKSANDRA KISELEVA	{"phone": "+70622807709"}
0005433397548	F70195	5685 103153	ALEKSEY NIKITIN	{"email": "aleksey-nikitin.1967@postgrespro.ru", "phone": "+70778507630"}
0005433397549	B04929	5325 994979	YURIY STEPANOV	{"email": "stepanovy-021979@postgrespro.ru", "phone": "+70427453584"}
0005433397550	0121C7	9369 864285	VALENTIN ZHUKOV	{"phone": "+70650724153"}
0005433397551	9B7ACF	0592 935615	EKATERINA SOROKINA	{"email": "esorokina_11121975@postgrespro.ru", "phone": "+70283095414"}
0005433397552	2866D7	6152 567295	MIKHAIL SOROKIN	{"email": "sorokin_m.121978@postgrespro.ru", "phone": "+70459992917"}
0005433397553	2299B1	6950 697103	ELIZAVETA VOROBEVA	{"phone": "+70634559165"}
0005433397554	8B059C	4219 747857	ANTON MATVEEV	{"phone": "+70838463965"}
0005433397555	8086D2	2754 462490	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila-10061973@postgrespro.ru", "phone": "+70942307745"}
0005433397556	4E3472	5829 983869	IRINA KAZAKOVA	{"phone": "+70805048380"}
0005433397557	897761	8767 062268	VALENTINA ABRAMOVA	{"phone": "+70290233187"}
0005433397558	897761	3159 849580	ELVIRA ERMAKOVA	{"phone": "+70238579868"}
0005433397559	8B37B3	9499 600863	ALEKSEY IVANOV	{"email": "ivanova-081980@postgrespro.ru", "phone": "+70262974320"}
0005433397560	8B37B3	8003 645799	NADEZHDA NIKITINA	{"phone": "+70378807209"}
0005433397561	306A85	1578 857703	ALEKSANDR NAZAROV	{"email": "nazarov.aleksandr.111976@postgrespro.ru", "phone": "+70896674268"}
0005433397562	7FCD98	5597 092992	ILYA ZHUKOV	{"email": "ilya_zhukov.1985@postgrespro.ru", "phone": "+70412380104"}
0005433397563	435DC6	7583 468297	SERGEY ORLOV	{"email": "orlov_sergey21071978@postgrespro.ru", "phone": "+70317741253"}
0005433397564	435DC6	8612 749799	IVAN IVANOV	{"email": "ivanovivan_011962@postgrespro.ru", "phone": "+70488535208"}
0005433397565	181893	1528 625514	VASILIY GRIGOREV	{"phone": "+70189520978"}
0005433397566	1D3BFF	5591 107089	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr-1960@postgrespro.ru", "phone": "+70238530370"}
0005433397567	1D3BFF	1832 575892	NATALYA GORBUNOVA	{"email": "gorbunova-n_121978@postgrespro.ru", "phone": "+70022760881"}
0005433397568	C4DF4A	6765 859139	VASILIY ZAKHAROV	{"phone": "+70305041415"}
0005433397569	C4DF4A	7462 790910	SOFIYA VOLKOVA	{"email": "volkova-sofiya.011969@postgrespro.ru", "phone": "+70544168703"}
0005433397570	B6C5EE	1534 153731	EKATERINA ABRAMOVA	{"phone": "+70531586637"}
0005433397571	FE6AB3	6990 746603	NIKOLAY KULIKOV	{"phone": "+70545961385"}
0005433397572	2AC4FD	8994 724839	ANTONINA FADEEVA	{"email": "fadeeva.antonina061978@postgrespro.ru", "phone": "+70263884530"}
0005433397573	030595	5836 739177	TATYANA KOVALEVA	{"phone": "+70809646211"}
0005433397574	AEBEE0	3229 947992	MARIYA ERMAKOVA	{"phone": "+70870692569"}
0005433397575	AEBEE0	6632 922441	VYACHESLAV KUZNECOV	{"phone": "+70415971305"}
0005433397576	AEBEE0	6218 100012	SVETLANA FROLOVA	{"phone": "+70813270453"}
0005433397577	7808EE	8597 571987	TAMARA ILINA	{"email": "ilina.t_18041968@postgrespro.ru", "phone": "+70365759097"}
0005433397578	29B95D	9547 409666	LYUBOV NIKOLAEVA	{"phone": "+70320947580"}
0005433397579	29B95D	4563 086003	VERA ABRAMOVA	{"email": "vabramova_1965@postgrespro.ru", "phone": "+70675194360"}
0005433397580	61527E	2511 315848	ALEKSEY POPOV	{"phone": "+70507548524"}
0005433397581	E3B84B	2525 052326	ALENA KUZNECOVA	{"email": "kuznecovaalena.111971@postgrespro.ru", "phone": "+70722803905"}
0005433397582	E3B84B	7300 803714	RUSLAN TIMOFEEV	{"phone": "+70908169728"}
0005433397583	EB3FB4	5504 856782	ANDREY OSIPOV	{"phone": "+70900627042"}
0005433397584	EB3FB4	4596 761589	VLADIMIR PETROV	{"email": "petrov.vladimir05041960@postgrespro.ru", "phone": "+70348217358"}
0005433397585	9DF05F	7776 830431	ANDREY VOLKOV	{"email": "volkov_a-29101974@postgrespro.ru", "phone": "+70190625412"}
0005433397586	6393C3	1648 043750	IGOR TIKHONOV	{"phone": "+70586646915"}
0005433397587	6A93A9	3988 302508	TAMARA DAVYDOVA	{"email": "t-davydova-27031974@postgrespro.ru", "phone": "+70421351305"}
0005433397588	6A93A9	3664 360433	ZOYA SEMENOVA	{"email": "zsemenova081975@postgrespro.ru", "phone": "+70655809761"}
0005433397589	6AC8AB	7701 330720	LYUBOV FEDOROVA	{"phone": "+70937858770"}
0005433397590	166DBB	4290 978207	DENIS KAZAKOV	{"email": "dkazakov.111976@postgrespro.ru", "phone": "+70916651038"}
0005433397591	A83EB9	5337 381256	SERGEY FOMIN	{"phone": "+70927997033"}
0005433397592	FCFC07	0961 618550	ALEKSANDR STEPANOV	{"email": "a_stepanov.061984@postgrespro.ru", "phone": "+70034218261"}
0005433397593	426AC4	0260 083788	NINA KUZMINA	{"phone": "+70147045523"}
0005433397594	E97A52	7073 416739	VALENTINA GUSEVA	{"email": "guseva.valentina1978@postgrespro.ru", "phone": "+70479147205"}
0005433397595	F0277D	8838 257312	VYACHESLAV SEMENOV	{"email": "semenov-v.061978@postgrespro.ru", "phone": "+70114120749"}
0005433397596	CB8C05	4972 598574	ANASTASIYA ZAYCEVA	{"email": "zayceva-a01121962@postgrespro.ru", "phone": "+70898758475"}
0005433397597	BC76AA	2946 947592	ANASTASIYA MAKAROVA	{"email": "makarova.a_1974@postgrespro.ru", "phone": "+70065211189"}
0005433397598	E6C08E	1089 086517	NATALIYA ZHURAVLEVA	{"email": "zhuravleva.nataliya011983@postgrespro.ru", "phone": "+70580507307"}
0005433397599	ADD335	8849 822785	PAVEL MIRONOV	{"email": "mironov_p.25051963@postgrespro.ru", "phone": "+70523522622"}
0005433397601	BC6664	3985 844904	TATYANA ILINA	{"phone": "+70199596323"}
0005433397602	BC6664	1837 745942	NIKOLAY SAVELEV	{"email": "nikolay-savelev-22101979@postgrespro.ru", "phone": "+70903106203"}
0005433397603	ACA943	3635 907328	ALLA KULIKOVA	{"phone": "+70462297949"}
0005433397604	ACA943	7154 842909	LYUDMILA MALYSHEVA	{"phone": "+70641717536"}
0005433397605	972905	8305 853992	NATALIYA STEPANOVA	{"phone": "+70751932129"}
0005433397606	6AD5EE	7869 851568	NIKITA SIDOROV	{"phone": "+70285060877"}
0005433397607	2F9C08	9133 494314	TAMARA AKIMOVA	{"phone": "+70313036780"}
0005433397608	9D2B4C	6804 151398	SERGEY SOKOLOV	{"phone": "+70326167442"}
0005433397609	6BE802	1506 854430	VITALIY STEPANOV	{"phone": "+70065111741"}
0005433397610	D53838	8691 394718	FANIYA MELNIKOVA	{"email": "melnikova-faniya.1977@postgrespro.ru", "phone": "+70483302426"}
0005433397611	DFA22B	4540 338319	NIKOLAY TARASOV	{"email": "n.tarasov.1970@postgrespro.ru", "phone": "+70823238344"}
0005433397612	33C4E0	1432 850978	EVGENIY TIMOFEEV	{"email": "etimofeev-1972@postgrespro.ru", "phone": "+70963687675"}
0005433397613	5320EC	2274 629861	DANILA POPOV	{"email": "d_popov.24111964@postgrespro.ru", "phone": "+70179109606"}
0005433397614	5320EC	0283 872730	DMITRIY BORISOV	{"email": "dborisov1957@postgrespro.ru", "phone": "+70725692537"}
0005433397615	98A7EA	1994 123576	VLADIMIR GORBUNOV	{"email": "vladimir_gorbunov.121985@postgrespro.ru", "phone": "+70899377307"}
0005433397616	98A7EA	6118 530155	VLADIMIR SOLOVEV	{"phone": "+70504688264"}
0005433397617	AE5D9E	0037 880761	ALFIYA SEMENOVA	{"email": "semenovaalfiya-04031978@postgrespro.ru", "phone": "+70880207518"}
0005433397618	56B054	7761 295191	VLADIMIR FILIPPOV	{"email": "vladimir-filippov-1973@postgrespro.ru", "phone": "+70458354219"}
0005433397619	D9720C	5312 211819	EKATERINA TARASOVA	{"phone": "+70203935950"}
0005433397620	D9720C	9362 677662	GALIYA IVANOVA	{"phone": "+70953224472"}
0005433397621	DC9473	2227 570158	RUSTAM YAKOVLEV	{"email": "r-yakovlev-01081959@postgrespro.ru", "phone": "+70528706366"}
0005433397622	DC9473	8830 179740	VLADIMIR DAVYDOV	{"email": "davydov.v19061964@postgrespro.ru", "phone": "+70121194153"}
0005433397623	088E72	6414 314559	LYUBOV MALYSHEVA	{"phone": "+70015882185"}
0005433397624	938D02	1579 643425	VARVARA KOROLEVA	{"phone": "+70269113886"}
0005433397625	863AA0	5002 311132	LYUBOV PETROVA	{"phone": "+70221601280"}
0005433397626	863AA0	3541 860151	ROZA SMIRNOVA	{"phone": "+70781916139"}
0005433397627	800D9F	6480 723196	IGOR DAVYDOV	{"phone": "+70193627114"}
0005433397628	0B6707	6599 193320	ALEKSANDR TIKHONOV	{"email": "a_tikhonov-051972@postgrespro.ru", "phone": "+70094870184"}
0005433397629	F99775	4357 745739	VLADIMIR AFANASEV	{"email": "afanasev_vladimir-07081971@postgrespro.ru", "phone": "+70191711302"}
0005433397630	F99775	0076 802816	VALERIY SIDOROV	{"email": "sidorov-valeriy.1985@postgrespro.ru", "phone": "+70144659554"}
0005433397631	90713A	5238 519511	ALEKSANDR KAZAKOV	{"email": "aleksandr-kazakov-24011968@postgrespro.ru", "phone": "+70081257657"}
0005433397632	7D2B4C	2194 811101	SERGEY ANTONOV	{"phone": "+70158424690"}
0005433397633	7D2B4C	0919 515211	DMITRIY KOROLEV	{"phone": "+70164944687"}
0005433397634	F8A48F	9313 204133	SOFYA MASLOVA	{"email": "s-maslova.071967@postgrespro.ru", "phone": "+70429032343"}
0005433397635	1B95E4	0224 147153	VERA MAKAROVA	{"phone": "+70574289152"}
0005433397636	6C70F7	5801 920789	KIRILL SOKOLOV	{"email": "sokolov.k-06011986@postgrespro.ru", "phone": "+70862331350"}
0005433397637	6C70F7	8890 003555	VALENTINA SOROKINA	{"phone": "+70109283243"}
0005433397638	011BB0	4803 787649	VALERIY GERASIMOV	{"email": "gerasimov.v-091978@postgrespro.ru", "phone": "+70969378614"}
0005433397639	9DBA66	9360 020086	VIKTOR GERASIMOV	{"email": "viktor.gerasimov_051974@postgrespro.ru", "phone": "+70425488700"}
0005433397640	DEE9AD	7740 618810	ALEKSANDR IVANOV	{"email": "aivanov04051959@postgrespro.ru", "phone": "+70543759129"}
0005433397815	15D62C	9205 875126	ANDREY ORLOV	{"phone": "+70285069250"}
0005433397641	DEE9AD	4926 852187	SERGEY KUZNECOV	{"email": "kuznecov.s-1968@postgrespro.ru", "phone": "+70912580582"}
0005433397642	C0C175	7739 871114	ZLATA KULIKOVA	{"phone": "+70095674649"}
0005433397643	C0C175	7171 712528	DANIYA ORLOVA	{"email": "daniya-orlova-1979@postgrespro.ru", "phone": "+70999526497"}
0005433397644	8304B0	6215 395105	ANNA POLYAKOVA	{"email": "polyakovaa_081959@postgrespro.ru", "phone": "+70289245205"}
0005433397645	8304B0	5241 673366	ALEKSANDR PAVLOV	{"email": "pavlov.a101968@postgrespro.ru", "phone": "+70886719179"}
0005433397646	F48B9C	5105 422513	ALEKSANDR BONDARENKO	{"email": "aleksandr_bondarenko-101971@postgrespro.ru", "phone": "+70475323281"}
0005433397647	F48B9C	6526 784071	RAISA IVANOVA	{"email": "r-ivanova-081976@postgrespro.ru", "phone": "+70250800962"}
0005433397648	F48B9C	9631 258800	ANNA DENISOVA	{"email": "annadenisova.20031982@postgrespro.ru", "phone": "+70700274264"}
0005433397649	C2904E	0411 965293	KRISTINA MASLOVA	{"phone": "+70028908157"}
0005433397650	101619	4539 480644	VLADIMIR KUZNECOV	{"email": "kuznecov-v_01121985@postgrespro.ru", "phone": "+70949517196"}
0005433397651	101619	7327 108282	ANATOLIY ILIN	{"phone": "+70864424894"}
0005433397652	F5A55C	6377 708702	OLGA ANISIMOVA	{"email": "anisimova.olga_1965@postgrespro.ru", "phone": "+70833427782"}
0005433397653	0A9916	9295 795882	NIKOLAY FEDOTOV	{"email": "fedotovn_04041974@postgrespro.ru", "phone": "+70911692882"}
0005433397654	0A9916	9528 644572	TIMOFEY NIKITIN	{"phone": "+70008806971"}
0005433397655	9AF76C	7585 940697	POLINA RODIONOVA	{"email": "rodionova_p.01081972@postgrespro.ru", "phone": "+70368745781"}
0005433397711	7EFEE3	2479 702895	ANATOLIY ROMANOV	{"phone": "+70314300391"}
0005433397656	18AF5A	7422 985669	OKSANA KUZNECOVA	{"email": "oksana_kuznecova-01101977@postgrespro.ru", "phone": "+70088200077"}
0005433397657	526CC9	3968 863407	ANDREY ZAYCEV	{"email": "zaycevandrey-121976@postgrespro.ru", "phone": "+70109433156"}
0005433397658	486366	7735 787661	TAMARA KOZLOVA	{"email": "tamarakozlova.02101967@postgrespro.ru", "phone": "+70920272069"}
0005433397659	486366	2278 276590	MARIYA KOROLEVA	{"phone": "+70399819642"}
0005433397660	486366	8337 906708	YULIYA SIDOROVA	{"email": "sidorova-yuliya_1969@postgrespro.ru", "phone": "+70114691257"}
0005433397661	85A932	5732 473300	ANDREY IVANOV	{"email": "ivanov_andrey_21121957@postgrespro.ru", "phone": "+70100355645"}
0005433397662	B068D2	8065 180899	KIRILL FILIPPOV	{"phone": "+70342532489"}
0005433397663	2F11AA	2077 135690	VALERIY GORBUNOV	{"phone": "+70280855106"}
0005433397664	263608	4190 840252	VLADIMIR VOLKOV	{"email": "volkov.vladimir09061974@postgrespro.ru", "phone": "+70133243707"}
0005433397665	263608	4614 642427	OLESYA BELYAEVA	{"email": "belyaeva.olesya_051961@postgrespro.ru", "phone": "+70359504784"}
0005433397666	263608	9019 920433	OLEG SCHERBAKOV	{"email": "olegscherbakov_101982@postgrespro.ru", "phone": "+70137540250"}
0005433397667	0874E9	1729 199365	ALEKSANDR AFANASEV	{"email": "afanasev-a15121974@postgrespro.ru", "phone": "+70733512286"}
0005433397668	0874E9	7654 234351	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_071959@postgrespro.ru", "phone": "+70488550357"}
0005433397669	0874E9	7774 779485	NATALYA ZAYCEVA	{"email": "natalya_zayceva_1955@postgrespro.ru", "phone": "+70789889934"}
0005433397670	1B5F0D	1884 829165	LIDIYA ABRAMOVA	{"phone": "+70068036809"}
0005433397671	BB28C6	2954 686257	ALEKSANDR BELOV	{"phone": "+70255833062"}
0005433397672	AE90EC	8749 968288	IRINA SCHERBAKOVA	{"email": "scherbakovai-1982@postgrespro.ru", "phone": "+70781747496"}
0005433397673	AE90EC	7640 514050	ANDREY SOROKIN	{"email": "andrey-sorokin011980@postgrespro.ru", "phone": "+70700740640"}
0005433397674	AE90EC	1902 877753	ELIZAVETA DANILOVA	{"email": "e-danilova_1969@postgrespro.ru", "phone": "+70210505519"}
0005433397675	4FEBBB	4907 002959	GENNADIY IVANOV	{"email": "ivanov_g.14071966@postgrespro.ru", "phone": "+70939804970"}
0005433397676	D7396A	8586 543415	KRISTINA SEMENOVA	{"phone": "+70353562886"}
0005433397677	C2EF45	1567 320270	LYUBOV MAKAROVA	{"phone": "+70450599035"}
0005433397678	C76A45	9124 171308	GALINA ALEKSANDROVA	{"phone": "+70458806256"}
0005433397679	C76A45	7728 888275	VALENTINA KAZAKOVA	{"email": "kazakovav061963@postgrespro.ru", "phone": "+70020932632"}
0005433397680	C76A45	5788 599944	RAISA FILATOVA	{"phone": "+70714600385"}
0005433397681	3CBF17	4401 814720	ARTEMIY OSIPOV	{"phone": "+70724409856"}
0005433397682	ADC7E7	1756 001181	ANNA KISELEVA	{"email": "kiseleva.anna_021974@postgrespro.ru", "phone": "+70380433143"}
0005433397683	153050	7408 950746	ILYA NOVIKOV	{"email": "novikovi061983@postgrespro.ru", "phone": "+70969489600"}
0005433397684	CE93AA	2334 109749	LIDIYA ZHURAVLEVA	{"email": "zhuravleva.lidiya27071974@postgrespro.ru", "phone": "+70474846497"}
0005433397685	613EC3	8265 348513	LYUBOV VASILEVA	{"email": "vasileva-l03091960@postgrespro.ru", "phone": "+70370991713"}
0005433397686	B2941C	7176 705640	RAISA ZHURAVLEVA	{"email": "raisa.zhuravleva_051979@postgrespro.ru", "phone": "+70476734101"}
0005433397687	9C20EB	4583 796613	NAILYA KOROLEVA	{"phone": "+70974192026"}
0005433397688	458936	2050 161745	EVGENIY GUSEV	{"email": "evgeniy-gusev1974@postgrespro.ru", "phone": "+70923127683"}
0005433397689	FC6B00	6904 500058	LYUBOV ROMANOVA	{"phone": "+70409739218"}
0005433397690	505B06	7677 843140	VIKTORIYA LEBEDEVA	{"phone": "+70567355805"}
0005433397691	505B06	6418 792663	ANDREY CHERNOV	{"phone": "+70457714379"}
0005433397692	505B06	9164 084677	OLGA KAZAKOVA	{"email": "o_kazakova-1979@postgrespro.ru", "phone": "+70065172225"}
0005433397693	C04AE4	1067 938855	ELVIRA MASLOVA	{"email": "elvira.maslova.021982@postgrespro.ru", "phone": "+70111399333"}
0005433397694	C04AE4	7158 527992	MARINA BARANOVA	{"email": "baranova_marina_1970@postgrespro.ru", "phone": "+70613967824"}
0005433397695	93C64E	8486 948570	ILYA MOROZOV	{"phone": "+70843124339"}
0005433397696	3EAA20	1480 022935	FEDOR KOZLOV	{"email": "fedor.kozlov_1980@postgrespro.ru", "phone": "+70823158777"}
0005433397697	1A338F	3520 428200	ANNA BORISOVA	{"phone": "+70642578463"}
0005433397698	85E644	7600 657427	ALEKSANDR AFANASEV	{"email": "a_afanasev_04111987@postgrespro.ru", "phone": "+70014872051"}
0005433397699	8D93DB	4386 382138	LYUDMILA AKIMOVA	{"phone": "+70300946131"}
0005433397700	8D93DB	7252 093530	VIKTOR BELOV	{"phone": "+70335541308"}
0005433397701	8D93DB	2503 397931	ALEKSEY SEMENOV	{"email": "a-semenov.23081972@postgrespro.ru", "phone": "+70512403010"}
0005433397702	B7A600	6154 092785	YURIY MIKHAYLOV	{"email": "yuriy_mikhaylov_081966@postgrespro.ru", "phone": "+70216292204"}
0005433397703	5AB984	0052 608832	YULIYA ALEKSEEVA	{"email": "yuliya_alekseeva_1970@postgrespro.ru", "phone": "+70686402358"}
0005433397704	F5FFC0	3225 853297	ALLA KARPOVA	{"email": "karpova_alla-031977@postgrespro.ru", "phone": "+70737098956"}
0005433397705	F5FFC0	9176 373887	VLADIMIR GUSEV	{"phone": "+70364444834"}
0005433397706	F5FFC0	7483 332875	DMITRIY ANDREEV	{"email": "dmitriy-andreev-1970@postgrespro.ru", "phone": "+70231223513"}
0005433397707	A090C9	2471 805030	ILYA PETROV	{"email": "petrov-i-15051962@postgrespro.ru", "phone": "+70364744482"}
0005433397708	35AFE6	3834 103995	MIKHAIL OSIPOV	{"phone": "+70046638435"}
0005433397709	567CD5	5849 181935	VALENTINA DMITRIEVA	{"phone": "+70580404257"}
0005433397710	7EFEE3	2058 812428	ALEKSEY TIKHONOV	{"phone": "+70103315645"}
0005433397712	7EFEE3	1583 607546	KIRILL BONDARENKO	{"phone": "+70027180669"}
0005433397713	9E34E6	1131 995855	MARGARITA VOLKOVA	{"email": "volkova.margarita_1970@postgrespro.ru", "phone": "+70782118363"}
0005433397714	40BC47	6939 586386	TATYANA MATVEEVA	{"email": "t-matveeva-1977@postgrespro.ru", "phone": "+70038319409"}
0005433397715	C2EAB0	8147 710074	ALBINA NIKOLAEVA	{"email": "a_nikolaeva-18071991@postgrespro.ru", "phone": "+70681821925"}
0005433397716	D73DA2	6754 410582	VLADIMIR BARANOV	{"phone": "+70444416937"}
0005433397717	A2927C	7122 063940	EKATERINA NIKITINA	{"email": "nikitina-ekaterina_1979@postgrespro.ru", "phone": "+70587884651"}
0005433397718	A2927C	4559 558479	NADEZHDA KULIKOVA	{"phone": "+70948702354"}
0005433397719	F352B8	5082 537102	ANTONINA TIKHONOVA	{"email": "tikhonova-a1969@postgrespro.ru", "phone": "+70315048501"}
0005433397720	F352B8	7130 017684	ANATOLIY GORBUNOV	{"email": "anatoliy.gorbunov.1983@postgrespro.ru", "phone": "+70617318409"}
0005433397721	694851	1114 749750	IRINA CHERNOVA	{"email": "irina.chernova_1967@postgrespro.ru", "phone": "+70741588392"}
0005433397722	29EE47	5026 884210	YURIY SEMENOV	{"phone": "+70170894036"}
0005433397723	642435	3109 504213	DMITRIY BORISOV	{"email": "dborisov1988@postgrespro.ru", "phone": "+70928385209"}
0005433397724	33A504	2341 424740	ARINA ANDREEVA	{"email": "arina.andreeva-1966@postgrespro.ru", "phone": "+70659593814"}
0005433397725	33A504	4493 502598	PETR NIKITIN	{"email": "petrnikitin.1972@postgrespro.ru", "phone": "+70190809968"}
0005433397726	4FA246	2717 865417	OLEG KULIKOV	{"phone": "+70639924927"}
0005433397727	66BF62	6310 986059	ANASTASIYA NOVIKOVA	{"email": "novikova_a_08071970@postgrespro.ru", "phone": "+70458991898"}
0005433397728	66BF62	3109 639638	NADEZHDA IVANOVA	{"email": "n-ivanova16111973@postgrespro.ru", "phone": "+70323125870"}
0005433397729	85F7DA	5061 679981	DMITRIY SIDOROV	{"email": "dmitriy_sidorov1971@postgrespro.ru", "phone": "+70622489171"}
0005433397730	85F7DA	7747 728345	TATYANA DMITRIEVA	{"phone": "+70413193033"}
0005433397731	F23EAC	5440 392937	SERGEY POPOV	{"email": "popov.sergey061975@postgrespro.ru", "phone": "+70143377823"}
0005433397732	AB5A8B	4255 281896	ALEKSANDR NAUMOV	{"phone": "+70963710890"}
0005433397733	0D29B5	2949 918568	ROMAN ZHUKOV	{"phone": "+70399380927"}
0005433397734	0D29B5	3392 465293	VALENTINA FILIPPOVA	{"phone": "+70939773468"}
0005433397735	65167B	6372 009447	VALERIY ABRAMOV	{"phone": "+70583380878"}
0005433397736	2979B6	2871 266902	NIKOLAY TIKHONOV	{"phone": "+70970400926"}
0005433397737	BC0F85	5393 219515	NINA OVCHINNIKOVA	{"email": "ovchinnikova-nina061970@postgrespro.ru", "phone": "+70208160103"}
0005433397738	D8F2CA	2308 900974	LYUDMILA ZAYCEVA	{"phone": "+70554152879"}
0005433397739	D8F2CA	3676 359874	VITALIY GRIGOREV	{"email": "grigorevv121982@postgrespro.ru", "phone": "+70132508303"}
0005433397740	C8F89B	8404 349023	MAKSIM SOLOVEV	{"email": "solovevm_1979@postgrespro.ru", "phone": "+70962953956"}
0005433397741	8AD7DF	4057 588837	VYACHESLAV MEDVEDEV	{"phone": "+70224368474"}
0005433397742	8AD7DF	8892 731231	IRINA KOMAROVA	{"email": "i.komarova1973@postgrespro.ru", "phone": "+70144415416"}
0005433397743	8AD7DF	1717 928700	VLADIMIR MAKAROV	{"phone": "+70777336185"}
0005433397744	B4FCAF	1449 585793	ANATOLIY MELNIKOV	{"email": "anatoliy-melnikov-121976@postgrespro.ru", "phone": "+70577688039"}
0005433397745	884B7E	6473 217302	YULIYA KRASNOVA	{"email": "ykrasnova18091966@postgrespro.ru", "phone": "+70363240202"}
0005433397746	884B7E	4670 867058	VERA BORISOVA	{"phone": "+70728738014"}
0005433397747	D8B82E	3292 514598	BOGDAN VASILEV	{"email": "vasilev.bogdan.1976@postgrespro.ru", "phone": "+70333769685"}
0005433397748	D8B82E	9009 265863	TATYANA ALEKSEEVA	{"phone": "+70017081340"}
0005433397749	CE2256	4802 129958	EKATERINA TIMOFEEVA	{"phone": "+70618642678"}
0005433397750	FAAF85	2062 809929	NIKOLAY BONDARENKO	{"email": "nikolay_bondarenko_1967@postgrespro.ru", "phone": "+70855786107"}
0005433397751	FAAF85	6353 024369	VALENTINA AFANASEVA	{"email": "afanasevavalentina.041976@postgrespro.ru", "phone": "+70742048081"}
0005433397752	3A7E6B	7441 103830	SERGEY ISAEV	{"phone": "+70897446183"}
0005433397753	3A7E6B	2772 005812	ELLA SEMENOVA	{"email": "ellasemenova-091965@postgrespro.ru", "phone": "+70597049352"}
0005433397754	FC85B7	8030 971334	ELENA ORLOVA	{"email": "elena_orlova-08031976@postgrespro.ru", "phone": "+70180910958"}
0005433397755	ABAF05	9539 824601	BORIS KUZNECOV	{"email": "kuznecovboris27041971@postgrespro.ru", "phone": "+70363771568"}
0005433397756	88F6DD	3105 933816	OLGA FOMINA	{"email": "o.fomina.16011972@postgrespro.ru", "phone": "+70068222236"}
0005433397757	687139	5200 659281	VALERIYA ROMANOVA	{"email": "valeriya_romanova_1975@postgrespro.ru", "phone": "+70670736078"}
0005433397758	741BA0	2666 813897	ILONA ABRAMOVA	{"email": "abramovailona-1968@postgrespro.ru", "phone": "+70263178132"}
0005433397759	741BA0	0125 782448	RADIK KAZAKOV	{"phone": "+70005523923"}
0005433397760	741BA0	4936 458657	SABINA KARPOVA	{"email": "sabina_karpova-1975@postgrespro.ru", "phone": "+70016839806"}
0005433397761	E6EA1C	7275 668854	LYUBOV MIKHAYLOVA	{"email": "l_mikhaylova_03111974@postgrespro.ru", "phone": "+70319116604"}
0005433397762	DB92DB	7191 967679	ALEKSANDR KONOVALOV	{"email": "a-konovalov_121959@postgrespro.ru", "phone": "+70274652955"}
0005433397763	FC608E	0624 107947	PAVEL MEDVEDEV	{"email": "p-medvedev-1971@postgrespro.ru", "phone": "+70386072298"}
0005433397764	890487	3678 144081	VALENTINA KULIKOVA	{"email": "v.kulikova.16071976@postgrespro.ru", "phone": "+70854559731"}
0005433397765	890487	8450 354932	VIKTORIYA MOROZOVA	{"phone": "+70072710157"}
0005433397766	2E4FCE	9673 717477	MIKHAIL VASILEV	{"email": "m_vasilev.1981@postgrespro.ru", "phone": "+70339367149"}
0005433397767	8D712A	1080 894444	ELENA SMIRNOVA	{"email": "smirnova-e_051969@postgrespro.ru", "phone": "+70429817660"}
0005433397768	8D712A	3203 451496	DMITRIY TARASOV	{"phone": "+70489525179"}
0005433397769	3887F4	0798 385618	ALEKSANDR KOROLEV	{"email": "korolev-aleksandr-111972@postgrespro.ru", "phone": "+70631965388"}
0005433397770	D5DC25	0423 336136	NATALYA KAZAKOVA	{"email": "kazakovanatalya071982@postgrespro.ru", "phone": "+70954559319"}
0005433397771	4C7C71	7848 674342	ALEKSANDR DMITRIEV	{"phone": "+70050095178"}
0005433397772	4C7C71	4905 456629	GALINA NIKITINA	{"email": "g-nikitina_23081972@postgrespro.ru", "phone": "+70036466321"}
0005433397773	4C7C71	2538 921938	OKSANA MIRONOVA	{"email": "mironova_oksana.07111974@postgrespro.ru", "phone": "+70060160259"}
0005433397774	164DA3	9803 005252	MAKSIM FILIPPOV	{"email": "mfilippov061979@postgrespro.ru", "phone": "+70513857793"}
0005433397775	DC28A3	3646 859381	TATYANA SAVELEVA	{"phone": "+70600576063"}
0005433397776	2D02B6	9617 027093	DMITRIY GORBUNOV	{"email": "dmitriygorbunov.1978@postgrespro.ru", "phone": "+70640002675"}
0005433397777	2D02B6	8945 338854	ALBERT ZAYCEV	{"email": "albert.zaycev-11111970@postgrespro.ru", "phone": "+70470979440"}
0005433397778	5C32AD	0089 936467	NADEZHDA ILINA	{"email": "ilina_nadezhda_121971@postgrespro.ru", "phone": "+70013001928"}
0005433397779	5C32AD	8942 237184	SVETLANA ROMANOVA	{"phone": "+70387731133"}
0005433397780	145833	9748 588128	KLAVDIYA TARASOVA	{"email": "tarasova_klavdiya1975@postgrespro.ru", "phone": "+70535305277"}
0005433397781	B55FE0	5763 850636	MARINA VOLKOVA	{"phone": "+70809275437"}
0005433397782	EA21E1	5123 652075	NATALIYA OSIPOVA	{"email": "nataliya-osipova-01081968@postgrespro.ru", "phone": "+70205246355"}
0005433397783	EA21E1	5071 148438	ALEKSANDR MATVEEV	{"email": "aleksandrmatveev.28011975@postgrespro.ru", "phone": "+70361616979"}
0005433397784	09BF81	3095 326729	ANNA SERGEEVA	{"email": "sergeeva_anna-1967@postgrespro.ru", "phone": "+70670386214"}
0005433397785	6E6C5F	7478 741212	LIDIYA ZAYCEVA	{"phone": "+70236865423"}
0005433397786	9BC48F	6877 700849	EVGENIY GRIGOREV	{"phone": "+70555814295"}
0005433397787	D4AAB3	2115 255457	IRINA BORISOVA	{"email": "i.borisova_1970@postgrespro.ru", "phone": "+70201538812"}
0005433397788	044CE5	0717 125575	IVAN PETROV	{"email": "i-petrov-1978@postgrespro.ru", "phone": "+70561381556"}
0005433397789	B03494	1470 667065	VIKTOR IVANOV	{"email": "v-ivanov_21021975@postgrespro.ru", "phone": "+70457063941"}
0005433397790	B03494	9094 573621	MIKHAIL SEMENOV	{"email": "msemenov.06031964@postgrespro.ru", "phone": "+70500273885"}
0005433397791	ABD916	3901 350998	TATYANA NIKITINA	{"email": "nikitina_tatyana.061967@postgrespro.ru", "phone": "+70204138659"}
0005433397792	ABD916	2582 624656	NIKOLAY GRIGOREV	{"phone": "+70711709044"}
0005433397793	71DE1F	2076 706560	ARTEM FEDOTOV	{"email": "fedotov-artem23041970@postgrespro.ru", "phone": "+70494457320"}
0005433397794	029C97	4414 732029	ANNA STEPANOVA	{"phone": "+70785736254"}
0005433397795	3E2791	2731 781661	ELENA OVCHINNIKOVA	{"phone": "+70153419135"}
0005433397796	3E2791	8945 249832	EKATERINA IVANOVA	{"phone": "+70433984185"}
0005433397797	B5CAB4	2329 427132	LYUBOV SERGEEVA	{"phone": "+70981343855"}
0005433397798	293C90	3720 658713	ELENA KALININA	{"phone": "+70380472415"}
0005433397799	C8E1BA	1410 812282	OLGA IVANOVA	{"email": "o_ivanova-02071979@postgrespro.ru", "phone": "+70665435687"}
0005433397800	5C681B	1874 116555	YULIYA SEMENOVA	{"email": "y.semenova_21091974@postgrespro.ru", "phone": "+70063995772"}
0005433397801	5C681B	6766 268410	LILIYA KUDRYASHOVA	{"email": "kudryashova-liliya1987@postgrespro.ru", "phone": "+70127848427"}
0005433397802	8587CF	4155 854937	ALEKSANDR MARTYNOV	{"email": "martynov_a.1969@postgrespro.ru", "phone": "+70660227547"}
0005433397803	8587CF	5265 584456	PAVEL NIKOLAEV	{"phone": "+70904063513"}
0005433397804	A6D966	1413 673719	EVGENIYA MIRONOVA	{"email": "evgeniyamironova1970@postgrespro.ru", "phone": "+70809657259"}
0005433397805	DAE7AB	5816 035102	ANATOLIY KRASNOV	{"email": "a.krasnov17051976@postgrespro.ru", "phone": "+70291774164"}
0005433397806	641F3E	5812 916256	SERGEY YAKOVLEV	{"phone": "+70577627264"}
0005433397807	C9AE3F	4122 254515	ALEKSANDR NAUMOV	{"email": "anaumov-21031978@postgrespro.ru", "phone": "+70955870632"}
0005433397808	C9AE3F	4152 481404	ZINAIDA KOVALEVA	{"phone": "+70580404394"}
0005433397809	159D57	4888 094779	MAKSIM ROMANOV	{"email": "maksimromanov1972@postgrespro.ru", "phone": "+70081372536"}
0005433397810	23B1BF	0708 552152	VALERIYA MIRONOVA	{"email": "mironova.v111984@postgrespro.ru", "phone": "+70512489826"}
0005433397811	5C0B27	7612 660637	EKATERINA STEPANOVA	{"phone": "+70579877759"}
0005433397812	5C0B27	1879 241085	LYUBOV NESTEROVA	{"email": "l-nesterova.031964@postgrespro.ru", "phone": "+70891367342"}
0005433397813	5C0B27	4917 258230	NIKOLAY POPOV	{"phone": "+70825941334"}
0005433397814	15D62C	0565 689440	EKATERINA KOLESNIKOVA	{"email": "ekaterina-kolesnikova-091976@postgrespro.ru", "phone": "+70556787267"}
0005433397816	15D62C	4146 506002	TATYANA KOROLEVA	{"email": "tkoroleva-1973@postgrespro.ru", "phone": "+70816722297"}
0005433397817	AB1A7B	1352 660367	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr_061970@postgrespro.ru", "phone": "+70784825960"}
0005433397818	2808E0	4870 643767	ALEKSANDR PAVLOV	{"phone": "+70227946167"}
0005433397819	F6B001	4650 451988	GALINA MIRONOVA	{"email": "mironova.galina.03071982@postgrespro.ru", "phone": "+70231466403"}
0005433397820	CB95D6	9983 553747	ILDAR SEMENOV	{"email": "i_semenov-081962@postgrespro.ru", "phone": "+70758599792"}
0005433397877	22B995	6850 107931	NADEZHDA ANDREEVA	{"phone": "+70087925298"}
0005433397821	E88249	8063 324459	TATYANA KOROLEVA	{"email": "koroleva.tatyana01041961@postgrespro.ru", "phone": "+70394376800"}
0005433397822	EBD7E6	4238 803333	IRINA MELNIKOVA	{"phone": "+70804212469"}
0005433397823	AAD49C	5998 915227	NADEZHDA NOVIKOVA	{"email": "nadezhda.novikova-1981@postgrespro.ru", "phone": "+70566788426"}
0005433397824	1C72BF	2908 201444	ELENA DAVYDOVA	{"email": "edavydova-1965@postgrespro.ru", "phone": "+70784928418"}
0005433397825	1C72BF	0962 180918	RUSLAN SCHERBAKOV	{"email": "scherbakov_r-21121988@postgrespro.ru", "phone": "+70451889670"}
0005433397826	3388AD	8558 044893	SERGEY BORISOV	{"phone": "+70121241581"}
0005433397827	BA63E9	5943 081584	VLADIMIR CHERNOV	{"phone": "+70022852435"}
0005433397828	4E139F	4531 928042	VALERIY KUZMIN	{"email": "kuzmin_v_081978@postgrespro.ru", "phone": "+70222656306"}
0005433397829	7EFC64	9082 033070	VLADIMIR MAKAROV	{"phone": "+70465468552"}
0005433397830	147017	3153 243288	ALEKSANDR VLASOV	{"phone": "+70317627752"}
0005433397831	31F46C	7747 647955	ROZALIYA KOZLOVA	{"phone": "+70954562103"}
0005433397832	23987C	8864 650653	YURIY VASILEV	{"phone": "+70363907996"}
0005433397833	23987C	4077 249954	VIKTOR DMITRIEV	{"email": "dmitriev-v.111972@postgrespro.ru", "phone": "+70786490170"}
0005433397834	23987C	7168 926850	GALINA KOROLEVA	{"email": "gkoroleva_11071962@postgrespro.ru", "phone": "+70534851176"}
0005433397835	E1EEC8	7366 410338	IRINA MALYSHEVA	{"email": "malysheva-irina.02031968@postgrespro.ru", "phone": "+70817260061"}
0005433397836	A60A79	3966 460087	SERGEY KUZMIN	{"email": "s_kuzmin04011974@postgrespro.ru", "phone": "+70142144958"}
0005433397837	07DAB7	8523 647873	ILYAS ZHURAVLEV	{"email": "zhuravlev.i.12061970@postgrespro.ru", "phone": "+70918362523"}
0005433397838	2C9EBC	0575 914216	ALEKSANDR VASILEV	{"email": "vasilev_a.031973@postgrespro.ru", "phone": "+70511139657"}
0005433397839	9955E4	5210 033717	ELENA NIKITINA	{"phone": "+70188237761"}
0005433397840	7E7C44	9855 177249	IRINA IVANOVA	{"email": "ivanova_i_22031974@postgrespro.ru", "phone": "+70358653709"}
0005433397841	08F920	2115 032428	TATYANA SIDOROVA	{"phone": "+70970212896"}
0005433397842	08F920	8570 360621	LARISA NESTEROVA	{"phone": "+70375263751"}
0005433397843	DF575F	0607 361111	LYUDMILA NESTEROVA	{"email": "nesteroval-121965@postgrespro.ru", "phone": "+70755029548"}
0005433397844	B22592	5812 442164	ALEKSANDR KISELEV	{"phone": "+70910729443"}
0005433397845	DAF8AD	5235 492614	VIKTORIYA DMITRIEVA	{"phone": "+70137109717"}
0005433397846	BA9B9E	6966 633050	ALEKSEY KUZNECOV	{"phone": "+70702700694"}
0005433397847	458EAD	6775 631083	SERGEY GRIGOREV	{"phone": "+70704505736"}
0005433397848	7D626A	0032 937655	POLINA TARASOVA	{"phone": "+70206667073"}
0005433397849	7D626A	5385 303462	TATYANA MAKAROVA	{"phone": "+70987071566"}
0005433397850	7846C2	2160 950974	OLGA LEBEDEVA	{"email": "olga_lebedeva_1976@postgrespro.ru", "phone": "+70662508695"}
0005433397851	F3A605	5266 580000	VLADIMIR TIKHONOV	{"phone": "+70224385185"}
0005433397852	658512	4061 484261	TATYANA VASILEVA	{"phone": "+70443523643"}
0005433397853	7D813F	5452 467568	OLGA ANISIMOVA	{"phone": "+70394338261"}
0005433397854	156EE4	3891 519356	VLADIMIR KUZNECOV	{"email": "vkuznecov.1974@postgrespro.ru", "phone": "+70990016487"}
0005433397855	1815FF	9907 894667	ANASTASIYA ZAKHAROVA	{"email": "zakharovaa15031964@postgrespro.ru", "phone": "+70430416054"}
0005433397856	1815FF	0145 184568	ALEKSANDR SOKOLOV	{"phone": "+70603039286"}
0005433397857	E65E70	1897 359771	VALENTINA BARANOVA	{"email": "baranova-v06041978@postgrespro.ru", "phone": "+70468036462"}
0005433397858	6589C0	9550 585424	LYUBOV KOROLEVA	{"email": "koroleval.27101975@postgrespro.ru", "phone": "+70288492905"}
0005433397859	A27AAE	4704 062310	ARTEM ZHUKOV	{"phone": "+70374379073"}
0005433397860	F62DB3	2659 746462	VIKTOR POPOV	{"email": "viktorpopov-24031977@postgrespro.ru", "phone": "+70398873149"}
0005433397861	F62DB3	4244 152590	LILIYA NESTEROVA	{"email": "liliya.nesterova-09011974@postgrespro.ru", "phone": "+70046985467"}
0005433397862	E1E32C	4926 069333	PETR DAVYDOV	{"email": "davydov.petr_081966@postgrespro.ru", "phone": "+70363176305"}
0005433397863	684A08	8454 120852	NATALYA ROMANOVA	{"phone": "+70042379788"}
0005433397864	684A08	5710 532376	NIKITA BELOV	{"email": "belovnikita.19091972@postgrespro.ru", "phone": "+70914709197"}
0005433397865	F3E1A8	8185 446930	VIKTOR ISAEV	{"email": "isaev_viktor-1975@postgrespro.ru", "phone": "+70101562837"}
0005433397866	F3E1A8	5055 902564	ALEKSANDR TIMOFEEV	{"email": "aleksandr-timofeev-081970@postgrespro.ru", "phone": "+70339032357"}
0005433397867	F4B6C9	7473 191275	EVGENIYA SOROKINA	{"email": "e.sorokina1978@postgrespro.ru", "phone": "+70372868978"}
0005433397868	065829	1284 424859	ALEKSEY AFANASEV	{"email": "a_afanasev.17031976@postgrespro.ru", "phone": "+70910395500"}
0005433397869	065829	6772 023230	PAVEL TARASOV	{"email": "p_tarasov_011979@postgrespro.ru", "phone": "+70276633626"}
0005433397870	065829	2195 251808	VIKTOR MATVEEV	{"email": "v_matveev.071973@postgrespro.ru", "phone": "+70124205477"}
0005433397871	19A77B	9941 988126	ALEKSEY ILIN	{"phone": "+70319690903"}
0005433397872	E01B58	5239 686744	ANASTASIYA KONDRATEVA	{"email": "a.kondrateva-10011971@postgrespro.ru", "phone": "+70502961491"}
0005433397873	E0AAC0	8871 393839	RAISA LAZAREVA	{"phone": "+70061234068"}
0005433397874	7BBC47	6429 856428	OLGA SOLOVEVA	{"phone": "+70825812746"}
0005433397875	EE7374	9240 024172	SVETLANA KUDRYASHOVA	{"phone": "+70953662515"}
0005433397876	5E2C93	0364 895584	EKATERINA ALEKSEEVA	{"email": "alekseeva.ekaterina_111970@postgrespro.ru", "phone": "+70048918476"}
0005433397878	ECE8FE	7687 495784	BORIS ABRAMOV	{"phone": "+70882888687"}
0005433397879	2365DE	1047 164352	NATALYA GUSEVA	{"phone": "+70705608504"}
0005433397880	5BCCCD	5015 760514	YULIYA GUSEVA	{"email": "guseva-y-24081977@postgrespro.ru", "phone": "+70110709293"}
0005433397881	F05612	1398 762754	ANDREY KAZAKOV	{"email": "a.kazakov_17071973@postgrespro.ru", "phone": "+70378198677"}
0005433397882	9E5529	7805 254892	ELENA KUZMINA	{"email": "kuzminae_1979@postgrespro.ru", "phone": "+70750248303"}
0005433397883	315E58	2706 013276	IVAN NAZAROV	{"email": "ivan-nazarov-111973@postgrespro.ru", "phone": "+70878054062"}
0005433397884	BBC9E0	0147 226689	SERGEY IVANOV	{"email": "ivanov-sergey_30071974@postgrespro.ru", "phone": "+70445983991"}
0005433397885	BBC9E0	8789 066330	LILIYA OVCHINNIKOVA	{"email": "l-ovchinnikova.04081970@postgrespro.ru", "phone": "+70799935688"}
0005433397886	A59D36	8116 440675	OLGA LEBEDEVA	{"phone": "+70423163060"}
0005433397887	A59D36	9295 243261	NADEZHDA VLASOVA	{"email": "vlasova-nadezhda.09111965@postgrespro.ru", "phone": "+70890269725"}
0005433397888	40253A	6050 629623	SERGEY EGOROV	{"email": "egorov.s.1977@postgrespro.ru", "phone": "+70181885007"}
0005433397889	40253A	0144 973935	VERA VASILEVA	{"phone": "+70093278304"}
0005433397890	40253A	0953 493430	MAYYA YAKOVLEVA	{"email": "yakovlevam.1973@postgrespro.ru", "phone": "+70730323835"}
0005433397891	DACAE7	3063 063747	MARINA TITOVA	{"phone": "+70194302866"}
0005433397892	D3E50A	2704 314415	ALEVTINA SOLOVEVA	{"phone": "+70794708266"}
0005433397893	D3E50A	7923 689079	NIKITA MAKSIMOV	{"email": "nikita.maksimov.1964@postgrespro.ru", "phone": "+70373005194"}
0005433397894	73A1FA	3516 661468	IVAN GUSEV	{"phone": "+70160549263"}
0005433397895	73A1FA	1848 489013	SERGEY KOZLOV	{"email": "kozlov_sergey20051956@postgrespro.ru", "phone": "+70791650856"}
0005433397896	1E350C	0613 282882	ELENA PAVLOVA	{"phone": "+70630094912"}
0005433397897	E971A6	5704 200424	SVETLANA ZOTOVA	{"email": "s-zotova_1965@postgrespro.ru", "phone": "+70602782208"}
0005433397898	93CE41	1216 331623	LYUBOV VLASOVA	{"email": "lyubovvlasova_29111969@postgrespro.ru", "phone": "+70901492419"}
0005433397899	F83811	7803 258674	NATALYA OSIPOVA	{"phone": "+70727717735"}
0005433397900	F83811	6839 842002	SERGEY SERGEEV	{"email": "sergeev_s.1973@postgrespro.ru", "phone": "+70519587127"}
0005433397901	F83811	6927 635567	NINA KUZNECOVA	{"email": "kuznecova-nina1972@postgrespro.ru", "phone": "+70869269962"}
0005433397902	1E3EBF	1274 662063	ELENA OSIPOVA	{"email": "elenaosipova.041983@postgrespro.ru", "phone": "+70849368993"}
0005433397903	377CFC	6309 085744	PELAGEYA IVANOVA	{"phone": "+70377382357"}
0005433397904	5E98CE	1604 169912	RASHIT GRIGOREV	{"phone": "+70690253079"}
0005433397905	860725	6705 997557	ALEKSANDRA NOVIKOVA	{"email": "anovikova_17091974@postgrespro.ru", "phone": "+70997647403"}
0005433397906	538DDE	9689 391171	IGOR KUZNECOV	{"email": "kuznecov-igor_081972@postgrespro.ru", "phone": "+70162327116"}
0005433397907	EE45AE	5126 280682	VALERIY SIDOROV	{"email": "valeriy_sidorov.31071964@postgrespro.ru", "phone": "+70430363411"}
0005433397908	E41BAB	9779 809634	MAKSIM IVANOV	{"phone": "+70252858260"}
0005433397909	CE37BA	5643 819855	DENIS SAVELEV	{"phone": "+70309210795"}
0005433397910	CE37BA	0832 610144	MIKHAIL MAKSIMOV	{"email": "maksimov.m.1968@postgrespro.ru", "phone": "+70800751511"}
0005433397911	CE37BA	1785 546169	VALERIYA KUZMINA	{"email": "kuzmina_v-1963@postgrespro.ru", "phone": "+70759623863"}
0005433397912	80869B	0566 380683	KLAVDIYA IVANOVA	{"phone": "+70299357007"}
0005433397913	20CC6E	7289 730702	LYUBOV NIKOLAEVA	{"email": "l.nikolaeva031986@postgrespro.ru", "phone": "+70364886057"}
0005433397914	18E7CF	4885 560051	ALEKSANDR KUZNECOV	{"email": "kuznecov.a.121986@postgrespro.ru", "phone": "+70554050679"}
0005433397915	18E7CF	5618 951794	VERA OVCHINNIKOVA	{"phone": "+70226510372"}
0005433397916	970370	0329 791625	ALEKSEY FEDOTOV	{"phone": "+70905138846"}
0005433397917	FF0096	7659 833588	YURIY POPOV	{"email": "popov.yuriy-1971@postgrespro.ru", "phone": "+70369376535"}
0005433397918	0C6459	9838 040926	SERGEY ROMANOV	{"phone": "+70179884862"}
0005433397919	B586C2	8937 765072	SERGEY YAKOVLEV	{"phone": "+70766975195"}
0005433397920	C2F98F	3880 641197	OLEG PAVLOV	{"email": "oleg_pavlov.18121964@postgrespro.ru", "phone": "+70471628589"}
0005433397921	46F0B3	9451 448519	NATALYA FILIPPOVA	{"phone": "+70452719600"}
0005433397922	46F0B3	1480 060489	VASILIY IVANOV	{"email": "ivanov.vasiliy.20061972@postgrespro.ru", "phone": "+70373491011"}
0005433397923	086563	5260 850304	SERGEY ORLOV	{"phone": "+70489868453"}
0005433397924	086563	3800 916575	TATYANA TROFIMOVA	{"email": "t-trofimova-1966@postgrespro.ru", "phone": "+70569363440"}
0005433397925	3AED84	4826 327935	SOFYA IVANOVA	{"phone": "+70341885052"}
0005433397926	3AED84	3508 291592	DMITRIY BONDARENKO	{"email": "dmitriy.bondarenko.111970@postgrespro.ru", "phone": "+70289173912"}
0005433397927	3AED84	8790 227949	NINA KOZLOVA	{"email": "n.kozlova_111970@postgrespro.ru", "phone": "+70229308933"}
0005433397928	514836	0117 420072	SERGEY ORLOV	{"email": "orlov.s.1955@postgrespro.ru", "phone": "+70060993735"}
0005433397929	22EE57	3042 154511	ALEKSANDRA KONOVALOVA	{"phone": "+70274878511"}
0005433397930	FCF64F	4801 150043	KSENIYA TROFIMOVA	{"phone": "+70468646572"}
0005433397931	7B7322	3466 227333	ANDREY FROLOV	{"phone": "+70160828052"}
0005433397932	7B7322	1492 564443	ALEKSANDR BORISOV	{"phone": "+70261888706"}
0005433397933	6A8677	1814 049791	PAVEL KULIKOV	{"email": "pkulikov-1973@postgrespro.ru", "phone": "+70567612167"}
0005433397934	7838C2	4553 085175	TAMARA DENISOVA	{"phone": "+70421609875"}
0005433397935	7838C2	3907 443137	ALEKSANDR RODIONOV	{"phone": "+70125530650"}
0005433397936	12A7AF	9636 904271	NATALYA LAZAREVA	{"email": "n-lazareva_031970@postgrespro.ru", "phone": "+70110072848"}
0005433397937	F65637	7094 768623	NATALIYA FROLOVA	{"phone": "+70661425552"}
0005433397938	2A90FD	3746 817095	ANATOLIY KULIKOV	{"email": "kulikova_121958@postgrespro.ru", "phone": "+70335576261"}
0005433397939	2A90FD	3120 541750	ARTEM GRIGOREV	{"email": "a.grigorev.26121965@postgrespro.ru", "phone": "+70109728027"}
0005433397940	2A90FD	4068 302876	NINA SOROKINA	{"email": "sorokina-nina_02111964@postgrespro.ru", "phone": "+70948249924"}
0005433397941	8CCFEC	5712 666425	VLADIMIR TIMOFEEV	{"email": "timofeev-v08051969@postgrespro.ru", "phone": "+70530842581"}
0005433397942	8CCFEC	1762 729643	DENIS KAZAKOV	{"phone": "+70322063200"}
0005433397943	BA68EA	1516 064475	EKATERINA KARPOVA	{"email": "karpova-e.14011975@postgrespro.ru", "phone": "+70500329172"}
0005433397944	003699	1974 419178	OLGA ORLOVA	{"email": "o-orlova_1972@postgrespro.ru", "phone": "+70687357272"}
0005433397945	003699	8225 915881	SERGEY EGOROV	{"phone": "+70763834133"}
0005433397946	F3C60E	3842 522954	ANNA ZAKHAROVA	{"phone": "+70315246292"}
0005433397947	B547C5	3702 322552	ELENA FEDOROVA	{"phone": "+70124269039"}
0005433397948	B547C5	2978 058473	YULIYA POPOVA	{"email": "yuliya.popova_1974@postgrespro.ru", "phone": "+70231413342"}
0005433397949	3003E1	9470 471846	EGOR KARPOV	{"email": "karpov_e_14031962@postgrespro.ru", "phone": "+70842504624"}
0005433397950	3003E1	2664 259607	GALINA MOISEEVA	{"phone": "+70209396413"}
0005433397951	E6E2F5	8056 226088	NATALIYA KAZAKOVA	{"email": "n.kazakova-081970@postgrespro.ru", "phone": "+70598839181"}
0005433397952	D88E15	6936 901117	YAROSLAV SCHERBAKOV	{"phone": "+70691286077"}
0005433397953	6867D1	2761 422127	IGOR BONDARENKO	{"phone": "+70007988936"}
0005433397954	5A5861	9236 227762	ANTON RODIONOV	{"email": "anton_rodionov07011981@postgrespro.ru", "phone": "+70684210209"}
0005433397955	C6FB8E	0719 722228	KRISTINA SMIRNOVA	{"email": "smirnova.kristina-1974@postgrespro.ru", "phone": "+70607291102"}
0005433397956	2EE86E	7920 794546	EKATERINA MELNIKOVA	{"phone": "+70744093827"}
0005433397957	2EE86E	7152 336701	DIANA SOROKINA	{"email": "d_sorokina-19081968@postgrespro.ru", "phone": "+70908898205"}
0005433397958	A7EEB1	5505 141326	NIKOLAY SMIRNOV	{"email": "n_smirnov-24011972@postgrespro.ru", "phone": "+70810302318"}
0005433397959	DB1E17	2825 160053	SERGEY DMITRIEV	{"email": "dmitriev.sergey_1969@postgrespro.ru", "phone": "+70447247007"}
0005433397960	0F3BE9	2362 803215	IGOR GERASIMOV	{"email": "igerasimov1966@postgrespro.ru", "phone": "+70251382150"}
0005433397961	591EFC	6785 810685	SVETLANA KUZNECOVA	{"phone": "+70521403937"}
0005433397962	50AB61	7491 677954	VLADIMIR FOMIN	{"phone": "+70094013349"}
0005433397963	AE85B7	1512 752514	NIKOLAY KRASNOV	{"email": "n-krasnov1974@postgrespro.ru", "phone": "+70624769842"}
0005433397964	C00866	3144 266380	ARINA LEBEDEVA	{"email": "lebedeva-arina_1965@postgrespro.ru", "phone": "+70862626383"}
0005433397965	BC717F	5387 278269	NINA KULIKOVA	{"email": "kulikovan_31051990@postgrespro.ru", "phone": "+70291821467"}
0005433397966	BC717F	8042 012413	OLGA ZAKHAROVA	{"email": "zakharovaolga061972@postgrespro.ru", "phone": "+70088116537"}
0005433397967	72B7BB	4458 700619	ANATOLIY ABRAMOV	{"email": "anatoliy-abramov_04081962@postgrespro.ru", "phone": "+70166763818"}
0005433397968	44984C	5018 556981	ANASTASIYA MIRONOVA	{"phone": "+70892205653"}
0005433397969	44984C	5311 299474	ALENA NAUMOVA	{"phone": "+70039127312"}
0005433397970	CB8150	9858 725108	ALEKSANDR KUZMIN	{"email": "a_kuzmin11081961@postgrespro.ru", "phone": "+70467194337"}
0005433397971	CB8150	6972 615244	VALERIYA DENISOVA	{"phone": "+70463664414"}
0005433397972	CB8150	5162 205263	ALEKSEY KAZAKOV	{"email": "kazakov-aleksey-1969@postgrespro.ru", "phone": "+70444597318"}
0005433397973	633463	8230 175924	NATALIYA ILINA	{"email": "ilina-nataliya071963@postgrespro.ru", "phone": "+70910938283"}
0005433397974	633463	8226 277204	SVETLANA KOROLEVA	{"phone": "+70761297840"}
0005433397975	28AF83	2317 601015	YULIYA SERGEEVA	{"email": "sergeevayuliya-18121971@postgrespro.ru", "phone": "+70398368617"}
0005433397976	7B696F	5442 981793	ANDREY MAKAROV	{"email": "andrey.makarov_1979@postgrespro.ru", "phone": "+70610011587"}
0005433397977	595D97	0105 278156	KSENIYA TIKHONOVA	{"phone": "+70284083622"}
0005433397978	595D97	5491 399362	NIKITA SMIRNOV	{"phone": "+70455451640"}
0005433397979	7F7C62	8044 941981	TATYANA TROFIMOVA	{"email": "trofimova_tatyana.041974@postgrespro.ru", "phone": "+70906288890"}
0005433397980	7F7C62	2315 715444	ALBINA VASILEVA	{"phone": "+70125937149"}
0005433397981	0D5D1C	8149 591954	YURIY MAKAROV	{"email": "makarov-yuriy051981@postgrespro.ru", "phone": "+70596302511"}
0005433397982	2F97A3	8630 007196	ANDREY EGOROV	{"phone": "+70146090540"}
0005433397983	2F97A3	5884 201106	ALEKSANDRA LUKYANOVA	{"email": "lukyanova-aleksandra-02081965@postgrespro.ru", "phone": "+70626122796"}
0005433397984	D7BBBE	5213 591869	VLADIMIR EGOROV	{"email": "egorov_vladimir_21071964@postgrespro.ru", "phone": "+70036724590"}
0005433397985	D7BBBE	5076 708147	RAVIL PETROV	{"phone": "+70116661916"}
0005433397986	8B05A6	1273 826737	OLEG ANTONOV	{"email": "antonov-oleg-1970@postgrespro.ru", "phone": "+70046070882"}
0005433397987	7540C6	5617 911164	MARGARITA POPOVA	{"phone": "+70936923714"}
0005433397988	4D6FF9	8956 924973	TATYANA MOROZOVA	{"email": "tatyanamorozova071975@postgrespro.ru", "phone": "+70265744733"}
0005433397989	77DA64	5489 300897	ALEKSANDR EGOROV	{"phone": "+70111488181"}
0005433397990	77DA64	1733 076354	RAVIL SHEVCHENKO	{"phone": "+70674961243"}
0005433397991	BCC286	2362 475291	NATALYA ZHUKOVA	{"phone": "+70951238699"}
0005433397992	BCC286	3849 273089	ALEKSEY VOROBEV	{"email": "avorobev-071966@postgrespro.ru", "phone": "+70728045498"}
0005433397993	EFDE18	6846 781780	IRINA SAVELEVA	{"email": "irina.saveleva.111970@postgrespro.ru", "phone": "+70745651028"}
0005433397994	209A5F	7168 175861	ALEKSANDR POPOV	{"phone": "+70797148866"}
0005433397995	FBA677	2910 015559	ANNA FEDOROVA	{"email": "fedorova_anna.011973@postgrespro.ru", "phone": "+70678131089"}
0005433397996	83CC2A	7813 970215	PAVEL EGOROV	{"email": "pavel_egorov_07041987@postgrespro.ru", "phone": "+70058385096"}
0005433397997	DF7CA9	5632 597920	MARK NIKOLAEV	{"email": "nikolaev_mark.041974@postgrespro.ru", "phone": "+70306980715"}
0005433398053	A59E8E	0823 840225	SEMEN FEDOTOV	{"phone": "+70051046267"}
0005433397998	1FADE7	6611 981794	ELENA EGOROVA	{"email": "egorovaelena.041974@postgrespro.ru", "phone": "+70209603563"}
0005433397999	1FADE7	4416 498057	NATALYA MOROZOVA	{"email": "natalya_morozova-121974@postgrespro.ru", "phone": "+70931022213"}
0005433398000	F25264	9079 044796	MARGARITA KRASNOVA	{"phone": "+70423979017"}
0005433398001	F25264	0693 396305	ROZA IVANOVA	{"email": "ivanova.r.1971@postgrespro.ru", "phone": "+70959896130"}
0005433398002	8B6238	4574 787341	SERGEY NAUMOV	{"phone": "+70292632475"}
0005433398003	8B6238	4310 473341	VLADIMIR KONOVALOV	{"email": "vladimirkonovalov.24011982@postgrespro.ru", "phone": "+70266655542"}
0005433398004	BDF27D	9224 251082	LIDIYA GRISHINA	{"email": "lidiya-grishina061970@postgrespro.ru", "phone": "+70494994049"}
0005433398005	CEC286	7375 234056	ALEKSEY KARPOV	{"email": "aleksey.karpov_17081957@postgrespro.ru", "phone": "+70809810123"}
0005433398006	742F93	1710 420468	DIANA STEPANOVA	{"phone": "+70495791534"}
0005433398007	5C4A4E	0180 244903	ALEVTINA MOROZOVA	{"phone": "+70700173405"}
0005433398008	5C4A4E	9142 053846	SERGEY GUSEV	{"email": "gusevsergey-02081971@postgrespro.ru", "phone": "+70172855897"}
0005433398009	5C4A4E	6218 624551	IRINA ZHUKOVA	{"phone": "+70251493254"}
0005433398010	B6AC83	6185 687000	YULIYA CHERNOVA	{"email": "chernovay.101969@postgrespro.ru", "phone": "+70964713517"}
0005433398011	5B20CB	0292 938213	SERGEY MATVEEV	{"email": "matveev-sergey.16031969@postgrespro.ru", "phone": "+70513479449"}
0005433398012	22506C	2661 435715	ALEKSEY ROMANOV	{"phone": "+70133302847"}
0005433398013	AC34D1	9155 054548	ALSU MASLOVA	{"phone": "+70877098445"}
0005433398014	FCFE04	3035 169975	ALEKSANDRA VOROBEVA	{"phone": "+70354324492"}
0005433398015	1AED11	3530 262651	DARYA KONDRATEVA	{"email": "kondrateva-d01121979@postgrespro.ru", "phone": "+70993897459"}
0005433398016	3A13B6	6421 523961	OLGA MELNIKOVA	{"email": "melnikova.olga_13061971@postgrespro.ru", "phone": "+70350832481"}
0005433398017	927A40	5589 735396	ANFISA BOGDANOVA	{"phone": "+70380107864"}
0005433398018	EB5A3C	4523 219186	VITALIY KUZNECOV	{"email": "vitaliy_kuznecov1972@postgrespro.ru", "phone": "+70081343483"}
0005433398019	EB5A3C	7942 091851	MAYYA VOLKOVA	{"email": "volkova.mayya101975@postgrespro.ru", "phone": "+70923900976"}
0005433398020	60EB91	0434 353870	NATALYA EGOROVA	{"phone": "+70392280208"}
0005433398021	59F43B	9680 575976	ALEKSEY KOZLOV	{"email": "aleksey-kozlov-1977@postgrespro.ru", "phone": "+70567074401"}
0005433398022	B3DAFF	2390 032572	LYUDMILA KOMAROVA	{"email": "komarova-lyudmila-18041959@postgrespro.ru", "phone": "+70989417649"}
0005433398023	3FAC49	0136 954093	NADEZHDA YAKOVLEVA	{"email": "n-yakovleva_1981@postgrespro.ru", "phone": "+70821878672"}
0005433398024	45A2C7	6056 748493	IRINA STEPANOVA	{"phone": "+70506569097"}
0005433398025	A41673	5349 813691	MARIYA SOROKINA	{"email": "sorokina_mariya-13101971@postgrespro.ru", "phone": "+70720600315"}
0005433398026	9809CE	6349 209665	EKATERINA YAKOVLEVA	{"email": "yakovleva-e.1978@postgrespro.ru", "phone": "+70719980179"}
0005433398027	2737D0	4538 824662	MAKSIM DMITRIEV	{"email": "dmitriev.maksim_08111978@postgrespro.ru", "phone": "+70280822574"}
0005433398028	21ED5A	4991 218480	EGOR GORBUNOV	{"email": "e-gorbunov021972@postgrespro.ru", "phone": "+70557539297"}
0005433398029	21ED5A	5645 368681	ALEKSANDR NIKITIN	{"phone": "+70498884005"}
0005433398030	C78D5F	0317 421449	VASILIY POPOV	{"email": "popov.v.011968@postgrespro.ru", "phone": "+70138204678"}
0005433398031	906002	7155 873621	ALEKSEY NOVIKOV	{"phone": "+70205963903"}
0005433398032	F3B127	0432 455245	ELENA MOROZOVA	{"email": "morozova.e_1970@postgrespro.ru", "phone": "+70900970612"}
0005433398033	DE948A	4076 892622	KONSTANTIN FEDOROV	{"email": "fedorov.konstantin-07111965@postgrespro.ru", "phone": "+70062809345"}
0005433398034	548BD5	9862 358831	GEORGIY ZAYCEV	{"email": "zaycev.g1966@postgrespro.ru", "phone": "+70991177768"}
0005433398035	ED22D3	4720 494825	NADEZHDA ZAYCEVA	{"phone": "+70528547636"}
0005433398036	828EB5	8403 409954	EVGENIY KISELEV	{"phone": "+70518775262"}
0005433398037	488AC2	3069 205296	LYUBOV ANDREEVA	{"phone": "+70149310589"}
0005433398038	4ED61D	3423 076122	IRINA MIRONOVA	{"email": "i.mironova04011975@postgrespro.ru", "phone": "+70601800147"}
0005433398039	0CA88C	9932 083806	NATALYA SOROKINA	{"phone": "+70011555398"}
0005433398040	189DCE	4732 981970	EVDOKIYA KRASNOVA	{"phone": "+70954705217"}
0005433398041	A6F26E	1328 491598	ALEKSANDR MELNIKOV	{"email": "melnikov_a_111978@postgrespro.ru", "phone": "+70307108832"}
0005433398042	A7D1E9	7139 311548	VALENTIN STEPANOV	{"email": "stepanov_valentin.011972@postgrespro.ru", "phone": "+70875518425"}
0005433398043	51B6A2	2987 647933	VALENTINA SOROKINA	{"email": "sorokinavalentina_1972@postgrespro.ru", "phone": "+70510465289"}
0005433398044	59406E	6465 109762	IGOR ORLOV	{"phone": "+70391893317"}
0005433398045	615F57	2117 079711	IRINA SOKOLOVA	{"email": "irina.sokolova.081970@postgrespro.ru", "phone": "+70037241835"}
0005433398046	615F57	4314 803610	KRISTINA MAKSIMOVA	{"phone": "+70057990590"}
0005433398047	621729	6034 085437	ELIZAVETA MATVEEVA	{"phone": "+70793285250"}
0005433398048	5DDFE4	3146 033779	ZINAIDA LEBEDEVA	{"phone": "+70796732769"}
0005433398049	75EBBC	0951 769980	SERGEY GORBUNOV	{"phone": "+70662424621"}
0005433398050	AF8093	9541 245420	DMITRIY MAKAROV	{"email": "dmitriy.makarov.24101970@postgrespro.ru", "phone": "+70262071337"}
0005433398051	BFF6F4	3265 364385	MAKSIM ORLOV	{"phone": "+70507263704"}
0005433398052	BFF6F4	8636 489867	ALEKSEY EGOROV	{"email": "egorov.a.21061976@postgrespro.ru", "phone": "+70540077184"}
0005433398054	9B4056	7324 507976	EKATERINA BORISOVA	{"phone": "+70721187986"}
0005433398055	9B4056	3061 269701	ANATOLIY NOVIKOV	{"email": "anatoliy_novikov_031978@postgrespro.ru", "phone": "+70451232242"}
0005433398056	9B4056	5037 319732	NIKOLAY KOROLEV	{"phone": "+70128477628"}
0005433398057	ACB579	6123 138976	TATYANA SIDOROVA	{"email": "sidorovatatyana19061972@postgrespro.ru", "phone": "+70294710749"}
0005433398058	F4B51F	3579 584564	LYUBOV NIKIFOROVA	{"email": "lyubov.nikiforova031987@postgrespro.ru", "phone": "+70929531686"}
0005433398059	4D1C07	6485 249297	VERA NESTEROVA	{"email": "veranesterova.1983@postgrespro.ru", "phone": "+70635895871"}
0005433398060	4D1C07	6056 044323	EVGENIY STEPANOV	{"email": "stepanov_e041974@postgrespro.ru", "phone": "+70684587411"}
0005433398061	06D7A8	7574 138400	ALEKSANDR SOROKIN	{"phone": "+70406447020"}
0005433398062	06D7A8	1742 593944	NAIL FROLOV	{"phone": "+70946867213"}
0005433398063	786BB3	1389 565122	IRINA KRASNOVA	{"phone": "+70984330874"}
0005433398064	786BB3	0245 359827	EKATERINA KONOVALOVA	{"email": "ekaterinakonovalova.031994@postgrespro.ru", "phone": "+70608989438"}
0005433398065	BA1801	6134 997623	GALINA KUZNECOVA	{"phone": "+70560404554"}
0005433398066	192933	9663 193449	ALEKSANDR MIRONOV	{"phone": "+70293492692"}
0005433398067	9BB91F	8551 156237	SERGEY VOLKOV	{"email": "volkov.sergey-1974@postgrespro.ru", "phone": "+70384145591"}
0005433398068	6A832C	0263 027469	LYUBOV SMIRNOVA	{"phone": "+70229343473"}
0005433398069	6A832C	7462 180371	LYUBOV YAKOVLEVA	{"email": "lyubov_yakovleva_08091987@postgrespro.ru", "phone": "+70626828572"}
0005433398070	97AE02	2927 416462	ELENA ZAYCEVA	{"email": "elena_zayceva-061972@postgrespro.ru", "phone": "+70332287147"}
0005433398071	56DEBC	5056 249625	NIKOLAY ZAKHAROV	{"email": "zakharov.n1971@postgrespro.ru", "phone": "+70502953954"}
0005433398072	69563C	7313 409172	FELIKS SOROKIN	{"email": "f_sorokin.121978@postgrespro.ru", "phone": "+70113349970"}
0005433398073	69563C	1997 329060	NAILYA PETROVA	{"phone": "+70825473826"}
0005433398074	69563C	9595 099496	ALEKSEY KAZAKOV	{"phone": "+70564768381"}
0005433398075	D261A7	0836 957352	ILYA FEDOROV	{"phone": "+70565023433"}
0005433398076	483BD9	6047 662634	DMITRIY SCHERBAKOV	{"phone": "+70464420854"}
0005433398077	2391E6	5307 457276	ELENA RYABOVA	{"email": "e.ryabova-30121971@postgrespro.ru", "phone": "+70494855438"}
0005433398078	2391E6	3656 496720	VIKTOR KAZAKOV	{"email": "viktor_kazakov1982@postgrespro.ru", "phone": "+70931278313"}
0005433398079	646AAD	8347 545149	BORIS TIKHONOV	{"email": "tikhonov-boris.19081967@postgrespro.ru", "phone": "+70015975840"}
0005433398080	3E7BBD	2842 497370	ALEKSEY KOROLEV	{"phone": "+70136412203"}
0005433398081	8ECB8A	5614 239672	PAVEL ANDREEV	{"email": "p_andreev.07061968@postgrespro.ru", "phone": "+70698766251"}
0005433398082	C9F5C9	5098 573113	VERA SOROKINA	{"phone": "+70473201976"}
0005433398083	C9F5C9	6675 874465	SERGEY IVANOV	{"email": "sergeyivanov_19111971@postgrespro.ru", "phone": "+70995620084"}
0005433398084	231157	4497 526655	ANATOLIY KOROLEV	{"phone": "+70937392421"}
0005433398085	231157	3296 053883	VYACHESLAV SOKOLOV	{"phone": "+70080283500"}
0005433398086	2191C1	4262 217260	ALEKSEY BONDARENKO	{"phone": "+70334184198"}
0005433398087	E2A7C7	5262 479287	VLADIMIR IVANOV	{"phone": "+70261915963"}
0005433398088	E1E146	4019 325619	VARVARA SAVELEVA	{"phone": "+70293867010"}
0005433398089	FD9D9E	3513 839498	VALENTINA POPOVA	{"phone": "+70410846305"}
0005433398090	5F73F2	3544 890093	ANAIT KOLESNIKOVA	{"email": "kolesnikova_a-1979@postgrespro.ru", "phone": "+70362646289"}
0005433398091	0E6CDB	4384 468386	VLADIMIR KISELEV	{"email": "v_kiselev.19051981@postgrespro.ru", "phone": "+70178844761"}
0005433398092	0E6CDB	4623 659462	YULIYA LAZAREVA	{"email": "lazareva_yuliya_1975@postgrespro.ru", "phone": "+70307512444"}
0005433398093	F349DA	2220 099600	EKATERINA FOMINA	{"email": "fomina_e-1971@postgrespro.ru", "phone": "+70666754087"}
0005433398094	F349DA	8530 382991	ANDREY SAVELEV	{"phone": "+70740509790"}
0005433398095	442384	5815 388671	YULIYA EFIMOVA	{"email": "yuliya-efimova.111971@postgrespro.ru", "phone": "+70058401168"}
0005433398096	F26BC0	0612 642758	ALEKSANDRA BOGDANOVA	{"phone": "+70656562900"}
0005433398097	2E0062	2445 027692	MARGARITA ANDREEVA	{"phone": "+70559363958"}
0005433398098	6281D2	0781 269787	ELENA DMITRIEVA	{"email": "e_dmitrieva.22041986@postgrespro.ru", "phone": "+70661642217"}
0005433398099	6A282B	2764 804077	LARISA MAKAROVA	{"phone": "+70504799872"}
0005433398100	6A282B	4636 019292	PAVEL TARASOV	{"email": "tarasovpavel-13011972@postgrespro.ru", "phone": "+70856140206"}
0005433398269	5F4F31	7444 618382	ALEKSANDR ILIN	{"phone": "+70270549666"}
0005433398101	79DE86	4031 169587	OKSANA TIMOFEEVA	{"email": "timofeeva-o_1977@postgrespro.ru", "phone": "+70904055674"}
0005433398102	79DE86	5179 687604	GENNADIY POPOV	{"email": "gpopov.051975@postgrespro.ru", "phone": "+70220745657"}
0005433398103	79DE86	1155 253061	MARINA KUZNECOVA	{"phone": "+70627418349"}
0005433398104	4CC710	3380 359739	ANTONINA POTAPOVA	{"email": "a.potapova-13021972@postgrespro.ru", "phone": "+70281280273"}
0005433398105	83DCB9	7959 961108	ANATOLIY BELOV	{"phone": "+70016015865"}
0005433398106	61F73E	1449 903089	MARIYA VASILEVA	{"phone": "+70841833828"}
0005433398107	61F73E	0015 866578	DMITRIY NOVIKOV	{"phone": "+70186226864"}
0005433398108	8617BF	2626 792414	GENNADIY BORISOV	{"phone": "+70992279918"}
0005433398277	FA39F9	1216 908197	ANTONINA VASILEVA	{"phone": "+70699749178"}
0005433398109	2ECB2B	0882 280650	TATYANA PETROVA	{"email": "tatyana.petrova-10041984@postgrespro.ru", "phone": "+70138043712"}
0005433398110	2ECB2B	3556 565793	MIKHAIL ALEKSANDROV	{"phone": "+70026825507"}
0005433398111	8690D1	7296 589771	LIDIYA ANDREEVA	{"email": "lidiya.andreeva_26101983@postgrespro.ru", "phone": "+70685782383"}
0005433398112	8690D1	0262 497435	IRINA ZAYCEVA	{"email": "zaycevai_1969@postgrespro.ru", "phone": "+70414305173"}
0005433398113	74EE76	6183 645136	TATYANA LOGINOVA	{"phone": "+70916246801"}
0005433398114	85C29C	5579 271556	IGOR ANTONOV	{"email": "antonov.igor-14061972@postgrespro.ru", "phone": "+70068610827"}
0005433398115	A9AF76	2059 059441	NADEZHDA OSIPOVA	{"email": "osipova.n021974@postgrespro.ru", "phone": "+70910275176"}
0005433398116	A9AF76	0368 916626	GENNADIY SEMENOV	{"email": "semenov-g1974@postgrespro.ru", "phone": "+70387778875"}
0005433398117	659EC8	9231 736191	MIKHAIL MAKAROV	{"email": "m-makarov1966@postgrespro.ru", "phone": "+70766402660"}
0005433398118	56113B	7717 231911	DMITRIY VASILEV	{"phone": "+70316358191"}
0005433398119	17DB8F	7043 093101	TATYANA ZHUKOVA	{"phone": "+70226912957"}
0005433398120	3DEC3A	4323 659205	LARISA POPOVA	{"email": "popova.larisa-101972@postgrespro.ru", "phone": "+70529815253"}
0005433398121	3DEC3A	1477 365630	MARK ZAKHAROV	{"email": "mark_zakharov1984@postgrespro.ru", "phone": "+70086772728"}
0005433398122	B61231	6792 050995	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov_061964@postgrespro.ru", "phone": "+70614995823"}
0005433398123	B61231	9653 671022	YURIY GORBUNOV	{"phone": "+70525608201"}
0005433398124	6F1F06	6777 913993	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr-1981@postgrespro.ru", "phone": "+70206897589"}
0005433398125	6F1F06	9317 161103	TATYANA STEPANOVA	{"email": "stepanova-tatyana_10081967@postgrespro.ru", "phone": "+70477181445"}
0005433398126	6F1F06	3785 332869	RAISA ROMANOVA	{"email": "romanovaraisa-07021971@postgrespro.ru", "phone": "+70654074686"}
0005433398127	AB817B	2238 027181	OLGA TARASOVA	{"phone": "+70092937280"}
0005433398128	0CA78D	2098 938715	ZINAIDA KRASNOVA	{"phone": "+70498392019"}
0005433398129	56989F	5283 397935	VLADIMIR KULIKOV	{"email": "kulikovvladimir08031972@postgrespro.ru", "phone": "+70636200968"}
0005433398130	56989F	2621 203690	EVGENIYA ANDREEVA	{"phone": "+70366252372"}
0005433398131	56989F	4512 331767	VLADIMIR KUZMIN	{"email": "vladimirkuzmin_09061970@postgrespro.ru", "phone": "+70017214235"}
0005433398132	A7830C	8110 474759	EKATERINA NESTEROVA	{"email": "e.nesterova.1984@postgrespro.ru", "phone": "+70274427762"}
0005433398133	A7830C	5578 420211	OLGA ZAKHAROVA	{"email": "o.zakharova_091971@postgrespro.ru", "phone": "+70968411885"}
0005433398134	1CE6EA	1847 821786	SERGEY MOROZOV	{"phone": "+70186236088"}
0005433398135	8A7182	0232 393381	IGOR VASILEV	{"phone": "+70477397680"}
0005433398136	8A7182	0593 120373	NATALIYA SOLOVEVA	{"phone": "+70913404824"}
0005433398137	B38071	1696 101533	LIDIYA RODIONOVA	{"email": "lidiya.rodionova-1964@postgrespro.ru", "phone": "+70783304764"}
0005433398138	52E4B2	4642 701135	VASILIY ANTONOV	{"email": "antonov_v_1976@postgrespro.ru", "phone": "+70407152110"}
0005433398139	83AF61	5552 321150	RIFAT AFANASEV	{"email": "r.afanasev22031975@postgrespro.ru", "phone": "+70157892592"}
0005433398140	B562CC	1853 993182	VALENTINA OSIPOVA	{"phone": "+70521361434"}
0005433398141	B562CC	8509 584506	RAISA ZAKHAROVA	{"phone": "+70350991541"}
0005433398142	8992F6	8160 553797	EVGENIY PETROV	{"email": "petrov_e.1975@postgrespro.ru", "phone": "+70542630910"}
0005433398143	8992F6	4232 839939	SERGEY GRIGOREV	{"email": "s-grigorev-1984@postgrespro.ru", "phone": "+70993434403"}
0005433398144	8A3E39	4403 192993	VYACHESLAV PETROV	{"phone": "+70121193102"}
0005433398145	668CA3	0199 732081	ALEKSEY FEDOTOV	{"phone": "+70389215959"}
0005433398146	3A3A47	1503 985090	EVGENIY VOLKOV	{"email": "volkov-e.25091982@postgrespro.ru", "phone": "+70648818393"}
0005433398147	71F1B4	6270 233183	ULYANA ABRAMOVA	{"email": "abramova-u081980@postgrespro.ru", "phone": "+70739760715"}
0005433398148	71F1B4	9630 662432	VLADIMIR ALEKSANDROV	{"phone": "+70514443989"}
0005433398149	6F7BC1	3980 035484	MARIYA ROMANOVA	{"email": "mariya.romanova-111977@postgrespro.ru", "phone": "+70616381949"}
0005433398150	6F7BC1	2087 765267	ALEKSANDR SMIRNOV	{"phone": "+70978661062"}
0005433398151	2BB37B	0558 845259	DARYA KUZNECOVA	{"email": "kuznecova-darya1973@postgrespro.ru", "phone": "+70549601269"}
0005433398152	F20CE9	2374 883642	ANNA KARPOVA	{"phone": "+70268687380"}
0005433398153	F20CE9	6676 842139	OLEG ANTONOV	{"phone": "+70904489257"}
0005433398154	D6A647	0515 735025	NATALYA KOZLOVA	{"email": "natalya-kozlova.1976@postgrespro.ru", "phone": "+70206585019"}
0005433398155	9F6E89	5838 848942	ZINAIDA NIKITINA	{"email": "nikitina_zinaida.11071961@postgrespro.ru", "phone": "+70405803617"}
0005433398156	5FD2B7	4109 819133	VALERIY NIKOLAEV	{"phone": "+70765815465"}
0005433398157	B1E004	3852 387766	IVAN ILIN	{"email": "i_ilin-1973@postgrespro.ru", "phone": "+70324662908"}
0005433398158	85A6C7	3671 136046	MARINA KULIKOVA	{"email": "kulikova_m_121973@postgrespro.ru", "phone": "+70153759649"}
0005433398159	FE64DD	7211 568966	ANDREY KONOVALOV	{"email": "a-konovalov_1962@postgrespro.ru", "phone": "+70188945951"}
0005433398160	F649D0	7384 130272	EVGENIYA KOROLEVA	{"phone": "+70763446372"}
0005433398161	F325F3	6105 961873	OLGA VOLKOVA	{"phone": "+70104804607"}
0005433398162	F325F3	0069 531829	MAKSIM MAKSIMOV	{"email": "m.maksimov.051974@postgrespro.ru", "phone": "+70506364177"}
0005433398163	A15CAA	5335 471045	TATYANA POPOVA	{"email": "popova-t_081969@postgrespro.ru", "phone": "+70504340789"}
0005433398164	A15CAA	9626 316910	ALEKSANDR YAKOVLEV	{"phone": "+70319718188"}
0005433398165	7A575E	1139 121717	YURIY IVANOV	{"email": "ivanov.y-1972@postgrespro.ru", "phone": "+70716151458"}
0005433398166	7A575E	8801 731151	ALEKSANDR KUZNECOV	{"phone": "+70045893701"}
0005433398167	6C3BCE	4449 392051	VASILIY MIRONOV	{"phone": "+70691304743"}
0005433398168	762D63	8641 806988	ANNA ZHURAVLEVA	{"email": "zhuravleva_anna1969@postgrespro.ru", "phone": "+70805673262"}
0005433398169	6C875B	5266 880453	LYUBOV SCHERBAKOVA	{"phone": "+70518911842"}
0005433398170	E8EC5D	2722 318551	PAVEL NIKOLAEV	{"phone": "+70085127300"}
0005433398171	E8EC5D	8335 642401	TATYANA NAUMOVA	{"phone": "+70420846781"}
0005433398172	95B07E	7097 868772	DINA NIKOLAEVA	{"email": "dinanikolaeva-18111967@postgrespro.ru", "phone": "+70345481743"}
0005433398173	95B07E	8515 756703	NATALYA STEPANOVA	{"email": "stepanova-n-26021965@postgrespro.ru", "phone": "+70636078716"}
0005433398174	9BAD19	1167 412405	SOFYA RODIONOVA	{"phone": "+70988015510"}
0005433398175	6CB245	4306 376897	NADEZHDA STEPANOVA	{"phone": "+70707617846"}
0005433398176	DD30FF	0628 148736	GALINA KARPOVA	{"phone": "+70322938147"}
0005433398177	4C16BA	3153 381022	ELENA YAKOVLEVA	{"phone": "+70268842057"}
0005433398178	4C16BA	2312 556104	VALENTINA DMITRIEVA	{"email": "v.dmitrieva-1978@postgrespro.ru", "phone": "+70124742582"}
0005433398179	0FA88F	6767 639248	VALERIY KONOVALOV	{"email": "konovalov-v101975@postgrespro.ru", "phone": "+70628360843"}
0005433398180	65F036	1546 008847	YULIYA NIKITINA	{"phone": "+70775058513"}
0005433398181	36C0D6	7650 772588	ELENA GUSEVA	{"phone": "+70513872848"}
0005433398182	BC0BD8	8757 060162	EVGENIY IVANOV	{"email": "ivanove10071967@postgrespro.ru", "phone": "+70148375531"}
0005433398183	628E5B	3555 380280	ANDREY CHERNOV	{"phone": "+70989787763"}
0005433398184	628E5B	0842 358487	VALENTINA SMIRNOVA	{"email": "smirnova.v-121971@postgrespro.ru", "phone": "+70714023556"}
0005433398185	7143BC	3611 240958	NIKITA EGOROV	{"email": "n-egorov_061967@postgrespro.ru", "phone": "+70761013919"}
0005433398186	7143BC	1828 449954	LYUBOV EGOROVA	{"phone": "+70494442934"}
0005433398187	B88889	0434 516375	DARYA NESTEROVA	{"phone": "+70575569203"}
0005433398188	0EEB84	1142 414617	ILYA SIDOROV	{"phone": "+70945388212"}
0005433398189	8BFFB2	8324 488381	LYUDMILA VOROBEVA	{"phone": "+70300405115"}
0005433398190	C6241D	9843 958199	ALEKSEY YAKOVLEV	{"email": "yakovleva_1976@postgrespro.ru", "phone": "+70913046130"}
0005433398191	5F0F50	9894 390190	ALEKSEY IVANOV	{"email": "ivanov.aleksey-16041981@postgrespro.ru", "phone": "+70901834524"}
0005433398192	6BD8FB	5588 771476	TATYANA SCHERBAKOVA	{"email": "tatyana.scherbakova_031978@postgrespro.ru", "phone": "+70789083322"}
0005433398193	6F1259	0065 610989	ILYA ZAKHAROV	{"email": "zakharov.i-1971@postgrespro.ru", "phone": "+70620998274"}
0005433398194	CE2851	6679 541359	ALEKSEY SEMENOV	{"email": "semenov-aleksey08091959@postgrespro.ru", "phone": "+70985167358"}
0005433398195	3A523B	1447 321778	MARIYA LOGINOVA	{"phone": "+70311962459"}
0005433398196	75FBFF	3294 722871	SERGEY SERGEEV	{"email": "sergeev-s.1983@postgrespro.ru", "phone": "+70991904296"}
0005433398197	3CFA11	0156 387508	LYUDMILA MAKSIMOVA	{"email": "maksimova.lyudmila24021968@postgrespro.ru", "phone": "+70340589186"}
0005433398198	8D6E3D	5325 098143	IGOR PAVLOV	{"email": "pavlov-igor011977@postgrespro.ru", "phone": "+70176463793"}
0005433398199	0271B6	2782 242686	VASILIY AFANASEV	{"phone": "+70226147930"}
0005433398200	8106FC	4188 098356	SVETLANA ANISIMOVA	{"email": "anisimova-s-09061972@postgrespro.ru", "phone": "+70286894249"}
0005433398201	7B4FD0	7736 963967	RAMZIYA DENISOVA	{"email": "denisova_ramziya_1971@postgrespro.ru", "phone": "+70342252139"}
0005433398202	FA73F6	3317 759581	MARIYA ZHURAVLEVA	{"email": "mariya.zhuravleva1973@postgrespro.ru", "phone": "+70890249552"}
0005433398203	E311F4	5739 919184	ANNA ALEKSEEVA	{"phone": "+70413065624"}
0005433398204	E311F4	1853 971750	ARSENIY ROMANOV	{"phone": "+70732437213"}
0005433398205	E311F4	0973 846473	VYACHESLAV ABRAMOV	{"email": "abramov-vyacheslav.041966@postgrespro.ru", "phone": "+70621913534"}
0005433398206	9D50E6	8823 788963	SERGEY PAVLOV	{"phone": "+70993602815"}
0005433398207	5EECC2	8025 676209	NIKOLAY SOROKIN	{"phone": "+70788572717"}
0005433398208	3C513D	9202 341825	VALENTINA ILINA	{"phone": "+70973604687"}
0005433398209	A8BA85	7982 188273	GALINA EFREMOVA	{"email": "efremova_g-051973@postgrespro.ru", "phone": "+70784980437"}
0005433398210	B291F4	8617 730579	GALINA ROMANOVA	{"email": "galina.romanova_1979@postgrespro.ru", "phone": "+70589708092"}
0005433398211	B291F4	1518 870169	TAISIYA SERGEEVA	{"email": "sergeeva-t-10021972@postgrespro.ru", "phone": "+70078756939"}
0005433398212	A73586	5254 744949	VALERIYA DMITRIEVA	{"email": "valeriya-dmitrieva.15051973@postgrespro.ru", "phone": "+70518266199"}
0005433398213	A73586	1135 418628	SERGEY KISELEV	{"email": "kiselev-sergey.27071966@postgrespro.ru", "phone": "+70700756176"}
0005433398214	63AA69	7631 174440	VERA KUZNECOVA	{"phone": "+70648084527"}
0005433398215	63AA69	7908 362365	MARIYA FEDOROVA	{"phone": "+70775856440"}
0005433398216	17F743	0821 381265	EGOR CHERNOV	{"phone": "+70637456002"}
0005433398217	6B01BD	5708 689013	NIKOLAY SEMENOV	{"phone": "+70923148531"}
0005433398218	6B01BD	4889 280843	MIKHAIL POPOV	{"phone": "+70492342538"}
0005433398219	8035B8	1538 222994	VIKTOR OSIPOV	{"email": "viktor-osipov_18111972@postgrespro.ru", "phone": "+70141326946"}
0005433398220	6C71E7	2582 031156	IGOR KUZNECOV	{"email": "i_kuznecov.20031972@postgrespro.ru", "phone": "+70174404173"}
0005433398221	E04B7F	7552 746852	EKATERINA BELOVA	{"email": "belova-e_1974@postgrespro.ru", "phone": "+70236520163"}
0005433398222	44D234	7419 133013	YURIY MOROZOV	{"phone": "+70237258756"}
0005433398223	44D234	3919 242677	MARAT KUDRYASHOV	{"email": "m.kudryashov-1973@postgrespro.ru", "phone": "+70141549921"}
0005433398224	A0985C	5160 218939	ANDREY IVANOV	{"email": "a_ivanov.1974@postgrespro.ru", "phone": "+70421153100"}
0005433398225	A0985C	4520 244641	ALEKSEY MAKSIMOV	{"phone": "+70858764070"}
0005433398226	772CF7	2727 977843	SERGEY KUZMIN	{"phone": "+70997693574"}
0005433398227	8E1488	6895 450388	TATYANA KUZMINA	{"phone": "+70862798417"}
0005433398228	E5E9ED	3999 205455	ANTONINA TIMOFEEVA	{"email": "antonina_timofeeva1981@postgrespro.ru", "phone": "+70086704129"}
0005433398229	B84CF8	8817 999224	ALENA VOROBEVA	{"email": "alena-vorobeva-05091973@postgrespro.ru", "phone": "+70585406925"}
0005433398230	A28936	1021 174135	YURIY YAKOVLEV	{"email": "yakovlev.yuriy.111973@postgrespro.ru", "phone": "+70775639062"}
0005433398231	2DACDF	6368 839588	ANDREY ORLOV	{"phone": "+70951566173"}
0005433398232	2DACDF	9473 956690	TATYANA MOROZOVA	{"email": "tatyanamorozova.1981@postgrespro.ru", "phone": "+70332076204"}
0005433398233	B9FA05	3660 378139	ANDREY YAKOVLEV	{"phone": "+70807745545"}
0005433398234	B9FA05	6176 681874	BORIS MATVEEV	{"phone": "+70662475021"}
0005433398235	B9FA05	7072 329389	VERA IVANOVA	{"phone": "+70086782071"}
0005433398236	7823C8	7102 307129	DENIS KUZNECOV	{"email": "dkuznecov28031971@postgrespro.ru", "phone": "+70940682790"}
0005433398237	899781	9242 698505	MARIYA PETROVA	{"email": "m.petrova.23061970@postgrespro.ru", "phone": "+70309273748"}
0005433398238	899781	5486 102009	MARIYA DAVYDOVA	{"email": "davydova_mariya14041964@postgrespro.ru", "phone": "+70395238021"}
0005433398239	899781	5861 465085	OLGA MAKAROVA	{"email": "makarova-olga_1981@postgrespro.ru", "phone": "+70237737507"}
0005433398240	6AEE65	4229 371338	TATYANA AFANASEVA	{"email": "tatyana-afanaseva.1977@postgrespro.ru", "phone": "+70545316489"}
0005433398241	7FBAC5	8737 498087	LYUBOV ANISIMOVA	{"email": "l-anisimova051967@postgrespro.ru", "phone": "+70915897929"}
0005433398242	17355B	8476 009362	ELENA GAVRILOVA	{"email": "gavrilovae.18021980@postgrespro.ru", "phone": "+70584155237"}
0005433398243	A35319	6595 121988	ANTONINA MALYSHEVA	{"email": "malysheva_antonina081977@postgrespro.ru", "phone": "+70241348048"}
0005433398244	A35319	2881 997252	BORIS MAKAROV	{"phone": "+70146839833"}
0005433398245	303989	7689 331750	OLGA RYABOVA	{"email": "olga_ryabova.061968@postgrespro.ru", "phone": "+70180319434"}
0005433398246	48A500	3491 706384	ANNA KOROLEVA	{"email": "anna-koroleva-1969@postgrespro.ru", "phone": "+70873505705"}
0005433398247	7AF493	2064 094709	NAILYA NOVIKOVA	{"phone": "+70708827967"}
0005433398248	7AF493	9861 294197	PAVEL FROLOV	{"email": "p.frolov_12021979@postgrespro.ru", "phone": "+70941532825"}
0005433398249	D5A082	7978 479532	VLADIMIR SOROKIN	{"phone": "+70020690830"}
0005433398250	5C2DDE	3965 970515	DMITRIY GUSEV	{"email": "dmitriygusev.021980@postgrespro.ru", "phone": "+70375391635"}
0005433398251	503629	7121 871129	ELENA POPOVA	{"email": "popovaelena_071979@postgrespro.ru", "phone": "+70399801969"}
0005433398252	503629	5972 665121	TAMARA DAVYDOVA	{"phone": "+70250397577"}
0005433398253	503629	4279 720670	YURIY GORBUNOV	{"phone": "+70665820448"}
0005433398254	A4AFFC	5513 927548	EKATERINA KOZLOVA	{"email": "kozlovae.121979@postgrespro.ru", "phone": "+70576275533"}
0005433398255	A4AFFC	0669 013777	ALEKSEY SOKOLOV	{"email": "sokolov-a1980@postgrespro.ru", "phone": "+70222440268"}
0005433398256	B8DB5F	1106 794055	LILIYA DAVYDOVA	{"phone": "+70246991317"}
0005433398257	3C0CDA	5185 712590	EKATERINA ROMANOVA	{"phone": "+70896338915"}
0005433398258	3C0CDA	2180 024386	OLEG YAKOVLEV	{"email": "yakovlev_o-01071975@postgrespro.ru", "phone": "+70626608508"}
0005433398259	039623	1263 339961	BORIS FROLOV	{"email": "frolovboris11011969@postgrespro.ru", "phone": "+70642136639"}
0005433398260	AD1E76	7503 587092	ALEKSEY BARANOV	{"email": "baranov-aleksey_20091960@postgrespro.ru", "phone": "+70363250363"}
0005433398261	34F8D0	9496 020176	ALEVTINA MOROZOVA	{"email": "morozova_a_29051972@postgrespro.ru", "phone": "+70897113495"}
0005433398262	CDC21C	6680 007050	VALENTINA EFIMOVA	{"email": "v-efimova_1978@postgrespro.ru", "phone": "+70654932435"}
0005433398263	166CF1	1013 217302	NADEZHDA EFIMOVA	{"phone": "+70163837013"}
0005433398264	166CF1	6132 285932	NATALYA PETROVA	{"email": "petrovanatalya_01071965@postgrespro.ru", "phone": "+70954454286"}
0005433398265	92E9A1	9286 628456	DMITRIY ANDREEV	{"phone": "+70173294927"}
0005433398266	08546B	7848 040211	MARIYA IVANOVA	{"email": "mariya-ivanova.1975@postgrespro.ru", "phone": "+70139097273"}
0005433398267	08546B	3038 268117	DAMIR SMIRNOV	{"phone": "+70528297926"}
0005433398268	1D0EB8	1331 310618	NADEZHDA DENISOVA	{"phone": "+70314382637"}
0005433398270	5F4F31	1231 024096	ANNA PAVLOVA	{"email": "pavlova.a-10071968@postgrespro.ru", "phone": "+70028210096"}
0005433398271	5F4F31	2502 715335	EVGENIY MEDVEDEV	{"email": "evgeniy_medvedev_081966@postgrespro.ru", "phone": "+70095715086"}
0005433398272	EDA75B	5033 910892	SERGEY SMIRNOV	{"email": "s.smirnov_06121961@postgrespro.ru", "phone": "+70788911540"}
0005433398273	35F7FE	9883 782010	VLADIMIR GUSEV	{"phone": "+70300065947"}
0005433398274	51E63B	8650 750694	ANDREY IVANOV	{"phone": "+70065116469"}
0005433398275	473A65	0207 198381	IRINA LEBEDEVA	{"email": "i_lebedeva-1973@postgrespro.ru", "phone": "+70442429019"}
0005433398276	78A7D8	3591 048589	OLEG MOISEEV	{"phone": "+70143079422"}
0005433398278	293C3B	3475 858311	MAKSIM NOVIKOV	{"phone": "+70785793282"}
0005433398279	39610E	8447 204119	YURIY ALEKSEEV	{"email": "alekseevyuriy_11071977@postgrespro.ru", "phone": "+70846118988"}
0005433398280	C04180	0856 287028	VLADIMIR ANDREEV	{"phone": "+70391001876"}
0005433398281	4C889D	1350 371419	TATYANA POPOVA	{"phone": "+70578845262"}
0005433398282	085B45	9781 400810	VIKTOR ANTONOV	{"phone": "+70622483230"}
0005433398283	085B45	9128 028664	EKATERINA NIKOLAEVA	{"email": "nikolaeva_ekaterina.1964@postgrespro.ru", "phone": "+70949036250"}
0005433398284	462E72	5598 841193	OLEG TIKHONOV	{"email": "tikhonovo.21111971@postgrespro.ru", "phone": "+70870024960"}
0005433398285	462E72	1226 636674	MAKSIM AFANASEV	{"phone": "+70722957411"}
0005433398286	462E72	3767 156437	ANDREY OSIPOV	{"phone": "+70627729021"}
0005433398287	842C21	3405 392636	TAMARA VASILEVA	{"email": "vasilevatamara.08081967@postgrespro.ru", "phone": "+70622604209"}
0005433398288	D8ECE8	4815 497853	TAMARA OSIPOVA	{"phone": "+70515870453"}
0005433398289	D8ECE8	7719 523770	IGOR SHEVCHENKO	{"email": "shevchenko_i22081972@postgrespro.ru", "phone": "+70261940901"}
0005433398290	E99641	2931 686663	ALEKSEY KOZLOV	{"email": "akozlov111975@postgrespro.ru", "phone": "+70091763558"}
0005433398291	4595C5	7137 747778	VLADIMIR SIDOROV	{"email": "sidorov_v1974@postgrespro.ru", "phone": "+70970537530"}
0005433398292	55818E	7214 285148	OLGA DENISOVA	{"phone": "+70999205212"}
0005433398293	2A03A1	1956 075397	ELENA IVANOVA	{"phone": "+70247306262"}
0005433398294	32B983	7113 472547	IVAN EGOROV	{"email": "egorov-i.091979@postgrespro.ru", "phone": "+70156773283"}
0005433398295	32B983	8905 274360	NATALYA NIKOLAEVA	{"phone": "+70811584341"}
0005433398296	263B76	2248 446332	OLEG EGOROV	{"email": "oleg.egorov.091963@postgrespro.ru", "phone": "+70649083524"}
0005433398297	A8A11D	3144 076008	LYUDMILA ANTONOVA	{"phone": "+70913656426"}
0005433398298	A8A11D	3040 017347	MARGARITA IVANOVA	{"phone": "+70227057210"}
0005433398299	A8A11D	7126 441837	VASILIY SHEVCHENKO	{"email": "shevchenko.v_1975@postgrespro.ru", "phone": "+70958062482"}
0005433398300	5F71C9	0834 778007	ELENA POPOVA	{"email": "popova.elena_1972@postgrespro.ru", "phone": "+70634977724"}
0005433398301	6482C7	6496 116022	NINA ZAKHAROVA	{"email": "nzakharova-1979@postgrespro.ru", "phone": "+70404226564"}
0005433398302	6482C7	5542 699868	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov.1970@postgrespro.ru", "phone": "+70613611501"}
0005433398303	61DE82	0289 174965	IVAN NIKITIN	{"phone": "+70528180724"}
0005433398304	61DE82	2893 388392	SVETLANA MELNIKOVA	{"email": "melnikovasvetlana_1974@postgrespro.ru", "phone": "+70333758927"}
0005433398305	FF4CEB	7650 316725	SVETLANA SOLOVEVA	{"phone": "+70493256989"}
0005433398306	1F9463	7793 034986	LYUDMILA AKIMOVA	{"phone": "+70467560994"}
0005433398307	2D3155	2857 692967	IVAN VASILEV	{"phone": "+70765231761"}
0005433398308	517634	7880 843151	POLINA ZAKHAROVA	{"email": "polina_zakharova-1980@postgrespro.ru", "phone": "+70595016443"}
0005433398309	517634	0993 859523	ANDREY SMIRNOV	{"phone": "+70015537107"}
0005433398310	D01922	0717 063815	VALENTINA IVANOVA	{"email": "valentina.ivanova.051973@postgrespro.ru", "phone": "+70785457240"}
0005433398311	844033	5505 166723	VASILISA IVANOVA	{"phone": "+70060456598"}
0005433398312	D4F50C	0305 388241	SEMEN ZHUKOV	{"phone": "+70737521018"}
0005433398313	CBBF63	4689 443750	YURIY MELNIKOV	{"email": "melnikov-y_011972@postgrespro.ru", "phone": "+70375040384"}
0005433398314	962FED	1686 724787	EVGENIY DENISOV	{"email": "denisov_evgeniy.031984@postgrespro.ru", "phone": "+70976552106"}
0005433398315	BE51D1	7510 556971	GENNADIY GAVRILOV	{"email": "gavrilov-gennadiy.021978@postgrespro.ru", "phone": "+70085958025"}
0005433398316	BAB0B6	6605 146338	NIKOLAY KUZNECOV	{"email": "kuznecovn_01011965@postgrespro.ru", "phone": "+70468382631"}
0005433398317	E7F678	1546 655567	OLGA SOKOLOVA	{"phone": "+70616065134"}
0005433398318	CCBE52	3183 729083	ILYA KAZAKOV	{"phone": "+70924287028"}
0005433398319	5865B1	9065 171399	ALEKSANDR FILIPPOV	{"email": "a_filippov.101966@postgrespro.ru", "phone": "+70332465013"}
0005433398320	5865B1	3046 811981	ANASTASIYA IVANOVA	{"email": "a-ivanova23041963@postgrespro.ru", "phone": "+70141332106"}
0005433398321	5865B1	3937 896952	VLADIMIR MEDVEDEV	{"email": "vladimir-medvedev_1959@postgrespro.ru", "phone": "+70991241884"}
0005433398322	F89927	9665 979113	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr.021975@postgrespro.ru", "phone": "+70671020009"}
0005433398323	9B19B7	8256 391076	VLADIMIR MOROZOV	{"email": "morozov.vladimir_1974@postgrespro.ru", "phone": "+70997593795"}
0005433398324	9B19B7	9625 339784	VASILIY MAKAROV	{"email": "vasiliy_makarov_15031985@postgrespro.ru", "phone": "+70379421060"}
0005433398325	7DA090	4164 825441	VERA ERMAKOVA	{"phone": "+70161246244"}
0005433398326	ED107D	9460 210913	NINA NIKITINA	{"phone": "+70359900006"}
0005433398327	351844	5762 026689	SERGEY MOISEEV	{"email": "moiseevs_061973@postgrespro.ru", "phone": "+70333697788"}
0005433398328	CD896B	7072 736268	ELEONORA NOVIKOVA	{"phone": "+70293588906"}
0005433398329	FEDAA4	4710 865251	OLEG MAKSIMOV	{"phone": "+70162200003"}
0005433398330	3F4C05	8543 522584	YANA ZHURAVLEVA	{"email": "yana.zhuravleva_1967@postgrespro.ru", "phone": "+70943141932"}
0005433398331	DA3189	7827 239185	VYACHESLAV NAZAROV	{"phone": "+70941080009"}
0005433398332	0DE89E	3782 642595	MARINA KRASNOVA	{"email": "marina-krasnova.1970@postgrespro.ru", "phone": "+70325692596"}
0005433398333	49ED8E	9746 194462	KONSTANTIN BORISOV	{"phone": "+70749998953"}
0005433398334	590AC5	8219 093093	OLGA MAKSIMOVA	{"email": "maksimovao.1977@postgrespro.ru", "phone": "+70453966310"}
0005433398335	D23CFE	5531 612965	ILYA ROMANOV	{"email": "i_romanov.1965@postgrespro.ru", "phone": "+70411922968"}
0005433398336	D23CFE	7009 847976	IGOR KRASNOV	{"email": "krasnov-i_011979@postgrespro.ru", "phone": "+70027780364"}
0005433398337	062533	9747 362654	ANTONINA VOLKOVA	{"email": "volkovaantonina-28101969@postgrespro.ru", "phone": "+70806380590"}
0005433398338	062533	7341 469385	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana051978@postgrespro.ru", "phone": "+70760199632"}
0005433398339	062533	5551 880396	TATYANA POPOVA	{"email": "t-popova.1968@postgrespro.ru", "phone": "+70907972189"}
0005433398340	2C0814	0726 730781	GALINA RYABOVA	{"phone": "+70993778307"}
0005433398341	2C0814	1238 103548	YULIYA KUDRYASHOVA	{"email": "yuliya-kudryashova-1970@postgrespro.ru", "phone": "+70184942177"}
0005433398342	E5172D	9940 223729	IRINA VOROBEVA	{"phone": "+70177218803"}
0005433398343	A5BA94	6163 274343	ANTONINA SOLOVEVA	{"phone": "+70780568907"}
0005433398344	656D40	2230 602257	SERGEY SERGEEV	{"email": "sergeev.sergey1976@postgrespro.ru", "phone": "+70327972731"}
0005433398345	AD8400	1437 344602	NADEZHDA FADEEVA	{"phone": "+70722278903"}
0005433398346	AD8400	7705 750498	VIKTOR IVANOV	{"phone": "+70528157338"}
0005433398347	D4515B	2094 116904	VALENTINA SOLOVEVA	{"phone": "+70842680610"}
0005433398348	F9EDCE	7805 862380	ALEKSANDR NOVIKOV	{"phone": "+70716236160"}
0005433398349	4C2645	5237 161483	RAVIL KOZLOV	{"phone": "+70748091626"}
0005433398350	4C2645	4101 256100	RAISA ORLOVA	{"email": "orlova_raisa-29101980@postgrespro.ru", "phone": "+70494099571"}
0005433398351	921329	3820 830701	VERA KUDRYASHOVA	{"email": "kudryashova_v_1969@postgrespro.ru", "phone": "+70903666482"}
0005433398352	4D6174	2516 889968	ELENA ZAKHAROVA	{"phone": "+70473884154"}
0005433398353	4D6174	3364 607902	VLADIMIR CHERNOV	{"phone": "+70131085512"}
0005433398354	4D6174	9157 396196	SERGEY TIKHONOV	{"phone": "+70180099176"}
0005433398355	C8250F	3532 423645	OLGA KUZNECOVA	{"email": "kuznecovao1970@postgrespro.ru", "phone": "+70173179087"}
0005433398356	C8250F	1379 463753	VADIM NIKOLAEV	{"email": "nikolaevvadim021976@postgrespro.ru", "phone": "+70770451873"}
0005433398357	C04826	0524 143943	ELVIRA NAZAROVA	{"email": "nazarova-e.1977@postgrespro.ru", "phone": "+70876785188"}
0005433398358	C04826	9611 740405	ALEKSANDR POPOV	{"email": "aleksandr.popov16011966@postgrespro.ru", "phone": "+70606670584"}
0005433398359	5EEEDA	7839 217375	PAVEL RODIONOV	{"email": "rodionovp.15111959@postgrespro.ru", "phone": "+70161592737"}
0005433398360	5EEEDA	4676 601373	ALEKSANDR EGOROV	{"phone": "+70645845350"}
0005433398361	5EEEDA	4966 032560	ANNA ILINA	{"phone": "+70384139442"}
0005433398362	A3093D	3538 977267	ANATOLIY ANTONOV	{"phone": "+70159497716"}
0005433398363	3E6151	6652 907304	RAMIS ALEKSANDROV	{"phone": "+70436558472"}
0005433398364	3E6151	6844 137187	TATYANA SERGEEVA	{"phone": "+70444646617"}
0005433398365	3E6151	9420 223192	ANASTASIYA SERGEEVA	{"email": "sergeevaanastasiya12041967@postgrespro.ru", "phone": "+70121333430"}
0005433398366	7F61F1	0971 819886	ANTONINA SERGEEVA	{"email": "antonina-sergeeva_121973@postgrespro.ru", "phone": "+70358732183"}
0005433398367	C92AE6	7200 647958	ANATOLIY SOKOLOV	{"phone": "+70873291339"}
0005433398368	580BF0	6046 589826	ANNA YUDINA	{"email": "anna.yudina_1980@postgrespro.ru", "phone": "+70353336497"}
0005433398369	6C83D5	6857 684199	ANASTASIYA EGOROVA	{"phone": "+70784277733"}
0005433398370	F62EC3	1278 593910	ALEKSANDRA ALEKSEEVA	{"phone": "+70545274078"}
0005433398371	7CC59F	0234 474564	IRINA SOLOVEVA	{"phone": "+70282417273"}
0005433398372	7CC59F	9900 233271	ALEKSEY SERGEEV	{"email": "a.sergeev.041964@postgrespro.ru", "phone": "+70544715915"}
0005433398373	674A06	1235 050224	MAKSIM KUZNECOV	{"phone": "+70578146826"}
0005433398374	674A06	9707 003924	ANATOLIY PAVLOV	{"phone": "+70285807904"}
0005433398375	B28216	6828 507378	VIKTOR KOZLOV	{"email": "v.kozlov1974@postgrespro.ru", "phone": "+70899339722"}
0005433398376	B28216	5101 135347	BORIS ISAEV	{"email": "isaev-boris_071977@postgrespro.ru", "phone": "+70394640764"}
0005433398377	F3F73A	2832 440578	MIKHAIL TIKHONOV	{"phone": "+70753395921"}
0005433398378	E4D2C6	1225 129962	NIKOLAY FEDOTOV	{"email": "fedotovnikolay_1974@postgrespro.ru", "phone": "+70955663399"}
0005433398379	C16848	0218 431258	TATYANA ZAYCEVA	{"email": "zayceva_tatyana-1981@postgrespro.ru", "phone": "+70089106581"}
0005433398380	C16848	0201 913827	VITALIY BELOV	{"phone": "+70791924907"}
0005433398381	567302	5364 394197	ALEKSANDR NIKITIN	{"phone": "+70811809230"}
0005433398382	7E64BA	9857 124545	RUSLAN KOZLOV	{"email": "ruslan_kozlov.14091975@postgrespro.ru", "phone": "+70402243998"}
0005433398383	7E64BA	3137 037467	VALERIY GRIGOREV	{"email": "grigorev.valeriy_041970@postgrespro.ru", "phone": "+70093364456"}
0005433398384	635B86	2360 426735	ANATOLIY NAUMOV	{"email": "anaumov_071968@postgrespro.ru", "phone": "+70448082490"}
0005433398385	3BFAB1	2361 742268	ELENA BARANOVA	{"phone": "+70482211170"}
0005433398386	F41D97	4417 098038	YURIY KUDRYASHOV	{"phone": "+70284903824"}
0005433398387	EB2D7F	3606 075679	ARTUR VASILEV	{"phone": "+70304972416"}
0005433398388	EB2D7F	4428 435308	IRINA BORISOVA	{"email": "borisovai24081995@postgrespro.ru", "phone": "+70308976273"}
0005433398389	5D2C75	6052 201439	ALEKSANDR MAKSIMOV	{"phone": "+70707911308"}
0005433398390	26BB9D	7568 173705	ALEKSANDR BELOV	{"phone": "+70276013745"}
0005433398391	8500AE	6939 576943	EVGENIYA BORISOVA	{"phone": "+70819973283"}
0005433398392	8500AE	1177 782437	ALEKSEY POPOV	{"phone": "+70633125326"}
0005433398393	68CDB9	8468 539819	ALEKSANDR SMIRNOV	{"email": "smirnov-a-071970@postgrespro.ru", "phone": "+70497045179"}
0005433398394	D2C9D5	6223 008463	VYACHESLAV POPOV	{"email": "popovv_101964@postgrespro.ru", "phone": "+70091411986"}
0005433398395	D2C9D5	4789 069674	ALEKSANDRA OSIPOVA	{"phone": "+70851674944"}
0005433398396	D2C9D5	2470 312629	ANDREY MEDVEDEV	{"phone": "+70175107784"}
0005433398397	FFFE7B	5900 819036	YULIYA FEDOROVA	{"phone": "+70990004063"}
0005433398398	FFFE7B	0648 279290	ALEKSEY IVANOV	{"phone": "+70001646596"}
0005433398399	44FADF	4738 813433	ANASTASIYA KUZNECOVA	{"phone": "+70565771041"}
0005433398400	44FADF	4511 202972	NIKOLAY NAZAROV	{"phone": "+70616715527"}
0005433398401	0FE02A	2678 687928	SERGEY RODIONOV	{"phone": "+70628602231"}
0005433398402	FD9260	2066 943729	SERGEY FROLOV	{"phone": "+70463820348"}
0005433398403	FD9260	8864 387967	SVETLANA NIKITINA	{"phone": "+70891663916"}
0005433398404	FD9260	3267 039248	ANASTASIYA FEDOROVA	{"email": "anastasiya.fedorova-28051966@postgrespro.ru", "phone": "+70896748852"}
0005433398405	34050E	5537 736292	YURIY CHERNOV	{"email": "yuriy.chernov111969@postgrespro.ru", "phone": "+70517368380"}
0005433398406	34050E	5095 002957	OLGA EGOROVA	{"email": "egorova_olga-1981@postgrespro.ru", "phone": "+70677419270"}
0005433398407	34050E	9697 157395	VERA ZHURAVLEVA	{"email": "zhuravleva_vera.1981@postgrespro.ru", "phone": "+70608135006"}
0005433398408	3BC1E8	4270 290285	ARTEM KUZMIN	{"email": "artemkuzmin.101978@postgrespro.ru", "phone": "+70789187334"}
0005433398409	54FE38	0905 545168	LYUBOV POPOVA	{"email": "popovalyubov_29111982@postgrespro.ru", "phone": "+70993260014"}
0005433398410	01B8D0	0204 016667	LIDIYA FROLOVA	{"phone": "+70097433666"}
0005433398411	CD4AEE	7417 963433	VALERIY TARASOV	{"phone": "+70035479013"}
0005433398412	E080C1	5425 750808	NATALYA BELOVA	{"email": "natalya.belova-031961@postgrespro.ru", "phone": "+70816037119"}
0005433398413	47B7A0	4044 231494	OKSANA LUKYANOVA	{"phone": "+70537332802"}
0005433398414	C6377A	2791 278931	EVGENIY AFANASEV	{"phone": "+70195994479"}
0005433398415	9EAED1	7738 804652	LYUBOV ZAKHAROVA	{"email": "zakharova-lyubov.061967@postgrespro.ru", "phone": "+70258528971"}
0005433398416	444FA3	1862 083781	VLADISLAV BORISOV	{"phone": "+70858250060"}
0005433398417	B9C149	4730 394972	YULIYA DANILOVA	{"phone": "+70542372492"}
0005433398418	B9C149	8004 112599	NIKOLAY VOLKOV	{"email": "volkovn_031972@postgrespro.ru", "phone": "+70240068214"}
0005433398419	B9C149	5036 159302	ALEKSANDR ZHUKOV	{"email": "zhukova-1976@postgrespro.ru", "phone": "+70930900425"}
0005433398420	48C8C8	2074 809288	TAMARA BARANOVA	{"email": "baranova_tamara-041975@postgrespro.ru", "phone": "+70005332007"}
0005433398421	FEE490	8177 026533	MARGARITA FROLOVA	{"email": "frolova_margarita_20051962@postgrespro.ru", "phone": "+70520452857"}
0005433398422	381EF4	7924 486574	DINA ALEKSANDROVA	{"phone": "+70270424923"}
0005433398423	C507E3	3894 639921	SERGEY SERGEEV	{"phone": "+70232175758"}
0005433398424	5559B7	9567 409809	TATYANA MARTYNOVA	{"phone": "+70573847308"}
0005433398425	7FC7C8	2329 887579	EVGENIY SAVELEV	{"phone": "+70098337979"}
0005433398426	7FC7C8	3946 578022	ALEKSEY MATVEEV	{"email": "matveev_aleksey08051976@postgrespro.ru", "phone": "+70189543035"}
0005433398427	B3A859	2254 712264	ELENA MALYSHEVA	{"email": "malysheva_e.15051976@postgrespro.ru", "phone": "+70873793670"}
0005433398428	B3A859	4118 592589	SVETLANA FILIPPOVA	{"phone": "+70198946990"}
0005433398429	79F136	0552 812787	VALENTINA GUSEVA	{"email": "guseva-valentina30081973@postgrespro.ru", "phone": "+70797094738"}
0005433398430	D9D3C3	1475 924606	SVETLANA KAZAKOVA	{"phone": "+70907821202"}
0005433398431	B9CE87	0253 023606	LUIZA KUZMINA	{"email": "kuzmina_luiza.011981@postgrespro.ru", "phone": "+70850229326"}
0005433398432	C6436D	7155 934026	YANA KUZNECOVA	{"email": "kuznecovayana051974@postgrespro.ru", "phone": "+70720261671"}
0005433398433	C6436D	9219 625453	VALERIY POPOV	{"phone": "+70602291400"}
0005433398434	8BE6A8	1249 032345	VIKTORIYA NAZAROVA	{"email": "nazarova_v.101970@postgrespro.ru", "phone": "+70703116101"}
0005433398435	8BE6A8	0796 176742	NIKOLAY SAVELEV	{"email": "savelev_n-031977@postgrespro.ru", "phone": "+70296506102"}
0005433398436	D88242	3213 535469	ALEKSANDR GORBUNOV	{"email": "a.gorbunov_1974@postgrespro.ru", "phone": "+70120985140"}
0005433398437	21DACD	7193 041635	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva_101982@postgrespro.ru", "phone": "+70145450440"}
0005433398438	A9B8BD	6071 265044	LILIYA MIKHAYLOVA	{"email": "mikhaylova.l-1961@postgrespro.ru", "phone": "+70490949869"}
0005433398439	CE87A4	9196 416847	ALEKSANDR PETROV	{"email": "petrov.aleksandr25091978@postgrespro.ru", "phone": "+70466453498"}
0005433398440	12EB70	8351 902245	ROMAN ANDREEV	{"phone": "+70296812325"}
0005433398441	DB804C	4651 584403	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev.1976@postgrespro.ru", "phone": "+70705918036"}
0005433398442	FACB38	4231 295732	VALENTINA KOVALEVA	{"phone": "+70614650971"}
0005433398443	FACB38	4203 980041	SVETLANA SMIRNOVA	{"phone": "+70446891520"}
0005433398444	5FBCB4	5367 558050	EDUARD NOVIKOV	{"email": "e-novikov-1974@postgrespro.ru", "phone": "+70485517017"}
0005433398445	5FBCB4	7742 516433	SERGEY ZAYCEV	{"email": "zaycevs.061977@postgrespro.ru", "phone": "+70151956640"}
0005433398446	1DE57D	5849 475045	TATYANA KALININA	{"email": "t-kalinina.06051969@postgrespro.ru", "phone": "+70934641034"}
0005433398447	8134F4	2604 834134	ALEKSANDR SCHERBAKOV	{"phone": "+70050853507"}
0005433398448	EF2034	2688 879106	VLADIMIR KRASNOV	{"email": "v-krasnov.1978@postgrespro.ru", "phone": "+70497809047"}
0005433398449	61E8B5	2575 780264	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_1974@postgrespro.ru", "phone": "+70250099647"}
0005433398450	61E8B5	3205 613641	EVGENIYA DENISOVA	{"email": "denisovaevgeniya_081972@postgrespro.ru", "phone": "+70346833570"}
0005433398451	84A324	4977 439074	GALINA MIRONOVA	{"email": "galina-mironova.061984@postgrespro.ru", "phone": "+70188863780"}
0005433398452	2A598B	9621 963360	ANTONINA MEDVEDEVA	{"phone": "+70645615611"}
0005433398453	812A93	9054 012345	ELENA KOROLEVA	{"phone": "+70895766370"}
0005433398454	74E3F9	3943 270190	ELENA FEDOROVA	{"email": "e_fedorova.29031977@postgrespro.ru", "phone": "+70763293125"}
0005433398455	270635	4930 495773	KLAVDIYA ILINA	{"phone": "+70406509221"}
0005433398456	90CEA3	5958 439107	VALENTINA KULIKOVA	{"email": "valentina-kulikova111963@postgrespro.ru", "phone": "+70341432269"}
0005433398457	05D6B3	3331 136889	MARIYA MOISEEVA	{"email": "moiseeva_mariya.041977@postgrespro.ru", "phone": "+70688215763"}
0005433398458	05D6B3	3383 655299	LYUBOV ZOTOVA	{"email": "l.zotova.111970@postgrespro.ru", "phone": "+70454020052"}
0005433398459	BEC8E6	4140 028480	MAKSIM KUZMIN	{"email": "maksim_kuzmin.24061954@postgrespro.ru", "phone": "+70489827958"}
0005433398460	2B0298	4491 949584	NINA MIRONOVA	{"phone": "+70822172457"}
0005433398461	C72550	1110 781998	VERA MIKHAYLOVA	{"phone": "+70275157349"}
0005433398462	409E2C	9994 990630	GENNADIY MAKSIMOV	{"phone": "+70307427482"}
0005433398463	409E2C	7092 868427	SERGEY SOKOLOV	{"email": "ssokolov-071974@postgrespro.ru", "phone": "+70417007687"}
0005433398464	18DEF6	2841 176429	ANASTASIYA KOMAROVA	{"phone": "+70322112685"}
0005433398465	AC6F14	5161 884939	MARIYA OSIPOVA	{"email": "m-osipova041969@postgrespro.ru", "phone": "+70952960912"}
0005433398466	AC6F14	7123 523508	VLADIMIR ALEKSEEV	{"email": "v_alekseev_1975@postgrespro.ru", "phone": "+70090491614"}
0005433398467	CB0629	9150 009540	ALEKSEY SAVELEV	{"email": "savelev_aleksey_1965@postgrespro.ru", "phone": "+70835635518"}
0005433398468	17ED8B	5684 036757	DMITRIY SIDOROV	{"phone": "+70327232854"}
0005433398469	EA84F7	0970 121689	IVAN POPOV	{"email": "popovivan-1977@postgrespro.ru", "phone": "+70589297582"}
0005433398470	46B297	4480 157238	EVGENIY KUZMIN	{"email": "kuzmin_e091969@postgrespro.ru", "phone": "+70362829256"}
0005433398471	0E3E1B	5328 701726	IRINA TIKHONOVA	{"email": "irina.tikhonova1967@postgrespro.ru", "phone": "+70087572428"}
0005433398708	5DF399	1738 888516	IGOR MAKAROV	{"phone": "+70442460120"}
0005433398472	5938D5	7769 886139	NIKOLAY FEDOROV	{"email": "nikolay_fedorov.031975@postgrespro.ru", "phone": "+70970946168"}
0005433398473	B45569	2758 998912	GALINA CHERNOVA	{"phone": "+70941675958"}
0005433398474	D50265	8597 989339	LIDIYA LEBEDEVA	{"phone": "+70360040000"}
0005433398475	D7CDCB	9489 331427	YULIYA ALEKSEEVA	{"email": "yuliya-alekseeva041970@postgrespro.ru", "phone": "+70807869901"}
0005433398476	D7CDCB	7585 940809	NINA ILINA	{"email": "n_ilina031977@postgrespro.ru", "phone": "+70725905725"}
0005433398477	7800FB	7727 395234	VLADIMIR FILIPPOV	{"email": "filippov-vladimir_1969@postgrespro.ru", "phone": "+70877903979"}
0005433398478	7800FB	0421 799812	LIDIYA MEDVEDEVA	{"email": "lidiya-medvedeva_30041967@postgrespro.ru", "phone": "+70992709980"}
0005433398479	0EA1C0	9543 817939	GENNADIY ISAEV	{"email": "g_isaev_021970@postgrespro.ru", "phone": "+70040935753"}
0005433398480	823DBB	9403 520069	VALENTINA STEPANOVA	{"phone": "+70477410148"}
0005433398481	823DBB	0792 132258	YANA ROMANOVA	{"email": "romanova-yana_10051982@postgrespro.ru", "phone": "+70427743408"}
0005433398482	299327	1943 472734	LYUBOV SCHERBAKOVA	{"email": "lyubov-scherbakova.16071980@postgrespro.ru", "phone": "+70950946953"}
0005433398483	299327	3083 992031	PAVEL AFANASEV	{"email": "pafanasev-1971@postgrespro.ru", "phone": "+70794619513"}
0005433398484	62303A	8737 838400	NATALYA VOLKOVA	{"phone": "+70647597423"}
0005433398485	FA7525	8730 032303	OKSANA MIKHAYLOVA	{"email": "oksanamikhaylova_1973@postgrespro.ru", "phone": "+70483925545"}
0005433398486	FCDAED	5257 594080	IRINA ANISIMOVA	{"phone": "+70209848124"}
0005433398487	5036CB	2702 793331	VLADISLAV ALEKSANDROV	{"email": "valeksandrov.1964@postgrespro.ru", "phone": "+70786877548"}
0005433398488	9132DA	3855 672889	TATYANA MOROZOVA	{"phone": "+70573505954"}
0005433398489	9132DA	6818 463318	ZINAIDA ANTONOVA	{"email": "antonova_zinaida_1971@postgrespro.ru", "phone": "+70387138489"}
0005433398490	9132DA	7525 608405	OLGA ALEKSEEVA	{"phone": "+70320060138"}
0005433398491	9F1DEB	0524 012018	OLGA PAVLOVA	{"phone": "+70862415047"}
0005433398492	9F1DEB	5956 906818	OKSANA PAVLOVA	{"email": "o-pavlova.031974@postgrespro.ru", "phone": "+70616071889"}
0005433398493	9F1DEB	7971 618189	ELENA ALEKSEEVA	{"phone": "+70303771076"}
0005433398494	6044BE	8923 011082	SVETLANA MIRONOVA	{"email": "mironova_svetlana.1971@postgrespro.ru", "phone": "+70892591752"}
0005433398495	9F391B	2884 702239	ANNA MEDVEDEVA	{"phone": "+70356706097"}
0005433398496	9F391B	1113 677237	ALEKSEY FROLOV	{"email": "aleksey_frolov1967@postgrespro.ru", "phone": "+70183526211"}
0005433398497	274C4B	1976 747876	ELENA SOKOLOVA	{"phone": "+70749247131"}
0005433398498	CA6DE3	8128 628294	NATALYA SEMENOVA	{"email": "n-semenova22011958@postgrespro.ru", "phone": "+70686712845"}
0005433398499	C9FD5F	9081 854001	YANA SERGEEVA	{"email": "y-sergeeva.11071980@postgrespro.ru", "phone": "+70649087564"}
0005433398500	2511A6	6241 056805	MARINA KUZNECOVA	{"email": "kuznecova_m_051971@postgrespro.ru", "phone": "+70240220955"}
0005433398501	A4AFE8	9945 462021	OLEG GORBUNOV	{"email": "gorbunov.oleg_121967@postgrespro.ru", "phone": "+70110838635"}
0005433398502	A4AFE8	4772 758374	VERA SMIRNOVA	{"phone": "+70707613285"}
0005433398503	5D5016	0523 510548	GALINA KUZNECOVA	{"email": "kuznecova-galina.1978@postgrespro.ru", "phone": "+70429029103"}
0005433398504	36862F	4783 124334	TATYANA VOLKOVA	{"email": "tatyana_volkova1967@postgrespro.ru", "phone": "+70367239714"}
0005433398505	65A497	5658 986179	SERGEY BORISOV	{"email": "borisovs.041981@postgrespro.ru", "phone": "+70932841678"}
0005433398506	77FB07	4464 739388	TAISIYA FROLOVA	{"email": "frolova.t.011978@postgrespro.ru", "phone": "+70264488340"}
0005433398507	136DA0	7373 459167	RAMZIYA FILIPPOVA	{"email": "ramziya-filippova-011977@postgrespro.ru", "phone": "+70899395641"}
0005433398508	1E694D	6797 386147	OLGA ZHURAVLEVA	{"phone": "+70930945787"}
0005433398509	1E694D	4601 224207	NIKOLAY MAKAROV	{"phone": "+70996769098"}
0005433398510	1E694D	4992 974260	NIKOLAY ROMANOV	{"phone": "+70541828137"}
0005433398511	6AE3B0	5062 082385	SVETLANA POLYAKOVA	{"email": "polyakovasvetlana1986@postgrespro.ru", "phone": "+70243658149"}
0005433398512	6AE3B0	4285 804758	IRINA VOLKOVA	{"phone": "+70222714624"}
0005433398513	2B0A1B	4475 267782	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr.031967@postgrespro.ru", "phone": "+70113763888"}
0005433398514	5E3BA4	8828 487812	MARINA TITOVA	{"email": "titova_marina.1974@postgrespro.ru", "phone": "+70373032835"}
0005433398515	E95579	9984 539282	SERGEY FEDOROV	{"phone": "+70099510384"}
0005433398516	923E94	8727 812877	MARINA BELOVA	{"email": "marina-belova-24071968@postgrespro.ru", "phone": "+70798247016"}
0005433398517	923E94	2330 768630	ELENA GUSEVA	{"email": "elenaguseva-051974@postgrespro.ru", "phone": "+70147508698"}
0005433398518	216DF1	2962 725885	IRINA OSIPOVA	{"email": "osipova.irina-25101959@postgrespro.ru", "phone": "+70854640009"}
0005433398519	2C1AF4	2710 012203	NATALYA YAKOVLEVA	{"phone": "+70779215379"}
0005433398520	72A3C3	7372 602211	EKATERINA SOKOLOVA	{"email": "e.sokolova-1975@postgrespro.ru", "phone": "+70289843403"}
0005433398521	72A3C3	7855 496801	LYUBOV MARTYNOVA	{"phone": "+70116964294"}
0005433398522	72A3C3	4844 540352	MARIYA VLASOVA	{"email": "vlasova.m051974@postgrespro.ru", "phone": "+70086905104"}
0005433398523	5CB500	7039 730085	MARAT FILIPPOV	{"phone": "+70531474345"}
0005433398524	971C83	3982 321951	SERGEY ZAKHAROV	{"email": "sergeyzakharov_08021970@postgrespro.ru", "phone": "+70032647247"}
0005433398525	B8CBC2	2114 275922	KONSTANTIN ABRAMOV	{"email": "abramov_konstantin-1966@postgrespro.ru", "phone": "+70740245462"}
0005433398526	D79602	7889 279729	DARYA NAZAROVA	{"phone": "+70882891413"}
0005433398527	1EE4BE	0885 018753	RUMIYA MIKHAYLOVA	{"email": "r.mikhaylova26061977@postgrespro.ru", "phone": "+70307387187"}
0005433398528	1EE4BE	0221 454495	VITALIY MIRONOV	{"phone": "+70397272112"}
0005433398529	432C38	9841 300244	MARINA ALEKSEEVA	{"email": "m_alekseeva.1971@postgrespro.ru", "phone": "+70884722257"}
0005433398530	0C90F7	7611 271959	TAISA MIKHAYLOVA	{"email": "mikhaylova.taisa18041969@postgrespro.ru", "phone": "+70420144364"}
0005433398531	0C90F7	5070 056763	LARISA NIKIFOROVA	{"email": "larisa.nikiforova-041962@postgrespro.ru", "phone": "+70071084024"}
0005433398532	1C8A53	0100 389795	YULIYA VASILEVA	{"email": "vasilevay031974@postgrespro.ru", "phone": "+70726359468"}
0005433398533	1C8A53	4087 781124	ELENA TIKHONOVA	{"phone": "+70093041160"}
0005433398534	D1C75B	7738 444723	SAMIR BORISOV	{"phone": "+70993825844"}
0005433398535	D32387	0686 579051	IRINA SIDOROVA	{"phone": "+70018261542"}
0005433398536	3BD0F1	9542 886338	TATYANA BOGDANOVA	{"email": "tatyana.bogdanova.071974@postgrespro.ru", "phone": "+70563991385"}
0005433398537	3BD0F1	0827 217193	SERGEY NAUMOV	{"email": "sergeynaumov31011970@postgrespro.ru", "phone": "+70637077654"}
0005433398538	3BD0F1	4580 147058	YULIYA AFANASEVA	{"email": "y-afanaseva.15081970@postgrespro.ru", "phone": "+70294200670"}
0005433398539	3BD0F1	6229 831770	VLADIMIR POPOV	{"email": "popov.vladimir.1972@postgrespro.ru", "phone": "+70743784710"}
0005433398540	F3058D	7666 294566	MIKHAIL TIKHONOV	{"email": "mikhail-tikhonov.29121974@postgrespro.ru", "phone": "+70837314171"}
0005433398541	F3058D	3883 931081	ELENA KOMAROVA	{"email": "elenakomarova_081971@postgrespro.ru", "phone": "+70306312266"}
0005433398542	1B1401	3527 040146	EDUARD FEDOROV	{"phone": "+70279100583"}
0005433398543	213C53	6995 501028	BORIS YAKOVLEV	{"email": "boris_yakovlev.12021967@postgrespro.ru", "phone": "+70102475772"}
0005433398544	F834E2	4314 569854	DMITRIY VOROBEV	{"phone": "+70641972624"}
0005433398545	D3BD21	7368 593813	ANATOLIY FROLOV	{"phone": "+70161343602"}
0005433398546	A94A5B	0993 182129	LYUDMILA VASILEVA	{"email": "lyudmila.vasileva19051964@postgrespro.ru", "phone": "+70102928705"}
0005433398547	469FC7	0870 905994	LIDIYA POPOVA	{"phone": "+70779533583"}
0005433398548	742B04	4446 664236	ALEKSANDR PETROV	{"email": "a_petrov_091969@postgrespro.ru", "phone": "+70789768941"}
0005433398549	03D1B6	7255 593894	MARK SEMENOV	{"phone": "+70507980255"}
0005433398550	03D1B6	2257 189176	LEONID GAVRILOV	{"email": "l_gavrilov1974@postgrespro.ru", "phone": "+70748793773"}
0005433398551	03D1B6	2489 123066	ARTEM EGOROV	{"email": "artem.egorov-1977@postgrespro.ru", "phone": "+70538832809"}
0005433398552	E8152C	1979 675986	VALENTINA EFREMOVA	{"email": "efremovav.12041969@postgrespro.ru", "phone": "+70139732090"}
0005433398553	4AAAEE	4302 827079	ELENA MATVEEVA	{"phone": "+70911299462"}
0005433398554	4AAAEE	5300 219457	SEMEN KOZLOV	{"phone": "+70213133758"}
0005433398555	10866F	3144 896066	NATALYA DENISOVA	{"email": "denisovanatalya_051973@postgrespro.ru", "phone": "+70106184746"}
0005433398556	23F880	1640 155950	SERGEY PETROV	{"phone": "+70207660585"}
0005433398557	23F880	7596 545499	ANDREY IVANOV	{"email": "ivanovandrey_19081979@postgrespro.ru", "phone": "+70007072983"}
0005433398558	98CF1F	2568 031366	EKATERINA GUSEVA	{"phone": "+70151607717"}
0005433398559	98CF1F	6189 478973	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey.1981@postgrespro.ru", "phone": "+70899891150"}
0005433398560	6528A1	4926 161725	VLADIMIR ZAKHAROV	{"phone": "+70834410111"}
0005433398561	6528A1	0101 682033	NINA GRISHINA	{"email": "grishinan-05091962@postgrespro.ru", "phone": "+70539842805"}
0005433398562	082AEF	5845 193662	ALEKSANDR NIKOLAEV	{"phone": "+70758165513"}
0005433398563	082AEF	6667 489185	ELVIRA MOISEEVA	{"email": "moiseeva-e121974@postgrespro.ru", "phone": "+70324038495"}
0005433398564	5A3595	5893 878603	OLGA FROLOVA	{"email": "frolovao.15081967@postgrespro.ru", "phone": "+70920852718"}
0005433398565	74B996	1378 821075	ANATOLIY ANDREEV	{"email": "anatoliy_andreev1970@postgrespro.ru", "phone": "+70157250771"}
0005433398566	D00CAA	0918 626743	MARIYA LEBEDEVA	{"email": "m_lebedeva.111973@postgrespro.ru", "phone": "+70541967262"}
0005433398567	6DAC05	4690 066472	ELENA MIKHAYLOVA	{"email": "mikhaylovaelena-18091975@postgrespro.ru", "phone": "+70850153222"}
0005433398568	4E9789	0719 170578	EKATERINA ILINA	{"email": "ekaterinailina-13111960@postgrespro.ru", "phone": "+70635820528"}
0005433398569	819EDB	3721 772734	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov.101969@postgrespro.ru", "phone": "+70674638686"}
0005433398570	50FCAA	4937 431722	DMITRIY POPOV	{"phone": "+70352357589"}
0005433398571	F80E1B	8074 489347	IRINA KOROLEVA	{"phone": "+70829988270"}
0005433398572	8C7218	7820 530316	SERGEY FROLOV	{"phone": "+70512090232"}
0005433398573	10F97F	2363 629294	RUSLAN PAVLOV	{"email": "pavlov_ruslan.16101967@postgrespro.ru", "phone": "+70226090490"}
0005433398574	10F97F	5815 443442	ALLA KISELEVA	{"email": "kiseleva.alla-10091983@postgrespro.ru", "phone": "+70666113214"}
0005433398575	A135F8	5095 981498	VLADIMIR PETROV	{"phone": "+70478392337"}
0005433398576	4A15E9	4144 602520	LARISA EGOROVA	{"phone": "+70158410173"}
0005433398577	5155D3	3829 587823	IGOR NAUMOV	{"phone": "+70965006834"}
0005433398578	5155D3	9239 736939	RASUL IVANOV	{"email": "r.ivanov.1978@postgrespro.ru", "phone": "+70768994612"}
0005433398579	FE7843	9064 492768	ANDREY BORISOV	{"phone": "+70929352372"}
0005433398580	FCDBF5	5202 847214	VYACHESLAV SOLOVEV	{"phone": "+70064631759"}
0005433398581	FCDBF5	2165 524462	NADEZHDA SAVELEVA	{"email": "nadezhda.saveleva-22051979@postgrespro.ru", "phone": "+70218308924"}
0005433398582	7F6D11	1268 187211	LYUBOV NIKITINA	{"phone": "+70422620643"}
0005433398583	FD7AA8	7103 854855	SVETLANA ANISIMOVA	{"phone": "+70491972268"}
0005433398584	FD7AA8	2611 968179	ALEKSANDRA SOROKINA	{"email": "sorokina-a_1979@postgrespro.ru", "phone": "+70185896059"}
0005433398585	137DFF	8816 323885	DMITRIY KUZMIN	{"phone": "+70610919630"}
0005433398586	EF19BB	2432 870203	TATYANA SERGEEVA	{"phone": "+70601609220"}
0005433398587	EF19BB	6487 335114	TAMARA NIKOLAEVA	{"email": "tamara-nikolaeva_091977@postgrespro.ru", "phone": "+70072963835"}
0005433398588	EFD034	6966 819254	VIKTOR VOLKOV	{"phone": "+70165268681"}
0005433398709	874434	0044 763501	SVETLANA LUKYANOVA	{"phone": "+70736240661"}
0005433398589	EFD034	7399 779529	NATALYA BELYAEVA	{"email": "belyaeva.n.111973@postgrespro.ru", "phone": "+70441024780"}
0005433398590	900B6A	3456 858227	VIKTOR STEPANOV	{"email": "stepanov.viktor_1968@postgrespro.ru", "phone": "+70030485511"}
0005433398591	628C7B	6198 175821	ELENA YAKOVLEVA	{"email": "elena-yakovleva08081964@postgrespro.ru", "phone": "+70433661390"}
0005433398592	8CA34D	6205 195681	VALENTINA CHERNOVA	{"phone": "+70857735443"}
0005433398593	28C7FF	2999 970836	ALEKSANDR MIKHAYLOV	{"phone": "+70625491621"}
0005433398594	8F3571	1434 755530	MIKHAIL ROMANOV	{"email": "m-romanov_1966@postgrespro.ru", "phone": "+70980308654"}
0005433398595	4B6554	0645 309128	LIDIYA STEPANOVA	{"email": "stepanoval.061966@postgrespro.ru", "phone": "+70751182879"}
0005433398596	C37ED6	2385 038813	TATYANA MOISEEVA	{"email": "tatyana.moiseeva_1979@postgrespro.ru", "phone": "+70899535239"}
0005433398597	4DA567	5545 277665	VLADIMIR DENISOV	{"email": "vladimirdenisov_14051977@postgrespro.ru", "phone": "+70215584514"}
0005433398598	8249EC	3893 100562	SVYATOSLAV DENISOV	{"phone": "+70869171654"}
0005433398599	47F940	9031 399011	YURIY RODIONOV	{"email": "yuriy_rodionov-111960@postgrespro.ru", "phone": "+70960385960"}
0005433398600	47F940	8626 854033	OLEG VASILEV	{"phone": "+70419984513"}
0005433398601	F92BC9	7660 210586	ALEKSEY TIKHONOV	{"phone": "+70371493847"}
0005433398602	569DA1	5259 460267	VLADIMIR ROMANOV	{"email": "romanov-vladimir_06021973@postgrespro.ru", "phone": "+70932319894"}
0005433398603	57E977	6165 084562	ANASTASIYA KISELEVA	{"email": "a_kiseleva041971@postgrespro.ru", "phone": "+70121764651"}
0005433398604	57E977	7723 155383	ANASTASIYA MATVEEVA	{"email": "a-matveeva_1968@postgrespro.ru", "phone": "+70599374918"}
0005433398605	57E977	4285 867842	FEDOR TIKHONOV	{"email": "f_tikhonov121973@postgrespro.ru", "phone": "+70956949528"}
0005433398606	259CF5	7381 097202	MARINA SEMENOVA	{"email": "m-semenova.1965@postgrespro.ru", "phone": "+70329262384"}
0005433398607	259CF5	5195 174358	ALEKSANDR SHEVCHENKO	{"phone": "+70628445935"}
0005433398608	2578ED	1022 911135	OLGA KOROLEVA	{"email": "olga_koroleva-011977@postgrespro.ru", "phone": "+70817474994"}
0005433398609	117727	1258 073742	VALENTINA MOISEEVA	{"email": "vmoiseeva1975@postgrespro.ru", "phone": "+70934691205"}
0005433398610	117727	2235 361916	NIKOLAY MAKSIMOV	{"email": "n.maksimov-1968@postgrespro.ru", "phone": "+70664804734"}
0005433398611	49B56D	2588 518364	ALEKSEY FOMIN	{"email": "fomin-a.14061974@postgrespro.ru", "phone": "+70428115228"}
0005433398612	F618C9	7471 521661	OLEG KUZNECOV	{"email": "o-kuznecov-18011972@postgrespro.ru", "phone": "+70214938181"}
0005433398613	D52E02	7873 277046	VASILIY VASILEV	{"phone": "+70655043749"}
0005433398614	C8B852	5364 093853	RUSLAN GERASIMOV	{"phone": "+70150865161"}
0005433398615	C8B852	6311 099492	SERGEY PETROV	{"email": "petrov-s1969@postgrespro.ru", "phone": "+70744972789"}
0005433398616	C8B852	7371 273617	RAMILYA BARANOVA	{"phone": "+70171000650"}
0005433398617	9C6E83	6747 527362	ZOYA POPOVA	{"email": "zpopova_1975@postgrespro.ru", "phone": "+70039905534"}
0005433398618	9C6E83	2860 019057	IREK GORBUNOV	{"phone": "+70999064153"}
0005433398619	E446C6	5870 631898	ANTONINA OSIPOVA	{"email": "osipova.antonina_1965@postgrespro.ru", "phone": "+70419912405"}
0005433398620	E446C6	0904 049801	ALEKSANDR VOLKOV	{"phone": "+70496950668"}
0005433398621	E446C6	2642 550376	NIKOLAY SCHERBAKOV	{"email": "scherbakov_nikolay-111966@postgrespro.ru", "phone": "+70531501460"}
0005433398622	CE0FB1	9976 158208	ANNA KALININA	{"email": "a_kalinina_28081965@postgrespro.ru", "phone": "+70452442740"}
0005433398623	A20689	9913 077179	NIKITA VASILEV	{"email": "n.vasilev1962@postgrespro.ru", "phone": "+70817416934"}
0005433398624	A20689	9720 007563	EGOR ANDREEV	{"email": "andreev_egor.061975@postgrespro.ru", "phone": "+70005697346"}
0005433398625	A32C39	6250 528072	SERGEY PETROV	{"email": "sergey_petrov_041973@postgrespro.ru", "phone": "+70536410031"}
0005433398626	41E1A5	7236 511775	NIKOLAY MEDVEDEV	{"email": "medvedevn121984@postgrespro.ru", "phone": "+70536575408"}
0005433398627	768B01	3805 937068	MARIYA MOROZOVA	{"email": "m.morozova.091973@postgrespro.ru", "phone": "+70311326182"}
0005433398628	7B65E3	6054 942696	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana.1967@postgrespro.ru", "phone": "+70215296827"}
0005433398629	18FCEF	1619 942604	ELENA KARPOVA	{"phone": "+70282568153"}
0005433398630	7F80B4	3305 194477	PAVEL ZHUKOV	{"phone": "+70662345056"}
0005433398631	7F80B4	4472 317020	IRINA KUZNECOVA	{"phone": "+70768928892"}
0005433398632	AE21C1	6908 518273	ANDREY NIKOLAEV	{"email": "nikolaeva23081975@postgrespro.ru", "phone": "+70167467510"}
0005433398633	318D8B	9575 976116	DARYA FROLOVA	{"phone": "+70865247642"}
0005433398634	4D0550	3127 271285	VALERIYA FROLOVA	{"phone": "+70520208341"}
0005433398635	851488	0231 804031	BULAT IVANOV	{"phone": "+70555391478"}
0005433398636	9EB95D	6064 507000	OLGA YAKOVLEVA	{"phone": "+70136046316"}
0005433398637	9EB95D	6072 417831	VALENTINA DENISOVA	{"email": "denisova_valentina24091984@postgrespro.ru", "phone": "+70459257448"}
0005433398638	9EB95D	7465 597735	OLGA KAZAKOVA	{"email": "kazakova.o1976@postgrespro.ru", "phone": "+70377435199"}
0005433398639	6D3A30	2634 633646	ELVIRA FOMINA	{"email": "elvira_fomina_1966@postgrespro.ru", "phone": "+70025145773"}
0005433398640	FE0CAC	1751 763218	NATALIYA ZAYCEVA	{"email": "nzayceva_071970@postgrespro.ru", "phone": "+70159025079"}
0005433398641	FE0CAC	8564 857030	VERA KOROLEVA	{"phone": "+70133577660"}
0005433398642	7E589C	9796 278749	ALINA EGOROVA	{"email": "egorova-a10031975@postgrespro.ru", "phone": "+70377113558"}
0005433398643	D740B4	9035 351964	MARIYA DAVYDOVA	{"email": "mariya-davydova-31101973@postgrespro.ru", "phone": "+70112497193"}
0005433398644	D740B4	8977 559060	DMITRIY FOMIN	{"phone": "+70579807724"}
0005433398645	3E6644	5908 335303	ANDREY MARTYNOV	{"email": "martynov.a-28091965@postgrespro.ru", "phone": "+70205371029"}
0005433398646	3E6644	8107 589516	GALINA MOISEEVA	{"phone": "+70403778220"}
0005433398647	8543D7	9614 391449	NATALYA ANDREEVA	{"email": "andreevan-101967@postgrespro.ru", "phone": "+70858392533"}
0005433398648	7370A8	4466 841016	ALEKSEY ZAKHAROV	{"email": "a-zakharov_1970@postgrespro.ru", "phone": "+70630590002"}
0005433398649	1AF0A5	9555 215234	NATALYA POLYAKOVA	{"email": "n-polyakova-121967@postgrespro.ru", "phone": "+70256647924"}
0005433398650	59D4A7	1277 066476	PAVEL KARPOV	{"email": "p_karpov081981@postgrespro.ru", "phone": "+70619142600"}
0005433398651	E07AA9	6557 042722	OLEG IVANOV	{"email": "ivanov-oleg_1977@postgrespro.ru", "phone": "+70085981951"}
0005433398652	D52FDE	9457 871549	VALERIY TIMOFEEV	{"phone": "+70749965988"}
0005433398653	E43718	2835 597688	VALENTIN RODIONOV	{"email": "rodionov_v_04071965@postgrespro.ru", "phone": "+70629582859"}
0005433398654	7E46F1	6797 145498	REGINA POPOVA	{"phone": "+70476203036"}
0005433398655	7E46F1	6376 424457	ANTONINA KOMAROVA	{"email": "komarova_a27071975@postgrespro.ru", "phone": "+70463253170"}
0005433398656	7E46F1	2743 002563	NINA SEMENOVA	{"email": "ninasemenova-14041967@postgrespro.ru", "phone": "+70383831378"}
0005433398657	973599	6174 698765	NATALYA ORLOVA	{"email": "orlovanatalya.071976@postgrespro.ru", "phone": "+70062554596"}
0005433398658	973599	7616 580316	VALERIY DAVYDOV	{"phone": "+70307599305"}
0005433398659	66C7C5	3791 805788	DMITRIY KRASNOV	{"email": "krasnov_dmitriy1978@postgrespro.ru", "phone": "+70750298071"}
0005433398660	20CBE6	5476 856364	NATALIYA NOVIKOVA	{"phone": "+70351967837"}
0005433398661	20CBE6	7428 859058	SVETLANA MOROZOVA	{"phone": "+70095121937"}
0005433398662	D2D2C5	3911 852909	TATYANA ANISIMOVA	{"phone": "+70280342759"}
0005433398663	992D40	5632 721559	EVGENIY MOROZOV	{"phone": "+70140785205"}
0005433398664	992D40	2630 626527	VIKTORIYA LEBEDEVA	{"phone": "+70013153370"}
0005433398665	7181BC	1871 238706	NATALYA ABRAMOVA	{"phone": "+70441877968"}
0005433398666	7181BC	0576 708076	ARTEM FILIPPOV	{"phone": "+70708098998"}
0005433398667	D54892	9202 477869	ALEKSANDRA SOKOLOVA	{"phone": "+70212783449"}
0005433398668	D54892	1565 473243	VLADIMIR IVANOV	{"phone": "+70282418612"}
0005433398669	6CC470	0696 063425	SERGEY KONOVALOV	{"phone": "+70005789540"}
0005433398670	CC23C8	7218 212611	DMITRIY NAZAROV	{"email": "nazarov-d-011962@postgrespro.ru", "phone": "+70298236464"}
0005433398671	613BB8	3509 772760	DMITRIY FILIPPOV	{"email": "dfilippov_1981@postgrespro.ru", "phone": "+70108493975"}
0005433398672	613BB8	7180 184380	TAMARA MAKAROVA	{"email": "tmakarova-071979@postgrespro.ru", "phone": "+70465706635"}
0005433398673	7AF0CD	2513 108672	ANDREY CHERNOV	{"phone": "+70389432649"}
0005433398674	7A9E28	2817 414499	OLGA TROFIMOVA	{"phone": "+70528907496"}
0005433398675	3C50B3	6454 738470	DMITRIY MEDVEDEV	{"email": "dmitriy_medvedev_1981@postgrespro.ru", "phone": "+70340077530"}
0005433398676	3C50B3	0203 316874	SERGEY NIKITIN	{"phone": "+70088958419"}
0005433398677	3C50B3	7934 536224	ADELINA GRISHINA	{"phone": "+70385492576"}
0005433398678	B81316	8779 214442	ANDREY SEMENOV	{"email": "asemenov.1961@postgrespro.ru", "phone": "+70626978200"}
0005433398679	07C9EE	3343 230450	OLGA ERMAKOVA	{"email": "olga.ermakova1992@postgrespro.ru", "phone": "+70975002534"}
0005433398680	07C9EE	3463 972909	MARIYA MIKHAYLOVA	{"phone": "+70092249756"}
0005433398681	DE410D	3400 149563	OLGA ABRAMOVA	{"phone": "+70009115646"}
0005433398682	DE410D	9735 826712	SVETLANA KOROLEVA	{"email": "koroleva-svetlana.061971@postgrespro.ru", "phone": "+70761954951"}
0005433398683	193EC9	8743 228141	ANDREY ZAYCEV	{"email": "zayceva_23121977@postgrespro.ru", "phone": "+70042216557"}
0005433398684	193EC9	9705 355833	SERGEY VASILEV	{"email": "vasilev-s_1978@postgrespro.ru", "phone": "+70562982964"}
0005433398685	2153B2	5866 853478	OLGA KONOVALOVA	{"phone": "+70619259913"}
0005433398686	26D2CD	4932 471509	DMITRIY SMIRNOV	{"email": "dmitriy_smirnov08011969@postgrespro.ru", "phone": "+70623413798"}
0005433398687	96960F	3559 178763	LYUBOV MOROZOVA	{"phone": "+70257278824"}
0005433398688	6E4A6A	2938 180888	NADEZHDA ROMANOVA	{"email": "romanova-n_1979@postgrespro.ru", "phone": "+70502004917"}
0005433398689	245535	1666 249529	MARIYA NIKOLAEVA	{"phone": "+70864558902"}
0005433398690	BD236E	9181 452031	SERGEY MELNIKOV	{"email": "s-melnikov_02021973@postgrespro.ru", "phone": "+70752992896"}
0005433398691	D14C92	5890 559650	VADIM IVANOV	{"email": "ivanov-v111980@postgrespro.ru", "phone": "+70742484207"}
0005433398692	B87E08	7534 337944	LYUBOV GERASIMOVA	{"phone": "+70532799223"}
0005433398693	47154D	1070 565352	ELENA IVANOVA	{"phone": "+70588080670"}
0005433398694	0D260E	0508 466344	NINA BARANOVA	{"email": "n_baranova_1983@postgrespro.ru", "phone": "+70838294600"}
0005433398695	0D260E	8658 741212	VYACHESLAV ALEKSEEV	{"phone": "+70397929278"}
0005433398696	876A95	0455 139972	TATYANA MAKAROVA	{"email": "makarova-tatyana-121976@postgrespro.ru", "phone": "+70033104590"}
0005433398697	C1E529	6084 519026	EVGENIY OSIPOV	{"email": "osipov_evgeniy1969@postgrespro.ru", "phone": "+70510798912"}
0005433398698	568722	1305 920916	IGOR PAVLOV	{"phone": "+70873520467"}
0005433398699	FA7E85	1940 708721	ANNA DMITRIEVA	{"phone": "+70908174309"}
0005433398700	FA7E85	6643 976986	VIKTORIYA SMIRNOVA	{"email": "viktoriya.smirnova.1964@postgrespro.ru", "phone": "+70813572196"}
0005433398701	53C8A8	2692 449345	EVGENIYA ANISIMOVA	{"phone": "+70980986407"}
0005433398702	380A24	2952 226697	ELENA MALYSHEVA	{"email": "malyshevaelena06071971@postgrespro.ru", "phone": "+70785225605"}
0005433398703	380A24	8919 890214	TATYANA NOVIKOVA	{"phone": "+70440475117"}
0005433398704	380A24	6109 111086	LYUDMILA GAVRILOVA	{"phone": "+70880704967"}
0005433398705	808D83	9936 044192	MAKSIM KOROLEV	{"email": "korolevm20091976@postgrespro.ru", "phone": "+70343897150"}
0005433398706	5DF399	9310 316888	YURIY TARASOV	{"email": "tarasov_y111976@postgrespro.ru", "phone": "+70005567249"}
0005433398707	5DF399	8194 877314	MARINA PAVLOVA	{"email": "pavlova-marina1966@postgrespro.ru", "phone": "+70070574292"}
0005433398710	874434	4188 880668	OLEG SOKOLOV	{"email": "osokolov1977@postgrespro.ru", "phone": "+70027730725"}
0005433398711	BBAD81	0090 319962	NADEZHDA ISAEVA	{"phone": "+70695816713"}
0005433398712	FAB34C	6030 049974	GALINA VLASOVA	{"phone": "+70123252814"}
0005433398713	FAB34C	6931 217572	ANNA KUZNECOVA	{"phone": "+70102426647"}
0005433398714	FAB34C	2392 734343	GALINA SERGEEVA	{"email": "galina.sergeeva.12101974@postgrespro.ru", "phone": "+70723135180"}
0005433398715	55AD57	5261 554662	NATALYA ILINA	{"email": "ilinanatalya051955@postgrespro.ru", "phone": "+70118890370"}
0005433398716	5B1526	7104 992821	LIDIYA KULIKOVA	{"email": "lidiya.kulikova-1979@postgrespro.ru", "phone": "+70750381320"}
0005433398717	5B1526	1363 469930	OLGA RODIONOVA	{"email": "olga.rodionova.1975@postgrespro.ru", "phone": "+70949508493"}
0005433398718	8BA767	3889 013250	KONSTANTIN KAZAKOV	{"phone": "+70308946652"}
0005433398719	18748D	6760 305307	VLADIMIR ZAKHAROV	{"phone": "+70052895871"}
0005433398720	23B7B3	1508 781332	KIRILL IVANOV	{"email": "ivanovk-031968@postgrespro.ru", "phone": "+70652989921"}
0005433398721	829E16	5305 970012	ALEKSANDRA BELYAEVA	{"phone": "+70369733067"}
0005433398722	44941E	7749 996641	ALIYA ABRAMOVA	{"email": "a-abramova-1976@postgrespro.ru", "phone": "+70296706700"}
0005433398723	8A1B25	5585 112962	ELENA FEDOROVA	{"email": "fedorova-elena-051978@postgrespro.ru", "phone": "+70103117273"}
0005433398724	8A1B25	2611 579668	YULIYA SOROKINA	{"phone": "+70806761716"}
0005433398725	A601C9	3227 877270	ZINAIDA ZHURAVLEVA	{"email": "z.zhuravleva-07031972@postgrespro.ru", "phone": "+70756125401"}
0005433398726	31C20A	8852 488049	ALEKSANDR FILIPPOV	{"phone": "+70013106916"}
0005433398727	397FA1	2029 366901	VALENTINA VASILEVA	{"phone": "+70048009792"}
0005433398728	1DAA8E	9885 979929	VLADIMIR KUDRYASHOV	{"phone": "+70127108101"}
0005433398729	1DAA8E	7136 605670	IRINA KULIKOVA	{"phone": "+70726787474"}
0005433398730	3EC215	6191 534918	NATALYA NIKOLAEVA	{"email": "natalya_nikolaeva-1963@postgrespro.ru", "phone": "+70338193856"}
0005433398731	881741	6851 042916	VERA ZHUKOVA	{"email": "v.zhukova-101977@postgrespro.ru", "phone": "+70663891312"}
0005433398732	881741	2231 991375	VASILIY KUZMIN	{"phone": "+70808876746"}
0005433398733	97A656	9142 200291	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov051971@postgrespro.ru", "phone": "+70933603822"}
0005433398734	712EA1	4420 068085	VLADIMIR GAVRILOV	{"email": "gavrilov_v.04051976@postgrespro.ru", "phone": "+70762773456"}
0005433398735	0DD178	6374 338331	ALEKSANDR PAVLOV	{"phone": "+70259070643"}
0005433398736	FB3E1A	6825 411055	YURIY BORISOV	{"phone": "+70633969477"}
0005433398737	15B8EE	4608 523242	ANASTASIYA MOROZOVA	{"phone": "+70922428690"}
0005433398738	66A5D3	0148 813810	FARIDA NIKITINA	{"email": "nikitina.f-27091970@postgrespro.ru", "phone": "+70136533912"}
0005433398739	33E4B5	9786 950136	ANDREY NIKITIN	{"email": "andrey-nikitin10071968@postgrespro.ru", "phone": "+70700437225"}
0005433398740	73307B	0518 514527	ILYA DMITRIEV	{"email": "dmitrievi_031964@postgrespro.ru", "phone": "+70493285643"}
0005433398741	73307B	4840 097767	VASILIY DENISOV	{"email": "vasiliy_denisov-12061975@postgrespro.ru", "phone": "+70119711400"}
0005433398742	73307B	0366 245204	VLADIMIR ZAYCEV	{"email": "v_zaycev_10101969@postgrespro.ru", "phone": "+70108224933"}
0005433398743	3D2B3D	4564 765553	ROMAN KAZAKOV	{"email": "kazakovroman1975@postgrespro.ru", "phone": "+70846688909"}
0005433398744	3D2B3D	2248 344580	EVGENIY OSIPOV	{"phone": "+70306506610"}
0005433398745	912D8C	1952 243525	MIKHAIL KUZNECOV	{"phone": "+70372015482"}
0005433398746	912D8C	4175 843410	LIYA PAVLOVA	{"email": "l.pavlova_1972@postgrespro.ru", "phone": "+70642801862"}
0005433398747	912D8C	8493 474982	VLADIMIR FEDOROV	{"email": "fedorov.vladimir-1974@postgrespro.ru", "phone": "+70713852945"}
0005433398748	6301A3	8448 447589	EKATERINA MELNIKOVA	{"email": "e_melnikova081973@postgrespro.ru", "phone": "+70031325961"}
0005433398749	06F766	3133 338552	ANDREY KUZNECOV	{"phone": "+70482845951"}
0005433398750	90C313	6980 870543	ILYA SHEVCHENKO	{"email": "ilya-shevchenko.1968@postgrespro.ru", "phone": "+70696298282"}
0005433398751	EEA83F	1772 441922	SERGEY MOISEEV	{"email": "s-moiseev-21081976@postgrespro.ru", "phone": "+70575747528"}
0005433398752	E15FB2	6254 610309	ANNA YAKOVLEVA	{"phone": "+70267669994"}
0005433398753	A62856	4477 532047	YULIYA FOMINA	{"email": "y.fomina1974@postgrespro.ru", "phone": "+70605307048"}
0005433398754	A62856	0672 904144	SHAMIL PAVLOV	{"email": "shamil_pavlov-1965@postgrespro.ru", "phone": "+70135452700"}
0005433398755	A1B76E	5565 579769	NATALYA KONDRATEVA	{"email": "n_kondrateva051966@postgrespro.ru", "phone": "+70612435020"}
0005433398756	82698F	9180 003908	YULIYA KISELEVA	{"email": "kiselevayuliya.1970@postgrespro.ru", "phone": "+70935202303"}
0005433398757	82698F	8693 950672	MARGARITA NOVIKOVA	{"email": "novikova-m.26061971@postgrespro.ru", "phone": "+70397247642"}
0005433398758	64B20F	7997 622404	DMITRIY EGOROV	{"email": "egorovdmitriy29121987@postgrespro.ru", "phone": "+70195184219"}
0005433398759	3EC852	1417 102062	NADEZHDA MARTYNOVA	{"phone": "+70793093422"}
0005433398760	0BD937	7287 790836	OLEG MAKAROV	{"email": "makarov_oleg-12071963@postgrespro.ru", "phone": "+70115605536"}
0005433398761	B5A651	0299 590389	VASILIY GRIGOREV	{"phone": "+70510846103"}
0005433398762	AE6E24	6318 940829	MAKSIM SOKOLOV	{"phone": "+70128135122"}
0005433398763	AE6E24	8335 547300	VITALIY VASILEV	{"email": "vasilev.v.06061966@postgrespro.ru", "phone": "+70867548730"}
0005433398764	950FE8	4939 547443	POLINA ZOTOVA	{"email": "p.zotova_121984@postgrespro.ru", "phone": "+70713690567"}
0005433398765	950FE8	8140 181585	ANNA ZHUKOVA	{"phone": "+70103429209"}
0005433398766	950FE8	3326 407438	VLADIMIR FOMIN	{"email": "fominvladimir1978@postgrespro.ru", "phone": "+70309411173"}
0005433398767	A728AD	0695 965657	YURIY SMIRNOV	{"phone": "+70611474535"}
0005433398768	A728AD	3161 573260	PETR GAVRILOV	{"email": "gavrilov-p.121991@postgrespro.ru", "phone": "+70787981959"}
0005433398769	0E7831	9476 569878	LYUBOV IVANOVA	{"phone": "+70062202387"}
0005433398770	0BE932	2217 507028	ALEKSEY MEDVEDEV	{"phone": "+70500242241"}
0005433398771	60616B	7424 014632	VLADIMIR MAKAROV	{"phone": "+70522881037"}
0005433398772	90C031	8467 432258	DMITRIY GUSEV	{"phone": "+70725728570"}
0005433398773	90C031	8816 591604	ALEKSANDR OSIPOV	{"phone": "+70290779303"}
0005433398774	0F7071	2263 749219	ALEKSANDR GERASIMOV	{"phone": "+70580785852"}
0005433398775	922B00	4196 124508	SVETLANA IVANOVA	{"phone": "+70935580066"}
0005433398776	85F16C	9849 073574	VIKTOR POPOV	{"email": "v_popov.07021971@postgrespro.ru", "phone": "+70197895748"}
0005433398777	0C1BE0	2053 873838	VASILIY KUZNECOV	{"email": "vkuznecov_21051969@postgrespro.ru", "phone": "+70517031977"}
0005433398778	BC183F	5968 827260	MAKSIM PAVLOV	{"email": "pavlov-m.031972@postgrespro.ru", "phone": "+70845388494"}
0005433398779	BC183F	8329 822760	SERGEY ZHURAVLEV	{"phone": "+70613462581"}
0005433398780	1CAAB4	9427 894146	ANTONINA NOVIKOVA	{"email": "antonina_novikova-05011968@postgrespro.ru", "phone": "+70957853004"}
0005433398781	D299F3	0046 569267	GALINA LUKYANOVA	{"phone": "+70896930845"}
0005433398782	463DE6	0249 119513	ALEKSANDR NAUMOV	{"phone": "+70092148716"}
0005433398783	6A65A7	7089 023376	MARIYA IVANOVA	{"phone": "+70353456482"}
0005433398784	8898A3	6384 165884	SVETLANA KUZNECOVA	{"phone": "+70165982909"}
0005433398785	D0CE5A	4826 388659	ALSU ZHUKOVA	{"phone": "+70361288237"}
0005433398786	D0CE5A	9827 008203	KRISTINA FEDOROVA	{"phone": "+70294898501"}
0005433398787	57DDAD	5784 403806	ALEKSEY IVANOV	{"phone": "+70768541843"}
0005433398788	57DDAD	8526 981840	ANDREY BELOV	{"email": "a_belov_041969@postgrespro.ru", "phone": "+70730707275"}
0005433398789	6769D9	7142 736568	ELENA KUZNECOVA	{"email": "e.kuznecova-1970@postgrespro.ru", "phone": "+70888770824"}
0005433398790	8B8B7A	0062 724021	VLADIMIR FEDOTOV	{"email": "fedotov-v_1972@postgrespro.ru", "phone": "+70736186166"}
0005433398791	6646FD	3124 257051	VLADIMIR DENISOV	{"phone": "+70546300137"}
0005433398792	A8F0D5	3521 865394	TATYANA ARKHIPOVA	{"email": "arkhipova-tatyana.021969@postgrespro.ru", "phone": "+70202716333"}
0005433398793	A8F0D5	1585 234184	VIKTORIYA NOVIKOVA	{"email": "novikova.v_1975@postgrespro.ru", "phone": "+70647713196"}
0005433398794	C0B9C7	9158 822601	GALINA MIKHAYLOVA	{"phone": "+70478390118"}
0005433398795	346228	2794 805957	GALINA ZAYCEVA	{"phone": "+70637786610"}
0005433398796	241C80	5585 491395	PAVEL STEPANOV	{"email": "pavelstepanov.081977@postgrespro.ru", "phone": "+70454310161"}
0005433398797	241C80	0653 134995	ANATOLIY DENISOV	{"phone": "+70359746119"}
0005433398798	6175E1	1719 863614	LIDIYA MAKAROVA	{"phone": "+70219978674"}
0005433398799	6175E1	5325 218131	EVGENIY BORISOV	{"phone": "+70841348417"}
0005433398800	8CC171	7790 187740	EDUARD PAVLOV	{"phone": "+70124288175"}
0005433398801	8CC171	3744 752413	ROMAN DAVYDOV	{"phone": "+70583981170"}
0005433398802	8CC171	0397 871724	VLADIMIR POPOV	{"phone": "+70336234487"}
0005433398803	363B66	6988 836768	TAMARA ZHUKOVA	{"email": "zhukova.t.111975@postgrespro.ru", "phone": "+70054091787"}
0005433398804	F2FC0B	6414 400132	ANASTASIYA VLASOVA	{"email": "a_vlasova-101969@postgrespro.ru", "phone": "+70712367738"}
0005433398805	5C21D0	8810 777367	ALEKSEY MELNIKOV	{"phone": "+70077891160"}
0005433398806	87BDD6	5269 006625	ALINA IVANOVA	{"email": "alina.ivanova22101973@postgrespro.ru", "phone": "+70551665510"}
0005433398807	0F258C	7720 281792	MIKHAIL MIKHAYLOV	{"phone": "+70479381019"}
0005433398808	47B228	1777 580212	LILIYA KUDRYASHOVA	{"phone": "+70086028177"}
0005433398809	2D7BF6	8618 287354	ALEKSEY SHEVCHENKO	{"email": "a-shevchenko_1979@postgrespro.ru", "phone": "+70475109959"}
0005433398810	1181B0	7215 297209	ALEKSANDR FROLOV	{"phone": "+70691001791"}
0005433398811	535AB1	4142 657745	NADEZHDA KUZNECOVA	{"email": "n_kuznecova-121967@postgrespro.ru", "phone": "+70145730292"}
0005433398812	7D9620	0706 038541	MARIYA MAKAROVA	{"email": "makarova.mariya_1966@postgrespro.ru", "phone": "+70461892805"}
0005433398813	7D9620	7380 415589	TATYANA KOLESNIKOVA	{"phone": "+70001254154"}
0005433398814	343D07	3128 139739	MARIYA POPOVA	{"email": "popova_mariya011970@postgrespro.ru", "phone": "+70998593497"}
0005433398815	215855	1434 474499	REGINA KAZAKOVA	{"email": "reginakazakova-26111974@postgrespro.ru", "phone": "+70415692912"}
0005433398816	DDBE4F	6713 250990	OLGA NIKOLAEVA	{"email": "nikolaeva_olga_15091965@postgrespro.ru", "phone": "+70938593357"}
0005433398817	955EE0	5203 697853	VADIM MOISEEV	{"email": "moiseevv_24021962@postgrespro.ru", "phone": "+70142708003"}
0005433398818	2E3423	4465 541441	EVGENIY ILIN	{"phone": "+70085491840"}
0005433398819	FA44E6	1152 093461	VALENTINA IVANOVA	{"email": "valentina-ivanova-121967@postgrespro.ru", "phone": "+70043219219"}
0005433398820	D05E30	1587 868983	LARISA ALEKSEEVA	{"phone": "+70423138493"}
0005433398821	DC8DE1	1323 231517	VALENTINA NIKOLAEVA	{"email": "v_nikolaeva.051978@postgrespro.ru", "phone": "+70117756130"}
0005433398822	DC8DE1	7428 704276	MARIYA NIKITINA	{"phone": "+70619844005"}
0005433398823	5F6563	0648 510261	VIKTOR IVANOV	{"email": "ivanovviktor.1972@postgrespro.ru", "phone": "+70388268948"}
0005433398824	4B8948	7006 232665	SVETLANA VOROBEVA	{"email": "svetlana_vorobeva_071961@postgrespro.ru", "phone": "+70057752477"}
0005433398825	741681	8173 734721	LEONID IVANOV	{"email": "ivanov_l-071972@postgrespro.ru", "phone": "+70664714896"}
0005433398826	D0051B	3599 316140	TATYANA ZAYCEVA	{"email": "zaycevatatyana_1965@postgrespro.ru", "phone": "+70610004517"}
0005433398827	EF8981	1997 114286	VERA FROLOVA	{"email": "v.frolova1975@postgrespro.ru", "phone": "+70299678642"}
0005433398828	E8699C	1983 036114	NATALIYA LAZAREVA	{"email": "nlazareva_26011966@postgrespro.ru", "phone": "+70677756330"}
0005433398829	53646E	3974 404238	ELENA KRASNOVA	{"email": "elena-krasnova.09111969@postgrespro.ru", "phone": "+70202224593"}
0005433398830	4BC800	2788 027804	DANIIL SOROKIN	{"email": "sorokindaniil-051979@postgrespro.ru", "phone": "+70827801888"}
0005433398831	2C1870	9296 925800	ELENA BORISOVA	{"phone": "+70520963583"}
0005433398832	249928	7816 093319	SOFYA MAKSIMOVA	{"email": "maksimovas24091965@postgrespro.ru", "phone": "+70461021522"}
0005433398833	48DC30	8784 475682	YULIYA AKIMOVA	{"phone": "+70377963404"}
0005433398834	A7CF73	9556 371487	VIKTOR KUZNECOV	{"email": "viktorkuznecov.19041978@postgrespro.ru", "phone": "+70287816388"}
0005433398835	A7CF73	9585 209775	ANTON FEDOTOV	{"email": "fedotov.a1970@postgrespro.ru", "phone": "+70799685923"}
0005433398836	106B71	8162 951912	GALINA KALININA	{"phone": "+70999035760"}
0005433398837	2B9D7C	9826 884347	IRINA NAZAROVA	{"email": "nazarova-irina_011960@postgrespro.ru", "phone": "+70038405737"}
0005433398838	7D154A	1009 012178	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov-071972@postgrespro.ru", "phone": "+70325577874"}
0005433398839	95F9D1	7069 819777	IVAN PAVLOV	{"phone": "+70493808144"}
0005433398840	BC1372	5161 338210	VALENTINA SOROKINA	{"email": "sorokina_valentina-091974@postgrespro.ru", "phone": "+70823406119"}
0005433398841	91CDC2	0254 382158	OLGA PETROVA	{"email": "petrova_o-1974@postgrespro.ru", "phone": "+70862425527"}
0005433398842	55840A	8047 097068	VLADIMIR BELOV	{"phone": "+70586260982"}
0005433398843	96E7FD	4977 431330	VYACHESLAV BORISOV	{"email": "vyacheslav-borisov13051972@postgrespro.ru", "phone": "+70536503899"}
0005433398844	96E7FD	6736 037741	YURIY PETROV	{"email": "petrov-y.03081961@postgrespro.ru", "phone": "+70574564093"}
0005433398845	7E424D	7509 878396	SERGEY NAUMOV	{"phone": "+70423560721"}
0005433398846	7E424D	5875 948186	MARIYA KOMAROVA	{"email": "mariya.komarova_041965@postgrespro.ru", "phone": "+70494634869"}
0005433398847	876C7F	4236 139523	ANDREY POPOV	{"email": "andrey-popov.29121984@postgrespro.ru", "phone": "+70147853557"}
0005433398848	876C7F	3839 214656	DENIS KUZNECOV	{"email": "kuznecov-d27061984@postgrespro.ru", "phone": "+70627500185"}
0005433398849	058F3B	0360 703655	EKATERINA SCHERBAKOVA	{"phone": "+70286463408"}
0005433398850	5FE802	6573 399692	IRINA AFANASEVA	{"phone": "+70788860621"}
0005433398851	17E54D	0814 276257	ALEKSANDR VOROBEV	{"phone": "+70594829604"}
0005433398852	17E54D	2234 386185	VALENTINA ZAYCEVA	{"phone": "+70350386017"}
0005433398853	3760B0	4384 569365	MARIYA PAVLOVA	{"email": "mpavlova-1982@postgrespro.ru", "phone": "+70547320191"}
0005433398854	BBF46A	7738 078545	MARIYA GORBUNOVA	{"email": "gorbunova_mariya_031969@postgrespro.ru", "phone": "+70031521090"}
0005433398855	BBF46A	2327 203146	SERGEY SOROKIN	{"phone": "+70764266168"}
0005433398856	66085F	1480 234499	SVETLANA CHERNOVA	{"email": "svetlana_chernova1975@postgrespro.ru", "phone": "+70819803286"}
0005433398857	B8D789	0259 492556	ALEKSEY EGOROV	{"email": "egorov_aleksey_011975@postgrespro.ru", "phone": "+70281121879"}
0005433398858	B8C339	8047 632900	ALEKSANDR FROLOV	{"phone": "+70716599469"}
0005433398859	B8C339	0675 319756	YURIY KOZLOV	{"phone": "+70202701990"}
0005433398860	B8C339	9567 680048	IRINA FOMINA	{"email": "fomina-irina1985@postgrespro.ru", "phone": "+70142389401"}
0005433398861	07ED7E	7650 250708	SVETLANA TARASOVA	{"phone": "+70728862532"}
0005433398862	73443E	2059 110723	DMITRIY KOZLOV	{"phone": "+70921709244"}
0005433398863	0ACCA1	2989 959323	EKATERINA KUZNECOVA	{"email": "kuznecova_ekaterina101963@postgrespro.ru", "phone": "+70690564296"}
0005433398864	2FAB41	7018 077261	NADEZHDA BELOVA	{"email": "n.belova_17011960@postgrespro.ru", "phone": "+70873707598"}
0005433398865	3F0F3C	1094 510262	TATYANA SCHERBAKOVA	{"phone": "+70406174038"}
0005433398866	3F0F3C	4194 385510	RUSLAN SOROKIN	{"phone": "+70299202554"}
0005433398867	575246	9601 950002	NIKOLAY FILIPPOV	{"email": "filippov_nikolay-1972@postgrespro.ru", "phone": "+70211812527"}
0005433398868	479585	3221 138908	NADEZHDA BARANOVA	{"phone": "+70481000759"}
0005433398869	CAF0FA	0734 226453	OKSANA NIKOLAEVA	{"email": "oksana-nikolaeva1979@postgrespro.ru", "phone": "+70491911515"}
0005433398870	F93D37	4288 811281	OLGA MOROZOVA	{"phone": "+70601936788"}
0005433398871	F93D37	8629 071304	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev.27101973@postgrespro.ru", "phone": "+70937721699"}
0005433398872	C90E21	7439 727040	DMITRIY MAKAROV	{"phone": "+70986336356"}
0005433398873	228FB4	6352 299463	VALENTINA VOLKOVA	{"email": "valentina_volkova29031973@postgrespro.ru", "phone": "+70225075764"}
0005433398874	228FB4	7449 145081	SERGEY SEMENOV	{"phone": "+70517174367"}
0005433398875	0BE579	7692 252270	GALINA KRASNOVA	{"phone": "+70964124397"}
0005433398876	0BE579	6448 900542	VLADISLAV KOZLOV	{"email": "kozlov_vladislav_28051975@postgrespro.ru", "phone": "+70174918286"}
0005433398877	3E8515	2288 094857	VERA ZAKHAROVA	{"phone": "+70697626972"}
0005433398878	BC4618	7902 606260	IVAN KRASNOV	{"email": "krasnov_ivan.051964@postgrespro.ru", "phone": "+70959685722"}
0005433398879	1990FC	4103 106764	TATYANA BORISOVA	{"email": "tatyanaborisova091976@postgrespro.ru", "phone": "+70875316336"}
0005433398880	AE69B1	5399 054917	VLADIMIR SERGEEV	{"email": "sergeevvladimir1964@postgrespro.ru", "phone": "+70267294319"}
0005433398881	AE69B1	0373 475082	NATALIYA TARASOVA	{"phone": "+70060283933"}
0005433398882	AE69B1	1989 935527	OLGA KAZAKOVA	{"phone": "+70367900921"}
0005433398939	526BE2	0988 805748	NATALYA OSIPOVA	{"phone": "+70558397197"}
0005433398883	8A836D	1826 003566	VALENTINA VOROBEVA	{"email": "vorobeva_valentina-08051975@postgrespro.ru", "phone": "+70485747420"}
0005433398884	8A836D	2751 271634	VIKTORIYA MAKSIMOVA	{"phone": "+70854240876"}
0005433398885	80235D	9644 045162	RAISA KARPOVA	{"phone": "+70663601874"}
0005433398886	C2A6E2	9335 903441	YURIY SERGEEV	{"phone": "+70354671705"}
0005433398887	1DFC79	4327 355301	ELENA GRISHINA	{"phone": "+70561507810"}
0005433398888	3F306F	6384 530148	VERA MEDVEDEVA	{"phone": "+70569655883"}
0005433398889	3F306F	0073 738528	MARINA DENISOVA	{"phone": "+70806864617"}
0005433398890	E59E14	2007 493683	LEONID MOISEEV	{"phone": "+70066560509"}
0005433398891	A29BEE	6650 007119	VALENTINA BORISOVA	{"email": "borisovav-13091977@postgrespro.ru", "phone": "+70363183627"}
0005433398892	8F6D69	6321 995314	YURIY BELOV	{"phone": "+70094112876"}
0005433398893	CA3A5D	9469 258028	ELENA SIDOROVA	{"email": "sidorova_elena.091968@postgrespro.ru", "phone": "+70162995506"}
0005433398894	CA3A5D	6211 448011	KRISTINA PETROVA	{"email": "k-petrova_071988@postgrespro.ru", "phone": "+70945949719"}
0005433398895	E47764	5538 628057	POLINA ORLOVA	{"email": "orlova.p.1975@postgrespro.ru", "phone": "+70570919903"}
0005433398896	E426CB	3279 009982	TATYANA MAKAROVA	{"email": "tatyana-makarova_011974@postgrespro.ru", "phone": "+70945604672"}
0005433398897	C70D15	2424 431162	ILNUR MEDVEDEV	{"phone": "+70875964444"}
0005433398898	93B739	0076 243441	NADEZHDA MALYSHEVA	{"email": "malysheva-nadezhda.01051982@postgrespro.ru", "phone": "+70367955742"}
0005433398899	C4EF69	3235 009024	ALEKSEY KRASNOV	{"phone": "+70852718157"}
0005433398900	C4EF69	8085 331656	EVGENIYA KISELEVA	{"phone": "+70266179542"}
0005433398901	FD8CA7	1152 239160	LYUBOV PETROVA	{"phone": "+70791045612"}
0005433398902	FD8CA7	9599 452599	TATYANA KUZNECOVA	{"phone": "+70303003402"}
0005433398903	443AA4	8428 541014	NADEZHDA KARPOVA	{"phone": "+70737069816"}
0005433398904	1EC397	0846 940387	TAMARA ZAKHAROVA	{"phone": "+70594006728"}
0005433398905	1EC397	9368 743166	VALENTINA CHERNOVA	{"phone": "+70297609624"}
0005433398906	0A7E60	8498 152218	IRINA KOROLEVA	{"email": "irina_koroleva071984@postgrespro.ru", "phone": "+70867023259"}
0005433398907	0A7E60	3647 602313	ALEKSANDR FROLOV	{"email": "frolov.aleksandr_1969@postgrespro.ru", "phone": "+70030256174"}
0005433398908	B44D8F	2957 624079	ILONA SOROKINA	{"phone": "+70778739147"}
0005433398909	E6FD2D	2233 460310	VIKTORIYA VLASOVA	{"email": "vlasovav.091973@postgrespro.ru", "phone": "+70828851279"}
0005433398910	6D12B7	1677 596230	ALEKSANDRA GRISHINA	{"email": "grishina_aleksandra.1971@postgrespro.ru", "phone": "+70006840993"}
0005433398911	985DFF	7384 720949	GALINA PAVLOVA	{"email": "galina_pavlova_12081976@postgrespro.ru", "phone": "+70494412152"}
0005433398912	985DFF	1779 514625	VALENTINA MIRONOVA	{"email": "mironova_v1962@postgrespro.ru", "phone": "+70347425903"}
0005433398913	117EF2	9328 862668	KSENIYA MIRONOVA	{"email": "k_mironova061969@postgrespro.ru", "phone": "+70126758735"}
0005433398914	117EF2	7207 588638	STANISLAV IVANOV	{"phone": "+70414438097"}
0005433398915	4ECC37	4352 309240	KIRILL KONOVALOV	{"phone": "+70814098759"}
0005433398916	F844DB	6374 601530	EKATERINA OVCHINNIKOVA	{"email": "ovchinnikovae-19091973@postgrespro.ru", "phone": "+70918746723"}
0005433398917	DC41C7	9249 686056	PAVEL FROLOV	{"email": "p_frolov.18021972@postgrespro.ru", "phone": "+70747993586"}
0005433398918	008B45	7939 896169	ALINA LAZAREVA	{"email": "lazareva.alina.101978@postgrespro.ru", "phone": "+70117689652"}
0005433398919	D658E4	1872 126920	SVETLANA ANTONOVA	{"email": "antonova-s.011978@postgrespro.ru", "phone": "+70186332447"}
0005433398920	18FB46	4591 622744	ANATOLIY KUZMIN	{"email": "kuzmin-a-10051970@postgrespro.ru", "phone": "+70825072435"}
0005433398921	18FB46	4666 265609	GALINA IVANOVA	{"phone": "+70833139678"}
0005433398922	455385	3297 525855	NINA EGOROVA	{"email": "n.egorova.03071974@postgrespro.ru", "phone": "+70062890891"}
0005433398923	850D12	7423 312903	ALEKSANDR PETROV	{"phone": "+70293935581"}
0005433398924	5C5029	4847 660382	POLINA KONDRATEVA	{"email": "kondrateva_p_1974@postgrespro.ru", "phone": "+70835248001"}
0005433398925	EFC366	5129 717720	ALEKSANDR NOVIKOV	{"email": "a-novikov-1950@postgrespro.ru", "phone": "+70848896077"}
0005433398926	A9E521	5536 518451	ANASTASIYA MAKAROVA	{"email": "makarova-anastasiya101984@postgrespro.ru", "phone": "+70929035746"}
0005433398927	A9E521	4630 436851	NINA MOROZOVA	{"phone": "+70259636978"}
0005433398928	6F7F4F	3763 833916	DMITRIY NAZAROV	{"email": "nazarovd20031973@postgrespro.ru", "phone": "+70935260310"}
0005433398929	0C6FCE	0039 966109	ANTONINA DENISOVA	{"email": "denisova-antonina-101967@postgrespro.ru", "phone": "+70521841534"}
0005433398930	12226B	3393 146301	IGOR VOLKOV	{"phone": "+70618310828"}
0005433398931	12226B	8658 879697	VASILISA FOMINA	{"email": "vfomina_071973@postgrespro.ru", "phone": "+70695664018"}
0005433398932	064485	9560 742093	STANISLAV KULIKOV	{"phone": "+70025828915"}
0005433398933	064485	5639 914229	ILGIZ SOROKIN	{"email": "sorokin-i-08121969@postgrespro.ru", "phone": "+70432412460"}
0005433398934	C9FDE4	5397 882221	ELENA ABRAMOVA	{"email": "e_abramova.1972@postgrespro.ru", "phone": "+70204423560"}
0005433398935	586172	7403 071402	VALENTINA ANTONOVA	{"phone": "+70501978584"}
0005433398936	647A46	8402 586862	MARINA FEDOROVA	{"phone": "+70146667542"}
0005433398937	647A46	2734 369314	GALINA RODIONOVA	{"phone": "+70882715459"}
0005433398938	7F93B5	0639 456029	SERGEY TIKHONOV	{"email": "tikhonovs_18121974@postgrespro.ru", "phone": "+70618256515"}
0005433398940	DB4074	3413 567926	IRINA POTAPOVA	{"phone": "+70954276063"}
0005433398941	DB4074	3394 571311	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova04051966@postgrespro.ru", "phone": "+70670227249"}
0005433398942	8C8737	2707 168202	YURIY FEDOROV	{"email": "y.fedorov-1973@postgrespro.ru", "phone": "+70055639341"}
0005433398943	F50F46	3288 896067	ALEKSANDR SEMENOV	{"phone": "+70962540838"}
0005433398944	F50F46	9905 201991	YULIYA MOROZOVA	{"phone": "+70221313610"}
0005433398945	076A26	9366 782580	ELENA GORBUNOVA	{"phone": "+70695850425"}
0005433398946	076A26	2260 737648	ARTUR IVANOV	{"phone": "+70400332595"}
0005433398947	A96C53	7157 234867	ALEKSEY ROMANOV	{"email": "aleksey_romanov021966@postgrespro.ru", "phone": "+70249404851"}
0005433398948	15424B	0204 538651	VALENTINA KUZNECOVA	{"email": "v-kuznecova_14101964@postgrespro.ru", "phone": "+70888946340"}
0005433398949	0FF1AC	5107 766033	EVGENIY SAVELEV	{"phone": "+70916813980"}
0005433398950	6F4245	1638 252303	NIKOLAY SHEVCHENKO	{"phone": "+70715707382"}
0005433398951	6F4245	7749 896753	VALERIY PETROV	{"email": "petrov-valeriy.111975@postgrespro.ru", "phone": "+70462570978"}
0005433398952	E8E96E	1304 588169	NATALIYA KUZNECOVA	{"phone": "+70760696868"}
0005433398953	E8E96E	7539 385425	NADEZHDA SIDOROVA	{"email": "sidorova_nadezhda.1973@postgrespro.ru", "phone": "+70855940191"}
0005433398954	35B9D7	0536 070343	NINA ANISIMOVA	{"phone": "+70815517878"}
0005433398955	70CFFD	8457 276319	ANNA TIKHONOVA	{"phone": "+70728423743"}
0005433398956	273256	0828 668881	ANASTASIYA STEPANOVA	{"email": "stepanovaa_1977@postgrespro.ru", "phone": "+70926345924"}
0005433398957	273256	0408 123891	MIKHAIL POPOV	{"email": "popov.mikhail-031982@postgrespro.ru", "phone": "+70702342146"}
0005433398958	A69A73	7778 904457	YULIYA LUKYANOVA	{"email": "y-lukyanova05011975@postgrespro.ru", "phone": "+70823025409"}
0005433398959	7185BF	1180 350025	GALINA MAKAROVA	{"email": "makarova.galina-1971@postgrespro.ru", "phone": "+70303360595"}
0005433398960	7185BF	4564 749359	ANDREY MEDVEDEV	{"phone": "+70974027192"}
0005433398961	5D0FEC	3587 859954	ANATOLIY KUZNECOV	{"phone": "+70451493755"}
0005433398962	5D0FEC	3181 883963	LYUBOV YAKOVLEVA	{"phone": "+70572387943"}
0005433398963	78AABA	2961 107070	OKSANA MAKAROVA	{"email": "omakarova.1974@postgrespro.ru", "phone": "+70652117876"}
0005433398964	78AABA	0475 972375	EKATERINA VASILEVA	{"email": "e-vasileva.121965@postgrespro.ru", "phone": "+70857349322"}
0005433398965	A19ABF	7487 936339	EVGENIY ALEKSEEV	{"email": "e.alekseev10011965@postgrespro.ru", "phone": "+70642010349"}
0005433398966	0E6D09	2749 045394	OLGA DENISOVA	{"email": "denisova-o_1981@postgrespro.ru", "phone": "+70996930497"}
0005433398967	9F59B6	5102 079283	ANATOLIY KRASNOV	{"email": "krasnov-a16081981@postgrespro.ru", "phone": "+70330368136"}
0005433398968	978DBE	7762 624704	VERA FROLOVA	{"email": "frolova-v-121975@postgrespro.ru", "phone": "+70955662567"}
0005433398969	978DBE	0886 897062	ALEKSEY NAUMOV	{"email": "aleksey-naumov1966@postgrespro.ru", "phone": "+70922201116"}
0005433398970	5C17E5	9776 126798	YURIY KAZAKOV	{"email": "yuriy.kazakov.031975@postgrespro.ru", "phone": "+70182636039"}
0005433398971	5C17E5	0165 137804	VITALIY BONDARENKO	{"email": "vitaliybondarenko.12011963@postgrespro.ru", "phone": "+70093138788"}
0005433398972	469D6E	9576 689394	VALENTINA ROMANOVA	{"email": "valentinaromanova31051968@postgrespro.ru", "phone": "+70719189084"}
0005433398973	469D6E	9016 147729	OLGA SOROKINA	{"email": "osorokina.1972@postgrespro.ru", "phone": "+70139623519"}
0005433398974	FB5BA2	6628 665162	ALEKSANDR IVANOV	{"email": "a.ivanov-081971@postgrespro.ru", "phone": "+70618827752"}
0005433398975	01ED26	9143 127646	LILIYA KALININA	{"phone": "+70467422441"}
0005433398976	01ED26	2822 676633	ILDAR GORBUNOV	{"email": "gorbunov-i_1983@postgrespro.ru", "phone": "+70350472624"}
0005433398977	077E87	5211 401763	ANTON ANTONOV	{"email": "antonovanton091983@postgrespro.ru", "phone": "+70915850529"}
0005433398978	E5F300	9666 858814	VALENTINA POPOVA	{"phone": "+70570947635"}
0005433398979	E6A5BC	4977 771704	ALEKSEY IVANOV	{"email": "aleksey-ivanov09021973@postgrespro.ru", "phone": "+70094431060"}
0005433398980	E6A5BC	0456 213037	OKSANA KUZNECOVA	{"email": "kuznecova_o01061975@postgrespro.ru", "phone": "+70248133612"}
0005433398981	670131	0984 787265	ANATOLIY ANTONOV	{"email": "anatoliy.antonov.08081975@postgrespro.ru", "phone": "+70593111234"}
0005433398982	4AE2A9	1276 237836	ANNA GAVRILOVA	{"phone": "+70197580539"}
0005433398983	C61565	9213 352824	DENIS ILIN	{"phone": "+70046694976"}
0005433398984	AA1642	0133 160569	ANATOLIY ZAKHAROV	{"email": "anatoliy_zakharov.15051985@postgrespro.ru", "phone": "+70084296593"}
0005433398985	49E43F	3762 787700	NATALIYA LOGINOVA	{"email": "nataliya-loginova-1977@postgrespro.ru", "phone": "+70147645108"}
0005433398986	49E43F	6491 826573	VALENTIN SOKOLOV	{"email": "vsokolov.10011974@postgrespro.ru", "phone": "+70151220206"}
0005433398987	5FEB29	0612 729035	VITALIY GUSEV	{"phone": "+70716019878"}
0005433398988	FD80EE	2768 982934	EDUARD MAKAROV	{"phone": "+70253527065"}
0005433398989	FD80EE	6548 160488	IVAN IVANOV	{"phone": "+70235384671"}
0005433398990	292018	1724 728680	YULIYA CHERNOVA	{"email": "chernova_yuliya.1980@postgrespro.ru", "phone": "+70661039350"}
0005433398991	411F10	7800 089612	ANASTASIYA MIKHAYLOVA	{"phone": "+70501627493"}
0005433398992	411F10	8252 774606	ANASTASIYA DAVYDOVA	{"phone": "+70388457385"}
0005433398993	BF5E01	7900 424442	LYUDMILA BOGDANOVA	{"phone": "+70170439577"}
0005433398994	428462	1051 525740	ANNA KUZNECOVA	{"phone": "+70740333398"}
0005433398995	74E85F	5165 748699	NATALYA STEPANOVA	{"phone": "+70921787662"}
0005433398996	9E6938	6968 202144	ANDREY ABRAMOV	{"phone": "+70753562105"}
0005433398997	9E6938	5777 521829	EVGENIYA RYABOVA	{"email": "ryabovae1972@postgrespro.ru", "phone": "+70392894086"}
0005433398998	56BEC6	2506 219799	ELENA MIRONOVA	{"phone": "+70861603318"}
0005433398999	56BEC6	8226 572674	VALENTINA GORBUNOVA	{"email": "valentina-gorbunova1964@postgrespro.ru", "phone": "+70288111098"}
0005433399000	903284	6159 462388	NATALYA EGOROVA	{"phone": "+70165835137"}
0005433399001	58019E	6040 587963	MAKSIM ALEKSEEV	{"email": "m-alekseev031972@postgrespro.ru", "phone": "+70488134590"}
0005433399002	976D69	7017 565653	RAFAIL SOROKIN	{"email": "rafail.sorokin_1987@postgrespro.ru", "phone": "+70307667545"}
0005433399003	F03354	4362 668768	ARTEM FEDOROV	{"phone": "+70067351835"}
0005433399004	69480A	1749 246077	DMITRIY ISAEV	{"email": "dmitriy_isaev_031976@postgrespro.ru", "phone": "+70746266512"}
0005433399005	69480A	0023 240045	ELENA KUZNECOVA	{"email": "kuznecovaelena-12091973@postgrespro.ru", "phone": "+70505211353"}
0005433399006	AAA4C1	9026 951852	ANNA SERGEEVA	{"email": "sergeeva_anna1974@postgrespro.ru", "phone": "+70026986623"}
0005433399007	EAD607	3901 031037	NAILYA VASILEVA	{"email": "vasileva.nailya.061979@postgrespro.ru", "phone": "+70025492669"}
0005433399008	EAD607	8947 543664	VIKTOR SAVELEV	{"phone": "+70645284338"}
0005433399307	8A5317	0464 910427	KSENIYA BORISOVA	{"phone": "+70109324172"}
0005433399009	EAD607	6993 690695	NIKOLAY ANDREEV	{"email": "nandreev1973@postgrespro.ru", "phone": "+70594625353"}
0005433399010	D87423	2923 506898	RAISA NOVIKOVA	{"phone": "+70523081023"}
0005433399011	D91F43	0857 749891	YULIYA ROMANOVA	{"phone": "+70829184081"}
0005433399012	D91F43	7595 620851	ANNA LOGINOVA	{"phone": "+70560819568"}
0005433399013	01B23F	9724 258885	TATYANA STEPANOVA	{"phone": "+70964849753"}
0005433399014	F576AC	7016 644147	OLGA KUZNECOVA	{"phone": "+70049171142"}
0005433399015	A3CD9F	3609 353719	MARINA PAVLOVA	{"phone": "+70883674768"}
0005433399016	832B86	7771 686913	SERGEY IVANOV	{"email": "s_ivanov_28011976@postgrespro.ru", "phone": "+70938003196"}
0005433399017	C37C89	9920 552926	GENNADIY BORISOV	{"email": "borisov.gennadiy_05111962@postgrespro.ru", "phone": "+70704789600"}
0005433399018	C37C89	3808 786196	VALENTINA ROMANOVA	{"email": "romanova.valentina1969@postgrespro.ru", "phone": "+70845059093"}
0005433399019	546DF3	2667 323545	MIKHAIL KOZLOV	{"email": "mikhailkozlov041981@postgrespro.ru", "phone": "+70331421749"}
0005433399020	F9F296	3259 585720	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-1972@postgrespro.ru", "phone": "+70207380457"}
0005433399021	F9F296	4197 478803	TATYANA ISAEVA	{"phone": "+70213263691"}
0005433399022	59E246	5563 600629	VALENTINA DMITRIEVA	{"email": "v-dmitrieva_1967@postgrespro.ru", "phone": "+70085700428"}
0005433399023	A9E99F	2857 448225	NATALYA ILINA	{"email": "n.ilina.101964@postgrespro.ru", "phone": "+70021346749"}
0005433399024	DEE49E	3918 272320	NADEZHDA NIKOLAEVA	{"phone": "+70715283874"}
0005433399025	DEE49E	5845 239625	MARINA VOLKOVA	{"email": "m.volkova_26021973@postgrespro.ru", "phone": "+70795010775"}
0005433399026	AFCD5E	8491 991538	NATALYA TIKHONOVA	{"email": "n.tikhonova_1981@postgrespro.ru", "phone": "+70160235715"}
0005433399027	AFCD5E	2679 653898	ADELINA ANDREEVA	{"email": "andreeva-a_1958@postgrespro.ru", "phone": "+70068029304"}
0005433399028	4245D6	8896 935861	TATYANA PETROVA	{"email": "petrova_t.27091966@postgrespro.ru", "phone": "+70197859963"}
0005433399029	4245D6	5246 465395	SERGEY MAKAROV	{"phone": "+70421461606"}
0005433399030	0DB0ED	4749 368811	IVAN GUSEV	{"phone": "+70583163420"}
0005433399031	0DB0ED	3137 790607	LYUBOV BARANOVA	{"email": "lyubov.baranova-1974@postgrespro.ru", "phone": "+70989668539"}
0005433399032	F538E1	0890 849292	EKATERINA IVANOVA	{"email": "eivanova.08101980@postgrespro.ru", "phone": "+70201981826"}
0005433399033	F538E1	5787 849480	GALINA ALEKSEEVA	{"phone": "+70536069795"}
0005433399034	7816B3	6567 328691	ELIZAVETA KONOVALOVA	{"email": "e-konovalova121964@postgrespro.ru", "phone": "+70246501449"}
0005433399035	109FE4	1926 947599	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_1975@postgrespro.ru", "phone": "+70610445555"}
0005433399036	B6F1AC	3741 410343	VALENTINA FROLOVA	{"phone": "+70759707571"}
0005433399037	133F25	8757 026137	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr-18071975@postgrespro.ru", "phone": "+70218622715"}
0005433399038	0EF3B9	7443 778458	VALENTINA LAZAREVA	{"phone": "+70404110881"}
0005433399039	AAE06A	9926 238552	OLGA KUZNECOVA	{"phone": "+70403750631"}
0005433399040	D8B1DE	1178 707274	IRINA OSIPOVA	{"phone": "+70894625651"}
0005433399041	A494F4	3375 222069	NATALYA POPOVA	{"email": "popova_n-081975@postgrespro.ru", "phone": "+70471816134"}
0005433399042	7FD97E	6790 298763	IVAN GRIGOREV	{"phone": "+70171989647"}
0005433399043	67BF70	0828 061573	TAMARA PETROVA	{"phone": "+70779802789"}
0005433399044	67BF70	4033 984639	ALEKSANDR ZAKHAROV	{"email": "a.zakharov-1979@postgrespro.ru", "phone": "+70453914520"}
0005433399045	B93512	7300 457601	VERA FILIPPOVA	{"email": "vera_filippova051966@postgrespro.ru", "phone": "+70556077600"}
0005433399046	B93512	6980 121230	VLADIMIR KRASNOV	{"phone": "+70712011198"}
0005433399047	CBBDDA	4332 506598	NATALYA KUDRYASHOVA	{"phone": "+70142292657"}
0005433399048	0BE643	0616 971315	GALINA YAKOVLEVA	{"email": "g_yakovleva_1980@postgrespro.ru", "phone": "+70523294141"}
0005433399049	C78C60	8609 173778	NIKITA TIKHONOV	{"phone": "+70097331735"}
0005433399050	C78C60	8869 403191	IVAN ZAKHAROV	{"email": "ivanzakharov.1976@postgrespro.ru", "phone": "+70263171981"}
0005433399051	1E6D2C	8151 474757	VASILIY MIKHAYLOV	{"phone": "+70567788831"}
0005433399052	1E6D2C	4464 884304	VITALIY MARTYNOV	{"email": "martynov.v_081966@postgrespro.ru", "phone": "+70069711441"}
0005433399053	E62A33	2963 319425	YURIY FEDOTOV	{"phone": "+70733214380"}
0005433399054	E62A33	0160 338438	ELENA KOZLOVA	{"phone": "+70326754698"}
0005433399055	E62A33	4354 213913	ANATOLIY MAKAROV	{"phone": "+70245712894"}
0005433399056	512CCE	6141 404621	GENNADIY ALEKSEEV	{"email": "gennadiy.alekseev.071969@postgrespro.ru", "phone": "+70271083741"}
0005433399057	512CCE	6911 693543	NATALYA DMITRIEVA	{"email": "dmitrieva.n_031980@postgrespro.ru", "phone": "+70144335149"}
0005433399058	59CC2B	2250 551359	LYUDMILA POLYAKOVA	{"phone": "+70938377485"}
0005433399059	59CC2B	1687 325915	STANISLAV KUZMIN	{"phone": "+70961723194"}
0005433399060	90209D	8782 262238	OKSANA MAKAROVA	{"email": "o_makarova_27101966@postgrespro.ru", "phone": "+70106408576"}
0005433399061	90209D	9051 068650	ELENA NIKOLAEVA	{"phone": "+70378497086"}
0005433399062	CF7E95	7255 080330	DMITRIY CHERNOV	{"email": "chernov.dmitriy_071977@postgrespro.ru", "phone": "+70197768426"}
0005433399063	9E1608	9997 684356	LYUDMILA POPOVA	{"email": "lyudmila-popova.121972@postgrespro.ru", "phone": "+70864507287"}
0005433399064	C43417	3437 243615	NATALYA VOROBEVA	{"email": "vorobeva-natalya021984@postgrespro.ru", "phone": "+70091643182"}
0005433399065	7964E6	1748 750413	NADEZHDA KUZNECOVA	{"phone": "+70929574607"}
0005433399066	D05273	5013 582925	ANDREY OSIPOV	{"phone": "+70419732390"}
0005433399067	D05273	9625 522189	NATALYA ALEKSEEVA	{"phone": "+70082483608"}
0005433399068	D986B9	8874 305699	LYUDMILA POPOVA	{"email": "lyudmila.popova041961@postgrespro.ru", "phone": "+70134990812"}
0005433399069	1385E4	4296 859720	MARINA MASLOVA	{"phone": "+70460874617"}
0005433399070	0D974D	7096 409947	TATYANA ZAYCEVA	{"email": "zaycevatatyana1976@postgrespro.ru", "phone": "+70919017905"}
0005433399071	0D974D	2442 258750	PAVEL PAVLOV	{"phone": "+70393684479"}
0005433399072	BFD14B	6506 345646	TAMARA NIKITINA	{"phone": "+70766232912"}
0005433399073	C737A6	6751 700890	OLEG KARPOV	{"email": "karpovoleg-081979@postgrespro.ru", "phone": "+70605666586"}
0005433399074	C737A6	2537 920519	IRINA YUDINA	{"email": "irina.yudina.1974@postgrespro.ru", "phone": "+70539477460"}
0005433399075	9BD27E	6405 892250	NATALIYA KUZNECOVA	{"phone": "+70048341546"}
0005433399076	DCDEB6	5797 512294	NIKITA POPOV	{"email": "popov_n_10081968@postgrespro.ru", "phone": "+70464890725"}
0005433399077	66A894	3478 895195	IRINA KOMAROVA	{"email": "ikomarova.06111974@postgrespro.ru", "phone": "+70417576187"}
0005433399078	66A894	8972 824477	SVETLANA TIKHONOVA	{"phone": "+70241867142"}
0005433399079	D5ADC7	7337 445649	ELENA POTAPOVA	{"email": "elenapotapova17111966@postgrespro.ru", "phone": "+70165110308"}
0005433399080	271EB1	5167 857977	DMITRIY KRASNOV	{"phone": "+70526469604"}
0005433399081	8E863D	2791 718204	SERGEY KUZNECOV	{"email": "kuznecov-sergey-1982@postgrespro.ru", "phone": "+70257478301"}
0005433399082	DA8FF5	3468 647405	DARYA IVANOVA	{"phone": "+70941064734"}
0005433399083	DA8FF5	1375 280448	ELIZAVETA NIKIFOROVA	{"phone": "+70720974585"}
0005433399084	DF4615	8639 461270	VERA MOROZOVA	{"email": "v_morozova.03101977@postgrespro.ru", "phone": "+70134235138"}
0005433399085	701DE1	8775 460842	NATALYA BORISOVA	{"email": "borisova_n.021974@postgrespro.ru", "phone": "+70421665362"}
0005433399086	4B3273	5536 012855	VLADIMIR ORLOV	{"phone": "+70276080688"}
0005433399087	AF14AE	9055 801081	NATALYA AKIMOVA	{"email": "n_akimova_28071971@postgrespro.ru", "phone": "+70090567289"}
0005433399088	AF14AE	8037 962012	NIKITA VASILEV	{"phone": "+70112122060"}
0005433399089	B269AD	4633 350276	ELENA SERGEEVA	{"phone": "+70259557975"}
0005433399090	B269AD	2926 185124	FANIL ILIN	{"email": "fanililin02091968@postgrespro.ru", "phone": "+70539463475"}
0005433399091	B269AD	4257 293093	SERGEY IVANOV	{"email": "ivanov.sergey-1970@postgrespro.ru", "phone": "+70044263658"}
0005433399092	654BBF	6458 195709	NATALYA PETROVA	{"phone": "+70502029643"}
0005433399093	654BBF	3897 960171	VYACHESLAV IVANOV	{"phone": "+70533373077"}
0005433399094	FBC638	6511 223296	FARIDA ZAYCEVA	{"email": "f-zayceva.1974@postgrespro.ru", "phone": "+70073590300"}
0005433399095	E8DC77	5320 715250	SERGEY YAKOVLEV	{"phone": "+70153303286"}
0005433399096	E8DC77	2514 768488	SERGEY KISELEV	{"email": "sergey.kiselev_12061974@postgrespro.ru", "phone": "+70596100658"}
0005433399097	4C1768	1753 918713	SERGEY KUZNECOV	{"phone": "+70240179183"}
0005433399098	44EB5E	0403 776390	KRISTINA KOZLOVA	{"phone": "+70816334228"}
0005433399099	DCFA7D	9776 739835	EKATERINA KUDRYASHOVA	{"email": "kudryashova.ekaterina.1972@postgrespro.ru", "phone": "+70753395518"}
0005433399100	705E8C	7933 284832	ELENA KUZNECOVA	{"phone": "+70246712383"}
0005433399101	705E8C	3231 612935	VALENTIN MEDVEDEV	{"phone": "+70711499316"}
0005433399102	705E8C	9891 921295	LYUDMILA BORISOVA	{"email": "borisova_lyudmila-1969@postgrespro.ru", "phone": "+70973632839"}
0005433399103	85FD4F	9993 620898	NINA KUZNECOVA	{"email": "n-kuznecova-12091967@postgrespro.ru", "phone": "+70433184758"}
0005433399104	85FD4F	4292 153734	OLGA SAVELEVA	{"phone": "+70170295596"}
0005433399105	492BE9	2342 949180	ALEKSANDR NIKITIN	{"phone": "+70664596388"}
0005433399106	0F936E	0155 275755	ANNA KOROLEVA	{"email": "a_koroleva01081976@postgrespro.ru", "phone": "+70984420214"}
0005433399107	C3CF4A	7829 775983	SERGEY EGOROV	{"phone": "+70167973440"}
0005433399108	62C8A4	3449 787718	ZINAIDA NESTEROVA	{"email": "z.nesterova-081973@postgrespro.ru", "phone": "+70784047895"}
0005433399109	8ACE0E	9697 161855	RUSTAM PAVLOV	{"phone": "+70298341791"}
0005433399110	8ACE0E	1167 308980	LYUDMILA ZOTOVA	{"email": "zotova-lyudmila_03091966@postgrespro.ru", "phone": "+70907979813"}
0005433399111	76EC65	0495 980974	SVETLANA IVANOVA	{"email": "ivanova_s.28041973@postgrespro.ru", "phone": "+70162975883"}
0005433399112	80F7D8	1801 038857	EVGENIYA VASILEVA	{"phone": "+70073099293"}
0005433399113	80F7D8	4128 656775	NATALIYA KUZMINA	{"email": "nataliyakuzmina-08101977@postgrespro.ru", "phone": "+70588212349"}
0005433399114	80F7D8	8416 752771	ROMAN MAKAROV	{"email": "rmakarov-07081969@postgrespro.ru", "phone": "+70472681542"}
0005433399115	80F7D8	1515 403735	GALINA ABRAMOVA	{"email": "abramova-g-19011977@postgrespro.ru", "phone": "+70992098967"}
0005433399116	74A8ED	3919 328583	ARTEM ZHURAVLEV	{"phone": "+70487124484"}
0005433399117	E185B3	1039 436564	GALINA KUZNECOVA	{"email": "gkuznecova_31011985@postgrespro.ru", "phone": "+70160003086"}
0005433399118	24A452	7302 532949	VALERIY KOZLOV	{"phone": "+70918700638"}
0005433399119	C28610	7426 724032	YULIYA ZAYCEVA	{"phone": "+70723242663"}
0005433399120	229218	8717 719776	DMITRIY MATVEEV	{"email": "dmitriy.matveev_19091969@postgrespro.ru", "phone": "+70444378703"}
0005433399121	229218	3396 437345	LYUDMILA RYABOVA	{"phone": "+70339011511"}
0005433399122	5E94CC	2295 906107	NIKOLAY PETROV	{"phone": "+70048417592"}
0005433399123	B05C77	5821 968600	VASILIY KARPOV	{"email": "v.karpov08031975@postgrespro.ru", "phone": "+70965310171"}
0005433399124	C41360	8487 861501	PAVEL KUZMIN	{"email": "pkuzmin.07011976@postgrespro.ru", "phone": "+70242026068"}
0005433399125	3058B1	1747 822276	GULNARA MIKHAYLOVA	{"email": "g_mikhaylova071986@postgrespro.ru", "phone": "+70240104529"}
0005433399126	7B5C54	5972 013631	VIKTOR ANDREEV	{"email": "viktorandreev-1966@postgrespro.ru", "phone": "+70143414243"}
0005433399127	7B5C54	5415 907028	DANIL VOLKOV	{"email": "danil_volkov-27021968@postgrespro.ru", "phone": "+70922248246"}
0005433399128	F3FFF4	5468 453123	POLINA BELOVA	{"phone": "+70377443855"}
0005433399129	3B66DA	9482 758645	KONSTANTIN POPOV	{"phone": "+70030607865"}
0005433399130	3B66DA	4432 766771	TAMARA TROFIMOVA	{"email": "trofimova.tamara_19061974@postgrespro.ru", "phone": "+70222050486"}
0005433399131	BD7BC9	3186 024087	VLADIMIR MATVEEV	{"email": "vladimir.matveev-1961@postgrespro.ru", "phone": "+70123147612"}
0005433399132	41B196	7522 821548	ELENA DENISOVA	{"email": "denisova.elena13061977@postgrespro.ru", "phone": "+70371202882"}
0005433399133	98C46B	7096 412823	VIKTOR DMITRIEV	{"email": "dmitriev.viktor011973@postgrespro.ru", "phone": "+70096314717"}
0005433399134	2FEF71	6069 724106	POLINA DAVYDOVA	{"phone": "+70975254694"}
0005433399135	2FEF71	8653 925909	ROMAN AFANASEV	{"phone": "+70000556388"}
0005433399136	2FEF71	2251 476026	TATYANA KRASNOVA	{"phone": "+70840336409"}
0005433399137	A2F5EA	9217 893231	SERGEY DMITRIEV	{"phone": "+70287820761"}
0005433399138	A2F5EA	6272 689534	VASILIY SERGEEV	{"email": "vasiliysergeev_1968@postgrespro.ru", "phone": "+70822725292"}
0005433399139	A2F5EA	9543 962994	SERGEY MOROZOV	{"phone": "+70162622246"}
0005433399140	A2F5EA	5297 959768	VASILIY SHEVCHENKO	{"phone": "+70365413313"}
0005433399141	CE038A	1474 527146	IVAN SOKOLOV	{"phone": "+70293429687"}
0005433399142	5D91ED	2132 809993	NADEZHDA KOROLEVA	{"phone": "+70536720078"}
0005433399143	03FF09	2371 174150	ANNA GRISHINA	{"phone": "+70443177126"}
0005433399144	D33CBF	9162 853715	ILMIRA GUSEVA	{"phone": "+70551583990"}
0005433399145	D33CBF	4082 040589	MARINA MOROZOVA	{"email": "m.morozova.1976@postgrespro.ru", "phone": "+70828728043"}
0005433399146	D33CBF	2778 471711	NADEZHDA MARTYNOVA	{"phone": "+70259441050"}
0005433399147	D93AAD	1963 764432	MARIYA MAKAROVA	{"phone": "+70297316822"}
0005433399148	A3A020	1305 395357	DMITRIY SERGEEV	{"email": "sergeev.dmitriy.1972@postgrespro.ru", "phone": "+70246567364"}
0005433399149	E49E76	8576 502400	VLADISLAV GUSEV	{"email": "gusev_v091982@postgrespro.ru", "phone": "+70612907118"}
0005433399150	E49E76	8754 666309	ANDREY AFANASEV	{"email": "andrey.afanasev.1965@postgrespro.ru", "phone": "+70538220090"}
0005433399151	2E0FC1	6926 878943	VLADIMIR OSIPOV	{"email": "osipov.v.111974@postgrespro.ru", "phone": "+70024076548"}
0005433399152	F72573	9699 814818	GENNADIY MEDVEDEV	{"email": "gennadiy_medvedev-1969@postgrespro.ru", "phone": "+70937479410"}
0005433399153	15685E	6595 860927	VALENTIN GAVRILOV	{"phone": "+70161310926"}
0005433399154	15685E	3432 323418	KSENIYA ANDREEVA	{"phone": "+70604183997"}
0005433399155	64420B	6167 016467	NINA EFIMOVA	{"email": "n.efimova_011962@postgrespro.ru", "phone": "+70796485246"}
0005433399156	64420B	0377 864225	DMITRIY MAKAROV	{"phone": "+70091085157"}
0005433399157	C5A9F0	1598 375091	TAISIYA BORISOVA	{"email": "t.borisova_1967@postgrespro.ru", "phone": "+70294653207"}
0005433399158	046558	0218 121225	POLINA FROLOVA	{"phone": "+70167632949"}
0005433399159	046558	2868 248084	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr.12081971@postgrespro.ru", "phone": "+70213751962"}
0005433399160	046558	7784 137272	MIKHAIL SMIRNOV	{"phone": "+70061139445"}
0005433399161	F07EE8	6410 915928	ANNA GORBUNOVA	{"phone": "+70414134337"}
0005433399162	96D10F	9229 096919	RIFAT DAVYDOV	{"phone": "+70169927402"}
0005433399163	A3D905	8562 547149	VALENTINA MOROZOVA	{"email": "valentina-morozova-111964@postgrespro.ru", "phone": "+70768187095"}
0005433399164	D1CD44	2128 048250	MARIYA LOGINOVA	{"phone": "+70059700679"}
0005433399165	E6FF48	0469 311480	ANDREY GUSEV	{"phone": "+70493344481"}
0005433399166	7A364C	2149 985068	IRINA NAZAROVA	{"phone": "+70432413150"}
0005433399167	7C3ACB	0112 836220	ANDREY SOLOVEV	{"phone": "+70626465310"}
0005433399168	FC90CB	0726 206252	NIKOLAY ANDREEV	{"email": "n-andreev.24031969@postgrespro.ru", "phone": "+70151336786"}
0005433399169	4E550F	4384 517772	MIKHAIL IVANOV	{"phone": "+70939985172"}
0005433399170	39848A	1233 811983	EKATERINA IVANOVA	{"email": "ivanova-e_1974@postgrespro.ru", "phone": "+70933950731"}
0005433399171	4A6ED0	1980 578491	GUZEL ANDREEVA	{"email": "andreeva_guzel27051978@postgrespro.ru", "phone": "+70060225437"}
0005433399172	4A6ED0	7691 615899	ANDREY NIKITIN	{"email": "a_nikitin.19041981@postgrespro.ru", "phone": "+70685623077"}
0005433399173	4A6ED0	3262 305346	ALEKSANDRA GERASIMOVA	{"phone": "+70103313158"}
0005433399174	19AAB1	8284 718814	ALEKSEY SHEVCHENKO	{"phone": "+70153145512"}
0005433399175	509C84	3240 458906	DARYA NESTEROVA	{"email": "nesterova.d_1963@postgrespro.ru", "phone": "+70178356833"}
0005433399176	7B6FED	7915 379338	MARIYA DMITRIEVA	{"email": "m-dmitrieva15031971@postgrespro.ru", "phone": "+70817304776"}
0005433399177	C3E545	3042 213869	IGOR MELNIKOV	{"email": "i_melnikov12021976@postgrespro.ru", "phone": "+70884907270"}
0005433399178	BB0FB1	6837 826911	SERGEY KUZNECOV	{"email": "kuznecov_s_121981@postgrespro.ru", "phone": "+70036423288"}
0005433399179	41E293	6292 484945	VIKTORIYA KAZAKOVA	{"phone": "+70535152170"}
0005433399180	41E293	7778 469278	PETR NIKOLAEV	{"email": "nikolaev.petr11061980@postgrespro.ru", "phone": "+70821084652"}
0005433399181	8DA835	8549 801521	EVGENIY STEPANOV	{"phone": "+70385882782"}
0005433399182	DBD653	0406 804202	VALERIY MAKAROV	{"email": "v.makarov.031967@postgrespro.ru", "phone": "+70801539180"}
0005433399183	15CF1D	4368 500469	VADIM ALEKSEEV	{"email": "v_alekseev.1971@postgrespro.ru", "phone": "+70639418153"}
0005433399184	15CF1D	8326 028068	NATALYA NIKITINA	{"email": "nikitina-n.1970@postgrespro.ru", "phone": "+70986116773"}
0005433399185	EFA984	8421 510036	VLADIMIR POPOV	{"email": "popov_vladimir-19121976@postgrespro.ru", "phone": "+70073786755"}
0005433399186	C1086D	0164 343484	ANDREY OSIPOV	{"email": "osipov.andrey091984@postgrespro.ru", "phone": "+70515602250"}
0005433399187	C1086D	7443 556273	VYACHESLAV MIRONOV	{"email": "mironov-vyacheslav.051977@postgrespro.ru", "phone": "+70713825128"}
0005433399188	03368D	9762 305363	SERGEY ANTONOV	{"email": "antonov.s.1983@postgrespro.ru", "phone": "+70283528206"}
0005433399189	92E63E	4273 953706	ALBERT MOISEEV	{"email": "moiseeva-1964@postgrespro.ru", "phone": "+70207540613"}
0005433399190	A25631	0077 201770	MAKSIM BORISOV	{"email": "borisov.m-08091978@postgrespro.ru", "phone": "+70226528108"}
0005433399191	A058EB	9197 216106	ANNA IVANOVA	{"phone": "+70909380623"}
0005433399192	031E39	2538 529169	NINA MAKAROVA	{"email": "makarova.n-04101971@postgrespro.ru", "phone": "+70872727916"}
0005433399193	031E39	2301 390069	RAISA OSIPOVA	{"phone": "+70236624906"}
0005433399194	37214F	9223 430467	VALERIYA TARASOVA	{"phone": "+70366127011"}
0005433399195	362009	8378 611783	SERGEY IVANOV	{"email": "sivanov1970@postgrespro.ru", "phone": "+70375471839"}
0005433399196	20FBF5	4141 174594	PELAGEYA ORLOVA	{"phone": "+70661571554"}
0005433399197	96FBB2	9755 095426	DANIIL POPOV	{"email": "d.popov27011971@postgrespro.ru", "phone": "+70264515744"}
0005433399198	0ED803	1591 159926	ARTUR SCHERBAKOV	{"email": "scherbakova_1973@postgrespro.ru", "phone": "+70799424080"}
0005433399199	0ED803	4529 978881	GALINA TROFIMOVA	{"email": "g-trofimova03121976@postgrespro.ru", "phone": "+70008902683"}
0005433399200	D657DD	2993 457298	ALEKSANDR SHEVCHENKO	{"email": "aleksandr-shevchenko-011973@postgrespro.ru", "phone": "+70461146471"}
0005433399201	D0B439	1954 779321	OLEG KISELEV	{"phone": "+70797968726"}
0005433399202	6D8292	1074 129469	OLGA ANDREEVA	{"email": "andreeva.o-12031977@postgrespro.ru", "phone": "+70607349907"}
0005433399203	0EF4EE	0004 836521	SERGEY KOZLOV	{"email": "kozlov-sergey1972@postgrespro.ru", "phone": "+70931635913"}
0005433399204	27BFF9	1066 509353	ALEKSANDR DAVYDOV	{"email": "davydov-a-1976@postgrespro.ru", "phone": "+70406017689"}
0005433399205	A826A7	9642 758503	GLEB EGOROV	{"email": "egorov-g101980@postgrespro.ru", "phone": "+70759771056"}
0005433399206	A826A7	2295 401584	VIKTOR FROLOV	{"phone": "+70298958315"}
0005433399207	825EA4	7805 434701	VERA SEMENOVA	{"phone": "+70466759251"}
0005433399208	825EA4	9267 954376	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy.081978@postgrespro.ru", "phone": "+70510173094"}
0005433399209	1CAE19	1331 764041	TAMARA KUZNECOVA	{"phone": "+70602405781"}
0005433399210	DEBC93	8554 623846	SVETLANA STEPANOVA	{"phone": "+70922960238"}
0005433399211	DEBC93	8964 074643	ALEKSEY BARANOV	{"phone": "+70650481571"}
0005433399212	D5FA02	6451 886562	ANATOLIY OSIPOV	{"email": "anatoliy_osipov_14051975@postgrespro.ru", "phone": "+70759980246"}
0005433399213	D5FA02	0684 531999	VIKTOR KUZNECOV	{"phone": "+70673149123"}
0005433399214	8B5BDE	4334 841503	IRINA KOZLOVA	{"email": "i.kozlova.031962@postgrespro.ru", "phone": "+70956451488"}
0005433399215	866DD4	3053 234404	LYUDMILA SOLOVEVA	{"email": "soloveva_l-1977@postgrespro.ru", "phone": "+70708732573"}
0005433399216	4E5015	0602 283143	MARIYA KAZAKOVA	{"email": "kazakovam-1956@postgrespro.ru", "phone": "+70845571743"}
0005433399217	5D5A43	3464 731145	TAMARA OSIPOVA	{"phone": "+70429903908"}
0005433399218	5D5A43	4780 382489	PAVEL MOROZOV	{"phone": "+70326868288"}
0005433399219	25CB3E	4081 305846	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.09111964@postgrespro.ru", "phone": "+70244208334"}
0005433399220	25CB3E	2611 021391	ALEKSEY ROMANOV	{"email": "romanovaleksey.031957@postgrespro.ru", "phone": "+70540323176"}
0005433399221	25CB3E	5117 774771	LYUDMILA KUZNECOVA	{"phone": "+70578643396"}
0005433399222	08D1AF	7567 728346	VIKTORIYA DMITRIEVA	{"email": "viktoriya.dmitrieva_1976@postgrespro.ru", "phone": "+70892749279"}
0005433399223	08D1AF	9385 677320	KSENIYA KOROLEVA	{"phone": "+70811276235"}
0005433399224	AF5950	1747 485840	ZINAIDA MEDVEDEVA	{"email": "zinaida-medvedeva-08041970@postgrespro.ru", "phone": "+70216303166"}
0005433399225	941F48	7510 246440	MIKHAIL SMIRNOV	{"phone": "+70009920405"}
0005433399226	4BD766	9288 040839	ALEKSANDR SEMENOV	{"phone": "+70769431471"}
0005433399227	4BD766	2935 602286	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr121977@postgrespro.ru", "phone": "+70116644780"}
0005433399228	A2A973	8320 124457	OLGA MAKAROVA	{"phone": "+70355724647"}
0005433399229	ECFFD7	5587 708748	ELENA ALEKSEEVA	{"phone": "+70585691083"}
0005433399230	FCD408	2010 339081	RAISA ANDREEVA	{"phone": "+70806262310"}
0005433399231	05110D	5235 363346	ALEKSEY KUZNECOV	{"phone": "+70530501394"}
0005433399232	349BED	6368 399121	LARISA MALYSHEVA	{"email": "lmalysheva-121973@postgrespro.ru", "phone": "+70848214817"}
0005433399233	C63EBE	8647 131866	EKATERINA SMIRNOVA	{"email": "ekaterina.smirnova111973@postgrespro.ru", "phone": "+70498868082"}
0005433399234	C63EBE	2494 869566	VIOLETTA GORBUNOVA	{"phone": "+70238726296"}
0005433399235	F2F1B1	1986 161407	IGOR EGOROV	{"email": "igor.egorov101975@postgrespro.ru", "phone": "+70716087851"}
0005433399236	F44177	8739 911695	ZINAIDA MIKHAYLOVA	{"phone": "+70035925789"}
0005433399237	D83B7F	7921 542877	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov.031974@postgrespro.ru", "phone": "+70937192589"}
0005433399238	AF83B1	4399 961248	IVAN GUSEV	{"email": "i_gusev_071971@postgrespro.ru", "phone": "+70324243519"}
0005433399239	804078	9734 146719	DMITRIY YAKOVLEV	{"phone": "+70224282634"}
0005433399240	30614D	9988 228259	VASILIY KUZMIN	{"email": "kuzmin_vasiliy041975@postgrespro.ru", "phone": "+70384799878"}
0005433399241	3B68BC	7833 521887	NADEZHDA KOROLEVA	{"phone": "+70546617245"}
0005433399242	28F4EF	8894 511454	PETR OSIPOV	{"email": "osipov_petr1976@postgrespro.ru", "phone": "+70515393533"}
0005433399243	E247C3	7734 986314	ELIZAVETA RYABOVA	{"email": "e.ryabova1972@postgrespro.ru", "phone": "+70860937314"}
0005433399244	90832F	7714 500014	NATALYA ZHURAVLEVA	{"phone": "+70613305989"}
0005433399245	90832F	2898 374662	SERGEY DMITRIEV	{"phone": "+70126805097"}
0005433399246	CCDC16	7641 659625	RUSLAN GRIGOREV	{"email": "grigorev-ruslan-1969@postgrespro.ru", "phone": "+70472463428"}
0005433399247	56C568	4195 274905	ARTEM VLASOV	{"phone": "+70647776631"}
0005433399248	E6E772	0203 108496	MARGARITA VOLKOVA	{"email": "volkova.margarita04081974@postgrespro.ru", "phone": "+70164495313"}
0005433399249	E6E772	4892 175346	NIKITA MAKAROV	{"email": "makarov.nikita-21091976@postgrespro.ru", "phone": "+70376742965"}
0005433399250	9D0481	4114 297835	DMITRIY IVANOV	{"email": "ivanovd-071991@postgrespro.ru", "phone": "+70278003360"}
0005433399251	9D0481	1693 558703	DENIS IVANOV	{"phone": "+70647421506"}
0005433399252	C4ED7C	8666 009261	DENIS MIKHAYLOV	{"email": "d-mikhaylov-081974@postgrespro.ru", "phone": "+70202242245"}
0005433399253	4E1358	9225 752242	ELIZAVETA STEPANOVA	{"email": "elizavetastepanova_031979@postgrespro.ru", "phone": "+70751429339"}
0005433399254	A446D4	9207 458501	ELIZAVETA ROMANOVA	{"email": "romanova-elizaveta_1957@postgrespro.ru", "phone": "+70593781774"}
0005433399255	611EB1	8924 201002	SERGEY NIKOLAEV	{"email": "nikolaevsergey.1964@postgrespro.ru", "phone": "+70276049640"}
0005433399256	E4714E	1727 946198	RAISA KOZLOVA	{"phone": "+70027865572"}
0005433399257	628628	2518 811893	SERGEY SMIRNOV	{"phone": "+70205778773"}
0005433399258	A2B5B8	8577 228948	PETR BORISOV	{"phone": "+70600515820"}
0005433399259	3F7182	7564 854703	OLGA LAZAREVA	{"email": "lazarevaolga1975@postgrespro.ru", "phone": "+70350840893"}
0005433399260	83B8F1	0408 250556	RINAT BORISOV	{"email": "borisov.r021972@postgrespro.ru", "phone": "+70673488894"}
0005433399261	559936	5397 059288	LYUBOV FILIPPOVA	{"email": "filippoval1991@postgrespro.ru", "phone": "+70306957408"}
0005433399262	559936	0210 200959	NIKOLAY SMIRNOV	{"email": "nikolay-smirnov_121988@postgrespro.ru", "phone": "+70163162621"}
0005433399263	805886	0619 083670	GALINA KISELEVA	{"email": "kiseleva.g_121973@postgrespro.ru", "phone": "+70549137185"}
0005433399264	27C970	5074 530727	ARSENIY SAVELEV	{"phone": "+70502017761"}
0005433399265	C5D1C1	1646 869939	EKATERINA LUKYANOVA	{"email": "e-lukyanova-051987@postgrespro.ru", "phone": "+70789994215"}
0005433399266	C5D1C1	4467 133558	ALENA PETROVA	{"email": "alena.petrova-25101980@postgrespro.ru", "phone": "+70296871413"}
0005433399267	FB6425	7142 538612	GALINA KUZMINA	{"phone": "+70374252143"}
0005433399268	27BB44	8674 279632	SERGEY BORISOV	{"email": "borisov_sergey1971@postgrespro.ru", "phone": "+70203454369"}
0005433399269	3239DE	2135 758113	OLGA IVANOVA	{"email": "oivanova_17021968@postgrespro.ru", "phone": "+70521767877"}
0005433399270	153969	7357 657782	ANATOLIY BELOV	{"phone": "+70162698940"}
0005433399271	F86FC9	8996 774752	STANISLAV DAVYDOV	{"email": "sdavydov1963@postgrespro.ru", "phone": "+70590870650"}
0005433399272	08C9F0	6029 087007	OLGA BARANOVA	{"email": "o.baranova-021973@postgrespro.ru", "phone": "+70636541539"}
0005433399273	E05C8F	3312 427784	ALBINA RODIONOVA	{"phone": "+70526671454"}
0005433399274	9BBE43	3356 258674	OLGA VASILEVA	{"email": "olgavasileva.1987@postgrespro.ru", "phone": "+70877323883"}
0005433399441	60659F	1624 540424	ELENA ANISIMOVA	{"phone": "+70886696412"}
0005433399275	EC0A86	0698 088587	VIKTOR POPOV	{"email": "v.popov.021976@postgrespro.ru", "phone": "+70938278363"}
0005433399276	EC0A86	8704 341027	ALIYA KUDRYASHOVA	{"email": "kudryashova.a.1963@postgrespro.ru", "phone": "+70009204772"}
0005433399277	BA483E	0479 017254	OLGA DANILOVA	{"phone": "+70947781361"}
0005433399278	BC93FD	5582 392089	EVGENIY SIDOROV	{"phone": "+70256580736"}
0005433399279	E2B697	3707 898213	IRINA BORISOVA	{"phone": "+70887265207"}
0005433399280	E2B697	2908 222799	ANATOLIY TIKHONOV	{"phone": "+70892611179"}
0005433399281	D73872	8456 594097	LIDIYA FILIPPOVA	{"email": "l-filippova-101969@postgrespro.ru", "phone": "+70938734038"}
0005433399282	D73872	7799 195151	ROMAN SIDOROV	{"email": "sidorov-r051959@postgrespro.ru", "phone": "+70900709201"}
0005433399283	D73872	9204 545753	NATALYA AFANASEVA	{"phone": "+70539005452"}
0005433399284	9E12E4	9148 715033	VLADIMIR EGOROV	{"email": "egorovvladimir_121960@postgrespro.ru", "phone": "+70150844695"}
0005433399285	5C39AF	2632 303664	EGOR ALEKSEEV	{"email": "alekseev-e-14111978@postgrespro.ru", "phone": "+70110685883"}
0005433399286	3A00E4	7701 372709	VALERIY KUZMIN	{"phone": "+70455266193"}
0005433399287	3A00E4	1193 293681	IRINA IVANOVA	{"email": "ivanova.irina_13071974@postgrespro.ru", "phone": "+70754852032"}
0005433399288	F855DC	6547 239996	KIRILL GORBUNOV	{"phone": "+70558009630"}
0005433399289	F855DC	4131 458001	IVAN MOISEEV	{"phone": "+70432840871"}
0005433399290	8664DB	0669 958824	ANNA TARASOVA	{"email": "atarasova021976@postgrespro.ru", "phone": "+70057178580"}
0005433399291	5E6839	6614 531940	VIKTOR STEPANOV	{"email": "stepanov-viktor-041967@postgrespro.ru", "phone": "+70906979617"}
0005433399292	F14C58	7771 221046	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey-071980@postgrespro.ru", "phone": "+70158596009"}
0005433399293	F14C58	1972 011129	IBRAGIM SOROKIN	{"email": "isorokin091967@postgrespro.ru", "phone": "+70349081960"}
0005433399294	613B25	7572 201085	EKATERINA PETROVA	{"email": "ekaterinapetrova_1979@postgrespro.ru", "phone": "+70426361843"}
0005433399295	0AE963	3834 545023	VASILIY CHERNOV	{"email": "vasiliy_chernov.101974@postgrespro.ru", "phone": "+70346225534"}
0005433399296	3D855E	1896 329694	EVGENIY NOVIKOV	{"email": "novikovevgeniy021972@postgrespro.ru", "phone": "+70579745687"}
0005433399297	FDB273	7882 389893	ANNA MAKSIMOVA	{"email": "maksimova-anna.1968@postgrespro.ru", "phone": "+70153910577"}
0005433399298	FDB273	4665 381862	DENIS BELOV	{"phone": "+70595857212"}
0005433399299	3608EA	5273 917929	ALEKSANDR IVANOV	{"email": "ivanov_a.30051970@postgrespro.ru", "phone": "+70482228018"}
0005433399300	024EC6	3277 378947	OKSANA VOLKOVA	{"email": "oksana-volkova1976@postgrespro.ru", "phone": "+70704497438"}
0005433399301	024EC6	3076 900079	NINA FADEEVA	{"email": "fadeeva_nina.041977@postgrespro.ru", "phone": "+70379374876"}
0005433399302	2A9442	3811 364138	NADEZHDA POPOVA	{"phone": "+70031507066"}
0005433399303	2A9442	6007 233377	VALERIY OSIPOV	{"email": "osipov_v-121977@postgrespro.ru", "phone": "+70861506192"}
0005433399304	2A9442	8221 302476	TATYANA KUDRYASHOVA	{"phone": "+70032042216"}
0005433399305	38C9ED	8547 835256	KIRILL MOROZOV	{"email": "morozovk-02071975@postgrespro.ru", "phone": "+70332171269"}
0005433399306	38C9ED	2206 365802	ALEKSANDR ALEKSEEV	{"phone": "+70042913447"}
0005433399308	1A7579	7724 607723	MARIYA EFIMOVA	{"email": "mariyaefimova1978@postgrespro.ru", "phone": "+70878649829"}
0005433399309	1A7579	0484 846327	GALIYA MIKHAYLOVA	{"email": "mikhaylovag_071974@postgrespro.ru", "phone": "+70383912242"}
0005433399310	238AEB	0213 956608	OLGA GRISHINA	{"email": "grishinaolga.1966@postgrespro.ru", "phone": "+70187246669"}
0005433399311	28B9D9	2611 863583	ALEKSANDRA VASILEVA	{"email": "vasileva-aleksandra-091971@postgrespro.ru", "phone": "+70816511117"}
0005433399312	E9767E	4819 151907	IVAN SEMENOV	{"email": "ivansemenov.1973@postgrespro.ru", "phone": "+70136096799"}
0005433399313	E9767E	1415 887495	PAVEL SOKOLOV	{"email": "pavel.sokolov.081973@postgrespro.ru", "phone": "+70621056340"}
0005433399314	5A4DAD	4451 194810	ALEKSANDR ZAKHAROV	{"phone": "+70711157961"}
0005433399315	5A4DAD	4710 750443	MARINA ZAKHAROVA	{"email": "marina-zakharova_091973@postgrespro.ru", "phone": "+70648266963"}
0005433399316	3D4F74	7981 420525	MARGARITA FADEEVA	{"phone": "+70309443866"}
0005433399317	CCAF2C	4468 788781	DMITRIY ZHUKOV	{"phone": "+70949909593"}
0005433399318	297332	6956 414375	OKSANA NOVIKOVA	{"email": "novikova.o_011973@postgrespro.ru", "phone": "+70108491601"}
0005433399319	297332	7038 002984	TATYANA BORISOVA	{"email": "borisova.t101965@postgrespro.ru", "phone": "+70143919423"}
0005433399320	AB7744	1350 295646	GALINA MATVEEVA	{"email": "matveeva-galina09041959@postgrespro.ru", "phone": "+70561740367"}
0005433399321	31CAFA	8636 236017	TATYANA ZAKHAROVA	{"email": "zakharova_t.031987@postgrespro.ru", "phone": "+70978907538"}
0005433399322	6F7D45	5653 178657	LYUDMILA ZHUKOVA	{"email": "zhukova.l091973@postgrespro.ru", "phone": "+70346810876"}
0005433399323	6F7D45	4682 558322	BORIS ROMANOV	{"phone": "+70690723501"}
0005433399324	EC04B2	3457 800362	SVETLANA FEDOROVA	{"phone": "+70629531940"}
0005433399325	B2034C	9378 388331	KSENIYA AFANASEVA	{"email": "k_afanaseva-061960@postgrespro.ru", "phone": "+70900802249"}
0005433399326	B2034C	2642 791311	NATALYA DENISOVA	{"phone": "+70158835312"}
0005433399327	884897	9330 785195	SVETLANA SMIRNOVA	{"email": "smirnova.s_18111975@postgrespro.ru", "phone": "+70458969683"}
0005433399328	380593	2419 177634	ALSU MAKSIMOVA	{"phone": "+70631130473"}
0005433399329	380593	3760 947247	GALINA SERGEEVA	{"email": "gsergeeva17061967@postgrespro.ru", "phone": "+70199466491"}
0005433399330	B75E78	2781 409067	DANIL ISAEV	{"email": "isaev.d1979@postgrespro.ru", "phone": "+70166813333"}
0005433399331	087533	6249 712862	MARINA MOROZOVA	{"email": "marina.morozova_30111984@postgrespro.ru", "phone": "+70526094451"}
0005433399332	D39C81	8042 807215	NINA FILATOVA	{"phone": "+70526402852"}
0005433399333	D39C81	7519 871352	ALEKSANDR KUZNECOV	{"phone": "+70759243848"}
0005433399334	28D8A0	7329 512753	EGOR ZHUKOV	{"phone": "+70556401559"}
0005433399335	28D8A0	6688 419230	VENIAMIN MAKAROV	{"phone": "+70368376479"}
0005433399336	B7FB3D	6287 650087	TATYANA SMIRNOVA	{"phone": "+70387271943"}
0005433399337	C93C4B	8306 846255	TATYANA PAVLOVA	{"email": "pavlovatatyana_01031975@postgrespro.ru", "phone": "+70588243031"}
0005433399338	2529C3	6895 125481	MARGARITA KUZMINA	{"email": "kuzminam.021975@postgrespro.ru", "phone": "+70365716699"}
0005433399339	2529C3	7959 598429	NIKITA IVANOV	{"email": "ivanovnikita.1986@postgrespro.ru", "phone": "+70767982523"}
0005433399340	EA1A26	5833 883742	ANNA KOMAROVA	{"phone": "+70198991025"}
0005433399341	75A826	9270 461337	PETR KUZNECOV	{"phone": "+70552867942"}
0005433399342	75A826	5891 158346	SVETLANA EGOROVA	{"phone": "+70932255392"}
0005433399343	AB43E4	7545 024590	OLGA PAVLOVA	{"email": "olga.pavlova.14051974@postgrespro.ru", "phone": "+70440496555"}
0005433399344	AB43E4	6954 631563	VIKTOR KUDRYASHOV	{"phone": "+70807998629"}
0005433399345	8A9193	4516 076082	MIKHAIL MIKHAYLOV	{"email": "mikhaylov_mikhail061958@postgrespro.ru", "phone": "+70228751530"}
0005433399346	FF863B	9455 856152	GALINA ZAKHAROVA	{"email": "zakharova_g_1972@postgrespro.ru", "phone": "+70286454090"}
0005433399347	BE838F	8824 199903	MARGARITA SEMENOVA	{"email": "margarita-semenova.111969@postgrespro.ru", "phone": "+70885603982"}
0005433399348	BE838F	6280 882249	RUFIYA VOLKOVA	{"email": "r_volkova.061975@postgrespro.ru", "phone": "+70739541612"}
0005433399349	BE838F	7614 797859	OLESYA BARANOVA	{"email": "olesyabaranova.13081968@postgrespro.ru", "phone": "+70919967943"}
0005433399350	21B37F	4476 724290	ALEKSANDRA MIRONOVA	{"phone": "+70090038810"}
0005433399351	21B37F	6847 352546	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov_1969@postgrespro.ru", "phone": "+70249951293"}
0005433399352	CD0649	5012 768495	IVAN GRIGOREV	{"phone": "+70277348876"}
0005433399353	EC4161	4544 160305	ANATOLIY SERGEEV	{"email": "sergeev_a11021958@postgrespro.ru", "phone": "+70561113008"}
0005433399354	993101	0045 638767	GULNARA KUZNECOVA	{"email": "g.kuznecova05051973@postgrespro.ru", "phone": "+70846178925"}
0005433399355	26EF77	8780 096076	YURIY VOLKOV	{"email": "volkovyuriy_03041966@postgrespro.ru", "phone": "+70749170413"}
0005433399356	95DF99	3194 466069	EVGENIY SMIRNOV	{"phone": "+70435572883"}
0005433399357	95DF99	9736 392093	ALEKSANDR ZAKHAROV	{"phone": "+70768139570"}
0005433399358	8E64ED	0328 484760	LYUDMILA KARPOVA	{"phone": "+70562927033"}
0005433399359	9AD92D	1825 579040	DMITRIY FEDOROV	{"email": "dmitriy_fedorov_05011972@postgrespro.ru", "phone": "+70250689089"}
0005433399360	64CD3C	7830 011997	ANDREY STEPANOV	{"phone": "+70812533415"}
0005433399361	E16E9E	4881 754664	OLGA PAVLOVA	{"email": "pavlovaolga.1983@postgrespro.ru", "phone": "+70124411509"}
0005433399362	E16E9E	0064 311926	OLGA MAKSIMOVA	{"phone": "+70663617037"}
0005433399363	E16E9E	1529 821258	INNA ZOTOVA	{"email": "inna.zotova_28011976@postgrespro.ru", "phone": "+70761983168"}
0005433399364	368D4C	3941 448218	LYUDMILA CHERNOVA	{"email": "l_chernova.12011976@postgrespro.ru", "phone": "+70009567029"}
0005433399365	971AF9	7136 056155	KIRILL PETROV	{"email": "kirillpetrov09061963@postgrespro.ru", "phone": "+70992863700"}
0005433399366	BED8BC	5207 211131	TATYANA MELNIKOVA	{"email": "tatyanamelnikova_19091970@postgrespro.ru", "phone": "+70810002074"}
0005433399367	DFF19C	5164 636999	ANASTASIYA ZHURAVLEVA	{"phone": "+70924103415"}
0005433399368	986FFE	6831 027518	MARIYA STEPANOVA	{"email": "stepanova.m101969@postgrespro.ru", "phone": "+70784563781"}
0005433399369	540162	0753 956660	NATALYA IVANOVA	{"email": "ivanova.n-22071977@postgrespro.ru", "phone": "+70924223223"}
0005433399370	F52BB2	3952 604156	VLADISLAV NOVIKOV	{"phone": "+70154197160"}
0005433399371	56261C	7327 149559	NINA MATVEEVA	{"phone": "+70073990777"}
0005433399372	56261C	9115 571206	NATALYA ISAEVA	{"phone": "+70755313899"}
0005433399373	AFB981	6527 739118	SERGEY GRIGOREV	{"phone": "+70340022174"}
0005433399374	3DE4BE	0625 155391	TATYANA STEPANOVA	{"email": "t_stepanova011964@postgrespro.ru", "phone": "+70420103183"}
0005433399375	3DE4BE	0386 137001	NATALYA IVANOVA	{"email": "ivanova.n-19041977@postgrespro.ru", "phone": "+70349566111"}
0005433399376	AB55CB	7111 135902	ANNA BORISOVA	{"email": "borisovaa.1973@postgrespro.ru", "phone": "+70079511670"}
0005433399377	EF7DFB	8277 630519	ALEKSANDR POPOV	{"phone": "+70417556501"}
0005433399378	A76F33	2497 758381	VYACHESLAV ZHUKOV	{"email": "zhukovvyacheslav_091973@postgrespro.ru", "phone": "+70650045742"}
0005433399379	E47BD8	8522 135958	ELENA DANILOVA	{"email": "danilova.e.1973@postgrespro.ru", "phone": "+70200581614"}
0005433399380	E47BD8	0423 349607	MARINA MEDVEDEVA	{"email": "m-medvedeva.111962@postgrespro.ru", "phone": "+70475811105"}
0005433399381	AFFC05	3533 432788	OKSANA DANILOVA	{"phone": "+70420970545"}
0005433399382	B32D41	6256 039776	GALINA ORLOVA	{"phone": "+70750816327"}
0005433399383	033716	3122 066843	ANDREY VOLKOV	{"email": "andreyvolkov-05011969@postgrespro.ru", "phone": "+70619889831"}
0005433399384	26AF2D	2564 165127	YURIY STEPANOV	{"email": "stepanovy-121963@postgrespro.ru", "phone": "+70876154125"}
0005433399385	26AF2D	4821 591795	NIKITA ANTONOV	{"email": "nikita.antonov-1978@postgrespro.ru", "phone": "+70575200642"}
0005433399386	FD8A71	1079 564526	RINAT KUZNECOV	{"email": "r-kuznecov-091973@postgrespro.ru", "phone": "+70193137048"}
0005433399387	FE42BD	6561 039950	VLADIMIR SCHERBAKOV	{"phone": "+70192416398"}
0005433399388	52E740	7743 612100	ALEKSEY MOROZOV	{"email": "morozov-a.031966@postgrespro.ru", "phone": "+70031243619"}
0005433399389	042C82	1063 490610	SVETLANA NOVIKOVA	{"email": "s_novikova.1974@postgrespro.ru", "phone": "+70810367792"}
0005433399390	E07F04	1685 627716	POLINA LOGINOVA	{"phone": "+70851816972"}
0005433399391	E07F04	8940 314582	SERGEY ISAEV	{"phone": "+70969926713"}
0005433399392	EECC99	3064 556223	DMITRIY FEDOROV	{"email": "dmitriyfedorov04061972@postgrespro.ru", "phone": "+70517916091"}
0005433399393	5D8E3C	0108 477824	ZINAIDA STEPANOVA	{"phone": "+70875142904"}
0005433399394	AFDB91	8902 759658	ANGELINA ANDREEVA	{"phone": "+70035895437"}
0005433399395	2009B1	5897 571893	NATALYA EGOROVA	{"email": "egorovan_1968@postgrespro.ru", "phone": "+70628496081"}
0005433399396	8DCEF9	5947 032921	TATYANA EFREMOVA	{"email": "t-efremova1975@postgrespro.ru", "phone": "+70149959117"}
0005433399397	8DCEF9	5670 315027	NINA IVANOVA	{"phone": "+70249503830"}
0005433399398	CFFD01	7329 299904	EVGENIY EGOROV	{"phone": "+70911501458"}
0005433399399	CFFD01	0179 893337	MARINA OSIPOVA	{"email": "osipova.m-051975@postgrespro.ru", "phone": "+70851380290"}
0005433399400	CFFD01	1954 681499	TATYANA LUKYANOVA	{"email": "tatyana-lukyanova-24101972@postgrespro.ru", "phone": "+70692383395"}
0005433399401	F7D728	8987 885519	SERGEY KUDRYASHOV	{"phone": "+70948362362"}
0005433399402	D980CE	5708 766023	SERGEY FROLOV	{"email": "frolovs.101975@postgrespro.ru", "phone": "+70620470041"}
0005433399403	D980CE	7118 962578	ALEKSANDR SERGEEV	{"email": "asergeev.08091968@postgrespro.ru", "phone": "+70162686028"}
0005433399404	7BE949	2008 248885	ELENA TIMOFEEVA	{"phone": "+70675569644"}
0005433399405	10F1A0	1750 935194	YULIYA MIKHAYLOVA	{"phone": "+70243960439"}
0005433399406	0B9E1A	9609 600480	MIKHAIL SCHERBAKOV	{"email": "m_scherbakov.1977@postgrespro.ru", "phone": "+70671703145"}
0005433399407	786EF7	7811 833571	ANASTASIYA FROLOVA	{"phone": "+70543616105"}
0005433399408	786EF7	1085 040391	MARIYA KOMAROVA	{"email": "komarova-mariya17091974@postgrespro.ru", "phone": "+70443475856"}
0005433399409	5E72E7	1473 949738	OLGA STEPANOVA	{"email": "o-stepanova_09111970@postgrespro.ru", "phone": "+70720351251"}
0005433399410	5E72E7	0368 531712	IRINA ROMANOVA	{"email": "romanovai.18091969@postgrespro.ru", "phone": "+70421233016"}
0005433399411	C3C678	4201 523323	DENIS TARASOV	{"email": "d.tarasov.1959@postgrespro.ru", "phone": "+70379778276"}
0005433399412	7C75FA	1238 191331	SERGEY MIKHAYLOV	{"phone": "+70028543110"}
0005433399413	7C75FA	5266 451008	NIKOLAY ABRAMOV	{"email": "abramov_nikolay_1983@postgrespro.ru", "phone": "+70063510909"}
0005433399414	7C75FA	7862 563897	SVETLANA ALEKSEEVA	{"email": "salekseeva.101981@postgrespro.ru", "phone": "+70658178521"}
0005433399415	3D61AF	3239 654848	NIKOLAY IVANOV	{"email": "nikolay.ivanov_10101960@postgrespro.ru", "phone": "+70127477281"}
0005433399416	C3A265	2319 056649	MIKHAIL VASILEV	{"email": "mikhail_vasilev-26041975@postgrespro.ru", "phone": "+70460883608"}
0005433399417	5486B1	4068 637549	ROMAN KAZAKOV	{"phone": "+70473876863"}
0005433399418	C2DD17	7461 413453	IRINA NIKITINA	{"email": "nikitinai-11091981@postgrespro.ru", "phone": "+70512889708"}
0005433399419	8A6B81	6569 293241	ANTON FEDOROV	{"email": "fedorov.a_071975@postgrespro.ru", "phone": "+70466090838"}
0005433399420	85C778	8395 812529	IGOR YAKOVLEV	{"email": "i.yakovlev.121977@postgrespro.ru", "phone": "+70070630950"}
0005433399421	72131F	1912 626203	SVETLANA PETROVA	{"email": "svetlana-petrova31011971@postgrespro.ru", "phone": "+70823425438"}
0005433399422	269F8F	3896 634713	SVETLANA AFANASEVA	{"phone": "+70797547075"}
0005433399423	2D5302	4342 480406	LYUDMILA EFREMOVA	{"phone": "+70266074197"}
0005433399424	60E9CF	7467 765635	VIKTOR KUZNECOV	{"email": "v-kuznecov.07071974@postgrespro.ru", "phone": "+70994860761"}
0005433399425	60E9CF	3536 884379	MARIYA TROFIMOVA	{"phone": "+70676357890"}
0005433399426	289AA2	9346 718701	VLADIMIR FROLOV	{"email": "frolov-v1974@postgrespro.ru", "phone": "+70081262950"}
0005433399427	D653D3	7551 602756	OLGA GUSEVA	{"phone": "+70490545639"}
0005433399428	F662E9	3071 246494	MARGARITA GRISHINA	{"phone": "+70454695486"}
0005433399429	F662E9	7578 175459	OLGA YUDINA	{"phone": "+70037373667"}
0005433399430	125E4C	0842 315813	YULIYA KALININA	{"phone": "+70568721259"}
0005433399431	125E4C	6510 220460	ALEKSANDR FOMIN	{"phone": "+70914524107"}
0005433399432	870438	7589 834700	VERA KONDRATEVA	{"phone": "+70073442967"}
0005433399433	870438	3162 802731	PAVEL NAZAROV	{"email": "p_nazarov-1968@postgrespro.ru", "phone": "+70718447259"}
0005433399434	DA9999	8305 700819	MARAT SMIRNOV	{"email": "smirnov_m.091968@postgrespro.ru", "phone": "+70679797180"}
0005433399435	DA9999	8524 440546	SERGEY NAUMOV	{"phone": "+70125555622"}
0005433399436	26447B	7242 908128	ANATOLIY BORISOV	{"email": "borisov_a_18061970@postgrespro.ru", "phone": "+70233776511"}
0005433399437	BB7EA9	6025 933311	KRISTINA ANDREEVA	{"email": "k-andreeva.26051980@postgrespro.ru", "phone": "+70928208859"}
0005433399438	5BCF33	5315 231519	ALEKSEY FEDOROV	{"email": "a_fedorov_1967@postgrespro.ru", "phone": "+70184275516"}
0005433399439	5BCF33	9220 417530	VIKTOR IVANOV	{"email": "ivanov-v.23121964@postgrespro.ru", "phone": "+70471047836"}
0005433399440	F45F7B	6814 967867	ALEKSANDR GAVRILOV	{"phone": "+70431644071"}
0005433399442	EA0915	2335 318812	ARINA KRASNOVA	{"phone": "+70537811281"}
0005433399443	EA0915	6449 773462	YURIY CHERNOV	{"phone": "+70099033272"}
0005433399444	265E1C	8484 360722	NIKITA KRASNOV	{"email": "krasnov.nikita-041972@postgrespro.ru", "phone": "+70183711162"}
0005433399445	F2FA41	6464 474069	IRINA NESTEROVA	{"phone": "+70995026370"}
0005433399446	056EFE	5790 473735	ANASTASIYA GRISHINA	{"email": "grishina.a_1973@postgrespro.ru", "phone": "+70955302758"}
0005433399447	37F78C	4136 333413	VITALIY PETROV	{"phone": "+70836048440"}
0005433399448	4D30B4	9200 734766	ARTEM EGOROV	{"email": "egorov_artem1977@postgrespro.ru", "phone": "+70367891642"}
0005433399449	84A1B8	4497 767044	OLGA DANILOVA	{"phone": "+70875095810"}
0005433399450	84A1B8	0131 808535	IGOR KOZLOV	{"email": "kozlovigor1970@postgrespro.ru", "phone": "+70000958289"}
0005433399451	420BB3	8214 295451	ALISA ZHURAVLEVA	{"phone": "+70018751858"}
0005433399452	E0592A	8714 895472	ANDREY NOVIKOV	{"email": "a_novikov_121967@postgrespro.ru", "phone": "+70122615235"}
0005433399453	33B87C	5295 391478	LYUDMILA BORISOVA	{"email": "borisova_lyudmila111963@postgrespro.ru", "phone": "+70094382402"}
0005433399454	C02EB4	4520 432423	ARTEM CHERNOV	{"phone": "+70525074687"}
0005433399455	C02EB4	3427 088267	ANNA VASILEVA	{"phone": "+70000222183"}
0005433399456	48A113	1412 581818	MARIYA CHERNOVA	{"email": "chernovamariya-04111963@postgrespro.ru", "phone": "+70181531336"}
0005433399457	0490E8	3757 280884	NATALYA ZHURAVLEVA	{"phone": "+70886505001"}
0005433399458	367492	5594 790241	MARIYA KONOVALOVA	{"email": "konovalova_mariya_061969@postgrespro.ru", "phone": "+70766360158"}
0005433399459	3479DE	0005 218216	ANASTASIYA BARANOVA	{"phone": "+70917370499"}
0005433399460	497603	6755 496965	MARIYA GUSEVA	{"phone": "+70318511458"}
0005433399461	0A7BF7	0300 658329	GALINA RYABOVA	{"phone": "+70287453121"}
0005433399462	5D27C6	4040 147146	ALEKSEY BORISOV	{"phone": "+70146181541"}
0005433399463	288D47	8786 276269	OLEG TARASOV	{"phone": "+70830085314"}
0005433399464	FD93FF	8141 542339	IVAN AFANASEV	{"phone": "+70294364527"}
0005433399465	3F6C35	5233 056426	KIRILL FEDOROV	{"phone": "+70679731675"}
0005433399466	13C552	1615 318100	TATYANA MAKAROVA	{"email": "tatyana-makarova-1973@postgrespro.ru", "phone": "+70258496900"}
0005433400929	B30ADA	5442 173932	OLEG EGOROV	{"email": "o_egorov.1964@postgrespro.ru", "phone": "+70165643914"}
0005433400930	FE7665	7847 896980	ARTUR GAVRILOV	{"phone": "+70945795624"}
0005433400931	2135F7	2180 949565	RUSTEM PETROV	{"email": "r_petrov_1970@postgrespro.ru", "phone": "+70159352565"}
0005433400932	2135F7	2090 667440	NATALYA POLYAKOVA	{"email": "polyakova_natalya_121977@postgrespro.ru", "phone": "+70838305297"}
0005433400933	2C5C07	4693 670902	VIKTOR ALEKSEEV	{"email": "alekseev.v_1984@postgrespro.ru", "phone": "+70456637586"}
0005433400934	6741EA	1414 680505	VALENTINA MATVEEVA	{"phone": "+70475874577"}
0005433400935	F0889A	3925 254506	ELENA KUZNECOVA	{"email": "kuznecova_elena_23021979@postgrespro.ru", "phone": "+70594423579"}
0005433400936	BEBBA2	3019 252103	YULIYA GRISHINA	{"phone": "+70579712999"}
0005433400937	D8BF15	6863 402299	OLGA VOLKOVA	{"email": "volkovaolga_31051972@postgrespro.ru", "phone": "+70469417975"}
0005433400938	AC070A	7079 223255	GALINA PAVLOVA	{"email": "pavlova.galina021974@postgrespro.ru", "phone": "+70122580114"}
0005433400939	AC070A	3204 904069	ELENA KONOVALOVA	{"phone": "+70213929076"}
0005433400940	8E21CB	5977 823620	NIKOLAY KARPOV	{"email": "nikolay.karpov1977@postgrespro.ru", "phone": "+70442949120"}
0005433400941	59F012	7166 451404	MIKHAIL GERASIMOV	{"email": "mikhail_gerasimov-071971@postgrespro.ru", "phone": "+70012771305"}
0005433400942	59F012	2036 276961	ALEKSANDR POPOV	{"email": "aleksandrpopov-1969@postgrespro.ru", "phone": "+70674340990"}
0005433400943	59F012	8507 849174	OLEG ROMANOV	{"email": "romanov.oleg_041976@postgrespro.ru", "phone": "+70133510099"}
0005433400944	EB4B19	6067 731590	ANNA ABRAMOVA	{"email": "anna-abramova-1977@postgrespro.ru", "phone": "+70477414587"}
0005433400945	EB4B19	1484 803079	ALEKSANDR MAKSIMOV	{"phone": "+70007413224"}
0005433400946	14D274	6199 299776	ANNA EFIMOVA	{"email": "anna.efimova_18051970@postgrespro.ru", "phone": "+70965519692"}
0005433400947	CF8DEB	6199 949545	RAILYA FROLOVA	{"phone": "+70656535349"}
0005433400948	AF8044	6440 051153	NATALIYA MARTYNOVA	{"phone": "+70736188775"}
0005433400949	AF8044	2274 466314	OLEG KULIKOV	{"phone": "+70707075650"}
0005433400950	56C994	8171 700647	TATYANA KOLESNIKOVA	{"phone": "+70086078121"}
0005433400951	6E5229	8416 490185	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev-011966@postgrespro.ru", "phone": "+70846605342"}
0005433401008	838446	5427 336233	TATYANA VOLKOVA	{"phone": "+70391371451"}
0005433400952	D1E3FC	7125 154339	NIKITA NIKOLAEV	{"email": "nikolaev-n-011979@postgrespro.ru", "phone": "+70995602902"}
0005433400953	D1E3FC	8693 743789	GALINA KONOVALOVA	{"email": "konovalova_g-1970@postgrespro.ru", "phone": "+70034678865"}
0005433400954	2BE546	6876 278850	PAVEL ZHURAVLEV	{"email": "p-zhuravlev021967@postgrespro.ru", "phone": "+70562825148"}
0005433400955	04F975	1679 258337	ANTONINA BORISOVA	{"email": "borisova.antonina26081957@postgrespro.ru", "phone": "+70382549531"}
0005433400956	04F975	6620 176925	ANZHELA VOROBEVA	{"email": "a_vorobeva_111975@postgrespro.ru", "phone": "+70747256984"}
0005433400957	F81CE6	2749 739331	ELENA STEPANOVA	{"email": "stepanova_elena.061971@postgrespro.ru", "phone": "+70399131354"}
0005433400958	F81CE6	5201 460429	ANDREY TIKHONOV	{"phone": "+70402560708"}
0005433400959	D20B1E	4818 140234	LYUDMILA IVANOVA	{"phone": "+70002014407"}
0005433400960	FBE502	5486 648847	ANASTASIYA KULIKOVA	{"phone": "+70008114052"}
0005433400961	49A4CF	1204 380793	SERGEY MARTYNOV	{"phone": "+70193896360"}
0005433400962	49A4CF	9943 324046	SERGEY VASILEV	{"email": "s_vasilev.121970@postgrespro.ru", "phone": "+70789797750"}
0005433400963	82D8DC	0162 318835	ALEKSANDRA YAKOVLEVA	{"phone": "+70588760891"}
0005433400964	2601E7	6782 105648	VLADIMIR PAVLOV	{"phone": "+70254313841"}
0005433400965	2601E7	3384 748232	NIKOLAY SIDOROV	{"phone": "+70140929478"}
0005433400966	E4B82C	9047 214853	VITALIY MIKHAYLOV	{"phone": "+70462454262"}
0005433400967	9B82BC	5673 921165	LIDIYA KUDRYASHOVA	{"email": "lidiya.kudryashova-11031976@postgrespro.ru", "phone": "+70245744083"}
0005433400968	9B82BC	2248 259785	GALINA DANILOVA	{"email": "gdanilova.31101973@postgrespro.ru", "phone": "+70663441254"}
0005433400969	B44A5B	0241 997373	ANNA ILINA	{"email": "ilina.anna_1978@postgrespro.ru", "phone": "+70427669637"}
0005433400970	FFAD6C	7623 037316	SERGEY ANTONOV	{"email": "sergey_antonov-041979@postgrespro.ru", "phone": "+70815217286"}
0005433400971	FFAD6C	5409 172421	VLADIMIR KOZLOV	{"email": "vladimir-kozlov.09091967@postgrespro.ru", "phone": "+70141727420"}
0005433400972	FFAD6C	3837 323430	IRINA PAVLOVA	{"email": "ipavlova011972@postgrespro.ru", "phone": "+70564733708"}
0005433400973	D7EDB8	0372 378173	GALINA VASILEVA	{"phone": "+70837692053"}
0005433400974	F7E3A0	8937 975248	KSENIYA ZHURAVLEVA	{"phone": "+70113220355"}
0005433400975	F7E3A0	1970 679097	ELENA NAZAROVA	{"email": "elena_nazarova_20101965@postgrespro.ru", "phone": "+70862366047"}
0005433400976	0BFB91	5899 668653	YURIY YAKOVLEV	{"email": "yyakovlev_17061971@postgrespro.ru", "phone": "+70563089979"}
0005433400977	D5C85F	1981 837385	ELENA KUZNECOVA	{"phone": "+70647655148"}
0005433400978	458BC0	5599 724612	KRISTINA FOMINA	{"phone": "+70766861922"}
0005433400979	2B82CF	1169 497450	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev.011971@postgrespro.ru", "phone": "+70747842491"}
0005433400980	D3F17B	8546 586883	MARIYA KUZMINA	{"phone": "+70247746008"}
0005433400981	D3F17B	7120 513989	SVETLANA KUDRYASHOVA	{"phone": "+70552037176"}
0005433400982	8FD504	9599 952814	LYUBOV NIKOLAEVA	{"email": "nikolaeva_lyubov_13091983@postgrespro.ru", "phone": "+70596191565"}
0005433400983	1A7F6C	6850 987371	SVETLANA KOVALEVA	{"phone": "+70788260120"}
0005433400984	843044	5668 310162	MIKHAIL ZHURAVLEV	{"email": "zhuravlevmikhail1979@postgrespro.ru", "phone": "+70882050485"}
0005433400985	7C34EE	0769 116673	SERGEY KISELEV	{"phone": "+70054024777"}
0005433400986	7C34EE	7468 298871	LYUDMILA NESTEROVA	{"phone": "+70987489746"}
0005433400987	034581	5825 266460	YURIY SCHERBAKOV	{"email": "scherbakovy021979@postgrespro.ru", "phone": "+70403659215"}
0005433400988	034581	5909 249750	VLADIMIR ALEKSEEV	{"phone": "+70148449770"}
0005433400989	6D7E69	7387 965999	ANNA BELOVA	{"phone": "+70456486024"}
0005433400990	93820F	3101 724942	YULIYA MIKHAYLOVA	{"email": "mikhaylovay.111982@postgrespro.ru", "phone": "+70060114847"}
0005433400991	93B05E	8297 922610	MARIYA MATVEEVA	{"email": "m-matveeva_1963@postgrespro.ru", "phone": "+70387139540"}
0005433400992	D5FE1F	8840 608059	PETR KOROLEV	{"phone": "+70844631393"}
0005433400993	D5FE1F	5107 336081	NATALYA IVANOVA	{"email": "n_ivanova-1973@postgrespro.ru", "phone": "+70180012003"}
0005433400994	80571F	8227 597330	MARIYA FROLOVA	{"email": "frolova-mariya.1969@postgrespro.ru", "phone": "+70761113771"}
0005433400995	80AB0F	0812 730171	GULNARA MOROZOVA	{"phone": "+70155524925"}
0005433400996	D8DF1F	0832 890270	NADEZHDA DAVYDOVA	{"email": "nadezhda_davydova_1972@postgrespro.ru", "phone": "+70157519478"}
0005433400997	2354D6	0062 050016	DMITRIY NAZAROV	{"phone": "+70896792263"}
0005433400998	B617DB	9544 675992	OLGA POPOVA	{"email": "popova_o-17051966@postgrespro.ru", "phone": "+70646353895"}
0005433400999	B617DB	3619 692846	NINA NESTEROVA	{"email": "nesterova_n.1974@postgrespro.ru", "phone": "+70130151437"}
0005433401000	F39DE2	0382 731665	VYACHESLAV OSIPOV	{"phone": "+70779447339"}
0005433401001	F39DE2	4077 616562	TATYANA ROMANOVA	{"email": "romanova-t-10081981@postgrespro.ru", "phone": "+70173023274"}
0005433401002	93E5DA	1459 518053	SVETLANA CHERNOVA	{"phone": "+70677241177"}
0005433401003	D54C00	1968 040572	ANDREY FEDOTOV	{"phone": "+70587072483"}
0005433401004	D54C00	5850 502974	VYACHESLAV ZAKHAROV	{"phone": "+70728790834"}
0005433401005	6AA6BF	2514 348486	PETR ANDREEV	{"phone": "+70323032203"}
0005433401006	D49358	9398 807712	LYUDMILA PETROVA	{"email": "petrova-l17101974@postgrespro.ru", "phone": "+70147704209"}
0005433401007	D49358	6671 506951	IRINA ALEKSEEVA	{"email": "i.alekseeva_19011961@postgrespro.ru", "phone": "+70902392938"}
0005433401009	10B3F2	6480 680421	VIKTORIYA IVANOVA	{"phone": "+70072137505"}
0005433401010	96FE83	5354 598759	MIKHAIL IVANOV	{"phone": "+70406423579"}
0005433401011	96FE83	1151 367966	NIKOLAY POPOV	{"email": "popovnikolay101965@postgrespro.ru", "phone": "+70876082497"}
0005433401012	EC98A1	0806 708507	SERGEY EGOROV	{"email": "s.egorov.27091965@postgrespro.ru", "phone": "+70964920473"}
0005433401013	4F659F	5086 722091	ALEKSANDR SHEVCHENKO	{"phone": "+70391072951"}
0005433401014	3ADFE0	8805 346414	VYACHESLAV NAUMOV	{"email": "naumov-vyacheslav_111977@postgrespro.ru", "phone": "+70549136885"}
0005433401015	33C425	9176 006102	ANASTASIYA MIKHAYLOVA	{"phone": "+70214769220"}
0005433401016	3D449D	3859 595179	ANDREY ZHURAVLEV	{"phone": "+70959352902"}
0005433401017	94249B	9182 606526	TAMARA MIRONOVA	{"phone": "+70026510294"}
0005433401018	94249B	1731 457532	VIKTOR KUZMIN	{"email": "viktor.kuzmin-1980@postgrespro.ru", "phone": "+70537172970"}
0005433401019	78C24E	9135 403947	GALINA ANDREEVA	{"phone": "+70250366375"}
0005433401020	DC7662	3321 831315	IGOR TIMOFEEV	{"phone": "+70947326371"}
0005433401021	F8A6AA	0623 427354	NIKOLAY VASILEV	{"phone": "+70348008479"}
0005433401022	F8A6AA	3231 531369	ALEKSEY POPOV	{"phone": "+70100440361"}
0005433401023	EA6AED	5624 127810	VLADIMIR FEDOROV	{"phone": "+70921532080"}
0005433401024	EA6AED	1930 002406	NATALYA ISAEVA	{"email": "isaeva.natalya_071990@postgrespro.ru", "phone": "+70895118939"}
0005433401025	1DBA60	7157 051420	VYACHESLAV MEDVEDEV	{"phone": "+70924519646"}
0005433401026	02F945	3270 713702	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov081978@postgrespro.ru", "phone": "+70510796691"}
0005433401027	D62E79	0148 245669	EKATERINA OSIPOVA	{"phone": "+70240133332"}
0005433401028	9E693B	2437 958463	SERGEY AFANASEV	{"email": "s.afanasev14091977@postgrespro.ru", "phone": "+70198357689"}
0005433401029	9E693B	3353 562909	KONSTANTIN FEDOTOV	{"email": "fedotov.k091973@postgrespro.ru", "phone": "+70410720538"}
0005433401030	549143	7114 690598	IRINA VASILEVA	{"email": "irina_vasileva-1980@postgrespro.ru", "phone": "+70448560759"}
0005433401031	74A12A	4213 208528	VASILIY TIKHONOV	{"phone": "+70876872153"}
0005433401032	9D4129	7912 980090	OLGA SAVELEVA	{"email": "olga.saveleva-26041954@postgrespro.ru", "phone": "+70127085282"}
0005433401033	9D4129	8142 516246	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy051971@postgrespro.ru", "phone": "+70829536487"}
0005433401034	690E25	4227 081471	ANATOLIY VOLKOV	{"email": "a.volkov-1971@postgrespro.ru", "phone": "+70295267275"}
0005433401035	690E25	7535 884299	TATYANA SEMENOVA	{"email": "tatyanasemenova1969@postgrespro.ru", "phone": "+70077684500"}
0005433401036	872297	3596 965542	SERGEY ZAKHAROV	{"email": "zakharov_sergey21111969@postgrespro.ru", "phone": "+70541149317"}
0005433401037	12EF6E	2592 355791	ALEKSANDR SOKOLOV	{"email": "asokolov_27081978@postgrespro.ru", "phone": "+70609950599"}
0005433401038	880F21	4133 600303	LYUDMILA ORLOVA	{"phone": "+70241052324"}
0005433401039	880F21	1859 288371	VALERIY FROLOV	{"email": "v.frolov1967@postgrespro.ru", "phone": "+70481656039"}
0005433401040	46CFAB	5485 116171	VLADIMIR ALEKSANDROV	{"phone": "+70704853170"}
0005433401041	46CFAB	2394 058506	VITALIY MAKAROV	{"phone": "+70421027110"}
0005433401042	33D65D	8570 014131	VIKTOR KUZNECOV	{"email": "kuznecov-viktor1975@postgrespro.ru", "phone": "+70765814437"}
0005433401043	C48571	0675 883414	SERGEY PAVLOV	{"phone": "+70929840444"}
0005433401044	651BCD	0779 531438	ELENA ZAYCEVA	{"phone": "+70617761593"}
0005433401045	69A915	1371 756027	NIKITA VOLKOV	{"phone": "+70305038849"}
0005433401046	6484F4	1350 310144	ELENA SCHERBAKOVA	{"email": "escherbakova1977@postgrespro.ru", "phone": "+70109720687"}
0005433401047	0C9C76	1158 200973	ANASTASIYA ALEKSEEVA	{"phone": "+70067005665"}
0005433401048	0C9C76	1749 168723	VIKTOR GERASIMOV	{"phone": "+70036237492"}
0005433401049	0C9C76	5868 787707	ANGELINA ZAKHAROVA	{"email": "zakharova_angelina-1965@postgrespro.ru", "phone": "+70833702458"}
0005433401050	9C8AB0	5805 268966	SVETLANA DENISOVA	{"phone": "+70648922032"}
0005433401051	9C8AB0	8317 163201	LYUBOV SMIRNOVA	{"email": "lyubov_smirnova_011975@postgrespro.ru", "phone": "+70327797245"}
0005433401052	1EEEFC	0930 192610	SVETLANA AFANASEVA	{"email": "afanaseva.svetlana03071979@postgrespro.ru", "phone": "+70061123300"}
0005433401053	34BD91	1099 898747	ELENA ABRAMOVA	{"phone": "+70062358369"}
0005433401054	99AE73	5323 240231	ALINA TARASOVA	{"phone": "+70896640679"}
0005433401055	BEDAE4	3394 993232	TATYANA ANTONOVA	{"email": "antonova_t.08081980@postgrespro.ru", "phone": "+70295934066"}
0005433401056	93FA43	8223 451025	VITALIY VOLKOV	{"phone": "+70309514551"}
0005433401057	07E36D	8924 631413	SERGEY ROMANOV	{"email": "sromanov.1982@postgrespro.ru", "phone": "+70137279204"}
0005433401058	C1FA7F	7586 248152	SERGEY KUZNECOV	{"phone": "+70349864856"}
0005433401059	339B62	3443 994299	VERA TROFIMOVA	{"phone": "+70246377742"}
0005433401060	339B62	6901 189337	OLGA ANDREEVA	{"phone": "+70912143729"}
0005433401061	BA9A76	1370 822071	VERA TIMOFEEVA	{"phone": "+70066377919"}
0005433401062	BA9A76	2429 781374	ANNA SOKOLOVA	{"email": "sokolova_a_19051977@postgrespro.ru", "phone": "+70437554759"}
0005433401063	A358B9	3632 819456	IGOR BARANOV	{"email": "baranov_i22031961@postgrespro.ru", "phone": "+70699414889"}
0005433401064	A358B9	2631 855404	RAISA TARASOVA	{"email": "tarasova_r_1971@postgrespro.ru", "phone": "+70616307719"}
0005433401065	74ADE7	7965 928986	YULIYA PAVLOVA	{"email": "pavlova_yuliya.1969@postgrespro.ru", "phone": "+70560862620"}
0005433401066	786CB2	9688 896645	DMITRIY ZHUKOV	{"phone": "+70488627034"}
0005433401067	786CB2	0632 149150	PETR SMIRNOV	{"email": "smirnovpetr_1969@postgrespro.ru", "phone": "+70296377854"}
0005433401068	B7A3B3	8382 392252	NIKOLAY FILIPPOV	{"email": "nfilippov.1970@postgrespro.ru", "phone": "+70537606836"}
0005433401069	456D6B	2878 523251	SERGEY STEPANOV	{"email": "s_stepanov.1958@postgrespro.ru", "phone": "+70461589956"}
0005433401070	532C0A	6287 747354	VALENTIN MAKAROV	{"phone": "+70906470824"}
0005433404677	9031C8	5009 042371	SVETLANA ZHURAVLEVA	{"email": "zhuravleva_s.1968@postgrespro.ru", "phone": "+70879189335"}
0005433404678	9031C8	4262 191612	TATYANA NIKOLAEVA	{"phone": "+70889413416"}
0005433404679	078AC8	3491 641462	OLGA DAVYDOVA	{"phone": "+70720732720"}
0005433404680	078AC8	1808 736994	TATYANA OVCHINNIKOVA	{"phone": "+70186201080"}
0005433404681	40FE8B	2141 953874	RENAT VOROBEV	{"email": "renat_vorobev-101970@postgrespro.ru", "phone": "+70852130291"}
0005433404682	FAA78F	7250 459813	TATYANA VOLKOVA	{"email": "tatyanavolkova1973@postgrespro.ru", "phone": "+70383311136"}
0005433404683	FAA78F	3735 347257	VLADIMIR KOROLEV	{"email": "korolevvladimir-041973@postgrespro.ru", "phone": "+70136257892"}
0005433404684	43C0ED	9230 853784	GALINA SOROKINA	{"phone": "+70120167300"}
0005433404685	8E4652	6279 811975	SVETLANA MIRONOVA	{"email": "svetlana-mironova-15031967@postgrespro.ru", "phone": "+70914974119"}
0005433404686	8E4652	8469 503447	NAILYA ZHURAVLEVA	{"email": "zhuravleva-nailya-14101975@postgrespro.ru", "phone": "+70153220899"}
0005433404687	C3B0EB	9966 808095	ANDREY SOROKIN	{"email": "sorokinandrey_1965@postgrespro.ru", "phone": "+70184776304"}
0005433404688	C3B0EB	0072 873900	ALEKSEY KUZMIN	{"phone": "+70028887837"}
0005433404689	F29C63	4776 195328	ELENA NIKITINA	{"email": "nikitina.e1959@postgrespro.ru", "phone": "+70513732013"}
0005433404690	F29C63	1956 731914	ANNA DMITRIEVA	{"email": "dmitrieva_anna_1970@postgrespro.ru", "phone": "+70043294774"}
0005433404691	BEAA1B	2068 935127	GENNADIY NAUMOV	{"email": "naumov.g071983@postgrespro.ru", "phone": "+70996954691"}
0005433404692	BEAA1B	4143 649288	PAVEL BARANOV	{"phone": "+70453395847"}
0005433404693	3F94E8	7619 723172	ANNA DENISOVA	{"email": "denisova_anna-1964@postgrespro.ru", "phone": "+70711352871"}
0005433404694	1E0834	9555 909446	NINA STEPANOVA	{"phone": "+70824584309"}
0005433404695	5BC2FA	0955 505550	VALERIY ORLOV	{"phone": "+70291772747"}
0005433404696	5BC2FA	8703 026247	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov-21081969@postgrespro.ru", "phone": "+70958591062"}
0005433404697	5246CC	0446 813631	TAMARA NIKITINA	{"email": "nikitina_t071968@postgrespro.ru", "phone": "+70718458864"}
0005433404698	5246CC	7123 798613	VLADIMIR KUZMIN	{"phone": "+70806744052"}
0005433404699	5BD70A	7280 051345	NIKITA NAZAROV	{"phone": "+70375999253"}
0005433404700	7E97E2	2260 590820	SVETLANA GAVRILOVA	{"email": "gavrilova-s.011972@postgrespro.ru", "phone": "+70043614638"}
0005433404701	FCEA75	6839 025574	ALEKSEY CHERNOV	{"email": "chernov-a.1969@postgrespro.ru", "phone": "+70587034287"}
0005433404702	FCEA75	3683 629203	LYUDMILA VOLKOVA	{"email": "lyudmila-volkova_061973@postgrespro.ru", "phone": "+70407680638"}
0005433404703	530BEB	8270 286080	LARISA FILATOVA	{"phone": "+70608130671"}
0005433404704	C51FDC	7980 686042	ELENA SCHERBAKOVA	{"phone": "+70909625605"}
0005433404705	C3A058	2251 016094	PAVEL IVANOV	{"phone": "+70656557498"}
0005433404706	BF8D93	0270 258424	VLADIMIR ANDREEV	{"email": "andreevv021970@postgrespro.ru", "phone": "+70415865280"}
0005433404707	BF8D93	4188 095707	ANDREY MIRONOV	{"email": "amironov-1964@postgrespro.ru", "phone": "+70091426203"}
0005433404708	6E26C0	5898 672821	ARTUR KUDRYASHOV	{"phone": "+70644905688"}
0005433404709	8BC6F7	7180 103684	DMITRIY SOLOVEV	{"email": "solovev.d_041971@postgrespro.ru", "phone": "+70373810315"}
0005433404710	B755E3	0385 395551	VALENTINA KISELEVA	{"email": "valentina-kiseleva-1966@postgrespro.ru", "phone": "+70643295387"}
0005433404711	B755E3	6499 972230	LYUBOV NAUMOVA	{"phone": "+70674511003"}
0005433404712	63B392	5565 846188	MARK ZAKHAROV	{"email": "mzakharov.26101971@postgrespro.ru", "phone": "+70697629974"}
0005433404713	B3E081	6833 718674	DENIS FEDOROV	{"phone": "+70246478348"}
0005433404714	B3E081	0429 221797	NADEZHDA TITOVA	{"email": "nadezhda_titova.121975@postgrespro.ru", "phone": "+70380387534"}
0005433404715	2190E4	6371 547713	ALEKSANDR TARASOV	{"phone": "+70938397604"}
0005433404716	86290B	5450 563212	PAVEL SCHERBAKOV	{"email": "p.scherbakov1963@postgrespro.ru", "phone": "+70197336933"}
0005433404717	CE0936	8594 310430	VIKTOR VOLKOV	{"phone": "+70645781849"}
0005433404718	CE0936	0197 270892	ELENA KOZLOVA	{"email": "e.kozlova-1971@postgrespro.ru", "phone": "+70461644425"}
0005433404719	6E661B	2033 100756	ANDREY EGOROV	{"email": "andrey.egorov-1981@postgrespro.ru", "phone": "+70154907459"}
0005433404720	E2901D	2217 515949	LEONID KUZNECOV	{"email": "kuznecov.l.18051965@postgrespro.ru", "phone": "+70061095506"}
0005433404721	E2901D	9603 094649	VLADIMIR MAKAROV	{"email": "vmakarov_25051974@postgrespro.ru", "phone": "+70090057414"}
0005433404722	7431DC	2711 447893	GALINA GRISHINA	{"phone": "+70227041805"}
0005433404723	C2AEF7	5728 568146	PAVEL MAKAROV	{"email": "pavelmakarov.1965@postgrespro.ru", "phone": "+70962926685"}
0005433404724	22D4A4	9452 492960	VALENTINA VASILEVA	{"phone": "+70214711887"}
0005433404725	7FBEDE	1249 172301	VIOLETTA ZAKHAROVA	{"email": "zakharova.v.021977@postgrespro.ru", "phone": "+70309499882"}
0005433404726	6E76F5	3799 546936	ALEKSANDR STEPANOV	{"email": "astepanov15111972@postgrespro.ru", "phone": "+70673318595"}
0005433404727	6E76F5	1529 151341	ALEKSANDR OSIPOV	{"phone": "+70663607998"}
0005433404728	7A8CD9	5299 508825	ELENA LAZAREVA	{"phone": "+70125742739"}
0005433404729	D79114	8123 892186	VIKTORIYA MAKAROVA	{"email": "viktoriya_makarova-1972@postgrespro.ru", "phone": "+70081893676"}
0005433404730	16DC9C	8008 414195	VLADIMIR SMIRNOV	{"email": "smirnov.v_011971@postgrespro.ru", "phone": "+70839586996"}
0005433404731	16DC9C	9701 558283	LYUDMILA EFIMOVA	{"phone": "+70553865454"}
0005433404732	16DC9C	0060 437661	ALEKSANDR ZAKHAROV	{"phone": "+70493918653"}
0005433404733	2DA71A	2271 168047	EKATERINA ROMANOVA	{"email": "e-romanova_111966@postgrespro.ru", "phone": "+70597884710"}
0005433404734	2DA71A	3552 143586	VIKTOR VASILEV	{"phone": "+70251098160"}
0005433404735	D96BA7	3391 049220	MARIYA PAVLOVA	{"phone": "+70356930991"}
0005433404736	DA01F9	3896 751973	MARIYA SERGEEVA	{"email": "sergeevam.1975@postgrespro.ru", "phone": "+70310323474"}
0005433404737	DA01F9	2373 690278	ILYA SCHERBAKOV	{"phone": "+70616285951"}
0005433404738	2E3574	3733 657516	MIKHAIL ORLOV	{"email": "mikhailorlov_1967@postgrespro.ru", "phone": "+70195645146"}
0005433404739	B6B063	7032 780578	VIKTOR ORLOV	{"email": "orlovviktor-10071980@postgrespro.ru", "phone": "+70155500739"}
0005433404740	A7292D	9372 725694	ELENA PETROVA	{"phone": "+70740367071"}
0005433404741	14E62C	8791 703043	MIKHAIL NIKOLAEV	{"email": "m_nikolaev1972@postgrespro.ru", "phone": "+70750616791"}
0005433404742	3226DF	0482 612703	VLADIMIR SIDOROV	{"email": "vladimir.sidorov_1971@postgrespro.ru", "phone": "+70521011770"}
0005433404743	3226DF	6557 313568	VYACHESLAV KUZNECOV	{"phone": "+70751754891"}
0005433404744	AB4836	0938 401640	KONSTANTIN KULIKOV	{"phone": "+70897731324"}
0005433404745	AB4836	3067 355944	ROMAN OSIPOV	{"email": "roman.osipov_091959@postgrespro.ru", "phone": "+70262069394"}
0005433404746	8CF764	7424 339780	ALEKSANDRA AFANASEVA	{"phone": "+70517724826"}
0005433404747	B5FB8B	5285 492603	ALEKSANDR TIKHONOV	{"email": "tikhonov-aleksandr-121966@postgrespro.ru", "phone": "+70088938741"}
0005433404748	B5FB8B	7067 938253	DMITRIY NAZAROV	{"email": "dmitriy_nazarov.12031968@postgrespro.ru", "phone": "+70619798108"}
0005433404749	777450	9706 763131	ALEKSEY ALEKSANDROV	{"email": "a_aleksandrov-1969@postgrespro.ru", "phone": "+70237838566"}
0005433404750	91AEE2	6582 675702	RAVIL SMIRNOV	{"phone": "+70966556019"}
0005433404751	ED5307	6432 901025	TATYANA SIDOROVA	{"phone": "+70010596373"}
0005433404752	ED5307	3973 896776	ALEKSEY POPOV	{"phone": "+70828239368"}
0005433404753	E0F6F5	0236 880638	DMITRIY MIRONOV	{"phone": "+70225748839"}
0005433404754	E0F6F5	0870 601805	ELENA ERMAKOVA	{"phone": "+70959044154"}
0005433404755	EE55A2	8364 237157	ANATOLIY NAUMOV	{"phone": "+70832129894"}
0005433404756	4621EC	5000 830001	OLGA POPOVA	{"phone": "+70800785221"}
0005433404757	A95377	7164 049400	MILENA POTAPOVA	{"phone": "+70241092979"}
0005433404758	A95377	3117 916478	ILYA TARASOV	{"email": "tarasov.i.1969@postgrespro.ru", "phone": "+70110554992"}
0005433404759	A95377	5496 826866	VALENTIN ZAKHAROV	{"email": "zakharov_v.081963@postgrespro.ru", "phone": "+70772196247"}
0005433404760	98E8FA	7806 413322	VLADIMIR VOLKOV	{"phone": "+70108693965"}
0005433404761	98E8FA	2062 338947	ALEKSEY ORLOV	{"email": "a-orlov_06061968@postgrespro.ru", "phone": "+70502598250"}
0005433404762	53EEF7	9748 366153	MARINA LEBEDEVA	{"phone": "+70640440380"}
0005433404763	D93DF7	0694 571400	DMITRIY SCHERBAKOV	{"phone": "+70781624558"}
0005433404764	D93DF7	7315 528045	VYACHESLAV MOISEEV	{"phone": "+70407811923"}
0005433404765	049093	8092 192737	ALEKSANDR GAVRILOV	{"phone": "+70560502819"}
0005433404766	89F3FA	3925 718384	ZINAIDA RODIONOVA	{"email": "zrodionova_18121983@postgrespro.ru", "phone": "+70342418429"}
0005433404767	83E415	5252 906059	GALINA GORBUNOVA	{"email": "galina.gorbunova.031971@postgrespro.ru", "phone": "+70181775467"}
0005433404768	ACFBDE	4894 242385	ALEKSANDRA VOLKOVA	{"email": "volkova-aleksandra_10071969@postgrespro.ru", "phone": "+70586531598"}
0005433404769	36FFE2	9415 927943	VLADIMIR ISAEV	{"email": "isaev_vladimir_25061974@postgrespro.ru", "phone": "+70458478662"}
0005433404770	AE6AC3	8341 027589	VLADIMIR POPOV	{"email": "v-popov_011975@postgrespro.ru", "phone": "+70076114958"}
0005433404771	D49FAF	7294 433042	MARIYA LUKYANOVA	{"phone": "+70211061412"}
0005433404772	BFC137	4046 361261	NIKITA SOKOLOV	{"phone": "+70487217934"}
0005433404773	8DE78E	0842 388742	ALENA DMITRIEVA	{"phone": "+70913510849"}
0005433404774	9CEB3E	7132 185556	SVETLANA ALEKSEEVA	{"phone": "+70459105775"}
0005433404775	D0DE8A	4448 325314	YULIYA FROLOVA	{"email": "frolovayuliya.23041971@postgrespro.ru", "phone": "+70928682717"}
0005433404776	E7418C	3348 565094	ANTONINA MATVEEVA	{"phone": "+70246890693"}
0005433404777	0F758C	7277 066336	IRINA MOISEEVA	{"email": "moiseeva-i_101985@postgrespro.ru", "phone": "+70641788052"}
0005433404778	76CA98	7352 894015	IGOR PAVLOV	{"phone": "+70744629938"}
0005433404779	A2C4B7	7293 061293	YULIYA BORISOVA	{"email": "y.borisova13121974@postgrespro.ru", "phone": "+70763198668"}
0005433404780	2AA1E4	1239 640192	ALBINA SEMENOVA	{"email": "semenova-albina26031981@postgrespro.ru", "phone": "+70820250032"}
0005433404781	8F56B2	4671 091247	VIKTOR OSIPOV	{"phone": "+70112484992"}
0005433404782	DDD674	0990 973529	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_22041973@postgrespro.ru", "phone": "+70966998254"}
0005433404783	DDD674	5223 027679	ARTEM PETROV	{"phone": "+70230477863"}
0005433404784	A36E7F	4802 848580	ANATOLIY GRIGOREV	{"email": "agrigorev1974@postgrespro.ru", "phone": "+70005667703"}
0005433404785	791EE1	0623 833507	VLADIMIR BELOV	{"phone": "+70023423222"}
0005433404786	F1B4A0	2364 009250	YURIY ORLOV	{"phone": "+70193914213"}
0005433404787	8B7568	6696 071114	TATYANA PAVLOVA	{"phone": "+70863902561"}
0005433404788	CF82E5	1655 879298	ANZHELA EGOROVA	{"email": "egorova-anzhela.19121974@postgrespro.ru", "phone": "+70810582220"}
0005433404845	89BD5D	6118 400420	SOFYA ANISIMOVA	{"phone": "+70777011560"}
0005433404789	CF82E5	5839 815009	PAVEL ROMANOV	{"email": "romanov_pavel.1983@postgrespro.ru", "phone": "+70467571833"}
0005433404790	DAEF90	6625 786975	ANATOLIY NIKITIN	{"email": "nikitina.14031966@postgrespro.ru", "phone": "+70622059801"}
0005433404791	DAEF90	6031 627007	OLGA ZAKHAROVA	{"phone": "+70043249643"}
0005433404792	5F348B	7467 364152	IVAN MATVEEV	{"email": "matveevivan.1978@postgrespro.ru", "phone": "+70564380927"}
0005433404793	A8F36D	6389 675824	ALEFTINA EFIMOVA	{"email": "aleftina-efimova_051966@postgrespro.ru", "phone": "+70202125208"}
0005433404794	A8F36D	2494 341785	LYUBOV NIKOLAEVA	{"email": "lyubov_nikolaeva.1970@postgrespro.ru", "phone": "+70599242266"}
0005433404795	3EB5BE	4644 991863	LYUBOV SCHERBAKOVA	{"phone": "+70355580710"}
0005433404796	D94655	9652 713479	ALEKSANDR SERGEEV	{"phone": "+70294823248"}
0005433404797	E10A18	3431 327223	AYRAT STEPANOV	{"phone": "+70051026861"}
0005433404798	ABE9C1	6684 516485	ALEKSEY SMIRNOV	{"email": "smirnova.091974@postgrespro.ru", "phone": "+70281569141"}
0005433404799	3ADE65	4783 440302	TATYANA ILINA	{"email": "tilina-1981@postgrespro.ru", "phone": "+70797265798"}
0005433404800	6BA315	0833 501615	VIKTORIYA POPOVA	{"email": "popova_viktoriya.031986@postgrespro.ru", "phone": "+70834879359"}
0005433404801	6BA315	9536 008615	YURIY SIDOROV	{"phone": "+70229633433"}
0005433404802	23E82B	8018 498085	LYUDMILA SOROKINA	{"email": "sorokina-lyudmila_1975@postgrespro.ru", "phone": "+70577265840"}
0005433404803	025B52	7330 824216	MARAT NAUMOV	{"phone": "+70320983305"}
0005433404804	025B52	1772 428782	ILYA SCHERBAKOV	{"phone": "+70099370158"}
0005433404805	623210	0799 854719	MARIYA ANTONOVA	{"email": "antonova_mariya16101963@postgrespro.ru", "phone": "+70798653929"}
0005433404806	22259E	4227 856925	NIKOLAY MIRONOV	{"email": "n-mironov_1964@postgrespro.ru", "phone": "+70319165412"}
0005433404807	17EBB5	8764 955715	NATALYA KOMAROVA	{"phone": "+70875874297"}
0005433404808	6C6EA6	1668 360505	TATYANA NOVIKOVA	{"email": "t_novikova_101987@postgrespro.ru", "phone": "+70639007816"}
0005433404809	26B7E1	5409 229584	IRINA ZOTOVA	{"phone": "+70852180736"}
0005433404810	26B7E1	4588 046892	IVAN SCHERBAKOV	{"email": "scherbakov.ivan1970@postgrespro.ru", "phone": "+70044645643"}
0005433404811	C86A84	1867 715038	ANATOLIY NIKOLAEV	{"email": "anikolaev21021978@postgrespro.ru", "phone": "+70239914819"}
0005433404812	9CBE78	5675 706408	YURIY PAVLOV	{"phone": "+70274222125"}
0005433404813	FB81F5	3226 275855	PAVEL KUZNECOV	{"phone": "+70530009025"}
0005433404814	844080	5880 319763	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev_1968@postgrespro.ru", "phone": "+70528303247"}
0005433404815	BAFE25	8137 742210	VALENTIN ZAYCEV	{"phone": "+70808593311"}
0005433404816	F22B32	3422 885555	STEPAN DAVYDOV	{"email": "s-davydov.25081972@postgrespro.ru", "phone": "+70130103718"}
0005433404817	F22B32	0563 070693	ALEKSANDRA VOLKOVA	{"email": "aleksandra_volkova.26011974@postgrespro.ru", "phone": "+70298682209"}
0005433404818	F22B32	2748 406105	ALEKSANDR ABRAMOV	{"email": "a_abramov_061980@postgrespro.ru", "phone": "+70060285501"}
0005433404819	B3747B	4381 842909	IGOR MIRONOV	{"email": "mironovi_121973@postgrespro.ru", "phone": "+70863677068"}
0005433404820	B3747B	0903 750818	SERGEY KUZMIN	{"phone": "+70830923573"}
0005433404821	EDAB57	0414 293623	VADIM IVANOV	{"phone": "+70296615754"}
0005433404822	EDAB57	6816 632877	OLGA TROFIMOVA	{"phone": "+70281629015"}
0005433404823	8EF4D7	0957 493701	ANATOLIY KUDRYASHOV	{"phone": "+70402368603"}
0005433404824	8EF4D7	5497 306463	ALEKSANDR SHEVCHENKO	{"phone": "+70149272842"}
0005433404825	8EF4D7	5813 376025	ANDREY IVANOV	{"phone": "+70196583381"}
0005433404826	75FDE5	4712 437176	GENNADIY MELNIKOV	{"email": "g.melnikov_22091982@postgrespro.ru", "phone": "+70272060008"}
0005433404827	424052	0787 634807	ELENA YAKOVLEVA	{"phone": "+70644367892"}
0005433404828	A238FB	4159 857501	OLESYA LAZAREVA	{"phone": "+70388950915"}
0005433404829	A238FB	2405 020943	ALEKSANDR KAZAKOV	{"email": "kazakov-a031973@postgrespro.ru", "phone": "+70333856357"}
0005433404830	F8725C	5291 303714	ANDREY ANTONOV	{"email": "a-antonov.15031975@postgrespro.ru", "phone": "+70105787568"}
0005433404831	F8725C	5579 639244	EKATERINA BELOVA	{"email": "belova_e1981@postgrespro.ru", "phone": "+70687452348"}
0005433404832	FAF5AB	1819 767102	ANASTASIYA VASILEVA	{"email": "vasileva_anastasiya.17011970@postgrespro.ru", "phone": "+70809398945"}
0005433404833	A727B8	8592 000153	SVETLANA DANILOVA	{"email": "danilova_s1961@postgrespro.ru", "phone": "+70982531394"}
0005433404834	A727B8	2434 341216	NURIYA GERASIMOVA	{"phone": "+70158308219"}
0005433404835	A1E925	0244 154519	LYUDMILA DAVYDOVA	{"phone": "+70917236755"}
0005433404836	8991BE	7647 261832	DANIIL VLASOV	{"phone": "+70116822029"}
0005433404837	8991BE	9151 018873	LYUDMILA FADEEVA	{"email": "fadeeva.l1967@postgrespro.ru", "phone": "+70777141957"}
0005433404838	B79072	9054 006509	SERGEY SEMENOV	{"email": "semenovsergey_1979@postgrespro.ru", "phone": "+70330529056"}
0005433404839	B79072	9558 310416	MAKSIM NAZAROV	{"email": "maksim-nazarov-071980@postgrespro.ru", "phone": "+70684061318"}
0005433404840	521DF4	9824 881088	MAKSIM KUZNECOV	{"phone": "+70755061725"}
0005433404841	B63FE1	2362 317513	SERGEY MOROZOV	{"phone": "+70655085263"}
0005433404842	79E5C8	8142 457900	GALINA MATVEEVA	{"email": "matveeva.g_101973@postgrespro.ru", "phone": "+70962874153"}
0005433404843	E7AFF3	8896 718079	VIKTOR FEDOROV	{"phone": "+70952993659"}
0005433404844	89BD5D	6894 804518	SERGEY KUZMIN	{"email": "kuzmin.s1981@postgrespro.ru", "phone": "+70535134545"}
0005433404846	1121F5	7226 433089	DIANA MAKAROVA	{"phone": "+70747624427"}
0005433404847	7EE2E1	9395 112367	YULIYA FILATOVA	{"phone": "+70888202506"}
0005433404848	3B775D	1958 547462	EKATERINA KOZLOVA	{"email": "ekaterina_kozlova1969@postgrespro.ru", "phone": "+70891002764"}
0005433404849	8E4C1A	7175 346681	NATALIYA ABRAMOVA	{"phone": "+70222641307"}
0005433404850	2D4478	2931 545663	LYUBOV ISAEVA	{"phone": "+70357327935"}
0005433404851	6B7E38	9061 426991	TAMARA IVANOVA	{"phone": "+70337703380"}
0005433404852	6B7E38	7055 292043	IRINA MAKSIMOVA	{"email": "irina.maksimova101968@postgrespro.ru", "phone": "+70578960510"}
0005433404853	2B8D1E	4449 452553	STANISLAV NAUMOV	{"email": "naumov.stanislav-1964@postgrespro.ru", "phone": "+70131841325"}
0005433404854	99D7FA	4777 643033	GALINA ZAYCEVA	{"email": "galina_zayceva-1971@postgrespro.ru", "phone": "+70931993954"}
0005433404855	25A4AC	3316 515658	ANASTASIYA NAUMOVA	{"phone": "+70075390175"}
0005433404856	D37A26	2478 066088	ANZHELIKA ANDREEVA	{"phone": "+70422467465"}
0005433404857	15752F	4172 292136	LYUDMILA ZHUKOVA	{"email": "zhukoval-121971@postgrespro.ru", "phone": "+70229656863"}
0005433404858	15752F	0578 990844	ALEKSANDRA KOMAROVA	{"phone": "+70227486529"}
0005433404859	C8D02F	4247 955903	VENERA MOISEEVA	{"phone": "+70791022774"}
0005433404860	C8D02F	2772 626631	VALENTIN MELNIKOV	{"email": "valentin.melnikov.05041971@postgrespro.ru", "phone": "+70138605027"}
0005433404861	593366	5125 321211	MARAT GUSEV	{"phone": "+70083706892"}
0005433404862	593366	2513 801409	KONSTANTIN KARPOV	{"phone": "+70178386848"}
0005433404863	593366	6470 616591	VITALIY DAVYDOV	{"email": "v.davydov_1974@postgrespro.ru", "phone": "+70532921906"}
0005433404864	FEE2A1	8124 102187	NATALYA PAVLOVA	{"phone": "+70385693524"}
0005433404865	98F960	2182 139400	OLGA KOVALEVA	{"email": "olga-kovaleva.011961@postgrespro.ru", "phone": "+70510615907"}
0005433404866	5C4911	3006 412904	LIDIYA ISAEVA	{"email": "isaeval_1975@postgrespro.ru", "phone": "+70289113820"}
0005433404867	56098F	5035 343125	SERGEY DENISOV	{"email": "denisov.sergey-1970@postgrespro.ru", "phone": "+70123272405"}
0005433404868	320CB0	8446 149121	NIKOLAY KUZNECOV	{"phone": "+70849382724"}
0005433404869	34FD37	8854 038610	NATALYA VLASOVA	{"phone": "+70045224181"}
0005433404870	B37483	4411 264827	SERGEY SOROKIN	{"phone": "+70126222996"}
0005433404871	057691	1829 638019	ANNA KALININA	{"email": "kalininaa.27091977@postgrespro.ru", "phone": "+70283854394"}
0005433404872	057691	8256 534031	EVGENIY IVANOV	{"email": "evgeniy_ivanov-011959@postgrespro.ru", "phone": "+70021951227"}
0005433404873	A4C60C	9753 991714	DMITRIY MIKHAYLOV	{"email": "mikhaylov-d.091972@postgrespro.ru", "phone": "+70809141863"}
0005433404874	124FB2	5024 756071	RASHID KRASNOV	{"phone": "+70930523974"}
0005433404875	40CB76	6946 925876	IVAN STEPANOV	{"email": "ivan_stepanov1965@postgrespro.ru", "phone": "+70156874966"}
0005433404876	08A26A	4824 417074	VALERIYA KUZMINA	{"phone": "+70482779057"}
0005433404877	08A26A	3075 503319	VERA ANISIMOVA	{"email": "anisimova_v_1972@postgrespro.ru", "phone": "+70941153595"}
0005433404878	3EFFDA	3366 254017	VALENTINA MARTYNOVA	{"email": "v.martynova.14091972@postgrespro.ru", "phone": "+70045366786"}
0005433404879	C217DD	7277 911067	MARIYA ALEKSEEVA	{"email": "alekseevamariya-011977@postgrespro.ru", "phone": "+70605313203"}
0005433404880	A83D18	8792 935500	DMITRIY FEDOROV	{"email": "d.fedorov031970@postgrespro.ru", "phone": "+70289728748"}
0005433404881	4AF589	7814 256914	YURIY MAKAROV	{"email": "makarov.yuriy17031968@postgrespro.ru", "phone": "+70222114550"}
0005433404882	81812F	2108 303620	NIKOLAY VOROBEV	{"email": "vorobev_n25091974@postgrespro.ru", "phone": "+70429436083"}
0005433404883	6D0407	3494 603976	EVGENIY VLASOV	{"phone": "+70827606512"}
0005433404884	1CECD7	4022 261048	IREK IVANOV	{"phone": "+70312468497"}
0005433404885	97684D	7336 126394	DMITRIY PETROV	{"phone": "+70473092496"}
0005433404886	14184B	4264 937479	MILANA ALEKSEEVA	{"email": "alekseeva.milana_021968@postgrespro.ru", "phone": "+70680502598"}
0005433404887	14184B	9023 426453	VARVARA MEDVEDEVA	{"phone": "+70547474001"}
0005433404888	F9C3C8	4648 224122	NINA KRASNOVA	{"email": "krasnovan_1960@postgrespro.ru", "phone": "+70615568608"}
0005433404889	F74517	4638 177033	SERGEY PETROV	{"email": "petrov.s_1973@postgrespro.ru", "phone": "+70774808788"}
0005433404890	32E831	8860 200833	OLGA ABRAMOVA	{"email": "abramova.olga.051974@postgrespro.ru", "phone": "+70734622092"}
0005433404891	F1F5A9	2011 321336	VLADIMIR VOLKOV	{"phone": "+70855683149"}
0005433404892	E818E1	5643 910099	DINARA BORISOVA	{"email": "borisovad_09021970@postgrespro.ru", "phone": "+70605324252"}
0005433404893	E818E1	0630 773695	SERGEY AFANASEV	{"email": "afanasevs.101975@postgrespro.ru", "phone": "+70800231473"}
0005433404894	88B1EC	2834 288434	MARIYA SMIRNOVA	{"phone": "+70721970190"}
0005433404895	88B1EC	8717 162969	VIKTOR IVANOV	{"email": "viktor.ivanov07041967@postgrespro.ru", "phone": "+70600471604"}
0005433404896	3AB79E	0681 053272	IRINA SAVELEVA	{"phone": "+70854013956"}
0005433404897	56CD01	5136 914122	ANNA POPOVA	{"email": "apopova_081964@postgrespro.ru", "phone": "+70864999410"}
0005433404898	93ACA2	0950 928653	ANDREY SEMENOV	{"email": "semenova.051964@postgrespro.ru", "phone": "+70664918544"}
0005433404899	ABF660	9021 425856	ANDREY OSIPOV	{"phone": "+70914480827"}
0005433404900	ABF660	1414 490213	VALENTINA SMIRNOVA	{"phone": "+70963652839"}
0005433404901	05D8E4	9499 705086	LYUDMILA MAKSIMOVA	{"email": "lyudmila_maksimova-03031968@postgrespro.ru", "phone": "+70861090023"}
0005433404902	9401C7	1326 894019	VALENTINA GUSEVA	{"phone": "+70149221578"}
0005433404903	9401C7	9477 612174	NADEZHDA KUZNECOVA	{"phone": "+70538524679"}
0005433404904	507843	8878 782933	OLEG FOMIN	{"phone": "+70861541541"}
0005433404905	92439F	8006 013022	LYUDMILA VASILEVA	{"email": "vasilevalyudmila_111976@postgrespro.ru", "phone": "+70886895175"}
0005433404906	92439F	6855 737420	VIKTOR GERASIMOV	{"email": "v-gerasimov051969@postgrespro.ru", "phone": "+70219012316"}
0005433404907	1ACCBF	4959 213429	DENIS PAVLOV	{"email": "d-pavlov_23071976@postgrespro.ru", "phone": "+70411346596"}
0005433404908	8DFC39	3394 915256	VLADIMIR NIKITIN	{"phone": "+70674509746"}
0005433404909	CA75C3	3312 145793	MARINA EFIMOVA	{"email": "m_efimova-021960@postgrespro.ru", "phone": "+70338602348"}
0005433404910	5BD98B	2625 453827	LYUBOV VASILEVA	{"phone": "+70689109367"}
0005433404911	5BD98B	3537 526193	VIKTORIYA LOGINOVA	{"email": "v.loginova_1964@postgrespro.ru", "phone": "+70441453197"}
0005433404912	71E9EC	1138 794261	LEONID VASILEV	{"phone": "+70374780999"}
0005433404913	4E0B69	3162 099662	IVAN ZHUKOV	{"email": "izhukov-031973@postgrespro.ru", "phone": "+70055447148"}
0005433404914	EDA55D	9597 715822	ANATOLIY MAKAROV	{"email": "anatoliymakarov_1958@postgrespro.ru", "phone": "+70870488440"}
0005433404915	6F9B19	9708 490460	GALINA GORBUNOVA	{"phone": "+70176797483"}
0005433404916	6F9B19	6374 311574	PETR SEMENOV	{"email": "semenovpetr_021972@postgrespro.ru", "phone": "+70260178263"}
0005433404917	C52BCC	2339 948084	ALEKSEY SCHERBAKOV	{"email": "scherbakova_1968@postgrespro.ru", "phone": "+70261181772"}
0005433404918	806864	7280 477984	ANASTASIYA KUZMINA	{"phone": "+70846648583"}
0005433404919	B9B132	4962 071401	IRINA SEMENOVA	{"phone": "+70013091561"}
0005433404920	B9B132	7060 213392	ALEKSEY TIMOFEEV	{"phone": "+70257561095"}
0005433404921	745167	6092 334678	ALEKSANDR VLASOV	{"phone": "+70357054353"}
0005433404922	36B5A7	0186 832545	MIKHAIL MOROZOV	{"email": "mikhail.morozov26111977@postgrespro.ru", "phone": "+70334664059"}
0005433404923	2BA606	8789 891253	ANDREY MIKHAYLOV	{"email": "a.mikhaylov_101960@postgrespro.ru", "phone": "+70198460903"}
0005433404924	8F1BBD	6407 518825	OLEG PAVLOV	{"phone": "+70983583278"}
0005433404925	8F1BBD	3427 659735	NINA NAUMOVA	{"email": "nina.naumova_31101972@postgrespro.ru", "phone": "+70810393031"}
0005433404926	EB496C	0374 232352	DMITRIY MOROZOV	{"email": "dmitriymorozov011966@postgrespro.ru", "phone": "+70421224293"}
0005433404927	B4AF30	9169 686887	ANTONINA VASILEVA	{"email": "a-vasileva.1975@postgrespro.ru", "phone": "+70340326329"}
0005433404928	EA0EFF	0417 207370	KRISTINA POPOVA	{"email": "popovak_04031974@postgrespro.ru", "phone": "+70165640230"}
0005433404929	66599F	0032 174526	OLGA IVANOVA	{"phone": "+70251737936"}
0005433404930	D7FC75	0847 658125	SERGEY KOZLOV	{"phone": "+70180590381"}
0005433404931	52E08D	9584 591996	LYUDMILA MARTYNOVA	{"email": "martynova.l15091976@postgrespro.ru", "phone": "+70632288613"}
0005433404932	05BF3F	2509 187077	VALENTINA KONOVALOVA	{"phone": "+70415050416"}
0005433404933	F96CC6	3217 212645	ANNA ISAEVA	{"email": "anna-isaeva1980@postgrespro.ru", "phone": "+70172719076"}
0005433404934	415006	5459 048830	MARIYA PAVLOVA	{"phone": "+70644711761"}
0005433404935	011AB0	9955 197463	ANATOLIY SOKOLOV	{"email": "anatoliy.sokolov1974@postgrespro.ru", "phone": "+70927399016"}
0005433404936	011AB0	6866 546132	IVAN ALEKSANDROV	{"phone": "+70688393673"}
0005433404937	23CA38	1943 645242	MAKSIM MARTYNOV	{"email": "martynovm.1967@postgrespro.ru", "phone": "+70990521216"}
0005433404938	23CA38	2014 818297	LARISA LOGINOVA	{"email": "l.loginova061977@postgrespro.ru", "phone": "+70312106317"}
0005433404939	226862	5287 352876	EKATERINA OSIPOVA	{"phone": "+70154867865"}
0005433404940	613A0B	0618 694495	IRINA SMIRNOVA	{"phone": "+70486969990"}
0005433404941	613A0B	5719 253044	KONSTANTIN YAKOVLEV	{"email": "konstantinyakovlev.1977@postgrespro.ru", "phone": "+70762687278"}
0005433404942	9AE690	4818 780227	ANATOLIY ZAKHAROV	{"email": "anatoliy_zakharov.22121969@postgrespro.ru", "phone": "+70036542571"}
0005433404943	C10149	6688 107850	TATYANA KULIKOVA	{"email": "kulikovat_01111973@postgrespro.ru", "phone": "+70537272559"}
0005433404944	C10149	9882 348159	ZINAIDA ABRAMOVA	{"email": "abramova.z071972@postgrespro.ru", "phone": "+70861964007"}
0005433404945	BE2290	2892 793952	ALEKSANDRA NESTEROVA	{"email": "aleksandra.nesterova1969@postgrespro.ru", "phone": "+70819288380"}
0005433404946	033144	3023 441769	VERA KUZNECOVA	{"phone": "+70462875666"}
0005433404947	8201B7	4467 580322	NADEZHDA SEMENOVA	{"phone": "+70492936590"}
0005433404948	8201B7	7020 856821	ELENA MARTYNOVA	{"phone": "+70820449215"}
0005433404949	8201B7	9837 822912	ALINA DENISOVA	{"phone": "+70404383813"}
0005433404950	8181AD	2701 548797	ILDAR KUZMIN	{"phone": "+70994920713"}
0005433404951	8181AD	7136 176534	OLGA PAVLOVA	{"phone": "+70085540499"}
0005433404952	9ED161	9329 964658	IRINA MIRONOVA	{"phone": "+70980660863"}
0005433404953	145B14	7462 044845	ELENA SCHERBAKOVA	{"email": "scherbakova_e-091970@postgrespro.ru", "phone": "+70778972099"}
0005433404954	D53904	5214 916142	ALFIYA KOLESNIKOVA	{"email": "alfiya.kolesnikova.03011976@postgrespro.ru", "phone": "+70475835798"}
0005433404955	691CD3	1002 394844	MARINA RYABOVA	{"email": "ryabovamarina031968@postgrespro.ru", "phone": "+70940709859"}
0005433404956	FE7410	3852 477380	SERGEY ALEKSANDROV	{"email": "aleksandrov_s.18011984@postgrespro.ru", "phone": "+70527756422"}
0005433404957	0FDFE8	8265 894390	DANIIL MARTYNOV	{"phone": "+70020410539"}
0005433404958	0FDFE8	1926 213888	NIKOLAY KAZAKOV	{"email": "n.kazakov1972@postgrespro.ru", "phone": "+70706444804"}
0005433404959	EED207	0162 152584	NIKOLAY RODIONOV	{"email": "n.rodionov.1968@postgrespro.ru", "phone": "+70526766105"}
0005433404960	326E10	3295 906614	EVGENIY BONDARENKO	{"phone": "+70387173879"}
0005433404961	326E10	6635 461962	ELENA KUDRYASHOVA	{"email": "kudryashova.elena-15021968@postgrespro.ru", "phone": "+70789812005"}
0005433404962	326E10	9902 324299	MIKHAIL MOROZOV	{"email": "morozovm_011981@postgrespro.ru", "phone": "+70181053657"}
0005433404963	B09126	8260 524331	NIKOLAY STEPANOV	{"email": "n_stepanov_1973@postgrespro.ru", "phone": "+70838891010"}
0005433404964	87B404	5671 189805	NIKOLAY DENISOV	{"email": "denisov_n_101980@postgrespro.ru", "phone": "+70086695462"}
0005433404965	508FEE	1144 923138	EKATERINA KARPOVA	{"phone": "+70093269596"}
0005433404966	508FEE	2446 775402	ELENA SEMENOVA	{"email": "semenova.elena-22061966@postgrespro.ru", "phone": "+70014511758"}
0005433404967	D1B41B	1432 834532	ILDAR ROMANOV	{"email": "ildarromanov-051965@postgrespro.ru", "phone": "+70386468666"}
0005433404968	6DBEA2	5670 941962	VLADIMIR BONDARENKO	{"email": "bondarenkov-031975@postgrespro.ru", "phone": "+70697813462"}
0005433404969	23431C	6363 205704	ALEKSANDRA IVANOVA	{"email": "ivanova.aleksandra-011971@postgrespro.ru", "phone": "+70066464572"}
0005433404970	62F639	0955 981782	ZINAIDA GAVRILOVA	{"email": "gavrilova.zinaida-021979@postgrespro.ru", "phone": "+70418657507"}
0005433404971	ADDD57	4331 755240	NATALYA KOZLOVA	{"phone": "+70118567349"}
0005433404972	ADDD57	7625 632220	ALEKSEY MIKHAYLOV	{"email": "mikhaylov-aleksey.061963@postgrespro.ru", "phone": "+70319929588"}
0005433404973	8CA741	9720 753429	DARYA NESTEROVA	{"phone": "+70963862098"}
0005433404974	8CA741	4274 554566	ELENA ANISIMOVA	{"email": "e-anisimova.061974@postgrespro.ru", "phone": "+70785280022"}
0005433404975	DC5686	3406 895097	DMITRIY BARANOV	{"phone": "+70710570847"}
0005433404976	57AC26	2811 115232	ALEKSANDR SOKOLOV	{"phone": "+70580645095"}
0005433404977	69EA39	1752 709717	ALEKSEY NOVIKOV	{"email": "novikov-aleksey.1970@postgrespro.ru", "phone": "+70292131562"}
0005433404978	69EA39	5705 733567	KRISTINA FOMINA	{"phone": "+70039164828"}
0005433404979	0D88AC	8879 325874	NADEZHDA NESTEROVA	{"email": "nesterova_n_28011970@postgrespro.ru", "phone": "+70779501314"}
0005433404980	73C648	8596 910389	VLADIMIR VOLKOV	{"email": "vladimir_volkov101970@postgrespro.ru", "phone": "+70579610145"}
0005433404981	7CAD04	5882 235700	ALEVTINA ALEKSANDROVA	{"email": "aleksandrova_alevtina-18061963@postgrespro.ru", "phone": "+70989552829"}
0005433404982	7CAD04	5645 700903	NINA KOZLOVA	{"phone": "+70214584602"}
0005433404983	198011	1998 994992	OLGA KOVALEVA	{"email": "kovaleva_olga-1973@postgrespro.ru", "phone": "+70738603036"}
0005433404984	146ED6	9516 497999	TATYANA KONDRATEVA	{"phone": "+70184842130"}
0005433404985	E776CB	3477 796000	MARIYA NAZAROVA	{"email": "mariya.nazarova.121973@postgrespro.ru", "phone": "+70668367582"}
0005433404986	0A365B	4031 199912	OLGA KAZAKOVA	{"phone": "+70172709034"}
0005433404987	5D1099	1960 094120	SERGEY PETROV	{"email": "sergey_petrov.021977@postgrespro.ru", "phone": "+70672340117"}
0005433404988	8D6267	4746 062807	VLADIMIR FILIPPOV	{"phone": "+70709452379"}
0005433404989	8D6267	5912 453138	VERA MAKSIMOVA	{"phone": "+70491830398"}
0005433404990	2520F5	9802 739636	IRINA DANILOVA	{"email": "danilovairina.29121957@postgrespro.ru", "phone": "+70074002556"}
0005433404991	230608	0864 517700	EVGENIY VASILEV	{"phone": "+70484478617"}
0005433404992	230608	5950 189584	RUSLAN MELNIKOV	{"phone": "+70946001723"}
0005433404993	7D77C7	9778 895624	VLADIMIR KUDRYASHOV	{"email": "kudryashov_vladimir.1968@postgrespro.ru", "phone": "+70143316823"}
0005433404994	45CD25	4766 649751	KIRILL BELOV	{"email": "k-belov.21041980@postgrespro.ru", "phone": "+70726579891"}
0005433404995	A8C4FF	3780 900424	KARINA DAVYDOVA	{"phone": "+70480284475"}
0005433404996	A8C4FF	2764 649652	ELENA NAUMOVA	{"phone": "+70188660565"}
0005433404997	286BC1	6078 610217	SVETLANA MALYSHEVA	{"phone": "+70820854647"}
0005433404998	286BC1	5032 511784	ANDREY NIKITIN	{"email": "anikitin.1961@postgrespro.ru", "phone": "+70739341051"}
0005433404999	286BC1	6679 784782	DMITRIY KUZNECOV	{"phone": "+70718692646"}
0005433405000	286BC1	4738 671704	EKATERINA KOROLEVA	{"email": "koroleva.ekaterina_30111970@postgrespro.ru", "phone": "+70965670849"}
0005433405001	875936	1919 911228	DMITRIY SERGEEV	{"email": "dmitriy.sergeev1976@postgrespro.ru", "phone": "+70951994603"}
0005433405002	875936	9989 113184	YULIYA POPOVA	{"phone": "+70705163279"}
0005433405003	6B8A43	3133 001887	VLADIMIR MOROZOV	{"phone": "+70446906190"}
0005433405004	6B8A43	0153 466852	IVAN KONOVALOV	{"phone": "+70131270077"}
0005433405005	C4690B	9395 776027	ANDREY ZAKHAROV	{"email": "azakharov.1973@postgrespro.ru", "phone": "+70205887841"}
0005433405006	DB4355	9522 054767	OLEG PAVLOV	{"phone": "+70925864129"}
0005433405007	4AFC63	5313 632937	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov.061973@postgrespro.ru", "phone": "+70803981037"}
0005433405008	F65548	0987 705256	VIKTORIYA ZAKHAROVA	{"email": "v_zakharova1973@postgrespro.ru", "phone": "+70203451718"}
0005433405009	BA0EAD	3980 434494	EVGENIY IVANOV	{"email": "evgeniy-ivanov.26051983@postgrespro.ru", "phone": "+70903580753"}
0005433405010	789541	2350 676564	ALEKSANDR ZAYCEV	{"phone": "+70009930509"}
0005433405011	808236	4647 855142	MAKSIM SCHERBAKOV	{"email": "m-scherbakov-1984@postgrespro.ru", "phone": "+70427137919"}
0005433405012	808236	9406 198180	SVETLANA KUZNECOVA	{"phone": "+70202299402"}
0005433405013	9AAE8D	9533 406382	LYUDMILA MAKAROVA	{"email": "lyudmilamakarova.19011980@postgrespro.ru", "phone": "+70883609220"}
0005433405014	9AAE8D	4790 012825	OLEG KOZLOV	{"email": "kozlov_oleg.1976@postgrespro.ru", "phone": "+70076548214"}
0005433405015	58C71F	8023 204894	ULYANA GUSEVA	{"email": "ulyanaguseva-011970@postgrespro.ru", "phone": "+70480060266"}
0005433405016	49A9BF	4023 432106	OKSANA SMIRNOVA	{"phone": "+70953173710"}
0005433405017	6FF6F9	8221 981619	LIDIYA GAVRILOVA	{"email": "gavrilova_lidiya_021973@postgrespro.ru", "phone": "+70854864778"}
0005433405018	6FF6F9	3646 254743	DIANA KUZNECOVA	{"phone": "+70085404563"}
0005433405019	7D8BB7	7810 716805	ANNA MIKHAYLOVA	{"email": "mikhaylova.anna.051982@postgrespro.ru", "phone": "+70437767661"}
0005433405020	A7A8EC	3210 767823	SVETLANA SOLOVEVA	{"email": "ssoloveva1965@postgrespro.ru", "phone": "+70800074523"}
0005433405021	72F660	0676 471158	ANNA IVANOVA	{"phone": "+70906331357"}
0005433405022	30A2DB	9861 182225	ANDREY VASILEV	{"email": "vasilev_andrey30051975@postgrespro.ru", "phone": "+70834295781"}
0005433405023	0BB557	4051 715577	TATYANA VOROBEVA	{"email": "vorobevatatyana-091966@postgrespro.ru", "phone": "+70379483856"}
0005433405024	AD7109	9683 044521	PAVEL KOZLOV	{"email": "kozlovp.031972@postgrespro.ru", "phone": "+70962756565"}
0005433405025	92BBE1	4300 578051	ROMAN CHERNOV	{"phone": "+70175577995"}
0005433405026	3D04E2	1718 505055	SERGEY AFANASEV	{"email": "afanasev_s-18051972@postgrespro.ru", "phone": "+70962867275"}
0005433405027	847B8B	7710 061715	OLGA SCHERBAKOVA	{"email": "scherbakova.o17101962@postgrespro.ru", "phone": "+70278776585"}
0005433405028	772620	3591 897550	ALEVTINA PAVLOVA	{"email": "pavlova.alevtina1968@postgrespro.ru", "phone": "+70322392899"}
0005433405029	A22C98	0700 899989	FANIL NAUMOV	{"phone": "+70847737428"}
0005433405030	600145	0270 149398	ELENA KUZNECOVA	{"phone": "+70299277199"}
0005433405031	C4A2E1	6900 003856	NINA FOMINA	{"email": "fominanina.051959@postgrespro.ru", "phone": "+70895869630"}
0005433405032	46AA68	9283 632418	KONSTANTIN PAVLOV	{"email": "k.pavlov18111973@postgrespro.ru", "phone": "+70228500831"}
0005433405033	46AA68	2318 616377	YAROSLAV STEPANOV	{"phone": "+70929625989"}
0005433405034	6CEBE1	9876 447505	ALEKSANDR CHERNOV	{"email": "chernov-a1968@postgrespro.ru", "phone": "+70740241520"}
0005433405035	6CEBE1	7114 894819	NADEZHDA NAZAROVA	{"email": "n-nazarova-091964@postgrespro.ru", "phone": "+70303490133"}
0005433405036	3D8222	0918 950889	TAMARA MALYSHEVA	{"email": "tamara-malysheva-1970@postgrespro.ru", "phone": "+70960181171"}
0005433405037	3D8222	8078 333721	IRINA FILIPPOVA	{"email": "filippova-i.13071974@postgrespro.ru", "phone": "+70629831908"}
0005433407477	589AAA	3734 902979	EGOR FILIPPOV	{"email": "e-filippov1964@postgrespro.ru", "phone": "+70758821544"}
0005433407478	6ED056	0719 021722	ALEKSANDRA AFANASEVA	{"phone": "+70784404916"}
0005433407479	6ED056	7092 036955	GALINA SOROKINA	{"phone": "+70705115112"}
0005433407480	F5DEB2	3956 434119	SVETLANA VASILEVA	{"email": "svetlana-vasileva_1977@postgrespro.ru", "phone": "+70140231604"}
0005433407481	87A1CC	2218 977609	ANNA MALYSHEVA	{"email": "a_malysheva.16031970@postgrespro.ru", "phone": "+70518300159"}
0005433407482	7394FB	8497 394327	YULIYA EGOROVA	{"phone": "+70995256873"}
0005433407483	C8300B	1650 372740	VLADIMIR BARANOV	{"email": "vladimirbaranov.02081974@postgrespro.ru", "phone": "+70953482509"}
0005433407484	B5E372	9034 391635	EGOR EGOROV	{"phone": "+70263364923"}
0005433407485	B5E372	8599 770838	MARIYA KOZLOVA	{"phone": "+70202708276"}
0005433407486	FE8467	8040 860292	LIDIYA SAVELEVA	{"email": "lsaveleva.15081966@postgrespro.ru", "phone": "+70990235977"}
0005433407487	FE8467	8124 348974	NINA SOKOLOVA	{"phone": "+70072393900"}
0005433407488	FE8467	1438 498667	LIDIYA ZAKHAROVA	{"phone": "+70154136939"}
0005433407489	B9545C	2418 347017	LYUBOV KONOVALOVA	{"phone": "+70676567624"}
0005433407490	FD909A	9360 204866	VASILIY MIKHAYLOV	{"phone": "+70100764857"}
0005433407491	9E961D	9000 791401	ILYA OSIPOV	{"phone": "+70383369347"}
0005433407492	7CA4BA	0788 811170	ANDREY ANDREEV	{"email": "andrey_andreev041980@postgrespro.ru", "phone": "+70518214638"}
0005433407493	7CA4BA	9151 440809	SERGEY BORISOV	{"email": "sergey_borisov-29041966@postgrespro.ru", "phone": "+70462191088"}
0005433407494	6759C0	8204 485938	VALENTIN IVANOV	{"email": "ivanov-v_18051966@postgrespro.ru", "phone": "+70406252316"}
0005433407495	3DB753	0038 375998	MIKHAIL KOZLOV	{"email": "mikhailkozlov1959@postgrespro.ru", "phone": "+70469157941"}
0005433407496	3DB753	1548 147981	NINA NAZAROVA	{"email": "ninanazarova_021960@postgrespro.ru", "phone": "+70328831977"}
0005433407497	6AE6EA	4966 502881	YURIY ROMANOV	{"email": "romanov.yuriy1968@postgrespro.ru", "phone": "+70499328127"}
0005433407498	BE448F	1963 187265	ARTEM KULIKOV	{"email": "kulikov-a-031983@postgrespro.ru", "phone": "+70035666282"}
0005433407499	BE448F	9932 486485	MILENA MASLOVA	{"phone": "+70985216305"}
0005433407500	0D34A6	4529 526270	SANIYA LEBEDEVA	{"email": "s-lebedeva_02021972@postgrespro.ru", "phone": "+70215302194"}
0005433407501	77B777	5800 847754	NATALYA SIDOROVA	{"email": "natalya.sidorova.20031971@postgrespro.ru", "phone": "+70782121897"}
0005433407502	C978B8	6273 113342	ANASTASIYA AKIMOVA	{"phone": "+70666174346"}
0005433407503	8865DB	1163 353267	ALEKSANDR MAKAROV	{"phone": "+70154682013"}
0005433407504	8865DB	8293 374136	DARYA IVANOVA	{"phone": "+70683554964"}
0005433407505	3D5E14	4241 275697	IVAN PAVLOV	{"phone": "+70640791576"}
0005433407506	3D5E14	8736 309019	NADEZHDA TIKHONOVA	{"phone": "+70195885681"}
0005433407507	542337	8725 090959	MARIYA PETROVA	{"email": "petrova-mariya_1977@postgrespro.ru", "phone": "+70680738111"}
0005433407508	50F191	0811 912342	ARMEN PETROV	{"email": "petrovarmen.071961@postgrespro.ru", "phone": "+70324201875"}
0005433407509	345F2E	2755 780051	YULIYA BARANOVA	{"phone": "+70900706652"}
0005433407510	345F2E	5944 158258	ILDAR ABRAMOV	{"email": "ildarabramov_101974@postgrespro.ru", "phone": "+70738932980"}
0005433407511	CE5190	2125 411331	MAKSIM KRASNOV	{"phone": "+70345488443"}
0005433407512	6B991C	5106 283989	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr051960@postgrespro.ru", "phone": "+70016224047"}
0005433407513	6B991C	8276 348831	SERGEY CHERNOV	{"email": "chernov_sergey.081964@postgrespro.ru", "phone": "+70048202802"}
0005433407514	0CF763	4473 634421	VLADIMIR ZAKHAROV	{"phone": "+70127907757"}
0005433407515	0CF763	1285 979346	NATALIYA FADEEVA	{"phone": "+70156402360"}
0005433407516	849907	8578 970969	RAVIL VOLKOV	{"email": "volkov.ravil091963@postgrespro.ru", "phone": "+70045926934"}
0005433407517	E70840	7925 675109	ILONA FILIPPOVA	{"email": "ilonafilippova_1973@postgrespro.ru", "phone": "+70374239660"}
0005433407518	7DFF28	1145 524196	EVGENIY SIDOROV	{"phone": "+70665812047"}
0005433407519	01F723	0863 642589	IRINA ZAYCEVA	{"phone": "+70596283157"}
0005433407520	01F723	5296 867127	MARINA ROMANOVA	{"email": "romanova.marina.12021964@postgrespro.ru", "phone": "+70642101033"}
0005433407521	AA6B36	6470 576492	OLEG SOKOLOV	{"phone": "+70226605194"}
0005433407522	0D84ED	8308 643321	IGOR PAVLOV	{"phone": "+70588592962"}
0005433407523	0D84ED	7125 317106	ZHANNA TIMOFEEVA	{"email": "timofeevazhanna.101975@postgrespro.ru", "phone": "+70613990519"}
0005433407524	7D7B70	4565 802208	VLADIMIR GORBUNOV	{"phone": "+70850264769"}
0005433407525	B71B40	3158 799163	YANA ERMAKOVA	{"email": "ermakova_yana1984@postgrespro.ru", "phone": "+70396241840"}
0005433407526	B71B40	1854 679414	NADEZHDA OSIPOVA	{"phone": "+70145814184"}
0005433407527	21542D	7215 951882	ELENA ABRAMOVA	{"phone": "+70741977150"}
0005433407528	21542D	5652 679032	YAROSLAV MEDVEDEV	{"email": "medvedevy.19111978@postgrespro.ru", "phone": "+70595363254"}
0005433407529	21542D	9302 247283	LYUBOV KULIKOVA	{"email": "kulikoval-06081977@postgrespro.ru", "phone": "+70848409534"}
0005433407530	3305DD	3413 008261	EVGENIYA SEMENOVA	{"phone": "+70447846247"}
0005433407531	3305DD	5974 276672	VLADIMIR PETROV	{"email": "vladimirpetrov.1976@postgrespro.ru", "phone": "+70809490482"}
0005433407532	66E882	0484 132087	ELENA SOKOLOVA	{"phone": "+70347209231"}
0005433407702	C7FD82	5296 081440	RIMMA NESTEROVA	{"phone": "+70694197011"}
0005433407533	7C50EF	8419 596812	ALEKSANDR VOROBEV	{"email": "aleksandr.vorobev121969@postgrespro.ru", "phone": "+70328387246"}
0005433407534	7C50EF	7799 828366	LYUBOV MIKHAYLOVA	{"email": "lmikhaylova.25061968@postgrespro.ru", "phone": "+70764163826"}
0005433407535	0E2996	5252 144796	ALEKSANDR PAVLOV	{"phone": "+70837604459"}
0005433407536	0E2996	8227 647557	EVDOKIYA NAZAROVA	{"phone": "+70608283953"}
0005433407537	5E8C6B	1923 923480	DENIS VOROBEV	{"phone": "+70086263325"}
0005433407538	DA6E9D	6901 056520	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey031976@postgrespro.ru", "phone": "+70535444819"}
0005433407539	ED1E30	7667 782783	YULIYA LUKYANOVA	{"email": "lukyanova_yuliya-061966@postgrespro.ru", "phone": "+70594592034"}
0005433407540	ED1E30	2653 834041	KAPITALINA SOROKINA	{"email": "kapitalina-sorokina_17101969@postgrespro.ru", "phone": "+70762198094"}
0005433407541	AD2FAA	8480 541623	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov-06061975@postgrespro.ru", "phone": "+70156465566"}
0005433407542	AD2FAA	8543 380452	ALBINA KONDRATEVA	{"email": "kondrateva_albina.21061965@postgrespro.ru", "phone": "+70473359148"}
0005433407543	EA16CF	4000 086694	ELENA SMIRNOVA	{"email": "smirnovaelena031979@postgrespro.ru", "phone": "+70230879241"}
0005433407544	EA16CF	1470 074397	RIMMA NIKOLAEVA	{"phone": "+70225393227"}
0005433407545	280524	3671 364054	YULIYA MIRONOVA	{"email": "mironova_y-081972@postgrespro.ru", "phone": "+70196164543"}
0005433407546	280524	8556 578344	OLGA POTAPOVA	{"email": "opotapova.1980@postgrespro.ru", "phone": "+70376297933"}
0005433407547	42C882	3018 092640	GALINA ROMANOVA	{"phone": "+70728349158"}
0005433407548	42C882	5836 930450	YURIY ANDREEV	{"phone": "+70497435274"}
0005433407549	42C882	6858 121537	LYUDMILA MAKAROVA	{"phone": "+70882212346"}
0005433407550	F783EC	7531 320423	NATALYA POPOVA	{"phone": "+70015159622"}
0005433407551	542A3E	3918 139556	VLADIMIR STEPANOV	{"phone": "+70552449332"}
0005433407552	542A3E	1639 649038	YULIYA LOGINOVA	{"email": "yuliya.loginova051985@postgrespro.ru", "phone": "+70610578367"}
0005433407553	EAC793	8150 137289	ANNA ARKHIPOVA	{"phone": "+70483534051"}
0005433407554	7FFB8B	0918 682704	ELENA KUZMINA	{"email": "kuzmina.e_1979@postgrespro.ru", "phone": "+70642798540"}
0005433407555	5CEBDF	3363 980874	VALENTINA ZAKHAROVA	{"email": "valentinazakharova22121986@postgrespro.ru", "phone": "+70628109212"}
0005433407556	F6E632	8125 999830	NIKOLAY ZHURAVLEV	{"email": "zhuravlev.n021977@postgrespro.ru", "phone": "+70107330477"}
0005433407557	F6E632	1448 777486	ALEKSANDR FILIPPOV	{"phone": "+70445454115"}
0005433407558	F6E632	7434 181674	NINA SCHERBAKOVA	{"email": "n-scherbakova1966@postgrespro.ru", "phone": "+70353780248"}
0005433407559	968914	0238 207018	ELENA ZOTOVA	{"phone": "+70874917963"}
0005433407560	968914	5793 215399	STANISLAV ZHURAVLEV	{"email": "zhuravlevstanislav-111965@postgrespro.ru", "phone": "+70965119799"}
0005433407561	200C93	7774 232177	LYUBOV SMIRNOVA	{"email": "smirnova_lyubov-081979@postgrespro.ru", "phone": "+70028443836"}
0005433407562	200C93	8708 220111	IRINA NIKOLAEVA	{"email": "i-nikolaeva03051970@postgrespro.ru", "phone": "+70246235430"}
0005433407563	200C93	4836 491674	ALEKSANDR FROLOV	{"email": "a-frolov_16121965@postgrespro.ru", "phone": "+70710141833"}
0005433407564	B3F72F	4862 927246	OLGA PAVLOVA	{"phone": "+70050666763"}
0005433407565	8CDD36	2536 509139	ELENA IVANOVA	{"phone": "+70547527040"}
0005433407566	9F437B	5533 832668	VALERIY VOLKOV	{"phone": "+70006375000"}
0005433407567	EA188D	2596 933259	ARTUR SAVELEV	{"email": "artursavelev-061967@postgrespro.ru", "phone": "+70441251692"}
0005433407568	A23E52	3149 331624	GULNARA NIKITINA	{"phone": "+70770435915"}
0005433407569	A77B7F	3595 698556	TAMARA ZHURAVLEVA	{"phone": "+70437323613"}
0005433407570	269CDC	3578 875515	DMITRIY FEDOTOV	{"phone": "+70337535664"}
0005433407571	7230DB	2458 454704	ALEKSANDRA BARANOVA	{"phone": "+70130390885"}
0005433407572	8ED076	1735 130142	VALERIY DENISOV	{"email": "denisov.valeriy02121971@postgrespro.ru", "phone": "+70778070605"}
0005433407573	8F6D47	7483 518807	KIRILL MIKHAYLOV	{"email": "kirill.mikhaylov.071972@postgrespro.ru", "phone": "+70053331291"}
0005433407574	8F6D47	4936 883922	ANNA ROMANOVA	{"phone": "+70713107382"}
0005433407575	6785B3	0755 996126	SERGEY MARTYNOV	{"email": "sergey.martynov-1964@postgrespro.ru", "phone": "+70664024445"}
0005433407576	6785B3	3457 077812	GALINA FEDOROVA	{"email": "g_fedorova_26051976@postgrespro.ru", "phone": "+70763028376"}
0005433407577	43C177	2734 720546	EDUARD MAKAROV	{"phone": "+70647361661"}
0005433407578	43C177	9341 772571	ANNA CHERNOVA	{"phone": "+70548232857"}
0005433407579	43C177	1361 334650	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.1966@postgrespro.ru", "phone": "+70531449583"}
0005433407580	7DB300	9441 744329	VYACHESLAV FROLOV	{"phone": "+70427223895"}
0005433407581	7DB300	6021 253096	NADEZHDA ARKHIPOVA	{"phone": "+70510155742"}
0005433407582	CA1724	3520 165895	RAFIS ILIN	{"email": "ilin_rafis1980@postgrespro.ru", "phone": "+70259603689"}
0005433407583	CA1724	2024 712841	MARGARITA ROMANOVA	{"email": "margarita_romanova-19121981@postgrespro.ru", "phone": "+70691686728"}
0005433407584	E870D3	3414 572338	OLEG TARASOV	{"phone": "+70225969115"}
0005433407585	E870D3	9857 907306	VYACHESLAV PETROV	{"phone": "+70215483848"}
0005433407586	402603	8128 321679	ALEKSANDR SERGEEV	{"phone": "+70609156590"}
0005433407587	993168	0074 961240	ANDREY DENISOV	{"email": "adenisov25101973@postgrespro.ru", "phone": "+70199094362"}
0005433407588	FF2D81	0576 568884	OLGA KUZNECOVA	{"phone": "+70619839475"}
0005433407589	FF2D81	7074 688197	MIKHAIL SOKOLOV	{"email": "mikhailsokolov.1969@postgrespro.ru", "phone": "+70086228842"}
0005433407590	42DC27	2454 548139	TATYANA MOISEEVA	{"phone": "+70188091127"}
0005433407591	42DC27	8984 356622	DENIS ANDREEV	{"phone": "+70538740421"}
0005433407592	9218F8	0181 224082	BORIS VLASOV	{"phone": "+70122412718"}
0005433407593	16C5F9	9997 221537	VITALIY SAVELEV	{"phone": "+70974164473"}
0005433407594	16C5F9	5399 749014	ALEKSANDRA STEPANOVA	{"phone": "+70857927184"}
0005433407595	4F1602	4802 742263	VLADIMIR VOROBEV	{"email": "vorobev_v-11111979@postgrespro.ru", "phone": "+70729064394"}
0005433407596	4F1602	4455 921055	GENNADIY FOMIN	{"phone": "+70253454624"}
0005433407597	803974	0936 324203	ANATOLIY KRASNOV	{"phone": "+70089802144"}
0005433407598	BD6FCB	0328 937202	TIMUR CHERNOV	{"email": "t.chernov_031964@postgrespro.ru", "phone": "+70318961863"}
0005433407599	1DE061	8349 725562	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr16021977@postgrespro.ru", "phone": "+70418627550"}
0005433407600	09B4C8	0082 071109	NADEZHDA MALYSHEVA	{"email": "nadezhdamalysheva.1970@postgrespro.ru", "phone": "+70914691592"}
0005433407601	D59DF0	1183 731216	TATYANA GERASIMOVA	{"email": "gerasimova_t1964@postgrespro.ru", "phone": "+70918976543"}
0005433407602	666476	6131 454085	ARTUR ALEKSEEV	{"phone": "+70400783660"}
0005433407603	14EE0E	2662 058232	NINA GAVRILOVA	{"phone": "+70756405288"}
0005433407604	14EE0E	4182 334682	MARINA NIKOLAEVA	{"phone": "+70835802773"}
0005433407605	D8D10A	1313 591832	ANDREY SMIRNOV	{"phone": "+70721984170"}
0005433407606	D8D10A	3687 071569	SVETLANA FROLOVA	{"phone": "+70804391077"}
0005433407607	B44FF5	1495 906555	NIKITA SERGEEV	{"email": "nikita_sergeev-081966@postgrespro.ru", "phone": "+70480392673"}
0005433407608	71C5A2	9719 481089	MIKHAIL MOROZOV	{"phone": "+70998513372"}
0005433407609	39A713	5934 145741	ARTUR KAZAKOV	{"email": "artur_kazakov_1969@postgrespro.ru", "phone": "+70479901520"}
0005433407610	A50FD1	5254 758690	DARYA KAZAKOVA	{"phone": "+70025764106"}
0005433407611	A50FD1	9643 876537	ANASTASIYA MAKAROVA	{"phone": "+70513917159"}
0005433407612	C2BBD3	9924 986051	NIKOLAY TARASOV	{"email": "tarasovn-12011977@postgrespro.ru", "phone": "+70941838765"}
0005433407613	C2BBD3	1521 244948	VIKTORIYA MOROZOVA	{"phone": "+70344414036"}
0005433407614	C2BBD3	3135 939201	ANATOLIY KOROLEV	{"email": "koroleva1969@postgrespro.ru", "phone": "+70304167157"}
0005433407615	1BF12D	6121 360633	GALINA ANDREEVA	{"email": "galinaandreeva_07021963@postgrespro.ru", "phone": "+70200757118"}
0005433407616	75A759	8671 641804	ANNA ILINA	{"phone": "+70328293313"}
0005433407617	381B8B	7067 725037	ANNA BELYAEVA	{"phone": "+70967985123"}
0005433407618	381B8B	4800 226459	GEORGIY EGOROV	{"email": "egorov_georgiy-031985@postgrespro.ru", "phone": "+70180307652"}
0005433407619	608D15	5003 574857	GALINA BELOVA	{"email": "gbelova-1969@postgrespro.ru", "phone": "+70777315783"}
0005433407620	F5C834	6566 247090	DIANA KRASNOVA	{"email": "dkrasnova091976@postgrespro.ru", "phone": "+70055620066"}
0005433407621	5F3D62	7228 474983	DARYA IVANOVA	{"email": "ivanova-darya.1974@postgrespro.ru", "phone": "+70970277351"}
0005433407622	5F3D62	3140 596443	PETR NIKOLAEV	{"email": "nikolaev_p.1970@postgrespro.ru", "phone": "+70932010255"}
0005433407623	3EC914	7446 338250	SERGEY MOISEEV	{"email": "sergey.moiseev-07101971@postgrespro.ru", "phone": "+70150319489"}
0005433407624	978D1D	5795 947543	YURIY KRASNOV	{"phone": "+70796372443"}
0005433407625	54B943	9980 590032	NIKOLAY IVANOV	{"email": "nikolay.ivanov.051964@postgrespro.ru", "phone": "+70848140502"}
0005433407626	19462F	5118 608363	DANIL CHERNOV	{"phone": "+70623143064"}
0005433407627	9E4B65	4423 467541	ANASTASIYA SAVELEVA	{"phone": "+70665017790"}
0005433407628	33AD30	5005 744816	ANATOLIY POPOV	{"email": "popov.anatoliy.061961@postgrespro.ru", "phone": "+70128185470"}
0005433407629	49F867	8194 574533	GALINA KAZAKOVA	{"phone": "+70144584884"}
0005433407630	C78D85	0214 491111	MARIYA BORISOVA	{"email": "mariya-borisova_1970@postgrespro.ru", "phone": "+70510171499"}
0005433407631	88FE95	0386 711962	VIKTORIYA KARPOVA	{"email": "viktoriya-karpova-091974@postgrespro.ru", "phone": "+70363332504"}
0005433407632	88FE95	0705 397322	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov_1986@postgrespro.ru", "phone": "+70371623232"}
0005433407633	EC1A76	8303 052326	ALEKSANDR SOKOLOV	{"phone": "+70013432239"}
0005433407634	EF9FD5	1713 287456	OLEG ZAYCEV	{"phone": "+70230011077"}
0005433407635	EF9FD5	5886 842741	ALEKSANDR VASILEV	{"phone": "+70092580602"}
0005433407636	EF9FD5	0143 206634	NIKITA KISELEV	{"email": "kiselev.n_021967@postgrespro.ru", "phone": "+70692636788"}
0005433407637	7D7F46	2705 727753	SERGEY GORBUNOV	{"phone": "+70876569595"}
0005433407638	A740F3	5774 868490	IVAN SAVELEV	{"email": "isavelev25071971@postgrespro.ru", "phone": "+70222851572"}
0005433407639	A1DBDB	7814 514316	IVAN ZAKHAROV	{"phone": "+70999383103"}
0005433407640	A1DBDB	2839 632406	LARISA VASILEVA	{"phone": "+70438266970"}
0005433407641	F61C88	7980 255146	MATVEY IVANOV	{"phone": "+70488201075"}
0005433407642	F61C88	5329 940215	SVETLANA TITOVA	{"phone": "+70114648543"}
0005433407643	62F611	4757 013276	ALBERT STEPANOV	{"email": "stepanov_albert-1965@postgrespro.ru", "phone": "+70724743997"}
0005433407644	3BB4AE	2096 394535	OLESYA MARTYNOVA	{"email": "o_martynova_04031976@postgrespro.ru", "phone": "+70219631894"}
0005433407645	07AA35	8313 622205	TATYANA RODIONOVA	{"email": "t.rodionova.22111974@postgrespro.ru", "phone": "+70305246586"}
0005433407646	07AA35	0637 768485	VERA SIDOROVA	{"phone": "+70655313775"}
0005433407647	240923	1517 899491	ANATOLIY POPOV	{"phone": "+70709111180"}
0005433407648	368B89	7629 311157	LARISA EGOROVA	{"phone": "+70407086198"}
0005433407649	368B89	2390 419602	SERGEY MOROZOV	{"email": "s-morozov_121960@postgrespro.ru", "phone": "+70354778662"}
0005433407650	928BAE	3133 579191	VALENTINA ZOTOVA	{"email": "zotova-v_1969@postgrespro.ru", "phone": "+70141244578"}
0005433407651	4A6E28	0124 647320	VIKTOR ALEKSEEV	{"phone": "+70408773344"}
0005433407652	4A6E28	8959 800097	ELENA ROMANOVA	{"phone": "+70564868435"}
0005433407653	DE2E3D	3618 806467	ALEKSEY BELOV	{"email": "belova08061971@postgrespro.ru", "phone": "+70517567301"}
0005433407654	DE2E3D	7962 428557	ANTON PETROV	{"phone": "+70744024364"}
0005433407655	3B2097	5204 104898	SVETLANA EGOROVA	{"email": "egorova_s.021978@postgrespro.ru", "phone": "+70642365490"}
0005433407656	A7E6B0	7825 656820	TATYANA ALEKSEEVA	{"phone": "+70775383114"}
0005433407657	78EDC9	2300 361722	PETR ANDREEV	{"phone": "+70039132984"}
0005433407658	78EDC9	5799 161271	ANDREY ZHUKOV	{"phone": "+70608563513"}
0005433407659	78EDC9	7359 746189	TAMARA LAZAREVA	{"email": "lazareva.t.07031973@postgrespro.ru", "phone": "+70960503251"}
0005433407660	027CE2	0860 620903	KLAVDIYA DAVYDOVA	{"phone": "+70762401601"}
0005433407661	1EFE68	5394 267781	YURIY ROMANOV	{"email": "yuriy.romanov.121966@postgrespro.ru", "phone": "+70216667048"}
0005433407662	1EFE68	9084 343553	ELENA VLASOVA	{"phone": "+70150180063"}
0005433407663	1F8D81	9557 147701	NINA FROLOVA	{"phone": "+70207201157"}
0005433407664	1F8D81	6078 676856	ARTUR FROLOV	{"email": "frolov_a.17121974@postgrespro.ru", "phone": "+70253567094"}
0005433407665	2CA220	3846 266691	ARTUR GUSEV	{"phone": "+70884568428"}
0005433407666	B238BA	6720 617729	SERGEY NIKITIN	{"email": "sergey-nikitin_15041963@postgrespro.ru", "phone": "+70986949458"}
0005433407667	CDE1EA	7863 161500	NIKOLAY POPOV	{"phone": "+70709529074"}
0005433407668	44BBA2	5799 121525	ANNA MOROZOVA	{"email": "morozovaanna27061967@postgrespro.ru", "phone": "+70521445672"}
0005433407669	6B1629	4764 532259	TATYANA MATVEEVA	{"phone": "+70896847326"}
0005433407670	6B1629	4895 102742	ZINAIDA KULIKOVA	{"email": "z_kulikova.29101976@postgrespro.ru", "phone": "+70652205518"}
0005433407671	16178A	1725 785241	VLADIMIR KULIKOV	{"email": "v.kulikov_021985@postgrespro.ru", "phone": "+70367391805"}
0005433407672	16178A	7266 340061	ELMIRA TARASOVA	{"email": "elmira-tarasova.051981@postgrespro.ru", "phone": "+70856919327"}
0005433407673	CABF7E	8872 952729	SVETLANA NAUMOVA	{"email": "naumova-s_061979@postgrespro.ru", "phone": "+70780618311"}
0005433407674	CABF7E	3916 962169	ILYA MOROZOV	{"phone": "+70230476465"}
0005433407675	1CF534	1781 805818	DMITRIY EGOROV	{"email": "egorov_dmitriy-051969@postgrespro.ru", "phone": "+70337671452"}
0005433407676	57F326	3736 092611	ALEKSANDR VOLKOV	{"phone": "+70366522885"}
0005433407677	749132	2558 521104	TAMARA SERGEEVA	{"email": "tamara.sergeeva031972@postgrespro.ru", "phone": "+70722431055"}
0005433407678	FAAAE4	3058 734473	ANNA KULIKOVA	{"phone": "+70024854349"}
0005433407679	FAAAE4	2842 232652	NIKOLAY SERGEEV	{"email": "sergeev.n.051973@postgrespro.ru", "phone": "+70982982977"}
0005433407680	E8BE16	7890 176287	SOFYA ANDREEVA	{"phone": "+70694886889"}
0005433407681	E8BE16	2355 265129	DMITRIY IVANOV	{"phone": "+70568133171"}
0005433407682	88F582	3024 889724	FEDOR SOKOLOV	{"email": "f.sokolov_12061955@postgrespro.ru", "phone": "+70318848454"}
0005433407683	CA448A	5756 084233	YURIY NOVIKOV	{"email": "novikovy021986@postgrespro.ru", "phone": "+70330008689"}
0005433407684	AD47E3	5368 954212	IRINA SERGEEVA	{"email": "i_sergeeva_1970@postgrespro.ru", "phone": "+70659769185"}
0005433407685	AD47E3	8256 644786	ALEVTINA MOROZOVA	{"phone": "+70016445672"}
0005433407686	AE8723	6609 188302	VALERIY IVANOV	{"email": "v_ivanov_1964@postgrespro.ru", "phone": "+70535444961"}
0005433407687	ECB04B	6124 042525	VALENTINA BARANOVA	{"phone": "+70032723839"}
0005433407688	ECB04B	7902 135986	ROMAN MOROZOV	{"email": "morozov.r_21111983@postgrespro.ru", "phone": "+70176499234"}
0005433407689	B4208F	2859 122243	ARTEM ZAYCEV	{"email": "zaycev.a10121981@postgrespro.ru", "phone": "+70917343478"}
0005433407690	4F2FB7	1937 948179	LYUDMILA MASLOVA	{"email": "l-maslova.1976@postgrespro.ru", "phone": "+70913525344"}
0005433407691	29A824	3052 049386	VLADIMIR FOMIN	{"email": "vladimir_fomin-061972@postgrespro.ru", "phone": "+70280323570"}
0005433407692	29A824	2632 774458	NADEZHDA GAVRILOVA	{"phone": "+70636273857"}
0005433407693	3EFF29	2978 081850	VERONIKA KALININA	{"phone": "+70532939402"}
0005433407694	3EFF29	2725 153781	NATALYA KAZAKOVA	{"phone": "+70668260820"}
0005433407695	3EB3F0	6848 084109	NIKOLAY POPOV	{"phone": "+70599299271"}
0005433407696	3EB3F0	8598 284001	LEONID DAVYDOV	{"email": "leoniddavydov.13021964@postgrespro.ru", "phone": "+70911294249"}
0005433407697	E2C7F7	4450 150110	EVGENIY KOZLOV	{"email": "kozlovevgeniy-1966@postgrespro.ru", "phone": "+70235122671"}
0005433407698	52FEA0	1045 201496	IGOR IVANOV	{"email": "igor-ivanov.1973@postgrespro.ru", "phone": "+70342458970"}
0005433407699	52FEA0	2525 969742	ANTON ANDREEV	{"phone": "+70524047644"}
0005433407700	52FEA0	3215 233942	LYUDMILA KRASNOVA	{"email": "krasnovalyudmila.061965@postgrespro.ru", "phone": "+70270338343"}
0005433407701	9E512F	0712 690448	VALERIY PETROV	{"phone": "+70945669065"}
0005433407703	B673CA	1022 692134	ANTON IVANOV	{"email": "ivanov_anton.061988@postgrespro.ru", "phone": "+70989393291"}
0005433407704	B673CA	5956 938633	ANASTASIYA PETROVA	{"email": "petrovaanastasiya-1966@postgrespro.ru", "phone": "+70515984864"}
0005433407705	216856	7181 322008	TATYANA VOLKOVA	{"email": "volkovat1977@postgrespro.ru", "phone": "+70219474500"}
0005433407706	4F10C5	0005 092980	VYACHESLAV OSIPOV	{"email": "osipovvyacheslav_07021974@postgrespro.ru", "phone": "+70498285448"}
0005433407707	72C733	5122 913617	OLGA MELNIKOVA	{"phone": "+70190398984"}
0005433407708	72C733	9742 571516	LYUBOV IVANOVA	{"phone": "+70972182093"}
0005433407709	78EC8D	9318 791704	YULIYA GRISHINA	{"phone": "+70125055037"}
0005433407710	862A6F	2170 406056	POLINA NESTEROVA	{"phone": "+70893438649"}
0005433407711	862A6F	1394 413120	VALENTINA POPOVA	{"email": "valentina.popova_081963@postgrespro.ru", "phone": "+70437096358"}
0005433407712	C78F99	2959 728198	MIKHAIL KUZNECOV	{"email": "m.kuznecov26051958@postgrespro.ru", "phone": "+70391755541"}
0005433415378	CFB322	6870 526377	SERGEY ROMANOV	{"email": "s.romanov_121976@postgrespro.ru", "phone": "+70769732550"}
0005433415379	8C6D93	2810 477523	TAMARA FOMINA	{"email": "t-fomina.1966@postgrespro.ru", "phone": "+70200829536"}
0005433415380	452090	2905 145681	SERGEY KULIKOV	{"phone": "+70456385715"}
0005433415381	00E2A4	0996 400408	PAVEL PAVLOV	{"email": "pavel-pavlov1975@postgrespro.ru", "phone": "+70064603743"}
0005433415382	00E2A4	2837 668077	FAIL ANTONOV	{"email": "failantonov041970@postgrespro.ru", "phone": "+70358902163"}
0005433415383	79A446	9340 081972	OLGA OSIPOVA	{"phone": "+70989134257"}
0005433415384	4893A1	8914 177573	VLADIMIR NOVIKOV	{"email": "novikov.v_091971@postgrespro.ru", "phone": "+70314932635"}
0005433415385	83D020	7892 191894	LARISA SOKOLOVA	{"phone": "+70021431830"}
0005433415386	55DC07	5350 029555	VIKTOR KISELEV	{"phone": "+70530783184"}
0005433415387	054793	5925 889786	SERGEY DENISOV	{"phone": "+70653743303"}
0005433415388	0201F5	9323 221589	SERGEY FEDOTOV	{"phone": "+70029884151"}
0005433415389	661B5B	5830 813533	VALERIY NOVIKOV	{"phone": "+70849031929"}
0005433415390	661B5B	3259 886917	GERMAN KUZNECOV	{"email": "german-kuznecov_021976@postgrespro.ru", "phone": "+70296873125"}
0005433415391	661B5B	3236 321811	LYUDMILA MATVEEVA	{"email": "lyudmila-matveeva_071971@postgrespro.ru", "phone": "+70557210030"}
0005433415392	D7DFEE	6434 155509	PAVEL TIKHONOV	{"email": "ptikhonov_1970@postgrespro.ru", "phone": "+70648668765"}
0005433415393	D7DFEE	2958 834394	ANASTASIYA KAZAKOVA	{"email": "kazakovaanastasiya_1971@postgrespro.ru", "phone": "+70664914825"}
0005433415394	021425	0871 888018	IGOR AFANASEV	{"email": "i-afanasev-021965@postgrespro.ru", "phone": "+70249627024"}
0005433415395	A0A28E	2522 189932	VALENTINA ANDREEVA	{"email": "v-andreeva1965@postgrespro.ru", "phone": "+70894036309"}
0005433415396	A0A28E	6640 511787	OLGA BORISOVA	{"phone": "+70420766072"}
0005433415397	B99583	5018 872106	ALEKSANDR SEMENOV	{"phone": "+70114119117"}
0005433415398	DDAF14	6884 715747	POLINA PAVLOVA	{"phone": "+70441949938"}
0005433415399	1101EE	5567 600484	OLGA TROFIMOVA	{"email": "otrofimova_15011985@postgrespro.ru", "phone": "+70229324535"}
0005433415400	A9E285	1490 113402	VLADIMIR MOROZOV	{"phone": "+70916535914"}
0005433415401	DF8E8F	2357 629030	NATALYA BARANOVA	{"email": "baranova-n.1981@postgrespro.ru", "phone": "+70191297139"}
0005433415402	556B2F	3809 516393	ANASTASIYA DMITRIEVA	{"email": "dmitrieva-a1960@postgrespro.ru", "phone": "+70861101421"}
0005433415403	FEB9BD	4069 943194	IRAIDA BOGDANOVA	{"phone": "+70090248619"}
0005433415404	FEB9BD	0810 362183	TATYANA NIKITINA	{"email": "nikitina.tatyana-031973@postgrespro.ru", "phone": "+70890181944"}
0005433415405	FEB9BD	5216 078032	EVGENIY CHERNOV	{"phone": "+70909936291"}
0005433415406	30E1AB	1713 635736	EKATERINA ROMANOVA	{"email": "e.romanova_11111971@postgrespro.ru", "phone": "+70420378824"}
0005433415407	413A00	0684 629247	SERGEY ALEKSEEV	{"phone": "+70148505899"}
0005433415408	B7C02F	6023 225459	IGOR MATVEEV	{"phone": "+70180058820"}
0005433415409	19D9F9	1021 078576	NATALYA LEBEDEVA	{"email": "lebedevan.1961@postgrespro.ru", "phone": "+70956710188"}
0005433415410	756F7F	2032 274205	NATALYA RYABOVA	{"email": "n_ryabova.20121974@postgrespro.ru", "phone": "+70576343701"}
0005433415411	AF4F92	6666 217884	ANTON IVANOV	{"phone": "+70111220101"}
0005433415412	AF4F92	0071 574155	NIKOLAY KISELEV	{"email": "kiselev.n-27111980@postgrespro.ru", "phone": "+70510735246"}
0005433415413	9B32EA	8613 361434	ARINA ROMANOVA	{"email": "romanovaa-051963@postgrespro.ru", "phone": "+70369726736"}
0005433415414	D36F41	4670 717304	VIOLETTA MATVEEVA	{"email": "vmatveeva_29091963@postgrespro.ru", "phone": "+70336289027"}
0005433415415	514E8B	3724 067482	ALEKSEY MIRONOV	{"email": "a-mironov-021976@postgrespro.ru", "phone": "+70159120436"}
0005433415416	30DCBA	9823 765033	VLADIMIR KAZAKOV	{"phone": "+70291235577"}
0005433415417	30DCBA	6896 247068	RUSTAM KAZAKOV	{"phone": "+70397971888"}
0005433415418	E519ED	9766 014158	NADEZHDA OSIPOVA	{"email": "osipova.nadezhda_1977@postgrespro.ru", "phone": "+70389751093"}
0005433415419	E519ED	8656 788818	LYUDMILA MIRONOVA	{"phone": "+70157322605"}
0005433415420	7AB18F	8362 544516	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr-101965@postgrespro.ru", "phone": "+70109626898"}
0005433415421	BAD3FD	8744 852191	EKATERINA NAUMOVA	{"phone": "+70530793621"}
0005433415422	BAD3FD	9821 741394	LARISA SEMENOVA	{"email": "semenova-larisa_1959@postgrespro.ru", "phone": "+70154477064"}
0005433415423	59E9CC	5664 608292	ARINA ZAKHAROVA	{"phone": "+70263454195"}
0005433415424	F59E20	0057 940501	ANDREY IVANOV	{"phone": "+70569546667"}
0005433415425	F59E20	6899 305003	VLADIMIR VASILEV	{"phone": "+70981992457"}
0005433415426	419736	4324 417705	ANASTASIYA FADEEVA	{"phone": "+70856701662"}
0005433415427	95365E	6783 424816	RAISA FROLOVA	{"phone": "+70417659930"}
0005433415428	95365E	2139 337660	VIKTOR MARTYNOV	{"email": "martynovv28031979@postgrespro.ru", "phone": "+70644830810"}
0005433415429	B8F011	0723 197125	LIDIYA KUZNECOVA	{"email": "lidiya.kuznecova-091975@postgrespro.ru", "phone": "+70775974389"}
0005433415430	B8F011	3162 498353	ANGELINA EGOROVA	{"email": "egorovaangelina-02071963@postgrespro.ru", "phone": "+70287241899"}
0005433415431	611D61	7759 509737	VERA ZAYCEVA	{"phone": "+70713635233"}
0005433415432	611D61	4198 804588	MIKHAIL TIKHONOV	{"phone": "+70977029201"}
0005433415433	159AE2	9968 924661	IRINA ROMANOVA	{"phone": "+70134777095"}
0005433415434	1E2FAE	2613 644123	YULIYA SMIRNOVA	{"phone": "+70481560220"}
0005433415435	76ACD6	0540 671658	NIKOLAY GAVRILOV	{"phone": "+70680977477"}
0005433415436	76ACD6	2817 132835	ANASTASIYA SEMENOVA	{"email": "semenova-anastasiya.011971@postgrespro.ru", "phone": "+70135307972"}
0005433415437	DDD82A	6394 999741	EKATERINA KOROLEVA	{"email": "e-koroleva021972@postgrespro.ru", "phone": "+70018423448"}
0005433415438	DDD82A	0487 598934	VYACHESLAV SIDOROV	{"email": "vsidorov011990@postgrespro.ru", "phone": "+70314433725"}
0005433415556	4723CA	0208 919607	ALEKSANDRA ERMAKOVA	{"phone": "+70045166055"}
0005433415439	1D8799	5956 661484	VYACHESLAV NIKOLAEV	{"email": "nikolaev-v-20061969@postgrespro.ru", "phone": "+70023128411"}
0005433415440	1D8799	3444 178138	SERGEY POPOV	{"email": "sergey-popov22021985@postgrespro.ru", "phone": "+70121825945"}
0005433415441	8BAB10	7796 175228	NIKOLAY BONDARENKO	{"phone": "+70862758781"}
0005433415442	F3367D	3897 620515	OLGA NAZAROVA	{"email": "nazarovaolga-16021983@postgrespro.ru", "phone": "+70714349042"}
0005433415443	F3367D	3776 121654	MARGARITA MEDVEDEVA	{"email": "medvedeva.margarita-26011984@postgrespro.ru", "phone": "+70570332485"}
0005433415444	F3367D	8639 245372	EKATERINA KRASNOVA	{"email": "krasnova.ekaterina_11061979@postgrespro.ru", "phone": "+70852263259"}
0005433415445	18042B	7348 676616	VLADA BORISOVA	{"phone": "+70295858400"}
0005433415446	65A6EA	0533 182734	MIKHAIL NAZAROV	{"phone": "+70858189738"}
0005433415447	65A6EA	1014 210840	MAKSIM GORBUNOV	{"email": "gorbunovmaksim.011972@postgrespro.ru", "phone": "+70397745935"}
0005433415448	65A6EA	4384 907400	ALEKSANDR ABRAMOV	{"email": "abramov-aleksandr23021979@postgrespro.ru", "phone": "+70214255573"}
0005433415449	65A6EA	1702 488287	VASILIY IVANOV	{"phone": "+70543650843"}
0005433415450	65A6EA	2482 783928	GEVORG ABRAMOV	{"phone": "+70515089183"}
0005433415451	2AA5C4	0483 332108	EVGENIY ZHUKOV	{"phone": "+70392195455"}
0005433415452	2AA5C4	9406 917811	ARTEM ROMANOV	{"email": "aromanov_1961@postgrespro.ru", "phone": "+70747820289"}
0005433415453	B60A16	0313 862523	SERGEY PAVLOV	{"phone": "+70234925096"}
0005433415454	BD8070	8978 472861	YURIY BORISOV	{"email": "borisov.y-02111970@postgrespro.ru", "phone": "+70892651419"}
0005433415455	8A8F7B	6606 130944	EVGENIY YAKOVLEV	{"phone": "+70633335802"}
0005433415456	B58B43	8869 352401	VLADIMIR OSIPOV	{"phone": "+70693616729"}
0005433415457	F3D236	8803 137621	ANTON KUZNECOV	{"email": "anton_kuznecov-1972@postgrespro.ru", "phone": "+70140952851"}
0005433415458	E2C9AF	3365 289541	SERGEY SERGEEV	{"phone": "+70873652684"}
0005433415459	28D5A2	4933 591581	TATYANA ABRAMOVA	{"email": "abramova_t_08081979@postgrespro.ru", "phone": "+70666889445"}
0005433415460	4C3DB8	9701 858222	VLADIMIR KUZNECOV	{"email": "kuznecov.v_081964@postgrespro.ru", "phone": "+70132659099"}
0005433415461	4C3DB8	2111 025788	TATYANA NAZAROVA	{"phone": "+70536227453"}
0005433415462	4C3DB8	3970 715340	TAMARA NOVIKOVA	{"email": "novikova-t.1975@postgrespro.ru", "phone": "+70788392828"}
0005433415463	E057C1	3382 414717	NIKOLAY PAVLOV	{"email": "n-pavlov-121962@postgrespro.ru", "phone": "+70791700015"}
0005433415464	E057C1	7011 421159	ARTUR IVANOV	{"phone": "+70444675427"}
0005433415465	5AE04E	4345 030772	DMITRIY ZAKHAROV	{"email": "zakharov.d101966@postgrespro.ru", "phone": "+70206851121"}
0005433415466	71946C	1249 785135	IGOR KUZNECOV	{"email": "igor.kuznecov041965@postgrespro.ru", "phone": "+70187548258"}
0005433415467	71946C	5738 819114	VLADIMIR ALEKSEEV	{"phone": "+70481739484"}
0005433415468	71946C	5167 857001	DMITRIY GERASIMOV	{"email": "dmitriy.gerasimov_111977@postgrespro.ru", "phone": "+70935005940"}
0005433415469	12F581	1561 904583	OLEG PAVLOV	{"phone": "+70102510061"}
0005433415470	DDAD26	3037 737965	MARIYA STEPANOVA	{"phone": "+70535717164"}
0005433415471	1E392D	6232 439183	EKATERINA NAZAROVA	{"phone": "+70349543615"}
0005433415472	1E392D	3995 954559	MAKSIM GRIGOREV	{"email": "maksim.grigorev_06051987@postgrespro.ru", "phone": "+70687428030"}
0005433415473	F8FB35	6270 207560	ANTONINA TROFIMOVA	{"email": "antoninatrofimova.06011979@postgrespro.ru", "phone": "+70761736320"}
0005433415474	D2AAAF	0844 046406	VERA KOVALEVA	{"email": "vkovaleva-1978@postgrespro.ru", "phone": "+70096967124"}
0005433415475	FE74B4	7622 861933	SVETLANA SOROKINA	{"email": "svetlanasorokina.1983@postgrespro.ru", "phone": "+70234727742"}
0005433415476	90E78D	4583 631106	MARIYA ANDREEVA	{"phone": "+70546752165"}
0005433415477	829005	3460 237603	LYUBOV IVANOVA	{"email": "l-ivanova-07071970@postgrespro.ru", "phone": "+70006407384"}
0005433415478	C1A9CA	1493 221303	ALEKSEY KUZMIN	{"email": "kuzmin-aleksey1972@postgrespro.ru", "phone": "+70809608011"}
0005433415479	0E2A21	5015 061627	ILYA MAKAROV	{"email": "i_makarov.09051970@postgrespro.ru", "phone": "+70711983832"}
0005433415480	0E2A21	8537 809421	FEDOR PETROV	{"email": "petrov.f-23121965@postgrespro.ru", "phone": "+70668839991"}
0005433415481	383719	9432 954622	RUSTEM NIKOLAEV	{"email": "nikolaev-rustem-15031980@postgrespro.ru", "phone": "+70457267395"}
0005433415482	383719	4940 375610	MIKHAIL NIKITIN	{"email": "nikitin-mikhail_081976@postgrespro.ru", "phone": "+70521129629"}
0005433415483	CF0291	4826 626474	IGOR NIKOLAEV	{"phone": "+70687775346"}
0005433415484	E1A6F8	8240 628383	STEPAN MAKSIMOV	{"phone": "+70995331624"}
0005433415485	5AF3F9	2975 664100	ELENA NAZAROVA	{"email": "nazarova-e-27081967@postgrespro.ru", "phone": "+70025274017"}
0005433415486	BB7CE1	3097 230256	VITALIY KONOVALOV	{"phone": "+70937641496"}
0005433415487	BB7CE1	4164 068101	OLGA MIRONOVA	{"email": "mironova_olga_1961@postgrespro.ru", "phone": "+70549279556"}
0005433415488	BB7CE1	4599 426521	TATYANA KARPOVA	{"email": "t_karpova.1975@postgrespro.ru", "phone": "+70179059975"}
0005433415489	2D9159	9901 285524	GALINA POPOVA	{"email": "galinapopova_07091972@postgrespro.ru", "phone": "+70330322723"}
0005433415490	F2C122	9555 328827	VLADIMIR MOISEEV	{"email": "moiseev_v_1968@postgrespro.ru", "phone": "+70869698453"}
0005433415491	A1959E	6469 832568	EGOR FEDOROV	{"phone": "+70844564057"}
0005433415492	E9A5C6	6676 189298	EVGENIY MIKHAYLOV	{"phone": "+70541515416"}
0005433415493	B6247F	9399 447976	NIKOLAY TARASOV	{"phone": "+70314711800"}
0005433415494	B6247F	7365 603314	ANASTASIYA MEDVEDEVA	{"phone": "+70952434016"}
0005433415495	4D3AED	9210 524947	VALERIYA ANDREEVA	{"email": "valeriya.andreeva-12101970@postgrespro.ru", "phone": "+70856690312"}
0005433415496	374318	1250 992427	ALEKSEY VOLKOV	{"email": "volkov.aleksey011970@postgrespro.ru", "phone": "+70710704076"}
0005433415675	FDAD43	8825 914888	ARTEM SOROKIN	{"phone": "+70086353681"}
0005433415497	94CB96	0909 854145	GALINA MELNIKOVA	{"email": "melnikova.galina-1965@postgrespro.ru", "phone": "+70995471235"}
0005433415498	AC3964	4334 166798	OLGA KOROLEVA	{"email": "korolevaolga_1987@postgrespro.ru", "phone": "+70045754204"}
0005433415499	9CD56F	1198 345408	SERGEY ROMANOV	{"email": "sromanov_101984@postgrespro.ru", "phone": "+70258268525"}
0005433415500	2440DD	4928 357322	SERGEY POPOV	{"phone": "+70928854045"}
0005433415501	2440DD	6927 427127	ANDREY MAKAROV	{"email": "makarov.andrey_25041982@postgrespro.ru", "phone": "+70852554101"}
0005433415502	2440DD	0218 799407	MIKHAIL MATVEEV	{"email": "mikhail_matveev_071964@postgrespro.ru", "phone": "+70880213354"}
0005433415503	D12855	3092 879166	LYUDMILA MAKAROVA	{"email": "makarova-l_22041974@postgrespro.ru", "phone": "+70362650221"}
0005433415504	8979E3	4494 695221	SERGEY STEPANOV	{"email": "stepanov.sergey-31071977@postgrespro.ru", "phone": "+70748377309"}
0005433415505	58AE1C	6423 336864	LYUBOV KONOVALOVA	{"phone": "+70027346183"}
0005433415506	58AE1C	9015 345033	ANASTASIYA KUDRYASHOVA	{"phone": "+70610499909"}
0005433415507	18BCAD	7880 153044	IGNAT EGOROV	{"phone": "+70447426671"}
0005433415508	18BCAD	4158 118068	EMIL ALEKSANDROV	{"phone": "+70506620818"}
0005433415509	6803EF	4276 417303	VLADIMIR BARANOV	{"phone": "+70556439116"}
0005433415510	5CF76C	7225 776400	LIDIYA CHERNOVA	{"email": "chernova-lidiya.121970@postgrespro.ru", "phone": "+70931009562"}
0005433415511	5CF76C	9043 067823	ILYA KOROLEV	{"phone": "+70986911780"}
0005433415512	90BA1E	3311 350308	VLADIMIR MARTYNOV	{"phone": "+70789401395"}
0005433415513	07A573	0963 512990	MIKHAIL GERASIMOV	{"email": "mikhailgerasimov-1987@postgrespro.ru", "phone": "+70074970060"}
0005433415514	07A573	5646 397064	DARYA MALYSHEVA	{"phone": "+70738017215"}
0005433415515	7E80D1	6010 020439	ELENA NAZAROVA	{"phone": "+70363460273"}
0005433415516	EBA789	2214 103193	ELENA ALEKSEEVA	{"phone": "+70913943751"}
0005433415517	0BCCE1	5074 045758	ANNA BORISOVA	{"email": "borisova_a-22101972@postgrespro.ru", "phone": "+70482565180"}
0005433415518	2FD2E5	0186 955367	ALEKSANDR KUZNECOV	{"email": "a-kuznecov.091981@postgrespro.ru", "phone": "+70677614904"}
0005433415519	2FD2E5	0309 133771	NIKOLAY OSIPOV	{"phone": "+70306930374"}
0005433415520	2FD2E5	2156 077170	NINA FILIPPOVA	{"email": "filippova-nina-111976@postgrespro.ru", "phone": "+70051355514"}
0005433415521	9490BE	7677 829640	GALINA DMITRIEVA	{"phone": "+70130251360"}
0005433415522	BADE16	0646 331706	SOFYA ZAKHAROVA	{"phone": "+70252271507"}
0005433415523	5A7801	0114 581149	OLGA SOROKINA	{"phone": "+70212570020"}
0005433415524	060EE8	0438 227303	VERA LEBEDEVA	{"phone": "+70170613117"}
0005433415525	059C8C	8872 493649	NIKITA NOVIKOV	{"phone": "+70172714075"}
0005433415526	0C835F	0028 642930	ANDREY MAKAROV	{"email": "andrey_makarov.11041973@postgrespro.ru", "phone": "+70346501443"}
0005433415527	0C835F	3822 502918	LIDIYA MOISEEVA	{"email": "moiseeval.29011974@postgrespro.ru", "phone": "+70238698504"}
0005433415528	D6411C	8640 982891	SVETLANA LEBEDEVA	{"phone": "+70970598677"}
0005433415529	D6411C	8167 098835	GALINA MELNIKOVA	{"phone": "+70076499204"}
0005433415530	D6411C	9317 336216	ANDREY GUSEV	{"phone": "+70542709174"}
0005433415531	65C45A	4223 933503	NATALYA MAKSIMOVA	{"phone": "+70236510250"}
0005433415532	65C45A	5134 630203	KRISTINA KAZAKOVA	{"email": "kazakova.k-1967@postgrespro.ru", "phone": "+70669546655"}
0005433415533	0790CD	9576 458628	VLADIMIR ISAEV	{"email": "v-isaev-1963@postgrespro.ru", "phone": "+70019575090"}
0005433415534	9F4D8A	3003 531015	SERGEY SMIRNOV	{"email": "s_smirnov.20091966@postgrespro.ru", "phone": "+70553903433"}
0005433415535	9F4D8A	8906 306549	SVETLANA POPOVA	{"email": "svetlana.popova_16121972@postgrespro.ru", "phone": "+70347137666"}
0005433415536	B519C0	8697 904728	NINA ROMANOVA	{"email": "nromanova_041973@postgrespro.ru", "phone": "+70216090018"}
0005433415537	ED082F	2511 469666	ALEKSEY TIKHONOV	{"phone": "+70353748620"}
0005433415538	ED082F	2943 420692	NADEZHDA FADEEVA	{"email": "fadeeva.n-101979@postgrespro.ru", "phone": "+70811320601"}
0005433415539	FD9ED7	9084 609484	SERGEY IVANOV	{"phone": "+70782801841"}
0005433415540	B3F96C	4768 317130	VLADIMIR BORISOV	{"email": "borisov-vladimir-041963@postgrespro.ru", "phone": "+70188459617"}
0005433415541	5A5837	0284 775885	NINA DANILOVA	{"email": "n-danilova_081978@postgrespro.ru", "phone": "+70780006178"}
0005433415542	5A5837	9697 185489	YULIYA SERGEEVA	{"email": "y_sergeeva061978@postgrespro.ru", "phone": "+70048490546"}
0005433415543	59D387	5845 693377	VASILISA ZAYCEVA	{"phone": "+70668076704"}
0005433415544	59D387	1927 904610	VALENTINA FROLOVA	{"email": "v.frolova-26071973@postgrespro.ru", "phone": "+70704638142"}
0005433415545	A72535	0448 788759	RAVIL KUZNECOV	{"email": "kuznecov.ravil-01021976@postgrespro.ru", "phone": "+70349015162"}
0005433415546	A72535	7998 066993	MARIYA FOMINA	{"email": "fomina_mariya-1964@postgrespro.ru", "phone": "+70872917524"}
0005433415547	34A32B	6927 808287	ALEKSANDR EGOROV	{"phone": "+70762834139"}
0005433415548	34A32B	2296 821969	MAKSIM STEPANOV	{"email": "maksimstepanov_011961@postgrespro.ru", "phone": "+70676733854"}
0005433415549	8BC659	0749 234681	ALEKSANDR ILIN	{"email": "ilinaleksandr_1973@postgrespro.ru", "phone": "+70401755741"}
0005433415550	8CA863	6891 189697	NIKITA ZHURAVLEV	{"email": "nikitazhuravlev-031968@postgrespro.ru", "phone": "+70494671036"}
0005433415551	D94887	0708 826758	IGOR ABRAMOV	{"email": "igor-abramov041969@postgrespro.ru", "phone": "+70358788595"}
0005433415552	A5370F	0754 132985	VASILIY MARTYNOV	{"email": "martynovv.17041978@postgrespro.ru", "phone": "+70182848843"}
0005433415553	BB930B	6823 220529	MARINA PAVLOVA	{"email": "pavlova_marina.16031984@postgrespro.ru", "phone": "+70163948954"}
0005433415554	3F680E	3080 214043	VASILIY MATVEEV	{"email": "matveev-v04071971@postgrespro.ru", "phone": "+70163450642"}
0005433415555	A6D1E1	6412 513661	VITALIY GAVRILOV	{"phone": "+70833974819"}
0005433415557	4723CA	2223 595130	EKATERINA ORLOVA	{"email": "orlovae_121967@postgrespro.ru", "phone": "+70605735218"}
0005433415558	256BDA	0387 226861	OKSANA TITOVA	{"phone": "+70795966492"}
0005433415559	256BDA	7855 566849	ZINAIDA MEDVEDEVA	{"email": "z-medvedeva.081976@postgrespro.ru", "phone": "+70272984463"}
0005433415560	256BDA	0050 679387	OLGA ANDREEVA	{"email": "andreevaolga-1980@postgrespro.ru", "phone": "+70660072710"}
0005433415561	11F620	3126 935564	YURIY NAUMOV	{"phone": "+70157582455"}
0005433415562	11F620	2438 758256	SVETLANA BELYAEVA	{"phone": "+70607685548"}
0005433415563	E59E69	0754 600628	ANASTASIYA ALEKSEEVA	{"email": "a_alekseeva1972@postgrespro.ru", "phone": "+70814390108"}
0005433415564	14B8F4	1893 939258	VYACHESLAV MELNIKOV	{"email": "vyacheslav.melnikov.1967@postgrespro.ru", "phone": "+70844236660"}
0005433415565	0B5969	7201 745639	VLADIMIR BONDARENKO	{"email": "vbondarenko25041975@postgrespro.ru", "phone": "+70008781969"}
0005433415566	0B5969	1516 712747	NINA LEBEDEVA	{"email": "lebedeva_n-1978@postgrespro.ru", "phone": "+70686448403"}
0005433415567	6BFA96	3948 838506	SERGEY SIDOROV	{"phone": "+70118934890"}
0005433415568	18E685	1992 832126	ALEKSANDR ZAKHAROV	{"phone": "+70569198374"}
0005433415569	2273F8	7286 780971	LYUDMILA ZHURAVLEVA	{"phone": "+70628981032"}
0005433415570	8E31F5	8786 044121	NADEZHDA IVANOVA	{"phone": "+70645426212"}
0005433415571	392C9B	0925 444424	KLAVDIYA BOGDANOVA	{"email": "klavdiya-bogdanova-1985@postgrespro.ru", "phone": "+70246953338"}
0005433415572	E3CC76	9907 868696	FLYURA MAKAROVA	{"email": "f-makarova111974@postgrespro.ru", "phone": "+70734366858"}
0005433415573	810A17	8832 723596	ALEKSANDR DENISOV	{"email": "aleksandr.denisov.1973@postgrespro.ru", "phone": "+70190669537"}
0005433415574	810A17	0812 363495	RUMIYA LEBEDEVA	{"phone": "+70500161752"}
0005433415575	E0682E	9373 184328	GENNADIY IVANOV	{"email": "gennadiy_ivanov10111967@postgrespro.ru", "phone": "+70747196047"}
0005433415576	E0682E	0345 737022	MIKHAIL ZAYCEV	{"email": "zaycev_mikhail-101981@postgrespro.ru", "phone": "+70726546623"}
0005433415577	E0682E	6468 429783	MIKHAIL BELOV	{"phone": "+70513966734"}
0005433415578	F469FB	9468 197394	VIKTOR CHERNOV	{"email": "chernov_v-121976@postgrespro.ru", "phone": "+70504870290"}
0005433415579	C9F145	7936 754417	IRINA OVCHINNIKOVA	{"phone": "+70951511358"}
0005433415580	C9F145	7673 348242	ELENA BORISOVA	{"email": "borisova.elena_111967@postgrespro.ru", "phone": "+70406174995"}
0005433415581	C6F6FE	0988 005458	KIRILL FOMIN	{"email": "fomin_kirill-10091974@postgrespro.ru", "phone": "+70624584793"}
0005433415582	DD279A	5106 896871	GALINA MAKAROVA	{"email": "makarovagalina.031972@postgrespro.ru", "phone": "+70704885060"}
0005433415583	DD279A	0406 001643	VADIM KOZLOV	{"email": "kozlov.vadim.091967@postgrespro.ru", "phone": "+70030939747"}
0005433415584	9B5F2A	5414 750358	ALEKSANDR STEPANOV	{"phone": "+70214970395"}
0005433415585	9B5F2A	5039 206136	SERGEY DAVYDOV	{"phone": "+70427271621"}
0005433415586	9B5F2A	9595 343869	IVAN KOROLEV	{"phone": "+70982138894"}
0005433415587	79B7C9	9288 831290	VLADIMIR YAKOVLEV	{"email": "yakovlevvladimir-09041983@postgrespro.ru", "phone": "+70289870173"}
0005433415588	79B7C9	1414 061734	SERGEY PETROV	{"phone": "+70304669421"}
0005433415589	ABE064	8393 440408	ALEKSANDRA GUSEVA	{"email": "guseva_aleksandra1969@postgrespro.ru", "phone": "+70793102558"}
0005433415590	ABE064	6386 859622	VLADIMIR KUZNECOV	{"phone": "+70311622155"}
0005433415591	07DF1A	2718 469446	IRINA DANILOVA	{"phone": "+70379784681"}
0005433415592	07DF1A	4352 705020	VIKTOR MOROZOV	{"email": "vmorozov23101972@postgrespro.ru", "phone": "+70637762867"}
0005433415593	078A29	8475 685004	SOFIYA KONOVALOVA	{"email": "sofiya-konovalova_08021961@postgrespro.ru", "phone": "+70443339998"}
0005433415594	4D2685	5432 571562	SOFYA POPOVA	{"phone": "+70753989481"}
0005433415595	9A6238	1540 753047	MARIYA BELYAEVA	{"email": "belyaeva_mariya-1967@postgrespro.ru", "phone": "+70370547240"}
0005433415596	464BB2	5315 031585	PAVEL GUSEV	{"email": "gusev-pavel.081975@postgrespro.ru", "phone": "+70788688668"}
0005433415597	464BB2	4445 851971	DMITRIY TARASOV	{"phone": "+70699766354"}
0005433415598	38B7F9	8207 572903	KLAVDIYA EGOROVA	{"email": "k.egorova.061965@postgrespro.ru", "phone": "+70045456504"}
0005433415599	38B7F9	8514 273179	ANNA RODIONOVA	{"email": "rodionova_a.16051974@postgrespro.ru", "phone": "+70881295308"}
0005433415600	38B7F9	5039 169246	SERGEY KUZNECOV	{"email": "sergey_kuznecov-061974@postgrespro.ru", "phone": "+70336681882"}
0005433415601	81E85C	0686 663591	ANDREY KUZNECOV	{"email": "kuznecov.a.111973@postgrespro.ru", "phone": "+70814393303"}
0005433415602	B4E722	1105 372666	SERGEY DENISOV	{"phone": "+70862083350"}
0005433415603	96782A	8934 355915	ALEKSANDRA OSIPOVA	{"phone": "+70797355907"}
0005433415604	93B510	3233 873698	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov-04041962@postgrespro.ru", "phone": "+70447974640"}
0005433415605	61FC0A	7837 680174	ANNA SIDOROVA	{"email": "sidorovaanna_041977@postgrespro.ru", "phone": "+70423942771"}
0005433415606	A70C89	6866 152669	IVAN PETROV	{"email": "ivanpetrov_07031972@postgrespro.ru", "phone": "+70828587605"}
0005433415607	A70C89	3527 350758	MARIYA KUZNECOVA	{"phone": "+70560140197"}
0005433415608	A70C89	5025 644776	ALEKSANDR BARANOV	{"phone": "+70759954885"}
0005433415609	B5FDA9	4186 339049	STANISLAV DMITRIEV	{"phone": "+70507905199"}
0005433415610	23268A	2720 623629	SERGEY KUZNECOV	{"email": "s-kuznecov20111980@postgrespro.ru", "phone": "+70921675884"}
0005433415611	23268A	6250 775062	GALINA BELOVA	{"phone": "+70385872106"}
0005433415612	E3AB4F	8649 704785	VALENTINA YUDINA	{"email": "yudinavalentina.1972@postgrespro.ru", "phone": "+70786592582"}
0005433415613	32A345	6279 973605	VLADIMIR BELOV	{"phone": "+70925782262"}
0005433415614	E21C3E	3263 294685	VLADIMIR VLASOV	{"phone": "+70861997762"}
0005433415615	E21C3E	7597 403892	ARTEM KOZLOV	{"phone": "+70192738044"}
0005433415616	17F760	7794 360082	ALINA BARANOVA	{"email": "baranova_a_1974@postgrespro.ru", "phone": "+70730556459"}
0005433415617	978352	4634 763804	MIKHAIL AFANASEV	{"email": "mikhail.afanasev.121965@postgrespro.ru", "phone": "+70980498107"}
0005433415618	879987	5875 364096	DARYA KARPOVA	{"email": "daryakarpova.1977@postgrespro.ru", "phone": "+70330337707"}
0005433415619	07235A	9987 651858	MARINA ZHURAVLEVA	{"email": "zhuravleva-m-18091989@postgrespro.ru", "phone": "+70418015993"}
0005433415620	353FA5	6451 639509	YURIY GUSEV	{"phone": "+70630703438"}
0005433415621	353FA5	9888 862045	NIKOLAY ANDREEV	{"phone": "+70507824577"}
0005433415622	4D057E	2215 220979	GENNADIY KUZNECOV	{"phone": "+70467449359"}
0005433415623	63D81C	0293 284501	KSENIYA KUZNECOVA	{"email": "k-kuznecova_20041970@postgrespro.ru", "phone": "+70638147470"}
0005433415624	63D81C	4301 172314	LYUDMILA GRISHINA	{"email": "grishina.lyudmila-11061976@postgrespro.ru", "phone": "+70257848217"}
0005433415625	2864DD	4463 593212	VERA GRISHINA	{"phone": "+70133189440"}
0005433415626	9472F0	5637 772976	NINA TROFIMOVA	{"phone": "+70616033848"}
0005433415627	9472F0	1337 513510	LYUBOV SIDOROVA	{"email": "sidorova.l04041965@postgrespro.ru", "phone": "+70651083242"}
0005433415628	CFA27E	7685 297899	ANASTASIYA FOMINA	{"phone": "+70975303365"}
0005433415629	CFA27E	0397 447038	MIKHAIL KUZMIN	{"email": "mikhailkuzmin_051971@postgrespro.ru", "phone": "+70884869054"}
0005433415630	E5D0AC	5762 550832	GALINA BOGDANOVA	{"phone": "+70210900275"}
0005433415631	896FAC	1796 109618	TAMARA KUZMINA	{"phone": "+70429655355"}
0005433415632	896FAC	7180 745064	NATALYA ORLOVA	{"phone": "+70884722123"}
0005433415633	7524FB	7896 296336	SVETLANA NIKITINA	{"email": "svetlananikitina06091959@postgrespro.ru", "phone": "+70977714894"}
0005433415634	43B6CD	4219 750239	ARINA BELOVA	{"phone": "+70273693223"}
0005433415635	6CFF17	6008 079574	DAMIR PAVLOV	{"email": "pavlov-damir011976@postgrespro.ru", "phone": "+70788141872"}
0005433415636	2E8931	6627 643579	TATYANA VOROBEVA	{"email": "tatyana_vorobeva_29081975@postgrespro.ru", "phone": "+70275276996"}
0005433415637	9D0E95	6327 655872	VERA KOLESNIKOVA	{"phone": "+70287936654"}
0005433415638	8591F8	0325 872794	ANTONINA GUSEVA	{"email": "a-guseva071966@postgrespro.ru", "phone": "+70928811088"}
0005433415639	E94E31	3796 042166	IVAN BARANOV	{"phone": "+70877684890"}
0005433415640	D49D80	1394 091006	EGOR KUZNECOV	{"phone": "+70705139811"}
0005433415641	D49D80	4027 785791	LIDIYA MAKAROVA	{"email": "l-makarova1975@postgrespro.ru", "phone": "+70297479662"}
0005433415642	D0DFE1	5267 755921	ELENA MAKSIMOVA	{"email": "maksimova_e_1982@postgrespro.ru", "phone": "+70166285769"}
0005433415643	D4849F	6705 962374	SAMVEL KUZNECOV	{"email": "samvel_kuznecov.31051967@postgrespro.ru", "phone": "+70553075189"}
0005433415644	3134AF	8301 879159	DMITRIY GERASIMOV	{"phone": "+70357826130"}
0005433415645	6FDAD4	5222 217965	SERGEY POPOV	{"email": "sergey_popov04071983@postgrespro.ru", "phone": "+70545365612"}
0005433415646	C78D33	1534 061681	DMITRIY MAKAROV	{"phone": "+70147345516"}
0005433415647	E487F0	6202 666188	EVGENIYA ORLOVA	{"phone": "+70667623446"}
0005433415648	E713B9	2071 534145	VARVARA KRASNOVA	{"email": "krasnova.varvara1972@postgrespro.ru", "phone": "+70685017660"}
0005433415649	C6E7ED	0724 308200	DANILA BORISOV	{"email": "borisov_d111980@postgrespro.ru", "phone": "+70174403682"}
0005433415650	C6E7ED	0792 492478	VADIM ROMANOV	{"phone": "+70288076922"}
0005433415651	C6E7ED	4843 743908	VLADIMIR PETROV	{"email": "petrov.vladimir1974@postgrespro.ru", "phone": "+70916913184"}
0005433415652	91B987	0872 706864	LARISA MELNIKOVA	{"email": "l-melnikova-1963@postgrespro.ru", "phone": "+70852188644"}
0005433415653	F1AAB7	8912 296303	IGOR GERASIMOV	{"email": "igor_gerasimov.101970@postgrespro.ru", "phone": "+70812310824"}
0005433415654	372A9A	8901 521391	VLADIMIR FOMIN	{"email": "vladimir.fomin_1972@postgrespro.ru", "phone": "+70178886923"}
0005433415655	372A9A	3994 689579	TATYANA ANISIMOVA	{"email": "anisimova_tatyana.091971@postgrespro.ru", "phone": "+70718293333"}
0005433415656	23BBD0	4172 116092	ALEVTINA NAZAROVA	{"email": "nazarova.a1962@postgrespro.ru", "phone": "+70222445420"}
0005433415657	23BBD0	9976 080674	VLADIMIR KOROLEV	{"email": "korolevvladimir22031986@postgrespro.ru", "phone": "+70492711107"}
0005433415658	23BBD0	1338 174437	ANGELINA KOLESNIKOVA	{"phone": "+70178415336"}
0005433415659	23BBD0	9561 785238	IVAN SAVELEV	{"phone": "+70973530991"}
0005433415660	FECA37	8204 986310	KARINA SOKOLOVA	{"phone": "+70158147365"}
0005433415661	FECA37	3967 844099	ALEKSEY AFANASEV	{"email": "aleksey_afanasev.10031971@postgrespro.ru", "phone": "+70568632382"}
0005433415662	422C69	3176 139131	ALENA BARANOVA	{"phone": "+70775520878"}
0005433415663	178DCD	3240 785463	VALENTINA MEDVEDEVA	{"phone": "+70063074597"}
0005433415664	178DCD	9252 839545	ALEKSANDR SAVELEV	{"email": "aleksandr.savelev_011970@postgrespro.ru", "phone": "+70168795802"}
0005433415665	84C0C4	9457 444186	PAVEL FEDOROV	{"email": "pavelfedorov_031987@postgrespro.ru", "phone": "+70655933606"}
0005433415666	84C0C4	4289 683310	EVGENIY ILIN	{"email": "ilin_evgeniy.18041968@postgrespro.ru", "phone": "+70544019869"}
0005433415667	6CF52B	7831 560714	VLADIMIR FOMIN	{"phone": "+70614253480"}
0005433415668	00DC18	8026 557511	ALEKSANDR SOKOLOV	{"phone": "+70646392845"}
0005433415669	E9DBF2	3854 994897	ANDREY EGOROV	{"phone": "+70992941402"}
0005433415670	F076CB	3588 529962	RENAT KUZNECOV	{"email": "kuznecovr_1967@postgrespro.ru", "phone": "+70746427855"}
0005433415671	EEEDEC	2006 277212	EVGENIY ORLOV	{"phone": "+70706768697"}
0005433415672	EEEDEC	4375 371777	KSENIYA TIKHONOVA	{"email": "tikhonovakseniya1971@postgrespro.ru", "phone": "+70437403174"}
0005433415673	74DD31	8313 482350	SERGEY GORBUNOV	{"email": "s_gorbunov_061966@postgrespro.ru", "phone": "+70383732476"}
0005433415674	5A345E	1974 894785	ELENA FILIPPOVA	{"email": "filippova-e-051979@postgrespro.ru", "phone": "+70453373315"}
0005433415676	C58F89	8342 898130	NINA KUZNECOVA	{"email": "nina.kuznecova_1974@postgrespro.ru", "phone": "+70445208459"}
0005433415677	B7274D	5359 904471	ALEKSANDR STEPANOV	{"phone": "+70986027035"}
0005433415678	A1107D	9357 515328	VLADIMIR SOKOLOV	{"email": "sokolov-v_17061973@postgrespro.ru", "phone": "+70997351112"}
0005433415679	A1107D	3355 227258	TATYANA MARTYNOVA	{"email": "t.martynova-1966@postgrespro.ru", "phone": "+70326611312"}
0005433415680	A1107D	9825 121490	ALEKSANDR MELNIKOV	{"email": "a-melnikov-121983@postgrespro.ru", "phone": "+70558793305"}
0005433415681	269236	6049 715604	LYUDMILA KONOVALOVA	{"email": "lkonovalova-041973@postgrespro.ru", "phone": "+70088791446"}
0005433415682	269236	2149 820974	LARISA ABRAMOVA	{"email": "abramovalarisa.1966@postgrespro.ru", "phone": "+70837790301"}
0005433415683	173CFC	4756 213722	LYUDMILA ANDREEVA	{"phone": "+70341784896"}
0005433415684	07D08D	5303 022244	MARINA ROMANOVA	{"email": "romanova_m-11031977@postgrespro.ru", "phone": "+70246711687"}
0005433415741	EF6139	4660 894609	ZHANNA LUKYANOVA	{"phone": "+70377899966"}
0005433415685	07D08D	5567 365646	VYACHESLAV IVANOV	{"email": "ivanov-v121967@postgrespro.ru", "phone": "+70607746197"}
0005433415686	F5F936	6857 806926	ALEKSANDR MARTYNOV	{"phone": "+70272000817"}
0005433415687	09050F	5940 763414	YULIYA SEMENOVA	{"phone": "+70837713185"}
0005433415688	F7F8E3	5759 308394	KIRILL ANDREEV	{"phone": "+70978694288"}
0005433415689	F7F8E3	4058 984448	NADEZHDA MOISEEVA	{"email": "moiseevan-091972@postgrespro.ru", "phone": "+70297009295"}
0005433415690	0C7FFB	7364 647228	YAROSLAV MIRONOV	{"email": "mironovyaroslav-111981@postgrespro.ru", "phone": "+70796441083"}
0005433415748	A6E971	4878 928048	TATYANA SMIRNOVA	{"phone": "+70476948824"}
0005433415691	346A6B	0121 790568	ANNA MATVEEVA	{"email": "matveeva.anna-081980@postgrespro.ru", "phone": "+70388355080"}
0005433415692	6EEB05	3695 900159	VENIAMIN VOLKOV	{"phone": "+70168260520"}
0005433415693	F932B8	3051 203658	NATALYA KAZAKOVA	{"email": "n-kazakova.071980@postgrespro.ru", "phone": "+70020482595"}
0005433415694	5BD10D	9932 785942	DMITRIY FILIPPOV	{"phone": "+70989357495"}
0005433415695	F0F443	9445 591146	ZULFIYA MIKHAYLOVA	{"phone": "+70380799569"}
0005433415696	F0F443	3560 943017	EVGENIYA MELNIKOVA	{"email": "evgeniyamelnikova-071980@postgrespro.ru", "phone": "+70323378023"}
0005433415697	F0F443	1522 272502	YURIY KUZNECOV	{"email": "y-kuznecov-07041976@postgrespro.ru", "phone": "+70907087211"}
0005433415698	303B06	8243 345113	LYUDMILA DAVYDOVA	{"email": "davydovalyudmila_19011980@postgrespro.ru", "phone": "+70988971955"}
0005433415699	4FF330	7277 987642	NIKITA MARTYNOV	{"email": "martynov_nikita-1956@postgrespro.ru", "phone": "+70831179984"}
0005433415700	F2F885	2421 123495	ALEKSEY TIKHONOV	{"email": "a-tikhonov-08011976@postgrespro.ru", "phone": "+70297212784"}
0005433415701	487226	3073 084335	MAKSIM KULIKOV	{"phone": "+70690753994"}
0005433415702	487226	1687 950882	DMITRIY DENISOV	{"phone": "+70604148344"}
0005433415703	FFAE40	0767 239908	ALEKSANDR GUSEV	{"phone": "+70457137472"}
0005433415704	C21C69	9917 405369	AMIR POPOV	{"email": "popov.amir-24031981@postgrespro.ru", "phone": "+70097140083"}
0005433415705	C21C69	1171 060571	EVGENIY KUZNECOV	{"phone": "+70224283223"}
0005433415706	3A185C	3267 170584	NINA ANDREEVA	{"phone": "+70399135237"}
0005433415707	3A185C	1372 260209	MIKHAIL SEMENOV	{"email": "mikhailsemenov_1973@postgrespro.ru", "phone": "+70163792196"}
0005433415708	AA93D1	0132 329209	YANA DENISOVA	{"email": "denisovay.22101972@postgrespro.ru", "phone": "+70571986536"}
0005433415709	39041F	3334 040867	SVETLANA KUZNECOVA	{"email": "kuznecovasvetlana.1968@postgrespro.ru", "phone": "+70908700691"}
0005433415710	FF718F	8215 501044	VALERIY PETROV	{"email": "valeriy_petrov-15051979@postgrespro.ru", "phone": "+70849748398"}
0005433415711	FF718F	5601 629479	MARINA OSIPOVA	{"email": "marina.osipova.1970@postgrespro.ru", "phone": "+70474710073"}
0005433415712	7AB494	5585 750333	VALENTINA ZAYCEVA	{"phone": "+70925682764"}
0005433415713	3335B8	7669 440319	SOFIYA NOVIKOVA	{"email": "novikova_s_041975@postgrespro.ru", "phone": "+70005321687"}
0005433415714	9AA5DB	9491 550008	TATYANA SMIRNOVA	{"email": "tatyana.smirnova_091977@postgrespro.ru", "phone": "+70511841604"}
0005433415715	9AA5DB	9799 050906	ANVAR NAZAROV	{"phone": "+70280172276"}
0005433415716	B8BB72	8352 287306	RAISA ANISIMOVA	{"email": "r-anisimova1978@postgrespro.ru", "phone": "+70929111723"}
0005433415717	624E80	5439 722714	MIKHAIL KOROLEV	{"phone": "+70060000745"}
0005433415718	624E80	2892 076499	AZAT BELOV	{"email": "azat.belov10111972@postgrespro.ru", "phone": "+70789322927"}
0005433415719	624E80	1755 848919	MARINA FEDOROVA	{"email": "fedorovamarina081968@postgrespro.ru", "phone": "+70123274138"}
0005433415720	2E8AFB	9167 009771	VALENTINA IVANOVA	{"email": "ivanova-v_101975@postgrespro.ru", "phone": "+70725166737"}
0005433415721	3A1D6D	1566 572209	VLADIMIR ZAKHAROV	{"email": "zakharovv_011983@postgrespro.ru", "phone": "+70398969942"}
0005433415722	459804	9781 742885	VLADIMIR BELOV	{"email": "belov.vladimir_101974@postgrespro.ru", "phone": "+70825018353"}
0005433415723	DA5765	4177 597507	MIKHAIL SIDOROV	{"phone": "+70448478308"}
0005433415724	295207	7014 879684	VALENTINA IVANOVA	{"phone": "+70032800020"}
0005433415725	647279	7565 038425	ANGELINA KUZMINA	{"email": "angelina.kuzmina-081963@postgrespro.ru", "phone": "+70924699575"}
0005433415726	4D3710	3740 751795	SERGEY NIKITIN	{"phone": "+70780348499"}
0005433415727	8E45A4	7572 107066	ALEKSEY FEDOROV	{"phone": "+70652784850"}
0005433415728	8E45A4	7242 586846	VITALIY KARPOV	{"phone": "+70977327199"}
0005433415729	EDDBB3	9522 187898	EKATERINA POPOVA	{"email": "popova_ekaterina121979@postgrespro.ru", "phone": "+70812878105"}
0005433415730	106602	5622 852960	ROMAN FILIPPOV	{"phone": "+70770121727"}
0005433415731	106602	0739 183684	GALINA ALEKSANDROVA	{"phone": "+70895379535"}
0005433415732	AC9CC4	8252 128745	DANIIL VOLKOV	{"email": "volkov_daniil_24071971@postgrespro.ru", "phone": "+70496610239"}
0005433415733	B8DD59	9398 472973	ALEKSEY PETROV	{"phone": "+70082679025"}
0005433415734	B8DD59	7758 431895	TAMARA SIDOROVA	{"email": "tamara.sidorova1986@postgrespro.ru", "phone": "+70915358275"}
0005433415735	1715E1	6266 079085	YURIY SOLOVEV	{"phone": "+70571809651"}
0005433415736	A266C8	0015 453181	NINA FEDOROVA	{"phone": "+70026512658"}
0005433415737	A266C8	7264 401296	MARINA SEMENOVA	{"phone": "+70108218886"}
0005433415738	335F5A	8627 811401	SVETLANA NIKITINA	{"phone": "+70182807734"}
0005433415739	4AA160	4254 153803	SERGEY KOZLOV	{"email": "kozlov.s_17011963@postgrespro.ru", "phone": "+70158982810"}
0005433415740	4AA160	5123 146955	DENIS KULIKOV	{"phone": "+70990292889"}
0005433415742	EF6139	9085 632496	NIKOLAY GERASIMOV	{"email": "gerasimovnikolay-031967@postgrespro.ru", "phone": "+70910163611"}
0005433415743	EF6139	8172 426660	VLADISLAV SEMENOV	{"email": "semenov.vladislav_051979@postgrespro.ru", "phone": "+70281836809"}
0005433415744	FF315B	3723 643038	ALEKSEY ANDREEV	{"email": "a-andreev.121988@postgrespro.ru", "phone": "+70816094309"}
0005433415745	32034E	7188 581625	VALERIYA BELOVA	{"phone": "+70764017514"}
0005433415746	9E7C86	2862 652651	ALEKSEY BELOV	{"phone": "+70852310928"}
0005433415747	A6E971	8587 931603	YANA POPOVA	{"email": "y_popova.18091975@postgrespro.ru", "phone": "+70494588613"}
0005433415749	8B36FA	6388 779872	IRINA SOLOVEVA	{"phone": "+70661923321"}
0005433415750	F8E36C	1410 117320	IVAN GERASIMOV	{"phone": "+70376490239"}
0005433415751	5C9E8B	9313 133809	EGOR VOROBEV	{"email": "e_vorobev29011988@postgrespro.ru", "phone": "+70645926070"}
0005433415752	5C9E8B	4048 733852	DMITRIY VLASOV	{"phone": "+70981791600"}
0005433415753	03B27E	4875 550378	VALENTINA KARPOVA	{"phone": "+70665923821"}
0005433415754	F43AF8	1828 562898	IRINA ABRAMOVA	{"email": "irina.abramova-1978@postgrespro.ru", "phone": "+70821356348"}
0005433415755	9F2222	2095 186318	SVETLANA ANISIMOVA	{"email": "anisimova-s-011967@postgrespro.ru", "phone": "+70933147411"}
0005433415756	1DAB3D	4370 107456	NIKOLAY MAKSIMOV	{"email": "maksimov.nikolay071970@postgrespro.ru", "phone": "+70925084783"}
0005433415757	1DAB3D	7413 856351	STANISLAV YAKOVLEV	{"phone": "+70640283370"}
0005433415758	9B7BA9	8587 054911	NINA LEBEDEVA	{"email": "lebedeva.n.1972@postgrespro.ru", "phone": "+70468396010"}
0005433415759	257C8F	9970 602471	ALEKSEY GUSEV	{"phone": "+70054718816"}
0005433415760	0FE080	3964 871110	ANTON RODIONOV	{"phone": "+70809726923"}
0005433415761	42C0A2	3659 827397	NINA VOROBEVA	{"email": "nina_vorobeva-1961@postgrespro.ru", "phone": "+70796281777"}
0005433415762	160BE4	2432 268806	LYUBOV IVANOVA	{"phone": "+70677725953"}
0005433415763	160BE4	2802 627916	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov_061978@postgrespro.ru", "phone": "+70343544963"}
0005433415764	00A614	2110 927595	VALENTINA NIKOLAEVA	{"email": "nikolaevavalentina.1970@postgrespro.ru", "phone": "+70811050446"}
0005433415765	541897	8970 177558	GEORGIY ALEKSEEV	{"email": "alekseevgeorgiy_041971@postgrespro.ru", "phone": "+70894238654"}
0005433415766	454003	7044 393190	ELENA SOKOLOVA	{"email": "sokolova.elena.1974@postgrespro.ru", "phone": "+70187326029"}
0005433415767	44D946	0475 283379	GRIGORIY FEDOROV	{"email": "fedorov.grigoriy.1973@postgrespro.ru", "phone": "+70389796473"}
0005433415768	6A222E	4816 414774	TATYANA AFANASEVA	{"phone": "+70816171368"}
0005433415769	3F9BEC	0871 974833	ALLA NIKIFOROVA	{"email": "nikiforova-alla1967@postgrespro.ru", "phone": "+70690753026"}
0005433415770	3F9BEC	0084 752705	OLESYA SOROKINA	{"email": "osorokina14091955@postgrespro.ru", "phone": "+70875937567"}
0005433415771	08FA59	4188 403516	FANIL DENISOV	{"email": "denisovf-1975@postgrespro.ru", "phone": "+70161893832"}
0005433415772	3B6A34	2345 249023	ANDREY STEPANOV	{"email": "a-stepanov06031965@postgrespro.ru", "phone": "+70244562299"}
0005433415773	9A3977	6792 820048	VLADIMIR SOKOLOV	{"phone": "+70409431368"}
0005433415774	B39149	6582 379516	NIKOLAY ZHURAVLEV	{"email": "nzhuravlev.1975@postgrespro.ru", "phone": "+70739884909"}
0005433415775	B39149	2865 041559	GENNADIY EGOROV	{"email": "gennadiy-egorov.17111975@postgrespro.ru", "phone": "+70080484622"}
0005433415776	5F1045	7381 440305	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr_23011968@postgrespro.ru", "phone": "+70787071954"}
0005433415777	E37812	8348 587398	ANTON KOZLOV	{"phone": "+70302454515"}
0005433415778	411BB7	9078 644990	IVAN PAVLOV	{"phone": "+70995341065"}
0005433415779	EDFEF3	6066 009464	ANASTASIYA VASILEVA	{"email": "anastasiya_vasileva20061980@postgrespro.ru", "phone": "+70307054930"}
0005433415780	EDFEF3	3183 452113	TAMARA PETROVA	{"phone": "+70630114906"}
0005433415781	EDFEF3	8797 118530	ANGELINA ZAYCEVA	{"phone": "+70419433923"}
0005433415782	4C9DB6	1838 491937	NINA VOLKOVA	{"email": "volkova-nina_051962@postgrespro.ru", "phone": "+70812239190"}
0005433415783	E42258	8510 223158	VIKTOR SOKOLOV	{"email": "viktorsokolov_1961@postgrespro.ru", "phone": "+70201648709"}
0005433415784	2DD073	8955 880013	ANTON SMIRNOV	{"phone": "+70699742210"}
0005433415785	2DD073	2595 466710	GALINA NOVIKOVA	{"email": "gnovikova.13091976@postgrespro.ru", "phone": "+70621265852"}
0005433415786	DB664E	5333 203062	VITALIY FILIPPOV	{"email": "vitaliyfilippov_1969@postgrespro.ru", "phone": "+70289668995"}
0005433415787	36AAE8	9559 963933	NATALYA EGOROVA	{"email": "natalya-egorova-121977@postgrespro.ru", "phone": "+70704191613"}
0005433415788	F37191	6534 211931	TATYANA ROMANOVA	{"phone": "+70672723720"}
0005433415789	F37191	7319 236066	ELENA YAKOVLEVA	{"email": "eyakovleva_30121960@postgrespro.ru", "phone": "+70154604892"}
0005433415790	4025DC	9753 273778	EGOR SIDOROV	{"email": "egor.sidorov-06091976@postgrespro.ru", "phone": "+70935761587"}
0005433415791	4025DC	4495 830507	ALEKSEY IVANOV	{"phone": "+70098382439"}
0005433415792	93A3A9	0246 536829	YULIYA PETROVA	{"phone": "+70919500743"}
0005433415793	35F501	6944 044726	VIKTOR NIKOLAEV	{"phone": "+70211833980"}
0005433416035	8BCD8B	4662 215792	ZOYA MIKHAYLOVA	{"phone": "+70004528745"}
0005433415794	35F501	8771 037052	MIKHAIL SOLOVEV	{"email": "solovev.m_10111970@postgrespro.ru", "phone": "+70585385071"}
0005433415795	5EE425	8904 802326	SVETLANA GORBUNOVA	{"phone": "+70152405706"}
0005433415796	EE5D14	4119 042773	IGOR SCHERBAKOV	{"email": "igor_scherbakov_1985@postgrespro.ru", "phone": "+70441858742"}
0005433415797	111C00	1310 625988	VERA RODIONOVA	{"email": "vera_rodionova_31121984@postgrespro.ru", "phone": "+70549641063"}
0005433415798	111C00	5891 064318	DMITRIY OSIPOV	{"email": "osipovdmitriy-05111970@postgrespro.ru", "phone": "+70650508496"}
0005433415799	78CC46	1711 499409	NATALYA MOISEEVA	{"phone": "+70363483707"}
0005433415800	4FFC4B	5838 047680	LYUDMILA POPOVA	{"phone": "+70999757772"}
0005433415801	4FFC4B	2565 072214	ANTON MAKAROV	{"phone": "+70150065035"}
0005433415802	44A446	1376 009175	TATYANA VOROBEVA	{"email": "vorobeva-tatyana.1989@postgrespro.ru", "phone": "+70280495657"}
0005433415803	887725	8008 450455	IRINA FEDOROVA	{"email": "ifedorova21061974@postgrespro.ru", "phone": "+70584390085"}
0005433415804	104A4E	4806 697650	ANASTASIYA KRASNOVA	{"phone": "+70566804500"}
0005433415805	104A4E	5143 336829	LYUDMILA POPOVA	{"email": "popova.l_081982@postgrespro.ru", "phone": "+70892042401"}
0005433415806	F25ED0	3260 121108	VLADISLAV FROLOV	{"phone": "+70098738331"}
0005433415807	D557F2	4024 393912	ALEKSANDR SOROKIN	{"phone": "+70188294871"}
0005433415808	D557F2	9602 419948	IRINA LEBEDEVA	{"phone": "+70982804044"}
0005433415809	3B2C01	0861 754753	VLADIMIR KISELEV	{"email": "vkiselev1967@postgrespro.ru", "phone": "+70428520101"}
0005433415810	0983E0	5598 948625	OKSANA MAKAROVA	{"email": "o.makarova26071972@postgrespro.ru", "phone": "+70735521572"}
0005433415811	BE3D24	6520 634670	NIKITA POPOV	{"email": "popov_n.1969@postgrespro.ru", "phone": "+70662870807"}
0005433415812	D105F8	5875 208496	MIKHAIL TIMOFEEV	{"phone": "+70641933621"}
0005433415813	32425C	5742 549381	RAISA PETROVA	{"email": "petrova.raisa-041976@postgrespro.ru", "phone": "+70260910973"}
0005433415814	32425C	1116 909014	DARYA DMITRIEVA	{"phone": "+70712842849"}
0005433415815	CA14B9	2050 125930	VALERIY RODIONOV	{"phone": "+70060941077"}
0005433415816	BE1332	9058 687163	SVETLANA KUZNECOVA	{"phone": "+70129007432"}
0005433415817	BE1332	9317 549294	POLINA KONDRATEVA	{"email": "polina_kondrateva.06021972@postgrespro.ru", "phone": "+70672575882"}
0005433415818	501669	0991 057568	OLEG OSIPOV	{"email": "o_osipov-1975@postgrespro.ru", "phone": "+70117076790"}
0005433415819	501669	2812 647378	OLEG ANDREEV	{"email": "oleg_andreev_011968@postgrespro.ru", "phone": "+70062722961"}
0005433415820	4960C4	3375 500847	LEV GUSEV	{"phone": "+70671356947"}
0005433415821	4960C4	7336 596955	LIDIYA NIKITINA	{"email": "nikitina-l-1974@postgrespro.ru", "phone": "+70786296944"}
0005433415822	46C0F8	1577 506013	SERGEY IVANOV	{"phone": "+70544664288"}
0005433415823	9BA128	6957 893010	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir1962@postgrespro.ru", "phone": "+70770761234"}
0005433415824	4FA9D8	8903 163459	VITALIY KULIKOV	{"email": "vitaliy.kulikov_1972@postgrespro.ru", "phone": "+70257280641"}
0005433415825	A6DAC7	3348 762773	ELIZAVETA ALEKSANDROVA	{"phone": "+70069475549"}
0005433415826	F27879	8201 734750	VLADIMIR GAVRILOV	{"email": "v.gavrilov1970@postgrespro.ru", "phone": "+70797282232"}
0005433415827	1D0BE4	0424 290976	TATYANA BORISOVA	{"email": "t_borisova.1976@postgrespro.ru", "phone": "+70529392094"}
0005433415828	AEFAF2	8791 667434	OLGA LAZAREVA	{"phone": "+70638164810"}
0005433415829	CCB556	2248 708932	ALEKSANDR GRIGOREV	{"email": "a.grigorev.071975@postgrespro.ru", "phone": "+70003630975"}
0005433415830	CCB556	4162 976352	DARYA VOLKOVA	{"email": "dvolkova021970@postgrespro.ru", "phone": "+70154479947"}
0005433415831	4209AF	9334 932843	DANIIL AFANASEV	{"phone": "+70043313521"}
0005433415832	0B0868	0115 015059	RAISA FROLOVA	{"phone": "+70682231759"}
0005433415833	567E8F	0977 712250	NIKITA MEDVEDEV	{"email": "nikita_medvedev.26011974@postgrespro.ru", "phone": "+70252917390"}
0005433415834	567E8F	2296 368233	VIKTOR FEDOTOV	{"email": "fedotov.v091985@postgrespro.ru", "phone": "+70649580695"}
0005433415835	FDF096	8245 633830	TATYANA POTAPOVA	{"email": "tatyana.potapova.061975@postgrespro.ru", "phone": "+70670785875"}
0005433415836	0637E5	6019 831153	DMITRIY STEPANOV	{"phone": "+70602692748"}
0005433415837	0637E5	0738 568460	ELENA LEBEDEVA	{"phone": "+70187255776"}
0005433415838	754C33	6931 243457	TAGIR MAKAROV	{"phone": "+70734206965"}
0005433415839	754C33	2396 893684	VIKTOR IVANOV	{"email": "ivanov.viktor1968@postgrespro.ru", "phone": "+70290974164"}
0005433415840	02EA09	6987 765210	YURIY KUZMIN	{"email": "kuzmin-y031970@postgrespro.ru", "phone": "+70892481515"}
0005433415841	02EA09	6600 610450	ALEKSANDR KOZLOV	{"email": "a-kozlov.021965@postgrespro.ru", "phone": "+70479029035"}
0005433415842	02EA09	9461 095868	ALEKSEY MATVEEV	{"phone": "+70104322370"}
0005433415843	AB527F	4413 065269	NATALYA PETROVA	{"email": "n.petrova_111975@postgrespro.ru", "phone": "+70486624391"}
0005433415844	AB527F	3657 052953	ILYA ALEKSANDROV	{"phone": "+70192439263"}
0005433415845	680584	5840 155136	EKATERINA ALEKSANDROVA	{"email": "e_aleksandrova011985@postgrespro.ru", "phone": "+70968973241"}
0005433415846	C2E800	4704 188309	ANNA KALININA	{"phone": "+70391768298"}
0005433415847	B3F606	5953 006309	ALEKSANDR DENISOV	{"email": "adenisov31081970@postgrespro.ru", "phone": "+70594592296"}
0005433415848	B6FC17	1059 558148	ALEKSANDR MOROZOV	{"email": "a_morozov1971@postgrespro.ru", "phone": "+70380230499"}
0005433415849	AEADEB	5556 123482	ANASTASIYA BORISOVA	{"email": "aborisova-1966@postgrespro.ru", "phone": "+70153641489"}
0005433415850	521BF9	4223 265260	ROMAN MAKAROV	{"phone": "+70772898120"}
0005433415851	521BF9	6704 065699	ELENA ALEKSANDROVA	{"phone": "+70360582553"}
0005433415852	CA8442	6172 286279	ANDREY IVANOV	{"phone": "+70525917029"}
0005433415853	CA8442	6359 744951	VALENTINA KONOVALOVA	{"email": "konovalova-valentina-12021979@postgrespro.ru", "phone": "+70386513596"}
0005433415854	F378BE	2005 862039	OLGA ZAYCEVA	{"email": "zayceva_olga-01121971@postgrespro.ru", "phone": "+70574368263"}
0005433415855	9A6A8D	0458 789300	IVAN DMITRIEV	{"phone": "+70157940092"}
0005433415856	9A6A8D	0261 828524	IRINA MAKSIMOVA	{"email": "i-maksimova_1980@postgrespro.ru", "phone": "+70789404554"}
0005433415857	8987B1	0277 642862	NINA KONOVALOVA	{"email": "nina_konovalova_11061963@postgrespro.ru", "phone": "+70867658684"}
0005433415858	C98C54	8431 144347	SERGEY POPOV	{"email": "popov_s.24061968@postgrespro.ru", "phone": "+70116431971"}
0005433415914	6E08BC	4434 116358	VASILIY KUZNECOV	{"phone": "+70069746164"}
0005433415859	4596CA	8171 078185	VYACHESLAV MOISEEV	{"email": "moiseev-vyacheslav.03111971@postgrespro.ru", "phone": "+70051727829"}
0005433415860	228074	1410 457810	ALLA IVANOVA	{"phone": "+70989377974"}
0005433415861	B733D6	7818 044589	NINA OSIPOVA	{"email": "osipova-n02011976@postgrespro.ru", "phone": "+70991333359"}
0005433415862	BC759D	0174 454688	VYACHESLAV KUZNECOV	{"email": "kuznecov-v-1972@postgrespro.ru", "phone": "+70456514445"}
0005433415863	45FBDD	9772 266522	ALEKSANDR KUZNECOV	{"email": "kuznecov-a081974@postgrespro.ru", "phone": "+70086871302"}
0005433415864	45FBDD	4843 961956	YULIYA EGOROVA	{"email": "egorova-yuliya-28041969@postgrespro.ru", "phone": "+70948314295"}
0005433415865	02A4E4	2388 288322	LIDIYA SIDOROVA	{"phone": "+70314046323"}
0005433415866	FFA3ED	3487 512266	VERA EGOROVA	{"phone": "+70490866031"}
0005433415867	FFA3ED	3359 459490	IRINA KAZAKOVA	{"phone": "+70577878577"}
0005433415868	FFA3ED	7526 229714	RAISA DMITRIEVA	{"phone": "+70554419239"}
0005433415869	53CCDC	4321 161671	ALEKSEY POPOV	{"phone": "+70700532238"}
0005433415870	C86255	4902 693796	VYACHESLAV TIMOFEEV	{"phone": "+70686436363"}
0005433415871	F7822D	9902 788798	YURIY NOVIKOV	{"email": "novikov-y_07051964@postgrespro.ru", "phone": "+70030347772"}
0005433415872	C9D7FB	2441 562257	PELAGEYA KOZLOVA	{"phone": "+70669349652"}
0005433415873	C9D7FB	2900 876650	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-16041973@postgrespro.ru", "phone": "+70300875365"}
0005433415874	61C17E	6448 280623	VALENTINA GUSEVA	{"email": "guseva-v-07031981@postgrespro.ru", "phone": "+70390086719"}
0005433415875	61C17E	6880 446916	ALEFTINA DENISOVA	{"phone": "+70078867632"}
0005433415876	61C17E	1924 982680	MIKHAIL MIRONOV	{"email": "mironov_mikhail-25041983@postgrespro.ru", "phone": "+70839451750"}
0005433415877	8FE54E	4183 080106	MARINA BORISOVA	{"email": "borisova-marina051965@postgrespro.ru", "phone": "+70707481283"}
0005433415878	8FE54E	5303 489951	PETR NOVIKOV	{"email": "novikovp041969@postgrespro.ru", "phone": "+70813473805"}
0005433415879	8FE54E	0692 749964	ALEKSEY RODIONOV	{"phone": "+70594818784"}
0005433415880	8FE54E	3025 507096	ALINA NAUMOVA	{"phone": "+70959984029"}
0005433415881	54A266	5097 115892	MARIYA KUZNECOVA	{"phone": "+70477483703"}
0005433415882	675918	2696 593072	OLGA KOZLOVA	{"phone": "+70524244160"}
0005433415883	44FB87	4462 978083	NIKOLAY NAZAROV	{"email": "n.nazarov.1968@postgrespro.ru", "phone": "+70676124021"}
0005433415884	44FB87	2257 113559	DMITRIY MEDVEDEV	{"phone": "+70699292883"}
0005433415885	3E14C3	3463 993668	LYUBOV ROMANOVA	{"phone": "+70548870094"}
0005433415886	3E14C3	2507 380312	FEDOR KUZMIN	{"phone": "+70162351787"}
0005433415887	4C1867	1478 638023	IVAN TIMOFEEV	{"email": "timofeev.ivan_24021976@postgrespro.ru", "phone": "+70876565840"}
0005433415888	4C1867	9951 172027	TATYANA SIDOROVA	{"email": "sidorova.t.25021966@postgrespro.ru", "phone": "+70639517514"}
0005433415889	B19634	0661 981934	STANISLAV YAKOVLEV	{"email": "yakovlev.s1966@postgrespro.ru", "phone": "+70312433751"}
0005433415890	1DE413	8218 788527	TATYANA SIDOROVA	{"email": "tatyanasidorova-031964@postgrespro.ru", "phone": "+70842839517"}
0005433415891	E8B264	5683 054012	YURIY YAKOVLEV	{"email": "yakovlev.yuriy.101963@postgrespro.ru", "phone": "+70470840143"}
0005433415892	2010FE	6380 357508	LEV ROMANOV	{"email": "romanov.lev_25011976@postgrespro.ru", "phone": "+70380497897"}
0005433415893	2010FE	2010 583195	ANDREY BONDARENKO	{"email": "a.bondarenko08011966@postgrespro.ru", "phone": "+70010360831"}
0005433415894	CF5754	1824 982260	VLADIMIR VLASOV	{"email": "vvlasov-1971@postgrespro.ru", "phone": "+70341505066"}
0005433415895	60B43B	8513 944157	GRIGORIY PAVLOV	{"phone": "+70740979736"}
0005433415896	F76BFF	3336 582094	DMITRIY VOROBEV	{"email": "vorobevd101962@postgrespro.ru", "phone": "+70804203600"}
0005433415897	07D21F	4058 304001	RUSLAN MEDVEDEV	{"phone": "+70676110645"}
0005433415898	D76F01	3815 077270	EDUARD IVANOV	{"email": "e-ivanov.1981@postgrespro.ru", "phone": "+70470138216"}
0005433415899	D76F01	6175 994621	LYUDMILA MALYSHEVA	{"email": "lyudmilamalysheva1973@postgrespro.ru", "phone": "+70304186187"}
0005433415900	D76F01	4784 396515	GALINA DMITRIEVA	{"phone": "+70011036270"}
0005433415901	EA31D9	0742 230590	ALEKSANDR BELOV	{"email": "abelov_101977@postgrespro.ru", "phone": "+70233759823"}
0005433415902	948026	6014 299667	NATALYA ILINA	{"email": "n.ilina_071971@postgrespro.ru", "phone": "+70338736694"}
0005433415903	EE2D4B	2816 069229	NATALYA KARPOVA	{"email": "n-karpova-011974@postgrespro.ru", "phone": "+70057121740"}
0005433415904	EE2D4B	9986 737917	ALEKSEY ZHURAVLEV	{"email": "a_zhuravlev.1960@postgrespro.ru", "phone": "+70130588313"}
0005433415905	A4E38F	8512 498503	IVAN SHEVCHENKO	{"email": "i-shevchenko-1982@postgrespro.ru", "phone": "+70214689683"}
0005433415906	A4E38F	1385 807897	LEV ALEKSANDROV	{"phone": "+70801723358"}
0005433415907	623CF1	2984 291052	EVGENIY IVANOV	{"phone": "+70307350077"}
0005433416020	8F0FAC	4707 427238	NIKOLAY ALEKSEEV	{"phone": "+70543095827"}
0005433415908	EE0CD8	6776 162920	PAVEL KUDRYASHOV	{"email": "kudryashov_p.1972@postgrespro.ru", "phone": "+70157317513"}
0005433415909	EE0CD8	5613 266168	ARTEM TIKHONOV	{"phone": "+70637369335"}
0005433415910	35904D	3680 775379	OLGA PAVLOVA	{"email": "olga.pavlova1977@postgrespro.ru", "phone": "+70162657536"}
0005433415911	35904D	3586 874040	ALEKSANDR ZAKHAROV	{"phone": "+70150789861"}
0005433415912	A3E239	3408 351961	ALEKSANDRA VOLKOVA	{"email": "volkova-a-13021975@postgrespro.ru", "phone": "+70337942059"}
0005433415913	E5CB4D	0906 911052	VALENTINA IVANOVA	{"phone": "+70306850458"}
0005433415915	6E08BC	3176 543911	LYUDMILA SEMENOVA	{"email": "l_semenova-1960@postgrespro.ru", "phone": "+70657569323"}
0005433415916	E2C886	1043 805000	LYUBOV LOGINOVA	{"email": "loginovalyubov021972@postgrespro.ru", "phone": "+70062686443"}
0005433415917	E2C886	0137 557001	NATALYA SCHERBAKOVA	{"email": "natalya.scherbakova.29121971@postgrespro.ru", "phone": "+70234427444"}
0005433415918	EA36F3	3018 823087	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina.1973@postgrespro.ru", "phone": "+70950389962"}
0005433415919	73F3A0	0985 199039	ANNA ANDREEVA	{"phone": "+70035240652"}
0005433415920	73F3A0	4543 427776	MARIYA GERASIMOVA	{"phone": "+70278123008"}
0005433415921	A0AF4D	0133 211520	FARIDA MOISEEVA	{"phone": "+70908034914"}
0005433415922	8DD0E0	3676 894472	VALENTINA ZAKHAROVA	{"phone": "+70797681733"}
0005433415923	19754E	7540 307779	NINA AFANASEVA	{"email": "nina_afanaseva-121973@postgrespro.ru", "phone": "+70999050074"}
0005433415924	4CD5CF	3463 923097	ALEKSEY FEDOROV	{"phone": "+70077673650"}
0005433415925	4CD5CF	2067 244349	DIANA TIMOFEEVA	{"phone": "+70052332493"}
0005433415926	9DF442	2066 842860	PAVEL NOVIKOV	{"phone": "+70204263604"}
0005433415927	9DF442	7789 095664	LYUDMILA KOMAROVA	{"phone": "+70746213042"}
0005433415928	CDBE1C	5251 197605	VLADIMIR GORBUNOV	{"email": "v.gorbunov051970@postgrespro.ru", "phone": "+70998600003"}
0005433415929	CDBE1C	1299 353208	ZOYA ZAKHAROVA	{"phone": "+70218693220"}
0005433415930	30D61B	4083 411986	ELENA LAZAREVA	{"phone": "+70572628066"}
0005433415931	30D61B	3310 372532	VITALIY NIKITIN	{"phone": "+70024343416"}
0005433415932	5DD7F7	2368 216661	NATALYA KISELEVA	{"phone": "+70080107385"}
0005433415933	5DD7F7	5415 073095	IRINA MEDVEDEVA	{"email": "medvedevai_1982@postgrespro.ru", "phone": "+70662572278"}
0005433415934	577F49	1936 903283	DZHAMILYA POPOVA	{"email": "d.popova_1964@postgrespro.ru", "phone": "+70663523288"}
0005433415935	D62312	3835 385249	ALEKSANDR ZHURAVLEV	{"phone": "+70846509240"}
0005433415936	D62312	8010 998213	VIKTOR EGOROV	{"phone": "+70079290475"}
0005433415937	5F5E8D	5509 694209	VERA SMIRNOVA	{"email": "smirnova-v021988@postgrespro.ru", "phone": "+70484541799"}
0005433415938	B17B52	2831 064037	OLEG CHERNOV	{"phone": "+70062574565"}
0005433415939	7C67B2	5598 531104	VALENTINA EFREMOVA	{"email": "vefremova_1963@postgrespro.ru", "phone": "+70831891182"}
0005433415940	90DE7C	4312 853139	ALBINA SMIRNOVA	{"email": "smirnovaalbina-121970@postgrespro.ru", "phone": "+70859015111"}
0005433415941	DBC52D	5569 807532	SVETLANA KISELEVA	{"phone": "+70245253556"}
0005433415942	A5A85B	2312 120539	SERGEY MOISEEV	{"email": "sergeymoiseev111971@postgrespro.ru", "phone": "+70735771247"}
0005433415943	CF2574	1516 973114	VASILIY SIDOROV	{"phone": "+70736041920"}
0005433415944	CF2574	3926 721122	GEORGIY FEDOTOV	{"email": "fedotov_g1984@postgrespro.ru", "phone": "+70877963094"}
0005433415945	638665	3776 143916	IVAN SCHERBAKOV	{"email": "scherbakovivan-1971@postgrespro.ru", "phone": "+70391881667"}
0005433415946	5A7B8E	4401 493115	ZINAIDA MIKHAYLOVA	{"email": "zinaida_mikhaylova1972@postgrespro.ru", "phone": "+70100425513"}
0005433415947	5A7B8E	7572 677428	LYUBOV CHERNOVA	{"email": "chernova_lyubov_06101972@postgrespro.ru", "phone": "+70297587247"}
0005433415948	129E6C	8286 273293	SVETLANA KOZLOVA	{"phone": "+70838046469"}
0005433415949	E60C7D	8073 070687	NATALYA MIKHAYLOVA	{"phone": "+70826223784"}
0005433415950	E34F76	6122 243570	IRINA SAVELEVA	{"phone": "+70624305939"}
0005433415951	27D9B7	4373 892098	LYUDMILA ZAKHAROVA	{"email": "zakharova-l19011969@postgrespro.ru", "phone": "+70538692546"}
0005433415952	27D9B7	2618 202771	MAKSIM FEDOROV	{"email": "fedorov_m.1977@postgrespro.ru", "phone": "+70854123385"}
0005433415953	47EE4D	4079 059837	ELENA YAKOVLEVA	{"email": "elenayakovleva-081972@postgrespro.ru", "phone": "+70963441963"}
0005433415954	47EE4D	0828 787982	TATYANA MAKAROVA	{"email": "tatyana.makarova03051968@postgrespro.ru", "phone": "+70752136984"}
0005433415955	E15222	2993 854258	VASILIY VOROBEV	{"phone": "+70256765004"}
0005433415956	E15222	6206 823876	DENIS SMIRNOV	{"email": "dsmirnov.1968@postgrespro.ru", "phone": "+70946011899"}
0005433415957	38AF86	8618 664462	ALEKSANDR MIKHAYLOV	{"phone": "+70757374864"}
0005433415958	38AF86	9427 772555	VYACHESLAV KUZMIN	{"phone": "+70102300136"}
0005433415959	B50CE0	9680 708984	ALEKSANDR GRIGOREV	{"phone": "+70900421286"}
0005433415960	F80B2F	8739 979165	TATYANA MOISEEVA	{"email": "moiseeva_tatyana.28041979@postgrespro.ru", "phone": "+70978168009"}
0005433415961	64C63D	3875 066035	YULIYA MIRONOVA	{"phone": "+70833710406"}
0005433415962	64C63D	3588 650673	NIKOLAY OSIPOV	{"phone": "+70449162021"}
0005433415963	BF79A6	4145 560699	ANNA KAZAKOVA	{"phone": "+70884996768"}
0005433415964	BF79A6	9105 718993	OLGA ZAKHAROVA	{"email": "zakharova.olga-111972@postgrespro.ru", "phone": "+70442352923"}
0005433415965	BFD250	9769 638871	PETR PETROV	{"email": "p.petrov_1978@postgrespro.ru", "phone": "+70310196057"}
0005433415966	BFD250	2462 848546	OLGA KOMAROVA	{"phone": "+70932646854"}
0005433415967	CEE29A	6696 732298	OLGA YAKOVLEVA	{"email": "olga.yakovleva.111973@postgrespro.ru", "phone": "+70846270503"}
0005433415968	905544	8583 077255	NIKITA SOLOVEV	{"phone": "+70062937208"}
0005433415969	249BF6	4916 015157	MARGARITA ZHURAVLEVA	{"email": "zhuravleva-margarita-091975@postgrespro.ru", "phone": "+70877938300"}
0005433415970	249BF6	0982 934016	ANATOLIY POPOV	{"email": "popova021961@postgrespro.ru", "phone": "+70893077047"}
0005433415971	249BF6	5926 441530	ROZALIYA ZAYCEVA	{"email": "rozaliyazayceva_1977@postgrespro.ru", "phone": "+70815012672"}
0005433415972	A15810	0718 675574	VLADISLAV SEMENOV	{"email": "semenov_vladislav_17011976@postgrespro.ru", "phone": "+70570656615"}
0005433415973	A15810	0224 681220	ROMAN SERGEEV	{"email": "sergeev.r1985@postgrespro.ru", "phone": "+70986942053"}
0005433415974	ADB18E	4724 614492	EKATERINA NIKITINA	{"phone": "+70715745933"}
0005433415975	D6BDBD	1504 199711	ALEKSANDR IVANOV	{"phone": "+70634550284"}
0005433415976	D6BDBD	7337 952432	VALENTINA ORLOVA	{"phone": "+70691764937"}
0005433415977	D6BDBD	5369 131395	ALENA POPOVA	{"email": "popova-a.02121974@postgrespro.ru", "phone": "+70866251618"}
0005433415978	6A115E	5163 147043	DMITRIY KOZLOV	{"email": "kozlovdmitriy.081967@postgrespro.ru", "phone": "+70847350046"}
0005433415979	0D5C76	7345 478467	NINA ZOTOVA	{"phone": "+70943259014"}
0005433415980	60B7C6	0340 303569	DARYA BELYAEVA	{"phone": "+70674238016"}
0005433415981	60B7C6	5137 994373	VIKTORIYA ERMAKOVA	{"phone": "+70185895060"}
0005433415982	901FF0	4335 002732	MARIYA KUZNECOVA	{"phone": "+70543144186"}
0005433415983	901FF0	2332 567558	OLGA POPOVA	{"phone": "+70538620033"}
0005433415984	EEC7FA	1313 561748	SVETLANA DENISOVA	{"email": "denisova-s_121965@postgrespro.ru", "phone": "+70048652663"}
0005433415985	EEC7FA	4208 687021	ALEKSANDR PETROV	{"phone": "+70828405734"}
0005433415986	2EC541	9996 997590	POLINA VASILEVA	{"email": "polina-vasileva06071977@postgrespro.ru", "phone": "+70430098112"}
0005433415987	2EC541	1388 646892	IRINA ARKHIPOVA	{"email": "arkhipovai_1982@postgrespro.ru", "phone": "+70653418740"}
0005433415988	DFF026	3647 731473	EVGENIY FEDOROV	{"email": "evgeniy_fedorov25011968@postgrespro.ru", "phone": "+70735621117"}
0005433415989	834144	6640 306030	TATYANA TITOVA	{"email": "tatyanatitova.111980@postgrespro.ru", "phone": "+70591289172"}
0005433415990	C79782	7833 238041	OLGA RYABOVA	{"phone": "+70032098234"}
0005433415991	D798B9	4900 765272	SERGEY VLASOV	{"email": "vlasov_sergey_28091981@postgrespro.ru", "phone": "+70517957501"}
0005433415992	10DDE0	6081 482848	OLESYA VLASOVA	{"phone": "+70013350248"}
0005433415993	10DDE0	7652 449310	NADEZHDA SMIRNOVA	{"email": "smirnova_nadezhda.1971@postgrespro.ru", "phone": "+70536135469"}
0005433415994	35CFA8	8737 824485	TATYANA ARKHIPOVA	{"email": "t-arkhipova.1975@postgrespro.ru", "phone": "+70756225268"}
0005433415995	35CFA8	4864 355400	NIKOLAY MAKAROV	{"phone": "+70591750412"}
0005433415996	35CFA8	5325 399587	DENIS FROLOV	{"phone": "+70313166813"}
0005433415997	1B7CEF	8127 724128	YURIY IVANOV	{"email": "ivanov_y_05011970@postgrespro.ru", "phone": "+70656328084"}
0005433415998	8A6644	1635 998766	ILYA POPOV	{"phone": "+70411622443"}
0005433415999	87DFB5	8638 946752	OLEG MOROZOV	{"email": "morozov-o-1969@postgrespro.ru", "phone": "+70029324045"}
0005433416000	87DFB5	3069 701326	ALEKSANDRA SMIRNOVA	{"phone": "+70919760324"}
0005433416001	002284	4243 472583	YULIYA POTAPOVA	{"email": "potapova-y031972@postgrespro.ru", "phone": "+70741844112"}
0005433416002	002284	2789 672030	ELENA MIRONOVA	{"email": "mironova-elena_051972@postgrespro.ru", "phone": "+70373308956"}
0005433416003	98F1F3	1217 937770	ANGELINA KUZNECOVA	{"phone": "+70518180295"}
0005433416004	799169	9125 284037	STANISLAV KARPOV	{"email": "karpov-s1979@postgrespro.ru", "phone": "+70239479799"}
0005433416005	799169	6072 600135	MAKSIM SCHERBAKOV	{"phone": "+70190961672"}
0005433416006	FFAFE0	1243 070210	NIKOLAY MOISEEV	{"phone": "+70283074883"}
0005433416007	433445	2476 358763	MARGARITA SOROKINA	{"phone": "+70185157988"}
0005433416008	76FA05	5783 576065	YURIY CHERNOV	{"phone": "+70966899727"}
0005433416009	5F716A	0947 579313	VALENTINA KOZLOVA	{"email": "vkozlova111965@postgrespro.ru", "phone": "+70450191545"}
0005433416010	3E834D	5211 518978	LARISA GUSEVA	{"email": "guseva-larisa.1971@postgrespro.ru", "phone": "+70608110310"}
0005433416011	3E834D	7191 179074	TATYANA LUKYANOVA	{"email": "lukyanova_tatyana-011991@postgrespro.ru", "phone": "+70080664987"}
0005433416012	00FFD1	9022 908803	SERGEY TARASOV	{"email": "tarasov.sergey-05021961@postgrespro.ru", "phone": "+70603459375"}
0005433416013	3B5B0C	6766 725322	OLEG NIKITIN	{"phone": "+70004226459"}
0005433416014	FC2331	3815 535473	GALINA SOKOLOVA	{"phone": "+70730773244"}
0005433416015	16E374	9518 528285	IRINA RYABOVA	{"email": "i.ryabova1972@postgrespro.ru", "phone": "+70590569884"}
0005433416016	62EE9B	9513 324862	MIKHAIL ANDREEV	{"phone": "+70146738452"}
0005433416017	62EE9B	7423 543529	ELENA SOKOLOVA	{"phone": "+70296982861"}
0005433416018	D24F88	4598 082191	VALENTINA STEPANOVA	{"email": "valentina-stepanova_06051978@postgrespro.ru", "phone": "+70938791932"}
0005433416019	D24F88	6662 660582	ANDREY NIKITIN	{"phone": "+70261183361"}
0005433416021	8F0FAC	8051 760083	YULIYA MARTYNOVA	{"email": "martynova.yuliya_25021981@postgrespro.ru", "phone": "+70486717502"}
0005433416022	8F0FAC	4072 104301	EKATERINA ORLOVA	{"email": "orlova.ekaterina_05111972@postgrespro.ru", "phone": "+70300063852"}
0005433416023	F8BA40	0348 380711	VERONIKA KOROLEVA	{"email": "v.koroleva_10031963@postgrespro.ru", "phone": "+70575610551"}
0005433416024	79B157	6118 483162	RAFIS NIKITIN	{"phone": "+70073092540"}
0005433416025	9BD5EE	8126 530939	ANTONINA ZAKHAROVA	{"phone": "+70149409206"}
0005433416026	40D71B	4163 481773	ELENA VASILEVA	{"phone": "+70235854263"}
0005433416027	8E2EE1	8248 027785	LILIYA FOMINA	{"phone": "+70617324576"}
0005433416028	8E2EE1	7473 295817	VLADIMIR ISAEV	{"phone": "+70088765825"}
0005433416029	8CC719	0956 350845	VITALIY ROMANOV	{"email": "romanov_v-051975@postgrespro.ru", "phone": "+70085324381"}
0005433416030	2FDC9B	2933 776755	ANDREY SHEVCHENKO	{"email": "shevchenko.andrey051987@postgrespro.ru", "phone": "+70868122891"}
0005433416031	F60CA7	6233 998335	NADEZHDA BELYAEVA	{"phone": "+70905110601"}
0005433416032	F60CA7	1032 842238	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr-081976@postgrespro.ru", "phone": "+70073918083"}
0005433416033	F60CA7	0673 157692	EKATERINA MIKHAYLOVA	{"email": "mikhaylova.ekaterina24061982@postgrespro.ru", "phone": "+70068280376"}
0005433416034	C232BD	9088 510856	MARGARITA MALYSHEVA	{"phone": "+70542102117"}
0005433416036	FD20D8	1937 463051	ANNA SMIRNOVA	{"email": "anna.smirnova_1968@postgrespro.ru", "phone": "+70222466158"}
0005433416037	82ABA3	8870 609718	ALEKSANDR KOZLOV	{"phone": "+70969695309"}
0005433416038	F0AD1B	1349 849951	LYUBOV POPOVA	{"phone": "+70601120583"}
0005433416039	F0AD1B	8448 913521	ANTONINA FOMINA	{"email": "a_fomina11021981@postgrespro.ru", "phone": "+70743782792"}
0005433416040	62CA81	9107 354323	IVAN KRASNOV	{"email": "i.krasnov-1970@postgrespro.ru", "phone": "+70243340835"}
0005433416041	44EB94	7949 513420	NIKOLAY IVANOV	{"phone": "+70817127272"}
0005433416042	44EB94	2408 934614	MARINA TITOVA	{"phone": "+70052797914"}
0005433416043	44EB94	1913 570382	NINA BELOVA	{"phone": "+70502196546"}
0005433416044	49BEC9	5807 952803	KONSTANTIN KARPOV	{"phone": "+70229367777"}
0005433416045	49BEC9	2893 825840	ALEKSEY KAZAKOV	{"email": "a-kazakov.06041963@postgrespro.ru", "phone": "+70129372046"}
0005433416046	49BEC9	7844 299555	ROMAN ALEKSEEV	{"email": "roman-alekseev061971@postgrespro.ru", "phone": "+70783433915"}
0005433416047	81E919	7431 426125	VLADIMIR PAVLOV	{"email": "vladimirpavlov101976@postgrespro.ru", "phone": "+70139065515"}
0005433416048	3CD8F8	8651 397782	ELENA NAZAROVA	{"phone": "+70616764222"}
0005433416049	3CD8F8	7916 761458	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir.101969@postgrespro.ru", "phone": "+70977075419"}
0005433416050	9C6907	0795 185277	SVETLANA MOROZOVA	{"email": "morozova.svetlana.1980@postgrespro.ru", "phone": "+70106760339"}
0005433416051	E7816E	2969 919663	SVETLANA SOROKINA	{"email": "svetlanasorokina_061970@postgrespro.ru", "phone": "+70126992169"}
0005433416052	1A9A3B	7038 249368	ELENA ERMAKOVA	{"email": "ermakova-e.25041966@postgrespro.ru", "phone": "+70160064881"}
0005433416053	4C7E52	1495 020495	GALINA ILINA	{"email": "ilinag.1982@postgrespro.ru", "phone": "+70727607027"}
0005433416054	369D9B	5586 025883	EKATERINA SIDOROVA	{"phone": "+70326528059"}
0005433416055	369D9B	5386 204413	VLADIMIR PAVLOV	{"email": "pavlovvladimir.1971@postgrespro.ru", "phone": "+70079275812"}
0005433416056	84A23E	3701 034876	ILYA VOLKOV	{"phone": "+70742546370"}
0005433416057	EA3B85	6785 045545	EKATERINA VOROBEVA	{"phone": "+70292314388"}
0005433416058	EA3B85	2481 781113	ILYAS KULIKOV	{"email": "kulikovi_06121968@postgrespro.ru", "phone": "+70460140409"}
0005433416059	EA3B85	0834 364213	TATYANA FROLOVA	{"email": "frolova_tatyana_041956@postgrespro.ru", "phone": "+70979115890"}
0005433416060	DDC218	6703 386419	VIKTOR BORISOV	{"email": "v_borisov_061975@postgrespro.ru", "phone": "+70139562396"}
0005433416061	89C1D5	2442 035944	VALENTINA ABRAMOVA	{"email": "abramova_valentina-03071967@postgrespro.ru", "phone": "+70957111278"}
0005433416062	89C1D5	3094 604986	DARYA KOROLEVA	{"email": "d.koroleva-1965@postgrespro.ru", "phone": "+70933909807"}
0005433416063	DF2B7A	1087 591772	SERGEY KARPOV	{"phone": "+70510723865"}
0005433416064	58D7C3	0112 180380	DENIS SEMENOV	{"phone": "+70825362376"}
0005433416065	58D7C3	1033 655903	KSENIYA BELOVA	{"phone": "+70505401039"}
0005433416066	0CA19A	0519 736703	ALEKSANDR IVANOV	{"phone": "+70624929866"}
0005433416067	46E31B	1419 178526	VALENTINA SOKOLOVA	{"email": "vsokolova1981@postgrespro.ru", "phone": "+70165583563"}
0005433416068	ED949F	9996 290245	OLGA ZAKHAROVA	{"phone": "+70730398390"}
0005433416069	ED949F	5236 608268	ANDREY EGOROV	{"email": "egorov.a.021980@postgrespro.ru", "phone": "+70000028623"}
0005433416070	4D9FCF	7255 722990	ARTEM IVANOV	{"email": "ivanov_artem1972@postgrespro.ru", "phone": "+70680921376"}
0005433416071	761288	5002 949822	SERGEY ANTONOV	{"phone": "+70190158987"}
0005433416072	761288	6082 974142	YULIYA KOROLEVA	{"email": "koroleva_y-091976@postgrespro.ru", "phone": "+70981848614"}
0005433416073	243BB0	8602 829452	ANDREY IVANOV	{"phone": "+70234220558"}
0005433416074	243BB0	2916 942260	NATALYA IVANOVA	{"email": "ivanovanatalya_021969@postgrespro.ru", "phone": "+70640998790"}
0005433416075	243BB0	6201 964596	RUSLAN SEMENOV	{"phone": "+70314444416"}
0005433416076	4560E4	0612 997192	NADEZHDA KALININA	{"email": "kalinina_nadezhda.101971@postgrespro.ru", "phone": "+70717245792"}
0005433416077	021D73	2168 013877	ALEKSEY GAVRILOV	{"phone": "+70412516047"}
0005433416078	46889D	4964 279342	ANDREY MAKSIMOV	{"email": "maksimova111986@postgrespro.ru", "phone": "+70831796570"}
0005433416079	01A42A	9495 737013	MIKHAIL IVANOV	{"phone": "+70225305371"}
0005433416080	395DF6	4940 686455	IVAN ISAEV	{"phone": "+70873923694"}
0005433416081	C51093	4026 782313	VLADIMIR PAVLOV	{"email": "vpavlov-111956@postgrespro.ru", "phone": "+70791418357"}
0005433416082	D9AD89	6292 956664	ANNA SMIRNOVA	{"email": "smirnova.a-10041965@postgrespro.ru", "phone": "+70566939506"}
0005433416083	D9AD89	2099 037883	EDUARD YAKOVLEV	{"email": "yakovlev-eduard-101972@postgrespro.ru", "phone": "+70044755743"}
0005433416084	41DC85	8697 097775	ANDREY MATVEEV	{"phone": "+70461564529"}
0005433416085	C0068B	3665 312224	ZINAIDA ORLOVA	{"phone": "+70880655245"}
0005433416086	C4265E	2992 065390	GALINA PAVLOVA	{"phone": "+70411097102"}
0005433416087	66B6F0	2170 202268	YULIYA GRISHINA	{"email": "grishinayuliya-08021968@postgrespro.ru", "phone": "+70168051781"}
0005433416088	66B6F0	3374 907601	VLADIMIR MOROZOV	{"phone": "+70059233438"}
0005433416089	51D762	1462 759505	ALEKSANDRA AKIMOVA	{"email": "akimova.a17091972@postgrespro.ru", "phone": "+70645665211"}
0005433416090	B8B484	9095 193287	VLADIMIR KAZAKOV	{"phone": "+70480082231"}
0005433416091	0B2129	3625 454360	ALEKSANDR KOROLEV	{"phone": "+70043954262"}
0005433416092	0B2129	7906 956189	MARIYA PAVLOVA	{"email": "m_pavlova_011971@postgrespro.ru", "phone": "+70199143184"}
0005433416093	0B2129	4776 025920	DMITRIY GRIGOREV	{"phone": "+70322193497"}
0005433416094	E6DAC5	6301 465543	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev-11111966@postgrespro.ru", "phone": "+70234567442"}
0005433416095	70CB16	7881 458820	VALENTINA SMIRNOVA	{"email": "valentina.smirnova13021978@postgrespro.ru", "phone": "+70914608730"}
0005433416096	70CB16	7159 645015	ANASTASIYA SCHERBAKOVA	{"email": "a.scherbakova.25031975@postgrespro.ru", "phone": "+70580360244"}
0005433416097	70CB16	7557 332098	VLADIMIR MAKSIMOV	{"email": "vladimir.maksimov.1987@postgrespro.ru", "phone": "+70265562218"}
0005433416098	78C4FF	6615 063111	LIDIYA NOVIKOVA	{"phone": "+70349033161"}
0005433416099	245814	8035 013256	GULSINA GORBUNOVA	{"phone": "+70210183682"}
0005433416100	245814	2289 985716	OLGA ALEKSEEVA	{"phone": "+70913917599"}
0005433416101	C9DB44	4088 239679	ANATOLIY SOROKIN	{"phone": "+70577499977"}
0005433416102	EDC8BD	3534 236830	IRINA FOMINA	{"email": "irina-fomina061979@postgrespro.ru", "phone": "+70454802593"}
0005433416103	93F03E	1753 170823	LYUDMILA VOLKOVA	{"email": "lvolkova_061977@postgrespro.ru", "phone": "+70665142839"}
0005433416104	BB4185	8811 726671	TIGRAN STEPANOV	{"phone": "+70143592756"}
0005433416105	FBCE3A	5541 464760	TATYANA IVANOVA	{"phone": "+70694386041"}
0005433416106	FBCE3A	2549 292800	SERGEY SOKOLOV	{"email": "sokolov.sergey-1967@postgrespro.ru", "phone": "+70303913089"}
0005433416107	E639E4	3917 987223	IVAN DENISOV	{"email": "i_denisov-13061968@postgrespro.ru", "phone": "+70996367096"}
0005433416108	4A0A77	4545 518606	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a_091988@postgrespro.ru", "phone": "+70263031302"}
0005433416109	6574FB	0437 861536	EKATERINA TIKHONOVA	{"email": "tikhonova_ekaterina_1968@postgrespro.ru", "phone": "+70464845210"}
0005433416110	6574FB	9027 352657	ANATOLIY NIKITIN	{"email": "nikitin-anatoliy.1963@postgrespro.ru", "phone": "+70896574013"}
0005433416111	8E87F9	6861 885512	OKSANA BARANOVA	{"phone": "+70847088509"}
0005433416112	D38968	0251 723104	ELIZAVETA GORBUNOVA	{"email": "egorbunova.28121963@postgrespro.ru", "phone": "+70887940291"}
0005433416113	7A3AEC	7911 711220	ANTON ALEKSANDROV	{"email": "aaleksandrov_051975@postgrespro.ru", "phone": "+70273687522"}
0005433416114	A5E180	7605 989665	LILIYA NIKIFOROVA	{"email": "liliyanikiforova-1980@postgrespro.ru", "phone": "+70801466575"}
0005433416115	0BCBBB	1813 997135	ANASTASIYA OSIPOVA	{"phone": "+70381957903"}
0005433416116	0BCBBB	3499 712312	VLADISLAV GERASIMOV	{"phone": "+70708696501"}
0005433416117	A55543	8855 194683	ALEKSANDR ZAYCEV	{"phone": "+70332082555"}
0005433416118	91423E	6017 322498	EVGENIY NIKITIN	{"phone": "+70137307056"}
0005433416119	230FF4	6068 498785	RUSLAN PETROV	{"email": "r-petrov.04031986@postgrespro.ru", "phone": "+70504663155"}
0005433416120	54E518	3596 776458	YULIYA KARPOVA	{"phone": "+70049782843"}
0005433416121	2C906D	3870 078269	OLGA MAKAROVA	{"email": "omakarova.111969@postgrespro.ru", "phone": "+70617667036"}
0005433416122	2C906D	1101 379244	INNA EGOROVA	{"email": "i.egorova.021979@postgrespro.ru", "phone": "+70882414393"}
0005433416123	434004	0166 709572	IRINA RODIONOVA	{"email": "i.rodionova.1961@postgrespro.ru", "phone": "+70322810196"}
0005433416124	940723	3287 119069	SVETLANA FADEEVA	{"email": "s_fadeeva_1966@postgrespro.ru", "phone": "+70005737183"}
0005433416125	0DAF8B	0544 019920	NATALYA SAVELEVA	{"phone": "+70667948220"}
0005433416126	0DAF8B	2274 161069	NATALYA BELOVA	{"email": "belova.n081971@postgrespro.ru", "phone": "+70079542102"}
0005433416127	998B23	9942 078762	NIKOLAY KISELEV	{"phone": "+70730608350"}
0005433416128	9833D2	5509 589198	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr1964@postgrespro.ru", "phone": "+70050436399"}
0005433416129	2B9BF2	7753 215420	RAISA FADEEVA	{"phone": "+70501725260"}
0005433416130	2B9BF2	4953 019294	VALENTINA KUZNECOVA	{"email": "v.kuznecova081974@postgrespro.ru", "phone": "+70437923109"}
0005433416131	DD3BBF	1846 873686	MARINA ABRAMOVA	{"email": "m_abramova_091971@postgrespro.ru", "phone": "+70885449146"}
0005433420249	8FAF77	4640 833467	VALERIY NIKOLAEV	{"email": "nikolaev-valeriy.041975@postgrespro.ru", "phone": "+70325786700"}
0005433420250	4D8188	8238 944606	PETR GRIGOREV	{"phone": "+70915624186"}
0005433420251	4D8188	2735 574507	EVA KUZNECOVA	{"email": "ekuznecova.27101974@postgrespro.ru", "phone": "+70757871578"}
0005433420252	660C7E	6268 110769	SVETLANA OSIPOVA	{"email": "osipova.s_18021972@postgrespro.ru", "phone": "+70885977804"}
0005433420253	660C7E	4209 237558	SERGEY KUZNECOV	{"phone": "+70505825775"}
0005433420254	3512D6	7590 567926	NINA GRISHINA	{"email": "n_grishina-011970@postgrespro.ru", "phone": "+70943545982"}
0005433420255	ADFF0B	9567 475318	VLADISLAV MOISEEV	{"email": "moiseev.vladislav_1974@postgrespro.ru", "phone": "+70878551200"}
0005433420256	ADFF0B	3636 592719	ALEKSANDR NAUMOV	{"email": "aleksandr_naumov1971@postgrespro.ru", "phone": "+70839338097"}
0005433420257	8D66C9	5241 013886	IRINA STEPANOVA	{"phone": "+70055450447"}
0005433420258	118C3A	7210 957560	VALENTINA MAKAROVA	{"phone": "+70027556946"}
0005433420259	A889C6	5450 677076	VLADISLAV VOLKOV	{"phone": "+70177683588"}
0005433420260	A889C6	0943 749306	VLADIMIR MAKAROV	{"email": "makarov_v10101980@postgrespro.ru", "phone": "+70847824674"}
0005433420261	A889C6	0726 531521	MARIYA ALEKSEEVA	{"email": "alekseeva-mariya_05021971@postgrespro.ru", "phone": "+70589184221"}
0005433420262	EAD334	0975 696711	YURIY KULIKOV	{"email": "yuriy.kulikov1977@postgrespro.ru", "phone": "+70603194748"}
0005433420263	F3E5CB	2418 398535	LIDIYA KONOVALOVA	{"email": "konovalova-lidiya_1970@postgrespro.ru", "phone": "+70060257518"}
0005433420264	703126	7730 118270	NADEZHDA MOROZOVA	{"email": "n.morozova-1985@postgrespro.ru", "phone": "+70247406026"}
0005433420265	D4A16B	8414 142261	ALEKSEY PAVLOV	{"phone": "+70907894437"}
0005433420266	893357	0524 770274	ANASTASIYA KONOVALOVA	{"phone": "+70401431579"}
0005433420267	A09186	0087 253120	LYUDMILA KOVALEVA	{"email": "kovaleva-l.1976@postgrespro.ru", "phone": "+70990796199"}
0005433420268	7581FB	8386 551993	TATYANA NIKOLAEVA	{"email": "tatyana_nikolaeva-12121974@postgrespro.ru", "phone": "+70412025306"}
0005433420269	C7B80F	7127 882073	NIKOLAY FROLOV	{"phone": "+70876523620"}
0005433420270	ED43E9	5758 273305	VLADIMIR POPOV	{"email": "vladimir.popov_1978@postgrespro.ru", "phone": "+70049058389"}
0005433420271	ED43E9	7810 665991	ANASTASIYA KUZMINA	{"phone": "+70927286588"}
0005433420272	62E2E8	5528 555547	KLAVDIYA GORBUNOVA	{"phone": "+70946329422"}
0005433420273	62E2E8	5634 249636	VIOLETTA VASILEVA	{"email": "vasileva-v1975@postgrespro.ru", "phone": "+70194227931"}
0005433420274	6BC504	1267 455796	MARIYA SOROKINA	{"phone": "+70410097229"}
0005433420275	6BC504	5575 537423	BORIS KUZNECOV	{"email": "kuznecovb_1985@postgrespro.ru", "phone": "+70205573576"}
0005433420276	FFB4D0	7183 228165	VLADIMIR EGOROV	{"email": "egorov.vladimir-1965@postgrespro.ru", "phone": "+70195773433"}
0005433420277	EBE326	6389 011718	LEONID ALEKSANDROV	{"email": "aleksandrov-leonid_121975@postgrespro.ru", "phone": "+70452895594"}
0005433420278	EBE326	2455 760626	ANASTASIYA STEPANOVA	{"phone": "+70046139616"}
0005433420279	497AA7	4794 094195	MARIYA ANTONOVA	{"email": "mariya_antonova.1970@postgrespro.ru", "phone": "+70599203238"}
0005433420280	2AACC9	5748 697761	IRINA STEPANOVA	{"email": "stepanova_irina.1976@postgrespro.ru", "phone": "+70452175568"}
0005433420281	809049	4283 545353	ANDREY SOROKIN	{"phone": "+70061778132"}
0005433420282	1755C3	7348 387531	VLADIMIR KRASNOV	{"email": "v_krasnov-15101978@postgrespro.ru", "phone": "+70388622807"}
0005433420283	D8C500	6178 345465	IRINA KUZMINA	{"phone": "+70777485320"}
0005433420284	D8C500	0631 603422	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy.011981@postgrespro.ru", "phone": "+70789919560"}
0005433420285	BC0577	7101 027019	ELENA MIRONOVA	{"email": "elena.mironova.25081975@postgrespro.ru", "phone": "+70742980118"}
0005433420286	8F402E	7111 582103	EVGENIY VOLKOV	{"email": "evgeniy.volkov-15091976@postgrespro.ru", "phone": "+70513273619"}
0005433420287	6D10DB	3606 762725	VIKTOR SCHERBAKOV	{"phone": "+70052469581"}
0005433420288	FC14FA	3876 792619	AMINA DANILOVA	{"phone": "+70230458016"}
0005433420289	FC14FA	8452 763044	SERGEY PETROV	{"phone": "+70842576253"}
0005433420290	E0D9F2	7939 876686	NINA DENISOVA	{"phone": "+70515183591"}
0005433420291	686BCD	2472 075254	POLINA BARANOVA	{"phone": "+70683776989"}
0005433420292	686BCD	2577 220948	VALENTINA TROFIMOVA	{"phone": "+70376031943"}
0005433420293	4B492C	1063 756470	TATYANA SOROKINA	{"email": "sorokinat101961@postgrespro.ru", "phone": "+70965151205"}
0005433420294	68E7CF	7972 001715	SERAFIMA ALEKSEEVA	{"phone": "+70518668015"}
0005433420295	504ECD	7204 006646	ZHANNA SOKOLOVA	{"email": "sokolova_zhanna_1977@postgrespro.ru", "phone": "+70596008629"}
0005433420296	504ECD	1943 871254	LEONID BORISOV	{"email": "borisov-leonid011968@postgrespro.ru", "phone": "+70528698571"}
0005433420297	D68A83	2104 660187	LYUBOV BARANOVA	{"email": "l-baranova_23031969@postgrespro.ru", "phone": "+70060889156"}
0005433420298	D68A83	8483 138929	ALEKSANDRA IVANOVA	{"email": "a-ivanova-19061966@postgrespro.ru", "phone": "+70234631951"}
0005433420299	7AA50D	8595 319696	VLADIMIR SEMENOV	{"email": "vsemenov12021970@postgrespro.ru", "phone": "+70108033507"}
0005433420300	DF0470	1743 567679	SVETLANA ZHUKOVA	{"email": "svetlana_zhukova_17031988@postgrespro.ru", "phone": "+70689245304"}
0005433420301	DA8D2F	3008 100213	MARIYA SEMENOVA	{"email": "m_semenova_021975@postgrespro.ru", "phone": "+70868460222"}
0005433420302	DA8D2F	0117 085850	ALEKSANDR BARANOV	{"phone": "+70916542932"}
0005433420303	8A8FB3	4073 065796	ANNA POPOVA	{"email": "a.popova_07011975@postgrespro.ru", "phone": "+70662567076"}
0005433420304	363818	1821 802677	NIKITA KOZLOV	{"email": "kozlovnikita_121977@postgrespro.ru", "phone": "+70167561479"}
0005433420305	363818	6333 685865	IRINA KONOVALOVA	{"email": "konovalova-irina-1955@postgrespro.ru", "phone": "+70273398653"}
0005433420306	33BB46	7394 581698	ALISHER IVANOV	{"email": "a.ivanov-17111974@postgrespro.ru", "phone": "+70391693192"}
0005433420307	33BB46	4486 991614	SERGEY ZHUKOV	{"email": "zhukov_sergey.22011974@postgrespro.ru", "phone": "+70351178311"}
0005433420308	33BB46	7257 142339	VALENTINA SIDOROVA	{"email": "sidorova-valentina_121978@postgrespro.ru", "phone": "+70401216750"}
0005433420309	5AC0A6	8273 436807	NIKOLAY MOROZOV	{"phone": "+70980264650"}
0005433420310	AD7F3A	0259 550169	MARINA DAVYDOVA	{"email": "marina.davydova1964@postgrespro.ru", "phone": "+70134322312"}
0005433420311	C18630	2600 021163	EVGENIY TARASOV	{"email": "e-tarasov021981@postgrespro.ru", "phone": "+70142204655"}
0005433420312	C18630	8239 055863	ILYA VOROBEV	{"phone": "+70103439943"}
0005433420313	7ADF28	9926 353806	KIRILL VASILEV	{"phone": "+70135276555"}
0005433420314	3D4AC2	2064 512894	LYUDMILA DMITRIEVA	{"phone": "+70099819917"}
0005433420315	A0D5F5	2241 893034	NIKOLAY ISAEV	{"email": "nikolay_isaev-19041981@postgrespro.ru", "phone": "+70274875884"}
0005433420316	A0D5F5	2557 379754	EDUARD GRIGOREV	{"phone": "+70228300097"}
0005433420317	21CDA9	0490 034434	ELENA IVANOVA	{"phone": "+70103533116"}
0005433420318	B92781	0431 318815	LILIYA NIKOLAEVA	{"phone": "+70698816833"}
0005433420319	B92781	9003 453755	EKATERINA YAKOVLEVA	{"email": "ekaterinayakovleva111968@postgrespro.ru", "phone": "+70067503232"}
0005433420320	D00E55	0622 467574	VLADIMIR FEDOROV	{"phone": "+70262812439"}
0005433420321	B6BE52	7778 693622	ELENA DAVYDOVA	{"email": "davydova.elena091978@postgrespro.ru", "phone": "+70451843774"}
0005433420322	DDA600	3276 921841	LIDIYA POPOVA	{"phone": "+70960706908"}
0005433420323	FEB91C	8122 296431	EVGENIY PETROV	{"email": "epetrov.1981@postgrespro.ru", "phone": "+70818211570"}
0005433420324	FEB91C	3930 869961	IGOR SCHERBAKOV	{"phone": "+70943911102"}
0005433420325	CBB215	5325 722354	LYUBOV KUZMINA	{"email": "kuzmina_l21021978@postgrespro.ru", "phone": "+70902420167"}
0005433420326	3114DB	4471 451375	ANTON SCHERBAKOV	{"email": "anton.scherbakov.1975@postgrespro.ru", "phone": "+70585525888"}
0005433420327	3114DB	4880 490472	VLADIMIR DENISOV	{"email": "denisov_vladimir.051976@postgrespro.ru", "phone": "+70587792482"}
0005433420328	C957C2	6013 103755	ALEKSEY MOISEEV	{"email": "moiseev.a-1981@postgrespro.ru", "phone": "+70653056879"}
0005433420389	832514	1556 373827	VLADIMIR GAVRILOV	{"phone": "+70670775818"}
0005433420329	22B4B8	1711 340997	DARYA GUSEVA	{"email": "darya_guseva_1970@postgrespro.ru", "phone": "+70858386494"}
0005433420330	22B4B8	4811 139140	LIDIYA NESTEROVA	{"email": "lnesterova_1972@postgrespro.ru", "phone": "+70539683899"}
0005433420331	36469B	6075 417874	INNA ZHUKOVA	{"email": "i.zhukova061969@postgrespro.ru", "phone": "+70082552965"}
0005433420332	36469B	9310 575058	ANTON EGOROV	{"email": "a_egorov-091978@postgrespro.ru", "phone": "+70506399252"}
0005433420333	36469B	5765 824989	DMITRIY ILIN	{"email": "dmitriyilin101967@postgrespro.ru", "phone": "+70217212991"}
0005433420334	1E7649	0624 730179	ANASTASIYA GORBUNOVA	{"phone": "+70799127170"}
0005433420335	F5C5BD	9746 515480	MARINA MOROZOVA	{"email": "morozova_m.1965@postgrespro.ru", "phone": "+70567068258"}
0005433420336	B68C5B	1653 306497	SERGEY POPOV	{"phone": "+70297276898"}
0005433420337	522403	0285 565351	IRINA ZAKHAROVA	{"phone": "+70535909903"}
0005433420338	63A9FD	3783 022242	VLADIMIR STEPANOV	{"phone": "+70960368393"}
0005433420339	7DA84B	0880 939681	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova-06051968@postgrespro.ru", "phone": "+70805972025"}
0005433420340	53FA9E	5651 868669	MARINA EGOROVA	{"phone": "+70229639806"}
0005433420341	C59A42	6656 244380	VIKTOR FOMIN	{"phone": "+70160417831"}
0005433420342	24B760	9761 091372	ANNA IVANOVA	{"email": "ivanovaa_09081982@postgrespro.ru", "phone": "+70257289344"}
0005433420343	E1B638	9361 696893	NIKITA KUZMIN	{"email": "n.kuzmin061969@postgrespro.ru", "phone": "+70748080510"}
0005433420344	823472	4963 120118	ELENA ANDREEVA	{"email": "andreeva.elena_02021966@postgrespro.ru", "phone": "+70141617397"}
0005433420345	823472	7264 667142	NINA POPOVA	{"phone": "+70732031124"}
0005433420346	CD8C14	1477 571312	SERGEY VOROBEV	{"phone": "+70800356645"}
0005433420347	FFAA40	3939 145288	LYUDMILA AFANASEVA	{"phone": "+70923335407"}
0005433420348	EDEB10	7969 371850	DMITRIY NIKOLAEV	{"email": "nikolaev_dmitriy.1967@postgrespro.ru", "phone": "+70585211362"}
0005433420349	EDEB10	4659 708906	YULIYA PETROVA	{"phone": "+70386809207"}
0005433420350	EDEB10	2338 855366	VLADIMIR KISELEV	{"email": "kiselevv20071967@postgrespro.ru", "phone": "+70931815626"}
0005433420351	70F7CF	3602 929062	EKATERINA IVANOVA	{"email": "ekaterina-ivanova1970@postgrespro.ru", "phone": "+70028219885"}
0005433420352	70F7CF	4480 629378	KRISTINA DMITRIEVA	{"phone": "+70189424009"}
0005433420353	FF7DC7	7011 634710	GENNADIY SAVELEV	{"email": "savelev.g041985@postgrespro.ru", "phone": "+70656476215"}
0005433420354	FF7DC7	8982 411757	ILYA SMIRNOV	{"email": "i.smirnov-1962@postgrespro.ru", "phone": "+70071501985"}
0005433420355	6C182D	9026 570728	VALERIY KONOVALOV	{"phone": "+70860320981"}
0005433420356	C12AA6	4741 380258	VLADISLAV ZAKHAROV	{"phone": "+70691758141"}
0005433420357	C64F27	4708 040279	ARSENIY MAKAROV	{"email": "arseniymakarov_1965@postgrespro.ru", "phone": "+70804025750"}
0005433420358	C64F27	9067 276047	IVAN PAVLOV	{"email": "ivan-pavlov_111966@postgrespro.ru", "phone": "+70619848967"}
0005433420359	1E5236	7929 154246	VITALIY TARASOV	{"phone": "+70680329780"}
0005433420360	1E5236	1714 282488	ANNA ANDREEVA	{"phone": "+70464748398"}
0005433420361	CE89D1	3656 476627	OLEG BORISOV	{"email": "borisov_o-1973@postgrespro.ru", "phone": "+70126935176"}
0005433420362	A311B7	8363 683722	ILYA KRASNOV	{"email": "krasnov.ilya-1976@postgrespro.ru", "phone": "+70924266573"}
0005433420363	A311B7	7980 355363	VERA ZOTOVA	{"email": "zotova_vera-30011976@postgrespro.ru", "phone": "+70984166859"}
0005433420364	A311B7	4642 411671	INNA NIKIFOROVA	{"email": "nikiforova.i_021981@postgrespro.ru", "phone": "+70570065607"}
0005433420365	5A46F2	6132 791138	ALEKSANDR SAVELEV	{"phone": "+70998777854"}
0005433420366	563DE2	4285 015105	ALEKSANDRA SOROKINA	{"email": "a.sorokina-05011982@postgrespro.ru", "phone": "+70746872968"}
0005433420367	C69576	7375 736534	ARMEN ZAKHAROV	{"email": "a_zakharov_051971@postgrespro.ru", "phone": "+70845718743"}
0005433420368	7415BD	0081 635076	VLADIMIR KULIKOV	{"phone": "+70204986527"}
0005433420369	B5E0F5	3223 831281	LYUDMILA KALININA	{"email": "lyudmilakalinina.021982@postgrespro.ru", "phone": "+70100295320"}
0005433420370	4CBA8E	7347 746487	IRINA IVANOVA	{"email": "ivanova_i.1971@postgrespro.ru", "phone": "+70422826074"}
0005433420371	B7BCF0	7889 169544	DARYA KUZNECOVA	{"email": "dkuznecova-041983@postgrespro.ru", "phone": "+70125793258"}
0005433420372	207788	9784 995568	NATALYA ROMANOVA	{"phone": "+70262435702"}
0005433420373	207788	8274 375779	ANDREY IVANOV	{"email": "andrey.ivanov-12111971@postgrespro.ru", "phone": "+70288171449"}
0005433420374	78FF4F	2717 651945	IGOR BELOV	{"email": "i.belov.21071979@postgrespro.ru", "phone": "+70955944828"}
0005433420375	D03464	9060 580860	STEPAN ZAYCEV	{"phone": "+70508833852"}
0005433420376	387DB2	6269 211435	VERONIKA NOVIKOVA	{"phone": "+70285336236"}
0005433420377	2EC96F	3730 547776	VYACHESLAV MAKAROV	{"phone": "+70441527298"}
0005433420378	2EC96F	3250 840394	ALENA MOROZOVA	{"phone": "+70170594719"}
0005433420379	2EC96F	5793 929407	ROMAN MIRONOV	{"phone": "+70078059040"}
0005433420380	27BCA0	8305 479798	LYUDMILA NIKITINA	{"phone": "+70100162892"}
0005433420381	27BCA0	3157 870757	MAKSIM KONOVALOV	{"phone": "+70545234812"}
0005433420382	15D38A	4149 394016	MARINA ALEKSEEVA	{"phone": "+70814032772"}
0005433420383	23AA1C	7236 216899	EVGENIY MOROZOV	{"phone": "+70386473476"}
0005433420384	07EFD9	1550 802099	SOFYA FEDOROVA	{"email": "fedorovas_31071978@postgrespro.ru", "phone": "+70486348423"}
0005433420385	A51F04	3153 354761	TATYANA NESTEROVA	{"email": "nesterova.t.30091982@postgrespro.ru", "phone": "+70642611070"}
0005433420386	EB1D1E	0946 263554	OLGA ORLOVA	{"phone": "+70750246366"}
0005433420387	832514	7034 464240	ANDREY NIKOLAEV	{"email": "anikolaev_23021972@postgrespro.ru", "phone": "+70289025765"}
0005433420388	832514	5977 705675	DMITRIY EGOROV	{"email": "egorov_d-22121973@postgrespro.ru", "phone": "+70588407235"}
0005433420390	791129	3200 672353	MARIYA ZOTOVA	{"email": "mariya_zotova-04091964@postgrespro.ru", "phone": "+70122524499"}
0005433420391	791129	2074 501566	PETR ANTONOV	{"email": "p-antonov-1978@postgrespro.ru", "phone": "+70240778257"}
0005433420392	D1330C	9444 076908	ANDREY ABRAMOV	{"phone": "+70228851886"}
0005433420393	D1330C	7355 739738	LIDIYA ZAYCEVA	{"email": "zayceva.l-081969@postgrespro.ru", "phone": "+70328903454"}
0005433420394	D1330C	7090 479469	IRINA LUKYANOVA	{"email": "i_lukyanova_27011979@postgrespro.ru", "phone": "+70206284406"}
0005433420395	653415	4931 102806	SERGEY NIKITIN	{"email": "nikitin-sergey.22071975@postgrespro.ru", "phone": "+70361989415"}
0005433420396	BFCC6D	8576 014227	KSENIYA KARPOVA	{"email": "k.karpova1976@postgrespro.ru", "phone": "+70303846399"}
0005433420397	F68787	4126 592622	SVETLANA LEBEDEVA	{"phone": "+70090615805"}
0005433420398	D7903D	0673 719497	OKSANA ANTONOVA	{"phone": "+70553553705"}
0005433420399	D7903D	6473 069336	PETR SOLOVEV	{"email": "petr_solovev.19091971@postgrespro.ru", "phone": "+70788621406"}
0005433420400	8F664E	2602 981381	MIKHAIL TIMOFEEV	{"email": "timofeev.m-1978@postgrespro.ru", "phone": "+70908098666"}
0005433420401	C2B64B	7030 634813	LIDIYA FEDOROVA	{"email": "lidiya_fedorova_1978@postgrespro.ru", "phone": "+70139700600"}
0005433420402	4DB43A	9770 828150	DMITRIY IVANOV	{"phone": "+70788991150"}
0005433420403	5785E5	0180 878045	NATALYA KOLESNIKOVA	{"phone": "+70600596306"}
0005433420404	C5D4CA	1173 329727	LYUBOV SERGEEVA	{"email": "l_sergeeva-011963@postgrespro.ru", "phone": "+70160382590"}
0005433420405	D121B8	4410 608843	NINA MOISEEVA	{"phone": "+70129807895"}
0005433420406	1BBDE4	1051 550948	DMITRIY BARANOV	{"email": "baranov.d.23041976@postgrespro.ru", "phone": "+70192765311"}
0005433420407	86E0D2	4865 026079	ANDREY RODIONOV	{"phone": "+70550447239"}
0005433420408	91282F	9738 062486	KRISTINA ANDREEVA	{"phone": "+70247448109"}
0005433420409	330E07	5322 946922	VLADISLAV PAVLOV	{"phone": "+70279240625"}
0005433420410	40818D	6154 891080	LYUDMILA CHERNOVA	{"email": "lyudmilachernova-01091976@postgrespro.ru", "phone": "+70401203229"}
0005433420411	40818D	2682 995684	SERGEY RODIONOV	{"email": "s.rodionov_03101975@postgrespro.ru", "phone": "+70184867080"}
0005433420412	40818D	5851 942239	VYACHESLAV KUZMIN	{"email": "v-kuzmin-1963@postgrespro.ru", "phone": "+70799102519"}
0005433420413	CC9ED7	6105 461610	NADEZHDA ALEKSEEVA	{"phone": "+70697093967"}
0005433420414	410097	4597 662307	ILYA MAKAROV	{"email": "makarov.i-15061965@postgrespro.ru", "phone": "+70721018491"}
0005433420415	CDB4AC	8107 701529	ALEKSEY ZHUKOV	{"email": "aleksey-zhukov_021973@postgrespro.ru", "phone": "+70993394478"}
0005433420416	CDB4AC	6438 771629	EVGENIY IVANOV	{"email": "eivanov.1985@postgrespro.ru", "phone": "+70630091844"}
0005433420417	E2945D	0026 863813	ILYA MAKSIMOV	{"email": "maksimov-ilya.25091961@postgrespro.ru", "phone": "+70910009738"}
0005433420418	E2945D	3334 176497	ANDREY ILIN	{"phone": "+70532288812"}
0005433420419	E2945D	4171 093089	ANASTASIYA KARPOVA	{"phone": "+70799810685"}
0005433420420	EFDE7E	8016 000626	ALEKSEY MOROZOV	{"email": "a.morozov-1965@postgrespro.ru", "phone": "+70714098703"}
0005433420421	EFDE7E	3598 468838	VERA MOISEEVA	{"phone": "+70988500320"}
0005433420422	E9948D	4496 891364	RAILYA KOROLEVA	{"email": "r_koroleva.011988@postgrespro.ru", "phone": "+70134220741"}
0005433420423	DE542A	6428 874186	OKSANA SAVELEVA	{"phone": "+70664999173"}
0005433420424	28AEF3	8248 569318	VLADIMIR ZAKHAROV	{"phone": "+70219874941"}
0005433420425	EE887C	1229 216953	LYUBOV BOGDANOVA	{"phone": "+70618839145"}
0005433420426	639A33	1106 927298	GRIGORIY NIKITIN	{"email": "nikitin.g_25011983@postgrespro.ru", "phone": "+70287466311"}
0005433420537	8BB259	1310 271643	ANATOLIY ALEKSEEV	{"phone": "+70172866638"}
0005433420427	639A33	3546 289113	EKATERINA FOMINA	{"email": "e.fomina30031965@postgrespro.ru", "phone": "+70277476585"}
0005433420428	E9CCEA	1289 213109	NATALYA VOROBEVA	{"email": "vorobeva-n.081980@postgrespro.ru", "phone": "+70100885102"}
0005433420429	9EEB7C	3299 637037	YURIY SOLOVEV	{"email": "solovev-yuriy-04021967@postgrespro.ru", "phone": "+70528173342"}
0005433420430	9EEB7C	1602 407018	IRINA KUZNECOVA	{"email": "irina-kuznecova-1972@postgrespro.ru", "phone": "+70398013221"}
0005433420431	2CF75E	7372 583169	ANTONINA POPOVA	{"email": "antonina.popova_1970@postgrespro.ru", "phone": "+70257464391"}
0005433420432	32677A	8330 121456	NATALYA KALININA	{"phone": "+70962050930"}
0005433420433	5BD0A0	8788 116422	ANNA GORBUNOVA	{"phone": "+70909763022"}
0005433420434	5BD0A0	7689 336366	EVGENIY KUZNECOV	{"email": "kuznecov_e.1972@postgrespro.ru", "phone": "+70326154477"}
0005433420435	550DBE	1261 933798	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev.01021980@postgrespro.ru", "phone": "+70472930042"}
0005433420436	69D82C	3768 045694	TATYANA ANDREEVA	{"email": "tatyanaandreeva.101972@postgrespro.ru", "phone": "+70272672119"}
0005433420437	854459	3835 010648	ALEKSANDR ORLOV	{"email": "aleksandrorlov.1968@postgrespro.ru", "phone": "+70884577296"}
0005433420438	6ADC44	2395 348647	EKATERINA IVANOVA	{"phone": "+70977844765"}
0005433420439	63F284	6978 599931	VYACHESLAV SIDOROV	{"phone": "+70754068431"}
0005433420440	C7D175	0534 464652	VLADISLAV SOKOLOV	{"email": "vladislav.sokolov-031971@postgrespro.ru", "phone": "+70233885150"}
0005433420441	C7D175	9795 584993	NIKOLAY SERGEEV	{"phone": "+70774983221"}
0005433420442	DFAB3D	4196 429042	RAISA KUZNECOVA	{"email": "r.kuznecova1985@postgrespro.ru", "phone": "+70589820273"}
0005433420443	DFAB3D	4708 045428	ELENA NIKOLAEVA	{"phone": "+70478742936"}
0005433420444	ECCBBA	7143 500705	VALENTINA YAKOVLEVA	{"email": "vyakovleva_17091974@postgrespro.ru", "phone": "+70569612186"}
0005433420445	ECCBBA	7498 065580	VLADIMIR TIKHONOV	{"email": "vladimir_tikhonov031966@postgrespro.ru", "phone": "+70815461169"}
0005433420446	FFFB2E	7285 847353	VITALIY SEMENOV	{"email": "semenov-vitaliy.1965@postgrespro.ru", "phone": "+70137948048"}
0005433420447	FFFB2E	2055 886814	SERGEY BORISOV	{"email": "sergey-borisov1979@postgrespro.ru", "phone": "+70136644250"}
0005433420448	70F3AF	0625 990240	NINA ZHUKOVA	{"phone": "+70266040566"}
0005433420449	55FCCE	4068 176526	ANDREY SIDOROV	{"phone": "+70386249786"}
0005433420450	E35AA4	6526 145525	ALEKSANDRA BARANOVA	{"phone": "+70879571269"}
0005433420451	E35AA4	7231 153061	FEDOR MIRONOV	{"email": "f.mironov.24051973@postgrespro.ru", "phone": "+70885309880"}
0005433420452	613FC4	4190 371450	ANASTASIYA DENISOVA	{"phone": "+70416058258"}
0005433420453	EAACB5	7051 933048	LYUDMILA KULIKOVA	{"email": "lyudmila.kulikova_07101978@postgrespro.ru", "phone": "+70030445299"}
0005433420454	CCC85C	5944 959574	SVETLANA MARTYNOVA	{"phone": "+70418616258"}
0005433420455	EB5419	5122 417866	MIKHAIL KUZNECOV	{"phone": "+70018586039"}
0005433420456	0BE7B9	9869 621760	NIKOLAY SAVELEV	{"phone": "+70643359498"}
0005433420457	FCD4E7	8455 397318	LEONID IVANOV	{"email": "ivanov.l16021971@postgrespro.ru", "phone": "+70805046984"}
0005433420458	F04D7F	3250 636400	VYACHESLAV GERASIMOV	{"email": "gerasimovv-29071990@postgrespro.ru", "phone": "+70808550705"}
0005433420459	F04D7F	1780 000499	NADIYA NIKITINA	{"phone": "+70158060080"}
0005433420460	E97A1B	6751 772062	YURIY PETROV	{"email": "petrov.yuriy011973@postgrespro.ru", "phone": "+70852713418"}
0005433420461	BF8670	8091 579065	SERGEY AFANASEV	{"email": "s_afanasev.1961@postgrespro.ru", "phone": "+70402216233"}
0005433420462	0024CD	0594 422639	BOGDAN KOZLOV	{"phone": "+70748921330"}
0005433420463	2FE3A5	2228 964931	ROZA ANTONOVA	{"phone": "+70460145164"}
0005433420464	E13E5D	6860 324147	DARYA KUZNECOVA	{"phone": "+70297406325"}
0005433420465	FBF738	4853 551615	PAVEL MIKHAYLOV	{"phone": "+70490245710"}
0005433420466	FBF738	2491 472012	ANATOLIY GRIGOREV	{"phone": "+70248578380"}
0005433420467	116877	2546 340602	ELENA EGOROVA	{"email": "e-egorova.101968@postgrespro.ru", "phone": "+70783209970"}
0005433420468	116877	9996 821300	DENIS NIKOLAEV	{"email": "nikolaevdenis11041983@postgrespro.ru", "phone": "+70964841518"}
0005433420469	902978	8126 076478	MIKHAIL SOKOLOV	{"email": "mikhail.sokolov071973@postgrespro.ru", "phone": "+70822348759"}
0005433420470	EA6F21	1575 918022	EKATERINA NIKITINA	{"phone": "+70914603814"}
0005433420471	B0E6CC	3542 753480	ALEKSEY KOZLOV	{"email": "a_kozlov121969@postgrespro.ru", "phone": "+70767144227"}
0005433420472	F2A738	2751 592298	EKATERINA PAVLOVA	{"phone": "+70424148556"}
0005433420473	F2A738	7169 600741	IRINA IVANOVA	{"email": "iivanova_1959@postgrespro.ru", "phone": "+70815795890"}
0005433420474	AA682A	4638 807282	MARINA IVANOVA	{"email": "ivanova.marina.1966@postgrespro.ru", "phone": "+70955858928"}
0005433420475	E60F63	9611 741270	KIRILL KAZAKOV	{"email": "k_kazakov28031970@postgrespro.ru", "phone": "+70398505375"}
0005433420476	49C523	9397 436148	SERGEY VLASOV	{"email": "sergey.vlasov-12021969@postgrespro.ru", "phone": "+70423212964"}
0005433420477	49C523	3361 648629	MARGARITA FILIPPOVA	{"email": "margaritafilippova_1970@postgrespro.ru", "phone": "+70939467816"}
0005433420478	6BC0EC	5854 972837	ANTON MIKHAYLOV	{"phone": "+70912015246"}
0005433420479	6BC0EC	6605 117519	SVETLANA DAVYDOVA	{"phone": "+70100735465"}
0005433420480	17F314	5229 888739	NINA BORISOVA	{"email": "ninaborisova_1983@postgrespro.ru", "phone": "+70586690305"}
0005433420481	17F314	4336 380822	IGOR ABRAMOV	{"email": "abramov_i.14051972@postgrespro.ru", "phone": "+70330569835"}
0005433420482	35F65E	8188 870202	KONSTANTIN MEDVEDEV	{"email": "k_medvedev.1985@postgrespro.ru", "phone": "+70347339780"}
0005433420483	35F65E	8080 731430	TATYANA SMIRNOVA	{"email": "smirnova_tatyana.11021983@postgrespro.ru", "phone": "+70293290991"}
0005433420484	F8DC97	0108 171252	ELENA SERGEEVA	{"phone": "+70934596160"}
0005433420485	D84778	5124 150833	VLADIMIR FOMIN	{"email": "vladimir.fomin_031976@postgrespro.ru", "phone": "+70340648780"}
0005433420486	263F0D	4405 452794	DMITRIY STEPANOV	{"phone": "+70146879642"}
0005433420487	263F0D	7446 796513	OLESYA SIDOROVA	{"phone": "+70208514846"}
0005433420488	B2D45C	0140 927477	MIKHAIL GORBUNOV	{"email": "mgorbunov1976@postgrespro.ru", "phone": "+70476628342"}
0005433420489	810139	5895 253608	EKATERINA OSIPOVA	{"email": "osipovaekaterina_081982@postgrespro.ru", "phone": "+70695355275"}
0005433420490	810139	1501 107575	TATYANA DANILOVA	{"phone": "+70029802821"}
0005433420491	810139	7081 013048	ALEKSANDR ILIN	{"email": "ailin_29071968@postgrespro.ru", "phone": "+70708778146"}
0005433420492	69D495	0194 254463	ROMAN GUSEV	{"phone": "+70888564742"}
0005433420493	69D495	7853 777724	ANATOLIY DMITRIEV	{"email": "anatoliy.dmitriev.101971@postgrespro.ru", "phone": "+70931497853"}
0005433420494	AB81DC	0964 279483	ANTON POPOV	{"email": "anton_popov-081965@postgrespro.ru", "phone": "+70001272252"}
0005433420495	AB81DC	5769 681140	VLADIMIR GERASIMOV	{"email": "gerasimov-v011971@postgrespro.ru", "phone": "+70672629203"}
0005433420496	DC4DB0	5906 589845	VLADIMIR PAVLOV	{"email": "pavlov_v-011974@postgrespro.ru", "phone": "+70040431123"}
0005433420497	A3664F	0024 597839	EGOR ANDREEV	{"phone": "+70027894654"}
0005433420498	60DF85	0748 158231	BORIS KISELEV	{"phone": "+70408587470"}
0005433420499	A060A3	3201 813855	YURIY EGOROV	{"phone": "+70276499951"}
0005433420500	A060A3	9942 042971	VALENTINA MOISEEVA	{"phone": "+70047604031"}
0005433420501	86D85E	4698 093240	ANATOLIY NIKITIN	{"email": "anatoliy-nikitin1981@postgrespro.ru", "phone": "+70018111507"}
0005433420502	81E192	7859 719816	TATYANA SMIRNOVA	{"phone": "+70951548207"}
0005433420503	81E192	9019 827866	OLEG PETROV	{"email": "oleg-petrov01051981@postgrespro.ru", "phone": "+70019512350"}
0005433420504	981E01	1655 745699	ARTEM KISELEV	{"email": "artem-kiselev.1966@postgrespro.ru", "phone": "+70004601911"}
0005433420505	88B53A	9279 073015	BORIS RODIONOV	{"email": "rodionov_boris.23031972@postgrespro.ru", "phone": "+70650030165"}
0005433420506	49353E	7201 765898	YURIY IVANOV	{"email": "yuriy_ivanov.30061977@postgrespro.ru", "phone": "+70346305212"}
0005433420507	5D3ADB	6201 601739	GALINA BARANOVA	{"email": "gbaranova1980@postgrespro.ru", "phone": "+70955322832"}
0005433420508	F216E0	1529 628153	SERGEY ALEKSEEV	{"email": "sergey.alekseev081982@postgrespro.ru", "phone": "+70502484587"}
0005433420509	8B0EB8	6357 125713	POLINA ANISIMOVA	{"email": "anisimova-p.1982@postgrespro.ru", "phone": "+70501009890"}
0005433420510	106F43	6176 271322	DMITRIY MIRONOV	{"email": "mironov.d_081980@postgrespro.ru", "phone": "+70111300972"}
0005433420511	ADCF20	8600 376491	ALEKSANDR SEMENOV	{"email": "semenov-a_031985@postgrespro.ru", "phone": "+70744987498"}
0005433420512	ADCF20	5328 985853	NIKITA OSIPOV	{"phone": "+70363292640"}
0005433420513	4A56ED	6957 143668	ELENA EFIMOVA	{"email": "efimova-elena_1986@postgrespro.ru", "phone": "+70505905698"}
0005433420514	71434E	4089 511704	KARINA FEDOROVA	{"phone": "+70516847116"}
0005433420515	9248FF	5371 303272	SERGEY FROLOV	{"email": "frolov-s_05041974@postgrespro.ru", "phone": "+70221634485"}
0005433420516	AECB9A	5523 277264	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin1972@postgrespro.ru", "phone": "+70640136429"}
0005433420517	F32C96	3465 015678	VLADIMIR FOMIN	{"email": "fomin_v_29051966@postgrespro.ru", "phone": "+70470052144"}
0005433420518	F49C4F	4536 026443	ALENA NESTEROVA	{"email": "nesterovaa121953@postgrespro.ru", "phone": "+70507021429"}
0005433420519	F49C4F	9731 148749	TATYANA POLYAKOVA	{"email": "tpolyakova-04091961@postgrespro.ru", "phone": "+70388053064"}
0005433420520	A9111B	4851 086743	LYUBOV KAZAKOVA	{"email": "lyubov-kazakova_061970@postgrespro.ru", "phone": "+70444104398"}
0005433420521	A9111B	2251 419695	MARIYA DENISOVA	{"email": "mdenisova-1982@postgrespro.ru", "phone": "+70602148078"}
0005433420522	612AA2	8009 018707	ALEKSANDR GUSEV	{"email": "gusev.aleksandr_1971@postgrespro.ru", "phone": "+70490474950"}
0005433420523	5C1ABA	2376 776009	ALEKSANDR KOROLEV	{"email": "aleksandr-korolev_1962@postgrespro.ru", "phone": "+70039337986"}
0005433420524	D4EC7D	9007 270610	ELENA MAKAROVA	{"phone": "+70297020888"}
0005433420525	67CD7E	5764 372932	ANDREY STEPANOV	{"phone": "+70752925933"}
0005433420526	67CD7E	0469 836442	TATYANA NESTEROVA	{"phone": "+70565982115"}
0005433420527	867C0B	0671 235674	IRINA KOROLEVA	{"email": "koroleva_irina_1985@postgrespro.ru", "phone": "+70339416566"}
0005433420528	D16E6B	3968 519912	VLADIMIR YAKOVLEV	{"email": "yakovlevvladimir1971@postgrespro.ru", "phone": "+70339224838"}
0005433420529	D16E6B	0818 773353	PETR VASILEV	{"phone": "+70562230433"}
0005433420530	914009	0515 551308	TATYANA KOROLEVA	{"email": "koroleva-t_1961@postgrespro.ru", "phone": "+70624642233"}
0005433420531	0069AE	4384 562152	ALEKSANDR KUZNECOV	{"phone": "+70947439671"}
0005433420532	1B4BA8	1409 478008	LYUBOV PETROVA	{"phone": "+70401048353"}
0005433420533	C23463	5416 872897	EVGENIY BORISOV	{"email": "eborisov.091971@postgrespro.ru", "phone": "+70730293400"}
0005433420534	C4F93F	7893 443979	ALLA GORBUNOVA	{"email": "a.gorbunova.1973@postgrespro.ru", "phone": "+70542189463"}
0005433420535	65CE7B	0880 570424	SERGEY KISELEV	{"phone": "+70664023356"}
0005433420536	7ADF7F	1803 554802	REGINA LOGINOVA	{"phone": "+70132355127"}
0005433420538	C37CEA	7391 021816	SERGEY FILIPPOV	{"email": "filippov-sergey021985@postgrespro.ru", "phone": "+70935215400"}
0005433420539	6E64B7	6530 690983	ANTONINA ALEKSANDROVA	{"phone": "+70147658652"}
0005433420540	6E64B7	8326 414645	SVETLANA PETROVA	{"email": "svetlanapetrova.06081974@postgrespro.ru", "phone": "+70890224616"}
0005433420541	CA3E4B	2109 336364	SVETLANA IVANOVA	{"email": "svetlana.ivanova.10021973@postgrespro.ru", "phone": "+70077376969"}
0005433420542	CA3E4B	7419 594068	ARMAN ILIN	{"email": "ilin_arman-1977@postgrespro.ru", "phone": "+70838411992"}
0005433420543	2F19D5	0204 966672	ALEKSANDRA NIKITINA	{"email": "anikitina-081971@postgrespro.ru", "phone": "+70084775483"}
0005433420544	2F19D5	8983 439303	VERA MASLOVA	{"email": "vmaslova1982@postgrespro.ru", "phone": "+70691360418"}
0005433420545	4F63C3	7682 190540	ELIZAVETA VLASOVA	{"phone": "+70172562751"}
0005433420546	7209F3	1880 068797	ANDREY SHEVCHENKO	{"email": "shevchenko.andrey-091967@postgrespro.ru", "phone": "+70690853688"}
0005433420547	1E6F9D	5149 257239	IVAN SOKOLOV	{"phone": "+70772549756"}
0005433420548	20AB74	8183 669428	ANDREY FEDOROV	{"phone": "+70907966856"}
0005433420549	20AB74	2031 387783	POLINA MAKSIMOVA	{"email": "polina.maksimova1977@postgrespro.ru", "phone": "+70863910483"}
0005433420550	6BB120	7576 437607	TAMARA ABRAMOVA	{"phone": "+70750836308"}
0005433420551	6BB120	3816 316763	RAISA KOMAROVA	{"phone": "+70841516494"}
0005433420552	6BB120	2102 495290	SVYATOSLAV SERGEEV	{"phone": "+70224304212"}
0005433420553	6BB120	6197 893308	DMITRIY ALEKSEEV	{"phone": "+70133637959"}
0005433420554	D8E31F	6144 540284	VALENTINA DMITRIEVA	{"email": "dmitrievav061970@postgrespro.ru", "phone": "+70155746036"}
0005433420555	47DF93	7405 113276	LYUDMILA KOVALEVA	{"email": "l.kovaleva_071971@postgrespro.ru", "phone": "+70573489051"}
0005433420556	3B66FC	7499 208225	VALENTIN KISELEV	{"phone": "+70317239324"}
0005433420557	F0AAA1	7660 378718	EKATERINA POPOVA	{"email": "popova.e_24011973@postgrespro.ru", "phone": "+70053009632"}
0005433420558	00E592	8717 536020	ALEKSEY NOVIKOV	{"phone": "+70819082450"}
0005433420559	3C2512	4680 557879	MAKSIM OSIPOV	{"email": "mosipov-111970@postgrespro.ru", "phone": "+70252767129"}
0005433420560	2C48D9	6651 041456	OLEG IVANOV	{"email": "ivanovoleg_071979@postgrespro.ru", "phone": "+70480321564"}
0005433420561	5A6094	8136 671968	TATYANA SCHERBAKOVA	{"email": "t.scherbakova1967@postgrespro.ru", "phone": "+70624282726"}
0005433420562	AD9811	4472 139938	DMITRIY ANTONOV	{"email": "dantonov.1966@postgrespro.ru", "phone": "+70471095333"}
0005433420563	9BD942	6124 013157	IVAN FOMIN	{"phone": "+70190392075"}
0005433420564	6F1D77	1264 020114	TATYANA LOGINOVA	{"email": "t_loginova121984@postgrespro.ru", "phone": "+70519141831"}
0005433420565	935B40	1761 236977	OLGA KUZNECOVA	{"phone": "+70299194943"}
0005433420566	EE8743	6788 402813	TATYANA ILINA	{"email": "tilina-19031977@postgrespro.ru", "phone": "+70078602593"}
0005433420567	D40D40	6572 412777	ELENA KONOVALOVA	{"email": "ekonovalova121980@postgrespro.ru", "phone": "+70067210958"}
0005433420568	F461F7	9789 507956	RAISA POLYAKOVA	{"phone": "+70822806634"}
0005433420569	DBFCB8	4618 962930	EVGENIY KARPOV	{"phone": "+70538203256"}
0005433420570	3D2939	1462 550417	EKATERINA MAKSIMOVA	{"email": "ekaterina-maksimova011971@postgrespro.ru", "phone": "+70041053401"}
0005433420571	3D2939	4825 107434	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy_111978@postgrespro.ru", "phone": "+70031456531"}
0005433420572	0DB3C2	1096 900160	VALENTIN SERGEEV	{"email": "sergeev.valentin.22051957@postgrespro.ru", "phone": "+70002558349"}
0005433420573	0DB3C2	6323 648630	ELENA DAVYDOVA	{"email": "davydovae.051969@postgrespro.ru", "phone": "+70169505170"}
0005433420574	0DB3C2	9875 178265	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev14111977@postgrespro.ru", "phone": "+70069483741"}
0005433420575	C3B49F	1251 804078	DANIIL MATVEEV	{"email": "matveev_daniil-101981@postgrespro.ru", "phone": "+70172715269"}
0005433420576	3FA93A	0421 245500	VLADIMIR MAKSIMOV	{"phone": "+70368883330"}
0005433420577	F441DF	5426 628936	ELENA NOVIKOVA	{"email": "novikova-elena_02021980@postgrespro.ru", "phone": "+70447030222"}
0005433420578	4EAE67	7369 384799	TATYANA POTAPOVA	{"phone": "+70804081329"}
0005433420579	CDA378	5136 579842	ALEKSEY IVANOV	{"email": "aleksey_ivanov26021965@postgrespro.ru", "phone": "+70954046554"}
0005433420580	CDA378	3140 281422	VALENTINA MELNIKOVA	{"email": "melnikovav-101977@postgrespro.ru", "phone": "+70247561120"}
0005433420581	7EDEF1	0727 520990	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko-15041969@postgrespro.ru", "phone": "+70509634722"}
0005433420582	7EDEF1	6244 252448	ANNA VASILEVA	{"email": "anna.vasileva-021967@postgrespro.ru", "phone": "+70937784501"}
0005433420583	CCCD57	1302 073011	IVAN ISAEV	{"phone": "+70009206067"}
0005433420584	20EE6A	6627 842567	TATYANA YAKOVLEVA	{"email": "yakovleva.tatyana24061976@postgrespro.ru", "phone": "+70464045792"}
0005433420585	0C1128	1278 677279	VYACHESLAV MOROZOV	{"email": "morozovvyacheslav_1965@postgrespro.ru", "phone": "+70828011805"}
0005433420586	F63951	9939 288146	OLGA SOROKINA	{"email": "o_sorokina_011972@postgrespro.ru", "phone": "+70623151249"}
0005433420587	F63951	7101 746241	ANNA KAZAKOVA	{"email": "kazakova-anna.021968@postgrespro.ru", "phone": "+70067567969"}
0005433420588	708652	7400 933067	ANNA SEMENOVA	{"phone": "+70283377621"}
0005433420589	708652	6368 601464	PAVEL RODIONOV	{"phone": "+70186731166"}
0005433420590	92AB7B	2094 589885	VERA ILINA	{"email": "v-ilina_03101965@postgrespro.ru", "phone": "+70987705815"}
0005433420591	05C51D	4855 887339	PAVEL BONDARENKO	{"phone": "+70989965361"}
0005433420592	9E45C4	9863 181190	GENNADIY SMIRNOV	{"phone": "+70696159095"}
0005433420593	9E45C4	5762 519565	NIKOLAY NIKOLAEV	{"email": "nikolaev_nikolay-041969@postgrespro.ru", "phone": "+70772040921"}
0005433420594	9DAC3B	7144 216359	GALINA MIRONOVA	{"phone": "+70545744601"}
0005433420595	505918	2781 370789	OKSANA FEDOROVA	{"email": "fedorovao-1984@postgrespro.ru", "phone": "+70619147493"}
0005433420596	505918	2218 503543	GALINA GAVRILOVA	{"phone": "+70039679437"}
0005433420597	01554C	4642 881922	NADEZHDA ALEKSANDROVA	{"phone": "+70437588052"}
0005433420598	01554C	4544 676928	DMITRIY MAKAROV	{"phone": "+70818132103"}
0005433420599	06E83B	6699 270169	NIKOLAY ISAEV	{"email": "nisaev1976@postgrespro.ru", "phone": "+70678856011"}
0005433420600	06E83B	9188 115032	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir.1967@postgrespro.ru", "phone": "+70246937252"}
0005433420601	501EF5	1315 574066	ALEKSANDR GAVRILOV	{"phone": "+70905875929"}
0005433420602	501EF5	7065 912847	VALENTINA ZHUKOVA	{"phone": "+70165459882"}
0005433420603	A35E2C	2050 427744	ZINAIDA ISAEVA	{"email": "z_isaeva.05081968@postgrespro.ru", "phone": "+70319453642"}
0005433420604	A35E2C	3167 272194	KRISTINA ERMAKOVA	{"email": "ermakova-kristina_1983@postgrespro.ru", "phone": "+70978697847"}
0005433420605	AFD22A	6478 987869	EVGENIY MOROZOV	{"email": "morozov-e-25021968@postgrespro.ru", "phone": "+70788450151"}
0005433420606	6F59E8	6036 146641	EVGENIY ANDREEV	{"email": "andreev.evgeniy_1976@postgrespro.ru", "phone": "+70825309753"}
0005433420607	B31A3F	2827 904894	STANISLAV DENISOV	{"email": "denisov-stanislav.021979@postgrespro.ru", "phone": "+70258751209"}
0005433420608	2856EC	9676 252527	SERGEY DENISOV	{"email": "denisovsergey_061976@postgrespro.ru", "phone": "+70646435798"}
0005433420609	920D40	5604 524451	LEONID KUZMIN	{"phone": "+70243488986"}
0005433420610	AA1B88	4177 220491	DANILA ZAYCEV	{"email": "zaycev_danila_1978@postgrespro.ru", "phone": "+70300972100"}
0005433420611	14A8BC	4933 879461	VIKTOR OSIPOV	{"phone": "+70193035271"}
0005433420612	14A8BC	9492 682902	ALLA PAVLOVA	{"phone": "+70140815983"}
0005433420613	F21C99	7769 598832	ALEKSANDR KUZNECOV	{"phone": "+70475117673"}
0005433420614	61C838	0089 615173	ALEKSANDR MOROZOV	{"phone": "+70121649060"}
0005433420615	E2DF31	6350 296857	GALINA SIDOROVA	{"phone": "+70347734808"}
0005433420616	D57647	8123 288900	DMITRIY MAKSIMOV	{"email": "maksimov_dmitriy_18121979@postgrespro.ru", "phone": "+70511065027"}
0005433420617	3E9A59	5836 322908	DMITRIY ZHURAVLEV	{"email": "zhuravlevd.101973@postgrespro.ru", "phone": "+70831798029"}
0005433420618	3E9A59	5302 423721	MARIYA GORBUNOVA	{"phone": "+70611024692"}
0005433420619	D36D4C	9929 473588	POLINA DAVYDOVA	{"phone": "+70677633944"}
0005433420620	F7BE2A	3056 949582	ALEKSEY FROLOV	{"email": "a_frolov081976@postgrespro.ru", "phone": "+70378399699"}
0005433420621	F7BE2A	7113 117396	MAKSIM FEDOROV	{"email": "maksim-fedorov111975@postgrespro.ru", "phone": "+70065957915"}
0005433420622	A29A29	8481 523314	YURIY NAUMOV	{"email": "naumov-y-26071981@postgrespro.ru", "phone": "+70218362296"}
0005433420623	58AA9A	6523 905224	RASHIT SCHERBAKOV	{"phone": "+70190859987"}
0005433420624	9F57EA	5896 852950	ELENA MEDVEDEVA	{"phone": "+70277958430"}
0005433420625	D19444	3902 650559	NADEZHDA SOROKINA	{"email": "sorokina.nadezhda_081976@postgrespro.ru", "phone": "+70889061320"}
0005433420626	CCBE38	5429 301130	KSENIYA MAKSIMOVA	{"email": "kseniya-maksimova_1971@postgrespro.ru", "phone": "+70305728639"}
0005433420627	788DC6	3669 479312	GALINA FILIPPOVA	{"phone": "+70085067078"}
0005433420628	499BD9	1345 259569	MARIYA SOROKINA	{"phone": "+70161340089"}
0005433420629	1D369A	4332 628139	EGOR MAKAROV	{"phone": "+70359494673"}
0005433420630	4858B2	2891 209325	LYUBOV VOLKOVA	{"phone": "+70844419201"}
0005433420631	4858B2	0913 900547	MARIYA KUZNECOVA	{"email": "kuznecova_mariya-011970@postgrespro.ru", "phone": "+70767586473"}
0005433420632	BE49E8	4321 299220	SERGEY GUSEV	{"phone": "+70917315568"}
0005433420633	ED8B68	5466 657089	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda1965@postgrespro.ru", "phone": "+70696184865"}
0005433420634	6D1893	2166 361204	LYUBOV FOMINA	{"phone": "+70089176660"}
0005433420635	4B3EE9	0066 461439	TAMARA MELNIKOVA	{"phone": "+70516270657"}
0005433420636	4B3EE9	6370 884070	FANIS KULIKOV	{"phone": "+70732946876"}
0005433420637	6EB1F6	7715 178964	ELENA TIKHONOVA	{"phone": "+70340989223"}
0005433420638	F45C79	2168 645436	LYUDMILA SOROKINA	{"phone": "+70630841173"}
0005433420639	F45C79	5748 504175	EVGENIY GUSEV	{"phone": "+70862599100"}
0005433420640	F45C79	0247 649700	ELVIRA POPOVA	{"phone": "+70874036823"}
0005433420641	611938	8713 702903	PETR KOZLOV	{"phone": "+70487905098"}
0005433420642	60861F	0340 561477	ALEKSANDR KOZLOV	{"phone": "+70988377237"}
0005433420643	60861F	6595 336004	IRINA SCHERBAKOVA	{"phone": "+70315240704"}
0005433420644	60861F	3500 046849	KRISTINA MELNIKOVA	{"phone": "+70176244954"}
0005433420645	8DDB27	2720 382162	VIKTOR DENISOV	{"email": "viktor_denisov02101968@postgrespro.ru", "phone": "+70344791421"}
0005433420646	8DDB27	1569 964187	VERA BELOVA	{"email": "vera.belova-28111987@postgrespro.ru", "phone": "+70614677613"}
0005433420647	F5F058	3487 998834	ALEKSEY EGOROV	{"phone": "+70762986025"}
0005433420648	13C767	0368 309830	PAVEL STEPANOV	{"email": "pstepanov-30111966@postgrespro.ru", "phone": "+70251889364"}
0005433420649	BB82F6	6752 602918	MIKHAIL ABRAMOV	{"email": "m-abramov.03061986@postgrespro.ru", "phone": "+70888545406"}
0005433420650	E6C6CF	8413 534948	VLADIMIR STEPANOV	{"phone": "+70499997299"}
0005433434180	7C8D1B	1633 852536	NINA PETROVA	{"email": "petrova.n-031975@postgrespro.ru", "phone": "+70711179608"}
0005433434181	91EC43	7194 735219	LILIYA LAZAREVA	{"email": "liliya.lazareva02071970@postgrespro.ru", "phone": "+70340949730"}
0005433434182	3457BF	9054 598524	ALEKSEY SCHERBAKOV	{"phone": "+70768993650"}
0005433434183	3457BF	6289 774025	DMITRIY SOROKIN	{"email": "d-sorokin-13031968@postgrespro.ru", "phone": "+70577561777"}
0005433434184	F94632	7845 974094	KSENIYA ILINA	{"email": "k-ilina021975@postgrespro.ru", "phone": "+70320143433"}
0005433434185	F94632	6799 623316	YULIYA POPOVA	{"phone": "+70999674625"}
0005433434186	4C5619	2024 847211	GALINA MAKAROVA	{"phone": "+70719276809"}
0005433434187	4C5619	8874 521421	NADEZHDA NAUMOVA	{"email": "naumova_nadezhda_011964@postgrespro.ru", "phone": "+70872720657"}
0005433434188	7C2268	3331 564196	YULIYA KUZMINA	{"email": "yuliya-kuzmina-1966@postgrespro.ru", "phone": "+70686084480"}
0005433434189	7C2268	8820 138411	YURIY MIRONOV	{"email": "y_mironov.1973@postgrespro.ru", "phone": "+70123776432"}
0005433434190	4A2A7F	4358 669983	MAKSIM ZAKHAROV	{"email": "m-zakharov091975@postgrespro.ru", "phone": "+70330416399"}
0005433434191	4A2A7F	1350 030399	NIKOLAY SEMENOV	{"phone": "+70147639791"}
0005433434192	9C23C5	4633 692899	ZHANNA EFREMOVA	{"phone": "+70060847189"}
0005433434193	5E3D97	6305 466025	VALENTINA BORISOVA	{"phone": "+70094832770"}
0005433434194	084F45	6598 567827	ALEKSEY PETROV	{"phone": "+70438650713"}
0005433434195	084F45	4470 555889	ELENA KOROLEVA	{"email": "elena_koroleva-25111973@postgrespro.ru", "phone": "+70099887002"}
0005433434196	084F45	1956 140064	GULNARA KUZNECOVA	{"email": "g.kuznecova-081973@postgrespro.ru", "phone": "+70469706639"}
0005433434197	4FB0EF	2259 256051	ANNA SOLOVEVA	{"email": "soloveva_anna.1987@postgrespro.ru", "phone": "+70806236763"}
0005433434198	2EDB5B	2316 832998	VENERA LUKYANOVA	{"phone": "+70267294939"}
0005433434199	052C33	0643 667341	VITALIY PETROV	{"phone": "+70754853212"}
0005433434200	979354	3874 113260	SVETLANA GAVRILOVA	{"phone": "+70163450176"}
0005433434201	979354	4680 531884	ANTON CHERNOV	{"email": "anton.chernov-071967@postgrespro.ru", "phone": "+70554410454"}
0005433434202	89E3C6	0116 465721	VALERIY VOLKOV	{"email": "v_volkov071965@postgrespro.ru", "phone": "+70304715512"}
0005433434203	89E3C6	7449 954190	SVETLANA GERASIMOVA	{"phone": "+70482545401"}
0005433434204	2725E1	0459 800637	ELENA STEPANOVA	{"email": "e.stepanova061978@postgrespro.ru", "phone": "+70075868605"}
0005433434205	2725E1	8523 304006	ALEKSEY KOROLEV	{"phone": "+70007370530"}
0005433434206	5A437B	3128 913224	ELENA KUZNECOVA	{"email": "elena.kuznecova_011972@postgrespro.ru", "phone": "+70896319138"}
0005433434207	5A437B	8421 412776	MARIYA ZOTOVA	{"phone": "+70565969111"}
0005433434208	9F7E63	0521 596852	ELENA LUKYANOVA	{"email": "lukyanova-e.21101976@postgrespro.ru", "phone": "+70042275044"}
0005433434209	344190	9545 366049	ANNA GUSEVA	{"phone": "+70766177144"}
0005433434210	344190	1314 906818	SERGEY KISELEV	{"email": "kiselevs_04081962@postgrespro.ru", "phone": "+70762998972"}
0005433434211	471285	5523 432367	MIKHAIL SERGEEV	{"email": "sergeev-mikhail101965@postgrespro.ru", "phone": "+70255835422"}
0005433434212	09BA0F	3736 799880	KARINA DMITRIEVA	{"email": "karina-dmitrieva1975@postgrespro.ru", "phone": "+70451827864"}
0005433434213	AE735E	8534 538549	MIKHAIL ANTONOV	{"email": "mikhail-antonov.011969@postgrespro.ru", "phone": "+70440139381"}
0005433434214	AE735E	5398 232929	ANDREY ANDREEV	{"phone": "+70699655844"}
0005433434274	FF037B	4669 748042	YURIY SOLOVEV	{"phone": "+70583305639"}
0005433434215	DD0615	6991 212468	ALEKSEY VOROBEV	{"email": "a_vorobev_1966@postgrespro.ru", "phone": "+70795589789"}
0005433434216	334E2C	9355 689350	NIKITA TIKHONOV	{"phone": "+70947089307"}
0005433434217	4C50E2	2107 209462	ILYA SIDOROV	{"email": "i_sidorov26091975@postgrespro.ru", "phone": "+70978295728"}
0005433434218	944ED2	3218 494630	ALESYA ANISIMOVA	{"email": "anisimova.a.13041973@postgrespro.ru", "phone": "+70837637601"}
0005433434219	A958B0	5311 083862	SVETLANA BORISOVA	{"email": "borisovasvetlana091974@postgrespro.ru", "phone": "+70876782238"}
0005433434220	406A07	0380 633123	RAVIL ALEKSEEV	{"phone": "+70663606541"}
0005433434221	657929	0860 830887	DMITRIY DAVYDOV	{"phone": "+70129779982"}
0005433434222	5A7E26	4994 413189	NIKOLAY SIDOROV	{"phone": "+70784483043"}
0005433434223	77F106	7482 161280	PAVEL TARASOV	{"email": "tarasov-pavel-23111974@postgrespro.ru", "phone": "+70129581215"}
0005433434224	BFC22E	7237 022927	LYUBOV KOROLEVA	{"email": "l.koroleva.1976@postgrespro.ru", "phone": "+70081276632"}
0005433434225	BFC22E	3689 709254	NIKOLAY ANTONOV	{"email": "n.antonov-14021969@postgrespro.ru", "phone": "+70967972396"}
0005433434226	D4FC45	2083 405733	NATALYA NESTEROVA	{"phone": "+70625014500"}
0005433434227	296445	7789 199304	DMITRIY PAVLOV	{"phone": "+70400087395"}
0005433434228	296445	6204 330619	TATYANA ANDREEVA	{"email": "t-andreeva_1965@postgrespro.ru", "phone": "+70198569637"}
0005433434229	07F5C0	3761 222563	PAVEL VLASOV	{"email": "pvlasov051968@postgrespro.ru", "phone": "+70497677806"}
0005433434230	72063F	2901 361887	LEONID DENISOV	{"phone": "+70742854856"}
0005433434231	72063F	0949 761162	GALINA IVANOVA	{"phone": "+70901658271"}
0005433434232	A13C52	1029 965125	MARIYA OSIPOVA	{"email": "osipova_m.14111976@postgrespro.ru", "phone": "+70597967632"}
0005433434233	4CC49F	1314 074940	SVETLANA YAKOVLEVA	{"phone": "+70091539134"}
0005433434234	F84C52	9990 549358	VLADIMIR DMITRIEV	{"email": "dmitriev_v-121973@postgrespro.ru", "phone": "+70079793124"}
0005433434235	873AB3	4158 149720	ELVIRA FILIPPOVA	{"phone": "+70131521670"}
0005433434236	873AB3	8816 504849	EKATERINA MAKAROVA	{"phone": "+70950959179"}
0005433434237	E9007A	2239 512827	OKSANA MOROZOVA	{"email": "morozova_o29111971@postgrespro.ru", "phone": "+70450398910"}
0005433434238	E9007A	5555 494221	ALEKSANDR KARPOV	{"phone": "+70602777597"}
0005433434239	D4347C	1116 357145	LIDIYA KUZNECOVA	{"email": "lidiya-kuznecova1968@postgrespro.ru", "phone": "+70159972571"}
0005433434240	F1995E	6977 054971	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.27051970@postgrespro.ru", "phone": "+70515489574"}
0005433434241	A618FC	0780 674958	DMITRIY ALEKSANDROV	{"email": "d_aleksandrov-05041966@postgrespro.ru", "phone": "+70567830782"}
0005433434242	A618FC	6271 670842	ALEKSANDRA EFIMOVA	{"email": "aefimova_31071952@postgrespro.ru", "phone": "+70977764674"}
0005433434243	97D066	5021 520793	DMITRIY ZAKHAROV	{"email": "d_zakharov.15011967@postgrespro.ru", "phone": "+70386803280"}
0005433434244	97D066	7741 729705	VLADIMIR SMIRNOV	{"phone": "+70296156240"}
0005433434245	97D066	6141 858240	ANDREY NAUMOV	{"phone": "+70031761469"}
0005433434246	501154	0051 294447	VERA VOROBEVA	{"phone": "+70548902998"}
0005433434247	501154	7019 379077	VASILIY BARANOV	{"email": "baranov_v15111967@postgrespro.ru", "phone": "+70605657167"}
0005433434248	522737	8305 376181	IVAN MELNIKOV	{"email": "melnikov_i.26031967@postgrespro.ru", "phone": "+70297063227"}
0005433434249	72876A	1239 650796	SVETLANA MATVEEVA	{"phone": "+70660093178"}
0005433434250	4D511E	2572 710846	IGOR IVANOV	{"email": "ivanov_i.26091980@postgrespro.ru", "phone": "+70007868727"}
0005433434251	4D511E	9081 321349	ELENA GERASIMOVA	{"email": "elena_gerasimova_05031976@postgrespro.ru", "phone": "+70030770753"}
0005433434252	AB5CAF	1505 068178	ROMAN MIRONOV	{"email": "mironov-r.101973@postgrespro.ru", "phone": "+70811925970"}
0005433434253	F3A7B9	6621 246473	LYUDMILA ZAYCEVA	{"email": "zaycevalyudmila_09111976@postgrespro.ru", "phone": "+70336078198"}
0005433434254	F4B507	2294 368096	ANATOLIY SOLOVEV	{"phone": "+70212133021"}
0005433434255	48C5BA	3937 281604	VLADIMIR ANDREEV	{"email": "vandreev.1971@postgrespro.ru", "phone": "+70249604980"}
0005433434256	9C2023	1961 991812	TATYANA SAVELEVA	{"phone": "+70135326454"}
0005433434257	9C2023	3419 451145	IVAN MIKHAYLOV	{"email": "mikhaylovi_16081978@postgrespro.ru", "phone": "+70714128475"}
0005433434258	8372CE	0245 906151	NADEZHDA LOGINOVA	{"phone": "+70557552088"}
0005433434259	8372CE	7978 671780	YURIY FILIPPOV	{"phone": "+70096404945"}
0005433434260	8372CE	6813 076893	VALENTINA ZAKHAROVA	{"email": "zakharova.v16011979@postgrespro.ru", "phone": "+70130375332"}
0005433434261	8C952B	5369 592027	ALEKSANDR DENISOV	{"email": "a.denisov_081982@postgrespro.ru", "phone": "+70704684794"}
0005433434262	700389	3706 707417	ANDREY MAKSIMOV	{"phone": "+70832613259"}
0005433434263	700389	5846 818758	ALEKSANDRA VASILEVA	{"email": "vasilevaa.1968@postgrespro.ru", "phone": "+70356992743"}
0005433434264	700389	1836 572398	VIKTOR CHERNOV	{"phone": "+70808710493"}
0005433434265	D3AFB0	2725 402391	VLADISLAV ROMANOV	{"phone": "+70815252446"}
0005433434266	940B82	6633 556091	GALINA MAKSIMOVA	{"email": "maksimova-galina-29121962@postgrespro.ru", "phone": "+70503960475"}
0005433434267	940B82	8596 950469	ANNA SIDOROVA	{"email": "a.sidorova-21011961@postgrespro.ru", "phone": "+70012743543"}
0005433434268	DD8533	2275 855207	MIKHAIL ZAKHAROV	{"email": "zakharov_mikhail_1973@postgrespro.ru", "phone": "+70199460487"}
0005433434269	E0B5F7	5114 045527	NIKOLAY VOROBEV	{"email": "n.vorobev_071972@postgrespro.ru", "phone": "+70186724742"}
0005433434270	E0B5F7	6419 457046	LIDIYA ROMANOVA	{"email": "romanova-lidiya-29031969@postgrespro.ru", "phone": "+70225032157"}
0005433434271	F155E9	2714 713938	KIRILL NIKITIN	{"email": "nikitin_kirill.07121969@postgrespro.ru", "phone": "+70203183056"}
0005433434272	47ACD1	6618 201864	IVAN KOROLEV	{"email": "ivan-korolev_26031971@postgrespro.ru", "phone": "+70556536807"}
0005433434273	FF037B	1818 174318	VERA DMITRIEVA	{"phone": "+70815622456"}
0005433434275	C41DD2	5646 651860	NADEZHDA ZHUKOVA	{"phone": "+70291932255"}
0005433434276	C41DD2	3362 145439	VLADIMIR CHERNOV	{"phone": "+70121947284"}
0005433434277	EC576B	1162 006976	VASILIY FEDOTOV	{"phone": "+70776842363"}
0005433434278	A1FD39	6664 202446	VALENTINA ZAKHAROVA	{"phone": "+70056327719"}
0005433434279	A1FD39	5832 619431	VALENTINA VOLKOVA	{"phone": "+70436783296"}
0005433434280	B6E388	0571 277612	VALENTINA YUDINA	{"email": "yudina_valentina1965@postgrespro.ru", "phone": "+70168567161"}
0005433434281	52101F	2400 387799	DMITRIY EGOROV	{"email": "d-egorov_041980@postgrespro.ru", "phone": "+70101470355"}
0005433434282	8F6FB3	6912 328717	VALENTINA KAZAKOVA	{"phone": "+70918203257"}
0005433434283	8F6FB3	8796 941773	VALERIYA MEDVEDEVA	{"email": "medvedeva-valeriya1963@postgrespro.ru", "phone": "+70140629720"}
0005433434284	3FC153	2864 917471	KLAVDIYA NAZAROVA	{"phone": "+70501869088"}
0005433434285	BA278F	7160 165035	ALEKSANDR SERGEEV	{"phone": "+70102001506"}
0005433434286	879B40	2545 503775	OLGA MAKAROVA	{"phone": "+70020418444"}
0005433434287	879B40	6982 237338	VLADISLAV ABRAMOV	{"email": "abramov_v.10081980@postgrespro.ru", "phone": "+70987872380"}
0005433434288	4762B5	0273 062868	LYUBOV EFREMOVA	{"email": "efremovalyubov.101975@postgrespro.ru", "phone": "+70022511776"}
0005433434289	4762B5	5152 008511	DINA FROLOVA	{"email": "dina-frolova_1965@postgrespro.ru", "phone": "+70310147714"}
0005433434290	321A0A	8180 378823	VALENTINA MELNIKOVA	{"email": "v.melnikova_10091977@postgrespro.ru", "phone": "+70357856497"}
0005433434291	8AFEEB	1011 990985	ALEKSEY BARANOV	{"phone": "+70479988113"}
0005433434292	8AFEEB	7608 202703	DIANA IVANOVA	{"phone": "+70634274651"}
0005433434293	4ABC3F	2387 266080	YULIYA SAVELEVA	{"phone": "+70061540534"}
0005433434294	B1A02A	4806 492215	YULIYA MIRONOVA	{"phone": "+70484794449"}
0005433434295	0DD727	6362 002680	RAISA MOISEEVA	{"email": "moiseevar-1968@postgrespro.ru", "phone": "+70248315522"}
0005433434296	466BA9	9205 381758	GALINA PETROVA	{"email": "petrova-g_06081960@postgrespro.ru", "phone": "+70899299975"}
0005433434297	466BA9	6762 330943	OLGA ZAKHAROVA	{"email": "o-zakharova_091967@postgrespro.ru", "phone": "+70691080156"}
0005433434298	670EF3	7330 786585	ALEKSEY EGOROV	{"email": "egorov-aleksey_1969@postgrespro.ru", "phone": "+70865977776"}
0005433434299	EE5883	7166 534268	MARIYA VOROBEVA	{"phone": "+70422575793"}
0005433434300	7CC81F	5001 701449	VLADIMIR EGOROV	{"phone": "+70897410854"}
0005433434301	7CC81F	3047 678116	VERONIKA OSIPOVA	{"phone": "+70599236430"}
0005433434302	E57D0E	2536 922158	ARTUR IVANOV	{"email": "ivanovartur1968@postgrespro.ru", "phone": "+70204932813"}
0005433434303	268D03	6952 465397	VIKTOR FEDOROV	{"email": "fedorovv.081971@postgrespro.ru", "phone": "+70989085299"}
0005433434304	E05C77	0186 246358	RUSLAN SCHERBAKOV	{"phone": "+70073364780"}
0005433434305	156FA5	5773 188970	IVAN SMIRNOV	{"phone": "+70494171732"}
0005433434306	156FA5	4333 895389	VLADISLAV VASILEV	{"email": "vladislav_vasilev-24051976@postgrespro.ru", "phone": "+70127709869"}
0005433434307	156FA5	6570 739237	NIKOLAY GRIGOREV	{"email": "grigorev_nikolay_011967@postgrespro.ru", "phone": "+70075417440"}
0005433434308	B57192	6057 415693	YURIY MOROZOV	{"phone": "+70559252297"}
0005433434309	B57192	3640 125228	SERGEY MOROZOV	{"email": "s.morozov04121980@postgrespro.ru", "phone": "+70897825509"}
0005433434310	B57192	4399 496113	NADEZHDA KUZNECOVA	{"phone": "+70782090432"}
0005433434311	3BF137	1639 269302	LYUDMILA ORLOVA	{"email": "orlova-l-121973@postgrespro.ru", "phone": "+70571041276"}
0005433434312	D70BD9	9995 550332	IRINA CHERNOVA	{"email": "i-chernova.1975@postgrespro.ru", "phone": "+70608445001"}
0005433434313	D70BD9	9974 024945	EVGENIY ANDREEV	{"phone": "+70026899821"}
0005433434314	D70BD9	8211 128157	ELIZAVETA MASLOVA	{"email": "maslova-elizaveta1961@postgrespro.ru", "phone": "+70826506360"}
0005433434315	D70BD9	7383 547392	ELENA ZAYCEVA	{"email": "elena_zayceva101985@postgrespro.ru", "phone": "+70621264431"}
0005433434316	3AD17F	9154 626039	IVAN ABRAMOV	{"phone": "+70802425257"}
0005433434317	3AD17F	0278 652738	LYUBOV GORBUNOVA	{"phone": "+70381257954"}
0005433434318	ECBA92	3990 145435	LYUBOV EGOROVA	{"email": "egorova_l091965@postgrespro.ru", "phone": "+70808137561"}
0005433434319	4D52B4	1190 620606	ALENA ANDREEVA	{"email": "alena-andreeva_1976@postgrespro.ru", "phone": "+70192535104"}
0005433434320	4D52B4	3677 696083	ANATOLIY AFANASEV	{"phone": "+70417928424"}
0005433434321	44C415	2583 256753	RAFAEL MOROZOV	{"phone": "+70088131386"}
0005433434322	742388	6562 982074	OLGA VOROBEVA	{"email": "vorobeva.olga1973@postgrespro.ru", "phone": "+70721423670"}
0005433434323	A23690	1891 475414	ALEKSEY KOROLEV	{"email": "aleksey.korolev06111982@postgrespro.ru", "phone": "+70762186659"}
0005433434324	A23690	7960 893292	TAMARA NIKOLAEVA	{"email": "tamaranikolaeva1970@postgrespro.ru", "phone": "+70189433853"}
0005433434325	7AEAF0	3343 097634	KONSTANTIN MAKAROV	{"email": "makarov_k-1970@postgrespro.ru", "phone": "+70793295471"}
0005433434326	7AEAF0	9554 367454	EVGENIY NAUMOV	{"email": "evgeniy.naumov-041972@postgrespro.ru", "phone": "+70577117729"}
0005433434327	4E3E89	7440 420855	ARINA KAZAKOVA	{"phone": "+70088699759"}
0005433434328	A36457	3903 051343	VERA PAVLOVA	{"phone": "+70030479964"}
0005433434329	B6F2EA	2727 875376	ALEKSEY IVANOV	{"phone": "+70733088642"}
0005433434330	5204A3	6102 713996	ALEKSANDR FOMIN	{"phone": "+70747053352"}
0005433434331	5204A3	6752 409303	ANASTASIYA NOVIKOVA	{"email": "anastasiya.novikova-011972@postgrespro.ru", "phone": "+70014527340"}
0005433434332	5204A3	9967 207248	VLADIMIR PETROV	{"email": "petrov_v02111967@postgrespro.ru", "phone": "+70333117565"}
0005433434333	5204A3	7617 306736	ELENA MATVEEVA	{"email": "ematveeva.11031966@postgrespro.ru", "phone": "+70639353421"}
0005433434334	3146F2	3456 791997	DMITRIY TIMOFEEV	{"email": "dtimofeev1965@postgrespro.ru", "phone": "+70799327597"}
0005433434335	0305C6	2083 740935	VLADIMIR GUSEV	{"phone": "+70973969989"}
0005433434336	0305C6	0524 089155	ANASTASIYA KOZLOVA	{"phone": "+70184835601"}
0005433434337	BE8844	0131 004395	IRINA SCHERBAKOVA	{"phone": "+70644290444"}
0005433434338	B781E6	0387 826035	ELIZAVETA DAVYDOVA	{"email": "e_davydova-121962@postgrespro.ru", "phone": "+70818794103"}
0005433434339	B781E6	1933 230988	OLEG TIMOFEEV	{"email": "olegtimofeev.1984@postgrespro.ru", "phone": "+70180222197"}
0005433434340	8CD66E	2921 685021	TAMARA KAZAKOVA	{"phone": "+70641024761"}
0005433434341	2F6D7B	0809 948519	SERGEY SCHERBAKOV	{"phone": "+70203104619"}
0005433434342	E99E45	2385 461052	VYACHESLAV KAZAKOV	{"email": "kazakovvyacheslav121969@postgrespro.ru", "phone": "+70357544939"}
0005433434343	47D9F5	7462 518291	ALENA ALEKSEEVA	{"email": "a_alekseeva-15031971@postgrespro.ru", "phone": "+70986313425"}
0005433434344	DDA1BF	0711 394231	VADIM KULIKOV	{"email": "kulikovv_041973@postgrespro.ru", "phone": "+70154809079"}
0005433434345	B66BF7	3825 086315	DMITRIY NIKOLAEV	{"email": "d-nikolaev.1975@postgrespro.ru", "phone": "+70345890535"}
0005433434346	E0D571	4671 354332	SVETLANA NESTEROVA	{"phone": "+70836492092"}
0005433434347	BE9744	2190 012211	VLADIMIR PETROV	{"phone": "+70425487043"}
0005433434348	6E150F	4380 548438	NIKITA KUZNECOV	{"email": "nikita-kuznecov.26081977@postgrespro.ru", "phone": "+70449901211"}
0005433434349	6348AD	5159 202697	LYUDMILA KOROLEVA	{"email": "koroleva_l.1978@postgrespro.ru", "phone": "+70387488501"}
0005433434350	52699D	1115 140996	SERGEY BONDARENKO	{"email": "sergeybondarenko.1978@postgrespro.ru", "phone": "+70702681466"}
0005433434351	CE546F	7957 718293	ANASTASIYA SOROKINA	{"email": "sorokinaanastasiya08121959@postgrespro.ru", "phone": "+70179269938"}
0005433434352	EF40C3	6612 744798	ALEKSANDR SIDOROV	{"phone": "+70920881375"}
0005433434353	EF40C3	6141 078087	ANDREY OSIPOV	{"email": "andrey_osipov.1960@postgrespro.ru", "phone": "+70656146361"}
0005433434354	04341E	4828 954399	VENERA NIKOLAEVA	{"email": "nikolaeva.v-14091969@postgrespro.ru", "phone": "+70201305313"}
0005433434355	2C5809	8468 446317	ANNA VASILEVA	{"email": "vasileva_anna_021975@postgrespro.ru", "phone": "+70175244290"}
0005433434356	F32E7A	6952 011225	ANDREY ANDREEV	{"email": "a.andreev.111976@postgrespro.ru", "phone": "+70890388871"}
0005433434357	F32E7A	6596 995085	ALEKSANDR KISELEV	{"phone": "+70048109372"}
0005433434358	E3C22A	7186 961412	RAVIL KOROLEV	{"email": "r_korolev_14021977@postgrespro.ru", "phone": "+70228040921"}
0005433434359	E3C22A	3014 850346	ANGELINA ALEKSANDROVA	{"email": "angelinaaleksandrova-04091964@postgrespro.ru", "phone": "+70321600967"}
0005433434360	B01FF9	3340 200973	RIMMA NAZAROVA	{"email": "rimmanazarova-111976@postgrespro.ru", "phone": "+70482844733"}
0005433434361	ABFA4A	2798 948852	MARIYA ANDREEVA	{"email": "m.andreeva.1985@postgrespro.ru", "phone": "+70057208602"}
0005433434362	ABFA4A	8428 801993	VALERIY PAVLOV	{"email": "vpavlov1976@postgrespro.ru", "phone": "+70846248175"}
0005433434363	AF88CB	7035 280843	POLINA IVANOVA	{"email": "polina_ivanova.30031965@postgrespro.ru", "phone": "+70002000842"}
0005433434364	4EEAFA	4882 807275	NATALYA PAVLOVA	{"phone": "+70966355602"}
0005433434365	4EEAFA	7301 014374	TAISIYA SAVELEVA	{"phone": "+70770337628"}
0005433434366	6BD46B	0313 519912	ANASTASIYA ORLOVA	{"email": "orlova-a_041966@postgrespro.ru", "phone": "+70537759220"}
0005433434367	4B837A	0331 540765	DANA FEDOROVA	{"phone": "+70530180002"}
0005433434368	A2E6E4	3489 702874	MARGARITA ABRAMOVA	{"phone": "+70328201661"}
0005433434369	A2E6E4	4227 829047	IRINA SMIRNOVA	{"phone": "+70173879827"}
0005433434370	598339	3634 757549	TATYANA SAVELEVA	{"phone": "+70725161508"}
0005433434371	598339	0622 058614	GALINA SOLOVEVA	{"email": "galina-soloveva_25011978@postgrespro.ru", "phone": "+70709305173"}
0005433434372	098BD0	6619 108965	DAMIR KULIKOV	{"phone": "+70029272544"}
0005433434373	098BD0	4494 967838	YURIY VASILEV	{"phone": "+70728579001"}
0005433434374	6E2CBD	6402 710266	FARID ILIN	{"email": "farid_ilin-101971@postgrespro.ru", "phone": "+70328801947"}
0005433434375	4616C1	4890 034833	VALERIY BONDARENKO	{"email": "v_bondarenko_1963@postgrespro.ru", "phone": "+70448040649"}
0005433434376	FBE4B1	0524 727787	OLEG ISAEV	{"email": "isaev-oleg-16091957@postgrespro.ru", "phone": "+70086674804"}
0005433434377	FBE4B1	7496 025078	TATYANA KUZNECOVA	{"phone": "+70534122732"}
0005433434378	7A5662	2921 694548	KSENIYA KUDRYASHOVA	{"email": "k_kudryashova-17071961@postgrespro.ru", "phone": "+70938905940"}
0005433434379	537240	7318 092282	KLAVDIYA KOLESNIKOVA	{"email": "klavdiya_kolesnikova-21071968@postgrespro.ru", "phone": "+70674874541"}
0005433434380	503585	5324 433137	ANNA MIKHAYLOVA	{"email": "mikhaylova-a-06101967@postgrespro.ru", "phone": "+70144588870"}
0005433434381	04C728	5465 381185	NATALYA MASLOVA	{"email": "maslovan_1979@postgrespro.ru", "phone": "+70644875703"}
0005433434382	B0CB08	8832 340937	ZINAIDA FILATOVA	{"email": "filatova.zinaida_24091960@postgrespro.ru", "phone": "+70443208273"}
0005433434383	B0CB08	0767 328185	RAUF KARPOV	{"phone": "+70265820475"}
0005433434384	75ADE4	0087 475137	VIKTOR VASILEV	{"email": "viktor-vasilev-05091964@postgrespro.ru", "phone": "+70355312578"}
0005433434385	75ADE4	4678 386392	ALEKSANDR SAVELEV	{"phone": "+70809689268"}
0005433434386	9BCB6D	9760 199794	LYUBOV IVANOVA	{"email": "l-ivanova.1977@postgrespro.ru", "phone": "+70728804547"}
0005433434387	9BCB6D	7855 685895	EVGENIY IVANOV	{"email": "evgeniy_ivanov_1968@postgrespro.ru", "phone": "+70717498626"}
0005433434388	EBB078	4064 793691	ALEKSANDR ZAYCEV	{"phone": "+70817204760"}
0005433434389	EBB078	1699 756819	NADEZHDA IVANOVA	{"phone": "+70936740753"}
0005433434390	734E46	8912 206905	ALEKSANDR KOROLEV	{"email": "aleksandrkorolev.051966@postgrespro.ru", "phone": "+70191087760"}
0005433434391	CE8250	1769 945532	ANDREY ALEKSANDROV	{"email": "andrey_aleksandrov.19041968@postgrespro.ru", "phone": "+70468281589"}
0005433434392	CE8250	5346 161457	ALINA GORBUNOVA	{"email": "gorbunova.a.111971@postgrespro.ru", "phone": "+70273290347"}
0005433434393	40AC07	1809 782167	VLADIMIR KAZAKOV	{"email": "kazakov-vladimir_1964@postgrespro.ru", "phone": "+70602067504"}
0005433434394	184D30	0012 737527	VLADIMIR SMIRNOV	{"email": "v-smirnov.27011962@postgrespro.ru", "phone": "+70200494823"}
0005433434395	328E99	0429 675496	VALENTINA ZAKHAROVA	{"phone": "+70493646249"}
0005433434396	9DC399	0295 161712	LARISA MIRONOVA	{"phone": "+70388962103"}
0005433434397	9DC399	8316 924219	ALEKSEY RODIONOV	{"phone": "+70932403141"}
0005433434398	070DFD	2801 119656	MARINA POPOVA	{"phone": "+70078236216"}
0005433434399	F94AEC	4384 138749	EVGENIY ALEKSEEV	{"email": "ealekseev091979@postgrespro.ru", "phone": "+70109085072"}
0005433434400	F94AEC	8847 770786	ALEKSANDR NOVIKOV	{"phone": "+70851685051"}
0005433434401	70858E	0016 221993	VIKTORIYA OSIPOVA	{"email": "v-osipova_05031973@postgrespro.ru", "phone": "+70678236343"}
0005433434402	F3E523	1676 876360	ANATOLIY VOROBEV	{"email": "vorobev-a10101974@postgrespro.ru", "phone": "+70320875246"}
0005433434403	F3E523	8480 433582	ARTEM FROLOV	{"phone": "+70502440436"}
0005433434404	748D9D	8730 501859	TAMARA KAZAKOVA	{"email": "kazakova_tamara-071969@postgrespro.ru", "phone": "+70548963152"}
0005433434405	0DEE38	1443 606656	ELINA LAZAREVA	{"email": "lazareva.elina.011968@postgrespro.ru", "phone": "+70927930625"}
0005433434406	0DEE38	6199 590799	NINA POLYAKOVA	{"email": "polyakova-nina-26091959@postgrespro.ru", "phone": "+70303365513"}
0005433434407	0DEE38	1374 135049	LYUDMILA BELOVA	{"phone": "+70096888066"}
0005433434408	745E77	4165 614326	NATALYA ZAKHAROVA	{"email": "zakharova_natalya.061959@postgrespro.ru", "phone": "+70208319401"}
0005433434409	745E77	3393 058766	NATALYA MOROZOVA	{"phone": "+70751575424"}
0005433434410	47CAAD	7079 927621	DILYARA ORLOVA	{"phone": "+70852523130"}
0005433434411	47CAAD	6669 797409	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev1975@postgrespro.ru", "phone": "+70165073319"}
0005433434412	AB1C49	6217 940203	OLEG BELOV	{"email": "o.belov25061981@postgrespro.ru", "phone": "+70542063067"}
0005433434413	AB1C49	3371 321266	MARIYA DENISOVA	{"email": "denisova_m-1969@postgrespro.ru", "phone": "+70652633569"}
0005433434414	3B28AA	2425 333243	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov.10101971@postgrespro.ru", "phone": "+70115837798"}
0005433434415	11EE94	0142 995888	LYUDMILA KRASNOVA	{"email": "krasnova-l_021983@postgrespro.ru", "phone": "+70907705196"}
0005433434416	11EE94	7563 661350	TATYANA KUZNECOVA	{"email": "tkuznecova_011974@postgrespro.ru", "phone": "+70530069889"}
0005433434417	AE2803	9135 956726	ALEKSANDR POPOV	{"email": "popov.a_1981@postgrespro.ru", "phone": "+70289778501"}
0005433434418	968825	1053 856296	IRINA MAKSIMOVA	{"phone": "+70094103655"}
0005433434419	B21C01	7856 673464	EKATERINA ANDREEVA	{"email": "ekaterina_andreeva1973@postgrespro.ru", "phone": "+70160139219"}
0005433434420	D4903C	6044 359141	NATALYA TARASOVA	{"email": "n.tarasova011958@postgrespro.ru", "phone": "+70942383526"}
0005433434421	B8D41C	9341 828434	ELENA ZHURAVLEVA	{"email": "e.zhuravleva091979@postgrespro.ru", "phone": "+70878879374"}
0005433434422	01E475	4982 560288	ALEKSANDRA ALEKSANDROVA	{"phone": "+70952089061"}
0005433434423	6827BD	1416 635956	DARYA ROMANOVA	{"email": "romanova-darya16121967@postgrespro.ru", "phone": "+70431504662"}
0005433434424	6B949D	8995 563817	NATALIYA KRASNOVA	{"email": "n.krasnova.051969@postgrespro.ru", "phone": "+70111251850"}
0005433434425	1E6E1A	9041 938992	LYUDMILA SMIRNOVA	{"phone": "+70799947615"}
0005433434426	2DC288	4759 557885	ELENA NOVIKOVA	{"phone": "+70477060468"}
0005433434427	2DC288	1328 126257	VLADIMIR IVANOV	{"email": "vivanov_12061974@postgrespro.ru", "phone": "+70628350759"}
0005433434428	9CCE70	9390 369224	ALEKSANDR BELOV	{"phone": "+70666020333"}
0005433434429	9CCE70	6024 765833	VLADISLAV AFANASEV	{"phone": "+70794041981"}
0005433434430	DECE31	3985 663918	ALEKSEY SIDOROV	{"email": "sidorov_a1960@postgrespro.ru", "phone": "+70933984863"}
0005433434431	DECE31	4677 425591	NAZAR MAKSIMOV	{"phone": "+70199879964"}
0005433434432	165FE1	3069 461819	RAFAEL NIKITIN	{"email": "r.nikitin1978@postgrespro.ru", "phone": "+70940257738"}
0005433434433	6A3E95	1992 159627	LYUDMILA BARANOVA	{"email": "baranova-l.1975@postgrespro.ru", "phone": "+70865346931"}
0005433434434	6A3E95	9282 512771	VLADIMIR MELNIKOV	{"phone": "+70550959163"}
0005433434435	588CA5	3662 846315	SERGEY BARANOV	{"email": "baranovs_22061958@postgrespro.ru", "phone": "+70788069137"}
0005433434436	832B87	4472 523994	NATALYA POPOVA	{"email": "popova-n-041979@postgrespro.ru", "phone": "+70999936517"}
0005433434437	1AF246	7471 613715	ALEKSANDRA NESTEROVA	{"email": "aleksandranesterova.1990@postgrespro.ru", "phone": "+70906466421"}
0005433434438	1AF246	7485 571789	FELIKS ZAKHAROV	{"phone": "+70497866733"}
0005433434439	1F71DD	7069 678234	ANTONINA MAKAROVA	{"email": "antonina.makarova_1981@postgrespro.ru", "phone": "+70616838661"}
0005433434440	1F71DD	3776 833511	NIKOLAY DAVYDOV	{"email": "davydov.n-1976@postgrespro.ru", "phone": "+70996203325"}
0005433434441	917734	3356 055554	FEDOR NAZAROV	{"phone": "+70470312082"}
0005433434442	7BEBA3	5864 526281	EGOR KUZNECOV	{"email": "egor.kuznecov.031976@postgrespro.ru", "phone": "+70157307930"}
0005433434443	86A8B3	5900 864448	IGOR VASILEV	{"phone": "+70077118341"}
0005433434444	97C4DC	4638 578233	NINA SAVELEVA	{"phone": "+70642417374"}
0005433434445	B66A91	6898 892916	ALEKSANDR DAVYDOV	{"email": "adavydov_25051978@postgrespro.ru", "phone": "+70824871561"}
0005433434446	8DD855	5412 452649	MIKHAIL ISAEV	{"phone": "+70062725712"}
0005433434447	453C75	8403 281638	MAKSIM SMIRNOV	{"phone": "+70365439696"}
0005433434448	73F6C4	7898 537558	ALEKSANDR IVANOV	{"phone": "+70585933666"}
0005433434449	E20EA7	9236 977295	YULIYA SERGEEVA	{"email": "sergeeva.y_03121976@postgrespro.ru", "phone": "+70434423174"}
0005433434450	E20EA7	3635 179480	VIKTOR KONOVALOV	{"email": "konovalov-viktor-1980@postgrespro.ru", "phone": "+70227203976"}
0005433434451	4BE32C	6278 078676	DMITRIY FOMIN	{"email": "d-fomin.04061968@postgrespro.ru", "phone": "+70150541034"}
0005433434452	D416ED	4123 938064	OLGA ROMANOVA	{"phone": "+70570866752"}
0005433434453	803B5C	9967 272849	DENIS VASILEV	{"email": "denis.vasilev-1960@postgrespro.ru", "phone": "+70214444239"}
0005433434454	803B5C	3979 973942	ZINAIDA IVANOVA	{"phone": "+70032539250"}
0005433434455	79C8EC	9872 732630	NIKOLAY ANDREEV	{"email": "nandreev.10041972@postgrespro.ru", "phone": "+70892830437"}
0005433434456	7825BC	5029 212632	PAVEL KISELEV	{"phone": "+70755821291"}
0005433434457	7825BC	4972 076617	ELENA DANILOVA	{"email": "elena_danilova.041965@postgrespro.ru", "phone": "+70523189722"}
0005433434458	844AF2	5928 499146	ARTEM VASILEV	{"phone": "+70914563857"}
0005433434459	84D5E1	7736 851832	MARINA ISAEVA	{"email": "m-isaeva.06121961@postgrespro.ru", "phone": "+70776533680"}
0005433434460	84D5E1	6178 341857	DENIS FEDOTOV	{"email": "fedotovdenis-1983@postgrespro.ru", "phone": "+70847080499"}
0005433434461	E3360B	5264 288645	DANIIL ZAYCEV	{"email": "zaycevd_081977@postgrespro.ru", "phone": "+70467576628"}
0005433434462	F23D8B	5588 583640	DMITRIY VASILEV	{"phone": "+70964763516"}
0005433434463	BB2C1C	2376 868233	MARINA DAVYDOVA	{"phone": "+70257909730"}
0005433434464	BB2C1C	4343 770266	PAVEL FROLOV	{"email": "pavel.frolov.1974@postgrespro.ru", "phone": "+70340296705"}
0005433434465	7A1C37	6888 815009	DMITRIY SMIRNOV	{"phone": "+70408590998"}
0005433434466	654F18	2715 536993	IVAN KUZNECOV	{"email": "kuznecov_ivan.041971@postgrespro.ru", "phone": "+70881755582"}
0005433434467	654F18	7545 833867	LYUBOV SERGEEVA	{"phone": "+70244183266"}
0005433434468	654F18	1211 102276	VADIM SCHERBAKOV	{"email": "vadim_scherbakov-10071972@postgrespro.ru", "phone": "+70112984082"}
0005433434469	DC369E	0801 199372	OLGA SIDOROVA	{"phone": "+70069689088"}
0005433434470	2AECE7	5191 693064	YURIY GUSEV	{"email": "gusevy.081967@postgrespro.ru", "phone": "+70789275761"}
0005433434471	2AECE7	3018 828472	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov1966@postgrespro.ru", "phone": "+70412965866"}
0005433434472	0B4C8C	4978 606600	GALINA NAUMOVA	{"phone": "+70914377756"}
0005433434473	0B4C8C	7366 484752	EKATERINA KRASNOVA	{"phone": "+70657999858"}
0005433434474	C93480	0106 643003	ANNA OSIPOVA	{"email": "anna.osipova_121968@postgrespro.ru", "phone": "+70482080417"}
0005433434475	C93480	0394 237206	VALENTIN SMIRNOV	{"email": "smirnov-valentin25021963@postgrespro.ru", "phone": "+70996697527"}
0005433434476	C93480	5470 239893	ALEKSANDR FILIPPOV	{"phone": "+70224608844"}
0005433434477	0BC5CE	1131 990132	ELENA TROFIMOVA	{"phone": "+70305608720"}
0005433434478	0BC5CE	7148 069221	ALEKSANDR SOROKIN	{"email": "a.sorokin-21101979@postgrespro.ru", "phone": "+70699291572"}
0005433434479	0F1ECB	7155 595715	YULIYA AFANASEVA	{"email": "afanaseva_yuliya01111977@postgrespro.ru", "phone": "+70360754121"}
0005433434480	0F1ECB	6596 345283	IVAN MIKHAYLOV	{"phone": "+70491421689"}
0005433434481	FF9866	8397 256255	EVGENIY NAZAROV	{"email": "e_nazarov_021976@postgrespro.ru", "phone": "+70928368125"}
0005433434482	CFB356	1999 086333	MIKHAIL MOROZOV	{"email": "m-morozov_1984@postgrespro.ru", "phone": "+70940295692"}
0005433434483	CFB356	9203 428141	LYUDMILA EFREMOVA	{"phone": "+70457535213"}
0005433434484	98EF9A	7687 358978	DARYA FEDOROVA	{"phone": "+70847936412"}
0005433434485	5C148B	1385 126757	IRINA GUSEVA	{"email": "i-guseva.1976@postgrespro.ru", "phone": "+70952155362"}
0005433434486	93B25C	6115 948492	MARYAM MIRONOVA	{"email": "maryam.mironova.18071969@postgrespro.ru", "phone": "+70698364399"}
0005433434487	81BCA4	3728 980796	YULIYA GRISHINA	{"phone": "+70843307300"}
0005433434488	3E39F4	0668 847976	ANASTASIYA TROFIMOVA	{"email": "anastasiya-trofimova-081976@postgrespro.ru", "phone": "+70694960088"}
0005433434489	3E39F4	9244 889238	MARINA MAKSIMOVA	{"email": "maksimovam.13121974@postgrespro.ru", "phone": "+70434439137"}
0005433434490	9EF8C9	4577 164907	ZOYA ALEKSEEVA	{"email": "alekseevazoya-17011972@postgrespro.ru", "phone": "+70641703942"}
0005433434491	88EBF9	7692 845517	VALENTINA ROMANOVA	{"email": "v_romanova.1976@postgrespro.ru", "phone": "+70115544848"}
0005433434492	1FF5FC	9469 666399	SERGEY KOZLOV	{"phone": "+70932993212"}
0005433434493	96BB32	6595 819363	IVAN PETROV	{"email": "ivanpetrov_29111966@postgrespro.ru", "phone": "+70597122844"}
0005433434494	96BB32	4536 761713	SNEZHANA GAVRILOVA	{"email": "gavrilova-snezhana_071969@postgrespro.ru", "phone": "+70992577771"}
0005433434495	F504A4	7840 489919	VIKTOR KARPOV	{"phone": "+70831042289"}
0005433434496	F504A4	9584 613691	DMITRIY KUZNECOV	{"phone": "+70299725689"}
0005433434497	7D2BC3	4175 132712	NADEZHDA KUZMINA	{"phone": "+70487908591"}
0005433434498	7D2BC3	2163 881889	RAFAEL IVANOV	{"email": "rafael.ivanov-081980@postgrespro.ru", "phone": "+70049550079"}
0005433434499	F780DF	8648 112348	ANATOLIY NOVIKOV	{"email": "novikov_a.011981@postgrespro.ru", "phone": "+70801221767"}
0005433434500	AAF5BE	9102 140130	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy_041974@postgrespro.ru", "phone": "+70926659189"}
0005433434501	AAF5BE	1030 704357	DARYA IVANOVA	{"phone": "+70830620809"}
0005433434502	7F5A5E	2038 438557	ALEKSANDR GUSEV	{"phone": "+70500602805"}
0005433434503	7F5A5E	0848 277709	ALBINA ANTONOVA	{"phone": "+70897914895"}
0005433434504	070798	8758 278009	ANNA BOGDANOVA	{"phone": "+70106358345"}
0005433434505	070798	9923 025074	NADEZHDA SIDOROVA	{"phone": "+70346431878"}
0005433434506	88B119	5448 624548	SERGEY ABRAMOV	{"phone": "+70669421313"}
0005433434507	AC6ACF	7565 634275	YURIY CHERNOV	{"email": "yuriy-chernov_20061972@postgrespro.ru", "phone": "+70343634904"}
0005433434508	AC6ACF	5652 926129	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya_061976@postgrespro.ru", "phone": "+70652791159"}
0005433434509	B41D0C	6585 414578	NINA ORLOVA	{"phone": "+70657976095"}
0005433434510	B41D0C	9357 898347	POLINA ZAYCEVA	{"email": "zayceva-polina-021965@postgrespro.ru", "phone": "+70617488364"}
0005433434511	47B998	0151 938313	ALEKSANDR GERASIMOV	{"email": "a.gerasimov-07061966@postgrespro.ru", "phone": "+70756875565"}
0005433434512	6E8054	0425 750888	SVETLANA ORLOVA	{"phone": "+70813308103"}
0005433434513	B38179	3199 224464	DMITRIY NIKITIN	{"email": "nikitind101975@postgrespro.ru", "phone": "+70270121906"}
0005433434514	460434	9721 761424	ALEKSEY ZAKHAROV	{"email": "zakharov-aleksey-1977@postgrespro.ru", "phone": "+70520913339"}
0005433434515	5CAFED	1541 645563	PETR SHEVCHENKO	{"phone": "+70324271400"}
0005433434516	B7FC15	5689 074593	VLADIMIR VOLKOV	{"email": "volkov-vladimir.011962@postgrespro.ru", "phone": "+70555389706"}
0005433434517	CBA600	4447 990891	VYACHESLAV KUZNECOV	{"phone": "+70266747673"}
0005433434518	BCCD66	1352 545586	VALENTINA KUZNECOVA	{"phone": "+70918515385"}
0005433434519	C68B37	7802 758203	ANASTASIYA NESTEROVA	{"email": "anastasiya.nesterova_18011970@postgrespro.ru", "phone": "+70408110743"}
0005433434520	997E47	6628 990790	ROMAN TIKHONOV	{"email": "tikhonov-r051973@postgrespro.ru", "phone": "+70737716998"}
0005433434521	B8B5D0	8427 506268	RUSLAN TIMOFEEV	{"email": "ruslan_timofeev.04081975@postgrespro.ru", "phone": "+70725218550"}
0005433434522	B8B5D0	0485 029227	MIKHAIL SCHERBAKOV	{"phone": "+70511024789"}
0005433434523	51E9CE	6721 001347	YANA KUZNECOVA	{"email": "y-kuznecova_051980@postgrespro.ru", "phone": "+70471307173"}
0005433434524	51E9CE	3407 660832	ZOYA ORLOVA	{"phone": "+70632033320"}
0005433434525	111BDE	8973 648203	SVETLANA KAZAKOVA	{"email": "kazakova_svetlana-101969@postgrespro.ru", "phone": "+70516338735"}
0005433434526	97C24A	8055 906622	ELENA CHERNOVA	{"email": "chernova.elena25071973@postgrespro.ru", "phone": "+70795434522"}
0005433434527	97C24A	0507 568430	RAISA KAZAKOVA	{"phone": "+70677142828"}
0005433434528	A681E7	3097 017735	SERGEY STEPANOV	{"email": "sergeystepanov-22051980@postgrespro.ru", "phone": "+70591557915"}
0005433434529	7CD91C	0486 368706	NINA PAVLOVA	{"phone": "+70957065487"}
0005433434530	7CD91C	6177 060441	VADIM KOZLOV	{"phone": "+70411095076"}
0005433434531	AA57DB	9373 248704	SERGEY GAVRILOV	{"email": "gavrilovs_04011977@postgrespro.ru", "phone": "+70533930722"}
0005433434532	AA57DB	6839 986558	ANDREY ABRAMOV	{"phone": "+70043556532"}
0005433434533	3F0153	8304 019214	FEDOR BELOV	{"email": "belovfedor_1973@postgrespro.ru", "phone": "+70298515765"}
0005433434534	4DF015	5797 922800	LYUBOV NIKITINA	{"email": "nikitinal-19111971@postgrespro.ru", "phone": "+70259115229"}
0005433434535	4DF015	9179 640206	ELENA MALYSHEVA	{"email": "e_malysheva_12091961@postgrespro.ru", "phone": "+70802275379"}
0005433434536	01F752	5913 744185	ELENA NIKITINA	{"email": "e-nikitina.1972@postgrespro.ru", "phone": "+70161626244"}
0005433434537	01F752	7982 702312	ELIZAVETA GRISHINA	{"email": "grishina.elizaveta_1985@postgrespro.ru", "phone": "+70450889505"}
0005433434538	9EB906	6493 250856	VERA PETROVA	{"phone": "+70168909167"}
0005433434539	9EB906	6296 804460	OKSANA FILIPPOVA	{"email": "filippova.oksana.061974@postgrespro.ru", "phone": "+70644665764"}
0005433434540	6D72BD	6153 028543	LARISA GAVRILOVA	{"email": "larisagavrilova031955@postgrespro.ru", "phone": "+70122282623"}
0005433434541	281C2D	1399 357803	OKSANA NIKITINA	{"phone": "+70728887784"}
0005433434542	4844E0	1611 801252	SVETLANA DMITRIEVA	{"email": "dmitrievasvetlana_1968@postgrespro.ru", "phone": "+70418119494"}
0005433434543	1693A7	5262 816007	VYACHESLAV ORLOV	{"email": "vyacheslavorlov.061971@postgrespro.ru", "phone": "+70542480566"}
0005433434544	F4F5EB	9003 604608	VALERIY BARANOV	{"phone": "+70447868492"}
0005433434545	F4F5EB	7723 097060	NIKITA MATVEEV	{"email": "matveev-nikita091970@postgrespro.ru", "phone": "+70468627608"}
0005433434546	2BB5EF	3311 884044	TAMARA POPOVA	{"phone": "+70903567403"}
0005433434547	8F716F	0136 612825	IGOR KUZNECOV	{"phone": "+70102576114"}
0005433434548	2A37E5	8194 905174	TATYANA NESTEROVA	{"email": "tatyana.nesterova_11101965@postgrespro.ru", "phone": "+70498236519"}
0005433434549	B6C903	4000 688414	RIMMA OVCHINNIKOVA	{"email": "ovchinnikova-rimma_1978@postgrespro.ru", "phone": "+70174834739"}
0005433434550	B6C903	3168 475466	OLGA MIRONOVA	{"email": "olga.mironova.1961@postgrespro.ru", "phone": "+70653361920"}
0005433434551	6A08D6	6141 698571	MARIYA KOVALEVA	{"phone": "+70297741338"}
0005433434552	4FE0FD	9100 132408	EKATERINA KONOVALOVA	{"email": "e-konovalova-1979@postgrespro.ru", "phone": "+70650003943"}
0005433434553	76DE65	6513 281753	NINA ZAYCEVA	{"email": "zayceva-nina-16041967@postgrespro.ru", "phone": "+70056216758"}
0005433434554	F4E986	2923 596281	SVETLANA ORLOVA	{"email": "orlova_svetlana_1971@postgrespro.ru", "phone": "+70683593407"}
0005433434555	07D00D	8415 206296	ANDREY AFANASEV	{"phone": "+70556182497"}
0005433434556	B06FA0	2174 489806	VALENTINA TARASOVA	{"email": "valentinatarasova-111981@postgrespro.ru", "phone": "+70190686533"}
0005433434557	B06FA0	4550 205851	ALBINA MAKAROVA	{"phone": "+70980407012"}
0005433434558	CF66D3	1627 174554	ALEKSANDR ZHUKOV	{"phone": "+70794535965"}
0005433434559	9C3070	6443 387419	ELENA PAVLOVA	{"email": "pavlovae06091980@postgrespro.ru", "phone": "+70034673728"}
0005433434560	56D8CB	0456 246837	VITALIY IVANOV	{"phone": "+70443057258"}
0005433434561	90001F	5840 226631	IGOR KISELEV	{"phone": "+70949898434"}
0005433434562	90001F	3884 768308	SOFYA SERGEEVA	{"email": "sofyasergeeva-1970@postgrespro.ru", "phone": "+70886556135"}
0005433434563	90001F	7749 095441	VERA MOROZOVA	{"email": "vmorozova.1975@postgrespro.ru", "phone": "+70364523851"}
0005433434564	6D473F	7658 184768	VLADIMIR SERGEEV	{"email": "vladimir.sergeev.09031971@postgrespro.ru", "phone": "+70632250962"}
0005433434565	6D473F	8023 545393	EKATERINA NIKOLAEVA	{"email": "nikolaeva-e_011979@postgrespro.ru", "phone": "+70502521398"}
0005433434566	4D74F0	3324 964851	SOFYA NAUMOVA	{"email": "naumova_sofya.18071978@postgrespro.ru", "phone": "+70488583732"}
0005433434567	4D74F0	8007 474038	OLGA SCHERBAKOVA	{"email": "o-scherbakova-19051965@postgrespro.ru", "phone": "+70466325231"}
0005433434568	4D74F0	6026 101461	IVAN FROLOV	{"phone": "+70437507117"}
0005433434569	D2794D	9193 393649	SANIYA BELYAEVA	{"phone": "+70132383974"}
0005433434570	274AD6	7646 061984	LYUDMILA SEMENOVA	{"phone": "+70299525388"}
0005433434571	149577	5015 237935	SERGEY NIKOLAEV	{"phone": "+70632486209"}
0005433434572	58A4A6	8037 433595	TATYANA MELNIKOVA	{"email": "melnikova_t-021950@postgrespro.ru", "phone": "+70510731699"}
0005433434573	58A4A6	3749 337701	LARISA LOGINOVA	{"email": "l.loginova031969@postgrespro.ru", "phone": "+70344787926"}
0005433434574	7EAD67	1828 117676	IGOR ZHUKOV	{"email": "zhukov-igor1963@postgrespro.ru", "phone": "+70318342239"}
0005433434575	7EAD67	4929 700802	VERA KOMAROVA	{"phone": "+70326318932"}
0005433434576	346AD3	2160 383544	GALINA PETROVA	{"email": "gpetrova091975@postgrespro.ru", "phone": "+70547383072"}
0005433434577	0E68C8	8691 624392	NIKOLAY ALEKSEEV	{"email": "alekseev_nikolay-19081963@postgrespro.ru", "phone": "+70996761259"}
0005433434578	0E68C8	2172 808042	VIKTOR CHERNOV	{"phone": "+70590712477"}
0005433434579	1EE826	3578 711739	SVETLANA AKIMOVA	{"email": "s-akimova.28011970@postgrespro.ru", "phone": "+70015910146"}
0005433434580	A24EBC	5869 149113	STEPAN ANDREEV	{"phone": "+70453491840"}
0005433434581	47A500	5141 721928	SVETLANA ANTONOVA	{"email": "santonova1968@postgrespro.ru", "phone": "+70137890979"}
0005433434582	47A500	6405 407942	NATALIYA NESTEROVA	{"phone": "+70058948852"}
0005433434583	B0F97C	6185 252596	EVGENIY AFANASEV	{"phone": "+70830799666"}
0005433434584	561DC0	0803 754928	DMITRIY RODIONOV	{"email": "rodionov.dmitriy_09061972@postgrespro.ru", "phone": "+70708619209"}
0005433434585	A94BF3	1931 953733	MARGARITA STEPANOVA	{"email": "stepanova_margarita.04021971@postgrespro.ru", "phone": "+70736558673"}
0005433434586	DF6550	0658 984170	LARISA MATVEEVA	{"phone": "+70193087042"}
0005433434587	7CA695	1399 778220	YULIYA ZHUKOVA	{"email": "y-zhukova.15011971@postgrespro.ru", "phone": "+70329966810"}
0005433434588	E7F569	9165 060936	TATYANA MATVEEVA	{"phone": "+70731098197"}
0005433434589	EEF588	2722 219580	VYACHESLAV VOROBEV	{"phone": "+70939322632"}
0005433434590	B58224	8332 164803	IRINA AFANASEVA	{"phone": "+70404815913"}
0005433434591	D55FA5	5090 974707	OLEG DMITRIEV	{"phone": "+70050648837"}
0005433434592	D55FA5	6536 730381	GALINA KRASNOVA	{"phone": "+70428883083"}
0005433434593	D55FA5	5986 065633	ANNA KRASNOVA	{"phone": "+70583541929"}
0005433434594	686289	5554 260396	SERGEY MATVEEV	{"email": "sergey-matveev_10111972@postgrespro.ru", "phone": "+70760462563"}
0005433434595	686289	1832 421244	ALEKSEY MIKHAYLOV	{"phone": "+70061633921"}
0005433434596	416A95	1097 102215	SEMEN SCHERBAKOV	{"email": "s.scherbakov-15021978@postgrespro.ru", "phone": "+70189294416"}
0005433434597	C55E89	5608 717529	OLEG KARPOV	{"email": "karpov.oleg_09111974@postgrespro.ru", "phone": "+70170308472"}
0005433434598	2DF9EF	5770 447458	NINA MIKHAYLOVA	{"email": "mikhaylova_nina_041980@postgrespro.ru", "phone": "+70336418653"}
0005433434599	E26AE2	8937 223119	ANDREY MAKAROV	{"phone": "+70667362862"}
0005433434600	D0152A	3048 723054	MARIYA KUZMINA	{"email": "kuzminamariya.021968@postgrespro.ru", "phone": "+70442637388"}
0005433434601	D0152A	0275 445127	NATALYA DMITRIEVA	{"phone": "+70584065922"}
0005433434602	7621B1	9002 834594	NIKOLAY BELOV	{"email": "nbelov.091981@postgrespro.ru", "phone": "+70573878526"}
0005433434603	7621B1	2520 213719	ROZA KRASNOVA	{"phone": "+70751050560"}
0005433434604	32FE78	2227 464231	VALENTINA EFREMOVA	{"phone": "+70470194596"}
0005433434605	32FE78	4267 415674	MARIYA VASILEVA	{"email": "mariya_vasileva_1977@postgrespro.ru", "phone": "+70772024789"}
0005433434606	C03CC1	5843 569764	VLADIMIR TIKHONOV	{"phone": "+70434242033"}
0005433434607	C03CC1	5403 939054	NATALYA TARASOVA	{"email": "n.tarasova.1967@postgrespro.ru", "phone": "+70864911451"}
0005433434608	F238EC	6927 110468	ARTEM SERGEEV	{"email": "a.sergeev.02121971@postgrespro.ru", "phone": "+70367518868"}
0005433434609	09F3A5	5131 204245	ALEKSANDRA KONDRATEVA	{"email": "a-kondrateva28031967@postgrespro.ru", "phone": "+70661256822"}
0005433434610	09F3A5	0058 892531	DMITRIY GAVRILOV	{"email": "gavrilov_dmitriy011966@postgrespro.ru", "phone": "+70199756757"}
0005433434611	09F3A5	9484 293475	ALEKSANDR ZAKHAROV	{"email": "a_zakharov_08021978@postgrespro.ru", "phone": "+70785739355"}
0005433434612	52113F	5721 364187	RAUZA NIKITINA	{"email": "nikitina_rauza_19111993@postgrespro.ru", "phone": "+70270085652"}
0005433434613	52113F	8813 011750	VALERIY MIKHAYLOV	{"phone": "+70233263464"}
0005433434614	63E272	7277 116636	EKATERINA RODIONOVA	{"phone": "+70812400437"}
0005433434615	DAD970	7569 779990	TATYANA ANDREEVA	{"email": "tatyana_andreeva071993@postgrespro.ru", "phone": "+70784801946"}
0005433434616	2F2DCB	8157 505962	NATALYA TIKHONOVA	{"email": "tikhonova.n111964@postgrespro.ru", "phone": "+70375644303"}
0005433434617	FBC38E	3530 187972	MARIYA CHERNOVA	{"email": "mariya-chernova-1977@postgrespro.ru", "phone": "+70653473943"}
0005433434618	AE3F91	3252 876133	OLGA NIKOLAEVA	{"phone": "+70826471338"}
0005433434619	074A2F	5003 879200	GRIGORIY MOROZOV	{"email": "grigoriy_morozov_02111971@postgrespro.ru", "phone": "+70709138893"}
0005433434620	25EEEF	9559 956312	VALENTINA YAKOVLEVA	{"phone": "+70701456735"}
0005433434621	25EEEF	8283 535280	OLEG NIKOLAEV	{"phone": "+70828369820"}
0005433434622	F11EE8	5354 680519	OKSANA ZOTOVA	{"email": "oksana_zotova_031979@postgrespro.ru", "phone": "+70950982088"}
0005433434623	F11EE8	9972 017336	NIKOLAY PETROV	{"email": "n-petrov031976@postgrespro.ru", "phone": "+70362765917"}
0005433434624	331F7E	6584 057514	ANASTASIYA MELNIKOVA	{"email": "melnikovaa_05021968@postgrespro.ru", "phone": "+70523580908"}
0005433434625	1FDD5E	5962 888557	ILYA KULIKOV	{"email": "kulikov.i011974@postgrespro.ru", "phone": "+70895538056"}
0005433434626	D40FD0	4039 735901	NIKITA MOISEEV	{"phone": "+70077257049"}
0005433434627	CCE25C	8575 358166	ANASTASIYA MARTYNOVA	{"phone": "+70360137513"}
0005433434628	C5E9E1	7698 741192	VLADIMIR VLASOV	{"email": "vlasov_vladimir-1972@postgrespro.ru", "phone": "+70329812436"}
0005433434629	2F1CA2	5018 735037	VALENTINA GERASIMOVA	{"phone": "+70241725785"}
0005433434630	53210F	7063 558538	EVGENIY BELOV	{"email": "belov_e.101971@postgrespro.ru", "phone": "+70807268193"}
0005433434631	7E59A6	6453 356060	ANASTASIYA EFIMOVA	{"email": "anastasiya-efimova.051971@postgrespro.ru", "phone": "+70897251469"}
0005433434632	4C0618	4194 597343	NATALYA ROMANOVA	{"phone": "+70896131092"}
0005433434633	4C0618	9194 720743	SVETLANA YAKOVLEVA	{"phone": "+70648453218"}
0005433434634	46DE58	7660 032181	YANA GAVRILOVA	{"email": "gavrilova.yana041970@postgrespro.ru", "phone": "+70697274686"}
0005433434635	46DE58	2802 862658	ANATOLIY MIKHAYLOV	{"email": "anatoliymikhaylov_051975@postgrespro.ru", "phone": "+70344521602"}
0005433434636	B48E1F	1725 157378	DENIS KONOVALOV	{"email": "d_konovalov101972@postgrespro.ru", "phone": "+70691941396"}
0005433434637	7D3F7E	8468 723741	LIDIYA FROLOVA	{"phone": "+70944132563"}
0005433434638	7D3F7E	9310 172089	IRINA NIKITINA	{"phone": "+70903336699"}
0005433434639	8383B9	2277 651111	SVETLANA VOROBEVA	{"email": "svetlana_vorobeva111970@postgrespro.ru", "phone": "+70911662950"}
0005433434640	983EF6	6243 222951	TATYANA KUZNECOVA	{"phone": "+70544040392"}
0005433434641	206287	3500 948346	TATYANA MEDVEDEVA	{"email": "medvedeva_t.1976@postgrespro.ru", "phone": "+70821648300"}
0005433434642	72F4A1	2545 311054	ANASTASIYA TITOVA	{"email": "titova.a051968@postgrespro.ru", "phone": "+70911735929"}
0005433434643	D40502	9340 863110	LYUBOV ANDREEVA	{"email": "andreeva_l_1968@postgrespro.ru", "phone": "+70511972726"}
0005433434644	C8FD02	4675 453047	NATALYA ORLOVA	{"phone": "+70196820746"}
0005433434645	562626	4549 041341	ELENA FADEEVA	{"email": "fadeevae.081980@postgrespro.ru", "phone": "+70271639131"}
0005433434646	CE7D32	0951 772623	ALEKSEY ILIN	{"email": "ilin_aleksey.21011961@postgrespro.ru", "phone": "+70478684256"}
0005433434647	50B95B	9761 391338	ANTON KUZNECOV	{"email": "kuznecov.a1972@postgrespro.ru", "phone": "+70716201898"}
0005433434648	50B95B	2087 847925	LYUDMILA ROMANOVA	{"email": "romanova.lyudmila24021982@postgrespro.ru", "phone": "+70078090383"}
0005433434649	50B95B	9111 055902	EVGENIY IVANOV	{"phone": "+70128190474"}
0005433434650	0668F6	4970 271506	ALEKSANDR MAKAROV	{"phone": "+70977476857"}
0005433434651	C94D54	6653 569829	YULIYA LAZAREVA	{"email": "lazareva.yuliya16121977@postgrespro.ru", "phone": "+70807804636"}
0005433434652	C94D54	7193 517109	NIKOLAY MIKHAYLOV	{"phone": "+70753172015"}
0005433434653	7D8C70	1088 458433	SOFYA ANDREEVA	{"phone": "+70332773592"}
0005433434654	7D8C70	3331 093987	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana.051967@postgrespro.ru", "phone": "+70286553792"}
0005433434655	804F32	9946 151651	ALEKSANDR SOROKIN	{"email": "asorokin_13011976@postgrespro.ru", "phone": "+70135258805"}
0005433434656	804F32	7956 380071	INGA LUKYANOVA	{"email": "lukyanovainga1969@postgrespro.ru", "phone": "+70043005962"}
0005433434657	9693E8	1518 484495	NIKOLAY FROLOV	{"email": "frolov.nikolay-1961@postgrespro.ru", "phone": "+70488119601"}
0005433434658	6E94C5	0281 945122	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylovaanastasiya_1962@postgrespro.ru", "phone": "+70552069922"}
0005433434659	26454E	7997 975128	EKATERINA KALININA	{"phone": "+70734681408"}
0005433434660	26454E	7595 556581	SVETLANA SAVELEVA	{"email": "saveleva-svetlana_091971@postgrespro.ru", "phone": "+70909445859"}
0005433434661	3BD301	7309 161102	IRINA PAVLOVA	{"email": "ipavlova.1975@postgrespro.ru", "phone": "+70903545139"}
0005433434662	42FF42	6641 057486	EVGENIY VOLKOV	{"email": "e.volkov_1969@postgrespro.ru", "phone": "+70294594045"}
0005433434773	6D463C	6341 489852	RAISA NIKIFOROVA	{"phone": "+70568693145"}
0005433434663	6AC7B6	1874 121083	VIKTOR FEDOTOV	{"email": "vfedotov.30061961@postgrespro.ru", "phone": "+70262490230"}
0005433434664	4F7244	1394 286491	SVETLANA IVANOVA	{"phone": "+70267179978"}
0005433434665	4E7624	5361 431762	TATYANA TITOVA	{"email": "t_titova_1968@postgrespro.ru", "phone": "+70408920608"}
0005433434666	4E7624	2795 773452	IVAN IVANOV	{"phone": "+70566577961"}
0005433434667	36BE7E	6747 684823	ANASTASIYA AFANASEVA	{"phone": "+70391380458"}
0005433434668	3636C5	1412 443926	LARISA NAZAROVA	{"phone": "+70160143102"}
0005433434669	71E112	2403 420076	EKATERINA ZAYCEVA	{"email": "e.zayceva.13011979@postgrespro.ru", "phone": "+70140752772"}
0005433434670	92B249	8495 354102	ELENA ANDREEVA	{"email": "eandreeva_12091979@postgrespro.ru", "phone": "+70335746739"}
0005433434671	276A2C	9400 957081	NATALYA VASILEVA	{"email": "vasileva.n.1968@postgrespro.ru", "phone": "+70719455858"}
0005433434672	276A2C	3368 918491	MARINA ANDREEVA	{"email": "andreeva_m.25011960@postgrespro.ru", "phone": "+70066805800"}
0005433434673	2D0E82	3322 702964	VASILISA KONOVALOVA	{"email": "vasilisakonovalova-091973@postgrespro.ru", "phone": "+70339654975"}
0005433434674	EC2F08	4219 928989	ALBINA ANTONOVA	{"email": "antonova.a.061974@postgrespro.ru", "phone": "+70894071014"}
0005433434675	5327D4	6661 376676	YURIY MOROZOV	{"phone": "+70048221105"}
0005433434676	CA04A6	8253 359777	OLGA GUSEVA	{"phone": "+70141561931"}
0005433434677	C942AE	6695 687668	VLADIMIR FOMIN	{"phone": "+70184625484"}
0005433434678	3046C1	7707 612755	LYUBOV GUSEVA	{"email": "lyubov.guseva-1971@postgrespro.ru", "phone": "+70080191122"}
0005433434679	F3F80C	3326 829184	IRINA ZAYCEVA	{"email": "i.zayceva1971@postgrespro.ru", "phone": "+70643038479"}
0005433434680	927FB8	7966 693710	GENNADIY KOZLOV	{"email": "kozlov.g04111972@postgrespro.ru", "phone": "+70923067909"}
0005433434681	927FB8	9418 326314	LARISA FEDOROVA	{"phone": "+70998761319"}
0005433434682	A69EC8	3183 912112	MARIYA MAKAROVA	{"email": "m_makarova1972@postgrespro.ru", "phone": "+70385532874"}
0005433434683	7A4C52	6202 829670	NATALYA SERGEEVA	{"email": "sergeeva.natalya-20081975@postgrespro.ru", "phone": "+70416424737"}
0005433434684	48320A	7801 483263	IRINA KARPOVA	{"email": "karpova-i-12101975@postgrespro.ru", "phone": "+70160413019"}
0005433434685	48320A	0774 873199	ANDREY DENISOV	{"email": "a.denisov1965@postgrespro.ru", "phone": "+70259945979"}
0005433434686	1F9A58	7166 805231	ROMAN GRIGOREV	{"email": "rgrigorev1972@postgrespro.ru", "phone": "+70859657275"}
0005433434687	B07159	4939 306443	ANTONINA NOVIKOVA	{"email": "novikovaa.02111962@postgrespro.ru", "phone": "+70482928217"}
0005433434688	F5B6C0	0670 769857	ALEKSANDR RODIONOV	{"phone": "+70057560857"}
0005433434689	C5AE85	2008 553515	VALENTINA EGOROVA	{"phone": "+70065157926"}
0005433434690	AB13FF	2962 208024	LIDIYA FOMINA	{"email": "fominal1967@postgrespro.ru", "phone": "+70269409220"}
0005433434691	A898C9	3027 589175	VIKTOR SERGEEV	{"email": "sergeev_v-1975@postgrespro.ru", "phone": "+70756784632"}
0005433434692	170355	0485 766031	NIKOLAY VASILEV	{"email": "n_vasilev-021973@postgrespro.ru", "phone": "+70869719453"}
0005433434693	170355	8432 464830	NAILYA SCHERBAKOVA	{"email": "nailya.scherbakova-07091964@postgrespro.ru", "phone": "+70723470956"}
0005433434694	170355	8062 763557	VADIM SOLOVEV	{"email": "v-solovev.08091975@postgrespro.ru", "phone": "+70741782999"}
0005433434695	D2B101	5935 630098	TIMUR ZAKHAROV	{"email": "timur.zakharov.1974@postgrespro.ru", "phone": "+70916865164"}
0005433434696	016431	6200 841002	TATYANA IVANOVA	{"phone": "+70753358625"}
0005433434697	EE084B	2971 286723	TATYANA RODIONOVA	{"email": "tatyana.rodionova.091975@postgrespro.ru", "phone": "+70457250987"}
0005433434698	B6FA3C	2215 448145	OKSANA DMITRIEVA	{"email": "o_dmitrieva.1973@postgrespro.ru", "phone": "+70112076240"}
0005433434699	B6FA3C	4642 220047	TATYANA DAVYDOVA	{"email": "davydovatatyana-1978@postgrespro.ru", "phone": "+70335798507"}
0005433434700	A1B735	1208 095527	VALENTINA STEPANOVA	{"phone": "+70269642420"}
0005433434701	1F95F8	1795 604838	VADIM VOROBEV	{"phone": "+70121841153"}
0005433434702	C61561	8465 356313	DMITRIY NAZAROV	{"email": "dmitriy_nazarov_19081976@postgrespro.ru", "phone": "+70536479777"}
0005433434703	AC1DF5	0105 721873	NIKOLAY IVANOV	{"email": "nikolay-ivanov.051966@postgrespro.ru", "phone": "+70781927170"}
0005433434704	2A6E3B	4458 815142	VLADIMIR EGOROV	{"phone": "+70963098883"}
0005433434705	2A6E3B	5022 547186	IRAIDA GERASIMOVA	{"phone": "+70766707722"}
0005433434706	C8DCE9	8962 353905	VIKTOR MOISEEV	{"phone": "+70847487608"}
0005433434707	AD69EC	4713 610730	OLGA GRISHINA	{"email": "grishina.olga.20041974@postgrespro.ru", "phone": "+70168358362"}
0005433434708	AD69EC	8630 543114	NIKOLAY ALEKSEEV	{"phone": "+70021654708"}
0005433434709	7FFAFB	1287 958258	NATALYA MOROZOVA	{"email": "morozova-n.10091977@postgrespro.ru", "phone": "+70591567443"}
0005433434710	A91FCC	4479 401401	DANIIL YAKOVLEV	{"phone": "+70236416967"}
0005433434711	A91FCC	0700 384268	YULIYA DAVYDOVA	{"phone": "+70221233314"}
0005433434712	05070A	6008 162852	VERA MAKAROVA	{"email": "vmakarova.051963@postgrespro.ru", "phone": "+70772030195"}
0005433434713	DAD5AB	5833 903433	MARIYA BARANOVA	{"email": "baranova.m.041965@postgrespro.ru", "phone": "+70429938699"}
0005433434714	071E6F	0079 639267	TAMARA SEMENOVA	{"email": "semenova_t21041964@postgrespro.ru", "phone": "+70030609914"}
0005433434715	1D370F	4007 738367	DENIS OSIPOV	{"email": "denis-osipov_061980@postgrespro.ru", "phone": "+70156866935"}
0005433434716	5E4FB0	5847 717715	ALEKSEY ZAYCEV	{"phone": "+70707569106"}
0005433434717	5E4FB0	6390 064330	VALENTINA SEMENOVA	{"phone": "+70116571760"}
0005433434718	B511D5	2966 806501	ILYA KARPOV	{"email": "karpov-ilya1958@postgrespro.ru", "phone": "+70407596015"}
0005433434719	B511D5	2097 994925	RAISA FILIPPOVA	{"email": "r_filippova03061974@postgrespro.ru", "phone": "+70185687399"}
0005433434720	B56FA4	3476 492036	ELENA SOROKINA	{"phone": "+70193253071"}
0005433434721	D9B9E2	7396 402892	ALEKSEY ORLOV	{"email": "aleksey_orlov1975@postgrespro.ru", "phone": "+70265162836"}
0005433434722	D9B9E2	4501 025112	SVETLANA MASLOVA	{"phone": "+70896727257"}
0005433434723	1B8125	7429 895485	ANATOLIY VOLKOV	{"phone": "+70050584745"}
0005433434724	155269	1523 285013	MARIYA MELNIKOVA	{"phone": "+70007705556"}
0005433434725	E30462	6282 955962	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova1974@postgrespro.ru", "phone": "+70508542633"}
0005433434726	E30462	2515 503758	LYUDMILA BELYAEVA	{"email": "l_belyaeva.19021972@postgrespro.ru", "phone": "+70213910113"}
0005433434727	C23696	8218 392790	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr.04041974@postgrespro.ru", "phone": "+70516236243"}
0005433434728	2725FA	3514 217767	PAVEL VASILEV	{"email": "vasilevp.1969@postgrespro.ru", "phone": "+70255312484"}
0005433434729	7AE412	3098 914780	IRINA ROMANOVA	{"email": "irina_romanova-081973@postgrespro.ru", "phone": "+70091877684"}
0005433434730	5F7223	6626 803965	VALENTINA BORISOVA	{"email": "borisova-v_07031960@postgrespro.ru", "phone": "+70496195348"}
0005433434731	5F7223	4953 335078	ALEKSANDR SEMENOV	{"email": "asemenov.031961@postgrespro.ru", "phone": "+70261145275"}
0005433434732	7D5432	7735 813181	LYUBOV TIMOFEEVA	{"phone": "+70158533747"}
0005433434733	0F74E0	9494 651326	GYUZEL ANISIMOVA	{"email": "anisimova.gyuzel04011977@postgrespro.ru", "phone": "+70976531507"}
0005433434734	0F74E0	0087 356314	ANDREY FEDOROV	{"email": "fedorov-a_1969@postgrespro.ru", "phone": "+70918009868"}
0005433434735	A618A8	6390 712090	PETR IVANOV	{"email": "ivanov_p07031977@postgrespro.ru", "phone": "+70761194161"}
0005433434736	02E75A	3505 891584	ELENA SIDOROVA	{"phone": "+70888076660"}
0005433434737	1E0D8A	9710 653756	EVGENIY IVANOV	{"phone": "+70992010782"}
0005433434738	BD107C	5545 924539	MARIYA KOVALEVA	{"email": "mariyakovaleva-11011975@postgrespro.ru", "phone": "+70248456094"}
0005433434739	BD107C	2861 393013	NIKOLAY GRIGOREV	{"phone": "+70721960845"}
0005433434740	B6D9BC	4539 745705	ARTEM SOLOVEV	{"email": "artemsolovev-081980@postgrespro.ru", "phone": "+70272047105"}
0005433434741	6E773D	1247 076331	DENIS KOZLOV	{"email": "kozlov.d.121962@postgrespro.ru", "phone": "+70515829927"}
0005433434742	6E773D	3720 067000	VALENTIN ISAEV	{"email": "visaev.1970@postgrespro.ru", "phone": "+70613879757"}
0005433434743	E10EBD	1187 023007	NATALYA BELOVA	{"phone": "+70893165723"}
0005433434984	8B6DE7	4310 930419	ALEKSANDR NIKOLAEV	{"phone": "+70837251211"}
0005433434744	DD77A7	9418 958360	OLGA KONDRATEVA	{"email": "kondrateva_o-011988@postgrespro.ru", "phone": "+70380344226"}
0005433434745	00AB87	6175 294320	ANGELINA NIKOLAEVA	{"phone": "+70751879123"}
0005433434746	E634C8	9014 680300	YURIY SIDOROV	{"email": "yuriy-sidorov.101970@postgrespro.ru", "phone": "+70645110708"}
0005433434747	EA29DB	4316 636975	SVETLANA KOROLEVA	{"phone": "+70811703222"}
0005433434748	963BE8	5156 434510	SVETLANA MARTYNOVA	{"email": "svetlanamartynova19051967@postgrespro.ru", "phone": "+70638147993"}
0005433434749	C21D7F	0849 433464	ANDREY STEPANOV	{"email": "andreystepanov_19071978@postgrespro.ru", "phone": "+70797409127"}
0005433434750	BDAB94	3431 362005	TATYANA NAZAROVA	{"phone": "+70420441707"}
0005433434751	BDAB94	6798 320006	NADEZHDA VOROBEVA	{"phone": "+70343135510"}
0005433434752	23F8DD	2379 187843	IVAN NOVIKOV	{"email": "novikov_i-10051972@postgrespro.ru", "phone": "+70291227151"}
0005433434753	7522A6	4527 922346	DMITRIY MAKSIMOV	{"phone": "+70522402209"}
0005433434754	E968D5	7002 503354	VIKTOR ROMANOV	{"email": "romanovviktor031966@postgrespro.ru", "phone": "+70878495462"}
0005433434755	E968D5	0430 109127	NIKOLAY ZHUKOV	{"email": "zhukov_n_26071978@postgrespro.ru", "phone": "+70389676742"}
0005433434756	F4E13D	9935 109122	VIKTOR SHEVCHENKO	{"phone": "+70403905077"}
0005433434757	3F4581	4502 381269	NIKOLAY VASILEV	{"email": "vasilevn1961@postgrespro.ru", "phone": "+70675750677"}
0005433434758	3F4581	3600 900052	NIKOLAY ANDREEV	{"phone": "+70071767101"}
0005433434759	D16588	7773 665351	EKATERINA KAZAKOVA	{"phone": "+70977588135"}
0005433434760	D16588	4900 465909	GEORGIY VOLKOV	{"phone": "+70246349154"}
0005433434761	7F57AF	1224 271542	ELENA KUZNECOVA	{"email": "kuznecova-e_1974@postgrespro.ru", "phone": "+70919529380"}
0005433434762	DAA899	8729 428047	LYUBOV NAZAROVA	{"email": "lyubov.nazarova17091967@postgrespro.ru", "phone": "+70449822130"}
0005433434763	D61D47	2832 491282	MARGARITA ABRAMOVA	{"phone": "+70360205879"}
0005433434764	BF4D9F	0576 372739	VERA LAZAREVA	{"email": "vera.lazareva-1962@postgrespro.ru", "phone": "+70348781126"}
0005433434765	C84C6C	5977 472073	ALEKSANDR SHEVCHENKO	{"phone": "+70048971268"}
0005433434766	C84C6C	7274 523646	GALINA VOROBEVA	{"email": "vorobeva.g-26061982@postgrespro.ru", "phone": "+70648283788"}
0005433434767	F6C98D	7342 592963	ANTONINA KUDRYASHOVA	{"phone": "+70121160439"}
0005433434768	37E1FF	4008 854609	ELENA ANDREEVA	{"email": "andreeva_elena.011975@postgrespro.ru", "phone": "+70462208950"}
0005433434769	152190	5127 828019	VADIM SIDOROV	{"email": "vadim_sidorov23021979@postgrespro.ru", "phone": "+70753777940"}
0005433434770	E8E97E	1402 142464	ALEKSANDR POPOV	{"phone": "+70744520477"}
0005433434771	D1834E	6719 597013	LYUDMILA DENISOVA	{"email": "l-denisova.07101968@postgrespro.ru", "phone": "+70071685166"}
0005433434772	D1834E	9608 630330	EVGENIYA DANILOVA	{"email": "danilovaevgeniya_1970@postgrespro.ru", "phone": "+70171078180"}
0005433434774	6CB461	1877 118939	VIKTOR KUZNECOV	{"phone": "+70926456629"}
0005433434775	AD0980	8645 444715	VALERIY KUZNECOV	{"phone": "+70194712087"}
0005433434776	1A0A1A	1628 579423	DANILA MAKSIMOV	{"email": "maksimov_danila-06061961@postgrespro.ru", "phone": "+70946519768"}
0005433434777	467B9A	2912 915832	VYACHESLAV KUZNECOV	{"email": "kuznecov-v20051969@postgrespro.ru", "phone": "+70982481800"}
0005433434778	FE5562	1414 351254	VASILIY SERGEEV	{"email": "sergeev.vasiliy_1981@postgrespro.ru", "phone": "+70204354035"}
0005433434779	54CF13	3176 795453	IVAN KARPOV	{"email": "karpov-i_1966@postgrespro.ru", "phone": "+70504161482"}
0005433434780	590D7E	3257 586785	KONSTANTIN PETROV	{"phone": "+70443498307"}
0005433434781	96C9B2	1060 081864	RAVILYA FOMINA	{"email": "ravilya-fomina021969@postgrespro.ru", "phone": "+70507445847"}
0005433434782	96C9B2	5056 089434	VENIAMIN PETROV	{"email": "petrov.v1981@postgrespro.ru", "phone": "+70206158925"}
0005433434783	D2742C	3172 621995	OKSANA CHERNOVA	{"email": "chernova-oksana061980@postgrespro.ru", "phone": "+70517450735"}
0005433434784	98CB89	6477 933149	ALEKSEY TIMOFEEV	{"phone": "+70429399674"}
0005433434785	B5EC61	6158 858968	VIKTOR MOISEEV	{"phone": "+70683173457"}
0005433434786	E195C7	7944 546312	EKATERINA IVANOVA	{"email": "ivanova.ekaterina.1970@postgrespro.ru", "phone": "+70139954245"}
0005433435233	FFF595	4024 952660	SERGEY KOROLEV	{"phone": "+70247921816"}
0005433434787	E195C7	6662 365668	GLEB KOROLEV	{"email": "korolev_g05121972@postgrespro.ru", "phone": "+70316082748"}
0005433434788	F1D0DC	8174 029329	ANNA MOROZOVA	{"phone": "+70408717415"}
0005433434789	43AF06	9075 479945	VALERIY FEDOROV	{"phone": "+70497476996"}
0005433434790	1F3255	8608 246051	ANDREY PETROV	{"email": "andreypetrov23071963@postgrespro.ru", "phone": "+70571133972"}
0005433434791	4183B5	1762 234328	ALEKSANDR ISAEV	{"email": "isaev.a1968@postgrespro.ru", "phone": "+70400155431"}
0005433434792	4183B5	4596 972464	NATALYA SAVELEVA	{"phone": "+70113485697"}
0005433434793	60077F	8376 124153	ALEKSEY FROLOV	{"email": "frolovaleksey121971@postgrespro.ru", "phone": "+70395960216"}
0005433434794	499E84	4295 939494	ZOYA STEPANOVA	{"phone": "+70709771176"}
0005433434795	949D0C	3878 279505	OKSANA KONDRATEVA	{"email": "kondratevao-21101984@postgrespro.ru", "phone": "+70691278958"}
0005433434796	949D0C	6175 693381	TAISIYA YAKOVLEVA	{"phone": "+70025820437"}
0005433434797	058074	1343 300310	LYUBOV PETROVA	{"email": "petrova_lyubov.071967@postgrespro.ru", "phone": "+70274447641"}
0005433434798	E9BD04	1283 465911	ALEKSANDR SERGEEV	{"phone": "+70412151731"}
0005433434799	E9BD04	3038 397476	DENIS MATVEEV	{"email": "matveevdenis111967@postgrespro.ru", "phone": "+70178553271"}
0005433434800	6B12E9	2918 923352	NIKITA VOLKOV	{"phone": "+70362941368"}
0005433434801	00E821	2957 588238	TATYANA SEMENOVA	{"email": "semenova.t22031978@postgrespro.ru", "phone": "+70706341350"}
0005433434802	4F3661	9190 468939	ANDREY KULIKOV	{"email": "kulikova.10021979@postgrespro.ru", "phone": "+70803806427"}
0005433434803	4F3661	4173 204931	NINA KOZLOVA	{"email": "nina-kozlova_011979@postgrespro.ru", "phone": "+70901615208"}
0005433434804	4E2022	9903 683798	EKATERINA ALEKSEEVA	{"phone": "+70763056888"}
0005433434805	E6DF1F	0435 469577	MIKHAIL GAVRILOV	{"phone": "+70365113297"}
0005433434806	E6DF1F	6188 727114	SERGEY NOVIKOV	{"phone": "+70263916918"}
0005433434807	8417B5	6205 638965	ARTEM KUZNECOV	{"phone": "+70862320982"}
0005433434808	8417B5	0637 465867	VLADIMIR VOROBEV	{"phone": "+70087380691"}
0005433434809	0B3972	0419 202795	SERGEY KULIKOV	{"email": "kulikov_sergey_081969@postgrespro.ru", "phone": "+70144831882"}
0005433434810	644DBC	9067 131138	YULIYA KUZMINA	{"phone": "+70516509542"}
0005433434811	644DBC	7336 778524	VIKTORIYA NIKITINA	{"email": "viktoriya.nikitina21111970@postgrespro.ru", "phone": "+70025153610"}
0005433434812	644DBC	2262 776819	OLEG BELOV	{"phone": "+70519244171"}
0005433434813	070682	6398 545216	SERGEY YAKOVLEV	{"email": "sergey-yakovlev.26111964@postgrespro.ru", "phone": "+70389901241"}
0005433434814	070682	5008 283632	TATYANA LAZAREVA	{"phone": "+70399337674"}
0005433434815	070682	9683 284593	VIKTOR BONDARENKO	{"phone": "+70864826366"}
0005433434816	070682	9615 411927	TATYANA VASILEVA	{"email": "t.vasileva-1973@postgrespro.ru", "phone": "+70303387855"}
0005433434817	070682	8258 369301	TAISIYA MATVEEVA	{"phone": "+70246604732"}
0005433434818	B59353	4520 980764	ROMAN MAKSIMOV	{"phone": "+70735962430"}
0005433434819	9394D8	3069 543263	PAVEL MOROZOV	{"email": "morozovpavel-1967@postgrespro.ru", "phone": "+70531995227"}
0005433434820	9394D8	4358 915442	VYACHESLAV ORLOV	{"email": "orlov_vyacheslav051977@postgrespro.ru", "phone": "+70106180314"}
0005433434821	23DAF9	9867 920838	ALEKSANDR KOZLOV	{"phone": "+70614367081"}
0005433434822	BF2B01	0005 645817	VLADIMIR KUZMIN	{"phone": "+70543228371"}
0005433434823	2D13BE	9974 622243	ANASTASIYA NIKOLAEVA	{"email": "anastasiya.nikolaeva.23081981@postgrespro.ru", "phone": "+70998104130"}
0005433434824	45D215	5208 228001	MARGARITA MATVEEVA	{"email": "matveeva-margarita-27121975@postgrespro.ru", "phone": "+70409232734"}
0005433434825	45D215	0577 314083	VLADIMIR GAVRILOV	{"email": "gavrilov.v.24041969@postgrespro.ru", "phone": "+70317544841"}
0005433434826	75A7F4	6968 216492	KRISTINA VOLKOVA	{"email": "volkova_kristina011980@postgrespro.ru", "phone": "+70695472619"}
0005433434827	75A7F4	2746 776725	NINA YAKOVLEVA	{"email": "yakovleva.n.31081966@postgrespro.ru", "phone": "+70717919191"}
0005433434828	BE42C5	3165 297514	IVAN SEMENOV	{"email": "semenov.i-21121969@postgrespro.ru", "phone": "+70601060685"}
0005433434829	BE42C5	8820 554713	SERGEY BARANOV	{"phone": "+70285824243"}
0005433434830	41431D	5719 455198	ANATOLIY IVANOV	{"email": "ivanov-a25071971@postgrespro.ru", "phone": "+70341723852"}
0005433434831	C06747	7984 327237	VALERIY PAVLOV	{"phone": "+70127253819"}
0005433434832	C9D372	6745 395306	NIKOLAY SOROKIN	{"phone": "+70829966596"}
0005433434833	56A826	3172 678705	VALENTINA KOZLOVA	{"email": "valentinakozlova_19021980@postgrespro.ru", "phone": "+70759673802"}
0005433434834	92FA16	7174 114295	OLEG FEDOROV	{"email": "o-fedorov.02071976@postgrespro.ru", "phone": "+70260513346"}
0005433434835	3C1032	7691 705739	VALERIY EGOROV	{"phone": "+70381353094"}
0005433434836	3C1032	7705 659400	LIDIYA DAVYDOVA	{"email": "lidiya.davydova1963@postgrespro.ru", "phone": "+70108524686"}
0005433434837	8F0925	2777 904225	NIKOLAY AFANASEV	{"email": "nikolay-afanasev-25081964@postgrespro.ru", "phone": "+70307880698"}
0005433434838	8F0925	1555 779079	VLADIMIR SOKOLOV	{"email": "vladimir-sokolov051970@postgrespro.ru", "phone": "+70585577986"}
0005433434839	AC5D7D	5884 979140	ALEKSANDR MIKHAYLOV	{"phone": "+70868053145"}
0005433434840	28183A	0218 323427	NIKOLAY MAKAROV	{"phone": "+70542412466"}
0005433434841	28183A	6916 329875	GALINA ORLOVA	{"email": "g.orlova.1974@postgrespro.ru", "phone": "+70932196376"}
0005433434842	2879D4	9962 915325	VALENTINA IVANOVA	{"phone": "+70599882298"}
0005433434843	AA1832	2976 843930	NAIL NIKITIN	{"email": "n-nikitin-091965@postgrespro.ru", "phone": "+70512573506"}
0005433434844	DB1ADC	8432 317936	LYUBOV AKIMOVA	{"phone": "+70344011304"}
0005433434845	FDA1C0	4628 322851	ELIZAVETA GORBUNOVA	{"email": "elizavetagorbunova1965@postgrespro.ru", "phone": "+70717559638"}
0005433434846	BCDC90	1016 901517	MAKSIM NIKOLAEV	{"email": "maksim_nikolaev_1977@postgrespro.ru", "phone": "+70805845878"}
0005433434847	6CFC32	3326 472076	ALEKSANDR ROMANOV	{"email": "a_romanov_1963@postgrespro.ru", "phone": "+70006866852"}
0005433434848	8BD120	0161 430705	VIKTOR BONDARENKO	{"email": "bondarenko.viktor.051969@postgrespro.ru", "phone": "+70505982735"}
0005433434849	723A26	4026 902978	MARIYA POPOVA	{"email": "popova.m1974@postgrespro.ru", "phone": "+70899105060"}
0005433434850	E14EC2	7048 510303	SVETLANA ZOTOVA	{"phone": "+70492192247"}
0005433434851	E14EC2	5299 770375	ANASTASIYA ALEKSEEVA	{"email": "a_alekseeva-18031974@postgrespro.ru", "phone": "+70564040881"}
0005433434852	3B35F9	9297 549189	GALINA GAVRILOVA	{"email": "galina_gavrilova111968@postgrespro.ru", "phone": "+70164339876"}
0005433434853	FCC848	6803 336187	MIKHAIL POPOV	{"phone": "+70359634773"}
0005433434854	FFAC65	2696 065143	ELENA FEDOROVA	{"email": "e.fedorova12111965@postgrespro.ru", "phone": "+70740107709"}
0005433434855	44740F	5901 269912	IGOR VOROBEV	{"email": "vorobevigor071989@postgrespro.ru", "phone": "+70311515214"}
0005433434856	B2A854	4465 092927	ALEKSANDRA KRASNOVA	{"email": "aleksandra_krasnova.1967@postgrespro.ru", "phone": "+70820052007"}
0005433434857	10AD12	6079 708940	SERGEY BELOV	{"phone": "+70111887859"}
0005433434858	10AD12	9145 232194	VALENTINA GUSEVA	{"phone": "+70047140210"}
0005433434859	75B047	9449 114598	VLADIMIR MEDVEDEV	{"phone": "+70044239612"}
0005433434860	01E707	2689 974961	YURIY ALEKSANDROV	{"phone": "+70365895054"}
0005433434861	438585	6234 811859	SERGEY POPOV	{"phone": "+70898537072"}
0005433435161	1AFF67	5723 944513	SVETLANA MAKSIMOVA	{"phone": "+70711403744"}
0005433434862	438585	3830 234664	MARIYA KUZNECOVA	{"email": "mariya-kuznecova.01031975@postgrespro.ru", "phone": "+70286256148"}
0005433434863	438585	5842 696803	VYACHESLAV ANTONOV	{"email": "antonov-vyacheslav06021980@postgrespro.ru", "phone": "+70180280417"}
0005433434864	9E462F	9162 910239	ALEKSANDR GORBUNOV	{"phone": "+70522091811"}
0005433434865	DC3E78	5897 466363	MARIYA NAUMOVA	{"email": "m.naumova041972@postgrespro.ru", "phone": "+70576392794"}
0005433434866	DC3E78	1961 206150	LYUBOV ISAEVA	{"phone": "+70919206734"}
0005433434867	4BD956	3867 580513	OLGA VOLKOVA	{"email": "o.volkova.12061969@postgrespro.ru", "phone": "+70431235067"}
0005433434868	A8BAFD	1732 841006	ANNA IVANOVA	{"phone": "+70397109696"}
0005433434869	6AA800	2118 788068	GEORGIY FROLOV	{"email": "gfrolov-011970@postgrespro.ru", "phone": "+70084613079"}
0005433434870	6AA800	2270 540370	VADIM MATVEEV	{"email": "matveevvadim_061973@postgrespro.ru", "phone": "+70063641923"}
0005433434871	654D1B	1991 816728	NIKOLAY ANDREEV	{"phone": "+70607606999"}
0005433434872	D7189B	0819 224893	KONSTANTIN SEMENOV	{"phone": "+70275256988"}
0005433434873	D7189B	7666 484924	EKATERINA EGOROVA	{"phone": "+70896785227"}
0005433434874	E3E630	6236 646078	VIKTOR MAKAROV	{"email": "makarovv031969@postgrespro.ru", "phone": "+70441197152"}
0005433434875	6E6297	7158 302533	IRINA ZHURAVLEVA	{"phone": "+70466651374"}
0005433434876	5B3F92	1251 099146	NADEZHDA ALEKSEEVA	{"email": "nadezhdaalekseeva_1975@postgrespro.ru", "phone": "+70231495503"}
0005433434877	5B3F92	1830 698040	TIMOFEY KISELEV	{"phone": "+70520443982"}
0005433434878	4C026B	5391 963828	KLAVDIYA OSIPOVA	{"phone": "+70915247267"}
0005433434879	4C026B	7008 917173	SVETLANA YAKOVLEVA	{"email": "svetlana.yakovleva_121971@postgrespro.ru", "phone": "+70029537769"}
0005433434880	9B28C5	9541 343954	IGOR ZAKHAROV	{"email": "zakharov.igor071988@postgrespro.ru", "phone": "+70876725257"}
0005433434881	F27E26	2235 527674	ROZA ZHUKOVA	{"email": "rozazhukova.08061990@postgrespro.ru", "phone": "+70820763631"}
0005433434882	F27E26	4139 525887	MARTA MALYSHEVA	{"phone": "+70939584232"}
0005433434883	2ED497	8906 709492	OLEG ZAKHAROV	{"email": "o_zakharov_09071971@postgrespro.ru", "phone": "+70436368315"}
0005433434884	A55664	1264 223727	LIDIYA POPOVA	{"phone": "+70964882916"}
0005433434885	B324EE	7652 769469	GALINA NIKITINA	{"phone": "+70889074125"}
0005433434886	16C2CF	8517 328757	YURIY POPOV	{"email": "popov.y11111955@postgrespro.ru", "phone": "+70334592478"}
0005433434887	EF4489	8942 604806	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr081982@postgrespro.ru", "phone": "+70151144335"}
0005433434888	40E0C6	8966 242222	VALENTINA MAKSIMOVA	{"email": "maksimova-valentina-1966@postgrespro.ru", "phone": "+70390805403"}
0005433434889	1EA550	0014 472571	VALENTIN PETROV	{"phone": "+70572622558"}
0005433434890	1EA550	3398 094504	LYUBOV GUSEVA	{"email": "gusevalyubov_21081971@postgrespro.ru", "phone": "+70622277875"}
0005433434891	1EA550	2909 023888	OLGA NESTEROVA	{"phone": "+70136787003"}
0005433434892	A3310D	1102 175228	IVAN NIKOLAEV	{"phone": "+70787804282"}
0005433434893	7780EF	9660 709881	LIDIYA ORLOVA	{"phone": "+70983602996"}
0005433434894	7780EF	2848 988577	VALENTINA ALEKSANDROVA	{"email": "valentina-aleksandrova1976@postgrespro.ru", "phone": "+70730295821"}
0005433434895	E8D8B6	8190 481248	ROMAN SIDOROV	{"email": "sidorov-roman_041975@postgrespro.ru", "phone": "+70186842939"}
0005433434896	BC0814	3247 073606	NIKOLAY MAKSIMOV	{"phone": "+70783777731"}
0005433434897	1EF497	6178 257070	ELENA ILINA	{"email": "ilina.elena-08061960@postgrespro.ru", "phone": "+70586940869"}
0005433434898	7DB4F3	8482 978560	NATALYA BARANOVA	{"phone": "+70683061264"}
0005433434899	81AC1C	1214 998069	MARIYA LEBEDEVA	{"email": "m_lebedeva111967@postgrespro.ru", "phone": "+70556768394"}
0005433434900	81AC1C	1020 944546	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov-101970@postgrespro.ru", "phone": "+70812650465"}
0005433434901	81AC1C	6475 242066	DMITRIY IVANOV	{"email": "ivanov.dmitriy-101968@postgrespro.ru", "phone": "+70121652033"}
0005433434902	A81B55	9144 604603	LYUDMILA ALEKSEEVA	{"phone": "+70975865724"}
0005433434903	7F11B4	0634 483633	TATYANA KAZAKOVA	{"phone": "+70241585246"}
0005433434904	CBCEFF	0615 818427	GALINA KOZLOVA	{"email": "galina-kozlova-29041978@postgrespro.ru", "phone": "+70318387334"}
0005433434905	52342A	5011 271101	IRINA TARASOVA	{"email": "irina.tarasova_1957@postgrespro.ru", "phone": "+70857841348"}
0005433434906	43E5D4	4741 416389	YURIY BORISOV	{"phone": "+70545461665"}
0005433434907	BE89EA	5113 163321	YURIY BORISOV	{"phone": "+70379775051"}
0005433434908	BE89EA	7489 202360	VALERIYA BORISOVA	{"email": "valeriya.borisova011977@postgrespro.ru", "phone": "+70114226220"}
0005433434909	A159F1	1174 029513	ALINA MIKHAYLOVA	{"email": "mikhaylova-a_071970@postgrespro.ru", "phone": "+70378509744"}
0005433434910	193B2E	0342 986911	TAMARA EGOROVA	{"phone": "+70860297688"}
0005433434911	9BABA1	4042 703344	BORIS ABRAMOV	{"email": "abramovboris.101975@postgrespro.ru", "phone": "+70052259231"}
0005433434912	115A79	7422 033304	EKATERINA FILIPPOVA	{"phone": "+70209335237"}
0005433434913	1D89CB	4090 128853	ALEKSANDR NAUMOV	{"phone": "+70377706665"}
0005433434914	DD2B03	7085 323342	DIANA MAKAROVA	{"email": "dianamakarova.29041979@postgrespro.ru", "phone": "+70693376660"}
0005433434915	39808D	4160 499717	ALEKSANDR TIKHONOV	{"email": "tikhonov.a.081983@postgrespro.ru", "phone": "+70716774185"}
0005433434916	1835CB	9343 788104	LIDIYA SOROKINA	{"phone": "+70070036051"}
0005433434917	28F6A0	8415 725676	MIKHAIL ZAYCEV	{"phone": "+70806224769"}
0005433434918	469542	8201 123307	MARIYA KUZNECOVA	{"phone": "+70770331013"}
0005433434919	E95A98	6496 914356	DANIYA MIKHAYLOVA	{"email": "mikhaylova_d1978@postgrespro.ru", "phone": "+70980990167"}
0005433434920	7D110A	4635 711802	TAMARA PAVLOVA	{"phone": "+70774867167"}
0005433434921	7D110A	3790 372086	LYUBOV KOROLEVA	{"phone": "+70727490107"}
0005433434922	86C5E0	7949 446104	VALERIY IVANOV	{"phone": "+70316648031"}
0005433434923	D406CF	9676 478851	VALENTINA DAVYDOVA	{"email": "v-davydova.07011967@postgrespro.ru", "phone": "+70014960687"}
0005433434924	BF1E05	7422 462557	EKATERINA KUZMINA	{"email": "kuzmina.e-08021966@postgrespro.ru", "phone": "+70819566981"}
0005433434925	BF1E05	1550 871991	GALINA SERGEEVA	{"phone": "+70906506457"}
0005433434926	7330FF	0761 536312	ZOYA FROLOVA	{"phone": "+70442022789"}
0005433434927	7330FF	5957 946225	EVGENIY PAVLOV	{"phone": "+70952795709"}
0005433434928	7330FF	7095 562226	ARTEM SCHERBAKOV	{"phone": "+70401471576"}
0005433434929	F72ACB	5486 264141	ALEKSANDR POPOV	{"email": "popov-aleksandr_29061965@postgrespro.ru", "phone": "+70722819460"}
0005433434930	F72ACB	6463 076446	VALENTINA KUZNECOVA	{"phone": "+70519052339"}
0005433434931	BA3DA5	2597 829675	NADEZHDA ERMAKOVA	{"email": "nermakova.1975@postgrespro.ru", "phone": "+70908195312"}
0005433434932	D15B76	5598 828568	OLGA NIKITINA	{"phone": "+70723388902"}
0005433434933	D15B76	4208 975489	POLINA KAZAKOVA	{"email": "kazakova_p_06041967@postgrespro.ru", "phone": "+70926284266"}
0005433434934	316979	8277 442928	IRINA SOKOLOVA	{"phone": "+70087791808"}
0005433434935	00E198	3358 040897	ARTUR IVANOV	{"email": "ivanovartur-031977@postgrespro.ru", "phone": "+70035661412"}
0005433434936	A194E1	2170 787237	VASILIY FILIPPOV	{"email": "filippov.v-021973@postgrespro.ru", "phone": "+70528961101"}
0005433434937	344439	9181 837068	VLADIMIR KUZNECOV	{"phone": "+70495587518"}
0005433434938	90A777	4013 914139	IRINA TARASOVA	{"phone": "+70692068410"}
0005433434939	A52761	0757 755297	ELIZAVETA MOISEEVA	{"email": "elizavetamoiseeva1972@postgrespro.ru", "phone": "+70536467633"}
0005433434940	943BD6	2696 603333	RUSLAN ROMANOV	{"email": "ruslan-romanov_041972@postgrespro.ru", "phone": "+70396199025"}
0005433434941	943BD6	5113 123675	PAVEL ZAYCEV	{"phone": "+70573922669"}
0005433434942	738A36	1655 571964	VYACHESLAV MOISEEV	{"email": "moiseev.v_1969@postgrespro.ru", "phone": "+70990178444"}
0005433434943	738A36	4720 054994	GEORGIY FEDOTOV	{"email": "gfedotov08071981@postgrespro.ru", "phone": "+70237048927"}
0005433434944	738A36	0444 691155	TATYANA OSIPOVA	{"email": "tatyana.osipova.1977@postgrespro.ru", "phone": "+70271419407"}
0005433434945	738A36	1455 468605	NATALYA FILIPPOVA	{"email": "natalya.filippova_031966@postgrespro.ru", "phone": "+70515290428"}
0005433434946	497613	9330 728287	VIKTOR FEDOTOV	{"phone": "+70402343691"}
0005433434947	C20F44	3144 285679	OLGA KARPOVA	{"email": "karpova-o1976@postgrespro.ru", "phone": "+70280085445"}
0005433434948	B74492	7653 693621	ILYA FROLOV	{"phone": "+70997682474"}
0005433434949	DC2452	9525 526196	ALEKSEY ZAKHAROV	{"email": "aleksey.zakharov.101968@postgrespro.ru", "phone": "+70245050079"}
0005433434950	3658C7	7292 152125	YURIY SAVELEV	{"phone": "+70152380248"}
0005433434951	CB5346	9418 973031	LILIYA ZAKHAROVA	{"phone": "+70479112193"}
0005433434952	CB5346	5565 893346	SVETLANA SMIRNOVA	{"phone": "+70519021833"}
0005433434953	CB5346	7686 588485	EVGENIY ZAYCEV	{"email": "zayceve_12081974@postgrespro.ru", "phone": "+70857022280"}
0005433434954	4E148D	1810 371863	VALENTINA MEDVEDEVA	{"phone": "+70812608537"}
0005433434955	4E148D	2692 510575	DARYA MELNIKOVA	{"email": "melnikova.darya_041974@postgrespro.ru", "phone": "+70741071355"}
0005433434956	94575D	3249 905110	ALEKSEY SEMENOV	{"email": "a.semenov-1967@postgrespro.ru", "phone": "+70833121525"}
0005433434957	94575D	7192 951890	SVETLANA ALEKSEEVA	{"phone": "+70684307275"}
0005433434958	82156F	1802 760498	RINAT GERASIMOV	{"email": "gerasimov_rinat30061971@postgrespro.ru", "phone": "+70777729016"}
0005433434959	B132D0	0249 431045	ELIZAVETA SERGEEVA	{"phone": "+70316464777"}
0005433434960	064E22	1410 361278	MAKSIM SCHERBAKOV	{"phone": "+70707711636"}
0005433434961	74F7CF	4896 855910	EVGENIY PETROV	{"phone": "+70074718882"}
0005433434962	99A837	9620 852128	PAVEL ZAYCEV	{"phone": "+70513053317"}
0005433434963	06F768	6270 818344	ALBINA MEDVEDEVA	{"email": "a.medvedeva-101971@postgrespro.ru", "phone": "+70688990095"}
0005433434964	06F768	2676 938958	ALINA IVANOVA	{"email": "ivanovaa041976@postgrespro.ru", "phone": "+70400016480"}
0005433434965	D73E45	7830 027363	LIDIYA MAKAROVA	{"phone": "+70400010270"}
0005433434966	3ED491	1710 922314	SERGEY EGOROV	{"phone": "+70722878736"}
0005433434967	486B35	1702 309896	NADEZHDA ZHUKOVA	{"phone": "+70939991464"}
0005433434968	C4D3E9	6139 995741	ALEKSANDRA ALEKSEEVA	{"phone": "+70216651555"}
0005433434969	C2C189	4256 846376	ALEKSANDR VLASOV	{"phone": "+70676929628"}
0005433434970	E54410	4300 385041	VASILIY YAKOVLEV	{"email": "vasiliyyakovlev-08121971@postgrespro.ru", "phone": "+70212049908"}
0005433434971	ABCC3D	7616 026450	ELMIRA DAVYDOVA	{"email": "elmira_davydova_1970@postgrespro.ru", "phone": "+70154737086"}
0005433434972	8279A0	6407 413900	ALEKSEY DENISOV	{"phone": "+70989054155"}
0005433434973	8279A0	1179 081265	ALEKSANDR FROLOV	{"phone": "+70613956005"}
0005433434974	8279A0	9639 476281	MAKSIM KONOVALOV	{"phone": "+70342608759"}
0005433434975	BB03D9	8173 832476	MARAT POPOV	{"email": "popovm-02031971@postgrespro.ru", "phone": "+70190488315"}
0005433434976	ACCE4F	8665 698521	LYUDMILA FEDOROVA	{"phone": "+70781709444"}
0005433434977	D66B12	7426 135319	STANISLAV SIDOROV	{"phone": "+70376048323"}
0005433434978	1EB9F2	1476 002669	YURIY KOROLEV	{"email": "yuriy.korolev_1971@postgrespro.ru", "phone": "+70185797403"}
0005433434979	1EB9F2	9900 523548	LYUDMILA KUZNECOVA	{"email": "kuznecova.lyudmila.121981@postgrespro.ru", "phone": "+70736855620"}
0005433434980	83776F	9602 672427	NATALYA KONOVALOVA	{"email": "n.konovalova-101975@postgrespro.ru", "phone": "+70529530284"}
0005433434981	83776F	4622 416483	GALINA VOLKOVA	{"email": "volkova.g09081974@postgrespro.ru", "phone": "+70423667734"}
0005433434982	83776F	4013 431187	RAISA ILINA	{"email": "r-ilina-1963@postgrespro.ru", "phone": "+70477212930"}
0005433434983	8B6DE7	2103 890034	SERGEY VASILEV	{"phone": "+70423138306"}
0005433434985	EEDFA9	4064 165063	LEV FROLOV	{"email": "frolov.lev101981@postgrespro.ru", "phone": "+70732076393"}
0005433434986	8A32D2	6621 018878	LYUDMILA ANDREEVA	{"phone": "+70262032805"}
0005433434987	DA1626	6101 207593	VYACHESLAV ILIN	{"email": "v-ilin_1973@postgrespro.ru", "phone": "+70379517835"}
0005433434988	EC94BB	5650 873847	YULIYA GERASIMOVA	{"email": "yuliyagerasimova_1979@postgrespro.ru", "phone": "+70671610241"}
0005433434989	EC94BB	2212 415017	NINA IVANOVA	{"email": "ivanova-nina021974@postgrespro.ru", "phone": "+70474594563"}
0005433434990	A14D4E	4225 476412	ALEKSANDR KONOVALOV	{"phone": "+70915718111"}
0005433434991	B4714B	4572 519483	NINA AKIMOVA	{"email": "akimova-n_14011961@postgrespro.ru", "phone": "+70259753349"}
0005433434992	B4714B	5398 984873	MARK SMIRNOV	{"email": "mark-smirnov_1975@postgrespro.ru", "phone": "+70378023148"}
0005433434993	A5639D	9010 984388	INNA POPOVA	{"email": "popova.inna-12121977@postgrespro.ru", "phone": "+70523374213"}
0005433434994	A5639D	6433 805003	ROMAN VASILEV	{"email": "rvasilev111975@postgrespro.ru", "phone": "+70265613711"}
0005433434995	553C77	7645 126531	DARYA GORBUNOVA	{"email": "gorbunova_darya.1980@postgrespro.ru", "phone": "+70227753225"}
0005433434996	553C77	4779 026124	SERGEY POPOV	{"phone": "+70381007541"}
0005433434997	58FED6	5301 765864	OLEG GUSEV	{"email": "oleg.gusev-31101976@postgrespro.ru", "phone": "+70336421851"}
0005433434998	58FED6	3168 269004	ILYA CHERNOV	{"email": "chernovilya_1965@postgrespro.ru", "phone": "+70357369501"}
0005433434999	B35A80	8199 050035	ANNA NESTEROVA	{"phone": "+70518529670"}
0005433435000	B35A80	6606 924436	IRINA GORBUNOVA	{"phone": "+70301500658"}
0005433435001	F71B0A	2928 347799	NINA DENISOVA	{"phone": "+70208762985"}
0005433435002	DEE335	7205 227326	VITALIY TIMOFEEV	{"email": "timofeevvitaliy-1978@postgrespro.ru", "phone": "+70878527344"}
0005433435003	8B40DE	3431 529947	ALEKSANDR MOISEEV	{"phone": "+70187855588"}
0005433435004	9CC5AB	0114 266055	SVETLANA VOLKOVA	{"email": "s-volkova-121969@postgrespro.ru", "phone": "+70235308017"}
0005433435005	33BF07	9014 819659	ANDREY DMITRIEV	{"email": "dmitriev_a-08061959@postgrespro.ru", "phone": "+70830372086"}
0005433435006	D3E8AD	5816 223376	ALEKSANDR VOLKOV	{"email": "a_volkov1974@postgrespro.ru", "phone": "+70233445690"}
0005433435007	47B784	8675 215037	ELENA POPOVA	{"email": "e_popova.1973@postgrespro.ru", "phone": "+70218228151"}
0005433435008	B349C9	5623 680158	TATYANA DANILOVA	{"phone": "+70092170773"}
0005433435009	B349C9	7594 000557	NATALYA MOROZOVA	{"phone": "+70606284876"}
0005433435010	9161E1	1756 154565	LYUDMILA KRASNOVA	{"phone": "+70887052635"}
0005433435290	57448B	2076 481815	VLADIMIR SIDOROV	{"phone": "+70703703346"}
0005433435011	0011A9	3615 625960	VITALIY SHEVCHENKO	{"email": "shevchenko-v_22101970@postgrespro.ru", "phone": "+70063304564"}
0005433435012	08FD92	8611 105076	INNA GAVRILOVA	{"phone": "+70674131529"}
0005433435013	3975E9	3634 758850	ALINA KOVALEVA	{"phone": "+70619820885"}
0005433435014	743DCC	7773 786643	ALEKSEY KUZNECOV	{"phone": "+70838430733"}
0005433435015	198CB3	8659 549630	SVETLANA ILINA	{"phone": "+70683779454"}
0005433435016	986FD6	2344 258610	DMITRIY GAVRILOV	{"phone": "+70892262011"}
0005433435017	AD9D54	0444 940144	VIKTOR PAVLOV	{"phone": "+70572268926"}
0005433435018	FA62F2	4205 951151	LILIYA ALEKSANDROVA	{"phone": "+70836070875"}
0005433435019	FA62F2	7180 477092	DARYA MAKSIMOVA	{"phone": "+70522436274"}
0005433435020	FA62F2	8609 226567	NINA FEDOROVA	{"email": "fedorova.n_011975@postgrespro.ru", "phone": "+70180287540"}
0005433435021	469F8A	7332 340654	ARSENIY ZAYCEV	{"email": "zaycev-a061968@postgrespro.ru", "phone": "+70070737171"}
0005433435022	851F8D	0435 971428	VERA TITOVA	{"phone": "+70114840934"}
0005433435023	851F8D	0364 281164	NATALYA IVANOVA	{"phone": "+70754839403"}
0005433435024	1A8C4E	0746 106882	MIKHAIL FOMIN	{"email": "fomin_m_1975@postgrespro.ru", "phone": "+70760183963"}
0005433435025	4BEC7D	0787 267411	MIKHAIL MOROZOV	{"phone": "+70091234529"}
0005433435026	4BEC7D	6630 499931	TATYANA DANILOVA	{"email": "danilova.t-04031978@postgrespro.ru", "phone": "+70318453179"}
0005433435027	4BEC7D	0397 253017	ALEKSANDR NIKITIN	{"phone": "+70546589635"}
0005433435028	C01A91	5160 339788	EVDOKIYA TIKHONOVA	{"email": "evdokiya.tikhonova1967@postgrespro.ru", "phone": "+70034542133"}
0005433435029	5B7F7D	5759 793555	ANDREY MOROZOV	{"phone": "+70938721636"}
0005433435030	5B7F7D	9269 299386	GENNADIY MIKHAYLOV	{"phone": "+70273784707"}
0005433435031	802EE0	3331 545305	SERGEY SMIRNOV	{"phone": "+70295852229"}
0005433435032	802EE0	8450 347617	ANTONINA IVANOVA	{"email": "ivanova_antonina1973@postgrespro.ru", "phone": "+70771529398"}
0005433435033	9ABD1E	1528 461577	NATALYA NIKOLAEVA	{"phone": "+70561433351"}
0005433435034	9ABD1E	8682 680231	LYUDMILA SERGEEVA	{"email": "l.sergeeva-19051971@postgrespro.ru", "phone": "+70706278398"}
0005433435035	DFE2EE	9508 800265	MARIANNA LUKYANOVA	{"email": "lukyanovamarianna1973@postgrespro.ru", "phone": "+70981257968"}
0005433435036	FDC56B	8532 470528	GENNADIY AFANASEV	{"email": "g-afanasev-1975@postgrespro.ru", "phone": "+70609247267"}
0005433435037	FD8158	4046 806641	SERGEY GUSEV	{"email": "sergeygusev-051973@postgrespro.ru", "phone": "+70858253100"}
0005433435038	35B58C	2951 728851	IGOR DAVYDOV	{"email": "igordavydov-23031970@postgrespro.ru", "phone": "+70879160555"}
0005433435039	35B58C	0610 934970	ROZA ZHURAVLEVA	{"phone": "+70539092520"}
0005433435040	74F3E7	4228 253906	VASILIY ABRAMOV	{"phone": "+70606290851"}
0005433435041	EAB50B	5378 140091	NIKOLAY NIKITIN	{"email": "n-nikitin-061958@postgrespro.ru", "phone": "+70427125913"}
0005433435042	EAB50B	1399 602270	ARTEM SCHERBAKOV	{"phone": "+70740953754"}
0005433435043	E6B57E	3360 441144	POLINA ALEKSANDROVA	{"phone": "+70925633467"}
0005433435044	D925A2	2847 136000	VALENTINA IVANOVA	{"phone": "+70871226212"}
0005433435407	C1064B	9174 342394	ARTEM IVANOV	{"phone": "+70583225554"}
0005433435045	17CD07	4560 525280	GALINA AFANASEVA	{"email": "galina.afanaseva061962@postgrespro.ru", "phone": "+70089575092"}
0005433435046	7C47CC	6359 583160	IRINA MATVEEVA	{"phone": "+70546603104"}
0005433435047	324385	7844 762881	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov-1978@postgrespro.ru", "phone": "+70284332402"}
0005433435048	F02732	8893 882690	ALEKSEY TIKHONOV	{"phone": "+70220293646"}
0005433435049	F02732	1324 637755	ELENA PAVLOVA	{"email": "e_pavlova091969@postgrespro.ru", "phone": "+70205304187"}
0005433435050	438D3E	5572 470050	ZINAIDA ISAEVA	{"email": "z_isaeva1970@postgrespro.ru", "phone": "+70905045711"}
0005433435051	B3E3B3	7317 863137	GENNADIY GERASIMOV	{"email": "gerasimov-gennadiy_071977@postgrespro.ru", "phone": "+70734164081"}
0005433435052	B3E3B3	9339 363724	SERGEY BELOV	{"email": "sergey_belov-1961@postgrespro.ru", "phone": "+70134420048"}
0005433435053	93C9AF	6756 219567	DMITRIY PAVLOV	{"email": "pavlov-d-11061958@postgrespro.ru", "phone": "+70163441865"}
0005433435054	9F4C02	8728 357445	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr_1970@postgrespro.ru", "phone": "+70421060862"}
0005433435055	A8E8DF	7317 755507	YULIYA VOROBEVA	{"phone": "+70075390517"}
0005433435056	BDA9CB	6696 077672	ALEKSANDR ZHURAVLEV	{"email": "azhuravlev101969@postgrespro.ru", "phone": "+70113193417"}
0005433435057	BDA9CB	3333 295071	ALEKSANDR NOVIKOV	{"phone": "+70025744575"}
0005433435058	3DB161	3200 965753	NINA KOVALEVA	{"phone": "+70245752390"}
0005433435059	3DB161	6626 560207	RUSLAN KOROLEV	{"phone": "+70162138617"}
0005433435060	A88301	9467 273122	LYUBOV KISELEVA	{"email": "kiseleva-lyubov.1973@postgrespro.ru", "phone": "+70933915461"}
0005433435061	F98EF2	6774 465452	ANNA SOROKINA	{"email": "sorokinaa071977@postgrespro.ru", "phone": "+70589555515"}
0005433435062	1E524F	2116 505158	NINA EGOROVA	{"email": "nina.egorova.1975@postgrespro.ru", "phone": "+70055263332"}
0005433435063	1E524F	4509 403270	DENIS KUZNECOV	{"phone": "+70205372888"}
0005433435064	7B4283	9421 714407	SERGEY NAUMOV	{"email": "naumov-s-081969@postgrespro.ru", "phone": "+70656388294"}
0005433435065	7B4283	3663 492919	ANDREY KONOVALOV	{"email": "a.konovalov.1983@postgrespro.ru", "phone": "+70917640885"}
0005433435066	EAE4CD	7864 843687	ALINA OVCHINNIKOVA	{"email": "ovchinnikovaa_30071979@postgrespro.ru", "phone": "+70740746746"}
0005433435067	13C2BB	0516 183026	ELENA MELNIKOVA	{"email": "melnikova-e_041975@postgrespro.ru", "phone": "+70162753898"}
0005433435068	13C2BB	1927 582780	ALEKSEY BONDARENKO	{"email": "bondarenko_a_06121967@postgrespro.ru", "phone": "+70794394803"}
0005433435069	9F890A	3264 298051	KSENIYA LUKYANOVA	{"phone": "+70702321438"}
0005433435070	91B85A	8881 392937	OLGA BELYAEVA	{"email": "belyaeva-o.1964@postgrespro.ru", "phone": "+70959507128"}
0005433435071	B4134A	3947 134156	MARIYA LEBEDEVA	{"email": "m_lebedeva_1981@postgrespro.ru", "phone": "+70990064767"}
0005433435072	6BB39C	2436 873633	ALEKSANDR MAKSIMOV	{"phone": "+70988747306"}
0005433435073	6BB39C	5500 388445	ANDREY KUZNECOV	{"phone": "+70376223443"}
0005433435074	23255F	9739 928704	NATALIYA YAKOVLEVA	{"phone": "+70917858278"}
0005433435075	96AEBA	3919 396270	ANATOLIY SIDOROV	{"email": "sidorov-a_081963@postgrespro.ru", "phone": "+70153790196"}
0005433435076	12B2F6	7477 376726	DANIIL MIRONOV	{"phone": "+70178690933"}
0005433435077	12B2F6	1285 335825	VIKTORIYA MOROZOVA	{"email": "v-morozova-061961@postgrespro.ru", "phone": "+70810727316"}
0005433435078	E376AB	0171 339638	VLADIMIR POPOV	{"email": "popov_v_081968@postgrespro.ru", "phone": "+70977344057"}
0005433435079	E376AB	9550 239375	IGOR FEDOROV	{"email": "igor-fedorov.07071973@postgrespro.ru", "phone": "+70014472929"}
0005433435080	348536	3718 666430	TATYANA KALININA	{"email": "t_kalinina_15051978@postgrespro.ru", "phone": "+70750021391"}
0005433435081	348536	1576 903665	NINA KUZMINA	{"email": "kuzmina_n121973@postgrespro.ru", "phone": "+70944863369"}
0005433435082	3D9B42	8873 122244	SERGEY PETROV	{"email": "s-petrov1966@postgrespro.ru", "phone": "+70756362322"}
0005433435083	87831A	0681 649008	VALENTIN ROMANOV	{"email": "romanov.valentin-031982@postgrespro.ru", "phone": "+70490599147"}
0005433435084	87831A	7976 049332	YULIYA NIKITINA	{"phone": "+70742620342"}
0005433435085	87831A	1958 307609	VLADIMIR BARANOV	{"phone": "+70725498485"}
0005433435086	CC5857	9765 783199	NINA ANDREEVA	{"email": "n_andreeva.01041972@postgrespro.ru", "phone": "+70550409171"}
0005433435087	9CFB8C	5227 076815	NIKITA NIKOLAEV	{"phone": "+70998212200"}
0005433435088	40787E	7478 399915	RUSLAN ZAYCEV	{"email": "ruslan_zaycev1960@postgrespro.ru", "phone": "+70238040960"}
0005433435089	40787E	3472 956718	ALEKSEY IVANOV	{"email": "ivanov-aleksey04041972@postgrespro.ru", "phone": "+70268991732"}
0005433435090	40787E	0922 907232	DMITRIY ROMANOV	{"email": "romanov-d_22111963@postgrespro.ru", "phone": "+70958703204"}
0005433435091	4058E0	4025 439905	DMITRIY MAKSIMOV	{"email": "maksimovd-1972@postgrespro.ru", "phone": "+70497295674"}
0005433435092	4058E0	0182 258298	ILGIZ MEDVEDEV	{"email": "medvedevilgiz031973@postgrespro.ru", "phone": "+70169688154"}
0005433435093	A841A4	2609 484208	IGOR ZAYCEV	{"email": "igor.zaycev-13081970@postgrespro.ru", "phone": "+70088087206"}
0005433435094	A841A4	4774 933308	ARTUR SOROKIN	{"phone": "+70912356740"}
0005433435095	EBF93A	2040 944753	OLGA ORLOVA	{"phone": "+70166534473"}
0005433435096	EBF93A	2213 452257	KAMIL NIKOLAEV	{"email": "nikolaevk-1979@postgrespro.ru", "phone": "+70952551262"}
0005433435097	FA4D29	2863 226963	ANNA GAVRILOVA	{"phone": "+70494683499"}
0005433435098	DD35E0	0907 281751	ALLA KUDRYASHOVA	{"phone": "+70028377360"}
0005433435099	E4EB0A	1123 897448	EKATERINA SOLOVEVA	{"phone": "+70879421769"}
0005433435100	E43C04	2484 997020	YULIYA VOLKOVA	{"phone": "+70718807547"}
0005433435101	E43C04	9958 557448	VALENTINA GRISHINA	{"phone": "+70467751250"}
0005433435102	0D1FB4	1793 280471	DMITRIY GUSEV	{"email": "dmitriy-gusev.1980@postgrespro.ru", "phone": "+70547148747"}
0005433435408	C1064B	6839 220502	NIKOLAY DENISOV	{"phone": "+70353821945"}
0005433435103	9B99E4	9561 605222	RAISA MOISEEVA	{"email": "r.moiseeva.051986@postgrespro.ru", "phone": "+70445253742"}
0005433435104	9B99E4	0813 283152	OLEG EGOROV	{"phone": "+70465224219"}
0005433435105	57D88F	9750 295173	DMITRIY ZAYCEV	{"phone": "+70768464276"}
0005433435106	57D88F	4867 471211	ROMAN ZAKHAROV	{"phone": "+70328374301"}
0005433435107	E58D22	9726 722415	LYUDMILA ROMANOVA	{"email": "romanova_lyudmila.111956@postgrespro.ru", "phone": "+70766232556"}
0005433435108	E58D22	3893 718375	EVA ANISIMOVA	{"phone": "+70186079920"}
0005433435109	1C5230	7345 767082	ALEKSEY SIDOROV	{"phone": "+70524538457"}
0005433435110	1C5230	8953 685784	TATYANA PAVLOVA	{"phone": "+70155244886"}
0005433435111	ABAFFA	9705 002317	VLADIMIR GAVRILOV	{"email": "v.gavrilov_1971@postgrespro.ru", "phone": "+70211936447"}
0005433435112	C222A8	0778 706368	ANDREY SMIRNOV	{"email": "smirnov_andrey_061976@postgrespro.ru", "phone": "+70452011292"}
0005433435113	63E456	1228 951377	OLGA POLYAKOVA	{"phone": "+70538328402"}
0005433435114	046BE0	2523 304807	ELENA STEPANOVA	{"phone": "+70628279061"}
0005433435115	402511	1502 386188	NIKOLAY KULIKOV	{"email": "kulikovnikolay_051979@postgrespro.ru", "phone": "+70843795479"}
0005433435116	8D7DBC	5888 901725	SERGEY SOROKIN	{"email": "sorokins_1971@postgrespro.ru", "phone": "+70535848510"}
0005433435117	8D7DBC	9986 681773	MARIYA NOVIKOVA	{"phone": "+70534305089"}
0005433435118	7523C0	9412 363160	VASILIY TARASOV	{"email": "vasiliytarasov081980@postgrespro.ru", "phone": "+70679804237"}
0005433435119	EBA53B	7702 368448	VIKTORIYA SEMENOVA	{"email": "viktoriya_semenova_16101961@postgrespro.ru", "phone": "+70158083332"}
0005433435120	D4BE18	3194 276283	MIKHAIL FILIPPOV	{"email": "mfilippov.081971@postgrespro.ru", "phone": "+70331270470"}
0005433435121	58C6A3	4373 627378	ANNA FEDOROVA	{"email": "a.fedorova.06031983@postgrespro.ru", "phone": "+70856700006"}
0005433435122	86DCDF	9505 216193	NATALYA ANDREEVA	{"email": "natalya-andreeva.021987@postgrespro.ru", "phone": "+70795590530"}
0005433435123	368F02	6321 073614	OLESYA POTAPOVA	{"email": "opotapova.22011975@postgrespro.ru", "phone": "+70775166268"}
0005433435124	368F02	2111 952943	SERGEY IVANOV	{"phone": "+70347977173"}
0005433435125	1610F5	2270 144298	ANDREY BELOV	{"phone": "+70626828369"}
0005433435126	1610F5	8714 299062	KLAVDIYA KUZNECOVA	{"email": "kuznecovaklavdiya-1967@postgrespro.ru", "phone": "+70318424432"}
0005433435127	B03F56	9416 486755	IRINA GAVRILOVA	{"email": "irina.gavrilova031970@postgrespro.ru", "phone": "+70801257041"}
0005433435128	C686CF	0992 915190	DMITRIY TIMOFEEV	{"phone": "+70835538843"}
0005433435129	C686CF	5154 969805	MIKHAIL VOLKOV	{"email": "volkov-m061970@postgrespro.ru", "phone": "+70737742798"}
0005433435130	42BB60	2348 812469	MARIYA EFIMOVA	{"email": "efimova_m101985@postgrespro.ru", "phone": "+70273616358"}
0005433435131	B2B08C	4786 189290	DMITRIY SOROKIN	{"email": "sorokin_d-12091977@postgrespro.ru", "phone": "+70741331176"}
0005433435132	20C092	1667 311480	DMITRIY POPOV	{"email": "dmitriypopov1963@postgrespro.ru", "phone": "+70666129644"}
0005433435133	723EB8	9586 485723	LIDIYA ANDREEVA	{"phone": "+70527843646"}
0005433435134	5A31A2	2942 382194	VADIM SMIRNOV	{"email": "vadim.smirnov26061973@postgrespro.ru", "phone": "+70479782035"}
0005433435135	9F4A0E	1893 931140	MARIYA MAKAROVA	{"email": "makarova_mariya.14111971@postgrespro.ru", "phone": "+70169901888"}
0005433435136	88F7C2	6627 977870	KIRA NIKITINA	{"email": "kiranikitina_031976@postgrespro.ru", "phone": "+70685079308"}
0005433435137	88F7C2	6810 106315	IRINA ROMANOVA	{"phone": "+70918151852"}
0005433435138	2C7944	6503 260243	ILYA ORLOV	{"email": "iorlov10031967@postgrespro.ru", "phone": "+70244118987"}
0005433435139	BBC404	6580 787000	PAVEL SERGEEV	{"email": "pavelsergeev.1967@postgrespro.ru", "phone": "+70757957178"}
0005433435140	BBC404	8295 631037	NIKOLAY ANTONOV	{"email": "nikolayantonov.1967@postgrespro.ru", "phone": "+70988921995"}
0005433435141	BBC404	1320 493485	OLGA FOMINA	{"email": "fominao1959@postgrespro.ru", "phone": "+70835785168"}
0005433435142	41B940	3949 344016	NATALYA ANTONOVA	{"email": "antonovan-041957@postgrespro.ru", "phone": "+70517508555"}
0005433435143	3A0F21	0652 360541	ANDREY SOKOLOV	{"email": "asokolov_28061977@postgrespro.ru", "phone": "+70224146376"}
0005433435144	3A0F21	9011 540775	ALEKSEY MEDVEDEV	{"phone": "+70142340980"}
0005433435145	972354	3936 918593	GALINA FROLOVA	{"phone": "+70029420417"}
0005433435146	972354	4493 594562	ALEKSANDR SOROKIN	{"phone": "+70843764888"}
0005433435147	9A093D	1712 308446	ELENA KUZNECOVA	{"email": "kuznecova.e-071974@postgrespro.ru", "phone": "+70400254541"}
0005433435148	58E945	0341 621545	NATALYA MAKAROVA	{"email": "n.makarova10111986@postgrespro.ru", "phone": "+70686602544"}
0005433435149	9F95C1	1325 386085	VALERIYA ZOTOVA	{"phone": "+70215234867"}
0005433435150	9F95C1	0459 810170	LYUBOV EFIMOVA	{"email": "efimova.l1972@postgrespro.ru", "phone": "+70647393206"}
0005433435151	20884F	7275 920692	VLADIMIR SOROKIN	{"phone": "+70646270407"}
0005433435152	E5479D	6570 522111	TATYANA NAZAROVA	{"email": "tatyana_nazarova-01061967@postgrespro.ru", "phone": "+70096659103"}
0005433435153	F8DFEF	0101 689711	ANDREY VOROBEV	{"email": "vorobev-andrey20031979@postgrespro.ru", "phone": "+70181741769"}
0005433435154	F8DFEF	2679 903906	ANASTASIYA SMIRNOVA	{"email": "smirnovaanastasiya-041981@postgrespro.ru", "phone": "+70880520832"}
0005433435155	5EB903	6531 649136	TATYANA DAVYDOVA	{"phone": "+70631511855"}
0005433435156	5EB903	3137 728889	VIKTORIYA STEPANOVA	{"email": "stepanova_viktoriya-071971@postgrespro.ru", "phone": "+70500817762"}
0005433435157	F89972	0649 516456	ELENA NESTEROVA	{"phone": "+70111634017"}
0005433435158	232C04	0909 375085	RAISA SEMENOVA	{"email": "raisa_semenova-18021975@postgrespro.ru", "phone": "+70116675231"}
0005433435159	232C04	2217 925255	TATYANA FILIPPOVA	{"phone": "+70742788355"}
0005433435160	1AFF67	7169 725868	NINA MELNIKOVA	{"email": "n.melnikova_27021962@postgrespro.ru", "phone": "+70440077921"}
0005433435162	2DF517	1153 221508	EVGENIY STEPANOV	{"email": "evgeniy-stepanov1969@postgrespro.ru", "phone": "+70668689521"}
0005433435163	2DF517	6547 883895	MARGARITA KUZNECOVA	{"email": "m-kuznecova_121970@postgrespro.ru", "phone": "+70442083177"}
0005433435164	44E90C	0561 013074	ANATOLIY ZAKHAROV	{"phone": "+70695066179"}
0005433435165	401697	7619 853455	DANIL ZHUKOV	{"phone": "+70962588416"}
0005433435166	401697	5365 787821	NINA SEMENOVA	{"email": "nina_semenova-1972@postgrespro.ru", "phone": "+70617371782"}
0005433435167	08C373	1804 655021	IGOR FEDOTOV	{"email": "fedotov-igor031965@postgrespro.ru", "phone": "+70122727914"}
0005433435168	08C373	7996 121094	SERGEY SCHERBAKOV	{"phone": "+70584330651"}
0005433435169	38D4B4	5473 195424	DMITRIY CHERNOV	{"phone": "+70528890259"}
0005433435170	FC20D5	6029 394933	VALENTINA IVANOVA	{"email": "ivanova-v-10011966@postgrespro.ru", "phone": "+70810374959"}
0005433435171	B6CE31	5370 106474	DMITRIY POPOV	{"email": "d.popov1975@postgrespro.ru", "phone": "+70624783013"}
0005433435172	C6CC91	1815 501056	TAGIR RODIONOV	{"phone": "+70330976442"}
0005433435173	C6CC91	7014 009243	DANIIL ALEKSANDROV	{"phone": "+70530213464"}
0005433435174	C20821	7246 759584	MIKHAIL GERASIMOV	{"email": "gerasimov.mikhail11031976@postgrespro.ru", "phone": "+70626849806"}
0005433435175	27E799	0584 923669	ANDREY NOVIKOV	{"phone": "+70021051224"}
0005433435176	3A6421	4734 772788	OLGA DMITRIEVA	{"phone": "+70786460589"}
0005433435177	C292C3	8643 119467	ANATOLIY KOROLEV	{"email": "anatoliy-korolev_061978@postgrespro.ru", "phone": "+70456258575"}
0005433435178	C292C3	0411 324279	VALENTINA BARANOVA	{"email": "baranova-v101978@postgrespro.ru", "phone": "+70869867147"}
0005433435179	FAEABC	1581 454872	VALENTIN SOLOVEV	{"email": "v.solovev14031976@postgrespro.ru", "phone": "+70509718945"}
0005433435180	9A21EB	4079 554233	ROMAN BARANOV	{"email": "roman_baranov.1967@postgrespro.ru", "phone": "+70772262931"}
0005433435181	B1738B	5369 431806	KLAVDIYA MIRONOVA	{"phone": "+70520100873"}
0005433435182	B1738B	6316 741215	YULIYA PAVLOVA	{"email": "yuliya-pavlova1973@postgrespro.ru", "phone": "+70514696959"}
0005433435183	F100A3	6244 487542	OLEG SOKOLOV	{"phone": "+70993975549"}
0005433435184	F100A3	1083 030590	TATYANA YUDINA	{"email": "yudina-t07011972@postgrespro.ru", "phone": "+70701426574"}
0005433435185	996763	4037 964127	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr-071975@postgrespro.ru", "phone": "+70307251670"}
0005433435186	DC374D	4573 808943	ANNA GORBUNOVA	{"phone": "+70286276108"}
0005433435187	DC374D	5356 367897	ALEKSANDR GRIGOREV	{"phone": "+70640250418"}
0005433435188	F2E8CE	2456 008621	NINA VASILEVA	{"phone": "+70859044808"}
0005433435189	2E4B97	2354 110273	ANATOLIY YAKOVLEV	{"email": "yakovlev-anatoliy-1968@postgrespro.ru", "phone": "+70528556451"}
0005433435190	247B44	8728 031301	ALEKSEY ANTONOV	{"phone": "+70150314434"}
0005433435191	247B44	6468 463632	PETR GAVRILOV	{"email": "gavrilov_petr18071990@postgrespro.ru", "phone": "+70030467109"}
0005433435192	6B9012	8028 573429	ANTONINA MAKAROVA	{"email": "makarovaantonina.1967@postgrespro.ru", "phone": "+70834948741"}
0005433435193	88F9C6	0665 935358	MAYA KONDRATEVA	{"phone": "+70280405712"}
0005433435194	83AB64	3077 412905	LIDIYA SEMENOVA	{"phone": "+70942839927"}
0005433435195	83AB64	5548 427530	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr.1964@postgrespro.ru", "phone": "+70192160278"}
0005433435196	F809A6	0196 291405	DENIS ROMANOV	{"phone": "+70088951627"}
0005433435197	D5824B	8989 995840	KLAVDIYA MIKHAYLOVA	{"phone": "+70993221658"}
0005433435198	503F10	1607 016671	PAVEL FEDOROV	{"phone": "+70845947593"}
0005433435199	503F10	3652 200821	PAVEL MELNIKOV	{"phone": "+70183762626"}
0005433435200	503F10	4677 452390	YAROSLAV SHEVCHENKO	{"phone": "+70550648463"}
0005433435201	9BFA05	1852 998700	ELENA BOGDANOVA	{"email": "ebogdanova-1981@postgrespro.ru", "phone": "+70040354831"}
0005433435202	BB8C44	8729 144733	EDUARD PAVLOV	{"email": "e-pavlov.07021972@postgrespro.ru", "phone": "+70999757650"}
0005433435203	6F0BD5	1626 080462	DMITRIY ZHURAVLEV	{"email": "d-zhuravlev.1973@postgrespro.ru", "phone": "+70896531535"}
0005433435204	C54201	3814 250193	ALISHER OSIPOV	{"email": "osipov.alisher-1967@postgrespro.ru", "phone": "+70370079683"}
0005433435205	81C827	8684 960387	ANDREY KOZLOV	{"phone": "+70307286884"}
0005433435206	B5A26E	2478 300585	ALEKSEY VOROBEV	{"email": "aleksey_vorobev.14091976@postgrespro.ru", "phone": "+70892576128"}
0005433435207	32889A	2326 188421	ALEKSANDRA FOMINA	{"email": "a.fomina_101971@postgrespro.ru", "phone": "+70536984366"}
0005433435208	136DBB	3805 811403	ALEKSANDR ALEKSANDROV	{"email": "aaleksandrov18111970@postgrespro.ru", "phone": "+70171544664"}
0005433435209	C491C3	8615 991946	MARINA STEPANOVA	{"email": "m_stepanova_011979@postgrespro.ru", "phone": "+70725650439"}
0005433435210	C491C3	5444 254936	DMITRIY TARASOV	{"phone": "+70878035964"}
0005433435211	37CFD5	1128 109953	NATALYA IVANOVA	{"email": "nivanova.061970@postgrespro.ru", "phone": "+70087660457"}
0005433435212	37CFD5	3051 218081	ALEKSEY ZAKHAROV	{"phone": "+70424320107"}
0005433435213	67C20B	6648 789099	ARTEM TIKHONOV	{"email": "tikhonova20101973@postgrespro.ru", "phone": "+70471942820"}
0005433435214	67C20B	1898 461231	VIKTOR FOMIN	{"email": "viktor.fomin29081971@postgrespro.ru", "phone": "+70647449165"}
0005433435215	5BBF82	4456 207740	OLGA SCHERBAKOVA	{"email": "scherbakova_olga30041966@postgrespro.ru", "phone": "+70543001911"}
0005433435216	5BBF82	2203 505932	VALENTINA OSIPOVA	{"email": "osipovav09011977@postgrespro.ru", "phone": "+70314034662"}
0005433435217	BA52ED	6726 543109	RAMIL DAVYDOV	{"email": "davydov.r.081976@postgrespro.ru", "phone": "+70095910643"}
0005433435218	BA52ED	8207 779448	YULIYA KAZAKOVA	{"phone": "+70556884404"}
0005433435219	6771C7	6085 392187	MIKHAIL SCHERBAKOV	{"email": "m-scherbakov1971@postgrespro.ru", "phone": "+70542878577"}
0005433435220	677D51	9825 214621	ALLA ALEKSEEVA	{"phone": "+70791769771"}
0005433435221	8D71C6	1559 042782	SERGEY VOLKOV	{"email": "volkov_s.111964@postgrespro.ru", "phone": "+70985772100"}
0005433435222	E2B16D	8031 838180	ANZHELA KRASNOVA	{"email": "anzhelakrasnova.1965@postgrespro.ru", "phone": "+70700272455"}
0005433435223	C4ECF7	5092 762279	EVGENIY KUZNECOV	{"phone": "+70605332803"}
0005433435224	689094	6929 145561	POLINA IVANOVA	{"email": "p_ivanova-1970@postgrespro.ru", "phone": "+70851532911"}
0005433435225	967CC2	8049 056319	GALINA MOROZOVA	{"email": "morozova-galina-16021966@postgrespro.ru", "phone": "+70176701718"}
0005433435226	155173	1803 309961	ANDREY FEDOTOV	{"email": "fedotov-a.031978@postgrespro.ru", "phone": "+70614157010"}
0005433435227	723458	2356 250359	IVAN SERGEEV	{"email": "sergeev.ivan_1985@postgrespro.ru", "phone": "+70445848684"}
0005433435228	035D0A	5079 319799	LYUBOV BELYAEVA	{"email": "belyaeva-lyubov.11081970@postgrespro.ru", "phone": "+70139767644"}
0005433435229	035D0A	5697 011308	NATALYA IVANOVA	{"email": "ivanova_n-1971@postgrespro.ru", "phone": "+70772403570"}
0005433435230	B3E2EE	9747 589463	SERGEY GORBUNOV	{"email": "sergey-gorbunov11091966@postgrespro.ru", "phone": "+70868794119"}
0005433435231	C366CC	7193 681085	YURIY GAVRILOV	{"phone": "+70206932560"}
0005433435232	C366CC	1804 635035	MARIYA LEBEDEVA	{"email": "lebedeva.mariya091983@postgrespro.ru", "phone": "+70059054760"}
0005433435234	FFF595	2295 627381	VALERIY ZAKHAROV	{"email": "v-zakharov1957@postgrespro.ru", "phone": "+70177679689"}
0005433435235	CA4669	2239 678931	ANDREY ZAYCEV	{"email": "zaycevandrey1963@postgrespro.ru", "phone": "+70915393819"}
0005433435236	FF4C36	9389 233131	STANISLAV KONOVALOV	{"phone": "+70955403049"}
0005433435237	045AF2	3522 011352	ANGELINA NIKOLAEVA	{"phone": "+70789860237"}
0005433435238	FDD4D5	6256 483799	ALEKSANDR FOMIN	{"phone": "+70454681527"}
0005433435239	F1EAC2	9824 746328	DAVID DENISOV	{"phone": "+70809847534"}
0005433435240	F1EAC2	0640 608532	ANASTASIYA EFIMOVA	{"phone": "+70251949416"}
0005433435241	91BA37	8304 410976	IGOR MIRONOV	{"email": "igormironov.041966@postgrespro.ru", "phone": "+70787694549"}
0005433435242	91BA37	8591 528188	AYRAT MAKAROV	{"email": "makarov-ayrat18081972@postgrespro.ru", "phone": "+70081756331"}
0005433435243	1ADB43	8131 965525	ANDREY SOLOVEV	{"email": "solovev-a23121980@postgrespro.ru", "phone": "+70133721021"}
0005433435244	787C48	7849 176601	VIKTOR KOZLOV	{"email": "v.kozlov.10061960@postgrespro.ru", "phone": "+70782744450"}
0005433435245	E6A97C	1064 787945	ELVINA MAKSIMOVA	{"email": "emaksimova.041969@postgrespro.ru", "phone": "+70766378097"}
0005433435246	E6A97C	2391 320812	FARID IVANOV	{"email": "ivanov-farid.20111974@postgrespro.ru", "phone": "+70537969993"}
0005433435247	DEA876	2000 312469	RINAT SERGEEV	{"phone": "+70208250239"}
0005433435248	DE8700	1541 189555	ALEKSANDR KUZMIN	{"phone": "+70439144007"}
0005433435249	DE8700	1998 277638	SVETLANA PAVLOVA	{"phone": "+70886213653"}
0005433435250	3B1166	5635 124297	IGOR GAVRILOV	{"email": "gavrilov.igor_30061976@postgrespro.ru", "phone": "+70515234395"}
0005433435251	3B1166	0106 054355	GALINA SERGEEVA	{"phone": "+70003476396"}
0005433435252	9DE67A	1512 510583	VERA EGOROVA	{"phone": "+70259825150"}
0005433435253	DC031A	1477 367206	EVGENIY SEMENOV	{"phone": "+70273358254"}
0005433435254	DC031A	2115 649231	NARIMAN TIKHONOV	{"email": "nariman.tikhonov1978@postgrespro.ru", "phone": "+70710474429"}
0005433435255	77217D	4868 475936	YURIY KUZNECOV	{"email": "kuznecov-y-08121968@postgrespro.ru", "phone": "+70701055292"}
0005433435256	3618B4	5563 195502	TIMUR SOROKIN	{"phone": "+70987673222"}
0005433435257	08FB2E	8366 036921	TAMARA ZAYCEVA	{"email": "tamara.zayceva.06101976@postgrespro.ru", "phone": "+70402757020"}
0005433435258	08FB2E	4390 788706	ALEKSANDR KUZNECOV	{"email": "a.kuznecov.041971@postgrespro.ru", "phone": "+70143915779"}
0005433435259	0DDD80	0953 964933	OLGA KOROLEVA	{"phone": "+70096263163"}
0005433435260	83B5A6	5995 330290	ANTON GERASIMOV	{"phone": "+70893099227"}
0005433435261	83B5A6	8004 615343	SERGEY PETROV	{"email": "petrovs.1969@postgrespro.ru", "phone": "+70552812843"}
0005433435262	5DE5F9	8495 445243	NADEZHDA YAKOVLEVA	{"email": "nadezhda-yakovleva-1963@postgrespro.ru", "phone": "+70340303635"}
0005433435263	F2225A	6052 076826	VALENTINA LUKYANOVA	{"phone": "+70039004371"}
0005433435264	51AA0F	7403 502965	GULNARA MATVEEVA	{"phone": "+70980784067"}
0005433435265	38CFBA	3904 342859	SERGEY CHERNOV	{"email": "chernov_s_121969@postgrespro.ru", "phone": "+70181830114"}
0005433435266	4885FC	1373 463518	KSENIYA RYABOVA	{"phone": "+70103466033"}
0005433435267	4885FC	3027 762010	EVGENIYA KUZNECOVA	{"email": "evgeniya-kuznecova-21121975@postgrespro.ru", "phone": "+70899579171"}
0005433435268	2BBCBA	9476 012520	OLGA IVANOVA	{"phone": "+70594081003"}
0005433435269	65513E	6826 727561	RAFAEL EGOROV	{"phone": "+70769813017"}
0005433435270	73DBB6	9173 272342	YULIYA YAKOVLEVA	{"phone": "+70246851607"}
0005433435271	570EBD	1921 481870	NATALIYA LAZAREVA	{"phone": "+70367469809"}
0005433435272	A7F9B0	0781 480517	ELENA AKIMOVA	{"email": "akimova-elena-26121963@postgrespro.ru", "phone": "+70796798865"}
0005433435273	A7F9B0	1880 109847	YULIYA KUZNECOVA	{"phone": "+70761274513"}
0005433435274	9BE7FF	0189 721988	LYUDMILA KUZNECOVA	{"email": "kuznecova.lyudmila081972@postgrespro.ru", "phone": "+70719018032"}
0005433435275	BD9079	6546 247988	SERGEY IVANOV	{"phone": "+70242997625"}
0005433435276	237020	5900 122388	VLADIMIR BONDARENKO	{"email": "bondarenko_v-111982@postgrespro.ru", "phone": "+70091663617"}
0005433435277	19201A	4280 005181	TATYANA VASILEVA	{"phone": "+70078455375"}
0005433435278	19201A	5061 467238	YAROSLAV SOKOLOV	{"email": "sokolov_yaroslav-121965@postgrespro.ru", "phone": "+70666643246"}
0005433435279	0583DF	9985 155848	ALEKSANDR KULIKOV	{"phone": "+70074519766"}
0005433435280	773841	4900 913182	VERA SOLOVEVA	{"email": "soloveva.v_1985@postgrespro.ru", "phone": "+70927117792"}
0005433435281	CFC4C7	8612 412028	TAMARA PAVLOVA	{"email": "pavlova-t-1976@postgrespro.ru", "phone": "+70097971642"}
0005433435282	CFC4C7	7968 071137	VIKTOR PETROV	{"email": "viktor-petrov_011972@postgrespro.ru", "phone": "+70299957870"}
0005433435283	9E5970	0920 640635	ALEKSANDR MAKSIMOV	{"email": "a_maksimov.24041971@postgrespro.ru", "phone": "+70770200459"}
0005433435284	9E5970	7620 300793	ALEKSEY SEMENOV	{"email": "semenov.aleksey021971@postgrespro.ru", "phone": "+70509950942"}
0005433435285	9E5970	7657 489612	ELENA SMIRNOVA	{"phone": "+70396843020"}
0005433435286	6E1D5D	7113 564516	ELMIRA ILINA	{"phone": "+70941642646"}
0005433435287	836531	0422 510462	ARTEM MIRONOV	{"email": "mironov-artem1969@postgrespro.ru", "phone": "+70929848260"}
0005433435288	836531	5754 692645	ANNA POLYAKOVA	{"email": "polyakova.a-1972@postgrespro.ru", "phone": "+70417330805"}
0005433435289	1E44BA	1081 646355	GALINA SOKOLOVA	{"email": "galina-sokolova_1979@postgrespro.ru", "phone": "+70436814096"}
0005433435291	655F9B	8937 804018	PELAGEYA KARPOVA	{"phone": "+70343155722"}
0005433435292	2E09ED	5602 491994	DMITRIY PETROV	{"email": "d_petrov-31071965@postgrespro.ru", "phone": "+70442074309"}
0005433435293	E9A8CE	9338 810288	VALENTINA MAKAROVA	{"email": "makarova.valentina-1966@postgrespro.ru", "phone": "+70588627835"}
0005433435294	B22F53	7798 222404	PETR GORBUNOV	{"email": "p-gorbunov-05061972@postgrespro.ru", "phone": "+70007098325"}
0005433435295	3F5605	8317 245076	ANNA IVANOVA	{"phone": "+70311194814"}
0005433435296	3F5605	4692 826778	SERGEY KULIKOV	{"email": "kulikov_s-09101974@postgrespro.ru", "phone": "+70536245791"}
0005433435297	7D8EB0	4777 671076	NATALYA KUZNECOVA	{"email": "n_kuznecova.12121972@postgrespro.ru", "phone": "+70701954784"}
0005433435298	9C11CD	6147 395545	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-08071966@postgrespro.ru", "phone": "+70924838662"}
0005433435299	9C11CD	4524 459026	ELENA SCHERBAKOVA	{"phone": "+70986343259"}
0005433435300	88DAEC	7440 961714	ALEKSEY ROMANOV	{"email": "romanov-aleksey_111974@postgrespro.ru", "phone": "+70359571950"}
0005433435301	16B0F0	1672 359793	DMITRIY SMIRNOV	{"phone": "+70320845271"}
0005433435302	10ADBA	8563 764793	SERGEY EGOROV	{"phone": "+70958359006"}
0005433435303	10ADBA	9695 792171	ROMAN ALEKSANDROV	{"phone": "+70409178754"}
0005433435304	F8E885	1872 707762	VALENTIN RODIONOV	{"phone": "+70544331452"}
0005433435305	BE512D	8446 790491	OLGA EFREMOVA	{"phone": "+70938117163"}
0005433435306	BE512D	3315 747405	ALEKSANDR ANTONOV	{"phone": "+70773016245"}
0005433435307	E0AAAD	5450 872683	MIKHAIL ZHUKOV	{"phone": "+70689969351"}
0005433435308	59A155	7436 690074	YURIY KUZNECOV	{"phone": "+70844061278"}
0005433435309	59A155	2786 171966	KLARA IVANOVA	{"email": "ivanova.k_071976@postgrespro.ru", "phone": "+70847943531"}
0005433435310	AFA3D8	5898 765176	RAISA YAKOVLEVA	{"email": "yakovleva-raisa_011970@postgrespro.ru", "phone": "+70925371869"}
0005433435311	AFA3D8	3965 637832	IRAIDA SOKOLOVA	{"phone": "+70358790075"}
0005433435312	5C4BAE	2005 871249	MARIYA ISAEVA	{"email": "mariyaisaeva1974@postgrespro.ru", "phone": "+70331188320"}
0005433435313	5815DA	0806 256264	TATYANA NIKITINA	{"phone": "+70618252806"}
0005433435314	5815DA	9685 956351	VALENTINA FEDOROVA	{"email": "vfedorova1968@postgrespro.ru", "phone": "+70830179831"}
0005433435315	277467	8698 157537	GALINA POPOVA	{"phone": "+70478967291"}
0005433435316	277467	7566 269737	ANDREY KONOVALOV	{"phone": "+70032690517"}
0005433435317	7E4E00	7286 435677	LYUBOV ARKHIPOVA	{"phone": "+70251993872"}
0005433435318	0442FA	7304 728882	MAKAR ZAKHAROV	{"email": "makarzakharov.23081976@postgrespro.ru", "phone": "+70854895074"}
0005433435319	86BAF7	4319 312398	ELENA AFANASEVA	{"email": "afanasevaelena27051986@postgrespro.ru", "phone": "+70272901187"}
0005433435320	3DF90C	3540 759871	SVETLANA VASILEVA	{"phone": "+70025632251"}
0005433435321	5C8AD2	1316 716553	OLGA CHERNOVA	{"email": "olga.chernova-101972@postgrespro.ru", "phone": "+70863296122"}
0005433435322	8D3338	1216 760888	DMITRIY BONDARENKO	{"email": "bondarenko-dmitriy-121971@postgrespro.ru", "phone": "+70046219732"}
0005433435323	8D3338	7873 403023	NIKOLAY BELOV	{"phone": "+70275493940"}
0005433435324	F04416	2174 693320	VLADIMIR MAKAROV	{"email": "makarovvladimir-08061979@postgrespro.ru", "phone": "+70940104485"}
0005433435325	F04416	9940 690017	LILIYA MAKSIMOVA	{"phone": "+70903947280"}
0005433435326	DE5A67	7852 410546	KAMILLA VOLKOVA	{"email": "k.volkova111983@postgrespro.ru", "phone": "+70199518622"}
0005433435327	0536B2	4925 065277	SERGEY ANDREEV	{"email": "s_andreev_12101970@postgrespro.ru", "phone": "+70622733048"}
0005433435328	B19F32	1543 249229	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov-1972@postgrespro.ru", "phone": "+70461141300"}
0005433435329	571626	1919 989612	VASILIY POPOV	{"email": "popovvasiliy_15061975@postgrespro.ru", "phone": "+70498882386"}
0005433435330	8CDE90	0042 406016	ALEKSANDRA MAKAROVA	{"phone": "+70257325109"}
0005433435331	8CDE90	4533 750591	VLADIMIR TARASOV	{"phone": "+70982664784"}
0005433435332	B326EC	1640 297501	LYUDMILA SOLOVEVA	{"email": "lyudmila.soloveva-121971@postgrespro.ru", "phone": "+70371525596"}
0005433435333	405278	9346 507232	ANATOLIY ANDREEV	{"email": "a.andreev_12081979@postgrespro.ru", "phone": "+70859249512"}
0005433435334	0E392D	8646 890232	TATYANA KUZMINA	{"email": "tkuzmina_081982@postgrespro.ru", "phone": "+70723222437"}
0005433435335	EED410	6115 970510	ANNA ROMANOVA	{"phone": "+70033795977"}
0005433435336	2E67B0	2177 107407	MARINA MALYSHEVA	{"email": "malysheva.m.1977@postgrespro.ru", "phone": "+70618472835"}
0005433435337	220934	9625 773624	VALERIY KUZNECOV	{"email": "valeriy.kuznecov-1973@postgrespro.ru", "phone": "+70390677944"}
0005433435338	2253E2	4437 597372	ROMAN SIDOROV	{"phone": "+70769780666"}
0005433435339	2253E2	5771 935367	IVAN KUZNECOV	{"phone": "+70065208932"}
0005433435340	FEE7C9	7634 662891	YURIY RODIONOV	{"phone": "+70643994123"}
0005433435341	FEE7C9	1628 879550	MIKHAIL FOMIN	{"phone": "+70432215617"}
0005433435342	F86F7C	0690 674512	TAISIYA DENISOVA	{"email": "t_denisova.081963@postgrespro.ru", "phone": "+70091471583"}
0005433435343	A4A177	5374 438252	IRINA EFIMOVA	{"email": "efimova_irina15021973@postgrespro.ru", "phone": "+70255918748"}
0005433435344	53BB07	6135 668252	LEONID STEPANOV	{"email": "leonid-stepanov-1985@postgrespro.ru", "phone": "+70481733639"}
0005433435345	6B5EF0	0898 646427	NINA SERGEEVA	{"email": "n_sergeeva.1978@postgrespro.ru", "phone": "+70619958389"}
0005433435346	6B5EF0	7566 408010	OLGA ZAYCEVA	{"email": "zaycevao_1973@postgrespro.ru", "phone": "+70793562975"}
0005433435347	17D594	9864 029892	NATALIYA FOMINA	{"phone": "+70272472307"}
0005433435348	5647DD	2799 562815	VALERIYA KAZAKOVA	{"phone": "+70972710099"}
0005433435349	5647DD	1036 543740	IRINA STEPANOVA	{"phone": "+70439982887"}
0005433435350	390869	4541 740554	VIKTORIYA MOISEEVA	{"phone": "+70754786531"}
0005433435351	98EAD4	6706 564924	SERGEY DMITRIEV	{"phone": "+70288588784"}
0005433435352	A5C213	8603 506290	NIKITA MAKAROV	{"phone": "+70406457005"}
0005433435353	0474B3	1130 899989	TATYANA FEDOROVA	{"phone": "+70447210929"}
0005433435354	DF9A6E	0306 812543	VIKTOR ISAEV	{"phone": "+70147777975"}
0005433435355	8BF7B5	4038 266337	ILYA SEMENOV	{"email": "isemenov.121965@postgrespro.ru", "phone": "+70405961331"}
0005433435356	22A1DE	4704 711481	PAVEL MATVEEV	{"email": "p_matveev_1963@postgrespro.ru", "phone": "+70969021716"}
0005433435357	22A1DE	9147 376677	ELVIRA GAVRILOVA	{"email": "gavrilova_elvira.01121974@postgrespro.ru", "phone": "+70974654875"}
0005433435358	B6254F	5257 295675	DENIS PAVLOV	{"phone": "+70907291088"}
0005433435359	D049A6	0435 487840	PELAGEYA IVANOVA	{"phone": "+70162597002"}
0005433435360	CF0E24	9700 381485	ARTEM ANTONOV	{"phone": "+70577920771"}
0005433435361	410C97	4496 314800	ALEKSEY VOLKOV	{"email": "a_volkov-021972@postgrespro.ru", "phone": "+70785870214"}
0005433435362	410C97	9247 840411	VALERIY ZAYCEV	{"phone": "+70238878932"}
0005433435363	75D9D6	2630 025331	IGOR EGOROV	{"email": "egorov-igor1977@postgrespro.ru", "phone": "+70050024742"}
0005433435364	DD9113	7922 111797	LYUDMILA ZAKHAROVA	{"phone": "+70226760422"}
0005433435365	422E96	2119 262383	RUSTAM KOROLEV	{"email": "rustam.korolev_1968@postgrespro.ru", "phone": "+70258533098"}
0005433435366	8AAE92	5662 740545	NATALYA TROFIMOVA	{"phone": "+70899069279"}
0005433435367	E98C24	6901 805269	MARIYA OSIPOVA	{"email": "mosipova.21081972@postgrespro.ru", "phone": "+70544576680"}
0005433435368	E98C24	7302 005358	TATYANA KOLESNIKOVA	{"phone": "+70269015820"}
0005433435369	3E5636	5312 667862	ELENA ZAKHAROVA	{"email": "zakharova-elena041975@postgrespro.ru", "phone": "+70863910482"}
0005433435370	3E5636	4920 047507	SERGEY SEMENOV	{"phone": "+70047423787"}
0005433435371	AF2A57	4262 760251	KLAVDIYA ARKHIPOVA	{"email": "k-arkhipova_09021967@postgrespro.ru", "phone": "+70444554390"}
0005433435372	F3F001	2930 900421	VALERIY KUZMIN	{"email": "valeriykuzmin.10121971@postgrespro.ru", "phone": "+70122300511"}
0005433435373	626CE9	7643 745381	EKATERINA ANTONOVA	{"phone": "+70128671991"}
0005433435374	ADB59D	8742 005945	OLGA SMIRNOVA	{"phone": "+70775156164"}
0005433435375	ADB59D	4079 307181	ALEKSEY PETROV	{"phone": "+70417073207"}
0005433435376	FD03FD	6757 046869	ALEKSEY PAVLOV	{"email": "a-pavlov-011976@postgrespro.ru", "phone": "+70288145148"}
0005433435377	156EDA	5733 618222	GENNADIY SOKOLOV	{"phone": "+70759960811"}
0005433435378	DDDD9A	6661 920842	OLGA FOMINA	{"phone": "+70132010484"}
0005433435379	5E45A6	8600 863422	PETR GAVRILOV	{"phone": "+70264731568"}
0005433435380	F6839C	4280 748539	ARTEM DENISOV	{"phone": "+70179907805"}
0005433435381	753DE4	2843 640130	ANDREY BARANOV	{"phone": "+70976973938"}
0005433435382	753DE4	7383 931873	SERGEY ABRAMOV	{"email": "sabramov-011967@postgrespro.ru", "phone": "+70071523560"}
0005433435383	3EF0B8	7898 823774	RINAT GRIGOREV	{"phone": "+70746960822"}
0005433435384	7606DA	1704 690182	MARGARITA VLASOVA	{"phone": "+70429270272"}
0005433435385	9B0C24	2232 739637	ALENA MELNIKOVA	{"phone": "+70956113142"}
0005433435386	D22B54	8324 484818	ANNA EFREMOVA	{"email": "aefremova_031967@postgrespro.ru", "phone": "+70813272481"}
0005433435387	2BF54C	6531 540657	RINAT KUZMIN	{"email": "kuzmin_r_1979@postgrespro.ru", "phone": "+70926227106"}
0005433435388	2BF54C	4425 814459	AMIR SOROKIN	{"phone": "+70018347379"}
0005433435389	2BF54C	2832 223783	MARAT KUZNECOV	{"email": "marat.kuznecov-28101963@postgrespro.ru", "phone": "+70447842758"}
0005433435390	46B40B	1796 855200	ARMEN KOROLEV	{"phone": "+70355494893"}
0005433435391	8B51D8	0313 362391	NATALYA IVANOVA	{"email": "n_ivanova.1974@postgrespro.ru", "phone": "+70413706208"}
0005433435392	8B51D8	8995 958516	ELENA KRASNOVA	{"phone": "+70271836056"}
0005433435393	76232F	0219 430955	LIDIYA SCHERBAKOVA	{"phone": "+70467003233"}
0005433435394	76232F	9355 748524	VIKTORIYA MEDVEDEVA	{"phone": "+70122523242"}
0005433435395	AB733B	2341 717886	EKATERINA ISAEVA	{"phone": "+70513908327"}
0005433435396	CC5700	4830 963299	ALEKSEY KOZLOV	{"email": "aleksey_kozlov-1982@postgrespro.ru", "phone": "+70941774673"}
0005433435397	5601E8	9572 601868	PAVEL KUZNECOV	{"phone": "+70263422615"}
0005433435398	5601E8	3050 362469	NINA ZAKHAROVA	{"phone": "+70670129052"}
0005433435399	1C7701	6229 582322	ANDREY ABRAMOV	{"email": "andrey.abramov-101967@postgrespro.ru", "phone": "+70511719281"}
0005433435400	1C7701	9975 615306	VALERIY PETROV	{"phone": "+70396081029"}
0005433435401	93B21B	8002 222750	SERGEY GRIGOREV	{"phone": "+70957169275"}
0005433435402	82E0C3	1054 317862	VALENTINA ROMANOVA	{"phone": "+70049569332"}
0005433435403	67DE11	0283 810013	LEONID SAVELEV	{"phone": "+70521639328"}
0005433435404	67DE11	6403 011163	ANASTASIYA KAZAKOVA	{"email": "kazakova_a.021963@postgrespro.ru", "phone": "+70781997259"}
0005433435405	73EEE8	0767 940352	ILYA PETROV	{"email": "ilya-petrov.07101977@postgrespro.ru", "phone": "+70036712443"}
0005433435406	D0C2A5	0659 790811	ARTEM MAKAROV	{"email": "makarov_artem-11111968@postgrespro.ru", "phone": "+70150242754"}
0005433435409	A96BF6	1597 398584	VALENTINA NAZAROVA	{"phone": "+70606011558"}
0005433435410	A96BF6	8084 886743	ALEKSEY KUZNECOV	{"phone": "+70239825294"}
0005433435411	973E19	1250 560798	YULIYA SEMENOVA	{"phone": "+70816696878"}
0005433435412	973E19	1488 025456	LILIYA NESTEROVA	{"email": "nesterova.liliya.1968@postgrespro.ru", "phone": "+70238856696"}
0005433435413	973E19	4984 144118	ANNA POTAPOVA	{"phone": "+70346315874"}
0005433435414	7F92B2	1186 355829	LYUBOV IVANOVA	{"email": "lyubov.ivanova_101971@postgrespro.ru", "phone": "+70177157833"}
0005433435415	14C349	1104 332129	VALENTINA SOROKINA	{"email": "valentinasorokina_1967@postgrespro.ru", "phone": "+70218049307"}
0005433435416	169993	7275 026297	LYUDMILA KISELEVA	{"phone": "+70076739925"}
0005433435417	169993	8659 960699	SERGEY DAVYDOV	{"phone": "+70693717550"}
0005433435418	3B70C9	3403 347057	ANDREY SOROKIN	{"email": "sorokin-a.05071971@postgrespro.ru", "phone": "+70053061403"}
0005433435419	B0F125	8039 391152	NATALYA SEMENOVA	{"phone": "+70810284504"}
0005433435420	A9E165	2257 238587	PELAGEYA YUDINA	{"phone": "+70334995988"}
0005433435421	390CEC	5489 563816	ANGELINA MIKHAYLOVA	{"phone": "+70864147456"}
0005433435422	958B8C	3558 313021	SVETLANA KUZNECOVA	{"email": "kuznecovasvetlana.28051984@postgrespro.ru", "phone": "+70454968588"}
0005433435423	8385B9	5282 044825	TAMARA ILINA	{"email": "ilina_tamara_1972@postgrespro.ru", "phone": "+70406560023"}
0005433435424	8385B9	1376 075803	KONSTANTIN STEPANOV	{"email": "konstantinstepanov_1980@postgrespro.ru", "phone": "+70716053147"}
0005433435425	9C912E	8879 224778	KSENIYA ZAKHAROVA	{"email": "zakharova.kseniya_17031986@postgrespro.ru", "phone": "+70707081042"}
0005433435426	E0685E	6385 702073	VERA MELNIKOVA	{"phone": "+70784347971"}
0005433435427	E0685E	9301 592700	ANTON SOKOLOV	{"email": "anton.sokolov021967@postgrespro.ru", "phone": "+70548952509"}
0005433435428	E0685E	0964 636247	OLGA SEMENOVA	{"phone": "+70070397047"}
0005433435429	AD74E8	6002 177134	VLADIMIR DENISOV	{"phone": "+70685673113"}
0005433435430	4DD12F	5420 520959	ANDREY PETROV	{"phone": "+70003537395"}
0005433435431	C2DF7C	2527 826598	ALEKSANDR KISELEV	{"phone": "+70739894023"}
0005433435432	17812F	7057 932976	DMITRIY VLASOV	{"phone": "+70332881588"}
0005433435433	17812F	3527 995356	EVGENIY IVANOV	{"phone": "+70455277268"}
0005433435434	17812F	6284 211409	DMITRIY EGOROV	{"phone": "+70588663927"}
0005433435435	870CB1	6500 806003	OLGA EGOROVA	{"email": "egorova.o-1973@postgrespro.ru", "phone": "+70372978430"}
0005433435436	404DE1	7669 172182	TATYANA TIMOFEEVA	{"email": "ttimofeeva_041964@postgrespro.ru", "phone": "+70375959929"}
0005433435437	947D16	2507 392175	ALEKSANDR KUZNECOV	{"phone": "+70743270867"}
0005433435438	DF7ED5	7637 178842	ALLA ANDREEVA	{"email": "andreeva_a_16031980@postgrespro.ru", "phone": "+70023945231"}
0005433435439	DF7ED5	3891 228192	ANNA MAKSIMOVA	{"phone": "+70274362790"}
0005433435440	5EDF0B	0450 411827	SERGEY NIKITIN	{"phone": "+70137874948"}
0005433435441	8F35F4	5619 979796	LYUDMILA ALEKSEEVA	{"email": "alekseeva.lyudmila031971@postgrespro.ru", "phone": "+70049327081"}
0005433435442	8F35F4	2784 427268	ARTEM EGOROV	{"email": "egorova-031973@postgrespro.ru", "phone": "+70859540109"}
0005433435443	A24151	2384 593710	VALENTINA GERASIMOVA	{"email": "gerasimova.valentina_021978@postgrespro.ru", "phone": "+70037949954"}
0005433435444	A24151	1618 679917	IVAN GERASIMOV	{"email": "gerasimov.ivan.061974@postgrespro.ru", "phone": "+70402694429"}
0005433435445	A609CA	2823 352379	VIKTOR KUZMIN	{"email": "kuzmin_viktor_081971@postgrespro.ru", "phone": "+70577590235"}
0005433435446	029139	7311 957851	VLADIMIR MOISEEV	{"phone": "+70269329280"}
0005433435447	9E9F95	1191 267167	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva_1971@postgrespro.ru", "phone": "+70489864610"}
0005433435448	5F2490	8047 612452	MARINA TIMOFEEVA	{"email": "timofeevam-071974@postgrespro.ru", "phone": "+70628942991"}
0005433435449	88100F	6349 633797	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova_091974@postgrespro.ru", "phone": "+70514352498"}
0005433435450	88100F	3710 598630	VLADIMIR CHERNOV	{"email": "chernov.v1971@postgrespro.ru", "phone": "+70794068331"}
0005433435451	88100F	9251 219619	LYUDMILA VLASOVA	{"email": "vlasova_l22031962@postgrespro.ru", "phone": "+70512021415"}
0005433435452	FBE8CB	9299 723293	YULIYA ABRAMOVA	{"email": "yuliya-abramova_061980@postgrespro.ru", "phone": "+70707457063"}
0005433435453	7DBD01	1144 333744	GALINA PETROVA	{"email": "galina_petrova_1957@postgrespro.ru", "phone": "+70401474131"}
0005433435454	7DBD01	2289 397546	TATYANA DAVYDOVA	{"phone": "+70466461041"}
0005433435455	7DBD01	8518 754023	EVGENIY NAZAROV	{"phone": "+70604659916"}
0005433435456	C0907D	8998 358391	ELENA SCHERBAKOVA	{"email": "scherbakova.elena-1974@postgrespro.ru", "phone": "+70244850468"}
0005433435457	C0907D	1690 486374	ALEKSANDRA ZAKHAROVA	{"phone": "+70504772247"}
0005433435458	4089EE	9680 116382	NINA ZAKHAROVA	{"phone": "+70076497348"}
0005433435459	C1B0E0	5662 731301	LILIYA FROLOVA	{"phone": "+70649646475"}
0005433435460	F4A677	9637 322050	SVETLANA DAVYDOVA	{"email": "davydova_svetlana_051970@postgrespro.ru", "phone": "+70152286871"}
0005433435461	07954C	2471 933463	RUSTAM NIKITIN	{"phone": "+70967759772"}
0005433435462	1A7582	6467 171234	ALEKSEY KUZMIN	{"phone": "+70849264723"}
0005433435463	5938B0	5523 727755	ALINA TARASOVA	{"email": "tarasova_a.091969@postgrespro.ru", "phone": "+70107019124"}
0005433435464	C71936	1632 558379	LYUDMILA IVANOVA	{"phone": "+70865358891"}
0005433435465	45A02C	6843 251260	EKATERINA ZAYCEVA	{"phone": "+70801343961"}
0005433435466	45A02C	6574 795164	VLADIMIR BARANOV	{"phone": "+70358771234"}
0005433435467	B13B35	1024 737066	NIKOLAY SERGEEV	{"email": "nikolay.sergeev.031967@postgrespro.ru", "phone": "+70575384290"}
0005433435468	B5A951	9051 447368	NATALYA SIDOROVA	{"email": "sidorovanatalya_081980@postgrespro.ru", "phone": "+70479560177"}
0005433435531	46005C	9136 589995	ALLA VOROBEVA	{"phone": "+70259812510"}
0005433435469	D7E488	1099 157843	VLADISLAV DAVYDOV	{"email": "davydov_v-1977@postgrespro.ru", "phone": "+70062779471"}
0005433435470	E92619	9056 165748	ALEKSANDR BELOV	{"email": "belovaleksandr-111976@postgrespro.ru", "phone": "+70468628520"}
0005433435471	2ED9F5	3708 213996	SERGEY ORLOV	{"phone": "+70109279682"}
0005433435472	2ED9F5	4615 115329	VIKTOR SOROKIN	{"phone": "+70650063613"}
0005433435473	6E7D33	0390 312692	VLADISLAV ANDREEV	{"phone": "+70386739600"}
0005433435474	443E69	9459 140446	ANATOLIY ABRAMOV	{"email": "abramov_a-011964@postgrespro.ru", "phone": "+70645005316"}
0005433435475	0D38AC	6584 465405	GALINA MIKHAYLOVA	{"phone": "+70509566289"}
0005433435476	0D38AC	9029 840699	VIKTOR KONOVALOV	{"phone": "+70347791296"}
0005433435477	3AE208	0755 067373	ANZHELIKA NIKOLAEVA	{"email": "nikolaeva-a.11051965@postgrespro.ru", "phone": "+70107855789"}
0005433435478	429ECA	3348 522613	VLADIMIR ZAKHAROV	{"email": "v.zakharov_041970@postgrespro.ru", "phone": "+70266794700"}
0005433435479	429ECA	1847 254239	NINA POLYAKOVA	{"phone": "+70995470091"}
0005433435480	429ECA	9926 443867	DENIS GAVRILOV	{"email": "gavrilovd-26011967@postgrespro.ru", "phone": "+70611682346"}
0005433435481	7D2B14	2737 111866	SERGEY KONOVALOV	{"phone": "+70895111953"}
0005433435482	1F4058	3834 738741	ANDREY MIRONOV	{"phone": "+70794682946"}
0005433435483	70A081	5803 287457	DMITRIY EGOROV	{"email": "dmitriy_egorov101973@postgrespro.ru", "phone": "+70322962966"}
0005433435484	70A081	3257 546157	ALBINA LEBEDEVA	{"phone": "+70014623451"}
0005433435485	70A081	4389 128275	GEORGIY ALEKSANDROV	{"phone": "+70237058218"}
0005433435486	072D25	4162 154407	SERGEY NIKOLAEV	{"email": "nikolaev.s101971@postgrespro.ru", "phone": "+70612940053"}
0005433435487	072D25	8775 030287	KRISTINA BELOVA	{"phone": "+70528332376"}
0005433435488	CDFEC1	4591 595689	TATYANA FEDOROVA	{"phone": "+70855696483"}
0005433435489	A39103	9233 313407	DARYA KUZNECOVA	{"email": "darya-kuznecova_01071973@postgrespro.ru", "phone": "+70298535077"}
0005433435490	D1A692	6814 008324	LYUDMILA MEDVEDEVA	{"email": "medvedeva-l27011967@postgrespro.ru", "phone": "+70611667017"}
0005433435491	796CBE	6373 340009	RAISA KOZLOVA	{"phone": "+70414923622"}
0005433435492	EFF95A	0254 280077	EGOR MOROZOV	{"email": "emorozov_061964@postgrespro.ru", "phone": "+70927663497"}
0005433435493	08E803	6215 683252	VASILIY BARANOV	{"phone": "+70211398121"}
0005433435494	08E803	6923 244633	DAMIR DENISOV	{"phone": "+70643502703"}
0005433435495	A58A43	3484 043250	ANASTASIYA ILINA	{"email": "anastasiyailina.1977@postgrespro.ru", "phone": "+70557274679"}
0005433435496	A58A43	0170 231826	VALENTINA POPOVA	{"email": "popova.valentina.101962@postgrespro.ru", "phone": "+70391452694"}
0005433435497	C8993F	6874 088685	OKSANA KUZNECOVA	{"phone": "+70748025737"}
0005433435498	327004	5923 457199	NADEZHDA KOROLEVA	{"email": "koroleva.n_041959@postgrespro.ru", "phone": "+70405532098"}
0005433435499	29A5EE	6747 363221	ANTON VLASOV	{"phone": "+70071734122"}
0005433435500	29A5EE	5341 553197	LIDIYA MARTYNOVA	{"phone": "+70067278967"}
0005433435501	6911DB	0738 504570	VASILIY NAZAROV	{"email": "nazarov-vasiliy_081966@postgrespro.ru", "phone": "+70523532869"}
0005433435502	C45CBB	1204 996744	SERGEY SCHERBAKOV	{"phone": "+70260454577"}
0005433435503	C45CBB	8843 951963	GALINA VASILEVA	{"phone": "+70950401877"}
0005433435504	9F20F1	6150 358529	ANATOLIY IVANOV	{"email": "anatoliy-ivanov.1964@postgrespro.ru", "phone": "+70976439657"}
0005433435505	62133C	4414 369135	VARVARA IVANOVA	{"phone": "+70703903289"}
0005433435506	CC0466	8079 382401	GALIYA BORISOVA	{"phone": "+70499612292"}
0005433435507	CC0466	1156 416136	VLADIMIR TARASOV	{"phone": "+70113636266"}
0005433435508	B2C64B	0391 849003	ELENA MIKHAYLOVA	{"phone": "+70405886899"}
0005433435509	C7F8FD	1530 098559	TATYANA VOLKOVA	{"phone": "+70268063316"}
0005433435510	3E6DAC	6097 139167	OLGA LAZAREVA	{"email": "lazarevao1970@postgrespro.ru", "phone": "+70719726173"}
0005433435511	39AD80	9982 405182	SERGEY VOLKOV	{"email": "svolkov_29071967@postgrespro.ru", "phone": "+70101752366"}
0005433435512	1B1D43	2265 646945	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr-031979@postgrespro.ru", "phone": "+70036252829"}
0005433435513	1B1D43	9768 305661	ANTON EGOROV	{"phone": "+70302663509"}
0005433435514	AA4887	3934 950961	KLAVDIYA IVANOVA	{"email": "ivanova_k1979@postgrespro.ru", "phone": "+70106863830"}
0005433435515	9C9733	4826 762235	MARINA SIDOROVA	{"phone": "+70176562419"}
0005433435516	E9EE5A	4498 097714	ALEKSANDRA KONOVALOVA	{"phone": "+70754116287"}
0005433435517	FF7F50	1442 044100	OLGA TIMOFEEVA	{"phone": "+70824873403"}
0005433435518	931236	0129 952363	DENIS KAZAKOV	{"phone": "+70464395456"}
0005433435519	931236	9094 096560	ELENA ANTONOVA	{"email": "antonova-e.31101981@postgrespro.ru", "phone": "+70646761105"}
0005433435520	931236	5766 143761	PAVEL NOVIKOV	{"email": "novikov_p30061970@postgrespro.ru", "phone": "+70230585302"}
0005433435521	76A7EB	3735 209736	VITALIY MOROZOV	{"phone": "+70308794054"}
0005433435522	D3EC35	5405 392438	ELENA ALEKSANDROVA	{"email": "aleksandrova_e.1979@postgrespro.ru", "phone": "+70847718963"}
0005433435523	9260A9	7279 846208	NADEZHDA SMIRNOVA	{"email": "smirnova.nadezhda-041966@postgrespro.ru", "phone": "+70696389416"}
0005433435524	9260A9	0711 292593	SERGEY KUZNECOV	{"email": "sergey_kuznecov.031975@postgrespro.ru", "phone": "+70378477113"}
0005433435525	0A11FE	3553 963533	LYUDMILA KUZMINA	{"phone": "+70232508180"}
0005433435526	0A11FE	2794 077918	VERA KOROLEVA	{"email": "vera_koroleva-101975@postgrespro.ru", "phone": "+70307830050"}
0005433435527	C75B14	5517 809856	SERGEY ABRAMOV	{"phone": "+70320854070"}
0005433435528	C75B14	2193 054849	DMITRIY NAUMOV	{"email": "d-naumov.031983@postgrespro.ru", "phone": "+70982789297"}
0005433435529	15DB38	4421 346954	EVGENIY FILIPPOV	{"email": "filippov-evgeniy-27021978@postgrespro.ru", "phone": "+70637892008"}
0005433435530	749161	4289 756846	DENIS MEDVEDEV	{"phone": "+70532441516"}
0005433435532	46005C	9972 116207	MAKSIM ANDREEV	{"email": "m.andreev25121953@postgrespro.ru", "phone": "+70630838186"}
0005433438763	EB1E23	7223 976847	IRINA ROMANOVA	{"phone": "+70490370725"}
0005433438764	884982	8576 174035	ALEKSANDR POPOV	{"phone": "+70445478225"}
0005433438765	44F4DC	8218 577149	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev_1971@postgrespro.ru", "phone": "+70124722579"}
0005433438766	F85033	4110 368576	MIKHAIL KAZAKOV	{"email": "mikhailkazakov1979@postgrespro.ru", "phone": "+70607848310"}
0005433438767	35ECFD	5341 541424	NADEZHDA ARKHIPOVA	{"email": "narkhipova1964@postgrespro.ru", "phone": "+70715651337"}
0005433438768	D4ABAB	5784 002907	NADEZHDA KOZLOVA	{"phone": "+70590473694"}
0005433438769	AB19B2	5546 518622	EKATERINA OSIPOVA	{"phone": "+70224206838"}
0005433438770	049FEB	7606 680627	ALENA VOLKOVA	{"phone": "+70566902494"}
0005433438771	10D6A4	9251 987580	SERGEY PETROV	{"phone": "+70404559380"}
0005433438772	0CD860	1606 802358	ANDREY ANDREEV	{"phone": "+70247953374"}
0005433438773	C9920E	6869 543320	OLEG KUDRYASHOV	{"phone": "+70250925503"}
0005433438774	C9920E	5556 496113	TAKHIR SERGEEV	{"phone": "+70039291089"}
0005433438775	1CC333	3163 952667	EVGENIY SIDOROV	{"email": "sidorovevgeniy.1977@postgrespro.ru", "phone": "+70637049311"}
0005433438776	04DC34	2671 227836	SERGEY ZHUKOV	{"phone": "+70649840929"}
0005433438777	642603	7393 541506	ROMAN SAVELEV	{"email": "roman_savelev.081984@postgrespro.ru", "phone": "+70020307355"}
0005433438778	642603	3610 571176	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin.22041975@postgrespro.ru", "phone": "+70468930410"}
0005433438779	36C766	4684 998919	NATALYA MAKSIMOVA	{"phone": "+70258212344"}
0005433438780	5B8B79	9430 711786	VALENTINA ALEKSEEVA	{"phone": "+70818870075"}
0005433438781	5B8B79	5842 050717	SERGEY NIKOLAEV	{"phone": "+70281524941"}
0005433438782	5B8B79	6981 642280	IGOR PETROV	{"email": "igor_petrov_1972@postgrespro.ru", "phone": "+70175816800"}
0005433438783	A60A42	9817 021753	MARIYA SEMENOVA	{"phone": "+70270240304"}
0005433438784	A60A42	4390 205632	IGOR KAZAKOV	{"phone": "+70465696274"}
0005433438785	B04874	8019 077887	VLADA KONDRATEVA	{"email": "v-kondrateva-071963@postgrespro.ru", "phone": "+70050749509"}
0005433438786	B04874	3741 129616	OKSANA MALYSHEVA	{"email": "oksanamalysheva_04081965@postgrespro.ru", "phone": "+70149679183"}
0005433438787	8BFC24	5739 007888	ANTONINA ANTONOVA	{"phone": "+70202687055"}
0005433438788	8BFC24	1666 664015	YULIYA POLYAKOVA	{"email": "ypolyakova.19101974@postgrespro.ru", "phone": "+70346404842"}
0005433438789	09FE5F	9937 527625	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr_1976@postgrespro.ru", "phone": "+70347190967"}
0005433438790	09FE5F	0193 377567	MARIYA KONOVALOVA	{"email": "konovalova.m-061973@postgrespro.ru", "phone": "+70219578279"}
0005433438791	09FE5F	5742 065766	ALEKSANDR VASILEV	{"email": "a_vasilev-111981@postgrespro.ru", "phone": "+70072529941"}
0005433438792	9BFCD2	8256 020393	MAKSIM MAKAROV	{"email": "m_makarov071976@postgrespro.ru", "phone": "+70005580883"}
0005433438793	9BFCD2	4127 976104	OLEG KOROLEV	{"email": "korolev.o_1970@postgrespro.ru", "phone": "+70404073807"}
0005433438794	9C37BA	8685 147531	TAMARA MATVEEVA	{"email": "tamara-matveeva1967@postgrespro.ru", "phone": "+70322798845"}
0005433438795	9C37BA	8682 296635	MIKHAIL BELOV	{"email": "mikhail.belov-1978@postgrespro.ru", "phone": "+70888386266"}
0005433438796	E18D0C	5885 339868	TATYANA MATVEEVA	{"phone": "+70472695760"}
0005433438797	35DE9C	6227 210313	MARGARITA ANTONOVA	{"phone": "+70489997825"}
0005433438798	AC8520	8808 388811	TATYANA GUSEVA	{"email": "gusevatatyana.25041973@postgrespro.ru", "phone": "+70082931286"}
0005433438799	23E0D7	1944 528715	MARIYA RYABOVA	{"phone": "+70514818514"}
0005433438800	3F59FC	3193 303049	IGOR AFANASEV	{"phone": "+70023980958"}
0005433438801	FC8045	6641 005005	ANDREY KOZLOV	{"phone": "+70306694686"}
0005433438802	55F266	0844 864020	ANDREY NIKITIN	{"email": "andreynikitin031979@postgrespro.ru", "phone": "+70661102076"}
0005433438803	275C3B	9910 261285	RAISA SOKOLOVA	{"email": "sokolova_raisa.1971@postgrespro.ru", "phone": "+70619085780"}
0005433438804	0546AB	6347 271946	ALEKSEY ZAYCEV	{"email": "zaycev.a_25091965@postgrespro.ru", "phone": "+70183665343"}
0005433438805	BC5062	9133 099043	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-a061980@postgrespro.ru", "phone": "+70105433558"}
0005433438806	A8A5F7	7234 399169	ANNA KOROLEVA	{"email": "koroleva-anna-111972@postgrespro.ru", "phone": "+70767229192"}
0005433438807	ADBFF4	8747 670080	ANASTASIYA VOLKOVA	{"phone": "+70863248819"}
0005433438808	ADBFF4	5309 336853	ZHANNA IVANOVA	{"phone": "+70972952507"}
0005433438809	5F57B7	3491 151663	ALINA MARTYNOVA	{"email": "martynova_a.091962@postgrespro.ru", "phone": "+70757320355"}
0005433438810	ADF641	9130 764587	ROZA POPOVA	{"email": "roza-popova.27011975@postgrespro.ru", "phone": "+70460499857"}
0005433438811	A0F191	2308 285570	TAMARA EFIMOVA	{"email": "tamara_efimova.021978@postgrespro.ru", "phone": "+70146243312"}
0005433438812	88F29A	1574 170497	ANNA ZOTOVA	{"email": "zotova_a081977@postgrespro.ru", "phone": "+70259842742"}
0005433438813	BE2BBF	5564 365208	ALEKSANDRA POPOVA	{"phone": "+70134175967"}
0005433438814	B636D0	1666 574557	DMITRIY ZHUKOV	{"email": "dmitriy.zhukov1965@postgrespro.ru", "phone": "+70257324093"}
0005433438815	937341	4001 208735	LYUDMILA MOROZOVA	{"phone": "+70154096961"}
0005433438816	937341	7781 340398	ELENA BORISOVA	{"email": "elena.borisova_121973@postgrespro.ru", "phone": "+70800863020"}
0005433438817	88E601	9337 422585	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov_14011969@postgrespro.ru", "phone": "+70999095368"}
0005433438818	0E0694	3843 614389	IRINA ORLOVA	{"email": "i_orlova_081972@postgrespro.ru", "phone": "+70834527821"}
0005433438819	7EEAA3	0881 594401	EVGENIY MATVEEV	{"phone": "+70665459520"}
0005433438820	3580F7	7578 457526	IVAN TIKHONOV	{"phone": "+70329773611"}
0005433438821	3580F7	4142 258648	NADEZHDA PETROVA	{"email": "petrova_n011979@postgrespro.ru", "phone": "+70875421389"}
0005433438822	F6F59C	5856 750277	OLGA GRISHINA	{"email": "olga_grishina-1982@postgrespro.ru", "phone": "+70404131504"}
0005433438823	C2C19A	4069 640400	ANASTASIYA NAUMOVA	{"email": "a_naumova.13011976@postgrespro.ru", "phone": "+70548165112"}
0005433438824	C2C19A	7501 864102	MARINA FOMINA	{"phone": "+70277389432"}
0005433438825	373E6F	8924 565238	ALEKSEY FEDOROV	{"phone": "+70561871427"}
0005433438826	C0FFBA	7359 871664	NADEZHDA SMIRNOVA	{"phone": "+70206622089"}
0005433438827	1A52F9	1543 786566	MAKSIM ANTONOV	{"phone": "+70036376996"}
0005433438828	12A5CA	1596 440245	NIKOLAY IVANOV	{"email": "nikolayivanov_29031977@postgrespro.ru", "phone": "+70542021095"}
0005433438829	12A5CA	3060 520895	VALERIY GRIGOREV	{"email": "valeriy_grigorev_051979@postgrespro.ru", "phone": "+70826089275"}
0005433438830	8121D3	0246 129833	MARIYA ZAYCEVA	{"phone": "+70367555344"}
0005433438831	914B6D	0057 243272	MIKHAIL FROLOV	{"email": "m-frolov111978@postgrespro.ru", "phone": "+70010247669"}
0005433438832	3DC550	3329 826437	ALEKSANDRA ORLOVA	{"phone": "+70668916267"}
0005433438833	003D47	3273 407171	TATYANA GAVRILOVA	{"email": "t_gavrilova.091970@postgrespro.ru", "phone": "+70744475407"}
0005433438834	003D47	3126 654726	EKATERINA LOGINOVA	{"email": "loginovae-1967@postgrespro.ru", "phone": "+70356326585"}
0005433438835	BD08BA	0895 176062	DMITRIY SMIRNOV	{"phone": "+70299601905"}
0005433438836	50BEBF	9549 655611	VLADISLAV ZAKHAROV	{"phone": "+70483936422"}
0005433438837	50BEBF	2079 561305	SERGEY SIDOROV	{"phone": "+70659362395"}
0005433438838	1A4E3A	8787 770074	SERGEY MOROZOV	{"email": "morozov.s031971@postgrespro.ru", "phone": "+70849146212"}
0005433438839	1A4E3A	0624 493298	SERGEY NIKOLAEV	{"phone": "+70823909516"}
0005433438840	371FDE	1191 271747	NATALYA KUZMINA	{"phone": "+70389292937"}
0005433438841	369B37	5542 701158	ALEKSEY PETROV	{"email": "a_petrov1969@postgrespro.ru", "phone": "+70096617823"}
0005433438842	158507	9872 309893	VSEVOLOD VASILEV	{"email": "vasilevv.1965@postgrespro.ru", "phone": "+70176007975"}
0005433438843	158507	0016 524724	VALENTINA FOMINA	{"phone": "+70978359581"}
0005433438844	9F7DAC	0979 785383	IRINA SMIRNOVA	{"email": "smirnova-i_1973@postgrespro.ru", "phone": "+70816287747"}
0005433438845	B6B73D	0778 020944	ALEKSANDR DENISOV	{"email": "denisov_aleksandr.071981@postgrespro.ru", "phone": "+70930268404"}
0005433438846	95EF2D	1769 601723	VALERIY NOVIKOV	{"phone": "+70501929178"}
0005433438847	95EF2D	6745 519917	RAISA KUZMINA	{"email": "raisa.kuzmina.1967@postgrespro.ru", "phone": "+70081675839"}
0005433438848	376C49	5882 862352	GALINA LEBEDEVA	{"phone": "+70313818205"}
0005433438849	55B528	9469 484835	VALENTINA VASILEVA	{"email": "valentina.vasileva.1976@postgrespro.ru", "phone": "+70026947588"}
0005433438850	29A0EA	5811 134395	PAVEL SOROKIN	{"phone": "+70694074738"}
0005433438851	E0B3B0	9211 217469	LIDIYA GRISHINA	{"phone": "+70357938800"}
0005433438852	17DFF0	1703 955629	ANNA EGOROVA	{"email": "a-egorova-1976@postgrespro.ru", "phone": "+70865774178"}
0005433438853	17DFF0	4762 232788	EKATERINA AKIMOVA	{"email": "eakimova1963@postgrespro.ru", "phone": "+70929047889"}
0005433438854	D8DDB7	2652 965335	VADIM KUZMIN	{"phone": "+70799966126"}
0005433438855	0FB7A1	9757 298596	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov.061969@postgrespro.ru", "phone": "+70204040157"}
0005433438856	18E850	0480 834584	ALEKSANDR KUZNECOV	{"phone": "+70149070558"}
0005433438857	18E850	1577 744384	ALEKSANDR ZHUKOV	{"email": "zhukov.a.26081973@postgrespro.ru", "phone": "+70845886635"}
0005433438858	098092	6951 405189	NATALYA SOKOLOVA	{"email": "sokolova-n_08071977@postgrespro.ru", "phone": "+70439496550"}
0005433438859	EC655E	2944 754393	ZINAIDA BORISOVA	{"phone": "+70590130436"}
0005433438860	29060F	5357 971393	VLADIMIR TIMOFEEV	{"phone": "+70959864225"}
0005433438861	E59AF3	3619 434773	SERGEY PAVLOV	{"email": "pavlov.sergey_31081968@postgrespro.ru", "phone": "+70634450657"}
0005433438862	7B3BEC	9899 579160	NATALYA ZAYCEVA	{"email": "zayceva_n.071971@postgrespro.ru", "phone": "+70876321373"}
0005433438863	4840D7	9631 077989	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.18041961@postgrespro.ru", "phone": "+70715299944"}
0005433438864	F8E2E9	7326 512045	MARIYA LOGINOVA	{"phone": "+70607400086"}
0005433438865	D04015	1325 029343	ANTONINA GERASIMOVA	{"phone": "+70122862157"}
0005433438866	19972B	1508 688818	DANILA MEDVEDEV	{"email": "d-medvedev-031977@postgrespro.ru", "phone": "+70825649465"}
0005433438867	19972B	7624 482821	SERGEY NOVIKOV	{"phone": "+70170511972"}
0005433438868	D408FD	6404 460487	ARTEM PAVLOV	{"email": "pavlov.artem.1975@postgrespro.ru", "phone": "+70893982665"}
0005433438869	A80F45	9052 427192	EVGENIY MARTYNOV	{"phone": "+70874907689"}
0005433438870	A80F45	4636 574770	ALINA SOLOVEVA	{"email": "asoloveva_08021976@postgrespro.ru", "phone": "+70763459526"}
0005433438871	FA2B71	2674 021002	NATALYA ANTONOVA	{"email": "natalya-antonova_07071969@postgrespro.ru", "phone": "+70449170422"}
0005433438872	FA2B71	6296 218387	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir_091969@postgrespro.ru", "phone": "+70755334384"}
0005433438873	58B706	4712 438746	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr-1970@postgrespro.ru", "phone": "+70173743323"}
0005433438874	58B706	6098 485783	ALEKSANDR ZHUKOV	{"email": "zhukova_1971@postgrespro.ru", "phone": "+70901945993"}
0005433438875	B4DB99	0326 993751	ELIZAVETA MATVEEVA	{"phone": "+70690994667"}
0005433438876	1A75C0	3319 757683	VLADIMIR KAZAKOV	{"phone": "+70645423697"}
0005433438877	D485ED	0947 859674	ALEKSANDR DMITRIEV	{"phone": "+70930708610"}
0005433438878	38DB93	4946 263064	OLGA TITOVA	{"email": "otitova_23091966@postgrespro.ru", "phone": "+70254712058"}
0005433438879	48E027	0959 475854	TATYANA KOLESNIKOVA	{"phone": "+70403930271"}
0005433438880	48E027	2192 030108	VALERIYA NESTEROVA	{"phone": "+70729807455"}
0005433438881	9AEFD1	1653 403755	VALENTINA DENISOVA	{"phone": "+70539688355"}
0005433438882	9AEFD1	4221 240499	ANDREY TIMOFEEV	{"phone": "+70149991824"}
0005433438883	A9449B	2955 120836	MAKSIM KULIKOV	{"phone": "+70900870016"}
0005433438884	53A17B	3760 805895	TATYANA IVANOVA	{"email": "ivanovatatyana12051962@postgrespro.ru", "phone": "+70051117794"}
0005433438885	53A17B	1322 681096	VERA ANDREEVA	{"phone": "+70360162204"}
0005433438886	1C09F7	5402 794711	EVGENIY CHERNOV	{"phone": "+70685208216"}
0005433438887	FFD658	6671 603481	ALINA ZAKHAROVA	{"email": "alinazakharova_061960@postgrespro.ru", "phone": "+70740608898"}
0005433438888	FFD658	9124 815890	SEMEN MIRONOV	{"phone": "+70337977860"}
0005433438889	F364CC	8335 143948	MARINA BORISOVA	{"email": "borisovamarina-26011970@postgrespro.ru", "phone": "+70296356444"}
0005433438890	F364CC	2562 589707	SERGEY KUDRYASHOV	{"email": "kudryashov_s121981@postgrespro.ru", "phone": "+70655867387"}
0005433438891	A72ED3	9314 629976	RAISA ORLOVA	{"email": "orlova_raisa.091978@postgrespro.ru", "phone": "+70795003632"}
0005433438892	A72ED3	0977 630110	TATYANA TARASOVA	{"phone": "+70376386617"}
0005433438893	94A52D	7484 982407	EVGENIYA VOLKOVA	{"email": "e-volkova-02021971@postgrespro.ru", "phone": "+70881179714"}
0005433438894	051C0F	2284 955865	ALEKSANDR ROMANOV	{"phone": "+70581504600"}
0005433438895	9C8619	2100 153474	SERGEY IVANOV	{"email": "s.ivanov-1967@postgrespro.ru", "phone": "+70005828504"}
0005433438896	9C8619	8549 684072	ANASTASIYA NOVIKOVA	{"phone": "+70725674800"}
0005433438897	7F3F12	1837 634776	NADEZHDA IVANOVA	{"email": "ivanova_n17021975@postgrespro.ru", "phone": "+70480143705"}
0005433438898	7F3F12	5113 860678	ALEKSANDR BELOV	{"email": "belov-a.071972@postgrespro.ru", "phone": "+70714226613"}
0005433438899	B0809A	0330 444135	MARIYA TITOVA	{"email": "m_titova.071975@postgrespro.ru", "phone": "+70260702137"}
0005433438900	374F95	7442 216645	MARIYA AFANASEVA	{"phone": "+70703017821"}
0005433438901	374F95	9343 311070	ALEKSANDR TIKHONOV	{"email": "tikhonov.a-16061972@postgrespro.ru", "phone": "+70021017689"}
0005433438902	374F95	7064 415720	SERGEY KRASNOV	{"phone": "+70179297966"}
0005433438903	088875	6921 731538	VLADIMIR FILIPPOV	{"email": "filippov.v.011971@postgrespro.ru", "phone": "+70983562167"}
0005433438904	088875	7206 290268	ALEKSANDR POPOV	{"email": "apopov.09011971@postgrespro.ru", "phone": "+70653665313"}
0005433438905	102E78	1891 241529	OLEG BELOV	{"phone": "+70890313690"}
0005433438906	DF2B7D	3043 097528	ALEKSANDR STEPANOV	{"phone": "+70738841689"}
0005433438907	79BCCE	1150 139405	SEMEN BELOV	{"email": "semen_belov-1975@postgrespro.ru", "phone": "+70379398386"}
0005433438908	3B06EF	1962 334125	VALERIY FOMIN	{"phone": "+70504271975"}
0005433438909	D40ABB	4741 523525	ALENA KOLESNIKOVA	{"phone": "+70887457000"}
0005433438910	D40ABB	6870 285681	SVETLANA FEDOROVA	{"phone": "+70719668227"}
0005433438911	D40ABB	9367 487127	VALENTIN NIKITIN	{"phone": "+70083070545"}
0005433438912	568600	5681 078048	DANIL FROLOV	{"phone": "+70188555356"}
0005433438913	256D96	1143 532300	DARYA EGOROVA	{"phone": "+70259366300"}
0005433438914	256D96	7694 434543	SERGEY GUSEV	{"email": "sergeygusev_05071982@postgrespro.ru", "phone": "+70287526280"}
0005433438915	05920D	5701 532470	VADIM BELOV	{"email": "belov-v08071972@postgrespro.ru", "phone": "+70247384854"}
0005433438916	C8672C	2949 563860	VLADIMIR ALEKSEEV	{"phone": "+70790423196"}
0005433438917	C8672C	6771 651163	TATYANA GERASIMOVA	{"email": "t-gerasimova-031974@postgrespro.ru", "phone": "+70005262446"}
0005433438918	267093	3412 045775	VERA ALEKSEEVA	{"phone": "+70530910139"}
0005433438919	267093	5937 722819	EKATERINA SOROKINA	{"phone": "+70198068835"}
0005433438920	068CBC	1441 420970	KONSTANTIN SEMENOV	{"phone": "+70315711536"}
0005433438921	068CBC	2606 206218	ANNA KONOVALOVA	{"email": "konovalova.a.041960@postgrespro.ru", "phone": "+70363910150"}
0005433438922	56D73A	9616 024951	SERGEY MIKHAYLOV	{"phone": "+70400839477"}
0005433438923	56D73A	8010 903712	SERGEY SEMENOV	{"phone": "+70583189127"}
0005433438924	5F9857	0862 191786	NADEZHDA OSIPOVA	{"phone": "+70538781212"}
0005433438925	FA7C5C	3601 957778	KLAVDIYA ISAEVA	{"email": "isaeva_klavdiya_06061981@postgrespro.ru", "phone": "+70995362454"}
0005433438926	D39F85	1396 981195	YURIY MAKAROV	{"email": "makarov_y_08091966@postgrespro.ru", "phone": "+70736500837"}
0005433438927	D39F85	5696 780714	ELENA KALININA	{"phone": "+70429179887"}
0005433438928	1ECC7A	1791 585434	RUSLAN MOROZOV	{"email": "morozov-r.11051975@postgrespro.ru", "phone": "+70719924847"}
0005433438929	8A7C48	3196 981588	ELENA KULIKOVA	{"email": "kulikova_elena_1971@postgrespro.ru", "phone": "+70940735490"}
0005433438930	8A7C48	7838 605011	ANATOLIY EGOROV	{"email": "anatoliy-egorov101984@postgrespro.ru", "phone": "+70421062936"}
0005433438931	8A7C48	4400 955094	NATALYA KISELEVA	{"phone": "+70637483613"}
0005433438932	5C0134	9802 681970	VIKTORIYA GERASIMOVA	{"phone": "+70968504737"}
0005433438933	5C0134	1470 456090	LYUDMILA KUZMINA	{"phone": "+70030644366"}
0005433438934	EA4683	7622 523898	VLADIMIR NAUMOV	{"phone": "+70083727192"}
0005433438935	EA4683	5176 806903	VLADIMIR BORISOV	{"email": "vladimir.borisov.081968@postgrespro.ru", "phone": "+70827368203"}
0005433438936	9596A2	8154 195509	YULIYA SOKOLOVA	{"phone": "+70478860481"}
0005433438937	26D14B	2613 844371	ANDREY EGOROV	{"email": "egorov.andrey.021983@postgrespro.ru", "phone": "+70320837649"}
0005433438938	26D14B	1653 058792	EVGENIYA VOLKOVA	{"phone": "+70453886135"}
0005433438939	26D14B	4062 838898	VYACHESLAV SHEVCHENKO	{"phone": "+70993788547"}
0005433438940	BC8ABB	0442 382268	VLADIMIR IVANOV	{"phone": "+70849858251"}
0005433438941	8C309D	3777 687262	DMITRIY ILIN	{"phone": "+70814899769"}
0005433438942	DF6206	0647 445135	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey.1975@postgrespro.ru", "phone": "+70037176035"}
0005433438943	DF6206	5170 597984	BORIS KAZAKOV	{"phone": "+70843329852"}
0005433438944	A385DC	9966 174964	TATYANA ISAEVA	{"phone": "+70488924322"}
0005433438945	A47A32	6713 717018	ALEKSANDRA DENISOVA	{"phone": "+70153371550"}
0005433438946	C6ADE4	7052 778960	KAROLINA ZOTOVA	{"phone": "+70825180907"}
0005433438947	8FD6D5	1159 852900	GENNADIY AFANASEV	{"phone": "+70857036595"}
0005433438948	E263B8	2970 566431	NIKOLAY ROMANOV	{"phone": "+70173301307"}
0005433438949	E263B8	6580 855826	NIKOLAY PETROV	{"phone": "+70493731148"}
0005433438950	43B8B0	1476 286251	DANIIL MAKSIMOV	{"phone": "+70402225427"}
0005433438951	43B8B0	3935 570647	EVGENIY SCHERBAKOV	{"phone": "+70277277598"}
0005433438952	6BFBBF	1722 887697	LYUBOV SEMENOVA	{"email": "semenovalyubov-1980@postgrespro.ru", "phone": "+70228391807"}
0005433438953	8D8136	4640 063331	MARIYA MASLOVA	{"phone": "+70362908579"}
0005433438954	8D8136	0388 216006	ALEKSANDR POPOV	{"email": "popov-aleksandr.071974@postgrespro.ru", "phone": "+70862896187"}
0005433438955	294257	8106 081641	VERA NIKIFOROVA	{"phone": "+70987305573"}
0005433438956	583828	8516 012353	OLEG SIDOROV	{"email": "sidorov.o_1976@postgrespro.ru", "phone": "+70448615889"}
0005433438957	583828	3179 976969	ROMAN STEPANOV	{"email": "roman.stepanov_101980@postgrespro.ru", "phone": "+70873490270"}
0005433438958	583828	2318 858161	TAMARA KISELEVA	{"phone": "+70007268466"}
0005433438959	7DFFA0	9734 697592	SVETLANA KOZLOVA	{"phone": "+70052504749"}
0005433438960	0E3CB7	5368 099092	TATYANA KISELEVA	{"email": "t_kiseleva.1968@postgrespro.ru", "phone": "+70053555783"}
0005433438961	0E3CB7	2758 488278	NATALYA MARTYNOVA	{"phone": "+70074129316"}
0005433438962	F47F2D	3387 623743	EKATERINA KOROLEVA	{"phone": "+70255979270"}
0005433438963	DCF100	6767 943909	VLADIMIR ANDREEV	{"phone": "+70340681260"}
0005433438964	CF1866	3860 500141	MARINA GAVRILOVA	{"email": "mgavrilova1979@postgrespro.ru", "phone": "+70964574588"}
0005433438965	FF4AFB	5649 508212	ANDREY ZAKHAROV	{"phone": "+70773400896"}
0005433438966	6C5614	0778 502124	VLADIMIR SOLOVEV	{"email": "vsolovev-041971@postgrespro.ru", "phone": "+70026784901"}
0005433438967	6C5614	1351 304499	DMITRIY KUDRYASHOV	{"email": "kudryashov.dmitriy041966@postgrespro.ru", "phone": "+70695582788"}
0005433438968	E8B1B5	3320 608229	SERGEY ZAKHAROV	{"phone": "+70598868544"}
0005433438969	EAAADF	0099 274660	VALENTINA KONOVALOVA	{"phone": "+70274574663"}
0005433438970	E8E22C	8982 118943	SVETLANA KISELEVA	{"email": "kiseleva_s1970@postgrespro.ru", "phone": "+70531932777"}
0005433438971	BEEBDB	2579 931312	IGOR MATVEEV	{"phone": "+70861192840"}
0005433438972	2C64E8	8875 934404	IRINA OSIPOVA	{"email": "irina_osipova-1973@postgrespro.ru", "phone": "+70482151679"}
0005433438973	B57D27	7633 763631	GALINA MARTYNOVA	{"phone": "+70176368974"}
0005433438974	599AC5	4855 244688	ALEKSANDR VASILEV	{"phone": "+70762915130"}
0005433438975	0D45A1	5488 758805	DMITRIY DMITRIEV	{"phone": "+70177457702"}
0005433438976	46242D	1751 470299	ALEKSANDR ANTONOV	{"email": "aleksandr_antonov_15071975@postgrespro.ru", "phone": "+70507191938"}
0005433438977	C9659C	5151 281490	ROMAN TARASOV	{"email": "roman.tarasov-1972@postgrespro.ru", "phone": "+70578894016"}
0005433438978	51F034	8948 035755	LYUBOV NESTEROVA	{"email": "lyubov.nesterova-05101958@postgrespro.ru", "phone": "+70868699315"}
0005433438979	71BB8F	2031 250935	RAISA GAVRILOVA	{"phone": "+70737735901"}
0005433438980	204285	8328 173809	ALEKSANDR FEDOROV	{"email": "a.fedorov-13121967@postgrespro.ru", "phone": "+70724703103"}
0005433438981	4E9778	5251 467712	ANNA AFANASEVA	{"email": "afanaseva.anna_10021967@postgrespro.ru", "phone": "+70213065349"}
0005433438982	4E9778	2285 982944	NATALYA NAZAROVA	{"email": "nazarova-natalya06111975@postgrespro.ru", "phone": "+70078049770"}
0005433438983	321B0D	3756 182636	ANASTASIYA MALYSHEVA	{"phone": "+70656146802"}
0005433438984	66627C	3480 016892	DMITRIY STEPANOV	{"phone": "+70942060554"}
0005433438985	F03AD9	5772 850562	IRINA KONOVALOVA	{"phone": "+70524454632"}
0005433438986	F03AD9	0260 457324	ROMAN VASILEV	{"phone": "+70375582369"}
0005433438987	8381F6	1276 087488	DANIIL ZHUKOV	{"email": "zhukov_daniil031967@postgrespro.ru", "phone": "+70114535147"}
0005433438988	4F720B	8635 093845	VALERIY SMIRNOV	{"email": "vsmirnov_1978@postgrespro.ru", "phone": "+70334972837"}
0005433438989	4F720B	7450 329545	NADEZHDA VLASOVA	{"email": "nvlasova.021973@postgrespro.ru", "phone": "+70205493852"}
0005433438990	4ED066	1940 225218	FANIL KUZMIN	{"email": "kuzmin_fanil04071970@postgrespro.ru", "phone": "+70363365340"}
0005433438991	19C6AD	6334 887926	ALEKSANDR BARANOV	{"email": "baranov-a1969@postgrespro.ru", "phone": "+70141181739"}
0005433438992	A51173	1473 671717	EVGENIY PAVLOV	{"email": "evgeniy_pavlov_1964@postgrespro.ru", "phone": "+70479045592"}
0005433438993	B2B62F	3366 020637	MARIYA DANILOVA	{"phone": "+70387212490"}
0005433438994	1E7D68	8750 819963	VLADIMIR KARPOV	{"phone": "+70036444659"}
0005433438995	48FF3F	5149 283589	OLGA IVANOVA	{"phone": "+70224111254"}
0005433438996	3DD89E	5298 174477	IGOR NIKOLAEV	{"phone": "+70889195354"}
0005433438997	CE2DC2	8027 647067	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr_031963@postgrespro.ru", "phone": "+70341474477"}
0005433438998	DBEC9E	5342 642553	VALENTINA FILATOVA	{"email": "v_filatova.101977@postgrespro.ru", "phone": "+70773443764"}
0005433438999	DBEC9E	2328 861663	ANDREY BARANOV	{"email": "baranov_a-1988@postgrespro.ru", "phone": "+70059435557"}
0005433439000	9AE930	7772 139879	GALINA KRASNOVA	{"phone": "+70604221463"}
0005433439001	9AE930	3543 233552	LINAR GRIGOREV	{"phone": "+70290710237"}
0005433439002	3BFFFA	6518 406435	NIKOLAY MEDVEDEV	{"email": "medvedev-nikolay031977@postgrespro.ru", "phone": "+70191446689"}
0005433439003	D52DA2	4039 071154	ELENA KULIKOVA	{"email": "kulikovaelena-01081982@postgrespro.ru", "phone": "+70844650542"}
0005433439004	D52DA2	3547 760223	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov.31101969@postgrespro.ru", "phone": "+70680885273"}
0005433439005	B68802	6359 471261	NIKOLAY ISAEV	{"email": "isaev.nikolay1980@postgrespro.ru", "phone": "+70065092508"}
0005433439006	22DD48	1899 138324	IVAN RODIONOV	{"phone": "+70780914199"}
0005433439007	22DD48	0217 740891	NADEZHDA FROLOVA	{"email": "n-frolova-05031968@postgrespro.ru", "phone": "+70076823064"}
0005433439008	22DD48	2680 147482	NADEZHDA SOKOLOVA	{"email": "n.sokolova_04021981@postgrespro.ru", "phone": "+70313162976"}
0005433439009	A31E70	1544 054155	FAINA OSIPOVA	{"phone": "+70031068818"}
0005433439010	6904E3	2963 161094	MAKSIM ALEKSANDROV	{"phone": "+70938020198"}
0005433439011	3473CC	5518 105381	ANTON FEDOROV	{"email": "fedorova_1966@postgrespro.ru", "phone": "+70285371944"}
0005433439012	F70831	2620 419923	VLADIMIR MARTYNOV	{"phone": "+70762619880"}
0005433439013	296636	9896 237414	GALINA YAKOVLEVA	{"email": "yakovleva_galina-1982@postgrespro.ru", "phone": "+70675334062"}
0005433439014	296636	6731 130714	NINA KUZMINA	{"email": "n-kuzmina_1977@postgrespro.ru", "phone": "+70210696890"}
0005433439015	DADC3F	4549 175983	KONSTANTIN KUZNECOV	{"email": "kuznecov_konstantin_20011981@postgrespro.ru", "phone": "+70188152491"}
0005433439016	DADC3F	9607 092894	NADEZHDA EGOROVA	{"phone": "+70261170826"}
0005433439017	F085B0	0382 965240	VLADISLAV POPOV	{"email": "popov-v051969@postgrespro.ru", "phone": "+70048399280"}
0005433439018	D71B24	1129 140686	ALEKSEY SMIRNOV	{"phone": "+70318956221"}
0005433439019	D7430C	1267 333269	FAINA KUZNECOVA	{"email": "kuznecova.faina.1968@postgrespro.ru", "phone": "+70437913628"}
0005433439020	5E1932	4675 789932	GALINA ANDREEVA	{"email": "andreeva.g01091980@postgrespro.ru", "phone": "+70123113470"}
0005433439021	5E1932	5474 794830	OLGA LEBEDEVA	{"phone": "+70959476923"}
0005433439022	3E8179	8912 379930	DANIIL GUSEV	{"email": "gusev.d.1969@postgrespro.ru", "phone": "+70612864527"}
0005433439023	3E8179	3613 220104	VITALIY NAZAROV	{"phone": "+70514015671"}
0005433439024	E09491	1445 612257	VALENTINA LOGINOVA	{"phone": "+70335668951"}
0005433439025	C0BC3D	5308 617490	SERGEY MOROZOV	{"email": "smorozov_04031962@postgrespro.ru", "phone": "+70400356672"}
0005433439026	DEF748	0394 238632	OLGA VLASOVA	{"phone": "+70190591888"}
0005433439027	B265B3	6524 218238	NATALYA NIKOLAEVA	{"email": "nnikolaeva_011979@postgrespro.ru", "phone": "+70513448427"}
0005433439028	9F129E	0955 341277	MARIYA KUZNECOVA	{"email": "mariyakuznecova-1968@postgrespro.ru", "phone": "+70271781930"}
0005433439029	9F129E	1598 626440	EKATERINA NIKOLAEVA	{"phone": "+70970203654"}
0005433439030	3116A7	3316 291838	PAVEL SHEVCHENKO	{"email": "shevchenkopavel11071976@postgrespro.ru", "phone": "+70850019444"}
0005433439031	C4CCD5	2269 386627	ELENA LAZAREVA	{"phone": "+70224138768"}
0005433439032	C6A784	3938 440256	ROMAN ZHUKOV	{"email": "zhukov.r1969@postgrespro.ru", "phone": "+70301687736"}
0005433439033	4F0DB6	4755 430063	NATALYA MELNIKOVA	{"email": "melnikova_n.15051971@postgrespro.ru", "phone": "+70232487633"}
0005433439034	2E26E3	1040 408081	NIKITA KUZNECOV	{"email": "n-kuznecov_23061977@postgrespro.ru", "phone": "+70015114164"}
0005433439035	2E26E3	9114 852535	YANA DAVYDOVA	{"email": "yanadavydova.1963@postgrespro.ru", "phone": "+70375757138"}
0005433439036	F66F45	5906 610429	TATYANA NESTEROVA	{"phone": "+70650701937"}
0005433439037	22317E	3736 098874	ROMAN ZHURAVLEV	{"email": "r-zhuravlev081973@postgrespro.ru", "phone": "+70977212950"}
0005433439038	22317E	7706 127989	KRISTINA SOKOLOVA	{"email": "kristinasokolova_121975@postgrespro.ru", "phone": "+70981700146"}
0005433439039	38338D	1149 663763	OLGA TITOVA	{"phone": "+70842297462"}
0005433439040	EF5A6E	0623 788383	ALEKSANDR KUZNECOV	{"phone": "+70189622016"}
0005433439041	3C331D	9791 994688	SERGEY ROMANOV	{"email": "sergey_romanov_15041974@postgrespro.ru", "phone": "+70052547623"}
0005433439042	D331E4	5412 641185	NIKOLAY IVANOV	{"phone": "+70579005966"}
0005433439043	D15CEC	2202 581539	SERGEY RODIONOV	{"email": "s-rodionov10081972@postgrespro.ru", "phone": "+70738476540"}
0005433439044	D15CEC	6529 657676	KAMILLA FADEEVA	{"email": "fadeevak_111973@postgrespro.ru", "phone": "+70759936003"}
0005433439045	81FDF2	8675 329788	VLADIMIR GORBUNOV	{"phone": "+70440229611"}
0005433439046	527450	6184 573060	MARINA KOLESNIKOVA	{"phone": "+70481483258"}
0005433439047	737171	9146 276622	LYUBOV IVANOVA	{"email": "ivanovalyubov-14111967@postgrespro.ru", "phone": "+70686482817"}
0005433439048	737171	4241 003196	KONSTANTIN MOISEEV	{"phone": "+70006620870"}
0005433439049	0F7799	2611 378463	VERA PETROVA	{"phone": "+70394542078"}
0005433439050	656890	6120 978688	ANATOLIY FILIPPOV	{"email": "anatoliy-filippov_101956@postgrespro.ru", "phone": "+70251714769"}
0005433439051	9FEE7B	4151 294095	SERGEY MEDVEDEV	{"email": "s_medvedev-29111967@postgrespro.ru", "phone": "+70913044111"}
0005433439052	1CF76B	3789 831472	IVAN FROLOV	{"phone": "+70804032295"}
0005433439053	9FC680	5729 343578	RAISA AFANASEVA	{"phone": "+70817519244"}
0005433439054	BD8416	1404 219189	KONSTANTIN NOVIKOV	{"phone": "+70354665541"}
0005433439055	BD8416	3133 159944	ANNA PETROVA	{"email": "petrova.anna111965@postgrespro.ru", "phone": "+70783315716"}
0005433439056	7A0165	4659 417503	MAKSIM GERASIMOV	{"phone": "+70510739046"}
0005433439057	DD6E50	3952 379065	SERGEY MAKAROV	{"email": "s-makarov22111977@postgrespro.ru", "phone": "+70469795455"}
0005433439058	DD6E50	4589 497143	ZULFIYA POTAPOVA	{"email": "zpotapova_21081955@postgrespro.ru", "phone": "+70299405351"}
0005433439059	6D44E0	2350 402964	GALINA SCHERBAKOVA	{"phone": "+70000988602"}
0005433439060	22F727	3575 980485	ELENA KONDRATEVA	{"phone": "+70557908287"}
0005433439061	9A9FE6	7311 083565	ALEKSANDR SEMENOV	{"email": "semenov-a081965@postgrespro.ru", "phone": "+70214614763"}
0005433439062	9A9FE6	3957 100446	ALINA ZHUKOVA	{"email": "a_zhukova_14031968@postgrespro.ru", "phone": "+70931277490"}
0005433439063	663882	6326 404224	IVAN ISAEV	{"phone": "+70676347720"}
0005433439064	A3984A	8359 247279	EKATERINA IVANOVA	{"phone": "+70793816755"}
0005433439065	4A9CEA	9314 520005	VIKTOR GUSEV	{"phone": "+70689131958"}
0005433439066	CF55CF	2321 732779	YURIY MIKHAYLOV	{"email": "yuriy.mikhaylov_031972@postgrespro.ru", "phone": "+70101436305"}
0005433439067	A1ED55	6119 597446	NINA KRASNOVA	{"email": "krasnova_n031975@postgrespro.ru", "phone": "+70955763084"}
0005433439068	D59B50	7599 011001	IGNAT PAVLOV	{"phone": "+70435488075"}
0005433439069	D59B50	4691 903328	OLEG SIDOROV	{"email": "olegsidorov.1970@postgrespro.ru", "phone": "+70327741252"}
0005433439070	B0798F	7096 942940	YURIY VLASOV	{"phone": "+70243413458"}
0005433439071	B0798F	4605 958043	PAVEL TARASOV	{"phone": "+70104312984"}
0005433439072	B0798F	8591 130396	ELENA TARASOVA	{"phone": "+70162070301"}
0005433439073	C2B3C5	3725 330114	KLAVDIYA PAVLOVA	{"email": "pavlova.klavdiya-051963@postgrespro.ru", "phone": "+70954719337"}
0005433439074	C2B3C5	3298 106429	SVETLANA KULIKOVA	{"email": "kulikovas1966@postgrespro.ru", "phone": "+70598999161"}
0005433439075	697985	2309 346914	TATYANA ANDREEVA	{"email": "tatyana.andreeva.12101961@postgrespro.ru", "phone": "+70979255262"}
0005433439076	549AC3	1003 663961	VYACHESLAV GERASIMOV	{"email": "v.gerasimov-1970@postgrespro.ru", "phone": "+70339051399"}
0005433439077	549AC3	2553 395005	LARISA SERGEEVA	{"phone": "+70394814549"}
0005433439078	E328FD	7461 824685	SERGEY ANTONOV	{"email": "antonovs_1965@postgrespro.ru", "phone": "+70910070870"}
0005433439079	5F8EB7	7545 892355	ALEKSANDR ILIN	{"phone": "+70842625204"}
0005433439080	469992	1603 037312	NIKOLAY KUZMIN	{"email": "kuzminnikolay24111980@postgrespro.ru", "phone": "+70429890051"}
0005433439081	7DE448	9922 198936	ROMAN FILIPPOV	{"phone": "+70438191501"}
0005433439082	A6B6FD	2229 502027	ALBINA KUZNECOVA	{"email": "kuznecova_a_01041975@postgrespro.ru", "phone": "+70534868406"}
0005433439083	838FFC	0181 951885	OLGA ERMAKOVA	{"email": "ermakovaolga.021967@postgrespro.ru", "phone": "+70756584597"}
0005433439084	7157F5	1975 124492	ANNA RYABOVA	{"email": "ryabova_a.011970@postgrespro.ru", "phone": "+70054462175"}
0005433439085	834223	0393 452277	LYUBOV VOROBEVA	{"email": "vorobeva.l1966@postgrespro.ru", "phone": "+70431126989"}
0005433439086	44A73E	9431 333137	KRISTINA ANTONOVA	{"phone": "+70131943363"}
0005433439087	01CFAA	9008 212634	SVETLANA KOROLEVA	{"email": "koroleva.svetlana-1968@postgrespro.ru", "phone": "+70807269942"}
0005433439088	01CFAA	7419 163488	IGOR SEMENOV	{"phone": "+70073084206"}
0005433439089	51E13D	1056 041183	ROMAN FROLOV	{"email": "frolov.roman.10081961@postgrespro.ru", "phone": "+70955368282"}
0005433439090	51E13D	7687 689898	ARTEM IVANOV	{"email": "ivanovartem_1980@postgrespro.ru", "phone": "+70805030004"}
0005433439091	51E13D	2315 968704	ANTONINA ROMANOVA	{"phone": "+70861771443"}
0005433439092	51E13D	4470 827230	ANASTASIYA SEMENOVA	{"email": "semenova-anastasiya.1983@postgrespro.ru", "phone": "+70124496432"}
0005433439093	D6B5BA	5029 252224	ALENA IVANOVA	{"phone": "+70027296674"}
0005433439094	D6B5BA	5300 746301	VIKTOR OSIPOV	{"email": "v_osipov-1980@postgrespro.ru", "phone": "+70293171792"}
0005433439095	314EA3	4203 523756	GRIGORIY DMITRIEV	{"email": "dmitriev_g.22121976@postgrespro.ru", "phone": "+70790710044"}
0005433439096	CC7921	7067 879191	DANILA TARASOV	{"phone": "+70343840491"}
0005433439097	995895	5344 835251	NIKOLAY AFANASEV	{"phone": "+70190153378"}
0005433439098	FB8CB9	8144 222774	VALENTINA ERMAKOVA	{"phone": "+70625127181"}
0005433439099	7F87EB	3925 315356	GEORGIY SIDOROV	{"email": "g.sidorov28091962@postgrespro.ru", "phone": "+70187825447"}
0005433439100	C424D0	6757 690117	MAKAR ILIN	{"phone": "+70531830229"}
0005433439101	393245	7022 951346	ANNA BELOVA	{"phone": "+70152029692"}
0005433439102	B6139D	3323 219310	MARIYA ILINA	{"phone": "+70312370881"}
0005433439103	02AD6B	3380 476968	LIDIYA TIMOFEEVA	{"phone": "+70808494538"}
0005433439104	5B2B3B	8989 095222	ALEKSEY KUZMIN	{"phone": "+70398493424"}
0005433439105	5B2B3B	1560 721081	ARTEM POPOV	{"phone": "+70385539061"}
0005433439106	CDCB17	2877 405330	ALEKSEY DENISOV	{"email": "denisov.a.051975@postgrespro.ru", "phone": "+70065274880"}
0005433439107	C49718	1953 400111	KLARA KUZNECOVA	{"email": "kkuznecova.1966@postgrespro.ru", "phone": "+70489534819"}
0005433439108	219D82	9073 061347	DMITRIY SOROKIN	{"phone": "+70059151514"}
0005433439109	219D82	9032 670158	TATYANA FILATOVA	{"phone": "+70491570160"}
0005433439110	5AB438	1075 532481	ROZA SIDOROVA	{"email": "roza-sidorova-10011970@postgrespro.ru", "phone": "+70468041213"}
0005433439111	5BF755	8033 431290	ELIZAVETA MELNIKOVA	{"email": "melnikova_e.04031973@postgrespro.ru", "phone": "+70007456411"}
0005433439112	036ACF	5499 411610	KONSTANTIN NIKOLAEV	{"email": "konstantinnikolaev-04031969@postgrespro.ru", "phone": "+70306134872"}
0005433439113	ED4A35	9188 504596	NATALYA MIRONOVA	{"phone": "+70816210865"}
0005433439114	6C9A47	5102 817423	NINA KISELEVA	{"phone": "+70072036980"}
0005433439115	6C9A47	8818 004022	VASILIY VOROBEV	{"phone": "+70241372705"}
0005433449583	F4F5DE	5968 104688	LYUBOV MOROZOVA	{"phone": "+70406802194"}
0005433449584	F4F5DE	2722 003167	ELENA IVANOVA	{"phone": "+70955875259"}
0005433449585	1F188C	5472 136016	VALENTIN YAKOVLEV	{"email": "v.yakovlev13111966@postgrespro.ru", "phone": "+70826549268"}
0005433449586	1F188C	7277 369873	TATYANA SEMENOVA	{"email": "semenova_t-1965@postgrespro.ru", "phone": "+70382087096"}
0005433449587	52B033	7031 259471	SERGEY SERGEEV	{"email": "sergeev_s.10071969@postgrespro.ru", "phone": "+70293983375"}
0005433449588	1EC8C6	0709 399893	GENNADIY MAKAROV	{"email": "makarovgennadiy-21101981@postgrespro.ru", "phone": "+70676008726"}
0005433449589	7516BE	3407 327497	ALEKSANDR ALEKSANDROV	{"phone": "+70087031001"}
0005433449590	7452F4	0086 983289	IRINA FOMINA	{"email": "fomina_irina.10121982@postgrespro.ru", "phone": "+70385265973"}
0005433449591	2687B6	2510 576440	DANILA GAVRILOV	{"phone": "+70497710733"}
0005433449592	6787CA	8862 749175	VYACHESLAV SOROKIN	{"phone": "+70226380836"}
0005433449593	357770	4323 997050	OLGA NESTEROVA	{"phone": "+70173905392"}
0005433449594	98AEDE	4532 089638	PAVEL SOROKIN	{"email": "p.sorokin.111966@postgrespro.ru", "phone": "+70171438780"}
0005433449595	25354D	1099 559662	STEPAN SEMENOV	{"email": "s_semenov.1978@postgrespro.ru", "phone": "+70509263097"}
0005433449596	4BA10B	6741 936074	SERGEY ZAYCEV	{"phone": "+70480097848"}
0005433449597	4BA10B	5994 821828	ALEKSANDR ORLOV	{"email": "orlov_a1973@postgrespro.ru", "phone": "+70897383102"}
0005433449598	4DEEA3	0998 800654	VALENTIN FEDOROV	{"email": "valentinfedorov1971@postgrespro.ru", "phone": "+70796412469"}
0005433449599	4DEEA3	8795 849224	OLGA LUKYANOVA	{"phone": "+70247199130"}
0005433449600	A2F089	5393 779266	OLGA PETROVA	{"email": "olga-petrova021973@postgrespro.ru", "phone": "+70827382707"}
0005433449601	A2F089	6636 343285	LILIYA ANTONOVA	{"email": "liliya-antonova-101978@postgrespro.ru", "phone": "+70181087282"}
0005433449602	E2270B	9132 869841	LYUBOV KUDRYASHOVA	{"phone": "+70028959232"}
0005433449603	E2270B	2893 097882	OLGA KOLESNIKOVA	{"email": "kolesnikova_olga.121960@postgrespro.ru", "phone": "+70601250620"}
0005433449604	1ECBCA	4872 945574	SVETLANA NESTEROVA	{"email": "snesterova-091971@postgrespro.ru", "phone": "+70661428175"}
0005433449605	1ECBCA	9971 651870	VALENTINA VASILEVA	{"phone": "+70363564910"}
0005433449606	C4EAD1	3653 033172	TATYANA VOROBEVA	{"email": "vorobeva_tatyana_1977@postgrespro.ru", "phone": "+70782174458"}
0005433449607	F03DC0	2053 640551	ALEKSANDR FOMIN	{"phone": "+70443948640"}
0005433449608	9CA5EF	3529 085992	ALEKSANDR TARASOV	{"email": "tarasovaleksandr_26041975@postgrespro.ru", "phone": "+70701776205"}
0005433449609	53C7F4	0316 867397	MARINA FADEEVA	{"phone": "+70689396228"}
0005433449610	702C60	2248 682442	MARIYA NAUMOVA	{"phone": "+70020847244"}
0005433449611	0C1BE2	9246 177083	TATYANA OSIPOVA	{"email": "osipova_t.1979@postgrespro.ru", "phone": "+70185334901"}
0005433449612	2902F5	6658 717721	ANNA BELYAEVA	{"email": "a_belyaeva_1974@postgrespro.ru", "phone": "+70565458528"}
0005433449613	2902F5	3821 062828	RUSLAN GERASIMOV	{"email": "r_gerasimov1973@postgrespro.ru", "phone": "+70040410636"}
0005433449614	2902F5	3163 225065	TATYANA SOKOLOVA	{"phone": "+70656554305"}
0005433449615	668BA2	2403 429190	NATALYA FILATOVA	{"email": "natalya.filatova.051966@postgrespro.ru", "phone": "+70223273921"}
0005433449616	04D930	7186 197163	PAVEL KUZMIN	{"email": "kuzmin.p.04061965@postgrespro.ru", "phone": "+70091886277"}
0005433449617	04D930	0313 919114	MIKHAIL MOROZOV	{"phone": "+70676667501"}
0005433449618	60D0FC	5947 474276	SERGEY NAZAROV	{"email": "sergeynazarov_021966@postgrespro.ru", "phone": "+70968959882"}
0005433449619	60D0FC	8444 240391	VALERIY KUZNECOV	{"email": "kuznecovv24111966@postgrespro.ru", "phone": "+70686236408"}
0005433449620	5A915A	7314 076857	VALENTINA EGOROVA	{"phone": "+70487036930"}
0005433449621	2E803A	2214 630788	EKATERINA ZAKHAROVA	{"email": "zakharova.e1974@postgrespro.ru", "phone": "+70671178649"}
0005433449622	2FB959	2096 426724	VLADIMIR MELNIKOV	{"phone": "+70598400266"}
0005433449623	2FB959	3602 118669	SOFYA OVCHINNIKOVA	{"email": "sofya-ovchinnikova-121967@postgrespro.ru", "phone": "+70758348590"}
0005433449624	7A5296	8200 530413	VYACHESLAV MATVEEV	{"phone": "+70922692446"}
0005433449625	7A5296	7065 631589	VIKTOR NOVIKOV	{"phone": "+70234164256"}
0005433449626	058178	3059 142690	KRISTINA TARASOVA	{"email": "tarasova_k.1977@postgrespro.ru", "phone": "+70683377747"}
0005433449627	D767C7	2168 961594	RAFAIL ORLOV	{"phone": "+70053101525"}
0005433449628	3AA900	2156 080017	NINA EGOROVA	{"email": "egorovanina-09121966@postgrespro.ru", "phone": "+70732515208"}
0005433449629	171B3F	9669 003538	EKATERINA KULIKOVA	{"phone": "+70027042035"}
0005433449630	E5D68B	2104 073972	TAMARA TITOVA	{"email": "titovatamara.28111971@postgrespro.ru", "phone": "+70840440969"}
0005433449631	E5D68B	7706 873099	ALEKSANDR KUDRYASHOV	{"phone": "+70563745713"}
0005433449632	B29417	4807 970415	VYACHESLAV GERASIMOV	{"phone": "+70953383042"}
0005433449633	245C22	4689 959368	ELMIRA DANILOVA	{"email": "elmira.danilova.23011975@postgrespro.ru", "phone": "+70068080330"}
0005433449634	3A9CC5	5343 844726	OLESYA GUSEVA	{"phone": "+70946980744"}
0005433449635	3A9CC5	7823 167271	EVGENIY NIKOLAEV	{"email": "e.nikolaev-09021979@postgrespro.ru", "phone": "+70957828097"}
0005433449636	9A5089	7543 149140	DMITRIY STEPANOV	{"email": "stepanov-dmitriy.081986@postgrespro.ru", "phone": "+70756498663"}
0005433449637	9A5089	1102 160694	PLATON ILIN	{"email": "p.ilin_1977@postgrespro.ru", "phone": "+70379581916"}
0005433449638	72CB99	2791 041476	MAKSIM ZHURAVLEV	{"email": "maksim_zhuravlev1972@postgrespro.ru", "phone": "+70441179590"}
0005433449639	3249D9	5580 811583	PETR DMITRIEV	{"email": "p-dmitriev.23101964@postgrespro.ru", "phone": "+70682670102"}
0005433449640	52A645	8202 200913	ALEKSANDR MOROZOV	{"phone": "+70924381305"}
0005433449641	52A645	5649 408697	IVAN ALEKSEEV	{"phone": "+70682480322"}
0005433449642	53E8DA	4796 899113	VIKTOR POPOV	{"phone": "+70898294187"}
0005433449643	A24D58	5240 308313	ALEKSEY BARANOV	{"phone": "+70486095923"}
0005433449644	63950F	4423 567538	ROZA ANDREEVA	{"phone": "+70041487934"}
0005433449645	B12A49	6296 118669	ARTEM VASILEV	{"email": "artem_vasilev13061970@postgrespro.ru", "phone": "+70433355125"}
0005433449646	C38AEF	6084 117819	ALEKSANDR VOROBEV	{"phone": "+70035589459"}
0005433449647	5F32BF	1295 351801	SERGEY ANDREEV	{"email": "andreevs.18041971@postgrespro.ru", "phone": "+70811634235"}
0005433449648	79B96E	2719 681212	VALENTIN SHEVCHENKO	{"email": "shevchenkovalentin.011975@postgrespro.ru", "phone": "+70160563053"}
0005433449649	79B96E	4866 859094	ALEKSANDR ILIN	{"email": "ailin.041973@postgrespro.ru", "phone": "+70727204651"}
0005433449650	0CD3B9	2354 926698	VYACHESLAV NOVIKOV	{"email": "vnovikov_041970@postgrespro.ru", "phone": "+70955756173"}
0005433449651	0CD3B9	4167 199621	GENNADIY ZAYCEV	{"email": "zaycev_gennadiy.17061973@postgrespro.ru", "phone": "+70362937441"}
0005433449652	BFA2BE	0301 081085	NIKOLAY ALEKSANDROV	{"email": "n.aleksandrov-1979@postgrespro.ru", "phone": "+70627617100"}
0005433449653	11472E	7194 299906	SVETLANA STEPANOVA	{"phone": "+70668434621"}
0005433449654	801C1A	8593 964977	VERA MARTYNOVA	{"email": "vmartynova-29081981@postgrespro.ru", "phone": "+70880019091"}
0005433449655	E5E8B7	2699 959278	LYUDMILA TITOVA	{"email": "ltitova-121972@postgrespro.ru", "phone": "+70499675981"}
0005433449656	2C081F	5266 062958	VERA NAZAROVA	{"email": "v-nazarova1971@postgrespro.ru", "phone": "+70201779418"}
0005433449657	6C3775	7836 852078	OLEG PAVLOV	{"email": "o-pavlov-021981@postgrespro.ru", "phone": "+70588356880"}
0005433449658	4B0B64	6776 726568	MAKSIM SOROKIN	{"email": "sorokin_m_1974@postgrespro.ru", "phone": "+70195617226"}
0005433449659	D1E88C	0801 592254	PETR VOROBEV	{"phone": "+70807375696"}
0005433449660	D1E88C	1962 511568	VERA IVANOVA	{"email": "vera.ivanova-061983@postgrespro.ru", "phone": "+70836362577"}
0005433449661	79766E	2336 300430	SOFIYA EFIMOVA	{"phone": "+70050542700"}
0005433449662	2F6CE1	7800 185917	EKATERINA KUZNECOVA	{"phone": "+70544835550"}
0005433449663	2F6CE1	9171 943493	NADIYA MOROZOVA	{"phone": "+70744411447"}
0005433449664	71FCBB	4525 738658	YURIY MEDVEDEV	{"phone": "+70877185061"}
0005433449665	8B89E3	1707 974279	SOFYA ROMANOVA	{"phone": "+70196386003"}
0005433449666	9CC6FB	7100 658289	LARISA ZHUKOVA	{"phone": "+70749757462"}
0005433449667	11229E	2682 620062	VERA SIDOROVA	{"phone": "+70161671758"}
0005433449668	8262BC	3771 005281	VLADIMIR OSIPOV	{"phone": "+70189575687"}
0005433449669	672A7B	4095 929513	ELENA SMIRNOVA	{"email": "elena.smirnova_101965@postgrespro.ru", "phone": "+70016220144"}
0005433449670	641D4D	4588 727906	MIKHAIL GAVRILOV	{"email": "gavrilovmikhail.1969@postgrespro.ru", "phone": "+70185559163"}
0005433449671	EEE19D	4158 084795	KONSTANTIN EGOROV	{"email": "k_egorov.1966@postgrespro.ru", "phone": "+70671532573"}
0005433449672	1233AA	4536 584851	SERGEY POPOV	{"email": "sergey_popov_08111975@postgrespro.ru", "phone": "+70120584219"}
0005433449673	1233AA	5014 776999	EVGENIY TIKHONOV	{"phone": "+70362082482"}
0005433449674	35682F	6171 311214	DMITRIY MATVEEV	{"email": "matveev.d-01051987@postgrespro.ru", "phone": "+70437520428"}
0005433449675	35682F	0669 721470	ZINAIDA PAVLOVA	{"phone": "+70157734212"}
0005433449676	17B561	1443 659934	ALEKSANDR MAKAROV	{"phone": "+70805006606"}
0005433449677	CDDBEF	8438 172453	ALEKSANDR OSIPOV	{"email": "aleksandrosipov.1970@postgrespro.ru", "phone": "+70484522222"}
0005433449678	FDE7A1	2927 400869	RUSLAN KISELEV	{"phone": "+70885296262"}
0005433449679	DD9A90	9639 923897	VYACHESLAV MAKAROV	{"email": "vyacheslav_makarov-1977@postgrespro.ru", "phone": "+70056168450"}
0005433449680	8C7EE4	9036 613800	GALINA KAZAKOVA	{"email": "kazakovagalina1973@postgrespro.ru", "phone": "+70036607101"}
0005433449681	DD0699	4725 941939	SVETLANA PAVLOVA	{"phone": "+70977570766"}
0005433449682	DD0699	0732 022705	NIKOLAY BELOV	{"email": "belov.n.021972@postgrespro.ru", "phone": "+70609074264"}
0005433449683	E5E62F	2628 861212	TATYANA MELNIKOVA	{"phone": "+70000655709"}
0005433449684	6600DC	4330 382367	ANATOLIY ZAKHAROV	{"phone": "+70478535027"}
0005433449685	496B8A	9342 984008	VALERIY PETROV	{"email": "vpetrov13091972@postgrespro.ru", "phone": "+70164221804"}
0005433449686	496B8A	8229 108288	EVGENIY YAKOVLEV	{"email": "eyakovlev_1978@postgrespro.ru", "phone": "+70283279473"}
0005433449687	88D192	4178 670051	YULIYA KRASNOVA	{"email": "yuliya_krasnova-1972@postgrespro.ru", "phone": "+70803222346"}
0005433449688	88D192	5440 274545	NATALYA KRASNOVA	{"phone": "+70476019155"}
0005433449689	8A5898	3568 579417	GRIGORIY IVANOV	{"email": "givanov-11021964@postgrespro.ru", "phone": "+70144614005"}
0005433449690	8A5898	3808 497720	VLADIMIR GRIGOREV	{"email": "vladimir.grigorev041972@postgrespro.ru", "phone": "+70351063266"}
0005433449691	A4F99A	9897 029411	NIKOLAY ZAYCEV	{"email": "zaycev_nikolay-021967@postgrespro.ru", "phone": "+70677928140"}
0005433449692	A4F99A	5255 269139	FEDOR ANTONOV	{"phone": "+70884308636"}
0005433449693	49E0DD	8923 845605	ALEKSANDR NAZAROV	{"phone": "+70146635287"}
0005433449694	5D5799	2560 845294	ANASTASIYA DENISOVA	{"phone": "+70476627622"}
0005433449695	C4C542	6867 454737	VIKTOR KONOVALOV	{"email": "konovalovv.01031982@postgrespro.ru", "phone": "+70924048467"}
0005433449696	E6BA35	0189 841342	YANA ANTONOVA	{"phone": "+70735190937"}
0005433449697	BEC9AF	3414 950047	SERGEY KOROLEV	{"email": "korolev-sergey-041963@postgrespro.ru", "phone": "+70446787961"}
0005433449698	BEC9AF	0677 389998	DINA KAZAKOVA	{"phone": "+70962399395"}
0005433449699	BEC9AF	2862 379198	ANDREY IVANOV	{"email": "aivanov071974@postgrespro.ru", "phone": "+70781538426"}
0005433449700	6CCDE7	5707 182042	MIKHAIL SMIRNOV	{"phone": "+70987248426"}
0005433449701	F69E8B	9814 360639	NIKOLAY SAVELEV	{"phone": "+70206319058"}
0005433449702	974EEB	8427 544419	KSENIYA IVANOVA	{"phone": "+70159491969"}
0005433449703	0C4CA8	7698 907364	RODION KOZLOV	{"email": "kozlov.rodion-1975@postgrespro.ru", "phone": "+70767770038"}
0005433449704	D10056	3447 022115	PAVEL NAUMOV	{"phone": "+70656491415"}
0005433449705	D10056	9393 956263	ROMAN VOLKOV	{"email": "roman_volkov.1971@postgrespro.ru", "phone": "+70374732457"}
0005433449706	507E01	4040 910637	NATALIYA SMIRNOVA	{"email": "n_smirnova.091981@postgrespro.ru", "phone": "+70174639810"}
0005433449707	061D57	7466 430026	IREK GUSEV	{"phone": "+70493848662"}
0005433449708	3D1BD4	9685 754042	EKATERINA SERGEEVA	{"email": "sergeevaekaterina1978@postgrespro.ru", "phone": "+70685509666"}
0005433449709	C7AD68	3916 759244	MARINA ORLOVA	{"phone": "+70995566527"}
0005433449710	C7AD68	8359 351269	IVAN SMIRNOV	{"phone": "+70296500291"}
0005433449711	5F0375	7185 587393	MIKHAIL EGOROV	{"phone": "+70411817217"}
0005433449712	5F0375	3943 542478	ALEKSANDR VASILEV	{"email": "a.vasilev-07111976@postgrespro.ru", "phone": "+70159530500"}
0005433449713	9D269E	6564 648697	DMITRIY RODIONOV	{"email": "drodionov-20091980@postgrespro.ru", "phone": "+70139149865"}
0005433449714	30272B	8870 952762	NIKOLAY GAVRILOV	{"email": "gavrilov.nikolay.24071977@postgrespro.ru", "phone": "+70752880117"}
0005433449715	30272B	2713 233142	IRINA KOROLEVA	{"email": "i-koroleva30051971@postgrespro.ru", "phone": "+70578042622"}
0005433449716	30272B	3752 835653	NIKOLAY BARANOV	{"phone": "+70944116080"}
0005433449717	AD03B7	2841 443213	ALEKSANDR ZAYCEV	{"phone": "+70960340603"}
0005433449718	FA1774	1035 897905	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov-1977@postgrespro.ru", "phone": "+70959510207"}
0005433449719	09864E	2132 024893	VLADIMIR NAUMOV	{"email": "naumov-vladimir-07101976@postgrespro.ru", "phone": "+70157224161"}
0005433449720	09864E	5323 810790	ELENA ZAYCEVA	{"phone": "+70708383484"}
0005433449721	7A6EB3	7404 623180	NATALYA MELNIKOVA	{"email": "natalya_melnikova29071978@postgrespro.ru", "phone": "+70831827268"}
0005433449722	F78125	2604 990354	VITALIY TARASOV	{"email": "vtarasov_1970@postgrespro.ru", "phone": "+70406823023"}
0005433449723	F78125	7454 887069	BORIS BONDARENKO	{"email": "borisbondarenko-051988@postgrespro.ru", "phone": "+70918396397"}
0005433449724	0E037E	0301 563296	ILDUS TIKHONOV	{"email": "i-tikhonov19111959@postgrespro.ru", "phone": "+70304182902"}
0005433449725	504E15	0945 654175	DMITRIY KONOVALOV	{"phone": "+70905414766"}
0005433449726	4793FD	6231 848201	OKSANA ANTONOVA	{"phone": "+70925154353"}
0005433449727	0826CC	3764 282937	NURLAN VOLKOV	{"email": "volkov_nurlan-23051968@postgrespro.ru", "phone": "+70354208872"}
0005433449728	85063A	4789 903923	NATALYA ZHURAVLEVA	{"email": "n-zhuravleva-081979@postgrespro.ru", "phone": "+70407852878"}
0005433449729	85063A	6749 274472	ALEKSANDR EGOROV	{"phone": "+70099610377"}
0005433449730	FCEBEB	2003 388104	ALEKSANDR YAKOVLEV	{"email": "ayakovlev111971@postgrespro.ru", "phone": "+70151273257"}
0005433449731	78A66A	3920 656062	NINA IVANOVA	{"email": "n.ivanova24071973@postgrespro.ru", "phone": "+70849561586"}
0005433449732	B46E4F	2350 732156	MARIYA ZOTOVA	{"email": "mariya-zotova1967@postgrespro.ru", "phone": "+70537590373"}
0005433449733	307E2D	5667 030448	DENIS NIKITIN	{"phone": "+70630984478"}
0005433449734	994F4D	2957 640565	PAVEL ORLOV	{"phone": "+70532752572"}
0005433449735	994F4D	6223 799614	DMITRIY POPOV	{"email": "dpopov-03061972@postgrespro.ru", "phone": "+70784015750"}
0005433449736	87AD1B	6010 291276	ELENA KONOVALOVA	{"email": "e-konovalova13091978@postgrespro.ru", "phone": "+70783702325"}
0005433449737	CE21E0	4326 165375	MIKHAIL TIMOFEEV	{"email": "timofeev.m-30061965@postgrespro.ru", "phone": "+70542288104"}
0005433449738	CE21E0	7398 087567	GALINA ILINA	{"phone": "+70432356513"}
0005433449739	AEE26C	2618 341450	RAFAEL PAVLOV	{"email": "rpavlov_111961@postgrespro.ru", "phone": "+70316699032"}
0005433449740	D7EB56	5218 788527	YURIY MAKAROV	{"phone": "+70727489607"}
0005433449741	7C7026	3264 465940	ALEKSEY KULIKOV	{"email": "kulikov.aleksey.05111968@postgrespro.ru", "phone": "+70542756904"}
0005433449742	7A0DC8	6390 277247	ANDREY ANTONOV	{"email": "antonovandrey101986@postgrespro.ru", "phone": "+70691490534"}
0005433449743	BA4B5F	9749 652659	YULIYA BORISOVA	{"email": "yuliya.borisova-1967@postgrespro.ru", "phone": "+70329404877"}
0005433449744	BA4B5F	1663 157227	EVGENIYA TITOVA	{"email": "titova_evgeniya1968@postgrespro.ru", "phone": "+70518873448"}
0005433449745	F7F54A	3024 335305	ALEKSANDR MIRONOV	{"email": "amironov07071973@postgrespro.ru", "phone": "+70362903409"}
0005433449746	F7F54A	2716 509192	ANZHELIKA VOROBEVA	{"phone": "+70345647883"}
0005433449747	B0799F	4821 709124	MARIYA TARASOVA	{"phone": "+70045509005"}
0005433449748	B0799F	0221 489002	KONSTANTIN OSIPOV	{"phone": "+70748553318"}
0005433449749	F81DAE	0453 594752	VITALIY CHERNOV	{"phone": "+70325668347"}
0005433449750	7142D2	9002 696727	ALEKSANDR SAVELEV	{"phone": "+70183868621"}
0005433449751	C811C3	2953 173483	LARISA KULIKOVA	{"email": "larisa_kulikova1977@postgrespro.ru", "phone": "+70739796230"}
0005433449752	C811C3	4591 801174	OLGA SIDOROVA	{"email": "olga_sidorova111974@postgrespro.ru", "phone": "+70604980930"}
0005433449753	F06AF4	6666 737934	KLAVDIYA ROMANOVA	{"phone": "+70448687131"}
0005433449754	ADFA46	5057 862523	SERGEY TIKHONOV	{"email": "s-tikhonov_1972@postgrespro.ru", "phone": "+70396631433"}
0005433449755	B056AA	8963 692302	DANILA DENISOV	{"phone": "+70649634218"}
0005433449756	B056AA	1301 699759	DENIS MAKAROV	{"phone": "+70008352627"}
0005433449757	D5F148	4305 884226	TATYANA KUZNECOVA	{"email": "t_kuznecova-09031975@postgrespro.ru", "phone": "+70850394379"}
0005433449758	1A60D0	1530 694660	DENIS MARTYNOV	{"phone": "+70738457221"}
0005433449759	170519	6089 451358	MARIYA FEDOROVA	{"email": "mariya_fedorova-111979@postgrespro.ru", "phone": "+70499183075"}
0005433449760	170519	7590 609382	ELENA ANTONOVA	{"email": "antonovae_24031961@postgrespro.ru", "phone": "+70595688681"}
0005433449761	9BB06B	1431 182967	STANISLAV AFANASEV	{"email": "afanasevstanislav03051972@postgrespro.ru", "phone": "+70575863387"}
0005433449762	16839B	0300 734135	MARINA GORBUNOVA	{"email": "gorbunova-marina-1976@postgrespro.ru", "phone": "+70976252526"}
0005433449763	4A821E	6476 055083	TATYANA FROLOVA	{"phone": "+70220341896"}
0005433449764	F16FFA	1261 354412	LARISA SEMENOVA	{"phone": "+70925927947"}
0005433449765	209522	4776 287825	YULIYA POTAPOVA	{"email": "yuliya-potapova_111969@postgrespro.ru", "phone": "+70826907646"}
0005433449766	209522	7751 518193	ALEKSEY ALEKSEEV	{"email": "a.alekseev-01041977@postgrespro.ru", "phone": "+70719638209"}
0005433449767	AC388F	0852 220816	LYUDMILA VLASOVA	{"email": "vlasova_lyudmila-11071981@postgrespro.ru", "phone": "+70666584717"}
0005433449768	E96554	0719 633138	RAISA GORBUNOVA	{"phone": "+70385633310"}
0005433449769	E96554	2368 119274	ARTEM NAUMOV	{"email": "a.naumov_14071960@postgrespro.ru", "phone": "+70776973091"}
0005433449770	E96554	2440 858605	ANDREY FILIPPOV	{"phone": "+70360024969"}
0005433449771	282EB2	1425 983988	VLADIMIR PETROV	{"email": "petrovvladimir-1970@postgrespro.ru", "phone": "+70252114303"}
0005433449772	880481	6702 515847	IGOR ZAYCEV	{"phone": "+70670280318"}
0005433449773	880481	6641 862136	SERGEY KUZNECOV	{"phone": "+70985718869"}
0005433449774	880481	5507 458564	IGOR KOROLEV	{"phone": "+70574701100"}
0005433449775	787823	3238 833907	TATYANA SEMENOVA	{"email": "semenova-t16121975@postgrespro.ru", "phone": "+70226691090"}
0005433449776	9EB368	7971 471148	VIKTOR EGOROV	{"phone": "+70653831529"}
0005433449777	1AB500	4708 644002	DMITRIY GAVRILOV	{"phone": "+70974426691"}
0005433449778	0DD2E6	0841 847930	VLADIMIR VOROBEV	{"email": "vorobev-v061979@postgrespro.ru", "phone": "+70910090619"}
0005433449779	0DD2E6	9115 877035	MADINA PAVLOVA	{"email": "pavlova-m-021970@postgrespro.ru", "phone": "+70905208836"}
0005433449780	D9AD1E	6952 138854	OLEG KUZMIN	{"email": "kuzmin_oleg.26061965@postgrespro.ru", "phone": "+70052542675"}
0005433449781	09B061	5341 158899	LYUDMILA KOMAROVA	{"phone": "+70244749750"}
0005433449782	09B061	8821 513760	TAMARA KUZNECOVA	{"email": "kuznecova_tamara-1973@postgrespro.ru", "phone": "+70696527910"}
0005433449783	927FC4	8258 530974	TAISIYA EGOROVA	{"email": "taisiyaegorova_1973@postgrespro.ru", "phone": "+70142685730"}
0005433449784	927FC4	0039 084805	ELENA KOROLEVA	{"phone": "+70205733244"}
0005433449785	AE75A9	6715 541605	MAKSIM ROMANOV	{"email": "maksim.romanov_1956@postgrespro.ru", "phone": "+70718007032"}
0005433449786	419D63	6481 216423	NIKOLAY NAZAROV	{"phone": "+70649941878"}
0005433449787	E0DD09	4832 558496	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva021967@postgrespro.ru", "phone": "+70011225762"}
0005433449788	7D0623	7188 349637	ALEKSANDR ALEKSANDROV	{"phone": "+70354310178"}
0005433449789	EBEB59	5196 379690	RAISA LAZAREVA	{"email": "r-lazareva.1973@postgrespro.ru", "phone": "+70565012763"}
0005433449790	0DA18F	0307 873960	ALINA YUDINA	{"email": "a_yudina041962@postgrespro.ru", "phone": "+70798475471"}
0005433449791	4C00CF	0528 484227	ARTEM NOVIKOV	{"phone": "+70968077422"}
0005433449792	4C00CF	0857 828735	IRINA EGOROVA	{"email": "egorova_irina121973@postgrespro.ru", "phone": "+70336502748"}
0005433449793	B3E202	5176 388507	YULIYA KOLESNIKOVA	{"phone": "+70622889881"}
0005433449794	E38AB4	9637 574251	LILIYA ZAKHAROVA	{"email": "l_zakharova16111967@postgrespro.ru", "phone": "+70526931112"}
0005433449795	84951A	8010 961183	ANASTASIYA NESTEROVA	{"email": "nesterovaanastasiya-09061972@postgrespro.ru", "phone": "+70862453341"}
0005433449796	05A268	3677 125561	NATALYA NIKITINA	{"email": "nnikitina_06011976@postgrespro.ru", "phone": "+70163120153"}
0005433449797	418A01	1307 803766	ALEKSANDR PETROV	{"email": "a-petrov-1976@postgrespro.ru", "phone": "+70007706386"}
0005433449798	F7B04B	2392 847359	DMITRIY KUZNECOV	{"email": "kuznecov-d.041973@postgrespro.ru", "phone": "+70477724622"}
0005433449799	7EB022	1997 285577	OLGA TARASOVA	{"phone": "+70031796555"}
0005433449800	8EABDC	4176 746976	ALEKSANDRA CHERNOVA	{"email": "chernova.aleksandra.041972@postgrespro.ru", "phone": "+70845054723"}
0005433449801	62FFE2	3246 382536	VALERIY ROMANOV	{"phone": "+70115084991"}
0005433449802	4517D6	7917 095383	LEV MOROZOV	{"email": "morozov_l1980@postgrespro.ru", "phone": "+70013755505"}
0005433449803	B14BF4	9424 121513	MARINA IVANOVA	{"phone": "+70463448585"}
0005433449804	B14BF4	0384 155246	OLGA NOVIKOVA	{"phone": "+70606811455"}
0005433449805	E778BE	2138 882277	ANNA ZHUKOVA	{"email": "zhukovaanna-081973@postgrespro.ru", "phone": "+70738933883"}
0005433449806	4AD636	9905 286305	LYUBOV SMIRNOVA	{"email": "l.smirnova.101981@postgrespro.ru", "phone": "+70058703216"}
0005433449807	96AC4A	8162 701251	VIKTORIYA POPOVA	{"email": "vpopova-071980@postgrespro.ru", "phone": "+70489419077"}
0005433449808	96AC4A	5450 142094	NATALYA NIKITINA	{"email": "nikitina-n.1967@postgrespro.ru", "phone": "+70158719308"}
0005433449809	0F76F4	9175 538007	VYACHESLAV IVANOV	{"phone": "+70727957121"}
0005433449810	33DF48	2667 277189	LARISA KUZNECOVA	{"phone": "+70877035393"}
0005433449811	630D33	3263 594816	EKATERINA CHERNOVA	{"email": "echernova.1967@postgrespro.ru", "phone": "+70547460906"}
0005433449812	467E66	8199 389649	MATVEY EGOROV	{"phone": "+70288050970"}
0005433449813	7A04C3	4575 542248	DENIS IVANOV	{"email": "ivanov_d-30121967@postgrespro.ru", "phone": "+70976428506"}
0005433449814	810C1C	9844 182446	NINA POPOVA	{"phone": "+70382539120"}
0005433449815	810C1C	7946 738161	SERGEY SEMENOV	{"email": "sergey-semenov_051976@postgrespro.ru", "phone": "+70195561009"}
0005433449816	1A9B81	8072 858162	NADEZHDA KALININA	{"phone": "+70728996817"}
0005433449817	2680CB	4328 088205	ALEKSEY YAKOVLEV	{"phone": "+70155022005"}
0005433449818	2680CB	7313 140374	ALEKSANDR FEDOTOV	{"phone": "+70687583685"}
0005433449819	AB698B	6848 475895	NADEZHDA EGOROVA	{"phone": "+70112478175"}
0005433449820	AB698B	9940 624293	EVGENIYA SEMENOVA	{"email": "semenova-e.1971@postgrespro.ru", "phone": "+70345142055"}
0005433449821	F10B1E	5758 291079	YAROSLAVA KUDRYASHOVA	{"email": "ykudryashova23041968@postgrespro.ru", "phone": "+70462175354"}
0005433449822	F10B1E	1937 062047	ALENA NIKITINA	{"phone": "+70064923089"}
0005433449823	A5A34D	5203 500803	NIKOLAY EGOROV	{"email": "nikolay-egorov-1976@postgrespro.ru", "phone": "+70148916035"}
0005433449824	A5A34D	3435 412884	DARYA PAVLOVA	{"phone": "+70141480538"}
0005433449825	4FCDF4	4733 385322	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-1979@postgrespro.ru", "phone": "+70596712438"}
0005433449826	4755EF	0697 703009	EVGENIY ZAKHAROV	{"phone": "+70847659019"}
0005433449827	7AADAA	2864 343603	ANNA MALYSHEVA	{"email": "malysheva-a_20031971@postgrespro.ru", "phone": "+70803094230"}
0005433449828	A8B5FE	5678 580306	EMILIYA MARTYNOVA	{"email": "martynova.emiliya-071979@postgrespro.ru", "phone": "+70782901345"}
0005433449829	A8B5FE	5029 533972	NATALYA LAZAREVA	{"email": "natalya-lazareva.1973@postgrespro.ru", "phone": "+70246168704"}
0005433449830	84A5AA	8103 437524	LIDIYA ZHURAVLEVA	{"phone": "+70618757905"}
0005433449831	B33673	3400 592328	VALERIY ZAYCEV	{"email": "vzaycev-13051967@postgrespro.ru", "phone": "+70395478870"}
0005433449832	0317DE	5672 702035	VALENTINA ALEKSANDROVA	{"email": "valeksandrova.1984@postgrespro.ru", "phone": "+70470608154"}
0005433449833	BA2CC7	4212 464384	IRINA EGOROVA	{"email": "egorova_irina_11081975@postgrespro.ru", "phone": "+70660031490"}
0005433449834	BA2CC7	5573 716379	ALEKSEY SOKOLOV	{"phone": "+70141919940"}
0005433449835	DE86A7	2970 278593	LYUBOV VASILEVA	{"phone": "+70154831567"}
0005433449836	DE86A7	6775 155869	VIKTORIYA IVANOVA	{"email": "v.ivanova_27021979@postgrespro.ru", "phone": "+70399533707"}
0005433449837	983589	0475 268558	OLGA MAKAROVA	{"phone": "+70787350160"}
0005433449838	983589	6736 769082	TAMARA MELNIKOVA	{"phone": "+70706856181"}
0005433449839	1206F5	9739 680265	OLEG ILIN	{"phone": "+70687357088"}
0005433449840	3B58DE	9921 746343	DMITRIY KONOVALOV	{"email": "konovalov-dmitriy_16091964@postgrespro.ru", "phone": "+70694105904"}
0005433449841	879FF3	4557 066374	SERGEY SEMENOV	{"email": "ssemenov1966@postgrespro.ru", "phone": "+70331438135"}
0005433449842	879FF3	1103 980621	NIKOLAY MARTYNOV	{"phone": "+70797180720"}
0005433449843	87DD00	2425 489903	LYUBOV KOZLOVA	{"email": "kozlova.l07031981@postgrespro.ru", "phone": "+70424906888"}
0005433449844	42F5F7	2582 344943	VLADISLAV BELOV	{"phone": "+70621899941"}
0005433449845	FBA8CF	5241 262003	MARGARITA TARASOVA	{"email": "tarasovamargarita.1984@postgrespro.ru", "phone": "+70166315802"}
0005433449846	5884EB	9975 980847	KIRILL ZAKHAROV	{"phone": "+70521201951"}
0005433449847	0AAEAA	5849 006233	EKATERINA OSIPOVA	{"email": "osipovaekaterina_28061976@postgrespro.ru", "phone": "+70505566468"}
0005433449848	226356	7291 162127	OLGA MOROZOVA	{"email": "morozova_o1967@postgrespro.ru", "phone": "+70329057213"}
0005433449849	226356	7827 965959	TAKHIR AFANASEV	{"phone": "+70385050880"}
0005433449850	A950BC	0414 277625	EKATERINA KONOVALOVA	{"email": "e.konovalova-14121972@postgrespro.ru", "phone": "+70881696061"}
0005433449851	5A03AA	0494 580234	RUSLAN MOISEEV	{"phone": "+70350166839"}
0005433449852	5A03AA	3677 923530	EVDOKIYA VASILEVA	{"email": "e_vasileva1973@postgrespro.ru", "phone": "+70541075377"}
0005433449853	0FA063	5821 941790	GALINA ILINA	{"phone": "+70320883986"}
0005433449854	0FA063	2391 980102	IRINA VASILEVA	{"email": "irina-vasileva-071969@postgrespro.ru", "phone": "+70612316852"}
0005433449855	C65FDB	0510 423406	IRINA CHERNOVA	{"email": "chernova_irina-1963@postgrespro.ru", "phone": "+70165360196"}
0005433449856	FBA2DC	6182 102318	NIKOLAY TARASOV	{"phone": "+70863002979"}
0005433449857	FBA2DC	7068 671202	IGOR KUZMIN	{"email": "kuzmin-igor.17071966@postgrespro.ru", "phone": "+70257164302"}
0005433449858	520320	6199 684757	LYUBOV PETROVA	{"email": "petrova_l.17101971@postgrespro.ru", "phone": "+70698193691"}
0005433449859	E7AACA	5777 261157	ALEKSANDR MAKAROV	{"email": "makarova_12051975@postgrespro.ru", "phone": "+70551470233"}
0005433449860	E7AACA	2992 641616	MARIYA ALEKSEEVA	{"phone": "+70132278263"}
0005433449861	D56676	4197 260786	VIKTOR ZAYCEV	{"email": "viktorzaycev_1977@postgrespro.ru", "phone": "+70393605756"}
0005433449862	5CDF23	8639 954127	ANDREY KUZNECOV	{"phone": "+70632811769"}
0005433449863	CDFC4E	1792 210171	NATALYA MOROZOVA	{"email": "morozovanatalya-041967@postgrespro.ru", "phone": "+70356249007"}
0005433449864	6F798E	1172 175647	ANDREY ALEKSANDROV	{"email": "andrey-aleksandrov09031974@postgrespro.ru", "phone": "+70502892555"}
0005433449865	CFF08C	7215 931956	MARIYA TARASOVA	{"phone": "+70807707713"}
0005433449866	CFF08C	3865 382094	NIKITA PAVLOV	{"phone": "+70309105657"}
0005433449867	AC9A72	4923 167259	EVGENIY SERGEEV	{"phone": "+70407032379"}
0005433449868	C6E4EC	3869 139774	DANILA FEDOROV	{"email": "fedorov_danila.1973@postgrespro.ru", "phone": "+70418937423"}
0005433449869	D4D8E3	6570 590609	MIKHAIL KOROLEV	{"email": "korolev.m.031976@postgrespro.ru", "phone": "+70991156531"}
0005433449870	69CD29	5905 187956	DARINA BORISOVA	{"phone": "+70804394202"}
0005433449871	97D0CA	3031 305879	IRINA NAZAROVA	{"phone": "+70727100519"}
0005433449872	97D0CA	8884 297963	VALERIYA MAKAROVA	{"phone": "+70933388197"}
0005433449873	AE0637	2225 452215	LYUBOV KALININA	{"phone": "+70879521828"}
0005433449874	7A3B87	5309 885167	NATALYA KARPOVA	{"phone": "+70731072190"}
0005433449875	7A3B87	3787 076900	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov26121975@postgrespro.ru", "phone": "+70026199629"}
0005433449876	AD07EC	0523 449213	NATALIYA SIDOROVA	{"phone": "+70424360642"}
0005433449877	5E2841	2203 601402	NATALYA MALYSHEVA	{"email": "n_malysheva_22081965@postgrespro.ru", "phone": "+70916444256"}
0005433449878	5E2841	7936 603689	LYUDMILA ROMANOVA	{"phone": "+70545036529"}
0005433449879	8E82C8	6613 686715	ANASTASIYA OSIPOVA	{"email": "a.osipova_1970@postgrespro.ru", "phone": "+70336735616"}
0005433449880	778EE6	4037 977618	VIKTOR KUZNECOV	{"email": "v.kuznecov1973@postgrespro.ru", "phone": "+70531627646"}
0005433449881	E93A51	3065 295371	TATYANA FEDOROVA	{"email": "fedorova-t.25111969@postgrespro.ru", "phone": "+70633347699"}
0005433449882	57E581	1673 808057	ANTON FOMIN	{"phone": "+70075667475"}
0005433449883	57E581	9329 429615	SERGEY KUZNECOV	{"email": "kuznecov_sergey16071976@postgrespro.ru", "phone": "+70799797464"}
0005433449884	7C3A08	3970 773227	ELENA MOROZOVA	{"email": "e_morozova_08071960@postgrespro.ru", "phone": "+70851438539"}
0005433449885	F6AF27	2497 571603	BORIS ABRAMOV	{"email": "abramov.b_1969@postgrespro.ru", "phone": "+70638962126"}
0005433449886	1750E4	7654 178720	DINARA NOVIKOVA	{"email": "d_novikova.031973@postgrespro.ru", "phone": "+70788843355"}
0005433449887	A8438A	4817 487066	SERGEY MIKHAYLOV	{"email": "sergey-mikhaylov1970@postgrespro.ru", "phone": "+70235087507"}
0005433449888	A8438A	0502 025261	NINA VASILEVA	{"email": "nina_vasileva_1967@postgrespro.ru", "phone": "+70362183806"}
0005433449889	410B77	0272 162900	VYACHESLAV ALEKSEEV	{"phone": "+70087899341"}
0005433449890	AB0B3B	2208 407051	EKATERINA KOVALEVA	{"email": "kovalevaekaterina-1972@postgrespro.ru", "phone": "+70923324361"}
0005433449891	29AE9C	5969 612017	ANNA ORLOVA	{"email": "orlovaanna011973@postgrespro.ru", "phone": "+70032537095"}
0005433449892	7479B0	3755 291912	IVAN SOLOVEV	{"phone": "+70073402052"}
0005433449893	7479B0	4853 656590	ANTON ZAYCEV	{"phone": "+70324592311"}
0005433449894	B42E8B	6776 858858	NATALYA YAKOVLEVA	{"email": "yakovlevanatalya091969@postgrespro.ru", "phone": "+70001577249"}
0005433449895	86ED50	9642 073100	GALINA SEMENOVA	{"email": "semenova-galina1962@postgrespro.ru", "phone": "+70541330516"}
0005433449896	86ED50	6215 905212	RUSLAN BELOV	{"phone": "+70221146998"}
0005433449897	F50894	7270 825986	GALINA POLYAKOVA	{"email": "galina.polyakova031969@postgrespro.ru", "phone": "+70028044388"}
0005433449898	F4CD07	3465 749310	IGOR GRIGOREV	{"phone": "+70280340879"}
0005433449899	F4CD07	3516 679791	NADEZHDA ANISIMOVA	{"email": "nadezhda_anisimova.081979@postgrespro.ru", "phone": "+70292073592"}
0005433449900	4800C3	7967 163831	NADEZHDA KISELEVA	{"phone": "+70534108715"}
0005433449901	ABDDFA	2727 668965	DINARA ZAKHAROVA	{"phone": "+70561933490"}
0005433449902	F1D4EF	6830 403508	MARINA MIRONOVA	{"phone": "+70879843329"}
0005433449903	E361EF	9345 875414	OLGA PETROVA	{"phone": "+70425597093"}
0005433449904	E361EF	3124 029700	ALENA MIKHAYLOVA	{"phone": "+70544218557"}
0005433449905	C90F3C	4694 205644	OLGA ARKHIPOVA	{"email": "arkhipova-olga-091967@postgrespro.ru", "phone": "+70215044508"}
0005433449906	B87A69	8332 688028	EVGENIYA ANDREEVA	{"phone": "+70335000620"}
0005433449907	B87A69	4569 205008	NATALYA ALEKSANDROVA	{"email": "n_aleksandrova_051976@postgrespro.ru", "phone": "+70971224243"}
0005433449908	3A28E9	5292 715372	ELMIRA MIKHAYLOVA	{"phone": "+70702949267"}
0005433449909	3A28E9	9728 704032	EGOR ANDREEV	{"email": "eandreev-121967@postgrespro.ru", "phone": "+70635985367"}
0005433449910	3A28E9	3947 181039	ELENA MOISEEVA	{"email": "moiseeva_e-22071972@postgrespro.ru", "phone": "+70935929956"}
0005433449911	7BF7D5	5782 364858	ANATOLIY IVANOV	{"email": "ivanovanatoliy_1983@postgrespro.ru", "phone": "+70390292355"}
0005433449912	7BF7D5	7071 059348	ALEKSEY ZAYCEV	{"email": "zaycev-aleksey_24061964@postgrespro.ru", "phone": "+70421085934"}
0005433449913	8A91E6	5996 558754	ANDREY GRIGOREV	{"email": "andreygrigorev30091974@postgrespro.ru", "phone": "+70821341183"}
0005433449914	CB7772	8725 212739	ALEKSANDR SMIRNOV	{"phone": "+70816876193"}
0005433449915	7E753F	3932 054022	ALEKSANDR ZAKHAROV	{"email": "zakharova.071980@postgrespro.ru", "phone": "+70955495891"}
0005433449916	0F3827	4280 508364	YAROSLAV ANDREEV	{"phone": "+70638801656"}
0005433449917	0F3827	7231 329607	ANNA BOGDANOVA	{"email": "bogdanova-a-1984@postgrespro.ru", "phone": "+70934654959"}
0005433449918	1A0991	6731 614279	VLADIMIR POPOV	{"phone": "+70660069417"}
0005433449919	1A0991	9820 149394	SERGEY SEMENOV	{"email": "sergey-semenov.011966@postgrespro.ru", "phone": "+70045334858"}
0005433449920	1A0991	2317 917419	NADEZHDA DMITRIEVA	{"email": "nadezhda.dmitrieva_121974@postgrespro.ru", "phone": "+70012190065"}
0005433449921	280178	4646 424303	VIKTOR KULIKOV	{"email": "vkulikov081985@postgrespro.ru", "phone": "+70374840250"}
0005433449922	20E5EC	7148 844410	ELENA ANTONOVA	{"phone": "+70619489206"}
0005433449923	0ED4AD	6640 306688	TAISIYA GUSEVA	{"email": "gusevataisiya.1975@postgrespro.ru", "phone": "+70468308234"}
0005433449924	0ED4AD	7781 529101	RAFAIL VASILEV	{"phone": "+70031553196"}
0005433449925	565630	9252 091808	ANDREY VASILEV	{"email": "vasilev_andrey_05041972@postgrespro.ru", "phone": "+70690502921"}
0005433449926	0CEF96	3371 133821	GALINA KOROLEVA	{"phone": "+70176591178"}
0005433449927	0CEF96	9401 204862	ALEKSANDR KUZMIN	{"email": "akuzmin1966@postgrespro.ru", "phone": "+70596869215"}
0005433449928	6E4C70	4537 662471	NIKOLAY NOVIKOV	{"email": "nikolaynovikov.061975@postgrespro.ru", "phone": "+70481637134"}
0005433449929	6D96D4	9815 773311	ELENA ORLOVA	{"email": "e-orlova_091977@postgrespro.ru", "phone": "+70835232198"}
0005433449930	6D96D4	2579 715835	VALERIY ORLOV	{"email": "orlov_valeriy-111971@postgrespro.ru", "phone": "+70268519189"}
0005433449931	4B920C	0325 295574	NINA TARASOVA	{"email": "tarasova.n_1978@postgrespro.ru", "phone": "+70312905534"}
0005433449932	550967	5615 744648	IRINA ZAKHAROVA	{"email": "zakharovairina111965@postgrespro.ru", "phone": "+70239363613"}
0005433449933	B19BC9	3257 964617	ZINAIDA MELNIKOVA	{"phone": "+70402272993"}
0005433449934	991C02	3771 141773	ALEKSEY MOROZOV	{"email": "morozovaleksey.1964@postgrespro.ru", "phone": "+70291028442"}
0005433449935	991C02	2857 483992	ANDREY NIKOLAEV	{"email": "nikolaevandrey_16031974@postgrespro.ru", "phone": "+70374612626"}
0005433449936	177D68	7187 046096	ANATOLIY FEDOROV	{"phone": "+70667028159"}
0005433449937	177D68	8908 128380	OLEG KRASNOV	{"phone": "+70379194542"}
0005433449938	EEC70B	4416 522827	ALEKSANDR ABRAMOV	{"email": "abramov.a_15091973@postgrespro.ru", "phone": "+70668288394"}
0005433449939	A725C9	8492 212851	NINA KUZMINA	{"email": "nina_kuzmina_1969@postgrespro.ru", "phone": "+70560255065"}
0005433449940	A725C9	2004 837186	LYUBOV KISELEVA	{"phone": "+70390242506"}
0005433449941	2F01B5	7869 410509	IRINA POLYAKOVA	{"email": "polyakova.irina.30051982@postgrespro.ru", "phone": "+70202869149"}
0005433449942	E6F4B3	9450 626009	MIKHAIL NOVIKOV	{"phone": "+70490311996"}
0005433449943	22FD86	0289 999972	ANNA PAVLOVA	{"email": "pavlova-a_051968@postgrespro.ru", "phone": "+70952410103"}
0005433449944	22FD86	3462 855657	VLADIMIR PETROV	{"email": "v.petrov_25011968@postgrespro.ru", "phone": "+70305613290"}
0005433449945	ACC011	1382 770637	ANDREY VLASOV	{"email": "vlasova.07011980@postgrespro.ru", "phone": "+70875921257"}
0005433449946	ACC011	8879 877845	ALEKSANDR ILIN	{"email": "ilin-a.1969@postgrespro.ru", "phone": "+70532204760"}
0005433449947	ACC011	2753 227608	OLEG SOROKIN	{"email": "sorokin.oleg-26011976@postgrespro.ru", "phone": "+70484762829"}
0005433449948	8C0344	1713 232281	NIKOLAY MAKSIMOV	{"phone": "+70155292837"}
0005433449949	DE9219	7325 328826	NADEZHDA ANISIMOVA	{"email": "nadezhda_anisimova1980@postgrespro.ru", "phone": "+70436473923"}
0005433449950	19988B	0047 922375	ALEKSANDR MIRONOV	{"phone": "+70629030966"}
0005433449951	232A94	9680 504183	RIMA YAKOVLEVA	{"phone": "+70401097599"}
0005433449952	232A94	9863 732062	DMITRIY MELNIKOV	{"email": "d_melnikov111965@postgrespro.ru", "phone": "+70680624906"}
0005433449953	F434CF	2386 900218	VLADIMIR SHEVCHENKO	{"phone": "+70602918662"}
0005433449954	45B49B	0417 825425	VALENTINA SEMENOVA	{"email": "v.semenova-1976@postgrespro.ru", "phone": "+70953424534"}
0005433449955	B744EC	0448 120580	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov101967@postgrespro.ru", "phone": "+70574896985"}
0005433449956	B8A48E	2567 777253	DENIS POPOV	{"phone": "+70732022156"}
0005433449957	820F23	2891 845742	VLADIMIR NOVIKOV	{"email": "novikov-v_121966@postgrespro.ru", "phone": "+70027120675"}
0005433449958	CFA7E1	2056 884126	DMITRIY YAKOVLEV	{"phone": "+70858669342"}
0005433449959	E8A68A	9249 114483	VERA LEBEDEVA	{"email": "lebedevav.1968@postgrespro.ru", "phone": "+70823168792"}
0005433449960	A091C4	2004 545003	GALINA TARASOVA	{"phone": "+70893378943"}
0005433449961	A778AE	7111 154748	SERGEY GORBUNOV	{"email": "s.gorbunov.11021973@postgrespro.ru", "phone": "+70883331019"}
0005433449962	0696C4	4138 393128	ANTON SMIRNOV	{"phone": "+70902926025"}
0005433449963	0696C4	5852 515968	GENNADIY NIKOLAEV	{"phone": "+70230355949"}
0005433449964	3B8AC2	1349 753431	ANAIT NAUMOVA	{"phone": "+70590571517"}
0005433449965	39282F	9338 778716	DENIS FOMIN	{"phone": "+70544737436"}
0005433449966	28C2A1	6729 551657	NADEZHDA NAZAROVA	{"email": "nnazarova1969@postgrespro.ru", "phone": "+70499823065"}
0005433449967	28C2A1	6577 031230	SERGEY MIKHAYLOV	{"email": "mikhaylov-sergey_011984@postgrespro.ru", "phone": "+70318449103"}
0005433449968	61C336	5589 184258	VLADISLAV NAUMOV	{"phone": "+70718478238"}
0005433449969	C613A9	9315 303855	SOFYA MALYSHEVA	{"email": "smalysheva1966@postgrespro.ru", "phone": "+70709673018"}
0005433449970	C613A9	0355 602666	ARTEM ZAYCEV	{"email": "zaycevartem_041970@postgrespro.ru", "phone": "+70879011678"}
0005433449971	84E14F	7072 196957	SERGEY OSIPOV	{"email": "sergey-osipov101973@postgrespro.ru", "phone": "+70917485161"}
0005433449972	E31084	5225 622414	VALERIY POPOV	{"email": "valeriypopov1970@postgrespro.ru", "phone": "+70544088551"}
0005433449973	0D1968	6547 797609	SERGEY POPOV	{"phone": "+70097814463"}
0005433449974	E3B7A6	7983 906406	SERGEY YAKOVLEV	{"email": "sergey_yakovlev_1967@postgrespro.ru", "phone": "+70985279574"}
0005433449975	DEF2C1	0112 270289	ALEKSEY KUZNECOV	{"phone": "+70486031602"}
0005433449976	DCEAF0	6170 442045	TAMARA MOROZOVA	{"phone": "+70012131060"}
0005433449977	305004	1066 802959	ANTONINA ILINA	{"phone": "+70539161497"}
0005433449978	305004	7105 325273	NADEZHDA ZOTOVA	{"phone": "+70319331867"}
0005433449979	3A7F56	8652 822075	EVGENIYA GORBUNOVA	{"phone": "+70628035118"}
0005433449980	1644D2	6363 923335	VASILIY VOROBEV	{"phone": "+70476765585"}
0005433449981	1644D2	8191 698653	NINA TIKHONOVA	{"phone": "+70518693421"}
0005433449982	708CCF	6185 816891	ALEKSANDRA ILINA	{"email": "ilinaa_04061978@postgrespro.ru", "phone": "+70261917934"}
0005433449983	708CCF	8081 795704	VALERIY ZAYCEV	{"phone": "+70738759705"}
0005433449984	708CCF	5086 658796	ALSU EFREMOVA	{"email": "alsu_efremova.1975@postgrespro.ru", "phone": "+70504787371"}
0005433449985	C0FC5D	7868 364806	NATALYA RYABOVA	{"email": "ryabovan-051964@postgrespro.ru", "phone": "+70483405703"}
0005433449986	C0FC5D	3649 994358	ELENA TIKHONOVA	{"email": "elenatikhonova_1972@postgrespro.ru", "phone": "+70076249314"}
0005433449987	2E444B	5979 959495	VALENTINA ALEKSANDROVA	{"email": "aleksandrova-valentina.1976@postgrespro.ru", "phone": "+70172545397"}
0005433449988	1A345D	0244 099892	IRINA KULIKOVA	{"phone": "+70737207605"}
0005433449989	964186	7151 519909	VALENTINA ZHUKOVA	{"email": "valentina-zhukova.121982@postgrespro.ru", "phone": "+70393902086"}
0005433449990	330F83	2372 347051	GALINA SOROKINA	{"phone": "+70949558352"}
0005433449991	59F724	6870 099288	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay_011972@postgrespro.ru", "phone": "+70831217969"}
0005433449992	AAA64E	1611 852170	MARGARITA MOISEEVA	{"email": "m-moiseeva_29091969@postgrespro.ru", "phone": "+70610527342"}
0005433449993	8AEAD5	3897 165237	IVAN ROMANOV	{"email": "i-romanov.071975@postgrespro.ru", "phone": "+70124907511"}
0005433449994	EFE6EE	3669 227893	YAROSLAV KULIKOV	{"phone": "+70066823918"}
0005433449995	EFE6EE	1983 433033	ANNA FROLOVA	{"email": "anna_frolova1976@postgrespro.ru", "phone": "+70822644295"}
0005433449996	17B55B	0834 765330	DENIS MAKAROV	{"email": "makarov.d_1960@postgrespro.ru", "phone": "+70903011634"}
0005433449997	17B55B	3337 060591	ELENA MALYSHEVA	{"phone": "+70867582575"}
0005433449998	2F429D	3330 212175	YURIY KARPOV	{"phone": "+70330943163"}
0005433449999	1020B9	6394 989109	ANDREY SCHERBAKOV	{"phone": "+70456555908"}
0005433450000	0230C2	4038 552407	OLEG DMITRIEV	{"phone": "+70715192358"}
0005433450001	BA9FA9	0999 834290	NIKOLAY PETROV	{"email": "petrov.nikolay_081982@postgrespro.ru", "phone": "+70839900868"}
0005433450002	BA9FA9	5941 302034	IGOR ALEKSEEV	{"phone": "+70648900966"}
0005433450003	579EFD	5838 621312	EGOR NIKOLAEV	{"phone": "+70630104123"}
0005433450004	1DCC2D	5537 141326	MAKAR MAKAROV	{"email": "makarmakarov-1978@postgrespro.ru", "phone": "+70592094632"}
0005433450005	A0289E	7204 473412	NIKOLAY MIKHAYLOV	{"phone": "+70726217670"}
0005433450006	FB25F8	4912 992727	SERGEY CHERNOV	{"email": "s-chernov1973@postgrespro.ru", "phone": "+70113471885"}
0005433450007	FB25F8	4926 886982	ZULFIYA DMITRIEVA	{"email": "dmitrieva_z.1985@postgrespro.ru", "phone": "+70162889203"}
0005433450008	44C6E0	7982 672210	GALINA SEMENOVA	{"email": "semenova_g.121978@postgrespro.ru", "phone": "+70731099024"}
0005433450009	44C6E0	0048 772576	VIKTOR BONDARENKO	{"phone": "+70839922787"}
0005433450010	39A9B1	8276 818656	ALEKSEY SHEVCHENKO	{"email": "shevchenko.aleksey-121967@postgrespro.ru", "phone": "+70438467705"}
0005433450011	39A9B1	4919 039512	ALEKSANDR ALEKSEEV	{"email": "a_alekseev_121969@postgrespro.ru", "phone": "+70499882195"}
0005433450012	C3885D	7823 948682	MIKHAIL KUZNECOV	{"email": "m.kuznecov-1977@postgrespro.ru", "phone": "+70128921426"}
0005433450013	685D5D	1530 822563	MIKHAIL ISAEV	{"phone": "+70339498783"}
0005433450014	C04EBB	1406 214674	ANNA NIKITINA	{"email": "a.nikitina.051972@postgrespro.ru", "phone": "+70274921919"}
0005433450015	1A9872	9418 441584	NATALIYA DAVYDOVA	{"email": "davydova.n_1969@postgrespro.ru", "phone": "+70279459101"}
0005433450016	3BB148	7514 181480	MARIYA ALEKSANDROVA	{"phone": "+70048575316"}
0005433450017	A79F04	9612 381769	ELENA KUZNECOVA	{"email": "elena.kuznecova-1961@postgrespro.ru", "phone": "+70310703942"}
0005433450018	A79F04	9061 287173	EVGENIY KOROLEV	{"phone": "+70930801258"}
0005433450019	44CA65	7237 657545	ALEKSANDR SOROKIN	{"email": "a-sorokin_1964@postgrespro.ru", "phone": "+70582816218"}
0005433450020	1DB8FF	7546 806618	IRINA OSIPOVA	{"email": "osipova.i-19061973@postgrespro.ru", "phone": "+70111285982"}
0005433450021	C9AA93	1848 585434	ELENA PETROVA	{"phone": "+70865203851"}
0005433450022	39B52D	9982 514595	IRINA PETROVA	{"email": "irina-petrova_23061979@postgrespro.ru", "phone": "+70501776866"}
0005433450023	F90722	9503 546466	ANASTASIYA KUZNECOVA	{"phone": "+70198359381"}
0005433450024	087DC5	2606 615808	IRAIDA IVANOVA	{"phone": "+70464314476"}
0005433450025	614CED	8709 692755	KIRILL STEPANOV	{"email": "stepanovkirill_1974@postgrespro.ru", "phone": "+70251228824"}
0005433450026	888CFE	5640 251709	ILGIZ ORLOV	{"phone": "+70820053138"}
0005433450027	888CFE	7735 247730	VERA FEDOROVA	{"email": "verafedorova03061974@postgrespro.ru", "phone": "+70609316880"}
0005433450028	E63E94	6415 424739	VALENTINA NIKOLAEVA	{"email": "nikolaeva.valentina041970@postgrespro.ru", "phone": "+70418356636"}
0005433450029	A3CC4F	5540 098779	SERGEY BORISOV	{"phone": "+70980011736"}
0005433450030	D34F18	3819 844024	EGOR TIKHONOV	{"phone": "+70430516518"}
0005433450031	D34F18	3788 604613	SERGEY KUZMIN	{"email": "sergey-kuzmin_02011974@postgrespro.ru", "phone": "+70027380157"}
0005433450032	071D9B	5488 811266	DIANA GAVRILOVA	{"phone": "+70173179035"}
0005433450033	0B6D29	3550 907436	ALEKSANDRA BELYAEVA	{"email": "belyaeva_aleksandra.1971@postgrespro.ru", "phone": "+70284764614"}
0005433450034	3D1A3C	3849 606073	ELENA KOLESNIKOVA	{"email": "elena_kolesnikova-21051973@postgrespro.ru", "phone": "+70314438438"}
0005433450035	37B3EA	8920 290670	VLADIMIR ANTONOV	{"phone": "+70930596365"}
0005433450036	37B3EA	2338 850791	MIKHAIL KULIKOV	{"phone": "+70684562807"}
0005433450037	E906BC	1889 756146	VIKTORIYA KUZNECOVA	{"email": "kuznecova_v.1963@postgrespro.ru", "phone": "+70150473578"}
0005433450094	411AD2	2919 850024	NADEZHDA VLASOVA	{"phone": "+70825936980"}
0005433450038	1454FD	1248 916395	KIRILL VASILEV	{"email": "k-vasilev_03061963@postgrespro.ru", "phone": "+70160357608"}
0005433450039	E31E2E	6053 814124	EDUARD NOVIKOV	{"phone": "+70622316422"}
0005433450040	E2DDAF	3525 383828	EGOR KISELEV	{"phone": "+70539499768"}
0005433450041	215F91	6283 078775	OLGA KUZNECOVA	{"email": "kuznecova-olga-1971@postgrespro.ru", "phone": "+70627891272"}
0005433450042	E9182F	6671 576037	SVETLANA GRISHINA	{"phone": "+70540878414"}
0005433450043	656FAB	0481 781991	ARTEM GUSEV	{"email": "gusev-a.04101981@postgrespro.ru", "phone": "+70222299511"}
0005433450044	AA0B18	0130 643001	VADIM VOROBEV	{"phone": "+70204782965"}
0005433450045	234C6B	9717 951635	OLGA ANDREEVA	{"phone": "+70214573870"}
0005433450046	22B521	5292 622158	VYACHESLAV KUZNECOV	{"email": "kuznecovv_121969@postgrespro.ru", "phone": "+70707413154"}
0005433450047	AD003E	6327 675843	GALINA MAKSIMOVA	{"email": "maksimovagalina1983@postgrespro.ru", "phone": "+70418039895"}
0005433450048	AD003E	6701 503765	VALENTINA POPOVA	{"phone": "+70974442513"}
0005433450049	3A7F82	6892 213695	MIKHAIL SCHERBAKOV	{"email": "mikhail.scherbakov_03011966@postgrespro.ru", "phone": "+70776755165"}
0005433450050	3A7F82	7793 176262	VIKTOR SOLOVEV	{"email": "solovevviktor-19031971@postgrespro.ru", "phone": "+70245100798"}
0005433450051	3A7F82	0978 085641	LYUBOV GORBUNOVA	{"email": "lyubov.gorbunova11031968@postgrespro.ru", "phone": "+70391198911"}
0005433450052	69276B	3183 072589	VLADIMIR MELNIKOV	{"phone": "+70089938138"}
0005433450053	754AB5	9098 783152	LYUDMILA KOZLOVA	{"phone": "+70689569097"}
0005433450054	2E1B7D	8993 597830	OLEG VASILEV	{"phone": "+70502866901"}
0005433450055	2E1B7D	3542 325413	IRINA MEDVEDEVA	{"email": "i-medvedeva_30101967@postgrespro.ru", "phone": "+70049852382"}
0005433450056	77A7B1	1643 935273	VALENTINA MOROZOVA	{"email": "valentina.morozova.1971@postgrespro.ru", "phone": "+70023874949"}
0005433450057	77A7B1	7026 968109	VIKTOR DAVYDOV	{"email": "davydov_viktor_1978@postgrespro.ru", "phone": "+70768748313"}
0005433450058	EE267B	5929 065319	OLEG SMIRNOV	{"phone": "+70023457607"}
0005433450059	EE267B	6995 049309	YURIY ZAKHAROV	{"phone": "+70342416677"}
0005433450060	6F67A0	5267 626982	DMITRIY POPOV	{"email": "popovdmitriy051961@postgrespro.ru", "phone": "+70403894639"}
0005433450061	EFC139	0038 970400	EVGENIY ZAYCEV	{"email": "evgeniy.zaycev-24051975@postgrespro.ru", "phone": "+70145229444"}
0005433450062	EFC139	4294 951162	ANTON EGOROV	{"email": "anton_egorov-061977@postgrespro.ru", "phone": "+70066911411"}
0005433450063	5844B7	2388 079353	VITALIY VOLKOV	{"phone": "+70073787098"}
0005433450064	FC594C	1799 734936	SANIYA VOLKOVA	{"email": "saniya_volkova.1971@postgrespro.ru", "phone": "+70062865761"}
0005433450065	5E4203	4848 532234	GALINA AFANASEVA	{"email": "afanaseva_galina071967@postgrespro.ru", "phone": "+70980118867"}
0005433450066	05BF0E	8620 972078	TATYANA CHERNOVA	{"email": "tatyana-chernova-081978@postgrespro.ru", "phone": "+70790527523"}
0005433450067	05BF0E	0925 253924	MARIYA EFIMOVA	{"phone": "+70765675289"}
0005433450068	29FEC5	4425 406560	ALEKSANDR PETROV	{"phone": "+70399337717"}
0005433450069	E2D920	9382 274176	IRINA MIRONOVA	{"email": "imironova_1965@postgrespro.ru", "phone": "+70681084030"}
0005433450070	E2D920	7529 450127	ANDREY KRASNOV	{"email": "krasnova.071969@postgrespro.ru", "phone": "+70045138388"}
0005433450071	B3E131	6005 374786	EVGENIY SOKOLOV	{"phone": "+70432232821"}
0005433450072	350768	4592 929606	ALBINA LOGINOVA	{"email": "a-loginova.16091966@postgrespro.ru", "phone": "+70286901811"}
0005433450073	350768	7882 836574	GALINA KUZNECOVA	{"phone": "+70898248082"}
0005433450074	66DEE4	7299 420404	SERGEY STEPANOV	{"email": "sergey_stepanov_091976@postgrespro.ru", "phone": "+70086705303"}
0005433450075	E9C558	8179 099242	YURIY ZAYCEV	{"email": "zaycevy_1967@postgrespro.ru", "phone": "+70027096784"}
0005433450076	A0CAD6	3824 478572	VALERIYA KUZMINA	{"phone": "+70742011524"}
0005433450077	5831E4	4864 557059	LYUDMILA DAVYDOVA	{"email": "davydova_l_24101986@postgrespro.ru", "phone": "+70952581655"}
0005433450078	4A3D2F	6365 684813	EKATERINA YAKOVLEVA	{"phone": "+70976025591"}
0005433450079	E129AE	7475 565934	MIKHAIL SAVELEV	{"email": "savelev.m1970@postgrespro.ru", "phone": "+70087818611"}
0005433450080	EC14A3	7360 506129	EKATERINA ZHURAVLEVA	{"phone": "+70986256208"}
0005433450081	C01237	4396 542050	SVETLANA IVANOVA	{"phone": "+70355194492"}
0005433450082	7619FF	0452 282789	TATYANA ORLOVA	{"phone": "+70212487847"}
0005433450083	A336C4	2846 655080	DENIS BORISOV	{"email": "borisov_denis01121973@postgrespro.ru", "phone": "+70912478179"}
0005433450084	A336C4	3485 970835	LIDIYA MASLOVA	{"phone": "+70805382096"}
0005433450085	91B602	6482 553640	ALEKSEY MELNIKOV	{"phone": "+70869384381"}
0005433450086	6B035F	1214 095169	MARIYA KOVALEVA	{"email": "kovaleva-mariya.1975@postgrespro.ru", "phone": "+70194749157"}
0005433450087	AB4A0A	9726 065545	ANDREY KOZLOV	{"email": "andrey-kozlov.05121977@postgrespro.ru", "phone": "+70322097785"}
0005433450088	AB4A0A	4677 209812	YURIY IVANOV	{"phone": "+70086771909"}
0005433450089	AB4A0A	8340 860537	VASILIY FEDOTOV	{"phone": "+70034847590"}
0005433450090	0F380C	1823 996653	MARIYA RODIONOVA	{"phone": "+70150347439"}
0005433450091	0D50C7	1865 990221	DMITRIY SOROKIN	{"email": "sorokind_30031981@postgrespro.ru", "phone": "+70527192131"}
0005433450092	0D50C7	3220 040510	NATALYA KOLESNIKOVA	{"phone": "+70000279391"}
0005433450093	4A52A6	2211 230528	MAKSIM MOROZOV	{"email": "morozov-maksim_21091969@postgrespro.ru", "phone": "+70518587868"}
0005433450095	411AD2	4520 442619	EKATERINA KUZNECOVA	{"phone": "+70582002015"}
0005433450096	4359FA	2000 620760	SERGEY SOKOLOV	{"phone": "+70949453918"}
0005433450097	4359FA	7947 419245	VLADISLAV BELOV	{"phone": "+70350900495"}
0005433450098	819891	4946 838899	VIKTOR PAVLOV	{"phone": "+70359178366"}
0005433450099	78FDFA	1758 264295	TAMARA BELOVA	{"email": "belova.tamara021970@postgrespro.ru", "phone": "+70112969053"}
0005433450100	97AE74	5099 342056	MARIYA NAUMOVA	{"email": "m_naumova1965@postgrespro.ru", "phone": "+70439050230"}
0005433450101	1D502A	7323 570102	MAKSIM DENISOV	{"phone": "+70394785330"}
0005433450102	B5BBAE	5352 716252	VASILIY PAVLOV	{"phone": "+70600791315"}
0005433450103	7C59D2	1850 313751	ILYA SOKOLOV	{"phone": "+70995171090"}
0005433450104	8228A2	0260 654868	MARIYA DENISOVA	{"email": "denisovamariya20061973@postgrespro.ru", "phone": "+70929741718"}
0005433450105	4E5743	8298 193489	IGOR SMIRNOV	{"phone": "+70600022224"}
0005433450106	821D87	6852 535181	VIKTOR SOROKIN	{"email": "viktor.sorokin-21051976@postgrespro.ru", "phone": "+70042238476"}
0005433450107	B40CF9	3478 427305	VYACHESLAV TARASOV	{"phone": "+70510811128"}
0005433450108	B40CF9	4092 312185	OLGA DANILOVA	{"phone": "+70591793310"}
0005433450109	A13537	3532 491889	ANDREY PETROV	{"email": "petrov.andrey-1965@postgrespro.ru", "phone": "+70718290108"}
0005433450110	CB66DA	1164 993095	OLGA BELYAEVA	{"email": "belyaevao_07011980@postgrespro.ru", "phone": "+70598751542"}
0005433450111	7F3742	0833 512077	EKATERINA SCHERBAKOVA	{"email": "scherbakova.ekaterina_051975@postgrespro.ru", "phone": "+70152222027"}
0005433450112	51B259	5090 990905	SERGEY FROLOV	{"phone": "+70874291793"}
0005433450113	AFF493	7340 179402	ALENA OVCHINNIKOVA	{"phone": "+70917517561"}
0005433450114	AFF493	5295 952708	ILYA VOROBEV	{"email": "i_vorobev_1964@postgrespro.ru", "phone": "+70827245781"}
0005433450115	3E5696	8540 008616	TIMUR MOROZOV	{"email": "t_morozov_1973@postgrespro.ru", "phone": "+70930672979"}
0005433450116	F182E5	2690 575429	MAKSIM ALEKSEEV	{"email": "malekseev-10081965@postgrespro.ru", "phone": "+70041795640"}
0005433450117	CA28CA	5915 854451	TAISIYA NAZAROVA	{"phone": "+70000202197"}
0005433450118	CA28CA	6741 305586	VLADIMIR ILIN	{"phone": "+70502387456"}
0005433450119	BB6149	8182 772772	YURIY KUZNECOV	{"phone": "+70901229081"}
0005433450120	909349	3643 546950	TATYANA SAVELEVA	{"phone": "+70959597734"}
0005433450121	3FC7F5	0983 274649	ZINAIDA PAVLOVA	{"phone": "+70606673628"}
0005433450122	D76D3D	1329 064699	DENIS KAZAKOV	{"email": "d-kazakov_26081981@postgrespro.ru", "phone": "+70100694783"}
0005433450123	275818	6556 979600	YURIY SOKOLOV	{"phone": "+70117366464"}
0005433450124	275818	2246 085783	VYACHESLAV SEMENOV	{"phone": "+70106203672"}
0005433450125	6B367B	7499 358143	ALEKSEY KONOVALOV	{"phone": "+70661071329"}
0005433450126	66BE37	2049 085138	ILYA MELNIKOV	{"phone": "+70423192053"}
0005433450294	2FC159	6111 527617	ELENA KOROLEVA	{"phone": "+70258766753"}
0005433450127	66BE37	3245 367794	ALENA BORISOVA	{"email": "borisova_alena011968@postgrespro.ru", "phone": "+70142589317"}
0005433450128	D2DB62	1714 556543	EVGENIY ISAEV	{"email": "e.isaev_1975@postgrespro.ru", "phone": "+70617393779"}
0005433450129	EEF2EC	7996 507979	ELENA DENISOVA	{"email": "edenisova.081970@postgrespro.ru", "phone": "+70180765295"}
0005433450130	6E052F	7445 985332	SERGEY KUDRYASHOV	{"phone": "+70814625891"}
0005433450131	CA91AC	7390 507371	OLGA SIDOROVA	{"email": "sidorova-o.101966@postgrespro.ru", "phone": "+70433972861"}
0005433450132	2F5D18	2549 722857	EKATERINA MAKSIMOVA	{"email": "e_maksimova29071966@postgrespro.ru", "phone": "+70264918521"}
0005433450133	F92092	5890 118142	MAKSIM SAVELEV	{"phone": "+70377887280"}
0005433450134	B8DC23	1089 012109	KLAVDIYA GAVRILOVA	{"phone": "+70591470778"}
0005433450135	205F89	7372 281503	NATALYA IVANOVA	{"phone": "+70360453134"}
0005433450136	2EC8AD	2885 026616	LIDIYA ANTONOVA	{"email": "lantonova-1980@postgrespro.ru", "phone": "+70436868541"}
0005433450137	3945CF	7132 846305	MARIYA MAKSIMOVA	{"phone": "+70721455534"}
0005433450138	3FDCAA	6317 152437	MIKHAIL SOKOLOV	{"email": "mikhail_sokolov_02051969@postgrespro.ru", "phone": "+70909300920"}
0005433450139	1DEBE0	2657 455927	ELENA ZAKHAROVA	{"phone": "+70363865425"}
0005433450140	1DEBE0	5741 721045	VERONIKA KOVALEVA	{"phone": "+70230740509"}
0005433450141	6229A5	9042 339747	VALENTINA DAVYDOVA	{"email": "v.davydova_1970@postgrespro.ru", "phone": "+70726669221"}
0005433450142	50B08E	1383 793435	NIKOLAY VOLKOV	{"phone": "+70777928481"}
0005433450143	50B08E	0984 058765	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.10051966@postgrespro.ru", "phone": "+70923452775"}
0005433450144	1DCAC4	1534 622506	MIKHAIL SHEVCHENKO	{"phone": "+70021308007"}
0005433450145	FCCEB2	2111 404981	RAFAIL FOMIN	{"phone": "+70452768894"}
0005433450146	FCCEB2	1250 292919	LYUDMILA FEDOROVA	{"phone": "+70173049896"}
0005433450147	FCCEB2	8345 830504	NIKOLAY KISELEV	{"email": "kiselevnikolay22081976@postgrespro.ru", "phone": "+70038159750"}
0005433450148	9AF776	6373 004396	ALLA ZAYCEVA	{"phone": "+70615557658"}
0005433450149	AC5FB8	6521 771077	ANASTASIYA DMITRIEVA	{"email": "dmitrieva_a.051973@postgrespro.ru", "phone": "+70869212268"}
0005433450150	9306C9	9656 218975	NATALYA FOMINA	{"email": "natalyafomina_061979@postgrespro.ru", "phone": "+70937600914"}
0005433450151	9306C9	7820 134779	ELENA PAVLOVA	{"email": "pavlova_e.021978@postgrespro.ru", "phone": "+70487936095"}
0005433450152	9306C9	3986 930315	MATVEY FROLOV	{"phone": "+70969964619"}
0005433450153	4C48BA	1236 901704	IRINA STEPANOVA	{"email": "stepanova.irina_021970@postgrespro.ru", "phone": "+70881746491"}
0005433450154	70525F	8974 389902	GENNADIY ZAKHAROV	{"email": "gennadiy.zakharov.20041972@postgrespro.ru", "phone": "+70758400110"}
0005433450155	278605	9480 975191	SERGEY MOISEEV	{"email": "moiseev-s.1975@postgrespro.ru", "phone": "+70879998383"}
0005433450156	A1A938	9229 230221	ALEKSANDR ZAYCEV	{"email": "a.zaycev.16011978@postgrespro.ru", "phone": "+70428913885"}
0005433450157	B96427	3005 038560	YANA AFANASEVA	{"email": "afanaseva_yana_1969@postgrespro.ru", "phone": "+70050478637"}
0005433450158	B96427	5425 910615	EVGENIYA SERGEEVA	{"email": "evgeniya-sergeeva27111977@postgrespro.ru", "phone": "+70986127962"}
0005433450159	094A84	4235 450307	ARSENIY DAVYDOV	{"email": "davydov.arseniy_06071969@postgrespro.ru", "phone": "+70140949243"}
0005433450160	5CC722	4373 970498	DANIL ZAKHAROV	{"phone": "+70420384208"}
0005433450161	164121	7968 768944	LEONID SIDOROV	{"phone": "+70940749683"}
0005433450162	164121	8631 073044	TATYANA ZHUKOVA	{"email": "zhukovatatyana_021976@postgrespro.ru", "phone": "+70431090508"}
0005433450163	EA3C39	9003 185924	SVETLANA ANISIMOVA	{"email": "anisimova_svetlana_1985@postgrespro.ru", "phone": "+70417790367"}
0005433450164	ECE297	7718 445946	ANDREY BELOV	{"email": "belov_andrey.05051959@postgrespro.ru", "phone": "+70494750222"}
0005433450165	ECE297	9087 384096	IVAN EGOROV	{"phone": "+70715272987"}
0005433450166	62C7E9	1481 009506	LEV BORISOV	{"email": "borisov.l1961@postgrespro.ru", "phone": "+70534944376"}
0005433450167	726176	4205 086723	SVETLANA IVANOVA	{"email": "ivanova-s-071972@postgrespro.ru", "phone": "+70283456441"}
0005433450168	726176	3989 209984	INNA GUSEVA	{"email": "guseva-inna_11091975@postgrespro.ru", "phone": "+70942309654"}
0005433450169	BACD4E	2083 602972	ANNA FILATOVA	{"phone": "+70549458894"}
0005433450170	BACD4E	8007 704702	ANDREY KUZNECOV	{"email": "kuznecovandrey-25051978@postgrespro.ru", "phone": "+70259857951"}
0005433450171	39969D	9439 231084	ELENA KAZAKOVA	{"email": "kazakova_e-1973@postgrespro.ru", "phone": "+70100803555"}
0005433450172	96A04F	5860 255167	ANTONINA MAKAROVA	{"email": "antonina_makarova_18121966@postgrespro.ru", "phone": "+70180199081"}
0005433450173	A4FB20	4479 932926	SERGEY MIRONOV	{"phone": "+70989871346"}
0005433450174	A4FB20	7883 113658	VYACHESLAV SERGEEV	{"email": "sergeevvyacheslav-29091975@postgrespro.ru", "phone": "+70235017157"}
0005433450175	85D41F	3016 878591	KSENIYA GORBUNOVA	{"phone": "+70517480411"}
0005433450176	A58910	6927 098974	VIKTOR DMITRIEV	{"phone": "+70491646815"}
0005433450177	B8E175	1446 599036	DANIL NAZAROV	{"phone": "+70658584095"}
0005433450178	B8E175	4957 759897	VALERIYA ALEKSEEVA	{"email": "alekseevavaleriya-1975@postgrespro.ru", "phone": "+70024195725"}
0005433450179	69BB57	2241 797682	OLGA BOGDANOVA	{"email": "bogdanova.o.1971@postgrespro.ru", "phone": "+70358130674"}
0005433450180	69BB57	1907 240438	NADEZHDA VOLKOVA	{"phone": "+70744626199"}
0005433450181	69BB57	1941 596509	RUSLAN GUSEV	{"email": "gusev_r_1962@postgrespro.ru", "phone": "+70574944345"}
0005433450182	04E232	2872 838099	ALEKSEY FROLOV	{"email": "alekseyfrolov16111970@postgrespro.ru", "phone": "+70718545571"}
0005433450183	29234D	7570 362315	DMITRIY KONOVALOV	{"phone": "+70162067991"}
0005433450184	2B4FDE	5618 631593	EKATERINA VASILEVA	{"email": "evasileva-28081977@postgrespro.ru", "phone": "+70991888973"}
0005433450185	D81001	0789 637150	POLINA ILINA	{"phone": "+70370295791"}
0005433450186	542AB2	7416 613208	LEONID SOKOLOV	{"email": "sokolov.leonid-041961@postgrespro.ru", "phone": "+70298416651"}
0005433450187	542AB2	7705 364813	ZINAIDA GERASIMOVA	{"email": "gerasimova-zinaida081975@postgrespro.ru", "phone": "+70134875989"}
0005433450188	542AB2	5130 003719	IVAN SMIRNOV	{"email": "smirnovivan.25111968@postgrespro.ru", "phone": "+70267089470"}
0005433450189	4E4F2A	4689 458864	MARINA IVANOVA	{"email": "ivanova_m_19081983@postgrespro.ru", "phone": "+70684749309"}
0005433450190	80D32C	9920 068878	LARISA IVANOVA	{"phone": "+70747397897"}
0005433450191	AF7787	5135 773919	ANATOLIY MATVEEV	{"phone": "+70797885921"}
0005433450192	CD901C	1037 585347	SERGEY TIKHONOV	{"phone": "+70614073439"}
0005433450193	1CD4A7	1072 069731	VALENTINA KISELEVA	{"email": "v.kiseleva021976@postgrespro.ru", "phone": "+70075075721"}
0005433450194	8463EE	4892 283884	VASILIY GAVRILOV	{"email": "gavrilov_v_031978@postgrespro.ru", "phone": "+70342573769"}
0005433450195	FC3F41	0926 503848	TATYANA KONDRATEVA	{"phone": "+70920969550"}
0005433450196	62E598	1063 196991	OLGA ZAKHAROVA	{"email": "zakharova_olga-071967@postgrespro.ru", "phone": "+70957256737"}
0005433450197	6929A5	7433 533051	VALENTINA SEMENOVA	{"phone": "+70113575820"}
0005433450198	6E6AAE	0463 720676	OLGA KUZNECOVA	{"email": "kuznecovao.071971@postgrespro.ru", "phone": "+70246309061"}
0005433450199	2FA4B6	9892 286959	EVGENIY FROLOV	{"phone": "+70546403012"}
0005433450200	9F0753	5429 644499	VLADIMIR POPOV	{"phone": "+70590232913"}
0005433450201	196093	1669 675406	PAVEL ZAYCEV	{"email": "pavel_zaycev-04071958@postgrespro.ru", "phone": "+70878380147"}
0005433450202	E396F1	4834 824755	VERA MAKAROVA	{"email": "vmakarova.28021974@postgrespro.ru", "phone": "+70802166266"}
0005433450203	A16947	7224 016365	LYUDMILA YUDINA	{"email": "lyudmila_yudina.041974@postgrespro.ru", "phone": "+70107191735"}
0005433450204	71C44C	8800 152920	ROMAN BORISOV	{"phone": "+70669837829"}
0005433450205	2AEB0D	1119 628750	NADEZHDA KUZNECOVA	{"email": "kuznecova.n.15011978@postgrespro.ru", "phone": "+70364554641"}
0005433450206	F8992D	3306 154571	VALENTINA NAUMOVA	{"phone": "+70495214914"}
0005433450207	0142DF	1020 561948	LILIYA NIKITINA	{"email": "lnikitina.021979@postgrespro.ru", "phone": "+70625002453"}
0005433450208	688814	7880 871248	ALEKSANDR EGOROV	{"phone": "+70731800717"}
0005433450209	EF5E16	7044 225893	DMITRIY ROMANOV	{"phone": "+70559737772"}
0005433450210	EF5E16	4506 667271	EVDOKIYA MAKAROVA	{"phone": "+70835564246"}
0005433450211	79B623	9918 853649	EVGENIY BONDARENKO	{"phone": "+70933320123"}
0005433450212	79B623	8963 821344	SERGEY KUZNECOV	{"phone": "+70114227916"}
0005433450213	1CC324	6486 312836	NIKOLAY ORLOV	{"phone": "+70864897227"}
0005433450214	1CC324	9315 651032	ROMAN NIKITIN	{"phone": "+70651218368"}
0005433450215	D4C5EA	5818 699592	VYACHESLAV BARANOV	{"email": "baranov-v.11031972@postgrespro.ru", "phone": "+70679479476"}
0005433450216	26B257	0817 177600	PETR YAKOVLEV	{"phone": "+70057546186"}
0005433450217	26B257	6118 473557	VLADIMIR ANTONOV	{"phone": "+70626144825"}
0005433450218	F58D2A	6385 573041	PAVEL VASILEV	{"email": "pvasilev_1970@postgrespro.ru", "phone": "+70785179675"}
0005433450219	DF6734	3355 154539	DMITRIY FOMIN	{"email": "dmitriy.fomin_07021969@postgrespro.ru", "phone": "+70263658038"}
0005433450220	DF6734	8662 881772	EKATERINA SAVELEVA	{"phone": "+70242800265"}
0005433450221	DCD95B	4243 097193	MAKSIM EGOROV	{"phone": "+70919357938"}
0005433450222	DCD95B	5581 384178	ELENA MARTYNOVA	{"email": "martynova.e.24101962@postgrespro.ru", "phone": "+70136123069"}
0005433450223	AECE48	1913 776417	SERGEY KUZNECOV	{"email": "s.kuznecov.08051979@postgrespro.ru", "phone": "+70863968777"}
0005433450224	AECE48	7681 947877	ANASTASIYA VOROBEVA	{"email": "a_vorobeva-071986@postgrespro.ru", "phone": "+70709687032"}
0005433450225	2DDF2A	1215 722447	MAKSIM TIKHONOV	{"phone": "+70975510803"}
0005433450226	124682	5481 229159	DMITRIY MAKSIMOV	{"email": "d-maksimov1974@postgrespro.ru", "phone": "+70138221519"}
0005433450227	E159DB	8179 683380	VYACHESLAV VASILEV	{"phone": "+70136457468"}
0005433450228	893FBD	2957 003250	ALEKSANDR KOROLEV	{"phone": "+70182479478"}
0005433450229	8F0517	2331 677677	MIKHAIL DENISOV	{"email": "denisovmikhail.1977@postgrespro.ru", "phone": "+70423381653"}
0005433450230	5B4AF6	4025 793358	OLGA NESTEROVA	{"email": "onesterova-021959@postgrespro.ru", "phone": "+70213795806"}
0005433450231	CFE992	1768 884297	ZOYA ZAKHAROVA	{"phone": "+70655294611"}
0005433450232	CFE992	1170 538888	VIKTOR GUSEV	{"email": "v_gusev23041963@postgrespro.ru", "phone": "+70359530857"}
0005433450233	D7D30F	8753 577631	ELENA VOLKOVA	{"email": "evolkova.011981@postgrespro.ru", "phone": "+70731256241"}
0005433450234	2F3986	7789 487779	TATYANA EGOROVA	{"phone": "+70373473467"}
0005433450235	E5B6AC	8612 004053	VLADIMIR IVANOV	{"email": "ivanov.vladimir.09051977@postgrespro.ru", "phone": "+70428768783"}
0005433450236	AA8F5F	5123 651857	EVGENIY KUZMIN	{"email": "kuzmin.e_101968@postgrespro.ru", "phone": "+70745301010"}
0005433450237	394927	7182 087535	ANASTASIYA KUZNECOVA	{"email": "akuznecova29081974@postgrespro.ru", "phone": "+70776643914"}
0005433450238	913D06	1335 991440	ANDREY NIKITIN	{"email": "nikitin-andrey_071975@postgrespro.ru", "phone": "+70473098358"}
0005433450239	787622	6244 996450	NATALYA KUZNECOVA	{"phone": "+70275875185"}
0005433450240	B1C22F	3668 010006	ELENA MATVEEVA	{"phone": "+70216675435"}
0005433450241	9FB721	6017 676456	EKATERINA ZAYCEVA	{"email": "zayceva-ekaterina.101974@postgrespro.ru", "phone": "+70319550105"}
0005433450242	951636	8208 887711	VALENTINA POPOVA	{"phone": "+70579472853"}
0005433450243	EB69AC	3287 142514	SVETLANA KARPOVA	{"email": "karpova.s-16021973@postgrespro.ru", "phone": "+70662594264"}
0005433450244	13E47F	5427 670062	OLGA KOZLOVA	{"phone": "+70408842409"}
0005433450245	AF5F43	3909 894921	PAVEL VLASOV	{"email": "vlasov_p_30101969@postgrespro.ru", "phone": "+70727668464"}
0005433450246	412B8C	0292 416196	ANTONINA KOROLEVA	{"email": "koroleva-antonina1969@postgrespro.ru", "phone": "+70285902857"}
0005433450247	412B8C	8696 262936	YURIY RODIONOV	{"email": "rodionovyuriy-121966@postgrespro.ru", "phone": "+70871990445"}
0005433450248	35D2D3	4212 061209	VIKTOR ZAKHAROV	{"email": "viktor-zakharov_1968@postgrespro.ru", "phone": "+70037947106"}
0005433450249	C46F9B	7438 048703	DARYA DENISOVA	{"phone": "+70171221161"}
0005433450250	C46F9B	1125 761085	EKATERINA TARASOVA	{"email": "ekaterinatarasova-1970@postgrespro.ru", "phone": "+70088390854"}
0005433450251	34D1A7	4255 067454	VALERIY KAZAKOV	{"email": "kazakov_v_1965@postgrespro.ru", "phone": "+70998931560"}
0005433450252	50E20B	7626 225093	VIKTORIYA TROFIMOVA	{"phone": "+70873168839"}
0005433450253	50E20B	0944 191049	IVAN VOLKOV	{"phone": "+70831493832"}
0005433450254	6D6A7E	0468 853209	MIKHAIL DMITRIEV	{"email": "dmitrievm051971@postgrespro.ru", "phone": "+70307497616"}
0005433450255	DE6A62	6910 079853	VITALIY GUSEV	{"phone": "+70368559253"}
0005433450256	B6AE13	2927 083751	ALEKSANDR KOROLEV	{"phone": "+70491891533"}
0005433450257	DC6ADD	1321 496146	VALENTINA SOLOVEVA	{"email": "v_soloveva_081973@postgrespro.ru", "phone": "+70846970235"}
0005433450258	E86786	5230 122653	MAKSIM TIKHONOV	{"email": "tikhonov_m.061965@postgrespro.ru", "phone": "+70241975968"}
0005433450259	F9C967	0996 458359	ANASTASIYA KULIKOVA	{"phone": "+70322476740"}
0005433450260	98A1F4	5382 460897	POLINA ZHUKOVA	{"email": "zhukova.p-13031981@postgrespro.ru", "phone": "+70908106293"}
0005433450261	8FF657	3284 142098	POLINA POPOVA	{"phone": "+70732367863"}
0005433450262	8FF657	1456 655023	LIDIYA TROFIMOVA	{"phone": "+70385302868"}
0005433450263	D30004	4903 428135	EGOR ALEKSANDROV	{"email": "e.aleksandrov06101968@postgrespro.ru", "phone": "+70604894884"}
0005433450264	C74E81	7813 843441	RAISA DENISOVA	{"phone": "+70827733743"}
0005433450265	C74E81	0774 960392	ALEKSANDR PETROV	{"email": "a.petrov24121990@postgrespro.ru", "phone": "+70068844537"}
0005433450266	182D52	5430 828636	SERGEY TIKHONOV	{"phone": "+70281455205"}
0005433450267	561F6E	0949 205195	ELMIRA KALININA	{"email": "e_kalinina.06111968@postgrespro.ru", "phone": "+70329243863"}
0005433450268	90CDA4	2215 504831	SVETLANA POPOVA	{"email": "s-popova-27081972@postgrespro.ru", "phone": "+70350661382"}
0005433450269	C16EF0	5787 249825	LYUBOV KONOVALOVA	{"phone": "+70244636971"}
0005433450270	C16EF0	2580 218193	EKATERINA LEBEDEVA	{"email": "ekaterina.lebedeva.111970@postgrespro.ru", "phone": "+70747475425"}
0005433450271	C16EF0	1754 161759	ARTUR ZHURAVLEV	{"email": "zhuravlev_artur1981@postgrespro.ru", "phone": "+70834043378"}
0005433450272	7C70D8	1719 544022	ELENA GORBUNOVA	{"email": "elena.gorbunova_031978@postgrespro.ru", "phone": "+70286380438"}
0005433450273	7C70D8	7902 907443	ARTUR TARASOV	{"phone": "+70739089730"}
0005433450274	71ADEC	5043 209011	NATALYA ZAYCEVA	{"email": "zayceva.natalya1971@postgrespro.ru", "phone": "+70145560650"}
0005433450275	71ADEC	2314 529812	VALERIY POPOV	{"phone": "+70928928259"}
0005433450276	FCFCC3	6256 423830	ANATOLIY ISAEV	{"email": "isaeva1976@postgrespro.ru", "phone": "+70949710784"}
0005433450277	FCFCC3	4844 080502	OLGA MOROZOVA	{"phone": "+70308058900"}
0005433450278	BE862B	7926 911724	GALINA BELOVA	{"email": "belova-g-061972@postgrespro.ru", "phone": "+70032476642"}
0005433450279	CDAC42	1547 883558	ALEKSEY SIDOROV	{"phone": "+70615012313"}
0005433450280	CF8115	2719 428107	YULIYA ISAEVA	{"phone": "+70357817908"}
0005433450281	CF8115	2340 941470	ANDREY DAVYDOV	{"phone": "+70315572136"}
0005433450282	FF3994	5655 608502	MAKSIM SCHERBAKOV	{"phone": "+70459713976"}
0005433450283	B7E896	8804 083873	IGOR NAZAROV	{"email": "nazarov.i_06021964@postgrespro.ru", "phone": "+70675882238"}
0005433450284	E08BBE	8292 403656	SVETLANA OSIPOVA	{"phone": "+70336304349"}
0005433450285	FFC452	7615 605451	ALEKSANDR BARANOV	{"email": "baranova-13101968@postgrespro.ru", "phone": "+70014508555"}
0005433450286	FFC452	9872 845085	VALERIY STEPANOV	{"email": "valeriy_stepanov.061982@postgrespro.ru", "phone": "+70218395746"}
0005433450287	FFC452	7083 673189	SERGEY KONOVALOV	{"email": "s.konovalov-051971@postgrespro.ru", "phone": "+70918431163"}
0005433450288	B18E08	3296 390561	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-021971@postgrespro.ru", "phone": "+70401687822"}
0005433450289	B18E08	4059 490446	ALEKSANDRA KISELEVA	{"phone": "+70977103651"}
0005433450290	8A596E	0682 147570	ANNA MOROZOVA	{"email": "a.morozova.101972@postgrespro.ru", "phone": "+70757060626"}
0005433450291	77D3C6	8077 495172	GALINA DENISOVA	{"email": "g.denisova071978@postgrespro.ru", "phone": "+70129139026"}
0005433450292	77D3C6	4999 080714	MARINA KOZLOVA	{"phone": "+70010849834"}
0005433450293	2FC159	8091 703007	ELENA NIKITINA	{"email": "nikitina-elena_081980@postgrespro.ru", "phone": "+70231113286"}
0005433450295	83B217	7682 683741	ELENA NOVIKOVA	{"email": "novikova_elena1970@postgrespro.ru", "phone": "+70521250045"}
0005433450296	83B217	4582 005913	EKATERINA VOLKOVA	{"phone": "+70770127588"}
0005433450297	F25A28	7341 948149	ALEKSANDR ZAKHAROV	{"email": "zakharov.a-101973@postgrespro.ru", "phone": "+70322860763"}
0005433450298	F25A28	3190 817281	DINARA EGOROVA	{"phone": "+70044773070"}
0005433450299	8193FC	5123 307744	DARYA BELYAEVA	{"email": "belyaeva_darya.1970@postgrespro.ru", "phone": "+70520387333"}
0005433450300	8193FC	7884 891671	GALINA SEMENOVA	{"email": "g_semenova011968@postgrespro.ru", "phone": "+70460293233"}
0005433450301	8193FC	5574 625221	ALISA YAKOVLEVA	{"email": "a.yakovleva.041978@postgrespro.ru", "phone": "+70115698621"}
0005433450302	6D91A5	6942 567088	ANATOLIY BORISOV	{"phone": "+70778614286"}
0005433450303	DA20F9	3998 458326	PAVEL ZHURAVLEV	{"email": "p.zhuravlev.1976@postgrespro.ru", "phone": "+70430717565"}
0005433450304	DA20F9	5724 691030	NIKITA MATVEEV	{"phone": "+70021820179"}
0005433450305	FB9FA7	4189 843825	ROMAN VLASOV	{"phone": "+70718718135"}
0005433450306	FB9FA7	6382 531594	DMITRIY KOROLEV	{"email": "korolevd.21061976@postgrespro.ru", "phone": "+70333026971"}
0005433450307	8EBB48	7920 570360	SVETLANA TIKHONOVA	{"phone": "+70041358679"}
0005433450308	AD508B	3736 264216	LYUBOV KOVALEVA	{"phone": "+70508372634"}
0005433450309	AD508B	8256 575377	VLADISLAV VLASOV	{"email": "vladislav-vlasov031975@postgrespro.ru", "phone": "+70628811877"}
0005433450310	5706BF	5968 210058	SEMEN SEMENOV	{"email": "s-semenov27021982@postgrespro.ru", "phone": "+70835605396"}
0005433450311	5706BF	9134 107603	VALERIY RODIONOV	{"email": "rodionov_valeriy-24021967@postgrespro.ru", "phone": "+70706587305"}
0005433450312	7DED1F	9364 961374	RAFAIL VOLKOV	{"email": "rvolkov021979@postgrespro.ru", "phone": "+70136069480"}
0005433450313	13EF3E	4346 340853	OLGA VOLKOVA	{"phone": "+70425677468"}
0005433450314	8FE5CA	1777 417536	GALINA VLASOVA	{"email": "vlasova_galina051991@postgrespro.ru", "phone": "+70848747916"}
0005433450315	A21AD8	3330 305059	OLGA DMITRIEVA	{"email": "dmitrieva_o.29011973@postgrespro.ru", "phone": "+70521628672"}
0005433450316	17AA31	1607 910382	MARINA MOROZOVA	{"phone": "+70025007427"}
0005433450317	A487AE	1420 893618	LARISA DENISOVA	{"phone": "+70761314821"}
0005433450318	A487AE	4675 657348	TATYANA FROLOVA	{"phone": "+70728419705"}
0005433450319	7D0116	0805 921257	RIMMA BOGDANOVA	{"phone": "+70512239100"}
0005433450320	FBA620	8284 273861	SERAFIMA KUZNECOVA	{"email": "s.kuznecova_19021977@postgrespro.ru", "phone": "+70301716653"}
0005433450321	67EFD8	5851 501721	ALEKSANDR DENISOV	{"phone": "+70483009444"}
0005433450322	158868	1060 696125	SERGEY KUZNECOV	{"email": "s-kuznecov-011971@postgrespro.ru", "phone": "+70523185779"}
0005433450323	89D639	5462 609996	ILNUR RODIONOV	{"phone": "+70815835556"}
0005433450324	56A31E	6159 817616	ANDREY MIKHAYLOV	{"phone": "+70223272752"}
0005433450325	56A31E	0374 349813	IRINA LOGINOVA	{"email": "loginova_i08031976@postgrespro.ru", "phone": "+70827021972"}
0005433450326	56A31E	5114 683826	MARINA KAZAKOVA	{"email": "kazakova-marina.13081972@postgrespro.ru", "phone": "+70813246724"}
0005433450327	6B7C35	0484 215494	RUSLAN MOROZOV	{"email": "morozov_ruslan-051969@postgrespro.ru", "phone": "+70641535634"}
0005433450328	6B7C35	1238 258520	IRINA MAKSIMOVA	{"email": "irinamaksimova_10091971@postgrespro.ru", "phone": "+70361829523"}
0005433450329	EAF347	0989 575323	MIKHAIL PETROV	{"email": "petrov_mikhail1968@postgrespro.ru", "phone": "+70114851601"}
0005433450330	EAF347	7739 845899	ALINA MOROZOVA	{"email": "alina-morozova30121956@postgrespro.ru", "phone": "+70364286197"}
0005433450331	4F13C5	0349 558417	SERGEY BELOV	{"phone": "+70379655035"}
0005433450332	8DFDB7	4328 631925	ANASTASIYA ORLOVA	{"phone": "+70895258991"}
0005433450333	807BB1	0341 680534	MIKHAIL MOISEEV	{"phone": "+70339040486"}
0005433450334	5E585F	2361 837524	OLGA NESTEROVA	{"phone": "+70728382539"}
0005433450335	5E585F	6470 352346	SERGEY MARTYNOV	{"phone": "+70463083788"}
0005433450336	E51E17	0161 236504	EVGENIY FILIPPOV	{"phone": "+70445625113"}
0005433450337	E51E17	9715 683824	MARINA KUDRYASHOVA	{"phone": "+70165675770"}
0005433450338	4C7B83	8066 523830	MARINA SMIRNOVA	{"phone": "+70435003750"}
0005433450339	BD07BF	3158 146913	YAROSLAV KOROLEV	{"phone": "+70745317826"}
0005433450340	B56E8C	3440 333637	ANTONINA SCHERBAKOVA	{"phone": "+70713615461"}
0005433450341	B56E8C	3775 192193	NIKITA VASILEV	{"email": "vasilevn.20051980@postgrespro.ru", "phone": "+70210111128"}
0005433450342	B56E8C	1126 188725	NADEZHDA EGOROVA	{"email": "n.egorova.051962@postgrespro.ru", "phone": "+70150852499"}
0005433450343	6B6953	3754 883840	VLADIMIR MIRONOV	{"phone": "+70509740058"}
0005433450344	6B6953	9521 929816	PETR ABRAMOV	{"phone": "+70632789200"}
0005433450345	271B0D	1798 763970	ALEKSANDR GUSEV	{"email": "gusev_aleksandr-1974@postgrespro.ru", "phone": "+70102616742"}
0005433450346	271B0D	7811 573487	SERGEY BELOV	{"phone": "+70700650558"}
0005433450347	6DD11F	6809 502507	ANTONINA KOZLOVA	{"email": "a.kozlova.1974@postgrespro.ru", "phone": "+70220197605"}
0005433450348	1CF60F	5160 475165	VLADIMIR PAVLOV	{"phone": "+70411963036"}
0005433450349	676498	4918 155477	ANASTASIYA NIKOLAEVA	{"email": "anastasiyanikolaeva.051983@postgrespro.ru", "phone": "+70654354399"}
0005433450350	676498	3418 034763	ANASTASIYA POPOVA	{"phone": "+70832099188"}
0005433450351	0BF8FE	0645 538606	VIKTOR SOLOVEV	{"phone": "+70107121507"}
0005433450352	A8BE3E	1497 119910	LILIYA SEMENOVA	{"phone": "+70185641424"}
0005433450353	A8BE3E	0929 041691	NINA MASLOVA	{"email": "ninamaslova1973@postgrespro.ru", "phone": "+70318157002"}
0005433450354	3E5003	4507 044252	ALEKSANDR BARANOV	{"phone": "+70695501588"}
0005433450355	57B935	5687 043699	ANASTASIYA SAVELEVA	{"phone": "+70939443965"}
0005433450356	57B935	2583 013570	SVETLANA KULIKOVA	{"email": "kulikova-svetlana-30111972@postgrespro.ru", "phone": "+70868250972"}
0005433450357	AB7CA6	3651 050534	DIANA KUZNECOVA	{"email": "kuznecova.d_1964@postgrespro.ru", "phone": "+70703155721"}
0005433450358	0ED0F5	8418 759644	RINAT ZAKHAROV	{"email": "zakharov.r_1974@postgrespro.ru", "phone": "+70793160158"}
0005433450359	2B50A5	3798 233362	VLADISLAV SCHERBAKOV	{"email": "scherbakov-v021976@postgrespro.ru", "phone": "+70868743766"}
0005433450360	2B50A5	9607 902464	VALENTINA MIKHAYLOVA	{"email": "v.mikhaylova-1958@postgrespro.ru", "phone": "+70065480339"}
0005433450361	3CFFDD	5221 618820	LYUBOV MIKHAYLOVA	{"phone": "+70232124284"}
0005433450362	2606A0	7697 491548	ALEKSANDR FOMIN	{"email": "fomin-aleksandr-1978@postgrespro.ru", "phone": "+70257817607"}
0005433450363	767A6F	1267 437306	GALINA SERGEEVA	{"email": "sergeeva-galina.011969@postgrespro.ru", "phone": "+70260763642"}
0005433450364	767A6F	5167 499573	YAROSLAV ANDREEV	{"phone": "+70723267236"}
0005433450365	AC4D7F	1735 818596	OLGA BELOVA	{"email": "o_belova-051967@postgrespro.ru", "phone": "+70168965641"}
0005433450366	AC4D7F	4496 495327	LYUDMILA VOROBEVA	{"phone": "+70761151036"}
0005433450367	632AD7	2090 547923	MARIYA MALYSHEVA	{"email": "m_malysheva13021977@postgrespro.ru", "phone": "+70259650827"}
0005433450368	632AD7	1425 215100	NADEZHDA ZAKHAROVA	{"email": "zakharova-n.091959@postgrespro.ru", "phone": "+70197149897"}
0005433450369	7C360A	3106 759278	MARIYA SAVELEVA	{"email": "saveleva-m_1970@postgrespro.ru", "phone": "+70558460702"}
0005433450370	EB84EA	7903 573107	EGOR ALEKSANDROV	{"phone": "+70433190511"}
0005433450371	EB84EA	8232 463165	YURIY KARPOV	{"phone": "+70987141167"}
0005433450372	813887	2769 650305	EKATERINA VOLKOVA	{"phone": "+70545802383"}
0005433450373	813887	7317 866563	VERA KAZAKOVA	{"email": "kazakova-v-091965@postgrespro.ru", "phone": "+70077219285"}
0005433450374	C4B5A0	2323 574358	VERA DANILOVA	{"phone": "+70424574374"}
0005433450375	C4B5A0	2731 471278	SERGEY IVANOV	{"phone": "+70058855609"}
0005433450376	34921D	1483 000393	NATALYA NIKITINA	{"phone": "+70241790969"}
0005433450377	D7DBCE	4567 421278	ALEKSANDR NAZAROV	{"phone": "+70308313576"}
0005433450378	389AA1	7174 080624	SVETLANA RODIONOVA	{"phone": "+70119936590"}
0005433450379	389AA1	6344 160328	ALEKSANDR FROLOV	{"email": "frolov.aleksandr-101972@postgrespro.ru", "phone": "+70851103477"}
0005433450380	0256E8	2215 051506	DMITRIY SOROKIN	{"email": "sorokin_dmitriy-021965@postgrespro.ru", "phone": "+70808549666"}
0005433450381	352582	2012 548110	LYUDMILA SAVELEVA	{"email": "saveleva-lyudmila-27031992@postgrespro.ru", "phone": "+70651024877"}
0005433450382	81CF22	2070 988202	VERA IVANOVA	{"email": "vivanova1960@postgrespro.ru", "phone": "+70212677851"}
0005433450383	81CF22	9963 018112	NADEZHDA MAKAROVA	{"email": "makarovanadezhda_051986@postgrespro.ru", "phone": "+70810795088"}
0005433450384	81CF22	3585 763463	ALEKSANDR ORLOV	{"phone": "+70551217214"}
0005433450385	A57A48	4070 013453	ALEKSANDR KARPOV	{"email": "karpovaleksandr.091964@postgrespro.ru", "phone": "+70548926045"}
0005433450386	23E50C	9926 732192	YULIYA LAZAREVA	{"phone": "+70161292494"}
0005433450387	1C989E	0893 294921	ALEKSANDRA FILATOVA	{"email": "filatova.aleksandra-021972@postgrespro.ru", "phone": "+70220508405"}
0005433450388	0A7D4B	1088 333804	TAMARA KUZMINA	{"phone": "+70136604351"}
0005433450389	0A7D4B	8517 900924	VASILIY OSIPOV	{"phone": "+70844232192"}
0005433450390	A6C3AC	3429 127306	MARINA YUDINA	{"phone": "+70129405330"}
0005433450391	E1FA5A	8993 154684	VLADIMIR SERGEEV	{"email": "v_sergeev011970@postgrespro.ru", "phone": "+70328580821"}
0005433450392	0E2093	5258 014616	NINA DMITRIEVA	{"phone": "+70592131887"}
0005433450393	A7320E	6938 531260	ELENA ZHUKOVA	{"email": "elena.zhukova_081977@postgrespro.ru", "phone": "+70869495881"}
0005433450394	A999A4	5074 756083	ROBERT MARTYNOV	{"phone": "+70298083894"}
0005433450395	86D868	9816 768232	VENERA MALYSHEVA	{"phone": "+70505287571"}
0005433450396	EA1E43	8801 795521	DMITRIY VOLKOV	{"email": "volkovdmitriy_22071976@postgrespro.ru", "phone": "+70781869027"}
0005433450397	EA1E43	2569 281672	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov-1971@postgrespro.ru", "phone": "+70914490815"}
0005433450398	9FDDF9	0538 615454	MARINA VASILEVA	{"email": "vasileva-marina1978@postgrespro.ru", "phone": "+70731225798"}
0005433450399	9FDDF9	0263 313136	SVETLANA MOROZOVA	{"phone": "+70829758328"}
0005433450400	F6BF6F	0878 709360	MAKSIM NIKOLAEV	{"email": "nikolaev_maksim_30111969@postgrespro.ru", "phone": "+70843756542"}
0005433450401	F6BF6F	6511 202690	NATALYA EGOROVA	{"phone": "+70837285893"}
0005433450402	660275	6708 328554	NADEZHDA FOMINA	{"phone": "+70722320869"}
0005433450403	660275	6435 806876	VIKTOR PETROV	{"email": "petrov.v.041977@postgrespro.ru", "phone": "+70087174618"}
0005433450404	72E0DF	7678 784130	ALEKSANDR NIKOLAEV	{"email": "anikolaev_12111973@postgrespro.ru", "phone": "+70362877751"}
0005433450405	EB63B7	4193 530569	EKATERINA BORISOVA	{"email": "borisova_e11041967@postgrespro.ru", "phone": "+70885858547"}
0005433450406	EB63B7	1017 594761	ELENA NIKOLAEVA	{"email": "elena-nikolaeva_101983@postgrespro.ru", "phone": "+70822652800"}
0005433450407	FBF0F5	8167 773473	VALERIY GORBUNOV	{"email": "valeriy_gorbunov_26061968@postgrespro.ru", "phone": "+70387915366"}
0005433450408	FBF0F5	6945 789702	NINA ANISIMOVA	{"phone": "+70745756167"}
0005433450409	5666F5	1378 225283	OLGA MOROZOVA	{"email": "morozova-olga16041977@postgrespro.ru", "phone": "+70435398927"}
0005433450410	A2B3D5	3511 004721	VIKTOR ALEKSANDROV	{"email": "aleksandrov_viktor_1985@postgrespro.ru", "phone": "+70521584505"}
0005433450411	A2B3D5	9490 757573	ALEKSEY OSIPOV	{"phone": "+70611665032"}
0005433450412	C43E74	3107 336428	ANDREY YAKOVLEV	{"email": "ayakovlev_18071979@postgrespro.ru", "phone": "+70373252793"}
0005433450413	797C0F	8760 031628	SERGEY FILIPPOV	{"email": "sergey-filippov_1966@postgrespro.ru", "phone": "+70154177542"}
0005433450414	6FFC05	9854 323425	ALEKSEY BORISOV	{"email": "a-borisov.1969@postgrespro.ru", "phone": "+70010872799"}
0005433450415	6FFC05	6463 856301	VLADIMIR GRIGOREV	{"phone": "+70989271697"}
0005433450416	23C9F2	5426 131388	INGA EGOROVA	{"phone": "+70476096215"}
0005433450417	955B8F	7175 110904	TIMUR KUZNECOV	{"email": "kuznecov_timur.1971@postgrespro.ru", "phone": "+70653435281"}
0005433450418	C02DAD	9193 108544	ANTON EGOROV	{"email": "egorov_anton.111976@postgrespro.ru", "phone": "+70737769651"}
0005433450419	C82BD3	3219 471623	ALEKSANDR IVANOV	{"email": "aleksandrivanov.051975@postgrespro.ru", "phone": "+70756319599"}
0005433450420	0864C5	2587 664105	SERGEY CHERNOV	{"phone": "+70745564330"}
0005433450421	253845	6356 783873	NINA KUZMINA	{"email": "kuzmina.n1966@postgrespro.ru", "phone": "+70954885776"}
0005433450422	253845	1841 498238	OLEG MAKAROV	{"phone": "+70555671467"}
0005433450423	714419	3232 856980	ALEKSANDR POPOV	{"email": "a_popov-11051971@postgrespro.ru", "phone": "+70619795259"}
0005433450424	714419	9822 749046	EKATERINA DANILOVA	{"phone": "+70143224112"}
0005433450425	714419	0425 562343	PRASKOVYA SEMENOVA	{"phone": "+70617015894"}
0005433450426	4B80B4	8444 974550	VASILIY TIMOFEEV	{"phone": "+70043071376"}
0005433450427	9289F1	1732 463252	MARIYA PAVLOVA	{"phone": "+70487200993"}
0005433450428	966871	0519 612490	TIMUR TIKHONOV	{"email": "timurtikhonov-061964@postgrespro.ru", "phone": "+70566696248"}
0005433450429	965CE6	6699 380221	TAMARA GERASIMOVA	{"email": "gerasimova-t-1959@postgrespro.ru", "phone": "+70117237321"}
0005433450430	965CE6	2484 041415	DENIS ROMANOV	{"email": "d.romanov1953@postgrespro.ru", "phone": "+70988292271"}
0005433450487	57639D	9281 048361	DMITRIY SAVELEV	{"phone": "+70001180198"}
0005433450431	5F73E2	3313 307899	TATYANA ALEKSEEVA	{"email": "t_alekseeva_071969@postgrespro.ru", "phone": "+70631002802"}
0005433450432	4C8B00	2279 874213	LIDIYA KULIKOVA	{"phone": "+70622949420"}
0005433450433	4C8B00	5667 393054	IRINA SOLOVEVA	{"phone": "+70055124390"}
0005433450434	24AFD9	1675 416039	VIKTOR FILIPPOV	{"phone": "+70071367742"}
0005433450435	24AFD9	6826 553697	VLADIMIR TARASOV	{"phone": "+70323628818"}
0005433450436	7E5484	5276 902905	SERGEY VLASOV	{"email": "s_vlasov.1985@postgrespro.ru", "phone": "+70404000789"}
0005433450437	271405	4923 457032	IOSIF NIKOLAEV	{"phone": "+70069314196"}
0005433450438	621E17	2337 931187	STANISLAV KOROLEV	{"phone": "+70036840487"}
0005433450439	621E17	7401 572213	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev.091964@postgrespro.ru", "phone": "+70494544380"}
0005433450440	E07A55	9642 793095	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay1973@postgrespro.ru", "phone": "+70985196944"}
0005433450441	7EDDD0	0751 082770	VALENTINA NOVIKOVA	{"email": "v_novikova-111980@postgrespro.ru", "phone": "+70342228921"}
0005433450442	1E81BE	2003 848390	ZOYA NIKITINA	{"email": "nikitina-zoya-08031973@postgrespro.ru", "phone": "+70880855030"}
0005433450443	1E81BE	8756 748817	LYUDMILA SERGEEVA	{"phone": "+70679061201"}
0005433450444	B72215	7364 716718	ANGELINA FEDOROVA	{"email": "fedorova.a121977@postgrespro.ru", "phone": "+70031345837"}
0005433450445	D98D9B	2881 641789	NADEZHDA KAZAKOVA	{"email": "kazakovanadezhda09021971@postgrespro.ru", "phone": "+70893405749"}
0005433450446	190EC7	4056 507480	ALEKSANDR ROMANOV	{"phone": "+70599405767"}
0005433450447	ABC526	8342 031984	VIKTOR KARPOV	{"email": "karpov_viktor.071976@postgrespro.ru", "phone": "+70813836664"}
0005433450448	6CBDF2	8501 544455	STANISLAV POPOV	{"email": "stanislav.popov_071964@postgrespro.ru", "phone": "+70136862302"}
0005433450449	3B7299	0735 523943	OLEG MEDVEDEV	{"phone": "+70365861641"}
0005433450450	F7AF11	2002 877424	RASHID KISELEV	{"phone": "+70322468660"}
0005433450451	E07A16	2113 653175	TATYANA MELNIKOVA	{"phone": "+70226177284"}
0005433450452	E07A16	0840 260620	ELENA ANTONOVA	{"email": "eantonova.29071975@postgrespro.ru", "phone": "+70182871856"}
0005433450453	F4A39B	0356 544166	OKSANA TITOVA	{"email": "o-titova13111960@postgrespro.ru", "phone": "+70513458490"}
0005433450454	320F73	3915 160214	SERGEY RODIONOV	{"phone": "+70070706356"}
0005433450455	BEBE6E	3268 330579	VASILISA NESTEROVA	{"email": "nesterova-vasilisa011963@postgrespro.ru", "phone": "+70150617335"}
0005433450456	FE6605	9684 155063	OLGA KOZLOVA	{"phone": "+70577180941"}
0005433450457	FE6605	7566 235811	YURIY DMITRIEV	{"phone": "+70006670761"}
0005433450458	FE6605	5702 696174	VASILIY VOLKOV	{"phone": "+70056147749"}
0005433450459	D59B44	8488 838237	VLADIMIR KUZMIN	{"email": "kuzmin.v_041972@postgrespro.ru", "phone": "+70237294553"}
0005433450460	D59B44	4339 052915	POLINA VOROBEVA	{"phone": "+70438681168"}
0005433450461	9CDC2A	7858 209350	NATALYA ERMAKOVA	{"phone": "+70512941806"}
0005433450462	B50723	6097 393701	LIDIYA KUDRYASHOVA	{"phone": "+70875841883"}
0005433450463	6160FC	1555 960056	RAVILYA VLASOVA	{"phone": "+70524458877"}
0005433450520	DDA726	3675 891492	VITALIY IVANOV	{"phone": "+70744505115"}
0005433450464	70F1A9	1601 359189	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr10031979@postgrespro.ru", "phone": "+70575080440"}
0005433450465	70F1A9	4767 438746	VIKTOR FILIPPOV	{"email": "filippovv-28061967@postgrespro.ru", "phone": "+70293616389"}
0005433450466	B960D8	0141 041213	OLGA TARASOVA	{"email": "otarasova27051977@postgrespro.ru", "phone": "+70884359144"}
0005433450467	91525F	3061 541036	DMITRIY KUZNECOV	{"phone": "+70069321112"}
0005433450468	676C35	7385 275612	EKATERINA KARPOVA	{"phone": "+70268049150"}
0005433450469	A08C60	9299 568136	DARYA LAZAREVA	{"phone": "+70899903218"}
0005433450470	DA53B0	9999 169047	MIKHAIL KARPOV	{"email": "karpov-m_021968@postgrespro.ru", "phone": "+70865174225"}
0005433450471	CF8F8F	3992 911288	MARINA SOLOVEVA	{"email": "m-soloveva-01081979@postgrespro.ru", "phone": "+70805718847"}
0005433450472	CF8F8F	2195 875468	ARTEM MOROZOV	{"phone": "+70870996201"}
0005433450473	64930D	9195 589092	GALINA KUZNECOVA	{"phone": "+70442302624"}
0005433450474	64930D	1180 781050	LYUDMILA MATVEEVA	{"phone": "+70961584881"}
0005433450475	1D04A2	4358 856111	VYACHESLAV FILIPPOV	{"phone": "+70631793545"}
0005433450476	1D04A2	0059 173287	NATALYA VOLKOVA	{"phone": "+70252665154"}
0005433450477	1D04A2	0552 678879	SVETLANA PETROVA	{"phone": "+70566528502"}
0005433450478	EAF908	6580 305433	NIKOLAY CHERNOV	{"phone": "+70863120063"}
0005433450479	9CC419	0942 083858	VLADA EGOROVA	{"email": "egorova-vlada_30031971@postgrespro.ru", "phone": "+70072676028"}
0005433450480	9CC419	6170 960228	ALEKSEY DENISOV	{"email": "denisov-a.1980@postgrespro.ru", "phone": "+70424692768"}
0005433450481	EEDE02	0887 188963	TATYANA EFREMOVA	{"email": "efremova-tatyana-1967@postgrespro.ru", "phone": "+70740671725"}
0005433450482	EEDE02	4374 891213	NINA IVANOVA	{"phone": "+70132860085"}
0005433450483	C9555E	5863 606560	ALEKSANDR VASILEV	{"email": "avasilev25071971@postgrespro.ru", "phone": "+70539941068"}
0005433450484	A0C3FE	5818 292348	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev_1977@postgrespro.ru", "phone": "+70254600801"}
0005433450485	048523	0456 103415	ILYA SCHERBAKOV	{"email": "scherbakov_i29041969@postgrespro.ru", "phone": "+70517293882"}
0005433450486	C4F96D	2666 325944	DMITRIY PAVLOV	{"email": "dmitriypavlov111968@postgrespro.ru", "phone": "+70748788232"}
0005433450488	4A7CE9	9667 717664	ANTONINA FILATOVA	{"email": "antoninafilatova_041976@postgrespro.ru", "phone": "+70710261625"}
0005433450489	C52904	6167 516065	VYACHESLAV NIKITIN	{"email": "v_nikitin.20091974@postgrespro.ru", "phone": "+70562275548"}
0005433450490	9AD9B9	2574 835057	VASILIY GRIGOREV	{"email": "vasiliy_grigorev1973@postgrespro.ru", "phone": "+70869874882"}
0005433450491	9AD9B9	6826 095961	DMITRIY BELOV	{"email": "belov_dmitriy1984@postgrespro.ru", "phone": "+70471957814"}
0005433450492	149E71	8810 151322	EVGENIY PETROV	{"phone": "+70894099745"}
0005433450493	1B768A	6579 372881	VLADIMIR SOROKIN	{"email": "vsorokin.081969@postgrespro.ru", "phone": "+70507076425"}
0005433450494	D5DC93	3897 177196	YURIY SEMENOV	{"phone": "+70512743195"}
0005433450495	71F607	2856 324392	ZINAIDA DANILOVA	{"email": "danilova.zinaida_1971@postgrespro.ru", "phone": "+70477507308"}
0005433450496	A2EE23	6670 858610	INNA KOROLEVA	{"email": "i_koroleva1980@postgrespro.ru", "phone": "+70993302091"}
0005433450497	425C77	0196 129498	EGOR ABRAMOV	{"email": "e-abramov15051977@postgrespro.ru", "phone": "+70845941162"}
0005433450498	425C77	6992 967422	ALEKSANDR MIRONOV	{"email": "a.mironov1979@postgrespro.ru", "phone": "+70309937979"}
0005433450499	DE9B54	2016 612722	ANASTASIYA ALEKSEEVA	{"phone": "+70592411870"}
0005433450500	668ACE	1561 609438	OLGA VASILEVA	{"email": "vasilevaolga_22021981@postgrespro.ru", "phone": "+70668084137"}
0005433450501	DC613A	8022 819846	ELENA GAVRILOVA	{"phone": "+70496507007"}
0005433450502	CF9A56	1618 953997	GALINA ERMAKOVA	{"email": "ermakova.galina.051972@postgrespro.ru", "phone": "+70657317256"}
0005433450503	CF9A56	6692 295893	GULIYA KUZNECOVA	{"email": "g_kuznecova.1971@postgrespro.ru", "phone": "+70016542250"}
0005433450504	914FDD	5424 211854	ANNA NIKOLAEVA	{"email": "anikolaeva.051966@postgrespro.ru", "phone": "+70041768447"}
0005433450505	C0F641	4455 940188	DANILA MEDVEDEV	{"phone": "+70417563887"}
0005433450506	C0F641	8646 542733	SERGEY TIKHONOV	{"phone": "+70738728912"}
0005433450507	AEA31F	9621 043339	VLADIMIR PAVLOV	{"email": "pavlov_v041965@postgrespro.ru", "phone": "+70915200702"}
0005433450508	4FC291	9606 356674	VALENTINA AKIMOVA	{"phone": "+70815970732"}
0005433450509	BC6AA9	4341 848079	VLADISLAV BORISOV	{"phone": "+70031011335"}
0005433450510	002193	7652 295785	NIKOLAY PETROV	{"phone": "+70542141825"}
0005433450511	002193	3545 908577	TAISIYA KOROLEVA	{"email": "koroleva.t.1960@postgrespro.ru", "phone": "+70466064638"}
0005433450512	2C8C67	9541 113295	ALEKSANDR MOROZOV	{"email": "amorozov09041971@postgrespro.ru", "phone": "+70198132378"}
0005433450513	2C8C67	7914 055317	YANA NESTEROVA	{"email": "yana.nesterova.1971@postgrespro.ru", "phone": "+70705653821"}
0005433450514	63E005	2587 516947	AMIR NAZAROV	{"phone": "+70562141821"}
0005433450515	63E005	0682 293319	IVAN IVANOV	{"email": "ivan.ivanov_1972@postgrespro.ru", "phone": "+70944181798"}
0005433450516	63E005	9372 708113	DMITRIY NAZAROV	{"phone": "+70846619891"}
0005433450517	16D02C	1485 212111	NIKOLAY KOZLOV	{"phone": "+70223785641"}
0005433450518	018753	4444 825373	EVGENIYA ILINA	{"phone": "+70744399396"}
0005433450519	DDA726	6482 964720	VADIM IVANOV	{"phone": "+70029761285"}
0005433450521	DB2E92	6364 714515	ANATOLIY SAVELEV	{"email": "savelev_anatoliy-011964@postgrespro.ru", "phone": "+70271451128"}
0005433450522	914597	5437 031787	ALEKSANDR KULIKOV	{"email": "kulikov-a021960@postgrespro.ru", "phone": "+70049515136"}
0005433450523	8AF625	5499 669485	EGOR YAKOVLEV	{"phone": "+70460924951"}
0005433450524	3DC17F	3140 086469	ALEKSANDR KULIKOV	{"email": "kulikov_a.04111977@postgrespro.ru", "phone": "+70766791410"}
0005433450525	D6C724	9340 504444	VALENTINA LUKYANOVA	{"email": "v_lukyanova-27121978@postgrespro.ru", "phone": "+70757048987"}
0005433450526	EEB07A	8287 272326	KONSTANTIN MEDVEDEV	{"email": "konstantin-medvedev-071971@postgrespro.ru", "phone": "+70959162608"}
0005433450527	EEB07A	8904 119763	ANNA NESTEROVA	{"email": "a-nesterova-04091977@postgrespro.ru", "phone": "+70182965015"}
0005433450528	EEB07A	0637 539586	DAMIR MEDVEDEV	{"phone": "+70710003715"}
0005433450529	EFB7A1	8523 352496	ALEKSEY DMITRIEV	{"email": "dmitriev_a_30091971@postgrespro.ru", "phone": "+70309567946"}
0005433450530	8838A4	2832 097209	LYUBOV MEDVEDEVA	{"email": "medvedeva-lyubov.26091980@postgrespro.ru", "phone": "+70537609711"}
0005433450531	B68C0E	2173 685143	ELENA ALEKSANDROVA	{"email": "e_aleksandrova_1974@postgrespro.ru", "phone": "+70831953596"}
0005433450532	B68C0E	2179 863144	ELENA FILIPPOVA	{"phone": "+70574205122"}
0005433450533	96527E	3495 111374	OLGA KOZLOVA	{"email": "kozlova_o_12061980@postgrespro.ru", "phone": "+70679007329"}
0005433450534	96527E	1424 301174	GALINA LOGINOVA	{"email": "loginova_g.021962@postgrespro.ru", "phone": "+70003607537"}
0005433450535	860A0D	5639 176223	ANNA STEPANOVA	{"email": "stepanova_anna1962@postgrespro.ru", "phone": "+70821827345"}
0005433450536	C706F1	8425 341232	ANTONINA DAVYDOVA	{"email": "davydovaa.021972@postgrespro.ru", "phone": "+70192237888"}
0005433450537	57B7B5	6292 823966	ROMAN NAZAROV	{"email": "nazarov_roman.1963@postgrespro.ru", "phone": "+70260149413"}
0005433450538	A0F2A5	7870 225805	YURIY MOROZOV	{"email": "morozov_yuriy_061956@postgrespro.ru", "phone": "+70289978259"}
0005433450539	535385	4771 840363	VLADIMIR NOVIKOV	{"phone": "+70669484223"}
0005433450540	EEDC5F	5813 206012	NIKOLAY VOLKOV	{"phone": "+70269169697"}
0005433450541	F545C4	7009 345494	ALEVTINA KUZMINA	{"phone": "+70796081913"}
0005433450542	FE9CB3	7934 041368	LILIYA ZAKHAROVA	{"email": "liliya-zakharova_24041977@postgrespro.ru", "phone": "+70567878562"}
0005433450543	FE9CB3	1957 042456	TAMARA BORISOVA	{"email": "borisova.t-1973@postgrespro.ru", "phone": "+70655649823"}
0005433450544	8759D8	8062 905805	MARINA TITOVA	{"email": "marinatitova021976@postgrespro.ru", "phone": "+70119015948"}
0005433450545	FC5E00	9652 260895	OKSANA KULIKOVA	{"phone": "+70068908258"}
0005433450546	FC5E00	6826 213904	SERGEY KOZLOV	{"phone": "+70941652458"}
0005433450547	7A1296	8572 970195	EKATERINA ZHURAVLEVA	{"email": "ekaterina.zhuravleva111965@postgrespro.ru", "phone": "+70349416941"}
0005433450548	7A1296	5789 768614	OLGA TIKHONOVA	{"email": "tikhonovaolga081962@postgrespro.ru", "phone": "+70004336774"}
0005433450549	7A1296	1986 344650	LYUBOV SCHERBAKOVA	{"phone": "+70486912621"}
0005433450550	331501	2874 848106	RAFIK SHEVCHENKO	{"email": "shevchenko_rafik-1979@postgrespro.ru", "phone": "+70778939292"}
0005433450551	C4504C	4361 517958	OLGA ROMANOVA	{"phone": "+70268129928"}
0005433450552	AC4A7A	4136 112556	ALEKSANDR TIKHONOV	{"email": "tikhonov_a.061962@postgrespro.ru", "phone": "+70504447437"}
0005433450553	AC4A7A	4461 541653	DENIS PAVLOV	{"email": "d-pavlov_011973@postgrespro.ru", "phone": "+70206909685"}
0005433450554	24DF71	5980 091208	YULIYA TIMOFEEVA	{"phone": "+70678923440"}
0005433450555	ED7413	7753 836845	GALINA YAKOVLEVA	{"phone": "+70022282716"}
0005433450556	0DC6CC	9841 104583	GERMAN ANTONOV	{"phone": "+70784073102"}
0005433450557	7F42D5	0634 848702	ANTONINA IVANOVA	{"phone": "+70202211709"}
0005433450558	F74125	2057 421551	ILGIZ MIRONOV	{"phone": "+70987869915"}
0005433450559	F74125	2867 632365	ELENA NESTEROVA	{"email": "e.nesterova_031967@postgrespro.ru", "phone": "+70698882940"}
0005433450560	92AFCC	2186 269097	MARIYA VASILEVA	{"phone": "+70510855179"}
0005433450561	EB523C	0754 421091	VLADIMIR SMIRNOV	{"phone": "+70132819844"}
0005433450562	402EFD	7006 741775	LYUDMILA MOROZOVA	{"phone": "+70202631791"}
0005433450563	1D2B35	0484 048829	ALEKSANDR KOZLOV	{"email": "a.kozlov021978@postgrespro.ru", "phone": "+70952182280"}
0005433450564	C737F2	8554 347961	ALEVTINA MATVEEVA	{"phone": "+70601416816"}
0005433450565	C737F2	1888 230405	VIKTORIYA POPOVA	{"phone": "+70363317611"}
0005433450566	FD592B	1638 954410	SALAVAT GRIGOREV	{"email": "sgrigorev_081966@postgrespro.ru", "phone": "+70353192305"}
0005433450567	FD592B	7260 486604	ANNA NIKITINA	{"email": "nikitina.a_1978@postgrespro.ru", "phone": "+70396363877"}
0005433450568	FD592B	1409 658130	ELVIRA NIKOLAEVA	{"email": "e_nikolaeva.1958@postgrespro.ru", "phone": "+70494147875"}
0005433450569	41ADE7	6058 351154	PETR IVANOV	{"email": "pivanov14061968@postgrespro.ru", "phone": "+70625463558"}
0005433450570	41ADE7	6154 603715	VITALIY GERASIMOV	{"phone": "+70467226635"}
0005433450571	11D8E9	2833 839300	EVGENIYA EGOROVA	{"phone": "+70892966543"}
0005433450572	11D8E9	8146 911539	SERGEY PAVLOV	{"email": "pavlov.sergey-1975@postgrespro.ru", "phone": "+70023112958"}
0005433450573	DABB15	4001 481745	ALEKSANDR KAZAKOV	{"phone": "+70208843802"}
0005433450574	526BB9	6265 492603	NATALYA ANDREEVA	{"email": "andreevan.06051966@postgrespro.ru", "phone": "+70678134848"}
0005433450575	7BE5D0	7705 032632	SAMIRA MELNIKOVA	{"phone": "+70143618136"}
0005433450576	7BE5D0	2953 276835	DMITRIY CHERNOV	{"email": "chernovd-1972@postgrespro.ru", "phone": "+70508382627"}
0005433450577	6194E9	0665 934246	VASILIY FILIPPOV	{"phone": "+70685224776"}
0005433450578	3E1FEF	2214 643834	ANATOLIY BONDARENKO	{"phone": "+70656515801"}
0005433450579	AC3C14	3329 638683	TATYANA KRASNOVA	{"phone": "+70631022066"}
0005433450580	3CCA14	7823 598334	VLADIMIR MEDVEDEV	{"email": "vmedvedev-07021969@postgrespro.ru", "phone": "+70512756066"}
0005433450581	B8C1D0	8566 728528	DMITRIY AFANASEV	{"email": "afanasev_dmitriy-031956@postgrespro.ru", "phone": "+70620398905"}
0005433450582	529DA5	7010 558963	ARTEMIY YAKOVLEV	{"email": "a.yakovlev_101974@postgrespro.ru", "phone": "+70775403087"}
0005433450583	42377F	7747 159054	ALEKSANDR MOISEEV	{"email": "moiseev.aleksandr-21101960@postgrespro.ru", "phone": "+70787666351"}
0005433450584	73192E	0498 852417	NATALYA MIRONOVA	{"email": "natalya-mironova.1968@postgrespro.ru", "phone": "+70715137517"}
0005433450585	644046	7247 732533	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-31121960@postgrespro.ru", "phone": "+70957254057"}
0005433450586	B93E88	7889 675274	NATALYA GORBUNOVA	{"email": "gorbunova_n-031972@postgrespro.ru", "phone": "+70188470558"}
0005433450587	755564	9191 289953	ANDREY MATVEEV	{"phone": "+70209445439"}
0005433450588	538802	1219 236778	DENIS KUZNECOV	{"phone": "+70386821231"}
0005433450589	D662A8	9604 623422	YULIYA SCHERBAKOVA	{"phone": "+70109284624"}
0005433450590	87152B	6248 753385	ALEKSEY FILIPPOV	{"phone": "+70716482824"}
0005433450591	5B5ACF	3156 999614	IVAN FROLOV	{"phone": "+70878020644"}
0005433450592	C941CB	8216 314757	LYUDMILA LAZAREVA	{"phone": "+70105319670"}
0005433450593	B886F1	8788 136796	EVGENIY KUZNECOV	{"email": "kuznecove_06051974@postgrespro.ru", "phone": "+70729301079"}
0005433450594	FE3833	8430 396737	VALENTINA MOROZOVA	{"email": "valentina-morozova.25091974@postgrespro.ru", "phone": "+70869589899"}
0005433450595	3D8873	5276 565873	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov-101965@postgrespro.ru", "phone": "+70686554691"}
0005433450596	B135F3	6090 030660	KRISTINA KISELEVA	{"email": "kiseleva-kristina-17011977@postgrespro.ru", "phone": "+70748692887"}
0005433450597	80DC71	8395 432098	ALEKSANDRA VASILEVA	{"phone": "+70359984958"}
0005433450598	9FE3D1	6367 839945	SERGEY YAKOVLEV	{"email": "yakovlev-sergey-101974@postgrespro.ru", "phone": "+70572291096"}
0005433450599	0FC756	6858 161499	SERGEY ANTONOV	{"phone": "+70298875203"}
0005433450600	ACDE5A	3499 165359	ANATOLIY CHERNOV	{"email": "achernov.081983@postgrespro.ru", "phone": "+70731011452"}
0005433450601	D259B1	2472 195447	SVETLANA GERASIMOVA	{"email": "svetlana_gerasimova.04101973@postgrespro.ru", "phone": "+70681024565"}
0005433450602	9FE9ED	5289 477307	VLADIMIR YAKOVLEV	{"phone": "+70124973891"}
0005433450603	9FE9ED	1813 686109	VALENTINA TROFIMOVA	{"email": "v_trofimova_071991@postgrespro.ru", "phone": "+70268229885"}
0005433450604	11F7B6	7860 350072	NADEZHDA SMIRNOVA	{"phone": "+70695293551"}
0005433450605	671C05	0111 914991	VLADIMIR KUZNECOV	{"phone": "+70459490786"}
0005433450606	F8999A	4115 800120	GERMAN SMIRNOV	{"email": "g_smirnov.01101967@postgrespro.ru", "phone": "+70236675835"}
0005433450607	B63704	3024 332304	EVGENIY SERGEEV	{"phone": "+70373120767"}
0005433450608	B63704	5496 732556	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov.121969@postgrespro.ru", "phone": "+70864202613"}
0005433450609	5E06F5	1585 218261	ALBINA ZAKHAROVA	{"email": "albina-zakharova031971@postgrespro.ru", "phone": "+70914485814"}
0005433450610	5E06F5	8986 932938	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrova_aleksandra.30111979@postgrespro.ru", "phone": "+70163835590"}
0005433450611	B6A796	8490 025072	ILNUR FROLOV	{"phone": "+70241789749"}
0005433450612	63A109	6592 349653	ALEKSEY FROLOV	{"email": "frolov.a021972@postgrespro.ru", "phone": "+70155275565"}
0005433451582	04D234	4742 123681	VLADIMIR ALEKSANDROV	{"phone": "+70520789568"}
0005433451583	B53F02	6433 465247	ALEKSANDR ZAKHAROV	{"phone": "+70526301941"}
0005433451584	F0C38F	6616 516500	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr.25011979@postgrespro.ru", "phone": "+70657823106"}
0005433451585	F0C38F	1340 859554	ANNA ANDREEVA	{"email": "andreevaanna.26111965@postgrespro.ru", "phone": "+70310902280"}
0005433451586	BD34A8	8110 424435	PAVEL MAKSIMOV	{"phone": "+70599530708"}
0005433451587	BEA98A	0135 861566	EKATERINA OSIPOVA	{"email": "osipovae1969@postgrespro.ru", "phone": "+70098119712"}
0005433451588	EC8F77	4623 392581	VASILIY NAUMOV	{"phone": "+70906854233"}
0005433451589	4ACB95	3097 451642	ANASTASIYA AFANASEVA	{"phone": "+70274128883"}
0005433451590	FE38B9	7748 637388	SERGEY GRIGOREV	{"phone": "+70383317830"}
0005433451591	A97CDA	4502 232348	VASILIY SEMENOV	{"email": "v.semenov.31011979@postgrespro.ru", "phone": "+70771651219"}
0005433451592	A97CDA	8393 923902	ANATOLIY SIDOROV	{"email": "anatoliy-sidorov-29111964@postgrespro.ru", "phone": "+70980740154"}
0005433451593	669543	1197 445652	ILYA PETROV	{"phone": "+70886453769"}
0005433451594	5E69CB	6969 611361	OLESYA ORLOVA	{"email": "o_orlova101976@postgrespro.ru", "phone": "+70097312489"}
0005433451595	5E69CB	5034 545929	ELENA VOROBEVA	{"email": "evorobeva-1974@postgrespro.ru", "phone": "+70823200131"}
0005433451596	5E69CB	2626 081890	NINA BELOVA	{"email": "belova_nina_091978@postgrespro.ru", "phone": "+70385540188"}
0005433451597	9CA307	8698 300485	TATYANA AFANASEVA	{"email": "tatyanaafanaseva021976@postgrespro.ru", "phone": "+70784999987"}
0005433451598	69BD4E	7376 051105	LYUBOV SERGEEVA	{"email": "sergeevalyubov1983@postgrespro.ru", "phone": "+70886139462"}
0005433451599	CBBFF7	2824 498119	ALEKSANDRA VOLKOVA	{"email": "avolkova_08081968@postgrespro.ru", "phone": "+70620506212"}
0005433451600	C7BB55	3597 649240	TAISA SMIRNOVA	{"phone": "+70919064918"}
0005433451601	57A33D	2463 983517	NADEZHDA IVANOVA	{"phone": "+70207324469"}
0005433451602	ACD961	0140 645865	NIKOLAY DENISOV	{"email": "denisov-nikolay_061964@postgrespro.ru", "phone": "+70664601646"}
0005433451603	ACD961	8194 879441	RUSLAN BARANOV	{"phone": "+70633185533"}
0005433451604	63A498	2846 021312	RAVIL ZAKHAROV	{"phone": "+70006996217"}
0005433451605	B76C65	0984 523355	MARIYA ZAYCEVA	{"phone": "+70066803117"}
0005433451606	FED50D	6617 279717	ANTONINA SAVELEVA	{"email": "a_saveleva.031971@postgrespro.ru", "phone": "+70468546363"}
0005433451607	FED50D	0571 574639	EVGENIY BELOV	{"email": "belov.evgeniy_041976@postgrespro.ru", "phone": "+70997911806"}
0005433451608	4F4794	5650 052826	TATYANA VLASOVA	{"email": "vlasova_t_1972@postgrespro.ru", "phone": "+70316057916"}
0005433451609	9109AD	0572 228279	NIKITA ABRAMOV	{"email": "abramov-nikita_111972@postgrespro.ru", "phone": "+70171912899"}
0005433451610	AEDEA4	4351 093278	POLINA EGOROVA	{"phone": "+70524645144"}
0005433451611	516ED8	3641 896579	MARGARITA MIKHAYLOVA	{"phone": "+70177466508"}
0005433451612	516ED8	2617 343891	SVETLANA ORLOVA	{"phone": "+70905966461"}
0005433451613	F4A628	6358 030789	ALEKSANDR ISAEV	{"phone": "+70594503820"}
0005433451614	F4A628	8882 668052	DMITRIY SHEVCHENKO	{"phone": "+70308126504"}
0005433451615	F4A628	5824 334587	ALEKSANDR IVANOV	{"phone": "+70078796292"}
0005433451616	A4FB5B	3865 056204	LARISA KUZNECOVA	{"email": "kuznecovalarisa_13071970@postgrespro.ru", "phone": "+70428254045"}
0005433451617	D1C35A	7323 848178	VALERIY SEMENOV	{"phone": "+70861419597"}
0005433451618	213507	1238 499583	SERGEY PETROV	{"email": "petrovs101971@postgrespro.ru", "phone": "+70560845567"}
0005433451619	0D2648	6521 868610	GALINA FROLOVA	{"email": "frolova_galina11071983@postgrespro.ru", "phone": "+70302695124"}
0005433451620	0D2648	6740 027754	ANNA SOROKINA	{"email": "sorokinaa-051974@postgrespro.ru", "phone": "+70901041399"}
0005433451621	F7325D	3938 862313	SVETLANA FILATOVA	{"email": "svetlanafilatova.021962@postgrespro.ru", "phone": "+70210193346"}
0005433451622	470234	1395 044884	VALENTINA POTAPOVA	{"email": "vpotapova071973@postgrespro.ru", "phone": "+70444315730"}
0005433451623	F98857	4511 463112	ALEKSANDR MIKHAYLOV	{"phone": "+70573794566"}
0005433451624	FC1BB2	4879 346077	KRISTINA MEDVEDEVA	{"email": "medvedevak.071967@postgrespro.ru", "phone": "+70003052206"}
0005433451625	C0ED1D	1335 763758	NINA SMIRNOVA	{"phone": "+70203168587"}
0005433451626	0B2B78	8840 302582	VLADISLAV EGOROV	{"email": "egorov-vladislav-041963@postgrespro.ru", "phone": "+70088966465"}
0005433451627	1E22AC	4565 601937	PAVEL KUDRYASHOV	{"email": "kudryashov-pavel051975@postgrespro.ru", "phone": "+70846439628"}
0005433451628	312135	1502 561793	VLADIMIR VASILEV	{"email": "vasilev-vladimir_011981@postgrespro.ru", "phone": "+70526406880"}
0005433451629	E56AF6	4855 656300	SVETLANA ZAKHAROVA	{"phone": "+70195473741"}
0005433451630	AC8978	2634 973906	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr.1973@postgrespro.ru", "phone": "+70349076661"}
0005433451631	2A76AE	4071 465912	ANDREY VASILEV	{"email": "vasilev.a1985@postgrespro.ru", "phone": "+70262759757"}
0005433451632	2A76AE	8742 596832	DARYA PETROVA	{"email": "darya.petrova_27071981@postgrespro.ru", "phone": "+70935206843"}
0005433451633	B639B0	1373 830827	MIKHAIL SMIRNOV	{"phone": "+70858659603"}
0005433451634	33248B	5851 945780	VADIM FEDOTOV	{"email": "fedotov-vadim-051964@postgrespro.ru", "phone": "+70928766369"}
0005433451635	33248B	5798 967199	KSENIYA NESTEROVA	{"email": "kseniya_nesterova.1966@postgrespro.ru", "phone": "+70387954024"}
0005433451636	1F7394	1931 619627	INNA GAVRILOVA	{"phone": "+70030048683"}
0005433451637	A25A32	2005 681117	ALEKSANDR MELNIKOV	{"phone": "+70302679512"}
0005433451638	8D7B92	8586 616961	TATYANA NIKIFOROVA	{"email": "nikiforovat.05101988@postgrespro.ru", "phone": "+70492071560"}
0005433451639	86F40E	2775 720318	VYACHESLAV ISAEV	{"phone": "+70896239653"}
0005433451640	0995A0	7753 563469	ALEKSANDR MOROZOV	{"phone": "+70323190280"}
0005433451641	57B953	5291 865078	IRINA NIKITINA	{"email": "irina-nikitina-1984@postgrespro.ru", "phone": "+70071822255"}
0005433451642	7FAFAD	0417 368876	ALEKSEY MARTYNOV	{"email": "a-martynov03071967@postgrespro.ru", "phone": "+70494456704"}
0005433451643	1C9E1B	1880 519818	NINA EFREMOVA	{"email": "efremova-nina_041970@postgrespro.ru", "phone": "+70995425037"}
0005433451644	7F56CA	7168 746277	EVGENIY ABRAMOV	{"email": "abramov.e-1970@postgrespro.ru", "phone": "+70700272400"}
0005433451645	95A361	8027 545050	IRINA ALEKSANDROVA	{"phone": "+70356431264"}
0005433451646	11B0D0	1434 225314	MARIYA CHERNOVA	{"email": "mariya_chernova.03081981@postgrespro.ru", "phone": "+70532289450"}
0005433451647	FD2DA6	8454 537111	ALEKSANDRA YUDINA	{"email": "a-yudina.24101969@postgrespro.ru", "phone": "+70186089750"}
0005433451648	B68F95	9344 591986	GENNADIY MOROZOV	{"email": "gennadiymorozov09061971@postgrespro.ru", "phone": "+70447531681"}
0005433451649	B68F95	3758 371399	EVGENIY ABRAMOV	{"email": "evgeniy_abramov28051978@postgrespro.ru", "phone": "+70478080025"}
0005433451650	FB6621	7383 730476	VALENTINA LOGINOVA	{"email": "loginova.v1975@postgrespro.ru", "phone": "+70727267628"}
0005433451651	38F0E2	1816 314435	ALEKSANDR DAVYDOV	{"email": "davydov.a-071973@postgrespro.ru", "phone": "+70933913125"}
0005433451652	64C236	1442 891702	YULIYA KAZAKOVA	{"phone": "+70151123356"}
0005433451653	94E818	8297 623190	ALEKSANDR KUDRYASHOV	{"email": "aleksandrkudryashov.1973@postgrespro.ru", "phone": "+70959727596"}
0005433451654	94E818	6224 587093	GALINA KUZNECOVA	{"phone": "+70478706634"}
0005433451655	6E4B01	9624 748388	GENNADIY IVANOV	{"email": "ivanov.gennadiy.27111989@postgrespro.ru", "phone": "+70749256685"}
0005433451656	06AE62	8932 625577	NADEZHDA KAZAKOVA	{"email": "kazakova-nadezhda.1969@postgrespro.ru", "phone": "+70753988611"}
0005433451657	80794C	3470 276720	VIKTORIYA SOKOLOVA	{"phone": "+70391713772"}
0005433451658	80794C	9244 717756	VLADIMIR ISAEV	{"email": "isaevvladimir091965@postgrespro.ru", "phone": "+70312041156"}
0005433451659	6AB88E	5576 425888	IRINA GRISHINA	{"email": "i-grishina.011974@postgrespro.ru", "phone": "+70252502473"}
0005433451660	6AB88E	4524 583876	ZOYA RODIONOVA	{"phone": "+70654213060"}
0005433451661	229F6C	2597 723959	VADIM SERGEEV	{"email": "sergeev-v-12041983@postgrespro.ru", "phone": "+70679262021"}
0005433451662	EA1CEB	8889 887810	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev24121968@postgrespro.ru", "phone": "+70391769402"}
0005433451663	40D09F	1933 093466	SVETLANA ZHUKOVA	{"email": "s-zhukova_1968@postgrespro.ru", "phone": "+70833961706"}
0005433451664	F9DD30	1493 623928	NADEZHDA IVANOVA	{"email": "ivanova-nadezhda-1982@postgrespro.ru", "phone": "+70738378121"}
0005433451665	F9DD30	0830 951126	IRINA ROMANOVA	{"email": "romanova-irina_1974@postgrespro.ru", "phone": "+70755026694"}
0005433451666	626B0F	0823 467978	ELENA RODIONOVA	{"email": "elena.rodionova-1967@postgrespro.ru", "phone": "+70316462768"}
0005433451667	626B0F	6563 765017	SERGEY MEDVEDEV	{"email": "medvedev-sergey_1975@postgrespro.ru", "phone": "+70686306032"}
0005433451668	626B0F	5252 401709	TATYANA VASILEVA	{"phone": "+70312905951"}
0005433451669	8D51BD	7752 676319	SERGEY GORBUNOV	{"email": "gorbunovsergey.1965@postgrespro.ru", "phone": "+70682092062"}
0005433451670	D0E36A	1961 047735	LYUBOV KARPOVA	{"email": "karpova-lyubov-1982@postgrespro.ru", "phone": "+70164362442"}
0005433451671	D0E36A	2581 486584	IRINA ZAYCEVA	{"phone": "+70404328467"}
0005433451672	1312BE	0921 985942	VLADIMIR SOKOLOV	{"phone": "+70788311996"}
0005433451673	D4D86D	7754 541783	VIKTOR GERASIMOV	{"email": "gerasimov_viktor_1968@postgrespro.ru", "phone": "+70389992586"}
0005433451674	867C06	4295 308092	ALEKSANDR GRIGOREV	{"phone": "+70366014490"}
0005433451675	867C06	2336 993985	GULFIYA EFIMOVA	{"email": "gulfiyaefimova.08081979@postgrespro.ru", "phone": "+70363317408"}
0005433451676	190B1D	4381 394557	VITALIY KUZMIN	{"email": "vitaliy.kuzmin071974@postgrespro.ru", "phone": "+70399601466"}
0005433451677	DE77FF	3682 469136	ELVIRA NIKIFOROVA	{"email": "elvira.nikiforova_12031969@postgrespro.ru", "phone": "+70234251796"}
0005433451678	DE77FF	3374 604693	LYUDMILA KONOVALOVA	{"phone": "+70169423725"}
0005433452701	28E3B0	2880 809425	MARIYA ORLOVA	{"email": "orlova_mariya20061977@postgrespro.ru", "phone": "+70814425734"}
0005433452702	C73E64	8817 352614	NIKOLAY KISELEV	{"email": "nikolay.kiselev071980@postgrespro.ru", "phone": "+70753203529"}
0005433452703	C73E64	7411 720954	IVAN FEDOROV	{"phone": "+70675565320"}
0005433452704	1B1E31	3056 404822	NADEZHDA GUSEVA	{"phone": "+70732772028"}
0005433452705	1B1E31	2427 227983	ANASTASIYA YAKOVLEVA	{"phone": "+70847786371"}
0005433452706	95E7EA	1709 498404	NATALIYA ALEKSEEVA	{"phone": "+70758319428"}
0005433452707	075E11	8400 620717	ALEKSEY SERGEEV	{"phone": "+70314332339"}
0005433452708	82BCB8	3201 759331	KIRA DENISOVA	{"phone": "+70518777202"}
0005433452709	82BCB8	5276 597498	ELENA ERMAKOVA	{"email": "elenaermakova101979@postgrespro.ru", "phone": "+70040909052"}
0005433452710	4F29ED	8484 140506	VALENTINA NIKOLAEVA	{"phone": "+70597506509"}
0005433452711	4F29ED	8643 293236	OLGA SOROKINA	{"phone": "+70081375160"}
0005433452712	E2110D	2684 296346	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr1964@postgrespro.ru", "phone": "+70454098434"}
0005433452713	E2110D	5397 547582	SOFYA BORISOVA	{"phone": "+70951154833"}
0005433452714	F8815B	7266 762472	VALENTINA GERASIMOVA	{"phone": "+70828831455"}
0005433452715	DCE7F4	2722 617001	VARVARA YAKOVLEVA	{"phone": "+70543719643"}
0005433452716	5C4314	6431 734179	LILIYA NAZAROVA	{"phone": "+70190760979"}
0005433452717	81065B	0292 067635	MARINA NAUMOVA	{"phone": "+70341556733"}
0005433452718	81065B	2796 675459	VITALIY EGOROV	{"email": "egorov-vitaliy_26051962@postgrespro.ru", "phone": "+70556700489"}
0005433452719	C07233	7951 819496	RUFIYA ANDREEVA	{"email": "r_andreeva1967@postgrespro.ru", "phone": "+70751643652"}
0005433452720	4D2104	2231 953613	SERGEY NOVIKOV	{"phone": "+70673604620"}
0005433452721	4E07B1	2557 573544	DENIS FROLOV	{"email": "denis-frolov1969@postgrespro.ru", "phone": "+70169419368"}
0005433452722	CC660B	1023 038131	ANASTASIYA ORLOVA	{"phone": "+70482959947"}
0005433452723	83F902	9439 987320	VIKTOR SMIRNOV	{"phone": "+70352862167"}
0005433452724	C8CE63	0813 492786	OLGA ZHUKOVA	{"phone": "+70349514621"}
0005433452725	B979C4	0257 966776	ALEKSEY ANDREEV	{"email": "aleksey-andreev.23081953@postgrespro.ru", "phone": "+70861855469"}
0005433452726	F923DF	8332 765628	IRINA IVANOVA	{"email": "ivanova_i.101979@postgrespro.ru", "phone": "+70506859589"}
0005433452727	F923DF	5927 762408	ALEKSANDRA SOKOLOVA	{"email": "asokolova-1974@postgrespro.ru", "phone": "+70334939330"}
0005433452728	F923DF	3072 288568	DENIS ALEKSEEV	{"email": "alekseev_denis.031975@postgrespro.ru", "phone": "+70250869381"}
0005433452729	CEC71B	7682 366209	SERGEY KUDRYASHOV	{"email": "kudryashovsergey14111976@postgrespro.ru", "phone": "+70384175280"}
0005433452730	CEC71B	4763 981286	VERA MARTYNOVA	{"email": "v.martynova1978@postgrespro.ru", "phone": "+70106016577"}
0005433452731	AF3944	4182 540703	SERGEY KUDRYASHOV	{"email": "kudryashov-sergey1977@postgrespro.ru", "phone": "+70771982426"}
0005433452732	AF3944	7090 961062	OLGA ZOTOVA	{"phone": "+70489778991"}
0005433452733	529FB8	3766 606078	VLADIMIR GERASIMOV	{"phone": "+70836767396"}
0005433452734	529FB8	9189 326918	VLADIMIR POPOV	{"phone": "+70251433991"}
0005433452735	45353E	0186 832792	MARIYA LOGINOVA	{"email": "loginova_mariya_1965@postgrespro.ru", "phone": "+70120645914"}
0005433452736	99AEDC	0284 467014	ANTONINA ZHURAVLEVA	{"phone": "+70549072173"}
0005433452737	99AEDC	2486 697772	YULIYA STEPANOVA	{"email": "stepanova_yuliya_111972@postgrespro.ru", "phone": "+70653917688"}
0005433452738	DD9C42	9516 150410	SVETLANA AKIMOVA	{"email": "svetlana.akimova_041975@postgrespro.ru", "phone": "+70984366867"}
0005433452739	6A575D	1521 468627	NIKITA SEMENOV	{"email": "semenov.nikita1976@postgrespro.ru", "phone": "+70218642451"}
0005433452740	4992A2	8017 785768	ANATOLIY MIRONOV	{"email": "mironov.anatoliy-1981@postgrespro.ru", "phone": "+70833720315"}
0005433452741	ACDB83	8192 481017	ALEKSANDR KUZNECOV	{"phone": "+70321569025"}
0005433452742	ACDB83	8267 266201	IRINA KOLESNIKOVA	{"email": "i-kolesnikova25021966@postgrespro.ru", "phone": "+70526325912"}
0005433452743	33F38D	4612 181065	REGINA NAZAROVA	{"phone": "+70226084106"}
0005433452744	33F38D	0414 731710	OKSANA VOROBEVA	{"email": "ovorobeva_031965@postgrespro.ru", "phone": "+70566511484"}
0005433452745	7446B1	1493 675293	IVAN NAUMOV	{"email": "naumov.ivan08111963@postgrespro.ru", "phone": "+70192883383"}
0005433452746	7446B1	6480 505814	VERA IVANOVA	{"phone": "+70468592477"}
0005433452747	AD373E	9702 643464	ALEKSANDRA VASILEVA	{"phone": "+70898189138"}
0005433452748	B04592	9391 499505	SERGEY PAVLOV	{"email": "s.pavlov20011979@postgrespro.ru", "phone": "+70418040816"}
0005433452749	361F6F	4379 609572	IVAN ISAEV	{"email": "i_isaev1970@postgrespro.ru", "phone": "+70735699072"}
0005433452750	2418E2	7183 434669	YURIY POPOV	{"phone": "+70498864865"}
0005433452751	46CEDA	1538 567296	VALERIY PAVLOV	{"phone": "+70011961819"}
0005433452752	BE6A27	4889 769221	VALENTINA PETROVA	{"email": "v.petrova-121971@postgrespro.ru", "phone": "+70650135559"}
0005433452753	BF4EF2	7983 432862	RAISA STEPANOVA	{"email": "r.stepanova1974@postgrespro.ru", "phone": "+70465971009"}
0005433452754	C55BFA	8575 712676	TATYANA ZAKHAROVA	{"email": "t_zakharova-1962@postgrespro.ru", "phone": "+70226193408"}
0005433452755	343214	2271 209867	VALERIY FROLOV	{"email": "valeriy_frolov_22091967@postgrespro.ru", "phone": "+70418467685"}
0005433452756	D6BF8C	7099 382177	STEPAN ORLOV	{"phone": "+70522806876"}
0005433452757	D6BF8C	8954 767253	DENIS SIDOROV	{"email": "sidorov.denis-011968@postgrespro.ru", "phone": "+70139997073"}
0005433452758	B8824F	5485 754091	RAVIL SOKOLOV	{"phone": "+70667195092"}
0005433452759	1C98BC	7723 095224	SERGEY SERGEEV	{"phone": "+70385784653"}
0005433452760	E0E765	9940 869960	ROMAN IVANOV	{"email": "ivanov-roman.071964@postgrespro.ru", "phone": "+70249234785"}
0005433452761	E0E765	3866 159558	LIDIYA MELNIKOVA	{"email": "melnikova.l_041971@postgrespro.ru", "phone": "+70599445144"}
0005433452762	5FCE50	7595 267743	IRINA MAKAROVA	{"email": "i_makarova1975@postgrespro.ru", "phone": "+70326532885"}
0005433452763	6588D9	8165 098492	MIKHAIL BORISOV	{"email": "m.borisov.121976@postgrespro.ru", "phone": "+70768339585"}
0005433452764	2E376E	9551 330122	KIRILL KUZMIN	{"phone": "+70498918046"}
0005433452765	3000B5	3967 521973	ALEKSANDR KUZNECOV	{"phone": "+70867229159"}
0005433452766	3000B5	0530 298624	YAKOV BARANOV	{"phone": "+70116317907"}
0005433452767	DC51E4	9704 865635	MARGARITA MIKHAYLOVA	{"email": "m-mikhaylova.101974@postgrespro.ru", "phone": "+70890606492"}
0005433452768	312EE2	0774 282449	VALERIY IVANOV	{"phone": "+70654661185"}
0005433452769	CE0132	0624 103428	VIKTOR KOROLEV	{"email": "korolev.viktor.051970@postgrespro.ru", "phone": "+70041591960"}
0005433452770	CE0132	7812 036678	GALINA KOVALEVA	{"email": "galina-kovaleva_1973@postgrespro.ru", "phone": "+70575793042"}
0005433452771	83FE9D	3750 720922	ALEKSEY NAZAROV	{"email": "anazarov_051980@postgrespro.ru", "phone": "+70638404665"}
0005433452772	83FE9D	3539 387437	NATALYA VOLKOVA	{"phone": "+70603632942"}
0005433452773	809684	0562 984898	GLEB SMIRNOV	{"email": "g-smirnov1958@postgrespro.ru", "phone": "+70445950844"}
0005433452774	DEAD22	5225 633551	ANASTASIYA KOROLEVA	{"phone": "+70150171248"}
0005433452775	6542FB	0783 528962	IRINA NOVIKOVA	{"email": "inovikova_1977@postgrespro.ru", "phone": "+70576618755"}
0005433452776	F85990	6318 124120	VLADIMIR FOMIN	{"email": "vfomin.03091968@postgrespro.ru", "phone": "+70937177893"}
0005433452777	F85990	2357 833299	NATALYA BORISOVA	{"phone": "+70128608589"}
0005433452778	EADA40	4927 914822	KSENIYA MOROZOVA	{"email": "kseniya_morozova.01041976@postgrespro.ru", "phone": "+70727636480"}
0005433452779	EADA40	5890 340686	ELEONORA FILIPPOVA	{"email": "filippova-e-12041972@postgrespro.ru", "phone": "+70871729538"}
0005433452780	6DB384	6855 668453	OLGA POPOVA	{"email": "olga.popova_1969@postgrespro.ru", "phone": "+70175714951"}
0005433452781	FA8658	4940 762164	DMITRIY ILIN	{"phone": "+70175092654"}
0005433452782	1DC256	3349 056219	ALEKSANDRA SOROKINA	{"phone": "+70626932467"}
0005433452783	1DC256	7793 628698	TATYANA PETROVA	{"phone": "+70593238359"}
0005433452784	1DC256	3476 644057	ALEKSEY VASILEV	{"phone": "+70148934446"}
0005433452785	6BD578	0528 638153	VIKTOR KAZAKOV	{"email": "vkazakov-041963@postgrespro.ru", "phone": "+70301367240"}
0005433452786	39AAB9	1280 515358	ZOYA POPOVA	{"phone": "+70681070778"}
0005433452787	39AAB9	0277 762617	YULIYA TARASOVA	{"email": "tarasova-yuliya1969@postgrespro.ru", "phone": "+70400900236"}
0005433452788	4D5B50	2122 326234	VALENTINA ZOTOVA	{"email": "zotova-valentina1978@postgrespro.ru", "phone": "+70409249743"}
0005433452789	4D5B50	3339 274180	BORIS VOROBEV	{"phone": "+70245045964"}
0005433452790	357EF1	5784 594966	VALENTINA SEMENOVA	{"email": "v-semenova041968@postgrespro.ru", "phone": "+70486849300"}
0005433452791	42FABB	2317 932860	VALENTIN MIRONOV	{"phone": "+70199042094"}
0005433452792	1CDA2F	8921 860254	SERGEY BELOV	{"phone": "+70775367673"}
0005433452793	1CDA2F	9408 802600	VASILIY KUZNECOV	{"email": "vasiliykuznecov-1976@postgrespro.ru", "phone": "+70429528374"}
0005433452794	DC2FE4	3514 320150	NIKOLAY ISAEV	{"email": "isaev-n-30071965@postgrespro.ru", "phone": "+70801405080"}
0005433452795	BFA664	9939 456019	DENIS SAVELEV	{"email": "dsavelev_031970@postgrespro.ru", "phone": "+70601919181"}
0005433452796	BD2B10	6154 713290	ALEKSANDR MAKSIMOV	{"phone": "+70762600193"}
0005433453726	3F940D	7310 751168	ALEKSANDRA KOROLEVA	{"phone": "+70523003643"}
0005433453727	CA49FE	0562 634106	ANNA KOLESNIKOVA	{"email": "anna.kolesnikova051974@postgrespro.ru", "phone": "+70193729716"}
0005433453728	DC87B9	9624 423108	ELENA SERGEEVA	{"email": "sergeeva_elena121964@postgrespro.ru", "phone": "+70939301627"}
0005433453729	3DDB40	6147 243142	LYUBOV SOLOVEVA	{"phone": "+70185409040"}
0005433453730	2AEF5C	3070 343048	ALEKSANDR VASILEV	{"phone": "+70126860892"}
0005433453731	2AEF5C	6490 191915	ELENA BORISOVA	{"phone": "+70692487877"}
0005433453732	E3E015	0207 887204	YULIYA DAVYDOVA	{"phone": "+70275571376"}
0005433453733	2A6FC5	7831 328707	ALENA AKIMOVA	{"phone": "+70022759297"}
0005433453734	2A6FC5	4740 246360	SERGEY AFANASEV	{"email": "safanasev-04101976@postgrespro.ru", "phone": "+70595305761"}
0005433453735	17C4B3	1700 493695	MAKSIM IVANOV	{"email": "maksimivanov_09111977@postgrespro.ru", "phone": "+70325500866"}
0005433453736	3E1BF3	7649 839228	EKATERINA ZHURAVLEVA	{"email": "zhuravleva-ekaterina13091957@postgrespro.ru", "phone": "+70360915394"}
0005433453737	CF83A3	5792 626125	ANASTASIYA ERMAKOVA	{"email": "ermakovaanastasiya_14061965@postgrespro.ru", "phone": "+70457430877"}
0005433453738	62744A	4442 338884	VALENTINA KOROLEVA	{"email": "v_koroleva1980@postgrespro.ru", "phone": "+70571013013"}
0005433453739	62744A	5439 013472	OLGA POPOVA	{"email": "popova-olga08101982@postgrespro.ru", "phone": "+70774508165"}
0005433453740	C66B8C	6330 139913	VIKTORIYA ORLOVA	{"email": "v_orlova1956@postgrespro.ru", "phone": "+70196489495"}
0005433453741	C66B8C	7917 585773	NATALYA FOMINA	{"phone": "+70045695508"}
0005433453742	C66B8C	1240 808692	ANNA KULIKOVA	{"phone": "+70713702344"}
0005433453743	84A6AB	8408 801102	KARINA NAUMOVA	{"email": "naumova-k031964@postgrespro.ru", "phone": "+70655106091"}
0005433453744	84A6AB	2775 854474	VLADIMIR KONOVALOV	{"email": "v-konovalov_1978@postgrespro.ru", "phone": "+70502643752"}
0005433453745	1A2258	7853 370716	TATYANA ISAEVA	{"email": "t_isaeva-14091970@postgrespro.ru", "phone": "+70526066562"}
0005433453746	1A2258	4819 701517	OKSANA DANILOVA	{"phone": "+70427499231"}
0005433453747	E13B4E	4116 925110	ANASTASIYA MARTYNOVA	{"phone": "+70541451707"}
0005433453748	E13B4E	6993 079380	YURIY ZAKHAROV	{"phone": "+70113945491"}
0005433453749	244CBF	4950 999171	DMITRIY EGOROV	{"phone": "+70391018892"}
0005433453750	120D3E	6370 025870	MARAT VOLKOV	{"email": "volkov_marat18111980@postgrespro.ru", "phone": "+70924776098"}
0005433453751	1B80E7	9767 980159	IGOR KAZAKOV	{"email": "igor-kazakov_051970@postgrespro.ru", "phone": "+70189655863"}
0005433453752	1B80E7	1838 060561	OKSANA GRISHINA	{"email": "o_grishina_21011974@postgrespro.ru", "phone": "+70898771192"}
0005433453753	4C2C43	4877 320587	NAIL SOROKIN	{"phone": "+70960145402"}
0005433453754	4C2C43	6315 325521	NATALYA MOROZOVA	{"phone": "+70449254010"}
0005433453755	B840FF	6851 450369	YULIYA NESTEROVA	{"email": "nesterova.y_061970@postgrespro.ru", "phone": "+70771145398"}
0005433453756	B840FF	2466 015026	ANATOLIY CHERNOV	{"phone": "+70286142475"}
0005433453757	B840FF	0803 841500	SVETLANA GERASIMOVA	{"email": "s-gerasimova.051988@postgrespro.ru", "phone": "+70728641376"}
0005433453758	9983A5	5127 737908	ALBINA ZOTOVA	{"email": "zotova.albina1969@postgrespro.ru", "phone": "+70250343072"}
0005433453759	778EEA	1247 822270	LIDIYA ALEKSANDROVA	{"phone": "+70740416681"}
0005433453760	778EEA	7097 307827	VITALIY ILIN	{"email": "vitaliy-ilin_081968@postgrespro.ru", "phone": "+70992981701"}
0005433453761	638237	2239 883503	ANZHELIKA MIKHAYLOVA	{"email": "a-mikhaylova-101957@postgrespro.ru", "phone": "+70440224508"}
0005433453762	5F883F	8107 839270	VLADIMIR SIDOROV	{"email": "v-sidorov-24091980@postgrespro.ru", "phone": "+70127721676"}
0005433453763	5F883F	5687 704783	TAISIYA ROMANOVA	{"phone": "+70363116571"}
0005433453764	EDEAB9	1276 201419	GALINA SAVELEVA	{"phone": "+70684425183"}
0005433453765	954886	7730 052433	TATYANA MARTYNOVA	{"email": "martynova_tatyana_30081972@postgrespro.ru", "phone": "+70066262819"}
0005433453766	119F09	5729 095186	ARTUR SOKOLOV	{"phone": "+70682650832"}
0005433453767	119F09	9258 188935	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr051957@postgrespro.ru", "phone": "+70993326958"}
0005433453768	984963	5191 724612	ANNA ILINA	{"phone": "+70234217882"}
0005433453769	027727	2623 976059	SVETLANA LEBEDEVA	{"email": "svetlana.lebedeva04021971@postgrespro.ru", "phone": "+70990405928"}
0005433453770	5729A2	8442 043309	VALENTINA ALEKSEEVA	{"phone": "+70622101791"}
0005433453771	CF2F47	3521 245332	SERGEY MIRONOV	{"phone": "+70200826073"}
0005433453772	2C8B0D	1966 374302	VYACHESLAV SOROKIN	{"phone": "+70684644934"}
0005433453773	BA61CE	1622 200696	MIKHAIL KUZNECOV	{"email": "kuznecov_m_051977@postgrespro.ru", "phone": "+70350582773"}
0005433453774	363798	6001 564638	MATVEY MAKSIMOV	{"email": "m.maksimov08081970@postgrespro.ru", "phone": "+70066170733"}
0005433453775	839EAB	9582 701402	SERGEY SEMENOV	{"email": "sergey_semenov1975@postgrespro.ru", "phone": "+70599835190"}
0005433453776	839EAB	7632 444106	VLADIMIR SHEVCHENKO	{"email": "shevchenko.v.1970@postgrespro.ru", "phone": "+70848078648"}
0005433453777	C7D7A2	4213 279295	VLADIMIR DENISOV	{"phone": "+70323799217"}
0005433453778	69A902	4534 160526	MARIYA KISELEVA	{"phone": "+70614666920"}
0005433453779	522892	9573 526146	LYUBOV ILINA	{"email": "l_ilina.05041971@postgrespro.ru", "phone": "+70394309296"}
0005433453780	F43BA0	2907 045189	NIKOLAY GORBUNOV	{"email": "gorbunovnikolay.29011974@postgrespro.ru", "phone": "+70009501510"}
0005433453781	F43BA0	5086 230959	VITALIY ALEKSANDROV	{"phone": "+70276176539"}
0005433453782	B9D0D9	0384 378078	YURIY TIMOFEEV	{"phone": "+70457138972"}
0005433453783	B9D0D9	0893 838008	GALINA KRASNOVA	{"phone": "+70842746956"}
0005433453784	B9D0D9	8863 691112	VALENTINA ZHUKOVA	{"email": "zhukova-v_30011960@postgrespro.ru", "phone": "+70180084886"}
0005433453785	2B3401	5977 583604	ALEKSANDR IVANOV	{"phone": "+70152587230"}
0005433453786	2B3401	5496 326139	ALEKSANDR MIRONOV	{"email": "a.mironov-17011968@postgrespro.ru", "phone": "+70312534776"}
0005433453787	C525CE	0088 354208	IVAN YAKOVLEV	{"phone": "+70250253423"}
0005433453788	71BA81	5337 077059	ALEKSANDRA MEDVEDEVA	{"phone": "+70525821797"}
0005433453789	920BC9	4145 409695	OLGA KUZNECOVA	{"email": "kuznecova-olga.27121955@postgrespro.ru", "phone": "+70629524230"}
0005433453790	E69CCF	3586 363357	NATALIYA ARKHIPOVA	{"email": "arkhipovanataliya_04071966@postgrespro.ru", "phone": "+70208399366"}
0005433453791	E69CCF	6422 636695	ALEVTINA ROMANOVA	{"phone": "+70226985520"}
0005433453792	3D4659	7490 967206	VASILIY ALEKSEEV	{"phone": "+70123326496"}
0005433453793	3D4659	3532 349035	NADIYA ANDREEVA	{"phone": "+70509710029"}
0005433453794	1BF868	7767 218027	LILIYA NIKITINA	{"email": "nikitina.l061963@postgrespro.ru", "phone": "+70112289528"}
0005433453795	1BF868	7316 402233	VALENTINA SERGEEVA	{"email": "v-sergeeva.09011980@postgrespro.ru", "phone": "+70078376490"}
0005433453796	45AC99	6150 750878	LYUDMILA VOROBEVA	{"phone": "+70976628025"}
0005433453797	566FDE	6055 088189	VITALIY POPOV	{"phone": "+70702110397"}
0005433453798	3D8791	4675 426581	ALEKSANDR SERGEEV	{"phone": "+70614870209"}
0005433453799	3D8791	7051 596731	FILIPP SOLOVEV	{"email": "solovev_filipp1982@postgrespro.ru", "phone": "+70989887752"}
0005433453800	3D8791	2012 557473	DMITRIY SOLOVEV	{"phone": "+70788706445"}
0005433453801	A4C3A1	0938 280606	LARISA SOKOLOVA	{"email": "sokolovalarisa_081972@postgrespro.ru", "phone": "+70689528443"}
0005433453802	72054E	5275 258325	DMITRIY NIKOLAEV	{"phone": "+70386667449"}
0005433453803	72054E	9498 446390	OLGA PAVLOVA	{"email": "olga-pavlova091977@postgrespro.ru", "phone": "+70168158353"}
0005433453804	AB5774	3883 320155	VALENTINA TROFIMOVA	{"phone": "+70654687502"}
0005433453805	F4B703	1443 865695	SVETLANA LAZAREVA	{"email": "lazareva.svetlana-1966@postgrespro.ru", "phone": "+70414987595"}
0005433453806	F4B703	1940 163816	NIKOLAY ALEKSEEV	{"phone": "+70696757590"}
0005433453807	DC26A1	5797 737032	ALEKSEY VOROBEV	{"phone": "+70485222800"}
0005433453808	DC26A1	5964 007542	ALEKSANDR FEDOTOV	{"phone": "+70981489225"}
0005433453809	C887A2	8153 554350	ALEKSEY SHEVCHENKO	{"phone": "+70364038770"}
0005433453810	C415BE	2931 548814	ANDREY SEMENOV	{"phone": "+70960737083"}
0005433453811	6174AD	3904 585536	NIKITA VOROBEV	{"phone": "+70981883147"}
0005433453812	B7EE12	4367 615156	VIKTOR TIMOFEEV	{"phone": "+70798773606"}
0005433453813	B7EE12	2501 969215	ALEKSANDRA BORISOVA	{"email": "aborisova031967@postgrespro.ru", "phone": "+70155642343"}
0005433453814	B35CF3	7243 728389	OLGA ZOTOVA	{"phone": "+70293046929"}
0005433453815	91A409	0639 992806	VERA ANTONOVA	{"email": "antonova-vera-071970@postgrespro.ru", "phone": "+70744621956"}
0005433453816	91A409	8030 907150	VLADIMIR SOKOLOV	{"phone": "+70486390785"}
0005433453817	91A409	1608 162238	DMITRIY KUZNECOV	{"email": "kuznecovd.051965@postgrespro.ru", "phone": "+70128556396"}
0005433453818	C5080C	0870 429707	ANASTASIYA SOLOVEVA	{"email": "anastasiyasoloveva_1975@postgrespro.ru", "phone": "+70847137818"}
0005433453819	118DA8	7884 121575	NINA POPOVA	{"email": "n_popova-041979@postgrespro.ru", "phone": "+70965964554"}
0005433453820	E07835	2988 274609	MARIYA VASILEVA	{"phone": "+70756871064"}
0005433454927	249F14	9444 304794	YURIY EGOROV	{"phone": "+70610336305"}
0005433454837	BF82BA	5649 373905	DMITRIY KAZAKOV	{"email": "d.kazakov.121969@postgrespro.ru", "phone": "+70384279552"}
0005433454838	BF82BA	0640 456343	ASKHAT FEDOTOV	{"phone": "+70729329929"}
0005433454839	AB629F	0740 374089	LEONID BELOV	{"email": "belovleonid_051964@postgrespro.ru", "phone": "+70017434055"}
0005433454840	AB629F	4867 589970	KIRILL GORBUNOV	{"phone": "+70853595676"}
0005433454841	99D0AA	2960 473664	MARIYA ANDREEVA	{"email": "m-andreeva30041971@postgrespro.ru", "phone": "+70639350653"}
0005433454842	99D0AA	1594 579141	VLADIMIR FEDOTOV	{"phone": "+70295814989"}
0005433454843	6B4E48	1565 110327	ELENA ZAYCEVA	{"phone": "+70341900109"}
0005433454844	4EFC7A	7851 311395	NATALYA MAKAROVA	{"phone": "+70986467960"}
0005433454845	935BC2	8893 210405	ANTONINA MATVEEVA	{"email": "matveeva_a_031967@postgrespro.ru", "phone": "+70773760688"}
0005433454846	935BC2	8755 783448	STANISLAV ORLOV	{"email": "sorlov_031961@postgrespro.ru", "phone": "+70892513058"}
0005433454847	02043B	1481 248715	SERGEY KUZNECOV	{"phone": "+70357625939"}
0005433454848	3C9095	8001 726007	TATYANA EFREMOVA	{"email": "t-efremova.21101973@postgrespro.ru", "phone": "+70946479914"}
0005433454849	FB2C98	4235 715576	VLADIMIR KONOVALOV	{"phone": "+70733370674"}
0005433454850	FB2C98	3497 943107	VIKTOR KULIKOV	{"email": "viktor_kulikov.021978@postgrespro.ru", "phone": "+70698940983"}
0005433454851	572720	1026 622961	OKSANA NIKOLAEVA	{"phone": "+70644646383"}
0005433454852	2D174A	1457 758954	VLADIMIR ALEKSANDROV	{"email": "v-aleksandrov-081985@postgrespro.ru", "phone": "+70781475687"}
0005433454853	D4869D	3690 129247	ELENA AFANASEVA	{"email": "afanaseva-elena.21011969@postgrespro.ru", "phone": "+70891541160"}
0005433454854	433452	5816 981364	NIKOLAY DENISOV	{"phone": "+70834561821"}
0005433454855	433452	4265 337018	VLADIMIR KONOVALOV	{"phone": "+70051961395"}
0005433454856	6FE7DF	1332 506859	VALERIYA KOROLEVA	{"email": "valeriya-koroleva_1988@postgrespro.ru", "phone": "+70653007269"}
0005433454857	280C88	5524 607646	DENIS ZHUKOV	{"email": "zhukov.denis_101967@postgrespro.ru", "phone": "+70944878512"}
0005433454858	526E68	4059 722425	OLGA ZOTOVA	{"phone": "+70584904350"}
0005433454859	8C5509	1420 777522	SERGEY PETROV	{"phone": "+70675976978"}
0005433454860	6518E9	3783 815857	ELENA LUKYANOVA	{"phone": "+70813812288"}
0005433454861	6518E9	3586 287860	YURIY FROLOV	{"email": "frolovyuriy1978@postgrespro.ru", "phone": "+70298764048"}
0005433454862	6518E9	9342 042813	KLAVDIYA SOKOLOVA	{"email": "sokolova_klavdiya.1973@postgrespro.ru", "phone": "+70897579762"}
0005433454863	8406E9	1656 714115	SERGEY GORBUNOV	{"phone": "+70350981178"}
0005433454864	674D11	3098 383179	KLAVDIYA DAVYDOVA	{"phone": "+70021131685"}
0005433454865	B87FDC	1769 711391	SERGEY KULIKOV	{"email": "kulikov_s-1969@postgrespro.ru", "phone": "+70669234798"}
0005433454866	B87FDC	9644 282900	NIKOLAY FROLOV	{"phone": "+70016843488"}
0005433454867	47771C	9729 165124	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin121972@postgrespro.ru", "phone": "+70166715229"}
0005433454868	47771C	8117 410886	FARIDA MAKAROVA	{"phone": "+70785011433"}
0005433454869	47771C	0161 572077	IVAN MOROZOV	{"email": "morozovi1977@postgrespro.ru", "phone": "+70648615862"}
0005433454870	56A871	7679 534172	DENIS NAZAROV	{"phone": "+70270740855"}
0005433454871	C201FE	1528 579253	YURIY ANDREEV	{"phone": "+70749173799"}
0005433454872	C201FE	5367 102512	ELENA SEMENOVA	{"email": "elena.semenova_1960@postgrespro.ru", "phone": "+70815843180"}
0005433454873	8479BD	3016 922300	NINA IVANOVA	{"email": "nina.ivanova051972@postgrespro.ru", "phone": "+70331182096"}
0005433454874	4E6D6F	5004 807082	EVA POPOVA	{"phone": "+70278397764"}
0005433454875	4E6D6F	1713 847562	ZLATA KUZMINA	{"phone": "+70862624908"}
0005433454876	26C43C	3681 425851	SERGEY FOMIN	{"email": "fomin.sergey.1962@postgrespro.ru", "phone": "+70183788864"}
0005433454877	16AE0B	9004 320509	RAFIK MIKHAYLOV	{"email": "rmikhaylov_121971@postgrespro.ru", "phone": "+70616412751"}
0005433454878	16AE0B	8790 249587	ALEKSEY NAZAROV	{"email": "nazarov_a_17071970@postgrespro.ru", "phone": "+70030549588"}
0005433454879	64A45B	7816 374821	GENNADIY SHEVCHENKO	{"email": "g-shevchenko-081966@postgrespro.ru", "phone": "+70478288162"}
0005433454880	64A45B	8910 898569	FEDOR ZAKHAROV	{"email": "zakharov_fedor-11121962@postgrespro.ru", "phone": "+70011157219"}
0005433454881	63252D	8176 459672	ARTEMIY IVANOV	{"email": "a.ivanov_101981@postgrespro.ru", "phone": "+70674985849"}
0005433454882	AE0C2D	1895 591780	YULIYA VLASOVA	{"email": "yuliyavlasova_07011974@postgrespro.ru", "phone": "+70222703630"}
0005433454883	9E7FFF	1590 272840	EVGENIY MOROZOV	{"email": "morozov-evgeniy20121969@postgrespro.ru", "phone": "+70393559190"}
0005433454884	9E7FFF	4947 141475	EDUARD AFANASEV	{"phone": "+70952993579"}
0005433454885	3CE096	5161 343747	ANNA POLYAKOVA	{"email": "polyakova_anna_1968@postgrespro.ru", "phone": "+70982102295"}
0005433454886	3CE096	4751 932236	IVAN ZAYCEV	{"email": "i.zaycev.1964@postgrespro.ru", "phone": "+70636488476"}
0005433454887	1FA05B	8333 011339	GALINA NOVIKOVA	{"email": "novikova.galina.1980@postgrespro.ru", "phone": "+70496035728"}
0005433454888	6C0259	3369 276137	IRINA TIKHONOVA	{"email": "tikhonova_irina-011975@postgrespro.ru", "phone": "+70131340021"}
0005433454889	5322B1	2079 874837	MARGARITA LAZAREVA	{"phone": "+70929418777"}
0005433454890	5322B1	0761 877251	NIKOLAY ANTONOV	{"phone": "+70471672862"}
0005433454891	5322B1	6974 826185	ALEKSANDR DAVYDOV	{"phone": "+70113339830"}
0005433454892	7EF782	9524 014292	ANDREY ALEKSANDROV	{"email": "aleksandrov-andrey_1980@postgrespro.ru", "phone": "+70868034690"}
0005433454893	7EF782	7059 365324	MARIYA MIRONOVA	{"email": "m-mironova1972@postgrespro.ru", "phone": "+70787970365"}
0005433454894	0C2FAC	5759 489758	OLGA VOLKOVA	{"email": "volkova_olga.10091981@postgrespro.ru", "phone": "+70537089921"}
0005433454895	49638C	8118 225183	ELENA ABRAMOVA	{"phone": "+70139659598"}
0005433454896	F8AECD	6845 269286	ANDREY IVANOV	{"email": "a.ivanov_021983@postgrespro.ru", "phone": "+70691182887"}
0005433454897	F8AECD	5911 083798	VERA NOVIKOVA	{"phone": "+70704792641"}
0005433454898	210980	5787 995546	VALENTINA MAKSIMOVA	{"email": "maksimovavalentina.021958@postgrespro.ru", "phone": "+70078530508"}
0005433454899	5FA44E	8705 882825	ALEKSEY ANTONOV	{"email": "aleksey_antonov-1988@postgrespro.ru", "phone": "+70753117442"}
0005433454900	A485E2	5941 913165	VLADIMIR ANDREEV	{"email": "v_andreev-08041960@postgrespro.ru", "phone": "+70338608084"}
0005433454901	DA7086	7545 363859	NATALYA VASILEVA	{"phone": "+70756400915"}
0005433454902	EC97EE	6964 978871	ALESYA PETROVA	{"email": "petrova_alesya_1961@postgrespro.ru", "phone": "+70239125167"}
0005433454903	EFEC72	5809 363413	MARINA DMITRIEVA	{"phone": "+70926869515"}
0005433454904	EFEC72	9342 463444	VIKTORIYA DAVYDOVA	{"email": "v_davydova_061973@postgrespro.ru", "phone": "+70235529545"}
0005433454905	EFAF95	4706 036290	ELENA TARASOVA	{"email": "etarasova-1975@postgrespro.ru", "phone": "+70855205282"}
0005433454906	4F2BC6	7930 300339	ELENA ABRAMOVA	{"email": "elena_abramova-1984@postgrespro.ru", "phone": "+70728520735"}
0005433454907	E8C03A	3181 787101	OLGA MEDVEDEVA	{"phone": "+70933180686"}
0005433454908	79160D	4208 905507	DMITRIY ILIN	{"email": "ilin.d_09021975@postgrespro.ru", "phone": "+70730381489"}
0005433454909	5286CA	9252 921262	OKSANA EFIMOVA	{"phone": "+70636503452"}
0005433454910	F178F8	1165 024968	EKATERINA YAKOVLEVA	{"phone": "+70692592802"}
0005433454911	F178F8	4233 777405	ANNA POPOVA	{"email": "anna_popova.031969@postgrespro.ru", "phone": "+70734615028"}
0005433454912	946AAB	9061 306169	NIKOLAY ANTONOV	{"email": "nikolay_antonov.27031975@postgrespro.ru", "phone": "+70780222157"}
0005433454913	7F165A	0429 030022	ANATOLIY ROMANOV	{"phone": "+70601274569"}
0005433454914	7F165A	6072 073316	NIKOLAY DENISOV	{"email": "n.denisov.101971@postgrespro.ru", "phone": "+70527113219"}
0005433454915	AF5D99	2996 857113	SERGEY GAVRILOV	{"phone": "+70160438155"}
0005433454916	AFC6C9	6893 358204	ALEKSANDR SOKOLOV	{"email": "sokolova101973@postgrespro.ru", "phone": "+70461474419"}
0005433454917	00FBC7	7702 578224	DENIS SMIRNOV	{"phone": "+70983565234"}
0005433454918	418DCA	1219 562106	ALEKSEY SAVELEV	{"phone": "+70062432219"}
0005433454919	3A4FBC	1146 901410	ELVIRA KONOVALOVA	{"email": "e_konovalova.11051970@postgrespro.ru", "phone": "+70945600151"}
0005433454920	3A4FBC	6527 635412	OKSANA FOMINA	{"email": "o-fomina.101969@postgrespro.ru", "phone": "+70034923706"}
0005433454921	73A1F4	8610 011300	ILYA MAKSIMOV	{"email": "maksimovilya_121974@postgrespro.ru", "phone": "+70891389495"}
0005433454922	73A1F4	4148 899727	INNA VOLKOVA	{"phone": "+70727361442"}
0005433454923	001D96	6386 102697	VALERIY NAZAROV	{"email": "nazarov.v_13031976@postgrespro.ru", "phone": "+70809014659"}
0005433454924	001D96	7904 431173	VALERIYA LOGINOVA	{"phone": "+70208658245"}
0005433454925	E84753	3735 831770	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov.061971@postgrespro.ru", "phone": "+70271032034"}
0005433454926	E84753	6313 158538	ALEKSANDR SCHERBAKOV	{"phone": "+70946860878"}
0005433454928	249F14	6506 778239	MARIYA MARTYNOVA	{"email": "martynova-m1971@postgrespro.ru", "phone": "+70049979579"}
0005433454929	D0F3BB	7094 734837	NIKOLAY GAVRILOV	{"email": "ngavrilov.09091977@postgrespro.ru", "phone": "+70943423031"}
0005433454930	A62CFB	0727 674896	OKSANA ORLOVA	{"email": "orlova_o-22081981@postgrespro.ru", "phone": "+70488925852"}
0005433454931	0B5052	2436 699929	ANNA TARASOVA	{"email": "anna.tarasova061974@postgrespro.ru", "phone": "+70732478137"}
0005433454932	E5080F	9805 148277	VLADIMIR YAKOVLEV	{"email": "vladimir.yakovlev.1978@postgrespro.ru", "phone": "+70295644896"}
0005433454933	4C0474	1069 798812	SVETLANA KOROLEVA	{"phone": "+70196725553"}
0005433454934	1290A2	1269 331682	SERGEY TIKHONOV	{"phone": "+70904863587"}
0005433456897	22CA10	2211 315183	ANDREY MOISEEV	{"email": "amoiseev-06071975@postgrespro.ru", "phone": "+70229345571"}
0005433456898	860113	0065 600399	VLADIMIR FOMIN	{"phone": "+70336291745"}
0005433456899	977FD2	1880 342422	EVGENIY KUZMIN	{"email": "kuzminevgeniy15071972@postgrespro.ru", "phone": "+70793309280"}
0005433456900	977FD2	7052 090066	LYUDMILA ABRAMOVA	{"email": "lyudmila-abramova.1955@postgrespro.ru", "phone": "+70160436783"}
0005433456901	3D9EF6	2518 195259	VLADIMIR POPOV	{"phone": "+70279383417"}
0005433456902	1C2BA2	3978 775059	ALEKSEY VASILEV	{"phone": "+70441124906"}
0005433456903	04DEEF	2695 829704	TAMARA KISELEVA	{"email": "kiseleva_t.1965@postgrespro.ru", "phone": "+70797457536"}
0005433456904	04DEEF	1247 388657	MIKHAIL KARPOV	{"phone": "+70752523887"}
0005433456905	45B8D4	5135 831522	DANILA VOLKOV	{"email": "volkov-danila031980@postgrespro.ru", "phone": "+70084582053"}
0005433456906	1FC239	1950 137181	OLGA MAKSIMOVA	{"phone": "+70889431900"}
0005433456907	F28644	4934 207247	ANASTASIYA TIMOFEEVA	{"phone": "+70400210571"}
0005433456908	F28644	1171 684896	ALEKSEY ZHURAVLEV	{"email": "zhuravlev_a_1961@postgrespro.ru", "phone": "+70290637591"}
0005433456909	BEC2FB	9427 598803	NATALYA PAVLOVA	{"email": "pavlova-natalya_03061974@postgrespro.ru", "phone": "+70563827223"}
0005433456910	BEC2FB	1248 151062	ANDREY ANDREEV	{"email": "andreev_andrey1981@postgrespro.ru", "phone": "+70478716258"}
0005433456911	435A3F	4345 153684	LYUBOV ALEKSEEVA	{"email": "alekseeva-l_1978@postgrespro.ru", "phone": "+70563607344"}
0005433456912	D1CB5B	2598 943323	NADEZHDA ZOTOVA	{"email": "zotova.nadezhda_1971@postgrespro.ru", "phone": "+70915571923"}
0005433456913	D1CB5B	6472 884470	ILYA GORBUNOV	{"phone": "+70447646942"}
0005433456914	715E79	4047 845297	MARINA IVANOVA	{"email": "ivanova_m.1969@postgrespro.ru", "phone": "+70733656722"}
0005433456915	4C1080	0989 354239	NATALIYA MIKHAYLOVA	{"phone": "+70584426359"}
0005433456916	C7018A	0632 830536	MARIYA AFANASEVA	{"phone": "+70465582842"}
0005433456917	E4590C	5901 052914	LIDIYA KUZNECOVA	{"phone": "+70464695292"}
0005433456918	C6E066	8179 892271	IRINA NIKITINA	{"phone": "+70309012802"}
0005433456919	C6E066	3385 213698	OLESYA KAZAKOVA	{"phone": "+70192201199"}
0005433456920	8CC303	0789 203638	SERGEY NIKITIN	{"email": "sergey-nikitin-031975@postgrespro.ru", "phone": "+70612755108"}
0005433456921	8DA079	6293 056012	SVETLANA YAKOVLEVA	{"phone": "+70649860546"}
0005433456922	8DA079	9476 305151	ANASTASIYA KUDRYASHOVA	{"phone": "+70690684248"}
0005433456923	A6E463	3683 343630	EVGENIY DAVYDOV	{"email": "davydov_e-01011980@postgrespro.ru", "phone": "+70772871349"}
0005433456924	19448A	9528 076655	DIANA MELNIKOVA	{"email": "diana.melnikova.011970@postgrespro.ru", "phone": "+70679307207"}
0005433456925	19448A	0977 205249	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana-1977@postgrespro.ru", "phone": "+70837409204"}
0005433456926	1BA6BA	8347 416687	ILYA NIKOLAEV	{"phone": "+70645265048"}
0005433459162	52E036	3726 743715	ALEKSEY ANTONOV	{"phone": "+70679244237"}
0005433456927	1BA6BA	0382 997976	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.05101974@postgrespro.ru", "phone": "+70797022478"}
0005433456928	02EBEF	2311 379563	ALEKSANDR TIMOFEEV	{"phone": "+70635396215"}
0005433456929	B7A86B	2148 050692	NIKOLAY BARANOV	{"email": "nikolaybaranov.071974@postgrespro.ru", "phone": "+70096780657"}
0005433456930	B7A86B	3688 156414	SERGEY NIKITIN	{"email": "s.nikitin_081978@postgrespro.ru", "phone": "+70318913089"}
0005433456931	3590B8	7465 683340	EVGENIYA MALYSHEVA	{"email": "malysheva.e.1961@postgrespro.ru", "phone": "+70462822782"}
0005433456932	CDD5C3	5573 039515	VALENTINA STEPANOVA	{"phone": "+70670472349"}
0005433456933	1D4922	4603 545752	SERGEY KARPOV	{"phone": "+70164103790"}
0005433456934	626465	5362 389463	VASILIY MOROZOV	{"phone": "+70216614059"}
0005433456935	00D413	1848 468470	GALINA KUDRYASHOVA	{"email": "kudryashova_galina03031961@postgrespro.ru", "phone": "+70913031888"}
0005433456936	2D647F	1040 600972	LIDIYA BELYAEVA	{"email": "belyaeva.lidiya.16011970@postgrespro.ru", "phone": "+70728429891"}
0005433456937	004364	8419 933265	IVAN ALEKSEEV	{"phone": "+70743249928"}
0005433456938	67F929	2475 518299	ALEKSANDR MOROZOV	{"phone": "+70398208279"}
0005433456939	53F3C8	6541 876203	MIKHAIL VASILEV	{"phone": "+70092429452"}
0005433456940	53F3C8	7839 867622	NINA FILIPPOVA	{"phone": "+70022168523"}
0005433456941	53F3C8	8401 422936	ALEKSANDRA TITOVA	{"email": "titova.aleksandra-1981@postgrespro.ru", "phone": "+70176552328"}
0005433456942	A99287	2331 429593	ILYAS SEMENOV	{"phone": "+70975122795"}
0005433456943	A99287	0509 477205	MARIYA KOZLOVA	{"phone": "+70450720619"}
0005433456944	197F28	2455 632244	SERGEY MAKSIMOV	{"phone": "+70432923770"}
0005433456945	077C97	6143 450181	ANTONINA ANISIMOVA	{"email": "a_anisimova_15031974@postgrespro.ru", "phone": "+70211911892"}
0005433456946	FDA6D7	8103 490315	NIKOLAY SOKOLOV	{"email": "sokolov_nikolay.111969@postgrespro.ru", "phone": "+70813822872"}
0005433456947	7E07C4	0551 346444	EVGENIY MAKAROV	{"phone": "+70737688129"}
0005433456948	7E07C4	0725 192047	ANNA MASLOVA	{"phone": "+70611354364"}
0005433456949	6B9A45	4232 010168	YULIYA ANTONOVA	{"email": "yuliya-antonova-031965@postgrespro.ru", "phone": "+70454788634"}
0005433456950	6B9A45	5757 240514	NIKOLAY SCHERBAKOV	{"phone": "+70187685772"}
0005433456951	6B9A45	2545 094462	VIKTOR PETROV	{"email": "v-petrov-1966@postgrespro.ru", "phone": "+70597166718"}
0005433456952	0EA370	7557 124124	TATYANA KISELEVA	{"phone": "+70433843158"}
0005433456953	FBC6E0	6311 740104	ILYA ZHUKOV	{"email": "zhukov_i051963@postgrespro.ru", "phone": "+70867706585"}
0005433456954	2F3978	9493 686392	NINA IVANOVA	{"phone": "+70325698033"}
0005433456955	2F3978	3599 768868	NADEZHDA BOGDANOVA	{"phone": "+70669893757"}
0005433456956	DCA9A0	9258 971051	ANDREY KUZNECOV	{"email": "kuznecova_04021982@postgrespro.ru", "phone": "+70263138050"}
0005433456957	FE23A7	5478 786251	KARINA ZOTOVA	{"phone": "+70613150427"}
0005433456958	F5327E	7703 892236	ANATOLIY GUSEV	{"phone": "+70149789898"}
0005433456959	F672BF	0977 404242	NIKOLAY VLASOV	{"phone": "+70480420374"}
0005433456960	210BA3	1724 812095	VALERIY FROLOV	{"phone": "+70663559420"}
0005433456961	210BA3	5805 297408	ANNA PAVLOVA	{"phone": "+70131041245"}
0005433456962	210BA3	2571 803012	SERGEY GUSEV	{"email": "s-gusev_1974@postgrespro.ru", "phone": "+70548816903"}
0005433456963	B5CD72	2522 108942	NATALYA KUZMINA	{"email": "kuzminanatalya111964@postgrespro.ru", "phone": "+70240285457"}
0005433456964	B5CD72	5523 720453	ANASTASIYA STEPANOVA	{"phone": "+70469584949"}
0005433456965	B5CD72	1971 953139	OLGA LOGINOVA	{"phone": "+70795100287"}
0005433456966	606DA0	0011 950944	ZINAIDA MATVEEVA	{"phone": "+70485187008"}
0005433456967	606DA0	2889 981161	MARINA CHERNOVA	{"phone": "+70218834829"}
0005433456968	606DA0	1710 013355	ANASTASIYA DANILOVA	{"phone": "+70715960504"}
0005433457080	0B60DD	5644 400027	NATALYA POPOVA	{"phone": "+70846225620"}
0005433456969	AE503B	7744 044723	ALEKSEY ZAKHAROV	{"email": "a.zakharov-02051981@postgrespro.ru", "phone": "+70186864958"}
0005433456970	6ACF27	5044 512176	ANDREY ALEKSANDROV	{"phone": "+70309213449"}
0005433456971	8377CA	5807 090639	ALEKSANDR GAVRILOV	{"phone": "+70422670494"}
0005433456972	8377CA	0275 953668	ROMAN ILIN	{"phone": "+70247960259"}
0005433456973	8377CA	7208 356175	ALEKSANDR EGOROV	{"phone": "+70852860243"}
0005433456974	F8F176	8301 439070	YURIY SAVELEV	{"phone": "+70267479067"}
0005433456975	F8F176	0591 533675	ANTON KONOVALOV	{"email": "konovalova-1969@postgrespro.ru", "phone": "+70681450368"}
0005433456976	5160A6	6281 370516	EVGENIY KOROLEV	{"phone": "+70173904154"}
0005433456977	827170	3021 234383	NADEZHDA ISAEVA	{"email": "n-isaeva-06071983@postgrespro.ru", "phone": "+70325441954"}
0005433456978	1E4167	0003 248552	ANNA DANILOVA	{"phone": "+70307704137"}
0005433456979	D2706E	9989 435744	VLADIMIR EGOROV	{"email": "vegorov1976@postgrespro.ru", "phone": "+70341624256"}
0005433456980	D2706E	1593 701321	ALEKSEY SEMENOV	{"phone": "+70369914557"}
0005433456981	77AE08	6859 273151	YULIYA ALEKSANDROVA	{"email": "aleksandrova.yuliya.031958@postgrespro.ru", "phone": "+70575399239"}
0005433456982	E2BBA4	4698 721846	DENIS FILIPPOV	{"phone": "+70811092504"}
0005433456983	E2BBA4	7941 585890	ANATOLIY KOZLOV	{"email": "kozlov.anatoliy.111965@postgrespro.ru", "phone": "+70317690497"}
0005433456984	6F087C	8536 794731	VALENTIN NIKITIN	{"email": "v_nikitin071960@postgrespro.ru", "phone": "+70469263999"}
0005433456985	B3F0E5	1731 654586	NIKOLAY BONDARENKO	{"phone": "+70498003737"}
0005433456986	B3F0E5	2584 616892	KIRILL MEDVEDEV	{"phone": "+70018394527"}
0005433456987	DBC337	2152 854026	ELENA KRASNOVA	{"email": "krasnova.elena.051977@postgrespro.ru", "phone": "+70363804621"}
0005433456988	573581	5881 096735	NIKOLAY BELOV	{"phone": "+70941836569"}
0005433459163	52E036	0610 003411	MARIANNA MIKHAYLOVA	{"phone": "+70236341293"}
0005433456989	668988	4617 718348	ALEKSEY ALEKSEEV	{"email": "aleksey-alekseev_041969@postgrespro.ru", "phone": "+70288258963"}
0005433456990	668988	2038 968908	VIKTOR MARTYNOV	{"email": "martynov.viktor-24021980@postgrespro.ru", "phone": "+70384632516"}
0005433456991	00556D	1522 179842	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev031972@postgrespro.ru", "phone": "+70137593024"}
0005433456992	00556D	9801 683915	OLGA YAKOVLEVA	{"phone": "+70482285220"}
0005433456993	00556D	8007 671602	MIKHAIL MAKSIMOV	{"phone": "+70719105948"}
0005433456994	C9B682	4112 061135	VALENTIN SCHERBAKOV	{"email": "scherbakov.v_021982@postgrespro.ru", "phone": "+70946487091"}
0005433456995	EACB67	9067 070654	SERGEY NAZAROV	{"email": "snazarov_24031969@postgrespro.ru", "phone": "+70774376499"}
0005433456996	EACB67	9916 538439	GALINA FOMINA	{"email": "fominag.1985@postgrespro.ru", "phone": "+70125754588"}
0005433456997	1D0C62	9070 153197	SERGEY MELNIKOV	{"email": "melnikov_s-011973@postgrespro.ru", "phone": "+70246139647"}
0005433456998	1D0C62	7382 182103	VIKTOR KOROLEV	{"email": "korolev_v.1964@postgrespro.ru", "phone": "+70196362596"}
0005433456999	1D0C62	1490 725220	NATALYA BELOVA	{"email": "belova_natalya1968@postgrespro.ru", "phone": "+70810523771"}
0005433457000	E77E03	9818 117378	GALINA SAVELEVA	{"phone": "+70378298058"}
0005433457001	051E9E	1008 250990	EKATERINA ORLOVA	{"phone": "+70718275598"}
0005433457002	051E9E	6233 844003	LYUBOV ZHURAVLEVA	{"phone": "+70165349220"}
0005433457003	051E9E	5568 807724	VLADIMIR DENISOV	{"phone": "+70797872416"}
0005433457004	6CA567	0406 515433	ANNA KOZLOVA	{"email": "a.kozlova_1981@postgrespro.ru", "phone": "+70866232821"}
0005433457005	219E67	5629 390980	ALEKSANDR SEMENOV	{"email": "semenovaleksandr.011980@postgrespro.ru", "phone": "+70959628517"}
0005433457006	117463	6673 901142	ELIZAVETA LOGINOVA	{"email": "e.loginova-081984@postgrespro.ru", "phone": "+70860415796"}
0005433457007	DA8FBF	2089 634516	YULIYA RODIONOVA	{"email": "rodionova_y081973@postgrespro.ru", "phone": "+70073330602"}
0005433457008	DA8FBF	9555 843093	SERGEY SIDOROV	{"email": "s.sidorov_101978@postgrespro.ru", "phone": "+70504342250"}
0005433457009	97C977	2064 864122	INNA SOLOVEVA	{"phone": "+70878068327"}
0005433457010	97C977	7875 487370	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya-041967@postgrespro.ru", "phone": "+70882398548"}
0005433457011	FD9906	6034 109256	VLADIMIR ROMANOV	{"email": "romanovvladimir061974@postgrespro.ru", "phone": "+70865467955"}
0005433457012	FE5CBE	4334 726305	MATVEY SAVELEV	{"phone": "+70939500819"}
0005433457013	FE5CBE	0701 948798	ZOYA MEDVEDEVA	{"email": "zoyamedvedeva_14081962@postgrespro.ru", "phone": "+70255307067"}
0005433457014	7D9B75	9276 759476	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr-061974@postgrespro.ru", "phone": "+70768557416"}
0005433457015	D4F4FF	9386 065374	VALENTINA IVANOVA	{"email": "ivanova-v12061969@postgrespro.ru", "phone": "+70738008013"}
0005433457016	EFEDF3	1087 158956	ELENA SAVELEVA	{"phone": "+70248468461"}
0005433457017	EFEDF3	4123 055702	GALINA NIKITINA	{"email": "g_nikitina_021974@postgrespro.ru", "phone": "+70068346995"}
0005433457018	B419BF	0491 355179	ZLATA KOVALEVA	{"email": "z-kovaleva07091973@postgrespro.ru", "phone": "+70004063833"}
0005433457019	B419BF	8492 596347	ANTON MARTYNOV	{"email": "martynov-anton.1960@postgrespro.ru", "phone": "+70182328051"}
0005433457020	C66B4B	0649 995097	MIKHAIL BORISOV	{"email": "mborisov_1977@postgrespro.ru", "phone": "+70944556624"}
0005433457021	3072D9	7505 005529	ALFIYA YAKOVLEVA	{"phone": "+70152319569"}
0005433457022	3072D9	8009 781580	ZOYA KOROLEVA	{"email": "zoya_koroleva29091975@postgrespro.ru", "phone": "+70129208814"}
0005433457023	B6E3F9	9357 944236	EKATERINA MAKAROVA	{"email": "makarova_e.27081974@postgrespro.ru", "phone": "+70426499164"}
0005433457024	93886B	6594 208039	VALENTINA MOROZOVA	{"email": "valentina_morozova.111986@postgrespro.ru", "phone": "+70408480996"}
0005433457025	306422	2993 697641	VALENTIN STEPANOV	{"email": "vstepanov.061971@postgrespro.ru", "phone": "+70765364660"}
0005433457026	306422	0452 835127	ALEKSANDR ROMANOV	{"email": "aleksandrromanov_01071980@postgrespro.ru", "phone": "+70354194242"}
0005433457027	C0459B	7762 172222	ALEKSANDR POPOV	{"phone": "+70990032900"}
0005433457028	D92BF2	4196 687191	ALINA YUDINA	{"phone": "+70953662219"}
0005433457029	DBC7B2	0741 730290	YURIY FEDOROV	{"email": "yuriyfedorov_22111966@postgrespro.ru", "phone": "+70754354432"}
0005433457030	B6DBE7	9636 577329	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir_1971@postgrespro.ru", "phone": "+70891111101"}
0005433457031	9B81C9	9936 232089	TATYANA BORISOVA	{"phone": "+70980049119"}
0005433457032	9B81C9	5239 931110	ALEKSEY KOZLOV	{"email": "alekseykozlov1976@postgrespro.ru", "phone": "+70386590698"}
0005433457033	9618B9	5613 206358	DENIS MIKHAYLOV	{"phone": "+70505102901"}
0005433457034	489791	5588 093480	VIKTOR DMITRIEV	{"phone": "+70203741386"}
0005433457035	489791	3064 435802	SERGEY ANTONOV	{"phone": "+70304969989"}
0005433457036	D8B58C	9508 708876	VENIAMIN DENISOV	{"phone": "+70145334460"}
0005433457037	D8B58C	1520 890708	VLADISLAV KOZLOV	{"phone": "+70333784168"}
0005433457038	486EF2	5875 670680	ARSEN ORLOV	{"email": "orlova-16011973@postgrespro.ru", "phone": "+70363223756"}
0005433457039	8EEB66	7788 082181	MARINA ANTONOVA	{"phone": "+70147824309"}
0005433457040	4CDFDF	5333 760410	SVETLANA GERASIMOVA	{"phone": "+70809618742"}
0005433457041	4CDFDF	6311 999534	VIKTORIYA KOZLOVA	{"phone": "+70053015951"}
0005433457042	ACA2B9	5019 026133	ALEKSANDR VOLKOV	{"email": "volkov-a091964@postgrespro.ru", "phone": "+70240452549"}
0005433457043	ACA2B9	4885 525922	YULIYA KOROLEVA	{"email": "y_koroleva-081965@postgrespro.ru", "phone": "+70220035679"}
0005433457044	ACA2B9	3634 186671	NIKITA KULIKOV	{"phone": "+70684565255"}
0005433457045	C7B412	0454 610816	VIOLETTA MAKSIMOVA	{"email": "v-maksimova-1961@postgrespro.ru", "phone": "+70358785370"}
0005433457046	C7B412	5120 492865	ALEKSANDR ORLOV	{"phone": "+70524590401"}
0005433457047	B762B3	0104 672975	RAISA KOROLEVA	{"phone": "+70606844807"}
0005433457048	B762B3	4804 115201	VIKTOR STEPANOV	{"email": "v_stepanov.17041974@postgrespro.ru", "phone": "+70859071744"}
0005433457049	0F2C6E	9906 837556	MARIYA NIKOLAEVA	{"email": "nikolaeva.mariya.1980@postgrespro.ru", "phone": "+70714259434"}
0005433457050	0F2C6E	2226 269626	GALINA GAVRILOVA	{"phone": "+70784696813"}
0005433457051	6025D0	2280 806909	FANIYA PETROVA	{"email": "faniya-petrova_1972@postgrespro.ru", "phone": "+70760983196"}
0005433457052	D219D6	5696 068384	GLEB NIKOLAEV	{"email": "gleb.nikolaev_1974@postgrespro.ru", "phone": "+70920644764"}
0005433457053	848A70	2485 378398	ELENA TIMOFEEVA	{"phone": "+70156745020"}
0005433457054	813708	8378 160582	RIMMA ILINA	{"phone": "+70358021454"}
0005433457055	813708	0067 741266	ANTON MEDVEDEV	{"phone": "+70590445321"}
0005433457056	FA6132	9053 544539	NADEZHDA NAZAROVA	{"email": "nazarovan-31121978@postgrespro.ru", "phone": "+70066866955"}
0005433457057	388AB0	3631 294524	MARINA BARANOVA	{"phone": "+70142500276"}
0005433457058	44937D	8118 447335	ANDREY DENISOV	{"phone": "+70058479527"}
0005433457059	283E77	6006 293958	ARTEM SCHERBAKOV	{"email": "scherbakov.a.15051957@postgrespro.ru", "phone": "+70605689560"}
0005433457060	283E77	3103 800943	ANNA EFREMOVA	{"email": "efremova-a_071971@postgrespro.ru", "phone": "+70219337542"}
0005433457061	6ACD32	7093 473099	DMITRIY SHEVCHENKO	{"email": "dmitriy_shevchenko-1971@postgrespro.ru", "phone": "+70872027183"}
0005433457062	C011CD	6361 580936	NATALYA BORISOVA	{"phone": "+70270089614"}
0005433457063	65CA69	7804 793996	YURIY PETROV	{"email": "petrov.y-20041973@postgrespro.ru", "phone": "+70970995467"}
0005433457064	65CA69	8745 925696	SVETLANA BORISOVA	{"phone": "+70660966664"}
0005433457065	1324E1	1038 375314	GENNADIY KOZLOV	{"email": "kozlov_g1970@postgrespro.ru", "phone": "+70703429659"}
0005433457066	36FCF8	6011 702187	TATYANA POPOVA	{"email": "t.popova111978@postgrespro.ru", "phone": "+70000691424"}
0005433457067	DE2415	5615 524232	GALINA MARTYNOVA	{"phone": "+70707363098"}
0005433457068	DE2415	5701 501155	ELVIRA RYABOVA	{"email": "ryabova.elvira_23071980@postgrespro.ru", "phone": "+70188716201"}
0005433457069	C340C9	8510 304248	PAVEL DAVYDOV	{"email": "davydov_pavel071969@postgrespro.ru", "phone": "+70931403411"}
0005433457070	C340C9	4088 266841	ZAKHAR POPOV	{"phone": "+70445994634"}
0005433457071	80A004	8431 210812	ALEKSANDR POPOV	{"email": "popov-aleksandr1969@postgrespro.ru", "phone": "+70073310714"}
0005433457072	7B1D03	7051 359936	OLEG SMIRNOV	{"email": "smirnov_oleg111964@postgrespro.ru", "phone": "+70459026908"}
0005433457073	7B1D03	8572 553096	ANDREY ZAYCEV	{"phone": "+70706282699"}
0005433457074	255C7D	4084 236835	IGOR ALEKSANDROV	{"email": "i.aleksandrov_13051971@postgrespro.ru", "phone": "+70560417845"}
0005433457075	8E4B22	6001 729358	VYACHESLAV SOLOVEV	{"email": "solovev_vyacheslav.011976@postgrespro.ru", "phone": "+70201100613"}
0005433457076	8E4B22	2476 370735	ALEKSANDR GERASIMOV	{"email": "a-gerasimov15081977@postgrespro.ru", "phone": "+70964964120"}
0005433457077	AB978E	6340 251592	ANDREY ZAYCEV	{"phone": "+70657625141"}
0005433457078	FFBD28	4378 589279	OLGA DENISOVA	{"email": "denisovao.1978@postgrespro.ru", "phone": "+70709006715"}
0005433457079	FFBD28	4468 552158	VLADIMIR GRIGOREV	{"email": "v_grigorev1986@postgrespro.ru", "phone": "+70946626096"}
0005433457081	0B60DD	8697 424192	TAISIYA POPOVA	{"email": "t_popova-24081981@postgrespro.ru", "phone": "+70763173557"}
0005433457082	0B60DD	4985 920683	ANASTASIYA TITOVA	{"email": "a.titova_17121966@postgrespro.ru", "phone": "+70662843779"}
0005433457083	2910C5	8457 287758	IRINA NAZAROVA	{"email": "nazarova-irina.091978@postgrespro.ru", "phone": "+70414307552"}
0005433457084	B27F43	3674 929991	OKSANA FADEEVA	{"phone": "+70438999274"}
0005433457085	F26779	7725 250334	KIRILL FILIPPOV	{"email": "filippovkirill_10091968@postgrespro.ru", "phone": "+70757803095"}
0005433457086	57C013	7858 416433	ARTEM RODIONOV	{"email": "rodionovartem-091973@postgrespro.ru", "phone": "+70003677980"}
0005433457087	6B2A7E	5868 232597	ELENA SEMENOVA	{"email": "e_semenova-16061977@postgrespro.ru", "phone": "+70466752577"}
0005433457088	D78ABE	6331 861977	EVGENIY KISELEV	{"phone": "+70253236023"}
0005433459143	259FC9	6422 344005	VLADIMIR GRIGOREV	{"email": "v-grigorev.091980@postgrespro.ru", "phone": "+70021800240"}
0005433459144	259FC9	7945 132739	MAKSIM IVANOV	{"email": "maksimivanov-071966@postgrespro.ru", "phone": "+70878852247"}
0005433459145	D0300F	5307 763551	VIKTOR POPOV	{"phone": "+70152667404"}
0005433459146	A6DD52	8020 984671	GENNADIY KUZNECOV	{"phone": "+70092036553"}
0005433459147	36B6AF	6351 407664	DMITRIY PAVLOV	{"email": "pavlov-d-1975@postgrespro.ru", "phone": "+70888950118"}
0005433459148	EA0EEF	3604 137203	SVETLANA MELNIKOVA	{"phone": "+70159181093"}
0005433459149	EA0EEF	3056 222120	ROMAN GUSEV	{"phone": "+70677865207"}
0005433459150	313BFE	1933 439652	VALENTINA YAKOVLEVA	{"email": "yakovleva_v-17011965@postgrespro.ru", "phone": "+70115551406"}
0005433459151	313BFE	0188 196709	NIKOLAY VASILEV	{"email": "vasilev.n-13101966@postgrespro.ru", "phone": "+70489570231"}
0005433459152	E4831F	0445 913854	IRINA MIRONOVA	{"phone": "+70727801932"}
0005433459153	1C2254	6643 380736	ELENA KUZNECOVA	{"email": "kuznecova.e19041979@postgrespro.ru", "phone": "+70812018652"}
0005433459154	BD3E73	1509 224220	SERGEY YAKOVLEV	{"email": "yakovlevs04011977@postgrespro.ru", "phone": "+70022299174"}
0005433459155	BD3E73	9445 895562	ROZA MOROZOVA	{"phone": "+70238643479"}
0005433459156	4EF479	7435 109361	GALINA POPOVA	{"phone": "+70175873033"}
0005433459157	AB701E	3009 272230	IGOR KAZAKOV	{"phone": "+70599575935"}
0005433459158	AB701E	0870 172238	NADEZHDA DANILOVA	{"email": "danilova_nadezhda30011976@postgrespro.ru", "phone": "+70226604306"}
0005433459159	5D0225	8631 365927	GALINA FROLOVA	{"email": "frolova.g_1969@postgrespro.ru", "phone": "+70667892369"}
0005433459160	C35BE4	7695 712197	EVGENIYA ZOTOVA	{"phone": "+70624191698"}
0005433459161	C35BE4	1108 378528	PAVEL SOKOLOV	{"phone": "+70181610281"}
0005433459164	52E036	7716 990587	LARISA ALEKSEEVA	{"email": "alekseeva_larisa.08061981@postgrespro.ru", "phone": "+70874059865"}
0005433459165	8655C3	0026 031435	GALINA SIDOROVA	{"phone": "+70902195529"}
0005433459166	B6EE71	5976 599630	ALEKSEY ABRAMOV	{"email": "abramov-a06051974@postgrespro.ru", "phone": "+70203579771"}
0005433459167	8F2687	4731 301994	MARIYA STEPANOVA	{"phone": "+70848428285"}
0005433459168	B9AB18	5054 766606	DAVID VOROBEV	{"email": "vorobev_david-01121967@postgrespro.ru", "phone": "+70906727333"}
0005433459169	62DCF4	0954 827057	LIDIYA MELNIKOVA	{"email": "lidiyamelnikova121976@postgrespro.ru", "phone": "+70520798550"}
0005433459170	62DCF4	9594 923453	IRINA VLASOVA	{"email": "irina.vlasova1963@postgrespro.ru", "phone": "+70415603221"}
0005433459171	AD4588	7794 304706	ALEKSANDR MOROZOV	{"phone": "+70204569204"}
0005433459172	028126	5560 097960	ALEKSANDR MAKSIMOV	{"email": "a-maksimov_1974@postgrespro.ru", "phone": "+70929677074"}
0005433459173	852BA6	6065 855778	NATALYA LEBEDEVA	{"phone": "+70206915803"}
0005433459174	852BA6	4343 315880	INNA KISELEVA	{"phone": "+70365472935"}
0005433459175	DA1191	8499 310242	PAVEL FILIPPOV	{"email": "filippov_pavel-1974@postgrespro.ru", "phone": "+70121308408"}
0005433459176	989DBE	5535 031759	ELENA MIRONOVA	{"phone": "+70951996131"}
0005433459177	38DE1F	9484 868327	MAKSIM VOLKOV	{"email": "maksim-volkov-051966@postgrespro.ru", "phone": "+70360896946"}
0005433459178	239BA7	4808 088395	ANNA ZAKHAROVA	{"phone": "+70768015855"}
0005433459179	239BA7	3789 893749	NINA KOMAROVA	{"phone": "+70801801106"}
0005433459180	BE592C	2217 965204	OKSANA VOLKOVA	{"email": "o-volkova_071977@postgrespro.ru", "phone": "+70545458593"}
0005433459181	BE592C	3075 232802	LYUDMILA KOVALEVA	{"phone": "+70786320219"}
0005433459182	02B7C9	2021 819416	SVETLANA POPOVA	{"phone": "+70409461841"}
0005433459183	2657A3	4782 435566	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova_20091965@postgrespro.ru", "phone": "+70148385754"}
0005433459184	2657A3	1654 685855	NIKOLAY MELNIKOV	{"email": "nikolaymelnikov_1969@postgrespro.ru", "phone": "+70759326416"}
0005433459185	36920E	2766 492590	OLGA MAKSIMOVA	{"phone": "+70019927442"}
0005433459186	36920E	1894 331397	LYUDMILA LOGINOVA	{"phone": "+70611111999"}
0005433459187	3E1E42	6604 198142	SERGEY SEMENOV	{"email": "semenov_s_1961@postgrespro.ru", "phone": "+70039329599"}
0005433459188	3E1E42	3154 121257	ALEKSANDR ZHUKOV	{"email": "a.zhukov.1964@postgrespro.ru", "phone": "+70996164826"}
0005433459189	3E1E42	9579 585263	VALENTINA ERMAKOVA	{"phone": "+70927841685"}
0005433459190	6C45A4	1376 451009	PAVEL KOROLEV	{"email": "p.korolev_07031976@postgrespro.ru", "phone": "+70338420624"}
0005433459191	6C45A4	0105 900991	VLADIMIR ABRAMOV	{"email": "v.abramov_031975@postgrespro.ru", "phone": "+70879093918"}
0005433459192	6909D8	5993 799823	DENIS SEMENOV	{"email": "denis-semenov22111967@postgrespro.ru", "phone": "+70665952599"}
0005433459193	B3118F	7503 971681	DMITRIY VASILEV	{"email": "vasilev_dmitriy-1959@postgrespro.ru", "phone": "+70964858696"}
0005433459194	B3118F	3904 380964	NATALYA KOZLOVA	{"email": "natalya.kozlova-23121960@postgrespro.ru", "phone": "+70784610607"}
0005433459195	3033E4	2825 883902	TATYANA SEMENOVA	{"email": "t-semenova.17051975@postgrespro.ru", "phone": "+70139556308"}
0005433459196	3033E4	4699 197350	ALEKSANDRA EFREMOVA	{"email": "efremovaa-1968@postgrespro.ru", "phone": "+70800430294"}
0005433459197	3033E4	7933 149389	VALENTINA ZAKHAROVA	{"email": "zakharova_valentina_1978@postgrespro.ru", "phone": "+70868750853"}
0005433459198	67FFF3	9560 422777	ALEKSEY POPOV	{"phone": "+70955186769"}
0005433459199	AB7E95	5425 303659	GALINA BORISOVA	{"phone": "+70230692885"}
0005433459200	93B628	1386 672344	VLADISLAV KULIKOV	{"phone": "+70448943778"}
0005433459201	D642E3	6026 829565	SERGEY BARANOV	{"phone": "+70877693648"}
0005433459202	D642E3	8992 587663	IRINA EGOROVA	{"email": "egorova.irina_081965@postgrespro.ru", "phone": "+70049021913"}
0005433459203	FC61AA	8855 305247	OLGA YAKOVLEVA	{"phone": "+70347076076"}
0005433459204	11D692	2179 831425	LYUDMILA EFREMOVA	{"email": "efremova-l_041972@postgrespro.ru", "phone": "+70488908767"}
0005433459205	EBC258	8942 609866	NAILYA RYABOVA	{"email": "nailya-ryabova1981@postgrespro.ru", "phone": "+70577403302"}
0005433459206	EBC258	7255 664895	ZOYA EGOROVA	{"email": "z_egorova1967@postgrespro.ru", "phone": "+70445862536"}
0005433459207	B0A2CA	1990 264861	EVGENIYA FILIPPOVA	{"email": "filippovaevgeniya_1967@postgrespro.ru", "phone": "+70377643784"}
0005433459208	B0A2CA	5511 788156	SANIYA KUZNECOVA	{"email": "kuznecovasaniya.1968@postgrespro.ru", "phone": "+70064745312"}
0005433459209	F30007	6671 137425	TATYANA MAKAROVA	{"phone": "+70463506382"}
0005433459210	7709EC	3932 770594	MARIYA ABRAMOVA	{"phone": "+70295536934"}
0005433459211	5BCD51	5702 003897	TAMARA KOROLEVA	{"email": "koroleva_t01061959@postgrespro.ru", "phone": "+70311041154"}
0005433459212	5BCD51	1414 430692	ROZALIYA ZAKHAROVA	{"email": "zakharova_r.24041973@postgrespro.ru", "phone": "+70873402746"}
0005433459213	5BCD51	9630 874736	ARTEM MAKAROV	{"phone": "+70305549054"}
0005433459214	20B897	8956 307559	ALSU GAVRILOVA	{"email": "gavrilovaalsu.111965@postgrespro.ru", "phone": "+70019435840"}
0005433459215	20B897	3562 059955	VLADIMIR ZHUKOV	{"phone": "+70207063053"}
0005433459216	719CBC	5213 252362	IGOR FROLOV	{"phone": "+70942706222"}
0005433459217	719CBC	2029 486172	KONSTANTIN SCHERBAKOV	{"email": "scherbakovk16031972@postgrespro.ru", "phone": "+70549396232"}
0005433459218	D3E7C4	8725 260660	SERGEY SERGEEV	{"phone": "+70331306120"}
0005433459219	86BBB6	8947 469399	EMIL BELOV	{"phone": "+70952820362"}
0005433459220	480E1D	0975 680401	ALENA ANTONOVA	{"email": "antonova-alena-071970@postgrespro.ru", "phone": "+70921130682"}
0005433459221	480E1D	4188 175857	ALEKSANDR DMITRIEV	{"phone": "+70716546193"}
0005433459222	B59AF8	1674 589661	KLAVDIYA TITOVA	{"email": "titova_klavdiya_1967@postgrespro.ru", "phone": "+70084945672"}
0005433459223	DDF661	4551 419984	ALEKSANDR NOVIKOV	{"phone": "+70904025072"}
0005433459224	DDF661	3844 666306	VASILIY KULIKOV	{"email": "kulikov-v.011966@postgrespro.ru", "phone": "+70599741139"}
0005433459225	2B832B	4387 427273	OLESYA PETROVA	{"phone": "+70777078420"}
0005433459226	EFE44D	5756 206563	VALERIY KRASNOV	{"email": "vkrasnov-021976@postgrespro.ru", "phone": "+70893564876"}
0005433459227	EFE44D	3746 325371	ALEKSEY KONOVALOV	{"email": "konovalova-18011972@postgrespro.ru", "phone": "+70417478553"}
0005433459228	40BDA3	4978 083091	PRASKOVYA LUKYANOVA	{"email": "praskovya-lukyanova_06071964@postgrespro.ru", "phone": "+70509289480"}
0005433459229	B3053D	8892 170257	PAVEL SHEVCHENKO	{"phone": "+70796944613"}
0005433459230	5056F6	7452 745912	MAKSIM IVANOV	{"phone": "+70546373921"}
0005433459231	5056F6	9693 464661	VALERIY FILIPPOV	{"phone": "+70738288722"}
0005433459232	6F5119	1607 343643	NATALYA DMITRIEVA	{"email": "dmitrieva.n1975@postgrespro.ru", "phone": "+70455826115"}
0005433459233	6F5119	5046 022003	ALEKSEY GAVRILOV	{"email": "a.gavrilov-1975@postgrespro.ru", "phone": "+70416143356"}
0005433459234	4C0A10	8248 186883	SERGEY CHERNOV	{"phone": "+70430360959"}
0005433459235	1F14B9	9028 937996	SVETLANA NESTEROVA	{"email": "s-nesterova_08091979@postgrespro.ru", "phone": "+70684315300"}
0005433459236	E3CCAB	0842 010030	OLGA MASLOVA	{"phone": "+70152668500"}
0005433459237	E3CCAB	8234 576192	YULIYA FEDOROVA	{"email": "fedorova-y_1970@postgrespro.ru", "phone": "+70399677458"}
0005433459238	61198A	2998 335254	ALEKSANDR DENISOV	{"phone": "+70270215777"}
0005433459239	61198A	3753 265210	SVETLANA IVANOVA	{"phone": "+70638871070"}
0005433459240	007F74	9884 321958	ALEKSANDR BARANOV	{"email": "baranovaleksandr-16011970@postgrespro.ru", "phone": "+70120816427"}
0005433459241	AF32F4	3739 284843	ANDREY KUZNECOV	{"email": "a.kuznecov.01071978@postgrespro.ru", "phone": "+70091349856"}
0005433459242	AF32F4	1556 348626	OLGA OVCHINNIKOVA	{"email": "o.ovchinnikova.1968@postgrespro.ru", "phone": "+70369923892"}
0005433459243	588C99	9716 044678	DANILA ZAKHAROV	{"phone": "+70671816682"}
0005433459244	89175C	2153 842958	LYUDMILA KUDRYASHOVA	{"phone": "+70565593898"}
0005433459245	89175C	3073 017232	NADEZHDA SIDOROVA	{"phone": "+70736181775"}
0005433459246	E6302A	4586 694604	EGOR GUSEV	{"phone": "+70727912219"}
0005433459247	0DEEE2	7236 046507	YULIYA MAKAROVA	{"phone": "+70615928863"}
0005433459248	4C0054	1901 414082	TATYANA KOZLOVA	{"email": "kozlova.tatyana1968@postgrespro.ru", "phone": "+70225632945"}
0005433459249	4C0054	5549 266288	YULIYA NESTEROVA	{"phone": "+70384336819"}
0005433459250	9B323D	3713 410829	VYACHESLAV MATVEEV	{"phone": "+70998657999"}
0005433459251	950542	3262 732336	NATALYA SCHERBAKOVA	{"phone": "+70357218746"}
0005433459252	4CFE12	3115 632108	TATYANA LEBEDEVA	{"email": "tatyanalebedeva.021978@postgrespro.ru", "phone": "+70609681229"}
0005433459253	43B5EC	3160 020703	ANTON IVANOV	{"phone": "+70294106823"}
0005433459254	43B5EC	7415 608398	NADEZHDA KRASNOVA	{"email": "krasnovanadezhda.011962@postgrespro.ru", "phone": "+70973950929"}
0005433459255	F8B12C	1313 481023	OLGA IVANOVA	{"email": "ivanovaolga_03021985@postgrespro.ru", "phone": "+70523690962"}
0005433459256	F8B12C	5499 231350	TATYANA TIMOFEEVA	{"email": "tatyana.timofeeva.1973@postgrespro.ru", "phone": "+70489591307"}
0005433459257	F55EE4	6350 136980	ZOYA ZHUKOVA	{"email": "zhukovaz_22081967@postgrespro.ru", "phone": "+70006218779"}
0005433459258	880CEF	5422 390731	VLADIMIR ROMANOV	{"phone": "+70842951312"}
0005433459259	880CEF	0225 528417	TAMARA ALEKSEEVA	{"email": "t_alekseeva.1968@postgrespro.ru", "phone": "+70493296960"}
0005433459260	CE38C1	8185 994074	ZHANNA DANILOVA	{"email": "z.danilova-08091982@postgrespro.ru", "phone": "+70308016908"}
0005433459261	CE38C1	6583 079561	NATALYA ABRAMOVA	{"phone": "+70053001757"}
0005433459262	CE38C1	3557 736529	DINA GERASIMOVA	{"email": "gerasimovad_25121974@postgrespro.ru", "phone": "+70513836566"}
0005433459263	51A10B	9003 282828	VLADIMIR ORLOV	{"email": "vladimir.orlov_1967@postgrespro.ru", "phone": "+70951925883"}
0005433459264	F0A126	8089 829317	TATYANA GORBUNOVA	{"email": "gorbunovatatyana21111960@postgrespro.ru", "phone": "+70475071946"}
0005433459265	48CD53	6462 413099	IRINA FILIPPOVA	{"phone": "+70516102368"}
0005433459266	AAE3AB	9112 459625	SERGEY KUZNECOV	{"phone": "+70030393315"}
0005433459267	AD6873	9559 080093	IRINA ANDREEVA	{"phone": "+70324609789"}
0005433459268	24E01D	4236 375786	RUSLAN NAUMOV	{"phone": "+70487630619"}
0005433459269	235679	1145 717647	NIKOLAY ALEKSANDROV	{"phone": "+70807141909"}
0005433459270	235679	2593 167613	TATYANA SEMENOVA	{"email": "semenovatatyana03051956@postgrespro.ru", "phone": "+70212986901"}
0005433459271	C9D67B	4167 253671	IGOR GERASIMOV	{"phone": "+70363479383"}
0005433459272	C9D67B	9138 358208	DMITRIY KOZLOV	{"email": "d_kozlov091965@postgrespro.ru", "phone": "+70912338966"}
0005433459273	569352	6263 226748	VLADIMIR EGOROV	{"phone": "+70516446887"}
0005433459274	F4B1D0	3482 687802	OLEG NIKOLAEV	{"email": "o-nikolaev121972@postgrespro.ru", "phone": "+70910731410"}
0005433459275	F4B1D0	9267 527764	IRINA BOGDANOVA	{"phone": "+70732229725"}
0005433459276	D480F8	2371 412226	EVGENIY IVANOV	{"phone": "+70568301772"}
0005433459277	0B614B	6949 925497	ANTONINA PETROVA	{"phone": "+70615705760"}
0005433459278	0B614B	4707 104237	ALENA KUZNECOVA	{"phone": "+70360788740"}
0005433459279	47A38F	0443 168631	GALINA FEDOROVA	{"email": "fedorova_galina.1979@postgrespro.ru", "phone": "+70008492765"}
0005433459280	47A38F	1247 827018	VALENTINA POPOVA	{"email": "popovavalentina1974@postgrespro.ru", "phone": "+70687425409"}
0005433459281	1E713F	4096 380018	DMITRIY SOLOVEV	{"phone": "+70974531003"}
0005433459282	1E713F	8883 174999	VLADIMIR GERASIMOV	{"phone": "+70436892147"}
0005433459283	1E713F	6670 583816	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev_051988@postgrespro.ru", "phone": "+70422041511"}
0005433459284	C78A20	6398 718827	ZLATA FEDOROVA	{"phone": "+70048083851"}
0005433459285	0BA314	3959 968462	VALENTINA AFANASEVA	{"phone": "+70084472126"}
0005433459286	0BA314	3320 698887	DANIIL IVANOV	{"phone": "+70125743472"}
0005433459287	0BA314	1413 377091	VALENTINA ABRAMOVA	{"phone": "+70737998687"}
0005433459288	61C3BF	3995 392233	ALEKSANDR KUZNECOV	{"phone": "+70990842639"}
0005433459289	58FC16	1419 362759	IVAN NAZAROV	{"phone": "+70517462130"}
0005433459290	4C1659	5810 135233	VLADIMIR GERASIMOV	{"email": "vgerasimov_071975@postgrespro.ru", "phone": "+70619274048"}
0005433459291	28C121	2214 962859	NATALYA PETROVA	{"email": "npetrova-091979@postgrespro.ru", "phone": "+70022283361"}
0005433459292	28C121	9731 089506	ALEKSANDRA YUDINA	{"email": "aleksandra_yudina_02091970@postgrespro.ru", "phone": "+70508845772"}
0005433459293	58ABE9	0244 928204	SERGEY EGOROV	{"email": "egorov-sergey.1978@postgrespro.ru", "phone": "+70708453756"}
0005433459294	58ABE9	6595 677822	IVAN KOZLOV	{"email": "i.kozlov_021970@postgrespro.ru", "phone": "+70709336587"}
0005433459295	E966F0	9930 604760	VALERIY SCHERBAKOV	{"email": "scherbakov.v_1966@postgrespro.ru", "phone": "+70794081940"}
0005433459296	E966F0	0267 390815	ANASTASIYA SAVELEVA	{"phone": "+70360722080"}
0005433459297	AA5969	2227 338076	ELENA VASILEVA	{"phone": "+70384960058"}
0005433459298	3A2991	6272 493735	TAMARA MOROZOVA	{"phone": "+70368665907"}
0005433459299	BBB204	6162 871764	ALBINA DENISOVA	{"phone": "+70844376666"}
0005433459300	66CB35	6060 220895	GALINA POTAPOVA	{"phone": "+70990107372"}
0005433459301	0A430C	6558 850058	NATALYA KOZLOVA	{"email": "kozlova_natalya-09031987@postgrespro.ru", "phone": "+70221368540"}
0005433459302	F82ECB	9221 955851	ALEKSANDR VOLKOV	{"phone": "+70822899853"}
0005433459303	F82ECB	9795 034790	SVETLANA SMIRNOVA	{"email": "smirnova-svetlana_121970@postgrespro.ru", "phone": "+70894726536"}
0005433459304	BE5147	6877 945473	YURIY MAKAROV	{"email": "makarovy1965@postgrespro.ru", "phone": "+70652089314"}
0005433459305	0CF934	9286 793457	ELENA FILIPPOVA	{"email": "filippova-e02031987@postgrespro.ru", "phone": "+70818237206"}
0005433459306	0CF934	2855 161552	NIKOLAY FILIPPOV	{"email": "filippovnikolay.1960@postgrespro.ru", "phone": "+70033638743"}
0005433459307	0CF934	8195 216159	SERGEY SEMENOV	{"phone": "+70597345522"}
0005433459308	6D7739	6415 234257	OLGA IVANOVA	{"phone": "+70896673935"}
0005433459309	6D7739	9958 578848	ROMAN FEDOROV	{"phone": "+70593108226"}
0005433459310	6D7739	1877 232180	MARIYA IVANOVA	{"email": "ivanova-mariya-19091975@postgrespro.ru", "phone": "+70974117283"}
0005433459311	22A02F	9678 754645	KIRILL KUZNECOV	{"phone": "+70099950754"}
0005433459312	0B04A6	3051 092510	MARIYA POPOVA	{"phone": "+70854115262"}
0005433459313	0B04A6	1151 076372	MARINA SEMENOVA	{"email": "semenova_marina_25041972@postgrespro.ru", "phone": "+70741104003"}
0005433459314	346710	1554 765844	OLGA CHERNOVA	{"phone": "+70833485438"}
0005433459315	A391F8	8120 659055	LYUDMILA SAVELEVA	{"phone": "+70369860488"}
0005433459316	A391F8	1224 668565	VALENTINA OSIPOVA	{"phone": "+70987991660"}
0005433459317	8E25DA	5544 535676	MAKSIM GERASIMOV	{"phone": "+70381899498"}
0005433459318	8E25DA	8056 469746	IRINA MARTYNOVA	{"email": "irina.martynova.021956@postgrespro.ru", "phone": "+70079854003"}
0005433459319	46270B	3449 467814	IVAN IVANOV	{"phone": "+70276284987"}
0005433459320	46270B	8247 401370	ALEKSANDR NAZAROV	{"email": "a-nazarov28121969@postgrespro.ru", "phone": "+70996566257"}
0005433459321	BA9D2D	6272 819063	ALEKSANDR GERASIMOV	{"phone": "+70858820227"}
0005433459322	03ABF1	0278 501662	MIKHAIL MOISEEV	{"phone": "+70053780299"}
0005433459323	03ABF1	1545 182715	KUZMA FILIPPOV	{"phone": "+70243019223"}
0005433459324	C2449D	9065 986773	VIKTORIYA KONDRATEVA	{"phone": "+70350620207"}
0005433459325	C2449D	8019 573563	SEMEN BONDARENKO	{"email": "semen.bondarenko_011968@postgrespro.ru", "phone": "+70244273450"}
0005433459326	B6FEC8	6438 846913	ALEKSEY GORBUNOV	{"email": "gorbunova-29121980@postgrespro.ru", "phone": "+70787149531"}
0005433459327	92A4F5	0410 782145	VADIM FEDOROV	{"email": "fedorov-v17061973@postgrespro.ru", "phone": "+70983748784"}
0005433459328	92A4F5	1343 323367	DANIIL GORBUNOV	{"phone": "+70707467406"}
0005433459329	365ED9	5213 418726	GALINA GUSEVA	{"phone": "+70804981331"}
0005433459330	365ED9	3734 534054	OLGA BORISOVA	{"phone": "+70847043011"}
0005433459331	B14C5F	2021 554061	IRINA FILIPPOVA	{"email": "filippova.i.07071983@postgrespro.ru", "phone": "+70413586192"}
0005433459332	B14C5F	5136 288781	DMITRIY SCHERBAKOV	{"phone": "+70025045948"}
0005433459333	81EECE	0204 815444	MARIYA STEPANOVA	{"phone": "+70682546893"}
0005433459334	5BBEC3	2056 645490	IRINA KOZLOVA	{"email": "kozlova-i11051969@postgrespro.ru", "phone": "+70952576825"}
0005433459335	8FCCBB	2584 248301	PAVEL ZHURAVLEV	{"email": "zhuravlev-pavel27051975@postgrespro.ru", "phone": "+70195017217"}
0005433459336	8FCCBB	1203 446356	NATALYA OSIPOVA	{"phone": "+70359769104"}
0005433459337	AAAA6B	2364 002317	RAISA KUZNECOVA	{"phone": "+70870392191"}
0005433459338	D5C4D2	1339 160743	OLGA MARTYNOVA	{"phone": "+70411658408"}
0005433459339	D5C4D2	8910 536475	NIKOLAY POPOV	{"phone": "+70410161097"}
0005433459340	76D0A2	6223 814298	ANTON ROMANOV	{"phone": "+70570450607"}
0005433459341	CACD3E	9130 961521	EKATERINA SMIRNOVA	{"email": "smirnova.e1977@postgrespro.ru", "phone": "+70546292038"}
0005433459342	4BB500	8984 554400	NINA SAVELEVA	{"phone": "+70243063687"}
0005433459343	4BB500	8647 366103	NATALYA NIKITINA	{"phone": "+70317801416"}
0005433459344	CA80B7	1836 101918	LYUDMILA LAZAREVA	{"email": "lazareva-l_021978@postgrespro.ru", "phone": "+70858898344"}
0005433459345	FDC52E	3866 728269	DMITRIY FILIPPOV	{"phone": "+70338951223"}
0005433459346	1192C2	7407 178629	ELENA TIKHONOVA	{"phone": "+70176384849"}
0005433459347	F446B1	1334 655616	TATYANA ILINA	{"email": "tatyana-ilina_011965@postgrespro.ru", "phone": "+70037777840"}
0005433460398	6F8E64	9581 782016	ALEKSANDR FROLOV	{"phone": "+70714544285"}
0005433460399	6F8E64	8192 323727	NATALYA IVANOVA	{"email": "ivanova_n.121970@postgrespro.ru", "phone": "+70507493744"}
0005433460400	423B5C	0059 910545	VIKTOR MELNIKOV	{"email": "melnikov-v-18081962@postgrespro.ru", "phone": "+70133135815"}
0005433460401	042460	3188 403026	VLADIMIR SERGEEV	{"email": "vladimir.sergeev.1990@postgrespro.ru", "phone": "+70582478124"}
0005433460402	B779E5	9482 593679	LYUDMILA FEDOROVA	{"phone": "+70587009460"}
0005433460403	7EE61E	5903 259282	TATYANA NIKOLAEVA	{"email": "tnikolaeva_1974@postgrespro.ru", "phone": "+70642096343"}
0005433460404	7EE61E	6732 784162	NATALYA POTAPOVA	{"email": "npotapova-1969@postgrespro.ru", "phone": "+70148918580"}
0005433460405	68921E	1269 055819	EGOR MAKAROV	{"phone": "+70107105198"}
0005433460406	113D1D	5127 226448	LIDIYA MOROZOVA	{"email": "morozova-l.1971@postgrespro.ru", "phone": "+70113477241"}
0005433460407	113D1D	3784 350185	TATYANA ALEKSANDROVA	{"email": "tatyana-aleksandrova_081971@postgrespro.ru", "phone": "+70488591980"}
0005433460408	08DC5C	6431 475981	ANATOLIY ANTONOV	{"email": "aantonov.1958@postgrespro.ru", "phone": "+70979156351"}
0005433460409	23EF9D	9092 558418	IVAN SERGEEV	{"email": "isergeev.06091977@postgrespro.ru", "phone": "+70597988164"}
0005433460410	C186EB	8150 212887	NATALYA PETROVA	{"email": "petrova_natalya16031969@postgrespro.ru", "phone": "+70567652477"}
0005433460411	A9A24B	7210 117697	VIKTOR KUZNECOV	{"email": "kuznecov-viktor.1982@postgrespro.ru", "phone": "+70201009503"}
0005433460412	0742D2	1632 548606	ARTEM DMITRIEV	{"email": "artem.dmitriev-07071969@postgrespro.ru", "phone": "+70738114508"}
0005433460413	B909E2	7796 168771	RAUF SMIRNOV	{"email": "smirnov.r.03031959@postgrespro.ru", "phone": "+70442105468"}
0005433460414	C26629	8179 406311	FELIKS KUDRYASHOV	{"email": "kudryashov.f07071968@postgrespro.ru", "phone": "+70247376486"}
0005433460415	9D553E	1879 845223	ANNA IVANOVA	{"phone": "+70069672572"}
0005433460416	9D553E	7248 992223	MAKSIM IVANOV	{"phone": "+70145185288"}
0005433460417	A12637	4523 516699	LYUDMILA MIKHAYLOVA	{"phone": "+70543915289"}
0005433460418	A12637	9639 133382	TATYANA POLYAKOVA	{"phone": "+70991546418"}
0005433460419	F66952	1863 060593	VIKTORIYA LAZAREVA	{"phone": "+70539331958"}
0005433460420	4C4472	3840 619278	RIMMA VASILEVA	{"email": "rimmavasileva_071975@postgrespro.ru", "phone": "+70605156581"}
0005433460421	6B26D3	7742 296703	ANASTASIYA MELNIKOVA	{"phone": "+70104201236"}
0005433460422	F01185	1910 483710	OLEG MIKHAYLOV	{"email": "mikhaylovoleg-041974@postgrespro.ru", "phone": "+70962069400"}
0005433460423	F01185	1245 138158	MARINA FROLOVA	{"email": "frolova_m-03081967@postgrespro.ru", "phone": "+70573881887"}
0005433460424	BC9B5E	0679 768584	VLADISLAV MAKAROV	{"email": "makarovvladislav.1979@postgrespro.ru", "phone": "+70571433584"}
0005433460425	8F51EA	2760 840263	MIKHAIL PETROV	{"phone": "+70710203228"}
0005433460426	043E4C	4091 682401	LYUDMILA MAKAROVA	{"phone": "+70698247152"}
0005433460427	C79EB4	1417 605253	NATALYA IVANOVA	{"email": "ivanova-n_11091964@postgrespro.ru", "phone": "+70600631840"}
0005433460428	C79EB4	1818 425718	ELENA NOVIKOVA	{"phone": "+70539544014"}
0005433460429	33D483	9203 440123	MARIYA NAUMOVA	{"phone": "+70446158458"}
0005433460430	6D871C	6700 724479	NADEZHDA KUZNECOVA	{"phone": "+70867384932"}
0005433460431	ABB6DA	5404 690205	EKATERINA BELOVA	{"email": "belova.e_1964@postgrespro.ru", "phone": "+70851530497"}
0005433460432	ABB6DA	8411 539069	ALEKSANDR NIKITIN	{"phone": "+70267355250"}
0005433460433	A49345	4792 220900	MIKHAIL ZHURAVLEV	{"phone": "+70790098162"}
0005433460434	A49345	5616 219233	EVGENIY SEMENOV	{"email": "semenovevgeniy.081975@postgrespro.ru", "phone": "+70151007112"}
0005433460435	D99A31	6803 606309	SERGEY GUSEV	{"phone": "+70706433202"}
0005433460436	D99A31	8536 461187	DMITRIY MAKSIMOV	{"phone": "+70692980300"}
0005433460437	322770	3010 381517	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir17031962@postgrespro.ru", "phone": "+70571671071"}
0005433460438	EA8A1B	9507 817644	LEONID KONOVALOV	{"phone": "+70513919699"}
0005433460439	EA8A1B	5072 119219	NADEZHDA KUZNECOVA	{"phone": "+70952575204"}
0005433460440	29BAF5	0260 913310	SERGEY TIKHONOV	{"email": "stikhonov_1975@postgrespro.ru", "phone": "+70914493697"}
0005433460441	20619F	3058 648127	ANNA NIKIFOROVA	{"email": "nikiforova_a.071967@postgrespro.ru", "phone": "+70449454134"}
0005433460442	20619F	9026 390305	NATALYA FILIPPOVA	{"phone": "+70367102318"}
0005433460443	B319C2	1221 354941	ELENA PETROVA	{"phone": "+70155015840"}
0005433460444	B319C2	1946 094814	RUSTAM IVANOV	{"email": "ivanov-r.111972@postgrespro.ru", "phone": "+70457708537"}
0005433460445	8E26DC	7698 172503	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov101971@postgrespro.ru", "phone": "+70814631657"}
0005433460446	FF741C	6582 041539	OLGA MELNIKOVA	{"email": "melnikova_olga-28121965@postgrespro.ru", "phone": "+70240324355"}
0005433460447	FF741C	6993 623002	KONSTANTIN ZAYCEV	{"phone": "+70129095932"}
0005433460448	92B568	7789 907843	ZOYA KUZNECOVA	{"email": "kuznecovaz.31101974@postgrespro.ru", "phone": "+70345796117"}
0005433460449	E8E6F3	3076 791282	NATALYA SOKOLOVA	{"email": "n_sokolova.061970@postgrespro.ru", "phone": "+70123062231"}
0005433460450	9FDB83	8897 360991	MIKHAIL KRASNOV	{"phone": "+70587786121"}
0005433460451	6BABD8	5597 454783	MARIYA EFREMOVA	{"email": "mariya-efremova.02021971@postgrespro.ru", "phone": "+70026569195"}
0005433460452	92C2BD	0429 471620	MARIYA EGOROVA	{"phone": "+70837748345"}
0005433460453	C00A1F	5870 926691	ARTEM ANTONOV	{"email": "artem-antonov_1979@postgrespro.ru", "phone": "+70679612521"}
0005433460454	5C6584	0770 658606	MIKHAIL KOZLOV	{"email": "mkozlov.1970@postgrespro.ru", "phone": "+70366779758"}
0005433460455	36CCA0	5114 016312	LARISA SIDOROVA	{"phone": "+70429024594"}
0005433460456	36CCA0	4001 848386	ROMAN KUZNECOV	{"email": "romankuznecov_1972@postgrespro.ru", "phone": "+70071785038"}
0005433460457	F787A4	8354 648462	NIKOLAY NIKITIN	{"phone": "+70096690709"}
0005433460458	F787A4	4888 484756	LYUDMILA DANILOVA	{"email": "danilova-l-03071980@postgrespro.ru", "phone": "+70723480144"}
0005433460459	2B2830	6138 957969	NINA RODIONOVA	{"phone": "+70161565662"}
0005433460460	A7D67C	8646 693059	ZHANNA BORISOVA	{"phone": "+70577944097"}
0005433460461	A6449D	4579 958986	ANDREY POPOV	{"phone": "+70240088501"}
0005433460462	D8D8B6	8380 616837	ILYA SMIRNOV	{"email": "smirnovilya.101962@postgrespro.ru", "phone": "+70003603477"}
0005433460463	706AE4	8171 759715	ALEKSANDR DMITRIEV	{"phone": "+70050295078"}
0005433460464	32E821	1819 211857	VLADISLAV IVANOV	{"phone": "+70450393105"}
0005433460465	53A3CB	6695 285773	ALEKSEY ZAKHAROV	{"phone": "+70913505875"}
0005433460466	53A3CB	3382 404752	DARYA MATVEEVA	{"phone": "+70583026792"}
0005433460467	431011	0762 438244	MARINA LEBEDEVA	{"phone": "+70225715251"}
0005433460468	431011	5032 726448	KLAVDIYA KUZNECOVA	{"phone": "+70366080928"}
0005433460469	B4C90F	3157 910819	VARVARA KONOVALOVA	{"phone": "+70781208342"}
0005433460470	C5780A	1208 507862	ELENA SIDOROVA	{"phone": "+70431060083"}
0005433460471	C922CC	0222 256955	MAKSIM ANTONOV	{"phone": "+70757225857"}
0005433460472	DF906A	1919 173432	RAISA MALYSHEVA	{"phone": "+70859878994"}
0005433460473	3DFA6C	0331 779429	MARIYA POPOVA	{"phone": "+70650302709"}
0005433460474	BD0262	1484 260232	ANATOLIY YAKOVLEV	{"phone": "+70231453367"}
0005433460475	AE5E19	2658 678152	DIANA MEDVEDEVA	{"phone": "+70489393619"}
0005433460476	7778B4	6951 776513	ALEKSEY BONDARENKO	{"phone": "+70712251952"}
0005433460477	7778B4	0494 030079	LYUDMILA FEDOROVA	{"email": "lyudmila.fedorova-1977@postgrespro.ru", "phone": "+70946249482"}
0005433460478	83E980	6157 441851	MARIYA POPOVA	{"phone": "+70325394626"}
0005433460479	83E980	4560 580951	ELENA KARPOVA	{"email": "karpova_elena-061973@postgrespro.ru", "phone": "+70231770006"}
0005433460480	9EF597	1612 850654	IVAN PETROV	{"phone": "+70617543684"}
0005433460481	C7AF01	7536 179882	ALEKSEY FEDOROV	{"phone": "+70155466287"}
0005433460482	FC2E09	5202 687077	MIKHAIL IVANOV	{"email": "m-ivanov.051973@postgrespro.ru", "phone": "+70335240905"}
0005433460483	C99F70	2449 377088	YULIYA MALYSHEVA	{"email": "malysheva_y.19121969@postgrespro.ru", "phone": "+70474803922"}
0005433460484	24B388	5504 630294	NATALYA ERMAKOVA	{"email": "ermakova-n.13111975@postgrespro.ru", "phone": "+70111207792"}
0005433460485	3D6A5B	6541 853091	GENNADIY MATVEEV	{"email": "gennadiy_matveev1982@postgrespro.ru", "phone": "+70606978889"}
0005433460486	D45569	1728 453862	ALEKSANDR ALEKSEEV	{"phone": "+70644995289"}
0005433460487	624D01	5299 225438	RAISA MATVEEVA	{"email": "matveeva_raisa1967@postgrespro.ru", "phone": "+70057391410"}
0005433460488	624D01	6530 560411	OKSANA DANILOVA	{"phone": "+70031676949"}
0005433460489	57DE31	8612 598655	VALERIY BORISOV	{"email": "borisovv_1970@postgrespro.ru", "phone": "+70332513695"}
0005433460490	726E02	1372 768119	VLADIMIR GRIGOREV	{"email": "vladimir-grigorev.1976@postgrespro.ru", "phone": "+70476543851"}
0005433460491	2E03C6	8264 091634	VLADIMIR ROMANOV	{"phone": "+70231304932"}
0005433460492	1453BD	8877 010569	NINA KUZNECOVA	{"email": "kuznecova-nina-121973@postgrespro.ru", "phone": "+70250097587"}
0005433460493	DAB2B2	8304 991086	YULIYA NOVIKOVA	{"phone": "+70425537366"}
0005433460494	5E4C2D	5741 592970	LARISA MATVEEVA	{"email": "matveevalarisa_30031974@postgrespro.ru", "phone": "+70215111259"}
0005433460495	347EB5	4086 655730	POLINA KOZLOVA	{"email": "p-kozlova-1967@postgrespro.ru", "phone": "+70594470969"}
0005433460496	9D76D7	0154 993794	DMITRIY YAKOVLEV	{"email": "d_yakovlev_1974@postgrespro.ru", "phone": "+70011765876"}
0005433460497	E63EB6	3211 134560	YURIY BORISOV	{"email": "borisov.yuriy.20011977@postgrespro.ru", "phone": "+70318783125"}
0005433460498	D4F74F	5338 876815	LYUDMILA KOROLEVA	{"email": "lyudmila-koroleva-101973@postgrespro.ru", "phone": "+70865553789"}
0005433461550	4534D1	1905 427656	YULIYA TIMOFEEVA	{"phone": "+70219290925"}
0005433461551	28D9F2	6062 657824	EKATERINA FROLOVA	{"email": "e_frolova1984@postgrespro.ru", "phone": "+70509765735"}
0005433461552	462BC4	1945 884791	NIKITA MEDVEDEV	{"phone": "+70721093121"}
0005433461553	FC73C0	6000 401995	ANNA NAZAROVA	{"email": "a_nazarova.031976@postgrespro.ru", "phone": "+70330584631"}
0005433461554	19178C	8063 981624	ANTONINA KISELEVA	{"email": "kiseleva_antonina.031971@postgrespro.ru", "phone": "+70002118822"}
0005433461555	79CA8E	0960 815135	IVAN SOLOVEV	{"phone": "+70217679427"}
0005433461556	741CB6	5628 994558	EVGENIYA FADEEVA	{"phone": "+70642589776"}
0005433461557	BCFDBF	6937 648912	VLADIMIR IVANOV	{"email": "v.ivanov-101976@postgrespro.ru", "phone": "+70117002841"}
0005433461558	8486EB	1550 111536	YURIY NAUMOV	{"email": "naumovy.111966@postgrespro.ru", "phone": "+70031438674"}
0005433461559	9239CF	1765 431318	VLADIMIR CHERNOV	{"email": "chernov_vladimir-1972@postgrespro.ru", "phone": "+70738866696"}
0005433461560	9239CF	4121 054998	ANTON ABRAMOV	{"phone": "+70891934674"}
0005433461561	BB6871	8310 563931	MARINA AKIMOVA	{"phone": "+70814154003"}
0005433461562	A470ED	4519 808452	EKATERINA FROLOVA	{"phone": "+70605149968"}
0005433461563	EA1CF7	9958 763526	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova101967@postgrespro.ru", "phone": "+70453611910"}
0005433461564	EA1CF7	0071 233278	ALFIYA NAZAROVA	{"email": "alfiyanazarova_071983@postgrespro.ru", "phone": "+70501198817"}
0005433461565	31BF28	4146 812372	ALEKSANDR SCHERBAKOV	{"phone": "+70813643607"}
0005433461566	683FF9	7028 786073	ALEKSANDR SOKOLOV	{"phone": "+70588326132"}
0005433461567	683FF9	2050 263611	LARISA YAKOVLEVA	{"email": "yakovleva_larisa.25031975@postgrespro.ru", "phone": "+70727553459"}
0005433461568	D14958	2435 133261	VYACHESLAV GUSEV	{"email": "vgusev-1978@postgrespro.ru", "phone": "+70642545457"}
0005433461569	F4159E	6789 853205	DANIL FROLOV	{"email": "frolovdanil_16021974@postgrespro.ru", "phone": "+70942297131"}
0005433461570	4DC362	6507 236702	ELENA YAKOVLEVA	{"email": "yakovlevae.1962@postgrespro.ru", "phone": "+70391187529"}
0005433461571	F478F3	1249 530863	NATALYA MAKAROVA	{"phone": "+70857431587"}
0005433461572	C12110	3231 238335	EKATERINA ILINA	{"email": "ekaterinailina_07041973@postgrespro.ru", "phone": "+70090892609"}
0005433461573	B4437F	3334 267032	VIKTOR ALEKSEEV	{"phone": "+70377259734"}
0005433461574	9CF9A6	5179 686151	IRINA KALININA	{"phone": "+70239327343"}
0005433461575	4623EC	3412 772377	LYUDMILA PAVLOVA	{"email": "l.pavlova111974@postgrespro.ru", "phone": "+70906548293"}
0005433461576	4623EC	8775 432651	VITALIY CHERNOV	{"phone": "+70323119264"}
0005433461577	179145	6044 212080	TATYANA KALININA	{"email": "kalininatatyana-22021968@postgrespro.ru", "phone": "+70362170556"}
0005433461578	9754B7	6924 423653	IVAN BELOV	{"phone": "+70931647905"}
0005433461579	9754B7	6344 941069	ALEKSANDR KISELEV	{"phone": "+70589067850"}
0005433461580	1CC629	0686 083059	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaa_1972@postgrespro.ru", "phone": "+70195308778"}
0005433461581	DF3D8F	3240 475274	NADEZHDA KONDRATEVA	{"phone": "+70554319798"}
0005433461582	339264	3077 254896	ZINAIDA TROFIMOVA	{"email": "trofimovazinaida.051966@postgrespro.ru", "phone": "+70188345051"}
0005433461583	9834AD	8011 116417	ELENA KONOVALOVA	{"phone": "+70099765396"}
0005433461584	9834AD	1407 073624	IRINA IVANOVA	{"phone": "+70069823018"}
0005433461585	A2D4BC	0784 929560	OLGA KUZMINA	{"phone": "+70093956275"}
0005433461586	A2D4BC	6339 824937	SOFYA YAKOVLEVA	{"phone": "+70298914796"}
0005433461587	73C210	1637 354792	VLADIMIR FOMIN	{"email": "v_fomin_1966@postgrespro.ru", "phone": "+70979265042"}
0005433461588	8360ED	8488 526561	RISHAT SEMENOV	{"phone": "+70003331130"}
0005433461589	D45AD7	2827 182987	OLGA ZHURAVLEVA	{"phone": "+70286439741"}
0005433461590	D45AD7	0704 891314	GALINA TARASOVA	{"email": "galina_tarasova_15091976@postgrespro.ru", "phone": "+70678799910"}
0005433461591	85A889	0072 928299	VIKTOR VASILEV	{"phone": "+70472328914"}
0005433461592	85A889	5508 478898	EVGENIY DMITRIEV	{"phone": "+70149960765"}
0005433461593	C4EF9F	5484 239571	KIRILL MOISEEV	{"email": "kirill-moiseev_081978@postgrespro.ru", "phone": "+70358585468"}
0005433461594	3D5119	1106 921684	SVETLANA ZAYCEVA	{"email": "s_zayceva.1973@postgrespro.ru", "phone": "+70524484793"}
0005433461595	2D175F	8427 695391	PAVEL NIKITIN	{"phone": "+70528288424"}
0005433461596	2D175F	8653 507084	BORIS SIDOROV	{"phone": "+70197107101"}
0005433461597	FA8229	4285 535920	ANDREY KUZNECOV	{"email": "a.kuznecov-021971@postgrespro.ru", "phone": "+70466685917"}
0005433461598	FA8229	0367 573243	BORIS VASILEV	{"email": "vasilev-boris.101976@postgrespro.ru", "phone": "+70768270613"}
0005433461599	9D02D4	1053 690499	ELENA MAKSIMOVA	{"email": "elena-maksimova_30041977@postgrespro.ru", "phone": "+70263843132"}
0005433461600	C60197	3532 328442	GALINA NAZAROVA	{"email": "gnazarova.1975@postgrespro.ru", "phone": "+70293821642"}
0005433461601	C60197	2502 206419	DMITRIY SERGEEV	{"email": "sergeev_dmitriy051970@postgrespro.ru", "phone": "+70287277088"}
0005433461602	F705BF	2483 580830	LYUBOV POPOVA	{"phone": "+70627108893"}
0005433461603	51C4DF	2536 150080	ELENA FEDOROVA	{"phone": "+70597959073"}
0005433461604	51C4DF	4585 120362	KSENIYA NOVIKOVA	{"email": "novikova_kseniya-1970@postgrespro.ru", "phone": "+70498132118"}
0005433461605	3920D0	4465 125223	OLGA PAVLOVA	{"phone": "+70325009148"}
0005433461606	5C1013	6786 583713	ALEKSANDR SOKOLOV	{"phone": "+70953011474"}
0005433461607	CFCB0A	3856 242629	EVGENIY MAKAROV	{"email": "makarov_evgeniy1971@postgrespro.ru", "phone": "+70952302674"}
0005433461608	5E3D20	0029 527393	LYUBOV KOZLOVA	{"email": "kozlova.lyubov.1975@postgrespro.ru", "phone": "+70799560440"}
0005433461609	5E3D20	4480 354143	TATYANA DANILOVA	{"email": "tatyanadanilova-021968@postgrespro.ru", "phone": "+70969151170"}
0005433461610	6CF3E4	7162 178851	ALEVTINA MARTYNOVA	{"phone": "+70220702463"}
0005433461611	6CF3E4	4416 633776	VASILIY CHERNOV	{"phone": "+70413780438"}
0005433461612	5E7F8A	0205 561838	VIKTOR FEDOTOV	{"email": "viktorfedotov-1973@postgrespro.ru", "phone": "+70963387017"}
0005433461613	4C3DD0	0384 286563	MIROSLAV NIKITIN	{"email": "m-nikitin.09061953@postgrespro.ru", "phone": "+70532018713"}
0005433461614	4F308F	1704 461547	ELENA EGOROVA	{"phone": "+70448559267"}
0005433461615	4F308F	0198 122785	TATYANA SOROKINA	{"email": "tsorokina081962@postgrespro.ru", "phone": "+70152511190"}
0005433461616	4F308F	4604 406381	VLADIMIR SHEVCHENKO	{"email": "vladimir-shevchenko.08091976@postgrespro.ru", "phone": "+70989669190"}
0005433461617	A0D2C0	5489 314507	ANATOLIY MAKSIMOV	{"email": "anatoliy_maksimov-1975@postgrespro.ru", "phone": "+70295388786"}
0005433461618	BEAB2B	9199 389686	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov031967@postgrespro.ru", "phone": "+70929138865"}
0005433461619	8D602C	7270 548029	IGOR KOZLOV	{"email": "igor_kozlov_081964@postgrespro.ru", "phone": "+70221248148"}
0005433461620	51C9EE	1174 149314	MIKHAIL DENISOV	{"email": "denisovm-091977@postgrespro.ru", "phone": "+70982168973"}
0005433461621	B61939	9603 791250	TATYANA ZAKHAROVA	{"phone": "+70061616978"}
0005433461622	B61939	2845 940360	ALEKSANDR VOROBEV	{"email": "a.vorobev1976@postgrespro.ru", "phone": "+70274178772"}
0005433461623	B61939	3502 778222	KONSTANTIN VASILEV	{"email": "konstantin_vasilev-061970@postgrespro.ru", "phone": "+70505159451"}
0005433461624	E79076	8086 278578	SERGEY DMITRIEV	{"email": "dmitrievs.19111967@postgrespro.ru", "phone": "+70991360113"}
0005433461625	F57E18	1731 124191	VLADIMIR BORISOV	{"phone": "+70772682798"}
0005433461626	320163	9438 278014	ARTEM BELOV	{"phone": "+70525684077"}
0005433461627	4BC81E	5494 636156	KONSTANTIN NOVIKOV	{"email": "konstantin-novikov_1976@postgrespro.ru", "phone": "+70638043958"}
0005433461628	2827A0	5303 676421	SERGEY AFANASEV	{"email": "s-afanasev_121964@postgrespro.ru", "phone": "+70785100939"}
0005433461629	8F1414	5822 747596	VERA KUZNECOVA	{"email": "kuznecova_v_041965@postgrespro.ru", "phone": "+70218490735"}
0005433461630	909BB0	3905 164721	ELENA VLASOVA	{"email": "vlasovaelena_061977@postgrespro.ru", "phone": "+70966560080"}
0005433461631	E815D2	8489 753935	ANNA MELNIKOVA	{"phone": "+70957744946"}
0005433461632	E815D2	5597 262765	VALENTIN BORISOV	{"email": "borisovvalentin.121967@postgrespro.ru", "phone": "+70854008652"}
0005433461633	D18D7C	9287 759681	ANDREY KUZNECOV	{"email": "kuznecov-andrey061981@postgrespro.ru", "phone": "+70552541007"}
0005433461634	D18D7C	4606 947857	SERGEY SCHERBAKOV	{"phone": "+70387436065"}
0005433461635	D18D7C	0954 224497	GALINA BELOVA	{"phone": "+70271935583"}
0005433461636	D181BE	9813 687560	KONSTANTIN STEPANOV	{"phone": "+70227110406"}
0005433461637	D181BE	7547 245598	TATYANA SEMENOVA	{"email": "semenova_tatyana.051970@postgrespro.ru", "phone": "+70234500161"}
0005433461638	1404AB	9274 986422	VASILIY KOZLOV	{"phone": "+70476124452"}
0005433461639	0F87E1	3130 572917	LYUDMILA MAKAROVA	{"email": "makarova.l.01041971@postgrespro.ru", "phone": "+70074812512"}
0005433461640	2A8222	6181 234525	SERGEY KARPOV	{"email": "karpov_sergey_16121961@postgrespro.ru", "phone": "+70500013436"}
0005433461641	520D00	9228 114414	BORIS DENISOV	{"phone": "+70801760083"}
0005433461642	E8A37E	9021 581799	IGOR ZHUKOV	{"phone": "+70615121052"}
0005433461643	E8A37E	0324 488269	MARIYA GAVRILOVA	{"phone": "+70619809184"}
0005433461644	37E020	3951 555208	GALINA DANILOVA	{"email": "g-danilova20121972@postgrespro.ru", "phone": "+70634416781"}
0005433461645	37E020	9895 468197	VLADIMIR POPOV	{"phone": "+70127720796"}
0005433461646	6E9A30	6884 832931	MARINA CHERNOVA	{"email": "marina.chernova_1973@postgrespro.ru", "phone": "+70640734097"}
0005433461647	080ED2	4761 007135	VIKTOR MEDVEDEV	{"phone": "+70234013358"}
0005433461648	07CF52	6760 677288	VALERIY MIKHAYLOV	{"email": "mikhaylovv_1969@postgrespro.ru", "phone": "+70336793903"}
0005433461649	B6ADEB	1755 742111	GALINA NIKITINA	{"phone": "+70586073696"}
0005433461650	287F73	9717 570962	VLADIMIR NIKITIN	{"phone": "+70977547686"}
0005433461651	ECCF2F	4234 239777	NIKOLAY SOKOLOV	{"email": "sokolov-nikolay.121974@postgrespro.ru", "phone": "+70087639876"}
0005433461652	9E2C3B	9569 789149	YULIYA MOROZOVA	{"email": "y-morozova_091982@postgrespro.ru", "phone": "+70949591216"}
0005433461653	CC109B	6148 496261	MAKSIM VASILEV	{"email": "vasilev.m.071975@postgrespro.ru", "phone": "+70074391443"}
0005433461654	CC109B	2667 858893	ALINA MATVEEVA	{"phone": "+70900777038"}
0005433461655	B40A71	4352 975827	ALEKSANDR BARANOV	{"email": "aleksandr.baranov-101973@postgrespro.ru", "phone": "+70125472691"}
0005433462708	A41045	6673 486882	ARTEM STEPANOV	{"phone": "+70689988369"}
0005433462709	37D432	6225 879584	TATYANA ZAKHAROVA	{"phone": "+70603699902"}
0005433462710	1AC26E	6072 873473	PAVEL SOROKIN	{"email": "sorokin.p1974@postgrespro.ru", "phone": "+70128258142"}
0005433462711	855D5A	5918 257221	TIMUR IVANOV	{"email": "ivanov_timur-101985@postgrespro.ru", "phone": "+70889020938"}
0005433462712	855D5A	9604 803453	YAKOV VLASOV	{"email": "vlasov_y_071969@postgrespro.ru", "phone": "+70191509879"}
0005433462713	3851CA	6855 681216	IRINA KOZLOVA	{"phone": "+70085522224"}
0005433462714	54F1CD	4988 509408	OLGA MIKHAYLOVA	{"email": "o_mikhaylova-031962@postgrespro.ru", "phone": "+70822836487"}
0005433462715	54F1CD	8437 767895	SANIYA POTAPOVA	{"email": "potapova_saniya21071963@postgrespro.ru", "phone": "+70667465870"}
0005433462716	FD90BF	6275 836951	SHAVKAT TIKHONOV	{"email": "tikhonov.shavkat_1970@postgrespro.ru", "phone": "+70338265936"}
0005433462717	1A303B	6675 215220	SVETLANA POPOVA	{"email": "popova.s_1972@postgrespro.ru", "phone": "+70373793811"}
0005433462718	AF3BE6	0246 996023	IVAN IVANOV	{"email": "ivanovivan_1976@postgrespro.ru", "phone": "+70598796751"}
0005433462719	54C1A3	8201 600383	NATALYA NIKOLAEVA	{"email": "n.nikolaeva-111979@postgrespro.ru", "phone": "+70556307390"}
0005433462720	A37393	4584 891643	KIRILL ROMANOV	{"email": "kromanov-021982@postgrespro.ru", "phone": "+70867277700"}
0005433462721	A37393	5961 059925	ELENA IVANOVA	{"phone": "+70234603790"}
0005433462722	7518AC	1898 598231	OLGA KONDRATEVA	{"phone": "+70713336516"}
0005433462723	9FBED9	8238 535802	LARISA KOROLEVA	{"email": "larisakoroleva-121961@postgrespro.ru", "phone": "+70926296863"}
0005433462724	164D4A	7268 861677	TATYANA GERASIMOVA	{"email": "gerasimova.t.081966@postgrespro.ru", "phone": "+70383549098"}
0005433462725	E37B96	5625 820127	NIKITA KUZNECOV	{"phone": "+70991262867"}
0005433462726	1C2297	6477 809283	NIKITA OSIPOV	{"phone": "+70485838014"}
0005433462727	1C2297	6312 648347	NIKOLAY SCHERBAKOV	{"email": "nikolayscherbakov.1968@postgrespro.ru", "phone": "+70114254495"}
0005433462728	0FE57C	6611 269186	ANDREY KONOVALOV	{"email": "konovalov_a_1972@postgrespro.ru", "phone": "+70643598023"}
0005433462729	0FE57C	7680 444413	DMITRIY TIKHONOV	{"phone": "+70817318045"}
0005433462730	38A7F6	1357 877419	RAISA ROMANOVA	{"email": "raisaromanova_1981@postgrespro.ru", "phone": "+70891996998"}
0005433462731	38A7F6	5003 870153	SERGEY ZAKHAROV	{"email": "zakharov.s-22101969@postgrespro.ru", "phone": "+70115484580"}
0005433462732	38A7F6	1400 208005	LIDIYA KUZNECOVA	{"phone": "+70072062939"}
0005433462733	C23A19	5573 622301	ANATOLIY VOLKOV	{"email": "volkov-anatoliy.13061974@postgrespro.ru", "phone": "+70789494818"}
0005433462734	5A7C1B	0548 301880	EVGENIYA IVANOVA	{"phone": "+70394007905"}
0005433462735	5A7C1B	0753 707597	NINA KOMAROVA	{"email": "n.komarova-031974@postgrespro.ru", "phone": "+70600774883"}
0005433462736	96698C	3948 019835	IRINA FOMINA	{"phone": "+70710796935"}
0005433462737	7B4E9A	2103 701670	VIKTORIYA KUDRYASHOVA	{"email": "vkudryashova-041971@postgrespro.ru", "phone": "+70992870428"}
0005433462738	441A7A	3707 147949	NINA ROMANOVA	{"email": "n_romanova011969@postgrespro.ru", "phone": "+70807752479"}
0005433462739	441A7A	7869 067165	DENIS SOROKIN	{"email": "sorokin-denis-1962@postgrespro.ru", "phone": "+70852473324"}
0005433462740	D7C333	8614 046672	RAIL VOLKOV	{"email": "volkov-rail_031979@postgrespro.ru", "phone": "+70553934258"}
0005433462741	D7C333	6503 870258	VLADISLAV ROMANOV	{"phone": "+70929570019"}
0005433462742	8AD400	4135 587012	YURIY DMITRIEV	{"email": "ydmitriev-01041975@postgrespro.ru", "phone": "+70872585633"}
0005433462743	C39928	8709 166727	SERGEY MOROZOV	{"email": "morozov_s.14021970@postgrespro.ru", "phone": "+70585130052"}
0005433462744	87DD66	6830 626802	DMITRIY GRIGOREV	{"phone": "+70764236987"}
0005433462745	C4EFA1	3973 677165	YULIYA MAKAROVA	{"email": "makarova_yuliya_16031970@postgrespro.ru", "phone": "+70809764522"}
0005433462746	68F017	3639 434966	EVGENIY VOLKOV	{"phone": "+70477281464"}
0005433462747	978008	8750 948415	PAVEL ZAKHAROV	{"email": "zakharov-pavel-1966@postgrespro.ru", "phone": "+70848174392"}
0005433462748	978008	0665 282558	PAVEL ZHURAVLEV	{"email": "zhuravlev.pavel_1972@postgrespro.ru", "phone": "+70500027977"}
0005433462749	E5ADA3	8445 104442	YULIYA ERMAKOVA	{"phone": "+70222125077"}
0005433462750	D695D3	1997 067898	OLGA KUDRYASHOVA	{"email": "kudryashova.olga.061971@postgrespro.ru", "phone": "+70788647667"}
0005433462751	A61961	7463 759073	GALINA PETROVA	{"phone": "+70658309131"}
0005433462752	BA8607	4765 785378	DENIS FEDOROV	{"email": "dfedorov.031963@postgrespro.ru", "phone": "+70655388017"}
0005433462753	EB29F4	2495 873586	DARYA FEDOROVA	{"email": "fedorova-darya_1970@postgrespro.ru", "phone": "+70976724595"}
0005433462754	5D90A6	7730 555190	LYUBOV ZHURAVLEVA	{"email": "zhuravleva_lyubov_11061972@postgrespro.ru", "phone": "+70070047336"}
0005433462755	A85BDD	6302 893102	OLGA KUZNECOVA	{"email": "kuznecova.olga_1972@postgrespro.ru", "phone": "+70648116099"}
0005433462756	A85BDD	1098 032845	EVGENIYA ZOTOVA	{"email": "evgeniya-zotova-051967@postgrespro.ru", "phone": "+70252688966"}
0005433462757	D98FE8	8999 754648	TAMARA EFREMOVA	{"email": "tamara.efremova28101972@postgrespro.ru", "phone": "+70069180798"}
0005433462758	2E8B4E	9869 140793	NATALYA KISELEVA	{"email": "kiseleva_n.1976@postgrespro.ru", "phone": "+70784617370"}
0005433462759	68EFD5	3172 203962	TATYANA KULIKOVA	{"email": "tatyana_kulikova_061968@postgrespro.ru", "phone": "+70280214409"}
0005433462760	77B029	0288 780241	TATYANA MAKAROVA	{"email": "tatyana.makarova-20061960@postgrespro.ru", "phone": "+70909456556"}
0005433462761	3E9042	9434 915410	NATALYA MOROZOVA	{"email": "morozova.n21081974@postgrespro.ru", "phone": "+70101052932"}
0005433462762	3E9042	6314 204008	ALEKSEY VASILEV	{"phone": "+70947430577"}
0005433462763	8B7B20	2491 514421	IRINA FILIPPOVA	{"email": "irina_filippova-04101977@postgrespro.ru", "phone": "+70777606150"}
0005433462764	0841BD	7708 029103	NIKITA PAVLOV	{"email": "pavlov.nikita121980@postgrespro.ru", "phone": "+70030373601"}
0005433462765	53C822	2374 956012	SOFYA OSIPOVA	{"phone": "+70708655451"}
0005433462766	6313F2	0673 384268	ALEKSANDR SEMENOV	{"phone": "+70383731487"}
0005433462767	6313F2	4172 867911	NIKOLAY NAZAROV	{"email": "nazarov_n091977@postgrespro.ru", "phone": "+70372805010"}
0005433462768	4C92EF	8109 812556	DANIL SOROKIN	{"phone": "+70971570961"}
0005433462769	EFF4D9	0024 626249	GALINA ZAYCEVA	{"email": "gzayceva011963@postgrespro.ru", "phone": "+70005248848"}
0005433462770	EFF4D9	8402 829924	OLEG MAKSIMOV	{"email": "maksimov_oleg-061964@postgrespro.ru", "phone": "+70231481734"}
0005433462771	ABBB0A	8838 405189	SERGEY KAZAKOV	{"email": "kazakov_s-041971@postgrespro.ru", "phone": "+70408282991"}
0005433462772	1483CA	0115 314788	OLGA PAVLOVA	{"email": "pavlovao-25061973@postgrespro.ru", "phone": "+70470626594"}
0005433462773	9857CE	6226 771737	KIRILL EGOROV	{"email": "egorovk011975@postgrespro.ru", "phone": "+70885349737"}
0005433462774	082691	4831 635420	VLADIMIR ISAEV	{"email": "v-isaev091958@postgrespro.ru", "phone": "+70747737854"}
0005433462775	082691	0164 973208	LIDIYA KUZNECOVA	{"phone": "+70132544067"}
0005433462776	81D386	0041 426063	ANATOLIY VOROBEV	{"email": "a.vorobev101975@postgrespro.ru", "phone": "+70250805307"}
0005433462777	6F4BEE	1532 830915	MIKHAIL ZAKHAROV	{"email": "zakharovmikhail01041972@postgrespro.ru", "phone": "+70462177284"}
0005433462778	FF0410	1375 527672	ANASTASIYA MASLOVA	{"phone": "+70526568326"}
0005433462779	823775	5020 867286	YULIYA KALININA	{"phone": "+70642190841"}
0005433462780	0A9857	0208 230551	VERA NESTEROVA	{"phone": "+70572365446"}
0005433462781	0A9857	3859 874904	ANGELINA GORBUNOVA	{"email": "gorbunova-angelina.1969@postgrespro.ru", "phone": "+70561597176"}
0005433462782	AEF7C3	9328 381900	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey.091969@postgrespro.ru", "phone": "+70910604714"}
0005433462783	9821B5	7958 284932	ALENA FEDOROVA	{"phone": "+70897241755"}
0005433462784	9821B5	7735 412266	KONSTANTIN ZHUKOV	{"phone": "+70863649262"}
0005433462785	21B3AF	6669 106693	OKSANA KUZMINA	{"phone": "+70513584641"}
0005433462786	78AE92	0990 489123	MARINA KONOVALOVA	{"phone": "+70692262065"}
0005433462787	78AE92	9412 482586	ARTEM ROMANOV	{"email": "romanov.artem_07121971@postgrespro.ru", "phone": "+70701079155"}
0005433462788	D2F3A1	0247 943124	LARISA SEMENOVA	{"email": "larisa.semenova.071961@postgrespro.ru", "phone": "+70880808371"}
0005433462789	3A1E01	5448 079797	VLADIMIR DENISOV	{"email": "denisov.v08011968@postgrespro.ru", "phone": "+70134561179"}
0005433462790	3A1E01	7256 737426	ILYA GRIGOREV	{"phone": "+70618257268"}
0005433462791	BA61A3	9692 631568	ELIZAVETA PETROVA	{"phone": "+70511130793"}
0005433462792	BA61A3	8446 559878	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov-121979@postgrespro.ru", "phone": "+70737785302"}
0005433462793	D0FFC1	3596 838708	VLADIMIR VASILEV	{"email": "vasilevv.1984@postgrespro.ru", "phone": "+70726985335"}
0005433462794	D0FFC1	8523 931506	VLADIMIR PAVLOV	{"email": "pavlovvladimir-11061974@postgrespro.ru", "phone": "+70145586800"}
0005433462795	41F9D3	5462 622984	ALBERT FEDOROV	{"email": "a-fedorov-011972@postgrespro.ru", "phone": "+70345912935"}
0005433462796	4C5030	4029 382541	KRISTINA MASLOVA	{"phone": "+70509650876"}
0005433462797	81F11A	4678 924771	IGOR YAKOVLEV	{"email": "iyakovlev_22081970@postgrespro.ru", "phone": "+70309882546"}
0005433462798	3C8465	4645 039681	STEPAN ILIN	{"email": "stepan.ilin25011972@postgrespro.ru", "phone": "+70980694075"}
0005433462799	7FABB6	2628 869730	IVAN FILIPPOV	{"email": "i-filippov_111972@postgrespro.ru", "phone": "+70538775811"}
0005433462800	7FABB6	4761 560201	OLGA KRASNOVA	{"email": "okrasnova24021975@postgrespro.ru", "phone": "+70553187535"}
0005433462801	2D0DB1	5455 150526	TAMARA NIKITINA	{"email": "t.nikitina-08071962@postgrespro.ru", "phone": "+70215372435"}
0005433462802	2D0DB1	3951 991174	NATALYA EGOROVA	{"phone": "+70352431200"}
0005433462803	351CEF	0781 469887	OLGA KUZNECOVA	{"phone": "+70137627863"}
0005433462804	86276A	4659 661293	SERGEY SMIRNOV	{"email": "sergeysmirnov.1975@postgrespro.ru", "phone": "+70487199290"}
0005433462805	AC540F	6637 493435	ANATOLIY ZAYCEV	{"email": "zaycev.a-1970@postgrespro.ru", "phone": "+70733322158"}
0005433462806	AC540F	7949 720891	KIRILL VLASOV	{"phone": "+70675987508"}
0005433462807	521BB0	9215 809464	EVGENIY NIKITIN	{"email": "evgeniy.nikitin_1975@postgrespro.ru", "phone": "+70905740126"}
0005433462808	521BB0	7175 619796	SERGEY SCHERBAKOV	{"phone": "+70663361252"}
0005433463861	BBB82F	8734 687202	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr19091977@postgrespro.ru", "phone": "+70314106363"}
0005433463862	BBB82F	1149 054742	SERGEY OSIPOV	{"email": "sosipov_091981@postgrespro.ru", "phone": "+70374917282"}
0005433463863	BBB82F	5987 828013	ILDAR FOMIN	{"phone": "+70953565125"}
0005433463864	5E1721	3740 909090	ANASTASIYA MAKSIMOVA	{"email": "maksimova-anastasiya.081959@postgrespro.ru", "phone": "+70191915883"}
0005433463865	5E1721	3052 350579	RUSLAN KONOVALOV	{"email": "r-konovalov.11011969@postgrespro.ru", "phone": "+70160972603"}
0005433463866	4EF43F	2602 092211	NIKOLAY KAZAKOV	{"email": "nkazakov.03111980@postgrespro.ru", "phone": "+70060274666"}
0005433463867	13F3A0	2592 221508	ALEKSANDR KOROLEV	{"email": "aleksandr_korolev041971@postgrespro.ru", "phone": "+70911423063"}
0005433463868	F2DB1B	0847 355399	VLADIMIR SCHERBAKOV	{"email": "vladimir_scherbakov05121977@postgrespro.ru", "phone": "+70098328658"}
0005433463869	7D736F	2382 245049	ALEKSANDR MARTYNOV	{"email": "a_martynov.15121972@postgrespro.ru", "phone": "+70752548702"}
0005433463870	5C3D7B	9046 116220	ANTONINA SIDOROVA	{"email": "a.sidorova-07031968@postgrespro.ru", "phone": "+70193025720"}
0005433463871	5C3D7B	6784 454855	VIOLETTA GORBUNOVA	{"phone": "+70217846182"}
0005433463872	B6E6B4	3794 289844	VERA GRISHINA	{"phone": "+70746627161"}
0005433463873	B4D6C1	5948 724850	SERGEY KUDRYASHOV	{"email": "skudryashov-1970@postgrespro.ru", "phone": "+70626701900"}
0005433463874	C51546	1996 623611	VALERIY BELOV	{"email": "belov-v-091977@postgrespro.ru", "phone": "+70965317505"}
0005433463875	513062	3020 722547	KRISTINA MEDVEDEVA	{"email": "k-medvedeva.1966@postgrespro.ru", "phone": "+70792338338"}
0005433463876	E3FAB4	1440 291255	SERGEY FEDOROV	{"email": "s-fedorov-13041971@postgrespro.ru", "phone": "+70098258219"}
0005433463877	102025	4942 730718	NADEZHDA ALEKSANDROVA	{"phone": "+70422452581"}
0005433463878	F65CBF	1956 206760	VERA ABRAMOVA	{"phone": "+70599243232"}
0005433463879	69875B	7722 174008	TAISIYA KULIKOVA	{"email": "taisiyakulikova1976@postgrespro.ru", "phone": "+70055526372"}
0005433463880	69875B	5562 235037	OLEG ABRAMOV	{"phone": "+70906925921"}
0005433463881	6D5DF7	9231 250734	EKATERINA ILINA	{"phone": "+70848036515"}
0005433463882	6D5DF7	9138 276620	ALLA DAVYDOVA	{"phone": "+70143129566"}
0005433463883	52FF62	1707 031372	GALINA OSIPOVA	{"email": "osipova.g_1982@postgrespro.ru", "phone": "+70475288010"}
0005433463884	3B1E55	3523 147816	ANDREY MOISEEV	{"email": "andrey_moiseev_101964@postgrespro.ru", "phone": "+70708908275"}
0005433463885	3B1E55	7922 505149	EVGENIYA ANDREEVA	{"email": "evgeniya-andreeva_17121977@postgrespro.ru", "phone": "+70743573745"}
0005433463886	A89653	9758 791208	DMITRIY ZAKHAROV	{"phone": "+70809623533"}
0005433463887	4D34FE	4488 340092	SERGEY KOROLEV	{"phone": "+70125487612"}
0005433463888	9213B4	2862 674725	FATIMA ZAYCEVA	{"phone": "+70903060085"}
0005433463889	C70390	8101 546903	EVGENIY VASILEV	{"email": "evgeniy_vasilev-1964@postgrespro.ru", "phone": "+70573561442"}
0005433463890	FCB47F	6928 033919	OLGA ALEKSEEVA	{"email": "o_alekseeva051970@postgrespro.ru", "phone": "+70940573241"}
0005433463891	D10FC3	1035 512256	ALEKSEY NIKOLAEV	{"phone": "+70702976736"}
0005433463892	D10FC3	5316 524216	YURIY KONOVALOV	{"email": "y-konovalov10091974@postgrespro.ru", "phone": "+70318852186"}
0005433463893	049E50	8793 912065	ANTONINA NIKITINA	{"email": "nikitina.a.1976@postgrespro.ru", "phone": "+70051983428"}
0005433463894	049E50	3527 034744	VALENTINA DMITRIEVA	{"phone": "+70500469181"}
0005433463895	1398BB	1290 977043	ELENA KOMAROVA	{"phone": "+70537251466"}
0005433463896	2CAF5D	3530 027355	LYUDMILA VLASOVA	{"phone": "+70046874656"}
0005433463897	B0DE49	7361 808894	YURIY MOROZOV	{"email": "yuriy-morozov_20081977@postgrespro.ru", "phone": "+70936460552"}
0005433463898	0B5B61	7917 960867	PAVEL GRIGOREV	{"email": "grigorev-pavel.08031986@postgrespro.ru", "phone": "+70676043464"}
0005433463899	D61C9E	9573 959839	ILNUR KULIKOV	{"phone": "+70229535819"}
0005433463900	AFE746	7648 382288	ANASTASIYA DAVYDOVA	{"phone": "+70770048630"}
0005433463901	AFE746	2516 419394	IRINA FROLOVA	{"email": "frolova.irina-19041980@postgrespro.ru", "phone": "+70395192455"}
0005433463902	AD9A9D	9129 584600	NATALYA NAUMOVA	{"email": "naumovan_17041980@postgrespro.ru", "phone": "+70208160095"}
0005433463903	AD9A9D	4469 972138	NATALIYA IVANOVA	{"phone": "+70599884942"}
0005433463904	A069D4	7418 808781	LYUDMILA DENISOVA	{"email": "denisoval.071978@postgrespro.ru", "phone": "+70996971691"}
0005433463905	E02E16	3409 439775	KSENIYA NOVIKOVA	{"phone": "+70268157764"}
0005433463906	7F87D6	4001 721833	ILYA BORISOV	{"email": "i_borisov.1971@postgrespro.ru", "phone": "+70918878048"}
0005433468542	618199	7746 780592	LEONID ZAKHAROV	{"phone": "+70994552896"}
0005433463907	7F87D6	2854 743231	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya1963@postgrespro.ru", "phone": "+70302241002"}
0005433463908	CD56D5	0774 970245	SERGEY FOMIN	{"email": "fomin-s_1962@postgrespro.ru", "phone": "+70577319510"}
0005433463909	CD56D5	4556 945549	ALEKSEY GRIGOREV	{"email": "grigoreva-021980@postgrespro.ru", "phone": "+70660046765"}
0005433463910	CD56D5	2628 167160	VITALIY ZAYCEV	{"email": "v-zaycev011978@postgrespro.ru", "phone": "+70088053708"}
0005433463911	6A8889	1738 844798	MARIYA BOGDANOVA	{"phone": "+70382398082"}
0005433463912	53CC0F	0103 554402	GALINA VOLKOVA	{"email": "g_volkova_29091974@postgrespro.ru", "phone": "+70025300678"}
0005433463913	81DD0D	5078 981026	OLGA POPOVA	{"phone": "+70810216575"}
0005433463914	81DD0D	5283 065388	ELENA OVCHINNIKOVA	{"phone": "+70756619059"}
0005433463915	3F8323	4605 228692	IGOR STEPANOV	{"phone": "+70441295161"}
0005433463916	C85912	1312 054642	ALEKSEY MEDVEDEV	{"phone": "+70642204706"}
0005433463917	8E4226	1944 218433	LYUDMILA MAKAROVA	{"email": "l-makarova-1985@postgrespro.ru", "phone": "+70128548626"}
0005433463918	A0BBC5	8559 805312	MARGARITA LUKYANOVA	{"email": "lukyanova.margarita_061970@postgrespro.ru", "phone": "+70657275779"}
0005433463919	F1045B	3633 670905	VLADIMIR SOROKIN	{"phone": "+70479299529"}
0005433463920	F1045B	3041 339079	VLADISLAV STEPANOV	{"phone": "+70613189008"}
0005433463921	86931B	8542 673201	VERA ZHUKOVA	{"email": "verazhukova.1979@postgrespro.ru", "phone": "+70872412517"}
0005433463922	F38B5F	1733 743224	IGOR IVANOV	{"phone": "+70098181332"}
0005433463923	F38B5F	2029 615627	NIKOLAY KOROLEV	{"phone": "+70479183097"}
0005433463924	4FA1A4	7647 318126	MARINA GRISHINA	{"email": "marinagrishina21121985@postgrespro.ru", "phone": "+70206565705"}
0005433463925	80DFC6	1626 799978	RAFAIL BONDARENKO	{"phone": "+70035021166"}
0005433463926	ED63A1	3831 756806	ANNA MAKAROVA	{"email": "makarova-anna_25111958@postgrespro.ru", "phone": "+70309942546"}
0005433463927	B8CBB1	4758 136505	YURIY RODIONOV	{"phone": "+70533102120"}
0005433463928	B8CBB1	2468 078897	VLADIMIR IVANOV	{"phone": "+70990734043"}
0005433463929	B8CBB1	0990 887141	EVGENIY VLASOV	{"phone": "+70910695850"}
0005433463930	8CD5D8	3059 784520	KLAVDIYA IVANOVA	{"email": "klavdiya.ivanova17101979@postgrespro.ru", "phone": "+70306652734"}
0005433463931	ABEF85	8989 388997	EVGENIYA YAKOVLEVA	{"phone": "+70793258488"}
0005433463932	ABEF85	6446 704220	VERA YAKOVLEVA	{"phone": "+70705042546"}
0005433463933	19FE54	0843 102633	VALENTIN FROLOV	{"phone": "+70970812238"}
0005433463934	73B513	4933 379232	VENERA ZOTOVA	{"email": "v_zotova.071969@postgrespro.ru", "phone": "+70529412998"}
0005433463935	D8F679	6930 038256	ELENA ZAYCEVA	{"phone": "+70405134733"}
0005433463936	430BC9	6888 999164	VLADIMIR STEPANOV	{"email": "stepanov-v.30071974@postgrespro.ru", "phone": "+70899955197"}
0005433463937	430BC9	6186 344327	NATALYA SAVELEVA	{"email": "natalya-saveleva_15041975@postgrespro.ru", "phone": "+70959047494"}
0005433463938	E3979B	7965 883089	OKSANA GERASIMOVA	{"phone": "+70978728219"}
0005433463939	181C75	7922 166466	LYUBOV MAKAROVA	{"email": "makarova-l.041982@postgrespro.ru", "phone": "+70542987376"}
0005433463940	C82D59	4830 842814	GRIGORIY MATVEEV	{"email": "matveev_g.16031974@postgrespro.ru", "phone": "+70386353050"}
0005433463941	DBDF35	3106 471405	IVAN NAUMOV	{"phone": "+70679797519"}
0005433463942	777B8E	5989 978169	NATALYA YAKOVLEVA	{"phone": "+70796992064"}
0005433463943	0CB756	8319 457409	RUSLAN GAVRILOV	{"phone": "+70758630315"}
0005433463944	A996C9	3995 652130	VIKTOR KUZNECOV	{"phone": "+70508200031"}
0005433463945	3ED136	6363 233402	ANNA KUZNECOVA	{"phone": "+70633157075"}
0005433463946	3ED136	4429 835405	NIKOLAY ROMANOV	{"phone": "+70004034959"}
0005433463947	3ED136	6622 437491	RIMMA ZAKHAROVA	{"email": "r-zakharova-011962@postgrespro.ru", "phone": "+70035693087"}
0005433463948	54986B	8883 801931	ALEKSANDR ANTONOV	{"email": "a_antonov_23021958@postgrespro.ru", "phone": "+70046823162"}
0005433463949	54986B	0812 478103	ALEKSEY SIDOROV	{"email": "alekseysidorov.081965@postgrespro.ru", "phone": "+70817463630"}
0005433463950	399B08	9496 726036	ALEKSANDR SHEVCHENKO	{"phone": "+70984316339"}
0005433463951	399B08	7792 384815	ANDREY TIMOFEEV	{"phone": "+70303799008"}
0005433463952	399B08	9064 360962	OKSANA ALEKSEEVA	{"email": "o.alekseeva-09081963@postgrespro.ru", "phone": "+70388931778"}
0005433463953	B8E0E7	7349 829620	NATALYA VASILEVA	{"email": "vasileva_n_1978@postgrespro.ru", "phone": "+70861858655"}
0005433463954	78B62B	5385 057300	TATYANA ALEKSEEVA	{"email": "alekseeva.t1967@postgrespro.ru", "phone": "+70660151418"}
0005433463955	2A876E	5864 965345	ALEKSEY SEMENOV	{"phone": "+70094418012"}
0005433463956	32B65B	8539 941065	ALEKSANDR VASILEV	{"email": "vasilev_a051971@postgrespro.ru", "phone": "+70334090953"}
0005433463957	1EC9F8	4003 087090	ALLA ROMANOVA	{"email": "alla-romanova.1972@postgrespro.ru", "phone": "+70339997708"}
0005433463958	F3A655	8494 240195	ANDREY IVANOV	{"email": "ivanov_andrey.1977@postgrespro.ru", "phone": "+70766341666"}
0005433463959	602C23	2314 795206	SERGEY SHEVCHENKO	{"phone": "+70702527590"}
0005433463960	602C23	0809 191721	NATALYA ZHURAVLEVA	{"email": "natalya-zhuravleva_111968@postgrespro.ru", "phone": "+70954097828"}
0005433463961	894C36	3827 625531	EKATERINA TIMOFEEVA	{"email": "timofeeva_ekaterina.26041977@postgrespro.ru", "phone": "+70837342632"}
0005433463962	38C9A3	7512 165970	PAVEL TIKHONOV	{"email": "pavel.tikhonov_1970@postgrespro.ru", "phone": "+70082288630"}
0005433463963	38C9A3	2408 718274	NATALYA TARASOVA	{"phone": "+70336139289"}
0005433463964	9A8E3D	2581 377489	ALEKSANDR MATVEEV	{"email": "matveev.aleksandr-09121969@postgrespro.ru", "phone": "+70142643978"}
0005433463965	9A8E3D	1054 086043	MAKSIM SEMENOV	{"email": "semenov.m-1968@postgrespro.ru", "phone": "+70478690497"}
0005433463966	28BAC3	3621 389924	ANNA IVANOVA	{"phone": "+70377936915"}
0005433463967	FCD972	0314 982109	ILYA SMIRNOV	{"phone": "+70218804416"}
0005433463968	FCD972	7411 806864	LIYA PETROVA	{"email": "l_petrova-031974@postgrespro.ru", "phone": "+70761901182"}
0005433468180	91B58B	6077 063659	VALENTINA BELYAEVA	{"phone": "+70099482452"}
0005433468181	5E46C6	3558 880631	KIRILL PAVLOV	{"email": "k_pavlov1971@postgrespro.ru", "phone": "+70030741211"}
0005433468182	31EA60	9951 099104	EVGENIY GRIGOREV	{"phone": "+70018568034"}
0005433468183	31EA60	5202 073464	INNA KOLESNIKOVA	{"email": "inna.kolesnikova_07061992@postgrespro.ru", "phone": "+70191581293"}
0005433468184	06F1F8	5609 876751	GENNADIY SERGEEV	{"email": "g-sergeev_1968@postgrespro.ru", "phone": "+70770782796"}
0005433468185	F0758A	7401 514055	SERGEY ROMANOV	{"phone": "+70990000103"}
0005433468186	7CE14C	5171 586849	MATVEY FOMIN	{"email": "matvey.fomin1971@postgrespro.ru", "phone": "+70827369192"}
0005433468187	A53EDB	5777 775294	VYACHESLAV SEMENOV	{"phone": "+70191387091"}
0005433468188	C68D22	8604 835708	NIKOLAY EGOROV	{"phone": "+70652885763"}
0005433468189	554FA4	0795 301214	ANDREY DENISOV	{"phone": "+70055924021"}
0005433468190	554FA4	5740 138295	ALEKSANDR DENISOV	{"email": "aleksandr-denisov.111975@postgrespro.ru", "phone": "+70561160664"}
0005433468191	09499E	1946 460050	MATVEY VASILEV	{"phone": "+70766611859"}
0005433468192	F13F13	9473 262961	ALEKSEY ZAKHAROV	{"email": "zakharova15061978@postgrespro.ru", "phone": "+70479374931"}
0005433468193	F13F13	0225 701199	VASILIY MARTYNOV	{"email": "martynovvasiliy-1972@postgrespro.ru", "phone": "+70044780168"}
0005433468194	F13F13	3368 214378	LARISA KULIKOVA	{"phone": "+70267023647"}
0005433468195	573EE9	3158 233424	VLADIMIR SOLOVEV	{"phone": "+70214284045"}
0005433468196	221845	1795 566455	MARINA POLYAKOVA	{"email": "marinapolyakova051965@postgrespro.ru", "phone": "+70645388255"}
0005433468197	221845	8615 823509	ALEKSANDR STEPANOV	{"phone": "+70390173689"}
0005433468198	295223	1126 001740	LYUBOV OSIPOVA	{"email": "osipova.l041979@postgrespro.ru", "phone": "+70464713923"}
0005433468199	295223	5553 539393	YULIYA DMITRIEVA	{"email": "yuliyadmitrieva_1968@postgrespro.ru", "phone": "+70891962773"}
0005433468200	295223	9786 639790	IRINA TARASOVA	{"phone": "+70521130203"}
0005433468201	3C3C60	9810 262975	ALENA KOMAROVA	{"phone": "+70229380860"}
0005433468202	3C3C60	6317 890192	IGNAT MOROZOV	{"phone": "+70702006704"}
0005433468203	723934	1762 904214	NADEZHDA ARKHIPOVA	{"email": "arkhipova_nadezhda19031977@postgrespro.ru", "phone": "+70929720365"}
0005433468204	8A5A2E	0110 481528	ALEKSANDR VASILEV	{"phone": "+70953675152"}
0005433468205	E4B6CB	4853 249374	OLEG KARPOV	{"phone": "+70837296445"}
0005433468206	4248FB	6129 689080	VALENTINA EFIMOVA	{"email": "efimova_v27121965@postgrespro.ru", "phone": "+70750159260"}
0005433468207	A58248	5348 856920	SERGEY KAZAKOV	{"email": "kazakovsergey111977@postgrespro.ru", "phone": "+70285449992"}
0005433468208	A58248	3818 804428	TATYANA KISELEVA	{"phone": "+70196940299"}
0005433468209	5B2E7D	8900 484681	VALENTINA TITOVA	{"email": "v_titova12011968@postgrespro.ru", "phone": "+70565623471"}
0005433468210	506207	1183 367102	NADEZHDA OSIPOVA	{"email": "osipova-n.08041963@postgrespro.ru", "phone": "+70252327214"}
0005433468211	506207	9291 372696	DARYA KISELEVA	{"email": "darya-kiseleva_1963@postgrespro.ru", "phone": "+70488238130"}
0005433468212	0FCE20	7777 373956	RENAT ALEKSEEV	{"email": "alekseev-renat_101972@postgrespro.ru", "phone": "+70252828264"}
0005433468213	23DBDF	5062 526092	IRINA MAKAROVA	{"phone": "+70449787686"}
0005433468214	1E89A8	5474 675430	IRINA ZHUKOVA	{"email": "zhukova-irina1967@postgrespro.ru", "phone": "+70899336472"}
0005433468215	1E89A8	5305 933452	OKSANA KOMAROVA	{"email": "komarovao031984@postgrespro.ru", "phone": "+70799659451"}
0005433468216	1F1AC4	4387 953369	RAISA TARASOVA	{"phone": "+70400966025"}
0005433468217	8F5E70	5340 307949	ELENA SIDOROVA	{"phone": "+70828022707"}
0005433468218	757B59	4168 224476	VERONIKA NIKIFOROVA	{"phone": "+70624984458"}
0005433468219	7FFC65	3663 196745	NINA ZHUKOVA	{"email": "nzhukova_18051973@postgrespro.ru", "phone": "+70758684737"}
0005433468220	7FFC65	7686 717246	MATVEY BORISOV	{"phone": "+70706101189"}
0005433468221	6E5E12	6418 864599	ANTONINA CHERNOVA	{"phone": "+70615451059"}
0005433468222	54D02B	9484 617689	ALEKSEY ANTONOV	{"phone": "+70766706469"}
0005433468223	733A47	6968 560887	TATYANA IVANOVA	{"email": "t-ivanova-26021972@postgrespro.ru", "phone": "+70877366338"}
0005433468224	E93362	4458 664986	LIDIYA KOLESNIKOVA	{"email": "l.kolesnikova-1959@postgrespro.ru", "phone": "+70841962738"}
0005433468225	ED0911	4626 363295	VERA PETROVA	{"email": "vpetrova121965@postgrespro.ru", "phone": "+70819968123"}
0005433468226	9D4497	3867 728895	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev.1969@postgrespro.ru", "phone": "+70308536592"}
0005433468227	9D4497	5787 431292	OLESYA LEBEDEVA	{"phone": "+70395761226"}
0005433468228	8CC916	0752 780626	ALENA IVANOVA	{"phone": "+70149154635"}
0005433468229	43DA2C	5850 330589	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov.18071971@postgrespro.ru", "phone": "+70141841624"}
0005433468230	1DBC03	9818 370767	SVETLANA PETROVA	{"email": "petrova-svetlana-011972@postgrespro.ru", "phone": "+70013962190"}
0005433468231	1DBC03	8243 773629	ALEVTINA MIKHAYLOVA	{"email": "alevtina_mikhaylova_1975@postgrespro.ru", "phone": "+70182144635"}
0005433468232	1DBC03	4048 869207	ALEKSANDR NAUMOV	{"email": "naumovaleksandr.20111970@postgrespro.ru", "phone": "+70889926998"}
0005433468233	C66DCC	0382 019776	EVGENIY ZAKHAROV	{"phone": "+70197401762"}
0005433468234	E4E8FA	8765 484682	NIKOLAY NOVIKOV	{"phone": "+70494139656"}
0005433468235	E4E8FA	0889 623743	VERA SOLOVEVA	{"email": "vera_soloveva.091980@postgrespro.ru", "phone": "+70742435774"}
0005433468236	F13E82	5335 656643	DMITRIY MAKAROV	{"phone": "+70105699684"}
0005433468237	A7DD5C	4639 952082	ELENA KUZMINA	{"email": "e.kuzmina1970@postgrespro.ru", "phone": "+70701612422"}
0005433468238	26AF63	9271 414386	ANNA AFANASEVA	{"email": "aafanaseva_1955@postgrespro.ru", "phone": "+70552886855"}
0005433468239	7FD19C	1897 414777	TATYANA ERMAKOVA	{"email": "t-ermakova-1984@postgrespro.ru", "phone": "+70957073469"}
0005433468240	2DFFBC	2836 873646	ANDREY IVANOV	{"phone": "+70941268460"}
0005433468241	E43933	0397 616813	SVETLANA POPOVA	{"email": "popovasvetlana_1970@postgrespro.ru", "phone": "+70383019945"}
0005433468242	23E841	8460 495266	TATYANA KONOVALOVA	{"email": "konovalova-tatyana-01031974@postgrespro.ru", "phone": "+70872435387"}
0005433468243	23E841	8226 657224	ALEKSANDR SIDOROV	{"phone": "+70613607316"}
0005433468244	F2F6F3	7395 060491	EVGENIY EGOROV	{"email": "e_egorov24121976@postgrespro.ru", "phone": "+70680124341"}
0005433468416	4E9CBC	3720 657779	SERGEY FEDOROV	{"phone": "+70703357051"}
0005433468245	45C866	4412 571343	IRINA EGOROVA	{"email": "irinaegorova_1972@postgrespro.ru", "phone": "+70211922670"}
0005433468246	45C866	7919 456353	GALINA NIKOLAEVA	{"phone": "+70545192361"}
0005433468247	007B9B	7481 683308	OLEG ALEKSANDROV	{"email": "o.aleksandrov.1965@postgrespro.ru", "phone": "+70855759531"}
0005433468248	E2BEB8	2564 242125	OLGA NOVIKOVA	{"phone": "+70433438177"}
0005433468249	E2BEB8	9693 630540	IRINA NOVIKOVA	{"phone": "+70553973377"}
0005433468250	92FD8D	2744 287684	OLEG KULIKOV	{"phone": "+70066897865"}
0005433468251	DDBBE2	5329 476301	ALEKSEY FOMIN	{"phone": "+70211653220"}
0005433468252	EF10F9	3247 038803	NATALYA POPOVA	{"email": "popovan_021975@postgrespro.ru", "phone": "+70063305045"}
0005433468253	EF10F9	2088 799789	ALEKSANDR MAKAROV	{"phone": "+70203015867"}
0005433468254	275302	7479 047967	ELENA ANTONOVA	{"phone": "+70603575749"}
0005433468255	FA746B	7403 765387	ANAIT GRISHINA	{"phone": "+70425816466"}
0005433468256	82ABBD	6591 772904	DENIS KAZAKOV	{"phone": "+70564644777"}
0005433468257	DD4D7D	4594 527781	ELENA ANISIMOVA	{"phone": "+70774983191"}
0005433468258	DD4D7D	7847 560244	RINAT GERASIMOV	{"phone": "+70814837965"}
0005433468259	412325	9431 690245	ANDREY CHERNOV	{"email": "chernov-andrey1970@postgrespro.ru", "phone": "+70031422329"}
0005433468260	FB7FAD	2991 205221	IGOR VOROBEV	{"email": "vorobevigor_121975@postgrespro.ru", "phone": "+70009832934"}
0005433468261	DF9BB5	4268 513747	ELVIRA MOROZOVA	{"email": "morozovaelvira08021968@postgrespro.ru", "phone": "+70590018713"}
0005433468262	D88343	1611 975165	NATALYA NESTEROVA	{"email": "natalya-nesterova08071967@postgrespro.ru", "phone": "+70677728802"}
0005433468263	D2CD80	4690 014871	ALEKSANDR BORISOV	{"email": "borisov.aleksandr_15081978@postgrespro.ru", "phone": "+70411776927"}
0005433468264	D2CD80	7155 646982	ANATOLIY NIKOLAEV	{"phone": "+70883719554"}
0005433468265	A53F10	1651 390499	TATYANA POPOVA	{"email": "popovat-09011968@postgrespro.ru", "phone": "+70489176438"}
0005433468266	D28916	6633 179011	OLGA VOLKOVA	{"phone": "+70806006809"}
0005433468267	380AA0	1946 228288	VALENTINA BORISOVA	{"phone": "+70316803418"}
0005433468268	835D1C	1201 810099	ANATOLIY MATVEEV	{"phone": "+70962112186"}
0005433468269	8001AC	3116 835915	YURIY VLASOV	{"phone": "+70511328594"}
0005433468270	8001AC	7343 716527	ANNA TARASOVA	{"phone": "+70877308760"}
0005433468271	21406F	1591 752284	MARK TIKHONOV	{"phone": "+70911468519"}
0005433468272	0FFFD9	5033 492838	VIKTOR BORISOV	{"email": "borisov_viktor1978@postgrespro.ru", "phone": "+70048289440"}
0005433468273	F905AF	8146 006414	OKSANA KOZLOVA	{"phone": "+70659495707"}
0005433468274	F2B84D	9227 209386	ALEVTINA TIKHONOVA	{"email": "tikhonova_alevtina_121983@postgrespro.ru", "phone": "+70549839040"}
0005433468275	F2B84D	6931 726247	ANDREY TIMOFEEV	{"email": "a.timofeev.1966@postgrespro.ru", "phone": "+70773434752"}
0005433468276	2E7B0D	0107 298291	LYUDMILA SEMENOVA	{"email": "semenova.lyudmila.101965@postgrespro.ru", "phone": "+70264685118"}
0005433468277	2E7B0D	6503 528114	VLADIMIR KRASNOV	{"phone": "+70835493421"}
0005433468278	5FF6B9	3522 364027	ALEKSANDR ORLOV	{"email": "orlovaleksandr-1974@postgrespro.ru", "phone": "+70080684136"}
0005433468279	B49095	7740 585481	ALEKSANDR FEDOTOV	{"email": "fedotov_a.04101953@postgrespro.ru", "phone": "+70781732119"}
0005433468280	B49095	0874 150349	ALEKSANDRA FROLOVA	{"phone": "+70536212563"}
0005433468281	81F556	4703 849534	NIKOLAY ALEKSEEV	{"email": "n_alekseev.06071964@postgrespro.ru", "phone": "+70823950673"}
0005433468282	81F556	4957 443067	ALINA PAVLOVA	{"email": "alina.pavlova1974@postgrespro.ru", "phone": "+70973121004"}
0005433468283	536A48	0611 368918	ELENA STEPANOVA	{"phone": "+70897431456"}
0005433468284	9F36EB	6866 356233	LADA SOKOLOVA	{"phone": "+70921967131"}
0005433468285	4A1FC4	7538 428242	NAIL KOZLOV	{"phone": "+70222570005"}
0005433468286	E15F34	0649 313585	ARTEM ILIN	{"email": "ilin_a.011973@postgrespro.ru", "phone": "+70251446242"}
0005433468287	BECCCA	4821 739503	SERGEY MEDVEDEV	{"email": "medvedev-sergey.071967@postgrespro.ru", "phone": "+70093568098"}
0005433468288	2D20C8	2847 185726	VLADIMIR SHEVCHENKO	{"email": "vladimir_shevchenko-02041968@postgrespro.ru", "phone": "+70120539688"}
0005433468289	D93B25	6238 144420	DENIS ABRAMOV	{"email": "denisabramov-121970@postgrespro.ru", "phone": "+70663463137"}
0005433468290	C07EDE	5503 108552	MIKHAIL MIRONOV	{"phone": "+70747308908"}
0005433468291	D17C56	7729 573074	VALENTIN SIDOROV	{"phone": "+70306223278"}
0005433468292	D17C56	8857 242028	VIKTORIYA LEBEDEVA	{"email": "viktoriyalebedeva-02101976@postgrespro.ru", "phone": "+70832562369"}
0005433468293	A55DE4	3400 107782	SERGEY KRASNOV	{"phone": "+70252532362"}
0005433468294	D46619	1838 699861	DMITRIY IVANOV	{"email": "dmitriyivanov1975@postgrespro.ru", "phone": "+70277537495"}
0005433468295	D46619	7138 039038	OLGA YAKOVLEVA	{"phone": "+70311700763"}
0005433468296	66CEAF	8577 801650	IRINA DANILOVA	{"email": "danilova-i.031977@postgrespro.ru", "phone": "+70816332467"}
0005433468297	5ED0F3	5621 240785	ALEKSANDR MOROZOV	{"email": "amorozov101973@postgrespro.ru", "phone": "+70722261494"}
0005433468298	1DF059	3250 419020	ALEKSANDRA ROMANOVA	{"phone": "+70560882731"}
0005433468299	B779F2	3862 930053	SERGEY NIKITIN	{"email": "s-nikitin31081973@postgrespro.ru", "phone": "+70269672125"}
0005433468300	F97364	3649 880759	OLGA BELYAEVA	{"phone": "+70181660146"}
0005433468301	EF9B7D	2681 777649	MARINA KRASNOVA	{"phone": "+70172185616"}
0005433468302	2DB5A8	9013 962080	MARGARITA SCHERBAKOVA	{"email": "scherbakova_margarita.1976@postgrespro.ru", "phone": "+70062081804"}
0005433468303	2DB5A8	7030 681373	VIKTOR SOKOLOV	{"email": "sokolov_viktor.011969@postgrespro.ru", "phone": "+70539766134"}
0005433468304	9C67EF	9584 952566	IVAN NIKOLAEV	{"phone": "+70054909276"}
0005433468305	744528	2800 716250	ELENA STEPANOVA	{"phone": "+70900316500"}
0005433468306	744528	7908 389762	YURIY KUZNECOV	{"phone": "+70856184066"}
0005433468307	744528	3236 374962	VITALIY ZAKHAROV	{"phone": "+70412776573"}
0005433468308	1A7164	0862 409862	ALIYA RYABOVA	{"phone": "+70129519342"}
0005433468309	BDB098	2859 643039	VLADISLAV BORISOV	{"phone": "+70850242980"}
0005433468310	D55F53	5738 977308	ALEKSANDR MAKSIMOV	{"email": "aleksandrmaksimov.26101975@postgrespro.ru", "phone": "+70653932408"}
0005433468311	47AC1F	9971 337020	LEONID PAVLOV	{"phone": "+70417316300"}
0005433468312	5B767D	9019 163784	ALEKSANDR ZAKHAROV	{"email": "zakharova-081967@postgrespro.ru", "phone": "+70342611623"}
0005433468313	4F430D	2466 095479	MAKSIM VASILEV	{"email": "vasilevmaksim.1971@postgrespro.ru", "phone": "+70343530155"}
0005433468314	678583	9302 773429	KAMILA STEPANOVA	{"email": "k_stepanova.1972@postgrespro.ru", "phone": "+70873512178"}
0005433468315	80BE6B	9005 412890	IRINA DENISOVA	{"phone": "+70160220234"}
0005433468316	C3F1D2	2417 519762	VIKTOR ZAYCEV	{"phone": "+70485985224"}
0005433468317	4F537C	1362 805521	SERGEY ISAEV	{"email": "sergey_isaev_1973@postgrespro.ru", "phone": "+70470093353"}
0005433468318	DD052A	2484 378627	MIKHAIL KOZLOV	{"email": "kozlov-mikhail_15121966@postgrespro.ru", "phone": "+70747994682"}
0005433468319	F3612D	7749 071024	YURIY SEMENOV	{"email": "y.semenov-19081981@postgrespro.ru", "phone": "+70939550208"}
0005433468320	F3612D	4007 544002	ALEKSANDR NIKITIN	{"phone": "+70296805486"}
0005433468321	EF4EA5	2536 067422	DMITRIY ILIN	{"phone": "+70291600724"}
0005433468322	9606CB	6915 285067	TATYANA NESTEROVA	{"email": "t-nesterova.22121971@postgrespro.ru", "phone": "+70351144144"}
0005433468323	944B21	3100 871089	IVAN KRASNOV	{"phone": "+70274489537"}
0005433468324	C84AA5	6320 703764	ANATOLIY GUSEV	{"phone": "+70585822771"}
0005433468325	C84AA5	3717 638943	ELENA BELOVA	{"email": "belova.elena-1973@postgrespro.ru", "phone": "+70799075713"}
0005433468326	DE55CA	8496 557559	ALEKSEY FEDOROV	{"phone": "+70930922816"}
0005433468327	DE55CA	2701 616755	VALENTINA PAVLOVA	{"phone": "+70356783500"}
0005433468328	16DA25	8628 410549	KSENIYA YUDINA	{"email": "yudina_k1971@postgrespro.ru", "phone": "+70310217142"}
0005433468329	61D0EA	4426 192531	ALEKSEY MAKSIMOV	{"email": "maksimov_aleksey_031977@postgrespro.ru", "phone": "+70118470901"}
0005433468330	0C4869	8559 314237	YURIY MOISEEV	{"phone": "+70065921381"}
0005433468331	802F35	7477 869896	TATYANA PETROVA	{"phone": "+70420958954"}
0005433468332	5F2783	0962 575785	NIKOLAY ANDREEV	{"phone": "+70004903622"}
0005433468333	FC9368	2741 345062	VIKTORIYA NIKITINA	{"email": "v_nikitina_01031978@postgrespro.ru", "phone": "+70482799671"}
0005433468334	FC9368	2596 926005	IVAN ORLOV	{"email": "orlov_ivan_11071971@postgrespro.ru", "phone": "+70087811144"}
0005433468335	FC9368	2194 657368	ANTON KUZNECOV	{"email": "anton-kuznecov-1965@postgrespro.ru", "phone": "+70386527007"}
0005433468336	A80080	2383 897846	MIKHAIL KULIKOV	{"email": "m_kulikov_08031975@postgrespro.ru", "phone": "+70477068602"}
0005433468337	2CCD0E	4115 346887	MIKHAIL NIKOLAEV	{"phone": "+70346607703"}
0005433468338	E99363	7095 025733	OLGA DAVYDOVA	{"phone": "+70332116238"}
0005433468339	6F7E08	0961 742468	ELVIRA GORBUNOVA	{"phone": "+70208343987"}
0005433468340	D8D800	1349 912807	GENNADIY KOZLOV	{"email": "g-kozlov-1968@postgrespro.ru", "phone": "+70436328678"}
0005433468341	C5BF74	6772 233671	ZOYA KAZAKOVA	{"phone": "+70834664597"}
0005433468342	C5BF74	6246 473613	RAISA NESTEROVA	{"email": "nesterovar121977@postgrespro.ru", "phone": "+70696669608"}
0005433468343	C5BF74	8274 448960	EGOR DENISOV	{"phone": "+70115626684"}
0005433468344	E3A577	9619 014823	ELENA YAKOVLEVA	{"email": "e.yakovleva13011969@postgrespro.ru", "phone": "+70650253153"}
0005433468345	6FEBBF	4793 723747	VERA FROLOVA	{"email": "frolova-v_13011970@postgrespro.ru", "phone": "+70921921064"}
0005433468346	655A2D	9306 050989	NIKOLAY POPOV	{"phone": "+70083239798"}
0005433468347	655A2D	1560 330445	ALFIYA IVANOVA	{"phone": "+70238282223"}
0005433468348	3A967E	0188 097621	DMITRIY GUSEV	{"email": "dmitriygusev23011978@postgrespro.ru", "phone": "+70815103611"}
0005433468349	3A967E	6645 870429	ERIK YAKOVLEV	{"phone": "+70049778738"}
0005433468350	E570C5	6891 131871	TATYANA STEPANOVA	{"email": "t_stepanova-1972@postgrespro.ru", "phone": "+70034671662"}
0005433468351	DFE35E	4745 350087	IRINA KRASNOVA	{"email": "krasnova_irina28121979@postgrespro.ru", "phone": "+70370883966"}
0005433468352	448617	0911 256678	GENNADIY FEDOROV	{"email": "g_fedorov_1961@postgrespro.ru", "phone": "+70562511763"}
0005433468353	DA4460	8654 892694	DANIIL KOZLOV	{"phone": "+70414777779"}
0005433468354	DA4460	2500 715744	LYUBOV ZAYCEVA	{"phone": "+70813611832"}
0005433468355	9E7672	4882 395362	ALEKSANDR ALEKSEEV	{"phone": "+70215729568"}
0005433468356	9E7672	7189 177138	SVYATOSLAV VOROBEV	{"email": "vorobev.s.081958@postgrespro.ru", "phone": "+70314399014"}
0005433468357	9E7672	6761 930613	ANATOLIY DMITRIEV	{"phone": "+70102773203"}
0005433468358	5030D2	6738 765477	ALEKSEY ALEKSEEV	{"phone": "+70237404320"}
0005433468359	5030D2	0498 104992	GALINA SCHERBAKOVA	{"email": "scherbakovagalina041965@postgrespro.ru", "phone": "+70531806933"}
0005433468360	166693	7061 448317	ROMAN KUDRYASHOV	{"phone": "+70919968334"}
0005433468361	166693	6711 324621	NIKITA SOLOVEV	{"email": "solovev_nikita-111970@postgrespro.ru", "phone": "+70074109403"}
0005433468362	DF9DF6	0901 504454	PETR POPOV	{"phone": "+70509250180"}
0005433468363	15F715	3782 277044	ANATOLIY KRASNOV	{"phone": "+70864427406"}
0005433468364	E46035	5821 464512	FEDOR GUSEV	{"phone": "+70856637545"}
0005433468365	E46035	1887 903266	NINA NIKITINA	{"phone": "+70065513144"}
0005433468366	E3DEF1	1998 148749	STEPAN MIKHAYLOV	{"phone": "+70036391888"}
0005433468367	E3DEF1	4357 068447	SVETLANA IVANOVA	{"phone": "+70082779317"}
0005433468368	C82A99	1831 480991	VERA MEDVEDEVA	{"email": "medvedeva_v19051977@postgrespro.ru", "phone": "+70844903851"}
0005433468369	745934	2599 095630	ALEVTINA NAUMOVA	{"phone": "+70674914707"}
0005433468370	745934	4589 586803	IRINA RODIONOVA	{"email": "irodionova1975@postgrespro.ru", "phone": "+70292844130"}
0005433468371	AAE9D5	2505 373580	ELENA SCHERBAKOVA	{"phone": "+70037818135"}
0005433468372	AAE9D5	3242 994772	IRINA NAUMOVA	{"phone": "+70528873789"}
0005433468373	246524	3064 501346	GERMAN PETROV	{"email": "petrov-g.21051976@postgrespro.ru", "phone": "+70427692535"}
0005433468374	E4F401	0242 355068	EKATERINA IVANOVA	{"email": "ekaterinaivanova101972@postgrespro.ru", "phone": "+70018834868"}
0005433468375	E4F401	8650 353109	OLGA AKIMOVA	{"email": "akimova.o_1982@postgrespro.ru", "phone": "+70042451317"}
0005433468376	E4F401	1470 731211	VLADIMIR ABRAMOV	{"email": "vladimir-abramov1966@postgrespro.ru", "phone": "+70707690548"}
0005433468377	1B8041	1604 421053	VARVARA POPOVA	{"email": "popova_varvara.1971@postgrespro.ru", "phone": "+70551043540"}
0005433468378	1B8041	2404 703628	ELENA OSIPOVA	{"phone": "+70555984929"}
0005433468379	293C94	5989 085587	YULIYA TARASOVA	{"email": "tarasova.y051958@postgrespro.ru", "phone": "+70622614876"}
0005433468380	293C94	4177 849797	ELENA BORISOVA	{"phone": "+70550676892"}
0005433468381	293C94	8675 004231	ELENA MIRONOVA	{"email": "mironova.elena-23041974@postgrespro.ru", "phone": "+70501180345"}
0005433468382	6EB374	6615 076338	EVGENIY NIKOLAEV	{"phone": "+70375732572"}
0005433468383	622BD0	5127 496216	ALEKSEY TARASOV	{"email": "tarasov-aleksey_22041974@postgrespro.ru", "phone": "+70382461678"}
0005433468384	4A152D	5312 467387	ELENA KULIKOVA	{"phone": "+70739638229"}
0005433468385	4A152D	5355 360857	ALEKSANDR OSIPOV	{"phone": "+70353935427"}
0005433468386	DB38FE	6909 716215	NATALYA SOLOVEVA	{"phone": "+70996063956"}
0005433468387	3DD071	2970 539071	KLAVDIYA EGOROVA	{"phone": "+70086614530"}
0005433468388	F9B442	0948 853473	OLGA MOROZOVA	{"phone": "+70463904260"}
0005433468389	F9B442	9552 467449	ANDREY VOROBEV	{"phone": "+70562602991"}
0005433468390	C9EA24	9881 493143	VERA AFANASEVA	{"phone": "+70193836892"}
0005433468391	6CAE9F	5474 368903	LEV KUZMIN	{"phone": "+70191316776"}
0005433468392	3123DB	3626 566611	NELLI MAKAROVA	{"email": "makarova.n061963@postgrespro.ru", "phone": "+70299859440"}
0005433468393	3123DB	2651 369172	VLADIMIR TIMOFEEV	{"email": "timofeev-v-11051974@postgrespro.ru", "phone": "+70560828759"}
0005433468394	C40379	6027 486113	ALENA NIKIFOROVA	{"email": "anikiforova24061966@postgrespro.ru", "phone": "+70315161020"}
0005433468395	C40379	2250 799485	SERGEY VASILEV	{"phone": "+70671348495"}
0005433468396	DA219A	5088 228207	ALEKSEY SEMENOV	{"email": "semenov.aleksey_091964@postgrespro.ru", "phone": "+70899729290"}
0005433468397	DA219A	6362 402807	NIKOLAY TIKHONOV	{"phone": "+70805137939"}
0005433468398	3BF12E	9329 213042	ALEKSEY PETROV	{"phone": "+70615024947"}
0005433468399	A06A56	8836 958965	VIKTORIYA FOMINA	{"email": "fomina_v071983@postgrespro.ru", "phone": "+70317510163"}
0005433468400	942B87	7765 075375	DARYA MASLOVA	{"phone": "+70197709749"}
0005433468401	FA73E7	9115 048832	VIKTOR MOROZOV	{"email": "vmorozov.1973@postgrespro.ru", "phone": "+70706864881"}
0005433468402	D7BE99	7594 886968	NIKOLAY SERGEEV	{"phone": "+70117019570"}
0005433468403	475956	5751 940455	SERGEY MAKAROV	{"email": "makarov.s_011967@postgrespro.ru", "phone": "+70255486764"}
0005433468404	475956	2471 930340	ANATOLIY ALEKSEEV	{"email": "alekseev_anatoliy_25051967@postgrespro.ru", "phone": "+70175174424"}
0005433468405	DFC201	6212 739957	VALERIYA NIKITINA	{"phone": "+70617404105"}
0005433468406	AE7090	1545 452607	ARTUR GAVRILOV	{"email": "gavrilov_a-011987@postgrespro.ru", "phone": "+70846088679"}
0005433468407	735FD9	2646 571194	ELENA NAUMOVA	{"phone": "+70890844576"}
0005433468408	735FD9	8484 398718	SERGEY KUDRYASHOV	{"phone": "+70781174339"}
0005433468409	44F432	8689 591444	ALEKSANDR KUZNECOV	{"email": "kuznecov_a30041981@postgrespro.ru", "phone": "+70914782869"}
0005433468410	5F7AF9	1955 123665	ANNA MAKAROVA	{"email": "anna-makarova.24031975@postgrespro.ru", "phone": "+70409525142"}
0005433468411	B3056A	7482 527029	ROMAN ABRAMOV	{"phone": "+70650981400"}
0005433468412	B54E09	5155 290102	ALEKSANDRA NOVIKOVA	{"email": "novikovaa-101982@postgrespro.ru", "phone": "+70070794216"}
0005433468413	590C06	1909 765337	VYACHESLAV VASILEV	{"email": "vasilevvyacheslav-07091984@postgrespro.ru", "phone": "+70045041471"}
0005433468414	CE5628	1045 095699	ALEKSANDR FEDOTOV	{"phone": "+70589863505"}
0005433468415	ECAC1B	9106 521251	ARTEM ZHUKOV	{"email": "a-zhukov.071974@postgrespro.ru", "phone": "+70785985406"}
0005433468417	512CBA	8385 477962	EKATERINA ABRAMOVA	{"phone": "+70501964970"}
0005433468418	DAB0FD	3539 326952	OLGA KOZLOVA	{"phone": "+70926151671"}
0005433468419	DAB0FD	6098 959444	MIKHAIL GUSEV	{"phone": "+70581431579"}
0005433468420	ED99D2	0547 211117	INNA PAVLOVA	{"phone": "+70375911955"}
0005433468421	7080A6	6337 479125	ANNA TITOVA	{"phone": "+70124492280"}
0005433468422	51DCFC	7455 069945	ZINAIDA SOKOLOVA	{"email": "sokolova.z1983@postgrespro.ru", "phone": "+70467534967"}
0005433468423	E3D06A	3285 005105	ALEKSANDR ISAEV	{"email": "aleksandr.isaev091964@postgrespro.ru", "phone": "+70664715244"}
0005433468424	F2935E	9343 809266	YULIYA VASILEVA	{"email": "yvasileva.1974@postgrespro.ru", "phone": "+70091210986"}
0005433468425	F2935E	1395 253861	VALERIY VLASOV	{"phone": "+70267084015"}
0005433468426	CD32EF	1177 461417	RENAT FOMIN	{"email": "fomin-renat1970@postgrespro.ru", "phone": "+70651489903"}
0005433468427	66DE96	4241 852008	RAISA KISELEVA	{"email": "r-kiseleva-1964@postgrespro.ru", "phone": "+70584508782"}
0005433468428	4DE2B3	3428 377040	LYUDMILA MAKAROVA	{"email": "makarova_l031979@postgrespro.ru", "phone": "+70566815266"}
0005433468429	82638D	4140 180271	DARYA KUZNECOVA	{"email": "d-kuznecova011984@postgrespro.ru", "phone": "+70758329819"}
0005433468430	82638D	2484 767791	NIKITA SERGEEV	{"phone": "+70427717061"}
0005433468431	C2B68E	4647 010225	LIDIYA LEBEDEVA	{"phone": "+70047097279"}
0005433468432	C2B68E	6080 601016	ALEKSANDR IVANOV	{"phone": "+70283988879"}
0005433468433	AF9832	3372 330377	KSENIYA CHERNOVA	{"email": "kseniya.chernova08071967@postgrespro.ru", "phone": "+70184265902"}
0005433468434	2DFF85	5505 069705	IVAN ZHURAVLEV	{"email": "zhuravlevivan-1984@postgrespro.ru", "phone": "+70427146686"}
0005433468435	2DFF85	3597 008722	SVETLANA POPOVA	{"email": "svetlanapopova-1964@postgrespro.ru", "phone": "+70678864603"}
0005433468436	FA68C9	5145 658604	MAKSIM EGOROV	{"phone": "+70107721191"}
0005433468437	FA68C9	0934 257927	LIDIYA FOMINA	{"phone": "+70156030635"}
0005433468438	D84F12	9444 892238	VALENTINA SIDOROVA	{"email": "sidorova.valentina-21031976@postgrespro.ru", "phone": "+70506007941"}
0005433468439	D84F12	2610 329876	LYUDMILA ZOTOVA	{"email": "lyudmilazotova-1974@postgrespro.ru", "phone": "+70728822153"}
0005433468440	D84F12	7223 741482	NINA FILATOVA	{"phone": "+70799766448"}
0005433468441	761DA3	0062 186419	ALEKSANDR RODIONOV	{"phone": "+70763449468"}
0005433468442	239E91	3399 713003	VALENTINA MAKAROVA	{"email": "makarovav_041967@postgrespro.ru", "phone": "+70887489500"}
0005433468443	239E91	8709 628661	NINA VASILEVA	{"email": "vasileva_nina26031976@postgrespro.ru", "phone": "+70520115202"}
0005433468444	06B69D	3712 350320	LILIYA NOVIKOVA	{"phone": "+70010029258"}
0005433468445	7DEB72	4951 920508	RUSLAN KUZNECOV	{"phone": "+70426953922"}
0005433468446	B698D8	7133 902387	OKSANA EFIMOVA	{"email": "efimovao.031987@postgrespro.ru", "phone": "+70934573253"}
0005433468447	B698D8	0160 294475	IVAN KUZNECOV	{"email": "ikuznecov.061977@postgrespro.ru", "phone": "+70629398732"}
0005433468448	5F6E20	8914 067301	ELIZAVETA IVANOVA	{"phone": "+70508821499"}
0005433468449	F978B7	9957 448639	ANDREY SERGEEV	{"email": "sergeev_andrey041966@postgrespro.ru", "phone": "+70504823939"}
0005433468450	FDE143	0190 674633	NIKOLAY VASILEV	{"email": "nikolay.vasilev1971@postgrespro.ru", "phone": "+70686963141"}
0005433468451	E55EE3	1214 401876	OLEG SMIRNOV	{"email": "smirnovo1961@postgrespro.ru", "phone": "+70293343089"}
0005433468452	2BF382	1781 549251	DMITRIY CHERNOV	{"email": "chernov-d15101959@postgrespro.ru", "phone": "+70533164954"}
0005433468453	EE2056	3099 365373	EVGENIY POPOV	{"email": "popov_evgeniy.1969@postgrespro.ru", "phone": "+70096511166"}
0005433468454	82D468	7905 560710	LYUDMILA SOLOVEVA	{"phone": "+70567226017"}
0005433468455	F818B5	5246 934840	ALEKSANDR POPOV	{"phone": "+70177913253"}
0005433468456	F818B5	0202 438474	VLADIMIR DMITRIEV	{"email": "v.dmitriev051977@postgrespro.ru", "phone": "+70208534834"}
0005433468457	94468C	1437 621678	DMITRIY FEDOTOV	{"email": "fedotov.d22071980@postgrespro.ru", "phone": "+70878685186"}
0005433468458	3B7A01	5352 495421	PETR ORLOV	{"phone": "+70611764099"}
0005433468459	E6D562	7205 424078	ROMAN VASILEV	{"phone": "+70552054100"}
0005433468460	E6D562	7366 003594	KRISTINA NIKOLAEVA	{"email": "k-nikolaeva04071981@postgrespro.ru", "phone": "+70988678769"}
0005433468461	08B667	3743 886356	VLADIMIR MAKSIMOV	{"email": "vmaksimov.07061976@postgrespro.ru", "phone": "+70954942530"}
0005433468462	EFABE0	2927 650981	GALINA GORBUNOVA	{"phone": "+70916238285"}
0005433468463	ED5845	2519 627472	SVETLANA IVANOVA	{"phone": "+70766666136"}
0005433468464	471865	9140 493735	ALEKSANDR MELNIKOV	{"email": "melnikov-a011971@postgrespro.ru", "phone": "+70611433187"}
0005433468465	471865	7134 996765	STANISLAV DENISOV	{"email": "denisov-s081978@postgrespro.ru", "phone": "+70600142811"}
0005433468466	30F8C9	5680 356471	VLADIMIR YAKOVLEV	{"phone": "+70443881964"}
0005433468467	19863D	7970 942100	RADIK NAUMOV	{"email": "r_naumov-041972@postgrespro.ru", "phone": "+70968322573"}
0005433468468	360BEF	6528 550088	ALEKSEY PETROV	{"email": "petrov_a26121964@postgrespro.ru", "phone": "+70126589392"}
0005433468469	360BEF	6366 980765	GALINA KULIKOVA	{"email": "kulikovagalina.1972@postgrespro.ru", "phone": "+70435639232"}
0005433468470	44D9BB	5389 281199	LEONID IVANOV	{"email": "leonid-ivanov.22061979@postgrespro.ru", "phone": "+70177415341"}
0005433468471	F2695A	4401 975026	ALEKSEY PETROV	{"phone": "+70331511567"}
0005433468472	C42579	4051 656942	YURIY KULIKOV	{"phone": "+70660130744"}
0005433468473	1FB4AF	2845 546508	ELENA PAVLOVA	{"email": "pavlovaelena_021979@postgrespro.ru", "phone": "+70216349380"}
0005433468474	3BAC27	8896 162445	SERGEY KOZLOV	{"phone": "+70355314819"}
0005433468475	C10A77	9169 322214	NIKOLAY MOROZOV	{"phone": "+70685363975"}
0005433468476	C10A77	5179 580536	TATYANA VOLKOVA	{"phone": "+70747695533"}
0005433468477	252C90	4588 917697	ALEKSANDR GAVRILOV	{"email": "gavrilov_a_1968@postgrespro.ru", "phone": "+70089446138"}
0005433468478	D4A951	2423 805717	MIKHAIL MAKSIMOV	{"phone": "+70027890303"}
0005433468479	D4A951	6341 727165	MARIYA KUZMINA	{"phone": "+70475035550"}
0005433468480	B5DDA5	0842 002070	ANDREY KONOVALOV	{"email": "andrey.konovalov091982@postgrespro.ru", "phone": "+70917710348"}
0005433468481	3856AA	5939 503949	TIMUR ABRAMOV	{"email": "abramov_t_1978@postgrespro.ru", "phone": "+70390668512"}
0005433468482	970765	8510 231944	ARTEM ALEKSANDROV	{"email": "aleksandrov-artem29061963@postgrespro.ru", "phone": "+70141620238"}
0005433468483	4A6B38	9886 597666	ALEKSEY KUZNECOV	{"email": "kuznecova-101980@postgrespro.ru", "phone": "+70001181913"}
0005433468484	F5EF87	9338 297148	RAISA VOLKOVA	{"email": "volkovar_111972@postgrespro.ru", "phone": "+70443453816"}
0005433468485	739BCA	5965 665579	IVAN CHERNOV	{"email": "i.chernov_1970@postgrespro.ru", "phone": "+70674146698"}
0005433468486	C2CDBF	8724 245746	YULIYA CHERNOVA	{"email": "y-chernova.1967@postgrespro.ru", "phone": "+70663124140"}
0005433468487	504F49	6924 170242	EVGENIY FEDOTOV	{"email": "evgeniy_fedotov-011964@postgrespro.ru", "phone": "+70151271833"}
0005433468488	AAAF5C	0830 728578	ANNA KOZLOVA	{"phone": "+70131823779"}
0005433468489	60FB06	7978 586014	IRINA ZOTOVA	{"email": "zotova_i_1968@postgrespro.ru", "phone": "+70417929709"}
0005433468490	6425BE	9820 486082	NIKITA NIKITIN	{"email": "nikitinn-011975@postgrespro.ru", "phone": "+70054902116"}
0005433468491	7B5DC6	9746 581496	EVGENIY TARASOV	{"email": "tarasov-evgeniy_03031966@postgrespro.ru", "phone": "+70443301838"}
0005433468492	77A886	2203 196562	KONSTANTIN ANDREEV	{"phone": "+70171248000"}
0005433468493	0135FD	1481 473326	VALENTINA ALEKSEEVA	{"email": "alekseeva.v-101980@postgrespro.ru", "phone": "+70083726060"}
0005433468494	52C7F4	2613 677791	VALENTINA POLYAKOVA	{"email": "valentina_polyakova.08021982@postgrespro.ru", "phone": "+70944508446"}
0005433468495	968D9F	1112 691099	OLEG ANDREEV	{"phone": "+70544195020"}
0005433468496	968D9F	3679 471186	MIKHAIL NIKITIN	{"email": "mikhail.nikitin.1975@postgrespro.ru", "phone": "+70357046505"}
0005433468497	968D9F	8319 149564	TATYANA ANTONOVA	{"phone": "+70418897381"}
0005433468498	FA4605	5105 061245	POLINA MARTYNOVA	{"phone": "+70294850293"}
0005433468499	FA4605	7509 736197	VASILIY KRASNOV	{"email": "v-krasnov_011969@postgrespro.ru", "phone": "+70616005468"}
0005433468500	2D1751	5266 234878	ALEKSANDR GRIGOREV	{"phone": "+70741400218"}
0005433468501	CB1176	0576 553109	DANIS KOZLOV	{"phone": "+70258868331"}
0005433468502	CB1176	8514 914321	EKATERINA ABRAMOVA	{"email": "abramova_ekaterina_091972@postgrespro.ru", "phone": "+70372700608"}
0005433468503	9F40F7	4064 735648	MAKSIM OSIPOV	{"email": "m-osipov.11091965@postgrespro.ru", "phone": "+70951159725"}
0005433468504	87A010	3245 151450	EVGENIY OSIPOV	{"phone": "+70204040762"}
0005433468505	87A010	3148 777812	EKATERINA ANTONOVA	{"email": "ekaterina-antonova.101973@postgrespro.ru", "phone": "+70981886261"}
0005433468506	87A010	2551 645274	TATYANA LEBEDEVA	{"email": "tatyana-lebedeva_1980@postgrespro.ru", "phone": "+70711634791"}
0005433468507	5202DF	6408 791187	VSEVOLOD POPOV	{"phone": "+70137418230"}
0005433468508	5202DF	7223 631227	VIKTOR ALEKSANDROV	{"email": "aleksandrov-v-091959@postgrespro.ru", "phone": "+70917589460"}
0005433468509	5202DF	5122 675171	VLADIMIR SOKOLOV	{"phone": "+70763444091"}
0005433468510	9D0498	7890 835966	LILIYA GORBUNOVA	{"email": "gorbunova.liliya.071979@postgrespro.ru", "phone": "+70084088264"}
0005433468511	9D0498	5905 006417	DMITRIY VASILEV	{"phone": "+70512471448"}
0005433468512	A7E6B7	7735 303415	GAGIK KUZMIN	{"phone": "+70894259146"}
0005433468513	A7E6B7	9836 830342	LYUBOV MAKAROVA	{"email": "makarova.lyubov_111978@postgrespro.ru", "phone": "+70667428209"}
0005433468514	A7E6B7	2807 378546	VALENTINA VASILEVA	{"phone": "+70604376556"}
0005433468515	23D1F8	7926 162783	VLADIMIR ROMANOV	{"email": "v_romanov-071979@postgrespro.ru", "phone": "+70083529759"}
0005433468516	ACC440	4260 394949	OLGA ANTONOVA	{"phone": "+70305632506"}
0005433468517	4CC64E	6524 058836	ANDREY DAVYDOV	{"phone": "+70195410695"}
0005433468518	65C968	1357 807387	KAMIL KRASNOV	{"phone": "+70357019370"}
0005433468519	939EE4	5280 446215	AYRAT IVANOV	{"email": "ivanov-a.21011975@postgrespro.ru", "phone": "+70023334609"}
0005433468520	9BEBCE	9849 770831	VLADIMIR VASILEV	{"phone": "+70139898881"}
0005433468521	9BEBCE	2480 034315	FEDOR AFANASEV	{"email": "fedor-afanasev1984@postgrespro.ru", "phone": "+70066028836"}
0005433468522	061A8F	9084 627777	RUSLAN MEDVEDEV	{"email": "medvedev_r-19101973@postgrespro.ru", "phone": "+70789623124"}
0005433468523	132130	0214 928592	EVGENIY IVANOV	{"email": "ivanove_29081959@postgrespro.ru", "phone": "+70307952779"}
0005433468524	7225FF	3967 975218	SERGEY SEMENOV	{"email": "semenov.sergey_16051979@postgrespro.ru", "phone": "+70877819973"}
0005433468525	7225FF	1503 954370	ALEKSEY AFANASEV	{"email": "afanasev-a-1968@postgrespro.ru", "phone": "+70577561839"}
0005433468526	5750C1	7240 702951	INNA SMIRNOVA	{"phone": "+70024794194"}
0005433468527	DC537D	4230 416546	ANASTASIYA TARASOVA	{"email": "tarasovaa071977@postgrespro.ru", "phone": "+70631433232"}
0005433468528	69AC85	7645 197266	VYACHESLAV PETROV	{"phone": "+70956159033"}
0005433468529	215490	2160 066074	OKSANA POPOVA	{"email": "popova.oksana.011966@postgrespro.ru", "phone": "+70668031321"}
0005433468530	215490	5290 649070	OLGA ZAYCEVA	{"email": "zaycevaolga-02111964@postgrespro.ru", "phone": "+70058286934"}
0005433468531	215490	7427 161664	GALINA KUZNECOVA	{"email": "kuznecova.galina.1970@postgrespro.ru", "phone": "+70942902357"}
0005433468532	215490	1872 935762	PAVEL KAZAKOV	{"phone": "+70403440153"}
0005433468533	9F51C3	1337 190903	ANATOLIY SIDOROV	{"email": "sidorova-031959@postgrespro.ru", "phone": "+70254247390"}
0005433468534	9F51C3	2950 021750	NADEZHDA KOMAROVA	{"phone": "+70662678095"}
0005433468535	7A4AEF	5920 519394	DMITRIY ZAYCEV	{"email": "zaycevdmitriy-1973@postgrespro.ru", "phone": "+70972310034"}
0005433468536	4CA52F	2772 929714	ALEKSANDR DENISOV	{"email": "a_denisov1977@postgrespro.ru", "phone": "+70773766121"}
0005433468537	612BC0	0850 942872	VALERIY VASILEV	{"phone": "+70353464251"}
0005433468538	81A078	9415 493251	VLADIMIR GUSEV	{"phone": "+70592035515"}
0005433468539	81A078	7864 454995	NIKOLAY SAVELEV	{"phone": "+70369469039"}
0005433468540	1F0319	9432 690701	VITALIY MIKHAYLOV	{"phone": "+70605755759"}
0005433468541	13B8FF	3877 786724	MIKHAIL FOMIN	{"phone": "+70840435431"}
0005433468543	E12327	9820 671120	ZHANNA TIKHONOVA	{"phone": "+70726616283"}
0005433468544	E12327	9692 332837	MARAT KUZNECOV	{"email": "maratkuznecov_29081984@postgrespro.ru", "phone": "+70949094825"}
0005433468545	AC65E7	2631 472392	NINA EFIMOVA	{"phone": "+70347715632"}
0005433468546	AC65E7	3515 602451	IRINA VASILEVA	{"email": "vasilevairina1965@postgrespro.ru", "phone": "+70841522513"}
0005433468547	FEF3CE	3600 171391	ALEKSEY SCHERBAKOV	{"email": "ascherbakov-071979@postgrespro.ru", "phone": "+70743795853"}
0005433468548	BCCDCA	1781 408350	TATYANA ERMAKOVA	{"email": "termakova25011961@postgrespro.ru", "phone": "+70057765468"}
0005433468549	08B351	4095 104028	ANDREY TIMOFEEV	{"email": "a.timofeev05011971@postgrespro.ru", "phone": "+70743119106"}
0005433468550	A390F5	0321 828123	ANTON KONOVALOV	{"phone": "+70652233018"}
0005433468551	A390F5	0863 934211	MARINA MOROZOVA	{"email": "morozovam_1974@postgrespro.ru", "phone": "+70241446873"}
0005433468552	A390F5	9773 201801	EKATERINA SERGEEVA	{"email": "sergeeva_ekaterina_05061976@postgrespro.ru", "phone": "+70574886290"}
0005433468553	55751D	1586 732558	SERGEY NAUMOV	{"email": "naumov-sergey.051977@postgrespro.ru", "phone": "+70640768517"}
0005433468554	3887C3	5786 065802	SERGEY DAVYDOV	{"email": "sergey-davydov1969@postgrespro.ru", "phone": "+70417911356"}
0005433468555	3887C3	3918 369675	TATYANA SERGEEVA	{"email": "sergeeva-tatyana_14031987@postgrespro.ru", "phone": "+70351380722"}
0005433468556	CEE663	7156 673291	VALERIY GORBUNOV	{"phone": "+70724013933"}
0005433468557	4351BB	7680 773579	SERGEY OSIPOV	{"phone": "+70634983742"}
0005433468558	F206BB	0567 285732	VLADIMIR ANDREEV	{"email": "andreev_vladimir041969@postgrespro.ru", "phone": "+70035188047"}
0005433468559	E4FE45	4290 888362	LYUDMILA SOROKINA	{"email": "lyudmilasorokina21011981@postgrespro.ru", "phone": "+70472303271"}
0005433468560	E4FE45	4474 318737	ALEKSEY KOROLEV	{"email": "aleksey_korolev-051977@postgrespro.ru", "phone": "+70217745689"}
0005433468561	FDB31D	7929 355022	TATYANA PETROVA	{"email": "tatyana-petrova.1959@postgrespro.ru", "phone": "+70483690797"}
0005433468562	553D21	7266 158083	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir1965@postgrespro.ru", "phone": "+70719714452"}
0005433468563	EE8AFB	8732 920384	VLADIMIR PETROV	{"email": "petrov_v_13081968@postgrespro.ru", "phone": "+70802015556"}
0005433468564	EE8AFB	2658 093522	MAKSIM MOROZOV	{"email": "morozovm05051971@postgrespro.ru", "phone": "+70006223700"}
0005433468565	F6B1A4	8621 179894	MARINA SERGEEVA	{"phone": "+70301303174"}
0005433468566	F6B1A4	8695 486681	TATYANA GAVRILOVA	{"email": "gavrilova_t.041974@postgrespro.ru", "phone": "+70776178083"}
0005433468567	F6B1A4	5992 783563	VALENTINA ROMANOVA	{"phone": "+70355589147"}
0005433468568	9B0654	7436 097757	LILIYA ZHUKOVA	{"email": "zhukova-l.1970@postgrespro.ru", "phone": "+70064292690"}
0005433468569	1F92FD	0984 882412	DMITRIY KAZAKOV	{"phone": "+70436785170"}
0005433468570	1F92FD	1119 878319	ANATOLIY FEDOTOV	{"email": "anatoliy.fedotov_1980@postgrespro.ru", "phone": "+70866482070"}
0005433468571	175446	6251 119248	NIKOLAY BONDARENKO	{"phone": "+70276581631"}
0005433468572	175446	2580 692202	LYUBOV VASILEVA	{"email": "vasileva.l.1971@postgrespro.ru", "phone": "+70673493653"}
0005433468573	8E9D17	1401 612278	ANGELINA MIRONOVA	{"phone": "+70499874084"}
0005433468574	8E9D17	3000 359928	RIMMA DANILOVA	{"phone": "+70920080656"}
0005433468575	5F4FA0	5267 031847	IVAN VOLKOV	{"phone": "+70933341211"}
0005433468576	5F4FA0	7659 380355	KIRILL TARASOV	{"phone": "+70313718085"}
0005433468577	41EE0D	4885 489060	TIMUR SEMENOV	{"email": "semenovtimur.1980@postgrespro.ru", "phone": "+70060839621"}
0005433468578	41EE0D	7976 616598	ARTUR SMIRNOV	{"email": "smirnov-a_1975@postgrespro.ru", "phone": "+70095929449"}
0005433468579	B42F99	7829 954090	ANDREY MOROZOV	{"phone": "+70466431284"}
0005433468580	849E27	3675 509688	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev.1980@postgrespro.ru", "phone": "+70789687875"}
0005433468581	B555EE	7314 315283	YURIY MEDVEDEV	{"phone": "+70611729733"}
0005433468582	64D123	6103 815578	VIKTOR KUZMIN	{"phone": "+70974621306"}
0005433468583	4E5EB1	0525 593937	DMITRIY AFANASEV	{"email": "afanasev.dmitriy.1972@postgrespro.ru", "phone": "+70362513294"}
0005433468584	4E5EB1	0725 627075	TATYANA IVANOVA	{"email": "ivanova-tatyana_1976@postgrespro.ru", "phone": "+70033258095"}
0005433468585	8F18FD	8198 871732	VYACHESLAV SERGEEV	{"email": "sergeevv.1960@postgrespro.ru", "phone": "+70816762096"}
0005433468586	0031D2	9981 692409	NIKOLAY SMIRNOV	{"phone": "+70616750677"}
0005433468587	70205F	7730 920781	VADIM ZAKHAROV	{"phone": "+70326714603"}
0005433468588	70205F	0936 541593	ALEKSANDR MIKHAYLOV	{"phone": "+70559467247"}
0005433468589	1824B2	4992 809346	YURIY PAVLOV	{"email": "pavlov.y.121970@postgrespro.ru", "phone": "+70504853441"}
0005433468590	1824B2	0510 305978	LEONID PETROV	{"email": "petrov-l121980@postgrespro.ru", "phone": "+70697461780"}
0005433468591	1824B2	5244 895959	NIKOLAY SOLOVEV	{"phone": "+70391485867"}
0005433468592	4F1FF2	4865 061013	ALEKSEY DMITRIEV	{"phone": "+70176587632"}
0005433468593	688342	4925 923083	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr.31121970@postgrespro.ru", "phone": "+70525214640"}
0005433468594	F19A8B	7306 276575	FEDOR NAZAROV	{"phone": "+70657494872"}
0005433468595	D2623B	6209 124764	GALINA TARASOVA	{"email": "tarasovag1980@postgrespro.ru", "phone": "+70468448500"}
0005433468596	4A6D5D	5216 784370	VLADIMIR SEMENOV	{"email": "vladimir-semenov_121965@postgrespro.ru", "phone": "+70054497686"}
0005433468597	39F718	9863 462904	IGOR TARASOV	{"email": "igor.tarasov05091974@postgrespro.ru", "phone": "+70548918424"}
0005433468598	B1DAAE	5220 813272	VIKTORIYA DENISOVA	{"phone": "+70909359692"}
0005433468599	FC20DA	8181 777803	ANTON MOROZOV	{"phone": "+70098428859"}
0005433468600	589C5F	2501 994923	EVGENIYA KOZLOVA	{"email": "e.kozlova.041971@postgrespro.ru", "phone": "+70037493856"}
0005433468601	AA54A9	9012 712790	YURIY EGOROV	{"phone": "+70861886459"}
0005433468602	AA54A9	0465 964146	ANATOLIY EGOROV	{"email": "egorov-a_021965@postgrespro.ru", "phone": "+70961501534"}
0005433468603	B5E805	1366 965439	ANATOLIY YAKOVLEV	{"email": "yakovleva23071975@postgrespro.ru", "phone": "+70952993526"}
0005433468604	392F69	8111 118450	MARIYA MASLOVA	{"email": "maslova.mariya051977@postgrespro.ru", "phone": "+70982895425"}
0005433468605	392F69	7898 272444	ZINAIDA VOLKOVA	{"email": "volkova_z_20121967@postgrespro.ru", "phone": "+70091433836"}
0005433468606	67752A	4499 325100	ELENA GRISHINA	{"email": "grishina_e1973@postgrespro.ru", "phone": "+70519110390"}
0005433468607	E2F636	1039 092786	DMITRIY ZAKHAROV	{"phone": "+70963987286"}
0005433468608	90D81D	9739 823862	NIKOLAY ZAYCEV	{"email": "zaycev.nikolay_1977@postgrespro.ru", "phone": "+70495752316"}
0005433473100	EC7F7F	8443 526173	ANATOLIY KUZNECOV	{"phone": "+70972589299"}
0005433473101	674FCF	4367 758273	VITALIY SIDOROV	{"email": "vsidorov.1961@postgrespro.ru", "phone": "+70657980181"}
0005433473102	674FCF	8842 666893	RAISA PETROVA	{"phone": "+70401373607"}
0005433473103	52036F	8667 135118	OKSANA FOMINA	{"email": "o_fomina.05061965@postgrespro.ru", "phone": "+70339041836"}
0005433473104	446A4A	1717 046057	NADEZHDA IVANOVA	{"email": "ivanova-n_1971@postgrespro.ru", "phone": "+70046004443"}
0005433473105	14F08E	4241 649495	SERGEY GORBUNOV	{"email": "gorbunov_s-23041969@postgrespro.ru", "phone": "+70527417932"}
0005433473106	5AF589	0046 584040	VERA KUZNECOVA	{"email": "v-kuznecova071986@postgrespro.ru", "phone": "+70784726588"}
0005433473107	AE00A9	7318 103917	EKATERINA IVANOVA	{"phone": "+70670232085"}
0005433473108	AE00A9	9884 177176	NATALYA OVCHINNIKOVA	{"email": "n_ovchinnikova-16021971@postgrespro.ru", "phone": "+70991287361"}
0005433473109	AF7221	1051 896028	TATYANA IVANOVA	{"email": "ivanova_t.011970@postgrespro.ru", "phone": "+70508526656"}
0005433473110	435EDE	6114 058471	VYACHESLAV CHERNOV	{"phone": "+70072929624"}
0005433473111	435EDE	3678 045111	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana_1962@postgrespro.ru", "phone": "+70973964638"}
0005433473112	F9257F	0686 697669	TATYANA VOROBEVA	{"email": "tatyanavorobeva.081959@postgrespro.ru", "phone": "+70700005471"}
0005433473113	F9257F	5435 156904	VIKTOR MEDVEDEV	{"email": "medvedevviktor_1972@postgrespro.ru", "phone": "+70784746812"}
0005433473114	F9257F	6429 990343	EVGENIY STEPANOV	{"email": "e_stepanov29031974@postgrespro.ru", "phone": "+70922406780"}
0005433473115	0FD9DD	3098 092220	ZHANNA TIMOFEEVA	{"phone": "+70575989348"}
0005433473116	EBE52D	2176 962941	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov1960@postgrespro.ru", "phone": "+70323389899"}
0005433473117	3CBDBA	9987 786439	EKATERINA FEDOROVA	{"phone": "+70684053672"}
0005433473118	E0F659	6134 192689	NINA ILINA	{"email": "ilina-n_051968@postgrespro.ru", "phone": "+70562863279"}
0005433473119	E0F659	4676 718841	TATYANA KOROLEVA	{"phone": "+70637324967"}
0005433473120	586A6E	5528 155371	BORIS SAVELEV	{"phone": "+70092530336"}
0005433473121	586A6E	2067 388040	IVAN SIDOROV	{"email": "sidorov.ivan-1981@postgrespro.ru", "phone": "+70419026531"}
0005433473122	586A6E	4895 994732	IVAN KUZNECOV	{"email": "ivan_kuznecov-041955@postgrespro.ru", "phone": "+70836775389"}
0005433473123	48F547	8284 942190	KHALIDA MAKSIMOVA	{"phone": "+70952078339"}
0005433473124	48F547	6365 085606	NATALYA MAKAROVA	{"email": "makarovanatalya_1981@postgrespro.ru", "phone": "+70341252869"}
0005433473125	782C2B	6878 318116	ROSTISLAV BORISOV	{"phone": "+70264957439"}
0005433473126	A0C143	7763 292354	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr.101963@postgrespro.ru", "phone": "+70055380652"}
0005433473127	A0C143	4992 199506	ARTEM KUZNECOV	{"email": "kuznecova.29071967@postgrespro.ru", "phone": "+70568620610"}
0005433473128	205C2C	9233 817492	VASILIY FROLOV	{"phone": "+70470506458"}
0005433473129	906584	5407 850372	TAMARA ORLOVA	{"phone": "+70909224992"}
0005433473130	028FBB	3704 930319	PAVEL SIDOROV	{"email": "sidorov-pavel_1973@postgrespro.ru", "phone": "+70146479051"}
0005433473131	90E982	8701 060072	GALINA SOROKINA	{"email": "gsorokina031971@postgrespro.ru", "phone": "+70031992181"}
0005433473132	1D13AE	0371 054130	LYUDMILA GUSEVA	{"email": "l_guseva031985@postgrespro.ru", "phone": "+70687224182"}
0005433473133	E5254C	1984 926683	VIKTORIYA IVANOVA	{"phone": "+70052450173"}
0005433473134	E5254C	9157 258182	ANGELINA SEMENOVA	{"email": "semenovaangelina1973@postgrespro.ru", "phone": "+70099610398"}
0005433473135	F178B9	8918 572138	LYUDMILA BELOVA	{"email": "belova_lyudmila.11111973@postgrespro.ru", "phone": "+70104494663"}
0005433473136	318C74	8005 370125	YURIY VASILEV	{"email": "vasilev.y07041978@postgrespro.ru", "phone": "+70455753192"}
0005433473137	318C74	4985 337908	VLADISLAV MOISEEV	{"phone": "+70442773195"}
0005433473138	99B2C8	0834 683845	ALEVTINA GAVRILOVA	{"phone": "+70032794063"}
0005433473139	BDB6A5	1834 948263	VALENTINA TARASOVA	{"email": "tarasovavalentina.1975@postgrespro.ru", "phone": "+70170580645"}
0005433473140	BDB6A5	1258 498999	SVETLANA PETROVA	{"email": "s.petrova1976@postgrespro.ru", "phone": "+70028574326"}
0005433473141	F2B92D	2323 046323	LIDIYA NESTEROVA	{"phone": "+70864806669"}
0005433473142	F2B92D	9189 213991	NELLI KOROLEVA	{"email": "koroleva-n-18031967@postgrespro.ru", "phone": "+70042293106"}
0005433473143	F2B92D	1888 538773	YURIY PETROV	{"email": "yuriy_petrov13121979@postgrespro.ru", "phone": "+70368372310"}
0005433473144	772D8C	5035 838972	MAKSIM GORBUNOV	{"email": "gorbunov-maksim-1969@postgrespro.ru", "phone": "+70912725261"}
0005433473145	19C87B	0585 313930	MARINA DANILOVA	{"email": "m.danilova_1966@postgrespro.ru", "phone": "+70126940347"}
0005433473146	E1FE38	1246 121814	MARINA PAVLOVA	{"email": "pavlova-marina.22051971@postgrespro.ru", "phone": "+70612524401"}
0005433473147	E1FE38	6820 350733	VERA IVANOVA	{"phone": "+70294144844"}
0005433473148	ADC24E	1128 122478	ALEKSANDR FEDOROV	{"phone": "+70795751302"}
0005433473149	CA47BC	5453 055167	DENIS KRASNOV	{"phone": "+70729728688"}
0005433473150	1B362D	7887 878402	VALENTINA VASILEVA	{"phone": "+70764505204"}
0005433473151	18FDE4	5704 819315	PAVEL NIKITIN	{"email": "nikitin-p_101963@postgrespro.ru", "phone": "+70071974581"}
0005433473152	8ED352	9038 004348	GALINA KUZMINA	{"email": "g_kuzmina-1975@postgrespro.ru", "phone": "+70589222749"}
0005433473153	A1D9B0	7538 320512	VIKTORIYA SIDOROVA	{"phone": "+70752918517"}
0005433473154	E8B1C8	0673 247949	ALEKSANDR KOROLEV	{"phone": "+70248755299"}
0005433473155	AB1D49	8177 085392	IVAN SMIRNOV	{"phone": "+70876852636"}
0005433473156	3E9558	2814 856317	ALEKSANDR SOKOLOV	{"phone": "+70118689725"}
0005433473157	457B2A	0237 494853	KRISTINA NAUMOVA	{"email": "kristinanaumova-031986@postgrespro.ru", "phone": "+70423804731"}
0005433473158	457B2A	4931 673740	KRISTINA POLYAKOVA	{"email": "polyakova_kristina-021972@postgrespro.ru", "phone": "+70677086200"}
0005433473159	B037DD	2596 010985	EVGENIY PETROV	{"email": "petrov_e_07031971@postgrespro.ru", "phone": "+70989697651"}
0005433473160	B037DD	7103 352561	ALEKSANDR KUDRYASHOV	{"phone": "+70856707008"}
0005433473161	F682B8	3394 615608	NATALYA SOKOLOVA	{"email": "natalya_sokolova.101974@postgrespro.ru", "phone": "+70770515148"}
0005433473162	38675C	7651 625029	OLGA PETROVA	{"phone": "+70883885330"}
0005433473163	F9215D	1711 528440	NINA ZAKHAROVA	{"phone": "+70397846106"}
0005433473164	F9215D	5234 766664	VALENTIN KUZNECOV	{"email": "valentin_kuznecov.1973@postgrespro.ru", "phone": "+70203263443"}
0005433473165	36CE1D	2967 448715	OLGA NIKOLAEVA	{"phone": "+70396071758"}
0005433473166	B94530	2393 507263	IRINA NIKIFOROVA	{"email": "nikiforova-i_011966@postgrespro.ru", "phone": "+70185987752"}
0005433473167	B94530	8617 290154	ANASTASIYA MELNIKOVA	{"phone": "+70840053543"}
0005433473168	EA67E2	6614 061781	EVGENIYA GORBUNOVA	{"phone": "+70557852803"}
0005433473169	3DEC96	4143 484961	NINA PAVLOVA	{"phone": "+70738966731"}
0005433473170	3DEC96	9070 607676	NATALYA PETROVA	{"phone": "+70479077075"}
0005433473171	F091F9	0877 335919	MARIYA GERASIMOVA	{"phone": "+70671356206"}
0005433473172	C38C56	6543 429471	VALERIY VASILEV	{"phone": "+70377094325"}
0005433473173	076427	4556 088267	YULIYA RODIONOVA	{"phone": "+70972465637"}
0005433473174	7F8A92	4737 512786	ELIZAVETA DAVYDOVA	{"email": "davydova-e.051975@postgrespro.ru", "phone": "+70503698024"}
0005433473175	7B78D9	6807 318834	OLGA FOMINA	{"phone": "+70953367619"}
0005433473176	7B78D9	7701 635767	ANATOLIY DAVYDOV	{"phone": "+70464213399"}
0005433473177	318640	6424 272729	ALEKSEY BORISOV	{"phone": "+70903582944"}
0005433473178	318640	3305 400890	KRISTINA KOMAROVA	{"email": "komarovakristina_1980@postgrespro.ru", "phone": "+70688193937"}
0005433473179	BCDDFB	7421 265355	POLINA KONDRATEVA	{"email": "pkondrateva25031975@postgrespro.ru", "phone": "+70601114603"}
0005433473180	003743	2039 494729	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_24111976@postgrespro.ru", "phone": "+70743027260"}
0005433473181	003743	7295 456977	SVETLANA DMITRIEVA	{"email": "dmitrieva_s-071977@postgrespro.ru", "phone": "+70444586734"}
0005433473182	A10932	7757 643011	VASILIY MELNIKOV	{"phone": "+70430103358"}
0005433473183	2A42E6	4624 644039	GALINA SOKOLOVA	{"email": "sokolova-galina-011966@postgrespro.ru", "phone": "+70313223326"}
0005433473184	2A42E6	2058 807688	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.30031974@postgrespro.ru", "phone": "+70334406894"}
0005433473185	B138B8	3848 439555	VASILIY ANDREEV	{"email": "andreev_v-031978@postgrespro.ru", "phone": "+70897679993"}
0005433473186	5D9935	2379 375144	ANDREY BORISOV	{"phone": "+70857936133"}
0005433473187	5D9935	2507 349130	NADEZHDA ILINA	{"phone": "+70536624654"}
0005433473188	4A7C6D	5548 945356	EVGENIY SOLOVEV	{"email": "evgeniysolovev_31081960@postgrespro.ru", "phone": "+70419553276"}
0005433473189	4A7C6D	2463 703262	VIKTORIYA NIKOLAEVA	{"email": "v_nikolaeva-09111975@postgrespro.ru", "phone": "+70255815585"}
0005433473190	E5FA1B	7589 350624	MARINA NIKOLAEVA	{"phone": "+70028953680"}
0005433473191	E5FA1B	1660 462524	NADEZHDA KUZNECOVA	{"email": "n_kuznecova_021976@postgrespro.ru", "phone": "+70645930309"}
0005433473192	E5FA1B	4479 070557	NADEZHDA YUDINA	{"phone": "+70007361946"}
0005433473193	456346	6999 622081	ILNUR NAZAROV	{"phone": "+70266974271"}
0005433473194	619D6B	4405 136472	SERGEY ANDREEV	{"email": "andreev.s10021971@postgrespro.ru", "phone": "+70585667682"}
0005433473195	619D6B	6847 864771	DENIS MIKHAYLOV	{"phone": "+70895236660"}
0005433473196	619D6B	0249 124291	OLGA SMIRNOVA	{"email": "olgasmirnova-03061966@postgrespro.ru", "phone": "+70384825782"}
0005433473197	210741	2931 383413	ALEVTINA VOLKOVA	{"email": "alevtinavolkova.081963@postgrespro.ru", "phone": "+70568819621"}
0005433473198	FF9965	0092 520282	IGOR PAVLOV	{"phone": "+70671804397"}
0005433473199	E116A0	9588 575594	NAIL ROMANOV	{"phone": "+70433308926"}
0005433473200	1E9773	9086 009005	VALERIY BELOV	{"phone": "+70486505092"}
0005433473201	EFC919	5116 558170	ALEKSEY FILIPPOV	{"email": "aleksey-filippov_03091972@postgrespro.ru", "phone": "+70543866303"}
0005433473202	B6BD5E	6706 710458	VLADIMIR FOMIN	{"phone": "+70052486166"}
0005433473203	37FB31	6772 005126	ALEKSEY ZHURAVLEV	{"email": "zhuravlevaleksey.061973@postgrespro.ru", "phone": "+70610300360"}
0005433473204	4826AB	5161 450596	ULYANA POTAPOVA	{"email": "ulyana.potapova061966@postgrespro.ru", "phone": "+70766023624"}
0005433473205	5BF4F1	7844 418083	ALEKSEY NIKOLAEV	{"email": "nikolaev_a.1963@postgrespro.ru", "phone": "+70743259798"}
0005433473206	F5FE0A	5938 256406	ANATOLIY IVANOV	{"phone": "+70741538091"}
0005433473207	D89B14	6894 469035	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova.1977@postgrespro.ru", "phone": "+70141477094"}
0005433473208	EB0850	6439 099531	EKATERINA YUDINA	{"phone": "+70846545252"}
0005433473209	EBD684	7923 658375	ALEKSANDRA KULIKOVA	{"email": "aleksandra.kulikova.071964@postgrespro.ru", "phone": "+70707030128"}
0005433473210	697973	7726 358564	SVETLANA ISAEVA	{"phone": "+70307916416"}
0005433473211	FE4A19	9034 194604	ALEKSEY FROLOV	{"email": "frolovaleksey121980@postgrespro.ru", "phone": "+70790599556"}
0005433473212	ABBCE8	0414 179473	VITALIY PETROV	{"phone": "+70924475250"}
0005433473213	577284	8490 297052	DANILA VASILEV	{"phone": "+70565130815"}
0005433473214	70D3BE	2741 457073	YULIYA VLASOVA	{"phone": "+70029949643"}
0005433473215	799A71	9118 139455	ANAIT DMITRIEVA	{"email": "anait_dmitrieva.071964@postgrespro.ru", "phone": "+70099297535"}
0005433473216	799A71	1662 215863	DENIS KOZLOV	{"email": "kozlov_d.21091972@postgrespro.ru", "phone": "+70925100648"}
0005433473217	799A71	0613 730275	ALEKSEY KUZNECOV	{"email": "alekseykuznecov.031986@postgrespro.ru", "phone": "+70626052142"}
0005433473218	6C4380	8656 007978	MARTA KOROLEVA	{"phone": "+70849330705"}
0005433473219	A754D6	6018 021355	ANATOLIY KOZLOV	{"email": "a-kozlov_18051958@postgrespro.ru", "phone": "+70336297836"}
0005433473220	1AE703	2568 535244	NIKITA MEDVEDEV	{"phone": "+70473798107"}
0005433473221	73F73E	5541 105225	EKATERINA VOROBEVA	{"phone": "+70468828266"}
0005433473222	D51B51	0990 164864	ALEKSANDR BELOV	{"email": "belovaleksandr-1967@postgrespro.ru", "phone": "+70234577225"}
0005433473223	D51B51	5553 039380	LYUDMILA NESTEROVA	{"email": "nesterova_lyudmila121972@postgrespro.ru", "phone": "+70721636543"}
0005433473224	D51B51	2182 601848	SVETLANA ANDREEVA	{"phone": "+70509579714"}
0005433473225	E3BF0C	8886 165226	ANATOLIY GAVRILOV	{"email": "gavrilov_anatoliy-08011978@postgrespro.ru", "phone": "+70826976019"}
0005433473226	AE69CF	1085 644269	ALIYA VOROBEVA	{"email": "aliya.vorobeva-1972@postgrespro.ru", "phone": "+70880893370"}
0005433473227	AE69CF	0515 473253	VIKTOR PETROV	{"email": "vpetrov_1971@postgrespro.ru", "phone": "+70224016236"}
0005433473228	AE69CF	4302 014504	ALEKSEY TIKHONOV	{"phone": "+70905948358"}
0005433473229	6D52F8	9765 398570	MARINA SMIRNOVA	{"email": "marinasmirnova.1960@postgrespro.ru", "phone": "+70992155744"}
0005433473230	CCD08D	7002 918174	VALERIY EGOROV	{"phone": "+70327100185"}
0005433473231	6AEEAE	4840 863024	NATALYA ALEKSANDROVA	{"email": "aleksandrova-natalya021968@postgrespro.ru", "phone": "+70370662075"}
0005433473232	33608E	2734 696441	INNA IVANOVA	{"phone": "+70081553956"}
0005433473233	08C91E	0952 537472	NATALYA KUZNECOVA	{"email": "nkuznecova_121962@postgrespro.ru", "phone": "+70374827344"}
0005433473234	08C91E	9496 023883	MAKSIM GORBUNOV	{"phone": "+70892294254"}
0005433473235	08C91E	8242 227869	ANTONINA SEMENOVA	{"email": "a.semenova.1987@postgrespro.ru", "phone": "+70992889005"}
0005433473236	3EFAB5	2543 411326	OLGA PETROVA	{"phone": "+70124757918"}
0005433473237	E406DE	5297 310330	NATALYA MATVEEVA	{"phone": "+70502661300"}
0005433473238	F81CAC	7543 230149	ELENA PETROVA	{"phone": "+70094152096"}
0005433473239	EB76E4	5512 972743	VERA LUKYANOVA	{"phone": "+70595536738"}
0005433473240	EB76E4	5693 321274	BORIS NIKOLAEV	{"phone": "+70183603312"}
0005433473241	C7FA6C	9383 454687	SERGEY IVANOV	{"email": "ivanov.sergey-09091971@postgrespro.ru", "phone": "+70160934904"}
0005433473242	F1F60D	7784 396206	YULIYA SIDOROVA	{"phone": "+70512148817"}
0005433473243	C68F35	1222 461456	BORIS POPOV	{"email": "popov.boris061970@postgrespro.ru", "phone": "+70525433749"}
0005433473244	E91881	7265 987769	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir.16091971@postgrespro.ru", "phone": "+70831184881"}
0005433473245	E91881	2335 513129	SVETLANA ROMANOVA	{"email": "svetlana_romanova-1981@postgrespro.ru", "phone": "+70392290603"}
0005433473246	EB5AF8	0150 436064	MARAT PETROV	{"email": "maratpetrov-051978@postgrespro.ru", "phone": "+70709040059"}
0005433473247	EB5AF8	1908 298274	NATALYA KUZNECOVA	{"email": "kuznecova.natalya1974@postgrespro.ru", "phone": "+70061808535"}
0005433473248	763421	5746 101715	LYUDMILA STEPANOVA	{"email": "lstepanova.091983@postgrespro.ru", "phone": "+70082804585"}
0005433473249	763421	1400 251809	MARIYA KUZNECOVA	{"email": "kuznecova.m_1966@postgrespro.ru", "phone": "+70066588666"}
0005433473250	962489	6512 955801	ELENA NESTEROVA	{"email": "nesterovae1966@postgrespro.ru", "phone": "+70346466037"}
0005433473251	231F4C	6194 343510	ANDREY KOZLOV	{"email": "a_kozlov_031968@postgrespro.ru", "phone": "+70215130866"}
0005433473252	231F4C	0602 063696	VALENTINA KAZAKOVA	{"email": "kazakova-v1973@postgrespro.ru", "phone": "+70410984727"}
0005433473253	231F4C	2626 818166	ALEKSEY POPOV	{"phone": "+70413175648"}
0005433473254	634541	8640 261621	YURIY EGOROV	{"email": "egorovyuriy.1979@postgrespro.ru", "phone": "+70195615089"}
0005433473255	16AF7B	1092 928015	ALEKSEY VASILEV	{"phone": "+70100379989"}
0005433473256	16AF7B	0757 852809	TAMARA LEBEDEVA	{"email": "tlebedeva.26031971@postgrespro.ru", "phone": "+70598430884"}
0005433473257	C8EB14	1423 585715	EDUARD TIMOFEEV	{"phone": "+70549203370"}
0005433473258	C8EB14	2840 333660	ALEKSEY KUDRYASHOV	{"phone": "+70120803866"}
0005433473259	C8EB14	0303 024641	ANDREY SOKOLOV	{"email": "sokolov-andrey_24041981@postgrespro.ru", "phone": "+70215133830"}
0005433473260	CDEF0A	7947 396031	NIKOLAY NIKITIN	{"email": "nikolaynikitin.031970@postgrespro.ru", "phone": "+70687625208"}
0005433473261	8FA29E	3078 784296	VALENTINA KOZLOVA	{"email": "valentina-kozlova.081969@postgrespro.ru", "phone": "+70759456670"}
0005433473262	8FA29E	2851 249396	SVETLANA MAKAROVA	{"email": "makarovas_081967@postgrespro.ru", "phone": "+70794940286"}
0005433473263	CE9C7B	4541 623000	VALERIY SMIRNOV	{"email": "valeriy_smirnov_101982@postgrespro.ru", "phone": "+70656831947"}
0005433473264	2A8B20	4338 048627	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir_081977@postgrespro.ru", "phone": "+70765421539"}
0005433473265	4CA0CF	7371 546409	ALEKSANDRA RYABOVA	{"phone": "+70099117328"}
0005433473266	E396E4	5430 521400	VLADIMIR KRASNOV	{"phone": "+70644439364"}
0005433473267	E396E4	1852 091024	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov-011979@postgrespro.ru", "phone": "+70526419170"}
0005433473268	196237	9035 328512	NIKITA NIKOLAEV	{"email": "n-nikolaev12091967@postgrespro.ru", "phone": "+70345969148"}
0005433473269	196237	7907 300611	ALEKSEY MEDVEDEV	{"email": "a.medvedev26011959@postgrespro.ru", "phone": "+70112144920"}
0005433473270	85450D	2266 970042	IRINA FEDOROVA	{"phone": "+70060129956"}
0005433473271	DE491D	1571 595916	MARINA POPOVA	{"phone": "+70813078910"}
0005433473272	063F7A	5753 111172	ANNA NOVIKOVA	{"email": "anovikova-071971@postgrespro.ru", "phone": "+70004709029"}
0005433473273	063F7A	4716 064388	GALINA SERGEEVA	{"phone": "+70755624409"}
0005433473274	6B977D	8059 749179	NATALYA MEDVEDEVA	{"phone": "+70127906867"}
0005433473275	6B977D	9459 822044	DMITRIY KULIKOV	{"phone": "+70335843353"}
0005433473276	38D786	4830 053043	GENNADIY KUZNECOV	{"phone": "+70589692872"}
0005433473277	A0B420	4666 424108	SVETLANA MARTYNOVA	{"email": "s_martynova_19091970@postgrespro.ru", "phone": "+70094851506"}
0005433473278	9CF9C7	7378 670811	OLGA GRISHINA	{"email": "grishinao_061967@postgrespro.ru", "phone": "+70707480982"}
0005433473279	4B306F	9862 845389	ZARINA ANTONOVA	{"email": "antonova_zarina1976@postgrespro.ru", "phone": "+70371118283"}
0005433473280	2602B6	2196 686806	MIKHAIL MELNIKOV	{"email": "melnikov-m-021980@postgrespro.ru", "phone": "+70941612086"}
0005433473281	013B66	6704 687559	ANNA MELNIKOVA	{"phone": "+70709089625"}
0005433473282	EE72FC	8089 016972	YURIY ISAEV	{"email": "isaev_y1974@postgrespro.ru", "phone": "+70224578011"}
0005433473283	EE72FC	3818 719925	NADEZHDA ZAKHAROVA	{"phone": "+70517886175"}
0005433473284	1B688A	1739 646942	GALINA ZOTOVA	{"email": "galinazotova_21041963@postgrespro.ru", "phone": "+70988174081"}
0005433473285	2AE78F	8797 637487	VLADIMIR KUZNECOV	{"phone": "+70506689541"}
0005433473286	2AE78F	2983 451483	BORIS PETROV	{"email": "petrov.b051983@postgrespro.ru", "phone": "+70220376891"}
0005433473287	16FE17	4963 694867	EVGENIY KARPOV	{"phone": "+70842119655"}
0005433473288	BB99A6	9965 660127	VYACHESLAV VASILEV	{"email": "vasilev-v.021965@postgrespro.ru", "phone": "+70750200835"}
0005433473289	BB99A6	6421 784466	DIANA SEMENOVA	{"email": "d-semenova-1979@postgrespro.ru", "phone": "+70571482660"}
0005433473290	4A1436	2486 693077	YULIYA KONOVALOVA	{"phone": "+70805119020"}
0005433473291	4A1436	6468 780244	TATYANA SEMENOVA	{"phone": "+70741602187"}
0005433473292	AEDBFE	8918 103239	SOFYA KUDRYASHOVA	{"phone": "+70034275574"}
0005433473293	AEDBFE	9372 051217	ALEKSEY VOROBEV	{"email": "a-vorobev_021971@postgrespro.ru", "phone": "+70389683559"}
0005433473294	10B873	9486 532028	NATALYA PAVLOVA	{"phone": "+70391785407"}
0005433473295	26508E	1445 665577	MARINA KUZMINA	{"phone": "+70796875080"}
0005433473296	522059	6228 153556	MARINA ANISIMOVA	{"email": "marina-anisimova_021984@postgrespro.ru", "phone": "+70762915243"}
0005433473297	F29B06	9897 987131	SERGEY STEPANOV	{"phone": "+70271982445"}
0005433473298	F29B06	2247 137766	ALEKSEY BELOV	{"phone": "+70848080641"}
0005433473299	ED08F5	9784 563900	DIANA SERGEEVA	{"phone": "+70245734070"}
0005433473300	371B34	6821 316914	ELENA ROMANOVA	{"email": "elena_romanova.071973@postgrespro.ru", "phone": "+70328860959"}
0005433473301	0FCDE8	5102 235267	MARINA GAVRILOVA	{"email": "marina.gavrilova_101974@postgrespro.ru", "phone": "+70917110147"}
0005433473302	0FCDE8	1766 836129	VALENTINA VLASOVA	{"email": "valentinavlasova.011967@postgrespro.ru", "phone": "+70150626965"}
0005433473303	9A4222	5395 992642	ANNA EGOROVA	{"phone": "+70484425866"}
0005433473304	9A4222	6982 655960	SVETLANA GERASIMOVA	{"phone": "+70193067846"}
0005433473305	B83E38	8737 789079	VYACHESLAV VASILEV	{"email": "vasilev.v01031964@postgrespro.ru", "phone": "+70292799618"}
0005433473306	B83E38	8695 492607	VERONIKA STEPANOVA	{"email": "stepanova_veronika.1966@postgrespro.ru", "phone": "+70183824874"}
0005433473307	FEB228	5575 842735	KRISTINA ISAEVA	{"email": "kisaeva_1968@postgrespro.ru", "phone": "+70964334972"}
0005433473308	B1FA7A	1646 389367	VASILIY SMIRNOV	{"email": "vasiliy_smirnov04081978@postgrespro.ru", "phone": "+70301379717"}
0005433473309	0D668A	2852 490094	DENIS DENISOV	{"phone": "+70268155638"}
0005433473310	2CDD14	8140 519616	DMITRIY ILIN	{"email": "d.ilin-111951@postgrespro.ru", "phone": "+70591992531"}
0005433473311	2CDD14	1699 204265	VASILIY KUZMIN	{"email": "vkuzmin.1972@postgrespro.ru", "phone": "+70372485978"}
0005433473312	F0ABA3	2251 433976	ELENA ERMAKOVA	{"phone": "+70614787728"}
0005433473313	F0ABA3	0909 084287	ALEKSANDR VOLKOV	{"email": "volkova-031978@postgrespro.ru", "phone": "+70836191708"}
0005433473314	51C3B1	6410 416791	SVETLANA KONDRATEVA	{"email": "kondrateva_s-1965@postgrespro.ru", "phone": "+70937476910"}
0005433473315	E32109	4517 897126	AIDA KISELEVA	{"phone": "+70100978226"}
0005433473316	E32109	3197 910157	TATYANA SOKOLOVA	{"phone": "+70880085592"}
0005433473317	A7838A	6701 187397	VLADIMIR MOROZOV	{"email": "vmorozov-1967@postgrespro.ru", "phone": "+70620203711"}
0005433473318	A7838A	0196 578092	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir.08031974@postgrespro.ru", "phone": "+70989643110"}
0005433473319	D6E0CA	7497 443494	SVETLANA MELNIKOVA	{"email": "melnikova.svetlana.1984@postgrespro.ru", "phone": "+70133817065"}
0005433473320	019B73	4500 789732	ARTEM MAKAROV	{"email": "artemmakarov_1963@postgrespro.ru", "phone": "+70932574229"}
0005433473321	9C67A8	4120 121186	ALEKSEY TIMOFEEV	{"phone": "+70378521818"}
0005433473322	736CB0	5604 521495	GENNADIY ILIN	{"email": "gennadiy-ilin-04041970@postgrespro.ru", "phone": "+70641923969"}
0005433473323	736CB0	6774 981902	OLEG IVANOV	{"email": "ivanov-o.121983@postgrespro.ru", "phone": "+70951487293"}
0005433473324	4BC19E	2905 421515	ALEKSANDR ORLOV	{"phone": "+70865957468"}
0005433473325	6D2213	7068 040995	MARINA FOMINA	{"email": "fominamarina1965@postgrespro.ru", "phone": "+70408095419"}
0005433473326	64545E	5793 296434	NINA BORISOVA	{"phone": "+70756480020"}
0005433473327	64545E	8184 396027	TATYANA ZAYCEVA	{"email": "zaycevat_021975@postgrespro.ru", "phone": "+70303872757"}
0005433473328	64545E	7601 180649	ALEKSANDR PETROV	{"email": "petrov.aleksandr_15081960@postgrespro.ru", "phone": "+70818000249"}
0005433473329	6DBC6A	0738 790013	SVETLANA ROMANOVA	{"email": "svetlanaromanova.1968@postgrespro.ru", "phone": "+70979988913"}
0005433473330	6DBC6A	7993 000895	ELENA IVANOVA	{"email": "elena-ivanova.091970@postgrespro.ru", "phone": "+70246946239"}
0005433473331	B38830	2034 553463	ELENA KAZAKOVA	{"email": "kazakova_elena-23081974@postgrespro.ru", "phone": "+70159829068"}
0005433473332	3D7922	9566 539231	DENIS IVANOV	{"email": "ivanov_d061965@postgrespro.ru", "phone": "+70030635581"}
0005433473333	3D7922	0490 550842	VLADISLAV MAKSIMOV	{"email": "maksimovv.081968@postgrespro.ru", "phone": "+70433263344"}
0005433473334	F5A499	2132 694555	VLADIMIR MEDVEDEV	{"phone": "+70738119599"}
0005433473335	80EB40	4464 437060	ELENA BORISOVA	{"email": "e_borisova.071977@postgrespro.ru", "phone": "+70788486933"}
0005433473336	80EB40	2593 213881	ELENA DAVYDOVA	{"phone": "+70066704185"}
0005433473337	F76F3C	6338 925606	NADEZHDA SMIRNOVA	{"phone": "+70225352993"}
0005433473338	72B831	9064 051668	VIKTOR BONDARENKO	{"phone": "+70628492906"}
0005433473339	72B831	7520 517682	ALEKSEY ALEKSANDROV	{"phone": "+70257726510"}
0005433473340	20C291	4108 865516	ZINAIDA DAVYDOVA	{"email": "davydova.z_25011967@postgrespro.ru", "phone": "+70548007663"}
0005433473341	98F935	0571 541723	ALINA SAVELEVA	{"phone": "+70469074396"}
0005433473342	72CC06	7173 283872	SERGEY BELOV	{"email": "s_belov-1968@postgrespro.ru", "phone": "+70272300147"}
0005433473343	AA74C2	0980 868566	ALEKSANDRA ORLOVA	{"phone": "+70569024360"}
0005433473344	AA74C2	1641 791041	VIKTOR MAKAROV	{"phone": "+70103336340"}
0005433473345	B8469F	1779 974580	MARINA SAVELEVA	{"phone": "+70775382426"}
0005433473346	7B907B	6273 659405	SERGEY SEMENOV	{"email": "semenov_s.25121970@postgrespro.ru", "phone": "+70629401406"}
0005433473347	32CA7C	9444 910592	YULIYA ALEKSEEVA	{"phone": "+70567542582"}
0005433473348	32CA7C	1541 683981	DMITRIY IVANOV	{"phone": "+70961824566"}
0005433473349	9484FA	4665 312962	LYUDMILA SOLOVEVA	{"email": "lsoloveva-101974@postgrespro.ru", "phone": "+70322783371"}
0005433473350	FF5877	5933 165626	MARINA FEDOROVA	{"phone": "+70983030730"}
0005433473351	FF5877	5063 406528	MARIYA TIMOFEEVA	{"email": "mariya.timofeeva.031968@postgrespro.ru", "phone": "+70915548626"}
0005433473352	FF5877	7773 178651	VIKTOR STEPANOV	{"phone": "+70827741311"}
0005433473353	9DDFC7	5175 245050	RAUZA AFANASEVA	{"phone": "+70872799549"}
0005433473354	58B934	2909 948528	KSENIYA MELNIKOVA	{"phone": "+70549272370"}
0005433473355	1E5218	4258 626744	VERA SERGEEVA	{"phone": "+70841265012"}
0005433473356	91FAD3	3187 312010	TATYANA NIKIFOROVA	{"email": "tatyana.nikiforova.1974@postgrespro.ru", "phone": "+70798329455"}
0005433473357	91FAD3	2803 842391	LARISA KRASNOVA	{"phone": "+70718815675"}
0005433473358	46CD14	4089 638747	ALEKSANDR FEDOROV	{"email": "fedorova.051965@postgrespro.ru", "phone": "+70809819690"}
0005433473359	14B04B	1914 251062	ARTEM IVANOV	{"email": "ivanova071979@postgrespro.ru", "phone": "+70833443290"}
0005433473360	D3815F	7351 980347	DMITRIY NIKOLAEV	{"email": "d_nikolaev-091976@postgrespro.ru", "phone": "+70574167204"}
0005433473361	90FBBF	5507 775902	VITALIY MAKSIMOV	{"phone": "+70204253326"}
0005433473362	90FBBF	6057 513691	IGOR IVANOV	{"phone": "+70762839381"}
0005433473363	4165B3	5725 419612	ANNA PAVLOVA	{"phone": "+70809436374"}
0005433473364	40912E	4085 486234	ELENA MAKAROVA	{"email": "makarova.elena.091975@postgrespro.ru", "phone": "+70259257124"}
0005433473365	DDB09C	2475 037509	ANASTASIYA KUZMINA	{"email": "kuzmina_anastasiya.27061971@postgrespro.ru", "phone": "+70186839703"}
0005433473366	8BAF4C	6661 289962	NIKOLAY ANDREEV	{"phone": "+70889198576"}
0005433473367	49CBB3	9199 083424	ROMAN MOISEEV	{"phone": "+70973298761"}
0005433473368	C3709F	9183 813031	ELENA MATVEEVA	{"email": "e_matveeva.061966@postgrespro.ru", "phone": "+70900693498"}
0005433473369	86D4AE	7562 878168	VLADIMIR ANDREEV	{"email": "vandreev_10111970@postgrespro.ru", "phone": "+70992910042"}
0005433473370	86D4AE	2994 432990	TATYANA ZHURAVLEVA	{"phone": "+70518459543"}
0005433473371	06016B	0018 908624	EGOR SERGEEV	{"email": "sergeev-e_18041974@postgrespro.ru", "phone": "+70322028614"}
0005433473372	868566	9850 593583	LYUDMILA LOGINOVA	{"email": "lyudmila_loginova_03041968@postgrespro.ru", "phone": "+70367720541"}
0005433473373	3B4721	3810 946510	PAVEL MELNIKOV	{"phone": "+70992844330"}
0005433473374	C40481	2540 456924	VLADIMIR KUZMIN	{"phone": "+70418075691"}
0005433473375	C40481	7540 911597	IRINA KALININA	{"phone": "+70763294032"}
0005433473376	C40481	8438 104096	MATVEY FILIPPOV	{"email": "filippov.matvey.021965@postgrespro.ru", "phone": "+70042522202"}
0005433473377	5EA56D	0408 418109	NINA VOROBEVA	{"phone": "+70387401848"}
0005433473378	036218	5298 563750	EKATERINA MOISEEVA	{"email": "e_moiseeva.10051974@postgrespro.ru", "phone": "+70796087525"}
0005433473379	036218	4175 625317	NIKOLAY EGOROV	{"phone": "+70556717602"}
0005433473380	B54039	6011 796995	SERGEY YAKOVLEV	{"email": "sergey.yakovlev1975@postgrespro.ru", "phone": "+70382118189"}
0005433473381	B54039	2711 988454	ALEKSANDR POPOV	{"email": "aleksandr.popov-1973@postgrespro.ru", "phone": "+70489870292"}
0005433473382	43630E	3419 207359	MARINA KOVALEVA	{"phone": "+70607057405"}
0005433473383	9D6467	5647 026787	LYUBOV KOROLEVA	{"phone": "+70253427719"}
0005433473384	509EFA	0387 177484	VALENTINA ANTONOVA	{"email": "antonovavalentina_071967@postgrespro.ru", "phone": "+70878256314"}
0005433473385	509EFA	2132 252124	GEORGIY SAVELEV	{"phone": "+70151197515"}
0005433473386	4A7A4D	0460 311080	KIRILL ALEKSEEV	{"phone": "+70076194009"}
0005433473387	952B5A	9825 115860	MARIYA KOROLEVA	{"email": "koroleva_mariya.17041973@postgrespro.ru", "phone": "+70517875229"}
0005433473388	9A766A	2731 031325	VIKTOR VLASOV	{"phone": "+70493404292"}
0005433473389	9A766A	2034 267961	VASILIY FEDOROV	{"phone": "+70904678286"}
0005433473390	3DAC6C	6737 489279	TATYANA GAVRILOVA	{"email": "gavrilovatatyana101973@postgrespro.ru", "phone": "+70758675737"}
0005433473391	019B9C	8126 697956	ROMAN ALEKSEEV	{"email": "romanalekseev-1977@postgrespro.ru", "phone": "+70079062062"}
0005433473392	514172	1728 046273	ANNA GERASIMOVA	{"phone": "+70372669906"}
0005433473393	514172	3200 197923	ANNA STEPANOVA	{"phone": "+70192808193"}
0005433473394	74619D	8741 264082	IRINA IVANOVA	{"email": "i.ivanova111966@postgrespro.ru", "phone": "+70189584593"}
0005433473395	B606F3	5261 359301	VARVARA SOLOVEVA	{"email": "vsoloveva-07061975@postgrespro.ru", "phone": "+70121408286"}
0005433473396	ABFB0C	0153 877435	VALENTINA MASLOVA	{"email": "maslova-v26111966@postgrespro.ru", "phone": "+70009481694"}
0005433473397	ABFB0C	9015 420258	PAVEL SEMENOV	{"email": "semenov.pavel.091981@postgrespro.ru", "phone": "+70894164406"}
0005433473398	4E090C	5963 578399	EGOR STEPANOV	{"email": "stepanov_egor-021979@postgrespro.ru", "phone": "+70561225549"}
0005433473399	4E090C	0775 010302	STANISLAV BORISOV	{"phone": "+70239950796"}
0005433473400	034A06	5518 566252	NATALYA KRASNOVA	{"phone": "+70913248584"}
0005433473401	034A06	5879 911466	IRINA IVANOVA	{"phone": "+70283183559"}
0005433473402	034A06	3329 923888	TATYANA FOMINA	{"email": "fomina-t021971@postgrespro.ru", "phone": "+70841715496"}
0005433473403	D75973	5640 112974	VIKTOR OSIPOV	{"email": "viktor-osipov_1979@postgrespro.ru", "phone": "+70641844034"}
0005433473404	D75973	3504 220318	VLADIMIR MATVEEV	{"phone": "+70886384579"}
0005433473405	C9A160	8542 370092	VARVARA TITOVA	{"phone": "+70610159511"}
0005433473406	C9A160	5233 746339	SERGEY ZHURAVLEV	{"phone": "+70563548686"}
0005433473407	D83180	7799 249372	VALERIY SHEVCHENKO	{"email": "vshevchenko_061970@postgrespro.ru", "phone": "+70892653703"}
0005433473408	EBB35B	5180 091781	MIKHAIL SOROKIN	{"email": "sorokin-mikhail-07041975@postgrespro.ru", "phone": "+70387167806"}
0005433473409	A8EFFA	6430 678120	LEONID DAVYDOV	{"phone": "+70899881073"}
0005433473410	74ACF7	6715 714341	SVETLANA DENISOVA	{"phone": "+70853232950"}
0005433473411	872DF7	8485 928991	ALEKSEY FOMIN	{"phone": "+70033386896"}
0005433473412	872DF7	3756 530330	ALI TARASOV	{"email": "a-tarasov.121980@postgrespro.ru", "phone": "+70889106120"}
0005433473413	EA00BA	3012 984416	SERGEY GERASIMOV	{"phone": "+70489938095"}
0005433473414	15D99C	2493 042809	MARINA KUZNECOVA	{"email": "kuznecova-marina.031980@postgrespro.ru", "phone": "+70535931613"}
0005433473415	311793	7491 193942	SVETLANA ALEKSANDROVA	{"email": "aleksandrova_svetlana-21061972@postgrespro.ru", "phone": "+70498635481"}
0005433473416	24CA98	6752 884076	ANATOLIY ALEKSANDROV	{"email": "anatoliyaleksandrov.021972@postgrespro.ru", "phone": "+70639197271"}
0005433473417	CE94C4	1614 164195	IVAN IVANOV	{"email": "ivan.ivanov_1978@postgrespro.ru", "phone": "+70471662488"}
0005433473418	FFEE40	1595 223741	VIKTOR PETROV	{"email": "vpetrov.13121970@postgrespro.ru", "phone": "+70704742742"}
0005433473419	FFEE40	1186 620606	NATALIYA KUZNECOVA	{"phone": "+70493213762"}
0005433473420	753520	3603 589558	VASILIY GERASIMOV	{"phone": "+70367447747"}
0005433473421	B405B4	5967 183732	VLADISLAV KONOVALOV	{"email": "konovalov_v_19031973@postgrespro.ru", "phone": "+70026504915"}
0005433473422	21CF71	1551 832921	OLGA EGOROVA	{"phone": "+70166104028"}
0005433473423	21CF71	1350 568831	ALEKSEY EGOROV	{"email": "aegorov-12011963@postgrespro.ru", "phone": "+70730334491"}
0005433473424	DA46E1	5229 272229	EVGENIYA SEMENOVA	{"email": "semenova-e.091980@postgrespro.ru", "phone": "+70948731893"}
0005433473425	2CCB31	6171 397161	OLGA ZAYCEVA	{"email": "ozayceva_22101969@postgrespro.ru", "phone": "+70265791381"}
0005433473426	2CCB31	2120 213522	VLADIMIR FILIPPOV	{"phone": "+70697452660"}
0005433473427	675865	3300 531759	VALENTINA MIRONOVA	{"phone": "+70942084033"}
0005433473428	7B7DFE	6610 453522	RINAT IVANOV	{"phone": "+70667977750"}
0005433473429	6D735A	2395 876168	ALENA ERMAKOVA	{"phone": "+70853624303"}
0005433473430	322ADB	2788 389568	ALEKSANDR KARPOV	{"phone": "+70058379564"}
0005433473431	2D190F	1536 154875	DMITRIY KAZAKOV	{"email": "d.kazakov.1983@postgrespro.ru", "phone": "+70492799892"}
0005433473432	948E2C	6524 349935	MARINA GAVRILOVA	{"phone": "+70771435914"}
0005433473433	FB0A31	3678 453636	ARTEM NIKOLAEV	{"email": "artem.nikolaev-041963@postgrespro.ru", "phone": "+70097597707"}
0005433473434	DC04AE	8798 414852	YURIY ALEKSEEV	{"email": "y.alekseev_23111971@postgrespro.ru", "phone": "+70099711344"}
0005433473435	C8D06F	2002 458011	ALEKSANDR ALEKSEEV	{"phone": "+70963904241"}
0005433473436	7F9EC0	2785 895972	ALEKSEY MATVEEV	{"email": "matveevaleksey011974@postgrespro.ru", "phone": "+70837805436"}
0005433473437	5A7EE2	8283 697251	SERGEY MIRONOV	{"email": "mironov.s_11011962@postgrespro.ru", "phone": "+70103750414"}
0005433473438	95689A	3633 008027	MIKHAIL ROMANOV	{"phone": "+70722959608"}
0005433473439	F72A65	0391 393776	YULIYA POPOVA	{"email": "popova-yuliya_19061975@postgrespro.ru", "phone": "+70017549769"}
0005433473440	F72A65	8014 808558	ANASTASIYA OVCHINNIKOVA	{"phone": "+70519779031"}
0005433473441	5993FB	0268 774442	MARIYA TITOVA	{"email": "mariya_titova1979@postgrespro.ru", "phone": "+70574968095"}
0005433473442	BCE6A8	1036 728907	LIDIYA BORISOVA	{"phone": "+70653659191"}
0005433473443	BCE6A8	2701 441855	SVETLANA BORISOVA	{"email": "s.borisova.23071964@postgrespro.ru", "phone": "+70947043211"}
0005433473444	D05214	2187 596735	ANATOLIY SERGEEV	{"email": "a_sergeev.30051970@postgrespro.ru", "phone": "+70230975631"}
0005433473445	C273C0	6671 581063	EVGENIY IVANOV	{"email": "ivanov_e.1973@postgrespro.ru", "phone": "+70555143106"}
0005433473446	5B9289	2994 966784	ANASTASIYA NIKOLAEVA	{"email": "a-nikolaeva-08021970@postgrespro.ru", "phone": "+70806909741"}
0005433473447	5B9289	1361 300078	ILYA FEDOROV	{"phone": "+70637489458"}
0005433473448	34B525	9224 893332	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev_1975@postgrespro.ru", "phone": "+70561728508"}
0005433473449	935FFC	1259 508430	NINA LOGINOVA	{"phone": "+70859429660"}
0005433473450	89A4B0	8348 046221	SERGEY DENISOV	{"email": "denisov_s-17021974@postgrespro.ru", "phone": "+70217405442"}
0005433473451	6967E4	7540 347295	VALENTINA SOROKINA	{"phone": "+70864008914"}
0005433473452	F00BDF	8492 832843	ALEKSANDR MOROZOV	{"phone": "+70946689026"}
0005433473453	527A9D	7039 879218	KLAVDIYA AKIMOVA	{"phone": "+70990089800"}
0005433473454	12F799	4727 712055	ANASTASIYA OVCHINNIKOVA	{"email": "anastasiya-ovchinnikova_15081979@postgrespro.ru", "phone": "+70952751753"}
0005433473455	12F799	9837 943476	YULIYA KUZNECOVA	{"email": "yuliyakuznecova-27031975@postgrespro.ru", "phone": "+70656696751"}
0005433473456	FE2FCA	0492 160944	NIKOLAY MOROZOV	{"email": "nikolay_morozov.111969@postgrespro.ru", "phone": "+70652957485"}
0005433473457	FE2FCA	3052 223112	SVETLANA KARPOVA	{"phone": "+70274913387"}
0005433473458	28CAA4	4419 840110	GEORGIY GERASIMOV	{"email": "georgiy_gerasimov_031971@postgrespro.ru", "phone": "+70894736241"}
0005433473459	28CAA4	9544 266481	VIKTORIYA KUZMINA	{"email": "kuzmina_v14081980@postgrespro.ru", "phone": "+70932342078"}
0005433473460	525E5E	3702 270236	RAIL ZAYCEV	{"email": "zaycev-r.05111973@postgrespro.ru", "phone": "+70124648175"}
0005433473461	525E5E	9597 645495	ELENA ROMANOVA	{"phone": "+70718786579"}
0005433473462	A70196	4161 772591	VASILIY KOZLOV	{"phone": "+70120903231"}
0005433473463	A70196	6997 152246	EVGENIYA NESTEROVA	{"email": "evgeniya-nesterova.1961@postgrespro.ru", "phone": "+70870030358"}
0005433473464	591C5B	8971 845397	GRIGORIY FEDOROV	{"phone": "+70066294783"}
0005433473465	D7D1B5	8703 705203	ANASTASIYA NIKITINA	{"phone": "+70525870416"}
0005433473466	D7D1B5	0239 599890	LEONID MAKAROV	{"email": "makarov_l1969@postgrespro.ru", "phone": "+70252313528"}
0005433473467	6FABD4	7471 969604	ALEKSEY STEPANOV	{"email": "aleksey.stepanov_1984@postgrespro.ru", "phone": "+70762386579"}
0005433473468	3BAB25	4912 496097	OLEG KONOVALOV	{"email": "oleg-konovalov-06101966@postgrespro.ru", "phone": "+70475825415"}
0005433473469	B0D960	9879 450180	ELENA SMIRNOVA	{"email": "smirnova.e-1980@postgrespro.ru", "phone": "+70706928217"}
0005433473470	716D83	5202 093027	TATYANA KUZNECOVA	{"email": "kuznecovatatyana_31071974@postgrespro.ru", "phone": "+70604321133"}
0005433473471	0F978A	0479 352597	NIKOLAY ISAEV	{"email": "n_isaev12031967@postgrespro.ru", "phone": "+70193296504"}
0005433473472	A46BE7	0922 592861	TAMARA SCHERBAKOVA	{"email": "scherbakova_t.101971@postgrespro.ru", "phone": "+70029909339"}
0005433473473	A46BE7	6530 514853	VALENTINA AFANASEVA	{"email": "v-afanaseva_1969@postgrespro.ru", "phone": "+70469502145"}
0005433473474	1D0808	7543 810373	NATALYA ANDREEVA	{"email": "andreevan_03071968@postgrespro.ru", "phone": "+70718086099"}
0005433473475	1D0808	5283 376839	OLGA ZAYCEVA	{"phone": "+70722916946"}
0005433473476	F3B676	4358 299967	SERGEY IVANOV	{"phone": "+70835218275"}
0005433473477	F3B676	6406 468128	TATYANA EGOROVA	{"email": "egorovat.101980@postgrespro.ru", "phone": "+70511776665"}
0005433473478	6CD870	1542 462446	SVETLANA PETROVA	{"phone": "+70925430898"}
0005433473479	66B500	6192 319408	EVGENIY NIKITIN	{"email": "evgeniy-nikitin_19101983@postgrespro.ru", "phone": "+70207499609"}
0005433473480	069ABD	8119 234051	ALEKSANDRA VLASOVA	{"phone": "+70114514099"}
0005433473481	295E36	9186 999084	SERGEY FEDOROV	{"phone": "+70099817769"}
0005433473482	D12E85	3587 867183	KRISTINA NAZAROVA	{"email": "knazarova-1980@postgrespro.ru", "phone": "+70985868639"}
0005433473483	DE3DEE	4640 118692	ALEKSANDRA MATVEEVA	{"phone": "+70419759677"}
0005433473484	DE3DEE	6590 945237	LYUBOV YAKOVLEVA	{"phone": "+70416395931"}
0005433473485	3F1916	9175 820023	ELENA KUZNECOVA	{"phone": "+70020843474"}
0005433473486	CBFA64	5999 617904	VYACHESLAV CHERNOV	{"email": "vyacheslavchernov-03061974@postgrespro.ru", "phone": "+70777660125"}
0005433473487	F0DC42	6870 557574	SNEZHANA VOROBEVA	{"email": "vorobeva-s1964@postgrespro.ru", "phone": "+70062721353"}
0005433473488	F0DC42	6275 550318	GALINA PAVLOVA	{"phone": "+70953875132"}
0005433473489	F0DC42	8187 686741	LIDIYA VOROBEVA	{"email": "vorobeva-l.08021976@postgrespro.ru", "phone": "+70246896003"}
0005433473490	6B2B69	6645 758267	MIKHAIL RODIONOV	{"email": "rodionov-mikhail-1978@postgrespro.ru", "phone": "+70282720739"}
0005433473491	40EBC9	6404 819432	ALEKSEY KUZNECOV	{"phone": "+70009728844"}
0005433473492	77271A	4483 609432	LYUBOV PETROVA	{"email": "petrova_lyubov.1973@postgrespro.ru", "phone": "+70725255324"}
0005433473493	D70496	5261 244193	ANASTASIYA PETROVA	{"phone": "+70626903197"}
0005433473494	628E2E	0855 459347	VALERIYA ARKHIPOVA	{"phone": "+70044737352"}
0005433473495	628E2E	2153 344614	OLEG IVANOV	{"email": "o-ivanov_081974@postgrespro.ru", "phone": "+70685842557"}
0005433473496	599483	6807 451191	SERGEY FROLOV	{"phone": "+70978879468"}
0005433473497	599483	6259 141098	TATYANA TIKHONOVA	{"email": "tikhonova.tatyana.091961@postgrespro.ru", "phone": "+70795249801"}
0005433473498	1F1A2A	6628 476174	MIKHAIL KUZMIN	{"email": "kuzmin-mikhail.04081973@postgrespro.ru", "phone": "+70580930220"}
0005433473499	470FF5	4618 868769	OLEG KUZNECOV	{"phone": "+70241388335"}
0005433473500	470FF5	7216 081558	YANA PETROVA	{"email": "yana.petrova_15011981@postgrespro.ru", "phone": "+70313164942"}
0005433473501	F8E25F	5632 846676	ANDREY SERGEEV	{"phone": "+70017911650"}
0005433473502	04D125	4123 683443	TATYANA KUZNECOVA	{"phone": "+70556738123"}
0005433473503	04D125	7517 737277	MAYYA EFIMOVA	{"phone": "+70864374020"}
0005433473504	04D125	7297 821584	VIKTOR KUZNECOV	{"phone": "+70255078907"}
0005433473505	CD8D74	9573 814608	ALINA MEDVEDEVA	{"phone": "+70406879222"}
0005433473506	495979	5910 205520	OLGA TIMOFEEVA	{"phone": "+70456888772"}
0005433473507	9ED3EB	1044 475566	VLADIMIR MIKHAYLOV	{"phone": "+70740478066"}
0005433473508	198FEC	1624 432016	ELENA OSIPOVA	{"phone": "+70473053841"}
0005433473509	314F4C	6737 987946	ELENA IVANOVA	{"phone": "+70393593313"}
0005433473510	4E7BBF	9235 369195	ALEKSANDR PETROV	{"email": "a_petrov041969@postgrespro.ru", "phone": "+70266528207"}
0005433473511	3557F6	0539 400011	ZOYA MAKAROVA	{"email": "makarovaz-16021972@postgrespro.ru", "phone": "+70156379630"}
0005433473512	EE3C88	3721 670421	KIRILL VOLKOV	{"email": "volkov-k-041982@postgrespro.ru", "phone": "+70744005141"}
0005433473513	767457	6516 850573	VALERIY NAUMOV	{"phone": "+70795228091"}
0005433473514	88A211	7016 133364	VIKTOR SERGEEV	{"email": "sergeev-viktor1971@postgrespro.ru", "phone": "+70413757390"}
0005433473515	1DB0AC	4064 688004	SERGEY NIKITIN	{"email": "nikitin-sergey23121973@postgrespro.ru", "phone": "+70168970678"}
0005433473516	9B374B	2954 333526	ANATOLIY KOROLEV	{"phone": "+70211094053"}
0005433473517	9B374B	0867 352270	NATALYA VOROBEVA	{"email": "natalya.vorobeva.101978@postgrespro.ru", "phone": "+70557808564"}
0005433473518	9B374B	2543 982039	SERGEY SOROKIN	{"phone": "+70146959733"}
0005433473519	584F86	6530 508055	SVETLANA NAZAROVA	{"phone": "+70425128535"}
0005433473520	6D7A5F	9309 326241	LILIYA KAZAKOVA	{"email": "l.kazakova1968@postgrespro.ru", "phone": "+70768191994"}
0005433473521	4DBA57	1709 801042	SOFYA FILIPPOVA	{"email": "sofya-filippova-1979@postgrespro.ru", "phone": "+70273031547"}
0005433473522	77C923	1955 354115	ALEKSEY MAKAROV	{"email": "makarov-a04031980@postgrespro.ru", "phone": "+70436415312"}
0005433473523	77C923	3014 097122	ELENA IVANOVA	{"phone": "+70921863780"}
0005433473524	E05894	2728 758318	ALEKSANDR SERGEEV	{"email": "a-sergeev_121973@postgrespro.ru", "phone": "+70885443733"}
0005433473525	E05894	7844 351424	ANASTASIYA PAVLOVA	{"phone": "+70164144079"}
0005433473526	51B672	7119 572599	NIKOLAY KOZLOV	{"email": "kozlovnikolay.1966@postgrespro.ru", "phone": "+70014470910"}
0005433473527	D8F3C0	9209 128546	GALINA NAZAROVA	{"phone": "+70871419180"}
0005433473528	702F41	9838 433397	ANDREY STEPANOV	{"phone": "+70684453743"}
0005433473529	76D3E6	8617 985421	YURIY MARTYNOV	{"phone": "+70897324519"}
0005433473530	805D13	8096 979041	GEORGIY BORISOV	{"email": "georgiy-borisov.051967@postgrespro.ru", "phone": "+70059493349"}
0005433473531	805D13	9056 430324	MURAD BELOV	{"phone": "+70877645669"}
0005433473532	722683	3405 466554	VLADIMIR KRASNOV	{"email": "krasnov_v_1971@postgrespro.ru", "phone": "+70934053975"}
0005433473533	722683	6595 921979	MAKSIM PETROV	{"email": "petrov_m-03091973@postgrespro.ru", "phone": "+70012268238"}
0005433473534	0DB2C2	8028 941118	GALINA MEDVEDEVA	{"phone": "+70516340832"}
0005433473535	0DB2C2	2204 718145	ANDREY ILIN	{"email": "ilin_a-08111971@postgrespro.ru", "phone": "+70161525596"}
0005433475630	EDEC22	2008 409942	MAKSIM ZAYCEV	{"email": "zaycev_m_111979@postgrespro.ru", "phone": "+70400591216"}
0005433475631	34B809	5583 602922	LYUDMILA STEPANOVA	{"email": "stepanova_lyudmila-1965@postgrespro.ru", "phone": "+70159333920"}
0005433475632	F4C972	5764 852526	EVGENIY SHEVCHENKO	{"phone": "+70343714108"}
0005433475633	F4C972	3726 290459	IGOR PAVLOV	{"phone": "+70682568885"}
0005433475634	7B6FD9	0971 383729	IRINA NIKITINA	{"phone": "+70847714391"}
0005433475635	7B6FD9	9774 926250	PETR NIKOLAEV	{"email": "nikolaev-p-1969@postgrespro.ru", "phone": "+70521853740"}
0005433475636	F674E2	6720 952131	VLADIMIR ZAKHAROV	{"phone": "+70184346855"}
0005433475637	C52AFF	1456 498274	VALERIY IVANOV	{"email": "ivanov_valeriy111976@postgrespro.ru", "phone": "+70740473392"}
0005433475638	5DAABC	8847 381997	VALENTIN BONDARENKO	{"email": "valentin_bondarenko-08121964@postgrespro.ru", "phone": "+70855498674"}
0005433475639	EC49B6	8606 849804	SERGEY PAVLOV	{"phone": "+70705801326"}
0005433475640	6398C0	0472 701491	ALEKSANDR MELNIKOV	{"phone": "+70158849855"}
0005433475641	EB0177	1358 019617	SERGEY NIKOLAEV	{"email": "sergey-nikolaev-26061979@postgrespro.ru", "phone": "+70505788485"}
0005433475642	EB0177	6022 942847	MARINA NIKITINA	{"email": "marina.nikitina-15061967@postgrespro.ru", "phone": "+70478932432"}
0005433475643	69A785	4480 092555	DARYA VASILEVA	{"email": "d.vasileva041978@postgrespro.ru", "phone": "+70957588055"}
0005433475644	F8DE1B	4671 572996	OKSANA CHERNOVA	{"phone": "+70977150043"}
0005433475645	72BC1A	5666 001982	VASILIY ALEKSEEV	{"email": "v.alekseev-111979@postgrespro.ru", "phone": "+70805811635"}
0005433475646	72BC1A	3865 059426	SERGEY MEDVEDEV	{"phone": "+70768411596"}
0005433475647	1E72F2	9073 795459	NIKOLAY RODIONOV	{"email": "rodionov.n.1972@postgrespro.ru", "phone": "+70212048702"}
0005433475648	581E05	3993 324916	VASILIY FROLOV	{"email": "vasiliy.frolov.01121980@postgrespro.ru", "phone": "+70484205609"}
0005433475649	581E05	9604 682773	KONSTANTIN NIKOLAEV	{"email": "k-nikolaev.22021967@postgrespro.ru", "phone": "+70773543870"}
0005433475650	C1525D	7201 413375	MARIYA GERASIMOVA	{"email": "mariya-gerasimova.07041955@postgrespro.ru", "phone": "+70010858628"}
0005433475651	C7C708	9841 169108	SVETLANA FEDOROVA	{"email": "fedorovas.30091971@postgrespro.ru", "phone": "+70204765566"}
0005433475652	37CFDA	6075 890667	ANDREY SIDOROV	{"email": "sidorovandrey.24061970@postgrespro.ru", "phone": "+70176050191"}
0005433475653	37CFDA	0825 208518	SERGEY POPOV	{"email": "s-popov09061974@postgrespro.ru", "phone": "+70048161641"}
0005433475654	07018A	2763 771427	VLADIMIR TARASOV	{"email": "vladimir.tarasov1978@postgrespro.ru", "phone": "+70931739922"}
0005433475655	07018A	2121 433216	VALENTINA KARPOVA	{"email": "karpova-v_031972@postgrespro.ru", "phone": "+70476870077"}
0005433475656	422ED9	5266 397030	ANDREY KAZAKOV	{"email": "a.kazakov.14071961@postgrespro.ru", "phone": "+70124875171"}
0005433475657	4E48DD	8462 744503	YULIYA GRISHINA	{"email": "y_grishina-07051961@postgrespro.ru", "phone": "+70538554070"}
0005433475658	4E48DD	4191 987407	TATYANA POPOVA	{"phone": "+70461159687"}
0005433475659	7D79C3	3247 899327	MARIYA PETROVA	{"phone": "+70596973305"}
0005433475660	2F2782	9567 116884	OLEG MATVEEV	{"phone": "+70227282912"}
0005433475661	2065D1	4887 188980	ANDREY DAVYDOV	{"email": "davydov.andrey.101978@postgrespro.ru", "phone": "+70760372166"}
0005433475662	2065D1	4666 542523	VITALIY VLASOV	{"email": "vvlasov081968@postgrespro.ru", "phone": "+70361586530"}
0005433475663	4E060A	4543 605926	DENIS ABRAMOV	{"phone": "+70587381612"}
0005433475779	90E280	3545 979367	SERGEY NIKITIN	{"phone": "+70583025779"}
0005433475664	9EC3BF	0108 149806	NATALYA KOROLEVA	{"email": "nkoroleva_1972@postgrespro.ru", "phone": "+70219125899"}
0005433475665	9EC3BF	3021 226674	ANNA RYABOVA	{"email": "ryabova.a-1972@postgrespro.ru", "phone": "+70960696817"}
0005433475666	4BE838	3248 819600	NIKOLAY MATVEEV	{"phone": "+70686574110"}
0005433475667	E898AE	9680 692875	ELENA KOZLOVA	{"phone": "+70224577046"}
0005433475668	E898AE	1434 564229	ALEKSEY MIRONOV	{"phone": "+70569608773"}
0005433475669	A9372D	8377 357414	PAVEL MARTYNOV	{"email": "martynov.p041971@postgrespro.ru", "phone": "+70556033348"}
0005433475670	477DAA	0557 230723	VLADIMIR ANDREEV	{"email": "andreev-v101979@postgrespro.ru", "phone": "+70348381042"}
0005433475671	2A43CF	5475 547582	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov-1971@postgrespro.ru", "phone": "+70702001206"}
0005433475672	BA8E34	7611 744828	RAFAEL KUZNECOV	{"phone": "+70683814886"}
0005433475673	63164C	3919 453369	NATALYA FROLOVA	{"phone": "+70765579440"}
0005433475674	5B93A9	2107 296142	ELENA KUZMINA	{"email": "elena_kuzmina-021962@postgrespro.ru", "phone": "+70968756483"}
0005433475675	5B93A9	0085 062337	DINA ZAKHAROVA	{"email": "dina-zakharova15051967@postgrespro.ru", "phone": "+70653368577"}
0005433475676	8385D4	2221 362108	LIDIYA SAVELEVA	{"email": "l.saveleva1984@postgrespro.ru", "phone": "+70152743294"}
0005433475677	8F38F1	4265 181209	ELENA BELYAEVA	{"email": "elena.belyaeva_091984@postgrespro.ru", "phone": "+70175692934"}
0005433475678	411DE6	7624 074216	VLADISLAV SOKOLOV	{"email": "vladislav-sokolov-011980@postgrespro.ru", "phone": "+70853249378"}
0005433475679	F6CDBE	3293 970320	SERGEY ANTONOV	{"email": "antonovs-05061981@postgrespro.ru", "phone": "+70514335595"}
0005433475680	F6CDBE	3118 392760	ALINA SEMENOVA	{"email": "a.semenova_1965@postgrespro.ru", "phone": "+70884641262"}
0005433475681	4A99E8	4082 663691	YULIYA BELOVA	{"email": "ybelova.11031974@postgrespro.ru", "phone": "+70782707215"}
0005433475682	78E002	8076 455598	LARISA PAVLOVA	{"email": "larisa_pavlova.16021968@postgrespro.ru", "phone": "+70276362111"}
0005433475683	18DB04	7951 799172	KONSTANTIN ZAYCEV	{"email": "konstantinzaycev.021985@postgrespro.ru", "phone": "+70399337800"}
0005433475684	18DB04	3110 795843	LYUBOV NIKITINA	{"email": "nikitina-l_06051967@postgrespro.ru", "phone": "+70986359267"}
0005433475685	7356C4	7570 894536	EVGENIY ZAKHAROV	{"phone": "+70099156061"}
0005433475686	E1A166	9750 661567	SERGEY ALEKSEEV	{"email": "alekseev-s.1964@postgrespro.ru", "phone": "+70530347380"}
0005433475687	D5007A	9129 452797	SOFYA ZHURAVLEVA	{"email": "zhuravleva-sofya1965@postgrespro.ru", "phone": "+70877544032"}
0005433475688	D5007A	6999 285669	ANDREY BORISOV	{"email": "andreyborisov061973@postgrespro.ru", "phone": "+70310911672"}
0005433475689	AA7A33	1048 669841	PAVEL TIKHONOV	{"email": "ptikhonov_1981@postgrespro.ru", "phone": "+70751635291"}
0005433475690	C532FB	1404 112239	ANATOLIY MOISEEV	{"email": "a.moiseev1963@postgrespro.ru", "phone": "+70417016943"}
0005433475691	C532FB	9927 511952	ELIZAVETA KONOVALOVA	{"email": "elizaveta_konovalova-1979@postgrespro.ru", "phone": "+70020718254"}
0005433475692	D2F992	8153 034213	EVGENIY IVANOV	{"email": "evgeniy.ivanov_121971@postgrespro.ru", "phone": "+70899000545"}
0005433475693	B6C92B	2625 636013	TATYANA MARTYNOVA	{"phone": "+70649927671"}
0005433475694	E7C6FF	1783 362423	LIDIYA ZOTOVA	{"phone": "+70766559704"}
0005433475695	E7C6FF	7506 079196	TATYANA VLASOVA	{"email": "vlasova_tatyana_121968@postgrespro.ru", "phone": "+70611445173"}
0005433475696	A92FD0	3717 135267	SERGEY KAZAKOV	{"email": "kazakov-s.27051960@postgrespro.ru", "phone": "+70069490333"}
0005433475697	A92FD0	9635 555969	ARTEM PAVLOV	{"phone": "+70808557013"}
0005433475698	D3F18E	1515 674258	VLADIMIR DENISOV	{"email": "vdenisov-1960@postgrespro.ru", "phone": "+70103792515"}
0005433475699	9F5EBB	8373 565199	VALERIY NAUMOV	{"phone": "+70045033229"}
0005433475700	9F5EBB	2895 070688	DMITRIY KUZNECOV	{"phone": "+70539796792"}
0005433475701	0657B9	5981 575870	ELENA PAVLOVA	{"phone": "+70373801392"}
0005433475702	F54CB1	9117 452686	DENIS OSIPOV	{"phone": "+70613057608"}
0005433475703	F54CB1	7086 457457	DARYA FROLOVA	{"phone": "+70167849241"}
0005433475704	F54CB1	4394 488737	MARIYA MASLOVA	{"email": "maslova.mariya011975@postgrespro.ru", "phone": "+70899755264"}
0005433475705	3AEA80	4795 642720	ALEKSANDR DAVYDOV	{"email": "a-davydov-081975@postgrespro.ru", "phone": "+70405591093"}
0005433475706	3AEA80	9506 949601	EKATERINA IVANOVA	{"email": "ekaterinaivanova.12031979@postgrespro.ru", "phone": "+70513782014"}
0005433475707	9EAF19	5442 714523	ANDREY IVANOV	{"email": "aivanov_061980@postgrespro.ru", "phone": "+70239887830"}
0005433475708	8AC475	2690 145459	NATALIYA MAKAROVA	{"email": "nataliya_makarova10121973@postgrespro.ru", "phone": "+70196711752"}
0005433475709	8AC475	9490 675909	OLEG FEDOTOV	{"phone": "+70236992203"}
0005433475710	E63087	2184 213713	MARIANNA DENISOVA	{"phone": "+70942036124"}
0005433475711	05533B	3442 545407	DANIIL KULIKOV	{"phone": "+70733163756"}
0005433475712	AC73C9	3880 679665	ANDREY KUZMIN	{"email": "andrey-kuzmin-16071971@postgrespro.ru", "phone": "+70737936848"}
0005433475713	438C58	6006 026920	DMITRIY GAVRILOV	{"email": "dmitriy-gavrilov-12081972@postgrespro.ru", "phone": "+70034607510"}
0005433475714	438C58	5746 725120	ALEKSANDR KOZLOV	{"email": "akozlov-27121970@postgrespro.ru", "phone": "+70337095290"}
0005433475715	CD1432	3853 745438	RAFAIL KUZNECOV	{"email": "kuznecov.rafail.08011975@postgrespro.ru", "phone": "+70140472495"}
0005433475716	0D21FC	8458 184184	ELENA POLYAKOVA	{"phone": "+70795043758"}
0005433475717	C450E1	3947 676419	NINA KONOVALOVA	{"phone": "+70753598620"}
0005433475718	EE9EEA	8444 842289	ANNA KOMAROVA	{"email": "komarovaanna-1971@postgrespro.ru", "phone": "+70913482560"}
0005433475719	2884D2	0577 422440	LARISA TITOVA	{"phone": "+70978433248"}
0005433475720	3F555D	9124 423976	SERGEY VASILEV	{"email": "vasilev-sergey_09031969@postgrespro.ru", "phone": "+70172724996"}
0005433475780	38153B	3600 285608	MARINA SIDOROVA	{"phone": "+70247821120"}
0005433475721	3E404A	9140 662024	DMITRIY SOKOLOV	{"email": "sokolovdmitriy051970@postgrespro.ru", "phone": "+70356613928"}
0005433475722	0B1814	7462 265595	VASILIY ZHURAVLEV	{"phone": "+70544485141"}
0005433475723	0B1814	2138 722448	ALEKSANDR NIKITIN	{"email": "nikitin_a121973@postgrespro.ru", "phone": "+70234188296"}
0005433475724	44C935	0885 291154	VASILIY RODIONOV	{"email": "rodionov.v_24081970@postgrespro.ru", "phone": "+70511992251"}
0005433475725	7D1A78	9228 948383	DARYA TARASOVA	{"email": "tarasovadarya_07041965@postgrespro.ru", "phone": "+70734796926"}
0005433475726	C9D58A	3616 883950	VITALIY KOROLEV	{"email": "korolev.v.1973@postgrespro.ru", "phone": "+70797420394"}
0005433475727	C9D58A	3986 612631	NATALYA SOKOLOVA	{"phone": "+70049018139"}
0005433475728	B4DF8B	8911 930452	DMITRIY MEDVEDEV	{"email": "medvedev_d-081970@postgrespro.ru", "phone": "+70874846546"}
0005433475729	B4DF8B	9681 496385	ANTON POPOV	{"phone": "+70597656256"}
0005433475730	F9821E	5657 921936	ANASTASIYA RODIONOVA	{"email": "rodionova_a_1977@postgrespro.ru", "phone": "+70140021484"}
0005433475731	F9821E	1830 868731	OLESYA OSIPOVA	{"email": "osipovaolesya_091973@postgrespro.ru", "phone": "+70044946940"}
0005433475732	F3228F	0734 063489	OLGA MALYSHEVA	{"email": "o-malysheva-20051975@postgrespro.ru", "phone": "+70499942573"}
0005433475733	F3228F	9562 813125	VALENTINA DMITRIEVA	{"email": "dmitrievavalentina.1982@postgrespro.ru", "phone": "+70637901900"}
0005433475734	02EFF8	4645 780848	OLEG MELNIKOV	{"email": "melnikov-oleg.04061977@postgrespro.ru", "phone": "+70708299620"}
0005433475735	58B76E	0570 031858	NIKITA ABRAMOV	{"email": "abramov_n_111977@postgrespro.ru", "phone": "+70078352628"}
0005433475736	58B76E	0822 241813	EVGENIYA SCHERBAKOVA	{"email": "evgeniya_scherbakova.05021974@postgrespro.ru", "phone": "+70778921864"}
0005433475737	79A577	1295 384364	VIKTOR ORLOV	{"email": "orlov-viktor.1966@postgrespro.ru", "phone": "+70735620843"}
0005433475738	EC009E	7836 246579	PAVEL ALEKSEEV	{"phone": "+70573708388"}
0005433475739	EC009E	8209 588259	EGOR EGOROV	{"phone": "+70683578053"}
0005433475740	5B4402	2809 153023	ALEKSEY ZAKHAROV	{"email": "zakharov-a_031973@postgrespro.ru", "phone": "+70658191515"}
0005433475741	8EE066	5409 254541	ILDAR VASILEV	{"phone": "+70898444256"}
0005433475742	8EE066	2453 455463	MIKHAIL ALEKSEEV	{"email": "alekseev-m_06011968@postgrespro.ru", "phone": "+70631620611"}
0005433475743	043066	4236 963611	ANASTASIYA ANDREEVA	{"email": "andreeva.a-011966@postgrespro.ru", "phone": "+70836687550"}
0005433475744	043066	6222 983083	VALERIY NOVIKOV	{"email": "vnovikov-091968@postgrespro.ru", "phone": "+70611751197"}
0005433475745	2B6450	0006 728485	VALENTIN MIRONOV	{"email": "mironov_valentin_011966@postgrespro.ru", "phone": "+70144385583"}
0005433475746	2B6450	6731 488912	SEMEN TIMOFEEV	{"phone": "+70243167467"}
0005433475747	C7BDE3	5777 131200	YULIYA DMITRIEVA	{"phone": "+70771084208"}
0005433475748	FB7B3B	2220 337604	ALEKSANDR MOROZOV	{"email": "a.morozov.081982@postgrespro.ru", "phone": "+70277205231"}
0005433475749	FB7B3B	1486 461181	IVAN SERGEEV	{"email": "sergeevivan20121974@postgrespro.ru", "phone": "+70325180804"}
0005433475750	FB7B3B	4831 896264	YURIY SEMENOV	{"phone": "+70677604183"}
0005433475751	C690C7	4284 454205	NIKOLAY ILIN	{"phone": "+70896955702"}
0005433475752	330CEE	5067 659460	ANASTASIYA MATVEEVA	{"email": "matveeva-anastasiya-021969@postgrespro.ru", "phone": "+70831612753"}
0005433475753	D80E43	5241 898562	YULIYA PAVLOVA	{"phone": "+70571288345"}
0005433475754	D80E43	3473 787123	ALEKSANDRA KUZNECOVA	{"phone": "+70475072237"}
0005433475755	33628F	8170 951849	LYUDMILA NIKITINA	{"phone": "+70640624613"}
0005433475756	C6F1BD	6302 869657	VYACHESLAV ANDREEV	{"phone": "+70848292506"}
0005433475757	C6F1BD	5449 462072	IGOR SEMENOV	{"phone": "+70116694451"}
0005433475758	C96AD2	0604 125907	VIKTOR ZHUKOV	{"email": "zhukov_v1976@postgrespro.ru", "phone": "+70783299323"}
0005433475759	C96AD2	8218 515628	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr-1983@postgrespro.ru", "phone": "+70903301772"}
0005433475760	BCCEAB	8062 730340	GENNADIY CHERNOV	{"email": "chernovg_21101964@postgrespro.ru", "phone": "+70660073432"}
0005433475761	BCCEAB	8513 841104	LARISA YAKOVLEVA	{"email": "l_yakovleva-1986@postgrespro.ru", "phone": "+70011315396"}
0005433475762	F008D5	5547 791491	ALEKSANDR NOVIKOV	{"phone": "+70986045212"}
0005433475763	B9DC8D	5930 665287	IRINA ERMAKOVA	{"email": "i_ermakova-24091972@postgrespro.ru", "phone": "+70183304964"}
0005433475764	B9DC8D	6195 000746	DMITRIY MAKSIMOV	{"email": "d-maksimov.21121973@postgrespro.ru", "phone": "+70499868177"}
0005433475765	86E770	9945 960368	KSENIYA ABRAMOVA	{"email": "kseniyaabramova-13091976@postgrespro.ru", "phone": "+70407695414"}
0005433475766	C65D32	6438 503558	DMITRIY STEPANOV	{"phone": "+70582327844"}
0005433475767	317B8A	0353 605589	ANASTASIYA MAKAROVA	{"phone": "+70535555039"}
0005433475768	A4A93E	6182 234752	MAKSIM IVANOV	{"phone": "+70380384252"}
0005433475769	2DC929	3993 681402	RAISA KOLESNIKOVA	{"phone": "+70037774514"}
0005433475770	2DC929	2739 236251	ELENA KUZMINA	{"email": "kuzminaelena30101972@postgrespro.ru", "phone": "+70204520406"}
0005433475771	2DC929	4523 847567	OKSANA SCHERBAKOVA	{"phone": "+70686363110"}
0005433475772	420BC1	9668 384964	ANNA YUDINA	{"email": "yudina_anna1969@postgrespro.ru", "phone": "+70668213202"}
0005433475773	FC7803	2402 192681	OLGA ZAYCEVA	{"email": "o_zayceva-06011967@postgrespro.ru", "phone": "+70068182514"}
0005433475774	FC7803	5114 981201	ALEKSEY KUZMIN	{"email": "kuzmina.111981@postgrespro.ru", "phone": "+70013920350"}
0005433475775	4518D8	2893 244755	ALEKSANDRA OSIPOVA	{"email": "aleksandra_osipova.091974@postgrespro.ru", "phone": "+70003383777"}
0005433475776	4518D8	5337 072514	STANISLAV SHEVCHENKO	{"email": "shevchenko-s-121967@postgrespro.ru", "phone": "+70561083859"}
0005433475777	B49FF8	4591 810160	NATALYA POLYAKOVA	{"phone": "+70527921309"}
0005433475778	90E280	6148 763372	NINA YAKOVLEVA	{"phone": "+70623413671"}
0005433475781	7E97E7	8763 302979	VALENTINA BELOVA	{"phone": "+70683468458"}
0005433475782	DBB768	1416 369816	VALENTINA ZAKHAROVA	{"email": "zakharovavalentina111967@postgrespro.ru", "phone": "+70013347749"}
0005433475783	1AA167	8660 616628	DENIS EGOROV	{"phone": "+70447729904"}
0005433475784	71ED72	6339 362594	PAVEL NIKITIN	{"email": "p_nikitin-1980@postgrespro.ru", "phone": "+70950560707"}
0005433475785	DEBD70	2086 891542	NATALYA ROMANOVA	{"email": "natalya-romanova-22091965@postgrespro.ru", "phone": "+70216951006"}
0005433475786	679F6D	3824 420536	SERGEY MARTYNOV	{"email": "martynovsergey1981@postgrespro.ru", "phone": "+70615038999"}
0005433475787	58461D	9288 274471	ANNA POPOVA	{"phone": "+70934691091"}
0005433475788	AA94E1	3642 494468	DIANA MIRONOVA	{"email": "d_mironova.28031969@postgrespro.ru", "phone": "+70476373195"}
0005433475789	AA94E1	1639 014575	DARYA FILIPPOVA	{"email": "filippova.darya-1973@postgrespro.ru", "phone": "+70970830379"}
0005433475790	5A3E6E	5364 313082	IRINA PETROVA	{"phone": "+70941480314"}
0005433475791	069876	4630 301604	MIKHAIL FEDOTOV	{"email": "fedotovm_13101968@postgrespro.ru", "phone": "+70156869184"}
0005433475792	069876	2114 357253	VLADIMIR YAKOVLEV	{"phone": "+70174312905"}
0005433475793	069876	7637 683006	LYUBOV ZAKHAROVA	{"email": "lyubov.zakharova_17091968@postgrespro.ru", "phone": "+70402959570"}
0005433475794	82696A	0648 445190	DMITRIY MATVEEV	{"email": "dmatveev-031967@postgrespro.ru", "phone": "+70582665832"}
0005433475795	82696A	0155 972355	LYUDMILA KUZMINA	{"email": "kuzminalyudmila101979@postgrespro.ru", "phone": "+70209534490"}
0005433475796	77A339	8441 247471	EKATERINA ZAYCEVA	{"email": "zayceva-ekaterina.1971@postgrespro.ru", "phone": "+70180671140"}
0005433475797	07C074	3216 545529	YURIY MIRONOV	{"email": "y.mironov-071972@postgrespro.ru", "phone": "+70526827444"}
0005433475798	2A22DC	9351 551297	LIDIYA VASILEVA	{"email": "vasileval111982@postgrespro.ru", "phone": "+70704883806"}
0005433475799	6093A2	8498 350500	ALEKSEY ISAEV	{"phone": "+70022579679"}
0005433475800	6093A2	2579 995093	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr1973@postgrespro.ru", "phone": "+70862746253"}
0005433475801	6093A2	7825 202135	PAVEL BARANOV	{"email": "baranov-p011968@postgrespro.ru", "phone": "+70541972229"}
0005433475802	69211A	5352 136735	VALENTINA DENISOVA	{"phone": "+70550229309"}
0005433475803	69211A	2897 807928	EKATERINA KOMAROVA	{"email": "komarova_ekaterina.11041983@postgrespro.ru", "phone": "+70711952914"}
0005433475804	B72F67	2565 926016	VALENTINA ZAYCEVA	{"phone": "+70646414760"}
0005433475805	3F6F23	8246 788234	MARINA NOVIKOVA	{"phone": "+70575693528"}
0005433475806	3F6F23	0235 445195	TATYANA ALEKSEEVA	{"email": "tatyana-alekseeva-25041966@postgrespro.ru", "phone": "+70909312031"}
0005433475807	359535	5860 456693	ELENA SCHERBAKOVA	{"phone": "+70833297607"}
0005433475808	AEE7C6	4635 851824	RAISA OSIPOVA	{"email": "raisa-osipova_22081962@postgrespro.ru", "phone": "+70245175770"}
0005433475809	02CD92	7426 406759	GRIGORIY VASILEV	{"email": "vasilev.g.21081970@postgrespro.ru", "phone": "+70154370834"}
0005433475810	EC89F4	3972 298655	KLAVDIYA MAKAROVA	{"email": "klavdiya-makarova-031968@postgrespro.ru", "phone": "+70833690392"}
0005433475811	EC89F4	8379 865453	EGOR VASILEV	{"phone": "+70131949499"}
0005433475812	487A21	6928 636623	EKATERINA SOROKINA	{"email": "e-sorokina-12011966@postgrespro.ru", "phone": "+70941771738"}
0005433475813	411139	6908 258481	ANASTASIYA PAVLOVA	{"phone": "+70396014147"}
0005433475814	AF3B52	5190 489682	SHAMIL SHEVCHENKO	{"email": "s.shevchenko.08021974@postgrespro.ru", "phone": "+70362121318"}
0005433475815	AF3B52	6690 710675	POLINA SERGEEVA	{"phone": "+70454275000"}
0005433475816	B0530B	4987 841102	VIKTORIYA KOROLEVA	{"phone": "+70218898072"}
0005433475817	C8196B	1300 697912	NATALIYA ROMANOVA	{"email": "n_romanova-01081970@postgrespro.ru", "phone": "+70822768132"}
0005433475818	24DEF5	9900 132240	ANNA VOLKOVA	{"phone": "+70248858457"}
0005433475819	24DEF5	0029 464616	MILANA NESTEROVA	{"email": "nesterova_m-1977@postgrespro.ru", "phone": "+70187243686"}
0005433475820	DCA5DD	5701 103627	MARK GRIGOREV	{"phone": "+70074463989"}
0005433475821	98B4FF	5273 267191	OLEG CHERNOV	{"phone": "+70241691675"}
0005433475822	E9D264	4696 840486	ALEKSEY POPOV	{"email": "apopov-29101967@postgrespro.ru", "phone": "+70784092088"}
0005433475823	E9D264	9641 621931	VALENTINA BORISOVA	{"phone": "+70412926191"}
0005433475824	1C8D90	0054 327356	VALERIYA SEMENOVA	{"email": "valeriya_semenova_1971@postgrespro.ru", "phone": "+70161631183"}
0005433475825	1C8D90	0720 891634	ILYA STEPANOV	{"email": "stepanov_ilya_1977@postgrespro.ru", "phone": "+70598959180"}
0005433475826	E3609F	0686 804749	IVAN ANDREEV	{"email": "i.andreev-18111962@postgrespro.ru", "phone": "+70874318646"}
0005433475827	17B70F	5594 343801	ROMAN BORISOV	{"phone": "+70277862410"}
0005433475828	B2CF5E	8518 875534	ALEKSEY GUSEV	{"email": "a_gusev-1981@postgrespro.ru", "phone": "+70163167633"}
0005433475829	7287EC	4286 121613	KSENIYA KUZNECOVA	{"phone": "+70505356630"}
0005433475830	D07700	7749 754586	NIKOLAY ANDREEV	{"email": "nikolay.andreev-1980@postgrespro.ru", "phone": "+70180711160"}
0005433475831	87F571	7967 007495	LYUDMILA KISELEVA	{"email": "l_kiseleva1965@postgrespro.ru", "phone": "+70880983457"}
0005433475832	87F571	9841 297980	TATYANA MARTYNOVA	{"phone": "+70468750914"}
0005433475833	12F248	2459 309594	DMITRIY KUZMIN	{"phone": "+70940116821"}
0005433475834	12F248	5359 443808	ANTON IVANOV	{"email": "antonivanov.1965@postgrespro.ru", "phone": "+70304958947"}
0005433475835	07DCAE	6159 281380	MARIYA IVANOVA	{"email": "mivanova-041968@postgrespro.ru", "phone": "+70591125181"}
0005433476855	199184	6763 091340	ANTONINA LAZAREVA	{"email": "antonina.lazareva_121968@postgrespro.ru", "phone": "+70317299658"}
0005433476856	5C02BE	6435 108738	ALEKSANDR KUDRYASHOV	{"email": "a.kudryashov-011964@postgrespro.ru", "phone": "+70815310579"}
0005433476857	B95C2E	3629 174585	LYUBOV FEDOROVA	{"email": "fedorova_l091980@postgrespro.ru", "phone": "+70496786104"}
0005433476858	263BBC	9879 572177	MAKSIM BELOV	{"phone": "+70921669235"}
0005433476859	25782D	4918 646979	ELENA OVCHINNIKOVA	{"phone": "+70341867433"}
0005433476860	25782D	0191 527586	EKATERINA GAVRILOVA	{"phone": "+70998730258"}
0005433476861	25782D	8136 791200	IRINA MIKHAYLOVA	{"phone": "+70805947078"}
0005433476862	742152	3118 711034	VIKTOR BORISOV	{"email": "borisovv-021965@postgrespro.ru", "phone": "+70169881281"}
0005433476863	742152	2008 401061	LIDIYA BELOVA	{"phone": "+70756523835"}
0005433476864	73BC70	6266 310113	TATYANA GERASIMOVA	{"email": "t.gerasimova17031976@postgrespro.ru", "phone": "+70333833063"}
0005433476865	73BC70	6331 509323	MARIYA ZAKHAROVA	{"phone": "+70050551987"}
0005433476866	266722	8794 716076	LYUBOV STEPANOVA	{"phone": "+70461643310"}
0005433476867	6AF67A	8331 257406	SERGEY KAZAKOV	{"phone": "+70381016183"}
0005433476868	7403F9	7024 235877	DMITRIY SAVELEV	{"phone": "+70872356246"}
0005433476869	7403F9	4347 063436	DMITRIY VOLKOV	{"email": "volkovd_091984@postgrespro.ru", "phone": "+70935101884"}
0005433476870	A87879	8342 278206	LIDIYA ROMANOVA	{"phone": "+70450756392"}
0005433476871	39E69E	0262 836786	DMITRIY BARANOV	{"email": "baranov_dmitriy_1973@postgrespro.ru", "phone": "+70323568488"}
0005433476872	D24383	3152 583907	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr051980@postgrespro.ru", "phone": "+70300256617"}
0005433476873	D24383	9316 912259	ARTEMIY ORLOV	{"phone": "+70120506513"}
0005433476874	9E9998	0886 277038	VIKTOR MAKSIMOV	{"email": "v.maksimov1966@postgrespro.ru", "phone": "+70431359937"}
0005433476875	312D99	0679 792974	IVAN MAKSIMOV	{"email": "maksimovivan_051969@postgrespro.ru", "phone": "+70023676640"}
0005433476876	281047	1887 401519	YULIYA RYABOVA	{"email": "yuliyaryabova14081968@postgrespro.ru", "phone": "+70318166817"}
0005433476877	281047	0024 450783	VALENTINA FEDOROVA	{"email": "v_fedorova-041980@postgrespro.ru", "phone": "+70387757079"}
0005433476878	38158D	6235 505956	LIDIYA SEMENOVA	{"email": "lidiyasemenova1969@postgrespro.ru", "phone": "+70316334495"}
0005433476879	38158D	4009 392076	VALENTINA EFREMOVA	{"phone": "+70773278601"}
0005433476880	38158D	6816 072512	IRINA KOROLEVA	{"email": "irina.koroleva1971@postgrespro.ru", "phone": "+70434652651"}
0005433476881	35D074	1794 514975	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov_091968@postgrespro.ru", "phone": "+70502479136"}
0005433476882	35D074	9476 366478	SERGEY MAKAROV	{"phone": "+70275645579"}
0005433476883	0E52D6	0640 229666	OLGA LUKYANOVA	{"email": "lukyanovaolga-121976@postgrespro.ru", "phone": "+70803605863"}
0005433476884	BD1AD6	1584 545191	NINA ISAEVA	{"email": "nina_isaeva.27011974@postgrespro.ru", "phone": "+70672663845"}
0005433476885	BD1AD6	4120 924554	MIKHAIL SCHERBAKOV	{"phone": "+70862650894"}
0005433476886	2006C0	3318 054312	NIKOLAY ROMANOV	{"email": "n-romanov.10081962@postgrespro.ru", "phone": "+70829653578"}
0005433476887	BBE93D	1593 026949	KONSTANTIN IVANOV	{"email": "ivanovk-19021976@postgrespro.ru", "phone": "+70312233950"}
0005433476888	09DFFD	5347 955382	MARINA CHERNOVA	{"email": "chernovamarina1972@postgrespro.ru", "phone": "+70621631514"}
0005433476889	09DFFD	3111 912435	NATALYA MEDVEDEVA	{"email": "natalya-medvedeva_28111968@postgrespro.ru", "phone": "+70239404032"}
0005433476890	09DFFD	6379 019009	ARTEM SMIRNOV	{"email": "a.smirnov.011976@postgrespro.ru", "phone": "+70807822649"}
0005433476891	645DAF	0678 741304	DARYA KOVALEVA	{"email": "kovalevad_1968@postgrespro.ru", "phone": "+70434892547"}
0005433476892	2106EC	7010 329877	EVGENIYA POPOVA	{"email": "e.popova.07011970@postgrespro.ru", "phone": "+70699938243"}
0005433476893	2106EC	8048 601393	VERA GAVRILOVA	{"email": "veragavrilova-081970@postgrespro.ru", "phone": "+70537221458"}
0005433476894	AF814C	2048 104616	LYUBOV LEBEDEVA	{"email": "lyubov-lebedeva30031968@postgrespro.ru", "phone": "+70400550331"}
0005433476895	AF814C	3513 535946	YULIYA FEDOROVA	{"email": "fedorova.yuliya.031972@postgrespro.ru", "phone": "+70739147523"}
0005433476896	5AF8BA	9899 642042	GALINA KUZNECOVA	{"email": "galina.kuznecova.19021965@postgrespro.ru", "phone": "+70430386128"}
0005433476897	D31B01	5613 369036	NINA MIKHAYLOVA	{"phone": "+70011875656"}
0005433476898	D31B01	9738 899545	ANASTASIYA KULIKOVA	{"email": "anastasiya-kulikova21111966@postgrespro.ru", "phone": "+70675643025"}
0005433476899	D31B01	5639 475658	ALEKSANDR ZHUKOV	{"phone": "+70822780273"}
0005433476900	D31B01	5286 250595	YURIY BONDARENKO	{"phone": "+70849410509"}
0005433476901	BB130B	0316 829495	PAVEL VLASOV	{"email": "vlasov_p.21061975@postgrespro.ru", "phone": "+70855302044"}
0005433476902	856A67	2104 796039	NIKOLAY MATVEEV	{"email": "matveevn-04011977@postgrespro.ru", "phone": "+70134007420"}
0005433476903	B7B663	7690 284347	TATYANA SOLOVEVA	{"email": "soloveva-t-1978@postgrespro.ru", "phone": "+70257960035"}
0005433476904	6DD38A	2587 486025	EVGENIY FEDOROV	{"email": "fedorovevgeniy121974@postgrespro.ru", "phone": "+70668646672"}
0005433476905	6DD38A	4000 577585	NIKOLAY PAVLOV	{"phone": "+70283530437"}
0005433476906	6DD38A	8829 547751	POLINA SAVELEVA	{"email": "polinasaveleva.1976@postgrespro.ru", "phone": "+70939408123"}
0005433476907	E54949	7070 571115	ELENA KALININA	{"phone": "+70765345069"}
0005433476908	B1046D	9734 186640	SERGEY ZAKHAROV	{"email": "sergey_zakharov-27121966@postgrespro.ru", "phone": "+70849403820"}
0005433476909	1CEB29	1833 044040	IVAN YAKOVLEV	{"email": "yakovlev-i-1967@postgrespro.ru", "phone": "+70504483616"}
0005433476910	1CEB29	5850 898060	OLESYA KULIKOVA	{"phone": "+70020862287"}
0005433476911	34A920	1691 159784	KONSTANTIN NIKOLAEV	{"phone": "+70737785582"}
0005433476912	34A920	8233 453567	NATALYA AKIMOVA	{"phone": "+70199883825"}
0005433476913	726C46	4593 474683	NATALYA MELNIKOVA	{"phone": "+70473617404"}
0005433476914	6D6F30	2238 210958	OKSANA ARKHIPOVA	{"email": "o_arkhipova09101968@postgrespro.ru", "phone": "+70924126164"}
0005433476915	B7CC59	6432 290016	EVDOKIYA VASILEVA	{"phone": "+70724545922"}
0005433476916	B7CC59	7531 919974	ANATOLIY SOROKIN	{"phone": "+70855471828"}
0005433476917	ADE8B2	3756 961952	ILYA MOROZOV	{"phone": "+70229988723"}
0005433476918	ADE8B2	1720 240277	ALEKSEY PETROV	{"email": "aleksey.petrov061970@postgrespro.ru", "phone": "+70313734645"}
0005433476919	D82461	3697 744906	NIKOLAY AFANASEV	{"email": "afanasev.nikolay.11041971@postgrespro.ru", "phone": "+70068282446"}
0005433476920	D82461	1114 815976	OLGA BARANOVA	{"phone": "+70519122815"}
0005433476921	A48DAE	4924 283936	DMITRIY ANTONOV	{"phone": "+70316263106"}
0005433476922	841327	2656 114178	ALEKSANDRA GERASIMOVA	{"phone": "+70133195139"}
0005433476923	841327	1139 859306	YURIY GERASIMOV	{"email": "gerasimov.yuriy.08031980@postgrespro.ru", "phone": "+70749740050"}
0005433476924	DF898C	0038 973604	ALEKSEY EGOROV	{"phone": "+70516848882"}
0005433476925	C934AA	5564 562666	LYUDMILA DANILOVA	{"phone": "+70019727032"}
0005433476926	C934AA	8030 032563	OLGA BOGDANOVA	{"phone": "+70204919844"}
0005433476927	705DCF	6970 979781	ELENA KOMAROVA	{"phone": "+70974114502"}
0005433476928	991855	8241 268118	ELENA PAVLOVA	{"phone": "+70719413751"}
0005433476929	CDF34B	3900 787468	NIKOLAY POPOV	{"phone": "+70988722329"}
0005433476930	CDF34B	2149 522924	ILYA GRIGOREV	{"phone": "+70138902222"}
0005433476931	CDF34B	9940 911141	LYUBOV FROLOVA	{"email": "l_frolova1971@postgrespro.ru", "phone": "+70401733955"}
0005433476932	452AF3	6397 050006	ELENA KONOVALOVA	{"phone": "+70320638028"}
0005433476933	452AF3	7250 154139	SOFYA KUZMINA	{"email": "sofya-kuzmina_1976@postgrespro.ru", "phone": "+70685874987"}
0005433476934	D96DAC	6918 405690	IRINA VOROBEVA	{"email": "vorobevai121971@postgrespro.ru", "phone": "+70906282472"}
0005433476935	4A1AC9	2641 402972	ALEKSANDR SMIRNOV	{"email": "smirnov-aleksandr041975@postgrespro.ru", "phone": "+70676674286"}
0005433476936	6CF70F	1338 839286	TIMUR SOROKIN	{"email": "timur_sorokin1963@postgrespro.ru", "phone": "+70149614172"}
0005433476937	6CF70F	6981 151599	OLGA KALININA	{"phone": "+70885207919"}
0005433476938	A2AF3E	5189 840506	ALEKSANDR BORISOV	{"phone": "+70077576862"}
0005433476939	D85163	1115 074797	VLADIMIR VOROBEV	{"phone": "+70023626714"}
0005433476940	D85163	3233 964891	NINA SEMENOVA	{"email": "semenova.n.1967@postgrespro.ru", "phone": "+70613989237"}
0005433476941	7163AC	7062 133511	DIANA MELNIKOVA	{"phone": "+70339087856"}
0005433476942	451A9D	3369 044519	ROZA ZHURAVLEVA	{"email": "zhuravleva_roza.05061971@postgrespro.ru", "phone": "+70580080574"}
0005433476943	451A9D	4675 569442	LIDIYA NIKITINA	{"email": "nikitina.l.091971@postgrespro.ru", "phone": "+70394054262"}
0005433476944	451A9D	7445 758155	ROZA MOROZOVA	{"email": "roza-morozova081976@postgrespro.ru", "phone": "+70426375560"}
0005433476945	DEFB59	8858 192847	VIKTORIYA DAVYDOVA	{"phone": "+70726085518"}
0005433476946	D4F46C	6507 300649	NATALYA IVANOVA	{"email": "natalya-ivanova.051978@postgrespro.ru", "phone": "+70118120935"}
0005433476947	43EF3A	6381 793410	ANNA DMITRIEVA	{"email": "anna_dmitrieva-1974@postgrespro.ru", "phone": "+70744852821"}
0005433476948	FA8B4E	9581 557358	ANDREY SHEVCHENKO	{"phone": "+70906713117"}
0005433476949	2A2D4B	0375 905431	ELIZAVETA YAKOVLEVA	{"phone": "+70435526171"}
0005433476950	7C1636	6667 317510	ANTONINA STEPANOVA	{"phone": "+70605239228"}
0005433476951	6CBC98	9723 664858	OKSANA NAUMOVA	{"email": "naumova.o_1975@postgrespro.ru", "phone": "+70722104767"}
0005433476952	78FEB4	5923 288361	ELENA KONOVALOVA	{"email": "konovalovaelena.13081973@postgrespro.ru", "phone": "+70620119765"}
0005433476953	78FEB4	1392 309892	LYUBOV POPOVA	{"phone": "+70330749356"}
0005433476954	B95139	6772 646224	IRINA SMIRNOVA	{"phone": "+70277407625"}
0005433476955	8CF318	4778 609544	VYACHESLAV KAZAKOV	{"email": "vyacheslav.kazakov02031970@postgrespro.ru", "phone": "+70612426643"}
0005433476956	8CF318	4013 478600	MARIYA MEDVEDEVA	{"email": "medvedeva-m121974@postgrespro.ru", "phone": "+70050847957"}
0005433476957	DAF293	0703 469156	VIKTOR ZAKHAROV	{"email": "viktor_zakharov_081983@postgrespro.ru", "phone": "+70991163131"}
0005433476958	F07AC5	8463 651201	VALENTIN SEMENOV	{"email": "semenov_valentin071983@postgrespro.ru", "phone": "+70241635732"}
0005433476959	F07AC5	5459 054955	NADEZHDA KRASNOVA	{"email": "nkrasnova-071975@postgrespro.ru", "phone": "+70984191737"}
0005433476960	F07AC5	7288 619273	LARISA MELNIKOVA	{"phone": "+70774797930"}
0005433476961	F07AC5	2054 729431	VLADIMIR GUSEV	{"phone": "+70575563036"}
0005433476962	80FE05	2495 182221	PAVEL NAZAROV	{"phone": "+70328173304"}
0005433476963	6AB2EC	5857 917826	ALEKSANDRA IVANOVA	{"email": "ivanova.a-1968@postgrespro.ru", "phone": "+70780014327"}
0005433476964	6AB2EC	7814 895580	LYUDMILA VOLKOVA	{"email": "volkovalyudmila_1968@postgrespro.ru", "phone": "+70303611459"}
0005433476965	E6BF16	7435 061617	SVETLANA STEPANOVA	{"email": "stepanova-svetlana-1969@postgrespro.ru", "phone": "+70965853987"}
0005433476966	75C428	5094 481365	ALEKSEY MEDVEDEV	{"email": "amedvedev-081973@postgrespro.ru", "phone": "+70699951283"}
0005433476967	F763DA	7816 317208	ANATOLIY SAVELEV	{"phone": "+70573579175"}
0005433476968	D8951A	2250 462543	MIKHAIL ALEKSEEV	{"phone": "+70313640418"}
0005433476969	31941D	0381 162445	ROMAN KUZMIN	{"phone": "+70681070597"}
0005433476970	31941D	1462 342709	VLADIMIR SHEVCHENKO	{"phone": "+70902095397"}
0005433476971	030CD0	8598 113476	SERGEY DMITRIEV	{"email": "sdmitriev.061968@postgrespro.ru", "phone": "+70041091325"}
0005433476972	030CD0	7949 556484	VLADISLAV DENISOV	{"phone": "+70966020438"}
0005433476973	5AD1BC	8912 528399	GRIGORIY PAVLOV	{"email": "pavlov_grigoriy_021965@postgrespro.ru", "phone": "+70844256749"}
0005433476974	5AD1BC	8462 136022	EVGENIYA CHERNOVA	{"phone": "+70183203133"}
0005433476975	327060	1226 085951	VERONIKA SERGEEVA	{"email": "v.sergeeva.121976@postgrespro.ru", "phone": "+70480126243"}
0005433476976	327060	1850 812112	VALENTINA IVANOVA	{"email": "vivanova_031960@postgrespro.ru", "phone": "+70230768011"}
0005433481242	C68374	7305 981930	LARISA IVANOVA	{"phone": "+70939163901"}
0005433476977	DEBF90	6582 125033	NATALIYA CHERNOVA	{"email": "nataliya-chernova.1962@postgrespro.ru", "phone": "+70032829358"}
0005433476978	1FD127	8829 904099	ANATOLIY PAVLOV	{"phone": "+70716457983"}
0005433476979	804C7C	4928 075529	LYUDMILA TIKHONOVA	{"email": "tikhonova-l1965@postgrespro.ru", "phone": "+70050547870"}
0005433476980	804C7C	3008 240387	LYUBOV MAKAROVA	{"phone": "+70430731388"}
0005433476981	804C7C	5780 879098	MARGARITA YAKOVLEVA	{"email": "margarita.yakovleva19061981@postgrespro.ru", "phone": "+70825107477"}
0005433476982	B5A210	2473 132010	ANTONINA KUZNECOVA	{"email": "a.kuznecova-011967@postgrespro.ru", "phone": "+70892916183"}
0005433476983	B5A210	4691 111337	VITALIY DMITRIEV	{"phone": "+70353254712"}
0005433476984	1A6A8B	1893 219822	LYUBOV IVANOVA	{"email": "l_ivanova.07011984@postgrespro.ru", "phone": "+70278212500"}
0005433476985	D133E0	6276 077115	GALINA ZHURAVLEVA	{"phone": "+70379803634"}
0005433476986	D133E0	1222 613514	MIKHAIL SEMENOV	{"email": "m_semenov1974@postgrespro.ru", "phone": "+70646762632"}
0005433476987	8AC8BC	9373 209995	ILYA NOVIKOV	{"phone": "+70224246214"}
0005433476988	8D30FC	6251 089877	ANDREY IVANOV	{"phone": "+70413357521"}
0005433476989	8D30FC	8454 559329	GULNARA MOISEEVA	{"phone": "+70053253463"}
0005433476990	3286F8	6004 844552	SVETLANA GUSEVA	{"phone": "+70796385180"}
0005433476991	3286F8	9420 523961	OLGA BORISOVA	{"phone": "+70482959458"}
0005433476992	671BA3	8505 422798	IGOR CHERNOV	{"phone": "+70724757364"}
0005433476993	CFF92F	8100 469840	EKATERINA KUZMINA	{"email": "kuzmina_ekaterina081975@postgrespro.ru", "phone": "+70484122069"}
0005433476994	CFF92F	8162 309118	DMITRIY SOROKIN	{"phone": "+70821840146"}
0005433476995	CFF92F	2899 104018	NATALIYA SEMENOVA	{"email": "nsemenova-061967@postgrespro.ru", "phone": "+70386248142"}
0005433476996	71FC72	1626 445086	NATALYA KAZAKOVA	{"phone": "+70926698859"}
0005433476997	181E68	7401 693701	EKATERINA ZAYCEVA	{"phone": "+70367721535"}
0005433476998	181E68	1015 252227	SERGEY FOMIN	{"phone": "+70665348030"}
0005433476999	D7078F	6707 442642	TATYANA KARPOVA	{"email": "karpova-tatyana1974@postgrespro.ru", "phone": "+70160997342"}
0005433477000	D7078F	1702 172710	GLEB SOROKIN	{"phone": "+70632321807"}
0005433477001	7139B4	7811 761212	LILIYA ZAKHAROVA	{"phone": "+70536197874"}
0005433477002	466936	8966 399307	GALINA KONOVALOVA	{"email": "konovalova_galina_031969@postgrespro.ru", "phone": "+70138885777"}
0005433477003	466936	0680 943289	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr021979@postgrespro.ru", "phone": "+70092087656"}
0005433477004	2C9E3C	2350 043254	LIDIYA ZAKHAROVA	{"email": "zakharova.lidiya1960@postgrespro.ru", "phone": "+70132082034"}
0005433477005	5A2158	8183 783090	ALEKSEY NIKITIN	{"email": "alekseynikitin.041982@postgrespro.ru", "phone": "+70718086421"}
0005433477006	5A2158	5254 720292	OLEG KULIKOV	{"phone": "+70484703506"}
0005433477007	5B1605	9553 424571	LARISA GAVRILOVA	{"phone": "+70651591484"}
0005433477008	D14A02	3936 905595	VALERIY KUZNECOV	{"email": "kuznecov-valeriy07121957@postgrespro.ru", "phone": "+70429459939"}
0005433477009	DFDD2B	7822 790403	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov.02121974@postgrespro.ru", "phone": "+70361391922"}
0005433477010	240C98	3263 047400	ANDREY NAUMOV	{"phone": "+70715741260"}
0005433477011	B2AC51	4957 784283	VLADIMIR ZHURAVLEV	{"email": "vladimir-zhuravlev-31101965@postgrespro.ru", "phone": "+70645790772"}
0005433477012	80F53A	9009 618626	RUSLAN KULIKOV	{"email": "kulikov.r-031984@postgrespro.ru", "phone": "+70618062885"}
0005433477013	3079F2	0963 105438	KRISTINA YAKOVLEVA	{"email": "yakovleva_kristina021987@postgrespro.ru", "phone": "+70607840510"}
0005433477014	3079F2	5272 893270	IVAN VOLKOV	{"phone": "+70990405078"}
0005433477015	DDCAEA	6565 144720	DMITRIY PETROV	{"email": "petrovdmitriy_1968@postgrespro.ru", "phone": "+70660819758"}
0005433477016	DDCAEA	4994 536095	ELENA MAKAROVA	{"email": "makarova-e1967@postgrespro.ru", "phone": "+70857713969"}
0005433477017	AB4DB9	4816 338072	VIKTOR DMITRIEV	{"phone": "+70681692587"}
0005433477018	A2B652	5101 179661	SVETLANA VOLKOVA	{"phone": "+70922809099"}
0005433477019	85E6D4	1033 427624	ALEKSANDR ROMANOV	{"phone": "+70181242087"}
0005433477020	85E6D4	0013 544871	IGOR ZAKHAROV	{"phone": "+70069965649"}
0005433477021	1E1DE0	2359 138864	VALERIY KUZNECOV	{"email": "kuznecov-valeriy.051968@postgrespro.ru", "phone": "+70623119245"}
0005433477022	68D937	3787 106513	NIKITA MOISEEV	{"phone": "+70447339668"}
0005433477023	68D937	8555 223095	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr-1982@postgrespro.ru", "phone": "+70919171237"}
0005433477024	DAAEF1	0933 105130	ANDREY VOLKOV	{"phone": "+70992935903"}
0005433477025	DAAEF1	9514 995347	ANNA IVANOVA	{"phone": "+70760438086"}
0005433477026	D23489	6659 367507	ALEKSANDR FEDOROV	{"email": "a-fedorov-1970@postgrespro.ru", "phone": "+70381379424"}
0005433477027	EBF1A5	8366 957056	PAVEL VASILEV	{"phone": "+70002426545"}
0005433477028	EBF1A5	1658 424354	ANNA ERMAKOVA	{"email": "aermakova.1963@postgrespro.ru", "phone": "+70759159711"}
0005433477029	71C647	8018 336273	PETR ANDREEV	{"phone": "+70374569396"}
0005433477030	2AAC15	4305 235020	YURIY MAKSIMOV	{"email": "y-maksimov021984@postgrespro.ru", "phone": "+70101673341"}
0005433477031	7CECF3	0260 906261	MARGARITA IVANOVA	{"phone": "+70972347013"}
0005433477032	7CECF3	9588 585707	ANDREY FEDOROV	{"email": "afedorov_29041977@postgrespro.ru", "phone": "+70592002507"}
0005433477033	5FB978	0462 505885	ANTON SEMENOV	{"phone": "+70330636821"}
0005433477034	234471	3661 287135	NATALYA NIKOLAEVA	{"phone": "+70666415193"}
0005433477035	C5CA50	1851 432673	ARTEM SOROKIN	{"phone": "+70500937730"}
0005433477036	C5CA50	1888 039081	STANISLAV KUZMIN	{"phone": "+70861421701"}
0005433477037	FBECD3	8799 398915	ANZHELIKA SOLOVEVA	{"phone": "+70037138299"}
0005433477038	FE8021	7522 356805	SERGEY KUZNECOV	{"email": "kuznecov-s22091976@postgrespro.ru", "phone": "+70262301470"}
0005433477039	38D129	7758 277846	MARINA NAZAROVA	{"email": "nazarova_marina12021973@postgrespro.ru", "phone": "+70332896003"}
0005433477040	38D129	5722 852840	VIKTOR KARPOV	{"email": "viktor-karpov.17101976@postgrespro.ru", "phone": "+70751273867"}
0005433477041	E7B0E4	6730 266341	MIKHAIL TARASOV	{"email": "mikhail_tarasov1975@postgrespro.ru", "phone": "+70497966597"}
0005433477042	0BA72C	8501 156186	FAINA IVANOVA	{"phone": "+70366072536"}
0005433477043	0BA72C	7404 424762	ALEKSANDR GORBUNOV	{"phone": "+70048652063"}
0005433477044	917A2B	2533 656677	DMITRIY ABRAMOV	{"phone": "+70414125488"}
0005433477045	B993A7	7538 108958	MARAT MIKHAYLOV	{"phone": "+70269150614"}
0005433477046	B993A7	5572 509381	INNA KOVALEVA	{"phone": "+70158255160"}
0005433477047	CEFF98	1996 207948	ALEKSANDR ALEKSEEV	{"phone": "+70381805283"}
0005433477048	181092	2554 749607	NINA FOMINA	{"email": "n_fomina.03081978@postgrespro.ru", "phone": "+70997317852"}
0005433477049	181092	7233 799144	GALINA SOROKINA	{"phone": "+70822766402"}
0005433477050	7AC26E	6694 951265	NINA GUSEVA	{"phone": "+70552838904"}
0005433477051	73F800	8344 885057	IGOR POPOV	{"phone": "+70242595572"}
0005433477052	463E90	9713 425999	VIKTOR ISAEV	{"email": "v-isaev.01101971@postgrespro.ru", "phone": "+70222322661"}
0005433477053	B1306A	4956 958444	MAYA ZHURAVLEVA	{"phone": "+70264904365"}
0005433477054	799325	4391 347116	OKSANA BELYAEVA	{"email": "belyaevao-24051982@postgrespro.ru", "phone": "+70401528431"}
0005433477055	245961	5117 483961	MAKSIM GORBUNOV	{"email": "gorbunov_maksim1976@postgrespro.ru", "phone": "+70166054672"}
0005433477056	387C0A	0278 441931	ALEKSANDR MAKAROV	{"phone": "+70003967659"}
0005433477057	387C0A	3759 114105	MARIYA FEDOROVA	{"phone": "+70309763044"}
0005433477058	302066	5130 647261	ROMAN SEMENOV	{"email": "roman_semenov_18031968@postgrespro.ru", "phone": "+70549211446"}
0005433477059	09BC76	6262 013783	ALEKSEY ROMANOV	{"email": "aleksey-romanov_121970@postgrespro.ru", "phone": "+70703908212"}
0005433477060	22F0AB	4181 564434	EKATERINA VOLKOVA	{"email": "ekaterina-volkova_1963@postgrespro.ru", "phone": "+70409998782"}
0005433477061	2D99DA	9376 536301	KLAVDIYA NIKITINA	{"email": "k_nikitina_081967@postgrespro.ru", "phone": "+70211024716"}
0005433477062	2D99DA	3352 396133	MARINA VOLKOVA	{"email": "m.volkova1978@postgrespro.ru", "phone": "+70177497178"}
0005433477063	2D99DA	7014 880294	TATYANA SOKOLOVA	{"email": "sokolova-tatyana-06041977@postgrespro.ru", "phone": "+70941896119"}
0005433477064	E8F424	7341 808838	ANDREY IVANOV	{"phone": "+70477490017"}
0005433477065	48FDE1	7117 371499	VLADIMIR VOROBEV	{"phone": "+70105177195"}
0005433477066	096C5B	6505 107364	RASIM SAVELEV	{"email": "rasim.savelev1968@postgrespro.ru", "phone": "+70407669309"}
0005433477067	36CBE8	4398 720491	ALEKSANDR MOROZOV	{"phone": "+70478489248"}
0005433477068	C6F068	5425 522047	DMITRIY VLASOV	{"phone": "+70758333224"}
0005433477069	D20306	3898 326490	POLINA MAKAROVA	{"phone": "+70162163341"}
0005433477070	460941	4997 798106	IGOR KOZLOV	{"phone": "+70847578402"}
0005433477071	2D164A	5951 842689	IRINA ANDREEVA	{"email": "andreeva_irina031971@postgrespro.ru", "phone": "+70304300695"}
0005433477072	5E90DA	5550 118376	ELENA SOLOVEVA	{"email": "elena_soloveva_031979@postgrespro.ru", "phone": "+70338864826"}
0005433477073	5E90DA	3374 607314	ANASTASIYA MIRONOVA	{"email": "anastasiya-mironova1975@postgrespro.ru", "phone": "+70650093539"}
0005433477074	737E94	8493 836330	DARINA FROLOVA	{"phone": "+70105760624"}
0005433477075	252395	4321 606631	RAIS MARTYNOV	{"email": "rmartynov-121977@postgrespro.ru", "phone": "+70112427746"}
0005433477076	252395	9132 791562	GALINA YAKOVLEVA	{"email": "yakovleva_galina19111964@postgrespro.ru", "phone": "+70573973693"}
0005433477077	252395	2213 548822	NATALYA IVANOVA	{"email": "n_ivanova.021972@postgrespro.ru", "phone": "+70119124860"}
0005433477078	766448	0813 123952	YURIY KUZMIN	{"email": "yuriy-kuzmin-03111979@postgrespro.ru", "phone": "+70210553518"}
0005433477079	766448	0907 422407	MARIYA NESTEROVA	{"phone": "+70206918319"}
0005433477080	766448	2369 440621	ARINA KOLESNIKOVA	{"phone": "+70753104232"}
0005433477081	2338CE	9962 804967	ALEKSEY SOROKIN	{"phone": "+70544386162"}
0005433477082	2338CE	6509 422788	LYUDMILA KARPOVA	{"email": "karpova-lyudmila_1967@postgrespro.ru", "phone": "+70186428555"}
0005433477083	E69DC4	5190 272325	IVAN SIDOROV	{"phone": "+70492771522"}
0005433477084	2D5F03	9432 876670	IGOR DMITRIEV	{"email": "igor.dmitriev.03091977@postgrespro.ru", "phone": "+70648162684"}
0005433477085	7D9870	8226 506897	NIKOLAY ILIN	{"email": "ilinn_20081973@postgrespro.ru", "phone": "+70221919353"}
0005433477086	7D9870	0562 030591	KRISTINA NESTEROVA	{"email": "kristina_nesterova_071983@postgrespro.ru", "phone": "+70030835088"}
0005433477087	FA7403	2504 155144	NINA MASLOVA	{"email": "maslova-n_1964@postgrespro.ru", "phone": "+70337033961"}
0005433477088	C43677	8580 335937	SERGEY ZAKHAROV	{"email": "zakharov_s.13081972@postgrespro.ru", "phone": "+70669282859"}
0005433477089	A006FE	3309 904536	DENIS MATVEEV	{"email": "d.matveev_1965@postgrespro.ru", "phone": "+70695085419"}
0005433477090	86A14A	2347 654134	ROMAN KRASNOV	{"email": "krasnovr_1966@postgrespro.ru", "phone": "+70798550498"}
0005433477091	86A14A	5294 150767	EVGENIY MARTYNOV	{"phone": "+70812375651"}
0005433477092	D9E910	9571 214838	ELENA ANDREEVA	{"email": "elena.andreeva-1975@postgrespro.ru", "phone": "+70908779572"}
0005433477093	D63FFD	1343 543355	STANISLAV MIKHAYLOV	{"phone": "+70527367000"}
0005433477094	729A10	2348 913131	VIKTOR KARPOV	{"email": "karpov_v-1976@postgrespro.ru", "phone": "+70432500156"}
0005433477095	D05783	5398 507785	NADEZHDA TIKHONOVA	{"email": "tikhonova_nadezhda061973@postgrespro.ru", "phone": "+70961610996"}
0005433477096	3AE050	8723 851669	VLADIMIR ZAKHAROV	{"email": "zakharov-v1983@postgrespro.ru", "phone": "+70895986905"}
0005433477097	56DB35	5404 160378	OKSANA KONOVALOVA	{"phone": "+70622098060"}
0005433481243	45B056	5909 204199	MARIYA VOROBEVA	{"phone": "+70356362250"}
0005433477098	56DB35	1733 838738	SVETLANA ANTONOVA	{"email": "antonova-s.011973@postgrespro.ru", "phone": "+70955469021"}
0005433477099	56DB35	7275 422014	MARIYA DAVYDOVA	{"email": "davydova.m_031971@postgrespro.ru", "phone": "+70048215445"}
0005433477100	8FFA5B	7429 774290	VLADISLAV POPOV	{"email": "vladislav-popov_1957@postgrespro.ru", "phone": "+70453456220"}
0005433477101	8FFA5B	6882 143392	VLADIMIR MAKAROV	{"phone": "+70418297926"}
0005433477102	2382A7	6888 338024	VALENTINA MOROZOVA	{"email": "morozova_valentina-23011982@postgrespro.ru", "phone": "+70434074257"}
0005433477103	1937B9	1232 448098	ANNA PAVLOVA	{"email": "annapavlova.1973@postgrespro.ru", "phone": "+70512134732"}
0005433477104	1937B9	0691 528625	SERGEY ANDREEV	{"phone": "+70945126436"}
0005433477105	2AD20E	1939 460874	DENIS SMIRNOV	{"phone": "+70241133268"}
0005433477106	2AD20E	3739 713398	EKATERINA ORLOVA	{"phone": "+70905133258"}
0005433477107	AF6DA9	7324 043517	ANASTASIYA BARANOVA	{"phone": "+70934706552"}
0005433477108	633B00	8488 621475	ALEKSANDR ANDREEV	{"phone": "+70421670792"}
0005433477109	66B3B9	2828 755201	LIDIYA ANDREEVA	{"phone": "+70382166484"}
0005433477110	04FE1B	2908 625824	ANATOLIY GAVRILOV	{"phone": "+70291213319"}
0005433477111	04FE1B	4227 022463	ANNA SEMENOVA	{"phone": "+70393603185"}
0005433477112	3E645F	2482 904289	MIKHAIL SOKOLOV	{"phone": "+70977387335"}
0005433477113	3E645F	5994 470572	VIKTOR CHERNOV	{"phone": "+70177987842"}
0005433477114	867766	1183 022541	KIRILL SEMENOV	{"email": "kirill.semenov.011983@postgrespro.ru", "phone": "+70595291191"}
0005433477115	3CFE7D	2894 458946	ANATOLIY GERASIMOV	{"email": "anatoliy.gerasimov091974@postgrespro.ru", "phone": "+70520786966"}
0005433477116	BAEA43	9378 232190	MARIYA TIKHONOVA	{"email": "mariya.tikhonova.13071961@postgrespro.ru", "phone": "+70112012618"}
0005433477117	BAEA43	7929 903362	RAVZA KUZMINA	{"email": "r_kuzmina-1981@postgrespro.ru", "phone": "+70615273957"}
0005433477118	54516E	4361 580799	SVETLANA BARANOVA	{"email": "baranova_svetlana_1968@postgrespro.ru", "phone": "+70356585665"}
0005433477119	306E39	2813 125558	IGOR DAVYDOV	{"email": "i-davydov1971@postgrespro.ru", "phone": "+70131174717"}
0005433477120	ED810E	6813 215246	ALEKSANDR FEDOTOV	{"phone": "+70773081689"}
0005433477121	F82068	0650 939997	FARID ANDREEV	{"phone": "+70566251796"}
0005433477122	F82068	1636 125490	NIKOLAY MATVEEV	{"email": "nikolay-matveev121983@postgrespro.ru", "phone": "+70649138785"}
0005433477123	16A522	1293 940497	SERGEY IVANOV	{"email": "s-ivanov_27021969@postgrespro.ru", "phone": "+70142600747"}
0005433477124	CC70CA	7040 001083	EVGENIY EGOROV	{"phone": "+70831935256"}
0005433477125	790233	1249 194086	ARINA KUZNECOVA	{"phone": "+70490424796"}
0005433477126	5856B1	0581 222136	NADEZHDA FILATOVA	{"email": "n_filatova_29051978@postgrespro.ru", "phone": "+70773322264"}
0005433477127	D37AA6	5795 199418	EVGENIYA EFIMOVA	{"phone": "+70151465002"}
0005433477128	D419F7	6933 772118	OLESYA ALEKSANDROVA	{"phone": "+70643873681"}
0005433477129	8C9C77	3107 641416	TAMARA CHERNOVA	{"email": "tamarachernova.10031981@postgrespro.ru", "phone": "+70979985388"}
0005433477130	FC6F7A	9151 440116	MARINA SEMENOVA	{"phone": "+70187278418"}
0005433477131	FDEAEA	1797 985001	NINA GRISHINA	{"email": "nina_grishina1967@postgrespro.ru", "phone": "+70978586733"}
0005433477132	FBB7B1	9139 284944	NATALYA MAKAROVA	{"phone": "+70208305107"}
0005433477133	FBB7B1	0389 416273	DMITRIY POPOV	{"phone": "+70269366030"}
0005433477134	FAD7BA	3370 530943	YULIYA KONOVALOVA	{"phone": "+70391263754"}
0005433477135	FAD7BA	7466 149329	EKATERINA DMITRIEVA	{"phone": "+70984133384"}
0005433477136	27B762	7236 109039	RUSLAN KRASNOV	{"phone": "+70701564137"}
0005433477137	043ABC	3034 044129	VIKTOR SEMENOV	{"email": "semenov.v-1978@postgrespro.ru", "phone": "+70858364953"}
0005433477138	A72C88	0215 472073	ARTEM IVANOV	{"phone": "+70704497048"}
0005433477139	ADDFDF	6578 809859	RUSTAM GORBUNOV	{"email": "r_gorbunov-021984@postgrespro.ru", "phone": "+70071716629"}
0005433477140	ADDFDF	1014 106893	LIDIYA ZHUKOVA	{"phone": "+70537994590"}
0005433477141	16CC8A	4861 743729	ROZA KRASNOVA	{"email": "krasnovaroza-111977@postgrespro.ru", "phone": "+70457776727"}
0005433477142	16CC8A	4242 258322	ILDAR BONDARENKO	{"phone": "+70984190646"}
0005433477143	16BB5C	8016 980941	OLGA SMIRNOVA	{"email": "olga.smirnova031984@postgrespro.ru", "phone": "+70541567201"}
0005433477144	83CC0A	4799 406135	MARIYA KRASNOVA	{"email": "krasnovamariya25081979@postgrespro.ru", "phone": "+70291593538"}
0005433477145	219A96	8784 329712	ANDREY NAZAROV	{"email": "nazarovandrey-1977@postgrespro.ru", "phone": "+70209160417"}
0005433477146	219A96	7527 554089	IGOR IVANOV	{"phone": "+70643644466"}
0005433477147	05DF7D	8321 049427	ALEKSEY GUSEV	{"email": "gusevaleksey15011977@postgrespro.ru", "phone": "+70604565821"}
0005433477148	05DF7D	7076 004493	OLGA KOVALEVA	{"email": "olga.kovaleva_1978@postgrespro.ru", "phone": "+70213286526"}
0005433477149	15D24B	5840 647100	IVAN ZHURAVLEV	{"phone": "+70810304570"}
0005433477150	8649DE	5186 234270	OKSANA NIKOLAEVA	{"email": "oksana-nikolaeva1977@postgrespro.ru", "phone": "+70910111551"}
0005433477151	C3E97F	9034 839853	OLGA MIRONOVA	{"email": "olgamironova_1972@postgrespro.ru", "phone": "+70305137816"}
0005433477152	614A2A	2052 967661	ANNA IVANOVA	{"phone": "+70100371093"}
0005433477153	614A2A	8145 582004	ZOYA IVANOVA	{"email": "zoya_ivanova021972@postgrespro.ru", "phone": "+70082026818"}
0005433477154	FE99CB	3405 088194	VERA MEDVEDEVA	{"phone": "+70999976150"}
0005433477155	3AFB79	3198 275983	VIKTOR KOROLEV	{"phone": "+70231689899"}
0005433477156	36AA83	4305 322616	VALERIYA KUZNECOVA	{"phone": "+70974461375"}
0005433477157	36AA83	6191 572751	FEDOR FEDOROV	{"email": "fedorovf_041977@postgrespro.ru", "phone": "+70230694487"}
0005433477158	ACA0FE	2585 509790	OLGA LUKYANOVA	{"email": "olgalukyanova101964@postgrespro.ru", "phone": "+70563177852"}
0005433477159	1EA9B8	1705 192320	ANDREY MIKHAYLOV	{"email": "andrey.mikhaylov1970@postgrespro.ru", "phone": "+70031811285"}
0005433477160	1EA9B8	1865 300275	KIRILL MAKAROV	{"phone": "+70046964228"}
0005433477161	B9488C	7880 998999	ZOYA GORBUNOVA	{"phone": "+70030431620"}
0005433477162	B9488C	7720 107209	ANDREY AFANASEV	{"email": "a.afanasev.21041975@postgrespro.ru", "phone": "+70106113817"}
0005433477163	1C511F	2521 778135	DANILA AFANASEV	{"phone": "+70735060867"}
0005433477164	1C511F	2721 847916	PAVEL ISAEV	{"email": "isaev.pavel1962@postgrespro.ru", "phone": "+70235108007"}
0005433477165	8AF305	5233 752542	DMITRIY NAZAROV	{"email": "d-nazarov_1977@postgrespro.ru", "phone": "+70127122824"}
0005433477166	8AF305	0405 090669	VASILIY ZAYCEV	{"phone": "+70815127371"}
0005433477167	F68609	4727 256219	NADEZHDA MAKAROVA	{"phone": "+70282972187"}
0005433477168	ED3E99	1830 882190	NADEZHDA MARTYNOVA	{"phone": "+70617410609"}
0005433477169	E591F1	4403 486810	ALEKSANDR TIKHONOV	{"email": "a.tikhonov.05011970@postgrespro.ru", "phone": "+70129981944"}
0005433477170	5A2006	6417 809436	TATYANA LAZAREVA	{"phone": "+70686347628"}
0005433477171	E329A7	3995 188942	ALENA MAKSIMOVA	{"email": "a_maksimova.091977@postgrespro.ru", "phone": "+70837655124"}
0005433477172	E8BF5E	5353 800816	EVGENIYA DENISOVA	{"phone": "+70604929279"}
0005433477173	ECB8A0	2874 716918	ARTEM GUSEV	{"email": "gusev_artem11011966@postgrespro.ru", "phone": "+70400587991"}
0005433477174	7B14B5	7288 250791	OKSANA RODIONOVA	{"email": "rodionova_o.1975@postgrespro.ru", "phone": "+70913878345"}
0005433477175	D85EBF	2807 661665	LARISA DANILOVA	{"phone": "+70376346294"}
0005433477176	D85EBF	0464 027339	YURIY SIDOROV	{"email": "yuriy.sidorov_17031976@postgrespro.ru", "phone": "+70653361514"}
0005433477177	CCE390	0799 808683	GALINA ANISIMOVA	{"phone": "+70708602247"}
0005433477178	CCE390	2355 980042	ANDREY VASILEV	{"email": "a_vasilev-21071973@postgrespro.ru", "phone": "+70070743409"}
0005433477179	5B7C3C	4094 843434	IVAN BONDARENKO	{"email": "bondarenko-i_091988@postgrespro.ru", "phone": "+70799791851"}
0005433477180	7216F4	5500 623121	VASILIY CHERNOV	{"phone": "+70383356471"}
0005433477181	7216F4	2746 210627	ALEKSANDR MATVEEV	{"phone": "+70604323307"}
0005433477182	5F579C	3992 896179	VLADIMIR VASILEV	{"email": "vasilev_vladimir-20021974@postgrespro.ru", "phone": "+70433108490"}
0005433477183	7A5D14	6913 302177	OLGA MATVEEVA	{"phone": "+70359133540"}
0005433477184	A6D6D0	3360 974096	KSENIYA BELOVA	{"phone": "+70120242183"}
0005433477185	A6D6D0	4346 501043	LYUDMILA KOVALEVA	{"email": "lyudmilakovaleva-091973@postgrespro.ru", "phone": "+70793439833"}
0005433477186	FE4738	1465 227475	LARISA TROFIMOVA	{"phone": "+70105501600"}
0005433477187	FE4738	7010 579167	ROBERT ILIN	{"phone": "+70216658935"}
0005433477188	49F2F3	4179 609225	VASILIY PETROV	{"email": "petrov.v27101977@postgrespro.ru", "phone": "+70173925956"}
0005433477189	49F2F3	1917 228128	DANIIL VASILEV	{"email": "daniil.vasilev_011981@postgrespro.ru", "phone": "+70477879977"}
0005433477190	BBD15A	7150 701460	OKSANA AFANASEVA	{"phone": "+70284200490"}
0005433477191	BBD15A	1273 920986	VIKTOR SIDOROV	{"phone": "+70174616323"}
0005433477192	AB8A7C	0692 634561	NATALIYA NOVIKOVA	{"email": "novikovanataliya121970@postgrespro.ru", "phone": "+70166768275"}
0005433477193	A1BD52	0373 013603	EMMA BELOVA	{"phone": "+70490055783"}
0005433477194	911A5E	2636 121562	EVDOKIYA ZOTOVA	{"phone": "+70494202827"}
0005433477195	523C03	7865 107507	OLGA VLASOVA	{"phone": "+70537897249"}
0005433477196	4367F0	1199 624895	ZHANNA POTAPOVA	{"phone": "+70585521419"}
0005433477197	C45794	6098 076756	IVAN FOMIN	{"email": "fomin-i.05121969@postgrespro.ru", "phone": "+70819100095"}
0005433477198	C45794	3497 472955	PETR SEMENOV	{"phone": "+70922651784"}
0005433477199	AAE561	5585 010250	BORIS NIKOLAEV	{"phone": "+70102880777"}
0005433477200	AAE561	7730 444866	IRINA ZHUKOVA	{"email": "zhukovai101971@postgrespro.ru", "phone": "+70495077080"}
0005433477201	D3FF33	0468 111813	VERA KUZNECOVA	{"email": "vera-kuznecova.1967@postgrespro.ru", "phone": "+70369903074"}
0005433477202	D3FF33	2651 618423	ANATOLIY PAVLOV	{"phone": "+70461798243"}
0005433477203	F1837C	0773 364634	ANASTASIYA ANISIMOVA	{"email": "anastasiyaanisimova_031972@postgrespro.ru", "phone": "+70033300635"}
0005433477204	F4AF38	9625 776822	SERGEY STEPANOV	{"phone": "+70819548299"}
0005433477205	846BBC	3410 971842	RAMIL MAKAROV	{"phone": "+70788124198"}
0005433477206	98D898	1044 808596	VIKTOR DAVYDOV	{"email": "viktor-davydov_1972@postgrespro.ru", "phone": "+70185477923"}
0005433477207	46B72A	2986 190155	GALINA MASLOVA	{"email": "maslovag_1970@postgrespro.ru", "phone": "+70644130686"}
0005433477208	46B72A	0154 438283	RINAT MELNIKOV	{"phone": "+70332454301"}
0005433477209	A7F968	1253 193300	NIKOLAY VASILEV	{"email": "n_vasilev.1978@postgrespro.ru", "phone": "+70903310361"}
0005433477210	C3F930	6669 553565	TATYANA ALEKSEEVA	{"email": "alekseeva.t.11051970@postgrespro.ru", "phone": "+70089241016"}
0005433477211	E1C8DA	6400 160339	ALEKSANDR NAZAROV	{"phone": "+70190532117"}
0005433477212	881C5D	4788 494789	VIKTOR MIRONOV	{"email": "mironov.v_081971@postgrespro.ru", "phone": "+70355261514"}
0005433477213	881C5D	1744 775965	VALERIY FROLOV	{"email": "frolov.valeriy_011962@postgrespro.ru", "phone": "+70904498926"}
0005433477214	F8A46F	7835 518996	VALERIY KONOVALOV	{"email": "v-konovalov02101965@postgrespro.ru", "phone": "+70047345841"}
0005433477215	F8A46F	1771 838312	IRINA FROLOVA	{"phone": "+70665556035"}
0005433477216	F8A46F	4640 111946	TATYANA KUZMINA	{"email": "kuzminat-09121967@postgrespro.ru", "phone": "+70446515153"}
0005433477217	91CDE0	3977 552210	GALINA SMIRNOVA	{"email": "smirnova-galina_1970@postgrespro.ru", "phone": "+70826703424"}
0005433477218	91CDE0	1453 953455	LYUBOV KALININA	{"email": "l_kalinina1974@postgrespro.ru", "phone": "+70928168248"}
0005433477219	80EB46	5575 669126	PAVEL PETROV	{"email": "petrovpavel_111973@postgrespro.ru", "phone": "+70271126133"}
0005433477220	DF170F	8658 677614	TATYANA YUDINA	{"email": "tatyanayudina-101979@postgrespro.ru", "phone": "+70538703720"}
0005433477221	DF170F	6696 635044	NATALYA SIDOROVA	{"email": "n_sidorova-011980@postgrespro.ru", "phone": "+70070516920"}
0005433477222	4AA3C5	2261 202164	VALENTINA KOROLEVA	{"email": "vkoroleva-1972@postgrespro.ru", "phone": "+70332819035"}
0005433477223	4AA3C5	7808 405471	SERGEY SHEVCHENKO	{"email": "sshevchenko.051976@postgrespro.ru", "phone": "+70685499787"}
0005433477224	FD28FD	7244 990532	VALERIY ZAYCEV	{"email": "zaycevvaleriy.1979@postgrespro.ru", "phone": "+70036021338"}
0005433477225	BD27C5	1381 798087	ALEKSEY MIKHAYLOV	{"email": "a_mikhaylov.1965@postgrespro.ru", "phone": "+70014159184"}
0005433477226	C09545	3403 286214	SVETLANA SAVELEVA	{"email": "saveleva_svetlana1977@postgrespro.ru", "phone": "+70634369312"}
0005433477227	692A6D	7553 598756	NADEZHDA KUZNECOVA	{"phone": "+70775864810"}
0005433477228	6D36AF	0573 932833	OLGA MOROZOVA	{"email": "omorozova1981@postgrespro.ru", "phone": "+70900557215"}
0005433477229	6D36AF	0213 376674	LILIYA EFIMOVA	{"phone": "+70019852332"}
0005433477230	33CEF0	9217 874003	VALENTINA SMIRNOVA	{"email": "v_smirnova-061968@postgrespro.ru", "phone": "+70625950710"}
0005433477231	40A506	8850 512846	EKATERINA VASILEVA	{"email": "vasilevae.051972@postgrespro.ru", "phone": "+70124624982"}
0005433477232	40A506	2955 733308	SNEZHANA BORISOVA	{"phone": "+70816555553"}
0005433477233	2E1B44	2360 286733	ALEKSANDRA POTAPOVA	{"email": "potapovaaleksandra-13031954@postgrespro.ru", "phone": "+70015567898"}
0005433477234	EE7610	7021 614730	MAKSIM SMIRNOV	{"email": "m_smirnov-28061963@postgrespro.ru", "phone": "+70914189927"}
0005433477235	EE7610	4905 541978	YURIY GERASIMOV	{"email": "y_gerasimov_1973@postgrespro.ru", "phone": "+70497048079"}
0005433477290	CA9485	1074 978128	VLADIMIR AFANASEV	{"phone": "+70939038987"}
0005433477236	54F360	5525 153217	YAROSLAV SAVELEV	{"email": "savelevy.111960@postgrespro.ru", "phone": "+70242976869"}
0005433477237	C3A4AF	2309 846821	NATALYA AFANASEVA	{"email": "afanasevanatalya1970@postgrespro.ru", "phone": "+70796057309"}
0005433477238	C3A4AF	3642 051062	ANNA MALYSHEVA	{"email": "anna.malysheva-13071976@postgrespro.ru", "phone": "+70497634523"}
0005433477239	C3A4AF	7310 514535	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev.091969@postgrespro.ru", "phone": "+70285445211"}
0005433477240	2F22F9	4981 359382	VIKTOR ANDREEV	{"email": "andreev.viktor_111967@postgrespro.ru", "phone": "+70999990463"}
0005433477241	2F22F9	9389 419119	DMITRIY DMITRIEV	{"email": "dmitrievd13021966@postgrespro.ru", "phone": "+70689047330"}
0005433477242	E97A20	4122 330941	OLGA KAZAKOVA	{"email": "kazakovaolga-1962@postgrespro.ru", "phone": "+70838502445"}
0005433477243	B4BE37	1926 875991	ALEKSANDR GORBUNOV	{"phone": "+70936755964"}
0005433477244	5BAB79	8348 639296	DMITRIY KUZNECOV	{"phone": "+70545354920"}
0005433477245	2A365F	5487 645231	IRINA SEMENOVA	{"phone": "+70451226369"}
0005433477246	3E97CC	7331 273174	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov1974@postgrespro.ru", "phone": "+70089252949"}
0005433477247	3E97CC	1375 660977	VALENTINA STEPANOVA	{"phone": "+70420126837"}
0005433477248	AE6796	8266 714291	YURIY NIKOLAEV	{"email": "nikolaev-y1974@postgrespro.ru", "phone": "+70929350134"}
0005433477249	7895B5	3517 621929	MIKHAIL MIKHAYLOV	{"email": "mikhaylov_mikhail_011977@postgrespro.ru", "phone": "+70954767942"}
0005433477250	F2280E	4689 047744	NADEZHDA SMIRNOVA	{"email": "nadezhda_smirnova.20071967@postgrespro.ru", "phone": "+70122526963"}
0005433477251	30F3A4	2089 142488	KLAVDIYA FROLOVA	{"email": "k_frolova.111973@postgrespro.ru", "phone": "+70790867654"}
0005433477252	6AF0F8	0118 601042	LYUBOV ANDREEVA	{"email": "l.andreeva061972@postgrespro.ru", "phone": "+70134822007"}
0005433477253	2632C3	3202 422639	ELIZAVETA ZHURAVLEVA	{"email": "zhuravleva_elizaveta_1975@postgrespro.ru", "phone": "+70219666319"}
0005433477254	FD303A	2710 035191	TAMARA STEPANOVA	{"phone": "+70502965029"}
0005433477255	FD303A	6097 685339	MARINA KRASNOVA	{"phone": "+70458142304"}
0005433477256	71EAF9	5315 171433	SVETLANA KALININA	{"email": "kalininasvetlana_15081970@postgrespro.ru", "phone": "+70973015769"}
0005433477257	047DDA	2218 072098	TATYANA ANDREEVA	{"phone": "+70720770616"}
0005433477258	047DDA	2148 702468	ALEKSANDRA MOISEEVA	{"email": "moiseevaa-22121972@postgrespro.ru", "phone": "+70258417686"}
0005433477259	0B4D84	9229 809568	PAVEL SAVELEV	{"email": "savelev_p-16011976@postgrespro.ru", "phone": "+70539609358"}
0005433477260	0B4D84	6679 553267	GALINA EGOROVA	{"email": "galina_egorova.1973@postgrespro.ru", "phone": "+70338645887"}
0005433477261	8ADA57	5668 682189	NIKOLAY NIKITIN	{"phone": "+70751830802"}
0005433477262	71B11A	8315 259788	MIKHAIL ABRAMOV	{"email": "abramov.mikhail1967@postgrespro.ru", "phone": "+70138368287"}
0005433477263	71B11A	8601 099069	VADIM ALEKSEEV	{"email": "alekseev_vadim.1978@postgrespro.ru", "phone": "+70532314779"}
0005433477264	FBFA1E	7865 008331	ANDREY KUZNECOV	{"email": "kuznecov-a_22011984@postgrespro.ru", "phone": "+70177151470"}
0005433477265	33E470	3153 675834	RINAT KISELEV	{"email": "kiselevr011969@postgrespro.ru", "phone": "+70799181376"}
0005433477266	33E470	8051 075267	OLGA SEMENOVA	{"email": "semenova-olga041978@postgrespro.ru", "phone": "+70106550921"}
0005433477267	E3855F	9522 583152	NADEZHDA KALININA	{"email": "kalinina-n-051976@postgrespro.ru", "phone": "+70262270460"}
0005433477268	4A0A5A	1957 693025	OLGA DENISOVA	{"email": "olga-denisova_021965@postgrespro.ru", "phone": "+70889311338"}
0005433477269	4A0A5A	9302 965641	DMITRIY TIKHONOV	{"email": "dmitriy.tikhonov-15011975@postgrespro.ru", "phone": "+70065900070"}
0005433477270	4A0A5A	8296 824447	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr_071970@postgrespro.ru", "phone": "+70810883330"}
0005433477271	3D647D	9693 379319	ALEKSANDR KUDRYASHOV	{"phone": "+70458634029"}
0005433477272	04A9EB	3036 093589	DMITRIY ANTONOV	{"email": "dantonov_1961@postgrespro.ru", "phone": "+70955228507"}
0005433477273	313507	3172 626758	PETR DAVYDOV	{"phone": "+70767376440"}
0005433477274	F196E6	5181 792820	PAVEL BELOV	{"email": "belovpavel-1971@postgrespro.ru", "phone": "+70088700797"}
0005433477275	9E8A7D	4633 222530	EVGENIY SAVELEV	{"email": "evgeniy_savelev_1968@postgrespro.ru", "phone": "+70681796800"}
0005433477276	9E8A7D	6381 669916	VASILIY SEMENOV	{"email": "semenovvasiliy_21031971@postgrespro.ru", "phone": "+70153585327"}
0005433477277	9E8A7D	2575 112571	ANNA EFIMOVA	{"email": "a.efimova.121960@postgrespro.ru", "phone": "+70641949787"}
0005433477278	9E8A7D	0296 993122	ALEKSEY SMIRNOV	{"phone": "+70358616608"}
0005433477279	498C98	8531 419709	DIANA MATVEEVA	{"phone": "+70968267206"}
0005433477280	0FD330	1337 354270	ROMAN FOMIN	{"phone": "+70957773439"}
0005433477281	0FD330	9428 532938	SERGEY ALEKSANDROV	{"email": "aleksandrovs_1963@postgrespro.ru", "phone": "+70501847423"}
0005433477282	0FD330	0565 493599	YURIY IVANOV	{"email": "ivanovyuriy051975@postgrespro.ru", "phone": "+70964095632"}
0005433477283	D121AB	6290 193591	GALINA MAKSIMOVA	{"email": "maksimova-galina.091975@postgrespro.ru", "phone": "+70251458141"}
0005433477284	27446A	6356 885109	SERGEY AFANASEV	{"phone": "+70827724430"}
0005433477285	27446A	1094 677813	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy1967@postgrespro.ru", "phone": "+70504197387"}
0005433477286	CBC26A	8595 904324	PAVEL ZHUKOV	{"email": "zhukov_p-1970@postgrespro.ru", "phone": "+70064684107"}
0005433477287	CBC26A	9842 345498	DAVID SERGEEV	{"phone": "+70235368642"}
0005433477288	B06CDE	1188 889428	ARINA MASLOVA	{"email": "maslova-a_1971@postgrespro.ru", "phone": "+70421840671"}
0005433477289	CA9485	3544 696826	LYUDMILA KISELEVA	{"email": "kiseleva_l_101960@postgrespro.ru", "phone": "+70351061802"}
0005433477291	284138	7636 172626	VIKTOR KUZNECOV	{"email": "kuznecov.viktor.03101973@postgrespro.ru", "phone": "+70050398162"}
0005433477292	C56594	3418 245754	VIKTOR ALEKSEEV	{"phone": "+70492297468"}
0005433477293	C56594	2657 528962	NIKOLAY KOROLEV	{"email": "nkorolev.101969@postgrespro.ru", "phone": "+70849443871"}
0005433477294	A24BF3	4989 320578	NATALYA ALEKSEEVA	{"email": "alekseeva.natalya_121970@postgrespro.ru", "phone": "+70508439310"}
0005433477295	A24BF3	5573 666108	EKATERINA ALEKSEEVA	{"email": "alekseeva_ekaterina13051978@postgrespro.ru", "phone": "+70403531740"}
0005433477296	C3C8FF	3344 572485	MARIYA KOMAROVA	{"phone": "+70221070934"}
0005433477297	F6EFD2	2425 095047	GENNADIY ANDREEV	{"email": "andreev_gennadiy-121978@postgrespro.ru", "phone": "+70484538634"}
0005433481250	7A56DE	3730 045596	VALENTINA KISELEVA	{"phone": "+70829170382"}
0005433481027	B87B53	9833 911190	KSENIYA IVANOVA	{"email": "ivanovak-11021966@postgrespro.ru", "phone": "+70631945044"}
0005433481028	B87B53	2720 481293	EKATERINA MAKAROVA	{"phone": "+70485139829"}
0005433481029	2DABC4	3045 770018	PAVEL RODIONOV	{"phone": "+70563990137"}
0005433481030	2DABC4	9068 531694	VASILIY KULIKOV	{"email": "kulikov-vasiliy-021974@postgrespro.ru", "phone": "+70858029593"}
0005433481031	408344	4326 086474	DMITRIY GUSEV	{"email": "d-gusev.041966@postgrespro.ru", "phone": "+70237946517"}
0005433481032	408344	2039 051004	SERGEY OSIPOV	{"email": "osipov.sergey-1969@postgrespro.ru", "phone": "+70146873103"}
0005433481033	F37FA4	0703 740655	LYUBOV ISAEVA	{"phone": "+70305971882"}
0005433481034	F37FA4	2407 573791	GALINA POTAPOVA	{"email": "potapovag-1973@postgrespro.ru", "phone": "+70746863364"}
0005433481035	560164	6983 958602	EVGENIY TIMOFEEV	{"phone": "+70920088780"}
0005433481036	1D9C46	2817 987150	GLEB NAUMOV	{"email": "g-naumov.081979@postgrespro.ru", "phone": "+70651946329"}
0005433481037	1D9C46	8352 491344	LARISA FILATOVA	{"phone": "+70796531868"}
0005433481038	549168	6450 539035	LYUDMILA KONOVALOVA	{"phone": "+70565426060"}
0005433481039	81F44F	9179 115405	ALEKSANDR FOMIN	{"phone": "+70603285862"}
0005433481040	ED32B9	5426 208116	LYUBOV RYABOVA	{"phone": "+70021991577"}
0005433481041	2C98B7	6383 700368	ROMAN IVANOV	{"email": "ivanovr-1981@postgrespro.ru", "phone": "+70507676319"}
0005433481042	2C98B7	4698 334266	ANASTASIYA ZOTOVA	{"email": "zotova_anastasiya.1978@postgrespro.ru", "phone": "+70287843283"}
0005433481043	2C98B7	4720 028603	NATALYA SOROKINA	{"phone": "+70873769587"}
0005433481044	26D60F	4949 718544	VERA KUZMINA	{"phone": "+70245836363"}
0005433481045	26D60F	5023 814443	IGOR ZHURAVLEV	{"email": "igor.zhuravlev-1968@postgrespro.ru", "phone": "+70637403334"}
0005433481046	78E4E2	8316 231762	MARIYA ZAYCEVA	{"phone": "+70642959939"}
0005433481047	7B2BCC	5786 158912	TATYANA KUZNECOVA	{"phone": "+70410637143"}
0005433481048	7B2BCC	8991 267756	VALERIY MAKSIMOV	{"phone": "+70001589925"}
0005433481049	C23084	2012 226754	LYUBOV IVANOVA	{"phone": "+70431759491"}
0005433481050	C23084	9000 293743	VYACHESLAV ANDREEV	{"email": "vyacheslavandreev121967@postgrespro.ru", "phone": "+70728740853"}
0005433481051	EAD57A	6739 890948	LILIYA KOROLEVA	{"phone": "+70758824283"}
0005433481052	185E44	8760 792740	OLGA SIDOROVA	{"email": "sidorovao_071970@postgrespro.ru", "phone": "+70121956976"}
0005433481053	EFA9B6	5583 859099	VASILIY MATVEEV	{"email": "matveev.vasiliy011973@postgrespro.ru", "phone": "+70660732814"}
0005433481054	4F6882	6277 759749	YULIYA EGOROVA	{"email": "yuliya_egorova.30051965@postgrespro.ru", "phone": "+70262574505"}
0005433481055	D051B8	7411 827391	ZOYA EGOROVA	{"phone": "+70212983868"}
0005433481056	3BFEA9	5379 219927	EVGENIY KOROLEV	{"email": "ekorolev121972@postgrespro.ru", "phone": "+70386269685"}
0005433481057	3BFEA9	4259 011708	EVGENIY MEDVEDEV	{"phone": "+70655683773"}
0005433481058	748D13	3848 024707	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr-091978@postgrespro.ru", "phone": "+70343232379"}
0005433481059	748D13	6066 431053	ZHANNA DENISOVA	{"phone": "+70478354804"}
0005433481060	579828	3252 584648	ROMAN ORLOV	{"email": "rorlov_15111964@postgrespro.ru", "phone": "+70614428830"}
0005433481061	579828	2617 471747	POLINA VOROBEVA	{"email": "polina-vorobeva071974@postgrespro.ru", "phone": "+70995448775"}
0005433481062	6EEF02	8033 882278	VALENTINA KOROLEVA	{"phone": "+70553641049"}
0005433481063	6EEF02	7929 724879	OLGA MIKHAYLOVA	{"email": "omikhaylova_081964@postgrespro.ru", "phone": "+70331996442"}
0005433481064	18E6B1	9323 740804	TATYANA NESTEROVA	{"phone": "+70384470605"}
0005433481065	18E6B1	9592 442859	PETR ZHURAVLEV	{"phone": "+70791802449"}
0005433481066	C85BFD	5115 022867	LYUBOV CHERNOVA	{"phone": "+70220189325"}
0005433481067	D623D2	3504 067233	YAROSLAV NIKITIN	{"email": "y.nikitin_091969@postgrespro.ru", "phone": "+70069993253"}
0005433481068	06FCE2	1560 044978	GALINA POPOVA	{"phone": "+70807835271"}
0005433481069	1DA0D9	5267 401206	OKSANA ORLOVA	{"phone": "+70781260993"}
0005433481070	39B464	4851 029083	EKATERINA BELOVA	{"email": "belova-e-051967@postgrespro.ru", "phone": "+70483814299"}
0005433481071	F7687E	9944 394747	GALINA KUZMINA	{"phone": "+70233471783"}
0005433481072	15456D	0454 100015	SERGEY ROMANOV	{"email": "romanov_sergey30061961@postgrespro.ru", "phone": "+70909551005"}
0005433481073	61E993	1987 733689	NADEZHDA NAZAROVA	{"email": "n-nazarova-19111971@postgrespro.ru", "phone": "+70638899089"}
0005433481074	484F94	9787 174020	PETR FEDOTOV	{"email": "petrfedotov-11111963@postgrespro.ru", "phone": "+70120649815"}
0005433481075	484F94	4496 187132	IRINA MELNIKOVA	{"phone": "+70983132547"}
0005433481076	89B76C	2262 237750	IVAN GAVRILOV	{"email": "igavrilov071980@postgrespro.ru", "phone": "+70064769644"}
0005433481077	89B76C	0315 441970	NADEZHDA ZAYCEVA	{"email": "nadezhda.zayceva011973@postgrespro.ru", "phone": "+70257611547"}
0005433481078	AA63B7	4522 585673	ANZHELA LEBEDEVA	{"email": "lebedeva_anzhela21061977@postgrespro.ru", "phone": "+70942639950"}
0005433481079	38AF8B	2064 763609	ANASTASIYA ANDREEVA	{"email": "anastasiyaandreeva-1968@postgrespro.ru", "phone": "+70954375771"}
0005433481080	38AF8B	4127 624586	VLADIMIR MEDVEDEV	{"phone": "+70176915612"}
0005433481081	A3B5CF	8183 198874	KLAVDIYA MATVEEVA	{"phone": "+70009496732"}
0005433481082	9323D0	5095 445768	VLADIMIR POPOV	{"email": "vladimir-popov.01031977@postgrespro.ru", "phone": "+70215433751"}
0005433481083	0F8AF3	1372 701577	ANNA OVCHINNIKOVA	{"email": "ovchinnikovaanna-08101973@postgrespro.ru", "phone": "+70448603030"}
0005433481084	0A7A97	1797 486946	INNA FEDOROVA	{"phone": "+70973039716"}
0005433481085	5FB267	6793 597223	TATYANA LUKYANOVA	{"email": "t.lukyanova1987@postgrespro.ru", "phone": "+70521176052"}
0005433481086	5FB267	8368 928395	ELENA SMIRNOVA	{"email": "elena-smirnova.1965@postgrespro.ru", "phone": "+70299331196"}
0005433481087	5FB267	4023 997217	LIDIYA SEMENOVA	{"phone": "+70439928992"}
0005433481088	319B03	1024 271418	LIDIYA KARPOVA	{"phone": "+70517622747"}
0005433481089	CECC95	8253 727186	LYUDMILA TARASOVA	{"email": "tarasova-lyudmila.1976@postgrespro.ru", "phone": "+70418242338"}
0005433481090	CECC95	8497 101214	EKATERINA SMIRNOVA	{"phone": "+70822483186"}
0005433481091	B3291B	5982 618938	OLGA FILIPPOVA	{"phone": "+70371748417"}
0005433481092	19B775	4798 204845	ALEKSANDR SEMENOV	{"phone": "+70171917106"}
0005433481093	89578C	1078 565809	DAMIR MAKAROV	{"email": "d-makarov_1974@postgrespro.ru", "phone": "+70718729508"}
0005433481094	E8B758	7234 720497	OKSANA ROMANOVA	{"email": "romanova.o111959@postgrespro.ru", "phone": "+70173454230"}
0005433481095	867A5F	6115 439296	ELENA MOROZOVA	{"email": "e_morozova111963@postgrespro.ru", "phone": "+70336027271"}
0005433481096	93C997	9974 031720	MAKSIM STEPANOV	{"phone": "+70305362481"}
0005433481097	6AEC9D	1733 720677	VALENTINA OSIPOVA	{"phone": "+70246583934"}
0005433481098	B96ABD	3411 935938	ANNA MIRONOVA	{"email": "mironovaa_1977@postgrespro.ru", "phone": "+70311093647"}
0005433481099	BB5671	9536 836979	ALEKSANDR KISELEV	{"phone": "+70351408502"}
0005433481100	BB5671	4460 653835	NATALIYA POPOVA	{"email": "popovanataliya-091985@postgrespro.ru", "phone": "+70163047901"}
0005433481101	1FAC32	6067 042524	MARIYA STEPANOVA	{"phone": "+70193263888"}
0005433481102	1D9784	2489 957659	NATALYA SOLOVEVA	{"phone": "+70843853514"}
0005433481103	0690EE	7689 025275	DMITRIY KOZLOV	{"email": "dmitriy.kozlov1979@postgrespro.ru", "phone": "+70461727117"}
0005433481104	1C1E63	6790 114033	MARIYA ISAEVA	{"phone": "+70654246568"}
0005433481105	1C1E63	9552 813045	VADIM FILIPPOV	{"email": "v.filippov091970@postgrespro.ru", "phone": "+70039729157"}
0005433481106	E6C1CA	6692 781462	ELENA ARKHIPOVA	{"phone": "+70502391556"}
0005433481107	B8A7C4	0010 882445	TATYANA VASILEVA	{"email": "vasilevatatyana_10061976@postgrespro.ru", "phone": "+70548899312"}
0005433481108	A5D03C	3299 907306	VLADIMIR ZAKHAROV	{"email": "zakharovv101971@postgrespro.ru", "phone": "+70668307750"}
0005433481109	6705C4	3769 602068	VLADIMIR SOKOLOV	{"phone": "+70677622082"}
0005433481110	6705C4	2249 801142	KSENIYA STEPANOVA	{"email": "kseniya-stepanova101972@postgrespro.ru", "phone": "+70038804896"}
0005433481111	56AEDA	0139 774606	LYUDMILA ARKHIPOVA	{"phone": "+70994576769"}
0005433481112	56AEDA	3938 868449	SERGEY MOISEEV	{"email": "sergey_moiseev1970@postgrespro.ru", "phone": "+70710999484"}
0005433481113	416259	2108 727600	TAMARA KUZMINA	{"email": "kuzmina-tamara_1976@postgrespro.ru", "phone": "+70542629837"}
0005433481114	416259	7825 384882	VIKTOR SMIRNOV	{"phone": "+70992095909"}
0005433481115	388BFC	3159 790729	NIKOLAY TIMOFEEV	{"phone": "+70078533098"}
0005433481116	136D6D	5652 342057	ANASTASIYA ISAEVA	{"phone": "+70847061091"}
0005433481117	136D6D	6593 997403	ILDAR GUSEV	{"phone": "+70918275672"}
0005433481118	4CECD5	0391 704757	VIKTOR BELOV	{"email": "viktor_belov.16121967@postgrespro.ru", "phone": "+70709132038"}
0005433481119	D564A9	0054 781554	VIKTOR BARANOV	{"email": "baranovv-101971@postgrespro.ru", "phone": "+70957905934"}
0005433481120	510622	0626 428612	VYACHESLAV MEDVEDEV	{"email": "v.medvedev.07111973@postgrespro.ru", "phone": "+70380122500"}
0005433481121	C88A40	5352 508187	ALENA MOROZOVA	{"email": "alenamorozova.031975@postgrespro.ru", "phone": "+70501076241"}
0005433481122	CB6D06	0935 976373	TAMARA STEPANOVA	{"email": "tamarastepanova_061971@postgrespro.ru", "phone": "+70253405719"}
0005433481123	E2E6F0	4429 069730	ANASTASIYA KUZNECOVA	{"email": "kuznecova_anastasiya-18111986@postgrespro.ru", "phone": "+70189497991"}
0005433481124	6C1618	8972 637022	ALEKSANDR KUZNECOV	{"phone": "+70190107478"}
0005433481125	B14D4F	1628 367755	EKATERINA SMIRNOVA	{"email": "smirnovaekaterina-20111973@postgrespro.ru", "phone": "+70435640611"}
0005433481126	8C98B7	5998 632860	ANASTASIYA KUZNECOVA	{"email": "kuznecova-anastasiya_081988@postgrespro.ru", "phone": "+70786739912"}
0005433481127	26B2D0	0450 450804	ANDREY CHERNOV	{"email": "a_chernov1968@postgrespro.ru", "phone": "+70280217579"}
0005433481128	C86521	1447 673195	ELIZAVETA OSIPOVA	{"phone": "+70079559304"}
0005433481129	DB6376	6017 413993	MARINA ALEKSEEVA	{"email": "alekseeva.marina121971@postgrespro.ru", "phone": "+70879254764"}
0005433481130	DB6376	5702 462234	VADIM SIDOROV	{"phone": "+70320904138"}
0005433481131	DB6376	2594 014596	NATALYA POPOVA	{"email": "natalya.popova15101987@postgrespro.ru", "phone": "+70402220654"}
0005433481132	31C84E	4085 376605	VALENTINA EFIMOVA	{"phone": "+70282652903"}
0005433481133	757193	0178 892231	MATVEY FEDOROV	{"email": "matvey-fedorov_041973@postgrespro.ru", "phone": "+70679839367"}
0005433481134	6ED734	8093 183710	ANGELINA NAZAROVA	{"phone": "+70911577262"}
0005433481135	96F3C4	9581 458542	OLGA PETROVA	{"email": "petrova_olga.1970@postgrespro.ru", "phone": "+70846879610"}
0005433481136	96F3C4	1038 679673	VALENTINA MOROZOVA	{"email": "morozovavalentina.08111974@postgrespro.ru", "phone": "+70504492731"}
0005433481137	E18B32	1369 654995	ALEKSEY NAZAROV	{"email": "nazarova101973@postgrespro.ru", "phone": "+70695301673"}
0005433481138	6E0055	1716 241381	ALINA FROLOVA	{"email": "frolova-alina_24081964@postgrespro.ru", "phone": "+70136366415"}
0005433481139	6E0055	8473 512660	VIKTOR KULIKOV	{"phone": "+70371941607"}
0005433481140	79169D	7375 624981	VERA SMIRNOVA	{"email": "v.smirnova-1956@postgrespro.ru", "phone": "+70222749976"}
0005433481141	79169D	3400 103554	VASILIY MOROZOV	{"phone": "+70179699604"}
0005433481142	79169D	9996 956755	VIKTOR IVANOV	{"phone": "+70513406046"}
0005433481143	AAA7DF	5729 366145	YURIY PAVLOV	{"email": "pavlovyuriy_25081983@postgrespro.ru", "phone": "+70329502728"}
0005433481144	BE185E	2087 097830	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr.101969@postgrespro.ru", "phone": "+70436174281"}
0005433481145	F08DF5	3938 133990	AZAT NAZAROV	{"email": "azat_nazarov1983@postgrespro.ru", "phone": "+70563441781"}
0005433481146	F08DF5	9384 206123	ANNA ZAKHAROVA	{"email": "zakharovaanna.1977@postgrespro.ru", "phone": "+70087241970"}
0005433481147	EBB494	5576 848577	VIKTOR YAKOVLEV	{"phone": "+70139158150"}
0005433481148	BDD953	1236 750916	IVAN VOLKOV	{"email": "volkov-ivan_1980@postgrespro.ru", "phone": "+70282144339"}
0005433481149	BDD953	1046 847998	YURIY ROMANOV	{"phone": "+70422769864"}
0005433481150	BDD953	1026 267631	ELENA NIKITINA	{"phone": "+70546896088"}
0005433481151	BDD953	8799 708170	LYUDMILA ANTONOVA	{"phone": "+70256009779"}
0005433481152	B3FE8E	5422 486008	ALEKSANDR KUZMIN	{"email": "kuzmin_a.02101977@postgrespro.ru", "phone": "+70070714829"}
0005433481153	45C37C	5710 552748	TAISIYA MATVEEVA	{"email": "t_matveeva24021970@postgrespro.ru", "phone": "+70955896652"}
0005433481154	22E643	7335 964001	ALEKSANDR KOZLOV	{"phone": "+70219840514"}
0005433481155	F85377	2106 097224	MAKSIM BONDARENKO	{"email": "maksimbondarenko.1975@postgrespro.ru", "phone": "+70787406200"}
0005433481156	32BCF4	8364 525615	VALENTINA KUZNECOVA	{"phone": "+70734943254"}
0005433481157	4762DA	6949 762221	SERGEY FEDOROV	{"email": "fedorov_sergey-061974@postgrespro.ru", "phone": "+70934897703"}
0005433481158	A15C6E	2215 756407	ANNA AKIMOVA	{"email": "akimova.anna_03051969@postgrespro.ru", "phone": "+70256253118"}
0005433481159	A15C6E	1210 590852	ALEKSANDRA FEDOROVA	{"phone": "+70892013327"}
0005433481160	3E1312	3264 361196	ALENA NIKOLAEVA	{"email": "a.nikolaeva10031989@postgrespro.ru", "phone": "+70264668593"}
0005433481161	3E1312	1784 291436	ANDREY GORBUNOV	{"phone": "+70092051782"}
0005433481162	968BDA	9199 633976	KSENIYA ANDREEVA	{"email": "andreevakseniya1978@postgrespro.ru", "phone": "+70826125556"}
0005433481163	968BDA	5774 307677	LYUDMILA CHERNOVA	{"phone": "+70483196330"}
0005433481164	E125DF	9850 709618	IVAN PAVLOV	{"email": "pavlov.ivan.1977@postgrespro.ru", "phone": "+70947105776"}
0005433481165	1C982D	0990 302329	GULNARA BELOVA	{"email": "gulnara_belova-1981@postgrespro.ru", "phone": "+70722965821"}
0005433481166	4A4807	5464 571329	VLADISLAV ZAKHAROV	{"phone": "+70581198396"}
0005433481167	2CD703	4200 883399	YURIY DAVYDOV	{"email": "davydov-yuriy_061965@postgrespro.ru", "phone": "+70356050882"}
0005433481168	2CD703	2482 960032	DENIS KARPOV	{"email": "karpov_denis-1980@postgrespro.ru", "phone": "+70120318063"}
0005433481169	69B782	7369 636260	GEVORG VLASOV	{"email": "g.vlasov-08081967@postgrespro.ru", "phone": "+70213537053"}
0005433481170	A339FE	4179 118951	ANNA FILIPPOVA	{"phone": "+70507576208"}
0005433481171	6C91B4	5656 021185	ALEKSANDR TIKHONOV	{"phone": "+70661117406"}
0005433481172	959031	0983 834839	EVGENIY CHERNOV	{"phone": "+70614052890"}
0005433481173	06001B	9236 234704	ELENA SEMENOVA	{"email": "semenova_e.26101966@postgrespro.ru", "phone": "+70103081248"}
0005433481174	80E770	8457 415393	NIKOLAY MIKHAYLOV	{"phone": "+70498616504"}
0005433481175	80E770	1733 015095	IVAN MAKAROV	{"phone": "+70668540768"}
0005433481176	10FC10	1236 598835	ELENA ERMAKOVA	{"phone": "+70034546400"}
0005433481177	5FE39F	3556 052539	NIKOLAY TIMOFEEV	{"email": "n.timofeev_041974@postgrespro.ru", "phone": "+70010615428"}
0005433481178	5FE39F	7130 108762	SVETLANA GORBUNOVA	{"email": "s_gorbunova10081964@postgrespro.ru", "phone": "+70970449630"}
0005433481179	EE1AFB	1936 239703	TATYANA LUKYANOVA	{"phone": "+70353141120"}
0005433481180	EE1AFB	2592 080002	YANA MEDVEDEVA	{"phone": "+70035271721"}
0005433481181	C6C1B5	9787 499011	VIKTOR BELOV	{"phone": "+70842494490"}
0005433481182	C6C1B5	5523 176742	NADEZHDA MAKSIMOVA	{"email": "nadezhda_maksimova071966@postgrespro.ru", "phone": "+70395401560"}
0005433481183	9F4C3D	1839 140494	VADIM SMIRNOV	{"phone": "+70681127154"}
0005433481184	9F4C3D	4642 405149	GALINA DANILOVA	{"email": "g.danilova-19051977@postgrespro.ru", "phone": "+70257437254"}
0005433481185	884002	3776 245457	VARVARA RODIONOVA	{"phone": "+70576987622"}
0005433481186	181EFC	1681 215880	MIKHAIL MAKAROV	{"phone": "+70478620327"}
0005433481187	181EFC	1363 897118	LYUBOV LUKYANOVA	{"phone": "+70683403320"}
0005433481188	05DCB5	9774 975856	VLADIMIR ANDREEV	{"email": "andreev.vladimir1983@postgrespro.ru", "phone": "+70591200486"}
0005433481189	48C132	3658 553847	POLINA KUZNECOVA	{"phone": "+70327174106"}
0005433481190	E223D6	2926 159955	GALINA KOVALEVA	{"phone": "+70261372693"}
0005433481191	E223D6	3667 793061	NIKOLAY MIRONOV	{"phone": "+70644205736"}
0005433481192	7F4B22	0224 893306	ARTEM MIKHAYLOV	{"phone": "+70254816271"}
0005433481193	EA90B9	9099 932614	MIKHAIL POPOV	{"phone": "+70932011076"}
0005433481194	E17854	4408 892800	EVGENIYA KONDRATEVA	{"email": "kondratevae_1974@postgrespro.ru", "phone": "+70528418577"}
0005433481195	7D49F9	7378 834016	VALENTINA BORISOVA	{"email": "v_borisova_30061971@postgrespro.ru", "phone": "+70920506602"}
0005433481196	7D49F9	1128 499957	NATALYA ISAEVA	{"phone": "+70053155277"}
0005433481197	7D49F9	6965 943110	ALEKSANDR PETROV	{"email": "petrov_aleksandr111960@postgrespro.ru", "phone": "+70626348918"}
0005433481198	0C2F49	4259 205691	IRINA SAVELEVA	{"phone": "+70162748686"}
0005433481199	644D01	0838 382760	NATALYA ANDREEVA	{"phone": "+70585576476"}
0005433481200	644D01	8252 934537	IRINA KUZNECOVA	{"email": "irina_kuznecova-03021962@postgrespro.ru", "phone": "+70480669007"}
0005433481201	31CA80	6377 245518	VLADIMIR DAVYDOV	{"email": "vladimir.davydov-20051961@postgrespro.ru", "phone": "+70864692581"}
0005433481202	31CA80	1827 006359	YULIYA POLYAKOVA	{"email": "polyakova_yuliya.10051980@postgrespro.ru", "phone": "+70188581259"}
0005433481203	01944F	9777 715460	ASKAR SOROKIN	{"phone": "+70078673107"}
0005433481204	687E15	0571 390335	STANISLAV NIKITIN	{"email": "nikitin_stanislav-051975@postgrespro.ru", "phone": "+70163812415"}
0005433481205	687E15	8733 356682	VERONIKA KUDRYASHOVA	{"phone": "+70652798024"}
0005433481206	AC6403	2677 208192	LYUBOV NAUMOVA	{"phone": "+70266165802"}
0005433481207	AC6403	3330 458724	ELENA ANDREEVA	{"email": "andreevaelena-1971@postgrespro.ru", "phone": "+70841023157"}
0005433481208	E817E9	4687 653545	ANTONINA KALININA	{"email": "kalinina.a-111974@postgrespro.ru", "phone": "+70505977407"}
0005433481209	46AB35	7900 589298	YULIYA ROMANOVA	{"email": "romanova_yuliya-021977@postgrespro.ru", "phone": "+70252217411"}
0005433481210	46AB35	6096 706833	SVETLANA KOMAROVA	{"phone": "+70232160112"}
0005433481211	924064	9702 402715	KONSTANTIN KISELEV	{"email": "kiselev.konstantin_1979@postgrespro.ru", "phone": "+70904252720"}
0005433481212	727A81	9457 478027	ARTEM MEDVEDEV	{"email": "a-medvedev_051971@postgrespro.ru", "phone": "+70277357316"}
0005433481213	CCE29D	7005 930362	IGOR GUSEV	{"email": "i.gusev_1987@postgrespro.ru", "phone": "+70962253848"}
0005433481214	ADC1AF	2109 828065	PAVEL MELNIKOV	{"email": "melnikov-pavel.28121969@postgrespro.ru", "phone": "+70885581009"}
0005433481215	ADC1AF	3961 463063	ELENA BOGDANOVA	{"phone": "+70768836136"}
0005433481216	ADC1AF	1302 191526	NADEZHDA ZAKHAROVA	{"phone": "+70711712322"}
0005433481217	9EC1EA	3812 020218	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey-061976@postgrespro.ru", "phone": "+70664767239"}
0005433481218	7415AA	1372 186461	VASILIY ZAKHAROV	{"phone": "+70696752597"}
0005433481219	7415AA	5269 557129	MARINA SEMENOVA	{"phone": "+70492202997"}
0005433481220	7415AA	4180 962816	MARIYA ROMANOVA	{"email": "mariyaromanova-041970@postgrespro.ru", "phone": "+70683803778"}
0005433481221	A7F0A8	7960 596165	NADEZHDA GERASIMOVA	{"email": "nadezhda-gerasimova-08121979@postgrespro.ru", "phone": "+70372438550"}
0005433481222	A7F0A8	4237 909991	NIKOLAY SOLOVEV	{"phone": "+70493507681"}
0005433481223	A7F0A8	5326 740833	ALEKSANDR ILIN	{"phone": "+70703010215"}
0005433481224	60211C	1966 531558	DMITRIY VOLKOV	{"email": "volkov_dmitriy03041961@postgrespro.ru", "phone": "+70759811155"}
0005433481225	B69E3D	8225 238476	NIKITA EGOROV	{"email": "egorov_n1974@postgrespro.ru", "phone": "+70288346900"}
0005433481226	582F77	1240 709166	SERGEY SHEVCHENKO	{"phone": "+70515952016"}
0005433481227	582F77	5792 684019	ALINA ROMANOVA	{"email": "alina.romanova21101965@postgrespro.ru", "phone": "+70719148706"}
0005433481228	582F77	5469 634107	OLGA KALININA	{"phone": "+70837237039"}
0005433481229	051BDD	1531 372100	NATALYA PAVLOVA	{"phone": "+70282105202"}
0005433481230	1A1776	7377 333058	NADEZHDA ANDREEVA	{"phone": "+70378009262"}
0005433481231	19709B	5670 252964	VALERIY KUZNECOV	{"email": "kuznecov_v_031977@postgrespro.ru", "phone": "+70699275213"}
0005433481232	19709B	9930 915655	TATYANA CHERNOVA	{"email": "t_chernova.08041975@postgrespro.ru", "phone": "+70142457591"}
0005433481233	318B48	4502 198966	ILNUR ZAYCEV	{"email": "ilnur.zaycev.091976@postgrespro.ru", "phone": "+70637118908"}
0005433481234	24A560	1988 997216	NATALYA MEDVEDEVA	{"email": "natalya.medvedeva-011973@postgrespro.ru", "phone": "+70377661010"}
0005433481235	24A560	9825 705733	SABINA KOZLOVA	{"phone": "+70744687335"}
0005433481236	9A7C9E	2836 302400	YULIYA NAUMOVA	{"email": "naumova_y_1958@postgrespro.ru", "phone": "+70175822825"}
0005433481237	9A7C9E	2223 664342	BOGDAN KARPOV	{"phone": "+70635308084"}
0005433481238	C5F282	1915 589484	TATYANA POTAPOVA	{"email": "t.potapova.12071963@postgrespro.ru", "phone": "+70558836806"}
0005433481239	C5F282	5746 041712	IGOR KUZNECOV	{"email": "kuznecov-i.081969@postgrespro.ru", "phone": "+70410017432"}
0005433481240	E66400	7456 049107	KIRILL MAKAROV	{"email": "makarov.kirill.1970@postgrespro.ru", "phone": "+70856892756"}
0005433481241	1A465D	3101 407640	ZINAIDA ZHUKOVA	{"phone": "+70377366295"}
0005433481244	CB1D6C	1210 098555	VLADIMIR MAKAROV	{"phone": "+70767590235"}
0005433481245	CB1D6C	0885 189870	LARISA ZOTOVA	{"email": "lzotova1984@postgrespro.ru", "phone": "+70999595930"}
0005433481246	A98590	6796 238834	ALEKSANDR FOMIN	{"phone": "+70453019059"}
0005433481247	22EDB2	2811 774219	NIKOLAY ZHUKOV	{"email": "zhukovnikolay1964@postgrespro.ru", "phone": "+70699161992"}
0005433481248	22EDB2	2197 150432	TAISIYA VOLKOVA	{"email": "volkovataisiya-1976@postgrespro.ru", "phone": "+70160064845"}
0005433481249	8FDA6B	2288 242605	ANTON KULIKOV	{"email": "anton.kulikov-071981@postgrespro.ru", "phone": "+70968604081"}
0005433481251	7A56DE	1852 373478	EVGENIY ALEKSEEV	{"phone": "+70518593233"}
0005433481252	7395FF	2079 922445	ALEKSEY ROMANOV	{"phone": "+70511007521"}
0005433481253	ECB3A6	9519 599661	MAKSIM TIMOFEEV	{"email": "maksim.timofeev-121975@postgrespro.ru", "phone": "+70221836618"}
0005433481254	6B3264	6391 498728	IGOR POPOV	{"email": "igor.popov091977@postgrespro.ru", "phone": "+70922118442"}
0005433481255	40294C	0059 791920	TATYANA TIKHONOVA	{"phone": "+70569248239"}
0005433481256	119727	9866 032825	SERGEY BORISOV	{"email": "borisov-s_29021968@postgrespro.ru", "phone": "+70124365848"}
0005433481257	51C4B2	4932 317131	ANDREY SIDOROV	{"phone": "+70919633356"}
0005433481258	37D047	5892 500319	LYUBOV ZHURAVLEVA	{"email": "lyubov_zhuravleva_1975@postgrespro.ru", "phone": "+70799999472"}
0005433481259	43CDF4	9450 468562	EKATERINA KOROLEVA	{"email": "e_koroleva.121985@postgrespro.ru", "phone": "+70730642641"}
0005433481260	75DD4A	7390 842790	NINA MOROZOVA	{"phone": "+70252503027"}
0005433481261	75DD4A	7594 350419	ELENA AFANASEVA	{"email": "afanaseva-e-111966@postgrespro.ru", "phone": "+70025209217"}
0005433481262	1DB698	9054 190945	OLGA SERGEEVA	{"email": "o-sergeeva21081966@postgrespro.ru", "phone": "+70946072336"}
0005433481263	3E42FD	0470 775986	MARINA POPOVA	{"phone": "+70683549077"}
0005433481264	3E42FD	9002 007805	IRINA ZHUKOVA	{"email": "irina.zhukova081970@postgrespro.ru", "phone": "+70521381850"}
0005433481265	CAF978	2105 731736	ELENA YUDINA	{"phone": "+70397074178"}
0005433481266	CAF978	9434 796237	OLGA ORLOVA	{"email": "orlova.olga-041972@postgrespro.ru", "phone": "+70520125604"}
0005433481267	050159	5567 957219	DMITRIY BORISOV	{"phone": "+70917121858"}
0005433481268	1611DB	4854 453805	VYACHESLAV KRASNOV	{"email": "krasnovv.011973@postgrespro.ru", "phone": "+70256996421"}
0005433481269	1611DB	5964 429666	GALINA MAKAROVA	{"phone": "+70721193913"}
0005433481270	0769AB	4666 406686	NATALYA GERASIMOVA	{"email": "natalya.gerasimova_1967@postgrespro.ru", "phone": "+70560787226"}
0005433481271	AA1223	5698 353464	ZINAIDA ANDREEVA	{"phone": "+70872516708"}
0005433481272	2ABE06	8482 212040	SEMEN SOROKIN	{"email": "s-sorokin_021976@postgrespro.ru", "phone": "+70743189717"}
0005433481273	6815AF	3029 595512	NADEZHDA KUZNECOVA	{"email": "kuznecova-n051968@postgrespro.ru", "phone": "+70710088167"}
0005433481274	80F268	4958 523935	ALEKSANDR PETROV	{"phone": "+70331995265"}
0005433481275	7EAEF8	4172 234898	ANNA SAVELEVA	{"email": "a_saveleva.021981@postgrespro.ru", "phone": "+70771947752"}
0005433481276	0BF6F5	6704 039621	IRINA KUZNECOVA	{"phone": "+70485048767"}
0005433481277	BAD6FB	2759 959818	RAMIL POPOV	{"email": "ramilpopov-081965@postgrespro.ru", "phone": "+70489277724"}
0005433481278	15F969	1253 603704	ALEKSANDR ALEKSANDROV	{"phone": "+70460336486"}
0005433481279	7702E9	5034 373485	VALENTINA KOVALEVA	{"email": "vkovaleva_1960@postgrespro.ru", "phone": "+70682839385"}
0005433481280	7702E9	7475 431255	MAKSIM TIKHONOV	{"email": "m-tikhonov-111972@postgrespro.ru", "phone": "+70516221364"}
0005433481281	A10850	0254 216758	MIKHAIL NIKOLAEV	{"email": "m-nikolaev.011972@postgrespro.ru", "phone": "+70711292829"}
0005433481282	2D84E3	2931 690012	ALEKSEY SMIRNOV	{"email": "smirnov-aleksey.021975@postgrespro.ru", "phone": "+70942479856"}
0005433481283	BC510F	2406 239079	IRINA POTAPOVA	{"email": "irina.potapova_1975@postgrespro.ru", "phone": "+70213702289"}
0005433481284	BC510F	2700 501971	VALENTIN FEDOTOV	{"email": "v_fedotov-02061966@postgrespro.ru", "phone": "+70200501008"}
0005433481285	28A85F	6408 208090	ANNA KULIKOVA	{"phone": "+70627565461"}
0005433481286	1579EF	0294 917621	MIKHAIL KUZNECOV	{"email": "kuznecov.mikhail_1965@postgrespro.ru", "phone": "+70899894850"}
0005433481287	E333AD	6959 379127	DENIS MATVEEV	{"phone": "+70975045547"}
0005433481288	E0AFD3	7091 670729	TATYANA ALEKSANDROVA	{"email": "aleksandrovat_121968@postgrespro.ru", "phone": "+70745588231"}
0005433481289	36FCB4	4078 461881	ALEKSEY FROLOV	{"email": "frolovaleksey.1983@postgrespro.ru", "phone": "+70673564886"}
0005433481290	36FCB4	2477 805044	ANDREY KUZMIN	{"phone": "+70093230886"}
0005433481291	846F8F	3304 630205	NINA FEDOROVA	{"phone": "+70990731300"}
0005433481292	846F8F	9099 465238	VERA NOVIKOVA	{"phone": "+70644118456"}
0005433481293	D6EC0F	2044 543263	MARINA KULIKOVA	{"phone": "+70545830740"}
0005433481294	BEC336	7841 323438	MARGARITA KUZMINA	{"phone": "+70991068426"}
0005433481295	CF337C	7193 311021	VLADIMIR KRASNOV	{"email": "v-krasnov_1978@postgrespro.ru", "phone": "+70403845276"}
0005433481296	CF337C	9279 520180	VLADIMIR KUZMIN	{"email": "kuzminvladimir-17071978@postgrespro.ru", "phone": "+70164654985"}
0005433481297	8EA013	0751 873851	ILYA KUZMIN	{"phone": "+70155944801"}
0005433481298	8EA013	3883 681413	PETR FROLOV	{"email": "petr.frolov.26071969@postgrespro.ru", "phone": "+70990313384"}
0005433481299	3FD506	7210 314814	MATVEY ZAYCEV	{"phone": "+70629091965"}
0005433481300	378610	3930 026355	GENNADIY KULIKOV	{"phone": "+70180839591"}
0005433481301	D65669	4012 803880	LIDIYA NESTEROVA	{"phone": "+70695560895"}
0005433481302	D65669	3682 556321	VALERIY SCHERBAKOV	{"email": "scherbakov-v_011960@postgrespro.ru", "phone": "+70164363310"}
0005433481303	339D74	6468 966894	MARIYA NESTEROVA	{"email": "nesterova-mariya-1974@postgrespro.ru", "phone": "+70702988576"}
0005433481304	848AAB	4961 217752	ARTEM SCHERBAKOV	{"phone": "+70844081214"}
0005433481305	848AAB	6103 576892	YANA KOMAROVA	{"email": "komarova.yana.05121971@postgrespro.ru", "phone": "+70393880204"}
0005433481306	4E9D69	5129 046190	IGOR MARTYNOV	{"email": "martynov-i_011982@postgrespro.ru", "phone": "+70827187531"}
0005433481307	A0D3FA	3393 527477	LEONTIY YAKOVLEV	{"email": "yakovlevl.20031971@postgrespro.ru", "phone": "+70300952420"}
0005433481308	D01185	6323 330333	ZAKHAR POPOV	{"email": "z_popov.22121975@postgrespro.ru", "phone": "+70818572438"}
0005433481309	D01185	5546 112217	NATALYA FILIPPOVA	{"email": "filippova_n.1978@postgrespro.ru", "phone": "+70771209324"}
0005433481310	342E12	5091 650402	OLGA SERGEEVA	{"email": "olgasergeeva-25041970@postgrespro.ru", "phone": "+70016836991"}
0005433481311	342E12	1977 267100	MARIYA EFIMOVA	{"email": "mariya_efimova041971@postgrespro.ru", "phone": "+70713657993"}
0005433481312	342E12	6838 329778	KARINA TROFIMOVA	{"email": "trofimovakarina-15121978@postgrespro.ru", "phone": "+70820696668"}
0005433481313	74977E	6341 445703	VALENTINA ZHUKOVA	{"phone": "+70244517486"}
0005433481314	485C59	4939 405967	ANDREY KAZAKOV	{"phone": "+70235047714"}
0005433481315	565319	2987 032095	VLADISLAV NOVIKOV	{"email": "novikov-vladislav.21041967@postgrespro.ru", "phone": "+70348759602"}
0005433481316	893CFE	3669 119610	SERGEY ALEKSANDROV	{"phone": "+70429911368"}
0005433481317	C1D0AF	9893 235981	ANTONINA ANDREEVA	{"email": "a_andreeva.05031978@postgrespro.ru", "phone": "+70607152239"}
0005433481318	6D4716	0657 099452	ANZHELIKA KRASNOVA	{"email": "a_krasnova_1970@postgrespro.ru", "phone": "+70392917491"}
0005433481319	6D4716	1712 756149	VALENTINA FILIPPOVA	{"phone": "+70763742329"}
0005433481320	A53BE8	2013 938966	OLGA NAUMOVA	{"phone": "+70809041485"}
0005433481321	18428C	9561 575401	SVETLANA GORBUNOVA	{"phone": "+70418443202"}
0005433481322	27FB33	4246 214583	DMITRIY MOISEEV	{"phone": "+70043742474"}
0005433481323	27FB33	9725 968108	MARIYA KALININA	{"phone": "+70017801307"}
0005433481324	2CE96E	1998 317722	VALENTINA NOVIKOVA	{"email": "novikovav-04061959@postgrespro.ru", "phone": "+70966863130"}
0005433481325	DC02D9	2228 554904	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya_1968@postgrespro.ru", "phone": "+70448342112"}
0005433481326	F2B537	9470 575232	ALEKSEY KONOVALOV	{"email": "konovalov.a121964@postgrespro.ru", "phone": "+70376975635"}
0005433481327	B1D3DB	0333 600224	GALINA VOLKOVA	{"phone": "+70020546301"}
0005433481328	B1D3DB	2666 288354	VLADIMIR PETROV	{"email": "petrov_vladimir.1966@postgrespro.ru", "phone": "+70590537317"}
0005433481329	CFA263	2261 389894	LILIYA ZAYCEVA	{"email": "l_zayceva-1977@postgrespro.ru", "phone": "+70615971130"}
0005433481330	9185CA	2664 533126	DARYA IVANOVA	{"email": "ivanova.d1958@postgrespro.ru", "phone": "+70535238796"}
0005433481331	06AEC3	6072 730376	SERGEY NAUMOV	{"phone": "+70504412713"}
0005433481332	1C431B	9271 418636	NINA DENISOVA	{"phone": "+70948241264"}
0005433481333	B24E13	5357 397256	TATYANA MOROZOVA	{"phone": "+70252398859"}
0005433481334	F10C6D	5514 110046	IVAN ZAKHAROV	{"phone": "+70270395984"}
0005433481335	E50918	7231 635907	DANIIL KRASNOV	{"phone": "+70550295270"}
0005433481336	E50918	4519 383937	NATALIYA LEBEDEVA	{"email": "lebedeva.nataliya1980@postgrespro.ru", "phone": "+70844130402"}
0005433481337	E420CE	0522 280724	EKATERINA ROMANOVA	{"email": "romanova-ekaterina.1964@postgrespro.ru", "phone": "+70550622818"}
0005433481338	876EC2	3253 376404	VITALIY POPOV	{"email": "vitaliy.popov_1971@postgrespro.ru", "phone": "+70920835508"}
0005433481339	876EC2	7729 454483	VLADIMIR MOROZOV	{"email": "vladimirmorozov111972@postgrespro.ru", "phone": "+70403402709"}
0005433481340	DA0FED	5797 882936	NIKOLAY SOKOLOV	{"email": "nikolay_sokolov_28051965@postgrespro.ru", "phone": "+70555642887"}
0005433481341	EB5BA5	9135 297305	TATYANA IVANOVA	{"email": "tatyana.ivanova-19051968@postgrespro.ru", "phone": "+70485841174"}
0005433481342	EB5BA5	5743 806180	NADEZHDA ORLOVA	{"phone": "+70897503424"}
0005433481343	400DBB	9530 753269	ALEKSANDRA DMITRIEVA	{"email": "aleksandradmitrieva_1967@postgrespro.ru", "phone": "+70162456028"}
0005433481344	400DBB	9387 654466	LIDIYA STEPANOVA	{"email": "stepanova-l-09091968@postgrespro.ru", "phone": "+70546956566"}
0005433481345	BF5308	3880 207478	NIKOLAY SHEVCHENKO	{"email": "nshevchenko.091986@postgrespro.ru", "phone": "+70258338658"}
0005433481346	5484DF	2718 772719	ANNA CHERNOVA	{"phone": "+70830536702"}
0005433481347	5484DF	6834 393039	ALEKSANDRA NIKOLAEVA	{"email": "nikolaevaaleksandra1969@postgrespro.ru", "phone": "+70607312014"}
0005433481348	E709E9	7759 379137	RAISA YAKOVLEVA	{"phone": "+70203402640"}
0005433481349	8CF112	9903 867907	DMITRIY IVANOV	{"phone": "+70610210028"}
0005433481350	99D5A4	5140 650417	EKATERINA VASILEVA	{"email": "vasileva-e1974@postgrespro.ru", "phone": "+70423103529"}
0005433481351	EE82E6	5719 459630	VALENTINA SIDOROVA	{"phone": "+70463776994"}
0005433481352	26F03E	0553 099865	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a.021975@postgrespro.ru", "phone": "+70583108147"}
0005433481353	B4B6F2	1659 796031	YANA SOLOVEVA	{"phone": "+70319566472"}
0005433481354	BDE5FC	9855 062736	VERA FROLOVA	{"email": "frolova-vera.25091980@postgrespro.ru", "phone": "+70341542910"}
0005433481355	FFD16B	9377 134266	LYUBOV ZAKHAROVA	{"phone": "+70894099538"}
0005433481356	D0DF07	3059 508827	DMITRIY MARTYNOV	{"phone": "+70787125892"}
0005433481357	AB083E	0108 515804	EKATERINA KARPOVA	{"email": "karpova.e27031964@postgrespro.ru", "phone": "+70768600002"}
0005433481358	AB083E	9372 751888	ALEKSEY FROLOV	{"phone": "+70235924730"}
0005433481359	803A9F	2253 763918	TATYANA KUZMINA	{"phone": "+70530947293"}
0005433481360	CD0C83	9437 261634	OLESYA NESTEROVA	{"email": "olesyanesterova_04101980@postgrespro.ru", "phone": "+70752120410"}
0005433481361	56ED6B	3369 771325	ARTEM MIRONOV	{"email": "mironov.artem-011980@postgrespro.ru", "phone": "+70052885925"}
0005433481362	56ED6B	9948 471013	ANNA VOLKOVA	{"phone": "+70522764192"}
0005433481363	FCE990	7886 063073	IRINA SAVELEVA	{"phone": "+70273826348"}
0005433481364	FCE990	8817 334275	YURIY PETROV	{"phone": "+70749185144"}
0005433481365	E7D269	3057 032578	IRINA EGOROVA	{"phone": "+70496618828"}
0005433481366	E7D269	8051 063394	VALENTINA MOROZOVA	{"email": "morozova_v.1973@postgrespro.ru", "phone": "+70435545064"}
0005433481367	66F206	9570 974393	LIDIYA MIKHAYLOVA	{"email": "mikhaylova_lidiya031974@postgrespro.ru", "phone": "+70752061694"}
0005433481368	C40CF5	8366 517943	ALEKSANDR GUSEV	{"phone": "+70714056338"}
0005433481369	C40CF5	9266 224925	VALENTINA SOLOVEVA	{"email": "vsoloveva.111963@postgrespro.ru", "phone": "+70168416215"}
0005433481370	D9DA70	9388 896839	NATALYA GORBUNOVA	{"email": "gorbunova.natalya_1976@postgrespro.ru", "phone": "+70926928570"}
0005433481371	D9DA70	1721 731967	ALEKSANDR ILIN	{"phone": "+70801533009"}
0005433481372	D9DA70	1663 739576	SVETLANA ZAKHAROVA	{"email": "zakharova_s.041982@postgrespro.ru", "phone": "+70319485277"}
0005433481373	273114	4050 864214	POLINA SEMENOVA	{"email": "p-semenova.07071977@postgrespro.ru", "phone": "+70296850245"}
0005433481374	273114	8977 717331	ANDREY KUZNECOV	{"phone": "+70558751725"}
0005433481375	915798	5830 014911	ALIYA EGOROVA	{"phone": "+70841248580"}
0005433481376	D3B70A	8484 450080	VLADIMIR MATVEEV	{"email": "matveev.v_05031969@postgrespro.ru", "phone": "+70625303018"}
0005433481377	7D4C28	5341 981154	ANNA KARPOVA	{"email": "akarpova_1963@postgrespro.ru", "phone": "+70701529152"}
0005433481378	7D4C28	6660 180802	LYUDMILA KUDRYASHOVA	{"phone": "+70331809932"}
0005433481379	279C1C	9007 578776	NATALYA GUSEVA	{"email": "guseva.natalya.1969@postgrespro.ru", "phone": "+70494168470"}
0005433481380	250279	7647 459509	ALEKSANDR KISELEV	{"phone": "+70320770480"}
0005433481381	250279	0156 411238	ANDREY GRIGOREV	{"phone": "+70028586170"}
0005433481382	6DD487	1035 470431	VALERIY DENISOV	{"email": "valeriy-denisov_031974@postgrespro.ru", "phone": "+70204763955"}
0005433481383	6DD487	0262 555370	MAKSIM POPOV	{"email": "popovmaksim.28021975@postgrespro.ru", "phone": "+70963096193"}
0005433481384	6DD14E	5584 843813	DINARA EFIMOVA	{"email": "d.efimova_1979@postgrespro.ru", "phone": "+70742361621"}
0005433481385	2FFA3D	9904 464085	VYACHESLAV SMIRNOV	{"email": "smirnovv-111972@postgrespro.ru", "phone": "+70432611736"}
0005433481386	2FFA3D	9808 336387	NIKOLAY NIKOLAEV	{"email": "nikolaev-n-1964@postgrespro.ru", "phone": "+70774203542"}
0005433496418	075EFD	4533 434991	EKATERINA EFREMOVA	{"phone": "+70523306069"}
0005433496419	075EFD	9522 382325	VLADIMIR VOROBEV	{"email": "vorobev-v.041977@postgrespro.ru", "phone": "+70850623617"}
0005433496420	56AED1	4820 389497	VALERIY KUZNECOV	{"phone": "+70053894381"}
0005433496421	DE54B9	3616 304745	NINA SIDOROVA	{"email": "nina-sidorova_07031977@postgrespro.ru", "phone": "+70268384048"}
0005433496422	B44108	0241 340279	IGOR IVANOV	{"phone": "+70952669751"}
0005433496423	B44108	3779 038121	IVAN PETROV	{"phone": "+70720185409"}
0005433496424	8B12D3	4750 880360	VERA SOKOLOVA	{"email": "verasokolova1974@postgrespro.ru", "phone": "+70925866711"}
0005433496425	DD6A00	8749 608611	MILENA ROMANOVA	{"phone": "+70944360346"}
0005433496426	DD6A00	6752 659674	KIRILL DAVYDOV	{"email": "davydov-k_18031966@postgrespro.ru", "phone": "+70340712851"}
0005433496427	6ABE44	3357 199239	MARIYA IVANOVA	{"phone": "+70006037743"}
0005433496428	6ABE44	0889 787662	ELENA SMIRNOVA	{"phone": "+70916616567"}
0005433496429	8F94DF	3776 190853	KONSTANTIN EGOROV	{"email": "egorov-k_10081969@postgrespro.ru", "phone": "+70234193927"}
0005433496430	0C5BCE	2673 661318	GEORGIY ZHURAVLEV	{"phone": "+70591037017"}
0005433496431	0C5BCE	7133 292913	NINA CHERNOVA	{"email": "nina_chernova_12031973@postgrespro.ru", "phone": "+70493367417"}
0005433496432	ACDD64	8785 484666	ELENA SEMENOVA	{"email": "semenovae_1971@postgrespro.ru", "phone": "+70358707150"}
0005433496433	ACDD64	4597 162499	EDUARD ZHURAVLEV	{"email": "eduard-zhuravlev_061959@postgrespro.ru", "phone": "+70445717041"}
0005433496434	ACDD64	3237 564995	NINA ZAKHAROVA	{"email": "zakharova-n1970@postgrespro.ru", "phone": "+70093439439"}
0005433496435	E84D85	3339 913456	ALLA BOGDANOVA	{"email": "bogdanova-alla_111979@postgrespro.ru", "phone": "+70045538433"}
0005433496436	939F96	7024 138622	ALEKSANDR KAZAKOV	{"phone": "+70810320823"}
0005433496437	F3944C	7824 174771	LYUBOV MASLOVA	{"phone": "+70693144097"}
0005433496438	F3944C	5856 935652	PAVEL VLASOV	{"phone": "+70549171878"}
0005433496439	F3944C	0107 214362	ANATOLIY MAKAROV	{"email": "anatoliy.makarov091968@postgrespro.ru", "phone": "+70611014340"}
0005433496440	835E6F	3096 740726	RAISA KONDRATEVA	{"phone": "+70601586742"}
0005433496441	44B0DC	4651 877569	VALERIY OSIPOV	{"email": "osipov_valeriy.01101978@postgrespro.ru", "phone": "+70294146872"}
0005433496442	44B0DC	9263 802183	ANNA PAVLOVA	{"phone": "+70423065004"}
0005433496443	F71D52	4729 014140	DENIS SHEVCHENKO	{"phone": "+70374845082"}
0005433496444	F71D52	0313 388149	TAISIYA NIKITINA	{"email": "taisiya.nikitina041968@postgrespro.ru", "phone": "+70670021815"}
0005433496445	DB53A5	5953 381738	VALERIY FILIPPOV	{"email": "v_filippov_091970@postgrespro.ru", "phone": "+70230368907"}
0005433496446	ABF698	3011 796085	ELENA GERASIMOVA	{"email": "egerasimova-15121959@postgrespro.ru", "phone": "+70765905523"}
0005433496447	C8CDBD	0570 606261	MARIYA NIKITINA	{"phone": "+70191864817"}
0005433496448	E90F88	6664 715696	IRINA SMIRNOVA	{"phone": "+70417287571"}
0005433496449	E90F88	2799 554277	OKSANA KOROLEVA	{"email": "oksana-koroleva_06011971@postgrespro.ru", "phone": "+70698194212"}
0005433496450	6B4CEF	0624 056595	DMITRIY TIMOFEEV	{"phone": "+70855146633"}
0005433496451	6B4CEF	2058 673773	YURIY FOMIN	{"phone": "+70387407852"}
0005433496452	46D576	7261 096642	SERGEY POPOV	{"email": "popov_s1984@postgrespro.ru", "phone": "+70229183152"}
0005433496453	46D576	9755 281396	ALEKSANDR SOKOLOV	{"phone": "+70098126480"}
0005433496454	49CB9D	7149 828080	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey_1973@postgrespro.ru", "phone": "+70901530576"}
0005433496455	DD6E24	3812 330958	TAMARA FILIPPOVA	{"phone": "+70838966891"}
0005433496456	805A19	4960 204438	VALENTINA ALEKSANDROVA	{"email": "aleksandrova_v_061980@postgrespro.ru", "phone": "+70718162603"}
0005433496457	1285F4	5255 343685	INNA RODIONOVA	{"email": "rodionovainna_051966@postgrespro.ru", "phone": "+70882475225"}
0005433496458	A496F6	2558 067146	VALENTINA MAKSIMOVA	{"email": "maksimova.valentina1982@postgrespro.ru", "phone": "+70574627105"}
0005433496459	5D32F0	7305 483044	VASILISA VOROBEVA	{"email": "vorobeva_vasilisa.101974@postgrespro.ru", "phone": "+70395511237"}
0005433496460	5D32F0	3222 501767	EKATERINA SCHERBAKOVA	{"phone": "+70837620114"}
0005433496461	C82455	0863 295149	LYUBOV ARKHIPOVA	{"phone": "+70904946624"}
0005433496462	C82455	8555 899635	GALINA DAVYDOVA	{"phone": "+70279956170"}
0005433496463	FE53BA	6079 074289	VLADIMIR RODIONOV	{"phone": "+70331169491"}
0005433496464	92EF4D	1946 585815	ZOYA BORISOVA	{"phone": "+70490103332"}
0005433496465	8E4A8D	8297 667905	NINA EGOROVA	{"phone": "+70817344270"}
0005433496466	DF4DD9	1191 619694	MIKHAIL KUDRYASHOV	{"phone": "+70017907643"}
0005433496467	DF4DD9	4282 113756	SVETLANA KAZAKOVA	{"phone": "+70912128999"}
0005433496468	FD09E9	3934 685742	EVDOKIYA SERGEEVA	{"email": "sergeeva.e27011972@postgrespro.ru", "phone": "+70858772775"}
0005433496469	FD09E9	8805 913002	SERGEY SERGEEV	{"email": "ssergeev1976@postgrespro.ru", "phone": "+70691487330"}
0005433496470	F5FF28	4027 197813	ELENA NAZAROVA	{"phone": "+70807517373"}
0005433496471	96E605	1034 881944	SVETLANA GRISHINA	{"email": "grishina-s-081963@postgrespro.ru", "phone": "+70054555408"}
0005433496472	96E605	0343 412078	ANASTASIYA CHERNOVA	{"phone": "+70262892300"}
0005433496473	8635EA	6395 389294	ALEKSANDR ANTONOV	{"email": "antonov-a-1974@postgrespro.ru", "phone": "+70379105403"}
0005433496474	8635EA	9652 709874	SERGEY BONDARENKO	{"email": "s-bondarenko.03051986@postgrespro.ru", "phone": "+70382151492"}
0005433496475	8635EA	0064 658972	ARSENIY ORLOV	{"email": "a-orlov_1979@postgrespro.ru", "phone": "+70014156031"}
0005433496476	A031E3	1704 011495	YURIY KUZNECOV	{"email": "kuznecov.y111973@postgrespro.ru", "phone": "+70048609067"}
0005433496477	A031E3	2828 359496	LYUDMILA VASILEVA	{"email": "vasileva_lyudmila.17051971@postgrespro.ru", "phone": "+70355607787"}
0005433496478	D0DFB7	2396 867740	ALEKSANDR DAVYDOV	{"email": "davydov-a.011984@postgrespro.ru", "phone": "+70690098506"}
0005433496479	D0DFB7	6656 616079	GRIGORIY KRASNOV	{"phone": "+70393656018"}
0005433496480	021B9B	2918 074042	VYACHESLAV ILIN	{"phone": "+70690460662"}
0005433496481	021B9B	4821 669724	IGOR ZHURAVLEV	{"email": "izhuravlev111974@postgrespro.ru", "phone": "+70278949370"}
0005433496482	021B9B	9171 575389	ANNA NOVIKOVA	{"phone": "+70781582644"}
0005433496483	2EB995	6584 862861	EVGENIY TIKHONOV	{"phone": "+70258390485"}
0005433496484	4F1C94	6977 191617	ALEKSANDRA NIKOLAEVA	{"phone": "+70640411317"}
0005433496485	B9A77A	7153 202664	ALEKSANDR NOVIKOV	{"phone": "+70287864942"}
0005433496486	EBD77C	8245 635632	ALEKSEY IVANOV	{"phone": "+70979378855"}
0005433496487	7D0910	8831 377223	VLADIMIR KUZMIN	{"email": "kuzmin-v-1970@postgrespro.ru", "phone": "+70724538482"}
0005433496488	7D0910	7847 512954	SEMEN IVANOV	{"email": "ivanov_s-02051976@postgrespro.ru", "phone": "+70879988821"}
0005433496489	86416B	3142 754191	TATYANA GUSEVA	{"phone": "+70710727677"}
0005433496490	AEF8CC	5794 265387	TATYANA SOKOLOVA	{"phone": "+70363681007"}
0005433496491	AEF8CC	5868 970774	MARINA SERGEEVA	{"email": "m-sergeeva-101965@postgrespro.ru", "phone": "+70220957380"}
0005433496492	AEF8CC	9105 692508	SVETLANA POPOVA	{"phone": "+70087854922"}
0005433496493	ED6E1B	1359 214523	SVETLANA NIKOLAEVA	{"email": "nikolaeva.svetlana061967@postgrespro.ru", "phone": "+70551357470"}
0005433496494	C3A6C2	4880 807612	VITALIY MIRONOV	{"email": "mironov_vitaliy-1961@postgrespro.ru", "phone": "+70797230122"}
0005433496495	C3A6C2	4381 807326	VLADIMIR KRASNOV	{"phone": "+70673220925"}
0005433496496	6BD567	7411 883059	ALINA NESTEROVA	{"email": "alina.nesterova-121973@postgrespro.ru", "phone": "+70349397153"}
0005433496497	70726C	6073 214175	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana-1971@postgrespro.ru", "phone": "+70918318091"}
0005433496498	B2D00D	0278 695952	EVGENIY SHEVCHENKO	{"email": "shevchenkoevgeniy09021966@postgrespro.ru", "phone": "+70522721412"}
0005433496499	B2D00D	3851 835113	VERA SIDOROVA	{"email": "sidorova.vera_1970@postgrespro.ru", "phone": "+70222063557"}
0005433496500	920E6C	3515 207316	VALERIYA EFIMOVA	{"email": "efimova.v20011966@postgrespro.ru", "phone": "+70176449523"}
0005433496501	E1CA2C	1858 633321	ILYA IVANOV	{"phone": "+70244247652"}
0005433496502	A19BB2	2690 289778	IRINA KUZMINA	{"phone": "+70252057424"}
0005433496503	DB9F9E	5926 234268	ALEKSEY SMIRNOV	{"phone": "+70304315276"}
0005433496504	2D9160	6694 989406	ANATOLIY VOROBEV	{"email": "a-vorobev_09081970@postgrespro.ru", "phone": "+70806492243"}
0005433496505	ED8DC8	9678 768933	NATALYA ANTONOVA	{"phone": "+70801422293"}
0005433496506	EF7B93	3583 236921	OKSANA MATVEEVA	{"phone": "+70419432779"}
0005433496507	0DB525	6256 080308	VASILIY TIMOFEEV	{"email": "timofeev.v_031980@postgrespro.ru", "phone": "+70272016560"}
0005433496508	4D2809	7120 339736	VALERIY MELNIKOV	{"email": "melnikov-v-1968@postgrespro.ru", "phone": "+70026570140"}
0005433496509	2CC26D	3495 930447	VALERIY ABRAMOV	{"phone": "+70770028317"}
0005433496510	5F57E9	2781 462802	NINA MAKAROVA	{"phone": "+70984210645"}
0005433496511	3C9596	8298 788947	TARAS ZAKHAROV	{"phone": "+70483117679"}
0005433496512	3C9596	0678 942480	SOFYA KUDRYASHOVA	{"phone": "+70034418430"}
0005433496513	5810C2	1167 923118	VIKTOR KUZMIN	{"email": "kuzminviktor1974@postgrespro.ru", "phone": "+70645076580"}
0005433496514	1DBD1D	9959 870252	NATALYA FEDOROVA	{"email": "fedorovanatalya_1974@postgrespro.ru", "phone": "+70836283063"}
0005433496515	E57E84	5912 891553	LIDIYA FADEEVA	{"email": "fadeeval_06081978@postgrespro.ru", "phone": "+70779541034"}
0005433496516	E57E84	1160 289363	VLADIMIR SOKOLOV	{"phone": "+70296078636"}
0005433496517	0271F2	1877 318162	TATYANA NOVIKOVA	{"phone": "+70235580232"}
0005433496518	7F0726	4429 433963	SERGEY IVANOV	{"phone": "+70694241906"}
0005433496519	44DF49	4143 417496	ALEKSANDR PAVLOV	{"phone": "+70302113466"}
0005433496520	44DF49	8112 735228	PAVEL GAVRILOV	{"phone": "+70545190279"}
0005433496521	991593	2932 357502	VIKTOR MAKAROV	{"email": "makarov_viktor-051984@postgrespro.ru", "phone": "+70911981146"}
0005433496522	991593	2111 169056	SERGEY KUZNECOV	{"email": "kuznecov-sergey-031967@postgrespro.ru", "phone": "+70247782124"}
0005433496523	14F3BE	6517 620606	LYUBOV FILIPPOVA	{"phone": "+70322590077"}
0005433496524	D196E5	8225 510553	TATYANA MEDVEDEVA	{"email": "tmedvedeva.1967@postgrespro.ru", "phone": "+70764199516"}
0005433496525	D196E5	6846 551781	ALEKSEY ANDREEV	{"email": "a-andreev-28041971@postgrespro.ru", "phone": "+70091334255"}
0005433496526	064C5D	4423 650440	ANDREY FEDOTOV	{"email": "fedotov-a_101975@postgrespro.ru", "phone": "+70823511543"}
0005433496527	284104	8264 290929	ROMAN KUZMIN	{"email": "roman.kuzmin.05091977@postgrespro.ru", "phone": "+70602782914"}
0005433496528	B88652	3311 757826	VALENTINA IVANOVA	{"email": "v-ivanova.101967@postgrespro.ru", "phone": "+70315815920"}
0005433496529	C08BE0	8169 831182	TATYANA BELOVA	{"phone": "+70005646989"}
0005433496530	90A65F	5711 796957	LYUBOV NESTEROVA	{"phone": "+70505651379"}
0005433496531	CE7B78	3760 794509	SERGEY MAKAROV	{"email": "smakarov-111975@postgrespro.ru", "phone": "+70130752267"}
0005433496532	CE7B78	1635 744836	EVGENIY NIKITIN	{"phone": "+70170446842"}
0005433496533	796641	2535 200343	VALERIY MATVEEV	{"email": "valeriymatveev.1968@postgrespro.ru", "phone": "+70825154029"}
0005433496534	F8E74B	9952 828913	IVAN NIKOLAEV	{"phone": "+70836788799"}
0005433496535	46987A	0434 059947	VALENTINA SMIRNOVA	{"email": "smirnova.valentina-1975@postgrespro.ru", "phone": "+70102398086"}
0005433496536	46987A	1519 909000	DMITRIY IVANOV	{"email": "d-ivanov_021977@postgrespro.ru", "phone": "+70936578434"}
0005433496537	76A737	4094 113926	LIDIYA SAVELEVA	{"phone": "+70493632425"}
0005433496538	402D85	3352 669643	YULIYA BORISOVA	{"phone": "+70673769546"}
0005433496539	402D85	8128 120983	ALEKSANDR ZAKHAROV	{"phone": "+70625353073"}
0005433496540	735E77	1089 229560	VLADIMIR PAVLOV	{"email": "v-pavlov1953@postgrespro.ru", "phone": "+70973757668"}
0005433496541	735E77	3699 165489	MARIYA TIKHONOVA	{"phone": "+70333294921"}
0005433496542	18AC93	3651 520437	LARISA SCHERBAKOVA	{"email": "scherbakoval22081970@postgrespro.ru", "phone": "+70296068998"}
0005433496543	C97DAE	8246 575699	VERA VASILEVA	{"email": "vasileva.vera011971@postgrespro.ru", "phone": "+70674703586"}
0005433496544	8E9F26	4765 910170	KSENIYA KUZNECOVA	{"phone": "+70865455396"}
0005433496545	C172E5	5394 310718	GALINA TROFIMOVA	{"email": "galina_trofimova111976@postgrespro.ru", "phone": "+70016146095"}
0005433496546	C172E5	1515 434709	LIDIYA DAVYDOVA	{"phone": "+70172464492"}
0005433496547	E89B02	2767 484327	ANDREY KISELEV	{"phone": "+70375108280"}
0005433496548	60E2CB	7864 076384	SERGEY PAVLOV	{"email": "pavlov.sergey.011968@postgrespro.ru", "phone": "+70682246761"}
0005433496549	60E2CB	3998 882849	LARISA AKIMOVA	{"phone": "+70913369002"}
0005433496550	303BDA	2319 351443	ELENA MOROZOVA	{"phone": "+70581660852"}
0005433496551	930558	7499 563229	IRINA ZHUKOVA	{"email": "zhukovai-09081965@postgrespro.ru", "phone": "+70333190268"}
0005433496552	930558	7655 188949	LIDIYA BELOVA	{"phone": "+70834833099"}
0005433496553	A2A502	3706 595121	DMITRIY TIKHONOV	{"email": "dmitriy-tikhonov.18081966@postgrespro.ru", "phone": "+70337932922"}
0005433496554	B4765F	3869 466792	YANINA SOROKINA	{"phone": "+70214306283"}
0005433496555	604668	7201 371665	SVETLANA MIRONOVA	{"phone": "+70694889696"}
0005433496556	F82B1B	4562 727085	LYUBOV MALYSHEVA	{"phone": "+70231256550"}
0005433496557	0D0207	7999 491187	ALLA ABRAMOVA	{"email": "abramova-a_02051970@postgrespro.ru", "phone": "+70744812130"}
0005433496558	0D0207	0842 336848	SERGEY IVANOV	{"email": "sivanov.18121980@postgrespro.ru", "phone": "+70880425724"}
0005433496559	B6126F	6645 905813	MILENA KUZNECOVA	{"email": "m.kuznecova-1973@postgrespro.ru", "phone": "+70811266445"}
0005433496560	CB4288	2285 818963	VITALIY FOMIN	{"email": "fomin.vitaliy-25061965@postgrespro.ru", "phone": "+70731130814"}
0005433496561	36B2C9	3648 982935	LIDIYA FILIPPOVA	{"phone": "+70259795479"}
0005433496562	36B2C9	7327 352489	NIKOLAY SOROKIN	{"email": "sorokin-n101965@postgrespro.ru", "phone": "+70537914959"}
0005433496563	9D1845	1188 155381	ANATOLIY MAKAROV	{"phone": "+70178573819"}
0005433496564	72F58B	4776 891481	KLAVDIYA GRISHINA	{"email": "grishina-klavdiya-11031971@postgrespro.ru", "phone": "+70095725898"}
0005433496565	711F79	9712 651858	OLGA CHERNOVA	{"email": "olgachernova.1972@postgrespro.ru", "phone": "+70796929693"}
0005433496566	711F79	1048 822845	ANATOLIY KISELEV	{"email": "kiselev.anatoliy.041979@postgrespro.ru", "phone": "+70578807380"}
0005433496567	BCBE0A	1763 509138	DANILA CHERNOV	{"phone": "+70538780076"}
0005433496568	9D2070	5092 172470	ALBINA GUSEVA	{"email": "a_guseva-031978@postgrespro.ru", "phone": "+70173129706"}
0005433496569	9D2070	3160 546834	ALSU STEPANOVA	{"phone": "+70580590798"}
0005433496570	ABE833	9316 853864	TATYANA SOROKINA	{"phone": "+70550210960"}
0005433496571	4B264E	9438 716241	OLGA BARANOVA	{"phone": "+70115521498"}
0005433496572	BA41CE	2711 717933	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr1966@postgrespro.ru", "phone": "+70405253016"}
0005433496573	E764BD	8741 008362	NIKOLAY VASILEV	{"phone": "+70600026342"}
0005433496574	E764BD	4720 231770	VLADIMIR ZAYCEV	{"phone": "+70015010240"}
0005433496575	C77C8F	9772 352551	KIRILL GRIGOREV	{"phone": "+70356315905"}
0005433496576	9254B7	1473 887147	NIKOLAY KARPOV	{"email": "nikolay.karpov21081980@postgrespro.ru", "phone": "+70754944141"}
0005433496577	9254B7	8055 458724	EKATERINA STEPANOVA	{"email": "e.stepanova-1981@postgrespro.ru", "phone": "+70234051013"}
0005433496578	E9756E	9805 131003	ANATOLIY ORLOV	{"email": "anatoliyorlov_071978@postgrespro.ru", "phone": "+70255376144"}
0005433496579	E9756E	3361 436669	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey15071970@postgrespro.ru", "phone": "+70639564097"}
0005433496580	C2F909	4621 865178	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey22041973@postgrespro.ru", "phone": "+70889569289"}
0005433496581	C2F909	0704 141230	GENNADIY VASILEV	{"email": "vasilevg_14081970@postgrespro.ru", "phone": "+70680684772"}
0005433496582	9E5978	7166 298847	VLADIMIR KOROLEV	{"email": "v.korolev_1969@postgrespro.ru", "phone": "+70256261939"}
0005433496583	D84F48	7723 875584	OLEG MOROZOV	{"phone": "+70800159991"}
0005433496584	819696	0012 588696	EKATERINA EFREMOVA	{"email": "e_efremova1979@postgrespro.ru", "phone": "+70901840337"}
0005433496585	1EE72B	9806 587097	KLAVDIYA MIKHAYLOVA	{"phone": "+70880829697"}
0005433496586	56457F	1500 838413	OKSANA RODIONOVA	{"email": "rodionova-o-111965@postgrespro.ru", "phone": "+70652536893"}
0005433496587	2D49A9	7946 118290	TATYANA STEPANOVA	{"phone": "+70463953606"}
0005433496588	B5B5CB	2496 372177	VLADIMIR ORLOV	{"phone": "+70225293069"}
0005433496589	88A592	6520 694164	GALINA VASILEVA	{"phone": "+70283819932"}
0005433496590	C2545B	5186 803647	TATYANA SERGEEVA	{"phone": "+70030424782"}
0005433496591	3B0702	1332 524100	VALERIYA ZOTOVA	{"email": "valeriyazotova_061971@postgrespro.ru", "phone": "+70881425481"}
0005433496592	705CEB	4434 102817	YAKOV KARPOV	{"email": "y-karpov-23101970@postgrespro.ru", "phone": "+70948546020"}
0005433496593	705CEB	7714 625007	YULIYA RODIONOVA	{"phone": "+70615169497"}
0005433496594	1DC55C	9875 200129	LYUDMILA KUZNECOVA	{"email": "lyudmila-kuznecova-29111974@postgrespro.ru", "phone": "+70131288625"}
0005433496595	4BF3C5	9204 073420	SVETLANA BELOVA	{"email": "svetlana_belova_091980@postgrespro.ru", "phone": "+70821890145"}
0005433496596	4BF3C5	7423 274873	IRINA DENISOVA	{"phone": "+70206617856"}
0005433496597	5D1773	0232 084546	KLAVDIYA ANDREEVA	{"email": "andreevaklavdiya.101962@postgrespro.ru", "phone": "+70624809621"}
0005433496598	5D1773	6983 426136	DMITRIY GORBUNOV	{"email": "dmitriy-gorbunov-19011979@postgrespro.ru", "phone": "+70353381542"}
0005433496599	D27E44	0318 170483	VALERIYA KUZNECOVA	{"email": "valeriya.kuznecova_091972@postgrespro.ru", "phone": "+70971406252"}
0005433496600	D27E44	3078 067240	ALEKSEY ILIN	{"email": "aleksey_ilin13081976@postgrespro.ru", "phone": "+70163918774"}
0005433496601	E1FF8A	8714 560489	SERGEY KULIKOV	{"email": "kulikov.s_041981@postgrespro.ru", "phone": "+70378138379"}
0005433496602	C99A91	7985 762867	ALINA TIKHONOVA	{"phone": "+70452978333"}
0005433496603	CC5021	7566 002995	DENIS NIKITIN	{"email": "d_nikitin_06041968@postgrespro.ru", "phone": "+70321003763"}
0005433496604	CC5021	7590 640641	NIKOLAY FEDOROV	{"phone": "+70237779002"}
0005433496605	B76345	5320 168864	MIKHAIL GERASIMOV	{"phone": "+70060454051"}
0005433496606	FB598A	4521 381855	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr1954@postgrespro.ru", "phone": "+70828604095"}
0005433496607	897C88	3355 048385	EGOR POPOV	{"phone": "+70241172376"}
0005433496608	98A585	4263 275386	GEORGIY GORBUNOV	{"phone": "+70396104142"}
0005433496609	580463	4045 961529	NATALYA OSIPOVA	{"email": "osipovanatalya.1958@postgrespro.ru", "phone": "+70852785455"}
0005433496610	580463	7729 238796	EKATERINA SERGEEVA	{"email": "sergeevaekaterina.30101977@postgrespro.ru", "phone": "+70640252176"}
0005433496611	580463	4397 297277	YURIY CHERNOV	{"email": "yuriy_chernov-12051969@postgrespro.ru", "phone": "+70928921638"}
0005433496612	580463	2294 283952	TAISIYA IVANOVA	{"phone": "+70188614594"}
0005433496613	618143	8068 171738	SERGEY PETROV	{"email": "s-petrov-1973@postgrespro.ru", "phone": "+70273393125"}
0005433496614	19DB24	6518 836383	NIKOLAY MELNIKOV	{"email": "n.melnikov-1976@postgrespro.ru", "phone": "+70976701815"}
0005433496615	19DB24	7932 144211	VERA NOVIKOVA	{"phone": "+70360974493"}
0005433496616	19DB24	2222 614752	SERGEY ALEKSEEV	{"phone": "+70147631476"}
0005433496617	19DB24	1332 492849	VLADIMIR GERASIMOV	{"email": "gerasimov.vladimir.071967@postgrespro.ru", "phone": "+70335598744"}
0005433496618	656130	0462 323117	OLGA EGOROVA	{"phone": "+70482891959"}
0005433496619	3D5A39	3506 241578	SERGEY BARANOV	{"email": "baranov.s.1970@postgrespro.ru", "phone": "+70667035995"}
0005433496620	3D5A39	9974 437289	DMITRIY KRASNOV	{"email": "d.krasnov.18031973@postgrespro.ru", "phone": "+70156904110"}
0005433496621	DA494F	9807 151860	ALEKSANDR GUSEV	{"email": "gusev-a-091979@postgrespro.ru", "phone": "+70806082305"}
0005433496622	811CCF	0048 681773	NINA GAVRILOVA	{"email": "nina-gavrilova.10031968@postgrespro.ru", "phone": "+70686025389"}
0005433496623	811CCF	9693 113250	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr061972@postgrespro.ru", "phone": "+70137305209"}
0005433496624	811CCF	7829 138231	MAKSIM MATVEEV	{"email": "matveev.m_1975@postgrespro.ru", "phone": "+70130391350"}
0005433496625	AAB10D	6594 858528	YURIY KUZNECOV	{"email": "yuriykuznecov-1983@postgrespro.ru", "phone": "+70886108399"}
0005433496626	EAF05D	5020 612101	DENIS BELOV	{"phone": "+70823876422"}
0005433496627	EAF05D	2217 861971	NINA DANILOVA	{"email": "n_danilova1973@postgrespro.ru", "phone": "+70330792727"}
0005433496628	EAF05D	5892 855319	VIKTORIYA DAVYDOVA	{"email": "vdavydova_1978@postgrespro.ru", "phone": "+70206415994"}
0005433496629	F51474	2312 870388	TATYANA KISELEVA	{"email": "kiselevatatyana.07101972@postgrespro.ru", "phone": "+70311754240"}
0005433496630	F51474	9585 165014	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov-011975@postgrespro.ru", "phone": "+70616257841"}
0005433496631	FFB1B9	4666 702765	TATYANA ABRAMOVA	{"email": "tabramova.28071969@postgrespro.ru", "phone": "+70738574585"}
0005433496632	FDBBEA	6941 623080	ALEKSANDR BARANOV	{"phone": "+70451550996"}
0005433496633	0792DB	3909 729269	MARIYA KAZAKOVA	{"phone": "+70408312061"}
0005433496634	0792DB	3625 400969	EVGENIYA MAKSIMOVA	{"email": "emaksimova.021975@postgrespro.ru", "phone": "+70520766704"}
0005433496635	259990	6953 793462	GENNADIY MAKAROV	{"phone": "+70406190366"}
0005433496636	288C21	3103 348390	EVGENIY GRIGOREV	{"email": "e-grigorev-08021971@postgrespro.ru", "phone": "+70980560533"}
0005433496637	288C21	1039 772072	SERGEY ZAKHAROV	{"phone": "+70781017427"}
0005433496638	288C21	8179 506593	RAFAIL ZAKHAROV	{"email": "rzakharov-021973@postgrespro.ru", "phone": "+70452435993"}
0005433496639	1DA058	8380 158800	YULIYA MASLOVA	{"phone": "+70052200254"}
0005433496640	1DA058	7068 878623	NATALYA KAZAKOVA	{"phone": "+70957527910"}
0005433496641	8F0200	7993 011835	LYUBOV ZAKHAROVA	{"phone": "+70565232022"}
0005433496642	AB5BAF	9954 409729	SERGEY KOZLOV	{"phone": "+70578868571"}
0005433496643	AB5BAF	5572 650765	DMITRIY PAVLOV	{"phone": "+70945668146"}
0005433496644	0014E3	0697 409732	IGOR NOVIKOV	{"phone": "+70618865802"}
0005433496645	0014E3	7845 050546	OLGA PETROVA	{"phone": "+70054373927"}
0005433496646	C2F2EA	5482 228736	MAKSIM IVANOV	{"email": "ivanov-m15101972@postgrespro.ru", "phone": "+70672991905"}
0005433496647	E67789	9711 754027	NIKOLAY RODIONOV	{"phone": "+70859397301"}
0005433496648	7EC121	7940 023296	ANASTASIYA FILATOVA	{"email": "filatova.a.121972@postgrespro.ru", "phone": "+70723967678"}
0005433496649	7EC121	6315 484291	SERGEY BORISOV	{"phone": "+70738080219"}
0005433496650	565032	6053 235137	VALERIYA SERGEEVA	{"email": "valeriya-sergeeva.1965@postgrespro.ru", "phone": "+70211391611"}
0005433496651	43F465	9407 137769	MARIYA MOISEEVA	{"email": "moiseevamariya.01091978@postgrespro.ru", "phone": "+70322396692"}
0005433496652	EBE9B7	0947 318056	GALINA KUZNECOVA	{"phone": "+70718377967"}
0005433496653	EBE9B7	9240 275743	NINA SOROKINA	{"phone": "+70036601473"}
0005433496654	D29CDA	2653 313779	SARIYA MASLOVA	{"email": "maslovas_081960@postgrespro.ru", "phone": "+70477912290"}
0005433496655	B71BC1	2991 408180	SERAFIM VASILEV	{"phone": "+70814606653"}
0005433496656	4E2288	3963 977741	ANDREY DMITRIEV	{"phone": "+70915862573"}
0005433496657	C35C28	4619 664000	GALINA SOROKINA	{"phone": "+70860076364"}
0005433496658	E9F21D	5671 540259	RAMIL KOROLEV	{"phone": "+70043470892"}
0005433496659	DC57EB	2099 513131	VYACHESLAV GRIGOREV	{"email": "v_grigorev-13091978@postgrespro.ru", "phone": "+70456897460"}
0005433496660	96DDA9	4585 700150	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov061963@postgrespro.ru", "phone": "+70111565601"}
0005433496661	AC9320	0672 038806	ALEKSEY DAVYDOV	{"email": "a.davydov.091972@postgrespro.ru", "phone": "+70821774111"}
0005433496662	AC9320	4640 100161	NIKOLAY KRASNOV	{"email": "nikolaykrasnov-1968@postgrespro.ru", "phone": "+70647639863"}
0005433496663	AC9320	9800 431337	LEONID EGOROV	{"phone": "+70369172750"}
0005433496664	9F7EAA	5784 054937	DARYA KARPOVA	{"phone": "+70523567590"}
0005433496665	84B66E	2385 416886	VITALIY MARTYNOV	{"phone": "+70514393780"}
0005433496666	F625F9	1988 892876	VALERIYA ANDREEVA	{"phone": "+70930994051"}
0005433496667	F625F9	9224 378600	NATALYA VASILEVA	{"phone": "+70373823910"}
0005433496668	0495E2	8169 875129	IVAN DAVYDOV	{"phone": "+70639302178"}
0005433496669	65A22A	4105 717016	VLADIMIR KRASNOV	{"phone": "+70517044136"}
0005433496670	3513DD	4781 728100	ILYA ORLOV	{"phone": "+70805740854"}
0005433496671	A3024E	8763 040243	YURIY KUDRYASHOV	{"phone": "+70692933146"}
0005433496672	73886B	9702 317804	ANNA KOZLOVA	{"email": "kozlova_a_04011970@postgrespro.ru", "phone": "+70021107349"}
0005433496673	1D936D	3857 564355	FANIL KUZMIN	{"email": "kuzmin-fanil-20051978@postgrespro.ru", "phone": "+70270040979"}
0005433496674	1D936D	8695 087813	RUSLAN NOVIKOV	{"email": "novikov_ruslan_1965@postgrespro.ru", "phone": "+70030878381"}
0005433496675	EC0A5B	8201 532941	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e-03111964@postgrespro.ru", "phone": "+70147621026"}
0005433496676	EC0A5B	1823 122796	VASILIY ORLOV	{"phone": "+70253142532"}
0005433496677	EC0A5B	3939 323731	NADEZHDA ZAYCEVA	{"email": "zayceva.nadezhda_051975@postgrespro.ru", "phone": "+70861361225"}
0005433496678	0FEE76	3568 840118	NIKOLAY DAVYDOV	{"phone": "+70139949993"}
0005433496679	0FEE76	6221 330936	DMITRIY KISELEV	{"phone": "+70980731604"}
0005433496680	BF6030	9947 665526	DMITRIY ZAYCEV	{"email": "d.zaycev.1958@postgrespro.ru", "phone": "+70278069674"}
0005433496681	7B20E6	3898 249668	VYACHESLAV NIKOLAEV	{"email": "nikolaev.v-1979@postgrespro.ru", "phone": "+70038790407"}
0005433496682	7B20E6	5667 315754	ALEKSANDR POPOV	{"email": "popov.aleksandr.1969@postgrespro.ru", "phone": "+70479153017"}
0005433496683	B1EEEC	3458 816694	OKSANA FROLOVA	{"phone": "+70146339341"}
0005433496684	B1EEEC	4947 259003	NATALYA ALEKSEEVA	{"phone": "+70387617501"}
0005433496685	4C519D	0985 211522	YURIY MEDVEDEV	{"phone": "+70033544450"}
0005433496686	4C519D	1233 448081	LYUBOV MIRONOVA	{"email": "mironova_lyubov.011964@postgrespro.ru", "phone": "+70105125178"}
0005433496687	EBD62D	0246 750079	VALENTINA KOZLOVA	{"email": "kozlovavalentina_13041972@postgrespro.ru", "phone": "+70000564541"}
0005433496688	EBD62D	4500 863098	ELENA KUZNECOVA	{"email": "kuznecova_elena_1969@postgrespro.ru", "phone": "+70739932506"}
0005433496689	E22E8F	4261 034848	ELENA KISELEVA	{"phone": "+70019255049"}
0005433496690	1E28C9	0521 710508	NATALYA DAVYDOVA	{"phone": "+70463276206"}
0005433496691	424A68	6227 542862	IRINA DANILOVA	{"email": "idanilova-101968@postgrespro.ru", "phone": "+70857896354"}
0005433496692	7ADC25	8208 499102	ALEKSANDR KUDRYASHOV	{"phone": "+70014140707"}
0005433496693	7ADC25	2321 199676	BOGDAN ROMANOV	{"email": "bromanov_1976@postgrespro.ru", "phone": "+70983483672"}
0005433496694	307FEE	1061 449883	NATALYA BELYAEVA	{"phone": "+70037772674"}
0005433496695	307FEE	9440 692611	PETR POPOV	{"email": "petrpopov_09071978@postgrespro.ru", "phone": "+70116974028"}
0005433496696	307FEE	0300 294677	NATALYA SMIRNOVA	{"phone": "+70215013112"}
0005433496697	9E0DB8	1045 397717	LARISA VOLKOVA	{"email": "larisa.volkova.1972@postgrespro.ru", "phone": "+70658304925"}
0005433496698	F5927F	7252 734389	GEORGIY KUZNECOV	{"email": "kuznecovg-16081976@postgrespro.ru", "phone": "+70984785259"}
0005433496699	7D3DA9	6041 926385	ALLA MOISEEVA	{"email": "allamoiseeva-1970@postgrespro.ru", "phone": "+70931994175"}
0005433496700	0A71E7	0021 879039	ZINAIDA NAZAROVA	{"phone": "+70151510849"}
0005433496701	48C99F	1632 642539	NIKOLAY NIKITIN	{"email": "n_nikitin-1967@postgrespro.ru", "phone": "+70539899168"}
0005433496702	66D203	8573 305655	IRINA TIKHONOVA	{"phone": "+70090882074"}
0005433496703	430B74	4440 940235	YULIYA FOMINA	{"phone": "+70290745178"}
0005433496704	430B74	5589 206701	OLGA ZAYCEVA	{"phone": "+70691088377"}
0005433496705	430B74	7237 615631	VARVARA KAZAKOVA	{"phone": "+70369148276"}
0005433496706	430B74	2509 503336	VIKTOR KRASNOV	{"email": "v.krasnov.22091966@postgrespro.ru", "phone": "+70759657413"}
0005433496707	9C53D7	0339 293419	EKATERINA KAZAKOVA	{"email": "kazakova_ekaterina20111970@postgrespro.ru", "phone": "+70992138490"}
0005433496708	E42FC1	1820 540059	ELENA FOMINA	{"email": "elena_fomina_111979@postgrespro.ru", "phone": "+70471351902"}
0005433496709	971595	7293 640817	TATYANA KRASNOVA	{"email": "krasnova-tatyana.061969@postgrespro.ru", "phone": "+70240079880"}
0005433496710	971595	6685 434492	YULIYA KOVALEVA	{"email": "y.kovaleva-09101961@postgrespro.ru", "phone": "+70485663828"}
0005433496711	A79B3A	4226 723658	IGOR ANTONOV	{"phone": "+70995693178"}
0005433496712	6F67BE	5088 559654	ALEKSANDR VASILEV	{"phone": "+70219558739"}
0005433496713	6A3B96	2400 950302	VYACHESLAV CHERNOV	{"phone": "+70196913478"}
0005433496714	1B516C	1407 853910	ELENA CHERNOVA	{"phone": "+70439129080"}
0005433496715	2E5FE5	2071 423336	LILIYA SCHERBAKOVA	{"phone": "+70913340583"}
0005433496716	2E5FE5	0581 650152	MIKHAIL MIRONOV	{"phone": "+70416485032"}
0005433496717	494412	8418 556831	NIKOLAY KUZNECOV	{"email": "n.kuznecov_1976@postgrespro.ru", "phone": "+70410821781"}
0005433496718	BD24ED	9387 190620	VALENTINA VASILEVA	{"email": "v_vasileva.1979@postgrespro.ru", "phone": "+70252807184"}
0005433496719	B02151	7073 942040	RADIK EGOROV	{"phone": "+70665103454"}
0005433496720	B02151	5443 217020	YULIYA KOROLEVA	{"email": "koroleva_yuliya05031974@postgrespro.ru", "phone": "+70483220830"}
0005433496721	8F571C	8791 451227	GALINA ZAKHAROVA	{"phone": "+70653690698"}
0005433496722	E7041C	9917 648088	MIKHAIL PETROV	{"phone": "+70449453830"}
0005433496723	E7041C	9476 269754	ALEKSANDR TIKHONOV	{"phone": "+70270348971"}
0005433496724	2D9B86	2661 814289	TATYANA PETROVA	{"phone": "+70935902956"}
0005433496725	F91816	5892 085868	TAMARA MIKHAYLOVA	{"phone": "+70097269654"}
0005433496726	F91816	3561 800603	ANDREY ILIN	{"phone": "+70858471482"}
0005433496727	A851F9	8594 539190	ELENA ZHUKOVA	{"email": "elena.zhukova-07061973@postgrespro.ru", "phone": "+70278099531"}
0005433496728	69DDDB	7123 729528	SEMEN GUSEV	{"email": "semen-gusev_021972@postgrespro.ru", "phone": "+70229792123"}
0005433496729	F3D902	8613 842023	ALEKSANDR MOISEEV	{"email": "moiseevaleksandr_061984@postgrespro.ru", "phone": "+70981609426"}
0005433496730	5944AA	8260 032228	ANNA ZAKHAROVA	{"phone": "+70317366781"}
0005433496731	5944AA	6319 145282	NATALYA FILIPPOVA	{"phone": "+70432810944"}
0005433496732	20C077	7128 571733	LYUDMILA IVANOVA	{"phone": "+70030303551"}
0005433496733	D67824	4847 802491	MARIYA SMIRNOVA	{"phone": "+70979157148"}
0005433496734	9710AA	7256 329244	MARIYA GUSEVA	{"phone": "+70787045596"}
0005433496735	869F7D	8332 539957	MARINA BORISOVA	{"phone": "+70945628718"}
0005433496736	6AC24A	4173 746141	DMITRIY OSIPOV	{"phone": "+70747886229"}
0005433496737	6AC24A	4587 082241	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr_1979@postgrespro.ru", "phone": "+70357720191"}
0005433496738	232AC4	4194 863988	REGINA SEMENOVA	{"phone": "+70468348636"}
0005433496739	94BBAB	1552 259226	TATYANA KOLESNIKOVA	{"email": "tatyanakolesnikova.111970@postgrespro.ru", "phone": "+70509031618"}
0005433496740	2D2FD4	6515 841193	LYUBOV SERGEEVA	{"phone": "+70830737858"}
0005433496741	150ECF	4468 856837	SERGEY ISAEV	{"phone": "+70520863435"}
0005433496742	A22832	3390 533516	VLADIMIR FEDOROV	{"email": "fedorovvladimir_101975@postgrespro.ru", "phone": "+70196971427"}
0005433496743	A22832	9416 904365	PETR ROMANOV	{"phone": "+70977682680"}
0005433496744	578D6F	3429 176055	ELENA FEDOROVA	{"phone": "+70960921267"}
0005433496745	3D7D8F	5448 833556	ANNA MELNIKOVA	{"email": "anna_melnikova-21021974@postgrespro.ru", "phone": "+70297803320"}
0005433496746	0735AE	3193 235703	ANTONINA DANILOVA	{"phone": "+70007812061"}
0005433496747	E4E16C	4177 481954	PAVEL DAVYDOV	{"email": "davydov_pavel-27111975@postgrespro.ru", "phone": "+70426934803"}
0005433496748	E4E16C	3049 955640	ANDREY KRASNOV	{"email": "a-krasnov-1964@postgrespro.ru", "phone": "+70178196377"}
0005433496749	E4E16C	5110 099486	EDUARD ZAYCEV	{"email": "ezaycev1971@postgrespro.ru", "phone": "+70323008644"}
0005433496750	7118B2	6628 307164	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_041977@postgrespro.ru", "phone": "+70001013929"}
0005433496751	7118B2	3776 951736	ANTONINA MEDVEDEVA	{"phone": "+70647339933"}
0005433496752	7118B2	1412 833197	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr11061976@postgrespro.ru", "phone": "+70996381586"}
0005433496753	C3DEA9	0580 797717	YULIYA ZOTOVA	{"phone": "+70450756600"}
0005433496754	5B8CEF	6352 548819	SVETLANA GUSEVA	{"email": "s-guseva.111974@postgrespro.ru", "phone": "+70807989522"}
0005433496755	3D47E9	5285 353139	ALEKSANDR ZAYCEV	{"email": "a_zaycev_1965@postgrespro.ru", "phone": "+70167608392"}
0005433496756	435407	5409 074395	LYUDMILA MOROZOVA	{"email": "morozoval031975@postgrespro.ru", "phone": "+70433539828"}
0005433496757	2E9DEF	4022 209981	IRINA MIKHAYLOVA	{"email": "i_mikhaylova_1962@postgrespro.ru", "phone": "+70688475738"}
0005433496758	B62FBB	1783 846565	NIKOLAY ZAKHAROV	{"phone": "+70301031520"}
0005433496759	B62FBB	8460 865747	NINA KOLESNIKOVA	{"phone": "+70011023030"}
0005433496760	F8F6DE	6933 084880	ELENA OVCHINNIKOVA	{"email": "elena_ovchinnikova.1975@postgrespro.ru", "phone": "+70804351387"}
0005433496761	F8F6DE	5236 920537	ALEKSEY SCHERBAKOV	{"email": "alekseyscherbakov23081968@postgrespro.ru", "phone": "+70750279858"}
0005433496762	F8F6DE	0722 156059	TIMUR IVANOV	{"phone": "+70157480826"}
0005433496763	B40C68	9293 951627	NIKITA VOROBEV	{"email": "vorobev.nikita-011972@postgrespro.ru", "phone": "+70889436101"}
0005433496764	CB9844	9485 397646	VIKTORIYA MAKAROVA	{"phone": "+70419314597"}
0005433496765	CB9844	5203 316315	NATALYA ILINA	{"phone": "+70703680173"}
0005433496766	08EA76	6320 835256	ALEKSEY KOROLEV	{"phone": "+70216448520"}
0005433496767	08EA76	3625 406004	ALEKSANDR YAKOVLEV	{"phone": "+70453752630"}
0005433496768	C0E503	2726 214503	SVETLANA PETROVA	{"email": "petrova_svetlana.30121974@postgrespro.ru", "phone": "+70694015309"}
0005433496769	D8EB78	6327 517134	SVETLANA TIKHONOVA	{"email": "tikhonova-svetlana_13111970@postgrespro.ru", "phone": "+70954452482"}
0005433496770	D8EB78	9756 660596	NATALYA CHERNOVA	{"email": "chernovan-12021979@postgrespro.ru", "phone": "+70384952644"}
0005433496771	D8EB78	8536 484802	IRINA TIKHONOVA	{"email": "tikhonovairina-1968@postgrespro.ru", "phone": "+70856011976"}
0005433496772	8A6444	9041 402522	ALEKSANDR OSIPOV	{"phone": "+70423446870"}
0005433496773	8A6444	2868 817347	VALERIY FROLOV	{"email": "valeriyfrolov_1973@postgrespro.ru", "phone": "+70408175840"}
0005433496774	FFEC9D	5296 000657	NIKOLAY ROMANOV	{"email": "nikolay-romanov091976@postgrespro.ru", "phone": "+70595308596"}
0005433496775	74FDDD	3951 253779	MIKHAIL ROMANOV	{"phone": "+70587408326"}
0005433496776	B51423	7894 307338	IGNAT ZHUKOV	{"email": "zhukov_ignat-111976@postgrespro.ru", "phone": "+70739850622"}
0005433496777	1BE289	2633 747610	IGNAT ORLOV	{"phone": "+70988159051"}
0005433496778	1BE289	9937 274802	OKSANA ZAYCEVA	{"phone": "+70633023981"}
0005433496779	11EC20	1535 442807	ELENA GAVRILOVA	{"email": "elenagavrilova.1971@postgrespro.ru", "phone": "+70862148151"}
0005433496780	4E889B	5161 022609	YURIY FOMIN	{"email": "yuriyfomin.18101972@postgrespro.ru", "phone": "+70013302746"}
0005433496781	A6D3F2	3098 416540	MIKHAIL ORLOV	{"phone": "+70263259541"}
0005433496782	A6D3F2	1740 361846	ALEKSANDR ANDREEV	{"email": "andreev-a_20111980@postgrespro.ru", "phone": "+70611595777"}
0005433496783	BB2BF6	2722 941843	ANASTASIYA OVCHINNIKOVA	{"phone": "+70995867821"}
0005433496784	47F7E8	9027 836047	IRINA NOVIKOVA	{"phone": "+70144799165"}
0005433496785	BA04FB	1915 201000	SERGEY PAVLOV	{"email": "pavlov.s.1968@postgrespro.ru", "phone": "+70221724429"}
0005433496786	BA04FB	7885 168683	VALERIY ROMANOV	{"phone": "+70797348261"}
0005433496787	6D85E9	6028 879075	IGOR SHEVCHENKO	{"phone": "+70309525030"}
0005433496788	6D85E9	0486 009449	DMITRIY KRASNOV	{"phone": "+70981999840"}
0005433496789	58DB26	2069 860435	TATYANA OSIPOVA	{"phone": "+70077527176"}
0005433496790	3A6B40	5353 982041	ANNA ZAYCEVA	{"email": "anna.zayceva.11121978@postgrespro.ru", "phone": "+70378166649"}
0005433496791	8B66B1	3408 549386	POLINA ZHURAVLEVA	{"email": "zhuravleva-polina1967@postgrespro.ru", "phone": "+70063572674"}
0005433496792	29EA68	9665 870204	GENNADIY MEDVEDEV	{"phone": "+70336002831"}
0005433496793	33E40B	6394 214751	MIKHAIL ANTONOV	{"phone": "+70995580962"}
0005433496794	FAC5AD	4466 445135	ANTONINA EGOROVA	{"email": "egorova.a-071967@postgrespro.ru", "phone": "+70370293633"}
0005433496795	CFA8F9	9260 470186	SERGEY MELNIKOV	{"phone": "+70058227177"}
0005433496796	96DA7E	2016 138617	EVGENIYA IVANOVA	{"email": "ivanova_evgeniya_1975@postgrespro.ru", "phone": "+70312527829"}
0005433496797	E95006	6111 094757	ZINAIDA SEMENOVA	{"phone": "+70204200367"}
0005433496798	9EC670	7320 940426	ELZA NOVIKOVA	{"phone": "+70904881428"}
0005433496799	9EC670	9775 636828	ALEKSANDR DMITRIEV	{"phone": "+70561498221"}
0005433496800	CCED24	7311 816270	SVETLANA MATVEEVA	{"email": "svetlana.matveeva1955@postgrespro.ru", "phone": "+70208945593"}
0005433496801	CCED24	7119 027680	ANDREY GUSEV	{"email": "andrey_gusev-091969@postgrespro.ru", "phone": "+70531932193"}
0005433496802	CCED24	9245 502329	VALERIY FEDOTOV	{"email": "valeriy.fedotov-1966@postgrespro.ru", "phone": "+70734400110"}
0005433496803	E6D402	1203 337503	KARINA POPOVA	{"email": "karinapopova1986@postgrespro.ru", "phone": "+70625869695"}
0005433496804	E6D402	3032 846444	EVGENIY MAKAROV	{"phone": "+70922702906"}
0005433496805	E57E8F	9037 326113	ARSENIY ZAYCEV	{"email": "a-zaycev1973@postgrespro.ru", "phone": "+70985324464"}
0005433496806	E44345	0142 396515	RUSLAN SIDOROV	{"phone": "+70500472824"}
0005433496807	FE609E	3223 393057	ROMAN ISAEV	{"email": "roman_isaev_03091956@postgrespro.ru", "phone": "+70628964366"}
0005433496808	FE609E	1193 473934	ALEKSANDR NAUMOV	{"email": "naumov-a031969@postgrespro.ru", "phone": "+70956796214"}
0005433496809	87BBCF	6104 380244	SEMEN AFANASEV	{"email": "semen.afanasev-091973@postgrespro.ru", "phone": "+70443825620"}
0005433496810	DAAA1B	4182 042445	TATYANA SCHERBAKOVA	{"phone": "+70551435611"}
0005433496811	4AA5A9	3978 058769	VLADIMIR KUZNECOV	{"phone": "+70679767772"}
0005433496812	4AA5A9	8807 601998	DMITRIY MAKSIMOV	{"phone": "+70265305352"}
0005433496813	07625B	6858 712627	ALBERT STEPANOV	{"phone": "+70994576990"}
0005433496814	296175	0635 945115	ALFIYA TROFIMOVA	{"phone": "+70354467214"}
0005433496815	296175	3814 038978	NIKOLAY KOZLOV	{"email": "nikolaykozlov-111973@postgrespro.ru", "phone": "+70385348797"}
0005433496816	8F2F49	1486 326868	TATYANA NIKOLAEVA	{"phone": "+70940562566"}
0005433496817	B33FE3	2314 927676	VLADIMIR ROMANOV	{"phone": "+70146294660"}
0005433496818	AE6850	2193 798651	SERGEY KUZNECOV	{"phone": "+70697450313"}
0005433496819	93A4EA	8948 137717	OLEG TIKHONOV	{"email": "olegtikhonov_25081979@postgrespro.ru", "phone": "+70920264841"}
0005433496820	DA17BE	2442 965835	ARSENIY MIRONOV	{"email": "arseniymironov_021968@postgrespro.ru", "phone": "+70026172932"}
0005433496821	DA17BE	6346 128634	VASILIY POPOV	{"email": "popov_vasiliy22041975@postgrespro.ru", "phone": "+70812130449"}
0005433496822	5CB969	4349 859180	BORIS MOROZOV	{"email": "morozov-b.20071965@postgrespro.ru", "phone": "+70784664339"}
0005433496823	5CB969	0264 812675	YULIYA SAVELEVA	{"email": "saveleva-y-1964@postgrespro.ru", "phone": "+70312988773"}
0005433496824	F7C13B	9935 197972	VALENTINA ARKHIPOVA	{"email": "valentina_arkhipova.17081978@postgrespro.ru", "phone": "+70927990192"}
0005433496825	9F2AEA	0609 819831	OKSANA ANDREEVA	{"phone": "+70795621033"}
0005433496826	9F2AEA	6915 269106	YURIY SCHERBAKOV	{"phone": "+70207318104"}
0005433496827	6A4C30	3045 755212	VALENTINA GUSEVA	{"email": "guseva-valentina_1977@postgrespro.ru", "phone": "+70070860625"}
0005433496828	52D477	3056 288331	TATYANA EGOROVA	{"email": "egorovat-14051973@postgrespro.ru", "phone": "+70229152700"}
0005433496829	52D477	3087 396609	ANDREY GUSEV	{"email": "andrey.gusev_1974@postgrespro.ru", "phone": "+70588885974"}
0005433496830	13F90A	6547 088300	ANASTASIYA KISELEVA	{"email": "kiseleva.anastasiya.1980@postgrespro.ru", "phone": "+70967263933"}
0005433496831	13F90A	3214 617492	OLGA KRASNOVA	{"email": "olga_krasnova_011967@postgrespro.ru", "phone": "+70304370916"}
0005433496832	5057B0	4567 468919	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr_22051981@postgrespro.ru", "phone": "+70706125056"}
0005433496833	E195B4	1462 351534	DINA ZHURAVLEVA	{"email": "d_zhuravleva-031981@postgrespro.ru", "phone": "+70958671459"}
0005433496834	E195B4	6559 559269	TATYANA FROLOVA	{"phone": "+70822123764"}
0005433496835	2EB7A1	9359 452296	IRINA PETROVA	{"email": "petrova-irina-21051977@postgrespro.ru", "phone": "+70220065234"}
0005433496836	4BAE3F	8252 333625	ALISA PAVLOVA	{"phone": "+70614095206"}
0005433496837	E03770	9428 850406	LIDIYA EFREMOVA	{"phone": "+70393182039"}
0005433496838	E03770	5598 204044	ALEKSEY ISAEV	{"phone": "+70691489818"}
0005433496839	7DB9FA	9270 430341	SABINA MAKAROVA	{"phone": "+70442573441"}
0005433496840	7DB9FA	8554 671412	SVETLANA ZOTOVA	{"email": "s-zotova-1984@postgrespro.ru", "phone": "+70229740271"}
0005433496841	7DB9FA	7470 282142	ANNA MATVEEVA	{"phone": "+70024124575"}
0005433496842	16E53B	6640 481551	OKSANA ANTONOVA	{"email": "antonovaoksana_1967@postgrespro.ru", "phone": "+70106265159"}
0005433496843	F5D60B	5066 139755	GALINA AKIMOVA	{"email": "g.akimova.011966@postgrespro.ru", "phone": "+70396414354"}
0005433496844	5B67D3	8253 652152	VIKTOR SAVELEV	{"email": "viktorsavelev.091974@postgrespro.ru", "phone": "+70278140592"}
0005433496845	5B67D3	8017 832367	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova.051965@postgrespro.ru", "phone": "+70516570883"}
0005433496846	9791E4	1302 240985	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko.22041971@postgrespro.ru", "phone": "+70375858707"}
0005433496847	CC3BF4	7323 117382	VADIM POPOV	{"email": "popovv.051974@postgrespro.ru", "phone": "+70199305202"}
0005433496848	17B06A	3142 441188	VALENTINA FROLOVA	{"phone": "+70311349014"}
0005433496849	CF859A	8619 442817	ANASTASIYA OSIPOVA	{"email": "osipovaanastasiya-011977@postgrespro.ru", "phone": "+70905812430"}
0005433496850	E04DEA	1498 637169	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr.02031974@postgrespro.ru", "phone": "+70449780204"}
0005433496851	AA2C26	8653 196233	OLEG GORBUNOV	{"email": "gorbunov-oleg.1983@postgrespro.ru", "phone": "+70332409625"}
0005433496852	67D8FC	4911 560731	GALINA YAKOVLEVA	{"email": "galina_yakovleva.18101976@postgrespro.ru", "phone": "+70410860122"}
0005433496853	36FCAB	9290 656970	ALEKSANDR KUZMIN	{"phone": "+70792519141"}
0005433496854	25AA01	0187 933961	TATYANA ILINA	{"email": "tatyanailina-16071985@postgrespro.ru", "phone": "+70850235611"}
0005433496855	EB21E7	6993 483234	KRISTINA KOROLEVA	{"phone": "+70972031792"}
0005433496856	EB21E7	1641 227273	LIDIYA POPOVA	{"phone": "+70829294374"}
0005433496857	132DA5	3650 301839	DMITRIY MARTYNOV	{"email": "martynovd051966@postgrespro.ru", "phone": "+70551632518"}
0005433496858	74F7D8	3490 612540	EKATERINA OVCHINNIKOVA	{"phone": "+70238756402"}
0005433496859	4D280A	7469 881216	NADEZHDA SERGEEVA	{"email": "nadezhda_sergeeva.16101976@postgrespro.ru", "phone": "+70980575749"}
0005433496860	D99BC7	6090 544633	YURIY MARTYNOV	{"email": "yuriy-martynov031979@postgrespro.ru", "phone": "+70422647978"}
0005433496861	D99BC7	8157 238071	ALEKSANDR SEMENOV	{"phone": "+70499321006"}
0005433496862	B6B6A9	5403 494901	LYUBOV KUDRYASHOVA	{"email": "kudryashova-lyubov1978@postgrespro.ru", "phone": "+70983953654"}
0005433496863	B6B6A9	1964 477008	ANNA MAKAROVA	{"phone": "+70643385183"}
0005433496864	7651CC	2596 027491	VIKTORIYA ISAEVA	{"email": "v.isaeva_101974@postgrespro.ru", "phone": "+70633488681"}
0005433496865	57AA25	0365 780240	YURIY TARASOV	{"phone": "+70443493777"}
0005433496866	E0BBE9	3006 546271	YURIY GUSEV	{"phone": "+70276879005"}
0005433496867	E0BBE9	1046 585085	OLGA MOISEEVA	{"phone": "+70135894078"}
0005433496868	E0BBE9	0158 831342	RIMMA STEPANOVA	{"phone": "+70795053667"}
0005433496869	EA5ABC	5145 921777	SOFIYA EGOROVA	{"email": "egorova-s-1978@postgrespro.ru", "phone": "+70623332606"}
0005433496870	C5C1F7	5848 590703	VALERIY TARASOV	{"phone": "+70185081438"}
0005433496871	029D10	5617 709581	ALEKSANDRA LEBEDEVA	{"phone": "+70368287164"}
0005433496872	571BE5	7495 161648	ELENA SCHERBAKOVA	{"phone": "+70103167136"}
0005433496873	571BE5	7794 873916	ANTON FOMIN	{"phone": "+70307475490"}
0005433496874	CDE3F5	2097 234754	RAFIK IVANOV	{"email": "ivanov_rafik-111977@postgrespro.ru", "phone": "+70333541005"}
0005433496875	CDE3F5	9966 218655	NADEZHDA ROMANOVA	{"phone": "+70476292673"}
0005433496876	0FD061	5779 899004	SERGEY CHERNOV	{"phone": "+70951354678"}
0005433496877	0FD061	0171 475646	VLADIMIR MELNIKOV	{"email": "v-melnikov.031986@postgrespro.ru", "phone": "+70110865568"}
0005433496878	C5F41F	7629 965457	PETR ALEKSEEV	{"email": "palekseev.30121975@postgrespro.ru", "phone": "+70390238875"}
0005433496879	C83B51	2473 533571	IRINA GRISHINA	{"phone": "+70517724033"}
0005433496880	C7AE08	2634 498066	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaa-011974@postgrespro.ru", "phone": "+70514277916"}
0005433496881	C5EDFA	0299 646992	IVAN STEPANOV	{"phone": "+70595713874"}
0005433496882	B723E1	7779 405999	MIKHAIL KUZMIN	{"email": "kuzmin-m_23101972@postgrespro.ru", "phone": "+70242469788"}
0005433496883	F6AA16	1767 940447	ALINA KOROLEVA	{"email": "koroleva.a-1978@postgrespro.ru", "phone": "+70165825303"}
0005433496884	F07642	4570 242796	NAILYA RYABOVA	{"phone": "+70728220104"}
0005433496885	F07642	8476 659956	VLADIMIR VOLKOV	{"email": "vladimir_volkov_1960@postgrespro.ru", "phone": "+70301061288"}
0005433496886	F07642	6456 022209	ALEKSANDR VASILEV	{"email": "vasilevaleksandr_1964@postgrespro.ru", "phone": "+70542780860"}
0005433496887	EC86E6	4351 741752	RAISA ABRAMOVA	{"phone": "+70894964793"}
0005433496888	EC86E6	6459 153725	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr.14091988@postgrespro.ru", "phone": "+70646636869"}
0005433496889	C5ACB6	5132 635433	MARINA IVANOVA	{"email": "ivanova-marina17111968@postgrespro.ru", "phone": "+70450198815"}
0005433496890	07E049	5627 705361	OLGA PETROVA	{"phone": "+70055100783"}
0005433496891	1B5CAA	1493 549760	MAYYA AFANASEVA	{"phone": "+70082252196"}
0005433496892	1B5CAA	1717 510875	NIKOLAY STEPANOV	{"email": "stepanov.n_07011982@postgrespro.ru", "phone": "+70794861425"}
0005433496893	A53BD3	8416 775885	NIKITA STEPANOV	{"email": "nikita-stepanov.061969@postgrespro.ru", "phone": "+70413654884"}
0005433496894	4845ED	5734 228854	NATALYA FADEEVA	{"email": "fadeeva_natalya_101967@postgrespro.ru", "phone": "+70055689319"}
0005433496895	4845ED	3019 996411	MIKHAIL KUZNECOV	{"phone": "+70158625974"}
0005433496896	A65A4B	9156 319750	LIDIYA OSIPOVA	{"email": "losipova-031969@postgrespro.ru", "phone": "+70905039550"}
0005433496897	431408	5283 661122	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey_111970@postgrespro.ru", "phone": "+70723393545"}
0005433496898	431408	7508 756847	EGOR YAKOVLEV	{"email": "yakovlev.e021981@postgrespro.ru", "phone": "+70480381395"}
0005433496899	F2E267	9125 680077	ALEKSANDR GAVRILOV	{"email": "gavrilova101972@postgrespro.ru", "phone": "+70185105376"}
0005433496900	F2E267	6398 500145	VLADIMIR FEDOTOV	{"email": "vfedotov_031972@postgrespro.ru", "phone": "+70763551583"}
0005433496901	1BA52D	1044 273114	VITALIY MATVEEV	{"email": "vitaliymatveev.1962@postgrespro.ru", "phone": "+70733944056"}
0005433496902	A00C0B	3556 775545	ANTON VASILEV	{"phone": "+70898022776"}
0005433496903	A00C0B	9921 762216	GALINA ANDREEVA	{"email": "andreeva-g-021963@postgrespro.ru", "phone": "+70584793791"}
0005433496904	ED084A	0626 822323	MARAT POPOV	{"phone": "+70966094275"}
0005433496905	01C941	2693 155159	OLGA LOGINOVA	{"phone": "+70835072426"}
0005433496906	2DB69C	0179 800968	SERGEY ANTONOV	{"email": "antonov_s-091974@postgrespro.ru", "phone": "+70373102704"}
0005433496907	2DB69C	4435 690885	NATALYA SOKOLOVA	{"phone": "+70640554960"}
0005433496908	150419	4617 472762	EKATERINA MAKSIMOVA	{"phone": "+70678124733"}
0005433496909	509BA3	2657 090314	ELENA SEMENOVA	{"phone": "+70316594237"}
0005433496910	602E53	0892 736210	DMITRIY SOLOVEV	{"phone": "+70655629344"}
0005433496911	3F4D3A	7320 493769	ROMAN POPOV	{"email": "popov_roman-031969@postgrespro.ru", "phone": "+70038532511"}
0005433496912	3F4D3A	7425 285969	ANNA SOROKINA	{"email": "sorokinaanna.08061975@postgrespro.ru", "phone": "+70574529354"}
0005433496913	02486E	2934 114816	ROBERT EGOROV	{"email": "regorov-21101972@postgrespro.ru", "phone": "+70787511511"}
0005433496914	30BD5B	6999 799351	SERGEY POPOV	{"email": "sergey_popov-01121979@postgrespro.ru", "phone": "+70859176477"}
0005433496915	A0FDA4	1649 235143	PAVEL MOISEEV	{"phone": "+70355763412"}
0005433496916	9117C6	0602 840765	GALINA MAKAROVA	{"email": "galina.makarova081975@postgrespro.ru", "phone": "+70270345235"}
0005433496917	9117C6	8321 886426	ANDREY NOVIKOV	{"phone": "+70831558825"}
0005433496918	2A0FD8	4343 934414	BULAT PAVLOV	{"email": "bulatpavlov.061988@postgrespro.ru", "phone": "+70042945727"}
0005433496919	2A0FD8	5959 474151	ANDREY ZAYCEV	{"email": "zaycev-a.1965@postgrespro.ru", "phone": "+70895714791"}
0005433496920	5C1808	5159 260075	VARVARA ZAYCEVA	{"email": "varvarazayceva_1975@postgrespro.ru", "phone": "+70694914813"}
0005433496921	CE7560	5060 066822	FAINA KALININA	{"phone": "+70936311501"}
0005433496922	549366	6728 537031	FARID SHEVCHENKO	{"phone": "+70132616988"}
0005433496923	E8B2E8	1580 096409	VLADIMIR SOKOLOV	{"phone": "+70772809654"}
0005433496924	E8B2E8	3037 044363	ALEKSANDR VOROBEV	{"email": "avorobev_1963@postgrespro.ru", "phone": "+70264346886"}
0005433496925	ED1DDC	4917 192992	OLGA FROLOVA	{"phone": "+70706555239"}
0005433496926	E94731	5780 761191	EVGENIY GUSEV	{"phone": "+70124332249"}
0005433496927	E94731	8715 312452	EGOR KARPOV	{"email": "karpov_egor1973@postgrespro.ru", "phone": "+70047724258"}
0005433496928	606B5D	5308 288378	OKSANA NESTEROVA	{"phone": "+70760194102"}
0005433496929	15FC2E	2031 147535	ANATOLIY MATVEEV	{"phone": "+70352042723"}
0005433496930	6D59AE	3465 695555	POLINA TARASOVA	{"phone": "+70669571456"}
0005433496931	0AA873	4244 272651	ANATOLIY VLASOV	{"phone": "+70719378266"}
0005433496932	80E2A8	7604 665731	ILMIRA ALEKSEEVA	{"email": "alekseeva-ilmira_091971@postgrespro.ru", "phone": "+70342140283"}
0005433496933	80E2A8	2109 266344	OLGA ZAKHAROVA	{"email": "zakharova-o.011969@postgrespro.ru", "phone": "+70560636816"}
0005433496934	E597DB	8333 890796	VYACHESLAV FEDOROV	{"email": "fedorov-vyacheslav111963@postgrespro.ru", "phone": "+70136391284"}
0005433496935	E597DB	8983 199036	MARINA VLASOVA	{"phone": "+70684963628"}
0005433496936	A4A7C9	0667 802526	LYUBOV DANILOVA	{"phone": "+70736752095"}
0005433496937	A4A7C9	0752 052949	EKATERINA PETROVA	{"email": "petrova-e-1987@postgrespro.ru", "phone": "+70594573097"}
0005433496938	A4A7C9	1538 042549	OLEG ZAKHAROV	{"email": "zakharov_oleg_17081963@postgrespro.ru", "phone": "+70618534848"}
0005433496939	0946A3	7714 847140	ALEKSEY KULIKOV	{"phone": "+70773092358"}
0005433496940	DFD9CF	9345 485214	LYUDMILA MATVEEVA	{"phone": "+70669852621"}
0005433496941	DFD9CF	9177 258880	ELENA LUKYANOVA	{"email": "elena-lukyanova081983@postgrespro.ru", "phone": "+70372869768"}
0005433496942	DFD9CF	3567 509509	DMITRIY IVANOV	{"phone": "+70160311982"}
0005433496943	55D97B	7577 059864	DMITRIY BORISOV	{"phone": "+70883593916"}
0005433496944	FA203B	4748 832330	SERGEY MOROZOV	{"email": "smorozov_041975@postgrespro.ru", "phone": "+70283134847"}
0005433496945	FA203B	4423 076666	TAMARA VOROBEVA	{"email": "vorobeva.tamara24071976@postgrespro.ru", "phone": "+70800395640"}
0005433496946	FA203B	4018 725186	NADEZHDA ZAYCEVA	{"phone": "+70797696083"}
0005433496947	DAA275	0703 935824	NADEZHDA KOZLOVA	{"phone": "+70558702096"}
0005433496948	81F331	8385 310134	ILDAR KONOVALOV	{"email": "konovalov_ildar-071967@postgrespro.ru", "phone": "+70387957428"}
0005433496949	754F36	5961 387845	ANASTASIYA BOGDANOVA	{"phone": "+70594616568"}
0005433496950	828501	6138 588452	KONSTANTIN SERGEEV	{"phone": "+70328922565"}
0005433496951	828501	2338 167420	VASILIY KULIKOV	{"phone": "+70658774041"}
0005433496952	B5CDC6	3572 331561	SERGEY IVANOV	{"email": "ivanov.sergey-14071961@postgrespro.ru", "phone": "+70314233884"}
0005433496953	2C3555	1803 614409	NIKOLAY KUZNECOV	{"phone": "+70445530673"}
0005433496954	3C337C	2353 525900	EKATERINA POPOVA	{"email": "e-popova.051980@postgrespro.ru", "phone": "+70104593384"}
0005433496955	4DE868	2873 363769	EMILIYA SERGEEVA	{"email": "sergeeva-emiliya-101969@postgrespro.ru", "phone": "+70574197307"}
0005433496956	BA257E	4833 643119	LYUDMILA KONDRATEVA	{"phone": "+70406452335"}
0005433496957	8078C3	5199 402498	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov.091973@postgrespro.ru", "phone": "+70039475322"}
0005433496958	8078C3	9341 674256	LYUDMILA GUSEVA	{"phone": "+70650630037"}
0005433496959	ADA4F3	3896 383194	VALENTINA FILIPPOVA	{"email": "filippova.valentina_06011964@postgrespro.ru", "phone": "+70323372706"}
0005433496960	ADA4F3	2770 369243	DANILA MEDVEDEV	{"phone": "+70252340232"}
0005433496961	FD120D	8513 455726	DMITRIY KUZMIN	{"email": "d.kuzmin_1974@postgrespro.ru", "phone": "+70341819524"}
0005433496962	B3692D	0109 700932	ANASTASIYA ABRAMOVA	{"email": "anastasiya-abramova-061968@postgrespro.ru", "phone": "+70141602445"}
0005433496963	B3692D	8942 887852	NATALIYA KUZMINA	{"phone": "+70035002739"}
0005433496964	50A124	1495 264605	ALEKSANDR ANDREEV	{"phone": "+70939644670"}
0005433496965	6AB4E8	8808 092360	EVGENIY DENISOV	{"email": "denisov_e-091953@postgrespro.ru", "phone": "+70760347711"}
0005433496966	209EE3	5711 256582	LYUDMILA STEPANOVA	{"phone": "+70524517905"}
0005433496967	862458	2712 362945	NIKOLAY VOLKOV	{"phone": "+70924645544"}
0005433496968	862458	9372 232737	GALINA ZHURAVLEVA	{"email": "g.zhuravleva_1965@postgrespro.ru", "phone": "+70761089776"}
0005433496969	FF70F7	1407 631069	VASILIY ANDREEV	{"email": "vasiliyandreev.05111970@postgrespro.ru", "phone": "+70988064018"}
0005433496970	E44B6B	1711 332711	EKATERINA ARKHIPOVA	{"email": "arkhipovaekaterina.1970@postgrespro.ru", "phone": "+70392411854"}
0005433496971	643623	0649 178406	NATALYA ALEKSANDROVA	{"phone": "+70037985110"}
0005433496972	643623	5970 062247	MIKHAIL KOROLEV	{"phone": "+70905957057"}
0005433496973	BFED94	6574 857073	OLGA KOZLOVA	{"phone": "+70790915145"}
0005433496974	C756F9	6854 690917	NATALYA MAKAROVA	{"phone": "+70628230099"}
0005433496975	C9E0D0	4558 520029	DARYA SEMENOVA	{"phone": "+70063249506"}
0005433496976	6BB8E0	4502 361729	YULIYA IVANOVA	{"phone": "+70287573612"}
0005433496977	6BB8E0	0490 653546	RINAT KUZNECOV	{"phone": "+70440600858"}
0005433496978	6BB8E0	7303 523027	STANISLAV KISELEV	{"email": "kiselevs1974@postgrespro.ru", "phone": "+70885487165"}
0005433496979	9AAB7F	9100 987203	PAVEL PAVLOV	{"phone": "+70839407056"}
0005433496980	9234B6	0757 207950	VYACHESLAV TIKHONOV	{"phone": "+70688478632"}
0005433496981	0C40D4	0171 960183	VADIM OSIPOV	{"email": "osipov.v1969@postgrespro.ru", "phone": "+70865842082"}
0005433496982	0C40D4	6251 085082	VALENTINA MIRONOVA	{"phone": "+70289617954"}
0005433496983	052E47	2882 551406	VLADIMIR KOROLEV	{"email": "vladimir-korolev-101972@postgrespro.ru", "phone": "+70146870052"}
0005433496984	052E47	7844 098196	ANASTASIYA ERMAKOVA	{"email": "anastasiya_ermakova_02071977@postgrespro.ru", "phone": "+70604446932"}
0005433496985	607731	5945 191623	ANDREY POPOV	{"phone": "+70907007687"}
0005433496986	12ECB5	3986 368013	NIKOLAY KISELEV	{"email": "kiselev.nikolay_04121958@postgrespro.ru", "phone": "+70269778855"}
0005433496987	12ECB5	0813 232266	VALERIY IVANOV	{"phone": "+70499517153"}
0005433496988	BB2520	3913 284380	MARIYA AFANASEVA	{"phone": "+70467305160"}
0005433496989	4F4176	8912 590738	LYAYSAN POPOVA	{"phone": "+70754328939"}
0005433496990	00B550	4727 649957	VLADIMIR SIDOROV	{"email": "sidorov.vladimir091971@postgrespro.ru", "phone": "+70562552334"}
0005433496991	2D589A	4899 711060	OLEG KUZNECOV	{"email": "oleg.kuznecov.051975@postgrespro.ru", "phone": "+70349484695"}
0005433496992	224B17	2804 203103	GALINA ERMAKOVA	{"phone": "+70732033022"}
0005433496993	966B5C	0401 667570	YULIYA VOROBEVA	{"email": "yuliyavorobeva.07051970@postgrespro.ru", "phone": "+70713416492"}
0005433496994	31B9E3	1881 842036	NADEZHDA FILIPPOVA	{"email": "filippova.n061981@postgrespro.ru", "phone": "+70634614569"}
0005433496995	25D943	9827 580291	ARTEM IVANOV	{"phone": "+70569262058"}
0005433496996	B0A5A1	7403 120303	MARINA MIRONOVA	{"email": "mironovamarina-061981@postgrespro.ru", "phone": "+70115085328"}
0005433496997	71327F	8018 314357	EKATERINA MELNIKOVA	{"phone": "+70313859242"}
0005433496998	71327F	5464 595813	SERGEY YAKOVLEV	{"email": "sergeyyakovlev_1968@postgrespro.ru", "phone": "+70083296257"}
0005433496999	4FA023	8070 312073	NADEZHDA AFANASEVA	{"phone": "+70757873392"}
0005433497000	11A489	5222 558292	ALEKSEY KUZMIN	{"phone": "+70124667334"}
0005433497001	EA8172	1971 637147	ELENA VOLKOVA	{"email": "e-volkova.1975@postgrespro.ru", "phone": "+70691900512"}
0005433497002	04FFEE	6957 752965	ANTON NOVIKOV	{"email": "novikov-a-05111961@postgrespro.ru", "phone": "+70915823936"}
0005433497003	2D0662	8662 512735	YURIY SMIRNOV	{"email": "y-smirnov.121977@postgrespro.ru", "phone": "+70311569593"}
0005433497004	2D0662	7994 881034	SERGEY KISELEV	{"phone": "+70187192042"}
0005433497005	D298A7	9178 336919	OLGA KOLESNIKOVA	{"email": "olga.kolesnikova_25041983@postgrespro.ru", "phone": "+70791749041"}
0005433497006	D298A7	2093 824004	EGOR KOROLEV	{"phone": "+70181298418"}
0005433497007	D298A7	1515 482754	VITALIY PETROV	{"phone": "+70123212190"}
0005433497008	081310	2649 794195	LARISA ALEKSEEVA	{"phone": "+70998269346"}
0005433497009	0828BF	6352 825716	MARINA TARASOVA	{"phone": "+70615179723"}
0005433497010	0828BF	7990 393170	LARISA OSIPOVA	{"phone": "+70243600229"}
0005433497011	0828BF	1227 055270	ALEKSEY ILIN	{"phone": "+70769956768"}
0005433497012	E0D35C	9555 617885	ARMEN ZHURAVLEV	{"email": "a.zhuravlev071967@postgrespro.ru", "phone": "+70276501516"}
0005433497013	E0D35C	7957 253410	NIKOLAY BELOV	{"phone": "+70317751776"}
0005433497014	FFF109	5902 685366	ARTEM ALEKSANDROV	{"email": "aleksandrov_a_121977@postgrespro.ru", "phone": "+70927564441"}
0005433497015	FFF109	0532 363189	BORIS SERGEEV	{"email": "borissergeev111989@postgrespro.ru", "phone": "+70759131305"}
0005433497016	FFF109	4398 617336	MAKSIM KUZMIN	{"email": "m-kuzmin1970@postgrespro.ru", "phone": "+70022801384"}
0005433497017	C4DF8A	1766 859729	NINA NIKOLAEVA	{"email": "n_nikolaeva-1964@postgrespro.ru", "phone": "+70285179963"}
0005433497018	2C685E	1170 713135	ALEKSEY POPOV	{"email": "aleksey_popov.1975@postgrespro.ru", "phone": "+70376543726"}
0005433497019	EE1E45	5532 639187	TATYANA ROMANOVA	{"email": "tatyana-romanova1976@postgrespro.ru", "phone": "+70601315040"}
0005433497020	2D9AE5	0068 069259	ANDREY KONOVALOV	{"email": "andrey.konovalov-06091981@postgrespro.ru", "phone": "+70341472958"}
0005433497021	2D9AE5	2102 256933	VSEVOLOD NAZAROV	{"email": "nazarov-v.1978@postgrespro.ru", "phone": "+70440079647"}
0005433497022	3CF093	0029 339434	ANATOLIY KUZNECOV	{"email": "kuznecov.anatoliy.20071968@postgrespro.ru", "phone": "+70104148685"}
0005433497023	3ED5D0	8863 163942	ALEKSEY PETROV	{"email": "petrova-11011965@postgrespro.ru", "phone": "+70951455367"}
0005433497024	715E81	6466 357611	LARISA ZHURAVLEVA	{"phone": "+70353367043"}
0005433497025	92D811	3806 945112	TATYANA NAZAROVA	{"email": "nazarova.tatyana-13081977@postgrespro.ru", "phone": "+70430005932"}
0005433497026	189A81	3047 184261	KIRILL CHERNOV	{"email": "kirillchernov_28021986@postgrespro.ru", "phone": "+70764075956"}
0005433497027	D46D5A	2619 853802	GLEB KONOVALOV	{"phone": "+70474806108"}
0005433497028	8E5580	0660 320022	NATALYA ALEKSANDROVA	{"phone": "+70380655728"}
0005433497029	8E5580	8064 222068	SERGEY ABRAMOV	{"email": "sabramov.08111975@postgrespro.ru", "phone": "+70243883595"}
0005433497030	D3251B	0913 148450	YULIYA IVANOVA	{"email": "ivanovayuliya-1965@postgrespro.ru", "phone": "+70823390721"}
0005433497031	D3251B	2025 013069	RASHID PAVLOV	{"email": "pavlov-r-071971@postgrespro.ru", "phone": "+70202710572"}
0005433497032	D3251B	4494 562239	SVETLANA POTAPOVA	{"email": "s-potapova.1982@postgrespro.ru", "phone": "+70475070710"}
0005433497033	1E90E0	5356 306430	TATYANA ZHUKOVA	{"phone": "+70101924863"}
0005433497034	1E90E0	2525 871208	MIKHAIL KOZLOV	{"email": "kozlov.mikhail12111975@postgrespro.ru", "phone": "+70365524274"}
0005433497035	8484A6	4662 753630	VALENTINA POPOVA	{"email": "popova_v-1963@postgrespro.ru", "phone": "+70449432284"}
0005433497036	B3823C	8075 536034	KONSTANTIN KUZNECOV	{"phone": "+70533940152"}
0005433497037	4CEC80	2328 332434	RUSTAM SERGEEV	{"email": "r_sergeev_051973@postgrespro.ru", "phone": "+70988170044"}
0005433497038	4CEC80	5879 888924	VALENTINA TITOVA	{"phone": "+70900899468"}
0005433497039	919C9F	0997 769609	OLEG IVANOV	{"email": "o.ivanov.121979@postgrespro.ru", "phone": "+70836660421"}
0005433497040	8D2E24	8171 771573	DMITRIY KUZMIN	{"phone": "+70402737001"}
0005433497041	609705	2770 949862	IGOR KUZNECOV	{"email": "igor.kuznecov_28081967@postgrespro.ru", "phone": "+70999506075"}
0005433497042	609705	6790 187130	IRINA ISAEVA	{"phone": "+70913712314"}
0005433497043	1964D3	6101 387582	KLAVDIYA VLASOVA	{"email": "vlasova_klavdiya_011984@postgrespro.ru", "phone": "+70446971663"}
0005433497044	1964D3	6174 765038	ANASTASIYA LEBEDEVA	{"email": "alebedeva-1973@postgrespro.ru", "phone": "+70460195910"}
0005433497045	D527F4	8488 951612	TAMARA TIMOFEEVA	{"phone": "+70347216514"}
0005433497046	EFDDE5	7578 650608	VLADISLAV MAKAROV	{"email": "v-makarov_14081967@postgrespro.ru", "phone": "+70388619943"}
0005433497047	BE0132	5904 226310	NADEZHDA MATVEEVA	{"phone": "+70074818952"}
0005433497048	BE0132	7864 145209	IVAN FEDOROV	{"email": "ifedorov-1978@postgrespro.ru", "phone": "+70281952214"}
0005433497049	38243D	2363 995898	LARISA NESTEROVA	{"phone": "+70947844339"}
0005433497050	797A8A	3719 290019	KIRILL MAKSIMOV	{"email": "maksimov-k_14081972@postgrespro.ru", "phone": "+70514501477"}
0005433497051	66DB40	4392 715643	EKATERINA LEBEDEVA	{"email": "ekaterina-lebedeva12041973@postgrespro.ru", "phone": "+70539622663"}
0005433497052	66DB40	9300 959265	VASILIY STEPANOV	{"phone": "+70086410308"}
0005433497053	61B942	5404 146912	LARISA STEPANOVA	{"email": "larisa-stepanova.1966@postgrespro.ru", "phone": "+70818556097"}
0005433497054	050D66	9764 484253	LILIYA PAVLOVA	{"email": "l_pavlova_1961@postgrespro.ru", "phone": "+70840970848"}
0005433497055	4DA826	1394 767268	SHAMIL GORBUNOV	{"email": "s_gorbunov.03111973@postgrespro.ru", "phone": "+70228412622"}
0005433497056	622DD3	2577 962381	ANASTASIYA GRISHINA	{"email": "a.grishina1981@postgrespro.ru", "phone": "+70982562562"}
0005433497057	BA12B9	1316 602441	ANASTASIYA VLASOVA	{"phone": "+70466278707"}
0005433497058	1C6550	9453 768466	VLADIMIR POPOV	{"email": "popov_vladimir-101969@postgrespro.ru", "phone": "+70638498825"}
0005433497059	C4290C	8816 600094	LYUDMILA NOVIKOVA	{"phone": "+70424125892"}
0005433497060	1870AD	7627 754070	VERA STEPANOVA	{"phone": "+70834233333"}
0005433497061	A46309	9108 835787	GALINA GRISHINA	{"phone": "+70327237431"}
0005433497062	A46309	0734 575212	ELENA SERGEEVA	{"email": "elena_sergeeva_1970@postgrespro.ru", "phone": "+70693442341"}
0005433497063	665DED	0024 993125	NINA KONOVALOVA	{"email": "nina_konovalova1972@postgrespro.ru", "phone": "+70905370803"}
0005433497064	E8C5D0	8946 108399	DMITRIY AFANASEV	{"phone": "+70946788168"}
0005433497065	196C12	7989 648132	MIKHAIL FILIPPOV	{"email": "mikhail_filippov1974@postgrespro.ru", "phone": "+70581643892"}
0005433497066	32781D	5860 538162	ALEVTINA KISELEVA	{"email": "a_kiseleva-1973@postgrespro.ru", "phone": "+70929498262"}
0005433497067	B65F91	6357 751541	ARTEM MELNIKOV	{"email": "artem.melnikov_1970@postgrespro.ru", "phone": "+70958300475"}
0005433497068	B65F91	1827 161002	VALENTINA ZHURAVLEVA	{"email": "valentina_zhuravleva-31081966@postgrespro.ru", "phone": "+70576896973"}
0005433497069	B65F91	5042 811077	ALEKSANDR SMIRNOV	{"phone": "+70178687873"}
0005433497070	2C995F	6256 850085	RAFAIL BELOV	{"phone": "+70645795413"}
0005433497071	2E2967	5547 972236	GULNARA ZAYCEVA	{"phone": "+70268019697"}
0005433497072	2E2967	0560 424834	ELENA MARTYNOVA	{"phone": "+70921053547"}
0005433497073	F6E068	9966 064509	GENNADIY ANTONOV	{"email": "antonovgennadiy_1980@postgrespro.ru", "phone": "+70438688452"}
0005433497074	D21C22	8838 832083	PAVEL FEDOROV	{"email": "fedorov.pavel-021971@postgrespro.ru", "phone": "+70585107850"}
0005433497075	F686EE	8942 998493	MIKHAIL FEDOTOV	{"phone": "+70008786865"}
0005433497076	68D07A	3586 596991	VLADIMIR VOLKOV	{"email": "vvolkov1966@postgrespro.ru", "phone": "+70834871228"}
0005433497077	FF6EF3	1720 882292	TATYANA FROLOVA	{"email": "frolova-t011972@postgrespro.ru", "phone": "+70855297161"}
0005433497078	B199BD	2878 405859	MARIYA ROMANOVA	{"email": "mariya-romanova_30041977@postgrespro.ru", "phone": "+70639475553"}
0005433497079	B199BD	7274 585928	VLADIMIR SAVELEV	{"email": "v.savelev.061971@postgrespro.ru", "phone": "+70416110045"}
0005433497080	0FBF51	5346 889587	NINA ZAKHAROVA	{"email": "n-zakharova03021971@postgrespro.ru", "phone": "+70119398890"}
0005433497081	0EC82A	2649 718471	DMITRIY FROLOV	{"phone": "+70448620795"}
0005433497082	73D2C4	6246 755921	YULIYA NESTEROVA	{"email": "nesterovayuliya-20021968@postgrespro.ru", "phone": "+70555677594"}
0005433497083	467203	6229 650726	DIANA ZAYCEVA	{"phone": "+70699558268"}
0005433497084	C855CF	1958 383105	ANNA NIKOLAEVA	{"email": "anna_nikolaeva-011980@postgrespro.ru", "phone": "+70074116108"}
0005433497085	B9620E	4331 681713	VALERIY CHERNOV	{"email": "chernovvaleriy.1968@postgrespro.ru", "phone": "+70337819371"}
0005433497086	B9620E	2530 613514	TATYANA VASILEVA	{"email": "t-vasileva.061972@postgrespro.ru", "phone": "+70811408702"}
0005433497087	2B31C2	4768 405554	YURIY EGOROV	{"email": "egorov.yuriy-011962@postgrespro.ru", "phone": "+70549153421"}
0005433497088	2B31C2	2870 615858	VASILIY SMIRNOV	{"phone": "+70095211854"}
0005433497089	2B31C2	6251 871109	NIKOLAY SHEVCHENKO	{"phone": "+70074094482"}
0005433497090	A743DB	0835 182264	NINA BARANOVA	{"email": "ninabaranova.081971@postgrespro.ru", "phone": "+70580353909"}
0005433497091	9129D3	8988 698311	LIDIYA SMIRNOVA	{"email": "smirnova.l041980@postgrespro.ru", "phone": "+70085737383"}
0005433497092	F31574	7066 201498	ILYA ZAYCEV	{"email": "zaycev_ilya_011966@postgrespro.ru", "phone": "+70712787918"}
0005433497093	AA7901	2904 672025	IGOR MIKHAYLOV	{"phone": "+70452150405"}
0005433497094	AA7901	8296 808003	ALEKSEY PETROV	{"email": "aleksey_petrov_1976@postgrespro.ru", "phone": "+70137034872"}
0005433497095	BBFB77	9888 715976	TATYANA DAVYDOVA	{"phone": "+70835256337"}
0005433497096	A93642	1415 237349	OLGA ZAKHAROVA	{"phone": "+70319360272"}
0005433497097	AD5C67	6967 425826	OLGA NESTEROVA	{"email": "nesterovao.011961@postgrespro.ru", "phone": "+70242123625"}
0005433497098	FD2F05	4106 365583	ALLA RODIONOVA	{"email": "allarodionova.091973@postgrespro.ru", "phone": "+70306740627"}
0005433497099	BA86AB	4898 158156	NINA ISAEVA	{"email": "nina-isaeva.1967@postgrespro.ru", "phone": "+70467255514"}
0005433497100	1EC127	2554 448934	EVGENIY ROMANOV	{"email": "evgeniy.romanov19111967@postgrespro.ru", "phone": "+70038426453"}
0005433497101	1EC127	6124 274790	LEONID PETROV	{"phone": "+70785505316"}
0005433497102	5490E1	9096 345195	ELENA GORBUNOVA	{"phone": "+70559570325"}
0005433497103	2D0A4E	5303 429376	VALENTINA EGOROVA	{"phone": "+70545472179"}
0005433497104	BDD9EE	8731 738580	KLAVDIYA AFANASEVA	{"phone": "+70129112265"}
0005433497105	838581	3493 554920	OLGA GUSEVA	{"phone": "+70644184610"}
0005433497106	C0B2AF	3396 509969	ELIZAVETA KOZLOVA	{"phone": "+70977158886"}
0005433497107	C0B2AF	1661 574531	ANASTASIYA SCHERBAKOVA	{"phone": "+70705342236"}
0005433497108	C0B2AF	4421 516949	ANDREY FEDOTOV	{"phone": "+70162211374"}
0005433497109	A870FB	2472 954023	MAKSIM ZAYCEV	{"phone": "+70613325683"}
0005433497110	A870FB	0653 392369	VLADIMIR ZAYCEV	{"email": "vladimir-zaycev.1969@postgrespro.ru", "phone": "+70224726142"}
0005433497111	A870FB	1553 139684	NIKOLAY EGOROV	{"email": "n_egorov-091964@postgrespro.ru", "phone": "+70318750959"}
0005433497112	2F34C8	5701 427723	VALERIY ORLOV	{"email": "orlov.valeriy.24071977@postgrespro.ru", "phone": "+70366005825"}
0005433497113	E8A0AB	0569 820482	ALEKSANDR POPOV	{"phone": "+70591137689"}
0005433497114	2C19B8	1586 158147	VIKTOR KOZLOV	{"email": "v-kozlov1977@postgrespro.ru", "phone": "+70063503276"}
0005433497115	2C19B8	1473 931849	NATALYA DENISOVA	{"phone": "+70219461450"}
0005433497116	55803D	4517 510117	NATALYA POPOVA	{"email": "popova-n_20111974@postgrespro.ru", "phone": "+70725530331"}
0005433497117	55803D	3471 217561	OLGA MELNIKOVA	{"phone": "+70660122191"}
0005433497118	BF6CD0	5509 027629	RAISA KRASNOVA	{"email": "krasnova-r.031968@postgrespro.ru", "phone": "+70682162494"}
0005433497119	BF6CD0	9073 540536	ALEKSANDR GAVRILOV	{"phone": "+70364735296"}
0005433497120	D8C184	7928 716793	NATALYA GORBUNOVA	{"phone": "+70551092531"}
0005433497121	D8C184	1807 146466	VLADIMIR YAKOVLEV	{"phone": "+70552568559"}
0005433497122	475489	7951 089344	VALERIY ILIN	{"email": "valeriy-ilin071969@postgrespro.ru", "phone": "+70187371342"}
0005433497123	48AC61	1205 313914	SVETLANA FROLOVA	{"email": "s.frolova.14111983@postgrespro.ru", "phone": "+70799311449"}
0005433497124	5AB5CD	2868 483629	INNA SIDOROVA	{"email": "sidorova.inna-02101958@postgrespro.ru", "phone": "+70682651680"}
0005433497125	B69135	6086 889321	NATALYA NIKITINA	{"email": "natalya.nikitina21101976@postgrespro.ru", "phone": "+70765607493"}
0005433497126	DF36BC	7762 175336	ALINA TARASOVA	{"email": "alinatarasova21021969@postgrespro.ru", "phone": "+70888212285"}
0005433497127	2DB2C3	6612 047427	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov-1985@postgrespro.ru", "phone": "+70437634624"}
0005433497128	2DB2C3	0025 350028	MARIYA NESTEROVA	{"email": "mariya_nesterova.111978@postgrespro.ru", "phone": "+70574827849"}
0005433497129	3A0CE9	9151 616148	ALEKSANDR MEDVEDEV	{"phone": "+70953904701"}
0005433497130	3A0CE9	4835 496040	NIKOLAY DENISOV	{"phone": "+70439134984"}
0005433497131	10FEF1	9006 046752	NIKOLAY ANTONOV	{"phone": "+70649749845"}
0005433497132	10FEF1	5794 409218	TAMARA MARTYNOVA	{"email": "tmartynova_1979@postgrespro.ru", "phone": "+70492342161"}
0005433497133	B2ED97	6957 228329	SERGEY MOISEEV	{"phone": "+70252348606"}
0005433497134	B2ED97	2500 073842	ALEKSANDR NIKOLAEV	{"email": "anikolaev_06121979@postgrespro.ru", "phone": "+70831687839"}
0005433497135	6106A1	8763 870615	OLGA NIKOLAEVA	{"phone": "+70285757393"}
0005433497136	6106A1	7659 321428	DMITRIY KAZAKOV	{"phone": "+70763615338"}
0005433497137	6106A1	1591 024018	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev.121978@postgrespro.ru", "phone": "+70254311656"}
0005433497138	886E93	5777 081302	ANATOLIY IVANOV	{"phone": "+70720281410"}
0005433497139	C2B9D0	6657 073056	KONSTANTIN SOROKIN	{"email": "sorokin.konstantin.05081976@postgrespro.ru", "phone": "+70045722075"}
0005433497140	0B1C85	2695 557128	ELIZAVETA DENISOVA	{"phone": "+70521319196"}
0005433497141	0B1C85	7287 720272	ILYA BELOV	{"email": "belovi1976@postgrespro.ru", "phone": "+70925672190"}
0005433497142	F7E889	7890 761977	ALEKSANDR VASILEV	{"phone": "+70630369138"}
0005433497143	A07304	1944 700723	MARIYA ZAKHAROVA	{"email": "zakharova-mariya-19061965@postgrespro.ru", "phone": "+70059500971"}
0005433497144	A07304	1691 483179	SVETLANA YAKOVLEVA	{"phone": "+70966244007"}
0005433497145	5E84D1	1716 112557	SERGEY PETROV	{"phone": "+70771414901"}
0005433497146	96F435	2459 845916	SERGEY MAKAROV	{"phone": "+70495544206"}
0005433497147	379C4A	3905 381895	IVAN ZAKHAROV	{"email": "ivan-zakharov_101969@postgrespro.ru", "phone": "+70575299772"}
0005433497148	47D065	7982 348333	SERGEY KRASNOV	{"phone": "+70796819805"}
0005433497149	FA7BEA	3153 714817	DMITRIY NAUMOV	{"phone": "+70165380254"}
0005433497150	FA7BEA	9705 454252	ALEKSANDR KUZMIN	{"phone": "+70194722664"}
0005433497151	E0CFA1	5514 500513	ALEKSEY GERASIMOV	{"email": "aleksey.gerasimov.071966@postgrespro.ru", "phone": "+70575095149"}
0005433497152	E0CFA1	6200 580158	NINA FROLOVA	{"email": "ninafrolova.13121969@postgrespro.ru", "phone": "+70881238572"}
0005433497153	8B14FE	1304 333581	VALERIY FROLOV	{"phone": "+70179319028"}
0005433497154	D73CB9	6496 245323	SERGEY DMITRIEV	{"phone": "+70890499984"}
0005433497155	D73CB9	2593 713219	ALEKSANDR MOROZOV	{"email": "a-morozov1967@postgrespro.ru", "phone": "+70940923154"}
0005433497156	9BF0FC	4996 709030	VERONIKA KULIKOVA	{"email": "kulikovav021970@postgrespro.ru", "phone": "+70014972590"}
0005433497157	C88A95	0202 948995	ANDREY KUZNECOV	{"phone": "+70685080277"}
0005433497158	A5BDFC	1252 586073	MARIYA MASLOVA	{"email": "maslova-mariya-1987@postgrespro.ru", "phone": "+70385420065"}
0005433497159	A39DC7	4017 748347	ALEKSANDR MELNIKOV	{"phone": "+70768483496"}
0005433497160	669BAF	5544 252587	MAKSIM TARASOV	{"email": "m.tarasov-09111962@postgrespro.ru", "phone": "+70146290941"}
0005433497161	7E0E6C	2169 043418	VIKTOR GORBUNOV	{"email": "viktor_gorbunov.23081975@postgrespro.ru", "phone": "+70129929340"}
0005433497162	7E0E6C	4010 938549	LEONID SEMENOV	{"email": "semenov-leonid-1969@postgrespro.ru", "phone": "+70382290732"}
0005433497163	6883F8	2728 057519	ANTON GUSEV	{"email": "a.gusev.1968@postgrespro.ru", "phone": "+70842879512"}
0005433497164	3A16BB	5705 024814	NADEZHDA KONDRATEVA	{"phone": "+70900617386"}
0005433497165	3A16BB	8112 785160	ANASTASIYA NAZAROVA	{"email": "nazarovaanastasiya1968@postgrespro.ru", "phone": "+70512461638"}
0005433497166	8E3246	7673 637749	NATALIYA NIKITINA	{"email": "nataliya_nikitina.02061975@postgrespro.ru", "phone": "+70211903744"}
0005433497167	8E3246	8668 268441	VALERIY FEDOROV	{"phone": "+70458870707"}
0005433497168	8E3246	6820 561105	GENNADIY KUZMIN	{"email": "kuzmin-gennadiy.081962@postgrespro.ru", "phone": "+70541151546"}
0005433497169	442911	4967 459996	VLADIMIR GUSEV	{"email": "v.gusev1969@postgrespro.ru", "phone": "+70529177263"}
0005433497170	442911	4925 974654	YURIY DAVYDOV	{"phone": "+70290371888"}
0005433497171	C7CB19	3980 738018	LARISA OSIPOVA	{"phone": "+70783116148"}
0005433497172	24E7DD	6413 476760	KSENIYA FROLOVA	{"phone": "+70292937362"}
0005433497173	21609C	8568 302816	NADEZHDA NIKOLAEVA	{"phone": "+70817162054"}
0005433497174	771C6F	3464 688908	OLGA VLASOVA	{"email": "vlasovaolga.23121980@postgrespro.ru", "phone": "+70609058301"}
0005433497175	771C6F	2266 615860	MARINA SEMENOVA	{"email": "semenovam11071972@postgrespro.ru", "phone": "+70797664323"}
0005433497176	1DED4C	0795 709290	ARTEM MATVEEV	{"phone": "+70368377227"}
0005433497177	20D6B6	6306 678795	NADEZHDA SERGEEVA	{"email": "sergeeva.n.051980@postgrespro.ru", "phone": "+70214821892"}
0005433497178	20D6B6	9026 245848	RAVIL VOROBEV	{"phone": "+70499839570"}
0005433497179	3DD93D	2477 292473	MARIYA NIKOLAEVA	{"email": "mariya.nikolaeva.011975@postgrespro.ru", "phone": "+70638044325"}
0005433497180	6C15CD	3152 308971	GALINA EGOROVA	{"email": "galina_egorova25011982@postgrespro.ru", "phone": "+70328567753"}
0005433497181	241CBD	4180 990448	NATALYA FILATOVA	{"email": "filatovan-041979@postgrespro.ru", "phone": "+70970606523"}
0005433497182	241CBD	1917 253347	VALENTINA ABRAMOVA	{"email": "abramovav-26111970@postgrespro.ru", "phone": "+70930756137"}
0005433497183	D87E5B	6525 015452	IRINA SOROKINA	{"email": "i.sorokina.1985@postgrespro.ru", "phone": "+70596449015"}
0005433497184	A5AFDB	0695 296272	PAVEL IVANOV	{"phone": "+70102268676"}
0005433497185	A5AFDB	8136 750682	LYUBOV KALININA	{"phone": "+70278671160"}
0005433497186	268A99	7201 137601	VARVARA KOROLEVA	{"phone": "+70815012178"}
0005433497187	268A99	8275 587427	EVGENIY NIKITIN	{"phone": "+70516487043"}
0005433497188	93C5BD	2761 040693	MARIYA TIKHONOVA	{"email": "tikhonova_m-29121974@postgrespro.ru", "phone": "+70228812623"}
0005433497189	F01C3E	2623 810005	RIMMA KUZNECOVA	{"phone": "+70288385081"}
0005433497190	D388AD	9568 168877	SVETLANA POPOVA	{"email": "s-popova.021980@postgrespro.ru", "phone": "+70979985374"}
0005433497191	D388AD	2636 392642	STANISLAV NAZAROV	{"email": "stanislav-nazarov_111971@postgrespro.ru", "phone": "+70384378638"}
0005433497192	0821BC	0288 688777	VLADIMIR TIMOFEEV	{"phone": "+70737307015"}
0005433497193	0821BC	1522 615062	OLESYA BORISOVA	{"phone": "+70732263235"}
0005433497194	0821BC	0735 600249	SERGEY DMITRIEV	{"phone": "+70260808936"}
0005433497195	09377B	8081 956241	VALERIY ALEKSANDROV	{"email": "aleksandrov_valeriy_08121977@postgrespro.ru", "phone": "+70921108058"}
0005433497196	89886D	3527 003578	ALEKSEY TIKHONOV	{"phone": "+70243065121"}
0005433497197	2D5753	1870 708601	OLGA VASILEVA	{"email": "vasileva_olga_23081977@postgrespro.ru", "phone": "+70813834379"}
0005433497198	815E82	5190 801127	ANNA KOZLOVA	{"phone": "+70870781364"}
0005433497199	815E82	3135 515552	ANTONINA YUDINA	{"phone": "+70269698194"}
0005433497200	88647C	6717 809880	LYUBOV NIKIFOROVA	{"email": "lyubov.nikiforova-101977@postgrespro.ru", "phone": "+70936289469"}
0005433497201	88647C	1661 957323	NATALYA POLYAKOVA	{"phone": "+70866539783"}
0005433497202	F1614B	0613 811404	EVGENIY ANDREEV	{"email": "andreev.evgeniy.091978@postgrespro.ru", "phone": "+70637069679"}
0005433497203	F1614B	9336 913645	ALISA NAUMOVA	{"phone": "+70791380264"}
0005433497204	F1614B	9789 758353	OLGA POPOVA	{"email": "popova.o_1972@postgrespro.ru", "phone": "+70945323564"}
0005433497205	93A1B2	1462 293432	MARIYA KOROLEVA	{"phone": "+70157391693"}
0005433497206	93A1B2	4486 034353	KRISTINA ZHUKOVA	{"email": "kristina_zhukova-06101962@postgrespro.ru", "phone": "+70724355659"}
0005433497207	93A1B2	1435 415810	SVETLANA ZHUKOVA	{"email": "zhukovas-01101972@postgrespro.ru", "phone": "+70314074209"}
0005433497208	F1C614	2774 879480	IRINA ZAKHAROVA	{"phone": "+70433943106"}
0005433497209	078776	0119 395771	MARINA SOROKINA	{"email": "sorokina.marina14041968@postgrespro.ru", "phone": "+70147288488"}
0005433497210	D3A144	2620 723509	ANDREY SERGEEV	{"phone": "+70559808170"}
0005433497211	D3A144	2794 883656	YULIYA KALININA	{"phone": "+70479198702"}
0005433497212	D3A144	1354 248167	SERGEY YAKOVLEV	{"phone": "+70411602723"}
0005433497213	BB1C43	6353 321267	TATYANA SERGEEVA	{"phone": "+70055093100"}
0005433497214	BB1C43	7265 700366	MARINA SEMENOVA	{"email": "marina-semenova_041975@postgrespro.ru", "phone": "+70428047718"}
0005433497215	A5FEBC	4951 354995	ILYA ALEKSEEV	{"phone": "+70706943937"}
0005433497216	307BBC	0333 745666	DMITRIY KRASNOV	{"email": "d-krasnov-06031968@postgrespro.ru", "phone": "+70044122476"}
0005433497217	EDD9CF	2985 012169	ANDREY EGOROV	{"email": "aegorov.1973@postgrespro.ru", "phone": "+70652720603"}
0005433497218	FEC1BE	2216 922333	ALEKSANDR DMITRIEV	{"phone": "+70952720604"}
0005433497219	D1F225	5561 887694	FATIMA ALEKSANDROVA	{"email": "aleksandrova.fatima.111968@postgrespro.ru", "phone": "+70872737554"}
0005433497220	B2D051	7299 753403	ELENA VOLKOVA	{"email": "volkovaelena.1974@postgrespro.ru", "phone": "+70358487732"}
0005433497221	612EA8	4422 696374	TATYANA LOGINOVA	{"phone": "+70298567655"}
0005433497222	E07CE0	7647 188853	LYUBOV NIKIFOROVA	{"email": "nikiforova-l081966@postgrespro.ru", "phone": "+70431996558"}
0005433497223	84A8D6	9577 531903	SERGEY IVANOV	{"email": "s-ivanov22101973@postgrespro.ru", "phone": "+70482774564"}
0005433497224	84A8D6	9077 043847	ALEKSANDR ORLOV	{"phone": "+70706922339"}
0005433497225	84A8D6	1189 262547	ELENA ZAKHAROVA	{"phone": "+70304216101"}
0005433497226	93ACB4	8392 112615	ALEKSANDR POPOV	{"email": "aleksandr-popov_1966@postgrespro.ru", "phone": "+70344953880"}
0005433497227	34630E	5149 339638	KRISTINA ZAYCEVA	{"email": "kristinazayceva.1971@postgrespro.ru", "phone": "+70494554418"}
0005433497228	34630E	0530 355293	GALINA PAVLOVA	{"phone": "+70276728507"}
0005433497229	34630E	2425 741661	TATYANA MOROZOVA	{"email": "tatyana_morozova02111967@postgrespro.ru", "phone": "+70285357963"}
0005433497230	6D2D11	9199 498418	ALEKSEY KRASNOV	{"email": "a-krasnov121964@postgrespro.ru", "phone": "+70648577810"}
0005433497231	5D38BB	7017 581862	LEV ISAEV	{"email": "isaev_lev-1963@postgrespro.ru", "phone": "+70333224564"}
0005433497232	5D38BB	8553 303368	SVETLANA KOROLEVA	{"email": "s_koroleva.20081962@postgrespro.ru", "phone": "+70176258645"}
0005433497233	978F32	2700 106257	DENIS KUZMIN	{"email": "dkuzmin.041983@postgrespro.ru", "phone": "+70049574572"}
0005433497234	BF46AF	3679 690412	YULIYA MOROZOVA	{"phone": "+70835504887"}
0005433497235	BF46AF	1998 048543	YURIY VASILEV	{"phone": "+70325529472"}
0005433497236	3B4B76	8691 926012	ANTON SAVELEV	{"email": "savelev-anton.1963@postgrespro.ru", "phone": "+70475920149"}
0005433497237	5723C2	7328 423106	VALERIY FROLOV	{"email": "frolovv15011961@postgrespro.ru", "phone": "+70779635256"}
0005433497238	1DCA7B	4217 957330	EVGENIY ZAKHAROV	{"email": "zakharov_e-31031974@postgrespro.ru", "phone": "+70080305356"}
0005433497239	1DCA7B	2689 013093	ARTEM KRASNOV	{"email": "a-krasnov.1968@postgrespro.ru", "phone": "+70280247569"}
0005433497240	F5A77C	0485 303890	ELENA TITOVA	{"email": "titova-elena06101975@postgrespro.ru", "phone": "+70889796685"}
0005433497241	F5A77C	1640 997940	VALENTIN MEDVEDEV	{"phone": "+70553785911"}
0005433497242	97A2D9	0896 231221	KONSTANTIN SAVELEV	{"phone": "+70211941765"}
0005433497243	7DCC61	7587 518246	MARINA BELOVA	{"email": "belova_m_10121980@postgrespro.ru", "phone": "+70232124839"}
0005433497244	40C16E	0771 773186	OLGA IVANOVA	{"phone": "+70540414390"}
0005433497245	0617AD	4442 096204	OLGA ROMANOVA	{"email": "oromanova-30061969@postgrespro.ru", "phone": "+70570471049"}
0005433497246	0617AD	1454 392728	RUSLAN NIKITIN	{"email": "ruslan-nikitin1972@postgrespro.ru", "phone": "+70351018090"}
0005433497247	1FCCAF	6813 123522	ALEKSANDR NIKITIN	{"email": "nikitin.aleksandr.05021964@postgrespro.ru", "phone": "+70989540946"}
0005433497248	C5CF4D	5819 576999	SVETLANA MARTYNOVA	{"email": "martynova-svetlana.30061972@postgrespro.ru", "phone": "+70398633817"}
0005433497249	AD78F8	7883 833090	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov_14041970@postgrespro.ru", "phone": "+70159345136"}
0005433497250	9BB613	3682 250432	ALEKSEY EGOROV	{"phone": "+70463115771"}
0005433497251	9BB613	0180 283313	NIKOLAY KARPOV	{"phone": "+70441949686"}
0005433497252	8F3E4B	7770 250701	ILMIRA TROFIMOVA	{"phone": "+70549255482"}
0005433497253	8F3E4B	9881 236303	NIKITA ANDREEV	{"phone": "+70835751248"}
0005433497254	E71310	0299 545325	SVETLANA EFIMOVA	{"email": "efimovasvetlana1973@postgrespro.ru", "phone": "+70470383736"}
0005433497255	B82CD5	1611 186185	ALEKSANDRA ABRAMOVA	{"phone": "+70619980009"}
0005433497256	953EE5	2203 115157	KIRILL ZAYCEV	{"phone": "+70033290794"}
0005433497257	953EE5	1518 224744	NINA NESTEROVA	{"phone": "+70892432599"}
0005433497258	953EE5	4741 558610	LYUDMILA OSIPOVA	{"email": "lyudmila.osipova021958@postgrespro.ru", "phone": "+70391556795"}
0005433497259	F0921D	7365 574667	LILIYA SOROKINA	{"phone": "+70223814078"}
0005433497260	C3E2CB	7591 389248	MAKSIM KISELEV	{"phone": "+70914304675"}
0005433497261	2F6FC3	5328 238432	MARINA FEDOROVA	{"email": "fedorova_marina_1977@postgrespro.ru", "phone": "+70764374050"}
0005433497262	AA6C24	3586 777356	ALINA IVANOVA	{"email": "a-ivanova1976@postgrespro.ru", "phone": "+70568323571"}
0005433497263	4EE9A4	7836 871539	IGOR TIKHONOV	{"phone": "+70330839671"}
0005433497264	E67D69	4594 207239	VALENTINA MELNIKOVA	{"email": "melnikova_v.021983@postgrespro.ru", "phone": "+70713953609"}
0005433497265	E67D69	2246 243487	OKSANA DANILOVA	{"email": "danilova-oksana031983@postgrespro.ru", "phone": "+70532410621"}
0005433497266	CB7239	1274 004415	EGOR ANDREEV	{"phone": "+70548400094"}
0005433497267	CB7239	8794 448590	ILNUR GUSEV	{"email": "gusev.ilnur.011970@postgrespro.ru", "phone": "+70361290058"}
0005433497268	353F93	2497 244046	SERGEY GAVRILOV	{"phone": "+70267918520"}
0005433497269	5D9B17	7880 529538	VLADIMIR SEMENOV	{"phone": "+70256178062"}
0005433497270	5D9B17	0779 730622	IVAN POPOV	{"email": "popov.i18011971@postgrespro.ru", "phone": "+70836424114"}
0005433497271	1AB984	1594 089340	VALENTINA KOROLEVA	{"email": "vkoroleva_1976@postgrespro.ru", "phone": "+70325417163"}
0005433497328	B79070	0069 747250	GALINA KUZMINA	{"phone": "+70754102013"}
0005433497272	1AB984	2482 063411	OKSANA SOKOLOVA	{"email": "oksana_sokolova.19121977@postgrespro.ru", "phone": "+70980784614"}
0005433497273	5BAA2A	6645 780522	LARISA FILATOVA	{"email": "filatova-l-111985@postgrespro.ru", "phone": "+70625556357"}
0005433497274	37891D	8422 362454	ANATOLIY SEMENOV	{"phone": "+70113857734"}
0005433497275	1D33FD	8526 331608	NADEZHDA OSIPOVA	{"email": "osipova-nadezhda1977@postgrespro.ru", "phone": "+70064624302"}
0005433497276	1D33FD	2312 521849	ANATOLIY BONDARENKO	{"email": "a-bondarenko.091970@postgrespro.ru", "phone": "+70131700574"}
0005433497277	213F99	9624 737979	LYUDMILA IVANOVA	{"email": "ivanoval041974@postgrespro.ru", "phone": "+70782637011"}
0005433497278	80118A	1656 718872	LYUDMILA IVANOVA	{"phone": "+70487028930"}
0005433497279	CAADF6	1031 033703	OLGA IVANOVA	{"email": "ivanova_olga-29121971@postgrespro.ru", "phone": "+70579469462"}
0005433497280	41C0D9	9477 160971	SVETLANA KOROLEVA	{"phone": "+70795366963"}
0005433497281	CB23AF	1285 648881	NELLI VLASOVA	{"email": "n-vlasova03011975@postgrespro.ru", "phone": "+70682269265"}
0005433497282	24E020	0351 904523	EVGENIY GAVRILOV	{"phone": "+70369085092"}
0005433497283	90F8AE	8455 195280	SERGEY PAVLOV	{"email": "sergey_pavlov091958@postgrespro.ru", "phone": "+70902122348"}
0005433497284	705D96	5803 841157	LYUBOV KALININA	{"email": "lyubov.kalinina-1955@postgrespro.ru", "phone": "+70590200772"}
0005433497285	C918F9	2483 021597	RUSLAN SCHERBAKOV	{"email": "scherbakovr_26081968@postgrespro.ru", "phone": "+70129604991"}
0005433497286	E2A95F	3390 602004	BULAT KULIKOV	{"phone": "+70026084311"}
0005433497287	E2A95F	5806 315307	DANIYA KRASNOVA	{"phone": "+70393198382"}
0005433497288	B03A0B	0289 340694	ELENA DMITRIEVA	{"email": "dmitrievae_071970@postgrespro.ru", "phone": "+70424542136"}
0005433497289	B03A0B	5908 369129	ILDAR SOROKIN	{"email": "sorokin.i_1973@postgrespro.ru", "phone": "+70047717358"}
0005433497290	B03A0B	7098 003177	TATYANA KISELEVA	{"phone": "+70570224968"}
0005433497291	11E5DC	1404 181731	NIKOLAY ORLOV	{"email": "orlovn-20011970@postgrespro.ru", "phone": "+70682619624"}
0005433497292	5F80D6	3009 771322	ANNA KOROLEVA	{"phone": "+70640516595"}
0005433497293	EF57D4	7418 758904	YULIYA KOROLEVA	{"email": "koroleva_y-25021975@postgrespro.ru", "phone": "+70970630493"}
0005433497294	B56514	4079 601353	TATYANA SOROKINA	{"phone": "+70194145959"}
0005433497295	C47006	9133 300924	FEDOR FOMIN	{"phone": "+70468374953"}
0005433497296	4D811B	7629 489953	NIKITA ISAEV	{"phone": "+70291780432"}
0005433497297	4D811B	3615 558033	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr.13111977@postgrespro.ru", "phone": "+70520076050"}
0005433497298	119946	4958 756295	ALEKSANDR KISELEV	{"phone": "+70858674755"}
0005433497299	A9DED2	6330 374923	NADEZHDA DENISOVA	{"email": "nadezhda-denisova-011972@postgrespro.ru", "phone": "+70845989374"}
0005433497300	7B9E3E	4349 434381	NATALIYA YAKOVLEVA	{"phone": "+70852048768"}
0005433497301	CDD42F	0982 356506	POLINA YUDINA	{"phone": "+70108126881"}
0005433497302	6F796A	4719 922730	VASILIY ROMANOV	{"phone": "+70372469757"}
0005433497303	BD77B9	5768 602898	GLEB DAVYDOV	{"phone": "+70169005803"}
0005433497304	A0CCE8	2149 769762	VLADIMIR OSIPOV	{"phone": "+70678815923"}
0005433497305	A0CCE8	9298 484572	VERA NIKITINA	{"email": "vera-nikitina.29091988@postgrespro.ru", "phone": "+70016727630"}
0005433497306	ECFB7C	1866 316087	VALENTINA POPOVA	{"email": "vpopova-1961@postgrespro.ru", "phone": "+70695014839"}
0005433497307	88827E	2276 779951	OLGA SIDOROVA	{"phone": "+70858475294"}
0005433497308	B510C6	7825 555262	DMITRIY BELOV	{"phone": "+70198152651"}
0005433497309	0D857F	5499 511751	ELENA MELNIKOVA	{"email": "elena_melnikova.061964@postgrespro.ru", "phone": "+70354901698"}
0005433497310	8EC86E	3967 666950	OLEG RODIONOV	{"email": "o-rodionov.051974@postgrespro.ru", "phone": "+70921590508"}
0005433497311	E79413	7386 779996	DENIS GAVRILOV	{"email": "gavrilov-d.08041985@postgrespro.ru", "phone": "+70236102717"}
0005433497312	E79413	2376 821651	EVGENIYA VOROBEVA	{"phone": "+70959817276"}
0005433497313	E79413	1408 638569	GENNADIY POPOV	{"phone": "+70024660309"}
0005433497314	B8C8A2	4562 930911	SERGEY SERGEEV	{"phone": "+70565179750"}
0005433497315	C64E5E	9965 308850	SERGEY MATVEEV	{"email": "sergey_matveev.14081977@postgrespro.ru", "phone": "+70710721985"}
0005433497316	12AA0B	2464 795031	ELENA KOZLOVA	{"phone": "+70864095852"}
0005433497317	12AA0B	1859 724326	EVGENIY FOMIN	{"email": "fomine-03081980@postgrespro.ru", "phone": "+70416002019"}
0005433497318	7E19C0	2996 464651	ANTON ALEKSANDROV	{"phone": "+70162277078"}
0005433497319	7E19C0	5577 327648	EKATERINA KALININA	{"email": "ekalinina.1973@postgrespro.ru", "phone": "+70131827590"}
0005433497320	616E5D	8917 461951	RAVIL ANDREEV	{"phone": "+70386977304"}
0005433497321	3CD652	2546 217434	NIKOLAY SEMENOV	{"email": "nikolaysemenov1977@postgrespro.ru", "phone": "+70187810556"}
0005433497322	32D06B	5237 769229	ALEKSEY CHERNOV	{"email": "chernov.a1974@postgrespro.ru", "phone": "+70032149686"}
0005433497323	D91375	8528 018365	ARSENIY ALEKSANDROV	{"email": "arseniy-aleksandrov-15041972@postgrespro.ru", "phone": "+70774789932"}
0005433497324	66981B	8868 350597	SERGEY AFANASEV	{"phone": "+70291027461"}
0005433497325	0C84F7	7044 524853	ALEKSEY VASILEV	{"phone": "+70674737018"}
0005433497326	A26DA8	0935 381668	DMITRIY KULIKOV	{"email": "kulikov_dmitriy_1979@postgrespro.ru", "phone": "+70504209640"}
0005433497327	A26DA8	0792 513103	IVAN POPOV	{"phone": "+70910772162"}
0005433497329	E94E11	3770 603919	ANASTASIYA FEDOROVA	{"email": "fedorova_a_011970@postgrespro.ru", "phone": "+70309873617"}
0005433497330	95EA04	3486 042025	YULIYA KUZMINA	{"phone": "+70336154744"}
0005433497331	EFCC59	7857 009655	NATALYA KISELEVA	{"phone": "+70372703352"}
0005433497332	EFCC59	1053 844711	SNEZHANA VOROBEVA	{"email": "svorobeva.041974@postgrespro.ru", "phone": "+70308365974"}
0005433497333	F50359	3053 936108	ANASTASIYA SCHERBAKOVA	{"phone": "+70821797747"}
0005433497334	F50359	2611 088732	OLGA ZHURAVLEVA	{"phone": "+70700123406"}
0005433497335	BB2A91	8147 460276	IRINA POPOVA	{"phone": "+70620038588"}
0005433497336	299FE1	2667 976828	NIKOLAY MIKHAYLOV	{"phone": "+70666607093"}
0005433497337	07FFAA	0874 078872	ALEKSANDR IVANOV	{"phone": "+70752244954"}
0005433497338	F07477	3278 054511	GENNADIY MAKAROV	{"email": "g_makarov1976@postgrespro.ru", "phone": "+70970280793"}
0005433497339	AF3CCB	8918 911843	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov_061969@postgrespro.ru", "phone": "+70915502762"}
0005433497340	AF3CCB	4460 579439	EKATERINA GUSEVA	{"email": "guseva-ekaterina1969@postgrespro.ru", "phone": "+70528269926"}
0005433497341	AC4D95	9923 124928	NINA VASILEVA	{"phone": "+70127782931"}
0005433497342	B4D812	4222 123796	SERGEY POPOV	{"email": "spopov1965@postgrespro.ru", "phone": "+70292358331"}
0005433497343	4CBDE9	4093 694773	GENNADIY KUZNECOV	{"email": "gennadiy.kuznecov.16041973@postgrespro.ru", "phone": "+70814274811"}
0005433497344	698B95	5718 880226	ALEKSANDR NAZAROV	{"email": "nazarov.a-051968@postgrespro.ru", "phone": "+70194061343"}
0005433497345	698B95	1461 779261	SERGEY BELOV	{"email": "sergeybelov111966@postgrespro.ru", "phone": "+70100229413"}
0005433497346	698B95	8651 992558	LYUDMILA GERASIMOVA	{"phone": "+70663106491"}
0005433497347	CF0AC1	8130 880332	NATALYA YUDINA	{"email": "yudinanatalya-1969@postgrespro.ru", "phone": "+70332427844"}
0005433497348	AED380	3345 723962	ILMIR POPOV	{"phone": "+70479814352"}
0005433497349	032A83	4807 355966	VIKTOR DAVYDOV	{"email": "davydov_viktor05121985@postgrespro.ru", "phone": "+70148356602"}
0005433497350	024D71	7153 934827	GEORGIY TIMOFEEV	{"email": "timofeev.g.021978@postgrespro.ru", "phone": "+70315520326"}
0005433497351	C9EDF8	9398 372833	ALEKSANDR RODIONOV	{"email": "aleksandr.rodionov_1960@postgrespro.ru", "phone": "+70890525718"}
0005433497352	674726	0871 607689	GENNADIY ALEKSEEV	{"phone": "+70895261127"}
0005433497353	D699FA	7907 510893	ROMAN SAVELEV	{"email": "savelev-r_07101968@postgrespro.ru", "phone": "+70992519066"}
0005433497354	0E3D2B	5982 910429	ALEKSANDR TARASOV	{"email": "a_tarasov_1974@postgrespro.ru", "phone": "+70377827838"}
0005433497355	AC8885	9591 237961	ALEKSEY NAZAROV	{"phone": "+70074976045"}
0005433497356	8A3193	7895 568884	KRISTINA OVCHINNIKOVA	{"email": "ovchinnikovak.051975@postgrespro.ru", "phone": "+70658159908"}
0005433497357	D29A3C	9321 320580	YURIY CHERNOV	{"email": "chernov_yuriy_1981@postgrespro.ru", "phone": "+70499952007"}
0005433497358	E47B00	6553 948238	OLGA ZAKHAROVA	{"phone": "+70154739224"}
0005433497359	62979B	7864 693756	ALEKSANDR PETROV	{"phone": "+70841136180"}
0005433497360	62979B	9074 490505	ILYA SOROKIN	{"phone": "+70295792977"}
0005433497361	7EC096	3761 115164	DMITRIY POPOV	{"email": "dmitriy-popov30031982@postgrespro.ru", "phone": "+70457896538"}
0005433497362	F69C8C	1295 722197	EVGENIY KUZNECOV	{"email": "e.kuznecov_041970@postgrespro.ru", "phone": "+70138032098"}
0005433497363	F69C8C	6955 248205	YURIY ROMANOV	{"phone": "+70518646840"}
0005433497364	F69C8C	3933 878359	DMITRIY MAKAROV	{"phone": "+70931713420"}
0005433497365	0E04B6	1922 543537	RAISA MIKHAYLOVA	{"phone": "+70037800887"}
0005433497366	0E04B6	4829 676904	GULSHAT NOVIKOVA	{"email": "gulshat_novikova_28101976@postgrespro.ru", "phone": "+70985129172"}
0005433497367	CB8791	2796 016749	EGOR ABRAMOV	{"phone": "+70983147893"}
0005433497368	5E536F	7300 974808	VALERIYA SOKOLOVA	{"email": "sokolova_v_07071964@postgrespro.ru", "phone": "+70574001617"}
0005433497369	D9AE1A	4476 713963	EVGENIY SCHERBAKOV	{"email": "scherbakov_e.05091966@postgrespro.ru", "phone": "+70022695874"}
0005433497370	63148B	4434 107604	VIKTOR SOLOVEV	{"email": "v-solovev1971@postgrespro.ru", "phone": "+70370835023"}
0005433497371	63148B	9056 640811	ALEKSANDR SAVELEV	{"phone": "+70253872916"}
0005433497372	6AB890	0690 074010	MARINA MELNIKOVA	{"email": "marina-melnikova.061971@postgrespro.ru", "phone": "+70031071445"}
0005433497373	6AB890	0355 547597	MARINA VASILEVA	{"email": "vasileva-marina_121967@postgrespro.ru", "phone": "+70562209645"}
0005433497374	4C1D9F	1793 413352	VLADIMIR KARPOV	{"email": "vladimirkarpov_071977@postgrespro.ru", "phone": "+70347910306"}
0005433497375	4C1D9F	8611 910607	OLGA MIKHAYLOVA	{"email": "olga.mikhaylova.1968@postgrespro.ru", "phone": "+70874357498"}
0005433497376	930088	7678 640524	DANILA KAZAKOV	{"phone": "+70772645165"}
0005433497377	85D5DD	6406 129448	OLESYA ANDREEVA	{"phone": "+70481127694"}
0005433497378	6182D9	4338 565965	IGOR ALEKSANDROV	{"phone": "+70794052413"}
0005433497379	6182D9	9985 272355	EVGENIY GRIGOREV	{"email": "grigorev-e_02051980@postgrespro.ru", "phone": "+70786460529"}
0005433497380	228BE0	6883 792494	IRINA NOVIKOVA	{"email": "irina.novikova-08101966@postgrespro.ru", "phone": "+70989882762"}
0005433497381	228BE0	5846 583504	TATYANA KUZNECOVA	{"phone": "+70587646259"}
0005433497382	152BCD	7139 235745	SOFYA KUZNECOVA	{"phone": "+70837351364"}
0005433497383	152BCD	5976 426552	ZLATA TITOVA	{"phone": "+70717891343"}
0005433497384	00DF7A	2704 593057	OLEG KUZMIN	{"phone": "+70559171828"}
0005433497385	00DF7A	0987 502371	NADEZHDA PAVLOVA	{"email": "pavlova_nadezhda-031970@postgrespro.ru", "phone": "+70081456221"}
0005433497386	6ECE83	7820 647914	TAMARA NIKITINA	{"phone": "+70856738216"}
0005433497387	3C9322	8288 535026	VLADIMIR EGOROV	{"email": "v.egorov-11121978@postgrespro.ru", "phone": "+70182327164"}
0005433497388	3C9322	3804 697054	NATALYA ILINA	{"email": "n.ilina.1970@postgrespro.ru", "phone": "+70650783179"}
0005433497389	0F3074	2836 031362	TATYANA RYABOVA	{"email": "t_ryabova-1972@postgrespro.ru", "phone": "+70201461098"}
0005433497390	8C4325	9141 452999	MIKHAIL ZAKHAROV	{"email": "mikhail-zakharov_051977@postgrespro.ru", "phone": "+70071063768"}
0005433497391	AEB0D1	4510 001794	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr-29111969@postgrespro.ru", "phone": "+70711662813"}
0005433497392	0546D0	4220 504744	SEMEN KULIKOV	{"email": "s.kulikov-1974@postgrespro.ru", "phone": "+70591325525"}
0005433497393	5BCF90	2709 180745	LILIYA ZOTOVA	{"phone": "+70728403448"}
0005433497394	5BCF90	6070 254599	ANATOLIY NIKOLAEV	{"email": "anatoliy_nikolaev.011963@postgrespro.ru", "phone": "+70498241656"}
0005433497395	3F7E3A	3634 118659	VERA FEDOROVA	{"email": "fedorovav_1984@postgrespro.ru", "phone": "+70273983894"}
0005433497396	FD4A23	1340 352398	LYUBOV LEBEDEVA	{"email": "lyubovlebedeva_04091960@postgrespro.ru", "phone": "+70502357861"}
0005433497397	D1F0F9	8942 035494	SVETLANA ANTONOVA	{"email": "s-antonova1965@postgrespro.ru", "phone": "+70679906258"}
0005433497398	6B2930	8162 386407	ANGELINA ZAYCEVA	{"email": "zayceva-angelina.27121977@postgrespro.ru", "phone": "+70255826707"}
0005433497399	6B2930	2128 292074	GALINA NESTEROVA	{"phone": "+70185067785"}
0005433497400	49C928	5225 843133	ELVINA ZHUKOVA	{"email": "zhukova-e-061970@postgrespro.ru", "phone": "+70265813116"}
0005433497401	1C61E3	4181 565017	SERGEY PAVLOV	{"email": "pavlov_s021971@postgrespro.ru", "phone": "+70380621645"}
0005433497402	1C61E3	3492 592294	DANILA SEMENOV	{"phone": "+70063446549"}
0005433497403	0ECB32	9644 264054	GENNADIY GUSEV	{"email": "gennadiy.gusev101970@postgrespro.ru", "phone": "+70386034540"}
0005433497404	0ECB32	8754 364390	IGOR ZHUKOV	{"phone": "+70562167891"}
0005433497405	76BC7B	5276 799416	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr.021963@postgrespro.ru", "phone": "+70837394933"}
0005433497406	D4510D	6635 947255	IGOR TIKHONOV	{"phone": "+70833081876"}
0005433497407	F54207	6603 198243	IRINA EGOROVA	{"phone": "+70456979926"}
0005433497408	F54207	7370 334314	GALINA BORISOVA	{"phone": "+70790858214"}
0005433497409	9998A0	8463 677497	IRINA PETROVA	{"email": "petrova_irina.111964@postgrespro.ru", "phone": "+70803117316"}
0005433497410	6A4C34	9432 539144	OLGA KOZLOVA	{"phone": "+70513202879"}
0005433497411	6A4C34	7302 725732	YULIYA STEPANOVA	{"phone": "+70226898478"}
0005433497412	6A4C34	1226 215127	YURIY GERASIMOV	{"phone": "+70841447903"}
0005433497413	44D286	5961 609325	ALEKSANDR GUSEV	{"phone": "+70665039476"}
0005433497414	5333F1	3372 779150	MARIYA MIKHAYLOVA	{"phone": "+70048335790"}
0005433497415	5333F1	0290 419717	MARINA MAKAROVA	{"phone": "+70291669290"}
0005433497416	08F39E	6265 669418	ROMAN ZHURAVLEV	{"phone": "+70078490019"}
0005433497417	08F39E	6642 702746	RAMIL ZAKHAROV	{"phone": "+70360974028"}
0005433497418	B9B678	8700 198267	LIDIYA BORISOVA	{"phone": "+70166101474"}
0005433497419	23AC48	7921 997479	PAVEL ZHURAVLEV	{"email": "zhuravlev.p_021972@postgrespro.ru", "phone": "+70539079328"}
0005433497420	7FB43D	0504 865098	DMITRIY ANDREEV	{"email": "andreevd1968@postgrespro.ru", "phone": "+70168850918"}
0005433497421	7FB43D	0384 951737	NINA KOVALEVA	{"email": "nina_kovaleva_30011968@postgrespro.ru", "phone": "+70159891745"}
0005433497422	B3132F	7821 329649	MIKHAIL BONDARENKO	{"phone": "+70595051284"}
0005433497423	2D6AA3	5132 956824	IGOR KAZAKOV	{"email": "igor_kazakov-1966@postgrespro.ru", "phone": "+70964523436"}
0005433497424	50B8C3	6606 726087	LIDIYA SOROKINA	{"phone": "+70998803795"}
0005433497425	50B8C3	9671 111658	ANDREY STEPANOV	{"phone": "+70590370479"}
0005433497426	E3EA51	9796 408914	SERGEY SOLOVEV	{"email": "sergey.solovev_11021981@postgrespro.ru", "phone": "+70302991257"}
0005433497427	F0F0C7	0980 120483	ARTEM KOZLOV	{"email": "akozlov041975@postgrespro.ru", "phone": "+70280226143"}
0005433497428	F0F0C7	1695 921226	VLADIMIR MAKAROV	{"email": "v_makarov-10111971@postgrespro.ru", "phone": "+70940961346"}
0005433497429	F0F0C7	0280 139613	TATYANA IVANOVA	{"phone": "+70239312512"}
0005433497430	0439BF	5490 589581	YAROSLAV KUDRYASHOV	{"email": "kudryashov.yaroslav1975@postgrespro.ru", "phone": "+70329721818"}
0005433497431	0439BF	0650 029423	YURIY BONDARENKO	{"phone": "+70038883737"}
0005433497432	B17839	8627 045238	OLGA IVANOVA	{"email": "olga.ivanova-071968@postgrespro.ru", "phone": "+70894593165"}
0005433497433	B17839	2332 909657	SERGEY ISAEV	{"email": "sisaev-1974@postgrespro.ru", "phone": "+70887543973"}
0005433497434	571CBE	8234 805927	SERGEY MIRONOV	{"phone": "+70947230410"}
0005433497435	1719B7	3200 540495	SERGEY ABRAMOV	{"phone": "+70691922968"}
0005433497436	AC2750	2975 828635	ALEKSEY ILIN	{"phone": "+70689511337"}
0005433497437	1B64A1	8622 584441	ZINAIDA LUKYANOVA	{"email": "lukyanova_zinaida.17061976@postgrespro.ru", "phone": "+70761108240"}
0005433497438	0E1CA8	9061 662539	VIKTOR CHERNOV	{"phone": "+70840031043"}
0005433497439	0E1CA8	4917 974979	EVGENIY MATVEEV	{"email": "evgeniy-matveev1976@postgrespro.ru", "phone": "+70577546813"}
0005433497440	D345EC	3155 503603	ELENA KISELEVA	{"phone": "+70710710193"}
0005433497441	09DA4A	3681 989410	ALEKSEY MARTYNOV	{"email": "martynov_aleksey.1963@postgrespro.ru", "phone": "+70319435855"}
0005433497442	09DA4A	2884 711790	EVGENIYA KOLESNIKOVA	{"email": "ekolesnikova-16101970@postgrespro.ru", "phone": "+70591377654"}
0005433497443	82259B	5628 903886	VERA CHERNOVA	{"phone": "+70426650111"}
0005433497444	4F8B88	4787 091110	IRINA VLASOVA	{"phone": "+70929514914"}
0005433497445	D219C7	0133 613563	GALINA NIKIFOROVA	{"email": "nikiforova.galina.051968@postgrespro.ru", "phone": "+70687154490"}
0005433497446	D219C7	7379 324947	VLADIMIR NIKITIN	{"phone": "+70079127961"}
0005433497447	1D5123	7219 349830	VIKTOR TIKHONOV	{"phone": "+70081239686"}
0005433497448	2AAF3D	5439 502280	NATALYA MIKHAYLOVA	{"email": "mikhaylova_n.091976@postgrespro.ru", "phone": "+70855628089"}
0005433497449	09F592	2382 540041	OLGA IVANOVA	{"email": "olgaivanova-111959@postgrespro.ru", "phone": "+70009006461"}
0005433497450	09F592	3997 206833	VALENTINA ZAKHAROVA	{"email": "zakharova_v-17121968@postgrespro.ru", "phone": "+70666125691"}
0005433497451	477B93	6728 421039	VALENTINA VOLKOVA	{"phone": "+70187606200"}
0005433497452	477B93	3671 919313	DMITRIY KRASNOV	{"email": "krasnovd-1975@postgrespro.ru", "phone": "+70908995971"}
0005433497453	C2C0CD	5046 460913	GENNADIY NIKITIN	{"email": "g.nikitin-1965@postgrespro.ru", "phone": "+70265609440"}
0005433497454	C2C0CD	5432 737594	LIDIYA MIKHAYLOVA	{"email": "mikhaylova_lidiya_26051969@postgrespro.ru", "phone": "+70372143224"}
0005433497455	39C28A	6323 492638	OKSANA OVCHINNIKOVA	{"phone": "+70985010987"}
0005433497456	39C28A	7190 393516	NIKOLAY OSIPOV	{"email": "osipov-nikolay_1976@postgrespro.ru", "phone": "+70747369295"}
0005433497457	7AC66C	9868 110004	ALEKSEY FEDOTOV	{"phone": "+70151963554"}
0005433497458	5EE076	2701 828369	VASILIY NOVIKOV	{"email": "vasiliynovikov_05061970@postgrespro.ru", "phone": "+70430000884"}
0005433497459	8FA6D5	8647 487111	EDUARD TIKHONOV	{"email": "etikhonov_17081971@postgrespro.ru", "phone": "+70967871212"}
0005433497460	BE1E95	7322 717767	OLEG ANDREEV	{"email": "andreev.o-011974@postgrespro.ru", "phone": "+70447729432"}
0005433497461	DB54F2	3898 450617	NATALYA SOKOLOVA	{"phone": "+70587335589"}
0005433497462	DB54F2	6855 519250	ANDREY KISELEV	{"email": "kiselev_andrey1981@postgrespro.ru", "phone": "+70622208834"}
0005433497463	C3FC8B	3132 042548	VYACHESLAV KOZLOV	{"email": "vyacheslav.kozlov-1970@postgrespro.ru", "phone": "+70795675147"}
0005433497464	CAA9B6	9751 321379	NATALIYA SMIRNOVA	{"email": "smirnovan1959@postgrespro.ru", "phone": "+70637841971"}
0005433497465	49F084	6664 974101	ANDREY RODIONOV	{"phone": "+70663584891"}
0005433497466	49F084	1115 485012	EVGENIY VLASOV	{"phone": "+70163216388"}
0005433497467	2B1F79	9921 411328	VIKTOR ZHUKOV	{"email": "zhukov.v.1964@postgrespro.ru", "phone": "+70853108584"}
0005433497468	B66C70	0951 836769	ZINAIDA KUZMINA	{"phone": "+70305404372"}
0005433497469	B66C70	7704 811253	ALEKSEY POPOV	{"phone": "+70508228245"}
0005433497470	45E05D	3806 612163	TATYANA ORLOVA	{"phone": "+70091224617"}
0005433497471	62E65D	6518 468931	DANILA ANTONOV	{"email": "d_antonov_111971@postgrespro.ru", "phone": "+70461634670"}
0005433497472	1FC8B2	5164 769649	TAMARA ORLOVA	{"email": "orlova-tamara061969@postgrespro.ru", "phone": "+70304598709"}
0005433497473	87C1D1	9887 874081	YURIY ZAKHAROV	{"email": "zakharovyuriy.061957@postgrespro.ru", "phone": "+70229570476"}
0005433497474	87C1D1	3848 148896	ANNA POPOVA	{"email": "anna.popova101974@postgrespro.ru", "phone": "+70638326424"}
0005433497475	A488C1	6325 710831	VLADIMIR SMIRNOV	{"phone": "+70729679865"}
0005433497476	8ABF85	0140 973695	LYUDMILA DAVYDOVA	{"phone": "+70049009944"}
0005433497477	54D8F0	4851 802266	MIKHAIL MEDVEDEV	{"email": "medvedev-mikhail_061977@postgrespro.ru", "phone": "+70649159717"}
0005433497478	54D8F0	4778 796435	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaa.011972@postgrespro.ru", "phone": "+70391267514"}
0005433497479	A4F79C	1866 817439	NATALYA ZHUKOVA	{"email": "zhukova.natalya09091971@postgrespro.ru", "phone": "+70334524918"}
0005433497480	17512B	6983 458652	SERGEY POPOV	{"phone": "+70763344412"}
0005433497481	17512B	9829 362812	LYUBOV NESTEROVA	{"email": "nesterova_l.27091978@postgrespro.ru", "phone": "+70095397324"}
0005433497482	17512B	5266 114702	KLARA TITOVA	{"email": "titova-klara-1983@postgrespro.ru", "phone": "+70478341660"}
0005433497483	17512B	5724 550186	MARIYA KALININA	{"email": "mariya_kalinina.111967@postgrespro.ru", "phone": "+70566830936"}
0005433497484	591431	1636 866019	NADEZHDA ABRAMOVA	{"email": "abramova.nadezhda.011970@postgrespro.ru", "phone": "+70339129104"}
0005433497485	591431	7605 520255	VADIM KISELEV	{"phone": "+70476969931"}
0005433497486	591431	7464 917833	NADEZHDA MATVEEVA	{"phone": "+70587421829"}
0005433497487	B1D3B7	8155 663595	ALEKSEY KUZNECOV	{"email": "a-kuznecov_10091982@postgrespro.ru", "phone": "+70245971537"}
0005433497488	B1D3B7	6309 224338	ALEKSEY KISELEV	{"email": "aleksey_kiselev_091979@postgrespro.ru", "phone": "+70919937841"}
0005433497489	45C029	3080 762783	ANNA MIKHAYLOVA	{"phone": "+70913328414"}
0005433497490	DF0FC0	4193 238674	TATYANA KUZNECOVA	{"phone": "+70435204174"}
0005433497491	FF97C3	3510 314766	ALEKSANDRA KONOVALOVA	{"phone": "+70816323581"}
0005433497492	B412FE	9750 095002	ALINA LEBEDEVA	{"phone": "+70744420396"}
0005433497493	CE83F8	9263 208262	EVGENIYA ROMANOVA	{"phone": "+70966056671"}
0005433497494	B01137	5704 212551	NINA SCHERBAKOVA	{"email": "scherbakovan-1981@postgrespro.ru", "phone": "+70128137067"}
0005433497495	BB69B2	9722 232548	TAMARA FROLOVA	{"phone": "+70785097539"}
0005433497550	82EB63	2061 812250	YURIY KAZAKOV	{"phone": "+70407259577"}
0005433497496	BB69B2	8511 028708	MARIYA TIKHONOVA	{"email": "tikhonovamariya.1981@postgrespro.ru", "phone": "+70536686069"}
0005433497497	447D22	9661 927759	IRINA NESTEROVA	{"email": "nesterovairina_1967@postgrespro.ru", "phone": "+70413720788"}
0005433497498	B21563	7688 644018	ALEKSANDRA STEPANOVA	{"phone": "+70483903252"}
0005433497499	9EA1F7	9840 045614	MARIYA EFIMOVA	{"phone": "+70906137626"}
0005433497500	26372B	0151 984846	KIRILL DMITRIEV	{"email": "dmitrievkirill.021972@postgrespro.ru", "phone": "+70983315719"}
0005433497501	AEEB1F	5464 635062	TATYANA BELOVA	{"email": "belovat.101976@postgrespro.ru", "phone": "+70554200684"}
0005433497502	92D474	4897 973421	MIKHAIL SOROKIN	{"email": "m_sorokin_09101970@postgrespro.ru", "phone": "+70244586372"}
0005433497503	39D2C1	3192 125882	VITALIY KUZMIN	{"email": "kuzmin_vitaliy1969@postgrespro.ru", "phone": "+70117751851"}
0005433497504	39D2C1	4046 156393	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana.1962@postgrespro.ru", "phone": "+70669385792"}
0005433497505	E2CC70	0883 703187	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.041983@postgrespro.ru", "phone": "+70302484180"}
0005433497506	E2CC70	2181 681454	KRISTINA KAZAKOVA	{"email": "kazakova.kristina-031971@postgrespro.ru", "phone": "+70450501283"}
0005433497507	E2CC70	6537 335548	MIKHAIL KUZNECOV	{"email": "mkuznecov-16051962@postgrespro.ru", "phone": "+70225265301"}
0005433497508	220E14	2579 601713	VLADIMIR GERASIMOV	{"phone": "+70382402051"}
0005433497509	220E14	1950 748177	VALERIY NOVIKOV	{"email": "v-novikov.16101968@postgrespro.ru", "phone": "+70778416396"}
0005433497510	2337C3	1071 134750	LIYA NIKIFOROVA	{"phone": "+70164870459"}
0005433497511	0461C4	5451 153177	ANDREY BONDARENKO	{"email": "andrey_bondarenko081973@postgrespro.ru", "phone": "+70423095598"}
0005433497512	A7B209	3989 160254	DMITRIY GRIGOREV	{"phone": "+70957740319"}
0005433497513	7B6589	9786 046232	LYUDMILA FILIPPOVA	{"email": "filippova_l-06101970@postgrespro.ru", "phone": "+70538583918"}
0005433497514	7B6589	4546 872209	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr1964@postgrespro.ru", "phone": "+70227304108"}
0005433497515	6AF825	9234 751865	ZINAIDA ARKHIPOVA	{"email": "arkhipova-zinaida1980@postgrespro.ru", "phone": "+70777024189"}
0005433497516	6AF825	1756 706853	ANASTASIYA ILINA	{"email": "ilina-a-1982@postgrespro.ru", "phone": "+70256318737"}
0005433497517	3CB788	3753 988368	DMITRIY SMIRNOV	{"phone": "+70064048367"}
0005433497518	47B8DC	9836 238298	TATYANA FROLOVA	{"email": "frolova.tatyana_1976@postgrespro.ru", "phone": "+70603956491"}
0005433497519	47B8DC	6269 428711	VIKTORIYA MELNIKOVA	{"email": "v_melnikova_051962@postgrespro.ru", "phone": "+70028801578"}
0005433497520	FA1139	7428 809444	ELENA SAVELEVA	{"email": "elena_saveleva_111978@postgrespro.ru", "phone": "+70825347220"}
0005433497521	210E5E	1801 334577	TATYANA GERASIMOVA	{"email": "gerasimovat_1959@postgrespro.ru", "phone": "+70700051736"}
0005433497522	57D383	0060 395207	SVETLANA OSIPOVA	{"email": "osipova.svetlana-26051967@postgrespro.ru", "phone": "+70655319918"}
0005433497523	ED70F4	8699 677462	LYUDMILA VASILEVA	{"phone": "+70492784641"}
0005433497524	7EA918	4715 776144	IGOR KUZNECOV	{"phone": "+70479350822"}
0005433497525	9C75B4	5331 356164	TATYANA EGOROVA	{"email": "t-egorova21101970@postgrespro.ru", "phone": "+70517278654"}
0005433497526	07B251	1227 806452	NIKOLAY NAUMOV	{"email": "n-naumov-1967@postgrespro.ru", "phone": "+70249442875"}
0005433497527	07B251	8880 164585	LIDIYA BELOVA	{"phone": "+70148389029"}
0005433497528	299668	4813 652787	DARINA ZAKHAROVA	{"email": "zakharovad20111977@postgrespro.ru", "phone": "+70646518299"}
0005433497529	1AFEF3	7564 229526	MILANA MOROZOVA	{"phone": "+70815151838"}
0005433497530	C48D02	6067 447512	VLADISLAV ALEKSEEV	{"phone": "+70138455864"}
0005433497531	81E948	5190 115954	ALEKSANDR NIKOLAEV	{"phone": "+70413546125"}
0005433497532	81E948	6435 438970	ALEKSEY ZHURAVLEV	{"email": "alekseyzhuravlev_1982@postgrespro.ru", "phone": "+70685104564"}
0005433497533	1D4DD8	7990 134811	DENIS MOROZOV	{"email": "denis_morozov.26021986@postgrespro.ru", "phone": "+70617025572"}
0005433497534	1D4DD8	6132 532145	ALEKSANDR RODIONOV	{"email": "aleksandr.rodionov_30101966@postgrespro.ru", "phone": "+70886595140"}
0005433497535	76672D	0707 889104	EKATERINA KISELEVA	{"phone": "+70090945923"}
0005433497536	76672D	9008 203428	ALEKSEY SOKOLOV	{"email": "alekseysokolov_121966@postgrespro.ru", "phone": "+70447222061"}
0005433497537	320793	4908 916650	VALENTINA KOMAROVA	{"email": "komarova_v_1962@postgrespro.ru", "phone": "+70541237943"}
0005433497538	320793	2397 799439	EVA NIKIFOROVA	{"phone": "+70109288358"}
0005433497539	7BE506	8982 954846	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr_011970@postgrespro.ru", "phone": "+70515768013"}
0005433497540	3EB70F	3947 475027	VALENTINA SEMENOVA	{"phone": "+70092940809"}
0005433497541	586C11	5328 732823	IRINA KONOVALOVA	{"phone": "+70180026547"}
0005433497542	973921	3584 130583	OLGA KUZNECOVA	{"email": "kuznecova_olga.28051974@postgrespro.ru", "phone": "+70712967175"}
0005433497543	973921	6435 059941	MARINA IVANOVA	{"email": "m_ivanova_011980@postgrespro.ru", "phone": "+70685796631"}
0005433497544	98342E	2910 103066	ALEKSANDR IVANOV	{"email": "ivanov_a101976@postgrespro.ru", "phone": "+70746661975"}
0005433497545	F99D2E	8718 752924	VERONIKA ORLOVA	{"email": "orlova.veronika.011979@postgrespro.ru", "phone": "+70107648387"}
0005433497546	30BAD8	5009 429495	TATYANA EGOROVA	{"email": "egorova_t1978@postgrespro.ru", "phone": "+70136906928"}
0005433497547	4DF714	4465 757860	ALEKSANDR SMIRNOV	{"phone": "+70880834339"}
0005433497548	419B65	4026 383387	SVETLANA NAZAROVA	{"email": "snazarova-081976@postgrespro.ru", "phone": "+70238474577"}
0005433497549	D3885A	2703 849421	VIKTOR SMIRNOV	{"email": "smirnov-viktor-111970@postgrespro.ru", "phone": "+70253573647"}
0005433497551	2904AE	2820 492101	ANDREY SEMENOV	{"email": "a_semenov.1967@postgrespro.ru", "phone": "+70822074792"}
0005433497552	6D5066	1234 141635	LYUDMILA FEDOROVA	{"phone": "+70784273040"}
0005433497553	CB011E	8314 486598	ALEKSANDR TIKHONOV	{"phone": "+70695899231"}
0005433497554	CB011E	5649 155270	ELENA SEMENOVA	{"phone": "+70845149864"}
0005433497555	CB011E	1716 631768	ANATOLIY NIKOLAEV	{"email": "nikolaev-anatoliy.031970@postgrespro.ru", "phone": "+70501755265"}
0005433497556	612C44	3129 955959	NIKITA DENISOV	{"email": "nikitadenisov111969@postgrespro.ru", "phone": "+70155821260"}
0005433497557	811FBE	3253 685699	ANNA ROMANOVA	{"phone": "+70366994802"}
0005433497558	4F860E	2070 565497	OKSANA KOROLEVA	{"email": "koroleva_o-1969@postgrespro.ru", "phone": "+70722763485"}
0005433497559	5AD829	2844 189294	EVDOKIYA ANISIMOVA	{"email": "evdokiya.anisimova1971@postgrespro.ru", "phone": "+70998493809"}
0005433497560	1C8C52	6326 164413	PETR KAZAKOV	{"email": "kazakovpetr1970@postgrespro.ru", "phone": "+70958729587"}
0005433497561	88B146	5730 935511	DAVID VOLKOV	{"phone": "+70650245430"}
0005433497562	88B146	9621 682894	GULFIYA NIKOLAEVA	{"phone": "+70326093936"}
0005433497563	F30F24	5987 306469	VASILIY YAKOVLEV	{"email": "yakovlev_v-1966@postgrespro.ru", "phone": "+70544310580"}
0005433497564	5D79B4	5302 575207	ANNA ANTONOVA	{"email": "anna_antonova-11031963@postgrespro.ru", "phone": "+70353017619"}
0005433497565	18048B	8438 925719	VITALIY ANTONOV	{"phone": "+70327642614"}
0005433497566	18048B	2417 547149	ALEKSEY PETROV	{"email": "petrov.a_1975@postgrespro.ru", "phone": "+70242187426"}
0005433497567	C50063	8981 638569	VASILIY EGOROV	{"email": "vasiliy_egorov_14101964@postgrespro.ru", "phone": "+70453427438"}
0005433497568	67C852	6691 574749	SERGEY PAVLOV	{"email": "s_pavlov29031957@postgrespro.ru", "phone": "+70486521888"}
0005433497569	F11D44	8656 139602	ANASTASIYA NAZAROVA	{"phone": "+70248652627"}
0005433497570	F0C464	7071 555754	OLGA ILINA	{"phone": "+70824412208"}
0005433497571	1F2B57	5840 974033	ROMAN FEDOROV	{"email": "fedorov-r.051970@postgrespro.ru", "phone": "+70296408537"}
0005433497572	1F2B57	3563 934738	INESSA POPOVA	{"email": "popova.i-1982@postgrespro.ru", "phone": "+70631609153"}
0005433497573	1F2B57	9286 230918	TATYANA KUZNECOVA	{"email": "tkuznecova.1975@postgrespro.ru", "phone": "+70845494605"}
0005433497574	DF7F8A	5497 799774	GENNADIY SOLOVEV	{"phone": "+70486664093"}
0005433497575	C95E4B	6656 930876	NATALYA POLYAKOVA	{"email": "natalyapolyakova_05011977@postgrespro.ru", "phone": "+70006275170"}
0005433497576	FCD10D	5408 452541	VLADIMIR KRASNOV	{"email": "krasnov_vladimir-04051962@postgrespro.ru", "phone": "+70710029818"}
0005433497577	FCD10D	1103 673321	IGOR CHERNOV	{"email": "i_chernov.041984@postgrespro.ru", "phone": "+70003286265"}
0005433497578	5E73BB	3173 759299	OKSANA MOROZOVA	{"phone": "+70814584245"}
0005433497579	C18D6D	3993 278103	KONSTANTIN DMITRIEV	{"email": "dmitriev_konstantin-11091972@postgrespro.ru", "phone": "+70946299822"}
0005433497580	BCFB37	5911 245250	OLGA GUSEVA	{"phone": "+70870788190"}
0005433497581	3F0B22	3229 743610	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov_30041965@postgrespro.ru", "phone": "+70120927879"}
0005433497582	D4AA17	7389 250946	IGOR GRIGOREV	{"phone": "+70017213786"}
0005433497583	545004	4392 736905	ALEKSEY DAVYDOV	{"email": "a_davydov.12091977@postgrespro.ru", "phone": "+70960532466"}
0005433497584	545004	5998 774095	ELENA KAZAKOVA	{"email": "kazakova.e.011974@postgrespro.ru", "phone": "+70265140153"}
0005433497585	970F0A	4815 987971	VALENTINA GORBUNOVA	{"phone": "+70547230123"}
0005433497586	27E47F	1346 212450	TATYANA EGOROVA	{"email": "egorova-tatyana-061977@postgrespro.ru", "phone": "+70910103230"}
0005433497587	27E47F	2625 259159	NATALYA SIDOROVA	{"email": "natalyasidorova031979@postgrespro.ru", "phone": "+70089351732"}
0005433497588	C3BA2C	3420 015642	RAISA ABRAMOVA	{"email": "abramova_r.09041966@postgrespro.ru", "phone": "+70881159683"}
0005433497589	6DF029	6969 513999	BORIS SEMENOV	{"phone": "+70251876320"}
0005433497590	BCE2DE	7326 096470	NATALYA KONOVALOVA	{"email": "natalya-konovalova.1963@postgrespro.ru", "phone": "+70056950003"}
0005433497591	8627F4	7511 728122	VYACHESLAV SCHERBAKOV	{"phone": "+70214903395"}
0005433497592	8627F4	3163 556376	DAMIR FILIPPOV	{"email": "d.filippov_1972@postgrespro.ru", "phone": "+70541076035"}
0005433497593	D97CCA	3113 030804	NATALYA AKIMOVA	{"email": "n.akimova_12071972@postgrespro.ru", "phone": "+70548698878"}
0005433497594	1E9FA6	4338 057245	YULIYA AFANASEVA	{"phone": "+70749295811"}
0005433497595	E1EE5D	3673 653670	LILIYA ZHURAVLEVA	{"phone": "+70416477337"}
0005433497596	45DA1E	1928 720830	NATALYA KARPOVA	{"email": "nkarpova-1979@postgrespro.ru", "phone": "+70958152903"}
0005433497597	530965	9195 624150	SERGEY NOVIKOV	{"email": "sergeynovikov05021968@postgrespro.ru", "phone": "+70247787946"}
0005433497598	8001D0	0229 363327	RUSLAN KRASNOV	{"email": "ruslankrasnov091985@postgrespro.ru", "phone": "+70573056841"}
0005433497599	8001D0	9274 344146	MIKHAIL KRASNOV	{"email": "krasnovm.1972@postgrespro.ru", "phone": "+70443812103"}
0005433497600	0A658D	9676 582205	NATALYA STEPANOVA	{"phone": "+70553737256"}
0005433497601	7D3FA5	4107 664534	IRAIDA KOROLEVA	{"phone": "+70009476608"}
0005433497602	80AFF2	3447 377712	NIKOLAY NAZAROV	{"phone": "+70326089610"}
0005433497603	7AECE9	5875 448836	VIKTOR KISELEV	{"phone": "+70480707277"}
0005433497604	4A1FA8	0613 468448	VIKTOR ZHUKOV	{"phone": "+70054982003"}
0005433497605	2A58F3	4328 062505	ALEKSANDRA EGOROVA	{"phone": "+70715853147"}
0005433497606	1EDEF5	4524 551801	ANDREY KUDRYASHOV	{"phone": "+70891800342"}
0005433497607	7223E6	7834 661364	GALINA GAVRILOVA	{"email": "gavrilova.galina_091976@postgrespro.ru", "phone": "+70497022711"}
0005433497608	7223E6	9535 451809	MARK MIRONOV	{"email": "mironov-m_1974@postgrespro.ru", "phone": "+70448547141"}
0005433497609	826610	7986 947565	ELENA KUDRYASHOVA	{"phone": "+70776612479"}
0005433497610	14D421	3833 565601	YULIYA KULIKOVA	{"phone": "+70630854149"}
0005433497611	478AA1	3698 025668	ALEKSEY MELNIKOV	{"email": "melnikov-a.1970@postgrespro.ru", "phone": "+70728315574"}
0005433497612	B1F9CE	9775 171631	NAILYA SOROKINA	{"email": "sorokina-n-1964@postgrespro.ru", "phone": "+70757725224"}
0005433497613	B1F9CE	0358 226288	LIDIYA BARANOVA	{"phone": "+70850324666"}
0005433497614	0A0AC9	5497 239978	DMITRIY POPOV	{"email": "popov-dmitriy-1980@postgrespro.ru", "phone": "+70118597417"}
0005433497615	0A0AC9	0101 828162	ALEKSEY IVANOV	{"email": "ivanovaleksey_011981@postgrespro.ru", "phone": "+70607482824"}
0005433497616	398ED7	5702 575687	NATALYA MAKAROVA	{"phone": "+70458000567"}
0005433497617	BAE2D3	1109 043921	MIKHAIL TIKHONOV	{"email": "tikhonov-mikhail.1972@postgrespro.ru", "phone": "+70298566754"}
0005433497618	BAE2D3	7305 393727	MARIYA MOROZOVA	{"email": "morozova-mariya_02021975@postgrespro.ru", "phone": "+70081456435"}
0005433497619	BAE2D3	8989 951351	IRINA LOGINOVA	{"phone": "+70849597480"}
0005433497620	8C1494	7431 453171	VLADIMIR VLASOV	{"email": "vlasovvladimir_011971@postgrespro.ru", "phone": "+70129194391"}
0005433497621	8C1494	6224 701228	MAKSIM TIMOFEEV	{"email": "m-timofeev_27121979@postgrespro.ru", "phone": "+70200650062"}
0005433497622	10102D	7469 404688	OLEG ZAKHAROV	{"email": "o.zakharov-081973@postgrespro.ru", "phone": "+70664625928"}
0005433497623	6822D3	9005 597921	VLADISLAV ZAKHAROV	{"phone": "+70973715075"}
0005433497624	7117D0	8616 636804	IGOR ZAKHAROV	{"phone": "+70100025931"}
0005433497625	73194B	5918 175937	MIKHAIL MOROZOV	{"email": "morozov_m1976@postgrespro.ru", "phone": "+70726825106"}
0005433497626	73194B	4736 793700	NATALYA LEBEDEVA	{"email": "lebedeva_natalya.25101978@postgrespro.ru", "phone": "+70174251511"}
0005433497627	F9B472	9694 130983	SERGEY GORBUNOV	{"email": "gorbunov-s.081981@postgrespro.ru", "phone": "+70536068703"}
0005433497628	F9B472	7269 761484	EVGENIYA GERASIMOVA	{"phone": "+70283695046"}
0005433497629	F5FC62	0741 438035	VIKTORIYA DANILOVA	{"email": "danilova.viktoriya_27071964@postgrespro.ru", "phone": "+70602880181"}
0005433497630	F5FC62	9834 475185	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov_011966@postgrespro.ru", "phone": "+70399962736"}
0005433497631	F5FC62	9708 883592	VLADIMIR KUZMIN	{"phone": "+70803852006"}
0005433497632	0F9791	4494 843021	ALEKSANDR ROMANOV	{"phone": "+70904916881"}
0005433497800	16E640	8641 961234	ALEKSANDR KUZMIN	{"phone": "+70384342898"}
0005433497633	C621D6	4795 143056	ELENA KUZMINA	{"email": "elena-kuzmina.021977@postgrespro.ru", "phone": "+70581981626"}
0005433497634	C621D6	4140 103137	OLGA MIRONOVA	{"email": "mironova-olga_091972@postgrespro.ru", "phone": "+70526542900"}
0005433497635	A608C3	4411 803507	LYUBOV ORLOVA	{"email": "orloval041977@postgrespro.ru", "phone": "+70598432498"}
0005433497636	CAF9EA	4875 103503	LILIYA EGOROVA	{"email": "liliya.egorova-1968@postgrespro.ru", "phone": "+70686478825"}
0005433497637	D122ED	0730 068410	IGOR SEMENOV	{"email": "semenov.igor_031972@postgrespro.ru", "phone": "+70571578141"}
0005433497638	D122ED	3726 934696	ILYA ILIN	{"phone": "+70929511214"}
0005433497639	C7A9E0	6131 995014	ELENA MEDVEDEVA	{"email": "elena_medvedeva-25091981@postgrespro.ru", "phone": "+70223998017"}
0005433497640	21ADD2	3137 525069	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr021981@postgrespro.ru", "phone": "+70704477597"}
0005433497641	95E055	1698 537097	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr051975@postgrespro.ru", "phone": "+70921154099"}
0005433497642	3DCB5B	1223 202818	MARINA SOKOLOVA	{"email": "sokolova_m.1960@postgrespro.ru", "phone": "+70556465651"}
0005433497643	3DCB5B	0585 775617	ALEKSANDR SIDOROV	{"phone": "+70660683313"}
0005433497644	8B4469	5410 273411	ALEKSANDR GERASIMOV	{"phone": "+70670156281"}
0005433497645	DE7680	9267 230757	YURIY IVANOV	{"email": "yuriy-ivanov27051978@postgrespro.ru", "phone": "+70577610285"}
0005433497646	1A9C56	4371 461703	NATALYA FADEEVA	{"phone": "+70675015831"}
0005433497647	1A9C56	8070 769631	EVGENIYA TIKHONOVA	{"phone": "+70993740141"}
0005433497648	6EB606	3561 282591	ALEKSEY ROMANOV	{"phone": "+70492266657"}
0005433497649	24D989	4453 896474	INESSA KUZNECOVA	{"email": "inessa_kuznecova_1970@postgrespro.ru", "phone": "+70457029747"}
0005433497650	A9B3FF	3916 551423	ANNA YUDINA	{"phone": "+70942964140"}
0005433497651	C24292	3337 851462	NINA VASILEVA	{"phone": "+70144112555"}
0005433497652	92FE0F	0323 270043	VLADIMIR KULIKOV	{"email": "kulikov_v.021986@postgrespro.ru", "phone": "+70995002654"}
0005433497653	3AD64E	5717 124443	KONSTANTIN KARPOV	{"phone": "+70994748918"}
0005433497654	5A27C6	1405 922128	NATALYA FILATOVA	{"email": "natalya.filatova1981@postgrespro.ru", "phone": "+70210101053"}
0005433497655	80440D	7426 886204	MIKHAIL PETROV	{"email": "petrov.mikhail.1975@postgrespro.ru", "phone": "+70215340027"}
0005433497656	835D79	6244 547686	NINA ALEKSEEVA	{"phone": "+70406615136"}
0005433497657	C26604	5431 185537	SVETLANA ANTONOVA	{"phone": "+70685739209"}
0005433497658	F32076	1675 377124	ROMAN GUSEV	{"phone": "+70229965729"}
0005433497659	A1BD02	5875 458128	NINA POPOVA	{"email": "n_popova091969@postgrespro.ru", "phone": "+70838672846"}
0005433497660	DA2996	9349 676994	NINA BELOVA	{"phone": "+70139007890"}
0005433497661	044BF9	5152 889405	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov_13111959@postgrespro.ru", "phone": "+70026767786"}
0005433497662	044BF9	9324 331798	VALENTIN IVANOV	{"email": "v.ivanov-061968@postgrespro.ru", "phone": "+70650106671"}
0005433497663	0342CD	8013 312053	TATYANA EGOROVA	{"phone": "+70001986639"}
0005433497664	BA02A1	7946 195470	RAFAEL KUZMIN	{"phone": "+70195507004"}
0005433497665	DDD303	8116 274861	ALEKSANDR GUSEV	{"email": "aleksandr-gusev1973@postgrespro.ru", "phone": "+70760656675"}
0005433497666	6E5364	3840 038893	DMITRIY TIKHONOV	{"phone": "+70292781519"}
0005433497667	6E5364	5602 602880	SERGEY DENISOV	{"phone": "+70066687236"}
0005433497668	D74D03	1782 337495	NIKOLAY STEPANOV	{"phone": "+70325571543"}
0005433497669	8D72A2	0918 346843	IGOR PAVLOV	{"email": "igor-pavlov-17011983@postgrespro.ru", "phone": "+70966102117"}
0005433497670	8D72A2	3006 144487	SERGEY KUZNECOV	{"email": "kuznecovsergey_07101970@postgrespro.ru", "phone": "+70517160866"}
0005433497671	8D72A2	6906 890483	EGOR ALEKSANDROV	{"phone": "+70790855698"}
0005433497672	EEAC2D	4222 809662	VITALIY NOVIKOV	{"phone": "+70870749693"}
0005433497673	81540D	1815 015204	VIKTOR SCHERBAKOV	{"email": "viktorscherbakov-021967@postgrespro.ru", "phone": "+70204263378"}
0005433497674	81540D	2539 223524	EVGENIY ZAKHAROV	{"phone": "+70416231291"}
0005433497675	81540D	5722 164635	ALEKSANDR DMITRIEV	{"phone": "+70143223431"}
0005433497676	F7CA82	6527 022912	LYUDMILA KUZNECOVA	{"phone": "+70442779915"}
0005433497677	8DEFE5	6152 713852	ANTON IVANOV	{"phone": "+70455814846"}
0005433497678	3FFEA1	3244 101860	NATALYA TROFIMOVA	{"email": "n.trofimova.1966@postgrespro.ru", "phone": "+70529202385"}
0005433497679	EA53D6	8052 427408	OLGA KOROLEVA	{"email": "olga_koroleva.1975@postgrespro.ru", "phone": "+70794995076"}
0005433497680	EA53D6	9301 033849	ILYA NAUMOV	{"phone": "+70707221011"}
0005433497681	AADDEB	3436 200932	DMITRIY CHERNOV	{"phone": "+70830895328"}
0005433497682	AADDEB	5119 005026	GENNADIY PAVLOV	{"email": "pavlov_gennadiy-071970@postgrespro.ru", "phone": "+70814550732"}
0005433497683	494E4C	2088 720624	IRINA KISELEVA	{"email": "irinakiseleva011971@postgrespro.ru", "phone": "+70631526726"}
0005433497684	E56317	8903 445698	MARIYA KRASNOVA	{"email": "mkrasnova_1965@postgrespro.ru", "phone": "+70934211480"}
0005433497685	77069D	9883 368183	ALEKSEY ZAKHAROV	{"email": "zakharov.a_031967@postgrespro.ru", "phone": "+70153360614"}
0005433497686	5B2B8E	7036 738963	SVETLANA MEDVEDEVA	{"phone": "+70846546115"}
0005433497687	E537E2	6924 841363	ALEKSEY IVANOV	{"email": "ivanov-aleksey1972@postgrespro.ru", "phone": "+70004796338"}
0005433497688	0C5982	0638 094742	TATYANA FOMINA	{"email": "fominat.06061965@postgrespro.ru", "phone": "+70813922262"}
0005433497689	0C5982	7552 891191	ELENA ISAEVA	{"email": "elena.isaeva011981@postgrespro.ru", "phone": "+70199247577"}
0005433497690	B5B4A5	5577 163108	RAMIL ISAEV	{"email": "isaevr-20011975@postgrespro.ru", "phone": "+70098608519"}
0005433497691	018F2C	9832 462301	ANDREY ORLOV	{"phone": "+70693172880"}
0005433497692	018F2C	0168 464853	ELENA IVANOVA	{"phone": "+70296641285"}
0005433497693	033035	5993 508433	SERGEY ZAKHAROV	{"email": "zakharov-sergey-1960@postgrespro.ru", "phone": "+70805872417"}
0005433497694	41EA9F	4397 498629	ARTEM TARASOV	{"email": "artem-tarasov-11011968@postgrespro.ru", "phone": "+70381410776"}
0005433497695	665BBA	7230 705791	ANASTASIYA KUDRYASHOVA	{"phone": "+70102110386"}
0005433497696	4E31CE	6479 681470	OLGA TIKHONOVA	{"email": "olga_tikhonova021965@postgrespro.ru", "phone": "+70295455936"}
0005433497697	D7A40D	8827 641645	DARYA VOLKOVA	{"phone": "+70433922340"}
0005433497698	75EAE7	7468 672607	VALENTINA VASILEVA	{"phone": "+70261265886"}
0005433497699	D64BE8	9476 758258	ANTONINA ZOTOVA	{"email": "zotovaa.091978@postgrespro.ru", "phone": "+70226537479"}
0005433497700	8B5507	9598 583791	ZULFIYA SOKOLOVA	{"email": "sokolova_z121968@postgrespro.ru", "phone": "+70476200652"}
0005433497701	5F4BF8	7520 896973	SHAMIL RODIONOV	{"phone": "+70942561733"}
0005433497702	3D8523	1867 477933	ALEKSEY MEDVEDEV	{"phone": "+70870561911"}
0005433497703	D1FB5E	8551 481770	ELIZAVETA ISAEVA	{"phone": "+70966655052"}
0005433497704	D1FB5E	1677 882290	SERGEY ABRAMOV	{"email": "sergey-abramov-1962@postgrespro.ru", "phone": "+70865801194"}
0005433497705	B8C9A6	2806 008900	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova1983@postgrespro.ru", "phone": "+70893689667"}
0005433497706	985C69	5467 213335	ANATOLIY IVANOV	{"email": "anatoliyivanov-101967@postgrespro.ru", "phone": "+70042714940"}
0005433497707	2D7897	3005 036686	VALENTINA ABRAMOVA	{"email": "abramova.v11041977@postgrespro.ru", "phone": "+70823048645"}
0005433497708	2D7897	5644 420266	VALERIY KOZLOV	{"phone": "+70651262840"}
0005433497709	83899F	6763 563744	VALERIY KUZNECOV	{"email": "kuznecov_v-101971@postgrespro.ru", "phone": "+70236697453"}
0005433497710	83899F	7317 508787	MARIYA KISELEVA	{"phone": "+70721004700"}
0005433497711	96DDDF	3550 580077	TATYANA PETROVA	{"email": "petrova-t061977@postgrespro.ru", "phone": "+70664288839"}
0005433497712	E88463	1799 008010	ANNA FEDOROVA	{"email": "anna.fedorova-101962@postgrespro.ru", "phone": "+70868801667"}
0005433497713	E88463	5300 566581	ANNA ANISIMOVA	{"email": "anisimovaa101979@postgrespro.ru", "phone": "+70211791466"}
0005433497714	AC8334	1977 553814	ILYA KULIKOV	{"phone": "+70370564976"}
0005433497715	AC8334	5136 342930	DENIS DAVYDOV	{"email": "denis.davydov.1966@postgrespro.ru", "phone": "+70035873612"}
0005433497716	A4DF46	1097 512324	DMITRIY KRASNOV	{"email": "d-krasnov27101981@postgrespro.ru", "phone": "+70775659400"}
0005433497717	A4DF46	1392 431280	NIKOLAY NOVIKOV	{"email": "novikov_n_1968@postgrespro.ru", "phone": "+70917077483"}
0005433497718	D8920E	9776 500434	TATYANA DMITRIEVA	{"phone": "+70730945190"}
0005433497719	D8920E	8766 998804	VERA BARANOVA	{"phone": "+70448437285"}
0005433497720	9A4B47	8986 429619	GALINA KONOVALOVA	{"phone": "+70232403019"}
0005433497721	73E2A7	1857 103704	DMITRIY ORLOV	{"email": "d-orlov-1976@postgrespro.ru", "phone": "+70123705935"}
0005433497722	04286A	4385 069130	ALEKSANDRA GERASIMOVA	{"phone": "+70878510724"}
0005433497723	B028E4	8439 353771	ALEKSEY ANDREEV	{"phone": "+70691737207"}
0005433497724	B028E4	6832 822440	TIMOFEY ZAKHAROV	{"email": "t.zakharov_07111967@postgrespro.ru", "phone": "+70552361561"}
0005433497725	8E22DF	7724 003322	DENIS KUZNECOV	{"phone": "+70644298257"}
0005433497726	EA8665	6177 693877	OLGA MALYSHEVA	{"phone": "+70456568930"}
0005433497727	EA8665	9565 334530	YULIYA LEBEDEVA	{"phone": "+70611917304"}
0005433497728	EA8665	7958 796256	RAISA KOZLOVA	{"phone": "+70569667923"}
0005433497729	B0DA3F	3587 499770	OLEG BORISOV	{"email": "borisov-o10101965@postgrespro.ru", "phone": "+70159633657"}
0005433497730	B0DA3F	1773 776579	RAMIL TIMOFEEV	{"phone": "+70643137416"}
0005433497731	0E65AD	3411 651995	VALENTINA KUDRYASHOVA	{"phone": "+70140447788"}
0005433497732	0E65AD	9348 571652	VALENTINA LOGINOVA	{"phone": "+70135385461"}
0005433497733	BB36AD	7633 381212	SERGEY IVANOV	{"phone": "+70879945855"}
0005433497734	8E2930	5823 469001	NATALYA CHERNOVA	{"email": "chernovan1971@postgrespro.ru", "phone": "+70651655066"}
0005433497735	DEAA9A	5254 816671	MARINA BORISOVA	{"email": "marina_borisova1982@postgrespro.ru", "phone": "+70828860204"}
0005433497736	DEAA9A	1554 075090	RUSTYAM IVANOV	{"phone": "+70496591972"}
0005433497737	763A9D	9382 313570	ALEKSANDR NAUMOV	{"phone": "+70827664840"}
0005433497738	9169E7	5401 878613	VLADISLAV IVANOV	{"email": "ivanovvladislav-101967@postgrespro.ru", "phone": "+70736919052"}
0005433497739	05FA71	7277 572889	EVGENIY MOROZOV	{"phone": "+70662112578"}
0005433497740	05FA71	8551 001388	NIKOLAY MOROZOV	{"email": "morozov_nikolay-1971@postgrespro.ru", "phone": "+70023252650"}
0005433497741	B9F5EF	3449 906332	VALENTINA KUZMINA	{"email": "kuzmina.v.12091972@postgrespro.ru", "phone": "+70371378852"}
0005433497742	C3B70F	5227 108563	ALEKSANDR SAVELEV	{"phone": "+70259995542"}
0005433497743	C3B70F	3312 570688	LYUBOV CHERNOVA	{"email": "lyubovchernova_1961@postgrespro.ru", "phone": "+70858522610"}
0005433497744	1032DC	0548 460349	SERGEY ALEKSANDROV	{"email": "aleksandrov.sergey_26101972@postgrespro.ru", "phone": "+70263846262"}
0005433497745	1032DC	0071 117608	TATYANA TIMOFEEVA	{"email": "tatyana_timofeeva-1967@postgrespro.ru", "phone": "+70788059785"}
0005433497746	A85D9F	2855 891771	MAGOMED POPOV	{"email": "m.popov_19011973@postgrespro.ru", "phone": "+70832654176"}
0005433497747	374FC7	0963 959410	ALEKSANDR GORBUNOV	{"phone": "+70957101667"}
0005433497748	F5D045	6054 904138	VALENTINA DENISOVA	{"email": "denisova_v.1968@postgrespro.ru", "phone": "+70140236030"}
0005433497749	457E04	7259 377935	ALEKSEY TARASOV	{"phone": "+70584379862"}
0005433497750	FEFE29	3508 026165	ELENA ZAYCEVA	{"email": "zayceva.elena.121966@postgrespro.ru", "phone": "+70473141623"}
0005433497751	488611	4356 030405	VLADIMIR MOROZOV	{"phone": "+70643159296"}
0005433497752	F947BF	2069 470862	DMITRIY KRASNOV	{"email": "d.krasnov.061956@postgrespro.ru", "phone": "+70888942328"}
0005433497753	A0443F	1840 998487	VLADISLAV NAZAROV	{"email": "nazarov-vladislav_04021983@postgrespro.ru", "phone": "+70280981881"}
0005433497754	C87BFA	1695 057471	VYACHESLAV GUSEV	{"email": "gusev_v_051985@postgrespro.ru", "phone": "+70851878478"}
0005433497755	7B44FE	2388 532740	VASILIY SHEVCHENKO	{"phone": "+70345624929"}
0005433497756	7B44FE	0997 846077	VLADIMIR YAKOVLEV	{"email": "vyakovlev-23021980@postgrespro.ru", "phone": "+70302855899"}
0005433497757	2071BB	0007 792949	ELENA ERMAKOVA	{"phone": "+70895918493"}
0005433497758	6FEDC3	1180 136136	ALEKSANDR MIRONOV	{"phone": "+70709839392"}
0005433497759	6FEDC3	1556 583503	TATYANA ALEKSEEVA	{"email": "tatyanaalekseeva_1966@postgrespro.ru", "phone": "+70827678507"}
0005433497760	D8A048	7939 416515	ANDREY ANTONOV	{"phone": "+70740028027"}
0005433497761	D8A048	2248 437707	VIKTOR DMITRIEV	{"email": "dmitrievv091967@postgrespro.ru", "phone": "+70661066270"}
0005433497762	D8A048	8744 045456	ALFIYA KOVALEVA	{"phone": "+70044619024"}
0005433497763	CE155D	2750 364567	ANASTASIYA KOMAROVA	{"phone": "+70686742940"}
0005433497764	244A94	1124 043735	ELENA OSIPOVA	{"email": "elenaosipova.07061970@postgrespro.ru", "phone": "+70537034746"}
0005433497765	244A94	4633 998181	TATYANA GORBUNOVA	{"email": "t.gorbunova_051985@postgrespro.ru", "phone": "+70582575178"}
0005433497766	D60227	0200 668265	NATALYA GAVRILOVA	{"phone": "+70553316742"}
0005433497767	9B72E1	2577 393899	ANASTASIYA VASILEVA	{"email": "vasilevaanastasiya-04061969@postgrespro.ru", "phone": "+70065000273"}
0005433497768	9B72E1	7958 795821	VLADIMIR DAVYDOV	{"phone": "+70712588481"}
0005433497769	7D1DE4	9883 435624	VALENTINA ZAYCEVA	{"email": "zayceva-v-041969@postgrespro.ru", "phone": "+70559541839"}
0005433497770	DB58A9	8178 522832	VALERIY ALEKSANDROV	{"phone": "+70140326432"}
0005433497771	F9D506	5637 912165	VADIM YAKOVLEV	{"phone": "+70895118508"}
0005433497772	F9D506	5998 654482	ALINA PETROVA	{"phone": "+70246210088"}
0005433497773	E60236	4486 148408	EKATERINA KAZAKOVA	{"phone": "+70336505946"}
0005433497830	1474A4	4760 030519	NATALYA MIRONOVA	{"phone": "+70960249115"}
0005433497774	E60236	8654 487089	VALENTINA KOROLEVA	{"email": "korolevavalentina1972@postgrespro.ru", "phone": "+70926262167"}
0005433497775	E60236	3043 216151	ANNA ALEKSANDROVA	{"phone": "+70964929300"}
0005433497776	D79206	0963 273838	SERGEY MIRONOV	{"phone": "+70923113566"}
0005433497777	6E1DD6	6363 117096	DENIS GUSEV	{"phone": "+70352701822"}
0005433497778	03B430	6791 189586	VIKTOR BELOV	{"email": "belov_v.20081972@postgrespro.ru", "phone": "+70198024918"}
0005433497779	9C829B	2542 922438	PETR BONDARENKO	{"phone": "+70208730772"}
0005433497780	9C829B	8947 291578	ZINAIDA GUSEVA	{"email": "zinaida_guseva.19091976@postgrespro.ru", "phone": "+70594061010"}
0005433497781	9C829B	0249 131410	ALEKSANDR FOMIN	{"phone": "+70169755302"}
0005433497782	33863C	1274 496107	EVGENIY ALEKSEEV	{"email": "alekseev.e.1980@postgrespro.ru", "phone": "+70099227397"}
0005433497783	76C8DD	2570 233605	NINA BELYAEVA	{"email": "belyaeva-n.31031982@postgrespro.ru", "phone": "+70256588064"}
0005433497784	76C8DD	4277 156715	KRISTINA TARASOVA	{"email": "tarasova-kristina.1977@postgrespro.ru", "phone": "+70022317921"}
0005433497785	203363	7665 409893	LYUDMILA ZOTOVA	{"email": "lyudmila_zotova011967@postgrespro.ru", "phone": "+70158301862"}
0005433497786	A09561	8653 426504	TAMARA FEDOROVA	{"email": "fedorova.t_1965@postgrespro.ru", "phone": "+70993033798"}
0005433497787	A09561	3592 599207	ANDREY ZAYCEV	{"phone": "+70837308332"}
0005433497788	43CDC5	8151 951575	SERGEY ILIN	{"email": "ilin-sergey_1977@postgrespro.ru", "phone": "+70456286646"}
0005433497789	462368	5858 865687	SVETLANA FEDOROVA	{"email": "fedorova-svetlana_021973@postgrespro.ru", "phone": "+70142187007"}
0005433497790	C9E2BD	3722 485619	MARIYA MOROZOVA	{"phone": "+70670650984"}
0005433497791	CB7DE0	5331 068216	NATALIYA GUSEVA	{"email": "nataliya-guseva091960@postgrespro.ru", "phone": "+70847846990"}
0005433497792	A1BB3F	4122 732943	OLGA MOROZOVA	{"email": "morozova.o.04041977@postgrespro.ru", "phone": "+70666000904"}
0005433497793	A1BB3F	7936 391703	NINA FROLOVA	{"email": "ninafrolova031964@postgrespro.ru", "phone": "+70029860265"}
0005433497794	775055	5122 265439	DMITRIY KOZLOV	{"email": "d.kozlov27051973@postgrespro.ru", "phone": "+70290308692"}
0005433497795	B6A64D	4778 636153	VERONIKA MIRONOVA	{"phone": "+70840992967"}
0005433497796	B57886	4569 897607	LYUBOV SAVELEVA	{"phone": "+70202216368"}
0005433497797	DC7DD2	9689 560795	VLADIMIR BELOV	{"phone": "+70790103504"}
0005433497798	06FAE4	8059 070803	ANNA BOGDANOVA	{"phone": "+70579973245"}
0005433497799	06FAE4	1393 731782	IVAN POPOV	{"phone": "+70542667165"}
0005433497801	021B19	1143 922871	NATALYA OSIPOVA	{"phone": "+70492167877"}
0005433497802	83F85E	2651 045271	YULIYA AFANASEVA	{"email": "yafanaseva1977@postgrespro.ru", "phone": "+70145751307"}
0005433497803	83F85E	0393 004593	IRINA EFREMOVA	{"phone": "+70713275345"}
0005433497804	83F85E	6134 694092	GALINA GORBUNOVA	{"email": "gorbunovagalina1972@postgrespro.ru", "phone": "+70432799724"}
0005433497805	7330BB	6805 947138	EDUARD FROLOV	{"email": "e_frolov17061973@postgrespro.ru", "phone": "+70668667161"}
0005433497806	373712	1419 203102	ALEKSANDRA PAVLOVA	{"phone": "+70586997753"}
0005433497807	373712	3199 940205	KARINA SAVELEVA	{"email": "karina-saveleva.051972@postgrespro.ru", "phone": "+70120256410"}
0005433497808	0B287F	5564 149191	ELENA VLASOVA	{"phone": "+70280436497"}
0005433497809	D375D7	1515 330563	NIKOLAY RODIONOV	{"phone": "+70988851378"}
0005433497810	D375D7	7317 562602	EVGENIY VOROBEV	{"email": "vorobevevgeniy.1970@postgrespro.ru", "phone": "+70231059467"}
0005433497811	9ABFA8	8277 440205	ELENA NESTEROVA	{"email": "nesterovae_1978@postgrespro.ru", "phone": "+70347103979"}
0005433497812	10C420	3250 018771	TAMARA DANILOVA	{"phone": "+70285167336"}
0005433497813	10C420	3785 640384	SERGEY BELOV	{"email": "sergey-belov-081975@postgrespro.ru", "phone": "+70590821295"}
0005433497814	DCEC77	4826 826396	YULIYA NIKOLAEVA	{"phone": "+70780506369"}
0005433497815	E4B4FB	2243 615362	SHAMIL VLASOV	{"phone": "+70926710870"}
0005433497816	5070E3	8276 217298	SEMEN VASILEV	{"phone": "+70556161741"}
0005433497817	5372A9	8682 331524	ALEKSANDR SOLOVEV	{"phone": "+70003958499"}
0005433497818	5372A9	0196 921536	NATALYA FOMINA	{"email": "n_fomina121981@postgrespro.ru", "phone": "+70713079767"}
0005433497819	5372A9	2026 101871	DANIIL SAVELEV	{"phone": "+70701471257"}
0005433497820	A29883	1194 449037	ALEKSEY ILIN	{"email": "ilin_aleksey.071977@postgrespro.ru", "phone": "+70118092822"}
0005433497821	19CAE7	6991 732718	NATALYA FILIPPOVA	{"phone": "+70936553541"}
0005433497822	3C7AC0	7400 920188	BORIS ALEKSEEV	{"phone": "+70926347056"}
0005433497823	F629CB	9487 123412	KSENIYA DAVYDOVA	{"phone": "+70676108349"}
0005433497824	B57531	8037 877100	VLADIMIR MEDVEDEV	{"email": "vladimirmedvedev-18071958@postgrespro.ru", "phone": "+70176809765"}
0005433497825	D4996C	3464 008726	KIRILL KULIKOV	{"email": "kkulikov09011969@postgrespro.ru", "phone": "+70851971291"}
0005433497826	D4996C	6943 099868	IRINA KOMAROVA	{"email": "i.komarova-121973@postgrespro.ru", "phone": "+70298342320"}
0005433497827	205D23	6838 193328	SERGEY SOKOLOV	{"phone": "+70847265018"}
0005433497828	BC352C	0675 379665	ZHANNA KOZLOVA	{"email": "kozlovaz.041973@postgrespro.ru", "phone": "+70239879557"}
0005433497829	BC352C	1974 107636	IRINA ZAKHAROVA	{"email": "irina.zakharova-101975@postgrespro.ru", "phone": "+70570376606"}
0005433497831	1474A4	7702 295904	MARIYA MAKAROVA	{"email": "mmakarova-011967@postgrespro.ru", "phone": "+70857885289"}
0005433497832	643B34	2960 249765	TIMOFEY MAKAROV	{"phone": "+70084186239"}
0005433497833	1429DD	3547 721471	ALEKSANDRA SOLOVEVA	{"phone": "+70643804165"}
0005433497834	F16153	4374 725161	VITALIY FROLOV	{"email": "frolov.v10071975@postgrespro.ru", "phone": "+70747344593"}
0005433497835	364522	7014 517622	NIKITA SCHERBAKOV	{"email": "scherbakov-nikita.1980@postgrespro.ru", "phone": "+70134471214"}
0005433497836	364522	3444 377219	IRINA NOVIKOVA	{"email": "novikova_i.1973@postgrespro.ru", "phone": "+70231185527"}
0005433497837	D26045	4735 189214	YAROSLAV KUZNECOV	{"phone": "+70387685761"}
0005433497838	D26045	9626 087358	EVDOKIYA FROLOVA	{"phone": "+70966850046"}
0005433497839	B3F378	9295 514835	ELENA IVANOVA	{"phone": "+70770936370"}
0005433497840	1FC5EC	0316 127639	SVETLANA ZAKHAROVA	{"phone": "+70931778103"}
0005433497841	83A003	0702 077056	LYUDMILA VOROBEVA	{"phone": "+70115208287"}
0005433497842	C18B12	4211 664767	KIRILL ILIN	{"phone": "+70739114424"}
0005433497843	DA518C	2951 755493	ALEKSEY BONDARENKO	{"phone": "+70726253633"}
0005433497844	12C8D7	0926 528057	OLGA CHERNOVA	{"email": "o.chernova_12011985@postgrespro.ru", "phone": "+70459406337"}
0005433497845	5EDD3D	3941 378487	BORIS MOROZOV	{"email": "borismorozov1984@postgrespro.ru", "phone": "+70269798295"}
0005433497846	5EDD3D	8441 458712	ELENA LUKYANOVA	{"phone": "+70839014026"}
0005433497847	592C48	9901 986465	NINA MAKAROVA	{"phone": "+70283237315"}
0005433497848	6750B9	1727 753875	NIKOLAY DMITRIEV	{"email": "nikolay_dmitriev021972@postgrespro.ru", "phone": "+70631327351"}
0005433497849	6750B9	8298 916221	IRINA ALEKSEEVA	{"phone": "+70819420365"}
0005433497850	5EED19	5648 289696	ALEKSEY FOMIN	{"email": "aleksey_fomin.021971@postgrespro.ru", "phone": "+70326815223"}
0005433497851	520F13	6279 440266	VALENTINA OSIPOVA	{"phone": "+70955674923"}
0005433497852	72C8E2	3722 318334	ALEVTINA NESTEROVA	{"email": "alevtinanesterova_1972@postgrespro.ru", "phone": "+70577896151"}
0005433497853	EE7F7A	3796 919133	AYRAT AFANASEV	{"email": "afanasev_a_1978@postgrespro.ru", "phone": "+70541251746"}
0005433497854	729D0B	7263 081162	VLADIMIR OSIPOV	{"phone": "+70571227671"}
0005433497855	A1A465	8273 110866	VYACHESLAV EGOROV	{"email": "v-egorov_021972@postgrespro.ru", "phone": "+70881663453"}
0005433497856	A1A465	7969 342891	SERGEY IVANOV	{"email": "s.ivanov1968@postgrespro.ru", "phone": "+70553979426"}
0005433497857	71B9D9	7739 897014	VALENTINA ALEKSEEVA	{"email": "alekseeva_valentina_1982@postgrespro.ru", "phone": "+70066377394"}
0005433497858	71B9D9	8333 746037	IVAN DENISOV	{"phone": "+70949684340"}
0005433497859	D3B292	5757 592112	EVGENIYA TARASOVA	{"email": "evgeniya_tarasova.1988@postgrespro.ru", "phone": "+70957922898"}
0005433497860	3005D6	9438 549719	NATALYA IVANOVA	{"email": "natalya_ivanova011971@postgrespro.ru", "phone": "+70582060872"}
0005433497861	805515	3649 114635	IVAN FEDOTOV	{"phone": "+70068879892"}
0005433497862	00D643	2411 288065	ANTONINA ROMANOVA	{"phone": "+70241603871"}
0005433497863	00D643	3704 493483	ANVAR ZAYCEV	{"email": "zayceva-1967@postgrespro.ru", "phone": "+70067222250"}
0005433497864	BF6517	3222 629027	NIKOLAY RODIONOV	{"email": "rodionovnikolay_1975@postgrespro.ru", "phone": "+70937178101"}
0005433497865	E0E237	5606 071121	POLINA ZAKHAROVA	{"email": "polina_zakharova.1976@postgrespro.ru", "phone": "+70702088329"}
0005433497866	F6EF92	8684 842426	ELENA TIMOFEEVA	{"phone": "+70528676573"}
0005433497867	39A0FE	4821 509143	SOFYA SERGEEVA	{"phone": "+70336531233"}
0005433497868	39A0FE	1377 931751	ELENA MEDVEDEVA	{"phone": "+70716644186"}
0005433497869	F0DE9C	8321 230624	DIANA KUZNECOVA	{"phone": "+70366026855"}
0005433497870	F0DE9C	8078 910455	ALEKSEY MEDVEDEV	{"phone": "+70420350107"}
0005433497871	50F5F5	7768 172762	DMITRIY ZHUKOV	{"email": "dzhukov-1960@postgrespro.ru", "phone": "+70033296065"}
0005433497872	483029	3830 741516	STANISLAV KULIKOV	{"phone": "+70974212566"}
0005433497873	C1D8E4	3113 450157	LYUBOV EFIMOVA	{"email": "efimova_lyubov.22031983@postgrespro.ru", "phone": "+70699541394"}
0005433497874	88D4B9	5255 948546	NINA MAKSIMOVA	{"email": "maksimova_nina-1974@postgrespro.ru", "phone": "+70427190211"}
0005433497875	706F9A	0638 222771	VIKTOR ZHUKOV	{"email": "zhukovv1981@postgrespro.ru", "phone": "+70911977989"}
0005433497876	706F9A	8782 525216	PAVEL KOROLEV	{"phone": "+70997122654"}
0005433497877	B981BB	3585 073171	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov_31121981@postgrespro.ru", "phone": "+70242720133"}
0005433497878	B981BB	4057 262252	VLADIMIR MOROZOV	{"phone": "+70705435810"}
0005433497879	D737A6	1554 787215	MIKHAIL KOZLOV	{"phone": "+70201327588"}
0005433497880	D737A6	1482 444227	MARGARITA ORLOVA	{"phone": "+70692767103"}
0005433497881	04AA24	3608 583638	NATALIYA CHERNOVA	{"email": "chernova.nataliya1967@postgrespro.ru", "phone": "+70523162424"}
0005433497882	04AA24	0220 219702	OLGA VASILEVA	{"email": "vasileva-olga-1962@postgrespro.ru", "phone": "+70771372739"}
0005433497883	87341D	9676 900113	ALEKSANDR TARASOV	{"phone": "+70833302605"}
0005433497884	87341D	6872 665955	ELENA EGOROVA	{"email": "e_egorova.01061975@postgrespro.ru", "phone": "+70799737378"}
0005433497885	742151	7660 417124	NIKITA POPOV	{"phone": "+70896010688"}
0005433497886	A35178	2260 833830	RUSLAN MEDVEDEV	{"email": "medvedev_r1974@postgrespro.ru", "phone": "+70629961651"}
0005433497887	D1C610	9596 869928	EVGENIY NIKOLAEV	{"email": "evgeniynikolaev_011974@postgrespro.ru", "phone": "+70950821972"}
0005433497888	7B1A8D	4868 786124	VLADIMIR STEPANOV	{"phone": "+70900269328"}
0005433497889	7B1A8D	9243 587416	YULIYA VOROBEVA	{"email": "vorobeva.yuliya1974@postgrespro.ru", "phone": "+70838928400"}
0005433497890	A9E275	5237 380161	SERGEY ANTONOV	{"phone": "+70739444638"}
0005433497891	E0829D	2443 602675	GULNARA SOLOVEVA	{"email": "solovevag.03091975@postgrespro.ru", "phone": "+70058936385"}
0005433497892	54A66D	3593 555206	ZINAIDA MIRONOVA	{"phone": "+70141141727"}
0005433497893	FD76EA	3212 331933	ALEVTINA EFREMOVA	{"phone": "+70862166277"}
0005433497894	FD76EA	7006 741328	NATALYA IVANOVA	{"email": "n.ivanova1980@postgrespro.ru", "phone": "+70760360996"}
0005433506853	B0A2FE	4728 985794	LYUDMILA FILATOVA	{"phone": "+70607706665"}
0005433506854	41F8BE	3687 241181	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov.v14051962@postgrespro.ru", "phone": "+70939706767"}
0005433506855	3C720B	2036 854651	VALERIY POPOV	{"phone": "+70705592900"}
0005433506856	3C720B	4572 087619	VLADIMIR NAZAROV	{"phone": "+70286643476"}
0005433506857	0F09DD	9042 517964	DANIIL KUZNECOV	{"email": "kuznecov_d-041978@postgrespro.ru", "phone": "+70761546877"}
0005433506858	0F09DD	1609 427735	VLADIMIR MAKAROV	{"phone": "+70761943838"}
0005433506859	41A637	5727 895966	VASILIY TIKHONOV	{"email": "tikhonov.vasiliy_12031986@postgrespro.ru", "phone": "+70115427847"}
0005433506860	E58E68	5248 207633	ALEKSANDR NOVIKOV	{"email": "novikov-a1970@postgrespro.ru", "phone": "+70242637961"}
0005433506861	8B02BB	6261 711526	ANDREY BARANOV	{"phone": "+70136724341"}
0005433506862	0D89BA	3860 021274	ARINA STEPANOVA	{"phone": "+70416037663"}
0005433506863	DA903E	4450 061924	YURIY MELNIKOV	{"email": "melnikov-y-1970@postgrespro.ru", "phone": "+70858630035"}
0005433506864	AA5829	7318 953046	TATYANA MIRONOVA	{"phone": "+70722125398"}
0005433506865	480449	6512 300546	VLADIMIR TARASOV	{"phone": "+70467298348"}
0005433506866	480449	1379 710855	LYUDMILA LEBEDEVA	{"phone": "+70474142245"}
0005433506867	5F5900	1784 059829	VLADIMIR IVANOV	{"phone": "+70324963936"}
0005433506868	859F70	9846 849128	MAKSIM KONOVALOV	{"phone": "+70198145922"}
0005433506869	B17BD1	2411 451737	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.081969@postgrespro.ru", "phone": "+70420148912"}
0005433506870	636086	9426 820831	IVAN KUZNECOV	{"email": "ivan-kuznecov.061969@postgrespro.ru", "phone": "+70972260237"}
0005433506871	11F9B3	9508 165130	SVETLANA ANTONOVA	{"phone": "+70319557921"}
0005433506872	3E3A14	2862 216844	TATYANA ZAYCEVA	{"phone": "+70440242229"}
0005433506873	3E3A14	8046 612394	ROMAN NAUMOV	{"email": "naumov-roman.23071974@postgrespro.ru", "phone": "+70003082535"}
0005433506874	863FDC	2673 828897	EVGENIYA POPOVA	{"phone": "+70345564636"}
0005433506875	F68CEF	6772 642730	KIRILL SOKOLOV	{"email": "sokolov-kirill_29021976@postgrespro.ru", "phone": "+70983810618"}
0005433506876	CCCF9F	8381 759564	PAVEL ALEKSANDROV	{"phone": "+70385167143"}
0005433506877	0755E1	2070 327690	ELINA KUZNECOVA	{"phone": "+70788791773"}
0005433506878	0755E1	5511 855008	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov.24101968@postgrespro.ru", "phone": "+70598412336"}
0005433506879	AEAE67	2548 790584	GAGIK KUZNECOV	{"phone": "+70772102386"}
0005433506880	772D59	9938 890092	ANNA TIMOFEEVA	{"phone": "+70331121547"}
0005433506881	772D59	4500 949456	RAVIL TIKHONOV	{"phone": "+70982182118"}
0005433506882	D5411B	2308 429024	VIKTORIYA KONDRATEVA	{"email": "kondrateva_viktoriya.17031974@postgrespro.ru", "phone": "+70179869192"}
0005433506883	4B54A8	7224 372747	VALENTIN STEPANOV	{"phone": "+70584881543"}
0005433506884	9E012C	3274 094365	VIKTOR KRASNOV	{"phone": "+70848339720"}
0005433506885	5F9ECC	6901 775775	MARIYA BORISOVA	{"email": "m.borisova_05071969@postgrespro.ru", "phone": "+70817156915"}
0005433506886	7256AB	1382 765789	DARYA VOLKOVA	{"email": "d_volkova_18111979@postgrespro.ru", "phone": "+70023214940"}
0005433506887	5FFB86	4181 363794	VLADIMIR MOROZOV	{"phone": "+70675627211"}
0005433506888	669FAE	7846 730057	NADEZHDA KONOVALOVA	{"email": "n_konovalova-011962@postgrespro.ru", "phone": "+70239686460"}
0005433506889	669FAE	0480 813124	ZHANNA POPOVA	{"email": "popovazhanna-1972@postgrespro.ru", "phone": "+70837746766"}
0005433506890	46E59A	1238 576556	IRINA TIMOFEEVA	{"phone": "+70798968273"}
0005433506891	729C23	9883 022922	ELENA ZAKHAROVA	{"email": "zakharova_e_1970@postgrespro.ru", "phone": "+70892746583"}
0005433506892	290291	5986 422627	SVETLANA MAKAROVA	{"phone": "+70011492415"}
0005433506893	66FB0B	9300 710143	SERGEY EGOROV	{"email": "egorov_s_011969@postgrespro.ru", "phone": "+70332246004"}
0005433506894	1B832A	3431 319400	OLGA FEDOROVA	{"phone": "+70154581949"}
0005433506895	A33CF5	9669 843844	OLGA SMIRNOVA	{"phone": "+70135757390"}
0005433506896	96BDCB	4904 184815	ALEKSEY PETROV	{"email": "petrov_a_22011970@postgrespro.ru", "phone": "+70794576261"}
0005433506897	8C8E4C	4122 698771	OLGA FADEEVA	{"phone": "+70370845278"}
0005433506898	ED225B	5776 744025	ALEKSANDR PETROV	{"phone": "+70856136277"}
0005433506899	ED225B	9550 230878	DENIS KAZAKOV	{"email": "dkazakov_111977@postgrespro.ru", "phone": "+70491371892"}
0005433506900	ED225B	5091 007357	EKATERINA KONOVALOVA	{"email": "e_konovalova071976@postgrespro.ru", "phone": "+70329896203"}
0005433506901	4A5D96	3998 149650	EVGENIY KONOVALOV	{"email": "konovalov.evgeniy04121976@postgrespro.ru", "phone": "+70190376446"}
0005433506902	A139DF	3058 594838	DENIS MAKSIMOV	{"phone": "+70667683180"}
0005433506903	A139DF	6193 417990	NATALYA EFIMOVA	{"email": "efimovan25101978@postgrespro.ru", "phone": "+70156219943"}
0005433506904	672326	0684 296968	EKATERINA AKIMOVA	{"email": "akimova_e_031981@postgrespro.ru", "phone": "+70613841293"}
0005433506905	349027	2439 394729	ALEKSEY FEDOROV	{"phone": "+70778776309"}
0005433506906	391ACF	5927 430732	DINARA IVANOVA	{"phone": "+70988608566"}
0005433506907	EA7B51	3112 802441	VLADIMIR TIKHONOV	{"phone": "+70391248707"}
0005433506908	3A3E74	9810 506550	ANDREY RODIONOV	{"email": "andrey_rodionov16021978@postgrespro.ru", "phone": "+70263431609"}
0005433506909	9FB058	8548 565812	LYUBOV SEMENOVA	{"email": "lsemenova_28061975@postgrespro.ru", "phone": "+70810491801"}
0005433506910	0378F9	2944 224696	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya-12111971@postgrespro.ru", "phone": "+70246327926"}
0005433506911	0378F9	1391 804786	GEORGIY ROMANOV	{"email": "romanovgeorgiy081980@postgrespro.ru", "phone": "+70999298448"}
0005433506912	94708C	3015 964861	NINA ZHUKOVA	{"email": "zhukova.n-041969@postgrespro.ru", "phone": "+70466087779"}
0005433506913	7E9E8E	4631 258382	TATYANA SERGEEVA	{"email": "sergeevat.1968@postgrespro.ru", "phone": "+70120830600"}
0005433506914	75A5A6	5812 467815	VASILIY IVANOV	{"email": "ivanov-v_111973@postgrespro.ru", "phone": "+70167312056"}
0005433506915	4C5930	9097 085911	SERGEY ZAKHAROV	{"phone": "+70620047492"}
0005433506916	F30F60	4553 980760	LILIYA KUZNECOVA	{"phone": "+70081511970"}
0005433506917	8C6646	2061 398552	MARIANNA ALEKSEEVA	{"phone": "+70849056252"}
0005433506918	8C6646	9555 036745	NINA KUZNECOVA	{"phone": "+70120969105"}
0005433506919	8C6646	3988 876395	YULIYA RODIONOVA	{"phone": "+70424641586"}
0005433506920	A82D0C	2190 412879	ALEKSANDR KULIKOV	{"email": "a-kulikov.1963@postgrespro.ru", "phone": "+70208139757"}
0005433506921	FAF437	2261 145251	RAISA ANISIMOVA	{"email": "anisimova-r_1981@postgrespro.ru", "phone": "+70674127848"}
0005433506922	FAF437	4720 279326	VYACHESLAV BORISOV	{"email": "vborisov.08081975@postgrespro.ru", "phone": "+70065009079"}
0005433506923	053F20	8175 244229	ALEKSEY OSIPOV	{"email": "osipov_a_1978@postgrespro.ru", "phone": "+70014034854"}
0005433506924	053F20	3653 410939	VERA VASILEVA	{"phone": "+70933649339"}
0005433506925	6FE72F	2784 330585	RUSLAN KARPOV	{"phone": "+70413487903"}
0005433506926	9DAAF7	3108 142979	EKATERINA SOROKINA	{"phone": "+70021114010"}
0005433506927	F16EAC	5320 014481	ANASTASIYA POLYAKOVA	{"email": "polyakovaa_1968@postgrespro.ru", "phone": "+70377794317"}
0005433506928	847A0B	1576 260261	MARIYA SERGEEVA	{"email": "sergeeva-mariya1968@postgrespro.ru", "phone": "+70660778601"}
0005433506929	FA87E7	9916 308084	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr28101970@postgrespro.ru", "phone": "+70773249807"}
0005433506930	A01752	4236 419289	GENNADIY TIKHONOV	{"email": "tikhonovg.07121963@postgrespro.ru", "phone": "+70268884622"}
0005433506931	57964D	0075 938706	SERGEY SMIRNOV	{"email": "sergey.smirnov-08071975@postgrespro.ru", "phone": "+70946232631"}
0005433506932	16DCEC	2731 729895	DANIIL TARASOV	{"phone": "+70303645106"}
0005433506933	571E40	7654 143684	KRISTINA NIKIFOROVA	{"phone": "+70403341383"}
0005433506934	571E40	0183 603061	MIKHAIL TIMOFEEV	{"phone": "+70738025435"}
0005433506935	905487	2280 352268	GALINA ANTONOVA	{"email": "g.antonova101958@postgrespro.ru", "phone": "+70568850914"}
0005433506936	18B70C	1942 497089	TATYANA MOROZOVA	{"email": "tatyana_morozova.1971@postgrespro.ru", "phone": "+70467688558"}
0005433506937	18B70C	7849 665130	IVAN POPOV	{"phone": "+70439814915"}
0005433506938	227008	9684 768233	ANNA NIKITINA	{"phone": "+70393232743"}
0005433506939	AAAFD6	2484 669128	ELENA FROLOVA	{"email": "frolova-elena-1975@postgrespro.ru", "phone": "+70568981574"}
0005433506940	646BBE	5637 866866	MARIYA KONDRATEVA	{"phone": "+70187646000"}
0005433506941	646BBE	1414 461104	NADEZHDA MAKAROVA	{"phone": "+70793418879"}
0005433506942	9CA528	9032 624977	ARTUR FROLOV	{"phone": "+70694425413"}
0005433506943	E9A802	0989 370340	VASILIY KISELEV	{"email": "v-kiselev-021966@postgrespro.ru", "phone": "+70534302304"}
0005433506944	FC388B	0966 546107	EVGENIY SEMENOV	{"phone": "+70996856638"}
0005433506945	962DF8	5129 346621	GALINA VASILEVA	{"email": "g-vasileva.23091967@postgrespro.ru", "phone": "+70671400414"}
0005433506946	962DF8	8977 219520	SVETLANA SOKOLOVA	{"phone": "+70521208668"}
0005433506947	EA0F6F	0042 311521	VALENTINA ANDREEVA	{"email": "andreeva_valentina-06051964@postgrespro.ru", "phone": "+70114788149"}
0005433506948	69C193	1822 594189	LYUDMILA NAZAROVA	{"phone": "+70372110750"}
0005433506949	ED1A44	2319 980114	IVAN MIRONOV	{"phone": "+70995219229"}
0005433506950	C616CC	0052 649837	SVETLANA BELOVA	{"phone": "+70946511961"}
0005433506951	C616CC	8227 017967	NATALYA ALEKSEEVA	{"email": "natalya-alekseeva-1980@postgrespro.ru", "phone": "+70831722031"}
0005433506952	BA177F	3548 092389	ALEKSEY SOLOVEV	{"phone": "+70653339944"}
0005433506953	BA177F	5291 503875	VLADIMIR KUZMIN	{"phone": "+70333669832"}
0005433506954	290EEB	8835 704826	VIKTOR DMITRIEV	{"email": "dmitriev.v_061981@postgrespro.ru", "phone": "+70648636646"}
0005433506955	EB2DDB	0829 417727	EVGENIY MOROZOV	{"phone": "+70882205226"}
0005433506956	67A77A	3515 918951	ANNA PAVLOVA	{"email": "a-pavlova.051976@postgrespro.ru", "phone": "+70521114799"}
0005433506957	67A77A	4093 034284	VERA VASILEVA	{"phone": "+70332914251"}
0005433506958	FD2F80	1991 594347	DMITRIY PETROV	{"phone": "+70349485491"}
0005433506959	60B433	8393 813948	ANATOLIY SOLOVEV	{"phone": "+70356185397"}
0005433506960	A5AAD1	6153 240720	ANDREY ILIN	{"email": "ilin.andrey-26031956@postgrespro.ru", "phone": "+70839256842"}
0005433506961	B5300A	8494 243513	NADEZHDA ANTONOVA	{"email": "nantonova.051963@postgrespro.ru", "phone": "+70624710904"}
0005433506962	B5300A	4118 727757	EDUARD FEDOROV	{"phone": "+70850311590"}
0005433506963	E40E0A	5349 470882	ANNA FEDOROVA	{"email": "fedorova_anna.111968@postgrespro.ru", "phone": "+70248311488"}
0005433506964	E40E0A	8196 859504	TATYANA SMIRNOVA	{"phone": "+70235684280"}
0005433506965	E5A22F	5789 986401	TATYANA ARKHIPOVA	{"phone": "+70350384202"}
0005433506966	2A0337	4377 193729	NIKOLAY NOVIKOV	{"phone": "+70854119738"}
0005433506967	2A0337	8810 629982	VIKTORIYA MATVEEVA	{"phone": "+70814505990"}
0005433506968	B50A7A	4784 224557	MIKHAIL DENISOV	{"email": "m-denisov1976@postgrespro.ru", "phone": "+70648174241"}
0005433506969	5F0FDD	9332 242886	IGOR ROMANOV	{"phone": "+70183018638"}
0005433506970	5F0FDD	1639 857715	VADIM KUZMIN	{"email": "kuzmin_vadim_15081977@postgrespro.ru", "phone": "+70274336726"}
0005433506971	DCD67F	7518 394787	OLGA KISELEVA	{"email": "kiselevaolga061970@postgrespro.ru", "phone": "+70677201409"}
0005433506972	C1C7BE	0643 719104	SERGEY FROLOV	{"email": "frolov.sergey-091958@postgrespro.ru", "phone": "+70550977762"}
0005433506973	09BF6A	6167 782239	GALINA DANILOVA	{"phone": "+70743786937"}
0005433506974	6B02AA	7989 095260	RUSTEM IVANOV	{"phone": "+70468831173"}
0005433506975	FDFCE2	7867 885897	OLGA POLYAKOVA	{"phone": "+70483110503"}
0005433506976	61D59E	1453 885609	TATYANA ANDREEVA	{"phone": "+70267392233"}
0005433506977	7202F8	9724 419929	SERGEY BARANOV	{"phone": "+70622739749"}
0005433506978	427FB7	4799 433266	ANDREY ISAEV	{"phone": "+70640484218"}
0005433506979	07BF53	1792 659704	OLGA ORLOVA	{"phone": "+70139860986"}
0005433506980	73AE6B	3441 287207	MAKSIM KUZNECOV	{"email": "m-kuznecov-1980@postgrespro.ru", "phone": "+70913191011"}
0005433506981	CD54BB	3120 698919	PAVEL GORBUNOV	{"email": "p-gorbunov.1963@postgrespro.ru", "phone": "+70293546291"}
0005433506982	507E31	7079 068422	NIKOLAY TARASOV	{"email": "n_tarasov.21121978@postgrespro.ru", "phone": "+70725780530"}
0005433506983	86A39B	7168 467957	ALBERT MIRONOV	{"email": "a-mironov1969@postgrespro.ru", "phone": "+70153396121"}
0005433506984	86A39B	8945 170748	ALEKSANDR KISELEV	{"phone": "+70436945931"}
0005433506985	A6DCCC	4562 243748	PAVEL ANTONOV	{"phone": "+70337459347"}
0005433506986	A6DCCC	2171 868253	ALEKSEY NAZAROV	{"email": "nazarov-a-07081981@postgrespro.ru", "phone": "+70578771670"}
0005433506987	A6DCCC	7893 338870	SVETLANA KUZMINA	{"email": "skuzmina-15011975@postgrespro.ru", "phone": "+70728096609"}
0005433506988	5883B4	7781 351089	ALEKSEY POPOV	{"phone": "+70579160482"}
0005433506989	D7E714	2122 643534	TATYANA NAZAROVA	{"phone": "+70934166209"}
0005433506990	3A31DB	5962 298602	PETR KUZNECOV	{"email": "kuznecov-petr.15051970@postgrespro.ru", "phone": "+70300642105"}
0005433506991	291EC4	2471 761538	LYUDMILA SOKOLOVA	{"phone": "+70627539792"}
0005433506992	D22399	4555 424847	IGOR DMITRIEV	{"email": "igor_dmitriev1970@postgrespro.ru", "phone": "+70826233619"}
0005433506993	E29E81	9809 403705	RIMMA MAKSIMOVA	{"email": "r-maksimova041975@postgrespro.ru", "phone": "+70802681715"}
0005433506994	BE5F23	6497 196365	PAVEL AFANASEV	{"phone": "+70277384875"}
0005433506995	F4C2D4	0347 141306	EVGENIYA ALEKSEEVA	{"email": "alekseeva_e-15011967@postgrespro.ru", "phone": "+70019963649"}
0005433506996	82339D	7810 971821	TATYANA LOGINOVA	{"email": "loginova.t.111968@postgrespro.ru", "phone": "+70322523839"}
0005433506997	4E97EB	6819 550771	VIKTORIYA MOROZOVA	{"phone": "+70226866545"}
0005433506998	4E97EB	3279 438329	RADIK TIKHONOV	{"phone": "+70391294668"}
0005433506999	94A1C0	0969 562526	KIRA TARASOVA	{"email": "kiratarasova_08081978@postgrespro.ru", "phone": "+70395945552"}
0005433507000	94A1C0	1689 901639	NATALYA NAUMOVA	{"phone": "+70261450256"}
0005433507001	8ABE04	9551 181688	OLGA MOROZOVA	{"phone": "+70754272006"}
0005433507002	D6BA0C	8656 808563	LYUDMILA LUKYANOVA	{"email": "lukyanova-lyudmila11091975@postgrespro.ru", "phone": "+70822585673"}
0005433507003	086C42	7737 923134	KLAVDIYA OSIPOVA	{"email": "osipovaklavdiya-13011960@postgrespro.ru", "phone": "+70616483672"}
0005433507004	446E58	7507 449064	NADEZHDA MIRONOVA	{"phone": "+70582528966"}
0005433507005	FC7380	1449 274729	DENIS SERGEEV	{"email": "sergeevdenis-02091961@postgrespro.ru", "phone": "+70832211214"}
0005433507006	D9E245	2988 800862	ANASTASIYA KISELEVA	{"phone": "+70357953269"}
0005433507007	980260	0944 081114	LYUDMILA EGOROVA	{"email": "l.egorova101963@postgrespro.ru", "phone": "+70539880824"}
0005433507008	980260	7302 392485	OLGA EGOROVA	{"email": "olga_egorova081973@postgrespro.ru", "phone": "+70893135084"}
0005433507009	980260	7190 864274	VITALIY ANDREEV	{"phone": "+70767673062"}
0005433507010	64C2B0	0775 595524	TATYANA ALEKSANDROVA	{"phone": "+70760396396"}
0005433507011	0ECEEF	8230 632440	LILIYA GORBUNOVA	{"email": "l-gorbunova-081971@postgrespro.ru", "phone": "+70086465777"}
0005433507012	0ECEEF	8676 070758	OKSANA KRASNOVA	{"email": "o-krasnova_071962@postgrespro.ru", "phone": "+70730060273"}
0005433507013	A865D7	0219 549685	LYUBOV KOMAROVA	{"email": "komarova.lyubov.31101967@postgrespro.ru", "phone": "+70987589819"}
0005433507014	CD8FF2	6507 734616	RAIL ZAYCEV	{"phone": "+70899859510"}
0005433507015	3222A0	5248 285076	VALERIYA DENISOVA	{"email": "denisova.valeriya-061973@postgrespro.ru", "phone": "+70521287284"}
0005433507016	3222A0	9758 506655	YURIY ILIN	{"email": "yuriy_ilin_101970@postgrespro.ru", "phone": "+70774710910"}
0005433507017	A76B17	2535 007858	VADIM IVANOV	{"email": "ivanov.vadim_25011973@postgrespro.ru", "phone": "+70856521522"}
0005433507018	A76B17	7863 167611	DMITRIY KULIKOV	{"email": "d-kulikov.051974@postgrespro.ru", "phone": "+70193940002"}
0005433507019	0C68B4	9959 940510	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov22101977@postgrespro.ru", "phone": "+70687730219"}
0005433507020	0C68B4	1724 162612	GALINA VOLKOVA	{"phone": "+70378295326"}
0005433507021	3C2EC0	6759 527187	DENIS IVANOV	{"phone": "+70756022305"}
0005433507022	3C2EC0	7835 889661	EKATERINA KOMAROVA	{"email": "ekaterinakomarova-1981@postgrespro.ru", "phone": "+70737106311"}
0005433507023	8363EE	5133 402986	ALEKSEY VOROBEV	{"phone": "+70567611970"}
0005433507024	0F3B88	9924 540842	VLADISLAV KUZMIN	{"email": "kuzminv-1974@postgrespro.ru", "phone": "+70227947872"}
0005433507025	CB125D	1506 695878	SVETLANA ZAYCEVA	{"email": "s-zayceva.10041961@postgrespro.ru", "phone": "+70939512802"}
0005433507026	CB125D	3925 372326	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr19061968@postgrespro.ru", "phone": "+70092144585"}
0005433507027	5D9640	5113 776840	ANGELINA MELNIKOVA	{"email": "a.melnikova-1959@postgrespro.ru", "phone": "+70620111457"}
0005433507028	7A3A58	7880 442192	OLGA KAZAKOVA	{"phone": "+70242165277"}
0005433507029	7A3A58	3359 199884	ALEKSEY KONOVALOV	{"email": "aleksey_konovalov-1963@postgrespro.ru", "phone": "+70637320396"}
0005433507030	F2D282	5540 746529	VIKTOR VOROBEV	{"email": "v.vorobev1981@postgrespro.ru", "phone": "+70719433196"}
0005433507031	F2D282	7722 720697	VIKTOR YAKOVLEV	{"phone": "+70008642086"}
0005433507032	CF6C5D	0937 502786	TATYANA DENISOVA	{"email": "denisovat.121972@postgrespro.ru", "phone": "+70759149848"}
0005433507033	CF6C5D	1836 267857	GENNADIY SMIRNOV	{"phone": "+70840269427"}
0005433507034	FF0440	8030 462004	EKATERINA KUZMINA	{"email": "e.kuzmina-031974@postgrespro.ru", "phone": "+70953985585"}
0005433507035	8E5D52	7814 832494	NINA MOROZOVA	{"email": "morozova.n_1976@postgrespro.ru", "phone": "+70075010623"}
0005433507036	C126B1	1964 575692	TATYANA ABRAMOVA	{"email": "abramova.tatyana_091973@postgrespro.ru", "phone": "+70620230896"}
0005433507037	5109E1	7005 080112	DMITRIY GERASIMOV	{"email": "gerasimov_dmitriy_101972@postgrespro.ru", "phone": "+70296912840"}
0005433507038	8A4834	8177 598717	ELENA KOZLOVA	{"phone": "+70405030163"}
0005433507039	F1358D	7064 173256	PETR IVANOV	{"phone": "+70617296632"}
0005433507040	FF5F93	2801 081872	MARIYA SIDOROVA	{"email": "m_sidorova1969@postgrespro.ru", "phone": "+70568552605"}
0005433507041	FF5F93	3826 798531	GALINA PETROVA	{"phone": "+70262168303"}
0005433507042	396583	0595 481648	ALISA SOROKINA	{"phone": "+70449552048"}
0005433507043	AABD5F	9277 597574	ELENA FILATOVA	{"email": "e.filatova07121981@postgrespro.ru", "phone": "+70587175240"}
0005433507044	C9E6C2	2801 723344	RAISA VASILEVA	{"phone": "+70625406695"}
0005433507045	91977C	6920 523845	ALEKSANDR STEPANOV	{"phone": "+70105389904"}
0005433507046	D4943B	1112 680118	VALENTINA BORISOVA	{"email": "valentina_borisova.1970@postgrespro.ru", "phone": "+70763565344"}
0005433507047	D4943B	9189 368976	YULIYA SMIRNOVA	{"phone": "+70822379715"}
0005433507048	123891	1045 283351	DENIS IVANOV	{"phone": "+70130770398"}
0005433507049	123891	2228 558893	ELENA FROLOVA	{"email": "frolova.elena.051971@postgrespro.ru", "phone": "+70330671708"}
0005433507050	ED7164	8187 126769	ZINAIDA FOMINA	{"email": "z_fomina_101970@postgrespro.ru", "phone": "+70427365589"}
0005433507051	3FB44B	9663 186055	IGOR OSIPOV	{"email": "osipovi_061966@postgrespro.ru", "phone": "+70715428379"}
0005433507052	F2CB10	4407 834638	ELENA GAVRILOVA	{"email": "gavrilovaelena.061975@postgrespro.ru", "phone": "+70837446295"}
0005433507053	E23A47	7031 251108	SERGEY KOROLEV	{"email": "s_korolev-121974@postgrespro.ru", "phone": "+70285799283"}
0005433507054	E23A47	0246 147120	EKATERINA MEDVEDEVA	{"email": "ekaterina.medvedeva1964@postgrespro.ru", "phone": "+70703208746"}
0005433507055	AE7F5E	7341 801339	VLADIMIR MEDVEDEV	{"email": "v_medvedev_1959@postgrespro.ru", "phone": "+70090311325"}
0005433507056	AE7F5E	1376 393474	GULNARA NIKOLAEVA	{"email": "gulnara.nikolaeva08101975@postgrespro.ru", "phone": "+70367482037"}
0005433507057	162985	0043 233179	NATALYA IVANOVA	{"email": "natalya_ivanova-051978@postgrespro.ru", "phone": "+70498786110"}
0005433507058	E47209	8747 971191	NINA FILATOVA	{"phone": "+70838356369"}
0005433507059	AF3F59	8489 609964	ANNA NOVIKOVA	{"phone": "+70263576524"}
0005433507060	AF3F59	0754 340062	OLGA FOMINA	{"email": "fomina.o091973@postgrespro.ru", "phone": "+70691130046"}
0005433507061	AF3F59	8448 459977	GALINA ZAYCEVA	{"email": "galina-zayceva-1977@postgrespro.ru", "phone": "+70244040915"}
0005433507062	C13B00	0775 861755	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova-1968@postgrespro.ru", "phone": "+70781282468"}
0005433507063	E9D76D	0561 431208	YULIYA SERGEEVA	{"phone": "+70586416191"}
0005433507064	E1DD7F	3923 226874	MAKSIM NIKITIN	{"email": "mnikitin-1967@postgrespro.ru", "phone": "+70093168497"}
0005433507065	E97BF2	8636 286515	VERA ISAEVA	{"phone": "+70649488001"}
0005433507066	E97BF2	7595 982912	LARISA TIKHONOVA	{"phone": "+70378993708"}
0005433507067	8A8D93	7698 775700	ALEKSANDR SOKOLOV	{"phone": "+70508016612"}
0005433507068	533E4B	0005 404718	ALEKSANDR MARTYNOV	{"email": "aleksandr_martynov22121974@postgrespro.ru", "phone": "+70213741482"}
0005433507069	533E4B	2751 609877	IGOR KAZAKOV	{"phone": "+70119533922"}
0005433507070	FF0392	4616 203077	ALINA ILINA	{"email": "ilinaalina1980@postgrespro.ru", "phone": "+70288309761"}
0005433507071	4C685C	9778 851018	VLADIMIR VASILEV	{"email": "v_vasilev28011984@postgrespro.ru", "phone": "+70206949113"}
0005433507072	4C685C	3492 567430	NIKOLAY MAKAROV	{"phone": "+70154643760"}
0005433507073	A7F3D2	2212 876761	LYUDMILA TITOVA	{"email": "titovalyudmila-02071970@postgrespro.ru", "phone": "+70183946554"}
0005433507074	E2F438	9870 911037	TATYANA ZAYCEVA	{"phone": "+70968148240"}
0005433507075	55C3E9	0180 017846	NIKITA FROLOV	{"phone": "+70580354123"}
0005433507076	55C3E9	9721 055022	DENIS ALEKSANDROV	{"phone": "+70343298344"}
0005433507077	138FB9	1817 562296	KIRILL MIRONOV	{"email": "mironov.k_101970@postgrespro.ru", "phone": "+70570997097"}
0005433507078	138FB9	0176 446639	OKSANA ANDREEVA	{"email": "andreeva-o041977@postgrespro.ru", "phone": "+70372154069"}
0005433507079	D0B68C	8509 507887	LYUBOV VLASOVA	{"email": "vlasova-l16071966@postgrespro.ru", "phone": "+70495373259"}
0005433507080	D0B68C	9973 789658	ANGELINA VOLKOVA	{"phone": "+70774451475"}
0005433507081	DBEE6E	5699 967136	KSENIYA PAVLOVA	{"email": "pavlovak.1972@postgrespro.ru", "phone": "+70561710350"}
0005433507082	623B49	4087 854658	ALEKSANDR MAKAROV	{"phone": "+70849015207"}
0005433507083	623B49	9329 410071	LIDIYA SMIRNOVA	{"email": "smirnova_l30061974@postgrespro.ru", "phone": "+70556240324"}
0005433507084	A28AE8	7988 849283	TATYANA GUSEVA	{"phone": "+70998382263"}
0005433507085	673D5D	8610 855832	EVGENIY KUZNECOV	{"email": "e_kuznecov.021971@postgrespro.ru", "phone": "+70441737996"}
0005433507086	673D5D	1664 137789	VALENTINA KARPOVA	{"email": "karpova-v.18051972@postgrespro.ru", "phone": "+70749027814"}
0005433507087	759581	7438 149397	IRINA FILIPPOVA	{"email": "irina.filippova-031972@postgrespro.ru", "phone": "+70928288425"}
0005433507088	D6C5CB	0199 001502	VADIM IVANOV	{"phone": "+70893492520"}
0005433507089	27477C	7846 693819	ANASTASIYA POPOVA	{"email": "popovaa_1966@postgrespro.ru", "phone": "+70445516912"}
0005433507090	6979A8	2407 673470	EGOR ORLOV	{"email": "orlov_egor-30031975@postgrespro.ru", "phone": "+70704979596"}
0005433507091	6979A8	8069 317228	YURIY KONOVALOV	{"email": "konovalov_yuriy1972@postgrespro.ru", "phone": "+70539043191"}
0005433507092	7A10C7	3413 830452	IRINA ZAKHAROVA	{"email": "zakharova-irina.1968@postgrespro.ru", "phone": "+70583580218"}
0005433507093	97259B	6312 343048	VALERIY KULIKOV	{"email": "v_kulikov.1968@postgrespro.ru", "phone": "+70741731582"}
0005433507094	37B3A3	6385 596322	OLGA SEMENOVA	{"phone": "+70562068349"}
0005433507095	BDB2F5	1556 330678	TATYANA KONOVALOVA	{"phone": "+70490452513"}
0005433507096	B3E869	9805 088571	BORIS ANTONOV	{"phone": "+70792877485"}
0005433507097	B3E869	1831 677417	VALENTINA IVANOVA	{"phone": "+70033029137"}
0005433507098	F4053A	3310 628108	NINA VLASOVA	{"phone": "+70479583015"}
0005433507099	F8D778	4864 763714	MARINA BARANOVA	{"phone": "+70781187082"}
0005433507100	82C3FD	3359 477426	VALENTINA KALININA	{"email": "kalinina-valentina.10091969@postgrespro.ru", "phone": "+70297685809"}
0005433507101	3557F3	5317 913312	ANASTASIYA KRASNOVA	{"email": "krasnova-anastasiya121970@postgrespro.ru", "phone": "+70541565831"}
0005433507102	7AC74C	2139 124290	VADIM NAZAROV	{"phone": "+70784219296"}
0005433507103	7AC74C	4988 293827	MIKHAIL KUZMIN	{"email": "kuzmin.mikhail-1970@postgrespro.ru", "phone": "+70035405181"}
0005433507104	A3D628	4561 556287	KLAVDIYA STEPANOVA	{"email": "stepanova.k011981@postgrespro.ru", "phone": "+70135730118"}
0005433507105	A3D628	0645 358710	NADEZHDA KOVALEVA	{"phone": "+70513995670"}
0005433507106	E7A1EF	4796 309561	VALENTINA MELNIKOVA	{"phone": "+70301359547"}
0005433507107	B50424	4558 070574	DMITRIY KUDRYASHOV	{"email": "d-kudryashov28121965@postgrespro.ru", "phone": "+70621841258"}
0005433507108	01E6A0	8558 435906	ALEKSANDR ANDREEV	{"email": "a.andreev_091962@postgrespro.ru", "phone": "+70334823540"}
0005433507109	F9A6D5	8377 948266	NADEZHDA SERGEEVA	{"email": "n_sergeeva031973@postgrespro.ru", "phone": "+70490660820"}
0005433507110	F9A6D5	1170 249693	ANDREY SMIRNOV	{"email": "smirnov-a18021975@postgrespro.ru", "phone": "+70044384322"}
0005433507111	F9A6D5	4863 593619	NADEZHDA KUZNECOVA	{"phone": "+70988880778"}
0005433507112	695370	4474 611694	ANNA LAZAREVA	{"phone": "+70756354017"}
0005433507113	7A55FE	6566 680139	OKSANA MARTYNOVA	{"email": "oksanamartynova-051972@postgrespro.ru", "phone": "+70798781383"}
0005433507114	45B821	9630 875840	SERGEY PAVLOV	{"email": "pavlov.s-10091968@postgrespro.ru", "phone": "+70567065620"}
0005433507115	45B821	7635 459294	VLADIMIR PETROV	{"phone": "+70805381695"}
0005433507116	5C3958	8650 516238	VLADIMIR STEPANOV	{"email": "stepanovv_06071969@postgrespro.ru", "phone": "+70681593707"}
0005433507117	12392B	9187 939181	OLGA BOGDANOVA	{"email": "o.bogdanova.17051961@postgrespro.ru", "phone": "+70054335516"}
0005433507118	EE8417	6085 015614	VLADIMIR ORLOV	{"email": "v_orlov_18041964@postgrespro.ru", "phone": "+70986318104"}
0005433507119	6A674B	4805 622285	KONSTANTIN MOISEEV	{"phone": "+70701992512"}
0005433507120	CB365C	1649 719905	IVAN NIKOLAEV	{"email": "nikolaev_i.29121965@postgrespro.ru", "phone": "+70895288502"}
0005433507121	A0B0A5	4260 715912	ELIZAVETA BARANOVA	{"phone": "+70189146338"}
0005433507122	7266BA	1209 239052	TATYANA LOGINOVA	{"phone": "+70396702839"}
0005433507123	75C194	1634 280589	ALEKSANDR MAKSIMOV	{"email": "amaksimov.1969@postgrespro.ru", "phone": "+70558343632"}
0005433507124	75C194	7699 115415	GENNADIY PAVLOV	{"phone": "+70074763788"}
0005433507125	75C194	1519 095983	ANNA POTAPOVA	{"email": "apotapova17011968@postgrespro.ru", "phone": "+70241341013"}
0005433507126	457C54	5916 281031	ROMAN GAVRILOV	{"phone": "+70623415974"}
0005433507127	3C4B28	7064 022442	KSENIYA OSIPOVA	{"phone": "+70906183540"}
0005433507128	697F5F	0172 191675	TATYANA KOROLEVA	{"email": "t-koroleva_1965@postgrespro.ru", "phone": "+70314194707"}
0005433507129	60EB3F	7895 373222	GENNADIY NIKITIN	{"phone": "+70902541895"}
0005433507130	A8C393	8677 816019	LYUDMILA PETROVA	{"email": "l-petrova_121966@postgrespro.ru", "phone": "+70458242075"}
0005433507131	DE498B	9196 899011	OKSANA STEPANOVA	{"phone": "+70101447410"}
0005433507132	C2293A	6800 363182	VASILIY VASILEV	{"email": "vasilevvasiliy.101972@postgrespro.ru", "phone": "+70497217134"}
0005433507133	03E899	8508 445863	ANDREY OSIPOV	{"email": "osipov-andrey.061988@postgrespro.ru", "phone": "+70942750659"}
0005433507134	6E5B08	5094 297208	VLADIMIR KOZLOV	{"phone": "+70612724194"}
0005433507135	2DFDCD	8896 909215	ANASTASIYA ZHUKOVA	{"email": "zhukova-anastasiya051966@postgrespro.ru", "phone": "+70255743523"}
0005433507136	2DFDCD	6164 073859	DMITRIY ORLOV	{"email": "orlovd-22111980@postgrespro.ru", "phone": "+70317888025"}
0005433507137	5D438A	9533 266033	VALENTINA KONOVALOVA	{"email": "konovalova-valentina-05111973@postgrespro.ru", "phone": "+70370159836"}
0005433507138	5D438A	3298 453021	NINA SCHERBAKOVA	{"phone": "+70880808090"}
0005433507139	CB937E	5249 738538	MARIANNA ANDREEVA	{"email": "mariannaandreeva-19061967@postgrespro.ru", "phone": "+70351149638"}
0005433507140	CB937E	2768 929953	INESSA ABRAMOVA	{"email": "abramova-i-07071979@postgrespro.ru", "phone": "+70833901479"}
0005433507141	76680F	0074 851508	SERGEY PETROV	{"phone": "+70321784650"}
0005433507142	051D71	1069 753103	DENIS MAKAROV	{"email": "d_makarov07081985@postgrespro.ru", "phone": "+70415739810"}
0005433507143	4FE93F	9963 163384	NATALYA POTAPOVA	{"email": "potapova-natalya_061971@postgrespro.ru", "phone": "+70601975624"}
0005433507144	4FE93F	8845 822452	ANDREY VLASOV	{"email": "a_vlasov.19031964@postgrespro.ru", "phone": "+70226995113"}
0005433507145	24F42E	0809 642977	ANTONINA POPOVA	{"email": "popovaa-1965@postgrespro.ru", "phone": "+70622166799"}
0005433507146	24F42E	9382 686978	RAMIL VOROBEV	{"email": "ramil-vorobev_04041972@postgrespro.ru", "phone": "+70802732748"}
0005433507147	B0E6A8	5873 937336	DARYA ZAYCEVA	{"phone": "+70020934432"}
0005433507148	FD8911	4010 838647	VIKTOR KRASNOV	{"email": "krasnovv011965@postgrespro.ru", "phone": "+70762037238"}
0005433507149	6B9963	7177 146668	MARINA DMITRIEVA	{"email": "dmitrieva_m-13031975@postgrespro.ru", "phone": "+70567830870"}
0005433507150	DB87EE	2893 456377	PETR BARANOV	{"email": "petr_baranov-031980@postgrespro.ru", "phone": "+70059116394"}
0005433507151	A01145	2169 656327	NADEZHDA KRASNOVA	{"email": "n.krasnova1971@postgrespro.ru", "phone": "+70939837445"}
0005433507152	A01145	8441 912719	TATYANA VOROBEVA	{"email": "vorobevatatyana.1976@postgrespro.ru", "phone": "+70162660260"}
0005433507153	67A63C	3050 315968	MARIYA MIKHAYLOVA	{"phone": "+70188205909"}
0005433507154	205BEB	0951 966689	STANISLAV SEMENOV	{"phone": "+70719855357"}
0005433507155	205BEB	4790 208233	MARINA LOGINOVA	{"phone": "+70149342167"}
0005433507156	667921	8021 831749	MIKHAIL IVANOV	{"email": "ivanov_mikhail1974@postgrespro.ru", "phone": "+70526455372"}
0005433507157	FB7356	0758 874732	ALEKSANDR KUZNECOV	{"phone": "+70644827996"}
0005433507158	1D6558	6044 790086	DMITRIY GRIGOREV	{"phone": "+70918549286"}
0005433507159	1D6558	7528 063819	ANATOLIY MEDVEDEV	{"email": "medvedevanatoliy.1959@postgrespro.ru", "phone": "+70920358631"}
0005433507160	E439EB	6755 005156	VERA SERGEEVA	{"phone": "+70264202624"}
0005433507161	B17E44	0692 516353	GUZEL NAUMOVA	{"phone": "+70481726724"}
0005433507162	AFED52	5208 625691	ANNA MALYSHEVA	{"email": "a_malysheva1968@postgrespro.ru", "phone": "+70322956540"}
0005433507163	FF409A	6099 608359	LILIYA KOVALEVA	{"email": "lkovaleva_051969@postgrespro.ru", "phone": "+70432690876"}
0005433507164	FF409A	9878 672662	GALINA KOROLEVA	{"phone": "+70711635944"}
0005433507165	B054A7	1534 998194	MIKHAIL TIMOFEEV	{"email": "m_timofeev-17091960@postgrespro.ru", "phone": "+70868482781"}
0005433507166	C8CF2F	4480 078395	OLEG PAVLOV	{"phone": "+70717612263"}
0005433507167	F08040	1968 286430	LYUDMILA ANISIMOVA	{"phone": "+70452895484"}
0005433507168	BD9F89	7615 750829	VALERIY MEDVEDEV	{"phone": "+70858046016"}
0005433507169	9DBBFF	2753 051202	VLADISLAV SIDOROV	{"email": "vladislav-sidorov_1972@postgrespro.ru", "phone": "+70608894231"}
0005433507170	9DBBFF	9415 959627	ARTEM SERGEEV	{"email": "artem.sergeev_031977@postgrespro.ru", "phone": "+70808102646"}
0005433507171	9DBBFF	7639 247571	OLESYA KUZMINA	{"phone": "+70273860964"}
0005433507172	BF2B10	7467 068274	IRINA KAZAKOVA	{"email": "kazakovairina1965@postgrespro.ru", "phone": "+70411561178"}
0005433507173	20F3BA	4151 162799	PAVEL KRASNOV	{"email": "krasnov-p30111964@postgrespro.ru", "phone": "+70778870722"}
0005433507174	5F1C29	0641 513073	ANATOLIY IVANOV	{"email": "a_ivanov_27021971@postgrespro.ru", "phone": "+70121342633"}
0005433507175	3D1F2D	2634 761411	ALEKSANDR RODIONOV	{"phone": "+70764029316"}
0005433507176	A0C7D4	2503 706047	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova-13031977@postgrespro.ru", "phone": "+70743679210"}
0005433507177	A292AD	3501 518123	SABINA KONDRATEVA	{"phone": "+70647007330"}
0005433507178	C6D488	1884 044703	SVETLANA LOGINOVA	{"email": "svetlana-loginova1973@postgrespro.ru", "phone": "+70624203112"}
0005433507179	AE4A97	9160 714845	OLGA STEPANOVA	{"phone": "+70651597770"}
0005433507180	2679EA	4530 199429	ANDREY ANDREEV	{"phone": "+70156590399"}
0005433507181	75EC83	3584 603297	SVETLANA RODIONOVA	{"email": "svetlana_rodionova071977@postgrespro.ru", "phone": "+70118742621"}
0005433507182	C89C52	5240 527414	TATYANA ZHURAVLEVA	{"email": "zhuravlevat-1968@postgrespro.ru", "phone": "+70658607512"}
0005433507183	98C5F9	1535 877454	SVETLANA MEDVEDEVA	{"email": "smedvedeva1971@postgrespro.ru", "phone": "+70518062050"}
0005433507184	E891E1	2572 033015	VIKTORIYA KULIKOVA	{"phone": "+70508626145"}
0005433507185	E891E1	6012 227882	NATALYA KOMAROVA	{"phone": "+70951415021"}
0005433507186	304D0E	6130 191644	RUSTAM KUDRYASHOV	{"phone": "+70213835677"}
0005433507187	61C55D	3669 302375	VALERIY SMIRNOV	{"phone": "+70007593087"}
0005433507188	3E95FB	7961 764674	PAVEL POPOV	{"phone": "+70011173844"}
0005433507189	034C46	7975 491964	SERGEY NIKITIN	{"email": "sergey-nikitin_24061970@postgrespro.ru", "phone": "+70194449657"}
0005433507190	DAF225	8586 750166	TATYANA DENISOVA	{"email": "t_denisova.091967@postgrespro.ru", "phone": "+70960849665"}
0005433507191	DC3A0F	6775 325170	TIMUR GRIGOREV	{"email": "grigorevtimur.31101974@postgrespro.ru", "phone": "+70522498746"}
0005433507192	640EE6	6555 467870	OKSANA CHERNOVA	{"phone": "+70601958551"}
0005433507193	37F233	8035 445687	ARTEM NIKOLAEV	{"phone": "+70211682538"}
0005433507194	8C29BF	3205 431095	NATALYA ISAEVA	{"email": "n.isaeva.28101972@postgrespro.ru", "phone": "+70605357627"}
0005433507195	8C29BF	6993 627604	KAMIL SAVELEV	{"email": "kamil-savelev1974@postgrespro.ru", "phone": "+70817355905"}
0005433507196	C49E37	6362 003689	OLGA ANISIMOVA	{"email": "olga-anisimova_011975@postgrespro.ru", "phone": "+70684755821"}
0005433507197	C49E37	9928 531638	GRIGORIY KONOVALOV	{"email": "konovalov.grigoriy_121971@postgrespro.ru", "phone": "+70838958242"}
0005433507198	1C1BC7	3147 273266	SEMEN VASILEV	{"email": "s_vasilev.31071976@postgrespro.ru", "phone": "+70637432868"}
0005433507199	ADB77B	1082 199559	VLADIMIR KISELEV	{"phone": "+70206335520"}
0005433507200	ADB77B	2720 913016	TATYANA GERASIMOVA	{"email": "gerasimovatatyana.011974@postgrespro.ru", "phone": "+70376463793"}
0005433507201	AB3FA9	4029 040046	ELENA ISAEVA	{"phone": "+70090563897"}
0005433507202	9AADCA	6209 801350	VALENTINA ILINA	{"phone": "+70653552716"}
0005433507203	9DC592	6408 153897	ILYA ORLOV	{"email": "orlov.i_041983@postgrespro.ru", "phone": "+70703042325"}
0005433507204	45F791	2185 649473	KARINA IVANOVA	{"phone": "+70156667945"}
0005433507205	45F791	2849 094233	PAVEL ZHUKOV	{"email": "pavelzhukov-07111962@postgrespro.ru", "phone": "+70092068807"}
0005433507206	591865	2537 847718	NATALYA AFANASEVA	{"phone": "+70544601193"}
0005433507207	918488	9613 314411	NADEZHDA SERGEEVA	{"phone": "+70561090360"}
0005433507208	B75701	3036 705894	MAKSIM SOROKIN	{"phone": "+70007292958"}
0005433507209	B75701	4118 802373	LYUDMILA KUZNECOVA	{"email": "kuznecova_l22061965@postgrespro.ru", "phone": "+70541058683"}
0005433507210	B95027	5793 727744	ANATOLIY ROMANOV	{"phone": "+70999015620"}
0005433507211	B95027	2489 125714	NADEZHDA BORISOVA	{"phone": "+70013772438"}
0005433507212	6C68F0	1326 230243	NATALYA SIDOROVA	{"email": "nsidorova13041971@postgrespro.ru", "phone": "+70654850153"}
0005433507213	F8D268	9764 775323	ALEKSANDR NOVIKOV	{"phone": "+70074340601"}
0005433507214	00E195	1549 697790	KONSTANTIN ALEKSANDROV	{"phone": "+70658554772"}
0005433507215	34D440	4570 491100	OLGA ZAYCEVA	{"phone": "+70629476839"}
0005433507216	9562BC	6658 427270	ALEKSANDR GRIGOREV	{"email": "agrigorev19081973@postgrespro.ru", "phone": "+70450070141"}
0005433507217	E1AE09	4077 604183	NAIL SCHERBAKOV	{"phone": "+70447435628"}
0005433507218	DDFF6A	9790 064092	MIKHAIL VOLKOV	{"email": "volkovm-26041976@postgrespro.ru", "phone": "+70167774558"}
0005433507219	646553	0541 426350	VYACHESLAV KUZMIN	{"email": "kuzmin-v_12021970@postgrespro.ru", "phone": "+70641877012"}
0005433507220	98FCBE	7319 408170	GRIGORIY KUZNECOV	{"email": "kuznecov-grigoriy25071959@postgrespro.ru", "phone": "+70422456338"}
0005433507221	BD560F	1499 242137	EKATERINA KUZNECOVA	{"phone": "+70181369258"}
0005433507222	BD560F	3780 627574	MARINA VASILEVA	{"email": "vasileva-marina_111966@postgrespro.ru", "phone": "+70918942534"}
0005433507223	64A3E5	2597 749145	LIDIYA OVCHINNIKOVA	{"phone": "+70612827858"}
0005433507224	FEF357	6699 044941	SERGEY NIKOLAEV	{"phone": "+70157246294"}
0005433507225	FEF357	7726 005700	LYUBOV SOLOVEVA	{"phone": "+70498191150"}
0005433507226	2331C2	6118 705595	EVGENIY MAKAROV	{"email": "e_makarov1970@postgrespro.ru", "phone": "+70278140792"}
0005433507227	A8B981	9973 970920	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr1974@postgrespro.ru", "phone": "+70724328326"}
0005433507228	A8B981	5210 089533	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov.1986@postgrespro.ru", "phone": "+70578864082"}
0005433507229	F0483C	7774 860631	TATYANA PETROVA	{"email": "tatyana-petrova1968@postgrespro.ru", "phone": "+70257185321"}
0005433507230	DA20A6	1418 741328	TATYANA MARTYNOVA	{"email": "tmartynova.1976@postgrespro.ru", "phone": "+70197487607"}
0005433507231	930FB1	1468 359253	OLGA RODIONOVA	{"email": "rodionova_o19041971@postgrespro.ru", "phone": "+70907474318"}
0005433507232	AFFA27	4557 549643	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr-03121962@postgrespro.ru", "phone": "+70331378136"}
0005433507233	AFFA27	1742 379280	EVGENIY YAKOVLEV	{"email": "evgeniyyakovlev.081980@postgrespro.ru", "phone": "+70234294060"}
0005433507234	FF7DDD	2096 608928	IRINA OVCHINNIKOVA	{"email": "ovchinnikova-irina.041983@postgrespro.ru", "phone": "+70150010905"}
0005433507235	FF7DDD	5867 683909	NONNA GRISHINA	{"phone": "+70502357502"}
0005433507236	8B27BC	6287 387984	OLGA SIDOROVA	{"email": "o.sidorova.081976@postgrespro.ru", "phone": "+70949248130"}
0005433507237	8B27BC	1168 707145	GALINA MIRONOVA	{"phone": "+70626590707"}
0005433507238	A93B00	1832 538837	SERGEY POPOV	{"email": "sergeypopov_1969@postgrespro.ru", "phone": "+70512362964"}
0005433507239	B4D93B	3240 708695	EVGENIYA IVANOVA	{"email": "evgeniya.ivanova-1961@postgrespro.ru", "phone": "+70563277972"}
0005433507240	46DFFC	2403 389764	NATALIYA BORISOVA	{"phone": "+70303409015"}
0005433507241	61D35E	1934 482786	MARIYA TROFIMOVA	{"email": "mariya_trofimova_1988@postgrespro.ru", "phone": "+70500216761"}
0005433507242	61D35E	5970 816418	NIKOLAY OSIPOV	{"phone": "+70759277459"}
0005433507243	76CBDB	9105 945164	ANNA TARASOVA	{"phone": "+70502674115"}
0005433507244	3E3554	1200 361263	YURIY FROLOV	{"email": "y_frolov.1968@postgrespro.ru", "phone": "+70747802166"}
0005433507245	B7E294	0813 102221	ALLA DENISOVA	{"phone": "+70595211506"}
0005433507246	12BCBB	0362 357218	GENNADIY KUZNECOV	{"phone": "+70421141902"}
0005433507247	3A26DC	3702 869513	NATALYA FILIPPOVA	{"email": "nfilippova-21011972@postgrespro.ru", "phone": "+70780242986"}
0005433507248	C1613B	2205 489031	ANNA MOISEEVA	{"phone": "+70518873208"}
0005433507249	C1613B	6368 828041	NATALYA PAVLOVA	{"phone": "+70361958199"}
0005433507250	47A8C5	7043 846341	VALENTINA RODIONOVA	{"phone": "+70747058871"}
0005433507251	D57E39	4231 120314	VADIM GUSEV	{"phone": "+70202381814"}
0005433507252	D57E39	5841 458662	NINA SMIRNOVA	{"phone": "+70470953805"}
0005433507253	65DD00	7498 040123	EMILIYA LOGINOVA	{"phone": "+70337536391"}
0005433507254	65DD00	6514 352112	NIKOLAY ANTONOV	{"phone": "+70928801076"}
0005433507255	0E8B94	3246 270373	POLINA VASILEVA	{"phone": "+70517293195"}
0005433507256	9053F7	7349 878370	NIKOLAY KUZMIN	{"email": "nikolay-kuzmin1971@postgrespro.ru", "phone": "+70274302169"}
0005433507257	88E86B	5854 192036	ALEKSANDR SAVELEV	{"email": "asavelev_1960@postgrespro.ru", "phone": "+70773212636"}
0005433507258	88E86B	5231 765218	LARISA BELYAEVA	{"email": "belyaeva.l-19041970@postgrespro.ru", "phone": "+70035106978"}
0005433507259	E6B9BB	1410 077259	RAISA NIKOLAEVA	{"phone": "+70499702581"}
0005433507260	E6B9BB	7173 179853	VLADIMIR KRASNOV	{"phone": "+70845107622"}
0005433507261	E5BA50	7585 564445	MARINA IVANOVA	{"email": "marina.ivanova01111968@postgrespro.ru", "phone": "+70642374684"}
0005433507262	E5BA50	9895 963048	VALERIY SHEVCHENKO	{"email": "valeriyshevchenko_1969@postgrespro.ru", "phone": "+70456729018"}
0005433507263	55197B	0863 114720	VLADIMIR ZHUKOV	{"phone": "+70169646466"}
0005433507264	55197B	6503 636640	EGOR DAVYDOV	{"phone": "+70989582857"}
0005433507265	CB82A8	7580 590068	VLADIMIR SCHERBAKOV	{"phone": "+70389542484"}
0005433507266	E67360	8601 888132	IGOR PETROV	{"phone": "+70804878746"}
0005433507267	9B493E	3220 885424	SERGEY MIRONOV	{"email": "s-mironov_061969@postgrespro.ru", "phone": "+70238390472"}
0005433507268	5F6CAA	7513 442064	YULIYA NOVIKOVA	{"phone": "+70750926669"}
0005433507269	F12496	3768 365423	VIKTOR VLASOV	{"email": "vlasov-viktor_1965@postgrespro.ru", "phone": "+70504125569"}
0005433507270	F12496	3960 052290	POLINA KOROLEVA	{"email": "koroleva-p-1976@postgrespro.ru", "phone": "+70637599847"}
0005433507271	F12496	4112 605266	DMITRIY MOISEEV	{"email": "moiseev_d-1975@postgrespro.ru", "phone": "+70340005541"}
0005433507272	FF2EB3	2929 154978	EVGENIYA ZHUKOVA	{"phone": "+70343251883"}
0005433507273	FF2EB3	5184 780989	EKATERINA MAKAROVA	{"phone": "+70734180379"}
0005433507274	BF6BB1	7016 360023	ALEKSANDRA BARANOVA	{"email": "abaranova_011979@postgrespro.ru", "phone": "+70070638700"}
0005433507459	CB7CFF	1509 986686	VALENTINA RODIONOVA	{"phone": "+70760172535"}
0005433507275	BF6BB1	5698 052023	FANIYA KOLESNIKOVA	{"email": "kolesnikova_f_14121987@postgrespro.ru", "phone": "+70850824460"}
0005433507276	BF6BB1	8260 665995	RUSLAN SEMENOV	{"phone": "+70961865262"}
0005433507277	504817	7067 624448	OLGA ROMANOVA	{"email": "romanova_olga.07061973@postgrespro.ru", "phone": "+70315786086"}
0005433507278	29E546	3930 651094	OKSANA MAKAROVA	{"email": "o-makarova-1977@postgrespro.ru", "phone": "+70899865679"}
0005433507279	5FCE24	1130 414690	KAMILA MIRONOVA	{"phone": "+70827150880"}
0005433507280	2C3BB9	5755 831164	ALINA FOMINA	{"phone": "+70944540041"}
0005433507281	2C3BB9	3606 892694	NIKOLAY DAVYDOV	{"phone": "+70619490212"}
0005433507282	07A0CB	9296 554305	ALEKSANDR KISELEV	{"phone": "+70448106417"}
0005433507283	07A0CB	7361 229358	LYUDMILA MEDVEDEVA	{"email": "medvedeva-lyudmila031970@postgrespro.ru", "phone": "+70654906449"}
0005433507284	A7DC4A	7866 137748	TAMARA ZAYCEVA	{"email": "tamara-zayceva-1973@postgrespro.ru", "phone": "+70180325349"}
0005433507285	0D15F9	2567 812064	ANDREY FEDOTOV	{"phone": "+70493021022"}
0005433507286	B33E2A	5694 727755	EKATERINA MEDVEDEVA	{"email": "e_medvedeva1966@postgrespro.ru", "phone": "+70149046844"}
0005433507287	2A1B19	8876 895168	TATYANA YAKOVLEVA	{"phone": "+70892237413"}
0005433507288	588EEF	7220 839017	NINA DANILOVA	{"phone": "+70559341853"}
0005433507289	B6AC24	6343 839262	ALEKSEY NAUMOV	{"phone": "+70329439369"}
0005433507290	B6AC24	0764 703765	DMITRIY MATVEEV	{"email": "d-matveev021956@postgrespro.ru", "phone": "+70914923006"}
0005433507291	6DC2C7	4623 095167	ANNA RYABOVA	{"email": "anna-ryabova_21031979@postgrespro.ru", "phone": "+70281481114"}
0005433507292	1C0572	2947 801436	DENIS EGOROV	{"phone": "+70721632556"}
0005433507293	F45E51	1375 137499	PAVEL KUZNECOV	{"phone": "+70930807406"}
0005433507294	F45E51	9374 423312	NIKOLAY SIDOROV	{"email": "n.sidorov.091967@postgrespro.ru", "phone": "+70611267203"}
0005433507295	60DEE2	5289 924400	ANNA ZHUKOVA	{"email": "zhukovaa.111976@postgrespro.ru", "phone": "+70262311291"}
0005433507296	60DEE2	5610 874413	TATYANA KRASNOVA	{"phone": "+70935604369"}
0005433507297	2D1FCD	8540 221099	ALEKSANDRA SOROKINA	{"email": "sorokina_aleksandra_1983@postgrespro.ru", "phone": "+70985391382"}
0005433507298	2D1FCD	8848 860403	NINA AFANASEVA	{"phone": "+70980283491"}
0005433507299	D84957	6218 578721	EMILIYA ANDREEVA	{"phone": "+70355520498"}
0005433507300	DCFF60	1615 138184	PRASKOVYA MIKHAYLOVA	{"email": "mikhaylova-p_02041981@postgrespro.ru", "phone": "+70246667725"}
0005433507301	DCFF60	8235 301026	EKATERINA MIKHAYLOVA	{"email": "mikhaylova.ekaterina-19121961@postgrespro.ru", "phone": "+70932319681"}
0005433507302	F16697	3165 350470	ANDREY STEPANOV	{"email": "stepanov-a-091973@postgrespro.ru", "phone": "+70188058002"}
0005433507303	0FCBC3	0138 265600	ALEKSANDR VOLKOV	{"phone": "+70027791411"}
0005433507304	85DC9E	0366 847359	ALEKSANDR CHERNOV	{"phone": "+70194596154"}
0005433507305	35FBAC	9302 616617	VLADIMIR SAVELEV	{"phone": "+70971923898"}
0005433507306	35FBAC	3016 029461	MIKHAIL TIMOFEEV	{"email": "timofeevm-1965@postgrespro.ru", "phone": "+70654513755"}
0005433507307	35FBAC	5093 018465	KONSTANTIN VOLKOV	{"email": "k.volkov_22031967@postgrespro.ru", "phone": "+70821410253"}
0005433507308	723673	2604 528273	ANNA NIKOLAEVA	{"email": "nikolaeva_anna_16111962@postgrespro.ru", "phone": "+70221993327"}
0005433507309	F6FAC1	1945 848973	IGOR SCHERBAKOV	{"email": "scherbakov.igor-1966@postgrespro.ru", "phone": "+70331338517"}
0005433507310	F6FAC1	4516 638654	YURIY GAVRILOV	{"phone": "+70376936458"}
0005433507311	B246B0	3526 467270	ANNA MAKSIMOVA	{"email": "maksimova_a071969@postgrespro.ru", "phone": "+70851758849"}
0005433507312	F7758B	6782 973411	ELENA IVANOVA	{"phone": "+70401511019"}
0005433507313	6D71A5	0132 648020	YULIYA IVANOVA	{"email": "yivanova.04111986@postgrespro.ru", "phone": "+70530627297"}
0005433507314	6D71A5	7293 635181	SERGEY PAVLOV	{"phone": "+70426437269"}
0005433507315	EEF75D	3644 599398	VALERIY NAUMOV	{"phone": "+70283045641"}
0005433507316	A1CECB	2796 096240	VALERIY KOZLOV	{"phone": "+70338224341"}
0005433507317	4F28E1	8588 386059	RODION KISELEV	{"phone": "+70654469133"}
0005433507318	080E11	7602 498769	ANZHELIKA FILIPPOVA	{"email": "filippova.anzhelika1976@postgrespro.ru", "phone": "+70133344489"}
0005433507319	080E11	9728 516232	KLAVDIYA NOVIKOVA	{"phone": "+70673732512"}
0005433507320	E5494B	6408 042066	TIMOFEY SERGEEV	{"phone": "+70924240237"}
0005433507321	E5494B	5286 806033	SERGEY SMIRNOV	{"email": "ssmirnov_1971@postgrespro.ru", "phone": "+70733039613"}
0005433507322	881AD5	1569 385015	GALINA IVANOVA	{"phone": "+70548210226"}
0005433507323	881AD5	5240 567912	LYUBOV SAVELEVA	{"phone": "+70764533664"}
0005433507324	1A4627	7670 147102	ALEKSEY ZHUKOV	{"email": "a-zhukov_23051960@postgrespro.ru", "phone": "+70114781025"}
0005433507325	BA14DF	9409 420972	ELENA FEDOROVA	{"email": "e.fedorova.13071963@postgrespro.ru", "phone": "+70125970941"}
0005433507326	848B4C	5935 490110	VLADISLAV NAZAROV	{"phone": "+70219387234"}
0005433507327	DB0AFB	8354 077037	OLGA KUZNECOVA	{"phone": "+70441025449"}
0005433507328	DB0AFB	1191 587813	ANATOLIY KRASNOV	{"email": "akrasnov-03011972@postgrespro.ru", "phone": "+70837937112"}
0005433507329	2324FA	8087 435612	SERGEY ROMANOV	{"email": "sromanov-1968@postgrespro.ru", "phone": "+70242837251"}
0005433507330	CE49D5	2110 398066	VALENTIN ANTONOV	{"email": "antonov-v.1973@postgrespro.ru", "phone": "+70279481139"}
0005433507331	E3E9C7	0210 875258	VALENTINA MOROZOVA	{"email": "morozova.valentina-1970@postgrespro.ru", "phone": "+70060012778"}
0005433507332	AFD3FC	8925 896217	OKSANA KUZNECOVA	{"email": "kuznecova.o021977@postgrespro.ru", "phone": "+70685197106"}
0005433507333	AFD3FC	3693 796550	MARINA KISELEVA	{"email": "marina-kiseleva.26081967@postgrespro.ru", "phone": "+70774011035"}
0005433507334	AFD3FC	1494 985493	ANASTASIYA FEDOROVA	{"phone": "+70091042863"}
0005433507335	43E749	6951 003809	NATALYA KOROLEVA	{"phone": "+70638408225"}
0005433507336	D10050	2997 671345	YULIYA NESTEROVA	{"email": "yuliyanesterova29101967@postgrespro.ru", "phone": "+70352872860"}
0005433507337	ADFF6A	0493 337006	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev1960@postgrespro.ru", "phone": "+70315817024"}
0005433507338	ADFF6A	8612 828875	DARYA CHERNOVA	{"phone": "+70526097506"}
0005433507339	60B806	3040 912210	NATALIYA ZAKHAROVA	{"email": "nataliya-zakharova_021964@postgrespro.ru", "phone": "+70011199961"}
0005433507340	60B806	3698 178767	ANNA POTAPOVA	{"phone": "+70608605584"}
0005433507341	FCB908	4977 572211	ALEKSANDRA FOMINA	{"email": "a_fomina_1961@postgrespro.ru", "phone": "+70733617099"}
0005433507342	D06165	6875 306205	EDUARD ANTONOV	{"email": "eduard.antonov-30011970@postgrespro.ru", "phone": "+70906080920"}
0005433507343	0725CC	7749 967414	MARIYA KAZAKOVA	{"email": "mariyakazakova_1974@postgrespro.ru", "phone": "+70463237822"}
0005433507344	6BCC01	3008 751421	RIMMA IVANOVA	{"email": "rimma.ivanova03081973@postgrespro.ru", "phone": "+70637513682"}
0005433507345	DD8395	8686 907496	VYACHESLAV POPOV	{"email": "v.popov_121961@postgrespro.ru", "phone": "+70010680000"}
0005433507346	DD8395	2047 555087	GALINA FILIPPOVA	{"email": "filippova-g_1977@postgrespro.ru", "phone": "+70252642523"}
0005433507347	C36324	4533 945871	ANATOLIY ALEKSEEV	{"email": "alekseev.anatoliy061974@postgrespro.ru", "phone": "+70722701163"}
0005433507348	887EB0	3696 121742	VYACHESLAV PAVLOV	{"email": "pavlov_vyacheslav.06011969@postgrespro.ru", "phone": "+70105109726"}
0005433507349	B958EA	3772 248593	NATALYA ZOTOVA	{"phone": "+70795096781"}
0005433507350	B958EA	2427 110085	LYUDMILA NIKITINA	{"phone": "+70264170219"}
0005433507351	B958EA	2062 260990	NADEZHDA FOMINA	{"phone": "+70505635697"}
0005433507352	8DB064	6759 958839	ELIZAVETA KOLESNIKOVA	{"phone": "+70589657870"}
0005433507353	98A2EB	0412 521326	ILYA FEDOROV	{"email": "fedorov.i.14051974@postgrespro.ru", "phone": "+70274579825"}
0005433507354	00BACA	1478 812613	OLEG SEMENOV	{"phone": "+70332495604"}
0005433507355	E6A149	4130 196397	TATYANA KOROLEVA	{"email": "korolevatatyana-05091971@postgrespro.ru", "phone": "+70601215761"}
0005433507356	E6A149	3443 149645	EGOR VASILEV	{"email": "vasilev-egor.06121972@postgrespro.ru", "phone": "+70582436817"}
0005433507357	313197	6819 460675	DMITRIY SERGEEV	{"email": "d_sergeev11091971@postgrespro.ru", "phone": "+70042279159"}
0005433507358	313197	4651 604984	NINA DANILOVA	{"email": "danilova.n_13041979@postgrespro.ru", "phone": "+70260509780"}
0005433507359	6740BF	1915 380311	BORIS ANDREEV	{"phone": "+70957821439"}
0005433507360	6740BF	6456 859255	VASILIY MATVEEV	{"phone": "+70636849517"}
0005433507361	424F71	2202 233292	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr-091976@postgrespro.ru", "phone": "+70265855668"}
0005433507362	2461A9	8202 485461	ALEKSANDR VLASOV	{"phone": "+70836065495"}
0005433507363	2461A9	6648 371977	IGOR ALEKSANDROV	{"email": "igor_aleksandrov-051976@postgrespro.ru", "phone": "+70155801471"}
0005433507364	2461A9	5344 796123	RUSLAN BORISOV	{"email": "ruslan.borisov_1972@postgrespro.ru", "phone": "+70135459249"}
0005433507365	29A0BB	1521 047624	YULIYA CHERNOVA	{"phone": "+70385289031"}
0005433507366	C992AF	1270 933310	OLEG NAUMOV	{"phone": "+70260814036"}
0005433507367	138363	6274 766342	EVGENIYA KUDRYASHOVA	{"phone": "+70643088169"}
0005433507368	138363	5730 786945	NATALYA ALEKSEEVA	{"email": "natalyaalekseeva_031969@postgrespro.ru", "phone": "+70507028074"}
0005433507369	138363	1247 377186	ALEKSANDR KUZNECOV	{"phone": "+70239346690"}
0005433507370	FA8D16	3431 868361	MARINA MAKAROVA	{"phone": "+70416023973"}
0005433507371	A03E69	7257 035005	ANNA TIMOFEEVA	{"email": "timofeeva_anna1981@postgrespro.ru", "phone": "+70406489527"}
0005433507372	A03E69	9577 533792	VALENTIN KUZNECOV	{"phone": "+70185456431"}
0005433507373	0B29B1	6631 342035	SERGEY SHEVCHENKO	{"phone": "+70189888696"}
0005433507374	258FD6	9684 848897	YANA FEDOROVA	{"phone": "+70171483987"}
0005433507375	B64E58	1788 668528	EKATERINA MIKHAYLOVA	{"phone": "+70794551054"}
0005433507376	B64E58	0165 292010	TATYANA ERMAKOVA	{"email": "t_ermakova.031967@postgrespro.ru", "phone": "+70621327975"}
0005433507377	ADC280	3177 234249	KONSTANTIN MAKAROV	{"phone": "+70986875221"}
0005433507378	ADC280	2162 869913	ALEKSANDR ABRAMOV	{"email": "a-abramov061968@postgrespro.ru", "phone": "+70844302392"}
0005433507379	F8B746	6845 003904	IRINA DENISOVA	{"phone": "+70145080475"}
0005433507380	4EFBCB	4259 452727	ANDREY GORBUNOV	{"phone": "+70751969948"}
0005433507381	6478A2	0513 978263	ALEKSANDR ISAEV	{"email": "isaev_aleksandr051967@postgrespro.ru", "phone": "+70622611631"}
0005433507382	6065CA	9473 322077	IRINA NOVIKOVA	{"phone": "+70590496613"}
0005433507383	25D988	8262 509339	NIKOLAY ZAYCEV	{"phone": "+70943535136"}
0005433507384	723F0A	8676 639120	GALINA GUSEVA	{"email": "galina-guseva08031967@postgrespro.ru", "phone": "+70040634120"}
0005433507385	9126A3	9520 263331	ANATOLIY MAKSIMOV	{"phone": "+70731938834"}
0005433507386	9126A3	1230 895755	ANDREY ALEKSANDROV	{"email": "aleksandrov_andrey01031984@postgrespro.ru", "phone": "+70780979936"}
0005433507387	AC86A1	0473 306231	LYUDMILA IVANOVA	{"phone": "+70653470451"}
0005433507388	32F03F	3911 711017	VYACHESLAV MAKSIMOV	{"phone": "+70065993800"}
0005433507389	B19100	3317 751644	MARIYA VOROBEVA	{"email": "vorobeva.mariya-081971@postgrespro.ru", "phone": "+70971070073"}
0005433507390	CD2139	2332 160192	YULIYA LAZAREVA	{"phone": "+70227299814"}
0005433507391	CD2139	4296 062325	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-1968@postgrespro.ru", "phone": "+70793978492"}
0005433507392	17B289	2391 401821	EVGENIYA KOMAROVA	{"email": "komarova.e.1982@postgrespro.ru", "phone": "+70673837037"}
0005433507393	A7524F	8107 945593	YURIY IVANOV	{"email": "yuriy.ivanov.1972@postgrespro.ru", "phone": "+70904683661"}
0005433507394	EDB9BB	8968 879197	VALERIY SIDOROV	{"phone": "+70640527615"}
0005433507395	6D5F3C	4680 771523	NIKOLAY POPOV	{"email": "nikolay_popov-03111961@postgrespro.ru", "phone": "+70927433939"}
0005433507396	5B3A80	5807 101450	ANASTASIYA SCHERBAKOVA	{"email": "scherbakovaanastasiya.1955@postgrespro.ru", "phone": "+70475073757"}
0005433507397	CE95D6	8199 005335	TATYANA KOVALEVA	{"phone": "+70736527355"}
0005433507398	DC566B	0746 207646	YURIY SOKOLOV	{"phone": "+70109928685"}
0005433507399	92AF8C	6985 746998	YURIY SOKOLOV	{"email": "sokolov_yuriy-1975@postgrespro.ru", "phone": "+70832727949"}
0005433507400	92AF8C	3431 253176	VIKTOR VOROBEV	{"phone": "+70260146368"}
0005433507401	755E03	1744 080651	EKATERINA KUZNECOVA	{"email": "ekaterina_kuznecova-16111974@postgrespro.ru", "phone": "+70410697972"}
0005433507402	72C8B4	9714 014943	DMITRIY MIRONOV	{"phone": "+70249172374"}
0005433507403	95CDB2	6627 799688	LYUDMILA NAZAROVA	{"phone": "+70541025187"}
0005433507404	95CDB2	2116 022791	VLADIMIR MAKSIMOV	{"phone": "+70214619174"}
0005433507405	95CDB2	9303 210779	IVAN NAUMOV	{"email": "inaumov-16061981@postgrespro.ru", "phone": "+70236537620"}
0005433507406	7786A7	3791 348247	ALINA KOLESNIKOVA	{"email": "kolesnikova_a1975@postgrespro.ru", "phone": "+70677544938"}
0005433507407	F44DDF	8284 904782	ALEKSEY MATVEEV	{"phone": "+70979482031"}
0005433507408	2DA957	4567 622648	MIKHAIL ORLOV	{"phone": "+70549134718"}
0005433507409	D0990C	2062 361575	ALEKSANDR STEPANOV	{"phone": "+70356748543"}
0005433507410	D0990C	8574 327106	VALENTINA PETROVA	{"email": "petrova.valentina.1975@postgrespro.ru", "phone": "+70497240686"}
0005433507411	2A522F	7066 943860	VALENTINA POPOVA	{"email": "popova_valentina-1986@postgrespro.ru", "phone": "+70743080793"}
0005433507412	2C7EB9	7071 465608	PAVEL MOROZOV	{"phone": "+70325474466"}
0005433507413	C73E0C	0092 366144	VITALIY MAKSIMOV	{"email": "v_maksimov-09061966@postgrespro.ru", "phone": "+70983019643"}
0005433507414	C73E0C	8900 660999	ALINA SERGEEVA	{"phone": "+70360853725"}
0005433507415	A88655	5813 322330	EVGENIY MIKHAYLOV	{"email": "evgeniy_mikhaylov-1972@postgrespro.ru", "phone": "+70235988946"}
0005433507416	CD9472	6704 621312	ALINA BELOVA	{"email": "a_belova1976@postgrespro.ru", "phone": "+70962645798"}
0005433507417	CD9472	4054 117882	ANDREY PAVLOV	{"phone": "+70537891681"}
0005433507418	859469	6337 764681	YULIYA ANTONOVA	{"phone": "+70228425566"}
0005433507419	27B616	7754 277626	TATYANA NIKOLAEVA	{"phone": "+70016415143"}
0005433507420	27B616	4005 055493	LILIYA MIRONOVA	{"phone": "+70232334436"}
0005433507421	DEEF6F	1386 964241	TATYANA KONOVALOVA	{"phone": "+70155687645"}
0005433507422	DEEF6F	9708 585068	VLADIMIR ILIN	{"email": "ilin.v_1967@postgrespro.ru", "phone": "+70807813131"}
0005433507423	34B1BB	1168 527458	MILANA IVANOVA	{"email": "m_ivanova-01111954@postgrespro.ru", "phone": "+70214676347"}
0005433507424	096489	7494 341737	NADEZHDA IVANOVA	{"email": "ivanova_n13121974@postgrespro.ru", "phone": "+70372417702"}
0005433507425	B5AA21	0852 570281	VARVARA NOVIKOVA	{"phone": "+70452690696"}
0005433507426	B5AA21	8938 174493	NINA ROMANOVA	{"email": "nromanova-021969@postgrespro.ru", "phone": "+70138978421"}
0005433507427	468DB3	9556 839757	KONSTANTIN DAVYDOV	{"phone": "+70359277899"}
0005433507428	468DB3	9245 533738	IRINA PAVLOVA	{"email": "ipavlova071981@postgrespro.ru", "phone": "+70051463484"}
0005433507429	A92450	4023 057214	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova.26031970@postgrespro.ru", "phone": "+70278039729"}
0005433507430	8BC2F4	4574 207942	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov16111986@postgrespro.ru", "phone": "+70362167355"}
0005433507431	8BC2F4	9425 019353	OLEG ALEKSANDROV	{"phone": "+70715896561"}
0005433507432	5F4739	2906 018008	ELENA POPOVA	{"phone": "+70808253764"}
0005433507433	348E8D	7835 135622	ALLA NAZAROVA	{"phone": "+70929612847"}
0005433507434	579827	0725 839300	SERGEY MARTYNOV	{"email": "martynov_sergey.041971@postgrespro.ru", "phone": "+70859488864"}
0005433507435	1F28FE	1026 338851	YURIY NAUMOV	{"phone": "+70815889241"}
0005433507436	0A4943	1851 609008	ALEKSANDR ZHUKOV	{"phone": "+70761750306"}
0005433507437	11DCA0	7895 963074	NADEZHDA CHERNOVA	{"phone": "+70237998291"}
0005433507438	11DCA0	4769 985870	SEMEN ANTONOV	{"phone": "+70865723567"}
0005433507439	11DCA0	4837 065552	DMITRIY GORBUNOV	{"phone": "+70595916663"}
0005433507440	E0D79B	5701 754454	IGOR NIKITIN	{"phone": "+70751151508"}
0005433507441	72892A	8602 615862	VLADIMIR GORBUNOV	{"phone": "+70136680221"}
0005433507442	D6EC3F	2377 520089	YAROSLAV STEPANOV	{"phone": "+70036659316"}
0005433507443	2BEC64	7172 281326	VALENTINA SOKOLOVA	{"email": "sokolova-v041969@postgrespro.ru", "phone": "+70714871884"}
0005433507444	2BEC64	6572 440147	GALINA ALEKSEEVA	{"email": "galekseeva.091978@postgrespro.ru", "phone": "+70686957970"}
0005433507445	22B8B5	5230 592377	ALEKSANDRA NIKIFOROVA	{"email": "nikiforova_aleksandra.07081966@postgrespro.ru", "phone": "+70879766642"}
0005433507446	3F3E5E	3014 853518	GENNADIY NIKITIN	{"phone": "+70199062316"}
0005433507447	BBAE6F	0065 092388	VIKTOR MOROZOV	{"phone": "+70816566089"}
0005433507448	FE2346	1608 552247	TAMARA IVANOVA	{"phone": "+70568697179"}
0005433507449	FE2346	5246 658753	PAVEL BELOV	{"phone": "+70506320310"}
0005433507450	97A1A3	4056 334104	IRINA KOROLEVA	{"email": "koroleva.irina_101971@postgrespro.ru", "phone": "+70365985599"}
0005433507451	7981D1	5742 149466	NATALYA KAZAKOVA	{"email": "kazakova-n_1971@postgrespro.ru", "phone": "+70501702140"}
0005433507452	6A584C	8530 435845	SERGEY KONOVALOV	{"phone": "+70031835184"}
0005433507453	6A584C	5721 639953	MARTA BORISOVA	{"phone": "+70596343754"}
0005433507454	0EFAFB	9418 139146	ANDREY GORBUNOV	{"email": "gorbunov-a07061967@postgrespro.ru", "phone": "+70055962670"}
0005433507455	BA6242	7917 611600	SERGEY TARASOV	{"phone": "+70191901817"}
0005433507456	5A946F	9835 849499	EDUARD VASILEV	{"email": "eduard.vasilev-1976@postgrespro.ru", "phone": "+70250603510"}
0005433507457	169C49	3357 902965	DANIIL TARASOV	{"phone": "+70220929865"}
0005433507458	EBCB7F	9170 146539	ANNA KUZMINA	{"phone": "+70310120101"}
0005433507460	CB7CFF	5595 423681	ALEKSANDR MELNIKOV	{"phone": "+70081332076"}
0005433507461	932437	6685 770718	GALINA SERGEEVA	{"email": "sergeeva-g_031970@postgrespro.ru", "phone": "+70859330449"}
0005433507462	A01A00	0110 225097	ELENA SERGEEVA	{"phone": "+70520721069"}
0005433507463	856229	8809 293187	ALSU MOROZOVA	{"phone": "+70155297005"}
0005433507464	91E01E	4478 638025	VIKTORIYA POPOVA	{"phone": "+70159585072"}
0005433507465	A321F0	3218 180699	BULAT GAVRILOV	{"email": "gavrilov_bulat1978@postgrespro.ru", "phone": "+70165358035"}
0005433507466	B1D3FA	0185 448690	SVETLANA VASILEVA	{"email": "svetlana.vasileva.021971@postgrespro.ru", "phone": "+70372291617"}
0005433507467	2B970C	6528 184486	VLADIMIR BONDARENKO	{"phone": "+70869375515"}
0005433507468	2B970C	4939 697597	YURIY POPOV	{"email": "yuriy.popov_1955@postgrespro.ru", "phone": "+70472983494"}
0005433507469	EDCB75	8433 002511	NATALYA IVANOVA	{"phone": "+70069264206"}
0005433507470	50028E	3696 779067	VIKTOR POPOV	{"phone": "+70484342849"}
0005433507471	7EDC2F	7753 690757	NIKOLAY STEPANOV	{"email": "stepanov.nikolay-091974@postgrespro.ru", "phone": "+70649984384"}
0005433507472	3B485F	5137 073421	ELEONORA IVANOVA	{"phone": "+70170107482"}
0005433507473	60CF8D	6456 027774	ELENA TARASOVA	{"email": "elena-tarasova_20021977@postgrespro.ru", "phone": "+70031702221"}
0005433507474	60CF8D	3071 456965	SOFIYA FOMINA	{"email": "fomina_s.121972@postgrespro.ru", "phone": "+70404999340"}
0005433507475	EFBBE9	8103 305431	VERA MIKHAYLOVA	{"email": "v_mikhaylova-1963@postgrespro.ru", "phone": "+70653299862"}
0005433507476	7BF05A	6163 539646	VLADIMIR BONDARENKO	{"email": "bondarenko_v1973@postgrespro.ru", "phone": "+70231398680"}
0005433507477	CAD73D	3027 871825	TAISIYA IVANOVA	{"email": "t.ivanova-011969@postgrespro.ru", "phone": "+70067455464"}
0005433507478	CAD73D	9558 823877	ANTONINA NIKOLAEVA	{"email": "nikolaeva_a-21081972@postgrespro.ru", "phone": "+70204554743"}
0005433507479	93687B	5501 578136	ELENA SEMENOVA	{"phone": "+70279771197"}
0005433507480	90C0CA	0050 506576	DARYA POPOVA	{"email": "d_popova-1974@postgrespro.ru", "phone": "+70415857010"}
0005433507481	90C0CA	8311 418940	ALLA POTAPOVA	{"email": "potapova-alla-061972@postgrespro.ru", "phone": "+70115903777"}
0005433507482	5D0B9D	6278 443378	ALEKSEY SOLOVEV	{"phone": "+70431271266"}
0005433507483	5D0B9D	3711 381574	SVETLANA LOGINOVA	{"phone": "+70889598960"}
0005433507484	F9C513	6111 635513	IGOR POPOV	{"email": "i_popov-16061965@postgrespro.ru", "phone": "+70159502188"}
0005433507485	F9C513	6734 690018	ANNA KOZLOVA	{"email": "kozlova-a_051982@postgrespro.ru", "phone": "+70735823482"}
0005433507486	1CEC31	7606 359123	KSENIYA ZAKHAROVA	{"phone": "+70961478033"}
0005433507487	2B2E87	0095 861100	IGOR MELNIKOV	{"email": "melnikov_i_15101966@postgrespro.ru", "phone": "+70073481762"}
0005433507488	478735	4354 692938	ELENA MOROZOVA	{"email": "morozova.elena_25021977@postgrespro.ru", "phone": "+70614513007"}
0005433507489	ACF6CE	4264 686761	OKSANA EFIMOVA	{"phone": "+70673129125"}
0005433507490	BCB182	8063 440797	VASILIY ZAKHAROV	{"phone": "+70297874036"}
0005433507491	BCB182	4032 556120	TATYANA SMIRNOVA	{"phone": "+70772488211"}
0005433507492	EA8DF5	7149 547103	GALINA KULIKOVA	{"phone": "+70123055623"}
0005433507493	23A0B3	4413 389570	RUSLAN POPOV	{"phone": "+70338064211"}
0005433507494	470CDF	9584 447094	NIKOLAY ALEKSEEV	{"email": "alekseev_n_1972@postgrespro.ru", "phone": "+70289484835"}
0005433507495	470CDF	2505 946287	SVETLANA TIMOFEEVA	{"phone": "+70050353941"}
0005433507496	BC4E05	8079 634519	ANDREY SMIRNOV	{"email": "smirnov-andrey_071980@postgrespro.ru", "phone": "+70900101149"}
0005433507497	BC4E05	6686 232368	VALENTINA KOZLOVA	{"phone": "+70773850834"}
0005433507498	2A227B	8196 184483	TAMARA KARPOVA	{"email": "t-karpova_27041970@postgrespro.ru", "phone": "+70512328863"}
0005433507499	2A227B	4718 320025	RINAT NIKOLAEV	{"email": "nikolaev.rinat-03091972@postgrespro.ru", "phone": "+70532742581"}
0005433507500	EBA89B	5070 269495	VIKTOR ANDREEV	{"phone": "+70764869831"}
0005433507501	206ECF	6167 326178	DARYA NAUMOVA	{"email": "naumova.darya-15061988@postgrespro.ru", "phone": "+70005327468"}
0005433507502	206ECF	4662 063911	OKSANA VASILEVA	{"email": "vasilevaoksana-1980@postgrespro.ru", "phone": "+70125494937"}
0005433507503	BC4041	1596 284258	GALINA EGOROVA	{"phone": "+70692584035"}
0005433507504	BC4041	8375 538944	MARIYA SOKOLOVA	{"phone": "+70666180566"}
0005433507505	320AAF	9120 736784	IVAN GERASIMOV	{"phone": "+70639620949"}
0005433507506	AA7304	1336 139618	TATYANA VASILEVA	{"phone": "+70976815760"}
0005433507507	8DA911	2304 582628	SVETLANA ROMANOVA	{"phone": "+70835581550"}
0005433507508	20BC5C	1713 004477	MARINA KOROLEVA	{"email": "koroleva.m02051974@postgrespro.ru", "phone": "+70776575028"}
0005433507509	1703DF	6457 594493	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy_1974@postgrespro.ru", "phone": "+70907543548"}
0005433507510	1703DF	5210 025282	DMITRIY MAKAROV	{"phone": "+70853711738"}
0005433507511	1703DF	8195 147823	MARGARITA TITOVA	{"phone": "+70260326585"}
0005433507512	C2AE25	4702 085406	YULIYA MIKHAYLOVA	{"email": "mikhaylova-yuliya.1982@postgrespro.ru", "phone": "+70915942631"}
0005433507513	041EA6	0915 254024	NIKOLAY POPOV	{"email": "n_popov_13031972@postgrespro.ru", "phone": "+70999782121"}
0005433507514	06BC47	0143 400819	LYUBOV POPOVA	{"email": "popoval-021964@postgrespro.ru", "phone": "+70658369708"}
0005433507515	1A5E28	7933 520077	RAISA BELOVA	{"email": "belova-r1965@postgrespro.ru", "phone": "+70432883324"}
0005433507516	5D409F	9118 288713	SOFIYA OVCHINNIKOVA	{"email": "ovchinnikovas_24081967@postgrespro.ru", "phone": "+70277188322"}
0005433507517	5D409F	4500 745756	NAILYA GRISHINA	{"phone": "+70954778811"}
0005433507518	6D018E	2314 831616	TATYANA BOGDANOVA	{"email": "bogdanova.tatyana13071972@postgrespro.ru", "phone": "+70753137952"}
0005433507519	6D018E	4945 828868	ALEKSEY NAZAROV	{"email": "nazarov_aleksey111967@postgrespro.ru", "phone": "+70661167952"}
0005433507520	AD1560	7199 280283	YURIY STEPANOV	{"email": "stepanov_yuriy.27031963@postgrespro.ru", "phone": "+70253555305"}
0005433507521	AD1560	4657 883357	ANGELINA ANTONOVA	{"email": "antonova_angelina-081965@postgrespro.ru", "phone": "+70758916934"}
0005433507522	AD1560	4275 562310	TATYANA NAUMOVA	{"phone": "+70377190642"}
0005433507523	71D0F4	5375 344714	ELVIRA FILIPPOVA	{"email": "filippovaelvira-1960@postgrespro.ru", "phone": "+70845385842"}
0005433507524	71D0F4	1578 096060	RAFAIL ABRAMOV	{"phone": "+70073594074"}
0005433507525	641284	4867 702017	VALENTINA KALININA	{"email": "valentinakalinina_11021974@postgrespro.ru", "phone": "+70371428307"}
0005433507526	80CDB7	5879 271478	MARIYA ZAYCEVA	{"phone": "+70001261937"}
0005433507527	B821BB	7590 609989	VLADIMIR TARASOV	{"email": "tarasov_vladimir_1959@postgrespro.ru", "phone": "+70468035630"}
0005433507528	E9CECE	2061 386185	DMITRIY FEDOROV	{"email": "fedorovd-1979@postgrespro.ru", "phone": "+70807490466"}
0005433507529	E9CECE	4068 370075	EVGENIYA SOKOLOVA	{"email": "sokolovae_1964@postgrespro.ru", "phone": "+70616551165"}
0005433507530	D50217	0440 573501	GENNADIY MAKSIMOV	{"email": "g-maksimov-041969@postgrespro.ru", "phone": "+70360319692"}
0005433507531	D50217	1174 284185	LYUDMILA DMITRIEVA	{"email": "lyudmiladmitrieva.101974@postgrespro.ru", "phone": "+70871523904"}
0005433507532	5A7459	3478 913529	ALEKSANDR KULIKOV	{"email": "aleksandr_kulikov.28051974@postgrespro.ru", "phone": "+70863169393"}
0005433507533	282CB5	1660 385423	VIKTOR NAUMOV	{"email": "viktor.naumov_021979@postgrespro.ru", "phone": "+70263882932"}
0005433507534	04ACA1	5059 984553	POLINA MARTYNOVA	{"email": "polinamartynova.051976@postgrespro.ru", "phone": "+70630141251"}
0005433507535	89659A	3288 560853	TATYANA KUZNECOVA	{"email": "t_kuznecova-021962@postgrespro.ru", "phone": "+70392427021"}
0005433507536	711729	8151 226092	IGOR FEDOROV	{"email": "fedorov.igor-1968@postgrespro.ru", "phone": "+70319499404"}
0005433507537	C8DBFC	1708 103794	ALEKSANDR SIDOROV	{"email": "a-sidorov_26111972@postgrespro.ru", "phone": "+70813607921"}
0005433507538	C8DBFC	4128 018478	FEDOR BELOV	{"phone": "+70203966174"}
0005433507539	254FAC	9628 794917	GALINA ILINA	{"email": "g_ilina-1977@postgrespro.ru", "phone": "+70239622815"}
0005433507540	D7F1EA	9629 281485	VIKTORIYA NIKOLAEVA	{"email": "v_nikolaeva1980@postgrespro.ru", "phone": "+70707166144"}
0005433507541	B815D0	9585 177981	ILDAR IVANOV	{"phone": "+70212773344"}
0005433507542	B815D0	6501 163243	YULIYA ILINA	{"phone": "+70357362018"}
0005433507543	5B3CE6	3906 706403	ANTON NOVIKOV	{"phone": "+70203554639"}
0005433507544	5B3CE6	8660 565744	VALENTINA ROMANOVA	{"phone": "+70497160028"}
0005433507545	7926A2	3718 871224	SERGEY FROLOV	{"phone": "+70221792558"}
0005433507546	51D91B	7562 411367	ANNA KULIKOVA	{"phone": "+70027300471"}
0005433507547	D4D41F	6460 463555	KONSTANTIN KUZNECOV	{"email": "konstantinkuznecov.091966@postgrespro.ru", "phone": "+70596367383"}
0005433507548	B7AD9D	3525 804569	MIKHAIL BONDARENKO	{"email": "m.bondarenko111976@postgrespro.ru", "phone": "+70332637155"}
0005433507549	F647A2	2166 985208	OLGA ZAYCEVA	{"phone": "+70334640259"}
0005433507550	008612	4982 721100	SERGEY KONOVALOV	{"phone": "+70729500818"}
0005433507551	77EEAE	6868 980227	ALEKSANDR MAKAROV	{"phone": "+70457187169"}
0005433507552	76698F	6571 195522	ARTEM SMIRNOV	{"phone": "+70264615480"}
0005433507553	76698F	2559 614929	ALEKSEY STEPANOV	{"email": "stepanovaleksey-1976@postgrespro.ru", "phone": "+70551027432"}
0005433507554	70280C	4161 420430	SOFYA DANILOVA	{"phone": "+70537484690"}
0005433507555	1A10A6	9682 682069	MAKSIM MAKAROV	{"email": "mmakarov.1973@postgrespro.ru", "phone": "+70429200801"}
0005433507556	849EE9	2838 923241	ALEKSANDRA ABRAMOVA	{"email": "aabramova.031982@postgrespro.ru", "phone": "+70846810504"}
0005433507557	849EE9	7280 885079	TATYANA SEMENOVA	{"phone": "+70913683846"}
0005433507558	412756	7109 109567	VLADIMIR NAZAROV	{"email": "nazarovvladimir.071982@postgrespro.ru", "phone": "+70778089893"}
0005433507559	A9155F	7867 072368	ALEKSANDR VASILEV	{"phone": "+70269750170"}
0005433507616	D15275	0125 342043	VLADIMIR FEDOROV	{"phone": "+70458865160"}
0005433507560	02790D	9566 787468	ANASTASIYA GRISHINA	{"email": "grishinaanastasiya-25091976@postgrespro.ru", "phone": "+70339978604"}
0005433507561	02790D	9608 584545	KSENIYA NIKIFOROVA	{"phone": "+70749956209"}
0005433507562	E299DA	7318 196342	OLGA NAZAROVA	{"email": "nazarova_o1971@postgrespro.ru", "phone": "+70136046739"}
0005433507563	B8AD85	1228 067271	SVETLANA KUZNECOVA	{"phone": "+70037655014"}
0005433507564	D52E79	7917 987714	YULIYA KUZNECOVA	{"email": "yuliya_kuznecova_1979@postgrespro.ru", "phone": "+70467108265"}
0005433507565	E98EEB	8545 105399	ELENA MARTYNOVA	{"phone": "+70077166719"}
0005433507566	C2B67E	2308 788595	ELENA BARANOVA	{"phone": "+70690416379"}
0005433507567	C2B67E	9572 014540	TATYANA SOLOVEVA	{"email": "tatyana-soloveva-1981@postgrespro.ru", "phone": "+70973831127"}
0005433507568	8DE58F	3400 822254	OKSANA BARANOVA	{"email": "baranova-o-1975@postgrespro.ru", "phone": "+70620364722"}
0005433507569	8DE58F	3383 754257	EVGENIY KUZNECOV	{"phone": "+70795268738"}
0005433507570	CB4865	4483 817684	LIDIYA SAVELEVA	{"email": "saveleva-l30041975@postgrespro.ru", "phone": "+70616995775"}
0005433507571	899899	2778 658638	ALEKSANDR KRASNOV	{"email": "krasnov.a081973@postgrespro.ru", "phone": "+70093544973"}
0005433507572	899899	7135 329929	DANIIL NAUMOV	{"email": "naumovd-04061975@postgrespro.ru", "phone": "+70887211725"}
0005433507573	EFD2D0	8409 098675	ILDAR CHERNOV	{"phone": "+70821446022"}
0005433507574	9FA7E4	5992 000991	KSENIYA PETROVA	{"email": "petrova.kseniya_25021962@postgrespro.ru", "phone": "+70461565379"}
0005433507575	04A726	1508 682515	EKATERINA SOKOLOVA	{"email": "ekaterina_sokolova30051979@postgrespro.ru", "phone": "+70177631769"}
0005433507576	A2C1E8	5640 436387	RISHAT OSIPOV	{"phone": "+70834838540"}
0005433507577	0B5255	3523 775135	NATALYA KONOVALOVA	{"phone": "+70573312472"}
0005433507578	9AB9F3	2162 733981	IVAN ANDREEV	{"email": "i_andreev_1965@postgrespro.ru", "phone": "+70133638421"}
0005433507579	AE2732	0489 367230	DANIIL VOROBEV	{"email": "vorobev_daniil16041968@postgrespro.ru", "phone": "+70994713163"}
0005433507580	4FF77E	5964 724490	ANATOLIY GRIGOREV	{"phone": "+70505332254"}
0005433507581	159A12	4303 381106	SERGEY MARTYNOV	{"phone": "+70434709293"}
0005433507582	159A12	4588 923620	SVETLANA MOROZOVA	{"email": "s.morozova-1969@postgrespro.ru", "phone": "+70090993534"}
0005433507583	494ECE	2979 832729	ALEKSANDR VLASOV	{"phone": "+70896863162"}
0005433507584	069374	0256 630138	VALENTINA SERGEEVA	{"email": "valentina_sergeeva_1968@postgrespro.ru", "phone": "+70584149880"}
0005433507585	7E28D1	6571 075073	SVETLANA SCHERBAKOVA	{"phone": "+70440661226"}
0005433507586	1B129F	7574 483481	POLINA FROLOVA	{"phone": "+70855607491"}
0005433507587	7A1E61	2092 173424	VLADIMIR MAKAROV	{"phone": "+70480980187"}
0005433507588	780639	9975 880378	VALENTINA ISAEVA	{"phone": "+70797016845"}
0005433507589	821FAE	9877 074669	EVGENIY YAKOVLEV	{"email": "e-yakovlev1977@postgrespro.ru", "phone": "+70313806114"}
0005433507590	3663B0	5044 795229	POLINA ZHUKOVA	{"email": "p-zhukova_1972@postgrespro.ru", "phone": "+70788001397"}
0005433507591	3663B0	9431 165719	IGOR SERGEEV	{"email": "sergeev-i_1975@postgrespro.ru", "phone": "+70176404877"}
0005433507592	58B0E5	7659 320141	STANISLAV IVANOV	{"phone": "+70818858846"}
0005433507593	BD6A08	9127 490914	ANNA VASILEVA	{"email": "annavasileva1988@postgrespro.ru", "phone": "+70742635116"}
0005433507594	BD6A08	9274 692974	DENIS ZHUKOV	{"email": "zhukovd05121971@postgrespro.ru", "phone": "+70149098722"}
0005433507595	68B14E	0744 329944	NATALYA ZAYCEVA	{"email": "n-zayceva081966@postgrespro.ru", "phone": "+70747189204"}
0005433507596	D1C151	0960 670389	ALEKSANDR OSIPOV	{"email": "aleksandr.osipov-011981@postgrespro.ru", "phone": "+70668738262"}
0005433507597	D1C151	8873 637259	SERGEY ISAEV	{"email": "isaev_s.29111955@postgrespro.ru", "phone": "+70566029631"}
0005433507598	A527DE	0787 119825	GALINA TIKHONOVA	{"phone": "+70357183702"}
0005433507599	E97AA5	7860 287223	VLADIMIR KUZNECOV	{"phone": "+70117560843"}
0005433507600	A724E7	9504 295218	IGOR KONOVALOV	{"email": "i.konovalov031981@postgrespro.ru", "phone": "+70338120427"}
0005433507601	A724E7	9805 934812	VENIAMIN DENISOV	{"phone": "+70176744022"}
0005433507602	D063E8	5154 482344	SVETLANA FOMINA	{"email": "s.fomina.1968@postgrespro.ru", "phone": "+70520817629"}
0005433507603	D063E8	4816 621020	ANDREY ISAEV	{"email": "a-isaev.19061972@postgrespro.ru", "phone": "+70765180615"}
0005433507604	01164E	7119 197446	NIKOLAY PETROV	{"phone": "+70984155067"}
0005433507605	01164E	2967 991175	NINA VOLKOVA	{"email": "volkovanina-041973@postgrespro.ru", "phone": "+70502207537"}
0005433507606	CF9CE9	0453 682186	ANTON FROLOV	{"email": "frolov-anton.03091980@postgrespro.ru", "phone": "+70102914803"}
0005433507607	98494D	3316 993805	SERGEY FILIPPOV	{"phone": "+70151518169"}
0005433507608	0F8FDE	7551 464631	OLGA SERGEEVA	{"phone": "+70174587702"}
0005433507609	0F8FDE	2393 568599	ZOYA SMIRNOVA	{"phone": "+70099626299"}
0005433507610	A3EBBC	9813 280631	ILDAR NIKOLAEV	{"email": "nikolaev-ildar121970@postgrespro.ru", "phone": "+70640457350"}
0005433507611	2DBB32	4405 931974	OLEG TIKHONOV	{"email": "tikhonov.o17021974@postgrespro.ru", "phone": "+70960795285"}
0005433507612	97D3FE	5481 378096	ALEKSANDR ZAYCEV	{"email": "zaycev_aleksandr.03071979@postgrespro.ru", "phone": "+70080759671"}
0005433507613	FAF955	1248 395005	KSENIYA POLYAKOVA	{"phone": "+70424976513"}
0005433507614	270B35	1280 752375	VLADIMIR ISAEV	{"phone": "+70226014577"}
0005433507615	F4FBC3	1789 679547	ANTONINA NAZAROVA	{"phone": "+70906440185"}
0005433507617	A8C979	0099 605379	NADEZHDA ALEKSANDROVA	{"email": "n_aleksandrova_26091978@postgrespro.ru", "phone": "+70915720236"}
0005433507618	A8C979	9088 997074	GALINA KUZMINA	{"phone": "+70032600830"}
0005433507619	741844	8230 743839	EVGENIY EGOROV	{"email": "evgeniy-egorov_17081970@postgrespro.ru", "phone": "+70428117484"}
0005433507620	1ED1E5	2493 779865	DMITRIY VOROBEV	{"email": "dmitriy-vorobev-13071972@postgrespro.ru", "phone": "+70512460676"}
0005433507621	1A4B24	2227 006379	MATVEY CHERNOV	{"phone": "+70758861695"}
0005433507622	1A4B24	9432 386237	ELMIRA ROMANOVA	{"email": "elmira.romanova-1966@postgrespro.ru", "phone": "+70602868936"}
0005433507623	0EC87E	1612 877262	LYUBOV KUZNECOVA	{"phone": "+70872400165"}
0005433507624	0EC87E	8871 477011	VALENTINA MEDVEDEVA	{"email": "medvedevavalentina.1966@postgrespro.ru", "phone": "+70194161758"}
0005433507625	AAEAA9	1455 698411	LARISA KOZLOVA	{"email": "kozloval1963@postgrespro.ru", "phone": "+70753503380"}
0005433507626	AAEAA9	9948 265521	TATYANA ZAYCEVA	{"email": "zayceva.t.1980@postgrespro.ru", "phone": "+70371492771"}
0005433507627	6CE0A8	2509 455946	MIKHAIL POPOV	{"email": "m-popov_04011978@postgrespro.ru", "phone": "+70312020505"}
0005433507628	AB0546	4889 863612	VALENTINA FOMINA	{"phone": "+70861402421"}
0005433507629	DEE061	5100 481199	VALERIY VASILEV	{"email": "v_vasilev_1975@postgrespro.ru", "phone": "+70965071570"}
0005433507630	E6EA43	3780 913615	NATALYA SOLOVEVA	{"phone": "+70426818451"}
0005433507631	E6EA43	9015 112994	ALEKSEY DMITRIEV	{"email": "aleksey.dmitriev.14121969@postgrespro.ru", "phone": "+70606909440"}
0005433507632	FBB637	3416 108551	VERA VASILEVA	{"email": "vasileva-v1984@postgrespro.ru", "phone": "+70028232522"}
0005433507633	7AE0FC	1609 771701	GALINA OSIPOVA	{"email": "osipova_galina.20091963@postgrespro.ru", "phone": "+70872298661"}
0005433507634	580B41	6317 885802	VALERIY PAVLOV	{"email": "pavlov.v_1971@postgrespro.ru", "phone": "+70543945364"}
0005433507635	580B41	2231 516019	NATALYA SOKOLOVA	{"email": "nsokolova_23021970@postgrespro.ru", "phone": "+70641283201"}
0005433507636	69615E	4214 872754	YULIYA KUZNECOVA	{"phone": "+70836416995"}
0005433507637	E74F76	1436 061106	ALISHER KULIKOV	{"email": "kulikov.a021969@postgrespro.ru", "phone": "+70756431860"}
0005433507638	A97EF6	4116 066678	ALEKSANDR TIKHONOV	{"email": "tikhonova24011969@postgrespro.ru", "phone": "+70736670197"}
0005433507639	240BF3	2856 590054	MARIYA MIKHAYLOVA	{"phone": "+70443424716"}
0005433507640	240BF3	1167 135249	VERA GERASIMOVA	{"email": "vgerasimova15031962@postgrespro.ru", "phone": "+70342828266"}
0005433507641	846512	6605 746027	DMITRIY FEDOTOV	{"phone": "+70615082682"}
0005433507642	4B02A2	1168 956469	MARIYA VOLKOVA	{"phone": "+70843128254"}
0005433507643	2E2B93	3010 969631	EVGENIY DENISOV	{"email": "denisov-evgeniy.1975@postgrespro.ru", "phone": "+70099933633"}
0005433507644	2E2B93	6274 526572	VLADIMIR DENISOV	{"email": "denisov-v_25021983@postgrespro.ru", "phone": "+70080911281"}
0005433507645	88CF17	4738 356131	YURIY CHERNOV	{"email": "chernov_yuriy081975@postgrespro.ru", "phone": "+70055775385"}
0005433507646	E7B6BF	4445 418382	ELENA KOROLEVA	{"email": "koroleva-elena.12031972@postgrespro.ru", "phone": "+70799952420"}
0005433507647	E7B6BF	7738 254696	OLGA LAZAREVA	{"email": "lazareva.o_24031964@postgrespro.ru", "phone": "+70788937026"}
0005433507648	770AB0	5719 392736	SERGEY ROMANOV	{"email": "romanov.sergey-011972@postgrespro.ru", "phone": "+70946562922"}
0005433507649	1DA915	5940 182684	LYUDMILA FOMINA	{"phone": "+70933177976"}
0005433507650	1DA915	3996 638501	ANTONINA BELOVA	{"phone": "+70068098931"}
0005433507651	1DA915	2917 489304	IRINA KALININA	{"email": "kalinina-irina_1974@postgrespro.ru", "phone": "+70283020609"}
0005433507652	04EC2C	1844 203195	PETR IVANOV	{"email": "ivanovpetr081975@postgrespro.ru", "phone": "+70665425777"}
0005433507653	8052CF	5356 522780	SERGEY MOISEEV	{"email": "moiseev.s-1974@postgrespro.ru", "phone": "+70871145896"}
0005433507654	00AEE8	0858 644368	ALEKSANDR ORLOV	{"phone": "+70045246772"}
0005433507655	00AEE8	9152 024847	VALENTINA BELYAEVA	{"email": "belyaeva.valentina.031975@postgrespro.ru", "phone": "+70973125638"}
0005433507656	F18108	9505 085515	LIDIYA KALININA	{"phone": "+70991579650"}
0005433507657	F18108	7511 239323	ARTEM NAUMOV	{"phone": "+70144635386"}
0005433507658	E355B4	1789 652085	DARYA NESTEROVA	{"email": "darya.nesterova.1964@postgrespro.ru", "phone": "+70029579249"}
0005433507659	14A4FC	6655 323227	FARIDA MIRONOVA	{"email": "farida_mironova_1979@postgrespro.ru", "phone": "+70474909914"}
0005433507660	9EEC54	6973 227393	DANIIL ANDREEV	{"phone": "+70041334487"}
0005433507661	DE3712	1962 872782	ALEKSEY MATVEEV	{"email": "matveev.aleksey-16081969@postgrespro.ru", "phone": "+70379894095"}
0005433507662	2330EF	3634 869231	ALEKSANDR KONOVALOV	{"email": "konovalov_aleksandr_1978@postgrespro.ru", "phone": "+70128357552"}
0005433507663	8D1960	5692 138536	DMITRIY ROMANOV	{"email": "d.romanov1980@postgrespro.ru", "phone": "+70940154651"}
0005433507664	57995D	2790 783750	LILIYA TIKHONOVA	{"email": "tikhonova-liliya.021975@postgrespro.ru", "phone": "+70894858684"}
0005433507665	57995D	3225 160571	ANTONINA MEDVEDEVA	{"phone": "+70331027437"}
0005433507666	C1EF8A	3947 859255	OKSANA ISAEVA	{"phone": "+70443084761"}
0005433507667	C1EF8A	4761 449308	SERGEY IVANOV	{"email": "sivanov-15081965@postgrespro.ru", "phone": "+70881286327"}
0005433507668	BA9E3A	8289 664357	ANDREY YAKOVLEV	{"phone": "+70497391716"}
0005433507669	BA9E3A	2399 095265	VIKTOR DAVYDOV	{"email": "davydov-v-19081962@postgrespro.ru", "phone": "+70114921480"}
0005433507670	C05FCC	4628 910460	MARINA VASILEVA	{"email": "marinavasileva_081975@postgrespro.ru", "phone": "+70483053335"}
0005433507671	718A17	4706 953329	LYUDMILA IVANOVA	{"phone": "+70716627888"}
0005433507672	718A17	5668 858643	IRINA KUZNECOVA	{"phone": "+70631554550"}
0005433507673	2EAD12	9973 065379	ALEKSANDR KONOVALOV	{"email": "konovalov.aleksandr07061968@postgrespro.ru", "phone": "+70601079952"}
0005433507674	2EAD12	1635 945474	GENNADIY VASILEV	{"email": "g-vasilev-27121973@postgrespro.ru", "phone": "+70610712650"}
0005433507675	2EAD12	1420 037771	NIKITA TIMOFEEV	{"email": "timofeev.nikita_111978@postgrespro.ru", "phone": "+70048017905"}
0005433507676	792138	2511 944137	ANDREY MATVEEV	{"email": "matveev-andrey21061969@postgrespro.ru", "phone": "+70781801752"}
0005433507677	501331	9976 176662	ALEKSANDR IVANOV	{"email": "ivanov-a_17071971@postgrespro.ru", "phone": "+70300515291"}
0005433507678	A92DC7	5881 263694	SERGEY STEPANOV	{"email": "sergey.stepanov-28041967@postgrespro.ru", "phone": "+70130850981"}
0005433507679	3E4A8E	2342 979707	NATALYA NESTEROVA	{"email": "natalyanesterova-08051965@postgrespro.ru", "phone": "+70981161792"}
0005433507680	AAE205	9901 873086	OLEG POPOV	{"email": "olegpopov10121972@postgrespro.ru", "phone": "+70284700961"}
0005433507681	A8A9F5	2903 611364	OLGA NESTEROVA	{"phone": "+70378064532"}
0005433507682	72536D	8212 057944	ANDREY NIKOLAEV	{"phone": "+70419378325"}
0005433507683	47CD6F	7395 173263	ALEKSEY KISELEV	{"email": "akiselev-1977@postgrespro.ru", "phone": "+70477926766"}
0005433507684	47CD6F	1768 031881	ALEKSEY VASILEV	{"email": "vasilev-aleksey121969@postgrespro.ru", "phone": "+70392764579"}
0005433507685	3E5EA7	4348 844807	EVDOKIYA ALEKSANDROVA	{"phone": "+70988052099"}
0005433507686	3E5EA7	1696 397614	VIKTORIYA OSIPOVA	{"email": "viktoriya_osipova_1962@postgrespro.ru", "phone": "+70558164733"}
0005433507687	B276B3	8997 915028	RAISA POTAPOVA	{"phone": "+70720462301"}
0005433507688	ADF8B9	2582 033126	NATALYA BORISOVA	{"phone": "+70212933345"}
0005433507689	08FF9D	1725 259393	VITALIY CHERNOV	{"phone": "+70197317569"}
0005433507690	C1A18D	4324 519125	IVAN ABRAMOV	{"phone": "+70625272704"}
0005433507691	A37AB3	3728 790312	BOGDAN ALEKSANDROV	{"phone": "+70532518034"}
0005433507692	F69E6A	4082 182494	VLADIMIR SMIRNOV	{"email": "smirnovvladimir061963@postgrespro.ru", "phone": "+70009401390"}
0005433507693	F69E6A	4972 766195	TAMARA ZHURAVLEVA	{"phone": "+70933031566"}
0005433507694	F69E6A	5347 402041	ALEKSANDR BARANOV	{"phone": "+70877855148"}
0005433507695	98AC59	1460 240963	GALINA SOROKINA	{"phone": "+70670092276"}
0005433507696	98AC59	1287 610281	NIKOLAY NOVIKOV	{"email": "n.novikov111972@postgrespro.ru", "phone": "+70319989441"}
0005433507697	64E3DC	5349 073662	TAMARA VASILEVA	{"email": "t.vasileva.30061970@postgrespro.ru", "phone": "+70068725103"}
0005433507698	9F81A5	2069 465030	DMITRIY MIKHAYLOV	{"phone": "+70877332546"}
0005433507699	1BA5D0	6486 945848	ARTUR ROMANOV	{"email": "romanov.a.1970@postgrespro.ru", "phone": "+70079349035"}
0005433507700	68B244	5552 715974	IGOR KUZNECOV	{"email": "kuznecovigor-021969@postgrespro.ru", "phone": "+70111981415"}
0005433507701	92F421	7808 200878	VASILIY VASILEV	{"email": "vasilevvasiliy-1966@postgrespro.ru", "phone": "+70553368742"}
0005433507702	894536	1204 227802	VLADISLAV KUZNECOV	{"email": "kuznecov.v-121971@postgrespro.ru", "phone": "+70672971100"}
0005433507703	66220E	4858 085115	OKSANA VLASOVA	{"phone": "+70800191915"}
0005433507704	3C1481	8531 289841	VITALIY SMIRNOV	{"phone": "+70369541992"}
0005433507705	311D60	3385 987450	ANTON NIKITIN	{"phone": "+70370992884"}
0005433507706	AD12F7	6375 367380	FAIL FEDOROV	{"email": "fedorov.f1976@postgrespro.ru", "phone": "+70888084500"}
0005433507707	E8CDD9	0677 346237	MARIYA PETROVA	{"email": "petrova.mariya.24061974@postgrespro.ru", "phone": "+70744442740"}
0005433507708	6CF8B9	8765 933406	NATALYA TARASOVA	{"phone": "+70034383521"}
0005433507709	C0D69E	8145 391823	IRINA MASLOVA	{"phone": "+70066248545"}
0005433507710	C0D69E	1642 276610	VLADIMIR CHERNOV	{"email": "chernov-v.101972@postgrespro.ru", "phone": "+70479537282"}
0005433507711	326391	7534 063510	ALEKSANDR MIKHAYLOV	{"phone": "+70046510522"}
0005433507712	326391	6492 811216	DMITRIY SIDOROV	{"phone": "+70153473001"}
0005433507713	F24718	3035 280950	EDUARD SMIRNOV	{"email": "eduardsmirnov.1972@postgrespro.ru", "phone": "+70026847653"}
0005433507714	ADDCE4	3763 669548	VLADIMIR ANDREEV	{"email": "andreevvladimir021961@postgrespro.ru", "phone": "+70851013453"}
0005433507715	5C5729	1464 618956	VLADIMIR KUZMIN	{"email": "v-kuzmin_011974@postgrespro.ru", "phone": "+70308211724"}
0005433507716	5C5729	5257 620035	OLGA FROLOVA	{"phone": "+70101585328"}
0005433507717	CA9301	7740 211953	VLADIMIR IVANOV	{"phone": "+70525389642"}
0005433507718	CA9301	8938 708325	EKATERINA ISAEVA	{"phone": "+70206223350"}
0005433507719	CA9FB2	3023 944601	VIKTOR SHEVCHENKO	{"email": "viktor_shevchenko-121968@postgrespro.ru", "phone": "+70416248783"}
0005433507720	A39F70	5821 591329	ALENA KARPOVA	{"email": "a_karpova-24111968@postgrespro.ru", "phone": "+70127481166"}
0005433507721	C96A99	2682 263857	VENIAMIN STEPANOV	{"phone": "+70964522010"}
0005433507722	2C0227	6229 369768	ELENA ALEKSEEVA	{"email": "elena.alekseeva-1970@postgrespro.ru", "phone": "+70082945581"}
0005433507723	600603	1549 215345	IGOR TIMOFEEV	{"phone": "+70396628706"}
0005433507724	285046	5609 893040	EVDOKIYA MAKSIMOVA	{"email": "maksimova-e.01091971@postgrespro.ru", "phone": "+70545798204"}
0005433507725	285046	3544 824262	IVAN KARPOV	{"phone": "+70938800322"}
0005433507726	FB47D7	6141 708216	EVGENIY DENISOV	{"phone": "+70553408163"}
0005433507727	6C81C3	1288 272986	DMITRIY SHEVCHENKO	{"email": "dmitriyshevchenko-1989@postgrespro.ru", "phone": "+70487879332"}
0005433507728	F600B3	3112 887887	NIKOLAY BARANOV	{"email": "nikolay.baranov-21011975@postgrespro.ru", "phone": "+70020371033"}
0005433507729	66311B	8213 684686	LIDIYA KALININA	{"phone": "+70557979431"}
0005433507730	5C9773	7599 348851	DMITRIY SOKOLOV	{"phone": "+70529240373"}
0005433507731	5C9773	7087 110684	ANTON KONOVALOV	{"phone": "+70199091519"}
0005433507732	5BCEB7	5515 544107	VASILIY NIKOLAEV	{"email": "nikolaev_vasiliy.20081973@postgrespro.ru", "phone": "+70728298171"}
0005433511801	8FC8A1	1509 193395	ALEKSANDR KOROLEV	{"email": "korolev-aleksandr_1976@postgrespro.ru", "phone": "+70745032770"}
0005433511802	96EBD6	7778 148395	ALEKSEY NAUMOV	{"email": "naumov_a-061971@postgrespro.ru", "phone": "+70859665726"}
0005433511803	96EBD6	4376 825600	VASILIY KUZNECOV	{"phone": "+70670197348"}
0005433511804	96EBD6	8630 296298	MAKSIM NAUMOV	{"email": "naumov-m_1975@postgrespro.ru", "phone": "+70323682843"}
0005433511805	1F9C5B	1655 269096	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr_1970@postgrespro.ru", "phone": "+70449790786"}
0005433511806	1F9C5B	4304 987610	LYUDMILA KUDRYASHOVA	{"phone": "+70844282727"}
0005433511807	1F9C5B	8250 120555	YULIYA KALININA	{"email": "kalininay.1968@postgrespro.ru", "phone": "+70350669132"}
0005433511808	0E8230	8460 913564	NADEZHDA LOGINOVA	{"email": "loginova_nadezhda-26011972@postgrespro.ru", "phone": "+70449922454"}
0005433511809	0E8230	0411 772490	VIKTOR IVANOV	{"phone": "+70948747500"}
0005433511810	9B91F8	7045 935504	YULIYA ZHUKOVA	{"email": "yuliyazhukova1966@postgrespro.ru", "phone": "+70897189164"}
0005433511811	9D16AE	1885 741574	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila_1971@postgrespro.ru", "phone": "+70764865664"}
0005433511812	9D16AE	7293 897810	ANDREY NAUMOV	{"email": "naumova1970@postgrespro.ru", "phone": "+70194698497"}
0005433511813	DF4131	8464 942776	LILIYA KOROLEVA	{"phone": "+70758887101"}
0005433511814	DF4131	6824 186104	EKATERINA ARKHIPOVA	{"phone": "+70260189199"}
0005433511815	7160F3	8717 657083	NADEZHDA ISAEVA	{"email": "isaeva_nadezhda.041965@postgrespro.ru", "phone": "+70473108284"}
0005433511816	7160F3	0541 259704	NIKOLAY TIMOFEEV	{"email": "n-timofeev071966@postgrespro.ru", "phone": "+70579224879"}
0005433511817	451B05	4469 019418	DMITRIY VASILEV	{"phone": "+70953575250"}
0005433511818	C74CFB	2568 750127	VLADIMIR MOROZOV	{"phone": "+70230364918"}
0005433511819	C74CFB	5396 214792	OLEG MIKHAYLOV	{"email": "mikhaylov_o_01061973@postgrespro.ru", "phone": "+70729952969"}
0005433511820	889F6D	0183 872181	ROMAN ROMANOV	{"phone": "+70143552916"}
0005433511821	889F6D	1871 496073	TATYANA PAVLOVA	{"phone": "+70872759655"}
0005433511822	889F6D	4175 219718	IGOR DENISOV	{"phone": "+70322283747"}
0005433511823	E8B008	0219 635717	TATYANA NAUMOVA	{"email": "t_naumova18061974@postgrespro.ru", "phone": "+70499826365"}
0005433511824	0182A4	2666 852269	MARIYA KUZNECOVA	{"email": "kuznecova-mariya_04031993@postgrespro.ru", "phone": "+70412091410"}
0005433511825	0182A4	6572 484315	OLGA NIKITINA	{"email": "olga_nikitina-21091973@postgrespro.ru", "phone": "+70463344710"}
0005433511826	870E6B	8305 005345	NIKOLAY FEDOROV	{"email": "fedorovnikolay_1975@postgrespro.ru", "phone": "+70730895196"}
0005433511827	51EF10	0098 866088	SERGEY SMIRNOV	{"email": "smirnov-s-1962@postgrespro.ru", "phone": "+70202907519"}
0005433511828	022D40	5284 957667	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr_12111966@postgrespro.ru", "phone": "+70017749396"}
0005433511829	178001	7594 694802	VLADIMIR KOZLOV	{"email": "kozlov-v11011975@postgrespro.ru", "phone": "+70465792866"}
0005433511830	51D832	6787 171658	TAMARA FROLOVA	{"phone": "+70038045168"}
0005433511831	51D832	2984 668660	EVGENIY ZAYCEV	{"email": "evgeniy-zaycev17101964@postgrespro.ru", "phone": "+70070465849"}
0005433511832	89910D	3981 569846	LILIYA FILATOVA	{"phone": "+70843799277"}
0005433511833	89910D	6297 545572	LEV ORLOV	{"email": "orlovl_101978@postgrespro.ru", "phone": "+70017219401"}
0005433511834	E60C9A	7266 267695	IVAN KAZAKOV	{"phone": "+70122327253"}
0005433511835	E60C9A	9349 729446	ARTEM KUZMIN	{"email": "artemkuzmin.1971@postgrespro.ru", "phone": "+70144496523"}
0005433511836	99B45D	7119 906040	SERGEY CHERNOV	{"email": "chernovsergey-1979@postgrespro.ru", "phone": "+70179409629"}
0005433511837	99B45D	6391 721002	ALEKSANDR IVANOV	{"email": "a_ivanov_15081978@postgrespro.ru", "phone": "+70421445935"}
0005433511838	99B45D	9331 503259	NIKOLAY MAKAROV	{"phone": "+70748808777"}
0005433511839	50CE15	8933 141795	SVETLANA KUZNECOVA	{"phone": "+70163761942"}
0005433511840	19787D	4706 261786	VALERIY EGOROV	{"phone": "+70592975845"}
0005433511841	EFCB35	3559 787965	YURIY VASILEV	{"phone": "+70584197124"}
0005433511842	529BC7	3111 033795	SERGEY ISAEV	{"email": "sisaev_06041973@postgrespro.ru", "phone": "+70227106898"}
0005433511843	529BC7	8143 970982	RAISA KUZMINA	{"email": "kuzmina-raisa11071963@postgrespro.ru", "phone": "+70268247511"}
0005433511844	B554E2	4119 826935	VALENTINA BORISOVA	{"phone": "+70519705722"}
0005433511845	15721B	0278 927078	VIKTOR ZAKHAROV	{"email": "viktorzakharov20011964@postgrespro.ru", "phone": "+70217492259"}
0005433511846	83E260	4285 572989	ANNA TITOVA	{"email": "titova-a_1972@postgrespro.ru", "phone": "+70744979767"}
0005433511847	8D60BE	3895 146072	MARINA BELOVA	{"phone": "+70403435087"}
0005433511848	8D60BE	3013 990927	MIKHAIL IVANOV	{"email": "m-ivanov1979@postgrespro.ru", "phone": "+70762336197"}
0005433511849	551550	5281 540164	SERGEY MARTYNOV	{"email": "sergey.martynov-1972@postgrespro.ru", "phone": "+70064034698"}
0005433511850	551550	6901 932783	PAVEL BELOV	{"phone": "+70630422952"}
0005433511851	013D7F	3330 882155	ALEKSEY IVANOV	{"email": "ivanov-a-31101962@postgrespro.ru", "phone": "+70084715204"}
0005433511852	5B766F	4079 166031	EKATERINA KULIKOVA	{"email": "e_kulikova-1969@postgrespro.ru", "phone": "+70529074728"}
0005433511853	944294	1874 311327	BOGDAN VOLKOV	{"email": "volkov_bogdan-01101972@postgrespro.ru", "phone": "+70971150433"}
0005433511854	944294	0317 296688	OLGA FILATOVA	{"phone": "+70883772035"}
0005433511855	944294	7215 051904	NINA KUZMINA	{"phone": "+70077170313"}
0005433511856	944294	0049 806089	DMITRIY TIKHONOV	{"phone": "+70861123596"}
0005433511857	B4EAA0	4667 080964	NAIL BARANOV	{"phone": "+70049261535"}
0005433511858	F709F5	4734 223198	BORIS YAKOVLEV	{"phone": "+70478213337"}
0005433511859	556574	7603 299268	SERGEY KUZNECOV	{"phone": "+70998501902"}
0005433511860	556574	5596 656158	LYUBOV SIDOROVA	{"phone": "+70355851174"}
0005433511861	52902F	3089 195066	ALEKSANDR PAVLOV	{"email": "apavlov081960@postgrespro.ru", "phone": "+70101490825"}
0005433511862	079AFD	7557 005403	ROMAN KOZLOV	{"phone": "+70098363052"}
0005433511863	079AFD	4515 428455	SVETLANA LUKYANOVA	{"email": "s-lukyanova-28061977@postgrespro.ru", "phone": "+70238639680"}
0005433511864	2E7D88	0541 911981	NATALYA PAVLOVA	{"phone": "+70376330860"}
0005433511865	2E7D88	3497 024734	ANDREY NAUMOV	{"phone": "+70894212862"}
0005433511866	2B8B6E	2643 823204	TATYANA ROMANOVA	{"phone": "+70895495749"}
0005433511867	D2757B	5180 079913	KRISTINA MAKAROVA	{"email": "makarova_k-091966@postgrespro.ru", "phone": "+70025188946"}
0005433511868	95D288	1599 074969	VLADIMIR POPOV	{"email": "popovvladimir13101968@postgrespro.ru", "phone": "+70072925569"}
0005433511869	1C1F2E	5241 276156	EGOR KUDRYASHOV	{"phone": "+70751445760"}
0005433511870	06D1DE	6438 367358	NIKOLAY VASILEV	{"email": "vasilev-nikolay_04011973@postgrespro.ru", "phone": "+70466012696"}
0005433511871	B81968	0232 353020	ANNA PETROVA	{"email": "petrovaanna.121969@postgrespro.ru", "phone": "+70343914073"}
0005433511872	B81968	8014 712719	GALINA BARANOVA	{"email": "baranovagalina-16091953@postgrespro.ru", "phone": "+70060869474"}
0005433511873	B81968	8614 708243	SERGEY MELNIKOV	{"email": "sergey-melnikov-121971@postgrespro.ru", "phone": "+70681882058"}
0005433511874	E90A01	1780 807551	YURIY ORLOV	{"phone": "+70005448927"}
0005433511875	498A4C	4654 509178	DMITRIY SIDOROV	{"email": "sidorov.dmitriy.14121972@postgrespro.ru", "phone": "+70729696446"}
0005433511876	2161D7	9833 666478	ALEKSEY PAVLOV	{"email": "aleksey-pavlov.011970@postgrespro.ru", "phone": "+70852295766"}
0005433511877	2161D7	0079 663098	DMITRIY NAUMOV	{"email": "naumov_d_031983@postgrespro.ru", "phone": "+70868258671"}
0005433511878	A2E8B3	6283 218272	ANASTASIYA KULIKOVA	{"phone": "+70232653840"}
0005433511879	D767E4	1455 089566	VASILIY GUSEV	{"email": "gusev-vasiliy-18091967@postgrespro.ru", "phone": "+70262729394"}
0005433511880	D767E4	6595 550101	RAMIL YAKOVLEV	{"email": "ryakovlev_031971@postgrespro.ru", "phone": "+70284466954"}
0005433511881	4FAC14	6854 592897	TATYANA SOROKINA	{"email": "sorokinat.1976@postgrespro.ru", "phone": "+70311389629"}
0005433511882	4FAC14	5409 324650	NIKOLAY IVANOV	{"phone": "+70243064695"}
0005433511883	45DF1D	0958 143415	IRINA ANISIMOVA	{"phone": "+70547110433"}
0005433511884	373EE4	6317 866081	ALSU TIKHONOVA	{"email": "tikhonova-a.11041976@postgrespro.ru", "phone": "+70157921896"}
0005433511885	25DA25	3376 911504	SVETLANA STEPANOVA	{"phone": "+70809000254"}
0005433511886	25DA25	4245 751912	EDUARD VOROBEV	{"email": "vorobeveduard.031975@postgrespro.ru", "phone": "+70416877181"}
0005433511887	52BB29	0992 453558	ALEKSANDR ILIN	{"phone": "+70031261070"}
0005433511888	A0345A	1815 749340	DANIIL MATVEEV	{"phone": "+70151511837"}
0005433511889	59798C	8329 152667	SERGEY KUZNECOV	{"phone": "+70636823267"}
0005433511890	F494AA	3477 321883	ARTEM AFANASEV	{"phone": "+70222785249"}
0005433511891	A6E397	3405 350442	SERGEY FOMIN	{"email": "sergey_fomin20071981@postgrespro.ru", "phone": "+70160275105"}
0005433511892	51751D	5271 345739	SVETLANA ALEKSANDROVA	{"email": "svetlanaaleksandrova_18031974@postgrespro.ru", "phone": "+70453109604"}
0005433511893	51751D	1517 506936	ANDREY ZHURAVLEV	{"email": "zhuravleva-21101978@postgrespro.ru", "phone": "+70167310052"}
0005433511894	B5F348	1924 149597	VALENTINA MAKSIMOVA	{"phone": "+70583095010"}
0005433511895	1279DE	1833 005177	EVGENIY MARTYNOV	{"phone": "+70276682743"}
0005433511896	1279DE	4201 364992	VLADIMIR KUZNECOV	{"phone": "+70623050997"}
0005433511897	C015A0	1690 013833	IGOR MARTYNOV	{"email": "igor.martynov.101975@postgrespro.ru", "phone": "+70865116356"}
0005433511898	141ADD	8599 034092	OLGA ANISIMOVA	{"phone": "+70095815771"}
0005433511899	6C1B05	0951 936202	EGOR BORISOV	{"email": "egorborisov_06071969@postgrespro.ru", "phone": "+70379999179"}
0005433511900	0F7115	1273 550403	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov_121975@postgrespro.ru", "phone": "+70549890058"}
0005433511901	0F7115	3759 882658	KSENIYA KONOVALOVA	{"email": "k-konovalova.1971@postgrespro.ru", "phone": "+70785548032"}
0005433511902	466429	1223 619087	NIKOLAY VLASOV	{"phone": "+70492055795"}
0005433511903	5437E4	1343 560194	GEORGIY KUZNECOV	{"email": "georgiy.kuznecov_041964@postgrespro.ru", "phone": "+70182052781"}
0005433511904	1B68D8	5699 037748	DENIS NAZAROV	{"email": "nazarovd_111961@postgrespro.ru", "phone": "+70414579161"}
0005433511905	1B68D8	6418 496534	ELENA KUZNECOVA	{"phone": "+70568849394"}
0005433511906	0BE991	5989 713645	VYACHESLAV GORBUNOV	{"email": "v.gorbunov.1965@postgrespro.ru", "phone": "+70788904230"}
0005433511907	0BE991	0057 763834	SERGEY ZHUKOV	{"phone": "+70818698766"}
0005433511908	4258D8	5262 339262	NIKOLAY GRIGOREV	{"email": "ngrigorev27121966@postgrespro.ru", "phone": "+70052841974"}
0005433511909	4258D8	4014 725093	DANILA IVANOV	{"email": "d-ivanov-24111969@postgrespro.ru", "phone": "+70731404957"}
0005433511910	4CCA85	3468 459798	ARTEM SCHERBAKOV	{"email": "artem-scherbakov_011984@postgrespro.ru", "phone": "+70932917007"}
0005433511911	450CED	3464 972262	PETR GERASIMOV	{"email": "gerasimov.petr-1980@postgrespro.ru", "phone": "+70578877268"}
0005433511912	7F3E7D	0757 829149	ALENA KOZLOVA	{"phone": "+70480884747"}
0005433511913	7F3E7D	5681 456810	TAMARA ILINA	{"phone": "+70868300436"}
0005433511914	67FA88	9151 239298	ALEKSEY SOKOLOV	{"phone": "+70082605317"}
0005433511915	49BE6C	3008 103037	LARISA VASILEVA	{"email": "larisa_vasileva29101976@postgrespro.ru", "phone": "+70824734308"}
0005433511916	1376B2	5758 628435	PAVEL MAKAROV	{"email": "p.makarov.04071973@postgrespro.ru", "phone": "+70139132009"}
0005433511917	27D05B	9030 864492	NIKOLAY NIKOLAEV	{"email": "nnikolaev21041967@postgrespro.ru", "phone": "+70935634869"}
0005433511918	E2073E	8591 059149	VLADIMIR IVANOV	{"phone": "+70110006663"}
0005433511919	E2073E	4311 650457	SVETLANA VASILEVA	{"phone": "+70746201838"}
0005433511920	6AAFC9	1523 695923	NATALYA FOMINA	{"email": "natalyafomina.1970@postgrespro.ru", "phone": "+70845079107"}
0005433511921	E5CE06	6022 944890	VLADIMIR POPOV	{"phone": "+70077979193"}
0005433511922	B67499	6653 706806	SVETLANA PAVLOVA	{"email": "svetlanapavlova081974@postgrespro.ru", "phone": "+70369749500"}
0005433511923	BF4CD7	7101 272602	NIKITA BORISOV	{"phone": "+70424286188"}
0005433511924	BF4CD7	6707 759671	LARISA ORLOVA	{"phone": "+70564484611"}
0005433511925	BF4CD7	6932 462087	RAISA EGOROVA	{"email": "egorova_raisa_1979@postgrespro.ru", "phone": "+70943708304"}
0005433511926	9F9992	3262 307658	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda09111961@postgrespro.ru", "phone": "+70280721714"}
0005433511927	2F6E33	3921 285874	VENIAMIN MARTYNOV	{"email": "martynov.veniamin_08081971@postgrespro.ru", "phone": "+70599811469"}
0005433511928	320595	3503 224925	ANDREY GUSEV	{"email": "andrey.gusev_1964@postgrespro.ru", "phone": "+70898789137"}
0005433511929	320595	3112 374698	MIKHAIL ILIN	{"phone": "+70980404102"}
0005433511930	B03EEC	3060 403808	GALINA OSIPOVA	{"phone": "+70481569506"}
0005433511931	B03EEC	3732 870287	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev_1974@postgrespro.ru", "phone": "+70815830035"}
0005433511932	97D43E	2141 637103	ELENA EGOROVA	{"phone": "+70376713779"}
0005433511933	97D43E	8249 836421	TATYANA NAZAROVA	{"email": "t_nazarova.1973@postgrespro.ru", "phone": "+70215807877"}
0005433511934	8E626C	1629 133589	LYUBOV BORISOVA	{"phone": "+70089574709"}
0005433511935	8E626C	8935 785797	OLGA PETROVA	{"email": "opetrova.071987@postgrespro.ru", "phone": "+70263169358"}
0005433511936	201553	5162 633620	EVGENIY ISAEV	{"email": "isaevevgeniy-02071984@postgrespro.ru", "phone": "+70926101560"}
0005433511937	DA6D3F	0636 785852	YURIY NIKOLAEV	{"phone": "+70897453127"}
0005433511938	AF99E3	3378 793811	TATYANA RODIONOVA	{"email": "tatyana-rodionova1971@postgrespro.ru", "phone": "+70109682620"}
0005433511939	AF99E3	7342 933348	GALINA ZAKHAROVA	{"email": "g_zakharova_1953@postgrespro.ru", "phone": "+70939728628"}
0005433511940	FE16FC	0596 459490	SERGEY ORLOV	{"email": "sorlov091981@postgrespro.ru", "phone": "+70129780965"}
0005433511941	C37A07	0842 047460	TATYANA POTAPOVA	{"email": "t.potapova-04031979@postgrespro.ru", "phone": "+70319308914"}
0005433511942	53E2BA	3216 359766	ELIZAVETA SAVELEVA	{"email": "e_saveleva_26031973@postgrespro.ru", "phone": "+70302946145"}
0005433511943	53E2BA	3517 260382	ELIZAVETA GORBUNOVA	{"email": "e_gorbunova.1972@postgrespro.ru", "phone": "+70174822074"}
0005433511944	48207E	6747 674210	MARINA KONOVALOVA	{"phone": "+70356399332"}
0005433511945	37004A	0100 201076	EKATERINA ZAKHAROVA	{"email": "ekaterinazakharova1982@postgrespro.ru", "phone": "+70785727421"}
0005433511946	0173F3	5507 261970	MAKSIM KISELEV	{"email": "maksim-kiselev.101975@postgrespro.ru", "phone": "+70883564215"}
0005433511947	A565DE	1902 361593	VIKTOR FEDOROV	{"email": "fedorovv1971@postgrespro.ru", "phone": "+70352833803"}
0005433511948	A565DE	4607 717663	YURIY RODIONOV	{"email": "rodionov.y071974@postgrespro.ru", "phone": "+70163625086"}
0005433511949	0AFDAB	4905 015944	NADEZHDA MOISEEVA	{"email": "moiseevanadezhda.18091972@postgrespro.ru", "phone": "+70827888464"}
0005433511950	0AFDAB	8472 948383	SVETLANA VLASOVA	{"email": "svetlanavlasova25091976@postgrespro.ru", "phone": "+70396289518"}
0005433511951	06C911	1551 337322	NATALYA TIMOFEEVA	{"phone": "+70327327356"}
0005433511952	06C911	1162 286727	OLGA FILIPPOVA	{"email": "olga_filippova1982@postgrespro.ru", "phone": "+70068742117"}
0005433511953	100BEA	2356 492441	ELENA ZHURAVLEVA	{"email": "zhuravleva.e1963@postgrespro.ru", "phone": "+70146492998"}
0005433511954	437C89	3223 881478	SOFYA ILINA	{"phone": "+70761534714"}
0005433511955	FC786B	5571 035571	KRISTINA BELOVA	{"phone": "+70750923567"}
0005433511956	FD08C8	9560 642708	STEPAN ANTONOV	{"email": "s_antonov-1969@postgrespro.ru", "phone": "+70482159521"}
0005433511957	8C7D12	3614 417066	ALEKSEY AFANASEV	{"email": "alekseyafanasev091986@postgrespro.ru", "phone": "+70888200078"}
0005433511958	3A0A2D	3350 165368	MIKHAIL BONDARENKO	{"email": "bondarenko_mikhail-071978@postgrespro.ru", "phone": "+70209445286"}
0005433511959	3A0A2D	2261 564769	SERGEY OSIPOV	{"phone": "+70207423730"}
0005433511960	E63E06	5150 695130	ANASTASIYA ILINA	{"email": "a.ilina.041981@postgrespro.ru", "phone": "+70901934379"}
0005433511961	65A799	4751 430198	ALEKSEY SEMENOV	{"phone": "+70449811052"}
0005433511962	65A799	3135 669091	VALENTINA PETROVA	{"phone": "+70218752944"}
0005433511963	65A799	7874 445001	NATALIYA NIKOLAEVA	{"email": "n-nikolaeva.021964@postgrespro.ru", "phone": "+70377516301"}
0005433511964	4D1504	8004 240485	VALENTINA MASLOVA	{"email": "maslova.valentina28021966@postgrespro.ru", "phone": "+70339225496"}
0005433511965	4D1504	7424 903057	NATALYA ORLOVA	{"email": "orlova.n021972@postgrespro.ru", "phone": "+70965984632"}
0005433511966	4D1504	3534 531651	KONSTANTIN YAKOVLEV	{"phone": "+70734783652"}
0005433511967	EB9929	5810 551718	VERA SERGEEVA	{"email": "sergeeva_vera021973@postgrespro.ru", "phone": "+70332940791"}
0005433511968	EB9929	0391 329928	KSENIYA MAKAROVA	{"email": "makarova.kseniya-1989@postgrespro.ru", "phone": "+70898511777"}
0005433511969	34CF6B	3947 876850	TATYANA ZAKHAROVA	{"email": "tatyanazakharova_1970@postgrespro.ru", "phone": "+70775612781"}
0005433511970	584564	3535 897457	SERGEY SOROKIN	{"phone": "+70857281896"}
0005433511971	B67DD2	3516 003637	ALEKSANDR DAVYDOV	{"phone": "+70163955173"}
0005433511972	21473C	0500 978302	GALINA KAZAKOVA	{"email": "kazakovag-011973@postgrespro.ru", "phone": "+70656103353"}
0005433511973	978525	3248 191480	VLADIMIR OSIPOV	{"email": "osipov-v091974@postgrespro.ru", "phone": "+70823957717"}
0005433511974	978525	1666 271791	VASILIY NOVIKOV	{"phone": "+70229275408"}
0005433511975	AE19B6	4239 990957	ELIZAVETA ANDREEVA	{"email": "andreeva.elizaveta.051968@postgrespro.ru", "phone": "+70225016082"}
0005433511976	5E286D	6957 810253	VLADIMIR SEMENOV	{"email": "vladimir.semenov-1967@postgrespro.ru", "phone": "+70007166052"}
0005433511977	B313C6	4681 232116	OLGA FEDOROVA	{"phone": "+70420789861"}
0005433511978	A642D0	7819 393704	VIKTOR KOZLOV	{"phone": "+70672642846"}
0005433511979	2EDC7C	1227 790185	GALINA GERASIMOVA	{"phone": "+70639280437"}
0005433511980	E278DB	0335 701479	VLADIMIR KUZNECOV	{"phone": "+70231832313"}
0005433511981	5ACEDB	0901 212309	NIKOLAY ZAKHAROV	{"phone": "+70433503096"}
0005433511982	5ACEDB	6836 739677	NADEZHDA MAKAROVA	{"phone": "+70355499261"}
0005433511983	5ACEDB	2705 242793	VLADIMIR SERGEEV	{"email": "sergeev-vladimir_1979@postgrespro.ru", "phone": "+70827933817"}
0005433511984	695FE2	8247 768766	IGOR SERGEEV	{"phone": "+70334423364"}
0005433511985	8ED3F5	2010 945633	ANASTASIYA VASILEVA	{"phone": "+70302070960"}
0005433511986	26D81F	0587 231830	LIDIYA FEDOROVA	{"email": "fedorova.lidiya101965@postgrespro.ru", "phone": "+70905288846"}
0005433511987	26D81F	0781 866893	ALEKSEY SMIRNOV	{"phone": "+70001465237"}
0005433511988	C1908B	8786 182529	DARYA ZAKHAROVA	{"phone": "+70160124081"}
0005433511989	ABBE2E	0903 364699	ANDREY ILIN	{"phone": "+70941449993"}
0005433511990	853466	0960 990594	ARINA KUZNECOVA	{"phone": "+70910752937"}
0005433511991	B98639	5403 726844	TATYANA NAZAROVA	{"phone": "+70841041955"}
0005433511992	D6D039	9614 791310	SVETLANA NIKOLAEVA	{"phone": "+70706593766"}
0005433511993	D6D039	8359 654740	KRISTINA ORLOVA	{"phone": "+70370800664"}
0005433511994	BC0F9B	5837 907462	SERGEY VOLKOV	{"email": "sergey.volkov-10041974@postgrespro.ru", "phone": "+70661643720"}
0005433511995	BC0F9B	3040 547448	NATALYA KARPOVA	{"phone": "+70711680654"}
0005433511996	033A87	3629 312256	MARINA BARANOVA	{"phone": "+70729977690"}
0005433511997	033A87	2066 760010	IGOR FOMIN	{"phone": "+70532393644"}
0005433511998	F49D7F	4385 420179	ANNA MAKAROVA	{"phone": "+70598207814"}
0005433511999	9AB4C2	4664 450603	ALEKSANDR MEDVEDEV	{"email": "medvedev.a_021967@postgrespro.ru", "phone": "+70543209427"}
0005433512000	9AB4C2	5739 998677	VASILIY SCHERBAKOV	{"phone": "+70107029831"}
0005433512001	C1D906	1547 300363	DMITRIY SAVELEV	{"email": "dsavelev.1984@postgrespro.ru", "phone": "+70141573064"}
0005433512002	C1D906	3987 566704	GALINA FEDOROVA	{"email": "galina_fedorova_1983@postgrespro.ru", "phone": "+70632606455"}
0005433512003	1AF46A	1915 461669	DARYA KALININA	{"email": "darya_kalinina-111973@postgrespro.ru", "phone": "+70304043954"}
0005433512188	521E18	0123 560767	PAVEL FEDOROV	{"phone": "+70500968960"}
0005433512004	DB00BA	1682 748920	VLADIMIR POPOV	{"email": "vladimir-popov_1964@postgrespro.ru", "phone": "+70354203173"}
0005433512005	3C8D85	2129 844934	ALEKSEY NIKOLAEV	{"phone": "+70148850860"}
0005433512006	2DF729	4088 014998	VLADIMIR FROLOV	{"phone": "+70105053574"}
0005433512007	074526	8258 044032	SERGEY PETROV	{"email": "sergey.petrov.1978@postgrespro.ru", "phone": "+70804774215"}
0005433512008	167E4B	6655 376842	ELENA GRISHINA	{"phone": "+70969954272"}
0005433512009	3B49F9	4995 905478	KLAVDIYA KONDRATEVA	{"email": "klavdiya_kondrateva-1964@postgrespro.ru", "phone": "+70079347543"}
0005433512010	9EFD8A	3102 325586	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail-1978@postgrespro.ru", "phone": "+70167925907"}
0005433512011	91D888	4949 551181	VALERIY MIKHAYLOV	{"phone": "+70578650893"}
0005433512012	568D06	6731 112689	ALEKSANDR KULIKOV	{"phone": "+70313793966"}
0005433512013	28B183	0271 106986	VALERIY MOROZOV	{"email": "morozov-valeriy.1979@postgrespro.ru", "phone": "+70595218762"}
0005433512014	2C65D5	2770 413721	VASILIY ILIN	{"phone": "+70100156319"}
0005433512015	2C65D5	5875 327993	EKATERINA NESTEROVA	{"email": "nesterova.ekaterina1971@postgrespro.ru", "phone": "+70721113962"}
0005433512016	B1DDFD	6104 959639	RUSLAN IVANOV	{"phone": "+70092098083"}
0005433512017	1862EE	5616 277431	VIKTORIYA OSIPOVA	{"phone": "+70838690119"}
0005433512018	1862EE	2525 981507	MARINA ABRAMOVA	{"phone": "+70966299602"}
0005433512019	A94CDC	1078 670178	SERGEY MEDVEDEV	{"phone": "+70184182122"}
0005433512020	A94CDC	2764 792021	NIKOLAY IVANOV	{"email": "ivanovn.1965@postgrespro.ru", "phone": "+70432054850"}
0005433512021	8E5BF7	4926 347758	ALBINA ROMANOVA	{"phone": "+70190482298"}
0005433512022	D01EFB	2683 073412	VASILIY FEDOROV	{"phone": "+70078310003"}
0005433512023	DE159A	2360 542326	NADEZHDA FEDOROVA	{"email": "nadezhdafedorova.041973@postgrespro.ru", "phone": "+70317036338"}
0005433512024	C4C63F	2422 008770	NIKOLAY KOZLOV	{"phone": "+70105687645"}
0005433512025	C4C63F	5064 989199	KIRILL KOROLEV	{"phone": "+70936089342"}
0005433512026	C4C63F	7063 415257	MAKSIM MELNIKOV	{"email": "maksim.melnikov-021963@postgrespro.ru", "phone": "+70598302586"}
0005433512027	2BE878	6508 785010	NINA KUZMINA	{"email": "kuzmina_n_1965@postgrespro.ru", "phone": "+70176317713"}
0005433512028	C26238	8106 728300	VALENTIN DMITRIEV	{"email": "valentindmitriev_021970@postgrespro.ru", "phone": "+70738165949"}
0005433512029	215AA6	0700 112135	YULIYA VLASOVA	{"phone": "+70970306931"}
0005433512030	CC2E96	1383 811457	MIKHAIL FEDOTOV	{"email": "fedotovmikhail.11011975@postgrespro.ru", "phone": "+70413421301"}
0005433512031	8954A4	8287 272437	STEPAN NAZAROV	{"phone": "+70983978115"}
0005433512032	7812F5	6691 896795	ANNA KARPOVA	{"phone": "+70861486069"}
0005433512033	7812F5	9067 711998	TAISIYA IVANOVA	{"email": "ivanovat-07041969@postgrespro.ru", "phone": "+70998892626"}
0005433512034	3D77FB	1981 209773	KRISTINA PAVLOVA	{"phone": "+70720005012"}
0005433512035	3D77FB	0104 620158	STANISLAV IVANOV	{"email": "stanislav_ivanov.1973@postgrespro.ru", "phone": "+70241081036"}
0005433512036	26148B	4743 659480	EVGENIYA ABRAMOVA	{"email": "abramova-evgeniya_031960@postgrespro.ru", "phone": "+70805416091"}
0005433512037	32A17F	5490 684481	ANNA POPOVA	{"email": "popovaanna.111972@postgrespro.ru", "phone": "+70495414718"}
0005433512038	269B3D	4579 754439	VYACHESLAV POPOV	{"phone": "+70280978861"}
0005433512039	F2D437	9196 282518	NIKITA GRIGOREV	{"email": "grigorev-nikita-29081968@postgrespro.ru", "phone": "+70907585128"}
0005433512040	4D450D	7916 097688	OLGA ARKHIPOVA	{"phone": "+70158957908"}
0005433512041	1BC9E9	3615 660225	ZINAIDA KOVALEVA	{"email": "zkovaleva.07041966@postgrespro.ru", "phone": "+70048913616"}
0005433512042	13FCD4	3270 298366	ALEKSANDR SEMENOV	{"phone": "+70073461979"}
0005433512043	154977	9247 541831	KSENIYA DENISOVA	{"phone": "+70258894534"}
0005433512044	D0BBA8	5308 650951	ELMIRA TITOVA	{"phone": "+70808934314"}
0005433512045	794EBE	5874 556005	DMITRIY ZAYCEV	{"email": "zaycev_dmitriy_071974@postgrespro.ru", "phone": "+70370876318"}
0005433512046	8BE057	0253 381803	GALIYA DANILOVA	{"email": "g-danilova.031977@postgrespro.ru", "phone": "+70480496243"}
0005433512047	BEE858	0091 892114	EGOR KUZNECOV	{"email": "kuznecov.egor101968@postgrespro.ru", "phone": "+70304927349"}
0005433512048	3067AA	9038 329981	NADEZHDA PAVLOVA	{"phone": "+70309309449"}
0005433512049	2F34C2	2325 937811	ALEKSANDR KUZNECOV	{"phone": "+70150937952"}
0005433512050	91C117	8681 247683	ANTON VLASOV	{"phone": "+70758068731"}
0005433512051	FBC914	7066 928973	NIKOLAY DAVYDOV	{"email": "davydovn.1969@postgrespro.ru", "phone": "+70615873841"}
0005433512052	9EDAC9	2122 130548	OLEG MOISEEV	{"phone": "+70990425114"}
0005433512053	9EDAC9	1390 516862	EVGENIY DENISOV	{"phone": "+70581293186"}
0005433512054	9EDAC9	7450 696519	ANNA IVANOVA	{"email": "ivanova_a_13111969@postgrespro.ru", "phone": "+70354094117"}
0005433512055	E0F189	9096 836752	ALEKSEY VASILEV	{"phone": "+70865771436"}
0005433512056	322A42	1175 682407	EKATERINA KUZNECOVA	{"email": "ekaterina-kuznecova-031976@postgrespro.ru", "phone": "+70443331468"}
0005433512057	322A42	4555 371746	MARINA SOROKINA	{"phone": "+70791907760"}
0005433512058	5610B6	1886 256769	SVETLANA MOROZOVA	{"phone": "+70926584218"}
0005433512059	2449B2	0767 334358	ALEKSANDR MIRONOV	{"email": "aleksandr_mironov-1964@postgrespro.ru", "phone": "+70736498825"}
0005433512060	65F725	8519 123727	OLGA LAZAREVA	{"email": "olazareva_1968@postgrespro.ru", "phone": "+70937951827"}
0005433512061	339000	3874 821778	ANDREY MIKHAYLOV	{"email": "a_mikhaylov_01031988@postgrespro.ru", "phone": "+70680572240"}
0005433512062	54A400	9498 256767	OLGA TIMOFEEVA	{"email": "o-timofeeva-16051964@postgrespro.ru", "phone": "+70407652122"}
0005433512063	45F421	1489 403330	MARINA NOVIKOVA	{"phone": "+70859231636"}
0005433512064	3CFAE2	3904 011176	LIDIYA MAKSIMOVA	{"email": "l-maksimova_11031974@postgrespro.ru", "phone": "+70750819718"}
0005433512065	26FF28	8231 802653	ALEKSANDR SOKOLOV	{"email": "asokolov-1975@postgrespro.ru", "phone": "+70170238943"}
0005433512066	26FF28	4840 071636	NATALYA KULIKOVA	{"email": "kulikova.natalya_071983@postgrespro.ru", "phone": "+70685221218"}
0005433512067	9DFAE9	9716 558987	IRINA KUZNECOVA	{"phone": "+70738443272"}
0005433512068	0F0AB2	9893 793739	VADIM POPOV	{"phone": "+70555465693"}
0005433512069	0F0AB2	0104 798781	SERGEY NOVIKOV	{"email": "sergey.novikov_021972@postgrespro.ru", "phone": "+70363304391"}
0005433512070	79C404	8645 276333	ANNA MELNIKOVA	{"email": "a_melnikova-1971@postgrespro.ru", "phone": "+70673628420"}
0005433512071	79C404	3551 655166	EVGENIYA ERMAKOVA	{"email": "evgeniya.ermakova11031974@postgrespro.ru", "phone": "+70645581992"}
0005433512072	61A5F2	0493 501446	VIKTOR KOZLOV	{"email": "viktor_kozlov.02061972@postgrespro.ru", "phone": "+70013679579"}
0005433512073	61A5F2	4185 579841	GALINA GORBUNOVA	{"phone": "+70909950244"}
0005433512074	75308B	7991 339481	MILANA KOZLOVA	{"email": "kozlova-m.14011977@postgrespro.ru", "phone": "+70978060619"}
0005433512075	75308B	4491 905414	OLGA NIKOLAEVA	{"phone": "+70480817791"}
0005433512076	0BFF97	4743 553771	IGOR FILIPPOV	{"email": "igorfilippov1965@postgrespro.ru", "phone": "+70082550093"}
0005433512077	9736B1	9342 124751	SVETLANA BARANOVA	{"email": "baranova_svetlana01061977@postgrespro.ru", "phone": "+70719202788"}
0005433512078	9E7346	2109 643208	VALERIY KUZNECOV	{"email": "kuznecovv-121968@postgrespro.ru", "phone": "+70164683175"}
0005433512079	9E7346	1467 469473	VALENTINA KARPOVA	{"phone": "+70534638577"}
0005433512080	CFDCAD	0479 543751	VALENTINA TIKHONOVA	{"phone": "+70705632946"}
0005433512081	AC4F4D	3069 231384	NADEZHDA KUZMINA	{"email": "nadezhda.kuzmina_1969@postgrespro.ru", "phone": "+70269837122"}
0005433512082	AC4F4D	8689 192381	NIKITA ZHURAVLEV	{"phone": "+70783966132"}
0005433512083	AC4F4D	4591 716416	VALERIY VOROBEV	{"email": "valeriy.vorobev_1968@postgrespro.ru", "phone": "+70367924227"}
0005433512084	E1DFF2	6282 440669	VLADIMIR OSIPOV	{"phone": "+70873697185"}
0005433512085	13236D	6564 719687	DMITRIY ANTONOV	{"phone": "+70070559822"}
0005433512086	13236D	7754 667802	LYUBOV SEMENOVA	{"email": "l_semenova-1963@postgrespro.ru", "phone": "+70455329892"}
0005433512087	258321	7548 712274	TATYANA KOVALEVA	{"phone": "+70299414639"}
0005433512088	258321	9269 162406	NATALYA OSIPOVA	{"phone": "+70626098375"}
0005433512089	47A142	2660 762014	OLGA YAKOVLEVA	{"email": "yakovleva.o.1962@postgrespro.ru", "phone": "+70139041342"}
0005433512090	9CE035	5844 481130	ARTEM FILIPPOV	{"email": "a_filippov-1965@postgrespro.ru", "phone": "+70219685691"}
0005433512091	7F4695	0400 659865	TATYANA MEDVEDEVA	{"phone": "+70352324125"}
0005433512092	7F4695	0596 367555	KSENIYA ZAKHAROVA	{"phone": "+70395164870"}
0005433512093	635119	3177 717663	IRINA DENISOVA	{"phone": "+70139243000"}
0005433512094	635119	1789 446309	VALENTINA YAKOVLEVA	{"phone": "+70577835064"}
0005433512095	6041F8	7884 570791	PAVEL ABRAMOV	{"phone": "+70516821074"}
0005433512096	896E63	9038 059893	VLADIMIR FOMIN	{"phone": "+70680575137"}
0005433512097	7A0A06	4165 707977	MARIYA IVANOVA	{"phone": "+70047682062"}
0005433512098	6A4310	4529 902901	NATALYA MAKAROVA	{"phone": "+70855718943"}
0005433512099	05B789	8991 597642	IGOR VASILEV	{"email": "vasilev-i-101966@postgrespro.ru", "phone": "+70690147506"}
0005433512100	05B789	8176 084434	OLGA ILINA	{"email": "ilinaolga.17041966@postgrespro.ru", "phone": "+70913718566"}
0005433512101	E5445C	0597 683241	ALEKSEY MOISEEV	{"email": "moiseev.a_01101966@postgrespro.ru", "phone": "+70783897576"}
0005433512102	57B309	9353 439262	ALEKSANDR VASILEV	{"phone": "+70287969799"}
0005433512103	7472BF	0508 412247	ALEKSEY KAZAKOV	{"phone": "+70366560136"}
0005433512104	2BFEDE	2143 022778	NADEZHDA SOKOLOVA	{"phone": "+70220832683"}
0005433512105	2BFEDE	9013 828602	VLADIMIR BELOV	{"email": "vladimirbelov1972@postgrespro.ru", "phone": "+70337194409"}
0005433512106	D3FD41	3422 336256	ANASTASIYA POPOVA	{"email": "anastasiyapopova-22121981@postgrespro.ru", "phone": "+70725254797"}
0005433512107	D3FD41	8578 358212	SERGEY VLASOV	{"phone": "+70451989186"}
0005433512108	3DC81B	3223 609392	VLADIMIR VASILEV	{"phone": "+70357184223"}
0005433512109	3DC81B	2260 177254	ANDREY SMIRNOV	{"email": "andrey-smirnov11031971@postgrespro.ru", "phone": "+70400044253"}
0005433512110	BB9348	2784 109230	VLADIMIR VASILEV	{"phone": "+70602264706"}
0005433512111	B8FDA7	2650 084921	OLGA ROMANOVA	{"phone": "+70404678786"}
0005433512112	F12D12	3910 931992	SVETLANA KOROLEVA	{"email": "s.koroleva-1970@postgrespro.ru", "phone": "+70554749068"}
0005433512113	CC42B4	5930 751263	YULIYA LUKYANOVA	{"phone": "+70680799167"}
0005433512114	7C4E40	5565 283161	LYUDMILA RODIONOVA	{"email": "lyudmilarodionova-28111971@postgrespro.ru", "phone": "+70238137056"}
0005433512115	BFA8F3	9405 609569	LYUDMILA POPOVA	{"phone": "+70389420311"}
0005433512116	9AF94C	2026 671975	IRINA LOGINOVA	{"email": "loginova.irina1971@postgrespro.ru", "phone": "+70309561862"}
0005433512117	9AF94C	4029 079473	NATALYA LEBEDEVA	{"email": "natalya.lebedeva16091979@postgrespro.ru", "phone": "+70801833462"}
0005433512118	6E4A04	9849 613508	YULIYA ERMAKOVA	{"phone": "+70416952353"}
0005433512119	6E4A04	9815 501016	NATALYA MALYSHEVA	{"phone": "+70466223813"}
0005433512120	54D545	8505 013358	DMITRIY TARASOV	{"phone": "+70349281537"}
0005433512121	058EBC	3221 460959	MARIYA BORISOVA	{"email": "mariya.borisova-13061968@postgrespro.ru", "phone": "+70095615109"}
0005433512122	1E9ED8	2307 393117	ALEKSANDR FROLOV	{"phone": "+70015099180"}
0005433512123	1E9ED8	4702 269198	MAKSIM ISAEV	{"phone": "+70879026220"}
0005433512124	108F10	5618 934000	EKATERINA EGOROVA	{"phone": "+70088849236"}
0005433512125	108F10	8104 627865	YURIY MAKSIMOV	{"email": "y.maksimov-1977@postgrespro.ru", "phone": "+70394895748"}
0005433512126	F8C0C9	0299 564087	NATALYA STEPANOVA	{"email": "natalya_stepanova_091970@postgrespro.ru", "phone": "+70529480842"}
0005433512127	F8C0C9	1532 099372	MIKHAIL BORISOV	{"email": "mikhail-borisov-1971@postgrespro.ru", "phone": "+70288337439"}
0005433512128	9338F7	1784 383526	MIKHAIL GRIGOREV	{"phone": "+70359576700"}
0005433512129	9338F7	8384 747556	TATYANA SERGEEVA	{"phone": "+70756310540"}
0005433512130	9338F7	8973 611404	NIKOLAY VLASOV	{"phone": "+70366912399"}
0005433512131	8CF484	3933 723635	OLGA KRASNOVA	{"phone": "+70542260382"}
0005433512132	88CA76	9439 338553	LEONID KULIKOV	{"email": "l-kulikov121971@postgrespro.ru", "phone": "+70508476019"}
0005433512133	9095E2	8889 355516	IRINA MAKAROVA	{"email": "makarova_i_31081979@postgrespro.ru", "phone": "+70048509546"}
0005433512134	BE662B	5691 232493	ANATOLIY VOLKOV	{"phone": "+70289061730"}
0005433512135	A62282	4333 768519	NATALYA GRISHINA	{"email": "grishina.natalya1964@postgrespro.ru", "phone": "+70585635437"}
0005433512136	51BDC4	8853 665340	VALENTINA SCHERBAKOVA	{"email": "valentina.scherbakova121981@postgrespro.ru", "phone": "+70683114545"}
0005433512137	6B94EF	6998 021117	TATYANA KUDRYASHOVA	{"phone": "+70585350932"}
0005433512138	6B94EF	0862 343126	RAVILYA SIDOROVA	{"phone": "+70278106855"}
0005433512139	8A7917	6520 215713	VITALIY MOROZOV	{"phone": "+70598308904"}
0005433512140	8A7917	8777 876593	EKATERINA PAVLOVA	{"email": "pavlova-e1969@postgrespro.ru", "phone": "+70571834716"}
0005433512141	DCE4A8	4204 341406	VIKTOR SAVELEV	{"phone": "+70643679075"}
0005433512142	817A46	8706 272668	BORIS MAKSIMOV	{"phone": "+70089575054"}
0005433512143	817A46	4343 684607	VALENTINA TARASOVA	{"email": "v-tarasova121972@postgrespro.ru", "phone": "+70820038485"}
0005433512144	5D77F3	4824 859360	IVAN ZAYCEV	{"email": "ivan-zaycev_1978@postgrespro.ru", "phone": "+70985060316"}
0005433512145	9E120A	7652 218546	ZOYA MAKAROVA	{"email": "z-makarova.061970@postgrespro.ru", "phone": "+70960294500"}
0005433512146	9697A4	3538 840848	ALEKSEY VASILEV	{"phone": "+70356917937"}
0005433512147	EF71DE	7309 848217	VERA BELOVA	{"email": "vera.belova-1967@postgrespro.ru", "phone": "+70509630472"}
0005433512148	EF71DE	4978 088160	SAID SCHERBAKOV	{"email": "scherbakov-s061980@postgrespro.ru", "phone": "+70250120736"}
0005433512149	31A155	0909 708294	VALERIYA KOVALEVA	{"phone": "+70976169116"}
0005433512150	D50EBA	1507 147912	DARYA BORISOVA	{"phone": "+70306691667"}
0005433512151	D50EBA	9373 803385	ALEKSEY SOKOLOV	{"email": "sokolova_081976@postgrespro.ru", "phone": "+70390612054"}
0005433512152	9772E3	6797 233992	NATALYA KOROLEVA	{"phone": "+70959674698"}
0005433512153	102982	0871 237006	EVGENIY KUZMIN	{"email": "kuzmin-e-111964@postgrespro.ru", "phone": "+70557517922"}
0005433512154	102982	0588 569902	ELENA TIKHONOVA	{"phone": "+70076030421"}
0005433512155	53C7FC	2999 486129	ALLA ANDREEVA	{"phone": "+70594784125"}
0005433512156	53C7FC	0494 904615	ALEKSANDR SEMENOV	{"phone": "+70163491325"}
0005433512157	4DEC61	7893 722286	EVGENIY DAVYDOV	{"email": "evgeniydavydov-18071969@postgrespro.ru", "phone": "+70199495118"}
0005433512158	4DEC61	3713 491023	MIKHAIL SHEVCHENKO	{"email": "mikhail_shevchenko_10031974@postgrespro.ru", "phone": "+70847382692"}
0005433512159	64B31F	5967 039074	VLADISLAV STEPANOV	{"email": "vladislav-stepanov_1976@postgrespro.ru", "phone": "+70243632649"}
0005433512160	64B31F	4590 125876	VLADIMIR IVANOV	{"phone": "+70471726041"}
0005433512161	5948F8	8429 244975	IRINA STEPANOVA	{"email": "stepanovairina03101975@postgrespro.ru", "phone": "+70595507151"}
0005433512162	5948F8	3460 645084	RAMIL AFANASEV	{"phone": "+70907106407"}
0005433512163	9AD7AE	3718 473701	VLADIMIR GAVRILOV	{"phone": "+70988879651"}
0005433512164	FC979C	1581 753743	ELENA GAVRILOVA	{"email": "e_gavrilova-1970@postgrespro.ru", "phone": "+70910938132"}
0005433512165	E2CD5E	2324 472793	NATALYA POTAPOVA	{"email": "potapovan-01011978@postgrespro.ru", "phone": "+70781281261"}
0005433512166	E66748	8765 481008	NINA VOLKOVA	{"phone": "+70323803395"}
0005433512167	DCCAC4	4354 493013	VIKTOR IVANOV	{"phone": "+70219786954"}
0005433512168	2CA27C	2155 611433	VLADIMIR NIKOLAEV	{"email": "nikolaev_v121963@postgrespro.ru", "phone": "+70822587122"}
0005433512169	93A9BE	8116 415197	VALERIY MIKHAYLOV	{"phone": "+70433389927"}
0005433512170	9B4741	9509 360654	MARIYA KOVALEVA	{"email": "kovaleva-m23081983@postgrespro.ru", "phone": "+70103401070"}
0005433512171	9B4741	7105 851059	LYUBOV ANDREEVA	{"phone": "+70923043887"}
0005433512172	02FBC6	9106 110313	VALERIYA BORISOVA	{"email": "borisova_v.011964@postgrespro.ru", "phone": "+70784219318"}
0005433512173	10899A	8166 801313	ANNA OSIPOVA	{"email": "osipovaa031974@postgrespro.ru", "phone": "+70037787862"}
0005433512174	10899A	7085 364649	EVGENIY MIKHAYLOV	{"email": "mikhaylov_evgeniy.091971@postgrespro.ru", "phone": "+70354560878"}
0005433512175	10899A	8326 516238	VALERIYA RYABOVA	{"email": "ryabova-valeriya-101975@postgrespro.ru", "phone": "+70691529188"}
0005433512176	744831	9358 550052	ANTONINA DAVYDOVA	{"email": "antonina.davydova_041976@postgrespro.ru", "phone": "+70845751750"}
0005433512177	D5708E	3481 647437	YULIYA KUZMINA	{"email": "kuzmina_yuliya061970@postgrespro.ru", "phone": "+70189243062"}
0005433512178	072CA5	3529 080900	SVETLANA PAVLOVA	{"phone": "+70586710920"}
0005433512179	072CA5	3345 801113	VYACHESLAV IVANOV	{"email": "vyacheslavivanov_1969@postgrespro.ru", "phone": "+70152199710"}
0005433512180	0FFD3E	3102 587931	ALEKSANDR YAKOVLEV	{"phone": "+70277797832"}
0005433512181	1C6176	5301 883283	ANNA SCHERBAKOVA	{"phone": "+70914229481"}
0005433512182	1C6176	5702 360934	SERGEY VASILEV	{"email": "sergeyvasilev_1965@postgrespro.ru", "phone": "+70179671056"}
0005433512183	1C6176	0909 399860	SERGEY POPOV	{"phone": "+70230101659"}
0005433512184	9D6E03	2310 605263	SERGEY SAVELEV	{"email": "sergey.savelev.1976@postgrespro.ru", "phone": "+70663923793"}
0005433512185	851E84	8192 396215	VERONIKA IVANOVA	{"phone": "+70478176341"}
0005433512186	851E84	9692 101066	VLADIMIR KRASNOV	{"phone": "+70709565518"}
0005433512187	521E18	8735 987389	LYUBOV SIDOROVA	{"phone": "+70894951077"}
0005433512189	1AEC90	7314 552547	MARINA VOLKOVA	{"phone": "+70580410510"}
0005433512190	1AEC90	0592 589779	GULNARA OVCHINNIKOVA	{"phone": "+70979152459"}
0005433512191	543479	3507 522747	NATALYA KOZLOVA	{"email": "kozlova-natalya_041962@postgrespro.ru", "phone": "+70598246975"}
0005433512192	543479	9644 547793	SERGEY EGOROV	{"email": "sergey.egorov_1971@postgrespro.ru", "phone": "+70063263867"}
0005433512193	543479	9288 535965	GULIYA ANISIMOVA	{"email": "anisimova.g-27021968@postgrespro.ru", "phone": "+70186013373"}
0005433512194	3B575D	7734 660279	DENIS NAZAROV	{"email": "nazarovd.01041982@postgrespro.ru", "phone": "+70693201843"}
0005433512195	3B575D	6226 660476	ROMAN BARANOV	{"phone": "+70531169625"}
0005433512196	ABA43E	1562 334039	LYUDMILA PETROVA	{"phone": "+70884662685"}
0005433512197	D2F4D0	6739 311001	OLEG GAVRILOV	{"phone": "+70517366709"}
0005433512198	D2F4D0	6999 853718	ANNA ZAYCEVA	{"phone": "+70230755700"}
0005433516721	C5740D	7868 014733	ALEKSANDR GORBUNOV	{"phone": "+70659524329"}
0005433516722	234A58	3199 530022	NATALYA STEPANOVA	{"phone": "+70902382271"}
0005433516723	EC0F9C	6988 400289	DARYA NIKITINA	{"email": "nikitina_darya-1971@postgrespro.ru", "phone": "+70589533687"}
0005433516724	A395A3	9147 121901	RUSLAN SMIRNOV	{"email": "r.smirnov20091977@postgrespro.ru", "phone": "+70881991731"}
0005433516725	F507D1	6426 708054	ALEKSANDR SAVELEV	{"phone": "+70079335130"}
0005433516726	7935A0	8201 616341	VERA POPOVA	{"email": "vera_popova-22061987@postgrespro.ru", "phone": "+70419728481"}
0005433516727	B22495	0025 040386	LYUDMILA OVCHINNIKOVA	{"email": "l-ovchinnikova-1970@postgrespro.ru", "phone": "+70842213979"}
0005433516728	E32694	2442 490101	VASILIY FROLOV	{"email": "frolovvasiliy_1980@postgrespro.ru", "phone": "+70600948995"}
0005433516729	E32694	4440 461289	ALEKSANDR SOROKIN	{"email": "a-sorokin091963@postgrespro.ru", "phone": "+70772245797"}
0005433516730	41FD3F	2900 472822	TATYANA KRASNOVA	{"phone": "+70519761912"}
0005433516731	41FD3F	7876 254484	NADEZHDA PAVLOVA	{"phone": "+70741609650"}
0005433516732	F04524	6516 807219	EVGENIYA SEMENOVA	{"phone": "+70616088461"}
0005433516733	F04524	5188 423437	LYUDMILA BELOVA	{"email": "l-belova_081967@postgrespro.ru", "phone": "+70615533229"}
0005433516734	1A4E82	5580 415741	DMITRIY KULIKOV	{"phone": "+70360074559"}
0005433516735	8086DA	0816 578401	RAFAIL VASILEV	{"phone": "+70436079148"}
0005433516736	8086DA	2811 318858	KIRILL FEDOROV	{"email": "fedorov_kirill061964@postgrespro.ru", "phone": "+70817982412"}
0005433516737	8086DA	1690 604520	VIKTOR VLASOV	{"phone": "+70798702886"}
0005433516738	718747	8378 429131	NIKOLAY MOROZOV	{"email": "morozov-n_091963@postgrespro.ru", "phone": "+70813985718"}
0005433516739	718747	0333 620628	VALENTIN ZAYCEV	{"email": "zaycevv_03121971@postgrespro.ru", "phone": "+70487108040"}
0005433516740	37C4D9	7261 095007	NADEZHDA TITOVA	{"email": "nadezhda-titova-20081982@postgrespro.ru", "phone": "+70560642985"}
0005433516741	64F998	8567 579659	ALEKSANDR SCHERBAKOV	{"phone": "+70780545326"}
0005433516742	64F998	4845 585767	BORIS SCHERBAKOV	{"phone": "+70564541736"}
0005433516743	7E3894	3300 446688	LYUDMILA MAKSIMOVA	{"email": "lmaksimova_091964@postgrespro.ru", "phone": "+70721683084"}
0005433516744	383A87	5231 066279	VALERIY SCHERBAKOV	{"email": "scherbakov.valeriy.1984@postgrespro.ru", "phone": "+70085248853"}
0005433516745	998E46	3489 304604	GENNADIY MATVEEV	{"phone": "+70979385720"}
0005433516746	3C208E	1794 956495	MARGARITA BORISOVA	{"email": "margarita-borisova_1968@postgrespro.ru", "phone": "+70086306852"}
0005433516747	A318A1	5507 196726	TATYANA FOMINA	{"phone": "+70014979209"}
0005433516748	B68FCB	2972 485826	SERGEY SAVELEV	{"email": "sergey-savelev_25031975@postgrespro.ru", "phone": "+70781381945"}
0005433516749	AAE6E3	0286 217879	NURLAN SCHERBAKOV	{"email": "scherbakov-n.111954@postgrespro.ru", "phone": "+70874044365"}
0005433516750	E098A9	0458 491725	LYUBOV MELNIKOVA	{"email": "lmelnikova121975@postgrespro.ru", "phone": "+70276519531"}
0005433516751	A858DF	6805 301988	GALINA ISAEVA	{"email": "isaevag081973@postgrespro.ru", "phone": "+70275183762"}
0005433516752	5CB38F	8878 209493	ALEKSANDR VOROBEV	{"email": "vorobev_a.1985@postgrespro.ru", "phone": "+70161661546"}
0005433516753	954B2D	1438 765229	IVAN FEDOROV	{"phone": "+70086952951"}
0005433516754	136822	0432 701651	NIKOLAY MEDVEDEV	{"email": "n.medvedev_041969@postgrespro.ru", "phone": "+70462570320"}
0005433516755	136822	8294 657840	INNA TIKHONOVA	{"email": "i_tikhonova_27071974@postgrespro.ru", "phone": "+70038931880"}
0005433516756	16FDA6	2582 257664	RAISA TROFIMOVA	{"phone": "+70216596864"}
0005433516757	A78C3F	5286 053613	VYACHESLAV FILIPPOV	{"email": "v_filippov1977@postgrespro.ru", "phone": "+70008599549"}
0005433516758	FB3F07	5083 021757	NATALIYA ORLOVA	{"phone": "+70361614753"}
0005433516759	E74872	3420 267822	LARISA ABRAMOVA	{"phone": "+70405672874"}
0005433516760	E9D7F4	8655 087933	EKATERINA YUDINA	{"email": "yudina.e-06071981@postgrespro.ru", "phone": "+70792255594"}
0005433516761	406B29	3593 740479	NATALYA IVANOVA	{"phone": "+70645664315"}
0005433516762	695BB4	6284 494638	FAINA KAZAKOVA	{"phone": "+70464310149"}
0005433516763	695BB4	2804 907615	LYUDMILA KONOVALOVA	{"phone": "+70909683418"}
0005433516764	489F7E	5666 850897	ANDREY KUDRYASHOV	{"email": "a_kudryashov_1975@postgrespro.ru", "phone": "+70492047806"}
0005433516765	675F7E	9823 061537	KRISTINA ROMANOVA	{"email": "romanovak1962@postgrespro.ru", "phone": "+70928167248"}
0005433516766	3141E3	7517 645095	ANASTASIYA DENISOVA	{"phone": "+70078966995"}
0005433516767	3141E3	9394 881910	NATALYA MOROZOVA	{"email": "morozovan_1965@postgrespro.ru", "phone": "+70873004095"}
0005433516768	56873C	6011 794325	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov-111968@postgrespro.ru", "phone": "+70718351438"}
0005433516769	04F339	7348 382062	GENNADIY KUZNECOV	{"email": "gennadiykuznecov.011965@postgrespro.ru", "phone": "+70128419468"}
0005433516770	04F339	8223 155931	NIKOLAY KUZNECOV	{"phone": "+70017946144"}
0005433516771	172BB7	2646 367103	OLGA LEBEDEVA	{"email": "lebedevao_1968@postgrespro.ru", "phone": "+70671422986"}
0005433516772	F16E1C	1250 596163	FEDOR IVANOV	{"email": "ivanov.fedor07031985@postgrespro.ru", "phone": "+70811237134"}
0005433516773	F16E1C	5970 603486	ELINA KARPOVA	{"email": "karpova-e081971@postgrespro.ru", "phone": "+70242931535"}
0005433516774	1EA1EC	2543 422970	ALEKSANDR BORISOV	{"phone": "+70650422788"}
0005433516775	1EA1EC	6062 773706	NATALYA KOROLEVA	{"phone": "+70480278220"}
0005433516776	7E61D3	6251 523005	RAFAIL SMIRNOV	{"phone": "+70684605257"}
0005433516777	00BB10	3051 053154	ANDREY DENISOV	{"phone": "+70067015447"}
0005433516778	CBB786	1259 930162	ANATOLIY ORLOV	{"phone": "+70328782563"}
0005433516779	D52E33	6102 216115	YURIY MEDVEDEV	{"email": "yuriy-medvedev-05111982@postgrespro.ru", "phone": "+70591487582"}
0005433516780	522C08	6611 726539	MARIYA KOROLEVA	{"phone": "+70765393934"}
0005433516781	93FBB8	8805 187534	ZOYA ZHUKOVA	{"email": "z-zhukova.18031977@postgrespro.ru", "phone": "+70972511445"}
0005433516782	52F986	0525 820360	IRINA GUSEVA	{"email": "iguseva-30091969@postgrespro.ru", "phone": "+70091976993"}
0005433516783	52F986	6864 122816	VLADIMIR DENISOV	{"email": "vladimir-denisov.07011975@postgrespro.ru", "phone": "+70247693456"}
0005433516784	52F986	3058 800656	ANNA ZOTOVA	{"email": "zotova-anna.1959@postgrespro.ru", "phone": "+70746195624"}
0005433516785	759C4C	3755 764171	KIRILL NIKITIN	{"phone": "+70073765845"}
0005433516786	53B35A	2086 785282	OKSANA ANDREEVA	{"email": "o-andreeva.081973@postgrespro.ru", "phone": "+70424272665"}
0005433516787	9158C3	2622 898363	IGOR BELOV	{"email": "belov_igor-12111973@postgrespro.ru", "phone": "+70254855509"}
0005433516788	FF1F55	2388 081232	MARIYA NIKOLAEVA	{"phone": "+70870271879"}
0005433516789	FF1F55	0838 626288	VALENTINA KONDRATEVA	{"email": "kondratevav.071965@postgrespro.ru", "phone": "+70677769196"}
0005433516790	5DCC47	4886 610722	NIKITA POPOV	{"phone": "+70496978699"}
0005433516791	6F8786	9625 481831	ANNA MELNIKOVA	{"phone": "+70137309274"}
0005433516792	6F8786	6701 958201	ALEVTINA KOZLOVA	{"phone": "+70376047469"}
0005433516793	806ADD	0636 474200	VIKTORIYA KISELEVA	{"email": "kiseleva-v-21061962@postgrespro.ru", "phone": "+70987044120"}
0005433516794	BCD264	4631 812052	MARINA GERASIMOVA	{"phone": "+70533086942"}
0005433516795	BCD264	3065 458379	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko_1977@postgrespro.ru", "phone": "+70383719808"}
0005433516796	8B111E	5993 050486	ANATOLIY KOZLOV	{"email": "kozlov_a_081981@postgrespro.ru", "phone": "+70007604630"}
0005433516797	DD63F2	5942 487554	ALEKSEY VLASOV	{"email": "a_vlasov101981@postgrespro.ru", "phone": "+70900360596"}
0005433516798	3B3BFC	8203 295729	EVGENIY POPOV	{"email": "popov-e.1976@postgrespro.ru", "phone": "+70706143608"}
0005433516799	3B3BFC	2985 502360	KARINA ALEKSANDROVA	{"email": "aleksandrova_k.11071966@postgrespro.ru", "phone": "+70737588861"}
0005433516800	F54625	5600 792439	TATYANA ZHUKOVA	{"email": "tatyana_zhukova1974@postgrespro.ru", "phone": "+70788039307"}
0005433516801	F54625	5993 570080	DAVID ORLOV	{"email": "david-orlov.061988@postgrespro.ru", "phone": "+70363270651"}
0005433516802	8DD748	8575 153633	LIDIYA ARKHIPOVA	{"email": "l.arkhipova.27111964@postgrespro.ru", "phone": "+70168690350"}
0005433516803	5977DF	6551 125872	OLGA AFANASEVA	{"email": "afanaseva_o-1976@postgrespro.ru", "phone": "+70522021191"}
0005433516804	BD46BE	9457 915184	SERGEY ALEKSANDROV	{"email": "aleksandrovsergey.23021970@postgrespro.ru", "phone": "+70059910356"}
0005433516805	813DFB	2312 780070	VIKTOR RODIONOV	{"email": "rodionov-v1969@postgrespro.ru", "phone": "+70001588657"}
0005433516974	78E0CC	7107 438642	DENIS FEDOTOV	{"phone": "+70271136071"}
0005433516806	25CCFB	5052 291505	TATYANA SOROKINA	{"email": "sorokinat.071966@postgrespro.ru", "phone": "+70149091829"}
0005433516807	D52450	2890 960263	VIKTORIYA TARASOVA	{"phone": "+70564419585"}
0005433516808	D52450	9294 933745	YURIY IVANOV	{"email": "ivanov-y-1974@postgrespro.ru", "phone": "+70346412785"}
0005433516809	D52450	7421 321935	TATYANA SOLOVEVA	{"email": "solovevat.10031966@postgrespro.ru", "phone": "+70910884143"}
0005433516810	D52450	8222 821132	SERGEY MATVEEV	{"email": "s-matveev031966@postgrespro.ru", "phone": "+70891671143"}
0005433516811	986ABB	2183 009184	OLGA KOVALEVA	{"phone": "+70267601961"}
0005433516812	9095A6	4960 740517	DENIS EGOROV	{"email": "denis-egorov-1967@postgrespro.ru", "phone": "+70812707165"}
0005433516813	5B315A	9464 619491	ELENA SEMENOVA	{"email": "semenovaelena-091972@postgrespro.ru", "phone": "+70597307893"}
0005433516814	1E9ED1	3412 452732	YULIYA MALYSHEVA	{"phone": "+70951998905"}
0005433516815	9DEE26	7388 139105	ALEKSEY FROLOV	{"email": "frolov-aleksey-28061975@postgrespro.ru", "phone": "+70020588804"}
0005433516816	9DEE26	6680 290353	MARIYA PAVLOVA	{"phone": "+70130175461"}
0005433516817	538FBF	8295 115588	FEDOR MOROZOV	{"phone": "+70545153843"}
0005433516818	538FBF	0132 923583	RAISA MEDVEDEVA	{"phone": "+70237359258"}
0005433516819	98387A	8080 306147	DMITRIY EGOROV	{"email": "egorovd-011973@postgrespro.ru", "phone": "+70637382572"}
0005433516820	B6C2E5	3551 196873	GALINA FILATOVA	{"phone": "+70468940509"}
0005433516821	B6C2E5	8379 614910	NINA BARANOVA	{"phone": "+70872589112"}
0005433516822	B2B8EA	9536 699326	LEONID KULIKOV	{"email": "leonid-kulikov_061975@postgrespro.ru", "phone": "+70894470115"}
0005433516823	CA1E5A	4828 290287	RAVIL NIKITIN	{"email": "nikitin_ravil_081967@postgrespro.ru", "phone": "+70032381928"}
0005433516824	1E26C4	4820 217034	VLADISLAV SMIRNOV	{"email": "v-smirnov-1983@postgrespro.ru", "phone": "+70250914806"}
0005433516825	1E26C4	5800 614115	TATYANA VLASOVA	{"email": "t.vlasova1972@postgrespro.ru", "phone": "+70534723253"}
0005433516826	1E26C4	5620 124063	EVGENIY MELNIKOV	{"phone": "+70647808763"}
0005433516827	CC778D	6081 778876	ELENA NOVIKOVA	{"phone": "+70482000124"}
0005433516828	56446B	8683 429646	IRINA ORLOVA	{"email": "irina.orlova.1956@postgrespro.ru", "phone": "+70189619436"}
0005433516829	56446B	7780 238578	SVETLANA VASILEVA	{"email": "svasileva_1971@postgrespro.ru", "phone": "+70619274387"}
0005433516830	85F5A2	6843 473451	SERGEY KONOVALOV	{"phone": "+70537189645"}
0005433516831	85F5A2	9753 292249	SVETLANA MEDVEDEVA	{"phone": "+70411053258"}
0005433516832	E43DB6	7646 737739	IGOR MOISEEV	{"phone": "+70815147703"}
0005433516833	E43DB6	8517 262537	DMITRIY SEMENOV	{"phone": "+70325238723"}
0005433516834	2859FA	1257 214612	SERGEY AFANASEV	{"phone": "+70145972534"}
0005433516835	2859FA	8605 424840	TATYANA ERMAKOVA	{"email": "tatyana_ermakova011961@postgrespro.ru", "phone": "+70100289604"}
0005433516836	5CCE4B	7958 011192	VYACHESLAV KUZNECOV	{"phone": "+70781609781"}
0005433516837	04E66D	5418 810606	ALEKSANDR ROMANOV	{"email": "a_romanov.17031960@postgrespro.ru", "phone": "+70783257191"}
0005433516838	0C78F2	3750 452118	VALENTINA DANILOVA	{"phone": "+70916199923"}
0005433516839	2336B9	3885 915029	ALLA SCHERBAKOVA	{"email": "a_scherbakova.29051971@postgrespro.ru", "phone": "+70394877742"}
0005433516840	A058EE	7092 138632	RIMMA SOKOLOVA	{"phone": "+70792025172"}
0005433516841	EAE455	6959 994123	VIKTOR NIKITIN	{"email": "v-nikitin031970@postgrespro.ru", "phone": "+70745901087"}
0005433516842	EAE455	0857 860995	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr-1966@postgrespro.ru", "phone": "+70655509015"}
0005433516843	B0F092	5131 459002	LEONID SIDOROV	{"phone": "+70477869911"}
0005433516844	DD8729	0626 351005	ALEKSANDR ZHUKOV	{"phone": "+70065855066"}
0005433516845	CD3964	9353 300635	ELENA SERGEEVA	{"phone": "+70910611419"}
0005433516846	CD3964	1169 399686	VITALIY BORISOV	{"email": "vitaliyborisov.14071986@postgrespro.ru", "phone": "+70427439386"}
0005433516847	CD3964	2860 920086	MARAT VASILEV	{"email": "vasilev.m.041972@postgrespro.ru", "phone": "+70816789113"}
0005433516848	22E3FA	5690 097088	NATALYA EGOROVA	{"email": "natalya.egorova_071975@postgrespro.ru", "phone": "+70982356548"}
0005433516849	22E3FA	8442 640819	ROMAN ISAEV	{"email": "roman-isaev02081976@postgrespro.ru", "phone": "+70350032069"}
0005433516850	85F91B	2176 458902	ANTONINA IVANOVA	{"email": "antoninaivanova10101968@postgrespro.ru", "phone": "+70882007933"}
0005433516851	7EDF04	2926 874563	VALERIY GORBUNOV	{"phone": "+70037388154"}
0005433516852	7EDF04	4574 502526	ALEKSANDR GUSEV	{"phone": "+70438750658"}
0005433516853	5F97FE	5189 465657	IRINA PAVLOVA	{"phone": "+70595102257"}
0005433516854	5F97FE	0536 846592	ANATOLIY MATVEEV	{"email": "a-matveev_19061976@postgrespro.ru", "phone": "+70466781802"}
0005433516855	32CBBE	1613 998081	SERGEY SOROKIN	{"email": "sorokins_1979@postgrespro.ru", "phone": "+70141380532"}
0005433516856	15FC79	8258 182256	VASILIY MEDVEDEV	{"email": "v.medvedev_111975@postgrespro.ru", "phone": "+70127373581"}
0005433516857	218D9C	3161 844654	ANASTASIYA NESTEROVA	{"email": "nesterova.anastasiya1972@postgrespro.ru", "phone": "+70685513805"}
0005433516858	52021E	7967 918188	SERGEY SCHERBAKOV	{"email": "s.scherbakov_061965@postgrespro.ru", "phone": "+70099454996"}
0005433516859	55B012	3847 059766	ALEKSANDR ZAKHAROV	{"phone": "+70746120688"}
0005433516860	A9FBEE	1440 099987	NAIL KAZAKOV	{"phone": "+70158678895"}
0005433516861	A9FBEE	7487 393089	NAZAR ZHUKOV	{"email": "zhukov-nazar_1964@postgrespro.ru", "phone": "+70753808516"}
0005433516862	1505D0	7411 810095	KRISTINA MOROZOVA	{"email": "morozova.kristina_121961@postgrespro.ru", "phone": "+70451131835"}
0005433516863	CDDA32	0751 698203	IRINA NIKITINA	{"phone": "+70534200471"}
0005433516864	D6FEE3	5147 574533	PAVEL MOROZOV	{"phone": "+70229728234"}
0005433516865	D6FEE3	7937 863330	TATYANA ZAKHAROVA	{"phone": "+70496055798"}
0005433516866	B9FC1D	3459 913301	EKATERINA MIKHAYLOVA	{"email": "mikhaylova.ekaterina.1979@postgrespro.ru", "phone": "+70515807758"}
0005433516867	B9FC1D	1073 525911	VLADISLAV ZHUKOV	{"phone": "+70684000795"}
0005433516868	C64D7F	3802 277877	DMITRIY ABRAMOV	{"email": "dmitriy.abramov_16061981@postgrespro.ru", "phone": "+70184358247"}
0005433516869	ED25D6	6434 313647	GALINA DMITRIEVA	{"email": "g_dmitrieva_1953@postgrespro.ru", "phone": "+70202999473"}
0005433516870	ED25D6	5111 950238	ROMAN CHERNOV	{"email": "r.chernov-10111973@postgrespro.ru", "phone": "+70151234396"}
0005433516871	0BB43F	7552 147389	SERGEY DENISOV	{"email": "sergey-denisov.081972@postgrespro.ru", "phone": "+70164882385"}
0005433516872	C03460	3617 588555	ILDAR VOROBEV	{"email": "vorobev-ildar_011971@postgrespro.ru", "phone": "+70072023871"}
0005433516873	0B9084	1973 213889	PELAGEYA YUDINA	{"phone": "+70688006190"}
0005433516874	0B9084	0199 098571	OLEG KUZNECOV	{"phone": "+70895814152"}
0005433516875	06A224	0883 273412	GRIGORIY SCHERBAKOV	{"phone": "+70924471848"}
0005433516876	06A224	0814 047365	ELENA KARPOVA	{"email": "elenakarpova.111963@postgrespro.ru", "phone": "+70368738396"}
0005433516877	3EAA36	0828 204718	DAVID KUDRYASHOV	{"phone": "+70149788896"}
0005433516878	B1E9CC	2974 793466	MARIYA ZHUKOVA	{"phone": "+70646774738"}
0005433516879	B1E9CC	1022 112908	MARIYA BARANOVA	{"phone": "+70600332592"}
0005433516880	07F6A9	2054 881362	VLADIMIR GRIGOREV	{"phone": "+70799330188"}
0005433516881	07F6A9	5207 879579	ALEKSEY KUZNECOV	{"phone": "+70722444553"}
0005433516882	D1BB34	0823 612938	NATALIYA NESTEROVA	{"email": "nataliya-nesterova-1969@postgrespro.ru", "phone": "+70415630185"}
0005433516883	D1BB34	3589 593541	LYUBOV POTAPOVA	{"phone": "+70070909054"}
0005433516884	EC23EE	3812 799067	ARTEM SEMENOV	{"email": "artemsemenov06071967@postgrespro.ru", "phone": "+70433226690"}
0005433516885	EC23EE	2265 009962	LIDIYA PAVLOVA	{"phone": "+70893880756"}
0005433516886	39ED88	7741 647523	TAMARA GORBUNOVA	{"phone": "+70773422213"}
0005433516887	22195D	8432 097927	ALEKSANDR PETROV	{"phone": "+70091445909"}
0005433516888	BCC70D	7407 914661	VYACHESLAV KAZAKOV	{"phone": "+70681886464"}
0005433516889	BCC70D	8622 762276	DENIS SIDOROV	{"phone": "+70980283065"}
0005433516890	BC0CDA	3731 489774	MAKSIM GRIGOREV	{"phone": "+70644492887"}
0005433516891	CD2AD1	8137 679301	DMITRIY FEDOROV	{"email": "fedorov_d.1978@postgrespro.ru", "phone": "+70933014388"}
0005433516892	CD2AD1	6252 863607	OLGA ISAEVA	{"phone": "+70636027817"}
0005433516893	3AACF9	6336 696144	DMITRIY MARTYNOV	{"phone": "+70072077205"}
0005433516894	2A888F	5676 670007	ALEKSEY NIKITIN	{"email": "nikitin_aleksey-1981@postgrespro.ru", "phone": "+70108435216"}
0005433516895	50A6CE	3896 208363	TATYANA SMIRNOVA	{"email": "tatyana.smirnova1964@postgrespro.ru", "phone": "+70512026865"}
0005433516896	50A6CE	0411 012776	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova_1976@postgrespro.ru", "phone": "+70017334925"}
0005433516897	74AE46	5840 028090	ROMAN TARASOV	{"phone": "+70636915909"}
0005433516898	A1A9B5	7135 547053	SERGEY IVANOV	{"email": "sergey-ivanov1962@postgrespro.ru", "phone": "+70902012250"}
0005433516899	BF9C87	9841 083790	DARINA SEMENOVA	{"email": "d_semenova121974@postgrespro.ru", "phone": "+70709038926"}
0005433516900	50E207	2538 411103	VLADIMIR SCHERBAKOV	{"email": "scherbakovv.10041962@postgrespro.ru", "phone": "+70696560830"}
0005433516901	637F5A	4940 744262	IVAN MIKHAYLOV	{"email": "ivan_mikhaylov.26031970@postgrespro.ru", "phone": "+70761123775"}
0005433516902	C34722	2823 141328	OKSANA VASILEVA	{"phone": "+70934962150"}
0005433516903	BCED59	7444 549047	LARISA IVANOVA	{"email": "ivanova_l091958@postgrespro.ru", "phone": "+70438169379"}
0005433516904	A7E85C	3366 119256	EKATERINA AKIMOVA	{"phone": "+70247664470"}
0005433516905	E1512B	5712 805288	VLADIMIR ALEKSEEV	{"phone": "+70774547341"}
0005433516906	F19F49	5362 156833	VERA KOZLOVA	{"phone": "+70807887296"}
0005433516907	F19F49	3618 032932	GENNADIY MIKHAYLOV	{"email": "mikhaylov_g_13091972@postgrespro.ru", "phone": "+70694677640"}
0005433516908	2BBD1B	7383 297196	ZOYA ANTONOVA	{"phone": "+70796576617"}
0005433516909	A772DC	3745 045909	MARAT ABRAMOV	{"email": "maratabramov-06051971@postgrespro.ru", "phone": "+70442110281"}
0005433516910	90AECC	0018 420659	YURIY KRASNOV	{"phone": "+70300050101"}
0005433516911	90AECC	6232 468854	ARTEM SIDOROV	{"email": "sidorov-a091970@postgrespro.ru", "phone": "+70727658226"}
0005433516912	2A433E	2738 840995	MARINA ISAEVA	{"phone": "+70423365798"}
0005433516913	2DC36B	2002 399616	RUFIYA CHERNOVA	{"phone": "+70937743981"}
0005433516914	768FC3	9719 493105	MAKSIM ABRAMOV	{"phone": "+70125794051"}
0005433516915	213A66	0185 649657	LYUDMILA NIKITINA	{"email": "nikitina-l-14051980@postgrespro.ru", "phone": "+70379851414"}
0005433516916	10CAC3	3133 458625	IRINA TROFIMOVA	{"email": "i.trofimova19121965@postgrespro.ru", "phone": "+70817507418"}
0005433516917	54EA48	5541 124137	ELENA CHERNOVA	{"email": "chernova-elena031975@postgrespro.ru", "phone": "+70103002402"}
0005433516918	54EA48	1448 172536	RUDOLF DMITRIEV	{"email": "dmitriev-r05051966@postgrespro.ru", "phone": "+70858171120"}
0005433516919	DC2684	9676 440396	LYUBOV STEPANOVA	{"email": "lyubov.stepanova-1972@postgrespro.ru", "phone": "+70884578633"}
0005433516920	DC2684	9148 356712	PAVEL ORLOV	{"email": "orlov_pavel-1967@postgrespro.ru", "phone": "+70211427771"}
0005433516921	AC01E2	7852 900594	SVETLANA AFANASEVA	{"email": "afanaseva.s12111969@postgrespro.ru", "phone": "+70935890002"}
0005433516922	851AAE	3872 210946	VALENTINA RODIONOVA	{"phone": "+70299670606"}
0005433516923	851AAE	4229 712537	VLADIMIR NAZAROV	{"email": "nazarov_v-091975@postgrespro.ru", "phone": "+70441601916"}
0005433516924	681277	3994 669856	MARINA MAKSIMOVA	{"email": "maksimova.marina-05111970@postgrespro.ru", "phone": "+70472687905"}
0005433516925	9634AD	6688 449186	ARTEM SOROKIN	{"phone": "+70026860680"}
0005433516926	E31586	6380 954430	TATYANA MOROZOVA	{"email": "tatyana.morozova.1970@postgrespro.ru", "phone": "+70594649556"}
0005433516927	C2D526	6340 393805	OKSANA GUSEVA	{"phone": "+70888170691"}
0005433516928	C2D526	5780 227181	SVETLANA SOROKINA	{"email": "sorokinas_1970@postgrespro.ru", "phone": "+70497628521"}
0005433516929	E95309	0736 689139	OLGA IVANOVA	{"email": "olgaivanova21071964@postgrespro.ru", "phone": "+70538909288"}
0005433516930	EF45C6	9043 203240	DIANA LUKYANOVA	{"phone": "+70625745268"}
0005433516931	EF45C6	9899 026532	ANDREY BARANOV	{"phone": "+70602983247"}
0005433516932	21080D	6282 795892	POLINA NAZAROVA	{"phone": "+70820946470"}
0005433516933	FF8E84	0102 919169	IRINA SAVELEVA	{"email": "saveleva.irina-1980@postgrespro.ru", "phone": "+70359013153"}
0005433516934	379837	4907 222299	PAVEL NIKITIN	{"email": "p_nikitin.061977@postgrespro.ru", "phone": "+70170871048"}
0005433516935	379837	9720 002572	ALEKSANDR KAZAKOV	{"phone": "+70789088154"}
0005433516936	A5E7A8	2225 406569	SERGEY MOROZOV	{"email": "morozovsergey_17101973@postgrespro.ru", "phone": "+70862907793"}
0005433516937	C9E9F3	1194 592519	TATYANA VOLKOVA	{"phone": "+70729689820"}
0005433516938	C9E9F3	7277 531502	MIKHAIL DAVYDOV	{"email": "mdavydov1978@postgrespro.ru", "phone": "+70680620194"}
0005433516939	7F985E	5865 394589	NADEZHDA NIKOLAEVA	{"phone": "+70170141014"}
0005433516940	81454B	0913 622068	YURIY VOLKOV	{"phone": "+70829552631"}
0005433516941	43DE89	2340 531373	RAISA ZAKHAROVA	{"phone": "+70356380489"}
0005433516942	43DE89	9892 701390	DMITRIY MIKHAYLOV	{"email": "mikhaylov-d1972@postgrespro.ru", "phone": "+70731853272"}
0005433516943	28A8C2	5862 223777	YULIYA VOROBEVA	{"phone": "+70388481997"}
0005433516944	1262BA	9084 749109	VIKTOR SOKOLOV	{"email": "sokolov.viktor_1977@postgrespro.ru", "phone": "+70023130290"}
0005433516945	1262BA	3425 354786	NIKOLAY YAKOVLEV	{"phone": "+70276636433"}
0005433516946	1024FF	0637 914520	BORIS ALEKSEEV	{"email": "boris-alekseev.071978@postgrespro.ru", "phone": "+70428284093"}
0005433516947	A5C221	7083 848319	PAVEL TIMOFEEV	{"phone": "+70421015046"}
0005433516948	2480A7	2361 436704	IVAN POPOV	{"email": "ipopov.1968@postgrespro.ru", "phone": "+70473202334"}
0005433516949	934EEA	8906 739831	ALEKSEY SOROKIN	{"email": "a.sorokin.1969@postgrespro.ru", "phone": "+70927906688"}
0005433517012	54599D	3509 312450	NIKITA KOZLOV	{"phone": "+70997874251"}
0005433516950	1E534E	1942 162352	LILIYA SMIRNOVA	{"email": "smirnova-liliya.041971@postgrespro.ru", "phone": "+70743568121"}
0005433516951	72F8F9	5072 242112	TATYANA ZAYCEVA	{"phone": "+70080690388"}
0005433516952	46A310	5725 832601	KONSTANTIN NAZAROV	{"phone": "+70075640635"}
0005433516953	2FE0EC	9034 387162	SOFIYA EFIMOVA	{"email": "efimova_s_25061964@postgrespro.ru", "phone": "+70870351935"}
0005433516954	E04F07	2389 695107	ILGIZ IVANOV	{"email": "ilgiz_ivanov.12051964@postgrespro.ru", "phone": "+70901493855"}
0005433516955	77B3A2	2902 611967	DMITRIY KONOVALOV	{"email": "konovalov_dmitriy.011978@postgrespro.ru", "phone": "+70705122401"}
0005433516956	6C1AE7	0999 571245	VALENTINA KUZNECOVA	{"phone": "+70336578180"}
0005433516957	6C1AE7	7181 355469	OKSANA NAZAROVA	{"phone": "+70724041988"}
0005433516958	D3B791	2124 210629	MIKHAIL KOZLOV	{"phone": "+70619435777"}
0005433516959	C62B13	5907 721024	MIKHAIL GERASIMOV	{"phone": "+70457976747"}
0005433516960	80450D	8233 201195	KARIM GUSEV	{"email": "karim.gusev_121977@postgrespro.ru", "phone": "+70930661188"}
0005433516961	3B34FD	4805 646418	VALERIYA NIKIFOROVA	{"phone": "+70440070288"}
0005433516962	6E4A94	3076 398094	RAISA MALYSHEVA	{"phone": "+70438456162"}
0005433516963	66ACA4	5165 009209	ANATOLIY ALEKSEEV	{"email": "anatoliy_alekseev.1975@postgrespro.ru", "phone": "+70656772522"}
0005433516964	66ACA4	3799 352429	NIKOLAY SHEVCHENKO	{"email": "n.shevchenko23061964@postgrespro.ru", "phone": "+70169362809"}
0005433516965	66ACA4	4224 573555	VLADIMIR NIKOLAEV	{"phone": "+70053983596"}
0005433516966	3F4DA3	8300 372594	MIKHAIL FILIPPOV	{"phone": "+70676343214"}
0005433516967	05554B	5610 860348	MAKSIM EGOROV	{"email": "egorov.maksim.051970@postgrespro.ru", "phone": "+70673448258"}
0005433516968	319916	3755 474759	VERA BORISOVA	{"email": "veraborisova111969@postgrespro.ru", "phone": "+70846264732"}
0005433516969	319916	7133 877944	MARIYA PAVLOVA	{"email": "m_pavlova1978@postgrespro.ru", "phone": "+70701461894"}
0005433516970	8F74B0	4602 917391	EVGENIY IVANOV	{"phone": "+70469077839"}
0005433516971	5B4EA4	7139 971823	GENNADIY ZHURAVLEV	{"email": "zhuravlevg1968@postgrespro.ru", "phone": "+70115828450"}
0005433516972	5B4EA4	5068 685630	ALEVTINA KOROLEVA	{"phone": "+70858968566"}
0005433516973	1C9C31	4106 934947	TATYANA ARKHIPOVA	{"phone": "+70991799714"}
0005433516975	78E0CC	3616 489701	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov_081967@postgrespro.ru", "phone": "+70986503869"}
0005433516976	78E0CC	1091 503675	TATYANA RYABOVA	{"email": "t.ryabova30051974@postgrespro.ru", "phone": "+70514965202"}
0005433516977	78E0CC	7845 439911	VIKTOR VLASOV	{"email": "vlasov.viktor.1979@postgrespro.ru", "phone": "+70074883915"}
0005433516978	6EB548	7778 807712	DMITRIY STEPANOV	{"phone": "+70033531593"}
0005433516979	3FA91F	7149 095008	TATYANA FEDOROVA	{"email": "fedorovat.25021971@postgrespro.ru", "phone": "+70600925710"}
0005433516980	3FA91F	4950 813590	VLADIMIR MELNIKOV	{"phone": "+70463997992"}
0005433516981	0AD62C	7380 851959	IGOR VLASOV	{"email": "vlasov_i.09021975@postgrespro.ru", "phone": "+70759628367"}
0005433516982	85B630	8045 935557	TATYANA VASILEVA	{"phone": "+70071846492"}
0005433516983	3C5619	2398 319762	VALENTINA MOISEEVA	{"phone": "+70510666247"}
0005433516984	3C5619	6602 866057	MARGARITA POPOVA	{"phone": "+70039423514"}
0005433516985	FE3040	2310 459750	ALEKSEY MOISEEV	{"email": "a-moiseev-1975@postgrespro.ru", "phone": "+70657932705"}
0005433516986	FE3040	4310 307426	ANDREY KAZAKOV	{"phone": "+70959455675"}
0005433516987	3735DE	2911 633568	VSEVOLOD GERASIMOV	{"phone": "+70844095136"}
0005433516988	0A0714	4771 771360	ANDREY NIKOLAEV	{"email": "a-nikolaev_30111967@postgrespro.ru", "phone": "+70647409797"}
0005433516989	EF1C8B	4540 335782	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay-041972@postgrespro.ru", "phone": "+70126777188"}
0005433516990	EF1C8B	1698 109373	ANNA MIKHAYLOVA	{"email": "mikhaylova-anna071967@postgrespro.ru", "phone": "+70428150327"}
0005433516991	2831FC	5304 773626	ANASTASIYA PETROVA	{"phone": "+70612720459"}
0005433516992	29E95C	0849 041518	EVA KAZAKOVA	{"email": "kazakova_e.121976@postgrespro.ru", "phone": "+70713022490"}
0005433516993	6D9577	5528 823835	GALINA IVANOVA	{"email": "g.ivanova_1973@postgrespro.ru", "phone": "+70735766597"}
0005433516994	6D9577	8119 931945	SVETLANA TARASOVA	{"email": "svetlana_tarasova-15051966@postgrespro.ru", "phone": "+70844008713"}
0005433516995	6D9577	5866 638009	NATALYA KOMAROVA	{"phone": "+70085393564"}
0005433516996	C3D6F2	5626 451161	SERGEY ALEKSANDROV	{"email": "aleksandrov_s1960@postgrespro.ru", "phone": "+70013462605"}
0005433516997	8324C5	0878 213371	MIKHAIL GUSEV	{"email": "gusev-m-1981@postgrespro.ru", "phone": "+70205417520"}
0005433516998	8324C5	2629 576241	NADEZHDA NIKOLAEVA	{"phone": "+70540028582"}
0005433516999	B85198	6644 302233	VLADIMIR PETROV	{"phone": "+70486792969"}
0005433517000	B85198	6492 890767	PAVEL BORISOV	{"phone": "+70515546377"}
0005433517001	B85198	2148 432189	DARYA FEDOROVA	{"phone": "+70355181559"}
0005433517002	9DFECF	7081 686221	EVGENIY SEMENOV	{"phone": "+70186708770"}
0005433517003	BAAD61	8150 091823	ANATOLIY KUZNECOV	{"phone": "+70170478575"}
0005433517004	BFE5FB	2351 343892	EVGENIY EGOROV	{"phone": "+70267599843"}
0005433517005	6F8D57	4352 553590	EKATERINA ANDREEVA	{"phone": "+70846857299"}
0005433517006	5F9E13	7397 516493	ANATOLIY KUZMIN	{"email": "kuzmin_anatoliy_20061976@postgrespro.ru", "phone": "+70705701047"}
0005433517007	7F598D	9636 999981	VLADIMIR GUSEV	{"email": "gusev.vladimir.101964@postgrespro.ru", "phone": "+70566358600"}
0005433517008	7F598D	7538 500927	ALEKSANDR ILIN	{"phone": "+70391453144"}
0005433517009	FBAAF1	3304 750899	NINA SIDOROVA	{"phone": "+70951596360"}
0005433517010	52D8FC	0844 258090	ANDREY KULIKOV	{"email": "kulikov-andrey-021970@postgrespro.ru", "phone": "+70779077044"}
0005433517011	52D8FC	0918 839987	DMITRIY STEPANOV	{"phone": "+70289797651"}
0005433517013	216CAB	6189 600627	PAVEL STEPANOV	{"email": "stepanovp1976@postgrespro.ru", "phone": "+70251139916"}
0005433517014	216CAB	2962 173057	ALENA GERASIMOVA	{"email": "gerasimova_alena091961@postgrespro.ru", "phone": "+70389307845"}
0005433517015	FCA693	2555 503867	ALEKSANDR ABRAMOV	{"phone": "+70412130790"}
0005433517016	FCA693	5179 369561	DARYA PETROVA	{"email": "petrovadarya_1969@postgrespro.ru", "phone": "+70182378295"}
0005433517017	96BDEB	3758 030971	KONSTANTIN ANDREEV	{"email": "kandreev_1976@postgrespro.ru", "phone": "+70229620332"}
0005433517018	96BDEB	5072 575449	NATALYA ZHUKOVA	{"phone": "+70059591262"}
0005433517019	0D282A	2286 676204	ANTONINA TARASOVA	{"email": "antoninatarasova16051970@postgrespro.ru", "phone": "+70018198751"}
0005433517020	BFE948	5305 182081	ELENA OSIPOVA	{"email": "elena_osipova101973@postgrespro.ru", "phone": "+70221559380"}
0005433517021	4771AB	1903 179934	DMITRIY GRIGOREV	{"phone": "+70285602008"}
0005433517022	A5271E	7930 682478	EKATERINA OSIPOVA	{"email": "osipova.e.101965@postgrespro.ru", "phone": "+70233710381"}
0005433517023	E1AF2A	4068 799721	DMITRIY OSIPOV	{"email": "dmitriy-osipov-1966@postgrespro.ru", "phone": "+70194148280"}
0005433517024	727D1C	2777 479925	SERGEY MIKHAYLOV	{"phone": "+70226411436"}
0005433517025	D0ABD2	0619 021852	DMITRIY MAKAROV	{"phone": "+70600083686"}
0005433517026	F6B2EB	6646 240607	TATYANA ALEKSEEVA	{"phone": "+70882070149"}
0005433517027	F6B2EB	7942 974049	GALINA GAVRILOVA	{"email": "g-gavrilova.021968@postgrespro.ru", "phone": "+70068998518"}
0005433517028	FC726C	3210 764284	TAMARA VLASOVA	{"email": "t_vlasova17051978@postgrespro.ru", "phone": "+70701463532"}
0005433517029	FC726C	3416 224764	VERA KISELEVA	{"phone": "+70140924203"}
0005433517030	45366D	3062 232348	ALEKSEY MIKHAYLOV	{"phone": "+70089892742"}
0005433517144	989F9B	0865 253953	GALINA MAKSIMOVA	{"phone": "+70604835392"}
0005433517031	45366D	4960 451398	SVETLANA NOVIKOVA	{"email": "novikovasvetlana17081974@postgrespro.ru", "phone": "+70836135292"}
0005433517032	45366D	8304 439565	NATALYA NAZAROVA	{"email": "nazarovan.16061977@postgrespro.ru", "phone": "+70632058226"}
0005433517033	4722CF	1402 197837	NADEZHDA NAZAROVA	{"email": "nazarova.n-091977@postgrespro.ru", "phone": "+70702783450"}
0005433517034	14E960	5946 021846	IGOR TARASOV	{"phone": "+70199559780"}
0005433517035	DE9036	9897 759992	ANATOLIY FOMIN	{"phone": "+70676089661"}
0005433517036	A72DCD	6543 486779	IRINA SERGEEVA	{"email": "sergeeva_irina.1980@postgrespro.ru", "phone": "+70063943364"}
0005433517037	B32304	5358 327102	IVAN VLASOV	{"phone": "+70143350881"}
0005433517038	B32304	5983 884380	ARTEM ALEKSEEV	{"email": "alekseev_a061972@postgrespro.ru", "phone": "+70498954840"}
0005433517039	1EE28A	3247 363919	VIKTOR POPOV	{"email": "v.popov21061963@postgrespro.ru", "phone": "+70222052113"}
0005433517040	32A3EF	5793 377924	OLGA NIKITINA	{"phone": "+70773148918"}
0005433517041	32A3EF	1851 268178	EKATERINA ORLOVA	{"phone": "+70673352197"}
0005433517042	32A3EF	7543 805395	ANATOLIY ALEKSANDROV	{"phone": "+70760757398"}
0005433517043	2DC931	9638 188361	MARIYA STEPANOVA	{"phone": "+70510875706"}
0005433517044	2DC931	8147 725350	OKSANA KUZNECOVA	{"email": "oksanakuznecova_021982@postgrespro.ru", "phone": "+70326656318"}
0005433517045	67E3A2	4695 373866	ANDREY KONOVALOV	{"email": "andrey.konovalov.06051974@postgrespro.ru", "phone": "+70960548805"}
0005433517046	67E3A2	1641 304503	IVAN SOROKIN	{"email": "ivan-sorokin.1971@postgrespro.ru", "phone": "+70487554282"}
0005433517047	C2DA62	7577 423441	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov.1961@postgrespro.ru", "phone": "+70958783392"}
0005433517048	A3263B	4914 584473	VLADIMIR ANDREEV	{"email": "vladimirandreev_021972@postgrespro.ru", "phone": "+70422488174"}
0005433517049	CA32FB	1934 479540	YULIYA GAVRILOVA	{"email": "gavrilova.y1982@postgrespro.ru", "phone": "+70723407309"}
0005433517050	0B3E92	8198 564246	ELENA CHERNOVA	{"email": "chernovae-041976@postgrespro.ru", "phone": "+70073388385"}
0005433517051	032CD1	2285 703541	MARINA MAKAROVA	{"phone": "+70510642151"}
0005433517052	032CD1	5503 799362	LIDIYA MOROZOVA	{"email": "l.morozova17081969@postgrespro.ru", "phone": "+70463173940"}
0005433517053	F9410A	6459 738332	ALEKSANDR ROMANOV	{"email": "romanova_091968@postgrespro.ru", "phone": "+70504684660"}
0005433517054	F9410A	9870 163904	ROMAN SMIRNOV	{"email": "rsmirnov-23031973@postgrespro.ru", "phone": "+70196778024"}
0005433517055	ADB39D	7093 847464	SOFIYA IVANOVA	{"email": "ivanova_sofiya05031975@postgrespro.ru", "phone": "+70522506753"}
0005433517056	ADB39D	5931 907649	MARIYA POPOVA	{"email": "popovamariya_1982@postgrespro.ru", "phone": "+70927824023"}
0005433517057	ADB39D	5721 565275	YURIY FEDOROV	{"phone": "+70433943546"}
0005433517058	5EFBF2	8091 987535	ANISA LEBEDEVA	{"email": "lebedeva_a.111957@postgrespro.ru", "phone": "+70077826785"}
0005433517059	5EFBF2	8839 373343	MARIYA MATVEEVA	{"email": "mariyamatveeva.1975@postgrespro.ru", "phone": "+70809973776"}
0005433517060	34165D	4074 711717	KIRILL PAVLOV	{"phone": "+70691385726"}
0005433517061	34165D	8041 695830	ARTEM ZHUKOV	{"email": "zhukov-a_25101971@postgrespro.ru", "phone": "+70323609273"}
0005433517062	34165D	2207 466338	MIKHAIL BARANOV	{"email": "baranov_mikhail_091978@postgrespro.ru", "phone": "+70661410004"}
0005433517063	9C315C	8886 213420	SERGEY SAVELEV	{"phone": "+70246256168"}
0005433517064	9C315C	9823 619938	VASILIY MOISEEV	{"phone": "+70038211732"}
0005433517065	83E4A4	6216 788509	VERA SMIRNOVA	{"email": "vera-smirnova07021975@postgrespro.ru", "phone": "+70246478776"}
0005433517066	83E4A4	7910 429797	SERGEY FEDOROV	{"email": "s.fedorov.011972@postgrespro.ru", "phone": "+70682392712"}
0005433517067	E550C1	5252 482637	ALEKSEY FEDOTOV	{"phone": "+70719997360"}
0005433517068	B3ED8C	5266 963437	VLADIMIR GORBUNOV	{"phone": "+70174815971"}
0005433517069	BFE275	9557 677695	MIKHAIL IVANOV	{"phone": "+70508246004"}
0005433517070	E6B97F	5901 140829	IRINA MOROZOVA	{"phone": "+70708255930"}
0005433517071	E6B97F	9906 316606	SERGEY KUZNECOV	{"email": "sergey-kuznecov-031965@postgrespro.ru", "phone": "+70517763541"}
0005433517072	6758A0	6826 832308	YULIYA DMITRIEVA	{"email": "yuliya_dmitrieva111982@postgrespro.ru", "phone": "+70610460360"}
0005433517073	6758A0	0411 047079	EKATERINA ZHUKOVA	{"phone": "+70059971940"}
0005433517074	FFFBC6	9908 799387	NATALYA KUZMINA	{"email": "kuzmina.natalya-071986@postgrespro.ru", "phone": "+70682391848"}
0005433517075	B6FBF0	9802 553734	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov_1966@postgrespro.ru", "phone": "+70458468001"}
0005433517076	418AED	5217 771168	ELENA MEDVEDEVA	{"phone": "+70785698432"}
0005433517077	418AED	9279 808879	VLADIMIR MIRONOV	{"phone": "+70021698504"}
0005433517078	5EA3DE	4249 588002	YURIY PAVLOV	{"phone": "+70267335955"}
0005433517079	5EA3DE	6947 049779	NATALYA POPOVA	{"email": "natalyapopova-1970@postgrespro.ru", "phone": "+70683028158"}
0005433517080	034758	2098 747959	YURIY VOLKOV	{"phone": "+70934284274"}
0005433517081	903A10	3983 616939	TATYANA SCHERBAKOVA	{"phone": "+70504616768"}
0005433517082	903A10	1804 212546	SALAVAT TIKHONOV	{"email": "salavat_tikhonov_1985@postgrespro.ru", "phone": "+70989376132"}
0005433517083	65065D	2731 824844	ANTONINA MATVEEVA	{"email": "a_matveeva_041963@postgrespro.ru", "phone": "+70565048144"}
0005433517084	65065D	4968 330632	VIKTOR NAZAROV	{"phone": "+70717219480"}
0005433517085	16EAD6	1891 990457	OLGA KUZNECOVA	{"phone": "+70682578995"}
0005433517086	AF5F3E	9759 420795	ALEKSEY IVANOV	{"email": "ivanov-aleksey061960@postgrespro.ru", "phone": "+70873329869"}
0005433517087	AF5F3E	4874 675276	EKATERINA RYABOVA	{"email": "e-ryabova_12101985@postgrespro.ru", "phone": "+70366937027"}
0005433517088	E59800	3735 584154	PAVEL SOLOVEV	{"phone": "+70601683922"}
0005433517089	E59800	8113 257842	ANTON BARANOV	{"email": "baranov-anton1974@postgrespro.ru", "phone": "+70051476726"}
0005433517090	169890	7824 606181	ALEKSEY NAZAROV	{"phone": "+70993306790"}
0005433517091	DEEAF0	8817 952821	ILYA EGOROV	{"email": "i.egorov061977@postgrespro.ru", "phone": "+70388286808"}
0005433517092	389FA1	8246 989679	VLADIMIR ZAKHAROV	{"email": "v-zakharov.26071968@postgrespro.ru", "phone": "+70652514834"}
0005433517093	93C3D1	2954 745460	SERGEY ILIN	{"email": "ilinsergey_09111973@postgrespro.ru", "phone": "+70738742818"}
0005433517094	48F574	1556 104036	VLADIMIR VOLKOV	{"email": "volkov-vladimir_07101975@postgrespro.ru", "phone": "+70498128191"}
0005433517095	48F574	9424 789181	EKATERINA VASILEVA	{"email": "vasilevaekaterina1963@postgrespro.ru", "phone": "+70774940418"}
0005433517096	7FBD5E	5077 534990	VIKTOR KUZMIN	{"email": "kuzmin_v.071960@postgrespro.ru", "phone": "+70379844018"}
0005433517097	642978	4945 757659	SAVELIY MOROZOV	{"email": "morozovs1974@postgrespro.ru", "phone": "+70489587615"}
0005433517098	9253E8	5009 466238	GALINA IVANOVA	{"phone": "+70371321822"}
0005433517099	89028C	8821 705100	ANASTASIYA KUZNECOVA	{"phone": "+70715678414"}
0005433517100	89028C	8516 180965	GRIGORIY KUZNECOV	{"phone": "+70162593823"}
0005433517101	73B047	8670 244815	KONSTANTIN ANDREEV	{"phone": "+70745227528"}
0005433517102	73B047	4783 997112	EVDOKIYA MAKAROVA	{"email": "emakarova_101962@postgrespro.ru", "phone": "+70816507881"}
0005433517103	73B047	5328 211981	NIKOLAY EGOROV	{"phone": "+70683875125"}
0005433517104	99A182	2623 924890	OLGA SCHERBAKOVA	{"email": "o_scherbakova-1970@postgrespro.ru", "phone": "+70813581464"}
0005433517105	A8E41E	0229 010885	DMITRIY NAUMOV	{"email": "naumovd-1974@postgrespro.ru", "phone": "+70461726765"}
0005433517106	C08136	3785 840485	GALINA MIKHAYLOVA	{"phone": "+70767822427"}
0005433517107	A8AE79	9129 640698	VLADIMIR ANDREEV	{"phone": "+70612518870"}
0005433517108	585F6A	9201 988052	ALEKSANDR EGOROV	{"phone": "+70874184607"}
0005433517109	2C4927	7660 056765	OKSANA IVANOVA	{"phone": "+70670069834"}
0005433517110	18E798	2053 610402	VLADIMIR KUZNECOV	{"phone": "+70694034808"}
0005433517111	18E798	7181 214634	NADEZHDA GERASIMOVA	{"phone": "+70293059642"}
0005433517112	6D5BEF	8056 213270	GALINA SMIRNOVA	{"phone": "+70363985772"}
0005433517113	584D10	4783 811866	ELENA VASILEVA	{"phone": "+70761325801"}
0005433517114	B225A5	8178 631636	KLAVDIYA SOKOLOVA	{"email": "sokolova_klavdiya021970@postgrespro.ru", "phone": "+70338448897"}
0005433517115	4BECB6	0218 539293	ALIYA SCHERBAKOVA	{"phone": "+70409109031"}
0005433517116	753D97	5092 187908	KRISTINA BOGDANOVA	{"phone": "+70347456908"}
0005433517117	753D97	7192 450594	ANASTASIYA TITOVA	{"phone": "+70793342399"}
0005433517118	5AD770	2768 811828	ALEKSEY MIRONOV	{"email": "amironov17101979@postgrespro.ru", "phone": "+70781110591"}
0005433517119	C33943	4816 595351	YURIY ANTONOV	{"phone": "+70096120635"}
0005433517120	6BB567	1604 549119	ANTONINA ZAKHAROVA	{"phone": "+70014450583"}
0005433517121	047DFC	7964 701136	NATALYA TIMOFEEVA	{"email": "natalya.timofeeva101959@postgrespro.ru", "phone": "+70914693609"}
0005433517122	3799CE	1976 147261	YURIY PAVLOV	{"phone": "+70779731242"}
0005433517123	3799CE	5250 199709	VLADIMIR VOLKOV	{"phone": "+70040482168"}
0005433517124	3799CE	2038 386303	ALEKSEY BELOV	{"phone": "+70919145551"}
0005433517125	9551A2	0011 978822	ALEKSANDR GORBUNOV	{"phone": "+70191537189"}
0005433517126	AA7887	8265 969489	ANATOLIY GAVRILOV	{"email": "anatoliy_gavrilov071985@postgrespro.ru", "phone": "+70647412688"}
0005433517127	617792	0469 036537	IGOR BARANOV	{"phone": "+70748772743"}
0005433517128	33FCD2	4096 676006	OLGA ZAYCEVA	{"phone": "+70706131957"}
0005433517129	C54FFC	3482 146442	VALERIY ANDREEV	{"phone": "+70825409161"}
0005433517130	C97519	1392 953576	VADIM ORLOV	{"phone": "+70871675659"}
0005433517131	C49998	9155 585332	VASILIY KRASNOV	{"email": "krasnovvasiliy-26061975@postgrespro.ru", "phone": "+70179802222"}
0005433517132	C49998	0423 743116	OLGA TITOVA	{"phone": "+70069346477"}
0005433517133	C49998	7607 306853	YURIY SOKOLOV	{"phone": "+70000797964"}
0005433517134	01FA4A	4662 257261	ANATOLIY ANTONOV	{"email": "anatoliyantonov-121979@postgrespro.ru", "phone": "+70361564290"}
0005433517135	01FA4A	8072 698154	YURIY ZAYCEV	{"email": "zaycev.yuriy_1965@postgrespro.ru", "phone": "+70127220977"}
0005433517136	01FA4A	3496 114074	YULIYA LAZAREVA	{"email": "lazarevayuliya.01111968@postgrespro.ru", "phone": "+70647467354"}
0005433517137	17ACB5	7846 336949	VALENTINA FADEEVA	{"email": "fadeeva.valentina_01121979@postgrespro.ru", "phone": "+70125497254"}
0005433517138	17ACB5	4906 306897	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_08081982@postgrespro.ru", "phone": "+70302380506"}
0005433517139	049B56	7845 138774	DARYA ORLOVA	{"phone": "+70510974715"}
0005433517140	049B56	8771 475508	ANDREY TARASOV	{"email": "andrey_tarasov-03021971@postgrespro.ru", "phone": "+70168182077"}
0005433517141	55E020	1617 588611	ELENA MIKHAYLOVA	{"email": "mikhaylova-elena1975@postgrespro.ru", "phone": "+70491800362"}
0005433517142	11ED1A	3399 600419	NIKOLAY SIDOROV	{"email": "sidorovnikolay-21121971@postgrespro.ru", "phone": "+70117307734"}
0005433517143	989F9B	7642 942218	SEMEN MATVEEV	{"phone": "+70972231101"}
0005433517145	989F9B	5188 341827	ALEKSANDR IVANOV	{"email": "aleksandrivanov.20111959@postgrespro.ru", "phone": "+70408588711"}
0005433517146	4D8333	3392 695880	ELENA TIMOFEEVA	{"phone": "+70562793491"}
0005433517147	3A89B8	9332 437827	OLGA MELNIKOVA	{"email": "melnikova.olga_1970@postgrespro.ru", "phone": "+70544761001"}
0005433517148	3A89B8	3003 790624	ANDREY ORLOV	{"email": "orlov.a11101984@postgrespro.ru", "phone": "+70757425308"}
0005433517149	5046D8	9200 846692	DARYA MAKSIMOVA	{"email": "d.maksimova-1963@postgrespro.ru", "phone": "+70917950237"}
0005433517150	C15B68	5295 432540	RAISA KOZLOVA	{"email": "raisa_kozlova.1976@postgrespro.ru", "phone": "+70139453925"}
0005433517151	C15B68	0532 612925	EKATERINA ALEKSANDROVA	{"email": "ekaterinaaleksandrova_22031965@postgrespro.ru", "phone": "+70694049277"}
0005433517152	C42A31	6760 579781	DANIIL EGOROV	{"email": "d.egorov_021968@postgrespro.ru", "phone": "+70493075648"}
0005433517153	E7F426	8607 871094	VLADIMIR POPOV	{"phone": "+70860703223"}
0005433517154	E7F426	6444 611096	LARISA VLASOVA	{"phone": "+70858043969"}
0005433517155	D5253C	3990 151646	OLESYA NIKITINA	{"email": "olesya_nikitina-071967@postgrespro.ru", "phone": "+70674634244"}
0005433517156	9DDB94	0153 213865	EGOR KUZNECOV	{"phone": "+70165615950"}
0005433517157	9DDB94	7831 721864	ALEKSANDR SMIRNOV	{"phone": "+70503811832"}
0005433517158	EFB01A	4350 376117	SERGEY NOVIKOV	{"email": "snovikov_25101973@postgrespro.ru", "phone": "+70024719122"}
0005433517159	39566A	2902 705555	VALENTINA DANILOVA	{"email": "danilova.v-27051963@postgrespro.ru", "phone": "+70110532608"}
0005433517160	9731ED	2265 248889	ELENA PAVLOVA	{"phone": "+70553199587"}
0005433517161	9731ED	5194 487549	GALINA ANDREEVA	{"email": "andreeva_g11071967@postgrespro.ru", "phone": "+70269445649"}
0005433517162	325AD7	6527 806792	ALEKSANDR ZAKHAROV	{"phone": "+70722354863"}
0005433517163	884E66	6400 123099	VALENTINA ALEKSEEVA	{"phone": "+70865936154"}
0005433517164	4CE76E	6557 978590	ELENA VASILEVA	{"email": "vasilevae1967@postgrespro.ru", "phone": "+70214987723"}
0005433517165	AB19BD	8006 648999	EKATERINA MAKSIMOVA	{"email": "ekaterina_maksimova_1982@postgrespro.ru", "phone": "+70209979773"}
0005433517166	E171B4	8834 558355	SVETLANA VOROBEVA	{"email": "svetlanavorobeva28081975@postgrespro.ru", "phone": "+70909173072"}
0005433517167	C05BAE	3559 206149	NIKOLAY TIMOFEEV	{"email": "timofeev.n_10121972@postgrespro.ru", "phone": "+70151554107"}
0005433517168	C05BAE	2531 857987	VASILIY OSIPOV	{"email": "v_osipov-05041982@postgrespro.ru", "phone": "+70882385886"}
0005433519430	F3DE8E	4129 778076	MARINA ALEKSANDROVA	{"phone": "+70702433983"}
0005433519377	DEA7A6	0278 765615	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov.1976@postgrespro.ru", "phone": "+70263855527"}
0005433519378	234050	2739 358389	ELENA KULIKOVA	{"email": "kulikova-e_1966@postgrespro.ru", "phone": "+70828700539"}
0005433519379	FEF4B6	0178 127975	IVAN FROLOV	{"email": "frolov_i.1963@postgrespro.ru", "phone": "+70106785698"}
0005433519380	C8B9D2	7048 401648	MAKSIM ZAKHAROV	{"phone": "+70121718158"}
0005433519381	E14A3F	3360 143471	TATYANA BORISOVA	{"email": "tatyana_borisova.041962@postgrespro.ru", "phone": "+70635075383"}
0005433519382	B6B9FB	5744 015843	OLGA KARPOVA	{"email": "karpova_olga.1977@postgrespro.ru", "phone": "+70185493975"}
0005433519383	B6B9FB	3160 038939	ALEKSANDR ISAEV	{"email": "a_isaev1962@postgrespro.ru", "phone": "+70112480225"}
0005433519384	5BC594	4873 607848	YAROSLAV KUZNECOV	{"phone": "+70032489758"}
0005433519385	5BC594	1691 213163	ARTEM FROLOV	{"phone": "+70604574393"}
0005433519386	251DE7	0085 036116	NIKOLAY MIRONOV	{"email": "mironovn.1966@postgrespro.ru", "phone": "+70832174850"}
0005433519387	251DE7	5020 391480	SVETLANA NAUMOVA	{"email": "naumova_s-041967@postgrespro.ru", "phone": "+70408548919"}
0005433519388	251DE7	6117 236619	ANNA PETROVA	{"email": "a_petrova-20071977@postgrespro.ru", "phone": "+70416676602"}
0005433519389	8D0104	2766 260007	MIKHAIL SCHERBAKOV	{"email": "scherbakov.m.05121968@postgrespro.ru", "phone": "+70337430864"}
0005433519390	EC5E39	3633 956517	SERGEY GAVRILOV	{"email": "sergey.gavrilov03121966@postgrespro.ru", "phone": "+70828076149"}
0005433519391	9B2E6D	8259 708108	BOGDAN SERGEEV	{"phone": "+70323119451"}
0005433519392	5F08D6	4780 725235	SERGEY NIKITIN	{"phone": "+70483982289"}
0005433519393	5F08D6	9390 311333	LARISA POTAPOVA	{"phone": "+70409993995"}
0005433519394	F936AE	6283 073520	NIKOLAY KULIKOV	{"email": "n_kulikov_1977@postgrespro.ru", "phone": "+70249758404"}
0005433519395	BBC5C0	8966 315685	ANTON PAVLOV	{"email": "pavlov.anton-1979@postgrespro.ru", "phone": "+70134473189"}
0005433519396	C62EEA	1297 336664	DMITRIY SCHERBAKOV	{"phone": "+70652618499"}
0005433519397	8C55B1	3811 709363	SVETLANA RODIONOVA	{"phone": "+70265107835"}
0005433519398	2435C5	1889 383500	ANASTASIYA ARKHIPOVA	{"phone": "+70364574366"}
0005433519399	2435C5	0150 466628	NIKOLAY FOMIN	{"email": "fominn_1962@postgrespro.ru", "phone": "+70046872140"}
0005433519400	033848	1032 986491	ALEKSANDR SMIRNOV	{"phone": "+70923428177"}
0005433519401	E5CDA5	2265 860846	MARINA BOGDANOVA	{"email": "bogdanova-marina-1960@postgrespro.ru", "phone": "+70147432325"}
0005433519402	E5CDA5	3694 311828	IVAN TARASOV	{"phone": "+70779378278"}
0005433519403	F8E399	0503 571060	ELENA KUZMINA	{"email": "elena.kuzmina1968@postgrespro.ru", "phone": "+70399999775"}
0005433519404	EFBECF	1316 798250	VYACHESLAV VOLKOV	{"email": "volkov.v-1965@postgrespro.ru", "phone": "+70412406939"}
0005433519405	AB1D58	7541 204425	TAISIYA NESTEROVA	{"phone": "+70051389243"}
0005433519406	2867DD	4286 160646	VALENTINA KOVALEVA	{"phone": "+70443923192"}
0005433519407	A83EE7	2972 990932	NIKOLAY MIRONOV	{"email": "mironov-nikolay_021985@postgrespro.ru", "phone": "+70770092572"}
0005433519408	A83EE7	9721 663566	VYACHESLAV SEMENOV	{"phone": "+70528455446"}
0005433519409	952A7F	5627 407604	EVGENIY ABRAMOV	{"phone": "+70802022616"}
0005433519410	952A7F	3622 715913	EVGENIY ZAKHAROV	{"email": "e-zakharov1977@postgrespro.ru", "phone": "+70169878206"}
0005433519411	3F3DE1	9073 286851	SERGEY RODIONOV	{"phone": "+70081478322"}
0005433519412	C4BA0A	5336 520026	VIKTOR KARPOV	{"email": "v-karpov1964@postgrespro.ru", "phone": "+70856649846"}
0005433519413	C4BA0A	9825 871076	SERGEY PETROV	{"email": "s.petrov-011972@postgrespro.ru", "phone": "+70316390777"}
0005433519414	A1F31C	4681 016024	ROZALIYA SEMENOVA	{"phone": "+70488669360"}
0005433519415	4CFDB4	4655 337456	OLGA BELYAEVA	{"email": "olga_belyaeva_1971@postgrespro.ru", "phone": "+70466230977"}
0005433519416	4CFDB4	7131 141162	LIDIYA TIKHONOVA	{"email": "tikhonova_l061984@postgrespro.ru", "phone": "+70726893206"}
0005433519417	0E1467	1314 568534	DARINA TARASOVA	{"email": "d.tarasova.041979@postgrespro.ru", "phone": "+70104866666"}
0005433519418	0E1467	4134 762586	VIKTOR VOLKOV	{"phone": "+70042188374"}
0005433519419	DB1F62	9162 634996	NIKOLAY ABRAMOV	{"email": "n-abramov1984@postgrespro.ru", "phone": "+70626323544"}
0005433519420	C8CE50	3514 095815	NADEZHDA KUZNECOVA	{"email": "kuznecova_n.22031970@postgrespro.ru", "phone": "+70454545954"}
0005433519421	C8CE50	7676 567149	NINA KOVALEVA	{"email": "n_kovaleva_071981@postgrespro.ru", "phone": "+70913666117"}
0005433519422	5435E7	5754 519556	NINA DAVYDOVA	{"email": "davydova.n051975@postgrespro.ru", "phone": "+70578225915"}
0005433519423	1BED57	6322 621693	VASILIY ABRAMOV	{"phone": "+70851836762"}
0005433519424	2F81F2	9681 248214	NATALYA KUZNECOVA	{"email": "kuznecova-natalya-111981@postgrespro.ru", "phone": "+70133001623"}
0005433519425	9D1A77	1875 958851	ELENA KISELEVA	{"email": "kiseleva-elena.1964@postgrespro.ru", "phone": "+70238686551"}
0005433519426	9D1A77	5797 469515	EVGENIY GUSEV	{"email": "egusev.22051976@postgrespro.ru", "phone": "+70506623561"}
0005433519427	2493ED	1851 244465	STANISLAV KULIKOV	{"email": "kulikovs_1963@postgrespro.ru", "phone": "+70053343399"}
0005433519428	BE6C50	9143 151417	ZOYA SCHERBAKOVA	{"email": "scherbakova_z101971@postgrespro.ru", "phone": "+70576038851"}
0005433519429	BE6C50	9171 351508	NIKITA SMIRNOV	{"email": "smirnovnikita.101981@postgrespro.ru", "phone": "+70053861888"}
0005433519431	E7C3C3	4485 988622	DENIS GAVRILOV	{"email": "gavrilovd011977@postgrespro.ru", "phone": "+70319753684"}
0005433519432	BA0A77	6464 551541	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy_1960@postgrespro.ru", "phone": "+70308699876"}
0005433519433	17B579	1980 504558	NATALYA MOISEEVA	{"email": "moiseeva_n_09041977@postgrespro.ru", "phone": "+70472574266"}
0005433519434	1B1D5B	3779 304328	ANNA EGOROVA	{"phone": "+70021618478"}
0005433519435	CEA5A1	2082 130394	IRINA MOROZOVA	{"phone": "+70878826989"}
0005433519436	CEA5A1	3989 351944	MARIYA PAVLOVA	{"email": "mariyapavlova-1972@postgrespro.ru", "phone": "+70803350948"}
0005433519437	42A4A0	3992 588765	BORIS ABRAMOV	{"email": "abramov_boris071970@postgrespro.ru", "phone": "+70503067220"}
0005433519438	42A4A0	5411 962345	SERGEY EGOROV	{"email": "s.egorov.1977@postgrespro.ru", "phone": "+70432898439"}
0005433519439	E7CA05	5481 187189	DMITRIY VOROBEV	{"email": "dmitriy-vorobev.121982@postgrespro.ru", "phone": "+70781333406"}
0005433519440	0CFD45	3026 509890	LEYLA KOMAROVA	{"phone": "+70964496835"}
0005433519441	E45D2C	0973 845700	LARISA KUZNECOVA	{"email": "lkuznecova_01121977@postgrespro.ru", "phone": "+70322263141"}
0005433519442	96DAD4	7912 091479	NIKITA STEPANOV	{"phone": "+70922803163"}
0005433519443	AFAE7C	7426 357520	DANIIL SERGEEV	{"email": "d_sergeev_09071972@postgrespro.ru", "phone": "+70152850420"}
0005433519444	53FDA5	4745 614142	LYUDMILA KONDRATEVA	{"email": "kondrateva_l.28061971@postgrespro.ru", "phone": "+70982813684"}
0005433519445	A1FBF3	1059 998911	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir_07081961@postgrespro.ru", "phone": "+70259527521"}
0005433519446	BD00E5	7998 117728	ALEKSEY SIDOROV	{"phone": "+70646720444"}
0005433519447	AE8EF7	8608 133001	RAMIL SHEVCHENKO	{"phone": "+70441045937"}
0005433519448	AE8EF7	0841 160692	VLADIMIR TARASOV	{"email": "tarasov-vladimir.30101981@postgrespro.ru", "phone": "+70164049076"}
0005433519449	47DE50	1951 151658	MILENA KUZNECOVA	{"email": "kuznecova_milena-061963@postgrespro.ru", "phone": "+70333062176"}
0005433519450	47DE50	0768 593076	ANTONINA STEPANOVA	{"phone": "+70503843466"}
0005433519451	DF2A3D	2058 647400	ANNA KOROLEVA	{"email": "koroleva.anna-1974@postgrespro.ru", "phone": "+70607633339"}
0005433519452	2367D8	7882 580591	ALEKSANDR POPOV	{"phone": "+70452670745"}
0005433519453	2367D8	8500 644515	EVGENIY SMIRNOV	{"phone": "+70413738025"}
0005433519454	8172F2	9448 002878	YURIY MIKHAYLOV	{"email": "mikhaylov-yuriy1973@postgrespro.ru", "phone": "+70875556713"}
0005433519455	8172F2	9431 709452	SERGEY ZAYCEV	{"email": "zaycev-s.021960@postgrespro.ru", "phone": "+70335439074"}
0005433519456	FB104E	6051 323156	DMITRIY NIKITIN	{"phone": "+70325600836"}
0005433519457	540944	0631 893233	EVGENIY OSIPOV	{"phone": "+70092993493"}
0005433519458	B81B6B	5623 707477	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy031979@postgrespro.ru", "phone": "+70091224773"}
0005433519459	3E74D4	7583 908386	VALERIYA ZHURAVLEVA	{"phone": "+70508752826"}
0005433519460	03B5E1	5927 728809	BORIS TIMOFEEV	{"phone": "+70022205337"}
0005433519461	03B5E1	7314 047823	DANILA PAVLOV	{"phone": "+70150381271"}
0005433519462	03B5E1	0945 696724	ALEKSEY SOLOVEV	{"phone": "+70726956825"}
0005433519463	97D1B6	5785 274137	ARTEM KAZAKOV	{"email": "artemkazakov31011983@postgrespro.ru", "phone": "+70682570628"}
0005433519464	97D1B6	5785 137759	VLADISLAV VASILEV	{"phone": "+70109855667"}
0005433519465	EC77D8	7809 025454	OLGA DENISOVA	{"phone": "+70664840384"}
0005433519466	C17BAC	7468 755806	ELIZAVETA OSIPOVA	{"email": "e-osipova.12021976@postgrespro.ru", "phone": "+70989888890"}
0005433519467	84D241	8106 937230	MARIYA KOZLOVA	{"phone": "+70773752493"}
0005433519468	A4A444	5364 659847	NATALYA DENISOVA	{"phone": "+70917563075"}
0005433519469	22D9BC	1914 586088	ANASTASIYA KOMAROVA	{"email": "komarova.a.1966@postgrespro.ru", "phone": "+70763949339"}
0005433519470	0E0EC7	0197 455126	SERGEY STEPANOV	{"phone": "+70012335049"}
0005433519471	30FEEC	4370 367210	DANIIL FEDOTOV	{"phone": "+70274852738"}
0005433519472	7DB660	3577 603813	GALINA FROLOVA	{"email": "galina-frolova_02071962@postgrespro.ru", "phone": "+70382856596"}
0005433519473	C73873	0333 437691	ANDREY BORISOV	{"email": "a-borisov071977@postgrespro.ru", "phone": "+70671555312"}
0005433519474	734203	0781 928416	LEONID PETROV	{"email": "petrov-l-1976@postgrespro.ru", "phone": "+70490166398"}
0005433519475	734203	5467 499787	ANDREY MOISEEV	{"email": "moiseev_andrey.26091975@postgrespro.ru", "phone": "+70413325790"}
0005433519476	746424	0586 922062	AYRAT SOLOVEV	{"phone": "+70845237420"}
0005433519477	BB22CA	1506 013814	NATALYA KOLESNIKOVA	{"email": "nkolesnikova.1976@postgrespro.ru", "phone": "+70311458237"}
0005433519478	AF570F	2688 266621	SERGEY KULIKOV	{"phone": "+70300236113"}
0005433519479	AF570F	2429 070573	VALERIY TIMOFEEV	{"email": "timofeev-v_27081979@postgrespro.ru", "phone": "+70020131305"}
0005433519480	AF570F	7409 407877	VLADIMIR SOROKIN	{"email": "sorokinvladimir16111972@postgrespro.ru", "phone": "+70758006116"}
0005433519481	BDEC2F	0212 369311	MARINA EFREMOVA	{"email": "efremova-m.21031970@postgrespro.ru", "phone": "+70123562224"}
0005433519482	37921A	1140 332732	SERAFIMA MATVEEVA	{"phone": "+70597876376"}
0005433519483	C0C48F	3583 989256	VIKTOR VOLKOV	{"phone": "+70892620847"}
0005433519484	191566	2609 183543	ANATOLIY CHERNOV	{"phone": "+70372390393"}
0005433519485	191566	2034 031053	NIKOLAY ANTONOV	{"email": "nikolay-antonov_1982@postgrespro.ru", "phone": "+70912758480"}
0005433519486	0C90A1	3114 137429	FEDOR SAVELEV	{"email": "savelev_fedor.1975@postgrespro.ru", "phone": "+70184447345"}
0005433519487	AE51AF	6117 702150	VALENTINA FOMINA	{"phone": "+70496582889"}
0005433519488	EEAF50	6187 447910	GENNADIY ANTONOV	{"phone": "+70859406359"}
0005433519489	91E065	9798 983629	VYACHESLAV KUZNECOV	{"phone": "+70283675280"}
0005433519490	91E065	2674 594272	TATYANA MELNIKOVA	{"phone": "+70905791986"}
0005433519491	91E065	4123 979715	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.01031967@postgrespro.ru", "phone": "+70963994583"}
0005433519492	6369A4	8413 725252	GALINA VASILEVA	{"email": "galina-vasileva-081981@postgrespro.ru", "phone": "+70158589732"}
0005433519493	6369A4	1806 755475	NADEZHDA BARANOVA	{"phone": "+70548473198"}
0005433519494	D0A3E9	6000 921833	MAKSIM KAZAKOV	{"phone": "+70824705296"}
0005433519495	58135C	7997 063914	IGOR PAVLOV	{"phone": "+70707358115"}
0005433519496	58135C	6000 712946	ANATOLIY VASILEV	{"phone": "+70815776150"}
0005433519497	F2AA75	1821 118584	TIMUR KONOVALOV	{"phone": "+70036534018"}
0005433519498	0688A7	8300 134258	ALBINA ANDREEVA	{"phone": "+70178706019"}
0005433519499	469FAB	3048 779313	MARINA FROLOVA	{"email": "marina_frolova_1979@postgrespro.ru", "phone": "+70171509304"}
0005433519500	EFAC46	2864 751464	VALENTINA KARPOVA	{"email": "valentina_karpova-1965@postgrespro.ru", "phone": "+70300018616"}
0005433519501	BD4EFF	2711 447688	ALEKSANDR NIKOLAEV	{"phone": "+70890046938"}
0005433519502	7EC48B	2602 677142	VALENTINA MARTYNOVA	{"email": "valentinamartynova121969@postgrespro.ru", "phone": "+70625130447"}
0005433519503	8849BB	2454 716795	INESSA IVANOVA	{"phone": "+70124495945"}
0005433519504	8849BB	4740 429519	EKATERINA KUZMINA	{"email": "kuzminaekaterina_1971@postgrespro.ru", "phone": "+70248375265"}
0005433519505	F27860	8616 537405	EKATERINA ZAKHAROVA	{"email": "ekaterina.zakharova.17071977@postgrespro.ru", "phone": "+70568944499"}
0005433519506	F27860	0682 880104	VLADIMIR FROLOV	{"phone": "+70412175634"}
0005433519507	303293	2244 410186	NIKOLAY VOLKOV	{"phone": "+70577233888"}
0005433519508	303293	2768 375262	KIRILL ROMANOV	{"phone": "+70608658713"}
0005433519509	FE832A	3674 310014	ALEKSANDR MEDVEDEV	{"phone": "+70243564853"}
0005433519510	CE3471	4428 198704	VIKTORIYA KUZMINA	{"phone": "+70977783822"}
0005433519511	33C16E	3174 320317	LYUDMILA ILINA	{"email": "lyudmila_ilina.03121987@postgrespro.ru", "phone": "+70041513217"}
0005433519512	33C16E	7467 465744	MIKHAIL SMIRNOV	{"phone": "+70200224624"}
0005433519513	F81101	9563 656524	ELENA FEDOROVA	{"email": "e.fedorova071963@postgrespro.ru", "phone": "+70196354504"}
0005433519514	7E7511	7445 288555	VLADIMIR DAVYDOV	{"phone": "+70318766380"}
0005433519515	7E7511	4041 586202	ELIZAVETA KUZNECOVA	{"email": "kuznecova.e.1972@postgrespro.ru", "phone": "+70576361103"}
0005433519516	EB7484	2288 501914	OLGA KOROLEVA	{"email": "o.koroleva10021961@postgrespro.ru", "phone": "+70751730128"}
0005433519517	997D17	8525 456904	OLEG KARPOV	{"email": "karpov_oleg07111965@postgrespro.ru", "phone": "+70273710928"}
0005433519518	997D17	6200 657717	VERA ILINA	{"phone": "+70420484043"}
0005433519519	A1F78D	6029 301817	GULNARA POLYAKOVA	{"email": "polyakova.g.101963@postgrespro.ru", "phone": "+70579656230"}
0005433519520	781799	8365 450052	SERGEY GAVRILOV	{"email": "gavrilov.s.11111977@postgrespro.ru", "phone": "+70377221968"}
0005433519521	8D0618	1452 538039	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr19021974@postgrespro.ru", "phone": "+70952862702"}
0005433519522	8D0618	8553 130951	VIKTOR ROMANOV	{"email": "romanov-v-1975@postgrespro.ru", "phone": "+70255344112"}
0005433519523	348545	0497 904234	TATYANA ANDREEVA	{"email": "tatyanaandreeva1972@postgrespro.ru", "phone": "+70759134936"}
0005433519524	E75390	6382 437991	YULIYA TARASOVA	{"email": "yuliya.tarasova22051977@postgrespro.ru", "phone": "+70842253842"}
0005433519525	B5EDFB	3140 248767	SERGEY KULIKOV	{"phone": "+70672602467"}
0005433519526	0ED79F	4800 500515	LEONID ZHUKOV	{"phone": "+70993953363"}
0005433519527	848ED4	1680 262910	ALEKSEY NAZAROV	{"email": "nazarov_aleksey.29031969@postgrespro.ru", "phone": "+70324185528"}
0005433519528	848ED4	1981 292121	VIKTOR ZHUKOV	{"email": "zhukov-v18011962@postgrespro.ru", "phone": "+70182500179"}
0005433519529	848ED4	0901 504374	MARINA EGOROVA	{"email": "marina.egorova.011977@postgrespro.ru", "phone": "+70584950429"}
0005433519530	EEE67A	2042 297961	RUSLAN KUZNECOV	{"email": "ruslan_kuznecov031986@postgrespro.ru", "phone": "+70092950854"}
0005433519531	6A2A8E	8958 145492	RENATA KULIKOVA	{"phone": "+70055905424"}
0005433519532	C682C4	0511 951205	ILYA NIKITIN	{"phone": "+70964333768"}
0005433519533	C189B5	2404 788079	NIKITA TIKHONOV	{"phone": "+70426570198"}
0005433519534	9054E1	3914 315060	IGOR GAVRILOV	{"phone": "+70222186491"}
0005433519535	016281	0088 958322	ANATOLIY SCHERBAKOV	{"email": "scherbakov.anatoliy-041971@postgrespro.ru", "phone": "+70414453129"}
0005433519536	031D27	8025 271272	ZINAIDA ALEKSEEVA	{"email": "zinaidaalekseeva-011971@postgrespro.ru", "phone": "+70640875113"}
0005433519537	A6D420	0647 968980	ANATOLIY FEDOROV	{"phone": "+70968073996"}
0005433519538	B78E19	0870 810597	VLADISLAV DENISOV	{"email": "denisov_v.09081978@postgrespro.ru", "phone": "+70794927956"}
0005433519539	3A53C5	2152 923898	NATALYA IVANOVA	{"email": "nivanova.011974@postgrespro.ru", "phone": "+70022020230"}
0005433519540	FCCB11	0831 406746	ALEKSEY MIKHAYLOV	{"phone": "+70315301693"}
0005433519541	FCCB11	1572 731533	YURIY NIKITIN	{"email": "yuriy_nikitin.041970@postgrespro.ru", "phone": "+70516433835"}
0005433519542	287320	5115 295761	DMITRIY ORLOV	{"email": "orlov.dmitriy-1972@postgrespro.ru", "phone": "+70418035178"}
0005433519543	F911B3	0572 892397	VIKTORIYA KAZAKOVA	{"phone": "+70737202116"}
0005433519544	A4EC2C	5995 442460	VALERIYA KULIKOVA	{"phone": "+70883442482"}
0005433519545	3D4A4D	4948 789675	LIDIYA MATVEEVA	{"email": "matveeva_l_1980@postgrespro.ru", "phone": "+70763901629"}
0005433519546	387B2E	4946 987043	VLADISLAV DAVYDOV	{"email": "davydov-v_15061968@postgrespro.ru", "phone": "+70583810662"}
0005433519547	387B2E	3071 295216	SVETLANA POPOVA	{"email": "popova_svetlana1969@postgrespro.ru", "phone": "+70804810691"}
0005433519548	325CAC	3943 317672	YULIYA KOMAROVA	{"phone": "+70829708500"}
0005433519549	B8AAD6	5692 317938	MAKSIM IVANOV	{"phone": "+70829235550"}
0005433519550	E9A68F	1302 577226	NATALYA KAZAKOVA	{"phone": "+70389013357"}
0005433519551	57A79F	2676 733034	SERGEY KUZNECOV	{"phone": "+70772582675"}
0005433519552	264EEB	4227 838042	ANASTASIYA ZOTOVA	{"email": "a-zotova.1957@postgrespro.ru", "phone": "+70209659939"}
0005433519553	E1C7E7	8939 144874	ANTON SEMENOV	{"phone": "+70340112427"}
0005433519554	B6AB44	5270 898625	ALEKSANDR ILIN	{"phone": "+70930353868"}
0005433519555	464990	7434 038533	IGOR MIKHAYLOV	{"email": "mikhaylov_i.10011973@postgrespro.ru", "phone": "+70956664069"}
0005433519556	464990	9725 191030	ALEKSANDR KUZNECOV	{"phone": "+70656472943"}
0005433519557	D8DF2E	3731 070600	SERGEY FEDOTOV	{"phone": "+70071907031"}
0005433519558	D8DF2E	8684 696507	SVETLANA ARKHIPOVA	{"email": "arkhipovasvetlana.1979@postgrespro.ru", "phone": "+70766171684"}
0005433519559	55FAB8	0813 603374	ANTONINA KUZNECOVA	{"email": "antonina_kuznecova.101969@postgrespro.ru", "phone": "+70995181029"}
0005433519560	80F6CB	7766 701104	VITALIY KOROLEV	{"phone": "+70839919588"}
0005433519561	AF1E7A	1472 636466	GALINA KONOVALOVA	{"phone": "+70228790237"}
0005433519562	F17D04	7668 650112	TATYANA VLASOVA	{"phone": "+70904947987"}
0005433519563	F17D04	9535 446463	VALERIY GAVRILOV	{"email": "gavrilov.v1970@postgrespro.ru", "phone": "+70751494457"}
0005433519564	F17D04	0420 622895	YAROSLAV VASILEV	{"email": "yaroslav.vasilev_1979@postgrespro.ru", "phone": "+70396848522"}
0005433519565	E86BF9	8343 803689	MIKHAIL KUZMIN	{"phone": "+70852052546"}
0005433519566	5E0A6E	3803 453564	VALERIY FROLOV	{"email": "frolov-valeriy1968@postgrespro.ru", "phone": "+70683535445"}
0005433519567	BCC62A	0210 772373	ALEKSANDR MOROZOV	{"email": "amorozov-081975@postgrespro.ru", "phone": "+70175730665"}
0005433519568	BCC62A	5754 992353	DIANA FILATOVA	{"phone": "+70574625869"}
0005433519569	7367BD	7427 295352	ALEKSANDR VASILEV	{"phone": "+70588883757"}
0005433519570	952D76	5625 884142	OLEG FEDOTOV	{"phone": "+70455616993"}
0005433519571	3361D2	8815 571091	DMITRIY ANTONOV	{"email": "dantonov.1963@postgrespro.ru", "phone": "+70991833123"}
0005433519572	3361D2	7547 671464	SERGEY DENISOV	{"phone": "+70831841002"}
0005433519573	3361D2	3502 394594	MARINA KOMAROVA	{"phone": "+70527353621"}
0005433519574	9E8265	9543 981805	NIKOLAY IVANOV	{"phone": "+70702308378"}
0005433519575	9E411A	1597 123624	DMITRIY IVANOV	{"email": "d_ivanov-19101966@postgrespro.ru", "phone": "+70364475173"}
0005433519576	CF456B	2631 983275	OLGA KALININA	{"email": "o-kalinina_031972@postgrespro.ru", "phone": "+70025623051"}
0005433519577	09EC74	3741 248555	VLADIMIR MELNIKOV	{"phone": "+70004669529"}
0005433519578	09EC74	5044 256781	ANDREY ZHURAVLEV	{"phone": "+70189137188"}
0005433519579	5CBD07	0910 526812	NATALYA ZHUKOVA	{"phone": "+70878504018"}
0005433519580	723793	4078 028889	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova-1981@postgrespro.ru", "phone": "+70654059222"}
0005433519581	723793	8801 247090	NATALYA SOROKINA	{"email": "sorokinan.08071963@postgrespro.ru", "phone": "+70913290892"}
0005433519582	876D05	7887 318917	ANDREY MEDVEDEV	{"email": "medvedev_andrey-11101970@postgrespro.ru", "phone": "+70672309732"}
0005433519583	0ACF1B	8985 984524	VLADIMIR NIKOLAEV	{"email": "v.nikolaev.041977@postgrespro.ru", "phone": "+70869343817"}
0005433519584	0ACF1B	3578 277468	OLEG SOLOVEV	{"email": "solovev.oleg.071973@postgrespro.ru", "phone": "+70881219218"}
0005433519585	3A892D	9899 704530	KSENIYA PAVLOVA	{"email": "pavlova_k_1964@postgrespro.ru", "phone": "+70070913357"}
0005433519586	3DD2EC	2022 738097	NATALYA ORLOVA	{"phone": "+70778368370"}
0005433519587	3DD2EC	5967 178402	FAINA KAZAKOVA	{"phone": "+70321217907"}
0005433519588	B6FA54	0289 361185	VIKTOR SCHERBAKOV	{"phone": "+70030361811"}
0005433519589	BBE923	6313 360762	KONSTANTIN EGOROV	{"phone": "+70159225074"}
0005433519590	BCF04A	3294 852310	VLADISLAV GERASIMOV	{"email": "vladislav.gerasimov10011985@postgrespro.ru", "phone": "+70255037252"}
0005433519591	A5A494	8358 878366	TATYANA NIKOLAEVA	{"phone": "+70015876824"}
0005433519592	A5A494	5697 153141	DENIS DMITRIEV	{"phone": "+70310641089"}
0005433524846	E09A74	1839 157577	MARIYA ANTONOVA	{"email": "m-antonova1974@postgrespro.ru", "phone": "+70503438104"}
0005433524847	BAB3F3	0310 024894	TATYANA PETROVA	{"phone": "+70144132379"}
0005433524848	354329	4711 680142	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr-1965@postgrespro.ru", "phone": "+70190973098"}
0005433524849	6A70EC	3014 088452	DMITRIY MEDVEDEV	{"email": "medvedev_dmitriy_08031974@postgrespro.ru", "phone": "+70675001072"}
0005433524850	6A70EC	0095 679315	VLADIMIR SOLOVEV	{"phone": "+70484484428"}
0005433524851	C0045A	9128 721619	NADEZHDA SCHERBAKOVA	{"phone": "+70027124124"}
0005433524852	989AA8	1765 039043	VALERIY CHERNOV	{"email": "v-chernov19111967@postgrespro.ru", "phone": "+70346953676"}
0005433524853	F23497	7953 581531	SERGEY SEMENOV	{"email": "s-semenov-1971@postgrespro.ru", "phone": "+70399714198"}
0005433524854	7D6B77	0965 383294	DENIS OSIPOV	{"phone": "+70206017064"}
0005433524855	86B66F	8630 729584	NAILYA VOLKOVA	{"phone": "+70818443734"}
0005433524856	6A6B9A	3080 163514	IVAN MOROZOV	{"email": "morozovivan121965@postgrespro.ru", "phone": "+70034785372"}
0005433524857	6A7B69	1183 447155	TATYANA KUZNECOVA	{"phone": "+70102583187"}
0005433524858	6A7B69	1135 426438	VALENTINA IVANOVA	{"email": "valentina.ivanova.1974@postgrespro.ru", "phone": "+70803867940"}
0005433524859	6A7B69	3182 737070	EVGENIY SCHERBAKOV	{"email": "scherbakov-e-051966@postgrespro.ru", "phone": "+70616537121"}
0005433524860	064178	4598 877319	YURIY IVANOV	{"email": "yuriyivanov-1970@postgrespro.ru", "phone": "+70582835843"}
0005433524861	F780CF	6170 288132	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-28041965@postgrespro.ru", "phone": "+70965763540"}
0005433524862	45401C	1792 700169	YANA PETROVA	{"email": "y.petrova1981@postgrespro.ru", "phone": "+70246840603"}
0005433524863	45401C	5761 099977	ALEKSANDR IVANOV	{"phone": "+70488770004"}
0005433524864	12F52F	4028 936381	DENIS AFANASEV	{"email": "afanasevd_18101971@postgrespro.ru", "phone": "+70239428347"}
0005433524865	12F52F	3697 935385	MARIYA KOZLOVA	{"email": "mariya_kozlova-28071976@postgrespro.ru", "phone": "+70834593392"}
0005433524866	C9F7BC	4531 604821	MIKHAIL SIDOROV	{"email": "m-sidorov.071972@postgrespro.ru", "phone": "+70206811995"}
0005433524867	9096DC	3525 305662	ANNA MAKAROVA	{"email": "makarova.a051972@postgrespro.ru", "phone": "+70933630063"}
0005433524868	9096DC	4872 868373	IVAN PETROV	{"phone": "+70258718119"}
0005433524869	9096DC	5115 276278	NATALYA CHERNOVA	{"email": "natalyachernova1962@postgrespro.ru", "phone": "+70916687845"}
0005433524870	2FCD92	3787 487123	LYUBOV MAKAROVA	{"email": "l.makarova-101966@postgrespro.ru", "phone": "+70612376499"}
0005433524871	265014	8007 847586	ALEKSANDR IVANOV	{"phone": "+70279973279"}
0005433524872	ED1531	5348 702951	YURIY ISAEV	{"phone": "+70818356911"}
0005433524873	ED1531	4414 722619	SERGEY ALEKSEEV	{"email": "alekseevs_061973@postgrespro.ru", "phone": "+70633710216"}
0005433524874	A62FD8	1025 116139	NIKOLAY PETROV	{"email": "petrov_n.081977@postgrespro.ru", "phone": "+70313166019"}
0005433524875	A62FD8	7894 698737	SAVELIY ANTONOV	{"email": "antonov_saveliy.1956@postgrespro.ru", "phone": "+70256552879"}
0005433524876	3376AE	7375 190464	ELENA GORBUNOVA	{"phone": "+70082427886"}
0005433524877	3376AE	8476 629365	KRISTINA ZHUKOVA	{"email": "zhukova_kristina-02121965@postgrespro.ru", "phone": "+70912163319"}
0005433524878	EE047B	4190 914055	LYUBOV MIKHAYLOVA	{"phone": "+70704520574"}
0005433524879	EE047B	6544 269397	ANDREY SAVELEV	{"phone": "+70980992570"}
0005433524880	EE047B	7024 577471	NATALYA NIKOLAEVA	{"email": "natalya.nikolaeva-051968@postgrespro.ru", "phone": "+70680369009"}
0005433524881	C4723D	1084 662900	NIKOLAY ZHUKOV	{"email": "zhukov_n1967@postgrespro.ru", "phone": "+70035200453"}
0005433524882	AB0AA4	0056 394359	DMITRIY KOROLEV	{"email": "korolev-d_071968@postgrespro.ru", "phone": "+70779078623"}
0005433524883	1FC9EE	2168 149845	VLADIMIR SERGEEV	{"phone": "+70951015005"}
0005433524884	1FC9EE	7710 230682	MARIYA TIMOFEEVA	{"phone": "+70062705166"}
0005433524885	4F902E	3168 434554	ARINA ILINA	{"phone": "+70096581151"}
0005433524886	4F902E	3931 309389	NATALYA SOLOVEVA	{"phone": "+70250128465"}
0005433524887	4EBB3B	7626 148628	EVGENIY ZAYCEV	{"phone": "+70093006464"}
0005433524888	4EBB3B	9884 415792	ALEKSEY SEMENOV	{"email": "semenov.a061967@postgrespro.ru", "phone": "+70120604376"}
0005433524889	5A8740	8501 029006	EMMA GAVRILOVA	{"phone": "+70498471266"}
0005433524890	BEC4A4	8923 000638	ALEKSEY FOMIN	{"email": "fominaleksey_27101971@postgrespro.ru", "phone": "+70233783936"}
0005433524891	BEC4A4	4200 833646	DMITRIY OSIPOV	{"email": "dosipov.01121966@postgrespro.ru", "phone": "+70516644130"}
0005433524892	9FB9CF	9996 798631	REGINA KOMAROVA	{"phone": "+70879924451"}
0005433524893	9FB9CF	6731 607218	OLEG NAUMOV	{"email": "oleg.naumov.021975@postgrespro.ru", "phone": "+70188571367"}
0005433524894	5B5684	7897 768790	ELIZAVETA VOLKOVA	{"email": "volkova-e_031968@postgrespro.ru", "phone": "+70393213901"}
0005433524895	5B5684	7742 505720	VYACHESLAV POPOV	{"phone": "+70834826280"}
0005433524896	8C0DA6	3726 449877	SERGEY MIRONOV	{"email": "mironov_s121968@postgrespro.ru", "phone": "+70050487921"}
0005433524897	479B44	1156 530328	DARYA DENISOVA	{"email": "denisova-d.06101957@postgrespro.ru", "phone": "+70707690575"}
0005433524898	903B6E	1036 383505	MARIYA SERGEEVA	{"email": "sergeeva-mariya_04041973@postgrespro.ru", "phone": "+70169470502"}
0005433524899	903B6E	4726 282658	VARVARA POPOVA	{"email": "v_popova.081969@postgrespro.ru", "phone": "+70474198937"}
0005433524900	D4E41B	4156 138545	ROBERT MELNIKOV	{"email": "melnikovrobert.31121963@postgrespro.ru", "phone": "+70211185219"}
0005433524901	F4E58D	5853 143293	NINA BELYAEVA	{"email": "belyaevan_051980@postgrespro.ru", "phone": "+70430280707"}
0005433524902	F4E58D	9001 163235	OLGA KUZNECOVA	{"email": "o.kuznecova_31051971@postgrespro.ru", "phone": "+70368429136"}
0005433524903	76090E	5795 274025	VLADIMIR DENISOV	{"phone": "+70573375970"}
0005433524904	0B2322	8230 242845	YURIY BELOV	{"phone": "+70394205199"}
0005433524905	0B2322	0015 665455	VALERIY FILIPPOV	{"phone": "+70664584765"}
0005433524906	BDE368	7570 832519	SERGEY BARANOV	{"phone": "+70766590423"}
0005433524907	BDE368	0974 979850	NIKOLAY ZHUKOV	{"email": "zhukov_n-19041962@postgrespro.ru", "phone": "+70839636618"}
0005433524908	531FA4	7532 070324	VERA STEPANOVA	{"email": "stepanova_v_011975@postgrespro.ru", "phone": "+70388944476"}
0005433524909	74AA90	4255 168338	ILYA BELOV	{"email": "ibelov-1980@postgrespro.ru", "phone": "+70070224375"}
0005433524910	66448E	8067 170183	ANTONINA IVANOVA	{"email": "ivanovaantonina.07091960@postgrespro.ru", "phone": "+70339725471"}
0005433524911	66448E	9917 778555	NIKITA ZHUKOV	{"phone": "+70042100402"}
0005433524912	842B77	1890 889437	ALEKSEY IVANOV	{"phone": "+70620470328"}
0005433524913	DCB573	2325 617095	TATYANA GUSEVA	{"email": "guseva.t-1972@postgrespro.ru", "phone": "+70623661699"}
0005433524914	2B20C1	1487 149807	YULIYA FROLOVA	{"email": "yuliya_frolova.02021973@postgrespro.ru", "phone": "+70390846901"}
0005433524915	2B20C1	7982 511627	MAKSIM DENISOV	{"email": "m-denisov-031981@postgrespro.ru", "phone": "+70279785684"}
0005433524916	226A92	4983 274289	GALINA KAZAKOVA	{"phone": "+70120212452"}
0005433524917	8ACC4B	1797 505962	ANTON MOROZOV	{"email": "morozov-anton.051982@postgrespro.ru", "phone": "+70612879335"}
0005433524918	8ACC4B	4954 694348	DMITRIY BELOV	{"email": "belov.dmitriy28061973@postgrespro.ru", "phone": "+70290233318"}
0005433524919	3E53BD	1727 382694	NATALYA MAKAROVA	{"email": "makarovanatalya-111962@postgrespro.ru", "phone": "+70204111548"}
0005433524920	3E53BD	0610 650312	VERA TIMOFEEVA	{"email": "vera.timofeeva-021987@postgrespro.ru", "phone": "+70839440853"}
0005433524921	761ED8	0587 816903	IRINA SOLOVEVA	{"phone": "+70825830845"}
0005433524922	761ED8	0791 261563	ALENA GORBUNOVA	{"phone": "+70124184694"}
0005433524923	1D977D	4867 733146	PAVEL NIKOLAEV	{"email": "nikolaev_pavel-1972@postgrespro.ru", "phone": "+70277606106"}
0005433524924	1D977D	0240 806492	LIDIYA SEMENOVA	{"email": "semenova.l.041975@postgrespro.ru", "phone": "+70528143581"}
0005433524925	12D1C5	8094 514575	VALENTINA YUDINA	{"phone": "+70020199357"}
0005433524926	12D1C5	3868 631977	VLADIMIR OSIPOV	{"phone": "+70390325941"}
0005433524927	33C8AC	8927 511872	VIKTORIYA KUZNECOVA	{"phone": "+70126600745"}
0005433524928	6E2D25	9142 125952	TATYANA KULIKOVA	{"email": "kulikova-t-1973@postgrespro.ru", "phone": "+70378011036"}
0005433524929	808034	3432 008976	ALEKSEY ZHURAVLEV	{"phone": "+70048791022"}
0005433524930	612DEB	1236 759742	VADIM VLASOV	{"email": "vadim.vlasov.18041971@postgrespro.ru", "phone": "+70364784349"}
0005433524931	612DEB	7937 057335	ELENA ILINA	{"email": "eilina-1975@postgrespro.ru", "phone": "+70047656215"}
0005433524932	3A4C28	1666 741047	ELENA SOLOVEVA	{"email": "solovevaelena_071980@postgrespro.ru", "phone": "+70067500489"}
0005433524933	F4E786	2846 512328	IRINA YAKOVLEVA	{"phone": "+70717262797"}
0005433524934	F4E786	6727 655687	SVETLANA VOLKOVA	{"email": "volkova-svetlana-13031967@postgrespro.ru", "phone": "+70419972560"}
0005433524935	F4E786	0773 081398	IGOR DMITRIEV	{"phone": "+70565883950"}
0005433524936	021707	7785 424230	ANDREY YAKOVLEV	{"email": "yakovlev-andrey.1969@postgrespro.ru", "phone": "+70123299700"}
0005433524937	B06BCB	5199 716573	ELENA SEMENOVA	{"phone": "+70782595970"}
0005433524938	B06BCB	7263 294619	TATYANA KOROLEVA	{"phone": "+70478003645"}
0005433524939	FE60CC	6855 754706	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev.071975@postgrespro.ru", "phone": "+70734824990"}
0005433524940	B7CC56	2775 730748	NIKOLAY IVANOV	{"phone": "+70565935733"}
0005433524941	A524B5	9239 495870	LYUBOV ANTONOVA	{"phone": "+70775155663"}
0005433524942	A524B5	8242 991826	MIKHAIL IVANOV	{"phone": "+70636362735"}
0005433524943	8FEEA5	4138 689553	ANNA NIKOLAEVA	{"email": "nikolaeva-anna_1965@postgrespro.ru", "phone": "+70410923788"}
0005433524944	2BB36D	2165 318474	ELENA ZAYCEVA	{"email": "elenazayceva1976@postgrespro.ru", "phone": "+70688904821"}
0005433524945	20484C	5928 292630	ELENA SOROKINA	{"email": "esorokina_17111968@postgrespro.ru", "phone": "+70967074629"}
0005433524946	7CA0F8	8498 396090	DMITRIY STEPANOV	{"phone": "+70943374047"}
0005433524947	C82A11	5005 983217	YULIYA BELOVA	{"email": "belovay_091973@postgrespro.ru", "phone": "+70279676794"}
0005433524948	ADF77C	2385 279332	EVGENIY PAVLOV	{"email": "epavlov111966@postgrespro.ru", "phone": "+70652708314"}
0005433524949	ADF77C	4807 841468	ANASTASIYA ANTONOVA	{"phone": "+70289169751"}
0005433524950	55C82E	6371 270169	EVGENIYA AKIMOVA	{"email": "e-akimova.06061972@postgrespro.ru", "phone": "+70458932412"}
0005433524951	55C82E	0844 366212	IRINA PAVLOVA	{"email": "irina-pavlova_13091974@postgrespro.ru", "phone": "+70055523066"}
0005433524952	38D719	3433 613942	DANILA NAZAROV	{"email": "nazarov-d_1972@postgrespro.ru", "phone": "+70975401843"}
0005433524953	38D719	9858 302917	OLGA KRASNOVA	{"phone": "+70218793046"}
0005433524954	8B758C	0042 850360	ANNA SERGEEVA	{"email": "sergeeva-a.03081968@postgrespro.ru", "phone": "+70230598973"}
0005433524955	A10B26	8482 741696	VASILIY NIKITIN	{"email": "vasiliy.nikitin_111969@postgrespro.ru", "phone": "+70785729003"}
0005433524956	472A9B	4687 468178	PAVEL FEDOROV	{"email": "fedorov_p.27071969@postgrespro.ru", "phone": "+70592812562"}
0005433524957	8841F2	4312 728857	TATYANA PAVLOVA	{"email": "pavlova_tatyana.1971@postgrespro.ru", "phone": "+70887348749"}
0005433524958	6DEDA3	4687 061336	DMITRIY FOMIN	{"email": "fomin-dmitriy121980@postgrespro.ru", "phone": "+70592129219"}
0005433524959	6DEDA3	2509 317084	ELIZAVETA YAKOVLEVA	{"phone": "+70880515358"}
0005433524960	AC2224	4108 816517	NATALYA ANTONOVA	{"phone": "+70848631143"}
0005433524961	AC2224	3728 710685	YAROSLAV MELNIKOV	{"email": "melnikovy.20111969@postgrespro.ru", "phone": "+70377098219"}
0005433524962	AC2224	2486 856769	YURIY SOLOVEV	{"phone": "+70601941624"}
0005433524963	E97608	8256 395151	IGOR SEMENOV	{"email": "i_semenov_1956@postgrespro.ru", "phone": "+70920125661"}
0005433524964	03E3F1	0489 187777	NINA ZAYCEVA	{"email": "nina.zayceva-03011974@postgrespro.ru", "phone": "+70142998946"}
0005433524965	B9B010	4009 929496	TATYANA VOROBEVA	{"phone": "+70109027478"}
0005433524966	B9B010	4983 065627	ELENA KOVALEVA	{"phone": "+70645801121"}
0005433524967	72A45F	5960 020540	ALEKSANDRA KISELEVA	{"phone": "+70830234143"}
0005433524968	98FF7A	3993 664435	KARINA OSIPOVA	{"email": "k-osipova_1969@postgrespro.ru", "phone": "+70364522327"}
0005433524969	A225CB	7047 051301	VALENTINA CHERNOVA	{"email": "vchernova051970@postgrespro.ru", "phone": "+70651065693"}
0005433524970	81DA6A	8399 142139	MARINA VOROBEVA	{"phone": "+70747062723"}
0005433524971	270A75	4971 919186	RAISA TROFIMOVA	{"email": "trofimova_r.27021973@postgrespro.ru", "phone": "+70478957280"}
0005433524972	B52A73	8644 689288	VIKTOR ZAYCEV	{"email": "viktor_zaycev061977@postgrespro.ru", "phone": "+70413880122"}
0005433524973	B52A73	2625 080407	ALEKSANDR MIRONOV	{"phone": "+70583830544"}
0005433524974	C0E916	7843 006858	NIKOLAY KUZNECOV	{"phone": "+70497881110"}
0005433524975	9C9D5E	5446 849957	VLADISLAV ZHUKOV	{"email": "v_zhukov.02031972@postgrespro.ru", "phone": "+70414290821"}
0005433524976	9CF984	5158 119875	IGOR MIRONOV	{"email": "mironov_igor17121977@postgrespro.ru", "phone": "+70242317654"}
0005433524977	3EF178	1482 704481	IRINA KUZMINA	{"email": "irina_kuzmina.101974@postgrespro.ru", "phone": "+70150903955"}
0005433524978	2F14DB	9714 684423	BORIS ANDREEV	{"phone": "+70163447264"}
0005433524979	99E5BC	9023 753197	LYUDMILA KOROLEVA	{"email": "l_koroleva.1963@postgrespro.ru", "phone": "+70705418501"}
0005433524980	183B2E	2192 769010	OLGA SEMENOVA	{"email": "semenovao061976@postgrespro.ru", "phone": "+70969975813"}
0005433524981	135C23	4467 113662	OLESYA ROMANOVA	{"email": "o_romanova101980@postgrespro.ru", "phone": "+70890144428"}
0005433524982	1531A2	1508 603669	NIKOLAY TARASOV	{"email": "tarasovn_031972@postgrespro.ru", "phone": "+70508642854"}
0005433524983	36779D	4387 340480	ANDREY ALEKSANDROV	{"phone": "+70922249617"}
0005433524984	96B73C	0245 984898	OLGA YAKOVLEVA	{"email": "yakovleva_o.031962@postgrespro.ru", "phone": "+70122161809"}
0005433524985	A4C40C	1947 830939	GALINA MELNIKOVA	{"email": "g.melnikova_1977@postgrespro.ru", "phone": "+70022028455"}
0005433524986	56AF51	1790 641396	LILIYA KUZNECOVA	{"phone": "+70612436075"}
0005433524987	56AF51	5667 713821	FATYMA KUZNECOVA	{"email": "kuznecova_fatyma13091973@postgrespro.ru", "phone": "+70591672317"}
0005433524988	9485D1	4385 511277	NATALYA MATVEEVA	{"phone": "+70414545037"}
0005433524989	7C0298	0391 086245	ANDREY SEMENOV	{"email": "andrey_semenov.091978@postgrespro.ru", "phone": "+70041266429"}
0005433524990	7C0298	6864 909843	SVETLANA MAKAROVA	{"phone": "+70590263636"}
0005433524991	01AD93	3304 847164	ALEKSEY NIKOLAEV	{"email": "nikolaeva-25011987@postgrespro.ru", "phone": "+70075395208"}
0005433524992	01AD93	0605 096988	VALENTINA IVANOVA	{"email": "ivanova_v.091972@postgrespro.ru", "phone": "+70098953599"}
0005433524993	01AD93	0251 035416	RAMIS CHERNOV	{"email": "chernov.ramis_02101975@postgrespro.ru", "phone": "+70700930873"}
0005433524994	4804EB	3036 990153	VALENTIN OSIPOV	{"email": "osipov_v_1969@postgrespro.ru", "phone": "+70922065049"}
0005433524995	30322F	7073 834293	LYUDMILA ALEKSEEVA	{"phone": "+70802668642"}
0005433524996	F8FF14	3879 830845	YURIY ANDREEV	{"email": "yuriyandreev051967@postgrespro.ru", "phone": "+70871689091"}
0005433524997	7BABD4	1364 560521	VLADIMIR ALEKSEEV	{"phone": "+70233976715"}
0005433524998	D8E922	5798 390758	ANNA ZOTOVA	{"email": "zotova_anna1966@postgrespro.ru", "phone": "+70653235529"}
0005433524999	45C4BF	0976 217200	EVGENIY KRASNOV	{"phone": "+70672187598"}
0005433525000	45C4BF	5625 589913	NINA ZOTOVA	{"phone": "+70386813607"}
0005433525001	CE96CB	4118 756724	ARTEM FROLOV	{"email": "frolov-a-1985@postgrespro.ru", "phone": "+70729968836"}
0005433525002	CE96CB	8972 016287	VLADIMIR DENISOV	{"email": "v.denisov10011964@postgrespro.ru", "phone": "+70917730466"}
0005433525003	2EDF6D	8088 518210	GALINA RYABOVA	{"phone": "+70490364614"}
0005433525004	2EDF6D	8571 583888	MIKHAIL POPOV	{"email": "popov_mikhail-1971@postgrespro.ru", "phone": "+70027362675"}
0005433525005	328CA0	8862 833031	ELIZAVETA MELNIKOVA	{"email": "melnikova.e01051968@postgrespro.ru", "phone": "+70331653447"}
0005433525006	328CA0	1438 764685	SERGEY SERGEEV	{"phone": "+70276711907"}
0005433525007	99BE44	6298 506348	ALENA FILIPPOVA	{"phone": "+70942425429"}
0005433525008	5479FE	0780 581786	MARIYA ABRAMOVA	{"phone": "+70734114640"}
0005433525009	E6FBB1	9710 499264	ALEKSEY MAKSIMOV	{"phone": "+70359851840"}
0005433525010	E6FBB1	5577 113575	OKSANA RYABOVA	{"email": "oksana-ryabova_1972@postgrespro.ru", "phone": "+70538663323"}
0005433525011	6642DD	2508 633000	ALEKSANDR ALEKSEEV	{"email": "alekseeva_111984@postgrespro.ru", "phone": "+70337145230"}
0005433525012	ECBBA7	6453 530936	SVETLANA BELOVA	{"email": "svetlana-belova071968@postgrespro.ru", "phone": "+70862637247"}
0005433525013	ECBBA7	2514 139189	YULIYA NOVIKOVA	{"phone": "+70066426521"}
0005433525014	7017B0	7619 946910	GALINA MASLOVA	{"email": "maslovagalina1971@postgrespro.ru", "phone": "+70416343715"}
0005433525015	7017B0	9809 106532	DARYA SOROKINA	{"email": "d.sorokina_22101981@postgrespro.ru", "phone": "+70486026615"}
0005433525016	C39974	6327 432628	ALEKSANDR IVANOV	{"phone": "+70673510155"}
0005433525017	2B9305	4327 857678	VLADISLAV MOROZOV	{"phone": "+70659835095"}
0005433525018	2B9305	1289 023815	EKATERINA NOVIKOVA	{"email": "ekaterina-novikova.29021980@postgrespro.ru", "phone": "+70813171571"}
0005433525019	190293	4348 898152	IVAN ABRAMOV	{"phone": "+70203117366"}
0005433525020	190293	3558 622388	NIKOLAY KAZAKOV	{"phone": "+70174838209"}
0005433525021	B2493F	1018 404430	POLINA ALEKSEEVA	{"phone": "+70099162134"}
0005433525022	B2493F	3457 575683	NATALYA POPOVA	{"email": "natalya-popova-29101971@postgrespro.ru", "phone": "+70247397373"}
0005433525023	FA10CC	9198 985961	NATALYA VOLKOVA	{"phone": "+70372457603"}
0005433525024	08654B	8094 238295	SERGEY KULIKOV	{"phone": "+70893371651"}
0005433525025	0BEA3D	9873 148280	GRIGORIY SCHERBAKOV	{"email": "scherbakov-g1974@postgrespro.ru", "phone": "+70410782462"}
0005433525026	0BEA3D	9910 626083	ALEKSEY POPOV	{"email": "popovaleksey18091967@postgrespro.ru", "phone": "+70885589306"}
0005433525027	0BEA3D	0152 285209	VALENTINA KUZNECOVA	{"phone": "+70291461653"}
0005433525028	72111D	0130 633438	DMITRIY ORLOV	{"email": "orlovdmitriy.1972@postgrespro.ru", "phone": "+70094026842"}
0005433525029	72111D	2363 946109	EGOR KUZNECOV	{"email": "kuznecove_1976@postgrespro.ru", "phone": "+70651390592"}
0005433525030	B020B7	7257 126935	OLGA NIKOLAEVA	{"email": "olga.nikolaeva-111972@postgrespro.ru", "phone": "+70985242845"}
0005433525031	556CA4	7232 039859	SERGEY ROMANOV	{"email": "s_romanov1958@postgrespro.ru", "phone": "+70804653369"}
0005433525032	556CA4	8250 168767	YURIY MAKSIMOV	{"phone": "+70444548623"}
0005433525033	941ADB	8435 418351	MAYA VOROBEVA	{"phone": "+70563115521"}
0005433525034	B3069D	0949 158901	PETR KONOVALOV	{"phone": "+70005861169"}
0005433525035	BEF0BB	0778 919558	MIKHAIL FEDOROV	{"phone": "+70098849772"}
0005433525036	C3DF64	7030 390172	SNEZHANA GUSEVA	{"email": "guseva-snezhana_04031976@postgrespro.ru", "phone": "+70545924094"}
0005433525037	C3DF64	8486 357515	ALEKSANDR OSIPOV	{"email": "osipov.a.28071977@postgrespro.ru", "phone": "+70736815852"}
0005433525038	C3DF64	8875 724643	NINA ANTONOVA	{"email": "n.antonova.061975@postgrespro.ru", "phone": "+70711784270"}
0005433525039	204323	5182 574836	NADEZHDA GRISHINA	{"phone": "+70792962578"}
0005433525040	B14426	8840 008093	NATALYA BOGDANOVA	{"phone": "+70822653313"}
0005433525041	E05F63	2869 762036	ANDREY DENISOV	{"email": "a_denisov021970@postgrespro.ru", "phone": "+70530176156"}
0005433525042	4F3A95	3945 877567	OLGA SAVELEVA	{"email": "olga_saveleva06091958@postgrespro.ru", "phone": "+70526495189"}
0005433525043	FDA36C	6410 457488	ALEKSEY FEDOROV	{"phone": "+70172267559"}
0005433525044	2ACD2E	8407 782741	LYUDMILA EFREMOVA	{"phone": "+70437986216"}
0005433525045	2EE2C3	1908 621998	ELENA MOROZOVA	{"phone": "+70905904979"}
0005433525046	98780E	9802 335781	OLGA NAZAROVA	{"phone": "+70345127666"}
0005433525047	9ADBEE	5482 267406	RAISA SMIRNOVA	{"email": "smirnova_raisa-031970@postgrespro.ru", "phone": "+70426323010"}
0005433525048	9ADBEE	9503 802287	ANNA SOKOLOVA	{"phone": "+70687736054"}
0005433525049	DAFB0D	6888 788785	NINA DAVYDOVA	{"phone": "+70376042135"}
0005433525050	E479E2	2405 439395	TATYANA DAVYDOVA	{"phone": "+70848568138"}
0005433525051	087F78	6461 718076	EKATERINA ZAKHAROVA	{"phone": "+70074511994"}
0005433525052	D6DC4C	4076 250923	TATYANA IVANOVA	{"email": "tatyanaivanova-1963@postgrespro.ru", "phone": "+70037815472"}
0005433525053	7712C2	5809 885802	VASILIY ALEKSANDROV	{"email": "v-aleksandrov.051972@postgrespro.ru", "phone": "+70045729231"}
0005433525054	513FC1	0975 984706	YURIY KULIKOV	{"phone": "+70575220701"}
0005433525055	22E1CA	8078 361300	VALERIY FROLOV	{"phone": "+70488716044"}
0005433525056	CFCAF1	4577 148297	LYUBOV ANTONOVA	{"phone": "+70827277198"}
0005433525057	4E6F36	5166 696857	TATYANA MOISEEVA	{"phone": "+70317493057"}
0005433525058	3A0DBC	0230 501757	VLADIMIR VLASOV	{"email": "v_vlasov_29061987@postgrespro.ru", "phone": "+70099052729"}
0005433525059	C996B7	3509 849230	NIKOLAY VOROBEV	{"phone": "+70511371696"}
0005433525060	1C4C0F	1910 856050	EDUARD MAKAROV	{"email": "makarov-eduard-091979@postgrespro.ru", "phone": "+70119614038"}
0005433525061	9F91C4	2858 619092	OKSANA EGOROVA	{"phone": "+70859530024"}
0005433525062	04B301	1514 749368	SERGEY IVANOV	{"email": "ivanov_sergey.101971@postgrespro.ru", "phone": "+70884363871"}
0005433525063	04B301	7228 382235	SERGEY PETROV	{"phone": "+70130689065"}
0005433525064	616676	9955 668653	OLGA PAVLOVA	{"phone": "+70893722712"}
0005433525065	616676	3532 897138	RAISA NAUMOVA	{"email": "r-naumova.21101976@postgrespro.ru", "phone": "+70176689712"}
0005433525066	1BAF57	2106 263276	MARINA GAVRILOVA	{"email": "gavrilova.marina-1970@postgrespro.ru", "phone": "+70891947906"}
0005433525067	1BAF57	8091 932161	NADEZHDA PETROVA	{"email": "nadezhda-petrova011982@postgrespro.ru", "phone": "+70078021034"}
0005433525068	73A385	7187 942125	TATYANA NAZAROVA	{"phone": "+70738836519"}
0005433525069	73A385	8303 907048	OLGA VOROBEVA	{"email": "vorobeva.olga1962@postgrespro.ru", "phone": "+70992683346"}
0005433525070	BE9BC3	7128 910771	OKSANA KUZMINA	{"email": "o_kuzmina.091960@postgrespro.ru", "phone": "+70386609185"}
0005433525071	E1AA8C	5404 829900	IVAN ABRAMOV	{"phone": "+70994069639"}
0005433525308	2F7287	0582 353535	IVAN GUSEV	{"phone": "+70496667700"}
0005433525072	DAA83C	5576 328784	ALENA VOLKOVA	{"email": "volkova_a-11051965@postgrespro.ru", "phone": "+70130347910"}
0005433525073	84012E	7362 412590	IRINA ABRAMOVA	{"email": "abramova-i_1964@postgrespro.ru", "phone": "+70798231089"}
0005433525074	383122	4463 893784	YURIY BONDARENKO	{"email": "y.bondarenko1968@postgrespro.ru", "phone": "+70610445735"}
0005433525075	9695B9	2512 891914	VITALIY VASILEV	{"email": "vasilev_v-121988@postgrespro.ru", "phone": "+70659669529"}
0005433525076	8A279E	0404 463809	MARIYA NAUMOVA	{"email": "naumova_mariya.18011970@postgrespro.ru", "phone": "+70140399030"}
0005433525077	68FA72	4237 849962	SERGEY ZAYCEV	{"phone": "+70871244065"}
0005433525078	68FA72	5170 005371	VERA POPOVA	{"phone": "+70854001390"}
0005433525079	68FA72	9613 459247	VALENTINA POPOVA	{"phone": "+70787489812"}
0005433525080	FB38C9	0915 568763	VALERIY VOROBEV	{"phone": "+70787918884"}
0005433525081	FB38C9	9656 637514	NATALYA MELNIKOVA	{"phone": "+70126508113"}
0005433525082	3DB5EA	7022 583693	VIKTOR KUZNECOV	{"email": "kuznecovviktor-1982@postgrespro.ru", "phone": "+70622947118"}
0005433525083	CC8D6E	7539 526540	MIKHAIL SOKOLOV	{"email": "sokolov-mikhail.071979@postgrespro.ru", "phone": "+70329197592"}
0005433525084	CC8D6E	5993 134487	SVETLANA GERASIMOVA	{"email": "gerasimovasvetlana.101975@postgrespro.ru", "phone": "+70433431649"}
0005433525085	50DAA1	2107 930935	ALEKSEY GORBUNOV	{"phone": "+70170446006"}
0005433525086	E6B5E1	3274 981667	TAMARA BELOVA	{"phone": "+70503041171"}
0005433525087	B5A2E7	1685 641873	LARISA DENISOVA	{"email": "larisadenisova_031973@postgrespro.ru", "phone": "+70295847311"}
0005433525088	59DBFE	6052 509556	VALENTIN KULIKOV	{"email": "kulikov-valentin_091974@postgrespro.ru", "phone": "+70973258325"}
0005433525089	59DBFE	8717 016263	PAVEL KUZNECOV	{"phone": "+70233442103"}
0005433525090	685B17	1524 144047	TAMARA LOGINOVA	{"email": "tamara_loginova-071974@postgrespro.ru", "phone": "+70820046153"}
0005433525091	685B17	1135 492979	VLADIMIR TIKHONOV	{"email": "tikhonov-vladimir-03041974@postgrespro.ru", "phone": "+70894950323"}
0005433525092	685B17	7592 678195	VYACHESLAV FEDOROV	{"phone": "+70694539785"}
0005433525093	9ECDD3	2865 696980	ZINAIDA MIRONOVA	{"email": "mironovaz1976@postgrespro.ru", "phone": "+70357601336"}
0005433525094	3E4A19	8419 900124	DMITRIY MOISEEV	{"email": "moiseev-dmitriy_101962@postgrespro.ru", "phone": "+70208863859"}
0005433525095	3E4A19	6520 222837	NATALYA MAKAROVA	{"phone": "+70931690874"}
0005433525096	A86ECB	2526 333035	MIKHAIL SERGEEV	{"phone": "+70543372462"}
0005433525097	A86ECB	8187 315683	GULNARA SOKOLOVA	{"email": "gulnara_sokolova.1960@postgrespro.ru", "phone": "+70036830679"}
0005433525098	A86ECB	8516 489764	DANIIL DMITRIEV	{"email": "daniil.dmitriev.121967@postgrespro.ru", "phone": "+70927821130"}
0005433525099	702C03	7330 612283	GALINA YUDINA	{"phone": "+70796718260"}
0005433525100	5D0906	4056 074247	MIKHAIL MAKSIMOV	{"email": "m.maksimov_23101967@postgrespro.ru", "phone": "+70673627960"}
0005433525101	5D0906	9973 329270	LYUDMILA KOROLEVA	{"phone": "+70277553819"}
0005433525102	ABA227	1133 908376	IRINA RYABOVA	{"email": "i_ryabova-1979@postgrespro.ru", "phone": "+70314041945"}
0005433525103	F8E600	6867 972526	VASILIY SIDOROV	{"phone": "+70707914932"}
0005433525104	16C274	6434 821279	ALFIYA ZAYCEVA	{"phone": "+70667169939"}
0005433525105	16C274	6340 836526	SERGEY MOISEEV	{"email": "s_moiseev-111970@postgrespro.ru", "phone": "+70622228464"}
0005433525106	2B134A	3521 390496	VLADIMIR KRASNOV	{"phone": "+70808649238"}
0005433525107	7F1D61	5393 531290	NADEZHDA FROLOVA	{"phone": "+70482208358"}
0005433525108	6B629D	3438 623281	VLADIMIR BELOV	{"phone": "+70018530057"}
0005433525109	6B629D	6400 330943	YURIY KOZLOV	{"phone": "+70972960868"}
0005433525110	84EB47	0638 989804	VIKTOR VASILEV	{"email": "vasilev_v.03031972@postgrespro.ru", "phone": "+70459959064"}
0005433525111	84EB47	2550 503776	EKATERINA ZHURAVLEVA	{"email": "zhuravlevae.13031971@postgrespro.ru", "phone": "+70824262329"}
0005433525112	498E1F	0562 869769	ZHANNA MALYSHEVA	{"phone": "+70341205254"}
0005433525113	D710D3	6030 639118	VITALIY KOZLOV	{"email": "vkozlov-13111973@postgrespro.ru", "phone": "+70214689589"}
0005433525114	9E6849	6730 339038	DENIS FEDOROV	{"email": "denis-fedorov_1969@postgrespro.ru", "phone": "+70276065501"}
0005433525115	E59D60	9488 877713	OLEG KRASNOV	{"email": "krasnov.oleg.051967@postgrespro.ru", "phone": "+70159448005"}
0005433525116	0A7996	5298 872049	IRINA MARTYNOVA	{"phone": "+70923334451"}
0005433525117	CE4F62	0386 478607	ANASTASIYA BORISOVA	{"phone": "+70160859797"}
0005433525118	AC691D	7200 108295	VLADIMIR SMIRNOV	{"phone": "+70198058312"}
0005433525119	AC691D	7542 608125	SVETLANA EGOROVA	{"email": "egorovas-1973@postgrespro.ru", "phone": "+70918408955"}
0005433525120	150C63	6371 683401	ANNA SOKOLOVA	{"email": "annasokolova-1965@postgrespro.ru", "phone": "+70756369355"}
0005433525121	4849AA	9684 864078	LYUBOV KOVALEVA	{"email": "l-kovaleva-101974@postgrespro.ru", "phone": "+70102766294"}
0005433525122	803D38	3913 184980	VLADIMIR NIKOLAEV	{"email": "v_nikolaev.1967@postgrespro.ru", "phone": "+70544970576"}
0005433525123	803D38	9201 041357	IGOR STEPANOV	{"email": "stepanovigor-1967@postgrespro.ru", "phone": "+70074262613"}
0005433525124	B33F0E	0229 138207	IGOR ZAYCEV	{"phone": "+70748581550"}
0005433525125	B33F0E	6092 813241	EDUARD MAKSIMOV	{"phone": "+70160184162"}
0005433525126	350BDE	7279 692234	ALEKSANDR MIRONOV	{"phone": "+70906926146"}
0005433525127	688A56	4445 485878	ELENA SOLOVEVA	{"phone": "+70579395849"}
0005433525128	688A56	3544 663810	ALEKSANDR ALEKSEEV	{"email": "alekseev_a-17051973@postgrespro.ru", "phone": "+70576039967"}
0005433525129	85DE75	4447 541037	ZHANNA KARPOVA	{"phone": "+70100950092"}
0005433525130	A5EC03	5386 431013	ALEKSANDR IVANOV	{"phone": "+70825096707"}
0005433525131	C43F70	3647 112562	ALEKSANDR TIMOFEEV	{"phone": "+70577305473"}
0005433525132	C43F70	4698 916120	ANNA KOZLOVA	{"phone": "+70805079018"}
0005433525133	FA1864	9911 355726	IVAN CHERNOV	{"email": "i_chernov14091974@postgrespro.ru", "phone": "+70812595779"}
0005433525134	FA1864	8372 706433	ZINAIDA ANTONOVA	{"email": "antonova-zinaida.051966@postgrespro.ru", "phone": "+70445832465"}
0005433525135	FA1864	3833 413323	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva-29061962@postgrespro.ru", "phone": "+70427146567"}
0005433525136	7FCB82	5088 561144	YURIY ANTONOV	{"email": "antonovyuriy_1969@postgrespro.ru", "phone": "+70130845629"}
0005433525137	B7C5D0	6164 681864	NATALYA VOLKOVA	{"phone": "+70604422013"}
0005433525138	B7C5D0	8994 638544	VENERA ANISIMOVA	{"email": "v-anisimova.23031976@postgrespro.ru", "phone": "+70014200162"}
0005433525139	B7C5D0	0576 096317	KONSTANTIN TIKHONOV	{"email": "tikhonov-konstantin1975@postgrespro.ru", "phone": "+70758845791"}
0005433525140	5291A1	1669 529657	SERGEY NIKOLAEV	{"email": "sergey_nikolaev_1972@postgrespro.ru", "phone": "+70638857267"}
0005433525141	F74906	1840 107652	YURIY MAKSIMOV	{"email": "maksimov-yuriy-1969@postgrespro.ru", "phone": "+70042235792"}
0005433525142	673CED	5458 020312	ELENA SERGEEVA	{"email": "sergeeva-elena-28071969@postgrespro.ru", "phone": "+70855638341"}
0005433525143	E32C65	6536 417712	SVETLANA VOLKOVA	{"email": "volkova.svetlana12041980@postgrespro.ru", "phone": "+70470040734"}
0005433525144	21BEB0	9639 109993	VLADIMIR FEDOTOV	{"phone": "+70748842420"}
0005433525145	21BEB0	2507 660612	ELENA MELNIKOVA	{"phone": "+70882545264"}
0005433525146	BF416B	4579 889492	TAMARA IVANOVA	{"email": "tamara-ivanova.1966@postgrespro.ru", "phone": "+70967135629"}
0005433525147	63D1C5	2182 669296	TATYANA POTAPOVA	{"email": "tatyana.potapova-09081970@postgrespro.ru", "phone": "+70365748431"}
0005433525148	63D1C5	2852 981912	ANDREY SERGEEV	{"email": "andreysergeev_1965@postgrespro.ru", "phone": "+70525525128"}
0005433525149	9E5641	9796 158780	ALEKSANDR OSIPOV	{"email": "osipovaleksandr_111974@postgrespro.ru", "phone": "+70943010843"}
0005433525150	3258EC	7540 126735	TAMARA BARANOVA	{"email": "baranovatamara.081975@postgrespro.ru", "phone": "+70848054931"}
0005433525151	6B3943	1223 658297	MARIANNA NIKOLAEVA	{"phone": "+70679495395"}
0005433525152	2C215E	1427 456728	ELENA GERASIMOVA	{"phone": "+70650838546"}
0005433525153	987240	7795 228813	VALENTINA SOKOLOVA	{"phone": "+70346273216"}
0005433525154	987240	2651 342098	VLADIMIR ISAEV	{"phone": "+70238464571"}
0005433525155	2F0EC6	3644 416245	LARISA PETROVA	{"email": "petrovalarisa.071982@postgrespro.ru", "phone": "+70573737350"}
0005433525156	2F0EC6	5137 242799	ELENA VOLKOVA	{"email": "elena-volkova_1980@postgrespro.ru", "phone": "+70075127530"}
0005433525157	2F0EC6	7931 923466	ILYA ANTONOV	{"phone": "+70557779731"}
0005433525158	4F2C3B	7265 456304	SERGEY ANDREEV	{"email": "andreev_sergey_1981@postgrespro.ru", "phone": "+70438723839"}
0005433525159	C02B02	8447 035859	IGOR SCHERBAKOV	{"email": "scherbakov.igor.1969@postgrespro.ru", "phone": "+70248823397"}
0005433525160	039894	3221 871962	ALEKSANDR KRASNOV	{"phone": "+70103086027"}
0005433525161	039894	1448 473496	OLEG ZAKHAROV	{"phone": "+70401565557"}
0005433525162	039894	0407 220306	OLGA KOROLEVA	{"phone": "+70901709130"}
0005433525163	9DF45F	7048 680763	VALENTINA GUSEVA	{"phone": "+70358384911"}
0005433525164	B8AE8B	8689 826234	DMITRIY VOLKOV	{"email": "volkov_d.20111971@postgrespro.ru", "phone": "+70680285627"}
0005433525165	B8AE8B	2366 158086	GENNADIY ZAKHAROV	{"email": "gennadiy.zakharov_01021966@postgrespro.ru", "phone": "+70103786939"}
0005433525166	107EC7	0705 157961	VIKTOR SOLOVEV	{"phone": "+70282048631"}
0005433525167	3C5E15	7402 428402	ANATOLIY ZHURAVLEV	{"email": "a_zhuravlev-1981@postgrespro.ru", "phone": "+70575706161"}
0005433525168	CAE5B4	1987 982875	OKSANA VOLKOVA	{"phone": "+70408993416"}
0005433525169	D2A0AC	8560 543354	IGOR YAKOVLEV	{"email": "yakovlevigor.1983@postgrespro.ru", "phone": "+70658838692"}
0005433525170	4AAF0B	3843 221744	LYUDMILA IVANOVA	{"email": "l-ivanova.04061974@postgrespro.ru", "phone": "+70323246409"}
0005433525171	F72B49	9104 588832	ALEKSANDR KUZNECOV	{"phone": "+70472360067"}
0005433525172	C62F32	9776 610941	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr-14061972@postgrespro.ru", "phone": "+70520387127"}
0005433525173	198498	4150 003084	ILYA TIKHONOV	{"phone": "+70072720944"}
0005433525174	823AFE	1979 270692	DARYA MALYSHEVA	{"email": "darya-malysheva-01121979@postgrespro.ru", "phone": "+70558868232"}
0005433525175	978305	3868 293961	LYUBOV NIKITINA	{"phone": "+70497859674"}
0005433525176	98E48B	7385 912945	EKATERINA MIRONOVA	{"phone": "+70849533952"}
0005433525177	C33B99	9015 975578	MIKHAIL SIDOROV	{"phone": "+70563048540"}
0005433525178	C33B99	1030 870641	ELENA NIKOLAEVA	{"phone": "+70883080476"}
0005433525179	7EA066	5650 415967	OLGA ALEKSEEVA	{"phone": "+70676845495"}
0005433525180	7EA066	7919 127445	SERGEY SOKOLOV	{"phone": "+70224136812"}
0005433525181	7EA066	5980 616106	NIKOLAY GORBUNOV	{"phone": "+70515304765"}
0005433525182	D46923	6075 703234	SERGEY KUZNECOV	{"email": "sergey.kuznecov-1976@postgrespro.ru", "phone": "+70135058399"}
0005433525183	DEADA2	6363 956027	DMITRIY ZHURAVLEV	{"phone": "+70429256373"}
0005433525184	DEADA2	0219 497112	MARINA MAKAROVA	{"email": "marina-makarova1976@postgrespro.ru", "phone": "+70992606001"}
0005433525185	DEADA2	5631 857632	VADIM SHEVCHENKO	{"phone": "+70073930013"}
0005433525186	4DAE14	6320 173510	ANDREY STEPANOV	{"phone": "+70914801137"}
0005433525187	053750	1017 838815	LYUDMILA POTAPOVA	{"email": "potapova_l_03091976@postgrespro.ru", "phone": "+70729301846"}
0005433525188	03C55B	0818 130607	TATYANA SOKOLOVA	{"phone": "+70552172739"}
0005433525189	72FC18	2587 023156	LYUBOV DANILOVA	{"email": "danilova_lyubov_08071969@postgrespro.ru", "phone": "+70794839101"}
0005433525190	98AF89	9740 347909	ANDREY ILIN	{"email": "a.ilin-121961@postgrespro.ru", "phone": "+70112568922"}
0005433525191	98AF89	2211 553047	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila_1967@postgrespro.ru", "phone": "+70293554447"}
0005433525192	B8E26B	7590 404284	TAMARA ANTONOVA	{"email": "antonovatamara-22081966@postgrespro.ru", "phone": "+70433986671"}
0005433525193	0606E3	2364 534929	GALINA IVANOVA	{"email": "ivanova.galina.22071964@postgrespro.ru", "phone": "+70600057567"}
0005433525194	8E2D3D	6471 859745	ANNA SERGEEVA	{"email": "anna.sergeeva-011972@postgrespro.ru", "phone": "+70872743494"}
0005433525195	C18372	5665 842592	VASILIY TIMOFEEV	{"email": "vtimofeev.081975@postgrespro.ru", "phone": "+70715082215"}
0005433525196	C18372	7571 543867	ELENA PETROVA	{"phone": "+70615464672"}
0005433525197	2E8B9E	9433 227141	NATALYA YAKOVLEVA	{"email": "nyakovleva19081971@postgrespro.ru", "phone": "+70520743156"}
0005433525198	EB12A7	6121 631545	ZINAIDA SOROKINA	{"phone": "+70284124291"}
0005433525199	EB12A7	9466 943541	VASILIY EGOROV	{"phone": "+70495258416"}
0005433525200	15BFAD	6307 586344	ANASTASIYA ROMANOVA	{"phone": "+70733849204"}
0005433525201	15BFAD	9794 176379	SERGEY SERGEEV	{"email": "sergeevsergey1977@postgrespro.ru", "phone": "+70561652079"}
0005433525202	15BFAD	0572 175973	NATALYA SOROKINA	{"email": "sorokina-natalya1977@postgrespro.ru", "phone": "+70792564456"}
0005433525203	18914B	8362 441570	ALEKSANDR SMIRNOV	{"email": "smirnova-051981@postgrespro.ru", "phone": "+70465139959"}
0005433525204	B3EBA7	5707 177745	SERGEY KULIKOV	{"email": "sergey-kulikov.29101976@postgrespro.ru", "phone": "+70125978034"}
0005433525205	78C081	7299 609151	ALBINA LEBEDEVA	{"phone": "+70775331511"}
0005433525206	2BEEFC	4477 119126	VLADIMIR KUZNECOV	{"phone": "+70581257716"}
0005433525207	2BEEFC	8582 655531	VERA CHERNOVA	{"phone": "+70349867727"}
0005433525208	763347	4906 381498	VLADIMIR KARPOV	{"phone": "+70137417590"}
0005433525209	1EE028	5146 397587	ANASTASIYA SMIRNOVA	{"phone": "+70153465832"}
0005433525210	1EE028	4001 573563	ELIZAVETA ISAEVA	{"phone": "+70813324639"}
0005433525211	FADEB1	6244 524384	NATALYA SOLOVEVA	{"email": "n_soloveva-1972@postgrespro.ru", "phone": "+70073016281"}
0005433525212	F14F76	4614 094459	LARISA LOGINOVA	{"email": "loginova-larisa-17041975@postgrespro.ru", "phone": "+70934094136"}
0005433525213	F14F76	9904 455500	SERGEY KUZMIN	{"phone": "+70838864074"}
0005433525214	F14F76	2632 813913	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey.05021966@postgrespro.ru", "phone": "+70699302747"}
0005433525215	F9A75F	2323 200381	SERGEY TIKHONOV	{"email": "s-tikhonov_051966@postgrespro.ru", "phone": "+70206561218"}
0005433525216	373FAC	8738 014731	OLGA FILATOVA	{"phone": "+70441337619"}
0005433525217	472259	7515 572567	NINA LEBEDEVA	{"email": "lebedevanina-1972@postgrespro.ru", "phone": "+70057058921"}
0005433525218	472259	9024 415799	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_vladimir.12031977@postgrespro.ru", "phone": "+70123584066"}
0005433525219	179C9C	2535 324141	DARYA NIKITINA	{"phone": "+70790074071"}
0005433525220	179C9C	9056 963651	ANATOLIY KOZLOV	{"phone": "+70609977877"}
0005433525221	B3C02F	6882 449852	ROMAN MELNIKOV	{"email": "r-melnikov-041967@postgrespro.ru", "phone": "+70830648001"}
0005433525222	B7396A	3070 975666	YURIY GORBUNOV	{"email": "y_gorbunov.1970@postgrespro.ru", "phone": "+70169067226"}
0005433525223	B7396A	5663 848553	KONSTANTIN SOROKIN	{"phone": "+70169726626"}
0005433525224	5D222F	4172 944178	YAKOV ISAEV	{"phone": "+70283970576"}
0005433525225	28C12A	6663 402375	ALI BARANOV	{"email": "alibaranov.24121970@postgrespro.ru", "phone": "+70091010970"}
0005433525226	28C12A	5760 661346	OLESYA NESTEROVA	{"phone": "+70244006490"}
0005433525227	8AEAB2	4803 206508	ANTONINA KONOVALOVA	{"email": "konovalova-a.1982@postgrespro.ru", "phone": "+70543111641"}
0005433525228	8AEAB2	5275 377834	NATALYA KONOVALOVA	{"email": "konovalova-natalya121968@postgrespro.ru", "phone": "+70299642931"}
0005433525229	F0AFAC	2599 509653	VASILIY KUZNECOV	{"phone": "+70028153577"}
0005433525230	F0AFAC	1992 350106	VALENTINA VOROBEVA	{"email": "vorobeva_valentina-17061970@postgrespro.ru", "phone": "+70971466468"}
0005433525231	B4E2F8	8102 543449	ALEKSEY ALEKSEEV	{"email": "aalekseev.10041963@postgrespro.ru", "phone": "+70593785488"}
0005433525232	B5BCFF	9942 664049	ANGELINA ZAKHAROVA	{"email": "zakharova.angelina1958@postgrespro.ru", "phone": "+70460467763"}
0005433525233	CDC033	8149 125865	ALEKSEY DENISOV	{"email": "aleksey-denisov-12121974@postgrespro.ru", "phone": "+70313202738"}
0005433525234	A79CFB	2650 327640	ANNA DANILOVA	{"email": "danilova.a_121979@postgrespro.ru", "phone": "+70339874903"}
0005433525235	A79CFB	8410 989169	IGOR SIDOROV	{"phone": "+70176415425"}
0005433525236	E6DE2D	4954 403552	VALERIY KAZAKOV	{"email": "kazakov.v1965@postgrespro.ru", "phone": "+70918159310"}
0005433525237	E6DE2D	3724 599693	MIKHAIL ROMANOV	{"email": "mromanov_11091969@postgrespro.ru", "phone": "+70860020417"}
0005433525238	D8F3EC	6270 822769	DENIS PAVLOV	{"email": "denis_pavlov-1972@postgrespro.ru", "phone": "+70321736087"}
0005433525239	D8F3EC	7281 105710	VIKTORIYA FROLOVA	{"email": "frolova_viktoriya.111972@postgrespro.ru", "phone": "+70730722293"}
0005433525240	F3EB6C	1919 610701	EVGENIYA TITOVA	{"email": "evgeniyatitova-18011967@postgrespro.ru", "phone": "+70985113921"}
0005433525241	F3EB6C	7444 591672	LYUDMILA STEPANOVA	{"email": "l_stepanova.091959@postgrespro.ru", "phone": "+70862752784"}
0005433525242	CA0671	7667 646133	TAMARA SCHERBAKOVA	{"email": "tamara-scherbakova071956@postgrespro.ru", "phone": "+70452694776"}
0005433525243	CA0671	9172 555782	DMITRIY ILIN	{"email": "ilin.dmitriy_011981@postgrespro.ru", "phone": "+70173768556"}
0005433525244	457CD8	7746 484539	TATYANA KOVALEVA	{"email": "kovaleva-t.16051974@postgrespro.ru", "phone": "+70607487752"}
0005433525245	2DE3F4	6576 970624	FEDOR GUSEV	{"email": "gusevfedor18101980@postgrespro.ru", "phone": "+70052530003"}
0005433525246	1B2C9F	5639 351611	KLAVDIYA NIKOLAEVA	{"phone": "+70577328246"}
0005433525247	4CE75A	8781 151867	LARISA KARPOVA	{"phone": "+70424135188"}
0005433525248	4CE75A	7115 298038	SERGEY MATVEEV	{"phone": "+70552676056"}
0005433525249	EEE060	9529 586369	ELENA DANILOVA	{"phone": "+70025109675"}
0005433525250	2063FC	6483 511998	MARINA ZHURAVLEVA	{"email": "zhuravleva-marina121973@postgrespro.ru", "phone": "+70637528264"}
0005433525251	2063FC	4168 048057	VADIM CHERNOV	{"phone": "+70823364769"}
0005433525252	B49BA7	4999 180068	VLADIMIR ISAEV	{"email": "vladimirisaev.061976@postgrespro.ru", "phone": "+70941945125"}
0005433525253	1FDA7A	5504 027974	VIKTOR NOVIKOV	{"email": "viktornovikov.24021971@postgrespro.ru", "phone": "+70292543242"}
0005433525254	6F5FB5	3629 576161	ARTEMIY ISAEV	{"email": "isaeva04031969@postgrespro.ru", "phone": "+70079694291"}
0005433525255	6F5FB5	2963 357322	NATALYA LOGINOVA	{"phone": "+70800913496"}
0005433525256	E3C804	2187 784247	ANATOLIY VASILEV	{"email": "vasilev-a_041972@postgrespro.ru", "phone": "+70874790551"}
0005433525257	E3C804	0162 505750	MARIYA OSIPOVA	{"phone": "+70255465181"}
0005433525258	BF89E1	0605 532190	LYUBOV STEPANOVA	{"phone": "+70550345307"}
0005433525259	BF89E1	0561 889601	EGOR SAVELEV	{"phone": "+70415074210"}
0005433525260	BF89E1	6583 688667	VALENTINA POTAPOVA	{"email": "potapova.valentina-28101971@postgrespro.ru", "phone": "+70670103222"}
0005433525261	537218	9428 484263	LYUDMILA BELOVA	{"email": "belovalyudmila-1973@postgrespro.ru", "phone": "+70574606863"}
0005433525262	3C09BC	4561 072836	LYUDMILA ILINA	{"email": "ilina-l_091967@postgrespro.ru", "phone": "+70412176370"}
0005433525263	3C09BC	9454 900591	DANIL BELOV	{"phone": "+70319930295"}
0005433525264	96F271	9157 427284	SERGEY BELOV	{"email": "sergeybelov_1972@postgrespro.ru", "phone": "+70350975975"}
0005433525265	D4CC5B	7090 068188	ANDREY SEMENOV	{"phone": "+70165865931"}
0005433525266	F6DC02	2717 517780	EVGENIYA GUSEVA	{"phone": "+70051331008"}
0005433525267	1BE0D4	0106 444071	VALERIY ILIN	{"email": "ilin.valeriy.1979@postgrespro.ru", "phone": "+70410303788"}
0005433525268	1494FD	9882 098848	KONSTANTIN KUZNECOV	{"email": "k_kuznecov_1981@postgrespro.ru", "phone": "+70965319473"}
0005433525269	1494FD	2713 352316	ANDREY ABRAMOV	{"email": "andrey.abramov-1973@postgrespro.ru", "phone": "+70360188887"}
0005433525270	B7A650	8887 905023	DENIS KAZAKOV	{"phone": "+70912267187"}
0005433525271	B7A650	6120 334021	SERGEY KAZAKOV	{"email": "kazakov.sergey_1977@postgrespro.ru", "phone": "+70414119811"}
0005433525272	F0FF8F	8697 893754	NATALYA IVANOVA	{"phone": "+70980183188"}
0005433525273	2F2F48	2676 003068	NADEZHDA SERGEEVA	{"email": "sergeevanadezhda_06091973@postgrespro.ru", "phone": "+70668398145"}
0005433525274	A5B184	6129 895166	NIKOLAY IVANOV	{"email": "nikolayivanov-09051974@postgrespro.ru", "phone": "+70821801546"}
0005433525275	8296B0	2936 005741	MARIYA FILIPPOVA	{"phone": "+70732588584"}
0005433525276	8296B0	0452 454896	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov.1961@postgrespro.ru", "phone": "+70715656776"}
0005433525277	E0DC25	2809 184387	SERGEY KUZMIN	{"email": "kuzmin_s071985@postgrespro.ru", "phone": "+70739172801"}
0005433525278	E74499	9376 339624	PAVEL CHERNOV	{"email": "pavel.chernov.1967@postgrespro.ru", "phone": "+70123280589"}
0005433525279	E74499	1981 431385	TATYANA MEDVEDEVA	{"email": "medvedeva-t_31121972@postgrespro.ru", "phone": "+70156846354"}
0005433525280	E74499	9701 305953	KAMIL FROLOV	{"phone": "+70949590981"}
0005433525281	AAB328	5183 290818	SERGEY SERGEEV	{"email": "sergey-sergeev15041969@postgrespro.ru", "phone": "+70002664967"}
0005433525282	AAB328	8725 806292	ANDREY MIRONOV	{"email": "andrey.mironov-1963@postgrespro.ru", "phone": "+70191310591"}
0005433525283	FCD447	2520 453649	OLGA IVANOVA	{"email": "o_ivanova091965@postgrespro.ru", "phone": "+70938601887"}
0005433525284	FCD447	0603 386853	OLGA POPOVA	{"email": "popova-olga_051975@postgrespro.ru", "phone": "+70510300943"}
0005433525285	DBFDE3	3211 779055	ILSHAT BELOV	{"phone": "+70529491150"}
0005433525286	3A5596	3020 935991	OLESYA IVANOVA	{"phone": "+70780946800"}
0005433525287	C98243	8287 090200	VLADIMIR SOROKIN	{"email": "v.sorokin1968@postgrespro.ru", "phone": "+70723875482"}
0005433525288	C98243	8059 351053	ANATOLIY KUZMIN	{"email": "kuzmina_1970@postgrespro.ru", "phone": "+70384556089"}
0005433525289	7A1D34	9879 509205	NINA SOKOLOVA	{"phone": "+70681942543"}
0005433525290	7A1D34	4024 331421	ANDREY NIKOLAEV	{"email": "andrey-nikolaev_1965@postgrespro.ru", "phone": "+70154711010"}
0005433525291	1B45BD	6013 823484	ALEKSEY STEPANOV	{"email": "astepanov-11101981@postgrespro.ru", "phone": "+70907125224"}
0005433525292	BB5179	3272 460910	EVGENIYA PAVLOVA	{"email": "e.pavlova.051981@postgrespro.ru", "phone": "+70053432044"}
0005433525293	BB5179	8518 608569	SVETLANA LUKYANOVA	{"phone": "+70005950226"}
0005433525294	D1E985	8659 536696	NINA ZAYCEVA	{"email": "zayceva.nina1973@postgrespro.ru", "phone": "+70227420773"}
0005433525295	D1E985	8671 369230	ANDREY YAKOVLEV	{"email": "yakovlev-andrey.17081970@postgrespro.ru", "phone": "+70016522899"}
0005433525296	B4E67C	4345 619519	DMITRIY POPOV	{"phone": "+70684902604"}
0005433525297	154914	9044 087619	ALEKSANDR PETROV	{"phone": "+70433664617"}
0005433525298	154914	7160 583726	IRINA KOROLEVA	{"email": "koroleva.irina1982@postgrespro.ru", "phone": "+70096350361"}
0005433525299	D9AD8F	8341 577101	FAIL NIKOLAEV	{"phone": "+70722677848"}
0005433525300	D9AD8F	5276 052429	DMITRIY RODIONOV	{"phone": "+70819018633"}
0005433525301	576F09	2620 169404	MARIYA MOROZOVA	{"email": "mariyamorozova_09121959@postgrespro.ru", "phone": "+70869924595"}
0005433525302	EF52B8	6273 027996	MARIYA ALEKSEEVA	{"email": "mariyaalekseeva-29091973@postgrespro.ru", "phone": "+70443016630"}
0005433525303	EF52B8	7437 040126	LYUDMILA SMIRNOVA	{"email": "smirnovalyudmila_031972@postgrespro.ru", "phone": "+70774366532"}
0005433525304	E06933	6390 104072	VLADIMIR FILIPPOV	{"email": "filippov-vladimir1961@postgrespro.ru", "phone": "+70472241608"}
0005433525305	E06933	3627 966689	ALEKSEY VASILEV	{"email": "vasilev-aleksey081975@postgrespro.ru", "phone": "+70397470570"}
0005433525306	B5D375	4610 848675	VIKTOR FROLOV	{"email": "frolovv_1960@postgrespro.ru", "phone": "+70750674809"}
0005433525307	B5D375	2356 880008	ANATOLIY SOKOLOV	{"email": "sokolovanatoliy26031970@postgrespro.ru", "phone": "+70517963829"}
0005433525309	D21969	4208 232257	VYACHESLAV ALEKSEEV	{"email": "v.alekseev-1991@postgrespro.ru", "phone": "+70465443645"}
0005433525310	D21969	2470 563849	LIDIYA YAKOVLEVA	{"phone": "+70902688151"}
0005433525311	CFC9F1	4314 296813	MARIYA TIKHONOVA	{"phone": "+70624047263"}
0005433525312	655215	4841 546291	VLADIMIR PETROV	{"email": "vladimir_petrov081965@postgrespro.ru", "phone": "+70498640179"}
0005433525313	9699E3	6019 579359	MARIYA TITOVA	{"phone": "+70179322083"}
0005433525314	9699E3	3762 617285	ALEKSEY IVANOV	{"phone": "+70619779310"}
0005433525315	DF9CD6	3078 580392	VLADIMIR BORISOV	{"email": "v.borisov.1974@postgrespro.ru", "phone": "+70954699346"}
0005433525316	9933C4	7397 403053	SERGEY ANDREEV	{"phone": "+70558308724"}
0005433525317	2DC593	7550 949984	BORIS FROLOV	{"email": "frolov-b-011966@postgrespro.ru", "phone": "+70303562784"}
0005433525318	0EBBD8	7136 015368	YURIY SERGEEV	{"email": "sergeevyuriy031981@postgrespro.ru", "phone": "+70027086358"}
0005433525319	C89CB9	3607 384967	MIKHAIL KUDRYASHOV	{"email": "mikhail_kudryashov.021984@postgrespro.ru", "phone": "+70627510610"}
0005433525320	3A7DAA	5020 390637	GULNARA KOZLOVA	{"email": "kozlova-g1978@postgrespro.ru", "phone": "+70670634011"}
0005433525321	6C85B8	6179 209118	ALEKSANDR GRIGOREV	{"email": "agrigorev.09021982@postgrespro.ru", "phone": "+70502861057"}
0005433525322	6C85B8	1274 076226	SERGEY ANDREEV	{"email": "andreev-s.17021971@postgrespro.ru", "phone": "+70993727602"}
0005433525323	BA9426	1085 787121	SERGEY ZAKHAROV	{"phone": "+70163848430"}
0005433525324	BA9426	2139 230613	GALINA TIMOFEEVA	{"phone": "+70297003423"}
0005433525325	BA9426	0246 157857	FEDOR KRASNOV	{"phone": "+70350390445"}
0005433525326	BEFAE6	2500 133191	VALENTINA DMITRIEVA	{"email": "dmitrievav.1984@postgrespro.ru", "phone": "+70538434217"}
0005433525327	BEFAE6	8544 597062	MARIYA VOLKOVA	{"email": "mariyavolkova-10081972@postgrespro.ru", "phone": "+70295346247"}
0005433525328	601E74	1483 095876	ALEKSEY MARTYNOV	{"phone": "+70399861367"}
0005433525329	601E74	0259 655965	ANNA KRASNOVA	{"email": "anna-krasnova.081978@postgrespro.ru", "phone": "+70875846978"}
0005433525330	691CD6	2882 689985	ANGELINA NIKOLAEVA	{"phone": "+70133488777"}
0005433525331	691CD6	6007 569030	NINA NESTEROVA	{"phone": "+70511377589"}
0005433525332	CFBEA8	6152 594449	SOFIYA ZOTOVA	{"phone": "+70116224152"}
0005433525333	D0A445	1557 200265	VALERIY MELNIKOV	{"phone": "+70116603149"}
0005433525334	9A5A91	0671 803740	EVGENIY TIMOFEEV	{"email": "timofeev_e.111970@postgrespro.ru", "phone": "+70352111185"}
0005433525335	4FBA6C	7523 340616	SERGEY DAVYDOV	{"email": "davydov_sergey.14011982@postgrespro.ru", "phone": "+70876250769"}
0005433525336	A77296	5565 270599	TATYANA SAVELEVA	{"email": "tsaveleva1970@postgrespro.ru", "phone": "+70203526754"}
0005433525337	A77296	3473 975661	MAKSIM KUDRYASHOV	{"email": "kudryashov.m_06031972@postgrespro.ru", "phone": "+70231041036"}
0005433525338	16AD06	2315 635219	NELLI KUZNECOVA	{"email": "kuznecova-n1980@postgrespro.ru", "phone": "+70475872297"}
0005433525339	2E9DCA	2092 775187	LYUDMILA ZOTOVA	{"email": "l.zotova18121977@postgrespro.ru", "phone": "+70427780111"}
0005433525340	4B2B23	9225 154200	ALEKSANDR FILIPPOV	{"email": "filippov_a.16011968@postgrespro.ru", "phone": "+70924031922"}
0005433525341	9C2C85	9540 635204	NADEZHDA NESTEROVA	{"phone": "+70428765850"}
0005433525342	B2A7DA	2852 436660	YULIYA IVANOVA	{"phone": "+70471759209"}
0005433525343	BC1CB1	2988 280561	EVGENIY SIDOROV	{"phone": "+70540629518"}
0005433525344	BC1CB1	6336 527116	EVGENIYA SMIRNOVA	{"phone": "+70576128237"}
0005433525345	A83091	7883 875099	ANDREY FEDOROV	{"email": "fedorov.andrey-27031971@postgrespro.ru", "phone": "+70580311114"}
0005433525346	3DE47C	5230 262487	GALINA LEBEDEVA	{"email": "g-lebedeva_1978@postgrespro.ru", "phone": "+70865055645"}
0005433525347	339E2D	7865 998384	ANTON NIKOLAEV	{"email": "anton-nikolaev.1976@postgrespro.ru", "phone": "+70207525068"}
0005433525348	8F460E	5670 951117	ALEKSANDRA ARKHIPOVA	{"phone": "+70421289847"}
0005433525349	F94A9A	3443 187253	LYUDMILA NAUMOVA	{"phone": "+70581181060"}
0005433525350	F94A9A	2827 784061	ELENA GUSEVA	{"email": "e.guseva_011962@postgrespro.ru", "phone": "+70661407691"}
0005433525351	D50F75	3859 957062	ALEKSANDRA TIMOFEEVA	{"email": "timofeeva_a-1965@postgrespro.ru", "phone": "+70735323406"}
0005433525352	D50F75	0023 809639	ANNA PAVLOVA	{"email": "anna_pavlova-1970@postgrespro.ru", "phone": "+70521900187"}
0005433525353	D50F75	1552 476928	VIKTOR SAVELEV	{"email": "savelev.viktor-1967@postgrespro.ru", "phone": "+70378912087"}
0005433525354	DEC0EB	9039 881418	KIRILL ORLOV	{"email": "orlovkirill1966@postgrespro.ru", "phone": "+70901366686"}
0005433525355	0D0DB0	1698 752678	IRINA MEDVEDEVA	{"email": "imedvedeva-1973@postgrespro.ru", "phone": "+70590319726"}
0005433525356	21BBCC	4332 456518	MARGARITA ORLOVA	{"email": "orlova.margarita_21011973@postgrespro.ru", "phone": "+70550138638"}
0005433525357	CE145E	5134 376731	SHAMIL CHERNOV	{"email": "chernovshamil_24051971@postgrespro.ru", "phone": "+70206245814"}
0005433525358	389320	7330 750492	KSENIYA KUZMINA	{"email": "kuzmina_kseniya.02011964@postgrespro.ru", "phone": "+70317335825"}
0005433525359	96C745	6047 393972	LYAYSAN IVANOVA	{"phone": "+70882121747"}
0005433525360	96C745	2525 436691	SERGEY STEPANOV	{"email": "stepanov-s.051982@postgrespro.ru", "phone": "+70415367529"}
0005433525361	F0E8D7	6461 591352	DMITRIY STEPANOV	{"phone": "+70610179816"}
0005433525362	F0E8D7	4209 528730	SVETLANA EFREMOVA	{"phone": "+70993486395"}
0005433525363	01E1E1	3393 610771	DMITRIY MOROZOV	{"email": "morozov.d-05021967@postgrespro.ru", "phone": "+70271159654"}
0005433525364	6CD1B4	7020 500348	IRINA IVANOVA	{"email": "i.ivanova-30031976@postgrespro.ru", "phone": "+70498456785"}
0005433527248	79E7B7	3746 862838	NIKOLAY GRIGOREV	{"phone": "+70422444879"}
0005433527199	E967C6	8897 111949	ALEKSANDR POPOV	{"phone": "+70641030778"}
0005433527200	9CE97F	4517 034695	TATYANA GAVRILOVA	{"phone": "+70512171503"}
0005433527201	021E78	6052 333661	ELENA NIKOLAEVA	{"phone": "+70718202815"}
0005433527202	6CFA33	2388 217541	TATYANA KUDRYASHOVA	{"phone": "+70326418821"}
0005433527203	A29177	4212 768141	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov-081971@postgrespro.ru", "phone": "+70314587163"}
0005433527204	F2EE8E	5530 331383	YAROSLAV DMITRIEV	{"email": "ydmitriev1975@postgrespro.ru", "phone": "+70915611281"}
0005433527205	38AA32	8978 768745	TATYANA MAKSIMOVA	{"email": "maksimovatatyana_01111968@postgrespro.ru", "phone": "+70342696048"}
0005433527206	38AA32	1285 974556	DIANA MELNIKOVA	{"email": "melnikova_d25061964@postgrespro.ru", "phone": "+70420001265"}
0005433527207	153C0F	0713 421279	ILMIRA SEMENOVA	{"email": "semenova-i-17101976@postgrespro.ru", "phone": "+70523582234"}
0005433527208	153C0F	1375 891566	ALEKSANDR KOROLEV	{"email": "aleksandr_korolev-011976@postgrespro.ru", "phone": "+70560465672"}
0005433527209	153C0F	4210 245541	PAVEL IVANOV	{"email": "pavel_ivanov031970@postgrespro.ru", "phone": "+70113496409"}
0005433527210	153C0F	3993 747067	NADEZHDA KOROLEVA	{"email": "n.koroleva-12081973@postgrespro.ru", "phone": "+70609943052"}
0005433527211	4AA78B	6421 326442	IVAN DMITRIEV	{"email": "dmitriev_ivan_1967@postgrespro.ru", "phone": "+70868373462"}
0005433527212	4AA78B	1415 909957	TATYANA GUSEVA	{"email": "t.guseva-1970@postgrespro.ru", "phone": "+70023419533"}
0005433527213	4AA78B	2997 512658	TATYANA DMITRIEVA	{"phone": "+70878659792"}
0005433527214	BF111D	2697 538947	EVGENIY CHERNOV	{"email": "e-chernov091968@postgrespro.ru", "phone": "+70501157267"}
0005433527215	A4DEB1	1713 820683	VALERIYA FILATOVA	{"email": "v.filatova_121979@postgrespro.ru", "phone": "+70345981617"}
0005433527216	11E88F	9458 104443	LYUDMILA EGOROVA	{"phone": "+70830776393"}
0005433527217	F071D6	4000 195110	NIKOLAY GUSEV	{"email": "gusev.n1971@postgrespro.ru", "phone": "+70068036687"}
0005433527218	F071D6	0509 357968	ARTEM KISELEV	{"email": "kiselev_a.27071953@postgrespro.ru", "phone": "+70280681984"}
0005433527219	9B3EE6	1302 394506	DANIIL ZHURAVLEV	{"phone": "+70736976901"}
0005433527220	22AFF9	3843 683120	VALENTINA KISELEVA	{"email": "kiseleva.v.1966@postgrespro.ru", "phone": "+70521048615"}
0005433527221	993487	7384 567883	NIKOLAY FROLOV	{"email": "frolovnikolay041964@postgrespro.ru", "phone": "+70434117995"}
0005433527222	152D37	5091 818711	TAMARA TIKHONOVA	{"phone": "+70438037858"}
0005433527223	152D37	5772 873977	OLGA YUDINA	{"phone": "+70198625372"}
0005433527224	152D37	5778 607584	ALEKSANDR PETROV	{"email": "petrov_aleksandr091977@postgrespro.ru", "phone": "+70063871661"}
0005433527225	152D37	4220 502703	YAROSLAV SERGEEV	{"email": "sergeevyaroslav.071983@postgrespro.ru", "phone": "+70922672591"}
0005433527226	34E3F8	6546 626806	DMITRIY GAVRILOV	{"phone": "+70948669149"}
0005433527227	8B0649	1542 952347	PETR BARANOV	{"phone": "+70390289526"}
0005433527228	8B0649	1705 838770	LYUDMILA MATVEEVA	{"email": "matveeva.lyudmila111969@postgrespro.ru", "phone": "+70170157988"}
0005433527229	A3B104	8367 562841	LYUDMILA SEMENOVA	{"email": "lyudmila_semenova_1973@postgrespro.ru", "phone": "+70409455492"}
0005433527230	A3B104	1516 170546	VLADIMIR KONOVALOV	{"email": "konovalovvladimir-1971@postgrespro.ru", "phone": "+70918530033"}
0005433527231	3D2E3A	4618 146353	DMITRIY SIDOROV	{"email": "sidorovd061978@postgrespro.ru", "phone": "+70300111840"}
0005433527232	3D2E3A	4305 382971	RAIS NIKOLAEV	{"email": "r-nikolaev.14121977@postgrespro.ru", "phone": "+70316928679"}
0005433527233	5A9D1A	1702 409947	SVETLANA ZHURAVLEVA	{"email": "zhuravleva.s28111980@postgrespro.ru", "phone": "+70850607297"}
0005433527234	6203B4	5381 944685	ALEKSEY VASILEV	{"phone": "+70510049622"}
0005433527235	D3C1A0	0829 595577	MARYAM IVANOVA	{"email": "ivanovamaryam_1972@postgrespro.ru", "phone": "+70312590252"}
0005433527236	D3C1A0	6320 320103	GALINA SEMENOVA	{"email": "galinasemenova_1962@postgrespro.ru", "phone": "+70554949349"}
0005433527237	057EEF	5916 078001	DMITRIY FILIPPOV	{"email": "dfilippov30051984@postgrespro.ru", "phone": "+70999518430"}
0005433527238	057EEF	4015 157833	VITALIY POPOV	{"email": "v_popov_23121965@postgrespro.ru", "phone": "+70527805736"}
0005433527239	2F5331	9527 887650	ALEKSEY KUDRYASHOV	{"email": "aleksey.kudryashov.1981@postgrespro.ru", "phone": "+70297074554"}
0005433527240	2F5331	3511 605732	NATALYA CHERNOVA	{"phone": "+70203062656"}
0005433527241	81C7D6	3485 713139	YULIYA IVANOVA	{"phone": "+70741004782"}
0005433527242	266BCB	3360 484946	VYACHESLAV PETROV	{"phone": "+70308022352"}
0005433527243	DDC415	6305 564902	NIKOLAY ILIN	{"phone": "+70218494920"}
0005433527244	279228	5038 981690	ILYA OSIPOV	{"phone": "+70639437719"}
0005433527245	80485D	4354 898820	SERGEY FROLOV	{"phone": "+70561427831"}
0005433527246	80485D	7413 126433	YULIYA MAKAROVA	{"phone": "+70495894200"}
0005433527247	79E7B7	3588 078191	OLGA KAZAKOVA	{"phone": "+70574814731"}
0005433527249	975C78	7962 714544	PAVEL SMIRNOV	{"phone": "+70560230744"}
0005433527250	975C78	8068 488639	EVGENIY NAUMOV	{"email": "naumovevgeniy_081967@postgrespro.ru", "phone": "+70809329811"}
0005433527251	42D143	2232 571095	SVETLANA STEPANOVA	{"email": "s-stepanova-12091975@postgrespro.ru", "phone": "+70543857399"}
0005433527252	668504	7184 919249	IVAN GRIGOREV	{"phone": "+70752275358"}
0005433527253	668504	7166 914231	OLEG KUDRYASHOV	{"phone": "+70255943424"}
0005433527254	8C6DFC	1155 182062	EKATERINA DAVYDOVA	{"phone": "+70893628990"}
0005433527255	8C6DFC	6770 881048	NATALYA SMIRNOVA	{"phone": "+70414867616"}
0005433527256	8A1628	9557 742845	SERGEY VASILEV	{"email": "vasilev_s_1977@postgrespro.ru", "phone": "+70600031195"}
0005433527257	DEE369	1462 660332	MAKSIM DAVYDOV	{"phone": "+70905464213"}
0005433527258	DEE369	6099 977739	ANDREY MELNIKOV	{"email": "melnikov-andrey-05041984@postgrespro.ru", "phone": "+70288377550"}
0005433527259	DEE369	2227 760163	GALINA VOROBEVA	{"email": "g-vorobeva.1981@postgrespro.ru", "phone": "+70862226701"}
0005433527260	3C8F91	7889 743643	ALEKSANDR KUZNECOV	{"phone": "+70132228559"}
0005433527261	77ABE2	2853 253670	ROMAN FROLOV	{"phone": "+70106073222"}
0005433527262	77ABE2	5376 170139	ELENA VASILEVA	{"phone": "+70044920468"}
0005433527263	FDED56	4186 359011	VIKTOR SAVELEV	{"email": "vsavelev061962@postgrespro.ru", "phone": "+70576547271"}
0005433527264	FDED56	5686 293472	MAKSIM ALEKSANDROV	{"phone": "+70754045744"}
0005433527265	E91FA1	3298 448798	IVAN SMIRNOV	{"phone": "+70039964421"}
0005433527266	10B06F	9834 880483	MARINA OSIPOVA	{"email": "m.osipova-1969@postgrespro.ru", "phone": "+70235648531"}
0005433527267	16AA59	8338 941562	ALEKSANDR SMIRNOV	{"email": "smirnov-a-1963@postgrespro.ru", "phone": "+70107194983"}
0005433527268	900574	4654 942948	SVETLANA PETROVA	{"email": "s-petrova_071980@postgrespro.ru", "phone": "+70959372974"}
0005433527269	4EB1CC	7883 222986	ARTEM KARPOV	{"email": "karpov_artem_1970@postgrespro.ru", "phone": "+70383552193"}
0005433527270	280784	2114 503940	KSENIYA ISAEVA	{"phone": "+70031370473"}
0005433527271	BB1C19	1938 935395	ZLATA SEMENOVA	{"phone": "+70580903583"}
0005433527272	BB1C19	1896 464028	PETR SOROKIN	{"email": "sorokinp-12041978@postgrespro.ru", "phone": "+70887196906"}
0005433527273	428569	4521 927797	MIKHAIL KAZAKOV	{"phone": "+70593154432"}
0005433527274	428569	6755 119020	NINA MAKSIMOVA	{"phone": "+70308676760"}
0005433527275	428569	8899 821385	NIKITA SOKOLOV	{"phone": "+70231604803"}
0005433527276	FD956D	8872 170718	NIKOLAY FROLOV	{"email": "nikolay-frolov09111965@postgrespro.ru", "phone": "+70669932253"}
0005433527277	229D41	5522 564656	OLGA KUZNECOVA	{"email": "o_kuznecova06021972@postgrespro.ru", "phone": "+70833268542"}
0005433527278	11F1BC	9224 318774	ANDREY KUZNECOV	{"email": "kuznecovandrey-1964@postgrespro.ru", "phone": "+70432352172"}
0005433527279	11F1BC	0961 595412	NATALYA ANDREEVA	{"email": "natalya_andreeva_17071964@postgrespro.ru", "phone": "+70046071678"}
0005433527280	ED52EC	9772 694378	ANATOLIY NIKOLAEV	{"phone": "+70778297816"}
0005433527281	ED52EC	0219 752568	ANATOLIY ZHUKOV	{"email": "zhukov-a-1971@postgrespro.ru", "phone": "+70667128311"}
0005433527282	7C9950	0226 441031	OKSANA PAVLOVA	{"phone": "+70598378877"}
0005433527283	291D43	9446 019790	VALENTINA PETROVA	{"email": "petrova-valentina_1972@postgrespro.ru", "phone": "+70211250217"}
0005433527284	F83FF6	2732 655792	OLGA SMIRNOVA	{"phone": "+70620921712"}
0005433527285	903DD8	9081 473028	ALENA ROMANOVA	{"email": "romanova_a-12041975@postgrespro.ru", "phone": "+70409136811"}
0005433527286	903DD8	7499 071040	LYUDMILA MAKAROVA	{"email": "makarova-l_1965@postgrespro.ru", "phone": "+70832791492"}
0005433527287	A6A957	9643 211459	ALEKSEY MOISEEV	{"phone": "+70301075279"}
0005433527288	A6A957	5987 370172	ANASTASIYA KOZLOVA	{"phone": "+70977092621"}
0005433527289	DDB07D	9744 838377	VITALIY GUSEV	{"phone": "+70647360438"}
0005433527290	DDB07D	1756 428047	TATYANA MALYSHEVA	{"phone": "+70462397580"}
0005433527291	DDB07D	1577 863906	GUZEL ILINA	{"phone": "+70269994728"}
0005433527292	579F78	3178 825672	ALEKSANDR ROMANOV	{"phone": "+70855971894"}
0005433527293	E08273	3302 046981	ARTEM ORLOV	{"email": "orlovartem_1968@postgrespro.ru", "phone": "+70877059250"}
0005433527294	55300D	7365 771389	VLADIMIR TARASOV	{"email": "v-tarasov.16101965@postgrespro.ru", "phone": "+70192048896"}
0005433527295	55300D	4136 023002	ALEKSANDR MOROZOV	{"email": "a.morozov_03061977@postgrespro.ru", "phone": "+70698672680"}
0005433527296	C9CDE2	3529 713892	VALERIY MEDVEDEV	{"phone": "+70975680440"}
0005433527297	C9CDE2	1340 012682	VASILIY SMIRNOV	{"email": "smirnov_vasiliy.1970@postgrespro.ru", "phone": "+70414625521"}
0005433527298	56A732	8927 185646	ALEKSANDR ZAYCEV	{"phone": "+70595021299"}
0005433527299	AA598B	1766 577724	VLADIMIR POPOV	{"email": "v_popov_05021965@postgrespro.ru", "phone": "+70907432455"}
0005433527300	67975A	9156 996520	KONSTANTIN ANDREEV	{"email": "andreevkonstantin1954@postgrespro.ru", "phone": "+70120377345"}
0005433527301	5BC076	2924 707907	VALERIYA LAZAREVA	{"email": "lazareva.valeriya02091966@postgrespro.ru", "phone": "+70152825988"}
0005433527302	CA95E4	1190 390568	GALINA FILATOVA	{"email": "filatova.g-091985@postgrespro.ru", "phone": "+70315334379"}
0005433527303	154692	1384 284925	SERGEY VASILEV	{"phone": "+70990293805"}
0005433527304	154692	3795 657832	ANZHELIKA KONOVALOVA	{"email": "a-konovalova_1991@postgrespro.ru", "phone": "+70389350626"}
0005433527305	2D1304	6948 263045	ALEKSANDRA KUZNECOVA	{"phone": "+70466987096"}
0005433527306	CDE234	5411 594750	ALEKSEY ALEKSEEV	{"phone": "+70349819078"}
0005433527307	6308F2	3017 602257	DMITRIY NIKITIN	{"email": "nikitin-dmitriy011963@postgrespro.ru", "phone": "+70429663888"}
0005433527308	6308F2	7840 474245	VLADISLAV NAZAROV	{"phone": "+70497141655"}
0005433527309	6308F2	9849 279202	LYUBOV DMITRIEVA	{"email": "l-dmitrieva031983@postgrespro.ru", "phone": "+70479932631"}
0005433527310	A0D82B	5651 918504	IVAN VOLKOV	{"phone": "+70113286526"}
0005433527311	A0D82B	5287 856432	NATALYA MAKAROVA	{"email": "makarova-natalya.091964@postgrespro.ru", "phone": "+70471716043"}
0005433527312	952E8E	8527 502710	ANASTASIYA MAKSIMOVA	{"phone": "+70772748347"}
0005433527313	DA4DDA	8694 604566	SVETLANA OVCHINNIKOVA	{"email": "sovchinnikova.1970@postgrespro.ru", "phone": "+70719002638"}
0005433527314	B4D0AB	8998 440675	EVGENIY KISELEV	{"phone": "+70126557563"}
0005433527315	B2382D	7892 041398	RAISA FROLOVA	{"phone": "+70733762077"}
0005433527316	44D056	4974 437776	MAKSIM KAZAKOV	{"email": "m_kazakov.17111983@postgrespro.ru", "phone": "+70342082025"}
0005433527317	C0B89B	5236 055779	OLGA DMITRIEVA	{"email": "o_dmitrieva-1986@postgrespro.ru", "phone": "+70188866673"}
0005433527318	8100EA	7124 001919	ANDREY BORISOV	{"email": "andrey-borisov_27071971@postgrespro.ru", "phone": "+70354789993"}
0005433527319	807C76	0287 519826	ALBERT SHEVCHENKO	{"phone": "+70992295311"}
0005433527320	A331B2	9884 557134	SVETLANA NIKOLAEVA	{"email": "nikolaevasvetlana_1980@postgrespro.ru", "phone": "+70640609156"}
0005433527321	A331B2	2626 440393	MARIYA IVANOVA	{"phone": "+70902172237"}
0005433527322	A331B2	9600 848042	NADEZHDA KUZNECOVA	{"email": "n.kuznecova_15021976@postgrespro.ru", "phone": "+70771098684"}
0005433527323	7EE40B	5712 330177	DMITRIY EGOROV	{"phone": "+70862392092"}
0005433527324	B82CDC	1150 777927	NATALYA NIKITINA	{"email": "nikitina-natalya_07021973@postgrespro.ru", "phone": "+70292043205"}
0005433527325	33CEE6	0026 895539	ANATOLIY ROMANOV	{"email": "romanov.anatoliy_20091972@postgrespro.ru", "phone": "+70939078369"}
0005433527326	6F5D01	9045 124601	GALINA BORISOVA	{"phone": "+70009113753"}
0005433527327	6F5D01	0390 525960	VERA KARPOVA	{"phone": "+70638370124"}
0005433527328	0ABA76	1228 447808	GALINA KOROLEVA	{"phone": "+70684138978"}
0005433527329	57977E	5640 282913	EVGENIY STEPANOV	{"email": "evgeniy.stepanov.24041977@postgrespro.ru", "phone": "+70375567681"}
0005433527330	57977E	1190 348305	KONSTANTIN BORISOV	{"phone": "+70197628419"}
0005433527331	CB531A	5092 253925	DMITRIY CHERNOV	{"email": "chernovd_30121968@postgrespro.ru", "phone": "+70578176943"}
0005433527332	CB531A	6005 808319	YURIY MELNIKOV	{"phone": "+70855854464"}
0005433527333	9CD412	3816 674808	YULIYA KOROLEVA	{"phone": "+70878532566"}
0005433527334	90D2D3	1367 559167	LYUBOV TARASOVA	{"email": "l_tarasova.091967@postgrespro.ru", "phone": "+70635291293"}
0005433527335	DA8787	9364 814591	TATYANA MELNIKOVA	{"phone": "+70464498739"}
0005433527336	5D73F0	4213 756333	OKSANA RYABOVA	{"phone": "+70255172820"}
0005433527337	F3EC0F	1463 386136	SERGEY DENISOV	{"email": "denisov-sergey.23081982@postgrespro.ru", "phone": "+70735187676"}
0005433527338	72922D	9858 369366	EKATERINA MOROZOVA	{"email": "e_morozova-051983@postgrespro.ru", "phone": "+70314820406"}
0005433527339	77E0CC	7668 533310	OLEG GAVRILOV	{"email": "oleg.gavrilov_1952@postgrespro.ru", "phone": "+70380661811"}
0005433527340	233007	3350 680325	ALEKSEY VASILEV	{"phone": "+70690339139"}
0005433527341	A2912A	2134 881914	LYUDMILA ZAKHAROVA	{"phone": "+70939425753"}
0005433527342	A2912A	7885 084796	LARISA SEMENOVA	{"email": "semenova-larisa-011980@postgrespro.ru", "phone": "+70787421031"}
0005433527343	54AEA0	1488 143096	OLGA SOROKINA	{"phone": "+70300343259"}
0005433527344	59CDD7	4893 788549	EGOR MOROZOV	{"email": "morozov.egor.011983@postgrespro.ru", "phone": "+70049223759"}
0005433527345	59CDD7	9391 377066	IRINA ANISIMOVA	{"email": "ianisimova111972@postgrespro.ru", "phone": "+70788004617"}
0005433527346	218329	2547 547895	NIKOLAY MELNIKOV	{"email": "melnikovn.071968@postgrespro.ru", "phone": "+70831689938"}
0005433527347	067FD5	1236 617878	VIKTOR PETROV	{"email": "petrov-viktor-091977@postgrespro.ru", "phone": "+70670418830"}
0005433527348	067FD5	8694 760645	EKATERINA VASILEVA	{"email": "e_vasileva.121984@postgrespro.ru", "phone": "+70712309195"}
0005433527349	B8DBDE	3007 678912	NIKOLAY BORISOV	{"phone": "+70530648648"}
0005433527350	B8DBDE	0256 027589	VALENTIN KOROLEV	{"phone": "+70263382608"}
0005433527351	A877FC	9183 485278	TAMARA POTAPOVA	{"email": "potapova.tamara-30061982@postgrespro.ru", "phone": "+70127300290"}
0005433527352	A877FC	9146 184548	IRINA NOVIKOVA	{"phone": "+70622747904"}
0005433527353	67EC44	5608 758325	STANISLAV CHERNOV	{"email": "s-chernov1964@postgrespro.ru", "phone": "+70290763997"}
0005433527354	67EC44	5515 299362	YURIY NIKITIN	{"email": "yuriy.nikitin.18051971@postgrespro.ru", "phone": "+70068297865"}
0005433527355	59A84D	3344 604568	SERGEY KONOVALOV	{"phone": "+70041536392"}
0005433527356	445750	0627 053844	VLADIMIR MAKAROV	{"phone": "+70165707591"}
0005433527357	E60C4E	3435 120690	GENNADIY ANTONOV	{"phone": "+70363964037"}
0005433527358	E60C4E	2786 241222	KAMIL ZHURAVLEV	{"email": "k_zhuravlev25071975@postgrespro.ru", "phone": "+70900649833"}
0005433527359	E60C4E	3205 218605	ELENA MOISEEVA	{"email": "moiseeva_elena_1977@postgrespro.ru", "phone": "+70345468336"}
0005433527360	E60C4E	6220 366404	VYACHESLAV NOVIKOV	{"email": "vyacheslav_novikov.101968@postgrespro.ru", "phone": "+70082060844"}
0005433527361	290913	4787 219799	ANATOLIY KUZNECOV	{"phone": "+70897502952"}
0005433527362	290913	3595 127332	DARYA MASLOVA	{"email": "darya.maslova.011960@postgrespro.ru", "phone": "+70572113613"}
0005433527363	E4927A	9162 265249	VALENTINA TARASOVA	{"email": "vtarasova_121963@postgrespro.ru", "phone": "+70334601791"}
0005433527364	C69B4E	6437 819134	LYUDMILA KRASNOVA	{"email": "lyudmilakrasnova071971@postgrespro.ru", "phone": "+70451392772"}
0005433527365	24072C	9351 416418	VYACHESLAV SMIRNOV	{"email": "v_smirnov_081976@postgrespro.ru", "phone": "+70052205084"}
0005433527366	AC7755	3471 505149	KRISTINA NAZAROVA	{"email": "nazarova_kristina.111977@postgrespro.ru", "phone": "+70237824221"}
0005433527367	AA372A	4499 519867	VLADIMIR GRIGOREV	{"phone": "+70588185032"}
0005433527368	9F5451	9364 860069	OLGA VASILEVA	{"phone": "+70765657981"}
0005433527369	9F5451	1249 545955	NATALYA SOKOLOVA	{"email": "n-sokolova081978@postgrespro.ru", "phone": "+70215435588"}
0005433527370	30B0BC	9214 756193	TAMARA FROLOVA	{"email": "t-frolova_1970@postgrespro.ru", "phone": "+70526147295"}
0005433527371	C2D7BD	5456 204360	LARISA TROFIMOVA	{"email": "larisa_trofimova_071975@postgrespro.ru", "phone": "+70074436179"}
0005433527372	7E91AB	7449 011681	MIKHAIL IVANOV	{"phone": "+70533718266"}
0005433527373	7E91AB	0275 079939	DMITRIY EGOROV	{"email": "dmitriyegorov-071962@postgrespro.ru", "phone": "+70071147001"}
0005433527374	B4D797	7966 229443	SERGEY FILIPPOV	{"email": "sfilippov17091980@postgrespro.ru", "phone": "+70305592701"}
0005433527375	4D2E7B	5878 740121	GALINA TARASOVA	{"phone": "+70546540763"}
0005433529210	8B0DE2	8379 927542	EKATERINA GERASIMOVA	{"email": "gerasimovae1963@postgrespro.ru", "phone": "+70754293664"}
0005433529211	BBE27F	6151 048427	VLADIMIR EGOROV	{"email": "egorov.vladimir_1961@postgrespro.ru", "phone": "+70915099171"}
0005433529212	BBE27F	5567 618724	ELENA KOVALEVA	{"phone": "+70786652212"}
0005433529213	D92D9E	8305 779472	NATALYA IVANOVA	{"email": "ivanova_natalya-1974@postgrespro.ru", "phone": "+70187690104"}
0005433529214	53C36A	3255 948241	MARIYA NIKITINA	{"email": "nikitina-mariya-19041962@postgrespro.ru", "phone": "+70462931044"}
0005433529215	0A1149	3034 169938	NATALYA BELOVA	{"email": "n.belova.061975@postgrespro.ru", "phone": "+70339613317"}
0005433529216	0A1149	0890 682941	NIKOLAY EGOROV	{"phone": "+70351100389"}
0005433529217	D08704	9030 504491	ANTON SHEVCHENKO	{"email": "shevchenko.a.041958@postgrespro.ru", "phone": "+70136315341"}
0005433529218	D08704	6369 546200	EVGENIY YAKOVLEV	{"email": "yakovlev_e_091958@postgrespro.ru", "phone": "+70867244191"}
0005433529219	4C1197	6161 770867	IGOR IVANOV	{"phone": "+70864560883"}
0005433529220	4C1197	0476 940145	SERGEY SOROKIN	{"email": "sorokin.sergey1971@postgrespro.ru", "phone": "+70516349881"}
0005433529221	4C1197	4677 334172	EVGENIY SHEVCHENKO	{"phone": "+70342612418"}
0005433529222	A291EB	9166 513841	EKATERINA VASILEVA	{"phone": "+70571421760"}
0005433529223	4F598B	6330 184601	SERGEY RODIONOV	{"phone": "+70644392166"}
0005433529224	4F598B	4748 861838	LIDIYA CHERNOVA	{"phone": "+70972671008"}
0005433529225	3315DC	2000 393373	NIKOLAY SCHERBAKOV	{"phone": "+70472145405"}
0005433529226	475CFB	3475 553383	EVGENIY POPOV	{"email": "popove-26071970@postgrespro.ru", "phone": "+70921839149"}
0005433529227	475CFB	3771 968794	OLGA EGOROVA	{"phone": "+70364472015"}
0005433529228	6BB6E9	9210 850303	GALINA ZAKHAROVA	{"phone": "+70034798581"}
0005433529229	191F36	0975 712746	LYUDMILA POTAPOVA	{"email": "lyudmila-potapova.1978@postgrespro.ru", "phone": "+70853848298"}
0005433529230	8C7882	5069 815635	DMITRIY CHERNOV	{"email": "dmitriy.chernov-1962@postgrespro.ru", "phone": "+70334468335"}
0005433529231	0F6508	0246 765012	YURIY KULIKOV	{"phone": "+70995822370"}
0005433529232	C61FEE	6619 499293	DANIL SOKOLOV	{"email": "d_sokolov_1973@postgrespro.ru", "phone": "+70792132408"}
0005433529233	C61FEE	5819 126103	OLGA KOVALEVA	{"phone": "+70522072965"}
0005433529234	C61FEE	2852 451511	ELENA MAKAROVA	{"phone": "+70917758149"}
0005433529235	5C58A3	5844 129072	NADEZHDA SMIRNOVA	{"email": "n_smirnova-1966@postgrespro.ru", "phone": "+70865736005"}
0005433529236	5C58A3	4827 771462	ALEKSANDR MIRONOV	{"email": "a.mironov-081980@postgrespro.ru", "phone": "+70498265408"}
0005433529237	DEB307	4329 725563	YULIYA PAVLOVA	{"email": "y_pavlova_1963@postgrespro.ru", "phone": "+70142485618"}
0005433529238	1634C8	9819 768274	EVGENIY MEDVEDEV	{"phone": "+70280431577"}
0005433529239	494BEB	2066 037879	ARTEM KOZLOV	{"phone": "+70645955620"}
0005433529240	23C065	0226 545594	DMITRIY MEDVEDEV	{"email": "dmitriymedvedev.1971@postgrespro.ru", "phone": "+70867518050"}
0005433529241	23C065	3578 435342	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov.04051973@postgrespro.ru", "phone": "+70654007069"}
0005433529242	68EAFF	5791 021544	MAKSIM TIMOFEEV	{"phone": "+70523803219"}
0005433529243	68EAFF	0372 519325	NATALYA LUKYANOVA	{"email": "lukyanovanatalya.121974@postgrespro.ru", "phone": "+70403150212"}
0005433529244	BBD50B	0017 712641	VLADIMIR ZAKHAROV	{"phone": "+70939600390"}
0005433529245	E796FF	3231 350378	DMITRIY KONOVALOV	{"email": "konovalov-d_22051956@postgrespro.ru", "phone": "+70326591073"}
0005433529246	B7D134	9943 754174	KRISTINA GORBUNOVA	{"email": "gorbunovakristina_101973@postgrespro.ru", "phone": "+70981846696"}
0005433529247	72C7DD	5875 593222	ELENA SOLOVEVA	{"phone": "+70132304218"}
0005433529248	906E99	2401 560814	GALINA ANISIMOVA	{"email": "galina-anisimova.071981@postgrespro.ru", "phone": "+70137827937"}
0005433529249	002B8A	3886 556603	GALINA OSIPOVA	{"email": "osipova-galina.071964@postgrespro.ru", "phone": "+70072594347"}
0005433529250	26ACEC	9698 991689	PAVEL FOMIN	{"phone": "+70754246751"}
0005433529251	26ACEC	0926 514069	ALEKSANDR CHERNOV	{"email": "chernov_a-12121963@postgrespro.ru", "phone": "+70031359656"}
0005433529252	AE46B0	2962 489534	VLADIMIR NAUMOV	{"phone": "+70304044262"}
0005433529253	AE46B0	4628 343040	SVETLANA BARANOVA	{"phone": "+70562470541"}
0005433529254	EAEE7B	9033 327084	VIKTOR TARASOV	{"phone": "+70792896572"}
0005433529255	EAEE7B	8608 068061	SERGEY DAVYDOV	{"phone": "+70911233074"}
0005433529256	2083ED	1229 968327	VIKTOR KOZLOV	{"phone": "+70799821930"}
0005433529257	80C0CA	0843 242573	ANATOLIY EGOROV	{"phone": "+70331993198"}
0005433529258	708482	0121 827397	MAKSIM PETROV	{"phone": "+70962586459"}
0005433529259	00127A	6492 445208	ANATOLIY BORISOV	{"email": "borisov-a.071963@postgrespro.ru", "phone": "+70322048383"}
0005433529260	A5D1C1	1695 671680	IGOR ZHUKOV	{"email": "zhukov-igor.30111971@postgrespro.ru", "phone": "+70071658998"}
0005433529261	26C143	5388 929605	NIKOLAY FILIPPOV	{"phone": "+70289625103"}
0005433529262	26C143	8920 258392	NATALIYA ERMAKOVA	{"phone": "+70704027493"}
0005433529263	AF8413	2983 110374	ANASTASIYA KARPOVA	{"email": "a.karpova05111966@postgrespro.ru", "phone": "+70641792143"}
0005433529264	AF8413	9701 461502	PAVEL PAVLOV	{"phone": "+70436451602"}
0005433529265	CD0222	5228 953223	DANIIL KAZAKOV	{"email": "daniil_kazakov021968@postgrespro.ru", "phone": "+70949983460"}
0005433529266	CD0222	9315 369690	NATALYA EGOROVA	{"email": "egorova.n_1980@postgrespro.ru", "phone": "+70436596647"}
0005433529267	3F406F	4577 592151	TATYANA TARASOVA	{"email": "t.tarasova1965@postgrespro.ru", "phone": "+70184957192"}
0005433529268	48B547	0763 806038	YURIY FILIPPOV	{"email": "y.filippov.1976@postgrespro.ru", "phone": "+70004272462"}
0005433529269	9B5F16	7015 305080	OLGA TIKHONOVA	{"email": "o.tikhonova-26041971@postgrespro.ru", "phone": "+70540157636"}
0005433529270	0292F2	8733 012789	NATALYA FADEEVA	{"email": "n-fadeeva-1977@postgrespro.ru", "phone": "+70948036541"}
0005433529271	221AF1	9056 635542	VLADIMIR PETROV	{"email": "v_petrov-1972@postgrespro.ru", "phone": "+70933462306"}
0005433529272	F78F4D	7833 548540	IVAN IVANOV	{"phone": "+70673614800"}
0005433529273	AF0408	1528 974136	OLGA ANISIMOVA	{"email": "oanisimova-101975@postgrespro.ru", "phone": "+70441643239"}
0005433529274	AF0408	8255 924401	RAFAEL OSIPOV	{"email": "osipov-r.09111967@postgrespro.ru", "phone": "+70946213434"}
0005433529275	4CF30A	0600 238520	OKSANA FADEEVA	{"email": "fadeeva_o-051971@postgrespro.ru", "phone": "+70263933947"}
0005433529276	4CF30A	6149 871288	GLEB IVANOV	{"email": "ivanovg-121967@postgrespro.ru", "phone": "+70049886367"}
0005433529277	FEE78E	4932 966364	LYUBOV SCHERBAKOVA	{"phone": "+70534050519"}
0005433529278	FEE78E	6897 840751	ANDREY STEPANOV	{"phone": "+70842094732"}
0005433529279	50C43F	1236 804423	MARIYA KISELEVA	{"phone": "+70182122101"}
0005433529280	FA13E5	8743 004301	SERGEY ZAKHAROV	{"email": "zakharov-s23091966@postgrespro.ru", "phone": "+70651868653"}
0005433529281	FA13E5	2191 821735	ANTONINA KALININA	{"phone": "+70605825881"}
0005433529282	5C9FE3	3094 154314	SERGEY SOKOLOV	{"phone": "+70325701122"}
0005433529283	5C9FE3	1243 217673	LYUDMILA OSIPOVA	{"phone": "+70874871830"}
0005433529284	CE27B1	3091 582002	ILDAR GORBUNOV	{"email": "igorbunov041968@postgrespro.ru", "phone": "+70667512660"}
0005433529285	1AF564	2660 558037	ALENA BORISOVA	{"email": "alena_borisova_041966@postgrespro.ru", "phone": "+70083820446"}
0005433529286	1AF564	2587 375809	ANDREY SOROKIN	{"email": "andrey_sorokin-021977@postgrespro.ru", "phone": "+70062258206"}
0005433529287	0E4D67	5638 829548	OLEG FOMIN	{"phone": "+70564307812"}
0005433529288	0E4D67	5735 552933	ANATOLIY MARTYNOV	{"email": "martynov_a-081967@postgrespro.ru", "phone": "+70041668241"}
0005433529289	0E4D67	6222 854197	ILDAR GUSEV	{"phone": "+70679112909"}
0005433529290	BD5856	5430 469990	GULNARA SOLOVEVA	{"phone": "+70887130938"}
0005433529291	FA12B7	8800 108454	ALINA MALYSHEVA	{"email": "malysheva_alina021980@postgrespro.ru", "phone": "+70499307460"}
0005433529292	D21CB7	0176 225946	NADEZHDA SOKOLOVA	{"phone": "+70924818246"}
0005433529293	EF7C83	0984 601372	NATALYA ZAYCEVA	{"phone": "+70333603256"}
0005433529294	EF7C83	6988 489126	ANZHELIKA MOISEEVA	{"phone": "+70964749301"}
0005433529295	B88907	2062 910562	IRINA FROLOVA	{"phone": "+70896025592"}
0005433529296	6594BB	3327 623082	ALEKSANDR IVANOV	{"phone": "+70523023771"}
0005433529297	6514CD	1464 992028	LIDIYA PETROVA	{"email": "lidiyapetrova1969@postgrespro.ru", "phone": "+70698595552"}
0005433529298	1B9D40	7246 921625	VADIM GERASIMOV	{"email": "gerasimovvadim_1966@postgrespro.ru", "phone": "+70610986874"}
0005433529299	1B9D40	1455 101528	SVETLANA VLASOVA	{"email": "svetlana-vlasova.1966@postgrespro.ru", "phone": "+70954063978"}
0005433529300	50F787	5256 542158	ALEKSEY YAKOVLEV	{"phone": "+70813092631"}
0005433529301	50F787	4334 985531	IVAN GORBUNOV	{"email": "ivan-gorbunov-111965@postgrespro.ru", "phone": "+70888319570"}
0005433529302	8B05D4	3294 250459	EDUARD EGOROV	{"phone": "+70703819753"}
0005433529303	217759	1698 483959	VIKTOR ISAEV	{"email": "isaev-v_111985@postgrespro.ru", "phone": "+70552149533"}
0005433529304	D50974	0762 432214	ALFIYA BORISOVA	{"phone": "+70544307760"}
0005433529305	F3DD6B	5313 167456	NIKITA DMITRIEV	{"email": "n-dmitriev_1976@postgrespro.ru", "phone": "+70494960266"}
0005433529306	278986	0742 540789	ELENA ERMAKOVA	{"email": "ermakova-elena-1983@postgrespro.ru", "phone": "+70841959106"}
0005433529307	278986	5597 197971	ALEKSEY DMITRIEV	{"phone": "+70202323675"}
0005433529308	6015E9	5825 346073	YURIY KONOVALOV	{"email": "y.konovalov-25061968@postgrespro.ru", "phone": "+70120632266"}
0005433529309	E1930C	1049 482965	OLGA KULIKOVA	{"phone": "+70095488533"}
0005433529310	AD2FBF	8138 616934	VASILIY ILIN	{"phone": "+70350698275"}
0005433529311	AD2FBF	4912 459517	SERGEY PAVLOV	{"email": "pavlov_sergey-09071977@postgrespro.ru", "phone": "+70730553097"}
0005433529312	0BF16F	2545 258466	VIKTOR PETROV	{"email": "petrovviktor-121973@postgrespro.ru", "phone": "+70188174120"}
0005433529313	0BF16F	0498 995421	IVAN DAVYDOV	{"email": "idavydov_06081971@postgrespro.ru", "phone": "+70194115634"}
0005433529314	0BF16F	6518 937193	YURIY ZAKHAROV	{"email": "yzakharov-121974@postgrespro.ru", "phone": "+70686533033"}
0005433529315	D28F3B	0114 179029	BORIS NIKITIN	{"phone": "+70122894794"}
0005433529316	D28F3B	3393 551880	MIKHAIL IVANOV	{"phone": "+70760041459"}
0005433529317	C35682	9803 401782	OLGA BOGDANOVA	{"email": "olga_bogdanova06111973@postgrespro.ru", "phone": "+70031086492"}
0005433529318	A856C9	1362 639197	ZULFIYA KISELEVA	{"phone": "+70630290893"}
0005433529319	ECC158	2640 476442	ALEKSANDR GRIGOREV	{"phone": "+70360944253"}
0005433529320	ECC158	1124 301360	MIKHAIL NAZAROV	{"phone": "+70553037478"}
0005433529321	62726D	2891 410870	ALEKSANDR KONOVALOV	{"phone": "+70276027405"}
0005433529322	12DEB0	1160 844073	RAISA KONDRATEVA	{"phone": "+70585676104"}
0005433529323	E7FFF9	9804 710584	SERGEY SMIRNOV	{"email": "smirnovsergey-19021976@postgrespro.ru", "phone": "+70249775519"}
0005433529324	216163	6153 421123	MARIYA KAZAKOVA	{"email": "kazakova_mariya021972@postgrespro.ru", "phone": "+70399316588"}
0005433529325	216163	4902 513240	SERGEY SIDOROV	{"email": "s.sidorov-061977@postgrespro.ru", "phone": "+70530598077"}
0005433529326	216163	8497 979666	ANDREY POPOV	{"phone": "+70369751522"}
0005433529327	0319C3	0372 515125	ALEKSEY TARASOV	{"phone": "+70665829524"}
0005433529328	C6C773	2831 609422	ELMIRA MELNIKOVA	{"email": "melnikova-elmira_041959@postgrespro.ru", "phone": "+70222997699"}
0005433529329	C6C773	9292 765021	ANASTASIYA ANDREEVA	{"phone": "+70837621246"}
0005433529330	BB520F	9895 909802	LYUBOV KUZNECOVA	{"phone": "+70459061725"}
0005433529331	BB520F	6277 175290	OLGA MOROZOVA	{"email": "o.morozova-051973@postgrespro.ru", "phone": "+70543076983"}
0005433529332	BE0C9F	5463 430708	GENNADIY BONDARENKO	{"email": "gennadiybondarenko_20061978@postgrespro.ru", "phone": "+70365322195"}
0005433529333	4B53C4	1695 301498	ALEKSANDR MAKAROV	{"phone": "+70675296204"}
0005433529334	E1869F	2674 446808	ANASTASIYA PETROVA	{"email": "a.petrova-101976@postgrespro.ru", "phone": "+70557012319"}
0005433529335	E1869F	9269 859945	KLAVDIYA PETROVA	{"email": "petrovak.101974@postgrespro.ru", "phone": "+70928707442"}
0005433529336	49378D	9767 404638	ANNA ISAEVA	{"email": "isaeva_anna_041972@postgrespro.ru", "phone": "+70130813387"}
0005433529337	D7484F	6736 972736	SVETLANA SEMENOVA	{"email": "s_semenova1979@postgrespro.ru", "phone": "+70046513417"}
0005433529338	D7484F	6161 830403	DANIIL ALEKSEEV	{"email": "daniil.alekseev.051974@postgrespro.ru", "phone": "+70852419828"}
0005433529339	4BCD5C	4499 209183	IGOR EGOROV	{"email": "egorov_igor1971@postgrespro.ru", "phone": "+70533565966"}
0005433529340	3A8B4E	2331 821789	ANATOLIY IVANOV	{"email": "a_ivanov121958@postgrespro.ru", "phone": "+70202425603"}
0005433529341	33435E	7401 072287	ALENA VOLKOVA	{"email": "volkova-a101974@postgrespro.ru", "phone": "+70334789424"}
0005433529342	9195E1	7368 396292	BULAT MAKAROV	{"email": "bulat-makarov_051976@postgrespro.ru", "phone": "+70430849986"}
0005433529343	9195E1	8470 528694	EKATERINA VOLKOVA	{"email": "volkova_e.051974@postgrespro.ru", "phone": "+70952282413"}
0005433529344	9195E1	4166 655378	LEONID MARTYNOV	{"phone": "+70778252957"}
0005433529345	476729	1530 227997	IRINA KUZMINA	{"phone": "+70743560039"}
0005433529346	8D2990	8857 925656	GALINA SERGEEVA	{"email": "gsergeeva.10081979@postgrespro.ru", "phone": "+70333035811"}
0005433529347	237B22	4762 605327	SERGEY FROLOV	{"phone": "+70670736611"}
0005433529348	237B22	0694 904531	ANDREY ANDREEV	{"email": "andreev_andrey1974@postgrespro.ru", "phone": "+70602499317"}
0005433529349	AEC210	1113 606062	NIKITA DENISOV	{"email": "denisovnikita-25041965@postgrespro.ru", "phone": "+70538416694"}
0005433529350	AEC210	8953 247082	SVETLANA PETROVA	{"email": "svetlana-petrova_1971@postgrespro.ru", "phone": "+70348477112"}
0005433529351	80B251	3093 278429	TAMARA MAKSIMOVA	{"phone": "+70181477180"}
0005433529352	80B251	2887 741184	NATALYA ABRAMOVA	{"email": "natalya.abramova-02081972@postgrespro.ru", "phone": "+70900293677"}
0005433529353	FB2995	1153 154614	ALEKSEY PAVLOV	{"phone": "+70878579993"}
0005433529354	750AFB	9903 919119	EVDOKIYA BORISOVA	{"email": "e.borisova021977@postgrespro.ru", "phone": "+70170941738"}
0005433529355	750AFB	2788 826731	NIKOLAY KOROLEV	{"phone": "+70675088471"}
0005433529356	750AFB	5416 798777	EVGENIY MIRONOV	{"email": "evgeniymironov.081961@postgrespro.ru", "phone": "+70702374911"}
0005433529357	A594CD	3693 603215	NIKOLAY NAUMOV	{"phone": "+70805828926"}
0005433529358	179FCF	1926 739661	SERGEY RODIONOV	{"email": "rodionov.sergey14041976@postgrespro.ru", "phone": "+70099773883"}
0005433529359	179FCF	8378 621579	LYUBOV NIKOLAEVA	{"phone": "+70914831715"}
0005433529360	0A7424	5636 409474	TATYANA SMIRNOVA	{"email": "smirnova.tatyana081981@postgrespro.ru", "phone": "+70306847184"}
0005433529361	AF1DCA	1360 635823	VIKTORIYA KOZLOVA	{"phone": "+70812930169"}
0005433529362	03B59C	5423 291188	VLADIMIR ILIN	{"email": "v.ilin1966@postgrespro.ru", "phone": "+70254531227"}
0005433529363	E31221	2584 025140	ANATOLIY NAZAROV	{"email": "nazarov-anatoliy.01051972@postgrespro.ru", "phone": "+70763573066"}
0005433529364	459342	9954 815756	ALEKSANDR ALEKSEEV	{"phone": "+70271599032"}
0005433529365	6B844A	3668 667923	NINA IVANOVA	{"email": "nina-ivanova_1975@postgrespro.ru", "phone": "+70053352445"}
0005433529366	6B844A	0969 728682	ANNA GERASIMOVA	{"phone": "+70775826239"}
0005433529367	3A77B2	9278 144102	DMITRIY PAVLOV	{"phone": "+70090254455"}
0005433529368	3A77B2	3063 636772	DENIS MAKAROV	{"phone": "+70550827007"}
0005433529369	00CF0D	3816 678490	ALBINA SEMENOVA	{"phone": "+70588488558"}
0005433529370	E6058F	9779 325321	VIKTOR KUZNECOV	{"phone": "+70396028298"}
0005433529371	E6058F	5663 124921	VYACHESLAV CHERNOV	{"email": "chernovvyacheslav_29081971@postgrespro.ru", "phone": "+70818608649"}
0005433529372	B7FD0F	5877 969186	ALEKSANDR ABRAMOV	{"phone": "+70388304571"}
0005433529373	AB88EF	9130 637439	VIKTOR KUZMIN	{"phone": "+70689922096"}
0005433529374	AB88EF	4738 440769	TATYANA ZAYCEVA	{"phone": "+70656907048"}
0005433529375	92C748	8202 149862	DARYA IVANOVA	{"email": "ivanova.darya_09021974@postgrespro.ru", "phone": "+70566386265"}
0005433529376	92C748	8829 656610	MARIYA GORBUNOVA	{"phone": "+70499761970"}
0005433529377	92C748	7779 622702	ALEKSANDR NIKOLAEV	{"phone": "+70333748320"}
0005433529378	C87671	0247 844811	MARIYA ABRAMOVA	{"email": "abramova.mariya.081975@postgrespro.ru", "phone": "+70877471761"}
0005433529379	5986F5	9009 636138	TATYANA SOROKINA	{"email": "tatyana_sorokina-02041963@postgrespro.ru", "phone": "+70004112731"}
0005433529380	68B088	5354 133692	DMITRIY KOZLOV	{"phone": "+70104806556"}
0005433529381	EF1A81	7316 994468	AZAT EGOROV	{"email": "a_egorov-15071963@postgrespro.ru", "phone": "+70920853549"}
0005433529382	50FA22	0760 955708	VIKTOR IVANOV	{"phone": "+70472960880"}
0005433529383	50FA22	0454 321251	MARIYA POLYAKOVA	{"phone": "+70233766216"}
0005433529384	B4D6C2	2808 107969	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay_041980@postgrespro.ru", "phone": "+70595240937"}
0005433529385	AF61B1	3033 802553	NINA FROLOVA	{"email": "nfrolova_1975@postgrespro.ru", "phone": "+70686821204"}
0005433529386	A488C0	3893 886614	ANATOLIY MAKAROV	{"phone": "+70609822342"}
0005433529387	A488C0	3184 914137	LYUDMILA SEMENOVA	{"email": "lyudmila-semenova-081972@postgrespro.ru", "phone": "+70511963058"}
0005433529388	9E66FD	0331 065530	EKATERINA NIKOLAEVA	{"email": "nikolaeva_ekaterina_081971@postgrespro.ru", "phone": "+70130961176"}
0005433529389	9E66FD	2658 038129	DMITRIY KARPOV	{"phone": "+70711333451"}
0005433529390	1CC4A0	0414 277326	ALFIYA BELOVA	{"phone": "+70462968978"}
0005433531232	F4C812	6474 190488	SERGEY MAKSIMOV	{"phone": "+70115574693"}
0005433531233	F4C812	5605 123301	KLAVDIYA ISAEVA	{"phone": "+70583996207"}
0005433531345	AE1579	3619 096492	NATALYA LUKYANOVA	{"phone": "+70763588986"}
0005433531326	48DC24	8397 317753	TATYANA YAKOVLEVA	{"phone": "+70704587083"}
0005433531286	6009FE	5329 001976	ANNA ZAYCEVA	{"phone": "+70673655292"}
0005433531225	EBFCA4	7749 051037	DMITRIY MARTYNOV	{"email": "dmitriy-martynov051964@postgrespro.ru", "phone": "+70142374722"}
0005433531226	EBFCA4	9205 527175	ANDREY ZAYCEV	{"email": "zaycev_andrey_041978@postgrespro.ru", "phone": "+70902216576"}
0005433531227	E61B64	0118 590301	IRINA KUZNECOVA	{"phone": "+70604413428"}
0005433531228	E61B64	8911 615983	ALEKSEY FROLOV	{"phone": "+70846822465"}
0005433531229	432127	9685 703590	MARINA YUDINA	{"phone": "+70160477778"}
0005433531230	D31864	4622 047932	ANGELINA KONDRATEVA	{"phone": "+70036818195"}
0005433531231	79DB2A	6541 055019	SERGEY IVANOV	{"email": "ivanovsergey08061970@postgrespro.ru", "phone": "+70166935512"}
0005433531234	E304F8	8140 079539	ROMAN TIKHONOV	{"email": "tikhonovroman-1976@postgrespro.ru", "phone": "+70241160478"}
0005433531235	68BE51	0125 318320	ARINA KOZLOVA	{"email": "a.kozlova_1976@postgrespro.ru", "phone": "+70007407727"}
0005433531236	68BE51	6824 471723	NINA MELNIKOVA	{"phone": "+70656993081"}
0005433531237	DCCAED	1706 925664	MAKSIM ROMANOV	{"email": "romanov-maksim.1976@postgrespro.ru", "phone": "+70557820780"}
0005433531238	B22C6A	7047 049897	KSENIYA SCHERBAKOVA	{"email": "scherbakovakseniya_051964@postgrespro.ru", "phone": "+70484965536"}
0005433531239	2592F6	4043 951130	VERA DAVYDOVA	{"email": "davydova.v_031966@postgrespro.ru", "phone": "+70094666872"}
0005433531240	3EB890	4118 707822	VLADIMIR POPOV	{"phone": "+70002354893"}
0005433531241	7B7081	2188 289747	EVGENIYA ORLOVA	{"phone": "+70979130321"}
0005433531242	7B7081	8839 491430	BORIS FILIPPOV	{"email": "b_filippov.07111967@postgrespro.ru", "phone": "+70094356614"}
0005433531243	C4E75F	8368 765160	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova_a.22011968@postgrespro.ru", "phone": "+70474305375"}
0005433531244	C4E75F	2252 236239	IVAN ANDREEV	{"email": "ivan_andreev-30111963@postgrespro.ru", "phone": "+70213032585"}
0005433531245	3EAAD0	2277 214689	SERGEY EGOROV	{"email": "sergeyegorov1966@postgrespro.ru", "phone": "+70373273095"}
0005433531246	3EAAD0	1334 517491	EVGENIY ZAKHAROV	{"email": "e-zakharov_15011970@postgrespro.ru", "phone": "+70297604428"}
0005433531247	54CCA6	1826 928959	SERGEY NOVIKOV	{"email": "novikov-s-20041968@postgrespro.ru", "phone": "+70969566878"}
0005433531248	54CCA6	2198 103269	STANISLAV PETROV	{"phone": "+70220896320"}
0005433531249	42BC82	0884 834324	GRIGORIY SEMENOV	{"email": "g_semenov-111969@postgrespro.ru", "phone": "+70086182166"}
0005433531250	42BC82	0070 694251	VASILIY KONOVALOV	{"email": "konovalov.vasiliy30111973@postgrespro.ru", "phone": "+70995959060"}
0005433531251	741900	2138 116687	LYUDMILA SOROKINA	{"email": "sorokina_lyudmila.1970@postgrespro.ru", "phone": "+70026499098"}
0005433531252	EE7821	4670 167584	ANDREY MAKAROV	{"phone": "+70165819033"}
0005433531253	2B6266	6881 470293	TATYANA BOGDANOVA	{"phone": "+70207868382"}
0005433531254	2B6266	3694 769178	EKATERINA ALEKSEEVA	{"email": "e-alekseeva18091970@postgrespro.ru", "phone": "+70481939734"}
0005433531255	EA672F	2391 419637	VASILIY MATVEEV	{"email": "vasiliy.matveev_1959@postgrespro.ru", "phone": "+70224311144"}
0005433531256	EA672F	0764 582298	VIKTOR PETROV	{"email": "viktor-petrov051981@postgrespro.ru", "phone": "+70219926776"}
0005433531257	49367B	8575 804731	OLGA GORBUNOVA	{"phone": "+70560932207"}
0005433531258	F085F4	7033 838410	YULIYA GAVRILOVA	{"phone": "+70248797240"}
0005433531259	F085F4	1597 682304	IRINA FEDOROVA	{"phone": "+70140680335"}
0005433531260	F085F4	5523 846070	ALEKSANDR BELOV	{"phone": "+70984890388"}
0005433531261	6F244D	3241 533377	NIKITA NAZAROV	{"phone": "+70824476230"}
0005433531262	6F244D	8494 130580	SOFYA VOLKOVA	{"email": "volkova_s041974@postgrespro.ru", "phone": "+70972297719"}
0005433531263	DBA304	7262 884410	ANNA SERGEEVA	{"email": "anna.sergeeva_1974@postgrespro.ru", "phone": "+70375830987"}
0005433531264	DBA304	5238 997825	OLGA ORLOVA	{"phone": "+70148316819"}
0005433531265	AD5DAD	8918 298516	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov1957@postgrespro.ru", "phone": "+70219080759"}
0005433531266	5C827E	1455 885114	ALSU KUZNECOVA	{"phone": "+70515602007"}
0005433531267	5E4F8C	2895 844060	TATYANA KALININA	{"phone": "+70213993474"}
0005433531268	5E4F8C	0333 684990	ALEKSANDRA KOROLEVA	{"phone": "+70678112794"}
0005433531269	7BF76C	0808 618632	SERGEY SIDOROV	{"phone": "+70473778294"}
0005433531270	7BF76C	4210 617325	VALENTINA KONDRATEVA	{"email": "kondrateva.valentina.08051976@postgrespro.ru", "phone": "+70329696786"}
0005433531271	C7D924	8576 680202	ALEKSANDRA KONOVALOVA	{"phone": "+70148616117"}
0005433531272	C7D924	8301 658515	NINA VOLKOVA	{"email": "nina_volkova-31101974@postgrespro.ru", "phone": "+70369610256"}
0005433531273	17F81A	7370 902371	VALERIY MOISEEV	{"email": "moiseev-v-011969@postgrespro.ru", "phone": "+70846150685"}
0005433531274	C2A49B	7711 043007	GALINA NESTEROVA	{"email": "nesterova_g_021982@postgrespro.ru", "phone": "+70666461458"}
0005433531275	ED9F35	1787 334036	ANNA ORLOVA	{"phone": "+70768571182"}
0005433531276	ED9F35	4317 079526	LIDIYA PAVLOVA	{"email": "pavlovalidiya_02011962@postgrespro.ru", "phone": "+70916573200"}
0005433531277	ED9F35	0746 287259	ELMIRA TARASOVA	{"phone": "+70995824609"}
0005433531278	BA00A5	6514 042361	EVGENIY TARASOV	{"email": "tarasov.e_061984@postgrespro.ru", "phone": "+70613826848"}
0005433531279	8F6983	9281 016873	EVGENIY KUZNECOV	{"phone": "+70561498835"}
0005433531280	E72150	3489 815697	VIKTOR MAKSIMOV	{"phone": "+70868822993"}
0005433531281	3D61AC	4251 875823	ANATOLIY MELNIKOV	{"email": "melnikov.anatoliy-031980@postgrespro.ru", "phone": "+70518932254"}
0005433531282	3CD7F3	8349 157186	OKSANA EGOROVA	{"phone": "+70386812814"}
0005433531283	D80B36	2670 320370	EKATERINA ZAKHAROVA	{"email": "zakharova_ekaterina-011976@postgrespro.ru", "phone": "+70502156968"}
0005433531284	2F0B6A	6691 455012	SVETLANA PAVLOVA	{"email": "svetlanapavlova.12021960@postgrespro.ru", "phone": "+70260245224"}
0005433531285	2F0B6A	1577 125077	ANTONINA KUZNECOVA	{"email": "antonina_kuznecova.19081983@postgrespro.ru", "phone": "+70857260093"}
0005433531287	E0E8C9	5629 365156	ELENA TIKHONOVA	{"phone": "+70246210386"}
0005433531288	E0E8C9	9028 955530	ANDREY KONOVALOV	{"phone": "+70141597842"}
0005433531289	6559F2	9176 883795	ANDREY NOVIKOV	{"email": "novikov-a.28041965@postgrespro.ru", "phone": "+70352630179"}
0005433531290	9C7983	4956 293358	SVETLANA ZHUKOVA	{"email": "s-zhukova.30071975@postgrespro.ru", "phone": "+70740191487"}
0005433531291	8B44BF	9183 890129	TATYANA SERGEEVA	{"phone": "+70973257262"}
0005433531292	0E6EC2	7346 299777	ALEKSANDR ZAKHAROV	{"phone": "+70220449309"}
0005433531293	90E9AF	3217 965872	NATALYA POTAPOVA	{"email": "potapova_n-081976@postgrespro.ru", "phone": "+70901687170"}
0005433531294	F9DEFE	8251 679290	DMITRIY NIKITIN	{"phone": "+70634542166"}
0005433531295	AABDBE	5384 936396	ZINAIDA NESTEROVA	{"email": "znesterova.021963@postgrespro.ru", "phone": "+70685042311"}
0005433531296	574283	7251 686707	MARIYA MAKAROVA	{"phone": "+70960497509"}
0005433531297	574283	4209 505498	ALENA TROFIMOVA	{"phone": "+70312763218"}
0005433531298	B4DCB2	9677 675150	KONSTANTIN VLASOV	{"email": "konstantin-vlasov1976@postgrespro.ru", "phone": "+70227930341"}
0005433531299	B4DCB2	1668 157151	IRINA ZAKHAROVA	{"email": "izakharova101970@postgrespro.ru", "phone": "+70039828127"}
0005433531300	B4DCB2	1239 269448	NATALYA ABRAMOVA	{"phone": "+70300306423"}
0005433531301	F21C6E	3945 087490	ELENA ZHURAVLEVA	{"phone": "+70728606739"}
0005433531302	D278D0	7477 044791	ANATOLIY GUSEV	{"email": "a_gusev_091966@postgrespro.ru", "phone": "+70635742536"}
0005433531303	D278D0	5078 856853	SERGEY MELNIKOV	{"email": "sergey_melnikov.071976@postgrespro.ru", "phone": "+70436986455"}
0005433531304	3D19E0	3594 814692	VIKTOR KOZLOV	{"phone": "+70061400689"}
0005433531305	177C31	6342 520569	ELENA KRASNOVA	{"email": "ekrasnova_1970@postgrespro.ru", "phone": "+70785581784"}
0005433531306	9E1EDE	8691 864113	KSENIYA MIRONOVA	{"email": "mironova_kseniya.08071980@postgrespro.ru", "phone": "+70071866734"}
0005433531307	D47EAB	9685 355923	ZOYA TIKHONOVA	{"phone": "+70728890135"}
0005433531308	7B3115	4206 587131	ANASTASIYA MALYSHEVA	{"email": "a_malysheva.031970@postgrespro.ru", "phone": "+70180907486"}
0005433531309	8EF86C	9847 486660	TATYANA ILINA	{"phone": "+70200007828"}
0005433531310	8EF86C	0220 770568	MAKSIM SERGEEV	{"email": "sergeevmaksim.071976@postgrespro.ru", "phone": "+70406978864"}
0005433531311	BB0747	3851 051945	GALINA NESTEROVA	{"phone": "+70050869273"}
0005433531312	BB0747	6663 318003	OLGA MIKHAYLOVA	{"phone": "+70545284452"}
0005433531313	7A47AA	0222 187746	VASILIY PAVLOV	{"phone": "+70276880193"}
0005433531314	0C52D4	3586 687267	ALEKSANDR KRASNOV	{"phone": "+70613197519"}
0005433531315	5033EB	5131 582244	IRINA IVANOVA	{"phone": "+70912068815"}
0005433531316	7E2066	2922 639816	ALEKSANDR NIKITIN	{"phone": "+70612206691"}
0005433531317	7E2066	6448 329356	ALEKSEY ILIN	{"phone": "+70973271621"}
0005433531318	7F516F	6062 233805	PETR FEDOTOV	{"email": "fedotov-petr.29021976@postgrespro.ru", "phone": "+70706664043"}
0005433531319	7F516F	6511 347436	VALENTINA EFREMOVA	{"phone": "+70010626162"}
0005433531320	6E9F00	4009 065279	MARIYA ROMANOVA	{"email": "m_romanova_1963@postgrespro.ru", "phone": "+70396195259"}
0005433531321	6E9F00	2906 029794	ANDREY NIKITIN	{"phone": "+70985833445"}
0005433531322	E2161E	5853 704072	TATYANA GUSEVA	{"email": "t-guseva.1966@postgrespro.ru", "phone": "+70454355413"}
0005433531323	E2161E	3246 909559	NIKOLAY SEMENOV	{"phone": "+70302608682"}
0005433531324	EDB65C	4451 716252	LARISA ANTONOVA	{"email": "l_antonova-101966@postgrespro.ru", "phone": "+70326081600"}
0005433531325	EDB65C	7416 250299	LYUDMILA EFIMOVA	{"phone": "+70485517749"}
0005433531327	9C21E8	0287 258679	SERGEY MEDVEDEV	{"email": "medvedev.sergey1973@postgrespro.ru", "phone": "+70694366227"}
0005433531328	CD1A3C	1402 490692	IRINA MAKAROVA	{"phone": "+70004295765"}
0005433531329	CD1A3C	9024 538229	VIKTOR SIDOROV	{"phone": "+70750549029"}
0005433531330	CD1A3C	3070 373274	ALIYA GRISHINA	{"email": "aliyagrishina.06101969@postgrespro.ru", "phone": "+70193077477"}
0005433531331	C916E6	3917 023080	GALINA MAKAROVA	{"email": "makarovagalina25011962@postgrespro.ru", "phone": "+70504629271"}
0005433531332	FD9092	0592 533023	EKATERINA SMIRNOVA	{"email": "smirnova.e.17101974@postgrespro.ru", "phone": "+70226732074"}
0005433531333	13C289	4996 490094	ALEKSANDR CHERNOV	{"phone": "+70273438983"}
0005433531334	13C289	7169 609385	ANASTASIYA ZHURAVLEVA	{"email": "anastasiyazhuravleva1982@postgrespro.ru", "phone": "+70854772693"}
0005433531335	13C289	9275 835492	VLADIMIR KUZNECOV	{"phone": "+70028532598"}
0005433531336	593B21	8440 089499	ELENA SOKOLOVA	{"email": "e_sokolova1972@postgrespro.ru", "phone": "+70933289062"}
0005433531337	E5758F	9113 904799	ALENA NOVIKOVA	{"email": "a_novikova.1976@postgrespro.ru", "phone": "+70071220050"}
0005433531338	31C820	3956 700764	IVAN KULIKOV	{"phone": "+70751688994"}
0005433531339	0D64C4	5602 576363	YULIYA DAVYDOVA	{"email": "yuliya-davydova_25081977@postgrespro.ru", "phone": "+70459984054"}
0005433531340	0D64C4	5075 223870	VLADIMIR TIMOFEEV	{"email": "vladimir_timofeev031968@postgrespro.ru", "phone": "+70568745013"}
0005433531341	7DB6D0	7860 978824	ANTON KOZLOV	{"phone": "+70416134848"}
0005433531342	BA115F	9989 779623	YURIY VASILEV	{"email": "y-vasilev_081964@postgrespro.ru", "phone": "+70940454315"}
0005433531343	71833D	5727 104211	GENNADIY FILIPPOV	{"phone": "+70497850330"}
0005433531344	070383	9197 785517	TATYANA IVANOVA	{"email": "ivanova-tatyana-13071977@postgrespro.ru", "phone": "+70748343013"}
0005433531346	AE1579	9854 979371	SOFYA ROMANOVA	{"email": "romanova_s-071972@postgrespro.ru", "phone": "+70716406558"}
0005433531347	1AC224	2223 693121	ELIZAVETA NOVIKOVA	{"phone": "+70405773591"}
0005433531348	1AC224	1417 206677	ALEKSEY NOVIKOV	{"email": "novikova_18071968@postgrespro.ru", "phone": "+70062438997"}
0005433531349	BB64C0	2425 230328	GRIGORIY BORISOV	{"email": "grigoriy-borisov-1972@postgrespro.ru", "phone": "+70123839519"}
0005433531350	196F8E	4218 479054	ILYA MATVEEV	{"phone": "+70332561443"}
0005433531351	6FF327	9111 898263	VALENTINA KOVALEVA	{"phone": "+70283381897"}
0005433531352	D5D0FA	8831 487911	SERGEY GAVRILOV	{"email": "s.gavrilov-1976@postgrespro.ru", "phone": "+70356777209"}
0005433531353	FF6FC8	1193 261192	NATALYA SEMENOVA	{"email": "semenova-natalya.031966@postgrespro.ru", "phone": "+70875673772"}
0005433531354	21BD05	2274 595601	OLGA SIDOROVA	{"phone": "+70712113184"}
0005433531355	21BD05	4058 929698	SERGEY MIKHAYLOV	{"phone": "+70122455842"}
0005433531356	21BD05	9553 195101	ELENA PETROVA	{"email": "petrovaelena.111974@postgrespro.ru", "phone": "+70463674239"}
0005433531357	9BCCAD	2186 757979	ALEKSANDR TARASOV	{"phone": "+70167343782"}
0005433531358	3E1D4F	4059 135029	ANDREY VLASOV	{"email": "andreyvlasov.1975@postgrespro.ru", "phone": "+70839752137"}
0005433531359	5A7F5F	8169 470199	DMITRIY ORLOV	{"email": "orlov-dmitriy-031976@postgrespro.ru", "phone": "+70507758711"}
0005433531360	0EEEF9	4537 099684	STANISLAV CHERNOV	{"phone": "+70699294082"}
0005433531361	DBD3C6	7475 986888	DMITRIY SMIRNOV	{"email": "smirnovd1969@postgrespro.ru", "phone": "+70457255132"}
0005433531362	DBD3C6	1816 549656	VYACHESLAV MAKSIMOV	{"phone": "+70996140905"}
0005433531363	AA285A	7516 361902	RUSLAN TIKHONOV	{"email": "ruslantikhonov.05121965@postgrespro.ru", "phone": "+70704706883"}
0005433531364	E16D7C	5435 860059	MARINA NIKITINA	{"email": "nikitina-marina1971@postgrespro.ru", "phone": "+70261855877"}
0005433531365	E16D7C	2624 740742	MIKHAIL EGOROV	{"phone": "+70981533338"}
0005433531366	F447C0	3534 423088	KSENIYA FOMINA	{"email": "kseniya-fomina-011974@postgrespro.ru", "phone": "+70123711469"}
0005433531367	ED46B6	7509 896136	NATALYA GERASIMOVA	{"phone": "+70104448662"}
0005433531368	ED46B6	7017 677656	ANASTASIYA YAKOVLEVA	{"phone": "+70347477609"}
0005433531369	1E33CE	8206 574776	ELENA YAKOVLEVA	{"phone": "+70477203200"}
0005433531370	1E33CE	1481 113864	YURIY FROLOV	{"email": "frolovy061974@postgrespro.ru", "phone": "+70778953145"}
0005433531371	B9721A	3907 561938	VLADIMIR KAZAKOV	{"phone": "+70513255967"}
0005433531372	B9721A	0780 731705	ALEKSEY NIKITIN	{"email": "nikitin_a-18031978@postgrespro.ru", "phone": "+70133044683"}
0005433531373	F7C983	3237 117225	OLGA FEDOROVA	{"email": "fedorova.olga.01081968@postgrespro.ru", "phone": "+70236558722"}
0005433531374	F7C983	0180 914858	TATYANA KUZMINA	{"email": "kuzmina-tatyana061974@postgrespro.ru", "phone": "+70831288124"}
0005433531375	25F59D	2863 135383	ANASTASIYA FEDOROVA	{"email": "fedorovaa_071977@postgrespro.ru", "phone": "+70816298100"}
0005433531376	DE5B76	6780 594085	SERGEY NOVIKOV	{"email": "novikovs_1987@postgrespro.ru", "phone": "+70576463654"}
0005433531377	1841F9	9160 575850	SERGEY GORBUNOV	{"phone": "+70286568223"}
0005433531378	1841F9	3955 349528	ILDAR VASILEV	{"email": "i_vasilev_1971@postgrespro.ru", "phone": "+70486254246"}
0005433531379	1BE692	9561 437645	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey20091966@postgrespro.ru", "phone": "+70774878210"}
0005433531380	F260BA	4926 859428	ANATOLIY MAKAROV	{"phone": "+70468744929"}
0005433531381	DE6DC0	4776 654798	IRINA SERGEEVA	{"email": "irinasergeeva_20021971@postgrespro.ru", "phone": "+70585813051"}
0005433531382	69D206	4576 700771	OLGA MALYSHEVA	{"phone": "+70834490660"}
0005433531383	69D206	1300 003784	ANDREY BONDARENKO	{"email": "andrey.bondarenko-08011968@postgrespro.ru", "phone": "+70577057858"}
0005433531384	45290A	8115 723420	RUSLAN ZAYCEV	{"email": "zaycev-ruslan05031971@postgrespro.ru", "phone": "+70716382886"}
0005433531385	441C75	9336 702270	MARIYA KARPOVA	{"phone": "+70571769890"}
0005433531386	CCD293	9677 878672	VASILIY NIKOLAEV	{"email": "vasiliy-nikolaev1984@postgrespro.ru", "phone": "+70025811335"}
0005433531387	CCD293	1955 579458	ALEKSEY ZAYCEV	{"phone": "+70125421174"}
0005433531388	CCD293	3377 273477	LYUBOV PAVLOVA	{"phone": "+70506658034"}
0005433531389	EA959D	8421 076488	VIKTORIYA DENISOVA	{"email": "denisova_v.27051972@postgrespro.ru", "phone": "+70765397217"}
0005433531390	B0F53C	9982 830683	ANNA SERGEEVA	{"phone": "+70551921483"}
0005433531391	B0F53C	5094 136617	OLGA STEPANOVA	{"phone": "+70063812835"}
0005433531392	A1501D	8138 105399	DANILA KOROLEV	{"phone": "+70368320422"}
0005433531393	2C8326	3582 674889	ALEKSEY GUSEV	{"email": "gusev.aleksey_1952@postgrespro.ru", "phone": "+70558427136"}
0005433531394	99DD45	2850 411666	ANASTASIYA BARANOVA	{"phone": "+70251934107"}
0005433531395	7D4F8D	1268 548645	EGOR VASILEV	{"phone": "+70826459486"}
0005433531396	7D4F8D	7459 005176	VALENTINA VOLKOVA	{"email": "volkova_v1968@postgrespro.ru", "phone": "+70682503122"}
0005433531397	7D4F8D	4316 809835	EVGENIY KOZLOV	{"phone": "+70683766542"}
0005433531398	7D4F8D	7006 269320	ALEKSEY FROLOV	{"email": "a.frolov_31121971@postgrespro.ru", "phone": "+70324025767"}
0005433531399	04E5AC	4008 410300	PAVEL IVANOV	{"email": "ivanov_pavel-021974@postgrespro.ru", "phone": "+70606532526"}
0005433531400	04E5AC	9952 171697	ALEKSANDR MIKHAYLOV	{"phone": "+70472667910"}
0005433531401	94FA67	8373 003216	YULIYA SERGEEVA	{"email": "yuliya.sergeeva_1968@postgrespro.ru", "phone": "+70081011596"}
0005433531402	94FA67	5052 083413	GENNADIY NIKITIN	{"email": "nikitin_gennadiy-23081972@postgrespro.ru", "phone": "+70246130197"}
0005433531403	16FE58	0904 354978	VALERIY IVANOV	{"phone": "+70514514619"}
0005433531404	81965D	7746 712501	EKATERINA KISELEVA	{"email": "kiseleva.e-15061961@postgrespro.ru", "phone": "+70071087961"}
0005433531405	5F3332	6978 186833	IGOR ALEKSANDROV	{"email": "igor_aleksandrov_1970@postgrespro.ru", "phone": "+70326767654"}
0005433533240	912EA4	7790 648542	TATYANA FROLOVA	{"email": "t-frolova16071969@postgrespro.ru", "phone": "+70853413984"}
0005433533241	588120	4664 540108	VIKTORIYA MELNIKOVA	{"email": "viktoriyamelnikova_1965@postgrespro.ru", "phone": "+70928044077"}
0005433533242	588120	7186 092217	ALEKSEY DAVYDOV	{"email": "aleksey-davydov.11021968@postgrespro.ru", "phone": "+70315500104"}
0005433533243	35E098	0366 540041	VIKTOR GRIGOREV	{"phone": "+70074291059"}
0005433533244	74572C	8090 162661	NATALYA POTAPOVA	{"email": "n.potapova_27111980@postgrespro.ru", "phone": "+70783977530"}
0005433533245	74572C	8630 390919	OLGA KOROLEVA	{"phone": "+70153612382"}
0005433533246	A735C7	1977 590150	DENIS VOLKOV	{"phone": "+70220853528"}
0005433533247	DA4D23	4195 807007	VALERIYA BELOVA	{"phone": "+70004782365"}
0005433533248	D58D4A	5662 583268	GALINA MOISEEVA	{"email": "moiseeva.galina.1978@postgrespro.ru", "phone": "+70727925766"}
0005433533249	EADC52	9576 709171	RUSLAN VASILEV	{"phone": "+70174104109"}
0005433533250	A0B887	2583 779694	NINA NOVIKOVA	{"phone": "+70578336545"}
0005433533251	AB2F94	3229 149311	LARISA SAVELEVA	{"phone": "+70018455566"}
0005433533252	AB2F94	8991 500255	IGOR SOKOLOV	{"email": "i-sokolov1965@postgrespro.ru", "phone": "+70544943221"}
0005433533253	22B5D9	2351 932547	ANTONINA MAKAROVA	{"email": "a.makarova_111971@postgrespro.ru", "phone": "+70792660503"}
0005433533254	6DE1BE	2508 853817	LARISA SMIRNOVA	{"phone": "+70957688436"}
0005433533255	3A0361	8117 854542	NATALYA BORISOVA	{"email": "n_borisova_021976@postgrespro.ru", "phone": "+70617432638"}
0005433533256	3A0361	8192 613122	GALINA SOROKINA	{"email": "g-sorokina.22041968@postgrespro.ru", "phone": "+70850878447"}
0005433533257	1C50E3	5300 806599	VALENTINA NIKITINA	{"phone": "+70845775427"}
0005433533258	658324	8268 156358	VALENTINA SMIRNOVA	{"phone": "+70732900321"}
0005433533259	658324	4900 938635	ARTEM FROLOV	{"phone": "+70048273171"}
0005433533260	704F79	3456 952556	ALEKSANDR SEMENOV	{"phone": "+70427617165"}
0005433533261	C49E38	1850 182093	SERGEY PETROV	{"email": "sergeypetrov-08081973@postgrespro.ru", "phone": "+70355717786"}
0005433533262	659A58	0801 100057	SERGEY ALEKSANDROV	{"email": "aleksandrov-sergey061973@postgrespro.ru", "phone": "+70356655826"}
0005433533263	FBFB7D	2285 687649	VIKTOR BORISOV	{"email": "viktor.borisov.31081979@postgrespro.ru", "phone": "+70508635812"}
0005433533264	FBFB7D	6105 166571	BORIS SIDOROV	{"email": "sidorov.boris011972@postgrespro.ru", "phone": "+70581790752"}
0005433533265	A197C5	8812 190897	VLADIMIR KUZNECOV	{"phone": "+70408340297"}
0005433533266	F46EBF	1923 638636	NIKOLAY ORLOV	{"phone": "+70125657766"}
0005433533267	F46EBF	9906 243604	ANASTASIYA VOROBEVA	{"phone": "+70826199812"}
0005433533268	B62051	7907 160919	ELENA KUZNECOVA	{"email": "elena-kuznecova_121972@postgrespro.ru", "phone": "+70273312651"}
0005433533269	B62051	2591 422712	SERGEY NAUMOV	{"phone": "+70102520654"}
0005433533270	E751C5	6619 285129	GALINA MIRONOVA	{"email": "mironova_galina_1980@postgrespro.ru", "phone": "+70928386373"}
0005433533271	A5F757	2962 798906	VIKTORIYA POPOVA	{"email": "v-popova_1978@postgrespro.ru", "phone": "+70849000712"}
0005433533272	EE3A53	6774 729796	ALEKSANDR VASILEV	{"phone": "+70068844339"}
0005433533273	EE3A53	4397 925725	EVGENIY SEMENOV	{"email": "semenov_e.1962@postgrespro.ru", "phone": "+70461532852"}
0005433533274	BE2E63	7390 374577	VERONIKA BELOVA	{"email": "belova.veronika101982@postgrespro.ru", "phone": "+70807622228"}
0005433533275	BE2E63	3859 718239	VIKTOR GRIGOREV	{"phone": "+70279651065"}
0005433533276	F41285	7110 715714	SAVELIY NIKOLAEV	{"email": "nikolaevs_15121967@postgrespro.ru", "phone": "+70230621884"}
0005433533277	A0978F	5123 025943	ANTONINA NIKOLAEVA	{"phone": "+70509914427"}
0005433533278	A0978F	1056 018343	ALINA KONDRATEVA	{"phone": "+70358820342"}
0005433533279	64A78E	6240 347213	YURIY KUDRYASHOV	{"phone": "+70783804400"}
0005433533280	64A78E	4203 549069	OLGA NIKITINA	{"email": "olga_nikitina.1981@postgrespro.ru", "phone": "+70243327649"}
0005433533281	136C93	3935 892063	IVAN MAKSIMOV	{"email": "maksimov.ivan1977@postgrespro.ru", "phone": "+70083974022"}
0005433533282	136C93	0358 284746	RAISA BORISOVA	{"email": "borisova.raisa_1979@postgrespro.ru", "phone": "+70864444494"}
0005433533283	F904EB	7497 850174	ALEKSANDR MAKAROV	{"phone": "+70962867079"}
0005433533284	F017CB	2990 276528	MIKHAIL RODIONOV	{"phone": "+70576437114"}
0005433533285	2D1D43	1196 898246	VLADIMIR SHEVCHENKO	{"email": "shevchenko-v.1973@postgrespro.ru", "phone": "+70623022723"}
0005433533286	2D1D43	7580 070326	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr121973@postgrespro.ru", "phone": "+70363510554"}
0005433533287	3449CA	9389 494944	VALENTINA FEDOROVA	{"email": "fedorova_v.04111959@postgrespro.ru", "phone": "+70373792972"}
0005433533288	28E04A	2449 771781	OLGA MAKAROVA	{"email": "omakarova20071971@postgrespro.ru", "phone": "+70012121417"}
0005433533289	28E04A	5873 260416	FEDOR GERASIMOV	{"email": "gerasimovfedor_081978@postgrespro.ru", "phone": "+70324544568"}
0005433533290	563760	4488 153943	IVAN SMIRNOV	{"phone": "+70876536640"}
0005433533291	96B660	0057 870231	OLGA POPOVA	{"email": "olga-popova1979@postgrespro.ru", "phone": "+70665478989"}
0005433533292	96B660	0686 434489	IVAN OSIPOV	{"phone": "+70779321365"}
0005433533293	E2F26D	5400 903336	ILYA BELOV	{"email": "belov-ilya_17051964@postgrespro.ru", "phone": "+70692723343"}
0005433533294	6DB89C	4576 180045	NIKOLAY TIKHONOV	{"phone": "+70215566780"}
0005433533295	6DB89C	9403 144114	ALEKSEY VOROBEV	{"phone": "+70871555636"}
0005433533296	FA48EB	5154 567127	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a.03011976@postgrespro.ru", "phone": "+70638449049"}
0005433533297	FA48EB	8819 838766	SOFYA FEDOROVA	{"email": "fedorovasofya.1971@postgrespro.ru", "phone": "+70164790082"}
0005433533298	5445AA	1615 612288	EVGENIYA GAVRILOVA	{"email": "gavrilova_e_1970@postgrespro.ru", "phone": "+70098226812"}
0005433533299	5445AA	5562 810246	ELENA EFIMOVA	{"email": "elenaefimova-031975@postgrespro.ru", "phone": "+70920573541"}
0005433533300	6AA299	0977 382938	ANDREY GUSEV	{"phone": "+70226923439"}
0005433533301	6371B6	1243 973025	NATALYA KUDRYASHOVA	{"email": "n_kudryashova-121967@postgrespro.ru", "phone": "+70674525461"}
0005433533302	6371B6	6368 547518	ALEKSANDR NOVIKOV	{"phone": "+70643698733"}
0005433533303	DBF3A5	2838 571047	TATYANA ANTONOVA	{"email": "tatyanaantonova_29081977@postgrespro.ru", "phone": "+70430771366"}
0005433533304	DBF3A5	7009 693631	OLEG EGOROV	{"phone": "+70149879680"}
0005433533305	99CB01	2521 099015	PRASKOVYA SOLOVEVA	{"email": "soloveva.praskovya-06121976@postgrespro.ru", "phone": "+70946938356"}
0005433533306	99CB01	3447 352089	GENNADIY VASILEV	{"email": "vasilev.g1969@postgrespro.ru", "phone": "+70698508727"}
0005433533307	4804D2	6389 014537	ALEKSANDR KUZNECOV	{"phone": "+70769374789"}
0005433533308	E149B7	7381 420812	NIKOLAY SIDOROV	{"email": "sidorovn.101963@postgrespro.ru", "phone": "+70564747862"}
0005433533309	8CDAC8	7666 594893	NIKITA KOZLOV	{"phone": "+70647292243"}
0005433533310	5395FA	5572 067100	VLADIMIR ZAYCEV	{"email": "v-zaycev1986@postgrespro.ru", "phone": "+70273107373"}
0005433533311	2EC3EF	3852 925806	VALENTINA NESTEROVA	{"email": "v.nesterova.081978@postgrespro.ru", "phone": "+70144637009"}
0005433533312	5DDDB3	1039 083126	NADEZHDA ERMAKOVA	{"phone": "+70444334984"}
0005433533313	5DDDB3	6552 144165	NIKOLAY SOROKIN	{"phone": "+70688581114"}
0005433533314	391131	9083 076380	TAMARA IVANOVA	{"email": "ivanovatamara_1979@postgrespro.ru", "phone": "+70966702258"}
0005433533315	91E271	7498 086593	ANDREY YAKOVLEV	{"email": "ayakovlev021977@postgrespro.ru", "phone": "+70121087214"}
0005433533316	FB2BF2	4357 043284	DARYA ANDREEVA	{"phone": "+70132143041"}
0005433533317	4A4C9B	3421 649034	VIKTOR ZAKHAROV	{"email": "zakharovv_18081976@postgrespro.ru", "phone": "+70651879856"}
0005433533318	29B42D	1797 711761	IGOR KUZMIN	{"email": "kuzminigor27051971@postgrespro.ru", "phone": "+70542115893"}
0005433533319	1F3E91	3113 485235	SVETLANA FILATOVA	{"email": "s_filatova_18071967@postgrespro.ru", "phone": "+70143739353"}
0005433533320	C75060	5517 624665	ARTEM VASILEV	{"phone": "+70164225508"}
0005433533321	31E5DB	9838 496752	PAVEL ABRAMOV	{"email": "pavelabramov-1980@postgrespro.ru", "phone": "+70376012778"}
0005433533322	31E5DB	1444 435046	VASILIY VASILEV	{"email": "vasilevv_1988@postgrespro.ru", "phone": "+70488193162"}
0005433533323	8ACE87	4717 569039	NATALYA IVANOVA	{"email": "natalya-ivanova_041967@postgrespro.ru", "phone": "+70827748471"}
0005433533324	8ACE87	9406 430812	EVGENIY SOROKIN	{"email": "esorokin.1985@postgrespro.ru", "phone": "+70366868923"}
0005433533325	2EA634	8501 816125	LYUBOV OVCHINNIKOVA	{"phone": "+70341903722"}
0005433533326	954B5C	7339 793150	OLGA MARTYNOVA	{"email": "olga-martynova.1981@postgrespro.ru", "phone": "+70283925672"}
0005433533327	203D0C	8079 393010	ELENA MAKSIMOVA	{"email": "maksimova-e_1962@postgrespro.ru", "phone": "+70312449835"}
0005433533328	1381F1	8479 312841	ELENA RYABOVA	{"email": "ryabova.e_011967@postgrespro.ru", "phone": "+70556478171"}
0005433533329	3C76C3	4668 067218	IGOR MOROZOV	{"email": "i_morozov.22031967@postgrespro.ru", "phone": "+70847279492"}
0005433533330	3C76C3	3109 580792	ELENA SEMENOVA	{"phone": "+70414812095"}
0005433533331	B80B3C	6551 025369	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova-22031968@postgrespro.ru", "phone": "+70421445227"}
0005433533332	A4A71A	8530 165522	NATALYA KISELEVA	{"phone": "+70851979910"}
0005433533333	A4A71A	6450 419678	IVAN SOROKIN	{"phone": "+70768381261"}
0005433533334	C8C2DF	1520 784113	NIKOLAY ANDREEV	{"email": "andreev_n071979@postgrespro.ru", "phone": "+70223870907"}
0005433533335	C8C2DF	4481 442261	ANDREY SOLOVEV	{"phone": "+70943889487"}
0005433533336	22820E	5061 972095	PETR GERASIMOV	{"phone": "+70358797601"}
0005433533337	888622	8176 336422	ANATOLIY IVANOV	{"phone": "+70740136751"}
0005433533338	697B1A	0840 344573	MAKSIM KUZMIN	{"email": "mkuzmin.09011977@postgrespro.ru", "phone": "+70892992874"}
0005433533339	697B1A	3407 134451	EVGENIY SHEVCHENKO	{"email": "shevchenko.evgeniy.1965@postgrespro.ru", "phone": "+70207716001"}
0005433533340	697B1A	3049 120771	ALIYA EFREMOVA	{"email": "aefremova-1970@postgrespro.ru", "phone": "+70039399263"}
0005433533341	772A89	6944 370290	NINA MELNIKOVA	{"email": "n_melnikova1964@postgrespro.ru", "phone": "+70208173991"}
0005433533342	DC3DAA	2880 997207	ALEKSANDR ISAEV	{"email": "a_isaev.1962@postgrespro.ru", "phone": "+70712450041"}
0005433533343	042ECE	4461 219137	VIKTOR FROLOV	{"email": "frolov_v-051966@postgrespro.ru", "phone": "+70527174432"}
0005433533344	BFE2AB	9951 167171	KIRILL NIKOLAEV	{"email": "nikolaev_kirill-21121976@postgrespro.ru", "phone": "+70878474093"}
0005433533345	BFE2AB	7491 855791	OLEG TIMOFEEV	{"email": "timofeev.o13091970@postgrespro.ru", "phone": "+70408547999"}
0005433533346	9060E2	6157 648328	IRINA KOLESNIKOVA	{"phone": "+70014153100"}
0005433533347	9060E2	6946 039751	ELIZAVETA ZAKHAROVA	{"email": "zakharova-elizaveta.1974@postgrespro.ru", "phone": "+70969203544"}
0005433533348	9060E2	3473 758759	ARTEMIY MELNIKOV	{"email": "artemiy-melnikov_09011962@postgrespro.ru", "phone": "+70558379112"}
0005433533349	7359A4	3565 389313	VLADIMIR DENISOV	{"email": "vladimirdenisov.28081972@postgrespro.ru", "phone": "+70697690746"}
0005433533350	E7411A	2610 399029	ANDREY YAKOVLEV	{"email": "a.yakovlev.07071974@postgrespro.ru", "phone": "+70051357930"}
0005433533351	E7411A	9331 091993	TATYANA KOLESNIKOVA	{"phone": "+70736499668"}
0005433533352	0A2E8E	1092 368277	ANDREY ZAYCEV	{"email": "zaycev-andrey-121966@postgrespro.ru", "phone": "+70941375523"}
0005433533353	0A2E8E	8672 579813	ANNA PETROVA	{"email": "a-petrova121989@postgrespro.ru", "phone": "+70418306782"}
0005433533354	B87A6E	8197 347405	IVAN SMIRNOV	{"email": "smirnov.i_30011979@postgrespro.ru", "phone": "+70233553909"}
0005433533355	F8DA72	7900 022423	MIKHAIL KISELEV	{"email": "m_kiselev_061977@postgrespro.ru", "phone": "+70453238210"}
0005433533356	239FF1	8552 033821	NIKITA SOROKIN	{"phone": "+70310242231"}
0005433533357	184C3C	9208 350203	ROMAN ZHURAVLEV	{"email": "rzhuravlev-051970@postgrespro.ru", "phone": "+70727245241"}
0005433533358	B5C661	0517 008727	VLADIMIR KOZLOV	{"phone": "+70052657250"}
0005433533359	B23B61	7395 157985	ANASTASIYA KOROLEVA	{"email": "akoroleva.28081974@postgrespro.ru", "phone": "+70528626220"}
0005433533360	CDCE19	4403 278407	SERGEY YAKOVLEV	{"email": "yakovlev-sergey_05011970@postgrespro.ru", "phone": "+70808968694"}
0005433533361	CDCE19	5039 573806	NATALYA KUZMINA	{"email": "natalya-kuzmina_13111969@postgrespro.ru", "phone": "+70345435377"}
0005433533362	FED542	0656 730816	PAVEL ISAEV	{"phone": "+70290944894"}
0005433533363	6425E9	4533 904534	YULIYA SOKOLOVA	{"email": "sokolova.y-23031961@postgrespro.ru", "phone": "+70441274343"}
0005433533364	72FC05	9139 849228	ELENA NOVIKOVA	{"phone": "+70687725572"}
0005433533365	7CA1FC	3392 877715	SERGEY PETROV	{"phone": "+70979578070"}
0005433533366	7CA1FC	3750 132265	EVGENIYA KUZNECOVA	{"email": "evgeniya_kuznecova.1977@postgrespro.ru", "phone": "+70242807730"}
0005433533367	2DA9E7	2020 590717	GRIGORIY POPOV	{"email": "popov-grigoriy.1970@postgrespro.ru", "phone": "+70065191069"}
0005433533368	1D4C68	4022 882482	YURIY BONDARENKO	{"phone": "+70507265982"}
0005433533369	1D4C68	6075 274867	VERA NAZAROVA	{"phone": "+70359750356"}
0005433533370	D34677	9524 928799	ILYA KOZLOV	{"phone": "+70996349367"}
0005433533371	FF0747	4922 760923	PETR NAZAROV	{"email": "nazarov-petr07051974@postgrespro.ru", "phone": "+70580161064"}
0005433533372	FF0747	5857 666614	ALEKSANDR ZHUKOV	{"email": "zhukov_aleksandr_061980@postgrespro.ru", "phone": "+70105707791"}
0005433533373	F1992E	9255 582216	VYACHESLAV POPOV	{"email": "vyacheslavpopov.101984@postgrespro.ru", "phone": "+70088958611"}
0005433533374	F1992E	9028 486576	DMITRIY FILIPPOV	{"email": "filippov.dmitriy_1964@postgrespro.ru", "phone": "+70907269524"}
0005433533375	486926	8668 764563	PAVEL IVANOV	{"phone": "+70833667399"}
0005433533376	A8A70F	2039 980546	ELIZAVETA NIKOLAEVA	{"email": "elizaveta-nikolaeva031981@postgrespro.ru", "phone": "+70181739469"}
0005433533377	A8A70F	8367 330509	TATYANA BOGDANOVA	{"phone": "+70406109181"}
0005433533378	481012	2591 584833	IRINA KUZNECOVA	{"email": "kuznecovairina-071970@postgrespro.ru", "phone": "+70201982498"}
0005433533379	481012	3569 227737	SERGEY GAVRILOV	{"email": "sergeygavrilov-051982@postgrespro.ru", "phone": "+70007906151"}
0005433533380	8C5D1A	0463 321910	ANNA ZAKHAROVA	{"phone": "+70067187442"}
0005433533381	8C5D1A	4825 468845	TATYANA STEPANOVA	{"phone": "+70833093362"}
0005433533382	26CBAD	3293 106366	LEONID MOROZOV	{"phone": "+70736194792"}
0005433533383	26CBAD	8020 904885	ERIK CHERNOV	{"email": "echernov_111970@postgrespro.ru", "phone": "+70600531317"}
0005433533384	8D9BEF	1732 457856	ELENA FADEEVA	{"email": "fadeeva.e.22051975@postgrespro.ru", "phone": "+70758965039"}
0005433533385	713E50	9964 775293	TATYANA KUZNECOVA	{"email": "kuznecovat-071966@postgrespro.ru", "phone": "+70975871937"}
0005433533386	879F22	4709 442914	MARIYA CHERNOVA	{"phone": "+70263317081"}
0005433533387	879F22	9500 145767	SERGEY NAUMOV	{"email": "sergey-naumov05111964@postgrespro.ru", "phone": "+70659400613"}
0005433533388	41E7E9	3448 484820	SVETLANA ANDREEVA	{"email": "svetlana.andreeva081965@postgrespro.ru", "phone": "+70918909153"}
0005433533389	41E7E9	8412 759155	SERGEY KUZMIN	{"email": "s_kuzmin1961@postgrespro.ru", "phone": "+70838026298"}
0005433533390	72207C	6001 475815	ANNA POTAPOVA	{"phone": "+70318726446"}
0005433533391	E4A52A	7711 753581	GALINA POPOVA	{"email": "popova_galina-1959@postgrespro.ru", "phone": "+70055054660"}
0005433533392	B587C7	0038 554449	IRINA SEMENOVA	{"email": "irina-semenova-111973@postgrespro.ru", "phone": "+70134052006"}
0005433533393	4F4BDF	1817 731711	OLEG YAKOVLEV	{"email": "yakovlev.oleg14071976@postgrespro.ru", "phone": "+70391144070"}
0005433533394	4F4BDF	4260 185556	DMITRIY MAKAROV	{"email": "d-makarov_091978@postgrespro.ru", "phone": "+70256160253"}
0005433533395	CE6DF1	5236 326064	DMITRIY OSIPOV	{"phone": "+70140104096"}
0005433533396	CE6DF1	1757 618641	VLADISLAV DENISOV	{"email": "denisov.vladislav1972@postgrespro.ru", "phone": "+70779829447"}
0005433533397	4CF764	4763 110202	ANASTASIYA TIKHONOVA	{"phone": "+70391307091"}
0005433533398	AEB7EE	6832 072275	IVAN ROMANOV	{"email": "ivan-romanov-24051973@postgrespro.ru", "phone": "+70506211247"}
0005433533399	38375C	5834 438066	MARIYA NIKOLAEVA	{"email": "nikolaeva_mariya061971@postgrespro.ru", "phone": "+70395263659"}
0005433533400	38375C	5782 981050	YULIYA FILIPPOVA	{"phone": "+70131769336"}
0005433533401	B1F073	6100 604878	ALEKSANDR FEDOTOV	{"phone": "+70164259068"}
0005433533402	717DFD	5761 781781	ARINA KONOVALOVA	{"email": "akonovalova041964@postgrespro.ru", "phone": "+70214297073"}
0005433533403	C6F53F	4764 185443	ALEKSEY ABRAMOV	{"phone": "+70400280010"}
0005433533404	C6F53F	3941 117790	OLESYA KUZNECOVA	{"phone": "+70707170731"}
0005433533405	28D497	9637 996354	LYUBOV POLYAKOVA	{"email": "l-polyakova.14121971@postgrespro.ru", "phone": "+70417031269"}
0005433533406	7EB7E3	8600 771612	IRINA TARASOVA	{"phone": "+70411534348"}
0005433533407	8165B4	9310 995534	NIKITA MIKHAYLOV	{"phone": "+70779847123"}
0005433533408	8165B4	1615 464545	ADELINA TIKHONOVA	{"email": "tikhonova-adelina_1977@postgrespro.ru", "phone": "+70559597403"}
0005433533409	673ACA	7827 692507	LYUDMILA GERASIMOVA	{"email": "lyudmila-gerasimova071980@postgrespro.ru", "phone": "+70703806326"}
0005433533410	A9B951	3290 442743	ALEKSANDR MIRONOV	{"phone": "+70285030611"}
0005433533411	851A5A	6649 019154	ELENA ANISIMOVA	{"email": "anisimova.elena-1977@postgrespro.ru", "phone": "+70713369122"}
0005433533412	FBB62D	8233 576418	OLGA DENISOVA	{"email": "denisova.olga.10011974@postgrespro.ru", "phone": "+70072176697"}
0005433533413	073F63	2484 427410	DARYA KARPOVA	{"phone": "+70389135874"}
0005433533414	39D8B8	5701 581570	NATALYA FROLOVA	{"phone": "+70039358530"}
0005433533415	39D8B8	2307 518669	VADIM BARANOV	{"email": "vadimbaranov.15041958@postgrespro.ru", "phone": "+70002796925"}
0005433533416	555519	7596 999615	VERA KUZNECOVA	{"email": "vera-kuznecova19011979@postgrespro.ru", "phone": "+70276703438"}
0005433533417	555519	6379 730349	LEONTIY PETROV	{"email": "petrov.l.1977@postgrespro.ru", "phone": "+70024858704"}
0005433533418	B6D9DE	5281 834618	ALEKSANDR IVANOV	{"email": "aivanov.081969@postgrespro.ru", "phone": "+70546350663"}
0005433533419	60D072	8457 797341	VALENTINA KOROLEVA	{"phone": "+70157740093"}
0005433533420	60D072	0713 364941	TATYANA POTAPOVA	{"email": "potapova-tatyana-29031975@postgrespro.ru", "phone": "+70531355721"}
0005433533421	62AF97	4800 734759	ELIZAVETA FROLOVA	{"email": "e-frolova101975@postgrespro.ru", "phone": "+70374413689"}
0005433533422	1C4407	0231 471512	TATYANA SERGEEVA	{"email": "tatyanasergeeva1963@postgrespro.ru", "phone": "+70390136980"}
0005433534460	69D2E2	1034 313606	NADEZHDA AKIMOVA	{"email": "n_akimova.22071967@postgrespro.ru", "phone": "+70207386705"}
0005433534461	E94102	3259 100782	TATYANA FEDOROVA	{"email": "fedorovatatyana.061982@postgrespro.ru", "phone": "+70678643742"}
0005433534462	E94102	8249 600653	YULIYA FADEEVA	{"email": "fadeeva.yuliya_081962@postgrespro.ru", "phone": "+70495777673"}
0005433534463	E94102	3054 661902	LARISA MOISEEVA	{"email": "larisa.moiseeva-1968@postgrespro.ru", "phone": "+70895580472"}
0005433534464	36E558	1805 502244	MARAT TIMOFEEV	{"email": "marat-timofeev-05051972@postgrespro.ru", "phone": "+70109567396"}
0005433534465	36E558	6848 271147	ANDREY FEDOTOV	{"email": "afedotov-1978@postgrespro.ru", "phone": "+70238835064"}
0005433534466	36E558	3317 283290	NATALYA KONOVALOVA	{"phone": "+70108848109"}
0005433534467	AA3EB6	5312 349114	VALENTINA TIKHONOVA	{"email": "tikhonovavalentina.101983@postgrespro.ru", "phone": "+70671251784"}
0005433534468	AA3EB6	0805 530614	VIKTOR SEMENOV	{"email": "semenovv011985@postgrespro.ru", "phone": "+70457652819"}
0005433534469	1F641B	5763 175643	ALFIYA ILINA	{"email": "ailina_061969@postgrespro.ru", "phone": "+70647230853"}
0005433534470	F6D7AC	3666 769244	BORIS NIKITIN	{"phone": "+70685600627"}
0005433534471	F6D7AC	1960 162993	GALINA NAUMOVA	{"email": "naumova.g-26011972@postgrespro.ru", "phone": "+70718772183"}
0005433534472	4E280A	2495 591561	ANATOLIY MEDVEDEV	{"email": "amedvedev_1963@postgrespro.ru", "phone": "+70993137056"}
0005433534473	624D40	1006 527429	MAKSIM BELOV	{"email": "maksim.belov_121966@postgrespro.ru", "phone": "+70647882830"}
0005433534474	4EFBAC	8338 135277	ALEKSANDRA MOISEEVA	{"email": "moiseeva.aleksandra18111969@postgrespro.ru", "phone": "+70932683986"}
0005433534475	76862A	0548 053119	EKATERINA ZHUKOVA	{"phone": "+70951462501"}
0005433534476	76862A	1115 367977	VALENTINA SEMENOVA	{"phone": "+70302374211"}
0005433534477	C6A2E6	9222 052684	PETR DENISOV	{"email": "petr-denisov_091971@postgrespro.ru", "phone": "+70052537506"}
0005433534478	9C7DD5	7579 449576	ALEKSEY BELOV	{"email": "belov.a-29091983@postgrespro.ru", "phone": "+70259611959"}
0005433534479	86240D	4012 779445	ANTONINA NAUMOVA	{"email": "naumova.antonina_1969@postgrespro.ru", "phone": "+70852777161"}
0005433534480	86240D	6473 796868	PAVEL KUZMIN	{"phone": "+70035454948"}
0005433534481	9810FF	9492 169294	OLGA FROLOVA	{"email": "frolova-o_22051968@postgrespro.ru", "phone": "+70022833721"}
0005433534482	9400D8	8117 414255	SERGEY ZAYCEV	{"phone": "+70724188817"}
0005433534483	9400D8	6887 640944	LYUBOV TIKHONOVA	{"email": "tikhonovalyubov-1975@postgrespro.ru", "phone": "+70610975805"}
0005433534484	0310FA	9706 633452	VERA NAUMOVA	{"email": "naumovavera_1981@postgrespro.ru", "phone": "+70869575737"}
0005433534485	A742C0	1141 933493	ALEKSANDR MARTYNOV	{"phone": "+70245357645"}
0005433534486	B8CE27	0090 453483	NIKOLAY MOROZOV	{"email": "morozovn.19031960@postgrespro.ru", "phone": "+70300740729"}
0005433534487	B8CE27	7965 099293	ALEKSANDR NOVIKOV	{"phone": "+70569070328"}
0005433534488	126BD3	0965 861023	ANASTASIYA KOZLOVA	{"email": "kozlova-a1964@postgrespro.ru", "phone": "+70781199763"}
0005433534489	757921	0101 586353	OLGA POLYAKOVA	{"email": "polyakova.olga.1969@postgrespro.ru", "phone": "+70034650380"}
0005433534490	757921	1672 699387	TATYANA MATVEEVA	{"email": "matveeva_tatyana-041972@postgrespro.ru", "phone": "+70570799969"}
0005433534491	16836D	2948 968996	GALINA BORISOVA	{"phone": "+70946273529"}
0005433534492	96A579	0200 967798	NATALYA ANTONOVA	{"email": "natalya.antonova_1972@postgrespro.ru", "phone": "+70519820987"}
0005433534493	44F366	4929 158042	TAMARA NIKOLAEVA	{"phone": "+70687773166"}
0005433534494	44F366	1643 049241	EKATERINA MALYSHEVA	{"email": "e_malysheva14041973@postgrespro.ru", "phone": "+70561739111"}
0005433534495	DE9623	9705 342748	TATYANA TARASOVA	{"phone": "+70316332297"}
0005433534496	DE9623	6731 154261	TAMARA ZOTOVA	{"phone": "+70983493826"}
0005433534497	62219A	9773 875251	VERA ARKHIPOVA	{"email": "arkhipova-v.051968@postgrespro.ru", "phone": "+70868235999"}
0005433534498	3495D8	0398 363048	NADEZHDA ANDREEVA	{"phone": "+70259072577"}
0005433534499	3495D8	0476 225811	ELENA ANDREEVA	{"email": "andreevaelena_1968@postgrespro.ru", "phone": "+70160816812"}
0005433534500	4FB72D	1154 855315	ROMAN KUZMIN	{"email": "kuzmin-r.15031972@postgrespro.ru", "phone": "+70093590260"}
0005433534501	4BFB6F	3386 214497	NATALYA POTAPOVA	{"phone": "+70268208803"}
0005433534502	4F5723	7881 956457	IRINA ZHURAVLEVA	{"phone": "+70433862830"}
0005433534503	76EA1B	8043 526572	ANDREY POPOV	{"email": "popov-andrey_031972@postgrespro.ru", "phone": "+70546187561"}
0005433534504	9B70C2	7947 287087	ELENA ANDREEVA	{"email": "elena-andreeva_07071983@postgrespro.ru", "phone": "+70824745108"}
0005433534505	31629B	1221 043607	NIKOLAY MIKHAYLOV	{"email": "n.mikhaylov-23071974@postgrespro.ru", "phone": "+70514444258"}
0005433534506	ADF674	2273 680767	OLESYA KUZNECOVA	{"email": "kuznecova-olesya-081966@postgrespro.ru", "phone": "+70529081749"}
0005433534507	ADF674	5119 973649	ALEKSANDR MELNIKOV	{"phone": "+70441012362"}
0005433534508	B96E5D	7342 158383	OLGA MOISEEVA	{"phone": "+70257954099"}
0005433534509	F0D152	9141 951844	DMITRIY VASILEV	{"email": "vasilev-dmitriy-061969@postgrespro.ru", "phone": "+70599724703"}
0005433534510	9969A3	0414 281627	RAISA MAKAROVA	{"email": "r_makarova_111976@postgrespro.ru", "phone": "+70149430132"}
0005433534511	11332F	0074 558025	ANDREY TIMOFEEV	{"phone": "+70641829329"}
0005433534512	11332F	6110 833386	SVETLANA ANDREEVA	{"email": "andreeva-s.1957@postgrespro.ru", "phone": "+70471344802"}
0005433534513	46553B	1692 269764	NIKOLAY SEMENOV	{"email": "semenov-nikolay.1974@postgrespro.ru", "phone": "+70482862904"}
0005433534514	46553B	4077 271348	VASILIY GUSEV	{"email": "vasiliy-gusev021975@postgrespro.ru", "phone": "+70667450718"}
0005433534515	ED732B	0538 032844	MARIYA ANDREEVA	{"phone": "+70860902932"}
0005433534516	F13837	0236 643028	TATYANA ILINA	{"phone": "+70741746907"}
0005433534517	F13837	3424 328778	SVETLANA CHERNOVA	{"phone": "+70774475611"}
0005433534518	D6B5E1	8440 387915	VLADIMIR NIKOLAEV	{"phone": "+70336046757"}
0005433534519	7502B1	4734 346828	YURIY MAKSIMOV	{"phone": "+70322230465"}
0005433534520	28D545	2164 264633	VALENTINA MAKAROVA	{"email": "makarova.valentina.091980@postgrespro.ru", "phone": "+70790865833"}
0005433534521	28D545	6414 166981	ALEKSEY KOROLEV	{"email": "akorolev_011977@postgrespro.ru", "phone": "+70865925719"}
0005433534522	1D98B6	3150 465415	ANDREY MOISEEV	{"email": "moiseev-a.061969@postgrespro.ru", "phone": "+70737821348"}
0005433534523	91FACA	1023 417023	ELENA DENISOVA	{"email": "elena_denisova1972@postgrespro.ru", "phone": "+70516193100"}
0005433534524	EEC316	5316 494416	LYUBOV ISAEVA	{"phone": "+70183006715"}
0005433534525	EEC316	9904 642565	ALINA BELYAEVA	{"phone": "+70391578863"}
0005433534526	AC45AD	2419 348591	DMITRIY SERGEEV	{"phone": "+70184129937"}
0005433534527	8E6D92	6786 225121	ANTON FOMIN	{"phone": "+70906911226"}
0005433534528	CA3A1D	3242 780086	VADIM SMIRNOV	{"email": "vadim_smirnov_1986@postgrespro.ru", "phone": "+70731188011"}
0005433534529	CA3A1D	2547 824510	MIKHAIL GAVRILOV	{"email": "mikhailgavrilov_1971@postgrespro.ru", "phone": "+70223410690"}
0005433534530	713006	4020 245646	VIKTORIYA MEDVEDEVA	{"phone": "+70929425837"}
0005433534531	83DF20	4814 314652	VLADIMIR FEDOTOV	{"phone": "+70067798057"}
0005433534532	BFDA64	1482 281008	LYUDMILA YAKOVLEVA	{"email": "lyudmilayakovleva10061980@postgrespro.ru", "phone": "+70125063639"}
0005433534533	BFDA64	9912 378188	GALINA MARTYNOVA	{"email": "martynova_g-29071970@postgrespro.ru", "phone": "+70354073192"}
0005433534534	848A42	6605 668190	LYUBOV TIMOFEEVA	{"phone": "+70514867990"}
0005433534535	848A42	3481 316030	ARINA AFANASEVA	{"email": "a.afanaseva-1986@postgrespro.ru", "phone": "+70299868073"}
0005433534536	5B7178	6752 591896	PAVEL ALEKSANDROV	{"phone": "+70586337500"}
0005433534537	573D69	9702 131105	DENIS PETROV	{"email": "petrov_d_1971@postgrespro.ru", "phone": "+70805811799"}
0005433534538	ACB747	3979 024167	OLGA NIKOLAEVA	{"phone": "+70399263969"}
0005433534539	ED14C4	6873 330182	ELENA MAKAROVA	{"phone": "+70748174821"}
0005433534540	ED14C4	2677 935265	VYACHESLAV OSIPOV	{"phone": "+70323163721"}
0005433534541	3CA1D6	4588 245112	ALEKSANDR DENISOV	{"email": "denisov_a-061956@postgrespro.ru", "phone": "+70643839603"}
0005433534542	3CA1D6	2663 947292	NAILYA MASLOVA	{"phone": "+70208630484"}
0005433534543	6D117A	2516 059920	TATYANA MOISEEVA	{"email": "moiseevatatyana071967@postgrespro.ru", "phone": "+70341142786"}
0005433534544	B2F211	3263 636755	OLEG NIKITIN	{"email": "onikitin051981@postgrespro.ru", "phone": "+70226908432"}
0005433534545	1A55DC	3751 517773	OKSANA ALEKSANDROVA	{"phone": "+70265792235"}
0005433534546	AB0191	9717 915629	TATYANA SAVELEVA	{"phone": "+70298176989"}
0005433534547	3F9E13	6136 176062	ALEKSANDR KOZLOV	{"email": "a.kozlov-07051976@postgrespro.ru", "phone": "+70572810610"}
0005433534548	8D6968	1403 767858	VALENTINA AFANASEVA	{"phone": "+70790234108"}
0005433534549	8D6968	5188 464643	ALINA SOLOVEVA	{"email": "a-soloveva06051978@postgrespro.ru", "phone": "+70857113012"}
0005433534550	C2CB02	4638 738354	VALENTINA ANISIMOVA	{"email": "v-anisimova27071974@postgrespro.ru", "phone": "+70291350961"}
0005433534551	E382EE	0634 398481	ALEKSANDR KAZAKOV	{"email": "kazakov-a_03111981@postgrespro.ru", "phone": "+70877576844"}
0005433534552	942DCC	1130 023849	NIKOLAY ILIN	{"phone": "+70485155577"}
0005433534553	357A6B	8476 900904	DARYA IVANOVA	{"phone": "+70146105705"}
0005433534554	E3A373	6212 166222	STANISLAV KISELEV	{"email": "s-kiselev_1970@postgrespro.ru", "phone": "+70396423759"}
0005433534555	10FDCB	6713 485754	ALEKSEY TIKHONOV	{"email": "tikhonov_aleksey_011982@postgrespro.ru", "phone": "+70247464029"}
0005433534556	E7FA38	4790 873625	SERGEY KULIKOV	{"phone": "+70464847498"}
0005433534557	DBB3A9	4403 064020	EKATERINA MOROZOVA	{"email": "morozova-ekaterina_1973@postgrespro.ru", "phone": "+70713278979"}
0005433534558	DBB3A9	0106 421996	GENNADIY ORLOV	{"email": "orlovg1979@postgrespro.ru", "phone": "+70598748229"}
0005433534559	928BC2	7737 079860	ROMAN NAZAROV	{"phone": "+70639049726"}
0005433534560	928BC2	2651 940731	IVAN BELOV	{"phone": "+70071055064"}
0005433534561	39B1B8	8490 163434	YULIYA KUZNECOVA	{"email": "y.kuznecova071971@postgrespro.ru", "phone": "+70946956576"}
0005433534562	28AED5	5057 716526	IRINA SOLOVEVA	{"email": "soloveva_irina051971@postgrespro.ru", "phone": "+70010290903"}
0005433538717	31EDEF	8547 533782	VIKTORIYA TIKHONOVA	{"phone": "+70200117789"}
0005433538718	31EDEF	7192 264041	DARYA KONDRATEVA	{"email": "kondrateva-darya.18011967@postgrespro.ru", "phone": "+70730118679"}
0005433538719	675F63	9753 553943	LYUDMILA ANDREEVA	{"email": "andreeva-l20091963@postgrespro.ru", "phone": "+70146300916"}
0005433538720	943FB7	5146 327195	ALEKSANDR FILIPPOV	{"phone": "+70260052867"}
0005433538721	D40955	6951 085072	ALEKSEY ZHURAVLEV	{"phone": "+70318114026"}
0005433538722	973E52	8348 643660	ANTON MOISEEV	{"phone": "+70915268515"}
0005433538723	973E52	6878 077332	SEMEN MIRONOV	{"email": "semen_mironov.1980@postgrespro.ru", "phone": "+70625757775"}
0005433538724	4CB3D6	8325 575682	ROMAN POPOV	{"email": "popov-roman-1966@postgrespro.ru", "phone": "+70042317947"}
0005433538725	D339FD	4276 006988	GALINA SAVELEVA	{"phone": "+70063094729"}
0005433538726	D339FD	4932 433438	EKATERINA MATVEEVA	{"phone": "+70513758763"}
0005433538727	DD1C72	8447 117272	NATALYA MOROZOVA	{"email": "n_morozova.08041962@postgrespro.ru", "phone": "+70699557615"}
0005433538728	DD1C72	6785 428214	NIKITA SOKOLOV	{"email": "nikita-sokolov-13111971@postgrespro.ru", "phone": "+70321223754"}
0005433538729	71868D	9534 231367	IVAN IVANOV	{"email": "ivan_ivanov-29061968@postgrespro.ru", "phone": "+70381034624"}
0005433538730	71868D	4795 237564	ALENA KOROLEVA	{"phone": "+70554744469"}
0005433538731	71868D	8913 909837	VITALIY CHERNOV	{"phone": "+70918706888"}
0005433538732	E3E4EF	5227 198896	VERA NIKIFOROVA	{"email": "vera.nikiforova041968@postgrespro.ru", "phone": "+70040076833"}
0005433538733	E3E4EF	1275 678056	ALLA PETROVA	{"phone": "+70198012805"}
0005433538734	7EDA34	0328 817788	YURIY NIKOLAEV	{"phone": "+70775201374"}
0005433538735	7EDA34	1679 352947	RUSLAN MARTYNOV	{"email": "ruslan_martynov_07061975@postgrespro.ru", "phone": "+70317462965"}
0005433538736	7EDA34	5043 484567	LARISA RODIONOVA	{"phone": "+70928493218"}
0005433538737	BCBA4A	4225 179755	PAVEL ALEKSANDROV	{"phone": "+70413218546"}
0005433538738	0F999D	3267 509714	MARIYA PAVLOVA	{"phone": "+70798292380"}
0005433538739	0F999D	2044 019882	YANA KUZNECOVA	{"phone": "+70754336839"}
0005433538740	846EA5	9641 385014	SERGEY ZAYCEV	{"phone": "+70882433656"}
0005433538741	D296EE	5614 755848	ANASTASIYA MELNIKOVA	{"phone": "+70733532409"}
0005433538742	D3A330	5358 167818	KSENIYA ANISIMOVA	{"email": "anisimova-k_121972@postgrespro.ru", "phone": "+70969387490"}
0005433538743	E7F235	5221 603457	VADIM BONDARENKO	{"phone": "+70043536932"}
0005433538744	F6C1DE	4023 198936	OLGA MAKSIMOVA	{"phone": "+70269494661"}
0005433538745	F6C1DE	8032 266021	ANTONINA DANILOVA	{"phone": "+70846848707"}
0005433538746	EC0B8A	7176 960199	YURIY ZHUKOV	{"email": "y.zhukov_021978@postgrespro.ru", "phone": "+70879958737"}
0005433538747	EC0B8A	9377 794494	INNA KUZMINA	{"email": "kuzminainna_101962@postgrespro.ru", "phone": "+70573960882"}
0005433538748	CF9FD3	3646 291236	SVETLANA TIKHONOVA	{"email": "s-tikhonova-1968@postgrespro.ru", "phone": "+70414110928"}
0005433538749	31EB3A	8996 131042	ELENA ANTONOVA	{"email": "eantonova14121968@postgrespro.ru", "phone": "+70194683139"}
0005433538750	31EB3A	3304 065985	OKSANA POPOVA	{"phone": "+70706550091"}
0005433538751	17380F	4703 354908	SERGEY SCHERBAKOV	{"email": "scherbakov.s-02071974@postgrespro.ru", "phone": "+70873507226"}
0005433538752	17380F	8804 805952	ILYA STEPANOV	{"phone": "+70884954782"}
0005433538753	17380F	6381 548722	EKATERINA ANDREEVA	{"email": "eandreeva_05031979@postgrespro.ru", "phone": "+70490218015"}
0005433538754	062A84	8035 811943	NADEZHDA SOKOLOVA	{"phone": "+70272336450"}
0005433538755	69E6C5	2127 757580	LYUDMILA GAVRILOVA	{"email": "gavrilovalyudmila1964@postgrespro.ru", "phone": "+70761117557"}
0005433538756	69E6C5	7694 994853	SERGEY BORISOV	{"phone": "+70594122065"}
0005433538757	D9268C	3769 574244	KSENIYA FADEEVA	{"phone": "+70442461108"}
0005433538758	D9268C	0896 175704	ALEKSANDR RODIONOV	{"phone": "+70053702290"}
0005433538759	8684FA	4496 808889	OLGA NIKIFOROVA	{"phone": "+70034680491"}
0005433538760	B05EE9	6108 194531	MAKSIM MIRONOV	{"email": "maksimmironov05061959@postgrespro.ru", "phone": "+70818066628"}
0005433538761	B05EE9	7346 179400	ELENA CHERNOVA	{"phone": "+70799354801"}
0005433538762	3C188B	2127 470022	ANTONINA ERMAKOVA	{"phone": "+70735112064"}
0005433538763	3C188B	3690 785738	ROMAN CHERNOV	{"phone": "+70066083212"}
0005433538764	3C188B	3007 264645	ALEKSANDR BONDARENKO	{"phone": "+70456448554"}
0005433538765	546216	7432 024091	EVGENIY GUSEV	{"email": "guseve.051971@postgrespro.ru", "phone": "+70147602006"}
0005433538766	510DB2	3663 687189	DANILA SOLOVEV	{"phone": "+70164254176"}
0005433538767	510DB2	9491 036013	VLADIMIR ANTONOV	{"phone": "+70393081476"}
0005433538768	510DB2	9149 479527	ALEKSANDR KISELEV	{"email": "aleksandr_kiselev-061972@postgrespro.ru", "phone": "+70959965230"}
0005433538769	2BB7B1	2314 438972	NATALYA FADEEVA	{"email": "fadeevan.071967@postgrespro.ru", "phone": "+70452888052"}
0005433538770	FB3477	7768 183102	OLGA VOLKOVA	{"email": "o.volkova_03021965@postgrespro.ru", "phone": "+70268102482"}
0005433538771	1520B0	2026 812393	VALENTINA POPOVA	{"email": "popova.v-021977@postgrespro.ru", "phone": "+70581825588"}
0005433538772	7D7758	5734 419847	ANATOLIY SEMENOV	{"email": "a-semenov11061972@postgrespro.ru", "phone": "+70646566532"}
0005433538773	7D7758	2746 613588	VERA BELYAEVA	{"email": "belyaeva_vera.1973@postgrespro.ru", "phone": "+70418814592"}
0005433538774	0210AA	7295 801987	ELVIRA OVCHINNIKOVA	{"email": "elvira-ovchinnikova.14011965@postgrespro.ru", "phone": "+70227027819"}
0005433538775	48D959	2599 166921	ALEKSEY DAVYDOV	{"phone": "+70891213437"}
0005433538776	711E9F	3602 174466	EVGENIYA GERASIMOVA	{"phone": "+70106527570"}
0005433538777	0696D8	2278 825179	LYUBOV KOMAROVA	{"phone": "+70747805951"}
0005433538778	46D153	4173 703045	ELVIRA DMITRIEVA	{"phone": "+70637945240"}
0005433538779	46D153	3963 144455	SERGEY AFANASEV	{"email": "afanasev.s-111964@postgrespro.ru", "phone": "+70261811364"}
0005433538780	E499ED	5496 010590	NIKOLAY TIKHONOV	{"email": "ntikhonov-101985@postgrespro.ru", "phone": "+70536104886"}
0005433538781	E499ED	9055 197205	ALEKSEY SEMENOV	{"email": "semenov.a_1967@postgrespro.ru", "phone": "+70950919797"}
0005433538782	9E8EAE	4145 024212	VENIAMIN OSIPOV	{"email": "osipov-veniamin1972@postgrespro.ru", "phone": "+70355823857"}
0005433538783	7E0F83	6801 541146	VLADIMIR MIKHAYLOV	{"phone": "+70637020912"}
0005433538784	B02073	9577 454510	MARIYA POPOVA	{"email": "mariyapopova.16041984@postgrespro.ru", "phone": "+70053413604"}
0005433538785	177CC2	8880 833571	MARIYA LUKYANOVA	{"email": "mariya_lukyanova031966@postgrespro.ru", "phone": "+70244593400"}
0005433538786	913B3C	9548 707295	STANISLAV FEDOROV	{"phone": "+70741451070"}
0005433538787	7DB123	5450 755856	YULIYA VOROBEVA	{"phone": "+70405785527"}
0005433538788	18E18E	3485 353750	ANDREY ZAKHAROV	{"phone": "+70711622868"}
0005433538789	807050	5039 235781	VLADIMIR KAZAKOV	{"email": "kazakov-v071970@postgrespro.ru", "phone": "+70285087035"}
0005433538790	1D097A	7324 621005	ANATOLIY ANDREEV	{"email": "andreev_a-22081984@postgrespro.ru", "phone": "+70990758415"}
0005433538791	1D097A	1183 819617	VADIM NIKITIN	{"email": "nikitin-v101979@postgrespro.ru", "phone": "+70314104304"}
0005433538792	0CA2CF	1120 934379	GALINA NIKIFOROVA	{"phone": "+70206213156"}
0005433538793	0CA2CF	2678 230262	ANDREY ANTONOV	{"email": "antonov-andrey-041981@postgrespro.ru", "phone": "+70270323497"}
0005433538794	4E363E	1623 808918	NATALYA BELOVA	{"email": "belova_natalya041970@postgrespro.ru", "phone": "+70772551270"}
0005433538795	93B8B7	1108 445621	LIDIYA MAKAROVA	{"phone": "+70285783888"}
0005433538796	93B8B7	9871 910394	ZLATA ZHURAVLEVA	{"email": "z-zhuravleva091965@postgrespro.ru", "phone": "+70783109703"}
0005433538797	93B8B7	1055 345524	RAISA ANTONOVA	{"email": "antonova.raisa-17071971@postgrespro.ru", "phone": "+70090920755"}
0005433538798	CAF7DD	0868 316315	ELENA VOLKOVA	{"email": "e_volkova1973@postgrespro.ru", "phone": "+70326710551"}
0005433538799	12E60B	6310 607922	ELIZAVETA BELOVA	{"email": "elizaveta_belova-1972@postgrespro.ru", "phone": "+70502635603"}
0005433538800	12E60B	0113 307416	ANASTASIYA FOMINA	{"phone": "+70227353349"}
0005433538801	2C667B	3620 429726	SERGEY FEDOTOV	{"email": "fedotov_s_1972@postgrespro.ru", "phone": "+70426138428"}
0005433538802	04B1CB	0318 269671	ELENA ZAYCEVA	{"email": "zaycevaelena-121980@postgrespro.ru", "phone": "+70822077091"}
0005433538803	04B1CB	4476 671330	VERA EGOROVA	{"email": "egorova.vera_1968@postgrespro.ru", "phone": "+70307210140"}
0005433538804	CA4CC4	0359 282550	VLADIMIR ZAKHAROV	{"email": "v.zakharov.021978@postgrespro.ru", "phone": "+70255820015"}
0005433538805	FB3B64	4160 296346	NADEZHDA ROMANOVA	{"phone": "+70847359411"}
0005433538806	ACD14A	7390 754501	NIKOLAY PAVLOV	{"phone": "+70082725580"}
0005433538807	ACD14A	9424 805083	DMITRIY GORBUNOV	{"email": "gorbunovdmitriy.121974@postgrespro.ru", "phone": "+70462529218"}
0005433538808	A1D3ED	9793 473307	ANNA ABRAMOVA	{"phone": "+70664941714"}
0005433538809	A1D3ED	3827 625760	TAMARA VOLKOVA	{"email": "volkova_t.1962@postgrespro.ru", "phone": "+70338929267"}
0005433538810	BA96D0	6489 530108	YURIY PETROV	{"email": "petrov.yuriy24021963@postgrespro.ru", "phone": "+70385843215"}
0005433538811	F54F38	4680 740250	IRINA ZAKHAROVA	{"email": "i.zakharova.021972@postgrespro.ru", "phone": "+70380461429"}
0005433538812	F54F38	0497 167499	TATYANA YAKOVLEVA	{"email": "yakovlevat031976@postgrespro.ru", "phone": "+70066436328"}
0005433538813	CC4175	5129 746431	TAMARA DMITRIEVA	{"email": "dmitrieva-t-1969@postgrespro.ru", "phone": "+70276652784"}
0005433538814	D3540E	5109 067962	NATALYA VASILEVA	{"email": "n_vasileva.1967@postgrespro.ru", "phone": "+70018672834"}
0005433538815	D3540E	1880 855284	VIKTOR DENISOV	{"email": "viktor_denisov24101957@postgrespro.ru", "phone": "+70440186514"}
0005433538816	1EF821	9724 075002	ELENA NESTEROVA	{"email": "e-nesterova.031970@postgrespro.ru", "phone": "+70362395864"}
0005433538817	73D59C	4633 830114	RAVIL SOKOLOV	{"phone": "+70662516650"}
0005433538818	93BECA	7241 025065	GALINA ZAYCEVA	{"phone": "+70794954260"}
0005433538819	DD1E24	0400 647643	SERGEY BELOV	{"email": "belov_sergey.16121962@postgrespro.ru", "phone": "+70135734550"}
0005433538820	CDE76F	0199 265518	ALEKSEY VOLKOV	{"phone": "+70184988970"}
0005433538821	CDE76F	4739 711777	IGOR BARANOV	{"email": "baranov-igor.101977@postgrespro.ru", "phone": "+70052273026"}
0005433538822	CDE76F	7815 190449	SERGEY BARANOV	{"phone": "+70478231515"}
0005433538823	469C88	1063 365409	OLEG SCHERBAKOV	{"email": "o.scherbakov-1970@postgrespro.ru", "phone": "+70134243794"}
0005433538824	9B59B3	2590 006258	ZOYA VOLKOVA	{"phone": "+70181887302"}
0005433538825	9B59B3	6278 723209	IRINA VLASOVA	{"email": "vlasova_i-08091972@postgrespro.ru", "phone": "+70664721186"}
0005433538826	25520E	7821 785302	MARIYA SOROKINA	{"email": "msorokina.1976@postgrespro.ru", "phone": "+70468354279"}
0005433538827	25520E	4047 908966	MAKSIM KUZNECOV	{"email": "kuznecov-maksim_27031975@postgrespro.ru", "phone": "+70280190321"}
0005433538828	25520E	7843 790750	VERA IVANOVA	{"email": "ivanova.v_061976@postgrespro.ru", "phone": "+70850724710"}
0005433538829	25520E	9079 127225	IRINA IVANOVA	{"email": "ivanova-i-19031973@postgrespro.ru", "phone": "+70380697659"}
0005433538830	6678E9	1665 476481	MIKHAIL DAVYDOV	{"phone": "+70832329763"}
0005433538831	6678E9	8530 403446	IVAN MELNIKOV	{"email": "i_melnikov.051971@postgrespro.ru", "phone": "+70334299859"}
0005433538832	C38D8A	0723 729065	MARIYA ZHURAVLEVA	{"email": "mariya-zhuravleva-1964@postgrespro.ru", "phone": "+70499716565"}
0005433538833	C38D8A	8908 626946	VLADIMIR SOKOLOV	{"email": "vsokolov1981@postgrespro.ru", "phone": "+70286467056"}
0005433538834	FDF0C3	5815 591641	TATYANA ALEKSEEVA	{"phone": "+70514478348"}
0005433538835	B90220	7792 178804	ALEKSANDR FROLOV	{"email": "frolov.aleksandr-18091970@postgrespro.ru", "phone": "+70312688199"}
0005433538836	B90220	4929 037478	NIKOLAY CHERNOV	{"email": "n.chernov.04101971@postgrespro.ru", "phone": "+70755467465"}
0005433538837	1A0552	6162 693612	MADINA SAVELEVA	{"email": "saveleva.madina.18101972@postgrespro.ru", "phone": "+70913346902"}
0005433538838	743E8A	9133 625870	ILDAR MIRONOV	{"email": "ildar-mironov-091980@postgrespro.ru", "phone": "+70137555277"}
0005433538839	743E8A	8310 781122	VLADIMIR SOKOLOV	{"phone": "+70167014926"}
0005433538840	299D4E	5718 126949	MARINA ZAKHAROVA	{"phone": "+70474019940"}
0005433538841	FE02DD	6144 305224	OLGA MAKAROVA	{"email": "o_makarova_1972@postgrespro.ru", "phone": "+70952635804"}
0005433538842	EE5523	2508 042428	NADEZHDA KOZLOVA	{"email": "n_kozlova031996@postgrespro.ru", "phone": "+70687748900"}
0005433538843	36DC25	3327 346048	NATALYA ERMAKOVA	{"phone": "+70724023628"}
0005433538844	5A7EFE	4789 075824	VALENTINA YUDINA	{"phone": "+70280186974"}
0005433538845	48629A	0958 905902	MAKSIM YAKOVLEV	{"email": "yakovlev_maksim08061978@postgrespro.ru", "phone": "+70268572686"}
0005433538846	990EE7	6850 703319	ILYA VOROBEV	{"email": "ilya.vorobev1970@postgrespro.ru", "phone": "+70423353667"}
0005433538847	990EE7	6781 911808	ANNA NIKOLAEVA	{"email": "annanikolaeva.091983@postgrespro.ru", "phone": "+70817984106"}
0005433538848	8ACEB9	6850 593107	DANIIL TIKHONOV	{"phone": "+70905349835"}
0005433538849	38F25F	0055 681131	OLGA BELOVA	{"email": "belova-o_08101969@postgrespro.ru", "phone": "+70296144007"}
0005433538850	567A6C	3839 479814	ZINAIDA ZHURAVLEVA	{"phone": "+70802726550"}
0005433538851	AFBA00	3076 379080	IVAN IVANOV	{"email": "ivanov_i071982@postgrespro.ru", "phone": "+70151657666"}
0005433538852	9845B2	5210 366237	DARYA KOROLEVA	{"phone": "+70132822370"}
0005433538853	6CB285	2399 068282	TATYANA FADEEVA	{"phone": "+70909385830"}
0005433538854	57877B	4271 624237	VERA STEPANOVA	{"email": "verastepanova.11071971@postgrespro.ru", "phone": "+70946392845"}
0005433538855	AC4A21	9766 540490	VALERIYA SEMENOVA	{"phone": "+70056857506"}
0005433538856	AC4A21	5731 921305	VYACHESLAV SIDOROV	{"email": "sidorov-v-23091966@postgrespro.ru", "phone": "+70829230006"}
0005433538857	5D9A0F	3006 545168	DIANA VLASOVA	{"email": "diana.vlasova_09051970@postgrespro.ru", "phone": "+70231077359"}
0005433538858	A465ED	3716 669777	KIRILL NAZAROV	{"email": "nazarov_kirill.01031978@postgrespro.ru", "phone": "+70099629985"}
0005433538859	842E16	9616 976549	ANNA PAVLOVA	{"phone": "+70677793485"}
0005433538860	787EA9	3062 653965	STANISLAV KOROLEV	{"email": "korolev-stanislav_14121976@postgrespro.ru", "phone": "+70066476020"}
0005433538861	A83AA6	9161 301301	YULIYA LUKYANOVA	{"email": "lukyanovay-16101967@postgrespro.ru", "phone": "+70916229266"}
0005433538862	A83AA6	6593 502180	RAISA KOMAROVA	{"phone": "+70192624095"}
0005433538863	188226	0935 420480	ROMAN TARASOV	{"phone": "+70088168168"}
0005433538864	F2ADA1	6152 927006	PETR FROLOV	{"phone": "+70989237736"}
0005433538865	F2ADA1	6506 243396	DMITRIY TARASOV	{"email": "dmitriytarasov011960@postgrespro.ru", "phone": "+70587994460"}
0005433538866	5D583B	0783 707202	LEV NIKOLAEV	{"email": "nikolaev_lev.011968@postgrespro.ru", "phone": "+70882734278"}
0005433538867	C7BCC1	3034 851531	ANDREY SOROKIN	{"phone": "+70201627922"}
0005433538868	C7BCC1	9736 652573	ZINAIDA SERGEEVA	{"email": "sergeeva.z121966@postgrespro.ru", "phone": "+70961061375"}
0005433538869	B699F7	7421 368789	ILYA VASILEV	{"email": "i-vasilev-06011977@postgrespro.ru", "phone": "+70551998807"}
0005433538870	F18889	4245 465834	MIKHAIL KULIKOV	{"phone": "+70494024044"}
0005433538871	93F849	4849 778386	ALEKSANDR IVANOV	{"phone": "+70848246306"}
0005433538872	1F6EED	8643 694198	ALEKSANDR KULIKOV	{"phone": "+70279380229"}
0005433538873	73EF80	3286 673158	KLAVDIYA ANDREEVA	{"email": "klavdiya.andreeva-091978@postgrespro.ru", "phone": "+70491818553"}
0005433538874	73EF80	3681 842925	VALENTINA KISELEVA	{"email": "v_kiseleva021979@postgrespro.ru", "phone": "+70524327609"}
0005433538875	F29C2C	6250 154565	TATYANA MAKSIMOVA	{"phone": "+70824519976"}
0005433538876	F29C2C	7541 365664	MARSEL NIKITIN	{"email": "nikitinmarsel-07121977@postgrespro.ru", "phone": "+70904128853"}
0005433538877	55467E	5746 151254	ELIZAVETA ALEKSEEVA	{"phone": "+70702341746"}
0005433538878	61838D	8311 608003	IRINA POPOVA	{"phone": "+70192805139"}
0005433538879	61838D	2714 287289	IRINA EGOROVA	{"email": "egorova-i_081979@postgrespro.ru", "phone": "+70604541354"}
0005433538880	156A6D	6305 580145	YURIY KUZNECOV	{"email": "kuznecov.yuriy_011956@postgrespro.ru", "phone": "+70656589189"}
0005433538881	C2E112	4318 060181	EVGENIY SHEVCHENKO	{"email": "e-shevchenko_28121963@postgrespro.ru", "phone": "+70217976840"}
0005433538882	C2E112	5489 314119	DMITRIY IVANOV	{"email": "ivanov-dmitriy_18071972@postgrespro.ru", "phone": "+70462326845"}
0005433538883	C2E112	2299 830786	NIKOLAY ISAEV	{"email": "isaev-nikolay_1970@postgrespro.ru", "phone": "+70591031214"}
0005433538884	C447D6	7391 376244	EVGENIY YAKOVLEV	{"phone": "+70230789186"}
0005433538885	C447D6	6166 668774	VIKTOR BORISOV	{"phone": "+70870305942"}
0005433538886	ACBA91	8370 489265	SAVELIY ORLOV	{"phone": "+70248604847"}
0005433538887	643563	6685 309005	IRINA TIMOFEEVA	{"email": "timofeeva_irina1968@postgrespro.ru", "phone": "+70846984387"}
0005433538888	643563	9517 250030	OLESYA KUZMINA	{"phone": "+70382010909"}
0005433538889	BAD8ED	6775 974579	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina_041975@postgrespro.ru", "phone": "+70500716300"}
0005433538890	733971	7795 057088	ELENA VASILEVA	{"email": "vasileva_elena.1978@postgrespro.ru", "phone": "+70687669361"}
0005433538891	5AF0B3	4451 911843	ANATOLIY DAVYDOV	{"email": "a.davydov22121972@postgrespro.ru", "phone": "+70238969146"}
0005433538892	5AF0B3	0244 567729	ALEKSANDR KONOVALOV	{"phone": "+70785971459"}
0005433538893	326D8E	3803 768459	TATYANA ANTONOVA	{"phone": "+70790962194"}
0005433538894	AF2A5D	6572 943383	RAISA POPOVA	{"email": "popova_r-22031979@postgrespro.ru", "phone": "+70253748151"}
0005433538895	DF8A0C	4838 723857	ELENA TARASOVA	{"phone": "+70220251678"}
0005433538896	DF8A0C	0568 508566	MARAT MAKAROV	{"phone": "+70594482120"}
0005433538897	62A036	8775 078160	IVAN SCHERBAKOV	{"phone": "+70407323175"}
0005433538898	62A036	2976 900902	NIKOLAY ABRAMOV	{"email": "n_abramov_27051973@postgrespro.ru", "phone": "+70418725980"}
0005433538899	62A036	9798 342728	DMITRIY PAVLOV	{"email": "dpavlov_1971@postgrespro.ru", "phone": "+70690470920"}
0005433538900	43DAF0	9201 744572	ANASTASIYA YUDINA	{"email": "yudina_anastasiya1983@postgrespro.ru", "phone": "+70448315061"}
0005433538901	AB2BA4	4383 675943	VLADIMIR DMITRIEV	{"email": "dmitriev_vladimir-081972@postgrespro.ru", "phone": "+70694520893"}
0005433538902	6386E2	8356 011371	LYUDMILA TROFIMOVA	{"email": "trofimova_l.081982@postgrespro.ru", "phone": "+70099901594"}
0005433538903	21A62D	7486 350747	RINAT MAKSIMOV	{"phone": "+70917543253"}
0005433538904	21A62D	9257 837545	TAISIYA FOMINA	{"email": "fomina.taisiya-1979@postgrespro.ru", "phone": "+70794551530"}
0005433538905	5F3BDC	7019 997619	ANDREY KUZNECOV	{"phone": "+70643118084"}
0005433538906	857E2D	5073 524517	OLEG ROMANOV	{"email": "romanov-oleg-29041981@postgrespro.ru", "phone": "+70687867528"}
0005433538907	70A9CD	3085 809353	SERGEY STEPANOV	{"email": "s-stepanov1975@postgrespro.ru", "phone": "+70073193627"}
0005433538908	704D42	3275 788201	SERGEY ALEKSEEV	{"email": "alekseev-s061961@postgrespro.ru", "phone": "+70285107442"}
0005433538909	B033DB	6275 399901	GALINA NIKOLAEVA	{"email": "nikolaeva.galina-081973@postgrespro.ru", "phone": "+70529253098"}
0005433538910	C64B70	3411 531535	SERGEY GRIGOREV	{"email": "s-grigorev-111967@postgrespro.ru", "phone": "+70308890652"}
0005433538911	0BCD9B	0701 845644	NIKOLAY ZAYCEV	{"phone": "+70328050254"}
0005433538912	0BCD9B	9315 635564	OLGA LOGINOVA	{"email": "loginova-o_121978@postgrespro.ru", "phone": "+70291310569"}
0005433538913	BD0758	8411 364844	TAISIYA GUSEVA	{"email": "guseva_taisiya.1963@postgrespro.ru", "phone": "+70625557406"}
0005433538914	6C0037	7068 699629	ARTEM ROMANOV	{"phone": "+70765404887"}
0005433538915	6C0037	1488 802636	TATYANA ZAYCEVA	{"email": "zaycevatatyana-1986@postgrespro.ru", "phone": "+70515392619"}
0005433538916	FBBA1B	9508 748124	ANASTASIYA BARANOVA	{"email": "baranova.anastasiya_031980@postgrespro.ru", "phone": "+70025884608"}
0005433538917	1B77A9	1342 950875	MARIYA SOROKINA	{"email": "msorokina.101973@postgrespro.ru", "phone": "+70801037257"}
0005433538918	16C3CE	3368 781821	DMITRIY NIKOLAEV	{"phone": "+70836388666"}
0005433538919	16C3CE	1450 343584	EVGENIY ALEKSEEV	{"phone": "+70110973796"}
0005433538920	6E4A17	5887 033740	SERGEY ORLOV	{"phone": "+70696367985"}
0005433538921	80FF97	4194 008296	STANISLAV KOZLOV	{"phone": "+70679256221"}
0005433538922	80FF97	8233 703067	SVETLANA FROLOVA	{"phone": "+70558286183"}
0005433538923	889456	9543 002998	VERA GAVRILOVA	{"phone": "+70410000354"}
0005433538924	69094E	4868 398149	NINA MELNIKOVA	{"phone": "+70971318661"}
0005433538925	6A6874	7428 869225	VIKTORIYA POPOVA	{"phone": "+70047681579"}
0005433538926	6A6874	6825 186352	VITALIY SMIRNOV	{"email": "smirnov.v_1977@postgrespro.ru", "phone": "+70236471155"}
0005433538927	31BC0D	4958 776096	ZINAIDA VLASOVA	{"email": "zinaida_vlasova091981@postgrespro.ru", "phone": "+70453589574"}
0005433538928	CF817C	9480 436545	VALENTINA GERASIMOVA	{"phone": "+70759549133"}
0005433538929	B40BD6	9605 365410	ALEKSEY KARPOV	{"email": "a_karpov-01041974@postgrespro.ru", "phone": "+70043927055"}
0005433538930	B40BD6	3788 182252	OLGA MATVEEVA	{"email": "o-matveeva-1964@postgrespro.ru", "phone": "+70116313348"}
0005433538931	7FA709	3334 553562	IGOR KUZNECOV	{"email": "i_kuznecov.111973@postgrespro.ru", "phone": "+70593648109"}
0005433538932	4F1EA6	7468 400627	ANDREY BONDARENKO	{"phone": "+70026802575"}
0005433538933	4F1EA6	2901 541103	ALEKSANDR KUZMIN	{"phone": "+70178749458"}
0005433538934	C241EE	9729 199285	IRINA EGOROVA	{"phone": "+70902021717"}
0005433538935	5238F1	1628 415872	GENNADIY SCHERBAKOV	{"phone": "+70330850647"}
0005433538936	C47288	9332 042519	NADEZHDA MASLOVA	{"email": "nadezhda_maslova.091971@postgrespro.ru", "phone": "+70756102927"}
0005433538937	C47288	6616 585431	GENNADIY TIKHONOV	{"email": "tikhonov.gennadiy121976@postgrespro.ru", "phone": "+70657611529"}
0005433538938	D1180A	5940 688899	VIKTOR NAZAROV	{"email": "v-nazarov_21061964@postgrespro.ru", "phone": "+70806551180"}
0005433538939	D1180A	3562 600361	ILYA GORBUNOV	{"phone": "+70711186854"}
0005433538940	D1180A	4569 887803	IGOR KUZNECOV	{"phone": "+70430767333"}
0005433538941	E94E3C	0563 628398	NATALYA YAKOVLEVA	{"email": "n-yakovleva_101962@postgrespro.ru", "phone": "+70297542956"}
0005433538942	E94E3C	6293 946734	KIRILL KULIKOV	{"phone": "+70990548985"}
0005433538943	61B146	7056 176709	MARIYA YAKOVLEVA	{"phone": "+70851537332"}
0005433538944	4C608A	2834 056877	ALEVTINA FEDOROVA	{"email": "afedorova_021965@postgrespro.ru", "phone": "+70726316849"}
0005433538945	4C608A	5208 850261	ALEKSANDR KUZNECOV	{"email": "akuznecov041964@postgrespro.ru", "phone": "+70333768108"}
0005433538946	4C608A	0203 970039	TATYANA GUSEVA	{"phone": "+70687171865"}
0005433538947	905012	0867 679632	VLADIMIR MAKAROV	{"email": "vladimir-makarov1972@postgrespro.ru", "phone": "+70742969266"}
0005433538948	90935B	9330 922871	NATALIYA RODIONOVA	{"email": "nataliya-rodionova_15101972@postgrespro.ru", "phone": "+70205486590"}
0005433538949	1C94F0	1267 904174	TATYANA ZOTOVA	{"email": "zotova.t.18091973@postgrespro.ru", "phone": "+70892853057"}
0005433538950	1C94F0	4347 563859	ANASTASIYA MAKAROVA	{"email": "makarova_a_1971@postgrespro.ru", "phone": "+70636072113"}
0005433538951	1C94F0	8757 876450	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a_031975@postgrespro.ru", "phone": "+70747890156"}
0005433538952	7278EE	8985 480570	FAINA VLASOVA	{"phone": "+70046659640"}
0005433538953	7278EE	9928 969246	NIKOLAY DMITRIEV	{"email": "dmitrievnikolay_1961@postgrespro.ru", "phone": "+70323442609"}
0005433538954	7278EE	5390 072356	ALEKSEY MAKAROV	{"phone": "+70177810929"}
0005433538955	C64C53	5008 131006	YURIY KOROLEV	{"email": "korolev.y.061977@postgrespro.ru", "phone": "+70137897151"}
0005433538956	C64C53	5270 340807	ANTONINA ROMANOVA	{"email": "romanova_a_1975@postgrespro.ru", "phone": "+70457904085"}
0005433538957	C64C53	9634 745465	LIDIYA BOGDANOVA	{"email": "lidiya-bogdanova-1975@postgrespro.ru", "phone": "+70244524820"}
0005433538958	C64C53	2789 984150	ALEKSANDR SOKOLOV	{"phone": "+70453949847"}
0005433538959	C86BB8	0315 925349	OLESYA AFANASEVA	{"phone": "+70836797643"}
0005433538960	C86BB8	0913 671042	YAKOV PETROV	{"email": "ypetrov.01091979@postgrespro.ru", "phone": "+70403278465"}
0005433538961	244411	0484 588012	SERGEY KUZNECOV	{"email": "kuznecov.sergey12091973@postgrespro.ru", "phone": "+70261167160"}
0005433538962	244411	0408 325758	ELENA KISELEVA	{"phone": "+70529759207"}
0005433538963	BC8CD6	0580 263972	YULIYA MARTYNOVA	{"phone": "+70322560143"}
0005433538964	729398	7631 552996	KLAVDIYA LOGINOVA	{"phone": "+70720083774"}
0005433538965	729398	9837 747911	YULIYA SERGEEVA	{"phone": "+70404331795"}
0005433538966	729398	4697 845540	LYUDMILA ORLOVA	{"email": "orlova_l-20111963@postgrespro.ru", "phone": "+70530653378"}
0005433538967	6A1CF3	0797 370565	MIROSLAV KUZMIN	{"phone": "+70714326760"}
0005433538968	C0223A	6362 799014	IVAN DMITRIEV	{"phone": "+70527146905"}
0005433538969	586D07	0638 400695	ANASTASIYA NESTEROVA	{"email": "anastasiyanesterova1976@postgrespro.ru", "phone": "+70499996102"}
0005433538970	D00A79	7321 717277	IRAIDA KONOVALOVA	{"email": "i_konovalova-1964@postgrespro.ru", "phone": "+70125514638"}
0005433538971	7D7DE0	1758 706168	LYUDMILA VOLKOVA	{"email": "lvolkova_061971@postgrespro.ru", "phone": "+70096198162"}
0005433538972	F6CC68	0254 503881	ARSEN KRASNOV	{"phone": "+70527450515"}
0005433538973	EBF7E2	4238 443239	IGOR MEDVEDEV	{"email": "igor.medvedev.22071967@postgrespro.ru", "phone": "+70346971507"}
0005433538974	D2F4E8	4735 138151	OLGA ORLOVA	{"email": "o.orlova.1971@postgrespro.ru", "phone": "+70164688229"}
0005433538975	7AF4FD	0958 935815	VALENTINA KULIKOVA	{"phone": "+70510910952"}
0005433538976	5E46F3	9159 552557	ANTONINA TARASOVA	{"email": "atarasova.25031967@postgrespro.ru", "phone": "+70324277821"}
0005433538977	5E46F3	3532 051534	MIKHAIL GUSEV	{"email": "m-gusev031966@postgrespro.ru", "phone": "+70685422071"}
0005433538978	26A328	8463 059645	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-06041961@postgrespro.ru", "phone": "+70143184580"}
0005433538979	80B4CA	6974 321316	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova021977@postgrespro.ru", "phone": "+70030478479"}
0005433538980	561468	5977 799694	VASILIY ALEKSEEV	{"phone": "+70921091408"}
0005433538981	561468	7856 594689	OLGA EGOROVA	{"email": "olgaegorova20041976@postgrespro.ru", "phone": "+70102445355"}
0005433538982	82C602	5447 877709	MIKHAIL MEDVEDEV	{"email": "medvedev_m051972@postgrespro.ru", "phone": "+70262786656"}
0005433538983	C5CB5F	6167 604873	ALEKSANDR DAVYDOV	{"phone": "+70810283998"}
0005433538984	35BFFB	5557 846237	LYUDMILA KOLESNIKOVA	{"phone": "+70193296252"}
0005433538985	94939A	7978 234787	DARYA IVANOVA	{"phone": "+70583336010"}
0005433538986	94939A	0536 551874	ANATOLIY FEDOTOV	{"phone": "+70932155324"}
0005433538987	C39031	9801 578243	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr041970@postgrespro.ru", "phone": "+70021224170"}
0005433538988	35BEE8	6718 733482	SERGEY GUSEV	{"email": "gusev-s.27121969@postgrespro.ru", "phone": "+70704458543"}
0005433538989	4BFD04	1655 480927	SVETLANA SOROKINA	{"phone": "+70516713801"}
0005433538990	4BFD04	5087 179161	TATYANA FEDOROVA	{"email": "tatyana_fedorova_1976@postgrespro.ru", "phone": "+70578536059"}
0005433538991	E6BF36	6161 261807	EKATERINA RYABOVA	{"email": "ryabova-ekaterina-02081967@postgrespro.ru", "phone": "+70875368600"}
0005433538992	FFAAEF	6573 964210	VIKTOR EGOROV	{"email": "v.egorov1961@postgrespro.ru", "phone": "+70450907749"}
0005433538993	715729	1725 216009	ROMAN FROLOV	{"phone": "+70590580992"}
0005433538994	F93EE9	6072 167311	VERA KOZLOVA	{"email": "vera_kozlova-1964@postgrespro.ru", "phone": "+70346149754"}
0005433538995	4F8610	1774 088601	IRINA NIKIFOROVA	{"email": "inikiforova12091974@postgrespro.ru", "phone": "+70544285076"}
0005433538996	D39E00	3011 719568	TAISIYA ROMANOVA	{"phone": "+70114356434"}
0005433539110	417E96	4591 566109	ANDREY FROLOV	{"phone": "+70886287372"}
0005433538997	D39E00	6607 148167	IRINA BARANOVA	{"email": "baranovai1978@postgrespro.ru", "phone": "+70811497389"}
0005433538998	81E2D8	0613 693751	ANNA NIKITINA	{"email": "anna_nikitina_1975@postgrespro.ru", "phone": "+70365086867"}
0005433538999	81E2D8	2885 515663	SERGEY SHEVCHENKO	{"phone": "+70856723129"}
0005433539000	85A279	6766 455414	TAMARA GRISHINA	{"email": "grishina-t_10071970@postgrespro.ru", "phone": "+70787513082"}
0005433539001	85A279	3051 933907	POLINA ILINA	{"email": "polina-ilina_1968@postgrespro.ru", "phone": "+70798028223"}
0005433539002	E58EF6	7144 465213	VLADIMIR KONOVALOV	{"phone": "+70344656873"}
0005433539003	32BA4C	0477 688764	EKATERINA PETROVA	{"email": "petrovae111973@postgrespro.ru", "phone": "+70248082780"}
0005433539004	32BA4C	5483 669021	ARTUR KARPOV	{"phone": "+70076994219"}
0005433539005	D3ED3A	7584 036783	VIKTOR CHERNOV	{"phone": "+70607530120"}
0005433539006	8148BC	9627 197276	SVETLANA IVANOVA	{"email": "svetlana.ivanova.111975@postgrespro.ru", "phone": "+70665579494"}
0005433539007	8148BC	6986 812007	SVETLANA KUZNECOVA	{"phone": "+70774482790"}
0005433539008	92E0B0	0235 610677	MARAT SCHERBAKOV	{"email": "m_scherbakov-041972@postgrespro.ru", "phone": "+70416234772"}
0005433539009	B7DD18	3519 708918	GALINA MAKAROVA	{"email": "g-makarova_13031971@postgrespro.ru", "phone": "+70537949328"}
0005433539010	8CF1B6	0380 472447	YULIYA KAZAKOVA	{"phone": "+70448019424"}
0005433539011	8CF1B6	5324 898951	ANTON ORLOV	{"phone": "+70574210716"}
0005433539012	EB34DC	6308 266188	VLADIMIR SHEVCHENKO	{"phone": "+70320665523"}
0005433539013	EB34DC	2365 504458	OLGA ANDREEVA	{"email": "o.andreeva.13111977@postgrespro.ru", "phone": "+70098589619"}
0005433539014	7A076F	4873 544227	GENNADIY VOLKOV	{"phone": "+70390535133"}
0005433539015	7A076F	4173 838664	DMITRIY RODIONOV	{"email": "dmitriy-rodionov-27051974@postgrespro.ru", "phone": "+70540176471"}
0005433539016	C50864	1332 940134	LEV VASILEV	{"phone": "+70982100851"}
0005433539017	120023	0569 508237	MARINA MAKAROVA	{"phone": "+70868874437"}
0005433539018	120023	8261 052479	ANDREY PETROV	{"phone": "+70357578824"}
0005433539019	76A08F	5835 236768	KSENIYA KONOVALOVA	{"phone": "+70101613300"}
0005433539020	848B1C	8582 802720	LIDIYA SAVELEVA	{"phone": "+70303779072"}
0005433539021	BEF439	7264 047234	NATALYA NIKITINA	{"phone": "+70876371275"}
0005433539022	BEF439	0298 731161	OKSANA KONDRATEVA	{"phone": "+70643419279"}
0005433539023	CC889B	2544 016875	OLGA ILINA	{"phone": "+70477273847"}
0005433539024	5D385A	0488 989014	DARYA TROFIMOVA	{"phone": "+70099740206"}
0005433539025	5D385A	6505 524050	NATALYA MATVEEVA	{"phone": "+70494162720"}
0005433539026	720229	6396 001428	ANNA PETROVA	{"email": "annapetrova07071973@postgrespro.ru", "phone": "+70740133996"}
0005433539027	720229	3358 192422	SERGEY SERGEEV	{"email": "s-sergeev-1976@postgrespro.ru", "phone": "+70883078043"}
0005433539028	6C42CB	9431 851720	PAVEL KUZNECOV	{"phone": "+70829209915"}
0005433539029	6C42CB	3854 581472	OLEG MATVEEV	{"phone": "+70761371745"}
0005433539030	AAD467	9407 775189	GRIGORIY SOLOVEV	{"email": "grigoriy-solovev1974@postgrespro.ru", "phone": "+70504068763"}
0005433539031	9F9863	8790 443153	KSENIYA BELOVA	{"email": "belova-k.29041980@postgrespro.ru", "phone": "+70261208538"}
0005433539032	CC7C88	8669 529791	OLESYA BELYAEVA	{"email": "o_belyaeva-1962@postgrespro.ru", "phone": "+70750528935"}
0005433539033	EF9055	8231 754872	SERGEY DAVYDOV	{"phone": "+70867035119"}
0005433539034	2DBA11	7475 319918	MIKHAIL KOROLEV	{"phone": "+70975044815"}
0005433539035	E4CEF5	1906 123564	ALEKSEY NIKITIN	{"email": "a-nikitin1970@postgrespro.ru", "phone": "+70851565617"}
0005433539036	0920D5	4112 506216	IRINA IVANOVA	{"phone": "+70343642752"}
0005433539037	0920D5	7994 334357	EVGENIY ORLOV	{"email": "orlov.e1972@postgrespro.ru", "phone": "+70732018372"}
0005433539038	FFD371	4216 896664	PETR SEMENOV	{"phone": "+70912837749"}
0005433539039	BE5B39	7560 486676	LILIYA KARPOVA	{"phone": "+70397805184"}
0005433539040	BE5B39	2096 652206	RAIS VOROBEV	{"email": "vorobev_r-031978@postgrespro.ru", "phone": "+70372009705"}
0005433539041	27C9DA	0165 651403	SERGEY MOROZOV	{"phone": "+70515927393"}
0005433539042	27C9DA	8177 853736	TATYANA BELOVA	{"phone": "+70009542435"}
0005433539043	60B6AF	4624 908338	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev-041976@postgrespro.ru", "phone": "+70315874444"}
0005433539044	3BBCF6	3018 242829	IRINA ABRAMOVA	{"email": "abramova_i21101976@postgrespro.ru", "phone": "+70675476587"}
0005433539045	5854CD	7982 686100	TATYANA SEMENOVA	{"phone": "+70102020384"}
0005433539046	5854CD	7451 943588	NIKOLAY VOLKOV	{"email": "volkov_n.1971@postgrespro.ru", "phone": "+70391259721"}
0005433539047	5FFE01	5978 790173	OLGA FEDOROVA	{"phone": "+70988336131"}
0005433539048	5FFE01	6574 652610	ALEKSANDR MAKAROV	{"phone": "+70586249036"}
0005433539049	D2FEEA	7074 751865	NATALYA NAZAROVA	{"phone": "+70073450780"}
0005433539050	D2FEEA	7853 841783	LYUBOV IVANOVA	{"email": "lyubov_ivanova071975@postgrespro.ru", "phone": "+70252964172"}
0005433539051	2C11EE	1973 070737	YULIYA GORBUNOVA	{"email": "yuliya-gorbunova081979@postgrespro.ru", "phone": "+70547713342"}
0005433539052	873C1F	5775 881288	ALEKSANDR ANDREEV	{"email": "andreev.a.07031979@postgrespro.ru", "phone": "+70967603946"}
0005433539053	88F5AA	8123 229240	EVGENIY SOLOVEV	{"email": "evgeniysolovev.06041965@postgrespro.ru", "phone": "+70030948429"}
0005433539054	88F5AA	9898 586776	ELENA KARPOVA	{"email": "karpova_elena_081976@postgrespro.ru", "phone": "+70008807064"}
0005433539055	88F5AA	3165 095113	VIKTORIYA DANILOVA	{"email": "danilova.viktoriya.1952@postgrespro.ru", "phone": "+70282380359"}
0005433539056	CAF629	4733 496083	VERA SOROKINA	{"phone": "+70503124970"}
0005433539057	1D2943	3864 646138	ALEKSEY VOLKOV	{"email": "a.volkov.23051972@postgrespro.ru", "phone": "+70402978741"}
0005433539058	B39367	5082 081060	MIKHAIL ZAKHAROV	{"email": "zakharov.m1972@postgrespro.ru", "phone": "+70804781339"}
0005433539059	F41BEE	8033 456982	NATALYA TARASOVA	{"phone": "+70072158017"}
0005433539060	D3299A	3965 596523	DANIL IVANOV	{"phone": "+70812586791"}
0005433539061	D3299A	0691 060417	VALENTINA DAVYDOVA	{"phone": "+70968381624"}
0005433539062	14E355	0807 530430	EKATERINA VASILEVA	{"phone": "+70725762008"}
0005433539063	8D22A3	7137 545571	KONSTANTIN CHERNOV	{"phone": "+70148527198"}
0005433539064	8D22A3	2490 118308	VERA AKIMOVA	{"email": "vera.akimova.011973@postgrespro.ru", "phone": "+70067015545"}
0005433539065	49D4BE	5505 288582	SABINA DMITRIEVA	{"email": "dmitrieva.s.25101970@postgrespro.ru", "phone": "+70749056395"}
0005433539066	98B71D	1292 114078	ZOYA KOMAROVA	{"phone": "+70193518679"}
0005433539067	52ECA4	9235 869369	VLADIMIR FOMIN	{"email": "fominv_15091975@postgrespro.ru", "phone": "+70962640240"}
0005433539068	52ECA4	7337 723989	VLADIMIR FROLOV	{"email": "frolovvladimir-061971@postgrespro.ru", "phone": "+70712878443"}
0005433539069	B81AAE	6953 249006	VERA KRASNOVA	{"phone": "+70322661282"}
0005433539070	8775FC	7312 648130	LYUBOV ZOTOVA	{"phone": "+70889580555"}
0005433539071	D837B3	9384 115914	ALLA FADEEVA	{"email": "allafadeeva-1970@postgrespro.ru", "phone": "+70521814376"}
0005433539072	C937E7	0818 233432	KLAVDIYA NOVIKOVA	{"email": "klavdiyanovikova-1972@postgrespro.ru", "phone": "+70176398349"}
0005433539073	693816	0517 870630	LYUDMILA NAUMOVA	{"email": "l.naumova18061981@postgrespro.ru", "phone": "+70399327568"}
0005433539074	7FF722	0972 280748	YANA LUKYANOVA	{"email": "yanalukyanova-23091972@postgrespro.ru", "phone": "+70362130256"}
0005433539075	FED29F	6065 765654	NADEZHDA TARASOVA	{"email": "nadezhda-tarasova-1972@postgrespro.ru", "phone": "+70113682650"}
0005433539076	57593E	9810 605552	ANNA BORISOVA	{"email": "borisova.anna31071956@postgrespro.ru", "phone": "+70626173815"}
0005433539077	A667CA	7837 586325	YANA KAZAKOVA	{"email": "ykazakova021974@postgrespro.ru", "phone": "+70972182033"}
0005433539078	8766A9	2801 850042	ELIZAVETA STEPANOVA	{"phone": "+70868020403"}
0005433539079	9432F6	8609 598850	SVETLANA VASILEVA	{"email": "vasileva.svetlana19091977@postgrespro.ru", "phone": "+70125570723"}
0005433539080	9432F6	4881 825842	VYACHESLAV TIKHONOV	{"email": "vyacheslav_tikhonov-1968@postgrespro.ru", "phone": "+70650507478"}
0005433539081	9432F6	4042 677079	EVGENIY VASILEV	{"email": "vasilev.e.15031971@postgrespro.ru", "phone": "+70816732718"}
0005433539082	C052A2	1376 430359	SERGEY BARANOV	{"email": "baranov.sergey_1962@postgrespro.ru", "phone": "+70945004426"}
0005433539083	C052A2	0375 403592	EKATERINA KOROLEVA	{"phone": "+70993207924"}
0005433539084	BF784B	0195 276195	TATYANA NESTEROVA	{"email": "nesterovat_11081976@postgrespro.ru", "phone": "+70185619097"}
0005433539085	BD29F8	9381 343134	ANNA KRASNOVA	{"phone": "+70976802891"}
0005433539086	BD29F8	8507 944360	DARYA ROMANOVA	{"phone": "+70542081631"}
0005433539087	81B34C	4126 598231	OKSANA MELNIKOVA	{"email": "melnikova_o1978@postgrespro.ru", "phone": "+70821738475"}
0005433539088	D72B43	1672 151561	MARIYA PETROVA	{"phone": "+70466608739"}
0005433539089	27C13C	0755 695592	LYUDMILA ERMAKOVA	{"email": "lyudmila.ermakova-12031974@postgrespro.ru", "phone": "+70282839574"}
0005433539090	B2A377	6996 694195	DMITRIY MOISEEV	{"phone": "+70615024242"}
0005433539091	7AFD14	3092 100688	VLADIMIR KRASNOV	{"email": "vladimir.krasnov_25031980@postgrespro.ru", "phone": "+70941528334"}
0005433539092	7AFD14	4450 594920	NIKITA ZHUKOV	{"phone": "+70715927643"}
0005433539093	7AFD14	0581 520617	ILYA POPOV	{"email": "i_popov-16021979@postgrespro.ru", "phone": "+70778029579"}
0005433539094	B705DF	4828 639654	IVAN YAKOVLEV	{"phone": "+70039291348"}
0005433539095	59D63D	1618 624751	RAVIL KUZNECOV	{"phone": "+70925315370"}
0005433539096	A6ACE4	3943 840872	EGOR KUZNECOV	{"email": "ekuznecov_05021968@postgrespro.ru", "phone": "+70104879321"}
0005433539097	45A6E1	7168 910454	VLADIMIR SMIRNOV	{"phone": "+70954881082"}
0005433539098	47EB58	2596 367474	TATYANA KUDRYASHOVA	{"email": "t_kudryashova_121975@postgrespro.ru", "phone": "+70445000340"}
0005433539099	47EB58	7727 204144	IVAN KUZMIN	{"phone": "+70600452373"}
0005433539100	47EB58	1440 744749	ZINAIDA OVCHINNIKOVA	{"phone": "+70704164595"}
0005433539101	D1E76C	3164 945507	EVGENIY NOVIKOV	{"email": "novikov-e.1978@postgrespro.ru", "phone": "+70492882579"}
0005433539102	F0A9F9	3632 731601	TATYANA LAZAREVA	{"phone": "+70652341276"}
0005433539103	E97E74	5550 985457	OLGA MASLOVA	{"phone": "+70694274586"}
0005433539104	2DF2F9	4386 769922	VLADISLAV MELNIKOV	{"phone": "+70472601951"}
0005433539105	EF8ED0	6601 510922	YULIYA POPOVA	{"phone": "+70577410976"}
0005433539106	1C0650	4968 302937	ALEKSEY KARPOV	{"email": "karpovaleksey.061967@postgrespro.ru", "phone": "+70743895562"}
0005433539107	1C0650	5409 965233	NINA ISAEVA	{"email": "isaeva.nina-24101968@postgrespro.ru", "phone": "+70626474493"}
0005433539108	1C0650	7474 809002	TATYANA KOROLEVA	{"email": "koroleva.t.16041973@postgrespro.ru", "phone": "+70317247843"}
0005433539109	8AD462	8619 168924	SERGEY DMITRIEV	{"email": "dmitriev.s091970@postgrespro.ru", "phone": "+70638448824"}
0005433539111	417E96	2651 528568	VERA ILINA	{"phone": "+70139717520"}
0005433539112	5F2588	0393 447300	ALEKSEY TARASOV	{"phone": "+70986198104"}
0005433539113	5F2588	4250 182443	NATALYA SEMENOVA	{"phone": "+70727018298"}
0005433539114	DC0D8A	7217 252156	IVAN NIKOLAEV	{"phone": "+70985513754"}
0005433539115	DC0D8A	7033 892054	ZOYA FADEEVA	{"email": "zoyafadeeva_19121972@postgrespro.ru", "phone": "+70850909485"}
0005433539116	39B094	6463 274566	TATYANA BARANOVA	{"phone": "+70731074460"}
0005433539117	FBEE1B	8759 624465	VALERIYA YAKOVLEVA	{"email": "yakovleva-v.021972@postgrespro.ru", "phone": "+70154452181"}
0005433539118	FBEE1B	1726 544326	ELENA TIMOFEEVA	{"phone": "+70074833162"}
0005433539119	66E4BB	8136 164381	RASHIT NOVIKOV	{"phone": "+70094150219"}
0005433539120	66E4BB	4199 162692	NIKITA KUZNECOV	{"phone": "+70521627035"}
0005433539121	B5F5B4	7533 014914	DANIIL ABRAMOV	{"phone": "+70841839419"}
0005433539122	B5F5B4	8209 371453	NATALYA TIKHONOVA	{"email": "tikhonovanatalya-091969@postgrespro.ru", "phone": "+70558715810"}
0005433539123	90ACB7	3586 577175	SVETLANA KONDRATEVA	{"email": "kondrateva-svetlana_28101980@postgrespro.ru", "phone": "+70895063317"}
0005433539124	5FB22E	2485 048477	EVGENIY DAVYDOV	{"phone": "+70220870042"}
0005433568015	84FD81	5995 172390	YURIY KAZAKOV	{"phone": "+70153366196"}
0005433568016	84FD81	1694 269917	MARIYA ANDREEVA	{"phone": "+70457754652"}
0005433568017	AF1C86	9337 805270	ILYA VOLKOV	{"email": "i_volkov_1974@postgrespro.ru", "phone": "+70734141140"}
0005433568018	83AABB	1414 321828	ANDREY TIMOFEEV	{"phone": "+70283717487"}
0005433568019	83AABB	9904 971307	ZINAIDA SEMENOVA	{"email": "semenova.zinaida111981@postgrespro.ru", "phone": "+70258410624"}
0005433568020	69EF19	6818 724353	VIKTOR ZHURAVLEV	{"email": "zhuravlevviktor_23081972@postgrespro.ru", "phone": "+70683158520"}
0005433568021	778D29	7392 640790	VLADIMIR POPOV	{"phone": "+70659936232"}
0005433568022	D304D1	7758 507867	ALEKSEY ABRAMOV	{"email": "abramov_a27061963@postgrespro.ru", "phone": "+70935697702"}
0005433568023	AAED5A	3440 269727	ANDREY NIKITIN	{"phone": "+70374139785"}
0005433568024	1E1691	0316 020011	VYACHESLAV ILIN	{"email": "v_ilin121965@postgrespro.ru", "phone": "+70751725776"}
0005433568025	1E1691	9654 556914	VALENTINA RYABOVA	{"email": "v.ryabova_071966@postgrespro.ru", "phone": "+70915170417"}
0005433568026	1E1691	7273 566641	ALEKSANDRA SIDOROVA	{"phone": "+70530123329"}
0005433568027	252886	9841 965638	EVGENIY GAVRILOV	{"email": "e_gavrilov.1983@postgrespro.ru", "phone": "+70918047572"}
0005433568028	CE494A	8904 222790	ANASTASIYA FEDOROVA	{"email": "fedorovaa.10071972@postgrespro.ru", "phone": "+70666116078"}
0005433568029	CE494A	6010 814095	EKATERINA FEDOROVA	{"phone": "+70094649391"}
0005433568030	8F5B12	7025 246157	VENIAMIN MAKSIMOV	{"phone": "+70614494105"}
0005433568031	8F5B12	9746 072605	NINA NIKIFOROVA	{"phone": "+70291739601"}
0005433568032	631FC8	9339 211390	IVAN BONDARENKO	{"email": "ivan-bondarenko.011972@postgrespro.ru", "phone": "+70240170599"}
0005433568033	DA2085	8012 796836	PETR FILIPPOV	{"phone": "+70754897878"}
0005433568034	F4C573	2269 655953	PETR PAVLOV	{"email": "p_pavlov.031967@postgrespro.ru", "phone": "+70539326462"}
0005433568035	E84C34	5576 306349	VIKTOR OSIPOV	{"email": "osipov_viktor.1967@postgrespro.ru", "phone": "+70961416163"}
0005433568036	E84C34	1689 943268	ALEKSANDR SIDOROV	{"phone": "+70761510527"}
0005433568037	C0B41B	9998 972303	YULIYA DAVYDOVA	{"email": "davydova_yuliya_111968@postgrespro.ru", "phone": "+70563139590"}
0005433568038	5E1210	1804 918191	NATALYA BARANOVA	{"email": "baranova_n-17011978@postgrespro.ru", "phone": "+70088896274"}
0005433568214	CFE41C	0782 497487	DINARA ANDREEVA	{"phone": "+70283223366"}
0005433568039	D53FAA	3094 438214	EVGENIY IVANOV	{"email": "ivanov_evgeniy.071966@postgrespro.ru", "phone": "+70431122681"}
0005433568040	42AD3C	5353 740412	MARIYA MIKHAYLOVA	{"email": "mikhaylova-mariya1979@postgrespro.ru", "phone": "+70566827053"}
0005433568041	972238	3340 222186	SERGEY AFANASEV	{"email": "sergeyafanasev1982@postgrespro.ru", "phone": "+70913089236"}
0005433568042	FC3A07	5051 037222	VYACHESLAV ZAKHAROV	{"phone": "+70508634278"}
0005433568043	08EF23	3738 250837	YULIYA BORISOVA	{"phone": "+70333016630"}
0005433568044	08EF23	1972 555138	ELENA VOROBEVA	{"email": "vorobevaelena-111968@postgrespro.ru", "phone": "+70223483505"}
0005433568045	36B0D9	9658 310452	ALEKSANDR ROMANOV	{"email": "romanovaleksandr11081966@postgrespro.ru", "phone": "+70270405152"}
0005433568046	36B0D9	9135 641434	YULIYA MELNIKOVA	{"email": "ymelnikova-07021966@postgrespro.ru", "phone": "+70446143559"}
0005433568047	F3EADF	3062 953864	POLINA ZHUKOVA	{"email": "polina_zhukova-101977@postgrespro.ru", "phone": "+70984190063"}
0005433568048	466B7E	3751 774108	MARINA ANDREEVA	{"phone": "+70867713006"}
0005433568049	160869	3025 512914	ANTONINA IVANOVA	{"email": "ivanova-a1979@postgrespro.ru", "phone": "+70106934860"}
0005433568050	FAD7A7	4563 029671	LYUBOV EFIMOVA	{"email": "lyubov.efimova_061975@postgrespro.ru", "phone": "+70736303112"}
0005433568051	14FE74	9972 886439	SVETLANA DAVYDOVA	{"phone": "+70040073077"}
0005433568052	5F51A7	4949 143265	TATYANA KUDRYASHOVA	{"email": "kudryashovatatyana_24011974@postgrespro.ru", "phone": "+70060275782"}
0005433568053	BB52C0	3326 899354	LYUBOV KUZNECOVA	{"email": "lkuznecova-07051975@postgrespro.ru", "phone": "+70540796878"}
0005433568054	C59A5C	2927 605886	SERGEY ABRAMOV	{"email": "abramov_sergey_11041981@postgrespro.ru", "phone": "+70118790390"}
0005433568055	C59A5C	2931 738531	ANDREY DMITRIEV	{"email": "andreydmitriev021977@postgrespro.ru", "phone": "+70959106433"}
0005433568056	2119F7	7663 616341	EGOR KOROLEV	{"phone": "+70594118845"}
0005433568057	E47183	5246 715596	LIDIYA NIKITINA	{"email": "lidiya-nikitina.121971@postgrespro.ru", "phone": "+70849365450"}
0005433568058	65E767	5721 551155	ALEKSEY ZAYCEV	{"phone": "+70835484076"}
0005433568059	65E767	9997 859052	EKATERINA ANDREEVA	{"email": "ekaterina-andreeva1963@postgrespro.ru", "phone": "+70549963810"}
0005433568060	1BFC68	7819 432203	EVGENIYA ABRAMOVA	{"email": "evgeniya_abramova20021961@postgrespro.ru", "phone": "+70493367998"}
0005433568061	BC46A0	7317 412291	VALENTINA VASILEVA	{"email": "vasileva-v_091958@postgrespro.ru", "phone": "+70107260168"}
0005433568062	41D233	8593 967457	TIMUR YAKOVLEV	{"email": "yakovlevt.06011972@postgrespro.ru", "phone": "+70938367656"}
0005433568063	C01A02	2524 766853	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr03121969@postgrespro.ru", "phone": "+70367253245"}
0005433568064	B7F241	1454 299990	OLGA KOVALEVA	{"phone": "+70353745660"}
0005433568065	5DCA09	2142 008771	EKATERINA PAVLOVA	{"phone": "+70283486103"}
0005433568066	96E4CF	1099 758276	MAKSIM ISAEV	{"email": "m-isaev_031988@postgrespro.ru", "phone": "+70834463136"}
0005433568067	D1FF7F	5655 278998	SERGEY KAZAKOV	{"email": "kazakov_s.101964@postgrespro.ru", "phone": "+70986271227"}
0005433568068	C625BC	4090 018611	ANDREY IVANOV	{"email": "andrey-ivanov.1971@postgrespro.ru", "phone": "+70904298364"}
0005433568069	1E4F6C	3405 911960	MARIYA ARKHIPOVA	{"phone": "+70771679176"}
0005433568070	2C8E7B	0767 786954	NINA DAVYDOVA	{"phone": "+70822114888"}
0005433568071	2C8E7B	7868 828271	SVETLANA BARANOVA	{"phone": "+70635010394"}
0005433568072	2C8E7B	8473 227475	VITALIY SMIRNOV	{"phone": "+70880074911"}
0005433568073	2C8E7B	8160 873661	GALINA SOKOLOVA	{"phone": "+70794683481"}
0005433568074	7062CF	5363 329036	IRINA BORISOVA	{"phone": "+70574388253"}
0005433568075	01AFD0	2689 678652	VYACHESLAV SOLOVEV	{"email": "solovevvyacheslav_1980@postgrespro.ru", "phone": "+70751402597"}
0005433568076	C67498	8312 119930	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr.121967@postgrespro.ru", "phone": "+70043903124"}
0005433568077	4E7F76	1221 489799	VALENTINA IVANOVA	{"email": "ivanovav1965@postgrespro.ru", "phone": "+70225126923"}
0005433568078	8A871E	9215 300686	NIKOLAY ZAYCEV	{"email": "zaycev-n_22011980@postgrespro.ru", "phone": "+70466866301"}
0005433568079	8A871E	4173 904317	MARIYA POPOVA	{"phone": "+70717085881"}
0005433568080	8A871E	7082 433894	RAISA MALYSHEVA	{"phone": "+70909128367"}
0005433568081	AA4BA9	7642 438529	NIKITA KULIKOV	{"phone": "+70527038187"}
0005433568082	3EC6FA	3381 282692	IVAN FROLOV	{"phone": "+70861243130"}
0005433568083	96D0F6	3870 083983	ROMAN KUZNECOV	{"email": "kuznecov-roman.121965@postgrespro.ru", "phone": "+70708933709"}
0005433568084	8744DC	4483 401125	IVAN SOLOVEV	{"email": "solovev-i.011962@postgrespro.ru", "phone": "+70773623666"}
0005433568085	0D0104	7983 869960	ALEKSANDR POPOV	{"email": "popov_a_061973@postgrespro.ru", "phone": "+70485901587"}
0005433568086	815114	5565 985576	MIKHAIL SAVELEV	{"email": "mikhail.savelev081975@postgrespro.ru", "phone": "+70532310135"}
0005433568087	204BAC	8729 582869	VALERIY GORBUNOV	{"email": "gorbunov.v.011983@postgrespro.ru", "phone": "+70788634054"}
0005433568088	23C99C	4096 766169	ANNA NESTEROVA	{"email": "nesterova-a.15011979@postgrespro.ru", "phone": "+70200572414"}
0005433568089	23C99C	0075 241238	VIKTOR YAKOVLEV	{"email": "yakovlev_v_01071974@postgrespro.ru", "phone": "+70503952694"}
0005433568090	1947E4	9138 227062	OLGA NAUMOVA	{"email": "naumova_olga17121959@postgrespro.ru", "phone": "+70182381543"}
0005433568091	C90928	4665 661296	MARIYA MALYSHEVA	{"phone": "+70651095533"}
0005433568092	C90928	1990 671764	OLEG KONOVALOV	{"email": "konovalov.oleg-1978@postgrespro.ru", "phone": "+70549893030"}
0005433568093	75B5DB	5832 729187	ZAKHAR TIMOFEEV	{"phone": "+70509863548"}
0005433568094	4A13F0	3825 986194	EGOR MOISEEV	{"email": "e.moiseev_05101977@postgrespro.ru", "phone": "+70045301345"}
0005433568095	4A13F0	1747 053034	VALENTINA ILINA	{"email": "v-ilina_1970@postgrespro.ru", "phone": "+70140685468"}
0005433568273	ED140A	3295 658885	KONSTANTIN NIKITIN	{"phone": "+70647915899"}
0005433568096	25B485	0982 092055	VALERIY SERGEEV	{"email": "sergeev_v.18031971@postgrespro.ru", "phone": "+70704180480"}
0005433568097	25B485	3047 392218	ILYA VOROBEV	{"email": "ilya-vorobev.15101960@postgrespro.ru", "phone": "+70213384457"}
0005433568098	25B485	9462 506679	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev.091980@postgrespro.ru", "phone": "+70406017517"}
0005433568099	7662F7	9587 345799	VLADIMIR FEDOROV	{"email": "fedorov.vladimir-12101963@postgrespro.ru", "phone": "+70049928292"}
0005433568100	D86E92	0157 867658	ANTONINA KAZAKOVA	{"phone": "+70926286264"}
0005433568101	F835D5	9274 716101	KONSTANTIN SOROKIN	{"email": "sorokin.k-17021977@postgrespro.ru", "phone": "+70911466979"}
0005433568102	E21E4A	6731 479061	PAVEL MEDVEDEV	{"phone": "+70086659176"}
0005433568103	3DAD5B	9515 990122	IRINA NIKOLAEVA	{"email": "nikolaeva_i.01031969@postgrespro.ru", "phone": "+70482598561"}
0005433568104	3DAD5B	6528 163416	VIKTOR IVANOV	{"email": "ivanovv.021970@postgrespro.ru", "phone": "+70681870769"}
0005433568105	3B1481	7054 225988	EKATERINA ALEKSEEVA	{"email": "alekseeva_e1974@postgrespro.ru", "phone": "+70306687800"}
0005433568106	3B1481	6040 123781	LYUDMILA KAZAKOVA	{"email": "kazakova_lyudmila06051965@postgrespro.ru", "phone": "+70472304481"}
0005433568107	533F85	6694 675047	MARGARITA TROFIMOVA	{"phone": "+70964164641"}
0005433568108	AD3C5C	9573 487925	NADEZHDA ARKHIPOVA	{"email": "arkhipova.n_1976@postgrespro.ru", "phone": "+70993732376"}
0005433568109	997C53	4235 015823	VIKTOR KUZNECOV	{"email": "viktor_kuznecov-14041959@postgrespro.ru", "phone": "+70652911523"}
0005433568110	997C53	1178 080159	NATALYA MOROZOVA	{"phone": "+70127885272"}
0005433568111	FC62B9	2320 009157	LIDIYA FROLOVA	{"email": "froloval25051977@postgrespro.ru", "phone": "+70082643990"}
0005433568112	2311EA	9880 014217	ANDREY SAVELEV	{"phone": "+70266407696"}
0005433568113	2311EA	3562 731120	RUSTAM ISAEV	{"email": "isaevrustam07021973@postgrespro.ru", "phone": "+70292882855"}
0005433568114	55325B	5025 069050	SVETLANA ANDREEVA	{"phone": "+70116409636"}
0005433568115	1D8104	4849 468544	ALEKSEY KAZAKOV	{"email": "aleksey-kazakov-16041973@postgrespro.ru", "phone": "+70624632254"}
0005433568116	1D8104	2584 407797	TAMARA KAZAKOVA	{"email": "kazakova.t071978@postgrespro.ru", "phone": "+70140696852"}
0005433568117	4AB502	6077 890284	PAVEL SHEVCHENKO	{"email": "p.shevchenko_041964@postgrespro.ru", "phone": "+70377717290"}
0005433568118	4967F6	7439 248122	TATYANA FOMINA	{"email": "fomina-t26101965@postgrespro.ru", "phone": "+70452087502"}
0005433568119	4967F6	8579 594989	ALEKSANDR BARANOV	{"email": "abaranov18081966@postgrespro.ru", "phone": "+70982662431"}
0005433568120	E7D729	4133 111794	LYUBOV MOISEEVA	{"phone": "+70368001169"}
0005433568121	E7D729	0470 910853	ANATOLIY GAVRILOV	{"email": "a-gavrilov_011969@postgrespro.ru", "phone": "+70063835801"}
0005433568122	7C2C8A	2500 336102	LYUDMILA IVANOVA	{"email": "lyudmilaivanova-1979@postgrespro.ru", "phone": "+70305066326"}
0005433568123	7C2C8A	2992 116718	EKATERINA KULIKOVA	{"email": "kulikova-ekaterina22021975@postgrespro.ru", "phone": "+70576255418"}
0005433568124	4C40C7	5994 372318	KIRILL PETROV	{"phone": "+70725922919"}
0005433568125	4C40C7	9887 187843	DMITRIY SOROKIN	{"email": "dsorokin1978@postgrespro.ru", "phone": "+70880582141"}
0005433568126	C42603	2959 931297	ALEKSEY ANDREEV	{"email": "a.andreev1975@postgrespro.ru", "phone": "+70055724558"}
0005433568127	AAEDC4	8772 583724	VALENTINA NIKOLAEVA	{"email": "v_nikolaeva-061980@postgrespro.ru", "phone": "+70596250680"}
0005433568128	AAEDC4	6538 176864	ALENA EFIMOVA	{"phone": "+70882088848"}
0005433568129	AAEDC4	3653 915489	NIKOLAY KOROLEV	{"email": "nikolay.korolev_26121968@postgrespro.ru", "phone": "+70814290910"}
0005433568130	A07E7A	4897 874935	KSENIYA BELYAEVA	{"email": "belyaevakseniya.09041981@postgrespro.ru", "phone": "+70736335137"}
0005433568131	A07E7A	6844 825577	ELENA SCHERBAKOVA	{"phone": "+70467443011"}
0005433568132	6BA690	5608 332225	GALINA OVCHINNIKOVA	{"phone": "+70262433511"}
0005433568133	640322	6935 830106	POLINA KUZNECOVA	{"email": "pkuznecova081975@postgrespro.ru", "phone": "+70837147618"}
0005433568134	9B1B09	2230 461618	YURIY KISELEV	{"email": "kiselev_y.1976@postgrespro.ru", "phone": "+70293182319"}
0005433568135	C81A08	3479 307541	RINAT SIDOROV	{"email": "sidorov_rinat_1965@postgrespro.ru", "phone": "+70367524150"}
0005433568136	A1D187	5817 365412	ELENA POLYAKOVA	{"email": "elena.polyakova1967@postgrespro.ru", "phone": "+70401298855"}
0005433568137	9C2639	2983 735916	MIKHAIL ALEKSEEV	{"phone": "+70388101045"}
0005433568138	1F1CF8	0716 663151	ALEKSANDR VOROBEV	{"phone": "+70576767529"}
0005433568139	8799C8	0027 417852	VLADIMIR DENISOV	{"phone": "+70130813034"}
0005433568140	153A4C	4595 778793	MATVEY STEPANOV	{"phone": "+70484518152"}
0005433568141	C5D569	1157 548172	ANNA MAKSIMOVA	{"email": "maksimova_anna-26071978@postgrespro.ru", "phone": "+70471054454"}
0005433568142	569E9C	1756 976631	PAVEL IVANOV	{"email": "ivanov.pavel.13091972@postgrespro.ru", "phone": "+70044708307"}
0005433568143	569E9C	4985 246473	ANATOLIY DMITRIEV	{"email": "anatoliy-dmitriev_1968@postgrespro.ru", "phone": "+70138841868"}
0005433568144	06366B	1286 053333	PAVEL BORISOV	{"email": "borisov.p24051963@postgrespro.ru", "phone": "+70873227984"}
0005433568145	06366B	1157 916935	SVETLANA ZHURAVLEVA	{"phone": "+70418147898"}
0005433568146	06366B	6706 274698	SVETLANA VLASOVA	{"phone": "+70364062970"}
0005433568147	D7EDE6	0841 065655	NINA MOISEEVA	{"phone": "+70301203481"}
0005433568148	10EC98	5568 941271	VASILIY NIKOLAEV	{"email": "nikolaev.v.17051981@postgrespro.ru", "phone": "+70826909700"}
0005433568149	E4F931	4177 312834	VLADIMIR ABRAMOV	{"email": "abramov_v-051976@postgrespro.ru", "phone": "+70300813361"}
0005433568150	F7FA1C	9186 044567	RAIL GRIGOREV	{"email": "rail-grigorev-1981@postgrespro.ru", "phone": "+70488482508"}
0005433568151	A217D4	2349 961669	ZOYA TIMOFEEVA	{"email": "timofeeva-zoya.101976@postgrespro.ru", "phone": "+70544080337"}
0005433568152	3F608D	7319 394123	NATALYA MAKAROVA	{"email": "n.makarova-08111958@postgrespro.ru", "phone": "+70472638995"}
0005433568153	393476	8021 028522	EVGENIY DMITRIEV	{"email": "dmitriev.e101967@postgrespro.ru", "phone": "+70790814250"}
0005433568154	393476	9365 710729	ELIZAVETA STEPANOVA	{"phone": "+70976442710"}
0005433568155	694B0F	5181 660399	ROSTISLAV VOLKOV	{"email": "volkovr21041970@postgrespro.ru", "phone": "+70630940626"}
0005433568156	D14BCB	5378 657696	NATALYA ANTONOVA	{"email": "antonova-n.01021984@postgrespro.ru", "phone": "+70414808447"}
0005433568157	611AFC	8257 592824	NATALYA KOLESNIKOVA	{"phone": "+70453017250"}
0005433568158	737C09	8996 529774	TATYANA LOGINOVA	{"email": "t_loginova_1978@postgrespro.ru", "phone": "+70057757461"}
0005433568159	D97BC9	6624 184584	EKATERINA KOVALEVA	{"email": "kovaleva.e061968@postgrespro.ru", "phone": "+70825530785"}
0005433568160	D97BC9	7017 535521	VITALIY KUZNECOV	{"email": "vitaliykuznecov-06081976@postgrespro.ru", "phone": "+70632849295"}
0005433568161	741E80	0526 096751	OLGA ANTONOVA	{"email": "olga_antonova_021979@postgrespro.ru", "phone": "+70436543532"}
0005433568162	41F199	5252 147360	VYACHESLAV VOROBEV	{"phone": "+70449393648"}
0005433568163	1D2467	6832 586398	YANA STEPANOVA	{"phone": "+70284544605"}
0005433568164	8AE994	0420 258312	VITALIY BONDARENKO	{"email": "bondarenko-vitaliy121981@postgrespro.ru", "phone": "+70776247834"}
0005433568165	AD11D1	1277 097881	NADEZHDA FROLOVA	{"phone": "+70687668037"}
0005433568166	2D06F0	9860 544386	EKATERINA IVANOVA	{"phone": "+70606630604"}
0005433568167	BD4AAE	9053 826513	VLADISLAV SEMENOV	{"phone": "+70558371665"}
0005433568168	052B15	8262 796433	ANTONINA FROLOVA	{"phone": "+70933512535"}
0005433568169	CA04D4	2633 190008	VLADISLAV VOLKOV	{"email": "volkovvladislav.071961@postgrespro.ru", "phone": "+70291565738"}
0005433568170	E4CC46	5876 630856	GEORGIY NOVIKOV	{"email": "georgiy-novikov-1978@postgrespro.ru", "phone": "+70465673170"}
0005433568171	EF2FB8	6745 457003	ELENA YAKOVLEVA	{"phone": "+70192101419"}
0005433568172	01BF27	9337 728916	MARINA LEBEDEVA	{"phone": "+70005113480"}
0005433568173	51F5FC	3882 088186	ALEVTINA EGOROVA	{"phone": "+70943849802"}
0005433568174	51F5FC	5073 067048	GENNADIY MAKSIMOV	{"email": "maksimov_g19041982@postgrespro.ru", "phone": "+70394163420"}
0005433568175	5E0190	0089 400764	ANTON FROLOV	{"email": "frolova-101966@postgrespro.ru", "phone": "+70529078495"}
0005433568176	FDAE67	7654 056936	OLEG NIKOLAEV	{"email": "oleg.nikolaev_1990@postgrespro.ru", "phone": "+70204673697"}
0005433568177	FDAE67	3036 276038	ALEKSEY DMITRIEV	{"email": "a-dmitriev-021985@postgrespro.ru", "phone": "+70262150279"}
0005433568178	485B4A	2062 624032	ALINA MOROZOVA	{"phone": "+70853352277"}
0005433568179	CB33CF	8425 620909	SERGEY NIKITIN	{"email": "nikitin.s.021967@postgrespro.ru", "phone": "+70985030679"}
0005433568180	CB33CF	3585 258505	IVAN KUZNECOV	{"email": "i-kuznecov1965@postgrespro.ru", "phone": "+70147013118"}
0005433568181	5BD676	5706 943520	LYUBOV ABRAMOVA	{"email": "abramova-lyubov1971@postgrespro.ru", "phone": "+70055490037"}
0005433568182	168BBE	8463 995322	OLESYA SEMENOVA	{"phone": "+70116727793"}
0005433568183	168BBE	3879 556798	RINAT PAVLOV	{"email": "pavlov_r011991@postgrespro.ru", "phone": "+70616064426"}
0005433568184	C31773	5414 138870	MATVEY SOLOVEV	{"phone": "+70760083003"}
0005433568185	C31773	7314 474496	ILYA GAVRILOV	{"phone": "+70918937472"}
0005433568186	C31773	3088 661191	ALEKSANDR STEPANOV	{"phone": "+70124371660"}
0005433568187	B2592B	2471 805812	ALEKSEY ZHUKOV	{"email": "a_zhukov_03041989@postgrespro.ru", "phone": "+70682425042"}
0005433568188	00A39B	9614 723151	DMITRIY FEDOTOV	{"phone": "+70071854290"}
0005433568189	836261	1995 256173	IVAN MAKAROV	{"email": "i_makarov_1978@postgrespro.ru", "phone": "+70570864587"}
0005433568190	F2CDE9	2738 853500	ANASTASIYA SEMENOVA	{"email": "semenova_anastasiya.10111978@postgrespro.ru", "phone": "+70860789859"}
0005433568191	F2CDE9	1701 745739	ANTON BARANOV	{"email": "a.baranov.021972@postgrespro.ru", "phone": "+70547439488"}
0005433568192	6DF943	0319 682702	LEONID ANDREEV	{"phone": "+70757953337"}
0005433568193	6DF943	5714 793538	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr.1964@postgrespro.ru", "phone": "+70040344848"}
0005433568194	D0DA43	1001 354413	VALENTINA MIKHAYLOVA	{"phone": "+70457667689"}
0005433568195	859824	1256 223436	SERGEY KOZLOV	{"email": "kozlov.sergey1968@postgrespro.ru", "phone": "+70331574182"}
0005433568196	859824	4168 030086	MARIYA SERGEEVA	{"phone": "+70380179225"}
0005433568197	B19C5A	8290 722400	RAVIL IVANOV	{"phone": "+70936896238"}
0005433568198	C73D28	5846 760749	EVGENIY VOROBEV	{"phone": "+70725908488"}
0005433568199	C25776	5903 539264	VALENTINA MELNIKOVA	{"phone": "+70061709099"}
0005433568200	0583BA	0259 110987	SVETLANA GERASIMOVA	{"phone": "+70085133539"}
0005433568201	0583BA	4773 416527	SERGEY PETROV	{"email": "s-petrov.061970@postgrespro.ru", "phone": "+70835942329"}
0005433568202	0B8A76	9467 183908	IRINA ZAYCEVA	{"phone": "+70793971442"}
0005433568203	2EA0BD	7403 689128	VASILIY DAVYDOV	{"email": "vasiliydavydov041970@postgrespro.ru", "phone": "+70091503234"}
0005433568204	DC7B20	0458 149068	EKATERINA EFREMOVA	{"email": "efremova.e_061962@postgrespro.ru", "phone": "+70715846142"}
0005433568205	B1CB9C	2475 508784	MARINA AKIMOVA	{"phone": "+70764291506"}
0005433568206	47F4EC	2725 025141	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr.02011966@postgrespro.ru", "phone": "+70578608786"}
0005433568207	15BDED	3409 340674	SERGEY SIDOROV	{"phone": "+70956031099"}
0005433568208	B1EBAD	7535 124324	SVETLANA NOVIKOVA	{"phone": "+70489565450"}
0005433568209	25328B	8713 352118	MARAT ALEKSEEV	{"phone": "+70460090202"}
0005433568210	2C691C	4699 618216	MARINA KOVALEVA	{"email": "kovaleva-marina21031965@postgrespro.ru", "phone": "+70686817800"}
0005433568211	5A471F	2099 021717	DMITRIY KUZNECOV	{"phone": "+70293129007"}
0005433568212	CFE41C	0175 678586	GALINA ZAKHAROVA	{"phone": "+70604477928"}
0005433568213	CFE41C	9623 396003	GALINA IVANOVA	{"phone": "+70591958767"}
0005433568215	C66203	3278 686399	SERGEY PETROV	{"email": "sergey.petrov_031980@postgrespro.ru", "phone": "+70664443454"}
0005433568216	90278E	8811 496793	RAVIL VASILEV	{"email": "r.vasilev-1975@postgrespro.ru", "phone": "+70733823030"}
0005433568217	604AC5	7332 441722	VYACHESLAV MOISEEV	{"email": "moiseev-vyacheslav_1982@postgrespro.ru", "phone": "+70316284579"}
0005433568218	604AC5	0833 540683	GRIGORIY MOROZOV	{"email": "g-morozov19051966@postgrespro.ru", "phone": "+70658139515"}
0005433568219	9C959C	2700 449901	VLADIMIR STEPANOV	{"phone": "+70711102001"}
0005433568220	1FA6E0	6950 664224	LYUBOV KALININA	{"phone": "+70858560877"}
0005433568221	7A6DFA	6086 949002	YURIY MAKAROV	{"email": "yuriy-makarov031979@postgrespro.ru", "phone": "+70062326400"}
0005433568222	7A6DFA	7676 785843	IGOR ANTONOV	{"email": "iantonov_1981@postgrespro.ru", "phone": "+70757952441"}
0005433568280	368AD1	8784 126902	ELENA VASILEVA	{"phone": "+70975659641"}
0005433568223	7A6DFA	3270 742292	EKATERINA KONOVALOVA	{"email": "konovalova_e011962@postgrespro.ru", "phone": "+70581152656"}
0005433568224	FEFC33	1480 387005	ILYA MIRONOV	{"email": "mironov-i-1979@postgrespro.ru", "phone": "+70739663078"}
0005433568225	12973F	1939 985334	SERGEY NAZAROV	{"phone": "+70961721960"}
0005433568226	12973F	0528 771038	NATALYA MAKSIMOVA	{"email": "nmaksimova-19021981@postgrespro.ru", "phone": "+70835805050"}
0005433568227	74F759	5607 798470	YURIY MOROZOV	{"phone": "+70949549400"}
0005433568228	74F759	3866 019742	IGOR NOVIKOV	{"email": "novikov_i1974@postgrespro.ru", "phone": "+70437682624"}
0005433568229	304361	0925 322688	ALEKSANDR MEDVEDEV	{"phone": "+70366898301"}
0005433568230	E89E22	4325 105876	IRINA AKIMOVA	{"email": "akimova_irina-041992@postgrespro.ru", "phone": "+70464126648"}
0005433568231	B2CC7B	3539 892199	ELENA KOROLEVA	{"phone": "+70747880870"}
0005433568232	70F453	0264 947596	DMITRIY NOVIKOV	{"email": "dmitriy.novikov_1974@postgrespro.ru", "phone": "+70536963674"}
0005433568233	4822C0	9521 302313	FEDOR KISELEV	{"email": "kiselevf.23061974@postgrespro.ru", "phone": "+70514422361"}
0005433568234	4822C0	1873 363271	ALEKSEY VOROBEV	{"phone": "+70237178257"}
0005433568235	27D7C7	6596 190126	VLADIMIR ROMANOV	{"email": "romanov_v07051969@postgrespro.ru", "phone": "+70983759007"}
0005433568236	B5A83D	3595 281241	VIKTOR ZHURAVLEV	{"phone": "+70567602361"}
0005433568237	B5A83D	1471 804690	SERGEY ISAEV	{"email": "sergeyisaev.1966@postgrespro.ru", "phone": "+70424621187"}
0005433568238	87ACD7	8022 250346	SERGEY GUSEV	{"email": "s-gusev_011960@postgrespro.ru", "phone": "+70127314813"}
0005433568239	F00365	6744 846135	VALERIY KISELEV	{"phone": "+70697952517"}
0005433568240	0FEC14	1291 719865	EVELINA STEPANOVA	{"phone": "+70181413891"}
0005433568241	22C79D	2857 038029	SANIYA VOLKOVA	{"email": "volkova-s-13071961@postgrespro.ru", "phone": "+70706033607"}
0005433568242	CA4EB4	3184 963041	ARINA ORLOVA	{"phone": "+70303672949"}
0005433568355	F6C347	7177 891616	DANIIL GUSEV	{"phone": "+70069044941"}
0005433568243	6A5912	7162 209476	NINA ANTONOVA	{"email": "nantonova.21081961@postgrespro.ru", "phone": "+70111930011"}
0005433568244	9663AA	7237 911361	SERGEY AFANASEV	{"phone": "+70792843942"}
0005433568245	F0FC08	2666 542716	OLEG MATVEEV	{"email": "matveevoleg_091966@postgrespro.ru", "phone": "+70278006687"}
0005433568246	67AD51	1488 258098	VIKTOR NIKOLAEV	{"phone": "+70736326165"}
0005433568247	67AD51	1756 809965	STANISLAV IVANOV	{"phone": "+70081162673"}
0005433568248	DEAB7B	2830 973463	GALINA NOVIKOVA	{"email": "novikova_g1974@postgrespro.ru", "phone": "+70513863891"}
0005433568249	E04888	2184 939491	GENNADIY ZHURAVLEV	{"phone": "+70979520353"}
0005433568250	E04888	0818 557465	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov.051988@postgrespro.ru", "phone": "+70930496389"}
0005433568251	E04888	5509 507276	OLEG EGOROV	{"phone": "+70581152406"}
0005433568252	90CED1	5371 176018	ELENA GORBUNOVA	{"email": "e.gorbunova081967@postgrespro.ru", "phone": "+70322288292"}
0005433568253	E8D92E	0006 823241	INNA KAZAKOVA	{"phone": "+70708803213"}
0005433568254	D97B4D	7804 229752	TATYANA ILINA	{"phone": "+70004125107"}
0005433568255	9144A8	4818 729053	ALEKSANDR MIKHAYLOV	{"phone": "+70231411805"}
0005433568256	7A2181	6533 205689	NADEZHDA NAUMOVA	{"phone": "+70048773059"}
0005433568257	8BC3C8	7860 994280	YULIYA DMITRIEVA	{"email": "y.dmitrieva.101966@postgrespro.ru", "phone": "+70954586216"}
0005433568258	8BC3C8	6645 953912	VYACHESLAV FEDOROV	{"email": "fedorovv.21061972@postgrespro.ru", "phone": "+70074402359"}
0005433568259	DAD44C	7520 007127	MARIYA SMIRNOVA	{"phone": "+70823893329"}
0005433568260	E4EAE1	8727 042832	ANASTASIYA ZAYCEVA	{"email": "anastasiya_zayceva1967@postgrespro.ru", "phone": "+70420305415"}
0005433568261	E4EAE1	7374 433786	ELENA KUZNECOVA	{"phone": "+70070602756"}
0005433568262	E84865	6889 210522	DARYA ALEKSANDROVA	{"phone": "+70185824352"}
0005433568263	BDC954	1802 003116	YULIYA NESTEROVA	{"email": "yuliyanesterova27081965@postgrespro.ru", "phone": "+70859606988"}
0005433568264	BDC954	9857 043306	ALEVTINA TROFIMOVA	{"phone": "+70772779360"}
0005433568265	C93F2B	4802 497759	ALEKSANDR MAKSIMOV	{"email": "maksimov_a-1970@postgrespro.ru", "phone": "+70499299848"}
0005433568266	32678C	3986 796659	SVETLANA NOVIKOVA	{"email": "s-novikova28091983@postgrespro.ru", "phone": "+70517148705"}
0005433568267	36D03F	2527 189443	VALERIYA SMIRNOVA	{"phone": "+70195983875"}
0005433568268	11E4F4	5679 950197	SERGEY TIMOFEEV	{"email": "s-timofeev.031975@postgrespro.ru", "phone": "+70490988705"}
0005433568269	407055	9160 529480	ALEKSANDR BORISOV	{"email": "borisova_061977@postgrespro.ru", "phone": "+70267434415"}
0005433568270	0C585A	5224 837834	LYUDMILA GORBUNOVA	{"email": "gorbunova.l_081968@postgrespro.ru", "phone": "+70260669060"}
0005433568271	066AF3	5205 614158	VERA IVANOVA	{"phone": "+70752191508"}
0005433568272	73CCD3	2833 852727	PETR VOLKOV	{"email": "volkov_petr_081980@postgrespro.ru", "phone": "+70423915521"}
0005433568274	42E8F4	0997 018060	OLGA ERMAKOVA	{"phone": "+70200841605"}
0005433568275	42E8F4	6751 791275	BORIS MAKSIMOV	{"phone": "+70294486082"}
0005433568276	111962	2542 603771	ALEKSANDR BELOV	{"email": "belova_28041963@postgrespro.ru", "phone": "+70275986420"}
0005433568277	3707C2	3322 719194	VLADIMIR PETROV	{"phone": "+70086094053"}
0005433568278	3707C2	1210 641634	LIDIYA SEMENOVA	{"email": "l_semenova-1983@postgrespro.ru", "phone": "+70976903302"}
0005433568279	8AAD57	7165 059361	ZINAIDA PAVLOVA	{"phone": "+70208589711"}
0005433568281	9570F2	6567 440695	VLADIMIR ANDREEV	{"email": "andreev.v-041968@postgrespro.ru", "phone": "+70203854923"}
0005433568282	9570F2	0375 875471	ALEKSANDR PETROV	{"email": "petrov-a1971@postgrespro.ru", "phone": "+70615778685"}
0005433568283	8FCACA	0941 284884	YURIY KOROLEV	{"email": "korolev_yuriy1967@postgrespro.ru", "phone": "+70876462095"}
0005433568284	8FCACA	4881 688091	ALEFTINA MIKHAYLOVA	{"email": "a.mikhaylova-1983@postgrespro.ru", "phone": "+70619286313"}
0005433568285	F00F82	4621 122931	STANISLAV PAVLOV	{"phone": "+70029679145"}
0005433568286	6C9805	2382 417378	SERGEY MELNIKOV	{"phone": "+70318120154"}
0005433568287	6C9805	0939 709051	MAKSIM STEPANOV	{"email": "maksimstepanov_091968@postgrespro.ru", "phone": "+70365084059"}
0005433568288	57DA05	5238 353746	SERGEY GERASIMOV	{"phone": "+70543199262"}
0005433568289	57DA05	4304 636825	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova_011966@postgrespro.ru", "phone": "+70806850621"}
0005433568290	1C9FD6	4786 034958	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr_121974@postgrespro.ru", "phone": "+70711319628"}
0005433568291	17F634	4891 475319	DENIS OSIPOV	{"phone": "+70472911334"}
0005433568292	46E0D5	6387 969376	YAKOV ANTONOV	{"email": "antonov_yakov-021966@postgrespro.ru", "phone": "+70105482976"}
0005433568293	482027	8849 182915	OLGA PETROVA	{"email": "o.petrova24061978@postgrespro.ru", "phone": "+70344257234"}
0005433568294	5A3CE5	0242 374440	MARIYA OSIPOVA	{"email": "mariya.osipova.1986@postgrespro.ru", "phone": "+70736774787"}
0005433568295	5A3CE5	6541 684832	MAKSIM GRIGOREV	{"email": "maksimgrigorev_091976@postgrespro.ru", "phone": "+70797072060"}
0005433568296	066C9C	3587 703748	NINEL NIKITINA	{"phone": "+70677361800"}
0005433568297	8D2AED	7562 457756	IRINA KUZNECOVA	{"email": "irinakuznecova.04071984@postgrespro.ru", "phone": "+70759063273"}
0005433568298	8D2AED	0572 315702	VYACHESLAV DAVYDOV	{"phone": "+70579783030"}
0005433568299	006404	5521 066851	TATYANA MIRONOVA	{"email": "mironova-tatyana-22011976@postgrespro.ru", "phone": "+70672730927"}
0005433568300	006404	2974 098649	VYACHESLAV ZHURAVLEV	{"email": "vzhuravlev.11101978@postgrespro.ru", "phone": "+70514998638"}
0005433568301	A4910B	7306 459400	NINA FILIPPOVA	{"email": "filippova.n-1964@postgrespro.ru", "phone": "+70901342159"}
0005433568302	E58C72	7659 358640	ALEKSANDR ABRAMOV	{"phone": "+70064362438"}
0005433568303	1F6373	2599 627135	MARINA ANDREEVA	{"email": "marinaandreeva.1975@postgrespro.ru", "phone": "+70204503629"}
0005433568304	CE965D	6255 132315	DENIS SMIRNOV	{"phone": "+70195525652"}
0005433568305	2DBE25	5860 653432	NIKOLAY NOVIKOV	{"email": "n-novikov1977@postgrespro.ru", "phone": "+70442204121"}
0005433568306	ED8B36	9081 977263	TATYANA VOLKOVA	{"phone": "+70011939379"}
0005433568307	ED8B36	4972 380143	RAISA GERASIMOVA	{"email": "gerasimova_raisa_18081986@postgrespro.ru", "phone": "+70470941074"}
0005433568308	93E476	8593 600952	ELENA ZAKHAROVA	{"phone": "+70407086914"}
0005433568309	11CB23	5339 490345	RIMA MASLOVA	{"email": "rima.maslova_1969@postgrespro.ru", "phone": "+70393116895"}
0005433568310	11CB23	0127 208366	PAVEL ALEKSANDROV	{"phone": "+70367376654"}
0005433568311	2FC201	9123 858725	OLEG POPOV	{"phone": "+70795320413"}
0005433568312	77C2AD	3852 249871	IRINA MAKAROVA	{"email": "makarova.i_16111973@postgrespro.ru", "phone": "+70048746836"}
0005433568313	77C2AD	0220 337776	NATALYA NIKITINA	{"phone": "+70435314305"}
0005433568314	77C2AD	5070 889022	EKATERINA OSIPOVA	{"email": "osipova.e.011980@postgrespro.ru", "phone": "+70589009893"}
0005433568315	3A39E4	5624 496100	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr.09081967@postgrespro.ru", "phone": "+70136002008"}
0005433568316	DB04D7	2056 498488	MIKHAIL KRASNOV	{"email": "mikhail_krasnov.18061973@postgrespro.ru", "phone": "+70990202120"}
0005433568317	3DB31C	8184 493695	TATYANA DANILOVA	{"email": "tatyana.danilova021975@postgrespro.ru", "phone": "+70931231183"}
0005433568318	919492	8283 340809	OLEG PAVLOV	{"phone": "+70133250315"}
0005433568319	8E834E	5708 731792	ANDREY KULIKOV	{"email": "kulikov.a-31071974@postgrespro.ru", "phone": "+70405970383"}
0005433568320	96F287	3043 735202	SERGEY KUZNECOV	{"email": "s-kuznecov1977@postgrespro.ru", "phone": "+70906970612"}
0005433568321	2CF64C	5986 851788	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda.051969@postgrespro.ru", "phone": "+70691555155"}
0005433568322	3AE18A	7026 469858	ALLA ANDREEVA	{"email": "a-andreeva111981@postgrespro.ru", "phone": "+70254519067"}
0005433568323	028CF2	0877 211494	SERGEY KUZNECOV	{"email": "skuznecov1959@postgrespro.ru", "phone": "+70615578211"}
0005433568324	830285	5578 080889	ILYA RODIONOV	{"email": "rodionov_ilya_1969@postgrespro.ru", "phone": "+70374582882"}
0005433568325	80A7C5	5834 380470	ANNA KISELEVA	{"email": "kiseleva-anna.1968@postgrespro.ru", "phone": "+70976086278"}
0005433568326	A4A8E8	2486 935709	ARTEM ISAEV	{"email": "isaev-artem_16021978@postgrespro.ru", "phone": "+70008016262"}
0005433568327	4506EA	0246 711787	ALEKSANDR STEPANOV	{"email": "astepanov_09051983@postgrespro.ru", "phone": "+70525047109"}
0005433568328	62A6A9	4054 013611	OLGA DMITRIEVA	{"email": "dmitrieva-olga_08101981@postgrespro.ru", "phone": "+70020893082"}
0005433568329	62A6A9	1664 534425	VERA FILIPPOVA	{"email": "filippova.vera1969@postgrespro.ru", "phone": "+70823262876"}
0005433568330	D3BB25	1981 965759	TAISA LUKYANOVA	{"email": "lukyanova_taisa-031971@postgrespro.ru", "phone": "+70248208256"}
0005433568331	A88A92	1223 124481	SERGEY MIKHAYLOV	{"email": "mikhaylov.s.14031973@postgrespro.ru", "phone": "+70239863533"}
0005433568332	B374BB	4042 263489	IVAN ROMANOV	{"phone": "+70066526960"}
0005433568333	B374BB	5188 084043	VASILIY NIKOLAEV	{"phone": "+70176382031"}
0005433568334	BE9F9C	3703 413843	LARISA MAKSIMOVA	{"email": "maksimova.larisa_22021958@postgrespro.ru", "phone": "+70437693404"}
0005433568335	3BE9BB	1265 845945	ALEKSANDR PAVLOV	{"phone": "+70277854525"}
0005433568336	3BE9BB	0363 505588	IVAN NIKITIN	{"email": "ivannikitin-25051961@postgrespro.ru", "phone": "+70738678874"}
0005433568337	4AF5E2	9897 151689	OLGA KUZMINA	{"phone": "+70366566597"}
0005433568338	4AF5E2	0614 572165	SERGEY POPOV	{"phone": "+70069622821"}
0005433568339	711627	7200 292849	SVETLANA NIKOLAEVA	{"email": "svetlana-nikolaeva1963@postgrespro.ru", "phone": "+70491471808"}
0005433568340	711627	7325 525235	TATYANA NAZAROVA	{"email": "t.nazarova111980@postgrespro.ru", "phone": "+70867834706"}
0005433568341	08E51A	2057 004851	OKSANA MASLOVA	{"email": "maslova_o.031969@postgrespro.ru", "phone": "+70287366947"}
0005433568342	08E51A	3343 224157	VALENTIN NOVIKOV	{"email": "novikov_v.1971@postgrespro.ru", "phone": "+70499684764"}
0005433568343	A48D0D	5474 190053	ALEKSEY PAVLOV	{"email": "aleksey.pavlov.031971@postgrespro.ru", "phone": "+70980021050"}
0005433568344	973C92	2938 722609	VLADISLAV ILIN	{"email": "v-ilin-11121973@postgrespro.ru", "phone": "+70386599661"}
0005433568345	EC6AD8	8373 200135	ARTEM ZAKHAROV	{"email": "zakharovartem.1969@postgrespro.ru", "phone": "+70652221076"}
0005433568346	337222	4727 800906	ARINA NIKOLAEVA	{"email": "arina-nikolaeva.15061964@postgrespro.ru", "phone": "+70504609168"}
0005433568347	337222	8762 250732	ALEKSANDR BORISOV	{"phone": "+70416504457"}
0005433568348	34FCDA	1845 773410	PAVEL ALEKSEEV	{"email": "pavelalekseev_1971@postgrespro.ru", "phone": "+70595250633"}
0005433568349	2E9B75	2768 001920	VADIM GUSEV	{"email": "vadim-gusev-1977@postgrespro.ru", "phone": "+70347080600"}
0005433568350	6886D6	1893 051313	ALEKSANDR SAVELEV	{"phone": "+70775790717"}
0005433568351	F33FC2	9324 282220	YURIY EGOROV	{"email": "y-egorov_10031980@postgrespro.ru", "phone": "+70004177622"}
0005433568352	F33FC2	6087 667506	NATALYA SOKOLOVA	{"phone": "+70672684639"}
0005433568353	C2A013	6223 346554	ALEKSANDR SOKOLOV	{"phone": "+70466495522"}
0005433568354	5C93FB	1910 086685	MAKSIM FROLOV	{"email": "frolov_m-10041979@postgrespro.ru", "phone": "+70319977481"}
0005433568356	72120B	0544 233767	SERGEY MOROZOV	{"email": "morozov_s-011978@postgrespro.ru", "phone": "+70682546488"}
0005433568357	8B7B11	1084 729535	ALEKSANDRA ANTONOVA	{"email": "aleksandra_antonova_27061978@postgrespro.ru", "phone": "+70917581059"}
0005433568358	4879B0	3974 801352	VIKTORIYA LUKYANOVA	{"email": "lukyanovaviktoriya101970@postgrespro.ru", "phone": "+70748851875"}
0005433568359	5932D6	3296 871414	ANASTASIYA SOKOLOVA	{"phone": "+70005249733"}
0005433568360	70638B	8717 396329	VIKTOR MELNIKOV	{"email": "v.melnikov-1971@postgrespro.ru", "phone": "+70593890272"}
0005433568361	70638B	7495 110440	ELIZAVETA MOROZOVA	{"phone": "+70587753561"}
0005433568362	1FEDB1	3729 881067	DARYA LOGINOVA	{"email": "d_loginova11031963@postgrespro.ru", "phone": "+70035574434"}
0005433568363	323C30	8049 328614	GYUZEL FEDOROVA	{"phone": "+70581744540"}
0005433568364	A6C72F	9577 935160	ALEKSEY MOROZOV	{"phone": "+70899124553"}
0005433568365	2666A4	8741 174937	ANDREY MEDVEDEV	{"email": "amedvedev1974@postgrespro.ru", "phone": "+70300268305"}
0005433568366	C917F0	5695 741569	LYUDMILA MIRONOVA	{"email": "mironova_lyudmila_17121976@postgrespro.ru", "phone": "+70871384528"}
0005433568367	C917F0	3450 907787	VIKTOR KULIKOV	{"phone": "+70038108355"}
0005433568368	D198E9	7647 610252	SERGEY GERASIMOV	{"email": "gerasimov-sergey_061963@postgrespro.ru", "phone": "+70119652316"}
0005433568369	C457D5	6955 464208	ANASTASIYA STEPANOVA	{"phone": "+70657347720"}
0005433568370	E9A28D	2210 070081	TATYANA KISELEVA	{"phone": "+70869412448"}
0005433568371	D629B4	8138 928433	SERGEY NIKITIN	{"phone": "+70462986040"}
0005433568372	6AE668	1911 204650	ALEKSANDRA FROLOVA	{"email": "aleksandra-frolova-041977@postgrespro.ru", "phone": "+70129548664"}
0005433568373	6AE668	4382 120995	EVGENIY ANTONOV	{"email": "antonov-evgeniy_051979@postgrespro.ru", "phone": "+70382151102"}
0005433568374	F862DA	0569 222577	IGOR VASILEV	{"email": "vasilev-igor-1965@postgrespro.ru", "phone": "+70665060698"}
0005433568375	CA22B4	2016 075900	VLADIMIR ALEKSANDROV	{"phone": "+70012383006"}
0005433568376	CA22B4	5045 289709	VERA VOLKOVA	{"email": "vera.volkova28121963@postgrespro.ru", "phone": "+70588903138"}
0005433568377	98E185	9326 988956	ILSHAT GRIGOREV	{"phone": "+70193984479"}
0005433568378	98E185	4006 153792	NADEZHDA LAZAREVA	{"email": "lazareva_n13121973@postgrespro.ru", "phone": "+70797140685"}
0005433568379	8970EB	5812 833840	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr_04051982@postgrespro.ru", "phone": "+70829697798"}
0005433568380	B62CB8	2275 034926	VLADIMIR TARASOV	{"email": "tarasovv_1973@postgrespro.ru", "phone": "+70063708477"}
0005433568381	B62CB8	5749 042013	IGOR FEDOTOV	{"email": "fedotov.i_101968@postgrespro.ru", "phone": "+70393105826"}
0005433568382	727835	0481 883697	IRINA MIKHAYLOVA	{"phone": "+70156465980"}
0005433568383	727835	7309 067080	VENIAMIN SCHERBAKOV	{"phone": "+70527664188"}
0005433568384	3125EF	3469 820416	MARINA ANTONOVA	{"phone": "+70418564989"}
0005433568385	43FBFD	7535 769756	NATALYA ZOTOVA	{"email": "nzotova-1978@postgrespro.ru", "phone": "+70729544726"}
0005433568386	A8FAB0	9667 063662	GRIGORIY SOROKIN	{"phone": "+70678373407"}
0005433568387	CE6D21	7525 546760	NATALYA ORLOVA	{"phone": "+70473783100"}
0005433568388	CE6D21	8393 261746	GALINA NIKIFOROVA	{"email": "nikiforova_galina1976@postgrespro.ru", "phone": "+70979788038"}
0005433568389	28F857	4900 723954	VLADIMIR NAUMOV	{"phone": "+70702739484"}
0005433568390	28F857	0113 048527	NIKOLAY DMITRIEV	{"email": "dmitriev-n.1978@postgrespro.ru", "phone": "+70017844912"}
0005433568391	28F857	2895 291662	SERGEY EGOROV	{"email": "sergey.egorov.1970@postgrespro.ru", "phone": "+70561321004"}
0005433568392	6E16D9	9006 896592	TAMARA MAKAROVA	{"phone": "+70011757348"}
0005433568393	F96AA5	0210 156603	SERGEY KOROLEV	{"phone": "+70357331953"}
0005433568394	FEA74D	1368 308475	VALERIY ZAYCEV	{"email": "valeriyzaycev-091969@postgrespro.ru", "phone": "+70070633053"}
0005433568395	64B053	1959 320112	VERA FADEEVA	{"email": "fadeevavera_121980@postgrespro.ru", "phone": "+70748390921"}
0005433568396	64B053	9706 938839	MARINA PETROVA	{"phone": "+70804118859"}
0005433568397	F8C093	4522 115458	ELENA ALEKSANDROVA	{"email": "e.aleksandrova.031987@postgrespro.ru", "phone": "+70102982963"}
0005433568398	D6EA86	0054 974936	ANDREY MELNIKOV	{"email": "andrey.melnikov.16061973@postgrespro.ru", "phone": "+70693260491"}
0005433568399	D6EA86	1421 492262	ANNA MEDVEDEVA	{"email": "medvedeva.anna-25111978@postgrespro.ru", "phone": "+70050578289"}
0005433568400	A1466B	6340 280608	MAKSIM MAKAROV	{"phone": "+70212750052"}
0005433568401	406FDC	2930 011695	ALENA KOVALEVA	{"phone": "+70562221729"}
0005433568402	406FDC	1942 475907	ALEKSEY NOVIKOV	{"email": "a.novikov1962@postgrespro.ru", "phone": "+70590395899"}
0005433568403	721343	5340 042057	MARIYA DMITRIEVA	{"email": "m.dmitrieva.08121966@postgrespro.ru", "phone": "+70629501376"}
0005433568404	721343	7690 617586	NADEZHDA KUZNECOVA	{"phone": "+70508484847"}
0005433568405	1AEEC8	6635 709821	ALINA IVANOVA	{"phone": "+70102387162"}
0005433568406	C38DA8	2410 963635	PETR KUDRYASHOV	{"email": "p_kudryashov1979@postgrespro.ru", "phone": "+70503916482"}
0005433568407	C38DA8	8061 128878	VALERIY TIKHONOV	{"phone": "+70065672833"}
0005433568408	19D044	2700 139961	YURIY KUZNECOV	{"email": "y_kuznecov-071965@postgrespro.ru", "phone": "+70500898686"}
0005433568409	19D044	0436 808720	YURIY MOROZOV	{"email": "morozov.yuriy1982@postgrespro.ru", "phone": "+70172859094"}
0005433568410	B70890	5549 450382	ELENA DMITRIEVA	{"email": "dmitrieva.elena1972@postgrespro.ru", "phone": "+70183836325"}
0005433568523	197589	3910 602459	VENERA KOVALEVA	{"phone": "+70249469802"}
0005433568411	B70890	5020 181293	TAMARA LEBEDEVA	{"email": "tamaralebedeva.1968@postgrespro.ru", "phone": "+70134561124"}
0005433568412	57A7ED	6072 772588	VALERIY AFANASEV	{"phone": "+70215623200"}
0005433568413	8CB506	3514 938129	ALEKSANDR KARPOV	{"phone": "+70724172018"}
0005433568414	DDFB03	0190 058360	EDUARD NIKITIN	{"email": "e.nikitin-11061962@postgrespro.ru", "phone": "+70302126609"}
0005433568415	DDFB03	6240 360265	IGOR ILIN	{"phone": "+70360541003"}
0005433568416	712B00	9265 071933	FLYURA PAVLOVA	{"email": "flyurapavlova_1970@postgrespro.ru", "phone": "+70467471555"}
0005433568417	32CFFD	1899 476143	SERGEY SERGEEV	{"email": "sergeysergeev.121979@postgrespro.ru", "phone": "+70119055189"}
0005433568418	ED65D7	3153 348293	VALENTIN GERASIMOV	{"email": "gerasimov.valentin27061976@postgrespro.ru", "phone": "+70852023427"}
0005433568419	95C555	5204 822600	VIKTOR MOISEEV	{"phone": "+70876975381"}
0005433568420	38ACBD	7938 013022	NIKOLAY FROLOV	{"email": "frolov-n_051967@postgrespro.ru", "phone": "+70306970829"}
0005433568421	38ACBD	7689 517447	IRINA MAKAROVA	{"phone": "+70817040459"}
0005433568422	642EC2	9150 658069	NATALYA ALEKSEEVA	{"email": "alekseeva_n_24061971@postgrespro.ru", "phone": "+70964498051"}
0005433568423	5FE6E0	2667 736369	YULIYA KOLESNIKOVA	{"email": "kolesnikova-y-1973@postgrespro.ru", "phone": "+70439728291"}
0005433568424	328E75	5235 445195	ALEKSEY SIDOROV	{"email": "sidorovaleksey1965@postgrespro.ru", "phone": "+70292890303"}
0005433568425	D8B1CE	0146 873621	TATYANA LOGINOVA	{"email": "loginova_tatyana.04081969@postgrespro.ru", "phone": "+70603934406"}
0005433568426	6D62ED	5363 317019	RENATA RODIONOVA	{"phone": "+70793036652"}
0005433568427	36E5CD	8981 394376	VIKTOR KUZNECOV	{"phone": "+70359424797"}
0005433568428	1C9B8F	2510 729372	ANASTASIYA LEBEDEVA	{"phone": "+70172486091"}
0005433568429	A75F99	1157 488231	DANIYA SEMENOVA	{"phone": "+70735557110"}
0005433568430	1516A3	6437 516584	MIKHAIL MOROZOV	{"email": "morozov.m021968@postgrespro.ru", "phone": "+70618041431"}
0005433568431	C13761	5287 345176	ALBINA NAZAROVA	{"phone": "+70908419269"}
0005433568432	43224E	7719 592071	NADEZHDA CHERNOVA	{"phone": "+70912028773"}
0005433568433	0EF8DF	5352 264658	VALERIYA FROLOVA	{"phone": "+70653100122"}
0005433568434	0EF8DF	4978 856657	OKSANA TIMOFEEVA	{"phone": "+70997725503"}
0005433568435	E5C7B2	7771 400751	PETR FOMIN	{"email": "p_fomin081971@postgrespro.ru", "phone": "+70749270706"}
0005433568436	E5C7B2	2580 018130	VLADIMIR MARTYNOV	{"phone": "+70864735398"}
0005433568437	E5C7B2	1438 133357	ELENA VASILEVA	{"email": "elena-vasileva071979@postgrespro.ru", "phone": "+70584909944"}
0005433568438	B0BF54	0584 437357	EKATERINA SEMENOVA	{"phone": "+70653176977"}
0005433568439	3615CD	6507 203868	ALEKSANDRA MOROZOVA	{"phone": "+70337516457"}
0005433568440	3615CD	7827 634996	NATALYA NIKITINA	{"email": "nikitina-n.31051969@postgrespro.ru", "phone": "+70353611532"}
0005433568441	20DB22	1480 490481	GENNADIY PAVLOV	{"email": "pavlov_gennadiy-1975@postgrespro.ru", "phone": "+70177583693"}
0005433568442	421215	5779 166445	ULYANA KUZNECOVA	{"email": "kuznecova.u.091980@postgrespro.ru", "phone": "+70838350432"}
0005433568443	22F6D4	3128 126913	TATYANA EGOROVA	{"phone": "+70101046291"}
0005433568444	51CEBD	5930 543430	ANTONINA DENISOVA	{"phone": "+70606893180"}
0005433568445	51CEBD	2577 813740	KONSTANTIN MELNIKOV	{"phone": "+70675360968"}
0005433568446	8AC098	3957 731998	ALEKSEY ABRAMOV	{"phone": "+70730449160"}
0005433568447	F35998	1758 480674	LIDIYA DAVYDOVA	{"email": "lidiya.davydova.091968@postgrespro.ru", "phone": "+70889071220"}
0005433568448	F35998	0396 892914	VYACHESLAV PETROV	{"email": "petrov-v.03121973@postgrespro.ru", "phone": "+70262134501"}
0005433568449	9E0640	2125 292265	VIKTOR KRASNOV	{"email": "viktor-krasnov22111976@postgrespro.ru", "phone": "+70114069080"}
0005433568450	9E0640	7981 354838	NADEZHDA ZAYCEVA	{"email": "zayceva-n_1975@postgrespro.ru", "phone": "+70316895932"}
0005433568451	F8E9F7	8326 884310	VIKTORIYA GORBUNOVA	{"email": "vgorbunova111976@postgrespro.ru", "phone": "+70673209306"}
0005433568452	F8E9F7	4800 446215	ANASTASIYA KOZLOVA	{"phone": "+70647290929"}
0005433568453	D529E7	0542 256281	RUSLAN VASILEV	{"phone": "+70834812759"}
0005433568454	D529E7	3257 367145	TATYANA NIKOLAEVA	{"email": "nikolaeva.tatyana_06021976@postgrespro.ru", "phone": "+70585907758"}
0005433568455	6D4403	2953 638727	VLADIMIR MARTYNOV	{"email": "martynov_vladimir-1974@postgrespro.ru", "phone": "+70715412630"}
0005433568456	6D4403	1534 949468	OLEG SERGEEV	{"email": "o.sergeev23041965@postgrespro.ru", "phone": "+70629126242"}
0005433568457	6D4403	7467 387232	LIDIYA MOISEEVA	{"email": "moiseeva_l1983@postgrespro.ru", "phone": "+70090283605"}
0005433568458	318E80	0713 021953	IRINA GRISHINA	{"email": "grishina-irina.14051963@postgrespro.ru", "phone": "+70863000229"}
0005433568459	D66963	1922 807751	EDUARD KOROLEV	{"phone": "+70061638072"}
0005433568460	DFB165	5819 120565	TATYANA SMIRNOVA	{"email": "t.smirnova.12051973@postgrespro.ru", "phone": "+70818575837"}
0005433568461	745528	0747 052872	ALEKSANDR AFANASEV	{"phone": "+70199696421"}
0005433568462	45E388	2860 883328	VLADIMIR GORBUNOV	{"email": "gorbunov.v12061974@postgrespro.ru", "phone": "+70138396608"}
0005433568463	45E388	5644 405413	NATALYA SOROKINA	{"email": "sorokina_n10061983@postgrespro.ru", "phone": "+70185285339"}
0005433568464	36CF67	3770 726314	NATALYA BELOVA	{"email": "belova_n.071976@postgrespro.ru", "phone": "+70449465438"}
0005433568465	EC5FE2	1051 599983	IRINA BORISOVA	{"email": "irina-borisova.1981@postgrespro.ru", "phone": "+70872186116"}
0005433568466	EC5FE2	6205 862145	IRINA MAKAROVA	{"phone": "+70030237463"}
0005433568467	EC5FE2	1770 777536	NAIL BORISOV	{"email": "borisov-n_09021974@postgrespro.ru", "phone": "+70430972835"}
0005433568468	42B536	3253 987553	DANIL MAKAROV	{"phone": "+70901605111"}
0005433568469	42B536	0392 747747	SERGEY PETROV	{"phone": "+70883307617"}
0005433568470	42B536	6088 187632	ELENA KUZNECOVA	{"email": "elenakuznecova.1974@postgrespro.ru", "phone": "+70217511867"}
0005433568471	9B69F9	4000 760269	EKATERINA KONOVALOVA	{"email": "ekaterina-konovalova-13101974@postgrespro.ru", "phone": "+70927165997"}
0005433568472	C58616	6442 140167	ALEKSEY PETROV	{"phone": "+70539402679"}
0005433568473	F06B3A	8840 121877	IRINA MIRONOVA	{"phone": "+70998491530"}
0005433568474	607FA2	4578 507088	IRINA NIKOLAEVA	{"email": "nikolaeva-irina.1968@postgrespro.ru", "phone": "+70619462380"}
0005433568475	4C4CAE	0980 592685	OLGA AKIMOVA	{"email": "akimova_olga.15041978@postgrespro.ru", "phone": "+70552007938"}
0005433568476	22ECA8	3482 034850	KIRILL OSIPOV	{"email": "k-osipov_1962@postgrespro.ru", "phone": "+70577558725"}
0005433568477	D17479	1052 465661	TATYANA PETROVA	{"email": "tatyanapetrova-041969@postgrespro.ru", "phone": "+70364936287"}
0005433568478	C7E868	7706 939927	NIKOLAY ANDREEV	{"email": "n-andreev_111979@postgrespro.ru", "phone": "+70670167789"}
0005433568479	7BCDFC	0738 998374	ANNA ALEKSEEVA	{"email": "alekseeva.a.1973@postgrespro.ru", "phone": "+70916249491"}
0005433568480	36F19D	6093 735581	VASILISA SOROKINA	{"phone": "+70967024586"}
0005433568481	CB5B2E	6040 506462	VLADIMIR MIRONOV	{"phone": "+70083914722"}
0005433568482	CB5B2E	0726 164525	POLINA KAZAKOVA	{"email": "kazakova.polina.081960@postgrespro.ru", "phone": "+70094643363"}
0005433568483	77D563	6359 608316	EKATERINA DENISOVA	{"email": "denisova.e30101970@postgrespro.ru", "phone": "+70218508432"}
0005433568484	34209D	2364 233397	LYUBOV OVCHINNIKOVA	{"email": "l.ovchinnikova.1965@postgrespro.ru", "phone": "+70664407226"}
0005433568485	34209D	4213 247221	IRINA CHERNOVA	{"phone": "+70618830879"}
0005433568486	B27B3C	9283 266882	LYUDMILA KUZNECOVA	{"phone": "+70064964109"}
0005433568487	A3129D	8557 116875	VALENTINA VASILEVA	{"phone": "+70997695258"}
0005433568488	DB0263	8069 428379	EVGENIY KUZNECOV	{"phone": "+70030358544"}
0005433568489	7D7D45	3075 311749	OLGA MATVEEVA	{"phone": "+70387112110"}
0005433568490	4A31A6	5861 523769	IVAN MELNIKOV	{"phone": "+70522669936"}
0005433568491	0227E0	7654 453083	ANDREY ANDREEV	{"email": "a-andreev-041980@postgrespro.ru", "phone": "+70645966851"}
0005433568492	B44D65	9743 563429	VALERIY SERGEEV	{"phone": "+70091368654"}
0005433568493	B44D65	4738 103999	NADEZHDA POPOVA	{"phone": "+70371626170"}
0005433568494	88B319	2109 912883	MARAT SOROKIN	{"email": "msorokin.091982@postgrespro.ru", "phone": "+70607152729"}
0005433568495	88B319	8204 618598	MARINA ILINA	{"phone": "+70452534787"}
0005433568496	CDE5B1	7542 393187	VLADIMIR KUZMIN	{"email": "vkuzmin_05031966@postgrespro.ru", "phone": "+70894754804"}
0005433568497	57922F	8483 402777	PETR MIKHAYLOV	{"email": "petr-mikhaylov_26071978@postgrespro.ru", "phone": "+70393383595"}
0005433568498	236725	3084 348042	MIKHAIL ZAKHAROV	{"email": "zakharov-mikhail.061981@postgrespro.ru", "phone": "+70593482188"}
0005433568499	7559F8	4012 804146	NATALYA ARKHIPOVA	{"phone": "+70952002009"}
0005433568500	7559F8	2523 843760	NELLYA LEBEDEVA	{"phone": "+70936632313"}
0005433568501	0DF187	1715 966883	NIKITA KOZLOV	{"phone": "+70605530064"}
0005433568502	BAF49F	0910 341644	KONSTANTIN GORBUNOV	{"email": "gorbunov_konstantin-121974@postgrespro.ru", "phone": "+70735481823"}
0005433568503	BAF49F	1341 809331	IVAN ANDREEV	{"phone": "+70028790602"}
0005433568504	84185D	3214 997295	YULIYA NESTEROVA	{"phone": "+70719103927"}
0005433568505	E9CF32	6804 536563	VIKTOR GUSEV	{"phone": "+70791267966"}
0005433568506	E9CF32	9558 800454	GEORGIY SHEVCHENKO	{"phone": "+70712099937"}
0005433568507	4C257C	7223 715503	VALENTINA NIKOLAEVA	{"email": "valentina.nikolaeva101966@postgrespro.ru", "phone": "+70394581956"}
0005433568508	4C257C	8155 463574	EKATERINA ROMANOVA	{"email": "ekaterina-romanova-27121970@postgrespro.ru", "phone": "+70628375754"}
0005433568509	3E7FAB	5815 947865	LARISA VASILEVA	{"email": "larisa-vasileva22061968@postgrespro.ru", "phone": "+70499522567"}
0005433568510	AA48B0	5459 566330	EVGENIY ALEKSANDROV	{"email": "ealeksandrov_1965@postgrespro.ru", "phone": "+70653503178"}
0005433568511	AA48B0	3014 861728	LYUDMILA SAVELEVA	{"phone": "+70280434400"}
0005433568512	688A6A	6876 811152	NATALYA TIMOFEEVA	{"phone": "+70726115426"}
0005433568513	688A6A	0977 901129	ANNA ZAYCEVA	{"phone": "+70784627275"}
0005433568514	25AC54	1768 047211	SVETLANA SIDOROVA	{"phone": "+70016835666"}
0005433568515	25AC54	8622 838739	NIKOLAY MOISEEV	{"email": "nikolay.moiseev-30101967@postgrespro.ru", "phone": "+70573282431"}
0005433568516	9D4294	2332 686753	ANATOLIY IVANOV	{"email": "aivanov_061976@postgrespro.ru", "phone": "+70520440236"}
0005433568517	A5D362	4184 988531	LYUDMILA BELYAEVA	{"phone": "+70121234480"}
0005433568518	AAB79F	1938 572477	SERGEY EGOROV	{"email": "sergey-egorov_041978@postgrespro.ru", "phone": "+70584744990"}
0005433568519	C98942	3506 652963	KLIM AFANASEV	{"email": "k.afanasev1972@postgrespro.ru", "phone": "+70520921287"}
0005433568520	C98942	2169 547240	MARIYA MIKHAYLOVA	{"email": "m-mikhaylova.1980@postgrespro.ru", "phone": "+70547887279"}
0005433568521	CC56FD	6981 172679	DENIS KAZAKOV	{"phone": "+70557703644"}
0005433568522	348098	1617 578429	NINA KUZNECOVA	{"email": "kuznecova-n_1967@postgrespro.ru", "phone": "+70032454074"}
0005433568524	60319D	8462 584824	VITALIY ALEKSEEV	{"email": "v.alekseev.10041973@postgrespro.ru", "phone": "+70090886407"}
0005433568525	F0C6A1	8984 697386	MARINA KUZNECOVA	{"phone": "+70460027526"}
0005433568526	F0C6A1	2705 897501	SERGEY MATVEEV	{"phone": "+70803899305"}
0005433568527	042472	2962 117025	NINA ZHURAVLEVA	{"phone": "+70976658436"}
0005433568528	A6B68D	9799 777355	GALINA KUZNECOVA	{"phone": "+70836795657"}
0005433568529	A6B68D	5545 612777	TATYANA KOLESNIKOVA	{"email": "kolesnikovat-1976@postgrespro.ru", "phone": "+70347913934"}
0005433568530	878294	9666 421395	NIKOLAY POPOV	{"email": "nikolay-popov-1962@postgrespro.ru", "phone": "+70282931685"}
0005433568531	30D495	4022 760281	ANNA KOZLOVA	{"email": "anna-kozlova1976@postgrespro.ru", "phone": "+70070751195"}
0005433568532	30D495	2796 376924	GENNADIY MIRONOV	{"phone": "+70111395215"}
0005433568533	0733A6	2886 262148	NINA ANDREEVA	{"email": "andreeva_nina-011979@postgrespro.ru", "phone": "+70477539934"}
0005433568534	78B0E7	7905 457652	VALENTINA GUSEVA	{"email": "valentinaguseva.031971@postgrespro.ru", "phone": "+70766537073"}
0005433568535	FF990B	7863 176560	OLGA GORBUNOVA	{"email": "olga-gorbunova1978@postgrespro.ru", "phone": "+70516627159"}
0005433568536	2922D4	9855 700233	TAMARA IVANOVA	{"phone": "+70268503199"}
0005433568537	2922D4	2302 726133	ANNA GUSEVA	{"email": "guseva_anna.091969@postgrespro.ru", "phone": "+70307647392"}
0005433568538	BFB145	4430 895501	ANTONINA ABRAMOVA	{"phone": "+70780367510"}
0005433568539	04C4F9	1727 134340	ANASTASIYA PAVLOVA	{"email": "pavlova.a_061984@postgrespro.ru", "phone": "+70961461857"}
0005433568540	9D8CFF	6976 662434	PETR ZAKHAROV	{"phone": "+70203208485"}
0005433568541	9D8CFF	5021 049467	YURIY FILIPPOV	{"phone": "+70888922920"}
0005433568542	08173C	5863 533796	ANNA NAUMOVA	{"phone": "+70101036913"}
0005433568543	08173C	7132 116349	IVAN DMITRIEV	{"phone": "+70416318502"}
0005433568544	0F1C37	5035 579271	SERGEY NIKITIN	{"email": "sergey-nikitin11101975@postgrespro.ru", "phone": "+70077219752"}
0005433568545	42650B	1303 074381	VIKTOR PETROV	{"email": "viktor_petrov_1984@postgrespro.ru", "phone": "+70482708021"}
0005433568546	42650B	0460 866601	MAKSIM ILIN	{"email": "maksim_ilin-23041972@postgrespro.ru", "phone": "+70364390139"}
0005433568547	30882D	5919 025957	KSENIYA YAKOVLEVA	{"email": "yakovleva-k-08071970@postgrespro.ru", "phone": "+70323078371"}
0005433568548	D49BC8	7450 347251	VLADIMIR KUZNECOV	{"phone": "+70677986170"}
0005433568549	D49BC8	7315 756181	ELENA SIDOROVA	{"email": "sidorovae.031965@postgrespro.ru", "phone": "+70239425253"}
0005433568550	18F563	7533 303043	LYUDMILA IVANOVA	{"phone": "+70373834560"}
0005433568551	5E8F08	2813 231274	LIDIYA GUSEVA	{"email": "guseva.lidiya081976@postgrespro.ru", "phone": "+70675203159"}
0005433568552	99D028	0752 302704	VYACHESLAV NAZAROV	{"email": "nazarov-vyacheslav.06011982@postgrespro.ru", "phone": "+70804242643"}
0005433568553	99D028	7563 946202	IVAN ZAYCEV	{"email": "zaycev-i.121973@postgrespro.ru", "phone": "+70187068445"}
0005433568554	BD4BC5	7050 043642	NIKOLAY OSIPOV	{"email": "nikolayosipov051980@postgrespro.ru", "phone": "+70047352161"}
0005433568555	700EEF	5261 996102	DMITRIY PAVLOV	{"email": "d-pavlov_1982@postgrespro.ru", "phone": "+70237928424"}
0005433568556	F7E010	4938 137740	POLINA ANDREEVA	{"email": "andreevap_081965@postgrespro.ru", "phone": "+70431911601"}
0005433568557	2877F2	1992 624730	OKSANA TIKHONOVA	{"phone": "+70094812692"}
0005433568558	2877F2	0623 659797	KRISTINA KUZNECOVA	{"phone": "+70626635298"}
0005433568559	E94BAD	7512 895641	LIDIYA ZHURAVLEVA	{"phone": "+70235921490"}
0005433568560	773140	1454 861081	ELENA STEPANOVA	{"email": "estepanova_23091981@postgrespro.ru", "phone": "+70660144534"}
0005433568561	436282	1972 411582	VLADIMIR RODIONOV	{"email": "rodionov_vladimir041978@postgrespro.ru", "phone": "+70415678026"}
0005433568562	436282	7456 774797	ROMAN ANDREEV	{"email": "andreev.roman-111981@postgrespro.ru", "phone": "+70628464312"}
0005433568563	FAB1D8	1047 959983	TIMOFEY ALEKSEEV	{"phone": "+70764575945"}
0005433568564	FAB1D8	5760 112640	RINAT DMITRIEV	{"email": "dmitriev.rinat011984@postgrespro.ru", "phone": "+70380239359"}
0005433568565	92D050	1284 675780	IRAIDA EFIMOVA	{"email": "efimovairaida061964@postgrespro.ru", "phone": "+70136968237"}
0005433568566	92D050	0540 197529	YULIYA KALININA	{"email": "kalininayuliya27071976@postgrespro.ru", "phone": "+70627545514"}
0005433568567	92D050	6967 597377	LIDIYA IVANOVA	{"email": "ivanoval081978@postgrespro.ru", "phone": "+70464562777"}
0005433568568	A8110B	4017 349473	VIKTOR KUZMIN	{"phone": "+70723778145"}
0005433568569	5AAE00	9553 845642	EKATERINA DAVYDOVA	{"email": "edavydova091962@postgrespro.ru", "phone": "+70384983574"}
0005433568570	5AAE00	6253 013053	IGOR IVANOV	{"email": "i.ivanov.07111976@postgrespro.ru", "phone": "+70480664916"}
0005433568571	7D1880	2554 633302	KLAVDIYA SMIRNOVA	{"phone": "+70675195563"}
0005433568572	EB082F	2971 803841	NATALYA POPOVA	{"email": "popova.n.1969@postgrespro.ru", "phone": "+70237295839"}
0005433568573	C532AB	8269 964630	KIRILL KUZMIN	{"email": "kuzmin.k-07071963@postgrespro.ru", "phone": "+70203239906"}
0005433568574	0AB089	3229 376604	RAISA LOGINOVA	{"email": "raisa_loginova_1967@postgrespro.ru", "phone": "+70092423557"}
0005433568575	79D7AA	5790 173610	VALERIY FEDOROV	{"email": "fedorov_valeriy-1973@postgrespro.ru", "phone": "+70171947476"}
0005433568576	79D7AA	3872 737256	MARIYA NAUMOVA	{"email": "m-naumova-30091970@postgrespro.ru", "phone": "+70416870346"}
0005433568577	3EE3D2	0020 026015	VYACHESLAV PAVLOV	{"email": "v-pavlov.091985@postgrespro.ru", "phone": "+70444727812"}
0005433568578	40663B	3863 769365	NINA BORISOVA	{"email": "borisova-nina.031986@postgrespro.ru", "phone": "+70388733423"}
0005433568579	56EE80	4156 522795	SERGEY KUZNECOV	{"phone": "+70522838751"}
0005433568580	A5B96B	9663 667115	ANNA PAVLOVA	{"phone": "+70426026550"}
0005433568581	868393	3240 124058	RUSTAM PAVLOV	{"phone": "+70545021047"}
0005433568582	69C5A0	2490 690606	LIDIYA KUZNECOVA	{"email": "l-kuznecova-061958@postgrespro.ru", "phone": "+70278322027"}
0005433568583	A324E0	8401 869255	DENIS EGOROV	{"phone": "+70939156084"}
0005433568584	7D4229	6672 492325	TATYANA BELOVA	{"email": "t-belova.07041977@postgrespro.ru", "phone": "+70165808092"}
0005433568585	2D46B7	2580 352986	EKATERINA KUDRYASHOVA	{"email": "e_kudryashova_1971@postgrespro.ru", "phone": "+70487841095"}
0005433568586	2D46B7	0396 003574	VALENTIN NOVIKOV	{"email": "valentinnovikov_1969@postgrespro.ru", "phone": "+70117775241"}
0005433568587	CF42B8	3088 126192	OLGA KUZNECOVA	{"phone": "+70091240437"}
0005433568588	CF42B8	3802 140019	VALENTINA IVANOVA	{"phone": "+70603238500"}
0005433568589	141235	9829 912959	TATYANA SCHERBAKOVA	{"phone": "+70627741231"}
0005433568590	86F272	3168 807667	YURIY SAVELEV	{"email": "savelev-yuriy-1961@postgrespro.ru", "phone": "+70637789686"}
0005433568591	765E9D	6608 125266	SERGEY KUZMIN	{"phone": "+70870971400"}
0005433568592	765E9D	9971 787139	YURIY POPOV	{"phone": "+70279882462"}
0005433568593	41EB91	0990 739859	EKATERINA KARPOVA	{"phone": "+70618974752"}
0005433568594	F28A54	1738 403792	RAISA OVCHINNIKOVA	{"email": "ovchinnikova-r.1971@postgrespro.ru", "phone": "+70740674753"}
0005433568595	F28A54	0096 996653	RAISA SOROKINA	{"email": "sorokina-raisa.07081974@postgrespro.ru", "phone": "+70753846658"}
0005433568596	15C5EE	1810 790568	EGOR ZHUKOV	{"email": "zhukov.e-1962@postgrespro.ru", "phone": "+70618625777"}
0005433568597	8CEAC8	4558 605430	SVETLANA MALYSHEVA	{"email": "svetlana.malysheva-1969@postgrespro.ru", "phone": "+70594778318"}
0005433568598	8CEAC8	1845 394187	TATYANA AFANASEVA	{"email": "afanaseva-t-1957@postgrespro.ru", "phone": "+70215892330"}
0005433568599	83F38D	1700 844059	TAMARA ROMANOVA	{"phone": "+70388739647"}
0005433568600	6724DD	5238 606755	VALENTINA AFANASEVA	{"phone": "+70501604893"}
0005433568601	F481F5	0372 424792	ZOYA DAVYDOVA	{"email": "davydova.z_31071971@postgrespro.ru", "phone": "+70981649150"}
0005433568602	F481F5	2460 484977	YAROSLAV SIDOROV	{"phone": "+70163908720"}
0005433568603	1EA18E	8850 538791	EVGENIY VASILEV	{"phone": "+70322616908"}
0005433568604	1EA18E	6875 677179	ANATOLIY KUZNECOV	{"phone": "+70964146120"}
0005433568605	ED7582	7221 755207	VLADIMIR FILIPPOV	{"phone": "+70509553535"}
0005433568606	6BFC38	9629 188854	LILIYA BORISOVA	{"email": "liliyaborisova-21031991@postgrespro.ru", "phone": "+70304497962"}
0005433568607	00DCE0	7521 092019	EKATERINA KUZNECOVA	{"phone": "+70764825094"}
0005433568608	00DCE0	9007 009319	ELENA SOKOLOVA	{"email": "sokolova_e10101972@postgrespro.ru", "phone": "+70556098445"}
0005433568609	CDC01A	4682 065314	ANDREY IVANOV	{"email": "a.ivanov_27051976@postgrespro.ru", "phone": "+70100697412"}
0005433568610	7FD5D1	2601 737863	NIKITA ISAEV	{"phone": "+70737806044"}
0005433568611	F9C885	3126 077853	EKATERINA MOISEEVA	{"email": "moiseevaekaterina25121974@postgrespro.ru", "phone": "+70004856197"}
0005433568612	C28660	6627 469208	EVGENIY DMITRIEV	{"phone": "+70731345918"}
0005433568613	C28660	1922 237553	ALLA KUZNECOVA	{"phone": "+70809984233"}
0005433568614	8D8C2A	2318 851279	ALEKSEY ILIN	{"email": "a.ilin-1970@postgrespro.ru", "phone": "+70940905487"}
0005433568615	8D8C2A	0470 835151	SOFIYA ZAKHAROVA	{"email": "sofiya-zakharova-071970@postgrespro.ru", "phone": "+70718954892"}
0005433568616	90D499	7393 983346	YULIYA NIKITINA	{"phone": "+70286752500"}
0005433568617	E84530	3002 038692	VALENTINA SOROKINA	{"phone": "+70145759186"}
0005433568618	618EC3	5093 389436	VLADIMIR MARTYNOV	{"email": "martynov_v1976@postgrespro.ru", "phone": "+70806492320"}
0005433568619	618EC3	7390 504675	MIKHAIL KUDRYASHOV	{"email": "kudryashovm_18021979@postgrespro.ru", "phone": "+70915152597"}
0005433568620	E4EDB1	7476 133591	VLADIMIR KAZAKOV	{"phone": "+70362491095"}
0005433568621	E4EDB1	8729 088408	VIKTOR VOROBEV	{"phone": "+70392658804"}
0005433568622	C88E38	3145 571017	GALINA TARASOVA	{"phone": "+70879280258"}
0005433568623	3B471D	2846 526694	TATYANA NIKIFOROVA	{"email": "nikiforova-tatyana.19031956@postgrespro.ru", "phone": "+70773314976"}
0005433568624	E889C5	6892 657101	ALEKSANDR KUZMIN	{"email": "kuzmin.a.041969@postgrespro.ru", "phone": "+70448024478"}
0005433568625	887BD7	0682 717992	GALINA MOROZOVA	{"phone": "+70434094069"}
0005433568626	887BD7	0495 115827	MAKSIM BELOV	{"email": "belov.maksim_1965@postgrespro.ru", "phone": "+70374030713"}
0005433568627	887BD7	9035 245356	ALEKSANDR VLASOV	{"email": "a-vlasov.1980@postgrespro.ru", "phone": "+70841024587"}
0005433568628	FF6674	9924 148095	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov.1969@postgrespro.ru", "phone": "+70093511483"}
0005433568806	07D56F	4821 093257	MIKHAIL DAVYDOV	{"phone": "+70434633834"}
0005433568629	FF6674	0030 965827	ALEKSANDR POPOV	{"email": "popov-a.31081969@postgrespro.ru", "phone": "+70068323129"}
0005433568630	FF6674	2843 138535	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov29041971@postgrespro.ru", "phone": "+70148963927"}
0005433568631	526524	1862 909692	SERGEY AFANASEV	{"email": "afanasevsergey-121973@postgrespro.ru", "phone": "+70838317754"}
0005433568632	7A57F7	9483 557817	OLEG PAVLOV	{"phone": "+70516194838"}
0005433568633	7A57F7	8736 161338	MARINA KUZMINA	{"email": "mkuzmina.1969@postgrespro.ru", "phone": "+70162597727"}
0005433568634	A2FFB1	5184 290030	OLGA EFREMOVA	{"email": "oefremova-1972@postgrespro.ru", "phone": "+70676532827"}
0005433568635	A2FFB1	2436 123826	DMITRIY MEDVEDEV	{"phone": "+70136923772"}
0005433568636	7BEE0A	9841 369502	MARIYA SOROKINA	{"email": "sorokinam.051972@postgrespro.ru", "phone": "+70037763812"}
0005433568637	4F9E4E	8980 527556	ANASTASIYA ANDREEVA	{"phone": "+70835701125"}
0005433568638	024C07	6288 644420	TATYANA MIKHAYLOVA	{"email": "mikhaylova.tatyana-071961@postgrespro.ru", "phone": "+70277107685"}
0005433568639	A99B13	2749 571450	LYUBOV PAVLOVA	{"phone": "+70805971889"}
0005433568640	A99B13	5400 341003	NIKOLAY SOKOLOV	{"email": "sokolov-n1980@postgrespro.ru", "phone": "+70109966258"}
0005433568641	DF7053	4206 122154	ALEKSANDR SCHERBAKOV	{"phone": "+70269648391"}
0005433568642	43966D	5103 897628	NATALYA TIKHONOVA	{"email": "tikhonova-natalya1973@postgrespro.ru", "phone": "+70903009576"}
0005433568643	A3D502	6317 073926	ALEKSANDRA STEPANOVA	{"phone": "+70018288394"}
0005433568644	45C037	9627 857923	LYUBOV TARASOVA	{"email": "tarasova_l_17081973@postgrespro.ru", "phone": "+70617055351"}
0005433568645	0BBE7A	9293 398473	SVETLANA BARANOVA	{"email": "baranova-svetlana_061980@postgrespro.ru", "phone": "+70955221631"}
0005433568646	CD1B36	9010 461272	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr1960@postgrespro.ru", "phone": "+70495531061"}
0005433568647	2FE031	0944 582955	LIDIYA CHERNOVA	{"phone": "+70652673219"}
0005433568648	2FE031	2483 560974	ANNA KAZAKOVA	{"phone": "+70572285160"}
0005433568649	DD3DB9	3549 299935	OLEG SIDOROV	{"email": "o_sidorov1978@postgrespro.ru", "phone": "+70127610521"}
0005433568650	DD3DB9	0295 175807	TATYANA FILIPPOVA	{"email": "t.filippova-1983@postgrespro.ru", "phone": "+70943636062"}
0005433568651	A05542	5980 616962	ZINAIDA NAZAROVA	{"phone": "+70491551276"}
0005433568652	5D6665	0058 586477	DAMIR SCHERBAKOV	{"email": "d.scherbakov091964@postgrespro.ru", "phone": "+70134802737"}
0005433568653	3BB58C	5996 553115	ILMIR DENISOV	{"phone": "+70021962108"}
0005433568654	1D2978	5731 119380	NATALYA ISAEVA	{"phone": "+70352859769"}
0005433568655	077185	4536 840041	DMITRIY VASILEV	{"email": "vasilev.d.051972@postgrespro.ru", "phone": "+70230089280"}
0005433568656	077185	3361 898760	ARTEM IVANOV	{"phone": "+70615215453"}
0005433568657	73F841	2733 376729	ALEKSEY SOLOVEV	{"email": "solovev_aleksey091963@postgrespro.ru", "phone": "+70365444321"}
0005433568658	CC8E5E	0641 327026	ALEKSANDR PAVLOV	{"email": "a.pavlov-1959@postgrespro.ru", "phone": "+70347454438"}
0005433568659	1F2BED	1532 367936	VIKTOR KOZLOV	{"phone": "+70367946391"}
0005433568660	4A5DE0	9198 171747	ALEKSANDR GERASIMOV	{"email": "agerasimov101977@postgrespro.ru", "phone": "+70497752536"}
0005433568661	4A5DE0	4746 455676	SEMEN SCHERBAKOV	{"email": "scherbakov.semen01051971@postgrespro.ru", "phone": "+70635459431"}
0005433568662	163784	6149 340598	MARIYA ZAKHAROVA	{"phone": "+70420720967"}
0005433568663	9CA6E8	2618 125394	VLADIMIR PETROV	{"email": "v.petrov.1979@postgrespro.ru", "phone": "+70615661544"}
0005433568664	515FB7	3826 449921	ZOYA FILIPPOVA	{"email": "z.filippova121969@postgrespro.ru", "phone": "+70238724382"}
0005433568665	0BCE2B	4808 425815	ANNA POPOVA	{"email": "popova_anna.1969@postgrespro.ru", "phone": "+70161438559"}
0005433568666	73F806	4974 450424	VASILIY FEDOROV	{"email": "vasiliy.fedorov_041975@postgrespro.ru", "phone": "+70065034383"}
0005433568667	725C75	9125 175259	ANDREY SOKOLOV	{"phone": "+70900584114"}
0005433568668	C23593	7096 596072	ANTONINA KRASNOVA	{"phone": "+70978321531"}
0005433568669	037DD7	5071 533120	ZINAIDA NIKIFOROVA	{"phone": "+70029904014"}
0005433568670	14B067	5826 998781	SERGEY OSIPOV	{"phone": "+70837476780"}
0005433568671	48025B	0144 368331	GENNADIY ANTONOV	{"phone": "+70469288985"}
0005433568672	48025B	3941 470936	VYACHESLAV BORISOV	{"phone": "+70273243841"}
0005433568673	60CD38	0753 669492	VYACHESLAV ALEKSANDROV	{"phone": "+70258854410"}
0005433568674	716166	1424 958371	ALEKSANDR KOZLOV	{"email": "akozlov031967@postgrespro.ru", "phone": "+70819555670"}
0005433568675	2EC2F0	4588 669913	LYUDMILA TIMOFEEVA	{"email": "timofeeva-lyudmila-13021963@postgrespro.ru", "phone": "+70590706427"}
0005433568676	732D2E	6748 228203	ANGELINA KUZMINA	{"email": "a_kuzmina.07091967@postgrespro.ru", "phone": "+70162181173"}
0005433568677	9161AA	5383 185370	LYUBOV NAZAROVA	{"email": "nazarova_lyubov12101984@postgrespro.ru", "phone": "+70913524053"}
0005433568678	2DBDFC	2784 532921	SHAMIL SEMENOV	{"phone": "+70227091541"}
0005433568679	58E208	0035 852471	GALINA EGOROVA	{"email": "egorovagalina.121968@postgrespro.ru", "phone": "+70686657080"}
0005433568680	905B35	4907 696023	VALENTINA SERGEEVA	{"email": "v-sergeeva_091977@postgrespro.ru", "phone": "+70907058399"}
0005433568681	7F970F	5170 381011	ALEKSANDR VASILEV	{"email": "vasileva.1956@postgrespro.ru", "phone": "+70375696143"}
0005433568682	37FF04	4069 635991	EKATERINA BORISOVA	{"email": "borisova.e.1985@postgrespro.ru", "phone": "+70144056306"}
0005433568683	68F424	5624 704586	VALENTINA KONDRATEVA	{"email": "valentina.kondrateva.101956@postgrespro.ru", "phone": "+70791737200"}
0005433568684	733F29	6671 846228	ANASTASIYA NAZAROVA	{"phone": "+70945170444"}
0005433568685	C2CF24	4454 470988	LYUDMILA KUZNECOVA	{"phone": "+70057234827"}
0005433568686	4C7173	6524 527394	GERMAN IVANOV	{"phone": "+70015075091"}
0005433568687	F00BAA	9259 011211	ANDREY ALEKSANDROV	{"phone": "+70462421766"}
0005433568688	0EABF2	5620 230957	ALENA BELYAEVA	{"email": "belyaeva_alena-091972@postgrespro.ru", "phone": "+70755956502"}
0005433568689	986BFD	3809 394275	ANATOLIY POPOV	{"email": "popovanatoliy121961@postgrespro.ru", "phone": "+70154801962"}
0005433568745	6A2696	4108 069947	ALEKSEY ROMANOV	{"phone": "+70266614087"}
0005433568690	A2DCE1	9057 784121	MAKSIM ALEKSANDROV	{"email": "maksim.aleksandrov_1973@postgrespro.ru", "phone": "+70904269299"}
0005433568691	24403B	3017 351402	LARISA NIKOLAEVA	{"email": "larisa.nikolaeva_031978@postgrespro.ru", "phone": "+70973829876"}
0005433568692	F5658C	8818 669937	DENIS BELOV	{"phone": "+70761576560"}
0005433568693	9E22FC	9461 779348	EVGENIY ZAYCEV	{"email": "zaycev.evgeniy_28081968@postgrespro.ru", "phone": "+70721819703"}
0005433568694	9E22FC	1945 699428	VITALIY RODIONOV	{"phone": "+70018155047"}
0005433568695	D8DB04	5062 788479	ANNA KUDRYASHOVA	{"email": "kudryashova-a.071971@postgrespro.ru", "phone": "+70169351825"}
0005433568696	09E6CB	5921 983853	OLGA NIKOLAEVA	{"email": "nikolaeva_o_101978@postgrespro.ru", "phone": "+70134271063"}
0005433568697	5963FE	0052 800455	NATALYA MALYSHEVA	{"email": "natalyamalysheva_1983@postgrespro.ru", "phone": "+70299417480"}
0005433568698	DDF86D	4531 961171	ANDREY FEDOTOV	{"email": "a_fedotov-04021974@postgrespro.ru", "phone": "+70367042487"}
0005433568699	E0D842	8561 158983	LYUDMILA POPOVA	{"email": "l_popova-091983@postgrespro.ru", "phone": "+70158378186"}
0005433568700	A245B9	6220 392588	SERGEY POPOV	{"phone": "+70932023506"}
0005433568701	C96E6C	2431 447930	ALEKSANDR RODIONOV	{"phone": "+70363788783"}
0005433568702	93BC73	4255 129634	ANATOLIY NIKITIN	{"phone": "+70388685651"}
0005433568703	6003B0	3751 346918	ALEKSEY IVANOV	{"phone": "+70183180726"}
0005433568704	F40E1E	9784 925572	ALEKSANDR ZAYCEV	{"email": "zaycev.aleksandr.061959@postgrespro.ru", "phone": "+70002289837"}
0005433568705	77118E	9016 081739	IVAN MAKAROV	{"phone": "+70102041321"}
0005433568706	77118E	1286 308816	SERGEY SHEVCHENKO	{"phone": "+70774706574"}
0005433568707	4D257D	2081 169656	VALENTINA VASILEVA	{"email": "vvasileva011965@postgrespro.ru", "phone": "+70081445173"}
0005433568708	4244FF	2694 684210	ALEKSANDR IVANOV	{"phone": "+70211123899"}
0005433568709	4244FF	3383 503675	NADEZHDA BOGDANOVA	{"phone": "+70356321848"}
0005433568710	6EE7A6	5247 643725	SVETLANA PAVLOVA	{"email": "svetlana-pavlova_14091981@postgrespro.ru", "phone": "+70069895530"}
0005433568711	B986F3	1360 264987	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov.031973@postgrespro.ru", "phone": "+70055288202"}
0005433568712	BB62A8	7782 576244	ANNA KOZLOVA	{"email": "kozlova.anna.02021964@postgrespro.ru", "phone": "+70055814099"}
0005433568713	BB62A8	2838 709223	VLADIMIR NIKOLAEV	{"email": "nikolaev.v-12091978@postgrespro.ru", "phone": "+70578096108"}
0005433568714	0F81EA	6664 649783	ANGELINA ABRAMOVA	{"email": "abramovaa041975@postgrespro.ru", "phone": "+70653018508"}
0005433568715	155866	0376 384503	DMITRIY GUSEV	{"phone": "+70356028395"}
0005433568716	C8170B	7689 488308	ELENA POLYAKOVA	{"email": "polyakova_e.07071959@postgrespro.ru", "phone": "+70475825633"}
0005433568717	CD4CA1	0130 748539	SVETLANA GUSEVA	{"phone": "+70215162347"}
0005433568718	F6AA04	9535 018824	IGOR SOKOLOV	{"email": "sokolov-i_16111970@postgrespro.ru", "phone": "+70849146480"}
0005433568719	D43FDA	4553 489534	VERA MOROZOVA	{"phone": "+70096731058"}
0005433568720	D43FDA	7043 033372	VLADIMIR MAKAROV	{"email": "makarovv_1966@postgrespro.ru", "phone": "+70112343118"}
0005433568721	8267B1	4062 716458	LYUBOV POPOVA	{"email": "lpopova-1970@postgrespro.ru", "phone": "+70828204799"}
0005433568722	FFF9DD	4131 994457	VIKTOR SAVELEV	{"phone": "+70717828655"}
0005433568723	592500	0007 138220	EKATERINA FEDOROVA	{"email": "fedorova-e_1970@postgrespro.ru", "phone": "+70226328427"}
0005433568724	592500	7580 826041	GALINA VLASOVA	{"email": "vlasova_galina.1971@postgrespro.ru", "phone": "+70979651068"}
0005433568725	48D735	0942 188174	ANDREY BELOV	{"phone": "+70187772745"}
0005433568726	0B9165	1424 067053	VALENTINA NOVIKOVA	{"phone": "+70912589038"}
0005433568727	0B9165	4093 612303	ROMAN MAKAROV	{"email": "makarov-roman111971@postgrespro.ru", "phone": "+70341398100"}
0005433568728	0366FA	8836 476144	VENERA VASILEVA	{"phone": "+70015953198"}
0005433568729	DA871F	4966 326836	NIKOLAY BELOV	{"email": "belov-n101962@postgrespro.ru", "phone": "+70470779262"}
0005433568730	4A84EF	9040 473168	ANASTASIYA DANILOVA	{"phone": "+70373454184"}
0005433568731	F65348	3548 888942	NIKOLAY IVANOV	{"phone": "+70301683128"}
0005433568732	B78D41	3567 565196	VYACHESLAV KUZMIN	{"phone": "+70166709531"}
0005433568733	73E900	2183 284462	SVETLANA VASILEVA	{"phone": "+70380594565"}
0005433568734	73E900	8931 342395	MARIYA FROLOVA	{"phone": "+70988958348"}
0005433568735	28E189	1324 190380	MARIYA FILIPPOVA	{"email": "m_filippova_04091959@postgrespro.ru", "phone": "+70837652910"}
0005433568736	28E189	4660 129530	ALEKSANDR OSIPOV	{"email": "aosipov-02031966@postgrespro.ru", "phone": "+70105036536"}
0005433568737	E3309B	7827 771692	ANTON GERASIMOV	{"phone": "+70944951321"}
0005433568738	57CF81	9695 381581	NIKOLAY MAKAROV	{"email": "makarov-nikolay05121971@postgrespro.ru", "phone": "+70870431768"}
0005433568739	A8CD0A	3632 908978	MARIYA VLASOVA	{"email": "vlasova_mariya061964@postgrespro.ru", "phone": "+70159777937"}
0005433568740	584121	5571 742599	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.1978@postgrespro.ru", "phone": "+70777972349"}
0005433568741	F4AA8A	3084 894607	DARYA KUZNECOVA	{"email": "d_kuznecova_18091974@postgrespro.ru", "phone": "+70278870015"}
0005433568742	F4AA8A	0865 220794	SVETLANA GAVRILOVA	{"email": "gavrilovas-21101970@postgrespro.ru", "phone": "+70163745506"}
0005433568743	E592E5	0099 625551	NATALYA FILATOVA	{"email": "filatova.natalya121976@postgrespro.ru", "phone": "+70310429289"}
0005433568744	D38683	0271 710338	FEDOR PAVLOV	{"email": "pavlov-fedor_30091982@postgrespro.ru", "phone": "+70211647545"}
0005433568746	E76896	1792 575576	YULIYA KUZNECOVA	{"phone": "+70411763014"}
0005433568747	2BC3C8	3884 461660	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda-051969@postgrespro.ru", "phone": "+70143530438"}
0005433568748	2BC3C8	9204 006717	SHAVKAT NOVIKOV	{"phone": "+70043369604"}
0005433568749	6A9E06	5199 647298	VERA OVCHINNIKOVA	{"phone": "+70704849939"}
0005433568750	A7B0CC	5177 546973	ELENA IVANOVA	{"email": "elenaivanova-06031966@postgrespro.ru", "phone": "+70186647999"}
0005433568751	A7B0CC	6279 389236	YULIYA MAKSIMOVA	{"phone": "+70064756659"}
0005433568752	A7B0CC	7732 977359	ANTONINA MOROZOVA	{"phone": "+70880963893"}
0005433568753	A7B0CC	1261 669364	VLADIMIR ANDREEV	{"email": "andreev.vladimir021965@postgrespro.ru", "phone": "+70686601604"}
0005433568754	44952C	5584 270387	VALENTINA ABRAMOVA	{"phone": "+70530099312"}
0005433568755	44952C	0864 751422	NIKOLAY PAVLOV	{"email": "n_pavlov.1969@postgrespro.ru", "phone": "+70043263142"}
0005433568756	4FBF91	0771 481721	PETR ILIN	{"email": "petrilin-20081968@postgrespro.ru", "phone": "+70145923907"}
0005433568757	4FBF91	1559 091906	NIKOLAY FILIPPOV	{"phone": "+70657580511"}
0005433568758	9C0AE9	4472 036896	GALINA ORLOVA	{"phone": "+70701329820"}
0005433568759	9C0AE9	9997 047125	NATALYA MELNIKOVA	{"email": "melnikova_n-111975@postgrespro.ru", "phone": "+70184966233"}
0005433568760	E7E8F8	4568 190437	VLADIMIR VASILEV	{"email": "vasilev_v23031979@postgrespro.ru", "phone": "+70891381826"}
0005433568761	0D5CB5	9291 402221	ILYA DENISOV	{"email": "denisov.ilya061969@postgrespro.ru", "phone": "+70403852951"}
0005433568762	0D5CB5	5181 253338	NIKOLAY DAVYDOV	{"email": "nikolay_davydov.071980@postgrespro.ru", "phone": "+70795657522"}
0005433568763	ACC330	8313 705321	ELENA ILINA	{"email": "ilinae_101977@postgrespro.ru", "phone": "+70773156845"}
0005433568764	ACC330	8632 286621	LYUDMILA ORLOVA	{"email": "lyudmilaorlova.111980@postgrespro.ru", "phone": "+70763435058"}
0005433568765	ACC330	3131 425445	EKATERINA IVANOVA	{"email": "ivanovaekaterina071984@postgrespro.ru", "phone": "+70592726307"}
0005433568766	B78B63	6985 473436	DENIS ANTONOV	{"email": "denis.antonov03051980@postgrespro.ru", "phone": "+70871188213"}
0005433568767	212131	4188 813291	SERGEY IVANOV	{"phone": "+70831465135"}
0005433568768	B87D43	6551 585820	ANDREY DMITRIEV	{"phone": "+70170931044"}
0005433568769	2D7A93	0995 285255	MAKSIM ABRAMOV	{"phone": "+70884228737"}
0005433568770	E80A8E	8309 246975	DMITRIY KONOVALOV	{"email": "dmitriy-konovalov.031964@postgrespro.ru", "phone": "+70809097634"}
0005433568771	E80A8E	2535 851717	EKATERINA PETROVA	{"email": "e-petrova13081972@postgrespro.ru", "phone": "+70581190103"}
0005433568772	9EAC8B	3188 467124	ANTONINA OVCHINNIKOVA	{"phone": "+70020513776"}
0005433568773	3F4D71	7656 277096	VASILIY GUSEV	{"email": "gusev.v1972@postgrespro.ru", "phone": "+70383429130"}
0005433568774	967D2D	8018 086887	MAKSIM ROMANOV	{"phone": "+70014689786"}
0005433568775	E91AC9	6382 325574	VYACHESLAV DAVYDOV	{"phone": "+70042219969"}
0005433568776	E91AC9	8654 616904	ALEKSANDR IVANOV	{"email": "aleksandrivanov1971@postgrespro.ru", "phone": "+70406947360"}
0005433568777	3A4AEE	8006 311024	VALENTINA ZAYCEVA	{"phone": "+70678098310"}
0005433568778	3A4AEE	8990 067939	TAMARA BARANOVA	{"phone": "+70206920331"}
0005433568779	995465	7162 939305	VALERIY POPOV	{"email": "popov_v-19101963@postgrespro.ru", "phone": "+70630022549"}
0005433568780	014AD6	1897 679294	ALLA PETROVA	{"email": "petrovaalla091980@postgrespro.ru", "phone": "+70454973528"}
0005433568781	014AD6	9972 686421	MARIYA IVANOVA	{"phone": "+70972078498"}
0005433568782	5BC0DE	7988 713755	KONSTANTIN KISELEV	{"phone": "+70394384494"}
0005433568783	5BC0DE	7274 281313	ELENA ZAKHAROVA	{"phone": "+70802802832"}
0005433568784	15ED31	8448 186519	VALENTINA FEDOROVA	{"email": "fedorova-v.28101977@postgrespro.ru", "phone": "+70187103209"}
0005433568785	754FC7	2891 003494	ALEKSEY OSIPOV	{"email": "aleksey-osipov12121983@postgrespro.ru", "phone": "+70157622343"}
0005433568786	754FC7	7128 255401	LYUDMILA NAZAROVA	{"email": "lyudmilanazarova_1964@postgrespro.ru", "phone": "+70853970556"}
0005433568787	795CC1	7823 257118	EVGENIY MARTYNOV	{"email": "evgeniymartynov101980@postgrespro.ru", "phone": "+70966968722"}
0005433568788	795CC1	0720 545717	TATYANA NIKITINA	{"email": "tnikitina1965@postgrespro.ru", "phone": "+70838465444"}
0005433568789	505AAE	5151 054547	NINA NIKOLAEVA	{"phone": "+70274438965"}
0005433568790	12DD11	7396 803668	NIKOLAY FEDOROV	{"email": "fedorov.nikolay-1966@postgrespro.ru", "phone": "+70494864297"}
0005433568791	EF3810	9585 272473	NINA NIKITINA	{"email": "n.nikitina_1974@postgrespro.ru", "phone": "+70023865083"}
0005433568792	EF3810	4723 436024	MAKSIM ZAKHAROV	{"email": "zakharov-m1963@postgrespro.ru", "phone": "+70117791921"}
0005433568793	78EFDE	5489 889666	SERGEY KUDRYASHOV	{"phone": "+70586287384"}
0005433568794	78EFDE	1456 299950	MARIYA VOLKOVA	{"email": "mariya-volkova_27041970@postgrespro.ru", "phone": "+70462235579"}
0005433568795	FAAEF3	1499 874351	TATYANA ORLOVA	{"phone": "+70876886782"}
0005433568796	2A972A	7276 490760	SVETLANA CHERNOVA	{"email": "chernova-s-28021984@postgrespro.ru", "phone": "+70051277324"}
0005433568797	ED6099	1747 592257	ANZHELIKA ANDREEVA	{"email": "a-andreeva_021986@postgrespro.ru", "phone": "+70456810472"}
0005433568798	ED6099	2286 058923	VLADIMIR RODIONOV	{"email": "v.rodionov_1970@postgrespro.ru", "phone": "+70338298886"}
0005433568799	6D5AE1	8743 746121	ANDREY SAVELEV	{"phone": "+70570116728"}
0005433568800	ABD410	2432 162830	OLGA ZAKHAROVA	{"phone": "+70404704460"}
0005433568801	60FDB4	1207 667764	LYUDMILA SIDOROVA	{"phone": "+70395120551"}
0005433568802	CF1CF0	7675 598696	KONSTANTIN NIKOLAEV	{"phone": "+70727154218"}
0005433568803	554202	4533 765604	MIKHAIL IVANOV	{"email": "mikhail.ivanov.22021965@postgrespro.ru", "phone": "+70528406021"}
0005433568804	554202	6582 780526	ANDREY SIDOROV	{"email": "sidorova_121978@postgrespro.ru", "phone": "+70021110378"}
0005433568805	69E896	8036 201279	ANNA NIKIFOROVA	{"email": "nikiforova_a_061973@postgrespro.ru", "phone": "+70199922139"}
0005433568807	7303F3	8178 068758	VLADIMIR KRASNOV	{"phone": "+70713076617"}
0005433568808	A3F46F	1667 979587	NIKOLAY MELNIKOV	{"email": "melnikov-nikolay-1972@postgrespro.ru", "phone": "+70525730426"}
0005433568809	217036	8828 134408	VALENTINA KOVALEVA	{"email": "kovalevavalentina_1967@postgrespro.ru", "phone": "+70835298820"}
0005433568810	7C3A8D	3814 210085	NAILYA KULIKOVA	{"phone": "+70042113824"}
0005433568811	294872	4344 765731	LIDIYA SOKOLOVA	{"phone": "+70234471164"}
0005433568812	B93C27	8940 433613	VIKTOR KULIKOV	{"phone": "+70553292696"}
0005433568813	147476	2423 194199	ALFIYA ISAEVA	{"email": "isaevaalfiya-1983@postgrespro.ru", "phone": "+70192183621"}
0005433568814	147476	6056 018132	SERGEY BARANOV	{"email": "sergey_baranov.11111975@postgrespro.ru", "phone": "+70703339895"}
0005433568815	191577	7621 556294	PAVEL SERGEEV	{"phone": "+70835209701"}
0005433568816	191577	7768 223394	MARIYA OVCHINNIKOVA	{"phone": "+70886816484"}
0005433568817	191577	6011 523688	SVETLANA MAKSIMOVA	{"phone": "+70955580215"}
0005433568818	191577	5333 358644	EVGENIY IVANOV	{"email": "evgeniy.ivanov.1974@postgrespro.ru", "phone": "+70353089447"}
0005433568819	2D6B84	4297 228265	ALEKSANDR KULIKOV	{"phone": "+70007933617"}
0005433568820	2D6B84	8471 455045	NINA BORISOVA	{"phone": "+70614501592"}
0005433568821	DFB731	6852 649447	ALBINA DAVYDOVA	{"phone": "+70612146484"}
0005433568822	BBB3BA	6026 728423	SOFYA KONOVALOVA	{"email": "sofya-konovalova-09061968@postgrespro.ru", "phone": "+70225209290"}
0005433568823	4F3361	5197 845285	VYACHESLAV KOROLEV	{"email": "korolev-vyacheslav-1971@postgrespro.ru", "phone": "+70676153973"}
0005433568824	ECB63B	7262 468054	SERGEY IVANOV	{"phone": "+70074522882"}
0005433568825	ECB63B	9524 228631	ALEKSANDR STEPANOV	{"email": "aleksandrstepanov1961@postgrespro.ru", "phone": "+70067771479"}
0005433568826	CBCCE4	2567 460865	OLGA MIRONOVA	{"email": "o.mironova101966@postgrespro.ru", "phone": "+70903353435"}
0005433568827	85A423	1887 931748	MARIYA TIKHONOVA	{"email": "tikhonovam-121976@postgrespro.ru", "phone": "+70976690503"}
0005433568828	F22CA6	8829 647267	SERGEY NOVIKOV	{"email": "s_novikov-09091974@postgrespro.ru", "phone": "+70397423878"}
0005433568829	F22CA6	9943 749212	NATALYA ARKHIPOVA	{"email": "natalyaarkhipova.111987@postgrespro.ru", "phone": "+70859769565"}
0005433568830	F22CA6	1872 576176	VLADIMIR ALEKSEEV	{"phone": "+70376685362"}
0005433568831	8BF944	1476 203959	TATYANA ARKHIPOVA	{"phone": "+70023483495"}
0005433568832	8BF944	2000 279857	VIKTORIYA SEMENOVA	{"email": "semenovav1972@postgrespro.ru", "phone": "+70726986334"}
0005433568833	468CC2	8822 954167	ALEKSEY POPOV	{"phone": "+70881501441"}
0005433568834	428D66	5167 235776	LYUBOV MATVEEVA	{"phone": "+70434806549"}
0005433568890	4C9CF2	6308 208117	ELENA KOMAROVA	{"phone": "+70551227492"}
0005433568835	428D66	0522 311172	NATALIYA KRASNOVA	{"email": "krasnova_n.20121964@postgrespro.ru", "phone": "+70002540738"}
0005433568836	C78289	1000 879185	LIDIYA FROLOVA	{"phone": "+70566888796"}
0005433568837	CF4E12	7711 220269	NATALYA ALEKSEEVA	{"email": "alekseeva_n1961@postgrespro.ru", "phone": "+70792807477"}
0005433568838	CF4E12	3292 478299	NINA TITOVA	{"email": "nina.titova091971@postgrespro.ru", "phone": "+70749189857"}
0005433568839	4AC4E6	5056 519099	VALERIY GORBUNOV	{"phone": "+70231436026"}
0005433568840	4AC4E6	8759 948421	YANA TROFIMOVA	{"email": "yana.trofimova091971@postgrespro.ru", "phone": "+70700418720"}
0005433568841	DA8807	8714 859329	VASILIY DAVYDOV	{"phone": "+70900271129"}
0005433568842	58B868	7277 794297	NIKOLAY NIKITIN	{"email": "n-nikitin.101973@postgrespro.ru", "phone": "+70714406046"}
0005433568843	58B868	9578 064459	EKATERINA KUZMINA	{"email": "ekaterinakuzmina.17121979@postgrespro.ru", "phone": "+70313925209"}
0005433568844	558FD5	4666 260001	DMITRIY FEDOTOV	{"phone": "+70533402279"}
0005433568845	558FD5	5380 550289	LEONID AFANASEV	{"phone": "+70158104452"}
0005433568846	558FD5	9793 674191	MARIYA MAKAROVA	{"email": "m.makarova.08011961@postgrespro.ru", "phone": "+70314097730"}
0005433568847	DA199C	7987 427860	OLESYA KUZMINA	{"email": "olesya.kuzmina-1980@postgrespro.ru", "phone": "+70767092853"}
0005433568848	B64174	4685 482600	ARTEM EGOROV	{"phone": "+70142183240"}
0005433568849	E6F314	5875 572672	OLEG MELNIKOV	{"phone": "+70855091602"}
0005433568850	E6F314	9550 420558	BORIS DMITRIEV	{"email": "dmitriev.boris.1981@postgrespro.ru", "phone": "+70287097453"}
0005433568851	7FDA76	3409 311204	ALFIYA EFREMOVA	{"email": "efremova.alfiya_1974@postgrespro.ru", "phone": "+70838221999"}
0005433568852	7FDA76	5254 093075	KLARA ZOTOVA	{"email": "zotova.klara15051968@postgrespro.ru", "phone": "+70009716192"}
0005433568853	9A107D	3879 217237	MIKHAIL SERGEEV	{"phone": "+70872849279"}
0005433568854	74AD9F	0088 983910	LIDIYA MARTYNOVA	{"phone": "+70699396953"}
0005433568855	3E318F	9223 741893	VLADIMIR IVANOV	{"phone": "+70227814781"}
0005433568856	BDACE8	7617 813389	NIKOLAY KUZMIN	{"phone": "+70742501081"}
0005433568857	BDACE8	1244 406431	SABINA KOMAROVA	{"email": "komarova.s12121973@postgrespro.ru", "phone": "+70419750145"}
0005433568858	E9FEE9	9674 196462	NATALYA SERGEEVA	{"email": "sergeevanatalya1978@postgrespro.ru", "phone": "+70661784883"}
0005433568859	E9FEE9	4975 893089	VASILIY ZAYCEV	{"email": "vasiliy-zaycev071966@postgrespro.ru", "phone": "+70766820548"}
0005433568860	8EAABE	1962 895506	OLGA TITOVA	{"phone": "+70924916006"}
0005433568861	C86CCB	2016 009539	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy.31121971@postgrespro.ru", "phone": "+70481443725"}
0005433568862	4047C4	0089 671836	NADEZHDA EFIMOVA	{"phone": "+70184549359"}
0005433568863	F7B19B	3769 730113	YURIY IVANOV	{"email": "yuriyivanov-18101976@postgrespro.ru", "phone": "+70794462516"}
0005433568864	F7B19B	5161 691435	MAKSIM MOROZOV	{"email": "morozov_m.081969@postgrespro.ru", "phone": "+70335861858"}
0005433568865	F7B19B	4198 270889	SERGEY IVANOV	{"email": "s.ivanov.101962@postgrespro.ru", "phone": "+70896007109"}
0005433568866	C5B597	7641 191011	ALEKSEY PETROV	{"phone": "+70712835632"}
0005433568867	503943	7306 793688	VIKTORIYA KOVALEVA	{"phone": "+70371049558"}
0005433568868	A301A2	1886 861811	MARINA MAKSIMOVA	{"phone": "+70394022187"}
0005433568869	A14514	0021 125760	TATYANA KUZMINA	{"phone": "+70366939845"}
0005433568870	0362AB	4596 125276	OLEG BORISOV	{"phone": "+70740660649"}
0005433568871	1149D7	5499 121928	ALISA ROMANOVA	{"email": "alisaromanova.101977@postgrespro.ru", "phone": "+70852377963"}
0005433568872	70F4A2	4867 156328	SOFYA LAZAREVA	{"email": "s.lazareva06051974@postgrespro.ru", "phone": "+70512953366"}
0005433568873	AE25BF	5056 562426	TAMARA ZHUKOVA	{"email": "zhukovat_091970@postgrespro.ru", "phone": "+70011298045"}
0005433568874	BB1723	5420 766946	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr-1986@postgrespro.ru", "phone": "+70134293239"}
0005433568875	BB1723	3782 945634	NIKOLAY PAVLOV	{"email": "pavlov_n_24081961@postgrespro.ru", "phone": "+70691864018"}
0005433568876	9CE177	0877 385688	LYUBOV SERGEEVA	{"email": "l-sergeeva.29101963@postgrespro.ru", "phone": "+70844958845"}
0005433568877	0C95BD	1439 309795	MARIYA KUZNECOVA	{"email": "kuznecovamariya_1963@postgrespro.ru", "phone": "+70932727248"}
0005433568878	075FB7	5079 262412	RAMIL NAUMOV	{"email": "naumovramil-1966@postgrespro.ru", "phone": "+70178921202"}
0005433568879	075FB7	3636 174371	ANNA BELYAEVA	{"email": "a_belyaeva-021981@postgrespro.ru", "phone": "+70034710743"}
0005433568880	E00EDF	1201 845736	ELENA KARPOVA	{"email": "karpova.e.1960@postgrespro.ru", "phone": "+70331046550"}
0005433568881	2766F2	9436 080371	ANTON MELNIKOV	{"email": "melnikov-anton_11061966@postgrespro.ru", "phone": "+70711985510"}
0005433568882	ECC677	7863 778682	ELENA NIKITINA	{"phone": "+70652500697"}
0005433568883	ECC677	7160 091526	SERGEY NOVIKOV	{"email": "novikov.sergey1966@postgrespro.ru", "phone": "+70614519584"}
0005433568884	C5D3CD	3173 030361	ALEKSEY ZAYCEV	{"phone": "+70259491566"}
0005433568885	C5D3CD	5117 035286	ALEKSANDR PETROV	{"phone": "+70584713314"}
0005433568886	E24ADC	3645 589838	GALINA ILINA	{"phone": "+70383982141"}
0005433568887	7F6B14	0249 193606	LILIYA OVCHINNIKOVA	{"email": "l_ovchinnikova_091970@postgrespro.ru", "phone": "+70873718515"}
0005433568888	7F6B14	6497 348471	RITA ILINA	{"email": "ilina-rita.121969@postgrespro.ru", "phone": "+70246171406"}
0005433568889	D8D072	4864 805117	VIKTOR BONDARENKO	{"email": "bondarenko_viktor1972@postgrespro.ru", "phone": "+70783710943"}
0005433568891	4C9CF2	7727 241236	ANNA VOLKOVA	{"phone": "+70536900466"}
0005433568892	4C9CF2	7015 349849	VALERIY ZAKHAROV	{"phone": "+70122624981"}
0005433568893	6196E6	1657 404776	VIKTOR SOLOVEV	{"phone": "+70770746734"}
0005433568894	6196E6	5216 144858	SERGEY ZAKHAROV	{"phone": "+70373829447"}
0005433568895	867F6A	6685 173693	VASILIY OSIPOV	{"email": "osipov.vasiliy02081982@postgrespro.ru", "phone": "+70473833255"}
0005433568896	97CEED	6591 044922	MARGARITA KISELEVA	{"email": "kiseleva_margarita_02011989@postgrespro.ru", "phone": "+70457458743"}
0005433568897	84020C	3648 668719	ARTEM IVANOV	{"email": "ivanova.1965@postgrespro.ru", "phone": "+70007168648"}
0005433568898	73A53B	2261 387868	GALINA NESTEROVA	{"phone": "+70792767838"}
0005433568899	73A53B	2066 480369	NIKITA IVANOV	{"email": "ivanov-n23101979@postgrespro.ru", "phone": "+70497991078"}
0005433568900	73A53B	7198 754900	SERGEY RODIONOV	{"email": "rodionov-s.081980@postgrespro.ru", "phone": "+70579325171"}
0005433568901	861D53	8955 385222	VIKTOR YAKOVLEV	{"email": "viktor_yakovlev.1959@postgrespro.ru", "phone": "+70573684683"}
0005433568902	861D53	1322 820540	ALEVTINA KUDRYASHOVA	{"phone": "+70837965682"}
0005433568903	522BD1	0065 329652	OLGA DAVYDOVA	{"phone": "+70904805303"}
0005433568904	522BD1	9998 615067	SVETLANA ROMANOVA	{"email": "romanova_s1966@postgrespro.ru", "phone": "+70109399439"}
0005433568905	522BD1	0204 078295	OLGA ZAYCEVA	{"email": "zayceva-o_041966@postgrespro.ru", "phone": "+70802450729"}
0005433568906	09AC70	5121 221406	TIMOFEY ROMANOV	{"email": "romanov.t.051981@postgrespro.ru", "phone": "+70221512317"}
0005433568907	09AC70	7700 472000	VALERIY ZAYCEV	{"email": "valeriy-zaycev_1968@postgrespro.ru", "phone": "+70451693897"}
0005433568908	C76720	2150 455740	ARINA ARKHIPOVA	{"phone": "+70942949710"}
0005433568909	466F0B	4467 213173	NADEZHDA VOLKOVA	{"phone": "+70344525127"}
0005433568910	466F0B	0007 013183	RUSLAN BELOV	{"phone": "+70995986175"}
0005433568911	A3F127	1878 380432	VASILIY ANTONOV	{"email": "v-antonov11071964@postgrespro.ru", "phone": "+70037206614"}
0005433568912	061F28	9346 106245	VIKTORIYA KUZNECOVA	{"phone": "+70506746457"}
0005433568913	CF9D86	3594 004360	RASHID IVANOV	{"phone": "+70113168707"}
0005433568914	CF9D86	0173 474683	TATYANA GORBUNOVA	{"phone": "+70485948771"}
0005433568915	4CA8EF	3388 422513	NIKOLAY BORISOV	{"email": "borisovnikolay_111962@postgrespro.ru", "phone": "+70481783973"}
0005433568916	2465B4	4431 354040	VYACHESLAV CHERNOV	{"phone": "+70936132061"}
0005433568917	2EC2C8	2767 496172	ARTEMIY EGOROV	{"email": "artemiy.egorov_06011981@postgrespro.ru", "phone": "+70316882859"}
0005433568918	29D3C2	1897 167343	VIKTOR ORLOV	{"phone": "+70128594577"}
0005433568919	2B98C3	4723 691756	VLADIMIR SAVELEV	{"email": "savelev_vladimir-101971@postgrespro.ru", "phone": "+70194741239"}
0005433568920	F6D839	3624 996623	PRASKOVYA MAKAROVA	{"phone": "+70316109665"}
0005433568921	2783BC	6999 084452	NIKOLAY MAKSIMOV	{"phone": "+70204064808"}
0005433568922	1BC8B2	7806 058722	ANTON ALEKSEEV	{"phone": "+70447102902"}
0005433568923	F4E12D	4729 821426	YULIYA OSIPOVA	{"email": "osipova.y.15071963@postgrespro.ru", "phone": "+70707322578"}
0005433568924	F4E12D	8555 340192	NADEZHDA MIRONOVA	{"email": "mironovanadezhda.15111961@postgrespro.ru", "phone": "+70360972072"}
0005433568925	8112AB	7644 958398	KLAVDIYA KALININA	{"email": "k-kalinina-091972@postgrespro.ru", "phone": "+70488324784"}
0005433568926	59BE00	5499 384754	LYUDMILA ILINA	{"email": "ilinal1967@postgrespro.ru", "phone": "+70529118455"}
0005433568927	B61A30	7833 414119	ALEKSANDR KUZNECOV	{"phone": "+70643744959"}
0005433568928	B61A30	1713 381213	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr.23071977@postgrespro.ru", "phone": "+70333434933"}
0005433568929	27C733	6025 647737	TAISIYA VOLKOVA	{"phone": "+70039672989"}
0005433568930	8B6D5E	0773 453895	MARINA KUZMINA	{"email": "marina.kuzmina1976@postgrespro.ru", "phone": "+70567739353"}
0005433568931	131118	1852 455309	SVETLANA LAZAREVA	{"email": "lazareva.s-1971@postgrespro.ru", "phone": "+70387423870"}
0005433568932	131118	9018 893210	KRISTINA ILINA	{"email": "ilinak02061968@postgrespro.ru", "phone": "+70232195519"}
0005433568933	8FA8BC	7910 055587	SOFIYA FOMINA	{"email": "fomina_sofiya11111965@postgrespro.ru", "phone": "+70222478126"}
0005433568934	FF1F90	2022 740259	LYUBOV IVANOVA	{"phone": "+70835870770"}
0005433568935	319D17	2611 654559	EKATERINA GERASIMOVA	{"email": "gerasimovaekaterina21111961@postgrespro.ru", "phone": "+70173588230"}
0005433568936	319D17	9146 685145	NIKOLAY KARPOV	{"phone": "+70295596792"}
0005433568937	319D17	2404 005263	TATYANA SMIRNOVA	{"phone": "+70693625944"}
0005433568938	781B3A	2512 004586	ALESYA PAVLOVA	{"email": "pavlova.a1972@postgrespro.ru", "phone": "+70066898050"}
0005433568939	36CFB3	9015 560412	ALEKSEY EGOROV	{"phone": "+70292100870"}
0005433568940	98DF1B	5315 278020	ALEKSANDR ABRAMOV	{"phone": "+70084892066"}
0005433568941	DD21F9	1444 002347	IRINA KOROLEVA	{"email": "irina_koroleva-101973@postgrespro.ru", "phone": "+70775619696"}
0005433568942	614CA6	1224 460061	ANTON MAKAROV	{"email": "amakarov_1982@postgrespro.ru", "phone": "+70908097796"}
0005433568943	93EA27	5221 670202	ELENA KUZNECOVA	{"email": "kuznecovae031973@postgrespro.ru", "phone": "+70526692035"}
0005433568944	D5BFA0	7597 195340	IRINA KUZNECOVA	{"email": "i_kuznecova-011968@postgrespro.ru", "phone": "+70075807217"}
0005433568945	86711C	9147 298291	ANDREY GAVRILOV	{"email": "andreygavrilov_12111980@postgrespro.ru", "phone": "+70771185164"}
0005433568946	93B16C	2745 402637	SERGEY KUZMIN	{"email": "s_kuzmin.041968@postgrespro.ru", "phone": "+70648827518"}
0005433568947	93B16C	0354 017736	ALEKSANDR POPOV	{"email": "aleksandr.popov_061984@postgrespro.ru", "phone": "+70107551884"}
0005433568948	485729	0677 885766	VALERIY BORISOV	{"phone": "+70806409118"}
0005433568949	A1D371	4007 443996	ROMAN MAKSIMOV	{"phone": "+70681032111"}
0005433568950	7D31E5	2526 593516	VSEVOLOD KUZNECOV	{"email": "v-kuznecov-01011966@postgrespro.ru", "phone": "+70476778879"}
0005433568951	1ECA26	3776 468426	LIDIYA KUZNECOVA	{"phone": "+70751760627"}
0005433568952	C9BACF	0987 567104	ANGELINA SOKOLOVA	{"phone": "+70604946815"}
0005433568953	C9BACF	1575 262410	TAMARA FEDOROVA	{"email": "tfedorova-101958@postgrespro.ru", "phone": "+70545495293"}
0005433568954	877BB6	0797 938069	NATALYA POPOVA	{"email": "popova.n_1976@postgrespro.ru", "phone": "+70474875266"}
0005433568955	217A9C	6260 951501	NATALYA OVCHINNIKOVA	{"phone": "+70793161926"}
0005433568956	16FADA	5847 243200	GALINA KOVALEVA	{"email": "g_kovaleva061979@postgrespro.ru", "phone": "+70130470370"}
0005433568957	16FADA	8496 460421	TATYANA YUDINA	{"phone": "+70305443380"}
0005433568958	9803B8	6410 408563	EVGENIY GERASIMOV	{"email": "gerasimovevgeniy.1966@postgrespro.ru", "phone": "+70206678166"}
0005433568959	C9976B	7189 350396	EVGENIY NAZAROV	{"email": "nazarov.e-16081968@postgrespro.ru", "phone": "+70154436633"}
0005433568960	79DD2F	7628 217684	ELENA AKIMOVA	{"email": "akimova-elena1971@postgrespro.ru", "phone": "+70571127047"}
0005433568961	AE5513	5341 379103	LYUBOV BELYAEVA	{"email": "belyaeva.l-18121963@postgrespro.ru", "phone": "+70665022928"}
0005433568962	875185	7899 711963	ANASTASIYA CHERNOVA	{"email": "anastasiya_chernova.051967@postgrespro.ru", "phone": "+70191627725"}
0005433568963	2DFA68	3736 325259	VITALIY IVANOV	{"email": "ivanov-vitaliy041984@postgrespro.ru", "phone": "+70477582475"}
0005433568964	7A8745	1495 816502	OLGA IVANOVA	{"email": "o_ivanova.021980@postgrespro.ru", "phone": "+70020518402"}
0005433568965	7A8745	0481 423405	ALINA VLASOVA	{"email": "alina.vlasova.06071972@postgrespro.ru", "phone": "+70046036887"}
0005433568966	FD6461	0571 948062	NIKOLAY KUDRYASHOV	{"phone": "+70797023699"}
0005433568967	760945	3014 890532	LYUBOV ZHURAVLEVA	{"email": "l-zhuravleva.1983@postgrespro.ru", "phone": "+70835203983"}
0005433568968	8C7B50	8977 343089	TATYANA SMIRNOVA	{"email": "tatyanasmirnova-1964@postgrespro.ru", "phone": "+70531684230"}
0005433568969	4493BA	9060 312781	GALINA TITOVA	{"email": "titovagalina_1972@postgrespro.ru", "phone": "+70669303576"}
0005433568970	4493BA	3910 711724	VYACHESLAV MOISEEV	{"phone": "+70862051362"}
0005433568971	8795F3	5039 990747	GALINA AFANASEVA	{"email": "galinaafanaseva.061986@postgrespro.ru", "phone": "+70840155022"}
0005433568972	68C249	9982 983996	DENIS CHERNOV	{"email": "chernovdenis081977@postgrespro.ru", "phone": "+70288115981"}
0005433568973	071473	3415 252153	KONSTANTIN KAZAKOV	{"email": "k-kazakov.24091979@postgrespro.ru", "phone": "+70606492324"}
0005433568974	9AC905	3919 611558	ALEKSANDR TIKHONOV	{"phone": "+70761117734"}
0005433568975	9AC905	1416 719974	VLADIMIR IVANOV	{"phone": "+70363915397"}
0005433568976	62DCFB	2806 175792	ANASTASIYA TARASOVA	{"email": "anastasiyatarasova_17061959@postgrespro.ru", "phone": "+70187669289"}
0005433568977	62DCFB	5241 755920	ALEKSANDR ZAYCEV	{"email": "zaycev-a04091976@postgrespro.ru", "phone": "+70966808144"}
0005433568978	62DCFB	2144 568075	IGOR SOLOVEV	{"phone": "+70455962107"}
0005433568979	6AAB85	5400 939740	LARISA TIKHONOVA	{"email": "tikhonova-larisa-101977@postgrespro.ru", "phone": "+70118171590"}
0005433568980	6AAB85	1250 112867	IRINA NIKOLAEVA	{"phone": "+70073336451"}
0005433568981	55D008	0548 836623	LYUBOV EGOROVA	{"phone": "+70426474854"}
0005433568982	4C42D4	0305 269055	NIKOLAY DENISOV	{"email": "denisov-n.1961@postgrespro.ru", "phone": "+70601088394"}
0005433568983	E1EC6E	1279 770174	ARTEM EGOROV	{"phone": "+70419644576"}
0005433568984	FEB8F2	4133 437564	RASIM SOLOVEV	{"phone": "+70738842755"}
0005433568985	C66232	9601 261750	SERGEY KULIKOV	{"phone": "+70952805506"}
0005433568986	C66232	5875 510582	SERGEY FEDOROV	{"email": "fedorov_sergey-041970@postgrespro.ru", "phone": "+70382876299"}
0005433568987	5274F0	4481 412832	ELENA MELNIKOVA	{"phone": "+70095419287"}
0005433568988	BACE05	4981 759783	DMITRIY FEDOROV	{"phone": "+70132048156"}
0005433568989	BACE05	1379 046157	OLGA ALEKSANDROVA	{"phone": "+70561013994"}
0005433568990	BACE05	8513 114688	NATALYA MATVEEVA	{"email": "natalya-matveeva-04011963@postgrespro.ru", "phone": "+70669020974"}
0005433568991	16BF9E	3470 356501	SERGEY IVANOV	{"email": "sivanov101963@postgrespro.ru", "phone": "+70255953432"}
0005433568992	BFC3F5	2011 540040	REGINA GERASIMOVA	{"email": "gerasimovaregina.081980@postgrespro.ru", "phone": "+70687064868"}
0005433568993	BFC3F5	9204 576468	NATALYA AFANASEVA	{"phone": "+70220605194"}
0005433568994	18E545	4183 687328	ELENA POPOVA	{"phone": "+70308358140"}
0005433568995	F940A5	8025 068045	ALEKSANDR POPOV	{"phone": "+70404346075"}
0005433568996	0E18FB	0614 399571	ZLATA TROFIMOVA	{"email": "z_trofimova1980@postgrespro.ru", "phone": "+70472513268"}
0005433568997	0E18FB	1893 952371	LYUBOV NIKOLAEVA	{"email": "lyubov_nikolaeva_061959@postgrespro.ru", "phone": "+70370681921"}
0005433568998	78A79B	0927 801214	DMITRIY KUZMIN	{"email": "d_kuzmin.06041970@postgrespro.ru", "phone": "+70976852024"}
0005433568999	70053B	3268 148201	ELENA KONOVALOVA	{"email": "konovalova_elena1964@postgrespro.ru", "phone": "+70161103840"}
0005433569000	D4B537	0383 629453	EVGENIY KAZAKOV	{"phone": "+70535194292"}
0005433569001	D4B537	9956 966476	KSENIYA IVANOVA	{"phone": "+70872913119"}
0005433569002	FB42F2	8456 662254	SVETLANA ISAEVA	{"phone": "+70533797648"}
0005433569003	7BEEE1	5516 607209	LIDIYA KALININA	{"email": "kalininalidiya28061971@postgrespro.ru", "phone": "+70568553915"}
0005433569004	7BEEE1	9705 819234	TATYANA ZAKHAROVA	{"phone": "+70493229533"}
0005433569005	BFB18D	8862 538356	ELENA CHERNOVA	{"phone": "+70501018568"}
0005433569006	A54DE2	9651 080046	LARISA KUZNECOVA	{"phone": "+70081924639"}
0005433569007	BEBAE7	6799 445365	SVETLANA PAVLOVA	{"email": "pavlova-s.041971@postgrespro.ru", "phone": "+70426545949"}
0005433569008	BEBAE7	8689 608317	EVGENIYA VOLKOVA	{"email": "volkova-evgeniya1968@postgrespro.ru", "phone": "+70411544671"}
0005433569009	69AD2C	3074 756051	ELENA CHERNOVA	{"phone": "+70199494722"}
0005433569010	69AD2C	8088 962384	NIKOLAY DMITRIEV	{"phone": "+70804261805"}
0005433569011	DB787C	6880 731337	ELIZAVETA LOGINOVA	{"phone": "+70550354671"}
0005433569012	31CF8C	1393 939912	GALINA VOROBEVA	{"email": "vorobeva-g.19101967@postgrespro.ru", "phone": "+70429358964"}
0005433569013	906975	1372 450983	NADEZHDA KUZNECOVA	{"phone": "+70406862879"}
0005433569014	67D81B	3153 037341	VIKTOR ZHURAVLEV	{"phone": "+70565461708"}
0005433569015	67D81B	9593 907832	OLGA KULIKOVA	{"phone": "+70181811872"}
0005433569016	676411	1833 561729	IRINA ANTONOVA	{"email": "antonova.irina091973@postgrespro.ru", "phone": "+70420566730"}
0005433569017	676411	4634 059715	LEONID IVANOV	{"phone": "+70947875723"}
0005433569018	F3D6FF	2093 186420	SERGEY MEDVEDEV	{"email": "s.medvedev-28121977@postgrespro.ru", "phone": "+70721494315"}
0005433569019	C3E78A	6809 910092	ILDUS VOLKOV	{"email": "ildusvolkov-011977@postgrespro.ru", "phone": "+70137826892"}
0005433569020	AC9EB4	9871 529608	SOFYA ZAKHAROVA	{"email": "zakharova.s-1962@postgrespro.ru", "phone": "+70328158133"}
0005433569021	AC9EB4	7383 666154	NATALIYA EGOROVA	{"phone": "+70798421660"}
0005433569022	AC9EB4	7017 515519	VIKTOR NIKITIN	{"email": "v-nikitin111970@postgrespro.ru", "phone": "+70676823515"}
0005433569023	EF76C6	6112 942850	ALEKSANDR POPOV	{"email": "popov-aleksandr021971@postgrespro.ru", "phone": "+70933365942"}
0005433569024	10EAC5	9745 040667	EVGENIY MAKSIMOV	{"email": "e-maksimov.1973@postgrespro.ru", "phone": "+70332070783"}
0005433569025	3262DC	3153 005937	KLAVDIYA KISELEVA	{"phone": "+70507406269"}
0005433569026	F7C502	5242 944985	ALINA NESTEROVA	{"email": "alinanesterova051958@postgrespro.ru", "phone": "+70734256671"}
0005433569027	FA5BED	5412 220189	ZINAIDA TIKHONOVA	{"email": "tikhonova_zinaida.19111976@postgrespro.ru", "phone": "+70843354684"}
0005433569028	FA5BED	3792 754209	ANASTASIYA KUZNECOVA	{"phone": "+70221419654"}
0005433569029	3CB4BA	6432 053585	PETR DENISOV	{"email": "petrdenisov_1977@postgrespro.ru", "phone": "+70640431207"}
0005433569030	BFCCB9	8351 113878	OKSANA KRASNOVA	{"email": "krasnova-oksana_1971@postgrespro.ru", "phone": "+70162899806"}
0005433569031	6920B9	5195 679306	FAINA DMITRIEVA	{"phone": "+70476787739"}
0005433569032	DF1CDA	8436 548946	LYUDMILA ALEKSEEVA	{"email": "lyudmilaalekseeva-30121968@postgrespro.ru", "phone": "+70201993807"}
0005433569033	0D1281	9695 017828	ANNA TIMOFEEVA	{"phone": "+70581220506"}
0005433569034	815B23	3912 900625	ALEKSANDR ISAEV	{"email": "aleksandr-isaev.1978@postgrespro.ru", "phone": "+70573759684"}
0005433569035	815B23	0956 202487	IGOR SOROKIN	{"phone": "+70084651517"}
0005433569036	97D848	7666 201269	DMITRIY SAVELEV	{"phone": "+70827728712"}
0005433569037	97D848	7997 123567	NATALYA SOLOVEVA	{"email": "soloveva_natalya24101979@postgrespro.ru", "phone": "+70004347225"}
0005433569038	76B328	2604 085249	PAVEL DENISOV	{"phone": "+70314877509"}
0005433569039	23D334	4187 132818	ANDREY ANTONOV	{"email": "antonova-12071986@postgrespro.ru", "phone": "+70698186268"}
0005433569040	474477	2532 731973	SOFYA ROMANOVA	{"phone": "+70020238752"}
0005433569041	B593B5	3789 978982	ALEKSANDR ZHURAVLEV	{"phone": "+70054104804"}
0005433569042	B593B5	6456 672852	IVAN NIKOLAEV	{"phone": "+70741439141"}
0005433569043	697E36	8556 939176	ALEKSANDR ZHURAVLEV	{"phone": "+70621455774"}
0005433569044	644615	2000 455662	ILYA OSIPOV	{"phone": "+70771850316"}
0005433569045	644615	0124 783897	LYUDMILA SEMENOVA	{"email": "semenovalyudmila.1973@postgrespro.ru", "phone": "+70680756227"}
0005433569046	B2A8C4	8603 101255	ALEKSANDR BORISOV	{"phone": "+70697805228"}
0005433569047	EA6EB1	8746 290827	ELMIRA KUZMINA	{"email": "e.kuzmina_021977@postgrespro.ru", "phone": "+70284650205"}
0005433569048	EA6EB1	7846 084081	ANNA BELYAEVA	{"phone": "+70302022839"}
0005433569049	0F786A	7736 229113	PETR POPOV	{"phone": "+70936139189"}
0005433569050	0F786A	6269 624094	PETR IVANOV	{"email": "ivanov-petr.29111970@postgrespro.ru", "phone": "+70547530303"}
0005433569051	56B285	0056 635514	VIKTORIYA NIKOLAEVA	{"email": "vnikolaeva_1971@postgrespro.ru", "phone": "+70973120523"}
0005433569052	BFB659	0406 594559	NINA VLASOVA	{"email": "vlasovanina041985@postgrespro.ru", "phone": "+70960178667"}
0005433569053	BFB659	0409 554636	VLADISLAV ANDREEV	{"email": "v.andreev.091981@postgrespro.ru", "phone": "+70541509079"}
0005433569054	BAB000	7942 601010	ELIZAVETA VOLKOVA	{"phone": "+70561369108"}
0005433569055	0EB1A4	9540 910483	NURIYA KRASNOVA	{"phone": "+70178638867"}
0005433569056	0EB1A4	4733 334790	VALENTINA KOMAROVA	{"email": "v_komarova1980@postgrespro.ru", "phone": "+70972258515"}
0005433569057	D1E059	0905 917473	NIKOLAY MOISEEV	{"phone": "+70531081798"}
0005433569058	C6132D	4673 222355	YURIY NAUMOV	{"phone": "+70031567650"}
0005433569059	C6132D	0296 010513	TATYANA BELOVA	{"email": "t_belova20081968@postgrespro.ru", "phone": "+70905657387"}
0005433569060	CE0BE2	0516 798429	ZAKHAR KUZNECOV	{"email": "zakhar.kuznecov-1974@postgrespro.ru", "phone": "+70805486844"}
0005433569061	1BFDA9	0862 978119	VLADIMIR ALEKSANDROV	{"email": "valeksandrov.1971@postgrespro.ru", "phone": "+70528132704"}
0005433569062	70B0B3	8028 410044	RAUF KUDRYASHOV	{"email": "kudryashov_r_031966@postgrespro.ru", "phone": "+70380538318"}
0005433569063	446341	5393 977603	DMITRIY VOLKOV	{"email": "volkov_d.1966@postgrespro.ru", "phone": "+70891400668"}
0005433569064	5C1B56	1324 025409	ZINAIDA ANTONOVA	{"email": "zinaida-antonova-021984@postgrespro.ru", "phone": "+70432781588"}
0005433569065	B67CDD	4259 141048	LYUBOV KRASNOVA	{"phone": "+70083113819"}
0005433569066	B67CDD	5256 678678	OLGA KOROLEVA	{"email": "o_koroleva.101967@postgrespro.ru", "phone": "+70188902016"}
0005433569067	7CD75A	7849 921711	ANNA DMITRIEVA	{"phone": "+70898984644"}
0005433569068	360CE0	3928 854884	NIKOLAY SHEVCHENKO	{"phone": "+70368727854"}
0005433569069	2CD735	5264 305174	PAVEL VOLKOV	{"phone": "+70950831289"}
0005433569070	B49E57	7467 345785	LYUDMILA ZAKHAROVA	{"email": "zakharoval.1978@postgrespro.ru", "phone": "+70564509681"}
0005433569071	380B68	9435 547762	SERGEY BORISOV	{"phone": "+70834509549"}
0005433569072	A40003	7947 889367	SERGEY GRIGOREV	{"email": "grigorev_s-21031971@postgrespro.ru", "phone": "+70049259933"}
0005433569073	FA00A6	4213 951188	GALINA TARASOVA	{"email": "galina-tarasova-15021972@postgrespro.ru", "phone": "+70157007437"}
0005433569074	FA00A6	8138 435101	SOFYA MAKAROVA	{"phone": "+70641306118"}
0005433569075	A3320A	1467 803089	VERA BELOVA	{"phone": "+70295110726"}
0005433569076	A3320A	3392 732673	VALERIY KRASNOV	{"phone": "+70403476412"}
0005433569077	8943A2	2137 967675	PAVEL KOZLOV	{"email": "pavelkozlov.041970@postgrespro.ru", "phone": "+70940967392"}
0005433569078	8943A2	5136 715528	VIKTORIYA VLASOVA	{"phone": "+70090579550"}
0005433569079	41AC25	9877 322353	ANTON VASILEV	{"phone": "+70505579655"}
0005433569080	85DE6B	8614 865794	ALEKSANDR VOROBEV	{"phone": "+70338746630"}
0005433569081	056A42	0268 627963	OLGA MATVEEVA	{"phone": "+70193573864"}
0005433569082	056A42	2332 742779	TATYANA PETROVA	{"email": "petrova.t_18121982@postgrespro.ru", "phone": "+70909808776"}
0005433569083	AB0ACB	5978 950704	NIKOLAY TARASOV	{"email": "tarasov.n.11041964@postgrespro.ru", "phone": "+70812250353"}
0005433569084	DC1A73	5958 801073	ALLA PAVLOVA	{"email": "alla.pavlova.011977@postgrespro.ru", "phone": "+70053264247"}
0005433569085	31768A	9343 094743	ANDREY IVANOV	{"email": "andrey-ivanov_101971@postgrespro.ru", "phone": "+70021556204"}
0005433569086	8FC8B3	1296 238202	SERGEY ABRAMOV	{"phone": "+70118144635"}
0005433569087	22D2AF	0589 582553	DARYA ANDREEVA	{"email": "d_andreeva.07011985@postgrespro.ru", "phone": "+70772652333"}
0005433569088	1E5AA6	1318 925710	YULIYA KONDRATEVA	{"email": "kondratevay-09011980@postgrespro.ru", "phone": "+70116576973"}
0005433569089	1D6B31	2980 194119	MILANA KUZMINA	{"email": "kuzmina.m.021972@postgrespro.ru", "phone": "+70390921838"}
0005433569090	1D6B31	8531 957698	STEPAN KUZNECOV	{"email": "kuznecov.s.1976@postgrespro.ru", "phone": "+70171884486"}
0005433569091	9D8028	2566 320389	ELENA ARKHIPOVA	{"email": "arkhipova_elena_06111969@postgrespro.ru", "phone": "+70301970813"}
0005433569092	59FC27	8640 361189	EVGENIY POPOV	{"email": "evgeniy.popov_11011981@postgrespro.ru", "phone": "+70804049671"}
0005433569093	59FC27	5337 094979	ELENA ALEKSEEVA	{"email": "elena.alekseeva.021977@postgrespro.ru", "phone": "+70800606081"}
0005433569094	6D5FF9	6695 999580	EKATERINA MAKAROVA	{"email": "e-makarova021964@postgrespro.ru", "phone": "+70395632983"}
0005433569095	9ECE70	1949 586279	NINA ANISIMOVA	{"email": "anisimova_n.1973@postgrespro.ru", "phone": "+70429839986"}
0005433569096	F7AEF2	3063 938709	KAROLINA MATVEEVA	{"phone": "+70756705071"}
0005433569097	CB5122	7065 506970	MARIYA SCHERBAKOVA	{"email": "mscherbakova10031965@postgrespro.ru", "phone": "+70409431968"}
0005433569098	035542	1835 318939	AMINA ZHUKOVA	{"phone": "+70131246874"}
0005433569099	6BF609	4290 211096	VLADIMIR NAUMOV	{"email": "vladimir.naumov081969@postgrespro.ru", "phone": "+70098932725"}
0005433569100	CB2CE2	1994 052355	VLADIMIR PAVLOV	{"phone": "+70626656812"}
0005433569101	6ECC3C	5724 724806	NIKOLAY SOROKIN	{"email": "sorokin.nikolay-07031976@postgrespro.ru", "phone": "+70921423320"}
0005433569102	F87EED	1710 604810	ALEKSEY BARANOV	{"phone": "+70774985405"}
0005433569103	F87EED	3045 967931	MARIYA SERGEEVA	{"phone": "+70463857923"}
0005433569104	DD2E94	1339 897474	YULIYA FILATOVA	{"email": "y-filatova_1972@postgrespro.ru", "phone": "+70862181061"}
0005433569105	D5FD04	2588 448724	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr.20031971@postgrespro.ru", "phone": "+70168769887"}
0005433569106	D5FD04	2666 680279	RAISA YUDINA	{"phone": "+70540620828"}
0005433569107	6E10EC	7283 595345	OLGA SMIRNOVA	{"email": "smirnovaolga-011976@postgrespro.ru", "phone": "+70527707071"}
0005433569108	6E10EC	2699 692454	ROMAN KARPOV	{"email": "karpov_roman-06091965@postgrespro.ru", "phone": "+70646061366"}
0005433569109	3B0DA7	4099 252081	VLADIMIR FROLOV	{"email": "vfrolov_23121976@postgrespro.ru", "phone": "+70522943791"}
0005433569110	3B0DA7	8172 173840	YURIY KISELEV	{"email": "y.kiselev_27121971@postgrespro.ru", "phone": "+70901345605"}
0005433569111	D3C7EF	0756 104035	ARTEM ZAKHAROV	{"email": "zakharov_a091976@postgrespro.ru", "phone": "+70216479514"}
0005433569112	95572B	7492 272457	ALEKSANDR KOZLOV	{"phone": "+70768094519"}
0005433569113	95572B	9067 250902	SVETLANA STEPANOVA	{"phone": "+70426176084"}
0005433569114	95572B	1152 141131	EVGENIY KONOVALOV	{"email": "e_konovalov-1971@postgrespro.ru", "phone": "+70782703906"}
0005433569115	F3047F	9312 379397	EKATERINA ANTONOVA	{"phone": "+70761745393"}
0005433569116	F3047F	8835 072274	EVGENIYA ANDREEVA	{"phone": "+70934542976"}
0005433569117	3B69DE	8136 735284	INNA KALININA	{"email": "kalinina_i-1975@postgrespro.ru", "phone": "+70222480177"}
0005433569118	3B69DE	3161 299170	MIKHAIL PAVLOV	{"phone": "+70150815799"}
0005433569119	3B69DE	3638 655105	ALEKSANDR KRASNOV	{"email": "aleksandr_krasnov_19081981@postgrespro.ru", "phone": "+70196557683"}
0005433569120	800CCC	7195 914349	OLGA AKIMOVA	{"phone": "+70972263004"}
0005433569121	800CCC	5957 738728	SERGEY MIRONOV	{"phone": "+70019275134"}
0005433569122	0C115C	8690 080493	PAVEL BORISOV	{"phone": "+70462800308"}
0005433569123	04F21D	6100 447438	ELMIRA FADEEVA	{"email": "elmira-fadeeva.041960@postgrespro.ru", "phone": "+70387125072"}
0005433569124	249AC3	1191 227899	NATALIYA EGOROVA	{"phone": "+70567473491"}
0005433569125	4E9F41	7297 255066	LYUBOV KISELEVA	{"email": "kiseleva.lyubov-19031968@postgrespro.ru", "phone": "+70781658305"}
0005433569126	5C43AE	5325 612058	SERGEY KONOVALOV	{"phone": "+70300934757"}
0005433569127	67C4D2	5059 508574	YURIY OSIPOV	{"phone": "+70218784283"}
0005433569128	743999	1881 521188	MARIYA SIDOROVA	{"email": "mariyasidorova10101976@postgrespro.ru", "phone": "+70604148027"}
0005433569129	03FE57	2667 119617	VIKTOR BARANOV	{"phone": "+70128626771"}
0005433569130	807FBE	1384 846031	KSENIYA ZAKHAROVA	{"email": "kzakharova1978@postgrespro.ru", "phone": "+70450539683"}
0005433569131	807FBE	7921 520960	DMITRIY KULIKOV	{"phone": "+70655919228"}
0005433569132	8E2FA4	0020 936085	VYACHESLAV PAVLOV	{"phone": "+70095194573"}
0005433569133	8E2FA4	1090 312922	NIKOLAY GRIGOREV	{"email": "grigorevnikolay27111968@postgrespro.ru", "phone": "+70697934104"}
0005433569134	E34F78	7792 775137	ALEKSANDR KUZMIN	{"email": "kuzmin_a_21041978@postgrespro.ru", "phone": "+70257464244"}
0005433569135	EC040C	9911 167114	VYACHESLAV SAVELEV	{"email": "savelev.vyacheslav.1969@postgrespro.ru", "phone": "+70059899216"}
0005433569136	882DF4	4617 596431	ZINAIDA KUZMINA	{"phone": "+70814193007"}
0005433569137	882DF4	6561 324573	FILIPP RODIONOV	{"phone": "+70495308274"}
0005433569138	0EA8CC	4774 330201	SERGEY NOVIKOV	{"email": "novikov_s-27041973@postgrespro.ru", "phone": "+70129482606"}
0005433569139	B461DE	5444 253920	ELENA ZHURAVLEVA	{"email": "elena.zhuravleva_31051965@postgrespro.ru", "phone": "+70311317554"}
0005433569140	9631E6	9493 488322	MARINA TROFIMOVA	{"phone": "+70014490446"}
0005433569141	774925	6302 137559	IRINA IVANOVA	{"phone": "+70011094267"}
0005433569142	6F4F8C	3555 538375	VYACHESLAV SCHERBAKOV	{"email": "v.scherbakov-19091958@postgrespro.ru", "phone": "+70459862068"}
0005433569143	6F4F8C	0162 667586	ALFIYA KISELEVA	{"phone": "+70673643948"}
0005433569144	6BE0DE	5682 677606	PETR KOROLEV	{"phone": "+70973195765"}
0005433569145	6BE0DE	6754 927545	ALEKSANDR SMIRNOV	{"phone": "+70104887649"}
0005433569146	6BE0DE	5256 990254	OLGA PAVLOVA	{"email": "olga_pavlova.121971@postgrespro.ru", "phone": "+70608463355"}
0005433569147	5FCA2D	7998 640375	VERA ROMANOVA	{"email": "v.romanova_061977@postgrespro.ru", "phone": "+70159721935"}
0005433569148	7D2E42	7664 753406	VALERIY KOZLOV	{"email": "kozlov-v-23021978@postgrespro.ru", "phone": "+70789014452"}
0005433569149	6C04C0	1843 899576	NADEZHDA LEBEDEVA	{"email": "lebedeva_nadezhda23061968@postgrespro.ru", "phone": "+70095878710"}
0005433569150	251D77	9603 261023	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr_1968@postgrespro.ru", "phone": "+70496912975"}
0005433569151	7C3268	6805 606466	EVDOKIYA BELYAEVA	{"email": "belyaevaevdokiya-111967@postgrespro.ru", "phone": "+70421649985"}
0005433569152	43E1B1	7162 799651	OLEG BELOV	{"email": "olegbelov13061965@postgrespro.ru", "phone": "+70353058780"}
0005433569153	7AC659	7240 224540	ANFISA NIKOLAEVA	{"email": "nikolaeva.anfisa1982@postgrespro.ru", "phone": "+70780790799"}
0005433569154	690E0F	0747 757403	NADEZHDA ISAEVA	{"phone": "+70761449619"}
0005433569155	5F2644	3198 882988	ALEKSANDR FOMIN	{"email": "fomin-a_07031973@postgrespro.ru", "phone": "+70708350503"}
0005433569156	80FC9C	1145 813748	SERGEY KUZMIN	{"email": "kuzmin.s20021971@postgrespro.ru", "phone": "+70532971101"}
0005433569157	80FC9C	1897 760018	ALENA MATVEEVA	{"email": "a-matveeva101973@postgrespro.ru", "phone": "+70914687484"}
0005433569158	4A381C	6082 900506	NADEZHDA MATVEEVA	{"phone": "+70789820509"}
0005433569159	7E5906	4211 849592	VIKTOR PAVLOV	{"email": "pavlov_viktor_1976@postgrespro.ru", "phone": "+70774563052"}
0005433569160	7E5906	3912 923151	SVETLANA TIKHONOVA	{"email": "tikhonova.s-101968@postgrespro.ru", "phone": "+70314828694"}
0005433569161	7E5906	2551 222827	VLADIMIR SOKOLOV	{"email": "sokolovv.31031969@postgrespro.ru", "phone": "+70145102461"}
0005433569162	4439B2	5113 201144	ALEKSEY MAKAROV	{"phone": "+70650482374"}
0005433569163	4439B2	0207 514904	VLADIMIR SOLOVEV	{"email": "solovevv-041982@postgrespro.ru", "phone": "+70479732405"}
0005433569164	20861D	4701 606345	YURIY KOZLOV	{"phone": "+70740422175"}
0005433569165	1FD4C5	3856 823701	MAKSIM ZHURAVLEV	{"phone": "+70256897412"}
0005433569166	275486	3341 583008	NADEZHDA NIKOLAEVA	{"phone": "+70130445747"}
0005433569167	5BDAE0	5938 815984	RASHIT NOVIKOV	{"phone": "+70347590240"}
0005433569168	371A3D	3731 992870	RAISA NIKITINA	{"phone": "+70604453411"}
0005433569169	371A3D	9031 712426	VASILIY MAKAROV	{"email": "makarov.v_1976@postgrespro.ru", "phone": "+70374019249"}
0005433569170	4F946E	9420 211033	ALEKSEY SERGEEV	{"email": "aleksey-sergeev-03101968@postgrespro.ru", "phone": "+70211432928"}
0005433569171	EAA20F	4882 604012	ALBINA GORBUNOVA	{"phone": "+70210542390"}
0005433569172	BA5B92	5157 344708	ALEKSANDR PAVLOV	{"phone": "+70775592306"}
0005433569173	562E9B	0971 099749	EDUARD SCHERBAKOV	{"phone": "+70610499248"}
0005433569174	1CD990	3065 587984	TATYANA BORISOVA	{"email": "t-borisova_28081976@postgrespro.ru", "phone": "+70534479117"}
0005433569175	1CD990	9431 681605	NIKITA BORISOV	{"phone": "+70698592072"}
0005433569176	7CC904	3934 044178	SERGEY MAKAROV	{"email": "sergey_makarov.041987@postgrespro.ru", "phone": "+70595864796"}
0005433569177	6C597E	9859 036862	MAKSIM SOLOVEV	{"phone": "+70352068261"}
0005433569178	6C597E	3229 199905	VIKTOR ANDREEV	{"phone": "+70613684193"}
0005433569179	8761FF	7060 879323	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.25101972@postgrespro.ru", "phone": "+70134266078"}
0005433569180	829745	2004 996236	VASILIY ZHUKOV	{"phone": "+70263838673"}
0005433569181	8280FE	5806 533990	FARIT FEDOROV	{"email": "farit_fedorov-1966@postgrespro.ru", "phone": "+70907626346"}
0005433569182	403075	4133 281304	ANDREY SHEVCHENKO	{"phone": "+70896990598"}
0005433569183	403075	4471 693674	FARIT YAKOVLEV	{"phone": "+70078288359"}
0005433569184	CC33E6	8628 837855	MARGARITA MEDVEDEVA	{"phone": "+70508804681"}
0005433569185	CC33E6	5931 969850	TATYANA MAKAROVA	{"phone": "+70558947705"}
0005433569186	6043BE	2275 221450	LIDIYA KULIKOVA	{"phone": "+70773958802"}
0005433569187	B06710	5673 614068	NIKOLAY ANDREEV	{"email": "andreevn071981@postgrespro.ru", "phone": "+70415082272"}
0005433569188	81CD93	5560 284394	ELIZAVETA ABRAMOVA	{"email": "e-abramova_1986@postgrespro.ru", "phone": "+70065679674"}
0005433569189	F9136A	9087 307654	VLADISLAV TIMOFEEV	{"email": "timofeev-vladislav_12071975@postgrespro.ru", "phone": "+70280490500"}
0005433569190	96624F	6286 252733	ELENA ARKHIPOVA	{"email": "arkhipova_elena.22021965@postgrespro.ru", "phone": "+70699804471"}
0005433569191	96624F	1983 919918	ALEKSANDR MEDVEDEV	{"email": "a_medvedev091971@postgrespro.ru", "phone": "+70011861787"}
0005433569192	245B64	3322 209482	ROMAN KAZAKOV	{"phone": "+70588852527"}
0005433569193	94EE68	7776 387539	ANDREY EGOROV	{"phone": "+70418104528"}
0005433569194	37884F	9142 774917	VADIM KULIKOV	{"email": "kulikovvadim081967@postgrespro.ru", "phone": "+70392442015"}
0005433569195	37884F	3517 712724	ANTON VASILEV	{"phone": "+70807649438"}
0005433569196	593307	9112 765044	ELENA TARASOVA	{"phone": "+70868596159"}
0005433569197	593307	7555 312086	PAVEL KUZMIN	{"email": "kuzminpavel_25061982@postgrespro.ru", "phone": "+70527627193"}
0005433569198	1E3FC1	6976 138623	SERGEY SEMENOV	{"phone": "+70620266723"}
0005433569199	E9314A	4239 748568	EVGENIY GUSEV	{"email": "evgeniy-gusev_101967@postgrespro.ru", "phone": "+70817714210"}
0005433569200	E9314A	5825 904678	MAKSIM MOROZOV	{"email": "m.morozov_081969@postgrespro.ru", "phone": "+70138594121"}
0005433569201	7A15E9	7236 523468	ALEKSANDR IVANOV	{"phone": "+70473776569"}
0005433569202	36BE7F	9253 161892	MARIYA SMIRNOVA	{"phone": "+70631593987"}
0005433569203	36BE7F	8085 486755	ANTONINA MOISEEVA	{"phone": "+70868260361"}
0005433569204	56A282	4921 186018	IRINA POTAPOVA	{"email": "i_potapova.10051967@postgrespro.ru", "phone": "+70461431819"}
0005433569205	35A230	6928 353335	NADEZHDA EGOROVA	{"email": "nadezhda.egorova.071970@postgrespro.ru", "phone": "+70526461316"}
0005433569206	35A230	9304 003327	ARTEM KUZNECOV	{"email": "artem_kuznecov-121974@postgrespro.ru", "phone": "+70819026375"}
0005433569207	3A0B1F	4754 690207	GALINA EGOROVA	{"email": "galina.egorova-1972@postgrespro.ru", "phone": "+70991706216"}
0005433569208	01C36C	5843 542330	IOSIF SMIRNOV	{"email": "iosif.smirnov-071980@postgrespro.ru", "phone": "+70618213416"}
0005433569209	EAC80E	2934 762236	EKATERINA FILATOVA	{"email": "ekaterina.filatova-1968@postgrespro.ru", "phone": "+70284826837"}
0005433569210	3526D5	2219 757248	ELENA KULIKOVA	{"email": "ekulikova101969@postgrespro.ru", "phone": "+70175295000"}
0005433569211	3526D5	4636 109356	TATYANA BORISOVA	{"phone": "+70932898446"}
0005433569212	FD8535	1486 622488	IGOR KUZNECOV	{"email": "ikuznecov.1973@postgrespro.ru", "phone": "+70868519411"}
0005433569213	8AD039	3492 313820	ALINA MAKAROVA	{"email": "amakarova.081993@postgrespro.ru", "phone": "+70204236870"}
0005433569214	8AD039	8866 968791	OLESYA ZHUKOVA	{"email": "olesya_zhukova.1970@postgrespro.ru", "phone": "+70042620169"}
0005433569215	8AD039	7153 970137	ANATOLIY GORBUNOV	{"email": "a.gorbunov.041974@postgrespro.ru", "phone": "+70625897197"}
0005433569216	68454A	4691 731504	IVAN GERASIMOV	{"email": "ivan_gerasimov1971@postgrespro.ru", "phone": "+70844781254"}
0005433569217	CF5EED	3217 673181	VIKTOR ANDREEV	{"email": "andreevv081969@postgrespro.ru", "phone": "+70951356421"}
0005433569218	D8264C	7459 596694	OLEG ABRAMOV	{"email": "abramov.o.27121975@postgrespro.ru", "phone": "+70121886056"}
0005433569219	BEE49E	2136 956825	SERGEY ALEKSEEV	{"email": "alekseev-s29081969@postgrespro.ru", "phone": "+70851533854"}
0005433569220	BEE49E	6041 753369	GEORGIY NAUMOV	{"email": "gnaumov_1963@postgrespro.ru", "phone": "+70838219563"}
0005433569221	BEE49E	1600 343317	NIKITA GERASIMOV	{"phone": "+70964145248"}
0005433569222	9A7B38	2008 394576	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a_081971@postgrespro.ru", "phone": "+70386435518"}
0005433569223	D98B9B	4216 800280	SERGEY RODIONOV	{"phone": "+70295238036"}
0005433569224	D98B9B	5807 873245	VALENTINA ZAYCEVA	{"phone": "+70647701741"}
0005433569225	D98B9B	8644 854684	SVETLANA MOROZOVA	{"email": "s-morozova-1971@postgrespro.ru", "phone": "+70396985327"}
0005433569226	C36C72	2215 559096	VLADIMIR TIMOFEEV	{"phone": "+70393299923"}
0005433569227	40A40E	8038 074696	IRINA BELYAEVA	{"email": "i.belyaeva_1957@postgrespro.ru", "phone": "+70349369327"}
0005433569228	E7EDD3	4002 343236	KARINA ALEKSEEVA	{"email": "alekseeva-k.19091965@postgrespro.ru", "phone": "+70309206584"}
0005433569229	4203A3	2474 647449	PETR KRASNOV	{"phone": "+70844904565"}
0005433569230	8902C8	4024 713970	VLADIMIR MEDVEDEV	{"phone": "+70634642550"}
0005433569231	F1C3E3	9311 621530	ANASTASIYA KISELEVA	{"email": "kiselevaanastasiya031972@postgrespro.ru", "phone": "+70741497686"}
0005433569232	F1C3E3	6929 406331	ELIZAVETA DENISOVA	{"phone": "+70907467823"}
0005433569233	A0929E	7820 921315	ARTEM SEMENOV	{"email": "artem-semenov28091974@postgrespro.ru", "phone": "+70482623255"}
0005433569234	D582FE	3268 171438	ANATOLIY YAKOVLEV	{"phone": "+70833244415"}
0005433569235	A90D03	5248 719578	LYUDMILA DAVYDOVA	{"phone": "+70744036428"}
0005433569236	8A1981	7970 422490	MARAT ZHURAVLEV	{"phone": "+70592144149"}
0005433569237	F73178	9373 430852	FEDOR FEDOROV	{"phone": "+70109113976"}
0005433569238	C4A656	2675 161068	IRINA VASILEVA	{"email": "irina-vasileva_121966@postgrespro.ru", "phone": "+70634222683"}
0005433569239	BD71C1	4367 661129	FARIT KAZAKOV	{"email": "kazakov.farit_1979@postgrespro.ru", "phone": "+70046922474"}
0005433569240	BD71C1	3846 268621	ANATOLIY AFANASEV	{"email": "anatoliy.afanasev081973@postgrespro.ru", "phone": "+70126594799"}
0005433569241	4A3517	7775 157850	IRINA FADEEVA	{"phone": "+70726962937"}
0005433569242	37FE21	5244 691137	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir061977@postgrespro.ru", "phone": "+70983289447"}
0005433569243	37FE21	3687 153625	MAKSIM KRASNOV	{"email": "krasnov.maksim101980@postgrespro.ru", "phone": "+70791626089"}
0005433569244	3B6D93	9354 000082	SERGEY NIKITIN	{"email": "nikitin-sergey.11081971@postgrespro.ru", "phone": "+70478069821"}
0005433569245	3B6D93	9258 822292	VIKTOR MOISEEV	{"email": "moiseev_viktor20121960@postgrespro.ru", "phone": "+70319685329"}
0005433569246	A12DD5	5307 231236	SVETLANA KOVALEVA	{"email": "kovaleva.s.031966@postgrespro.ru", "phone": "+70246014000"}
0005433569247	A12DD5	4686 902095	ARINA TARASOVA	{"email": "tarasovaarina_15051970@postgrespro.ru", "phone": "+70212730820"}
0005433569248	D7DF34	1142 677263	NIKOLAY PETROV	{"phone": "+70231943558"}
0005433569249	D7DF34	4443 458279	VALENTINA KISELEVA	{"email": "kiselevav_1966@postgrespro.ru", "phone": "+70941583611"}
0005433569250	865EDD	9684 373238	ANATOLIY ILIN	{"email": "ilin-a_09121973@postgrespro.ru", "phone": "+70749435954"}
0005433569251	0264E8	5768 366537	ALEKSANDR ANTONOV	{"phone": "+70929431606"}
0005433569252	0264E8	9675 051732	LARISA EFIMOVA	{"email": "larisa.efimova1964@postgrespro.ru", "phone": "+70229114390"}
0005433569253	CEF082	7323 607024	NIKOLAY ALEKSANDROV	{"email": "naleksandrov.09091968@postgrespro.ru", "phone": "+70053036628"}
0005433569254	44F905	0379 399125	RENAT VOROBEV	{"phone": "+70133209807"}
0005433569255	A9E519	2451 507864	ALEKSANDR KUZNECOV	{"email": "a-kuznecov.1985@postgrespro.ru", "phone": "+70770337187"}
0005433569256	964D21	5941 785855	PELAGEYA KULIKOVA	{"email": "p-kulikova.061971@postgrespro.ru", "phone": "+70961053629"}
0005433569257	964D21	0922 777110	ALEKSEY SCHERBAKOV	{"email": "alekseyscherbakov_1963@postgrespro.ru", "phone": "+70535085569"}
0005433569258	8CCD01	8819 252217	TATYANA AKIMOVA	{"email": "akimova_tatyana-1968@postgrespro.ru", "phone": "+70115322093"}
0005433569259	302B66	0240 000888	YULIYA RODIONOVA	{"email": "rodionova_yuliya.1964@postgrespro.ru", "phone": "+70984794093"}
0005433569260	E2A193	4593 842371	BORIS KUZNECOV	{"email": "boriskuznecov1970@postgrespro.ru", "phone": "+70962172019"}
0005433569261	25ABE7	2730 756655	YULIYA KOZLOVA	{"phone": "+70733786971"}
0005433569262	25ABE7	5432 657605	MARIYA SIDOROVA	{"email": "sidorova-m-30091981@postgrespro.ru", "phone": "+70796845934"}
0005433569263	69BA1B	2442 362826	GALINA ZAKHAROVA	{"phone": "+70875628817"}
0005433569264	BAAD73	3970 508155	ALEKSEY EGOROV	{"phone": "+70957710385"}
0005433569265	BAAD73	4515 300346	OLGA NAZAROVA	{"phone": "+70838637534"}
0005433569266	6A268D	6467 497380	RAMIL GORBUNOV	{"email": "gorbunov_r-041966@postgrespro.ru", "phone": "+70542935547"}
0005433569267	A4DE9D	1078 106043	OLGA MASLOVA	{"email": "olga.maslova021980@postgrespro.ru", "phone": "+70889173690"}
0005433569268	328F0F	6357 583884	ALEKSANDR TIKHONOV	{"email": "tikhonov.aleksandr-04051968@postgrespro.ru", "phone": "+70934957035"}
0005433569269	C78E9F	6845 582709	EVGENIY ROMANOV	{"phone": "+70806328757"}
0005433569270	37ED1C	1614 978909	ELENA MOISEEVA	{"email": "e_moiseeva-1968@postgrespro.ru", "phone": "+70635301587"}
0005433569271	37ED1C	5458 123331	VERA PAVLOVA	{"email": "v_pavlova.07041969@postgrespro.ru", "phone": "+70237662875"}
0005433569272	20590B	8466 102609	EVGENIY KULIKOV	{"email": "kulikov-evgeniy-16031966@postgrespro.ru", "phone": "+70941673417"}
0005433569273	20590B	8062 283559	EVGENIY SOLOVEV	{"phone": "+70737734989"}
0005433569274	7917E8	7391 972685	MARINA MOISEEVA	{"email": "moiseeva.marina.1973@postgrespro.ru", "phone": "+70650638945"}
0005433569275	7917E8	3607 184298	ELENA DMITRIEVA	{"phone": "+70081850738"}
0005433569276	513A6C	1537 438645	VIKTOR ANTONOV	{"phone": "+70465747330"}
0005433569277	513A6C	8893 832306	RUSLAN DMITRIEV	{"phone": "+70559266547"}
0005433569278	B876DB	7803 887462	INNA SOKOLOVA	{"phone": "+70686756232"}
0005433569279	B876DB	5160 647889	SERGEY BELOV	{"phone": "+70384457014"}
0005433569280	57D588	0582 516550	ANDREY KUZNECOV	{"phone": "+70526387434"}
0005433569281	950214	1724 028068	ALEKSANDR SOKOLOV	{"phone": "+70246471016"}
0005433569282	E53CF7	6307 808470	DMITRIY FOMIN	{"email": "fomindmitriy_19051976@postgrespro.ru", "phone": "+70299990341"}
0005433569283	E53CF7	9033 693782	NIKOLAY SOKOLOV	{"email": "nsokolov-16111965@postgrespro.ru", "phone": "+70041411044"}
0005433569284	0DCD99	8384 104720	LILIYA ZAKHAROVA	{"email": "zakharova-liliya_061961@postgrespro.ru", "phone": "+70474175106"}
0005433569285	4CCF63	5992 686142	VERA FILIPPOVA	{"email": "filippova.v04051968@postgrespro.ru", "phone": "+70783328497"}
0005433569286	52D3F4	0525 673999	PAVEL SERGEEV	{"email": "pavel-sergeev.22081967@postgrespro.ru", "phone": "+70805169811"}
0005433569287	2CAA8B	7728 843738	NINA MALYSHEVA	{"email": "malysheva-n_121969@postgrespro.ru", "phone": "+70754853525"}
0005433569288	6CE8F7	6626 740262	LIDIYA NAUMOVA	{"email": "naumoval.27061974@postgrespro.ru", "phone": "+70681237318"}
0005433569289	F9BF7C	7502 280921	ALENA ZHUKOVA	{"email": "a-zhukova_1976@postgrespro.ru", "phone": "+70509099021"}
0005433569290	7EE7F9	6552 157851	NATALYA BELOVA	{"phone": "+70494563722"}
0005433569291	7EE7F9	4874 575672	OKSANA NIKITINA	{"phone": "+70133267907"}
0005433569292	8CEB1E	8783 399056	EKATERINA KOROLEVA	{"phone": "+70147064526"}
0005433569293	8CEB1E	2722 701354	ALEKSEY PAVLOV	{"phone": "+70042179860"}
0005433569294	8CEB1E	7267 545600	GALINA KULIKOVA	{"phone": "+70057640624"}
0005433569295	335112	5071 666513	MARIYA SEMENOVA	{"phone": "+70787379482"}
0005433569296	335112	9805 272253	MARINA ANDREEVA	{"email": "andreeva-marina-1967@postgrespro.ru", "phone": "+70003693845"}
0005433569297	AAB070	8908 942660	ALEKSANDR MEDVEDEV	{"email": "aleksandr.medvedev.051971@postgrespro.ru", "phone": "+70436861747"}
0005433569298	AB16F1	2254 739797	ALINA DAVYDOVA	{"phone": "+70514918563"}
0005433569299	7547E5	2743 988092	VALENTINA KUZMINA	{"phone": "+70352055613"}
0005433569300	5C1445	1176 534893	IGOR MIRONOV	{"email": "imironov-22061973@postgrespro.ru", "phone": "+70143460510"}
0005433569301	5C1445	2555 558572	EKATERINA MAKAROVA	{"phone": "+70540762310"}
0005433569302	DC25BD	0486 338069	IGOR POPOV	{"email": "igor_popov_31051980@postgrespro.ru", "phone": "+70996898110"}
0005433569303	75E29B	9582 477216	VLADIMIR ANTONOV	{"phone": "+70406776439"}
0005433569304	75E29B	4136 825806	IVAN MAKSIMOV	{"email": "maksimov.ivan.031979@postgrespro.ru", "phone": "+70153284465"}
0005433569305	8CBB77	3240 639437	ALENA KARPOVA	{"phone": "+70717848189"}
0005433569306	8CBB77	8021 087982	SVETLANA YAKOVLEVA	{"phone": "+70182150527"}
0005433569307	7E8158	8835 965800	VIKTOR SCHERBAKOV	{"phone": "+70628328736"}
0005433569308	1F3DE5	4426 489883	RAMIL MOROZOV	{"phone": "+70446204342"}
0005433569309	1F3DE5	4460 595708	ALEKSANDR DAVYDOV	{"email": "aleksandr_davydov_121963@postgrespro.ru", "phone": "+70974220454"}
0005433569310	119AA5	7201 609603	ALEKSANDR ABRAMOV	{"phone": "+70986906925"}
0005433569311	55A53E	6720 629849	ANTONINA BELOVA	{"email": "abelova1979@postgrespro.ru", "phone": "+70630271325"}
0005433569312	899100	6668 928309	NADEZHDA NIKITINA	{"email": "nikitinanadezhda-01121962@postgrespro.ru", "phone": "+70653757015"}
0005433569313	899100	0252 039169	TATYANA GUSEVA	{"email": "guseva.t.1981@postgrespro.ru", "phone": "+70106576665"}
0005433569314	8DEE7B	3937 425462	LARISA TITOVA	{"email": "l-titova-051976@postgrespro.ru", "phone": "+70758911045"}
0005433569315	8DEE7B	8302 459898	ANASTASIYA BOGDANOVA	{"phone": "+70435051618"}
0005433569316	6A2B7B	4935 031897	VLADIMIR POPOV	{"email": "popov.v_17031969@postgrespro.ru", "phone": "+70957850294"}
0005433569317	4EC62F	5841 312082	ILYA DMITRIEV	{"email": "i.dmitriev091972@postgrespro.ru", "phone": "+70275230307"}
0005433569318	2D9396	6608 697664	ELENA VASILEVA	{"phone": "+70208684520"}
0005433569319	3DCCC8	7787 905764	ANDREY BONDARENKO	{"phone": "+70903178593"}
0005433569320	73EE1A	2374 393173	VALENTINA MIRONOVA	{"phone": "+70965167627"}
0005433569321	73EE1A	1526 767501	VALENTINA MEDVEDEVA	{"email": "medvedeva.v18101972@postgrespro.ru", "phone": "+70109414292"}
0005433569322	F56F1A	7350 905910	VALENTINA SIDOROVA	{"email": "sidorova-valentina-1976@postgrespro.ru", "phone": "+70869178488"}
0005433569323	F56F1A	5860 066518	EVGENIY STEPANOV	{"phone": "+70916358720"}
0005433569324	E9C376	5138 239409	EDUARD MAKAROV	{"email": "makarov.eduard1967@postgrespro.ru", "phone": "+70880367199"}
0005433569325	442627	3966 046274	POLINA VASILEVA	{"email": "vasileva-p14051976@postgrespro.ru", "phone": "+70407740023"}
0005433569326	DAF37E	3211 518981	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana-20091970@postgrespro.ru", "phone": "+70417464833"}
0005433569327	BF406A	0996 020970	DENIS SCHERBAKOV	{"email": "scherbakov_d-1977@postgrespro.ru", "phone": "+70336505392"}
0005433569328	BF406A	2349 958666	MARIYA MIRONOVA	{"phone": "+70639883661"}
0005433569329	2849A2	8942 013725	EKATERINA SOLOVEVA	{"phone": "+70458817514"}
0005433569330	FABBCA	3686 792467	NINA VOLKOVA	{"phone": "+70145882115"}
0005433569331	FABBCA	2907 860159	ANDREY FEDOROV	{"phone": "+70770659862"}
0005433569332	A6E386	9444 921025	NIKOLAY IVANOV	{"phone": "+70578034745"}
0005433569333	A6E386	2243 640367	NATALYA KRASNOVA	{"phone": "+70641393517"}
0005433569334	2F5B4E	8352 310084	ANTONINA ANDREEVA	{"email": "aandreeva1971@postgrespro.ru", "phone": "+70019948710"}
0005433569335	A3CA1E	8631 800542	PAVEL KISELEV	{"email": "p.kiselev_061976@postgrespro.ru", "phone": "+70667176114"}
0005433569336	6A24C0	2597 661265	LYUDMILA GAVRILOVA	{"phone": "+70564150287"}
0005433569337	6A24C0	1499 116666	OLGA IVANOVA	{"email": "ivanova_olga13121965@postgrespro.ru", "phone": "+70228342080"}
0005433569338	3CC4B2	9300 898310	LILIYA ILINA	{"phone": "+70646899888"}
0005433569339	D76B5C	5499 364958	VIKTOR ZHURAVLEV	{"email": "v_zhuravlev.09051965@postgrespro.ru", "phone": "+70032699805"}
0005433569340	D76B5C	0201 471661	ELENA VLASOVA	{"phone": "+70066783901"}
0005433569341	F9D329	4766 408243	ANASTASIYA KOMAROVA	{"phone": "+70746457176"}
0005433569342	1EE249	4020 473030	ALENA NIKOLAEVA	{"email": "nikolaeva-a_021970@postgrespro.ru", "phone": "+70536940058"}
0005433569343	1EE249	2461 408174	VALENTINA KOVALEVA	{"phone": "+70912198147"}
0005433569344	A4C7B7	0056 841012	VALENTINA MELNIKOVA	{"phone": "+70413374774"}
0005433569345	366246	3799 014585	ANTONINA ZAKHAROVA	{"email": "zakharovaa_121981@postgrespro.ru", "phone": "+70563284322"}
0005433569346	366246	9564 959118	MARINA DANILOVA	{"phone": "+70395994026"}
0005433569347	0C7B2B	4552 549487	ALEKSANDR ALEKSANDROV	{"phone": "+70533282756"}
0005433569348	43489A	5173 511298	ILYA EGOROV	{"email": "ilya_egorov_15101968@postgrespro.ru", "phone": "+70550334445"}
0005433569349	C65358	5567 730315	DMITRIY ILIN	{"phone": "+70763860960"}
0005433569350	C65358	1115 802125	DANILA PAVLOV	{"phone": "+70963559495"}
0005433569351	FBCE89	5954 545446	IVAN MAKAROV	{"phone": "+70862804829"}
0005433569352	498E59	1764 087856	ALEKSANDRA KOZLOVA	{"email": "aleksandrakozlova1982@postgrespro.ru", "phone": "+70530305131"}
0005433569353	4E1128	3977 295677	TATYANA YUDINA	{"phone": "+70718611225"}
0005433569354	4E1128	8911 506031	SERGEY MOROZOV	{"phone": "+70301406496"}
0005433569355	7F65B6	8449 223735	OLGA FILATOVA	{"phone": "+70194204440"}
0005433569356	51B356	8779 383075	SERGEY MARTYNOV	{"email": "s_martynov_01041974@postgrespro.ru", "phone": "+70985281738"}
0005433569357	163582	5781 485534	ANDREY ALEKSEEV	{"email": "aalekseev.031967@postgrespro.ru", "phone": "+70042622354"}
0005433569358	163582	5438 866192	VLADISLAV MARTYNOV	{"phone": "+70981632838"}
0005433569359	19FFEA	7994 334998	LYUBOV ANDREEVA	{"email": "andreeval.06071979@postgrespro.ru", "phone": "+70690412569"}
0005433569360	37D8B6	3700 430832	EVGENIY ISAEV	{"phone": "+70457829304"}
0005433569361	135207	3167 861505	ELENA VLASOVA	{"email": "evlasova-24041973@postgrespro.ru", "phone": "+70672972520"}
0005433569362	135207	7614 694484	RAISA LUKYANOVA	{"phone": "+70142008101"}
0005433569363	135207	0037 613906	VYACHESLAV ROMANOV	{"phone": "+70486869342"}
0005433569364	39C0AD	7000 252874	DMITRIY SHEVCHENKO	{"email": "dshevchenko13081981@postgrespro.ru", "phone": "+70566869442"}
0005433569365	AE27E8	8525 237049	ALEKSEY MOROZOV	{"email": "morozov-aleksey.011977@postgrespro.ru", "phone": "+70706208930"}
0005433569366	AE27E8	0228 471147	KONSTANTIN FILIPPOV	{"phone": "+70777019599"}
0005433569367	253D36	9267 243465	VALERIY KUZNECOV	{"email": "kuznecov-valeriy.031975@postgrespro.ru", "phone": "+70283072472"}
0005433569368	B753F4	1235 170634	IVAN STEPANOV	{"phone": "+70214450375"}
0005433569369	44E0A5	6585 166856	ALEKSEY TIMOFEEV	{"phone": "+70217185784"}
0005433569370	0842FF	5272 399929	RUSTAM ABRAMOV	{"email": "rustam.abramov-04091970@postgrespro.ru", "phone": "+70024078539"}
0005433569371	955E80	4748 962472	ANASTASIYA KISELEVA	{"phone": "+70998112027"}
0005433569372	955E80	7000 464189	ZINAIDA SAVELEVA	{"email": "savelevazinaida-26041971@postgrespro.ru", "phone": "+70583031430"}
0005433569373	955E80	1521 233033	VLADISLAV IVANOV	{"phone": "+70935345514"}
0005433569374	65AF13	3639 526832	ALEKSANDR FOMIN	{"phone": "+70275033927"}
0005433569375	DEFB6D	0684 090639	IVAN ROMANOV	{"email": "romanov_i.081967@postgrespro.ru", "phone": "+70323796771"}
0005433569376	DEFB6D	4205 336981	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev041984@postgrespro.ru", "phone": "+70157290865"}
0005433569377	8DB1B7	2511 333243	ILYA MAKSIMOV	{"email": "maksimov_i13091978@postgrespro.ru", "phone": "+70980756133"}
0005433569378	D0A08C	2875 821988	DMITRIY MIRONOV	{"phone": "+70126291383"}
0005433569379	D0A08C	3296 322543	ZULFIYA SAVELEVA	{"phone": "+70243245524"}
0005433569380	51B54C	3137 927692	VIKTOR EGOROV	{"email": "egorovv_07031966@postgrespro.ru", "phone": "+70294257685"}
0005433569381	51B54C	2380 935552	ALEKSEY EGOROV	{"phone": "+70885420278"}
0005433569382	49184C	6880 061624	ALEKSANDR SOROKIN	{"phone": "+70475743547"}
0005433569383	3C4679	9954 784158	VLADIMIR GORBUNOV	{"phone": "+70830544873"}
0005433569384	803BE2	6368 609866	YURIY ORLOV	{"phone": "+70373694876"}
0005433569385	009709	6775 680564	MARGARITA ANISIMOVA	{"phone": "+70995816603"}
0005433569386	EA55E4	0168 278401	PAVEL IVANOV	{"phone": "+70281236875"}
0005433569387	D34A61	9594 998830	TAMARA SOROKINA	{"phone": "+70366460081"}
0005433569388	5494AA	8987 228331	VALENTINA GAVRILOVA	{"email": "gavrilova-v_051956@postgrespro.ru", "phone": "+70557446070"}
0005433569389	2311D7	2094 581122	LYUDMILA ANISIMOVA	{"email": "lanisimova-1972@postgrespro.ru", "phone": "+70312605557"}
0005433569390	2311D7	5201 366793	ELENA VOLKOVA	{"email": "volkova_elena-1972@postgrespro.ru", "phone": "+70464349576"}
0005433569391	DE3AEF	1871 632075	ANDREY VOROBEV	{"phone": "+70453858196"}
0005433569392	388D8C	4737 654077	ANASTASIYA KONDRATEVA	{"email": "a.kondrateva.09051966@postgrespro.ru", "phone": "+70719440818"}
0005433569393	65CF99	5059 708934	ARTEM AFANASEV	{"phone": "+70754102633"}
0005433569394	403AF6	8591 170823	VALERIY MEDVEDEV	{"phone": "+70223923614"}
0005433569395	D094F6	4933 450952	VIKTOR PETROV	{"email": "v_petrov_1965@postgrespro.ru", "phone": "+70731820763"}
0005433569396	7E6026	9360 804914	VALERIY ALEKSEEV	{"phone": "+70945990527"}
0005433569397	7D6216	0164 354710	IVAN ZAKHAROV	{"email": "zakharov.ivan1973@postgrespro.ru", "phone": "+70861557930"}
0005433569398	1901F3	8082 631110	POLINA FEDOROVA	{"email": "polina-fedorova-11101967@postgrespro.ru", "phone": "+70837008040"}
0005433569399	F7D964	6622 550708	IVAN SOROKIN	{"email": "ivansorokin_121976@postgrespro.ru", "phone": "+70532752965"}
0005433569400	7D65D3	2165 110377	VLADIMIR SIDOROV	{"phone": "+70306382197"}
0005433569401	7D65D3	8402 927916	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev_1978@postgrespro.ru", "phone": "+70224038794"}
0005433569402	20A295	0715 297320	DENIS MOROZOV	{"email": "d_morozov_031982@postgrespro.ru", "phone": "+70629297483"}
0005433569403	081266	4592 762527	EKATERINA RYABOVA	{"phone": "+70927165424"}
0005433569404	081266	3960 791573	YULIYA POLYAKOVA	{"phone": "+70110933824"}
0005433569405	D573D6	3168 387593	ELIZAVETA KUZMINA	{"phone": "+70017568505"}
0005433569406	0DA035	2350 168750	ILYA SIDOROV	{"email": "sidorov.ilya25081971@postgrespro.ru", "phone": "+70701210966"}
0005433569407	83CE63	7746 034743	DENIS NIKITIN	{"email": "nikitin-denis17051988@postgrespro.ru", "phone": "+70315391994"}
0005433569408	83CE63	6246 581809	YURIY BELOV	{"email": "belov_y_111972@postgrespro.ru", "phone": "+70697248681"}
0005433569409	9CFD05	5945 572329	MARIYA RYABOVA	{"phone": "+70799109299"}
0005433569410	AA8E37	5508 398203	IRINA ARKHIPOVA	{"email": "arkhipova-irina1968@postgrespro.ru", "phone": "+70942526398"}
0005433569411	AA8E37	7832 671383	NATALYA IVANOVA	{"email": "ivanovanatalya_041965@postgrespro.ru", "phone": "+70768311204"}
0005433569412	D434C0	9958 793339	ALEKSEY MIKHAYLOV	{"phone": "+70842755859"}
0005433569413	D434C0	2261 068860	OLESYA KRASNOVA	{"email": "o_krasnova.08071974@postgrespro.ru", "phone": "+70900918126"}
0005433569414	117027	4652 621950	SVETLANA NIKOLAEVA	{"phone": "+70033621593"}
0005433569415	117027	1895 017034	ELENA EFIMOVA	{"phone": "+70583451439"}
0005433569416	117027	4498 645988	ALENA FILIPPOVA	{"email": "alena.filippova-02061979@postgrespro.ru", "phone": "+70148475778"}
0005433569417	DB6EA3	3957 274868	ELENA DAVYDOVA	{"email": "e_davydova27081977@postgrespro.ru", "phone": "+70191400382"}
0005433569418	F71D67	0952 714184	MIKHAIL NAZAROV	{"phone": "+70748887790"}
0005433569419	F71D67	5365 513577	IRINA KAZAKOVA	{"phone": "+70370725814"}
0005433569420	F71D67	1430 195943	SERGEY MEDVEDEV	{"phone": "+70455595222"}
0005433569421	FE0159	5470 560437	ALEKSANDR ZAKHAROV	{"phone": "+70879915363"}
0005433569422	C5E61B	9036 459457	MARIYA MAKAROVA	{"email": "makarovamariya.081978@postgrespro.ru", "phone": "+70745327394"}
0005433569423	6D0815	9592 014807	LYUDMILA ARKHIPOVA	{"email": "l-arkhipova26121970@postgrespro.ru", "phone": "+70185318436"}
0005433569424	A930B2	4172 630807	RINAT PETROV	{"email": "petrov-r.111972@postgrespro.ru", "phone": "+70728069619"}
0005433569425	6C6F98	8952 981250	YANA MAKAROVA	{"email": "makarovay.18011970@postgrespro.ru", "phone": "+70570595628"}
0005433569426	DC8F15	1504 900072	FANIL SIDOROV	{"email": "sidorov.f-30031971@postgrespro.ru", "phone": "+70634201020"}
0005433569427	99D33A	7178 693025	VIKTOR BORISOV	{"phone": "+70790775097"}
0005433569428	EAD4F7	8930 598524	ANNA ANISIMOVA	{"phone": "+70776580792"}
0005433569429	EAD4F7	7439 502124	LYUDMILA KOVALEVA	{"email": "kovaleva.l-14081978@postgrespro.ru", "phone": "+70546623846"}
0005433569430	F30EE7	3662 043323	VIKTOR MIKHAYLOV	{"email": "viktormikhaylov-24111971@postgrespro.ru", "phone": "+70386216087"}
0005433569431	FE0258	0360 788509	ALENA OVCHINNIKOVA	{"email": "aovchinnikova-27121960@postgrespro.ru", "phone": "+70833361013"}
0005433569432	EA4144	8675 622282	TATYANA EGOROVA	{"phone": "+70103267337"}
0005433569433	EA4144	1936 890874	LYUBOV LOGINOVA	{"email": "lloginova_1984@postgrespro.ru", "phone": "+70816881269"}
0005433569434	BA7B87	1157 887999	MARINA NIKITINA	{"email": "m_nikitina-12121972@postgrespro.ru", "phone": "+70406942816"}
0005433569435	64769F	4243 401717	VALENTINA MOROZOVA	{"email": "morozova_valentina.061971@postgrespro.ru", "phone": "+70205791616"}
0005433569436	64769F	8312 413806	NIKOLAY VLASOV	{"phone": "+70290790356"}
0005433569437	B88847	5404 748117	YURIY KOROLEV	{"email": "korolev-y_1971@postgrespro.ru", "phone": "+70587404872"}
0005433569438	D8F1E5	7111 448956	TATYANA PETROVA	{"email": "petrovat_1974@postgrespro.ru", "phone": "+70821880422"}
0005433569439	238B2A	4929 158594	YULIYA LEBEDEVA	{"email": "lebedeva_yuliya_05111993@postgrespro.ru", "phone": "+70208752597"}
0005433569440	D5CEB6	4528 981802	DIANA TARASOVA	{"phone": "+70308295048"}
0005433569441	D5CEB6	8943 028484	ROMAN KUZMIN	{"email": "kuzmin_r.051990@postgrespro.ru", "phone": "+70153971052"}
0005433569442	B4A21C	5533 406642	SOFYA ANISIMOVA	{"phone": "+70429208445"}
0005433569443	BB2C21	7413 515411	MARIYA ZAKHAROVA	{"email": "zakharovamariya10091973@postgrespro.ru", "phone": "+70489940770"}
0005433569444	BB2C21	8394 633049	ANDREY NIKOLAEV	{"phone": "+70536834737"}
0005433569445	0084D4	2587 402430	NIKOLAY RODIONOV	{"email": "rodionov-n_20111973@postgrespro.ru", "phone": "+70060876497"}
0005433569446	0084D4	7444 838551	EVGENIY KUDRYASHOV	{"phone": "+70894241919"}
0005433569447	0084D4	1905 292034	OLEG KUDRYASHOV	{"phone": "+70770922482"}
0005433569448	19C376	6525 214693	EVGENIY SEMENOV	{"email": "semenov-e.1971@postgrespro.ru", "phone": "+70536587984"}
0005433569449	8C5064	0697 386919	ALEKSANDR MOROZOV	{"phone": "+70713897597"}
0005433569562	2C7B40	9959 165039	VLADIMIR MARTYNOV	{"phone": "+70116020069"}
0005433569450	8C5064	8167 429086	VASILIY BELOV	{"email": "vasiliy.belov-30061965@postgrespro.ru", "phone": "+70575587254"}
0005433569451	AB1EDB	1123 998874	IVAN GAVRILOV	{"email": "gavrilov.i_06011971@postgrespro.ru", "phone": "+70265766587"}
0005433569452	D902C8	7779 540775	ANASTASIYA DANILOVA	{"phone": "+70729770626"}
0005433569453	EE441A	6431 508338	IRINA KOROLEVA	{"email": "korolevairina-03121969@postgrespro.ru", "phone": "+70559367431"}
0005433569454	EE441A	6544 862150	TAMARA BORISOVA	{"email": "borisova.t_1969@postgrespro.ru", "phone": "+70598601754"}
0005433569455	3B40CF	1383 244124	VLADA BARANOVA	{"phone": "+70605649711"}
0005433569456	3B40CF	9660 111129	MIKHAIL MEDVEDEV	{"email": "mikhail_medvedev.05061966@postgrespro.ru", "phone": "+70628475515"}
0005433569457	27B591	3867 528191	EKATERINA ZAKHAROVA	{"phone": "+70281213916"}
0005433569458	27B591	5127 621295	ALEKSEY DAVYDOV	{"phone": "+70772257252"}
0005433569459	D530E7	0586 614541	DMITRIY KAZAKOV	{"email": "d-kazakov_01011981@postgrespro.ru", "phone": "+70632918089"}
0005433569460	44B10B	7176 292342	ANZHELA SOROKINA	{"phone": "+70596263043"}
0005433569461	09A543	9294 750449	DMITRIY KUZMIN	{"phone": "+70242637320"}
0005433569462	815CA5	8535 599306	MARINA IVANOVA	{"phone": "+70799675070"}
0005433569463	F72DAB	9147 113553	NIKOLAY GORBUNOV	{"phone": "+70392375301"}
0005433569464	F72DAB	8377 961702	SERGEY PAVLOV	{"phone": "+70072125825"}
0005433569465	F5E425	5362 551471	GENNADIY KUZNECOV	{"phone": "+70800707542"}
0005433569466	108D2B	8684 672535	GEORGIY NIKOLAEV	{"phone": "+70149897930"}
0005433569467	108D2B	7641 028946	ELENA SIDOROVA	{"phone": "+70199529157"}
0005433569468	19D149	5370 531126	ALLA DMITRIEVA	{"phone": "+70999003963"}
0005433569469	DC3F53	3827 434216	ALEKSEY DMITRIEV	{"email": "dmitriev-a-01081973@postgrespro.ru", "phone": "+70568444344"}
0005433569470	9DEB3C	2134 313680	ZOYA KUZNECOVA	{"phone": "+70253604299"}
0005433569471	9DEB3C	1575 619696	ANTONINA ZAKHAROVA	{"phone": "+70800133945"}
0005433569472	433DF3	1267 861931	ALEKSANDR FEDOROV	{"phone": "+70075733610"}
0005433569473	2694E6	6602 430740	OLGA GERASIMOVA	{"phone": "+70211117861"}
0005433569474	0EF76D	3406 731260	YURIY ILIN	{"email": "ilin_y1970@postgrespro.ru", "phone": "+70572826805"}
0005433569475	0EF76D	2053 052509	DANIIL TIKHONOV	{"email": "dtikhonov.1976@postgrespro.ru", "phone": "+70753586726"}
0005433569476	0EF76D	7816 488450	NADEZHDA RYABOVA	{"phone": "+70587850101"}
0005433569477	0EF76D	1721 467301	POLINA MALYSHEVA	{"email": "polinamalysheva.051955@postgrespro.ru", "phone": "+70117020345"}
0005433569478	CF9EF2	6749 259304	DANIL GRIGOREV	{"phone": "+70203529586"}
0005433569479	B90979	3824 287520	VERA ZOTOVA	{"email": "vzotova.091977@postgrespro.ru", "phone": "+70007569697"}
0005433569480	16CC2E	3717 267567	ANDREY KONOVALOV	{"email": "konovalov_andrey.1979@postgrespro.ru", "phone": "+70537891311"}
0005433569481	16CC2E	7951 263382	ANDREY SOLOVEV	{"email": "andrey-solovev.1977@postgrespro.ru", "phone": "+70885619293"}
0005433569482	BA1926	7275 114834	IRINA KUZNECOVA	{"email": "kuznecovai_20061965@postgrespro.ru", "phone": "+70742086177"}
0005433569483	F68768	0086 565175	YURIY NAZAROV	{"phone": "+70773462420"}
0005433569484	F68768	9420 139450	OLESYA CHERNOVA	{"email": "chernova_o.031974@postgrespro.ru", "phone": "+70652410100"}
0005433569485	492BDC	2759 776306	SVETLANA ZHUKOVA	{"phone": "+70210519080"}
0005433569486	F64AFB	5564 777543	ARTEM FEDOROV	{"email": "artem_fedorov.041958@postgrespro.ru", "phone": "+70634882538"}
0005433569487	F64AFB	9716 522083	IRINA TIMOFEEVA	{"email": "timofeeva_i-27121975@postgrespro.ru", "phone": "+70089171289"}
0005433569488	B026B9	3845 722167	IGOR PETROV	{"phone": "+70169576328"}
0005433569489	FEA257	4228 424457	LIDIYA BARANOVA	{"phone": "+70054376833"}
0005433569490	D92262	7607 329033	LYUDMILA ERMAKOVA	{"email": "ermakoval14081965@postgrespro.ru", "phone": "+70657844612"}
0005433569491	775083	8684 072824	VITALIY MOROZOV	{"phone": "+70670165554"}
0005433569492	775083	0553 913028	VIKTOR NOVIKOV	{"email": "vnovikov_021973@postgrespro.ru", "phone": "+70880690904"}
0005433569493	830E38	9226 488910	NIKOLAY KUZNECOV	{"phone": "+70544917402"}
0005433569494	830E38	3647 834139	VIKTOR VOROBEV	{"email": "v.vorobev.081974@postgrespro.ru", "phone": "+70065728414"}
0005433569495	E586EF	4962 945906	STANISLAV VASILEV	{"email": "s-vasilev.111976@postgrespro.ru", "phone": "+70016540736"}
0005433569496	BC4027	3746 063519	ANDREY BELOV	{"email": "andreybelov_071979@postgrespro.ru", "phone": "+70346420792"}
0005433569497	BC4027	2501 835231	EVGENIY KRASNOV	{"email": "krasnov_evgeniy-011973@postgrespro.ru", "phone": "+70630272142"}
0005433569498	EC7109	0960 615937	TATYANA KALININA	{"phone": "+70833107209"}
0005433569499	EC7109	3596 650638	IRINA EGOROVA	{"email": "egorova-irina-091961@postgrespro.ru", "phone": "+70346570705"}
0005433569500	BFC92E	7551 110419	MIKHAIL NAZAROV	{"email": "nazarov_mikhail1977@postgrespro.ru", "phone": "+70012908906"}
0005433569501	195CA8	3608 650948	OKSANA FILIPPOVA	{"phone": "+70526287451"}
0005433569502	195CA8	8433 435879	DANIYA ABRAMOVA	{"email": "daniya_abramova1978@postgrespro.ru", "phone": "+70452787588"}
0005433569503	2AD2C9	7257 266647	TATYANA POPOVA	{"email": "popovat_041977@postgrespro.ru", "phone": "+70038666642"}
0005433569504	2AD2C9	8149 957910	FEDOR DAVYDOV	{"email": "fdavydov_1966@postgrespro.ru", "phone": "+70229224455"}
0005433569505	B627CD	5862 871963	DMITRIY KULIKOV	{"email": "kulikov-d.1975@postgrespro.ru", "phone": "+70763482164"}
0005433569563	0AB52E	8727 640187	LYUDMILA ERMAKOVA	{"phone": "+70029073619"}
0005433569506	CF9B79	5642 496485	TATYANA MIKHAYLOVA	{"email": "mikhaylova_tatyana.1968@postgrespro.ru", "phone": "+70681788664"}
0005433569507	D29B89	7043 778654	ALEKSANDR KAZAKOV	{"phone": "+70196909520"}
0005433569508	D5B663	5365 851974	LIDIYA IVANOVA	{"email": "ivanova.l_011968@postgrespro.ru", "phone": "+70543266285"}
0005433569509	2F5B48	2778 251967	ALEKSEY ALEKSEEV	{"email": "alekseev.aleksey051981@postgrespro.ru", "phone": "+70377455148"}
0005433569510	7CD435	2221 889104	YANA MAKAROVA	{"phone": "+70356487545"}
0005433569511	0D2376	3269 855821	TATYANA NIKOLAEVA	{"phone": "+70065582075"}
0005433569512	52D18C	9313 055506	ALENA MIRONOVA	{"email": "amironova21031972@postgrespro.ru", "phone": "+70697829851"}
0005433569513	339FED	3294 838487	OLGA ZHUKOVA	{"email": "zhukovao22041970@postgrespro.ru", "phone": "+70286519729"}
0005433569514	DFC79E	9407 194506	ALEKSANDR MAKAROV	{"phone": "+70605259675"}
0005433569515	B26114	6085 679819	ELENA AFANASEVA	{"email": "afanaseva_e.12091970@postgrespro.ru", "phone": "+70021676330"}
0005433569516	B26114	3859 193385	RAFAIL SOROKIN	{"email": "sorokinrafail011976@postgrespro.ru", "phone": "+70298488659"}
0005433569517	8DAB14	9270 935893	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov1983@postgrespro.ru", "phone": "+70329930099"}
0005433569518	47ADE0	0683 524643	MAKSIM AFANASEV	{"phone": "+70136383092"}
0005433569519	986E1B	0226 572184	DMITRIY SCHERBAKOV	{"email": "dmitriy.scherbakov.08101971@postgrespro.ru", "phone": "+70816143561"}
0005433569520	986E1B	9699 846983	ARTEM ZAKHAROV	{"email": "artem-zakharov_121993@postgrespro.ru", "phone": "+70204588621"}
0005433569521	986E1B	6049 476241	VLADIMIR TIMOFEEV	{"phone": "+70537959894"}
0005433569522	986E1B	2968 647426	VIKTOR SCHERBAKOV	{"email": "scherbakov.viktor.031975@postgrespro.ru", "phone": "+70813806568"}
0005433569523	2D2087	2096 628968	ANASTASIYA KRASNOVA	{"email": "a-krasnova-081963@postgrespro.ru", "phone": "+70593400809"}
0005433569524	EDDC93	7826 807774	IVAN VLASOV	{"phone": "+70217201109"}
0005433569525	EDDC93	7789 915788	VIKTOR KAZAKOV	{"phone": "+70478881139"}
0005433569526	D116B9	9484 685310	TATYANA KOVALEVA	{"phone": "+70343445397"}
0005433569639	2B7C2F	2606 825952	ANDREY VOLKOV	{"phone": "+70772967605"}
0005433569527	D72BA3	1300 670180	EKATERINA AFANASEVA	{"email": "afanasevae.1981@postgrespro.ru", "phone": "+70192862483"}
0005433569528	D72BA3	6249 080849	ANDREY FROLOV	{"email": "frolovandrey.31101980@postgrespro.ru", "phone": "+70946838864"}
0005433569529	900F90	2678 718149	TATYANA MAKSIMOVA	{"phone": "+70144707937"}
0005433569530	F87592	1495 715069	VYACHESLAV DENISOV	{"phone": "+70693277441"}
0005433569531	F87592	1694 594874	NATALIYA IVANOVA	{"phone": "+70745944162"}
0005433569532	31CCD3	9594 351770	NIKOLAY VOROBEV	{"phone": "+70249470889"}
0005433569533	A67335	4901 413900	NATALYA VOLKOVA	{"email": "volkova.n_1978@postgrespro.ru", "phone": "+70799441182"}
0005433569534	B7EDEC	8804 373754	IGOR KOZLOV	{"email": "igorkozlov-1969@postgrespro.ru", "phone": "+70595500985"}
0005433569535	F63AA0	1813 319214	NATALYA SOLOVEVA	{"phone": "+70825950114"}
0005433569536	93D25B	9903 037207	GALINA NIKITINA	{"email": "nikitina.g011973@postgrespro.ru", "phone": "+70253990656"}
0005433569537	781690	0914 800343	TATYANA VLASOVA	{"email": "vlasovat1977@postgrespro.ru", "phone": "+70560203704"}
0005433569538	6B5370	7816 525488	VALENTINA VASILEVA	{"email": "valentina_vasileva_111971@postgrespro.ru", "phone": "+70152925040"}
0005433569539	6B5370	7689 310755	LYUBOV OVCHINNIKOVA	{"phone": "+70285214507"}
0005433569540	6B5370	9105 868687	IRINA GRISHINA	{"phone": "+70008382038"}
0005433569541	5AF6DA	5693 917750	ANZHELA ISAEVA	{"phone": "+70415211756"}
0005433569542	1323C8	7082 216990	ALEKSANDR EGOROV	{"email": "aleksandr-egorov_16011982@postgrespro.ru", "phone": "+70825003315"}
0005433569543	1323C8	7764 027959	RAISA MOROZOVA	{"email": "morozova_raisa.1968@postgrespro.ru", "phone": "+70756733247"}
0005433569544	0C4246	0986 091107	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.v_20061976@postgrespro.ru", "phone": "+70385568089"}
0005433569545	6861EF	3037 976883	IVAN MOROZOV	{"phone": "+70977232298"}
0005433569546	2326E9	9154 270897	OLEG ZAKHAROV	{"phone": "+70494419296"}
0005433569547	C21B79	7794 902824	GRIGORIY VASILEV	{"email": "grigoriyvasilev1985@postgrespro.ru", "phone": "+70689940534"}
0005433569548	150368	7669 883042	SERGEY ILIN	{"phone": "+70945823895"}
0005433569549	F2B1C8	0711 264830	EKATERINA SERGEEVA	{"email": "e_sergeeva-1974@postgrespro.ru", "phone": "+70588956609"}
0005433569550	338C6B	0904 896840	NATALYA NAUMOVA	{"phone": "+70311213944"}
0005433569551	B59036	0757 041264	TATYANA TROFIMOVA	{"email": "trofimova.tatyana.19101974@postgrespro.ru", "phone": "+70778819274"}
0005433569552	36DC63	1465 822919	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov_25061986@postgrespro.ru", "phone": "+70921172100"}
0005433569553	B5EFA4	0476 264336	NIKOLAY KISELEV	{"phone": "+70556489786"}
0005433569554	54EC25	3319 966493	GALINA FOMINA	{"phone": "+70912436569"}
0005433569555	3F9DD0	7065 473553	MIKHAIL GRIGOREV	{"phone": "+70639398318"}
0005433569556	BFF775	3876 026257	VLADIMIR ANDREEV	{"email": "andreev.v.03101972@postgrespro.ru", "phone": "+70972948094"}
0005433569557	5245FA	8815 561724	LYUBOV ANDREEVA	{"phone": "+70568127023"}
0005433569558	71A180	7588 382989	OLGA NIKITINA	{"email": "olga_nikitina.21011983@postgrespro.ru", "phone": "+70610057204"}
0005433569559	D60D49	5014 118667	NINA ROMANOVA	{"phone": "+70230355529"}
0005433569560	993800	0599 229232	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a-021980@postgrespro.ru", "phone": "+70475946082"}
0005433569561	993800	1721 749473	TIMUR MOROZOV	{"phone": "+70065218312"}
0005433569564	0AB52E	6019 150564	ALISA EFIMOVA	{"phone": "+70971106325"}
0005433569565	2993B4	7651 126888	OKSANA KOLESNIKOVA	{"email": "oksana-kolesnikova20021972@postgrespro.ru", "phone": "+70133493461"}
0005433569566	7BEE3A	8346 100231	GALINA SEMENOVA	{"email": "semenova.g.05061972@postgrespro.ru", "phone": "+70829558780"}
0005433569567	7D296B	3534 062879	NINA YAKOVLEVA	{"email": "n_yakovleva.111983@postgrespro.ru", "phone": "+70349799750"}
0005433569568	076C94	2175 547915	INNA GERASIMOVA	{"email": "gerasimova-i-1966@postgrespro.ru", "phone": "+70460910919"}
0005433569569	8DE7A7	1738 984505	EKATERINA LAZAREVA	{"phone": "+70638355910"}
0005433569570	FAB2D6	5959 908205	NATALYA TARASOVA	{"phone": "+70601576239"}
0005433569571	AAA488	4721 316579	ELENA PAVLOVA	{"phone": "+70950786176"}
0005433569572	AAA488	0474 574565	ANATOLIY SCHERBAKOV	{"email": "a_scherbakov-01061954@postgrespro.ru", "phone": "+70675682136"}
0005433569573	67CD7C	3014 569465	ALEKSANDR MATVEEV	{"email": "matveeva071972@postgrespro.ru", "phone": "+70396361762"}
0005433569574	91114B	7967 380283	NATALYA KARPOVA	{"phone": "+70334762351"}
0005433569575	91114B	6451 039486	OLGA SCHERBAKOVA	{"email": "scherbakova.o.041967@postgrespro.ru", "phone": "+70400101757"}
0005433569576	1CD31F	1766 415533	TATYANA ZAKHAROVA	{"email": "tzakharova.26011975@postgrespro.ru", "phone": "+70931697989"}
0005433569577	1CD31F	7927 658345	ALEKSEY AFANASEV	{"phone": "+70189315847"}
0005433569578	6A8572	4662 842961	DANILA MOISEEV	{"phone": "+70872621201"}
0005433569579	807FC8	1645 356306	LIDIYA BELYAEVA	{"email": "belyaeva-l-081974@postgrespro.ru", "phone": "+70171729921"}
0005433569580	CFE410	2381 069855	MIKHAIL MIRONOV	{"phone": "+70805062137"}
0005433569581	4ABA21	4337 071830	YURIY ABRAMOV	{"email": "abramov.yuriy30051979@postgrespro.ru", "phone": "+70716525551"}
0005433569582	10642B	1389 328051	NINA ABRAMOVA	{"phone": "+70828374389"}
0005433569583	10642B	7471 651411	LIDIYA ZHUKOVA	{"phone": "+70388479860"}
0005433569584	B41E29	5285 308468	BORIS DMITRIEV	{"email": "boris_dmitriev091979@postgrespro.ru", "phone": "+70280291693"}
0005433569585	48BB03	7006 181607	VADIM DMITRIEV	{"email": "dmitriev-vadim-081983@postgrespro.ru", "phone": "+70913310098"}
0005433569586	48BB03	3420 305749	OLGA KALININA	{"email": "okalinina_12111971@postgrespro.ru", "phone": "+70453786398"}
0005433569587	0E356E	7946 127590	ANASTASIYA DMITRIEVA	{"email": "admitrieva111984@postgrespro.ru", "phone": "+70423228226"}
0005433569588	0E356E	5509 911674	ROMAN ISAEV	{"phone": "+70566446865"}
0005433569589	DFBC52	0530 244252	YULIYA MIKHAYLOVA	{"phone": "+70784068518"}
0005433569590	4F01A5	4193 426078	SERGEY NOVIKOV	{"email": "s_novikov1970@postgrespro.ru", "phone": "+70633134184"}
0005433569591	5F90D0	5839 814178	OLGA BELOVA	{"email": "belovaolga.1976@postgrespro.ru", "phone": "+70374399417"}
0005433569592	5F90D0	8508 844121	RAFAIL ALEKSEEV	{"phone": "+70426544727"}
0005433569593	4C599F	9558 496737	LYUDMILA AKIMOVA	{"phone": "+70960176805"}
0005433569594	4C599F	5901 637594	VIKTORIYA MATVEEVA	{"email": "matveevav.041971@postgrespro.ru", "phone": "+70794324807"}
0005433569595	3BA742	7504 869892	ARTEM SERGEEV	{"email": "a-sergeev-08051972@postgrespro.ru", "phone": "+70372825276"}
0005433569596	3BA742	8424 311134	NINA TIKHONOVA	{"email": "tikhonova-n-031976@postgrespro.ru", "phone": "+70722665696"}
0005433569597	66B7E6	5171 290355	KONSTANTIN GRIGOREV	{"phone": "+70535146309"}
0005433569598	4F71F3	1408 962389	DARYA KUZNECOVA	{"email": "kuznecovadarya.1974@postgrespro.ru", "phone": "+70555126540"}
0005433569599	95FF8A	5538 874748	ANDREY SERGEEV	{"phone": "+70899310978"}
0005433569600	A4AE91	9279 784655	ALEKSANDR SMIRNOV	{"email": "smirnov-aleksandr-09071982@postgrespro.ru", "phone": "+70841937922"}
0005433569601	31D192	3909 152534	VALERIY PAVLOV	{"email": "pavlov-valeriy.01011978@postgrespro.ru", "phone": "+70599372652"}
0005433569602	0D75C8	1562 407622	SERGEY IVANOV	{"email": "ivanov-s021971@postgrespro.ru", "phone": "+70476708996"}
0005433569603	7537C8	3185 148638	ALEKSEY TARASOV	{"email": "tarasova_1971@postgrespro.ru", "phone": "+70753204648"}
0005433569604	63DAE2	4813 974607	YURIY PAVLOV	{"email": "yuriy-pavlov-1970@postgrespro.ru", "phone": "+70819539738"}
0005433569605	0423F0	2229 178638	ANASTASIYA PETROVA	{"phone": "+70861749070"}
0005433569606	07B105	1730 518320	SERGEY SAVELEV	{"phone": "+70665493353"}
0005433569607	07B105	0282 895354	EVGENIYA SIDOROVA	{"email": "sidorova.e.1964@postgrespro.ru", "phone": "+70716683344"}
0005433569608	07B105	4004 141286	VIKTOR ANDREEV	{"phone": "+70597068693"}
0005433569609	7AF219	7531 030725	MARINA MELNIKOVA	{"phone": "+70487304208"}
0005433569610	0381D2	1248 164282	LYUDMILA TARASOVA	{"email": "tarasova.l_111975@postgrespro.ru", "phone": "+70145760514"}
0005433569611	07BED6	0573 948431	NATALYA FROLOVA	{"email": "frolova.natalya-101968@postgrespro.ru", "phone": "+70389216324"}
0005433569612	DCCCC6	8916 029818	ALEKSANDR ANDREEV	{"phone": "+70261223694"}
0005433569613	B75465	1590 331385	ARTEM MAKSIMOV	{"email": "maksimov_a101973@postgrespro.ru", "phone": "+70208597549"}
0005433569614	A339A0	8885 282500	ANASTASIYA IVANOVA	{"phone": "+70551777488"}
0005433569615	A339A0	1923 077417	RAISA KUZNECOVA	{"phone": "+70781999585"}
0005433569616	EFBFAF	0697 111061	ALEKSEY ZHURAVLEV	{"phone": "+70442514899"}
0005433569617	475C5C	1378 392805	VLADIMIR IVANOV	{"email": "ivanov_vladimir_08111983@postgrespro.ru", "phone": "+70503292482"}
0005433569618	5489A9	1562 947517	ALEKSANDR POPOV	{"email": "aleksandr_popov.10011978@postgrespro.ru", "phone": "+70219771979"}
0005433569842	164ED2	5349 172347	TAMARA VOROBEVA	{"phone": "+70103730224"}
0005433569619	167BF6	2567 080208	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir-021974@postgrespro.ru", "phone": "+70942525383"}
0005433569620	FB3031	0160 877317	GALINA NOVIKOVA	{"phone": "+70959215047"}
0005433569621	ADA1AD	0131 609748	EKATERINA ANDREEVA	{"email": "andreevaekaterina051974@postgrespro.ru", "phone": "+70354488743"}
0005433569622	5908BB	5263 129211	LILIYA SOKOLOVA	{"phone": "+70110792801"}
0005433569623	8F0068	1864 137931	VALENTINA CHERNOVA	{"phone": "+70607426807"}
0005433569624	2E27B2	7251 293899	NATALYA RODIONOVA	{"email": "rodionovanatalya-1966@postgrespro.ru", "phone": "+70473173997"}
0005433569625	0B789E	8423 843940	LIDIYA NOVIKOVA	{"email": "lidiya-novikova091969@postgrespro.ru", "phone": "+70682760179"}
0005433569626	EA4216	0230 534760	ZINAIDA FROLOVA	{"email": "frolova.z_05011974@postgrespro.ru", "phone": "+70388919401"}
0005433569627	B4B665	2709 745124	LIDIYA GORBUNOVA	{"email": "lidiya_gorbunova-1975@postgrespro.ru", "phone": "+70731562761"}
0005433569628	B4B665	2945 653159	VIKTOR OSIPOV	{"phone": "+70639041711"}
0005433569629	8031E1	9199 864921	VALENTINA NESTEROVA	{"email": "v-nesterova-11121979@postgrespro.ru", "phone": "+70404459909"}
0005433569630	6EC777	8917 386625	NIKOLAY BORISOV	{"phone": "+70481236413"}
0005433569631	50005E	1342 230634	ANDREY SMIRNOV	{"email": "smirnov-andrey-121964@postgrespro.ru", "phone": "+70984644370"}
0005433569632	02B894	5373 294011	MARINA LAZAREVA	{"email": "marina.lazareva-101971@postgrespro.ru", "phone": "+70458287357"}
0005433569633	ABF926	4326 987169	NATALYA IVANOVA	{"phone": "+70857999735"}
0005433569634	ABF926	1073 260951	VYACHESLAV ZAYCEV	{"email": "v.zaycev-25011969@postgrespro.ru", "phone": "+70157298669"}
0005433569635	7E3805	4983 135196	SVYATOSLAV BONDARENKO	{"email": "bondarenkos09061965@postgrespro.ru", "phone": "+70952892389"}
0005433569636	7E3805	5857 910313	MARIYA PAVLOVA	{"email": "pavlovam.1965@postgrespro.ru", "phone": "+70807562091"}
0005433569637	3B4A38	6082 360049	NIKITA MELNIKOV	{"phone": "+70257050908"}
0005433569638	154320	7942 473663	LYUDMILA LAZAREVA	{"phone": "+70618452427"}
0005433569640	2B7C2F	7901 997261	VASILISA KRASNOVA	{"email": "vasilisa-krasnova_1964@postgrespro.ru", "phone": "+70826340213"}
0005433569641	0F30B3	1917 451931	ANTON KUZNECOV	{"phone": "+70624603135"}
0005433569642	044915	3118 704844	LYUDMILA DAVYDOVA	{"email": "lyudmila_davydova.23061978@postgrespro.ru", "phone": "+70070016768"}
0005433569643	D31ECB	4417 533888	KRISTINA DANILOVA	{"phone": "+70677381806"}
0005433569644	1B9414	9774 899277	LYUDMILA ALEKSEEVA	{"email": "l_alekseeva-081985@postgrespro.ru", "phone": "+70859626678"}
0005433569645	1B9414	5250 731792	VLADISLAV BELOV	{"phone": "+70342700185"}
0005433569646	DDD044	1054 414221	EVGENIYA KUZNECOVA	{"phone": "+70055624842"}
0005433569647	DDD044	1378 159942	SVETLANA KOLESNIKOVA	{"phone": "+70621584691"}
0005433569648	DDD044	5021 343231	YURIY SEMENOV	{"email": "semenov_y_26121972@postgrespro.ru", "phone": "+70930056770"}
0005433569649	EADCA1	3768 396318	DMITRIY SMIRNOV	{"phone": "+70227225835"}
0005433569650	EADCA1	7699 655205	YURIY TIKHONOV	{"email": "tikhonovyuriy_24011975@postgrespro.ru", "phone": "+70994880256"}
0005433569651	3EE90C	7803 928995	IRINA NIKOLAEVA	{"phone": "+70961766253"}
0005433569652	3EE90C	0880 385167	SERGEY NOVIKOV	{"email": "novikov.sergey-1979@postgrespro.ru", "phone": "+70873744937"}
0005433569653	A804E7	7437 973291	VASILIY KOZLOV	{"email": "kozlovvasiliy_29051984@postgrespro.ru", "phone": "+70550026202"}
0005433569654	A804E7	0157 670688	EVGENIYA MIKHAYLOVA	{"phone": "+70580702251"}
0005433569655	4B99C6	0559 490240	ILYA KRASNOV	{"phone": "+70864918698"}
0005433569656	4B99C6	9559 293117	ANDREY NAUMOV	{"email": "naumov.a_1971@postgrespro.ru", "phone": "+70441466650"}
0005433569657	DDB98F	4882 581714	EKATERINA IVANOVA	{"email": "ekaterina.ivanova06101975@postgrespro.ru", "phone": "+70523742437"}
0005433569658	DDB98F	7128 934009	ELENA ANDREEVA	{"email": "andreevaelena.28121972@postgrespro.ru", "phone": "+70647018198"}
0005433569659	D4B4A1	6209 098536	IGOR GAVRILOV	{"phone": "+70618463420"}
0005433569660	AFF185	8445 025405	ANATOLIY DAVYDOV	{"email": "anatoliy_davydov-22091963@postgrespro.ru", "phone": "+70863090101"}
0005433569661	AFF185	9885 891676	NADEZHDA RODIONOVA	{"email": "n_rodionova.25031975@postgrespro.ru", "phone": "+70275451886"}
0005433569662	A88ED3	0408 176039	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr.041974@postgrespro.ru", "phone": "+70338596262"}
0005433569663	8EF5D6	5380 508483	GALINA IVANOVA	{"email": "g.ivanova_04061980@postgrespro.ru", "phone": "+70519075771"}
0005433569664	75FE96	1439 550479	SVETLANA KOROLEVA	{"email": "s.koroleva.031982@postgrespro.ru", "phone": "+70999387505"}
0005433569665	75FE96	6526 887467	RAMIL ALEKSEEV	{"email": "ramil_alekseev-1970@postgrespro.ru", "phone": "+70283495788"}
0005433569666	EA7CDE	8127 203944	IRINA ALEKSANDROVA	{"email": "i-aleksandrova_101967@postgrespro.ru", "phone": "+70158014121"}
0005433569667	EA7CDE	5128 723000	KIRILL KOROLEV	{"email": "kkorolev_1966@postgrespro.ru", "phone": "+70074259601"}
0005433569668	EA7CDE	6244 133259	OLGA EGOROVA	{"email": "egorova_olga-1964@postgrespro.ru", "phone": "+70320161586"}
0005433569669	D93151	3861 314762	ALEKSANDR IVANOV	{"phone": "+70800309038"}
0005433569670	A2542C	1158 234271	OLGA KUZNECOVA	{"email": "o_kuznecova_081970@postgrespro.ru", "phone": "+70174864374"}
0005433569671	152BD9	2803 507796	GALINA FILIPPOVA	{"email": "filippova.g.1981@postgrespro.ru", "phone": "+70860366184"}
0005433569672	152BD9	7084 132771	IRINA ANDREEVA	{"email": "andreeva.i_25051966@postgrespro.ru", "phone": "+70570019678"}
0005433569673	152BD9	4825 853208	MARIYA SOLOVEVA	{"email": "soloveva.mariya_071973@postgrespro.ru", "phone": "+70545927519"}
0005433569674	8CE224	2600 312829	ALEKSANDR KONOVALOV	{"email": "a.konovalov_051981@postgrespro.ru", "phone": "+70604922007"}
0005433569675	CAB252	3221 773534	IRINA FROLOVA	{"phone": "+70291915743"}
0005433569676	CAB252	8304 179712	SVETLANA POPOVA	{"phone": "+70925382939"}
0005433569677	8EFA8C	6401 127501	TATYANA ARKHIPOVA	{"phone": "+70043933604"}
0005433569678	03321D	7683 123842	OLGA EGOROVA	{"phone": "+70248900214"}
0005433569679	EEFA42	5433 796909	MAYYA KOROLEVA	{"phone": "+70658606609"}
0005433569680	4139D1	4624 596524	ANNA ROMANOVA	{"email": "romanova-anna_051978@postgrespro.ru", "phone": "+70415298491"}
0005433569681	91C9F6	7779 898249	SVETLANA ZHURAVLEVA	{"phone": "+70105644022"}
0005433569682	91C9F6	8631 932584	SERGEY NAZAROV	{"phone": "+70404980019"}
0005433569683	CFD2CA	0636 276758	EVGENIY SHEVCHENKO	{"email": "shevchenko_e-1962@postgrespro.ru", "phone": "+70718289916"}
0005433569684	AA2613	9922 844586	KRISTINA ZAKHAROVA	{"phone": "+70969028257"}
0005433569685	BA6886	2960 096943	VERA NESTEROVA	{"email": "nesterova.v-1960@postgrespro.ru", "phone": "+70177581102"}
0005433569686	790961	6845 913646	EKATERINA MOROZOVA	{"email": "morozova_e_05101970@postgrespro.ru", "phone": "+70698618596"}
0005433569687	790961	0103 447524	SERGEY GAVRILOV	{"email": "gavrilov-sergey.02021968@postgrespro.ru", "phone": "+70159997721"}
0005433569688	C95250	1319 718025	ALIYA ZHUKOVA	{"phone": "+70037385189"}
0005433569689	C95250	7162 227784	ARSENIY SEMENOV	{"phone": "+70256607385"}
0005433569690	7D5D9D	7152 497228	TATYANA EGOROVA	{"email": "tatyana_egorova_111973@postgrespro.ru", "phone": "+70582710702"}
0005433569691	7D5D9D	3958 465046	OLGA TIMOFEEVA	{"email": "timofeevaolga-28041979@postgrespro.ru", "phone": "+70939835722"}
0005433569692	2850B2	7490 767250	PETR GAVRILOV	{"email": "gavrilov.p03051963@postgrespro.ru", "phone": "+70098703452"}
0005433569693	00347F	5183 191243	VALENTINA KOROLEVA	{"phone": "+70477866612"}
0005433569694	00347F	6236 566507	ARTEM MELNIKOV	{"phone": "+70310582357"}
0005433569695	DF249D	3547 061447	YURIY SERGEEV	{"email": "sergeev_yuriy021984@postgrespro.ru", "phone": "+70138510910"}
0005433569696	548EB4	2330 508730	EKATERINA BELYAEVA	{"email": "belyaeva-ekaterina-1966@postgrespro.ru", "phone": "+70858986720"}
0005433569697	548EB4	1428 624105	VASILIY GORBUNOV	{"phone": "+70263950312"}
0005433569698	71154A	3836 282232	NADEZHDA DAVYDOVA	{"phone": "+70894210958"}
0005433569699	EDB390	4740 153388	ALEKSEY STEPANOV	{"email": "stepanova071974@postgrespro.ru", "phone": "+70964110406"}
0005433569700	3FDCC8	5135 907863	TATYANA DMITRIEVA	{"phone": "+70617963536"}
0005433569701	B981EB	5652 878182	MARIYA PAVLOVA	{"phone": "+70224034064"}
0005433569702	EC4833	7855 775843	ALEKSEY KISELEV	{"email": "kiselev_aleksey1965@postgrespro.ru", "phone": "+70012681598"}
0005433569703	4EF0E6	9757 341038	ALINA SOROKINA	{"email": "alina-sorokina.28101968@postgrespro.ru", "phone": "+70257831527"}
0005433569704	AA00F6	3537 800629	NIKOLAY BARANOV	{"phone": "+70016602584"}
0005433569705	1D1760	1129 364138	MARIYA TARASOVA	{"email": "tarasovam021977@postgrespro.ru", "phone": "+70914767559"}
0005433569706	CB6766	2864 774893	VIKTOR POPOV	{"email": "v_popov-09031962@postgrespro.ru", "phone": "+70976457270"}
0005433569707	F67B82	2466 640676	VALENTINA ANDREEVA	{"phone": "+70526673694"}
0005433569708	F67B82	5178 465024	GALINA TROFIMOVA	{"email": "g-trofimova1973@postgrespro.ru", "phone": "+70551408683"}
0005433569709	368136	8156 215991	GLEB GORBUNOV	{"phone": "+70548143587"}
0005433569710	72B7CD	5102 164154	SERGEY POPOV	{"email": "popovs_11021964@postgrespro.ru", "phone": "+70168413946"}
0005433569711	835510	6136 499443	VALENTINA FOMINA	{"phone": "+70705823283"}
0005433569712	FD0506	5115 418642	SVETLANA ZHUKOVA	{"email": "zhukova_s.26101973@postgrespro.ru", "phone": "+70501734107"}
0005433569713	9FD961	9991 574372	ARINA FOMINA	{"phone": "+70276817969"}
0005433569714	9FD961	8279 064997	ALEKSANDR KOZLOV	{"email": "akozlov_17101972@postgrespro.ru", "phone": "+70628554996"}
0005433569715	A8FEBA	5056 743488	EVGENIY KUZNECOV	{"phone": "+70317610430"}
0005433569716	DF6751	8725 927042	SERGEY MIKHAYLOV	{"email": "mikhaylov_sergey_24091965@postgrespro.ru", "phone": "+70921846935"}
0005433569717	14300E	1898 737144	LIDIYA NESTEROVA	{"phone": "+70160385795"}
0005433569718	30C291	8131 694912	GALINA KOZLOVA	{"email": "kozlova_galina_081960@postgrespro.ru", "phone": "+70174748874"}
0005433569719	472C1C	9831 901803	GALINA TIKHONOVA	{"phone": "+70712036047"}
0005433569720	B021DC	8598 486943	MAKSIM PAVLOV	{"email": "pavlov-maksim101966@postgrespro.ru", "phone": "+70144731640"}
0005433569721	ADE8B0	0817 641146	ANATOLIY MEDVEDEV	{"email": "medvedev-anatoliy-24031985@postgrespro.ru", "phone": "+70530433699"}
0005433569722	ABD6BC	4571 000044	TATYANA IVANOVA	{"email": "tatyana.ivanova_1985@postgrespro.ru", "phone": "+70140956859"}
0005433569723	9EE176	4789 230986	DMITRIY DENISOV	{"email": "dmitriy.denisov-1974@postgrespro.ru", "phone": "+70141358571"}
0005433569724	B4D64A	4939 275082	ALEKSEY DMITRIEV	{"phone": "+70818710907"}
0005433569725	B4D64A	5344 443293	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay1978@postgrespro.ru", "phone": "+70006482088"}
0005433569726	B4D64A	7136 965453	TATYANA IVANOVA	{"email": "ivanova_tatyana_08081983@postgrespro.ru", "phone": "+70567846829"}
0005433569727	6F3C3E	2811 333417	ALEKSEY FROLOV	{"phone": "+70796935219"}
0005433569728	6F3C3E	8316 594360	BOGDAN ABRAMOV	{"phone": "+70800180922"}
0005433569729	0833A5	7873 754814	DARYA OVCHINNIKOVA	{"email": "darya_ovchinnikova121985@postgrespro.ru", "phone": "+70777925088"}
0005433569730	124E9C	5028 713310	VLADIMIR MIRONOV	{"email": "v.mironov.1966@postgrespro.ru", "phone": "+70852416796"}
0005433569731	4D0EB7	4451 176266	LYUBOV SERGEEVA	{"email": "sergeeva-l.18011977@postgrespro.ru", "phone": "+70381157471"}
0005433569732	4D0EB7	2423 649047	EKATERINA NAZAROVA	{"email": "enazarova_111976@postgrespro.ru", "phone": "+70379850943"}
0005433569733	4D0EB7	7621 300674	ANASTASIYA ZAYCEVA	{"email": "anastasiya-zayceva111975@postgrespro.ru", "phone": "+70438453501"}
0005433569734	CDF662	8146 932096	TATYANA EGOROVA	{"email": "egorova_t06041973@postgrespro.ru", "phone": "+70683401156"}
0005433569735	0F5CFB	9117 125038	GENNADIY SCHERBAKOV	{"email": "g.scherbakov.02091992@postgrespro.ru", "phone": "+70366487995"}
0005433569736	CB6E0C	7771 489673	TATYANA ZAKHAROVA	{"phone": "+70507559104"}
0005433569737	13F589	5459 974110	ROZA AFANASEVA	{"email": "afanaseva_roza1968@postgrespro.ru", "phone": "+70908317545"}
0005433569738	DCF4D2	8025 449771	GALINA MIKHAYLOVA	{"email": "mikhaylova-galina101980@postgrespro.ru", "phone": "+70287322667"}
0005433569739	DCF4D2	7856 736244	ALEKSANDR KUZNECOV	{"email": "a.kuznecov-10051970@postgrespro.ru", "phone": "+70199018059"}
0005433569740	E34C85	3645 149229	PAVEL FEDOROV	{"phone": "+70257306523"}
0005433569741	D850A0	8690 451128	DENIS PETROV	{"phone": "+70521363515"}
0005433569742	D850A0	6115 807573	DZHAMILYA ANISIMOVA	{"email": "anisimovadzhamilya-061967@postgrespro.ru", "phone": "+70628941974"}
0005433569743	D850A0	3900 024006	OLGA KOVALEVA	{"email": "kovaleva.olga.101963@postgrespro.ru", "phone": "+70136334010"}
0005433569744	959D21	7245 101260	YULIYA EGOROVA	{"email": "yuliya_egorova.1978@postgrespro.ru", "phone": "+70480152530"}
0005433569745	959D21	1188 423292	NIKITA SOROKIN	{"email": "nikitasorokin-1974@postgrespro.ru", "phone": "+70225924749"}
0005433569746	646870	8839 359244	ANNA POPOVA	{"email": "popova_anna_1979@postgrespro.ru", "phone": "+70463360935"}
0005433569747	DC1F66	2989 647773	IBRAGIM KUZNECOV	{"phone": "+70525381609"}
0005433569748	DC1F66	4041 686392	IGOR PETROV	{"email": "petrovi.061967@postgrespro.ru", "phone": "+70766820058"}
0005433569749	52A562	1722 668392	ELENA KOLESNIKOVA	{"email": "e.kolesnikova.1965@postgrespro.ru", "phone": "+70748365658"}
0005433569750	550822	1201 935567	VLADIMIR DENISOV	{"email": "denisov.v_13021966@postgrespro.ru", "phone": "+70535270233"}
0005433569751	550822	6737 207251	VLADIMIR ZAKHAROV	{"phone": "+70035164714"}
0005433569752	550822	5717 549323	SVETLANA LOGINOVA	{"email": "svetlana_loginova-031960@postgrespro.ru", "phone": "+70021462899"}
0005433569753	E577DB	2967 555740	OKSANA ALEKSANDROVA	{"email": "oksanaaleksandrova02111982@postgrespro.ru", "phone": "+70030774269"}
0005433569754	810323	8655 904765	YANA KUZMINA	{"phone": "+70331218738"}
0005433569755	397D32	9863 249581	IRINA SOROKINA	{"phone": "+70989676833"}
0005433569756	46433B	5851 826853	LYUDMILA ZAKHAROVA	{"email": "lzakharova.071954@postgrespro.ru", "phone": "+70030489460"}
0005433569757	FC5625	4204 996210	YAROSLAV NAUMOV	{"email": "yaroslavnaumov121972@postgrespro.ru", "phone": "+70561986936"}
0005433569758	A9B472	6263 997579	NADEZHDA PAVLOVA	{"phone": "+70791934395"}
0005433569759	00B811	1260 741469	VERONIKA ALEKSANDROVA	{"email": "v-aleksandrova02031978@postgrespro.ru", "phone": "+70720759313"}
0005433569760	3FB454	5214 725154	DMITRIY RODIONOV	{"phone": "+70869477722"}
0005433569761	C523BC	9486 069014	ILGIZ MAKAROV	{"phone": "+70803171926"}
0005433569762	326C11	1501 467210	ANNA KOROLEVA	{"phone": "+70145217847"}
0005433569763	8DF591	7407 635845	ANATOLIY MARTYNOV	{"phone": "+70899238394"}
0005433569764	8DF591	2528 010750	ALEKSANDR FOMIN	{"email": "fomin-a-1976@postgrespro.ru", "phone": "+70969099888"}
0005433569765	E5CAD6	3620 099458	VIKTOR KISELEV	{"email": "viktor_kiselev1963@postgrespro.ru", "phone": "+70158218698"}
0005433569766	32B4D5	0820 441167	NADEZHDA BOGDANOVA	{"email": "nadezhda-bogdanova_1971@postgrespro.ru", "phone": "+70184052614"}
0005433569767	F84187	7364 812377	YULIYA POPOVA	{"phone": "+70455348886"}
0005433569768	DD3DC6	5193 256822	VALENTIN KRASNOV	{"phone": "+70258956311"}
0005433569769	DD3DC6	7753 365522	VLADIMIR PETROV	{"email": "petrovv-09121976@postgrespro.ru", "phone": "+70157901137"}
0005433569770	DD3DC6	8313 780639	EDUARD KUZNECOV	{"email": "e.kuznecov1973@postgrespro.ru", "phone": "+70263259140"}
0005433569771	E88C3F	3224 069376	SVETLANA GORBUNOVA	{"phone": "+70859537646"}
0005433569772	E88C3F	8922 119771	ANASTASIYA ARKHIPOVA	{"email": "arkhipovaa_1967@postgrespro.ru", "phone": "+70168637666"}
0005433569773	E35731	4779 206315	SERGEY EGOROV	{"email": "s.egorov.09091981@postgrespro.ru", "phone": "+70789147747"}
0005433569774	C35C86	5764 347002	DANIIL BELOV	{"phone": "+70409950840"}
0005433569775	8E2BFC	6322 118714	LIDIYA SMIRNOVA	{"email": "l.smirnova.04081980@postgrespro.ru", "phone": "+70330326963"}
0005433569776	F2C423	9841 112858	IRINA FEDOROVA	{"email": "irinafedorova.1963@postgrespro.ru", "phone": "+70282366275"}
0005433569777	36DE4D	0967 773145	ALEKSEY SOROKIN	{"phone": "+70752457943"}
0005433569778	B54933	2340 202804	RAVIL KUDRYASHOV	{"email": "kudryashov-ravil.081971@postgrespro.ru", "phone": "+70902424525"}
0005433569779	E510C6	4121 382333	DANIIL VOLKOV	{"email": "volkov_daniil051979@postgrespro.ru", "phone": "+70880362249"}
0005433569780	E510C6	0468 788171	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev-10091972@postgrespro.ru", "phone": "+70881248907"}
0005433569781	E510C6	4839 033335	VLADIMIR NAZAROV	{"email": "nazarovv.021970@postgrespro.ru", "phone": "+70626843973"}
0005433569782	230352	7307 737962	VLADIMIR NIKITIN	{"phone": "+70696785529"}
0005433569783	A59A46	7680 562853	MARIYA GORBUNOVA	{"phone": "+70658795897"}
0005433569784	1AC5C2	9086 978695	SVETLANA DANILOVA	{"phone": "+70439704381"}
0005433569785	1AC5C2	6002 852510	NIKOLAY KUZNECOV	{"email": "kuznecov.n.1979@postgrespro.ru", "phone": "+70123578248"}
0005433569786	1B298E	4791 080470	ALEKSEY KOZLOV	{"email": "kozlovaleksey_061978@postgrespro.ru", "phone": "+70860850910"}
0005433569787	1B298E	7407 929178	LYUDMILA MAKAROVA	{"phone": "+70831472726"}
0005433569788	A96240	6615 470658	YURIY ORLOV	{"phone": "+70795148272"}
0005433569789	A96240	4033 333504	ELENA KAZAKOVA	{"email": "kazakova_e-041975@postgrespro.ru", "phone": "+70833696531"}
0005433569790	D8796B	7527 542766	RAMIS NAZAROV	{"phone": "+70863356480"}
0005433569791	D8796B	1387 880741	ANNA SEMENOVA	{"email": "semenovaanna_1978@postgrespro.ru", "phone": "+70569532640"}
0005433569792	614953	8758 580497	ELIZAVETA DENISOVA	{"email": "denisovaelizaveta_19081976@postgrespro.ru", "phone": "+70820362995"}
0005433569793	214661	1775 013137	SERGEY BELOV	{"email": "belov.sergey-081967@postgrespro.ru", "phone": "+70774102324"}
0005433569794	038EB8	9595 066907	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov_021963@postgrespro.ru", "phone": "+70195966646"}
0005433569795	A08880	4379 990065	NADEZHDA ERMAKOVA	{"phone": "+70812188112"}
0005433569796	401B35	2114 885164	MARINA FILIPPOVA	{"phone": "+70237310895"}
0005433569797	401B35	8991 882184	ALLA LUKYANOVA	{"phone": "+70276327488"}
0005433569798	921536	1015 720790	RUMIYA MAKAROVA	{"email": "makarovarumiya_1978@postgrespro.ru", "phone": "+70288377491"}
0005433569799	921536	6375 192656	ALEKSEY SERGEEV	{"email": "sergeev-a081964@postgrespro.ru", "phone": "+70098497605"}
0005433569800	290340	9203 043148	IRINA BARANOVA	{"phone": "+70217670521"}
0005433569801	5C2147	3083 779856	IGOR MIKHAYLOV	{"phone": "+70219065669"}
0005433569802	A5E3FC	3401 230163	IRINA NIKITINA	{"email": "irinanikitina.021977@postgrespro.ru", "phone": "+70870103490"}
0005433569803	768DE9	1327 549110	IGOR ZAKHAROV	{"phone": "+70958685346"}
0005433569804	768DE9	1365 590214	ELENA SEMENOVA	{"phone": "+70369091963"}
0005433569805	4345E1	8872 712635	OLGA KONDRATEVA	{"phone": "+70382262878"}
0005433569806	4345E1	2652 819427	GENNADIY GAVRILOV	{"phone": "+70532625425"}
0005433569807	4345E1	2519 010008	KSENIYA STEPANOVA	{"phone": "+70303158018"}
0005433569808	F2FE55	2699 833600	YURIY NOVIKOV	{"phone": "+70783582501"}
0005433569809	F2FE55	4980 108605	VIKTOR GRIGOREV	{"phone": "+70840544674"}
0005433569810	F71922	7140 695727	SERGEY MOROZOV	{"phone": "+70980893110"}
0005433569811	E5FAF7	8732 569840	NADEZHDA NIKIFOROVA	{"phone": "+70367121072"}
0005433569812	03B1B7	1153 010900	LILIYA EFREMOVA	{"phone": "+70136216741"}
0005433569813	C5BA05	1131 433773	TAMARA KONDRATEVA	{"phone": "+70712642848"}
0005433569814	CEA69B	4729 127339	IRINA ANDREEVA	{"phone": "+70250310647"}
0005433569815	2A5F46	7607 886532	EGOR SHEVCHENKO	{"phone": "+70772556851"}
0005433569816	A82A68	0354 590075	ANASTASIYA VOLKOVA	{"phone": "+70471156032"}
0005433569817	A82A68	9361 101787	NIKITA POPOV	{"phone": "+70624640965"}
0005433569818	8B83E0	5122 506635	VYACHESLAV KONOVALOV	{"phone": "+70740725494"}
0005433569819	35EA17	2989 947624	ANTONINA KUZMINA	{"email": "antonina-kuzmina101960@postgrespro.ru", "phone": "+70392590593"}
0005433569820	35EA17	2210 940836	VIKTOR POPOV	{"email": "popov.viktor-061976@postgrespro.ru", "phone": "+70681268477"}
0005433569821	3FD218	1879 471818	LYUDMILA POPOVA	{"phone": "+70179470739"}
0005433569822	AE8667	8423 701152	ALEKSANDR BELOV	{"phone": "+70158353995"}
0005433569823	A4FC71	7793 734387	TATYANA AFANASEVA	{"phone": "+70352767331"}
0005433570064	42FF11	7970 905049	YULIYA KONOVALOVA	{"phone": "+70835220393"}
0005433569824	A10F4F	4964 351449	NINA SIDOROVA	{"email": "nina_sidorova_1965@postgrespro.ru", "phone": "+70166481937"}
0005433569825	C1D207	3429 373721	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov011965@postgrespro.ru", "phone": "+70891974055"}
0005433569826	599D56	5833 509529	ANTONINA KUZNECOVA	{"email": "a.kuznecova.091978@postgrespro.ru", "phone": "+70013848679"}
0005433569827	512C95	0623 559024	NATALYA VASILEVA	{"email": "vasileva_natalya.02091966@postgrespro.ru", "phone": "+70216585102"}
0005433569828	217A0F	2102 029374	EDUARD MOROZOV	{"email": "eduardmorozov_1969@postgrespro.ru", "phone": "+70296549407"}
0005433569829	5DB18C	1469 248206	YURIY MIKHAYLOV	{"phone": "+70215519252"}
0005433569830	AC9EF3	9208 090026	KARINA ZHURAVLEVA	{"phone": "+70181881255"}
0005433569831	6A8CA1	9720 467887	SERGEY ANTONOV	{"phone": "+70279429547"}
0005433569832	433CAD	7841 928725	MAKAR ALEKSEEV	{"phone": "+70131628271"}
0005433569833	433CAD	6955 037448	MARK NIKITIN	{"email": "mark.nikitin-081972@postgrespro.ru", "phone": "+70779473400"}
0005433569834	B363F9	5455 367352	ANATOLIY AFANASEV	{"email": "a_afanasev101971@postgrespro.ru", "phone": "+70788280464"}
0005433569835	B363F9	9494 201578	MIKHAIL POPOV	{"email": "popovmikhail.15051970@postgrespro.ru", "phone": "+70631548267"}
0005433569836	D2768B	9723 018517	ANASTASIYA SOKOLOVA	{"phone": "+70179588709"}
0005433569837	BABD96	7042 249857	ALEKSANDR SERGEEV	{"email": "a.sergeev_021963@postgrespro.ru", "phone": "+70567572227"}
0005433569838	B5C0E3	4134 979553	OLEG MIKHAYLOV	{"phone": "+70635171529"}
0005433569839	8D2540	4721 649976	VALERIY SEMENOV	{"email": "v_semenov-01021970@postgrespro.ru", "phone": "+70401250783"}
0005433569840	8D2540	1286 915544	IRINA KUZMINA	{"email": "irina_kuzmina011968@postgrespro.ru", "phone": "+70931641813"}
0005433569841	E06BF2	7686 331726	ALLA NIKITINA	{"email": "a-nikitina.041964@postgrespro.ru", "phone": "+70794366646"}
0005433569843	0DA3EA	0631 169355	TAMARA PAVLOVA	{"email": "pavlova-t28051966@postgrespro.ru", "phone": "+70022449973"}
0005433569844	1732A9	7377 686791	YULIYA DAVYDOVA	{"email": "ydavydova_1973@postgrespro.ru", "phone": "+70495075752"}
0005433569845	D54F84	8531 294582	NATALYA ALEKSEEVA	{"phone": "+70238068281"}
0005433569846	01A42B	9934 797315	YURIY SOKOLOV	{"email": "yuriy_sokolov-27071979@postgrespro.ru", "phone": "+70289631390"}
0005433569847	F45045	0394 851823	OLGA SEMENOVA	{"email": "semenovaolga-071963@postgrespro.ru", "phone": "+70044280966"}
0005433569848	1B3105	3696 505380	MARINA TIKHONOVA	{"phone": "+70516305976"}
0005433569849	042DFF	0868 011496	ELENA SERGEEVA	{"phone": "+70753836361"}
0005433569850	49EEC6	7363 387418	ALEKSANDR POPOV	{"email": "a.popov101986@postgrespro.ru", "phone": "+70912684203"}
0005433569851	7F38B5	7302 242465	OLEG ALEKSEEV	{"email": "oleg.alekseev14071961@postgrespro.ru", "phone": "+70234091412"}
0005433569852	1EFCCA	5701 708403	ANNA GERASIMOVA	{"phone": "+70974378458"}
0005433569853	3188D1	7840 633436	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev111967@postgrespro.ru", "phone": "+70837419379"}
0005433569854	EC64DC	2843 174043	EKATERINA POPOVA	{"phone": "+70113785964"}
0005433569855	C96742	0721 823847	NATALIYA PAVLOVA	{"email": "pavlova-n02101969@postgrespro.ru", "phone": "+70163667808"}
0005433569856	CEF8A6	4331 362291	NINA IVANOVA	{"email": "n_ivanova.1980@postgrespro.ru", "phone": "+70252476840"}
0005433569857	3B5746	7433 719379	MAKSIM DAVYDOV	{"email": "davydov.m-1969@postgrespro.ru", "phone": "+70645231530"}
0005433569858	10D68E	4268 488936	NADEZHDA NESTEROVA	{"phone": "+70056995457"}
0005433569859	F922A2	6431 070410	KSENIYA VLASOVA	{"email": "vlasova_k061974@postgrespro.ru", "phone": "+70699737509"}
0005433569860	0C99A9	2426 368132	ANFISA SEMENOVA	{"phone": "+70180814061"}
0005433569861	836B2F	7194 512941	YURIY ALEKSEEV	{"phone": "+70229385442"}
0005433569862	11DD01	8357 213528	IGOR ILIN	{"email": "igorilin_101974@postgrespro.ru", "phone": "+70516546101"}
0005433569863	CCE8EB	3412 982257	VALENTINA FOMINA	{"email": "valentina-fomina17091967@postgrespro.ru", "phone": "+70023903951"}
0005433569864	188A25	8592 792525	ILYA STEPANOV	{"phone": "+70260358293"}
0005433569865	188A25	7293 270411	ANATOLIY IVANOV	{"email": "a.ivanov-1974@postgrespro.ru", "phone": "+70936315746"}
0005433569866	460F18	6848 830102	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova-02091961@postgrespro.ru", "phone": "+70972504552"}
0005433569867	76E7C9	1706 915400	TIMUR SAVELEV	{"phone": "+70426957287"}
0005433569868	B98864	3779 214821	ALINA GUSEVA	{"email": "aguseva_1964@postgrespro.ru", "phone": "+70564609511"}
0005433569869	B98864	4742 933512	ANATOLIY DMITRIEV	{"phone": "+70127858591"}
0005433569870	844D6A	2788 198490	SERGEY GUSEV	{"email": "gusevsergey111975@postgrespro.ru", "phone": "+70087802168"}
0005433569871	844D6A	3975 428125	ARTUR TIKHONOV	{"phone": "+70846973363"}
0005433569872	FAA973	7802 113303	SVETLANA KUZNECOVA	{"phone": "+70842499729"}
0005433569873	67C555	1049 273523	YURIY SCHERBAKOV	{"phone": "+70298536469"}
0005433569874	61F636	4294 518306	EGOR KUDRYASHOV	{"phone": "+70435214280"}
0005433569875	61F636	4150 687451	ANNA GERASIMOVA	{"phone": "+70353085432"}
0005433569876	93CD47	7854 861732	OLGA TARASOVA	{"email": "tarasova-olga_1973@postgrespro.ru", "phone": "+70199717449"}
0005433569877	4EE504	8299 110408	TATYANA GERASIMOVA	{"email": "tatyana-gerasimova-1969@postgrespro.ru", "phone": "+70800415953"}
0005433569878	4EE504	4140 921621	NATALYA SIDOROVA	{"email": "sidorova.natalya111971@postgrespro.ru", "phone": "+70175997363"}
0005433569879	B49649	5554 036700	ILYA SIDOROV	{"phone": "+70200010020"}
0005433569880	5FD08E	1545 088112	TATYANA FOMINA	{"phone": "+70531688911"}
0005433569881	21A722	5456 249300	VERA TARASOVA	{"phone": "+70057683005"}
0005433569882	484B14	3979 918124	DMITRIY MIRONOV	{"email": "d_mironov_1964@postgrespro.ru", "phone": "+70801929361"}
0005433569883	484B14	8818 295062	NIKOLAY DAVYDOV	{"phone": "+70034328023"}
0005433570065	CF4948	6590 624876	VERONIKA SMIRNOVA	{"phone": "+70252898916"}
0005433569884	2166BE	7564 911969	TATYANA SOKOLOVA	{"email": "t_sokolova.25021974@postgrespro.ru", "phone": "+70100623329"}
0005433569885	BC87DB	1358 409626	ANTONINA ZAKHAROVA	{"phone": "+70717461573"}
0005433569886	B90928	0907 074894	ANATOLIY ANDREEV	{"phone": "+70587902398"}
0005433569887	B90928	8118 383848	MIKHAIL ORLOV	{"phone": "+70495667496"}
0005433569888	AB90CE	3908 151072	GALINA MIKHAYLOVA	{"email": "g.mikhaylova1975@postgrespro.ru", "phone": "+70013566664"}
0005433569889	C151A2	5110 374008	NAIL ILIN	{"email": "ilin.nail23101963@postgrespro.ru", "phone": "+70587309010"}
0005433569890	C151A2	8616 706999	ALEKSANDR SOROKIN	{"phone": "+70310151956"}
0005433569891	E33C25	4504 750510	SERGEY SAVELEV	{"phone": "+70897846764"}
0005433569892	5B2C5E	5724 480565	PAVEL MOROZOV	{"phone": "+70738955641"}
0005433569893	5B2C5E	3247 542732	EKATERINA MATVEEVA	{"phone": "+70688087901"}
0005433569894	246FE5	7926 684305	MARINA EFREMOVA	{"email": "efremovamarina.1974@postgrespro.ru", "phone": "+70232203508"}
0005433569895	246FE5	6931 139278	ANDREY TARASOV	{"phone": "+70964052637"}
0005433569896	9173C7	1424 541703	ANTONINA NIKOLAEVA	{"phone": "+70532608444"}
0005433569897	FC5A28	1189 399723	MARINA KUZNECOVA	{"email": "kuznecova_marina.1971@postgrespro.ru", "phone": "+70646378533"}
0005433569898	FC5A28	8710 726677	NADEZHDA FOMINA	{"phone": "+70462476873"}
0005433569899	B832F0	0439 724419	VLADIMIR DMITRIEV	{"email": "dmitriev_vladimir.09071980@postgrespro.ru", "phone": "+70086968448"}
0005433569900	6C3719	6375 025697	MARINA STEPANOVA	{"email": "m-stepanova-1971@postgrespro.ru", "phone": "+70784436159"}
0005433569901	21295C	0744 518417	OLGA SAVELEVA	{"phone": "+70708838100"}
0005433569902	D05A20	9416 995516	STEPAN NIKITIN	{"email": "stepan_nikitin_1966@postgrespro.ru", "phone": "+70333012394"}
0005433569903	D05A20	1523 718300	OLGA MAKAROVA	{"phone": "+70712586155"}
0005433569904	409361	2955 132297	ANDREY KUZNECOV	{"email": "kuznecov.andrey.041967@postgrespro.ru", "phone": "+70300249406"}
0005433569905	FF39B9	9944 747436	SVETLANA NESTEROVA	{"email": "svetlana-nesterova.081975@postgrespro.ru", "phone": "+70851548915"}
0005433569906	FF39B9	7759 084061	ALEKSANDR STEPANOV	{"phone": "+70002414821"}
0005433569907	0C56B7	5054 675765	ALEKSEY KUZNECOV	{"email": "kuznecov-a_051971@postgrespro.ru", "phone": "+70197932869"}
0005433569908	4B64B5	6138 562302	ZOYA MEDVEDEVA	{"phone": "+70581090257"}
0005433569909	1CD667	9740 046621	IVAN GUSEV	{"email": "gusev.ivan1975@postgrespro.ru", "phone": "+70114065267"}
0005433569910	AF78CE	5297 116757	STANISLAV YAKOVLEV	{"email": "yakovlevs021978@postgrespro.ru", "phone": "+70832754521"}
0005433569911	0B2851	8298 269290	GALINA GORBUNOVA	{"phone": "+70297530868"}
0005433569912	0B2851	2089 493019	SVETLANA ORLOVA	{"phone": "+70585220658"}
0005433569913	0B2851	1771 171771	ANTON NAZAROV	{"phone": "+70758048952"}
0005433569914	C63EE4	5495 742010	EVGENIYA SEMENOVA	{"phone": "+70914820982"}
0005433569915	C489E2	4058 295047	ALEKSEY PETROV	{"email": "petrov-a26021976@postgrespro.ru", "phone": "+70082857362"}
0005433569916	6BA4CD	3406 544106	DANILA EGOROV	{"email": "egorov_danila.1964@postgrespro.ru", "phone": "+70805663614"}
0005433569917	5B2C49	5638 943080	EKATERINA FILIPPOVA	{"email": "filippova-e011972@postgrespro.ru", "phone": "+70024182534"}
0005433569918	45CFF9	3991 569053	SVETLANA EGOROVA	{"phone": "+70225110650"}
0005433569919	45CFF9	3264 382925	SERGEY STEPANOV	{"phone": "+70370145042"}
0005433569920	6D6BF6	9626 853403	OLEG KAZAKOV	{"email": "o-kazakov1960@postgrespro.ru", "phone": "+70434646694"}
0005433569921	55A151	8988 720915	VYACHESLAV STEPANOV	{"phone": "+70940133026"}
0005433569922	55A151	8916 271514	SERGEY CHERNOV	{"phone": "+70356569765"}
0005433569923	F4FC52	4576 614171	VLADIMIR FEDOROV	{"email": "vladimir-fedorov.1982@postgrespro.ru", "phone": "+70238475119"}
0005433569924	F4FC52	4910 750296	ELENA ALEKSEEVA	{"phone": "+70277407774"}
0005433569925	836D34	4013 714299	ARTUR FEDOROV	{"phone": "+70096312985"}
0005433569926	836D34	8688 439221	TATYANA BORISOVA	{"email": "borisova.t_27021972@postgrespro.ru", "phone": "+70980345859"}
0005433569927	E9C4D1	2478 960198	TAMARA NESTEROVA	{"phone": "+70341671962"}
0005433569928	F37508	6039 852976	VLADIMIR NIKITIN	{"email": "nikitin_v-111963@postgrespro.ru", "phone": "+70152213944"}
0005433569929	F37508	2393 444368	POLINA GORBUNOVA	{"email": "gorbunova_p-1967@postgrespro.ru", "phone": "+70257818558"}
0005433569930	B58CC0	5078 322434	NINA VLASOVA	{"email": "vlasova_nina1970@postgrespro.ru", "phone": "+70716265991"}
0005433569931	F6CFFF	5471 061207	ALBINA ANDREEVA	{"email": "a.andreeva-121980@postgrespro.ru", "phone": "+70823223835"}
0005433569932	2EFB7B	4280 478934	ANATOLIY EGOROV	{"phone": "+70971263850"}
0005433569933	2EFB7B	1721 493230	MARGARITA SIDOROVA	{"phone": "+70099683161"}
0005433569934	CEEAA2	9256 995180	KLAVDIYA BELYAEVA	{"phone": "+70856798515"}
0005433569935	0220D2	3903 322983	VIKTOR CHERNOV	{"email": "chernov.viktor031956@postgrespro.ru", "phone": "+70129626676"}
0005433569936	0220D2	9919 561355	PAVEL MAKAROV	{"email": "p_makarov.061972@postgrespro.ru", "phone": "+70466550937"}
0005433569937	8AE8CF	5153 667743	SERGEY NOVIKOV	{"phone": "+70279648666"}
0005433569938	6E0DBF	1400 196241	LYUBOV FEDOROVA	{"email": "l_fedorova_1977@postgrespro.ru", "phone": "+70213221317"}
0005433569939	CF0198	2875 911675	NINA ILINA	{"phone": "+70352492533"}
0005433569940	8D9F15	6730 996290	ANNA GAVRILOVA	{"email": "gavrilova.anna_01091973@postgrespro.ru", "phone": "+70367036782"}
0005433569941	F5012A	4867 422468	SERGEY ZHURAVLEV	{"email": "s.zhuravlev-19101982@postgrespro.ru", "phone": "+70173385450"}
0005433569942	261B80	8084 637666	EGOR PAVLOV	{"email": "pavlovegor20071964@postgrespro.ru", "phone": "+70500372300"}
0005433569943	530262	0984 339797	NIKOLAY SEMENOV	{"email": "n_semenov-1965@postgrespro.ru", "phone": "+70858215290"}
0005433569944	AD342E	1814 325488	SERGEY SHEVCHENKO	{"phone": "+70513431136"}
0005433569945	D8667A	8329 620905	NIKOLAY FOMIN	{"email": "n-fomin-061963@postgrespro.ru", "phone": "+70864031392"}
0005433569946	D8667A	2700 212911	ELENA GORBUNOVA	{"phone": "+70066016310"}
0005433569947	843E64	9790 161302	MARIYA FROLOVA	{"email": "m_frolova-041969@postgrespro.ru", "phone": "+70173538844"}
0005433569948	A24702	5190 069312	SERGEY FEDOROV	{"phone": "+70648533175"}
0005433569949	932C0D	8577 900262	EVGENIY KUZMIN	{"phone": "+70542533778"}
0005433569950	932C0D	0472 344812	YULIYA NIKITINA	{"email": "nikitina-y-1973@postgrespro.ru", "phone": "+70050437736"}
0005433569951	9AC86E	2931 528671	NIKOLAY SEMENOV	{"phone": "+70845954063"}
0005433569952	3487CA	5678 131636	NATALYA TIKHONOVA	{"phone": "+70443407690"}
0005433569953	EF0976	7394 194516	NIKITA TIMOFEEV	{"email": "nikita_timofeev101980@postgrespro.ru", "phone": "+70704391825"}
0005433569954	EF0976	7508 966179	LILIYA IVANOVA	{"phone": "+70561649716"}
0005433569955	B0D109	3104 756134	SERGEY RODIONOV	{"phone": "+70726216784"}
0005433569956	A087BC	9961 971384	VIKTOR MAKAROV	{"phone": "+70328781095"}
0005433569957	EDA081	6723 286113	ANATOLIY MOROZOV	{"email": "morozov-a-111981@postgrespro.ru", "phone": "+70141443778"}
0005433569958	A44459	2221 469598	MARIYA FROLOVA	{"email": "frolovam_121970@postgrespro.ru", "phone": "+70601225329"}
0005433569959	A44459	3749 495637	ALEKSANDRA BELYAEVA	{"email": "aleksandra.belyaeva_26071968@postgrespro.ru", "phone": "+70429437950"}
0005433569960	82531C	1988 218675	MIKHAIL ANDREEV	{"email": "andreev.m_07081979@postgrespro.ru", "phone": "+70776617904"}
0005433569961	FC2AC4	7537 448429	VALENTINA ALEKSANDROVA	{"phone": "+70411269901"}
0005433569962	CFA034	2450 751173	LYUDMILA FILATOVA	{"phone": "+70102532257"}
0005433569963	CFA034	3897 582458	RUSLAN VASILEV	{"phone": "+70378382545"}
0005433569964	52A4DB	9254 648300	EKATERINA OSIPOVA	{"phone": "+70382344840"}
0005433569965	221E7E	3742 077072	SERGEY DMITRIEV	{"email": "dmitriev.sergey1978@postgrespro.ru", "phone": "+70555375859"}
0005433569966	221E7E	4782 312980	MAKSIM IVANOV	{"email": "maksim-ivanov-1963@postgrespro.ru", "phone": "+70836022229"}
0005433569967	2FBA3A	7693 626953	OLGA ROMANOVA	{"email": "romanova-o1981@postgrespro.ru", "phone": "+70732009276"}
0005433569968	2FBA3A	7093 416777	ALEKSANDR DMITRIEV	{"phone": "+70433843105"}
0005433569969	75BD98	1422 673768	VIKTOR OSIPOV	{"phone": "+70472086924"}
0005433569970	A4141B	7200 370119	MAKSIM PETROV	{"email": "petrovm1968@postgrespro.ru", "phone": "+70469070320"}
0005433569971	0FF823	5149 327458	ROMAN IVANOV	{"phone": "+70918262641"}
0005433569972	F1D085	6439 950630	ALEKSEY VOROBEV	{"email": "alekseyvorobev031987@postgrespro.ru", "phone": "+70392661519"}
0005433569973	53AABC	5957 100318	SERGEY IVANOV	{"phone": "+70397965846"}
0005433569974	CCEBEB	8173 074894	VALENTIN TIKHONOV	{"email": "v-tikhonov-19021972@postgrespro.ru", "phone": "+70108329529"}
0005433569975	B0A584	8908 159377	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov-061973@postgrespro.ru", "phone": "+70627566908"}
0005433569976	49DA52	0002 835848	VLADISLAV ISAEV	{"email": "isaev_vladislav.01111957@postgrespro.ru", "phone": "+70012709094"}
0005433569977	0CB967	4393 200320	EDUARD KUZMIN	{"phone": "+70306915440"}
0005433569978	0CB967	9562 757249	RUSTAM KOZLOV	{"email": "r-kozlov-101976@postgrespro.ru", "phone": "+70587223336"}
0005433569979	3DDB62	6963 059879	SEMEN FEDOROV	{"phone": "+70378859255"}
0005433569980	2C4408	9527 995975	OKSANA BELOVA	{"email": "belova-o.071977@postgrespro.ru", "phone": "+70466398975"}
0005433569981	2C4408	8853 020943	VALENTINA ANTONOVA	{"phone": "+70391999954"}
0005433569982	2C4408	9572 738082	VIKTORIYA FILIPPOVA	{"phone": "+70345944535"}
0005433569983	A49914	7839 578462	NADEZHDA LAZAREVA	{"phone": "+70161815879"}
0005433569984	A49914	6418 925424	VERA NOVIKOVA	{"phone": "+70661837327"}
0005433569985	A49914	1529 328254	VIKTOR ANTONOV	{"email": "vantonov_021975@postgrespro.ru", "phone": "+70494552580"}
0005433569986	13A4A2	6921 741883	MIKHAIL MELNIKOV	{"phone": "+70272466545"}
0005433569987	ACBACA	4040 323287	ALEKSANDR FILIPPOV	{"email": "a.filippov31071971@postgrespro.ru", "phone": "+70429947933"}
0005433569988	ACBACA	2170 458502	PAVEL PETROV	{"email": "petrov-pavel.011964@postgrespro.ru", "phone": "+70918440976"}
0005433569989	E03B7A	6360 619839	SERGEY STEPANOV	{"phone": "+70212322350"}
0005433569990	BF129F	7376 468298	VERONIKA TIKHONOVA	{"phone": "+70529687711"}
0005433569991	65BE17	5768 914807	OLGA ZAKHAROVA	{"phone": "+70375158806"}
0005433569992	65BE17	9665 058619	VLADIMIR MIKHAYLOV	{"phone": "+70982133782"}
0005433569993	9A2EF9	3634 813979	TATYANA ISAEVA	{"phone": "+70973375339"}
0005433569994	6F6116	7948 749020	NIKOLAY AFANASEV	{"email": "afanasev_n.081971@postgrespro.ru", "phone": "+70816529201"}
0005433569995	55EAB3	9324 877553	TIMUR POPOV	{"email": "t_popov.04091971@postgrespro.ru", "phone": "+70515415275"}
0005433569996	956328	6222 014707	NATALYA IVANOVA	{"phone": "+70215778702"}
0005433569997	956328	7376 800712	MARIYA MAKAROVA	{"phone": "+70906633553"}
0005433569998	F49E64	0509 590539	MARIYA LAZAREVA	{"email": "lazareva-m_111965@postgrespro.ru", "phone": "+70757810655"}
0005433569999	8B00F8	9836 506416	DENIS KUZNECOV	{"email": "kuznecov-denis_1959@postgrespro.ru", "phone": "+70273339482"}
0005433570000	599546	8968 961842	ALEKSEY KRASNOV	{"phone": "+70617777172"}
0005433570001	73B299	5095 121962	OLGA SCHERBAKOVA	{"email": "olga-scherbakova_11121965@postgrespro.ru", "phone": "+70168198993"}
0005433570002	73B299	4929 472425	SERGEY SEMENOV	{"phone": "+70166785044"}
0005433570003	95CF0A	7403 131648	NATALYA VASILEVA	{"email": "n-vasileva-1963@postgrespro.ru", "phone": "+70879925264"}
0005433570004	3F93DE	5090 178848	LYUBOV ISAEVA	{"phone": "+70569582653"}
0005433570005	AE5CA6	1866 026646	NATALYA NIKOLAEVA	{"email": "natalya.nikolaeva_1974@postgrespro.ru", "phone": "+70770390226"}
0005433570308	FE0A6F	9107 007159	VYACHESLAV MATVEEV	{"phone": "+70731111058"}
0005433570006	8A1A3A	0548 139020	TATYANA DENISOVA	{"email": "tatyana-denisova.1979@postgrespro.ru", "phone": "+70969468113"}
0005433570007	3E9EB4	7487 340274	REGINA KUZNECOVA	{"email": "r_kuznecova08081980@postgrespro.ru", "phone": "+70549421492"}
0005433570008	A38568	3083 257935	EVGENIY ISAEV	{"phone": "+70505801763"}
0005433570009	ED11D8	1257 490648	KONSTANTIN ROMANOV	{"email": "romanov.konstantin-111979@postgrespro.ru", "phone": "+70540932921"}
0005433570010	ED11D8	3767 308970	MARAT VASILEV	{"email": "mvasilev_111981@postgrespro.ru", "phone": "+70136233327"}
0005433570011	811D37	4301 957885	INNA KUZNECOVA	{"email": "kuznecova.inna_22101973@postgrespro.ru", "phone": "+70112106759"}
0005433570012	018687	3951 820544	LYUDMILA FADEEVA	{"phone": "+70699394412"}
0005433570013	11557A	0102 418997	GALINA POPOVA	{"email": "popova_g.16051976@postgrespro.ru", "phone": "+70476623488"}
0005433570014	11557A	0110 794804	ARTEM NAZAROV	{"email": "artem_nazarov_1968@postgrespro.ru", "phone": "+70703167063"}
0005433570015	29E34C	0233 690728	LYUDMILA SOKOLOVA	{"phone": "+70915598505"}
0005433570016	65773A	9182 863590	DMITRIY SMIRNOV	{"email": "dmitriysmirnov.30011970@postgrespro.ru", "phone": "+70413809030"}
0005433570017	E47B33	2349 532387	PAVEL ZHUKOV	{"phone": "+70289009855"}
0005433570018	E47B33	5624 469541	OLGA KUDRYASHOVA	{"email": "olga_kudryashova11041967@postgrespro.ru", "phone": "+70797352762"}
0005433570019	17AC12	7043 119943	ALEKSEY FROLOV	{"phone": "+70447831102"}
0005433570020	17AC12	7516 515068	IVAN PETROV	{"phone": "+70374217822"}
0005433570021	C4C649	4620 315816	SERGEY KRASNOV	{"email": "sergey-krasnov1969@postgrespro.ru", "phone": "+70565758098"}
0005433570022	C4C649	0471 843642	ALEKSANDR IVANOV	{"phone": "+70909126854"}
0005433570023	C4C649	8156 641331	ALEKSEY ANDREEV	{"email": "a-andreev-111962@postgrespro.ru", "phone": "+70951744597"}
0005433570024	4A9B70	9447 096672	SERGEY IVANOV	{"phone": "+70093572352"}
0005433570025	913510	7673 071215	KSENIYA EFIMOVA	{"email": "k_efimova_1978@postgrespro.ru", "phone": "+70339272040"}
0005433570026	CD3E50	5743 633072	RAVIL VOLKOV	{"phone": "+70649542678"}
0005433570027	C13C83	6408 543771	VERA MATVEEVA	{"phone": "+70613735197"}
0005433570028	C13C83	6931 588239	MARIYA KUZNECOVA	{"email": "mariya-kuznecova-23011968@postgrespro.ru", "phone": "+70036122456"}
0005433570029	1F7638	7036 689162	TATYANA TIKHONOVA	{"phone": "+70384143592"}
0005433570030	9A032D	3406 253299	MARTA GERASIMOVA	{"email": "gerasimova_marta-021973@postgrespro.ru", "phone": "+70649615702"}
0005433570031	C2BA10	2058 596317	EVGENIY GRIGOREV	{"phone": "+70187216097"}
0005433570032	C2BA10	5951 164225	NIKOLAY DAVYDOV	{"email": "nikolay.davydov1970@postgrespro.ru", "phone": "+70122258549"}
0005433570033	C2BA10	0475 171971	MIKHAIL AFANASEV	{"phone": "+70247411581"}
0005433570034	5284D0	2546 895967	EKATERINA KUZNECOVA	{"phone": "+70101003006"}
0005433570035	1F3FAA	9876 399530	VITALIY FOMIN	{"phone": "+70201227095"}
0005433570036	A3219F	4423 794385	ANDREY MOROZOV	{"email": "morozovandrey_011968@postgrespro.ru", "phone": "+70748175404"}
0005433570037	A0920C	4158 922711	ANATOLIY FOMIN	{"email": "afomin.01071987@postgrespro.ru", "phone": "+70743777283"}
0005433570038	A0920C	9636 335594	ALEKSANDR ISAEV	{"email": "a.isaev_21061975@postgrespro.ru", "phone": "+70343745605"}
0005433570039	77261A	0302 593318	ALEKSEY ZHUKOV	{"email": "azhukov.111972@postgrespro.ru", "phone": "+70001482718"}
0005433570040	77261A	1073 212181	VLADISLAV SEMENOV	{"phone": "+70111398001"}
0005433570041	13F36A	0428 612871	VLADIMIR SMIRNOV	{"phone": "+70983203403"}
0005433570042	13F36A	0183 601604	ELENA FILATOVA	{"phone": "+70794724895"}
0005433570043	99840B	6712 967460	GENNADIY BELOV	{"email": "gennadiy_belov.29051967@postgrespro.ru", "phone": "+70793230051"}
0005433570044	99840B	7516 150785	ALEKSANDRA CHERNOVA	{"email": "a_chernova-25061969@postgrespro.ru", "phone": "+70934648808"}
0005433570045	A7BD16	8738 018193	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov_1983@postgrespro.ru", "phone": "+70347558512"}
0005433570046	3EA899	5498 171022	SOFYA KULIKOVA	{"email": "kulikova-sofya011984@postgrespro.ru", "phone": "+70818413318"}
0005433570047	BB7FB1	2906 740510	EKATERINA ISAEVA	{"phone": "+70013651500"}
0005433570048	BB7FB1	7172 192061	LIDIYA NOVIKOVA	{"email": "novikova.lidiya_041969@postgrespro.ru", "phone": "+70796741553"}
0005433570049	270912	3099 470420	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva.29031964@postgrespro.ru", "phone": "+70192220277"}
0005433570050	270912	2540 225657	VIKTOR ROMANOV	{"email": "viktor.romanov-1970@postgrespro.ru", "phone": "+70502875807"}
0005433570051	8DD69A	2523 063832	ALEKSEY TIMOFEEV	{"email": "timofeevaleksey1955@postgrespro.ru", "phone": "+70759268024"}
0005433570052	8DD69A	4173 860079	NATALYA KOVALEVA	{"email": "kovaleva.natalya-1972@postgrespro.ru", "phone": "+70603194034"}
0005433570053	69946B	2303 368987	LIDIYA GERASIMOVA	{"email": "gerasimova-l_15041965@postgrespro.ru", "phone": "+70110753556"}
0005433570054	372774	8464 514224	NIKOLAY ZAYCEV	{"phone": "+70092771451"}
0005433570055	372774	1044 846611	ALEKSEY ZAYCEV	{"email": "a-zaycev_121961@postgrespro.ru", "phone": "+70761071357"}
0005433570056	A25C62	7679 491914	ANNA RYABOVA	{"email": "ryabova.anna-1977@postgrespro.ru", "phone": "+70521664197"}
0005433570057	91431E	3608 148322	ALEKSANDR GAVRILOV	{"email": "gavrilov.aleksandr111974@postgrespro.ru", "phone": "+70047561240"}
0005433570058	91431E	6244 280502	SOFYA FILIPPOVA	{"email": "filippova_s26041965@postgrespro.ru", "phone": "+70516156951"}
0005433570059	0635E2	5805 864167	LIDIYA EGOROVA	{"email": "egoroval-1971@postgrespro.ru", "phone": "+70503575842"}
0005433570060	0635E2	3539 966174	ALEKSEY ANDREEV	{"email": "andreev.aleksey1977@postgrespro.ru", "phone": "+70342303158"}
0005433570061	8F5B2D	6287 238391	RUSTAM ABRAMOV	{"phone": "+70655560993"}
0005433570062	8F5B2D	8181 904728	RAISA BOGDANOVA	{"phone": "+70024538805"}
0005433570063	42FF11	6408 998982	ELENA LEBEDEVA	{"email": "elenalebedeva091974@postgrespro.ru", "phone": "+70913719789"}
0005433570066	5CA1F2	4009 192622	MIKHAIL STEPANOV	{"email": "mikhail-stepanov-051976@postgrespro.ru", "phone": "+70053148753"}
0005433570067	6EC400	5465 461631	YULIYA BARANOVA	{"email": "baranova-y_111964@postgrespro.ru", "phone": "+70112187644"}
0005433570068	5D873E	3849 537522	ALLA MALYSHEVA	{"phone": "+70131485532"}
0005433570069	DF15F8	6655 607473	NIKOLAY FROLOV	{"email": "frolov.nikolay.19021972@postgrespro.ru", "phone": "+70271295821"}
0005433570070	DF15F8	2689 736435	DMITRIY BORISOV	{"email": "borisov-d_011964@postgrespro.ru", "phone": "+70241348522"}
0005433570071	2629E9	6318 038093	DMITRIY SOROKIN	{"email": "sorokin-d-1971@postgrespro.ru", "phone": "+70379012250"}
0005433570072	EDD500	6711 954869	MARINA BELOVA	{"phone": "+70685684820"}
0005433570073	44EDD1	8523 324855	TAMARA TITOVA	{"email": "t_titova.021980@postgrespro.ru", "phone": "+70589930048"}
0005433570074	E651B9	9396 988117	VASILIY FEDOTOV	{"email": "vasiliy_fedotov071969@postgrespro.ru", "phone": "+70966885975"}
0005433570075	E651B9	3146 792957	MARAT ILIN	{"phone": "+70946547150"}
0005433570076	3CA106	7503 291382	ANASTASIYA DAVYDOVA	{"phone": "+70260538081"}
0005433570077	F7E573	8542 306049	NINA BORISOVA	{"email": "n.borisova_1968@postgrespro.ru", "phone": "+70670372418"}
0005433570078	146C7C	6014 036168	VLADIMIR KOROLEV	{"phone": "+70807844175"}
0005433570079	7428DD	0098 720023	VLADIMIR MARTYNOV	{"phone": "+70499995202"}
0005433570080	7428DD	6549 485105	TAMARA FROLOVA	{"email": "frolovatamara1970@postgrespro.ru", "phone": "+70245855301"}
0005433570081	7428DD	9787 180793	NIKOLAY PETROV	{"phone": "+70581071792"}
0005433570082	48A7C5	9454 383655	ANZHELIKA STEPANOVA	{"phone": "+70651775563"}
0005433570083	48A7C5	3352 706684	SERGEY RODIONOV	{"email": "sergey.rodionov_021975@postgrespro.ru", "phone": "+70909027985"}
0005433570084	48A7C5	0348 388394	YULIYA ERMAKOVA	{"phone": "+70982628063"}
0005433570085	9221A9	4662 809239	GALINA GORBUNOVA	{"email": "g-gorbunova_05021971@postgrespro.ru", "phone": "+70901743696"}
0005433570086	9221A9	1572 406655	YAROSLAV ZHURAVLEV	{"phone": "+70095750871"}
0005433570087	F0AE68	5613 256249	EVGENIY POPOV	{"email": "popov-e-11101973@postgrespro.ru", "phone": "+70820190790"}
0005433570088	CF3169	3863 400915	OLGA GAVRILOVA	{"email": "gavrilova.o20031976@postgrespro.ru", "phone": "+70278297323"}
0005433570089	CF3169	5980 621241	SERGEY TIKHONOV	{"phone": "+70694430384"}
0005433570090	4DF9F9	6648 891534	DMITRIY EGOROV	{"phone": "+70578163704"}
0005433570091	4DF9F9	1613 793904	ANASTASIYA SOLOVEVA	{"email": "soloveva_a-24061970@postgrespro.ru", "phone": "+70057520579"}
0005433570092	E3994F	6572 182110	ELENA GERASIMOVA	{"email": "gerasimova_elena04011979@postgrespro.ru", "phone": "+70262538708"}
0005433570093	E3994F	7894 324962	VASILIY SOLOVEV	{"email": "solovev_vasiliy_28011968@postgrespro.ru", "phone": "+70163190692"}
0005433570094	097544	7860 256438	MARIYA BELOVA	{"email": "mariyabelova-21121969@postgrespro.ru", "phone": "+70598531099"}
0005433570095	5398E5	7039 281181	LYUBOV VOROBEVA	{"email": "lvorobeva.031974@postgrespro.ru", "phone": "+70495242812"}
0005433570096	5398E5	6424 731486	YULIYA KOZLOVA	{"phone": "+70949927476"}
0005433570097	D07752	8423 254919	YURIY VOLKOV	{"email": "volkov.y_19101966@postgrespro.ru", "phone": "+70809040983"}
0005433570098	EF69D1	6329 806664	EGOR DENISOV	{"email": "denisov-egor031984@postgrespro.ru", "phone": "+70392157400"}
0005433570099	6BCA9E	1142 438231	SERGEY KISELEV	{"email": "kiselev_sergey_021978@postgrespro.ru", "phone": "+70596152404"}
0005433570100	FA6512	1411 413570	ANTONINA POPOVA	{"email": "antoninapopova_1968@postgrespro.ru", "phone": "+70786170018"}
0005433570101	738D2A	6336 967475	EVGENIY MARTYNOV	{"email": "martynov_evgeniy1990@postgrespro.ru", "phone": "+70851251053"}
0005433570102	738D2A	6059 387285	ELIZAVETA IVANOVA	{"phone": "+70249510157"}
0005433570103	738D2A	6938 744209	VIKTORIYA MIRONOVA	{"email": "mironova_viktoriya.081966@postgrespro.ru", "phone": "+70108647616"}
0005433570104	9C5F03	7357 746663	IGOR IVANOV	{"email": "igor-ivanov_1965@postgrespro.ru", "phone": "+70421367347"}
0005433570105	9C5F03	4304 701834	SERGEY SERGEEV	{"phone": "+70009243501"}
0005433570106	8FCE6A	6097 742303	LYUBOV ANDREEVA	{"phone": "+70834258395"}
0005433570107	211874	9076 439115	IGOR POPOV	{"phone": "+70180405074"}
0005433570108	211874	8094 727451	VLADIMIR PETROV	{"email": "petrovv_11111984@postgrespro.ru", "phone": "+70298135826"}
0005433570109	C8AF3C	4854 931943	VERA GAVRILOVA	{"phone": "+70058793863"}
0005433570110	E1C2CA	6138 338257	LIDIYA SIDOROVA	{"email": "sidorova-lidiya_1954@postgrespro.ru", "phone": "+70605957178"}
0005433570111	E1C2CA	1053 130931	NIKOLAY ZAYCEV	{"phone": "+70803493716"}
0005433570112	10D5A7	2339 958977	ALEKSANDR BONDARENKO	{"email": "bondarenkoaleksandr_1975@postgrespro.ru", "phone": "+70723082854"}
0005433570113	A119AA	9936 816720	SERGEY GERASIMOV	{"email": "sgerasimov.101961@postgrespro.ru", "phone": "+70905584810"}
0005433570114	306040	2684 301515	VLADIMIR IVANOV	{"phone": "+70064676173"}
0005433570115	2C869A	3860 435933	STANISLAV SOKOLOV	{"phone": "+70897098098"}
0005433570116	DFD4DC	7813 882461	MARIYA TIMOFEEVA	{"phone": "+70311109571"}
0005433570117	DFD4DC	3107 021053	YURIY VASILEV	{"email": "vasilev.y-11031976@postgrespro.ru", "phone": "+70755530077"}
0005433570118	7C1440	4003 346458	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey1972@postgrespro.ru", "phone": "+70254084225"}
0005433570119	E52CD0	9137 796435	DMITRIY MIRONOV	{"email": "d-mironov-1968@postgrespro.ru", "phone": "+70483918488"}
0005433570120	E52CD0	3630 352625	VENIAMIN KUZNECOV	{"email": "veniamin.kuznecov1980@postgrespro.ru", "phone": "+70952828537"}
0005433570121	69AC7A	3423 394221	NINA KUZNECOVA	{"phone": "+70489623746"}
0005433570122	4B1B89	0122 446226	ARINA VASILEVA	{"phone": "+70553946202"}
0005433570123	667CDC	6589 630173	OLEG NIKOLAEV	{"phone": "+70336883599"}
0005433570124	5F34E0	8975 662311	IVAN SOROKIN	{"email": "sorokin_i121971@postgrespro.ru", "phone": "+70907570781"}
0005433570125	CD07DB	2420 107009	ANATOLIY POPOV	{"email": "popov_anatoliy_1971@postgrespro.ru", "phone": "+70351185350"}
0005433570126	A73AF5	7194 092928	VIKTOR IVANOV	{"phone": "+70193973728"}
0005433570127	2C7D4D	1849 946120	VIKTORIYA KUZNECOVA	{"email": "kuznecova-viktoriya-19061973@postgrespro.ru", "phone": "+70833253547"}
0005433570128	2F93D9	3755 659731	ELENA BORISOVA	{"email": "e-borisova_121973@postgrespro.ru", "phone": "+70423614929"}
0005433570129	2F93D9	1844 591884	LYUDMILA SOLOVEVA	{"phone": "+70807593494"}
0005433570130	F308DF	6193 122681	SERGEY KAZAKOV	{"email": "sergey.kazakov15071971@postgrespro.ru", "phone": "+70805282645"}
0005433570131	268205	6611 060810	NIKITA VASILEV	{"email": "vasilev.n061976@postgrespro.ru", "phone": "+70304417875"}
0005433570132	268205	5346 313106	PETR ANTONOV	{"email": "petr_antonov-1972@postgrespro.ru", "phone": "+70357704073"}
0005433570133	268205	4317 997045	ARTEM DAVYDOV	{"phone": "+70379064097"}
0005433570134	268205	4709 893307	VALERIY KULIKOV	{"phone": "+70482047469"}
0005433570135	3ECA28	3820 826498	ALEKSANDR BELOV	{"phone": "+70802392587"}
0005433570136	3423EF	3706 453821	LEV MELNIKOV	{"email": "melnikov.lev.31081955@postgrespro.ru", "phone": "+70024075259"}
0005433570137	EC83E8	2089 838285	SVETLANA VOLKOVA	{"email": "svetlana.volkova.18041974@postgrespro.ru", "phone": "+70969564634"}
0005433570138	35890B	7180 932384	VIKTOR POPOV	{"phone": "+70000525336"}
0005433570139	35890B	8481 336375	LIDIYA MAKAROVA	{"phone": "+70122809684"}
0005433570140	73DA67	2172 917481	ALEKSANDR SCHERBAKOV	{"phone": "+70227555318"}
0005433570141	56BD75	6442 234877	RAFAIL MIKHAYLOV	{"phone": "+70510249719"}
0005433570142	2420CB	6708 919529	VLADIMIR MAKAROV	{"email": "makarov.vladimir04111979@postgrespro.ru", "phone": "+70918678232"}
0005433570143	2420CB	7251 649696	SERGEY KISELEV	{"phone": "+70624375654"}
0005433570144	2420CB	3264 640152	DMITRIY ROMANOV	{"phone": "+70762115712"}
0005433570145	C4166C	3793 216543	OLGA IVANOVA	{"email": "ivanova-olga_1971@postgrespro.ru", "phone": "+70026825178"}
0005433570146	C47BC7	9718 446857	OLGA PAVLOVA	{"phone": "+70700092325"}
0005433570147	43E227	1645 024853	SERGEY VASILEV	{"email": "sergey-vasilev.1967@postgrespro.ru", "phone": "+70980703999"}
0005433570148	5856C4	9071 418498	EVGENIY BARANOV	{"phone": "+70556357678"}
0005433570149	5856C4	8161 855389	ANDREY KUZNECOV	{"phone": "+70004154637"}
0005433570150	F9BC83	6631 730737	NATALYA TIMOFEEVA	{"email": "n-timofeeva15091969@postgrespro.ru", "phone": "+70463566928"}
0005433570151	D4AEED	1635 121380	ALEKSEY KOZLOV	{"phone": "+70336389044"}
0005433570152	CA993B	9985 430937	ALEKSANDR IVANOV	{"email": "ivanov_a-13081973@postgrespro.ru", "phone": "+70018061873"}
0005433570153	DDC52C	1084 794160	ALEVTINA SMIRNOVA	{"phone": "+70808831779"}
0005433570154	DDC52C	3716 058152	PELAGEYA RODIONOVA	{"phone": "+70441488847"}
0005433570155	420D3E	3977 404501	MAKSIM SOROKIN	{"email": "maksim-sorokin_20111977@postgrespro.ru", "phone": "+70464992538"}
0005433570156	7CC197	0576 446963	VERA KOMAROVA	{"phone": "+70195411390"}
0005433570157	7CC197	0085 015631	ANNA ALEKSEEVA	{"email": "alekseeva_a_041971@postgrespro.ru", "phone": "+70610170474"}
0005433570158	047B53	0573 091725	VALENTINA PAVLOVA	{"phone": "+70557635066"}
0005433570159	0F5150	2308 452633	MARINA POLYAKOVA	{"email": "marina-polyakova_23091969@postgrespro.ru", "phone": "+70304918112"}
0005433570160	639335	0983 294397	IGOR SOLOVEV	{"phone": "+70200900456"}
0005433570161	3216DA	7211 694304	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov101958@postgrespro.ru", "phone": "+70244173494"}
0005433570162	3216DA	8758 722474	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir_28051973@postgrespro.ru", "phone": "+70073402395"}
0005433570163	EFA105	9608 801925	DMITRIY ALEKSEEV	{"phone": "+70088485828"}
0005433570164	EFA105	0757 810760	OLGA VOLKOVA	{"email": "volkova_o-15101968@postgrespro.ru", "phone": "+70136514520"}
0005433570165	68E1CE	1951 338758	ROMAN ROMANOV	{"phone": "+70748481905"}
0005433570166	56DFF4	5861 147528	SVETLANA DANILOVA	{"phone": "+70840872460"}
0005433570167	03E356	9778 752979	MIKHAIL ORLOV	{"phone": "+70992085189"}
0005433570168	03E356	2046 187769	OLESYA KOROLEVA	{"email": "koroleva_o071964@postgrespro.ru", "phone": "+70998585698"}
0005433570169	906871	2435 221831	IVAN KUZNECOV	{"phone": "+70647880378"}
0005433570170	946362	1475 704838	LIDIYA IVANOVA	{"email": "livanova.27111969@postgrespro.ru", "phone": "+70288995685"}
0005433570171	F5A76E	1419 150583	NIKOLAY FILIPPOV	{"phone": "+70435209158"}
0005433570172	A129D2	0013 203629	TATYANA NIKITINA	{"phone": "+70233966502"}
0005433570173	BEEEF3	5639 973599	ELENA PAVLOVA	{"phone": "+70087791715"}
0005433570174	9A305C	5059 165619	ALFIYA TIKHONOVA	{"phone": "+70379937583"}
0005433570175	9A305C	6158 770630	EVGENIY ANTONOV	{"phone": "+70085337006"}
0005433570176	9A305C	2234 969497	OLGA RODIONOVA	{"phone": "+70123861260"}
0005433570177	5D7E53	7703 266292	ALEKSANDR NIKITIN	{"email": "nikitin.aleksandr-28101970@postgrespro.ru", "phone": "+70534952381"}
0005433570178	6A86BE	7672 220838	SERGEY KUZNECOV	{"phone": "+70971903550"}
0005433570179	6A86BE	6844 326812	NINA ILINA	{"phone": "+70780548928"}
0005433570180	135EC1	3719 125239	ELENA EFREMOVA	{"email": "elenaefremova.1964@postgrespro.ru", "phone": "+70087602527"}
0005433570181	6B2DBF	6878 023821	ANNA LEBEDEVA	{"email": "alebedeva06061975@postgrespro.ru", "phone": "+70578052141"}
0005433570182	6B2DBF	9703 438773	ELENA MOISEEVA	{"phone": "+70069981060"}
0005433570183	AEFCBB	0503 684633	ELENA KOROLEVA	{"phone": "+70666880764"}
0005433570184	BE6AF9	4475 879250	MARIYA GUSEVA	{"email": "guseva.m.1964@postgrespro.ru", "phone": "+70969065080"}
0005433570185	BE6AF9	9726 112348	YULIYA EGOROVA	{"email": "yuliya-egorova_1979@postgrespro.ru", "phone": "+70027461965"}
0005433570186	BE6AF9	6652 688751	VLADIMIR SEMENOV	{"phone": "+70247476483"}
0005433570187	7BC481	8981 563661	SERGEY KOROLEV	{"email": "s_korolev1970@postgrespro.ru", "phone": "+70500965434"}
0005433570188	FC2F60	5960 780005	ELIZAVETA KAZAKOVA	{"phone": "+70927648880"}
0005433570189	CCE1C4	9130 423739	MARYAM KUZMINA	{"email": "kuzmina-m.19021973@postgrespro.ru", "phone": "+70918018427"}
0005433570190	CCE1C4	4204 248119	NINA VOROBEVA	{"phone": "+70773305013"}
0005433570191	9382B0	9786 105939	NADEZHDA KUZNECOVA	{"phone": "+70817887503"}
0005433570192	9382B0	3778 048349	DMITRIY NAZAROV	{"phone": "+70286708291"}
0005433570193	A735A0	1012 138816	TATYANA VOLKOVA	{"email": "volkova-t.1974@postgrespro.ru", "phone": "+70717251885"}
0005433570194	E400A2	8178 618814	TAISIYA KOZLOVA	{"email": "kozlovat_1966@postgrespro.ru", "phone": "+70007752511"}
0005433570195	9E83F0	1888 116471	GULFIYA DMITRIEVA	{"phone": "+70017341342"}
0005433570196	5B039C	5076 073427	DENIS ANTONOV	{"email": "antonov.d1970@postgrespro.ru", "phone": "+70284597914"}
0005433570197	5F4082	4091 782142	ALEKSANDR DMITRIEV	{"email": "dmitriev.a081969@postgrespro.ru", "phone": "+70311797023"}
0005433570198	2F2CD6	8727 140845	VALERIY IVANOV	{"phone": "+70056576569"}
0005433570199	2F2CD6	7489 986869	ALEKSANDR DENISOV	{"email": "denisov-aleksandr_20081979@postgrespro.ru", "phone": "+70979060862"}
0005433570200	72A25E	7022 202022	GALINA VOROBEVA	{"phone": "+70177599333"}
0005433570201	B295CA	1244 630598	KONSTANTIN FOMIN	{"phone": "+70199727550"}
0005433570202	0CD7A5	9076 886384	NATALYA SIDOROVA	{"phone": "+70567620456"}
0005433570203	85364F	5573 593730	EMIL KAZAKOV	{"email": "kazakov_e_111963@postgrespro.ru", "phone": "+70707219671"}
0005433570204	85364F	0081 908525	ANNA KUZNECOVA	{"phone": "+70744409180"}
0005433570205	14AABF	5491 259281	YURIY MIRONOV	{"phone": "+70311059686"}
0005433570206	14AABF	4584 746719	ZOYA MAKAROVA	{"phone": "+70838406553"}
0005433570207	70CB2C	6199 727744	SERGEY FROLOV	{"email": "sergeyfrolov.1972@postgrespro.ru", "phone": "+70253427661"}
0005433570208	4C297C	8202 995006	DMITRIY VOLKOV	{"email": "volkov-d1973@postgrespro.ru", "phone": "+70106785281"}
0005433570209	C7C298	0327 086654	NIKOLAY KUZMIN	{"phone": "+70468991166"}
0005433570210	C7C298	3698 226981	TATYANA LEBEDEVA	{"phone": "+70411576691"}
0005433570211	94DEEB	7792 240740	ELENA AFANASEVA	{"phone": "+70975679670"}
0005433570212	94DEEB	7315 985563	GALIYA EGOROVA	{"email": "g_egorova021979@postgrespro.ru", "phone": "+70955011802"}
0005433570213	081D7F	7967 119571	ILYA MELNIKOV	{"phone": "+70662763862"}
0005433570214	F81745	5268 451727	ALEKSANDR FILIPPOV	{"phone": "+70181035750"}
0005433570215	BBF6CC	1158 834692	LEONID TARASOV	{"email": "ltarasov061968@postgrespro.ru", "phone": "+70224493376"}
0005433570216	C7D0C2	5944 055215	NATALYA ANTONOVA	{"phone": "+70308924939"}
0005433570217	2FE6FF	9082 490486	LEV PAVLOV	{"email": "l-pavlov-13101976@postgrespro.ru", "phone": "+70106751564"}
0005433570218	C471DB	8766 039834	OKSANA ZOTOVA	{"email": "o_zotova07061976@postgrespro.ru", "phone": "+70543557029"}
0005433570219	62ECCF	1721 749348	IRINA ANTONOVA	{"phone": "+70847549244"}
0005433570220	11DF14	8663 458971	SERGEY ANDREEV	{"phone": "+70292027736"}
0005433570221	7E6D6C	6745 168049	SERGEY SOLOVEV	{"phone": "+70456187983"}
0005433570222	54384E	5363 312562	VASILIY KOZLOV	{"phone": "+70141048094"}
0005433570223	07EBC7	4012 560436	DMITRIY SAVELEV	{"email": "d-savelev-051969@postgrespro.ru", "phone": "+70699297032"}
0005433570224	E892E2	3813 827335	ZOYA SCHERBAKOVA	{"email": "z-scherbakova_02031974@postgrespro.ru", "phone": "+70183441365"}
0005433570225	0CBF14	0439 266955	EVGENIY BONDARENKO	{"phone": "+70862221210"}
0005433570226	433818	8258 700828	OLGA MOROZOVA	{"email": "morozova_olga-14041970@postgrespro.ru", "phone": "+70692512572"}
0005433570227	C7B07F	8043 627425	AMIR ILIN	{"email": "amir-ilin11031971@postgrespro.ru", "phone": "+70965868764"}
0005433570228	CA8E3A	8353 823656	MARIYA KUDRYASHOVA	{"email": "mariyakudryashova_11061972@postgrespro.ru", "phone": "+70464317036"}
0005433570229	1EC661	6997 552155	ALEKSANDR KARPOV	{"email": "karpov.a.041975@postgrespro.ru", "phone": "+70437262580"}
0005433570230	1EC661	8569 414075	ANTONINA GORBUNOVA	{"phone": "+70576883774"}
0005433570231	387B4B	6787 715893	MARINA MELNIKOVA	{"phone": "+70869412195"}
0005433570232	5719AB	5944 841848	MIKHAIL MOROZOV	{"email": "morozov.mikhail011982@postgrespro.ru", "phone": "+70236438536"}
0005433570233	F75BA7	1744 300251	ALEKSEY SOLOVEV	{"phone": "+70260676634"}
0005433570234	364EE5	0348 804240	ANASTASIYA MAKAROVA	{"phone": "+70211710173"}
0005433570235	2A40EA	7250 279045	MARINA MAKAROVA	{"email": "makarovam02081965@postgrespro.ru", "phone": "+70869378124"}
0005433570236	948BF3	9870 155719	VERA MELNIKOVA	{"phone": "+70276492743"}
0005433570237	72DCBD	2652 587283	VLADIMIR KUZNECOV	{"phone": "+70700458000"}
0005433570238	72DCBD	4513 453233	LIDIYA SEMENOVA	{"email": "semenoval09101975@postgrespro.ru", "phone": "+70641274668"}
0005433570239	0B18A8	2006 815588	ROMAN SOKOLOV	{"email": "romansokolov031968@postgrespro.ru", "phone": "+70761125663"}
0005433570240	0B18A8	3008 361686	LYUDMILA ZAKHAROVA	{"email": "zakharova_l1968@postgrespro.ru", "phone": "+70340203650"}
0005433570241	0B18A8	9839 154374	TATYANA VASILEVA	{"email": "vasileva.t.1976@postgrespro.ru", "phone": "+70957337670"}
0005433570242	1EF5C6	3013 393626	ANASTASIYA MEDVEDEVA	{"phone": "+70097521857"}
0005433570243	A9DB14	6436 882194	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir031985@postgrespro.ru", "phone": "+70427159218"}
0005433570244	A9DB14	5155 220264	ARTEM EGOROV	{"phone": "+70974215221"}
0005433570245	A9DB14	9627 479909	BORIS MOROZOV	{"email": "bmorozov1970@postgrespro.ru", "phone": "+70696972064"}
0005433570246	F828FC	4353 543122	ARTEM ROMANOV	{"email": "romanov_a_17091969@postgrespro.ru", "phone": "+70612114425"}
0005433570247	D645F2	3462 720910	TAMARA MIKHAYLOVA	{"email": "mikhaylova.t.121969@postgrespro.ru", "phone": "+70759669061"}
0005433570248	D645F2	2346 283988	VALENTINA KONDRATEVA	{"email": "v-kondrateva.111975@postgrespro.ru", "phone": "+70843638783"}
0005433570249	AA5A36	4891 823610	GENNADIY ZAYCEV	{"email": "gennadiy_zaycev_1972@postgrespro.ru", "phone": "+70479736380"}
0005433570250	4A5650	5352 581271	NATALYA BOGDANOVA	{"phone": "+70346533551"}
0005433570251	136094	0634 565979	OLGA NIKOLAEVA	{"phone": "+70730313814"}
0005433570252	68F222	4757 247371	ANGELINA VASILEVA	{"phone": "+70910107645"}
0005433570253	B7C37F	2759 173570	SERGEY KUZMIN	{"email": "sergey-kuzmin25031979@postgrespro.ru", "phone": "+70234200936"}
0005433570254	A22B7A	0794 847745	PLATON KUDRYASHOV	{"phone": "+70982284750"}
0005433570255	A22B7A	9842 390607	ELIZAVETA ANISIMOVA	{"email": "anisimova.elizaveta1972@postgrespro.ru", "phone": "+70697518485"}
0005433570256	40630C	7656 985213	ANTON SEMENOV	{"phone": "+70981042468"}
0005433570257	40630C	6243 690777	ALEKSEY STEPANOV	{"phone": "+70304493148"}
0005433570258	528C61	1251 561357	VYACHESLAV SERGEEV	{"phone": "+70392918238"}
0005433570259	635F66	3105 939598	SERGEY KOROLEV	{"email": "sergeykorolev_1971@postgrespro.ru", "phone": "+70689469456"}
0005433570260	64791C	4397 455592	SEMEN SHEVCHENKO	{"email": "semen_shevchenko12061980@postgrespro.ru", "phone": "+70896586442"}
0005433570261	B216F8	6536 827959	ELENA KUZMINA	{"email": "ekuzmina-111968@postgrespro.ru", "phone": "+70352437433"}
0005433570262	16CB7D	0089 799120	ELENA GUSEVA	{"phone": "+70015046446"}
0005433570263	3988E5	1534 145633	IGOR EGOROV	{"email": "egorov_i_02101969@postgrespro.ru", "phone": "+70900338487"}
0005433570264	8993D1	8948 023870	YULIYA IVANOVA	{"phone": "+70626622125"}
0005433570265	8425B1	6416 675699	MARIYA AFANASEVA	{"email": "mariyaafanaseva111968@postgrespro.ru", "phone": "+70875593527"}
0005433570266	1AFC3F	6771 686409	NIKOLAY MATVEEV	{"phone": "+70392038494"}
0005433570267	39CF97	3725 401455	LYUDMILA FOMINA	{"phone": "+70929423738"}
0005433570268	E883FD	7810 160486	MARINA KUZNECOVA	{"phone": "+70550116172"}
0005433570269	E883FD	8864 474375	ANATOLIY SMIRNOV	{"phone": "+70797830008"}
0005433570270	65F29C	6077 497421	ALEKSEY BORISOV	{"phone": "+70126301605"}
0005433570271	5E327A	9472 914210	DENIS KOZLOV	{"email": "deniskozlov21081972@postgrespro.ru", "phone": "+70530407710"}
0005433570272	5E327A	3449 868949	ANDREY MATVEEV	{"email": "andreymatveev25101983@postgrespro.ru", "phone": "+70673604284"}
0005433570273	31B587	9054 721676	DMITRIY ABRAMOV	{"phone": "+70386183358"}
0005433570274	31B587	0575 922523	IVAN BELOV	{"email": "i-belov-16051969@postgrespro.ru", "phone": "+70741191063"}
0005433570275	701956	8619 652536	ANATOLIY NOVIKOV	{"phone": "+70803732067"}
0005433570276	5AC99E	8851 753099	RUSTEM MELNIKOV	{"email": "rustem.melnikov091971@postgrespro.ru", "phone": "+70296992648"}
0005433570277	64A48B	1416 413729	IVAN ANDREEV	{"phone": "+70862983060"}
0005433570278	64A48B	4400 554600	YURIY OSIPOV	{"email": "osipovyuriy-121974@postgrespro.ru", "phone": "+70790819696"}
0005433570279	CA8076	9962 244123	EKATERINA MELNIKOVA	{"phone": "+70501617673"}
0005433570280	CA8076	9403 471827	ALEKSEY MEDVEDEV	{"email": "medvedev-aleksey-011991@postgrespro.ru", "phone": "+70381203011"}
0005433570281	6CC354	8340 754608	RAMIL KAZAKOV	{"phone": "+70192956829"}
0005433570282	6CC354	5280 194862	KSENIYA SOROKINA	{"phone": "+70722964717"}
0005433570283	CF6D6E	6570 900529	MARIYA GERASIMOVA	{"email": "gerasimova-mariya09041977@postgrespro.ru", "phone": "+70706261564"}
0005433570284	D10AD7	1457 479433	VIKTORIYA IVANOVA	{"phone": "+70895370414"}
0005433570285	3022A6	3950 332150	VERA KALININA	{"phone": "+70216209506"}
0005433570286	D6D0BA	5971 470364	MAKSIM KUZNECOV	{"phone": "+70748489361"}
0005433570287	260988	8257 242651	NATALYA SAVELEVA	{"email": "nsaveleva-08071969@postgrespro.ru", "phone": "+70989599708"}
0005433570288	260988	3173 228077	ANNA KUZNECOVA	{"email": "a-kuznecova-15031980@postgrespro.ru", "phone": "+70283441241"}
0005433570289	565D3F	4727 523229	GALINA ZHURAVLEVA	{"phone": "+70124551792"}
0005433570290	15219C	0668 370836	INNA DENISOVA	{"email": "idenisova_22061983@postgrespro.ru", "phone": "+70413273172"}
0005433570291	496B84	1108 864725	EKATERINA PAVLOVA	{"email": "pavlova_e.31011965@postgrespro.ru", "phone": "+70707781804"}
0005433570292	496B84	3942 347154	VYACHESLAV KARPOV	{"email": "vyacheslav_karpov1976@postgrespro.ru", "phone": "+70287147638"}
0005433570293	4AF467	4495 048356	ILYA FROLOV	{"email": "frolov.i.051962@postgrespro.ru", "phone": "+70530593774"}
0005433570294	C81164	7514 426588	LIDIYA PETROVA	{"email": "lidiyapetrova-20111977@postgrespro.ru", "phone": "+70160883605"}
0005433570295	A6FF3D	3230 310975	TATYANA ALEKSANDROVA	{"email": "tatyana.aleksandrova-1986@postgrespro.ru", "phone": "+70864840764"}
0005433570296	A6FF3D	6796 793977	NATALYA SOROKINA	{"phone": "+70049530478"}
0005433570297	8D3D45	4062 283343	YANA FOMINA	{"phone": "+70054893997"}
0005433570298	D39008	2004 764849	ALEKSANDR BELOV	{"phone": "+70455266500"}
0005433570299	412BA3	8798 122128	ANDREY KUZNECOV	{"email": "andrey_kuznecov051968@postgrespro.ru", "phone": "+70446282786"}
0005433570300	412BA3	8720 458557	LARISA FROLOVA	{"email": "frolova_l081976@postgrespro.ru", "phone": "+70548988515"}
0005433570301	7030C1	1879 621938	SERGEY SERGEEV	{"email": "sergeev-sergey_12041962@postgrespro.ru", "phone": "+70742866778"}
0005433570302	718B76	0440 310930	NIKOLAY SHEVCHENKO	{"email": "nikolay.shevchenko.011973@postgrespro.ru", "phone": "+70431910279"}
0005433570303	C1F54D	4781 888400	ALFIYA MARTYNOVA	{"email": "a_martynova_1970@postgrespro.ru", "phone": "+70707899578"}
0005433570304	441B07	2002 697649	VASILIY NAUMOV	{"email": "naumov_v-17091979@postgrespro.ru", "phone": "+70657116052"}
0005433570305	441B07	5578 891005	EVGENIY SMIRNOV	{"email": "evgeniy.smirnov.08111965@postgrespro.ru", "phone": "+70470048372"}
0005433570306	441B07	1239 141918	ALEKSEY GUSEV	{"phone": "+70507522989"}
0005433570307	02A40A	9916 880217	ELIZAVETA DMITRIEVA	{"email": "elizaveta_dmitrieva.061969@postgrespro.ru", "phone": "+70218628855"}
0005433570309	DE9A4C	8373 356155	GEORGIY BORISOV	{"phone": "+70893183333"}
0005433570310	8850B4	2324 341938	VENERA SAVELEVA	{"email": "venerasaveleva.03051975@postgrespro.ru", "phone": "+70842752248"}
0005433570311	FB828E	3572 277557	ALEKSANDR AFANASEV	{"email": "aafanasev_061979@postgrespro.ru", "phone": "+70516101477"}
0005433570312	8100FE	2762 617929	SERGEY NAZAROV	{"phone": "+70135684867"}
0005433570313	FBF3CE	8161 017532	TATYANA GERASIMOVA	{"email": "gerasimova_tatyana-091972@postgrespro.ru", "phone": "+70402073533"}
0005433570314	FBF3CE	8770 977775	GULSINA SERGEEVA	{"phone": "+70186028230"}
0005433570315	865A29	1319 931368	MARIYA FROLOVA	{"phone": "+70473648430"}
0005433570316	865A29	0605 703511	ARTEM KAZAKOV	{"phone": "+70113418406"}
0005433570317	2E4235	7521 928844	RAMILYA NAUMOVA	{"phone": "+70052003334"}
0005433570318	2E4235	2226 149048	TAMARA PAVLOVA	{"email": "tamarapavlova-1983@postgrespro.ru", "phone": "+70017492153"}
0005433570319	FE8F8F	0908 167033	NADEZHDA KUZNECOVA	{"phone": "+70772060803"}
0005433570320	FE8F8F	4029 886573	TATYANA NAUMOVA	{"email": "tatyana.naumova1971@postgrespro.ru", "phone": "+70592233829"}
0005433570321	0BC1C6	4145 633840	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr.17031980@postgrespro.ru", "phone": "+70463262611"}
0005433570322	0BC1C6	9052 345708	DMITRIY SMIRNOV	{"email": "smirnov.d.18041966@postgrespro.ru", "phone": "+70942057175"}
0005433570323	9FF391	8656 731139	SVETLANA BELOVA	{"phone": "+70311454037"}
0005433570324	9FF391	2278 559581	MARIYA BELOVA	{"email": "mbelova_051970@postgrespro.ru", "phone": "+70767846084"}
0005433570325	9FF391	4678 686777	SVETLANA VASILEVA	{"phone": "+70547351841"}
0005433570326	6A0EB5	8238 530731	SERGEY ANDREEV	{"phone": "+70345009864"}
0005433570327	6F0515	3571 872746	ANDREY VASILEV	{"email": "a.vasilev-071967@postgrespro.ru", "phone": "+70274998723"}
0005433570328	2CCEE9	8945 965590	SERGEY PETROV	{"phone": "+70408906683"}
0005433570329	2FC23F	1339 244358	NINA ZAKHAROVA	{"email": "zakharova-nina.14081971@postgrespro.ru", "phone": "+70368152403"}
0005433570330	E3DD83	4154 189248	VLADIMIR KISELEV	{"email": "kiselev_vladimir_19081969@postgrespro.ru", "phone": "+70201721084"}
0005433570331	BE74DF	0982 837893	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr-1989@postgrespro.ru", "phone": "+70703364628"}
0005433570332	BE74DF	5577 350438	MIKHAIL TARASOV	{"email": "mtarasov011979@postgrespro.ru", "phone": "+70936508852"}
0005433570333	404BCA	5799 069447	SERGEY VOROBEV	{"email": "vorobevsergey-1969@postgrespro.ru", "phone": "+70975583874"}
0005433570334	6E16B4	8494 554448	EGOR SAVELEV	{"phone": "+70990546505"}
0005433570335	6E16B4	9963 608337	LILIYA FROLOVA	{"email": "lfrolova.111988@postgrespro.ru", "phone": "+70921105833"}
0005433570336	6E16B4	6579 191842	VIKTORIYA BELOVA	{"phone": "+70998153253"}
0005433570337	6B9409	8521 261324	VALERIYA FROLOVA	{"email": "frolova-valeriya-011965@postgrespro.ru", "phone": "+70531798133"}
0005433570338	FEFD67	3631 051947	VERA GRISHINA	{"email": "v-grishina31081972@postgrespro.ru", "phone": "+70515391145"}
0005433570339	FEFD67	1525 820086	VIKTOR PETROV	{"phone": "+70723485146"}
0005433570340	FEFD67	7530 061242	ELENA NIKOLAEVA	{"email": "elena_nikolaeva_1972@postgrespro.ru", "phone": "+70692249689"}
0005433570341	55B78E	8010 299595	LIDIYA MAKSIMOVA	{"phone": "+70750842282"}
0005433570342	591343	3681 479456	SERGEY VASILEV	{"phone": "+70242549282"}
0005433570343	0F0A9C	8058 972439	TATYANA ZHURAVLEVA	{"email": "zhuravlevat.121964@postgrespro.ru", "phone": "+70918494557"}
0005433570344	0F0A9C	8479 479404	SERGEY ZAKHAROV	{"email": "sergey.zakharov111964@postgrespro.ru", "phone": "+70555152495"}
0005433570345	0F0A9C	0273 405882	ZINAIDA NESTEROVA	{"email": "znesterova.021979@postgrespro.ru", "phone": "+70600755325"}
0005433570346	34BDE5	4999 450200	ALEKSANDR MARTYNOV	{"phone": "+70098127660"}
0005433570347	34BDE5	0077 974728	IVAN VASILEV	{"phone": "+70797879265"}
0005433570348	B4D831	8837 240249	VADIM MEDVEDEV	{"phone": "+70637460738"}
0005433570349	B4D831	1543 237179	NIKITA TIKHONOV	{"email": "nikitatikhonov_08011980@postgrespro.ru", "phone": "+70733008658"}
0005433570350	E194E9	9850 845525	NIKOLAY IVANOV	{"phone": "+70057498313"}
0005433570351	E14905	8690 436530	SERGEY BORISOV	{"email": "borisov.s.061968@postgrespro.ru", "phone": "+70095903038"}
0005433570352	E14905	0625 448365	ELENA GUSEVA	{"email": "e_guseva091974@postgrespro.ru", "phone": "+70465611651"}
0005433570353	E14905	7845 122479	NIKOLAY SAVELEV	{"phone": "+70257493321"}
0005433570354	83D113	9506 479711	NIKOLAY KISELEV	{"email": "nikolay-kiselev1978@postgrespro.ru", "phone": "+70026984048"}
0005433570355	83D113	2357 994153	VITALIY POPOV	{"phone": "+70391645016"}
0005433570356	2EEB5F	6624 530856	GENNADIY MIRONOV	{"email": "gennadiy.mironov1974@postgrespro.ru", "phone": "+70753266873"}
0005433570357	891A7B	4527 719154	VALERIY AFANASEV	{"email": "valeriy-afanasev011981@postgrespro.ru", "phone": "+70801985632"}
0005433570358	E79489	2893 929746	NIKITA SEMENOV	{"email": "semenovn_121974@postgrespro.ru", "phone": "+70928719312"}
0005433570359	403E24	4244 061426	MARINA KARPOVA	{"email": "karpova-marina.1975@postgrespro.ru", "phone": "+70601337740"}
0005433570360	1C4DA7	6484 282635	SERGEY VOLKOV	{"email": "svolkov.011963@postgrespro.ru", "phone": "+70531672693"}
0005433570361	51D784	7286 026458	ALEKSANDRA POPOVA	{"email": "aleksandra-popova_1971@postgrespro.ru", "phone": "+70419422697"}
0005433570362	E6C715	1177 570465	TATYANA ZHURAVLEVA	{"phone": "+70368171740"}
0005433570363	366332	6296 344318	OLGA KISELEVA	{"phone": "+70422141142"}
0005433570364	366332	7084 275704	DMITRIY IVANOV	{"phone": "+70138056246"}
0005433570365	29478B	2890 317486	ALEKSEY YAKOVLEV	{"email": "yakovlev-aleksey-02121971@postgrespro.ru", "phone": "+70151522507"}
0005433570366	29478B	7394 319790	MAKSIM NIKITIN	{"email": "nikitinmaksim_1968@postgrespro.ru", "phone": "+70513432042"}
0005433570367	C61744	4687 272908	LINAR MEDVEDEV	{"phone": "+70762953298"}
0005433570368	B78024	8286 295107	YURIY CHERNOV	{"phone": "+70683505907"}
0005433570369	89ADF2	0182 625966	ANTONINA YUDINA	{"email": "a-yudina_1968@postgrespro.ru", "phone": "+70364161804"}
0005433570370	B36D5E	0664 235282	ALEKSANDR NIKITIN	{"phone": "+70756458577"}
0005433570371	B36D5E	4593 713851	PAVEL VOROBEV	{"email": "vorobev_p.021983@postgrespro.ru", "phone": "+70664663419"}
0005433570372	B36D5E	2785 564419	IVAN MIRONOV	{"email": "mironov.ivan.22121972@postgrespro.ru", "phone": "+70969745281"}
0005433570373	7F5018	2662 626766	ALEKSANDRA SIDOROVA	{"email": "asidorova_07041968@postgrespro.ru", "phone": "+70797243055"}
0005433570374	7F5018	8840 904043	TATYANA GAVRILOVA	{"email": "gavrilovat-121962@postgrespro.ru", "phone": "+70172525188"}
0005433570375	A2AA89	3153 487316	ELENA ROMANOVA	{"email": "romanova_elena_01111964@postgrespro.ru", "phone": "+70881427685"}
0005433570376	7389C4	9727 194690	VLADIMIR VOLKOV	{"email": "volkov-v_06091973@postgrespro.ru", "phone": "+70319219688"}
0005433570377	2CA7E2	9286 168782	VALENTINA KOZLOVA	{"email": "kozlova-v-04081972@postgrespro.ru", "phone": "+70856439753"}
0005433570378	2426DA	0561 885459	ELIZAVETA PAVLOVA	{"email": "elizaveta.pavlova25081966@postgrespro.ru", "phone": "+70051467658"}
0005433570379	872BD7	2253 705790	ANDREY SCHERBAKOV	{"email": "scherbakov.a021974@postgrespro.ru", "phone": "+70575057162"}
0005433570380	872BD7	2749 658757	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev_021978@postgrespro.ru", "phone": "+70600038437"}
0005433570381	872BD7	3271 947482	ANDREY ZAKHAROV	{"phone": "+70721489450"}
0005433570382	447C45	0711 323101	IRINA FILATOVA	{"email": "filatova-irina_1977@postgrespro.ru", "phone": "+70194170665"}
0005433570383	AED35E	9533 801520	OLGA ZHURAVLEVA	{"email": "olgazhuravleva1973@postgrespro.ru", "phone": "+70656883348"}
0005433570384	70CE1B	5107 998017	LARISA KRASNOVA	{"phone": "+70392542928"}
0005433570385	89F900	6569 832437	ELENA KOZLOVA	{"email": "elena_kozlova.021980@postgrespro.ru", "phone": "+70609873971"}
0005433570386	42C434	8814 286690	OKSANA YAKOVLEVA	{"email": "o_yakovleva-021964@postgrespro.ru", "phone": "+70200569351"}
0005433570387	0920EF	1997 299088	VIKTOR KISELEV	{"phone": "+70641155069"}
0005433570388	E3AF56	6183 800719	ANASTASIYA KONOVALOVA	{"email": "konovalovaa1973@postgrespro.ru", "phone": "+70287483103"}
0005433570389	E3AF56	5054 342729	DMITRIY IVANOV	{"email": "d-ivanov.011966@postgrespro.ru", "phone": "+70134682753"}
0005433570390	95AD79	4714 660613	RINAT VOLKOV	{"phone": "+70043429514"}
0005433570391	ECAF5F	8153 652518	NIKOLAY KRASNOV	{"email": "krasnov.nikolay21111967@postgrespro.ru", "phone": "+70826058587"}
0005433570392	AB6D8D	8045 713576	NIKITA SOROKIN	{"email": "n-sorokin061958@postgrespro.ru", "phone": "+70052640899"}
0005433570393	4ECA03	7088 870386	DMITRIY RODIONOV	{"email": "rodionov-dmitriy30101973@postgrespro.ru", "phone": "+70054606827"}
0005433570394	4ECA03	4537 219208	IVAN ANDREEV	{"email": "i_andreev.28031976@postgrespro.ru", "phone": "+70892281713"}
0005433570395	4EF696	3038 904348	TAMARA KRASNOVA	{"email": "krasnovat_23011981@postgrespro.ru", "phone": "+70799951287"}
0005433570396	F02FDF	7162 299007	DARYA ANTONOVA	{"phone": "+70547059913"}
0005433570397	F02FDF	5235 353326	VYACHESLAV VOROBEV	{"email": "vorobev_vyacheslav.1954@postgrespro.ru", "phone": "+70916269126"}
0005433570398	3D4379	5614 813865	ALEKSANDR IVANOV	{"phone": "+70494572842"}
0005433570399	104F71	7099 872645	NATALYA SERGEEVA	{"email": "sergeeva.natalya_1972@postgrespro.ru", "phone": "+70333762730"}
0005433570400	104F71	4255 048271	ALBERT DENISOV	{"email": "a-denisov-011966@postgrespro.ru", "phone": "+70441629852"}
0005433570401	D630AD	1571 084044	ALEKSEY KOZLOV	{"email": "kozlov_aleksey27061964@postgrespro.ru", "phone": "+70370216259"}
0005433570402	3C53C3	7365 671919	ALISA SAVELEVA	{"phone": "+70121583843"}
0005433570403	3C53C3	1250 710921	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey_051975@postgrespro.ru", "phone": "+70684710371"}
0005433570404	2F7CB3	1579 836994	NADEZHDA ZHURAVLEVA	{"email": "zhuravleva_nadezhda-041956@postgrespro.ru", "phone": "+70763219265"}
0005433570405	2F7CB3	0903 542572	DENIS FEDOROV	{"email": "fedorovdenis_1977@postgrespro.ru", "phone": "+70419424266"}
0005433570406	743607	5205 124986	NIKOLAY SAVELEV	{"email": "savelevnikolay1969@postgrespro.ru", "phone": "+70964357088"}
0005433570407	743607	8732 517280	EVGENIY KUZNECOV	{"phone": "+70429524252"}
0005433570408	2DF727	1763 972474	NATALYA KAZAKOVA	{"email": "kazakovan_1976@postgrespro.ru", "phone": "+70233357051"}
0005433570409	2DF727	3571 820184	MARIYA EGOROVA	{"email": "m.egorova_1978@postgrespro.ru", "phone": "+70883839792"}
0005433570410	A74E64	2622 351881	TATYANA VLASOVA	{"email": "vlasova_tatyana.081972@postgrespro.ru", "phone": "+70341526133"}
0005433570411	F50701	9243 651195	NADEZHDA DENISOVA	{"email": "denisovanadezhda.22081967@postgrespro.ru", "phone": "+70293124632"}
0005433570412	59EAAD	7563 368373	RUSTAM NIKITIN	{"email": "nikitinr.041978@postgrespro.ru", "phone": "+70103922283"}
0005433570413	7D7465	6541 264974	EVGENIY TIKHONOV	{"phone": "+70348266356"}
0005433570414	389DB5	6911 020218	GALINA ARKHIPOVA	{"phone": "+70206589772"}
0005433570415	389DB5	0648 389326	KARINA MIRONOVA	{"email": "mironova.karina22051971@postgrespro.ru", "phone": "+70843352029"}
0005433570416	A36667	3561 370716	TAMARA MOROZOVA	{"phone": "+70307255340"}
0005433570417	A36667	6354 063944	ANATOLIY SERGEEV	{"email": "anatoliy-sergeev.08081981@postgrespro.ru", "phone": "+70677432584"}
0005433570418	A68FB8	8931 318104	GYUZEL ZAYCEVA	{"phone": "+70597486778"}
0005433570419	7D2794	2729 673375	MARINA LAZAREVA	{"phone": "+70846825183"}
0005433570420	7D2794	2531 422293	GALINA TITOVA	{"email": "galina-titova.071955@postgrespro.ru", "phone": "+70923657214"}
0005433570421	3F4118	6013 082971	VASILIY GUSEV	{"phone": "+70883933655"}
0005433570422	3F4118	6785 672073	VALERIY GERASIMOV	{"email": "v.gerasimov_1977@postgrespro.ru", "phone": "+70262082992"}
0005433570423	E5F637	6102 707115	RENAT NIKITIN	{"email": "nikitin_renat.04041971@postgrespro.ru", "phone": "+70061963792"}
0005433570424	2EE4AD	3539 909981	VLADA NAUMOVA	{"email": "vnaumova.091986@postgrespro.ru", "phone": "+70232741925"}
0005433570425	4CB774	0882 676913	GALINA VOROBEVA	{"email": "galina_vorobeva-081966@postgrespro.ru", "phone": "+70202398587"}
0005433570426	535318	5307 876489	EVGENIY FEDOROV	{"email": "evgeniy_fedorov-20031958@postgrespro.ru", "phone": "+70938839236"}
0005433570427	6D1A16	3183 712452	IRINA MIKHAYLOVA	{"phone": "+70587669179"}
0005433570428	C33699	2397 815723	VIKTOR MOROZOV	{"phone": "+70191563934"}
0005433570429	84A19B	0533 884652	YULIYA FEDOROVA	{"phone": "+70163688991"}
0005433570430	62CE94	5305 560391	KLAVDIYA NIKOLAEVA	{"phone": "+70114474161"}
0005433570431	CD52F3	3766 049176	ANDREY SERGEEV	{"phone": "+70968057581"}
0005433570432	5369D7	7649 802022	VIKTORIYA GUSEVA	{"phone": "+70743718750"}
0005433570433	77E43F	8662 836671	NATALYA KAZAKOVA	{"email": "kazakova-n-24061970@postgrespro.ru", "phone": "+70308889255"}
0005433570434	8A7B8E	0021 112750	VALENTINA IVANOVA	{"email": "v-ivanova-04091982@postgrespro.ru", "phone": "+70994760874"}
0005433570435	EF9218	6324 525066	OKSANA KUZNECOVA	{"email": "kuznecova_o-1970@postgrespro.ru", "phone": "+70704100951"}
0005433570436	89108B	9238 863304	LIDIYA ARKHIPOVA	{"phone": "+70817193679"}
0005433570437	5820CB	0721 109304	ANNA IVANOVA	{"email": "a_ivanova.051980@postgrespro.ru", "phone": "+70849122405"}
0005433570438	5820CB	9176 503527	ELENA SOROKINA	{"email": "sorokina.e23081978@postgrespro.ru", "phone": "+70440300752"}
0005433570439	3587F1	9552 617557	SERGEY VASILEV	{"phone": "+70469178739"}
0005433570440	3587F1	2635 000964	MARGARITA KOROLEVA	{"phone": "+70406010612"}
0005433570441	2B4562	7153 072449	ALEKSANDR VASILEV	{"email": "vasileva041982@postgrespro.ru", "phone": "+70079876578"}
0005433570442	2E7F14	3374 735750	KLAVDIYA FOMINA	{"phone": "+70693936603"}
0005433570443	2E7F14	2420 376198	SERGEY KONOVALOV	{"email": "konovalov-s.101980@postgrespro.ru", "phone": "+70668872198"}
0005433570444	C67049	5940 689453	NATALIYA PETROVA	{"phone": "+70294959770"}
0005433570445	F30478	8594 788504	GALINA BARANOVA	{"email": "baranova_galina_08031969@postgrespro.ru", "phone": "+70908655715"}
0005433570446	BE52B0	2219 942972	MARGARITA KAZAKOVA	{"phone": "+70773364347"}
0005433570447	AE1BF4	3049 914804	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_021986@postgrespro.ru", "phone": "+70820460836"}
0005433570448	CCF764	3609 356784	ANNA VOLKOVA	{"phone": "+70972097977"}
0005433570449	2A0F06	3157 143125	ALEKSANDR ALEKSANDROV	{"email": "aaleksandrov_21021976@postgrespro.ru", "phone": "+70151193607"}
0005433570450	C17B92	0145 656707	MATVEY ANTONOV	{"email": "antonovmatvey_061967@postgrespro.ru", "phone": "+70306922696"}
0005433570451	C17B92	0387 519342	ANASTASIYA POPOVA	{"email": "a-popova_041974@postgrespro.ru", "phone": "+70205501059"}
0005433570452	C17B92	0492 795290	OKSANA KOROLEVA	{"email": "o_koroleva07041966@postgrespro.ru", "phone": "+70785482364"}
0005433570453	232A50	3819 609251	ALEKSANDR ZAKHAROV	{"email": "a.zakharov041973@postgrespro.ru", "phone": "+70571631537"}
0005433570454	920705	0743 941337	EGOR ZAYCEV	{"phone": "+70899039112"}
0005433570455	236028	3279 660778	VALERIYA MAKAROVA	{"email": "makarova.valeriya-101972@postgrespro.ru", "phone": "+70009530355"}
0005433570456	236028	9911 989417	DMITRIY RODIONOV	{"phone": "+70081619371"}
0005433570457	BCB281	3611 639812	DMITRIY TIMOFEEV	{"email": "timofeev_dmitriy-031973@postgrespro.ru", "phone": "+70975886348"}
0005433570458	8A7CD5	6695 699092	ANNA KALININA	{"email": "kalinina_anna-111973@postgrespro.ru", "phone": "+70595018355"}
0005433570459	D3DFB6	8077 155427	VITALIY AFANASEV	{"email": "v_afanasev-05041977@postgrespro.ru", "phone": "+70792138258"}
0005433570460	55C92F	2627 122448	NINA ANDREEVA	{"email": "andreeva.nina.081974@postgrespro.ru", "phone": "+70450722794"}
0005433570461	0D2386	1408 632072	SERGEY KUZNECOV	{"email": "kuznecov.sergey.14061976@postgrespro.ru", "phone": "+70826397385"}
0005433570462	0D2386	2052 471638	SERGEY BARANOV	{"phone": "+70700722328"}
0005433570463	06E416	6106 502955	GULNARA KOZLOVA	{"phone": "+70869684709"}
0005433570464	4EB2DD	9805 978752	KSENIYA ANDREEVA	{"email": "andreeva-k11101967@postgrespro.ru", "phone": "+70820108948"}
0005433570465	4C2D4F	2387 729668	SERGEY SCHERBAKOV	{"email": "sergeyscherbakov-1974@postgrespro.ru", "phone": "+70712126803"}
0005433570466	672704	2375 132461	ZINAIDA ALEKSANDROVA	{"phone": "+70071442293"}
0005433570467	644ED1	8060 404247	ALENA KUZNECOVA	{"phone": "+70349299711"}
0005433570468	53D8E5	8273 182004	ALEKSANDR SOKOLOV	{"phone": "+70300602985"}
0005433570469	F82CD7	4496 516875	VIKTOR KULIKOV	{"email": "viktor-kulikov_26051986@postgrespro.ru", "phone": "+70767594671"}
0005433570470	F82CD7	4910 026606	IGOR AFANASEV	{"email": "afanasev.igor081965@postgrespro.ru", "phone": "+70356985584"}
0005433570471	4EA265	0745 961938	EDUARD NOVIKOV	{"phone": "+70355231409"}
0005433570472	DEF28A	4250 427677	LYUDMILA MALYSHEVA	{"phone": "+70727853651"}
0005433570473	DEF28A	9915 153330	NATALYA NIKOLAEVA	{"phone": "+70072941371"}
0005433570474	3B95F2	4587 789157	IRINA KAZAKOVA	{"email": "kazakova-irina-01111962@postgrespro.ru", "phone": "+70076213262"}
0005433570475	1589B6	9571 828609	MIKHAIL PETROV	{"email": "petrov.m-1969@postgrespro.ru", "phone": "+70532527861"}
0005433570476	6B2EE7	8339 260685	VLADIMIR MOISEEV	{"email": "moiseev_v_02021965@postgrespro.ru", "phone": "+70272543656"}
0005433570477	1B594C	2611 587089	MAKSIM GRIGOREV	{"email": "grigorev_maksim.22031963@postgrespro.ru", "phone": "+70722356815"}
0005433570478	643B24	6911 409557	ANASTASIYA SMIRNOVA	{"email": "anastasiyasmirnova_091970@postgrespro.ru", "phone": "+70462384883"}
0005433570479	8D445A	3151 173843	ELENA SMIRNOVA	{"phone": "+70285494788"}
0005433570480	F3D7FF	2318 391791	IVAN ZAKHAROV	{"phone": "+70991123918"}
0005433570481	86B362	4431 006460	NADEZHDA KOZLOVA	{"email": "kozlova.n_111962@postgrespro.ru", "phone": "+70832334494"}
0005433570482	515C98	9782 177539	EDUARD NOVIKOV	{"phone": "+70358289277"}
0005433570483	BBBE9C	5285 507849	NATALYA ZOTOVA	{"email": "natalyazotova-011971@postgrespro.ru", "phone": "+70711748844"}
0005433570484	BBBE9C	6332 387975	IVAN BORISOV	{"email": "borisov.i.1969@postgrespro.ru", "phone": "+70212436751"}
0005433570485	973D65	2545 316384	ARTEM SOKOLOV	{"email": "asokolov1964@postgrespro.ru", "phone": "+70362517586"}
0005433570486	973D65	9012 219622	VLADIMIR BORISOV	{"email": "vladimirborisov-1971@postgrespro.ru", "phone": "+70589766393"}
0005433570487	973D65	8064 513652	ANTON NOVIKOV	{"phone": "+70255269036"}
0005433570488	781F38	8075 610014	VYACHESLAV SOLOVEV	{"email": "vyacheslav-solovev1975@postgrespro.ru", "phone": "+70952305209"}
0005433570489	BDA0AC	7762 602942	VLADIMIR FEDOROV	{"email": "fedorov-vladimir.1978@postgrespro.ru", "phone": "+70045490876"}
0005433570490	18187F	1419 466505	SERGEY POPOV	{"phone": "+70657933356"}
0005433570491	6C3E85	7104 126850	ALEKSANDR DMITRIEV	{"phone": "+70399753866"}
0005433570492	37D91E	1874 437082	ZOYA VOLKOVA	{"email": "volkova-zoya.1975@postgrespro.ru", "phone": "+70114046021"}
0005433570493	F7FED5	6682 520329	ANTONINA KAZAKOVA	{"phone": "+70601756495"}
0005433570494	F7FED5	1605 856938	IGOR NIKITIN	{"phone": "+70187636142"}
0005433570495	C68005	5175 549089	ANATOLIY RODIONOV	{"phone": "+70946154560"}
0005433570496	C68005	0261 012838	DENIS IVANOV	{"phone": "+70100319543"}
0005433570497	8C8795	3143 110325	OKSANA SIDOROVA	{"phone": "+70944203191"}
0005433570498	8C8795	4483 043944	YULIYA EGOROVA	{"phone": "+70523303858"}
0005433570499	4E24F8	5154 959410	NIKITA CHERNOV	{"phone": "+70933100772"}
0005433570500	4E24F8	8607 412059	ALEKSANDR DENISOV	{"email": "denisov.aleksandr021967@postgrespro.ru", "phone": "+70099409081"}
0005433570501	2B847D	2076 847863	IRINA EFREMOVA	{"email": "i.efremova_101990@postgrespro.ru", "phone": "+70366040145"}
0005433570502	713FF4	8975 997398	KRISTINA DAVYDOVA	{"phone": "+70940002752"}
0005433570503	713FF4	8317 573835	VLADIMIR MATVEEV	{"email": "v-matveev_1960@postgrespro.ru", "phone": "+70569278054"}
0005433570504	8FC7D3	3083 012893	ANNA BOGDANOVA	{"email": "annabogdanova091969@postgrespro.ru", "phone": "+70525227364"}
0005433570505	93DC0A	8704 275406	VALENTINA KUZNECOVA	{"phone": "+70443180363"}
0005433570506	CD4C67	3235 322690	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr_061974@postgrespro.ru", "phone": "+70151122473"}
0005433570507	CD4C67	4808 478760	NADEZHDA FROLOVA	{"phone": "+70536961530"}
0005433570508	A9ABE4	8146 810553	SVETLANA TARASOVA	{"email": "tarasova-s.081961@postgrespro.ru", "phone": "+70123641245"}
0005433570509	10A100	8872 244495	VLADIMIR RODIONOV	{"email": "rodionov-vladimir_051981@postgrespro.ru", "phone": "+70853041313"}
0005433570510	D265C2	9526 935131	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a.08091974@postgrespro.ru", "phone": "+70121108208"}
0005433570511	757979	8718 283662	SOFYA CHERNOVA	{"email": "chernova.sofya.26061963@postgrespro.ru", "phone": "+70399489436"}
0005433570512	757979	6989 439036	SERGEY MIKHAYLOV	{"email": "mikhaylov-s041977@postgrespro.ru", "phone": "+70489624380"}
0005433570623	172A88	5693 158367	KARIM KONOVALOV	{"phone": "+70381377376"}
0005433570513	E1473B	7190 732548	OKSANA ANDREEVA	{"email": "andreeva.o061968@postgrespro.ru", "phone": "+70866406126"}
0005433570514	D7468B	6495 821779	ANDREY KISELEV	{"phone": "+70922628540"}
0005433570515	D7468B	4729 838321	OLGA KARPOVA	{"phone": "+70061369716"}
0005433570516	57CDA1	6896 476069	ALEVTINA PAVLOVA	{"phone": "+70354399681"}
0005433570517	57CDA1	1838 125712	DMITRIY MIRONOV	{"email": "d_mironov_081985@postgrespro.ru", "phone": "+70242737188"}
0005433570518	9ECBEE	3119 448655	GALINA ISAEVA	{"email": "g-isaeva-10121969@postgrespro.ru", "phone": "+70973603306"}
0005433570519	02EC0E	1768 264691	VASILIY POPOV	{"email": "popov-vasiliy_1974@postgrespro.ru", "phone": "+70085061600"}
0005433570520	892E8A	9468 158243	PETR MIKHAYLOV	{"phone": "+70841305069"}
0005433570521	892E8A	4780 383835	OKSANA BARANOVA	{"email": "o_baranova1980@postgrespro.ru", "phone": "+70665271142"}
0005433570522	863245	6668 436664	ANGELINA KUZMINA	{"phone": "+70868056770"}
0005433570523	E9DEA2	8185 974053	IRINA CHERNOVA	{"email": "irinachernova_1980@postgrespro.ru", "phone": "+70770510321"}
0005433570524	D583A1	4376 488258	VERA KOROLEVA	{"phone": "+70777470802"}
0005433570525	D583A1	6087 772429	RAISA TIKHONOVA	{"phone": "+70332884027"}
0005433570526	F0648A	4845 806854	ALEKSEY TIKHONOV	{"phone": "+70978223595"}
0005433570527	81FA94	4643 039645	PAVEL IVANOV	{"phone": "+70427174524"}
0005433570528	81FA94	1916 405110	EVA KAZAKOVA	{"email": "eva.kazakova.30101976@postgrespro.ru", "phone": "+70446365829"}
0005433570529	C74634	2391 024218	NIKOLAY SOLOVEV	{"email": "n-solovev_011975@postgrespro.ru", "phone": "+70345737990"}
0005433570530	429584	9636 190639	ALEKSEY ILIN	{"email": "ilin.a.06061973@postgrespro.ru", "phone": "+70991429004"}
0005433570531	B34B21	0085 704438	ALISA KRASNOVA	{"email": "krasnova_alisa-02031970@postgrespro.ru", "phone": "+70463931511"}
0005433570532	B34B21	8011 189239	ALEKSANDR BORISOV	{"email": "aleksandr_borisov-1965@postgrespro.ru", "phone": "+70229402958"}
0005433570533	E65024	8452 802974	IRINA ILINA	{"email": "irina.ilina-29051976@postgrespro.ru", "phone": "+70791403827"}
0005433570534	80BD2A	3752 523068	ALEKSANDRA KRASNOVA	{"email": "krasnova.a.041985@postgrespro.ru", "phone": "+70724882609"}
0005433570535	ED7488	6331 880605	ANDREY SOKOLOV	{"phone": "+70033859107"}
0005433570536	DBB197	7691 016109	ARTEM GUSEV	{"email": "a-gusev.031974@postgrespro.ru", "phone": "+70956066014"}
0005433570537	129224	4700 897576	SVETLANA SERGEEVA	{"email": "ssergeeva.09111971@postgrespro.ru", "phone": "+70319177937"}
0005433570538	129224	9231 001338	ALEKSANDR KULIKOV	{"phone": "+70238906631"}
0005433570539	129224	8708 522667	ALEKSANDR FOMIN	{"email": "aleksandrfomin.1967@postgrespro.ru", "phone": "+70870391452"}
0005433570540	FAD5B4	2153 941934	ALEKSANDR GUSEV	{"phone": "+70629542731"}
0005433570541	FAD5B4	5633 992157	ANATOLIY BORISOV	{"email": "a_borisov_031968@postgrespro.ru", "phone": "+70801780251"}
0005433570542	FAD5B4	3884 419761	VIKTOR DMITRIEV	{"email": "dmitriev_v_051980@postgrespro.ru", "phone": "+70140705872"}
0005433570543	2B4033	2883 974677	ANTON ZHUKOV	{"email": "a_zhukov-26091973@postgrespro.ru", "phone": "+70419677275"}
0005433570544	9EEFA5	0611 519596	IVAN IVANOV	{"email": "ivanivanov.051978@postgrespro.ru", "phone": "+70135665133"}
0005433570545	C24D69	5022 986051	ANTONINA NAZAROVA	{"email": "antonina-nazarova_1976@postgrespro.ru", "phone": "+70025073580"}
0005433570546	5D6B95	0318 865722	TAMARA ISAEVA	{"phone": "+70002600774"}
0005433570547	935E61	5850 887690	MARINA KISELEVA	{"phone": "+70363833094"}
0005433570548	5FD69B	0819 487797	TATYANA DMITRIEVA	{"phone": "+70206881716"}
0005433570549	251632	7289 431495	ELENA DMITRIEVA	{"email": "e.dmitrieva-1980@postgrespro.ru", "phone": "+70399217033"}
0005433570550	853934	4920 371537	ALEKSANDR RODIONOV	{"phone": "+70970881978"}
0005433570551	853934	3962 727753	GALINA OSIPOVA	{"phone": "+70257490008"}
0005433570552	A329D1	9213 621729	DANIIL KARPOV	{"phone": "+70431501225"}
0005433570553	E87896	5358 669542	ARTEM ISAEV	{"phone": "+70647298037"}
0005433570554	452A64	7554 608625	VLADISLAV KUDRYASHOV	{"email": "kudryashovv.1976@postgrespro.ru", "phone": "+70214344264"}
0005433570555	452A64	9809 897012	VLADIMIR NIKOLAEV	{"phone": "+70732996636"}
0005433570556	B1BD52	7201 002891	ANATOLIY ALEKSEEV	{"email": "alekseev_anatoliy11121968@postgrespro.ru", "phone": "+70991364451"}
0005433570557	8BD798	2291 613877	ELENA NOVIKOVA	{"email": "novikova_elena_1969@postgrespro.ru", "phone": "+70060979953"}
0005433570558	CDEF22	6986 551186	ANTONINA ROMANOVA	{"phone": "+70209412342"}
0005433570559	CDEF22	3086 970001	VALERIYA GUSEVA	{"phone": "+70342660385"}
0005433570560	0E185C	1245 539561	ARTEM ISAEV	{"phone": "+70293881711"}
0005433570561	0E185C	3783 567073	OLGA MAKSIMOVA	{"phone": "+70860568052"}
0005433570562	D5C1FE	4094 817933	ELENA LUKYANOVA	{"phone": "+70502350506"}
0005433570563	D5C1FE	8602 700137	SVETLANA OSIPOVA	{"email": "s-osipova.23031974@postgrespro.ru", "phone": "+70579901601"}
0005433570564	ED06A1	9658 124581	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila_061974@postgrespro.ru", "phone": "+70000352615"}
0005433570565	4D12AE	0419 477771	PETR TIKHONOV	{"phone": "+70940087749"}
0005433570566	4D8DAF	9674 165211	SERGEY OSIPOV	{"email": "sergey.osipov1965@postgrespro.ru", "phone": "+70222737539"}
0005433570567	88C256	3168 552022	ASIYA BOGDANOVA	{"email": "bogdanova.a_031975@postgrespro.ru", "phone": "+70219806214"}
0005433570568	C9C94C	9054 553905	LEV ANDREEV	{"phone": "+70270037015"}
0005433570569	C9C94C	9678 303241	NIKOLAY SOLOVEV	{"email": "nikolay-solovev17071979@postgrespro.ru", "phone": "+70972190118"}
0005433570570	1868CC	0506 170109	VIKTORIYA LOGINOVA	{"email": "loginova-viktoriya_011969@postgrespro.ru", "phone": "+70137622267"}
0005433570571	431593	1566 150440	MARIYA PAVLOVA	{"email": "pavlova.mariya27031972@postgrespro.ru", "phone": "+70335483668"}
0005433570572	431593	4399 038691	POLINA KUZMINA	{"phone": "+70045949588"}
0005433570573	61BE76	9459 747852	EVGENIY NIKITIN	{"email": "evgeniy_nikitin-25051972@postgrespro.ru", "phone": "+70193843261"}
0005433570574	00F82A	4360 638936	VADIM DENISOV	{"email": "v_denisov02091968@postgrespro.ru", "phone": "+70571073151"}
0005433570575	853E7F	1633 766349	LYUDMILA VOLKOVA	{"email": "volkova.lyudmila1971@postgrespro.ru", "phone": "+70827465072"}
0005433570576	0DDBC4	8950 133329	MARINA KOZLOVA	{"phone": "+70699039059"}
0005433570577	8AF0BD	1278 159329	RAVZA MAKAROVA	{"email": "makarova_ravza_1971@postgrespro.ru", "phone": "+70949288567"}
0005433570578	86EA6E	8063 912162	SERGEY MEDVEDEV	{"email": "medvedev_sergey-20051974@postgrespro.ru", "phone": "+70656439903"}
0005433570579	3AD724	5693 036760	GALINA MIKHAYLOVA	{"phone": "+70905913781"}
0005433570580	FB7894	8660 936410	NINA IVANOVA	{"email": "nina-ivanova-021983@postgrespro.ru", "phone": "+70780852626"}
0005433570581	FB7894	4183 106438	TIGRAN KOZLOV	{"email": "kozlovt011978@postgrespro.ru", "phone": "+70460351334"}
0005433570582	142438	3491 405941	RUSTAM VASILEV	{"email": "vasilev_rustam_16061970@postgrespro.ru", "phone": "+70667939418"}
0005433570583	E1C08A	3895 817276	VALENTINA KONOVALOVA	{"email": "konovalova_v_091974@postgrespro.ru", "phone": "+70146955494"}
0005433570584	FB17E0	4546 688615	VASILIY BORISOV	{"email": "v_borisov_1969@postgrespro.ru", "phone": "+70339290228"}
0005433570585	FB17E0	7760 436970	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.nikolay_1985@postgrespro.ru", "phone": "+70048234327"}
0005433570586	ABAA99	7873 951454	NIKITA MAKAROV	{"email": "makarov-nikita-14081969@postgrespro.ru", "phone": "+70495458607"}
0005433570587	ABAA99	3525 651733	VADIM ZAYCEV	{"phone": "+70871745994"}
0005433570588	55505B	0849 608145	NADEZHDA VASILEVA	{"email": "vasileva_n_20071980@postgrespro.ru", "phone": "+70742625081"}
0005433570589	5B05F8	2057 094210	GERMAN ALEKSANDROV	{"email": "g-aleksandrov-101981@postgrespro.ru", "phone": "+70568259316"}
0005433570590	5B05F8	8794 575861	DMITRIY FEDOROV	{"phone": "+70493647745"}
0005433570591	69B962	6908 604130	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova-lyubov_1967@postgrespro.ru", "phone": "+70889138559"}
0005433570592	845903	8979 154883	ALENA MEDVEDEVA	{"phone": "+70537625906"}
0005433570593	845903	0225 108025	ARTEM SMIRNOV	{"email": "a.smirnov091971@postgrespro.ru", "phone": "+70036040726"}
0005433570594	BC68F1	1500 129991	ARTEM TARASOV	{"phone": "+70237843925"}
0005433570595	BC68F1	2324 669273	VITALIY FROLOV	{"email": "v-frolov_1966@postgrespro.ru", "phone": "+70642689091"}
0005433570596	DC48CE	8449 210477	TAMARA ALEKSEEVA	{"phone": "+70261866516"}
0005433570597	DC48CE	9652 130388	YULIYA CHERNOVA	{"email": "chernova-y_1969@postgrespro.ru", "phone": "+70157860094"}
0005433570598	54E219	4467 676727	OLGA KISELEVA	{"email": "o.kiseleva17081971@postgrespro.ru", "phone": "+70535847141"}
0005433570599	73E4CB	6070 548677	TATYANA GAVRILOVA	{"phone": "+70727738619"}
0005433570600	4E5B5C	9102 487719	OLESYA DMITRIEVA	{"phone": "+70816971015"}
0005433570601	CC22A8	1658 830189	SERGEY ROMANOV	{"email": "sergey_romanov.21081972@postgrespro.ru", "phone": "+70129961925"}
0005433570602	F3F740	8272 959720	VALENTINA FROLOVA	{"email": "valentina-frolova-04051967@postgrespro.ru", "phone": "+70680092598"}
0005433570603	FC5B4B	0262 424876	SALAVAT TIMOFEEV	{"email": "salavat.timofeev-021975@postgrespro.ru", "phone": "+70251372454"}
0005433570604	80C34A	2249 950691	OLGA LEBEDEVA	{"phone": "+70125120192"}
0005433570605	1E9349	6082 185264	ZINAIDA MAKSIMOVA	{"email": "zmaksimova_21041978@postgrespro.ru", "phone": "+70505535294"}
0005433570606	1E9349	0276 230234	OLEG NOVIKOV	{"phone": "+70836962575"}
0005433570607	A843A2	5458 747052	NINA GERASIMOVA	{"email": "gerasimova.nina121960@postgrespro.ru", "phone": "+70508148020"}
0005433570608	A843A2	8250 650528	VLADIMIR CHERNOV	{"email": "vladimirchernov021962@postgrespro.ru", "phone": "+70103702416"}
0005433570609	D2FFC8	3266 184614	ALLA ZAYCEVA	{"email": "zaycevaalla-1984@postgrespro.ru", "phone": "+70206408687"}
0005433570610	2803B1	0022 944662	MAKSIM FROLOV	{"phone": "+70114616085"}
0005433570611	2803B1	5831 101441	NIKOLAY SOROKIN	{"phone": "+70714363677"}
0005433570612	B94FC5	2088 027304	EKATERINA MIRONOVA	{"email": "mironovae-06091971@postgrespro.ru", "phone": "+70800640863"}
0005433570613	4679D5	4460 702751	IVAN EGOROV	{"phone": "+70192126722"}
0005433570614	4679D5	0311 414806	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov.051977@postgrespro.ru", "phone": "+70380022825"}
0005433570615	0951B7	6213 340738	NADEZHDA BORISOVA	{"email": "borisova-n04041965@postgrespro.ru", "phone": "+70451363702"}
0005433570616	4789E4	8945 045840	SERGEY ZAKHAROV	{"email": "sergeyzakharov_081976@postgrespro.ru", "phone": "+70148856815"}
0005433570617	C90542	9404 661644	VALENTINA SEMENOVA	{"phone": "+70042202614"}
0005433570618	ECDDE5	0891 384182	LARISA VLASOVA	{"email": "l-vlasova-011973@postgrespro.ru", "phone": "+70650429582"}
0005433570619	049029	7064 743088	VITALIY KUZNECOV	{"email": "kuznecov.vitaliy_1972@postgrespro.ru", "phone": "+70935730582"}
0005433570620	43C08D	8435 177397	OLGA FILIPPOVA	{"email": "o_filippova.15081977@postgrespro.ru", "phone": "+70329607616"}
0005433570621	57033A	1165 420639	ALEKSEY ALEKSEEV	{"phone": "+70716432836"}
0005433570622	172A88	6383 396112	GULIYA EGOROVA	{"email": "gegorova-031971@postgrespro.ru", "phone": "+70115888203"}
0005433570624	B9449A	9641 475658	OLGA KUZNECOVA	{"phone": "+70649415352"}
0005433570625	25EF59	1530 069285	RAMILYA LEBEDEVA	{"email": "r-lebedeva19011983@postgrespro.ru", "phone": "+70174347109"}
0005433570626	5F84BA	6319 596084	SVETLANA KULIKOVA	{"phone": "+70302053688"}
0005433570627	CD1203	8263 529992	LYUDMILA KUZMINA	{"phone": "+70071083221"}
0005433570628	D7508A	3767 927394	VYACHESLAV BORISOV	{"phone": "+70650351634"}
0005433570629	D7508A	2567 915743	ARTUR BORISOV	{"email": "artur.borisov22041959@postgrespro.ru", "phone": "+70837010824"}
0005433570630	7BF07D	2613 015436	FEDOR KARPOV	{"phone": "+70246341681"}
0005433570631	4ED173	0300 616675	SERGEY IVANOV	{"email": "ivanov-sergey.1966@postgrespro.ru", "phone": "+70955107550"}
0005433570632	2F6B0B	9044 674708	NIKITA ZAKHAROV	{"email": "nikitazakharov_1973@postgrespro.ru", "phone": "+70607505341"}
0005433570633	2F6B0B	8198 138980	TAMARA MATVEEVA	{"email": "matveevatamara.17081973@postgrespro.ru", "phone": "+70102343219"}
0005433570634	43F06D	5946 495621	NIKOLAY VASILEV	{"phone": "+70592684093"}
0005433570635	8C510D	9334 880853	DMITRIY SOROKIN	{"email": "dmitriy.sorokin_22011974@postgrespro.ru", "phone": "+70732779233"}
0005433570636	8C510D	3003 656801	VALERIY BORISOV	{"email": "valeriy-borisov08051962@postgrespro.ru", "phone": "+70894573133"}
0005433570637	D6F5FA	8255 759645	PAVEL KUZNECOV	{"email": "kuznecov.p_071970@postgrespro.ru", "phone": "+70202131085"}
0005433570638	C292F3	4921 136285	IVAN ZAKHAROV	{"email": "ivanzakharov121975@postgrespro.ru", "phone": "+70017165937"}
0005433570639	533317	7543 840664	OLGA DENISOVA	{"email": "o_denisova_081975@postgrespro.ru", "phone": "+70010567733"}
0005433570640	8F0C93	6107 870475	RUSLAN PETROV	{"email": "ruslan.petrov_03041960@postgrespro.ru", "phone": "+70371313934"}
0005433570641	8F0C93	9102 651413	VALENTINA PAVLOVA	{"email": "pavlovavalentina1975@postgrespro.ru", "phone": "+70897375507"}
0005433570642	9A1BD0	2366 960578	ANDREY FROLOV	{"email": "frolov-a1966@postgrespro.ru", "phone": "+70160443407"}
0005433570643	54636D	0968 885057	ELENA ZHURAVLEVA	{"email": "zhuravleva.e.051979@postgrespro.ru", "phone": "+70656068121"}
0005433570644	54636D	3323 715010	ROBERT GORBUNOV	{"phone": "+70471862042"}
0005433570645	304798	3170 167140	ANDREY ANDREEV	{"email": "a_andreev_1957@postgrespro.ru", "phone": "+70095353601"}
0005433570646	890CFF	8052 371197	ANGELINA BELYAEVA	{"email": "belyaeva_angelina_041971@postgrespro.ru", "phone": "+70511940246"}
0005433570647	890CFF	9752 660607	VYACHESLAV DENISOV	{"phone": "+70344000878"}
0005433570648	4A2301	1983 510643	ANASTASIYA PAVLOVA	{"phone": "+70081356285"}
0005433570649	5CBCC0	2503 016456	ALLA KULIKOVA	{"email": "kulikovaalla081974@postgrespro.ru", "phone": "+70611865446"}
0005433570650	5CBCC0	6427 220741	ELENA KRASNOVA	{"phone": "+70832928333"}
0005433570651	D9A1B9	8492 455418	ALEKSEY PAVLOV	{"phone": "+70059915164"}
0005433570652	3CE679	6515 370303	EKATERINA BELYAEVA	{"phone": "+70883152743"}
0005433570653	CB0394	4918 581976	VLADIMIR SAVELEV	{"phone": "+70936235891"}
0005433570654	CB0394	7822 822266	REGINA KOZLOVA	{"phone": "+70970910352"}
0005433570655	E70513	8880 359465	KIRILL ROMANOV	{"email": "kirill_romanov05111962@postgrespro.ru", "phone": "+70700218525"}
0005433570656	E70513	7468 288568	YULIYA SERGEEVA	{"phone": "+70135778753"}
0005433570657	5C787E	1561 873823	IGOR BARANOV	{"email": "ibaranov_101965@postgrespro.ru", "phone": "+70251868825"}
0005433570658	5C787E	4618 778630	IVAN TARASOV	{"email": "i.tarasov1974@postgrespro.ru", "phone": "+70483165492"}
0005433570659	559F12	9127 704003	MARIYA FROLOVA	{"email": "m.frolova-1977@postgrespro.ru", "phone": "+70548551267"}
0005433570660	559F12	0691 141812	ARINA SMIRNOVA	{"phone": "+70675600105"}
0005433570661	C43DB9	5377 918915	ELMIRA KOVALEVA	{"email": "elmira.kovaleva.051973@postgrespro.ru", "phone": "+70459319923"}
0005433570662	3FF29F	3236 949436	IVAN IVANOV	{"email": "ivanovivan_1972@postgrespro.ru", "phone": "+70656788408"}
0005433570663	3C8398	8833 704090	ELENA KUZNECOVA	{"email": "kuznecova.e29011961@postgrespro.ru", "phone": "+70163571962"}
0005433570664	3C8398	0251 881780	VIKTOR TIKHONOV	{"email": "tikhonov.viktor_28011969@postgrespro.ru", "phone": "+70551709729"}
0005433570665	05523D	9966 849509	LYUDMILA MIKHAYLOVA	{"phone": "+70967218086"}
0005433570666	2FD171	9873 096519	GULFIYA MALYSHEVA	{"email": "gulfiya_malysheva_081967@postgrespro.ru", "phone": "+70539291418"}
0005433570667	FFEC95	9595 612819	EKATERINA DANILOVA	{"email": "danilova-e_1980@postgrespro.ru", "phone": "+70590085570"}
0005433570668	FFEC95	8129 749066	DANIIL PETROV	{"phone": "+70766433192"}
0005433570669	C69D10	5765 425315	ELENA MAKSIMOVA	{"phone": "+70936146077"}
0005433570670	5DFA31	2151 960688	VALENTINA FEDOROVA	{"email": "valentinafedorova_24081974@postgrespro.ru", "phone": "+70673574295"}
0005433570671	F11C7C	6542 372210	ANNA ZAKHAROVA	{"email": "anna_zakharova03021971@postgrespro.ru", "phone": "+70935555007"}
0005433570672	31568E	1173 816598	ANDREY KOROLEV	{"email": "korolev-a13071969@postgrespro.ru", "phone": "+70867863412"}
0005433570673	70F026	7054 292700	ALEKSEY MEDVEDEV	{"phone": "+70636447186"}
0005433570674	478C68	6096 571074	ALEKSEY SOLOVEV	{"email": "solovev-a_30091966@postgrespro.ru", "phone": "+70412195777"}
0005433570675	ED4E11	1732 184690	ELENA FILIPPOVA	{"email": "filippova.e.09111968@postgrespro.ru", "phone": "+70037415660"}
0005433570676	EA1405	7335 833444	ZINAIDA YAKOVLEVA	{"phone": "+70225813417"}
0005433570677	DB1197	6484 364841	ALEKSEY SCHERBAKOV	{"phone": "+70312541486"}
0005433570678	ED940E	9336 556333	DENIS RODIONOV	{"email": "rodionovdenis1966@postgrespro.ru", "phone": "+70479290154"}
0005433570679	CA406D	5149 083736	MARAT EGOROV	{"email": "egorovm121966@postgrespro.ru", "phone": "+70029047624"}
0005433570680	C1785E	9654 153349	LYUDMILA NIKIFOROVA	{"email": "lyudmila.nikiforova-081973@postgrespro.ru", "phone": "+70210468696"}
0005433570681	353B97	3391 430869	MARGARITA KRASNOVA	{"phone": "+70911376730"}
0005433570682	9483DD	8838 914375	PETR RODIONOV	{"phone": "+70791396725"}
0005433570683	7EE446	1749 707090	SERGEY GORBUNOV	{"phone": "+70360143877"}
0005433570684	DB4B46	2644 617263	IVAN ZHURAVLEV	{"phone": "+70273442070"}
0005433570685	8FE1F7	4713 962652	MIKHAIL FILIPPOV	{"email": "mfilippov_1969@postgrespro.ru", "phone": "+70072330650"}
0005433570686	D07055	0292 099996	VLADIMIR NAUMOV	{"phone": "+70250545852"}
0005433570687	134790	1755 577171	IVAN IVANOV	{"email": "i_ivanov_051957@postgrespro.ru", "phone": "+70609063142"}
0005433570688	921F40	4091 053103	IBRAGIM RODIONOV	{"phone": "+70275766379"}
0005433570689	921F40	7874 684964	NINA TIKHONOVA	{"email": "tikhonova-nina_01091970@postgrespro.ru", "phone": "+70856060672"}
0005433570690	ECC601	5916 710550	KRISTINA ZAYCEVA	{"phone": "+70606403864"}
0005433570691	ECC601	4698 406658	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr051976@postgrespro.ru", "phone": "+70725966417"}
0005433570692	EBE283	7269 857526	SVETLANA POLYAKOVA	{"email": "s_polyakova_1978@postgrespro.ru", "phone": "+70212760463"}
0005433570693	EBE283	6848 156830	YULIYA BELYAEVA	{"phone": "+70681102397"}
0005433570694	9FFBCD	2972 846987	OLGA NOVIKOVA	{"phone": "+70766986325"}
0005433570695	4061C2	6896 570565	KONSTANTIN KUZNECOV	{"phone": "+70535824691"}
0005433570696	4061C2	5941 010228	NADEZHDA DAVYDOVA	{"phone": "+70321129644"}
0005433570697	EBFCEC	8808 597235	IGOR FOMIN	{"phone": "+70290903683"}
0005433570698	EBFCEC	7428 612827	TATYANA GRISHINA	{"email": "grishina.t-121964@postgrespro.ru", "phone": "+70924730863"}
0005433570699	EC7438	8221 739971	NATALYA NAZAROVA	{"email": "nazarova_natalya.1979@postgrespro.ru", "phone": "+70649556560"}
0005433570700	A38530	2202 248940	VIKTOR FILIPPOV	{"email": "v-filippov_1980@postgrespro.ru", "phone": "+70215634177"}
0005433570701	6DFE42	9691 469451	OLGA KOMAROVA	{"email": "komarova-o_27081967@postgrespro.ru", "phone": "+70645196997"}
0005433570702	BE4D7B	0437 476809	GENNADIY CHERNOV	{"email": "chernov_gennadiy_041977@postgrespro.ru", "phone": "+70254325336"}
0005433570703	311984	0032 824384	VLADIMIR CHERNOV	{"email": "chernov_vladimir.06041974@postgrespro.ru", "phone": "+70854451054"}
0005433570704	B592D8	4660 028475	ILDAR TIMOFEEV	{"email": "itimofeev.061974@postgrespro.ru", "phone": "+70983021367"}
0005433570705	F7684A	4537 946241	IRAIDA EFREMOVA	{"phone": "+70948940403"}
0005433570706	64427A	2248 396895	ELIZAVETA TIKHONOVA	{"phone": "+70892986487"}
0005433570707	64427A	1847 020976	ALEKSEY OSIPOV	{"phone": "+70428719821"}
0005433570708	BC57BF	1510 083206	YURIY KONOVALOV	{"phone": "+70624329572"}
0005433570709	E3DF47	9218 222426	GENNADIY FEDOROV	{"email": "g.fedorov-23021972@postgrespro.ru", "phone": "+70991104231"}
0005433570710	E3DF47	5769 108201	EKATERINA KOROLEVA	{"email": "ekoroleva-22081982@postgrespro.ru", "phone": "+70485144239"}
0005433570711	8C75B1	6249 690258	ELENA KULIKOVA	{"phone": "+70188173583"}
0005433570712	D7383A	2694 983869	LYUBOV ROMANOVA	{"phone": "+70878765754"}
0005433570713	5F0E9C	0155 710366	KIRILL KUZNECOV	{"email": "kuznecov-k_101978@postgrespro.ru", "phone": "+70815399083"}
0005433570714	1F9B9C	2481 585016	TATYANA KISELEVA	{"email": "tkiseleva.1973@postgrespro.ru", "phone": "+70706332674"}
0005433570715	1F9B9C	0211 401633	NAIL KRASNOV	{"email": "krasnov_nail_1960@postgrespro.ru", "phone": "+70450531577"}
0005433570716	4C1B7A	3411 246777	ALEKSANDR MOROZOV	{"phone": "+70996630160"}
0005433570717	4C1B7A	9283 417742	DENIS DENISOV	{"email": "denisov-denis_091967@postgrespro.ru", "phone": "+70493446909"}
0005433570718	A06B66	7365 515777	OLGA IVANOVA	{"phone": "+70884357255"}
0005433570719	A06B66	2399 015391	NATALYA ANDREEVA	{"phone": "+70300294861"}
0005433570720	444D6C	8085 442048	DMITRIY KUZNECOV	{"email": "dmitriykuznecov1971@postgrespro.ru", "phone": "+70008398569"}
0005433570721	6EE716	9280 666487	ELENA SCHERBAKOVA	{"email": "elena-scherbakova.14111981@postgrespro.ru", "phone": "+70151544503"}
0005433570722	CC0E57	2572 052709	LYUBOV KONOVALOVA	{"email": "konovalova.l-051974@postgrespro.ru", "phone": "+70823130384"}
0005433570723	A39C9F	8072 246673	NINA SERGEEVA	{"email": "sergeeva.nina-09011961@postgrespro.ru", "phone": "+70316138702"}
0005433570724	A39C9F	2679 248179	VLADIMIR KUZNECOV	{"phone": "+70996070813"}
0005433570725	7D4FA9	8311 562859	NINA RYABOVA	{"email": "ryabova.nina.04111960@postgrespro.ru", "phone": "+70497851850"}
0005433570726	7D4FA9	8467 660123	ROBERT GAVRILOV	{"phone": "+70043039775"}
0005433570727	2657E4	5041 073338	MAKSIM SOLOVEV	{"email": "m-solovev_10011965@postgrespro.ru", "phone": "+70028021055"}
0005433570728	1A566A	5555 804913	SERGEY ALEKSEEV	{"email": "alekseev-s.051973@postgrespro.ru", "phone": "+70557781255"}
0005433570729	B1A7A7	7835 069824	LEV IVANOV	{"email": "lev_ivanov-25021971@postgrespro.ru", "phone": "+70560561485"}
0005433570730	F0A3D2	4635 175018	SERGEY BORISOV	{"email": "sborisov1969@postgrespro.ru", "phone": "+70343829514"}
0005433570731	E35AE1	7267 019225	VLADIMIR BORISOV	{"phone": "+70885816709"}
0005433570732	C940A0	5775 885654	ALEKSANDR CHERNOV	{"phone": "+70312715390"}
0005433570733	F529A4	0708 909074	SVETLANA TIKHONOVA	{"email": "tikhonova_s.091969@postgrespro.ru", "phone": "+70728147709"}
0005433570734	C98498	6640 390300	OLGA ALEKSEEVA	{"email": "alekseevaolga121975@postgrespro.ru", "phone": "+70779438415"}
0005433570735	C98498	4103 850835	VITALIY SOROKIN	{"phone": "+70463063361"}
0005433570736	13BF93	3144 079220	NIKOLAY BELOV	{"email": "nikolaybelov_14071973@postgrespro.ru", "phone": "+70467653608"}
0005433570737	13BF93	4508 206315	GENNADIY SMIRNOV	{"email": "smirnov-g031983@postgrespro.ru", "phone": "+70550486982"}
0005433570738	F8538B	1893 461827	LIDIYA POTAPOVA	{"email": "lidiya-potapova.1970@postgrespro.ru", "phone": "+70926209461"}
0005433570739	33F5BF	5180 849548	VYACHESLAV SERGEEV	{"phone": "+70175794093"}
0005433570740	33F5BF	4612 151845	MARIYA BELOVA	{"email": "belova.m_121969@postgrespro.ru", "phone": "+70536872003"}
0005433570741	0E657C	7331 035175	ELENA LEBEDEVA	{"email": "lebedeva_e.021982@postgrespro.ru", "phone": "+70184575575"}
0005433570742	FE8430	9144 347771	OLGA IVANOVA	{"phone": "+70317034980"}
0005433570743	FE8430	6243 188671	LYUDMILA IVANOVA	{"phone": "+70171470076"}
0005433570744	7C0EDF	1791 452966	OLESYA MARTYNOVA	{"email": "martynovao-091977@postgrespro.ru", "phone": "+70816728939"}
0005433570745	7C0EDF	4067 698367	OLGA ZAKHAROVA	{"phone": "+70729935918"}
0005433570746	75DE12	7349 144644	MARIYA KOLESNIKOVA	{"email": "kolesnikova-mariya_27111965@postgrespro.ru", "phone": "+70730616554"}
0005433570747	F39585	9744 489273	VADIM GAVRILOV	{"email": "v.gavrilov_28071964@postgrespro.ru", "phone": "+70499682075"}
0005433570748	4CAEA2	8141 865821	ANDREY PETROV	{"phone": "+70907412423"}
0005433570749	4CAEA2	2858 180127	VALENTINA GAVRILOVA	{"email": "v.gavrilova_1957@postgrespro.ru", "phone": "+70542348613"}
0005433570750	8581C5	3377 606409	DMITRIY MATVEEV	{"email": "matveev-dmitriy.111976@postgrespro.ru", "phone": "+70841400376"}
0005433570751	6AC268	9187 259586	PAVEL KUZMIN	{"email": "kuzmin-p-1978@postgrespro.ru", "phone": "+70978202849"}
0005433570752	3FF409	1231 792988	NIKOLAY SIDOROV	{"phone": "+70080101414"}
0005433570753	7D9DA4	5603 928816	RUSHANIYA MEDVEDEVA	{"email": "rushaniya.medvedeva_19111981@postgrespro.ru", "phone": "+70246629591"}
0005433570754	B4FE6D	5664 989097	NURLAN POPOV	{"phone": "+70044936245"}
0005433570755	6138B0	9473 507145	VALENTIN MOROZOV	{"email": "v_morozov_121965@postgrespro.ru", "phone": "+70843896030"}
0005433570756	07647A	5700 523309	GALINA GUSEVA	{"phone": "+70316920039"}
0005433570757	D5A0C1	7127 006515	ALEKSEY GERASIMOV	{"phone": "+70056365506"}
0005433570758	BFC074	8174 671364	ELENA YUDINA	{"phone": "+70086297525"}
0005433570759	78562E	6129 555603	ALEKSEY KUZNECOV	{"email": "kuznecov.a.09041973@postgrespro.ru", "phone": "+70980356466"}
0005433570760	1B96A7	2377 617301	SERGEY POPOV	{"email": "popov-sergey_1976@postgrespro.ru", "phone": "+70386951611"}
0005433570761	8E5D58	3430 210785	VLADISLAV KRASNOV	{"phone": "+70591629019"}
0005433570762	8E5D58	1130 361014	OLGA DANILOVA	{"phone": "+70499482454"}
0005433570763	1F1ADA	6417 438617	ARINA BELOVA	{"phone": "+70062954510"}
0005433570764	B9BB53	9242 939699	ANNA KUZMINA	{"phone": "+70228809633"}
0005433570765	B9BB53	0544 340424	EVGENIY KUZMIN	{"email": "evgeniykuzmin-25081975@postgrespro.ru", "phone": "+70556376399"}
0005433570766	E74AC7	7731 131028	DIANA SERGEEVA	{"phone": "+70073130421"}
0005433570767	E74AC7	4926 120214	IVAN GORBUNOV	{"email": "ivan.gorbunov_09121967@postgrespro.ru", "phone": "+70517163520"}
0005433570768	C51A56	4114 924689	IVAN SAVELEV	{"phone": "+70738736429"}
0005433570769	C51A56	2652 487194	VLADIMIR KOZLOV	{"phone": "+70364558155"}
0005433570770	C51A56	0118 538026	ALEKSEY MATVEEV	{"phone": "+70107285756"}
0005433570771	3FCECC	6370 243795	IRINA KISELEVA	{"email": "kiseleva-i.1976@postgrespro.ru", "phone": "+70406668992"}
0005433570772	E9F35E	6245 039725	IGOR BELOV	{"phone": "+70467650794"}
0005433570773	8C2CFF	0946 439084	NATALYA NIKITINA	{"email": "nikitina.natalya_18081961@postgrespro.ru", "phone": "+70105563372"}
0005433570774	8C2CFF	4425 736759	ALEKSANDR MELNIKOV	{"phone": "+70960127220"}
0005433570775	D7505A	3858 733787	ANNA SOLOVEVA	{"phone": "+70543303396"}
0005433570776	95451B	7254 204598	ELENA NOVIKOVA	{"email": "elenanovikova-101972@postgrespro.ru", "phone": "+70128167507"}
0005433570777	95451B	9277 009575	SERGEY DMITRIEV	{"phone": "+70768998300"}
0005433570778	092FB2	6276 301665	ANASTASIYA DMITRIEVA	{"email": "dmitrieva_anastasiya-121969@postgrespro.ru", "phone": "+70020982206"}
0005433570779	B25F0A	1025 497869	IGOR MAKSIMOV	{"phone": "+70108859202"}
0005433570780	B25F0A	6549 181932	SEMEN FROLOV	{"phone": "+70085238107"}
0005433570781	AD56D2	4927 199767	YULIYA TROFIMOVA	{"email": "y_trofimova.051973@postgrespro.ru", "phone": "+70389452142"}
0005433570782	539539	0753 682396	ANDREY MARTYNOV	{"phone": "+70042628766"}
0005433570783	539539	6724 775920	VLADIMIR MAKSIMOV	{"phone": "+70731556701"}
0005433570784	C27C34	8568 695446	ELIZAVETA KOROLEVA	{"email": "elizaveta-koroleva.1984@postgrespro.ru", "phone": "+70039811855"}
0005433570785	C27C34	1221 566115	EGOR KOZLOV	{"phone": "+70037204537"}
0005433570786	D9B416	2377 651295	LEONID ALEKSANDROV	{"email": "aleksandrov-leonid_14021976@postgrespro.ru", "phone": "+70167658329"}
0005433570787	D9B416	0657 354642	GALINA KUZNECOVA	{"phone": "+70666713083"}
0005433570788	8B490E	2571 610926	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr_1969@postgrespro.ru", "phone": "+70983887733"}
0005433570789	4B1DA2	9879 567368	VLADIMIR KULIKOV	{"email": "vladimir-kulikov.1976@postgrespro.ru", "phone": "+70504054058"}
0005433570790	4B1DA2	6659 499867	VALERIY PETROV	{"email": "petrovvaleriy.011970@postgrespro.ru", "phone": "+70256997555"}
0005433570791	4B1DA2	8678 770551	MARIYA DMITRIEVA	{"email": "dmitrievam-1981@postgrespro.ru", "phone": "+70781065757"}
0005433570792	45B6BE	9583 676944	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrova_aleksandra_07081978@postgrespro.ru", "phone": "+70015181300"}
0005433570793	45B6BE	4907 119517	ELIZAVETA KUZMINA	{"phone": "+70440368358"}
0005433570794	997BD3	9550 594259	ELENA ROMANOVA	{"email": "elenaromanova-01031969@postgrespro.ru", "phone": "+70330087959"}
0005433570795	757225	5972 520635	NINA SERGEEVA	{"email": "sergeeva.n.031964@postgrespro.ru", "phone": "+70181608484"}
0005433570796	87753B	7453 945696	NINA MOROZOVA	{"phone": "+70998119057"}
0005433570797	87753B	0981 186797	MIKHAIL POPOV	{"phone": "+70739300936"}
0005433570798	87753B	8552 241753	MAKSIM PETROV	{"phone": "+70876725590"}
0005433570799	3649B0	5613 812829	OKSANA SMIRNOVA	{"email": "smirnova_o1981@postgrespro.ru", "phone": "+70062286726"}
0005433570800	3D1F22	7144 109769	MAKSIM KAZAKOV	{"email": "mkazakov-1980@postgrespro.ru", "phone": "+70228993712"}
0005433570801	DD7C1A	0789 547148	IRAIDA ZHUKOVA	{"phone": "+70376000711"}
0005433570802	F2648A	2453 011566	SVETLANA MIKHAYLOVA	{"phone": "+70156665372"}
0005433570803	F2648A	3070 710692	IGOR TIKHONOV	{"phone": "+70697060427"}
0005433570804	4BAA08	6388 117684	MAKSIM SOLOVEV	{"email": "solovev-m.051967@postgrespro.ru", "phone": "+70037300256"}
0005433570805	4BAA08	1033 078665	LIDIYA VASILEVA	{"email": "vasileva-l_08091961@postgrespro.ru", "phone": "+70159113555"}
0005433570806	FF5E27	0529 161521	TAMARA AFANASEVA	{"phone": "+70523215091"}
0005433570807	FF5E27	9277 822977	VALENTINA MALYSHEVA	{"email": "v.malysheva-1970@postgrespro.ru", "phone": "+70688090599"}
0005433570808	FF5E27	0657 801171	ILYA RODIONOV	{"phone": "+70317043052"}
0005433570809	39ADAA	8532 961643	NADEZHDA DAVYDOVA	{"email": "davydova-n-1972@postgrespro.ru", "phone": "+70747716362"}
0005433570810	24F366	8978 344909	NINA SIDOROVA	{"phone": "+70517287900"}
0005433570811	974E77	8939 272568	GALINA ILINA	{"phone": "+70789228641"}
0005433570812	4D5E5B	8965 748855	ROMAN MOISEEV	{"phone": "+70275132552"}
0005433570813	18C00A	0565 080225	ALLA KUZMINA	{"phone": "+70159926108"}
0005433570814	9E8665	2418 915115	EKATERINA IVANOVA	{"email": "ekaterinaivanova1967@postgrespro.ru", "phone": "+70244006435"}
0005433570815	9E8665	9508 487236	ALEKSEY VASILEV	{"email": "vasilev-a.101970@postgrespro.ru", "phone": "+70771503782"}
0005433570816	F352B0	8957 655869	ANASTASIYA MIRONOVA	{"phone": "+70416613436"}
0005433570817	D144D7	7502 525883	VIKTORIYA MAKSIMOVA	{"phone": "+70959774098"}
0005433570818	BBD25E	3325 545365	ANDREY EGOROV	{"email": "andrey.egorov081962@postgrespro.ru", "phone": "+70155007129"}
0005433570819	12200C	1332 419360	SERGEY ZHUKOV	{"phone": "+70297759720"}
0005433570820	1EDF04	1971 515118	IGOR PETROV	{"email": "petrov.igor-19091971@postgrespro.ru", "phone": "+70669285429"}
0005433570821	3E54E4	4069 635182	SERGEY KUZNECOV	{"email": "s-kuznecov-071989@postgrespro.ru", "phone": "+70917627097"}
0005433570822	3E54E4	4724 812701	VYACHESLAV ALEKSEEV	{"email": "v.alekseev-1971@postgrespro.ru", "phone": "+70619737517"}
0005433570823	693982	9730 390459	OKSANA MOISEEVA	{"email": "o_moiseeva.16051981@postgrespro.ru", "phone": "+70981538799"}
0005433570824	06A528	5261 794753	VLADIMIR NOVIKOV	{"phone": "+70324050473"}
0005433570825	06A528	1470 947058	MATVEY KOROLEV	{"email": "matvey-korolev_27121960@postgrespro.ru", "phone": "+70792739537"}
0005433570826	8646A2	1021 720063	ALEKSANDR KOZLOV	{"phone": "+70314960332"}
0005433570827	FAC2D7	5622 685002	TAISIYA ANDREEVA	{"email": "andreeva_taisiya-28011955@postgrespro.ru", "phone": "+70412508832"}
0005433570828	5BD34A	5417 867980	YULIYA KARPOVA	{"email": "yuliyakarpova1965@postgrespro.ru", "phone": "+70371612191"}
0005433570829	D2C291	4919 472228	NATALIYA SOLOVEVA	{"email": "n.soloveva1969@postgrespro.ru", "phone": "+70905687177"}
0005433570830	D2C291	7480 696643	OLEG MIKHAYLOV	{"email": "mikhaylov.oleg-121971@postgrespro.ru", "phone": "+70157149661"}
0005433570831	D2C291	7083 044844	LYUDMILA LUKYANOVA	{"phone": "+70554514372"}
0005433570832	6C49D4	2151 120545	TATYANA MASLOVA	{"email": "t.maslova-1970@postgrespro.ru", "phone": "+70405525013"}
0005433570833	7CA8C5	8930 569982	YURIY FILIPPOV	{"email": "filippov-y-1970@postgrespro.ru", "phone": "+70116054660"}
0005433570834	DA6A12	1509 806397	YURIY NIKITIN	{"email": "y_nikitin22111969@postgrespro.ru", "phone": "+70598919123"}
0005433570835	DA6A12	3187 850068	YURIY VOLKOV	{"email": "y_volkov.111964@postgrespro.ru", "phone": "+70955882071"}
0005433570836	53230F	7105 042961	MARIYA NIKOLAEVA	{"phone": "+70891728478"}
0005433570837	53230F	8011 218885	TAMARA ABRAMOVA	{"email": "t.abramova-27071978@postgrespro.ru", "phone": "+70509027704"}
0005433570838	E09F18	8316 229557	NATALIYA RODIONOVA	{"email": "n_rodionova.101975@postgrespro.ru", "phone": "+70414519542"}
0005433570839	18863B	8640 729696	MIKHAIL STEPANOV	{"email": "stepanovm-1982@postgrespro.ru", "phone": "+70862345581"}
0005433570840	18863B	2911 891710	GALINA ARKHIPOVA	{"phone": "+70544525064"}
0005433570841	F1329C	2995 089135	ELENA GRISHINA	{"email": "e_grishina-021971@postgrespro.ru", "phone": "+70129961609"}
0005433570842	F1329C	4329 161482	NINA VOLKOVA	{"email": "n_volkova-14081951@postgrespro.ru", "phone": "+70068302763"}
0005433570843	3FE5E2	9072 339183	VLADIMIR POPOV	{"phone": "+70039234023"}
0005433570844	1E170F	5186 015776	VLADIMIR BARANOV	{"email": "vladimirbaranov.1972@postgrespro.ru", "phone": "+70855787242"}
0005433570845	1C47DF	0314 970733	ARTEM MARTYNOV	{"phone": "+70635843701"}
0005433570846	1C47DF	8686 322121	MARIANNA SAVELEVA	{"phone": "+70305878099"}
0005433570847	9998CF	5787 940769	NIKOLAY DAVYDOV	{"email": "nikolaydavydov27041968@postgrespro.ru", "phone": "+70844964548"}
0005433570848	269504	5020 109703	VLADIMIR VOROBEV	{"email": "vorobev_vladimir26051965@postgrespro.ru", "phone": "+70650601773"}
0005433570849	269504	6118 003045	NATALIYA STEPANOVA	{"email": "stepanova_n.22121982@postgrespro.ru", "phone": "+70777372721"}
0005433570850	269504	3243 617042	EKATERINA LEBEDEVA	{"phone": "+70549859469"}
0005433570851	0046B5	3746 444797	YURIY NOVIKOV	{"phone": "+70162638851"}
0005433570852	02A0AE	0878 690434	IRINA KARPOVA	{"email": "karpova-irina_041976@postgrespro.ru", "phone": "+70722292089"}
0005433570853	6376D4	7024 803235	ELENA GORBUNOVA	{"email": "gorbunova-e101968@postgrespro.ru", "phone": "+70246282756"}
0005433570854	41EF18	5586 949658	ALEKSANDR ILIN	{"email": "ailin_1963@postgrespro.ru", "phone": "+70866736590"}
0005433570855	29A6DC	7792 931325	VADIM MEDVEDEV	{"phone": "+70223721432"}
0005433570856	98E033	0026 809930	EVGENIY MOISEEV	{"phone": "+70481835383"}
0005433570857	B62CC7	4187 709725	ALBERT VOLKOV	{"email": "volkov_a_1968@postgrespro.ru", "phone": "+70723411417"}
0005433570858	17D2C1	7549 661691	VLADIMIR SOKOLOV	{"phone": "+70858775707"}
0005433570859	45DE77	3206 650853	SERGEY KUZNECOV	{"phone": "+70654838860"}
0005433570860	73EEE9	5913 117850	MIKHAIL ALEKSANDROV	{"phone": "+70921404448"}
0005433570861	2072E0	5154 722173	INNA PAVLOVA	{"phone": "+70298384259"}
0005433570862	65072B	6394 459043	GALINA IVANOVA	{"phone": "+70939304365"}
0005433570863	DE18BE	0138 050198	LYUDMILA NIKITINA	{"email": "nikitina-lyudmila-10091970@postgrespro.ru", "phone": "+70375426439"}
0005433570864	4ACB3F	0787 581647	NATALYA LUKYANOVA	{"phone": "+70658064508"}
0005433570865	FD621D	5503 232288	OLGA IVANOVA	{"phone": "+70541145822"}
0005433570866	AEA3D6	1290 765657	GENNADIY KONOVALOV	{"phone": "+70004323490"}
0005433570867	46EF1C	8750 398049	LYUDMILA MALYSHEVA	{"email": "lmalysheva-111978@postgrespro.ru", "phone": "+70312055161"}
0005433570868	1BEE95	8050 932356	SERGEY SERGEEV	{"phone": "+70399633347"}
0005433570869	9DA7AA	2618 020091	BORIS MOROZOV	{"email": "morozov.boris16101987@postgrespro.ru", "phone": "+70952741601"}
0005433570870	C007A8	7841 879484	ALEKSEY POPOV	{"email": "popov_a_041972@postgrespro.ru", "phone": "+70326380594"}
0005433570871	C007A8	3817 470375	ALEKSANDR POPOV	{"email": "aleksandr_popov.061972@postgrespro.ru", "phone": "+70575147809"}
0005433570872	034DF3	6753 564896	NATALYA POPOVA	{"phone": "+70888326166"}
0005433570873	034DF3	9126 862141	PETR KONOVALOV	{"email": "konovalovpetr_1975@postgrespro.ru", "phone": "+70308024873"}
0005433570874	6FDC4F	2188 275458	VLADISLAV ALEKSANDROV	{"email": "vladislav-aleksandrov_031977@postgrespro.ru", "phone": "+70273376580"}
0005433570875	085C72	0355 077717	ANATOLIY KISELEV	{"email": "anatoliy_kiselev-1966@postgrespro.ru", "phone": "+70641107921"}
0005433570876	DE1520	5303 285565	DMITRIY TARASOV	{"phone": "+70127452559"}
0005433570877	119E05	3380 729947	NATALYA LOGINOVA	{"email": "loginova-n.17061982@postgrespro.ru", "phone": "+70953661488"}
0005433570878	B62737	0808 867463	LIDIYA POPOVA	{"email": "l-popova_02091962@postgrespro.ru", "phone": "+70015803123"}
0005433570879	2C2BED	4949 669300	KLAVDIYA KOVALEVA	{"phone": "+70330810029"}
0005433570880	0C94FD	6249 062708	OLESYA SEMENOVA	{"phone": "+70623253472"}
0005433570881	D87CCC	9405 339952	GALINA KUZNECOVA	{"email": "gkuznecova.1973@postgrespro.ru", "phone": "+70400862988"}
0005433570882	8C7D9A	4119 527110	RAFAIL MAKSIMOV	{"phone": "+70721910837"}
0005433570883	F2C7F6	3150 902268	VALERIY KUZMIN	{"email": "kuzmin.valeriy-1972@postgrespro.ru", "phone": "+70955833335"}
0005433570884	334D88	5191 934987	MIKHAIL MELNIKOV	{"email": "melnikov.mikhail_13011975@postgrespro.ru", "phone": "+70426326764"}
0005433570885	9083F0	9217 351150	ANNA FOMINA	{"email": "fomina.anna-1970@postgrespro.ru", "phone": "+70034958658"}
0005433570886	F44C66	6185 131893	ELENA IVANOVA	{"email": "ivanova.elena.23121965@postgrespro.ru", "phone": "+70613077404"}
0005433570887	9CD0AC	7814 410361	NADEZHDA VLASOVA	{"phone": "+70484766201"}
0005433570888	65BE0E	1077 960425	IVAN NOVIKOV	{"email": "novikov_i.04041973@postgrespro.ru", "phone": "+70817276561"}
0005433570889	F1B8BF	8166 988155	ARTUR KARPOV	{"email": "akarpov1973@postgrespro.ru", "phone": "+70831678651"}
0005433570890	F1B8BF	2115 869883	EKATERINA DAVYDOVA	{"email": "davydova_e_08021968@postgrespro.ru", "phone": "+70763081388"}
0005433570891	988C02	1477 533769	NIKITA IVANOV	{"email": "ivanovnikita_121986@postgrespro.ru", "phone": "+70710406464"}
0005433570892	40D432	2312 823689	ALEVTINA KOROLEVA	{"email": "koroleva_a-1974@postgrespro.ru", "phone": "+70552784667"}
0005433570893	6ED308	6426 406487	NINA MAKAROVA	{"email": "nina_makarova081973@postgrespro.ru", "phone": "+70774842578"}
0005433570894	27A68C	8635 958014	OLEG SOLOVEV	{"email": "o_solovev.021982@postgrespro.ru", "phone": "+70855744185"}
0005433570895	27A68C	0955 833594	ANASTASIYA ALEKSEEVA	{"phone": "+70191664443"}
0005433570896	5D4A5A	0399 584774	NINA SIDOROVA	{"email": "sidorova-nina.081965@postgrespro.ru", "phone": "+70004497544"}
0005433570897	0F81D5	3315 980519	NATALYA KUZNECOVA	{"phone": "+70360750283"}
0005433570898	9A6220	6294 972159	ALBINA GRISHINA	{"phone": "+70415701203"}
0005433570899	023864	0352 000434	OLGA BELYAEVA	{"phone": "+70602394744"}
0005433570900	5E6538	0506 419406	SVETLANA IVANOVA	{"email": "ivanovasvetlana-1968@postgrespro.ru", "phone": "+70080900570"}
0005433570901	D7AB2A	8174 300500	ALEKSANDR PAVLOV	{"phone": "+70130168614"}
0005433570902	D7AB2A	1351 164003	VLADISLAV BARANOV	{"phone": "+70742629313"}
0005433570903	465650	6282 725989	OLGA MALYSHEVA	{"email": "malysheva_olga.1972@postgrespro.ru", "phone": "+70787012627"}
0005433570904	465650	9820 921567	VLADISLAV MAKAROV	{"phone": "+70266299236"}
0005433570905	465650	5216 981361	ANATOLIY STEPANOV	{"email": "a-stepanov.041976@postgrespro.ru", "phone": "+70918794155"}
0005433570906	BFB39F	4649 283181	NATALYA VLASOVA	{"email": "natalyavlasova_1965@postgrespro.ru", "phone": "+70415287849"}
0005433570907	BFB39F	1044 909813	EVGENIYA FILATOVA	{"phone": "+70247089444"}
0005433570908	459C65	2086 002163	LEONID DENISOV	{"email": "l_denisov-1971@postgrespro.ru", "phone": "+70715298298"}
0005433570909	4FE3C6	8390 785666	OLGA NOVIKOVA	{"phone": "+70423537853"}
0005433570910	6253BA	2410 843345	EVDOKIYA KUZNECOVA	{"email": "kuznecova_e-011977@postgrespro.ru", "phone": "+70187805914"}
0005433570911	962335	4045 049352	LYUDMILA GRISHINA	{"email": "lgrishina-1970@postgrespro.ru", "phone": "+70580507449"}
0005433570912	D8B579	0409 549857	GENNADIY SAVELEV	{"email": "gennadiy-savelev_1964@postgrespro.ru", "phone": "+70684643893"}
0005433570913	0BDAB6	8268 772707	SERGEY KOZLOV	{"email": "kozlovs1964@postgrespro.ru", "phone": "+70902257517"}
0005433570914	0BDAB6	5307 017403	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov_07081967@postgrespro.ru", "phone": "+70975418379"}
0005433570915	0BDAB6	8526 808435	LYUDMILA PAVLOVA	{"email": "lyudmila_pavlova-1963@postgrespro.ru", "phone": "+70678682582"}
0005433570916	89CF5E	0052 306482	OLGA VOROBEVA	{"email": "ovorobeva011967@postgrespro.ru", "phone": "+70265421116"}
0005433570917	89CF5E	9262 607139	ARTEM SCHERBAKOV	{"phone": "+70759265062"}
0005433570918	386E17	9884 311067	DMITRIY FEDOROV	{"email": "dmitriyfedorov_051979@postgrespro.ru", "phone": "+70139553503"}
0005433570919	3C05D0	3999 235280	ARTEM POPOV	{"email": "popov_artem1958@postgrespro.ru", "phone": "+70330712317"}
0005433570920	3C05D0	3116 425705	YURIY KAZAKOV	{"email": "kazakov.yuriy-1981@postgrespro.ru", "phone": "+70436221439"}
0005433570921	3C05D0	4832 748690	ALEKSANDRA RODIONOVA	{"email": "rodionovaaleksandra.121964@postgrespro.ru", "phone": "+70436599592"}
0005433570922	4E6EE6	7527 013100	MARIYA AFANASEVA	{"email": "mafanaseva_031968@postgrespro.ru", "phone": "+70079059814"}
0005433570923	AB5371	0089 558791	TALGAT TIKHONOV	{"phone": "+70074376780"}
0005433570924	613A41	9915 610295	GALINA ANISIMOVA	{"email": "anisimova_galina-011969@postgrespro.ru", "phone": "+70158668942"}
0005433570925	D1F455	4557 969493	TATYANA KISELEVA	{"phone": "+70145882613"}
0005433570926	9E5648	6356 399087	NATALYA SOKOLOVA	{"email": "n.sokolova121974@postgrespro.ru", "phone": "+70219405454"}
0005433570927	9E5648	7458 781559	VASILIY BONDARENKO	{"email": "vbondarenko1973@postgrespro.ru", "phone": "+70556706318"}
0005433570928	8EE874	1273 177515	SERGEY FOMIN	{"email": "sergey_fomin.17061968@postgrespro.ru", "phone": "+70540472108"}
0005433570929	752883	9660 556622	BULAT MAKSIMOV	{"email": "maksimov.b.1959@postgrespro.ru", "phone": "+70815673869"}
0005433570930	2AD774	4463 924756	DANIIL DMITRIEV	{"email": "daniil.dmitriev04081976@postgrespro.ru", "phone": "+70796450466"}
0005433570931	2AD774	4407 978769	DIANA MAKAROVA	{"phone": "+70620468071"}
0005433570932	2747A8	5195 371042	LYUBOV KAZAKOVA	{"email": "kazakova_l-12021975@postgrespro.ru", "phone": "+70979581283"}
0005433570933	281DAC	1796 713512	STEPAN ZHUKOV	{"email": "zhukov_s_1971@postgrespro.ru", "phone": "+70658418716"}
0005433570934	281DAC	3369 675789	ALEKSANDR IVANOV	{"phone": "+70925091545"}
0005433570935	1BF950	7144 492019	SERGEY BORISOV	{"email": "sergey_borisov.22021965@postgrespro.ru", "phone": "+70384650019"}
0005433570936	B5ACC9	0358 816892	EKATERINA LOGINOVA	{"phone": "+70850682498"}
0005433570937	A0712E	3573 426956	OKSANA MIRONOVA	{"phone": "+70769017154"}
0005433570938	973F6D	1767 186653	ALEKSANDR MOROZOV	{"email": "morozov-a_071975@postgrespro.ru", "phone": "+70457680484"}
0005433570939	973F6D	0431 248554	LYUDMILA BORISOVA	{"phone": "+70831290702"}
0005433570940	16712A	5859 338371	ELENA MAKSIMOVA	{"email": "elenamaksimova-121977@postgrespro.ru", "phone": "+70557159304"}
0005433570941	67B126	4552 783046	NATALYA SMIRNOVA	{"email": "smirnovanatalya-29011972@postgrespro.ru", "phone": "+70683036657"}
0005433570942	C711A4	3485 915277	DMITRIY FROLOV	{"phone": "+70321951452"}
0005433570943	C7E06E	7448 702108	NADEZHDA SERGEEVA	{"email": "n.sergeeva27041989@postgrespro.ru", "phone": "+70297888187"}
0005433570944	C7E06E	0543 540416	VLADIMIR KULIKOV	{"email": "vladimirkulikov-27011979@postgrespro.ru", "phone": "+70651171183"}
0005433570945	E0B277	2527 388228	VLADIMIR BELOV	{"email": "vbelov-1974@postgrespro.ru", "phone": "+70641041282"}
0005433570946	9146BD	3601 320096	PETR VOROBEV	{"phone": "+70268066159"}
0005433570947	314676	0812 985797	SOFIYA LOGINOVA	{"email": "loginova.s-011958@postgrespro.ru", "phone": "+70005439137"}
0005433570948	FD014A	8625 691567	MIKHAIL DAVYDOV	{"phone": "+70748147789"}
0005433570949	58DA17	3380 185132	PAVEL FILIPPOV	{"email": "filippovp18111965@postgrespro.ru", "phone": "+70643272218"}
0005433570950	58DA17	6143 513253	YULIYA VASILEVA	{"email": "vasileva-yuliya.20021978@postgrespro.ru", "phone": "+70697629465"}
0005433570951	58DA17	1523 045085	NATALYA EGOROVA	{"email": "n-egorova.1985@postgrespro.ru", "phone": "+70704174926"}
0005433570952	E97E9F	4203 779882	YULIYA SERGEEVA	{"phone": "+70160684900"}
0005433570953	E97E9F	8897 683068	NATALYA SAVELEVA	{"phone": "+70319740835"}
0005433570954	E97E9F	8041 907128	OLGA KRASNOVA	{"email": "olga-krasnova-111961@postgrespro.ru", "phone": "+70774281762"}
0005433570955	A1B9C4	4240 084171	NINA POTAPOVA	{"email": "potapova.nina-121973@postgrespro.ru", "phone": "+70117984992"}
0005433570956	5D0F84	8626 710814	ALEKSEY ANDREEV	{"phone": "+70676414327"}
0005433570957	549A28	6320 337578	SERGEY ROMANOV	{"email": "romanovs-051977@postgrespro.ru", "phone": "+70002280942"}
0005433570958	4925E1	1778 304151	KONSTANTIN ALEKSEEV	{"email": "alekseev-k.011972@postgrespro.ru", "phone": "+70448215822"}
0005433570959	4925E1	5359 831084	SERGEY BARANOV	{"email": "baranov_sergey08031959@postgrespro.ru", "phone": "+70356010835"}
0005433570960	06EF66	1433 852234	VLADIMIR BONDARENKO	{"email": "bondarenko_vladimir-30041968@postgrespro.ru", "phone": "+70262984354"}
0005433570961	A6563A	4391 766079	ZINAIDA GUSEVA	{"email": "guseva_z.1977@postgrespro.ru", "phone": "+70331607614"}
0005433570962	3D0F82	8599 520360	ELIZAVETA EFREMOVA	{"email": "elizaveta_efremova_10111968@postgrespro.ru", "phone": "+70573189936"}
0005433570963	20BF30	8015 172380	OLGA MIKHAYLOVA	{"email": "mikhaylova.o.071976@postgrespro.ru", "phone": "+70731730086"}
0005433570964	D32E7C	2045 813710	VYACHESLAV PETROV	{"email": "petrov.vyacheslav1960@postgrespro.ru", "phone": "+70958787119"}
0005433570965	FC1488	8522 033911	KIRILL SMIRNOV	{"email": "smirnov-k1988@postgrespro.ru", "phone": "+70238712617"}
0005433570966	3FFE73	3907 899435	VLADIMIR ROMANOV	{"email": "vladimirromanov_10061964@postgrespro.ru", "phone": "+70500077237"}
0005433570967	6FE442	3404 838923	ILYA KRASNOV	{"phone": "+70790518327"}
0005433570968	B0BCC2	8281 188318	YURIY FEDOTOV	{"email": "fedotovyuriy-101973@postgrespro.ru", "phone": "+70610850427"}
0005433570969	B0BCC2	6583 808347	DARYA FILIPPOVA	{"email": "darya_filippova.1969@postgrespro.ru", "phone": "+70501813106"}
0005433570970	D41ABB	9138 829845	KSENIYA FROLOVA	{"phone": "+70240083857"}
0005433570971	D41ABB	0432 498092	NADEZHDA KOZLOVA	{"phone": "+70038657295"}
0005433570972	7D6DCA	4201 372852	RAISA VASILEVA	{"phone": "+70320166623"}
0005433570973	7D6DCA	3498 561098	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov_20081964@postgrespro.ru", "phone": "+70718965966"}
0005433570974	4E014E	9193 222346	SOFIYA KUZMINA	{"email": "sofiyakuzmina-11061972@postgrespro.ru", "phone": "+70352367247"}
0005433570975	4E014E	2154 903875	ELIZAVETA GAVRILOVA	{"email": "elizaveta.gavrilova1964@postgrespro.ru", "phone": "+70558878337"}
0005433570976	4E014E	4234 150136	RUSTEM FOMIN	{"phone": "+70233666338"}
0005433570977	F8288F	5012 024142	ELENA KOLESNIKOVA	{"email": "kolesnikova-elena031973@postgrespro.ru", "phone": "+70993816046"}
0005433570978	F8288F	1988 581776	ANAIT OVCHINNIKOVA	{"email": "ovchinnikovaa1979@postgrespro.ru", "phone": "+70068119019"}
0005433570979	F8288F	0946 715228	ROZALIYA KUZMINA	{"email": "kuzmina_rozaliya.121970@postgrespro.ru", "phone": "+70219999825"}
0005433570980	14ABDE	7888 482950	ALINA IVANOVA	{"email": "ivanova_a_061980@postgrespro.ru", "phone": "+70282041558"}
0005433570981	C4DAB6	5897 278983	GALINA SOROKINA	{"email": "galina.sorokina_1976@postgrespro.ru", "phone": "+70188239528"}
0005433570982	8E0889	6396 756508	SERGEY DENISOV	{"email": "denisov.sergey.071984@postgrespro.ru", "phone": "+70961405361"}
0005433570983	B1B484	0190 928886	NIKOLAY SAVELEV	{"email": "nsavelev.1965@postgrespro.ru", "phone": "+70338252714"}
0005433570984	B1B484	2749 134750	GALIYA KUDRYASHOVA	{"email": "kudryashova_galiya-1973@postgrespro.ru", "phone": "+70490023817"}
0005433570985	0E46EF	0260 383797	PELAGEYA BARANOVA	{"email": "pelageya_baranova_06031969@postgrespro.ru", "phone": "+70363853093"}
0005433570986	528F84	2420 262081	NIKOLAY VOROBEV	{"phone": "+70981705548"}
0005433570987	528F84	4709 311581	MIKHAIL YAKOVLEV	{"phone": "+70116196288"}
0005433570988	528F84	6433 833551	LIDIYA ERMAKOVA	{"phone": "+70628850069"}
0005433570989	772084	3160 147516	YURIY KULIKOV	{"email": "ykulikov_1984@postgrespro.ru", "phone": "+70987946694"}
0005433570990	772084	3667 926385	SVETLANA LAZAREVA	{"phone": "+70450824804"}
0005433577848	3951DB	5519 879266	ELENA SCHERBAKOVA	{"phone": "+70366017836"}
0005433577561	EFED42	7501 168341	ILYA VOLKOV	{"email": "volkov.ilya_1964@postgrespro.ru", "phone": "+70130449064"}
0005433577562	979B56	4736 790606	ELEONORA DMITRIEVA	{"email": "e-dmitrieva071972@postgrespro.ru", "phone": "+70734391532"}
0005433577563	1DEBDF	5752 926248	NATALYA BELOVA	{"phone": "+70179389810"}
0005433577564	F50A3F	3541 505608	SOFYA MIKHAYLOVA	{"phone": "+70147271409"}
0005433577565	59C9C0	7105 098523	VERA KALININA	{"email": "kalinina-v_24081971@postgrespro.ru", "phone": "+70763535674"}
0005433577566	59C9C0	0544 041770	OLGA PETROVA	{"email": "petrovao17031979@postgrespro.ru", "phone": "+70315042694"}
0005433577567	BDA76E	5828 818707	IGOR ALEKSEEV	{"email": "i-alekseev041973@postgrespro.ru", "phone": "+70833209814"}
0005433577568	1AB04B	7172 155393	KSENIYA LEBEDEVA	{"email": "kseniya_lebedeva-1979@postgrespro.ru", "phone": "+70104960509"}
0005433577569	1AB04B	8734 470754	EVA SIDOROVA	{"email": "eva-sidorova_1985@postgrespro.ru", "phone": "+70888598797"}
0005433577570	1AB04B	6841 579137	SERGEY FOMIN	{"email": "fominsergey_101968@postgrespro.ru", "phone": "+70869283798"}
0005433577571	7E32C8	0199 407457	ROMAN NOVIKOV	{"email": "novikov-r_081984@postgrespro.ru", "phone": "+70720613634"}
0005433577572	8066F3	9593 178280	OLGA KONOVALOVA	{"email": "o-konovalova.1973@postgrespro.ru", "phone": "+70095161991"}
0005433577573	8066F3	4079 522852	ALEKSANDR TIKHONOV	{"phone": "+70507232014"}
0005433577574	C20A13	4294 627420	EKATERINA ABRAMOVA	{"phone": "+70118601552"}
0005433577575	C20A13	7752 615316	ANDREY STEPANOV	{"email": "stepanov-andrey111975@postgrespro.ru", "phone": "+70458775751"}
0005433577576	C20A13	6224 281830	TATYANA FILIPPOVA	{"phone": "+70009108528"}
0005433577577	0A5A3A	3860 004012	YULIYA KONDRATEVA	{"email": "kondrateva.y-051972@postgrespro.ru", "phone": "+70079947091"}
0005433577578	0A5A3A	6970 775429	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.g_031970@postgrespro.ru", "phone": "+70404796835"}
0005433577579	B2C2AE	1122 859506	TATYANA POLYAKOVA	{"email": "tatyana_polyakova_071969@postgrespro.ru", "phone": "+70470519968"}
0005433577580	1EA65F	5409 058221	GALINA ARKHIPOVA	{"phone": "+70360384280"}
0005433577641	C96899	4097 155415	EKATERINA VASILEVA	{"phone": "+70152924382"}
0005433577581	1EA65F	0216 830279	NIKOLAY SOLOVEV	{"email": "solovev_nikolay-091972@postgrespro.ru", "phone": "+70711049594"}
0005433577582	2D969C	8695 284430	ALBERT VOROBEV	{"email": "avorobev10081973@postgrespro.ru", "phone": "+70223275962"}
0005433577583	8DFA9A	0707 166489	TATYANA IVANOVA	{"phone": "+70146506907"}
0005433577584	8DFA9A	0160 842899	TAISIYA KISELEVA	{"phone": "+70054205703"}
0005433577585	943266	1758 223936	VADIM TIKHONOV	{"phone": "+70470326154"}
0005433577586	E56C67	9971 731280	VALENTINA NOVIKOVA	{"phone": "+70678412966"}
0005433577587	E56C67	4253 166512	VIKTOR DMITRIEV	{"phone": "+70999877711"}
0005433577588	2C8A15	4344 277780	DARYA LEBEDEVA	{"email": "darya.lebedeva1969@postgrespro.ru", "phone": "+70502823801"}
0005433577589	2C8A15	7275 145847	ARTEM BELOV	{"phone": "+70509671312"}
0005433577590	A4A6FD	4406 068916	LYUDMILA GERASIMOVA	{"email": "gerasimovalyudmila_1972@postgrespro.ru", "phone": "+70677256274"}
0005433577591	76BE65	8058 514896	NATALYA KOROLEVA	{"phone": "+70587677108"}
0005433577592	76BE65	0465 669360	NIKOLAY NIKITIN	{"phone": "+70603845766"}
0005433577593	6D5371	4868 043167	VLADIMIR RODIONOV	{"email": "vladimir_rodionov18071973@postgrespro.ru", "phone": "+70256998576"}
0005433577594	1D8380	8954 680846	DENIS VOROBEV	{"email": "d-vorobev_111977@postgrespro.ru", "phone": "+70071830493"}
0005433577595	52138A	5544 976884	NATALYA TARASOVA	{"email": "tarasovanatalya_18061962@postgrespro.ru", "phone": "+70912908371"}
0005433577596	981324	4341 227626	MARINA SCHERBAKOVA	{"email": "marina-scherbakova-1972@postgrespro.ru", "phone": "+70333989329"}
0005433577597	C91B36	3473 826906	ELENA KISELEVA	{"email": "elena-kiseleva.1974@postgrespro.ru", "phone": "+70464647628"}
0005433577598	B90BF6	8175 127686	DENIS MIKHAYLOV	{"email": "mikhaylov.denis111975@postgrespro.ru", "phone": "+70046950225"}
0005433577599	D2914C	2453 340972	VADIM KOZLOV	{"email": "vadim_kozlov_1970@postgrespro.ru", "phone": "+70995950370"}
0005433577600	BA45DD	0595 357557	VLADISLAV MIRONOV	{"email": "mironov.v-1971@postgrespro.ru", "phone": "+70532169409"}
0005433577601	BA45DD	2339 050124	ARINA FEDOROVA	{"phone": "+70800664508"}
0005433577602	BA45DD	3232 580234	SERGEY AFANASEV	{"phone": "+70633710063"}
0005433577603	A459B2	1605 381086	VLADIMIR CHERNOV	{"email": "vladimirchernov-27031964@postgrespro.ru", "phone": "+70107195783"}
0005433577604	67EB7C	3190 315280	NIKOLAY SAVELEV	{"email": "savelev_n.061963@postgrespro.ru", "phone": "+70373135116"}
0005433577605	5664A1	0164 284220	SERGEY MAKSIMOV	{"email": "maksimovsergey.1965@postgrespro.ru", "phone": "+70129340951"}
0005433577606	5664A1	4711 593099	EVELINA GRISHINA	{"phone": "+70273969953"}
0005433577607	E35E3E	5430 829340	VLADISLAV IVANOV	{"phone": "+70182465660"}
0005433577608	E35E3E	5237 724341	OLGA OSIPOVA	{"email": "osipova-o_1979@postgrespro.ru", "phone": "+70227731429"}
0005433577609	E35E3E	4937 406341	SERGEY KRASNOV	{"phone": "+70158460600"}
0005433577610	CC4983	8268 233563	TAMARA ANTONOVA	{"phone": "+70085133949"}
0005433577611	8B4CAF	0642 103978	OLGA NESTEROVA	{"email": "nesterova_olga-05051960@postgrespro.ru", "phone": "+70973682253"}
0005433577612	8B4CAF	4575 141740	VLADIMIR IVANOV	{"phone": "+70910882706"}
0005433577613	33B12D	9187 349545	VLADIMIR BELOV	{"phone": "+70220840959"}
0005433577614	C3EBF3	9885 932032	MARIYA ZAYCEVA	{"email": "zayceva-m_061980@postgrespro.ru", "phone": "+70255468941"}
0005433577615	C8C011	7231 198079	LEV KUZNECOV	{"phone": "+70739139935"}
0005433577616	258C84	3830 246066	SVETLANA DANILOVA	{"email": "danilova-s1972@postgrespro.ru", "phone": "+70819934911"}
0005433577617	48A8DC	0192 766332	EVGENIY TIMOFEEV	{"email": "timofeev-evgeniy12111971@postgrespro.ru", "phone": "+70251998260"}
0005433577618	E986A9	8441 778850	PRASKOVYA SOKOLOVA	{"email": "sokolovap011964@postgrespro.ru", "phone": "+70194193542"}
0005433577619	F2BBC1	6884 813373	ELENA POPOVA	{"email": "popova-e.021974@postgrespro.ru", "phone": "+70579019969"}
0005433577620	F2BBC1	1677 478543	OKSANA SMIRNOVA	{"email": "smirnova_o1962@postgrespro.ru", "phone": "+70634395273"}
0005433577621	B70830	5242 877227	LYUBOV NOVIKOVA	{"phone": "+70189277468"}
0005433577622	0CCAEC	6750 995271	ALEKSANDR IVANOV	{"email": "a.ivanov101962@postgrespro.ru", "phone": "+70959635170"}
0005433577623	846DA0	7753 799040	ALEKSANDR TIMOFEEV	{"email": "atimofeev1961@postgrespro.ru", "phone": "+70539576153"}
0005433577624	84BEC0	2007 572223	NIKOLAY VOROBEV	{"email": "vorobev_nikolay-1983@postgrespro.ru", "phone": "+70896404131"}
0005433577625	FCAFC5	8508 542081	VYACHESLAV PETROV	{"email": "vyacheslavpetrov-071974@postgrespro.ru", "phone": "+70768374801"}
0005433577626	FBBBFB	6933 607077	NADEZHDA RYABOVA	{"phone": "+70403207959"}
0005433577627	BFA185	9670 206611	ANDREY SCHERBAKOV	{"email": "scherbakov-andrey-121968@postgrespro.ru", "phone": "+70479678658"}
0005433577628	7AD6D0	6049 382614	YURIY GORBUNOV	{"email": "gorbunov-yuriy_101959@postgrespro.ru", "phone": "+70688920867"}
0005433577629	87207F	0423 657203	ANNA MALYSHEVA	{"phone": "+70543962025"}
0005433577630	A4C4C7	6359 878534	ARSEN KOZLOV	{"email": "kozlov.arsen_20071975@postgrespro.ru", "phone": "+70243296199"}
0005433577631	A4C4C7	8219 341148	TATYANA VLASOVA	{"phone": "+70272419766"}
0005433577632	A4C4C7	9542 625463	MARINA KUZNECOVA	{"phone": "+70853029597"}
0005433577633	B834FC	7065 941913	YANA NESTEROVA	{"phone": "+70998067515"}
0005433577634	B05F73	7527 602823	SALAVAT ANTONOV	{"phone": "+70818383575"}
0005433577635	40DB8A	3157 785771	ALEKSEY TIMOFEEV	{"email": "aleksey_timofeev_091983@postgrespro.ru", "phone": "+70522301032"}
0005433577636	852334	9820 954475	EVGENIYA IVANOVA	{"email": "ivanovaevgeniya19101973@postgrespro.ru", "phone": "+70547632859"}
0005433577637	6FAF57	4052 473053	ALEKSANDRA MAKSIMOVA	{"phone": "+70826836959"}
0005433577638	64C971	9088 687174	FANIYA BELYAEVA	{"email": "belyaeva-faniya.1976@postgrespro.ru", "phone": "+70975921333"}
0005433577639	64C971	9900 356879	NATALYA KOLESNIKOVA	{"phone": "+70672194280"}
0005433577640	046D73	5093 211950	VIKTOR OSIPOV	{"phone": "+70187749474"}
0005433577642	D91BE4	2853 477983	ALEKSANDRA ARKHIPOVA	{"email": "arkhipova-a011970@postgrespro.ru", "phone": "+70489390855"}
0005433577643	462C86	2042 411127	NINA KOMAROVA	{"email": "nina_komarova.30091972@postgrespro.ru", "phone": "+70020685489"}
0005433577644	462C86	5594 356544	ANNA NOVIKOVA	{"phone": "+70070182060"}
0005433577645	781511	6809 141323	ANASTASIYA MAKAROVA	{"phone": "+70903751304"}
0005433577646	BC2738	1469 357284	ALEKSANDR ROMANOV	{"email": "romanov.a-07041971@postgrespro.ru", "phone": "+70489809529"}
0005433577647	BC2738	5673 044018	KAPITALINA GERASIMOVA	{"email": "gerasimova.kapitalina-041960@postgrespro.ru", "phone": "+70608636724"}
0005433577648	1DC9BC	7007 986420	ANASTASIYA KUZMINA	{"email": "anastasiya_kuzmina19021968@postgrespro.ru", "phone": "+70839025209"}
0005433577649	1DC9BC	3240 539224	RASHID BELOV	{"email": "belov.rashid_091982@postgrespro.ru", "phone": "+70976313951"}
0005433577650	1F3339	0678 358660	ALEKSANDR ISAEV	{"email": "aleksandr_isaev-121978@postgrespro.ru", "phone": "+70658056236"}
0005433577651	1F3339	7196 773113	GLEB BARANOV	{"phone": "+70440163775"}
0005433577652	C8A711	3809 596851	SALAVAT FROLOV	{"phone": "+70657248021"}
0005433577653	EAD09C	1468 934830	GALINA ALEKSEEVA	{"phone": "+70289416552"}
0005433577654	A0D2E8	3689 962642	IRINA KOROLEVA	{"phone": "+70241213685"}
0005433577655	ACACE5	7227 789874	ELENA FILATOVA	{"email": "elena_filatova_031960@postgrespro.ru", "phone": "+70092784928"}
0005433577656	4890E9	8691 215063	NATALYA NOVIKOVA	{"phone": "+70091706104"}
0005433577657	4890E9	2761 057242	EVGENIYA KONOVALOVA	{"email": "konovalovaevgeniya_111984@postgrespro.ru", "phone": "+70935636345"}
0005433577658	4890E9	6700 507924	LIDIYA BARANOVA	{"email": "baranovalidiya-27021978@postgrespro.ru", "phone": "+70088240197"}
0005433577659	7005EE	7504 580934	SERGEY FOMIN	{"phone": "+70307475997"}
0005433577660	7005EE	3330 691094	SERGEY SIDOROV	{"email": "sergey-sidorov-08051977@postgrespro.ru", "phone": "+70346042442"}
0005433577661	6DC05F	6605 630057	ILYA BORISOV	{"email": "borisovi.031969@postgrespro.ru", "phone": "+70705493027"}
0005433577662	7D222F	3140 140948	EKATERINA BELOVA	{"phone": "+70390307848"}
0005433577663	E4A862	2717 053910	YURIY VOLKOV	{"email": "volkov-y-18021979@postgrespro.ru", "phone": "+70391905803"}
0005433577664	9C9E6E	0168 866291	ALEKSANDR ISAEV	{"phone": "+70380889035"}
0005433577665	ED98C1	9312 581446	SERGEY OSIPOV	{"email": "osipov-s-24051974@postgrespro.ru", "phone": "+70854669918"}
0005433577666	9838CD	0033 169942	ALEKSANDR POPOV	{"email": "aleksandr_popov041963@postgrespro.ru", "phone": "+70153247561"}
0005433577667	D14E4E	6180 155693	NATALYA MIKHAYLOVA	{"phone": "+70014467241"}
0005433577668	0E14AB	8328 229496	ANDREY VASILEV	{"email": "vasilev-andrey-111966@postgrespro.ru", "phone": "+70240057995"}
0005433577669	CC08C7	5714 257351	SERGEY KOZLOV	{"phone": "+70619240635"}
0005433577670	CC08C7	8857 802201	YANA RYABOVA	{"phone": "+70571046837"}
0005433577671	7D08CA	0131 695568	YULIYA MOROZOVA	{"phone": "+70777256895"}
0005433577672	440083	0634 025068	VLADIMIR MOISEEV	{"email": "v_moiseev.1980@postgrespro.ru", "phone": "+70147391001"}
0005433577673	440083	3381 118780	ALEKSANDR MEDVEDEV	{"phone": "+70806137307"}
0005433577674	09C222	7719 112638	NURLAN IVANOV	{"phone": "+70068935784"}
0005433577675	168E2F	4080 261618	MARINA FEDOROVA	{"phone": "+70613833178"}
0005433577676	168E2F	9312 070005	ELENA NIKOLAEVA	{"email": "elenanikolaeva-051968@postgrespro.ru", "phone": "+70072507971"}
0005433577677	16D8F3	7786 799502	PETR NIKITIN	{"email": "p_nikitin_28061962@postgrespro.ru", "phone": "+70736664203"}
0005433577678	491EC0	4708 065403	EKATERINA KULIKOVA	{"phone": "+70734327218"}
0005433577679	491EC0	0191 777176	RINAT MAKAROV	{"email": "rmakarov_1970@postgrespro.ru", "phone": "+70177460252"}
0005433577680	1B8A9F	2818 844485	VALERIY KUZNECOV	{"email": "valeriy_kuznecov-15101975@postgrespro.ru", "phone": "+70350574318"}
0005433577681	DA0CCA	2215 012381	TATYANA OSIPOVA	{"email": "osipova-t-021976@postgrespro.ru", "phone": "+70991125687"}
0005433577682	611FB3	0929 711048	EVGENIYA NIKIFOROVA	{"phone": "+70425465747"}
0005433577683	355848	9645 752970	NIKOLAY NOVIKOV	{"email": "nnovikov01121979@postgrespro.ru", "phone": "+70628970260"}
0005433577684	B8DDA8	0027 323418	TAMARA FOMINA	{"phone": "+70846927720"}
0005433577685	641508	4266 404535	OLGA VOLKOVA	{"phone": "+70857953728"}
0005433577686	641508	4706 676678	NATALIYA NIKOLAEVA	{"phone": "+70911063276"}
0005433577687	C059F1	2077 057093	ALEKSANDR ISAEV	{"phone": "+70308025952"}
0005433577688	12791B	7827 267369	LILIYA KONOVALOVA	{"email": "liliya-konovalova.051971@postgrespro.ru", "phone": "+70845486397"}
0005433577689	5D044E	2271 598398	ZINAIDA MATVEEVA	{"email": "zinaida.matveeva.061971@postgrespro.ru", "phone": "+70421482884"}
0005433577690	10CA0C	4309 687996	ANASTASIYA KOLESNIKOVA	{"email": "anastasiyakolesnikova_1969@postgrespro.ru", "phone": "+70811915258"}
0005433577691	4784F9	5771 472083	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev.31101971@postgrespro.ru", "phone": "+70244269356"}
0005433577692	68864F	7473 513953	ARTEM SCHERBAKOV	{"email": "artem_scherbakov.08061987@postgrespro.ru", "phone": "+70176734546"}
0005433577693	68864F	9767 003838	MIKHAIL SOROKIN	{"email": "mikhailsorokin.091966@postgrespro.ru", "phone": "+70970389092"}
0005433577694	D79BAC	2374 861969	NATALIYA MELNIKOVA	{"phone": "+70113286858"}
0005433577695	D79BAC	9104 765894	EVGENIY STEPANOV	{"email": "stepanov_evgeniy.1968@postgrespro.ru", "phone": "+70215851556"}
0005433577696	9E0E6B	4344 450638	VLADIMIR ZHUKOV	{"phone": "+70399420216"}
0005433577697	649EEF	5693 406239	ALEKSANDRA TITOVA	{"phone": "+70759320652"}
0005433577698	649EEF	1237 404921	NIKITA ANDREEV	{"email": "andreev-nikita.1971@postgrespro.ru", "phone": "+70652871746"}
0005433577699	C1E470	7759 826936	ARTEM ALEKSEEV	{"phone": "+70396757138"}
0005433577700	C1E470	7181 037248	ILYAS SIDOROV	{"email": "sidorov-ilyas071970@postgrespro.ru", "phone": "+70309378181"}
0005433577701	47EACB	1199 432552	PELAGEYA SAVELEVA	{"phone": "+70607217234"}
0005433577702	C488AB	3090 511298	VASILIY KUDRYASHOV	{"phone": "+70577920185"}
0005433577703	C488AB	0930 614794	VIKTOR RODIONOV	{"email": "v-rodionov.30011977@postgrespro.ru", "phone": "+70966625170"}
0005433577704	C488AB	7237 398298	EVGENIYA KUZMINA	{"email": "evgeniya-kuzmina_1966@postgrespro.ru", "phone": "+70851057195"}
0005433577705	F8F492	5526 787182	ILYA PETROV	{"phone": "+70691614546"}
0005433577706	F8F492	1987 831441	VIKTORIYA POPOVA	{"email": "v.popova051971@postgrespro.ru", "phone": "+70642792920"}
0005433577707	F7BBF7	7780 123823	ALINA GUSEVA	{"phone": "+70538148650"}
0005433577708	F7BBF7	9048 779430	ALEKSANDR MOROZOV	{"email": "amorozov-041975@postgrespro.ru", "phone": "+70851413681"}
0005433577709	C58885	3245 270892	ANATOLIY SAVELEV	{"email": "savelev_a-1966@postgrespro.ru", "phone": "+70874364538"}
0005433577710	875695	7253 132779	ANASTASIYA DENISOVA	{"phone": "+70152119666"}
0005433577711	593056	4109 960200	GALINA BELOVA	{"email": "g.belova-1966@postgrespro.ru", "phone": "+70528084987"}
0005433577712	593056	0225 833430	VLADIMIR TARASOV	{"email": "tarasov.vladimir_021961@postgrespro.ru", "phone": "+70450327627"}
0005433577713	9B315D	0949 085581	GALINA VLASOVA	{"email": "vlasova-g.1968@postgrespro.ru", "phone": "+70671630117"}
0005433577714	DA0C99	7119 354867	KAMIL SMIRNOV	{"email": "k.smirnov-1968@postgrespro.ru", "phone": "+70334798271"}
0005433577715	DA0C99	1332 260131	ANDREY IVANOV	{"phone": "+70162360467"}
0005433577716	C323F6	9143 533682	LIDIYA IVANOVA	{"email": "lidiya.ivanova.04041961@postgrespro.ru", "phone": "+70583929395"}
0005433577717	1B144E	6329 226036	ANNA GERASIMOVA	{"phone": "+70349311361"}
0005433577718	CF4226	1394 139337	VLADIMIR STEPANOV	{"email": "stepanov-vladimir.13031969@postgrespro.ru", "phone": "+70059929932"}
0005433577719	CF4226	4126 486918	RUSHANIYA KUZNECOVA	{"email": "kuznecova.rushaniya.061978@postgrespro.ru", "phone": "+70342137845"}
0005433577720	CF4226	6802 242279	ELENA ROMANOVA	{"email": "elenaromanova.021968@postgrespro.ru", "phone": "+70109253452"}
0005433577721	55B181	0125 736243	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev-051956@postgrespro.ru", "phone": "+70014028422"}
0005433577722	55B181	7677 074093	MARINA VOLKOVA	{"phone": "+70704017002"}
0005433577723	9A31BF	5256 948692	OKSANA BELOVA	{"email": "o.belova.23101962@postgrespro.ru", "phone": "+70420428053"}
0005433577724	4C1096	5804 313287	YURIY PAVLOV	{"phone": "+70238696465"}
0005433577725	4C1096	3721 789576	VALENTINA GAVRILOVA	{"email": "valentina-gavrilova.091974@postgrespro.ru", "phone": "+70866794247"}
0005433577726	4C1096	6655 115046	OKSANA LAZAREVA	{"email": "lazareva_o.1969@postgrespro.ru", "phone": "+70307730697"}
0005433577727	FD2AF5	3156 686550	MIKHAIL FROLOV	{"phone": "+70313221713"}
0005433577728	FD2AF5	8687 579496	VASILIY SERGEEV	{"email": "vasiliy-sergeev.28031978@postgrespro.ru", "phone": "+70804628941"}
0005433577729	95DD5B	1189 404172	EKATERINA SEMENOVA	{"email": "semenova.ekaterina_081969@postgrespro.ru", "phone": "+70718261573"}
0005433577730	34C963	5975 026678	ROMAN FEDOROV	{"email": "r-fedorov-1970@postgrespro.ru", "phone": "+70433107377"}
0005433577731	80B72A	9161 318728	ANASTASIYA DMITRIEVA	{"phone": "+70148807227"}
0005433577732	CF59B5	2750 246737	SERGEY SMIRNOV	{"phone": "+70221286027"}
0005433577733	CF59B5	6685 947809	LARISA NESTEROVA	{"phone": "+70743181845"}
0005433577734	5C9CDE	6993 483897	VLADIMIR TARASOV	{"phone": "+70557052870"}
0005433577735	A9EF32	7358 390233	NADEZHDA MIRONOVA	{"email": "mironova-nadezhda091970@postgrespro.ru", "phone": "+70287156892"}
0005433577736	CC284E	9988 364878	TATYANA ANDREEVA	{"email": "andreeva-tatyana.27011968@postgrespro.ru", "phone": "+70692668932"}
0005433577737	BB07E5	9981 896922	DENIS GORBUNOV	{"email": "gorbunovd.05091972@postgrespro.ru", "phone": "+70165481785"}
0005433577738	096805	7924 457498	ANDREY ZAYCEV	{"email": "zayceva011974@postgrespro.ru", "phone": "+70452479063"}
0005433577739	096805	5211 038111	DMITRIY IVANOV	{"phone": "+70037678788"}
0005433577740	096805	6563 116356	KLAVDIYA MALYSHEVA	{"email": "malysheva.k_1974@postgrespro.ru", "phone": "+70412649878"}
0005433577741	D986EC	1449 542619	GENNADIY DENISOV	{"email": "g_denisov.121973@postgrespro.ru", "phone": "+70781488034"}
0005433577742	D986EC	4905 651412	NIKOLAY AFANASEV	{"email": "nikolayafanasev02011965@postgrespro.ru", "phone": "+70990925205"}
0005433577743	A46E3B	4263 208692	ALEKSEY GUSEV	{"email": "alekseygusev.30071960@postgrespro.ru", "phone": "+70064710247"}
0005433577744	445383	7878 871624	PAVEL VLASOV	{"email": "pavel-vlasov_081966@postgrespro.ru", "phone": "+70667802355"}
0005433577745	03765F	3323 642572	NATALYA FILATOVA	{"phone": "+70622409437"}
0005433577746	800A34	5971 592156	GALINA FILIPPOVA	{"email": "g.filippova1966@postgrespro.ru", "phone": "+70026888183"}
0005433577747	104255	6762 755531	DENIS MAKAROV	{"phone": "+70634119687"}
0005433577748	A7F751	4902 060295	ALEKSANDR MELNIKOV	{"phone": "+70373779843"}
0005433577749	7376A1	9450 499997	IRINA KISELEVA	{"email": "irinakiseleva-091979@postgrespro.ru", "phone": "+70249731897"}
0005433577750	56CB9A	5386 936583	VLADIMIR ISAEV	{"email": "v_isaev.08011982@postgrespro.ru", "phone": "+70552367556"}
0005433577751	B3B685	0572 168962	DMITRIY BARANOV	{"email": "baranov.dmitriy.1969@postgrespro.ru", "phone": "+70228565827"}
0005433577752	B3B685	8367 204430	OLGA SOKOLOVA	{"email": "sokolova-olga1958@postgrespro.ru", "phone": "+70664163397"}
0005433577753	BA2139	9872 017913	ALEKSEY VLASOV	{"email": "vlasov-a25011966@postgrespro.ru", "phone": "+70969599079"}
0005433577754	FEA044	1078 581399	NINA ROMANOVA	{"phone": "+70741173322"}
0005433577755	FEA044	0383 442963	VALENTINA YAKOVLEVA	{"phone": "+70566105539"}
0005433577756	7EF399	3315 310025	NATALIYA GORBUNOVA	{"phone": "+70434999330"}
0005433577757	D37525	8319 745330	VLADIMIR VOLKOV	{"phone": "+70635341902"}
0005433577758	8CB513	2881 888561	VLADIMIR VASILEV	{"phone": "+70548173468"}
0005433577759	8CB513	0896 203337	NIKOLAY NAZAROV	{"email": "nazarov_nikolay.031974@postgrespro.ru", "phone": "+70947546217"}
0005433577760	D83058	5686 027473	PAVEL EGOROV	{"phone": "+70182210339"}
0005433577761	E701D1	1206 476927	VALERIY NAUMOV	{"phone": "+70845147047"}
0005433577762	E701D1	5385 950459	NIKOLAY FEDOROV	{"phone": "+70615342721"}
0005433577763	E701D1	5445 834750	EVGENIYA AFANASEVA	{"phone": "+70263741193"}
0005433577764	86366C	1077 845238	ALEKSANDR MIKHAYLOV	{"phone": "+70728058422"}
0005433577765	95CA83	6002 859121	VLADISLAV SCHERBAKOV	{"phone": "+70327888026"}
0005433577766	95CA83	7133 641201	ARTEMIY FILIPPOV	{"email": "a_filippov_31081974@postgrespro.ru", "phone": "+70092903447"}
0005433577767	95CA83	4879 878678	TATYANA MATVEEVA	{"phone": "+70816966446"}
0005433577768	84E732	8858 341277	ALEFTINA KOZLOVA	{"phone": "+70053630835"}
0005433577769	2C8318	7511 580308	NINA NIKOLAEVA	{"email": "nnikolaeva031970@postgrespro.ru", "phone": "+70023838912"}
0005433577770	2C8318	2301 071563	ALEKSANDR MATVEEV	{"phone": "+70706791902"}
0005433577771	4F731F	3630 951950	ANZHELA FOMINA	{"phone": "+70568500646"}
0005433577772	E70B90	9350 105456	ELENA LUKYANOVA	{"email": "elenalukyanova_071967@postgrespro.ru", "phone": "+70507206187"}
0005433577773	767B26	3560 205846	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov.101975@postgrespro.ru", "phone": "+70115277805"}
0005433577774	8BDE3F	6480 854657	IVAN KUZNECOV	{"email": "ivan-kuznecov-1972@postgrespro.ru", "phone": "+70919241164"}
0005433577775	9C8211	4219 520403	VLADIMIR ANDREEV	{"phone": "+70743651288"}
0005433577776	F0AC39	9414 137673	YURIY FEDOTOV	{"email": "yuriy.fedotov_031969@postgrespro.ru", "phone": "+70214098200"}
0005433577777	D3E7B6	7687 441377	TATYANA KONDRATEVA	{"phone": "+70076793284"}
0005433577778	D3E7B6	2334 473944	EVGENIY MARTYNOV	{"email": "martynov_e_1971@postgrespro.ru", "phone": "+70065572289"}
0005433577779	4D2D8E	2508 603490	MARGARITA ANDREEVA	{"email": "margarita.andreeva-1977@postgrespro.ru", "phone": "+70326911726"}
0005433577780	4D2D8E	4236 596609	LYUCIYA VASILEVA	{"email": "vasileva_lyuciya_1972@postgrespro.ru", "phone": "+70360705469"}
0005433577781	4D2D8E	7056 240692	MAYYA KOMAROVA	{"email": "m_komarova011974@postgrespro.ru", "phone": "+70983570181"}
0005433577782	0121F0	1746 176700	DANIIL RODIONOV	{"phone": "+70754678484"}
0005433577783	0121F0	2217 758886	NATALYA GAVRILOVA	{"email": "ngavrilova22021973@postgrespro.ru", "phone": "+70535040105"}
0005433577784	D822BB	0623 945463	YURIY IVANOV	{"email": "yuriyivanov28101968@postgrespro.ru", "phone": "+70052534148"}
0005433577785	B4E12A	3597 511905	ALEKSANDR VASILEV	{"email": "vasilev_a15051970@postgrespro.ru", "phone": "+70294607983"}
0005433577786	B4E12A	3825 008520	MIKHAIL ZHURAVLEV	{"phone": "+70945199501"}
0005433577787	B4E12A	5762 013334	LYUDMILA YAKOVLEVA	{"phone": "+70034569963"}
0005433577788	7C811A	5635 028482	VLADIMIR PAVLOV	{"email": "v.pavlov-27061970@postgrespro.ru", "phone": "+70066858255"}
0005433577789	D67EC2	3843 457143	MARIYA POPOVA	{"email": "popova_m03061976@postgrespro.ru", "phone": "+70886358980"}
0005433577790	7BB850	6791 946220	MARINA ROMANOVA	{"phone": "+70835852662"}
0005433577791	404AA3	1643 556401	ALLA SEMENOVA	{"phone": "+70195268558"}
0005433577792	4194DD	8440 464556	IVAN VOROBEV	{"email": "vorobev_ivan.061964@postgrespro.ru", "phone": "+70783614993"}
0005433577793	90F850	1008 602886	SERGEY KUDRYASHOV	{"email": "kudryashovs.121967@postgrespro.ru", "phone": "+70798687874"}
0005433577794	CDA502	2810 418936	TATYANA POPOVA	{"email": "popova.t_1963@postgrespro.ru", "phone": "+70577320159"}
0005433577795	CDA502	6546 116184	LIDIYA KOZLOVA	{"email": "lidiya-kozlova-061978@postgrespro.ru", "phone": "+70011119613"}
0005433577796	100548	0662 206544	IRINA ABRAMOVA	{"email": "abramova-irina_061977@postgrespro.ru", "phone": "+70922509463"}
0005433577797	100548	4127 848557	VALENTINA GERASIMOVA	{"email": "valentinagerasimova-14081979@postgrespro.ru", "phone": "+70197494997"}
0005433577798	791B7E	2426 547736	DMITRIY TIMOFEEV	{"phone": "+70876816023"}
0005433577799	18E214	9513 354070	GENNADIY SEMENOV	{"email": "g_semenov_1968@postgrespro.ru", "phone": "+70605239498"}
0005433577800	C42D78	3233 677264	NATALIYA EFIMOVA	{"email": "n_efimova.1975@postgrespro.ru", "phone": "+70128368526"}
0005433577801	C42D78	0412 871011	VALENTINA SOLOVEVA	{"email": "v_soloveva.041981@postgrespro.ru", "phone": "+70657002802"}
0005433577802	BDBA6D	1955 082815	IGOR KAZAKOV	{"phone": "+70754444522"}
0005433577803	BDBA6D	3711 455952	ALEKSANDR ILIN	{"phone": "+70586968624"}
0005433577804	0CD092	4693 278053	MIKHAIL EGOROV	{"phone": "+70966429544"}
0005433577805	0CD092	3762 424606	VLADISLAV ROMANOV	{"phone": "+70781674278"}
0005433577806	D6D083	3991 555244	NATALYA KUZNECOVA	{"email": "kuznecova-natalya.041976@postgrespro.ru", "phone": "+70091657842"}
0005433577807	C3DF7E	3558 263032	AYRAT MOISEEV	{"phone": "+70412230626"}
0005433577808	C3DF7E	8340 361988	IGOR CHERNOV	{"email": "chernov.igor_13031974@postgrespro.ru", "phone": "+70967745800"}
0005433577809	FFBB15	8931 580763	VARVARA EFIMOVA	{"email": "efimova-varvara_1965@postgrespro.ru", "phone": "+70880820321"}
0005433577810	FFBB15	4008 075497	LIDIYA NOVIKOVA	{"phone": "+70618802458"}
0005433577811	FFBB15	4372 431883	LIDIYA SIDOROVA	{"phone": "+70343870101"}
0005433577812	642228	5939 891383	VIKTOR GUSEV	{"phone": "+70597372537"}
0005433577813	69E4BE	8442 080219	RAFIS SEMENOV	{"phone": "+70464077642"}
0005433577814	5C9ABD	9388 693642	NIKOLAY KUZNECOV	{"phone": "+70159613584"}
0005433577815	1DCD89	2139 203433	NADEZHDA EGOROVA	{"email": "egorovan21121966@postgrespro.ru", "phone": "+70057003917"}
0005433577816	14293D	5890 151541	NIKITA POPOV	{"phone": "+70239245093"}
0005433577817	EAFEC1	2834 499343	ALEKSEY MOISEEV	{"email": "moiseev_a_19121985@postgrespro.ru", "phone": "+70334187312"}
0005433577818	EAFEC1	6137 699191	LYUDMILA TIKHONOVA	{"phone": "+70792927950"}
0005433577819	9AE970	5680 812221	DMITRIY VASILEV	{"email": "vasilev.dmitriy.01031970@postgrespro.ru", "phone": "+70763887897"}
0005433577820	280B32	9700 881421	DMITRIY KAZAKOV	{"phone": "+70043016817"}
0005433577821	C96423	2684 184525	DANILA DENISOV	{"email": "denisovd031967@postgrespro.ru", "phone": "+70973084932"}
0005433577822	310350	6616 881867	SVETLANA ZAKHAROVA	{"email": "szakharova05071971@postgrespro.ru", "phone": "+70128001623"}
0005433577823	310350	7364 960055	IRINA GORBUNOVA	{"email": "irina-gorbunova-051974@postgrespro.ru", "phone": "+70696498707"}
0005433577824	91CBB7	8291 615350	NADEZHDA ERMAKOVA	{"email": "ermakova_n.051969@postgrespro.ru", "phone": "+70955645401"}
0005433577825	258DD8	1047 123811	IVAN BELOV	{"email": "ivanbelov_111973@postgrespro.ru", "phone": "+70381239841"}
0005433577826	F1720C	8285 308390	VALENTINA LEBEDEVA	{"email": "valentinalebedeva_22121979@postgrespro.ru", "phone": "+70865822994"}
0005433577827	F1720C	5448 496627	VARVARA GORBUNOVA	{"phone": "+70411623809"}
0005433577828	A800A5	5989 754988	SERGEY FILIPPOV	{"email": "sfilippov11061968@postgrespro.ru", "phone": "+70456081826"}
0005433577829	9058E2	2076 749571	DMITRIY MATVEEV	{"phone": "+70462072137"}
0005433577830	E103F0	8459 125917	ELIZAVETA SERGEEVA	{"email": "sergeeva-e_1973@postgrespro.ru", "phone": "+70526654745"}
0005433577831	15B650	3370 485491	YURIY VOROBEV	{"email": "y_vorobev-1979@postgrespro.ru", "phone": "+70882445127"}
0005433577832	15B650	1865 362904	VLADIMIR SIDOROV	{"email": "v-sidorov-18081967@postgrespro.ru", "phone": "+70512770114"}
0005433577833	4902B7	1199 503692	PAVEL PETROV	{"phone": "+70161610553"}
0005433577834	4902B7	0808 147228	ILYAS ANDREEV	{"email": "andreev.i041966@postgrespro.ru", "phone": "+70283463406"}
0005433577835	D4661E	8311 837484	VLADIMIR ANTONOV	{"phone": "+70900857779"}
0005433577836	83B486	5225 766656	SERGEY SOROKIN	{"phone": "+70177955419"}
0005433577837	FCF9AF	8671 633360	MARINA BARANOVA	{"phone": "+70269387491"}
0005433577838	07EF83	2546 501375	NINA BOGDANOVA	{"phone": "+70673778295"}
0005433577839	96E3B0	8300 249883	POLINA KALININA	{"email": "pkalinina-1967@postgrespro.ru", "phone": "+70723214107"}
0005433577840	2CF02B	1210 760494	GENNADIY VOLKOV	{"email": "gvolkov.04121975@postgrespro.ru", "phone": "+70501080541"}
0005433577841	0A8002	6343 004614	YULIYA MATVEEVA	{"email": "y-matveeva_01041966@postgrespro.ru", "phone": "+70171176797"}
0005433577842	0A8002	5346 387397	VIKTOR YAKOVLEV	{"email": "viktor.yakovlev.1973@postgrespro.ru", "phone": "+70260060477"}
0005433577843	F2FFB7	7468 334045	ALEKSANDRA FEDOROVA	{"phone": "+70694439562"}
0005433577844	1C00D4	1353 130785	TATYANA POPOVA	{"phone": "+70577038424"}
0005433577845	1C00D4	4618 171090	YANA KOZLOVA	{"phone": "+70972091016"}
0005433577846	6C9335	0137 891948	ARTUR SERGEEV	{"phone": "+70147701379"}
0005433577847	3951DB	6980 218504	LYUDMILA IVANOVA	{"email": "lyudmilaivanova-08111969@postgrespro.ru", "phone": "+70081439309"}
0005433577849	3951DB	9226 707094	ALINA POPOVA	{"email": "a_popova1978@postgrespro.ru", "phone": "+70545978835"}
0005433577850	E04794	6294 952682	NIKOLAY MOROZOV	{"email": "n_morozov.01011969@postgrespro.ru", "phone": "+70707527266"}
0005433577851	E04794	5993 524071	ALEKSANDR PETROV	{"email": "aleksandr-petrov091980@postgrespro.ru", "phone": "+70358586872"}
0005433577852	682C0A	6067 010724	EVGENIY VASILEV	{"phone": "+70382265783"}
0005433577853	682C0A	4911 072162	ALEKSEY SHEVCHENKO	{"email": "ashevchenko-021982@postgrespro.ru", "phone": "+70317378783"}
0005433577854	458F52	9582 873528	ALEKSEY SEMENOV	{"phone": "+70206032279"}
0005433577855	11C021	5074 218347	ANASTASIYA ZHUKOVA	{"email": "zhukova_anastasiya-111977@postgrespro.ru", "phone": "+70531417897"}
0005433577856	11C021	8826 777052	NATALYA TARASOVA	{"email": "ntarasova_011979@postgrespro.ru", "phone": "+70981124356"}
0005433577857	E821FD	9846 881857	ELENA ZAKHAROVA	{"email": "e_zakharova-081974@postgrespro.ru", "phone": "+70374325574"}
0005433577858	FB49DB	2881 522328	SERGEY MAKAROV	{"email": "makarovsergey-13021969@postgrespro.ru", "phone": "+70413990437"}
0005433577859	FB49DB	1168 198583	LYUDMILA KULIKOVA	{"email": "kulikova_lyudmila_13011965@postgrespro.ru", "phone": "+70993403710"}
0005433577860	144166	9632 919928	STANISLAV SERGEEV	{"phone": "+70635066829"}
0005433577861	144166	6463 208374	ELENA NAZAROVA	{"phone": "+70002711555"}
0005433577862	4AC229	4057 006706	LYUDMILA FEDOROVA	{"email": "lyudmila.fedorova-041972@postgrespro.ru", "phone": "+70912557983"}
0005433577863	A80372	3352 831323	ELIZAVETA TIKHONOVA	{"phone": "+70301899796"}
0005433577864	A80372	3069 170119	NELLI ANDREEVA	{"phone": "+70534105136"}
0005433577865	EC9342	5706 386486	YULIYA ALEKSEEVA	{"email": "y.alekseeva_1962@postgrespro.ru", "phone": "+70841660886"}
0005433577866	5B9D8A	3646 824874	TATYANA MAKAROVA	{"phone": "+70415896399"}
0005433577867	426168	1026 685752	NADEZHDA NAZAROVA	{"email": "nazarovanadezhda041966@postgrespro.ru", "phone": "+70359936770"}
0005433577868	68C2E3	6750 014864	ALEKSANDR FEDOROV	{"email": "a-fedorov1985@postgrespro.ru", "phone": "+70796438913"}
0005433577869	68C2E3	4752 242564	SERGEY CHERNOV	{"phone": "+70132234436"}
0005433577870	B8E36F	1424 729740	LYUBOV NAUMOVA	{"phone": "+70111262852"}
0005433577871	C1C498	4676 944171	VALERIY FROLOV	{"phone": "+70896271152"}
0005433577872	0BCDEB	7525 581212	LYUDMILA PETROVA	{"phone": "+70624686355"}
0005433577873	059CD6	2222 071075	ANATOLIY DENISOV	{"phone": "+70663135064"}
0005433577874	752A82	8756 490583	VASILIY KUZNECOV	{"email": "kuznecov-vasiliy.121968@postgrespro.ru", "phone": "+70257336774"}
0005433577875	6D665B	3950 837490	GYUZEL ANISIMOVA	{"email": "anisimova_gyuzel.23121974@postgrespro.ru", "phone": "+70902684502"}
0005433577876	6D665B	6887 419809	SERGEY KUZNECOV	{"email": "sergeykuznecov021975@postgrespro.ru", "phone": "+70540973640"}
0005433577877	6DF959	7591 374817	SHAMIL SOKOLOV	{"phone": "+70979279787"}
0005433577878	9B560E	9480 456894	YULIYA ALEKSANDROVA	{"phone": "+70846120681"}
0005433577879	9B560E	1420 603153	ANDREY ANTONOV	{"email": "antonov_a_1972@postgrespro.ru", "phone": "+70143504555"}
0005433577880	173989	5038 545199	YURIY MAKSIMOV	{"phone": "+70278902564"}
0005433577881	173989	8473 906141	ALEKSEY VASILEV	{"phone": "+70346141614"}
0005433577882	3F9DA2	2091 517998	IVAN STEPANOV	{"phone": "+70294755939"}
0005433577883	1A33B0	5956 144151	VERA BORISOVA	{"email": "vera.borisova.101977@postgrespro.ru", "phone": "+70645780532"}
0005433577884	028735	8845 724789	NADEZHDA OSIPOVA	{"email": "n_osipova.12081962@postgrespro.ru", "phone": "+70079949087"}
0005433577885	028735	9060 729012	VALENTINA ANDREEVA	{"phone": "+70603406933"}
0005433577886	F5F718	8065 114418	IVAN NIKITIN	{"phone": "+70096631715"}
0005433577887	F5F718	8442 193477	ZINAIDA PETROVA	{"phone": "+70385256722"}
0005433577888	633A9B	3188 094340	MARIYA IVANOVA	{"email": "ivanova-m1976@postgrespro.ru", "phone": "+70182032845"}
0005433578001	FC4A24	0561 669620	VALENTINA STEPANOVA	{"phone": "+70464844659"}
0005433577889	449205	9070 199426	MARIYA FROLOVA	{"email": "m.frolova.19021986@postgrespro.ru", "phone": "+70108616991"}
0005433577890	E89F5D	5669 964484	ALEKSANDR MELNIKOV	{"phone": "+70033089875"}
0005433577891	9DF2DB	4934 684614	NATALYA PETROVA	{"email": "petrova-natalya_1976@postgrespro.ru", "phone": "+70968142651"}
0005433577892	9DF2DB	0772 130836	EKATERINA KOZLOVA	{"phone": "+70304928887"}
0005433577893	8FD9C0	2658 990603	RUSLAN ZHURAVLEV	{"email": "r_zhuravlev.1969@postgrespro.ru", "phone": "+70635910057"}
0005433577894	8FD9C0	3448 709492	DARYA TIKHONOVA	{"phone": "+70639541053"}
0005433577895	8FD9C0	3052 202942	GENNADIY SHEVCHENKO	{"email": "shevchenkog051978@postgrespro.ru", "phone": "+70417648477"}
0005433577896	5069FE	5765 650108	STANISLAV NOVIKOV	{"phone": "+70422295026"}
0005433577897	D40409	0099 798576	MARINA IVANOVA	{"phone": "+70874687130"}
0005433577898	8512AD	2500 802737	NINA KAZAKOVA	{"email": "nkazakova.111972@postgrespro.ru", "phone": "+70338903063"}
0005433577899	3563B9	2195 919868	MARIYA POPOVA	{"email": "mariya_popova.081972@postgrespro.ru", "phone": "+70485780928"}
0005433577900	3563B9	7280 461156	VIKTOR VASILEV	{"email": "vasilev-v.1978@postgrespro.ru", "phone": "+70218402365"}
0005433577901	18D091	9688 830093	BORIS DMITRIEV	{"phone": "+70615821985"}
0005433577902	4A8916	6564 680300	DARYA ISAEVA	{"email": "isaeva-darya-16061980@postgrespro.ru", "phone": "+70883170435"}
0005433577903	096E91	1214 971764	DMITRIY ILIN	{"email": "dmitriy-ilin071980@postgrespro.ru", "phone": "+70297275138"}
0005433577904	096E91	9315 393232	RAISA ALEKSEEVA	{"email": "alekseeva.raisa.011977@postgrespro.ru", "phone": "+70730840048"}
0005433577905	362FFD	0961 093161	ALEKSANDR MIRONOV	{"phone": "+70971919036"}
0005433577906	E86CF6	4412 059732	NATALIYA SOLOVEVA	{"email": "soloveva_nataliya_28031957@postgrespro.ru", "phone": "+70446189940"}
0005433577907	177FDF	8536 280748	VALENTINA KUZNECOVA	{"phone": "+70913953275"}
0005433577908	096F35	6276 151946	VIKTORIYA ORLOVA	{"phone": "+70069552515"}
0005433577909	096F35	1228 398057	LEONID ZAKHAROV	{"email": "zakharov-leonid_1971@postgrespro.ru", "phone": "+70648374351"}
0005433577910	9B65EC	1300 442105	ALEKSANDR KUZNECOV	{"phone": "+70144427572"}
0005433577911	9B65EC	2443 914432	ILYA KUZNECOV	{"phone": "+70259316713"}
0005433577912	4024F0	2900 020632	OLEG ABRAMOV	{"email": "olegabramov_1969@postgrespro.ru", "phone": "+70535515418"}
0005433577913	EC9CC5	5006 379423	ZOYA GERASIMOVA	{"email": "zoya_gerasimova-03081969@postgrespro.ru", "phone": "+70447608674"}
0005433577914	EC9CC5	1928 460339	MIKHAIL STEPANOV	{"email": "m.stepanov09031975@postgrespro.ru", "phone": "+70179906678"}
0005433577915	A5DF71	9254 981437	LARISA DENISOVA	{"email": "larisa-denisova081963@postgrespro.ru", "phone": "+70967302635"}
0005433577916	E9AF53	7830 867692	ANDREY ILIN	{"email": "andrey-ilin_051965@postgrespro.ru", "phone": "+70857591128"}
0005433577917	E9AF53	0084 970736	ELENA MEDVEDEVA	{"email": "elena_medvedeva14061972@postgrespro.ru", "phone": "+70048952798"}
0005433577918	3BF74C	7903 155090	OKSANA POPOVA	{"email": "o_popova_091956@postgrespro.ru", "phone": "+70030286728"}
0005433577919	A27B8B	3683 217637	ELENA KULIKOVA	{"email": "elenakulikova111975@postgrespro.ru", "phone": "+70348929123"}
0005433577920	A27B8B	4453 812207	SERGEY IVANOV	{"phone": "+70022935701"}
0005433577921	A27B8B	1122 235092	IRINA VOLKOVA	{"phone": "+70340484366"}
0005433577922	A27B8B	7093 545989	MARINA NAUMOVA	{"email": "marina.naumova.1980@postgrespro.ru", "phone": "+70965475934"}
0005433577923	389460	5871 832419	MIKHAIL KONOVALOV	{"phone": "+70377536361"}
0005433577924	C1A145	7086 174844	NINA TIKHONOVA	{"email": "tikhonova.n.24051966@postgrespro.ru", "phone": "+70868005333"}
0005433577925	8F348D	9958 245213	PAVEL ALEKSEEV	{"email": "alekseev.pavel.1966@postgrespro.ru", "phone": "+70988115970"}
0005433577926	4D3B52	6513 601073	DMITRIY CHERNOV	{"phone": "+70463117067"}
0005433577927	4D3B52	3281 384043	YURIY EGOROV	{"phone": "+70845336383"}
0005433577928	7DAE46	4453 838545	SERGEY FEDOROV	{"phone": "+70816141270"}
0005433577929	28F736	9466 502628	VERA FEDOROVA	{"phone": "+70857599124"}
0005433577930	14E707	3016 773970	SERGEY SEMENOV	{"email": "semenov_sergey.091985@postgrespro.ru", "phone": "+70447014910"}
0005433577931	A7F2B6	4455 082209	ELENA NAUMOVA	{"phone": "+70442644006"}
0005433577932	A7F2B6	9963 679261	ANDREY SHEVCHENKO	{"email": "a.shevchenko.091978@postgrespro.ru", "phone": "+70912150282"}
0005433577933	BE776D	8143 853829	ANDREY KRASNOV	{"phone": "+70437065038"}
0005433577934	D225FA	4121 594519	ANATOLIY TARASOV	{"phone": "+70976129996"}
0005433577935	BA141E	1659 490192	LYUDMILA NESTEROVA	{"phone": "+70052510819"}
0005433577936	BA141E	4242 455362	LYUDMILA CHERNOVA	{"phone": "+70853883452"}
0005433577937	36BD7A	8865 550380	VALENTIN GORBUNOV	{"email": "gorbunov.v121966@postgrespro.ru", "phone": "+70375208959"}
0005433577938	9BFB06	1456 210945	ELENA KOMAROVA	{"phone": "+70051876460"}
0005433577939	9BFB06	8414 258365	KRISTINA NAZAROVA	{"phone": "+70508658188"}
0005433577940	9BFB06	9894 124693	LYUDMILA TIKHONOVA	{"email": "l_tikhonova23021969@postgrespro.ru", "phone": "+70122040150"}
0005433577941	9BFB06	8605 588957	YURIY NIKITIN	{"phone": "+70613214217"}
0005433577942	EE0331	8615 876538	IRINA SERGEEVA	{"email": "irina.sergeeva.031987@postgrespro.ru", "phone": "+70887940998"}
0005433577943	EE0331	5255 795734	OLGA YUDINA	{"email": "yudina.olga18121968@postgrespro.ru", "phone": "+70196043715"}
0005433577944	FCC1AD	5402 528563	EVGENIY BORISOV	{"phone": "+70604112297"}
0005433577945	FC802C	3606 540633	EKATERINA ZHUKOVA	{"email": "zhukova_e-1983@postgrespro.ru", "phone": "+70447526557"}
0005433577946	232DB9	8571 147981	OKSANA EFIMOVA	{"email": "oksana-efimova-1985@postgrespro.ru", "phone": "+70331314688"}
0005433577947	232DB9	4682 978754	VALENTINA KUZMINA	{"phone": "+70612086831"}
0005433577948	BF2E1B	0952 199681	VERA GAVRILOVA	{"phone": "+70017211021"}
0005433577949	E06B84	6148 724039	VLADIMIR NOVIKOV	{"phone": "+70438654219"}
0005433577950	E06B84	6696 034431	ANNA ROMANOVA	{"phone": "+70280093086"}
0005433577951	6CADB0	6422 263114	STANISLAV MELNIKOV	{"email": "melnikov-stanislav29111965@postgrespro.ru", "phone": "+70730570578"}
0005433577952	6CADB0	2102 868514	ZOYA STEPANOVA	{"email": "stepanova_zoya.071970@postgrespro.ru", "phone": "+70171804137"}
0005433577953	DF5829	8348 072660	EVGENIY KOZLOV	{"email": "kozlove121971@postgrespro.ru", "phone": "+70432804846"}
0005433577954	E8D948	9775 700083	ALEKSANDR EGOROV	{"email": "egorov_aleksandr_18061969@postgrespro.ru", "phone": "+70481499614"}
0005433577955	E8D948	3642 821132	VIKTOR FEDOROV	{"email": "fedorov_viktor1965@postgrespro.ru", "phone": "+70335027168"}
0005433577956	925B43	2711 386074	SERGEY KAZAKOV	{"phone": "+70823195555"}
0005433577957	925B43	1925 524840	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova_anastasiya_1974@postgrespro.ru", "phone": "+70730869403"}
0005433577958	925B43	3272 840983	GALINA NIKITINA	{"email": "g.nikitina31051965@postgrespro.ru", "phone": "+70035176210"}
0005433577959	696A43	9359 433335	ILYA VASILEV	{"phone": "+70249338736"}
0005433577960	AB4924	9297 367470	IRINA KAZAKOVA	{"email": "kazakova.i_1980@postgrespro.ru", "phone": "+70991675641"}
0005433577961	AB4924	0075 557331	IVAN SERGEEV	{"email": "i.sergeev071973@postgrespro.ru", "phone": "+70963878789"}
0005433577962	B54E6B	1524 819056	VERA IVANOVA	{"phone": "+70882967648"}
0005433577963	A35F72	9689 209128	OKSANA KOROLEVA	{"phone": "+70309407360"}
0005433577964	C81326	5299 849637	EVGENIY ANDREEV	{"email": "evgeniy.andreev_031967@postgrespro.ru", "phone": "+70323942933"}
0005433577965	C81326	3681 151071	IRINA KUZNECOVA	{"email": "i_kuznecova.15101976@postgrespro.ru", "phone": "+70085972876"}
0005433577966	C81326	1566 096714	SERGEY SEMENOV	{"email": "s.semenov.17121968@postgrespro.ru", "phone": "+70562013620"}
0005433577967	94E372	6266 529207	NADEZHDA ERMAKOVA	{"phone": "+70165237379"}
0005433577968	94E372	1738 621483	DARYA KUZNECOVA	{"phone": "+70783804931"}
0005433577969	2A4C5E	3011 236276	EKATERINA KRASNOVA	{"phone": "+70143871948"}
0005433577970	2A4C5E	1442 029463	ALEKSEY FEDOROV	{"phone": "+70353279489"}
0005433577971	0EA050	5636 676311	LYUBOV KUZNECOVA	{"phone": "+70425220217"}
0005433577972	80FA6E	0249 288782	LEV FROLOV	{"email": "frolov_lev-29121959@postgrespro.ru", "phone": "+70981799010"}
0005433577973	09D86B	7920 826585	DMITRIY FROLOV	{"phone": "+70780282453"}
0005433577974	A903C2	0568 907888	VYACHESLAV KUZNECOV	{"email": "v.kuznecov_1968@postgrespro.ru", "phone": "+70350496414"}
0005433577975	A903C2	0003 797170	LYUDMILA GUSEVA	{"email": "lyudmila-guseva.24031981@postgrespro.ru", "phone": "+70800377173"}
0005433577976	C5EEA2	5104 639657	ALEKSANDR BELOV	{"phone": "+70583267851"}
0005433577977	E0B5C6	1948 459535	OLGA RYABOVA	{"phone": "+70315458755"}
0005433577978	E9886F	6456 498483	MARIYA ARKHIPOVA	{"email": "m_arkhipova-30101972@postgrespro.ru", "phone": "+70802253116"}
0005433577979	4DBEE8	2681 231872	VLADIMIR KUZNECOV	{"email": "v.kuznecov19031964@postgrespro.ru", "phone": "+70103854222"}
0005433577980	C54949	9187 982040	KIRA ROMANOVA	{"phone": "+70338325945"}
0005433577981	C54949	0416 308460	ANATOLIY NIKOLAEV	{"phone": "+70446681368"}
0005433577982	9E2A2F	1883 885399	ARTEM STEPANOV	{"email": "stepanova_07071975@postgrespro.ru", "phone": "+70095656204"}
0005433577983	9CE57B	7623 568788	ALEKSANDR DAVYDOV	{"email": "davydov_a.101959@postgrespro.ru", "phone": "+70828727792"}
0005433577984	42C493	7053 477660	NIKOLAY PAVLOV	{"email": "pavlov_nikolay-021967@postgrespro.ru", "phone": "+70398632271"}
0005433577985	084994	7766 479700	OLESYA PETROVA	{"email": "petrovao_1971@postgrespro.ru", "phone": "+70719341313"}
0005433577986	BE9A1D	2844 051932	EVGENIY ANTONOV	{"email": "eantonov_1964@postgrespro.ru", "phone": "+70349243135"}
0005433577987	BE9A1D	2407 440383	ALEKSANDR KRASNOV	{"email": "krasnov.a1967@postgrespro.ru", "phone": "+70666748905"}
0005433577988	B6FCDC	0097 696800	ANATOLIY BARANOV	{"phone": "+70417353187"}
0005433577989	6E7C08	0987 910652	EKATERINA PETROVA	{"email": "e.petrova25011968@postgrespro.ru", "phone": "+70150912078"}
0005433577990	6E7C08	8032 781923	ALEKSANDR GAVRILOV	{"phone": "+70798052809"}
0005433577991	2AAE21	9298 039710	ALEKSANDR PETROV	{"phone": "+70713101592"}
0005433577992	2AAE21	6755 652488	ALEKSANDR RODIONOV	{"phone": "+70923389580"}
0005433577993	E80E00	8090 473172	GALINA ERMAKOVA	{"email": "germakova.1968@postgrespro.ru", "phone": "+70274248805"}
0005433577994	E80E00	1197 931558	MAKSIM SAVELEV	{"email": "savelev-maksim.12101968@postgrespro.ru", "phone": "+70594504045"}
0005433577995	41B57C	5291 651569	FEDOR SCHERBAKOV	{"phone": "+70338887480"}
0005433577996	9CDCCC	5590 887592	GALINA MOISEEVA	{"email": "moiseeva.galina.16091968@postgrespro.ru", "phone": "+70692697353"}
0005433577997	CA4D42	4446 904745	DANILA POPOV	{"email": "popov.danila-031978@postgrespro.ru", "phone": "+70259725803"}
0005433577998	348CE2	2054 745551	EVGENIY SAVELEV	{"phone": "+70733939309"}
0005433577999	348CE2	4673 815520	PAVEL NIKITIN	{"phone": "+70902965116"}
0005433578000	E3B187	7417 868731	OLGA IVANOVA	{"phone": "+70212039608"}
0005433578002	FC4A24	5992 830422	KONSTANTIN KRASNOV	{"email": "krasnov_konstantin-021971@postgrespro.ru", "phone": "+70360426651"}
0005433578003	B3AEB6	6084 768498	EVGENIY SHEVCHENKO	{"email": "shevchenkoevgeniy_051965@postgrespro.ru", "phone": "+70282116611"}
0005433578004	AF8E3F	1701 160506	SVETLANA MARTYNOVA	{"phone": "+70945548697"}
0005433578005	7395BB	3222 561874	ULYANA ILINA	{"email": "ulyana_ilina_1969@postgrespro.ru", "phone": "+70024717801"}
0005433578006	179B33	2326 483410	ALI STEPANOV	{"phone": "+70366664346"}
0005433578007	824A3A	7925 781813	ANDREY MIKHAYLOV	{"email": "a-mikhaylov_111967@postgrespro.ru", "phone": "+70390961006"}
0005433578008	0E5C50	4554 441046	ELENA ANISIMOVA	{"email": "anisimova-elena-1970@postgrespro.ru", "phone": "+70823756434"}
0005433578009	AB97A3	4421 105311	OLEG TIKHONOV	{"phone": "+70317353412"}
0005433578010	FC1513	9326 904630	VIKTORIYA PETROVA	{"email": "petrova_viktoriya1973@postgrespro.ru", "phone": "+70698539796"}
0005433578011	F91061	3003 015880	VASILIY IVANOV	{"email": "ivanovv-1964@postgrespro.ru", "phone": "+70669942868"}
0005433578012	6EC41E	6294 204226	RUSLAN MIKHAYLOV	{"email": "mikhaylov_r_011958@postgrespro.ru", "phone": "+70478440793"}
0005433578013	6EC41E	2891 768483	GALINA SCHERBAKOVA	{"email": "g.scherbakova1968@postgrespro.ru", "phone": "+70319334878"}
0005433578014	A47F9A	9604 986760	LYUBOV SMIRNOVA	{"phone": "+70039875978"}
0005433578015	DAD0FB	3695 734628	ALEKSEY ANTONOV	{"phone": "+70443301178"}
0005433578016	DAD0FB	6312 338252	ALEKSANDR PAVLOV	{"phone": "+70237542422"}
0005433578017	96C74E	4479 473645	ALEKSANDR BELOV	{"email": "belov_aleksandr101976@postgrespro.ru", "phone": "+70519422668"}
0005433578018	2286AE	5907 686777	KONSTANTIN ALEKSEEV	{"email": "alekseev-konstantin121982@postgrespro.ru", "phone": "+70797661952"}
0005433578019	FC5B74	5920 271394	IRINA MIKHAYLOVA	{"email": "mikhaylova.i041986@postgrespro.ru", "phone": "+70821749732"}
0005433578020	05EC2F	5610 145487	NATALYA KOZLOVA	{"email": "kozlova_n-1966@postgrespro.ru", "phone": "+70556079567"}
0005433578021	05EC2F	4137 572871	OLGA SOLOVEVA	{"email": "soloveva-o_05101969@postgrespro.ru", "phone": "+70986648758"}
0005433578022	05EC2F	6706 207906	ANASTASIYA NAZAROVA	{"phone": "+70919797083"}
0005433578023	25BA3D	7450 707064	SERGEY POPOV	{"phone": "+70461366477"}
0005433578024	036AF2	7063 756457	OLEG FOMIN	{"email": "o-fomin03011971@postgrespro.ru", "phone": "+70781095107"}
0005433578025	46F7FE	2629 955598	ALEKSANDR BELOV	{"email": "a.belov.1960@postgrespro.ru", "phone": "+70058891907"}
0005433578026	57FEFB	7481 637139	LYUBOV IVANOVA	{"email": "ivanova.l.11031969@postgrespro.ru", "phone": "+70560748704"}
0005433578027	527C64	5932 201814	OLGA BORISOVA	{"phone": "+70938781629"}
0005433578028	9DF873	5691 317491	IRINA BARANOVA	{"phone": "+70321018302"}
0005433578029	174369	1214 228256	ELENA LAZAREVA	{"email": "e.lazareva021978@postgrespro.ru", "phone": "+70987000997"}
0005433578030	3827CE	6172 291718	NINA IVANOVA	{"email": "ivanova_nina-1975@postgrespro.ru", "phone": "+70095703868"}
0005433578031	9F87BE	9043 024030	NINA NIKITINA	{"email": "nina-nikitina.17041963@postgrespro.ru", "phone": "+70125948395"}
0005433578032	E2D059	1355 381077	PETR SERGEEV	{"phone": "+70762461650"}
0005433578033	A9784D	1798 328067	OKSANA MIRONOVA	{"email": "mironova-oksana.031964@postgrespro.ru", "phone": "+70905248468"}
0005433578034	A9784D	2042 315731	ANDREY MOISEEV	{"phone": "+70753719164"}
0005433578035	0FA5A1	7286 104299	ALEKSANDR CHERNOV	{"phone": "+70613870867"}
0005433578036	C6D06A	9002 547869	DENIS SHEVCHENKO	{"email": "shevchenko-d04051976@postgrespro.ru", "phone": "+70078447154"}
0005433578037	C6D06A	4295 379027	DANILA IVANOV	{"email": "ivanov.d.04021972@postgrespro.ru", "phone": "+70865338839"}
0005433578038	21A500	9911 424715	OLGA NAUMOVA	{"email": "naumova_o_1970@postgrespro.ru", "phone": "+70528904587"}
0005433578039	C5179A	1781 681825	VERA MIKHAYLOVA	{"email": "mikhaylova.v_121973@postgrespro.ru", "phone": "+70251556064"}
0005433578040	62C519	5192 268280	GULFIYA FEDOROVA	{"phone": "+70275397813"}
0005433578041	EB1041	0306 006393	VASILIY ANDREEV	{"phone": "+70365493620"}
0005433578042	EB1041	4945 313769	SVETLANA MAKAROVA	{"email": "s_makarova-26051976@postgrespro.ru", "phone": "+70072514892"}
0005433578043	2DD7F6	5800 910798	ANATOLIY OSIPOV	{"phone": "+70100660099"}
0005433578044	618CC7	4638 175806	MAKSIM GUSEV	{"phone": "+70695340077"}
0005433578045	618CC7	0119 286567	SERGEY SERGEEV	{"email": "sergeev.s061969@postgrespro.ru", "phone": "+70381475025"}
0005433578046	5BF2F3	0163 424360	ANNA MOROZOVA	{"phone": "+70538398644"}
0005433578047	2A61C5	5462 482868	VLADIMIR MAKSIMOV	{"email": "v.maksimov_18011970@postgrespro.ru", "phone": "+70971082725"}
0005433578048	79B54D	1746 158735	KSENIYA GRISHINA	{"phone": "+70730176132"}
0005433578049	79B54D	1142 386322	VITALIY SERGEEV	{"phone": "+70903381144"}
0005433578050	C65BB7	2985 280670	LYUBOV KAZAKOVA	{"email": "l.kazakova-1978@postgrespro.ru", "phone": "+70562129296"}
0005433578051	D405B7	6764 263300	LYUDMILA KULIKOVA	{"phone": "+70330134618"}
0005433578052	D405B7	8110 259781	MAKSIM NOVIKOV	{"email": "mnovikov.1973@postgrespro.ru", "phone": "+70875868312"}
0005433578053	1616CC	0704 983963	NATALIYA NAZAROVA	{"email": "nazarovanataliya.22031973@postgrespro.ru", "phone": "+70582890527"}
0005433578054	C58E50	0394 791063	MARIYA VOLKOVA	{"email": "mvolkova.1974@postgrespro.ru", "phone": "+70854196016"}
0005433578055	C58E50	4677 649966	LYUBOV NESTEROVA	{"email": "nesterova.lyubov1982@postgrespro.ru", "phone": "+70579292221"}
0005433578056	74C3AF	3834 712336	VLADIMIR MIKHAYLOV	{"email": "vladimirmikhaylov_081979@postgrespro.ru", "phone": "+70067887438"}
0005433578113	1B17DD	3611 137248	FARIT NIKOLAEV	{"phone": "+70506267111"}
0005433578057	30845D	5033 079091	OLGA PAVLOVA	{"email": "olga.pavlova-121967@postgrespro.ru", "phone": "+70162996346"}
0005433578058	F49C45	8058 849068	RINAT MARTYNOV	{"phone": "+70461233880"}
0005433578059	F49C45	6725 847808	STANISLAV DMITRIEV	{"phone": "+70617478564"}
0005433578060	63E6A9	7454 646831	ZAKHAR ORLOV	{"phone": "+70272664686"}
0005433578061	2B6237	2401 655440	VLADIMIR BONDARENKO	{"email": "v-bondarenko1968@postgrespro.ru", "phone": "+70842153287"}
0005433578062	2B6237	8681 361959	ANNA ZAKHAROVA	{"phone": "+70264191943"}
0005433578063	7FBFDF	7338 513746	SVETLANA IVANOVA	{"email": "svetlanaivanova.1970@postgrespro.ru", "phone": "+70395317976"}
0005433578064	48CE6E	2084 289254	VALERIY PETROV	{"email": "v.petrov.08121974@postgrespro.ru", "phone": "+70033265900"}
0005433578065	48CE6E	2259 662646	ILGIZ VOLKOV	{"email": "volkov-i.13081978@postgrespro.ru", "phone": "+70287456876"}
0005433578066	B70A06	1147 317129	LYUDMILA MALYSHEVA	{"phone": "+70754133918"}
0005433578067	27F159	1111 022871	TATYANA EGOROVA	{"email": "t-egorova-071973@postgrespro.ru", "phone": "+70277032829"}
0005433578068	27F159	3823 507955	ARTEM FEDOROV	{"phone": "+70093160690"}
0005433578069	4EAEA8	8739 371509	TATYANA MAKAROVA	{"phone": "+70542022621"}
0005433578070	51BDB3	7297 646091	VIKTOR KONOVALOV	{"email": "v-konovalov.05101976@postgrespro.ru", "phone": "+70224154648"}
0005433578071	7C66C1	0339 132684	IVAN SOKOLOV	{"email": "i.sokolov-28111963@postgrespro.ru", "phone": "+70932967611"}
0005433578072	7C66C1	9313 016234	IRINA VASILEVA	{"phone": "+70988037967"}
0005433578073	7C66C1	9320 291054	LARISA PETROVA	{"phone": "+70294417637"}
0005433578074	7C66C1	9662 071069	NINA KOROLEVA	{"phone": "+70328639273"}
0005433578075	840DF7	7990 702424	IVAN IVANOV	{"phone": "+70773957622"}
0005433578076	995306	9147 545469	ALEKSANDR MELNIKOV	{"email": "a-melnikov.19021971@postgrespro.ru", "phone": "+70611921332"}
0005433578077	F0494A	6424 941105	RUMIYA GAVRILOVA	{"email": "rumiya-gavrilova-21011974@postgrespro.ru", "phone": "+70041058536"}
0005433578078	B05300	4145 040547	ARSENIY AFANASEV	{"email": "afanasev_a-15041971@postgrespro.ru", "phone": "+70126547177"}
0005433578079	37074C	5884 230085	ALEKSANDR PETROV	{"email": "petrova-081976@postgrespro.ru", "phone": "+70315771014"}
0005433578080	37074C	4790 367088	MIKHAIL PETROV	{"phone": "+70636252559"}
0005433578081	C38FCF	5829 925934	OLGA MIKHAYLOVA	{"phone": "+70046188280"}
0005433578082	0A52F6	0802 955354	ALEKSEY SIDOROV	{"email": "sidorov_a.16071972@postgrespro.ru", "phone": "+70173213162"}
0005433578083	0A52F6	9705 932580	NATALYA LOGINOVA	{"phone": "+70003515547"}
0005433578084	B05567	1371 281863	EDGAR PAVLOV	{"phone": "+70201760768"}
0005433578085	62470F	6914 098219	VLADIMIR GUSEV	{"phone": "+70324015014"}
0005433578086	319037	3433 291937	GALINA IVANOVA	{"email": "ivanovag-011973@postgrespro.ru", "phone": "+70326286746"}
0005433578087	AF9AE5	3650 996047	DMITRIY FEDOTOV	{"phone": "+70083224334"}
0005433578088	AF9AE5	6375 027499	MARINA KAZAKOVA	{"phone": "+70755797918"}
0005433578089	D185FE	4177 053922	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.1968@postgrespro.ru", "phone": "+70398275442"}
0005433578090	D185FE	5517 993256	EKATERINA ZHURAVLEVA	{"email": "ezhuravleva-1971@postgrespro.ru", "phone": "+70521412765"}
0005433578091	86422D	0331 178934	YANA MOISEEVA	{"phone": "+70764968733"}
0005433578092	9B8F78	7682 668572	ANNA NAZAROVA	{"email": "nazarova.a-1965@postgrespro.ru", "phone": "+70216461390"}
0005433578093	B236B9	7621 224737	LYUDMILA ZAYCEVA	{"email": "lyudmila-zayceva.011959@postgrespro.ru", "phone": "+70675973835"}
0005433578094	B60FFD	3505 516424	YULIYA SOROKINA	{"email": "yuliya.sorokina.1971@postgrespro.ru", "phone": "+70995606074"}
0005433578095	B1D42C	3202 160752	DMITRIY ORLOV	{"email": "dmitriyorlov_1971@postgrespro.ru", "phone": "+70163599322"}
0005433578096	B1D42C	2503 069632	REGINA ROMANOVA	{"phone": "+70710339834"}
0005433578097	F5D29C	9019 757434	ELENA DAVYDOVA	{"email": "davydova.elena-26101971@postgrespro.ru", "phone": "+70199482606"}
0005433578098	04ABFC	3888 709081	ANDREY KARPOV	{"phone": "+70571695461"}
0005433578099	BC5B26	0037 214230	NATALYA MALYSHEVA	{"email": "natalyamalysheva091971@postgrespro.ru", "phone": "+70739856067"}
0005433578100	230C2E	8327 975120	VALERIY NAZAROV	{"phone": "+70265469008"}
0005433578101	49E19B	6348 777531	ARTEM POPOV	{"email": "apopov1968@postgrespro.ru", "phone": "+70793100950"}
0005433578102	082B94	8809 369465	ANTON SIDOROV	{"email": "anton_sidorov_17031964@postgrespro.ru", "phone": "+70689758532"}
0005433578103	082B94	6190 549737	IRINA MATVEEVA	{"phone": "+70914464677"}
0005433578104	082B94	1301 953329	ARINA KUZNECOVA	{"email": "arina.kuznecova_21101971@postgrespro.ru", "phone": "+70448187415"}
0005433578105	F7B26C	6697 694547	VALERIYA TITOVA	{"phone": "+70381307893"}
0005433578106	27246F	5918 407513	TATYANA YAKOVLEVA	{"email": "yakovleva_t_26061980@postgrespro.ru", "phone": "+70443582757"}
0005433578107	02F402	4058 477385	VALENTINA VLASOVA	{"phone": "+70460646239"}
0005433578108	AD6AEC	6035 704839	MARIYA ALEKSANDROVA	{"phone": "+70451777853"}
0005433578109	AD6AEC	0951 086174	ALEKSEY NOVIKOV	{"email": "novikov-aleksey-051975@postgrespro.ru", "phone": "+70331261233"}
0005433578110	B8838D	6343 191696	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov121972@postgrespro.ru", "phone": "+70920825069"}
0005433578111	B8838D	6286 030127	VLADIMIR KOZLOV	{"email": "kozlov-v-1972@postgrespro.ru", "phone": "+70606193095"}
0005433578112	1B17DD	6290 324528	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr.1983@postgrespro.ru", "phone": "+70077427508"}
0005433578114	1B17DD	4254 167927	MARINA KOZLOVA	{"phone": "+70626305965"}
0005433578115	0FB1E2	2914 272198	ELENA CHERNOVA	{"phone": "+70034361918"}
0005433578116	0FB1E2	0057 664874	ALEKSEY DAVYDOV	{"email": "a.davydov.061963@postgrespro.ru", "phone": "+70301949073"}
0005433578117	ABF262	8817 585006	DMITRIY FROLOV	{"email": "frolovd1982@postgrespro.ru", "phone": "+70288700006"}
0005433578118	ABF262	5905 632427	YULIYA GUSEVA	{"phone": "+70626787283"}
0005433578119	ABF262	5992 907528	MARINA KOVALEVA	{"phone": "+70185099052"}
0005433578120	4894DC	3894 943306	RUSLAN KOZLOV	{"email": "r.kozlov-1965@postgrespro.ru", "phone": "+70745691401"}
0005433578121	4894DC	0792 252255	ILDUS KOZLOV	{"phone": "+70159317896"}
0005433578122	20D415	5360 877678	SERGEY TIKHONOV	{"email": "tikhonov_s.14121965@postgrespro.ru", "phone": "+70880449752"}
0005433578123	85F4EA	6534 267876	ALEVTINA ANTONOVA	{"phone": "+70454853918"}
0005433578124	393085	1138 448928	ANNA NIKITINA	{"email": "a.nikitina_111985@postgrespro.ru", "phone": "+70687283486"}
0005433578125	3732C3	9827 736375	YURIY KUDRYASHOV	{"phone": "+70415191118"}
0005433578126	BE16FB	8836 992102	KRISTINA DMITRIEVA	{"email": "k.dmitrieva-16121965@postgrespro.ru", "phone": "+70565755979"}
0005433578127	BE16FB	4371 513340	TATYANA KOVALEVA	{"email": "kovaleva_tatyana-22081963@postgrespro.ru", "phone": "+70676889659"}
0005433578128	5870A4	6239 199472	OLEG MOISEEV	{"email": "moiseev-o_061975@postgrespro.ru", "phone": "+70319063918"}
0005433578129	5870A4	5301 128303	PETR VASILEV	{"email": "vasilevpetr1964@postgrespro.ru", "phone": "+70698296963"}
0005433578130	FF57A9	8939 580251	VLADIMIR IVANOV	{"phone": "+70950959697"}
0005433578131	FF57A9	7312 041709	LYUBOV EGOROVA	{"email": "egorovalyubov-1962@postgrespro.ru", "phone": "+70480625872"}
0005433578132	83CCA2	8215 338373	IRINA NESTEROVA	{"phone": "+70435845062"}
0005433578133	83CCA2	1716 808423	SVETLANA VASILEVA	{"email": "svetlana-vasileva.1970@postgrespro.ru", "phone": "+70754953733"}
0005433578134	11E84A	2416 383626	ELENA ZAYCEVA	{"phone": "+70203575602"}
0005433578135	11E84A	7172 295959	EVGENIYA KOMAROVA	{"phone": "+70426513621"}
0005433578136	41321B	2103 835773	ARINA OSIPOVA	{"email": "aosipova1964@postgrespro.ru", "phone": "+70509972355"}
0005433578137	41321B	7297 096020	NATALIYA NAZAROVA	{"email": "nazarovanataliya.16121966@postgrespro.ru", "phone": "+70969827076"}
0005433578138	5EAD3E	7446 964291	NADEZHDA SMIRNOVA	{"email": "nadezhda-smirnova_11051973@postgrespro.ru", "phone": "+70759529802"}
0005433578139	5EAD3E	2702 811130	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey.1982@postgrespro.ru", "phone": "+70086640288"}
0005433578140	8648DD	9018 182123	VALERIY KUZNECOV	{"phone": "+70431245878"}
0005433578141	5B5FB6	4137 545897	VALERIY GORBUNOV	{"email": "valeriy_gorbunov.09071976@postgrespro.ru", "phone": "+70988912396"}
0005433578142	3AA361	8719 035222	SVETLANA SMIRNOVA	{"email": "smirnova.s_041971@postgrespro.ru", "phone": "+70131373565"}
0005433578143	E29564	6960 830898	GRIGORIY KARPOV	{"email": "grigoriy.karpov1974@postgrespro.ru", "phone": "+70587841447"}
0005433578144	E29564	9750 123233	RAVIL VASILEV	{"phone": "+70251726476"}
0005433578145	1E9A5A	1407 034032	NIKOLAY FEDOROV	{"email": "n-fedorov1969@postgrespro.ru", "phone": "+70033498184"}
0005433578146	AF6B6D	3058 917872	POLINA KOLESNIKOVA	{"phone": "+70419980257"}
0005433578147	AF6B6D	0940 994349	ANASTASIYA KAZAKOVA	{"phone": "+70373514475"}
0005433578148	AF6B6D	2500 485345	ELENA SAVELEVA	{"email": "saveleva.elena.1969@postgrespro.ru", "phone": "+70030933224"}
0005433578149	A7DA35	0261 565493	OKSANA PETROVA	{"email": "petrovao_1978@postgrespro.ru", "phone": "+70274543519"}
0005433578150	AD42D7	9472 665889	ALSU PAVLOVA	{"email": "alsu-pavlova_011972@postgrespro.ru", "phone": "+70410760453"}
0005433578151	AD42D7	1280 111449	GALINA NIKITINA	{"phone": "+70088966658"}
0005433578152	CE0583	8740 915639	MARINA ZAKHAROVA	{"email": "zakharovamarina.29041979@postgrespro.ru", "phone": "+70064117658"}
0005433578153	C3DA32	1263 884816	ANNA LOGINOVA	{"phone": "+70982010319"}
0005433578154	DA2446	0914 390268	NATALYA SMIRNOVA	{"phone": "+70558730983"}
0005433578155	DA2446	7258 589173	OLEG KISELEV	{"email": "kiselev.o.1960@postgrespro.ru", "phone": "+70718244330"}
0005433578156	9263C6	1554 073963	VERA SEMENOVA	{"email": "semenova.v.1969@postgrespro.ru", "phone": "+70745423967"}
0005433578157	9263C6	6565 222038	TATYANA EGOROVA	{"email": "tatyana_egorova.21071970@postgrespro.ru", "phone": "+70497028855"}
0005433578158	1DE000	0928 615911	DMITRIY NOVIKOV	{"phone": "+70463536937"}
0005433578159	03CE3A	0216 353965	GALINA YAKOVLEVA	{"email": "g.yakovleva081974@postgrespro.ru", "phone": "+70077671567"}
0005433578160	A45190	7540 245522	ALEKSEY SOROKIN	{"email": "sorokin-aleksey-14121973@postgrespro.ru", "phone": "+70599244902"}
0005433578161	EE9BF3	2164 386359	VALERIY NAZAROV	{"phone": "+70364419772"}
0005433578162	EE9BF3	9152 699382	ALEKSEY FOMIN	{"phone": "+70195832773"}
0005433578163	4F864D	1552 450217	YULIYA ANDREEVA	{"phone": "+70122606478"}
0005433578164	4F864D	0456 183255	IVAN BORISOV	{"email": "ivan_borisov.1977@postgrespro.ru", "phone": "+70386423467"}
0005433578165	E55FAF	3801 729832	POLINA POPOVA	{"email": "polina-popova.051969@postgrespro.ru", "phone": "+70309878146"}
0005433578166	E55FAF	3381 307843	KONSTANTIN KUZMIN	{"phone": "+70265300645"}
0005433578167	E55FAF	3827 783667	LEONID GRIGOREV	{"phone": "+70852209306"}
0005433578168	C91707	5952 424784	VALENTINA GERASIMOVA	{"phone": "+70113536088"}
0005433578169	398B5F	5977 937160	ANDREY GORBUNOV	{"email": "gorbunov_a.30041974@postgrespro.ru", "phone": "+70228991370"}
0005433578170	398B5F	6255 577654	YURIY BELOV	{"email": "y.belov-24081972@postgrespro.ru", "phone": "+70318429405"}
0005433578171	48F39D	8480 034168	ELIZAVETA KUZNECOVA	{"phone": "+70433969692"}
0005433578172	124F8D	7246 174712	ANDREY MOISEEV	{"email": "moiseev.a_13091970@postgrespro.ru", "phone": "+70386452618"}
0005433578173	124F8D	6501 031249	YURIY KONOVALOV	{"phone": "+70889429486"}
0005433578174	68FD77	7273 661095	MIKHAIL SOROKIN	{"phone": "+70841480838"}
0005433578175	EB90D1	7137 427197	EKATERINA DANILOVA	{"email": "e-danilova-1971@postgrespro.ru", "phone": "+70466850037"}
0005433578176	EB90D1	9348 998129	POLINA DMITRIEVA	{"email": "dmitrieva_polina.101962@postgrespro.ru", "phone": "+70487477597"}
0005433578177	56B6C8	1215 484722	ANATOLIY DENISOV	{"phone": "+70778625272"}
0005433578178	9599B3	2572 047243	OLGA NIKOLAEVA	{"email": "o_nikolaeva-1971@postgrespro.ru", "phone": "+70673535258"}
0005433578179	79F190	1980 433510	NATALYA ALEKSANDROVA	{"phone": "+70888347381"}
0005433578180	9CB85B	9593 635046	VALENTINA ROMANOVA	{"phone": "+70383747918"}
0005433578181	15DA4B	8928 335453	NAIL MIRONOV	{"email": "mironov_n011960@postgrespro.ru", "phone": "+70087625053"}
0005433578182	4E4A8B	3192 726763	TATYANA POTAPOVA	{"email": "potapova_t.22061968@postgrespro.ru", "phone": "+70636107093"}
0005433578183	4E4A8B	9757 971025	IVAN STEPANOV	{"email": "stepanov-ivan.031977@postgrespro.ru", "phone": "+70543113413"}
0005433578184	6F01F0	0877 220522	MARINA KOROLEVA	{"email": "mkoroleva-081975@postgrespro.ru", "phone": "+70856489447"}
0005433578185	47BAAE	7298 104480	NATALIYA KAZAKOVA	{"email": "n.kazakova-1984@postgrespro.ru", "phone": "+70127098972"}
0005433578186	47BAAE	1917 361002	NIKOLAY ALEKSEEV	{"email": "alekseev_nikolay_14101974@postgrespro.ru", "phone": "+70275330583"}
0005433578187	F0846D	7191 648771	KIRILL NAUMOV	{"phone": "+70912668830"}
0005433578188	FD0A5B	3246 329053	LYUDMILA POTAPOVA	{"email": "potapovalyudmila1974@postgrespro.ru", "phone": "+70410064538"}
0005433578189	FE08C9	2315 522559	ALEKSEY TARASOV	{"phone": "+70023380073"}
0005433578190	A1CB44	2035 346272	ALEKSANDR BARANOV	{"email": "baranov.a_07121974@postgrespro.ru", "phone": "+70113599439"}
0005433578191	A1CB44	4747 179413	SERGEY SERGEEV	{"phone": "+70658137419"}
0005433578192	6D0F94	1655 059283	LEONID VOLKOV	{"phone": "+70313300772"}
0005433578193	6D0F94	2829 515939	MIKHAIL SIDOROV	{"phone": "+70577743617"}
0005433578194	1EB26F	7930 962017	ARTUR IVANOV	{"email": "arturivanov1975@postgrespro.ru", "phone": "+70487272713"}
0005433578195	DB0004	6845 179040	TATYANA TARASOVA	{"email": "tarasova-tatyana031976@postgrespro.ru", "phone": "+70522537458"}
0005433578196	211703	6594 185091	OLGA POPOVA	{"phone": "+70393097299"}
0005433578197	211703	0672 239723	IRINA ALEKSEEVA	{"email": "irinaalekseeva-28101972@postgrespro.ru", "phone": "+70005066096"}
0005433578198	211703	8172 394100	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-30031977@postgrespro.ru", "phone": "+70988602987"}
0005433578199	744044	1557 134387	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov-071978@postgrespro.ru", "phone": "+70063563162"}
0005433578200	744044	7090 214321	DANIYA ZAKHAROVA	{"email": "zakharova-daniya.1961@postgrespro.ru", "phone": "+70390006989"}
0005433578201	E8B92E	3605 152230	MARIYA TROFIMOVA	{"phone": "+70996709185"}
0005433578202	E8B92E	6536 969647	EKATERINA FEDOROVA	{"email": "ekaterina.fedorova_021963@postgrespro.ru", "phone": "+70129355179"}
0005433578203	E8B92E	9860 107460	ELENA VOROBEVA	{"phone": "+70102303794"}
0005433578204	7D6319	7460 422587	NINA GORBUNOVA	{"email": "gorbunova_nina_051968@postgrespro.ru", "phone": "+70199801680"}
0005433578205	7D6319	9674 717054	TAMARA MOROZOVA	{"email": "morozovatamara.07091980@postgrespro.ru", "phone": "+70267989089"}
0005433578206	9AF66B	4353 566382	ANNA FILIPPOVA	{"phone": "+70827098501"}
0005433613386	5512A1	6102 539220	TAISIYA TARASOVA	{"email": "tarasovataisiya.08041969@postgrespro.ru", "phone": "+70455332866"}
0005433613387	5512A1	1401 108700	VALERIYA ABRAMOVA	{"email": "abramovavaleriya_101975@postgrespro.ru", "phone": "+70274162128"}
0005433613388	A2CE12	3553 584934	ELENA NIKOLAEVA	{"email": "nikolaevae-011977@postgrespro.ru", "phone": "+70973304866"}
0005433613389	A54DCC	2327 865236	EKATERINA NIKOLAEVA	{"email": "e.nikolaeva.111967@postgrespro.ru", "phone": "+70727636535"}
0005433613390	F76371	6817 257910	TATYANA AKIMOVA	{"email": "tatyana-akimova071977@postgrespro.ru", "phone": "+70383260419"}
0005433613391	F76371	3613 990159	GALINA GERASIMOVA	{"phone": "+70904843106"}
0005433613392	4EEC39	6227 849757	ALEKSANDR GRIGOREV	{"email": "a-grigorev25021974@postgrespro.ru", "phone": "+70520444150"}
0005433613393	4EEC39	6091 037119	STANISLAV IVANOV	{"phone": "+70731284407"}
0005433613394	4EEC39	0344 809466	NADEZHDA FADEEVA	{"phone": "+70579773838"}
0005433613395	4EEC39	1031 622446	NATALYA MATVEEVA	{"phone": "+70216687830"}
0005433613396	530FE9	0595 700463	DENIS FEDOTOV	{"email": "d.fedotov-1975@postgrespro.ru", "phone": "+70678583775"}
0005433613397	EDEE76	6726 974212	MARINA SOLOVEVA	{"phone": "+70624134967"}
0005433613398	EDEE76	5900 117034	OLEG TIKHONOV	{"phone": "+70098793872"}
0005433613399	FC5C56	4907 115809	ANASTASIYA FEDOROVA	{"phone": "+70976136010"}
0005433613400	75FE20	8205 020107	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay1972@postgrespro.ru", "phone": "+70838805110"}
0005433613401	76C5AD	6888 849928	ANNA VLASOVA	{"phone": "+70217848881"}
0005433613402	22B082	4246 971119	GENNADIY KONOVALOV	{"email": "konovalovgennadiy1967@postgrespro.ru", "phone": "+70104647047"}
0005433613403	22B082	0795 614156	SERGEY VOROBEV	{"email": "sergey_vorobev1963@postgrespro.ru", "phone": "+70578645640"}
0005433613404	22B082	0402 707077	NATALYA CHERNOVA	{"phone": "+70289210590"}
0005433613405	687950	3548 369341	OLGA ISAEVA	{"phone": "+70756938295"}
0005433613406	687950	8981 027817	NATALYA VASILEVA	{"email": "vasilevan02081975@postgrespro.ru", "phone": "+70211392244"}
0005433613407	57F778	9366 245452	STANISLAV POPOV	{"phone": "+70060453963"}
0005433613408	FA6810	5687 938065	ANDREY MIRONOV	{"phone": "+70662896945"}
0005433613409	FA6810	1312 678723	LYUBOV NESTEROVA	{"email": "nesterova_l.1971@postgrespro.ru", "phone": "+70925255449"}
0005433613410	F72A66	8241 185587	DANIIL ZAKHAROV	{"email": "daniil_zakharov.19031973@postgrespro.ru", "phone": "+70613168606"}
0005433613411	DAF7EC	6548 760819	DARYA RYABOVA	{"email": "ryabova.darya.1980@postgrespro.ru", "phone": "+70492253405"}
0005433613412	D5FB36	7438 407787	TATYANA PETROVA	{"email": "petrova.tatyana_1977@postgrespro.ru", "phone": "+70231573397"}
0005433613413	D5FB36	0686 186407	VALENTINA ZAKHAROVA	{"phone": "+70532579838"}
0005433613414	0A68D4	2242 240860	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov_13041979@postgrespro.ru", "phone": "+70343327163"}
0005433613415	DCCCFF	8806 415464	ALEKSEY BONDARENKO	{"email": "aleksey-bondarenko-28071974@postgrespro.ru", "phone": "+70572055826"}
0005433613416	6C312D	4198 897343	ALLA FADEEVA	{"email": "alla_fadeeva.071963@postgrespro.ru", "phone": "+70674382699"}
0005433613417	6C312D	1470 258414	KLAVDIYA FROLOVA	{"phone": "+70520087982"}
0005433613418	D681FA	7382 497229	ELENA MIKHAYLOVA	{"email": "mikhaylova-e28101962@postgrespro.ru", "phone": "+70413336422"}
0005433613419	7E28E1	7350 549126	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr021968@postgrespro.ru", "phone": "+70299127795"}
0005433613420	7E28E1	5322 145314	ALEKSANDRA FEDOROVA	{"email": "aleksandra-fedorova-19051968@postgrespro.ru", "phone": "+70281893920"}
0005433613421	816F0C	0714 541244	KSENIYA GRISHINA	{"email": "kseniya-grishina1974@postgrespro.ru", "phone": "+70804737309"}
0005433613422	84A316	6771 826940	MIKHAIL ZAYCEV	{"email": "zaycev.m-1980@postgrespro.ru", "phone": "+70739770344"}
0005433613423	F47DDA	2693 879782	MARIYA FROLOVA	{"email": "mariyafrolova_1975@postgrespro.ru", "phone": "+70856561288"}
0005433613424	9ECA61	6104 213986	YANA FEDOROVA	{"email": "fedorova-yana_091978@postgrespro.ru", "phone": "+70538335676"}
0005433613425	FF76B1	1407 178990	MAYYA DAVYDOVA	{"phone": "+70908874406"}
0005433613426	ACE58D	8692 549882	ANTON SEMENOV	{"phone": "+70911686722"}
0005433613427	4E0E40	9370 735162	MAKSIM BELOV	{"email": "maksimbelov-101970@postgrespro.ru", "phone": "+70478104737"}
0005433613428	719A33	6038 089092	POLINA GUSEVA	{"phone": "+70365439716"}
0005433613429	0BBF64	7157 501319	ARTEM NOVIKOV	{"email": "novikov_artem_1968@postgrespro.ru", "phone": "+70589449978"}
0005433613430	121107	7369 460652	MARAT GUSEV	{"email": "mgusev1973@postgrespro.ru", "phone": "+70454406581"}
0005433613431	121107	2918 187802	ALEKSEY TIKHONOV	{"phone": "+70472935712"}
0005433613432	79453F	4355 112269	ALEKSEY CHERNOV	{"email": "chernov.aleksey-08091965@postgrespro.ru", "phone": "+70482955380"}
0005433613433	33537E	4114 677603	VIKTOR KRASNOV	{"phone": "+70763476617"}
0005433613434	33537E	3691 186706	POLINA MIKHAYLOVA	{"email": "mikhaylova-polina.021965@postgrespro.ru", "phone": "+70709194798"}
0005433613435	33537E	7233 661587	VALENTIN KISELEV	{"phone": "+70359608928"}
0005433613436	6BE74B	8813 886589	KLAVDIYA EGOROVA	{"email": "egorovak081986@postgrespro.ru", "phone": "+70544833138"}
0005433613437	F276EB	4169 511905	NINA SOROKINA	{"email": "nina_sorokina-081981@postgrespro.ru", "phone": "+70735517486"}
0005433613438	567B30	0359 313990	VLADIMIR NOVIKOV	{"email": "vladimir_novikov_10011965@postgrespro.ru", "phone": "+70432941134"}
0005433613439	C5FC8D	1921 319511	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana_1969@postgrespro.ru", "phone": "+70906806728"}
0005433613440	4EC6D7	8627 309549	ROMAN SERGEEV	{"email": "romansergeev-031975@postgrespro.ru", "phone": "+70276214732"}
0005433613441	4EC6D7	0530 008916	ALEKSANDR SAVELEV	{"phone": "+70061853698"}
0005433613442	4EC6D7	3021 642537	MAKSIM FEDOTOV	{"email": "fedotov-m_09061980@postgrespro.ru", "phone": "+70029236175"}
0005433613443	845211	1546 467891	ILNAR MEDVEDEV	{"phone": "+70723204738"}
0005433613444	845211	8459 575475	ANASTASIYA BELOVA	{"email": "belova.anastasiya.1969@postgrespro.ru", "phone": "+70749372025"}
0005433613445	E39D3C	1595 062692	SERGEY DAVYDOV	{"email": "davydov-sergey.10101970@postgrespro.ru", "phone": "+70174767326"}
0005433613446	E39D3C	1587 170069	DMITRIY AFANASEV	{"phone": "+70323607403"}
0005433613447	814425	0096 588910	NIKOLAY AFANASEV	{"email": "afanasevn-01121971@postgrespro.ru", "phone": "+70776689136"}
0005433613448	BA38C3	1325 658764	VASILIY KULIKOV	{"phone": "+70873871437"}
0005433613449	6FBFA7	6061 299516	ILYA ZAKHAROV	{"email": "zakharovi-13091969@postgrespro.ru", "phone": "+70634188053"}
0005433613450	6FBFA7	2771 896333	ANTONINA KULIKOVA	{"email": "a-kulikova_1973@postgrespro.ru", "phone": "+70505319659"}
0005433613451	8F6863	6881 008318	VIKTOR ABRAMOV	{"phone": "+70401259425"}
0005433613452	8F6863	9513 244901	ELENA KOLESNIKOVA	{"email": "kolesnikova_e_1972@postgrespro.ru", "phone": "+70002926012"}
0005433613453	832D02	5592 385500	ALEKSEY SOKOLOV	{"email": "sokolova-24041975@postgrespro.ru", "phone": "+70812542249"}
0005433613454	F3226E	8577 114246	EVGENIY SERGEEV	{"email": "evgeniy.sergeev.021980@postgrespro.ru", "phone": "+70165309041"}
0005433613455	826163	0862 718055	ALEKSEY ZAKHAROV	{"email": "zakharov.a_1974@postgrespro.ru", "phone": "+70155493404"}
0005433613456	B4E13D	7949 845874	DENIS SMIRNOV	{"phone": "+70071199967"}
0005433613457	49DAD7	2877 831876	VALERIY NOVIKOV	{"email": "vnovikov-25121968@postgrespro.ru", "phone": "+70990387617"}
0005433613458	49DAD7	5308 016715	ANNA KOMAROVA	{"phone": "+70472230323"}
0005433613459	594FB5	3084 981303	LEONTIY KUZNECOV	{"email": "kuznecovleontiy22021974@postgrespro.ru", "phone": "+70092713989"}
0005433613460	415A54	2558 950362	VLADIMIR SEMENOV	{"email": "v-semenov-1977@postgrespro.ru", "phone": "+70482530455"}
0005433613461	F03272	2891 772502	STANISLAV MARTYNOV	{"email": "martynov-s21041974@postgrespro.ru", "phone": "+70461833006"}
0005433613462	F03272	1254 303601	ANNA NESTEROVA	{"phone": "+70527960244"}
0005433613463	8154DE	8854 893558	ALEKSANDR EGOROV	{"phone": "+70875293680"}
0005433613464	12AED0	3378 197378	ANASTASIYA KONOVALOVA	{"phone": "+70711923025"}
0005433613465	FEA37C	8816 602817	VYACHESLAV ILIN	{"phone": "+70293721087"}
0005433613466	BB9D60	3498 188718	ANASTASIYA MEDVEDEVA	{"phone": "+70004023798"}
0005433613467	47E481	2134 734660	ALEKSANDR MARTYNOV	{"phone": "+70763001731"}
0005433613468	855A5B	9252 740801	NIKOLAY NOVIKOV	{"email": "nikolay.novikov-21071973@postgrespro.ru", "phone": "+70859732547"}
0005433613469	8E995D	7685 171307	MARIYA DMITRIEVA	{"email": "dmitrieva_m071968@postgrespro.ru", "phone": "+70601859156"}
0005433613470	6D9C42	3296 393809	VYACHESLAV KAZAKOV	{"email": "kazakov.v.06011989@postgrespro.ru", "phone": "+70461664596"}
0005433613471	DE292D	7599 067191	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov1966@postgrespro.ru", "phone": "+70913477599"}
0005433613472	90049B	1422 672946	ANTON NIKOLAEV	{"phone": "+70764966813"}
0005433613473	E0074C	7461 143295	ANNA SMIRNOVA	{"phone": "+70416381854"}
0005433613474	E0074C	6450 827783	STANISLAV ZHURAVLEV	{"email": "stanislav-zhuravlev-08111984@postgrespro.ru", "phone": "+70697896411"}
0005433613475	E0074C	5505 932958	ALEKSEY FEDOTOV	{"email": "fedotov.aleksey_011969@postgrespro.ru", "phone": "+70179844189"}
0005433613476	07D56A	4966 052426	VALENTINA STEPANOVA	{"email": "v_stepanova.26011969@postgrespro.ru", "phone": "+70893747409"}
0005433613477	81AC92	9316 566474	VADIM KUZNECOV	{"email": "v.kuznecov13041964@postgrespro.ru", "phone": "+70013001412"}
0005433613478	FC7B96	5688 298035	FAINA LAZAREVA	{"email": "fainalazareva_091954@postgrespro.ru", "phone": "+70809332400"}
0005433613479	7FBC81	7166 536343	LYUDMILA NAUMOVA	{"email": "naumova-l.27071980@postgrespro.ru", "phone": "+70304950160"}
0005433613480	201E9B	8651 328516	LYUBOV MELNIKOVA	{"email": "lmelnikova-031978@postgrespro.ru", "phone": "+70349128087"}
0005433613481	FEDC31	3464 942233	ANASTASIYA PAVLOVA	{"phone": "+70227066636"}
0005433613482	244641	8127 475911	SERGEY MOISEEV	{"email": "moiseev.sergey.1961@postgrespro.ru", "phone": "+70060029980"}
0005433613483	244641	5030 964649	ANDREY KISELEV	{"phone": "+70889753985"}
0005433613484	71DAA3	5465 020062	SVETLANA KOVALEVA	{"phone": "+70328685231"}
0005433613485	71DAA3	3810 331392	ANATOLIY SERGEEV	{"phone": "+70077862333"}
0005433613486	E603EB	9350 292536	YURIY IVANOV	{"email": "ivanov-yuriy_051964@postgrespro.ru", "phone": "+70783652922"}
0005433613487	654DFD	8342 662639	RAISA SMIRNOVA	{"email": "r.smirnova.23041963@postgrespro.ru", "phone": "+70937928461"}
0005433613488	55D7DF	1473 344870	MARIYA VOLKOVA	{"email": "volkova.m_1985@postgrespro.ru", "phone": "+70403807075"}
0005433613489	55D7DF	6422 368002	SERGEY VASILEV	{"email": "vasilev_s-1971@postgrespro.ru", "phone": "+70538222983"}
0005433613490	6E82BD	8155 777265	ALEKSEY DENISOV	{"phone": "+70621448952"}
0005433613491	C64AC1	9021 992412	NATALYA SCHERBAKOVA	{"email": "natalyascherbakova_1966@postgrespro.ru", "phone": "+70204769664"}
0005433613492	C64AC1	9059 048734	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey_1976@postgrespro.ru", "phone": "+70201725722"}
0005433613493	942280	9309 864607	ALEKSEY BELOV	{"email": "aleksey.belov-121975@postgrespro.ru", "phone": "+70968973174"}
0005433613494	942280	2046 213714	TATYANA KALININA	{"email": "kalinina_tatyana-03031970@postgrespro.ru", "phone": "+70301695453"}
0005433613495	942280	2951 740726	RIMMA KULIKOVA	{"email": "kulikovar_041968@postgrespro.ru", "phone": "+70800258594"}
0005433613496	790C47	2837 267476	ALEKSEY KARPOV	{"email": "akarpov_071969@postgrespro.ru", "phone": "+70048898882"}
0005433613497	10D373	7520 488156	DMITRIY SERGEEV	{"phone": "+70454971368"}
0005433613498	A6C48A	1925 225264	PAVEL SHEVCHENKO	{"phone": "+70333528668"}
0005433613499	A6C48A	2684 928444	GALINA GUSEVA	{"email": "guseva.galina1983@postgrespro.ru", "phone": "+70021418992"}
0005433613500	6C1C45	4760 233332	SERGEY KISELEV	{"email": "skiselev_05111981@postgrespro.ru", "phone": "+70583509163"}
0005433613501	6C1C45	0384 684241	YANA PETROVA	{"phone": "+70411218037"}
0005433613502	D56576	7474 403950	NATALYA POPOVA	{"email": "popova_n-051973@postgrespro.ru", "phone": "+70193774502"}
0005433613503	D64831	9938 561786	MARIYA ZAYCEVA	{"email": "m-zayceva-1973@postgrespro.ru", "phone": "+70434801505"}
0005433613504	2BC266	8303 434497	TAMARA GORBUNOVA	{"email": "gorbunova-tamara_19011967@postgrespro.ru", "phone": "+70470348773"}
0005433613505	BEC633	5850 519755	ALEKSANDR RODIONOV	{"phone": "+70523659015"}
0005433613506	02D753	0413 761788	OLGA SMIRNOVA	{"email": "olga-smirnova-13101970@postgrespro.ru", "phone": "+70339413004"}
0005433613507	02D753	5846 138685	SERGEY BORISOV	{"email": "sborisov.01111970@postgrespro.ru", "phone": "+70038171303"}
0005433613508	A90401	2041 006273	NATALIYA ALEKSANDROVA	{"phone": "+70964965839"}
0005433613509	A90401	3667 665448	YURIY GORBUNOV	{"email": "gorbunov_y_09041981@postgrespro.ru", "phone": "+70159470860"}
0005433613510	EFC570	0611 119696	YULIYA PETROVA	{"email": "petrovay_121984@postgrespro.ru", "phone": "+70856001362"}
0005433613511	D19B0C	4851 175597	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana_20031968@postgrespro.ru", "phone": "+70353125158"}
0005433613512	D19B0C	5731 586106	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_08101967@postgrespro.ru", "phone": "+70528043949"}
0005433613513	B42810	1380 959632	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova041982@postgrespro.ru", "phone": "+70629314768"}
0005433613514	B42810	3403 115877	NINA BELYAEVA	{"email": "ninabelyaeva_1988@postgrespro.ru", "phone": "+70406127011"}
0005433613515	0CF4A5	1824 277377	MARIYA ZHURAVLEVA	{"phone": "+70366929438"}
0005433613516	0E116D	6246 318378	DARYA TIMOFEEVA	{"email": "d.timofeeva_1972@postgrespro.ru", "phone": "+70225161033"}
0005433613517	7E532D	2320 657364	LIDIYA SERGEEVA	{"email": "lidiya-sergeeva.04091978@postgrespro.ru", "phone": "+70427160295"}
0005433613518	AD43A7	6588 995506	ROMAN FILIPPOV	{"phone": "+70078084507"}
0005433613519	AD43A7	8573 520040	VIKTOR NOVIKOV	{"email": "v_novikov03051961@postgrespro.ru", "phone": "+70868327331"}
0005433613520	D31916	1935 299084	EKATERINA EFIMOVA	{"email": "efimova-ekaterina_081983@postgrespro.ru", "phone": "+70745350759"}
0005433613521	EE3E90	8510 810264	NADEZHDA TITOVA	{"phone": "+70952939887"}
0005433613522	E1831B	2771 144123	OKSANA ANDREEVA	{"phone": "+70066764158"}
0005433613523	E1831B	0646 457410	EVGENIY MAKAROV	{"email": "emakarov-1984@postgrespro.ru", "phone": "+70080584701"}
0005433613524	62A59D	5685 048513	VLADISLAV NOVIKOV	{"email": "novikov-vladislav_1966@postgrespro.ru", "phone": "+70007346610"}
0005433613525	62A59D	3377 649164	YURIY PETROV	{"email": "petrov.yuriy.21111970@postgrespro.ru", "phone": "+70015318556"}
0005433613526	00CF2F	6846 945265	SVETLANA FEDOROVA	{"email": "fedorova.s-091974@postgrespro.ru", "phone": "+70962641021"}
0005433613527	A7F06C	9820 457926	NIKOLAY ABRAMOV	{"phone": "+70758776971"}
0005433613528	F07488	1914 165453	ALENA RODIONOVA	{"phone": "+70568373839"}
0005433613529	AA2DB2	6361 461251	YURIY TIMOFEEV	{"phone": "+70349266193"}
0005433613530	B51B27	3268 714855	EVGENIY MAKAROV	{"phone": "+70825137030"}
0005433613531	E6136F	2214 276370	VITALIY TARASOV	{"email": "vitaliytarasov-031968@postgrespro.ru", "phone": "+70087911710"}
0005433613532	355778	7983 333144	VALENTINA ZHUKOVA	{"email": "zhukova_v-1972@postgrespro.ru", "phone": "+70466786648"}
0005433613533	355778	0719 566148	SERGEY EGOROV	{"email": "egorov.sergey-1977@postgrespro.ru", "phone": "+70600592754"}
0005433613534	927A97	5064 041656	EVGENIY MATVEEV	{"phone": "+70533501308"}
0005433613535	3ECF9E	5553 040177	VLADIMIR VOLKOV	{"phone": "+70245746720"}
0005433613536	3773B0	9217 935026	EVGENIY GAVRILOV	{"phone": "+70659960455"}
0005433613537	3773B0	1221 741298	ELENA VOLKOVA	{"email": "volkova_elena-14021971@postgrespro.ru", "phone": "+70234395230"}
0005433613538	3DBFCE	7152 173272	ELLA SOKOLOVA	{"email": "sokolovae02121973@postgrespro.ru", "phone": "+70426328006"}
0005433613539	87D2C8	5500 764148	VLADIMIR PAVLOV	{"email": "vladimirpavlov_15031985@postgrespro.ru", "phone": "+70288798794"}
0005433613540	87D2C8	9567 786770	PETR KOZLOV	{"email": "kozlov-p_12061975@postgrespro.ru", "phone": "+70628639829"}
0005433613541	63DDF3	1757 391695	EKATERINA ORLOVA	{"email": "eorlova.1972@postgrespro.ru", "phone": "+70847836599"}
0005433613542	63DDF3	3808 072162	DANIYA YAKOVLEVA	{"email": "yakovleva-d061969@postgrespro.ru", "phone": "+70116420993"}
0005433613543	63DDF3	8721 421816	SERGEY BARANOV	{"phone": "+70247091385"}
0005433613544	C21E85	4524 253512	YURIY BARANOV	{"phone": "+70925060979"}
0005433613545	C776B9	3003 971787	LYUBOV MAKSIMOVA	{"email": "maksimova_l.1971@postgrespro.ru", "phone": "+70595615889"}
0005433613546	C776B9	5920 434113	ELMIRA ABRAMOVA	{"phone": "+70484605656"}
0005433613547	6DD862	9781 136355	KLAVDIYA ALEKSEEVA	{"email": "k_alekseeva_1962@postgrespro.ru", "phone": "+70960981853"}
0005433613548	CDEFE6	0027 567541	ANDREY ORLOV	{"phone": "+70187504419"}
0005433613549	8548D6	8411 632909	ELENA DAVYDOVA	{"email": "davydova_elena-31011983@postgrespro.ru", "phone": "+70186014192"}
0005433613550	B0BCFB	9993 685976	TAMARA MELNIKOVA	{"email": "tamara-melnikova1970@postgrespro.ru", "phone": "+70177887229"}
0005433613551	59A88D	9556 816092	ZINAIDA KOROLEVA	{"phone": "+70973530238"}
0005433613552	1A08D3	0779 110390	IGOR EGOROV	{"phone": "+70547969059"}
0005433613553	1A08D3	2707 728891	ANNA KOROLEVA	{"phone": "+70299667565"}
0005433613554	9C38E6	7248 513721	NATALYA NIKIFOROVA	{"phone": "+70247735273"}
0005433613555	8DA59B	8622 456455	GERMAN NIKOLAEV	{"phone": "+70481085569"}
0005433613556	82D31C	2037 066188	ANDREY MELNIKOV	{"phone": "+70608419416"}
0005433613557	C8B461	2581 198980	MARINA MOROZOVA	{"email": "marina-morozova-1959@postgrespro.ru", "phone": "+70830506141"}
0005433613558	9F746F	2282 584969	ANATOLIY SCHERBAKOV	{"phone": "+70946169666"}
0005433613559	AB0C85	7584 370711	ELENA ALEKSANDROVA	{"phone": "+70301937878"}
0005433613560	36133B	2937 180656	VLADIMIR OSIPOV	{"email": "vladimir.osipov_071967@postgrespro.ru", "phone": "+70862281000"}
0005433613561	A71D27	2132 849304	SERGEY MARTYNOV	{"phone": "+70815124709"}
0005433613562	A71D27	7349 702857	VITALIY ZAYCEV	{"email": "vitaliy_zaycev.18091971@postgrespro.ru", "phone": "+70137357052"}
0005433613563	FE00C9	0252 998537	SVETLANA SOROKINA	{"phone": "+70362809959"}
0005433613564	FE00C9	9640 349583	VSEVOLOD ANDREEV	{"phone": "+70826352928"}
0005433613565	FE00C9	6628 777432	RAISA KARPOVA	{"phone": "+70039213526"}
0005433613566	C6CE72	4968 164437	MAKSIM SOROKIN	{"email": "sorokinm-16121966@postgrespro.ru", "phone": "+70073805590"}
0005433613567	C6CE72	2387 663525	YULIYA TIMOFEEVA	{"email": "timofeeva-yuliya-1960@postgrespro.ru", "phone": "+70190758731"}
0005433613568	0B25C5	6275 600706	FEDOR GAVRILOV	{"email": "fgavrilov1970@postgrespro.ru", "phone": "+70101540898"}
0005433613569	0B25C5	5967 094432	VYACHESLAV SIDOROV	{"phone": "+70854925939"}
0005433613570	2B656A	4297 827072	OLEG TIKHONOV	{"phone": "+70589338000"}
0005433613571	2B656A	2387 450591	ALEKSANDR SOROKIN	{"phone": "+70559880994"}
0005433613572	CE0E7B	1022 811915	ELENA EFREMOVA	{"email": "efremovaelena121963@postgrespro.ru", "phone": "+70655010685"}
0005433613573	75C059	2124 603444	GENNADIY SEMENOV	{"phone": "+70967961441"}
0005433613574	DA10C9	7598 713059	ALEKSANDR NIKITIN	{"phone": "+70543409773"}
0005433613575	6BA483	8461 549494	SERGEY MATVEEV	{"email": "matveev_s-021968@postgrespro.ru", "phone": "+70115321192"}
0005433613576	B77FB0	4600 100437	IRAIDA ANTONOVA	{"email": "antonova_iraida-10071967@postgrespro.ru", "phone": "+70497256682"}
0005433613577	B77FB0	4588 912663	ANNA PETROVA	{"email": "petrova-anna_23061967@postgrespro.ru", "phone": "+70023843538"}
0005433613578	B77FB0	4408 044284	ELVIRA KUZMINA	{"email": "ekuzmina.111977@postgrespro.ru", "phone": "+70585517240"}
0005433613579	D48F54	9849 052584	DMITRIY NIKITIN	{"email": "nikitin.dmitriy_1974@postgrespro.ru", "phone": "+70596679112"}
0005433613580	7A04EC	5343 011158	ALEKSEY IVANOV	{"email": "a-ivanov.121967@postgrespro.ru", "phone": "+70572703735"}
0005433613581	7A04EC	2260 032581	DIANA VOROBEVA	{"email": "vorobeva-diana-121969@postgrespro.ru", "phone": "+70722896723"}
0005433613582	34513F	5691 068301	ALEKSANDR VASILEV	{"phone": "+70901170818"}
0005433613583	7DD878	6728 568634	KIRILL MIKHAYLOV	{"email": "kirillmikhaylov-24041970@postgrespro.ru", "phone": "+70182776815"}
0005433613584	9AFC91	7010 566686	ILYA VLASOV	{"email": "vlasov_ilya28011967@postgrespro.ru", "phone": "+70493098992"}
0005433613585	9AFC91	4269 092282	ILYA MELNIKOV	{"phone": "+70291947680"}
0005433613586	F44003	0422 490412	VLADIMIR NIKOLAEV	{"email": "nikolaev_v_081968@postgrespro.ru", "phone": "+70900077242"}
0005433613587	5FDCB1	5688 513958	ANASTASIYA VOLKOVA	{"email": "anastasiyavolkova13121971@postgrespro.ru", "phone": "+70783311526"}
0005433613588	5FDCB1	0929 990028	OLGA FADEEVA	{"phone": "+70947523001"}
0005433613589	10F113	6172 029157	NATALYA NIKIFOROVA	{"email": "nikiforova-n_1978@postgrespro.ru", "phone": "+70784402550"}
0005433613590	10F113	7967 239350	NADEZHDA FILIPPOVA	{"phone": "+70043766870"}
0005433613591	D16D8A	3413 455168	ALEKSANDR MATVEEV	{"phone": "+70222682782"}
0005433613592	04A5E2	0854 559100	ALEKSANDR ABRAMOV	{"phone": "+70373924390"}
0005433613593	D4740B	0758 606178	LYUDMILA BORISOVA	{"email": "borisova-lyudmila.1977@postgrespro.ru", "phone": "+70805967693"}
0005433613594	D4740B	2064 315787	EVGENIY IVANOV	{"email": "ivanov.e_1977@postgrespro.ru", "phone": "+70809224427"}
0005433613595	EE858B	1268 290547	AZAT ZAYCEV	{"email": "azaycev-25041971@postgrespro.ru", "phone": "+70218305977"}
0005433613596	CA4ECB	6508 560205	VALERIYA FROLOVA	{"phone": "+70359222668"}
0005433613597	CA4ECB	5779 684686	SERGEY NIKITIN	{"email": "sergey.nikitin121972@postgrespro.ru", "phone": "+70165526911"}
0005433613598	CA4ECB	3708 054963	VLADIMIR FOMIN	{"phone": "+70661537827"}
0005433613599	3E2D6F	0068 357051	VALENTINA IVANOVA	{"phone": "+70433214512"}
0005433613600	3E2D6F	1102 736432	ROMAN KISELEV	{"email": "kiselev-roman11081973@postgrespro.ru", "phone": "+70332941341"}
0005433613601	D335E9	2143 965102	TAMARA SEMENOVA	{"phone": "+70773815144"}
0005433613602	FD6AAA	2813 416893	EVGENIYA SMIRNOVA	{"email": "smirnova-e1974@postgrespro.ru", "phone": "+70657982385"}
0005433613603	D568F7	7384 904062	ANNA IVANOVA	{"email": "a.ivanova1983@postgrespro.ru", "phone": "+70404458826"}
0005433613604	D568F7	5189 192739	GEORGIY SEMENOV	{"phone": "+70915661241"}
0005433613605	715C53	3414 052156	TATYANA SEMENOVA	{"phone": "+70377088009"}
0005433613606	715C53	1033 595419	VLADIMIR MATVEEV	{"phone": "+70521073021"}
0005433613607	35A33D	7454 460363	ANASTASIYA MOISEEVA	{"phone": "+70404678789"}
0005433613608	C05CEC	6991 063346	NADEZHDA SOKOLOVA	{"email": "n-sokolova.1966@postgrespro.ru", "phone": "+70372533991"}
0005433613609	C05CEC	2451 400789	RUSTAM TIMOFEEV	{"email": "timofeev-rustam-1979@postgrespro.ru", "phone": "+70074481879"}
0005433613610	571150	6159 818812	ANDREY MIRONOV	{"email": "andrey.mironov-071973@postgrespro.ru", "phone": "+70119500628"}
0005433613611	8641CC	4999 519669	ANNA ANISIMOVA	{"email": "a.anisimova-011965@postgrespro.ru", "phone": "+70677705080"}
0005433613612	8641CC	0233 636441	ALEKSEY GERASIMOV	{"phone": "+70623336602"}
0005433613613	BC448E	5899 652431	ZHANNA MELNIKOVA	{"phone": "+70425465438"}
0005433613614	BC448E	6793 496357	ROMAN VASILEV	{"phone": "+70064911284"}
0005433613615	410371	9511 148635	ELENA KISELEVA	{"email": "kiseleva-e_03091971@postgrespro.ru", "phone": "+70701656047"}
0005433613616	E4A4B3	5366 669286	SERGEY MELNIKOV	{"email": "smelnikov_1971@postgrespro.ru", "phone": "+70176730077"}
0005433613617	9B1CB4	5223 530079	GALINA KOROLEVA	{"email": "g.koroleva_1971@postgrespro.ru", "phone": "+70573501847"}
0005433613618	57021C	8109 721213	VIKTOR VLASOV	{"email": "vlasov_viktor1968@postgrespro.ru", "phone": "+70186761538"}
0005433613619	243881	8570 971657	POLINA TARASOVA	{"email": "p_tarasova22021963@postgrespro.ru", "phone": "+70447254004"}
0005433613620	243881	2478 976539	MARIYA CHERNOVA	{"phone": "+70167849282"}
0005433613621	C9B760	2927 991735	IRINA KRASNOVA	{"email": "i-krasnova_011976@postgrespro.ru", "phone": "+70895995562"}
0005433613622	C9B760	6509 078627	ANNA ZAYCEVA	{"phone": "+70054034157"}
0005433613623	B0E50B	7273 790111	VERA ARKHIPOVA	{"phone": "+70365552243"}
0005433613624	CC74B5	5392 299876	ARINA MAKAROVA	{"email": "makarova_arina.22061960@postgrespro.ru", "phone": "+70885443600"}
0005433613625	CC74B5	4732 225716	ILYA KUDRYASHOV	{"email": "kudryashov-ilya-05121959@postgrespro.ru", "phone": "+70009868220"}
0005433613626	B40BDF	2085 881041	VALENTINA STEPANOVA	{"email": "valentina_stepanova.021977@postgrespro.ru", "phone": "+70346245410"}
0005433613627	B40BDF	6499 818094	TATYANA STEPANOVA	{"email": "stepanova.tatyana.061968@postgrespro.ru", "phone": "+70340033857"}
0005433613628	5D146B	8739 346168	SERGEY IVANOV	{"email": "s.ivanov-18091975@postgrespro.ru", "phone": "+70420834172"}
0005433613629	7EFCE8	3737 370305	TATYANA SIDOROVA	{"phone": "+70146121443"}
0005433613630	7EFCE8	0285 169399	LYUBOV KONOVALOVA	{"email": "lkonovalova.061971@postgrespro.ru", "phone": "+70375588493"}
0005433613631	85FD50	2817 116251	ALEKSANDR KARPOV	{"phone": "+70972133331"}
0005433613632	85FD50	8134 643802	NIKITA FROLOV	{"phone": "+70339399794"}
0005433613633	2CAAC3	7765 797851	GENNADIY FOMIN	{"email": "foming-011967@postgrespro.ru", "phone": "+70282410029"}
0005433613634	20C5DD	9050 969007	SVETLANA MIKHAYLOVA	{"phone": "+70185286927"}
0005433613635	20C5DD	9602 815048	OLEG KUZNECOV	{"phone": "+70965372054"}
0005433613636	F25435	7718 472776	ALEKSANDR PETROV	{"email": "petrov_a-29121962@postgrespro.ru", "phone": "+70136360399"}
0005433613637	E4AB04	0210 521998	ALEKSANDRA KUZMINA	{"email": "aleksandra.kuzmina-1971@postgrespro.ru", "phone": "+70848056957"}
0005433613638	E4AB04	0505 818352	VYACHESLAV ROMANOV	{"email": "romanovv1973@postgrespro.ru", "phone": "+70620663188"}
0005433613639	1D9E7E	9729 137029	IRINA ILINA	{"email": "i-ilina_061985@postgrespro.ru", "phone": "+70986941744"}
0005433613640	1D9E7E	5296 344030	NIKOLAY BELOV	{"phone": "+70292790159"}
0005433613641	1D9E7E	9869 843155	EVGENIY KULIKOV	{"email": "kulikov-evgeniy_15071979@postgrespro.ru", "phone": "+70397218601"}
0005433613642	D2187E	2314 679374	TATYANA ZAYCEVA	{"phone": "+70216579231"}
0005433613643	024F31	7307 355741	MARIYA KISELEVA	{"phone": "+70572438396"}
0005433613644	ED614D	0531 686292	GENNADIY VOLKOV	{"email": "gennadiyvolkov_19091979@postgrespro.ru", "phone": "+70400590826"}
0005433613645	13ECB7	1485 154260	OLGA CHERNOVA	{"email": "chernova-olga.17081976@postgrespro.ru", "phone": "+70912072871"}
0005433613646	13ECB7	9368 452190	ALEKSEY GAVRILOV	{"phone": "+70727797159"}
0005433613647	13ECB7	7338 413801	GALINA ILINA	{"phone": "+70112484753"}
0005433613648	EB9089	4190 214168	NINA DAVYDOVA	{"phone": "+70239628849"}
0005433613649	EB9089	7344 245811	ANNA KUZNECOVA	{"email": "kuznecova_a-15041984@postgrespro.ru", "phone": "+70302546437"}
0005433613650	EB9089	6613 164160	ELDAR FILIPPOV	{"phone": "+70873273840"}
0005433613651	FEB58D	8381 022425	ANDREY NIKITIN	{"email": "nikitin.a-061967@postgrespro.ru", "phone": "+70964266813"}
0005433613652	509AAA	0512 092723	ZAKHAR TIMOFEEV	{"email": "timofeevzakhar.06111981@postgrespro.ru", "phone": "+70758132125"}
0005433613653	509AAA	8998 837766	OLGA VASILEVA	{"phone": "+70876917911"}
0005433613654	364FAC	7209 864536	NATALYA IVANOVA	{"email": "n_ivanova1966@postgrespro.ru", "phone": "+70033017356"}
0005433613655	56F20F	2626 813492	IRINA SAVELEVA	{"email": "irina_saveleva051974@postgrespro.ru", "phone": "+70369193243"}
0005433613656	61DEC3	3812 273026	ALEKSANDR ALEKSANDROV	{"phone": "+70559936046"}
0005433613657	79D98E	0185 658110	OLGA EGOROVA	{"phone": "+70196836846"}
0005433613658	406D6E	5252 516395	GALINA EGOROVA	{"email": "egorova.galina-051971@postgrespro.ru", "phone": "+70057703317"}
0005433613659	CDECD9	1100 324184	TAMARA SCHERBAKOVA	{"phone": "+70497572646"}
0005433613660	F4F816	4833 111035	DMITRIY YAKOVLEV	{"email": "yakovlevdmitriy-26091971@postgrespro.ru", "phone": "+70344578275"}
0005433613661	3403FE	0695 142744	MARIYA KUZNECOVA	{"email": "mariya.kuznecova_31121968@postgrespro.ru", "phone": "+70813498125"}
0005433613662	F31FA9	9311 568780	ALEKSANDR KUZNECOV	{"phone": "+70649711895"}
0005433613663	F31FA9	1955 399383	EVGENIY NIKITIN	{"email": "nikitin-e-27011984@postgrespro.ru", "phone": "+70438806606"}
0005433613664	F31FA9	2668 728188	ANNA MEDVEDEVA	{"email": "a-medvedeva011977@postgrespro.ru", "phone": "+70790597606"}
0005433613665	927838	8901 909065	POLINA GORBUNOVA	{"phone": "+70066894287"}
0005433613666	927838	8194 827083	LYUDMILA ANDREEVA	{"phone": "+70563678423"}
0005433613667	A440B8	2481 156811	VLADIMIR KULIKOV	{"phone": "+70816502597"}
0005433613668	D793AE	9387 565327	ZOYA RODIONOVA	{"email": "z-rodionova.1966@postgrespro.ru", "phone": "+70671703276"}
0005433613669	8CFE05	2058 578042	ALEKSANDR SHEVCHENKO	{"phone": "+70824218041"}
0005433613670	D8B957	6515 361108	VLADIMIR NOVIKOV	{"phone": "+70105025949"}
0005433613671	C79EFD	3893 171405	SERGEY NIKITIN	{"phone": "+70853114132"}
0005433613672	E4D89D	8755 788485	ANNA ORLOVA	{"email": "aorlova_1965@postgrespro.ru", "phone": "+70567249260"}
0005433613673	562113	2030 769590	VALERIYA KOROLEVA	{"phone": "+70168958580"}
0005433613674	2FCA04	3819 311754	ANDREY POPOV	{"email": "popov_a-1970@postgrespro.ru", "phone": "+70169576913"}
0005433613675	2FCA04	0938 229712	NINA FEDOROVA	{"phone": "+70099709584"}
0005433613676	DD0E3A	3262 660732	NIKOLAY ISAEV	{"email": "n.isaev.11111976@postgrespro.ru", "phone": "+70731749158"}
0005433613677	C44C25	6696 009294	YULIYA PAVLOVA	{"phone": "+70688362235"}
0005433613678	0CC80C	7347 341445	YULIYA FOMINA	{"phone": "+70358519700"}
0005433613679	0B67B2	5706 153386	VITALIY ANDREEV	{"phone": "+70444615602"}
0005433613680	D51060	5687 891001	VALENTINA FROLOVA	{"phone": "+70224124903"}
0005433613681	74C89E	4384 600884	VADIM MIKHAYLOV	{"email": "v.mikhaylov.30101971@postgrespro.ru", "phone": "+70864812264"}
0005433613682	74C89E	6562 307635	ALEKSANDRA POPOVA	{"email": "popova.a24031975@postgrespro.ru", "phone": "+70576410790"}
0005433613683	E485D5	9209 989603	OLEG IVANOV	{"email": "ivanovo16101966@postgrespro.ru", "phone": "+70481686428"}
0005433613684	E485D5	7545 686342	OLGA ILINA	{"email": "olga-ilina.1979@postgrespro.ru", "phone": "+70825074972"}
0005433613685	C807F3	7486 807795	ALEKSANDR ROMANOV	{"phone": "+70884590675"}
0005433613686	C807F3	8774 265629	ANNA EFREMOVA	{"phone": "+70084578016"}
0005433613687	C10552	2156 459618	FEDOR KOZLOV	{"email": "f_kozlov1966@postgrespro.ru", "phone": "+70397096984"}
0005433613688	C10552	5787 595595	NIKOLAY KISELEV	{"email": "kiselevn.07081984@postgrespro.ru", "phone": "+70424612255"}
0005433613689	C10552	4291 653710	SERGEY IVANOV	{"email": "sergeyivanov_1972@postgrespro.ru", "phone": "+70570251501"}
0005433613690	353955	4931 956487	VLADIMIR POPOV	{"phone": "+70963377438"}
0005433613691	348099	9585 714285	ELIZAVETA NAUMOVA	{"phone": "+70740352245"}
0005433613692	99076E	6125 090411	GALINA POLYAKOVA	{"email": "g_polyakova-1970@postgrespro.ru", "phone": "+70237524413"}
0005433613693	99076E	7614 087480	IGOR STEPANOV	{"email": "stepanovi-22121978@postgrespro.ru", "phone": "+70917025006"}
0005433613694	4E5E5E	5050 694571	ANTONINA GORBUNOVA	{"phone": "+70105140099"}
0005433613695	4E5E5E	6811 989685	ALEKSANDR SEMENOV	{"email": "asemenov.1967@postgrespro.ru", "phone": "+70286069193"}
0005433613696	6E89D3	6460 081681	NINEL ZAKHAROVA	{"phone": "+70064624123"}
0005433613697	9329F4	1284 732156	LYUDMILA VASILEVA	{"email": "l-vasileva1970@postgrespro.ru", "phone": "+70760587143"}
0005433613698	85359C	4218 925306	NIKOLAY YAKOVLEV	{"email": "nikolayyakovlev.091972@postgrespro.ru", "phone": "+70089301272"}
0005433613699	11B73C	1626 266975	VASILIY ABRAMOV	{"phone": "+70242891800"}
0005433613700	DF71B1	7893 605909	EDUARD MEDVEDEV	{"phone": "+70180144009"}
0005433613701	CA6212	4732 237555	SVETLANA PETROVA	{"email": "petrovasvetlana.28011970@postgrespro.ru", "phone": "+70598008974"}
0005433613702	CA6212	4536 678884	ELENA KONOVALOVA	{"phone": "+70538335062"}
0005433613703	4311BB	9069 563699	ANDREY FOMIN	{"phone": "+70655981349"}
0005433613704	BA8D8A	0031 600984	NATALYA ALEKSANDROVA	{"email": "aleksandrova_natalya-1971@postgrespro.ru", "phone": "+70889850050"}
0005433613705	75EF73	9254 006142	TATYANA FILIPPOVA	{"phone": "+70384157421"}
0005433613706	245816	5023 520714	NATALYA FROLOVA	{"email": "n_frolova-11071965@postgrespro.ru", "phone": "+70252161697"}
0005433613707	6E5601	5116 998046	SERGEY SERGEEV	{"email": "s.sergeev.101972@postgrespro.ru", "phone": "+70542035963"}
0005433613708	6E5601	4955 287060	NINA MEDVEDEVA	{"email": "medvedeva_nina-30111961@postgrespro.ru", "phone": "+70787296910"}
0005433613709	6E5601	6461 875492	RUSTAM DENISOV	{"email": "r_denisov_011975@postgrespro.ru", "phone": "+70365927234"}
0005433613710	7715AC	2748 989290	MARIYA DENISOVA	{"email": "denisovamariya.011985@postgrespro.ru", "phone": "+70493924734"}
0005433613711	B538B9	2337 571012	TATYANA MIKHAYLOVA	{"email": "t-mikhaylova.03051968@postgrespro.ru", "phone": "+70923475497"}
0005433613712	B538B9	0240 023491	VIKTOR DENISOV	{"phone": "+70560462738"}
0005433613713	732403	5387 809697	ANATOLIY SAVELEV	{"email": "saveleva-05111974@postgrespro.ru", "phone": "+70573104150"}
0005433613714	732403	9378 250533	ALI SOKOLOV	{"email": "alisokolov.11051980@postgrespro.ru", "phone": "+70362587322"}
0005433613715	732403	0008 780854	MARGARITA ROMANOVA	{"email": "romanova-m.1971@postgrespro.ru", "phone": "+70246825538"}
0005433613716	A8330E	1496 285449	ALEKSANDR PETROV	{"email": "petrov.a.081972@postgrespro.ru", "phone": "+70343230422"}
0005433613717	AA2B6A	7163 061274	TAMARA KALININA	{"email": "tamara_kalinina.29051967@postgrespro.ru", "phone": "+70065304241"}
0005433613718	AA2B6A	7203 429132	NAILYA KULIKOVA	{"phone": "+70273923626"}
0005433613719	BF4F39	0410 776055	SVETLANA POTAPOVA	{"email": "potapovasvetlana06061976@postgrespro.ru", "phone": "+70409248428"}
0005433613720	BF4F39	1376 166963	LYUBOV BELYAEVA	{"email": "belyaeva.lyubov031969@postgrespro.ru", "phone": "+70767402374"}
0005433613721	ECDDB8	7309 006693	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov16051968@postgrespro.ru", "phone": "+70799623325"}
0005433613722	E6DACD	3983 944249	ANTON BORISOV	{"phone": "+70809329433"}
0005433613723	E6DACD	2308 037086	SERGEY SMIRNOV	{"email": "ssmirnov_041974@postgrespro.ru", "phone": "+70166743532"}
0005433613724	E6DACD	2557 106390	IVAN KUZNECOV	{"email": "kuznecovivan-091970@postgrespro.ru", "phone": "+70392518822"}
0005433613725	182D18	2716 244335	NADEZHDA SOKOLOVA	{"phone": "+70016035185"}
0005433613726	02F372	8308 896217	NADEZHDA SAVELEVA	{"phone": "+70300203812"}
0005433613727	0ED8E1	3082 459070	LEV DMITRIEV	{"email": "dmitriev-lev_08051968@postgrespro.ru", "phone": "+70119498583"}
0005433613728	FA6D30	1849 057613	SERGEY NIKOLAEV	{"phone": "+70587285805"}
0005433613729	FA6D30	5513 314020	LYUBOV ALEKSANDROVA	{"phone": "+70611427946"}
0005433613730	E467B1	9174 133360	ANATOLIY ANTONOV	{"phone": "+70793831051"}
0005433613731	E467B1	7230 716486	ROMAN BORISOV	{"phone": "+70563679392"}
0005433613732	553C84	8496 247864	ANATOLIY POPOV	{"phone": "+70825838454"}
0005433613733	6B7714	0564 459067	ANNA POPOVA	{"email": "anna_popova_29011971@postgrespro.ru", "phone": "+70484423896"}
0005433613734	1B478B	9883 868187	YURIY ROMANOV	{"email": "yuriyromanov.1980@postgrespro.ru", "phone": "+70969718412"}
0005433613735	060673	3332 660073	YANA VASILEVA	{"email": "yana.vasileva_1962@postgrespro.ru", "phone": "+70781540424"}
0005433613736	286D36	4894 027529	LARISA YAKOVLEVA	{"email": "yakovlevalarisa_29121969@postgrespro.ru", "phone": "+70031931012"}
0005433613737	6AF337	7528 479708	TATYANA SOKOLOVA	{"phone": "+70147383255"}
0005433613738	91D4D3	6429 702540	ALINA SOROKINA	{"email": "alinasorokina-13041975@postgrespro.ru", "phone": "+70247476521"}
0005433613739	C2B1C3	5593 360838	DARYA ALEKSEEVA	{"phone": "+70765257640"}
0005433613740	C2B1C3	2891 846417	SVETLANA TIMOFEEVA	{"phone": "+70258079058"}
0005433613741	0F29CC	4111 234073	VIKTOR MATVEEV	{"email": "matveev-viktor-17021984@postgrespro.ru", "phone": "+70292680462"}
0005433613742	0F29CC	5839 887577	LEONID PETROV	{"phone": "+70732404268"}
0005433613743	7B60B0	2258 484196	NADEZHDA LEBEDEVA	{"email": "n.lebedeva_02091982@postgrespro.ru", "phone": "+70832035757"}
0005433613744	F6B605	8597 387868	VIKTOR ABRAMOV	{"phone": "+70779141417"}
0005433613745	C52EB3	1698 397086	VALENTINA FROLOVA	{"email": "valentina.frolova.051976@postgrespro.ru", "phone": "+70180864318"}
0005433613746	EF349C	1516 356358	NIKITA STEPANOV	{"phone": "+70087203397"}
0005433613747	EF349C	2954 004540	YAROSLAV IVANOV	{"phone": "+70993114737"}
0005433613748	EF349C	6379 238225	SEMEN SERGEEV	{"phone": "+70204650371"}
0005433613749	7CE02A	5296 072041	OLEG MATVEEV	{"email": "omatveev031974@postgrespro.ru", "phone": "+70584897021"}
0005433613750	5A066A	2126 725883	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov-061967@postgrespro.ru", "phone": "+70141278731"}
0005433613751	C8B9ED	9246 961736	ZINAIDA KRASNOVA	{"email": "zinaida-krasnova_01081980@postgrespro.ru", "phone": "+70437500279"}
0005433613752	78C90C	1559 658804	IRINA ERMAKOVA	{"email": "iermakova_041975@postgrespro.ru", "phone": "+70448134575"}
0005433613753	25EEFD	2225 302955	ALEKSANDR MELNIKOV	{"email": "melnikova-1971@postgrespro.ru", "phone": "+70373366360"}
0005433613754	3BCC9A	0236 111056	SERGEY KISELEV	{"email": "kiselev-sergey.111975@postgrespro.ru", "phone": "+70952915158"}
0005433613755	F5E2DD	9233 451217	VLADISLAV MIKHAYLOV	{"email": "mikhaylov-vladislav_021975@postgrespro.ru", "phone": "+70225517042"}
0005433613756	4A7176	7875 083952	MIKHAIL SOKOLOV	{"email": "mikhail_sokolov-31081972@postgrespro.ru", "phone": "+70064073399"}
0005433613757	DE82E0	0771 875501	KSENIYA NAZAROVA	{"email": "nazarova.k1966@postgrespro.ru", "phone": "+70954102705"}
0005433613758	44EDE5	6646 472801	YURIY ROMANOV	{"email": "romanov-yuriy.30101970@postgrespro.ru", "phone": "+70952591996"}
0005433613759	E38E58	0051 285177	NINA OVCHINNIKOVA	{"email": "n_ovchinnikova091983@postgrespro.ru", "phone": "+70183250265"}
0005433613760	E38E58	6438 313500	NINA BOGDANOVA	{"phone": "+70311181691"}
0005433613761	25270D	8994 097319	TATYANA PETROVA	{"phone": "+70780149627"}
0005433613762	E9B109	1804 838387	ALEKSANDR SERGEEV	{"email": "a.sergeev_111966@postgrespro.ru", "phone": "+70485525962"}
0005433613763	E9B109	8855 137214	DARYA ILINA	{"email": "ilina.d1967@postgrespro.ru", "phone": "+70713435742"}
0005433613932	7DE06C	8723 117241	VALENTINA NIKITINA	{"phone": "+70253616407"}
0005433613764	336753	1914 055614	MARIYA FEDOROVA	{"email": "m_fedorova081976@postgrespro.ru", "phone": "+70870881368"}
0005433613765	723263	0591 123321	DANILA VOLKOV	{"email": "d_volkov24081975@postgrespro.ru", "phone": "+70237981477"}
0005433613766	59BB43	1738 091632	KSENIYA FADEEVA	{"email": "k_fadeeva111971@postgrespro.ru", "phone": "+70900566371"}
0005433613767	59BB43	7245 359663	EVGENIY NIKITIN	{"phone": "+70425944771"}
0005433613768	59BB43	2754 212769	ARTEM ORLOV	{"phone": "+70124982180"}
0005433613769	91DF38	2250 352825	NADEZHDA MIRONOVA	{"phone": "+70993782440"}
0005433613770	234EA2	1758 261181	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr.081961@postgrespro.ru", "phone": "+70306464089"}
0005433613771	EDDD21	5386 118225	ANASTASIYA AKIMOVA	{"email": "anastasiya.akimova_1966@postgrespro.ru", "phone": "+70639066038"}
0005433613772	8B7BAF	6983 045938	LIDIYA MAKSIMOVA	{"email": "maksimova_l.111977@postgrespro.ru", "phone": "+70764929781"}
0005433613773	67665D	6292 809212	LARISA TARASOVA	{"phone": "+70907681859"}
0005433613774	6A823C	8996 063121	VALENTINA ZAYCEVA	{"email": "zayceva-valentina.10071982@postgrespro.ru", "phone": "+70628702651"}
0005433613775	5058CA	0159 390435	SERGEY KOZLOV	{"phone": "+70878299405"}
0005433613776	205F25	0737 101451	YURIY IVANOV	{"email": "ivanovy-071979@postgrespro.ru", "phone": "+70610284398"}
0005433613777	B8709A	8784 916309	ALEKSANDR GRIGOREV	{"email": "a.grigorev_20121969@postgrespro.ru", "phone": "+70912097470"}
0005433613778	B8709A	9627 271827	ALENA KUZNECOVA	{"email": "kuznecova-alena-101975@postgrespro.ru", "phone": "+70197630900"}
0005433613779	275498	8575 537986	TATYANA MIKHAYLOVA	{"phone": "+70658511183"}
0005433613780	013E94	3486 955173	VLADIMIR PETROV	{"phone": "+70743715366"}
0005433613781	013E94	3531 743813	OKSANA GORBUNOVA	{"phone": "+70159906072"}
0005433613782	857E28	9119 576521	ALEKSANDRA ARKHIPOVA	{"phone": "+70719293053"}
0005433613783	9CF563	6099 902540	ARTEM VOROBEV	{"phone": "+70559918505"}
0005433613784	A26661	7156 443432	IVAN PETROV	{"email": "petrov-ivan.071972@postgrespro.ru", "phone": "+70318098226"}
0005433613785	C45481	4977 508496	MARINA MAKAROVA	{"email": "makarova.marina061962@postgrespro.ru", "phone": "+70603298930"}
0005433613786	6CA951	3872 237715	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov061971@postgrespro.ru", "phone": "+70354965502"}
0005433613787	6CA951	0710 049139	SERGEY ANDREEV	{"email": "andreev_s111974@postgrespro.ru", "phone": "+70554365876"}
0005433613788	92C366	9050 692000	LIDIYA TIKHONOVA	{"email": "tikhonoval06021977@postgrespro.ru", "phone": "+70306679112"}
0005433613789	446E5D	8292 106452	ANASTASIYA GUSEVA	{"phone": "+70039722852"}
0005433613790	446E5D	4888 215729	NADEZHDA NESTEROVA	{"phone": "+70807978601"}
0005433613791	8CF258	5630 853407	VALERIY PAVLOV	{"phone": "+70292691606"}
0005433613792	8CF258	8497 159633	ALEKSANDR ALEKSANDROV	{"phone": "+70709776236"}
0005433613793	8B6B3D	3621 017431	NADEZHDA NAUMOVA	{"email": "n.naumova1965@postgrespro.ru", "phone": "+70919298034"}
0005433613794	CE9A31	3816 621446	ANNA KUDRYASHOVA	{"phone": "+70025015549"}
0005433613795	C6A2E2	8254 232372	LIDIYA DAVYDOVA	{"phone": "+70115700590"}
0005433613796	6FD7C6	1309 089901	ALEKSANDR MATVEEV	{"phone": "+70801668600"}
0005433613797	D8F3DE	0640 597004	PETR NIKITIN	{"phone": "+70276079258"}
0005433613798	71AA74	8807 538281	TATYANA PETROVA	{"email": "petrova_tatyana.23081973@postgrespro.ru", "phone": "+70399518823"}
0005433613799	483EBD	1549 121523	VITALIY KUZNECOV	{"email": "kuznecov.v.24021963@postgrespro.ru", "phone": "+70478760122"}
0005433613800	B9A710	7655 982272	TATYANA KARPOVA	{"email": "karpovatatyana1966@postgrespro.ru", "phone": "+70088616511"}
0005433613801	741FD6	5884 128354	ELENA DMITRIEVA	{"email": "dmitrieva.e-091980@postgrespro.ru", "phone": "+70100326655"}
0005433613802	741FD6	0270 960510	EKATERINA LOGINOVA	{"phone": "+70882689516"}
0005433613803	C953A5	8945 346720	ALEKSANDR MARTYNOV	{"email": "amartynov.121970@postgrespro.ru", "phone": "+70871543009"}
0005433613804	7307DE	1152 948729	ANDREY KOROLEV	{"email": "andreykorolev-011969@postgrespro.ru", "phone": "+70928632240"}
0005433613805	091D48	1988 773649	DENIS MOISEEV	{"email": "moiseev-d-031965@postgrespro.ru", "phone": "+70871380707"}
0005433613806	85528E	4378 040672	GENNADIY ROMANOV	{"email": "romanov_g.08061964@postgrespro.ru", "phone": "+70921468229"}
0005433613807	5587C4	2028 937373	VIKTORIYA SMIRNOVA	{"phone": "+70236940904"}
0005433613808	5587C4	0429 091667	IRINA SOKOLOVA	{"phone": "+70058170104"}
0005433613809	5587C4	1714 732869	ANDREY RODIONOV	{"email": "andrey_rodionov05051981@postgrespro.ru", "phone": "+70181462659"}
0005433613810	9423B1	3088 361943	KONSTANTIN FROLOV	{"phone": "+70752686811"}
0005433613811	144C5A	5396 383737	IRAIDA SCHERBAKOVA	{"email": "i-scherbakova.031966@postgrespro.ru", "phone": "+70708793299"}
0005433613812	144C5A	4560 190847	DAMIR ABRAMOV	{"email": "abramovd_031966@postgrespro.ru", "phone": "+70468256955"}
0005433613813	144C5A	1463 623859	MIKHAIL SOROKIN	{"email": "mikhail_sorokin_03081971@postgrespro.ru", "phone": "+70058890681"}
0005433613814	B9B4AF	9677 308886	LYUDMILA VASILEVA	{"email": "l-vasileva-1980@postgrespro.ru", "phone": "+70365116302"}
0005433613815	B9B4AF	8050 952637	TATYANA POPOVA	{"email": "popova.t-051977@postgrespro.ru", "phone": "+70800029629"}
0005433613816	B9B4AF	7281 318153	NADEZHDA LEBEDEVA	{"email": "n_lebedeva.07081965@postgrespro.ru", "phone": "+70357888853"}
0005433613817	7DBB47	0083 780077	LYUBOV EFREMOVA	{"phone": "+70971554348"}
0005433613818	C7C99A	6925 556104	EVGENIYA TITOVA	{"email": "e.titova1976@postgrespro.ru", "phone": "+70074439699"}
0005433613819	66FF2B	8730 961733	VIKTOR ZAYCEV	{"email": "viktor_zaycev-1972@postgrespro.ru", "phone": "+70955635825"}
0005433613820	773DF5	7898 107542	ANATOLIY GRIGOREV	{"email": "grigoreva.031980@postgrespro.ru", "phone": "+70230923537"}
0005433613821	AC0DF4	5689 441877	ANNA ALEKSEEVA	{"email": "alekseeva.anna_011956@postgrespro.ru", "phone": "+70903979118"}
0005433613822	9A9F83	2796 635124	ALEKSANDR ISAEV	{"phone": "+70637416425"}
0005433613823	074516	6774 533862	LYUDMILA ERMAKOVA	{"phone": "+70195751234"}
0005433613824	074516	6395 487240	OLGA VASILEVA	{"phone": "+70923927630"}
0005433613825	074516	8985 925211	LIDIYA GRISHINA	{"email": "grishina_l25031978@postgrespro.ru", "phone": "+70649562761"}
0005433613826	3E6243	8608 720153	LYUDMILA GORBUNOVA	{"email": "lyudmila.gorbunova_1977@postgrespro.ru", "phone": "+70228538671"}
0005433613827	380703	4393 392423	OLESYA DAVYDOVA	{"email": "olesyadavydova-041980@postgrespro.ru", "phone": "+70497563062"}
0005433613828	4288E0	2663 917984	VALENTINA DENISOVA	{"phone": "+70215990030"}
0005433613829	DE2E83	7665 361705	DAMIR BORISOV	{"email": "borisovdamir1978@postgrespro.ru", "phone": "+70873793306"}
0005433613830	DE2E83	3844 871455	IVAN SCHERBAKOV	{"phone": "+70517337922"}
0005433613831	63C00A	0181 127957	RAISA IVANOVA	{"phone": "+70401076299"}
0005433613832	6C9D5A	1693 668157	MIKHAIL MIRONOV	{"phone": "+70409632929"}
0005433613833	6F752F	4019 196803	NATALYA OSIPOVA	{"phone": "+70112878490"}
0005433613834	0958BA	8887 903218	ALEKSEY KISELEV	{"phone": "+70898565656"}
0005433613835	553974	4419 119474	PAVEL DENISOV	{"phone": "+70454601444"}
0005433613836	AD3873	3052 447087	IVAN MARTYNOV	{"phone": "+70045289571"}
0005433613837	7EF2D4	6090 026000	IVAN NIKOLAEV	{"email": "i.nikolaev.121956@postgrespro.ru", "phone": "+70133293145"}
0005433613838	7EF2D4	9715 578634	MARIYA SIDOROVA	{"email": "mariya_sidorova_111961@postgrespro.ru", "phone": "+70561681694"}
0005433613839	938062	3119 542553	MIKHAIL GORBUNOV	{"phone": "+70310677527"}
0005433613840	623294	3786 446146	IGOR IVANOV	{"phone": "+70084226717"}
0005433613841	E63E0A	7652 783153	NINA MASLOVA	{"phone": "+70630178799"}
0005433613842	C3CB5F	2007 363020	OLGA KOROLEVA	{"email": "korolevao.1975@postgrespro.ru", "phone": "+70048977998"}
0005433613843	9364A7	7966 445759	VALENTIN ILIN	{"phone": "+70385200442"}
0005433613844	A25C06	7268 387797	SERGEY DENISOV	{"phone": "+70001217050"}
0005433613845	8457B0	3025 387553	VLADIMIR SERGEEV	{"phone": "+70580281335"}
0005433613846	9ECF3E	9811 419329	SERGEY ISAEV	{"phone": "+70200187046"}
0005433613847	35EB47	5859 519615	NIKOLAY KOZLOV	{"email": "kozlovn21021972@postgrespro.ru", "phone": "+70759445091"}
0005433613848	F5E86E	9047 007107	LARISA ROMANOVA	{"email": "romanovalarisa.1964@postgrespro.ru", "phone": "+70983963466"}
0005433613849	4625D7	3665 650318	TATYANA GORBUNOVA	{"email": "gorbunova-t_30061969@postgrespro.ru", "phone": "+70067361852"}
0005433613850	EAE553	1823 914166	SVETLANA KOZLOVA	{"phone": "+70006962083"}
0005433613851	E8549F	1763 870893	ALEKSEY ANTONOV	{"email": "antonov_a061980@postgrespro.ru", "phone": "+70598194922"}
0005433613852	DC74F9	0983 098586	MARIYA DENISOVA	{"phone": "+70781752952"}
0005433613853	DC74F9	3581 677108	TAMARA NOVIKOVA	{"email": "novikova-t-121972@postgrespro.ru", "phone": "+70269494125"}
0005433613854	2EC0AB	8860 804193	TATYANA ORLOVA	{"email": "tatyana_orlova19071973@postgrespro.ru", "phone": "+70263411628"}
0005433613855	A24DDC	2930 298554	YURIY FEDOROV	{"email": "yfedorov-1972@postgrespro.ru", "phone": "+70758381691"}
0005433613856	A24DDC	6891 681933	GRIGORIY BELOV	{"phone": "+70739840195"}
0005433613857	1F922C	2870 066323	ZOYA IVANOVA	{"email": "zoyaivanova-07061975@postgrespro.ru", "phone": "+70769424865"}
0005433613858	1F922C	4057 636462	VITALIY ILIN	{"phone": "+70179102763"}
0005433613859	E9D14E	7262 547393	NATALIYA SAVELEVA	{"phone": "+70537850041"}
0005433613860	173505	1600 738160	RIFAT TARASOV	{"email": "r.tarasov-111962@postgrespro.ru", "phone": "+70794408598"}
0005433613861	173505	8002 318401	ALEKSANDR FROLOV	{"phone": "+70973039152"}
0005433613862	173505	7721 083344	NINA ANDREEVA	{"phone": "+70703064285"}
0005433613863	E07F8E	0787 432888	ALEKSEY VOROBEV	{"email": "vorobev_a.17081978@postgrespro.ru", "phone": "+70012054431"}
0005433613864	D9619D	7991 829653	ELENA AFANASEVA	{"phone": "+70062633784"}
0005433613865	D9619D	0536 705960	PAVEL SOLOVEV	{"email": "solovev.pavel-01111987@postgrespro.ru", "phone": "+70505352188"}
0005433613866	D631F8	8933 057272	KIRILL MARTYNOV	{"email": "kirillmartynov_1968@postgrespro.ru", "phone": "+70731544269"}
0005433613867	4DB10A	9977 254493	NINA DMITRIEVA	{"email": "dmitrievanina-051982@postgrespro.ru", "phone": "+70209660001"}
0005433613868	7A0536	0336 875975	YURIY PETROV	{"phone": "+70982084471"}
0005433613869	CF1DBA	3251 248061	VERA TIMOFEEVA	{"phone": "+70089524446"}
0005433613870	8E9E3F	4444 483270	NATALYA BORISOVA	{"email": "natalya-borisova-031983@postgrespro.ru", "phone": "+70053969528"}
0005433613871	FD28C2	2885 037281	VALERIY KONOVALOV	{"phone": "+70916201350"}
0005433613872	F67110	8183 676189	VLADIMIR MIRONOV	{"email": "v.mironov-14091957@postgrespro.ru", "phone": "+70295558330"}
0005433613873	B651FC	1745 271164	ELENA KOZLOVA	{"phone": "+70622356879"}
0005433613874	36F372	3449 019323	SVETLANA KARPOVA	{"phone": "+70141621432"}
0005433613875	36F372	7198 565417	ANNA IVANOVA	{"phone": "+70820543482"}
0005433613876	8FDAD0	0087 753669	GENNADIY ANDREEV	{"email": "andreev.gennadiy_031975@postgrespro.ru", "phone": "+70153870914"}
0005433613877	6C988F	0105 440442	GALINA OSIPOVA	{"phone": "+70451152869"}
0005433613878	1B0629	7158 949003	ANNA ANTONOVA	{"email": "a.antonova-011973@postgrespro.ru", "phone": "+70214360560"}
0005433613879	1B0629	7847 813256	MIKHAIL KOROLEV	{"email": "korolev-m01071980@postgrespro.ru", "phone": "+70335800355"}
0005433613880	89090E	8893 894598	YURIY KUZNECOV	{"phone": "+70301934519"}
0005433613881	FCA0FC	9911 829703	ANAIT SIDOROVA	{"email": "a_sidorova_08071977@postgrespro.ru", "phone": "+70675716190"}
0005433613882	6D9F70	4394 579753	NADEZHDA KUZMINA	{"email": "nadezhdakuzmina-1977@postgrespro.ru", "phone": "+70704069716"}
0005433613883	EBCD30	6878 560639	MARIYA POLYAKOVA	{"phone": "+70562653596"}
0005433613884	985103	8128 581310	IGOR ANDREEV	{"phone": "+70228589455"}
0005433613885	33749E	7566 661195	ALEKSANDR MAKAROV	{"phone": "+70583426242"}
0005433613886	A37968	8923 532170	ANDREY FROLOV	{"email": "afrolov051970@postgrespro.ru", "phone": "+70841254856"}
0005433613887	AACA43	5356 807225	NIKOLAY MAKAROV	{"email": "nikolay-makarov_071975@postgrespro.ru", "phone": "+70194172870"}
0005433613888	5EE96D	7749 480577	IGOR ALEKSANDROV	{"email": "aleksandrov-igor1979@postgrespro.ru", "phone": "+70031417357"}
0005433613889	4555E1	0678 075312	VLADIMIR STEPANOV	{"email": "stepanov.v20021980@postgrespro.ru", "phone": "+70530004491"}
0005433613890	E76187	1534 334718	RAMILYA STEPANOVA	{"phone": "+70637883175"}
0005433613891	E76187	1540 323065	VYACHESLAV TIKHONOV	{"phone": "+70679740736"}
0005433613892	70DA28	9509 080436	ALEKSANDR ANTONOV	{"phone": "+70233050699"}
0005433613893	70DA28	4229 992980	NATALYA MIRONOVA	{"email": "n.mironova_041963@postgrespro.ru", "phone": "+70593018078"}
0005433613894	70DA28	7367 124686	DMITRIY KOZLOV	{"phone": "+70049176995"}
0005433613895	631CB1	3411 289067	TATYANA MOROZOVA	{"phone": "+70984296043"}
0005433613896	631CB1	9102 509651	NIKOLAY KUZNECOV	{"phone": "+70291721726"}
0005433613897	3B6BE2	4872 298233	ALEVTINA KOROLEVA	{"email": "korolevaa1981@postgrespro.ru", "phone": "+70358036302"}
0005433613898	009FC6	3472 713146	OKSANA OVCHINNIKOVA	{"phone": "+70125691159"}
0005433613899	009FC6	8311 675390	EVGENIYA YAKOVLEVA	{"phone": "+70244689241"}
0005433613900	26D64B	2318 153291	IRINA AFANASEVA	{"email": "i-afanaseva.111965@postgrespro.ru", "phone": "+70003086204"}
0005433613901	6D69F6	7539 246089	NIKITA SIDOROV	{"email": "sidorov.nikita-04041981@postgrespro.ru", "phone": "+70777131360"}
0005433613902	22629C	0948 326247	VALENTINA TITOVA	{"email": "v-titova.30031983@postgrespro.ru", "phone": "+70278335631"}
0005433613903	22629C	0441 823849	ANDREY FILIPPOV	{"phone": "+70063672714"}
0005433613904	7F150C	4953 642431	MARINA KUZMINA	{"email": "m.kuzmina.1951@postgrespro.ru", "phone": "+70517452328"}
0005433613905	7F150C	1205 871619	ALEKSEY IVANOV	{"email": "alekseyivanov-12041959@postgrespro.ru", "phone": "+70317203184"}
0005433613906	0A02D6	1556 224935	SVETLANA TIKHONOVA	{"email": "tikhonova-s.07091978@postgrespro.ru", "phone": "+70722028857"}
0005433613907	C2BCCC	4051 509588	OLGA ROMANOVA	{"email": "romanova-olga25031970@postgrespro.ru", "phone": "+70381865205"}
0005433613908	54FD6A	5735 106953	VLADIMIR DAVYDOV	{"email": "vladimir_davydov031982@postgrespro.ru", "phone": "+70955130577"}
0005433613909	54FD6A	2578 725345	GENNADIY KARPOV	{"phone": "+70326055369"}
0005433613910	E85349	5186 073954	LIDIYA EGOROVA	{"phone": "+70530805764"}
0005433613911	582E89	0675 537520	VALERIYA MAKAROVA	{"phone": "+70865896414"}
0005433613912	5E219E	2183 344273	OLEG SOKOLOV	{"email": "olegsokolov-1976@postgrespro.ru", "phone": "+70225972545"}
0005433613913	51D8DF	3643 185036	ELIZAVETA PETROVA	{"phone": "+70055506969"}
0005433613914	0C232A	7628 286147	LIDIYA SOROKINA	{"email": "lidiyasorokina-091973@postgrespro.ru", "phone": "+70665816299"}
0005433613915	D95CC7	6391 261334	IRINA NOVIKOVA	{"phone": "+70239699276"}
0005433613916	058E0A	5517 615478	ALEKSANDR SOROKIN	{"phone": "+70361510331"}
0005433613917	664AE4	0794 485541	ELENA MELNIKOVA	{"email": "elena_melnikova-03121972@postgrespro.ru", "phone": "+70961606117"}
0005433613918	452847	0283 385121	ARKADIY VOLKOV	{"email": "arkadiy-volkov.111958@postgrespro.ru", "phone": "+70695748813"}
0005433613919	452847	2866 282248	KONSTANTIN ZHURAVLEV	{"phone": "+70201090622"}
0005433613920	E29F68	8933 636640	ALEKSEY DENISOV	{"phone": "+70080847431"}
0005433613921	DCB417	4578 804586	DMITRIY VOLKOV	{"email": "volkov.dmitriy_011968@postgrespro.ru", "phone": "+70171635518"}
0005433613922	2A193E	1633 257213	ELENA KUZNECOVA	{"phone": "+70747981578"}
0005433613923	268662	3106 385419	VIKTOR IVANOV	{"email": "ivanov-viktor-081972@postgrespro.ru", "phone": "+70691046772"}
0005433613924	F50EB3	0782 358621	VYACHESLAV GERASIMOV	{"email": "gerasimov.vyacheslav021970@postgrespro.ru", "phone": "+70414566260"}
0005433613925	5D9680	0135 468245	VLADIMIR FROLOV	{"phone": "+70720994562"}
0005433613926	C33ED8	1308 660171	ALEKSANDR SIDOROV	{"phone": "+70902002468"}
0005433613927	C33ED8	9573 624103	IVAN DENISOV	{"phone": "+70162868489"}
0005433613928	DC54BF	3181 229219	ALEKSEY AFANASEV	{"email": "afanasev_aleksey1977@postgrespro.ru", "phone": "+70214336952"}
0005433613929	DE35E5	6852 407082	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin_09021974@postgrespro.ru", "phone": "+70442569500"}
0005433613930	AD84E9	3007 162696	ILYA MAKAROV	{"email": "ilya_makarov.061975@postgrespro.ru", "phone": "+70844084949"}
0005433613931	7DE06C	4526 890726	RUSLAN SAVELEV	{"phone": "+70205610323"}
0005433613933	7DE06C	0978 621031	ELENA NOVIKOVA	{"phone": "+70973581882"}
0005433613934	DAFC72	3141 181798	ANDREY YAKOVLEV	{"email": "yakovlev-andrey1966@postgrespro.ru", "phone": "+70210170703"}
0005433613935	DAFC72	2000 394223	VLADIMIR KOZLOV	{"email": "kozlov-v.21081964@postgrespro.ru", "phone": "+70020441854"}
0005433613936	DAFC72	9052 005965	DMITRIY VOLKOV	{"phone": "+70869432845"}
0005433613937	913CD5	8716 130070	DANILA ZHUKOV	{"email": "zhukov.d.1963@postgrespro.ru", "phone": "+70349036993"}
0005433613938	913CD5	5126 289789	LYUBOV MAKAROVA	{"phone": "+70562084989"}
0005433613939	B43A7D	9064 409067	VALENTINA NIKOLAEVA	{"phone": "+70304079455"}
0005433613940	B43A7D	0752 367002	VLADIMIR SAVELEV	{"email": "savelevvladimir-121977@postgrespro.ru", "phone": "+70210624805"}
0005433613941	75E484	3826 162269	OLGA MARTYNOVA	{"phone": "+70072823124"}
0005433613942	75E484	6603 349441	VLADISLAV KUZNECOV	{"phone": "+70150569943"}
0005433613943	46D678	0310 869655	YURIY MOROZOV	{"phone": "+70079056072"}
0005433613944	F9F4E2	4474 920835	SVETLANA CHERNOVA	{"email": "s-chernova.101981@postgrespro.ru", "phone": "+70748148772"}
0005433613945	8B1D05	1050 837376	ANDREY KARPOV	{"phone": "+70965001278"}
0005433613946	976AF0	3536 346769	STANISLAV STEPANOV	{"email": "stanislav-stepanov_031969@postgrespro.ru", "phone": "+70774284315"}
0005433613947	976AF0	0242 234329	NATALYA MARTYNOVA	{"email": "natalya.martynova_1973@postgrespro.ru", "phone": "+70518978359"}
0005433613948	3B7EF9	3041 799004	DANILA SOROKIN	{"email": "sorokin.danila031966@postgrespro.ru", "phone": "+70692545298"}
0005433613949	3B7EF9	4523 634438	ELENA SIDOROVA	{"email": "elenasidorova_021982@postgrespro.ru", "phone": "+70614097895"}
0005433613950	3C8045	5393 736142	DENIS GORBUNOV	{"email": "denis-gorbunov091978@postgrespro.ru", "phone": "+70439580159"}
0005433613951	536340	3436 246411	ALEKSANDRA KUZNECOVA	{"email": "a.kuznecova_21101971@postgrespro.ru", "phone": "+70798704976"}
0005433613952	536340	5844 120197	LYUDMILA NOVIKOVA	{"email": "novikoval_1980@postgrespro.ru", "phone": "+70589856275"}
0005433613953	F9D330	9424 293561	ELENA OVCHINNIKOVA	{"phone": "+70946679949"}
0005433613954	F9D330	2810 938230	IGOR POPOV	{"email": "popov_igor.111971@postgrespro.ru", "phone": "+70649511209"}
0005433613955	A4D4D4	6196 451318	LYUBOV SEMENOVA	{"phone": "+70430030906"}
0005433613956	B740EA	9761 004424	DMITRIY KUZMIN	{"email": "dmitriy_kuzmin031970@postgrespro.ru", "phone": "+70450814996"}
0005433613957	881674	4027 201163	LYUBOV CHERNOVA	{"email": "l_chernova-1973@postgrespro.ru", "phone": "+70745595082"}
0005433613958	A641C7	8171 638750	KSENIYA NIKOLAEVA	{"email": "kseniyanikolaeva-1967@postgrespro.ru", "phone": "+70231598959"}
0005433613959	1C859B	0969 683247	OLGA PETROVA	{"email": "o-petrova1970@postgrespro.ru", "phone": "+70752682835"}
0005433613960	1C24B4	6536 406187	ALEKSANDR SOKOLOV	{"email": "asokolov_07101976@postgrespro.ru", "phone": "+70582249321"}
0005433613961	B29101	3510 063952	ELENA FADEEVA	{"email": "fadeeva_elena-07071968@postgrespro.ru", "phone": "+70966534680"}
0005433613962	929A6E	1832 075598	PETR KUZNECOV	{"email": "kuznecov.p_091975@postgrespro.ru", "phone": "+70427393436"}
0005433613963	929A6E	1805 833617	PETR TIKHONOV	{"phone": "+70034931766"}
0005433613964	270B7C	8021 708271	PAVEL DAVYDOV	{"email": "pdavydov-071970@postgrespro.ru", "phone": "+70962492275"}
0005433613965	EFB55D	2707 781276	ALEKSANDR ABRAMOV	{"email": "a_abramov_1981@postgrespro.ru", "phone": "+70804885531"}
0005433613966	E60255	6619 285382	ANASTASIYA KAZAKOVA	{"email": "anastasiya_kazakova26091973@postgrespro.ru", "phone": "+70483701320"}
0005433613967	E60255	3370 012811	NADEZHDA KUZMINA	{"email": "kuzminanadezhda.12061969@postgrespro.ru", "phone": "+70190738169"}
0005433613968	3BE128	4294 698934	LYUDMILA ABRAMOVA	{"email": "labramova.21011974@postgrespro.ru", "phone": "+70536443782"}
0005433613969	956FFC	6050 612723	OLGA SOROKINA	{"phone": "+70401897136"}
0005433613970	0BA804	1691 597276	LEV NIKITIN	{"phone": "+70262867588"}
0005433613971	0BA804	9877 730814	ANATOLIY TIMOFEEV	{"email": "timofeev_anatoliy_1973@postgrespro.ru", "phone": "+70037682570"}
0005433613972	DB835B	6335 827315	OLEG AFANASEV	{"phone": "+70236148711"}
0005433613973	BF79B4	7135 282069	ANATOLIY KUZMIN	{"phone": "+70762194868"}
0005433613974	8F0191	9197 277744	VALENTINA RYABOVA	{"phone": "+70126169910"}
0005433613975	440FEF	9790 302911	LYUDMILA KOROLEVA	{"email": "lkoroleva-10111980@postgrespro.ru", "phone": "+70667880564"}
0005433613976	D6E6AF	9321 152587	MARGARITA ALEKSEEVA	{"phone": "+70778485224"}
0005433613977	9454E7	5780 469582	ELENA MELNIKOVA	{"email": "melnikova.e.021977@postgrespro.ru", "phone": "+70025438805"}
0005433613978	9454E7	8668 547143	MIKHAIL ORLOV	{"email": "orlov-mikhail-12111963@postgrespro.ru", "phone": "+70690592681"}
0005433613979	FCF050	4002 895927	VALERIY KUZNECOV	{"phone": "+70393026690"}
0005433613980	980EA4	3899 481823	VYACHESLAV KUZMIN	{"email": "vyacheslav-kuzmin_1971@postgrespro.ru", "phone": "+70424010784"}
0005433613981	980EA4	5566 269641	NINA MOROZOVA	{"email": "n_morozova-011960@postgrespro.ru", "phone": "+70758887794"}
0005433613982	504440	0071 743526	ANATOLIY NIKITIN	{"email": "a_nikitin.01071965@postgrespro.ru", "phone": "+70358236554"}
0005433613983	504440	4898 425785	LYUDMILA SOKOLOVA	{"email": "sokolovalyudmila1974@postgrespro.ru", "phone": "+70863088328"}
0005433613984	00DD63	9844 766562	NINA GRISHINA	{"phone": "+70758273638"}
0005433613985	185CB8	7554 127842	ALEVTINA SOKOLOVA	{"email": "sokolovaa.031978@postgrespro.ru", "phone": "+70992963580"}
0005433613986	185CB8	0997 843961	VALERIY ABRAMOV	{"phone": "+70851326761"}
0005433613987	AA9C81	4989 300537	ALEKSANDR GERASIMOV	{"email": "a_gerasimov-1969@postgrespro.ru", "phone": "+70549181098"}
0005433613988	CB355A	0391 747347	OLGA SOLOVEVA	{"email": "olga-soloveva-121966@postgrespro.ru", "phone": "+70040490675"}
0005433613989	D17D41	9221 286222	ANATOLIY KUDRYASHOV	{"phone": "+70789401689"}
0005433613990	744BFB	3058 645361	ANASTASIYA OSIPOVA	{"email": "aosipova1977@postgrespro.ru", "phone": "+70405109118"}
0005433613991	744BFB	1815 493478	LYUBOV KOZLOVA	{"phone": "+70489492782"}
0005433613992	B6E4F0	3948 812054	LYUBOV VOROBEVA	{"phone": "+70662602022"}
0005433613993	B6E4F0	5467 038828	KSENIYA PAVLOVA	{"email": "k-pavlova-031959@postgrespro.ru", "phone": "+70735322904"}
0005433613994	E4654C	3488 025796	GALINA POPOVA	{"email": "popova-galina.101968@postgrespro.ru", "phone": "+70007314758"}
0005433613995	B5DF2F	7086 124365	ROMAN MATVEEV	{"email": "roman.matveev.071973@postgrespro.ru", "phone": "+70579197251"}
0005433613996	51877C	5235 523275	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov.04101973@postgrespro.ru", "phone": "+70423393840"}
0005433613997	3FA1ED	1017 793341	NINEL FADEEVA	{"phone": "+70129589986"}
0005433613998	3FA1ED	4587 090980	OLGA DMITRIEVA	{"email": "olga.dmitrieva_16121987@postgrespro.ru", "phone": "+70595477745"}
0005433613999	361EA2	3518 726926	TATYANA KOROLEVA	{"email": "tatyana_koroleva-05021968@postgrespro.ru", "phone": "+70649591698"}
0005433614000	2A4EE4	9636 965260	VALENTINA VASILEVA	{"phone": "+70982164625"}
0005433614001	2A4EE4	1141 222868	ANATOLIY VASILEV	{"email": "a_vasilev23031978@postgrespro.ru", "phone": "+70959361723"}
0005433614002	7CDE7B	5888 452634	NATALYA MATVEEVA	{"email": "natalya-matveeva.1979@postgrespro.ru", "phone": "+70011061764"}
0005433614003	6C40B5	3423 829361	ALEKSANDR OSIPOV	{"phone": "+70719342058"}
0005433614004	6C40B5	2407 038204	TAISIYA POTAPOVA	{"phone": "+70610268378"}
0005433614005	6C40B5	9438 893959	KIRILL SOROKIN	{"email": "sorokinkirill-1970@postgrespro.ru", "phone": "+70816004011"}
0005433614006	D9DC5F	0610 083141	VLADIMIR SEMENOV	{"phone": "+70050135766"}
0005433614007	4D49FF	1032 291347	ALEKSANDR IVANOV	{"phone": "+70789223670"}
0005433614008	8AEDA2	8067 587420	ALEKSEY MIKHAYLOV	{"phone": "+70617581818"}
0005433614009	1B3535	6332 086865	VIKTOR NOVIKOV	{"phone": "+70985706614"}
0005433614010	1B3535	1111 226066	ALBINA MARTYNOVA	{"email": "albina_martynova081970@postgrespro.ru", "phone": "+70128586948"}
0005433614011	2F9FD4	1734 581423	NATALYA NIKITINA	{"phone": "+70615205519"}
0005433614012	E0981F	7600 057624	OLEG KUZMIN	{"phone": "+70865034065"}
0005433614013	883835	4928 440973	VLADIMIR MARTYNOV	{"email": "vladimir-martynov-07031965@postgrespro.ru", "phone": "+70781540820"}
0005433614014	883835	5257 268753	NINA BOGDANOVA	{"phone": "+70610530410"}
0005433614015	C86437	3639 379897	ALEKSANDR SAVELEV	{"phone": "+70525941758"}
0005433614016	FE454B	4609 543108	SERGEY NIKITIN	{"email": "nikitin-s-1972@postgrespro.ru", "phone": "+70644613245"}
0005433614017	3C6AD3	0019 769937	ELENA VASILEVA	{"email": "vasilevaelena19031963@postgrespro.ru", "phone": "+70860885414"}
0005433614018	3C6AD3	7228 008269	MIKHAIL MATVEEV	{"phone": "+70279032381"}
0005433614019	FD27DB	4074 272547	DANIIL ALEKSEEV	{"phone": "+70405760530"}
0005433614020	1063F6	0330 189530	LYUDMILA OSIPOVA	{"email": "lyudmila_osipova.1981@postgrespro.ru", "phone": "+70512181036"}
0005433614021	948CED	4279 049593	DARYA KONDRATEVA	{"phone": "+70477922399"}
0005433614022	0248E6	2207 473837	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr.121967@postgrespro.ru", "phone": "+70254467879"}
0005433614023	0471DA	4919 495516	VERA MEDVEDEVA	{"email": "medvedeva.v_011987@postgrespro.ru", "phone": "+70123756868"}
0005433614024	B779AE	0618 442264	IGOR FEDOROV	{"email": "i-fedorov-10071967@postgrespro.ru", "phone": "+70225771029"}
0005433614025	B779AE	9173 978631	SVETLANA DENISOVA	{"phone": "+70488295165"}
0005433614026	B779AE	0699 825560	TATYANA KRASNOVA	{"phone": "+70316025436"}
0005433614027	13EA6F	3418 315949	VLADIMIR SOKOLOV	{"email": "v-sokolov.061962@postgrespro.ru", "phone": "+70552884270"}
0005433614028	CA4965	7913 721035	TATYANA GERASIMOVA	{"phone": "+70425312423"}
0005433614029	206FAE	9064 535644	VERA PAVLOVA	{"phone": "+70039760536"}
0005433614030	75C8E5	9739 816286	VALENTINA KULIKOVA	{"email": "kulikovavalentina091966@postgrespro.ru", "phone": "+70293712317"}
0005433614031	75C8E5	5300 009415	GALINA ANTONOVA	{"phone": "+70898427829"}
0005433614032	E46729	6672 844057	VERA ZAYCEVA	{"phone": "+70836914780"}
0005433614033	E46729	8346 536492	ILDAR KUZNECOV	{"phone": "+70002911207"}
0005433614034	A0C64B	8311 440809	INNA IVANOVA	{"email": "ivanova.i-1973@postgrespro.ru", "phone": "+70919831363"}
0005433614035	18154E	6812 590506	ANASTASIYA ZAKHAROVA	{"email": "anastasiyazakharova_21101961@postgrespro.ru", "phone": "+70056903183"}
0005433614036	18154E	4718 816862	STANISLAV DENISOV	{"phone": "+70749260251"}
0005433614037	18154E	1253 214111	VALERIYA FROLOVA	{"email": "frolova-valeriya04031968@postgrespro.ru", "phone": "+70361625697"}
0005433614038	12382B	6405 608094	ALEKSEY ALEKSEEV	{"phone": "+70174868998"}
0005433614039	442A8C	5398 246698	GALINA BOGDANOVA	{"email": "galinabogdanova12031976@postgrespro.ru", "phone": "+70774877981"}
0005433614040	F8E770	2419 724253	VLADIMIR KAZAKOV	{"email": "kazakov_vladimir01031967@postgrespro.ru", "phone": "+70995541955"}
0005433614041	B5E38A	1000 293114	ILYAS FEDOROV	{"email": "ilyas-fedorov.12091976@postgrespro.ru", "phone": "+70757958578"}
0005433614042	378F57	9271 060768	ANNA BARANOVA	{"email": "baranovaanna22101972@postgrespro.ru", "phone": "+70797518324"}
0005433614043	BC4FCE	9608 655863	ANDREY BORISOV	{"phone": "+70616718065"}
0005433614044	BC4FCE	0064 540055	YURIY EGOROV	{"phone": "+70296279494"}
0005433614045	2F8AB5	2092 393813	KIRILL DMITRIEV	{"email": "dmitriev-k_18121967@postgrespro.ru", "phone": "+70429606343"}
0005433614046	B2C75F	8236 198035	TATYANA KOROLEVA	{"phone": "+70408174999"}
0005433614047	86187B	5501 389201	ANDREY ANTONOV	{"email": "a_antonov_1977@postgrespro.ru", "phone": "+70994790040"}
0005433614048	86187B	7107 937763	MARIYA VASILEVA	{"email": "vasileva-mariya_041971@postgrespro.ru", "phone": "+70851760629"}
0005433614049	2A5356	1174 314594	PETR ANDREEV	{"email": "andreev-petr.1965@postgrespro.ru", "phone": "+70407044628"}
0005433614050	2A5356	5214 173390	ALEKSANDR ROMANOV	{"phone": "+70026096779"}
0005433614051	2A5356	9566 828659	ANATOLIY AFANASEV	{"phone": "+70901362648"}
0005433614052	0F2CCE	1662 226324	VLADIMIR NOVIKOV	{"phone": "+70215181783"}
0005433614053	0F2CCE	7562 672295	PAVEL SHEVCHENKO	{"email": "shevchenkop071967@postgrespro.ru", "phone": "+70153100605"}
0005433614054	4B0928	9559 349375	NATALYA KUZMINA	{"phone": "+70354844939"}
0005433614055	E66BB5	0336 205865	NIKOLAY KOZLOV	{"phone": "+70631089348"}
0005433614056	EACE17	5608 810126	ALEKSANDR TIMOFEEV	{"email": "timofeev-a1956@postgrespro.ru", "phone": "+70183663975"}
0005433614057	EC5821	8154 028966	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov-1965@postgrespro.ru", "phone": "+70224309329"}
0005433614058	EC5821	9614 724192	OLGA MATVEEVA	{"email": "matveeva_olga.15111978@postgrespro.ru", "phone": "+70473084858"}
0005433614059	151CC1	2718 364365	OLGA SOKOLOVA	{"email": "osokolova-041966@postgrespro.ru", "phone": "+70154398194"}
0005433614060	702A0D	4638 652977	VALENTINA YUDINA	{"phone": "+70966239878"}
0005433614061	702A0D	4690 692064	YULIYA GAVRILOVA	{"email": "y_gavrilova041968@postgrespro.ru", "phone": "+70259948070"}
0005433614062	702A0D	9546 296461	NADEZHDA VASILEVA	{"phone": "+70068771995"}
0005433614063	E33BCF	6739 497145	NIKOLAY GORBUNOV	{"email": "ngorbunov1963@postgrespro.ru", "phone": "+70170695051"}
0005433614064	319AA3	5572 556839	MIKHAIL VLASOV	{"email": "mikhail_vlasov-1980@postgrespro.ru", "phone": "+70697377829"}
0005433614065	A39EE1	0646 941451	DENIS IVANOV	{"email": "denis_ivanov_09111975@postgrespro.ru", "phone": "+70264409240"}
0005433614066	DE1A49	3570 585127	VYACHESLAV FEDOROV	{"phone": "+70029985284"}
0005433614067	DE1A49	4341 566902	DARYA AKIMOVA	{"email": "akimovadarya.1978@postgrespro.ru", "phone": "+70586008251"}
0005433614068	2A3C81	4618 824627	POLINA MEDVEDEVA	{"phone": "+70938492505"}
0005433614069	E6F447	8426 551766	SVETLANA SOROKINA	{"email": "sorokina-svetlana31031958@postgrespro.ru", "phone": "+70457780632"}
0005433614070	DEE40C	9949 070509	EVGENIY VASILEV	{"email": "evgeniy_vasilev_26091972@postgrespro.ru", "phone": "+70789241323"}
0005433614071	DEE40C	6466 487401	TATYANA VASILEVA	{"email": "tatyana_vasileva.1965@postgrespro.ru", "phone": "+70644278120"}
0005433614072	E7D242	6957 535358	PETR MARTYNOV	{"email": "martynov_petr101966@postgrespro.ru", "phone": "+70536826251"}
0005433614073	E7D242	5721 150463	EKATERINA SOKOLOVA	{"email": "ekaterina.sokolova.091972@postgrespro.ru", "phone": "+70214106957"}
0005433614074	5F3A63	1555 953850	ELENA OSIPOVA	{"phone": "+70254100841"}
0005433614075	CD3470	0088 407249	VLADIMIR TARASOV	{"email": "vladimirtarasov-20011962@postgrespro.ru", "phone": "+70197917323"}
0005433614076	A79867	7061 946844	SERGEY TARASOV	{"phone": "+70700081021"}
0005433614077	B5BA8E	5855 723130	OKSANA KOZLOVA	{"email": "o-kozlova.031967@postgrespro.ru", "phone": "+70348780367"}
0005433614078	B5BA8E	4819 059280	SERGEY BORISOV	{"email": "borisovsergey-1962@postgrespro.ru", "phone": "+70675010404"}
0005433614079	B5BA8E	7867 650850	ANNA PETROVA	{"phone": "+70068570507"}
0005433614080	FB407C	0080 194993	LYUBOV NIKITINA	{"email": "nikitinalyubov.19091963@postgrespro.ru", "phone": "+70654560742"}
0005433614081	FB407C	6836 918999	ILYA MARTYNOV	{"email": "ilya_martynov_28031967@postgrespro.ru", "phone": "+70635512731"}
0005433614082	B39986	0481 348329	SERGEY MIKHAYLOV	{"phone": "+70344761590"}
0005433614083	B39986	8077 167551	GENNADIY ISAEV	{"email": "g_isaev.1970@postgrespro.ru", "phone": "+70472642227"}
0005433614084	B50FC1	7208 009232	IGNAT CHERNOV	{"phone": "+70345051152"}
0005433614085	7B56E6	7146 010806	MAKSIM MOROZOV	{"email": "morozov_m-021971@postgrespro.ru", "phone": "+70467455638"}
0005433614086	C1850F	7777 594909	EVGENIYA VOLKOVA	{"phone": "+70118951938"}
0005433614087	7A2075	9898 297677	MARIYA FEDOROVA	{"phone": "+70594021189"}
0005433614088	A756A0	5842 015053	ALEKSEY PETROV	{"email": "aleksey_petrov.1973@postgrespro.ru", "phone": "+70369343449"}
0005433614089	2241CB	1432 044075	SERGEY ZAKHAROV	{"email": "s.zakharov24081976@postgrespro.ru", "phone": "+70791621416"}
0005433614090	5A2CF6	7740 083463	NADEZHDA GERASIMOVA	{"phone": "+70755292205"}
0005433614091	D42C35	2262 847893	ALEKSANDR SCHERBAKOV	{"phone": "+70707776848"}
0005433614092	5843BB	1226 079102	ANASTASIYA BARANOVA	{"phone": "+70873612938"}
0005433614093	27D79E	0558 816015	ALEKSEY IVANOV	{"email": "ivanov-aleksey_04061973@postgrespro.ru", "phone": "+70174838470"}
0005433614094	27D79E	6856 247333	EKATERINA NAZAROVA	{"phone": "+70869644028"}
0005433614095	4349DD	4189 584932	ASKHAT GERASIMOV	{"email": "gerasimov_askhat_041965@postgrespro.ru", "phone": "+70944181505"}
0005433614096	4349DD	5241 908965	NADEZHDA IVANOVA	{"email": "ivanova.n081972@postgrespro.ru", "phone": "+70661032621"}
0005433614097	50D481	0483 772721	IRINA FEDOROVA	{"phone": "+70356137691"}
0005433614098	50D481	2993 793095	VLADIMIR NIKITIN	{"email": "nikitin-v-26071978@postgrespro.ru", "phone": "+70523151335"}
0005433614099	2E52FD	2194 310006	MATRENA SOKOLOVA	{"email": "m-sokolova-1974@postgrespro.ru", "phone": "+70169511357"}
0005433614100	12D997	1775 511326	ANATOLIY MAKAROV	{"email": "makarov.a.041973@postgrespro.ru", "phone": "+70219173417"}
0005433614101	12D997	8076 032782	VERA LUKYANOVA	{"email": "v.lukyanova03031971@postgrespro.ru", "phone": "+70791527422"}
0005433614102	FE2BE4	8476 991815	YURIY BARANOV	{"phone": "+70376519165"}
0005433614103	C9C1CA	2528 016306	ALEKSEY BELOV	{"phone": "+70868340569"}
0005433614104	A7BC7A	1796 787081	VLADIMIR SAVELEV	{"phone": "+70736103789"}
0005433614105	A7BC7A	7184 706137	IVAN ANDREEV	{"email": "andreev-i.121967@postgrespro.ru", "phone": "+70522763069"}
0005433614106	A7BC7A	7026 614121	MARINA FEDOROVA	{"phone": "+70726103168"}
0005433614107	99111F	4866 228873	GEORGIY VLASOV	{"email": "g-vlasov-1975@postgrespro.ru", "phone": "+70354190590"}
0005433614108	99111F	5020 358613	ANGELINA MAKAROVA	{"phone": "+70271460769"}
0005433614109	CCEA90	0456 418293	OLGA BORISOVA	{"email": "borisova.o.1974@postgrespro.ru", "phone": "+70447350661"}
0005433614110	72578A	9361 233248	NIKITA PAVLOV	{"email": "nikitapavlov-08081975@postgrespro.ru", "phone": "+70216585762"}
0005433614111	ACC446	0338 697494	IVAN MAKSIMOV	{"email": "ivan_maksimov.1968@postgrespro.ru", "phone": "+70658752430"}
0005433614112	315070	0069 161436	OLGA SAVELEVA	{"email": "saveleva-o_16111965@postgrespro.ru", "phone": "+70220472533"}
0005433614113	315070	2741 092271	DMITRIY DMITRIEV	{"email": "dmitriev.d-03111975@postgrespro.ru", "phone": "+70052522126"}
0005433614114	3CA908	5955 510786	NATALYA DENISOVA	{"email": "natalya-denisova09111968@postgrespro.ru", "phone": "+70500048632"}
0005433614115	BBD0FA	3582 113670	ARTEM ABRAMOV	{"email": "artem-abramov-17101968@postgrespro.ru", "phone": "+70165101581"}
0005433614116	D8CB7E	4714 252295	TATYANA KUZNECOVA	{"phone": "+70085748692"}
0005433614117	A107BD	0541 335856	MARIYA ZAKHAROVA	{"email": "zakharova_m-1979@postgrespro.ru", "phone": "+70424280596"}
0005433614118	452AC8	7301 934397	ALEKSANDR GUSEV	{"phone": "+70853992030"}
0005433614119	53838E	6715 517038	ANTON ABRAMOV	{"email": "abramov-a_19111953@postgrespro.ru", "phone": "+70408842923"}
0005433614120	53838E	5430 942004	VLADIMIR SERGEEV	{"email": "sergeev.v29081979@postgrespro.ru", "phone": "+70399936754"}
0005433614121	53838E	6143 759305	ASIYA AKIMOVA	{"email": "akimova.a_17031962@postgrespro.ru", "phone": "+70286943386"}
0005433614122	F192B7	9416 927091	ARTEM IVANOV	{"phone": "+70967916482"}
0005433614123	F68E8A	7207 791869	NINA ERMAKOVA	{"phone": "+70392166027"}
0005433614124	F68E8A	4978 931421	IVAN ZAKHAROV	{"email": "zakharovi-021977@postgrespro.ru", "phone": "+70149878046"}
0005433614125	EB8486	8798 412055	VALERIY MIKHAYLOV	{"email": "v_mikhaylov.25101972@postgrespro.ru", "phone": "+70251076572"}
0005433614126	B7F350	8664 005066	ALEKSANDR PETROV	{"email": "petrov-aleksandr_071970@postgrespro.ru", "phone": "+70501101621"}
0005433614127	11C97D	0238 568198	NATALIYA POPOVA	{"email": "nataliya.popova.081979@postgrespro.ru", "phone": "+70684152470"}
0005433614128	53F114	4930 295434	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr_1955@postgrespro.ru", "phone": "+70424066029"}
0005433614129	53F114	2668 584011	NIKOLAY VASILEV	{"email": "nvasilev081963@postgrespro.ru", "phone": "+70563618384"}
0005433614130	E88771	7846 670653	VALERIY SOKOLOV	{"email": "sokolov-v-041968@postgrespro.ru", "phone": "+70258659938"}
0005433614131	93471A	6532 357212	ALINA MALYSHEVA	{"email": "alina-malysheva.1971@postgrespro.ru", "phone": "+70423981833"}
0005433614132	A7D521	6353 606898	INESSA ANDREEVA	{"email": "inessaandreeva_1967@postgrespro.ru", "phone": "+70822822643"}
0005433614133	D1341B	0097 923525	NATALYA SERGEEVA	{"phone": "+70434704805"}
0005433614134	D1341B	3356 877870	ILDAR KULIKOV	{"phone": "+70103786478"}
0005433614135	29904F	1710 420398	ANDREY NOVIKOV	{"phone": "+70183388801"}
0005433614136	4F26BD	4561 386375	DANIIL IVANOV	{"phone": "+70375369500"}
0005433614137	47FF0E	5833 249827	YURIY GERASIMOV	{"email": "gerasimov-y_01061970@postgrespro.ru", "phone": "+70915826630"}
0005433614138	7BD725	3623 000399	ALEKSEY SAVELEV	{"phone": "+70277666552"}
0005433614139	7BD725	9225 471732	NATALYA ANDREEVA	{"email": "natalya-andreeva_041962@postgrespro.ru", "phone": "+70865660789"}
0005433614140	E76F36	2738 054288	TATYANA ZAYCEVA	{"phone": "+70867193208"}
0005433614141	BEA4AB	0589 663876	LYUDMILA KUDRYASHOVA	{"phone": "+70191348391"}
0005433614142	BEA4AB	1890 938396	ALEKSANDR KUZMIN	{"email": "kuzmina-051971@postgrespro.ru", "phone": "+70883914936"}
0005433614143	BEA4AB	2148 068081	SERGEY VASILEV	{"phone": "+70745742083"}
0005433614144	FD9657	9739 250732	ANASTASIYA POPOVA	{"phone": "+70455965310"}
0005433614145	FD9657	5887 701707	SERGEY KARPOV	{"phone": "+70369797069"}
0005433614146	FD9657	4784 732742	GENNADIY POPOV	{"phone": "+70519596316"}
0005433614147	B8DBCF	0909 185974	ELENA MIRONOVA	{"email": "mironova_elena25081983@postgrespro.ru", "phone": "+70213520454"}
0005433614148	F5D67F	6283 179974	ANATOLIY ZAYCEV	{"email": "zaycev-anatoliy03091973@postgrespro.ru", "phone": "+70507750321"}
0005433614149	A8A928	8836 099993	VASILIY ZAYCEV	{"email": "vasiliy.zaycev.111985@postgrespro.ru", "phone": "+70004762172"}
0005433614150	A8A928	1954 147231	SERGEY ANTONOV	{"email": "sergey_antonov_1973@postgrespro.ru", "phone": "+70513797476"}
0005433614151	9CC5FD	8495 738500	RAISA KONOVALOVA	{"phone": "+70852118701"}
0005433614152	5AEBA8	4725 134344	FARIT NAZAROV	{"phone": "+70142213067"}
0005433614153	5AEBA8	4056 171084	LEV ABRAMOV	{"email": "abramov-l-1974@postgrespro.ru", "phone": "+70482941203"}
0005433614154	477D38	2686 758757	SVETLANA RODIONOVA	{"phone": "+70317048650"}
0005433614155	FF2DBF	2128 442060	ANDREY ZHURAVLEV	{"email": "a.zhuravlev-061965@postgrespro.ru", "phone": "+70640638896"}
0005433614156	02945F	0316 024541	ANDREY MAKSIMOV	{"phone": "+70939588657"}
0005433614157	A17FF2	3272 215004	LYUDMILA AKIMOVA	{"email": "l-akimova01011986@postgrespro.ru", "phone": "+70220395799"}
0005433614158	DCFEB9	4474 902125	EVGENIYA LOGINOVA	{"email": "evgeniya_loginova-1968@postgrespro.ru", "phone": "+70315623723"}
0005433614159	E34095	4216 960553	DMITRIY SERGEEV	{"email": "dsergeev17031978@postgrespro.ru", "phone": "+70270754360"}
0005433614160	37184A	9968 706875	YULIYA GRISHINA	{"phone": "+70621202762"}
0005433614161	EE377F	9814 496046	EVGENIY KAZAKOV	{"email": "kazakov_e.061971@postgrespro.ru", "phone": "+70931949384"}
0005433614162	4D2BBF	9966 992716	RUSLAN FEDOROV	{"email": "fedorovruslan-26091969@postgrespro.ru", "phone": "+70836135383"}
0005433614163	84B110	7047 250055	ALEKSANDR SOROKIN	{"phone": "+70269139911"}
0005433614164	64F9C0	7904 544833	MARIYA ANISIMOVA	{"phone": "+70967722498"}
0005433614165	348D5E	3619 681287	ANASTASIYA KISELEVA	{"phone": "+70735220460"}
0005433614166	46E555	9800 705280	LILIYA MALYSHEVA	{"email": "malysheva-l.11061982@postgrespro.ru", "phone": "+70003914510"}
0005433614167	A995A8	6079 628669	OLGA KARPOVA	{"phone": "+70122509814"}
0005433614168	A995A8	6771 196299	SVETLANA SIDOROVA	{"email": "sidorova-svetlana_041983@postgrespro.ru", "phone": "+70132014318"}
0005433614169	CCAF95	8037 252277	LYUDMILA LAZAREVA	{"email": "lazareva_lyudmila-051970@postgrespro.ru", "phone": "+70628043270"}
0005433614170	4758C5	4266 168100	EVGENIY KAZAKOV	{"email": "kazakov.e_051974@postgrespro.ru", "phone": "+70997525719"}
0005433614171	E6970B	8637 985959	ILYA SCHERBAKOV	{"email": "ischerbakov-28081968@postgrespro.ru", "phone": "+70188129335"}
0005433614172	B4A7C5	6149 362388	KONSTANTIN MAKAROV	{"phone": "+70931357253"}
0005433614173	B4A7C5	8006 043455	SVETLANA ORLOVA	{"phone": "+70054113826"}
0005433614174	94EB1F	9817 162164	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina081972@postgrespro.ru", "phone": "+70470480246"}
0005433614175	94EB1F	7915 547973	STANISLAV KARPOV	{"phone": "+70251325745"}
0005433614176	C4275C	9325 670355	NATALYA MOISEEVA	{"email": "natalyamoiseeva-051974@postgrespro.ru", "phone": "+70452172756"}
0005433614177	C4275C	9344 230499	VALERIY TARASOV	{"phone": "+70041646774"}
0005433614178	6D300A	5927 084641	EKATERINA POPOVA	{"email": "popova-e_021968@postgrespro.ru", "phone": "+70384242142"}
0005433614179	1D6E3A	2739 057830	VIKTORIYA LUKYANOVA	{"phone": "+70145068775"}
0005433614180	1D6E3A	7927 583530	MARIYA ABRAMOVA	{"email": "abramova.mariya.21011966@postgrespro.ru", "phone": "+70418777550"}
0005433614181	03FC4C	0905 647096	ANDREY ILIN	{"email": "ailin-10041972@postgrespro.ru", "phone": "+70313042110"}
0005433614182	03FC4C	9120 801387	GEORGIY KUZNECOV	{"email": "g.kuznecov1974@postgrespro.ru", "phone": "+70007902805"}
0005433614183	30BFD7	3300 972655	VALENTINA KRASNOVA	{"email": "krasnova-v29051973@postgrespro.ru", "phone": "+70805781938"}
0005433614184	57DE53	4515 180450	IRINA DAVYDOVA	{"email": "davydova_i-101960@postgrespro.ru", "phone": "+70187772669"}
0005433614185	57DE53	9286 844866	NATALYA SAVELEVA	{"phone": "+70515858306"}
0005433614186	57DE53	3205 042458	TAMARA SMIRNOVA	{"phone": "+70661624229"}
0005433614187	B75E55	1782 454692	DENIS OSIPOV	{"email": "d_osipov-1969@postgrespro.ru", "phone": "+70046747760"}
0005433614188	B75E55	4144 147229	TAMARA ORLOVA	{"email": "orlova-tamara.30101974@postgrespro.ru", "phone": "+70857404399"}
0005433614189	93A406	1384 592461	YURIY KUZMIN	{"email": "ykuzmin111971@postgrespro.ru", "phone": "+70216577943"}
0005433614190	BD1585	0817 980567	EVGENIYA KUZNECOVA	{"phone": "+70966051750"}
0005433614191	BD1585	8118 085712	VALENTINA NESTEROVA	{"phone": "+70548210489"}
0005433614192	C0F4F6	4898 912494	DMITRIY PETROV	{"email": "petrovd_121967@postgrespro.ru", "phone": "+70467046999"}
0005433614193	AE61AB	7656 627576	ANDREY NIKITIN	{"phone": "+70374739773"}
0005433614194	AE61AB	7666 586758	LYUDMILA GERASIMOVA	{"phone": "+70884555659"}
0005433614195	6DEBA6	1390 670313	EKATERINA FEDOROVA	{"phone": "+70044855988"}
0005433614196	6DEBA6	9851 260321	RAISA LOGINOVA	{"email": "loginova.r.15081969@postgrespro.ru", "phone": "+70094138591"}
0005433614197	EABD14	5278 857585	SERGEY BELOV	{"phone": "+70475394862"}
0005433614198	EABD14	2215 893517	DMITRIY FEDOTOV	{"email": "fedotov_dmitriy011965@postgrespro.ru", "phone": "+70840640412"}
0005433614199	5B9F29	8379 924129	LINAR IVANOV	{"phone": "+70465376483"}
0005433614200	D43375	5174 951339	VLADIMIR POPOV	{"phone": "+70923421556"}
0005433614201	0E908E	8975 579651	VALENTINA SEMENOVA	{"email": "v_semenova011980@postgrespro.ru", "phone": "+70961502585"}
0005433614202	881F66	5707 625319	VALERIY STEPANOV	{"email": "stepanovv.111980@postgrespro.ru", "phone": "+70282944322"}
0005433614203	22075C	1822 625958	PAVEL OSIPOV	{"phone": "+70443604305"}
0005433614204	769F20	8798 223469	ANNA PAVLOVA	{"email": "pavlova.anna1978@postgrespro.ru", "phone": "+70715128368"}
0005433614205	7A6DDA	8170 714593	ANATOLIY KULIKOV	{"phone": "+70845202486"}
0005433614206	7A8A97	0621 680768	ANASTASIYA KOZLOVA	{"email": "anastasiya-kozlova.071961@postgrespro.ru", "phone": "+70603413721"}
0005433614207	8D18E4	8581 349903	DARYA DMITRIEVA	{"phone": "+70032035329"}
0005433614208	28B986	7847 711906	VLADISLAV TARASOV	{"phone": "+70923382111"}
0005433614209	D5526E	6822 803564	EMIL DMITRIEV	{"phone": "+70486363024"}
0005433614210	E17818	6067 271296	GALINA SCHERBAKOVA	{"phone": "+70214769670"}
0005433614211	E17818	6781 317778	NATALIYA IVANOVA	{"email": "ivanovanataliya-1966@postgrespro.ru", "phone": "+70379431948"}
0005433614212	D1F9E5	6482 374612	PETR YAKOVLEV	{"email": "petr-yakovlev19051982@postgrespro.ru", "phone": "+70363077763"}
0005433614213	E3C314	9817 456453	OLGA STEPANOVA	{"email": "o-stepanova.1972@postgrespro.ru", "phone": "+70385474895"}
0005433614214	792F04	7452 819268	YURIY VASILEV	{"email": "vasilev-yuriy.011977@postgrespro.ru", "phone": "+70223958076"}
0005433614215	9E3639	8138 367159	FANIL KUZNECOV	{"email": "fanilkuznecov1975@postgrespro.ru", "phone": "+70361431467"}
0005433614216	6C65B7	8869 251281	SVETLANA BARANOVA	{"email": "baranova_s091960@postgrespro.ru", "phone": "+70199420088"}
0005433614217	6C65B7	0775 349634	NIKOLAY KUZNECOV	{"email": "nikolaykuznecov06071971@postgrespro.ru", "phone": "+70530365143"}
0005433614218	3EA357	6511 288765	MARINA KUZMINA	{"email": "m_kuzmina041974@postgrespro.ru", "phone": "+70405165341"}
0005433614219	3EA357	1627 634164	DMITRIY ZHURAVLEV	{"email": "dmitriy_zhuravlev1967@postgrespro.ru", "phone": "+70551350836"}
0005433614220	422578	2688 088207	PETR NIKOLAEV	{"phone": "+70435530259"}
0005433614221	422578	9920 408518	VYACHESLAV DMITRIEV	{"email": "dmitriev.v_1971@postgrespro.ru", "phone": "+70289166255"}
0005433614222	361356	8565 817467	IVAN MOROZOV	{"phone": "+70061584201"}
0005433614223	AE8B62	5293 738371	DENIS ZHURAVLEV	{"email": "denis_zhuravlev_1977@postgrespro.ru", "phone": "+70908550629"}
0005433614224	590393	8398 962298	ANASTASIYA VOLKOVA	{"email": "volkova.a_041973@postgrespro.ru", "phone": "+70801102383"}
0005433614225	590393	3178 908138	EKATERINA GUSEVA	{"phone": "+70886321173"}
0005433614226	82ADA4	4759 257604	ALEKSANDRA FOMINA	{"phone": "+70889261899"}
0005433614227	D071AF	5815 784467	SOFYA KONDRATEVA	{"phone": "+70407477922"}
0005433614228	981A18	5269 071683	TATYANA MAKAROVA	{"phone": "+70758597655"}
0005433614229	FB1863	5030 918818	NINA CHERNOVA	{"phone": "+70443467202"}
0005433614230	FB1863	0076 271175	VASILIY KONOVALOV	{"phone": "+70686836855"}
0005433614231	884FDB	9262 302124	SERGEY SCHERBAKOV	{"email": "sscherbakov_08011979@postgrespro.ru", "phone": "+70776108094"}
0005433614232	884FDB	3304 606630	EVDOKIYA GRISHINA	{"phone": "+70949001421"}
0005433614233	9953A9	6616 207805	DMITRIY SERGEEV	{"email": "dmitriy-sergeev1973@postgrespro.ru", "phone": "+70320971422"}
0005433614234	9953A9	8625 551364	NATALYA SEMENOVA	{"email": "semenova-n04101970@postgrespro.ru", "phone": "+70391385847"}
0005433614235	60282C	3330 121612	LYUDMILA FILATOVA	{"email": "lfilatova061974@postgrespro.ru", "phone": "+70162113257"}
0005433614236	BDCC72	3540 826834	SOFYA LEBEDEVA	{"email": "sofya_lebedeva-21081968@postgrespro.ru", "phone": "+70964809552"}
0005433614237	3C7517	8627 784082	NINA SERGEEVA	{"phone": "+70456241843"}
0005433614238	8756DC	1146 534106	ANASTASIYA BORISOVA	{"phone": "+70363389277"}
0005433614239	2B3BC0	9147 857054	ALEKSEY ILIN	{"phone": "+70941177810"}
0005433614240	2B3BC0	3244 853367	NATALYA BORISOVA	{"email": "borisova.n091973@postgrespro.ru", "phone": "+70992194092"}
0005433614241	6B6A8B	5309 289068	VITALIY SMIRNOV	{"email": "smirnov_vitaliy_091974@postgrespro.ru", "phone": "+70051414438"}
0005433614242	A5AA52	3718 179757	MARIYA VASILEVA	{"email": "vasileva-m_021971@postgrespro.ru", "phone": "+70126790725"}
0005433614243	45C055	9136 326982	MARIYA VOLKOVA	{"phone": "+70796388294"}
0005433614244	834A59	3751 647015	SERGEY ROMANOV	{"email": "romanovsergey_02021979@postgrespro.ru", "phone": "+70174222994"}
0005433614245	D64C9D	8043 818786	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr-1979@postgrespro.ru", "phone": "+70040384546"}
0005433614246	5ABADF	7490 500574	OLGA ANISIMOVA	{"phone": "+70502140988"}
0005433614247	5ABADF	9023 432974	EKATERINA FOMINA	{"email": "fomina-e.1971@postgrespro.ru", "phone": "+70930037255"}
0005433614248	5ABADF	0563 767684	DENIS AFANASEV	{"email": "afanasev.d_081976@postgrespro.ru", "phone": "+70663414798"}
0005433614249	AA26B1	1684 442991	SERGEY ANDREEV	{"email": "andreev.s.25041977@postgrespro.ru", "phone": "+70527627845"}
0005433614250	6C0122	5796 422579	ELENA SOLOVEVA	{"email": "e-soloveva11061959@postgrespro.ru", "phone": "+70365777457"}
0005433614251	6C0122	9143 129510	NADEZHDA TIMOFEEVA	{"email": "timofeeva_n10081968@postgrespro.ru", "phone": "+70969450832"}
0005433614252	5D6DBB	2668 519012	KIRILL KUZMIN	{"email": "kirill_kuzmin.071976@postgrespro.ru", "phone": "+70934992641"}
0005433614253	2687C5	7446 068697	ALEKSANDRA SEMENOVA	{"email": "semenova-a1969@postgrespro.ru", "phone": "+70152232598"}
0005433614254	6B56A5	5386 201698	LYUDMILA NIKIFOROVA	{"email": "lyudmila-nikiforova_07091969@postgrespro.ru", "phone": "+70934948994"}
0005433614255	3CD0E2	5974 210250	NIKOLAY DAVYDOV	{"phone": "+70468258789"}
0005433614256	04AA44	4904 211038	LARISA KUZNECOVA	{"email": "kuznecova.l-071971@postgrespro.ru", "phone": "+70174743901"}
0005433614257	905FD7	2962 771622	SVETLANA NOVIKOVA	{"phone": "+70393794397"}
0005433614258	905FD7	0054 334876	ANASTASIYA VOLKOVA	{"email": "avolkova1980@postgrespro.ru", "phone": "+70396635810"}
0005433614259	80AD3F	6383 390890	FAIL KUZNECOV	{"email": "fkuznecov24071984@postgrespro.ru", "phone": "+70762914911"}
0005433614260	A92B6F	8837 815164	MARIYA SIDOROVA	{"email": "m_sidorova-09061968@postgrespro.ru", "phone": "+70976082493"}
0005433614261	5CCD53	4868 643893	ANATOLIY ORLOV	{"phone": "+70950403271"}
0005433614262	5CCD53	5157 950317	ANASTASIYA FEDOROVA	{"email": "a-fedorova_1969@postgrespro.ru", "phone": "+70130203558"}
0005433614263	9D9A7C	6572 731620	TATYANA BOGDANOVA	{"email": "tbogdanova.021976@postgrespro.ru", "phone": "+70080050648"}
0005433614264	CF4309	2255 875483	ZHANNA TROFIMOVA	{"phone": "+70061647180"}
0005433614265	CD658E	8723 296766	NATALYA LEBEDEVA	{"phone": "+70567828777"}
0005433614266	DC6ECE	7558 631284	VIKTOR POPOV	{"email": "viktorpopov-1967@postgrespro.ru", "phone": "+70651418038"}
0005433614267	B13D3E	4819 505966	NIKOLAY DENISOV	{"phone": "+70024620974"}
0005433614268	66F3CD	5006 698906	LYUDMILA KISELEVA	{"phone": "+70862729569"}
0005433614269	48855B	7279 344443	ANTON IVANOV	{"email": "anton-ivanov_1986@postgrespro.ru", "phone": "+70114002818"}
0005433614270	890CD9	8257 116948	DAVID NIKOLAEV	{"email": "d_nikolaev-091967@postgrespro.ru", "phone": "+70097252697"}
0005433614271	890CD9	6575 747803	VERA ALEKSANDROVA	{"phone": "+70014018610"}
0005433614272	B89F1D	7528 735838	ANASTASIYA TARASOVA	{"email": "tarasovaanastasiya.14041974@postgrespro.ru", "phone": "+70889544437"}
0005433614273	88AC43	3190 654047	ANDREY AFANASEV	{"email": "afanasev-andrey-041962@postgrespro.ru", "phone": "+70619288609"}
0005433614274	88AC43	8958 962917	SERGEY KUZNECOV	{"email": "kuznecovs-1971@postgrespro.ru", "phone": "+70217394362"}
0005433614275	BAFC09	0880 870900	EVGENIYA GRISHINA	{"phone": "+70558023469"}
0005433614276	DD547D	2142 257894	ELENA NIKITINA	{"phone": "+70552988422"}
0005433614277	4348F1	9012 676674	RUSTAM YAKOVLEV	{"email": "yakovlev.rustam-1972@postgrespro.ru", "phone": "+70379300277"}
0005433614278	84DCD1	9055 502910	MAKSIM BELOV	{"phone": "+70376609948"}
0005433614279	D49760	7808 943083	VLADIMIR KULIKOV	{"phone": "+70049564616"}
0005433614280	D5B82B	8535 033892	MIKHAIL PAVLOV	{"email": "pavlov-m1980@postgrespro.ru", "phone": "+70925598166"}
0005433614281	D5B82B	1924 193425	IVAN DMITRIEV	{"email": "ivan.dmitriev_1969@postgrespro.ru", "phone": "+70883197745"}
0005433614282	1E727B	1091 970324	GALINA SIDOROVA	{"phone": "+70115355123"}
0005433614283	1E727B	1158 667705	VALENTIN KRASNOV	{"phone": "+70849487740"}
0005433614284	1E727B	7159 374602	ALEKSEY NIKOLAEV	{"email": "a.nikolaev25061963@postgrespro.ru", "phone": "+70068489371"}
0005433614285	916172	6333 296858	VALENTINA FILATOVA	{"phone": "+70741306975"}
0005433614286	531697	6562 267047	ROMAN NIKOLAEV	{"email": "roman.nikolaev_05111968@postgrespro.ru", "phone": "+70261881247"}
0005433614287	531697	1707 070216	ANATOLIY KOROLEV	{"email": "a.korolev1973@postgrespro.ru", "phone": "+70981950264"}
0005433614288	B66944	6336 564896	NATALYA ILINA	{"phone": "+70900685807"}
0005433614289	B66944	0577 998876	OLGA SOROKINA	{"phone": "+70245600666"}
0005433614290	BB629F	0789 879154	SERGEY ISAEV	{"email": "s-isaev25091970@postgrespro.ru", "phone": "+70619929088"}
0005433614291	B3A380	6960 747828	VLADIMIR FROLOV	{"email": "frolovvladimir-061970@postgrespro.ru", "phone": "+70743025344"}
0005433614292	B3A380	4851 811699	NIKOLAY NIKITIN	{"email": "nikitin-n121974@postgrespro.ru", "phone": "+70667453964"}
0005433614293	B745AE	6939 864932	MAKSIM DMITRIEV	{"phone": "+70161059374"}
0005433614294	DE23F4	5092 679851	YULIYA ZAKHAROVA	{"phone": "+70070558901"}
0005433614295	1CDB81	7430 887827	SERGEY IVANOV	{"phone": "+70394521822"}
0005433614296	1CDB81	4522 625222	VLADIMIR MIKHAYLOV	{"phone": "+70774773817"}
0005433614297	E59DA9	6551 125805	IGOR NIKITIN	{"phone": "+70613893672"}
0005433614298	E59DA9	7120 952152	ELENA ALEKSANDROVA	{"email": "aleksandrova-elena_1961@postgrespro.ru", "phone": "+70203074091"}
0005433614299	2F2411	2005 897042	MAYYA MAKAROVA	{"phone": "+70298040191"}
0005433614300	42010F	8355 186709	NIKOLAY KUZNECOV	{"phone": "+70928934149"}
0005433614301	7B34A4	1313 805945	DMITRIY ZAYCEV	{"email": "dzaycev-051970@postgrespro.ru", "phone": "+70150630456"}
0005433614302	B16020	8593 034053	ELENA POPOVA	{"phone": "+70148206155"}
0005433614303	C2C8CC	5901 089032	ALEKSANDR SAVELEV	{"phone": "+70138642328"}
0005433614304	C2C8CC	7387 122235	ARTEM MOISEEV	{"phone": "+70674094309"}
0005433614305	A07B50	1763 553149	VALENTIN KAZAKOV	{"email": "kazakov_v_041968@postgrespro.ru", "phone": "+70692523706"}
0005433614306	B24194	0996 410815	VIKTORIYA PAVLOVA	{"phone": "+70873210429"}
0005433614307	51C882	6745 114556	SERGEY KISELEV	{"email": "sergey-kiselev.10051972@postgrespro.ru", "phone": "+70355163292"}
0005433614308	AB8090	4396 913184	ANDREY SMIRNOV	{"email": "smirnov.andrey-07111966@postgrespro.ru", "phone": "+70502042358"}
0005433614309	5C4B48	9468 177677	TAMARA KRASNOVA	{"phone": "+70506303607"}
0005433614310	4ECD95	4540 875411	MIKHAIL ANTONOV	{"phone": "+70916222337"}
0005433614311	7B530F	0846 554877	LYUDMILA ORLOVA	{"email": "l.orlova.27021965@postgrespro.ru", "phone": "+70828619664"}
0005433614312	4CDA3C	4670 059072	ROMAN KONOVALOV	{"email": "romankonovalov.07021970@postgrespro.ru", "phone": "+70507559363"}
0005433614313	C4DB58	8870 607529	NINA ERMAKOVA	{"email": "n-ermakova12121972@postgrespro.ru", "phone": "+70522871240"}
0005433614314	776651	1207 279783	ANDREY MIRONOV	{"phone": "+70810928795"}
0005433614315	776651	9579 204330	ZINAIDA ANTONOVA	{"email": "antonova-zinaida1977@postgrespro.ru", "phone": "+70972112566"}
0005433614316	781CE0	0680 004005	ALENA SCHERBAKOVA	{"phone": "+70915145002"}
0005433614317	FA5817	2565 344108	VIKTOR GUSEV	{"phone": "+70130066404"}
0005433614318	926451	7802 833882	ROMAN IVANOV	{"email": "ivanovr_021978@postgrespro.ru", "phone": "+70815228177"}
0005433614319	926451	6733 066497	NATALYA YAKOVLEVA	{"phone": "+70091242643"}
0005433614320	EBA0E6	5608 552374	GENNADIY ALEKSEEV	{"phone": "+70606725318"}
0005433614321	EBA0E6	0037 588494	LIDIYA BARANOVA	{"phone": "+70135970444"}
0005433614322	EBA0E6	5829 831306	LARISA YAKOVLEVA	{"email": "yakovleva.larisa_1974@postgrespro.ru", "phone": "+70199034496"}
0005433614323	416A0E	7441 202665	DMITRIY YAKOVLEV	{"phone": "+70999867157"}
0005433614324	416A0E	5768 080876	EVGENIY KOROLEV	{"phone": "+70002531874"}
0005433614325	416A0E	5814 315315	IRINA POTAPOVA	{"phone": "+70244585395"}
0005433614326	A86374	6479 840320	PAVEL BORISOV	{"phone": "+70092852354"}
0005433614327	FBCA5D	9751 430699	YURIY VOLKOV	{"email": "y.volkov15031987@postgrespro.ru", "phone": "+70854877819"}
0005433614328	FBCA5D	4636 113975	EVGENIY OSIPOV	{"phone": "+70441963513"}
0005433614329	3965F4	2319 950255	VLADIMIR MOISEEV	{"email": "moiseev-vladimir1981@postgrespro.ru", "phone": "+70255427030"}
0005433614330	C78564	4224 728915	TATYANA MAKAROVA	{"phone": "+70326177813"}
0005433614331	18FB62	0902 435456	ZOYA GAVRILOVA	{"email": "z_gavrilova1965@postgrespro.ru", "phone": "+70388697239"}
0005433614332	4E6DC0	1731 170929	RUSLAN GAVRILOV	{"phone": "+70938737312"}
0005433614333	4E6DC0	1999 733091	ANNA AKIMOVA	{"phone": "+70416861914"}
0005433614334	8E2CD7	1513 279259	ELIZAVETA ISAEVA	{"email": "isaeva_elizaveta-1966@postgrespro.ru", "phone": "+70117954645"}
0005433614335	ABB66F	9347 333460	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev.1980@postgrespro.ru", "phone": "+70231722432"}
0005433614336	88B33E	1682 221033	DMITRIY DAVYDOV	{"email": "d_davydov.061973@postgrespro.ru", "phone": "+70067130642"}
0005433614337	88B33E	3749 958190	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov_1972@postgrespro.ru", "phone": "+70022076269"}
0005433614338	4BD5CE	7418 010803	NINA ERMAKOVA	{"email": "nina-ermakova1977@postgrespro.ru", "phone": "+70845454916"}
0005433614339	D2582A	6488 154409	YURIY DENISOV	{"phone": "+70775048606"}
0005433614340	CB19E6	8289 783134	ALEKSANDRA KULIKOVA	{"email": "a_kulikova_14021970@postgrespro.ru", "phone": "+70319418672"}
0005433614341	CB19E6	0544 061801	TATYANA ZAYCEVA	{"email": "tatyanazayceva-28041957@postgrespro.ru", "phone": "+70488648047"}
0005433614342	CE0519	5406 342765	LYUBOV SOKOLOVA	{"phone": "+70516695256"}
0005433614343	CE0519	1335 876462	ELENA SEMENOVA	{"phone": "+70716513198"}
0005433614344	3F03DC	2645 696930	NATALYA GORBUNOVA	{"phone": "+70842694482"}
0005433614345	3F03DC	0367 887918	VALERIY MIRONOV	{"email": "vmironov.051961@postgrespro.ru", "phone": "+70348869417"}
0005433614346	4B9F4F	5206 553840	LYUBOV GRISHINA	{"phone": "+70050830162"}
0005433614347	E2565A	8417 474941	ANNA DMITRIEVA	{"email": "a.dmitrieva-031977@postgrespro.ru", "phone": "+70102885989"}
0005433614348	F3C418	9824 010932	KIRILL FEDOROV	{"email": "k-fedorov_1972@postgrespro.ru", "phone": "+70855572083"}
0005433614349	437C3B	8772 994055	NIKOLAY MIKHAYLOV	{"email": "nikolay_mikhaylov24111960@postgrespro.ru", "phone": "+70157692567"}
0005433614350	437C3B	1020 670784	MARINA DENISOVA	{"email": "m_denisova.14121965@postgrespro.ru", "phone": "+70681778183"}
0005433614351	13A642	8743 172771	SERGEY RODIONOV	{"email": "sergey_rodionov.17041977@postgrespro.ru", "phone": "+70290317188"}
0005433614352	B2BA6B	8584 324197	NIKOLAY FOMIN	{"phone": "+70137764429"}
0005433614353	BEC522	1195 917003	DARYA SOLOVEVA	{"email": "solovevadarya.091968@postgrespro.ru", "phone": "+70819599872"}
0005433614354	BEC522	8544 373478	SERGEY KAZAKOV	{"email": "skazakov081972@postgrespro.ru", "phone": "+70419663144"}
0005433614355	19035E	7083 237348	VASILIY NIKOLAEV	{"phone": "+70110873505"}
0005433614356	BB575D	3430 846435	ALEKSEY SOROKIN	{"email": "a_sorokin1975@postgrespro.ru", "phone": "+70494898513"}
0005433614357	B04612	5495 887173	DMITRIY GUSEV	{"email": "d_gusev.08071980@postgrespro.ru", "phone": "+70134988434"}
0005433614358	7266D9	6323 800746	SERGEY SHEVCHENKO	{"phone": "+70452995507"}
0005433614359	BAA3AD	4273 233542	SERGEY SCHERBAKOV	{"phone": "+70586053637"}
0005433614360	49D8CE	8550 196037	DENIS KONOVALOV	{"email": "konovalov.denis.06061977@postgrespro.ru", "phone": "+70348880532"}
0005433614361	4EF773	0965 794535	VLADIMIR FEDOROV	{"phone": "+70735393755"}
0005433614362	4EF773	1744 994791	ELENA POPOVA	{"email": "popova_e_1974@postgrespro.ru", "phone": "+70736539662"}
0005433614363	194B06	1166 687657	MIKHAIL YAKOVLEV	{"email": "m-yakovlev121978@postgrespro.ru", "phone": "+70400778831"}
0005433614364	053EFD	8781 064705	VALENTINA MAKAROVA	{"email": "makarova_valentina13061961@postgrespro.ru", "phone": "+70069265637"}
0005433614365	053EFD	9023 966052	EVGENIYA LEBEDEVA	{"email": "lebedeva-evgeniya12071972@postgrespro.ru", "phone": "+70153059073"}
0005433614366	CB47DB	7208 069283	NATALYA SERGEEVA	{"email": "sergeevan051971@postgrespro.ru", "phone": "+70086569785"}
0005433614367	14F016	1254 712924	GEORGIY PAVLOV	{"email": "georgiy_pavlov.041968@postgrespro.ru", "phone": "+70812292454"}
0005433614368	AA16DA	4727 550721	SERGEY OSIPOV	{"email": "osipovs.011972@postgrespro.ru", "phone": "+70165367415"}
0005433614369	AA16DA	0320 427556	OLGA GAVRILOVA	{"phone": "+70239546517"}
0005433614370	AA16DA	6887 115222	SULTAN MIRONOV	{"phone": "+70601635058"}
0005433614371	6B1D36	6006 687189	GERMAN KUZMIN	{"email": "germankuzmin.1970@postgrespro.ru", "phone": "+70754099725"}
0005433614372	BBAB31	8954 911141	OKSANA MAKAROVA	{"email": "makarova_oksana.11041972@postgrespro.ru", "phone": "+70541220928"}
0005433614373	89DBCB	9949 545590	TATYANA ZAYCEVA	{"email": "zayceva.t.1960@postgrespro.ru", "phone": "+70947160338"}
0005433614374	379038	2347 330193	VALERIY ZHUKOV	{"email": "valeriyzhukov041959@postgrespro.ru", "phone": "+70439116421"}
0005433614375	379038	8622 007533	ANDREY KULIKOV	{"phone": "+70605619465"}
0005433614376	A4FED6	4827 619916	DMITRIY BONDARENKO	{"email": "bondarenkodmitriy-29111980@postgrespro.ru", "phone": "+70501428567"}
0005433614377	A4FED6	1261 445308	ALEKSEY NIKOLAEV	{"phone": "+70557064534"}
0005433614378	C9EFF7	1581 452117	VYACHESLAV SCHERBAKOV	{"email": "v_scherbakov.011968@postgrespro.ru", "phone": "+70818220011"}
0005433614379	C9EFF7	0091 877119	ALISA KISELEVA	{"email": "kiseleva-alisa25061969@postgrespro.ru", "phone": "+70253469899"}
0005433614380	C9EFF7	1508 881494	ALEKSANDR MOROZOV	{"phone": "+70451443437"}
0005433614381	5FFD8D	6384 698450	SVETLANA SOROKINA	{"phone": "+70321234385"}
0005433614382	5FFD8D	8861 693630	SVETLANA EGOROVA	{"phone": "+70365661384"}
0005433614383	61B118	6724 045098	NINA KOZLOVA	{"phone": "+70626223754"}
0005433614384	719EFE	2497 920889	SVETLANA SIDOROVA	{"phone": "+70543455354"}
0005433614385	9E86AA	4262 108813	NADEZHDA PAVLOVA	{"email": "nadezhda-pavlova_25071971@postgrespro.ru", "phone": "+70227895196"}
0005433614386	969FF0	2959 130213	PAVEL KARPOV	{"phone": "+70703966268"}
0005433614387	5A0C1F	4827 630093	VLADIMIR SCHERBAKOV	{"phone": "+70771681073"}
0005433614388	5A0C1F	3806 734501	VALENTINA IVANOVA	{"email": "ivanova-valentina091963@postgrespro.ru", "phone": "+70385698483"}
0005433614389	5A0C1F	7231 820771	ALEKSANDR FROLOV	{"email": "frolov.aleksandr_081967@postgrespro.ru", "phone": "+70224028523"}
0005433614390	3A837F	8575 635634	OKSANA VLASOVA	{"phone": "+70256228421"}
0005433614391	AF3082	3072 034217	EKATERINA NAZAROVA	{"phone": "+70483360513"}
0005433614392	52E8D4	6699 226778	NIKOLAY ALEKSANDROV	{"email": "nikolay.aleksandrov_1973@postgrespro.ru", "phone": "+70874339793"}
0005433614393	FAC0E6	1035 257954	VALERIY SCHERBAKOV	{"email": "scherbakovv_1977@postgrespro.ru", "phone": "+70194043920"}
0005433614394	FAC0E6	9630 785428	VIKTORIYA NAZAROVA	{"email": "nazarovaviktoriya-1963@postgrespro.ru", "phone": "+70110843626"}
0005433614395	975E7D	5155 290501	NADEZHDA VOLKOVA	{"phone": "+70060611622"}
0005433614396	69DD9F	2306 411018	ANASTASIYA ILINA	{"email": "ilina.anastasiya081973@postgrespro.ru", "phone": "+70093647032"}
0005433614397	4B76CB	5991 406261	OLGA GERASIMOVA	{"phone": "+70598348409"}
0005433614398	D97BDF	9326 495578	YULIYA NAZAROVA	{"phone": "+70476046508"}
0005433614399	772650	7752 625086	NATALYA BORISOVA	{"phone": "+70283091843"}
0005433614400	2F8ABA	3350 775597	NADEZHDA POPOVA	{"phone": "+70060225523"}
0005433614401	341BF9	8347 254844	ELENA LEBEDEVA	{"email": "e_lebedeva_05011981@postgrespro.ru", "phone": "+70854415765"}
0005433614402	10AD0E	8173 011971	ALISHER DMITRIEV	{"phone": "+70082422087"}
0005433614403	4E9171	3824 329107	NATALYA ANISIMOVA	{"phone": "+70971167076"}
0005433614404	4E9171	3963 177709	NADEZHDA MAKSIMOVA	{"email": "maksimovan.11021978@postgrespro.ru", "phone": "+70190678310"}
0005433614405	172D92	1351 429820	MAKSIM TIKHONOV	{"email": "tikhonov-maksim10011968@postgrespro.ru", "phone": "+70324354046"}
0005433614406	C0C844	1572 918526	MAKSIM IVANOV	{"email": "ivanovm-21121966@postgrespro.ru", "phone": "+70907526261"}
0005433614407	8F96C2	4677 971972	VALENTINA NIKIFOROVA	{"email": "nikiforova_v.041967@postgrespro.ru", "phone": "+70568808138"}
0005433614408	33C30E	3406 616877	ILYA YAKOVLEV	{"phone": "+70733551561"}
0005433614409	33C30E	8282 954006	NINA POLYAKOVA	{"email": "polyakova-nina_071973@postgrespro.ru", "phone": "+70828513461"}
0005433614410	C0F67C	8196 806216	GULNARA GERASIMOVA	{"email": "g.gerasimova.24011970@postgrespro.ru", "phone": "+70822602058"}
0005433614411	C0F67C	4351 485097	PETR ROMANOV	{"phone": "+70659795426"}
0005433614412	85837A	1622 598623	ALEKSANDR BONDARENKO	{"phone": "+70291443951"}
0005433614413	E6B72B	2424 473126	SERGEY BORISOV	{"phone": "+70316938161"}
0005433614414	96770B	1556 876583	ALEKSANDR SMIRNOV	{"phone": "+70943955440"}
0005433614415	1ED7FD	4198 220173	ILYA GUSEV	{"email": "ilya_gusev.081966@postgrespro.ru", "phone": "+70054910017"}
0005433614416	51DDEE	9662 987931	ANASTASIYA KUZNECOVA	{"email": "akuznecova_1980@postgrespro.ru", "phone": "+70027871240"}
0005433614417	A42465	9824 832829	EKATERINA MIRONOVA	{"email": "e_mironova031962@postgrespro.ru", "phone": "+70415662077"}
0005433614418	A42465	1815 693162	NATALYA LAZAREVA	{"email": "n-lazareva_1970@postgrespro.ru", "phone": "+70947835896"}
0005433614419	A55D0F	3035 267852	SULTAN MELNIKOV	{"email": "melnikov_s-021967@postgrespro.ru", "phone": "+70489861828"}
0005433614420	A55D0F	3759 193368	EVGENIY MIKHAYLOV	{"phone": "+70014903609"}
0005433614421	7EA416	2835 342025	NELYA KARPOVA	{"email": "karpova.nelya_111972@postgrespro.ru", "phone": "+70425216148"}
0005433614422	0A2FB2	2681 255454	NIKITA SOKOLOV	{"phone": "+70435942751"}
0005433614423	5D69DC	0421 992464	NATALYA KALININA	{"phone": "+70768326782"}
0005433614424	C0C4AD	0881 516312	LEONID TIMOFEEV	{"phone": "+70426006823"}
0005433614425	C0C4AD	9972 111790	ZINAIDA MOROZOVA	{"email": "z_morozova_101965@postgrespro.ru", "phone": "+70974322545"}
0005433614426	E5C27F	7601 247657	MARIYA DAVYDOVA	{"email": "davydova.m.12041967@postgrespro.ru", "phone": "+70641680592"}
0005433614427	C479EE	1459 232433	ANASTASIYA KUZMINA	{"email": "kuzmina.a1969@postgrespro.ru", "phone": "+70233796155"}
0005433614428	ABF45D	3024 958076	VLADISLAV VLASOV	{"email": "vladislav_vlasov07121966@postgrespro.ru", "phone": "+70198195911"}
0005433614429	82515E	2323 036553	NADEZHDA PAVLOVA	{"email": "pavlova-n_071975@postgrespro.ru", "phone": "+70896574729"}
0005433614430	25438A	7359 410395	IGOR POPOV	{"email": "popovigor_14021971@postgrespro.ru", "phone": "+70105205351"}
0005433614431	645811	4338 828392	ALEKSANDR IVANOV	{"phone": "+70446424867"}
0005433614432	645811	2804 994249	OLGA ANDREEVA	{"email": "andreeva-o_051967@postgrespro.ru", "phone": "+70259585452"}
0005433614433	999813	7943 258351	ANDREY MAKAROV	{"email": "andrey_makarov-01051967@postgrespro.ru", "phone": "+70702465831"}
0005433614434	C6999D	8731 006058	VLADIMIR POPOV	{"email": "popov-vladimir_25121975@postgrespro.ru", "phone": "+70720067207"}
0005433614435	7E065E	9166 279943	YURIY BORISOV	{"phone": "+70112589616"}
0005433614436	255448	0504 842086	OKSANA NESTEROVA	{"email": "o-nesterova.1965@postgrespro.ru", "phone": "+70832495256"}
0005433614437	F7CFAB	1642 674715	KONSTANTIN MOISEEV	{"email": "kmoiseev-1983@postgrespro.ru", "phone": "+70417979340"}
0005433614438	F7CFAB	5185 375538	MARIYA ZHUKOVA	{"email": "m_zhukova.13091966@postgrespro.ru", "phone": "+70324225045"}
0005433614439	9E56D7	9435 936987	ROMAN SHEVCHENKO	{"phone": "+70775974611"}
0005433614440	A5863B	9392 991860	ALEKSANDR POPOV	{"email": "popov-a-14081958@postgrespro.ru", "phone": "+70844653421"}
0005433614441	D44C58	0230 465487	ELENA ZAKHAROVA	{"phone": "+70316255441"}
0005433614442	D44C58	0565 629461	ELENA MALYSHEVA	{"email": "emalysheva.28071984@postgrespro.ru", "phone": "+70718514576"}
0005433614443	C37923	3977 313311	ALEKSEY KOZLOV	{"phone": "+70990573967"}
0005433614444	CDB425	7753 574965	TATYANA MAKAROVA	{"email": "tatyana.makarova.041969@postgrespro.ru", "phone": "+70503188938"}
0005433614445	237FC6	7107 562292	RAFAIL NAUMOV	{"email": "r.naumov-25041972@postgrespro.ru", "phone": "+70775141030"}
0005433614446	237FC6	6155 119342	LYUDMILA ORLOVA	{"email": "orlova.lyudmila-1980@postgrespro.ru", "phone": "+70340664006"}
0005433614447	D08155	0737 802663	ALENA MELNIKOVA	{"email": "melnikova-alena_011970@postgrespro.ru", "phone": "+70099289437"}
0005433614448	77FD20	4993 523901	VALENTIN DENISOV	{"phone": "+70904556587"}
0005433614449	A4E98D	0397 467707	ANASTASIYA MIRONOVA	{"email": "mironova-anastasiya071972@postgrespro.ru", "phone": "+70388400888"}
0005433614450	B52952	6272 981899	VITALIY SIDOROV	{"email": "sidorov-v1972@postgrespro.ru", "phone": "+70548433464"}
0005433614451	B52952	2529 758456	SERGEY ROMANOV	{"email": "romanovsergey_1962@postgrespro.ru", "phone": "+70397922299"}
0005433614452	C9440C	2000 793844	GENNADIY VOLKOV	{"phone": "+70512971011"}
0005433614453	FCB23E	5354 395479	ANTON SHEVCHENKO	{"email": "ashevchenko-12061988@postgrespro.ru", "phone": "+70607457476"}
0005433614454	0F01A3	3557 987398	YURIY KOROLEV	{"phone": "+70197710968"}
0005433614455	F73128	5825 102538	BOGDAN ANTONOV	{"email": "antonovbogdan-18061964@postgrespro.ru", "phone": "+70967694027"}
0005433614456	F73128	9761 501480	DAMIR ALEKSEEV	{"email": "alekseev_damir-011974@postgrespro.ru", "phone": "+70823025065"}
0005433614457	4BF4A9	4705 913438	ALEKSANDR MOROZOV	{"email": "amorozov-031963@postgrespro.ru", "phone": "+70338971867"}
0005433614458	505A0D	8148 102774	TATYANA MATVEEVA	{"email": "tatyanamatveeva.031967@postgrespro.ru", "phone": "+70329234143"}
0005433614459	505A0D	3506 755025	ALEKSANDR DENISOV	{"phone": "+70753799805"}
0005433614460	5F8961	4496 839374	ANTON IVANOV	{"phone": "+70815692986"}
0005433614461	006FB9	9187 038066	MARIYA ZHUKOVA	{"phone": "+70490878004"}
0005433614462	9B898B	5357 174443	SVETLANA TIMOFEEVA	{"email": "stimofeeva_101966@postgrespro.ru", "phone": "+70824563136"}
0005433614463	8D6F02	4140 453994	FARIDA RODIONOVA	{"email": "frodionova_081964@postgrespro.ru", "phone": "+70017793667"}
0005433614464	3B83DC	6015 925163	OLESYA NAUMOVA	{"phone": "+70389354645"}
0005433614465	B95F3D	9999 935084	NATALYA IVANOVA	{"phone": "+70683024612"}
0005433614466	A5D3BC	6330 706990	KIRILL TIMOFEEV	{"email": "timofeev-kirill-041970@postgrespro.ru", "phone": "+70715816469"}
0005433614467	A5D3BC	0538 216864	NINA FEDOROVA	{"phone": "+70933407300"}
0005433614468	F4B4DA	9532 219454	VLADIMIR PAVLOV	{"email": "vpavlov21091960@postgrespro.ru", "phone": "+70185351499"}
0005433614469	841A54	0782 612937	LARISA ALEKSEEVA	{"email": "l_alekseeva_101960@postgrespro.ru", "phone": "+70974876903"}
0005433614470	841A54	3126 511522	ANATOLIY KOZLOV	{"phone": "+70555737048"}
0005433614471	FA8C5F	1484 727394	EVGENIY PETROV	{"email": "e-petrov_1976@postgrespro.ru", "phone": "+70574318239"}
0005433614472	FA8C5F	8374 429073	GENNADIY ZAKHAROV	{"email": "g-zakharov_13081964@postgrespro.ru", "phone": "+70687702055"}
0005433614473	FA8C5F	4562 581819	VLADISLAV FEDOTOV	{"phone": "+70437439145"}
0005433614474	FA8C5F	4453 474400	ALEKSANDRA NESTEROVA	{"phone": "+70498515964"}
0005433614475	24276D	5782 730651	VALENTIN MIKHAYLOV	{"phone": "+70007222284"}
0005433614476	24276D	1662 625590	GALINA GORBUNOVA	{"email": "g.gorbunova.09121980@postgrespro.ru", "phone": "+70160558741"}
0005433614477	24276D	9397 789471	DMITRIY KOZLOV	{"email": "dmitriy_kozlov-21071973@postgrespro.ru", "phone": "+70948829392"}
0005433614478	F58D70	8644 363082	VIKTOR PAVLOV	{"phone": "+70196764929"}
0005433614479	37F06C	1163 937406	EKATERINA NIKOLAEVA	{"email": "e-nikolaeva101969@postgrespro.ru", "phone": "+70066520554"}
0005433614480	37F06C	3967 332857	VLADIMIR VOLKOV	{"email": "volkov-v.1964@postgrespro.ru", "phone": "+70469543517"}
0005433614481	A528E4	6337 384554	ARTEM NIKOLAEV	{"email": "anikolaev_101973@postgrespro.ru", "phone": "+70231416285"}
0005433614482	A528E4	2751 779527	VYACHESLAV KUZNECOV	{"phone": "+70467035534"}
0005433614483	60E401	4758 714965	NADEZHDA KARPOVA	{"phone": "+70964009918"}
0005433614484	1CFA83	4214 918503	MARIYA SERGEEVA	{"email": "msergeeva.1975@postgrespro.ru", "phone": "+70549335247"}
0005433614485	09AAA0	0186 067275	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov.27061969@postgrespro.ru", "phone": "+70915490624"}
0005433614486	09AAA0	5026 614654	VLADIMIR ROMANOV	{"phone": "+70861699583"}
0005433614487	A28286	9664 349638	DARYA IVANOVA	{"phone": "+70103204450"}
0005433614488	5B4D7B	3465 939799	LYUBOV KAZAKOVA	{"email": "lyubov_kazakova-021965@postgrespro.ru", "phone": "+70194024135"}
0005433614489	5B4D7B	9050 090996	DMITRIY STEPANOV	{"phone": "+70107192019"}
0005433614490	1570FA	7667 656931	MARIYA KULIKOVA	{"phone": "+70246736365"}
0005433614491	F10574	0452 365954	PETR KISELEV	{"email": "petr-kiselev.101966@postgrespro.ru", "phone": "+70916448669"}
0005433614492	F10574	6255 186174	GULFIYA CHERNOVA	{"email": "gulfiyachernova.1953@postgrespro.ru", "phone": "+70012409084"}
0005433614493	D1B936	4414 907460	LIDIYA OVCHINNIKOVA	{"phone": "+70763527880"}
0005433614494	0C02B6	4915 481404	VALENTINA OSIPOVA	{"email": "osipova.v.15101972@postgrespro.ru", "phone": "+70919470801"}
0005433614495	0C02B6	3553 056881	IVAN ALEKSANDROV	{"phone": "+70694784739"}
0005433614496	B36282	1664 307032	LIDIYA TITOVA	{"phone": "+70754165194"}
0005433614497	B36282	3044 399365	ANASTASIYA SMIRNOVA	{"phone": "+70381655998"}
0005433614498	B36282	4784 463884	EGOR MIRONOV	{"email": "mironov.e_1979@postgrespro.ru", "phone": "+70930382068"}
0005433614499	AF7AB1	8741 646704	KONSTANTIN MELNIKOV	{"phone": "+70906295242"}
0005433614500	F9492D	0369 272467	ANDREY POPOV	{"email": "a-popov-23081970@postgrespro.ru", "phone": "+70904673078"}
0005433614501	120EA0	8550 023025	ANDREY MOROZOV	{"email": "morozovandrey_07071967@postgrespro.ru", "phone": "+70551483088"}
0005433614502	C11B83	9666 155923	ANNA ANTONOVA	{"phone": "+70114397387"}
0005433614503	C11B83	2900 588142	LARISA BOGDANOVA	{"email": "larisa-bogdanova.1966@postgrespro.ru", "phone": "+70745773502"}
0005433614504	2BD76A	2498 240742	TAKHIR VOLKOV	{"phone": "+70742094836"}
0005433614505	5B4698	7990 888012	ANASTASIYA CHERNOVA	{"phone": "+70718649375"}
0005433614506	8AC594	0333 518936	LYUDMILA NESTEROVA	{"email": "nesterova_lyudmila.1962@postgrespro.ru", "phone": "+70348711903"}
0005433614507	5FCECD	3980 612412	VASILIY SAVELEV	{"phone": "+70129610372"}
0005433614508	5FCECD	3939 043841	NATALYA LEBEDEVA	{"email": "lebedevan061983@postgrespro.ru", "phone": "+70841457145"}
0005433614509	E567B6	1368 887304	VALERIYA MARTYNOVA	{"phone": "+70081383245"}
0005433614510	C98E4B	9555 961383	VALENTINA NOVIKOVA	{"email": "vnovikova-111970@postgrespro.ru", "phone": "+70736957130"}
0005433614511	B732A9	7214 649410	OLGA MOROZOVA	{"phone": "+70156810320"}
0005433614512	7E020F	0982 267530	OLEG DAVYDOV	{"phone": "+70637166659"}
0005433614513	EC2186	9600 061738	ALEKSANDRA GUSEVA	{"email": "guseva_a.021971@postgrespro.ru", "phone": "+70218697245"}
0005433614514	EC2186	8090 888503	OLGA DMITRIEVA	{"email": "odmitrieva_051965@postgrespro.ru", "phone": "+70514643088"}
0005433614515	2DAE7B	6642 085339	TATYANA SOKOLOVA	{"phone": "+70909493524"}
0005433614516	EA15EF	4354 825544	ANATOLIY POPOV	{"email": "anatoliy-popov.1979@postgrespro.ru", "phone": "+70368536719"}
0005433614517	EA15EF	0408 834819	EVGENIY VLASOV	{"email": "evgeniyvlasov.05121972@postgrespro.ru", "phone": "+70881546180"}
0005433614518	BCD950	3674 573621	VALENTINA YAKOVLEVA	{"phone": "+70130862349"}
0005433614519	BCD950	9243 089705	VERA NIKIFOROVA	{"email": "v_nikiforova081970@postgrespro.ru", "phone": "+70934312281"}
0005433614520	FDE3C0	7666 707960	ALEKSANDR FROLOV	{"email": "aleksandr-frolov.28081977@postgrespro.ru", "phone": "+70624953983"}
0005433614521	FDE3C0	1772 567299	VIKTOR NIKOLAEV	{"phone": "+70644295594"}
0005433614522	FDE3C0	3774 017734	DARYA IVANOVA	{"email": "darya.ivanova121983@postgrespro.ru", "phone": "+70121060231"}
0005433614523	2132AF	9448 542597	NADEZHDA ILINA	{"email": "n-ilina_1981@postgrespro.ru", "phone": "+70790323569"}
0005433614524	68F6DE	4602 810527	EVGENIY DENISOV	{"phone": "+70729139106"}
0005433614525	028A71	8426 628691	VLADIMIR ANTONOV	{"email": "antonovvladimir02031990@postgrespro.ru", "phone": "+70171553565"}
0005433614526	6AC886	9232 812302	ZINAIDA BARANOVA	{"email": "baranova-zinaida_1970@postgrespro.ru", "phone": "+70896055327"}
0005433614527	A89F38	7738 336469	DINARA NAUMOVA	{"email": "dinara.naumova.1980@postgrespro.ru", "phone": "+70388694280"}
0005433614528	38F7D3	9054 752558	MIKHAIL MAKSIMOV	{"phone": "+70823477757"}
0005433614529	38F7D3	7759 725702	IGOR NIKOLAEV	{"email": "nikolaevigor.1975@postgrespro.ru", "phone": "+70585455743"}
0005433614530	1AB668	2213 579045	POLINA VOLKOVA	{"email": "volkova-p101984@postgrespro.ru", "phone": "+70277719136"}
0005433614531	1AB668	4833 117504	MIKHAIL KUZNECOV	{"email": "kuznecovmikhail_02081981@postgrespro.ru", "phone": "+70340343305"}
0005433614532	8342C5	5914 647473	SERGEY ZHUKOV	{"email": "szhukov27031971@postgrespro.ru", "phone": "+70293996648"}
0005433614533	7C7B46	2647 014207	VALENTINA ZAYCEVA	{"email": "zayceva_v-021978@postgrespro.ru", "phone": "+70869953579"}
0005433614534	616A4E	6243 084023	ALEKSEY ROMANOV	{"phone": "+70598196897"}
0005433614535	616A4E	7368 013927	OKSANA TROFIMOVA	{"phone": "+70423434918"}
0005433614536	616A4E	2837 531213	OLGA AFANASEVA	{"email": "afanaseva-olga_061978@postgrespro.ru", "phone": "+70071849093"}
0005433614537	6809EE	5898 103165	ANDREY KOROLEV	{"phone": "+70755950011"}
0005433614538	0D1E8F	5978 083224	ELENA NAZAROVA	{"phone": "+70892033613"}
0005433614539	A41AFB	8225 798563	TATYANA LAZAREVA	{"email": "t-lazareva_23061965@postgrespro.ru", "phone": "+70314646604"}
0005433614540	DBCA29	9370 286403	ELENA RYABOVA	{"phone": "+70759519168"}
0005433614541	FCBF7F	7605 494269	LARISA BOGDANOVA	{"phone": "+70539273887"}
0005433614542	B63AAA	8898 230896	LYUDMILA KUZNECOVA	{"phone": "+70293184547"}
0005433614543	3CDE94	0525 467410	IRINA IVANOVA	{"email": "i.ivanova-1968@postgrespro.ru", "phone": "+70507538053"}
0005433614544	0AC84E	6645 078984	SOFIYA ALEKSEEVA	{"email": "sofiya_alekseeva_1981@postgrespro.ru", "phone": "+70831704561"}
0005433614545	ACBAD4	6596 026403	KONSTANTIN POPOV	{"phone": "+70976448090"}
0005433614546	DD3589	1535 184550	OLGA KALININA	{"phone": "+70131206117"}
0005433614547	C65FE8	4761 131220	NADEZHDA ANISIMOVA	{"email": "nadezhdaanisimova_21021972@postgrespro.ru", "phone": "+70080349384"}
0005433614548	043C4A	5019 692783	IGOR SCHERBAKOV	{"email": "i.scherbakov.20021980@postgrespro.ru", "phone": "+70680149913"}
0005433614549	16DDC7	9243 614240	EKATERINA MAKAROVA	{"email": "makarova_ekaterina-111983@postgrespro.ru", "phone": "+70135734961"}
0005433614550	4A9300	2166 334848	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov.1970@postgrespro.ru", "phone": "+70836706806"}
0005433614551	CEC974	2067 829891	LARISA FEDOROVA	{"phone": "+70903728193"}
0005433614552	40805F	8032 570883	NADEZHDA NIKOLAEVA	{"email": "nnikolaeva.121967@postgrespro.ru", "phone": "+70362078923"}
0005433614553	76BD9B	4613 619693	VLADIMIR GRIGOREV	{"email": "grigorev_v031975@postgrespro.ru", "phone": "+70988212167"}
0005433614554	7563C2	1404 757907	MARINA POPOVA	{"phone": "+70956999065"}
0005433614555	7563C2	0959 740337	LYUDMILA MALYSHEVA	{"email": "malysheva-l.041978@postgrespro.ru", "phone": "+70898028525"}
0005433614556	C5BD02	9419 049349	SVETLANA MAKSIMOVA	{"email": "maksimova.s02071974@postgrespro.ru", "phone": "+70915506743"}
0005433614557	C5BD02	5932 265727	LYUDMILA KOLESNIKOVA	{"email": "lyudmila-kolesnikova_31031976@postgrespro.ru", "phone": "+70482742069"}
0005433614558	F9E0EE	4750 155172	VALENTINA MAKAROVA	{"phone": "+70147578090"}
0005433614559	F9E0EE	6608 735413	ARTEM RODIONOV	{"phone": "+70570447196"}
0005433614560	F9E0EE	3668 280610	IVAN CHERNOV	{"email": "i_chernov_051978@postgrespro.ru", "phone": "+70481672385"}
0005433614561	EED46F	6027 529874	RUZALIYA SCHERBAKOVA	{"phone": "+70013373151"}
0005433614562	DA2E17	0588 078186	VALERIY VASILEV	{"email": "vasilevv-29091986@postgrespro.ru", "phone": "+70211932221"}
0005433614563	7508B4	6509 066372	RAMIL NOVIKOV	{"phone": "+70565839074"}
0005433614564	7508B4	7189 125947	VIKTOR FEDOROV	{"email": "v-fedorov-03041985@postgrespro.ru", "phone": "+70502125592"}
0005433614565	EDA85A	6682 657880	ANTON KARPOV	{"phone": "+70825715073"}
0005433614566	EDA85A	3767 729677	ELENA ORLOVA	{"email": "orlova-elena_021961@postgrespro.ru", "phone": "+70797762892"}
0005433614567	EDA85A	3983 119116	RUSLAN GRIGOREV	{"email": "rgrigorev1980@postgrespro.ru", "phone": "+70040968023"}
0005433614568	90CD46	4693 558394	NIKOLAY CHERNOV	{"email": "nikolay_chernov-021970@postgrespro.ru", "phone": "+70329421650"}
0005433614569	7B7149	5039 756250	ANDREY TARASOV	{"phone": "+70839925015"}
0005433614570	1896B0	8472 730477	LYUBOV MARTYNOVA	{"phone": "+70259397521"}
0005433614571	1896B0	8242 360896	VITALIY DAVYDOV	{"email": "davydov.v_17091967@postgrespro.ru", "phone": "+70747363582"}
0005433614572	50778A	5447 828119	INESSA LAZAREVA	{"email": "lazareva-i-1954@postgrespro.ru", "phone": "+70641703960"}
0005433614573	C3AE98	6689 522837	ALEKSEY KRASNOV	{"phone": "+70425529785"}
0005433614574	B496C7	5410 644968	SVETLANA PETROVA	{"phone": "+70303797771"}
0005433614575	5812A2	7901 145581	PAVEL BONDARENKO	{"email": "p.bondarenko-1972@postgrespro.ru", "phone": "+70997679541"}
0005433614576	413429	1079 747810	RINAT PETROV	{"phone": "+70498244576"}
0005433614577	413429	9846 875072	EVGENIY MOROZOV	{"email": "e.morozov101972@postgrespro.ru", "phone": "+70302835967"}
0005433614578	2C1E01	4619 515644	ALEKSANDR BARANOV	{"phone": "+70733213722"}
0005433614579	8CE496	8074 622506	NINA SMIRNOVA	{"email": "smirnovanina1969@postgrespro.ru", "phone": "+70724687135"}
0005433614580	8CE496	6235 195139	ILYA CHERNOV	{"phone": "+70680488812"}
0005433614581	A29E6A	9970 208965	IRINA BELOVA	{"phone": "+70458867418"}
0005433614582	FC5FBD	0118 956515	EKATERINA NAZAROVA	{"email": "nazarova-ekaterina29111982@postgrespro.ru", "phone": "+70157765332"}
0005433614583	C23B71	5925 883982	SERGEY ANTONOV	{"phone": "+70431709449"}
0005433614584	6BC4D9	0669 085722	MAKSIM MIKHAYLOV	{"phone": "+70565831477"}
0005433614585	6BC4D9	7791 630592	YURIY MOROZOV	{"phone": "+70323242584"}
0005433614586	F52F7D	4543 106296	ELENA CHERNOVA	{"email": "chernova.elena-23021975@postgrespro.ru", "phone": "+70254926513"}
0005433614587	EFEFFD	0875 216526	ANATOLIY IVANOV	{"email": "a.ivanov-1976@postgrespro.ru", "phone": "+70512371263"}
0005433614588	E0C119	4413 328159	MARINA KUZNECOVA	{"phone": "+70875945543"}
0005433614589	E0C119	3657 522250	VLADIMIR BELOV	{"phone": "+70741246945"}
0005433614590	69E239	7969 522460	MIKHAIL KONOVALOV	{"phone": "+70472297975"}
0005433614591	5D7D02	4714 417844	NATALYA LUKYANOVA	{"email": "natalya_lukyanova.1960@postgrespro.ru", "phone": "+70712341160"}
0005433614592	7CA414	2186 530212	VALENTINA VOLKOVA	{"phone": "+70274893668"}
0005433614593	7CA414	5627 392357	OKSANA ORLOVA	{"phone": "+70260879516"}
0005433614594	7CA414	4918 498500	KSENIYA NAZAROVA	{"email": "nazarova-kseniya.1975@postgrespro.ru", "phone": "+70407700225"}
0005433614595	7BA16A	5585 392134	ARTEM GRIGOREV	{"email": "grigorev.artem-1970@postgrespro.ru", "phone": "+70906860759"}
0005433614596	1EFA59	3823 633660	ALEVTINA NESTEROVA	{"phone": "+70918920225"}
0005433614597	A69F16	9222 078281	ANNA TITOVA	{"phone": "+70397442899"}
0005433614598	A69F16	9248 689640	TATYANA ERMAKOVA	{"phone": "+70560308389"}
0005433614599	032C5E	2624 994313	TATYANA ILINA	{"phone": "+70910833908"}
0005433614600	D3E979	2497 716731	VIKTOR KUZNECOV	{"phone": "+70708224502"}
0005433614601	666A61	3371 965543	ARTEM NAZAROV	{"phone": "+70602234928"}
0005433614602	666A61	1517 548364	OLGA GRISHINA	{"phone": "+70311186361"}
0005433614603	E6B894	5760 346677	ARTEM TIKHONOV	{"phone": "+70602130775"}
0005433614604	C79B21	5860 497790	PAVEL FEDOROV	{"email": "fedorov.pavel_1974@postgrespro.ru", "phone": "+70216217436"}
0005433614605	BAEC1F	5456 754852	VALENTINA MATVEEVA	{"phone": "+70406490990"}
0005433614606	BAEC1F	4485 234513	VIKTOR KOROLEV	{"email": "korolev_viktor1972@postgrespro.ru", "phone": "+70615130325"}
0005433614607	28A853	8791 084206	ALEKSANDR IVANOV	{"phone": "+70775728784"}
0005433614608	19604A	5749 836428	ALEKSEY VOROBEV	{"phone": "+70234931491"}
0005433614609	D2557E	3551 156846	DENIS KONOVALOV	{"email": "denis_konovalov.011967@postgrespro.ru", "phone": "+70504851213"}
0005433614610	8FF6C3	1216 393171	OLEG TARASOV	{"email": "o_tarasov091978@postgrespro.ru", "phone": "+70143205358"}
0005433614611	8FF6C3	8909 507039	EVGENIY OSIPOV	{"email": "osipov.e_13111964@postgrespro.ru", "phone": "+70150347061"}
0005433614612	EEDE78	4173 869751	ANTONINA AKIMOVA	{"phone": "+70743728587"}
0005433614613	EEDE78	7421 666356	NADEZHDA LEBEDEVA	{"email": "lebedevan23041971@postgrespro.ru", "phone": "+70263352792"}
0005433614614	3C28C2	7437 503550	ALEKSANDR SIDOROV	{"phone": "+70403607179"}
0005433614615	E10F77	2195 500501	RINAT CHERNOV	{"email": "rinatchernov.27031973@postgrespro.ru", "phone": "+70833930185"}
0005433614616	60A6A0	1840 318571	ROMAN MAKSIMOV	{"email": "r.maksimov.1975@postgrespro.ru", "phone": "+70421597273"}
0005433614617	57CE6B	0061 241058	ANNA KOVALEVA	{"phone": "+70275888857"}
0005433614618	0E8C11	7881 626128	NADEZHDA SOKOLOVA	{"phone": "+70125018691"}
0005433614619	0E8C11	9505 662056	VASILIY MIRONOV	{"phone": "+70460744508"}
0005433614620	5BF8E9	8080 346816	LIDIYA MELNIKOVA	{"phone": "+70813223331"}
0005433614621	5BF8E9	4513 271956	ALEKSANDR MIRONOV	{"email": "mironov_a_24081971@postgrespro.ru", "phone": "+70226546506"}
0005433614622	3930E3	2331 458692	IGOR POPOV	{"phone": "+70895414722"}
0005433614623	5CBD93	8106 770432	ANDREY VOROBEV	{"phone": "+70170654954"}
0005433614624	5CBD93	7772 880699	ELENA TIMOFEEVA	{"phone": "+70144948982"}
0005433614625	93ACF2	9499 865061	ANDREY VOLKOV	{"email": "volkov_a1966@postgrespro.ru", "phone": "+70691821003"}
0005433614626	459B7E	0536 294063	ANTON POPOV	{"email": "popova111968@postgrespro.ru", "phone": "+70793178435"}
0005433614627	125566	3736 778896	ANNA TARASOVA	{"email": "tarasova_anna-071972@postgrespro.ru", "phone": "+70534864158"}
0005433614628	3B08FE	8087 361976	DMITRIY FEDOROV	{"phone": "+70620154569"}
0005433614629	804303	0053 239153	NINA OSIPOVA	{"phone": "+70759610386"}
0005433614630	021D92	4026 514285	OLGA STEPANOVA	{"email": "olga-stepanova-111978@postgrespro.ru", "phone": "+70988879153"}
0005433614631	D13AE5	1324 331058	SERGEY SMIRNOV	{"phone": "+70850959495"}
0005433614632	52BC44	7539 856342	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila-26031977@postgrespro.ru", "phone": "+70962400679"}
0005433614633	BA231A	9520 527924	VLADIMIR KARPOV	{"email": "karpovv.04121970@postgrespro.ru", "phone": "+70845300859"}
0005433614634	51B109	7985 708209	ELIZAVETA MELNIKOVA	{"email": "melnikova_elizaveta.1977@postgrespro.ru", "phone": "+70951435869"}
0005433614635	CCF14C	9895 645055	ALEKSEY ABRAMOV	{"phone": "+70743565533"}
0005433614636	2DB1A4	3627 427825	OKSANA KOROLEVA	{"email": "o.koroleva_1974@postgrespro.ru", "phone": "+70989550351"}
0005433614637	9814F0	0145 622408	NADEZHDA GAVRILOVA	{"email": "gavrilova_nadezhda.031977@postgrespro.ru", "phone": "+70351470944"}
0005433614638	9814F0	9760 600839	MAKSIM MARTYNOV	{"email": "martynov_m-1972@postgrespro.ru", "phone": "+70233446741"}
0005433614639	B7196C	2216 226572	ALEKSANDR KARPOV	{"email": "aleksandrkarpov1988@postgrespro.ru", "phone": "+70212595940"}
0005433614640	ECB134	8641 303114	ELENA ALEKSANDROVA	{"email": "e.aleksandrova-21071976@postgrespro.ru", "phone": "+70538506286"}
0005433614641	DBA5AF	8531 123869	ANATOLIY FROLOV	{"email": "afrolov.021983@postgrespro.ru", "phone": "+70246120998"}
0005433614642	B6B520	1088 920329	ANATOLIY KONOVALOV	{"email": "konovalov.a01051969@postgrespro.ru", "phone": "+70059313680"}
0005433614643	981BDD	8734 113365	ALEKSANDR KONOVALOV	{"email": "a.konovalov_17051961@postgrespro.ru", "phone": "+70261644410"}
0005433614644	7A2581	5366 845189	NINA SOKOLOVA	{"email": "sokolova-n-1969@postgrespro.ru", "phone": "+70735230063"}
0005433614645	02BB99	6650 273083	TATYANA ANTONOVA	{"email": "antonovat.21111970@postgrespro.ru", "phone": "+70392540843"}
0005433614646	377B3A	5230 211983	EKATERINA TROFIMOVA	{"phone": "+70672405055"}
0005433614647	F309DF	6031 715993	RAISA BARANOVA	{"phone": "+70466993468"}
0005433614648	1AC1F3	0412 710360	VALENTINA TITOVA	{"email": "titova.v_051984@postgrespro.ru", "phone": "+70176176166"}
0005433614649	1AC1F3	7349 775654	LYUDMILA STEPANOVA	{"phone": "+70301789036"}
0005433614650	14D431	0370 759044	LYUDMILA KUZNECOVA	{"phone": "+70444179511"}
0005433614651	A1E8BE	4133 296266	MAKSIM VASILEV	{"email": "m.vasilev_061966@postgrespro.ru", "phone": "+70425904247"}
0005433614652	A24A3B	7688 153888	ANZHELIKA SOKOLOVA	{"phone": "+70108054861"}
0005433614653	A24A3B	3106 335444	ZULFIYA MAKAROVA	{"phone": "+70748702123"}
0005433614654	EEBE08	0974 933306	LYUDMILA KARPOVA	{"phone": "+70402735292"}
0005433614655	EEBE08	5290 131903	ALEKSEY DAVYDOV	{"email": "adavydov_1971@postgrespro.ru", "phone": "+70394613970"}
0005433614656	D3C889	8638 426137	ALEKSEY BELOV	{"phone": "+70159500279"}
0005433614657	C99D45	3105 586451	ANNA POPOVA	{"email": "a_popova1958@postgrespro.ru", "phone": "+70129045160"}
0005433614658	68991F	5542 236367	SERGEY ZAKHAROV	{"phone": "+70774247519"}
0005433614659	F9694D	2327 774940	LYUDMILA PETROVA	{"email": "petrova-lyudmila_1968@postgrespro.ru", "phone": "+70348077399"}
0005433614660	AF73E9	0961 319334	ELENA VASILEVA	{"phone": "+70747569659"}
0005433614661	AF73E9	4337 607496	EKATERINA ABRAMOVA	{"email": "abramova_e_071974@postgrespro.ru", "phone": "+70609826495"}
0005433614662	FCAD17	0867 202116	ALEKSANDR MATVEEV	{"email": "a-matveev_081971@postgrespro.ru", "phone": "+70115960604"}
0005433614723	184354	9531 421908	OLGA KOROLEVA	{"phone": "+70545649835"}
0005433614663	F5305E	0278 313128	ALINA EFIMOVA	{"email": "efimova.a_041970@postgrespro.ru", "phone": "+70974619869"}
0005433614664	F5305E	0681 992588	DMITRIY GRIGOREV	{"phone": "+70019046354"}
0005433614665	12CF02	8543 558499	ANATOLIY PETROV	{"email": "anatoliy-petrov_1972@postgrespro.ru", "phone": "+70094831510"}
0005433614666	12CF02	5726 225825	KLAVDIYA ZAYCEVA	{"phone": "+70268210221"}
0005433614667	12CF02	6819 597657	OLGA ZHURAVLEVA	{"email": "zhuravleva-olga.09061962@postgrespro.ru", "phone": "+70638037753"}
0005433614668	F1E486	8199 414399	YURIY NIKOLAEV	{"email": "nikolaevy_1962@postgrespro.ru", "phone": "+70161081548"}
0005433614669	F1E486	4489 060709	ELENA MIKHAYLOVA	{"email": "mikhaylova.elena.04081966@postgrespro.ru", "phone": "+70375142786"}
0005433614670	8BB520	1280 199546	ALEKSANDR MARTYNOV	{"email": "martynov_aleksandr.1968@postgrespro.ru", "phone": "+70370597986"}
0005433614671	8BB520	3404 446952	EVGENIYA EGOROVA	{"phone": "+70995717810"}
0005433614672	803EDF	0077 936731	DARYA FILIPPOVA	{"phone": "+70303172601"}
0005433614673	39AACA	9475 694666	VLADIMIR ZAYCEV	{"email": "zaycev_v_081972@postgrespro.ru", "phone": "+70118960297"}
0005433614674	D00EC9	2992 087396	ELENA FADEEVA	{"phone": "+70058422510"}
0005433614675	D00EC9	7125 486818	IGOR SEMENOV	{"email": "igor_semenov.1964@postgrespro.ru", "phone": "+70792151276"}
0005433614676	9A4BD6	6592 722096	LYUBOV MAKAROVA	{"email": "makarovalyubov12111975@postgrespro.ru", "phone": "+70679544547"}
0005433614677	9A4BD6	1510 589881	ANNA KUZNECOVA	{"phone": "+70873273401"}
0005433614678	0DB9EC	8954 001272	GALINA YAKOVLEVA	{"email": "g.yakovleva.031973@postgrespro.ru", "phone": "+70926214145"}
0005433614679	F80F16	8870 788225	NAILYA KOROLEVA	{"phone": "+70851568893"}
0005433614680	F80F16	3057 484013	NATALYA KONOVALOVA	{"phone": "+70863336985"}
0005433614681	DB381F	1761 650730	TATYANA VOROBEVA	{"email": "vorobeva_tatyana_061975@postgrespro.ru", "phone": "+70463716951"}
0005433614682	DB381F	1489 717142	VLADIMIR BONDARENKO	{"email": "v.bondarenko071961@postgrespro.ru", "phone": "+70464067648"}
0005433614683	706AE7	4888 085605	VLADIMIR BONDARENKO	{"email": "v-bondarenko_08011976@postgrespro.ru", "phone": "+70902627910"}
0005433614684	FA6901	2477 789969	NATALYA BELOVA	{"phone": "+70569473918"}
0005433614685	FA6901	9388 561268	ELENA KUDRYASHOVA	{"phone": "+70444134736"}
0005433614686	2FA1D3	7132 933208	VALERIYA FADEEVA	{"email": "fadeeva-valeriya.021971@postgrespro.ru", "phone": "+70169148388"}
0005433614687	FD3766	9509 135741	VERA SOKOLOVA	{"phone": "+70831236199"}
0005433614688	FD3766	3428 277123	VALENTINA KARPOVA	{"email": "v.karpova1966@postgrespro.ru", "phone": "+70191598839"}
0005433614689	E005DE	5725 741604	TAMARA ISAEVA	{"email": "tisaeva.051969@postgrespro.ru", "phone": "+70136320688"}
0005433614690	E005DE	0506 376137	IGOR PETROV	{"email": "i-petrov23011980@postgrespro.ru", "phone": "+70035105127"}
0005433614691	E005DE	3991 421593	ROMAN SEMENOV	{"phone": "+70843230010"}
0005433614692	22A1A8	9572 859145	EVGENIY FROLOV	{"email": "evgeniy-frolov-26091956@postgrespro.ru", "phone": "+70963425211"}
0005433614693	22A1A8	0745 167242	ALEKSEY PETROV	{"email": "aleksey-petrov_071964@postgrespro.ru", "phone": "+70403027017"}
0005433614694	22A1A8	0986 483329	VIKTOR NIKOLAEV	{"email": "nikolaev.viktor_1957@postgrespro.ru", "phone": "+70524882928"}
0005433614695	31BBA5	6450 205192	NADEZHDA FOMINA	{"email": "fomina.nadezhda-1983@postgrespro.ru", "phone": "+70138473393"}
0005433614696	302EF9	9064 416959	ALBERT YAKOVLEV	{"email": "albert.yakovlev-10121973@postgrespro.ru", "phone": "+70061389823"}
0005433614697	302EF9	6400 522417	VLADIMIR DENISOV	{"phone": "+70504397240"}
0005433614698	11B936	0096 249228	VYACHESLAV ZHUKOV	{"phone": "+70665917955"}
0005433614699	27B1CE	4099 224556	OLEG ANDREEV	{"email": "andreev-oleg.061962@postgrespro.ru", "phone": "+70381968143"}
0005433614700	0711E5	4174 754429	NIKOLAY KULIKOV	{"phone": "+70148828712"}
0005433614701	C974F5	9904 185497	EVGENIY SMIRNOV	{"email": "smirnovevgeniy071965@postgrespro.ru", "phone": "+70419722952"}
0005433614702	1AF859	8345 853976	MARINA LOGINOVA	{"phone": "+70943345769"}
0005433614703	1AF859	2447 607737	KSENIYA EGOROVA	{"email": "egorova-kseniya_081979@postgrespro.ru", "phone": "+70638501933"}
0005433614704	1AF859	2092 865996	NINA ZHUKOVA	{"email": "zhukova_nina.071970@postgrespro.ru", "phone": "+70535050983"}
0005433614705	7275E4	8497 821384	PETR IVANOV	{"phone": "+70577855810"}
0005433614706	9650FD	0469 937027	DARYA SCHERBAKOVA	{"phone": "+70749598098"}
0005433614707	9650FD	1751 754932	VIKTOR FILIPPOV	{"email": "vfilippov-021974@postgrespro.ru", "phone": "+70265857660"}
0005433614708	2B6AC3	2692 450774	IGOR MARTYNOV	{"phone": "+70130111838"}
0005433614709	A3C94E	5963 576889	LYUDMILA KOVALEVA	{"email": "kovaleva_lyudmila_05101970@postgrespro.ru", "phone": "+70648815115"}
0005433614710	A3C94E	7951 111868	OLESYA SOKOLOVA	{"phone": "+70365832718"}
0005433614711	BCEE3D	1714 019695	ROMAN NIKITIN	{"email": "roman-nikitin_061980@postgrespro.ru", "phone": "+70894115655"}
0005433614712	BCEE3D	8550 782728	GALINA MIRONOVA	{"phone": "+70192310235"}
0005433614713	2B8764	8096 197298	ALEKSANDR POPOV	{"phone": "+70785241739"}
0005433614714	2B8764	3790 652408	MIKHAIL POPOV	{"email": "popovm_1985@postgrespro.ru", "phone": "+70209922991"}
0005433614715	90AC6B	9865 010993	EVGENIY SEMENOV	{"email": "semenove_25111969@postgrespro.ru", "phone": "+70403733632"}
0005433614716	90AC6B	9810 528992	ALEKSANDRA IVANOVA	{"email": "aivanova21101965@postgrespro.ru", "phone": "+70144681621"}
0005433614717	E22FDA	3195 494761	VIKTOR KUZNECOV	{"phone": "+70509302544"}
0005433614718	E22FDA	6565 984793	IVAN ZHUKOV	{"phone": "+70739463994"}
0005433614719	05B626	6521 658056	DMITRIY BORISOV	{"phone": "+70792525668"}
0005433614720	F9B671	9092 833623	IGOR IVANOV	{"phone": "+70518350829"}
0005433614721	F9B671	8262 498808	ANDREY PETROV	{"email": "petrov_andrey.12041964@postgrespro.ru", "phone": "+70843205054"}
0005433614722	184354	6710 604814	KSENIYA SAVELEVA	{"phone": "+70627469157"}
0005433614724	9A9690	9957 820661	ANDREY GORBUNOV	{"email": "a.gorbunov.18091964@postgrespro.ru", "phone": "+70050189731"}
0005433614725	9A4C12	4188 125276	ALEKSANDR POPOV	{"email": "a.popov.13031967@postgrespro.ru", "phone": "+70033999571"}
0005433614726	52E354	6081 616575	OLESYA SOROKINA	{"email": "olesya_sorokina_27111974@postgrespro.ru", "phone": "+70621643145"}
0005433614727	EF4C3E	2036 444621	VADIM ANTONOV	{"email": "antonov_vadim-05091975@postgrespro.ru", "phone": "+70773620770"}
0005433614728	3F1E3D	4632 488384	MARGARITA FEDOROVA	{"email": "fedorova_margarita.1969@postgrespro.ru", "phone": "+70872311536"}
0005433614729	3F1E3D	6897 343858	ANNA SMIRNOVA	{"phone": "+70806981622"}
0005433614730	3F1E3D	8158 838641	ROMAN MOROZOV	{"phone": "+70203278821"}
0005433614731	C299CA	3248 140863	MAKAR SAVELEV	{"email": "m-savelev-31051969@postgrespro.ru", "phone": "+70550627897"}
0005433614732	6B0A9F	1301 582403	EVGENIY KUZNECOV	{"phone": "+70870930282"}
0005433614733	699F9C	5200 054349	IRINA ILINA	{"email": "ilina_irina_051966@postgrespro.ru", "phone": "+70433597923"}
0005433614734	7B31DE	8449 230468	NADEZHDA BELOVA	{"phone": "+70579146390"}
0005433614735	0C4E57	0863 979059	ALEKSANDR KUZMIN	{"phone": "+70843832039"}
0005433614736	7CFA2F	0781 221751	KARINA OSIPOVA	{"email": "osipova-karina-04091974@postgrespro.ru", "phone": "+70787708754"}
0005433614737	7CFA2F	9869 255427	OLESYA MAKAROVA	{"phone": "+70709050116"}
0005433614738	426331	4945 669027	VALENTINA EFIMOVA	{"phone": "+70262929041"}
0005433614739	743839	5701 660279	ALIYA NIKITINA	{"phone": "+70938699550"}
0005433614740	B1A21E	1324 770341	EKATERINA VASILEVA	{"email": "vasileva.ekaterina.07031968@postgrespro.ru", "phone": "+70944693984"}
0005433614741	968DE2	8127 040598	EVGENIY SEMENOV	{"email": "e_semenov.1977@postgrespro.ru", "phone": "+70366585920"}
0005433614742	5E009E	1861 699627	NIKITA VOLKOV	{"email": "nikita.volkov.01091975@postgrespro.ru", "phone": "+70561496996"}
0005433614743	CB84A3	6366 624953	RIMMA IVANOVA	{"phone": "+70814295564"}
0005433614744	132E51	1750 293534	NINA KUZNECOVA	{"email": "kuznecovanina_071966@postgrespro.ru", "phone": "+70606494790"}
0005433614745	28BD8D	5862 474172	FEDOR KOZLOV	{"email": "f.kozlov-04041976@postgrespro.ru", "phone": "+70040576662"}
0005433614746	28BD8D	5263 782871	GLEB FROLOV	{"phone": "+70929036066"}
0005433614747	A0062D	5652 655358	ALI ZAKHAROV	{"email": "a.zakharov-07011980@postgrespro.ru", "phone": "+70676572391"}
0005433614748	9F9F07	1151 772344	ANASTASIYA SERGEEVA	{"email": "sergeeva-anastasiya_11011976@postgrespro.ru", "phone": "+70148039600"}
0005433614749	90BEFC	5502 220175	VIKTOR PETROV	{"email": "petrov-viktor_031977@postgrespro.ru", "phone": "+70651794678"}
0005433614750	830368	7831 392179	SERGEY IVANOV	{"phone": "+70279711509"}
0005433614751	3BA646	2985 735934	YULIYA KAZAKOVA	{"phone": "+70910482749"}
0005433614752	3BA646	1704 103029	VLADIMIR NIKITIN	{"email": "nikitin_vladimir_07081966@postgrespro.ru", "phone": "+70560287767"}
0005433614753	CAE563	0881 792027	MIKHAIL KUZNECOV	{"email": "kuznecov-m.011951@postgrespro.ru", "phone": "+70350747166"}
0005433614754	CAE563	7668 615750	VLADIMIR ANDREEV	{"phone": "+70443623576"}
0005433614755	0684AA	1021 527304	LYUDMILA DENISOVA	{"email": "denisova_lyudmila.12091972@postgrespro.ru", "phone": "+70912175269"}
0005433614756	346BA0	4439 658254	SVETLANA ILINA	{"phone": "+70827612930"}
0005433614757	346BA0	9904 660528	ALEKSANDR VOLKOV	{"phone": "+70388258211"}
0005433614758	789201	9859 996862	NIKOLAY RODIONOV	{"phone": "+70266891321"}
0005433614759	789201	6525 360044	ELMIRA MAKAROVA	{"email": "makarova-elmira-071972@postgrespro.ru", "phone": "+70918641210"}
0005433614760	03DB6E	5148 851281	MARINA BOGDANOVA	{"email": "marina-bogdanova091973@postgrespro.ru", "phone": "+70743010854"}
0005433614761	1393DC	7743 923087	NIKOLAY ANTONOV	{"email": "nantonov.121971@postgrespro.ru", "phone": "+70402939088"}
0005433614762	1393DC	1247 618654	LIDIYA EGOROVA	{"email": "egorovalidiya.26111975@postgrespro.ru", "phone": "+70100525080"}
0005433614763	7C17D8	9324 539281	NATALYA FEDOROVA	{"email": "natalya_fedorova_101965@postgrespro.ru", "phone": "+70761748417"}
0005433614764	7C17D8	5565 734777	VLADIMIR SOROKIN	{"phone": "+70618744659"}
0005433614765	30913A	6663 518645	RAISA STEPANOVA	{"phone": "+70164389300"}
0005433614766	127CE4	6784 132729	OKSANA EGOROVA	{"email": "egorova-oksana-10021980@postgrespro.ru", "phone": "+70486716669"}
0005433614767	127CE4	8945 127765	TATYANA OSIPOVA	{"phone": "+70814528435"}
0005433614768	051A6D	0980 694126	LARISA NIKOLAEVA	{"email": "larisanikolaeva1963@postgrespro.ru", "phone": "+70305349789"}
0005433614769	051A6D	5376 278019	NADEZHDA DENISOVA	{"phone": "+70807497077"}
0005433614770	C84614	9664 799852	NIKOLAY ANDREEV	{"email": "andreevnikolay25091967@postgrespro.ru", "phone": "+70987378784"}
0005433614771	C84614	0045 426712	LARISA MAKAROVA	{"phone": "+70352172944"}
0005433614772	F50D16	6829 649007	TAISIYA TARASOVA	{"email": "tarasova-taisiya_081982@postgrespro.ru", "phone": "+70950778613"}
0005433614773	F50D16	8785 568964	OKSANA GRISHINA	{"email": "o-grishina-031968@postgrespro.ru", "phone": "+70151609730"}
0005433614774	437F96	4934 780053	NIKOLAY ANTONOV	{"phone": "+70096146387"}
0005433614775	7A5888	4721 664292	NIKOLAY MIKHAYLOV	{"email": "n-mikhaylov071964@postgrespro.ru", "phone": "+70331810008"}
0005433614776	0E1CE9	3920 252701	MARIYA ARKHIPOVA	{"phone": "+70668430134"}
0005433614777	C4BF6A	3291 274391	VERA KOVALEVA	{"email": "v.kovaleva.1980@postgrespro.ru", "phone": "+70375170330"}
0005433614778	DEC7F3	9453 880499	YURIY KAZAKOV	{"phone": "+70817818776"}
0005433614779	89373D	3812 180206	PAVEL ALEKSANDROV	{"email": "pavel-aleksandrov_1973@postgrespro.ru", "phone": "+70053992589"}
0005433614780	89373D	6475 360758	ALEKSANDR ABRAMOV	{"phone": "+70820135446"}
0005433614781	89373D	3304 414082	TATYANA MASLOVA	{"phone": "+70717409221"}
0005433614782	A66C52	1540 252394	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova_1981@postgrespro.ru", "phone": "+70206901419"}
0005433614783	A66C52	7556 599369	ANTON ROMANOV	{"phone": "+70331672879"}
0005433614784	76BD4A	1913 314855	KONSTANTIN ANDREEV	{"email": "andreevk1968@postgrespro.ru", "phone": "+70885545313"}
0005433614785	76BD4A	1732 365242	YAROSLAV KUZNECOV	{"email": "y-kuznecov.01051977@postgrespro.ru", "phone": "+70515791726"}
0005433614786	320F46	0190 529579	SERGEY MELNIKOV	{"phone": "+70337753238"}
0005433614787	320F46	9236 055600	ANATOLIY KAZAKOV	{"email": "kazakovanatoliy_07051969@postgrespro.ru", "phone": "+70372203841"}
0005433614788	E75C13	6317 544680	VIKTOR KRASNOV	{"email": "viktor-krasnov-1970@postgrespro.ru", "phone": "+70935384339"}
0005433614789	E75C13	1029 057476	ALEKSANDR PETROV	{"email": "petrovaleksandr22021961@postgrespro.ru", "phone": "+70132754493"}
0005433614790	1FE5B9	9118 736334	YURIY DAVYDOV	{"email": "davydovy.11051974@postgrespro.ru", "phone": "+70104062743"}
0005433614791	1FE5B9	0034 413908	GUZEL FROLOVA	{"email": "guzel.frolova.1964@postgrespro.ru", "phone": "+70311582041"}
0005433614792	1FE5B9	9531 206586	ALEKSANDR NOVIKOV	{"email": "novikov.a_111972@postgrespro.ru", "phone": "+70290399591"}
0005433614793	6BEB4A	1667 643285	ALEKSANDR NAUMOV	{"email": "naumov.a_091981@postgrespro.ru", "phone": "+70632959199"}
0005433614794	6BEB4A	6521 788187	EKATERINA ALEKSEEVA	{"phone": "+70837894010"}
0005433614795	38E330	5788 423126	GALINA SOROKINA	{"email": "gsorokina20011971@postgrespro.ru", "phone": "+70415344279"}
0005433614796	38E330	1664 796471	ASKHAT SMIRNOV	{"email": "a-smirnov15021971@postgrespro.ru", "phone": "+70182974100"}
0005433614797	48FF9A	8808 823084	EKATERINA FILIPPOVA	{"email": "filippova-ekaterina_061975@postgrespro.ru", "phone": "+70640872449"}
0005433614798	48FF9A	9312 875165	LIDIYA KUDRYASHOVA	{"email": "lidiya-kudryashova111964@postgrespro.ru", "phone": "+70744830435"}
0005433614799	48FF9A	7671 790585	TATYANA NIKITINA	{"phone": "+70906456195"}
0005433614800	D0152E	6551 990753	TAMARA BORISOVA	{"email": "t_borisova.09051967@postgrespro.ru", "phone": "+70549207943"}
0005433614801	AFAA2D	5298 265038	LYUDMILA KOROLEVA	{"phone": "+70814324788"}
0005433614802	25B1F4	2267 653034	TATYANA IVANOVA	{"phone": "+70547061447"}
0005433614803	FADC26	0200 198985	ELENA PAVLOVA	{"email": "elena.pavlova.05061976@postgrespro.ru", "phone": "+70095313869"}
0005433614804	B35269	0504 980014	EVGENIYA TARASOVA	{"email": "etarasova1965@postgrespro.ru", "phone": "+70271540228"}
0005433614805	B35269	5451 885820	TAMARA KOMAROVA	{"email": "tamara-komarova.1989@postgrespro.ru", "phone": "+70863728139"}
0005433614806	B35269	5866 447317	VIKTOR DENISOV	{"phone": "+70397870458"}
0005433614807	250A6F	4530 157495	MARIYA NESTEROVA	{"email": "nesterova.mariya111970@postgrespro.ru", "phone": "+70145990049"}
0005433614808	560D4C	2561 090143	ALEKSANDRA MOROZOVA	{"email": "morozova_a.20031972@postgrespro.ru", "phone": "+70651549194"}
0005433614809	EB971E	7323 554712	NIKITA VLASOV	{"phone": "+70103462676"}
0005433614810	572AAD	3050 803663	LYUDMILA VOLKOVA	{"email": "lyudmila_volkova-30081972@postgrespro.ru", "phone": "+70393541655"}
0005433614811	10D229	6971 795955	MARINA GRISHINA	{"email": "grishina-m_1975@postgrespro.ru", "phone": "+70874747365"}
0005433614812	A68751	6617 916182	ALEKSEY KRASNOV	{"email": "aleksey-krasnov021974@postgrespro.ru", "phone": "+70611238173"}
0005433614813	00E22A	1798 470760	ANTON MOROZOV	{"phone": "+70770404030"}
0005433614814	9951AF	6238 019197	SERGEY MAKAROV	{"email": "makarovsergey_111976@postgrespro.ru", "phone": "+70184079628"}
0005433614815	9951AF	6897 013707	VLADIMIR SIDOROV	{"phone": "+70303950745"}
0005433614816	B19BDD	9312 804627	ANDREY MOISEEV	{"phone": "+70943004542"}
0005433614817	C6131B	9530 682843	YURIY KAZAKOV	{"email": "kazakov.yuriy-03071962@postgrespro.ru", "phone": "+70137464334"}
0005433614818	F2C000	0290 321750	ANNA DMITRIEVA	{"phone": "+70271760339"}
0005433614819	F2C000	0731 709652	SERGEY MIKHAYLOV	{"email": "s-mikhaylov-1970@postgrespro.ru", "phone": "+70343222041"}
0005433614820	8CB156	0552 386446	LIDIYA AFANASEVA	{"email": "afanaseval_121961@postgrespro.ru", "phone": "+70306755984"}
0005433614933	B961FA	6226 662741	LIDIYA ZAKHAROVA	{"phone": "+70326444327"}
0005433614821	8CB156	0148 897653	NADEZHDA ROMANOVA	{"email": "romanova-n_1961@postgrespro.ru", "phone": "+70827760156"}
0005433614822	B5CCC9	9330 134313	SERGEY KONOVALOV	{"email": "s.konovalov.1973@postgrespro.ru", "phone": "+70071915995"}
0005433614823	B5CCC9	2405 782994	NADEZHDA DMITRIEVA	{"phone": "+70762718759"}
0005433614824	B5CCC9	8207 119163	SERGEY MAKAROV	{"phone": "+70365124784"}
0005433614825	8D4A36	9846 400562	RUSTEM FILIPPOV	{"email": "rustem.filippov.25071975@postgrespro.ru", "phone": "+70161563882"}
0005433614826	A6D588	0666 391021	NADEZHDA NIKOLAEVA	{"email": "nikolaevan.10061982@postgrespro.ru", "phone": "+70501592876"}
0005433614827	D8655C	0939 694103	ANATOLIY KUZMIN	{"email": "a_kuzmin13091975@postgrespro.ru", "phone": "+70003885315"}
0005433614828	D8655C	0024 240932	IRINA ALEKSEEVA	{"email": "alekseeva_i-121976@postgrespro.ru", "phone": "+70207356199"}
0005433614829	D8655C	4931 044636	VALERIYA ZOTOVA	{"email": "zotovav_121976@postgrespro.ru", "phone": "+70951209374"}
0005433614830	EC432D	3477 833507	OKSANA ZOTOVA	{"email": "oksana.zotova_091962@postgrespro.ru", "phone": "+70162475971"}
0005433614831	E3839E	9975 870596	NATALYA POPOVA	{"email": "popova.n-1965@postgrespro.ru", "phone": "+70115866600"}
0005433614832	019E46	1650 333535	ANNA KALININA	{"phone": "+70065275257"}
0005433614833	019E46	3382 876576	ALEKSANDR AFANASEV	{"email": "afanasev-a-17071974@postgrespro.ru", "phone": "+70288663825"}
0005433614834	8F35E6	4362 663978	YURIY POPOV	{"email": "y-popov.1970@postgrespro.ru", "phone": "+70637174148"}
0005433614835	E03869	9322 333708	MIKHAIL MARTYNOV	{"email": "mikhailmartynov_051981@postgrespro.ru", "phone": "+70699341956"}
0005433614836	0C5B18	6314 921936	EVGENIY ALEKSANDROV	{"phone": "+70690478461"}
0005433614837	F8A57C	8312 668713	ELENA KONOVALOVA	{"email": "konovalovaelena_12121966@postgrespro.ru", "phone": "+70646341841"}
0005433614838	31D79F	9532 835706	EKATERINA TIKHONOVA	{"email": "tikhonova-ekaterina091970@postgrespro.ru", "phone": "+70751765292"}
0005433614839	31D79F	8650 212259	OKSANA LAZAREVA	{"email": "lazareva_oksana.1980@postgrespro.ru", "phone": "+70870671961"}
0005433614840	C61294	3312 082642	ANNA ANTONOVA	{"email": "anna.antonova_1970@postgrespro.ru", "phone": "+70214675091"}
0005433614841	C61294	4769 762581	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov-111969@postgrespro.ru", "phone": "+70897929436"}
0005433614842	A77753	7640 113486	ELENA NIKITINA	{"phone": "+70642276940"}
0005433614843	A77753	0110 927276	NATALYA AKIMOVA	{"phone": "+70514926705"}
0005433614844	A77753	2729 045250	NATALYA KUZMINA	{"phone": "+70386943056"}
0005433614845	23BAD6	8718 596338	TAMARA ANDREEVA	{"email": "tamara-andreeva091978@postgrespro.ru", "phone": "+70570377173"}
0005433614846	23BAD6	0184 502896	LYUBOV MOISEEVA	{"email": "l_moiseeva-31121975@postgrespro.ru", "phone": "+70785023268"}
0005433614847	F71E70	7410 455685	ALEKSEY MOROZOV	{"email": "morozov.a-01031978@postgrespro.ru", "phone": "+70582878234"}
0005433614848	266BD4	6942 780583	NIKOLAY SAVELEV	{"email": "savelev-n-19041975@postgrespro.ru", "phone": "+70764560185"}
0005433614849	266BD4	8872 204806	VASILIY NIKITIN	{"email": "nikitin_v.1966@postgrespro.ru", "phone": "+70468561528"}
0005433614850	C11E4C	0005 232524	VALENTINA DENISOVA	{"email": "v-denisova.08061971@postgrespro.ru", "phone": "+70535280295"}
0005433614851	C11E4C	2695 685695	ELENA KAZAKOVA	{"email": "kazakova.e_1981@postgrespro.ru", "phone": "+70793567924"}
0005433614852	5D145E	1535 475379	VENIAMIN FROLOV	{"email": "veniamin.frolov011981@postgrespro.ru", "phone": "+70475713703"}
0005433614853	5D145E	6465 952979	KLAVDIYA VLASOVA	{"email": "klavdiya.vlasova.1975@postgrespro.ru", "phone": "+70689290401"}
0005433614854	6AC512	6819 819656	ROZA POTAPOVA	{"phone": "+70665298364"}
0005433614855	6AC512	9426 839158	YANA DENISOVA	{"email": "y-denisova_1967@postgrespro.ru", "phone": "+70560317329"}
0005433614856	41447E	5555 231548	NATALYA OSIPOVA	{"email": "osipova_natalya-111973@postgrespro.ru", "phone": "+70199025053"}
0005433614857	41447E	9660 487641	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-13051969@postgrespro.ru", "phone": "+70545016071"}
0005433614858	6DB182	6061 719814	MAKSIM MOROZOV	{"email": "morozov_maksim-12091981@postgrespro.ru", "phone": "+70165398464"}
0005433614859	5DEBF1	9776 468593	ANATOLIY CHERNOV	{"email": "chernovanatoliy_1966@postgrespro.ru", "phone": "+70509305447"}
0005433614860	624554	4095 052264	IVAN MAKAROV	{"email": "i_makarov-19011968@postgrespro.ru", "phone": "+70445877619"}
0005433614861	E92D93	5524 664105	TATYANA NOVIKOVA	{"phone": "+70684986445"}
0005433614862	4AB0D4	2697 554818	YULIYA ZAKHAROVA	{"email": "zakharova.yuliya.031973@postgrespro.ru", "phone": "+70681231592"}
0005433614863	4AB0D4	2824 853667	ALEKSANDR GORBUNOV	{"phone": "+70231147380"}
0005433614864	A874AC	4857 612148	VALENTINA KONOVALOVA	{"phone": "+70443125381"}
0005433614865	F6DCBF	8164 007199	DMITRIY VASILEV	{"phone": "+70384590962"}
0005433614866	F6DCBF	2636 051691	TATYANA NAUMOVA	{"email": "tnaumova011980@postgrespro.ru", "phone": "+70761888233"}
0005433614867	F05848	2447 739494	ANDREY STEPANOV	{"email": "stepanov_andrey.10031978@postgrespro.ru", "phone": "+70884035261"}
0005433614868	ED6006	6316 706111	EVGENIYA ZAYCEVA	{"phone": "+70664537063"}
0005433614869	BFB59E	2913 616928	PELAGEYA IVANOVA	{"email": "ivanova.pelageya_31011972@postgrespro.ru", "phone": "+70029393843"}
0005433614870	6F1A09	0216 792285	VIKTOR KISELEV	{"email": "kiselev.viktor_1981@postgrespro.ru", "phone": "+70315566761"}
0005433614871	F14764	6826 588329	NATALYA MOROZOVA	{"email": "morozova_natalya.17011969@postgrespro.ru", "phone": "+70297945374"}
0005433614872	8D7038	9305 817348	ALEKSANDR DAVYDOV	{"phone": "+70792769107"}
0005433614873	3C2F15	3496 003888	SERGEY STEPANOV	{"phone": "+70685965722"}
0005433614874	46C53C	4119 486143	NATALYA MAKAROVA	{"email": "makarova-n-041982@postgrespro.ru", "phone": "+70579844869"}
0005433614875	46C53C	1635 437393	ALEKSEY CHERNOV	{"email": "alekseychernov_09041975@postgrespro.ru", "phone": "+70843827098"}
0005433614876	48D85F	8832 662861	ANDREY SEMENOV	{"phone": "+70017085630"}
0005433614877	F08B2E	1015 295083	ANGELINA NAUMOVA	{"phone": "+70333882968"}
0005433614878	F08B2E	3750 059147	VLADIMIR ROMANOV	{"email": "romanov.v_03041964@postgrespro.ru", "phone": "+70239088986"}
0005433614879	B04FBA	8145 689426	ANATOLIY NOVIKOV	{"phone": "+70649693716"}
0005433614880	9ABAAF	3856 025563	LYUDMILA MIKHAYLOVA	{"phone": "+70450548372"}
0005433614881	9ABAAF	6027 252502	IRINA MOROZOVA	{"phone": "+70004063924"}
0005433614882	39A45E	5388 313041	MILANA ZAKHAROVA	{"email": "m-zakharova_02081980@postgrespro.ru", "phone": "+70268474441"}
0005433614883	68C5FF	7549 992007	ELENA KOROLEVA	{"email": "koroleva-elena.1978@postgrespro.ru", "phone": "+70642028896"}
0005433614884	68C5FF	4606 846448	EKATERINA ALEKSEEVA	{"phone": "+70307564921"}
0005433614885	405E6C	6119 472224	PETR GORBUNOV	{"phone": "+70116739647"}
0005433614886	F30E56	1079 940842	ALEKSEY ZHUKOV	{"phone": "+70652124143"}
0005433614887	664F9A	3781 960484	SERGEY FEDOROV	{"phone": "+70491258294"}
0005433614888	9A0473	0585 273999	ALEKSANDRA VOROBEVA	{"phone": "+70663814421"}
0005433614889	9A0473	1739 186124	IVAN IVANOV	{"email": "ivanov-ivan1968@postgrespro.ru", "phone": "+70070858778"}
0005433614890	AE392C	0606 841608	NATALIYA EGOROVA	{"email": "negorova.1978@postgrespro.ru", "phone": "+70466064687"}
0005433614891	79EE70	6566 153504	ANGELINA CHERNOVA	{"email": "chernova.a-08051964@postgrespro.ru", "phone": "+70971540220"}
0005433614892	150A0B	3883 755493	VLADIMIR KOZLOV	{"phone": "+70692042156"}
0005433614893	0A7B64	6933 420064	IGOR FEDOROV	{"phone": "+70843451059"}
0005433614894	C0AD12	6025 112737	EVGENIYA ANDREEVA	{"email": "evgeniya_andreeva-1967@postgrespro.ru", "phone": "+70110740103"}
0005433614895	C0AD12	1667 336003	LIDIYA SERGEEVA	{"phone": "+70638661120"}
0005433614896	C0AD12	6820 341131	YURIY NIKITIN	{"email": "yuriy_nikitin111975@postgrespro.ru", "phone": "+70863249876"}
0005433614897	14E25E	6738 652057	ALEKSANDR GUSEV	{"phone": "+70222490168"}
0005433614898	2653D5	8047 163370	EKATERINA NOVIKOVA	{"phone": "+70622799588"}
0005433614899	A740B0	8205 181606	SOFYA KISELEVA	{"phone": "+70595343844"}
0005433614900	A740B0	3204 801123	ALEKSANDR KARPOV	{"phone": "+70121539194"}
0005433614901	121F4A	9058 513750	LIDIYA NOVIKOVA	{"email": "l.novikova_1966@postgrespro.ru", "phone": "+70709428716"}
0005433614902	121F4A	6158 978978	IGOR ZAYCEV	{"phone": "+70127070917"}
0005433614903	C0CD59	0375 689018	ISLAM POPOV	{"phone": "+70598938243"}
0005433614904	B16B9A	8356 393403	LYUDMILA PETROVA	{"phone": "+70262326161"}
0005433614905	5DB6F6	5107 560929	OLGA BELOVA	{"phone": "+70924579593"}
0005433614906	52DB14	6430 258456	ANNA KUZNECOVA	{"email": "annakuznecova.23021969@postgrespro.ru", "phone": "+70045619653"}
0005433614907	DB61BB	1674 574125	ALEKSANDR ILIN	{"phone": "+70041749018"}
0005433614908	09DB17	2263 965663	VLADIMIR MOROZOV	{"phone": "+70019235582"}
0005433614909	11A2A1	8355 390988	NIKOLAY PAVLOV	{"phone": "+70603156115"}
0005433614910	2524A9	6475 614623	ZINAIDA OVCHINNIKOVA	{"phone": "+70513339818"}
0005433614911	471F3C	4490 857739	IRINA SERGEEVA	{"email": "irina.sergeeva071979@postgrespro.ru", "phone": "+70246238663"}
0005433614912	DB923D	1143 605689	ILYA KUZNECOV	{"phone": "+70535364343"}
0005433614913	A1A9C8	4201 224577	ANATOLIY IVANOV	{"email": "ivanovanatoliy1966@postgrespro.ru", "phone": "+70941376548"}
0005433614914	5539EB	7651 317951	TATYANA CHERNOVA	{"phone": "+70374500487"}
0005433614915	E057F3	9671 425920	SERGEY FEDOTOV	{"phone": "+70288270065"}
0005433614916	A986F2	8998 850657	IRINA FEDOROVA	{"phone": "+70859966556"}
0005433614917	A986F2	8024 216777	VITALIY CHERNOV	{"email": "vitaliy_chernov_081966@postgrespro.ru", "phone": "+70239993932"}
0005433614918	303889	0466 048201	IRINA EGOROVA	{"email": "iegorova-051972@postgrespro.ru", "phone": "+70728422389"}
0005433614919	297FA0	4743 158141	EGOR MELNIKOV	{"phone": "+70353587086"}
0005433614920	297FA0	9117 499174	NADEZHDA TARASOVA	{"phone": "+70021160315"}
0005433614921	930E41	1737 620558	VLADIMIR ABRAMOV	{"email": "abramov.vladimir.1974@postgrespro.ru", "phone": "+70114667219"}
0005433614922	25CFDD	1284 924272	NADEZHDA LEBEDEVA	{"phone": "+70425595624"}
0005433614923	25CFDD	5848 671735	NIKOLAY ANTONOV	{"email": "nikolay_antonov.031963@postgrespro.ru", "phone": "+70051244030"}
0005433614924	3DFBB5	4986 577304	NINA KOZLOVA	{"phone": "+70174633177"}
0005433614925	3DFBB5	0702 727339	OLGA POPOVA	{"email": "popova-olga_061956@postgrespro.ru", "phone": "+70797134592"}
0005433614926	3DFBB5	3733 958511	LILIYA PETROVA	{"phone": "+70793382656"}
0005433614927	2354A5	7166 627343	IRINA KUZMINA	{"phone": "+70163773428"}
0005433614928	B301BE	9256 801192	ALEKSEY MEDVEDEV	{"phone": "+70301949368"}
0005433614929	A803C1	9260 114819	MIKHAIL MIKHAYLOV	{"phone": "+70742570199"}
0005433614930	7E82E4	3177 783275	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana-1982@postgrespro.ru", "phone": "+70061318329"}
0005433614931	D0E361	0466 438952	DARYA ZAYCEVA	{"phone": "+70596278322"}
0005433614932	1EEB88	5735 911050	LYUDMILA ORLOVA	{"email": "lorlova.101960@postgrespro.ru", "phone": "+70552773154"}
0005433614934	6D8277	8783 953284	DENIS MOROZOV	{"email": "d-morozov06051970@postgrespro.ru", "phone": "+70618838904"}
0005433614935	BAB708	4632 349185	LYUBOV BELYAEVA	{"email": "l-belyaeva-031978@postgrespro.ru", "phone": "+70164891946"}
0005433614936	F7CF8A	2657 174796	SERGEY TARASOV	{"phone": "+70294825473"}
0005433614937	6C3DF9	3567 771316	IVAN ORLOV	{"email": "i-orlov.1982@postgrespro.ru", "phone": "+70374017554"}
0005433614938	6C3DF9	2817 897155	VIKTOR MEDVEDEV	{"phone": "+70298484084"}
0005433614939	E5776D	7168 586850	ELENA KISELEVA	{"phone": "+70636394519"}
0005433614940	3CEC2F	5313 943918	VITALIY FEDOROV	{"email": "v.fedorov1972@postgrespro.ru", "phone": "+70664656869"}
0005433614941	9C515F	7749 660686	MARIYA ZAKHAROVA	{"phone": "+70297867130"}
0005433614942	9C515F	3589 699040	EKATERINA MARTYNOVA	{"phone": "+70979587293"}
0005433614943	930E34	1602 409182	ZINAIDA ALEKSANDROVA	{"email": "aleksandrovazinaida-091969@postgrespro.ru", "phone": "+70201774873"}
0005433614944	FD4062	8629 028218	OLGA KONOVALOVA	{"phone": "+70838488198"}
0005433614945	6192B2	8736 183634	ELISEY MIRONOV	{"phone": "+70876543567"}
0005433614946	8024E0	3083 658803	VYACHESLAV EGOROV	{"phone": "+70036361210"}
0005433614947	8024E0	8487 823059	VALENTINA ERMAKOVA	{"phone": "+70435730695"}
0005433614948	27AEF9	3454 356186	RAISA DENISOVA	{"phone": "+70324889623"}
0005433614949	27AEF9	9893 900171	VLADIMIR BARANOV	{"email": "vladimir-baranov.071977@postgrespro.ru", "phone": "+70733315578"}
0005433614950	C0B16A	9315 421644	YURIY DENISOV	{"phone": "+70077851636"}
0005433614951	C6920B	0834 289495	GALINA PETROVA	{"email": "petrova.galina.22031970@postgrespro.ru", "phone": "+70975692338"}
0005433614952	D85176	8891 103734	ANDREY KUZNECOV	{"phone": "+70683629748"}
0005433614953	C264AD	1860 130818	ALEKSANDR MARTYNOV	{"phone": "+70906933864"}
0005433614954	748CC6	0904 225159	VLADISLAV DMITRIEV	{"phone": "+70242594873"}
0005433614955	FC6ADC	2795 888759	NATALYA POPOVA	{"email": "natalyapopova18091973@postgrespro.ru", "phone": "+70994530483"}
0005433614956	FC6ADC	5803 719494	TATYANA OSIPOVA	{"phone": "+70810332660"}
0005433614957	6A0720	0002 449866	TATYANA KARPOVA	{"email": "karpova_tatyana11021968@postgrespro.ru", "phone": "+70530396648"}
0005433614958	0AC52A	4375 779922	EVGENIY SOROKIN	{"phone": "+70300283487"}
0005433614959	7A3011	3981 726642	NIKOLAY FILIPPOV	{"phone": "+70531526696"}
0005433614960	C2AD2F	4392 157275	GALINA KUZMINA	{"phone": "+70220809101"}
0005433614961	9F4130	2439 354015	EKATERINA VOLKOVA	{"phone": "+70993402645"}
0005433614962	38A4BD	4190 341290	ZINAIDA KARPOVA	{"phone": "+70714217168"}
0005433614963	38A4BD	3500 433598	VLADIMIR SIDOROV	{"email": "sidorov_vladimir.13031965@postgrespro.ru", "phone": "+70527254284"}
0005433614964	38A4BD	7075 769411	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.17021972@postgrespro.ru", "phone": "+70683695127"}
0005433614965	DCA858	5348 109781	IRINA NIKOLAEVA	{"email": "nikolaeva-i_04081976@postgrespro.ru", "phone": "+70751785054"}
0005433614966	46C4B8	8315 239586	VYACHESLAV TIKHONOV	{"phone": "+70282305612"}
0005433614967	46C4B8	1578 934414	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr081976@postgrespro.ru", "phone": "+70396621434"}
0005433614968	9F74FB	4052 675843	VLADIMIR ZAKHAROV	{"email": "v.zakharov-09111976@postgrespro.ru", "phone": "+70923657237"}
0005433614969	50068D	8057 663376	YAROSLAV SHEVCHENKO	{"phone": "+70504660332"}
0005433614970	50068D	3930 682059	POLINA DMITRIEVA	{"email": "p-dmitrieva1976@postgrespro.ru", "phone": "+70149670818"}
0005433614971	14B10D	2045 969008	IRINA KUZNECOVA	{"phone": "+70441385172"}
0005433614972	F19B6F	5712 135324	PETR VLASOV	{"phone": "+70077316217"}
0005433614973	20041C	2707 845738	ANDREY STEPANOV	{"phone": "+70567024599"}
0005433614974	F7364B	4985 479939	GALINA NAZAROVA	{"phone": "+70278168232"}
0005433614975	F7364B	7162 640387	KARINA NIKITINA	{"email": "k.nikitina.061974@postgrespro.ru", "phone": "+70359273133"}
0005433614976	F7364B	3218 634167	ANNA KUZMINA	{"phone": "+70106746292"}
0005433614977	C5066B	6731 898776	MARIYA NOVIKOVA	{"email": "novikovamariya-08041964@postgrespro.ru", "phone": "+70218029706"}
0005433614978	E30DA3	3352 318637	ANDREY EGOROV	{"email": "egorov-andrey.11091979@postgrespro.ru", "phone": "+70605964964"}
0005433614979	E30DA3	6891 933115	ALEKSEY EGOROV	{"phone": "+70773785565"}
0005433614980	EDCE0A	2201 315454	INNA ALEKSEEVA	{"phone": "+70718806707"}
0005433614981	653529	8199 573989	KSENIYA KOROLEVA	{"email": "koroleva-kseniya.08081968@postgrespro.ru", "phone": "+70189584309"}
0005433614982	653529	2400 123563	ZOYA NESTEROVA	{"email": "nesterova.zoya_081972@postgrespro.ru", "phone": "+70984548624"}
0005433614983	D0A358	7477 346408	OLGA KOZLOVA	{"email": "kozlovao-1975@postgrespro.ru", "phone": "+70520459321"}
0005433614984	A28745	2199 214540	ALEKSEY SEMENOV	{"phone": "+70977108183"}
0005433614985	0927F9	7468 009457	VLADISLAV VLASOV	{"email": "vladislavvlasov-22011985@postgrespro.ru", "phone": "+70838128608"}
0005433614986	F230DA	2693 343686	VIKTOR NIKITIN	{"phone": "+70549817500"}
0005433614987	153C6A	1907 735241	DENIS NAUMOV	{"email": "denis-naumov-1971@postgrespro.ru", "phone": "+70599315919"}
0005433614988	CA3AE8	3631 220998	VALERIY PAVLOV	{"email": "pavlov-valeriy_1965@postgrespro.ru", "phone": "+70239832957"}
0005433614989	0A2BF6	8914 303544	EVGENIY KOROLEV	{"phone": "+70537452655"}
0005433614990	0A2BF6	5855 559520	YULIYA GUSEVA	{"email": "y.guseva-1967@postgrespro.ru", "phone": "+70826938002"}
0005433614991	8845E5	0549 906522	ANDREY SOKOLOV	{"email": "andrey_sokolov.031976@postgrespro.ru", "phone": "+70301331764"}
0005433614992	C26DF8	5615 803552	DMITRIY MAKAROV	{"email": "makarovd-15081967@postgrespro.ru", "phone": "+70214310801"}
0005433614993	C26DF8	9669 399295	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr1962@postgrespro.ru", "phone": "+70719954568"}
0005433614994	C26DF8	0058 043770	NIKOLAY GERASIMOV	{"email": "gerasimov_nikolay_021975@postgrespro.ru", "phone": "+70052145931"}
0005433614995	2E2726	5619 429050	SOFYA MELNIKOVA	{"email": "melnikovasofya.1967@postgrespro.ru", "phone": "+70468038558"}
0005433614996	2E811A	7305 189665	NIKOLAY SIDOROV	{"email": "sidorov_nikolay.081981@postgrespro.ru", "phone": "+70187247513"}
0005433614997	40E177	5123 338551	IRINA BORISOVA	{"phone": "+70771076984"}
0005433614998	40E177	0477 355217	VALENTINA NESTEROVA	{"email": "nesterova_valentina1964@postgrespro.ru", "phone": "+70378003848"}
0005433614999	58B03B	5881 924047	LYUDMILA IVANOVA	{"email": "ivanova.l.031969@postgrespro.ru", "phone": "+70718108397"}
0005433615000	4E52E3	0757 378917	NINA ISAEVA	{"email": "isaeva.n-25041962@postgrespro.ru", "phone": "+70338508711"}
0005433615001	4E52E3	0874 666485	MARIYA ISAEVA	{"email": "mariyaisaeva20031961@postgrespro.ru", "phone": "+70073178877"}
0005433615002	7903D6	5370 647808	KLAVDIYA ROMANOVA	{"phone": "+70574591654"}
0005433615003	E7245E	6496 123830	YURIY KUZNECOV	{"phone": "+70019621467"}
0005433615004	E7245E	8317 068405	ILSHAT MAKAROV	{"phone": "+70125576085"}
0005433615005	D515A4	6373 097700	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev-1964@postgrespro.ru", "phone": "+70564726115"}
0005433615006	D3E76E	5995 741163	ELENA KULIKOVA	{"email": "kulikovaelena.101979@postgrespro.ru", "phone": "+70858319613"}
0005433615007	D3E76E	2770 800998	ALEKSANDR PAVLOV	{"phone": "+70165041465"}
0005433615008	6CA200	8060 062934	SVETLANA BELOVA	{"email": "s_belova_28121973@postgrespro.ru", "phone": "+70779693791"}
0005433615009	14D4D7	4748 449330	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr_061987@postgrespro.ru", "phone": "+70460249271"}
0005433615010	C91474	3516 511526	GENNADIY GORBUNOV	{"phone": "+70630288957"}
0005433615011	8DB4E4	7272 877305	ELENA VOLKOVA	{"phone": "+70304615786"}
0005433615012	2BA489	1876 401732	SVETLANA FEDOROVA	{"phone": "+70981930894"}
0005433615013	2BA489	3439 424965	SERGEY KULIKOV	{"email": "kulikov_s1975@postgrespro.ru", "phone": "+70074448771"}
0005433615014	2BA489	1472 391690	IRINA KOZLOVA	{"phone": "+70014255678"}
0005433615015	A042A3	8732 391195	TATYANA VOLKOVA	{"email": "tatyana.volkova_08021968@postgrespro.ru", "phone": "+70601074677"}
0005433615016	A042A3	1116 432738	GENNADIY DENISOV	{"phone": "+70633079626"}
0005433615017	3E1B15	3246 877189	NIKOLAY KAZAKOV	{"email": "kazakovnikolay-1984@postgrespro.ru", "phone": "+70090225610"}
0005433615018	72F562	5179 299226	YULIYA ERMAKOVA	{"phone": "+70579606072"}
0005433615019	72F562	2884 308084	NATALYA SOKOLOVA	{"email": "sokolova.n-041978@postgrespro.ru", "phone": "+70945265076"}
0005433615020	35BF4C	8199 147621	EVGENIYA ILINA	{"email": "e_ilina-021967@postgrespro.ru", "phone": "+70126599119"}
0005433615021	53AEBD	7787 583428	SERGEY GAVRILOV	{"email": "sgavrilov01011966@postgrespro.ru", "phone": "+70297945562"}
0005433615022	4FE209	0001 061171	GENNADIY FILIPPOV	{"email": "filippov.gennadiy-1971@postgrespro.ru", "phone": "+70243350044"}
0005433615023	34DA7A	2327 730928	VASILIY FILIPPOV	{"email": "v_filippov.09081972@postgrespro.ru", "phone": "+70996741400"}
0005433615024	FD92A8	0071 710434	ALEVTINA KOLESNIKOVA	{"phone": "+70563065076"}
0005433615025	5292D2	8149 033496	MIKHAIL ALEKSEEV	{"phone": "+70693289848"}
0005433615026	4EBAF3	1968 331260	RIMMA ABRAMOVA	{"email": "rimmaabramova.27121976@postgrespro.ru", "phone": "+70587909281"}
0005433615027	A10F3E	3283 104428	IGOR GUSEV	{"email": "gusev.i.28081980@postgrespro.ru", "phone": "+70166535842"}
0005433615028	E028B2	7165 887730	NADEZHDA VOROBEVA	{"phone": "+70026299858"}
0005433615029	97F97F	9478 013248	OLGA KOZLOVA	{"phone": "+70351513924"}
0005433615030	233ED2	2648 210498	OLGA NAZAROVA	{"phone": "+70036851464"}
0005433615031	233ED2	2926 179762	OLGA KOLESNIKOVA	{"phone": "+70367787588"}
0005433615032	8DC3A2	5965 678684	KSENIYA ZAYCEVA	{"phone": "+70191248259"}
0005433615033	8DC3A2	2753 498790	ANTONINA ARKHIPOVA	{"email": "arkhipova_antonina.19041974@postgrespro.ru", "phone": "+70714859209"}
0005433615034	13A816	9749 566819	NINA SMIRNOVA	{"email": "smirnova-nina-1968@postgrespro.ru", "phone": "+70518491000"}
0005433615035	CAE5D4	5613 813569	LYUBOV OVCHINNIKOVA	{"email": "lyubov_ovchinnikova1972@postgrespro.ru", "phone": "+70530713375"}
0005433615036	CAE5D4	5771 040535	RAISA FROLOVA	{"email": "rfrolova-1961@postgrespro.ru", "phone": "+70067130792"}
0005433615037	F88C02	5105 244571	ALEKSANDR DENISOV	{"phone": "+70685017706"}
0005433615038	F88C02	7359 910790	VALERIY BELOV	{"email": "belov.valeriy-1955@postgrespro.ru", "phone": "+70592181321"}
0005433615039	F88C02	4805 977113	MIKHAIL DMITRIEV	{"email": "dmitriev_m-20031983@postgrespro.ru", "phone": "+70369406640"}
0005433615040	D36319	0823 508289	ALEKSEY ISAEV	{"phone": "+70094600519"}
0005433615041	4372EB	0606 429450	GALINA ROMANOVA	{"phone": "+70480080090"}
0005433615042	4D371C	4608 349482	SVETLANA MOROZOVA	{"phone": "+70836030231"}
0005433615043	E00383	3485 465651	ANZHELIKA VLASOVA	{"email": "anzhelikavlasova_051976@postgrespro.ru", "phone": "+70839713842"}
0005433615044	3A116B	9119 495335	VENERA LEBEDEVA	{"email": "lebedevavenera061959@postgrespro.ru", "phone": "+70754510025"}
0005433615045	22B62D	9841 838078	EVGENIYA KOMAROVA	{"phone": "+70480231460"}
0005433615046	59316A	5540 407427	YURIY DAVYDOV	{"email": "y.davydov_061963@postgrespro.ru", "phone": "+70980210961"}
0005433615047	59316A	5009 551393	DMITRIY KRASNOV	{"phone": "+70538065650"}
0005433615048	4B1745	9232 774315	EMILIYA FILIPPOVA	{"phone": "+70390055605"}
0005433615049	4B1745	3273 971165	LYUDMILA NAZAROVA	{"email": "nazarova.lyudmila.101975@postgrespro.ru", "phone": "+70772199871"}
0005433615050	C14C8F	1188 626202	EVGENIY RODIONOV	{"phone": "+70166784062"}
0005433615051	569329	0751 025015	KSENIYA YAKOVLEVA	{"phone": "+70502738273"}
0005433615052	3B1DB4	2040 648417	KLAVDIYA FILATOVA	{"phone": "+70565714324"}
0005433615053	A0846B	0787 117135	ELENA ILINA	{"email": "ilina.elena1965@postgrespro.ru", "phone": "+70040108217"}
0005433615054	298172	0015 488937	OLGA MIKHAYLOVA	{"phone": "+70461343955"}
0005433615055	2F1EB8	9855 019131	OLEG MOROZOV	{"phone": "+70651147241"}
0005433615056	2F1EB8	1448 403320	ANNA NESTEROVA	{"phone": "+70151451701"}
0005433615057	826468	1412 541988	ALEKSEY KUDRYASHOV	{"email": "kudryashovaleksey-02031983@postgrespro.ru", "phone": "+70541740630"}
0005433615058	826468	9768 134297	ANASTASIYA POPOVA	{"phone": "+70118440632"}
0005433615059	99D2EE	8578 664776	VYACHESLAV KUZMIN	{"phone": "+70775889489"}
0005433615060	6BD6C5	4139 849815	MARFA SMIRNOVA	{"phone": "+70134113399"}
0005433615061	6BD6C5	5201 441041	VIKTOR SMIRNOV	{"email": "viktorsmirnov_1973@postgrespro.ru", "phone": "+70466362392"}
0005433615062	AA4D52	0307 250319	MARIYA EGOROVA	{"phone": "+70784705401"}
0005433615063	AA4D52	5026 088925	ILYA GRIGOREV	{"email": "grigorevi_06011971@postgrespro.ru", "phone": "+70546011711"}
0005433615064	E319FE	1278 972976	ANDREY IVANOV	{"email": "a-ivanov_23081981@postgrespro.ru", "phone": "+70483329210"}
0005433615065	E319FE	9995 949926	IRINA GERASIMOVA	{"email": "gerasimova.i031975@postgrespro.ru", "phone": "+70954324958"}
0005433615066	E319FE	6119 759006	NATALYA NOVIKOVA	{"phone": "+70752258255"}
0005433615067	6142AC	8874 601567	IGOR SEMENOV	{"email": "semenov_igor10061973@postgrespro.ru", "phone": "+70198828559"}
0005433615068	6142AC	9885 076446	EKATERINA GAVRILOVA	{"email": "gavrilova_ekaterina_101963@postgrespro.ru", "phone": "+70073734978"}
0005433615069	CEB986	8130 388952	IVAN KUZNECOV	{"email": "ivankuznecov-02071963@postgrespro.ru", "phone": "+70506114553"}
0005433615070	3D7479	1826 834819	IGOR PAVLOV	{"phone": "+70844010819"}
0005433615071	3D7479	2820 635070	NATALYA NIKITINA	{"phone": "+70893159425"}
0005433615072	EB0136	1026 323360	RUMIYA NAZAROVA	{"email": "rumiyanazarova1974@postgrespro.ru", "phone": "+70553967599"}
0005433615073	F536A9	5322 113792	RIMMA EFIMOVA	{"phone": "+70804371260"}
0005433615074	F536A9	7843 610053	VIKTOR STEPANOV	{"phone": "+70277062018"}
0005433615075	F536A9	0874 960177	ANASTASIYA DAVYDOVA	{"phone": "+70882802464"}
0005433615076	31FAE9	7514 272985	LYUBOV DENISOVA	{"email": "denisova_l101968@postgrespro.ru", "phone": "+70265692383"}
0005433615077	31FAE9	6987 707905	ALENA NIKOLAEVA	{"email": "a-nikolaeva.29021980@postgrespro.ru", "phone": "+70426404010"}
0005433615078	31FAE9	3202 612452	LARISA SMIRNOVA	{"email": "smirnoval-05111981@postgrespro.ru", "phone": "+70864898271"}
0005433615079	31FAE9	5973 002500	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova.29091974@postgrespro.ru", "phone": "+70308314469"}
0005433615080	01342C	8692 640933	ANDREY DAVYDOV	{"phone": "+70324242900"}
0005433615081	F83101	6868 196613	IGOR PETROV	{"phone": "+70707044108"}
0005433615082	DC5F3A	1642 406392	ARTEM SOROKIN	{"email": "a.sorokin.28021979@postgrespro.ru", "phone": "+70475662003"}
0005433615083	9AB9B9	9299 567002	RAFAEL MAKAROV	{"phone": "+70676637214"}
0005433615084	324EC2	3855 470973	NATALYA NAUMOVA	{"email": "natalya-naumova30121981@postgrespro.ru", "phone": "+70967316548"}
0005433615085	BF0AB3	7845 225366	GEORGIY ZHUKOV	{"phone": "+70569331831"}
0005433615086	9EA987	6805 322215	DMITRIY PETROV	{"email": "d_petrov.071967@postgrespro.ru", "phone": "+70170903530"}
0005433615087	9EA987	9815 141991	KLAVDIYA TARASOVA	{"phone": "+70619847544"}
0005433615088	9EA987	7029 033231	SERGEY FEDOTOV	{"email": "fedotovs_011983@postgrespro.ru", "phone": "+70719428969"}
0005433615089	9EA987	8667 558455	DARYA SEMENOVA	{"email": "darya.semenova_12051971@postgrespro.ru", "phone": "+70463988289"}
0005433615090	284C97	0056 734711	YURIY PETROV	{"email": "y.petrov.21071966@postgrespro.ru", "phone": "+70994634519"}
0005433615091	284C97	0449 664772	MIKHAIL FOMIN	{"phone": "+70225382568"}
0005433615092	B3E4A4	3127 813054	TAGIR VASILEV	{"email": "vasilev-t-101977@postgrespro.ru", "phone": "+70929710395"}
0005433615093	55257E	0875 475109	YURIY STEPANOV	{"phone": "+70291586221"}
0005433615094	30B258	2917 233496	RAISA MEDVEDEVA	{"email": "medvedeva-raisa-031976@postgrespro.ru", "phone": "+70389305358"}
0005433615095	7B6036	3765 524689	ANZHELIKA ANDREEVA	{"phone": "+70553316021"}
0005433615096	37B2EA	8001 867892	SERGEY ANTONOV	{"email": "antonov-s021971@postgrespro.ru", "phone": "+70930910746"}
0005433615097	37B2EA	5483 250935	VLADIMIR IVANOV	{"email": "ivanov.v_08091969@postgrespro.ru", "phone": "+70915618155"}
0005433615098	FB2A55	7377 980170	IRINA KOROLEVA	{"email": "koroleva-i_1964@postgrespro.ru", "phone": "+70102478592"}
0005433615099	FB2A55	9025 329758	NATALYA PAVLOVA	{"phone": "+70246548676"}
0005433615100	FB2A55	5455 360023	PETR POPOV	{"email": "p-popov29011971@postgrespro.ru", "phone": "+70897878584"}
0005433615101	5D5741	5525 850078	TATYANA VOLKOVA	{"phone": "+70566936071"}
0005433615102	597A4B	5811 768056	LIDIYA GORBUNOVA	{"email": "gorbunova.lidiya.121981@postgrespro.ru", "phone": "+70946260577"}
0005433615103	EE69EC	8162 168477	VALENTINA CHERNOVA	{"email": "chernova_valentina_1982@postgrespro.ru", "phone": "+70945808780"}
0005433615104	D6F1E5	4783 693511	SERGEY VASILEV	{"phone": "+70117983609"}
0005433615105	E00945	1719 753502	OLGA ZHURAVLEVA	{"email": "ozhuravleva_1975@postgrespro.ru", "phone": "+70258486592"}
0005433615106	BC461F	8367 874615	RUSTEM GORBUNOV	{"email": "rustem_gorbunov051977@postgrespro.ru", "phone": "+70187457748"}
0005433615107	E8ACCC	0992 276150	ILYA GAVRILOV	{"phone": "+70104537124"}
0005433615108	5B90CA	7312 365662	SERGEY ROMANOV	{"email": "romanov-s1972@postgrespro.ru", "phone": "+70765682575"}
0005433615109	5B90CA	1405 968056	LIDIYA KUZMINA	{"phone": "+70092764564"}
0005433615110	5B90CA	3691 033012	YURIY TIKHONOV	{"email": "yuriy_tikhonov_1980@postgrespro.ru", "phone": "+70131652859"}
0005433615111	E4A72A	7059 827078	KONSTANTIN TARASOV	{"email": "k-tarasov011974@postgrespro.ru", "phone": "+70115641649"}
0005433615112	02EC40	3698 338859	FILIPP ANTONOV	{"email": "f.antonov.21061972@postgrespro.ru", "phone": "+70540111769"}
0005433615113	02EC40	2587 593335	MARIYA KRASNOVA	{"phone": "+70932855706"}
0005433615114	2CC600	9739 605787	ANDREY KUZNECOV	{"phone": "+70094345608"}
0005433615115	C761FE	9880 756522	VALENTINA DAVYDOVA	{"email": "davydova_v-15011974@postgrespro.ru", "phone": "+70038148066"}
0005433615116	735AA9	3244 799736	ANDREY RODIONOV	{"email": "rodionov_andrey-27091967@postgrespro.ru", "phone": "+70078080400"}
0005433615117	735AA9	1931 124015	VLADIMIR DAVYDOV	{"phone": "+70137736677"}
0005433615118	AFF60D	4173 812718	IRINA PETROVA	{"email": "i_petrova011990@postgrespro.ru", "phone": "+70009784017"}
0005433615119	339DB5	9300 742021	ANDREY KULIKOV	{"email": "a.kulikov071977@postgrespro.ru", "phone": "+70098662543"}
0005433615120	B37DAD	8999 660473	YULIYA POPOVA	{"phone": "+70243851011"}
0005433615121	B37DAD	1154 369888	OLGA KONDRATEVA	{"phone": "+70785893863"}
0005433615122	FA95B2	0818 025699	LYUBOV BARANOVA	{"email": "lyubov_baranova_1976@postgrespro.ru", "phone": "+70646684411"}
0005433615123	B29FD6	5455 524868	ELENA KUZMINA	{"email": "elena.kuzmina_1974@postgrespro.ru", "phone": "+70509891275"}
0005433615124	B29FD6	0325 268786	NATALYA EFREMOVA	{"phone": "+70098875387"}
0005433615125	081A8E	8836 037477	KARINA IVANOVA	{"email": "karinaivanova.11081981@postgrespro.ru", "phone": "+70313729453"}
0005433615126	081A8E	6389 078184	YULIYA DENISOVA	{"phone": "+70193967428"}
0005433615127	683F91	4902 661437	GALINA MAKSIMOVA	{"email": "g.maksimova.021972@postgrespro.ru", "phone": "+70676750163"}
0005433615128	CBCD09	7546 826931	OLGA KOROLEVA	{"phone": "+70282287023"}
0005433615129	64C7C0	9862 986318	MARIYA KONOVALOVA	{"email": "konovalova-m1980@postgrespro.ru", "phone": "+70549757677"}
0005433615130	4E306C	6375 391381	TAMARA GERASIMOVA	{"email": "tgerasimova031983@postgrespro.ru", "phone": "+70213381407"}
0005433615131	4E306C	8609 118036	LYUBOV VASILEVA	{"email": "vasilevalyubov_1965@postgrespro.ru", "phone": "+70463307551"}
0005433615132	C38772	2809 038913	ALEKSANDR GUSEV	{"email": "a_gusev_1971@postgrespro.ru", "phone": "+70360897047"}
0005433615133	C38772	0183 182117	EVGENIY POPOV	{"email": "e.popov.011983@postgrespro.ru", "phone": "+70193932856"}
0005433615134	C38772	3103 367788	KIRILL AFANASEV	{"phone": "+70084931976"}
0005433615135	32F80D	7874 450252	KRISTINA KOROLEVA	{"email": "kkoroleva-01061964@postgrespro.ru", "phone": "+70597987281"}
0005433615136	38A8F2	2131 628355	SERGEY POPOV	{"email": "popov.s.111963@postgrespro.ru", "phone": "+70820261913"}
0005433615137	841D06	4945 628099	ALEKSANDRA ROMANOVA	{"phone": "+70848507874"}
0005433615138	3B4781	1789 416750	EVGENIY FEDOTOV	{"phone": "+70760051550"}
0005433615139	D48644	4702 663423	TIMUR VOLKOV	{"email": "t.volkov_14101970@postgrespro.ru", "phone": "+70587049341"}
0005433615140	D48644	0058 596036	TATYANA SOLOVEVA	{"phone": "+70599586402"}
0005433615141	8DF334	4122 235113	IRINA KOROLEVA	{"phone": "+70505246163"}
0005433615142	6319F7	1542 666430	ALEKSANDR MEDVEDEV	{"email": "medvedev-a-081983@postgrespro.ru", "phone": "+70459134050"}
0005433615143	D8C4FF	7846 717779	ANDREY ZHURAVLEV	{"phone": "+70357840463"}
0005433615144	245ED7	2531 963861	IVAN GAVRILOV	{"phone": "+70231827540"}
0005433615145	216FD1	7887 022149	LYUDMILA EFIMOVA	{"email": "l.efimova_061973@postgrespro.ru", "phone": "+70550168465"}
0005433615146	216FD1	1877 624512	IGOR SCHERBAKOV	{"email": "ischerbakov-1967@postgrespro.ru", "phone": "+70096353508"}
0005433615147	6F3EA8	6749 107070	LYUBOV SERGEEVA	{"phone": "+70319035513"}
0005433615148	F2BAB9	5151 199949	NATALYA NESTEROVA	{"phone": "+70393460594"}
0005433615149	F2BAB9	7788 589546	VALENTINA POPOVA	{"email": "v-popova_25121977@postgrespro.ru", "phone": "+70351955151"}
0005433615150	215189	4570 484602	LIDIYA ALEKSANDROVA	{"email": "aleksandrova.lidiya_24061972@postgrespro.ru", "phone": "+70107013250"}
0005433615151	215189	6763 077116	OLGA DAVYDOVA	{"email": "o_davydova22071981@postgrespro.ru", "phone": "+70291887775"}
0005433615152	D0002F	1916 391315	ANTON SOKOLOV	{"phone": "+70932697543"}
0005433615153	D0002F	8912 094534	EVGENIY ISAEV	{"phone": "+70710738834"}
0005433615154	97DDE7	1477 576252	ALFIYA OSIPOVA	{"email": "alfiya_osipova1965@postgrespro.ru", "phone": "+70876085368"}
0005433615155	97DDE7	6837 380182	ISLAM BORISOV	{"phone": "+70747053179"}
0005433615156	DA506A	5845 328743	VALENTINA MARTYNOVA	{"phone": "+70231181177"}
0005433615157	1D3878	2000 055650	ALEKSANDR MAKAROV	{"phone": "+70332491570"}
0005433615158	E4FEE6	1704 033231	KLAVDIYA KOZLOVA	{"phone": "+70778126475"}
0005433615159	E4FEE6	9253 698078	NINA SOROKINA	{"email": "nina.sorokina_021970@postgrespro.ru", "phone": "+70530438757"}
0005433615160	C3EB1C	9639 131289	SVETLANA EGOROVA	{"phone": "+70347839151"}
0005433615161	760261	0286 554060	MIKHAIL SERGEEV	{"email": "mikhail_sergeev_1970@postgrespro.ru", "phone": "+70958572652"}
0005433615162	ADC6D8	0039 045226	ALEKSANDR FROLOV	{"phone": "+70746025023"}
0005433615163	92528E	8192 254923	NATALYA YAKOVLEVA	{"phone": "+70655795124"}
0005433615164	C12064	2458 356216	IVAN SEMENOV	{"email": "ivansemenov1974@postgrespro.ru", "phone": "+70264898535"}
0005433615165	C12064	5437 886412	NATALYA GRISHINA	{"email": "ngrishina.10121970@postgrespro.ru", "phone": "+70786132174"}
0005433615166	C12064	1763 025640	ELENA ROMANOVA	{"email": "romanova.e-051972@postgrespro.ru", "phone": "+70771692443"}
0005433615167	ED6479	1272 053370	NATALYA YAKOVLEVA	{"phone": "+70505790848"}
0005433615168	A250F3	2644 825691	ANNA IVANOVA	{"email": "ivanova_anna.051971@postgrespro.ru", "phone": "+70815581727"}
0005433615169	C868C1	6738 100639	ANDREY KUZNECOV	{"email": "kuznecov_andrey_1975@postgrespro.ru", "phone": "+70749090758"}
0005433615170	060B64	9558 037973	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev_29121959@postgrespro.ru", "phone": "+70775676193"}
0005433615171	E5210E	6972 688584	KRISTINA KOZLOVA	{"email": "k.kozlova-061972@postgrespro.ru", "phone": "+70018871140"}
0005433615172	770D2D	7413 403766	REGINA BOGDANOVA	{"phone": "+70448134674"}
0005433615173	E5DCD9	9019 840578	ALEKSANDR SEMENOV	{"email": "semenov-a_15071973@postgrespro.ru", "phone": "+70050372655"}
0005433615174	0A186D	3069 489873	RENAT MAKAROV	{"phone": "+70672011599"}
0005433615175	B792FA	1382 973952	ANNA NESTEROVA	{"email": "a_nesterova031970@postgrespro.ru", "phone": "+70213869582"}
0005433615176	1ABD87	5895 559865	NINA VOROBEVA	{"phone": "+70251295039"}
0005433615177	7BB801	1858 280626	DMITRIY EGOROV	{"email": "egorov_d-28121979@postgrespro.ru", "phone": "+70148198337"}
0005433615178	00E132	8359 630800	VLADIMIR MELNIKOV	{"email": "melnikovv071980@postgrespro.ru", "phone": "+70235930825"}
0005433615179	00E132	3241 634899	VLADIMIR MOROZOV	{"phone": "+70175689342"}
0005433615180	A6D075	2072 942829	ALEKSANDR IVANOV	{"email": "a.ivanov-061968@postgrespro.ru", "phone": "+70344271570"}
0005433615181	5747FE	3925 613631	NIKOLAY PETROV	{"email": "petrov-nikolay.06041970@postgrespro.ru", "phone": "+70716028623"}
0005433615182	9B19BF	0241 923363	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_vladimir_101970@postgrespro.ru", "phone": "+70711086066"}
0005433615183	46C702	2864 651602	ELENA MIRONOVA	{"email": "elena_mironova_1967@postgrespro.ru", "phone": "+70700118441"}
0005433615184	41D125	8604 796521	ALEKSEY RODIONOV	{"phone": "+70759806046"}
0005433615185	61D542	0469 882038	ALEKSANDR ISAEV	{"phone": "+70555198445"}
0005433615186	75FFBD	0754 951666	OLGA SOLOVEVA	{"phone": "+70875410995"}
0005433615187	75FFBD	9287 050156	TAMARA KOVALEVA	{"email": "tamara-kovaleva071971@postgrespro.ru", "phone": "+70291358037"}
0005433615188	59063F	5123 144184	NADEZHDA ROMANOVA	{"phone": "+70908835068"}
0005433615189	59063F	5057 399530	OLEG GRIGOREV	{"phone": "+70266496910"}
0005433615190	6FE1BE	3556 313547	EGOR KONOVALOV	{"email": "konovalov_egor1989@postgrespro.ru", "phone": "+70875921735"}
0005433615191	6FE1BE	8042 793627	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev021968@postgrespro.ru", "phone": "+70903758645"}
0005433615192	65E6D3	4901 478240	ANZHELIKA NESTEROVA	{"email": "nesterova-a.091971@postgrespro.ru", "phone": "+70894030506"}
0005433615193	65E6D3	3727 101317	NADEZHDA FOMINA	{"email": "nadezhda-fomina.17101971@postgrespro.ru", "phone": "+70041395968"}
0005433615194	5F33CF	7709 703592	TAMARA ORLOVA	{"email": "orlova_t011975@postgrespro.ru", "phone": "+70807730788"}
0005433615195	76F94B	2751 819389	POLINA KUDRYASHOVA	{"email": "kudryashovap.25111966@postgrespro.ru", "phone": "+70441888402"}
0005433615196	76F94B	7444 288794	MARIYA IVANOVA	{"email": "mariya.ivanova-06071966@postgrespro.ru", "phone": "+70514014140"}
0005433615197	E59F8D	4368 325841	ANDREY GAVRILOV	{"phone": "+70050251279"}
0005433615198	E59F8D	3721 629690	ANDREY KUZMIN	{"phone": "+70407814122"}
0005433615199	D3644B	9890 783896	LEONID DENISOV	{"email": "denisov_leonid-28051968@postgrespro.ru", "phone": "+70887284770"}
0005433615200	D3644B	6458 313330	KLARA ISAEVA	{"phone": "+70687980344"}
0005433615201	75EEA9	7323 082978	SERGEY PAVLOV	{"phone": "+70886352548"}
0005433615202	75EEA9	8452 281522	RADIK KAZAKOV	{"email": "r.kazakov1963@postgrespro.ru", "phone": "+70577426886"}
0005433615203	75EEA9	4217 915822	VLADISLAV TIKHONOV	{"email": "v_tikhonov.25101979@postgrespro.ru", "phone": "+70011379988"}
0005433615204	6B48E7	0964 673275	MIKHAIL PAVLOV	{"email": "mpavlov041980@postgrespro.ru", "phone": "+70492821822"}
0005433615205	6B48E7	3935 167542	LILIYA OSIPOVA	{"email": "liliya-osipova-05101975@postgrespro.ru", "phone": "+70175469890"}
0005433615206	5791F8	8795 453078	NIKITA MIKHAYLOV	{"phone": "+70356961217"}
0005433615207	5791F8	4708 145146	INESSA KOMAROVA	{"phone": "+70108043033"}
0005433615208	7718F3	6184 589037	DARYA BELOVA	{"phone": "+70289860600"}
0005433615209	7718F3	9403 707795	VALERIY SOKOLOV	{"phone": "+70332560042"}
0005433615210	EEC234	0117 337932	YURIY SIDOROV	{"phone": "+70088239047"}
0005433615211	EEC234	4053 135525	SERGEY SEMENOV	{"phone": "+70750144843"}
0005433615212	C4ABC8	1207 554892	NINA RODIONOVA	{"phone": "+70493989814"}
0005433615213	EA69BF	3937 181643	IVAN SERGEEV	{"email": "i-sergeev1976@postgrespro.ru", "phone": "+70164981303"}
0005433615214	2E4114	0217 318500	MARINA FEDOROVA	{"email": "marina-fedorova-13121972@postgrespro.ru", "phone": "+70870721621"}
0005433615215	F2BC34	0979 417761	ASIYA SOKOLOVA	{"phone": "+70021929077"}
0005433615216	F2BC34	4034 586047	STANISLAV POPOV	{"email": "stanislavpopov031971@postgrespro.ru", "phone": "+70210172234"}
0005433615217	744C94	8970 412154	SERGEY MOROZOV	{"phone": "+70952382366"}
0005433615218	4B8408	0270 679729	MARIYA PAVLOVA	{"email": "mariya-pavlova121972@postgrespro.ru", "phone": "+70825290028"}
0005433615219	D596F4	7499 312721	ANATOLIY YAKOVLEV	{"phone": "+70723453282"}
0005433615220	9C6776	1190 163190	LYUBOV NIKITINA	{"email": "nikitina_lyubov_16061971@postgrespro.ru", "phone": "+70708526970"}
0005433615221	9C6776	6481 979302	ARTEM GUSEV	{"email": "a.gusev.21021973@postgrespro.ru", "phone": "+70032261043"}
0005433615222	9C6776	4936 085481	GALINA MIKHAYLOVA	{"phone": "+70963414967"}
0005433615223	B766FA	9943 730927	ELENA MASLOVA	{"email": "maslova_e_25101977@postgrespro.ru", "phone": "+70165176639"}
0005433615224	B766FA	1059 745942	MARIYA NIKOLAEVA	{"email": "mariyanikolaeva-02011968@postgrespro.ru", "phone": "+70467738084"}
0005433615225	A5D3ED	6173 909150	VLADIMIR RODIONOV	{"phone": "+70919173576"}
0005433615226	A42E37	0908 618745	LYUBOV AKIMOVA	{"phone": "+70169727725"}
0005433615227	50E87F	5395 489725	ELEONORA EGOROVA	{"phone": "+70747644769"}
0005433615228	33C25A	0175 056942	TAMARA ZOTOVA	{"phone": "+70409037626"}
0005433615229	DFA40E	2634 172438	PAVEL STEPANOV	{"phone": "+70613836537"}
0005433615230	DFA40E	7397 082325	ELIZAVETA RODIONOVA	{"phone": "+70077114696"}
0005433615231	A4D6E5	4592 368375	TATYANA SIDOROVA	{"email": "sidorovatatyana_27121968@postgrespro.ru", "phone": "+70353818953"}
0005433615232	1F29C9	6670 849285	OLGA GRISHINA	{"email": "o.grishina.1970@postgrespro.ru", "phone": "+70531677114"}
0005433615233	1F29C9	4939 292809	MARINA POTAPOVA	{"email": "potapova-marina-081969@postgrespro.ru", "phone": "+70836932454"}
0005433615234	1F29C9	1106 737250	LYUDMILA ALEKSANDROVA	{"phone": "+70392196314"}
0005433615235	B2B10D	1577 923962	ALEKSANDR ILIN	{"email": "ilin_aleksandr-071983@postgrespro.ru", "phone": "+70230443738"}
0005433615236	B2B10D	8345 081941	VALENTINA MEDVEDEVA	{"phone": "+70829553167"}
0005433615237	878833	2760 766850	EVGENIYA KARPOVA	{"email": "ekarpova-11111976@postgrespro.ru", "phone": "+70879844494"}
0005433615238	E3D019	5787 614644	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin_051971@postgrespro.ru", "phone": "+70512890008"}
0005433615239	E3D019	0582 841436	ALEKSANDR GORBUNOV	{"email": "gorbunov.a.091980@postgrespro.ru", "phone": "+70922156608"}
0005433615240	2BC8DF	8684 356871	MIKHAIL ALEKSEEV	{"phone": "+70609704719"}
0005433615241	07A598	0631 651456	ANDREY AFANASEV	{"phone": "+70836308439"}
0005433615242	A9B7DF	4812 951812	ANTON NAUMOV	{"email": "anton-naumov.031971@postgrespro.ru", "phone": "+70544404073"}
0005433615243	0A60D1	7068 693700	TATYANA TIKHONOVA	{"email": "tikhonovatatyana-1988@postgrespro.ru", "phone": "+70072734304"}
0005433615244	0A60D1	3276 467647	ANASTASIYA KONOVALOVA	{"phone": "+70468957596"}
0005433615245	F5B38A	1615 336951	ALEKSEY ISAEV	{"phone": "+70921143983"}
0005433615246	FD8550	9640 591803	PAVEL IVANOV	{"phone": "+70417579757"}
0005433615247	FD8550	7501 825715	LIDIYA ILINA	{"email": "ilina.l051987@postgrespro.ru", "phone": "+70787369608"}
0005433615248	02A8D3	0666 630809	ALEKSANDR BORISOV	{"email": "a-borisov_15111977@postgrespro.ru", "phone": "+70878914339"}
0005433615249	D2E425	1140 628841	OLGA KONOVALOVA	{"phone": "+70876162649"}
0005433615250	D2E425	4585 185595	ALEKSANDRA ROMANOVA	{"email": "romanova-aleksandra-11071965@postgrespro.ru", "phone": "+70591386084"}
0005433615251	1BCAA1	8477 457893	LYUDMILA IVANOVA	{"email": "l-ivanova.29031967@postgrespro.ru", "phone": "+70849415827"}
0005433615252	1BCAA1	8338 174849	ROMAN VOLKOV	{"email": "volkov_r-061969@postgrespro.ru", "phone": "+70112404339"}
0005433615253	1BCAA1	6918 518193	NATALYA PETROVA	{"phone": "+70946805574"}
0005433615254	CBA4C7	1037 342829	MARINA SOLOVEVA	{"email": "m-soloveva-091967@postgrespro.ru", "phone": "+70343475732"}
0005433615255	CBA4C7	8825 083763	IGOR KUZNECOV	{"phone": "+70402308497"}
0005433615256	D5E3C0	1144 736626	ROMAN MOISEEV	{"phone": "+70576795127"}
0005433615257	5A732C	5250 546477	LYUDMILA STEPANOVA	{"phone": "+70241119931"}
0005433615258	5A732C	7083 404847	NIKOLAY MOISEEV	{"phone": "+70227572756"}
0005433615259	5A732C	4570 733352	VSEVOLOD ORLOV	{"phone": "+70271077557"}
0005433615260	2A5846	9261 498155	VADIM KUZNECOV	{"phone": "+70327068944"}
0005433615261	0AE531	4836 488288	ALEKSEY VOLKOV	{"email": "alekseyvolkov_021965@postgrespro.ru", "phone": "+70779157236"}
0005433615262	0AE531	6214 222845	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev-10051965@postgrespro.ru", "phone": "+70449774510"}
0005433615263	0AE531	4163 267942	POLINA KALININA	{"email": "kalinina.p-18111974@postgrespro.ru", "phone": "+70943304518"}
0005433615264	2CFB60	5541 219086	LYUDMILA ABRAMOVA	{"phone": "+70111627185"}
0005433615265	504D90	6000 555095	NATALIYA ILINA	{"phone": "+70522768321"}
0005433615266	CB47AE	4432 908118	TATYANA ANDREEVA	{"phone": "+70071349016"}
0005433615267	7599F0	9326 898425	VALENTINA ANDREEVA	{"phone": "+70348628603"}
0005433615268	7599F0	4377 167781	OLGA GRISHINA	{"email": "olga_grishina.091977@postgrespro.ru", "phone": "+70563487679"}
0005433615269	3F5EC7	2273 910026	DMITRIY IVANOV	{"email": "ivanov_dmitriy_101968@postgrespro.ru", "phone": "+70892380420"}
0005433615270	6D7B6B	3328 122209	NIKOLAY KULIKOV	{"email": "kulikovnikolay.14121961@postgrespro.ru", "phone": "+70480565850"}
0005433615271	7A6149	5769 111579	GRIGORIY STEPANOV	{"email": "g-stepanov-061970@postgrespro.ru", "phone": "+70959337610"}
0005433615272	958EFA	9269 233444	NIKOLAY PAVLOV	{"phone": "+70009932498"}
0005433615273	958EFA	2593 135962	DMITRIY MATVEEV	{"email": "matveevdmitriy_091967@postgrespro.ru", "phone": "+70483235414"}
0005433615274	106E5E	8400 645893	DARYA YAKOVLEVA	{"email": "dyakovleva_1963@postgrespro.ru", "phone": "+70705929707"}
0005433615275	106E5E	3387 403736	VIKTOR MARTYNOV	{"email": "martynov_viktor_10071965@postgrespro.ru", "phone": "+70149914932"}
0005433615276	106E5E	5208 995519	VALENTIN KUZNECOV	{"email": "kuznecov.valentin1970@postgrespro.ru", "phone": "+70158140005"}
0005433615277	90D3AF	1782 962216	ALEKSANDR FOMIN	{"email": "fominaleksandr.1971@postgrespro.ru", "phone": "+70620960348"}
0005433615278	3C9206	1845 340127	ALEKSEY ALEKSEEV	{"phone": "+70234994756"}
0005433615279	3C9206	3731 569571	GULIYA ISAEVA	{"email": "isaeva.g1973@postgrespro.ru", "phone": "+70396283697"}
0005433615280	386DD3	6661 604751	RAMIL BONDARENKO	{"email": "rbondarenko_1980@postgrespro.ru", "phone": "+70832531800"}
0005433615281	386DD3	1635 015295	VLADIMIR MIKHAYLOV	{"phone": "+70421548472"}
0005433615282	649737	2420 715562	VLADIMIR ABRAMOV	{"phone": "+70503655712"}
0005433615283	649737	6982 669932	SVETLANA PETROVA	{"email": "svetlanapetrova_23011972@postgrespro.ru", "phone": "+70889208518"}
0005433615284	1F20AF	2995 410417	VLADIMIR GORBUNOV	{"email": "gorbunov_v.08071963@postgrespro.ru", "phone": "+70577079573"}
0005433615285	16B8B3	1641 341711	IVAN VOROBEV	{"phone": "+70643107585"}
0005433615286	EEDA77	8522 219398	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.nikolay-061966@postgrespro.ru", "phone": "+70935078213"}
0005433615287	A131DB	3247 655831	LEV POPOV	{"email": "l-popov.03081964@postgrespro.ru", "phone": "+70417780329"}
0005433615288	A131DB	5875 783457	SERGEY ALEKSANDROV	{"phone": "+70937610607"}
0005433615289	FFC1BE	5979 138285	MARIYA MELNIKOVA	{"email": "melnikova.m-091977@postgrespro.ru", "phone": "+70234687982"}
0005433615290	FFC1BE	6194 216208	SERGEY EGOROV	{"email": "egorov-sergey121981@postgrespro.ru", "phone": "+70137126735"}
0005433615291	E1E878	9105 786337	KONSTANTIN DENISOV	{"phone": "+70183797341"}
0005433615292	E1E878	5206 794471	OLEG IVANOV	{"email": "oleg_ivanov-01081974@postgrespro.ru", "phone": "+70076861584"}
0005433615293	E1E878	6206 882817	RAMIL VOROBEV	{"phone": "+70972365203"}
0005433615294	9F838C	9938 232227	POLINA BARANOVA	{"phone": "+70686657883"}
0005433615295	3680B1	4443 809545	VIKTORIYA KONDRATEVA	{"phone": "+70718831808"}
0005433615296	3680B1	8097 943357	VALENTINA STEPANOVA	{"email": "v_stepanova.1965@postgrespro.ru", "phone": "+70267518611"}
0005433615297	16E0FF	4549 723202	EGOR NIKOLAEV	{"phone": "+70841424978"}
0005433615298	982291	7913 560161	LIDIYA NAZAROVA	{"email": "l_nazarova25041977@postgrespro.ru", "phone": "+70809859689"}
0005433615299	AAD60F	5442 677446	TATYANA MARTYNOVA	{"email": "t.martynova1966@postgrespro.ru", "phone": "+70050242322"}
0005433615300	AAD60F	3070 691434	TATYANA AFANASEVA	{"phone": "+70907607014"}
0005433615301	204AFD	4265 724906	SERGEY ZHUKOV	{"email": "sergey-zhukov03041982@postgrespro.ru", "phone": "+70396819156"}
0005433615302	80CA12	1935 588462	RUSLAN FOMIN	{"email": "fomin.r.07081976@postgrespro.ru", "phone": "+70219860251"}
0005433615303	A0A6C2	4344 140463	SERGEY NIKOLAEV	{"email": "sergey_nikolaev-07091977@postgrespro.ru", "phone": "+70712356047"}
0005433615304	628D08	9584 639865	EVGENIY MIRONOV	{"phone": "+70707399428"}
0005433615305	C8B37B	1970 753485	GALINA KOROLEVA	{"phone": "+70002332404"}
0005433615306	C8B37B	0567 756018	YULIYA MEDVEDEVA	{"phone": "+70841290928"}
0005433615307	C8B37B	4014 805418	YULIYA STEPANOVA	{"phone": "+70840761394"}
0005433615308	5435C0	1128 611054	VALENTINA MAKAROVA	{"phone": "+70417334334"}
0005433615309	5435C0	5660 012546	KONSTANTIN DENISOV	{"email": "konstantin.denisov_18121973@postgrespro.ru", "phone": "+70959902086"}
0005433615310	5435C0	2655 893674	ELENA KOMAROVA	{"phone": "+70835802437"}
0005433615311	A94643	9624 207871	DARYA POPOVA	{"phone": "+70533181440"}
0005433615312	A94643	8480 063603	TATYANA NESTEROVA	{"email": "nesterova_tatyana-081970@postgrespro.ru", "phone": "+70208492259"}
0005433615313	46E641	0572 449657	SVETLANA SMIRNOVA	{"email": "s-smirnova-1973@postgrespro.ru", "phone": "+70408415312"}
0005433615314	46E641	6055 362301	ANNA DENISOVA	{"email": "denisova.a.1967@postgrespro.ru", "phone": "+70153783762"}
0005433615315	46E641	6465 848114	ALEKSANDR SAVELEV	{"phone": "+70749527742"}
0005433615316	50342E	4891 507909	SERGEY MEDVEDEV	{"email": "medvedevsergey1973@postgrespro.ru", "phone": "+70201740567"}
0005433615317	50342E	6873 521538	ARSEN EGOROV	{"phone": "+70329200990"}
0005433615318	EE71B3	6172 932081	ANDREY EGOROV	{"email": "egorov-andrey1975@postgrespro.ru", "phone": "+70784359410"}
0005433615319	EE71B3	5800 449051	OLGA KUZNECOVA	{"email": "kuznecova-olga.071981@postgrespro.ru", "phone": "+70916339193"}
0005433615320	605978	7043 877955	VALENTINA ZHUKOVA	{"email": "valentina.zhukova-25101968@postgrespro.ru", "phone": "+70265350454"}
0005433615321	605978	7679 257860	IVAN VLASOV	{"email": "i_vlasov091980@postgrespro.ru", "phone": "+70673477253"}
0005433615322	6F4433	5054 361267	MARINA IVANOVA	{"email": "m.ivanova-1971@postgrespro.ru", "phone": "+70655897061"}
0005433615323	AE5F86	9793 404600	ILDAR FROLOV	{"phone": "+70637231903"}
0005433615324	B17E0F	5412 990040	VYACHESLAV KISELEV	{"email": "kiselev-v-09051969@postgrespro.ru", "phone": "+70016885422"}
0005433615325	E26D34	0828 162235	GALINA NIKIFOROVA	{"phone": "+70531157109"}
0005433615326	E26D34	2642 778331	NATALYA POPOVA	{"email": "natalyapopova_061984@postgrespro.ru", "phone": "+70973979155"}
0005433615327	F2B112	4828 080394	NADEZHDA SMIRNOVA	{"phone": "+70758517641"}
0005433615328	F2B112	9148 489888	DMITRIY KOZLOV	{"phone": "+70334091125"}
0005433615329	F2B112	0427 678367	STANISLAV VOROBEV	{"phone": "+70295733289"}
0005433615330	376393	7007 969914	RUSLAN VASILEV	{"email": "ruslan.vasilev_1968@postgrespro.ru", "phone": "+70488658199"}
0005433615331	6F5EDF	1746 280215	ALEKSEY ALEKSANDROV	{"phone": "+70032926547"}
0005433615332	6F5EDF	2681 522212	MARINA TIMOFEEVA	{"phone": "+70670788386"}
0005433615333	D5D96A	1346 119243	GRIGORIY TARASOV	{"email": "grigoriytarasov_1975@postgrespro.ru", "phone": "+70026374380"}
0005433615334	F2BCFE	5526 575226	RAISA LEBEDEVA	{"email": "lebedevaraisa071965@postgrespro.ru", "phone": "+70424604096"}
0005433615335	41AB19	8785 662963	ALEKSANDRA ANDREEVA	{"email": "a.andreeva.111987@postgrespro.ru", "phone": "+70694019836"}
0005433615336	5F3432	0909 399224	IGOR FROLOV	{"phone": "+70847363855"}
0005433615337	CC63AF	9615 190033	ELENA KARPOVA	{"email": "elena.karpova-041978@postgrespro.ru", "phone": "+70137592912"}
0005433615338	66F335	9744 983431	ANDREY BORISOV	{"phone": "+70352243212"}
0005433615339	CA6A76	1794 729055	MILENA GERASIMOVA	{"email": "m-gerasimova-081970@postgrespro.ru", "phone": "+70501774397"}
0005433615340	ECC73E	8810 030152	ELENA MAKSIMOVA	{"phone": "+70113572500"}
0005433615341	9C4F5D	4408 713932	ANNA KISELEVA	{"phone": "+70242257143"}
0005433615342	9C4F5D	6344 235327	ELENA KUZNECOVA	{"phone": "+70738579606"}
0005433615343	6919F1	1970 859267	NIKOLAY ISAEV	{"phone": "+70915365323"}
0005433615344	08930A	9900 065764	ALEKSANDR GUSEV	{"email": "gusev.aleksandr1969@postgrespro.ru", "phone": "+70813875277"}
0005433615345	5B72B0	8854 635746	VALENTINA EGOROVA	{"email": "egorova-valentina.1972@postgrespro.ru", "phone": "+70089450502"}
0005433615346	4117F9	1638 704059	NATALYA VOLKOVA	{"email": "natalya.volkova-1978@postgrespro.ru", "phone": "+70716236102"}
0005433615347	ACE2F9	9152 554948	SERGEY IVANOV	{"email": "ivanovs_1989@postgrespro.ru", "phone": "+70669520131"}
0005433615348	2647E2	2964 626843	ALEKSANDR SMIRNOV	{"email": "smirnov-aleksandr-071971@postgrespro.ru", "phone": "+70466915569"}
0005433615349	2647E2	0344 117522	YULIYA GORBUNOVA	{"email": "y_gorbunova.081972@postgrespro.ru", "phone": "+70988993441"}
0005433615350	4E0C22	5857 026445	YULIYA STEPANOVA	{"phone": "+70723742095"}
0005433615351	01ADDC	4632 954166	MARINA SOROKINA	{"email": "sorokina.m_1971@postgrespro.ru", "phone": "+70558082431"}
0005433615352	6557AE	4347 673423	MATVEY DMITRIEV	{"phone": "+70341542580"}
0005433615353	80D1E1	8102 572436	ALEKSEY YAKOVLEV	{"phone": "+70455299478"}
0005433615354	2CFA9E	0226 961080	SERGEY BARANOV	{"email": "s_baranov041973@postgrespro.ru", "phone": "+70867548904"}
0005433615355	F5F9BE	2060 280493	IGOR PAVLOV	{"email": "pavlov-igor_121965@postgrespro.ru", "phone": "+70364267948"}
0005433615356	0EE910	4590 549252	EVGENIYA BORISOVA	{"email": "evgeniya_borisova_031981@postgrespro.ru", "phone": "+70520627999"}
0005433615357	379F3A	7602 389887	VALERIY CHERNOV	{"phone": "+70275711611"}
0005433615358	89EE5C	7426 180893	SERGEY NOVIKOV	{"email": "snovikov1975@postgrespro.ru", "phone": "+70472503720"}
0005433615359	A347C2	8688 784572	YULIYA SMIRNOVA	{"phone": "+70939249223"}
0005433615360	B6025E	4841 697362	VALENTIN NAZAROV	{"phone": "+70066072949"}
0005433615361	B6025E	9949 769688	VLADIMIR KAZAKOV	{"email": "vladimir.kazakov_23091968@postgrespro.ru", "phone": "+70445821027"}
0005433615362	699713	9669 169585	EKATERINA PETROVA	{"phone": "+70308393394"}
0005433615363	699713	1012 638334	ALEKSANDR KUZNECOV	{"phone": "+70979343179"}
0005433615364	D75C22	5744 573616	NINA PAVLOVA	{"phone": "+70702246808"}
0005433615365	5CAF4F	5254 408527	ALEKSEY KUZMIN	{"email": "aleksey_kuzmin-061963@postgrespro.ru", "phone": "+70449945675"}
0005433615366	7180B2	7212 663385	IVAN FROLOV	{"phone": "+70378785354"}
0005433615367	7180B2	1369 499487	KONSTANTIN KUZNECOV	{"email": "kuznecov-konstantin_101971@postgrespro.ru", "phone": "+70968151096"}
0005433615368	011315	8527 558794	ROZA PAVLOVA	{"email": "pavlova_roza.18051981@postgrespro.ru", "phone": "+70893750942"}
0005433615369	EDF358	7485 038883	ANDREY KUZNECOV	{"phone": "+70905253996"}
0005433615370	EDF358	3893 834791	MILANA MIRONOVA	{"email": "milana-mironova-1975@postgrespro.ru", "phone": "+70458846943"}
0005433615371	F1461F	9111 370991	ELENA KOLESNIKOVA	{"phone": "+70333992149"}
0005433615372	5475EF	4766 195633	ELENA MAKSIMOVA	{"email": "elena_maksimova.021980@postgrespro.ru", "phone": "+70703123557"}
0005433615373	184151	0005 310361	LYUDMILA VOLKOVA	{"email": "lyudmila.volkova_1975@postgrespro.ru", "phone": "+70888611257"}
0005433615374	184151	4542 166723	TATYANA LUKYANOVA	{"email": "t_lukyanova051975@postgrespro.ru", "phone": "+70696540389"}
0005433615375	A401DE	4805 727179	VALERIY FEDOROV	{"email": "fedorovvaleriy.1974@postgrespro.ru", "phone": "+70722583203"}
0005433615376	1B646E	5103 795893	NINA PAVLOVA	{"phone": "+70341611602"}
0005433615377	5B3933	9274 437987	VLADIMIR VASILEV	{"phone": "+70487624182"}
0005433615378	14FDD6	7821 178722	SANIYA MAKAROVA	{"phone": "+70962430208"}
0005433615379	9D2E80	0355 867269	ALEKSANDR MAKAROV	{"phone": "+70352882575"}
0005433615380	9D2E80	7843 889001	ANTONINA KONDRATEVA	{"phone": "+70967021586"}
0005433615436	CFA883	2479 498456	RUSLAN VASILEV	{"phone": "+70419359211"}
0005433615381	9D76DE	4700 299121	RAISA VLASOVA	{"email": "vlasova.r30041974@postgrespro.ru", "phone": "+70709786403"}
0005433615382	ACCD0F	3662 273178	NAILYA NAUMOVA	{"phone": "+70251506636"}
0005433615383	FF3F0D	0676 906062	ALEKSEY MIKHAYLOV	{"email": "amikhaylov.1970@postgrespro.ru", "phone": "+70606884540"}
0005433615384	FF3F0D	9854 410968	LEONID FEDOROV	{"email": "fedorov-leonid091970@postgrespro.ru", "phone": "+70132410101"}
0005433615385	120BC8	1739 422444	ALEKSEY CHERNOV	{"phone": "+70352990646"}
0005433615386	47AC1B	5248 660047	NIKOLAY SCHERBAKOV	{"email": "nikolay.scherbakov-1973@postgrespro.ru", "phone": "+70777195777"}
0005433615387	1A889B	2215 885360	VLADIMIR NAZAROV	{"phone": "+70125502363"}
0005433615388	1A889B	0261 657514	SERGEY BORISOV	{"email": "borisov.sergey.28051970@postgrespro.ru", "phone": "+70744688766"}
0005433615389	DB8A07	7885 678309	VIKTOR POPOV	{"phone": "+70437281202"}
0005433615390	8FFD0A	6238 927623	SVETLANA IVANOVA	{"phone": "+70787173691"}
0005433615391	8FFD0A	1325 311612	POLINA NIKIFOROVA	{"email": "nikiforova_polina-021963@postgrespro.ru", "phone": "+70180244740"}
0005433615392	33C21D	8564 036665	EVGENIY KARPOV	{"email": "e.karpov-1969@postgrespro.ru", "phone": "+70314976047"}
0005433615393	77FA9A	5315 489123	LYUBOV DANILOVA	{"phone": "+70404894845"}
0005433615394	77FA9A	1557 435204	LYUBOV KULIKOVA	{"email": "kulikovalyubov19031967@postgrespro.ru", "phone": "+70806737451"}
0005433615395	1719AB	4768 235594	MURAD DENISOV	{"email": "denisov.murad_1978@postgrespro.ru", "phone": "+70853224450"}
0005433615396	FBC4F2	9931 765899	NATALYA GAVRILOVA	{"email": "n-gavrilova.1974@postgrespro.ru", "phone": "+70615808670"}
0005433615397	D068C3	8959 787432	PAVEL ANDREEV	{"email": "andreev.pavel1967@postgrespro.ru", "phone": "+70559168467"}
0005433615398	D068C3	6030 156203	GALINA EGOROVA	{"email": "galina_egorova.031975@postgrespro.ru", "phone": "+70256240685"}
0005433615399	EA5889	5862 277100	ALEKSANDR SMIRNOV	{"email": "smirnova.26011963@postgrespro.ru", "phone": "+70384515772"}
0005433615400	EA5889	0072 226628	DANIIL TARASOV	{"phone": "+70623601965"}
0005433615401	EA5889	1340 657966	LYUBOV MOROZOVA	{"phone": "+70003825654"}
0005433615402	2544DA	0551 949289	ANATOLIY KULIKOV	{"phone": "+70960214482"}
0005433615403	8F9730	3759 110951	IRINA IVANOVA	{"email": "irinaivanova_09111979@postgrespro.ru", "phone": "+70750623711"}
0005433615404	128E23	4483 410097	ALINA GUSEVA	{"phone": "+70461527788"}
0005433615405	05139B	9709 815627	VYACHESLAV SOROKIN	{"email": "sorokin_vyacheslav-011971@postgrespro.ru", "phone": "+70767431001"}
0005433615406	CE50FF	8199 442365	ANTONINA MOROZOVA	{"email": "a-morozova-1971@postgrespro.ru", "phone": "+70949605544"}
0005433615407	743AA6	1814 200199	SHAMIL DENISOV	{"phone": "+70227919680"}
0005433615408	A88F01	1800 045493	ARINA OSIPOVA	{"email": "osipova-a_081972@postgrespro.ru", "phone": "+70863524802"}
0005433615409	190884	7572 371839	OLGA NOVIKOVA	{"email": "novikovaolga_23011968@postgrespro.ru", "phone": "+70651741890"}
0005433615410	C4DC2A	3968 605862	VLADIMIR MOISEEV	{"email": "vladimir.moiseev.1973@postgrespro.ru", "phone": "+70426494630"}
0005433615411	9A7DB1	4842 367900	SERGEY ZHUKOV	{"email": "sergeyzhukov_04091968@postgrespro.ru", "phone": "+70166033720"}
0005433615412	044616	5580 398120	YULIYA SOROKINA	{"phone": "+70860890077"}
0005433615413	25A56C	3411 348118	MAKSIM MATVEEV	{"email": "matveevmaksim1968@postgrespro.ru", "phone": "+70744726175"}
0005433615414	F12E73	8125 296791	ELIZAVETA SCHERBAKOVA	{"email": "escherbakova_01111966@postgrespro.ru", "phone": "+70892598768"}
0005433615415	F12E73	3801 900525	NATALYA SAVELEVA	{"email": "savelevanatalya-111970@postgrespro.ru", "phone": "+70426965193"}
0005433615416	B519B3	5600 555740	ALEKSEY FEDOROV	{"email": "a-fedorov.1972@postgrespro.ru", "phone": "+70506548728"}
0005433615417	B968DC	8146 357465	ILYA BONDARENKO	{"email": "ibondarenko1973@postgrespro.ru", "phone": "+70976239418"}
0005433615418	1E02F6	5035 614270	LYUDMILA ZAKHAROVA	{"email": "lyudmila.zakharova_031972@postgrespro.ru", "phone": "+70050444963"}
0005433615419	A45558	0636 378346	LYUBOV MAKSIMOVA	{"email": "maksimova-l.1982@postgrespro.ru", "phone": "+70563418291"}
0005433615420	235EFC	1732 938647	YURIY ZHURAVLEV	{"email": "zhuravlev.yuriy_011968@postgrespro.ru", "phone": "+70435401410"}
0005433615421	252A20	5983 865744	ZINAIDA SCHERBAKOVA	{"phone": "+70807294621"}
0005433615422	A3CD46	7188 775583	VIKTOR VLASOV	{"phone": "+70185673062"}
0005433615423	82D7B7	9512 229876	VALENTINA KOZLOVA	{"phone": "+70113726355"}
0005433615424	081E61	9955 713951	TATYANA BORISOVA	{"email": "tatyana_borisova1979@postgrespro.ru", "phone": "+70260957261"}
0005433615425	146FAA	4686 227281	GALIYA FROLOVA	{"phone": "+70431840649"}
0005433615426	0A652A	1213 512600	ALEKSANDR FEDOTOV	{"email": "a-fedotov.1968@postgrespro.ru", "phone": "+70111924918"}
0005433615427	3635D8	5235 308784	EVGENIYA GUSEVA	{"email": "e_guseva.27091976@postgrespro.ru", "phone": "+70890079764"}
0005433615428	D66650	6797 861363	ELIZAVETA KOLESNIKOVA	{"phone": "+70682905741"}
0005433615429	82D435	4568 642860	ALEKSANDR GUSEV	{"phone": "+70242713623"}
0005433615430	6DC032	1239 187567	EKATERINA TIKHONOVA	{"phone": "+70217343346"}
0005433615431	70AC24	7948 153156	ZINAIDA TARASOVA	{"email": "z_tarasova.24081973@postgrespro.ru", "phone": "+70478478321"}
0005433615432	54FCD4	8857 461044	ANDREY VOLKOV	{"email": "andreyvolkov_1974@postgrespro.ru", "phone": "+70980413508"}
0005433615433	54FCD4	1137 501345	OLGA ZHUKOVA	{"phone": "+70703200332"}
0005433615434	1DD442	3122 439659	IRINA ZHURAVLEVA	{"phone": "+70627892466"}
0005433615435	8FD38E	5645 239254	ELENA MAKAROVA	{"email": "e_makarova15101984@postgrespro.ru", "phone": "+70952138265"}
0005433615437	CFA883	9855 167632	NATALYA MELNIKOVA	{"phone": "+70768274175"}
0005433615438	738C68	1426 326304	MIKHAIL MIRONOV	{"phone": "+70598665965"}
0005433615439	88B852	3745 930701	ALEKSEY DENISOV	{"phone": "+70681351390"}
0005433615440	88B852	0377 302801	VALERIY KISELEV	{"phone": "+70311353614"}
0005433615441	88B852	4747 932185	VALENTINA ALEKSEEVA	{"email": "valekseeva-031980@postgrespro.ru", "phone": "+70783337364"}
0005433615442	FA2F40	2583 289049	SERGEY KUZNECOV	{"email": "s.kuznecov_31121965@postgrespro.ru", "phone": "+70150544321"}
0005433615443	1D2390	7924 441652	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr1981@postgrespro.ru", "phone": "+70746091652"}
0005433615444	1D2390	4359 795233	DMITRIY TARASOV	{"phone": "+70537504019"}
0005433615445	83735A	4332 458404	ANATOLIY ORLOV	{"phone": "+70650180443"}
0005433615446	CF7DE3	7592 909150	VLADISLAV STEPANOV	{"email": "vladislav.stepanov1972@postgrespro.ru", "phone": "+70491902085"}
0005433615447	F20742	6763 062959	ILYA FEDOTOV	{"phone": "+70042842124"}
0005433615448	23523F	7776 662449	OLEG NIKITIN	{"phone": "+70019739984"}
0005433615449	23523F	3965 928705	TATYANA KUZMINA	{"email": "tatyanakuzmina-1976@postgrespro.ru", "phone": "+70885806623"}
0005433615450	C7E591	2909 928805	MILANA ALEKSANDROVA	{"email": "aleksandrova_m101971@postgrespro.ru", "phone": "+70961676405"}
0005433615451	344707	1993 138765	MARINA NOVIKOVA	{"email": "mnovikova.10061973@postgrespro.ru", "phone": "+70742169827"}
0005433615452	55BD35	0035 524056	DENIS ALEKSANDROV	{"email": "aleksandrovd1971@postgrespro.ru", "phone": "+70025520741"}
0005433615453	55BD35	4501 639982	YULIYA MATVEEVA	{"email": "matveeva-y.1973@postgrespro.ru", "phone": "+70495854615"}
0005433615454	55BD35	7155 614029	SERGEY KOROLEV	{"email": "sergey.korolev-091969@postgrespro.ru", "phone": "+70618868458"}
0005433615455	E4CF53	0284 433272	DMITRIY NAZAROV	{"email": "nazarov-d_1977@postgrespro.ru", "phone": "+70981289965"}
0005433615456	17E099	6950 216159	TAMARA SEMENOVA	{"phone": "+70508885805"}
0005433615457	17E099	7275 834148	ANNA STEPANOVA	{"email": "stepanova-anna-121971@postgrespro.ru", "phone": "+70168734508"}
0005433615458	1FF1B2	8277 555562	ALEKSEY PETROV	{"phone": "+70214687704"}
0005433615459	1FF1B2	6535 197875	OLEG ABRAMOV	{"phone": "+70134369151"}
0005433615460	1FF1B2	0117 971728	RUSTAM SAVELEV	{"phone": "+70332222828"}
0005433615461	F87A74	5731 080562	PELAGEYA ZOTOVA	{"email": "p.zotova.30031978@postgrespro.ru", "phone": "+70252640160"}
0005433615462	F87A74	6515 263815	NATALYA VLASOVA	{"email": "n_vlasova081969@postgrespro.ru", "phone": "+70431259248"}
0005433615463	5EEE13	4296 625449	ILYA ISAEV	{"email": "ilyaisaev-1972@postgrespro.ru", "phone": "+70054432389"}
0005433615464	91D1CA	2008 937085	VLADIMIR ALEKSANDROV	{"email": "aleksandrov_v_1968@postgrespro.ru", "phone": "+70282096119"}
0005433615465	FB6175	2333 356079	ANDREY EGOROV	{"email": "a_egorov.1966@postgrespro.ru", "phone": "+70926422575"}
0005433615466	FB6175	2671 279322	MARGARITA MASLOVA	{"email": "m-maslova1966@postgrespro.ru", "phone": "+70073936387"}
0005433615467	29A8C3	6865 059627	ANNA LOGINOVA	{"phone": "+70824418304"}
0005433615468	29A8C3	3894 157190	KIRILL GUSEV	{"phone": "+70091371412"}
0005433615469	0D01B2	9773 589179	OLESYA KOLESNIKOVA	{"email": "olesya-kolesnikova121973@postgrespro.ru", "phone": "+70152275921"}
0005433615470	5D8D1B	2841 142275	VLADIMIR BONDARENKO	{"phone": "+70321406040"}
0005433615471	8148E7	8234 121888	TATYANA KULIKOVA	{"email": "kulikova-tatyana-05061970@postgrespro.ru", "phone": "+70627378317"}
0005433615472	D13F55	2358 152599	ALEKSANDR SOROKIN	{"email": "a.sorokin.30041980@postgrespro.ru", "phone": "+70034517663"}
0005433615473	8D0708	8108 546297	ANDREY KUZMIN	{"email": "a_kuzmin_041970@postgrespro.ru", "phone": "+70693864799"}
0005433615474	E64811	8309 980382	GALINA KONOVALOVA	{"phone": "+70746472103"}
0005433615475	E64811	0695 195450	ANNA EFREMOVA	{"email": "efremova-a.061966@postgrespro.ru", "phone": "+70236965610"}
0005433615476	59A5EF	0428 994816	LYUBOV SOKOLOVA	{"email": "sokolova_lyubov.121982@postgrespro.ru", "phone": "+70740994999"}
0005433615477	B56D2E	0928 153713	YULIYA GUSEVA	{"email": "y-guseva.30091978@postgrespro.ru", "phone": "+70086329672"}
0005433615478	8E8EE5	4804 783724	ANTONINA VOROBEVA	{"email": "antonina_vorobeva-051965@postgrespro.ru", "phone": "+70749657920"}
0005433615479	95A0A4	7340 562993	SVETLANA ZAYCEVA	{"phone": "+70738115523"}
0005433615480	367A50	6535 562880	KLAVDIYA KRASNOVA	{"email": "k-krasnova_1974@postgrespro.ru", "phone": "+70182644358"}
0005433615481	05EE28	3273 306185	ILYA MIKHAYLOV	{"email": "mikhaylov_ilya-1971@postgrespro.ru", "phone": "+70497758951"}
0005433615482	D32E25	8813 420818	EVGENIY KONOVALOV	{"email": "e-konovalov011958@postgrespro.ru", "phone": "+70375538115"}
0005433615483	2B6937	4119 850854	ANDREY FROLOV	{"email": "andreyfrolov-21051970@postgrespro.ru", "phone": "+70520617306"}
0005433615484	11AA95	4644 665019	PAVEL POPOV	{"phone": "+70786628726"}
0005433615485	11AA95	5031 943776	VLADISLAV KUZNECOV	{"email": "kuznecov-v.121984@postgrespro.ru", "phone": "+70301092027"}
0005433615486	ABA07F	5270 628362	KRISTINA SOLOVEVA	{"phone": "+70716596426"}
0005433615487	772190	0449 101883	TAMARA PETROVA	{"phone": "+70230127489"}
0005433615488	772190	9818 986682	ELENA YUDINA	{"phone": "+70704166941"}
0005433615489	9879DE	6883 882395	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a12071976@postgrespro.ru", "phone": "+70435214906"}
0005433615490	9879DE	1914 090263	EVGENIYA BORISOVA	{"email": "borisovaevgeniya-21101968@postgrespro.ru", "phone": "+70734896026"}
0005433615491	BD28BD	4911 876769	ALEKSANDRA IVANOVA	{"email": "aleksandra-ivanova031974@postgrespro.ru", "phone": "+70186993747"}
0005433615492	B8B2F5	8640 964281	LILIYA KONOVALOVA	{"phone": "+70778620415"}
0005433615493	26B0FA	8675 372140	ANNA ALEKSEEVA	{"email": "alekseeva.anna-07041979@postgrespro.ru", "phone": "+70406660860"}
0005433615494	085BF7	6443 813222	VALENTINA YAKOVLEVA	{"email": "valentinayakovleva_081990@postgrespro.ru", "phone": "+70437939473"}
0005433615495	085BF7	4141 565192	ZINAIDA SMIRNOVA	{"phone": "+70695656392"}
0005433615496	B7A8B8	0020 120317	ALEKSANDR GUSEV	{"email": "gusev-aleksandr-30111964@postgrespro.ru", "phone": "+70863890692"}
0005433615497	64BEB7	3409 104089	NELYA KOVALEVA	{"email": "nelyakovaleva-031981@postgrespro.ru", "phone": "+70017451006"}
0005433615498	630EFF	1999 278269	VLADIMIR ALEKSANDROV	{"phone": "+70167819502"}
0005433615499	630EFF	6771 271235	ALINA STEPANOVA	{"email": "stepanova_alina.1963@postgrespro.ru", "phone": "+70141809436"}
0005433615500	827E00	4288 747873	NINA LEBEDEVA	{"email": "n.lebedeva121982@postgrespro.ru", "phone": "+70979663976"}
0005433615501	B0156B	7797 721734	VERA SOKOLOVA	{"phone": "+70044407822"}
0005433615502	6A211E	8408 495007	RUMIYA KONOVALOVA	{"email": "r-konovalova29011968@postgrespro.ru", "phone": "+70272297427"}
0005433615503	9E5ED0	2133 206840	ALISA PETROVA	{"email": "petrovaalisa-1969@postgrespro.ru", "phone": "+70604259605"}
0005433615504	1219E5	9454 448382	NATALYA KUZMINA	{"phone": "+70600897193"}
0005433615505	8DABA8	8909 081432	DANIIL PAVLOV	{"phone": "+70949675704"}
0005433615506	80BF48	0376 843816	ALEKSANDR SMIRNOV	{"phone": "+70881056502"}
0005433615507	50E764	1337 927150	NADEZHDA ROMANOVA	{"email": "nadezhda-romanova_041977@postgrespro.ru", "phone": "+70343889643"}
0005433615508	6BDD51	9110 043748	GALINA MAKAROVA	{"email": "gmakarova_1973@postgrespro.ru", "phone": "+70140727699"}
0005433615509	9FA1DD	1806 667295	VLADIMIR EGOROV	{"phone": "+70531288520"}
0005433615510	9FA1DD	3447 326107	LYUBOV SCHERBAKOVA	{"email": "scherbakova_lyubov_26081975@postgrespro.ru", "phone": "+70869793599"}
0005433615511	9FA1DD	7002 062654	VALENTINA KOROLEVA	{"email": "v-koroleva-1966@postgrespro.ru", "phone": "+70212937305"}
0005433615512	CD4C65	7392 920108	VALENTINA ANDREEVA	{"phone": "+70576248957"}
0005433615513	29E660	0398 385717	MAYYA MATVEEVA	{"email": "matveeva_mayya07011966@postgrespro.ru", "phone": "+70946987021"}
0005433615514	3CA915	6503 842738	GULNARA SCHERBAKOVA	{"phone": "+70523066233"}
0005433615515	3CA915	4967 063759	PETR FILIPPOV	{"phone": "+70634978807"}
0005433615516	5D6BDE	9913 438234	OLGA GUSEVA	{"phone": "+70682365460"}
0005433615517	5D6BDE	6190 820490	ALEKSANDR KULIKOV	{"phone": "+70174356724"}
0005433615518	6354DB	8779 531489	VALERIY DAVYDOV	{"phone": "+70030098608"}
0005433615519	97C47D	4170 461826	GALINA NESTEROVA	{"phone": "+70473192669"}
0005433615520	41FCE2	4647 959842	IRINA ERMAKOVA	{"email": "irina.ermakova-05011977@postgrespro.ru", "phone": "+70348293543"}
0005433615521	5FE867	3420 175528	KRISTINA EFREMOVA	{"email": "efremova.k-121962@postgrespro.ru", "phone": "+70095450389"}
0005433615522	77124E	1742 717596	TAMARA SAVELEVA	{"email": "savelevat.1973@postgrespro.ru", "phone": "+70256243899"}
0005433615523	77124E	6490 723010	ALEKSANDRA ANISIMOVA	{"phone": "+70383584249"}
0005433615524	77124E	8709 511500	MARINA NESTEROVA	{"email": "marina-nesterova.091974@postgrespro.ru", "phone": "+70285805926"}
0005433615525	6ADFB1	8843 218136	VYACHESLAV POPOV	{"email": "popov-v_1973@postgrespro.ru", "phone": "+70845386457"}
0005433615526	C9753E	6722 234992	VLADIMIR KOROLEV	{"email": "korolevv-1979@postgrespro.ru", "phone": "+70376239953"}
0005433615527	0B9ECB	9225 435083	LYUBOV BORISOVA	{"email": "l-borisova-13031961@postgrespro.ru", "phone": "+70632477358"}
0005433615528	0B9ECB	7884 993404	KLAVDIYA KOLESNIKOVA	{"email": "k-kolesnikova-011981@postgrespro.ru", "phone": "+70324992495"}
0005433615529	FFD002	9140 836813	LYUBOV STEPANOVA	{"phone": "+70919843266"}
0005433615530	E0082B	6136 461324	INESSA BARANOVA	{"email": "ibaranova_04061971@postgrespro.ru", "phone": "+70303617506"}
0005433615531	E0082B	3563 764283	KSENIYA RYABOVA	{"email": "kseniya.ryabova081976@postgrespro.ru", "phone": "+70554357798"}
0005433615532	E05E33	9654 962210	ANGELINA TARASOVA	{"email": "tarasova_a.1970@postgrespro.ru", "phone": "+70476896877"}
0005433615533	E4006C	0483 078436	PAVEL GORBUNOV	{"email": "pavel.gorbunov_091977@postgrespro.ru", "phone": "+70296391107"}
0005433615534	36B7CF	8817 710597	NATALYA MARTYNOVA	{"phone": "+70742674209"}
0005433615535	36B7CF	7117 713597	YULIYA IVANOVA	{"phone": "+70856133364"}
0005433615536	C05959	0133 971218	RAISA VOLKOVA	{"phone": "+70937953894"}
0005433615537	C05959	6681 773044	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya_09101972@postgrespro.ru", "phone": "+70542031710"}
0005433615538	257CD8	8605 615646	MIKHAIL PAVLOV	{"email": "pavlov_m-06051964@postgrespro.ru", "phone": "+70539814153"}
0005433615539	2181D2	2988 358044	ALEKSEY ORLOV	{"email": "a-orlov-101971@postgrespro.ru", "phone": "+70682737525"}
0005433615540	2181D2	4833 944402	VITALIY MAKAROV	{"email": "vitaliy-makarov.051976@postgrespro.ru", "phone": "+70760909093"}
0005433615541	D3D05F	3881 817368	VALERIY ALEKSEEV	{"phone": "+70334234204"}
0005433615542	423E11	0549 441282	ANNA EGOROVA	{"phone": "+70572994873"}
0005433615543	691C66	1518 101502	ANATOLIY FEDOROV	{"email": "a-fedorov041962@postgrespro.ru", "phone": "+70767801112"}
0005433615544	5FE07C	5963 355167	NADEZHDA BELOVA	{"phone": "+70208796785"}
0005433615545	F7E421	8374 064560	EVGENIY BELOV	{"email": "ebelov.1961@postgrespro.ru", "phone": "+70278349629"}
0005433615546	72B8F4	0926 337580	SERGEY MAKAROV	{"email": "makarovsergey1964@postgrespro.ru", "phone": "+70187150333"}
0005433615547	582998	1954 422769	MARIYA KOROLEVA	{"email": "koroleva-mariya_17071976@postgrespro.ru", "phone": "+70588692149"}
0005433615548	F9B2B2	2397 579226	ANDREY ZAYCEV	{"phone": "+70487388816"}
0005433615549	48AAA0	2487 650983	IVAN YAKOVLEV	{"phone": "+70522637710"}
0005433615550	48AAA0	5347 432544	VLADIMIR BORISOV	{"email": "v.borisov-13071965@postgrespro.ru", "phone": "+70662386563"}
0005433615551	0694A9	9497 331635	VIKTOR ZAYCEV	{"email": "zaycev.viktor_1975@postgrespro.ru", "phone": "+70901286834"}
0005433615552	16AE81	9057 924242	NIKITA MELNIKOV	{"email": "n.melnikov-1961@postgrespro.ru", "phone": "+70237350213"}
0005433615553	16AE81	4645 447149	SERGEY VLASOV	{"phone": "+70797838570"}
0005433615554	6D0398	4622 228745	ELENA KARPOVA	{"email": "karpova-e.1962@postgrespro.ru", "phone": "+70493542919"}
0005433615555	56B97C	0015 244120	ILYA ISAEV	{"email": "isaevi1975@postgrespro.ru", "phone": "+70118538496"}
0005433615556	ADA508	0916 679750	KONSTANTIN ANDREEV	{"phone": "+70216334217"}
0005433615557	2280C4	5995 098007	NIKOLAY NIKOLAEV	{"phone": "+70216820956"}
0005433615558	2280C4	1620 466462	VLADIMIR NAZAROV	{"phone": "+70375538555"}
0005433615559	6F0892	0858 021841	ELENA ILINA	{"email": "eilina_1969@postgrespro.ru", "phone": "+70931214843"}
0005433615560	6F0892	7451 760422	MARIYA IVANOVA	{"email": "ivanovam26091978@postgrespro.ru", "phone": "+70303041885"}
0005433615561	8B6614	7312 179274	NIKOLAY KUZNECOV	{"email": "n-kuznecov-041967@postgrespro.ru", "phone": "+70155322889"}
0005433615562	8B6614	8188 589154	GEORGIY PETROV	{"email": "petrov-g1970@postgrespro.ru", "phone": "+70443729887"}
0005433615563	CC192D	3513 596289	MIKHAIL FEDOROV	{"phone": "+70706021761"}
0005433615564	782117	0317 866750	MAKSIM KISELEV	{"email": "maksimkiselev.021979@postgrespro.ru", "phone": "+70277301754"}
0005433615565	8F5CF7	7374 321168	EVGENIY GUSEV	{"email": "gusevevgeniy-041979@postgrespro.ru", "phone": "+70700785206"}
0005433615566	7C6FBB	6645 413856	TAMARA KUZNECOVA	{"phone": "+70385552487"}
0005433615567	E9FB90	5406 010020	TATYANA MARTYNOVA	{"email": "martynova.t_24071975@postgrespro.ru", "phone": "+70191510745"}
0005433615568	22C5A9	7668 726779	ALEKSANDR FOMIN	{"phone": "+70553966182"}
0005433615569	DD715C	6253 985144	LYUBOV NAZAROVA	{"phone": "+70657691864"}
0005433615570	5E2DA4	9043 376506	MAKSIM SAVELEV	{"email": "msavelev061972@postgrespro.ru", "phone": "+70591747851"}
0005433615571	659589	0341 193212	MARIYA POPOVA	{"email": "popovamariya.011985@postgrespro.ru", "phone": "+70962840285"}
0005433615572	9A395B	5289 111094	ALEVTINA KOROLEVA	{"email": "koroleva.a-12061976@postgrespro.ru", "phone": "+70206658756"}
0005433615573	9A395B	4031 168658	LYUDMILA ZAKHAROVA	{"email": "zakharova.l21101983@postgrespro.ru", "phone": "+70322186620"}
0005433615574	9A395B	7260 377168	ANNA DMITRIEVA	{"phone": "+70325805584"}
0005433615575	0A41FB	7645 740697	LIDIYA KUZNECOVA	{"phone": "+70605989297"}
0005433615576	0A41FB	2318 829307	VLADA ZHURAVLEVA	{"email": "zhuravleva.vlada_1967@postgrespro.ru", "phone": "+70025993855"}
0005433615577	A8BCD3	2347 828661	IGOR ISAEV	{"phone": "+70389246655"}
0005433615578	A8BCD3	2439 391901	ALEKSANDR MATVEEV	{"email": "matveev.a-1989@postgrespro.ru", "phone": "+70005626290"}
0005433615579	A8BCD3	2069 007044	YURIY ANTONOV	{"phone": "+70180651495"}
0005433615580	6DF83C	6600 378875	GALINA DANILOVA	{"phone": "+70547981089"}
0005433615581	069478	1922 065172	INNA VOLKOVA	{"phone": "+70885606132"}
0005433615582	069478	9676 844420	YULIYA PETROVA	{"phone": "+70635711981"}
0005433615583	309EB5	6295 852447	NIKOLAY ZAKHAROV	{"email": "zakharovn_09031979@postgrespro.ru", "phone": "+70191888565"}
0005433615584	309EB5	0701 827911	ELENA MIKHAYLOVA	{"email": "mikhaylova-e_1969@postgrespro.ru", "phone": "+70603581915"}
0005433615585	309EB5	9079 690002	MAKSIM SCHERBAKOV	{"email": "scherbakov-maksim_1960@postgrespro.ru", "phone": "+70129913897"}
0005433615586	D3192C	1442 391937	VERA GAVRILOVA	{"email": "v_gavrilova_1961@postgrespro.ru", "phone": "+70643605553"}
0005433615587	0D5827	8028 424539	EKATERINA NIKOLAEVA	{"phone": "+70516149788"}
0005433615588	5ABDF5	1101 608578	ARTEM DMITRIEV	{"phone": "+70318806625"}
0005433615589	A9E851	3555 138435	ANDREY STEPANOV	{"email": "andreystepanov1984@postgrespro.ru", "phone": "+70861803073"}
0005433615590	A9E851	5739 779416	OLESYA FOMINA	{"email": "o-fomina.15051957@postgrespro.ru", "phone": "+70380574715"}
0005433615591	9FB2D2	1605 166767	ALEKSANDR FEDOTOV	{"email": "fedotov.aleksandr_071969@postgrespro.ru", "phone": "+70062467539"}
0005433615592	D2D872	0219 151653	ELENA KUZNECOVA	{"email": "kuznecova.elena-08081967@postgrespro.ru", "phone": "+70572818822"}
0005433615593	29B820	3877 960165	ALENA YAKOVLEVA	{"email": "alena.yakovleva-091970@postgrespro.ru", "phone": "+70755718243"}
0005433615594	A3FCE8	1503 366151	VERA IVANOVA	{"phone": "+70303194635"}
0005433615595	622232	7378 232075	TATYANA ZAYCEVA	{"email": "zayceva-t_111970@postgrespro.ru", "phone": "+70713776529"}
0005433615596	1A720C	9761 219543	RUSTAM SMIRNOV	{"email": "r.smirnov30051964@postgrespro.ru", "phone": "+70900504994"}
0005433615597	6746E8	9399 975980	IGOR IVANOV	{"email": "i-ivanov_1970@postgrespro.ru", "phone": "+70981125153"}
0005433615598	976E27	4698 751072	ALINA KAZAKOVA	{"phone": "+70770364839"}
0005433615764	BE2235	8335 051679	IVAN SOROKIN	{"phone": "+70921411856"}
0005433615599	98B50B	9961 976977	GALINA SMIRNOVA	{"email": "g-smirnova-31031971@postgrespro.ru", "phone": "+70225741014"}
0005433615600	E6E2FC	1973 949950	ANASTASIYA FROLOVA	{"phone": "+70194542734"}
0005433615601	94FB8C	7921 104319	VIKTOR EGOROV	{"email": "vegorov021971@postgrespro.ru", "phone": "+70120703471"}
0005433615602	220C40	9753 428369	VALENTINA OVCHINNIKOVA	{"email": "valentina-ovchinnikova.031973@postgrespro.ru", "phone": "+70938038875"}
0005433615603	AC1046	1420 116008	OLGA ISAEVA	{"email": "isaeva_o_09111976@postgrespro.ru", "phone": "+70907390000"}
0005433615604	C5F2C1	3166 926366	NIKOLAY SIDOROV	{"phone": "+70955721846"}
0005433615605	C5F2C1	3187 783185	TATYANA OSIPOVA	{"email": "t-osipova.091970@postgrespro.ru", "phone": "+70504110134"}
0005433615606	A34835	5532 461638	LYUDMILA PETROVA	{"email": "petrova_lyudmila-1969@postgrespro.ru", "phone": "+70944335409"}
0005433615607	AEB6DE	0022 792618	MARIYA SOROKINA	{"email": "sorokina-m.17021977@postgrespro.ru", "phone": "+70470846055"}
0005433615608	22AFEE	7833 281842	ARTEM TIKHONOV	{"phone": "+70721938196"}
0005433615609	22AFEE	1585 132121	EKATERINA BELOVA	{"email": "e-belova-091967@postgrespro.ru", "phone": "+70128187276"}
0005433615610	008B53	6200 542578	KRISTINA EGOROVA	{"phone": "+70721885112"}
0005433615611	EB5B67	9602 716433	VLADIMIR NOVIKOV	{"email": "vnovikov_1954@postgrespro.ru", "phone": "+70289209925"}
0005433615612	AB3515	2262 230714	STANISLAV MEDVEDEV	{"email": "medvedev_s.03071972@postgrespro.ru", "phone": "+70984399792"}
0005433615613	A6AB1E	3161 284942	SERGEY DMITRIEV	{"email": "dmitriev-s_29031977@postgrespro.ru", "phone": "+70321121886"}
0005433615614	28A977	0803 212859	VITALIY STEPANOV	{"phone": "+70982156099"}
0005433615615	8B3923	5791 676352	NADEZHDA KUZNECOVA	{"phone": "+70906316687"}
0005433615616	8B3923	0644 075582	PAVEL GORBUNOV	{"email": "pavelgorbunov.071976@postgrespro.ru", "phone": "+70400062749"}
0005433615617	789F5C	7921 026363	VIKTORIYA NAZAROVA	{"email": "viktoriya_nazarova-09081965@postgrespro.ru", "phone": "+70628696305"}
0005433615618	4EEEEE	5793 958836	ALEKSANDR ROMANOV	{"phone": "+70893671827"}
0005433615619	C08750	0958 305108	KAPITALINA VOLKOVA	{"email": "kapitalinavolkova_1961@postgrespro.ru", "phone": "+70121368091"}
0005433615620	C08750	7354 100530	MIKHAIL NAZAROV	{"email": "mnazarov_1978@postgrespro.ru", "phone": "+70498371250"}
0005433615621	64AC96	5527 285115	NATALYA KAZAKOVA	{"email": "kazakova-natalya.1970@postgrespro.ru", "phone": "+70189106901"}
0005433615622	4AB1E6	9108 655896	TATYANA OVCHINNIKOVA	{"email": "tovchinnikova_091975@postgrespro.ru", "phone": "+70924734294"}
0005433615623	C9C182	1870 228613	ELENA ISAEVA	{"phone": "+70671195225"}
0005433615624	35185B	8695 103754	LYUDMILA SOLOVEVA	{"phone": "+70636425735"}
0005433615625	1CEA4F	6444 240157	OLGA NIKITINA	{"email": "o_nikitina.15081951@postgrespro.ru", "phone": "+70675672585"}
0005433615626	CDA7C6	7882 529987	ANATOLIY BORISOV	{"phone": "+70218113212"}
0005433615627	CDA7C6	2940 721050	ALEKSANDR ABRAMOV	{"email": "abramov.a-041967@postgrespro.ru", "phone": "+70628422091"}
0005433615628	788744	2882 965560	LEONID PETROV	{"email": "l-petrov_04031980@postgrespro.ru", "phone": "+70309008879"}
0005433615629	788744	3521 193770	ANNA KONOVALOVA	{"email": "konovalova.anna1971@postgrespro.ru", "phone": "+70802206399"}
0005433615630	0353C6	2280 328838	VALENTINA ALEKSANDROVA	{"email": "valentina-aleksandrova05031974@postgrespro.ru", "phone": "+70210243001"}
0005433615631	0353C6	1129 676386	DENIS POPOV	{"email": "denis_popov_071972@postgrespro.ru", "phone": "+70196051116"}
0005433615632	1DC570	0102 614512	ELENA NIKITINA	{"email": "elena_nikitina-1969@postgrespro.ru", "phone": "+70491105907"}
0005433615633	249E08	1448 087189	VASILIY MELNIKOV	{"email": "melnikov.v-111982@postgrespro.ru", "phone": "+70513825951"}
0005433615634	249E08	6319 515964	MAKSIM STEPANOV	{"email": "stepanov.maksim071960@postgrespro.ru", "phone": "+70324547850"}
0005433615635	BA7F9E	5680 073079	LYUBOV DAVYDOVA	{"email": "davydova_l-1973@postgrespro.ru", "phone": "+70755067680"}
0005433615636	539862	7552 420408	RAISA GERASIMOVA	{"email": "r_gerasimova30071975@postgrespro.ru", "phone": "+70785175278"}
0005433615637	71A2A1	0740 972483	OLEG KUDRYASHOV	{"phone": "+70449125844"}
0005433615638	99A6CC	9349 154958	KIRILL ANDREEV	{"email": "kirillandreev-091966@postgrespro.ru", "phone": "+70852823221"}
0005433615639	99A6CC	3989 180571	GENNADIY MEDVEDEV	{"email": "gennadiy_medvedev_041962@postgrespro.ru", "phone": "+70240793227"}
0005433615640	CA5332	5249 520323	YURIY VOROBEV	{"email": "yuriy-vorobev-051970@postgrespro.ru", "phone": "+70583370121"}
0005433615641	9AEA53	7036 274858	DAMIR FEDOROV	{"email": "damir.fedorov_1971@postgrespro.ru", "phone": "+70872831606"}
0005433615642	B96C9A	8496 020170	ANNA TARASOVA	{"email": "a_tarasova.011980@postgrespro.ru", "phone": "+70491235281"}
0005433615643	ACDB93	4495 439073	NATALYA KOLESNIKOVA	{"phone": "+70736780080"}
0005433615644	ACDB93	2332 572987	NATALYA ROMANOVA	{"phone": "+70060292239"}
0005433615645	314C38	5079 863100	NAIL SEMENOV	{"email": "n_semenov.051981@postgrespro.ru", "phone": "+70166172687"}
0005433615646	0B4751	1652 745625	KLAVDIYA GRISHINA	{"email": "klavdiya-grishina.051972@postgrespro.ru", "phone": "+70717532432"}
0005433615647	0B4751	0684 073769	DMITRIY NAZAROV	{"email": "dmitriy_nazarov-071976@postgrespro.ru", "phone": "+70567886377"}
0005433615648	4C2757	3072 077739	YURIY NOVIKOV	{"phone": "+70911998564"}
0005433615649	E49A56	4978 896278	EKATERINA POPOVA	{"phone": "+70109335166"}
0005433615650	62BDBA	5324 994323	SABINA VOLKOVA	{"email": "volkova-sabina1965@postgrespro.ru", "phone": "+70504470552"}
0005433615651	62BDBA	1283 908555	ZLATA KONDRATEVA	{"email": "kondrateva_z-1971@postgrespro.ru", "phone": "+70979537388"}
0005433615652	F5CFD1	2507 140157	GRIGORIY KONOVALOV	{"phone": "+70136138963"}
0005433615653	6BFA43	1348 534828	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov091971@postgrespro.ru", "phone": "+70044757716"}
0005433615654	6BFA43	6278 694403	ELENA MAKAROVA	{"email": "makarovaelena18061969@postgrespro.ru", "phone": "+70002265611"}
0005433615655	4448E1	6404 150592	LYUDMILA KOLESNIKOVA	{"email": "lyudmila-kolesnikova111962@postgrespro.ru", "phone": "+70016042360"}
0005433615656	F20BE7	0929 952460	NATALYA KULIKOVA	{"email": "nkulikova.061970@postgrespro.ru", "phone": "+70644077547"}
0005433615657	F20BE7	4886 160454	ELIZAVETA FOMINA	{"email": "elizaveta-fomina-11111980@postgrespro.ru", "phone": "+70028124083"}
0005433615658	449605	0458 763258	IRINA AKIMOVA	{"phone": "+70477645712"}
0005433615659	ED7EBA	3696 251634	VLADIMIR SAVELEV	{"email": "savelev_vladimir.041968@postgrespro.ru", "phone": "+70911924992"}
0005433615660	69E5AC	1517 266887	SEMEN MOROZOV	{"phone": "+70203334602"}
0005433615661	D70120	9866 889509	MIKHAIL KISELEV	{"phone": "+70690520102"}
0005433615662	5F2BD5	9511 245358	TATYANA ANDREEVA	{"email": "tatyana.andreeva071971@postgrespro.ru", "phone": "+70574925525"}
0005433615663	5F2BD5	5804 847590	GALINA POLYAKOVA	{"email": "polyakova.g21051979@postgrespro.ru", "phone": "+70631222140"}
0005433615664	7250C1	2653 125128	ANASTASIYA VOLKOVA	{"phone": "+70179776647"}
0005433615665	7250C1	8319 616301	VERA DAVYDOVA	{"email": "v.davydova1970@postgrespro.ru", "phone": "+70271766690"}
0005433615666	7250C1	8039 350759	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev101972@postgrespro.ru", "phone": "+70573544445"}
0005433615667	7F2BDA	0632 562052	VASILIY NAZAROV	{"email": "vasiliy.nazarov051969@postgrespro.ru", "phone": "+70761040589"}
0005433615668	6A356F	6527 856821	VIKTOR MAKSIMOV	{"email": "maksimov_v-1970@postgrespro.ru", "phone": "+70050929650"}
0005433615669	C51DB1	0011 329201	ALEKSANDR POPOV	{"email": "a_popov.24091976@postgrespro.ru", "phone": "+70267061414"}
0005433615729	A777E3	6102 546398	VSEVOLOD ZAYCEV	{"phone": "+70762753514"}
0005433615670	C51DB1	3781 809762	MIKHAIL ALEKSEEV	{"email": "alekseevm.15021975@postgrespro.ru", "phone": "+70165087121"}
0005433615671	C51DB1	4942 000194	SERGEY ZAYCEV	{"email": "szaycev-1969@postgrespro.ru", "phone": "+70609298463"}
0005433615672	AFA817	2887 737619	TATYANA DAVYDOVA	{"email": "davydovatatyana-08031970@postgrespro.ru", "phone": "+70873349156"}
0005433615673	AFA817	6137 226719	SERGEY MOROZOV	{"email": "morozov_s_1982@postgrespro.ru", "phone": "+70179663400"}
0005433615674	7B78BF	0520 508032	SERGEY SIDOROV	{"email": "s_sidorov_091972@postgrespro.ru", "phone": "+70267481269"}
0005433615675	7B78BF	1143 762167	MARINA NAUMOVA	{"phone": "+70145114544"}
0005433615676	0FF404	9635 906383	ELENA MARTYNOVA	{"phone": "+70974695044"}
0005433615677	A06640	3319 204681	ANNA NIKITINA	{"email": "nikitina.a.03081972@postgrespro.ru", "phone": "+70606301381"}
0005433615678	A06640	7289 668991	EGOR DENISOV	{"email": "denisov-e_021982@postgrespro.ru", "phone": "+70299866365"}
0005433615679	1CC857	5453 078362	IVAN TIKHONOV	{"email": "tikhonovivan.081976@postgrespro.ru", "phone": "+70517422301"}
0005433615680	1CC857	8048 968217	NINA KUDRYASHOVA	{"phone": "+70051828415"}
0005433615681	1CC857	7681 226335	ALEKSANDR TIMOFEEV	{"email": "atimofeev03031974@postgrespro.ru", "phone": "+70347250198"}
0005433615682	D8DC3D	5149 178389	SVETLANA ARKHIPOVA	{"email": "arkhipova-s.12101977@postgrespro.ru", "phone": "+70047685753"}
0005433615683	C3A619	3561 291005	KSENIYA KOVALEVA	{"email": "kovaleva_k28031966@postgrespro.ru", "phone": "+70159467943"}
0005433615684	9116DB	0336 961769	TATYANA PAVLOVA	{"email": "tatyanapavlova.19121970@postgrespro.ru", "phone": "+70134847874"}
0005433615685	9116DB	7862 264960	MARINA OVCHINNIKOVA	{"email": "marina-ovchinnikova.1960@postgrespro.ru", "phone": "+70354946422"}
0005433615686	953E3A	1199 158570	VALENTINA ANISIMOVA	{"phone": "+70409069052"}
0005433615687	953E3A	1483 814637	MIKHAIL ZHURAVLEV	{"phone": "+70554831496"}
0005433615688	D41A63	3653 934415	ILMIRA KRASNOVA	{"phone": "+70664123130"}
0005433615689	86D69D	8052 918815	RUSLAN POPOV	{"email": "popovruslan19121978@postgrespro.ru", "phone": "+70795207430"}
0005433615690	758DCF	8943 531822	NELYA FROLOVA	{"phone": "+70222339107"}
0005433615691	838E4B	3049 979399	ALEKSEY VLASOV	{"email": "vlasov_aleksey_31121970@postgrespro.ru", "phone": "+70283609779"}
0005433615692	37A7A2	9719 538933	ANASTASIYA MASLOVA	{"email": "maslova-a091964@postgrespro.ru", "phone": "+70122696362"}
0005433615693	3C542D	9714 931129	ANASTASIYA ALEKSEEVA	{"phone": "+70626983189"}
0005433615694	024775	8464 337662	NADEZHDA LUKYANOVA	{"email": "lukyanovan.15031972@postgrespro.ru", "phone": "+70151192328"}
0005433615695	1F6AFA	0916 557651	ANDREY ISAEV	{"phone": "+70063468534"}
0005433615696	C123F2	2493 593614	IRINA POTAPOVA	{"email": "irina.potapova.20101979@postgrespro.ru", "phone": "+70131207125"}
0005433615697	C123F2	5973 302660	ILDUS MARTYNOV	{"phone": "+70530857462"}
0005433615698	E85E09	1065 243369	OLGA POPOVA	{"phone": "+70785627553"}
0005433615699	D53017	7212 604758	NINA IVANOVA	{"phone": "+70928631178"}
0005433615700	D53017	1894 586267	VASILIY PETROV	{"email": "petrov-vasiliy.071985@postgrespro.ru", "phone": "+70918628565"}
0005433615701	96280F	2762 990576	PAVEL PAVLOV	{"email": "pavel_pavlov1973@postgrespro.ru", "phone": "+70016486981"}
0005433615702	D8F72D	6148 941671	SERGEY NIKOLAEV	{"phone": "+70757277860"}
0005433615703	A873A5	5572 948754	VLADIMIR IVANOV	{"email": "ivanovv-06021967@postgrespro.ru", "phone": "+70317946013"}
0005433615704	A873A5	5059 050050	YURIY MARTYNOV	{"email": "y_martynov-1965@postgrespro.ru", "phone": "+70184707061"}
0005433615705	A873A5	6534 770867	DARYA PAVLOVA	{"phone": "+70215650585"}
0005433615706	9C4646	5507 100996	NINA VOLKOVA	{"phone": "+70437795415"}
0005433615707	A4D1D6	1379 032192	GEORGIY FILIPPOV	{"phone": "+70013341972"}
0005433615708	6C3464	1776 838721	LILIYA ALEKSEEVA	{"email": "alekseeva.liliya.1967@postgrespro.ru", "phone": "+70183355911"}
0005433615709	D9734B	9904 821675	ANDREY MOROZOV	{"email": "andreymorozov081964@postgrespro.ru", "phone": "+70091334464"}
0005433615710	AC2D40	8036 022450	VERONIKA DMITRIEVA	{"phone": "+70842626791"}
0005433615711	A3666D	7256 192355	ALEKSEY KOROLEV	{"phone": "+70485653045"}
0005433615712	6198A3	9731 188604	ALEVTINA TARASOVA	{"phone": "+70316126845"}
0005433615713	4C1A64	2882 805004	NATALYA ZHUKOVA	{"email": "n.zhukova101971@postgrespro.ru", "phone": "+70705908842"}
0005433615714	00FB6B	7486 918649	EVGENIY SERGEEV	{"phone": "+70433982809"}
0005433615715	00FB6B	8457 884240	LARISA GORBUNOVA	{"email": "larisa-gorbunova-26081969@postgrespro.ru", "phone": "+70445499954"}
0005433615716	B79D2A	6611 878061	GRIGORIY GORBUNOV	{"phone": "+70098936843"}
0005433615717	B79D2A	4728 377980	ALEKSANDR VOROBEV	{"email": "vorobev_a-1971@postgrespro.ru", "phone": "+70292332211"}
0005433615718	B79D2A	6563 563866	TAMARA SCHERBAKOVA	{"email": "scherbakovatamara031979@postgrespro.ru", "phone": "+70687084870"}
0005433615719	AC13D0	6225 504941	LEONID VOROBEV	{"phone": "+70045645871"}
0005433615720	38E98D	1495 315187	ALENA VASILEVA	{"phone": "+70064427508"}
0005433615721	38E98D	7441 390573	ANNA MAKAROVA	{"email": "makarova-anna_1969@postgrespro.ru", "phone": "+70443528861"}
0005433615722	38E98D	1289 293634	VITALIY KARPOV	{"phone": "+70850956157"}
0005433615723	868247	4673 079027	ANASTASIYA POTAPOVA	{"email": "potapovaanastasiya-1978@postgrespro.ru", "phone": "+70743313415"}
0005433615724	9EE196	1996 508159	ANDREY FILIPPOV	{"phone": "+70802735660"}
0005433615725	454312	0752 943065	ANATOLIY STEPANOV	{"email": "astepanov-101967@postgrespro.ru", "phone": "+70838411686"}
0005433615726	454312	0515 758145	IRINA POTAPOVA	{"email": "potapova.i-28061980@postgrespro.ru", "phone": "+70200109422"}
0005433615727	56DEA9	0941 159967	TATYANA SCHERBAKOVA	{"phone": "+70087849784"}
0005433615728	56DEA9	0233 488515	TATYANA EFREMOVA	{"email": "tatyana-efremova.101962@postgrespro.ru", "phone": "+70193796837"}
0005433615730	20AFA4	8887 039607	EGOR KUZMIN	{"phone": "+70651297919"}
0005433615731	F72C65	7146 059968	ANGELINA ANISIMOVA	{"phone": "+70485307549"}
0005433615732	F72C65	5240 780782	ALEKSANDR GAVRILOV	{"email": "a_gavrilov-081969@postgrespro.ru", "phone": "+70177579547"}
0005433615733	D91A92	3783 246555	ANTON KULIKOV	{"email": "antonkulikov_1987@postgrespro.ru", "phone": "+70955402784"}
0005433615734	B36E4D	1283 787130	MARINA KISELEVA	{"email": "marina-kiseleva_18031960@postgrespro.ru", "phone": "+70265128302"}
0005433615735	8C1588	9891 260841	IGOR NAZAROV	{"email": "inazarov.1974@postgrespro.ru", "phone": "+70882731884"}
0005433615736	8C1588	3028 806079	KARINA KOZLOVA	{"phone": "+70673136210"}
0005433615737	F03BAE	5362 645083	MIKHAIL GAVRILOV	{"email": "mikhail_gavrilov_11061981@postgrespro.ru", "phone": "+70079575809"}
0005433615738	F03BAE	4032 566728	NINA KOROLEVA	{"email": "koroleva-n-1968@postgrespro.ru", "phone": "+70777688773"}
0005433615739	559564	3203 140429	VLADIMIR SMIRNOV	{"email": "vsmirnov1968@postgrespro.ru", "phone": "+70862780345"}
0005433615740	559564	3951 831003	POLINA NOVIKOVA	{"email": "novikova-polina071971@postgrespro.ru", "phone": "+70429220423"}
0005433615741	2D1A35	6056 960229	ALEKSEY ILIN	{"email": "ilin-aleksey.051974@postgrespro.ru", "phone": "+70635958216"}
0005433615742	2D1A35	9899 630718	DENIS KARPOV	{"email": "karpov_d-1986@postgrespro.ru", "phone": "+70236867174"}
0005433615743	CF5E94	9883 086027	ANASTASIYA GUSEVA	{"email": "a.guseva.10111963@postgrespro.ru", "phone": "+70480355916"}
0005433615744	BA9AF7	8633 357327	VALENTINA SEMENOVA	{"phone": "+70521966886"}
0005433615745	BA9AF7	3994 482527	ALEKSEY ANTONOV	{"email": "antonov-aleksey041974@postgrespro.ru", "phone": "+70397258038"}
0005433615746	A796CF	4819 575884	GALINA BARANOVA	{"phone": "+70537258001"}
0005433615747	A796CF	4721 326414	KONSTANTIN BELOV	{"phone": "+70414375431"}
0005433615748	54D25C	6810 141542	MARIYA TIKHONOVA	{"email": "tikhonova.mariya.041976@postgrespro.ru", "phone": "+70641008356"}
0005433615749	37AEE4	3964 283954	NIKOLAY GAVRILOV	{"email": "gavrilov_n1975@postgrespro.ru", "phone": "+70833300032"}
0005433615750	37AEE4	4912 009758	ALEKSANDR TARASOV	{"phone": "+70326378789"}
0005433615751	37AEE4	7647 295994	ELENA KOZLOVA	{"email": "kozlovaelena.1960@postgrespro.ru", "phone": "+70561070801"}
0005433615752	984623	0564 349727	ILYAS ANDREEV	{"phone": "+70714159583"}
0005433615753	984623	9216 390429	KONSTANTIN KOROLEV	{"phone": "+70092546295"}
0005433615754	4A66C7	8131 899416	AYRAT NIKITIN	{"email": "ayrat_nikitin_121974@postgrespro.ru", "phone": "+70099531819"}
0005433615755	4A66C7	5830 272486	SERGEY DENISOV	{"phone": "+70113933756"}
0005433615756	4A66C7	4882 322272	SERGEY VLASOV	{"email": "s_vlasov1971@postgrespro.ru", "phone": "+70390479937"}
0005433615757	8A0AB8	6713 594794	DMITRIY PAVLOV	{"phone": "+70153761151"}
0005433615758	BD795A	8982 092298	EVGENIY MARTYNOV	{"phone": "+70954307338"}
0005433615759	BD795A	7443 318935	ANDREY MOISEEV	{"phone": "+70578793318"}
0005433615760	BD795A	0704 315914	GALINA OSIPOVA	{"phone": "+70823051880"}
0005433615761	82B810	1308 178908	VASILIY SOLOVEV	{"phone": "+70351620828"}
0005433615762	5445DB	7703 919962	YULIYA MAKAROVA	{"email": "makarova-yuliya.041961@postgrespro.ru", "phone": "+70179592046"}
0005433615763	BE2235	2604 974579	KONSTANTIN MATVEEV	{"phone": "+70053890315"}
0005433615765	93D753	8905 356231	EKATERINA NAUMOVA	{"phone": "+70760870648"}
0005433615766	93D753	9561 432486	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev1973@postgrespro.ru", "phone": "+70170022630"}
0005433615767	00391F	6263 310332	GALINA KULIKOVA	{"phone": "+70823692505"}
0005433615768	00391F	8547 070203	NIKOLAY YAKOVLEV	{"phone": "+70079318600"}
0005433615769	C721F6	4061 165534	VALERIY SMIRNOV	{"email": "smirnov_v.13101958@postgrespro.ru", "phone": "+70869871430"}
0005433615770	D6250C	0789 805918	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir.1961@postgrespro.ru", "phone": "+70855575637"}
0005433615771	D6250C	1490 277730	ELENA GRISHINA	{"email": "elena_grishina_21011976@postgrespro.ru", "phone": "+70877806730"}
0005433615772	D6250C	8179 497587	ANNA ALEKSANDROVA	{"phone": "+70413894706"}
0005433615773	32FADB	1028 929069	ALENA ZHURAVLEVA	{"email": "zhuravlevaalena-1966@postgrespro.ru", "phone": "+70143124901"}
0005433615774	F115F8	7709 266531	NATALYA KOROLEVA	{"email": "koroleva_natalya.09031975@postgrespro.ru", "phone": "+70870773786"}
0005433615775	2837E2	1032 910272	MAKSIM EGOROV	{"phone": "+70805053717"}
0005433615776	2FB9E0	4572 450150	MARIYA YAKOVLEVA	{"phone": "+70109270910"}
0005433615777	D6A97F	0556 651781	ANDREY MIKHAYLOV	{"email": "mikhaylov.andrey_07051965@postgrespro.ru", "phone": "+70718491062"}
0005433615778	D87378	1820 386527	NIKOLAY PETROV	{"email": "petrovnikolay-09011978@postgrespro.ru", "phone": "+70072214540"}
0005433615779	66424F	3952 921139	VERA DENISOVA	{"email": "denisova_vera_071985@postgrespro.ru", "phone": "+70860174139"}
0005433615780	ED27BC	7118 746418	VITALIY SOKOLOV	{"email": "sokolov_vitaliy.1984@postgrespro.ru", "phone": "+70563053909"}
0005433615781	80A2A0	0521 507881	ANATOLIY TIMOFEEV	{"phone": "+70112680260"}
0005433615782	AF30A2	1396 072840	VLADISLAV KRASNOV	{"phone": "+70397567487"}
0005433615783	F96EB5	1167 429643	TATYANA PAVLOVA	{"email": "pavlova.t24091968@postgrespro.ru", "phone": "+70821689299"}
0005433615784	F96EB5	8295 948220	ANTON BORISOV	{"phone": "+70648671809"}
0005433615785	AEDAAB	0599 360542	LYUDMILA KUZMINA	{"phone": "+70978623380"}
0005433615786	C4C49B	9862 712658	DMITRIY MARTYNOV	{"phone": "+70777238585"}
0005433615787	F79A8E	7874 018989	ARSEN GERASIMOV	{"email": "arsengerasimov051980@postgrespro.ru", "phone": "+70932798849"}
0005433615788	F79A8E	3939 646702	KONSTANTIN ALEKSANDROV	{"phone": "+70757652144"}
0005433615789	1A4319	5059 427554	ANASTASIYA KUDRYASHOVA	{"phone": "+70445419279"}
0005433615790	94E27E	1146 051067	VIKTOR DAVYDOV	{"phone": "+70458537788"}
0005433615791	6BB3C0	0258 455942	ELENA ALEKSEEVA	{"email": "alekseeva.e-25071959@postgrespro.ru", "phone": "+70033000795"}
0005433615792	6BB3C0	8079 151926	DMITRIY KAZAKOV	{"email": "d.kazakov1978@postgrespro.ru", "phone": "+70290127038"}
0005433615793	798F72	6545 137195	OKSANA ZHURAVLEVA	{"phone": "+70546460300"}
0005433615794	B67935	3350 419029	KIRILL SOLOVEV	{"phone": "+70404908769"}
0005433615795	B67935	2543 047137	SVETLANA ZAYCEVA	{"email": "zayceva.svetlana.23021979@postgrespro.ru", "phone": "+70020829366"}
0005433615796	B67935	3196 142948	VLADIMIR BARANOV	{"email": "vbaranov-1974@postgrespro.ru", "phone": "+70373859061"}
0005433615797	E50675	9757 354254	YURIY PETROV	{"email": "petrov.y101975@postgrespro.ru", "phone": "+70094960684"}
0005433615798	E50675	7959 422177	GALINA TIKHONOVA	{"email": "tikhonova-galina_25111965@postgrespro.ru", "phone": "+70100113820"}
0005433615799	20FAF1	6131 517739	ROMAN BONDARENKO	{"phone": "+70542864479"}
0005433615800	20FAF1	3396 389796	SVETLANA BORISOVA	{"email": "borisovas-1969@postgrespro.ru", "phone": "+70374513985"}
0005433615801	20FAF1	8443 812811	ALEKSANDR SAVELEV	{"email": "a_savelev.13111969@postgrespro.ru", "phone": "+70166323287"}
0005433615802	247660	8153 961963	VALENTINA GORBUNOVA	{"phone": "+70870763024"}
0005433615803	CA31C0	2816 434431	ANTONINA AFANASEVA	{"email": "antoninaafanaseva1969@postgrespro.ru", "phone": "+70239154194"}
0005433615804	78FC97	8955 061888	EVGENIY KOROLEV	{"email": "e.korolev-1973@postgrespro.ru", "phone": "+70639651588"}
0005433615805	9B460B	3793 118968	LIDIYA DMITRIEVA	{"phone": "+70844015271"}
0005433615806	65E230	7195 818264	ALEKSANDR MATVEEV	{"email": "matveev.aleksandr_081965@postgrespro.ru", "phone": "+70655348356"}
0005433615807	65E230	4260 209601	ELVIRA KONDRATEVA	{"phone": "+70838990586"}
0005433615808	587E4B	7372 978485	LYUDMILA POPOVA	{"phone": "+70802705427"}
0005433615809	587E4B	6170 975826	KRISTINA AFANASEVA	{"phone": "+70796204850"}
0005433615810	A8FC78	3804 249428	LYUBOV BOGDANOVA	{"email": "bogdanova.l_11021971@postgrespro.ru", "phone": "+70237697597"}
0005433615811	27CC72	9721 879335	ANASTASIYA ANDREEVA	{"email": "a.andreeva031982@postgrespro.ru", "phone": "+70408564333"}
0005433615812	CB6DA5	7004 832953	ANTON NAZAROV	{"email": "nazarov.a.1964@postgrespro.ru", "phone": "+70345418678"}
0005433615813	CB6DA5	2354 504937	VLADIMIR KAZAKOV	{"phone": "+70517338774"}
0005433615814	DFBBC2	0867 253083	VITALIY NIKOLAEV	{"email": "nikolaev_v.31051970@postgrespro.ru", "phone": "+70716767998"}
0005433615815	11417E	9183 213124	ANTON OSIPOV	{"phone": "+70475178725"}
0005433615816	11417E	3492 771935	EVGENIY MATVEEV	{"email": "evgeniy_matveev101972@postgrespro.ru", "phone": "+70225480976"}
0005433615817	01D9D7	3520 667473	ANNA SOKOLOVA	{"phone": "+70947412986"}
0005433615818	76B87A	6008 837043	IRINA KOROLEVA	{"phone": "+70171004606"}
0005433615819	76B87A	3142 415049	KLAVDIYA EGOROVA	{"phone": "+70962225235"}
0005433615820	4EED98	5165 453209	PAVEL KOZLOV	{"phone": "+70102339767"}
0005433615821	1DDE40	9896 008903	OLGA MAKAROVA	{"email": "makarovao_12061978@postgrespro.ru", "phone": "+70400148059"}
0005433615822	F9219E	4451 044754	ZHANNA BARANOVA	{"phone": "+70541067951"}
0005433615823	C03ED3	8111 574423	VLADIMIR NIKITIN	{"email": "nikitin_vladimir_11041977@postgrespro.ru", "phone": "+70521566548"}
0005433615824	ED0903	5795 432611	ANDREY VLASOV	{"email": "vlasov_andrey1976@postgrespro.ru", "phone": "+70386800702"}
0005433615825	16A35F	7701 566748	ALEKSEY KOZLOV	{"email": "alekseykozlov20111983@postgrespro.ru", "phone": "+70703790052"}
0005433615826	66E7A9	9166 182806	ELENA DAVYDOVA	{"email": "davydova.e_24041959@postgrespro.ru", "phone": "+70114920104"}
0005433615827	66E7A9	7293 445817	GENNADIY TIKHONOV	{"email": "gennadiy.tikhonov_28051967@postgrespro.ru", "phone": "+70679164073"}
0005433615828	D22027	4593 746399	VALERIYA IVANOVA	{"phone": "+70822270815"}
0005433615829	ED2071	5754 285704	MARIYA POPOVA	{"email": "m-popova_1970@postgrespro.ru", "phone": "+70381029307"}
0005433615830	ED2071	4170 999717	ANNA KOROLEVA	{"email": "koroleva_a051961@postgrespro.ru", "phone": "+70652241189"}
0005433615831	923A19	2781 307036	VASILIY MATVEEV	{"phone": "+70736535188"}
0005433615832	7A0B75	9736 712091	SERGEY PETROV	{"phone": "+70305434811"}
0005433615833	FC1677	1952 214049	VALENTINA KISELEVA	{"email": "v-kiseleva.021963@postgrespro.ru", "phone": "+70641373852"}
0005433615834	F6F2C7	4514 748006	RAMIL FEDOROV	{"email": "ramilfedorov27031961@postgrespro.ru", "phone": "+70859482976"}
0005433615835	8E09BD	8945 256296	NIKOLAY DENISOV	{"phone": "+70502548942"}
0005433615836	0668E9	2551 355915	MATVEY IVANOV	{"phone": "+70368101154"}
0005433615837	188B73	8578 348232	ANDREY ZAKHAROV	{"email": "zakharov-andrey.18121967@postgrespro.ru", "phone": "+70402574199"}
0005433615838	188B73	9130 494146	MARINA PAVLOVA	{"email": "pavlovamarina-21031976@postgrespro.ru", "phone": "+70492339861"}
0005433615839	1049F1	5928 940056	NIKITA VOROBEV	{"email": "vorobevn.11101970@postgrespro.ru", "phone": "+70780664960"}
0005433615840	7D2018	2497 245802	MARIYA TITOVA	{"email": "m.titova-111973@postgrespro.ru", "phone": "+70331010796"}
0005433615841	7D2018	4568 905992	OLGA GUSEVA	{"email": "guseva-olga.011979@postgrespro.ru", "phone": "+70316344897"}
0005433615842	33FB54	2195 385819	IRINA POLYAKOVA	{"phone": "+70139809299"}
0005433615843	C74C3F	2079 488233	NATALIYA ERMAKOVA	{"email": "ermakova_nataliya_14091960@postgrespro.ru", "phone": "+70414763040"}
0005433615844	C74C3F	5489 032690	OLGA NIKIFOROVA	{"phone": "+70910324327"}
0005433615845	283B67	7851 084040	SERGEY NOVIKOV	{"email": "novikovsergey_121973@postgrespro.ru", "phone": "+70887016978"}
0005433615846	23BCCB	3584 984286	DMITRIY SMIRNOV	{"email": "smirnovd_1970@postgrespro.ru", "phone": "+70501508670"}
0005433615847	7B53AC	1997 437853	YULIYA ANTONOVA	{"phone": "+70652797895"}
0005433615848	970773	8864 653009	ANATOLIY ABRAMOV	{"phone": "+70850586496"}
0005433615849	940152	0347 894091	ALEKSANDR VLASOV	{"phone": "+70843126702"}
0005433615850	62D2E8	1528 659104	LYUBOV KUZMINA	{"email": "kuzmina.l.1983@postgrespro.ru", "phone": "+70295655143"}
0005433615851	62D2E8	3269 603525	MARINA KRASNOVA	{"email": "mkrasnova.111970@postgrespro.ru", "phone": "+70343658583"}
0005433615852	FCB617	4475 052957	ALEKSANDRA POPOVA	{"phone": "+70026622252"}
0005433615853	FCB617	4840 041363	SERGEY PETROV	{"phone": "+70000663692"}
0005433615854	8FE91F	4631 485624	ARTEM IVANOV	{"email": "ivanova-031966@postgrespro.ru", "phone": "+70091948405"}
0005433615855	0F9C21	9199 738639	VLADIMIR KOZLOV	{"email": "vladimirkozlov091971@postgrespro.ru", "phone": "+70846253317"}
0005433615856	FABBF8	6555 630455	VALENTINA FILIPPOVA	{"email": "filippova_valentina26121967@postgrespro.ru", "phone": "+70168191600"}
0005433615857	858225	0004 067803	ALEKSANDRA KONOVALOVA	{"email": "aleksandra.konovalova-081979@postgrespro.ru", "phone": "+70141141307"}
0005433615858	858225	5714 516521	LYUDMILA SMIRNOVA	{"phone": "+70867281064"}
0005433615859	F1D614	1568 285723	NATALYA CHERNOVA	{"email": "n_chernova28061981@postgrespro.ru", "phone": "+70925245640"}
0005433615860	7CDA17	1219 969030	LYUBOV AKIMOVA	{"email": "lyubov-akimova-1969@postgrespro.ru", "phone": "+70567410599"}
0005433615861	4B95CD	6204 409885	NIKOLAY ORLOV	{"email": "nikolay-orlov1978@postgrespro.ru", "phone": "+70255993341"}
0005433615862	4B95CD	1695 723192	NIKITA YAKOVLEV	{"email": "yakovlev.n121982@postgrespro.ru", "phone": "+70607738642"}
0005433615863	4B95CD	1665 081544	MARIYA MELNIKOVA	{"phone": "+70468524536"}
0005433615864	67F4EB	3955 309053	NIKOLAY SAVELEV	{"email": "nsavelev.121974@postgrespro.ru", "phone": "+70881841746"}
0005433615865	6EA01D	0042 908117	ALENA TIKHONOVA	{"email": "alena_tikhonova.051975@postgrespro.ru", "phone": "+70345144476"}
0005433615866	37028E	4798 164412	LYUDMILA IVANOVA	{"email": "l.ivanova031974@postgrespro.ru", "phone": "+70250255753"}
0005433615867	0613CE	2821 034464	IRINA KARPOVA	{"phone": "+70917503023"}
0005433615868	0613CE	9739 516386	ELVIRA GORBUNOVA	{"email": "elvira-gorbunova-021972@postgrespro.ru", "phone": "+70541428358"}
0005433615869	177609	2377 595076	LYUDMILA AFANASEVA	{"phone": "+70847918368"}
0005433615870	BE79E5	9051 521709	DMITRIY VASILEV	{"email": "dmitriy-vasilev.1972@postgrespro.ru", "phone": "+70099892176"}
0005433615871	77119F	4747 041140	GALINA LEBEDEVA	{"email": "galina-lebedeva-1972@postgrespro.ru", "phone": "+70879461853"}
0005433615872	577F82	9261 702739	PAVEL KUZNECOV	{"email": "kuznecov.p121977@postgrespro.ru", "phone": "+70793791829"}
0005433615873	E76286	1334 881752	LYUBOV MARTYNOVA	{"email": "l_martynova1962@postgrespro.ru", "phone": "+70402341910"}
0005433615874	DC7577	8459 291033	SERGEY ORLOV	{"phone": "+70893442102"}
0005433615875	DC7577	5241 054646	DMITRIY STEPANOV	{"phone": "+70777344227"}
0005433615876	53C179	4530 276162	ELENA PAVLOVA	{"email": "pavlovaelena-1966@postgrespro.ru", "phone": "+70669372111"}
0005433615877	2A9D3B	9928 704069	DMITRIY DMITRIEV	{"phone": "+70061832112"}
0005433615878	52D960	5442 377975	LYUBOV BELYAEVA	{"email": "lyubovbelyaeva.03121963@postgrespro.ru", "phone": "+70102848686"}
0005433615879	3EEA58	0054 088285	ELVIRA KUZNECOVA	{"phone": "+70904509023"}
0005433615880	411360	3010 719215	TATYANA MALYSHEVA	{"email": "t.malysheva.1981@postgrespro.ru", "phone": "+70273688027"}
0005433615881	ABF87B	7742 925487	KONSTANTIN BORISOV	{"email": "kborisov.26031965@postgrespro.ru", "phone": "+70652199204"}
0005433615882	79D956	7394 338695	OLEG DAVYDOV	{"email": "davydov_oleg-1958@postgrespro.ru", "phone": "+70036239267"}
0005433615883	415C10	9972 424873	NIKITA KOZLOV	{"phone": "+70658683595"}
0005433615884	3C47DB	2993 512916	FAIL MAKAROV	{"email": "makarovfail-1973@postgrespro.ru", "phone": "+70541796319"}
0005433615885	3C47DB	9610 281327	NIKOLAY ILIN	{"email": "n-ilin1966@postgrespro.ru", "phone": "+70280187676"}
0005433615886	89D4C4	1975 665404	ANNA TITOVA	{"phone": "+70360584991"}
0005433615887	487C32	6105 631428	OLGA MOROZOVA	{"phone": "+70013616198"}
0005433615888	63F107	2524 380414	KIRILL MIRONOV	{"email": "kirill-mironov-121963@postgrespro.ru", "phone": "+70364890967"}
0005433615889	CBD336	7112 162220	ROMAN RODIONOV	{"phone": "+70535496646"}
0005433615890	84663D	4139 229054	EVGENIY GUSEV	{"email": "e.gusev-22051972@postgrespro.ru", "phone": "+70861716467"}
0005433615891	84663D	6225 992461	ELENA ZHUKOVA	{"email": "elena_zhukova_06121967@postgrespro.ru", "phone": "+70472326798"}
0005433615892	84663D	7895 462334	KONSTANTIN FEDOROV	{"phone": "+70040075833"}
0005433615893	8E1C47	5038 042586	DENIS KONOVALOV	{"email": "denis_konovalov.02031971@postgrespro.ru", "phone": "+70965691187"}
0005433615894	8E1C47	6301 483421	MARGARITA SIDOROVA	{"email": "margaritasidorova.30121976@postgrespro.ru", "phone": "+70716450129"}
0005433615895	D5DC6D	1864 120582	VALENTINA ALEKSEEVA	{"email": "alekseeva-valentina1979@postgrespro.ru", "phone": "+70617147433"}
0005433615896	D5DC6D	2771 582555	NATALYA FEDOROVA	{"email": "fedorovan.10031980@postgrespro.ru", "phone": "+70955286461"}
0005433615897	E4EE1C	6348 103921	SERGEY SIDOROV	{"email": "s.sidorov_1984@postgrespro.ru", "phone": "+70340389591"}
0005433615898	8577FE	7471 510188	DENIS ISAEV	{"phone": "+70495301484"}
0005433615899	8577FE	4896 963689	NADEZHDA SOROKINA	{"phone": "+70336808857"}
0005433615900	7B91AA	7909 378139	DMITRIY ANTONOV	{"phone": "+70281649246"}
0005433615901	1FE07D	6775 980300	NATALYA ANISIMOVA	{"email": "n.anisimova.1972@postgrespro.ru", "phone": "+70923745476"}
0005433615902	110B19	1915 869573	NADEZHDA PETROVA	{"email": "petrova.n-091984@postgrespro.ru", "phone": "+70708420321"}
0005433615903	110B19	9772 163251	ELENA SOKOLOVA	{"phone": "+70488416291"}
0005433615904	180649	4281 522242	TATYANA BELYAEVA	{"phone": "+70450706827"}
0005433615905	24334A	9418 554943	ANNA AKIMOVA	{"phone": "+70970992172"}
0005433615906	F2ADDB	0101 633245	LEONID VASILEV	{"phone": "+70810684854"}
0005433615907	F2ADDB	0061 390095	ANATOLIY CHERNOV	{"email": "anatoliy_chernov05121967@postgrespro.ru", "phone": "+70898153517"}
0005433615908	5ECE1B	6076 283080	NINA RODIONOVA	{"phone": "+70319384308"}
0005433615909	998600	7552 786803	NINA FROLOVA	{"email": "nina.frolova.18111967@postgrespro.ru", "phone": "+70967613387"}
0005433615910	998600	0790 762379	VLADIMIR PAVLOV	{"phone": "+70505821045"}
0005433615911	F9B3DD	4532 098251	ALEKSANDR KAZAKOV	{"phone": "+70003878268"}
0005433615912	3DAE64	5293 726382	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr_30111961@postgrespro.ru", "phone": "+70761751959"}
0005433615913	C2E5B1	7383 228282	NATALYA STEPANOVA	{"phone": "+70251111673"}
0005433615914	C2E5B1	6674 241758	TAMARA FROLOVA	{"email": "tamara-frolova.101974@postgrespro.ru", "phone": "+70398986654"}
0005433615915	410B42	6538 328723	SERGEY MAKAROV	{"phone": "+70661005923"}
0005433615916	E5362E	7148 141739	SERGEY ISAEV	{"email": "isaevsergey.051980@postgrespro.ru", "phone": "+70812416992"}
0005433615917	F8585F	3812 680217	YURIY AFANASEV	{"phone": "+70917048929"}
0005433615918	F8585F	7421 625396	ALEKSANDR SMIRNOV	{"phone": "+70036683515"}
0005433615919	F8585F	1147 671140	DMITRIY ROMANOV	{"email": "romanov-dmitriy1974@postgrespro.ru", "phone": "+70240675283"}
0005433615920	B22144	8911 050402	ANNA IVANOVA	{"email": "ivanova_anna-19081961@postgrespro.ru", "phone": "+70371960684"}
0005433615921	B22144	6738 569119	ELENA TROFIMOVA	{"email": "trofimova.e_1978@postgrespro.ru", "phone": "+70389976486"}
0005433615922	53225B	3103 680767	ALEKSEY BONDARENKO	{"phone": "+70780743503"}
0005433615923	B862C3	0342 936766	ANATOLIY GUSEV	{"phone": "+70617059895"}
0005433615924	B862C3	6004 794415	ALEKSEY PETROV	{"email": "aleksey.petrov_111978@postgrespro.ru", "phone": "+70471420810"}
0005433615925	B862C3	1766 279817	OLGA KUZNECOVA	{"email": "kuznecovaolga.091981@postgrespro.ru", "phone": "+70363729969"}
0005433615926	D45B44	3782 651915	IRINA ZHURAVLEVA	{"email": "zhuravleva.i.09031961@postgrespro.ru", "phone": "+70051329461"}
0005433615927	D45B44	4352 082440	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev_1978@postgrespro.ru", "phone": "+70301508201"}
0005433615928	527A65	0253 359974	OLGA KONOVALOVA	{"email": "olga-konovalova.1965@postgrespro.ru", "phone": "+70432330038"}
0005433615929	02805E	2861 690437	PRASKOVYA KUDRYASHOVA	{"phone": "+70253401159"}
0005433615930	02805E	5082 928940	ALEKSANDR FOMIN	{"phone": "+70626031649"}
0005433615931	2D2EF4	4732 108337	ALEKSANDR VOLKOV	{"phone": "+70102485657"}
0005433615932	C1E16E	5893 954758	SERGEY GAVRILOV	{"phone": "+70661351642"}
0005433615933	C1E16E	5594 891520	ARKADIY FROLOV	{"email": "a_frolov_1970@postgrespro.ru", "phone": "+70435419739"}
0005433615934	2B3B72	7758 260023	ALEKSANDR PETROV	{"email": "apetrov_071974@postgrespro.ru", "phone": "+70014847083"}
0005433615935	5FA20F	9734 691914	NATALIYA RYABOVA	{"phone": "+70105835242"}
0005433615936	9A29ED	1894 929981	VALENTINA NESTEROVA	{"phone": "+70446277413"}
0005433615937	9A29ED	1452 635496	VERA MARTYNOVA	{"phone": "+70051601545"}
0005433615938	D42EDA	9488 911037	LYUDMILA SCHERBAKOVA	{"phone": "+70995416635"}
0005433615939	A502C2	7800 920847	VIKTOR VASILEV	{"phone": "+70516981475"}
0005433615940	9116EF	1296 175746	MARIYA BARANOVA	{"email": "m_baranova-16011967@postgrespro.ru", "phone": "+70926293241"}
0005433615941	9116EF	3217 751529	ANASTASIYA NIKOLAEVA	{"phone": "+70903020186"}
0005433615942	C73B84	2206 649711	TATYANA ALEKSEEVA	{"email": "alekseeva.t081969@postgrespro.ru", "phone": "+70442625457"}
0005433615943	C73B84	3756 886811	EVGENIY IVANOV	{"phone": "+70070316929"}
0005433615944	9E15EA	3959 611262	VIKTOR GRIGOREV	{"phone": "+70212369988"}
0005433615945	91819A	0756 546573	NIKOLAY ALEKSANDROV	{"email": "n.aleksandrov.1964@postgrespro.ru", "phone": "+70490208439"}
0005433615946	A70B26	3712 534380	VYACHESLAV MEDVEDEV	{"email": "medvedevvyacheslav-1967@postgrespro.ru", "phone": "+70295348647"}
0005433615947	D4EA15	1390 916382	VALENTIN KUZNECOV	{"email": "kuznecov.valentin041968@postgrespro.ru", "phone": "+70378589288"}
0005433615948	838FDF	5830 121469	ELENA KOROLEVA	{"email": "elena_koroleva_19061984@postgrespro.ru", "phone": "+70949389763"}
0005433615949	950897	5376 654094	NIKOLAY FEDOROV	{"phone": "+70677952618"}
0005433615950	CF836D	2745 490538	NIKOLAY DAVYDOV	{"phone": "+70126626631"}
0005433615951	F81E64	9074 809364	ALEKSANDR ALEKSEEV	{"email": "a-alekseev.1973@postgrespro.ru", "phone": "+70108440240"}
0005433615952	FED0C9	6988 901330	STEPAN GRIGOREV	{"phone": "+70386312451"}
0005433615953	F23511	5951 294154	MAKSIM SIDOROV	{"phone": "+70565660009"}
0005433615954	229CBB	8341 117203	GULNARA LEBEDEVA	{"phone": "+70881911923"}
0005433615955	05EDA1	3656 112716	EKATERINA DMITRIEVA	{"phone": "+70822021525"}
0005433615956	05EDA1	9145 671237	ALEKSANDR FEDOROV	{"email": "afedorov08011979@postgrespro.ru", "phone": "+70195132419"}
0005433615957	05EDA1	5698 331395	SERGEY SOKOLOV	{"phone": "+70131126211"}
0005433615958	82EF9C	3322 730700	ANATOLIY ABRAMOV	{"email": "a_abramov_1978@postgrespro.ru", "phone": "+70097964699"}
0005433615959	AC04FD	5940 399001	ARINA FILIPPOVA	{"email": "filippova_a.111977@postgrespro.ru", "phone": "+70285641709"}
0005433615960	148D98	6920 779988	VYACHESLAV SOROKIN	{"phone": "+70191822031"}
0005433615961	29F517	2984 875923	NINA BORISOVA	{"email": "borisova_nina091967@postgrespro.ru", "phone": "+70470404170"}
0005433615962	6238CF	9952 907661	VASILIY KAZAKOV	{"phone": "+70313546640"}
0005433615963	6238CF	1244 780747	ILYA PETROV	{"phone": "+70595990234"}
0005433615964	D18A19	6596 748174	VERA KOROLEVA	{"phone": "+70026329201"}
0005433615965	D18A19	6272 835627	NIKOLAY VOLKOV	{"email": "volkov-n061966@postgrespro.ru", "phone": "+70176738691"}
0005433615966	D18A19	6862 441738	ALFIYA MELNIKOVA	{"email": "a.melnikova_1971@postgrespro.ru", "phone": "+70301633947"}
0005433615967	AF7B90	3741 964262	MIKHAIL MOROZOV	{"email": "morozov-m-1960@postgrespro.ru", "phone": "+70336234877"}
0005433615968	9B65FC	1087 271774	NINA KUZNECOVA	{"phone": "+70587669895"}
0005433615969	9B65FC	0277 506546	NIKOLAY KUDRYASHOV	{"email": "kudryashovnikolay011978@postgrespro.ru", "phone": "+70882790682"}
0005433615970	016D05	4768 821611	TATYANA ZAYCEVA	{"email": "t_zayceva031980@postgrespro.ru", "phone": "+70793582299"}
0005433615971	F6BFBC	0211 021966	YURIY NIKOLAEV	{"email": "nikolaevyuriy_04091975@postgrespro.ru", "phone": "+70993568777"}
0005433615972	F6BFBC	2211 562417	FARID MAKAROV	{"email": "f_makarov_1972@postgrespro.ru", "phone": "+70088082871"}
0005433615973	F6BFBC	2396 372035	ALEKSEY PETROV	{"phone": "+70356982168"}
0005433615974	551E02	1367 828845	NATALYA KARPOVA	{"email": "karpovanatalya1961@postgrespro.ru", "phone": "+70323247294"}
0005433615975	6C9A17	9368 931487	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov.vyacheslav-111966@postgrespro.ru", "phone": "+70231792067"}
0005433615976	C5FA56	7905 187670	IRINA KOZLOVA	{"phone": "+70279946544"}
0005433615977	709C3B	4482 688871	VALENTINA TIMOFEEVA	{"email": "timofeevavalentina.111970@postgrespro.ru", "phone": "+70102595809"}
0005433615978	709C3B	5567 810385	RAISA PETROVA	{"email": "petrova-r.07051977@postgrespro.ru", "phone": "+70016423463"}
0005433615979	9BD168	3112 516631	YURIY KUZMIN	{"email": "kuzminy_16071967@postgrespro.ru", "phone": "+70091102610"}
0005433615980	580EDC	0417 451818	KSENIYA MAKSIMOVA	{"phone": "+70347331122"}
0005433615981	9B20C1	1099 974298	ANNA POTAPOVA	{"phone": "+70375715328"}
0005433615982	622DBC	6707 593835	ELIZAVETA YUDINA	{"phone": "+70969664175"}
0005433615983	A6A986	7304 419256	ANDREY ALEKSANDROV	{"email": "andreyaleksandrov-071978@postgrespro.ru", "phone": "+70190110684"}
0005433615984	A6A986	2208 424969	LYUDMILA LOGINOVA	{"phone": "+70378973074"}
0005433615985	31016F	5337 565527	MARIYA KUZNECOVA	{"phone": "+70483344767"}
0005433615986	547C11	4022 128474	ANDREY SERGEEV	{"email": "sergeev.andrey07111966@postgrespro.ru", "phone": "+70480118548"}
0005433615987	F51CAF	2531 323988	ALINA GRISHINA	{"email": "grishina-a_071976@postgrespro.ru", "phone": "+70863221309"}
0005433615988	3CCB2D	3452 289935	ARTEM KISELEV	{"phone": "+70886402686"}
0005433615989	5D94CF	9010 529692	ZLATA KALININA	{"phone": "+70201790462"}
0005433615990	6BCD01	4590 648915	NAIL SMIRNOV	{"phone": "+70364168961"}
0005433616102	0816D0	4125 034609	ALINA GAVRILOVA	{"phone": "+70478867308"}
0005433615991	6BCD01	6634 851539	TATYANA SMIRNOVA	{"email": "smirnova.t-1965@postgrespro.ru", "phone": "+70699056523"}
0005433615992	3EBD48	8823 781689	SERGEY VASILEV	{"phone": "+70094613648"}
0005433615993	3EBD48	8371 401824	YULIYA KRASNOVA	{"phone": "+70997203900"}
0005433615994	6CC44F	8703 007196	DENIS KUZNECOV	{"email": "deniskuznecov_1967@postgrespro.ru", "phone": "+70799389804"}
0005433615995	6CC44F	6926 216814	VIKTOR KRASNOV	{"phone": "+70780011190"}
0005433615996	3EFE59	4899 834439	VIKTOR MOROZOV	{"phone": "+70894426088"}
0005433615997	AA1886	8881 742669	ELENA ANDREEVA	{"phone": "+70971303011"}
0005433615998	82ED82	2984 345122	LYUBOV MAKAROVA	{"email": "makarovalyubov_1981@postgrespro.ru", "phone": "+70293453676"}
0005433615999	355B79	9880 977361	ALEKSANDR BARANOV	{"email": "abaranov-1969@postgrespro.ru", "phone": "+70203146475"}
0005433616000	D98101	9751 133028	ANATOLIY FROLOV	{"email": "frolov_a.121971@postgrespro.ru", "phone": "+70836897525"}
0005433616001	806BD4	8114 260551	IGOR ZAKHAROV	{"phone": "+70963031764"}
0005433616002	C552DB	0197 276358	NADEZHDA NOVIKOVA	{"phone": "+70643825644"}
0005433616003	D3FD73	9403 520838	VALENTINA IVANOVA	{"email": "valentina.ivanova.1983@postgrespro.ru", "phone": "+70887673980"}
0005433616004	D3FD73	7698 149591	TATYANA OSIPOVA	{"email": "tatyana.osipova_121967@postgrespro.ru", "phone": "+70786211532"}
0005433616005	7451FB	6321 238361	MARTA VASILEVA	{"email": "vasileva.m.1966@postgrespro.ru", "phone": "+70298893835"}
0005433616006	8F4958	3025 532546	MARIYA NIKITINA	{"email": "m-nikitina-1974@postgrespro.ru", "phone": "+70763743233"}
0005433616007	972C0C	3422 951543	SVETLANA ILINA	{"phone": "+70310146930"}
0005433616008	972C0C	5994 451356	ELENA PAVLOVA	{"phone": "+70161312402"}
0005433616009	972C0C	6701 936344	MARIYA SMIRNOVA	{"phone": "+70619405030"}
0005433616010	D1B58A	7300 313416	GALINA VOLKOVA	{"email": "g-volkova.101963@postgrespro.ru", "phone": "+70069784717"}
0005433616011	77DD58	1992 254226	VITALIY ROMANOV	{"email": "romanov.vitaliy.031974@postgrespro.ru", "phone": "+70319717637"}
0005433616012	77DD58	8840 517869	SERGEY SERGEEV	{"phone": "+70786141710"}
0005433616013	77DD58	4227 631654	OLGA POPOVA	{"email": "olga-popova111967@postgrespro.ru", "phone": "+70908530243"}
0005433616014	DF7B7C	9560 942019	LIDIYA BOGDANOVA	{"email": "bogdanoval1982@postgrespro.ru", "phone": "+70328862638"}
0005433616015	BAEA07	9938 474149	VLADIMIR IVANOV	{"email": "vivanov101973@postgrespro.ru", "phone": "+70528255577"}
0005433616016	CABF0A	5468 348458	LYUBOV SERGEEVA	{"email": "lyubov-sergeeva.1978@postgrespro.ru", "phone": "+70396772550"}
0005433616017	CABF0A	8368 003015	ZHANNA KOMAROVA	{"phone": "+70005848683"}
0005433616018	56FDE3	0865 818252	PAVEL NIKOLAEV	{"phone": "+70591854230"}
0005433616019	56FDE3	3814 994552	VERA MELNIKOVA	{"email": "veramelnikova1967@postgrespro.ru", "phone": "+70836112289"}
0005433616020	36C7EC	0852 814014	SERGEY PAVLOV	{"email": "s_pavlov.19061966@postgrespro.ru", "phone": "+70075862876"}
0005433616021	976EDB	8434 533929	VLADIMIR VASILEV	{"phone": "+70551508366"}
0005433616022	976EDB	8546 933330	SVETLANA TROFIMOVA	{"phone": "+70125841679"}
0005433616023	976EDB	0946 018987	GALINA VLASOVA	{"email": "vlasovag.111974@postgrespro.ru", "phone": "+70376219610"}
0005433616024	EF4AE3	3005 009257	SERGEY MIKHAYLOV	{"email": "mikhaylov.s-1974@postgrespro.ru", "phone": "+70008614758"}
0005433616025	57603E	9828 398300	ANASTASIYA VOROBEVA	{"phone": "+70433628319"}
0005433616026	DF3C96	0124 612624	YURIY KUDRYASHOV	{"email": "y_kudryashov1971@postgrespro.ru", "phone": "+70750625114"}
0005433616027	0E9F83	6666 021463	NATALYA POLYAKOVA	{"email": "polyakovanatalya01071972@postgrespro.ru", "phone": "+70691838059"}
0005433616028	5A41E4	3043 076664	VALENTINA SOLOVEVA	{"phone": "+70065010865"}
0005433616029	6078D8	1745 706440	ALEKSANDR IVANOV	{"phone": "+70247040955"}
0005433616030	2A5C7F	8830 223140	ALEKSANDR YAKOVLEV	{"phone": "+70270067421"}
0005433616031	9E1A3D	0174 039062	VYACHESLAV TIKHONOV	{"email": "vyacheslav.tikhonov-1970@postgrespro.ru", "phone": "+70944132496"}
0005433616032	9E1A3D	7860 327851	MIKHAIL POPOV	{"phone": "+70104552128"}
0005433616033	18453C	4743 692159	MARINA NESTEROVA	{"phone": "+70341898245"}
0005433616034	18453C	4618 420239	ILYA TARASOV	{"email": "i_tarasov_011964@postgrespro.ru", "phone": "+70273902747"}
0005433616035	4B2992	9152 671346	ELVIRA CHERNOVA	{"email": "chernovaelvira_021982@postgrespro.ru", "phone": "+70482341952"}
0005433616036	C08733	6579 434267	TATYANA SOLOVEVA	{"email": "soloveva_tatyana1970@postgrespro.ru", "phone": "+70554606123"}
0005433616037	C08733	2401 311133	GERMAN KUDRYASHOV	{"email": "german.kudryashov.1973@postgrespro.ru", "phone": "+70395116728"}
0005433616038	C08733	9986 871471	DMITRIY BARANOV	{"phone": "+70100181860"}
0005433616039	892986	6366 679295	VIKTORIYA SOLOVEVA	{"email": "vsoloveva051971@postgrespro.ru", "phone": "+70162148344"}
0005433616040	60C2C8	7284 598024	DANIIL MAKSIMOV	{"email": "d_maksimov.27091972@postgrespro.ru", "phone": "+70922626494"}
0005433616041	EB442A	5031 873530	VYACHESLAV GORBUNOV	{"email": "v_gorbunov-1964@postgrespro.ru", "phone": "+70234659203"}
0005433616042	0F77CA	6326 886372	NIKOLAY PAVLOV	{"phone": "+70175591597"}
0005433616043	A042CB	6975 382026	EVGENIY BELOV	{"phone": "+70918177891"}
0005433616044	A042CB	3894 951749	YULIYA BELOVA	{"email": "ybelova_1970@postgrespro.ru", "phone": "+70640800953"}
0005433616045	4A9E01	3811 620379	MARAT VASILEV	{"phone": "+70156820959"}
0005433616046	4A9E01	2815 042244	VIKTOR PETROV	{"phone": "+70507990677"}
0005433616047	736846	1082 808733	LARISA DAVYDOVA	{"email": "davydovalarisa.091964@postgrespro.ru", "phone": "+70761861933"}
0005433616048	B01245	3085 599035	VALENTINA KOZLOVA	{"email": "kozlova.v_1969@postgrespro.ru", "phone": "+70707408505"}
0005433616049	B01245	5091 614788	RAISA BORISOVA	{"email": "borisova.r-051969@postgrespro.ru", "phone": "+70653097160"}
0005433616050	78166B	9753 191763	ARTUR MAKAROV	{"email": "arturmakarov_1987@postgrespro.ru", "phone": "+70313177480"}
0005433616051	B183AB	5979 153367	SERGEY SMIRNOV	{"phone": "+70180683946"}
0005433616052	9136CF	9694 531166	ANNA PETROVA	{"email": "a.petrova.07031974@postgrespro.ru", "phone": "+70662315782"}
0005433616053	AA93B1	5998 329172	ANGELINA ANDREEVA	{"email": "aandreeva-31051978@postgrespro.ru", "phone": "+70656424763"}
0005433616054	22E970	8434 371367	IVAN FEDOROV	{"email": "ivan_fedorov.1981@postgrespro.ru", "phone": "+70400790920"}
0005433616055	E752E4	0074 138013	DMITRIY MIRONOV	{"email": "d-mironov-071974@postgrespro.ru", "phone": "+70532959742"}
0005433616056	0F038B	6148 929253	TATYANA BELOVA	{"phone": "+70083867147"}
0005433616057	741FDF	7254 750682	MARINA KRASNOVA	{"phone": "+70974885459"}
0005433616058	D19D93	7382 614618	ALISA POPOVA	{"phone": "+70236014275"}
0005433616059	619A93	6303 576141	ZOYA LEBEDEVA	{"phone": "+70234191071"}
0005433616060	619A93	6167 769242	MAKSIM SAVELEV	{"email": "maksim-savelev1968@postgrespro.ru", "phone": "+70676405413"}
0005433616061	7F0C22	8763 698563	SAMIRA GORBUNOVA	{"email": "s_gorbunova_30011970@postgrespro.ru", "phone": "+70681780848"}
0005433616062	838230	3137 383134	KIRILL SMIRNOV	{"phone": "+70768082884"}
0005433616063	838230	6681 008411	IRINA GAVRILOVA	{"email": "i-gavrilova.26011973@postgrespro.ru", "phone": "+70715967924"}
0005433616064	CA4297	0971 411741	VALENTINA VOLKOVA	{"phone": "+70833172941"}
0005433616065	FFA01D	6103 116292	INNA MELNIKOVA	{"email": "inna_melnikova_24071976@postgrespro.ru", "phone": "+70844652514"}
0005433616066	FFA01D	9442 479575	ALEKSANDR FOMIN	{"email": "fomin-a_091968@postgrespro.ru", "phone": "+70702614293"}
0005433616067	9C59DD	9347 043356	DARYA NIKOLAEVA	{"email": "d.nikolaeva.081976@postgrespro.ru", "phone": "+70898609556"}
0005433616068	9C59DD	3312 381321	SVETLANA MALYSHEVA	{"email": "malysheva-s101977@postgrespro.ru", "phone": "+70434191882"}
0005433616069	7FDA93	7431 090175	DARYA MAKAROVA	{"email": "makarova-d.22071962@postgrespro.ru", "phone": "+70151502185"}
0005433616070	4E6176	1146 995064	VALERIY KUZMIN	{"email": "kuzmin-valeriy121969@postgrespro.ru", "phone": "+70668030417"}
0005433616071	98DA39	7683 909052	SERGEY SMIRNOV	{"email": "smirnov.sergey.1964@postgrespro.ru", "phone": "+70716250510"}
0005433616072	F7D7D7	3317 354909	VALENTINA FOMINA	{"phone": "+70178600533"}
0005433616073	F7D7D7	8906 239123	KLAVDIYA KISELEVA	{"email": "kiselevaklavdiya111970@postgrespro.ru", "phone": "+70671254184"}
0005433616074	54B3E8	7116 122424	SERGEY SOLOVEV	{"phone": "+70759080314"}
0005433616075	53E358	8299 749331	VALERIY STEPANOV	{"phone": "+70381376597"}
0005433616076	53E358	6169 028480	TAISIYA STEPANOVA	{"email": "stepanova_taisiya18021973@postgrespro.ru", "phone": "+70396573163"}
0005433616077	3C5670	4042 749889	ALEKSEY ZHUKOV	{"email": "zhukov.a-22051967@postgrespro.ru", "phone": "+70237530564"}
0005433616078	3C5670	3475 820249	TATYANA GAVRILOVA	{"email": "tatyana-gavrilova-24071978@postgrespro.ru", "phone": "+70825886127"}
0005433616079	71910F	8595 545450	VITALIY PAVLOV	{"email": "pavlov_v.1976@postgrespro.ru", "phone": "+70403585656"}
0005433616080	37DF93	6360 370491	ANATOLIY PAVLOV	{"email": "pavlovanatoliy.17121976@postgrespro.ru", "phone": "+70307530162"}
0005433616081	05606D	2347 035729	OLGA VASILEVA	{"email": "olga_vasileva1973@postgrespro.ru", "phone": "+70172463904"}
0005433616082	05606D	2723 040827	NIKOLAY SIDOROV	{"phone": "+70409784580"}
0005433616083	27066D	2804 356833	TATYANA FEDOROVA	{"phone": "+70981256320"}
0005433616084	27066D	2831 945057	ASKAR KONOVALOV	{"phone": "+70342251148"}
0005433616085	051A75	9796 194143	ALEKSANDR KUZNECOV	{"phone": "+70841887904"}
0005433616086	364520	5616 414210	SOFIYA MOISEEVA	{"email": "s_moiseeva.02101971@postgrespro.ru", "phone": "+70453413285"}
0005433616087	8425FA	4885 907096	IVAN KUZNECOV	{"email": "kuznecovivan-03051982@postgrespro.ru", "phone": "+70048252411"}
0005433616088	ACEEC5	2403 929515	GALINA PETROVA	{"phone": "+70360849842"}
0005433616089	ACEEC5	6969 599659	GALINA ROMANOVA	{"email": "romanova_galina1964@postgrespro.ru", "phone": "+70747729833"}
0005433616090	496CFA	8126 408965	SVETLANA IVANOVA	{"email": "ivanova_s.14111977@postgrespro.ru", "phone": "+70240075405"}
0005433616091	496CFA	0911 115023	MAKSIM KULIKOV	{"email": "maksimkulikov081978@postgrespro.ru", "phone": "+70410980022"}
0005433616092	BF8C32	7929 261337	EVGENIYA KOZLOVA	{"email": "evgeniyakozlova-091979@postgrespro.ru", "phone": "+70444300493"}
0005433616093	103DCC	8344 024666	RUSTAM ANDREEV	{"email": "andreev_r-011988@postgrespro.ru", "phone": "+70934708330"}
0005433616094	25B0BF	3688 301152	ALEKSEY KUZNECOV	{"email": "akuznecov-121969@postgrespro.ru", "phone": "+70501818358"}
0005433616095	25B0BF	6696 855436	TATYANA BARANOVA	{"phone": "+70028899208"}
0005433616096	B5BC68	0119 590280	MARIYA ALEKSANDROVA	{"phone": "+70868669390"}
0005433616097	27599C	1354 641290	IGOR DMITRIEV	{"email": "igordmitriev_031971@postgrespro.ru", "phone": "+70225273990"}
0005433616098	27599C	5812 975007	VALERIY SAVELEV	{"email": "savelev-v_1968@postgrespro.ru", "phone": "+70746210976"}
0005433616099	27599C	6481 066361	YURIY BONDARENKO	{"phone": "+70937031122"}
0005433616100	92DBF8	5579 948321	ALEKSANDRA LAZAREVA	{"email": "lazareva-aleksandra_07051974@postgrespro.ru", "phone": "+70750944855"}
0005433616101	92DBF8	6780 140495	TAISIYA BARANOVA	{"email": "tbaranova_101977@postgrespro.ru", "phone": "+70016194390"}
0005433616103	27194E	1257 951357	RIMMA NOVIKOVA	{"email": "rimma.novikova081978@postgrespro.ru", "phone": "+70737186729"}
0005433616104	12D025	1628 972384	ANDREY ZHUKOV	{"phone": "+70683090787"}
0005433616105	12D025	6973 527595	ELENA DAVYDOVA	{"phone": "+70161439695"}
0005433616106	BEB550	1828 159065	MIKHAIL KISELEV	{"phone": "+70737705571"}
0005433616107	BEB550	0380 432716	RAISA FROLOVA	{"email": "frolovar1979@postgrespro.ru", "phone": "+70268828289"}
0005433616108	E933E7	7581 084400	YURIY SOKOLOV	{"phone": "+70158042332"}
0005433616109	E5B5AA	8789 655805	NIKOLAY VASILEV	{"email": "nikolay-vasilev-19031963@postgrespro.ru", "phone": "+70225246778"}
0005433616110	11FF19	3914 570789	TATYANA FEDOROVA	{"email": "fedorovat-031971@postgrespro.ru", "phone": "+70487614217"}
0005433616111	11FF19	6561 507497	IGOR KUDRYASHOV	{"phone": "+70121960575"}
0005433616112	458197	6208 488741	DMITRIY BORISOV	{"email": "dmitriy.borisov-14031963@postgrespro.ru", "phone": "+70859302470"}
0005433616113	8CACFB	0238 319479	VLADIMIR GAVRILOV	{"phone": "+70712157601"}
0005433616114	FBAD47	1462 002954	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay011972@postgrespro.ru", "phone": "+70289058412"}
0005433616115	793B2D	6282 224278	OLGA MOISEEVA	{"email": "moiseeva-o_06111974@postgrespro.ru", "phone": "+70462178679"}
0005433616116	793B2D	6180 579428	VIKTOR PAVLOV	{"email": "v.pavlov.1971@postgrespro.ru", "phone": "+70720171334"}
0005433616117	E4C393	5703 787698	VALERIY KUZMIN	{"phone": "+70843284118"}
0005433616118	E4C393	4173 360825	YULIYA SMIRNOVA	{"phone": "+70649951032"}
0005433616119	E4C393	5878 287341	SERGEY BORISOV	{"email": "sergeyborisov_14071977@postgrespro.ru", "phone": "+70978923021"}
0005433616120	C688D5	0468 849121	TAISIYA IVANOVA	{"phone": "+70645559600"}
0005433616121	C688D5	2887 595913	MIKHAIL NAZAROV	{"email": "mnazarov-16051967@postgrespro.ru", "phone": "+70939683178"}
0005433616122	6C4B02	2652 915400	EKATERINA NOVIKOVA	{"email": "enovikova_071972@postgrespro.ru", "phone": "+70354995280"}
0005433616123	6C4B02	9892 166869	MATRENA GUSEVA	{"phone": "+70223020385"}
0005433616124	9D60A2	5562 446683	YANA OVCHINNIKOVA	{"email": "y_ovchinnikova_22121979@postgrespro.ru", "phone": "+70173881026"}
0005433616125	EF5F6C	8646 018254	YULIYA PAVLOVA	{"phone": "+70626447140"}
0005433616126	9E62A4	2790 504757	IRINA NESTEROVA	{"phone": "+70430678341"}
0005433616127	9E62A4	6865 216278	ANDREY VOROBEV	{"email": "andrey.vorobev.1975@postgrespro.ru", "phone": "+70499443878"}
0005433616128	05C49B	0630 736982	SERGEY SCHERBAKOV	{"phone": "+70700449419"}
0005433616129	05C49B	7353 693121	VIKTOR SMIRNOV	{"email": "smirnovv.061965@postgrespro.ru", "phone": "+70001899857"}
0005433616130	27C33A	6237 414652	ANASTASIYA SMIRNOVA	{"email": "anastasiya_smirnova22111974@postgrespro.ru", "phone": "+70352347414"}
0005433616131	27C33A	8235 180232	ANNA KOVALEVA	{"email": "kovaleva.anna.021958@postgrespro.ru", "phone": "+70432547705"}
0005433616132	27C33A	2097 377150	DARYA DENISOVA	{"phone": "+70891915890"}
0005433616133	B6BA25	7770 486018	ALEKSEY TIKHONOV	{"email": "a_tikhonov.081972@postgrespro.ru", "phone": "+70238294364"}
0005433616134	B6BA25	3572 025864	SVETLANA MAKSIMOVA	{"phone": "+70547192822"}
0005433616135	CC6535	9741 209668	ANATOLIY NIKOLAEV	{"email": "nikolaev_anatoliy-051981@postgrespro.ru", "phone": "+70387438478"}
0005433616136	65227B	7457 026976	ANDREY GERASIMOV	{"email": "andrey-gerasimov1967@postgrespro.ru", "phone": "+70300140413"}
0005433616137	7308E4	5114 143241	ELENA MIKHAYLOVA	{"phone": "+70663719027"}
0005433616138	5EDA00	0374 288902	IRINA KONDRATEVA	{"phone": "+70549530924"}
0005433616139	228586	7566 337871	NIKOLAY SEMENOV	{"phone": "+70140562122"}
0005433616140	D3D6A4	1094 108462	RAISA IVANOVA	{"email": "ivanovar-041982@postgrespro.ru", "phone": "+70557146723"}
0005433616141	2DE938	7069 096955	MARINA ERMAKOVA	{"email": "m.ermakova.26121969@postgrespro.ru", "phone": "+70333112876"}
0005433616142	5B5258	3505 387475	DARYA FEDOROVA	{"email": "fedorovadarya.031975@postgrespro.ru", "phone": "+70278140515"}
0005433616143	5B5258	0753 951411	KSENIYA IVANOVA	{"email": "kivanova021973@postgrespro.ru", "phone": "+70498837821"}
0005433616144	85987F	9168 803134	MARIYA NAZAROVA	{"phone": "+70889445608"}
0005433616145	315D6F	7166 149561	ANATOLIY ALEKSEEV	{"phone": "+70175901117"}
0005433616146	315D6F	0934 593807	DARYA TIMOFEEVA	{"email": "timofeeva_d-1980@postgrespro.ru", "phone": "+70787728148"}
0005433616147	A85453	0458 049165	LIDIYA SERGEEVA	{"phone": "+70518682902"}
0005433616148	23C132	5948 988352	VYACHESLAV MIRONOV	{"email": "v-mironov_15071967@postgrespro.ru", "phone": "+70949028400"}
0005433616149	687859	8522 909883	TATYANA ARKHIPOVA	{"email": "t-arkhipova_081990@postgrespro.ru", "phone": "+70562483081"}
0005433616150	2186C3	3431 660886	ANDREY DENISOV	{"email": "andrey-denisov_1992@postgrespro.ru", "phone": "+70065198960"}
0005433616151	3CFAC8	2976 352029	IRINA YUDINA	{"phone": "+70492337055"}
0005433616152	3CFAC8	5751 988728	PELAGEYA EFREMOVA	{"email": "pefremova.16031958@postgrespro.ru", "phone": "+70547422841"}
0005433616153	200AE9	0690 426937	IGOR SERGEEV	{"email": "sergeev.igor121983@postgrespro.ru", "phone": "+70193616030"}
0005433616154	D0F72C	2272 737543	OLGA SOLOVEVA	{"phone": "+70924012844"}
0005433616155	4B21EE	2161 506916	YULIYA FADEEVA	{"email": "y-fadeeva_1978@postgrespro.ru", "phone": "+70986260039"}
0005433616156	6A227A	1293 483301	SERGEY KRASNOV	{"email": "sergey-krasnov04111975@postgrespro.ru", "phone": "+70240252955"}
0005433616157	F8A4EA	6150 218075	ALEKSANDR ZHUKOV	{"phone": "+70272005575"}
0005433616158	DA3561	9782 262306	VALERIYA LUKYANOVA	{"email": "valeriya_lukyanova25011961@postgrespro.ru", "phone": "+70956703509"}
0005433616159	DA3561	3122 733844	GEORGIY TIMOFEEV	{"email": "timofeev_georgiy_1981@postgrespro.ru", "phone": "+70531836995"}
0005433616160	C9BFF8	7467 260985	ALEKSEY CHERNOV	{"email": "alekseychernov-071974@postgrespro.ru", "phone": "+70346742479"}
0005433616161	AD24C3	2690 491603	OLGA FADEEVA	{"email": "olga.fadeeva-1967@postgrespro.ru", "phone": "+70173680336"}
0005433616162	AD24C3	4216 025390	NIKOLAY KOZLOV	{"phone": "+70963232338"}
0005433616163	AD24C3	3894 909643	LYUDMILA POLYAKOVA	{"email": "l.polyakova.14111969@postgrespro.ru", "phone": "+70419102714"}
0005433616164	0575EF	9181 503294	VASILIY PAVLOV	{"phone": "+70676750245"}
0005433616165	7A6F88	5286 992375	VADIM SOKOLOV	{"phone": "+70758330406"}
0005433616166	4E379A	2516 131445	IRAIDA GAVRILOVA	{"phone": "+70294956078"}
0005433616167	71E6BD	2939 239242	SERGEY FEDOROV	{"email": "sergey.fedorov101969@postgrespro.ru", "phone": "+70325271382"}
0005433616168	399089	4513 562602	VIKTOR SOLOVEV	{"email": "viktorsolovev19021967@postgrespro.ru", "phone": "+70271696743"}
0005433616169	1E2693	6537 251336	LYUBOV FILATOVA	{"email": "lyubov.filatova11101975@postgrespro.ru", "phone": "+70956700329"}
0005433616170	7A853B	8650 719587	OLGA ROMANOVA	{"email": "romanova_o_031973@postgrespro.ru", "phone": "+70261000220"}
0005433616171	A86383	6340 570439	SERGEY IVANOV	{"phone": "+70918105055"}
0005433616172	A86383	6120 352233	ANATOLIY DENISOV	{"email": "anatoliy-denisov1966@postgrespro.ru", "phone": "+70123169484"}
0005433616173	91EC8B	6375 135126	IVAN FEDOTOV	{"phone": "+70349401679"}
0005433616174	85BEA6	8768 611578	VITALIY FEDOROV	{"email": "v.fedorov_071965@postgrespro.ru", "phone": "+70667788799"}
0005433616175	931B9F	6516 880328	SERGEY OSIPOV	{"phone": "+70047740040"}
0005433616176	3A7331	4122 536755	LIDIYA KOROLEVA	{"email": "lidiya_koroleva.091969@postgrespro.ru", "phone": "+70939133340"}
0005433616177	137845	4429 277796	YANA KOZLOVA	{"phone": "+70398709604"}
0005433616178	137845	4911 310368	KONSTANTIN TIKHONOV	{"phone": "+70276798330"}
0005433616179	9A03EB	5991 885617	VIKTOR NAZAROV	{"email": "viktor.nazarov091961@postgrespro.ru", "phone": "+70241153745"}
0005433616180	683D09	7324 106856	ANASTASIYA SOROKINA	{"email": "sorokina.anastasiya.17041980@postgrespro.ru", "phone": "+70762756804"}
0005433616181	E0F7A7	1229 994528	EVGENIY VOROBEV	{"phone": "+70651302699"}
0005433616182	ED200D	1204 444962	ALEKSANDR ANDREEV	{"phone": "+70108971038"}
0005433616183	1166CB	9144 998264	MIKHAIL KULIKOV	{"phone": "+70138545922"}
0005433616184	CD629D	8568 550163	VALENTINA ANTONOVA	{"phone": "+70118580329"}
0005433616185	5AFB85	1216 512298	VLADIMIR ANTONOV	{"email": "antonov_vladimir31121984@postgrespro.ru", "phone": "+70300512485"}
0005433616186	944232	0846 267453	SERGEY MOROZOV	{"phone": "+70144658365"}
0005433616187	A16F72	2267 673417	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova.1970@postgrespro.ru", "phone": "+70812864629"}
0005433616188	A16F72	5780 102388	VALENTINA POTAPOVA	{"email": "potapova.v-081968@postgrespro.ru", "phone": "+70018791607"}
0005433616189	181823	3195 523313	SVETLANA SAVELEVA	{"phone": "+70443325561"}
0005433616190	AFF57A	9204 099341	ANTON FOMIN	{"email": "a-fomin-051971@postgrespro.ru", "phone": "+70984697257"}
0005433616191	AFF57A	6393 332413	ANASTASIYA KUZNECOVA	{"phone": "+70988208981"}
0005433616192	C5D2C0	6409 770556	SANIYA DAVYDOVA	{"email": "s-davydova_09111973@postgrespro.ru", "phone": "+70587547572"}
0005433616193	5F348C	8707 860383	TATYANA DMITRIEVA	{"phone": "+70913021223"}
0005433616194	C48436	5363 735389	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov1958@postgrespro.ru", "phone": "+70277439814"}
0005433616195	C48436	6106 020691	ALEKSANDRA NOVIKOVA	{"email": "novikova_aleksandra041973@postgrespro.ru", "phone": "+70557096064"}
0005433616196	CA6CE2	8382 054181	MIKHAIL RODIONOV	{"phone": "+70289927935"}
0005433616197	71A493	3043 583984	MIKHAIL TIMOFEEV	{"email": "timofeev.mikhail-1963@postgrespro.ru", "phone": "+70958066158"}
0005433616198	70B5C4	6797 557642	KRISTINA KULIKOVA	{"email": "kristina.kulikova-1969@postgrespro.ru", "phone": "+70562416399"}
0005433616199	6D9C51	7020 845597	VIKTOR BONDARENKO	{"phone": "+70488243291"}
0005433616200	5A9D1E	4543 757043	DMITRIY KULIKOV	{"phone": "+70367089773"}
0005433616201	5A9D1E	4846 637481	VLADIMIR ISAEV	{"phone": "+70390144505"}
0005433616202	230BAB	6430 685288	VALENTINA SEMENOVA	{"phone": "+70844662732"}
0005433616203	5D93FD	4717 137073	YULIYA ANDREEVA	{"email": "andreeva_y.04061971@postgrespro.ru", "phone": "+70687350687"}
0005433616204	F97BC0	9284 148729	ANDREY FEDOROV	{"phone": "+70122306354"}
0005433616205	7148ED	6153 606027	SERGEY VOROBEV	{"phone": "+70841912798"}
0005433616206	7148ED	4005 453087	OLGA EGOROVA	{"phone": "+70847714174"}
0005433616207	FDE027	3513 681059	TATYANA BARANOVA	{"phone": "+70689201433"}
0005433616208	A1D825	1576 871074	EVA IVANOVA	{"phone": "+70258712041"}
0005433616209	BFA658	8353 778989	DAMIR SCHERBAKOV	{"phone": "+70378868519"}
0005433616210	F498F7	0681 970315	ZINAIDA NAUMOVA	{"phone": "+70618481720"}
0005433616211	F498F7	2165 795463	ALEKSEY TIKHONOV	{"email": "tikhonovaleksey.1977@postgrespro.ru", "phone": "+70639851051"}
0005433616212	779B48	5625 513033	ALEKSANDR OSIPOV	{"phone": "+70096833965"}
0005433616213	3F709D	4196 894268	VLADIMIR RODIONOV	{"email": "rodionov-v.1966@postgrespro.ru", "phone": "+70224929595"}
0005433616214	3F709D	5512 781141	KRISTINA POPOVA	{"email": "popova-k.1974@postgrespro.ru", "phone": "+70022827748"}
0005433616382	E59476	1311 455338	VLADIMIR ROMANOV	{"phone": "+70145008659"}
0005433616215	7D1C46	8098 131237	VIKTOR MOISEEV	{"email": "viktor-moiseev_091971@postgrespro.ru", "phone": "+70597247120"}
0005433616216	7D1C46	6224 419593	IVAN SMIRNOV	{"email": "smirnov_i1983@postgrespro.ru", "phone": "+70892968136"}
0005433616217	D513A2	3282 819020	ELENA LAZAREVA	{"email": "elenalazareva-24021971@postgrespro.ru", "phone": "+70886902941"}
0005433616218	D513A2	7543 673129	TAMARA FILIPPOVA	{"phone": "+70051801614"}
0005433616219	87F259	5750 072051	IRINA IVANOVA	{"email": "ivanovairina_1967@postgrespro.ru", "phone": "+70904879427"}
0005433616220	E57CA4	3263 915607	YURIY GORBUNOV	{"email": "gorbunov_y1969@postgrespro.ru", "phone": "+70548273352"}
0005433616221	DC1112	1204 275607	KIRILL FROLOV	{"phone": "+70700478942"}
0005433616222	DC1112	0354 449574	LYUDMILA NAUMOVA	{"email": "lnaumova_121976@postgrespro.ru", "phone": "+70850878500"}
0005433616223	3D1626	9520 238660	VLADIMIR IVANOV	{"email": "v.ivanov22111979@postgrespro.ru", "phone": "+70516879241"}
0005433616224	3D1626	8292 445967	ARINA MOROZOVA	{"email": "a-morozova-051960@postgrespro.ru", "phone": "+70419295870"}
0005433616225	3D1626	8089 776737	ANTON BONDARENKO	{"phone": "+70826734750"}
0005433616226	3D1626	2601 328787	VIKTOR SCHERBAKOV	{"email": "v.scherbakov1983@postgrespro.ru", "phone": "+70065025569"}
0005433616227	B6BD12	6978 487600	YULIYA DENISOVA	{"phone": "+70362265229"}
0005433616228	B6BD12	4401 255509	PAVEL KUZNECOV	{"email": "pavel.kuznecov-111981@postgrespro.ru", "phone": "+70181348997"}
0005433616229	CC994A	7829 703517	ANDREY OSIPOV	{"phone": "+70166295271"}
0005433616230	4DEE4F	0778 191190	VLADIMIR PETROV	{"phone": "+70057116871"}
0005433616231	D8A068	1915 635490	OLGA POPOVA	{"email": "popova_olga1980@postgrespro.ru", "phone": "+70613660421"}
0005433616232	D8A068	9084 583998	ELENA ZAKHAROVA	{"email": "ezakharova.25011968@postgrespro.ru", "phone": "+70814071293"}
0005433616233	D8A068	4232 337686	POLINA MASLOVA	{"email": "polina.maslova_21101969@postgrespro.ru", "phone": "+70147582018"}
0005433616234	F54C8F	6926 633578	RUSTAM GORBUNOV	{"phone": "+70728633513"}
0005433616235	0306FB	5136 142947	NATALYA GERASIMOVA	{"phone": "+70918300230"}
0005433616236	D91E7A	6105 063538	ALEKSANDR FROLOV	{"email": "afrolov.16061977@postgrespro.ru", "phone": "+70121311394"}
0005433616237	33AED8	3164 156352	ALEKSANDR PETROV	{"phone": "+70067861401"}
0005433616238	D85A06	5074 104627	ALINA DANILOVA	{"phone": "+70377065584"}
0005433616239	B25D02	0015 325756	VLADIMIR MAKSIMOV	{"email": "vladimir-maksimov.1972@postgrespro.ru", "phone": "+70393945369"}
0005433616240	1336F3	6814 191991	YULIYA SOKOLOVA	{"phone": "+70799983419"}
0005433616241	66D614	2864 195217	EVGENIY ALEKSEEV	{"phone": "+70893730718"}
0005433616242	66D614	3371 081230	MARIYA KUZNECOVA	{"phone": "+70637766126"}
0005433616243	55C21A	3015 345217	YULIYA ZOTOVA	{"phone": "+70210742060"}
0005433616244	D73568	6265 870927	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev_031975@postgrespro.ru", "phone": "+70102093955"}
0005433616245	D73568	5301 370556	ALEKSANDR KULIKOV	{"phone": "+70291068505"}
0005433616246	7A2C80	6490 235823	SOFIYA FROLOVA	{"email": "s.frolova-18061975@postgrespro.ru", "phone": "+70807881744"}
0005433616247	117265	0119 936260	ANDREY MARTYNOV	{"email": "martynov-a-1973@postgrespro.ru", "phone": "+70614856630"}
0005433616248	117265	8401 079341	ANTONINA SOKOLOVA	{"email": "sokolova_antonina_101978@postgrespro.ru", "phone": "+70198722352"}
0005433616249	8005D4	9212 921886	VITALIY DENISOV	{"phone": "+70908497120"}
0005433616250	8DC4BA	3677 996998	OLGA CHERNOVA	{"phone": "+70593530612"}
0005433616251	B0A450	1059 658562	NATALYA ZHUKOVA	{"phone": "+70175147320"}
0005433616252	B0A450	4617 113432	ANDREY FEDOROV	{"email": "a_fedorov.111967@postgrespro.ru", "phone": "+70194764601"}
0005433616253	4EFC03	2792 050456	YULIYA BELYAEVA	{"phone": "+70603466361"}
0005433616254	CAF9DB	2678 333056	NIKOLAY PETROV	{"phone": "+70573238307"}
0005433616255	C1EA21	0894 127973	VLADIMIR MIKHAYLOV	{"phone": "+70452042027"}
0005433616256	A378DD	8060 091155	VASILIY NIKOLAEV	{"email": "nikolaev.vasiliy_021977@postgrespro.ru", "phone": "+70935541625"}
0005433616257	C0C10A	0996 002607	RAISA ABRAMOVA	{"phone": "+70418381408"}
0005433616258	C0C10A	5506 330707	ANNA ISAEVA	{"email": "anna.isaeva.10081968@postgrespro.ru", "phone": "+70571006090"}
0005433616259	C0C10A	7727 942005	TAKHIR KAZAKOV	{"phone": "+70103384643"}
0005433616260	652818	2321 357426	SERGEY BORISOV	{"email": "borisov_s.16101983@postgrespro.ru", "phone": "+70251431987"}
0005433616261	C246CA	2561 537682	TATYANA IVANOVA	{"email": "ivanova.t011980@postgrespro.ru", "phone": "+70639998239"}
0005433616262	C246CA	1365 868252	NINA VOLKOVA	{"email": "nina_volkova21021960@postgrespro.ru", "phone": "+70177081898"}
0005433616263	6803AD	6156 638394	SERGEY ALEKSANDROV	{"email": "aleksandrovs.1977@postgrespro.ru", "phone": "+70630669694"}
0005433616264	6803AD	8440 198990	ALEKSANDRA KUDRYASHOVA	{"email": "kudryashovaaleksandra_23061969@postgrespro.ru", "phone": "+70064403956"}
0005433616265	94C9DB	8060 905436	TAMARA MOROZOVA	{"phone": "+70289161717"}
0005433616266	E516DF	6631 579697	ANDREY KUDRYASHOV	{"email": "kudryashova_22091986@postgrespro.ru", "phone": "+70297945425"}
0005433616267	E516DF	7136 511115	OLEG DENISOV	{"phone": "+70775461374"}
0005433616268	E516DF	3655 907336	ROMAN PAVLOV	{"phone": "+70907196730"}
0005433616269	61E4FB	5311 770666	OKSANA FROLOVA	{"email": "o-frolova_30121978@postgrespro.ru", "phone": "+70010790169"}
0005433616270	61E4FB	2763 020602	MAKSIM ORLOV	{"phone": "+70211037938"}
0005433616271	4746F5	8456 488448	YURIY NIKITIN	{"email": "nikitin_yuriy.081971@postgrespro.ru", "phone": "+70768550772"}
0005433616272	E8AD62	7517 543675	LYUDMILA BELOVA	{"email": "belova-lyudmila04101972@postgrespro.ru", "phone": "+70436384269"}
0005433616273	E8AD62	9599 674879	EVGENIY MELNIKOV	{"phone": "+70803761920"}
0005433616274	E8AD62	9464 742097	IVAN DMITRIEV	{"email": "ivan-dmitriev.021976@postgrespro.ru", "phone": "+70204999717"}
0005433616275	F8FDCB	8639 600783	EKATERINA ABRAMOVA	{"email": "e_abramova.18061966@postgrespro.ru", "phone": "+70124537724"}
0005433616276	726FBA	3348 202460	SERGEY ZAKHAROV	{"email": "zakharov-s_1977@postgrespro.ru", "phone": "+70250201666"}
0005433616277	FC4102	7486 894777	ALEKSANDR MAKSIMOV	{"email": "maksimov.a.04041968@postgrespro.ru", "phone": "+70030759461"}
0005433616278	015331	0923 792071	ELENA MAKAROVA	{"phone": "+70022580355"}
0005433616279	A9CA41	5170 379171	ZINAIDA CHERNOVA	{"phone": "+70088642985"}
0005433616280	A5AC03	0830 600629	VASILIY VLASOV	{"email": "vasiliy_vlasov12051965@postgrespro.ru", "phone": "+70925071971"}
0005433616281	A5AC03	1573 693868	ALEKSANDR ZHUKOV	{"phone": "+70407809832"}
0005433616282	945D03	1072 422611	SVETLANA ZAKHAROVA	{"phone": "+70284971495"}
0005433616283	93CFA7	0706 323456	ELENA KOZLOVA	{"phone": "+70718186191"}
0005433616284	A599A4	2901 257526	VIKTOR MIKHAYLOV	{"phone": "+70306543719"}
0005433616285	A599A4	2739 571570	VITALIY KOZLOV	{"phone": "+70465108810"}
0005433616286	7799EE	9042 293155	SVETLANA FADEEVA	{"email": "svetlana.fadeeva_14081982@postgrespro.ru", "phone": "+70224299648"}
0005433616287	7799EE	6974 841049	SERGEY FROLOV	{"phone": "+70219017539"}
0005433616288	ECC52C	0629 010994	VLADIMIR PETROV	{"phone": "+70574441012"}
0005433616289	2B3145	2076 292906	RUSTAM ZAYCEV	{"email": "rustam_zaycev_1982@postgrespro.ru", "phone": "+70345847162"}
0005433616290	5034C9	5787 337106	OLEG GUSEV	{"email": "gusevo.1986@postgrespro.ru", "phone": "+70698153812"}
0005433616291	C43FE8	3048 887664	VALENTINA KUZMINA	{"phone": "+70681088562"}
0005433616292	C43FE8	9235 478665	TATYANA MIRONOVA	{"email": "tatyana.mironova-061967@postgrespro.ru", "phone": "+70906094797"}
0005433616293	C43FE8	2703 137175	OLEG SOROKIN	{"phone": "+70414968641"}
0005433616294	B88BD6	3579 829079	NATALYA GUSEVA	{"email": "n_guseva_28071981@postgrespro.ru", "phone": "+70330188884"}
0005433616295	3B5A29	8637 858339	TATYANA YAKOVLEVA	{"phone": "+70357065127"}
0005433616296	29F726	2889 094882	ANNA TARASOVA	{"email": "tarasova-anna_29031974@postgrespro.ru", "phone": "+70706021774"}
0005433616297	C16F40	3183 035988	NINA DANILOVA	{"phone": "+70021967100"}
0005433616298	AFAE5D	3738 244208	ALEKSEY GAVRILOV	{"email": "aleksey.gavrilov.1973@postgrespro.ru", "phone": "+70980631632"}
0005433616299	25F69E	3518 253408	ELENA KUZMINA	{"phone": "+70914338307"}
0005433616300	1AD24A	6986 115122	ELENA MATVEEVA	{"phone": "+70257304099"}
0005433616301	5E3E80	2897 299753	LIDIYA FOMINA	{"phone": "+70091994547"}
0005433616302	5E3E80	7886 913610	SERGEY KAZAKOV	{"email": "s.kazakov.021971@postgrespro.ru", "phone": "+70567413243"}
0005433616303	8D96B8	5423 607493	LYUDMILA KARPOVA	{"email": "karpova.lyudmila091967@postgrespro.ru", "phone": "+70260380700"}
0005433616304	AB51CB	4362 791163	LARISA NAZAROVA	{"phone": "+70790207458"}
0005433616305	0F3649	9250 727520	VYACHESLAV STEPANOV	{"phone": "+70564109983"}
0005433616306	006498	4379 506849	EKATERINA MELNIKOVA	{"phone": "+70547257763"}
0005433616307	62FB9C	3890 430186	ALEKSEY MELNIKOV	{"phone": "+70364054273"}
0005433616308	62FB9C	1489 196889	ZOYA IVANOVA	{"phone": "+70200549539"}
0005433616309	E75B43	3276 800243	VALENTINA NIKOLAEVA	{"phone": "+70011705509"}
0005433616310	E75B43	1762 852699	SERGEY NIKOLAEV	{"phone": "+70932120169"}
0005433616311	E75B43	7313 105912	DARYA BELOVA	{"phone": "+70053987286"}
0005433616312	08801D	1810 663159	SERGEY NAUMOV	{"phone": "+70338409358"}
0005433616313	84F2D5	0553 940981	LYUDMILA ZAKHAROVA	{"phone": "+70764901243"}
0005433616314	184013	8399 938499	ALEKSANDR DENISOV	{"email": "denisov_a_011966@postgrespro.ru", "phone": "+70200231405"}
0005433616315	5A5EF0	4946 006242	NINA SIDOROVA	{"email": "sidorovanina-091969@postgrespro.ru", "phone": "+70665120174"}
0005433616316	5A5EF0	6412 579080	ANDREY MOISEEV	{"email": "moiseev-andrey_1959@postgrespro.ru", "phone": "+70299926961"}
0005433616317	318925	7463 315509	NATALYA ZHURAVLEVA	{"phone": "+70824653510"}
0005433616318	39E95D	0960 861042	IRINA KOVALEVA	{"phone": "+70031069270"}
0005433616319	322402	4392 104018	VLADIMIR ANDREEV	{"email": "vladimir_andreev_1972@postgrespro.ru", "phone": "+70093554053"}
0005433616320	322402	3226 622023	PAVEL KULIKOV	{"email": "kulikov_p1964@postgrespro.ru", "phone": "+70474945963"}
0005433616321	322402	8301 842003	DMITRIY MELNIKOV	{"email": "dmelnikov.091978@postgrespro.ru", "phone": "+70407252948"}
0005433616322	D6FD5A	9512 593286	STANISLAV BELOV	{"phone": "+70275680389"}
0005433616323	0D48FF	4426 647328	TAMARA NIKIFOROVA	{"email": "nikiforova.tamara_09031976@postgrespro.ru", "phone": "+70927577469"}
0005433616324	0D48FF	2085 799716	VALENTINA KUZNECOVA	{"email": "vkuznecova_1968@postgrespro.ru", "phone": "+70232201921"}
0005433616325	C0B2E6	4797 688997	ELENA FROLOVA	{"email": "frolova.elena06071971@postgrespro.ru", "phone": "+70248295115"}
0005433616326	9FB74A	5740 152357	KLAVDIYA KOROLEVA	{"email": "korolevaklavdiya1967@postgrespro.ru", "phone": "+70943589443"}
0005433616383	E59476	2252 002610	ANDREY BORISOV	{"phone": "+70360142173"}
0005433616327	08C127	3652 441593	RAISA BELOVA	{"email": "raisabelova.121971@postgrespro.ru", "phone": "+70964397750"}
0005433616328	08C127	2222 432489	MIKHAIL KARPOV	{"email": "m_karpov-28031975@postgrespro.ru", "phone": "+70270330185"}
0005433616329	0F3B78	6204 329682	ALEKSANDR MATVEEV	{"email": "matveev_a_031971@postgrespro.ru", "phone": "+70203205821"}
0005433616330	1FD6A3	3669 020021	VALENTINA KUZNECOVA	{"email": "kuznecova.v011973@postgrespro.ru", "phone": "+70249702149"}
0005433616331	1FD6A3	3736 664027	OKSANA NOVIKOVA	{"email": "o.novikova.1971@postgrespro.ru", "phone": "+70917915869"}
0005433616332	63C039	7993 176722	MARINA MEDVEDEVA	{"email": "medvedeva-marina_23081964@postgrespro.ru", "phone": "+70944583765"}
0005433616333	F81DF3	3076 861965	ANTON STEPANOV	{"phone": "+70395417958"}
0005433616334	35DACC	6023 164408	VYACHESLAV ABRAMOV	{"email": "v.abramov091970@postgrespro.ru", "phone": "+70884282400"}
0005433616335	35DACC	3671 555451	VLADIMIR FROLOV	{"email": "vladimirfrolov_1971@postgrespro.ru", "phone": "+70953244061"}
0005433616336	35DACC	2210 759401	PETR EGOROV	{"email": "petr_egorov.1963@postgrespro.ru", "phone": "+70150361189"}
0005433616337	313834	1677 864001	VLADIMIR VASILEV	{"email": "v.vasilev.1963@postgrespro.ru", "phone": "+70497525959"}
0005433616338	208C29	4965 705649	ALEKSANDR BELOV	{"phone": "+70481117808"}
0005433616339	BAC8D9	5048 230104	SERGEY NAZAROV	{"email": "s_nazarov101977@postgrespro.ru", "phone": "+70370654156"}
0005433616340	BAC8D9	1757 350766	KSENIYA VASILEVA	{"email": "vasileva_kseniya.1963@postgrespro.ru", "phone": "+70652448583"}
0005433616341	E8D811	7564 792179	SERGEY KUZMIN	{"phone": "+70282450524"}
0005433616342	FE41CD	8325 258799	OKSANA SERGEEVA	{"email": "sergeeva-o011965@postgrespro.ru", "phone": "+70791591900"}
0005433616343	25F7EF	4775 486417	ALLA MIKHAYLOVA	{"email": "mikhaylova_a111969@postgrespro.ru", "phone": "+70642769710"}
0005433616344	25F7EF	9390 195147	EDUARD KOZLOV	{"email": "kozlove-1967@postgrespro.ru", "phone": "+70368661408"}
0005433616345	59AD95	0159 417950	ANASTASIYA MOROZOVA	{"email": "morozova_a1972@postgrespro.ru", "phone": "+70940600231"}
0005433616346	D47840	0484 540305	NATALYA NAUMOVA	{"phone": "+70490526342"}
0005433616347	CA3CEA	4769 873075	VERA MASLOVA	{"phone": "+70323133690"}
0005433616348	CAB84A	6715 982531	MARIYA EFIMOVA	{"phone": "+70476306801"}
0005433616349	EC2566	3931 207935	NATALYA PAVLOVA	{"email": "pavlova.n06091976@postgrespro.ru", "phone": "+70298250009"}
0005433616350	E11459	9041 899834	LIDIYA KUZMINA	{"email": "lidiya-kuzmina_011959@postgrespro.ru", "phone": "+70853688281"}
0005433616351	C86696	7839 533856	LYUDMILA CHERNOVA	{"phone": "+70889595186"}
0005433616352	EE4E9D	4372 264256	DMITRIY VLASOV	{"phone": "+70559914707"}
0005433616353	BF5C2D	8068 482792	VLADIMIR MEDVEDEV	{"phone": "+70123239904"}
0005433616354	3F90AC	7222 006689	KONSTANTIN SEMENOV	{"email": "k.semenov13071972@postgrespro.ru", "phone": "+70220290432"}
0005433616355	17C69D	6278 760099	NADEZHDA FILIPPOVA	{"email": "n_filippova_071976@postgrespro.ru", "phone": "+70012414171"}
0005433616356	17C69D	5560 412751	IGOR NOVIKOV	{"phone": "+70840487041"}
0005433616357	27D7DF	4586 953826	NATALYA ILINA	{"email": "natalya-ilina-13061973@postgrespro.ru", "phone": "+70712714885"}
0005433616358	234278	3606 815922	ALEKSANDR TIMOFEEV	{"email": "aleksandr-timofeev-1983@postgrespro.ru", "phone": "+70267609537"}
0005433616359	6A4E20	0850 675293	ANDREY PAVLOV	{"email": "pavlov_a_031971@postgrespro.ru", "phone": "+70212920408"}
0005433616360	8C71BF	2643 656741	YURIY VOROBEV	{"email": "yuriy-vorobev-1959@postgrespro.ru", "phone": "+70278451987"}
0005433616361	018895	8752 204719	ALEKSANDR KUZMIN	{"phone": "+70548858620"}
0005433616362	0E2690	6324 715922	SVETLANA TROFIMOVA	{"phone": "+70853740676"}
0005433616363	0E2690	4392 289451	VYACHESLAV ZHURAVLEV	{"email": "vyacheslavzhuravlev.19051959@postgrespro.ru", "phone": "+70857749606"}
0005433616364	19AB9A	4041 266002	VIKTORIYA SIDOROVA	{"phone": "+70892140682"}
0005433616365	87B845	0562 951175	SERGEY NIKOLAEV	{"phone": "+70825617964"}
0005433616366	CC05F0	1383 525084	ANTON ZAKHAROV	{"email": "a_zakharov_1966@postgrespro.ru", "phone": "+70670363007"}
0005433616367	CC05F0	5220 777112	ANATOLIY ANTONOV	{"email": "antonov.a101987@postgrespro.ru", "phone": "+70971062156"}
0005433616368	CC05F0	8413 476122	NATALYA GAVRILOVA	{"email": "gavrilova-natalya-1961@postgrespro.ru", "phone": "+70369070389"}
0005433616369	AA9D9A	7404 797917	SERGEY IVANOV	{"phone": "+70833644810"}
0005433616370	AA9D9A	9016 458983	ALEKSANDR KONOVALOV	{"email": "konovalov-aleksandr051975@postgrespro.ru", "phone": "+70138499869"}
0005433616371	019683	7265 168685	ELENA MOROZOVA	{"phone": "+70443348745"}
0005433616372	019683	1242 152327	IVAN EGOROV	{"phone": "+70187762149"}
0005433616373	019683	5655 673313	PAVEL NIKOLAEV	{"email": "p-nikolaev1973@postgrespro.ru", "phone": "+70145052583"}
0005433616374	DE5988	5736 404717	DMITRIY SERGEEV	{"email": "sergeev_dmitriy.121980@postgrespro.ru", "phone": "+70863164242"}
0005433616375	DE5988	6770 334502	VALENTINA BOGDANOVA	{"phone": "+70768784978"}
0005433616376	D95DB2	5604 032493	ANATOLIY KOROLEV	{"email": "a-korolev-091974@postgrespro.ru", "phone": "+70343072219"}
0005433616377	CD125F	9604 107866	SERGEY NOVIKOV	{"email": "sergeynovikov.1965@postgrespro.ru", "phone": "+70948790572"}
0005433616378	BBCE85	9683 162132	MIKHAIL NAZAROV	{"phone": "+70583402202"}
0005433616379	BBCE85	3561 124522	ZULFIYA OSIPOVA	{"phone": "+70577839656"}
0005433616380	B45206	5540 309056	MIKHAIL KAZAKOV	{"email": "kazakov-m_071978@postgrespro.ru", "phone": "+70507197185"}
0005433616381	B45206	2781 728601	EVGENIYA RODIONOVA	{"phone": "+70254438456"}
0005433616384	B91E5C	5894 195583	OLGA NAZAROVA	{"phone": "+70118685004"}
0005433616385	8871F8	6233 172006	NATALYA KOLESNIKOVA	{"email": "kolesnikovan.1977@postgrespro.ru", "phone": "+70799408638"}
0005433616386	2111BE	3035 914856	EKATERINA LAZAREVA	{"email": "ekaterina.lazareva.20011988@postgrespro.ru", "phone": "+70040230677"}
0005433616387	6432F4	2808 983955	ROMAN ZHUKOV	{"email": "zhukov-roman.1974@postgrespro.ru", "phone": "+70908106582"}
0005433616388	6432F4	1642 643223	OKSANA LUKYANOVA	{"phone": "+70332833981"}
0005433616389	E8ABCE	4682 242044	NATALYA GRISHINA	{"phone": "+70277936517"}
0005433616390	E8ABCE	7853 755149	SERGEY VLASOV	{"email": "vlasov.sergey.1970@postgrespro.ru", "phone": "+70490128173"}
0005433616391	A4D05E	3941 639165	LYUBOV SCHERBAKOVA	{"email": "scherbakova.lyubov_05061977@postgrespro.ru", "phone": "+70511392335"}
0005433616392	207EFF	4671 223612	EKATERINA FILIPPOVA	{"phone": "+70439741843"}
0005433616393	AFF8BA	2230 884624	ALEKSANDR FEDOROV	{"phone": "+70561341934"}
0005433616394	AFF8BA	9576 256703	SERGEY SOLOVEV	{"email": "solovev-sergey-1970@postgrespro.ru", "phone": "+70544201533"}
0005433616395	74F8FE	4292 656842	TATYANA FADEEVA	{"phone": "+70128363549"}
0005433616396	F9EE2E	6105 550724	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya24041972@postgrespro.ru", "phone": "+70500390282"}
0005433616397	F51FC6	9540 989768	ANTONINA IVANOVA	{"email": "a-ivanova_041976@postgrespro.ru", "phone": "+70906137265"}
0005433616398	F51FC6	9113 081494	ALEKSEY MAKAROV	{"phone": "+70472359171"}
0005433616399	F51FC6	0887 965012	LYUBOV ZAYCEVA	{"email": "zaycevalyubov_06031970@postgrespro.ru", "phone": "+70911351905"}
0005433616400	C86BFE	8617 471856	ZOYA GUSEVA	{"email": "z.guseva-26061969@postgrespro.ru", "phone": "+70747250774"}
0005433616401	C86BFE	6256 807702	NATALYA MIRONOVA	{"email": "mironovan-111971@postgrespro.ru", "phone": "+70716887521"}
0005433616402	2FB46A	4746 016277	NIKOLAY NIKOLAEV	{"email": "nikolaev.n_061975@postgrespro.ru", "phone": "+70154079239"}
0005433616403	54ED92	5099 201388	RAFAEL MOROZOV	{"email": "rafael.morozov.021983@postgrespro.ru", "phone": "+70546572938"}
0005433616404	54ED92	2682 064930	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr.19081971@postgrespro.ru", "phone": "+70184417522"}
0005433616405	22061E	6445 929865	ALEKSANDR IVANOV	{"phone": "+70414788571"}
0005433616406	3AE32D	7655 295459	OLGA STEPANOVA	{"phone": "+70510672933"}
0005433616407	3AE32D	7186 167309	SERGEY KRASNOV	{"email": "s-krasnov-15041976@postgrespro.ru", "phone": "+70438276974"}
0005433616408	3AE32D	4334 235610	TATYANA ZAYCEVA	{"phone": "+70563968307"}
0005433616409	3AE32D	3042 236673	ANNA TITOVA	{"email": "annatitova_18091978@postgrespro.ru", "phone": "+70690111823"}
0005433616410	5ADEBB	9691 261329	IVAN BORISOV	{"email": "i.borisov.1983@postgrespro.ru", "phone": "+70027249556"}
0005433616411	5ADEBB	0331 388409	OKSANA KONDRATEVA	{"email": "kondrateva-oksana_1976@postgrespro.ru", "phone": "+70089289020"}
0005433616412	5ADEBB	5107 510996	VERA KUZNECOVA	{"email": "v_kuznecova-1964@postgrespro.ru", "phone": "+70680109892"}
0005433616413	5ADEBB	9278 110464	IGOR SOLOVEV	{"phone": "+70114826627"}
0005433616414	8AC331	7492 805232	NIKOLAY SEMENOV	{"email": "semenovnikolay_021973@postgrespro.ru", "phone": "+70382267808"}
0005433616415	8AC331	7046 939874	SERGEY MOROZOV	{"phone": "+70211951806"}
0005433616416	7360B5	5985 303061	NIKOLAY KOROLEV	{"email": "korolev-nikolay_1978@postgrespro.ru", "phone": "+70311716331"}
0005433616417	DE195F	7485 552334	VALENTIN TIMOFEEV	{"email": "timofeev_valentin-17121985@postgrespro.ru", "phone": "+70977669188"}
0005433616418	89B655	7385 522714	VASILIY SERGEEV	{"email": "vsergeev.011978@postgrespro.ru", "phone": "+70925891547"}
0005433616419	16C9FD	0749 587558	RUSTAM KRASNOV	{"phone": "+70830309118"}
0005433616420	16C9FD	0824 817732	ANASTASIYA MARTYNOVA	{"email": "martynova-anastasiya-061972@postgrespro.ru", "phone": "+70056993680"}
0005433616421	CB52A0	7727 941658	ALSU CHERNOVA	{"phone": "+70131090073"}
0005433616422	0B1D39	2227 590023	NATALYA SEMENOVA	{"email": "semenova.n041976@postgrespro.ru", "phone": "+70401259429"}
0005433616423	298280	0115 231820	TATYANA SOLOVEVA	{"phone": "+70290652917"}
0005433616424	AEC50C	7838 320553	DARYA KONOVALOVA	{"phone": "+70190528863"}
0005433616425	42AB12	2478 558008	ANZHELIKA TARASOVA	{"email": "tarasova-anzhelika25121969@postgrespro.ru", "phone": "+70093680520"}
0005433616426	D64CC5	9439 144927	TATYANA POPOVA	{"phone": "+70720842890"}
0005433616427	FD0E4D	1639 858647	MARGARITA SERGEEVA	{"email": "m_sergeeva01021974@postgrespro.ru", "phone": "+70664823342"}
0005433616428	FD0E4D	2812 922782	ALEKSEY ROMANOV	{"email": "alekseyromanov.03041976@postgrespro.ru", "phone": "+70426962794"}
0005433616429	52223B	0719 957185	EKATERINA SOROKINA	{"email": "ekaterina-sorokina_061972@postgrespro.ru", "phone": "+70791512511"}
0005433616430	3CE5B2	8121 572069	VERA MAKAROVA	{"phone": "+70885779185"}
0005433616431	6D16EC	9398 017969	DENIS NAZAROV	{"email": "nazarov-denis_1967@postgrespro.ru", "phone": "+70423875911"}
0005433616432	19EDCA	7309 896416	AIDA ZAKHAROVA	{"email": "a_zakharova-1979@postgrespro.ru", "phone": "+70318962246"}
0005433616433	2BCB42	1279 170400	NATALYA NIKIFOROVA	{"email": "nikiforova.natalya.15081968@postgrespro.ru", "phone": "+70089921153"}
0005433616434	D273C6	7379 286340	GENNADIY VASILEV	{"phone": "+70555413359"}
0005433616435	D273C6	8506 370977	GALINA SOLOVEVA	{"email": "solovevag.08101971@postgrespro.ru", "phone": "+70338214031"}
0005433616436	BBFAE8	2456 832203	OLGA ROMANOVA	{"phone": "+70296983974"}
0005433616437	2FBB53	1536 537659	EGOR DMITRIEV	{"email": "edmitriev.1970@postgrespro.ru", "phone": "+70493583240"}
0005433616438	0D41AC	1685 554614	ARTUR KULIKOV	{"email": "artur-kulikov_1970@postgrespro.ru", "phone": "+70861388980"}
0005433616439	0D41AC	2220 504321	ELENA NIKITINA	{"email": "e.nikitina18121967@postgrespro.ru", "phone": "+70810802623"}
0005433616440	BFA816	2549 900726	VALENTINA POLYAKOVA	{"email": "v.polyakova-20051965@postgrespro.ru", "phone": "+70736280412"}
0005433616441	B99687	4855 163664	NATALYA TIKHONOVA	{"email": "natalya_tikhonova021966@postgrespro.ru", "phone": "+70945806997"}
0005433616442	B99687	7460 031577	NIKITA BONDARENKO	{"email": "bondarenko.n.021982@postgrespro.ru", "phone": "+70779350423"}
0005433616443	4E0725	0369 661287	EVGENIY MAKAROV	{"phone": "+70570323853"}
0005433616444	4E0725	2996 518529	NADEZHDA AKIMOVA	{"phone": "+70400869052"}
0005433616445	972A03	1049 274397	ARTUR SAVELEV	{"phone": "+70616739243"}
0005433616446	C26023	9952 190457	MARINA KUZNECOVA	{"phone": "+70159035711"}
0005433616447	C26023	5146 275196	DMITRIY YAKOVLEV	{"email": "yakovlev_dmitriy12121975@postgrespro.ru", "phone": "+70970151495"}
0005433616448	C26023	5751 882912	YANA GRISHINA	{"phone": "+70604282563"}
0005433616449	B7B8E1	2283 102848	EVGENIY GRIGOREV	{"phone": "+70221017214"}
0005433616450	C04EC1	8634 063459	VLADISLAV KAZAKOV	{"phone": "+70265489874"}
0005433616451	C04EC1	5798 441258	ALEKSEY MEDVEDEV	{"email": "a_medvedev-1964@postgrespro.ru", "phone": "+70863007174"}
0005433616452	62E7AA	3997 062120	NIKOLAY ILIN	{"phone": "+70333312964"}
0005433616453	B2B7FC	4458 580379	GALINA GUSEVA	{"email": "gusevagalina.1981@postgrespro.ru", "phone": "+70870606424"}
0005433616454	B2B7FC	7255 993803	YURIY SOROKIN	{"phone": "+70379099410"}
0005433616455	B2B7FC	7138 469577	MIKHAIL TARASOV	{"email": "tarasov.m-27061969@postgrespro.ru", "phone": "+70412000305"}
0005433616456	3A08FF	4015 344546	DARYA KUZNECOVA	{"phone": "+70831246354"}
0005433616457	3A08FF	5636 208942	ELENA POLYAKOVA	{"email": "e.polyakova.18091966@postgrespro.ru", "phone": "+70828131203"}
0005433616458	BFA3F9	7898 050557	ALEKSANDR ORLOV	{"email": "aleksandr.orlov.27011976@postgrespro.ru", "phone": "+70723373025"}
0005433616459	344443	1512 983298	SVETLANA FOMINA	{"email": "svetlana-fomina_08011981@postgrespro.ru", "phone": "+70415441401"}
0005433616460	3ADDF2	4330 669675	PAVEL ORLOV	{"email": "pavelorlov111970@postgrespro.ru", "phone": "+70870066953"}
0005433616461	2F67B3	8835 990177	VYACHESLAV POPOV	{"email": "popov-v.27091978@postgrespro.ru", "phone": "+70234588487"}
0005433616462	2F67B3	2931 714356	PETR FEDOROV	{"email": "petrfedorov-101977@postgrespro.ru", "phone": "+70655829142"}
0005433616463	2F67B3	9550 102030	MILENA ANTONOVA	{"email": "antonova_m-18061967@postgrespro.ru", "phone": "+70212596252"}
0005433616464	BF7961	5096 350884	TATYANA POPOVA	{"phone": "+70055926759"}
0005433616465	BF7961	4499 122457	YURIY KONOVALOV	{"email": "yuriy_konovalov.011970@postgrespro.ru", "phone": "+70808083915"}
0005433616466	BF7961	4769 124213	OLGA DENISOVA	{"email": "olgadenisova22061970@postgrespro.ru", "phone": "+70193003374"}
0005433616467	448774	2700 872406	ZARINA NAUMOVA	{"email": "zarina-naumova.1962@postgrespro.ru", "phone": "+70044622163"}
0005433616468	448774	3958 577803	IVAN ORLOV	{"email": "ivan.orlov.031977@postgrespro.ru", "phone": "+70106258320"}
0005433616469	0F6DF4	6884 785097	YULIYA KARPOVA	{"phone": "+70514127128"}
0005433616470	0F6DF4	6794 110877	ANASTASIYA ILINA	{"phone": "+70554139396"}
0005433616471	3D93AB	4369 601981	ELIZAVETA KOZLOVA	{"email": "e.kozlova091956@postgrespro.ru", "phone": "+70219248298"}
0005433616472	3D93AB	5246 057251	VIKTOR ZHURAVLEV	{"email": "zhuravlev-viktor22011985@postgrespro.ru", "phone": "+70806130700"}
0005433616473	3255AE	5637 912548	ALEKSEY IVANOV	{"email": "ivanov-aleksey111977@postgrespro.ru", "phone": "+70521577598"}
0005433616474	A5CC60	8057 490793	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev_1960@postgrespro.ru", "phone": "+70474438457"}
0005433616475	4C3E2E	9436 469014	BORIS KOZLOV	{"email": "kozlov.boris-1981@postgrespro.ru", "phone": "+70906265699"}
0005433616476	2A337A	1633 681695	DARYA KUZMINA	{"phone": "+70877249956"}
0005433616477	EF6BB8	2950 283127	IRINA KARPOVA	{"phone": "+70331562329"}
0005433616478	48B152	4302 476950	RASHID BORISOV	{"email": "borisov.r.121980@postgrespro.ru", "phone": "+70425871004"}
0005433616479	48B152	3996 206613	PAVEL KRASNOV	{"email": "pkrasnov23091973@postgrespro.ru", "phone": "+70068619488"}
0005433616480	AB28A7	6173 105459	NATALYA KALININA	{"email": "kalinina-n_061976@postgrespro.ru", "phone": "+70672388465"}
0005433616481	91A165	8698 794927	LYUDMILA EFREMOVA	{"email": "efremova-lyudmila.021979@postgrespro.ru", "phone": "+70396315101"}
0005433616482	D76F6B	0437 002241	LARISA SEMENOVA	{"phone": "+70389068321"}
0005433616483	D76F6B	6263 563338	NIKITA SCHERBAKOV	{"email": "nikitascherbakov071977@postgrespro.ru", "phone": "+70552977559"}
0005433616484	8FC501	9259 673069	DENIS KUZMIN	{"phone": "+70866162765"}
0005433616485	8F3E00	6027 085073	SERGEY MOISEEV	{"email": "s-moiseev29011972@postgrespro.ru", "phone": "+70788853537"}
0005433616486	5B6300	1655 056424	LYUBOV ORLOVA	{"email": "lyubov.orlova1972@postgrespro.ru", "phone": "+70440402670"}
0005433616487	C4644B	0969 875860	VALENTINA POPOVA	{"phone": "+70092525940"}
0005433616488	F34299	2401 416671	VALENTINA ISAEVA	{"email": "v_isaeva-031971@postgrespro.ru", "phone": "+70578170941"}
0005433616489	F34299	0368 762696	ANDREY PETROV	{"email": "petrov-andrey-16051963@postgrespro.ru", "phone": "+70872688544"}
0005433616490	F34299	7455 233013	VLADIMIR PAVLOV	{"phone": "+70547631502"}
0005433616491	26A317	5551 976769	LARISA IVANOVA	{"email": "larisaivanova-1963@postgrespro.ru", "phone": "+70080792744"}
0005433616492	5A7F66	9795 277061	ELIZAVETA ZHURAVLEVA	{"phone": "+70049329198"}
0005433616493	5A7F66	5634 631869	NADEZHDA DAVYDOVA	{"email": "davydova-n.05111973@postgrespro.ru", "phone": "+70554312171"}
0005433616494	45B906	8378 494411	ASIYA KAZAKOVA	{"email": "kazakovaasiya.081972@postgrespro.ru", "phone": "+70004014521"}
0005433616495	45B906	8727 279239	ANNA MAKSIMOVA	{"email": "maksimova-a_1974@postgrespro.ru", "phone": "+70710827208"}
0005433616496	5AEF29	1122 549670	GALINA KUZMINA	{"email": "galina_kuzmina-121966@postgrespro.ru", "phone": "+70716202753"}
0005433616497	5AEF29	0044 979926	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey041978@postgrespro.ru", "phone": "+70104186429"}
0005433616498	5AEF29	8639 019790	EVGENIYA RODIONOVA	{"email": "erodionova_1971@postgrespro.ru", "phone": "+70909006089"}
0005433616499	4D3576	2219 208591	ANASTASIYA SEMENOVA	{"email": "anastasiyasemenova091971@postgrespro.ru", "phone": "+70205170477"}
0005433616500	B028B2	4172 678426	ARSENIY SIDOROV	{"email": "sidorov_a-1979@postgrespro.ru", "phone": "+70819491761"}
0005433616501	B028B2	2582 107457	EVGENIYA YUDINA	{"phone": "+70614144668"}
0005433616502	D3008F	3299 615960	KIRILL GORBUNOV	{"phone": "+70097040531"}
0005433616503	E9D331	8399 142818	DARYA PETROVA	{"phone": "+70859203437"}
0005433616504	B72589	1390 636700	GALINA FROLOVA	{"email": "galinafrolova.08011958@postgrespro.ru", "phone": "+70372273560"}
0005433616505	B184D2	9932 375331	ANATOLIY IVANOV	{"email": "ivanov-anatoliy101968@postgrespro.ru", "phone": "+70176758953"}
0005433616506	B12C6A	6718 436392	DMITRIY TIMOFEEV	{"phone": "+70107678169"}
0005433616507	2406A3	6782 790187	NINA MEDVEDEVA	{"email": "nina_medvedeva111962@postgrespro.ru", "phone": "+70831098804"}
0005433616508	336139	1068 542973	ALEKSANDRA ILINA	{"email": "a.ilina011974@postgrespro.ru", "phone": "+70661692977"}
0005433616509	336139	8681 255395	VERA ANDREEVA	{"email": "andreeva_vera.27071977@postgrespro.ru", "phone": "+70571230747"}
0005433616510	05F992	9973 945290	MIKHAIL BELOV	{"email": "m-belov111980@postgrespro.ru", "phone": "+70145673250"}
0005433616511	FECCEA	8511 647552	ANDREY MIKHAYLOV	{"email": "andrey_mikhaylov.101986@postgrespro.ru", "phone": "+70734576739"}
0005433616512	F31E4C	3861 955891	VADIM PAVLOV	{"email": "v-pavlov.29111970@postgrespro.ru", "phone": "+70952719011"}
0005433616513	70020A	4971 786060	IRINA NIKIFOROVA	{"phone": "+70933921147"}
0005433616514	70020A	8166 772252	DANIIL KUZMIN	{"phone": "+70956066517"}
0005433616515	4066AF	8725 439528	VYACHESLAV GAVRILOV	{"email": "gavrilov_vyacheslav.11011968@postgrespro.ru", "phone": "+70110340888"}
0005433616516	28C897	5155 341379	ELIZAVETA IVANOVA	{"phone": "+70745542677"}
0005433616517	B2470A	2254 349684	GUZEL MALYSHEVA	{"phone": "+70821126271"}
0005433616518	287B87	6868 271642	LYUBOV PETROVA	{"phone": "+70536745572"}
0005433616519	5DC9C6	1268 381809	ALEKSANDR ROMANOV	{"phone": "+70866466138"}
0005433616520	A55C85	2253 144377	MAKSIM PETROV	{"email": "m.petrov.091969@postgrespro.ru", "phone": "+70725752573"}
0005433616521	98D394	5894 376426	VALERIYA ROMANOVA	{"email": "romanova-valeriya1974@postgrespro.ru", "phone": "+70800136578"}
0005433616522	98D394	4318 434842	NINA PAVLOVA	{"phone": "+70201904692"}
0005433616523	EDCF62	0194 463141	ALEKSANDR ANDREEV	{"phone": "+70069744657"}
0005433616524	28C2C3	1466 247568	VERA MIKHAYLOVA	{"phone": "+70985342704"}
0005433616525	B80330	7534 553707	NATALYA MELNIKOVA	{"phone": "+70129770170"}
0005433616526	72D862	9079 290713	EMIL KUZNECOV	{"phone": "+70270815491"}
0005433616527	A7BC23	0353 438235	OLGA SOKOLOVA	{"phone": "+70335902438"}
0005433616528	19EB28	8430 571216	VLADIMIR NIKOLAEV	{"email": "v-nikolaev-1974@postgrespro.ru", "phone": "+70531917181"}
0005433616529	19EB28	7560 611263	VERA GERASIMOVA	{"email": "vera-gerasimova1965@postgrespro.ru", "phone": "+70515913273"}
0005433616530	EBD2E3	1675 988170	OLGA IVANOVA	{"email": "o.ivanova-14071979@postgrespro.ru", "phone": "+70143770915"}
0005433616531	76CEF7	4091 505936	MARIYA SEMENOVA	{"email": "m-semenova-1981@postgrespro.ru", "phone": "+70083420045"}
0005433616532	76CEF7	2728 559849	ALEKSANDRA MEDVEDEVA	{"phone": "+70614324746"}
0005433616533	862745	1572 924851	ELENA VASILEVA	{"email": "elenavasileva-03091956@postgrespro.ru", "phone": "+70432048531"}
0005433616534	862745	2672 912009	GALINA SERGEEVA	{"phone": "+70478976333"}
0005433616535	843C53	9136 419230	OLGA DAVYDOVA	{"email": "davydova-olga.081968@postgrespro.ru", "phone": "+70217185102"}
0005433616536	B25F91	0055 469315	ZOYA GUSEVA	{"email": "zoya_guseva14121971@postgrespro.ru", "phone": "+70813158273"}
0005433616537	C46151	0018 997761	NADEZHDA ZAYCEVA	{"email": "zayceva.n-1967@postgrespro.ru", "phone": "+70123455153"}
0005433616538	0AE441	1472 340894	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir_1967@postgrespro.ru", "phone": "+70335956495"}
0005433616539	C07BE6	8883 563149	ALEKSANDRA MAKAROVA	{"email": "makarovaa1970@postgrespro.ru", "phone": "+70372702709"}
0005433616540	A81F75	3596 425345	DMITRIY MARTYNOV	{"phone": "+70367458919"}
0005433616541	A81F75	3604 973943	ELENA SOROKINA	{"phone": "+70946072203"}
0005433616542	A81F75	5094 664966	KRISTINA POPOVA	{"email": "popova.kristina-1988@postgrespro.ru", "phone": "+70628562609"}
0005433616543	47E82C	2694 803709	NIKOLAY SOLOVEV	{"email": "nikolay_solovev_10011970@postgrespro.ru", "phone": "+70462620583"}
0005433616544	22DCAA	4683 496736	NATALYA ALEKSEEVA	{"phone": "+70984403389"}
0005433616545	F8E26E	3025 905678	LYUDMILA MIKHAYLOVA	{"phone": "+70863447873"}
0005433616546	1D3775	2582 075620	VLADIMIR SOLOVEV	{"phone": "+70355385716"}
0005433616547	802D29	6307 562762	MARINA KUDRYASHOVA	{"phone": "+70458115668"}
0005433616548	802D29	0131 168634	OLGA STEPANOVA	{"email": "stepanova-olga02111974@postgrespro.ru", "phone": "+70867284689"}
0005433616549	802D29	0167 241721	ZOYA VASILEVA	{"email": "z-vasileva26091969@postgrespro.ru", "phone": "+70228350215"}
0005433616550	39567F	9949 043623	TAISIYA ZHUKOVA	{"email": "taisiya-zhukova-08101965@postgrespro.ru", "phone": "+70039546534"}
0005433616551	39567F	2230 984607	LYUBOV VOROBEVA	{"phone": "+70965819934"}
0005433616552	E2FDD2	3177 146964	ANATOLIY POPOV	{"phone": "+70782575336"}
0005433616553	1711EA	0877 280496	MARIYA DANILOVA	{"email": "mariyadanilova-11071982@postgrespro.ru", "phone": "+70422081591"}
0005433616554	1711EA	5769 904142	EVGENIY DENISOV	{"email": "edenisov101957@postgrespro.ru", "phone": "+70389429646"}
0005433616555	B31D37	1828 322245	OKSANA IVANOVA	{"email": "o.ivanova_1983@postgrespro.ru", "phone": "+70236623143"}
0005433616556	873249	3794 897160	BORIS CHERNOV	{"email": "borischernov_091971@postgrespro.ru", "phone": "+70566781281"}
0005433616557	2A8A22	3655 187932	MARINA BELOVA	{"phone": "+70472697156"}
0005433616558	03A7CA	1513 936511	VIKTORIYA YUDINA	{"phone": "+70468241348"}
0005433616559	03A7CA	2887 199431	KHALIDA VOROBEVA	{"email": "vorobeva.khalida-27011968@postgrespro.ru", "phone": "+70779843640"}
0005433616560	03A7CA	4115 658502	GALINA KONDRATEVA	{"phone": "+70297436436"}
0005433616561	0EFE17	3721 443474	DMITRIY SCHERBAKOV	{"phone": "+70154424717"}
0005433616562	0EFE17	2800 507595	PELAGEYA KAZAKOVA	{"email": "p-kazakova-061987@postgrespro.ru", "phone": "+70792516782"}
0005433616742	4F43A9	0596 647989	RIMMA FROLOVA	{"phone": "+70162122724"}
0005433616563	0E5635	0011 841420	ELENA MAKAROVA	{"email": "e-makarova.1958@postgrespro.ru", "phone": "+70063376523"}
0005433616564	F9E63E	8276 323889	EKATERINA KOROLEVA	{"email": "korolevae1973@postgrespro.ru", "phone": "+70560933795"}
0005433616565	F9E63E	9223 736070	GENNADIY MAKAROV	{"phone": "+70731655198"}
0005433616566	3FB459	9170 716387	ANNA ZAKHAROVA	{"phone": "+70667695154"}
0005433616567	822C9B	3062 883970	ZOYA SOKOLOVA	{"phone": "+70888607517"}
0005433616568	5AD8ED	4967 700210	ANDREY SEMENOV	{"phone": "+70144941285"}
0005433616569	F69CC5	4724 406345	ANNA SMIRNOVA	{"email": "smirnova_anna_20041977@postgrespro.ru", "phone": "+70154342881"}
0005433616570	F6EE60	8183 256232	VIKTOR EGOROV	{"email": "egorov.viktor.1980@postgrespro.ru", "phone": "+70282200694"}
0005433616571	F6EE60	7038 422184	ANNA ZHUKOVA	{"phone": "+70946700955"}
0005433616572	84B17E	1935 982796	GENNADIY ZAYCEV	{"phone": "+70468916489"}
0005433616573	E3EC8A	9170 702753	VLADIMIR SIDOROV	{"email": "sidorov_vladimir.1971@postgrespro.ru", "phone": "+70413843745"}
0005433616574	45F9F7	7109 479821	ALEKSANDR PAVLOV	{"phone": "+70283902017"}
0005433616575	45D09B	6565 072223	VLADIMIR ABRAMOV	{"phone": "+70151576659"}
0005433616576	8A7C64	9971 035029	ANZHELIKA NIKOLAEVA	{"email": "anzhelika.nikolaeva-1964@postgrespro.ru", "phone": "+70450676183"}
0005433616577	8A7C64	9819 295305	SERGEY VOROBEV	{"email": "vorobev.sergey17041974@postgrespro.ru", "phone": "+70024909043"}
0005433616578	2194A8	8092 205890	ZOYA MOROZOVA	{"email": "morozova.zoya-031972@postgrespro.ru", "phone": "+70205559158"}
0005433616579	36D8D9	8940 563550	VLADA KULIKOVA	{"email": "vlada_kulikova-1958@postgrespro.ru", "phone": "+70580372799"}
0005433616580	B349E4	7215 949505	VALENTINA KOLESNIKOVA	{"email": "vkolesnikova.21101965@postgrespro.ru", "phone": "+70149591911"}
0005433616581	3A1163	2028 835813	VIKTOR ISAEV	{"email": "v_isaev.041985@postgrespro.ru", "phone": "+70941032567"}
0005433616582	3A1163	8823 585649	YURIY KUZNECOV	{"email": "yuriy_kuznecov-041972@postgrespro.ru", "phone": "+70866119852"}
0005433616583	AB9933	8196 111753	FILIPP VOLKOV	{"email": "volkov-f1981@postgrespro.ru", "phone": "+70909563838"}
0005433616584	AB9933	0134 445450	VIKTOR OSIPOV	{"email": "osipov_viktor-19091975@postgrespro.ru", "phone": "+70563653243"}
0005433616585	AB9933	5074 237003	ROMAN NOVIKOV	{"email": "roman_novikov-18051965@postgrespro.ru", "phone": "+70410930261"}
0005433616586	7B3CFB	1369 924279	ALEKSANDR SEMENOV	{"email": "semenov-a.051971@postgrespro.ru", "phone": "+70915220270"}
0005433616587	4E4CBA	3222 859876	NIKOLAY BARANOV	{"email": "n.baranov.20051971@postgrespro.ru", "phone": "+70651546602"}
0005433616588	4E4CBA	9700 479449	ALEKSANDR MOISEEV	{"email": "aleksandrmoiseev_1962@postgrespro.ru", "phone": "+70511012792"}
0005433616589	4E80EE	9268 981941	YAROSLAV SEMENOV	{"phone": "+70657213592"}
0005433616590	651A37	7880 314034	VERA SERGEEVA	{"email": "v-sergeeva101970@postgrespro.ru", "phone": "+70324959960"}
0005433616591	4228D9	4271 726399	ELENA GERASIMOVA	{"phone": "+70153812759"}
0005433616592	B5CFD6	3956 043244	KLAVDIYA KISELEVA	{"email": "k_kiseleva_20031965@postgrespro.ru", "phone": "+70755074441"}
0005433616593	0EB76A	9565 049751	NATALYA EFIMOVA	{"phone": "+70740581348"}
0005433616594	0EB76A	8024 690610	VLADIMIR SMIRNOV	{"phone": "+70329542658"}
0005433616595	D4ACCD	9716 796347	EGOR VLASOV	{"phone": "+70114275270"}
0005433616596	97B667	1746 559305	RUSLAN BONDARENKO	{"email": "bondarenko_ruslan.101976@postgrespro.ru", "phone": "+70608643346"}
0005433616597	CDBD78	4206 088811	SERGEY FILIPPOV	{"phone": "+70341795858"}
0005433616598	CDBD78	3038 445739	EVGENIY KUDRYASHOV	{"phone": "+70921695103"}
0005433616599	FD6DC1	5049 455581	MARIYA ALEKSEEVA	{"email": "m-alekseeva-13111967@postgrespro.ru", "phone": "+70069798581"}
0005433616600	1AD647	4579 600183	ALEKSEY KONOVALOV	{"email": "akonovalov.20081981@postgrespro.ru", "phone": "+70872555440"}
0005433616601	53503F	7573 129602	YULIYA VOLKOVA	{"phone": "+70624536835"}
0005433616602	53503F	9825 560785	OLGA MEDVEDEVA	{"phone": "+70303965370"}
0005433616603	DC6BDF	2388 360086	AZAT CHERNOV	{"phone": "+70399732280"}
0005433616604	809CF2	1312 963783	ILYA KUDRYASHOV	{"phone": "+70059560176"}
0005433616605	5CFC36	6168 282814	MARIYA DANILOVA	{"email": "m_danilova011971@postgrespro.ru", "phone": "+70308961113"}
0005433616606	C2222F	8835 327579	ILYA SOROKIN	{"phone": "+70726125407"}
0005433616607	AA562B	7417 799408	SALAVAT TIKHONOV	{"email": "stikhonov.021980@postgrespro.ru", "phone": "+70784646940"}
0005433616608	31367D	6868 639251	VALERIY IVANOV	{"phone": "+70028726086"}
0005433616609	31367D	4841 798797	IRINA MOROZOVA	{"email": "irina-morozova_1963@postgrespro.ru", "phone": "+70991224944"}
0005433616610	674133	0752 589704	ANASTASIYA KUZMINA	{"phone": "+70622524439"}
0005433616611	674133	6875 586592	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov-041973@postgrespro.ru", "phone": "+70363453707"}
0005433616612	16149B	3806 584328	LYUDMILA KUZNECOVA	{"email": "kuznecova_l.14091962@postgrespro.ru", "phone": "+70877487736"}
0005433616613	244AD6	7861 659900	ANNA BARANOVA	{"email": "a.baranova081981@postgrespro.ru", "phone": "+70652232049"}
0005433616614	9D9CD5	3532 861507	IGOR NIKITIN	{"email": "nikitin-i.081977@postgrespro.ru", "phone": "+70481880897"}
0005433616615	2A7C9D	7031 223143	LYUBOV DAVYDOVA	{"email": "davydova-l_121980@postgrespro.ru", "phone": "+70430074060"}
0005433616616	2A7C9D	3523 350098	VARVARA KOLESNIKOVA	{"phone": "+70995389467"}
0005433616617	6FD781	7257 539384	ANDREY KOZLOV	{"email": "andrey.kozlov_1976@postgrespro.ru", "phone": "+70305960341"}
0005433616618	487DFA	5568 886140	NIKOLAY GERASIMOV	{"email": "gerasimov_nikolay041978@postgrespro.ru", "phone": "+70532121234"}
0005433616619	487DFA	7351 589768	LYUBOV VOLKOVA	{"email": "lyubov.volkova-1974@postgrespro.ru", "phone": "+70683253127"}
0005433616620	9FFAA9	9312 845631	RAMZIYA KUZMINA	{"phone": "+70285418535"}
0005433616621	9FFAA9	5998 620282	KARINA ANDREEVA	{"phone": "+70148610128"}
0005433616622	A2F1DA	7459 379752	RUSLAN PETROV	{"email": "rpetrov_16081972@postgrespro.ru", "phone": "+70064727016"}
0005433616623	8D1C00	5359 217868	MARIYA EFREMOVA	{"phone": "+70821438799"}
0005433616624	160E49	2844 801535	ELENA IVANOVA	{"email": "ivanova.e24041969@postgrespro.ru", "phone": "+70262822988"}
0005433616625	F2967B	7487 333861	VALENTINA ZAYCEVA	{"phone": "+70933930104"}
0005433616626	524B87	6549 778525	VLADIMIR TARASOV	{"phone": "+70497201283"}
0005433616627	CD70E2	8227 812563	LIDIYA YUDINA	{"email": "yudina.l071985@postgrespro.ru", "phone": "+70105595127"}
0005433616628	08C0D9	4022 792537	FEDOR KARPOV	{"phone": "+70194505339"}
0005433616629	08C0D9	2442 091981	MIKHAIL KARPOV	{"phone": "+70919023698"}
0005433616630	C2C2EB	4039 014335	RUSLAN KUDRYASHOV	{"email": "kudryashov.ruslan_041986@postgrespro.ru", "phone": "+70426620053"}
0005433616631	8BF7D4	7341 557399	YULIANA ILINA	{"phone": "+70647981805"}
0005433616632	ED2137	7546 146933	PELAGEYA MELNIKOVA	{"email": "melnikova_pelageya_1969@postgrespro.ru", "phone": "+70363378884"}
0005433616633	ED2137	8232 998533	DENIS ISAEV	{"email": "isaev.denis021976@postgrespro.ru", "phone": "+70538570307"}
0005433616634	300E56	1876 991398	RUSTAM VASILEV	{"email": "vasilev_rustam121977@postgrespro.ru", "phone": "+70234198772"}
0005433616635	DCE5A3	4362 108137	DMITRIY KOZLOV	{"phone": "+70448937490"}
0005433616636	30D064	4875 737936	IGOR KARPOV	{"phone": "+70555541753"}
0005433616637	30D064	6061 845229	RAISA KUDRYASHOVA	{"email": "r-kudryashova18021965@postgrespro.ru", "phone": "+70219248061"}
0005433616638	7F7C18	4802 763101	EVGENIYA DMITRIEVA	{"phone": "+70068333655"}
0005433616639	162133	4297 547969	BOGDAN MOISEEV	{"email": "moiseev_bogdan-1960@postgrespro.ru", "phone": "+70250897449"}
0005433616640	B1BA81	7695 692493	LYUBOV TIKHONOVA	{"email": "l_tikhonova-1966@postgrespro.ru", "phone": "+70521103090"}
0005433616641	B24F94	3885 312675	ALEKSANDR MAKSIMOV	{"email": "a.maksimov.121978@postgrespro.ru", "phone": "+70882412472"}
0005433616642	49D7BA	7369 728099	IVAN FROLOV	{"email": "ivan_frolov071972@postgrespro.ru", "phone": "+70959382479"}
0005433616643	1616CD	6911 629438	ALEKSEY NAZAROV	{"phone": "+70246183302"}
0005433616644	50AE53	4578 399875	RAFAEL FOMIN	{"phone": "+70851890520"}
0005433616645	B7EE95	0497 555657	SERGEY BARANOV	{"email": "baranovs1951@postgrespro.ru", "phone": "+70168601388"}
0005433616646	3E2B7F	1456 030464	VLADIMIR BONDARENKO	{"phone": "+70845516723"}
0005433616647	3E2B7F	3945 249906	ALEKSANDR ROMANOV	{"phone": "+70164747255"}
0005433616648	2F1215	6988 854842	TAMARA ERMAKOVA	{"email": "ermakova-tamara-091981@postgrespro.ru", "phone": "+70657811564"}
0005433616649	3C1835	5140 174335	DMITRIY FEDOTOV	{"phone": "+70369525997"}
0005433616650	3C1835	0245 915529	ALIK ANDREEV	{"email": "andreev.a-13121973@postgrespro.ru", "phone": "+70882077842"}
0005433616651	410F6A	9777 396948	NATALYA KOROLEVA	{"email": "n.koroleva-12081975@postgrespro.ru", "phone": "+70377673779"}
0005433616652	F44C0C	0392 264318	ANTONINA FILATOVA	{"email": "a-filatova-031969@postgrespro.ru", "phone": "+70392403414"}
0005433616653	69F582	0224 084680	OLGA NOVIKOVA	{"phone": "+70948006461"}
0005433616654	69F582	2809 919772	ALEKSANDR MOISEEV	{"phone": "+70734111720"}
0005433616655	69F582	5675 488963	MIKHAIL ROMANOV	{"email": "mromanov.1968@postgrespro.ru", "phone": "+70910976511"}
0005433616656	4D4873	5869 154335	EVGENIY VASILEV	{"email": "vasileve.101978@postgrespro.ru", "phone": "+70745984726"}
0005433616657	8DE8F1	8877 115679	GAGIK TIMOFEEV	{"phone": "+70047781438"}
0005433616658	8DE8F1	4263 103488	ANDREY ZAKHAROV	{"email": "a-zakharov1970@postgrespro.ru", "phone": "+70513206262"}
0005433616659	F7ADAD	9456 725471	YURIY SHEVCHENKO	{"email": "shevchenkoy_1971@postgrespro.ru", "phone": "+70805180613"}
0005433616660	5B37C7	5292 411407	LIDIYA MOISEEVA	{"phone": "+70988301468"}
0005433616661	DF46A0	6325 768958	TATYANA KOLESNIKOVA	{"email": "kolesnikova_t.031974@postgrespro.ru", "phone": "+70628146008"}
0005433616662	2276E0	9378 397168	ALEKSANDR FEDOROV	{"email": "afedorov-031968@postgrespro.ru", "phone": "+70181570665"}
0005433616663	AD07E8	0372 989103	MARIYA DANILOVA	{"phone": "+70352028995"}
0005433616664	AD07E8	7825 936001	RAFAIL PAVLOV	{"phone": "+70371264050"}
0005433616665	377AC3	4481 979014	LYUBOV NAZAROVA	{"phone": "+70421126094"}
0005433616666	B37B98	0304 319623	LYUDMILA EGOROVA	{"phone": "+70289263382"}
0005433616667	1FA58B	6495 951747	ZHANNA KOVALEVA	{"email": "zhanna.kovaleva-1971@postgrespro.ru", "phone": "+70524006424"}
0005433616668	49FB85	8879 040665	IRINA IVANOVA	{"phone": "+70039891135"}
0005433616669	49FB85	8456 915594	NATALYA GAVRILOVA	{"phone": "+70519276595"}
0005433616670	49FB85	1434 197490	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey.20101975@postgrespro.ru", "phone": "+70159086089"}
0005433616671	E72A86	1291 501237	TATYANA BORISOVA	{"email": "borisovatatyana-101971@postgrespro.ru", "phone": "+70827701252"}
0005433616672	73B8EC	4155 079083	TAMARA MIKHAYLOVA	{"email": "t.mikhaylova1978@postgrespro.ru", "phone": "+70072741306"}
0005433616673	8EA0B7	4188 323038	GALINA POPOVA	{"email": "popova.g_03031973@postgrespro.ru", "phone": "+70827737902"}
0005433616674	BDB89E	0986 605093	ELIZAVETA TITOVA	{"phone": "+70605895538"}
0005433616675	BDB89E	7371 976986	VLADIMIR ORLOV	{"email": "orlov-vladimir_31031986@postgrespro.ru", "phone": "+70058278114"}
0005433616676	D2236C	5624 349769	VALENTINA VOROBEVA	{"email": "vorobeva-v-1974@postgrespro.ru", "phone": "+70330907088"}
0005433616677	D2236C	1806 414637	ANATOLIY KAZAKOV	{"email": "kazakov.a-16021970@postgrespro.ru", "phone": "+70674549943"}
0005433616678	FA8B25	3640 904936	NIKOLAY GUSEV	{"phone": "+70340141057"}
0005433616679	FA8B25	5250 834134	MAKSIM KUZNECOV	{"email": "kuznecovmaksim.091970@postgrespro.ru", "phone": "+70247900522"}
0005433616680	5D68D3	2152 901680	ALEKSANDR MOROZOV	{"phone": "+70941956230"}
0005433616681	13C3EB	2060 069711	SERGEY MEDVEDEV	{"phone": "+70259133443"}
0005433616682	13C3EB	6646 892234	IRINA TIMOFEEVA	{"email": "irinatimofeeva.051983@postgrespro.ru", "phone": "+70255544516"}
0005433616683	E00CCA	5361 834098	ANASTASIYA ORLOVA	{"phone": "+70949095746"}
0005433616684	E00CCA	4801 017210	ALEKSANDR KOROLEV	{"phone": "+70950427710"}
0005433616685	DB2CEB	1258 391741	VERA GRISHINA	{"phone": "+70888885482"}
0005433616686	AB1E65	8269 690257	RAMILYA IVANOVA	{"phone": "+70925496919"}
0005433616687	E0C380	3343 888397	DIANA GAVRILOVA	{"phone": "+70165598829"}
0005433616688	E0C380	4406 710433	VALENTINA YUDINA	{"phone": "+70378900279"}
0005433616689	E0C380	6749 230196	ELENA IVANOVA	{"phone": "+70997534738"}
0005433616690	57366D	4140 504598	MAKSIM ZAYCEV	{"email": "m-zaycev1960@postgrespro.ru", "phone": "+70316922899"}
0005433616691	57366D	1605 962323	OLGA ANISIMOVA	{"email": "anisimova.o.091974@postgrespro.ru", "phone": "+70517645961"}
0005433616692	9CC993	9110 483986	SERGEY AFANASEV	{"phone": "+70061799853"}
0005433616693	4F465B	7510 139036	VASILIY KUZMIN	{"phone": "+70052156408"}
0005433616694	351190	9808 763416	VIKTOR KOROLEV	{"phone": "+70579468749"}
0005433616695	351190	1780 921767	OLESYA IVANOVA	{"email": "ivanova-o_031964@postgrespro.ru", "phone": "+70867963608"}
0005433616696	07377C	0197 389347	MARINA YAKOVLEVA	{"phone": "+70229434385"}
0005433616697	5AE553	2723 967837	MAYYA LEBEDEVA	{"email": "lebedevamayya-14121970@postgrespro.ru", "phone": "+70599618458"}
0005433616698	1B2A1B	2320 929466	ELENA NAZAROVA	{"phone": "+70715459359"}
0005433616699	2E7081	9176 616326	VLADIMIR NOVIKOV	{"phone": "+70337358270"}
0005433616700	DE9C11	0038 671333	ANATOLIY MATVEEV	{"phone": "+70806458749"}
0005433616701	DE9C11	1257 210421	VLADIMIR KRASNOV	{"email": "vladimir_krasnov_091958@postgrespro.ru", "phone": "+70449171961"}
0005433616702	614E6E	4606 912541	ELENA FILIPPOVA	{"email": "elenafilippova.071975@postgrespro.ru", "phone": "+70245596297"}
0005433616703	4AE361	8349 700917	SVETLANA POPOVA	{"phone": "+70571538967"}
0005433616704	22B10C	5188 462554	IRINA ZHURAVLEVA	{"email": "zhuravleva_irina_011980@postgrespro.ru", "phone": "+70021936228"}
0005433616705	6F05B1	5895 057278	VALERIY PETROV	{"email": "valeriy.petrov.29051966@postgrespro.ru", "phone": "+70136343561"}
0005433616706	D40B52	9035 174538	VYACHESLAV DENISOV	{"email": "denisov.vyacheslav1980@postgrespro.ru", "phone": "+70068260405"}
0005433616707	FD2106	7746 458205	SERGEY SHEVCHENKO	{"phone": "+70860105087"}
0005433616708	870663	0924 098739	ALEKSEY FEDOTOV	{"email": "aleksey.fedotov22111969@postgrespro.ru", "phone": "+70271686919"}
0005433616709	870663	1050 909846	IRINA ZHURAVLEVA	{"email": "izhuravleva-031985@postgrespro.ru", "phone": "+70898134890"}
0005433616710	631580	9706 206959	NADEZHDA SEMENOVA	{"email": "semenova_n031970@postgrespro.ru", "phone": "+70117050812"}
0005433616711	3CBFD2	6802 700487	RIMMA ANDREEVA	{"phone": "+70111683022"}
0005433616712	8E1F06	1721 372605	MARIYA MOROZOVA	{"phone": "+70576847855"}
0005433616713	BC3A04	1085 062593	IRINA VOROBEVA	{"email": "irinavorobeva1965@postgrespro.ru", "phone": "+70483852796"}
0005433616714	AC969F	1186 349030	LYUDMILA ZAKHAROVA	{"email": "zakharova-lyudmila-121973@postgrespro.ru", "phone": "+70852074558"}
0005433616715	842716	9741 130219	VYACHESLAV MIKHAYLOV	{"email": "vyacheslavmikhaylov_17011975@postgrespro.ru", "phone": "+70027735581"}
0005433616716	BE568D	9274 007448	NATALYA KUZMINA	{"phone": "+70886520711"}
0005433616717	57BF85	8703 572045	VLADIMIR VASILEV	{"email": "vvasilev1958@postgrespro.ru", "phone": "+70793931137"}
0005433616718	57BF85	6881 701580	DMITRIY SEMENOV	{"email": "d-semenov-1961@postgrespro.ru", "phone": "+70692637821"}
0005433616719	8DE5EC	5122 028577	DARYA KUZNECOVA	{"phone": "+70661177576"}
0005433616720	4279B2	4782 269513	VALENTINA VASILEVA	{"email": "valentina-vasileva_16011966@postgrespro.ru", "phone": "+70505511210"}
0005433616721	4279B2	8388 094462	TATYANA SOROKINA	{"phone": "+70152465005"}
0005433616722	CB8F35	8038 447819	EVGENIY SCHERBAKOV	{"email": "scherbakov_e_06121972@postgrespro.ru", "phone": "+70580024361"}
0005433616723	CB8F35	0396 458811	RUSLAN SCHERBAKOV	{"phone": "+70861271186"}
0005433616724	C5DAE6	3290 509626	RAISA SCHERBAKOVA	{"phone": "+70981304118"}
0005433616725	585433	4647 959204	ILYA ALEKSEEV	{"email": "alekseev_i12021979@postgrespro.ru", "phone": "+70175459985"}
0005433616726	0563EF	2744 685793	ANTONINA EFIMOVA	{"phone": "+70435965270"}
0005433616727	D5005B	5930 718426	ALBINA KULIKOVA	{"phone": "+70177366493"}
0005433616728	E630F7	7332 798883	LYUDMILA IVANOVA	{"email": "ivanova-l.061958@postgrespro.ru", "phone": "+70123839874"}
0005433616729	E630F7	3567 467103	SVETLANA VLASOVA	{"phone": "+70068081717"}
0005433616730	C82253	4545 463026	ELENA MAKAROVA	{"phone": "+70482055142"}
0005433616731	C82253	3316 425411	ZINAIDA FROLOVA	{"email": "frolova_z-021975@postgrespro.ru", "phone": "+70067056231"}
0005433616732	DAC294	9597 267171	LYUBOV KUZNECOVA	{"phone": "+70060677322"}
0005433616733	DAC294	2972 134658	EKATERINA KUDRYASHOVA	{"email": "e-kudryashova.26031971@postgrespro.ru", "phone": "+70416201085"}
0005433616734	0B5BAB	1986 217248	ALBERT VLASOV	{"phone": "+70149909012"}
0005433616735	0B5BAB	8291 225519	GENNADIY FILIPPOV	{"email": "gennadiy_filippov-04101979@postgrespro.ru", "phone": "+70094321316"}
0005433616736	0B5BAB	9418 577036	LILIYA NIKOLAEVA	{"email": "nikolaevaliliya-051970@postgrespro.ru", "phone": "+70783060935"}
0005433616737	40F280	3866 284604	DIANA KUZNECOVA	{"email": "kuznecovadiana-29031968@postgrespro.ru", "phone": "+70451702568"}
0005433616738	41ABDF	0819 861914	NATALYA VOLKOVA	{"email": "n.volkova17031963@postgrespro.ru", "phone": "+70926078745"}
0005433616739	C97C43	3019 283705	ALEKSANDR VLASOV	{"email": "a_vlasov-121978@postgrespro.ru", "phone": "+70894289689"}
0005433616740	235012	4873 229858	ANASTASIYA MAKAROVA	{"email": "a-makarova-1964@postgrespro.ru", "phone": "+70143328184"}
0005433616741	972519	8414 906717	TAMARA KAZAKOVA	{"email": "tamara.kazakova_11061960@postgrespro.ru", "phone": "+70601745247"}
0005433616743	460D77	3428 994406	YULIYA PETROVA	{"email": "petrova.y.021974@postgrespro.ru", "phone": "+70527183929"}
0005433616744	BE0634	3567 195170	MARINA ORLOVA	{"phone": "+70466123028"}
0005433616745	BE0634	8928 645060	FLYURA TARASOVA	{"email": "tarasova_f.041982@postgrespro.ru", "phone": "+70741107812"}
0005433616746	B2DA24	0061 645777	VALENTINA TIKHONOVA	{"phone": "+70498419230"}
0005433616747	42A9AF	5641 979238	NIKOLAY KRASNOV	{"email": "krasnov_n-051980@postgrespro.ru", "phone": "+70552243857"}
0005433616748	473911	5621 368091	YANA EGOROVA	{"phone": "+70964364025"}
0005433616749	473911	3281 997105	ANDREY SMIRNOV	{"email": "a_smirnov_26021977@postgrespro.ru", "phone": "+70683623244"}
0005433616750	9757ED	7177 363092	ALEKSANDR ZHUKOV	{"phone": "+70173390834"}
0005433616751	4BDBDF	0675 373798	VALENTIN KUZMIN	{"phone": "+70805145946"}
0005433616752	C63D77	6199 274380	ALEVTINA MASLOVA	{"email": "amaslova_011968@postgrespro.ru", "phone": "+70376210607"}
0005433616753	6676EA	7221 527045	YULIYA KULIKOVA	{"phone": "+70659225982"}
0005433616754	6676EA	7625 093322	YURIY MOROZOV	{"phone": "+70632233099"}
0005433616755	074BFD	6368 865671	MIKHAIL NIKOLAEV	{"email": "mnikolaev081990@postgrespro.ru", "phone": "+70326958378"}
0005433616756	F6CF23	2458 399817	ALEKSEY POPOV	{"phone": "+70851198677"}
0005433616757	F6CF23	6003 030843	ALEKSEY VLASOV	{"phone": "+70115304550"}
0005433616758	07DDBB	7407 804078	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev_041963@postgrespro.ru", "phone": "+70214967467"}
0005433616759	9F7C11	7472 039575	VLADIMIR MOROZOV	{"phone": "+70217363177"}
0005433616760	9F7C11	5412 615205	YURIY FOMIN	{"email": "y_fomin_1976@postgrespro.ru", "phone": "+70948227407"}
0005433616761	AF7A2A	9021 525759	NATALIYA SOROKINA	{"email": "nataliyasorokina_1970@postgrespro.ru", "phone": "+70917013701"}
0005433616762	7F86E8	5400 665964	NIKOLAY VOLKOV	{"phone": "+70125964473"}
0005433616763	D811CA	0640 108299	GALINA POPOVA	{"phone": "+70681737038"}
0005433616764	E1173B	2884 750961	LYUDMILA SIDOROVA	{"phone": "+70521702237"}
0005433616765	E1173B	6690 022175	VLADLEN KARPOV	{"phone": "+70481281689"}
0005433616766	A255A1	1794 210379	ELENA EFREMOVA	{"email": "e-efremova-18111983@postgrespro.ru", "phone": "+70146102550"}
0005433616767	A255A1	2416 891068	ANDREY PAVLOV	{"phone": "+70126468470"}
0005433616768	50C4C7	7598 792569	ALEKSANDR DMITRIEV	{"email": "a.dmitriev.081976@postgrespro.ru", "phone": "+70578639705"}
0005433616769	54502C	0659 044434	OLGA IVANOVA	{"phone": "+70441524599"}
0005433616770	54502C	4349 807802	KLAVDIYA ARKHIPOVA	{"phone": "+70024396873"}
0005433616771	CCFCD8	1118 477940	MARIYA BOGDANOVA	{"email": "bogdanova-mariya26111965@postgrespro.ru", "phone": "+70073557805"}
0005433616772	CCFCD8	9396 721894	SERGEY SEMENOV	{"email": "semenov-s111977@postgrespro.ru", "phone": "+70347053525"}
0005433616773	D26765	5356 513439	RUSLAN SCHERBAKOV	{"phone": "+70212243181"}
0005433616774	0E4D35	8472 257746	ANDREY FEDOTOV	{"phone": "+70482018854"}
0005433616775	3A735C	6351 576896	YULIYA BARANOVA	{"email": "baranova_y-1969@postgrespro.ru", "phone": "+70016538841"}
0005433616776	A924B7	7546 102697	ALEKSANDR CHERNOV	{"email": "achernov-08121975@postgrespro.ru", "phone": "+70330538364"}
0005433616777	4D0300	2174 880503	IRINA MELNIKOVA	{"email": "i_melnikova-19031961@postgrespro.ru", "phone": "+70246762153"}
0005433616778	4D0300	2528 751180	DENIS SAVELEV	{"email": "d.savelev.1973@postgrespro.ru", "phone": "+70995898374"}
0005433616779	577E34	4707 120323	KSENIYA KOZLOVA	{"email": "kozlova_kseniya_1965@postgrespro.ru", "phone": "+70904251170"}
0005433616780	C2E39B	7326 307520	KONSTANTIN SHEVCHENKO	{"phone": "+70051371999"}
0005433616781	7BC64E	0861 918223	SVETLANA KUZNECOVA	{"phone": "+70578423089"}
0005433616782	7BC64E	5687 204193	VLADIMIR ALEKSANDROV	{"phone": "+70628406525"}
0005433616783	45554B	4219 635576	DMITRIY BONDARENKO	{"phone": "+70743357500"}
0005433616784	45554B	5526 334467	MARIYA FEDOROVA	{"email": "fedorova_mariya31101976@postgrespro.ru", "phone": "+70316634213"}
0005433616785	BD2AFD	2056 454393	ANNA NAUMOVA	{"phone": "+70840000110"}
0005433616786	BD2AFD	8926 169915	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov.031976@postgrespro.ru", "phone": "+70693694298"}
0005433616787	F63CE1	7101 507889	DANIL SEMENOV	{"phone": "+70130209518"}
0005433616788	7DD6D0	0082 102658	MATVEY PAVLOV	{"email": "matvey-pavlov-23031981@postgrespro.ru", "phone": "+70163817983"}
0005433616789	D445A9	2542 566716	ALEKSANDRA BARANOVA	{"email": "baranova-a.1959@postgrespro.ru", "phone": "+70798699640"}
0005433616790	6B581D	5233 465595	ANDREY SMIRNOV	{"phone": "+70667002837"}
0005433616791	B3C0F3	1642 888151	EVGENIY PETROV	{"phone": "+70688713133"}
0005433616792	1D3CEA	2536 646008	ALSU KAZAKOVA	{"email": "kazakova-alsu1964@postgrespro.ru", "phone": "+70515476631"}
0005433616793	1D3CEA	7774 944512	TAMARA FOMINA	{"email": "fomina_t_04051968@postgrespro.ru", "phone": "+70315430007"}
0005433616794	1D3CEA	4531 330148	SERGEY POPOV	{"phone": "+70073596796"}
0005433616795	99CC7A	1820 635803	TATYANA TIKHONOVA	{"phone": "+70695268932"}
0005433616796	ED0B31	4394 994169	ALEKSEY KOZLOV	{"phone": "+70145550360"}
0005433616797	73A9AD	2058 721565	SERGEY KAZAKOV	{"phone": "+70778265223"}
0005433616798	73A9AD	9346 669387	OLGA TIKHONOVA	{"phone": "+70485407308"}
0005433616799	CE739E	7631 660575	ALEVTINA MOISEEVA	{"phone": "+70222159354"}
0005433616800	B79BE1	8491 129293	KIRILL FEDOTOV	{"email": "k-fedotov-1974@postgrespro.ru", "phone": "+70929147958"}
0005433616801	956E5F	6279 605634	ANATOLIY ZHUKOV	{"email": "zhukovanatoliy_081975@postgrespro.ru", "phone": "+70169337513"}
0005433616802	956E5F	0448 511242	ALEKSEY POPOV	{"email": "aleksey.popov011964@postgrespro.ru", "phone": "+70875356740"}
0005433616803	CB584F	8500 377998	ELENA RODIONOVA	{"email": "rodionova.elena23051964@postgrespro.ru", "phone": "+70375234626"}
0005433633245	E66031	7675 323599	NIKITA FEDOROV	{"phone": "+70412347916"}
0005433616804	FD89EA	0502 976667	VALENTINA YAKOVLEVA	{"email": "yakovleva_v_14091964@postgrespro.ru", "phone": "+70936163295"}
0005433616805	901459	0131 884537	ROMAN SOKOLOV	{"email": "roman_sokolov_101975@postgrespro.ru", "phone": "+70035566136"}
0005433616806	901459	4703 118575	ANDREY VASILEV	{"email": "andrey-vasilev1968@postgrespro.ru", "phone": "+70065028097"}
0005433616807	F058EF	7728 473290	DMITRIY KISELEV	{"email": "kiselev.dmitriy1972@postgrespro.ru", "phone": "+70466346977"}
0005433616808	89C5B2	8666 613987	LYUBOV KOROLEVA	{"phone": "+70144280790"}
0005433616809	014C42	5443 464946	NADEZHDA TARASOVA	{"email": "n-tarasova.081975@postgrespro.ru", "phone": "+70492555085"}
0005433616810	428414	2717 711016	SOFYA DAVYDOVA	{"email": "davydova-s.20111962@postgrespro.ru", "phone": "+70428963670"}
0005433616811	F00808	5493 733775	MAKSIM MAKSIMOV	{"phone": "+70188433894"}
0005433616812	C25EB8	2685 876153	ELENA ERMAKOVA	{"phone": "+70639050419"}
0005433616813	89A1FE	1569 331865	POLINA SERGEEVA	{"phone": "+70868320442"}
0005433616814	D1EA7A	2535 429950	DARYA ZAKHAROVA	{"email": "darya_zakharova-041974@postgrespro.ru", "phone": "+70935636275"}
0005433616815	1E4A07	0886 147590	MARIYA KUZNECOVA	{"phone": "+70496111680"}
0005433616816	1E4A07	6091 020492	ALEKSANDR KRASNOV	{"email": "krasnov-a.1985@postgrespro.ru", "phone": "+70813955848"}
0005433616817	D60AAE	9634 043653	MIKHAIL POPOV	{"email": "popov_m-28121969@postgrespro.ru", "phone": "+70567456178"}
0005433616818	B20BE6	2930 907707	ARTEM POPOV	{"phone": "+70290586974"}
0005433616819	BC4CB9	6105 850843	ANASTASIYA BOGDANOVA	{"email": "bogdanova_a-30081978@postgrespro.ru", "phone": "+70932650694"}
0005433616820	2F8731	3375 522801	BORIS ORLOV	{"email": "orlovboris_1961@postgrespro.ru", "phone": "+70620879479"}
0005433616821	5D977D	1971 698610	ALEKSEY KUZNECOV	{"phone": "+70086728046"}
0005433616822	A0F4A3	4228 768131	ELENA ANDREEVA	{"phone": "+70053261144"}
0005433616823	A0F4A3	7321 194135	SERGEY POPOV	{"email": "sergey_popov.1983@postgrespro.ru", "phone": "+70892543344"}
0005433616824	A0F4A3	2514 124223	YULIYA LAZAREVA	{"phone": "+70784021050"}
0005433616825	EE0663	8118 258669	MARAT KUZNECOV	{"email": "m-kuznecov_12071971@postgrespro.ru", "phone": "+70345778865"}
0005433616826	809181	5792 587306	RUSLAN KISELEV	{"phone": "+70393781439"}
0005433616827	918AED	9980 236429	YURIY KUZNECOV	{"phone": "+70284182844"}
0005433616828	D0BD63	9105 492742	ROZA POTAPOVA	{"phone": "+70017255779"}
0005433616829	C72591	7169 201979	VLADIMIR ANDREEV	{"email": "andreevvladimir_031969@postgrespro.ru", "phone": "+70369092965"}
0005433616830	C72591	8757 297898	DMITRIY MAKAROV	{"email": "makarovd_041981@postgrespro.ru", "phone": "+70577330242"}
0005433633495	62B81B	7338 003282	ALEKSANDR OSIPOV	{"phone": "+70998094209"}
0005433633213	6219A5	2847 174214	EVGENIY ZHURAVLEV	{"phone": "+70696634449"}
0005433633214	E8E882	9687 719201	LARISA BORISOVA	{"phone": "+70504538075"}
0005433633215	E8E882	8507 787494	ZOYA KULIKOVA	{"email": "zoya.kulikova.23081963@postgrespro.ru", "phone": "+70733820213"}
0005433633216	72E3C5	4319 916074	TIMOFEY DMITRIEV	{"phone": "+70524605521"}
0005433633217	72E3C5	3293 183214	ZOYA LUKYANOVA	{"email": "lukyanova_z-1977@postgrespro.ru", "phone": "+70896924005"}
0005433633218	200E76	0518 747883	VASILIY KUDRYASHOV	{"phone": "+70823317139"}
0005433633219	200E76	6124 666438	SERGEY FOMIN	{"email": "fomin_sergey_04101968@postgrespro.ru", "phone": "+70520092728"}
0005433633220	7A85CE	3449 993538	VLADIMIR TARASOV	{"email": "tarasov_vladimir.02051965@postgrespro.ru", "phone": "+70371525818"}
0005433633221	635C1E	7295 639840	ALEKSANDR VOLKOV	{"phone": "+70024945844"}
0005433633222	ABE16B	2869 141220	NIKOLAY CHERNOV	{"phone": "+70472431486"}
0005433633223	ABE16B	7656 885650	ANDREY MIRONOV	{"email": "andreymironov101967@postgrespro.ru", "phone": "+70323426896"}
0005433633224	2B88D0	5437 261269	ALLA PETROVA	{"email": "petrova.a031967@postgrespro.ru", "phone": "+70788226332"}
0005433633225	2B88D0	9146 372381	NINA CHERNOVA	{"email": "chernova-n.041982@postgrespro.ru", "phone": "+70607811602"}
0005433633226	46CFD8	6819 814770	ANNA PAVLOVA	{"email": "anna-pavlova-1972@postgrespro.ru", "phone": "+70273144001"}
0005433633227	B5792A	6097 875669	MARIYA EGOROVA	{"phone": "+70961929958"}
0005433633228	F061C8	8530 230195	NIKOLAY BARANOV	{"phone": "+70858064470"}
0005433633229	F061C8	9176 350738	ANATOLIY KULIKOV	{"email": "kulikov-a1978@postgrespro.ru", "phone": "+70223737180"}
0005433633230	834D6F	8146 588469	MARIYA SIDOROVA	{"phone": "+70048760757"}
0005433633231	834D6F	1789 336818	VALENTINA NIKITINA	{"email": "nikitinavalentina.1979@postgrespro.ru", "phone": "+70684702382"}
0005433633232	EC234F	1311 369485	ILYA BELOV	{"email": "ilyabelov.111978@postgrespro.ru", "phone": "+70891810398"}
0005433633233	EC234F	6308 303328	LYUDMILA GRISHINA	{"email": "grishina.l.1990@postgrespro.ru", "phone": "+70122334940"}
0005433633234	971D76	1360 535719	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay.22041964@postgrespro.ru", "phone": "+70405530604"}
0005433633235	3026C2	2066 124044	TAMARA PETROVA	{"phone": "+70559114819"}
0005433633236	BABAAF	5700 518872	ELENA KOLESNIKOVA	{"phone": "+70968597561"}
0005433633237	72B1D0	1620 885845	YURIY SOLOVEV	{"email": "solovevyuriy-1985@postgrespro.ru", "phone": "+70102581597"}
0005433633238	72B1D0	8067 381974	ANNA PETROVA	{"email": "petrova.a_1979@postgrespro.ru", "phone": "+70218206756"}
0005433633239	72B1D0	3187 586839	ANNA MASLOVA	{"phone": "+70426282794"}
0005433633240	F58B3A	1446 299936	KIRA VOROBEVA	{"email": "vorobeva_kira01121973@postgrespro.ru", "phone": "+70292854636"}
0005433633241	F58B3A	9803 817751	ELENA FILIPPOVA	{"phone": "+70752910379"}
0005433633242	3BAC17	0629 715730	LILIYA KALININA	{"email": "kalininaliliya_1980@postgrespro.ru", "phone": "+70334260807"}
0005433633243	3BAC17	8875 462943	MIKHAIL MATVEEV	{"phone": "+70282902925"}
0005433633244	E66031	1743 508155	MARINA NIKIFOROVA	{"phone": "+70209354907"}
0005433633246	ED43FA	8277 705095	SVETLANA KOROLEVA	{"phone": "+70505988254"}
0005433633247	FA05F1	4680 748622	VIKTORIYA ALEKSANDROVA	{"phone": "+70902659091"}
0005433633248	A906C4	0447 970983	MAKSIM VOLKOV	{"phone": "+70191260751"}
0005433633249	8EA292	3988 917544	EKATERINA ROMANOVA	{"phone": "+70973215337"}
0005433633250	1565EE	6632 183216	TATYANA KULIKOVA	{"email": "kulikova-tatyana_31081983@postgrespro.ru", "phone": "+70719020063"}
0005433633251	1565EE	7262 442402	SVETLANA BELOVA	{"phone": "+70068501175"}
0005433633252	FA00A3	5218 489889	SERGEY FILIPPOV	{"phone": "+70034123716"}
0005433633253	FA00A3	3105 914006	MARIYA VOROBEVA	{"email": "m-vorobeva-10021960@postgrespro.ru", "phone": "+70959960228"}
0005433633254	634D19	9243 171035	RAISA TARASOVA	{"phone": "+70506225165"}
0005433633255	001436	9007 567860	VLADIMIR KUZMIN	{"email": "v.kuzmin-1965@postgrespro.ru", "phone": "+70256976257"}
0005433633256	399B8B	8843 690485	EKATERINA ALEKSANDROVA	{"email": "ekaterina_aleksandrova.031965@postgrespro.ru", "phone": "+70760099674"}
0005433633257	399B8B	5335 979285	TATYANA EFREMOVA	{"phone": "+70702723233"}
0005433633258	D8E3D8	8521 528805	DARYA SAVELEVA	{"phone": "+70265084535"}
0005433633259	CA246F	9181 637456	DAMIR ANDREEV	{"phone": "+70914299668"}
0005433633260	CA246F	7428 640059	LYUBOV ANDREEVA	{"email": "andreeval.17111977@postgrespro.ru", "phone": "+70768979376"}
0005433633261	11FE0E	7843 702982	VERONIKA KISELEVA	{"email": "kiseleva-veronika041974@postgrespro.ru", "phone": "+70739393404"}
0005433633262	11FE0E	0609 819422	ANASTASIYA KOLESNIKOVA	{"email": "kolesnikova.anastasiya_04101962@postgrespro.ru", "phone": "+70071890497"}
0005433633263	11FE0E	3908 034418	TATYANA ROMANOVA	{"phone": "+70057605282"}
0005433633264	9FCFA0	6480 981720	ANNA CHERNOVA	{"email": "a-chernova-15101982@postgrespro.ru", "phone": "+70796867015"}
0005433633265	B97BD7	9981 467403	EVGENIY FEDOTOV	{"email": "fedotovevgeniy.14011977@postgrespro.ru", "phone": "+70776390446"}
0005433633266	B97BD7	9778 342118	LYUDMILA VLASOVA	{"email": "vlasova-lyudmila-1965@postgrespro.ru", "phone": "+70693367563"}
0005433633267	9A5658	0626 901362	VYACHESLAV YAKOVLEV	{"email": "yakovlev_vyacheslav-101973@postgrespro.ru", "phone": "+70900811137"}
0005433633268	9A5658	5322 738820	YULIYA LAZAREVA	{"phone": "+70760877765"}
0005433633269	3017BC	7676 584671	TATYANA VASILEVA	{"email": "tatyana-vasileva-15101975@postgrespro.ru", "phone": "+70704520681"}
0005433633270	3017BC	1381 221681	NATALYA MIRONOVA	{"email": "mironova_n031968@postgrespro.ru", "phone": "+70750610668"}
0005433633271	160289	1485 823927	VIKTORIYA ROMANOVA	{"phone": "+70059153596"}
0005433633272	314102	2768 426362	VLADIMIR ABRAMOV	{"phone": "+70371202787"}
0005433633273	D5E9A5	3825 968653	ALEKSANDR DMITRIEV	{"email": "dmitriev_aleksandr.081968@postgrespro.ru", "phone": "+70422353997"}
0005433633274	94CB1B	9332 422210	ROMAN NOVIKOV	{"phone": "+70304544706"}
0005433633275	5411E0	7301 632231	ANNA GERASIMOVA	{"email": "gerasimova_a_091964@postgrespro.ru", "phone": "+70399375447"}
0005433633276	5411E0	4292 292988	ELVIRA PAVLOVA	{"email": "e.pavlova_04071971@postgrespro.ru", "phone": "+70722300182"}
0005433633277	1232A9	7535 383820	ALLA NIKOLAEVA	{"phone": "+70654929598"}
0005433633278	1232A9	2031 501599	ANNA OSIPOVA	{"email": "annaosipova_18021981@postgrespro.ru", "phone": "+70273761828"}
0005433633279	4F5848	1115 976794	TATYANA FILIPPOVA	{"phone": "+70488037751"}
0005433633280	2B9F6F	3703 340129	ANDREY IVANOV	{"email": "ivanov.andrey1974@postgrespro.ru", "phone": "+70123004199"}
0005433633281	697ACD	7438 204491	NATALYA FEDOROVA	{"email": "fedorova_natalya1971@postgrespro.ru", "phone": "+70814976752"}
0005433633282	697ACD	6869 098096	YURIY TARASOV	{"email": "tarasovy_041976@postgrespro.ru", "phone": "+70726059791"}
0005433633283	ED1968	9774 916319	ALEKSEY CHERNOV	{"phone": "+70175180913"}
0005433633284	01BABE	2398 843137	VALENTINA KRASNOVA	{"email": "krasnova_valentina_24041967@postgrespro.ru", "phone": "+70075986930"}
0005433633285	01BABE	2019 141387	ROMAN SIDOROV	{"phone": "+70608571596"}
0005433633286	37B0EB	3481 210049	IRINA ZHURAVLEVA	{"phone": "+70791219992"}
0005433633287	4FA042	7000 231063	DANIYA KOVALEVA	{"email": "kovaleva.d-19071974@postgrespro.ru", "phone": "+70546456253"}
0005433633288	4FA042	0413 537488	YURIY ANDREEV	{"phone": "+70461687035"}
0005433633289	5BE75D	8327 296785	DMITRIY NOVIKOV	{"email": "d.novikov.1971@postgrespro.ru", "phone": "+70823991983"}
0005433633290	F41829	5987 883849	VLADIMIR NAUMOV	{"phone": "+70980830348"}
0005433633291	793CC9	2188 516378	VALERIY PETROV	{"phone": "+70566392509"}
0005433633292	1C5096	4828 140752	DMITRIY FROLOV	{"phone": "+70075603116"}
0005433633293	856285	0447 864834	EKATERINA KUZNECOVA	{"phone": "+70264771362"}
0005433633294	856285	1980 806928	MAKSIM SERGEEV	{"phone": "+70589201564"}
0005433633295	22B309	7311 896823	RUSLAN ISAEV	{"phone": "+70411919537"}
0005433633296	22B309	4293 502902	VIKTORIYA KUZNECOVA	{"phone": "+70454730385"}
0005433633297	896420	3914 285873	VIKTOR MELNIKOV	{"email": "v.melnikov.22111982@postgrespro.ru", "phone": "+70080841571"}
0005433633298	71A4C9	5260 324346	VALERIY KULIKOV	{"phone": "+70378793874"}
0005433633299	D96C28	9537 124366	ALEKSANDR MAKAROV	{"phone": "+70044294487"}
0005433633300	5E0267	1134 272470	ALEKSANDR CHERNOV	{"phone": "+70258408429"}
0005433633301	EB4346	8845 490878	NATALYA MELNIKOVA	{"phone": "+70153242191"}
0005433633302	C9F193	7189 480067	ROMAN GORBUNOV	{"email": "roman_gorbunov121957@postgrespro.ru", "phone": "+70522225580"}
0005433633303	15469E	9029 708134	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr061961@postgrespro.ru", "phone": "+70434339481"}
0005433633304	387EAD	3908 692162	EVGENIY ISAEV	{"phone": "+70970662233"}
0005433633305	4FCB0C	8630 511544	YANA GORBUNOVA	{"email": "gorbunova_yana_1977@postgrespro.ru", "phone": "+70969415657"}
0005433633306	B0047F	2776 551327	EGOR GORBUNOV	{"email": "gorbunov.e.091982@postgrespro.ru", "phone": "+70869984736"}
0005433633307	B0047F	6162 732512	ANASTASIYA NIKITINA	{"phone": "+70863853145"}
0005433633308	B0047F	7353 011841	SERGEY EGOROV	{"email": "egorov-sergey.121971@postgrespro.ru", "phone": "+70494056089"}
0005433633309	C64427	1618 620727	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.nikolay_071968@postgrespro.ru", "phone": "+70178169052"}
0005433633310	D3F2F3	2141 059814	MAKSIM PAVLOV	{"phone": "+70328551552"}
0005433633311	D3F2F3	1421 132667	DENIS DMITRIEV	{"email": "dmitriev_denis-20091967@postgrespro.ru", "phone": "+70173228427"}
0005433633312	23E0F9	5334 954589	GALINA NESTEROVA	{"phone": "+70141713392"}
0005433633313	23E0F9	1688 033997	DENIS POPOV	{"phone": "+70640020806"}
0005433633314	FD5744	7968 542190	EKATERINA PETROVA	{"email": "petrova_e.19041958@postgrespro.ru", "phone": "+70612862423"}
0005433633315	FD5744	9746 818728	ALEKSEY PAVLOV	{"phone": "+70260813790"}
0005433633316	28BD47	6713 830516	KARINA MIRONOVA	{"phone": "+70515425557"}
0005433633317	E143CC	9472 619715	YULIYA IVANOVA	{"email": "ivanova-yuliya-101986@postgrespro.ru", "phone": "+70638983663"}
0005433633318	A75ECC	8535 229253	VITALIY DMITRIEV	{"email": "dmitriev_vitaliy_19121964@postgrespro.ru", "phone": "+70891174137"}
0005433633319	9D9B9F	8689 962203	ALIYA IVANOVA	{"phone": "+70016783576"}
0005433633320	8E370C	3896 102256	ELENA NIKOLAEVA	{"email": "nikolaeva.e_031969@postgrespro.ru", "phone": "+70541883166"}
0005433633321	CD3333	6013 573133	IVAN KUDRYASHOV	{"email": "kudryashov_ivan.08111962@postgrespro.ru", "phone": "+70541541368"}
0005433633322	CD3333	0293 261282	DARYA ZAKHAROVA	{"phone": "+70877999430"}
0005433633323	18AF43	6631 085800	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr-1966@postgrespro.ru", "phone": "+70117037218"}
0005433633324	29491D	1954 400708	MAKSIM GUSEV	{"phone": "+70345249465"}
0005433633325	996855	5133 255773	YURIY SIDOROV	{"email": "sidorov_yuriy.051971@postgrespro.ru", "phone": "+70573726841"}
0005433633326	996855	4457 978251	IVAN ORLOV	{"phone": "+70692095471"}
0005433633327	C09BEF	2760 761293	VLADIMIR KISELEV	{"phone": "+70223223698"}
0005433633328	C09BEF	5129 237008	LIDIYA SOROKINA	{"email": "l_sorokina.06101952@postgrespro.ru", "phone": "+70665254442"}
0005433633329	53AE17	7430 013465	DMITRIY IVANOV	{"email": "ivanov.d-1960@postgrespro.ru", "phone": "+70805795014"}
0005433633330	53AE17	1131 383370	ALEKSANDR NAUMOV	{"phone": "+70937848703"}
0005433633331	CEF769	9375 872947	ALEKSEY KULIKOV	{"email": "kulikov_aleksey-1963@postgrespro.ru", "phone": "+70873491602"}
0005433633332	236A36	2999 287266	EVGENIY EGOROV	{"phone": "+70589329890"}
0005433633333	0276A4	8522 757276	IVAN NIKITIN	{"email": "nikitin_ivan_091968@postgrespro.ru", "phone": "+70904947579"}
0005433633334	0276A4	8369 351444	ELENA KUZNECOVA	{"email": "e.kuznecova_31081977@postgrespro.ru", "phone": "+70803372825"}
0005433633335	6AE19C	1709 911197	VERA NIKITINA	{"phone": "+70052046790"}
0005433633336	8C5957	7999 224964	ALEKSANDR MATVEEV	{"phone": "+70106645810"}
0005433633337	B34FA5	3182 571294	ANDREY TARASOV	{"phone": "+70762173049"}
0005433633338	0D8164	7356 250132	TATYANA BELOVA	{"phone": "+70070523351"}
0005433633339	0D8164	6205 795059	GENNADIY DMITRIEV	{"email": "gennadiy-dmitriev_121979@postgrespro.ru", "phone": "+70240200211"}
0005433633340	956923	8848 775004	SVETLANA MAKAROVA	{"email": "makarovasvetlana_1975@postgrespro.ru", "phone": "+70241190325"}
0005433633341	E2D517	7114 945384	ELENA POPOVA	{"phone": "+70185175164"}
0005433633342	A5CEAA	5696 437133	OLGA PAVLOVA	{"phone": "+70548410475"}
0005433633343	810C5D	1599 578971	SERGEY KONOVALOV	{"phone": "+70373351756"}
0005433633344	1CC2FF	4949 714498	ALEKSANDRA IVANOVA	{"phone": "+70004432092"}
0005433633345	1CC2FF	7757 102570	SERGEY KUZNECOV	{"email": "kuznecov_s-1972@postgrespro.ru", "phone": "+70534050097"}
0005433633346	8553C7	3896 223540	VIKTOR KUZNECOV	{"email": "kuznecov_viktor-011967@postgrespro.ru", "phone": "+70725218176"}
0005433633347	8B3BE0	8844 156323	KARINA AKIMOVA	{"email": "k.akimova-13021985@postgrespro.ru", "phone": "+70999123511"}
0005433633348	78D536	0485 183671	KONSTANTIN ZAYCEV	{"email": "zaycev-k_08031968@postgrespro.ru", "phone": "+70798753317"}
0005433633349	78D536	8654 387912	ELENA KUZNECOVA	{"email": "kuznecova_elena071968@postgrespro.ru", "phone": "+70508717037"}
0005433633350	5F4C42	6415 109327	DMITRIY SEMENOV	{"phone": "+70064123281"}
0005433633351	5F4C42	9216 387885	ALEKSEY MARTYNOV	{"email": "a-martynov.1969@postgrespro.ru", "phone": "+70974544152"}
0005433633352	037B22	0821 290035	OLGA DMITRIEVA	{"phone": "+70756122913"}
0005433633353	037B22	8543 796927	YURIY BELOV	{"email": "belov_y.1981@postgrespro.ru", "phone": "+70232302139"}
0005433633354	037B22	0242 112608	MARINA NESTEROVA	{"phone": "+70645627700"}
0005433633355	BFAB3D	5328 419750	SERGEY SOLOVEV	{"phone": "+70955101643"}
0005433633356	5C1DE4	9444 483013	ALEKSEY MEDVEDEV	{"email": "medvedevaleksey.03031978@postgrespro.ru", "phone": "+70321277370"}
0005433633357	19E11D	9833 360034	SANIYA KOZLOVA	{"phone": "+70756639987"}
0005433633358	2CE229	0134 336551	LYUDMILA MOROZOVA	{"phone": "+70793223672"}
0005433633359	33524C	7475 546819	REGINA FROLOVA	{"email": "regina_frolova_26111978@postgrespro.ru", "phone": "+70678598902"}
0005433633360	4CC55B	7810 149763	TAISIYA DANILOVA	{"phone": "+70411270681"}
0005433633361	7BD621	3517 152845	ELENA MATVEEVA	{"email": "matveeva-elena-1976@postgrespro.ru", "phone": "+70430514161"}
0005433633362	7BD621	6055 953011	ALEKSANDR SIDOROV	{"email": "sidorova021971@postgrespro.ru", "phone": "+70730762134"}
0005433633363	721A03	8669 645394	VADIM PAVLOV	{"email": "vpavlov061982@postgrespro.ru", "phone": "+70295560679"}
0005433633364	2ACE26	1867 022431	YURIY ZHUKOV	{"email": "yuriy-zhukov_08101965@postgrespro.ru", "phone": "+70412003231"}
0005433633365	814D0D	7900 991808	SVETLANA ZHURAVLEVA	{"email": "svetlana-zhuravleva-081986@postgrespro.ru", "phone": "+70129996507"}
0005433633366	814D0D	7108 880020	OLEG SIDOROV	{"email": "osidorov041974@postgrespro.ru", "phone": "+70697480275"}
0005433633367	814D0D	1819 996642	ARTEM FOMIN	{"email": "fomin_artem-04091968@postgrespro.ru", "phone": "+70203648820"}
0005433633368	9216DD	8422 866674	ALEKSANDR ORLOV	{"email": "aleksandr-orlov1978@postgrespro.ru", "phone": "+70156773610"}
0005433633369	9216DD	6736 322718	ALEKSANDR KRASNOV	{"email": "krasnov-aleksandr.041965@postgrespro.ru", "phone": "+70141530018"}
0005433633370	0E50B0	9171 594308	MARINA RYABOVA	{"email": "marina_ryabova16071979@postgrespro.ru", "phone": "+70031782396"}
0005433633371	0E50B0	5523 928133	VYACHESLAV GRIGOREV	{"phone": "+70779801004"}
0005433633372	A5061F	7586 767797	MAKSIM YAKOVLEV	{"email": "yakovlev_maksim-1980@postgrespro.ru", "phone": "+70717195229"}
0005433633373	832DF3	1388 941221	EVGENIY KAZAKOV	{"email": "ekazakov.1970@postgrespro.ru", "phone": "+70967816651"}
0005433633374	9AD2CB	3350 633159	GALINA NESTEROVA	{"email": "nesterova-g-121982@postgrespro.ru", "phone": "+70947720393"}
0005433633375	917187	1330 120144	TAMARA AKIMOVA	{"email": "takimova-011965@postgrespro.ru", "phone": "+70472283702"}
0005433633376	CBCBDD	7854 311099	ARTEM VOLKOV	{"email": "a_volkov_111991@postgrespro.ru", "phone": "+70343709727"}
0005433633377	CBCBDD	7203 715088	ALENA MIRONOVA	{"phone": "+70586294916"}
0005433633378	CBCBDD	4417 808337	LYUBOV RYABOVA	{"email": "l-ryabova.121963@postgrespro.ru", "phone": "+70098214755"}
0005433633379	CBCBDD	3401 041899	ELENA MARTYNOVA	{"email": "martynova.e051978@postgrespro.ru", "phone": "+70544116915"}
0005433633380	7D6E2B	4342 110342	NATALYA ZHUKOVA	{"email": "n_zhukova.10061961@postgrespro.ru", "phone": "+70958834729"}
0005433633381	7D6E2B	9872 174975	VALENTIN ABRAMOV	{"phone": "+70528205843"}
0005433633382	D0B232	8646 126463	EVGENIYA IVANOVA	{"email": "e-ivanova_21101967@postgrespro.ru", "phone": "+70691451174"}
0005433633383	513C60	5271 013159	IGOR GRIGOREV	{"email": "grigorev_i041973@postgrespro.ru", "phone": "+70244343553"}
0005433633384	962E46	1550 729187	VALERIY NAUMOV	{"email": "naumov-valeriy.27121962@postgrespro.ru", "phone": "+70860757363"}
0005433633385	5E9159	6011 447784	ANDREY ISAEV	{"phone": "+70928333051"}
0005433633386	5E9159	8470 987120	ANNA ERMAKOVA	{"phone": "+70104751478"}
0005433633387	76D760	9116 513709	EKATERINA ZAKHAROVA	{"email": "ekaterina-zakharova021988@postgrespro.ru", "phone": "+70669197330"}
0005433633388	BD3DB0	6685 418310	ANTONINA MELNIKOVA	{"phone": "+70942480413"}
0005433633389	BD3DB0	3478 386496	VIKTOR KISELEV	{"phone": "+70960882741"}
0005433633390	EE7432	2438 650301	VALENTIN SERGEEV	{"email": "sergeevv_1976@postgrespro.ru", "phone": "+70116062887"}
0005433633391	EE7432	5931 148144	LYUBOV GAVRILOVA	{"phone": "+70190035920"}
0005433633392	EE7432	5483 693103	PETR SOROKIN	{"email": "sorokin-petr.1971@postgrespro.ru", "phone": "+70183494459"}
0005433633393	EE7432	7338 045644	VALERIYA ZAKHAROVA	{"email": "v-zakharova_111968@postgrespro.ru", "phone": "+70947953381"}
0005433633394	8735DE	1364 407575	GEVORG NAZAROV	{"email": "nazarov-gevorg1972@postgrespro.ru", "phone": "+70945490757"}
0005433633395	010BD3	4916 528287	ALEKSEY NAZAROV	{"email": "nazarov-aleksey_1972@postgrespro.ru", "phone": "+70384672821"}
0005433633396	F2A1FE	1750 169848	NIKITA FROLOV	{"phone": "+70031573814"}
0005433633397	71281F	0284 100442	OLGA NAZAROVA	{"phone": "+70517496252"}
0005433633398	71281F	6888 628154	ALEKSANDR NAUMOV	{"email": "aleksandr_naumov_061961@postgrespro.ru", "phone": "+70466993258"}
0005433633399	5A30D0	9366 459829	ANTON BARANOV	{"email": "antonbaranov-08051979@postgrespro.ru", "phone": "+70932036292"}
0005433633400	92BA32	2155 450479	IGOR MIKHAYLOV	{"email": "imikhaylov-121968@postgrespro.ru", "phone": "+70620029811"}
0005433633401	4A6C11	8678 241725	YANA STEPANOVA	{"email": "stepanova.yana17061969@postgrespro.ru", "phone": "+70300293884"}
0005433633402	2F7CE0	0143 019847	OLGA KOMAROVA	{"email": "okomarova021971@postgrespro.ru", "phone": "+70804967687"}
0005433633403	5303C1	5847 572798	ANNA FOMINA	{"email": "fomina-a.061974@postgrespro.ru", "phone": "+70083974640"}
0005433633404	D19B8C	6511 803200	INNA FEDOROVA	{"email": "fedorova-i_031975@postgrespro.ru", "phone": "+70850998778"}
0005433633405	7DB6A7	4828 262440	SERGEY POPOV	{"email": "sergeypopov03061985@postgrespro.ru", "phone": "+70284316494"}
0005433633406	E2CD13	7865 190513	ALEKSANDR BORISOV	{"email": "borisov.a-071976@postgrespro.ru", "phone": "+70540376775"}
0005433633407	E2CD13	0631 383267	LYUBOV SEMENOVA	{"email": "lyubov-semenova-051976@postgrespro.ru", "phone": "+70438441967"}
0005433633408	EAEA2D	1506 782053	ZLATA POTAPOVA	{"email": "potapova.z.15071967@postgrespro.ru", "phone": "+70995641212"}
0005433633409	7BD1B3	4008 162019	LIYA TITOVA	{"email": "titoval-1979@postgrespro.ru", "phone": "+70280735110"}
0005433633410	7BD1B3	7666 187474	VIKTOR IVANOV	{"email": "v_ivanov24031975@postgrespro.ru", "phone": "+70436692363"}
0005433633411	E91A60	8294 778249	ANTON ABRAMOV	{"phone": "+70585057804"}
0005433633412	E91A60	3718 903721	LYUDMILA BORISOVA	{"phone": "+70139774849"}
0005433633413	B6E814	5436 711532	ELENA FROLOVA	{"email": "frolova.e.021967@postgrespro.ru", "phone": "+70976823493"}
0005433633414	F749EF	9647 774203	PAVEL ANTONOV	{"phone": "+70074374884"}
0005433633415	F0A7AE	5345 454577	MARGARITA MARTYNOVA	{"email": "m.martynova011977@postgrespro.ru", "phone": "+70208707706"}
0005433633416	E4C294	1090 659762	EVGENIY MIRONOV	{"email": "evgeniy_mironov081975@postgrespro.ru", "phone": "+70776731884"}
0005433633417	1AA5BF	4142 376350	MIKHAIL ALEKSEEV	{"email": "alekseev-m_081969@postgrespro.ru", "phone": "+70846562294"}
0005433633418	651CDE	8653 360644	OLEG SAVELEV	{"email": "oleg-savelev.041975@postgrespro.ru", "phone": "+70251143143"}
0005433633419	CE7757	2943 777864	NIKOLAY FROLOV	{"email": "frolov_n021978@postgrespro.ru", "phone": "+70365044388"}
0005433633420	9F5D39	0806 400140	OLGA IVANOVA	{"phone": "+70530903322"}
0005433633421	708861	6327 544797	LYUBOV MAKSIMOVA	{"email": "maksimovalyubov_07091977@postgrespro.ru", "phone": "+70723712133"}
0005433633422	9BFCC4	7253 505441	ANATOLIY PETROV	{"email": "petrov-anatoliy111967@postgrespro.ru", "phone": "+70537271470"}
0005433633423	AA7A6F	8769 206045	OLEG FILIPPOV	{"email": "oleg.filippov08041967@postgrespro.ru", "phone": "+70179616249"}
0005433633424	201463	2661 709931	SVETLANA BELOVA	{"email": "svetlanabelova1983@postgrespro.ru", "phone": "+70982222684"}
0005433633425	201463	3664 608947	LYUDMILA TIKHONOVA	{"phone": "+70737277447"}
0005433633426	41DAD9	0203 939552	ANATOLIY MAKAROV	{"email": "a_makarov1979@postgrespro.ru", "phone": "+70841647848"}
0005433633427	375DE4	6194 351747	OLESYA DENISOVA	{"phone": "+70958662951"}
0005433633428	375DE4	0869 761527	YULIYA ROMANOVA	{"email": "romanova_y-121970@postgrespro.ru", "phone": "+70089896087"}
0005433633429	A92C55	7116 260515	NINA KOROLEVA	{"phone": "+70102670892"}
0005433633430	B269F6	6479 816546	ELENA MELNIKOVA	{"email": "elena_melnikova_1963@postgrespro.ru", "phone": "+70668989780"}
0005433633431	B269F6	8866 273996	ANTONINA KOROLEVA	{"phone": "+70806155295"}
0005433633432	41C8A1	8478 975679	TATYANA FEDOROVA	{"email": "tatyana-fedorova-12061966@postgrespro.ru", "phone": "+70732116988"}
0005433633433	DAEC04	2087 285137	LYUDMILA EGOROVA	{"phone": "+70022198711"}
0005433633434	2E9B58	7411 488457	NINA KISELEVA	{"phone": "+70136941024"}
0005433633435	BB2CD4	8373 934052	VITALIY SAVELEV	{"phone": "+70946364156"}
0005433633436	442506	9833 133961	IRINA ANDREEVA	{"email": "andreeva.irina-1975@postgrespro.ru", "phone": "+70926762018"}
0005433633437	36B890	3158 352875	ANTON ORLOV	{"phone": "+70495377651"}
0005433633438	81639E	4447 191960	LYUBOV ZHURAVLEVA	{"phone": "+70096444850"}
0005433633439	DD3223	9477 991349	ILYA GAVRILOV	{"email": "i-gavrilov.071966@postgrespro.ru", "phone": "+70936112452"}
0005433633440	DD3223	9626 314407	SERGEY FEDOROV	{"email": "fedorovs_011961@postgrespro.ru", "phone": "+70072710609"}
0005433633441	30A841	8125 852976	ELENA NIKOLAEVA	{"email": "elenanikolaeva-1972@postgrespro.ru", "phone": "+70778740252"}
0005433633442	30A841	4964 416582	RUSTAM FOMIN	{"email": "rustam_fomin-051976@postgrespro.ru", "phone": "+70050139453"}
0005433633443	D2B1BA	0045 417719	VITALIY MEDVEDEV	{"phone": "+70440457209"}
0005433633444	5C2178	7483 752788	ELENA MIKHAYLOVA	{"email": "mikhaylova.elena.071970@postgrespro.ru", "phone": "+70973179862"}
0005433633445	F93309	2866 420135	ANNA PETROVA	{"email": "petrova-anna-1963@postgrespro.ru", "phone": "+70849445663"}
0005433633446	F93309	1909 000564	ANDREY MAKAROV	{"email": "makarov-a-1960@postgrespro.ru", "phone": "+70255326972"}
0005433633447	57C6C6	4250 231532	EKATERINA DAVYDOVA	{"email": "e.davydova011981@postgrespro.ru", "phone": "+70943474648"}
0005433633448	57C6C6	4113 168026	ANNA VASILEVA	{"email": "a_vasileva.02061978@postgrespro.ru", "phone": "+70977848356"}
0005433633449	2D1942	9452 524980	RUSLAN MIKHAYLOV	{"phone": "+70090587304"}
0005433633450	F71C78	2731 176470	MAKSIM KUZNECOV	{"phone": "+70072760821"}
0005433633451	1F74DA	0498 095223	ANDREY ILIN	{"phone": "+70372600284"}
0005433633452	A62883	9660 631948	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova.25051970@postgrespro.ru", "phone": "+70346832323"}
0005433633453	289C67	0356 315873	SERGEY MELNIKOV	{"phone": "+70994249108"}
0005433633454	289C67	4284 351166	OLEG BARANOV	{"email": "baranov-o-29071969@postgrespro.ru", "phone": "+70064816565"}
0005433633455	743419	2977 421889	ILDAR IVANOV	{"phone": "+70580682572"}
0005433633456	206484	0977 027451	NATALYA FROLOVA	{"phone": "+70121015794"}
0005433633457	D01782	1396 047205	DMITRIY NAZAROV	{"phone": "+70144830139"}
0005433633458	02C95F	4599 522757	YULIYA GUSEVA	{"phone": "+70229622808"}
0005433633459	02C95F	2004 630282	ALEKSEY RODIONOV	{"email": "rodionov-a-19071978@postgrespro.ru", "phone": "+70538125649"}
0005433633460	35B5FA	1058 478512	VIKTOR SEMENOV	{"email": "v.semenov_1956@postgrespro.ru", "phone": "+70239866725"}
0005433633461	35B5FA	8138 818608	VIKTOR KUDRYASHOV	{"email": "kudryashov.v071980@postgrespro.ru", "phone": "+70610472120"}
0005433633462	A87D79	4809 608089	SERGEY SOKOLOV	{"phone": "+70500640639"}
0005433633463	6BC54F	3802 991703	KSENIYA ARKHIPOVA	{"email": "arkhipova-kseniya.101962@postgrespro.ru", "phone": "+70478933189"}
0005433633464	F7B3F2	4110 663359	DMITRIY DENISOV	{"phone": "+70925473100"}
0005433633465	C7435F	8793 233641	YULIYA VOLKOVA	{"email": "volkova_yuliya_1970@postgrespro.ru", "phone": "+70982350472"}
0005433633466	5288A8	7491 626625	ELIZAVETA PETROVA	{"email": "e_petrova-1989@postgrespro.ru", "phone": "+70733034011"}
0005433633467	5288A8	5233 539658	PETR GORBUNOV	{"email": "gorbunov.p_021977@postgrespro.ru", "phone": "+70120294350"}
0005433633468	1AE663	8360 144819	LEV STEPANOV	{"phone": "+70599654657"}
0005433633469	1AE663	8819 890785	TATYANA FROLOVA	{"email": "frolova.tatyana_021954@postgrespro.ru", "phone": "+70608300492"}
0005433633470	84AC89	6742 723809	NATALYA FEDOROVA	{"email": "natalyafedorova121962@postgrespro.ru", "phone": "+70077761844"}
0005433633471	59590D	8724 720162	DMITRIY IVANOV	{"phone": "+70764878531"}
0005433633472	59590D	4625 637604	ELENA SIDOROVA	{"email": "sidorova-e12101969@postgrespro.ru", "phone": "+70465005407"}
0005433633473	491B2D	9419 730435	ALEKSANDR BELOV	{"phone": "+70856910036"}
0005433633474	D6493A	4474 647084	DMITRIY KUZNECOV	{"email": "kuznecov-d-20041977@postgrespro.ru", "phone": "+70180843496"}
0005433633475	641EAB	4793 509495	LIDIYA KOZLOVA	{"email": "l-kozlova-13031984@postgrespro.ru", "phone": "+70561669335"}
0005433633476	397AB1	5888 188367	ALLA KUZMINA	{"email": "alla_kuzmina-07101986@postgrespro.ru", "phone": "+70896183987"}
0005433633477	509D4B	4786 494870	NINA SOROKINA	{"email": "sorokina_n.1984@postgrespro.ru", "phone": "+70643606389"}
0005433633478	286EF2	5724 045920	VALENTINA POTAPOVA	{"email": "potapova_valentina.081969@postgrespro.ru", "phone": "+70593158734"}
0005433633479	DB5454	0642 856115	NADEZHDA MALYSHEVA	{"phone": "+70886984927"}
0005433633480	DB5454	7181 189857	NATALYA LAZAREVA	{"email": "natalyalazareva-1975@postgrespro.ru", "phone": "+70789505264"}
0005433633481	EA9091	8887 580753	ELENA GERASIMOVA	{"email": "gerasimova-elena1971@postgrespro.ru", "phone": "+70189931902"}
0005433633482	EA9091	5416 619211	VITALIY MIKHAYLOV	{"phone": "+70900151329"}
0005433633483	F0A366	1530 256262	PAVEL VASILEV	{"email": "pavel.vasilev041984@postgrespro.ru", "phone": "+70816110231"}
0005433633484	784314	1023 524957	EVDOKIYA GAVRILOVA	{"phone": "+70810163194"}
0005433633485	784314	4964 452739	OKSANA YUDINA	{"phone": "+70464882121"}
0005433633486	C47A9D	9692 455415	EKATERINA NAZAROVA	{"phone": "+70929573312"}
0005433633487	F2FB9C	8305 734936	ELENA GERASIMOVA	{"email": "gerasimova-elena-26071977@postgrespro.ru", "phone": "+70480177319"}
0005433633488	B0B8C5	6556 706001	NIKITA MEDVEDEV	{"email": "medvedev_n-27041972@postgrespro.ru", "phone": "+70185828156"}
0005433633489	B0B8C5	4402 294962	OLGA GORBUNOVA	{"phone": "+70463283668"}
0005433633490	E389D2	7355 801711	VIKTOR ZAYCEV	{"email": "zaycev.v-10051978@postgrespro.ru", "phone": "+70654339852"}
0005433633491	152D64	5857 377690	ALEKSANDR GORBUNOV	{"phone": "+70313512094"}
0005433633492	8FCD4A	3906 868401	ALEKSANDR KUZNECOV	{"phone": "+70136417702"}
0005433633493	227A1D	7901 952516	OLEG NAUMOV	{"email": "naumov.oleg_031970@postgrespro.ru", "phone": "+70973253290"}
0005433633494	554B78	8233 008566	NIKITA ZAKHAROV	{"phone": "+70058063536"}
0005433633496	5A17D9	9810 891765	VLADISLAV MAKAROV	{"phone": "+70655261469"}
0005433633497	5A17D9	5676 180840	ANNA MELNIKOVA	{"email": "melnikova-a.1971@postgrespro.ru", "phone": "+70243330131"}
0005433633498	F1688F	1643 730012	ANTONINA TARASOVA	{"phone": "+70200884981"}
0005433633499	581124	3870 656913	GALINA SOROKINA	{"email": "sorokina_galina17101973@postgrespro.ru", "phone": "+70698171997"}
0005433633500	1CAC5B	6764 284961	KRISTINA SOKOLOVA	{"email": "k_sokolova-111979@postgrespro.ru", "phone": "+70228702933"}
0005433633501	1CAC5B	0465 265198	MAKSIM ABRAMOV	{"phone": "+70354826326"}
0005433633502	1CAC5B	2121 585540	IRINA FOMINA	{"email": "fomina_i1964@postgrespro.ru", "phone": "+70908938416"}
0005433633503	AF00E9	7165 805853	PAVEL KAZAKOV	{"email": "kazakov_p-11021972@postgrespro.ru", "phone": "+70325606802"}
0005433633504	1878FD	9703 172744	ANATOLIY IVANOV	{"email": "ivanov-a.041969@postgrespro.ru", "phone": "+70040815686"}
0005433633505	1878FD	3237 642218	ALEKSEY ANDREEV	{"email": "aleksey-andreev.121973@postgrespro.ru", "phone": "+70437020855"}
0005433633506	D188CB	8784 170459	ELENA SEMENOVA	{"email": "elena_semenova-061973@postgrespro.ru", "phone": "+70209732645"}
0005433633507	D188CB	2939 872043	ALEVTINA SERGEEVA	{"phone": "+70983907561"}
0005433633508	2C6239	3586 821475	LEONID YAKOVLEV	{"email": "yakovlev_leonid-17041973@postgrespro.ru", "phone": "+70023183600"}
0005433633509	B0B710	2092 023760	ELENA IVANOVA	{"phone": "+70732255978"}
0005433633510	A079DC	1651 911747	PETR PETROV	{"email": "ppetrov101967@postgrespro.ru", "phone": "+70289639533"}
0005433633511	F6A0E5	3663 247516	MARIYA ANDREEVA	{"email": "m.andreeva-1974@postgrespro.ru", "phone": "+70070688117"}
0005433633512	F6A0E5	5473 068430	ZINAIDA ZAYCEVA	{"email": "zayceva_z.1960@postgrespro.ru", "phone": "+70904527027"}
0005433633513	A7F30A	5165 037096	VIKTOR NAZAROV	{"email": "vnazarov19021980@postgrespro.ru", "phone": "+70675887206"}
0005433633514	A7F30A	7609 522152	OLGA MATVEEVA	{"phone": "+70977577244"}
0005433633515	8B42B9	9670 016422	NADEZHDA ANISIMOVA	{"email": "nadezhda-anisimova.17011983@postgrespro.ru", "phone": "+70114847279"}
0005433633516	E9BC7B	9370 527896	DIANA FADEEVA	{"phone": "+70214738768"}
0005433633517	E9BC7B	8403 195103	VIKTOR ANTONOV	{"phone": "+70090117431"}
0005433633518	C28ED9	5081 549928	MARINA CHERNOVA	{"email": "mchernova_031970@postgrespro.ru", "phone": "+70829159097"}
0005433633519	C28ED9	0284 645432	GALINA MOROZOVA	{"email": "morozovagalina14031980@postgrespro.ru", "phone": "+70673054127"}
0005433633520	A43C71	8502 182940	YANA KUZNECOVA	{"phone": "+70679241368"}
0005433633521	A43C71	3042 121672	NATALYA BELYAEVA	{"phone": "+70894566592"}
0005433633522	622C3A	7982 118119	RAISA YAKOVLEVA	{"phone": "+70180371635"}
0005433633523	DAB809	3833 174184	EMIL SAVELEV	{"phone": "+70074939820"}
0005433633524	DAB809	6149 451298	DMITRIY SERGEEV	{"email": "dmitriy.sergeev-1969@postgrespro.ru", "phone": "+70656904195"}
0005433633525	D9C0F3	7482 300332	VERA TIKHONOVA	{"phone": "+70403923651"}
0005433633526	D9C0F3	8149 077221	IGOR NOVIKOV	{"email": "novikov.igor17111965@postgrespro.ru", "phone": "+70544892790"}
0005433633527	449EC9	8918 345449	KLAVDIYA MAKAROVA	{"email": "makarova.klavdiya_1978@postgrespro.ru", "phone": "+70154274276"}
0005433633528	7D0DA3	7989 792635	NADEZHDA MATVEEVA	{"email": "n_matveeva1967@postgrespro.ru", "phone": "+70979788076"}
0005433633529	7D0DA3	5457 859746	VLADIMIR GERASIMOV	{"email": "gerasimov_vladimir21041973@postgrespro.ru", "phone": "+70136508851"}
0005433633530	8F3750	5556 974544	VYACHESLAV SEMENOV	{"email": "vyacheslavsemenov03021978@postgrespro.ru", "phone": "+70910931686"}
0005433633531	148787	0028 142008	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-a-081969@postgrespro.ru", "phone": "+70195289361"}
0005433633532	F929B6	5338 720046	VERONIKA ZHURAVLEVA	{"phone": "+70938138720"}
0005433633533	A64FD8	5949 938586	ALEKSEY NAZAROV	{"phone": "+70106870418"}
0005433633534	A64FD8	8293 915024	OLGA AKIMOVA	{"phone": "+70572769578"}
0005433633535	D7B51E	1246 073172	POLINA MATVEEVA	{"email": "polina-matveeva_1977@postgrespro.ru", "phone": "+70530813378"}
0005433633536	D7B51E	4732 801284	VALENTIN TIKHONOV	{"email": "tikhonov-valentin23051983@postgrespro.ru", "phone": "+70658449126"}
0005433633537	D8BB75	7416 956335	EDUARD BORISOV	{"email": "eborisov_1984@postgrespro.ru", "phone": "+70836127154"}
0005433633538	D3A943	0761 211912	MARIYA ZHURAVLEVA	{"email": "m_zhuravleva_1981@postgrespro.ru", "phone": "+70732361027"}
0005433633539	9181E4	0100 901247	MAKSIM SCHERBAKOV	{"phone": "+70210974778"}
0005433633540	4CA41F	3848 598238	IRINA SEMENOVA	{"email": "i-semenova1980@postgrespro.ru", "phone": "+70360568042"}
0005433633541	695DF1	9933 346316	TATYANA VOLKOVA	{"phone": "+70746616087"}
0005433633542	206056	4121 464764	VALENTINA MOROZOVA	{"email": "valentina-morozova_12121956@postgrespro.ru", "phone": "+70660014980"}
0005433633543	206056	0258 970221	ALLA MASLOVA	{"email": "maslova.a081969@postgrespro.ru", "phone": "+70193097211"}
0005433633544	F99101	5766 224977	NADEZHDA CHERNOVA	{"email": "chernovan041972@postgrespro.ru", "phone": "+70810887297"}
0005433633545	F4287E	9579 315740	GULSHAT MIKHAYLOVA	{"phone": "+70282014742"}
0005433633546	A89979	0264 885497	ANNA LEBEDEVA	{"email": "lebedevaa_031977@postgrespro.ru", "phone": "+70791029007"}
0005433633547	5EC141	4239 919712	LEONID VLASOV	{"phone": "+70717377097"}
0005433633548	6B94FD	3725 490568	VLADIMIR GRIGOREV	{"phone": "+70114508743"}
0005433633549	4F4BBF	6118 385737	GALINA BOGDANOVA	{"email": "bogdanova.galina22101980@postgrespro.ru", "phone": "+70768640396"}
0005433633550	1FC7E2	8990 152126	VASILIY PAVLOV	{"phone": "+70440107430"}
0005433633551	1256E3	0481 264615	EKATERINA ANDREEVA	{"phone": "+70180843189"}
0005433633552	DC1C9D	3336 083578	SERGEY ANTONOV	{"email": "antonov.sergey.121967@postgrespro.ru", "phone": "+70372867146"}
0005433633553	DC1C9D	9622 170651	KARINA ROMANOVA	{"phone": "+70961764785"}
0005433633554	938C03	6440 016856	VLADIMIR FEDOROV	{"phone": "+70459921475"}
0005433633555	DFEB33	8292 603474	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova-1967@postgrespro.ru", "phone": "+70409122549"}
0005433633556	25B834	5175 925031	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev_1962@postgrespro.ru", "phone": "+70307249930"}
0005433633557	0F3283	9265 577444	ZHANNA KOMAROVA	{"phone": "+70744573975"}
0005433633558	710063	2949 843917	MAKSIM KOZLOV	{"phone": "+70910879824"}
0005433633559	710063	0512 107383	KRISTINA NIKIFOROVA	{"email": "kristina_nikiforova_081974@postgrespro.ru", "phone": "+70055855785"}
0005433633560	223F80	3621 774086	DMITRIY FILIPPOV	{"email": "dmitriy_filippov_081969@postgrespro.ru", "phone": "+70160196628"}
0005433633561	67BBAF	9639 038620	NIKITA DAVYDOV	{"email": "davydov.nikita_17071958@postgrespro.ru", "phone": "+70982576848"}
0005433633562	8D2961	2498 231461	RINAT GRIGOREV	{"phone": "+70862200013"}
0005433633563	8D2961	0487 422990	VITALIY VASILEV	{"phone": "+70041738283"}
0005433633564	F3D302	0411 252697	IRINA KUZNECOVA	{"email": "i_kuznecova-1965@postgrespro.ru", "phone": "+70036013433"}
0005433633565	FB1030	8643 068199	IVAN SEMENOV	{"phone": "+70261161139"}
0005433633566	FB1030	9227 874992	VLADIMIR ALEKSEEV	{"email": "alekseev.v-041974@postgrespro.ru", "phone": "+70670621719"}
0005433633567	DDBE26	5710 508481	ALEKSEY DENISOV	{"email": "denisovaleksey.28121976@postgrespro.ru", "phone": "+70611417874"}
0005433633568	E5C41E	7215 410730	EVGENIY BORISOV	{"phone": "+70482160410"}
0005433633569	E5C41E	7625 125936	NATALYA BARANOVA	{"email": "n.baranova.1974@postgrespro.ru", "phone": "+70162820614"}
0005433633570	B7C01E	9563 867688	OLGA KAZAKOVA	{"email": "olga.kazakova21031968@postgrespro.ru", "phone": "+70208139762"}
0005433633571	F8D673	5627 105564	ILYA DENISOV	{"phone": "+70119586191"}
0005433633572	AB92C8	3262 352141	ANDREY KUZNECOV	{"email": "andrey.kuznecov.1969@postgrespro.ru", "phone": "+70045789863"}
0005433633573	7D59CC	4210 400918	ELENA DMITRIEVA	{"email": "dmitrieva-e-041965@postgrespro.ru", "phone": "+70830130968"}
0005433633574	8096E1	4839 537459	DMITRIY KUZNECOV	{"phone": "+70283605512"}
0005433633575	8096E1	3027 900750	DMITRIY MELNIKOV	{"phone": "+70880924186"}
0005433633576	ABCF03	6669 193242	ANASTASIYA KONOVALOVA	{"phone": "+70626729487"}
0005433633577	0BEC73	5126 429240	NIKOLAY NIKITIN	{"email": "nikolay-nikitin.08051985@postgrespro.ru", "phone": "+70337049973"}
0005433633578	F0248B	2411 126736	YURIY AFANASEV	{"email": "afanasevyuriy1980@postgrespro.ru", "phone": "+70021682104"}
0005433633579	F0248B	9195 171858	LYUDMILA LEBEDEVA	{"email": "lyudmila.lebedeva_1958@postgrespro.ru", "phone": "+70658987447"}
0005433633580	23E877	0457 831229	VARVARA VASILEVA	{"phone": "+70590873055"}
0005433633581	FF5572	2973 963254	SERGEY ANDREEV	{"email": "andreevsergey-1962@postgrespro.ru", "phone": "+70906411371"}
0005433633582	C279EE	6492 823909	LYUDMILA ZHURAVLEVA	{"phone": "+70450958014"}
0005433633583	773420	6919 418515	LYUDMILA RODIONOVA	{"phone": "+70451965376"}
0005433633584	7C2FFD	9088 021115	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey071978@postgrespro.ru", "phone": "+70912302720"}
0005433633585	26CC3B	8049 496945	ANNA GUSEVA	{"email": "a-guseva25091972@postgrespro.ru", "phone": "+70250593798"}
0005433633586	3D6C09	1117 889704	DMITRIY PETROV	{"email": "dmitriy_petrov.1973@postgrespro.ru", "phone": "+70985304720"}
0005433633587	8F6A13	8956 467306	OLESYA ZAKHAROVA	{"email": "olesya-zakharova.19041979@postgrespro.ru", "phone": "+70663651311"}
0005433633588	8F6A13	3996 415722	ELENA VASILEVA	{"email": "elenavasileva081964@postgrespro.ru", "phone": "+70308613154"}
0005433633589	7EDCB0	4493 301779	VALENTINA IVANOVA	{"phone": "+70436452711"}
0005433633590	7EDCB0	9528 044457	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova1968@postgrespro.ru", "phone": "+70186544269"}
0005433633591	A60689	8303 489317	ELENA EFIMOVA	{"email": "eefimova21021954@postgrespro.ru", "phone": "+70509999355"}
0005433633592	A60689	6172 733456	NATALIYA KUZNECOVA	{"phone": "+70783438145"}
0005433633593	2DC69D	8272 510770	IRINA SERGEEVA	{"phone": "+70326372889"}
0005433633594	971A81	4460 743645	VLADIMIR SOROKIN	{"email": "vladimirsorokin.1977@postgrespro.ru", "phone": "+70002139755"}
0005433633595	E47D23	0992 678166	GALINA IVANOVA	{"phone": "+70492913514"}
0005433633596	F066EA	7326 446661	ANNA FROLOVA	{"phone": "+70230375180"}
0005433633597	F066EA	3520 581933	FEDOR TIKHONOV	{"phone": "+70318403047"}
0005433633598	F066EA	8365 023867	EGOR GRIGOREV	{"email": "grigorev-egor.25031972@postgrespro.ru", "phone": "+70431203328"}
0005433633599	EE54BA	8367 862114	VIKTOR SIDOROV	{"email": "sidorov.v-1962@postgrespro.ru", "phone": "+70028558994"}
0005433633600	AE70C0	1376 121201	IRINA POTAPOVA	{"phone": "+70485113507"}
0005433633601	AE70C0	1673 661966	ANASTASIYA DAVYDOVA	{"email": "davydova_a.26021967@postgrespro.ru", "phone": "+70716043116"}
0005433633602	129817	6156 972353	LYUBOV KUZNECOVA	{"phone": "+70607982979"}
0005433633603	129817	8660 750814	SERGEY ROMANOV	{"email": "s.romanov_081975@postgrespro.ru", "phone": "+70505229830"}
0005433633604	D0125A	6676 715033	DMITRIY VOLKOV	{"phone": "+70367868418"}
0005433633605	8EB88D	7524 397532	GENNADIY GORBUNOV	{"email": "gorbunov_gennadiy-071978@postgrespro.ru", "phone": "+70419521404"}
0005433633829	39186F	7761 852455	VALENTIN BARANOV	{"phone": "+70558443948"}
0005433633606	8EB88D	2713 063098	NATALYA MALYSHEVA	{"email": "malysheva-n-021970@postgrespro.ru", "phone": "+70244511101"}
0005433633607	A80D5B	0369 288545	VASILIY ZAKHAROV	{"email": "zakharov_v.30031978@postgrespro.ru", "phone": "+70636083889"}
0005433633608	9F2397	5896 279940	NIKITA KUZNECOV	{"phone": "+70140505741"}
0005433633609	6AF309	7008 677888	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov-1985@postgrespro.ru", "phone": "+70068239319"}
0005433633610	6AF309	5458 188589	ANDREY KUZNECOV	{"email": "kuznecov-a021983@postgrespro.ru", "phone": "+70906333801"}
0005433633611	66CC59	3148 085312	KIRA FEDOROVA	{"email": "kira_fedorova.1974@postgrespro.ru", "phone": "+70227296852"}
0005433633612	7A8163	7160 172279	ALEKSANDR BARANOV	{"email": "aleksandr-baranov-22051969@postgrespro.ru", "phone": "+70628404072"}
0005433633613	7A8163	7677 863080	VLADIMIR SOLOVEV	{"email": "solovevv-041966@postgrespro.ru", "phone": "+70549926358"}
0005433633614	26D5DE	5377 152598	ELENA BORISOVA	{"email": "borisova_e_1983@postgrespro.ru", "phone": "+70435469895"}
0005433633615	0FD2BE	6505 400374	EVGENIY BORISOV	{"phone": "+70631027299"}
0005433633616	5B714C	5115 951325	LYUDMILA SOROKINA	{"email": "l.sorokina.081970@postgrespro.ru", "phone": "+70259096113"}
0005433633617	42B9E8	2744 125380	DMITRIY VOLKOV	{"email": "dmitriy_volkov.1978@postgrespro.ru", "phone": "+70462230647"}
0005433633618	61FD72	5104 947457	DMITRIY NIKITIN	{"phone": "+70438856243"}
0005433633619	61FD72	8607 959572	LYUBOV KOZLOVA	{"phone": "+70383982486"}
0005433633620	942310	3283 361571	OLGA SIDOROVA	{"email": "o.sidorova.081973@postgrespro.ru", "phone": "+70102324419"}
0005433633621	26E1BA	0672 185055	VALENTINA ARKHIPOVA	{"email": "arkhipova-valentina021977@postgrespro.ru", "phone": "+70855882039"}
0005433633622	E48386	0852 955563	EKATERINA FROLOVA	{"email": "frolovae-041983@postgrespro.ru", "phone": "+70388342082"}
0005433633623	DA5889	7926 060589	VIKTOR NIKITIN	{"phone": "+70115871346"}
0005433633624	185823	3888 589884	ELENA VOLKOVA	{"email": "volkova_elena-091969@postgrespro.ru", "phone": "+70448394907"}
0005433633625	E2DAE1	7572 662926	OLGA BOGDANOVA	{"phone": "+70879449025"}
0005433633626	DA32E2	3773 093321	VLADISLAV KOZLOV	{"phone": "+70745672814"}
0005433633627	DA32E2	3110 179234	VASILIY BONDARENKO	{"phone": "+70667743952"}
0005433633628	A55FF1	0840 997622	OLGA MAKAROVA	{"email": "makarova_olga.031961@postgrespro.ru", "phone": "+70978513702"}
0005433633629	A55FF1	2141 139776	ALEKSEY KUZNECOV	{"phone": "+70025620261"}
0005433633630	03B217	8086 432178	OLGA KUZNECOVA	{"email": "okuznecova.1965@postgrespro.ru", "phone": "+70541605116"}
0005433633631	3D8E27	0462 697673	SVETLANA KOROLEVA	{"email": "skoroleva.041966@postgrespro.ru", "phone": "+70754408715"}
0005433633632	01F464	2505 733635	YURIY BARANOV	{"phone": "+70920072964"}
0005433633633	EE9ABF	6695 063600	VIKTOR KULIKOV	{"phone": "+70905588916"}
0005433633634	8E1244	5211 329891	PETR KUZMIN	{"phone": "+70427553093"}
0005433633635	D69980	9507 717629	OLGA DANILOVA	{"email": "o_danilova_1970@postgrespro.ru", "phone": "+70271034987"}
0005433633636	45C681	4354 975825	SERGEY KAZAKOV	{"phone": "+70455136945"}
0005433633637	45C681	0272 501293	GALINA MOROZOVA	{"email": "morozova-galina051966@postgrespro.ru", "phone": "+70234053950"}
0005433633638	45C681	5235 383423	OLGA LAZAREVA	{"email": "olgalazareva-29071969@postgrespro.ru", "phone": "+70744288565"}
0005433633639	B34310	4861 985227	OLGA EFIMOVA	{"phone": "+70950849115"}
0005433633640	70B65B	9642 033185	MARGARITA GORBUNOVA	{"email": "gorbunova.m-1974@postgrespro.ru", "phone": "+70869579306"}
0005433633641	73D4E6	3214 043612	ALEKSANDRA MAKAROVA	{"phone": "+70826909627"}
0005433633642	149AA5	2163 582209	ALEKSANDR IVANOV	{"email": "ivanov-a_31071980@postgrespro.ru", "phone": "+70216328576"}
0005433633643	149AA5	0170 421590	VALENTINA ILINA	{"phone": "+70412602656"}
0005433633644	149AA5	2876 386892	ANTONINA VLASOVA	{"email": "antonina.vlasova1972@postgrespro.ru", "phone": "+70756237528"}
0005433633645	149AA5	5038 365181	ANDREY ANDREEV	{"email": "a_andreev_1973@postgrespro.ru", "phone": "+70100971909"}
0005433633646	626739	7862 784643	VITALIY MAKSIMOV	{"phone": "+70593745156"}
0005433633647	626739	8891 797815	NIKOLAY ZAYCEV	{"email": "n_zaycev1966@postgrespro.ru", "phone": "+70931594545"}
0005433633648	54D7F8	0794 015950	ULYANA MASLOVA	{"phone": "+70027696389"}
0005433633649	679606	7350 338795	GALINA EFIMOVA	{"phone": "+70814724475"}
0005433633650	679606	7779 685831	MARIANNA PETROVA	{"phone": "+70120950887"}
0005433633651	3E36E0	1484 880672	DMITRIY NIKOLAEV	{"phone": "+70247770004"}
0005433633652	B6D4C4	4305 096437	YURIY ZAYCEV	{"email": "yuriyzaycev_071974@postgrespro.ru", "phone": "+70974946712"}
0005433633653	B6D4C4	3293 880766	DMITRIY VOLKOV	{"phone": "+70134988429"}
0005433633654	DED033	2946 743683	ALEKSANDR IVANOV	{"phone": "+70985542126"}
0005433633655	DED033	7752 472539	VADIM BELOV	{"email": "v_belov_1972@postgrespro.ru", "phone": "+70597678106"}
0005433633656	DED033	3601 504864	YULIYA KULIKOVA	{"email": "yuliya-kulikova021977@postgrespro.ru", "phone": "+70510148118"}
0005433633657	35B38A	3289 898334	OLEG MAKAROV	{"phone": "+70381184867"}
0005433633658	A855E2	0664 016412	ANASTASIYA NIKITINA	{"phone": "+70618847343"}
0005433633659	A855E2	2453 325664	FEDOR GORBUNOV	{"phone": "+70708163133"}
0005433633660	B1C185	6668 718772	MAKSIM NOVIKOV	{"email": "novikovmaksim-02061972@postgrespro.ru", "phone": "+70387298565"}
0005433633661	B1C185	3734 103516	IVAN IVANOV	{"email": "ivanov.i_031977@postgrespro.ru", "phone": "+70204946209"}
0005433633662	B1C185	7225 551055	EVGENIYA IVANOVA	{"email": "evgeniyaivanova_19111962@postgrespro.ru", "phone": "+70885807503"}
0005433633663	D9B075	2733 296871	EVGENIY KOZLOV	{"email": "kozlovevgeniy031973@postgrespro.ru", "phone": "+70927436829"}
0005433633664	279238	6619 230610	EGOR ALEKSANDROV	{"email": "aleksandrov_e.1972@postgrespro.ru", "phone": "+70500026797"}
0005433633665	CF3330	8024 017058	RAFAIL SCHERBAKOV	{"email": "rafail.scherbakov.1963@postgrespro.ru", "phone": "+70749338800"}
0005433633666	8D2ABE	2057 728139	ANDREY GERASIMOV	{"email": "gerasimov-a-11081966@postgrespro.ru", "phone": "+70060866097"}
0005433633667	38F618	9260 846601	YURIY IVANOV	{"email": "yuriyivanov.1968@postgrespro.ru", "phone": "+70042069001"}
0005433633668	B364CA	0771 291287	ANTON IVANOV	{"phone": "+70082317799"}
0005433633669	85CA3E	9300 103746	VYACHESLAV KUZNECOV	{"phone": "+70117910838"}
0005433633947	3F8FAB	0834 581062	GENNADIY EGOROV	{"phone": "+70485849482"}
0005433633670	5560A1	4907 771042	OLGA IVANOVA	{"email": "olga.ivanova07081965@postgrespro.ru", "phone": "+70680052265"}
0005433633671	626CC8	5988 958488	OLGA DENISOVA	{"phone": "+70302280502"}
0005433633672	223396	3284 027460	NINA NESTEROVA	{"email": "n-nesterova_1964@postgrespro.ru", "phone": "+70563996030"}
0005433633673	223396	5305 901578	YULIYA ISAEVA	{"email": "y.isaeva.1968@postgrespro.ru", "phone": "+70551300096"}
0005433633674	E5121A	6184 349666	IVAN MIKHAYLOV	{"email": "i.mikhaylov21121967@postgrespro.ru", "phone": "+70107548266"}
0005433633675	700973	7041 677344	VASILIY EGOROV	{"phone": "+70717983548"}
0005433633676	700973	7558 197547	VLADIMIR ILIN	{"email": "v.ilin_12061989@postgrespro.ru", "phone": "+70604814086"}
0005433633677	700973	7418 014274	VLADIMIR MELNIKOV	{"email": "melnikov_vladimir_20111967@postgrespro.ru", "phone": "+70213294447"}
0005433633678	7CAEB9	2325 801984	VLADISLAV NIKOLAEV	{"email": "nikolaev-v-02061967@postgrespro.ru", "phone": "+70047778932"}
0005433633679	14AEF9	1263 402389	OLGA POTAPOVA	{"phone": "+70355971257"}
0005433633680	DD5DB5	2405 661573	EVGENIY SAVELEV	{"email": "evgeniy-savelev.1971@postgrespro.ru", "phone": "+70882776037"}
0005433633681	D2E3F5	4927 379323	LYUBOV FEDOROVA	{"email": "fedorova-lyubov-1973@postgrespro.ru", "phone": "+70263881658"}
0005433633682	718F6B	5858 262976	ALEKSANDR KRASNOV	{"phone": "+70028686886"}
0005433633683	953E86	9169 962743	NADEZHDA SERGEEVA	{"phone": "+70594960985"}
0005433633684	F2CBE1	1149 139920	ANZHELIKA ALEKSEEVA	{"phone": "+70991369818"}
0005433633685	A6CAF3	2662 040094	VERA KULIKOVA	{"phone": "+70453157940"}
0005433633686	A6CAF3	0540 461920	ALEKSANDR NOVIKOV	{"phone": "+70545595826"}
0005433633687	4E8EE6	2004 476700	PETR SCHERBAKOV	{"email": "p.scherbakov.20061960@postgrespro.ru", "phone": "+70361410572"}
0005433633688	4E8EE6	3410 014218	MAKSIM GERASIMOV	{"email": "gerasimovmaksim.1975@postgrespro.ru", "phone": "+70121540449"}
0005433633689	82BFEE	7905 434673	ZOYA GAVRILOVA	{"phone": "+70153014171"}
0005433633690	D92889	5769 946552	ALEKSANDR AFANASEV	{"phone": "+70745191301"}
0005433633691	D92889	1398 243549	SERGEY FOMIN	{"phone": "+70225263143"}
0005433633692	337275	6025 549417	TATYANA KOLESNIKOVA	{"phone": "+70687826644"}
0005433633693	337275	8142 651401	TATYANA VASILEVA	{"phone": "+70005271209"}
0005433633694	ACF73E	7807 359358	VERA BELOVA	{"phone": "+70634285064"}
0005433633695	F5D54A	8123 214484	NADEZHDA KALININA	{"email": "kalininan_17101979@postgrespro.ru", "phone": "+70611269711"}
0005433633696	09C5A8	7792 787590	EKATERINA DMITRIEVA	{"email": "ekaterinadmitrieva_1976@postgrespro.ru", "phone": "+70685863880"}
0005433633697	4299FD	7293 659910	VLADISLAV NIKITIN	{"email": "v-nikitin-27101967@postgrespro.ru", "phone": "+70847896510"}
0005433633698	74ECB9	1716 156461	ALEKSANDR VASILEV	{"email": "aleksandrvasilev.01091967@postgrespro.ru", "phone": "+70738244010"}
0005433633699	C4380B	1651 249451	SERGEY SEMENOV	{"phone": "+70268329129"}
0005433633700	CBC24A	7353 842508	DENIS BORISOV	{"email": "d_borisov_031981@postgrespro.ru", "phone": "+70896149805"}
0005433633701	CBC24A	4886 027741	VALERIY BELOV	{"phone": "+70424172704"}
0005433633702	92874E	5869 488357	ANASTASIYA BELOVA	{"email": "belova_anastasiya1963@postgrespro.ru", "phone": "+70867867265"}
0005433633703	E230E6	5016 824298	ANNA FILATOVA	{"phone": "+70362093152"}
0005433633704	1DB61C	9743 491562	ANTON SERGEEV	{"phone": "+70952439368"}
0005433633705	3B576A	3062 201736	VLADIMIR ILIN	{"phone": "+70974534544"}
0005433633706	3B576A	7525 903503	VIKTORIYA DENISOVA	{"email": "viktoriyadenisova-08031962@postgrespro.ru", "phone": "+70405785761"}
0005433633707	74EC94	5729 930077	DARYA MIRONOVA	{"phone": "+70330123086"}
0005433633708	74EC94	2952 656685	TATYANA FADEEVA	{"phone": "+70112153708"}
0005433633709	A72754	8473 330558	PAVEL EGOROV	{"email": "egorovpavel_091968@postgrespro.ru", "phone": "+70349925918"}
0005433633710	A47DDB	0190 843176	OLEG PAVLOV	{"email": "oleg_pavlov-10071972@postgrespro.ru", "phone": "+70736106845"}
0005433633711	FC5B33	5398 666793	ELENA DENISOVA	{"email": "denisovaelena.1973@postgrespro.ru", "phone": "+70812441828"}
0005433633712	3DBD00	8190 613441	SERGEY KISELEV	{"email": "kiselev.sergey.111965@postgrespro.ru", "phone": "+70595985604"}
0005433633713	4DE065	6553 468987	GALIYA TIKHONOVA	{"phone": "+70928536059"}
0005433633714	895D8D	4716 678277	LYUBOV ALEKSEEVA	{"phone": "+70894018439"}
0005433633715	895D8D	6009 704051	VIKTOR PETROV	{"phone": "+70308658315"}
0005433633716	CCC49F	4924 123804	ALEKSANDR FEDOTOV	{"phone": "+70605724554"}
0005433633717	EA5F6B	7385 836625	YULIYA MASLOVA	{"email": "y.maslova1971@postgrespro.ru", "phone": "+70578508864"}
0005433633718	A2C4A0	3049 175843	ALEKSANDR KISELEV	{"email": "kiseleva_14091963@postgrespro.ru", "phone": "+70423973539"}
0005433633719	45569E	8217 863073	OLGA IVANOVA	{"email": "olgaivanova05021963@postgrespro.ru", "phone": "+70124300092"}
0005433633720	45569E	5672 785433	SVETLANA BOGDANOVA	{"phone": "+70481100279"}
0005433633721	EE8659	5263 032434	NATALYA KUZNECOVA	{"phone": "+70964580358"}
0005433633722	EE8659	8943 980741	IGOR MARTYNOV	{"email": "i_martynov_1968@postgrespro.ru", "phone": "+70016716784"}
0005433633723	51FD5E	3156 099334	ARTUR GERASIMOV	{"phone": "+70039516316"}
0005433633724	FE7F53	2569 241949	NATALYA ANISIMOVA	{"phone": "+70492738990"}
0005433633725	368F42	1905 651642	ELIZAVETA ZHURAVLEVA	{"phone": "+70318372328"}
0005433634004	51B5C0	1121 567639	VLADIMIR MAKAROV	{"phone": "+70134459282"}
0005433633726	428983	1758 706845	MARIYA KARPOVA	{"email": "karpova_mariya04111973@postgrespro.ru", "phone": "+70396113906"}
0005433633727	A15255	0668 865217	ALINA NIKOLAEVA	{"phone": "+70604120197"}
0005433633728	20888D	9900 383039	EKATERINA ZAKHAROVA	{"email": "ekaterina-zakharova.031973@postgrespro.ru", "phone": "+70193223359"}
0005433633729	20888D	9299 179834	TATYANA KOROLEVA	{"email": "tatyana.koroleva041981@postgrespro.ru", "phone": "+70178780339"}
0005433633730	C7703A	0055 826492	NIKOLAY FEDOROV	{"phone": "+70926556199"}
0005433633731	518C21	5588 906931	ALEKSANDRA MELNIKOVA	{"email": "melnikova_aleksandra1978@postgrespro.ru", "phone": "+70546992375"}
0005433633732	518C21	3125 102210	NINA MAKAROVA	{"email": "makarova_nina.11101969@postgrespro.ru", "phone": "+70493071346"}
0005433633733	11A66B	2116 552078	VLADIMIR KRASNOV	{"email": "krasnov.vladimir091974@postgrespro.ru", "phone": "+70683109841"}
0005433633734	36DD53	2042 642201	GENNADIY ABRAMOV	{"email": "abramov_g.1973@postgrespro.ru", "phone": "+70611920633"}
0005433633735	1B685C	0798 501951	YULIYA NAZAROVA	{"email": "yuliyanazarova-1978@postgrespro.ru", "phone": "+70755932607"}
0005433633736	1B685C	4416 203145	VLADIMIR GAVRILOV	{"phone": "+70994056583"}
0005433633737	0045DE	0392 588378	OKSANA SERGEEVA	{"email": "sergeeva-oksana_19031965@postgrespro.ru", "phone": "+70066797769"}
0005433633738	ED8ACC	6174 749066	ANASTASIYA EGOROVA	{"phone": "+70491382728"}
0005433633739	ED8ACC	8533 690971	SVETLANA ALEKSEEVA	{"email": "alekseeva-s.061975@postgrespro.ru", "phone": "+70039020144"}
0005433633740	0D9A5B	9470 004627	ANDREY ALEKSEEV	{"email": "alekseev_andrey-1972@postgrespro.ru", "phone": "+70170397675"}
0005433633741	B77A6E	1531 186045	ALEKSANDR GAVRILOV	{"email": "gavrilov_a_121973@postgrespro.ru", "phone": "+70339651588"}
0005433633742	5BCD1A	4962 074398	ANATOLIY BELOV	{"phone": "+70125658553"}
0005433633743	4B9FE6	9448 553605	MARINA VOROBEVA	{"email": "marina.vorobeva-19121975@postgrespro.ru", "phone": "+70838028785"}
0005433633744	4361B7	0176 066630	VLADIMIR VLASOV	{"phone": "+70474912777"}
0005433633745	4CA8E5	4280 206107	TATYANA ZHUKOVA	{"phone": "+70010060102"}
0005433633746	FC02B4	4835 567203	VALENTINA SOKOLOVA	{"email": "sokolova_valentina01101959@postgrespro.ru", "phone": "+70869511070"}
0005433633747	FC02B4	0857 477063	ELENA MAKAROVA	{"phone": "+70033885244"}
0005433633748	57100A	7404 827604	NATALYA BORISOVA	{"email": "n-borisova_1963@postgrespro.ru", "phone": "+70695924759"}
0005433633749	EE88CF	5498 007449	LYUBOV FROLOVA	{"phone": "+70852606423"}
0005433633750	D5638B	0091 287514	EVGENIY SIDOROV	{"email": "sidorovevgeniy_1978@postgrespro.ru", "phone": "+70928814388"}
0005433633751	D5638B	9827 952525	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr-1976@postgrespro.ru", "phone": "+70765013685"}
0005433633752	2C81A3	1076 379716	SERGEY AFANASEV	{"email": "afanasev-sergey_091968@postgrespro.ru", "phone": "+70377869700"}
0005433633753	2C81A3	6119 894827	FAINA PETROVA	{"email": "petrovafaina101979@postgrespro.ru", "phone": "+70099003586"}
0005433633754	45EAAB	1100 700911	VYACHESLAV SCHERBAKOV	{"phone": "+70673936087"}
0005433633755	7729E4	5793 801175	ANTON SOKOLOV	{"email": "sokolov.anton.011985@postgrespro.ru", "phone": "+70900677381"}
0005433633756	E892FB	9736 378434	ELENA STEPANOVA	{"email": "elena_stepanova-19041970@postgrespro.ru", "phone": "+70328136409"}
0005433633757	8820C0	9153 994203	SERGEY BARANOV	{"phone": "+70443554036"}
0005433633758	8820C0	8364 911877	ANASTASIYA KONDRATEVA	{"phone": "+70937419383"}
0005433633759	E29060	1066 888456	VIKTOR ROMANOV	{"phone": "+70070316827"}
0005433633760	5AB6D2	4270 707587	ANDREY KARPOV	{"phone": "+70790153720"}
0005433633761	D3EE3B	0847 056777	POLINA BOGDANOVA	{"email": "p_bogdanova15051962@postgrespro.ru", "phone": "+70939802159"}
0005433633762	382598	4171 890449	VASILIY VASILEV	{"phone": "+70819689182"}
0005433633763	382598	5143 440930	NADEZHDA MEDVEDEVA	{"phone": "+70245629786"}
0005433633764	382598	0997 806065	VLADIMIR DENISOV	{"email": "v-denisov27111973@postgrespro.ru", "phone": "+70991358939"}
0005433633765	E47D50	2532 774524	IRINA NIKOLAEVA	{"phone": "+70491164479"}
0005433633766	556BF2	7480 615292	VIKTOR IVANOV	{"email": "ivanov.viktor.061970@postgrespro.ru", "phone": "+70182098479"}
0005433633767	3F3EBD	0452 395036	NINA SMIRNOVA	{"email": "nina_smirnova1972@postgrespro.ru", "phone": "+70592909657"}
0005433633768	3F3EBD	4680 711351	MIKHAIL PETROV	{"phone": "+70674841509"}
0005433633769	AD1B9A	8634 108962	ALEKSANDRA ISAEVA	{"email": "aisaeva1971@postgrespro.ru", "phone": "+70810192191"}
0005433633770	DE105D	3941 292451	ANNA POPOVA	{"email": "popova_a_051973@postgrespro.ru", "phone": "+70401182557"}
0005433633771	0E93A3	2350 872519	ALEKSANDR KISELEV	{"phone": "+70007921763"}
0005433633772	79C60C	9920 941460	ANATOLIY IVANOV	{"phone": "+70772409727"}
0005433634050	E320CD	9568 091229	NIKITA ANDREEV	{"phone": "+70994576415"}
0005433633773	5B45F0	3962 175219	IGOR FROLOV	{"email": "igorfrolov_04121974@postgrespro.ru", "phone": "+70661972372"}
0005433633774	5B45F0	9585 804102	YURIY ROMANOV	{"phone": "+70832976394"}
0005433633775	678554	1065 473907	YURIY VOROBEV	{"phone": "+70386587763"}
0005433633776	4BAD44	8416 291426	TATYANA KUDRYASHOVA	{"email": "tatyana_kudryashova12051978@postgrespro.ru", "phone": "+70812406807"}
0005433633777	7DF781	0411 008561	ALEKSANDR KUDRYASHOV	{"phone": "+70017386171"}
0005433633778	FA16E6	1670 591147	ANATOLIY MAKAROV	{"phone": "+70343138661"}
0005433633779	AAA4BA	2894 107696	KONSTANTIN MOROZOV	{"phone": "+70338230318"}
0005433634005	E1DF5F	6210 526885	ELENA SMIRNOVA	{"phone": "+70525549654"}
0005433633780	A98F5A	7390 629638	DMITRIY KUDRYASHOV	{"email": "d-kudryashov1972@postgrespro.ru", "phone": "+70586335602"}
0005433633781	A98F5A	1881 409692	ARTUR KOZLOV	{"email": "arturkozlov_011972@postgrespro.ru", "phone": "+70883714177"}
0005433633782	0DBEDD	3718 671789	VITALIY ANDREEV	{"email": "andreev-vitaliy_071971@postgrespro.ru", "phone": "+70938204400"}
0005433633783	36E72F	3939 630649	DENIS FEDOTOV	{"email": "fedotov_denis.1972@postgrespro.ru", "phone": "+70441453808"}
0005433633784	1CBBF3	9429 931743	DANILA ZHURAVLEV	{"email": "dzhuravlev1982@postgrespro.ru", "phone": "+70550181771"}
0005433633785	ADBB22	8048 364324	MIKHAIL BORISOV	{"phone": "+70979040117"}
0005433633786	ADBB22	4093 572506	IRINA YAKOVLEVA	{"phone": "+70758133426"}
0005433633787	3649C5	0098 929935	YURIY SCHERBAKOV	{"phone": "+70608678128"}
0005433633788	3649C5	6821 505082	TAMARA FEDOROVA	{"phone": "+70845603349"}
0005433633789	1AD739	1341 495010	GYUZEL DANILOVA	{"phone": "+70021379117"}
0005433633790	1AD739	0024 169925	IRINA IVANOVA	{"phone": "+70213992180"}
0005433633791	990285	9410 992995	ANTON TARASOV	{"phone": "+70310126174"}
0005433633792	990285	5693 187537	VIKTOR YAKOVLEV	{"email": "viktor.yakovlev031976@postgrespro.ru", "phone": "+70055287485"}
0005433633793	252E52	2211 844231	MARIYA RYABOVA	{"email": "ryabovam.101974@postgrespro.ru", "phone": "+70462703668"}
0005433633794	252E52	8284 866433	NADEZHDA MIKHAYLOVA	{"phone": "+70840010412"}
0005433633795	2E2AAC	9920 326684	MAKSIM FEDOROV	{"phone": "+70953558062"}
0005433633796	810688	2517 225118	VLADIMIR SOROKIN	{"email": "vladimir-sorokin31011969@postgrespro.ru", "phone": "+70413694625"}
0005433633797	77E03C	4226 122461	MARIYA ARKHIPOVA	{"phone": "+70503307624"}
0005433633798	77E03C	4265 038407	ALEKSEY KOROLEV	{"email": "aleksey_korolev-1972@postgrespro.ru", "phone": "+70409360627"}
0005433633799	88F01B	8067 852155	ALEKSANDRA ANTONOVA	{"phone": "+70600741359"}
0005433633800	ECD2A0	5902 880630	VYACHESLAV CHERNOV	{"phone": "+70260735672"}
0005433633801	ECD2A0	7811 563748	VLADISLAV ILIN	{"phone": "+70461035718"}
0005433633802	EAEC31	3800 604861	SVETLANA GERASIMOVA	{"phone": "+70792906563"}
0005433633803	1A5284	1563 641716	ALEKSANDR GUSEV	{"phone": "+70845622047"}
0005433633804	4E3616	4001 874893	VALENTINA ZAKHAROVA	{"phone": "+70595450847"}
0005433633805	4E3616	5778 129577	VLADIMIR IVANOV	{"email": "ivanov_vladimir.051974@postgrespro.ru", "phone": "+70981203265"}
0005433633806	4E3616	7951 525401	NINA KALININA	{"email": "nina-kalinina_031976@postgrespro.ru", "phone": "+70689614536"}
0005433633807	36F9C8	1621 369853	MARIYA KALININA	{"email": "kalininamariya_1967@postgrespro.ru", "phone": "+70221549297"}
0005433633808	36F9C8	9791 378790	RENAT MARTYNOV	{"email": "martynov.r_1961@postgrespro.ru", "phone": "+70587164713"}
0005433633809	36F9C8	2983 309421	GALINA LUKYANOVA	{"phone": "+70148478551"}
0005433633810	DEB4DF	0282 260247	EVGENIY CHERNOV	{"email": "e.chernov051961@postgrespro.ru", "phone": "+70702584533"}
0005433633811	DEB4DF	5289 581794	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva.l.071972@postgrespro.ru", "phone": "+70274142312"}
0005433633812	DEB4DF	1309 261102	LYUBOV KOVALEVA	{"email": "kovaleva-l-061963@postgrespro.ru", "phone": "+70231897356"}
0005433633813	263E49	7064 186885	EKATERINA ORLOVA	{"phone": "+70657620849"}
0005433633814	09091A	6512 375170	SVETLANA SEMENOVA	{"email": "ssemenova_051968@postgrespro.ru", "phone": "+70188017905"}
0005433633815	11D71E	7986 459219	DANIIL KARPOV	{"email": "daniil.karpov_1967@postgrespro.ru", "phone": "+70034684467"}
0005433633816	11D71E	6472 801344	OLEG ABRAMOV	{"phone": "+70659883564"}
0005433633817	5F387B	9924 037601	VADIM PETROV	{"email": "vadimpetrov-1979@postgrespro.ru", "phone": "+70968226812"}
0005433633818	F31C61	2905 712058	ALEKSEY GERASIMOV	{"email": "aleksey.gerasimov-051985@postgrespro.ru", "phone": "+70862634052"}
0005433633819	F31C61	4219 186788	PRASKOVYA SOKOLOVA	{"email": "sokolova.p.1974@postgrespro.ru", "phone": "+70190006920"}
0005433633820	F31C61	0983 620165	IVAN TARASOV	{"phone": "+70016998227"}
0005433633821	25F93F	6019 539834	GALINA MELNIKOVA	{"email": "melnikova.g1965@postgrespro.ru", "phone": "+70949369916"}
0005433633822	5C4996	8432 606234	RADIK KULIKOV	{"email": "kulikov.radik_031976@postgrespro.ru", "phone": "+70842384039"}
0005433633823	5C4996	3601 623062	DIANA GORBUNOVA	{"phone": "+70020227808"}
0005433633824	748064	3820 591337	SERGEY MAKAROV	{"email": "makarov.sergey04011978@postgrespro.ru", "phone": "+70767755081"}
0005433633825	748064	7565 675386	VALERIY ANDREEV	{"email": "valeriy_andreev13051967@postgrespro.ru", "phone": "+70313957176"}
0005433633826	8CD969	7348 686444	LYUDMILA LAZAREVA	{"phone": "+70636065132"}
0005433633827	8CD969	6539 727674	MARIYA MEDVEDEVA	{"phone": "+70994988759"}
0005433633828	8CD969	4240 253242	NIKOLAY KULIKOV	{"phone": "+70646330426"}
0005433633830	2ADCEC	9162 271099	IVAN FOMIN	{"email": "fomin-ivan_1965@postgrespro.ru", "phone": "+70450694196"}
0005433633831	EB552D	5550 380521	ELENA ZOTOVA	{"email": "zotovaelena.19091974@postgrespro.ru", "phone": "+70438417733"}
0005433633832	EB552D	0417 084430	DANIIL IVANOV	{"email": "ivanov_daniil.111973@postgrespro.ru", "phone": "+70165621679"}
0005433633833	25D537	6154 199184	SEMEN KOZLOV	{"email": "kozlov-semen_30071978@postgrespro.ru", "phone": "+70644960057"}
0005433633834	E9814D	1767 835947	ANDREY FEDOROV	{"email": "fedorov_andrey_031979@postgrespro.ru", "phone": "+70797413846"}
0005433633835	E9814D	1503 226897	ELIZAVETA ZAYCEVA	{"email": "zayceva-elizaveta.071979@postgrespro.ru", "phone": "+70380480339"}
0005433633836	0D64B0	8237 940463	VALENTINA NIKOLAEVA	{"phone": "+70945910500"}
0005433633837	33285D	4484 624961	DAMIR CHERNOV	{"email": "d.chernov_02051967@postgrespro.ru", "phone": "+70447178702"}
0005433633838	FFDE2A	0913 625078	LYUBOV NAUMOVA	{"phone": "+70031679743"}
0005433633839	FFDE2A	2463 494593	NINA SEMENOVA	{"email": "ninasemenova_091969@postgrespro.ru", "phone": "+70861796642"}
0005433633840	3D4590	9736 387031	IRINA SAVELEVA	{"email": "saveleva-i1982@postgrespro.ru", "phone": "+70397429624"}
0005433633841	3C5F6C	7957 523406	ALINA ORLOVA	{"phone": "+70514149359"}
0005433633842	3C5F6C	6844 131576	TATYANA KISELEVA	{"phone": "+70905009292"}
0005433633843	73BE5A	4361 988595	NIKOLAY SOROKIN	{"email": "nsorokin.10061976@postgrespro.ru", "phone": "+70727626242"}
0005433633844	6D1651	8537 170965	DIANA PAVLOVA	{"email": "d_pavlova.111971@postgrespro.ru", "phone": "+70801112126"}
0005433633845	6D1651	0729 733257	OLGA ZAKHAROVA	{"email": "zakharova.o_071961@postgrespro.ru", "phone": "+70294885706"}
0005433633846	42F7E4	9895 991006	NIKOLAY FROLOV	{"email": "frolovn.031980@postgrespro.ru", "phone": "+70136891953"}
0005433633847	21EAF6	2968 087516	ANASTASIYA SEMENOVA	{"email": "semenova_anastasiya-1960@postgrespro.ru", "phone": "+70017028809"}
0005433633848	21EAF6	9828 018602	DARYA ORLOVA	{"email": "darya-orlova.1968@postgrespro.ru", "phone": "+70023867139"}
0005433633849	62212C	5363 492794	VIKTORIYA EGOROVA	{"email": "v.egorova.1981@postgrespro.ru", "phone": "+70192224308"}
0005433633850	39358A	6543 170196	ULYANA KULIKOVA	{"email": "u.kulikova041980@postgrespro.ru", "phone": "+70845682860"}
0005433633851	DF532B	2525 035467	TATYANA KOVALEVA	{"email": "kovaleva.tatyana_14081964@postgrespro.ru", "phone": "+70420349450"}
0005433633852	98ED34	8162 065052	DANIL MOROZOV	{"phone": "+70096170844"}
0005433633853	98ED34	4563 054270	NIKOLAY SOLOVEV	{"phone": "+70057019904"}
0005433633854	8B22EB	0485 641784	ANDREY MEDVEDEV	{"email": "medvedev-a09021980@postgrespro.ru", "phone": "+70940413878"}
0005433633855	6357F8	5257 095845	ALEKSANDR MELNIKOV	{"email": "melnikov_a_01071962@postgrespro.ru", "phone": "+70399921555"}
0005433633856	08F087	9866 564891	ANDREY MAKAROV	{"email": "makarova091976@postgrespro.ru", "phone": "+70247329155"}
0005433633857	A5D39D	5468 585340	ANDREY NOVIKOV	{"email": "novikov_andrey-1989@postgrespro.ru", "phone": "+70059768158"}
0005433633858	8466A2	8549 937921	ALEKSANDR CHERNOV	{"email": "aleksandr.chernov-021977@postgrespro.ru", "phone": "+70289143594"}
0005433633859	7A9653	2542 586720	GEORGIY TIKHONOV	{"email": "tikhonov-georgiy1970@postgrespro.ru", "phone": "+70632399787"}
0005433633860	7A9653	9915 135817	YULIYA RYABOVA	{"email": "y.ryabova_1976@postgrespro.ru", "phone": "+70292377617"}
0005433633861	7A9653	4918 445624	OLGA PETROVA	{"phone": "+70361093221"}
0005433633862	ABEF5B	2066 708299	NIKOLAY DENISOV	{"phone": "+70325717440"}
0005433633863	ABEF5B	8946 677986	ALEKSEY TARASOV	{"email": "a_tarasov-111974@postgrespro.ru", "phone": "+70407607973"}
0005433633864	2C2DD1	7870 751427	ELENA NAZAROVA	{"email": "elena-nazarova1979@postgrespro.ru", "phone": "+70748321465"}
0005433633865	8AD212	2134 841080	EKATERINA TARASOVA	{"email": "ekaterinatarasova-071991@postgrespro.ru", "phone": "+70055681721"}
0005433633866	8AD212	4058 592170	LEONID VOROBEV	{"email": "vorobev_leonid.11061972@postgrespro.ru", "phone": "+70769817487"}
0005433633867	8AD212	4797 996743	SVETLANA FEDOROVA	{"email": "svetlanafedorova.21071972@postgrespro.ru", "phone": "+70799093560"}
0005433633868	8AD212	4603 614316	LYUBOV VASILEVA	{"email": "lyubov_vasileva_1978@postgrespro.ru", "phone": "+70037500615"}
0005433633869	729D9B	0399 352067	MARINA LOGINOVA	{"email": "loginova.marina-121979@postgrespro.ru", "phone": "+70348054042"}
0005433633870	FE8B25	6282 569554	EKATERINA VASILEVA	{"email": "ekaterinavasileva-28041966@postgrespro.ru", "phone": "+70105134487"}
0005433633871	42F3BC	2490 203948	OLGA MAKSIMOVA	{"email": "maksimova.o-1972@postgrespro.ru", "phone": "+70162032698"}
0005433633872	42F3BC	9690 218254	ALEKSEY BELOV	{"email": "abelov.1970@postgrespro.ru", "phone": "+70588240236"}
0005433633873	F204AC	2594 792005	OKSANA MASLOVA	{"email": "maslova-oksana_071974@postgrespro.ru", "phone": "+70544060734"}
0005433633874	8A366D	1580 831547	OKSANA ABRAMOVA	{"email": "abramova_o_051967@postgrespro.ru", "phone": "+70868365764"}
0005433633875	08A21E	5690 220233	ALEKSEY KOROLEV	{"phone": "+70962282899"}
0005433633876	08A21E	5992 154354	NATALYA MOROZOVA	{"phone": "+70311340195"}
0005433633877	1DED58	4002 564141	MAKSIM PAVLOV	{"phone": "+70640650953"}
0005433633878	BCC334	2339 011518	ALENA ABRAMOVA	{"phone": "+70471857107"}
0005433633879	36B87B	5548 592458	VERA KULIKOVA	{"phone": "+70308999469"}
0005433633880	36B87B	6436 724689	ANDREY ALEKSANDROV	{"email": "aaleksandrov_111967@postgrespro.ru", "phone": "+70759783436"}
0005433633881	6576FA	2363 524231	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr.16051979@postgrespro.ru", "phone": "+70355099539"}
0005433633882	0B6954	5121 576413	ALEKSEY ZAYCEV	{"email": "zaycev_a_16071962@postgrespro.ru", "phone": "+70934862795"}
0005433633883	FFC38B	1218 146382	NIKOLAY FEDOROV	{"email": "fedorovn041972@postgrespro.ru", "phone": "+70900213351"}
0005433633884	293852	9020 976386	NIKOLAY ANTONOV	{"email": "n_antonov.071972@postgrespro.ru", "phone": "+70465732410"}
0005433633885	41D6E1	5236 881361	NATALYA KONOVALOVA	{"phone": "+70339060607"}
0005433633886	484A45	6791 582012	TAMARA NIKIFOROVA	{"email": "tamara_nikiforova.031977@postgrespro.ru", "phone": "+70162122409"}
0005433633887	FA046B	6770 541649	ALEKSEY KISELEV	{"email": "kiseleva-101972@postgrespro.ru", "phone": "+70228839009"}
0005433633888	5DD513	3787 728199	ELENA KOLESNIKOVA	{"email": "kolesnikova_elena.04111972@postgrespro.ru", "phone": "+70040607547"}
0005433633889	5DD513	9463 751282	VLADIMIR KARPOV	{"phone": "+70178228171"}
0005433633890	638645	1192 830739	SVETLANA MASLOVA	{"email": "maslova_s061971@postgrespro.ru", "phone": "+70457644737"}
0005433633891	638645	4400 641929	VLADIMIR POPOV	{"email": "vladimir_popov091988@postgrespro.ru", "phone": "+70138289825"}
0005433633892	A94AF9	6402 912187	DANIIL PETROV	{"email": "petrov.daniil.1969@postgrespro.ru", "phone": "+70795585833"}
0005433633893	65CD14	9710 046517	ANNA TIMOFEEVA	{"email": "annatimofeeva_021968@postgrespro.ru", "phone": "+70620374897"}
0005433633894	65CD14	6550 197364	VLADISLAV IVANOV	{"phone": "+70923019928"}
0005433633895	441CF8	9539 598872	YULIYA MAKSIMOVA	{"email": "yuliya.maksimova061969@postgrespro.ru", "phone": "+70574826138"}
0005433633896	441CF8	5680 194298	ALEKSANDR STEPANOV	{"phone": "+70899435433"}
0005433633897	F395BD	0430 693429	SERGEY MELNIKOV	{"email": "smelnikov-061963@postgrespro.ru", "phone": "+70212762800"}
0005433633898	CC7313	3911 212443	ZULFIYA MEDVEDEVA	{"email": "medvedeva.zulfiya.041977@postgrespro.ru", "phone": "+70489253677"}
0005433633899	CC7313	5594 855933	EKATERINA POPOVA	{"email": "popovae-121967@postgrespro.ru", "phone": "+70157095335"}
0005433633900	A83E9E	2710 710458	ANASTASIYA ZHURAVLEVA	{"phone": "+70603035264"}
0005433633901	18E62A	9293 203035	NATALYA ILINA	{"email": "n.ilina1964@postgrespro.ru", "phone": "+70282702494"}
0005433633902	7B2C5E	0488 830760	VLADIMIR FROLOV	{"phone": "+70591840917"}
0005433633903	23BE2D	2252 920829	YURIY IVANOV	{"phone": "+70500528764"}
0005433633904	23BE2D	1718 834518	MARIYA TIKHONOVA	{"email": "tikhonova_mariya_1975@postgrespro.ru", "phone": "+70552434164"}
0005433633905	19D2D5	6441 986257	VLADIMIR ALEKSEEV	{"email": "alekseev-v_071980@postgrespro.ru", "phone": "+70481058870"}
0005433633906	88404E	3708 204454	NIKOLAY ZHURAVLEV	{"phone": "+70032041303"}
0005433633907	88404E	8281 933826	VASILIY ALEKSANDROV	{"email": "v.aleksandrov041971@postgrespro.ru", "phone": "+70399682266"}
0005433633908	6E33F3	3323 698259	LYUBOV ROMANOVA	{"phone": "+70579765686"}
0005433633909	6E33F3	7379 458808	MARIYA KISELEVA	{"email": "kiselevam.071974@postgrespro.ru", "phone": "+70773350990"}
0005433633910	087C4E	2761 610460	NINA ANISIMOVA	{"phone": "+70564065688"}
0005433633911	61FE86	4055 316577	VLADIMIR ZAKHAROV	{"phone": "+70949592834"}
0005433633912	61FE86	5080 831410	LYUBOV VASILEVA	{"phone": "+70049231774"}
0005433633913	C04C38	4231 547802	SERGEY BELOV	{"phone": "+70365893190"}
0005433633914	A72B6A	6925 768892	LYUDMILA KONOVALOVA	{"email": "l.konovalova1977@postgrespro.ru", "phone": "+70039530408"}
0005433633915	A72B6A	3908 794117	ALEKSANDR GERASIMOV	{"phone": "+70033403078"}
0005433633916	A9177C	1357 156314	VASILIY MOROZOV	{"phone": "+70089926822"}
0005433633917	A9177C	9218 228455	VIKTORIYA KUZNECOVA	{"phone": "+70189514896"}
0005433633918	1A3E0E	4509 284598	VLADIMIR ZHUKOV	{"phone": "+70898174538"}
0005433633919	C2AC90	4054 616433	VALERIY ANTONOV	{"phone": "+70484645269"}
0005433633920	E600F6	2840 685695	MIKHAIL FILIPPOV	{"email": "m-filippov.1972@postgrespro.ru", "phone": "+70766256601"}
0005433633921	AD529E	8535 601218	MARIYA KUZMINA	{"phone": "+70822296313"}
0005433633922	F3B564	8265 502613	IRINA BORISOVA	{"phone": "+70696174002"}
0005433633923	2EEC2A	8312 972775	EVGENIY MAKSIMOV	{"phone": "+70575832335"}
0005433633924	079B14	6204 189117	TATYANA TITOVA	{"phone": "+70578331852"}
0005433633925	079B14	4602 444922	ANATOLIY KUZNECOV	{"phone": "+70382271298"}
0005433633926	1A104B	2459 953690	NIKOLAY BORISOV	{"phone": "+70122517752"}
0005433633927	DE5895	1061 129130	NADEZHDA POPOVA	{"email": "popova-nadezhda-1980@postgrespro.ru", "phone": "+70020544314"}
0005433633928	DE5895	1928 523597	VLADIMIR SIDOROV	{"email": "vsidorov14031983@postgrespro.ru", "phone": "+70866000974"}
0005433633929	EFA324	5723 117140	SOFYA YAKOVLEVA	{"phone": "+70011190243"}
0005433633930	6CE4DB	6001 172099	EKATERINA NIKOLAEVA	{"phone": "+70438709505"}
0005433633931	6CE4DB	3261 640553	LIDIYA SIDOROVA	{"email": "lidiya_sidorova.101970@postgrespro.ru", "phone": "+70967515664"}
0005433633932	6CE4DB	7910 138875	ANDREY KRASNOV	{"email": "andrey_krasnov1961@postgrespro.ru", "phone": "+70999241199"}
0005433633933	D91FE0	3769 664663	ANTON FEDOROV	{"email": "antonfedorov1975@postgrespro.ru", "phone": "+70331292645"}
0005433633934	D91FE0	8441 207382	IRINA POPOVA	{"email": "i.popova.011977@postgrespro.ru", "phone": "+70416587591"}
0005433633935	22DD77	7536 336489	ELENA NOVIKOVA	{"phone": "+70952437654"}
0005433633936	22DD77	7614 691502	SERGEY DENISOV	{"phone": "+70577533630"}
0005433633937	148937	1267 252716	ANNA GAVRILOVA	{"phone": "+70877803215"}
0005433633938	148937	5250 154062	YURIY GUSEV	{"email": "gusev_yuriy-11081981@postgrespro.ru", "phone": "+70404364392"}
0005433633939	CDEB89	4685 760356	MARGARITA KOROLEVA	{"email": "koroleva_margarita_1967@postgrespro.ru", "phone": "+70677865546"}
0005433633940	CDEB89	4170 646424	EDUARD ANDREEV	{"email": "andreev.eduard_1972@postgrespro.ru", "phone": "+70735071280"}
0005433633941	CDEB89	2580 286270	STANISLAV FEDOROV	{"email": "fedorovstanislav-27051974@postgrespro.ru", "phone": "+70198785348"}
0005433633942	3D13D6	5462 622448	MARINA NIKIFOROVA	{"email": "marina_nikiforova13091974@postgrespro.ru", "phone": "+70200779562"}
0005433633943	1FD594	0077 459639	ALEKSEY ZHURAVLEV	{"email": "a.zhuravlev_05051968@postgrespro.ru", "phone": "+70208848236"}
0005433633944	20425A	4277 576521	GENNADIY TIKHONOV	{"email": "tikhonov_gennadiy.1982@postgrespro.ru", "phone": "+70034180433"}
0005433633945	15141A	5512 422902	VERA BELYAEVA	{"phone": "+70252988055"}
0005433633946	497280	2075 666836	VALENTINA NESTEROVA	{"email": "nesterova-v_07081972@postgrespro.ru", "phone": "+70240956258"}
0005433633948	08A15F	4786 585113	EKATERINA ORLOVA	{"email": "orlova_e_1974@postgrespro.ru", "phone": "+70542125416"}
0005433633949	08A15F	7812 099329	DARYA TIMOFEEVA	{"email": "d.timofeeva-031970@postgrespro.ru", "phone": "+70497949088"}
0005433633950	979CE0	7298 073324	SVETLANA YAKOVLEVA	{"email": "s_yakovleva.111977@postgrespro.ru", "phone": "+70592432202"}
0005433633951	5613F1	3674 171913	YULIYA CHERNOVA	{"email": "y-chernova_011974@postgrespro.ru", "phone": "+70398709037"}
0005433633952	41D786	3501 689418	NELLI ZOTOVA	{"phone": "+70956257497"}
0005433633953	41D786	4395 260791	OLGA POLYAKOVA	{"phone": "+70020037113"}
0005433633954	ADCF38	7379 971707	GENNADIY SEMENOV	{"phone": "+70567749267"}
0005433633955	978383	0628 859651	DENIS DAVYDOV	{"phone": "+70166076874"}
0005433633956	978383	5694 005379	ANDREY KRASNOV	{"phone": "+70630000075"}
0005433633957	757C88	5849 745681	ALENA ALEKSEEVA	{"phone": "+70248892787"}
0005433633958	D80A0E	8756 588631	ELENA KRASNOVA	{"email": "elena-krasnova05071959@postgrespro.ru", "phone": "+70306912790"}
0005433633959	5B3734	9911 345273	NIKITA VASILEV	{"email": "n.vasilev-10061975@postgrespro.ru", "phone": "+70736721786"}
0005433633960	A83D7E	2707 132283	VALENTINA NIKITINA	{"email": "nikitina-v.1966@postgrespro.ru", "phone": "+70816121484"}
0005433633961	7C7D52	6438 330096	ELENA ANDREEVA	{"phone": "+70398267070"}
0005433633962	7C7D52	2970 490114	NATALYA MELNIKOVA	{"email": "nmelnikova01071973@postgrespro.ru", "phone": "+70809047410"}
0005433633963	59FB50	1467 940846	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr07101970@postgrespro.ru", "phone": "+70882079133"}
0005433633964	8538DD	1585 523779	YURIY SMIRNOV	{"phone": "+70807875483"}
0005433633965	8538DD	2745 470328	SERGEY KRASNOV	{"email": "krasnov_s_1959@postgrespro.ru", "phone": "+70094119229"}
0005433633966	618B72	8444 099773	DARYA IVANOVA	{"email": "ivanova-d.071985@postgrespro.ru", "phone": "+70191805345"}
0005433633967	3585CC	8510 385064	SERGEY DENISOV	{"email": "denisov-sergey_13051969@postgrespro.ru", "phone": "+70119054413"}
0005433633968	588968	3990 849303	MARIYA DANILOVA	{"email": "mariya_danilova_1968@postgrespro.ru", "phone": "+70008009131"}
0005433633969	395DE6	5328 774722	RIMMA NAUMOVA	{"email": "naumova-r-061967@postgrespro.ru", "phone": "+70399146685"}
0005433633970	395DE6	7459 590492	DMITRIY PETROV	{"phone": "+70680375939"}
0005433633971	B44AAA	8300 814835	IGOR SEMENOV	{"phone": "+70668139273"}
0005433633972	B44AAA	6190 042690	SERGEY NIKOLAEV	{"email": "sergey_nikolaev-1985@postgrespro.ru", "phone": "+70752606504"}
0005433633973	27724E	4035 237537	NINA ALEKSANDROVA	{"email": "aleksandrova_n-1969@postgrespro.ru", "phone": "+70601009281"}
0005433633974	27724E	8138 434205	NADEZHDA SIDOROVA	{"email": "n-sidorova1961@postgrespro.ru", "phone": "+70811908844"}
0005433633975	27724E	7360 171292	ALEKSANDR FROLOV	{"phone": "+70766061927"}
0005433633976	857E6C	0857 534850	ANATOLIY TIKHONOV	{"phone": "+70468408659"}
0005433633977	F4A8F7	7292 866236	NINA KOZLOVA	{"email": "n_kozlova_15081972@postgrespro.ru", "phone": "+70709472723"}
0005433633978	A48DAA	8681 849448	VERA NAZAROVA	{"phone": "+70104603920"}
0005433633979	FFA899	2020 438094	VYACHESLAV VASILEV	{"phone": "+70979339780"}
0005433633980	3AA5BA	6581 026734	SVETLANA EFREMOVA	{"email": "efremovas-07081965@postgrespro.ru", "phone": "+70097974259"}
0005433633981	3AA5BA	8345 904006	ALINA YAKOVLEVA	{"email": "yakovleva-a101978@postgrespro.ru", "phone": "+70213454038"}
0005433633982	0C7C14	3880 115467	VERA SOROKINA	{"phone": "+70453902110"}
0005433633983	667A9C	6595 263994	ANNA IVANOVA	{"phone": "+70907822722"}
0005433633984	CD20A0	5868 565327	ELENA BORISOVA	{"phone": "+70254786718"}
0005433633985	B4539E	5899 542148	RUSTAM MELNIKOV	{"phone": "+70124404000"}
0005433633986	B4539E	8430 197771	ANNA STEPANOVA	{"email": "a_stepanova-091974@postgrespro.ru", "phone": "+70724287116"}
0005433633987	77E341	9175 307904	SERGEY DAVYDOV	{"phone": "+70094753730"}
0005433633988	77E341	9750 005747	ELENA DENISOVA	{"email": "elena-denisova-101977@postgrespro.ru", "phone": "+70166537478"}
0005433633989	CB7195	1051 807741	NIKOLAY VASILEV	{"email": "vasilev.nikolay041976@postgrespro.ru", "phone": "+70150605002"}
0005433633990	88A90C	4521 767091	ANASTASIYA SEMENOVA	{"email": "semenova_a041976@postgrespro.ru", "phone": "+70795708458"}
0005433633991	511806	6967 998446	ANASTASIYA FEDOROVA	{"phone": "+70895565330"}
0005433633992	B6C67C	7454 721781	RIMMA VASILEVA	{"phone": "+70479755029"}
0005433633993	CD60DC	7155 967991	ALEKSANDR GUSEV	{"email": "aleksandr.gusev_1968@postgrespro.ru", "phone": "+70532996091"}
0005433633994	CD60DC	8236 407507	MAKSIM TIKHONOV	{"email": "tikhonov_maksim-1969@postgrespro.ru", "phone": "+70149930762"}
0005433633995	EF8CA5	2855 115653	YULIYA IVANOVA	{"email": "ivanovayuliya31121976@postgrespro.ru", "phone": "+70409017922"}
0005433633996	BF2C1C	3305 497344	SVETLANA FOMINA	{"phone": "+70678266229"}
0005433633997	BF2C1C	6342 842080	ANASTASIYA MIKHAYLOVA	{"phone": "+70728364432"}
0005433633998	6D0FD7	8878 666473	ELENA KOROLEVA	{"email": "koroleva-elena111972@postgrespro.ru", "phone": "+70972219822"}
0005433633999	B80849	5689 438419	VIKTORIYA KISELEVA	{"email": "viktoriya-kiseleva.1970@postgrespro.ru", "phone": "+70325981225"}
0005433634000	B80849	8160 150929	MARIYA NAUMOVA	{"email": "naumova_m-021961@postgrespro.ru", "phone": "+70594913239"}
0005433634001	5ADB16	4966 400426	SERGEY SCHERBAKOV	{"phone": "+70383753558"}
0005433634002	A2D298	4880 277134	IRINA GAVRILOVA	{"email": "gavrilova.irina-1972@postgrespro.ru", "phone": "+70909070859"}
0005433634003	51B5C0	2329 074433	ALEKSANDR SOKOLOV	{"phone": "+70293613507"}
0005433634006	5937D7	8727 182970	VLADISLAV ROMANOV	{"phone": "+70723457880"}
0005433634007	855449	5813 059469	MARGARITA TIMOFEEVA	{"email": "margarita-timofeeva-16051961@postgrespro.ru", "phone": "+70582139923"}
0005433634008	17A9E4	2643 087029	ELIZAVETA POPOVA	{"email": "epopova-121969@postgrespro.ru", "phone": "+70439879122"}
0005433634009	D4B123	6999 769826	ANASTASIYA DAVYDOVA	{"email": "anastasiyadavydova-1969@postgrespro.ru", "phone": "+70180093437"}
0005433634010	D4B123	9011 287402	VERA NIKOLAEVA	{"email": "nikolaeva.v_1967@postgrespro.ru", "phone": "+70125645175"}
0005433634011	4FCFB0	7057 699106	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-1972@postgrespro.ru", "phone": "+70636943826"}
0005433634012	7C8FC4	5456 975839	ANASTASIYA IVANOVA	{"phone": "+70075220253"}
0005433634013	7C8FC4	5881 084859	NATALYA SOROKINA	{"email": "nsorokina-09031970@postgrespro.ru", "phone": "+70144293051"}
0005433634014	FF60BF	8777 723371	ANTONINA OSIPOVA	{"phone": "+70744765329"}
0005433634015	F72018	3104 619058	NIKITA AFANASEV	{"email": "afanasevnikita.1973@postgrespro.ru", "phone": "+70218177533"}
0005433634016	D09078	8903 469507	SERGEY SMIRNOV	{"phone": "+70402082381"}
0005433634017	03BE94	2041 979019	ARTEM KUZNECOV	{"phone": "+70456449848"}
0005433634018	39A00A	5836 353440	VLADIMIR PAVLOV	{"phone": "+70296438978"}
0005433634019	39A00A	5504 481782	FEDOR TIKHONOV	{"email": "fedor-tikhonov_1973@postgrespro.ru", "phone": "+70594882658"}
0005433634020	058DB2	4777 318493	MARIYA MOROZOVA	{"email": "mariya-morozova-02121972@postgrespro.ru", "phone": "+70502655927"}
0005433634021	D26E09	2422 864680	VALENTINA ANDREEVA	{"phone": "+70902780879"}
0005433634022	99CB03	4474 761749	EVGENIYA LUKYANOVA	{"phone": "+70459255706"}
0005433634023	99CB03	4852 265516	NIKOLAY ROMANOV	{"phone": "+70347848560"}
0005433634024	99CB03	0141 909504	TATYANA NAUMOVA	{"phone": "+70652144567"}
0005433634025	20BA41	2547 936855	EVGENIYA MIRONOVA	{"email": "mironova.evgeniya-081980@postgrespro.ru", "phone": "+70416344780"}
0005433634026	7443CF	6542 365408	LIDIYA TIKHONOVA	{"phone": "+70985225191"}
0005433634027	A1D805	9692 507220	SERGEY KUZNECOV	{"email": "skuznecov_27051967@postgrespro.ru", "phone": "+70018661453"}
0005433634028	A1D805	9266 989207	ALEKSANDR FILIPPOV	{"email": "filippov-a_1977@postgrespro.ru", "phone": "+70652587289"}
0005433634029	A1D805	4802 264518	VERA ALEKSEEVA	{"email": "alekseeva-vera_19081980@postgrespro.ru", "phone": "+70293111204"}
0005433634030	657B12	9781 945625	ROMAN VOLKOV	{"phone": "+70018417692"}
0005433634031	47254F	0726 511724	DMITRIY GUSEV	{"email": "gusev.dmitriy_04051973@postgrespro.ru", "phone": "+70142263084"}
0005433634032	8A66E4	6500 922173	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy1964@postgrespro.ru", "phone": "+70249997296"}
0005433634033	BCA880	7610 519867	IRINA BELOVA	{"phone": "+70448157966"}
0005433634034	8ECCFD	0739 004210	VALERIYA KONOVALOVA	{"email": "valeriya.konovalova.1968@postgrespro.ru", "phone": "+70207683499"}
0005433634035	A93A12	9089 792258	TATYANA SOLOVEVA	{"email": "tatyanasoloveva-1976@postgrespro.ru", "phone": "+70251671161"}
0005433634036	4837D4	3969 884789	ALEKSEY DMITRIEV	{"phone": "+70727882612"}
0005433634037	96EA7F	7793 806156	NATALYA KULIKOVA	{"email": "kulikova.n.01071980@postgrespro.ru", "phone": "+70449211687"}
0005433634038	96EA7F	6830 805379	ELENA VLASOVA	{"email": "elena-vlasova-03101968@postgrespro.ru", "phone": "+70926765357"}
0005433634039	96EA7F	0611 981418	KRISTINA IVANOVA	{"email": "ivanovak.061986@postgrespro.ru", "phone": "+70052026851"}
0005433634040	3F19AA	6386 792133	VIKTOR ZAKHAROV	{"email": "zakharov.v_12021993@postgrespro.ru", "phone": "+70332050166"}
0005433634041	3F19AA	8079 414351	SVETLANA EGOROVA	{"email": "s_egorova1979@postgrespro.ru", "phone": "+70357655420"}
0005433634042	75720A	7490 980621	EVGENIY ALEKSEEV	{"email": "alekseev.e-121977@postgrespro.ru", "phone": "+70348736807"}
0005433634043	C5ECE1	1470 625140	VIKTOR TARASOV	{"phone": "+70818697999"}
0005433634044	D44ED1	8771 270930	NATALYA PAVLOVA	{"email": "natalya_pavlova1962@postgrespro.ru", "phone": "+70766778630"}
0005433634045	ADE06E	0768 272691	MARGARITA KULIKOVA	{"phone": "+70284670841"}
0005433634046	4DC1DB	7839 301498	DMITRIY VOLKOV	{"phone": "+70132780953"}
0005433634047	4DC1DB	9475 060373	VIKTOR FILIPPOV	{"email": "filippovv051965@postgrespro.ru", "phone": "+70969372086"}
0005433634048	76A2A2	2515 224643	GALIYA GRISHINA	{"email": "galiya-grishina_111961@postgrespro.ru", "phone": "+70374928111"}
0005433634049	A76847	2212 950199	SEMEN KOROLEV	{"email": "s-korolev.1972@postgrespro.ru", "phone": "+70840073771"}
0005433634051	4BFC81	1072 469887	TATYANA POPOVA	{"phone": "+70567029760"}
0005433634052	4F1A1C	7709 474062	YURIY KONOVALOV	{"email": "konovalov_y_17081971@postgrespro.ru", "phone": "+70315300528"}
0005433634053	4F1A1C	2887 781291	LYUDMILA NIKOLAEVA	{"phone": "+70608605056"}
0005433634054	151E49	1281 074296	VYACHESLAV PAVLOV	{"phone": "+70305777630"}
0005433634055	151E49	3854 948044	ANTON MAKAROV	{"phone": "+70093987308"}
0005433634056	6029FE	6799 777772	SVETLANA PETROVA	{"email": "svetlanapetrova_051958@postgrespro.ru", "phone": "+70939756947"}
0005433634057	42630C	8231 920993	SOFYA FROLOVA	{"phone": "+70529574787"}
0005433634058	9DDCD7	6093 643774	LIDIYA POPOVA	{"phone": "+70743850105"}
0005433634059	9DDCD7	1903 044637	VALENTINA SAVELEVA	{"email": "vsaveleva.071968@postgrespro.ru", "phone": "+70422506743"}
0005433634060	137CA8	0198 586104	MIROSLAV IVANOV	{"phone": "+70137727006"}
0005433634061	2282D0	8996 648022	VLADIMIR VLASOV	{"email": "vlasovvladimir.101968@postgrespro.ru", "phone": "+70298903692"}
0005433634228	FD2CBD	5252 104160	MARIYA STEPANOVA	{"phone": "+70577796580"}
0005433634062	94C576	0949 523221	ALEKSANDR ORLOV	{"email": "orlov-a.091982@postgrespro.ru", "phone": "+70567216405"}
0005433634063	0C3BFC	6938 400666	ELIZAVETA YUDINA	{"email": "eyudina_27081961@postgrespro.ru", "phone": "+70080731360"}
0005433634064	6AD983	1315 363398	ALEKSEY NIKITIN	{"email": "aleksey_nikitin.071979@postgrespro.ru", "phone": "+70507932261"}
0005433634065	6AD983	4433 063344	ANTONINA KISELEVA	{"email": "kiseleva.antonina-011980@postgrespro.ru", "phone": "+70363053724"}
0005433634066	B34340	4530 914020	MARGARITA SERGEEVA	{"email": "sergeeva_margarita06091974@postgrespro.ru", "phone": "+70786140742"}
0005433634067	62D5F3	1147 966871	IGOR MOISEEV	{"phone": "+70267588055"}
0005433634068	27884E	8539 403770	SERGEY NIKOLAEV	{"email": "sergeynikolaev-31051981@postgrespro.ru", "phone": "+70740104554"}
0005433634069	27884E	2675 386683	GLEB MIKHAYLOV	{"email": "gleb_mikhaylov-1964@postgrespro.ru", "phone": "+70439893048"}
0005433634070	15DC40	9906 646713	ALEKSANDRA IVANOVA	{"phone": "+70790154266"}
0005433634071	8F9459	7876 939021	EKATERINA MELNIKOVA	{"phone": "+70247861498"}
0005433634072	8F9459	4044 187844	NIKOLAY SEMENOV	{"email": "semenovnikolay_061971@postgrespro.ru", "phone": "+70129595952"}
0005433634073	01E3AF	6173 659244	VIKTOR SOROKIN	{"email": "vsorokin-031975@postgrespro.ru", "phone": "+70382916115"}
0005433634074	01E3AF	9387 376761	ANTONINA IVANOVA	{"phone": "+70973423578"}
0005433634075	A633C6	3145 119791	OLGA FILIPPOVA	{"phone": "+70153863598"}
0005433634076	BA7C5D	5772 913488	TATYANA ALEKSEEVA	{"email": "tatyanaalekseeva.1971@postgrespro.ru", "phone": "+70065364934"}
0005433634077	EEC0AC	3151 463908	YULIYA GORBUNOVA	{"email": "yuliya_gorbunova.1969@postgrespro.ru", "phone": "+70645085201"}
0005433634078	1ECF01	0939 898010	NATALIYA KUZNECOVA	{"email": "kuznecovan_09021960@postgrespro.ru", "phone": "+70002844283"}
0005433634079	9B1F55	7452 667211	ARTUR VOROBEV	{"phone": "+70357161672"}
0005433634080	2355EE	6433 676405	ELENA FEDOROVA	{"email": "e_fedorova011960@postgrespro.ru", "phone": "+70581725519"}
0005433634081	2355EE	7306 137338	OLGA MAKAROVA	{"email": "o.makarova_021972@postgrespro.ru", "phone": "+70205988565"}
0005433634082	85A9E8	5724 605882	GALINA KULIKOVA	{"phone": "+70962316873"}
0005433634083	AFF388	3729 018228	ANTON SIDOROV	{"email": "anton.sidorov-31071975@postgrespro.ru", "phone": "+70134745670"}
0005433634084	AFF388	7514 463509	ALEKSANDR EGOROV	{"phone": "+70232982046"}
0005433634085	06AC10	1247 795571	EVGENIY IVANOV	{"phone": "+70284155138"}
0005433634086	D23E9C	7804 034451	PAVEL SHEVCHENKO	{"phone": "+70310978772"}
0005433634087	F42C74	6598 409620	ANATOLIY MIRONOV	{"email": "mironov-anatoliy-121965@postgrespro.ru", "phone": "+70656256688"}
0005433634088	6A3334	5501 850383	EVGENIY TARASOV	{"phone": "+70281442115"}
0005433634089	5631FA	6663 796479	YURIY GERASIMOV	{"email": "gerasimov.yuriy_02021969@postgrespro.ru", "phone": "+70922759296"}
0005433634090	5631FA	8104 487730	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov17091966@postgrespro.ru", "phone": "+70106754534"}
0005433634091	DDADF8	4406 560770	DMITRIY SHEVCHENKO	{"email": "dshevchenko-1981@postgrespro.ru", "phone": "+70870791635"}
0005433634092	DDADF8	9589 080007	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr-21011973@postgrespro.ru", "phone": "+70709309261"}
0005433634093	DDADF8	3915 455964	EKATERINA EGOROVA	{"phone": "+70519200618"}
0005433634094	5AB1F7	7465 098747	NINA SIDOROVA	{"email": "sidorovan-08041973@postgrespro.ru", "phone": "+70358751619"}
0005433634095	0CD23E	8629 103027	GENNADIY POPOV	{"phone": "+70665516157"}
0005433634096	0CD23E	7258 652974	SVETLANA SCHERBAKOVA	{"phone": "+70101123855"}
0005433634097	BCEBC3	1557 243247	VALERIY MAKSIMOV	{"phone": "+70360683182"}
0005433634098	BCEBC3	8767 226843	SERGEY KOZLOV	{"phone": "+70197158710"}
0005433634099	5C127D	9867 476752	LYUDMILA VASILEVA	{"phone": "+70756659703"}
0005433634100	626FDA	5152 172325	FILIPP NAZAROV	{"phone": "+70013778366"}
0005433634101	000B97	6889 375514	ANDREY IVANOV	{"email": "andrey-ivanov.091973@postgrespro.ru", "phone": "+70497820699"}
0005433634102	80D198	5139 345903	IVAN SOROKIN	{"email": "ivan.sorokin-19051977@postgrespro.ru", "phone": "+70891349641"}
0005433634103	E68BE5	2047 980064	VLADISLAV RODIONOV	{"phone": "+70111805623"}
0005433634104	73456A	9258 976040	KRISTINA TARASOVA	{"phone": "+70479638509"}
0005433634105	73456A	9801 132452	ALBINA BELOVA	{"email": "belovaa_111961@postgrespro.ru", "phone": "+70898731797"}
0005433634106	EC3D93	6492 882503	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr-09091977@postgrespro.ru", "phone": "+70374110953"}
0005433634107	F086DE	6275 597740	VALENTINA SMIRNOVA	{"email": "smirnova-valentina_081973@postgrespro.ru", "phone": "+70616299840"}
0005433634108	F086DE	3332 362536	MARIYA POPOVA	{"email": "mariya-popova_081975@postgrespro.ru", "phone": "+70719478617"}
0005433634109	1D70C5	8041 517944	MARIYA NESTEROVA	{"email": "nesterova_mariya-23091980@postgrespro.ru", "phone": "+70892067728"}
0005433634110	1D70C5	3338 928115	VIKTOR TARASOV	{"phone": "+70592183169"}
0005433634111	4E38F2	6727 143821	VLADIMIR GRIGOREV	{"email": "grigorev-vladimir_1985@postgrespro.ru", "phone": "+70003106845"}
0005433634112	D505C2	1111 038376	ALEKSEY KUZNECOV	{"phone": "+70883130924"}
0005433634113	D4808C	2312 443033	AZAT ZHURAVLEV	{"email": "zhuravlev.a-111973@postgrespro.ru", "phone": "+70790554059"}
0005433634114	636AFA	1083 863679	GALINA KONOVALOVA	{"email": "galinakonovalova121966@postgrespro.ru", "phone": "+70915887272"}
0005433634115	B6BF8E	2450 469461	VALENTINA MARTYNOVA	{"email": "v_martynova-101980@postgrespro.ru", "phone": "+70235258867"}
0005433634116	FCAEF6	7900 376174	SVETLANA POPOVA	{"email": "popova_s_091966@postgrespro.ru", "phone": "+70898118016"}
0005433634117	40716E	4749 909933	ELENA EFREMOVA	{"email": "elenaefremova-1977@postgrespro.ru", "phone": "+70941271974"}
0005433634118	40716E	6659 627874	ROMAN GORBUNOV	{"phone": "+70399715307"}
0005433634119	828231	7268 162853	OKSANA ZAKHAROVA	{"email": "o_zakharova.091973@postgrespro.ru", "phone": "+70156548659"}
0005433634120	F3E860	7076 738866	VERA GAVRILOVA	{"email": "gavrilova.vera17101966@postgrespro.ru", "phone": "+70155459457"}
0005433634121	DBC40E	1457 712455	VALENTINA IVANOVA	{"phone": "+70114849868"}
0005433634122	E5AE84	5543 722940	EKATERINA ALEKSANDROVA	{"email": "aleksandrova_e.021967@postgrespro.ru", "phone": "+70407847765"}
0005433634123	561EB4	2461 770430	IGOR SOKOLOV	{"email": "igor_sokolov041975@postgrespro.ru", "phone": "+70787752908"}
0005433634124	561EB4	3727 933345	TAISIYA MIKHAYLOVA	{"email": "taisiya-mikhaylova.121975@postgrespro.ru", "phone": "+70996405431"}
0005433634125	561EB4	4120 734914	VARVARA FEDOROVA	{"email": "fedorova_v.101977@postgrespro.ru", "phone": "+70488450402"}
0005433634126	FF9713	4575 801859	MIKHAIL PAVLOV	{"email": "pavlovm-11041968@postgrespro.ru", "phone": "+70424315567"}
0005433634127	380B4D	7649 208736	ANASTASIYA POPOVA	{"email": "a-popova_1981@postgrespro.ru", "phone": "+70798936365"}
0005433634128	22A90F	0138 426127	ANASTASIYA ZAYCEVA	{"email": "zayceva-anastasiya.1981@postgrespro.ru", "phone": "+70968391249"}
0005433634129	22A90F	0592 938682	OKSANA KOLESNIKOVA	{"phone": "+70170397661"}
0005433634130	2E581D	3742 333627	VLADIMIR GRIGOREV	{"email": "grigorev-vladimir-10051963@postgrespro.ru", "phone": "+70184132404"}
0005433634131	275854	8757 632141	VLADIMIR FROLOV	{"phone": "+70469983229"}
0005433634132	275854	1071 574887	NADEZHDA POPOVA	{"phone": "+70166608899"}
0005433634193	B7B6C4	3023 911646	ALEKSANDR ZHURAVLEV	{"phone": "+70249069693"}
0005433634133	5B7B99	3639 311222	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v.091969@postgrespro.ru", "phone": "+70964714202"}
0005433634134	5B7B99	2797 427024	NATALYA PAVLOVA	{"email": "pavlovan-19081970@postgrespro.ru", "phone": "+70501862595"}
0005433634135	1798EB	2409 013772	VALERIY KUZNECOV	{"email": "v_kuznecov_10031977@postgrespro.ru", "phone": "+70187455652"}
0005433634136	1798EB	4286 120978	RODION PETROV	{"email": "rodionpetrov17031976@postgrespro.ru", "phone": "+70199589663"}
0005433634137	0173E0	9074 433930	EDUARD ILIN	{"email": "ilin-e_061977@postgrespro.ru", "phone": "+70223308727"}
0005433634138	30DAC3	4985 343109	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov07021983@postgrespro.ru", "phone": "+70222046361"}
0005433634139	B80182	3485 329206	ALEKSANDR ILIN	{"email": "aleksandr-ilin1973@postgrespro.ru", "phone": "+70738890862"}
0005433634140	E65104	6147 409909	ANNA ISAEVA	{"phone": "+70380317919"}
0005433634141	35C5EB	0921 307294	ARTEM ZAKHAROV	{"phone": "+70501348511"}
0005433634142	439514	1451 816295	VLADIMIR DAVYDOV	{"email": "v-davydov.03111979@postgrespro.ru", "phone": "+70546052776"}
0005433634143	6F0F25	5355 446824	NATALYA NAZAROVA	{"email": "nazarova-natalya_041962@postgrespro.ru", "phone": "+70680434398"}
0005433634144	F8706C	2411 815590	NINA FEDOROVA	{"email": "n.fedorova.1959@postgrespro.ru", "phone": "+70670130442"}
0005433634145	EF3799	3151 235993	VLADIMIR MAKAROV	{"email": "makarov-v_051977@postgrespro.ru", "phone": "+70942944092"}
0005433634146	8B0106	9197 788279	EKATERINA KUZNECOVA	{"phone": "+70670648596"}
0005433634147	8B0106	9573 854816	ANDREY EGOROV	{"email": "egorov-andrey_061977@postgrespro.ru", "phone": "+70850847378"}
0005433634148	F8CC5B	7311 280663	LYUBOV SEMENOVA	{"phone": "+70231510876"}
0005433634149	E2C15B	2466 754050	SERGEY BONDARENKO	{"email": "s_bondarenko111974@postgrespro.ru", "phone": "+70011477246"}
0005433634150	E2C15B	1345 370540	IGOR SEMENOV	{"phone": "+70576307836"}
0005433634151	A441F1	7971 492846	NINA KUZNECOVA	{"email": "nina.kuznecova-19011971@postgrespro.ru", "phone": "+70374028409"}
0005433634152	D62606	1560 151581	RAISA NAZAROVA	{"phone": "+70017757095"}
0005433634153	15126A	0336 717721	NIKITA ALEKSEEV	{"email": "nikita-alekseev07081977@postgrespro.ru", "phone": "+70299996283"}
0005433634154	23CF33	4872 658178	KONSTANTIN MELNIKOV	{"email": "melnikov.konstantin.10121978@postgrespro.ru", "phone": "+70886713626"}
0005433634155	296098	9819 199002	LYUDMILA ZHUKOVA	{"email": "lzhukova.19081969@postgrespro.ru", "phone": "+70255903015"}
0005433634156	615D09	3124 051104	ELENA MIKHAYLOVA	{"email": "emikhaylova-1970@postgrespro.ru", "phone": "+70567943019"}
0005433634157	615D09	1513 981016	ANDREY SERGEEV	{"email": "sergeev-andrey_11041969@postgrespro.ru", "phone": "+70998186226"}
0005433634158	59E74D	3651 863596	VLADIMIR SERGEEV	{"phone": "+70553472785"}
0005433634159	59E74D	9964 589259	ANGELINA IVANOVA	{"email": "a_ivanova31121975@postgrespro.ru", "phone": "+70853838181"}
0005433634160	4BB314	3101 751438	MARIYA SERGEEVA	{"phone": "+70842954698"}
0005433634161	494F82	1381 161707	OLGA ARKHIPOVA	{"phone": "+70169129718"}
0005433634162	494F82	4247 514320	NINA KUZMINA	{"phone": "+70942365677"}
0005433634163	27EF8B	4907 836028	ALEKSANDR NIKITIN	{"phone": "+70530007379"}
0005433634164	219DD3	3335 931948	NATALYA BOGDANOVA	{"phone": "+70169386549"}
0005433634165	219DD3	7479 187995	NIKITA GRIGOREV	{"email": "nikita_grigorev.041964@postgrespro.ru", "phone": "+70166322931"}
0005433634166	219DD3	8422 415377	NIKOLAY VASILEV	{"phone": "+70164177266"}
0005433634167	4E096D	0470 034093	DMITRIY VASILEV	{"email": "vasilev-d_29071979@postgrespro.ru", "phone": "+70805481561"}
0005433634168	4E096D	4117 785176	MIKHAIL ANDREEV	{"email": "mikhail_andreev-12091968@postgrespro.ru", "phone": "+70941906589"}
0005433634169	3755B2	3701 875690	SERGEY ZAKHAROV	{"email": "zakharov_s061973@postgrespro.ru", "phone": "+70826621072"}
0005433634170	889BA9	3510 198268	ELENA GRISHINA	{"phone": "+70788351010"}
0005433634229	799460	9009 740617	IRINA SIDOROVA	{"phone": "+70645541048"}
0005433634171	4E9141	2799 878447	NINA OVCHINNIKOVA	{"email": "ovchinnikova_nina.101973@postgrespro.ru", "phone": "+70888251550"}
0005433634172	4E9141	2532 708613	ANNA DENISOVA	{"phone": "+70654721195"}
0005433634173	4E35B9	7211 065148	VALENTINA ROMANOVA	{"email": "v.romanova20081970@postgrespro.ru", "phone": "+70814702502"}
0005433634174	E36510	0081 622119	YULIYA SMIRNOVA	{"phone": "+70918469814"}
0005433634175	E36510	5317 288830	EVGENIYA NIKOLAEVA	{"phone": "+70226567959"}
0005433634176	2F5E89	6159 637276	ANASTASIYA OVCHINNIKOVA	{"phone": "+70835833697"}
0005433634177	A290CC	7106 205531	TATYANA PAVLOVA	{"email": "pavlovatatyana-031972@postgrespro.ru", "phone": "+70199128466"}
0005433634178	A290CC	0816 446385	TATYANA ZAKHAROVA	{"phone": "+70073229770"}
0005433634179	572D10	4033 987600	NATALYA POPOVA	{"phone": "+70545124495"}
0005433634180	572D10	0178 611811	TATYANA GUSEVA	{"phone": "+70958973883"}
0005433634181	351DBD	3922 693125	VYACHESLAV KARPOV	{"email": "karpov_vyacheslav.1972@postgrespro.ru", "phone": "+70613756074"}
0005433634182	351DBD	1491 073403	ANASTASIYA KUZNECOVA	{"phone": "+70646839607"}
0005433634183	351DBD	7194 555336	ANDREY STEPANOV	{"phone": "+70783891470"}
0005433634184	30C16A	7107 988396	KSENIYA PAVLOVA	{"phone": "+70883010963"}
0005433634185	38CDCB	1029 822262	YURIY ANTONOV	{"phone": "+70671210100"}
0005433634186	38CDCB	3083 591706	MARINA POPOVA	{"phone": "+70871059830"}
0005433634187	2F069D	9447 594962	ALEKSEY KUZNECOV	{"phone": "+70863987620"}
0005433634188	955D66	2334 161208	IGOR MELNIKOV	{"phone": "+70795216995"}
0005433634189	7AA716	3887 593512	NIKOLAY TARASOV	{"phone": "+70213244294"}
0005433634190	1561D6	6124 973346	IVAN MARTYNOV	{"phone": "+70233571757"}
0005433634191	47D98E	0286 372306	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr-09031975@postgrespro.ru", "phone": "+70136929064"}
0005433634192	F48411	3606 910060	ALEKSEY GERASIMOV	{"phone": "+70061681316"}
0005433634194	7BE115	3521 282066	OLGA GORBUNOVA	{"email": "olga_gorbunova02101980@postgrespro.ru", "phone": "+70346155903"}
0005433634195	7BE115	1572 269231	RUSLAN GAVRILOV	{"email": "gavrilov.r_1967@postgrespro.ru", "phone": "+70464157212"}
0005433634196	0A670B	7891 315220	SVETLANA POPOVA	{"email": "popovas101966@postgrespro.ru", "phone": "+70993199264"}
0005433634197	AA172C	0813 273964	YURIY BORISOV	{"phone": "+70119472185"}
0005433634198	162156	0948 481452	VALERIY ZHUKOV	{"email": "zhukov_valeriy_22071971@postgrespro.ru", "phone": "+70080476218"}
0005433634199	9D8D5D	9537 311352	NINA OSIPOVA	{"phone": "+70643334518"}
0005433634200	85AEEE	0682 317986	RUSLAN MOROZOV	{"phone": "+70200965268"}
0005433634201	0DD372	2465 940629	SERGEY DENISOV	{"email": "denisovs.26101968@postgrespro.ru", "phone": "+70149172822"}
0005433634202	0DD372	2215 505965	VALERIYA EGOROVA	{"email": "valeriya.egorova-1976@postgrespro.ru", "phone": "+70780189780"}
0005433634203	91904C	1728 009093	SERGEY GRIGOREV	{"email": "sgrigorev-23061975@postgrespro.ru", "phone": "+70871243500"}
0005433634204	91904C	3265 135606	EGOR ZAKHAROV	{"phone": "+70993423295"}
0005433634205	C94D16	3884 105422	MAKSIM SIDOROV	{"phone": "+70873182055"}
0005433634206	4146FC	6940 766283	ANASTASIYA IVANOVA	{"email": "ivanova_a111970@postgrespro.ru", "phone": "+70901900033"}
0005433634207	97750B	9863 037100	NIKITA POPOV	{"email": "n.popov-1980@postgrespro.ru", "phone": "+70244599417"}
0005433634208	97750B	0037 975061	ANNA NIKOLAEVA	{"email": "anna-nikolaeva_10011962@postgrespro.ru", "phone": "+70284419493"}
0005433634209	97750B	7015 045699	MARIYA SOLOVEVA	{"email": "soloveva-m12021979@postgrespro.ru", "phone": "+70058315180"}
0005433634210	781CDE	9647 643981	LEONID ZAYCEV	{"phone": "+70643696398"}
0005433634211	E38D92	2517 454855	KLAVDIYA DANILOVA	{"phone": "+70318281157"}
0005433634212	594F25	1026 888841	RAISA MELNIKOVA	{"email": "melnikovaraisa011957@postgrespro.ru", "phone": "+70107130116"}
0005433634213	BE3591	7711 538949	OLGA MIKHAYLOVA	{"phone": "+70480115850"}
0005433634214	F72E50	7284 642183	SERGEY FEDOROV	{"phone": "+70923816951"}
0005433634215	8C6C48	2331 369824	VERA KOROLEVA	{"email": "koroleva.vera-1967@postgrespro.ru", "phone": "+70370728384"}
0005433634216	8C6C48	9142 318490	GENNADIY FOMIN	{"phone": "+70676035954"}
0005433634217	BA9789	9191 845279	OLGA ROMANOVA	{"phone": "+70479051344"}
0005433634218	9179F0	4868 423417	SEMEN MAKSIMOV	{"phone": "+70411531738"}
0005433634219	9179F0	1653 466734	ARTEM VASILEV	{"email": "artem.vasilev-011985@postgrespro.ru", "phone": "+70371540586"}
0005433634220	7FAFE4	1624 385988	EVGENIY BARANOV	{"email": "e.baranov.031956@postgrespro.ru", "phone": "+70743633657"}
0005433634221	039E03	3940 402805	ELENA SOLOVEVA	{"email": "e.soloveva-1972@postgrespro.ru", "phone": "+70232844366"}
0005433634222	D0E9C6	9266 421236	DARYA MELNIKOVA	{"email": "dmelnikova-1963@postgrespro.ru", "phone": "+70250038568"}
0005433634223	7BBC16	2482 460936	VLADIMIR IVANOV	{"phone": "+70060345667"}
0005433634224	7BBC16	9433 722026	ANASTASIYA ROMANOVA	{"phone": "+70155758777"}
0005433634225	31CA05	9300 985111	KIRILL ZAYCEV	{"email": "k.zaycev-31071977@postgrespro.ru", "phone": "+70929630480"}
0005433634226	822632	9368 203389	OLGA BELOVA	{"phone": "+70519964518"}
0005433634227	686373	4310 525168	MAKSIM ORLOV	{"email": "maksim_orlov-111968@postgrespro.ru", "phone": "+70526031899"}
0005433634230	2ED65E	0110 494580	ARTEM ZHURAVLEV	{"email": "zhuravlev-a-15011965@postgrespro.ru", "phone": "+70059463988"}
0005433634231	2ED65E	7144 039885	TATYANA NIKITINA	{"email": "nikitina-tatyana26071966@postgrespro.ru", "phone": "+70545020859"}
0005433634232	4B81C8	8634 736207	IVAN POPOV	{"phone": "+70724755688"}
0005433634233	82AF94	5260 598477	LIDIYA DENISOVA	{"phone": "+70925583783"}
0005433634234	39F031	7533 423407	SERGEY KUZNECOV	{"phone": "+70752519195"}
0005433634235	FA7604	5062 671245	NIKOLAY GERASIMOV	{"phone": "+70316172727"}
0005433634236	8CC63A	5504 439727	KONSTANTIN KUZNECOV	{"email": "konstantin-kuznecov21071974@postgrespro.ru", "phone": "+70346685908"}
0005433634237	8CC63A	9583 081394	DMITRIY FEDOROV	{"phone": "+70507689990"}
0005433634238	E4A890	0916 284464	IRINA ARKHIPOVA	{"email": "i.arkhipova1971@postgrespro.ru", "phone": "+70502653131"}
0005433634239	76F293	0963 701122	NIKOLAY POPOV	{"phone": "+70045212239"}
0005433634240	931D87	6815 337185	NIKOLAY GORBUNOV	{"email": "gorbunov.n.08121971@postgrespro.ru", "phone": "+70308348686"}
0005433634241	931D87	9330 457990	DENIS CHERNOV	{"email": "chernov.d-1975@postgrespro.ru", "phone": "+70810260851"}
0005433634242	931D87	1529 381623	LARISA GAVRILOVA	{"phone": "+70705345193"}
0005433634243	B6BAA3	8474 582562	IVAN IVANOV	{"phone": "+70836015097"}
0005433634244	B6BAA3	3593 808072	DENIS VASILEV	{"phone": "+70580910820"}
0005433634245	8326EF	9163 138750	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr1975@postgrespro.ru", "phone": "+70986770579"}
0005433634246	95E583	5791 166708	NIKOLAY ILIN	{"email": "n.ilin.11011966@postgrespro.ru", "phone": "+70315565061"}
0005433634247	3C2056	4848 803613	EKATERINA SAVELEVA	{"email": "ekaterina.saveleva.02031966@postgrespro.ru", "phone": "+70743976386"}
0005433634248	E0EAF5	5540 044465	ELENA IVANOVA	{"email": "ivanova-e.07081966@postgrespro.ru", "phone": "+70462427352"}
0005433634249	CF6234	6207 598292	STANISLAV AFANASEV	{"email": "afanasev-stanislav041975@postgrespro.ru", "phone": "+70118392500"}
0005433634250	CF6234	6808 251173	ALEKSANDR DENISOV	{"email": "aleksandr.denisov_1970@postgrespro.ru", "phone": "+70693833881"}
0005433634251	60B85F	9070 261725	VLADISLAV TIMOFEEV	{"phone": "+70629800361"}
0005433634252	332286	3387 096768	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-1970@postgrespro.ru", "phone": "+70416819311"}
0005433634253	332286	5224 235350	IVAN TIKHONOV	{"phone": "+70203974984"}
0005433634254	8F24E2	4123 280646	TATYANA GORBUNOVA	{"email": "gorbunova-tatyana_021970@postgrespro.ru", "phone": "+70329510086"}
0005433634255	7A286F	1681 529962	OLGA KISELEVA	{"email": "kiselevaolga09121990@postgrespro.ru", "phone": "+70751287284"}
0005433634256	7A286F	4660 954020	DARYA YAKOVLEVA	{"phone": "+70545772484"}
0005433634257	A0C889	9814 158587	VERA OVCHINNIKOVA	{"email": "v-ovchinnikova-28021979@postgrespro.ru", "phone": "+70869474664"}
0005433634258	A0C889	6201 265029	ANASTASIYA EFIMOVA	{"email": "aefimova.1974@postgrespro.ru", "phone": "+70153822136"}
0005433634259	117B88	6784 866061	EVGENIY ANDREEV	{"phone": "+70884100498"}
0005433634260	ED92C1	7802 102899	NADEZHDA MOROZOVA	{"phone": "+70929095365"}
0005433634261	633189	3255 555538	YURIY SIDOROV	{"email": "yuriysidorov_1980@postgrespro.ru", "phone": "+70346137909"}
0005433634262	AE36B6	9774 607083	PETR NOVIKOV	{"phone": "+70866315125"}
0005433634263	AE36B6	7244 430789	GENNADIY GAVRILOV	{"email": "ggavrilov-12071963@postgrespro.ru", "phone": "+70919245397"}
0005433634264	2995E1	6414 163809	DMITRIY ROMANOV	{"phone": "+70512022185"}
0005433634265	1DFED1	0238 197615	ANTON FROLOV	{"phone": "+70530540304"}
0005433634266	1DFED1	2967 286017	TATYANA DENISOVA	{"email": "t-denisova_041973@postgrespro.ru", "phone": "+70463324025"}
0005433634267	040B6A	6690 224824	ALEKSANDR SOROKIN	{"phone": "+70588943389"}
0005433634268	942108	5125 281350	ALEKSANDR SIDOROV	{"email": "sidorov_a_01081974@postgrespro.ru", "phone": "+70741849835"}
0005433634269	A4BEF3	8023 548444	YAN SOKOLOV	{"phone": "+70985814978"}
0005433634270	2B888A	6102 451185	TATYANA KOROLEVA	{"phone": "+70816963879"}
0005433634271	EDD221	0515 452819	NIKOLAY MELNIKOV	{"phone": "+70514862018"}
0005433634272	EDD221	7258 327912	LYUBOV NAUMOVA	{"email": "lyubovnaumova1973@postgrespro.ru", "phone": "+70523531403"}
0005433634273	E2911D	2662 592097	OLGA VOLKOVA	{"phone": "+70543831570"}
0005433634274	309A52	0776 826910	VIKTOR VOLKOV	{"phone": "+70100444032"}
0005433634275	5DD419	0722 912013	ELEONORA MIKHAYLOVA	{"email": "mikhaylovaeleonora-021971@postgrespro.ru", "phone": "+70614174730"}
0005433634276	5DD419	5080 941134	GALINA NAUMOVA	{"phone": "+70980957068"}
0005433634277	8C0405	9137 035756	IGOR MAKAROV	{"email": "makarov_i.24091959@postgrespro.ru", "phone": "+70032895786"}
0005433634278	0FE03C	1510 373655	SVETLANA SOROKINA	{"phone": "+70220650541"}
0005433634279	0FE03C	3414 046807	SERGEY MAKSIMOV	{"phone": "+70380387045"}
0005433634280	E6B674	7596 670409	EGOR ZHUKOV	{"email": "e_zhukov-21021964@postgrespro.ru", "phone": "+70946864848"}
0005433634281	A7A2CD	7343 057442	NIKOLAY DAVYDOV	{"phone": "+70289481315"}
0005433634282	AE4FC2	7097 683970	KRISTINA ZAYCEVA	{"email": "zaycevak.111981@postgrespro.ru", "phone": "+70577805220"}
0005433634283	D41E68	7691 917375	VLADIMIR BONDARENKO	{"email": "vladimir_bondarenko.07111977@postgrespro.ru", "phone": "+70543670138"}
0005433634284	E39FD2	1868 355440	IRINA TIKHONOVA	{"phone": "+70642161789"}
0005433634285	A9846B	2898 207996	ZOYA NAZAROVA	{"email": "zoya_nazarova1964@postgrespro.ru", "phone": "+70086432827"}
0005433634286	ED8F41	8162 836642	NADEZHDA BOGDANOVA	{"email": "bogdanova-nadezhda.08111968@postgrespro.ru", "phone": "+70434989948"}
0005433634287	ED8F41	0176 208835	NATALYA NIKOLAEVA	{"phone": "+70020656632"}
0005433634288	A8E049	0335 121830	VIKTOR AFANASEV	{"email": "afanasev-v-1965@postgrespro.ru", "phone": "+70280018208"}
0005433634289	A8E049	4464 889442	DANIIL YAKOVLEV	{"phone": "+70681701216"}
0005433634290	730E90	7669 187332	VADIM ABRAMOV	{"phone": "+70979851349"}
0005433634291	043BC9	2854 619607	ELENA VLASOVA	{"email": "vlasova.elena_1961@postgrespro.ru", "phone": "+70535619652"}
0005433634292	1D71A5	9866 038679	TATYANA KOZLOVA	{"phone": "+70113959425"}
0005433634293	1D71A5	4169 173768	MARSEL SAVELEV	{"email": "savelev-m_1978@postgrespro.ru", "phone": "+70787864585"}
0005433634294	BB5497	6635 554754	NATALYA ANDREEVA	{"email": "andreeva_natalya.071960@postgrespro.ru", "phone": "+70333121701"}
0005433634295	49E101	4918 330808	ALEKSEY MOROZOV	{"phone": "+70914819877"}
0005433634296	49E101	5736 977117	NINA KONDRATEVA	{"phone": "+70691814214"}
0005433634297	BA26B8	8905 243001	ANDREY BELOV	{"email": "belovandrey_1959@postgrespro.ru", "phone": "+70532272589"}
0005433634298	F44C21	4262 263932	DARYA IVANOVA	{"email": "ivanova.d_1961@postgrespro.ru", "phone": "+70246215011"}
0005433634299	F44C21	6818 525427	NINA FILIPPOVA	{"phone": "+70630034054"}
0005433634300	F6C3D3	1627 287099	ANTONINA VOROBEVA	{"email": "antonina.vorobeva_18081973@postgrespro.ru", "phone": "+70088135780"}
0005433634301	F6C3D3	3804 103353	SERGEY POPOV	{"email": "popovs-1981@postgrespro.ru", "phone": "+70649873221"}
0005433634302	A9E2AC	2062 979846	GALINA POPOVA	{"email": "g_popova_041973@postgrespro.ru", "phone": "+70918012692"}
0005433634303	A9E2AC	9465 275520	IVAN IVANOV	{"email": "ivanov-i02091963@postgrespro.ru", "phone": "+70890639643"}
0005433634304	1FF952	4073 252565	ELENA SOKOLOVA	{"email": "e_sokolova.071978@postgrespro.ru", "phone": "+70048459116"}
0005433634305	1FF952	9671 569237	PETR POPOV	{"phone": "+70620524377"}
0005433634306	BCF67B	8218 404237	DANILA VASILEV	{"email": "d_vasilev_20021979@postgrespro.ru", "phone": "+70279228269"}
0005433634307	BCF67B	4951 862792	YAN NAUMOV	{"phone": "+70191972302"}
0005433634308	E9F2C2	1926 722401	LYUBOV RYABOVA	{"email": "l-ryabova-061972@postgrespro.ru", "phone": "+70734999228"}
0005433634309	9BBE42	3080 246426	ARTUR VLASOV	{"email": "a-vlasov.26051978@postgrespro.ru", "phone": "+70555980697"}
0005433634310	0E7F5D	0739 041412	ANDREY ROMANOV	{"phone": "+70843157672"}
0005433634311	995332	2540 295648	ELIZAVETA KUZNECOVA	{"email": "e.kuznecova1981@postgrespro.ru", "phone": "+70445372191"}
0005433634312	995332	0282 647956	NIKOLAY PAVLOV	{"phone": "+70858192644"}
0005433634313	89509C	6264 791593	NIKOLAY ALEKSEEV	{"phone": "+70753371626"}
0005433634314	F64FB4	3816 856420	OLGA NAZAROVA	{"email": "nazarova-olga_22051977@postgrespro.ru", "phone": "+70652239846"}
0005433634315	1762EA	0249 263620	NATALYA NAZAROVA	{"phone": "+70543779667"}
0005433634316	1762EA	0421 944131	EVGENIYA NIKOLAEVA	{"email": "e-nikolaeva05101984@postgrespro.ru", "phone": "+70897732416"}
0005433634317	FFB9F4	3401 611630	IRINA FILIPPOVA	{"phone": "+70464282304"}
0005433634318	FFB9F4	4406 027532	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr.091976@postgrespro.ru", "phone": "+70634564220"}
0005433634319	F0109D	2485 054025	OLGA NIKOLAEVA	{"phone": "+70916183332"}
0005433634320	9AFC96	2889 513139	RAMIL ZHURAVLEV	{"phone": "+70939170642"}
0005433634321	306769	1034 332034	ALENA NESTEROVA	{"phone": "+70914024942"}
0005433634322	F1A392	4137 144883	YULIYA KOROLEVA	{"email": "yuliyakoroleva-061970@postgrespro.ru", "phone": "+70846207753"}
0005433634323	6A1642	2146 642780	MARGARITA ARKHIPOVA	{"email": "arkhipova_margarita111961@postgrespro.ru", "phone": "+70463722344"}
0005433634324	6A1642	8616 935078	VIKTORIYA SOLOVEVA	{"email": "solovevav1968@postgrespro.ru", "phone": "+70520523249"}
0005433634325	2F2CCB	3414 554306	EVGENIYA IVANOVA	{"phone": "+70336559192"}
0005433634326	2F2CCB	3517 927047	OKSANA DAVYDOVA	{"phone": "+70762228551"}
0005433634327	89ABE1	2500 748562	NINA VOROBEVA	{"email": "vorobevanina.1968@postgrespro.ru", "phone": "+70676452030"}
0005433634328	89ABE1	5208 811205	YULIYA SAVELEVA	{"email": "ysaveleva051989@postgrespro.ru", "phone": "+70760148645"}
0005433634329	F17AC0	8202 261811	MARINA OVCHINNIKOVA	{"phone": "+70045856163"}
0005433634330	F17AC0	7750 363459	DARYA VOROBEVA	{"email": "vorobevadarya1971@postgrespro.ru", "phone": "+70017210887"}
0005433634331	25510A	8329 594844	YULIYA MAKSIMOVA	{"email": "ymaksimova.1973@postgrespro.ru", "phone": "+70193311861"}
0005433634332	25510A	1413 405684	LARISA KAZAKOVA	{"phone": "+70632486779"}
0005433634333	E7225F	7734 628735	ELENA RODIONOVA	{"email": "rodionova-elena.111967@postgrespro.ru", "phone": "+70388024765"}
0005433634334	E7225F	8427 206987	NADEZHDA NIKITINA	{"email": "nadezhda.nikitina_09081977@postgrespro.ru", "phone": "+70964475266"}
0005433634335	470466	7626 456158	REGINA KUZNECOVA	{"email": "regina_kuznecova_24031974@postgrespro.ru", "phone": "+70684242592"}
0005433634336	15653A	5182 197799	LYUBOV MATVEEVA	{"phone": "+70511866004"}
0005433634337	B8D5B7	7111 846878	DMITRIY SMIRNOV	{"email": "dmitriy_smirnov1974@postgrespro.ru", "phone": "+70880381234"}
0005433634338	ADE88A	7005 714913	LYUDMILA KOROLEVA	{"phone": "+70642313663"}
0005433634339	ADE88A	4850 228639	EVGENIY YAKOVLEV	{"email": "evgeniy.yakovlev-26121975@postgrespro.ru", "phone": "+70550652251"}
0005433634340	806535	8315 678133	TATYANA ZHUKOVA	{"phone": "+70329724572"}
0005433634452	5C0D24	9701 597128	EKATERINA MIRONOVA	{"phone": "+70629308984"}
0005433634341	1E494A	9203 993057	GALINA GUSEVA	{"email": "gusevagalina_06101974@postgrespro.ru", "phone": "+70563999715"}
0005433634342	1E494A	4793 057174	IVAN SCHERBAKOV	{"phone": "+70798357684"}
0005433634343	007C11	4398 723649	ANDREY SCHERBAKOV	{"phone": "+70386417751"}
0005433634344	4B0452	8314 967838	VLADIMIR GUSEV	{"email": "vladimir.gusev_111978@postgrespro.ru", "phone": "+70295566660"}
0005433634345	73FD55	5625 427526	ILYA MATVEEV	{"email": "matveev_ilya-1975@postgrespro.ru", "phone": "+70659471869"}
0005433634346	13A3E6	2010 941913	VADIM STEPANOV	{"email": "vstepanov.28111970@postgrespro.ru", "phone": "+70114188737"}
0005433634347	13A3E6	5784 744882	OLGA FEDOROVA	{"phone": "+70185239280"}
0005433634348	13A3E6	8477 970577	LIDIYA KUZMINA	{"phone": "+70321380838"}
0005433634349	9393B0	9315 623207	IRINA DANILOVA	{"email": "danilovai.011981@postgrespro.ru", "phone": "+70746364717"}
0005433634350	9393B0	9496 354303	ALEKSANDR SMIRNOV	{"email": "smirnov_a-1968@postgrespro.ru", "phone": "+70927538528"}
0005433634351	01CF22	0739 974863	NIKOLAY DENISOV	{"phone": "+70043824775"}
0005433634352	DD311F	2467 582126	NADEZHDA ALEKSANDROVA	{"phone": "+70909937358"}
0005433634353	FB77C7	7141 503107	TATYANA ZHUKOVA	{"email": "zhukova.t-041965@postgrespro.ru", "phone": "+70716015529"}
0005433634354	FB77C7	8144 220734	VLADIMIR DAVYDOV	{"email": "vladimirdavydov_081966@postgrespro.ru", "phone": "+70951124566"}
0005433634355	7B4E13	5547 970333	VLADIMIR SCHERBAKOV	{"email": "vscherbakov-041979@postgrespro.ru", "phone": "+70545104605"}
0005433634356	A59766	4219 790347	ALEKSEY GERASIMOV	{"phone": "+70775318861"}
0005433634357	F2C828	8537 002515	LYUBOV YAKOVLEVA	{"email": "yakovleva_lyubov.1973@postgrespro.ru", "phone": "+70058893578"}
0005433634358	F2C828	7072 497595	NIKOLAY MELNIKOV	{"phone": "+70830051946"}
0005433634359	52D001	4507 658574	MARINA ARKHIPOVA	{"email": "arkhipova_m.031972@postgrespro.ru", "phone": "+70592197209"}
0005433634360	B9B659	1465 743395	LYUBOV MARTYNOVA	{"email": "lyubov.martynova1967@postgrespro.ru", "phone": "+70784092469"}
0005433634361	B9B659	7775 860347	ROZA SIDOROVA	{"email": "sidorova_r_1962@postgrespro.ru", "phone": "+70406480432"}
0005433634362	CC57D7	7317 726118	ROZALIYA AFANASEVA	{"phone": "+70577965357"}
0005433634363	5442E7	8847 547059	ELENA SERGEEVA	{"email": "sergeevaelena_111982@postgrespro.ru", "phone": "+70196779706"}
0005433634364	2C7201	3703 695328	ALEKSEY DMITRIEV	{"phone": "+70304515259"}
0005433634365	4ABCAD	3390 918304	NADEZHDA TROFIMOVA	{"email": "trofimova-n_061969@postgrespro.ru", "phone": "+70792273533"}
0005433634366	5B65CB	2906 514902	MIKHAIL ROMANOV	{"email": "mikhail_romanov-1967@postgrespro.ru", "phone": "+70110865487"}
0005433634367	5B65CB	1778 336462	LYUBOV ALEKSANDROVA	{"phone": "+70237036708"}
0005433634368	0165D7	5319 447934	ALEKSANDR FROLOV	{"phone": "+70905787693"}
0005433634369	0165D7	3496 544705	EKATERINA NAUMOVA	{"phone": "+70965847311"}
0005433634370	16196E	5431 234765	SALAVAT GAVRILOV	{"email": "salavat-gavrilov_1959@postgrespro.ru", "phone": "+70117165016"}
0005433634371	A2A602	6952 066515	GENNADIY SAVELEV	{"phone": "+70922974007"}
0005433634372	A2A602	2981 133546	VITALIY GRIGOREV	{"phone": "+70355411986"}
0005433634373	BD019A	3536 773475	SOFYA DAVYDOVA	{"email": "sofya_davydova01121976@postgrespro.ru", "phone": "+70575914659"}
0005433634374	BD019A	6767 009371	NIKOLAY KONOVALOV	{"phone": "+70209426716"}
0005433634375	778C8B	8390 228709	ALEKSANDRA SMIRNOVA	{"email": "smirnova-aleksandra-04041965@postgrespro.ru", "phone": "+70745442079"}
0005433634376	778C8B	5005 067442	ALEKSANDR VASILEV	{"email": "a_vasilev-1966@postgrespro.ru", "phone": "+70808886189"}
0005433634377	778C8B	1405 438700	ALEKSANDR MIKHAYLOV	{"phone": "+70597096144"}
0005433634378	1C4E70	4102 679809	SERGEY BELOV	{"phone": "+70844728653"}
0005433634379	788DA9	2377 739616	YULIYA NOVIKOVA	{"email": "yuliya.novikova_23101975@postgrespro.ru", "phone": "+70094868255"}
0005433634380	9FFF3B	7030 469218	ANDREY NOVIKOV	{"phone": "+70490827253"}
0005433634381	19F2EC	2585 794883	ALEKSEY MAKAROV	{"phone": "+70170425566"}
0005433634382	28D9D2	7571 653530	ALEKSEY MIKHAYLOV	{"email": "mikhaylov-a.28051967@postgrespro.ru", "phone": "+70466104189"}
0005433634383	28D9D2	9325 921673	LYUDMILA SOLOVEVA	{"phone": "+70055511444"}
0005433634384	0E764B	4462 232262	EVGENIY IVANOV	{"phone": "+70621467267"}
0005433634385	D1F8FC	4106 963146	MARIYA GRISHINA	{"phone": "+70148956720"}
0005433634386	D1F8FC	1080 528571	ANNA KUDRYASHOVA	{"email": "kudryashova.anna-1976@postgrespro.ru", "phone": "+70342444665"}
0005433634387	29D6F5	1276 037213	LYUBOV SMIRNOVA	{"phone": "+70773243297"}
0005433634388	298AF1	3422 599403	ALEKSEY SHEVCHENKO	{"email": "shevchenko-a.071962@postgrespro.ru", "phone": "+70176708148"}
0005433634389	057526	6460 314624	VIKTOR KUDRYASHOV	{"phone": "+70009694155"}
0005433634390	73C873	3051 355040	VIKTOR ZHURAVLEV	{"email": "vzhuravlev_1974@postgrespro.ru", "phone": "+70558086433"}
0005433634391	78B2D3	4889 294153	YURIY SIDOROV	{"email": "yuriy.sidorov.08011975@postgrespro.ru", "phone": "+70644881530"}
0005433634392	9871C2	9174 701935	MARINA GUSEVA	{"phone": "+70527707039"}
0005433634393	F2192B	8923 320294	EGOR PETROV	{"email": "petrov-e-051964@postgrespro.ru", "phone": "+70676707589"}
0005433634394	8BD0FA	2329 167711	OLEG SAVELEV	{"email": "savelev-o.101981@postgrespro.ru", "phone": "+70153539250"}
0005433634395	8BD0FA	3748 242325	OLGA BORISOVA	{"email": "borisova_olga.14061980@postgrespro.ru", "phone": "+70355049396"}
0005433634396	09E760	3008 707702	ALMIRA KUZNECOVA	{"phone": "+70471585743"}
0005433634397	9807A4	2250 772660	NINA VASILEVA	{"email": "vasileva-nina.1986@postgrespro.ru", "phone": "+70261592173"}
0005433634398	DA6D91	4274 611211	OLGA KUZNECOVA	{"email": "olgakuznecova061971@postgrespro.ru", "phone": "+70457878808"}
0005433634399	DA6D91	9301 567089	TATYANA DMITRIEVA	{"email": "dmitrieva-t_21031972@postgrespro.ru", "phone": "+70964843926"}
0005433634400	D3FC55	2433 407861	ANATOLIY ZHUKOV	{"phone": "+70474929385"}
0005433634401	34CBFB	9623 179257	NAILYA FROLOVA	{"phone": "+70988359827"}
0005433634402	E5B8B5	6742 591910	LYUBOV KUZMINA	{"email": "l-kuzmina.041968@postgrespro.ru", "phone": "+70814069375"}
0005433634403	E5B8B5	9212 904563	NIKOLAY PETROV	{"email": "petrov-n.21021977@postgrespro.ru", "phone": "+70177193923"}
0005433634404	696362	2226 189188	VLADIMIR FROLOV	{"phone": "+70054195747"}
0005433634405	2F182F	0964 668504	ALIYA POPOVA	{"email": "aliya_popova_13091979@postgrespro.ru", "phone": "+70851487834"}
0005433634406	2F182F	8923 639878	ELENA NAUMOVA	{"email": "e-naumova08011978@postgrespro.ru", "phone": "+70005591675"}
0005433634407	4F74A0	7712 299868	VALENTINA ANISIMOVA	{"email": "anisimova.valentina-28101979@postgrespro.ru", "phone": "+70488330653"}
0005433634408	452F23	4638 225765	LYUDMILA PETROVA	{"email": "petrova_lyudmila_031972@postgrespro.ru", "phone": "+70335554959"}
0005433634409	DBFFD4	4736 062835	SVETLANA BOGDANOVA	{"email": "bogdanova.svetlana-101967@postgrespro.ru", "phone": "+70254763604"}
0005433634410	3E664C	1221 411570	VALERIY PETROV	{"email": "petrovvaleriy-23041976@postgrespro.ru", "phone": "+70218302062"}
0005433634411	78CE7C	7933 156429	ALEKSANDR KULIKOV	{"phone": "+70681551559"}
0005433634412	D570F8	4029 755917	MAKSIM VASILEV	{"email": "maksim-vasilev1965@postgrespro.ru", "phone": "+70098201913"}
0005433634413	B6DDB8	7028 183009	ALEKSEY ORLOV	{"email": "aleksey_orlov-1975@postgrespro.ru", "phone": "+70671856981"}
0005433634414	A27380	2891 068078	MARINA BELOVA	{"email": "belova-m_1966@postgrespro.ru", "phone": "+70887288826"}
0005433634415	2C7B7C	3445 220876	ELENA AFANASEVA	{"phone": "+70359899542"}
0005433634416	2C7B7C	0548 657309	SERGEY ANDREEV	{"email": "s.andreev21121975@postgrespro.ru", "phone": "+70129220384"}
0005433634417	B203CF	4142 522691	ALEKSANDR EGOROV	{"email": "aleksandr.egorov091975@postgrespro.ru", "phone": "+70356858088"}
0005433634418	CC0B04	0240 125497	EKATERINA ANISIMOVA	{"email": "anisimova_e-1968@postgrespro.ru", "phone": "+70076210908"}
0005433634419	188F57	3070 189302	PAVEL FEDOROV	{"phone": "+70776356275"}
0005433634420	188F57	5471 409513	DARYA OSIPOVA	{"email": "dosipova1964@postgrespro.ru", "phone": "+70783549085"}
0005433634421	8C78AE	0607 265829	LYUDMILA VLASOVA	{"phone": "+70631827615"}
0005433634422	B003E2	5949 160713	KSENIYA FILIPPOVA	{"email": "k-filippova.09021971@postgrespro.ru", "phone": "+70861898079"}
0005433634423	B003E2	1761 304489	YULIYA VASILEVA	{"email": "vasileva.y_1979@postgrespro.ru", "phone": "+70952889620"}
0005433634424	B003E2	1406 679894	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.21011976@postgrespro.ru", "phone": "+70087809590"}
0005433634425	B003E2	2296 710696	VYACHESLAV KUZNECOV	{"phone": "+70532553160"}
0005433634426	A6428A	4677 319688	OLESYA ROMANOVA	{"email": "o.romanova-1980@postgrespro.ru", "phone": "+70696364785"}
0005433634427	A6428A	0811 867226	ANTON ZAYCEV	{"phone": "+70204110707"}
0005433634428	FDE95D	4451 980082	ANNA ABRAMOVA	{"email": "abramovaa-1973@postgrespro.ru", "phone": "+70280167099"}
0005433634429	75E84A	3913 091997	ANNA KARPOVA	{"phone": "+70563563757"}
0005433634430	75E84A	4465 943692	ANNA LAZAREVA	{"email": "lazarevaa1967@postgrespro.ru", "phone": "+70834718799"}
0005433634431	C03D1B	5171 066848	ELENA KUZNECOVA	{"email": "kuznecova.e1973@postgrespro.ru", "phone": "+70711232834"}
0005433634432	C03D1B	2021 062202	VYACHESLAV YAKOVLEV	{"phone": "+70832924233"}
0005433634433	FF9CDC	4505 969666	VALENTINA POPOVA	{"email": "popova_v.18111979@postgrespro.ru", "phone": "+70776651166"}
0005433634434	FF9CDC	2851 324545	ANNA MATVEEVA	{"phone": "+70433400093"}
0005433634435	FF9CDC	4912 259745	ALEKSANDR AFANASEV	{"phone": "+70233366992"}
0005433634436	AD920B	6892 972927	SERGEY NAUMOV	{"phone": "+70292686426"}
0005433634437	799820	0230 303659	SERGEY KUZMIN	{"phone": "+70012470430"}
0005433634438	F6247D	2606 441192	ANDREY KUZNECOV	{"email": "andrey_kuznecov.1967@postgrespro.ru", "phone": "+70948261688"}
0005433634439	02C595	4933 893647	SERGEY ILIN	{"phone": "+70182599792"}
0005433634440	02C595	4531 152462	ELENA PAVLOVA	{"phone": "+70226206234"}
0005433634441	CA722B	8008 601030	LYUBOV MOROZOVA	{"email": "morozovalyubov_041974@postgrespro.ru", "phone": "+70874905648"}
0005433634442	CA722B	3450 803546	VLADIMIR SHEVCHENKO	{"email": "vladimirshevchenko_1969@postgrespro.ru", "phone": "+70581004464"}
0005433634443	7F04B6	6671 419189	MARINA MALYSHEVA	{"email": "malysheva_marina_20091965@postgrespro.ru", "phone": "+70791393744"}
0005433634444	3FB5C5	1150 449659	ELENA MATVEEVA	{"phone": "+70452265039"}
0005433634445	9A867C	4386 333529	MARINA RODIONOVA	{"phone": "+70029292541"}
0005433634446	9A867C	4148 465204	ELIZAVETA DENISOVA	{"phone": "+70694380089"}
0005433634447	34C636	3091 636319	LYUBOV FADEEVA	{"email": "fadeeva.l_1965@postgrespro.ru", "phone": "+70528076410"}
0005433634448	34C636	3243 719172	FATIMA LAZAREVA	{"phone": "+70315066894"}
0005433634449	D2B7BE	0838 812515	TAMARA MAKAROVA	{"phone": "+70602775939"}
0005433634450	1BD815	7535 010899	NINA IVANOVA	{"email": "nina.ivanova.101972@postgrespro.ru", "phone": "+70692172050"}
0005433634451	5C0D24	5917 244264	VLADIMIR KRASNOV	{"phone": "+70368779746"}
0005433634453	061C67	1320 783971	ARTEM AFANASEV	{"email": "afanasev_artem.12011963@postgrespro.ru", "phone": "+70201512884"}
0005433634454	061C67	2350 279963	ANDREY POPOV	{"email": "a.popov.16071984@postgrespro.ru", "phone": "+70984626562"}
0005433634455	6CDE3E	5630 004971	TAMARA MOISEEVA	{"email": "t.moiseeva1969@postgrespro.ru", "phone": "+70135377194"}
0005433634456	6CDE3E	3982 312897	VERA STEPANOVA	{"email": "v.stepanova_24111978@postgrespro.ru", "phone": "+70402502421"}
0005433634457	7F5837	2965 157904	TATYANA VLASOVA	{"phone": "+70925149134"}
0005433634458	3FDCF9	5131 008164	ARTUR AFANASEV	{"phone": "+70331948034"}
0005433634459	608417	4897 402368	ALEKSANDR SOROKIN	{"phone": "+70735562070"}
0005433634460	F4E44C	6148 096751	ALEKSANDR RODIONOV	{"email": "a.rodionov-1968@postgrespro.ru", "phone": "+70809107994"}
0005433634461	227E9A	8637 158353	ELENA KUZNECOVA	{"email": "e.kuznecova.03111978@postgrespro.ru", "phone": "+70658043948"}
0005433634462	0F9BA0	1809 214249	EVGENIYA FADEEVA	{"email": "fadeeva-evgeniya10111975@postgrespro.ru", "phone": "+70148002903"}
0005433634463	0F9BA0	2876 380907	ROMAN CHERNOV	{"email": "rchernov071979@postgrespro.ru", "phone": "+70518344060"}
0005433634464	7360F8	4836 625516	TATYANA ZHUKOVA	{"phone": "+70831252001"}
0005433634465	117E9A	4332 710840	VIKTOR GAVRILOV	{"email": "gavrilovviktor03121975@postgrespro.ru", "phone": "+70220765221"}
0005433634466	117E9A	9141 457942	MAKSIM EGOROV	{"phone": "+70422117706"}
0005433634467	013514	2342 248767	IRINA POPOVA	{"phone": "+70618269898"}
0005433634468	354587	1856 991419	ELENA MARTYNOVA	{"email": "e.martynova.081971@postgrespro.ru", "phone": "+70011876732"}
0005433634469	694A16	7623 767602	ROZA OSIPOVA	{"phone": "+70482374356"}
0005433634470	C646DF	1064 501529	ALEKSANDR FROLOV	{"phone": "+70073982417"}
0005433634471	C646DF	2766 303331	YURIY SOROKIN	{"phone": "+70954862033"}
0005433634472	C646DF	7342 325114	VALENTINA ANTONOVA	{"phone": "+70562118189"}
0005433634473	C646DF	3118 097348	YULIYA POPOVA	{"phone": "+70994488841"}
0005433634474	48A525	3564 255295	ALINA VASILEVA	{"email": "a-vasileva-12091958@postgrespro.ru", "phone": "+70970901885"}
0005433634475	F5494C	4106 927986	YAROSLAV OSIPOV	{"email": "y.osipov-021968@postgrespro.ru", "phone": "+70567066164"}
0005433634476	C65272	4926 633841	TATYANA KULIKOVA	{"phone": "+70279238976"}
0005433634477	61206B	3606 830408	IRINA KOZLOVA	{"email": "irina-kozlova-20011971@postgrespro.ru", "phone": "+70120768687"}
0005433634478	61206B	9083 779319	ALEKSEY FROLOV	{"email": "afrolov.101986@postgrespro.ru", "phone": "+70851167547"}
0005433634479	61206B	9375 147911	VASILIY MAKAROV	{"phone": "+70783982911"}
0005433634480	8D700A	8678 480085	OKSANA MIKHAYLOVA	{"phone": "+70566847247"}
0005433634481	5195DA	0733 620833	ANATOLIY BONDARENKO	{"email": "bondarenko.a_04121972@postgrespro.ru", "phone": "+70129493345"}
0005433634482	AA99CD	2270 877000	EVGENIY EGOROV	{"phone": "+70749716780"}
0005433634483	71CFAE	2625 807918	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov.101981@postgrespro.ru", "phone": "+70292377320"}
0005433634484	831A7B	8102 018879	ELENA KOLESNIKOVA	{"email": "elena-kolesnikova.1967@postgrespro.ru", "phone": "+70505080026"}
0005433634485	3A2076	1612 914812	VASILIY GRIGOREV	{"phone": "+70326504778"}
0005433634486	4693ED	4721 391282	MARGARITA KUZNECOVA	{"email": "kuznecovam.081986@postgrespro.ru", "phone": "+70586151673"}
0005433634487	118B2D	3361 632836	RUSLAN POPOV	{"email": "rpopov.1958@postgrespro.ru", "phone": "+70951243348"}
0005433634488	CD9850	1641 369887	ANDREY NOVIKOV	{"email": "andrey-novikov-111972@postgrespro.ru", "phone": "+70891435495"}
0005433634489	CD9850	4601 489923	OLGA FOMINA	{"phone": "+70158230796"}
0005433634490	2C7FDA	2203 211171	ELENA VOLKOVA	{"phone": "+70270546039"}
0005433634491	2C7FDA	3754 822438	ALEKSANDR CHERNOV	{"phone": "+70297316139"}
0005433634492	D9194E	7067 314364	EKATERINA LEBEDEVA	{"email": "lebedeva.e09081976@postgrespro.ru", "phone": "+70859413629"}
0005433634493	096F4F	4638 800191	YULIYA BELOVA	{"phone": "+70321368418"}
0005433634494	096F4F	0641 459530	VALERIYA TROFIMOVA	{"phone": "+70422643481"}
0005433634495	7EF853	3560 190317	ALEKSANDR FROLOV	{"email": "frolov-a_1962@postgrespro.ru", "phone": "+70487487919"}
0005433634496	7EF853	8672 149501	NAILYA ROMANOVA	{"email": "n.romanova-061969@postgrespro.ru", "phone": "+70892404011"}
0005433634497	817ACA	9499 339595	ZHANNA BARANOVA	{"email": "baranova-zhanna.05021977@postgrespro.ru", "phone": "+70985420683"}
0005433634498	585BCD	1564 717278	NINA POPOVA	{"email": "popova_nina.1987@postgrespro.ru", "phone": "+70853643362"}
0005433634499	585BCD	1068 882308	YURIY SERGEEV	{"phone": "+70934553870"}
0005433634500	9D9F58	2829 917466	ANNA TIKHONOVA	{"phone": "+70755282553"}
0005433634501	9D9F58	0104 588194	ELENA VASILEVA	{"phone": "+70079635540"}
0005433634502	9D9F58	1341 806488	DANILA GAVRILOV	{"email": "danilagavrilov1959@postgrespro.ru", "phone": "+70011907431"}
0005433634503	E26632	3153 376005	VALENTINA MAKSIMOVA	{"phone": "+70502272661"}
0005433634504	521AC4	9894 457028	MAKSIM POPOV	{"phone": "+70209193137"}
0005433634505	7C63CA	8403 465375	LEV SEMENOV	{"phone": "+70510933730"}
0005433634506	701BB1	9511 882327	ANZHELA STEPANOVA	{"email": "anzhelastepanova101964@postgrespro.ru", "phone": "+70493357265"}
0005433634507	E9E6EB	9376 928768	YURIY POPOV	{"phone": "+70163219294"}
0005433634508	67A64D	9484 715795	ALEKSANDR POPOV	{"email": "popova.081973@postgrespro.ru", "phone": "+70040368484"}
0005433634509	E833BA	2909 281455	TATYANA NIKOLAEVA	{"phone": "+70379376608"}
0005433634510	20D174	3495 489895	NINA RODIONOVA	{"email": "nina.rodionova.16051977@postgrespro.ru", "phone": "+70807516388"}
0005433634511	A7D08C	9306 112712	NIKOLAY IVANOV	{"email": "ivanovnikolay10051976@postgrespro.ru", "phone": "+70898561353"}
0005433634512	71C2E1	8518 592581	ALEKSANDR RODIONOV	{"email": "aleksandr.rodionov08021962@postgrespro.ru", "phone": "+70247165363"}
0005433634513	34C135	9734 482247	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko1962@postgrespro.ru", "phone": "+70558029537"}
0005433634514	34C135	0102 299375	ANTONIDA KAZAKOVA	{"phone": "+70098692014"}
0005433634515	792248	9336 196987	ALEKSANDR FEDOTOV	{"email": "a.fedotov_11031963@postgrespro.ru", "phone": "+70074769149"}
0005433634516	6A895B	9410 834498	SANIYA POPOVA	{"email": "popova_saniya05091971@postgrespro.ru", "phone": "+70414035524"}
0005433634517	475BDF	0920 136540	SERGEY PETROV	{"email": "petrov-sergey.1973@postgrespro.ru", "phone": "+70107971648"}
0005433634518	475BDF	2375 258142	EKATERINA EGOROVA	{"phone": "+70319053138"}
0005433634519	F42706	0836 923241	EVGENIY ABRAMOV	{"email": "e.abramov07051976@postgrespro.ru", "phone": "+70293650294"}
0005433634520	39097E	4545 170894	YURIY KISELEV	{"phone": "+70913858718"}
0005433634521	DB76EB	5912 925682	ALEKSEY SOROKIN	{"email": "sorokin.a111959@postgrespro.ru", "phone": "+70000834904"}
0005433634522	9E64C4	9332 737652	NIKOLAY NOVIKOV	{"email": "nnovikov.21051986@postgrespro.ru", "phone": "+70146347659"}
0005433634523	9E64C4	2652 907267	ANDREY FILIPPOV	{"phone": "+70591593170"}
0005433634524	2EC639	7848 894574	LYUBOV LUKYANOVA	{"email": "llukyanova1960@postgrespro.ru", "phone": "+70342867791"}
0005433634525	6322D0	0001 887996	DMITRIY BORISOV	{"phone": "+70376987131"}
0005433634526	11228D	6354 525531	MARIYA GUSEVA	{"email": "gusevam101967@postgrespro.ru", "phone": "+70158272815"}
0005433634527	F0851E	5529 153248	STEPAN SIDOROV	{"email": "sidorov-stepan-1972@postgrespro.ru", "phone": "+70578730769"}
0005433634528	5C9D22	9881 926735	ALEKSANDR KOROLEV	{"email": "korolev-a.091973@postgrespro.ru", "phone": "+70290583099"}
0005433634529	845AD9	4424 318246	NATALYA CHERNOVA	{"email": "chernovanatalya-1972@postgrespro.ru", "phone": "+70763806151"}
0005433634530	384A02	6015 454864	YULIYA DENISOVA	{"email": "denisova.y_1974@postgrespro.ru", "phone": "+70466727806"}
0005433634531	384A02	0479 765554	SERGEY BORISOV	{"email": "sborisov.071977@postgrespro.ru", "phone": "+70325842763"}
0005433634532	576F97	1801 667976	VIKTOR SOROKIN	{"email": "sorokin-viktor-1968@postgrespro.ru", "phone": "+70069594595"}
0005433634533	89E5F0	0571 064682	VASILISA OSIPOVA	{"phone": "+70013488975"}
0005433634534	89E5F0	0757 924891	SVETLANA ZAYCEVA	{"email": "zayceva-s111970@postgrespro.ru", "phone": "+70412397152"}
0005433634535	F77393	1521 750771	VLADIMIR ORLOV	{"phone": "+70681278825"}
0005433634536	FB53EA	1063 032253	EKATERINA ROMANOVA	{"phone": "+70790910927"}
0005433634537	FB53EA	9893 459892	IRINA KONDRATEVA	{"phone": "+70141327362"}
0005433634538	B1CEEB	5660 035119	ALEKSEY PAVLOV	{"email": "pavlova17021965@postgrespro.ru", "phone": "+70798586729"}
0005433634539	41219C	5901 947004	VASILIY KUZNECOV	{"email": "v_kuznecov-1978@postgrespro.ru", "phone": "+70925868497"}
0005433634540	64FECF	1016 083542	ALINA MALYSHEVA	{"email": "alina.malysheva.1975@postgrespro.ru", "phone": "+70116973762"}
0005433634541	64FECF	9135 396624	SERGEY ILIN	{"phone": "+70807869094"}
0005433634542	E06101	0020 472608	SERGEY ANDREEV	{"email": "sergey_andreev_11101970@postgrespro.ru", "phone": "+70211431190"}
0005433634543	E06101	5516 230777	TATYANA ANTONOVA	{"email": "tatyana-antonova_021970@postgrespro.ru", "phone": "+70360166639"}
0005433634544	920D7D	7595 676969	TAMARA VLASOVA	{"email": "tamara-vlasova041963@postgrespro.ru", "phone": "+70402837524"}
0005433634545	923B9F	8393 120892	ANASTASIYA ALEKSEEVA	{"phone": "+70249563609"}
0005433634546	923B9F	1455 539530	ELVIRA VASILEVA	{"phone": "+70253183762"}
0005433634547	C44851	6587 327904	NATALYA MIKHAYLOVA	{"email": "nmikhaylova_041971@postgrespro.ru", "phone": "+70043040543"}
0005433634548	8D1CD9	5395 887984	ANATOLIY GRIGOREV	{"phone": "+70700318019"}
0005433634549	7C779E	9791 527955	LYUDMILA NIKITINA	{"email": "lyudmilanikitina-1980@postgrespro.ru", "phone": "+70139783002"}
0005433634550	9A9C1F	0523 173412	ELENA BORISOVA	{"email": "eborisova04061976@postgrespro.ru", "phone": "+70254578704"}
0005433634551	9A9C1F	7515 565434	ANATOLIY KOZLOV	{"phone": "+70585247367"}
0005433634552	5EED43	6578 986844	ANDREY MELNIKOV	{"phone": "+70528488332"}
0005433634553	5EED43	2925 952013	ANASTASIYA KAZAKOVA	{"email": "kazakova-a_30111971@postgrespro.ru", "phone": "+70056913740"}
0005433634554	936B89	3046 537010	DENIS BONDARENKO	{"phone": "+70907729489"}
0005433634555	0EF0BA	2952 127661	NADEZHDA RYABOVA	{"phone": "+70937913123"}
0005433634556	5A794A	0744 141563	FANIL VLASOV	{"email": "fanilvlasov_061969@postgrespro.ru", "phone": "+70400608447"}
0005433634557	5A794A	7772 231500	ALEKSANDR MOROZOV	{"phone": "+70037715366"}
0005433634558	793524	4775 090470	VADIM MAKSIMOV	{"email": "v_maksimov28011979@postgrespro.ru", "phone": "+70198365750"}
0005433634559	793524	5326 887164	EKATERINA KOROLEVA	{"email": "koroleva.ekaterina.17011967@postgrespro.ru", "phone": "+70201915965"}
0005433634560	86609B	8141 088138	NATALIYA IVANOVA	{"email": "n-ivanova_22041967@postgrespro.ru", "phone": "+70613583028"}
0005433634561	C40128	1711 378787	OLGA IVANOVA	{"email": "olga_ivanova.22051974@postgrespro.ru", "phone": "+70840709871"}
0005433634562	49EC34	0003 285480	LYUBOV MIKHAYLOVA	{"email": "mikhaylova-lyubov.28081967@postgrespro.ru", "phone": "+70479610368"}
0005433634563	49EC34	9151 122811	DMITRIY VASILEV	{"email": "vasilevdmitriy-27101957@postgrespro.ru", "phone": "+70954759671"}
0005433634564	D157FF	3694 145998	ELENA FADEEVA	{"email": "fadeeva.e_03041965@postgrespro.ru", "phone": "+70099225937"}
0005433634565	DEE7B4	8479 001279	ANDREY VOLKOV	{"phone": "+70144988351"}
0005433634566	DEE7B4	2095 046187	KLAVDIYA SOKOLOVA	{"phone": "+70914083581"}
0005433634567	330813	1866 389887	IRINA VLASOVA	{"phone": "+70629714145"}
0005433634568	5A0792	2118 119442	ALEKSANDR VOLKOV	{"phone": "+70270444707"}
0005433634569	5A0792	9851 330171	ALEKSEY ROMANOV	{"email": "a-romanov.02041979@postgrespro.ru", "phone": "+70126194735"}
0005433634570	B723AA	7132 577248	TAMARA ZAYCEVA	{"email": "tzayceva-041959@postgrespro.ru", "phone": "+70035117613"}
0005433634571	B723AA	5507 978918	ALEFTINA POPOVA	{"phone": "+70991442300"}
0005433634572	B723AA	0577 642640	RUMIYA VASILEVA	{"email": "vasileva-rumiya-06031964@postgrespro.ru", "phone": "+70381227650"}
0005433634573	8616D8	6414 484637	NATALYA KAZAKOVA	{"phone": "+70062827124"}
0005433634574	96DC39	7520 023034	LILIYA FILIPPOVA	{"phone": "+70923399398"}
0005433634575	E25E29	7238 813827	IRINA RYABOVA	{"phone": "+70893151755"}
0005433634576	0F4123	6264 514263	SERGEY SHEVCHENKO	{"email": "sshevchenko1972@postgrespro.ru", "phone": "+70205119132"}
0005433634577	0F4123	0946 109723	MARIYA KISELEVA	{"phone": "+70299187409"}
0005433634578	A7FD8C	3853 422213	POLINA NESTEROVA	{"email": "nesterovap-26101971@postgrespro.ru", "phone": "+70912851789"}
0005433634579	3095A1	4263 358351	VLADISLAV ZAKHAROV	{"email": "zakharov_v.16061977@postgrespro.ru", "phone": "+70985774134"}
0005433634580	3095A1	3062 862449	IVAN PETROV	{"email": "petrov-i-091975@postgrespro.ru", "phone": "+70957978709"}
0005433634581	3095A1	5453 599371	TATYANA IVANOVA	{"email": "ivanovatatyana-05121959@postgrespro.ru", "phone": "+70179705620"}
0005433634582	652934	8473 042181	ALEKSANDR MOISEEV	{"email": "aleksandr-moiseev.081981@postgrespro.ru", "phone": "+70739206636"}
0005433634583	0DDAF8	3762 688323	NINA TIKHONOVA	{"phone": "+70146428638"}
0005433634584	0DDAF8	1455 916899	EKATERINA TARASOVA	{"email": "tarasova_ekaterina-04111975@postgrespro.ru", "phone": "+70067912799"}
0005433634585	A3B3AB	1163 108895	VADIM KUZMIN	{"phone": "+70932464657"}
0005433634586	A3B3AB	0471 788060	ELENA KUZNECOVA	{"email": "kuznecovae_08011966@postgrespro.ru", "phone": "+70606033866"}
0005433634587	99B72D	5259 668152	MARINA KUZNECOVA	{"phone": "+70117895563"}
0005433634588	B1BFD4	7562 902969	SERGEY MAKAROV	{"email": "sergey_makarov-081978@postgrespro.ru", "phone": "+70962383846"}
0005433634589	B1BFD4	2993 042713	DARYA IVANOVA	{"phone": "+70106734863"}
0005433634590	3519F1	0475 982225	SEMEN ISAEV	{"email": "isaev.semen_051978@postgrespro.ru", "phone": "+70127723922"}
0005433634591	476387	4850 854638	STANISLAV GRIGOREV	{"phone": "+70873017424"}
0005433634592	141A0D	2482 805261	TATYANA SOLOVEVA	{"email": "solovevatatyana1965@postgrespro.ru", "phone": "+70014093280"}
0005433634593	141A0D	6293 296383	DMITRIY PETROV	{"phone": "+70742048033"}
0005433634594	05AB40	1849 454853	MAKSIM TIMOFEEV	{"phone": "+70005074065"}
0005433634595	05AB40	2066 580607	NIKOLAY GUSEV	{"email": "gusev.n.1972@postgrespro.ru", "phone": "+70330926476"}
0005433634596	05AB40	9894 280237	NATALYA NIKOLAEVA	{"phone": "+70676757490"}
0005433634597	F613B7	3093 490542	ALEKSANDR FROLOV	{"email": "afrolov-13051963@postgrespro.ru", "phone": "+70218558781"}
0005433634598	F613B7	2603 913930	VIKTOR NAZAROV	{"email": "vnazarov.04071972@postgrespro.ru", "phone": "+70108886558"}
0005433634599	634721	3377 071865	ELENA DAVYDOVA	{"email": "davydova-elena.1988@postgrespro.ru", "phone": "+70760900307"}
0005433634600	44E74B	0348 406819	NIKOLAY SHEVCHENKO	{"phone": "+70147780230"}
0005433634601	9E45EC	7961 648563	MIKHAIL KRASNOV	{"phone": "+70515862032"}
0005433634602	E7C529	9568 411134	DMITRIY CHERNOV	{"phone": "+70131468515"}
0005433634603	2A77B5	9596 270682	TAISIYA NESTEROVA	{"email": "nesterova-taisiya-20041980@postgrespro.ru", "phone": "+70232340872"}
0005433634604	A4F1C7	8258 926608	DANILA ANTONOV	{"email": "d_antonov_041960@postgrespro.ru", "phone": "+70373615165"}
0005433634605	804B27	7683 045705	ALEKSANDR BONDARENKO	{"phone": "+70176176453"}
0005433634606	F3A07E	6552 333770	VLADIMIR GUSEV	{"phone": "+70971962348"}
0005433634607	8E25A9	0112 251719	GALINA KRASNOVA	{"email": "krasnovag-1967@postgrespro.ru", "phone": "+70591129934"}
0005433634608	2F78A1	1665 078969	VADIM EGOROV	{"phone": "+70191458991"}
0005433634609	2F78A1	6960 476701	ZOYA VOROBEVA	{"phone": "+70146850737"}
0005433634610	EA72BB	3194 774020	KRISTINA AFANASEVA	{"phone": "+70528193746"}
0005433634611	F10446	4129 110709	ELENA ZHUKOVA	{"email": "zhukova_elena_1965@postgrespro.ru", "phone": "+70940695127"}
0005433634612	F00E64	1596 113878	TAMARA FADEEVA	{"email": "t-fadeeva091990@postgrespro.ru", "phone": "+70674121004"}
0005433634613	5AF2E0	0435 232569	ALEKSANDR IVANOV	{"email": "ivanovaleksandr_1988@postgrespro.ru", "phone": "+70818638390"}
0005433634614	F39186	3301 223965	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina-1971@postgrespro.ru", "phone": "+70668921878"}
0005433634615	384993	9936 127742	DARYA ANDREEVA	{"email": "dandreeva05101967@postgrespro.ru", "phone": "+70152934087"}
0005433634616	384993	8741 944992	OLESYA IVANOVA	{"email": "o_ivanova.1976@postgrespro.ru", "phone": "+70617801772"}
0005433634617	505F65	5420 736684	ALISHER ANTONOV	{"email": "alisher-antonov-1973@postgrespro.ru", "phone": "+70250023391"}
0005433634618	505F65	0177 362695	ANATOLIY KARPOV	{"email": "anatoliykarpov_09021972@postgrespro.ru", "phone": "+70352776451"}
0005433634619	1F9F31	5000 154144	GALINA ANTONOVA	{"phone": "+70618779469"}
0005433634620	694968	8745 274401	OKSANA KAZAKOVA	{"email": "kazakovao01121979@postgrespro.ru", "phone": "+70696623072"}
0005433634621	A6DE01	1286 128407	ELENA ANTONOVA	{"email": "antonovaelena31011974@postgrespro.ru", "phone": "+70630948226"}
0005433634622	A6DE01	4567 453125	DMITRIY SOROKIN	{"phone": "+70826661791"}
0005433634623	867B75	3063 216739	IGOR OSIPOV	{"phone": "+70714640273"}
0005433634624	7A617D	9732 548846	MARGARITA KOROLEVA	{"phone": "+70859690857"}
0005433634625	5DF8EB	7535 788492	VALERIY BARANOV	{"phone": "+70331889096"}
0005433634626	F79C21	9967 806386	IRINA BELOVA	{"phone": "+70503596717"}
0005433634627	25B451	2846 247026	IGOR KULIKOV	{"phone": "+70271662517"}
0005433634628	393541	6276 042961	VERA MAKSIMOVA	{"email": "maksimova-vera.111967@postgrespro.ru", "phone": "+70286259829"}
0005433634629	393541	8744 308859	PETR BORISOV	{"email": "borisovpetr-06071973@postgrespro.ru", "phone": "+70382458310"}
0005433634630	873C83	8670 966057	NIKOLAY VOROBEV	{"email": "nikolay.vorobev-031967@postgrespro.ru", "phone": "+70339333115"}
0005433634631	852FB0	7398 024665	LILIYA KRASNOVA	{"email": "liliya.krasnova_021965@postgrespro.ru", "phone": "+70469981693"}
0005433634632	734F99	3563 746736	SERGEY TARASOV	{"phone": "+70777177743"}
0005433634633	734F99	7688 237474	ALEKSANDR STEPANOV	{"email": "stepanov-a-21051976@postgrespro.ru", "phone": "+70801880186"}
0005433634634	A07526	0786 894445	GALINA KARPOVA	{"phone": "+70504586754"}
0005433634635	A07526	0313 267432	VLADIMIR VASILEV	{"phone": "+70507013389"}
0005433634636	A07526	2887 188080	MIKHAIL KULIKOV	{"email": "kulikov.mikhail.30111963@postgrespro.ru", "phone": "+70512122676"}
0005433634637	4562A6	6902 901561	LEONID DENISOV	{"email": "l_denisov.101984@postgrespro.ru", "phone": "+70928885088"}
0005433634638	CE2E31	8985 347897	ALEKSANDR KUZMIN	{"email": "kuzmina-1972@postgrespro.ru", "phone": "+70054267912"}
0005433634639	CE2E31	8457 651894	ANTON KUZNECOV	{"phone": "+70960913220"}
0005433634640	55A194	9905 821245	ELENA SMIRNOVA	{"email": "smirnova.e1976@postgrespro.ru", "phone": "+70079719979"}
0005433634641	55A194	3581 664540	NATALIYA MIRONOVA	{"email": "mironova-nataliya31071978@postgrespro.ru", "phone": "+70146295357"}
0005433634642	6B7236	5786 203398	TAMARA SOKOLOVA	{"email": "sokolovatamara_1963@postgrespro.ru", "phone": "+70213522078"}
0005433634643	6B7236	8800 181448	TATYANA SCHERBAKOVA	{"phone": "+70292635929"}
0005433634644	6B7236	6918 301327	GALINA FOMINA	{"email": "galina.fomina-051972@postgrespro.ru", "phone": "+70728341943"}
0005433634645	E2B210	0085 491640	VADIM SCHERBAKOV	{"phone": "+70236279497"}
0005433634646	E2B210	1512 504809	SVETLANA NAZAROVA	{"phone": "+70168129637"}
0005433634647	323C92	9811 152630	RAIL SCHERBAKOV	{"phone": "+70609409072"}
0005433634648	F69EF9	1666 853668	SERGEY ALEKSEEV	{"phone": "+70840687423"}
0005433634649	9B3FE3	6357 613285	ILYA ZAKHAROV	{"email": "zakharov_ilya.1973@postgrespro.ru", "phone": "+70463591052"}
0005433634650	F42A18	1759 661840	DANIIL SEMENOV	{"email": "semenov-d_1967@postgrespro.ru", "phone": "+70872861193"}
0005433634651	66116E	5239 944892	IRINA KOLESNIKOVA	{"phone": "+70301403035"}
0005433634652	66116E	7373 536942	NADEZHDA FILATOVA	{"email": "n.filatova.12061985@postgrespro.ru", "phone": "+70975709736"}
0005433634653	C9C85E	2458 429929	VASILIY GUSEV	{"email": "v_gusev_19011983@postgrespro.ru", "phone": "+70940098227"}
0005433634654	2E3254	3420 662145	ALEKSANDR SEMENOV	{"phone": "+70929085702"}
0005433634655	2E3254	2372 518267	ALEKSANDR VASILEV	{"phone": "+70930551925"}
0005433634656	04AF47	6308 845188	VALENTINA MAKAROVA	{"phone": "+70011687962"}
0005433634657	526EBE	2701 539398	VALERIYA KOROLEVA	{"email": "koroleva_v_22051978@postgrespro.ru", "phone": "+70190398352"}
0005433634658	12A944	4906 236117	ALEKSANDR TIMOFEEV	{"phone": "+70904601366"}
0005433634659	286EEF	5252 916704	MATRENA AKIMOVA	{"phone": "+70493279513"}
0005433634660	37DDF8	2094 051748	NATALIYA SERGEEVA	{"email": "nataliya_sergeeva12061969@postgrespro.ru", "phone": "+70188726764"}
0005433634661	C79FA2	7281 775685	EKATERINA OSIPOVA	{"phone": "+70388604172"}
0005433634662	E3BCB3	2969 127349	LYUBOV NESTEROVA	{"phone": "+70642383272"}
0005433634663	F4D537	1263 674420	NATALIYA KOROLEVA	{"email": "nataliya.koroleva071968@postgrespro.ru", "phone": "+70719027982"}
0005433634664	F4D537	4378 075403	IRINA BOGDANOVA	{"email": "bogdanovai-1978@postgrespro.ru", "phone": "+70875031716"}
0005433634665	5A3E56	9306 649695	VALENTINA ERMAKOVA	{"email": "ermakova-v16031970@postgrespro.ru", "phone": "+70524722230"}
0005433634666	5A3E56	7676 499190	ALEKSANDR ABRAMOV	{"phone": "+70068226105"}
0005433634667	3AD15D	9056 624633	ALEKSEY SOLOVEV	{"email": "a.solovev-27031964@postgrespro.ru", "phone": "+70462035802"}
0005433634668	823D41	2843 519889	VLADIMIR FILIPPOV	{"phone": "+70256674787"}
0005433634669	C10A12	6251 385603	GULIYA PETROVA	{"email": "petrova.g.1965@postgrespro.ru", "phone": "+70346229201"}
0005433634670	C10A12	7203 522395	EGOR KUZNECOV	{"email": "egorkuznecov091968@postgrespro.ru", "phone": "+70187859781"}
0005433634671	E6B67F	0781 629759	VLADIMIR KUZMIN	{"phone": "+70543838022"}
0005433634672	E6B67F	8616 021359	MARIYA BARANOVA	{"phone": "+70226830806"}
0005433634673	627984	5372 189796	EVGENIY ANDREEV	{"phone": "+70629123270"}
0005433634674	21245D	1810 144318	YULIYA SEMENOVA	{"email": "semenova.yuliya.15081977@postgrespro.ru", "phone": "+70069113578"}
0005433634675	C5533E	8460 179366	ALEKSANDR FROLOV	{"email": "frolovaleksandr.1960@postgrespro.ru", "phone": "+70597527291"}
0005433634676	A4C3F2	8459 014686	MARIYA KUZNECOVA	{"email": "mariyakuznecova-1980@postgrespro.ru", "phone": "+70836582208"}
0005433634677	94D408	0588 903582	ANTONINA GERASIMOVA	{"email": "gerasimova_a.021971@postgrespro.ru", "phone": "+70058075065"}
0005433634678	3DE2D8	6770 796982	ALLA STEPANOVA	{"phone": "+70999392379"}
0005433634679	973BB5	7528 260510	ALEKSANDR ALEKSEEV	{"phone": "+70953079477"}
0005433634680	973BB5	1809 343173	LYUDMILA SERGEEVA	{"phone": "+70743419803"}
0005433634681	32A38D	0527 860799	DMITRIY KONOVALOV	{"phone": "+70533026409"}
0005433634682	1A1260	6726 949767	SVETLANA TIKHONOVA	{"email": "stikhonova-22021962@postgrespro.ru", "phone": "+70584564239"}
0005433634683	7D2595	6291 270574	SERGEY KUDRYASHOV	{"phone": "+70014084786"}
0005433634684	065F1E	1804 649421	ALEKSANDRA SOROKINA	{"email": "aleksandra.sorokina051969@postgrespro.ru", "phone": "+70196736672"}
0005433634685	416D42	4414 180116	NATALYA FEDOROVA	{"email": "fedorova_n.13071973@postgrespro.ru", "phone": "+70175673578"}
0005433634686	8934BA	5319 837596	IRINA PAVLOVA	{"email": "irina-pavlova-1971@postgrespro.ru", "phone": "+70658584676"}
0005433634687	8934BA	5834 703714	EVGENIY MARTYNOV	{"phone": "+70267168375"}
0005433634688	CC3217	8598 801722	NADEZHDA LAZAREVA	{"phone": "+70945083970"}
0005433634689	5C3A95	4285 287826	LARISA LEBEDEVA	{"email": "l.lebedeva.081979@postgrespro.ru", "phone": "+70974002950"}
0005433634690	07DB49	4143 788029	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev101965@postgrespro.ru", "phone": "+70446649149"}
0005433634691	FD2B5A	8134 507446	VLADIMIR ANTONOV	{"phone": "+70077603633"}
0005433634692	C2E74C	0154 041751	ALEKSANDR KOZLOV	{"email": "a-kozlov071973@postgrespro.ru", "phone": "+70150244942"}
0005433634693	C2E74C	0899 402654	YULIYA PETROVA	{"email": "petrovayuliya15101975@postgrespro.ru", "phone": "+70531673958"}
0005433634694	C2E74C	9217 927774	VALENTINA PETROVA	{"phone": "+70918893364"}
0005433634695	3C5011	6944 502484	SVETLANA MATVEEVA	{"email": "matveeva.s.041969@postgrespro.ru", "phone": "+70596880560"}
0005433634696	021259	0364 243644	YANA GERASIMOVA	{"email": "gerasimovay.061967@postgrespro.ru", "phone": "+70342241719"}
0005433634697	541515	4949 311407	NIKOLAY MAKAROV	{"email": "makarov.n.29091960@postgrespro.ru", "phone": "+70492628167"}
0005433634698	4D1001	1248 967634	LYUBOV MASLOVA	{"phone": "+70115257125"}
0005433634699	4D1001	8400 786534	YANA LAZAREVA	{"phone": "+70152647262"}
0005433634700	FD1EFF	4379 326527	VIKTORIYA SOROKINA	{"email": "sorokinav-021973@postgrespro.ru", "phone": "+70558065553"}
0005433634701	FD1EFF	0883 144351	GALINA ZAKHAROVA	{"phone": "+70921446204"}
0005433634702	26213F	3657 639220	EGOR BARANOV	{"phone": "+70448323167"}
0005433634703	63DB04	7519 768778	MAKSIM IVANOV	{"phone": "+70967796951"}
0005433634704	5898ED	1676 273385	YURIY FEDOTOV	{"email": "fedotov.y28061979@postgrespro.ru", "phone": "+70035716788"}
0005433634705	5898ED	2708 577508	SERGEY PETROV	{"phone": "+70056897651"}
0005433634706	0DA4D4	1206 432840	SOFYA FEDOROVA	{"email": "sofya_fedorova_1976@postgrespro.ru", "phone": "+70409768201"}
0005433634707	0DA4D4	1981 875485	LYUDMILA LUKYANOVA	{"email": "lukyanova_lyudmila26071976@postgrespro.ru", "phone": "+70184184193"}
0005433634708	0DA4D4	4722 807726	ANDREY SOLOVEV	{"phone": "+70797020610"}
0005433634709	D7F209	4341 807272	KONSTANTIN MEDVEDEV	{"email": "medvedevk-21031960@postgrespro.ru", "phone": "+70467629488"}
0005433634710	D7F60B	4986 337480	MAKSIM MAKAROV	{"phone": "+70512975794"}
0005433634711	D7F60B	0340 917476	RAFAIL KUZNECOV	{"phone": "+70970829631"}
0005433634712	1FC13F	1866 015098	DMITRIY SAVELEV	{"email": "savelev-dmitriy.27031954@postgrespro.ru", "phone": "+70291964556"}
0005433634713	D3C984	4373 771249	ALEKSANDR YAKOVLEV	{"email": "yakovleva011985@postgrespro.ru", "phone": "+70825388217"}
0005433634714	26EE2B	0375 778398	ILGIZ FEDOTOV	{"phone": "+70801984209"}
0005433634715	706CF5	5797 135169	OKSANA ROMANOVA	{"phone": "+70443250952"}
0005433634716	A43E4F	5857 439383	EVGENIY SEMENOV	{"phone": "+70705297199"}
0005433634717	D9F21B	9647 026021	VLADIMIR SOROKIN	{"email": "sorokin-v_101968@postgrespro.ru", "phone": "+70720495066"}
0005433634718	D9F21B	9765 711864	SVETLANA MIKHAYLOVA	{"phone": "+70744163221"}
0005433634719	8392ED	7234 821125	DMITRIY KUZNECOV	{"email": "dkuznecov.1966@postgrespro.ru", "phone": "+70325727387"}
0005433634720	1C1751	9026 992907	OLEG AFANASEV	{"email": "afanasev_oleg_1965@postgrespro.ru", "phone": "+70356407709"}
0005433634721	332392	9569 694759	YULIYA VOROBEVA	{"email": "vorobeva-y-1972@postgrespro.ru", "phone": "+70977019988"}
0005433634722	332392	5999 003429	SERGEY IVANOV	{"phone": "+70101913474"}
0005433634723	CC5B05	9887 739642	SERGEY NIKITIN	{"email": "nikitinsergey.071976@postgrespro.ru", "phone": "+70359111962"}
0005433634724	ADAD72	6678 113010	IVAN ZAKHAROV	{"email": "ivan_zakharov_121969@postgrespro.ru", "phone": "+70153075457"}
0005433634725	ADAD72	9759 386150	OLEG SCHERBAKOV	{"phone": "+70396861463"}
0005433634726	ADAD72	8135 606806	NADEZHDA VLASOVA	{"email": "nadezhdavlasova_1976@postgrespro.ru", "phone": "+70074805680"}
0005433634727	9D7184	4102 076513	BOGDAN KISELEV	{"phone": "+70287689446"}
0005433634728	5ECD6E	9369 333900	MIKHAIL MAKAROV	{"email": "makarov.mikhail.1976@postgrespro.ru", "phone": "+70213092408"}
0005433634729	7CE1D1	1634 236138	MAKSIM IVANOV	{"email": "ivanov-m.091972@postgrespro.ru", "phone": "+70649703776"}
0005433634730	7CE1D1	2049 766597	ALEKSANDR MAKAROV	{"email": "makarov.a-041966@postgrespro.ru", "phone": "+70028711635"}
0005433634731	2CD4C5	1445 413905	NADEZHDA KOROLEVA	{"phone": "+70812215648"}
0005433642153	40925E	5885 572447	NIKOLAY DAVYDOV	{"phone": "+70709529697"}
0005433634732	56AE4E	2933 830821	EGOR YAKOVLEV	{"email": "e.yakovlev.13021977@postgrespro.ru", "phone": "+70621404602"}
0005433634733	CF7790	1556 820810	EKATERINA NESTEROVA	{"email": "e.nesterova_101955@postgrespro.ru", "phone": "+70539378257"}
0005433634734	CF7790	3232 252080	MIKHAIL FOMIN	{"email": "mikhail.fomin-011973@postgrespro.ru", "phone": "+70950828054"}
0005433634735	87264A	5863 863241	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr12011970@postgrespro.ru", "phone": "+70704381714"}
0005433634736	87264A	9644 510356	ALEKSEY ZAKHAROV	{"phone": "+70330917655"}
0005433634737	20AD96	6145 126674	VALENTINA SMIRNOVA	{"phone": "+70863522941"}
0005433634738	20AD96	5665 474948	ANATOLIY PETROV	{"phone": "+70740107928"}
0005433634739	1018A1	2052 386091	ELENA FILIPPOVA	{"email": "elenafilippova-041973@postgrespro.ru", "phone": "+70516936382"}
0005433634740	20E7B8	1168 378126	ALEKSANDR DAVYDOV	{"phone": "+70368128160"}
0005433634741	757115	9619 143750	NATALIYA KALININA	{"phone": "+70682473629"}
0005433634742	757115	9798 197549	SVETLANA BOGDANOVA	{"email": "s_bogdanova.20041968@postgrespro.ru", "phone": "+70660713980"}
0005433634743	757115	7473 099449	VERA NAZAROVA	{"email": "vera-nazarova-04011978@postgrespro.ru", "phone": "+70828834025"}
0005433634744	75DA4D	0690 515768	NINA VASILEVA	{"phone": "+70174305923"}
0005433634745	0255BA	7811 693599	YULIYA MIRONOVA	{"email": "mironova.y_11111979@postgrespro.ru", "phone": "+70178302404"}
0005433634746	0255BA	2575 465965	YURIY MOISEEV	{"email": "moiseev.yuriy111969@postgrespro.ru", "phone": "+70367538439"}
0005433634747	7ED24E	1794 739232	ELENA SAVELEVA	{"phone": "+70950777074"}
0005433634748	A74334	1059 400834	MARIYA POTAPOVA	{"email": "potapova.mariya_101973@postgrespro.ru", "phone": "+70431184775"}
0005433634749	38ADD1	7010 492523	ROMAN ANDREEV	{"phone": "+70020664629"}
0005433634750	A75681	6388 703859	OLGA MASLOVA	{"email": "maslovaolga_12071970@postgrespro.ru", "phone": "+70590351543"}
0005433634751	302003	4248 665284	OLGA SOLOVEVA	{"email": "soloveva-olga_1982@postgrespro.ru", "phone": "+70927390116"}
0005433634752	6F4798	3748 344419	ALEKSANDR FILIPPOV	{"phone": "+70704895605"}
0005433634753	6F4798	1414 350279	SVETLANA ILINA	{"phone": "+70963523693"}
0005433634754	6F4798	3058 978751	SERGEY KUZNECOV	{"email": "sergey_kuznecov_1977@postgrespro.ru", "phone": "+70722983220"}
0005433634755	C74D57	5202 266984	TATYANA KAZAKOVA	{"phone": "+70268397828"}
0005433634756	626CDD	8610 089210	VALENTIN MIKHAYLOV	{"email": "mikhaylovvalentin-071967@postgrespro.ru", "phone": "+70124933965"}
0005433634757	626CDD	2712 127210	GALINA LAZAREVA	{"phone": "+70052626990"}
0005433634758	E5FA49	8945 560479	VIKTORIYA SERGEEVA	{"email": "viktoriyasergeeva.02061959@postgrespro.ru", "phone": "+70651797447"}
0005433634759	B25909	0782 858363	NIKOLAY GAVRILOV	{"email": "n.gavrilov.16011978@postgrespro.ru", "phone": "+70380457843"}
0005433634760	B25909	6262 985974	LIDIYA ILINA	{"email": "ilinal1972@postgrespro.ru", "phone": "+70099590284"}
0005433634761	DE64B1	5155 281048	ANDREY MELNIKOV	{"email": "andrey.melnikov01061975@postgrespro.ru", "phone": "+70209609617"}
0005433634762	C8B527	6291 412622	VIKTORIYA STEPANOVA	{"phone": "+70783017696"}
0005433634763	1CD6BA	8176 518508	MAKSIM TIMOFEEV	{"email": "m.timofeev_12071974@postgrespro.ru", "phone": "+70563451467"}
0005433634764	BEA00D	5259 002088	MIKHAIL KOROLEV	{"email": "korolev.m.16081969@postgrespro.ru", "phone": "+70662156139"}
0005433634765	DA1B1B	6765 379878	VLADIMIR FILIPPOV	{"email": "vladimir-filippov_111978@postgrespro.ru", "phone": "+70563360076"}
0005433634766	DA1B1B	8435 165464	KRISTINA NOVIKOVA	{"phone": "+70637992554"}
0005433634767	3D8D9A	1606 321773	ALEKSANDR FOMIN	{"email": "fomin-aleksandr1981@postgrespro.ru", "phone": "+70790127986"}
0005433634768	CC331C	4434 878953	EVGENIY KONOVALOV	{"email": "evgeniy.konovalov.1970@postgrespro.ru", "phone": "+70401279934"}
0005433634769	02F309	4520 097513	YULIYA CHERNOVA	{"phone": "+70978848880"}
0005433634770	F5C67C	7494 520191	NIKOLAY FEDOROV	{"phone": "+70070487670"}
0005433634771	AA94AA	3997 872406	VADIM KUZNECOV	{"phone": "+70691755266"}
0005433634772	9BEBC0	1423 738987	GENNADIY MOISEEV	{"email": "moiseev_g.1968@postgrespro.ru", "phone": "+70686662116"}
0005433634773	BC3CF5	6778 256403	RAMZIYA SOKOLOVA	{"email": "sokolovaramziya.31121979@postgrespro.ru", "phone": "+70754520366"}
0005433634774	BC3CF5	5483 073599	ALEKSANDR PETROV	{"phone": "+70936514126"}
0005433634775	710F1A	7075 748705	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva.081970@postgrespro.ru", "phone": "+70590380954"}
0005433634776	710F1A	2969 408269	SERGEY FROLOV	{"email": "frolov_sergey_071961@postgrespro.ru", "phone": "+70520011277"}
0005433634777	F4A90F	2997 700013	SERGEY NOVIKOV	{"phone": "+70655310710"}
0005433634778	318FDA	1098 058297	EVGENIY GUSEV	{"phone": "+70422558880"}
0005433634779	318FDA	2617 938654	VERONIKA BELOVA	{"email": "v-belova.041973@postgrespro.ru", "phone": "+70526965791"}
0005433634780	BBAE31	0897 654203	VIKTOR PETROV	{"phone": "+70833156140"}
0005433634781	5672ED	4971 088850	NINA LUKYANOVA	{"email": "nina_lukyanova.031972@postgrespro.ru", "phone": "+70905847861"}
0005433634782	E2129B	9443 648933	VALENTINA SMIRNOVA	{"email": "v.smirnova_12121970@postgrespro.ru", "phone": "+70659485903"}
0005433634783	E2129B	3502 857487	NATALYA ANDREEVA	{"phone": "+70366785076"}
0005433634784	8B7460	1687 145499	TATYANA MAKSIMOVA	{"phone": "+70391270981"}
0005433634785	2227DE	8556 046567	MARIYA POPOVA	{"email": "mariya-popova-041967@postgrespro.ru", "phone": "+70913643942"}
0005433634786	CDBD08	5529 086405	YULIYA NOVIKOVA	{"phone": "+70645538067"}
0005433634787	CDBD08	9555 111889	NINA KISELEVA	{"email": "nina.kiseleva.08071978@postgrespro.ru", "phone": "+70188934048"}
0005433634788	74DFCF	8311 567212	VALENTINA SOROKINA	{"phone": "+70292249519"}
0005433634789	74DFCF	5576 193489	DANA GERASIMOVA	{"email": "gerasimova.d-011971@postgrespro.ru", "phone": "+70096824028"}
0005433634790	7F6893	5537 260699	ANDREY PAVLOV	{"phone": "+70665997012"}
0005433634791	F634BE	5434 976438	YULIYA DENISOVA	{"email": "yuliya-denisova.21091975@postgrespro.ru", "phone": "+70675259556"}
0005433634792	F634BE	9468 096169	SVETLANA SCHERBAKOVA	{"email": "svetlana.scherbakova.1977@postgrespro.ru", "phone": "+70551426171"}
0005433634793	EA16F4	9923 199320	IRINA DMITRIEVA	{"phone": "+70653366387"}
0005433634794	B4EC49	2043 661368	MIKHAIL EGOROV	{"phone": "+70316325196"}
0005433634795	7B02E5	0753 489528	ANASTASIYA MATVEEVA	{"email": "matveeva-anastasiya.051971@postgrespro.ru", "phone": "+70171614718"}
0005433634796	69667D	4934 853970	RAFIK KARPOV	{"phone": "+70006411308"}
0005433634797	4268B0	0437 488887	VIKTOR ZAKHAROV	{"email": "zakharov.viktor101962@postgrespro.ru", "phone": "+70029496244"}
0005433634798	773CDF	6126 898911	EVGENIY NIKOLAEV	{"email": "evgeniynikolaev-1978@postgrespro.ru", "phone": "+70205836939"}
0005433634799	771CF5	9065 795555	BOGDAN KUZNECOV	{"phone": "+70750638359"}
0005433634800	771CF5	1153 218737	NATALYA ZAYCEVA	{"phone": "+70377610099"}
0005433634801	A38263	2285 752837	YURIY ILIN	{"phone": "+70501524366"}
0005433634802	6905CB	9478 685872	MIKHAIL ANDREEV	{"phone": "+70916131181"}
0005433634803	53F23C	6576 643656	ANNA ANDREEVA	{"email": "andreeva.a_051968@postgrespro.ru", "phone": "+70179611223"}
0005433634804	314723	2861 313617	IVAN ZHUKOV	{"phone": "+70660791686"}
0005433634805	612FBE	3590 663918	TATYANA PETROVA	{"email": "petrova-t.20051972@postgrespro.ru", "phone": "+70352833531"}
0005433634806	612FBE	8479 311589	MARIYA PAVLOVA	{"email": "mariya-pavlova.091971@postgrespro.ru", "phone": "+70390788846"}
0005433634807	AF0BD5	5073 782772	VASILIY AFANASEV	{"email": "vasiliy_afanasev_1963@postgrespro.ru", "phone": "+70426157057"}
0005433634808	0CA51C	8322 320944	SERGEY NIKOLAEV	{"phone": "+70472696396"}
0005433634809	6327E4	7779 349693	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov-061973@postgrespro.ru", "phone": "+70830092064"}
0005433634810	F5632D	7514 875357	KIRILL PETROV	{"email": "k.petrov1983@postgrespro.ru", "phone": "+70127565848"}
0005433634811	F5632D	1261 116416	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev.1966@postgrespro.ru", "phone": "+70342133390"}
0005433634812	8E031A	8128 157258	DARYA MOISEEVA	{"phone": "+70128056663"}
0005433634813	B30B4B	2398 229727	ALEKSANDR FEDOTOV	{"email": "a-fedotov.1965@postgrespro.ru", "phone": "+70103043406"}
0005433634814	6B9E39	8008 716020	VIKTOR NIKITIN	{"email": "viktornikitin.17071979@postgrespro.ru", "phone": "+70295188194"}
0005433634815	44AF12	5252 478777	VALENTIN MAKSIMOV	{"email": "vmaksimov-1982@postgrespro.ru", "phone": "+70053513759"}
0005433634816	44AF12	5011 582627	ALLA KOZLOVA	{"phone": "+70808955333"}
0005433634817	BAC1BD	5668 277298	OLEG DAVYDOV	{"phone": "+70524244962"}
0005433634818	BAC1BD	3862 891767	ANATOLIY PAVLOV	{"phone": "+70587779693"}
0005433634819	F182EF	3652 278661	YURIY MELNIKOV	{"email": "melnikovyuriy-1976@postgrespro.ru", "phone": "+70772813747"}
0005433634820	F182EF	1397 807714	TATYANA SEMENOVA	{"phone": "+70928302148"}
0005433634821	AEF38D	2720 276909	NIKOLAY SOKOLOV	{"phone": "+70991260290"}
0005433634822	93F0B6	5682 294100	VLADISLAV ISAEV	{"phone": "+70761308129"}
0005433634823	B78E52	1920 632577	LYUBOV SOLOVEVA	{"email": "lyubov_soloveva_1988@postgrespro.ru", "phone": "+70245840825"}
0005433634824	4601A9	4683 950956	SERGEY ILIN	{"email": "ilin.sergey.20061978@postgrespro.ru", "phone": "+70183992638"}
0005433634825	330C84	6903 540881	IRINA ZOTOVA	{"phone": "+70348946340"}
0005433634826	330C84	1785 707425	LYUBOV KOVALEVA	{"email": "kovaleval_1982@postgrespro.ru", "phone": "+70019284231"}
0005433634827	330C84	5534 686392	MIKHAIL PAVLOV	{"phone": "+70576638632"}
0005433634828	7D3467	6491 178327	LYUBOV CHERNOVA	{"email": "lyubov_chernova_22111984@postgrespro.ru", "phone": "+70736200520"}
0005433634829	FA0A6B	4129 463743	ALFIYA PAVLOVA	{"phone": "+70777116694"}
0005433634830	FA0A6B	0146 501252	TATYANA LOGINOVA	{"phone": "+70721527453"}
0005433642137	3B3937	4502 331839	ALEKSEY ZAKHAROV	{"phone": "+70753774918"}
0005433642073	C5CB8F	9312 321804	VLADIMIR POPOV	{"email": "popov-vladimir_1973@postgrespro.ru", "phone": "+70213113877"}
0005433642074	085EDB	3676 212433	VITALIY MARTYNOV	{"email": "martynov.vitaliy.1956@postgrespro.ru", "phone": "+70090814313"}
0005433642075	085EDB	8345 140209	TATYANA NAZAROVA	{"phone": "+70201826926"}
0005433642076	E7A272	4405 521710	OLGA FEDOROVA	{"email": "ofedorova.09081986@postgrespro.ru", "phone": "+70773885242"}
0005433642077	E7A272	5980 952618	ANATOLIY ZAKHAROV	{"phone": "+70655029646"}
0005433642078	7CEE39	5193 624126	ALEKSANDR KRASNOV	{"phone": "+70154831675"}
0005433642079	7CEE39	5371 034188	ANDREY KUZNECOV	{"phone": "+70320502583"}
0005433642080	176B73	0198 673138	TATYANA YAKOVLEVA	{"email": "tatyanayakovleva.17041988@postgrespro.ru", "phone": "+70076509861"}
0005433642081	62EED4	3109 258573	MARIYA PETROVA	{"email": "m_petrova-111966@postgrespro.ru", "phone": "+70557342225"}
0005433642082	3FA1CA	7809 277325	YURIY ZHURAVLEV	{"email": "yuriyzhuravlev1962@postgrespro.ru", "phone": "+70255669421"}
0005433642083	3FA1CA	5371 407074	EMMA SEMENOVA	{"email": "emma-semenova.031973@postgrespro.ru", "phone": "+70095695459"}
0005433642084	6411CA	5442 454311	VLADIMIR IVANOV	{"email": "ivanovv1967@postgrespro.ru", "phone": "+70670372018"}
0005433642085	509462	1907 545374	NATALIYA NOVIKOVA	{"phone": "+70002556531"}
0005433642086	BB798E	2541 100852	ALEKSEY MELNIKOV	{"email": "melnikov-a.061974@postgrespro.ru", "phone": "+70122539566"}
0005433642087	1F96E2	8179 472652	VIKTORIYA SERGEEVA	{"email": "v_sergeeva-18111970@postgrespro.ru", "phone": "+70854142485"}
0005433642088	5A9B50	0027 846269	FLYURA SMIRNOVA	{"phone": "+70591347033"}
0005433642089	264027	4096 155496	IVAN NOVIKOV	{"email": "novikov.i031972@postgrespro.ru", "phone": "+70740854485"}
0005433642090	2BF589	5029 783889	ELENA ANTONOVA	{"email": "e_antonova-1960@postgrespro.ru", "phone": "+70930646316"}
0005433642091	14300B	1736 081025	ALISA TITOVA	{"phone": "+70174587834"}
0005433642092	582244	5225 460326	VYACHESLAV SEMENOV	{"email": "semenovv.1968@postgrespro.ru", "phone": "+70112160453"}
0005433642093	C99C2E	2316 998292	VLADIMIR FOMIN	{"phone": "+70988607622"}
0005433642094	5C9285	2207 948523	ZULFIYA POPOVA	{"phone": "+70179183547"}
0005433642095	046440	0195 073243	MARIYA MIRONOVA	{"phone": "+70897933395"}
0005433642096	FB3280	1002 831818	SERGEY OSIPOV	{"phone": "+70658443706"}
0005433642097	3EDC7B	5767 995479	LEONID BARANOV	{"email": "baranov.l.1967@postgrespro.ru", "phone": "+70415608401"}
0005433642098	3EDC7B	4691 676879	VALENTINA STEPANOVA	{"email": "valentinastepanova_11061969@postgrespro.ru", "phone": "+70263954044"}
0005433642099	76C0D2	0691 619229	DMITRIY SOROKIN	{"email": "dmitriysorokin1963@postgrespro.ru", "phone": "+70040311296"}
0005433642100	76C0D2	7928 718127	YULIYA DAVYDOVA	{"email": "davydova_yuliya_31051970@postgrespro.ru", "phone": "+70944349282"}
0005433642101	8B579E	1901 335367	DMITRIY SCHERBAKOV	{"email": "scherbakov-d-121965@postgrespro.ru", "phone": "+70246405820"}
0005433642102	7351DC	4374 593257	GALINA TROFIMOVA	{"email": "g.trofimova-10061966@postgrespro.ru", "phone": "+70805665062"}
0005433642103	C316C6	5613 405761	KLAVDIYA POPOVA	{"phone": "+70213747179"}
0005433642104	C316C6	3687 058033	TATYANA MOROZOVA	{"phone": "+70053065332"}
0005433642105	B55E3D	6296 285649	LYUBOV KOVALEVA	{"phone": "+70975158648"}
0005433642106	83E3E1	7850 080525	VADIM SEMENOV	{"email": "v_semenov031972@postgrespro.ru", "phone": "+70288412337"}
0005433642107	62ECED	4339 377151	ALEKSANDR KISELEV	{"phone": "+70126146271"}
0005433642108	E7A063	8480 040091	RAISA MIKHAYLOVA	{"phone": "+70159517207"}
0005433642109	BC790F	9203 940478	ANATOLIY OSIPOV	{"email": "anatoliy_osipov21011951@postgrespro.ru", "phone": "+70435677157"}
0005433642110	BC790F	9712 749350	ANASTASIYA ALEKSEEVA	{"email": "anastasiyaalekseeva.1964@postgrespro.ru", "phone": "+70259701766"}
0005433642111	E9A6EC	0453 602859	LILIYA OSIPOVA	{"phone": "+70685637742"}
0005433642112	CF1D09	4458 191275	TAMARA MOISEEVA	{"email": "moiseeva.tamara121972@postgrespro.ru", "phone": "+70912502728"}
0005433642113	CF1D09	1829 328655	ELENA ZOTOVA	{"phone": "+70051077224"}
0005433642114	76BFF7	7059 552039	ALEKSEY FEDOROV	{"email": "aleksey_fedorov-27111971@postgrespro.ru", "phone": "+70292291127"}
0005433642115	76BFF7	0979 404474	IRAIDA ILINA	{"email": "iraidailina.01031976@postgrespro.ru", "phone": "+70298293820"}
0005433642116	2A8A75	9826 117591	SERGEY NIKOLAEV	{"phone": "+70411722176"}
0005433642117	2A8A75	8114 952555	DARYA GUSEVA	{"phone": "+70846644162"}
0005433642118	346BBB	1147 114520	MAKSIM BORISOV	{"email": "borisov_maksim.1972@postgrespro.ru", "phone": "+70265663686"}
0005433642119	346BBB	9990 143589	ALEKSANDRA TIMOFEEVA	{"email": "timofeeva-aleksandra.06061971@postgrespro.ru", "phone": "+70476501367"}
0005433642120	71E24A	8770 955056	NIKOLAY IVANOV	{"phone": "+70766078775"}
0005433642121	232618	2141 329199	SVETLANA SCHERBAKOVA	{"email": "svetlanascherbakova-14071964@postgrespro.ru", "phone": "+70109140461"}
0005433642122	4E78EF	3806 827849	TAGIR SIDOROV	{"email": "sidorov_tagir041980@postgrespro.ru", "phone": "+70170990377"}
0005433642123	97973B	4095 033754	OLEG SOKOLOV	{"email": "sokolovoleg_071981@postgrespro.ru", "phone": "+70814341597"}
0005433642124	1D921D	8012 978149	LIDIYA BORISOVA	{"phone": "+70595010520"}
0005433642125	F9EB7C	3776 032755	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr-091969@postgrespro.ru", "phone": "+70468864613"}
0005433642126	5F7168	9630 124993	TATYANA ISAEVA	{"email": "tatyana_isaeva_031978@postgrespro.ru", "phone": "+70045130172"}
0005433642127	5F7168	8239 981355	MARIYA KUZNECOVA	{"email": "kuznecovamariya-27071974@postgrespro.ru", "phone": "+70600536003"}
0005433642128	5F7168	3435 095761	YULIYA MOROZOVA	{"phone": "+70043282626"}
0005433642129	887193	9455 010508	KSENIYA POLYAKOVA	{"phone": "+70893166194"}
0005433642130	887193	1877 734275	NIKITA ANDREEV	{"phone": "+70834929709"}
0005433642131	624E3A	8226 284894	NADEZHDA MIRONOVA	{"email": "nadezhdamironova07031972@postgrespro.ru", "phone": "+70944763676"}
0005433642132	624E3A	1920 018980	OLGA OVCHINNIKOVA	{"phone": "+70428755305"}
0005433642133	624E3A	5262 182760	FEDOR ORLOV	{"email": "orlov-fedor.23051970@postgrespro.ru", "phone": "+70682783714"}
0005433642134	BBB7CE	4345 900139	ANTONINA EFREMOVA	{"email": "efremova_antonina_111965@postgrespro.ru", "phone": "+70022938707"}
0005433642135	BBB7CE	7597 142092	DMITRIY ROMANOV	{"email": "romanovd.12011968@postgrespro.ru", "phone": "+70921441377"}
0005433642136	3B3937	4085 108755	DENIS BONDARENKO	{"phone": "+70672791285"}
0005433642138	F48F96	6022 849790	VALENTINA PAVLOVA	{"email": "v.pavlova.04031997@postgrespro.ru", "phone": "+70084626405"}
0005433642139	C0C82C	2235 726047	LARISA POPOVA	{"phone": "+70853924491"}
0005433642140	D8D4D5	8417 761038	VLADIMIR RODIONOV	{"phone": "+70902452426"}
0005433642141	21FAC2	4767 886925	NATALYA PAVLOVA	{"phone": "+70695851261"}
0005433642142	A44DC3	7702 376352	IVAN MOISEEV	{"email": "moiseev_ivan-1977@postgrespro.ru", "phone": "+70256399146"}
0005433642143	A44DC3	0925 445934	KONSTANTIN ANDREEV	{"phone": "+70264486279"}
0005433642144	DD84AA	3475 259623	EKATERINA POPOVA	{"phone": "+70213410881"}
0005433642145	DD84AA	3448 530728	NIKOLAY GUSEV	{"phone": "+70848853712"}
0005433642146	C80250	1672 046967	VENERA FROLOVA	{"email": "frolova-venera-111967@postgrespro.ru", "phone": "+70781349066"}
0005433642147	A92486	8473 281752	VLADIMIR PAVLOV	{"phone": "+70317884488"}
0005433642148	E661E1	1191 877361	NINA SERGEEVA	{"email": "nina_sergeeva.14121973@postgrespro.ru", "phone": "+70547863146"}
0005433642149	E661E1	2195 707139	ANDREY BORISOV	{"email": "andrey.borisov-1970@postgrespro.ru", "phone": "+70980291498"}
0005433642150	CE28D8	8699 101086	SOFYA IVANOVA	{"phone": "+70272114933"}
0005433642151	CE28D8	6941 040404	LARISA POLYAKOVA	{"phone": "+70378368049"}
0005433642152	F852D9	1815 852515	EVGENIY MAKSIMOV	{"phone": "+70541719624"}
0005433642154	C1436B	1708 931289	SVETLANA ABRAMOVA	{"email": "abramova.s-1981@postgrespro.ru", "phone": "+70230789910"}
0005433642155	BAD3AE	7330 585037	NIKOLAY SCHERBAKOV	{"phone": "+70203521286"}
0005433642156	A6B0F2	5142 061784	VLADIMIR PAVLOV	{"phone": "+70728587491"}
0005433642157	42C438	7461 889818	SVETLANA KARPOVA	{"phone": "+70680919534"}
0005433642158	42C438	2642 411802	VLADIMIR POPOV	{"phone": "+70679482969"}
0005433642159	018052	6965 035149	ALEKSANDR VASILEV	{"email": "vasilev-a.03041976@postgrespro.ru", "phone": "+70526735786"}
0005433642160	B4F7FE	6609 827641	TATYANA GUSEVA	{"email": "tguseva111970@postgrespro.ru", "phone": "+70207562768"}
0005433642161	801FBC	7757 550374	SVETLANA ANISIMOVA	{"phone": "+70852059997"}
0005433642162	E3E57C	6636 643411	YURIY KOROLEV	{"email": "y_korolev091972@postgrespro.ru", "phone": "+70216722393"}
0005433642163	4848E6	2824 113047	LIDIYA FILATOVA	{"email": "lidiya.filatova.07121973@postgrespro.ru", "phone": "+70092874205"}
0005433642164	4848E6	9877 802071	ALEKSEY SHEVCHENKO	{"email": "shevchenkoa09021968@postgrespro.ru", "phone": "+70437407161"}
0005433642165	98475C	0158 414092	ALENA YUDINA	{"email": "alena.yudina_041984@postgrespro.ru", "phone": "+70235384979"}
0005433642166	42AD10	8421 753332	OLEG RODIONOV	{"email": "rodionov-oleg.1976@postgrespro.ru", "phone": "+70767775495"}
0005433642167	E7D07F	6076 252981	EKATERINA MALYSHEVA	{"email": "e.malysheva.26081966@postgrespro.ru", "phone": "+70237204585"}
0005433642168	E7D07F	3180 538043	ALEKSEY ALEKSEEV	{"email": "alekseyalekseev041970@postgrespro.ru", "phone": "+70694792888"}
0005433642169	D726E6	5708 472418	DANILA VASILEV	{"email": "vasilev-d_011976@postgrespro.ru", "phone": "+70863237174"}
0005433642170	D726E6	9578 511145	KIRILL CHERNOV	{"phone": "+70198323698"}
0005433642171	E13C7D	9180 882948	OLGA SIDOROVA	{"email": "olga.sidorova_1976@postgrespro.ru", "phone": "+70087348307"}
0005433642172	E13C7D	4829 107059	DANILA VOLKOV	{"email": "d.volkov.03121960@postgrespro.ru", "phone": "+70456264244"}
0005433642173	37A232	1429 502432	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov06021971@postgrespro.ru", "phone": "+70686906567"}
0005433642174	8724DD	6712 843170	LYUDMILA MELNIKOVA	{"email": "melnikova.lyudmila_011971@postgrespro.ru", "phone": "+70080437853"}
0005433642175	8724DD	1639 925161	SERGEY BORISOV	{"email": "borisov_sergey.18081973@postgrespro.ru", "phone": "+70469795531"}
0005433642176	8724DD	5582 175882	IRINA KUZMINA	{"phone": "+70173261241"}
0005433642177	9D539F	3247 793518	RUSLAN MAKAROV	{"email": "makarov_r_121976@postgrespro.ru", "phone": "+70817768340"}
0005433642178	FC4CB3	8413 012574	ANATOLIY GORBUNOV	{"phone": "+70837163499"}
0005433642179	BE35F8	3606 823476	LYUBOV NIKIFOROVA	{"phone": "+70021398913"}
0005433642180	4569D3	8671 334310	ANDREY VLASOV	{"email": "vlasov-a_031977@postgrespro.ru", "phone": "+70761230911"}
0005433642181	18ADAA	2590 751361	VALENTINA EFIMOVA	{"email": "v_efimova_071965@postgrespro.ru", "phone": "+70539992514"}
0005433642182	F04942	9731 090977	ANASTASIYA PAVLOVA	{"phone": "+70221823071"}
0005433642183	9B837A	3097 889447	YULIYA AFANASEVA	{"email": "afanaseva.y.12091980@postgrespro.ru", "phone": "+70590266028"}
0005433642184	9B837A	8674 654265	NIKOLAY NIKITIN	{"email": "nnikitin-27081977@postgrespro.ru", "phone": "+70562247494"}
0005433642185	5E1B0D	8676 949316	NINA ZAKHAROVA	{"phone": "+70630664185"}
0005433642186	F2150E	9371 514354	NADEZHDA IVANOVA	{"phone": "+70555626668"}
0005433642187	463DE0	6089 893045	ANASTASIYA FROLOVA	{"phone": "+70061232206"}
0005433642188	E315B1	7728 975366	ELENA BORISOVA	{"email": "borisova.elena23121970@postgrespro.ru", "phone": "+70105350011"}
0005433642189	5B4945	2572 240528	VLADIMIR MATVEEV	{"email": "matveev.v-1968@postgrespro.ru", "phone": "+70812921796"}
0005433642190	9F7C27	9847 089907	KRISTINA EFREMOVA	{"email": "k_efremova-03091982@postgrespro.ru", "phone": "+70609154944"}
0005433642191	9F7C27	3085 475782	MARIYA MALYSHEVA	{"phone": "+70778575569"}
0005433642192	74542F	8335 688526	OLGA POPOVA	{"phone": "+70612589009"}
0005433642193	136A8B	2991 714788	OLGA VOROBEVA	{"email": "vorobeva-olga_24121965@postgrespro.ru", "phone": "+70964334790"}
0005433642194	C3A580	1583 999087	MIKHAIL FILIPPOV	{"email": "m_filippov-1971@postgrespro.ru", "phone": "+70068809307"}
0005433642195	34B0C2	1956 946471	SERGEY ORLOV	{"email": "orlov-sergey-02101965@postgrespro.ru", "phone": "+70810201322"}
0005433642196	098DDE	8431 091727	SERGEY VASILEV	{"phone": "+70599790894"}
0005433642197	9A4633	6261 448144	LYUBOV ANDREEVA	{"phone": "+70358546123"}
0005433642198	947C4F	8878 940119	ALEKSANDR GERASIMOV	{"email": "a.gerasimov-021975@postgrespro.ru", "phone": "+70176986494"}
0005433642199	DF0A50	8373 836467	ELIZAVETA MELNIKOVA	{"phone": "+70628451919"}
0005433642200	C1B7AB	8956 653972	ANTONINA FEDOROVA	{"email": "fedorova.antonina.31081977@postgrespro.ru", "phone": "+70840149542"}
0005433642201	2CA147	3831 050124	NADEZHDA LEBEDEVA	{"email": "nadezhda-lebedeva-1966@postgrespro.ru", "phone": "+70496619483"}
0005433642202	2CA147	9726 725887	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov_15121970@postgrespro.ru", "phone": "+70728385502"}
0005433642203	128C15	6502 137274	ELENA SOKOLOVA	{"phone": "+70853157907"}
0005433642204	ACDD0F	5071 763864	RAIL SERGEEV	{"email": "rail_sergeev_1967@postgrespro.ru", "phone": "+70447326177"}
0005433642205	ACDD0F	4082 046033	NADEZHDA GERASIMOVA	{"email": "gerasimova.n-1977@postgrespro.ru", "phone": "+70851590124"}
0005433642206	7A8EFB	1297 408996	OLGA KISELEVA	{"email": "olga.kiseleva.05071974@postgrespro.ru", "phone": "+70953657183"}
0005433642207	989E45	3999 891758	VIKTOR KAZAKOV	{"phone": "+70809235512"}
0005433642208	989E45	1714 005861	OLEG GAVRILOV	{"email": "gavrilov-o_10051966@postgrespro.ru", "phone": "+70786315723"}
0005433642209	A95427	4343 800798	ANDREY KUZNECOV	{"email": "andrey-kuznecov.1967@postgrespro.ru", "phone": "+70157803463"}
0005433642210	935DCD	4569 214036	VLADIMIR ZAKHAROV	{"email": "v-zakharov021972@postgrespro.ru", "phone": "+70045280906"}
0005433642211	52E25A	7157 320725	SERGEY KUZNECOV	{"phone": "+70889768377"}
0005433642212	52E25A	1231 610673	OLGA VOROBEVA	{"phone": "+70786631441"}
0005433642213	52E25A	8177 089730	ROMAN MARTYNOV	{"phone": "+70676769157"}
0005433642214	317C36	2488 106991	LILIYA POPOVA	{"email": "l.popova_1978@postgrespro.ru", "phone": "+70328392126"}
0005433642215	5BAA90	0995 951026	IRINA GORBUNOVA	{"phone": "+70133167115"}
0005433642216	0B7EF4	1017 625004	TATYANA ALEKSANDROVA	{"email": "tatyana_aleksandrova-18021971@postgrespro.ru", "phone": "+70373167218"}
0005433642217	BA8A5C	3199 247299	TAMARA FADEEVA	{"phone": "+70120118735"}
0005433642218	5BAA13	4706 828685	SERGEY FILIPPOV	{"phone": "+70384768957"}
0005433642219	5BAA13	8126 113982	SERGEY ZAKHAROV	{"email": "zakharov_s-1980@postgrespro.ru", "phone": "+70207872701"}
0005433642220	5BAA13	2849 309637	ALEKSEY POPOV	{"email": "popov_aleksey.17081961@postgrespro.ru", "phone": "+70334624496"}
0005433642221	28A33E	4425 366335	MARK BORISOV	{"email": "borisov-m-11041966@postgrespro.ru", "phone": "+70552313366"}
0005433642222	DE28AA	1630 191300	ALBINA BORISOVA	{"email": "albinaborisova101983@postgrespro.ru", "phone": "+70904053287"}
0005433642223	843FE7	7525 813186	NIKOLAY SIDOROV	{"phone": "+70372014767"}
0005433642224	752A12	6380 731503	OLGA SERGEEVA	{"email": "sergeevao-22051963@postgrespro.ru", "phone": "+70722150117"}
0005433642225	752A12	7127 247358	SERGEY AFANASEV	{"email": "s-afanasev.101967@postgrespro.ru", "phone": "+70537343141"}
0005433642226	F5C087	1228 803153	EVGENIY POPOV	{"phone": "+70162654064"}
0005433642227	F5C087	3131 830943	YURIY SOROKIN	{"email": "yuriysorokin-09091972@postgrespro.ru", "phone": "+70611009764"}
0005433642228	F5C087	7005 756658	ALEKSANDR ISAEV	{"email": "isaev-a_051972@postgrespro.ru", "phone": "+70844372859"}
0005433642229	43DF8D	1626 200994	EVGENIYA ARKHIPOVA	{"phone": "+70888036027"}
0005433642230	43DF8D	6913 720392	IRINA NIKITINA	{"email": "nikitina_irina.1987@postgrespro.ru", "phone": "+70951742582"}
0005433642231	3389F7	2872 144646	EKATERINA AKIMOVA	{"phone": "+70088774259"}
0005433642232	3389F7	7787 892823	ALEKSEY RODIONOV	{"phone": "+70219036428"}
0005433642233	C7303D	7413 519052	ALENA SOKOLOVA	{"phone": "+70994751993"}
0005433642234	BBE162	2320 815756	YULIYA FADEEVA	{"email": "yfadeeva-031982@postgrespro.ru", "phone": "+70056739187"}
0005433642235	BBE162	4308 913768	DENIS DAVYDOV	{"email": "denis.davydov-081977@postgrespro.ru", "phone": "+70478334942"}
0005433642236	5167E8	1779 885721	ANNA KOROLEVA	{"email": "korolevaanna.15081970@postgrespro.ru", "phone": "+70127532388"}
0005433642237	91B1AA	1891 144003	OLGA GRISHINA	{"phone": "+70238392798"}
0005433642238	91B1AA	5875 281642	VALENTINA DMITRIEVA	{"phone": "+70521096923"}
0005433642239	5D3DEE	8645 050396	OLGA TARASOVA	{"email": "tarasova_o-041983@postgrespro.ru", "phone": "+70206186992"}
0005433642240	5D3DEE	9225 328549	DMITRIY POPOV	{"email": "d.popov.10091979@postgrespro.ru", "phone": "+70320705802"}
0005433642241	C8FD52	9179 086258	YURIY MAKSIMOV	{"email": "yuriy-maksimov_1983@postgrespro.ru", "phone": "+70226671626"}
0005433642242	C248BE	1005 204698	NADEZHDA KALININA	{"email": "kalinina.nadezhda.081972@postgrespro.ru", "phone": "+70287610336"}
0005433642243	C248BE	1058 909529	IGOR MARTYNOV	{"email": "martynov_igor-24121975@postgrespro.ru", "phone": "+70192379985"}
0005433642244	C248BE	0874 979438	TAMARA MAKAROVA	{"email": "tamara.makarova.1964@postgrespro.ru", "phone": "+70883811552"}
0005433642245	C2FA5E	8308 934487	ALEKSEY MIKHAYLOV	{"email": "mikhaylovaleksey_19121978@postgrespro.ru", "phone": "+70829248489"}
0005433642246	F640EF	3963 513134	NIKOLAY MARTYNOV	{"phone": "+70425395510"}
0005433642247	F640EF	7192 265087	OLGA ILINA	{"phone": "+70450504324"}
0005433642248	DCBE22	7490 374283	KONSTANTIN FEDOTOV	{"email": "fedotov_konstantin.17071964@postgrespro.ru", "phone": "+70547714843"}
0005433642249	411E31	3677 048356	ANASTASIYA BOGDANOVA	{"email": "abogdanova19101971@postgrespro.ru", "phone": "+70600976411"}
0005433642250	D71F14	3987 015462	ALEKSANDR FEDOTOV	{"phone": "+70766404615"}
0005433642251	0705CC	4120 399736	SERGEY NAUMOV	{"email": "sergey_naumov.121992@postgrespro.ru", "phone": "+70229231405"}
0005433642252	92294C	6958 949272	OLGA LEBEDEVA	{"email": "olga-lebedeva_03081976@postgrespro.ru", "phone": "+70967120494"}
0005433642253	92294C	5357 276185	ALENA ANDREEVA	{"phone": "+70706626566"}
0005433642254	122341	1425 519846	NATALYA LAZAREVA	{"email": "n-lazareva_1969@postgrespro.ru", "phone": "+70914623248"}
0005433642255	D25A91	2006 618667	TATYANA YUDINA	{"phone": "+70851408672"}
0005433642256	5A16BF	5044 678173	TATYANA ISAEVA	{"email": "isaeva.t02081964@postgrespro.ru", "phone": "+70475282546"}
0005433642257	5A16BF	5755 699518	ARTEM ABRAMOV	{"email": "abramov.a1976@postgrespro.ru", "phone": "+70219557551"}
0005433642258	6CAAD9	1911 099354	INESSA STEPANOVA	{"email": "inessa_stepanova18011963@postgrespro.ru", "phone": "+70594970873"}
0005433642259	6C6849	3796 173646	VALENTINA GORBUNOVA	{"email": "valentina_gorbunova-1978@postgrespro.ru", "phone": "+70599801570"}
0005433642260	49ED1D	7894 162162	SVETLANA ORLOVA	{"email": "orlovas1971@postgrespro.ru", "phone": "+70973159339"}
0005433642261	49ED1D	3612 877311	KSENIYA VOROBEVA	{"phone": "+70497769952"}
0005433642262	42962B	3895 104680	VALERIY SMIRNOV	{"email": "valeriysmirnov-13031978@postgrespro.ru", "phone": "+70816765876"}
0005433642263	01337D	3617 593365	MAKSIM FOMIN	{"phone": "+70214225771"}
0005433642264	FAD3C8	5296 029804	OLEG PETROV	{"phone": "+70324364548"}
0005433642265	55DB50	6665 995229	NATALYA DAVYDOVA	{"email": "natalya_davydova-031972@postgrespro.ru", "phone": "+70781460671"}
0005433642266	55DB50	2987 739706	VASILIY ORLOV	{"email": "v.orlov.1967@postgrespro.ru", "phone": "+70807822346"}
0005433642267	55DB50	8488 561617	ALEKSEY VASILEV	{"phone": "+70993947355"}
0005433642268	C54224	5995 939592	ALEKSANDR FILIPPOV	{"phone": "+70845195872"}
0005433642269	C54224	1293 222087	EKATERINA KAZAKOVA	{"phone": "+70120462884"}
0005433642270	565B36	5805 012420	OLGA TITOVA	{"email": "titova-o_1965@postgrespro.ru", "phone": "+70587004621"}
0005433642271	F50F49	4451 045644	TATYANA KUZNECOVA	{"phone": "+70620271142"}
0005433642272	892855	3801 038680	ANASTASIYA KOROLEVA	{"email": "koroleva_a.09091961@postgrespro.ru", "phone": "+70844167676"}
0005433642273	6BE03F	1460 079937	LARISA ZAYCEVA	{"email": "larisa.zayceva15101974@postgrespro.ru", "phone": "+70698635494"}
0005433642274	299FCC	2690 135819	TAMARA ZHURAVLEVA	{"email": "tamara.zhuravleva-19011973@postgrespro.ru", "phone": "+70866614360"}
0005433642275	4284D4	9801 011487	LYUDMILA FILATOVA	{"phone": "+70472587156"}
0005433642276	4284D4	9413 771967	MAKSIM PETROV	{"phone": "+70874973117"}
0005433642277	9E7B80	5624 550465	DMITRIY BARANOV	{"email": "dmitriy_baranov_19101969@postgrespro.ru", "phone": "+70258620041"}
0005433642278	AAE117	5418 627413	VLADIMIR ILIN	{"email": "vladimir-ilin_1984@postgrespro.ru", "phone": "+70022575331"}
0005433642279	FDB85F	8401 236552	EVGENIY IVANOV	{"phone": "+70677818450"}
0005433642280	675228	1088 312977	NATALYA FROLOVA	{"phone": "+70665065015"}
0005433642281	226561	4642 262877	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.1977@postgrespro.ru", "phone": "+70143957485"}
0005433642282	7D6764	5841 636481	ELENA ZHURAVLEVA	{"phone": "+70620017023"}
0005433642283	287122	9507 092103	ANASTASIYA ALEKSEEVA	{"phone": "+70568486990"}
0005433642284	6B080F	4378 995591	ALEKSANDR BONDARENKO	{"phone": "+70480828949"}
0005433642285	6B080F	5538 880338	IRINA POPOVA	{"phone": "+70092513163"}
0005433642286	AE3734	8316 647923	YURIY ANDREEV	{"email": "yandreev30051970@postgrespro.ru", "phone": "+70824239911"}
0005433642287	1A022D	3404 182794	VASILIY MOISEEV	{"phone": "+70097016705"}
0005433642288	DF82A0	3303 157663	SERGEY MEDVEDEV	{"email": "medvedevs-101973@postgrespro.ru", "phone": "+70186686475"}
0005433642289	F4A0F8	7135 648197	OLEG NAZAROV	{"email": "o.nazarov101959@postgrespro.ru", "phone": "+70592655745"}
0005433642290	F4A0F8	7421 868509	TATYANA ZAYCEVA	{"phone": "+70723013373"}
0005433642291	0137AD	9536 788033	LYUBOV FOMINA	{"phone": "+70248549200"}
0005433642292	053367	0229 358900	OLESYA KALININA	{"phone": "+70815285654"}
0005433642293	053367	4469 043472	IGOR SHEVCHENKO	{"phone": "+70300540347"}
0005433642294	18D6C8	1232 176940	SVETLANA ABRAMOVA	{"email": "abramova-s_1967@postgrespro.ru", "phone": "+70986475193"}
0005433642295	02843E	1633 134679	RUSTYAM ZAKHAROV	{"phone": "+70987187778"}
0005433642296	02843E	1907 825742	OLGA ANTONOVA	{"email": "antonova.olga_1978@postgrespro.ru", "phone": "+70499602186"}
0005433642297	793B16	5682 150550	VALENTINA TIKHONOVA	{"email": "v.tikhonova-121970@postgrespro.ru", "phone": "+70014560048"}
0005433642298	2B5434	4514 397126	OLEG FEDOROV	{"email": "olegfedorov-1964@postgrespro.ru", "phone": "+70442753442"}
0005433642299	2B5434	3117 399540	YULIYA PAVLOVA	{"phone": "+70834061006"}
0005433642300	2B5434	5331 043037	MARINA POTAPOVA	{"email": "potapovam_06031971@postgrespro.ru", "phone": "+70427004985"}
0005433642301	126861	6083 292181	MARIYA DANILOVA	{"email": "danilovamariya_011976@postgrespro.ru", "phone": "+70430280126"}
0005433642302	1BC9D4	2343 814767	ANASTASIYA BELYAEVA	{"email": "a-belyaeva-021975@postgrespro.ru", "phone": "+70324535696"}
0005433642303	6905D8	8133 935725	ANNA YAKOVLEVA	{"phone": "+70071470807"}
0005433642304	347DC6	1934 873143	SERGEY FROLOV	{"phone": "+70595286625"}
0005433642305	A167F3	7145 630636	ANNA KOMAROVA	{"email": "komarova_a.1961@postgrespro.ru", "phone": "+70163478425"}
0005433642306	48552C	1237 288925	IVAN ZAYCEV	{"phone": "+70760551792"}
0005433642307	BE7D5C	9197 435240	ILDAR GERASIMOV	{"phone": "+70803936752"}
0005433642308	BE7D5C	5134 962135	PAVEL PETROV	{"email": "petrov_p-1978@postgrespro.ru", "phone": "+70425772070"}
0005433642309	AAD5BC	1576 839970	VIKTOR IVANOV	{"email": "viktor.ivanov101966@postgrespro.ru", "phone": "+70200495275"}
0005433642310	00F023	2321 856191	SVETLANA SERGEEVA	{"email": "svetlanasergeeva011985@postgrespro.ru", "phone": "+70341333844"}
0005433642311	1F8AFC	6710 745780	SVETLANA NESTEROVA	{"phone": "+70463294101"}
0005433642312	661E4B	9967 074426	VALERIY SEMENOV	{"phone": "+70215069524"}
0005433642313	F89C70	2327 938371	VASILIY KONOVALOV	{"email": "konovalov-vasiliy.03061974@postgrespro.ru", "phone": "+70297926095"}
0005433642314	CF1C67	5940 082222	VLADIMIR CHERNOV	{"phone": "+70204380085"}
0005433642315	E30507	6175 532263	LYUBOV KONOVALOVA	{"email": "lyubovkonovalova-031974@postgrespro.ru", "phone": "+70923834558"}
0005433642316	A64481	2937 813013	ILYA NOVIKOV	{"phone": "+70012956556"}
0005433642317	ABFC60	0862 777285	LIDIYA FROLOVA	{"email": "frolova-lidiya1988@postgrespro.ru", "phone": "+70406333239"}
0005433642318	ABFC60	0569 205948	IRINA PAVLOVA	{"phone": "+70652241206"}
0005433642319	94F92B	6500 174331	ANASTASIYA MEDVEDEVA	{"email": "medvedeva-anastasiya-23101962@postgrespro.ru", "phone": "+70079210819"}
0005433642320	6625EB	6441 386425	VIKTOR SCHERBAKOV	{"phone": "+70014225540"}
0005433642321	2C5C1F	7428 615654	LYUDMILA SOLOVEVA	{"email": "lyudmila.soloveva-05051977@postgrespro.ru", "phone": "+70569136211"}
0005433642322	093630	2912 520907	VLADIMIR KOZLOV	{"phone": "+70455419784"}
0005433642490	A11736	5064 741605	NADEZHDA DANILOVA	{"phone": "+70388545480"}
0005433642323	093630	2299 224099	SERGEY SMIRNOV	{"email": "s.smirnov_091974@postgrespro.ru", "phone": "+70981363908"}
0005433642324	92B08E	6396 646207	VITALIY ORLOV	{"phone": "+70356848782"}
0005433642325	F35E38	3094 269857	KRISTINA BOGDANOVA	{"phone": "+70031218453"}
0005433642326	F35E38	1924 832343	VYACHESLAV ILIN	{"email": "vilin_26081985@postgrespro.ru", "phone": "+70619590065"}
0005433642327	0F621D	5722 940373	NATALYA KRASNOVA	{"phone": "+70761596809"}
0005433642328	E30301	5826 771445	REGINA ALEKSANDROVA	{"phone": "+70883529051"}
0005433642329	E30301	6261 179792	DANIIL AFANASEV	{"email": "afanasev_d081963@postgrespro.ru", "phone": "+70285990240"}
0005433642330	E30301	7518 380319	IVAN SOROKIN	{"email": "sorokin_ivan-1960@postgrespro.ru", "phone": "+70911256457"}
0005433642331	AC7967	2459 397619	NIKOLAY SCHERBAKOV	{"email": "scherbakov-nikolay.15041980@postgrespro.ru", "phone": "+70202684658"}
0005433642332	01B0E1	2761 826244	OKSANA ZHUKOVA	{"email": "ozhukova.06031966@postgrespro.ru", "phone": "+70564078521"}
0005433642333	67E32E	2995 764177	MARIYA PAVLOVA	{"phone": "+70204043147"}
0005433642334	27EE00	7817 855878	OLGA DANILOVA	{"email": "danilovaolga_1961@postgrespro.ru", "phone": "+70440903176"}
0005433642335	AF8414	8716 907722	ANDREY SMIRNOV	{"phone": "+70717662354"}
0005433642336	130EAE	9116 044367	AZAT PETROV	{"email": "petrov_a.061971@postgrespro.ru", "phone": "+70833320992"}
0005433642337	130EAE	0426 418794	RUSTEM BELOV	{"phone": "+70747749914"}
0005433642338	2F9F37	0326 382548	ALENA KOMAROVA	{"phone": "+70509030367"}
0005433642339	CD08F0	3366 626606	VIKTOR YAKOVLEV	{"email": "yakovlev.v.071969@postgrespro.ru", "phone": "+70277689327"}
0005433642340	C71E84	5977 340636	NADEZHDA ROMANOVA	{"email": "nadezhda.romanova.041963@postgrespro.ru", "phone": "+70309335915"}
0005433642341	E54843	7874 610678	VALERIY TIMOFEEV	{"phone": "+70372282112"}
0005433642342	E54843	5732 962809	BORIS TIMOFEEV	{"phone": "+70661305812"}
0005433642343	E54843	3168 417298	OLGA ALEKSEEVA	{"phone": "+70802052034"}
0005433642344	2052F5	0517 551818	EVGENIY ZAKHAROV	{"phone": "+70769185901"}
0005433642345	CACF8A	3376 435037	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov-03071970@postgrespro.ru", "phone": "+70864533228"}
0005433642346	CACF8A	0621 838777	DMITRIY NIKITIN	{"email": "d.nikitin.011974@postgrespro.ru", "phone": "+70101590527"}
0005433642347	CACF8A	3033 807470	TATYANA PAVLOVA	{"email": "pavlova.tatyana_15041965@postgrespro.ru", "phone": "+70468380788"}
0005433642348	1769E5	4789 953168	LIDIYA GAVRILOVA	{"email": "gavriloval.19011968@postgrespro.ru", "phone": "+70894238441"}
0005433642349	61166A	7567 993240	PAVEL POPOV	{"email": "popov.pavel-1972@postgrespro.ru", "phone": "+70687533044"}
0005433642350	61166A	2942 622605	DMITRIY MAKAROV	{"email": "dmitriy_makarov.1964@postgrespro.ru", "phone": "+70145232478"}
0005433642351	5E5570	4802 213884	ALEKSANDR ANDREEV	{"phone": "+70456215498"}
0005433642352	0F1906	8010 270525	VERA RODIONOVA	{"phone": "+70446555521"}
0005433642353	FA5BCA	8373 602829	ALEKSANDR SOLOVEV	{"email": "a_solovev.011976@postgrespro.ru", "phone": "+70285225919"}
0005433642354	77F102	8865 190213	MARIYA MIKHAYLOVA	{"email": "mikhaylova_m-26021983@postgrespro.ru", "phone": "+70866370108"}
0005433642355	CEE794	5859 042514	MAKSIM IVANOV	{"email": "m_ivanov.051977@postgrespro.ru", "phone": "+70091958281"}
0005433642356	CEE794	2077 721136	IRINA TITOVA	{"phone": "+70775592179"}
0005433642357	CEE794	8981 816717	VLADIMIR GERASIMOV	{"email": "gerasimovvladimir-081970@postgrespro.ru", "phone": "+70240737031"}
0005433642358	CEE794	8097 077559	OLGA SERGEEVA	{"email": "sergeeva_olga1973@postgrespro.ru", "phone": "+70938880952"}
0005433642359	B717BB	7055 997198	MIKHAIL FROLOV	{"email": "m-frolov-121971@postgrespro.ru", "phone": "+70096907886"}
0005433642360	B717BB	7692 558328	VALENTINA MAKAROVA	{"email": "valentina-makarova.031979@postgrespro.ru", "phone": "+70747003440"}
0005433642361	B717BB	4050 637851	OLESYA KUZMINA	{"phone": "+70932095367"}
0005433642362	7066C2	4777 445315	IVAN VOLKOV	{"phone": "+70565246820"}
0005433642363	C8DE19	9944 637981	ALEKSANDR ALEKSEEV	{"email": "aalekseev.18011977@postgrespro.ru", "phone": "+70215913407"}
0005433642364	A4B24D	6261 825482	OLEG MAKSIMOV	{"phone": "+70284173343"}
0005433642365	41B204	0495 477843	NATALYA EGOROVA	{"email": "egorova-n-071975@postgrespro.ru", "phone": "+70649939573"}
0005433642366	41B204	2024 651031	ALEKSANDRA EGOROVA	{"email": "aleksandraegorova1983@postgrespro.ru", "phone": "+70143877778"}
0005433642367	070D6F	2686 034906	LYUBOV ISAEVA	{"email": "l.isaeva_1971@postgrespro.ru", "phone": "+70980048413"}
0005433642368	070D6F	7566 091507	NATALYA KISELEVA	{"email": "kiseleva_n-011989@postgrespro.ru", "phone": "+70889247162"}
0005433642369	1408D4	9626 708869	NADEZHDA KUZNECOVA	{"email": "n_kuznecova-1958@postgrespro.ru", "phone": "+70444075241"}
0005433642370	1408D4	8410 919282	MAKSIM POPOV	{"phone": "+70162440530"}
0005433642371	0452D4	6088 793706	ALEKSANDR NAUMOV	{"phone": "+70621995037"}
0005433642372	0452D4	8702 542988	ANNA KUZNECOVA	{"email": "kuznecova.anna_07101985@postgrespro.ru", "phone": "+70479747324"}
0005433642373	C32A59	8290 688040	EKATERINA KRASNOVA	{"phone": "+70769058915"}
0005433642374	C32A59	3438 683973	NADEZHDA POTAPOVA	{"phone": "+70650140655"}
0005433642375	14F1BD	5304 847832	PETR MOROZOV	{"email": "morozovpetr.091969@postgrespro.ru", "phone": "+70117144565"}
0005433642376	2EB64D	9189 757781	SERGEY NIKITIN	{"phone": "+70726807267"}
0005433642377	61D93B	8163 950695	SVETLANA SERGEEVA	{"phone": "+70252037690"}
0005433642378	61D93B	3466 648638	MARIYA LAZAREVA	{"email": "lazareva-m_1966@postgrespro.ru", "phone": "+70661764189"}
0005433642379	C99DE2	1847 531153	OLGA NIKOLAEVA	{"email": "o_nikolaeva.20101974@postgrespro.ru", "phone": "+70439826643"}
0005433642380	1535CD	9644 760144	LYUBOV KOZLOVA	{"phone": "+70410230259"}
0005433642381	5C54AE	6683 497497	EVGENIYA MAKAROVA	{"email": "makarova-e-09031983@postgrespro.ru", "phone": "+70478978941"}
0005433642382	61DE38	3612 195626	ALEKSANDRA BOGDANOVA	{"email": "aleksandra-bogdanova_30121973@postgrespro.ru", "phone": "+70984531962"}
0005433642383	61DE38	3512 944515	SVETLANA FILIPPOVA	{"phone": "+70271941062"}
0005433642384	47F18F	5991 333472	SERGEY BARANOV	{"phone": "+70081999214"}
0005433642385	47F18F	1187 562813	VADIM SOROKIN	{"phone": "+70722796352"}
0005433642386	6D15FA	9828 465797	SERGEY EGOROV	{"email": "sergey-egorov_041967@postgrespro.ru", "phone": "+70111549346"}
0005433642387	FFAC61	0325 941677	GENNADIY VOLKOV	{"email": "g.volkov031965@postgrespro.ru", "phone": "+70029822203"}
0005433642388	AFC9BF	1827 073438	NADEZHDA ERMAKOVA	{"email": "ermakova-n-1981@postgrespro.ru", "phone": "+70095614018"}
0005433642389	AFC9BF	4833 728544	PETR ALEKSEEV	{"phone": "+70611824020"}
0005433642390	8BDC0B	3531 562441	YULIYA PETROVA	{"email": "petrova.y_28031972@postgrespro.ru", "phone": "+70536856068"}
0005433642391	848D2B	9874 888316	NIKOLAY MELNIKOV	{"phone": "+70250748586"}
0005433642392	848D2B	3535 517246	AMINA ZHURAVLEVA	{"phone": "+70131647214"}
0005433642393	281756	3595 859920	GALINA ALEKSEEVA	{"phone": "+70015275065"}
0005433642394	D7E321	1759 453838	GENNADIY RODIONOV	{"email": "rodionovg.23071960@postgrespro.ru", "phone": "+70464753486"}
0005433642395	1813BC	5084 942903	NINA FILIPPOVA	{"email": "filippovanina-21051969@postgrespro.ru", "phone": "+70707143712"}
0005433642396	8D492D	5654 547608	LIDIYA BELYAEVA	{"phone": "+70377840517"}
0005433642397	9655F1	0852 066893	ALEKSEY DAVYDOV	{"phone": "+70351519279"}
0005433642398	BED05F	5732 134673	ALEKSANDR GAVRILOV	{"email": "gavrilova_19121961@postgrespro.ru", "phone": "+70267945596"}
0005433642399	676E9B	3838 726509	ANNA ROMANOVA	{"email": "romanovaanna.04031982@postgrespro.ru", "phone": "+70344143585"}
0005433642400	140666	3795 681129	YURIY GAVRILOV	{"phone": "+70610503495"}
0005433642401	140666	0350 662459	ANATOLIY RODIONOV	{"phone": "+70521136564"}
0005433642402	118B26	5507 645009	MARGARITA MOROZOVA	{"email": "morozova-margarita.26021979@postgrespro.ru", "phone": "+70816432975"}
0005433642403	118B26	6272 957768	NADEZHDA TARASOVA	{"email": "n.tarasova.121968@postgrespro.ru", "phone": "+70340475385"}
0005433642404	42A110	2390 451156	LARISA SOROKINA	{"email": "sorokina.l041973@postgrespro.ru", "phone": "+70900411978"}
0005433642405	42A110	4520 018699	IGOR OSIPOV	{"email": "osipov_igor.1973@postgrespro.ru", "phone": "+70396516599"}
0005433642406	9DF0C4	9063 835883	ANASTASIYA VASILEVA	{"email": "anastasiyavasileva_071981@postgrespro.ru", "phone": "+70593069921"}
0005433642407	9DF0C4	0228 629498	EVGENIY DAVYDOV	{"email": "davydove.11031975@postgrespro.ru", "phone": "+70179277875"}
0005433642408	F54021	6869 379703	NIKITA DAVYDOV	{"email": "davydov.nikita-051985@postgrespro.ru", "phone": "+70478057211"}
0005433642409	024DBD	1633 579269	KRISTINA ZHURAVLEVA	{"email": "kristina.zhuravleva29121961@postgrespro.ru", "phone": "+70553183904"}
0005433642410	4C3351	9056 668493	VERA NAZAROVA	{"phone": "+70029800905"}
0005433642411	4C3351	7332 405118	YANINA SOROKINA	{"email": "y-sorokina-05071976@postgrespro.ru", "phone": "+70161872314"}
0005433642412	4F8828	6806 493817	VIKTOR TARASOV	{"email": "tarasov-viktor_121979@postgrespro.ru", "phone": "+70967163825"}
0005433642413	200FFC	1309 210252	LARISA FROLOVA	{"phone": "+70469619131"}
0005433642414	414D23	3557 929421	EKATERINA PAVLOVA	{"email": "e-pavlova-22061970@postgrespro.ru", "phone": "+70543992771"}
0005433642415	E45F34	0921 638663	ANNA PAVLOVA	{"email": "anna-pavlova.031971@postgrespro.ru", "phone": "+70918171739"}
0005433642416	2807C2	9639 062894	STANISLAV SERGEEV	{"phone": "+70706368035"}
0005433642417	E318D4	1776 803690	EVGENIYA KUZNECOVA	{"phone": "+70444525235"}
0005433642418	130BB8	2548 593729	SOFYA MARTYNOVA	{"email": "martynova.s-30121978@postgrespro.ru", "phone": "+70125852857"}
0005433642419	130BB8	3874 295835	ELENA LAZAREVA	{"email": "lazareva_e.081972@postgrespro.ru", "phone": "+70340866463"}
0005433642420	77C54C	3144 089859	IVAN ANDREEV	{"email": "andreevi.1959@postgrespro.ru", "phone": "+70835339715"}
0005433642421	77C54C	5669 509085	ANATOLIY ABRAMOV	{"email": "aabramov.071972@postgrespro.ru", "phone": "+70977726653"}
0005433642422	32058F	1277 971236	NATALYA NIKIFOROVA	{"email": "n-nikiforova_30071967@postgrespro.ru", "phone": "+70841243070"}
0005433642423	1CCF08	2265 018636	LYUDMILA FILIPPOVA	{"email": "filippova.l.111961@postgrespro.ru", "phone": "+70455279841"}
0005433642424	64C126	5358 447502	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav-03101968@postgrespro.ru", "phone": "+70903483036"}
0005433642425	64C126	0027 412070	NATALYA KOLESNIKOVA	{"phone": "+70358151779"}
0005433642426	057DBE	6981 513118	IRINA ZAKHAROVA	{"phone": "+70578205283"}
0005433642427	057DBE	5710 197221	ANTONINA VASILEVA	{"phone": "+70496312697"}
0005433642428	993074	0406 217854	NATALYA KARPOVA	{"email": "karpova.natalya-031974@postgrespro.ru", "phone": "+70211410408"}
0005433642429	993074	7325 554518	EGOR KRASNOV	{"phone": "+70088016855"}
0005433642430	E90C54	6987 815674	VLADISLAV GAVRILOV	{"phone": "+70766262560"}
0005433642431	3E00F0	7513 687842	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr.1968@postgrespro.ru", "phone": "+70107041797"}
0005433642432	51EEC0	5418 821395	RUSTAM MIRONOV	{"email": "r-mironov-1970@postgrespro.ru", "phone": "+70567009766"}
0005433642433	1284EB	9341 039528	LYUDMILA RODIONOVA	{"phone": "+70113115781"}
0005433642434	1284EB	3601 936323	TIMOFEY KRASNOV	{"email": "krasnovtimofey.081971@postgrespro.ru", "phone": "+70565630833"}
0005433642435	B3028F	4415 990438	LYUBOV AFANASEVA	{"phone": "+70676127652"}
0005433642436	B3028F	3370 176239	ARTEM GORBUNOV	{"email": "gorbunov_artem.041973@postgrespro.ru", "phone": "+70860439184"}
0005433642437	00C024	3812 049539	IRINA DMITRIEVA	{"email": "dmitrieva_irina-04011965@postgrespro.ru", "phone": "+70939003002"}
0005433642438	4C6106	9209 549494	MARSEL PETROV	{"phone": "+70218853261"}
0005433642439	EDD789	4706 319464	FEDOR CHERNOV	{"phone": "+70191044982"}
0005433642440	8547EE	1748 747157	TATYANA KONDRATEVA	{"email": "kondratevat.1967@postgrespro.ru", "phone": "+70028227402"}
0005433642441	58FFF4	2160 364241	ANTONINA KUDRYASHOVA	{"phone": "+70888120077"}
0005433642442	DB1EC9	7162 105687	ANDREY KOZLOV	{"phone": "+70088773667"}
0005433642443	DB1EC9	7715 204782	VLADIMIR BARANOV	{"email": "baranov_v.071963@postgrespro.ru", "phone": "+70320553230"}
0005433642444	DB1EC9	1467 484631	ARTEM MOISEEV	{"email": "moiseev.a21021972@postgrespro.ru", "phone": "+70715684590"}
0005433642445	DB1EC9	1091 226414	ALBERT POPOV	{"email": "albertpopov-01101966@postgrespro.ru", "phone": "+70018118585"}
0005433642446	8D00D1	3469 837736	EKATERINA PAVLOVA	{"email": "pavlovae-1972@postgrespro.ru", "phone": "+70696283313"}
0005433642447	00B199	3907 385379	LIDIYA ZAYCEVA	{"phone": "+70273413235"}
0005433642448	A94D8B	5399 221281	TAMARA GUSEVA	{"email": "gusevat-01051963@postgrespro.ru", "phone": "+70097127755"}
0005433642449	561632	7872 773597	EVGENIY GAVRILOV	{"phone": "+70409144384"}
0005433642450	0D25A0	5661 362108	VLADIMIR DENISOV	{"email": "denisov_v_1972@postgrespro.ru", "phone": "+70143362124"}
0005433642451	0D25A0	3146 957116	MAKSIM STEPANOV	{"phone": "+70347181769"}
0005433642452	81ACC1	1823 003254	LYUBOV KOVALEVA	{"phone": "+70427167173"}
0005433642453	01FFD9	9715 757570	ROMAN SIDOROV	{"phone": "+70421443018"}
0005433642454	5E971C	3476 514262	ARTEM FROLOV	{"phone": "+70195925345"}
0005433642455	56BA3E	1448 223454	SERGEY YAKOVLEV	{"email": "yakovlev.sergey101962@postgrespro.ru", "phone": "+70042334625"}
0005433642456	9E92F9	8954 361359	OLGA ALEKSEEVA	{"email": "o.alekseeva031982@postgrespro.ru", "phone": "+70815221114"}
0005433642457	521E21	5357 725683	OLGA GERASIMOVA	{"phone": "+70588612986"}
0005433642458	521E21	6283 119200	ANTON KOZLOV	{"email": "kozlov-anton.071972@postgrespro.ru", "phone": "+70950562831"}
0005433642459	8514EF	0283 083165	ANDREY ALEKSEEV	{"email": "alekseev-a-1963@postgrespro.ru", "phone": "+70934905234"}
0005433642460	18F828	8537 134787	ROMAN EGOROV	{"phone": "+70501327265"}
0005433642461	18F828	1756 334413	LARISA YAKOVLEVA	{"email": "yakovleva.l.031960@postgrespro.ru", "phone": "+70474439202"}
0005433642462	4C9FC3	4352 372104	ANATOLIY GAVRILOV	{"phone": "+70571356214"}
0005433642463	4C9FC3	2319 666804	SERGEY KUDRYASHOV	{"email": "s_kudryashov.19071970@postgrespro.ru", "phone": "+70150047723"}
0005433642464	90A686	0322 296876	NADEZHDA NIKIFOROVA	{"email": "n.nikiforova_06121976@postgrespro.ru", "phone": "+70364432145"}
0005433642465	0A6B7F	1129 706493	ANASTASIYA ZOTOVA	{"phone": "+70475528305"}
0005433642466	0A6B7F	2932 906457	ANASTASIYA EFIMOVA	{"phone": "+70614985162"}
0005433642467	1B7402	4359 198430	LYUBOV MELNIKOVA	{"email": "melnikova.lyubov091964@postgrespro.ru", "phone": "+70216468898"}
0005433642468	1B7402	7124 055150	SERGEY ILIN	{"email": "sergey_ilin-061973@postgrespro.ru", "phone": "+70994737331"}
0005433642469	629B3E	4249 844266	ALEKSEY KOZLOV	{"email": "aleksey_kozlov.10041970@postgrespro.ru", "phone": "+70409080712"}
0005433642470	108E00	5620 339012	ELENA BELYAEVA	{"phone": "+70629147753"}
0005433642471	51A3C8	6357 060380	SERGEY AFANASEV	{"email": "afanasev-s18041979@postgrespro.ru", "phone": "+70211559911"}
0005433642472	595B01	2903 806208	VLADIMIR ALEKSANDROV	{"email": "valeksandrov_14061978@postgrespro.ru", "phone": "+70509365788"}
0005433642473	595B01	3866 759471	VALERIY GRIGOREV	{"phone": "+70125993112"}
0005433642474	8A6015	6430 278239	TATYANA KOMAROVA	{"email": "tatyana_komarova-061977@postgrespro.ru", "phone": "+70448478955"}
0005433642475	8A6015	7236 703090	VIKTORIYA ABRAMOVA	{"email": "abramova_viktoriya_21121970@postgrespro.ru", "phone": "+70799470859"}
0005433642476	93A5AE	4089 414665	ALEKSEY SERGEEV	{"phone": "+70771588114"}
0005433642477	BCFFC3	5395 846136	GALINA NAUMOVA	{"email": "naumova-g_1969@postgrespro.ru", "phone": "+70810490799"}
0005433642478	BCFFC3	4641 520727	NINA MAKAROVA	{"phone": "+70760485635"}
0005433642479	5C0D75	0972 992159	MAKSIM CHERNOV	{"email": "chernov-maksim1969@postgrespro.ru", "phone": "+70845868482"}
0005433642480	749898	5896 437485	ARTEM ZHURAVLEV	{"email": "artemzhuravlev31051964@postgrespro.ru", "phone": "+70544198053"}
0005433642481	FCC755	2776 937390	SVETLANA ROMANOVA	{"phone": "+70845445578"}
0005433642482	FCC755	0830 469294	TATYANA DAVYDOVA	{"email": "t-davydova-051969@postgrespro.ru", "phone": "+70478329045"}
0005433642483	DB41BF	0753 864924	PAVEL DAVYDOV	{"phone": "+70176434012"}
0005433642484	DB41BF	7621 987861	NATALIYA EGOROVA	{"phone": "+70502250915"}
0005433642485	13E024	0867 636225	IRINA MEDVEDEVA	{"email": "medvedeva-irina_1979@postgrespro.ru", "phone": "+70181706345"}
0005433642486	B8F6E2	5544 822252	NIKOLAY ANTONOV	{"phone": "+70402992754"}
0005433642487	2E7E90	3856 543296	KONSTANTIN KULIKOV	{"email": "k-kulikov-091965@postgrespro.ru", "phone": "+70377378716"}
0005433642488	55B56D	2038 545690	IRINA SERGEEVA	{"email": "sergeevairina_1975@postgrespro.ru", "phone": "+70622642420"}
0005433642489	A11736	4315 796551	YULIYA ROMANOVA	{"phone": "+70417573372"}
0005433642491	713E7D	8622 965509	VALERIY POPOV	{"email": "v.popov-23121964@postgrespro.ru", "phone": "+70729828380"}
0005433642492	713E7D	4012 128275	SERGEY KUZNECOV	{"email": "sergey-kuznecov-29071966@postgrespro.ru", "phone": "+70106716054"}
0005433642493	713E7D	6435 404923	ARTEM BORISOV	{"email": "aborisov27091968@postgrespro.ru", "phone": "+70549666084"}
0005433642494	3801B8	6723 494255	SERGEY ALEKSEEV	{"email": "sergeyalekseev-04121973@postgrespro.ru", "phone": "+70392389082"}
0005433642495	3801B8	0214 051753	TATYANA ALEKSEEVA	{"email": "alekseeva-t14101970@postgrespro.ru", "phone": "+70115905740"}
0005433642496	6D6F4F	8010 947074	VIKTOR SERGEEV	{"phone": "+70279115189"}
0005433642497	6D6F4F	6559 912130	NIKOLAY ROMANOV	{"phone": "+70759428984"}
0005433642498	712803	7316 755104	VERA FADEEVA	{"email": "vera.fadeeva1972@postgrespro.ru", "phone": "+70863518094"}
0005433642499	FCA502	5815 690616	VALERIY KUZNECOV	{"phone": "+70102206062"}
0005433642500	DAEF86	9130 007125	IVAN FEDOROV	{"email": "ivanfedorov.081977@postgrespro.ru", "phone": "+70928949196"}
0005433642501	8215F0	0583 508890	VALENTIN EGOROV	{"email": "v-egorov_17071971@postgrespro.ru", "phone": "+70530763479"}
0005433642502	8215F0	3986 186653	EVGENIY SOROKIN	{"phone": "+70274626967"}
0005433642503	84CA87	2266 478068	IRINA MAKAROVA	{"phone": "+70967370500"}
0005433642504	070198	6866 719585	KRISTINA NIKIFOROVA	{"phone": "+70634484261"}
0005433642505	CE99F4	7830 014791	SVETLANA NOVIKOVA	{"email": "svetlana.novikova041957@postgrespro.ru", "phone": "+70561582745"}
0005433642506	82426F	3443 302516	OLGA IVANOVA	{"email": "olga_ivanova.12061970@postgrespro.ru", "phone": "+70233498911"}
0005433642507	82426F	1428 280675	IVAN IVANOV	{"email": "ivanovi.17111972@postgrespro.ru", "phone": "+70499817387"}
0005433642508	2F74C8	8341 305873	ROMAN CHERNOV	{"email": "romanchernov-081979@postgrespro.ru", "phone": "+70964250200"}
0005433642509	2F74C8	7050 183719	EVGENIYA FROLOVA	{"email": "frolova_e.26071978@postgrespro.ru", "phone": "+70046859315"}
0005433642510	67FD38	1013 356853	ALEKSANDR VASILEV	{"phone": "+70596363730"}
0005433642511	F3FB42	6376 789943	KLAVDIYA FILIPPOVA	{"email": "k.filippova1974@postgrespro.ru", "phone": "+70828345561"}
0005433642512	087A3B	2580 298154	DMITRIY NIKOLAEV	{"phone": "+70398466229"}
0005433642513	920436	7333 118766	ANASTASIYA SOKOLOVA	{"email": "anastasiya.sokolova_1958@postgrespro.ru", "phone": "+70665455139"}
0005433642514	5B8732	6157 765502	SERGEY MARTYNOV	{"phone": "+70025974055"}
0005433642515	A200B6	3173 433318	TAMARA POLYAKOVA	{"email": "tamara.polyakova1967@postgrespro.ru", "phone": "+70187440562"}
0005433642516	F1140F	6910 586980	SOFIYA MAKAROVA	{"phone": "+70560175034"}
0005433642517	F1140F	7447 694070	SERGEY SERGEEV	{"email": "sergey_sergeev1968@postgrespro.ru", "phone": "+70959475446"}
0005433642518	F4BEEF	5274 719014	MATVEY MELNIKOV	{"phone": "+70833892602"}
0005433642519	9D3B90	9752 413313	ANDREY MOROZOV	{"phone": "+70743879947"}
0005433642520	5B4584	9036 614228	TAMARA MASLOVA	{"email": "maslova_tamara_1982@postgrespro.ru", "phone": "+70424614562"}
0005433642521	5579DC	0228 411125	VITALIY FEDOROV	{"phone": "+70867700910"}
0005433642522	1E5464	9360 120930	ALEKSEY ROMANOV	{"email": "a.romanov_02111971@postgrespro.ru", "phone": "+70952350556"}
0005433642523	1E5464	2964 042563	ALEKSANDR OSIPOV	{"email": "osipov_a-1976@postgrespro.ru", "phone": "+70136463748"}
0005433642524	A7FE4D	8157 103239	KARINA ROMANOVA	{"phone": "+70589874391"}
0005433642525	A7FE4D	7494 625324	EVGENIY EGOROV	{"email": "egorovevgeniy.1961@postgrespro.ru", "phone": "+70221463568"}
0005433642526	3563F7	6415 766012	EVGENIY POPOV	{"phone": "+70410305044"}
0005433642527	3563F7	5371 928236	ALENA FILIPPOVA	{"phone": "+70055170120"}
0005433642528	A02787	6979 798305	TAISIYA VOLKOVA	{"phone": "+70474831048"}
0005433642529	09CC57	6133 205158	PAVEL ROMANOV	{"email": "romanov_p-03021970@postgrespro.ru", "phone": "+70567080874"}
0005433642530	F44CE1	8939 447556	NATALYA MOROZOVA	{"email": "morozova_natalya-28011964@postgrespro.ru", "phone": "+70251541444"}
0005433642531	F44CE1	8969 946796	KIRILL FOMIN	{"email": "kirill-fomin.121976@postgrespro.ru", "phone": "+70336978877"}
0005433642532	DBCA48	4454 858336	LYUBOV VLASOVA	{"email": "vlasovalyubov_23081969@postgrespro.ru", "phone": "+70966047951"}
0005433642533	DBCA48	7186 879582	MIKHAIL MARTYNOV	{"phone": "+70987771027"}
0005433642534	7707B4	9218 993948	EVDOKIYA ILINA	{"email": "eilina.1973@postgrespro.ru", "phone": "+70772044692"}
0005433642535	7707B4	6435 035498	EVGENIYA SMIRNOVA	{"phone": "+70248772215"}
0005433642536	8A7493	1483 187856	YULIYA PETROVA	{"email": "petrovay1967@postgrespro.ru", "phone": "+70820046497"}
0005433642537	CFD54E	7342 074610	ALEKSANDR TARASOV	{"phone": "+70721973282"}
0005433642538	3DA4D8	3700 677544	ALINA KOROLEVA	{"phone": "+70577992675"}
0005433642539	B2C878	6477 533162	ANASTASIYA ROMANOVA	{"phone": "+70250111059"}
0005433642540	7CD8E7	5460 381050	ANNA SAVELEVA	{"email": "saveleva.anna051970@postgrespro.ru", "phone": "+70642442276"}
0005433642541	4A077C	9426 175746	MAKSIM NAZAROV	{"phone": "+70986249034"}
0005433642542	420BC4	3285 838117	TAMARA IVANOVA	{"phone": "+70588797392"}
0005433642543	D74587	7383 592885	GENNADIY MAKAROV	{"email": "makarovg_1966@postgrespro.ru", "phone": "+70951507892"}
0005433642544	D74587	1505 655184	YURIY VOLKOV	{"phone": "+70601181937"}
0005433642545	D74587	5582 308909	NADEZHDA OVCHINNIKOVA	{"phone": "+70671230596"}
0005433642546	A75FA5	4394 936543	ZINAIDA PAVLOVA	{"phone": "+70839082673"}
0005433642547	CC4904	0886 869335	TATYANA IVANOVA	{"email": "t-ivanova_051962@postgrespro.ru", "phone": "+70715421580"}
0005433642548	CC4904	0056 398947	MARAT ANDREEV	{"phone": "+70904883421"}
0005433642549	3B2A95	6517 021634	VYACHESLAV ISAEV	{"email": "v_isaev-1981@postgrespro.ru", "phone": "+70016813607"}
0005433642550	E91B15	3856 584014	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir_12081969@postgrespro.ru", "phone": "+70022983768"}
0005433642551	54BEB7	9814 939016	SOFIYA GERASIMOVA	{"email": "s-gerasimova-18011966@postgrespro.ru", "phone": "+70280806921"}
0005433642552	54BEB7	2150 808525	ALFIYA POPOVA	{"email": "popova.alfiya.1983@postgrespro.ru", "phone": "+70420775762"}
0005433642553	5EFC60	0718 340713	ALENA IVANOVA	{"email": "alena_ivanova.09121968@postgrespro.ru", "phone": "+70354370983"}
0005433642554	5EFC60	5960 962695	NIKOLAY SIDOROV	{"email": "nikolaysidorov23051974@postgrespro.ru", "phone": "+70740996995"}
0005433642555	BCF8EF	0240 961877	ALEKSANDR MIKHAYLOV	{"phone": "+70893238237"}
0005433642556	BCF8EF	6224 144889	OLEG MEDVEDEV	{"email": "medvedevo.1969@postgrespro.ru", "phone": "+70315468630"}
0005433642557	641216	8367 263158	ARINA KULIKOVA	{"phone": "+70369784354"}
0005433642558	2683B9	2511 538362	NADEZHDA POTAPOVA	{"email": "nadezhdapotapova16071963@postgrespro.ru", "phone": "+70938477664"}
0005433642559	7C9772	8991 140454	PAVEL POPOV	{"email": "popovpavel_061976@postgrespro.ru", "phone": "+70745107974"}
0005433642560	7C9772	8545 287268	VLADIMIR KUDRYASHOV	{"email": "kudryashov_vladimir25081973@postgrespro.ru", "phone": "+70037034538"}
0005433642561	4D1F4B	8662 101550	NATALYA FROLOVA	{"phone": "+70516891649"}
0005433642562	4D1F4B	0959 644870	SVETLANA MASLOVA	{"email": "maslovasvetlana-041977@postgrespro.ru", "phone": "+70946893188"}
0005433642563	8E509F	4680 778525	INNA NIKITINA	{"email": "inna.nikitina-27011974@postgrespro.ru", "phone": "+70050898600"}
0005433642564	8E509F	6404 310237	LYUDMILA KUZNECOVA	{"email": "lkuznecova1970@postgrespro.ru", "phone": "+70214836462"}
0005433642565	8E509F	2962 706586	YAROSLAV GERASIMOV	{"email": "gerasimovy-1979@postgrespro.ru", "phone": "+70231205805"}
0005433642566	62F05B	2384 140028	VITALIY KUZNECOV	{"email": "vitaliy-kuznecov.051969@postgrespro.ru", "phone": "+70018689482"}
0005433642567	54F6C3	3421 948991	ALBINA VOLKOVA	{"email": "a-volkova-091970@postgrespro.ru", "phone": "+70960784215"}
0005433642568	54F6C3	8548 934801	VIKTOR MEDVEDEV	{"phone": "+70783276130"}
0005433642569	F55AF2	7320 220412	GALINA MIRONOVA	{"phone": "+70868205362"}
0005433642570	F55AF2	6096 908704	SERGEY VLASOV	{"email": "sergey_vlasov.07091969@postgrespro.ru", "phone": "+70329128537"}
0005433642571	10EDA9	8600 092025	NINA RODIONOVA	{"email": "rodionova-n.05031979@postgrespro.ru", "phone": "+70598909174"}
0005433642572	10EDA9	7722 005578	VERA PAVLOVA	{"phone": "+70109072260"}
0005433642573	F45BF2	6670 775610	OKSANA BARANOVA	{"email": "oksana-baranova.031960@postgrespro.ru", "phone": "+70536864495"}
0005433642574	F45BF2	7621 289489	EVGENIY MELNIKOV	{"phone": "+70427354867"}
0005433642575	E857E5	1986 375630	NIKOLAY SAVELEV	{"email": "savelev_nikolay_111982@postgrespro.ru", "phone": "+70974062114"}
0005433642576	E857E5	2409 520181	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova-081978@postgrespro.ru", "phone": "+70631976918"}
0005433642577	47A05C	2178 691968	ZINAIDA NIKOLAEVA	{"phone": "+70491415150"}
0005433642578	996A23	7767 421860	RAISA TIMOFEEVA	{"phone": "+70108193647"}
0005433642579	45B02C	5215 224352	TATYANA CHERNOVA	{"email": "tatyana.chernova-13031968@postgrespro.ru", "phone": "+70756644419"}
0005433642580	45B02C	1837 260328	NATALYA KOROLEVA	{"phone": "+70488942251"}
0005433642581	88968A	9886 733824	ALEKSANDR SEMENOV	{"phone": "+70604682788"}
0005433642582	9F26F1	3824 067739	OKSANA FADEEVA	{"phone": "+70820871423"}
0005433642583	B111B1	1409 453463	ELENA MAKAROVA	{"phone": "+70130950477"}
0005433642584	B111B1	7453 628660	ANATOLIY MELNIKOV	{"email": "a.melnikov-24091966@postgrespro.ru", "phone": "+70393951304"}
0005433642585	C09A05	0597 003392	LIDIYA POPOVA	{"email": "popova_lidiya-011972@postgrespro.ru", "phone": "+70544146462"}
0005433642586	2991AB	6812 049996	MAKSIM GORBUNOV	{"email": "maksim-gorbunov-1969@postgrespro.ru", "phone": "+70307407941"}
0005433642587	E6867A	1641 280803	IRINA SMIRNOVA	{"phone": "+70222171390"}
0005433642588	E6867A	5895 487765	VERA ROMANOVA	{"email": "vera_romanova-06101973@postgrespro.ru", "phone": "+70647797346"}
0005433642589	701825	2470 918319	ALEKSEY ROMANOV	{"phone": "+70160321852"}
0005433642590	6610FD	0465 689477	ALEKSEY NIKOLAEV	{"phone": "+70997334423"}
0005433642591	C8A9E5	7117 504435	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev011967@postgrespro.ru", "phone": "+70668264796"}
0005433642592	3C6DF0	3373 519463	GENNADIY KONOVALOV	{"email": "konovalov.gennadiy-1970@postgrespro.ru", "phone": "+70986827913"}
0005433642593	771340	7486 348365	LYUBOV POPOVA	{"email": "lyubovpopova.041972@postgrespro.ru", "phone": "+70630143251"}
0005433642594	771340	0795 873791	ELENA KULIKOVA	{"email": "e.kulikova.17081957@postgrespro.ru", "phone": "+70539064515"}
0005433642595	B5D9C3	3975 744038	GALINA VOROBEVA	{"email": "vorobevagalina-021973@postgrespro.ru", "phone": "+70992607002"}
0005433642596	8768E9	4214 420429	DMITRIY SIDOROV	{"phone": "+70341494154"}
0005433642597	B6BA65	1660 813639	MIKHAIL ISAEV	{"phone": "+70558297279"}
0005433642598	990336	1404 142704	NINA NIKOLAEVA	{"email": "nikolaeva.n021967@postgrespro.ru", "phone": "+70542349980"}
0005433642599	990336	0138 642249	SERGEY POPOV	{"phone": "+70712235251"}
0005433642600	990336	4315 870572	LYUBOV EFREMOVA	{"email": "lyubov_efremova.17021977@postgrespro.ru", "phone": "+70722605097"}
0005433642601	633C7C	9634 225627	IRINA NIKIFOROVA	{"email": "i_nikiforova-041970@postgrespro.ru", "phone": "+70296039259"}
0005433642602	ECBD9C	6890 216798	VLADIMIR YAKOVLEV	{"phone": "+70785321897"}
0005433642603	76A1C5	9729 603717	VALERIY VASILEV	{"email": "vasilevvaleriy.1972@postgrespro.ru", "phone": "+70385271744"}
0005433642604	17320B	9523 254071	NIKOLAY MEDVEDEV	{"email": "medvedev-n121961@postgrespro.ru", "phone": "+70824249981"}
0005433642605	17320B	6970 463356	ALEKSEY ORLOV	{"phone": "+70276958721"}
0005433642606	BD05B7	3063 281013	ALEKSEY MELNIKOV	{"phone": "+70537953590"}
0005433642607	B909E6	3037 506242	ANATOLIY MIRONOV	{"email": "mironov.anatoliy_051979@postgrespro.ru", "phone": "+70078904990"}
0005433642608	B909E6	4050 195690	PAVEL MEDVEDEV	{"email": "medvedev.pavel081973@postgrespro.ru", "phone": "+70518772638"}
0005433642609	7A05EC	9260 781169	SVETLANA NIKIFOROVA	{"phone": "+70477926890"}
0005433642610	21AA76	5415 612712	ILYA MAKAROV	{"phone": "+70807715274"}
0005433642611	21AA76	0534 932301	STANISLAV ILIN	{"phone": "+70539633403"}
0005433642612	E1221F	4392 582020	NATALYA SERGEEVA	{"phone": "+70287307366"}
0005433642613	8B9301	6875 446276	VLADIMIR ALEKSANDROV	{"phone": "+70392856586"}
0005433642614	D50044	2573 613419	RAFAEL SAVELEV	{"phone": "+70831706857"}
0005433642615	D50044	9689 909739	STANISLAV TARASOV	{"email": "stanislavtarasov-1968@postgrespro.ru", "phone": "+70475353944"}
0005433642616	F15FC8	9591 655754	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.nadezhda_08051972@postgrespro.ru", "phone": "+70754934660"}
0005433642617	0B552B	4795 565353	YULIYA KUZNECOVA	{"email": "kuznecova.yuliya.1973@postgrespro.ru", "phone": "+70598546257"}
0005433642618	A61083	4369 902660	GALINA KUZNECOVA	{"email": "kuznecova-g-031967@postgrespro.ru", "phone": "+70943629115"}
0005433642619	F4EA44	9879 290802	DENIS YAKOVLEV	{"email": "dyakovlev.05071975@postgrespro.ru", "phone": "+70527372090"}
0005433642620	B098EA	8858 816015	ZINAIDA IVANOVA	{"phone": "+70796032475"}
0005433642621	71BDFC	7697 186114	ANASTASIYA KUZNECOVA	{"phone": "+70517200860"}
0005433642622	71BDFC	8894 417008	LYUBOV IVANOVA	{"email": "ivanova_l.081970@postgrespro.ru", "phone": "+70590582215"}
0005433642623	A54DF9	1462 735392	GALINA MOROZOVA	{"email": "morozova_g-051969@postgrespro.ru", "phone": "+70798376605"}
0005433642624	1C96C6	9704 741631	DENIS POPOV	{"email": "popov_d1966@postgrespro.ru", "phone": "+70858479388"}
0005433642625	1C96C6	2030 267483	LARISA KOROLEVA	{"phone": "+70120217800"}
0005433642626	F310BB	5367 837830	ALLA IVANOVA	{"email": "ivanova-alla_041986@postgrespro.ru", "phone": "+70953437318"}
0005433642627	F310BB	1197 067418	OLGA KISELEVA	{"phone": "+70685921875"}
0005433642628	FB52B1	5899 863497	ALEKSEY BELOV	{"email": "belov_aleksey-30031959@postgrespro.ru", "phone": "+70602432356"}
0005433642629	BC7897	6439 885255	VALENTINA IVANOVA	{"phone": "+70784340418"}
0005433642630	5AF2B4	3070 283262	NIKOLAY FEDOROV	{"email": "fedorov-n15121964@postgrespro.ru", "phone": "+70825193875"}
0005433642631	DB6F75	5679 072168	YURIY VASILEV	{"phone": "+70098199089"}
0005433642632	DBEA2A	7916 482619	RINAT BONDARENKO	{"email": "rinat-bondarenko_19061973@postgrespro.ru", "phone": "+70866974191"}
0005433642633	718F30	6917 637821	LILIYA DANILOVA	{"phone": "+70796676154"}
0005433642634	241F96	4707 285149	RUSLAN GERASIMOV	{"phone": "+70556023417"}
0005433642635	241F96	4212 691060	YULIYA FEDOROVA	{"phone": "+70886896751"}
0005433642636	241F96	1617 451647	ALEKSANDR SOKOLOV	{"email": "a.sokolov111970@postgrespro.ru", "phone": "+70757811561"}
0005433642637	8D7D54	7566 700089	VYACHESLAV NIKITIN	{"email": "nikitin-v.29121961@postgrespro.ru", "phone": "+70348901760"}
0005433642638	477577	3395 302276	DMITRIY NOVIKOV	{"phone": "+70143764847"}
0005433642639	6F621A	3207 549123	VALERIY IVANOV	{"email": "v_ivanov_011972@postgrespro.ru", "phone": "+70862157132"}
0005433642640	F4E7A1	4531 094829	GALINA MAKAROVA	{"phone": "+70447161131"}
0005433642641	484C85	4928 766680	EVGENIY ZHUKOV	{"phone": "+70763287487"}
0005433642642	D7A9EE	7009 228004	VITALIY MARTYNOV	{"phone": "+70636365406"}
0005433642643	EDBA07	9450 999627	NIKOLAY VASILEV	{"email": "n.vasilev_101970@postgrespro.ru", "phone": "+70661098273"}
0005433642644	C66300	3407 519710	GEORGIY GAVRILOV	{"phone": "+70777833276"}
0005433642645	E054F3	4884 637344	TATYANA EGOROVA	{"email": "tegorova-081981@postgrespro.ru", "phone": "+70789125759"}
0005433642646	E054F3	8487 221045	ANNA VOLKOVA	{"email": "avolkova_081977@postgrespro.ru", "phone": "+70961089386"}
0005433642647	789855	1645 296334	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr_02121966@postgrespro.ru", "phone": "+70807307835"}
0005433642648	789855	2541 429073	ILYA SHEVCHENKO	{"phone": "+70581623332"}
0005433642649	86B118	9942 839722	EVGENIY MOROZOV	{"phone": "+70860957092"}
0005433642650	86B118	4779 452840	KIRILL MEDVEDEV	{"phone": "+70830888839"}
0005433642651	EFABB8	4878 161373	ALEKSANDRA DENISOVA	{"phone": "+70623297049"}
0005433642652	EFABB8	0666 684984	EVGENIYA ORLOVA	{"email": "evgeniya-orlova.121975@postgrespro.ru", "phone": "+70278388083"}
0005433642653	9BBFF9	2525 129533	MARINA AKIMOVA	{"email": "akimovamarina06121969@postgrespro.ru", "phone": "+70641727225"}
0005433642654	2A683B	6646 535364	OLGA EGOROVA	{"email": "olga.egorova041981@postgrespro.ru", "phone": "+70461069650"}
0005433642655	C3E7BE	6487 476306	LYUBOV OSIPOVA	{"email": "osipova_l.061969@postgrespro.ru", "phone": "+70229974562"}
0005433642656	9B75BC	9720 397317	MADINA KRASNOVA	{"phone": "+70606797596"}
0005433642657	33859D	3348 814542	VALENTINA IVANOVA	{"phone": "+70338772146"}
0005433642658	712E31	4142 403463	MIKHAIL NOVIKOV	{"email": "novikov.m-021973@postgrespro.ru", "phone": "+70843400299"}
0005433642659	712E31	9717 588557	IVAN AFANASEV	{"email": "afanasev_ivan_1972@postgrespro.ru", "phone": "+70616104886"}
0005433642660	61C28A	2742 372262	ZHANNA LAZAREVA	{"email": "lazareva-zhanna-04101968@postgrespro.ru", "phone": "+70771909292"}
0005433642661	61C28A	8157 241883	ANDREY GRIGOREV	{"phone": "+70295449460"}
0005433642662	E7BBDA	0123 247267	TATYANA ZHURAVLEVA	{"phone": "+70877099443"}
0005433642663	75E666	3791 086158	YURIY DMITRIEV	{"phone": "+70253334841"}
0005433642664	75E666	8639 946273	OLEG NAUMOV	{"phone": "+70550298106"}
0005433642665	0A5A91	4086 238849	BORIS KOROLEV	{"phone": "+70471140639"}
0005433642666	2F0081	5317 504906	SERGEY NAZAROV	{"email": "nazarov_s_16071971@postgrespro.ru", "phone": "+70132137015"}
0005433642667	2F0081	6468 923491	EKATERINA DENISOVA	{"phone": "+70762684989"}
0005433642668	A0BD93	6021 621521	GRIGORIY SEMENOV	{"email": "semenovgrigoriy.1963@postgrespro.ru", "phone": "+70178834347"}
0005433642669	55BD66	9613 898846	DMITRIY BELOV	{"email": "belov-d.08061975@postgrespro.ru", "phone": "+70350899819"}
0005433642670	4BF00F	7508 290368	ELENA KOVALEVA	{"email": "elenakovaleva23111969@postgrespro.ru", "phone": "+70274774970"}
0005433642671	00DC94	8237 968510	VIKTOR ANDREEV	{"phone": "+70008674700"}
0005433642672	00DC94	1239 006848	NINA BOGDANOVA	{"phone": "+70615591539"}
0005433642673	E4897F	3828 175089	SHAVKAT SERGEEV	{"email": "shavkat_sergeev_24051982@postgrespro.ru", "phone": "+70209082799"}
0005433642674	4BAB6E	0890 291234	TATYANA OSIPOVA	{"email": "osipova_tatyana-071970@postgrespro.ru", "phone": "+70731071190"}
0005433642675	4B0AA4	5384 029103	ANATOLIY ILIN	{"email": "ilinanatoliy1965@postgrespro.ru", "phone": "+70013283447"}
0005433642676	5AD51E	8524 664175	VENERA SMIRNOVA	{"email": "venera.smirnova.1976@postgrespro.ru", "phone": "+70577741388"}
0005433642677	7AC5D0	2436 872974	ANASTASIYA VLASOVA	{"email": "vlasovaanastasiya.1964@postgrespro.ru", "phone": "+70311571844"}
0005433642678	7AC5D0	8045 922949	ELENA FROLOVA	{"phone": "+70169567758"}
0005433642679	31EA29	5399 738611	NADEZHDA KUDRYASHOVA	{"phone": "+70448821652"}
0005433642680	2EB9CC	7497 209951	ALEKSEY KUZNECOV	{"phone": "+70130406229"}
0005433642681	5B98EF	1753 557786	ELIZAVETA DANILOVA	{"email": "danilova-elizaveta-1970@postgrespro.ru", "phone": "+70753347952"}
0005433642682	B279C4	3449 726042	TATYANA VLASOVA	{"email": "vlasova.tatyana-1966@postgrespro.ru", "phone": "+70904735007"}
0005433642683	6A7DC3	2054 791966	NADEZHDA VASILEVA	{"email": "nvasileva.01101982@postgrespro.ru", "phone": "+70611896575"}
0005433642684	6A7DC3	6937 995794	TAMARA DANILOVA	{"phone": "+70651832818"}
0005433642685	6A7DC3	9746 866117	OLGA BELOVA	{"phone": "+70992388078"}
0005433642686	8D6E52	3132 177783	ALEKSANDR ALEKSEEV	{"email": "a.alekseev.18041986@postgrespro.ru", "phone": "+70365894547"}
0005433642687	8D6E52	4843 756420	TATYANA SAVELEVA	{"email": "t_saveleva_18031972@postgrespro.ru", "phone": "+70457672223"}
0005433642688	58B297	6627 537567	MAKSIM KARPOV	{"phone": "+70227121940"}
0005433642689	CBAE88	2998 812129	RAISA ZAKHAROVA	{"phone": "+70622813505"}
0005433642690	A687D0	7800 500640	ALINA ERMAKOVA	{"phone": "+70651570487"}
0005433642691	E1DCB6	2647 051846	TAISIYA SIDOROVA	{"phone": "+70383119673"}
0005433642692	9C2096	8158 072804	ANDREY ALEKSEEV	{"phone": "+70772101068"}
0005433642693	492E4B	2943 168762	IGOR EGOROV	{"email": "igoregorov061975@postgrespro.ru", "phone": "+70011022524"}
0005433642694	36C103	0553 800894	VLADIMIR MELNIKOV	{"email": "melnikov_vladimir.071969@postgrespro.ru", "phone": "+70266792549"}
0005433642695	36C103	0061 939061	DANIIL POPOV	{"phone": "+70641198975"}
0005433642696	36C103	8006 572402	STANISLAV CHERNOV	{"email": "chernov_stanislav111977@postgrespro.ru", "phone": "+70649944058"}
0005433642697	36C103	4600 818412	ANASTASIYA VASILEVA	{"email": "vasileva-anastasiya.04071980@postgrespro.ru", "phone": "+70966482973"}
0005433642698	BC3979	9654 125229	ALEKSANDR IVANOV	{"phone": "+70325823787"}
0005433642699	D43EDA	3108 889757	KIRILL VOLKOV	{"email": "volkov-k_1969@postgrespro.ru", "phone": "+70630078041"}
0005433642700	656010	3638 196294	YULIYA VOLKOVA	{"email": "y.volkova1980@postgrespro.ru", "phone": "+70237040116"}
0005433642701	CE79CF	8925 510466	DARYA NIKIFOROVA	{"phone": "+70454444328"}
0005433642702	B32834	8503 749950	SVETLANA TROFIMOVA	{"email": "trofimova.s.1981@postgrespro.ru", "phone": "+70492477477"}
0005433642703	42A7A0	1721 166687	YULIYA ERMAKOVA	{"email": "ermakova.yuliya.1974@postgrespro.ru", "phone": "+70123291001"}
0005433642704	42A7A0	6227 306485	LARISA KONOVALOVA	{"email": "konovaloval_061970@postgrespro.ru", "phone": "+70457194095"}
0005433642705	CCA885	4552 647129	SVETLANA FILATOVA	{"phone": "+70478308087"}
0005433642706	B554A4	4201 997837	VLADIMIR SAVELEV	{"email": "vsavelev24051974@postgrespro.ru", "phone": "+70622011793"}
0005433642707	B554A4	3963 319139	OLGA ROMANOVA	{"email": "romanovaolga-091976@postgrespro.ru", "phone": "+70192845061"}
0005433642708	AC3B2E	7934 493252	GENNADIY MIKHAYLOV	{"email": "gennadiy.mikhaylov-121979@postgrespro.ru", "phone": "+70078386950"}
0005433642709	0F67A8	4373 383470	NATALYA TIMOFEEVA	{"email": "timofeevan1967@postgrespro.ru", "phone": "+70989722587"}
0005433642710	BFAA22	9191 063881	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir.12081966@postgrespro.ru", "phone": "+70278350905"}
0005433642711	BFAA22	2920 836048	EKATERINA GAVRILOVA	{"phone": "+70394906881"}
0005433642712	BFAA22	5008 998273	IRINA FEDOROVA	{"phone": "+70325288258"}
0005433642713	153037	8472 415357	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova-1970@postgrespro.ru", "phone": "+70452562937"}
0005433642714	FE4592	2899 971396	DMITRIY KONOVALOV	{"phone": "+70482048435"}
0005433642715	324540	5089 891076	IRINA EFREMOVA	{"email": "irina_efremova-18081966@postgrespro.ru", "phone": "+70557994984"}
0005433642716	324540	1949 215215	IVAN ROMANOV	{"email": "romanov-ivan021973@postgrespro.ru", "phone": "+70950214522"}
0005433642717	8F1896	1097 375811	SEMEN KRASNOV	{"phone": "+70866191966"}
0005433642718	2C1DFC	6196 300414	VIOLETTA KONOVALOVA	{"phone": "+70763198337"}
0005433642719	2C1DFC	9789 737798	ANATOLIY MELNIKOV	{"email": "anatoliy_melnikov10051968@postgrespro.ru", "phone": "+70257880446"}
0005433642720	D6C221	6523 947511	YANA TARASOVA	{"email": "tarasova.y_30091971@postgrespro.ru", "phone": "+70694620720"}
0005433642721	4C8469	0170 722463	VERA KARPOVA	{"phone": "+70745519724"}
0005433642722	1F0F63	5368 556625	VLADIMIR OSIPOV	{"email": "osipov_v1965@postgrespro.ru", "phone": "+70367262711"}
0005433642723	1F0F63	4329 445807	ELENA LUKYANOVA	{"phone": "+70211949732"}
0005433642724	2697D0	4412 985525	VLADIMIR KARPOV	{"phone": "+70251950728"}
0005433642725	F01762	3703 474913	EKATERINA FILIPPOVA	{"email": "ekaterina.filippova.25051976@postgrespro.ru", "phone": "+70872089567"}
0005433642726	F01762	8837 380261	SVETLANA BELYAEVA	{"email": "belyaevas-091971@postgrespro.ru", "phone": "+70302322128"}
0005433642727	D645FB	2802 899596	YULIYA MALYSHEVA	{"phone": "+70522635247"}
0005433642728	066CCF	1147 432280	IRINA ROMANOVA	{"email": "irina.romanova-31031975@postgrespro.ru", "phone": "+70409145407"}
0005433642729	1ADB6E	5688 833127	SERGEY IVANOV	{"phone": "+70761130034"}
0005433642730	19522D	4570 852356	ALEKSANDR KONOVALOV	{"phone": "+70497856406"}
0005433642731	19522D	4239 849299	DARYA NIKITINA	{"phone": "+70994622689"}
0005433642732	19522D	1365 265068	YURIY FEDOTOV	{"email": "fedotovyuriy_051967@postgrespro.ru", "phone": "+70692449071"}
0005433642733	9EEB49	9997 431062	ANTON NIKOLAEV	{"email": "nikolaev-anton_1975@postgrespro.ru", "phone": "+70063021733"}
0005433642734	57834A	3813 630590	VERA KUDRYASHOVA	{"phone": "+70499870867"}
0005433642735	2347F4	5553 594311	ELENA SERGEEVA	{"email": "sergeeva.elena_1978@postgrespro.ru", "phone": "+70986020503"}
0005433642736	1EF6E9	7473 255373	NIKOLAY ORLOV	{"email": "orlov-nikolay_121971@postgrespro.ru", "phone": "+70782179684"}
0005433642737	7DF1A5	2261 860431	ALEKSANDR FEDOROV	{"phone": "+70308884844"}
0005433642738	EB48C7	4527 742749	KARINA DMITRIEVA	{"phone": "+70236745625"}
0005433642739	EB48C7	5324 542529	VYACHESLAV KOZLOV	{"phone": "+70041792114"}
0005433642740	86C87A	0845 018935	LYUDMILA LAZAREVA	{"phone": "+70798623217"}
0005433642741	418A4F	7323 804494	ALEKSEY SCHERBAKOV	{"phone": "+70359386458"}
0005433642742	9997DC	8273 524612	MARIYA MIKHAYLOVA	{"phone": "+70996365677"}
0005433642743	4E9C5C	8565 750324	NADEZHDA IVANOVA	{"phone": "+70662330449"}
0005433642744	8AAD52	9646 048766	NINA ERMAKOVA	{"phone": "+70318170096"}
0005433642745	8AAD52	3274 449781	SERGEY KUZMIN	{"email": "kuzmin.s05041956@postgrespro.ru", "phone": "+70628473261"}
0005433642746	9204C0	7100 905282	IRINA GUSEVA	{"phone": "+70642391786"}
0005433642747	CC75D1	3713 117183	ALEKSEY ABRAMOV	{"phone": "+70143468410"}
0005433642748	A743B2	0334 514734	ALEKSANDR GRIGOREV	{"email": "grigorev_a.1969@postgrespro.ru", "phone": "+70870724854"}
0005433642749	7F949F	3014 400887	OKSANA GRISHINA	{"email": "oksana_grishina-27031978@postgrespro.ru", "phone": "+70055113414"}
0005433642750	AACCA0	3308 337228	LARISA ALEKSANDROVA	{"phone": "+70301038695"}
0005433642751	AACCA0	6000 496191	ALEKSANDR IVANOV	{"email": "aleksandrivanov_04051967@postgrespro.ru", "phone": "+70149312839"}
0005433642752	A18F6F	9843 279738	VIKTOR FROLOV	{"email": "vfrolov1970@postgrespro.ru", "phone": "+70208461178"}
0005433642753	C4A8F6	2147 514338	IGOR GORBUNOV	{"phone": "+70914684318"}
0005433642754	C4A8F6	8113 020005	ARTUR FILIPPOV	{"phone": "+70466368054"}
0005433642755	9DE5C4	0894 252724	IVAN SOROKIN	{"email": "isorokin031968@postgrespro.ru", "phone": "+70076750418"}
0005433642756	F35B9F	5758 995669	NATALYA TARASOVA	{"email": "natalya-tarasova.08011976@postgrespro.ru", "phone": "+70663259504"}
0005433642757	F35B9F	6791 611026	EVGENIY YAKOVLEV	{"phone": "+70366336494"}
0005433642758	5542CF	2527 871081	VALENTIN VLASOV	{"email": "vlasov_valentin1977@postgrespro.ru", "phone": "+70489562129"}
0005433642759	5542CF	2620 279256	SVETLANA PETROVA	{"email": "svetlana-petrova_23041964@postgrespro.ru", "phone": "+70597353264"}
0005433642760	695B6F	1654 871039	ZINAIDA MOISEEVA	{"email": "moiseevazinaida_1971@postgrespro.ru", "phone": "+70616432392"}
0005433642761	49F9DB	3436 678530	ALEKSANDR NIKITIN	{"phone": "+70415063769"}
0005433642762	49F9DB	8342 164087	ANNA MOROZOVA	{"phone": "+70680932698"}
0005433642763	88AD18	1675 245348	IVAN SHEVCHENKO	{"email": "i.shevchenko_1975@postgrespro.ru", "phone": "+70284613790"}
0005433642764	58DADF	7858 517770	ILYA KUZNECOV	{"phone": "+70352833631"}
0005433642765	58DADF	2360 312068	ANZHELA KUZNECOVA	{"phone": "+70851798403"}
0005433642766	6E57C3	7657 143922	OKSANA GERASIMOVA	{"email": "oksana.gerasimova-20041981@postgrespro.ru", "phone": "+70114071579"}
0005433642767	32B9E0	0784 810316	SERGEY SOLOVEV	{"phone": "+70852476767"}
0005433642768	3A543C	7638 067237	MARIYA NAZAROVA	{"email": "nazarovamariya.1970@postgrespro.ru", "phone": "+70760318716"}
0005433642769	540AD9	5371 125230	GEORGIY ILIN	{"email": "iling_021964@postgrespro.ru", "phone": "+70563457743"}
0005433642770	192AEC	5515 130247	ALEKSANDR SIDOROV	{"phone": "+70366741592"}
0005433642771	192AEC	6302 948885	ALEKSANDR ANDREEV	{"email": "a.andreev_021994@postgrespro.ru", "phone": "+70410725060"}
0005433642772	A0D072	4663 160708	IVAN NOVIKOV	{"email": "i-novikov.12011974@postgrespro.ru", "phone": "+70642556764"}
0005433642773	7E8B83	8242 614320	NATALYA VASILEVA	{"phone": "+70464128557"}
0005433642774	B6A444	8081 661433	ALEKSANDR NIKOLAEV	{"phone": "+70936092817"}
0005433642775	46868C	1754 656429	OLGA DMITRIEVA	{"email": "o-dmitrieva.1979@postgrespro.ru", "phone": "+70909691249"}
0005433642776	1219EC	1678 138168	RAFIS SCHERBAKOV	{"phone": "+70273488200"}
0005433642777	5303E3	0364 250931	ALEKSEY ANDREEV	{"phone": "+70960940415"}
0005433642778	6B1EBB	5214 050201	NIKOLAY PAVLOV	{"email": "pavlov.n_1964@postgrespro.ru", "phone": "+70742594855"}
0005433642779	6B1EBB	5691 139221	ELENA ZAKHAROVA	{"phone": "+70408648400"}
0005433650365	F2D208	2702 880254	VALENTINA IVANOVA	{"email": "ivanovavalentina051975@postgrespro.ru", "phone": "+70116403637"}
0005433650366	9F4B61	2177 078637	GALINA POPOVA	{"phone": "+70917525633"}
0005433650367	EC4E75	3137 854904	MARIYA ILINA	{"email": "milina27051965@postgrespro.ru", "phone": "+70564798078"}
0005433650368	135396	2347 684826	MIKHAIL BORISOV	{"email": "mikhail_borisov.031973@postgrespro.ru", "phone": "+70492316118"}
0005433650369	2A9E03	2337 572152	YURIY NIKOLAEV	{"email": "yuriy-nikolaev_07051978@postgrespro.ru", "phone": "+70250359217"}
0005433650370	04CAF3	8080 564222	IVAN ROMANOV	{"email": "ivan.romanov1979@postgrespro.ru", "phone": "+70329237974"}
0005433650371	58EBD8	8980 232477	SVETLANA PAVLOVA	{"email": "s.pavlova061972@postgrespro.ru", "phone": "+70999488732"}
0005433650372	58EBD8	7159 585342	NADEZHDA KOZLOVA	{"phone": "+70777756425"}
0005433650373	DBA8BB	8752 390766	ANNA DAVYDOVA	{"phone": "+70144078308"}
0005433650374	6B5778	3274 944398	GALINA NOVIKOVA	{"email": "g.novikova.031967@postgrespro.ru", "phone": "+70564244432"}
0005433650375	6B5778	1862 348163	ALEKSANDR KUZNECOV	{"email": "akuznecov-1978@postgrespro.ru", "phone": "+70292734473"}
0005433650376	6B5778	3439 223856	LYUBOV POPOVA	{"email": "l.popova091978@postgrespro.ru", "phone": "+70899238153"}
0005433650377	0873E6	3156 695236	ALEKSEY SOLOVEV	{"phone": "+70500142670"}
0005433650378	0873E6	1971 015856	OLEG POPOV	{"email": "popov-o_25121970@postgrespro.ru", "phone": "+70746368646"}
0005433650379	0873E6	0104 892239	OLGA ANTONOVA	{"phone": "+70878761831"}
0005433650380	BC2B82	8526 275109	ARINA POTAPOVA	{"phone": "+70639854350"}
0005433650381	A26522	9685 640271	NATALYA NESTEROVA	{"email": "n.nesterova.081980@postgrespro.ru", "phone": "+70759168701"}
0005433650382	CB739F	5297 592839	VALERIYA ISAEVA	{"phone": "+70288216971"}
0005433650383	CB739F	7738 361326	VIKTOR SOROKIN	{"phone": "+70063622230"}
0005433650384	4820C0	4485 547997	NATALYA KOROLEVA	{"phone": "+70431644260"}
0005433650385	4820C0	1430 103934	IGOR ABRAMOV	{"email": "abramov_i_121970@postgrespro.ru", "phone": "+70615554219"}
0005433650386	8C5789	7778 949284	YULIYA IVANOVA	{"phone": "+70597178105"}
0005433650387	3FE6BA	9612 009105	ALEVTINA KOROLEVA	{"phone": "+70453311514"}
0005433650388	3FE6BA	6993 933397	EVGENIY POPOV	{"email": "evgeniypopov1980@postgrespro.ru", "phone": "+70241405376"}
0005433650389	154055	5169 451009	YAROSLAV VLASOV	{"email": "vlasovy_1972@postgrespro.ru", "phone": "+70327663534"}
0005433650390	CEFC97	5664 590065	IGOR YAKOVLEV	{"phone": "+70895641743"}
0005433650391	91F2AC	6171 778624	ANDREY YAKOVLEV	{"phone": "+70854957141"}
0005433650392	91F2AC	4559 329465	ALEKSANDRA SIDOROVA	{"email": "aleksandra-sidorova-22011974@postgrespro.ru", "phone": "+70161373826"}
0005433650393	11A0CC	8440 229185	SERGEY ZAKHAROV	{"phone": "+70342295742"}
0005433650394	DD99C6	9629 197140	ELENA PAVLOVA	{"phone": "+70866377068"}
0005433650395	5A4E03	6597 872356	TATYANA ROMANOVA	{"phone": "+70013399875"}
0005433650396	5A4E03	2426 618380	VLADIMIR NAUMOV	{"email": "vladimirnaumov-111970@postgrespro.ru", "phone": "+70771471646"}
0005433650397	762159	7766 361140	TAMARA KAZAKOVA	{"email": "tamara.kazakova1982@postgrespro.ru", "phone": "+70318000710"}
0005433650398	6BB364	0198 659763	VALENTINA VASILEVA	{"email": "v.vasileva1965@postgrespro.ru", "phone": "+70415181747"}
0005433650399	6BB364	2654 469911	VIKTORIYA DMITRIEVA	{"phone": "+70695213502"}
0005433650400	B7205E	0319 980439	ALEKSEY NAUMOV	{"email": "aleksey_naumov.031959@postgrespro.ru", "phone": "+70322124881"}
0005433650401	B7205E	1948 191020	YULIYA POPOVA	{"phone": "+70728932293"}
0005433650402	54E5C5	3332 433425	YULIYA LAZAREVA	{"phone": "+70523268907"}
0005433650403	C75B95	0901 173534	ANDREY PAVLOV	{"phone": "+70429549092"}
0005433650404	0AA178	1135 162954	EKATERINA POPOVA	{"phone": "+70386785182"}
0005433650405	AD505F	1567 633518	NADEZHDA FROLOVA	{"email": "nadezhda.frolova-031979@postgrespro.ru", "phone": "+70617692640"}
0005433650406	8DEC2B	4258 366722	ANNA KUZNECOVA	{"email": "anna_kuznecova051970@postgrespro.ru", "phone": "+70440209870"}
0005433650407	426690	5446 042370	EKATERINA PETROVA	{"email": "epetrova-1980@postgrespro.ru", "phone": "+70926447459"}
0005433650408	370BE7	8146 588084	ANNA KOZLOVA	{"email": "kozlova_a_25021967@postgrespro.ru", "phone": "+70169574001"}
0005433650409	BC8274	6913 460359	SVETLANA YUDINA	{"email": "yudina_svetlana.1976@postgrespro.ru", "phone": "+70916128190"}
0005433650410	89A5BC	1889 608860	OKSANA ZHURAVLEVA	{"email": "zhuravleva_oksana-02061973@postgrespro.ru", "phone": "+70794042427"}
0005433650411	6AF473	1421 922289	ANASTASIYA NAZAROVA	{"phone": "+70233109463"}
0005433650412	6AF473	3356 378121	ALEKSANDR FEDOROV	{"phone": "+70370089863"}
0005433650413	A1E25E	6129 332336	VLADIMIR KOZLOV	{"email": "kozlov.vladimir011975@postgrespro.ru", "phone": "+70642690824"}
0005433650414	A90349	7454 843909	ZOYA CHERNOVA	{"phone": "+70208995678"}
0005433650415	F4BDF4	7718 801848	ALEKSEY NIKITIN	{"phone": "+70142654478"}
0005433650416	DCFE05	5046 307730	ZINAIDA VOLKOVA	{"phone": "+70874046829"}
0005433650417	158149	2695 803182	ULYANA KISELEVA	{"phone": "+70052523285"}
0005433650418	158149	0002 151158	ALEKSANDR SAVELEV	{"phone": "+70126890593"}
0005433650419	88BBA2	6265 640571	LARISA GAVRILOVA	{"phone": "+70817360894"}
0005433650420	88BBA2	9830 759411	ALEKSANDRA NESTEROVA	{"phone": "+70665337690"}
0005433650421	0FEFB9	6832 940388	FARID IVANOV	{"phone": "+70941428179"}
0005433650422	BC5BDF	3575 681014	OLEG FEDOROV	{"email": "fedorovoleg.21111977@postgrespro.ru", "phone": "+70051466329"}
0005433650423	949BC3	6269 804964	ARINA SIDOROVA	{"email": "arina_sidorova_111962@postgrespro.ru", "phone": "+70062211326"}
0005433650424	949BC3	7102 054553	ANASTASIYA MELNIKOVA	{"email": "anastasiyamelnikova_27011964@postgrespro.ru", "phone": "+70694612786"}
0005433650425	C0B721	7892 865683	ALEKSANDR SERGEEV	{"phone": "+70239936547"}
0005433650426	D2DAEF	4785 584804	VITALIY KARPOV	{"phone": "+70023047429"}
0005433650427	D2DAEF	3567 695199	SERGEY EGOROV	{"phone": "+70197256641"}
0005433650428	6E394B	0761 005759	PAVEL SCHERBAKOV	{"email": "pscherbakov.09031987@postgrespro.ru", "phone": "+70510794818"}
0005433650429	C1501E	0489 490593	NATALIYA IVANOVA	{"phone": "+70692151887"}
0005433650430	79DB2E	7734 701004	KSENIYA MIRONOVA	{"email": "kseniya-mironova.021969@postgrespro.ru", "phone": "+70648358965"}
0005433650431	C6A405	6446 796480	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr13071979@postgrespro.ru", "phone": "+70823789139"}
0005433650432	C04EAD	9919 043855	ANATOLIY GORBUNOV	{"phone": "+70681655804"}
0005433650433	D33BB5	6552 916814	SERGEY ZAKHAROV	{"email": "zakharov_sergey_18101975@postgrespro.ru", "phone": "+70533089984"}
0005433650434	62A2A1	2827 752321	ANATOLIY PETROV	{"email": "petrov_anatoliy-10111976@postgrespro.ru", "phone": "+70462393390"}
0005433650435	DAEDA2	0938 017253	ALEKSANDR KOZLOV	{"email": "kozlova121970@postgrespro.ru", "phone": "+70364766034"}
0005433650436	C30A85	2021 930781	VLADIMIR IVANOV	{"phone": "+70642289863"}
0005433650437	C30A85	4181 592554	ARTEM CHERNOV	{"phone": "+70807752540"}
0005433650438	9C9F92	6240 171457	DMITRIY SMIRNOV	{"phone": "+70593896158"}
0005433650439	F74074	4668 104869	DMITRIY FILIPPOV	{"email": "dmitriyfilippov-071959@postgrespro.ru", "phone": "+70726019436"}
0005433650440	F74074	6500 771523	EKATERINA KOROLEVA	{"phone": "+70036333924"}
0005433650441	C5FFCB	6720 588399	ALEKSANDR ALEKSEEV	{"phone": "+70793412142"}
0005433650442	F6F7B2	0940 128472	ELENA LOGINOVA	{"email": "loginova_e1980@postgrespro.ru", "phone": "+70364576254"}
0005433650443	4B55A6	8483 192893	ZINAIDA PETROVA	{"email": "petrovazinaida_1974@postgrespro.ru", "phone": "+70658148765"}
0005433650444	4B55A6	0641 487879	ELENA SOKOLOVA	{"phone": "+70392997678"}
0005433650445	63FC44	5457 713667	KONSTANTIN IVANOV	{"phone": "+70420529563"}
0005433650446	63FC44	4265 841253	VERA MELNIKOVA	{"phone": "+70644825532"}
0005433650447	6E3789	5817 019920	IRINA MEDVEDEVA	{"email": "i.medvedeva_111971@postgrespro.ru", "phone": "+70950426104"}
0005433650448	6474D9	4251 335257	YANA MASLOVA	{"email": "yana-maslova-26071969@postgrespro.ru", "phone": "+70295423993"}
0005433650449	6474D9	0468 160143	ANASTASIYA NIKIFOROVA	{"phone": "+70279353493"}
0005433650450	FFFA21	5616 707329	LIDIYA ALEKSANDROVA	{"email": "aleksandroval.02111972@postgrespro.ru", "phone": "+70163638730"}
0005433650451	411405	3260 370583	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov.031981@postgrespro.ru", "phone": "+70112649397"}
0005433650452	0EB769	0456 816789	ROMAN SMIRNOV	{"email": "romansmirnov-031982@postgrespro.ru", "phone": "+70253521933"}
0005433650453	716DA7	7595 637226	ANTON TARASOV	{"phone": "+70964851632"}
0005433650454	C3F2C2	5498 313824	ANTONINA KOROLEVA	{"phone": "+70632070194"}
0005433650455	2326CE	8046 583097	TATYANA LAZAREVA	{"email": "tatyana.lazareva_1969@postgrespro.ru", "phone": "+70995637225"}
0005433650456	395114	1539 621400	MIKHAIL POPOV	{"phone": "+70368572455"}
0005433650457	7053CD	9267 019851	EVDOKIYA MELNIKOVA	{"email": "melnikova_e-081969@postgrespro.ru", "phone": "+70749683038"}
0005433650458	7053CD	9629 022875	VIKTOR SIDOROV	{"phone": "+70110129649"}
0005433650459	7053CD	7596 818801	ALEKSANDR KUZMIN	{"email": "akuzmin27081974@postgrespro.ru", "phone": "+70251707347"}
0005433650460	7053CD	4932 158830	EVGENIY SMIRNOV	{"phone": "+70320065206"}
0005433650461	D2AB59	4698 891478	ALEKSANDR MAKSIMOV	{"phone": "+70897889309"}
0005433650462	D2AB59	7073 694783	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.011960@postgrespro.ru", "phone": "+70766507959"}
0005433650463	CC38FC	1165 205649	GALINA ZAKHAROVA	{"phone": "+70686304212"}
0005433650464	C7BCF6	1335 920595	ELENA IVANOVA	{"email": "e-ivanova.011982@postgrespro.ru", "phone": "+70060425355"}
0005433650465	407BEF	1404 276108	ILYA SIDOROV	{"phone": "+70423807895"}
0005433650466	407BEF	8272 724065	VALERIY SEMENOV	{"email": "semenov-valeriy-091971@postgrespro.ru", "phone": "+70683649442"}
0005433650467	CC9141	0236 130940	NATALYA EGOROVA	{"phone": "+70615150078"}
0005433650468	75D453	4124 415618	NINA LOGINOVA	{"email": "loginova_n_06081965@postgrespro.ru", "phone": "+70617492768"}
0005433650469	6330AF	7503 815582	NATALYA IVANOVA	{"email": "natalya.ivanova.14061977@postgrespro.ru", "phone": "+70980466006"}
0005433650470	260E38	4599 590592	DANIIL MOISEEV	{"phone": "+70465187517"}
0005433650471	88D0B3	6471 610596	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy-15071981@postgrespro.ru", "phone": "+70438889397"}
0005433650472	88D0B3	2813 214535	VIKTORIYA PAVLOVA	{"email": "v-pavlova_03091964@postgrespro.ru", "phone": "+70492698984"}
0005433650473	37EC36	6098 064703	ALEKSANDRA FROLOVA	{"email": "aleksandra.frolova-14031964@postgrespro.ru", "phone": "+70417049062"}
0005433650474	37EC36	9560 836462	ANDREY KUZMIN	{"phone": "+70550779273"}
0005433650475	4AF73A	2902 597301	VITALIY KUZNECOV	{"phone": "+70248116110"}
0005433650476	761702	3455 483107	VLADIMIR MARTYNOV	{"phone": "+70008332009"}
0005433650477	BB68FC	4575 091616	RENATA FILATOVA	{"phone": "+70922970240"}
0005433650478	21E077	3406 129142	VIKTOR ILIN	{"phone": "+70115797877"}
0005433650479	43D692	8107 835109	ELENA IVANOVA	{"email": "elenaivanova_101963@postgrespro.ru", "phone": "+70489005548"}
0005433650480	B4EC79	5021 851334	ALINA DMITRIEVA	{"email": "alina.dmitrieva-22051968@postgrespro.ru", "phone": "+70338206289"}
0005433650481	804F56	9320 091712	VALENTINA KALININA	{"phone": "+70282263108"}
0005433650482	804F56	2533 652795	SERGEY PETROV	{"email": "sergeypetrov041978@postgrespro.ru", "phone": "+70585469166"}
0005433650483	B31B96	3559 202369	ALEKSEY AFANASEV	{"email": "afanasev_aleksey.04101981@postgrespro.ru", "phone": "+70899821369"}
0005433650484	E2C4C5	0508 150826	OLGA TARASOVA	{"email": "olga.tarasova1969@postgrespro.ru", "phone": "+70894192599"}
0005433650485	BE5368	7567 713304	SVETLANA VOLKOVA	{"phone": "+70356006039"}
0005433650486	97BB41	0556 876830	ANASTASIYA KAZAKOVA	{"email": "akazakova_02011961@postgrespro.ru", "phone": "+70864275353"}
0005433650487	97BB41	6385 012750	SERGEY ROMANOV	{"phone": "+70877054050"}
0005433650488	5E2F85	1841 097015	ELIZAVETA FADEEVA	{"email": "efadeeva051967@postgrespro.ru", "phone": "+70816457003"}
0005433650489	93D86C	1743 326914	IVAN ZAKHAROV	{"phone": "+70531767005"}
0005433650490	93D86C	9772 670680	YANA SEMENOVA	{"email": "y-semenova1976@postgrespro.ru", "phone": "+70581047252"}
0005433650491	2EAD71	3632 169606	NATALYA KUZNECOVA	{"phone": "+70334156730"}
0005433650492	278C4C	4935 698937	ANNA ANISIMOVA	{"phone": "+70482143477"}
0005433650493	F30DF1	8117 343921	TAMARA KUZNECOVA	{"phone": "+70339010010"}
0005433650494	504FBE	5365 072676	ANATOLIY BONDARENKO	{"email": "abondarenko_011978@postgrespro.ru", "phone": "+70707300727"}
0005433650495	504FBE	3165 999833	VERONIKA KAZAKOVA	{"phone": "+70184103440"}
0005433650496	FDADA4	3917 726425	IRINA STEPANOVA	{"phone": "+70183907936"}
0005433650497	FDADA4	2236 564520	ANNA IVANOVA	{"phone": "+70218782897"}
0005433650498	FDADA4	7164 584469	ANATOLIY KRASNOV	{"email": "krasnov.a_15031988@postgrespro.ru", "phone": "+70265878327"}
0005433650499	EBDEAB	6694 103239	ALEKSANDR BELOV	{"phone": "+70022036561"}
0005433650500	EBDEAB	1081 184500	SERGEY PETROV	{"phone": "+70330393073"}
0005433650501	E32574	5284 473231	KLAVDIYA NIKIFOROVA	{"email": "klavdiyanikiforova-26081966@postgrespro.ru", "phone": "+70616014910"}
0005433650502	E32574	7118 465334	TATYANA GUSEVA	{"email": "tguseva051974@postgrespro.ru", "phone": "+70846435205"}
0005433650503	6553FC	8474 999747	DANIYA RODIONOVA	{"email": "daniya.rodionova-16101973@postgrespro.ru", "phone": "+70476340876"}
0005433650504	B42237	4297 340782	IRINA KUZNECOVA	{"phone": "+70823656816"}
0005433650505	D15E28	1146 540543	VLADIMIR STEPANOV	{"email": "stepanovv19051974@postgrespro.ru", "phone": "+70900203482"}
0005433650506	C5F08D	9121 059656	OLGA FADEEVA	{"phone": "+70698361488"}
0005433650507	4219E4	4517 345537	POLINA NIKITINA	{"email": "polina_nikitina.061976@postgrespro.ru", "phone": "+70700342070"}
0005433650508	4219E4	8148 212031	ELENA PETROVA	{"email": "epetrova_111971@postgrespro.ru", "phone": "+70176333955"}
0005433650509	1BCE25	2470 112774	BORIS KISELEV	{"email": "kiselevb.041969@postgrespro.ru", "phone": "+70668023875"}
0005433650510	4FD311	3092 848154	LYUDMILA NIKITINA	{"phone": "+70037448932"}
0005433650511	89BD1D	8630 839745	SERGEY SEMENOV	{"phone": "+70628123085"}
0005433650512	0553C0	9434 095698	SERGEY GUSEV	{"phone": "+70174215235"}
0005433650513	50890F	0981 879111	ANASTASIYA RODIONOVA	{"email": "anastasiya_rodionova-20091972@postgrespro.ru", "phone": "+70927266262"}
0005433650514	50890F	9615 442396	LIDIYA VASILEVA	{"email": "vasileva_lidiya1976@postgrespro.ru", "phone": "+70859879735"}
0005433650515	D64F8B	0650 273881	IOSIF FILIPPOV	{"phone": "+70179266694"}
0005433650516	6BB0E4	5636 501410	VYACHESLAV ZAYCEV	{"phone": "+70117621095"}
0005433650517	6BB0E4	4134 096832	ANASTASIYA SEMENOVA	{"email": "anastasiyasemenova.14111972@postgrespro.ru", "phone": "+70876359299"}
0005433650518	E46B4C	6186 208780	KONSTANTIN SOKOLOV	{"email": "sokolov.k.01011968@postgrespro.ru", "phone": "+70667459227"}
0005433650519	2386CD	9387 000627	ALEKSANDR VASILEV	{"email": "vasileva031972@postgrespro.ru", "phone": "+70183999108"}
0005433650520	2386CD	5161 746423	PAVEL KRASNOV	{"email": "pkrasnov-111973@postgrespro.ru", "phone": "+70699113808"}
0005433650521	2386CD	6540 767205	DENIS STEPANOV	{"phone": "+70242009372"}
0005433650522	BCE891	4255 808690	NIKITA VLASOV	{"phone": "+70501551236"}
0005433650523	A68C0E	8402 608935	ANATOLIY ISAEV	{"phone": "+70151653654"}
0005433650524	07BB11	4924 860178	EVGENIY GORBUNOV	{"phone": "+70207882727"}
0005433650525	9B3C73	6096 451853	IVAN BELOV	{"email": "ivan.belov.1983@postgrespro.ru", "phone": "+70029123504"}
0005433650526	9B3C73	8567 986961	ROZA EGOROVA	{"phone": "+70437530838"}
0005433650527	3D2C08	3046 533811	GALINA RYABOVA	{"email": "ryabova.galina.091975@postgrespro.ru", "phone": "+70641968694"}
0005433650528	B59D39	1121 335113	PAVEL PETROV	{"email": "petrovp_1972@postgrespro.ru", "phone": "+70985012914"}
0005433650529	AC5BF6	7823 307312	ALEKSEY MIKHAYLOV	{"phone": "+70003306188"}
0005433650530	470CAA	2669 237188	ELENA KRASNOVA	{"phone": "+70431517639"}
0005433650531	A50265	3269 804699	VASILIY NOVIKOV	{"phone": "+70492123204"}
0005433650532	A50265	3427 295393	ANNA NIKIFOROVA	{"email": "a.nikiforova071982@postgrespro.ru", "phone": "+70433212228"}
0005433650533	99A275	5447 173513	VIKTORIYA ISAEVA	{"email": "isaeva_v081976@postgrespro.ru", "phone": "+70611528495"}
0005433650534	F8CA65	5793 994588	ALEKSANDR KONOVALOV	{"email": "konovalov.a_071978@postgrespro.ru", "phone": "+70653948613"}
0005433650535	87AF04	0519 176858	TATYANA PETROVA	{"email": "tatyana_petrova1978@postgrespro.ru", "phone": "+70635759700"}
0005433650536	997B12	3764 256624	NINA IVANOVA	{"email": "n.ivanova.031992@postgrespro.ru", "phone": "+70671020096"}
0005433650537	803D88	9177 328828	PELAGEYA MOROZOVA	{"email": "morozova-p26031974@postgrespro.ru", "phone": "+70570976523"}
0005433650538	E8DE43	9044 061193	ALEKSANDR STEPANOV	{"phone": "+70963282906"}
0005433650539	5FC248	4192 918638	ALEKSANDR KRASNOV	{"phone": "+70910588009"}
0005433650540	5FC248	4812 818022	KUZMA KUZNECOV	{"email": "kuzma_kuznecov.30011977@postgrespro.ru", "phone": "+70409530272"}
0005433650541	9A0F19	3681 578460	DMITRIY BELOV	{"email": "belov.d1958@postgrespro.ru", "phone": "+70264702589"}
0005433650542	FE5AB9	6872 647018	GALINA MOROZOVA	{"phone": "+70160345338"}
0005433650543	FE5AB9	2026 884762	YURIY SAVELEV	{"phone": "+70176888580"}
0005433650544	1273CD	7289 447160	SHAMIL ANDREEV	{"phone": "+70144537086"}
0005433650545	5D6AE2	9357 765350	MIKHAIL GORBUNOV	{"phone": "+70911402549"}
0005433650546	5D6AE2	0944 514409	ELENA KRASNOVA	{"email": "krasnova_e05101969@postgrespro.ru", "phone": "+70362123018"}
0005433650547	85D83B	6003 872221	TATYANA ROMANOVA	{"email": "tromanova-1963@postgrespro.ru", "phone": "+70732732761"}
0005433650548	3EC50B	0171 966319	ALEKSANDR SOROKIN	{"phone": "+70990069562"}
0005433650549	3EC50B	4482 542080	ARTEM FROLOV	{"email": "frolov.a1962@postgrespro.ru", "phone": "+70260989582"}
0005433650550	33D6CD	1987 409665	DMITRIY GORBUNOV	{"phone": "+70904125908"}
0005433650551	292AD8	9268 093597	MARINA ROMANOVA	{"phone": "+70450368733"}
0005433650552	292AD8	0319 515562	RUSLAN MELNIKOV	{"phone": "+70412624191"}
0005433650553	5015BE	5318 024896	ARINA AFANASEVA	{"email": "afanaseva.arina_041979@postgrespro.ru", "phone": "+70594816939"}
0005433650554	26A7E2	0386 423270	NATALYA NOVIKOVA	{"phone": "+70162425819"}
0005433650555	26A7E2	1874 569659	OLGA POTAPOVA	{"phone": "+70240241996"}
0005433650556	2D042E	8698 002894	EVGENIY IVANOV	{"email": "e_ivanov10061971@postgrespro.ru", "phone": "+70368379581"}
0005433650557	6A6FB1	2681 458422	VERONIKA RODIONOVA	{"email": "rodionovaveronika09031975@postgrespro.ru", "phone": "+70273228604"}
0005433650558	F8C410	7407 298636	ANDREY KUZNECOV	{"email": "andrey.kuznecov08071982@postgrespro.ru", "phone": "+70020186587"}
0005433650559	E84604	4056 012963	ARINA YAKOVLEVA	{"email": "yakovleva_a1973@postgrespro.ru", "phone": "+70889660142"}
0005433650560	E84604	9753 043516	OLGA NIKITINA	{"phone": "+70335597696"}
0005433650561	E84604	4436 504859	ANASTASIYA MELNIKOVA	{"phone": "+70539195837"}
0005433650562	E84604	1388 856232	LILIYA VOROBEVA	{"phone": "+70112819681"}
0005433650563	1E6FA2	5527 708832	YURIY SOROKIN	{"email": "y-sorokin.031968@postgrespro.ru", "phone": "+70554471086"}
0005433650564	8B99AD	2415 784151	LYUDMILA VOLKOVA	{"email": "volkoval_051965@postgrespro.ru", "phone": "+70510122369"}
0005433650565	CDFA20	4805 987157	ANDREY TIMOFEEV	{"phone": "+70431420186"}
0005433650566	F698B1	1240 035813	ALEKSANDR SERGEEV	{"phone": "+70251783543"}
0005433650567	9AA212	6719 125174	ALEKSANDRA PETROVA	{"phone": "+70376895550"}
0005433650568	CD2F18	4717 863288	VASILIY CHERNOV	{"email": "chernov.v-15071977@postgrespro.ru", "phone": "+70017475053"}
0005433650569	0045DB	8971 863442	ELENA MOISEEVA	{"phone": "+70192923575"}
0005433650570	962D6D	1115 424189	ALISA KOROLEVA	{"email": "koroleva_alisa22101963@postgrespro.ru", "phone": "+70950627208"}
0005433650571	16E7D1	1813 486873	OLGA ALEKSANDROVA	{"phone": "+70271332619"}
0005433650572	6978EF	6141 649301	ELENA MELNIKOVA	{"email": "e_melnikova22111963@postgrespro.ru", "phone": "+70283590111"}
0005433650573	6978EF	0060 279425	VALENTINA NESTEROVA	{"email": "nesterova.valentina091968@postgrespro.ru", "phone": "+70935887252"}
0005433650574	C7D7E3	1738 607657	DIANA NIKOLAEVA	{"phone": "+70993672106"}
0005433650575	C7D7E3	9968 691694	GENNADIY PETROV	{"email": "gennadiypetrov101973@postgrespro.ru", "phone": "+70301070891"}
0005433650576	71B581	8292 940816	NINA PETROVA	{"email": "n_petrova14051965@postgrespro.ru", "phone": "+70513448761"}
0005433650577	9198E1	6309 710796	ANDREY ZAYCEV	{"email": "zaycev.a.1989@postgrespro.ru", "phone": "+70718879679"}
0005433650578	691B4B	6140 269832	ANDREY ABRAMOV	{"email": "abramov-andrey.091976@postgrespro.ru", "phone": "+70440909589"}
0005433650579	EF0052	6785 651263	LILIYA MARTYNOVA	{"email": "martynova-liliya_1977@postgrespro.ru", "phone": "+70757008760"}
0005433650580	EF0052	3561 889665	ALEKSEY KULIKOV	{"email": "a_kulikov_1975@postgrespro.ru", "phone": "+70977246278"}
0005433650581	91C1CE	8916 082987	MARIYA MARTYNOVA	{"email": "martynova-m1978@postgrespro.ru", "phone": "+70403411345"}
0005433650582	13B6E6	5596 531969	POLINA STEPANOVA	{"email": "p-stepanova_071975@postgrespro.ru", "phone": "+70845021644"}
0005433650583	13B6E6	5392 179380	VLADIMIR BELOV	{"email": "vladimirbelov_1971@postgrespro.ru", "phone": "+70186816121"}
0005433650584	8CCE55	8447 814240	SERGEY TIKHONOV	{"email": "tikhonovsergey.25111961@postgrespro.ru", "phone": "+70256849133"}
0005433650585	500CB4	1380 879780	RINAT BELOV	{"phone": "+70342444600"}
0005433650586	BC7F46	6786 801068	ELENA DAVYDOVA	{"phone": "+70216496509"}
0005433650587	BC7F46	8651 342702	OLGA VASILEVA	{"email": "vasileva_o_1969@postgrespro.ru", "phone": "+70394039420"}
0005433650588	989006	9183 606161	ALEKSEY EGOROV	{"email": "aleksey_egorov-14071961@postgrespro.ru", "phone": "+70283517281"}
0005433650589	E0AD5F	3704 414393	ANDREY IVANOV	{"phone": "+70549906302"}
0005433650590	A543F5	6159 355740	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr051960@postgrespro.ru", "phone": "+70495739033"}
0005433650591	A0E38C	9163 367697	OLGA NIKOLAEVA	{"phone": "+70682736512"}
0005433650592	A0E38C	5802 648460	NADEZHDA EFIMOVA	{"email": "n.efimova06011980@postgrespro.ru", "phone": "+70071369103"}
0005433650593	BAE29A	5441 858921	LYUDMILA NIKITINA	{"phone": "+70979345677"}
0005433650594	42FCB9	2816 763009	MARIYA MOISEEVA	{"email": "m_moiseeva1971@postgrespro.ru", "phone": "+70626779263"}
0005433650595	ED5CC8	4437 497608	MARIYA LOGINOVA	{"email": "loginova.m-1971@postgrespro.ru", "phone": "+70434585117"}
0005433650596	EB95AB	3834 600115	NIKOLAY FEDOROV	{"email": "nikolayfedorov.121976@postgrespro.ru", "phone": "+70349334455"}
0005433650597	78C653	8506 189013	MARIYA FROLOVA	{"email": "mfrolova-041989@postgrespro.ru", "phone": "+70716243230"}
0005433650598	DD85D5	1863 415254	RAFAIL MIKHAYLOV	{"email": "rmikhaylov-11101978@postgrespro.ru", "phone": "+70553938954"}
0005433650599	E53950	7934 302666	ALEKSANDR GUSEV	{"phone": "+70784891479"}
0005433650600	E53950	4391 679303	GALINA MAKAROVA	{"email": "galinamakarova081969@postgrespro.ru", "phone": "+70282045124"}
0005433650601	0CA834	5539 979386	ANDREY ZHURAVLEV	{"email": "a.zhuravlev.1974@postgrespro.ru", "phone": "+70388749880"}
0005433650602	0CA834	8239 658727	NADEZHDA NOVIKOVA	{"email": "n_novikova.071968@postgrespro.ru", "phone": "+70217142418"}
0005433650603	46A586	9687 636885	ALEKSEY ORLOV	{"phone": "+70081158132"}
0005433650604	D194DE	0994 250774	RAIS ORLOV	{"email": "orlov.r_1976@postgrespro.ru", "phone": "+70911715639"}
0005433650605	B30F81	8437 131587	GEORGIY TIKHONOV	{"email": "georgiy_tikhonov-26061969@postgrespro.ru", "phone": "+70172919085"}
0005433650606	F247AF	2562 444614	IVAN KUDRYASHOV	{"email": "i-kudryashov_02091965@postgrespro.ru", "phone": "+70845198044"}
0005433650607	F247AF	8028 853872	SERGEY SMIRNOV	{"email": "smirnov.sergey-1973@postgrespro.ru", "phone": "+70837275180"}
0005433650608	BB76E5	1878 369822	IGOR NIKOLAEV	{"phone": "+70135699966"}
0005433650609	BB76E5	5746 321482	ANASTASIYA ROMANOVA	{"phone": "+70659561964"}
0005433650610	139CC8	0103 854944	ALEKSANDR SHEVCHENKO	{"phone": "+70635386217"}
0005433650611	E25700	0468 595079	SERGEY CHERNOV	{"phone": "+70409436681"}
0005433650612	003389	9129 730496	EKATERINA KUZNECOVA	{"phone": "+70151461061"}
0005433650613	003389	5385 743818	MAKSIM IVANOV	{"email": "mivanov-24071977@postgrespro.ru", "phone": "+70739799398"}
0005433650614	EEF84E	5120 479737	VIKTOR IVANOV	{"email": "viktor-ivanov031957@postgrespro.ru", "phone": "+70018652757"}
0005433650615	EC2A76	4106 937232	LYUDMILA KRASNOVA	{"email": "krasnova-l.12051967@postgrespro.ru", "phone": "+70393001676"}
0005433650616	81966E	5337 578110	MARGARITA ARKHIPOVA	{"email": "m_arkhipova14101975@postgrespro.ru", "phone": "+70944666105"}
0005433650617	907F3E	0484 710983	SERGEY ILIN	{"phone": "+70125952499"}
0005433650618	E61C6B	8346 778005	NADEZHDA PAVLOVA	{"phone": "+70860267382"}
0005433650619	022545	9735 135725	ZHANNA POTAPOVA	{"email": "zhanna_potapova-11021975@postgrespro.ru", "phone": "+70047342199"}
0005433650620	5DDF7A	4153 057994	VLADIMIR IVANOV	{"email": "ivanov_vladimir_27121975@postgrespro.ru", "phone": "+70190854954"}
0005433650621	1F3C82	5164 062250	ALEKSEY KOZLOV	{"email": "kozlov-a1977@postgrespro.ru", "phone": "+70087612526"}
0005433650622	3AB8DC	9351 234857	VALENTINA VASILEVA	{"email": "v-vasileva_26111973@postgrespro.ru", "phone": "+70281445050"}
0005433650623	7E891B	6291 835107	ANNA MELNIKOVA	{"phone": "+70930250482"}
0005433650624	D8E83D	7548 793150	NATALYA OVCHINNIKOVA	{"phone": "+70595777783"}
0005433650625	D8E83D	2757 037627	LYUDMILA GAVRILOVA	{"email": "gavrilova-l101974@postgrespro.ru", "phone": "+70033950064"}
0005433650626	806318	8885 640231	LYUDMILA ROMANOVA	{"email": "l-romanova.1961@postgrespro.ru", "phone": "+70490867551"}
0005433650627	1E1266	3139 211263	IVAN GUSEV	{"email": "gusev_ivan.121970@postgrespro.ru", "phone": "+70316956669"}
0005433650628	1E1266	7815 094308	ELENA LUKYANOVA	{"phone": "+70197884306"}
0005433650629	6037D1	5640 875547	OLGA LUKYANOVA	{"email": "o.lukyanova_1966@postgrespro.ru", "phone": "+70597379404"}
0005433650630	6037D1	6799 947133	ALEKSANDRA MIRONOVA	{"email": "mironova.aleksandra.1967@postgrespro.ru", "phone": "+70154075699"}
0005433650631	957988	1842 777916	ANATOLIY KRASNOV	{"phone": "+70729497437"}
0005433650632	957988	2719 213741	NIKOLAY PETROV	{"phone": "+70952591127"}
0005433650633	0EF74D	0185 324774	MIKHAIL KULIKOV	{"email": "kulikovmikhail_1973@postgrespro.ru", "phone": "+70122138345"}
0005433650634	D45228	7221 016659	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir081980@postgrespro.ru", "phone": "+70111384047"}
0005433650635	40D82E	5102 130859	ELENA KUZNECOVA	{"email": "elena-kuznecova1960@postgrespro.ru", "phone": "+70850835525"}
0005433650636	F0ABEF	4637 432536	ANDREY SOKOLOV	{"email": "andrey-sokolov09021968@postgrespro.ru", "phone": "+70391818527"}
0005433650637	F0ABEF	0637 566716	SOFYA IVANOVA	{"phone": "+70059481335"}
0005433650638	E4C7AE	8688 880629	YURIY DMITRIEV	{"phone": "+70263376186"}
0005433650639	5EF9CD	7036 864188	OLGA BORISOVA	{"email": "olga_borisova_27101975@postgrespro.ru", "phone": "+70154739338"}
0005433650640	F86F93	9621 562692	SERGEY KUZNECOV	{"email": "kuznecov_sergey14041980@postgrespro.ru", "phone": "+70771334504"}
0005433650641	EB7897	8840 394809	ALEKSANDR OSIPOV	{"email": "aleksandrosipov-051974@postgrespro.ru", "phone": "+70691130946"}
0005433650642	2E7985	0177 163401	ARINA MAKAROVA	{"phone": "+70208447033"}
0005433650643	CD941D	3284 930017	MARIYA MOROZOVA	{"email": "m.morozova_071968@postgrespro.ru", "phone": "+70944702516"}
0005433650644	345D08	5926 778130	PETR SIDOROV	{"email": "petr.sidorov121987@postgrespro.ru", "phone": "+70505310534"}
0005433650645	769B18	2076 733161	LEONID ANDREEV	{"email": "andreev.leonid_111973@postgrespro.ru", "phone": "+70400376947"}
0005433650646	769B18	3790 391801	VIKTORIYA ZAKHAROVA	{"email": "viktoriya-zakharova_101971@postgrespro.ru", "phone": "+70797228337"}
0005433650647	E814AC	4153 444196	TAMARA KONOVALOVA	{"phone": "+70236895653"}
0005433650648	E814AC	9531 270325	ALEKSANDR KONOVALOV	{"phone": "+70985768723"}
0005433650649	0D2880	3300 493960	ROMAN BELOV	{"phone": "+70011625719"}
0005433650650	0D2880	0915 671933	ILYA OSIPOV	{"phone": "+70254291217"}
0005433650651	F50E88	6038 163828	IVAN FEDOTOV	{"email": "fedotov.i.06081982@postgrespro.ru", "phone": "+70213972857"}
0005433650652	F50E88	5309 779612	ANNA KAZAKOVA	{"phone": "+70902217669"}
0005433650653	040034	7631 670206	ARTEMIY MOROZOV	{"phone": "+70715386543"}
0005433650654	040034	6938 154813	ZARINA KOZLOVA	{"email": "kozlova-zarina_061975@postgrespro.ru", "phone": "+70007492365"}
0005433650655	0E9777	5158 887131	OLESYA MIRONOVA	{"email": "olesya-mironova.101972@postgrespro.ru", "phone": "+70179554110"}
0005433650656	706911	1078 315844	VASILIY KAZAKOV	{"email": "vkazakov-18021971@postgrespro.ru", "phone": "+70622777675"}
0005433650657	24A70D	2960 523161	ANATOLIY FILIPPOV	{"email": "anatoliyfilippov-20071971@postgrespro.ru", "phone": "+70005801512"}
0005433650658	3922D5	2596 407558	YULIYA ABRAMOVA	{"email": "abramova_y_1975@postgrespro.ru", "phone": "+70514478367"}
0005433650659	FF4641	1235 420348	OLESYA NIKOLAEVA	{"phone": "+70842319761"}
0005433650660	FF4641	0234 526345	NINA FEDOROVA	{"email": "fedorova.nina.061967@postgrespro.ru", "phone": "+70195395777"}
0005433650661	C869CD	0509 738503	ILYA GERASIMOV	{"email": "i_gerasimov-07121973@postgrespro.ru", "phone": "+70478396231"}
0005433650662	6B133A	8807 696172	TATYANA KOROLEVA	{"phone": "+70640003237"}
0005433650663	8E32C4	4737 786272	NIKOLAY GUSEV	{"email": "nikolay_gusev.081976@postgrespro.ru", "phone": "+70574050631"}
0005433650664	AFDF03	5873 437691	ILYA YAKOVLEV	{"phone": "+70335439029"}
0005433650665	F9D7BE	9337 914531	SERGEY KOZLOV	{"email": "s-kozlov-041968@postgrespro.ru", "phone": "+70994891498"}
0005433650666	D83E6F	7229 507147	RIMMA ZHUKOVA	{"email": "zhukova-r_1970@postgrespro.ru", "phone": "+70812615344"}
0005433650667	0FA7B5	9930 071555	PELAGEYA ANTONOVA	{"email": "antonova.p24011960@postgrespro.ru", "phone": "+70130380403"}
0005433650668	8785BF	1714 943985	DARYA STEPANOVA	{"phone": "+70489697589"}
0005433650669	6B552D	0399 858863	VIKTOR MOISEEV	{"phone": "+70785549054"}
0005433650670	007A89	0981 527423	ALEKSANDR BONDARENKO	{"phone": "+70680669202"}
0005433650671	007A89	3749 665770	IGOR MIRONOV	{"phone": "+70714367425"}
0005433650672	1DE989	2090 928446	IGOR BORISOV	{"phone": "+70881014547"}
0005433650673	3D1AF0	1585 984283	ELENA VOROBEVA	{"phone": "+70660720993"}
0005433650674	4EDDB7	5609 788947	EVGENIY VOLKOV	{"email": "evgeniyvolkov-081958@postgrespro.ru", "phone": "+70476800807"}
0005433650675	AAAC22	6195 507559	ALEKSANDR ZAYCEV	{"phone": "+70182838037"}
0005433650676	F81412	5820 301879	IRINA NIKIFOROVA	{"email": "i.nikiforova_1975@postgrespro.ru", "phone": "+70584817221"}
0005433650677	043216	6260 614289	EVGENIYA MAKSIMOVA	{"email": "evgeniya.maksimova-031969@postgrespro.ru", "phone": "+70337135226"}
0005433650678	4A5E9B	3564 124543	EVGENIY SCHERBAKOV	{"email": "e_scherbakov.29021968@postgrespro.ru", "phone": "+70161205548"}
0005433650679	4A5E9B	1234 061568	VIKTOR OSIPOV	{"phone": "+70438490271"}
0005433650680	614FEF	9779 942836	NATALYA TARASOVA	{"phone": "+70252924847"}
0005433650681	614FEF	4322 361431	DANIIL KULIKOV	{"email": "dkulikov.1972@postgrespro.ru", "phone": "+70136112997"}
0005433650682	56B2B8	7614 437046	VERA TARASOVA	{"phone": "+70148019006"}
0005433650683	C52837	5537 809500	SERGEY AFANASEV	{"phone": "+70200505910"}
0005433650684	46557D	5112 313251	DIANA TIKHONOVA	{"email": "d_tikhonova121967@postgrespro.ru", "phone": "+70059766913"}
0005433650685	29C9B6	4027 149825	KSENIYA BARANOVA	{"phone": "+70093970121"}
0005433650686	29C9B6	5541 854622	VALERIYA OSIPOVA	{"phone": "+70443674656"}
0005433650687	57B05B	7824 128716	SERGEY MATVEEV	{"phone": "+70543312475"}
0005433650688	57B05B	6618 766035	YULIYA TARASOVA	{"phone": "+70817758802"}
0005433650689	57B05B	3396 486134	DMITRIY CHERNOV	{"phone": "+70061760615"}
0005433650690	98B4FA	8946 137708	SERGEY SEMENOV	{"email": "s-semenov1977@postgrespro.ru", "phone": "+70896612904"}
0005433650691	98B4FA	4896 422333	TATYANA ILINA	{"phone": "+70721197347"}
0005433650692	DF0578	8986 959926	DMITRIY MARTYNOV	{"email": "martynov.dmitriy1966@postgrespro.ru", "phone": "+70191903025"}
0005433650693	91EDE0	5506 911517	PETR ROMANOV	{"phone": "+70462895610"}
0005433650694	91EDE0	9543 709995	ELENA ABRAMOVA	{"phone": "+70699010841"}
0005433650695	9DD5DD	2377 160179	ELENA FILIPPOVA	{"email": "filippova-e-011968@postgrespro.ru", "phone": "+70560715742"}
0005433650696	9DD5DD	0474 703711	SERGEY ZHURAVLEV	{"phone": "+70372041724"}
0005433650697	A27131	0082 491444	GENNADIY RODIONOV	{"phone": "+70033815210"}
0005433650698	A27131	0755 489185	OLGA MIKHAYLOVA	{"phone": "+70791354278"}
0005433650699	A27131	6066 652324	VLADISLAV KUDRYASHOV	{"email": "vladislavkudryashov.05121974@postgrespro.ru", "phone": "+70608331013"}
0005433650700	C5D7BE	0910 620119	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr1976@postgrespro.ru", "phone": "+70970103411"}
0005433650701	C5D7BE	8032 316456	ANDREY IVANOV	{"phone": "+70701798098"}
0005433650702	937FF4	4812 181239	VALENTIN FILIPPOV	{"phone": "+70342713780"}
0005433650703	32760F	4687 280344	OLGA VOLKOVA	{"phone": "+70980458539"}
0005433650704	F03FA3	9422 938314	NATALYA ANDREEVA	{"phone": "+70134854750"}
0005433650705	90FC4F	7583 756424	MAKSIM SOKOLOV	{"phone": "+70276997813"}
0005433650706	90FC4F	3559 719694	NATALYA OVCHINNIKOVA	{"email": "natalya.ovchinnikova_1958@postgrespro.ru", "phone": "+70352758185"}
0005433650707	515DE3	3839 822217	ANATOLIY FEDOTOV	{"email": "fedotov_a031973@postgrespro.ru", "phone": "+70333450916"}
0005433650708	515DE3	0816 026417	ANTON PAVLOV	{"email": "anton_pavlov.1961@postgrespro.ru", "phone": "+70675156690"}
0005433650709	960DFE	8353 899682	EVGENIY KONOVALOV	{"email": "konovalove-051978@postgrespro.ru", "phone": "+70526295088"}
0005433650710	960DFE	2021 797733	EKATERINA FEDOROVA	{"email": "ekaterina.fedorova.021971@postgrespro.ru", "phone": "+70679060892"}
0005433650711	7A4EE7	5581 557079	SOFIYA POPOVA	{"email": "spopova.1971@postgrespro.ru", "phone": "+70725851951"}
0005433650712	FD4673	5307 257913	GALINA NOVIKOVA	{"email": "novikova_galina061971@postgrespro.ru", "phone": "+70052931991"}
0005433650713	CA474A	8083 875892	SERGEY GAVRILOV	{"phone": "+70394341516"}
0005433650714	ED7774	9101 100727	ANNA ORLOVA	{"phone": "+70479546527"}
0005433650715	73B32B	3849 941225	DMITRIY ILIN	{"phone": "+70191762929"}
0005433650716	73B32B	3522 203527	ILSHAT MARTYNOV	{"phone": "+70671358906"}
0005433650717	AD4399	4369 838474	ELENA BOGDANOVA	{"phone": "+70545605420"}
0005433650718	AD4399	3482 625897	IGOR TIKHONOV	{"email": "i-tikhonov-1967@postgrespro.ru", "phone": "+70460599987"}
0005433650719	97CFA5	9121 806481	NATALYA IVANOVA	{"phone": "+70631194356"}
0005433650720	24B7DC	5172 208700	NIKOLAY MAKSIMOV	{"email": "maksimov-nikolay_031969@postgrespro.ru", "phone": "+70660185415"}
0005433650721	24B7DC	9533 650640	VLADIMIR EGOROV	{"email": "v-egorov-1971@postgrespro.ru", "phone": "+70171494650"}
0005433650722	8EB15B	0848 318085	DMITRIY PETROV	{"phone": "+70981477822"}
0005433650723	8EB15B	1142 250161	ANTONINA KUZNECOVA	{"email": "antonina.kuznecova.1974@postgrespro.ru", "phone": "+70100226916"}
0005433650724	E0B2D4	2788 864858	ALSU ZHUKOVA	{"email": "zhukovaa-111966@postgrespro.ru", "phone": "+70113548387"}
0005433650725	E0B2D4	6417 789173	ALEKSEY ANDREEV	{"email": "andreev-aleksey.1965@postgrespro.ru", "phone": "+70738926307"}
0005433650726	34B5C2	9264 085784	VITALIY SERGEEV	{"phone": "+70803425810"}
0005433650727	34B5C2	5331 805955	TATYANA NIKOLAEVA	{"email": "nikolaevat-081983@postgrespro.ru", "phone": "+70079484093"}
0005433650728	71D416	0359 441637	OLGA SEMENOVA	{"phone": "+70863770896"}
0005433650729	990E7B	7135 185417	MARIYA KOROLEVA	{"phone": "+70867068399"}
0005433650730	990E7B	5156 790302	MARAT KARPOV	{"phone": "+70314911149"}
0005433650731	990E7B	4136 475014	ALEKSEY SOLOVEV	{"email": "solovev-a_101970@postgrespro.ru", "phone": "+70435710277"}
0005433650732	808E95	1771 463537	NINA POPOVA	{"email": "n.popova091981@postgrespro.ru", "phone": "+70839855918"}
0005433650733	808E95	1258 411440	SERGEY STEPANOV	{"email": "sergey_stepanov071978@postgrespro.ru", "phone": "+70392221954"}
0005433650734	39D5DD	7545 640258	TATYANA TARASOVA	{"phone": "+70850219868"}
0005433650735	A296C6	7916 003912	GALINA IVANOVA	{"email": "ivanova_galina_1967@postgrespro.ru", "phone": "+70354697670"}
0005433650736	6EC45F	5607 780040	STANISLAV MIKHAYLOV	{"phone": "+70274898461"}
0005433650737	632F5D	6919 183975	KONSTANTIN MOISEEV	{"email": "konstantinmoiseev081974@postgrespro.ru", "phone": "+70202881586"}
0005433650738	CB26CB	9867 282331	SERGEY TARASOV	{"email": "tarasov-sergey-27021973@postgrespro.ru", "phone": "+70344121875"}
0005433650739	49DC3B	1550 609469	OLEG MAKAROV	{"email": "olegmakarov_27021976@postgrespro.ru", "phone": "+70915360748"}
0005433650740	4B9650	5126 481023	EKATERINA ANISIMOVA	{"phone": "+70498522177"}
0005433650741	E49C30	6945 781921	ALESYA KOROLEVA	{"email": "koroleva_a.041976@postgrespro.ru", "phone": "+70918878827"}
0005433650742	A4E641	8393 491856	TATYANA ABRAMOVA	{"phone": "+70390992992"}
0005433650743	73A03D	0371 327011	OLGA KONDRATEVA	{"phone": "+70135135856"}
0005433650744	73A03D	9609 642035	SOFYA KONDRATEVA	{"email": "skondrateva.10071964@postgrespro.ru", "phone": "+70223216064"}
0005433650745	73A03D	7569 583033	LEONID NIKOLAEV	{"email": "l.nikolaev_1975@postgrespro.ru", "phone": "+70507808479"}
0005433650746	7B9AA7	6262 269031	ANGELINA GERASIMOVA	{"email": "gerasimova_angelina.1974@postgrespro.ru", "phone": "+70303035097"}
0005433650747	7B9AA7	3824 310888	TATYANA SOKOLOVA	{"phone": "+70595439201"}
0005433650748	08D5AC	9453 698869	ANASTASIYA FEDOROVA	{"email": "anastasiya-fedorova.1967@postgrespro.ru", "phone": "+70397177774"}
0005433650749	7A324C	9488 524261	KLAVDIYA ANISIMOVA	{"phone": "+70512823204"}
0005433650750	833795	7839 746702	ALEKSANDR YAKOVLEV	{"phone": "+70421334812"}
0005433650751	833795	4853 850861	LYUBOV ZAKHAROVA	{"email": "l.zakharova07041973@postgrespro.ru", "phone": "+70605808411"}
0005433650752	C3E795	0665 301252	OLGA KUZNECOVA	{"email": "kuznecova-olga101958@postgrespro.ru", "phone": "+70533723993"}
0005433650753	1526B7	6498 943966	DENIS KARPOV	{"email": "deniskarpov_071982@postgrespro.ru", "phone": "+70458592886"}
0005433650754	918C39	2426 193548	TATYANA VASILEVA	{"email": "vasilevat.081980@postgrespro.ru", "phone": "+70125139751"}
0005433650755	47CF71	0853 393839	DMITRIY AFANASEV	{"phone": "+70740960734"}
0005433650756	E5A1E2	0487 898954	NIKOLAY KARPOV	{"phone": "+70028259462"}
0005433650757	E5A1E2	6793 809852	YULIYA ROMANOVA	{"email": "romanova.y_011975@postgrespro.ru", "phone": "+70839221381"}
0005433650758	FDCA51	1772 404238	ALEKSEY SEMENOV	{"phone": "+70426028889"}
0005433650759	8D26A1	4735 173774	VERA ABRAMOVA	{"phone": "+70028617037"}
0005433650760	737A1E	3058 683103	OLGA NIKOLAEVA	{"phone": "+70104978972"}
0005433650761	D25F89	6769 282822	NATALIYA OVCHINNIKOVA	{"email": "n.ovchinnikova_08061978@postgrespro.ru", "phone": "+70105820304"}
0005433650762	3AC5DD	2320 033102	ELENA GUSEVA	{"phone": "+70210951476"}
0005433650763	3AC5DD	0308 314549	VALENTIN MAKAROV	{"email": "vmakarov-08121978@postgrespro.ru", "phone": "+70244526542"}
0005433650764	3035BD	9939 144190	NIKITA SEMENOV	{"phone": "+70948995736"}
0005433650765	3035BD	7282 008916	DMITRIY TARASOV	{"phone": "+70123446479"}
0005433650766	C524FA	5554 304991	DMITRIY SERGEEV	{"email": "dmitriysergeev_06111979@postgrespro.ru", "phone": "+70462455280"}
0005433650767	609EFD	8325 545479	DMITRIY CHERNOV	{"email": "chernov_d-05081975@postgrespro.ru", "phone": "+70610088529"}
0005433650768	C88F3F	4301 050219	IGOR FOMIN	{"email": "fominigor_16071968@postgrespro.ru", "phone": "+70497908381"}
0005433650769	65FB17	4051 552089	NADEZHDA GUSEVA	{"email": "n_guseva1972@postgrespro.ru", "phone": "+70710618356"}
0005433650770	952A0D	5358 890770	ELENA MOROZOVA	{"phone": "+70463865743"}
0005433650771	E6C220	0733 113643	ANATOLIY KRASNOV	{"email": "krasnov-a.021979@postgrespro.ru", "phone": "+70870663529"}
0005433650772	E6C220	3184 159117	NINA PETROVA	{"email": "n_petrova.05081970@postgrespro.ru", "phone": "+70884206541"}
0005433650773	CBFE08	7038 052796	STANISLAV FROLOV	{"email": "stanislavfrolov-021972@postgrespro.ru", "phone": "+70979654504"}
0005433650774	7F0CFA	4991 159789	RAISA FOMINA	{"email": "rfomina-1973@postgrespro.ru", "phone": "+70845197881"}
0005433650775	F484AA	3375 134271	KARINA VLASOVA	{"email": "k.vlasova061963@postgrespro.ru", "phone": "+70057548634"}
0005433650776	F484AA	7590 016278	PAVEL STEPANOV	{"phone": "+70158626730"}
0005433650777	83E4EB	1558 264689	SVETLANA ANISIMOVA	{"phone": "+70509785497"}
0005433650778	83E4EB	7144 991961	MARINA IVANOVA	{"email": "m.ivanova-061971@postgrespro.ru", "phone": "+70436809178"}
0005433650779	8BCA11	0470 397703	VSEVOLOD SOLOVEV	{"phone": "+70934106951"}
0005433650780	33AF20	0089 611292	ANATOLIY ROMANOV	{"email": "aromanov_31031978@postgrespro.ru", "phone": "+70933970905"}
0005433650781	BCF63F	5170 089421	DMITRIY ANTONOV	{"phone": "+70940137831"}
0005433650782	C8C16C	9170 896972	TATYANA IVANOVA	{"phone": "+70495745586"}
0005433650783	DB65C7	8233 120576	DMITRIY IVANOV	{"email": "ivanov-d_1964@postgrespro.ru", "phone": "+70333379185"}
0005433650784	DB65C7	0005 442455	DARYA ALEKSEEVA	{"email": "alekseeva-darya02021976@postgrespro.ru", "phone": "+70348491201"}
0005433650785	506B49	0485 709607	OLGA POPOVA	{"phone": "+70396558076"}
0005433650786	506B49	0100 039791	DENIS SEMENOV	{"email": "denis.semenov1967@postgrespro.ru", "phone": "+70436877870"}
0005433650787	C548F1	9410 655814	LYUBOV ZOTOVA	{"email": "zotova_l_021980@postgrespro.ru", "phone": "+70724185949"}
0005433650788	020495	3206 535423	IGOR GUSEV	{"phone": "+70493204166"}
0005433650789	4C8A08	6969 154375	ANATOLIY DENISOV	{"email": "a_denisov1975@postgrespro.ru", "phone": "+70013203371"}
0005433650790	358A7B	1265 604070	NADEZHDA MEDVEDEVA	{"phone": "+70799836702"}
0005433650791	AF1566	6527 681173	ALEKSEY FROLOV	{"email": "frolova-18061971@postgrespro.ru", "phone": "+70790889149"}
0005433650792	493543	6813 515643	ANDREY FILIPPOV	{"phone": "+70274998949"}
0005433650793	1D5838	2211 653846	GENNADIY SOKOLOV	{"phone": "+70018263499"}
0005433650794	80A8BF	1813 853356	NATALYA GUSEVA	{"phone": "+70005852451"}
0005433650795	80A8BF	7511 686293	PETR EGOROV	{"phone": "+70370877521"}
0005433650796	80A8BF	8613 575285	GLEB NOVIKOV	{"email": "gleb.novikov01091973@postgrespro.ru", "phone": "+70266643294"}
0005433650797	133361	1089 827270	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov061975@postgrespro.ru", "phone": "+70032699975"}
0005433650798	C7B268	1281 158123	EVGENIY BELOV	{"email": "belov.evgeniy_051970@postgrespro.ru", "phone": "+70298163862"}
0005433650799	F9B9A8	5579 407071	NADEZHDA VLASOVA	{"email": "nvlasova-07061967@postgrespro.ru", "phone": "+70294749028"}
0005433650800	DD4F70	8362 818058	GULNARA KONDRATEVA	{"email": "gkondrateva-1971@postgrespro.ru", "phone": "+70683383506"}
0005433650801	6896D6	0195 697998	ALEKSEY ALEKSEEV	{"email": "aleksey-alekseev03051965@postgrespro.ru", "phone": "+70149852375"}
0005433650802	9802D0	8782 770957	DAVID ALEKSEEV	{"email": "d_alekseev-011976@postgrespro.ru", "phone": "+70937179929"}
0005433650803	C8D913	6947 258679	VASILIY MOROZOV	{"phone": "+70234128586"}
0005433650804	C8D913	9133 820893	MIKHAIL PETROV	{"email": "petrov.mikhail.1962@postgrespro.ru", "phone": "+70283716552"}
0005433650805	859372	3089 483773	NIKOLAY SOLOVEV	{"phone": "+70773600699"}
0005433650806	859372	3486 220997	SERGEY ABRAMOV	{"phone": "+70438469372"}
0005433650807	902503	0220 059087	KONSTANTIN ILIN	{"email": "ilin_k.26071964@postgrespro.ru", "phone": "+70987785496"}
0005433650808	952713	4611 549789	VALENTINA FEDOROVA	{"email": "v.fedorova1969@postgrespro.ru", "phone": "+70286180249"}
0005433650809	1CBAF9	3282 003994	ZOYA ZHUKOVA	{"email": "zoya.zhukova_1961@postgrespro.ru", "phone": "+70051242875"}
0005433650810	1D60B9	8035 159549	NATALYA NESTEROVA	{"email": "nesterova.natalya_021974@postgrespro.ru", "phone": "+70690797216"}
0005433650811	1D60B9	1430 964412	TATYANA TITOVA	{"phone": "+70639977945"}
0005433650812	74AAF6	9161 303256	ALEKSEY BONDARENKO	{"phone": "+70118004634"}
0005433650813	74AAF6	1037 205601	DMITRIY IVANOV	{"phone": "+70121533172"}
0005433650814	AB0ED1	5450 601070	VALENTINA NESTEROVA	{"phone": "+70177528796"}
0005433650815	AB0ED1	0086 821270	OLGA KOMAROVA	{"email": "komarova_olga30121973@postgrespro.ru", "phone": "+70713500683"}
0005433650816	F3A978	2944 858152	TATYANA FILATOVA	{"phone": "+70101326892"}
0005433650817	F3A978	0803 763149	ROMAN GRIGOREV	{"email": "grigorev-roman1959@postgrespro.ru", "phone": "+70756002235"}
0005433650818	5EE95F	8261 148209	NATALYA POPOVA	{"phone": "+70797272844"}
0005433650819	497481	2899 142207	ARTEM ZHUKOV	{"email": "a_zhukov.13031958@postgrespro.ru", "phone": "+70481374570"}
0005433650820	497481	0419 026465	YULIYA DMITRIEVA	{"email": "y_dmitrieva.13011974@postgrespro.ru", "phone": "+70833012375"}
0005433650821	E351EA	9634 434991	OLEG ZAKHAROV	{"email": "ozakharov091966@postgrespro.ru", "phone": "+70106238006"}
0005433650822	2B9443	2380 619529	PAVEL GORBUNOV	{"email": "gorbunov_pavel.03011975@postgrespro.ru", "phone": "+70793983625"}
0005433650823	24DF27	7377 625129	VLADIMIR PETROV	{"phone": "+70269109094"}
0005433650824	B3FDB8	4902 948388	EVGENIYA MOISEEVA	{"phone": "+70669612949"}
0005433650825	DEE993	9549 778506	ALINA MOISEEVA	{"email": "a_moiseeva-06011972@postgrespro.ru", "phone": "+70968953361"}
0005433650826	AB2E9B	3458 929768	DMITRIY SMIRNOV	{"email": "smirnov.dmitriy-1964@postgrespro.ru", "phone": "+70968287448"}
0005433650827	AB2E9B	3166 739304	LARISA MIKHAYLOVA	{"phone": "+70812263314"}
0005433650828	AB2E9B	2866 239675	ANDREY TIMOFEEV	{"phone": "+70459789243"}
0005433650829	47AA09	8280 954396	LIDIYA KUDRYASHOVA	{"email": "kudryashovalidiya111966@postgrespro.ru", "phone": "+70746066781"}
0005433650830	D6E1AC	1396 953746	ELENA SIDOROVA	{"phone": "+70928199064"}
0005433650831	D6E1AC	5194 865570	ALEKSEY GERASIMOV	{"phone": "+70721454655"}
0005433650832	9CA1D4	4035 280233	KONSTANTIN IVANOV	{"email": "ivanov_k.1970@postgrespro.ru", "phone": "+70526664285"}
0005433650833	32723A	6646 095220	IVAN KUZNECOV	{"email": "kuznecov_i.051975@postgrespro.ru", "phone": "+70889290779"}
0005433650834	877281	3551 345408	SERGEY KUZMIN	{"email": "sergey.kuzmin.061975@postgrespro.ru", "phone": "+70943350920"}
0005433650835	877281	5529 610614	ALEKSEY FEDOROV	{"email": "fedorovaleksey-19041976@postgrespro.ru", "phone": "+70946177395"}
0005433650836	D81C05	7915 093230	SVETLANA MATVEEVA	{"phone": "+70704908005"}
0005433650837	2F8DD1	5220 966442	ALEKSANDR POPOV	{"phone": "+70419067792"}
0005433650838	2F8DD1	8559 733579	ANDREY POPOV	{"phone": "+70066310861"}
0005433650839	4AACBA	3014 719739	ALEKSEY PAVLOV	{"email": "a_pavlov_18101971@postgrespro.ru", "phone": "+70924074801"}
0005433650840	79BC77	2224 004831	BORIS MOISEEV	{"email": "moiseev_boris27101966@postgrespro.ru", "phone": "+70063370411"}
0005433650841	0B2F80	4508 207736	SVETLANA FROLOVA	{"email": "frolova-s_061978@postgrespro.ru", "phone": "+70700063443"}
0005433650842	6429E8	0288 461943	ELENA PETROVA	{"email": "elenapetrova1960@postgrespro.ru", "phone": "+70398019463"}
0005433650843	C44E51	6344 710819	SERGEY SOROKIN	{"phone": "+70827503255"}
0005433650844	AEBD88	6414 503466	ALEKSEY ANDREEV	{"email": "a_andreev.22051978@postgrespro.ru", "phone": "+70601247230"}
0005433650845	CC0973	6647 693506	ANASTASIYA ALEKSEEVA	{"email": "a.alekseeva.31051971@postgrespro.ru", "phone": "+70072609348"}
0005433650846	EE5E3B	0692 786519	MARGARITA KUZNECOVA	{"phone": "+70147128285"}
0005433650847	EE5E3B	2994 457319	ANDREY KUDRYASHOV	{"email": "a_kudryashov_1989@postgrespro.ru", "phone": "+70298163674"}
0005433650848	645399	7699 701219	ALEKSANDR BORISOV	{"email": "a-borisov_1990@postgrespro.ru", "phone": "+70753832962"}
0005433650849	D50F60	2014 965297	EVGENIY NIKOLAEV	{"email": "nikolaev.e.091977@postgrespro.ru", "phone": "+70748503176"}
0005433650850	D76FC9	0632 964449	DMITRIY SMIRNOV	{"phone": "+70193884204"}
0005433650851	D76FC9	5940 152846	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko.1972@postgrespro.ru", "phone": "+70224513575"}
0005433650852	B436F9	0845 063054	ELENA MAKAROVA	{"phone": "+70676115726"}
0005433650853	FA380E	2331 624434	EKATERINA KOMAROVA	{"email": "ekaterina-komarova.091962@postgrespro.ru", "phone": "+70176425623"}
0005433650854	5F47A0	8222 095015	YULIYA DMITRIEVA	{"email": "dmitrievay1974@postgrespro.ru", "phone": "+70056154263"}
0005433650855	DBFC74	9845 231384	BORIS TIKHONOV	{"email": "tikhonovb.081973@postgrespro.ru", "phone": "+70992730376"}
0005433650856	16C09A	9122 346472	YANA ORLOVA	{"phone": "+70521504099"}
0005433650857	9068F0	7013 833178	GALINA PAVLOVA	{"email": "galina.pavlova_19031972@postgrespro.ru", "phone": "+70844512419"}
0005433650858	9068F0	9554 645137	ARTEM MOISEEV	{"phone": "+70582490767"}
0005433650859	ADFC5F	5745 758281	ZINAIDA YAKOVLEVA	{"email": "zinaida-yakovleva.13081961@postgrespro.ru", "phone": "+70746237164"}
0005433650860	0E6133	4519 013578	ALEVTINA BARANOVA	{"email": "baranova.alevtina_1968@postgrespro.ru", "phone": "+70337899160"}
0005433650861	052EF5	4930 503796	KLAVDIYA VASILEVA	{"email": "vasileva.klavdiya_1976@postgrespro.ru", "phone": "+70928731697"}
0005433650862	36AB3E	5294 895213	TATYANA MOROZOVA	{"phone": "+70442807778"}
0005433650863	CC2916	5497 550627	SERGEY VASILEV	{"email": "vasilevs.011984@postgrespro.ru", "phone": "+70134821637"}
0005433650864	CC2916	7454 223537	MAKSIM KARPOV	{"email": "karpov_maksim_1974@postgrespro.ru", "phone": "+70980310116"}
0005433650865	A3A076	9116 348902	MIKHAIL YAKOVLEV	{"email": "mikhail_yakovlev_051964@postgrespro.ru", "phone": "+70795840147"}
0005433650866	5324B5	5111 146461	ANNA DAVYDOVA	{"email": "a_davydova101983@postgrespro.ru", "phone": "+70404988133"}
0005433650867	577D6C	3329 566576	ELENA SMIRNOVA	{"phone": "+70657046186"}
0005433650868	577D6C	2253 828598	GRIGORIY RODIONOV	{"phone": "+70506802106"}
0005433650869	A8B4D4	0075 806216	GENNADIY DAVYDOV	{"email": "davydov_g_07101967@postgrespro.ru", "phone": "+70417061975"}
0005433650870	8C7C97	1904 242471	OLGA ANISIMOVA	{"email": "o_anisimova-1966@postgrespro.ru", "phone": "+70423067459"}
0005433650871	B80A5E	1437 185974	ALEKSANDR DENISOV	{"email": "denisov_aleksandr_23081963@postgrespro.ru", "phone": "+70173767719"}
0005433650872	95CEB2	0077 542011	TATYANA BORISOVA	{"email": "borisova-tatyana101982@postgrespro.ru", "phone": "+70353915590"}
0005433650873	95CEB2	0671 149782	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir_04061968@postgrespro.ru", "phone": "+70009317815"}
0005433650874	10FC20	1558 675025	ALEKSANDR SEMENOV	{"phone": "+70662778695"}
0005433650875	CD5FB7	2680 567735	ANTON ALEKSEEV	{"phone": "+70991189676"}
0005433650876	BCB9E9	4662 576278	ALEKSANDR GUSEV	{"email": "aleksandr.gusev031974@postgrespro.ru", "phone": "+70478788386"}
0005433650877	BCB9E9	1378 493795	ANDREY IVANOV	{"email": "ivanov_andrey-13031966@postgrespro.ru", "phone": "+70952297849"}
0005433650878	55B517	7338 487767	STANISLAV VASILEV	{"email": "vasilevs13111966@postgrespro.ru", "phone": "+70025660729"}
0005433650879	6D202C	3333 059470	VLADIMIR RODIONOV	{"phone": "+70927358122"}
0005433650880	6D202C	3785 457547	MAKSIM NAZAROV	{"email": "mnazarov_021976@postgrespro.ru", "phone": "+70717299770"}
0005433650881	BF965D	5484 438070	GENNADIY FEDOTOV	{"phone": "+70481119472"}
0005433650882	36DAF4	7354 848192	ALEKSANDR ANTONOV	{"email": "antonovaleksandr-1977@postgrespro.ru", "phone": "+70855478973"}
0005433650883	ACAC2D	6013 038207	YURIY TARASOV	{"email": "y.tarasov-1978@postgrespro.ru", "phone": "+70011779348"}
0005433650884	B920BC	9366 679232	ELENA BELYAEVA	{"phone": "+70776165654"}
0005433650885	1C06A2	6292 910444	ANNA VOLKOVA	{"email": "avolkova-091971@postgrespro.ru", "phone": "+70140105601"}
0005433650886	4A0447	1641 013495	IVAN KUZNECOV	{"email": "kuznecov-ivan.041977@postgrespro.ru", "phone": "+70788804449"}
0005433650887	94FD3D	2103 188278	EVGENIY GERASIMOV	{"phone": "+70556824510"}
0005433650888	BE26DD	1439 033731	OLEG PAVLOV	{"email": "o.pavlov_071968@postgrespro.ru", "phone": "+70486524359"}
0005433650889	624CF4	4269 481534	LYUBOV VASILEVA	{"phone": "+70795679568"}
0005433650890	46E2A5	0762 451422	NATALYA SOROKINA	{"email": "sorokina-n.29051973@postgrespro.ru", "phone": "+70796328677"}
0005433650891	AA3BAB	4786 544220	MARIYA GUSEVA	{"phone": "+70272689819"}
0005433650892	1C3688	8992 446118	NATALYA EGOROVA	{"phone": "+70983888291"}
0005433650893	F6E2B9	2188 468391	ANDREY KUZMIN	{"email": "a.kuzmin101977@postgrespro.ru", "phone": "+70616786584"}
0005433650894	0EC3C0	0442 259824	DARYA BORISOVA	{"phone": "+70055987729"}
0005433650895	0EC3C0	9344 805257	VLADIMIR KUZMIN	{"email": "kuzminv.011979@postgrespro.ru", "phone": "+70962608666"}
0005433650896	537C64	5781 017195	EKATERINA GORBUNOVA	{"phone": "+70592749982"}
0005433650897	A8037E	5750 259469	MARINA ABRAMOVA	{"phone": "+70491924437"}
0005433650898	93705E	6796 340945	KARINA EGOROVA	{"email": "k-egorova-1976@postgrespro.ru", "phone": "+70455594959"}
0005433650899	148E47	8241 812320	TATYANA ANTONOVA	{"phone": "+70481090874"}
0005433650900	148E47	8505 124612	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr-06041964@postgrespro.ru", "phone": "+70091990304"}
0005433650901	75FE60	4471 509440	NIKOLAY AFANASEV	{"email": "afanasev_nikolay01111975@postgrespro.ru", "phone": "+70101264267"}
0005433650902	75FE60	3722 487239	ALEKSANDR KUZMIN	{"phone": "+70912153002"}
0005433650903	A118D5	9868 724560	EVGENIYA DENISOVA	{"email": "e_denisova-121970@postgrespro.ru", "phone": "+70213111444"}
0005433650904	BF69EF	2263 239697	ANTON KONOVALOV	{"email": "konovalov-anton_041979@postgrespro.ru", "phone": "+70549443940"}
0005433650905	BF69EF	4769 184817	SERGEY ISAEV	{"phone": "+70190764547"}
0005433650906	BF69EF	3216 738911	EVGENIY ZAKHAROV	{"phone": "+70030027600"}
0005433650907	BF69EF	1383 302777	NATALYA NAZAROVA	{"phone": "+70962511660"}
0005433650908	9C3EEA	9876 341920	KONSTANTIN POPOV	{"phone": "+70863387622"}
0005433650909	19CDCE	7796 791123	VYACHESLAV KOZLOV	{"phone": "+70463366210"}
0005433650910	6FFCB3	3097 152765	ELENA EFREMOVA	{"email": "elena_efremova101972@postgrespro.ru", "phone": "+70430270665"}
0005433650911	6FFCB3	3512 075273	ANNA YUDINA	{"email": "ayudina051978@postgrespro.ru", "phone": "+70291557467"}
0005433650912	6FFCB3	0414 158933	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov.091985@postgrespro.ru", "phone": "+70844089798"}
0005433650913	117456	8586 445918	EVGENIYA BORISOVA	{"phone": "+70094873975"}
0005433650914	303A21	0228 055612	ELENA PETROVA	{"email": "petrova.elena_1972@postgrespro.ru", "phone": "+70216906329"}
0005433650915	9CD938	0211 419191	RAMIL ZAKHAROV	{"email": "rzakharov-29041966@postgrespro.ru", "phone": "+70371794448"}
0005433650916	1D0E5A	6573 013530	OLGA IVANOVA	{"phone": "+70990495653"}
0005433650917	84EF41	7589 655949	ANASTASIYA KOVALEVA	{"phone": "+70070313994"}
0005433650918	84EF41	9605 484293	GALINA ILINA	{"phone": "+70623350119"}
0005433650919	9247E7	1982 977419	ALEKSANDR KARPOV	{"email": "a_karpov-121970@postgrespro.ru", "phone": "+70903263414"}
0005433650920	CE8C42	0251 135044	LYUBOV EFREMOVA	{"email": "efremova-l_1974@postgrespro.ru", "phone": "+70249543449"}
0005433650921	479B4C	8581 474395	ZULFIYA ILINA	{"email": "ilina-z-1974@postgrespro.ru", "phone": "+70488427820"}
0005433650922	0441FD	6494 895109	ANATOLIY DENISOV	{"phone": "+70604243528"}
0005433650923	82F6AC	8955 818399	LARISA KUZNECOVA	{"phone": "+70409307789"}
0005433650924	F5F072	2555 371211	NIKITA KOZLOV	{"phone": "+70364543595"}
0005433650925	F5F072	7459 872234	PELAGEYA PAVLOVA	{"phone": "+70436949337"}
0005433650926	FF5F8E	8376 271347	ROMAN TIMOFEEV	{"email": "rtimofeev-071967@postgrespro.ru", "phone": "+70074855859"}
0005433650927	29539B	6316 126755	EKATERINA BARANOVA	{"phone": "+70433579388"}
0005433650928	29539B	2483 553277	YURIY MATVEEV	{"phone": "+70828290248"}
0005433650929	F1B813	8888 399775	VLADIMIR KULIKOV	{"email": "kulikov.vladimir-1972@postgrespro.ru", "phone": "+70622800401"}
0005433650930	9B2ACD	8831 563617	EKATERINA KAZAKOVA	{"email": "e.kazakova_07041965@postgrespro.ru", "phone": "+70385024895"}
0005433650931	7B5881	2584 417761	ANASTASIYA IVANOVA	{"email": "aivanova.21051969@postgrespro.ru", "phone": "+70520206290"}
0005433650932	D313F3	5296 468830	TATYANA KUZMINA	{"email": "t-kuzmina_031964@postgrespro.ru", "phone": "+70587060788"}
0005433650933	D313F3	2791 021856	ELENA VOLKOVA	{"phone": "+70816812932"}
0005433650934	EDD8E8	3696 787167	VLADIMIR KISELEV	{"email": "kiselev.v08061958@postgrespro.ru", "phone": "+70528641679"}
0005433650935	A858F2	1483 214728	EVGENIYA ZHUKOVA	{"email": "evgeniya_zhukova061969@postgrespro.ru", "phone": "+70435862815"}
0005433650936	A858F2	4435 029400	INNA SERGEEVA	{"email": "i_sergeeva-1972@postgrespro.ru", "phone": "+70174551071"}
0005433650937	168670	2554 638602	NINA STEPANOVA	{"phone": "+70499059685"}
0005433650938	9A65D1	9505 475509	GRIGORIY ZAKHAROV	{"email": "zakharov_grigoriy.121968@postgrespro.ru", "phone": "+70169502988"}
0005433650939	9A65D1	0067 081506	EVGENIYA NAZAROVA	{"email": "nazarova.e.15101968@postgrespro.ru", "phone": "+70855912997"}
0005433650940	89A3EF	6191 452181	ALEKSEY SMIRNOV	{"phone": "+70508720834"}
0005433650941	89A3EF	9780 940544	KONSTANTIN ZHUKOV	{"email": "kzhukov.10041956@postgrespro.ru", "phone": "+70671790503"}
0005433650942	8BD0EA	7094 338668	TATYANA POLYAKOVA	{"email": "polyakova-t.031980@postgrespro.ru", "phone": "+70660831532"}
0005433650943	628A78	9773 439473	KHALIDA SEMENOVA	{"email": "khalida-semenova-081979@postgrespro.ru", "phone": "+70466718328"}
0005433650944	628A78	4146 480604	VLADIMIR FILIPPOV	{"email": "filippovv021976@postgrespro.ru", "phone": "+70773966287"}
0005433650945	6C2DE8	5400 284553	GENNADIY MAKAROV	{"email": "gmakarov-05011973@postgrespro.ru", "phone": "+70306810099"}
0005433650946	6C2DE8	4290 716661	DMITRIY KUZNECOV	{"phone": "+70980291577"}
0005433650947	6C2DE8	3798 826727	POLINA GRISHINA	{"phone": "+70956535439"}
0005433650948	DCDB69	7756 928779	SERGEY GAVRILOV	{"email": "gavrilov-s.071972@postgrespro.ru", "phone": "+70088244475"}
0005433650949	853BD3	0316 416604	VIKTOR KARPOV	{"phone": "+70766639489"}
0005433650950	493D61	8251 326083	PAVEL NIKOLAEV	{"phone": "+70505341677"}
0005433650951	60F607	9067 494610	ALEKSANDRA TIMOFEEVA	{"email": "aleksandratimofeeva-25011965@postgrespro.ru", "phone": "+70167622777"}
0005433650952	CFB61B	5757 821613	NIKOLAY GORBUNOV	{"email": "gorbunov-nikolay_1972@postgrespro.ru", "phone": "+70072929160"}
0005433650953	CFB61B	3411 404093	ALEKSEY VASILEV	{"email": "vasilev.aleksey-021974@postgrespro.ru", "phone": "+70436165993"}
0005433650954	F60E70	5863 074023	LIDIYA ORLOVA	{"phone": "+70493897143"}
0005433650955	60E6D3	2859 926638	VIKTOR NIKITIN	{"phone": "+70250557163"}
0005433650956	80BC24	6426 354560	NINA ANDREEVA	{"email": "n.andreeva.03101963@postgrespro.ru", "phone": "+70889278853"}
0005433650957	80BC24	6305 586916	VLADIMIR NAZAROV	{"email": "nazarovv-11041976@postgrespro.ru", "phone": "+70721421098"}
0005433650958	2DFF82	0540 532787	OLGA FILATOVA	{"phone": "+70897344066"}
0005433650959	3EE115	4455 549579	ILYA KARPOV	{"email": "karpovi_11071965@postgrespro.ru", "phone": "+70033688807"}
0005433650960	7EDEA7	9270 055783	EKATERINA EFIMOVA	{"phone": "+70926122349"}
0005433650961	7EDEA7	6162 306747	VALENTINA GORBUNOVA	{"phone": "+70236546069"}
0005433650962	F89AEC	3033 924299	VIKTOR TARASOV	{"email": "tarasovviktor.1962@postgrespro.ru", "phone": "+70163800409"}
0005433650963	A912EB	9576 991992	VYACHESLAV VOLKOV	{"email": "volkovvyacheslav-1966@postgrespro.ru", "phone": "+70337188221"}
0005433650964	259C08	7529 900537	OLGA EGOROVA	{"phone": "+70801261636"}
0005433650965	49D21E	5683 073454	ALEKSANDR ABRAMOV	{"phone": "+70345557051"}
0005433650966	49D21E	3120 478574	DMITRIY MAKSIMOV	{"email": "maksimov_d-1971@postgrespro.ru", "phone": "+70569423787"}
0005433650967	9D59F7	5943 753797	VALERIY SOROKIN	{"phone": "+70094145966"}
0005433650968	9D59F7	2079 717197	MIKHAIL MATVEEV	{"phone": "+70837216925"}
0005433650969	DE311E	6675 864669	NATALYA ANDREEVA	{"phone": "+70667888088"}
0005433650970	D440A0	9774 249284	MAYA MELNIKOVA	{"phone": "+70650963170"}
0005433650971	B8CD18	2716 338382	VYACHESLAV NOVIKOV	{"email": "novikov_v1978@postgrespro.ru", "phone": "+70131319197"}
0005433650972	06A5E2	6220 182558	LYUDMILA KRASNOVA	{"phone": "+70039423815"}
0005433650973	473B09	0238 314658	SERGEY NIKOLAEV	{"phone": "+70979548698"}
0005433650974	B3B25F	2595 380659	EVGENIY PAVLOV	{"phone": "+70821071407"}
0005433650975	8B606A	3110 507018	EKATERINA ZHUKOVA	{"phone": "+70343164345"}
0005433650976	F93235	8079 381431	RAMIL VASILEV	{"phone": "+70350254785"}
0005433650977	F8115C	6691 569669	LYUDMILA MELNIKOVA	{"email": "melnikova-lyudmila-1976@postgrespro.ru", "phone": "+70313695343"}
0005433650978	DCF965	2484 670078	NIKOLAY AFANASEV	{"phone": "+70068565717"}
0005433650979	A89B11	0780 437077	IVAN SEMENOV	{"phone": "+70069919515"}
0005433650980	FE1E78	6026 945953	VIKTOR KONOVALOV	{"phone": "+70238586952"}
0005433650981	2E12ED	5143 282501	RUSLAN ANTONOV	{"email": "r.antonov1975@postgrespro.ru", "phone": "+70250181938"}
0005433650982	B7DE5F	6373 642633	ALEVTINA ILINA	{"email": "ilinaa_1970@postgrespro.ru", "phone": "+70777144697"}
0005433650983	B7DE5F	8869 914633	ILYA MAKAROV	{"phone": "+70404465100"}
0005433650984	10079A	2971 655733	VARVARA MEDVEDEVA	{"phone": "+70540460312"}
0005433650985	10079A	9502 142373	ANATOLIY KARPOV	{"email": "akarpov-061976@postgrespro.ru", "phone": "+70052825032"}
0005433650986	10079A	4145 537244	VERA OVCHINNIKOVA	{"phone": "+70111316499"}
0005433650987	10079A	1655 175044	TATYANA MOROZOVA	{"phone": "+70347429149"}
0005433650988	909891	1222 732480	EVGENIYA KISELEVA	{"phone": "+70199623501"}
0005433650989	909891	5675 375126	MIKHAIL DENISOV	{"phone": "+70965675167"}
0005433650990	870729	8123 084968	TATYANA MALYSHEVA	{"phone": "+70913392067"}
0005433650991	20918E	4747 239932	MAKSIM SIDOROV	{"phone": "+70115429337"}
0005433650992	E38C46	3217 419574	INNA SMIRNOVA	{"phone": "+70850433800"}
0005433650993	E38C46	5067 373931	GALINA KOLESNIKOVA	{"phone": "+70565300976"}
0005433650994	7D0BC2	2065 925651	VLADIMIR BORISOV	{"phone": "+70458834014"}
0005433650995	7D0BC2	2498 502492	ELENA MOISEEVA	{"email": "moiseeva_elena_041965@postgrespro.ru", "phone": "+70187501192"}
0005433650996	9E2CAE	4099 623396	MARYAM AKIMOVA	{"phone": "+70680409095"}
0005433650997	B63B4A	6602 330231	SERGEY SEMENOV	{"email": "semenov.s25031961@postgrespro.ru", "phone": "+70122399756"}
0005433650998	B63B4A	4590 227481	YULIYA MAKSIMOVA	{"email": "maksimova_yuliya10121963@postgrespro.ru", "phone": "+70134616006"}
0005433650999	B63B4A	0499 413485	SERGEY PAVLOV	{"email": "sergey-pavlov.19041959@postgrespro.ru", "phone": "+70759678699"}
0005433651000	2D4C32	0996 227733	ANNA FEDOROVA	{"email": "fedorova.anna.081974@postgrespro.ru", "phone": "+70766671518"}
0005433651001	D463CE	6720 890695	LARISA BORISOVA	{"phone": "+70849873824"}
0005433651002	D463CE	0015 958278	OLGA SMIRNOVA	{"email": "smirnovao.1972@postgrespro.ru", "phone": "+70629750417"}
0005433651003	61BBDD	8611 747372	DMITRIY KUDRYASHOV	{"email": "dmitriy-kudryashov-1966@postgrespro.ru", "phone": "+70718477044"}
0005433651004	CB421E	0307 597130	ALEKSEY SCHERBAKOV	{"phone": "+70593233868"}
0005433651005	4ACCC4	9611 645813	SVETLANA IVANOVA	{"phone": "+70967922694"}
0005433651006	4ACCC4	6978 395719	OLGA ZOTOVA	{"email": "zotova_olga15091974@postgrespro.ru", "phone": "+70323886828"}
0005433651007	F5318A	4463 174328	ALEKSANDR KISELEV	{"phone": "+70164613458"}
0005433651008	6C9137	1459 614858	VALERIY KOZLOV	{"email": "v-kozlov.011967@postgrespro.ru", "phone": "+70373458113"}
0005433651009	6C9137	7598 647467	ANTONIDA NAUMOVA	{"email": "antonidanaumova.06081977@postgrespro.ru", "phone": "+70769061886"}
0005433651010	6B7BCC	4265 736694	ELENA NIKOLAEVA	{"phone": "+70560547283"}
0005433651011	6B7BCC	4956 541734	SVETLANA DAVYDOVA	{"phone": "+70399078500"}
0005433651012	742BAD	6868 119366	LARISA ISAEVA	{"phone": "+70135150665"}
0005433651013	0E8F32	2080 662990	VALENTINA TIMOFEEVA	{"phone": "+70233141115"}
0005433651014	3B4794	6436 319577	NATALYA MOROZOVA	{"email": "morozovan-1979@postgrespro.ru", "phone": "+70821770612"}
0005433651015	9E3E0B	1296 872385	TATYANA MAKAROVA	{"phone": "+70445032599"}
0005433651016	9E3E0B	8027 960260	YURIY SEMENOV	{"email": "yuriy.semenov_21051981@postgrespro.ru", "phone": "+70610095866"}
0005433651017	9E3E0B	8968 238689	ALEKSEY VLASOV	{"email": "a.vlasov_121984@postgrespro.ru", "phone": "+70779997794"}
0005433651018	D16940	8703 487512	MIKHAIL POPOV	{"email": "popov.m-28071979@postgrespro.ru", "phone": "+70692420666"}
0005433651019	0DC66B	5965 831046	ANDREY KAZAKOV	{"phone": "+70854881418"}
0005433651020	0DC66B	3387 062144	OLGA LOGINOVA	{"phone": "+70375089943"}
0005433651021	26B772	5318 846579	TATYANA VOLKOVA	{"email": "tatyana_volkova-07021970@postgrespro.ru", "phone": "+70709339243"}
0005433651022	CF4AE7	1939 739753	VALENTINA KOROLEVA	{"phone": "+70699253954"}
0005433651023	BA44E4	4464 366380	IRINA AFANASEVA	{"phone": "+70128417121"}
0005433651024	BA44E4	6145 126146	VLADIMIR POPOV	{"email": "v-popov081968@postgrespro.ru", "phone": "+70148673767"}
0005433651025	8E6283	0657 934468	TATYANA IVANOVA	{"phone": "+70576595999"}
0005433651026	C01A86	4903 712040	OLGA GORBUNOVA	{"email": "olgagorbunova.14021980@postgrespro.ru", "phone": "+70960597486"}
0005433651027	21C3B3	9857 190605	IVAN ANDREEV	{"phone": "+70921926056"}
0005433651028	21C3B3	2714 173726	EGOR YAKOVLEV	{"email": "yakovlev.egor01021964@postgrespro.ru", "phone": "+70752723629"}
0005433651029	796100	2717 014056	NATALYA ZAKHAROVA	{"email": "nzakharova.111959@postgrespro.ru", "phone": "+70273601550"}
0005433651030	E2A878	8146 714786	ELENA DENISOVA	{"phone": "+70446808345"}
0005433651031	4959EA	5862 852973	MARIYA SEMENOVA	{"email": "semenovamariya25041962@postgrespro.ru", "phone": "+70016766893"}
0005433651032	204C4F	9821 108776	SERGEY ISAEV	{"phone": "+70395451111"}
0005433651033	DB49E6	3548 182907	LEV TIKHONOV	{"phone": "+70508412499"}
0005433651034	AF014A	0682 303390	MARINA ANISIMOVA	{"email": "anisimova-m_1966@postgrespro.ru", "phone": "+70609216783"}
0005433651035	1D5CB9	9704 959263	ANZHELIKA KUZNECOVA	{"phone": "+70619657009"}
0005433651036	4EEEC1	8543 892177	ARTEM SIDOROV	{"email": "sidorova031967@postgrespro.ru", "phone": "+70796129872"}
0005433651037	4734E5	4669 738816	SERGEY SERGEEV	{"phone": "+70275072051"}
0005433651038	6C0A0B	6277 647009	VALERIY KULIKOV	{"phone": "+70991829273"}
0005433651039	566003	2898 768980	RAILYA ABRAMOVA	{"email": "railya-abramova1977@postgrespro.ru", "phone": "+70257799968"}
0005433651040	8398B9	5549 967478	VALERIY GERASIMOV	{"email": "gerasimov_v.031973@postgrespro.ru", "phone": "+70447660447"}
0005433651041	856763	7966 110297	VALERIY FEDOTOV	{"email": "fedotov-v_1975@postgrespro.ru", "phone": "+70426632079"}
0005433651042	97066A	0153 607965	VLADIMIR MOISEEV	{"email": "moiseev_vladimir-20121974@postgrespro.ru", "phone": "+70473218847"}
0005433651043	6EA1A1	5224 583149	YURIY ANTONOV	{"email": "yuriy-antonov1972@postgrespro.ru", "phone": "+70662721837"}
0005433651044	6EA1A1	0861 533591	TATYANA OSIPOVA	{"email": "tatyana.osipova_091961@postgrespro.ru", "phone": "+70349668513"}
0005433651045	51C380	3935 475146	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov_06121970@postgrespro.ru", "phone": "+70884698463"}
0005433651046	711B1B	2336 541723	GENNADIY MOROZOV	{"phone": "+70593082482"}
0005433651047	634615	3628 748306	RAZIYA LEBEDEVA	{"email": "lebedeva.r-04071971@postgrespro.ru", "phone": "+70145421782"}
0005433651048	A02FBA	3408 196263	VADIM IVANOV	{"phone": "+70568728949"}
0005433651049	0A9BFE	7355 617798	VALENTINA FROLOVA	{"email": "frolova.v-011976@postgrespro.ru", "phone": "+70407332752"}
0005433651050	6D0447	2485 352834	MAKSIM BONDARENKO	{"email": "bondarenko_maksim04051973@postgrespro.ru", "phone": "+70362359879"}
0005433651051	6D0447	0787 473382	KLAVDIYA SAVELEVA	{"email": "klavdiyasaveleva.041974@postgrespro.ru", "phone": "+70735325917"}
0005433651052	6D0447	7274 213684	LYUBOV KONOVALOVA	{"phone": "+70416132367"}
0005433651053	AE06E5	1302 916255	PETR KUDRYASHOV	{"email": "kudryashovp.051976@postgrespro.ru", "phone": "+70571650081"}
0005433651054	AE06E5	2350 523562	NIKOLAY GRIGOREV	{"email": "grigorev.nikolay_07031962@postgrespro.ru", "phone": "+70348908371"}
0005433651055	AE06E5	0790 492045	LYUDMILA POPOVA	{"email": "l_popova.031971@postgrespro.ru", "phone": "+70361254140"}
0005433651056	7405E6	9865 311378	SVYATOSLAV DAVYDOV	{"phone": "+70372775513"}
0005433651057	7405E6	1856 429732	GRIGORIY ZAKHAROV	{"phone": "+70309960406"}
0005433651058	0170B0	4918 900753	OLGA TARASOVA	{"phone": "+70418008438"}
0005433651059	18119B	2275 624320	ANNA OSIPOVA	{"email": "a_osipova_1980@postgrespro.ru", "phone": "+70549941940"}
0005433651060	A9CE2C	4329 068529	VIKTOR KUZNECOV	{"phone": "+70163149103"}
0005433651061	A9CE2C	4861 334363	VASILIY MEDVEDEV	{"email": "medvedevvasiliy_08071962@postgrespro.ru", "phone": "+70114955916"}
0005433651062	A9CE2C	7371 353210	EGOR SERGEEV	{"phone": "+70030593531"}
0005433651063	032860	3807 693069	ALEKSANDR ABRAMOV	{"email": "a_abramov_051974@postgrespro.ru", "phone": "+70190608208"}
0005433651064	032860	0311 946878	IVAN KISELEV	{"email": "ivan-kiselev1962@postgrespro.ru", "phone": "+70421115665"}
0005433651065	6D9586	1105 365733	ALEKSEY MOISEEV	{"phone": "+70989005970"}
0005433651066	67297A	7655 634142	ELIZAVETA STEPANOVA	{"phone": "+70058714115"}
0005433651067	8409EA	9492 327234	GALINA ALEKSEEVA	{"phone": "+70989283319"}
0005433651068	87FC62	3978 907153	KRISTINA KALININA	{"phone": "+70312529472"}
0005433651069	87FC62	9090 248298	ALENA ISAEVA	{"email": "a_isaeva-1973@postgrespro.ru", "phone": "+70959169614"}
0005433651070	B392FD	5684 867159	VALERIY BORISOV	{"email": "borisovvaleriy-041967@postgrespro.ru", "phone": "+70957627191"}
0005433651071	B392FD	9085 099526	VIKTORIYA KUZNECOVA	{"phone": "+70801143391"}
0005433651072	B392FD	6072 367223	ALENA ALEKSANDROVA	{"phone": "+70664852954"}
0005433651073	1AC806	1373 247126	SERGEY SAVELEV	{"phone": "+70856260215"}
0005433651074	1AC806	0815 511450	DMITRIY IVANOV	{"email": "d-ivanov.041960@postgrespro.ru", "phone": "+70875106434"}
0005433651075	5ED8AA	3785 159326	SERGEY ALEKSEEV	{"email": "alekseev-sergey_1960@postgrespro.ru", "phone": "+70964784420"}
0005433651076	5ED8AA	2895 848018	YURIY KOZLOV	{"phone": "+70475737262"}
0005433651077	B846B2	7929 737488	ELENA EGOROVA	{"phone": "+70254601954"}
0005433651078	2B2C67	8553 582089	VLADIMIR PETROV	{"phone": "+70086871608"}
0005433651079	2B2C67	7813 838267	VLADISLAV VLASOV	{"email": "vlasov-vladislav1973@postgrespro.ru", "phone": "+70655519033"}
0005433651080	E818E4	3799 236992	LEYLA ZAKHAROVA	{"phone": "+70656622884"}
0005433651081	E3C12F	0648 356350	KLAVDIYA PETROVA	{"phone": "+70604565273"}
0005433651082	D6A7F7	5155 332064	TATYANA PAVLOVA	{"phone": "+70126819763"}
0005433651083	690BB0	2738 397643	SVETLANA NIKIFOROVA	{"phone": "+70940632285"}
0005433651084	690BB0	4919 556267	ANNA KUDRYASHOVA	{"email": "kudryashovaanna-27011982@postgrespro.ru", "phone": "+70925746228"}
0005433651085	D9E5BD	2254 758341	TAMARA ZAKHAROVA	{"email": "t.zakharova.06021977@postgrespro.ru", "phone": "+70471224386"}
0005433651086	F15771	2214 265944	NIKOLAY STEPANOV	{"email": "stepanov.n.1973@postgrespro.ru", "phone": "+70776029792"}
0005433651087	57FCD8	1925 402329	OLGA KRASNOVA	{"phone": "+70590764883"}
0005433651088	8F28F2	1559 658847	SERAFIM CHERNOV	{"email": "chernovs-01081968@postgrespro.ru", "phone": "+70016422227"}
0005433651089	0A3046	5417 297664	ANDREY ROMANOV	{"email": "andrey-romanov061971@postgrespro.ru", "phone": "+70825905623"}
0005433651090	0A3046	7139 202704	ALEKSEY KARPOV	{"email": "akarpov.1970@postgrespro.ru", "phone": "+70047439909"}
0005433651091	9D0DF4	4425 817209	VLADIMIR VASILEV	{"phone": "+70276141336"}
0005433651092	D7B530	9910 101388	DANIIL KONOVALOV	{"email": "daniilkonovalov27101977@postgrespro.ru", "phone": "+70026705533"}
0005433651093	9519D6	3716 876497	VLADIMIR ROMANOV	{"email": "vladimir_romanov_1959@postgrespro.ru", "phone": "+70024570758"}
0005433651094	9519D6	4357 194226	SERGEY FILIPPOV	{"phone": "+70478556476"}
0005433651095	BE5501	7573 730693	ILYA IVANOV	{"email": "i_ivanov011963@postgrespro.ru", "phone": "+70149543721"}
0005433651096	F76CD0	9143 166903	OLGA DAVYDOVA	{"phone": "+70977032649"}
0005433651097	0022B4	0343 902980	LYUBOV ISAEVA	{"phone": "+70173163605"}
0005433651098	0022B4	0792 702668	RAISA AKIMOVA	{"email": "raisa_akimova.03011973@postgrespro.ru", "phone": "+70326922451"}
0005433651099	0022B4	6852 553215	ALEVTINA KULIKOVA	{"email": "a_kulikova.07061972@postgrespro.ru", "phone": "+70532343097"}
0005433651100	6B63D1	1333 806602	MAKSIM DENISOV	{"email": "maksimdenisov_1964@postgrespro.ru", "phone": "+70726835534"}
0005433651101	BE2A34	7987 166247	OLGA MELNIKOVA	{"phone": "+70483724786"}
0005433651102	954BC5	3706 913508	VYACHESLAV ZHURAVLEV	{"email": "zhuravlev-v061973@postgrespro.ru", "phone": "+70275156203"}
0005433651103	954BC5	4468 939498	FARIDA KUZNECOVA	{"phone": "+70866211333"}
0005433651104	29CF39	7153 412391	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov1972@postgrespro.ru", "phone": "+70762051298"}
0005433651105	4F03FB	5782 716616	NINA IVANOVA	{"phone": "+70694041975"}
0005433651106	4F03FB	9391 339700	TATYANA YAKOVLEVA	{"phone": "+70509876819"}
0005433651107	14F322	2053 544203	OKSANA YAKOVLEVA	{"phone": "+70510817730"}
0005433651108	14F322	3112 862246	VARVARA PETROVA	{"phone": "+70287512270"}
0005433651109	215327	3558 504840	NATALYA KISELEVA	{"phone": "+70562767281"}
0005433654647	578416	2143 083652	VYACHESLAV GRIGOREV	{"phone": "+70218744165"}
0005433654648	531C92	4270 733845	ELENA LEBEDEVA	{"email": "elenalebedeva-08071970@postgrespro.ru", "phone": "+70658357170"}
0005433654649	72E758	0346 281259	ANDREY ANDREEV	{"email": "andrey-andreev19101972@postgrespro.ru", "phone": "+70045593446"}
0005433654650	FBE9BC	7637 231637	POLINA KALININA	{"phone": "+70035721792"}
0005433654651	405807	7789 669833	KSENIYA ALEKSEEVA	{"email": "kalekseeva_13051962@postgrespro.ru", "phone": "+70876099078"}
0005433654652	8A082A	0444 004721	YULIYA STEPANOVA	{"phone": "+70803114906"}
0005433654653	8A082A	7172 659275	OLGA ISAEVA	{"email": "isaeva.olga.29011964@postgrespro.ru", "phone": "+70530636937"}
0005433654654	B3D090	6286 416318	SERGEY ISAEV	{"phone": "+70923377721"}
0005433654655	3FC30A	2661 516259	MARINA DANILOVA	{"phone": "+70484142535"}
0005433654656	3FC30A	2517 418820	ALEKSANDRA KUZMINA	{"email": "aleksandra-kuzmina-1984@postgrespro.ru", "phone": "+70565868241"}
0005433654657	ED8E63	9387 371095	RUSLAN VOLKOV	{"email": "volkov-ruslan-1975@postgrespro.ru", "phone": "+70344089843"}
0005433654658	30EC96	8150 396721	VALENTINA KARPOVA	{"email": "v.karpova-1984@postgrespro.ru", "phone": "+70142938466"}
0005433654659	8E2A82	8301 203563	LEONID ANTONOV	{"phone": "+70264291150"}
0005433654660	8E2A82	7601 463917	VLADIMIR EGOROV	{"email": "v-egorov1974@postgrespro.ru", "phone": "+70031576898"}
0005433654661	8E2A82	6379 863522	YANA SIDOROVA	{"email": "yana_sidorova.1974@postgrespro.ru", "phone": "+70446425883"}
0005433654662	5F4899	0150 632524	VLADISLAV FEDOTOV	{"email": "vladislav-fedotov.1968@postgrespro.ru", "phone": "+70020617559"}
0005433654663	5F4899	5709 148358	VLADIMIR MOROZOV	{"phone": "+70244081306"}
0005433654664	489F36	0010 428341	ANNA MOROZOVA	{"phone": "+70865522679"}
0005433654665	CF911D	9914 221758	ZULFIYA PAVLOVA	{"email": "pavlova.z_1967@postgrespro.ru", "phone": "+70721716968"}
0005433654666	CECEAE	3366 203348	ANZHELIKA SEMENOVA	{"phone": "+70463888448"}
0005433654667	4A5490	2747 222322	DMITRIY GRIGOREV	{"email": "dmitriy.grigorev061970@postgrespro.ru", "phone": "+70134005142"}
0005433654668	680DF3	8823 257282	ANTON TIKHONOV	{"email": "tikhonovanton-1978@postgrespro.ru", "phone": "+70047305868"}
0005433654669	8282C2	9215 640559	MARGARITA YAKOVLEVA	{"email": "yakovlevam_101968@postgrespro.ru", "phone": "+70362467756"}
0005433654670	8282C2	8435 517252	LYUDMILA POTAPOVA	{"phone": "+70636154750"}
0005433654671	69C912	1244 661946	VLADIMIR KISELEV	{"phone": "+70522094502"}
0005433654672	0C5B07	4447 448369	ANDREY SMIRNOV	{"phone": "+70039204990"}
0005433654673	2C188B	2122 787488	DMITRIY MIKHAYLOV	{"email": "dmitriy.mikhaylov-1971@postgrespro.ru", "phone": "+70942706951"}
0005433654674	3D71B7	5410 570007	ALEKSEY IVANOV	{"phone": "+70902872843"}
0005433654675	A81F6F	9989 395852	OLEG MIRONOV	{"email": "oleg_mironov-18011968@postgrespro.ru", "phone": "+70791701244"}
0005433654676	A81F6F	5770 462619	EKATERINA RODIONOVA	{"email": "rodionovaekaterina.20101985@postgrespro.ru", "phone": "+70589073344"}
0005433654677	0953E0	0628 311086	SAMVEL PETROV	{"email": "samvel_petrov_10071968@postgrespro.ru", "phone": "+70318073621"}
0005433654678	53ED15	7990 508165	SERGEY PETROV	{"phone": "+70934698829"}
0005433654679	53ED15	7048 180112	LYUBOV TIMOFEEVA	{"email": "timofeeval_041982@postgrespro.ru", "phone": "+70235834170"}
0005433654680	53ED15	3036 704956	ANASTASIYA POPOVA	{"email": "a.popova.1975@postgrespro.ru", "phone": "+70029178640"}
0005433654681	952E80	3514 059492	EKATERINA ANDREEVA	{"phone": "+70357292512"}
0005433654682	7BF9FB	3578 070123	VIKTORIYA KUZNECOVA	{"phone": "+70155890988"}
0005433654683	9D00AF	5635 096737	ANGELINA CHERNOVA	{"phone": "+70953436393"}
0005433654684	FB6AD1	7143 681821	VALENTINA SERGEEVA	{"phone": "+70771058017"}
0005433654685	8D6955	8776 693204	SVETLANA VLASOVA	{"email": "vlasova.s1977@postgrespro.ru", "phone": "+70338430750"}
0005433654686	CA6B81	1547 975575	ANASTASIYA PAVLOVA	{"email": "pavlova-a-1968@postgrespro.ru", "phone": "+70934061180"}
0005433654687	CA6B81	4270 679449	ALEKSEY ROMANOV	{"phone": "+70800414909"}
0005433654688	A6F65D	7316 134684	DMITRIY IVANOV	{"phone": "+70744833225"}
0005433654689	A6F65D	7906 735981	VALENTINA LOGINOVA	{"email": "loginovav.031977@postgrespro.ru", "phone": "+70465506194"}
0005433654690	E7D826	9845 431539	YULIYA SOLOVEVA	{"phone": "+70943574308"}
0005433654691	703F78	0195 849348	IVAN GRIGOREV	{"email": "grigorev_ivan_031972@postgrespro.ru", "phone": "+70119669564"}
0005433654692	703F78	2119 246912	VALENTIN GRIGOREV	{"email": "grigorev.v_1975@postgrespro.ru", "phone": "+70814657711"}
0005433654693	0847BE	0058 088421	GALINA ANDREEVA	{"email": "andreeva.g.1976@postgrespro.ru", "phone": "+70186550517"}
0005433654694	DEB9B9	7073 343096	ANASTASIYA FILIPPOVA	{"email": "filippovaanastasiya1989@postgrespro.ru", "phone": "+70786325084"}
0005433654695	4CFA1E	9786 875178	EKATERINA IVANOVA	{"phone": "+70121549101"}
0005433654696	4CFA1E	6919 270159	IRINA ISAEVA	{"email": "isaeva-irina_1978@postgrespro.ru", "phone": "+70800046115"}
0005433654697	9D7810	9893 673426	ALEKSANDR IVANOV	{"email": "ivanov-a18051980@postgrespro.ru", "phone": "+70637624368"}
0005433654698	E15DE5	0369 914544	DINARA ANDREEVA	{"phone": "+70127189777"}
0005433654699	233D7F	6941 451242	BORIS SCHERBAKOV	{"email": "scherbakov.boris.1967@postgrespro.ru", "phone": "+70680969151"}
0005433654700	233D7F	6300 624169	YURIY NIKITIN	{"email": "nikitin_yuriy_071980@postgrespro.ru", "phone": "+70855934202"}
0005433654701	1D74A7	9215 711839	MIKHAIL ZAKHAROV	{"phone": "+70011286740"}
0005433654702	53C41C	0967 290111	DIANA RODIONOVA	{"phone": "+70381237064"}
0005433654703	72E1E5	4327 538249	MARINA VOLKOVA	{"phone": "+70906790363"}
0005433654704	72E1E5	7943 366859	DMITRIY ALEKSANDROV	{"email": "dmitriy.aleksandrov091972@postgrespro.ru", "phone": "+70785418427"}
0005433654705	72E1E5	2497 247934	LYUBOV POPOVA	{"email": "popovalyubov.12041971@postgrespro.ru", "phone": "+70475491834"}
0005433654706	9AB101	9580 730733	SERGEY ANTONOV	{"email": "antonov_sergey_04091968@postgrespro.ru", "phone": "+70936596229"}
0005433654707	9AB101	8003 117086	DAMIR GAVRILOV	{"phone": "+70865190933"}
0005433654708	5A8776	8421 090763	DARYA YUDINA	{"phone": "+70234685237"}
0005433654709	5A8776	3624 702647	ANTONINA SMIRNOVA	{"phone": "+70027241654"}
0005433654710	9A8D20	0220 745602	LIYA PETROVA	{"phone": "+70978108048"}
0005433654711	E88BE2	2146 548121	NATALYA KUZNECOVA	{"phone": "+70521327442"}
0005433654712	055994	7584 280194	NATALIYA STEPANOVA	{"email": "stepanova_n_09121975@postgrespro.ru", "phone": "+70860191164"}
0005433654713	055994	9050 087384	IRINA KOZLOVA	{"email": "kozlova.irina.09031974@postgrespro.ru", "phone": "+70659916229"}
0005433654714	A26E77	6812 889386	VIKTORIYA STEPANOVA	{"email": "stepanova-viktoriya1957@postgrespro.ru", "phone": "+70130738866"}
0005433654715	0CDF69	5085 805394	TAMARA YAKOVLEVA	{"phone": "+70909330552"}
0005433654716	720F90	3786 541347	VLADIMIR KONOVALOV	{"email": "vkonovalov-1975@postgrespro.ru", "phone": "+70469116775"}
0005433654717	67BA5E	3497 010103	PETR NAZAROV	{"phone": "+70076665695"}
0005433654718	AE3322	4445 931561	OLGA SERGEEVA	{"email": "olgasergeeva-26011978@postgrespro.ru", "phone": "+70675643861"}
0005433654719	AE3322	6322 626173	VALERIY MAKSIMOV	{"email": "v_maksimov_24051984@postgrespro.ru", "phone": "+70826725485"}
0005433654720	C7DD61	7367 786772	ANASTASIYA SEMENOVA	{"email": "semenovaanastasiya081972@postgrespro.ru", "phone": "+70978477363"}
0005433654721	C7DD61	3630 696839	OKSANA MOROZOVA	{"email": "o_morozova23101963@postgrespro.ru", "phone": "+70878744733"}
0005433654722	C7DD61	1424 314420	VLADIMIR KAZAKOV	{"email": "kazakovvladimir_17051980@postgrespro.ru", "phone": "+70775221105"}
0005433654723	90300C	2592 947931	YULIYA MELNIKOVA	{"phone": "+70997459238"}
0005433654724	22B0A5	6927 042038	VYACHESLAV KRASNOV	{"phone": "+70112745417"}
0005433654725	9B138B	3313 931303	OKSANA ZAKHAROVA	{"phone": "+70059738969"}
0005433654726	EF634F	9882 560819	MARIYA LOGINOVA	{"phone": "+70748408623"}
0005433654727	EF634F	3100 914534	DMITRIY ABRAMOV	{"email": "dmitriy_abramov-091969@postgrespro.ru", "phone": "+70853264806"}
0005433654728	EF634F	2934 332843	VLADIMIR GAVRILOV	{"phone": "+70337620118"}
0005433654729	988DB7	7949 050275	LIDIYA MIKHAYLOVA	{"email": "lidiyamikhaylova111970@postgrespro.ru", "phone": "+70476460020"}
0005433654730	310A1D	0705 762793	LYUDMILA SMIRNOVA	{"phone": "+70059584057"}
0005433654731	B1D684	5072 991338	MARIYA GORBUNOVA	{"phone": "+70809428104"}
0005433654732	DDFA7A	4167 796965	ALEKSANDR SIDOROV	{"email": "sidorov-a_20091967@postgrespro.ru", "phone": "+70190073950"}
0005433654733	DDFA7A	4603 447975	SVETLANA KISELEVA	{"phone": "+70980229939"}
0005433654734	DDFA7A	7077 750656	ANATOLIY GAVRILOV	{"email": "gavrilov_a041971@postgrespro.ru", "phone": "+70835428966"}
0005433654735	AB588F	0290 124928	VLADIMIR YAKOVLEV	{"phone": "+70843921007"}
0005433654736	85CFD7	8124 329344	OLGA SIDOROVA	{"email": "sidorovaolga15071965@postgrespro.ru", "phone": "+70757429090"}
0005433654737	C0B8C3	2915 919018	DMITRIY ALEKSEEV	{"email": "alekseev-d.1973@postgrespro.ru", "phone": "+70491158667"}
0005433654738	05A398	9898 080494	VALENTINA SERGEEVA	{"email": "sergeevavalentina-041974@postgrespro.ru", "phone": "+70945619764"}
0005433654739	06C81D	6549 415432	ALEKSANDR ALEKSEEV	{"phone": "+70124895467"}
0005433654740	06C81D	7882 902455	SVETLANA MAKAROVA	{"email": "makarovasvetlana1985@postgrespro.ru", "phone": "+70708864947"}
0005433654741	2E835C	6156 200539	NIKITA SMIRNOV	{"phone": "+70615784901"}
0005433654742	2C810D	8389 828285	NATALYA MOROZOVA	{"email": "morozova-n_1967@postgrespro.ru", "phone": "+70474219896"}
0005433654743	2C810D	9942 892538	OLGA KULIKOVA	{"email": "olga_kulikova.061977@postgrespro.ru", "phone": "+70206556839"}
0005433654744	9E09AA	6722 609357	ANGELINA SCHERBAKOVA	{"phone": "+70775479937"}
0005433654745	0A7EC0	7984 616212	VLADIMIR VASILEV	{"email": "vasilev_vladimir13081967@postgrespro.ru", "phone": "+70334309903"}
0005433654746	FE9C50	5861 956757	LARISA NAUMOVA	{"email": "l-naumova.24061968@postgrespro.ru", "phone": "+70922381000"}
0005433654747	FE9C50	5204 305836	KONSTANTIN BARANOV	{"email": "k_baranov_24081970@postgrespro.ru", "phone": "+70504821254"}
0005433654748	FE9C50	9601 281904	SERGEY VOLKOV	{"phone": "+70697809531"}
0005433654749	47BBA7	9245 468608	KRISTINA NOVIKOVA	{"email": "k-novikova.1971@postgrespro.ru", "phone": "+70803758154"}
0005433654750	47BBA7	5323 023740	AZAT TIMOFEEV	{"email": "azat.timofeev.1972@postgrespro.ru", "phone": "+70476557110"}
0005433654751	6AC284	0020 671228	EKATERINA NOVIKOVA	{"email": "novikova.e.12051982@postgrespro.ru", "phone": "+70742954469"}
0005433654752	FE8B6E	3022 109731	VLADIMIR STEPANOV	{"phone": "+70572782762"}
0005433654753	FE8B6E	0678 142695	ZOYA ZAYCEVA	{"email": "z_zayceva_08031978@postgrespro.ru", "phone": "+70021332674"}
0005433654754	4CFADC	3687 007675	NADEZHDA MOROZOVA	{"email": "morozova.n.01021988@postgrespro.ru", "phone": "+70464486980"}
0005433654755	F1EAEE	0209 994964	GALINA VASILEVA	{"email": "vasileva_galina-1970@postgrespro.ru", "phone": "+70367054265"}
0005433654756	278C6F	1898 733509	VARVARA NESTEROVA	{"phone": "+70484262442"}
0005433654757	278C6F	9543 123815	YURIY RODIONOV	{"email": "rodionov-y-25061969@postgrespro.ru", "phone": "+70885286777"}
0005433654758	278C6F	9518 039982	LYUBOV ZHURAVLEVA	{"email": "lyubov-zhuravleva_1974@postgrespro.ru", "phone": "+70006810389"}
0005433654759	FB9184	0971 572183	VALERIY SERGEEV	{"phone": "+70612548432"}
0005433654760	AC2D49	0223 760759	KIRILL KONOVALOV	{"email": "kirillkonovalov.051977@postgrespro.ru", "phone": "+70354063624"}
0005433654761	AC2D49	7658 101711	LYUBOV STEPANOVA	{"email": "stepanova-lyubov071963@postgrespro.ru", "phone": "+70589637831"}
0005433654762	43E54F	2364 977298	SERGEY ZAKHAROV	{"phone": "+70951894709"}
0005433654763	45F2C6	0142 454125	ANNA SERGEEVA	{"phone": "+70788584405"}
0005433654764	45F2C6	9857 554342	VYACHESLAV NOVIKOV	{"phone": "+70268912653"}
0005433654765	6C8E9F	1831 826554	VIKTOR GERASIMOV	{"email": "gerasimov.v-01101981@postgrespro.ru", "phone": "+70877472229"}
0005433654766	6C8E9F	0682 862744	ELENA NESTEROVA	{"email": "e.nesterova.23121972@postgrespro.ru", "phone": "+70871807315"}
0005433654767	8FE214	8581 779192	VALERIY KULIKOV	{"email": "v_kulikov-1973@postgrespro.ru", "phone": "+70557926213"}
0005433654825	64EC97	3287 386020	IGOR MOROZOV	{"phone": "+70101581103"}
0005433654768	A55F60	3409 663642	VALENTINA GRISHINA	{"email": "valentina.grishina.1971@postgrespro.ru", "phone": "+70596056541"}
0005433654769	A55F60	4212 850559	SERGEY FROLOV	{"phone": "+70994257000"}
0005433654770	A55F60	5129 053401	IVAN KOZLOV	{"phone": "+70898286650"}
0005433654771	B59C37	5323 868562	MARIYA OSIPOVA	{"email": "osipova_mariya011976@postgrespro.ru", "phone": "+70675988233"}
0005433654772	92A462	2898 826930	ZINAIDA PETROVA	{"email": "petrovaz_1971@postgrespro.ru", "phone": "+70170244736"}
0005433654773	11D225	8916 170662	NATALYA ORLOVA	{"email": "natalya-orlova-20041959@postgrespro.ru", "phone": "+70634487286"}
0005433654774	74DF00	2337 408738	NATALYA MOISEEVA	{"email": "moiseeva.n-111978@postgrespro.ru", "phone": "+70119754183"}
0005433654775	74DF00	8433 960323	YURIY DMITRIEV	{"email": "yuriy_dmitriev_1968@postgrespro.ru", "phone": "+70061020832"}
0005433654776	D4D56C	2094 095003	SERGEY GRIGOREV	{"email": "grigorevs-22061975@postgrespro.ru", "phone": "+70869273508"}
0005433654777	F501C6	6940 668814	SVETLANA MOROZOVA	{"email": "s-morozova.30041976@postgrespro.ru", "phone": "+70395527990"}
0005433654778	F501C6	4243 571342	ANASTASIYA ABRAMOVA	{"phone": "+70236181652"}
0005433654779	FE089F	9446 288328	ELENA MEDVEDEVA	{"email": "medvedeva-elena.121975@postgrespro.ru", "phone": "+70991983152"}
0005433654780	D63928	8676 058873	ELENA KULIKOVA	{"phone": "+70750889781"}
0005433654781	867ED6	2558 909992	GALINA VASILEVA	{"email": "galina.vasileva20061984@postgrespro.ru", "phone": "+70748092402"}
0005433654782	9269DD	1141 481839	DENIS ZAYCEV	{"phone": "+70234333742"}
0005433654783	9269DD	5858 050198	YULIYA VLASOVA	{"email": "y_vlasova_1962@postgrespro.ru", "phone": "+70935782846"}
0005433654784	9269DD	8808 680075	ANDREY VOLKOV	{"email": "a-volkov-1983@postgrespro.ru", "phone": "+70803912147"}
0005433654785	8BD3F9	9990 502497	SERGEY ANTONOV	{"email": "antonov_sergey-071974@postgrespro.ru", "phone": "+70918025118"}
0005433654786	6015EE	8926 506822	ALEKSANDR SOROKIN	{"email": "a-sorokin041957@postgrespro.ru", "phone": "+70627681114"}
0005433654787	6015EE	7295 903523	YULIYA POPOVA	{"phone": "+70902924134"}
0005433654788	6015EE	2187 313026	VITALIY KRASNOV	{"email": "v-krasnov1974@postgrespro.ru", "phone": "+70405857232"}
0005433654789	3373F0	8422 292407	KLAVDIYA KOZLOVA	{"phone": "+70808763833"}
0005433654790	1654FD	2026 088122	VIKTOR RODIONOV	{"phone": "+70330810590"}
0005433654791	1654FD	7497 767511	ALEKSEY PAVLOV	{"email": "pavlov-aleksey_011973@postgrespro.ru", "phone": "+70444512389"}
0005433654792	751405	1141 958216	VLADIMIR FEDOROV	{"phone": "+70853333057"}
0005433654793	4CA2D7	4041 069329	VIKTOR SMIRNOV	{"email": "smirnov.viktor_1979@postgrespro.ru", "phone": "+70254049723"}
0005433654794	019213	1414 604969	TATYANA KOROLEVA	{"email": "korolevatatyana_071954@postgrespro.ru", "phone": "+70986037128"}
0005433654795	5A12E9	2362 680004	DARYA KOLESNIKOVA	{"phone": "+70826578362"}
0005433654796	5A12E9	2727 716312	ALBINA FILIPPOVA	{"email": "filippova-albina1980@postgrespro.ru", "phone": "+70576442475"}
0005433654797	5A12E9	5640 700555	LYUBOV PETROVA	{"email": "petrova.l-01051975@postgrespro.ru", "phone": "+70461922364"}
0005433654798	F8787C	2950 815989	RINAT ZAYCEV	{"email": "rzaycev_26121977@postgrespro.ru", "phone": "+70502478653"}
0005433654799	41F9B7	3878 220589	ANNA ROMANOVA	{"phone": "+70340949910"}
0005433654800	36D06B	9267 564183	ALEKSANDR FEDOTOV	{"phone": "+70764393879"}
0005433654801	AB67E2	7312 616650	VLADIMIR PETROV	{"phone": "+70642865561"}
0005433654802	6B8ED6	8672 510286	IRINA VOLKOVA	{"email": "volkova-i.121980@postgrespro.ru", "phone": "+70120260289"}
0005433654803	B24A97	7961 005694	LYUDMILA YUDINA	{"phone": "+70123035573"}
0005433654804	19B8BA	8525 962211	NATALYA FROLOVA	{"phone": "+70935783649"}
0005433654805	39310B	5138 694273	LUIZA ZAKHAROVA	{"email": "zakharovaluiza_1973@postgrespro.ru", "phone": "+70206401956"}
0005433654806	39310B	3251 867139	VIKTOR TIMOFEEV	{"email": "v-timofeev23011981@postgrespro.ru", "phone": "+70600785141"}
0005433654807	14D770	2953 630506	OLGA SOKOLOVA	{"email": "sokolova-o_041971@postgrespro.ru", "phone": "+70923375312"}
0005433654808	14D770	2543 935449	ANDREY TARASOV	{"email": "andreytarasov_1969@postgrespro.ru", "phone": "+70058967441"}
0005433654809	978ED2	9755 401401	VYACHESLAV TIKHONOV	{"email": "vyacheslav_tikhonov-011974@postgrespro.ru", "phone": "+70955972078"}
0005433654810	D904E0	2855 956957	SVETLANA SAVELEVA	{"email": "s_saveleva-22011974@postgrespro.ru", "phone": "+70009650233"}
0005433654811	D904E0	6249 228893	ALEKSEY AFANASEV	{"email": "aleksey.afanasev.11011978@postgrespro.ru", "phone": "+70596850473"}
0005433654812	F64242	2270 795688	EVGENIY ABRAMOV	{"email": "e-abramov.101971@postgrespro.ru", "phone": "+70778150300"}
0005433654813	F64242	7495 398146	VLADISLAV SCHERBAKOV	{"email": "scherbakov_vladislav111968@postgrespro.ru", "phone": "+70777660613"}
0005433654814	1062CF	9811 884303	SVETLANA KUZNECOVA	{"phone": "+70242059760"}
0005433654815	AB94C2	8136 443696	EKATERINA NIKOLAEVA	{"email": "ekaterinanikolaeva_1977@postgrespro.ru", "phone": "+70148904196"}
0005433654816	AB94C2	8123 794284	VITALIY SERGEEV	{"phone": "+70581721427"}
0005433654817	50F01B	4202 843103	OLGA KISELEVA	{"email": "kiseleva-olga18111970@postgrespro.ru", "phone": "+70455849913"}
0005433654818	E41D07	2061 924965	TATYANA FADEEVA	{"email": "t-fadeeva.09091976@postgrespro.ru", "phone": "+70044846935"}
0005433654819	E41D07	7356 585452	VLADISLAV MEDVEDEV	{"email": "medvedevv101970@postgrespro.ru", "phone": "+70166217447"}
0005433654820	9E8756	1021 801798	ALEKSANDR FEDOROV	{"email": "fedorova-1982@postgrespro.ru", "phone": "+70599744261"}
0005433654821	53E81B	2685 014371	DMITRIY KUZMIN	{"email": "d-kuzmin-051971@postgrespro.ru", "phone": "+70543365848"}
0005433654822	ECE5C7	1282 457085	OKSANA MATVEEVA	{"email": "matveeva.o1973@postgrespro.ru", "phone": "+70871440409"}
0005433654823	ECE5C7	0908 159990	YURIY ALEKSANDROV	{"phone": "+70017465716"}
0005433654824	614BAD	8817 369413	ALEKSANDR SMIRNOV	{"phone": "+70291636894"}
0005433654826	CE622C	4054 451628	ANGELINA SERGEEVA	{"phone": "+70360861170"}
0005433654827	08484C	0627 895163	ROZA PETROVA	{"phone": "+70013461927"}
0005433654828	80C0B0	5585 999364	RAFIK DMITRIEV	{"phone": "+70671325776"}
0005433654829	04FFC2	5628 763707	DMITRIY CHERNOV	{"phone": "+70359609304"}
0005433654830	6FB53E	4094 380031	POLINA ARKHIPOVA	{"phone": "+70311584719"}
0005433654831	380FD6	2252 012469	VALENTINA NAZAROVA	{"email": "valentina-nazarova.1983@postgrespro.ru", "phone": "+70411606528"}
0005433654832	4CF157	8285 501424	PETR ANTONOV	{"phone": "+70123126210"}
0005433654833	7C78A8	2344 137799	DAMIR GRIGOREV	{"email": "grigorev_d-05041974@postgrespro.ru", "phone": "+70048033889"}
0005433654834	8E8062	2722 726066	ANDREY POPOV	{"email": "a-popov-1979@postgrespro.ru", "phone": "+70925701668"}
0005433654835	8E8062	3201 163068	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr-17021976@postgrespro.ru", "phone": "+70929481697"}
0005433654836	0B1E5D	3826 823305	ANATOLIY BORISOV	{"email": "a-borisov-02061967@postgrespro.ru", "phone": "+70096664466"}
0005433654837	BB1241	3721 204351	OLGA MOISEEVA	{"email": "moiseeva.olga_18011969@postgrespro.ru", "phone": "+70111883912"}
0005433654838	3ACBBA	7426 812853	VLADISLAV ALEKSANDROV	{"phone": "+70432737823"}
0005433654839	D6D23E	5093 386569	ELENA GUSEVA	{"phone": "+70191113740"}
0005433654840	223653	7823 665203	EVGENIY VLASOV	{"email": "evgeniy-vlasov_16121970@postgrespro.ru", "phone": "+70985932062"}
0005433654841	223653	5060 893031	NIKOLAY GORBUNOV	{"phone": "+70562748060"}
0005433654842	0F01BC	6742 072201	NATALYA POLYAKOVA	{"email": "npolyakova1973@postgrespro.ru", "phone": "+70935509360"}
0005433654843	0F01BC	6943 655776	NADEZHDA LOGINOVA	{"phone": "+70370094541"}
0005433654844	36E2BF	4653 034572	POLINA MASLOVA	{"email": "maslova.polina-20101962@postgrespro.ru", "phone": "+70554347919"}
0005433654845	36E2BF	8566 634479	YURIY KOROLEV	{"phone": "+70704318195"}
0005433654846	36E2BF	4610 879162	TATYANA PETROVA	{"phone": "+70449982535"}
0005433654847	5609DC	1354 835828	NINA ZAKHAROVA	{"email": "zakharova_nina1963@postgrespro.ru", "phone": "+70305086496"}
0005433654848	E629AE	2197 851761	TATYANA VOLKOVA	{"phone": "+70557650750"}
0005433654849	E629AE	2612 215230	ANDREY MATVEEV	{"email": "matveev-andrey-1972@postgrespro.ru", "phone": "+70160805509"}
0005433654850	E629AE	8404 172253	MARIYA POPOVA	{"email": "popova_m1964@postgrespro.ru", "phone": "+70944413979"}
0005433654851	AC468E	6308 310387	DMITRIY NOVIKOV	{"phone": "+70047674022"}
0005433654852	AC468E	2691 448130	SERGEY KUZMIN	{"phone": "+70522233469"}
0005433654853	C076FC	7514 646690	KRISTINA PETROVA	{"phone": "+70063335650"}
0005433654854	C076FC	8800 583226	VASILIY SERGEEV	{"phone": "+70608978235"}
0005433654855	4F5AF7	1793 270556	TATYANA KUZNECOVA	{"email": "kuznecova.t.1975@postgrespro.ru", "phone": "+70004738120"}
0005433654856	2F166E	9293 519447	OLGA TIKHONOVA	{"phone": "+70685888947"}
0005433654857	7E45D3	7930 136714	VALERIY MOROZOV	{"phone": "+70826745008"}
0005433654858	7E45D3	3897 231869	ELENA TIKHONOVA	{"phone": "+70022786007"}
0005433654859	A5F847	8135 072167	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev1965@postgrespro.ru", "phone": "+70146509201"}
0005433654860	E43174	5269 349855	VLADIMIR TARASOV	{"phone": "+70255357717"}
0005433654861	E43174	9556 448536	IGOR NIKITIN	{"email": "nikitin_i_011975@postgrespro.ru", "phone": "+70718358371"}
0005433654862	E43174	3387 809925	ELENA FADEEVA	{"phone": "+70189058720"}
0005433654863	0B16FD	7814 435388	DARYA TIKHONOVA	{"phone": "+70691901413"}
0005433654864	DF7A0F	1898 603295	MARINA SOKOLOVA	{"phone": "+70155204148"}
0005433654865	C9E5D9	0431 602908	TAISIYA KUDRYASHOVA	{"phone": "+70262731187"}
0005433654866	B67616	7751 335084	TATYANA ZAYCEVA	{"email": "zayceva-tatyana.041968@postgrespro.ru", "phone": "+70556566501"}
0005433654867	05BFD6	2448 802749	VASILIY IVANOV	{"email": "vasiliy_ivanov.021966@postgrespro.ru", "phone": "+70755362420"}
0005433654868	5B4820	0796 493278	OLGA KOROLEVA	{"phone": "+70251204658"}
0005433654869	6CF974	2479 576008	ALEKSEY MIRONOV	{"phone": "+70958139461"}
0005433654870	59A99A	6768 231011	YURIY VLASOV	{"phone": "+70767925751"}
0005433654871	59A99A	2358 728736	MARINA POTAPOVA	{"email": "m_potapova-091978@postgrespro.ru", "phone": "+70645898598"}
0005433654872	FB136C	7135 558537	EKATERINA RODIONOVA	{"phone": "+70421098452"}
0005433654873	FB136C	7533 503310	NATALYA KAZAKOVA	{"email": "kazakova_natalya-051980@postgrespro.ru", "phone": "+70380589837"}
0005433654874	FB136C	6536 885649	ELENA NOVIKOVA	{"phone": "+70802942079"}
0005433654875	0B7B13	0997 865133	DMITRIY MAKAROV	{"phone": "+70761222022"}
0005433654876	350913	4955 096018	VASILIY NIKOLAEV	{"email": "vasiliy.nikolaev_1970@postgrespro.ru", "phone": "+70656111292"}
0005433654877	59CB37	8892 692208	VALERIY FEDOTOV	{"email": "fedotov-v-1977@postgrespro.ru", "phone": "+70794823164"}
0005433654878	42D451	2995 479630	VLADIMIR EGOROV	{"email": "vladimiregorov.091984@postgrespro.ru", "phone": "+70150931382"}
0005433654879	42F024	2657 636401	EDUARD MIRONOV	{"phone": "+70333366401"}
0005433654880	42F024	9278 219644	TAMARA EGOROVA	{"email": "egorova.t081976@postgrespro.ru", "phone": "+70924400579"}
0005433654881	74EA43	5313 085150	ANASTASIYA MATVEEVA	{"phone": "+70394897520"}
0005433654882	74EA43	0903 236646	ANTON SCHERBAKOV	{"email": "anton-scherbakov.101963@postgrespro.ru", "phone": "+70118242403"}
0005433654883	74EA43	3193 397973	DARYA PETROVA	{"email": "petrova_d-1968@postgrespro.ru", "phone": "+70096501010"}
0005433654884	FFE6D2	4793 472684	DMITRIY KUZNECOV	{"phone": "+70617732514"}
0005433654885	FFE6D2	4740 282752	DARYA DENISOVA	{"email": "darya-denisova.06011968@postgrespro.ru", "phone": "+70150665165"}
0005433654886	92D2D1	5180 223025	SVETLANA NIKIFOROVA	{"phone": "+70754761299"}
0005433654887	A718E0	3592 395241	VIKTOR KISELEV	{"email": "kiselevviktor.09091973@postgrespro.ru", "phone": "+70284398959"}
0005433654888	A718E0	0849 228975	ALEKSANDR IVANOV	{"email": "ivanov_a_041974@postgrespro.ru", "phone": "+70099938575"}
0005433654889	A718E0	8592 513172	ELENA MATVEEVA	{"email": "elena_matveeva25121964@postgrespro.ru", "phone": "+70748355174"}
0005433654890	EEFC74	6589 485283	ALEKSANDR SMIRNOV	{"phone": "+70310763371"}
0005433654891	EEFC74	8285 492651	GENNADIY POPOV	{"phone": "+70447932873"}
0005433654892	EEFC74	4694 667324	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr_111992@postgrespro.ru", "phone": "+70776890698"}
0005433654893	A47F4C	9126 700994	PAVEL KUZMIN	{"email": "kuzmin_pavel-1974@postgrespro.ru", "phone": "+70781104496"}
0005433654894	A47F4C	4324 399069	ARSENIY SEMENOV	{"email": "arseniy.semenov-1972@postgrespro.ru", "phone": "+70355103631"}
0005433654895	39B255	4114 497373	SERGEY MAKSIMOV	{"phone": "+70586212920"}
0005433654896	39B255	6253 190006	MURAT FROLOV	{"phone": "+70522918729"}
0005433654897	0A56EB	8378 753436	SERGEY KUZNECOV	{"phone": "+70447902335"}
0005433654898	0A56EB	5355 976720	NATALYA POPOVA	{"email": "popova-natalya-1972@postgrespro.ru", "phone": "+70563780613"}
0005433654899	050A93	8579 341868	ALEKSANDR ANTONOV	{"email": "antonova-021981@postgrespro.ru", "phone": "+70559155519"}
0005433654900	050A93	0004 332514	OLGA LUKYANOVA	{"phone": "+70397006286"}
0005433654901	95E1C0	0852 559476	TATYANA YAKOVLEVA	{"phone": "+70833620168"}
0005433654902	FF1D10	0400 653445	LYUBOV ILINA	{"phone": "+70999676857"}
0005433654903	2BE6C7	6263 410637	LIDIYA POPOVA	{"phone": "+70417012799"}
0005433654904	2BE6C7	4237 912127	ELENA ARKHIPOVA	{"phone": "+70827288670"}
0005433654905	D7324E	7345 892523	ELVINA ANDREEVA	{"email": "e.andreeva_20091982@postgrespro.ru", "phone": "+70850004753"}
0005433654906	DE80BE	6042 138715	VYACHESLAV CHERNOV	{"email": "chernovvyacheslav_111978@postgrespro.ru", "phone": "+70827124789"}
0005433654907	DE80BE	8454 789566	SANIYA ZAKHAROVA	{"phone": "+70058797498"}
0005433654908	DE80BE	9202 441349	DENIS VASILEV	{"phone": "+70649341340"}
0005433654909	069596	3726 903453	PLATON OSIPOV	{"email": "osipov_p-041977@postgrespro.ru", "phone": "+70566739587"}
0005433654910	F7F29E	5679 766868	VERA VOROBEVA	{"phone": "+70217976070"}
0005433654911	00E49F	1247 179691	OLEG MAKAROV	{"email": "o_makarov.101982@postgrespro.ru", "phone": "+70227391985"}
0005433654912	C63AD6	2873 175411	NATALYA ROMANOVA	{"phone": "+70732454375"}
0005433654913	098451	5679 378362	OKSANA TIMOFEEVA	{"email": "otimofeeva-03021973@postgrespro.ru", "phone": "+70396538080"}
0005433654914	098451	1401 353567	ALEKSANDR IVANOV	{"email": "ivanov.a.04121967@postgrespro.ru", "phone": "+70170816112"}
0005433654915	EE92C4	7972 380547	SVETLANA KISELEVA	{"phone": "+70776733651"}
0005433654916	677D30	8682 855864	IVAN KUZMIN	{"email": "kuzminivan_081973@postgrespro.ru", "phone": "+70774123311"}
0005433654917	AECA4C	0355 915237	VYACHESLAV GRIGOREV	{"email": "grigorev.vyacheslav.23061970@postgrespro.ru", "phone": "+70513293642"}
0005433654918	0D6A0D	3914 797944	TATYANA IVANOVA	{"phone": "+70927403626"}
0005433654919	0D6A0D	9106 689315	MARINA ABRAMOVA	{"phone": "+70178374657"}
0005433654920	0D6A0D	7909 884949	EKATERINA ZAYCEVA	{"phone": "+70811662163"}
0005433654921	B36DDF	8491 557573	LIDIYA RYABOVA	{"email": "lidiya.ryabova28031974@postgrespro.ru", "phone": "+70967134231"}
0005433654922	B4DC70	4296 078893	ALEKSANDR GAVRILOV	{"phone": "+70954273378"}
0005433654923	AD4B1E	5101 184151	ELENA DENISOVA	{"email": "denisova.e_11011978@postgrespro.ru", "phone": "+70479499441"}
0005433654924	AD4B1E	6635 796461	DMITRIY GRIGOREV	{"email": "grigorev-dmitriy-1974@postgrespro.ru", "phone": "+70710426845"}
0005433654925	7C69D6	2878 113754	ELENA ANISIMOVA	{"email": "anisimova_e-041971@postgrespro.ru", "phone": "+70314090109"}
0005433654926	B2D71C	2701 529327	NIKITA GRIGOREV	{"phone": "+70869186231"}
0005433654927	0357A0	3249 234538	OKSANA ROMANOVA	{"email": "romanova_o-06061969@postgrespro.ru", "phone": "+70865919927"}
0005433654928	933AE3	4162 727432	NATALYA SEMENOVA	{"email": "n.semenova.091966@postgrespro.ru", "phone": "+70092449296"}
0005433654929	609E7D	9673 347282	EKATERINA KONOVALOVA	{"email": "konovalova-ekaterina1987@postgrespro.ru", "phone": "+70023533301"}
0005433654930	8A3474	7846 558596	OKSANA DENISOVA	{"email": "o_denisova.1964@postgrespro.ru", "phone": "+70143403759"}
0005433654931	8C290D	4833 099622	GALINA KUDRYASHOVA	{"email": "kudryashova.galina-1962@postgrespro.ru", "phone": "+70515925935"}
0005433654932	7358EF	6986 993293	GALINA DMITRIEVA	{"phone": "+70796897026"}
0005433654933	C65CA4	9845 383943	TATYANA KOROLEVA	{"email": "t.koroleva02041984@postgrespro.ru", "phone": "+70241272257"}
0005433654934	C65CA4	8643 200643	BULAT MATVEEV	{"email": "bulatmatveev111975@postgrespro.ru", "phone": "+70962935757"}
0005433654935	ABBE19	4210 438398	SOFYA ORLOVA	{"phone": "+70453378925"}
0005433654936	C16C76	6806 593958	VLADIMIR STEPANOV	{"email": "vstepanov1974@postgrespro.ru", "phone": "+70717739124"}
0005433654937	D1E1E7	4142 833831	DMITRIY BARANOV	{"phone": "+70735560395"}
0005433654938	512AF8	7416 294878	VADIM VOLKOV	{"email": "volkov_vadim_05061967@postgrespro.ru", "phone": "+70701891239"}
0005433654939	1FCB82	4234 778401	ALEKSEY KUZMIN	{"phone": "+70228006369"}
0005433654940	66450D	1141 241274	EVGENIY OSIPOV	{"phone": "+70052710522"}
0005433654941	3AFA97	5382 391060	ANASTASIYA IVANOVA	{"phone": "+70460240680"}
0005433654942	3AFA97	5561 228092	NATALYA SMIRNOVA	{"email": "nsmirnova-1976@postgrespro.ru", "phone": "+70800099544"}
0005433654943	3AFA97	5879 745468	SVETLANA MELNIKOVA	{"email": "melnikova_s-021974@postgrespro.ru", "phone": "+70201757458"}
0005433654944	403B1B	4173 709585	ALEKSANDR KUZNECOV	{"phone": "+70496937873"}
0005433654945	403B1B	2103 338311	VALENTINA MALYSHEVA	{"email": "valentina-malysheva_09071976@postgrespro.ru", "phone": "+70120633605"}
0005433654946	558ED1	7440 608789	KLAVDIYA LOGINOVA	{"phone": "+70904954520"}
0005433654947	1E0895	1459 634042	ALLA NIKOLAEVA	{"email": "alla.nikolaeva.031967@postgrespro.ru", "phone": "+70495410288"}
0005433654948	6E71C8	6997 132490	GRIGORIY SERGEEV	{"phone": "+70935980442"}
0005433654949	78B187	7472 752492	EKATERINA MIKHAYLOVA	{"phone": "+70641598495"}
0005433654950	3F2433	6421 438013	ALEKSEY PETROV	{"email": "aleksey_petrov.031966@postgrespro.ru", "phone": "+70089202651"}
0005433654951	39E2FA	4718 194557	NATALYA MAKSIMOVA	{"email": "natalya-maksimova061974@postgrespro.ru", "phone": "+70975375638"}
0005433654952	BEAC69	7510 394246	VALENTINA MATVEEVA	{"email": "v.matveeva041967@postgrespro.ru", "phone": "+70053685054"}
0005433654953	BEAC69	3769 388068	VITALIY FOMIN	{"email": "fomin.v.01101975@postgrespro.ru", "phone": "+70366980713"}
0005433654954	F12AB5	7345 296489	LARISA KISELEVA	{"email": "larisa_kiseleva_121974@postgrespro.ru", "phone": "+70542783783"}
0005433654955	F12AB5	0314 349396	YURIY FILIPPOV	{"email": "filippov-y31101968@postgrespro.ru", "phone": "+70978330206"}
0005433654956	42FEF2	1157 101470	DINARA ZAKHAROVA	{"email": "dinara-zakharova.061974@postgrespro.ru", "phone": "+70365722669"}
0005433654957	332C15	3313 732890	OLGA ANTONOVA	{"email": "olga.antonova.15041963@postgrespro.ru", "phone": "+70708252920"}
0005433654958	86EAD7	7363 655107	BORIS ISAEV	{"email": "borisisaev031980@postgrespro.ru", "phone": "+70534653297"}
0005433654959	86EAD7	8294 699431	KIRILL KUDRYASHOV	{"email": "kudryashovkirill_111968@postgrespro.ru", "phone": "+70368377267"}
0005433654960	912385	1341 968291	ALEKSANDR CHERNOV	{"phone": "+70406322966"}
0005433654961	912385	3805 481083	ANASTASIYA RODIONOVA	{"phone": "+70472854789"}
0005433654962	0FF2A7	0549 199591	NATALYA GAVRILOVA	{"email": "gavrilova_natalya.1974@postgrespro.ru", "phone": "+70609354540"}
0005433654963	0FF2A7	4998 005135	IRINA KONDRATEVA	{"phone": "+70719187970"}
0005433654964	C51D14	6610 816210	LIDIYA SOKOLOVA	{"email": "sokolova_lidiya.071957@postgrespro.ru", "phone": "+70612419696"}
0005433654965	2CBBB2	4864 755239	OLGA NIKOLAEVA	{"phone": "+70731506838"}
0005433654966	2CBBB2	5273 545961	ALEKSEY VOROBEV	{"phone": "+70532222000"}
0005433654967	45A41A	7265 714206	VLADIMIR IVANOV	{"email": "vladimir_ivanov.111978@postgrespro.ru", "phone": "+70183483152"}
0005433654968	45A41A	0796 577777	NIKOLAY ZAKHAROV	{"phone": "+70700477269"}
0005433654969	0E30F5	8205 273905	SERGEY BORISOV	{"email": "borisov.s1975@postgrespro.ru", "phone": "+70509764637"}
0005433654970	6A956D	2341 521877	RAISA KOLESNIKOVA	{"email": "kolesnikovar-041969@postgrespro.ru", "phone": "+70683505974"}
0005433654971	759620	1917 004592	TAMARA GUSEVA	{"phone": "+70540445439"}
0005433654972	759620	8771 559290	LYUDMILA MARTYNOVA	{"email": "l_martynova.1975@postgrespro.ru", "phone": "+70207101019"}
0005433654973	40ED5E	9110 424806	MARIYA FOMINA	{"email": "mariyafomina-1965@postgrespro.ru", "phone": "+70158927128"}
0005433654974	AA2DB1	4682 217251	YULIYA ANDREEVA	{"email": "andreeva.yuliya-14031964@postgrespro.ru", "phone": "+70345975103"}
0005433654975	AA2DB1	0453 914940	ALEKSEY MEDVEDEV	{"phone": "+70008426736"}
0005433654976	DAD031	9263 363986	NADEZHDA KUZMINA	{"email": "kuzminanadezhda25041965@postgrespro.ru", "phone": "+70217970892"}
0005433654977	9E67F7	5375 441946	NIKOLAY IVANOV	{"email": "ivanov-n081978@postgrespro.ru", "phone": "+70779517905"}
0005433654978	9E67F7	1665 219040	ALEKSANDR MIRONOV	{"email": "aleksandr.mironov.1977@postgrespro.ru", "phone": "+70291989001"}
0005433654979	659F43	6773 139283	ALEKSEY VOLKOV	{"email": "volkov_a031974@postgrespro.ru", "phone": "+70605030356"}
0005433654980	2F7F41	7382 047982	OLEG ALEKSEEV	{"email": "alekseev_o05051977@postgrespro.ru", "phone": "+70886235386"}
0005433654981	E03F9D	9852 015265	IVAN CHERNOV	{"email": "i.chernov-1969@postgrespro.ru", "phone": "+70330249808"}
0005433654982	536CFB	2644 400381	SHAMIL IVANOV	{"email": "s_ivanov051974@postgrespro.ru", "phone": "+70998695903"}
0005433654983	10FEEE	9864 235487	SERGEY SCHERBAKOV	{"phone": "+70900302392"}
0005433654984	10FEEE	8105 243639	IRINA KOZLOVA	{"email": "kozlova-irina1978@postgrespro.ru", "phone": "+70286049954"}
0005433654985	1F0E54	4205 056717	YURIY NOVIKOV	{"phone": "+70003783620"}
0005433654986	1F0E54	7306 941071	YURIY KAZAKOV	{"phone": "+70880572046"}
0005433654987	9C0A65	9731 925476	MARINA DMITRIEVA	{"email": "marina-dmitrieva_1964@postgrespro.ru", "phone": "+70920049829"}
0005433654988	F92933	3435 534121	ALEKSANDR MAKSIMOV	{"phone": "+70014400750"}
0005433654989	F92933	5823 997468	IVAN MIRONOV	{"phone": "+70689390336"}
0005433656613	F40A40	2434 874268	DMITRIY CHERNOV	{"email": "dmitriy_chernov_111975@postgrespro.ru", "phone": "+70551155000"}
0005433656614	F40A40	0336 805773	LYUBOV VASILEVA	{"phone": "+70970810864"}
0005433656615	3684EE	9848 131154	ALEKSEY FROLOV	{"email": "a_frolov.111962@postgrespro.ru", "phone": "+70498617673"}
0005433656616	4521E2	8770 251715	SVETLANA BORISOVA	{"phone": "+70003318268"}
0005433656617	AA3434	1504 444439	VLADIMIR TIMOFEEV	{"email": "v.timofeev_1967@postgrespro.ru", "phone": "+70476105482"}
0005433656618	866A62	4381 612237	DENIS KUZNECOV	{"email": "kuznecovdenis.071969@postgrespro.ru", "phone": "+70314865102"}
0005433656619	4F29E0	1482 277048	ROZALIYA BELOVA	{"phone": "+70124826919"}
0005433656620	6879A0	0733 681512	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy.1972@postgrespro.ru", "phone": "+70922785592"}
0005433656621	BF3C1D	3886 180402	VALENTINA NOVIKOVA	{"phone": "+70089881606"}
0005433656622	6CFF22	1529 479457	ANATOLIY ZAYCEV	{"email": "zaycev_a25091962@postgrespro.ru", "phone": "+70642704490"}
0005433656623	19F55C	9711 280559	EKATERINA LEBEDEVA	{"email": "lebedeva-ekaterina_021972@postgrespro.ru", "phone": "+70656997877"}
0005433656624	58BF52	9838 315843	ILYA SOROKIN	{"phone": "+70113526523"}
0005433656625	8787C6	5514 955460	RUSLAN KARPOV	{"email": "ruslankarpov1976@postgrespro.ru", "phone": "+70741628388"}
0005433656626	328488	1363 126160	MAKSIM GUSEV	{"phone": "+70280319623"}
0005433656627	B0DD71	7552 120066	DMITRIY NOVIKOV	{"email": "novikovdmitriy-021968@postgrespro.ru", "phone": "+70361613361"}
0005433656628	34756A	6721 472540	MAKSIM BORISOV	{"email": "borisovmaksim_081971@postgrespro.ru", "phone": "+70621207131"}
0005433656629	A66002	5138 434546	MARINA KOROLEVA	{"phone": "+70676989747"}
0005433656630	A66002	2697 241396	VITALIY STEPANOV	{"email": "stepanovvitaliy_041979@postgrespro.ru", "phone": "+70494908984"}
0005433656631	AD91DF	7769 738673	VALERIY ORLOV	{"email": "valeriy.orlov-1967@postgrespro.ru", "phone": "+70037275416"}
0005433656632	AD91DF	3201 848424	VLADIMIR TARASOV	{"phone": "+70976031526"}
0005433656633	81642E	2648 690184	EKATERINA VLASOVA	{"email": "ekaterina-vlasova-1973@postgrespro.ru", "phone": "+70981369713"}
0005433656634	4D8562	9371 000755	ANNA EGOROVA	{"email": "egorovaa_1974@postgrespro.ru", "phone": "+70267812534"}
0005433656635	A6276A	1965 571994	VALENTINA MASLOVA	{"email": "v.maslova_1966@postgrespro.ru", "phone": "+70307103267"}
0005433656636	A6276A	7247 186149	GALINA KUZNECOVA	{"email": "galina.kuznecova_22031975@postgrespro.ru", "phone": "+70248898711"}
0005433656637	3A5D86	5569 972341	ALEKSEY VASILEV	{"email": "vasilev_aleksey_061972@postgrespro.ru", "phone": "+70770213360"}
0005433656638	4B012C	2019 726451	DINARA MATVEEVA	{"email": "matveeva-d.23031971@postgrespro.ru", "phone": "+70002755234"}
0005433656639	0ECFCE	3924 916980	SERGEY DAVYDOV	{"email": "sdavydov1972@postgrespro.ru", "phone": "+70366063581"}
0005433656640	0ECFCE	4173 163150	ALEKSANDR SHEVCHENKO	{"phone": "+70969485244"}
0005433656641	0ECFCE	8741 574612	SERGEY KISELEV	{"email": "kiselevs111976@postgrespro.ru", "phone": "+70069612366"}
0005433656642	153379	2525 337573	ARTEM VLASOV	{"phone": "+70681251482"}
0005433656643	EFE56B	7176 360667	NATALYA DMITRIEVA	{"phone": "+70696907971"}
0005433656644	EFE56B	9311 688895	NATALYA IVANOVA	{"email": "n_ivanova.1976@postgrespro.ru", "phone": "+70290542952"}
0005433656645	732193	6025 013200	EGOR POPOV	{"email": "popove_031970@postgrespro.ru", "phone": "+70298153592"}
0005433656646	151E8E	2846 819166	EVGENIY FEDOROV	{"phone": "+70503083652"}
0005433656647	8CC211	0777 382809	ANTONINA IVANOVA	{"email": "ivanova_a-1971@postgrespro.ru", "phone": "+70543135086"}
0005433656648	F5CE6C	3015 207789	RAIL DAVYDOV	{"phone": "+70396171607"}
0005433656649	305277	6059 780354	VASILIY DMITRIEV	{"phone": "+70802827353"}
0005433656650	92FCC7	0263 172049	ALEKSANDR NIKITIN	{"email": "nikitina21011977@postgrespro.ru", "phone": "+70435846704"}
0005433656651	996FB3	8726 811148	TATYANA MALYSHEVA	{"email": "tmalysheva.03051973@postgrespro.ru", "phone": "+70523622260"}
0005433656652	996FB3	9705 559865	SERGEY EGOROV	{"phone": "+70338683382"}
0005433656653	18E3CA	5488 652579	MAKSIM NAUMOV	{"phone": "+70391247039"}
0005433656654	EB587D	6352 313170	EKATERINA IVANOVA	{"email": "ivanova-ekaterina1986@postgrespro.ru", "phone": "+70421445217"}
0005433656655	EB587D	3201 764876	NATALYA LUKYANOVA	{"phone": "+70182975872"}
0005433656656	769DEB	9909 334045	SERGEY PAVLOV	{"email": "pavlov.s_1974@postgrespro.ru", "phone": "+70874971677"}
0005433656657	B76A64	3996 074713	ZLATA ALEKSEEVA	{"phone": "+70932860114"}
0005433656658	B76A64	6024 199540	LYUBOV FROLOVA	{"phone": "+70381355585"}
0005433656659	E34EE9	0104 903284	MARGARITA DANILOVA	{"phone": "+70791786283"}
0005433656660	440E4E	2686 580406	IVAN SAVELEV	{"email": "savelev.ivan.16011974@postgrespro.ru", "phone": "+70118295299"}
0005433656661	440E4E	1781 765807	ELINA BELYAEVA	{"email": "elina-belyaeva-081968@postgrespro.ru", "phone": "+70593748361"}
0005433656662	A7E404	4834 182235	PAVEL STEPANOV	{"email": "pstepanov.1974@postgrespro.ru", "phone": "+70914044488"}
0005433656663	5E8848	7595 791342	IGOR IVANOV	{"email": "i_ivanov-051976@postgrespro.ru", "phone": "+70314916852"}
0005433656664	ACC4DA	7944 407078	NIKOLAY DMITRIEV	{"email": "dmitriev_n_16071967@postgrespro.ru", "phone": "+70478966799"}
0005433656665	ACC4DA	1410 081170	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr1986@postgrespro.ru", "phone": "+70874206808"}
0005433656666	ACC4DA	1555 868302	VIKTOR KONOVALOV	{"email": "konovalov.viktor_1962@postgrespro.ru", "phone": "+70079716130"}
0005433656667	2BFE1A	9766 853184	LYUDMILA SIDOROVA	{"phone": "+70714399575"}
0005433656668	31AF5D	1378 181876	OLGA SIDOROVA	{"phone": "+70507763243"}
0005433656669	EC4EAD	7805 723374	LYUDMILA FILATOVA	{"phone": "+70629179167"}
0005433656670	A5FA86	6190 855129	NIKITA SEMENOV	{"email": "semenov_nikita031967@postgrespro.ru", "phone": "+70331789095"}
0005433656671	A2C8B2	5239 581590	AIDA PETROVA	{"email": "a.petrova27111973@postgrespro.ru", "phone": "+70661309169"}
0005433656672	E535AD	6593 350426	SVETLANA SEMENOVA	{"email": "svetlana-semenova_01041966@postgrespro.ru", "phone": "+70593347187"}
0005433656673	0D63AF	1857 388012	VLADIMIR SCHERBAKOV	{"email": "vscherbakov_1984@postgrespro.ru", "phone": "+70864262271"}
0005433656674	0D63AF	1492 352932	YURIY EGOROV	{"phone": "+70991454324"}
0005433656675	03804A	2447 129173	GENNADIY TARASOV	{"phone": "+70702727256"}
0005433656676	03804A	5002 491880	VASILIY VOLKOV	{"phone": "+70544797034"}
0005433656677	D3E64D	4969 666105	VIKTOR SHEVCHENKO	{"email": "v.shevchenko_1976@postgrespro.ru", "phone": "+70796524928"}
0005433656678	2A13CF	6957 340767	NATALYA MELNIKOVA	{"email": "melnikova-n-1982@postgrespro.ru", "phone": "+70784198838"}
0005433656679	2A13CF	7680 173013	ALEKSANDR BONDARENKO	{"email": "a_bondarenko-1953@postgrespro.ru", "phone": "+70677698220"}
0005433656680	B6823A	4269 369910	IRINA EFREMOVA	{"email": "efremova_irina.17071973@postgrespro.ru", "phone": "+70674378908"}
0005433656681	B6823A	3585 181195	MARIYA SOROKINA	{"email": "sorokina.mariya_081969@postgrespro.ru", "phone": "+70412579080"}
0005433656682	7F5CCB	0130 930044	ELINA ZHURAVLEVA	{"email": "e_zhuravleva_1967@postgrespro.ru", "phone": "+70261437030"}
0005433656683	7F5CCB	2877 640628	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr-1978@postgrespro.ru", "phone": "+70257801704"}
0005433656684	BCD420	0312 022410	VLADIMIR PETROV	{"email": "vladimir_petrov_20071975@postgrespro.ru", "phone": "+70000293004"}
0005433656685	BCD420	8889 004732	LIDIYA ZOTOVA	{"email": "lzotova09031966@postgrespro.ru", "phone": "+70715707883"}
0005433679805	55B8DC	9235 271646	TATYANA POPOVA	{"phone": "+70724173462"}
0005433656686	5E1118	0560 702017	DMITRIY FEDOTOV	{"email": "dmitriy-fedotov111964@postgrespro.ru", "phone": "+70676192987"}
0005433656687	61B428	9279 557863	SERGEY KUZNECOV	{"email": "s-kuznecov_121973@postgrespro.ru", "phone": "+70347766610"}
0005433656688	206428	6752 193128	VLADIMIR IVANOV	{"email": "vladimir_ivanov-07091973@postgrespro.ru", "phone": "+70558291825"}
0005433656689	900317	9339 692708	GERMAN KOROLEV	{"phone": "+70763765749"}
0005433656690	900317	1096 674645	ELENA SEMENOVA	{"phone": "+70746797367"}
0005433656691	BCA2E6	9749 925766	VALENTINA KAZAKOVA	{"phone": "+70125929626"}
0005433656692	5A932D	5869 444416	NINA MOISEEVA	{"email": "moiseevan.1977@postgrespro.ru", "phone": "+70512167724"}
0005433656693	DBFBAC	5849 238661	RUSLAN KAZAKOV	{"email": "kazakov_r-1957@postgrespro.ru", "phone": "+70951968149"}
0005433656694	299282	9395 167740	IRINA MIRONOVA	{"phone": "+70252685993"}
0005433656695	196B36	4834 774952	NIKOLAY MIRONOV	{"phone": "+70411580146"}
0005433656696	196B36	3432 009643	GALINA KOROLEVA	{"email": "galina.koroleva-1971@postgrespro.ru", "phone": "+70711828766"}
0005433656697	24343F	7182 134668	ANTONINA ARKHIPOVA	{"email": "a-arkhipova_1969@postgrespro.ru", "phone": "+70769529116"}
0005433656698	24343F	0724 930588	SERGEY SCHERBAKOV	{"email": "s.scherbakov-1964@postgrespro.ru", "phone": "+70112112318"}
0005433656699	BF16BF	3212 039876	VALENTINA KISELEVA	{"email": "vkiseleva_1978@postgrespro.ru", "phone": "+70325162794"}
0005433656700	BF16BF	4171 386573	EKATERINA MOISEEVA	{"email": "e_moiseeva-1982@postgrespro.ru", "phone": "+70316169689"}
0005433656701	AAE087	2974 492747	ANDREY KOZLOV	{"phone": "+70178801298"}
0005433656702	6B2C09	2854 560846	VALENTINA KOZLOVA	{"email": "kozlova_valentina_03111969@postgrespro.ru", "phone": "+70359945929"}
0005433656703	E8FBF2	5866 029749	VERA ERMAKOVA	{"phone": "+70240943198"}
0005433656704	19B9DE	4929 958531	ANATOLIY GUSEV	{"email": "gusev-anatoliy28051971@postgrespro.ru", "phone": "+70942229506"}
0005433656705	19B9DE	8912 670835	ANATOLIY NIKITIN	{"phone": "+70646098550"}
0005433656706	FC3415	9514 333963	GENNADIY NAUMOV	{"phone": "+70114909438"}
0005433656707	BE9631	9500 495368	OLGA AKIMOVA	{"phone": "+70532904006"}
0005433656708	BE9631	9723 777026	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-08081976@postgrespro.ru", "phone": "+70518097910"}
0005433656709	9CBF25	3184 507438	ANATOLIY ORLOV	{"phone": "+70246498597"}
0005433656710	CF50F8	6287 819764	VALERIY ZAYCEV	{"phone": "+70977078520"}
0005433656711	CF50F8	6176 080349	MARIYA POLYAKOVA	{"phone": "+70168115082"}
0005433656712	F1435A	9300 997420	IGOR YAKOVLEV	{"email": "yakovlev.igor_10101981@postgrespro.ru", "phone": "+70526437371"}
0005433656713	F1435A	4293 144959	ALEKSANDR KONOVALOV	{"phone": "+70330089530"}
0005433656714	22229B	7455 455143	ALEKSANDR ANTONOV	{"phone": "+70038673019"}
0005433656715	22229B	8544 883492	NINA KOROLEVA	{"email": "nina.koroleva-1969@postgrespro.ru", "phone": "+70148756938"}
0005433656716	A78C8D	9992 819050	TATYANA EFREMOVA	{"phone": "+70398213601"}
0005433656717	EBC355	7940 278911	ALEKSEY STEPANOV	{"phone": "+70400473575"}
0005433656718	EBC355	1579 680313	RUSLAN ORLOV	{"email": "orlov-r_31071979@postgrespro.ru", "phone": "+70614437606"}
0005433656719	FB2D66	7804 625257	NADEZHDA NAZAROVA	{"phone": "+70677314035"}
0005433656720	AEBD14	5962 261218	ANTONINA MATVEEVA	{"email": "matveeva-antonina-091978@postgrespro.ru", "phone": "+70378962911"}
0005433656721	AEBD14	9742 338574	VALENTINA SIDOROVA	{"phone": "+70818415506"}
0005433656722	31EAC1	7623 474021	ALINA DENISOVA	{"phone": "+70166042640"}
0005433656723	31EAC1	1234 343822	MARIYA NIKITINA	{"email": "m-nikitina_121968@postgrespro.ru", "phone": "+70361045365"}
0005433656724	2BFA1F	4991 061760	IGOR VASILEV	{"email": "vasilev-igor-071972@postgrespro.ru", "phone": "+70992902259"}
0005433656725	B24AF0	8920 868759	MIKHAIL IVANOV	{"phone": "+70793066529"}
0005433656726	750900	3556 736925	ANDREY MOISEEV	{"phone": "+70890874859"}
0005433656727	41BD86	6966 386674	KSENIYA TIKHONOVA	{"email": "kseniya_tikhonova051965@postgrespro.ru", "phone": "+70968250845"}
0005433656728	6C7884	3371 679987	ALEKSANDR IVANOV	{"email": "a-ivanov24101981@postgrespro.ru", "phone": "+70861307130"}
0005433656729	970BC8	3847 650613	PLATON SERGEEV	{"email": "platon-sergeev1957@postgrespro.ru", "phone": "+70959691425"}
0005433656730	AAE8E2	0807 919503	ANDREY KUZNECOV	{"phone": "+70584202594"}
0005433656731	AAE8E2	4218 539569	ANDREY SOLOVEV	{"email": "solovev.andrey071971@postgrespro.ru", "phone": "+70994368306"}
0005433656732	ADC030	0729 071933	VENERA KALININA	{"email": "kalinina_venera.1972@postgrespro.ru", "phone": "+70480234873"}
0005433656733	ADC030	8916 335426	VLADIMIR BELOV	{"phone": "+70917695590"}
0005433656734	E0A7D9	5845 090625	VLADIMIR KUZMIN	{"email": "kuzmin_v.111978@postgrespro.ru", "phone": "+70945200979"}
0005433656735	C7CB86	7040 754700	ELIZAVETA NIKOLAEVA	{"phone": "+70872732035"}
0005433656736	A16B46	1372 004046	ALINA VOROBEVA	{"email": "vorobeva.alina_15031977@postgrespro.ru", "phone": "+70329339451"}
0005433656737	A16B46	1440 433733	NIKITA IVANOV	{"phone": "+70615087657"}
0005433656738	A16B46	3470 815139	NINA ORLOVA	{"phone": "+70812921197"}
0005433656739	7892A4	7284 209368	OLGA LUKYANOVA	{"email": "lukyanova-o-24021982@postgrespro.ru", "phone": "+70235285669"}
0005433656740	12AF17	5587 318975	SERGEY BARANOV	{"email": "baranov-sergey121973@postgrespro.ru", "phone": "+70020037076"}
0005433656741	12AF17	0791 548019	ELENA VASILEVA	{"phone": "+70796344849"}
0005433656742	12AF17	3007 742321	NATALYA FEDOROVA	{"email": "fedorova.n1965@postgrespro.ru", "phone": "+70852748169"}
0005433656743	12AF17	7051 420863	ANDREY KARPOV	{"phone": "+70143506257"}
0005433656744	ACB7AD	8704 868530	NIKOLAY SEMENOV	{"email": "n-semenov_021959@postgrespro.ru", "phone": "+70464935257"}
0005433656745	BF5811	9375 066665	OLGA KUDRYASHOVA	{"email": "kudryashova-o021966@postgrespro.ru", "phone": "+70317997052"}
0005433656746	BF5811	2128 734813	DMITRIY TIKHONOV	{"phone": "+70434969227"}
0005433656747	231A5A	9577 657649	TATYANA MIKHAYLOVA	{"email": "mikhaylova.t_28121966@postgrespro.ru", "phone": "+70851257072"}
0005433656748	231A5A	2079 199664	LYUBOV IVANOVA	{"email": "ivanova.l-041972@postgrespro.ru", "phone": "+70468592035"}
0005433656749	2EA44D	9036 418450	DINA EGOROVA	{"phone": "+70170755087"}
0005433656750	6102A1	3945 266088	VLADIMIR TIMOFEEV	{"phone": "+70278018218"}
0005433656751	FFA4C8	1757 490024	MARGARITA NOVIKOVA	{"email": "novikovam1963@postgrespro.ru", "phone": "+70977627068"}
0005433656752	C83362	4169 447716	ALEKSANDR BONDARENKO	{"email": "abondarenko-1957@postgrespro.ru", "phone": "+70825961366"}
0005433656753	5C9257	9699 255680	ELENA MOISEEVA	{"email": "moiseeva.e.1962@postgrespro.ru", "phone": "+70078783844"}
0005433656754	9CB7E9	0388 390787	VALENTIN NAZAROV	{"email": "v_nazarov.1960@postgrespro.ru", "phone": "+70979367040"}
0005433656755	5FF1AE	8087 958686	EVGENIY KUZNECOV	{"phone": "+70986268410"}
0005433656756	018E2C	6550 857167	NIKOLAY ALEKSEEV	{"email": "n-alekseev_29061969@postgrespro.ru", "phone": "+70415139376"}
0005433656757	66A278	7141 844564	ANATOLIY ISAEV	{"email": "isaevanatoliy-1965@postgrespro.ru", "phone": "+70911839448"}
0005433656758	39846D	9074 442763	MARINA GUSEVA	{"phone": "+70787513825"}
0005433656759	39846D	0899 701278	VASILIY NAUMOV	{"email": "v-naumov071967@postgrespro.ru", "phone": "+70819923819"}
0005433656760	68D221	2689 185834	ELENA BELOVA	{"email": "belova-e.031980@postgrespro.ru", "phone": "+70943458926"}
0005433656761	C78C70	2314 551426	LYUDMILA SOLOVEVA	{"email": "solovevalyudmila.30121967@postgrespro.ru", "phone": "+70463582960"}
0005433656762	C78C70	1852 897617	DARYA ZAKHAROVA	{"email": "darya.zakharova091969@postgrespro.ru", "phone": "+70621922843"}
0005433656763	C78C70	2505 565824	ANTONINA MAKAROVA	{"phone": "+70336803258"}
0005433656764	14F491	3536 913225	TATYANA KULIKOVA	{"email": "tatyana-kulikova061968@postgrespro.ru", "phone": "+70821203512"}
0005433656765	14F491	8935 225124	PAVEL NOVIKOV	{"email": "pavel.novikov.19021967@postgrespro.ru", "phone": "+70120589534"}
0005433656766	7B6638	4521 068263	LARISA ABRAMOVA	{"phone": "+70710509302"}
0005433656767	48A150	6122 434439	ALEKSANDR ILIN	{"phone": "+70889451793"}
0005433656768	6829FF	1502 984942	TATYANA POTAPOVA	{"phone": "+70859071870"}
0005433679709	69A849	9146 742574	FEDOR KONOVALOV	{"email": "konovalovf-121982@postgrespro.ru", "phone": "+70691703172"}
0005433679710	7C346C	7118 940545	VASILIY KUZNECOV	{"email": "kuznecov-v-24021965@postgrespro.ru", "phone": "+70191208982"}
0005433679711	1B87FB	0270 764267	ROSTISLAV MAKAROV	{"phone": "+70847074768"}
0005433679712	FE3725	4499 389939	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.11021983@postgrespro.ru", "phone": "+70823597669"}
0005433679713	CA2EEB	3266 926750	SVETLANA DENISOVA	{"phone": "+70330153161"}
0005433679714	FB2ABA	7841 577775	ROMAN ZAKHAROV	{"email": "r_zakharov_091969@postgrespro.ru", "phone": "+70711682577"}
0005433679715	FB2ABA	9229 260149	VALERIY MIKHAYLOV	{"phone": "+70249176983"}
0005433679716	D82026	2091 461248	GALINA KONDRATEVA	{"phone": "+70631667564"}
0005433679717	4E4F65	1683 921033	LYUBOV GUSEVA	{"email": "lyubovguseva1978@postgrespro.ru", "phone": "+70497488189"}
0005433679718	46B6AA	0321 424570	ALEKSEY NIKOLAEV	{"phone": "+70995730968"}
0005433679719	46B6AA	0104 158773	DENIS STEPANOV	{"phone": "+70767141093"}
0005433679720	0AA345	2694 426436	NINA KALININA	{"phone": "+70596923030"}
0005433679721	0AA345	6002 988328	EKATERINA NESTEROVA	{"phone": "+70785296035"}
0005433679722	60A427	3195 503203	ROMAN NIKITIN	{"phone": "+70499563504"}
0005433679723	1C907A	4318 742203	IRINA MOROZOVA	{"email": "morozovairina.05041973@postgrespro.ru", "phone": "+70472418968"}
0005433679724	4B5DE6	2722 958374	DMITRIY POPOV	{"phone": "+70102862103"}
0005433679725	24F367	2168 986910	RAISA KUZNECOVA	{"phone": "+70547216256"}
0005433679726	4B8207	6974 129291	ANATOLIY GERASIMOV	{"phone": "+70283126339"}
0005433679727	EB9E76	0616 572960	VIKTORIYA VOLKOVA	{"phone": "+70303210418"}
0005433679728	7EBB25	3695 901592	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr.03081971@postgrespro.ru", "phone": "+70685089776"}
0005433679729	063CAC	9187 394599	SERGEY SEMENOV	{"email": "s-semenov-1978@postgrespro.ru", "phone": "+70015451530"}
0005433679730	381073	7639 736382	LEONID KONOVALOV	{"email": "leonidkonovalov061977@postgrespro.ru", "phone": "+70367739236"}
0005433679731	8743B4	7725 155244	MARINA KARPOVA	{"email": "karpova_m_111982@postgrespro.ru", "phone": "+70233500301"}
0005433679732	8743B4	8316 914652	IVAN SCHERBAKOV	{"phone": "+70157939860"}
0005433679733	8743B4	7624 311071	ELMIRA GUSEVA	{"email": "guseva-elmira_06111991@postgrespro.ru", "phone": "+70848200736"}
0005433679734	4D184D	8282 929271	PETR OSIPOV	{"email": "petr-osipov-1963@postgrespro.ru", "phone": "+70870532083"}
0005433679735	C73CAC	3127 286963	SVETLANA TROFIMOVA	{"email": "s.trofimova-1970@postgrespro.ru", "phone": "+70124452594"}
0005433679736	C73CAC	3261 970357	ANATOLIY GUSEV	{"email": "gusev_a.12071962@postgrespro.ru", "phone": "+70142650401"}
0005433679737	B3B61D	0698 220350	EVGENIY FEDOROV	{"phone": "+70906605787"}
0005433679738	D910B2	7595 532043	ALEKSEY STEPANOV	{"email": "stepanov_aleksey.28041972@postgrespro.ru", "phone": "+70791927719"}
0005433679739	9EFB7A	4789 888099	RAVZA BELOVA	{"email": "belova.ravza-071973@postgrespro.ru", "phone": "+70982240676"}
0005433679740	36CB93	5732 500272	MARGARITA KONOVALOVA	{"email": "margaritakonovalova_1970@postgrespro.ru", "phone": "+70748978634"}
0005433679741	36CB93	2813 796151	ALEKSANDR SCHERBAKOV	{"email": "scherbakova1976@postgrespro.ru", "phone": "+70319679716"}
0005433679742	9400A2	0055 252497	KIRILL SOROKIN	{"phone": "+70827051082"}
0005433679743	9400A2	0909 989149	IVAN RODIONOV	{"phone": "+70932093802"}
0005433679744	4D8E0C	7614 295436	ELENA MATVEEVA	{"phone": "+70225667071"}
0005433679745	4D8E0C	8836 509828	VIKTOR MATVEEV	{"phone": "+70503266632"}
0005433679746	4D8E0C	6869 131873	DMITRIY CHERNOV	{"phone": "+70045556852"}
0005433679747	2209A6	6724 884491	EVGENIY RODIONOV	{"email": "evgeniy-rodionov-21031971@postgrespro.ru", "phone": "+70127585792"}
0005433679748	C7E815	5349 445663	SERGEY POPOV	{"phone": "+70968094770"}
0005433679749	6341C5	9512 458272	ELENA MEDVEDEVA	{"email": "emedvedeva.29081974@postgrespro.ru", "phone": "+70576409206"}
0005433679750	3B007B	0622 867804	OKSANA AKIMOVA	{"email": "akimova_o-31011985@postgrespro.ru", "phone": "+70051490479"}
0005433679751	3B007B	5099 103661	SERGEY MAKAROV	{"email": "sergey_makarov_07031973@postgrespro.ru", "phone": "+70154347381"}
0005433679752	877263	4624 056565	ALEKSANDR KULIKOV	{"email": "a.kulikov.101973@postgrespro.ru", "phone": "+70999480617"}
0005433679753	877263	6269 570812	MARGARITA MARTYNOVA	{"email": "margaritamartynova.1956@postgrespro.ru", "phone": "+70062606125"}
0005433679754	511314	8780 627638	ALEKSANDR KUZNECOV	{"phone": "+70169463882"}
0005433679755	EFAA42	5708 218768	VLADIMIR BELOV	{"phone": "+70029642936"}
0005433679756	EFAA42	5738 741166	YULIYA NAZAROVA	{"email": "nazarova-y.011975@postgrespro.ru", "phone": "+70701479789"}
0005433679757	DA970B	2884 779522	NINA ALEKSANDROVA	{"email": "aleksandrova-nina_051986@postgrespro.ru", "phone": "+70819338313"}
0005433679758	4017AE	1608 920057	TIMUR ANTONOV	{"phone": "+70926275634"}
0005433679759	399BF7	4445 143776	VALERIY PETROV	{"email": "petrov_v_1968@postgrespro.ru", "phone": "+70106244117"}
0005433679760	1120AE	5739 716032	SERGEY VASILEV	{"email": "vasilev_sergey.1971@postgrespro.ru", "phone": "+70944021541"}
0005433679761	CC27EC	9921 963696	SERGEY MIRONOV	{"phone": "+70519637951"}
0005433679762	B9857C	5216 022555	VLADIMIR STEPANOV	{"email": "vladimir_stepanov_1970@postgrespro.ru", "phone": "+70163482844"}
0005433679763	3B05A1	5627 099052	NIKITA MOROZOV	{"phone": "+70738421088"}
0005433679764	E4E0BA	2962 660299	GALINA NESTEROVA	{"email": "galinanesterova.03111971@postgrespro.ru", "phone": "+70997007055"}
0005433679765	EF381F	2357 781711	ALENA VOLKOVA	{"email": "volkova.alena_021972@postgrespro.ru", "phone": "+70037986023"}
0005433679766	EF381F	1831 865689	SERGEY ZAYCEV	{"email": "zaycev-s.07041982@postgrespro.ru", "phone": "+70351785748"}
0005433679767	6EBE4A	9323 639386	NATALYA IVANOVA	{"phone": "+70128180733"}
0005433679768	6EBE4A	8370 912676	MIKHAIL KUZNECOV	{"phone": "+70381150880"}
0005433679769	D7A044	9675 926379	KRISTINA ZOTOVA	{"email": "zotovak-021978@postgrespro.ru", "phone": "+70067371463"}
0005433679770	481E33	6371 105051	IVAN TARASOV	{"phone": "+70248463345"}
0005433679771	A13F9B	5033 232961	NADEZHDA TIKHONOVA	{"phone": "+70894445083"}
0005433679772	D2779C	1663 535347	MARIYA DANILOVA	{"phone": "+70048528169"}
0005433679773	CE2455	2802 242116	ANNA KRASNOVA	{"email": "krasnova-a111978@postgrespro.ru", "phone": "+70607579783"}
0005433679774	CE2455	4184 617130	VASILIY ZHURAVLEV	{"email": "zhuravlev.v1967@postgrespro.ru", "phone": "+70298788339"}
0005433679775	CE2455	0093 933954	KHALIDA SCHERBAKOVA	{"phone": "+70656060723"}
0005433679776	925318	2646 533465	ALEKSANDR IVANOV	{"email": "aleksandrivanov-101975@postgrespro.ru", "phone": "+70406525477"}
0005433679777	B5B95A	3043 298235	VADIM STEPANOV	{"phone": "+70693825101"}
0005433679778	3EECA1	7737 490366	VALENTINA EGOROVA	{"email": "egorovavalentina.1983@postgrespro.ru", "phone": "+70492710058"}
0005433679779	C11A58	5961 098449	VALENTINA KOLESNIKOVA	{"email": "kolesnikova.v.041966@postgrespro.ru", "phone": "+70401498691"}
0005433679780	0F3C1F	8152 837633	LIDIYA DENISOVA	{"phone": "+70068142095"}
0005433679781	85A79A	5723 456509	SVETLANA FEDOROVA	{"email": "fedorovasvetlana.21091976@postgrespro.ru", "phone": "+70958722799"}
0005433679782	E2E955	9213 077119	ALEKSEY VLASOV	{"phone": "+70847770630"}
0005433679783	26DDA1	2425 275091	PAVEL IVANOV	{"phone": "+70217754548"}
0005433679784	B930B8	5536 759701	NINA ROMANOVA	{"email": "nina_romanova.1990@postgrespro.ru", "phone": "+70981891711"}
0005433679785	B930B8	3290 324241	NATALIYA MARTYNOVA	{"email": "nmartynova.23101975@postgrespro.ru", "phone": "+70416226767"}
0005433679786	B930B8	0698 291429	ANNA MAKAROVA	{"email": "makarova.a_1961@postgrespro.ru", "phone": "+70734996219"}
0005433679787	DB4C85	7122 704490	ELENA BELYAEVA	{"phone": "+70373467258"}
0005433679788	DB4C85	9916 073553	VERA MELNIKOVA	{"email": "melnikova_v1980@postgrespro.ru", "phone": "+70024566061"}
0005433679789	A9B49F	3600 254048	TATYANA GORBUNOVA	{"email": "gorbunova_tatyana-1974@postgrespro.ru", "phone": "+70161742028"}
0005433679790	6114E1	6874 307057	SERGEY FEDOROV	{"email": "fedorov_s.101984@postgrespro.ru", "phone": "+70338204299"}
0005433679791	D1D5CF	6727 109541	ANASTASIYA ANTONOVA	{"email": "antonova.anastasiya-13111975@postgrespro.ru", "phone": "+70745668266"}
0005433679792	8D6F19	3920 083814	ARTEM SERGEEV	{"email": "sergeevartem_1977@postgrespro.ru", "phone": "+70395792845"}
0005433679793	8D6F19	3617 680328	RAISA SCHERBAKOVA	{"phone": "+70858672057"}
0005433679794	8D6F19	5507 661899	VYACHESLAV MEDVEDEV	{"phone": "+70088806416"}
0005433679795	50F338	3947 967797	ANTONINA LEBEDEVA	{"phone": "+70074013441"}
0005433679796	32086E	6893 267695	NATALIYA TARASOVA	{"phone": "+70802485491"}
0005433679797	5C112A	6346 618324	SERGEY GUSEV	{"phone": "+70403971338"}
0005433679798	E6B2BE	4086 053855	IRINA POLYAKOVA	{"email": "polyakova-i.14041967@postgrespro.ru", "phone": "+70909403389"}
0005433679799	1E7F9C	7590 298242	LARISA SMIRNOVA	{"email": "smirnova.larisa.1980@postgrespro.ru", "phone": "+70534194878"}
0005433679800	67BA9A	2467 062291	RIMMA KRASNOVA	{"email": "krasnova-r.17041966@postgrespro.ru", "phone": "+70809236845"}
0005433679801	67BA9A	9153 480791	ELENA FEDOROVA	{"email": "fedorova_elena1973@postgrespro.ru", "phone": "+70092251916"}
0005433679802	C5B91A	5011 585290	IGOR DENISOV	{"email": "denisov_i-1970@postgrespro.ru", "phone": "+70535572264"}
0005433679803	254CA5	1299 098527	SERGEY POPOV	{"phone": "+70189837241"}
0005433679804	8E18D2	3178 164354	SVETLANA ROMANOVA	{"email": "svetlana-romanova041974@postgrespro.ru", "phone": "+70555892612"}
0005433679806	55B8DC	8516 759321	TATYANA SIDOROVA	{"phone": "+70756508879"}
0005433679807	5D2AD0	1760 306219	SERGEY CHERNOV	{"phone": "+70846130263"}
0005433679808	5D2AD0	5743 857849	GALINA GRISHINA	{"email": "grishina_galina_1973@postgrespro.ru", "phone": "+70933380236"}
0005433679809	EA3F21	9887 605315	NINA NIKITINA	{"email": "nnikitina-031979@postgrespro.ru", "phone": "+70650081239"}
0005433679810	EA3F21	0521 690160	MAKSIM VOLKOV	{"email": "m_volkov-28081965@postgrespro.ru", "phone": "+70112905410"}
0005433679811	DBB632	8220 310788	VLADIMIR PAVLOV	{"phone": "+70324304192"}
0005433679812	186935	8686 237049	DARYA TARASOVA	{"phone": "+70522099780"}
0005433679813	BA909B	6773 315286	LIDIYA KUZNECOVA	{"email": "kuznecova-l021972@postgrespro.ru", "phone": "+70581421835"}
0005433679814	FDE34E	5082 793862	SERGEY TIKHONOV	{"phone": "+70373525158"}
0005433679815	3E7104	8430 155403	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov.121967@postgrespro.ru", "phone": "+70130484389"}
0005433679816	A1C7CB	9864 896827	ANNA ABRAMOVA	{"phone": "+70303420599"}
0005433679817	12C92A	3806 974044	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey.1970@postgrespro.ru", "phone": "+70168596395"}
0005433679818	79D1CB	2867 864873	SOFIYA VOLKOVA	{"email": "s.volkova_1962@postgrespro.ru", "phone": "+70530788054"}
0005433679819	79D1CB	5242 629647	GALINA SIDOROVA	{"email": "sidorova_g-01011976@postgrespro.ru", "phone": "+70889914571"}
0005433679820	79D1CB	0552 289684	LIDIYA IVANOVA	{"email": "livanova021983@postgrespro.ru", "phone": "+70008540195"}
0005433679821	445519	8618 215705	NATALYA VASILEVA	{"email": "vasilevanatalya-12031967@postgrespro.ru", "phone": "+70696541973"}
0005433679822	E0E360	9379 706200	VIKTOR BARANOV	{"phone": "+70655260214"}
0005433679823	7FE6AD	1137 626886	VITALIY VASILEV	{"email": "v_vasilev-071960@postgrespro.ru", "phone": "+70489794869"}
0005433679824	3D6A96	2160 974781	POLINA ROMANOVA	{"email": "p_romanova-1970@postgrespro.ru", "phone": "+70898219934"}
0005433679825	5B8BE1	4044 529234	VLADISLAV KOZLOV	{"email": "kozlov_vladislav1965@postgrespro.ru", "phone": "+70772887110"}
0005433679826	3DC68B	6138 938185	ELENA KOZLOVA	{"email": "kozlova.elena.031973@postgrespro.ru", "phone": "+70727678428"}
0005433679827	2C8E3E	0503 711897	SVYATOSLAV SEMENOV	{"phone": "+70307981752"}
0005433679828	567D11	3358 920299	NADEZHDA ROMANOVA	{"email": "nromanova-081974@postgrespro.ru", "phone": "+70891941533"}
0005433679829	4D822E	4840 442516	EKATERINA DMITRIEVA	{"phone": "+70680287916"}
0005433679830	3F2D4F	2579 174339	GALINA NIKOLAEVA	{"email": "g_nikolaeva-10021982@postgrespro.ru", "phone": "+70488733764"}
0005433679831	84F03F	1810 301728	ELENA KUZNECOVA	{"email": "elena-kuznecova.13121980@postgrespro.ru", "phone": "+70201687821"}
0005433679832	C0F997	8923 992034	GRIGORIY MARTYNOV	{"email": "martynovgrigoriy1980@postgrespro.ru", "phone": "+70735636867"}
0005433679833	C0F997	7456 454810	ALEKSANDRA CHERNOVA	{"phone": "+70274729315"}
0005433679834	D1A327	6345 100281	VALENTIN AFANASEV	{"email": "vafanasev_26111963@postgrespro.ru", "phone": "+70181424320"}
0005433679835	12929B	2133 567746	NATALYA DENISOVA	{"email": "denisovanatalya-1979@postgrespro.ru", "phone": "+70236592088"}
0005433679836	12929B	2119 424539	GALINA POTAPOVA	{"email": "g.potapova_21021962@postgrespro.ru", "phone": "+70202540669"}
0005433679837	12929B	2042 790472	ELIZAVETA KAZAKOVA	{"phone": "+70940934713"}
0005433679838	AFDC69	1006 704126	ALEKSEY CHERNOV	{"email": "chernovaleksey_101974@postgrespro.ru", "phone": "+70597479719"}
0005433679839	D4EA75	5727 359533	IGOR DAVYDOV	{"phone": "+70978315033"}
0005433679840	D8575B	6202 666864	MARIYA POPOVA	{"email": "popova.mariya-101978@postgrespro.ru", "phone": "+70182479523"}
0005433679841	6410B7	5982 472244	NADEZHDA ISAEVA	{"phone": "+70102580546"}
0005433679842	15F382	2228 003373	IVAN TIMOFEEV	{"email": "timofeev.ivan_30041964@postgrespro.ru", "phone": "+70905240959"}
0005433679843	23D8B6	6254 427515	VALENTINA BARANOVA	{"phone": "+70151300090"}
0005433679844	23D8B6	8857 779205	EGOR BELOV	{"phone": "+70747157841"}
0005433679845	AF3F37	9300 668696	VIKTOR KOROLEV	{"email": "korolev_viktor.1967@postgrespro.ru", "phone": "+70818757236"}
0005433679846	AF3F37	6462 592196	ANASTASIYA NAZAROVA	{"email": "nazarovaa_061978@postgrespro.ru", "phone": "+70131004236"}
0005433679847	7389F6	0871 355454	NATALYA KAZAKOVA	{"phone": "+70287150727"}
0005433679848	DB4628	8305 113922	ANASTASIYA MARTYNOVA	{"phone": "+70005848506"}
0005433679849	DB4628	3474 208578	ALEKSANDR MIRONOV	{"phone": "+70325581674"}
0005433679850	6D368B	8381 423495	ALEKSEY BELOV	{"email": "belov-a26011977@postgrespro.ru", "phone": "+70254748397"}
0005433679851	DB59DF	8372 167126	ANTON POPOV	{"phone": "+70800049366"}
0005433679852	CC3792	8393 047179	ANDREY MELNIKOV	{"phone": "+70145548751"}
0005433679853	2A5D6C	3350 309412	KIRILL VOLKOV	{"phone": "+70513914235"}
0005433679854	2A5D6C	3882 797673	MARIYA VOROBEVA	{"phone": "+70963775568"}
0005433679855	062EC9	3305 366239	DARYA VOLKOVA	{"email": "volkovadarya-12041961@postgrespro.ru", "phone": "+70523975977"}
0005433679856	062EC9	3319 477815	NATALYA POTAPOVA	{"phone": "+70425808208"}
0005433679857	277284	4290 137899	DANIIL VOROBEV	{"email": "vorobev.d_1985@postgrespro.ru", "phone": "+70078173184"}
0005433679858	CC8204	9257 310152	EKATERINA FILATOVA	{"email": "e-filatova.021965@postgrespro.ru", "phone": "+70196880138"}
0005433679859	5C3D15	4135 343518	ALEKSANDRA ISAEVA	{"phone": "+70276925210"}
0005433679860	150457	3008 489002	EVGENIY PAVLOV	{"phone": "+70369383436"}
0005433679861	150457	7172 781329	LEONID KUZMIN	{"email": "kuzmin-l.031985@postgrespro.ru", "phone": "+70584472112"}
0005433679862	F07BC5	7642 906686	LYUDMILA DMITRIEVA	{"phone": "+70414818820"}
0005433679863	F07BC5	8270 604372	OLGA SOLOVEVA	{"phone": "+70155431919"}
0005433679864	030712	2280 485072	IRINA BORISOVA	{"email": "i.borisova121983@postgrespro.ru", "phone": "+70911360402"}
0005433679865	0BB555	2604 200298	ANDREY KUZNECOV	{"phone": "+70133243099"}
0005433679866	0BB555	4741 222705	OLEG IVANOV	{"phone": "+70989386656"}
0005433679867	0BB555	1104 768773	ANATOLIY FEDOROV	{"email": "fedorov.a_051973@postgrespro.ru", "phone": "+70429649391"}
0005433679868	AFC70D	3463 370033	NATALYA IVANOVA	{"phone": "+70643147719"}
0005433679869	EB9345	7114 927915	VLADIMIR ROMANOV	{"phone": "+70189550047"}
0005433679870	D2F03E	6976 512291	NADEZHDA FILATOVA	{"phone": "+70905862310"}
0005433679871	543BD5	1896 365527	LIDIYA VASILEVA	{"email": "vasileva-lidiya-05081968@postgrespro.ru", "phone": "+70019647521"}
0005433679872	BD2051	8872 087432	TATYANA BELOVA	{"email": "t_belova041984@postgrespro.ru", "phone": "+70763057142"}
0005433679873	BD2051	4626 666674	SERGEY FROLOV	{"phone": "+70991665233"}
0005433679874	AB22F2	1408 917868	VERA GUSEVA	{"email": "guseva.vera-02061956@postgrespro.ru", "phone": "+70903879348"}
0005433679875	2BEA1B	2836 041129	ELENA VLASOVA	{"phone": "+70875052198"}
0005433679876	7A7575	6242 184286	ELENA DAVYDOVA	{"email": "davydovaelena101973@postgrespro.ru", "phone": "+70262951707"}
0005433679877	7A7575	3934 943394	OLGA POTAPOVA	{"email": "olgapotapova_1963@postgrespro.ru", "phone": "+70903680755"}
0005433679878	945D56	2259 044605	SERGEY KUZNECOV	{"phone": "+70421452157"}
0005433679879	7D2D38	1211 150856	NADEZHDA GERASIMOVA	{"phone": "+70124288208"}
0005433679880	9972F0	8338 180546	DMITRIY IVANOV	{"email": "d_ivanov-021965@postgrespro.ru", "phone": "+70999683347"}
0005433679881	9972F0	2261 193572	ANDREY ALEKSANDROV	{"phone": "+70054620592"}
0005433679882	4A6193	5207 285574	IRINA DMITRIEVA	{"phone": "+70628803234"}
0005433679883	61D30C	1634 266954	LYUBOV DMITRIEVA	{"email": "dmitrieva.lyubov26111976@postgrespro.ru", "phone": "+70850295028"}
0005433679884	DD057E	0350 873172	ALEKSANDR VOLKOV	{"phone": "+70535153318"}
0005433679885	68FA07	0658 023004	INESSA KOZLOVA	{"email": "i.kozlova_24041978@postgrespro.ru", "phone": "+70545407094"}
0005433679886	597AA0	4292 559964	ARTEM POPOV	{"phone": "+70920079208"}
0005433679887	E8A8BE	7087 255726	NIKOLAY KUZMIN	{"phone": "+70477200152"}
0005433679888	E8A8BE	5402 322427	KRISTINA ZAKHAROVA	{"phone": "+70170626317"}
0005433679889	4E5042	5632 878796	SERGEY KUDRYASHOV	{"phone": "+70883090819"}
0005433679890	295861	7843 033420	DMITRIY SCHERBAKOV	{"phone": "+70321055858"}
0005433679891	E49930	4868 072326	MAKSIM YAKOVLEV	{"email": "yakovlev.maksim-21021961@postgrespro.ru", "phone": "+70535211612"}
0005433679892	2B39D6	2508 046097	IRINA MAKAROVA	{"phone": "+70996904821"}
0005433679893	45E105	5856 678498	SERGEY ALEKSEEV	{"email": "s.alekseev_30061973@postgrespro.ru", "phone": "+70750001853"}
0005433679894	45E105	4321 912554	VALENTINA VOLKOVA	{"phone": "+70029712308"}
0005433679895	2EA488	6864 752976	YULIYA ANISIMOVA	{"phone": "+70073782979"}
0005433679896	2EA488	6842 620874	TATYANA ILINA	{"email": "ilina_t_031966@postgrespro.ru", "phone": "+70853916476"}
0005433679897	2C732B	4430 283423	SERGEY PETROV	{"email": "sergey.petrov-1984@postgrespro.ru", "phone": "+70963110934"}
0005433679898	21F402	7704 595610	IRINA KONOVALOVA	{"email": "konovalova-irina_26011966@postgrespro.ru", "phone": "+70915311799"}
0005433679899	D26693	1140 075220	MARIYA EGOROVA	{"phone": "+70380291912"}
0005433679900	D26693	2541 611909	ANDREY ROMANOV	{"email": "romanov_a1957@postgrespro.ru", "phone": "+70230491758"}
0005433679901	A92C3F	0739 675485	RUSLAN SOKOLOV	{"email": "r-sokolov111972@postgrespro.ru", "phone": "+70841879033"}
0005433679902	A92C3F	3244 854189	VALERIY VOLKOV	{"phone": "+70896261643"}
0005433679903	6A7152	0512 011400	SNEZHANA ZHUKOVA	{"email": "zhukova_s1972@postgrespro.ru", "phone": "+70038818682"}
0005433679904	6A7152	8715 427316	ANASTASIYA GUSEVA	{"phone": "+70581976754"}
0005433679905	8C07BF	5854 956244	ELENA NESTEROVA	{"email": "enesterova_051974@postgrespro.ru", "phone": "+70606154207"}
0005433679906	262596	7739 707290	ALEKSEY SCHERBAKOV	{"phone": "+70384579102"}
0005433679907	93D597	0384 826922	ANZHELA KUZMINA	{"phone": "+70636217285"}
0005433679908	B54E62	3772 311143	NATALYA GUSEVA	{"email": "guseva_natalya.1978@postgrespro.ru", "phone": "+70786539634"}
0005433679909	85E1BD	6130 913895	SERGEY ILIN	{"email": "ilin-sergey.121969@postgrespro.ru", "phone": "+70850031208"}
0005433679910	F91C71	0355 573894	OLEG TARASOV	{"email": "tarasov.o1962@postgrespro.ru", "phone": "+70191260286"}
0005433679911	7829DB	5041 730417	VLADIMIR SOROKIN	{"phone": "+70116389421"}
0005433679912	A5E091	0124 275873	VIKTORIYA KRASNOVA	{"email": "viktoriya.krasnova-06081981@postgrespro.ru", "phone": "+70464000916"}
0005433679913	A5E091	2898 968902	ANDREY FROLOV	{"phone": "+70173662793"}
0005433679914	D2CCB6	8776 442313	VYACHESLAV PAVLOV	{"email": "pavlov.vyacheslav.031970@postgrespro.ru", "phone": "+70348398209"}
0005433679915	4EE95A	1684 702551	DANIL SHEVCHENKO	{"phone": "+70703522909"}
0005433679916	7CFA47	1699 748844	MIKHAIL MAKAROV	{"email": "makarov_mikhail1971@postgrespro.ru", "phone": "+70932315713"}
0005433679917	A8EE0F	1882 013656	VALENTIN CHERNOV	{"email": "valentinchernov15071968@postgrespro.ru", "phone": "+70092796501"}
0005433679918	6B83B9	2698 152612	EVGENIY KISELEV	{"phone": "+70215667779"}
0005433679919	B94551	4855 879880	YURIY DAVYDOV	{"phone": "+70392044229"}
0005433679920	2F08EF	0444 352418	OLGA KUDRYASHOVA	{"phone": "+70619973599"}
0005433679921	022315	8511 937088	MIKHAIL MOROZOV	{"email": "mmorozov.02051971@postgrespro.ru", "phone": "+70437163980"}
0005433679922	8CD26C	7219 028063	MIKHAIL PETROV	{"phone": "+70897667678"}
0005433679923	8CD26C	4401 928721	VLADIMIR IVANOV	{"phone": "+70059834966"}
0005433679924	B7880D	8582 591171	TATYANA GERASIMOVA	{"email": "gerasimova.t23061973@postgrespro.ru", "phone": "+70632474173"}
0005433679925	B7880D	6270 081932	DMITRIY NOVIKOV	{"phone": "+70353210357"}
0005433679926	D14440	4348 630899	SANIYA MALYSHEVA	{"phone": "+70481660908"}
0005433679927	D14440	6088 279701	MARIYA PAVLOVA	{"email": "pavlova.mariya.02111963@postgrespro.ru", "phone": "+70284039640"}
0005433679928	2E33AC	3587 424115	ALENA ABRAMOVA	{"email": "a_abramova_1984@postgrespro.ru", "phone": "+70352074729"}
0005433679929	F81033	6463 638153	NINA KISELEVA	{"phone": "+70600582937"}
0005433679930	F81033	0613 019080	ANDREY KULIKOV	{"email": "kulikovandrey-021980@postgrespro.ru", "phone": "+70796492477"}
0005433679931	9E5D9A	1228 053991	NINA ARKHIPOVA	{"phone": "+70400604942"}
0005433679932	75AEE7	6703 850933	ANGELINA ISAEVA	{"email": "isaeva-a_021978@postgrespro.ru", "phone": "+70478784544"}
0005433679933	03FF88	1034 090250	VITALIY KUZMIN	{"email": "vitaliy_kuzmin.121969@postgrespro.ru", "phone": "+70022941774"}
0005433679934	FDEE62	3987 852392	EVGENIY SIDOROV	{"phone": "+70189979078"}
0005433679935	FDEE62	6269 384561	SERGEY IVANOV	{"email": "ivanov_sergey-1979@postgrespro.ru", "phone": "+70814915403"}
0005433679936	812ADA	0452 885823	OLGA SOKOLOVA	{"phone": "+70989142326"}
0005433679937	31E94D	1943 785741	TATYANA POPOVA	{"email": "tpopova-061971@postgrespro.ru", "phone": "+70282511876"}
0005433679938	FF690A	1262 195539	LYUBOV DENISOVA	{"phone": "+70907886148"}
0005433679939	549683	1307 422280	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov_011971@postgrespro.ru", "phone": "+70983380447"}
0005433679940	A5BA7F	3214 472246	VERA MOISEEVA	{"email": "moiseeva_vera_021968@postgrespro.ru", "phone": "+70076422324"}
0005433679941	A5BA7F	3774 130537	NATALYA KUZNECOVA	{"email": "kuznecova_n_111976@postgrespro.ru", "phone": "+70829403644"}
0005433679942	9AB079	0393 590460	VYACHESLAV MATVEEV	{"email": "vyacheslav.matveev_09071963@postgrespro.ru", "phone": "+70213076247"}
0005433679943	898A2B	9020 880430	IRINA NIKOLAEVA	{"phone": "+70196485526"}
0005433679944	E24681	2220 563100	PETR POPOV	{"email": "p_popov28031965@postgrespro.ru", "phone": "+70388926599"}
0005433679945	CA15A7	0645 683096	NATALYA NOVIKOVA	{"email": "n-novikova.26011974@postgrespro.ru", "phone": "+70614835652"}
0005433679946	CF62C6	1593 413734	ELENA SOROKINA	{"phone": "+70301409808"}
0005433679947	B51C44	7393 059825	YULIYA IVANOVA	{"phone": "+70437735603"}
0005433679948	B51C44	7901 713381	LYUBOV EFREMOVA	{"email": "lefremova.18031968@postgrespro.ru", "phone": "+70951529372"}
0005433679949	44E773	1801 721224	VYACHESLAV NIKOLAEV	{"phone": "+70942701640"}
0005433679950	D3D833	1607 852549	MARIYA KISELEVA	{"email": "m.kiseleva.041974@postgrespro.ru", "phone": "+70137489437"}
0005433679951	A49BEE	9333 184481	LEV FROLOV	{"phone": "+70435903907"}
0005433679952	1A2658	9689 557011	VIKTORIYA SOKOLOVA	{"email": "sokolova_v-27081969@postgrespro.ru", "phone": "+70374453746"}
0005433679953	1A2658	8461 320398	TATYANA GUSEVA	{"email": "gusevatatyana-20051960@postgrespro.ru", "phone": "+70332243793"}
0005433679954	050B01	2771 882557	IRINA EGOROVA	{"phone": "+70910200843"}
0005433679955	C315C2	4370 942663	MARGARITA FROLOVA	{"phone": "+70824757125"}
0005433679956	FC7E4E	3538 792149	NIKOLAY MIKHAYLOV	{"phone": "+70941601906"}
0005433679957	30AA79	8506 303272	MARIYA EGOROVA	{"email": "egorova_m-011959@postgrespro.ru", "phone": "+70025207108"}
0005433679958	30AA79	7392 341062	NATALYA DMITRIEVA	{"phone": "+70666169895"}
0005433679959	9AED9A	2555 225197	SVETLANA OVCHINNIKOVA	{"phone": "+70039851531"}
0005433679960	9AED9A	1763 141635	TATYANA SIDOROVA	{"phone": "+70513645560"}
0005433679961	9A010D	1161 186569	ROZA VOLKOVA	{"email": "volkova_roza11041965@postgrespro.ru", "phone": "+70897935749"}
0005433679962	9A010D	7502 703967	ANATOLIY PAVLOV	{"email": "pavlova07121967@postgrespro.ru", "phone": "+70145041942"}
0005433679963	A04673	1902 645746	DMITRIY EGOROV	{"phone": "+70007436633"}
0005433679964	75F426	3662 251795	YULIYA LEBEDEVA	{"email": "yuliya_lebedeva.111970@postgrespro.ru", "phone": "+70742026378"}
0005433679965	B8CD82	4571 107573	ILGIZ VASILEV	{"phone": "+70318288516"}
0005433679966	B8CD82	3489 013801	VALENTINA KUZNECOVA	{"phone": "+70791146880"}
0005433679967	7E08EB	4007 820645	EKATERINA ILINA	{"email": "eilina_10061973@postgrespro.ru", "phone": "+70385720801"}
0005433679968	B78D6B	4983 057942	KIRILL GERASIMOV	{"email": "kgerasimov.1965@postgrespro.ru", "phone": "+70573354033"}
0005433679969	70AACF	4351 099638	EVGENIYA PAVLOVA	{"phone": "+70695710880"}
0005433679970	79E1F3	1091 963396	SOFYA TITOVA	{"email": "s_titova-1975@postgrespro.ru", "phone": "+70217696897"}
0005433679971	3701C7	4319 573405	LYUDMILA OVCHINNIKOVA	{"phone": "+70326124185"}
0005433679972	428340	6103 058218	VALENTINA KISELEVA	{"phone": "+70769854762"}
0005433679973	AE712D	7809 991378	ALEKSEY VOROBEV	{"phone": "+70750454265"}
0005433679974	5AA3A4	4788 625113	OLGA VASILEVA	{"email": "vasileva-o_021978@postgrespro.ru", "phone": "+70191624870"}
0005433679975	5AA3A4	3981 756148	ANDREY KAZAKOV	{"phone": "+70973128845"}
0005433679976	5AA3A4	1384 974344	VALERIY IVANOV	{"phone": "+70495646816"}
0005433679977	677683	2990 396228	ELENA MAKAROVA	{"phone": "+70762627436"}
0005433679978	EAA335	9839 621170	VIKTOR SMIRNOV	{"email": "v.smirnov-051965@postgrespro.ru", "phone": "+70224739614"}
0005433679979	18C154	6374 108848	YURIY TARASOV	{"email": "tarasov-y031961@postgrespro.ru", "phone": "+70993568546"}
0005433679980	18C154	5656 030313	GALINA BELYAEVA	{"phone": "+70048487936"}
0005433679981	F6C5C2	6483 396336	ZINAIDA ZHURAVLEVA	{"email": "z.zhuravleva-041964@postgrespro.ru", "phone": "+70585081069"}
0005433679982	033218	4702 720730	GALINA ZAKHAROVA	{"phone": "+70620140441"}
0005433679983	11C6DD	2461 644947	NATALYA EFIMOVA	{"phone": "+70401318169"}
0005433679984	D300EB	0013 014693	VALENTINA ABRAMOVA	{"phone": "+70510924166"}
0005433679985	55C03E	0407 083038	ARTEM FEDOTOV	{"phone": "+70618714065"}
0005433679986	0C9A30	3228 206855	ILYA SAVELEV	{"phone": "+70966011403"}
0005433679987	9A7FA6	6826 477754	SERGEY BORISOV	{"phone": "+70798693637"}
0005433679988	9A7FA6	2391 344017	ILYA VLASOV	{"email": "ilyavlasov051984@postgrespro.ru", "phone": "+70947815362"}
0005433679989	9B5F43	6856 725051	VLADIMIR PAVLOV	{"phone": "+70054947637"}
0005433679990	9B5F43	5755 875992	DMITRIY CHERNOV	{"email": "d.chernov_31121966@postgrespro.ru", "phone": "+70019486341"}
0005433679991	0A332D	6942 454723	NIKITA ANTONOV	{"email": "antonov.nikita_1980@postgrespro.ru", "phone": "+70550280463"}
0005433679992	82CDF6	3319 698411	VALERIY TARASOV	{"phone": "+70123927752"}
0005433679993	920FEE	7485 945724	YULIYA KOROLEVA	{"email": "koroleva_yuliya_061969@postgrespro.ru", "phone": "+70249691524"}
0005433679994	8A6298	6991 036155	LYUBOV MATVEEVA	{"phone": "+70704715188"}
0005433679995	8A6298	2491 034333	ALEKSANDR KRASNOV	{"phone": "+70866951586"}
0005433679996	FB3498	5723 657519	ALEKSEY GAVRILOV	{"email": "gavrilov_a_1978@postgrespro.ru", "phone": "+70081723272"}
0005433679997	88B1A5	5312 120601	SERGEY CHERNOV	{"email": "chernov.sergey1969@postgrespro.ru", "phone": "+70224484583"}
0005433679998	85329C	7109 070303	IRINA BELOVA	{"email": "belova-i.101960@postgrespro.ru", "phone": "+70497575722"}
0005433679999	85329C	8241 899278	VLADIMIR DAVYDOV	{"email": "vladimirdavydov.1968@postgrespro.ru", "phone": "+70360201882"}
0005433680000	6C289D	6853 900966	ANATOLIY KUZNECOV	{"phone": "+70188954992"}
0005433680001	299714	3655 185709	ELENA CHERNOVA	{"phone": "+70818132754"}
0005433680002	299714	5385 632251	ANNA KARPOVA	{"phone": "+70816526868"}
0005433680003	FD2C17	3744 057346	VALENTINA OSIPOVA	{"email": "osipova_valentina_1972@postgrespro.ru", "phone": "+70094111325"}
0005433680004	37A94B	1693 593440	TATYANA GRISHINA	{"email": "grishina.t-111978@postgrespro.ru", "phone": "+70513272824"}
0005433680005	66BD74	8718 171750	EKATERINA FILIPPOVA	{"phone": "+70795926317"}
0005433680006	B5B1C2	1722 096428	YULIYA LAZAREVA	{"email": "lazareva.y.1976@postgrespro.ru", "phone": "+70769650683"}
0005433680007	FFB2FC	5715 974647	ANDREY ZAKHAROV	{"email": "azakharov_13031971@postgrespro.ru", "phone": "+70658992476"}
0005433680008	FFB2FC	6416 348922	ALEKSANDR SMIRNOV	{"email": "smirnov.a_071982@postgrespro.ru", "phone": "+70176541950"}
0005433680009	C7F9C3	3633 489396	ELIZAVETA DMITRIEVA	{"email": "e-dmitrieva_071976@postgrespro.ru", "phone": "+70918243211"}
0005433680010	C7F9C3	9431 031468	VIKTOR GORBUNOV	{"phone": "+70386695302"}
0005433680011	C7F9C3	7898 695859	ELENA ALEKSEEVA	{"phone": "+70239622718"}
0005433680012	C7F9C3	5794 316870	ANASTASIYA EGOROVA	{"phone": "+70899840343"}
0005433680013	2FEC4C	4513 679394	VASILIY ANTONOV	{"phone": "+70662111694"}
0005433680014	2FEC4C	3206 101883	MARIYA NOVIKOVA	{"email": "novikova-mariya-031973@postgrespro.ru", "phone": "+70223649948"}
0005433680015	324EB3	0291 129453	SERGEY SEMENOV	{"email": "s.semenov.1972@postgrespro.ru", "phone": "+70708663573"}
0005433680016	7A145E	3149 681838	IVAN ZAYCEV	{"phone": "+70007920088"}
0005433680017	4E4E5F	1016 267305	DANIIL SIDOROV	{"email": "d_sidorov-041971@postgrespro.ru", "phone": "+70063457009"}
0005433680018	4E4E5F	6286 571532	IGOR MAKSIMOV	{"email": "maksimov-igor.011975@postgrespro.ru", "phone": "+70933415973"}
0005433680019	1783AC	0035 269659	VLADIMIR BORISOV	{"email": "vladimir_borisov_27041966@postgrespro.ru", "phone": "+70168101252"}
0005433680020	1783AC	0236 976862	YULIYA NIKITINA	{"phone": "+70343225218"}
0005433680021	5F2286	1671 370757	MARINA ALEKSEEVA	{"email": "malekseeva.1968@postgrespro.ru", "phone": "+70725463415"}
0005433680022	5F2286	7766 543110	RUSLAN ANTONOV	{"email": "ruslanantonov-071964@postgrespro.ru", "phone": "+70497405024"}
0005433680023	D1A828	1396 788384	NATALYA SOROKINA	{"email": "sorokina-n-061977@postgrespro.ru", "phone": "+70625393362"}
0005433680024	D1A828	5787 954749	RAMIL VASILEV	{"phone": "+70175421789"}
0005433680025	11BA32	1589 851411	ANTON PETROV	{"phone": "+70845114945"}
0005433680026	207942	8744 225466	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov-011977@postgrespro.ru", "phone": "+70773274493"}
0005433680027	6CEF81	6281 135719	FLYURA LEBEDEVA	{"email": "flebedeva_071978@postgrespro.ru", "phone": "+70157209643"}
0005433680028	492028	6543 440040	MARIYA AFANASEVA	{"email": "afanasevamariya_1988@postgrespro.ru", "phone": "+70563665316"}
0005433680029	199048	2813 941279	IRINA MELNIKOVA	{"email": "i-melnikova_1971@postgrespro.ru", "phone": "+70318391343"}
0005433680030	199048	0977 833994	ALEKSANDR BORISOV	{"email": "aleksandr-borisov.24091984@postgrespro.ru", "phone": "+70245641702"}
0005433680031	9D30F7	9645 323991	ILDAR NAUMOV	{"email": "naumov_i_21111976@postgrespro.ru", "phone": "+70765106754"}
0005433680032	C2A7FF	7617 937805	NINA EFREMOVA	{"phone": "+70149847236"}
0005433680033	0B3A21	9396 367362	MARIYA MARTYNOVA	{"email": "martynova_mariya-091971@postgrespro.ru", "phone": "+70752568524"}
0005433680034	0B3A21	4859 594823	ZINAIDA FOMINA	{"email": "fominazinaida_1976@postgrespro.ru", "phone": "+70611755732"}
0005433680035	0B3A21	4085 339116	VALERIYA TIMOFEEVA	{"phone": "+70398771875"}
0005433680036	0B3A21	2939 816700	LYUDMILA TIKHONOVA	{"phone": "+70679214538"}
0005433680037	3DC479	7962 215819	VALERIYA KONDRATEVA	{"email": "v-kondrateva1977@postgrespro.ru", "phone": "+70205429590"}
0005433680038	3DC479	5858 266852	KONSTANTIN TIMOFEEV	{"email": "timofeev.k.03071977@postgrespro.ru", "phone": "+70852394120"}
0005433680039	3DC479	2797 865023	KSENIYA ARKHIPOVA	{"email": "kseniya.arkhipova.27061975@postgrespro.ru", "phone": "+70859771075"}
0005433680040	F6F1F0	4817 878951	ELENA SOLOVEVA	{"phone": "+70297483239"}
0005433680041	F6F1F0	8445 083363	VADIM IVANOV	{"email": "vadimivanov.051971@postgrespro.ru", "phone": "+70772890746"}
0005433680042	3CB900	6710 636758	TATYANA CHERNOVA	{"email": "tatyana-chernova24121968@postgrespro.ru", "phone": "+70371226767"}
0005433680043	AEBCE6	9311 145355	VIKTORIYA KONDRATEVA	{"email": "viktoriya.kondrateva_1974@postgrespro.ru", "phone": "+70206813219"}
0005433680044	AEBCE6	2018 039494	ILYA DENISOV	{"phone": "+70641215288"}
0005433680045	AEBCE6	2571 803923	TATYANA AFANASEVA	{"email": "afanasevat-1980@postgrespro.ru", "phone": "+70656470133"}
0005433680046	DDEE62	3009 803871	OLGA SERGEEVA	{"email": "sergeevaolga101970@postgrespro.ru", "phone": "+70682866055"}
0005433680047	2A6070	5393 746230	DARYA MAKAROVA	{"phone": "+70489083615"}
0005433680048	DA1B51	9135 892626	NADEZHDA IVANOVA	{"email": "n-ivanova-21081983@postgrespro.ru", "phone": "+70408455459"}
0005433680049	6BFFA6	3104 135709	ELENA VOROBEVA	{"email": "e.vorobeva-081973@postgrespro.ru", "phone": "+70977300147"}
0005433680050	CF4304	3612 021464	EKATERINA DMITRIEVA	{"phone": "+70333954376"}
0005433680051	CF4304	7418 536465	ANASTASIYA KRASNOVA	{"email": "krasnova_anastasiya.17091984@postgrespro.ru", "phone": "+70401290601"}
0005433680052	BD3E1B	8688 430166	LYUDMILA PETROVA	{"email": "l.petrova-1976@postgrespro.ru", "phone": "+70495796504"}
0005433680053	D7963D	8707 271754	ANDREY KUZNECOV	{"email": "kuznecovandrey1984@postgrespro.ru", "phone": "+70116821550"}
0005433680054	D7963D	6672 110297	ARINA FADEEVA	{"phone": "+70245675405"}
0005433680055	1E8C15	3090 678761	ALEKSANDR ANDREEV	{"email": "andreeva-1972@postgrespro.ru", "phone": "+70754902433"}
0005433680056	1E8C15	0860 529064	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr.18111975@postgrespro.ru", "phone": "+70960251558"}
0005433680057	C1729E	0116 276875	TATYANA ABRAMOVA	{"phone": "+70672752458"}
0005433680058	B836B3	3324 772008	NIKOLAY ZAKHAROV	{"email": "n_zakharov-111965@postgrespro.ru", "phone": "+70880762920"}
0005433680059	3D0A21	9210 141938	RUSTAM GAVRILOV	{"phone": "+70863844654"}
0005433680060	04A8B0	2294 701592	MAKSIM TIKHONOV	{"email": "tikhonovm16101971@postgrespro.ru", "phone": "+70621732088"}
0005433680061	04A8B0	8459 056630	ANASTASIYA KOZLOVA	{"phone": "+70158768515"}
0005433680062	A6672D	5571 819049	SVETLANA MOISEEVA	{"phone": "+70476662146"}
0005433680063	A6672D	7848 463073	ARTEM MOISEEV	{"email": "artem_moiseev.1974@postgrespro.ru", "phone": "+70709188514"}
0005433680064	A2A492	7637 285160	PETR ORLOV	{"phone": "+70726239792"}
0005433680065	37FD63	1704 326223	ALFIYA SCHERBAKOVA	{"phone": "+70547569030"}
0005433680066	05C060	5207 916685	ALLA KRASNOVA	{"phone": "+70525993875"}
0005433680067	05C060	8331 146196	VYACHESLAV KOZLOV	{"phone": "+70137380641"}
0005433680068	E7C324	6035 205778	DMITRIY SERGEEV	{"phone": "+70098583078"}
0005433680069	E7C324	8065 693815	VLADIMIR PETROV	{"email": "v-petrov20031973@postgrespro.ru", "phone": "+70572578070"}
0005433680070	E7C324	0596 809818	ANTONINA KUZNECOVA	{"email": "antonina.kuznecova_1967@postgrespro.ru", "phone": "+70957822487"}
0005433680071	B8968B	3961 062095	EVGENIY MOROZOV	{"email": "morozov-evgeniy-1966@postgrespro.ru", "phone": "+70133530654"}
0005433680072	286B89	2787 803583	ANATOLIY MELNIKOV	{"phone": "+70414615522"}
0005433680073	286B89	3014 704425	DENIS NIKOLAEV	{"phone": "+70001296427"}
0005433680074	A179AF	6414 858919	OLGA NIKIFOROVA	{"email": "o.nikiforova.25111963@postgrespro.ru", "phone": "+70616008575"}
0005433680075	A179AF	4402 773394	ALEKSANDR FOMIN	{"phone": "+70017648875"}
0005433680076	52A03B	5577 608019	OLGA FROLOVA	{"phone": "+70571577267"}
0005433680077	E41557	0110 626333	ALEKSANDR KULIKOV	{"phone": "+70922862354"}
0005433680078	E41557	8392 208905	OLEG SCHERBAKOV	{"email": "o-scherbakov-1970@postgrespro.ru", "phone": "+70447741257"}
0005433680079	46B40D	3235 422299	DANIIL KAZAKOV	{"email": "kazakov_d.1982@postgrespro.ru", "phone": "+70107307907"}
0005433680080	1178FD	9433 513340	VLADIMIR ISAEV	{"phone": "+70671903174"}
0005433680081	1178FD	2721 192115	NINA MALYSHEVA	{"phone": "+70337986465"}
0005433680082	BBCBE7	1575 572543	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov051965@postgrespro.ru", "phone": "+70285654476"}
0005433680083	BBCBE7	7511 284697	SEMEN KUZNECOV	{"email": "kuznecovsemen_04061978@postgrespro.ru", "phone": "+70013931519"}
0005433680084	BBCBE7	7914 779072	NATALYA NAUMOVA	{"phone": "+70694874170"}
0005433680085	9E8B27	7260 270916	VLADIMIR VOROBEV	{"phone": "+70327481426"}
0005433680086	977AAD	4848 675066	NADEZHDA CHERNOVA	{"phone": "+70780827449"}
0005433680087	D5C9DF	5428 882456	VLADIMIR SCHERBAKOV	{"phone": "+70094857519"}
0005433680088	D7DCE9	5806 265161	ELIZAVETA EGOROVA	{"email": "elizaveta.egorova101980@postgrespro.ru", "phone": "+70535013034"}
0005433680089	D4C757	7467 940372	NATALYA ALEKSANDROVA	{"phone": "+70398589681"}
0005433680090	D4C757	1173 742903	GALINA PAVLOVA	{"email": "pavlova-galina_1972@postgrespro.ru", "phone": "+70972208144"}
0005433680091	6F0A55	4832 258058	NIKOLAY VOLKOV	{"phone": "+70999823801"}
0005433680092	8AEBBA	3293 087053	INNA TITOVA	{"phone": "+70618912674"}
0005433680093	EAC91B	5992 566945	VYACHESLAV EGOROV	{"email": "egorov_vyacheslav22011966@postgrespro.ru", "phone": "+70363598546"}
0005433680094	FFD5C3	3094 829037	PETR AFANASEV	{"email": "petr-afanasev_041969@postgrespro.ru", "phone": "+70814742355"}
0005433680095	FFD5C3	6582 565895	ALEKSANDR FROLOV	{"phone": "+70417928711"}
0005433680096	3D0899	2853 987668	VLADIMIR VLASOV	{"phone": "+70765689101"}
0005433680097	A8E62C	2299 708896	OLGA ANTONOVA	{"phone": "+70360304577"}
0005433680098	5E8AD2	1389 599278	LYUDMILA SAVELEVA	{"email": "lyudmila_saveleva.19021977@postgrespro.ru", "phone": "+70949764400"}
0005433680099	5E8AD2	5417 732490	LIDIYA RODIONOVA	{"phone": "+70520761924"}
0005433680100	941A8A	4708 522388	ANTON ZAYCEV	{"phone": "+70545040647"}
0005433680101	5E32B7	9957 012018	ELENA KUZNECOVA	{"phone": "+70754516909"}
0005433680102	1D6067	8381 947682	YULIYA SEMENOVA	{"email": "semenovayuliya.091969@postgrespro.ru", "phone": "+70843162751"}
0005433680103	82DFF3	2248 323065	EKATERINA GRISHINA	{"phone": "+70065705124"}
0005433680104	DA19E0	3467 608150	ROMAN BARANOV	{"email": "baranov.roman.051970@postgrespro.ru", "phone": "+70494975748"}
0005433680105	DA19E0	5064 980835	ANGELINA EFREMOVA	{"phone": "+70824963766"}
0005433680106	0F21F2	5802 050818	EVGENIY DMITRIEV	{"email": "e.dmitriev_011956@postgrespro.ru", "phone": "+70964305949"}
0005433680107	0F21F2	6258 625979	DMITRIY NOVIKOV	{"phone": "+70618003980"}
0005433680108	4630E9	7374 202710	NIKOLAY KISELEV	{"email": "kiselevnikolay061972@postgrespro.ru", "phone": "+70805643704"}
0005433680109	9E966A	0033 634537	VIKTOR FEDOROV	{"phone": "+70990426499"}
0005433680110	9E966A	0128 683525	KSENIYA MAKAROVA	{"email": "makarova.kseniya-07011968@postgrespro.ru", "phone": "+70083009843"}
0005433680111	DA3F7F	1379 460983	MARINA NOVIKOVA	{"phone": "+70841624569"}
0005433680112	DA3F7F	1961 923044	SERGEY MARTYNOV	{"email": "sergey.martynov_1955@postgrespro.ru", "phone": "+70043011965"}
0005433680113	81C728	7472 466405	DARYA ANISIMOVA	{"phone": "+70247281641"}
0005433680114	FC6F7E	2388 170209	EKATERINA VOLKOVA	{"phone": "+70386874281"}
0005433680115	887AFB	0718 278429	MIKHAIL VLASOV	{"email": "vlasov.mikhail_031969@postgrespro.ru", "phone": "+70219494829"}
0005433680116	887AFB	3734 109462	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_vyacheslav-29101969@postgrespro.ru", "phone": "+70886714920"}
0005433680117	4B88CE	0448 082214	GENNADIY ORLOV	{"phone": "+70014353208"}
0005433680118	E2B81A	2536 452240	ALEKSANDR BORISOV	{"phone": "+70634859704"}
0005433680119	E2B81A	9343 504145	SVETLANA MAKSIMOVA	{"email": "svetlana.maksimova11081962@postgrespro.ru", "phone": "+70638350283"}
0005433680120	7B8F1D	8753 819918	ELISEY SERGEEV	{"phone": "+70274794362"}
0005433680121	4BF4F1	2424 144707	VLADIMIR POPOV	{"email": "v-popov081978@postgrespro.ru", "phone": "+70681027283"}
0005433680122	E81942	1670 863019	SVETLANA ROMANOVA	{"phone": "+70306719132"}
0005433680123	E81942	4099 462456	MARIYA KUZNECOVA	{"phone": "+70561409048"}
0005433680124	E81942	0748 447367	LYUDMILA VLASOVA	{"phone": "+70822468129"}
0005433680125	2AA6A4	6775 935293	LYUDMILA EFREMOVA	{"email": "l-efremova14091980@postgrespro.ru", "phone": "+70768539254"}
0005433680126	2AA6A4	6872 374555	VIKTORIYA DENISOVA	{"phone": "+70345324639"}
0005433680127	661FDB	9634 944164	NIKITA ANTONOV	{"email": "antonovnikita.121971@postgrespro.ru", "phone": "+70932893779"}
0005433680128	00D96A	7928 057333	ANASTASIYA ZOTOVA	{"email": "zotova.a18101962@postgrespro.ru", "phone": "+70689339258"}
0005433680129	00D96A	9158 556798	NATALYA POPOVA	{"email": "popova.n-12011959@postgrespro.ru", "phone": "+70024033181"}
0005433680130	2B99F6	5844 492599	EVGENIY ZAYCEV	{"phone": "+70463311864"}
0005433680131	2B99F6	3980 760172	VYACHESLAV DAVYDOV	{"email": "vyacheslav.davydov-1966@postgrespro.ru", "phone": "+70352250843"}
0005433680132	799E48	1744 513674	ALEKSANDR MIKHAYLOV	{"phone": "+70023095087"}
0005433680133	0AF0BC	1141 887120	VALENTINA NIKOLAEVA	{"phone": "+70513264236"}
0005433680134	0AF0BC	1360 590579	EKATERINA SOLOVEVA	{"phone": "+70581951406"}
0005433680135	D2BC7E	3183 240748	SVETLANA EFREMOVA	{"phone": "+70067389818"}
0005433680136	BD3D55	3316 553528	EDUARD KUDRYASHOV	{"email": "eduard-kudryashov25081971@postgrespro.ru", "phone": "+70435837454"}
0005433680137	235958	6628 457911	KIRILL FROLOV	{"email": "frolov_kirill.05111972@postgrespro.ru", "phone": "+70982935609"}
0005433680138	235958	6235 847824	ARTEMIY KARPOV	{"phone": "+70373560066"}
0005433680139	235958	7317 503436	ALEKSANDR NIKITIN	{"phone": "+70874570745"}
0005433680140	A0A1F6	8282 185741	LEV VASILEV	{"phone": "+70427871841"}
0005433680141	A0A1F6	5851 114537	MARINA KARPOVA	{"email": "karpova_m1972@postgrespro.ru", "phone": "+70497194967"}
0005433680142	B5DE40	3263 312158	VIKTOR KOROLEV	{"email": "korolevv.051973@postgrespro.ru", "phone": "+70415278256"}
0005433680143	A3F5F6	6040 937766	LYUDMILA MAKAROVA	{"email": "lyudmila_makarova-20041969@postgrespro.ru", "phone": "+70350539196"}
0005433680144	E74A9D	1437 822332	VERA ALEKSEEVA	{"email": "alekseeva-v.22111975@postgrespro.ru", "phone": "+70497119175"}
0005433680145	0C04DC	7867 523952	SOFYA IVANOVA	{"email": "sofya-ivanova-24101973@postgrespro.ru", "phone": "+70189833807"}
0005433680146	187745	8952 165331	LIDIYA KUDRYASHOVA	{"phone": "+70103037793"}
0005433680147	07A996	9514 220821	VALERIY VLASOV	{"phone": "+70215217219"}
0005433680148	EF70F6	5635 256038	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov-011968@postgrespro.ru", "phone": "+70258314893"}
0005433680149	7C457C	8517 459457	YULIYA DAVYDOVA	{"email": "yuliyadavydova-28101974@postgrespro.ru", "phone": "+70659522025"}
0005433680150	4E8632	5631 665204	GENNADIY KRASNOV	{"phone": "+70437830473"}
0005433680151	5C20A8	8805 616941	VALERIY SOROKIN	{"phone": "+70137530591"}
0005433680152	FDE9DB	3885 428482	PETR NAZAROV	{"email": "pnazarov081969@postgrespro.ru", "phone": "+70539988379"}
0005433680153	57693F	9727 137704	VALERIY IVANOV	{"phone": "+70326877530"}
0005433680154	AC7317	3559 097428	MAKSIM PETROV	{"email": "maksim.petrov021968@postgrespro.ru", "phone": "+70231852574"}
0005433680155	AC7317	6179 450768	VYACHESLAV ILIN	{"email": "vyacheslav-ilin.1967@postgrespro.ru", "phone": "+70721075007"}
0005433680156	DFEB45	0233 239453	IVAN TARASOV	{"phone": "+70902349626"}
0005433680157	9A6A19	4366 834399	SERGEY ILIN	{"phone": "+70215982861"}
0005433680158	70B08A	3865 360040	VLADIMIR ILIN	{"phone": "+70989195006"}
0005433680159	70B08A	1760 092621	NIKOLAY BARANOV	{"email": "nikolay_baranov27071969@postgrespro.ru", "phone": "+70060830991"}
0005433680160	1EF141	3865 175355	SERGEY OSIPOV	{"phone": "+70251894684"}
0005433680161	6909F6	2313 409081	IRINA ZAYCEVA	{"email": "irina_zayceva.011975@postgrespro.ru", "phone": "+70314875767"}
0005433680162	718C2E	9485 493924	ELENA TARASOVA	{"email": "etarasova-07021977@postgrespro.ru", "phone": "+70976970765"}
0005433680163	969513	6376 902236	MARIYA NAUMOVA	{"phone": "+70678996689"}
0005433680164	969513	9901 806431	SERGEY SOROKIN	{"email": "sorokin-sergey.011981@postgrespro.ru", "phone": "+70528878778"}
0005433680165	535B52	0182 040059	NATALYA BELOVA	{"email": "belova_n041975@postgrespro.ru", "phone": "+70941429727"}
0005433680166	535B52	7049 327213	SERGEY PAVLOV	{"email": "sergey-pavlov.24071963@postgrespro.ru", "phone": "+70333523598"}
0005433680167	CB0ECB	0448 627359	OKSANA PETROVA	{"email": "oksana_petrova_01111966@postgrespro.ru", "phone": "+70601896287"}
0005433680168	CB0ECB	4994 114845	VALERIY MEDVEDEV	{"email": "medvedev_v.06031969@postgrespro.ru", "phone": "+70407206819"}
0005433680169	0344CC	2423 679058	VITALIY SCHERBAKOV	{"phone": "+70638334217"}
0005433680170	0344CC	1590 450991	ANASTASIYA ZAKHAROVA	{"email": "azakharova.1964@postgrespro.ru", "phone": "+70859663458"}
0005433680171	1EC64E	8749 983405	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr_1970@postgrespro.ru", "phone": "+70251438351"}
0005433680172	ED8B49	0210 739863	ALEKSANDR SCHERBAKOV	{"phone": "+70587769308"}
0005433680173	ABBDE5	3154 668614	NADEZHDA PAVLOVA	{"email": "nadezhdapavlova.26111977@postgrespro.ru", "phone": "+70065600917"}
0005433680174	973ECC	9920 560909	VASILIY TIKHONOV	{"phone": "+70819295536"}
0005433680175	13873A	8803 779180	SERGEY DENISOV	{"phone": "+70929421126"}
0005433680176	65F19D	7242 498141	ALEKSANDR MELNIKOV	{"phone": "+70596913083"}
0005433680177	607E9B	3971 801990	DARYA ZAKHAROVA	{"phone": "+70952463507"}
0005433680178	D96B2B	2226 679905	ANASTASIYA MEDVEDEVA	{"phone": "+70793480155"}
0005433680179	D96B2B	8055 418019	ELENA POTAPOVA	{"email": "e-potapova-111983@postgrespro.ru", "phone": "+70694998476"}
0005433680180	6505EF	2764 557510	VLADIMIR CHERNOV	{"phone": "+70200499332"}
0005433680181	5A985C	9964 018265	ANATOLIY SAVELEV	{"phone": "+70609067199"}
0005433680182	2AF272	7400 024829	KONSTANTIN POPOV	{"phone": "+70776853794"}
0005433680183	433780	5657 265603	OLGA ALEKSEEVA	{"phone": "+70581193145"}
0005433680184	6A042C	7906 839688	OLGA VOLKOVA	{"email": "volkova_olga.101969@postgrespro.ru", "phone": "+70938299014"}
0005433680185	41D465	9772 397968	ARTEM STEPANOV	{"email": "stepanov.artem_1977@postgrespro.ru", "phone": "+70370436802"}
0005433680186	41D465	4582 979535	IRINA FEDOROVA	{"phone": "+70185943037"}
0005433680187	41D465	9472 291774	YULIYA GRISHINA	{"email": "y.grishina07031979@postgrespro.ru", "phone": "+70736007567"}
0005433680188	7DDF5F	1030 704232	NATALYA MATVEEVA	{"email": "natalyamatveeva.22041969@postgrespro.ru", "phone": "+70284224754"}
0005433680189	7DDF5F	0187 089649	VYACHESLAV ANTONOV	{"email": "antonov-v.07031969@postgrespro.ru", "phone": "+70140364134"}
0005433680190	604FC6	7534 816909	ZOYA ABRAMOVA	{"email": "abramova_z22121971@postgrespro.ru", "phone": "+70713897140"}
0005433680191	28885D	0751 291358	ILYA IVANOV	{"phone": "+70962115655"}
0005433680192	0E0D9B	4468 706332	RUDOLF TIKHONOV	{"email": "rudolftikhonov1971@postgrespro.ru", "phone": "+70374124776"}
0005433680193	0E0D9B	1972 606085	IVAN KUDRYASHOV	{"email": "ivan-kudryashov061960@postgrespro.ru", "phone": "+70623545206"}
0005433680194	98A782	4043 983261	OKSANA BORISOVA	{"email": "borisova-oksana-041972@postgrespro.ru", "phone": "+70856865365"}
0005433680195	754F61	7476 849320	PETR DMITRIEV	{"phone": "+70657690444"}
0005433680196	754F61	0674 938592	IRINA MOROZOVA	{"email": "irinamorozova.051976@postgrespro.ru", "phone": "+70495693916"}
0005433680197	BFBE51	1583 771106	YURIY SAVELEV	{"phone": "+70128433962"}
0005433680198	CD9827	5306 192477	VYACHESLAV ABRAMOV	{"phone": "+70133646506"}
0005433680199	E008A2	2782 199495	IVAN ZHUKOV	{"email": "zhukov.i.101974@postgrespro.ru", "phone": "+70429132360"}
0005433680200	BF9518	5143 495046	ARTEM KISELEV	{"phone": "+70220004490"}
0005433680201	45F471	0615 857414	NIKOLAY STEPANOV	{"phone": "+70947526666"}
0005433680202	A19FF6	9933 680705	OLGA LAZAREVA	{"email": "lazarevao.1976@postgrespro.ru", "phone": "+70445118144"}
0005433680203	19F591	6819 803167	IRAIDA NIKIFOROVA	{"email": "nikiforova.iraida.051974@postgrespro.ru", "phone": "+70165649870"}
0005433680204	64C2DD	1687 479100	LYUBOV SERGEEVA	{"email": "lyubov-sergeeva1971@postgrespro.ru", "phone": "+70487907238"}
0005433680205	64C2DD	8606 862047	VALERIYA ORLOVA	{"phone": "+70182792311"}
0005433680206	B1C3B5	5708 364742	VLADIMIR SEMENOV	{"email": "vladimir-semenov_1966@postgrespro.ru", "phone": "+70078923363"}
0005433680207	EBB6C0	6865 572725	IRINA KRASNOVA	{"phone": "+70436268567"}
0005433680208	EBB6C0	1255 841355	ELENA RYABOVA	{"phone": "+70946737342"}
0005433680209	D10728	6198 161321	MARINA POLYAKOVA	{"email": "polyakova-m_1978@postgrespro.ru", "phone": "+70866704670"}
0005433680210	A1B031	7754 314692	NINA STEPANOVA	{"email": "n-stepanova.1963@postgrespro.ru", "phone": "+70100658241"}
0005433680211	A1B031	3985 150331	VYACHESLAV VOROBEV	{"phone": "+70459239207"}
0005433680212	FFE62B	6274 490560	VLADIMIR ZAYCEV	{"phone": "+70424207711"}
0005433680213	FFE62B	4992 382863	TATYANA MATVEEVA	{"email": "tatyana.matveeva-1967@postgrespro.ru", "phone": "+70014219970"}
0005433680214	79AED1	9772 398946	VLADIMIR SOKOLOV	{"phone": "+70204266542"}
0005433680215	5967E2	8232 384862	ANDREY OSIPOV	{"email": "osipov_a31031963@postgrespro.ru", "phone": "+70885789527"}
0005433680216	5967E2	6810 141725	SERGEY PETROV	{"phone": "+70656561619"}
0005433680217	213292	9368 707429	NIKOLAY MOISEEV	{"email": "n-moiseev_09011976@postgrespro.ru", "phone": "+70120823522"}
0005433680218	A3036B	1425 341390	KIRILL ABRAMOV	{"phone": "+70457258170"}
0005433680219	5470A7	6065 205797	NIKOLAY ZHURAVLEV	{"phone": "+70649153715"}
0005433680220	5470A7	7109 520178	ANDREY SOLOVEV	{"phone": "+70589161778"}
0005433680221	0C3137	0068 262222	SERGEY GUSEV	{"phone": "+70112731504"}
0005433680222	899A2B	6339 373549	ALEKSANDR VOLKOV	{"phone": "+70765517591"}
0005433680223	543457	5419 844488	ELENA NOVIKOVA	{"email": "elenanovikova061974@postgrespro.ru", "phone": "+70134935777"}
0005433680224	543457	7477 980680	EKATERINA ZAKHAROVA	{"email": "ekaterinazakharova-1975@postgrespro.ru", "phone": "+70261447650"}
0005433680225	81686F	1269 261435	ALEKSANDR GORBUNOV	{"phone": "+70244843129"}
0005433680226	06E66B	3163 411747	LYUDMILA VASILEVA	{"email": "lyudmila.vasileva-091973@postgrespro.ru", "phone": "+70214469172"}
0005433680227	7D2F7D	5555 689714	OLESYA ALEKSEEVA	{"email": "alekseevao-06071979@postgrespro.ru", "phone": "+70408682092"}
0005433680228	F82BF2	1374 059959	VLADIMIR IVANOV	{"phone": "+70387054595"}
0005433680229	8CF3F2	9059 966005	RUSLAN SOROKIN	{"phone": "+70097260180"}
0005433680230	59F729	2599 577312	ANASTASIYA FILIPPOVA	{"email": "filippova.a_16051971@postgrespro.ru", "phone": "+70811624915"}
0005433680231	337BFF	3825 732236	SVETLANA SERGEEVA	{"phone": "+70827936811"}
0005433680232	246A75	9027 560749	ALEKSANDR ANDREEV	{"phone": "+70307990512"}
0005433680233	2769DE	4466 863380	ANDREY DMITRIEV	{"email": "dmitriev-a-16041961@postgrespro.ru", "phone": "+70865084821"}
0005433680234	2769DE	7479 666410	NATALYA KAZAKOVA	{"email": "kazakova_natalya_1951@postgrespro.ru", "phone": "+70824827440"}
0005433680235	240C1F	8543 861021	LYUDMILA SAVELEVA	{"phone": "+70414373677"}
0005433680236	EF8E91	9441 212930	SERGEY KONOVALOV	{"phone": "+70143059561"}
0005433680237	A0B0D2	6713 342885	VALENTIN MOROZOV	{"phone": "+70076001703"}
0005433680238	A0B0D2	0412 885471	ALEKSANDR KUZNECOV	{"phone": "+70492963143"}
0005433680239	7080CD	9490 562193	ANNA FOMINA	{"phone": "+70455711164"}
0005433680240	39C538	9907 907786	ELENA KOROLEVA	{"phone": "+70910008670"}
0005433680241	39C538	6971 121232	VALERIY DAVYDOV	{"email": "v-davydov_1975@postgrespro.ru", "phone": "+70905086132"}
0005433680242	39C538	1695 157976	NATALYA KONDRATEVA	{"phone": "+70809226665"}
0005433680243	9AE4D8	1820 772702	VIKTOR IVANOV	{"email": "viktorivanov-13031958@postgrespro.ru", "phone": "+70770027707"}
0005433680244	725185	3650 109364	ANNA VLASOVA	{"email": "a.vlasova_10071977@postgrespro.ru", "phone": "+70671244411"}
0005433680245	98AE60	6132 301561	NINA ALEKSEEVA	{"email": "alekseeva-nina_1976@postgrespro.ru", "phone": "+70112505908"}
0005433680246	98AE60	5415 869390	ALEKSANDR DENISOV	{"email": "denisov-a-1985@postgrespro.ru", "phone": "+70972561338"}
0005433680247	1EA0E9	0887 073953	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr_101971@postgrespro.ru", "phone": "+70055158235"}
0005433680248	1EA0E9	8155 005570	LYUDMILA MELNIKOVA	{"phone": "+70465201205"}
0005433680249	E17A2F	6543 204453	IRINA IVANOVA	{"phone": "+70409555156"}
0005433680250	E17A2F	1032 232091	ANNA ABRAMOVA	{"email": "abramova-anna1976@postgrespro.ru", "phone": "+70874793297"}
0005433680251	E17A2F	3374 454780	ANDREY PETROV	{"email": "a.petrov_13091979@postgrespro.ru", "phone": "+70370485801"}
0005433680252	9E020C	4295 751011	ELENA KUZNECOVA	{"phone": "+70647720430"}
0005433680253	450B4E	7687 596970	ANATOLIY TARASOV	{"phone": "+70542825859"}
0005433680254	450B4E	5021 342661	GRIGORIY IVANOV	{"phone": "+70921463278"}
0005433680255	450B4E	6967 990554	ELIZAVETA FROLOVA	{"email": "frolova-e.17121993@postgrespro.ru", "phone": "+70861778365"}
0005433680256	450B4E	9709 275351	SERGEY PETROV	{"email": "petrov.s-1974@postgrespro.ru", "phone": "+70297771115"}
0005433680257	E4279D	5496 638021	VARVARA MELNIKOVA	{"phone": "+70537544513"}
0005433680258	1297C0	7053 865920	RENATA LOGINOVA	{"phone": "+70872174419"}
0005433680259	F8B897	2175 569710	ANDREY DENISOV	{"email": "adenisov_01111961@postgrespro.ru", "phone": "+70526819390"}
0005433680260	75BD0B	0629 839148	YAROSLAV POPOV	{"email": "yaroslav-popov_011981@postgrespro.ru", "phone": "+70351426504"}
0005433680261	73992C	3394 913557	ROMAN SEMENOV	{"email": "semenov-roman091976@postgrespro.ru", "phone": "+70644035858"}
0005433680262	73992C	1195 749949	VALENTINA MEDVEDEVA	{"phone": "+70608114820"}
0005433680263	7B01AF	3477 541947	VADIM KOROLEV	{"email": "v.korolev_041977@postgrespro.ru", "phone": "+70770941457"}
0005433680264	7B01AF	6802 537929	ELENA POPOVA	{"email": "elena-popova20021974@postgrespro.ru", "phone": "+70253818420"}
0005433680265	8DD11E	3520 417623	VALERIY KONOVALOV	{"phone": "+70061510060"}
0005433680266	8DD11E	8222 033431	VLADIMIR VOLKOV	{"phone": "+70702824366"}
0005433680267	C2A337	4863 305104	MIKHAIL ZAKHAROV	{"email": "mzakharov_101963@postgrespro.ru", "phone": "+70579261518"}
0005433680268	6E8D53	9218 263731	YULIYA BOGDANOVA	{"phone": "+70549513838"}
0005433680269	537CEA	2744 805037	ANATOLIY VASILEV	{"phone": "+70979945885"}
0005433680270	90AD3A	1565 557597	EVGENIY ABRAMOV	{"phone": "+70029978025"}
0005433680271	DCD038	5700 885145	YURIY FEDOROV	{"phone": "+70960300691"}
0005433680272	DCD038	4925 494427	ELENA ANTONOVA	{"email": "antonova.e.26101972@postgrespro.ru", "phone": "+70218829256"}
0005433680273	EA7F6F	7518 740200	ANASTASIYA TARASOVA	{"phone": "+70945188077"}
0005433680274	D3DBAD	9294 952043	IRINA KUZMINA	{"email": "irina_kuzmina_23111983@postgrespro.ru", "phone": "+70061760201"}
0005433680275	D3DBAD	5206 793334	DMITRIY ROMANOV	{"email": "romanovd.1975@postgrespro.ru", "phone": "+70271171101"}
0005433680276	11B688	4070 803741	MARINA ZHURAVLEVA	{"phone": "+70874114535"}
0005433680277	6B7072	6943 491562	NATALYA SAVELEVA	{"email": "n_saveleva.1970@postgrespro.ru", "phone": "+70624562808"}
0005433680278	6B7072	5674 358411	VERA KOMAROVA	{"phone": "+70194687793"}
0005433680279	1469CF	2640 589568	VIKTORIYA NIKIFOROVA	{"phone": "+70582812863"}
0005433680280	2D33FE	4700 783032	VYACHESLAV MOROZOV	{"email": "morozov.vyacheslav-041971@postgrespro.ru", "phone": "+70605735502"}
0005433680281	8FCFCB	1728 623505	ALEKSANDR KUZNECOV	{"phone": "+70407934352"}
0005433680282	8FCFCB	3889 715594	MAKSIM BARANOV	{"phone": "+70019030985"}
0005433680283	50F75C	6033 242190	MARINA LEBEDEVA	{"email": "marina.lebedeva1968@postgrespro.ru", "phone": "+70127382539"}
0005433680284	5A9CC8	9807 865162	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin.101972@postgrespro.ru", "phone": "+70062334214"}
0005433680285	5A9CC8	4798 596573	VYACHESLAV NIKOLAEV	{"email": "nikolaevv_101980@postgrespro.ru", "phone": "+70994159201"}
0005433680286	C09925	9465 693237	MARIYA KUZMINA	{"email": "mariya.kuzmina091976@postgrespro.ru", "phone": "+70716455445"}
0005433680287	C09925	7602 849501	VLADIMIR TIKHONOV	{"phone": "+70367510824"}
0005433680288	AABAF1	0611 241253	ELENA GERASIMOVA	{"email": "e_gerasimova-05031967@postgrespro.ru", "phone": "+70036315674"}
0005433680289	818B3B	3575 244830	VALENTINA MATVEEVA	{"email": "matveeva-valentina_1971@postgrespro.ru", "phone": "+70617345928"}
0005433680290	4AAB61	4205 321197	ALEKSEY EGOROV	{"email": "aleksey.egorov_14061971@postgrespro.ru", "phone": "+70267567006"}
0005433680291	4AAB61	4478 479663	OLEG NIKOLAEV	{"email": "oleg_nikolaev.18071974@postgrespro.ru", "phone": "+70868374645"}
0005433680292	4AAB61	0989 120145	EKATERINA NAUMOVA	{"email": "e_naumova031966@postgrespro.ru", "phone": "+70635793530"}
0005433680293	DD4DE0	6663 849718	DMITRIY FOMIN	{"email": "fomind-29041974@postgrespro.ru", "phone": "+70760584089"}
0005433680294	CA0FE5	7385 309979	MARINA GRISHINA	{"email": "marina_grishina.031977@postgrespro.ru", "phone": "+70219705495"}
0005433680295	CA0FE5	4929 724335	POLINA MAKAROVA	{"email": "makarovap06081975@postgrespro.ru", "phone": "+70201121048"}
0005433680296	5F2D8D	6760 323088	VITALIY NIKITIN	{"email": "vnikitin.08101974@postgrespro.ru", "phone": "+70712311291"}
0005433680297	56A874	1924 009944	ALBINA DMITRIEVA	{"phone": "+70135625456"}
0005433680298	F5B5A6	2868 667880	ANNA ANDREEVA	{"phone": "+70084474539"}
0005433680299	F5B5A6	5016 811786	ANDREY MOROZOV	{"email": "morozov.andrey_1979@postgrespro.ru", "phone": "+70849014033"}
0005433680300	5DA70B	7798 447588	VLADIMIR SERGEEV	{"email": "sergeev.v.061965@postgrespro.ru", "phone": "+70195716065"}
0005433680301	67B60C	2051 790901	VADIM KRASNOV	{"phone": "+70289681014"}
0005433680302	129DBA	3875 697801	SERGEY STEPANOV	{"email": "stepanov.sergey_1972@postgrespro.ru", "phone": "+70134766049"}
0005433680303	129DBA	9675 895177	SERGEY VASILEV	{"phone": "+70594495019"}
0005433680304	546EDE	2190 292437	ALEKSEY BONDARENKO	{"phone": "+70704938186"}
0005433680305	0B2440	6054 614521	DENIS ZHURAVLEV	{"phone": "+70492130286"}
0005433680306	DBDFFE	5876 704207	YURIY VLASOV	{"email": "yuriy_vlasov031973@postgrespro.ru", "phone": "+70730826357"}
0005433680307	5345E4	5369 411424	ILYA GORBUNOV	{"phone": "+70280058481"}
0005433680308	61601D	1390 524297	EVA MIKHAYLOVA	{"phone": "+70389227941"}
0005433680309	61601D	2943 359017	RAISA MAKSIMOVA	{"phone": "+70002776341"}
0005433680310	44FDE0	4034 712503	ALEKSEY DMITRIEV	{"phone": "+70179930719"}
0005433680311	530B99	4129 208218	MATRENA MIRONOVA	{"phone": "+70063993291"}
0005433680312	34DF40	7984 382535	YURIY DENISOV	{"phone": "+70907682577"}
0005433680313	86963A	7089 625496	MARINA SEMENOVA	{"phone": "+70167308687"}
0005433680314	DAD7D3	6008 859515	LILIYA NAZAROVA	{"phone": "+70420450814"}
0005433680315	8B618B	2815 053399	MARINA ISAEVA	{"phone": "+70779467318"}
0005433680316	8B618B	2924 489496	VIKTOR BORISOV	{"email": "borisov.v.1976@postgrespro.ru", "phone": "+70332027439"}
0005433680317	0C9D5A	0504 884840	ELIZAVETA CHERNOVA	{"email": "e_chernova-29061969@postgrespro.ru", "phone": "+70487266283"}
0005433680318	6AB419	9890 179917	ELENA KOZLOVA	{"email": "e_kozlova_061973@postgrespro.ru", "phone": "+70882198931"}
0005433680319	BA05A1	9503 686579	LYUDMILA KARPOVA	{"email": "karpova-lyudmila121970@postgrespro.ru", "phone": "+70630497902"}
0005433680320	BA05A1	6026 084144	SVETLANA GORBUNOVA	{"email": "gorbunova.s_061974@postgrespro.ru", "phone": "+70376863637"}
0005433680321	257853	0997 610530	SERGEY ANTONOV	{"phone": "+70677864893"}
0005433680322	FF8431	0582 209465	ALEKSEY ZAYCEV	{"phone": "+70056407045"}
0005433680323	FF8431	1728 185294	INNA STEPANOVA	{"email": "inna_stepanova-061976@postgrespro.ru", "phone": "+70622740578"}
0005433680324	C6A6DD	1202 882073	VIKTORIYA GUSEVA	{"email": "guseva_v_1965@postgrespro.ru", "phone": "+70359889040"}
0005433680325	32966F	5340 780578	ALEKSANDR SEMENOV	{"phone": "+70917308278"}
0005433680326	76E7FC	8302 980203	ALEKSANDR MELNIKOV	{"phone": "+70993827270"}
0005433680327	A09926	1138 486059	IRINA ISAEVA	{"phone": "+70360738349"}
0005433680328	A09926	8980 659192	VERA KOLESNIKOVA	{"phone": "+70122142060"}
0005433680329	F820F0	0188 250455	NATALYA NIKIFOROVA	{"email": "natalyanikiforova.24011971@postgrespro.ru", "phone": "+70746169392"}
0005433680330	EB0891	3503 764379	GALINA RYABOVA	{"email": "ryabovag.09031965@postgrespro.ru", "phone": "+70599915952"}
0005433680331	8DC89B	2783 029646	VIKTOR BORISOV	{"phone": "+70012607016"}
0005433680332	BCE47B	8244 265932	MARIYA GUSEVA	{"email": "guseva_mariya-1969@postgrespro.ru", "phone": "+70906453022"}
0005433680333	B3BE58	2257 187061	ZINAIDA KOROLEVA	{"email": "koroleva_zinaida-25101967@postgrespro.ru", "phone": "+70213123864"}
0005433680334	B4043E	3924 654741	PLATON SIDOROV	{"phone": "+70792875517"}
0005433680335	B4043E	7869 423046	IVAN ROMANOV	{"phone": "+70117625786"}
0005433680336	B4043E	6992 555371	GULNARA KULIKOVA	{"phone": "+70938141391"}
0005433680337	E0B8C5	5273 031037	ELENA VASILEVA	{"phone": "+70472982962"}
0005433680338	76A61A	9560 314792	ANNA EFIMOVA	{"email": "efimova_a.08041980@postgrespro.ru", "phone": "+70147601091"}
0005433680339	76A61A	9259 873535	NIKOLAY NAUMOV	{"phone": "+70066760548"}
0005433680340	76A61A	5669 013806	MAKSIM YAKOVLEV	{"phone": "+70254281188"}
0005433680341	77CA0F	7191 180406	MARIYA KUDRYASHOVA	{"phone": "+70190095541"}
0005433680342	D1E866	6742 456762	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov_1977@postgrespro.ru", "phone": "+70539833874"}
0005433680343	D1E866	4466 253356	ZOYA FOMINA	{"email": "fomina_zoya-011983@postgrespro.ru", "phone": "+70879851404"}
0005433680344	D1E866	5879 651669	ALEKSANDR NIKITIN	{"email": "a.nikitin_051977@postgrespro.ru", "phone": "+70974578544"}
0005433680345	00E6D8	1820 158250	ELIZAVETA LAZAREVA	{"email": "lazareva.elizaveta-07081966@postgrespro.ru", "phone": "+70710468740"}
0005433680457	28EFE9	3604 392075	SERGEY MOROZOV	{"phone": "+70283341071"}
0005433680346	6028FE	1429 920718	MAKSIM KUZMIN	{"email": "maksim-kuzmin.07011971@postgrespro.ru", "phone": "+70333289619"}
0005433680347	2FEEF9	2540 892999	GENNADIY ORLOV	{"phone": "+70593950741"}
0005433680348	38AD61	0994 691647	ALEKSANDRA ANDREEVA	{"phone": "+70369553977"}
0005433680349	38AD61	3246 027001	SERGEY KRASNOV	{"phone": "+70642114755"}
0005433680528	70EA0C	9263 096669	ZULFIYA KARPOVA	{"phone": "+70390926820"}
0005433680350	A87002	3720 882141	ELENA KONOVALOVA	{"email": "elena-konovalova31031983@postgrespro.ru", "phone": "+70240910267"}
0005433680351	5E3AD8	6825 252541	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov06041970@postgrespro.ru", "phone": "+70610832214"}
0005433680352	5E3AD8	2044 261127	ELENA KOZLOVA	{"phone": "+70364802608"}
0005433680353	F13876	0847 193407	IRINA DMITRIEVA	{"phone": "+70119549108"}
0005433680354	1A5433	1443 797135	VITALIY GAVRILOV	{"email": "v-gavrilov-061963@postgrespro.ru", "phone": "+70941550905"}
0005433680355	897BDE	0185 477037	DMITRIY SOROKIN	{"email": "sorokind-111985@postgrespro.ru", "phone": "+70290023160"}
0005433680356	3E59F6	2932 293857	SERGEY VLASOV	{"email": "vlasov_sergey_1987@postgrespro.ru", "phone": "+70148250941"}
0005433680357	836191	1551 313522	DMITRIY MEDVEDEV	{"email": "medvedev-dmitriy_05101968@postgrespro.ru", "phone": "+70298998839"}
0005433680358	7282AA	3900 701762	GALINA MELNIKOVA	{"phone": "+70407918768"}
0005433680359	D0ECFF	4886 995832	LIDIYA MAKAROVA	{"phone": "+70841131706"}
0005433680360	A631F0	3974 883577	VLADIMIR IVANOV	{"phone": "+70517295865"}
0005433680361	CA22AC	2643 994325	IRINA MELNIKOVA	{"email": "melnikova.i.1967@postgrespro.ru", "phone": "+70900361416"}
0005433680362	A68189	7603 323351	GALINA ALEKSEEVA	{"email": "galina_alekseeva071977@postgrespro.ru", "phone": "+70600260283"}
0005433680363	83821B	8878 706450	VALENTIN VASILEV	{"phone": "+70440207269"}
0005433680364	83821B	9885 159697	SERGEY KAZAKOV	{"email": "kazakov_s-1979@postgrespro.ru", "phone": "+70550498315"}
0005433680365	3B54F0	7165 570313	NADEZHDA EGOROVA	{"email": "n_egorova.1969@postgrespro.ru", "phone": "+70864554038"}
0005433680366	6135D4	2092 303022	ALENA LAZAREVA	{"phone": "+70388038898"}
0005433680367	E49725	0996 527118	KIRILL BORISOV	{"phone": "+70695596027"}
0005433680368	B3E909	7515 403119	ILYAS PETROV	{"email": "ilyas.petrov-121970@postgrespro.ru", "phone": "+70732717738"}
0005433680369	6518AA	7191 983757	MARGARITA KONOVALOVA	{"email": "margarita.konovalova121978@postgrespro.ru", "phone": "+70267048845"}
0005433680370	6518AA	3360 100988	OLGA ARKHIPOVA	{"phone": "+70345497026"}
0005433680371	8C18D3	5721 900744	ARTEM KISELEV	{"phone": "+70585675116"}
0005433680372	8C18D3	8290 626751	IRINA NAUMOVA	{"phone": "+70220521676"}
0005433680373	449A5A	8218 975023	YURIY ABRAMOV	{"phone": "+70638407467"}
0005433680374	8DE57E	7321 006068	YURIY KOZLOV	{"phone": "+70841666859"}
0005433680375	3D2D48	0201 852115	MIKHAIL IVANOV	{"phone": "+70399883036"}
0005433680376	3D2D48	7206 862357	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov-051970@postgrespro.ru", "phone": "+70172939426"}
0005433680377	4A1A64	0186 762472	TAISA VASILEVA	{"phone": "+70984209263"}
0005433680378	E291D3	8844 084418	NADEZHDA BELOVA	{"email": "belovanadezhda-121974@postgrespro.ru", "phone": "+70136265846"}
0005433680379	A67398	2871 621760	ALEKSEY ABRAMOV	{"email": "a_abramov.16061966@postgrespro.ru", "phone": "+70751664655"}
0005433680380	4F8527	4942 078499	STANISLAV MAKAROV	{"phone": "+70192331838"}
0005433680381	238E29	7074 898508	TATYANA FROLOVA	{"phone": "+70004143732"}
0005433680382	9E949F	5505 557718	NINA IVANOVA	{"phone": "+70913807524"}
0005433680383	ECBA57	4920 106973	SERGEY ANTONOV	{"phone": "+70783554243"}
0005433680384	3B25DA	1304 170917	YURIY GRIGOREV	{"phone": "+70031859274"}
0005433680385	741B1E	3198 940515	SOFIYA KUZNECOVA	{"email": "sofiyakuznecova.15011973@postgrespro.ru", "phone": "+70389778358"}
0005433680386	741B1E	4634 420875	IRINA ZHURAVLEVA	{"email": "zhuravleva_i.1976@postgrespro.ru", "phone": "+70804097072"}
0005433680387	B74C92	6496 359105	IRINA STEPANOVA	{"email": "stepanovai1976@postgrespro.ru", "phone": "+70030447984"}
0005433680388	C6B8EF	9972 542330	ROMAN KRASNOV	{"phone": "+70090675801"}
0005433680389	3048D9	3047 075254	NADEZHDA ZHUKOVA	{"phone": "+70031055148"}
0005433680390	B50F2B	6945 989571	VLADIMIR IVANOV	{"email": "vladimirivanov.20041978@postgrespro.ru", "phone": "+70882820890"}
0005433680391	787D0F	0270 523563	GUZEL PAVLOVA	{"email": "g_pavlova.111964@postgrespro.ru", "phone": "+70148474611"}
0005433680392	04905D	3476 364386	GRIGORIY SCHERBAKOV	{"email": "scherbakovg-1974@postgrespro.ru", "phone": "+70669628286"}
0005433680393	7603BF	3279 139770	MARINA SEMENOVA	{"email": "m_semenova_1973@postgrespro.ru", "phone": "+70853614589"}
0005433680394	7603BF	1603 159591	ANDREY MAKAROV	{"phone": "+70236657201"}
0005433680395	E3BC3E	1202 488542	MARGARITA KOZLOVA	{"email": "margarita_kozlova_1974@postgrespro.ru", "phone": "+70681177827"}
0005433680396	E3BC3E	4783 281760	LIDIYA PETROVA	{"email": "petrova_l011981@postgrespro.ru", "phone": "+70410613952"}
0005433680397	CD6794	9089 895755	SERGEY EGOROV	{"phone": "+70775295873"}
0005433680398	CD6794	9550 800480	EVGENIY STEPANOV	{"email": "stepanov.e.09071960@postgrespro.ru", "phone": "+70907429013"}
0005433680399	CD6794	3944 424401	ELENA NOVIKOVA	{"email": "e-novikova_091977@postgrespro.ru", "phone": "+70897234654"}
0005433680400	C25689	8817 706980	ANTON ALEKSANDROV	{"phone": "+70551184067"}
0005433680401	016064	7242 206864	SERGEY ORLOV	{"email": "orlov.sergey111968@postgrespro.ru", "phone": "+70150914507"}
0005433680402	A7AFF7	5800 957566	ARTEM ANTONOV	{"email": "aantonov02071977@postgrespro.ru", "phone": "+70870560986"}
0005433680403	2C7E66	3589 751373	TATYANA NOVIKOVA	{"email": "novikovatatyana-10101966@postgrespro.ru", "phone": "+70227060003"}
0005433680404	31BEB5	7554 947477	TATYANA POPOVA	{"phone": "+70636783084"}
0005433680405	D6551B	2383 311227	MARIYA KUZNECOVA	{"email": "kuznecova-mariya-1971@postgrespro.ru", "phone": "+70185340311"}
0005433680406	05616B	6462 995519	ALEKSANDRA ROMANOVA	{"email": "aleksandra_romanova1984@postgrespro.ru", "phone": "+70976672356"}
0005433680407	B00EB5	2061 178917	VALENTIN SMIRNOV	{"phone": "+70942954552"}
0005433680408	E08CB7	8625 438979	ELENA ALEKSANDROVA	{"phone": "+70431822296"}
0005433680409	E08CB7	0348 089382	RAISA TIKHONOVA	{"email": "tikhonova.r1967@postgrespro.ru", "phone": "+70767587717"}
0005433680410	FB6167	7475 079543	EVA KUZMINA	{"email": "eva-kuzmina-08021972@postgrespro.ru", "phone": "+70937267431"}
0005433680411	1460BB	2268 449316	VLADIMIR VLASOV	{"email": "vlasov-vladimir_1969@postgrespro.ru", "phone": "+70378052523"}
0005433680412	6F962F	5329 799725	OKSANA FILIPPOVA	{"email": "filippova-oksana.08101973@postgrespro.ru", "phone": "+70179904673"}
0005433680413	C3BFE3	7162 345395	YULIYA ZHUKOVA	{"phone": "+70936006843"}
0005433680414	C3BFE3	1259 911753	ALEKSEY PETROV	{"phone": "+70451843124"}
0005433680415	E2D5D4	4814 628657	OLESYA MIRONOVA	{"email": "mironova.o-1968@postgrespro.ru", "phone": "+70769741538"}
0005433680416	E2D5D4	5884 534740	KIRILL VOROBEV	{"email": "vorobevk_111962@postgrespro.ru", "phone": "+70594466776"}
0005433680417	D770A2	7996 319314	ELENA EGOROVA	{"phone": "+70836513328"}
0005433680418	7373AE	0129 223459	RAISA POLYAKOVA	{"email": "r-polyakova-1977@postgrespro.ru", "phone": "+70386175328"}
0005433680419	9F933A	6236 599129	VALENTINA PETROVA	{"phone": "+70244714172"}
0005433680420	9F933A	9125 433378	DARYA SMIRNOVA	{"email": "darya.smirnova1971@postgrespro.ru", "phone": "+70283025510"}
0005433680421	45C505	4499 554032	YAROSLAV VLASOV	{"email": "y-vlasov.031964@postgrespro.ru", "phone": "+70204453121"}
0005433680422	76287C	9836 508506	SHAMIL SMIRNOV	{"email": "s_smirnov_111982@postgrespro.ru", "phone": "+70593155347"}
0005433680423	032FA5	9945 469233	YURIY NOVIKOV	{"email": "novikovy-1968@postgrespro.ru", "phone": "+70016738649"}
0005433680424	4B9249	2082 909374	TAMARA MAKAROVA	{"phone": "+70928699422"}
0005433680425	4B9249	4906 384842	VIKTOR NAUMOV	{"phone": "+70501302503"}
0005433680426	EE0653	7022 528101	GALIYA VASILEVA	{"email": "vasileva.g13101966@postgrespro.ru", "phone": "+70492193137"}
0005433680427	CF40B6	9921 403282	VIOLETTA SOROKINA	{"email": "sorokina-violetta.101971@postgrespro.ru", "phone": "+70489895299"}
0005433680428	C5251B	7850 271113	VIKTOR SERGEEV	{"email": "sergeev_v_061972@postgrespro.ru", "phone": "+70560031998"}
0005433680429	C5251B	6286 816606	OLGA MIKHAYLOVA	{"email": "o-mikhaylova091974@postgrespro.ru", "phone": "+70823210053"}
0005433680430	C5251B	5323 190955	DMITRIY ZAYCEV	{"phone": "+70401864998"}
0005433680431	A983D6	4313 018300	LYUDMILA EGOROVA	{"email": "egorovalyudmila-091979@postgrespro.ru", "phone": "+70782873380"}
0005433680432	76617D	3396 177011	VLADIMIR VOLKOV	{"email": "v_volkov1968@postgrespro.ru", "phone": "+70646256090"}
0005433680433	76617D	1546 755949	ANNA KOROLEVA	{"phone": "+70130123475"}
0005433680434	E2ABAE	2901 677381	ANTONINA ZAYCEVA	{"email": "antonina.zayceva27071972@postgrespro.ru", "phone": "+70457422882"}
0005433680435	90825E	9386 432132	KARIM NIKOLAEV	{"email": "karim-nikolaev.031967@postgrespro.ru", "phone": "+70148784350"}
0005433680436	147347	2830 593521	NIKOLAY ALEKSEEV	{"email": "alekseev-n15101977@postgrespro.ru", "phone": "+70301026374"}
0005433680437	A4B197	4945 759876	VITALIY MOISEEV	{"email": "moiseevvitaliy_121972@postgrespro.ru", "phone": "+70446516999"}
0005433680438	C0F4B5	6144 086374	ANASTASIYA SERGEEVA	{"phone": "+70031282161"}
0005433680439	7AAB74	7153 509638	NINA KUZNECOVA	{"email": "nina_kuznecova.1972@postgrespro.ru", "phone": "+70632888844"}
0005433680440	23CEB3	0786 358081	LYUDMILA KRASNOVA	{"phone": "+70971918164"}
0005433680441	15E841	6285 792449	OLEG CHERNOV	{"phone": "+70608903727"}
0005433680442	3151F6	8841 336962	VYACHESLAV KUZNECOV	{"phone": "+70170681251"}
0005433680443	8A9F51	1360 914353	NATALYA KUZNECOVA	{"email": "natalyakuznecova101967@postgrespro.ru", "phone": "+70837666789"}
0005433680444	AE3769	2841 906085	DMITRIY MAKAROV	{"phone": "+70242187981"}
0005433680445	AE3769	7929 317813	BORIS ANTONOV	{"phone": "+70916965117"}
0005433680446	AE3769	7130 894678	ELENA MALYSHEVA	{"email": "malysheva_e1969@postgrespro.ru", "phone": "+70376075313"}
0005433680447	241B0E	8170 858997	PAVEL ANDREEV	{"email": "andreev.pavel1975@postgrespro.ru", "phone": "+70264983002"}
0005433680448	241B0E	2422 028956	ZULFIYA FEDOROVA	{"email": "zulfiya-fedorova_1964@postgrespro.ru", "phone": "+70314077753"}
0005433680449	E8E7C1	2221 707865	NINA FROLOVA	{"email": "frolovanina-121973@postgrespro.ru", "phone": "+70897247978"}
0005433680450	E8E7C1	3392 601520	ALEKSEY KUZNECOV	{"email": "kuznecov-a.31101968@postgrespro.ru", "phone": "+70350189452"}
0005433680451	E8E7C1	7403 747320	DENIS MARTYNOV	{"email": "d_martynov_21091977@postgrespro.ru", "phone": "+70521396801"}
0005433680452	4A57A6	8617 858325	YURIY VASILEV	{"email": "vasilev-y_111970@postgrespro.ru", "phone": "+70518338243"}
0005433680453	4A57A6	1765 650638	VIKTOR SOLOVEV	{"email": "solovev_viktor071972@postgrespro.ru", "phone": "+70910322099"}
0005433680454	064633	0019 304296	GALINA LUKYANOVA	{"email": "lukyanova-g1954@postgrespro.ru", "phone": "+70865037457"}
0005433680455	9855F8	2959 675824	ALEKSANDR STEPANOV	{"phone": "+70891050952"}
0005433680456	28EFE9	6864 535685	ALEKSANDR SCHERBAKOV	{"phone": "+70507293266"}
0005433680458	29C99C	3173 850571	ANDREY KISELEV	{"phone": "+70554779202"}
0005433680459	29C99C	7807 926738	YULIYA RYABOVA	{"email": "yuliya_ryabova_06021970@postgrespro.ru", "phone": "+70248870517"}
0005433680460	10EA6E	9913 006710	ALEKSANDR MOROZOV	{"email": "morozov-a04121967@postgrespro.ru", "phone": "+70096142991"}
0005433680461	10EA6E	2410 365400	MURAT KAZAKOV	{"phone": "+70582464524"}
0005433680462	AC3402	8602 441887	YURIY ALEKSEEV	{"email": "alekseev_y_111976@postgrespro.ru", "phone": "+70510275100"}
0005433680463	77B69A	2514 052438	ANASTASIYA MEDVEDEVA	{"email": "medvedeva.a_051962@postgrespro.ru", "phone": "+70512359271"}
0005433680464	77B69A	0291 924767	ANDREY KUDRYASHOV	{"email": "andrey.kudryashov_1972@postgrespro.ru", "phone": "+70061105888"}
0005433680465	757146	8707 350198	VLADIMIR FROLOV	{"email": "vfrolov17071969@postgrespro.ru", "phone": "+70092642070"}
0005433680466	D6DFE8	9652 343398	NINA PAVLOVA	{"phone": "+70315407218"}
0005433680467	1E19BE	0151 824889	DMITRIY EGOROV	{"email": "egorov_d.1973@postgrespro.ru", "phone": "+70012470923"}
0005433680468	1E19BE	9590 352269	ZULFIYA DAVYDOVA	{"email": "davydovaz-1986@postgrespro.ru", "phone": "+70493444645"}
0005433680469	928D9E	7582 683788	TAISIYA KUZNECOVA	{"email": "kuznecova.taisiya_1979@postgrespro.ru", "phone": "+70691028437"}
0005433680470	6B0488	3089 222434	YURIY IVANOV	{"email": "ivanov-y_031972@postgrespro.ru", "phone": "+70229812223"}
0005433680471	E739CE	1992 417374	YURIY VOROBEV	{"email": "yvorobev-01031982@postgrespro.ru", "phone": "+70907381514"}
0005433680472	BA8833	6058 388638	ANASTASIYA VOROBEVA	{"email": "vorobeva-a_1960@postgrespro.ru", "phone": "+70447263186"}
0005433680473	990F4A	0259 295986	SERGEY NIKITIN	{"phone": "+70650658105"}
0005433680474	1EA6BE	9258 598430	NINA TARASOVA	{"phone": "+70219234146"}
0005433680475	1EA6BE	0677 074333	VIKTOR FILIPPOV	{"email": "viktor_filippov.091983@postgrespro.ru", "phone": "+70019819670"}
0005433680476	C9BC6C	4581 132102	SEMEN DAVYDOV	{"email": "semen_davydov.04061970@postgrespro.ru", "phone": "+70085435246"}
0005433680477	2019EF	1362 771031	EKATERINA ARKHIPOVA	{"phone": "+70045490447"}
0005433680478	F81447	1079 835748	LYUDMILA ERMAKOVA	{"email": "ermakoval-041968@postgrespro.ru", "phone": "+70299485574"}
0005433680479	59BDB1	1638 177249	NATALYA NIKITINA	{"phone": "+70118776277"}
0005433680480	59BDB1	5450 126573	VLADIMIR MEDVEDEV	{"email": "medvedev-v.05071979@postgrespro.ru", "phone": "+70892712754"}
0005433680481	EDB9D1	0407 933446	LYUDMILA TARASOVA	{"phone": "+70868387272"}
0005433680482	EDB9D1	5395 151437	SERGEY AFANASEV	{"phone": "+70456000634"}
0005433680483	506E75	5917 286293	VITALIY MATVEEV	{"email": "matveev.v061971@postgrespro.ru", "phone": "+70498047088"}
0005433680484	506E75	7921 073389	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev_1972@postgrespro.ru", "phone": "+70546783652"}
0005433680485	C7BCB1	2810 489400	ILYA CHERNOV	{"phone": "+70896859907"}
0005433680486	064BEC	0422 831408	ANNA FADEEVA	{"phone": "+70084144649"}
0005433680487	71AEE3	9951 443732	ANDREY NAZAROV	{"phone": "+70192398678"}
0005433680488	AE3743	9655 821105	ALEKSANDR KUZMIN	{"email": "a_kuzmin.1965@postgrespro.ru", "phone": "+70301404386"}
0005433680489	AE3743	7236 793228	NATALYA FROLOVA	{"email": "frolova_natalya30081974@postgrespro.ru", "phone": "+70340325030"}
0005433680490	5E822C	9177 991935	VSEVOLOD MAKAROV	{"phone": "+70752500089"}
0005433680491	5E822C	2124 515672	IGOR ANTONOV	{"phone": "+70784615192"}
0005433680492	56A202	9357 231863	ARTEM MEDVEDEV	{"phone": "+70311014785"}
0005433680493	551ECB	3861 992889	EKATERINA KUDRYASHOVA	{"email": "ekaterina.kudryashova041970@postgrespro.ru", "phone": "+70072584918"}
0005433680494	7B4CEE	9587 983740	EDUARD VOLKOV	{"phone": "+70373161656"}
0005433680495	7B4CEE	6469 183420	ILDAR ZAYCEV	{"phone": "+70976120957"}
0005433680496	6CE2D9	0471 062181	ELIZAVETA SCHERBAKOVA	{"email": "escherbakova-06081971@postgrespro.ru", "phone": "+70620753721"}
0005433680497	7C2157	3870 526321	YULIYA FADEEVA	{"email": "y_fadeeva-1972@postgrespro.ru", "phone": "+70864834719"}
0005433680498	9D4242	5948 239279	DMITRIY SIDOROV	{"phone": "+70192508746"}
0005433680499	DD195E	2180 534722	NATALYA POLYAKOVA	{"phone": "+70221978144"}
0005433680500	6E2C39	4262 724795	SVETLANA POPOVA	{"phone": "+70586111723"}
0005433680501	3472AF	4804 171476	RAMIL VOROBEV	{"phone": "+70856428613"}
0005433680502	9AC6F9	1665 281905	ALEKSANDR FROLOV	{"phone": "+70712078230"}
0005433680503	D02BDA	6460 992140	EKATERINA POPOVA	{"email": "ekaterina_popova-1969@postgrespro.ru", "phone": "+70819218927"}
0005433680504	D02BDA	6643 300642	NATALYA ALEKSANDROVA	{"phone": "+70664534675"}
0005433680505	02819D	4003 452619	NATALYA ZAYCEVA	{"phone": "+70537038617"}
0005433680506	A7E7C7	8824 300817	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev.061979@postgrespro.ru", "phone": "+70204818505"}
0005433680507	454932	2782 035858	DENIS PETROV	{"email": "petrov_d.051971@postgrespro.ru", "phone": "+70006970412"}
0005433680508	59BEB8	5830 380724	TATYANA TITOVA	{"phone": "+70746298724"}
0005433680509	013D87	3859 897098	ALEKSANDR TIKHONOV	{"email": "tikhonov-a.031968@postgrespro.ru", "phone": "+70411825476"}
0005433680510	013D87	3401 114493	SERGEY MIKHAYLOV	{"phone": "+70488602620"}
0005433680511	A18E58	0164 958729	EVGENIYA POTAPOVA	{"phone": "+70609099902"}
0005433680512	2A006C	2690 919226	OKSANA ORLOVA	{"phone": "+70305588717"}
0005433680513	8C5D7A	7439 004511	TAMARA MAKAROVA	{"email": "tamaramakarova.27011973@postgrespro.ru", "phone": "+70667655532"}
0005433680514	D6FFB2	3584 376874	VALENTIN NAUMOV	{"email": "naumov_v_1976@postgrespro.ru", "phone": "+70153097279"}
0005433680515	A33EAA	7142 271345	ALEKSEY KUZNECOV	{"phone": "+70523788345"}
0005433680516	A33EAA	9601 848719	MARIYA PETROVA	{"email": "petrovamariya04091961@postgrespro.ru", "phone": "+70026709688"}
0005433680517	924ED7	8322 499793	MARIYA GERASIMOVA	{"email": "mgerasimova-16011970@postgrespro.ru", "phone": "+70125296099"}
0005433680518	C509F4	4012 865410	TAISIYA GORBUNOVA	{"email": "gorbunova_taisiya1962@postgrespro.ru", "phone": "+70868675625"}
0005433680519	184C4B	3962 989257	ALEKSANDRA PETROVA	{"email": "aleksandra.petrova.17111965@postgrespro.ru", "phone": "+70741018223"}
0005433680520	A59912	0165 154773	IRINA TIMOFEEVA	{"email": "timofeeva.i.021977@postgrespro.ru", "phone": "+70190636303"}
0005433680521	D93A30	8993 198399	VALERIY EGOROV	{"email": "egorov.valeriy.10071971@postgrespro.ru", "phone": "+70801150645"}
0005433680522	4B18C5	8528 630657	ROMAN MOROZOV	{"phone": "+70832034123"}
0005433680523	0BE20E	6734 352069	VALENTINA GERASIMOVA	{"phone": "+70556502397"}
0005433680524	0BE20E	2285 877556	ALEKSANDR KAZAKOV	{"phone": "+70128246628"}
0005433680525	9E240A	5697 766966	RAISA KUZNECOVA	{"email": "kuznecova-raisa.121977@postgrespro.ru", "phone": "+70300521987"}
0005433680526	D08066	3780 307771	VIKTOR CHERNOV	{"email": "chernovviktor.1967@postgrespro.ru", "phone": "+70951643603"}
0005433680527	D08066	9542 486899	ROMAN POPOV	{"phone": "+70914877108"}
0005433680529	C93E50	8924 234016	VLADIMIR KAZAKOV	{"phone": "+70069922756"}
0005433680530	DDFCD4	9896 752955	VLADIMIR SOROKIN	{"phone": "+70796599226"}
0005433680531	73B1D0	4978 509242	VERA TIKHONOVA	{"email": "tikhonova_v.26121972@postgrespro.ru", "phone": "+70586890106"}
0005433680532	0674B9	4900 793056	GRIGORIY ISAEV	{"email": "isaev.grigoriy_061975@postgrespro.ru", "phone": "+70898471886"}
0005433680533	E6FAB9	8420 993190	EGOR FILIPPOV	{"email": "egor.filippov_011977@postgrespro.ru", "phone": "+70206213926"}
0005433680534	1314FB	8654 536807	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova.s-1962@postgrespro.ru", "phone": "+70942006793"}
0005433680535	11C619	2650 108288	ALEKSANDR STEPANOV	{"email": "stepanov.a1978@postgrespro.ru", "phone": "+70261262211"}
0005433680536	709414	9152 333767	ELMIRA FILIPPOVA	{"email": "filippova-elmira_02041967@postgrespro.ru", "phone": "+70542330713"}
0005433680537	709414	1365 696199	SERGEY SHEVCHENKO	{"phone": "+70829719137"}
0005433680538	0DEB33	1536 955943	SERGEY SERGEEV	{"email": "ssergeev-24061981@postgrespro.ru", "phone": "+70946960965"}
0005433680539	C5F432	3622 521246	EVGENIYA DAVYDOVA	{"phone": "+70809107798"}
0005433680540	116089	0830 535944	NIKOLAY SOLOVEV	{"phone": "+70653719587"}
0005433680541	116089	9405 630497	VLADIMIR DENISOV	{"email": "denisov.vladimir-27091969@postgrespro.ru", "phone": "+70664093271"}
0005433680542	6B3210	2548 548670	VLADIMIR NIKITIN	{"phone": "+70178458300"}
0005433680543	6B3210	6505 992857	VALERIY MOROZOV	{"phone": "+70367798891"}
0005433680544	AB8FDF	2949 581980	ANDREY SAVELEV	{"email": "savelev.a1968@postgrespro.ru", "phone": "+70554951020"}
0005433680545	CA3501	4737 790207	DMITRIY RODIONOV	{"email": "rodionovd_23041977@postgrespro.ru", "phone": "+70083178074"}
0005433680546	CA3501	0064 875308	OLGA GORBUNOVA	{"email": "olga.gorbunova.1969@postgrespro.ru", "phone": "+70921604291"}
0005433680547	21DFF5	1847 339454	ALEKSANDR MAKAROV	{"email": "a.makarov021974@postgrespro.ru", "phone": "+70869883177"}
0005433680548	5BA622	9453 641918	OLGA GAVRILOVA	{"email": "gavrilova_o_021969@postgrespro.ru", "phone": "+70559807909"}
0005433680549	5BA622	7382 636566	ALEKSEY SHEVCHENKO	{"email": "shevchenko.a-1967@postgrespro.ru", "phone": "+70415590782"}
0005433680550	5BA622	4255 939960	DMITRIY NAZAROV	{"phone": "+70991806730"}
0005433680551	04D3DE	8632 853986	MIKHAIL SCHERBAKOV	{"email": "scherbakov.mikhail_29111966@postgrespro.ru", "phone": "+70219694482"}
0005433680552	096B9C	6350 807684	SERGEY NAUMOV	{"phone": "+70365532170"}
0005433680553	096B9C	5106 662845	GALINA RYABOVA	{"phone": "+70602032325"}
0005433680554	32D581	2812 451511	POLINA BELOVA	{"phone": "+70543664660"}
0005433680555	290B65	5103 962146	MARGARITA KUZNECOVA	{"email": "m-kuznecova_021971@postgrespro.ru", "phone": "+70324707625"}
0005433680556	290B65	3401 310501	EDUARD PAVLOV	{"email": "eduard-pavlov_1974@postgrespro.ru", "phone": "+70035531542"}
0005433680557	290B65	0638 857218	RIMMA SOROKINA	{"email": "r-sorokina_1963@postgrespro.ru", "phone": "+70343907241"}
0005433680558	57B46E	0424 766683	ANTON SOKOLOV	{"email": "sokolova_071972@postgrespro.ru", "phone": "+70422045869"}
0005433680559	3C7EC1	0066 939463	EVDOKIYA ALEKSEEVA	{"phone": "+70874115625"}
0005433680560	88CA2A	5518 257944	EKATERINA KUDRYASHOVA	{"phone": "+70640373743"}
0005433680561	88CA2A	6255 889932	ELENA EGOROVA	{"email": "egorova-elena28011970@postgrespro.ru", "phone": "+70092929302"}
0005433680562	328A33	8914 997923	LYUDMILA ROMANOVA	{"phone": "+70958005943"}
0005433680563	011776	5297 918699	VITALIY POPOV	{"phone": "+70025165867"}
0005433680564	5521F7	1271 674517	VIKTOR SHEVCHENKO	{"email": "shevchenko.v1966@postgrespro.ru", "phone": "+70963014981"}
0005433680565	10D41F	8377 336237	ALEKSEY NIKOLAEV	{"phone": "+70409906133"}
0005433680566	37C692	3749 732648	VASILIY GORBUNOV	{"email": "v-gorbunov.04021953@postgrespro.ru", "phone": "+70219791099"}
0005433680567	64A7F9	5980 969681	MAKSIM VASILEV	{"phone": "+70051537476"}
0005433680568	64A7F9	0709 780068	ILYA MOROZOV	{"email": "i_morozov_1964@postgrespro.ru", "phone": "+70049339677"}
0005433680569	E6EDD9	9237 731284	NADEZHDA MAKAROVA	{"phone": "+70796898786"}
0005433680570	E6EDD9	9077 831333	DAMIR VOLKOV	{"phone": "+70128775602"}
0005433680571	8FC864	8970 230549	SVETLANA ZHURAVLEVA	{"phone": "+70984304448"}
0005433680572	D22AA3	8032 160923	ARKADIY SOLOVEV	{"email": "solovev.a.1968@postgrespro.ru", "phone": "+70370782242"}
0005433680573	D22AA3	6772 032541	EGOR FROLOV	{"phone": "+70778303051"}
0005433680574	25CF76	3657 459404	SERGEY GAVRILOV	{"email": "sergeygavrilov_1963@postgrespro.ru", "phone": "+70811501775"}
0005433680575	DB4FC4	0420 827216	SERGEY GAVRILOV	{"email": "sergey_gavrilov_1965@postgrespro.ru", "phone": "+70950544235"}
0005433680576	BAE3CA	2150 269822	VIKTOR SCHERBAKOV	{"email": "vscherbakov_101980@postgrespro.ru", "phone": "+70903196616"}
0005433680577	4C466C	1117 553736	ANNA MASLOVA	{"phone": "+70514743526"}
0005433680578	813BD6	8333 194230	VYACHESLAV ROMANOV	{"phone": "+70538386498"}
0005433680579	813BD6	0435 054645	RUSLAN MIRONOV	{"phone": "+70445122040"}
0005433680580	6366A8	2511 959673	NADEZHDA BORISOVA	{"email": "borisova-nadezhda1980@postgrespro.ru", "phone": "+70655418784"}
0005433680581	6366A8	8965 064494	IGOR KOZLOV	{"phone": "+70699727318"}
0005433680582	D53E14	2216 315661	MARIYA NIKIFOROVA	{"email": "nikiforovamariya18061970@postgrespro.ru", "phone": "+70139547555"}
0005433680583	43F32A	5837 799483	SERGEY MOROZOV	{"phone": "+70208556310"}
0005433680584	E0BB9E	6684 021532	ALEKSANDRA MELNIKOVA	{"phone": "+70556723248"}
0005433680585	4B4542	4428 520680	ELENA DMITRIEVA	{"phone": "+70598451046"}
0005433680586	4B4542	1746 188387	LYUBOV KONOVALOVA	{"phone": "+70029449074"}
0005433680587	0A4B0C	9017 502109	VITALIY PETROV	{"email": "petrov-v-091972@postgrespro.ru", "phone": "+70248993463"}
0005433680588	0DEF50	5172 271294	ANATOLIY TIKHONOV	{"phone": "+70100525890"}
0005433680589	5E1D43	8091 246075	ALEVTINA DAVYDOVA	{"email": "alevtina_davydova_30081971@postgrespro.ru", "phone": "+70677377406"}
0005433680590	405999	7664 481051	ZARINA KONOVALOVA	{"email": "konovalovaz-011970@postgrespro.ru", "phone": "+70138379669"}
0005433680591	405999	5323 079015	VIKTOR BORISOV	{"phone": "+70480019924"}
0005433680592	5F80CF	1483 514403	ALEKSEY TARASOV	{"email": "tarasov-aleksey.08101971@postgrespro.ru", "phone": "+70035553533"}
0005433680593	985898	5617 721567	VIKTORIYA RYABOVA	{"phone": "+70050074240"}
0005433680594	26797B	2636 195359	ANDREY KONOVALOV	{"email": "konovalovandrey-25071961@postgrespro.ru", "phone": "+70292669338"}
0005433680595	26797B	1780 806880	NIKOLAY IVANOV	{"email": "nikolay-ivanov-18041968@postgrespro.ru", "phone": "+70750208263"}
0005433680596	55F6C4	2207 978868	VLADIMIR ROMANOV	{"email": "vladimir_romanov_13081979@postgrespro.ru", "phone": "+70757454408"}
0005433680597	55F6C4	4051 666216	IRINA DANILOVA	{"email": "danilova.irina041972@postgrespro.ru", "phone": "+70297360057"}
0005433680598	F891E5	6249 884495	YURIY STEPANOV	{"phone": "+70596967952"}
0005433680599	F891E5	3214 715581	MARINA MEDVEDEVA	{"phone": "+70229618640"}
0005433680600	3C0839	2779 480581	TATYANA NIKITINA	{"phone": "+70890321467"}
0005433680601	3C0839	5541 540030	LARISA PAVLOVA	{"email": "pavlova.l.30101977@postgrespro.ru", "phone": "+70918241342"}
0005433680602	DE9FA1	7066 149191	ANNA ROMANOVA	{"email": "romanova-anna.091985@postgrespro.ru", "phone": "+70790583536"}
0005433680603	DE9FA1	9039 310525	AZAT MOROZOV	{"phone": "+70332327563"}
0005433680604	DE42FF	0966 389403	EKATERINA KUZMINA	{"email": "ekuzmina_22081972@postgrespro.ru", "phone": "+70344841654"}
0005433680605	23EDF0	9309 466723	NIKITA SHEVCHENKO	{"email": "shevchenko.n091962@postgrespro.ru", "phone": "+70883383626"}
0005433680606	0D578C	9281 921146	RAISA MAKSIMOVA	{"email": "maksimova-raisa_19071976@postgrespro.ru", "phone": "+70825468281"}
0005433680607	0D578C	5323 601714	VITALIY SAVELEV	{"phone": "+70671202075"}
0005433680608	3A3F7D	7485 610035	EKATERINA KOZLOVA	{"email": "kozlova-ekaterina.1975@postgrespro.ru", "phone": "+70494826411"}
0005433680609	A6BFBA	9395 046738	ILMIRA KUZNECOVA	{"email": "ikuznecova.051979@postgrespro.ru", "phone": "+70516706570"}
0005433680610	A6BFBA	2853 537922	ANNA BELYAEVA	{"email": "belyaevaa_051962@postgrespro.ru", "phone": "+70102053607"}
0005433680611	858EC1	9986 209937	TAMARA VASILEVA	{"phone": "+70491817047"}
0005433680612	46A782	4335 307088	GENNADIY BARANOV	{"email": "gbaranov-25071981@postgrespro.ru", "phone": "+70812645051"}
0005433680613	AE8E68	1189 218783	ARTEMIY SAVELEV	{"email": "artemiy_savelev-16071973@postgrespro.ru", "phone": "+70776313627"}
0005433680614	35BC8A	2341 923466	EVGENIY KUZNECOV	{"email": "e-kuznecov_1971@postgrespro.ru", "phone": "+70139731431"}
0005433680615	9A1B7F	4268 910147	VALENTINA MOISEEVA	{"phone": "+70008414477"}
0005433680616	DB61BA	4111 325285	RINAT MAKSIMOV	{"phone": "+70455095000"}
0005433680617	A62C6B	3010 832943	LYUDMILA VOROBEVA	{"phone": "+70522167851"}
0005433680618	A62C6B	9257 879499	FARIDA FADEEVA	{"phone": "+70450167710"}
0005433680619	33EB47	5862 637019	ANDREY ALEKSANDROV	{"email": "a_aleksandrov.18041962@postgrespro.ru", "phone": "+70220149296"}
0005433680620	A80D37	3741 818539	YURIY NAUMOV	{"phone": "+70571303668"}
0005433680621	A80D37	1682 018060	YULIYA TIMOFEEVA	{"phone": "+70081355171"}
0005433680622	A80D37	8561 849918	SERGEY PETROV	{"phone": "+70054665158"}
0005433680623	D26BEA	6470 689718	ZINAIDA YAKOVLEVA	{"phone": "+70317415210"}
0005433680624	A05811	6679 150278	ALEKSANDR ZAYCEV	{"phone": "+70980464209"}
0005433680625	C3DC04	6929 045592	ARINA KARPOVA	{"phone": "+70181229022"}
0005433680626	EEFE59	1257 918320	VIKTOR DENISOV	{"email": "v-denisov06111972@postgrespro.ru", "phone": "+70351693908"}
0005433680627	7FE4B4	5280 032850	PAVEL FILIPPOV	{"phone": "+70905036244"}
0005433680628	7FE4B4	5335 570055	ASIYA KOMAROVA	{"email": "a_komarova04061973@postgrespro.ru", "phone": "+70136394371"}
0005433680629	87D39F	5563 919219	DENIS GUSEV	{"phone": "+70580874114"}
0005433680630	319827	4042 682972	PRASKOVYA ZHUKOVA	{"email": "zhukova_p1972@postgrespro.ru", "phone": "+70040471634"}
0005433680631	319827	6660 938747	ANNA KAZAKOVA	{"email": "kazakova_a.121976@postgrespro.ru", "phone": "+70650850104"}
0005433680632	D00E9C	8640 486045	RUSTAM PAVLOV	{"email": "pavlov.r.081981@postgrespro.ru", "phone": "+70080964964"}
0005433680633	85817D	2975 851991	IGOR KISELEV	{"email": "kiselev_i.061983@postgrespro.ru", "phone": "+70189787270"}
0005433680634	85817D	3470 509136	ALEKSANDR MAKAROV	{"email": "makarov.a_09091967@postgrespro.ru", "phone": "+70728181632"}
0005433680635	7F04D3	7459 241453	ELENA MAKAROVA	{"email": "makarova_e-20071965@postgrespro.ru", "phone": "+70321796396"}
0005433680636	7F04D3	6171 608830	ELENA SEMENOVA	{"email": "elena_semenova.061970@postgrespro.ru", "phone": "+70266339694"}
0005433680637	676ECD	0491 745845	TATYANA SEMENOVA	{"phone": "+70607020436"}
0005433680638	7C9D42	6121 404918	IGOR MOROZOV	{"phone": "+70607255844"}
0005433680639	D649E9	6401 315068	ALI SOROKIN	{"email": "sorokin-a.071970@postgrespro.ru", "phone": "+70773664691"}
0005433680640	8F62A5	0087 231959	KRISTINA NIKITINA	{"email": "k.nikitina19021972@postgrespro.ru", "phone": "+70529011804"}
0005433680641	8F62A5	6967 621398	OLGA ABRAMOVA	{"email": "olga_abramova_03111979@postgrespro.ru", "phone": "+70986100760"}
0005433680642	8F62A5	8483 144957	OLEG FEDOROV	{"phone": "+70633502906"}
0005433680643	B0EC70	8273 454494	VLADIMIR IVANOV	{"phone": "+70122624425"}
0005433680644	17AFFD	7865 287241	MAKSIM GUSEV	{"email": "gusev-maksim_1969@postgrespro.ru", "phone": "+70610261671"}
0005433680645	D23FC3	9595 527609	ANDREY POPOV	{"email": "a.popov-1979@postgrespro.ru", "phone": "+70722807921"}
0005433680646	D23FC3	3324 635376	EVGENIY MOISEEV	{"email": "e-moiseev_05031978@postgrespro.ru", "phone": "+70603206985"}
0005433680647	D23FC3	4494 431540	EKATERINA POPOVA	{"email": "ekaterina-popova-1970@postgrespro.ru", "phone": "+70364431267"}
0005433680648	33F688	3199 140000	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr.18031971@postgrespro.ru", "phone": "+70805693446"}
0005433680649	22C431	3490 748819	DANIIL POPOV	{"email": "daniil-popov-11101973@postgrespro.ru", "phone": "+70355529987"}
0005433680650	CB4743	1438 046954	MARINA TROFIMOVA	{"phone": "+70846460789"}
0005433680651	5C9558	0226 857360	EVGENIY MELNIKOV	{"phone": "+70947240109"}
0005433680652	5C9558	8298 189524	BOGDAN DMITRIEV	{"phone": "+70888965625"}
0005433680653	0AD47B	7349 362187	RAISA BOGDANOVA	{"email": "bogdanovaraisa.1966@postgrespro.ru", "phone": "+70358654417"}
0005433680654	6B4340	2441 482954	ANATOLIY KISELEV	{"phone": "+70083589760"}
0005433680655	C789C3	3688 197367	LYUBOV FOMINA	{"email": "fominalyubov-13041965@postgrespro.ru", "phone": "+70899136809"}
0005433680656	1BDBDC	3849 402272	ALEKSEY NOVIKOV	{"phone": "+70608705008"}
0005433680657	1BDBDC	2851 298292	SERGEY IVANOV	{"phone": "+70869791361"}
0005433680658	4D23B9	9373 341002	TATYANA VOROBEVA	{"email": "t-vorobeva011974@postgrespro.ru", "phone": "+70365356046"}
0005433680659	4D23B9	0908 149402	LIDIYA SOKOLOVA	{"phone": "+70529032456"}
0005433680660	A94FF3	5066 321031	MAKSIM KULIKOV	{"email": "kulikov_maksim_1984@postgrespro.ru", "phone": "+70069725275"}
0005433680661	E0C6FC	9153 076465	OLESYA SOKOLOVA	{"phone": "+70473639972"}
0005433680662	E0C6FC	8753 666134	MARIYA KISELEVA	{"phone": "+70345515573"}
0005433680663	EA91E2	1082 014690	MARIYA VOROBEVA	{"email": "m_vorobeva.1973@postgrespro.ru", "phone": "+70332837900"}
0005433680664	774EFC	5570 196146	TAMARA TARASOVA	{"email": "tamara_tarasova_1975@postgrespro.ru", "phone": "+70915090508"}
0005433680665	774EFC	5219 017812	TATYANA TARASOVA	{"phone": "+70450507978"}
0005433680666	860F11	4420 823986	NIKOLAY KOROLEV	{"phone": "+70310342360"}
0005433680667	B9E2E5	8354 679447	SVETLANA NIKITINA	{"email": "s-nikitina-081971@postgrespro.ru", "phone": "+70108941334"}
0005433680668	B9E2E5	8619 545857	SVETLANA NESTEROVA	{"email": "s_nesterova-101973@postgrespro.ru", "phone": "+70385687608"}
0005433680669	DA12E1	3537 872587	EKATERINA LOGINOVA	{"email": "loginova.ekaterina.1969@postgrespro.ru", "phone": "+70420202952"}
0005433680670	ADB143	5385 853710	NELLI SOKOLOVA	{"phone": "+70768461566"}
0005433680671	ADB143	9505 113767	VLADISLAV SEMENOV	{"phone": "+70086658168"}
0005433680672	B49ED8	0954 159338	DARYA ERMAKOVA	{"phone": "+70004911797"}
0005433680673	2005A6	8204 279593	VYACHESLAV IVANOV	{"email": "ivanovv.051970@postgrespro.ru", "phone": "+70448452732"}
0005433680674	4A6D85	1259 944021	VALERIY KOZLOV	{"email": "kozlov.valeriy1974@postgrespro.ru", "phone": "+70535584566"}
0005433680675	D2F443	1100 097817	EKATERINA ZHUKOVA	{"phone": "+70279325811"}
0005433680676	D2F443	7975 883481	YULIANA KOMAROVA	{"email": "komarova-y1983@postgrespro.ru", "phone": "+70882085193"}
0005433680677	C9314B	0680 720172	OKSANA POTAPOVA	{"email": "potapova.oksana041979@postgrespro.ru", "phone": "+70401360413"}
0005433680678	ED29A2	1308 075133	NATALYA POPOVA	{"email": "popova-n-08081974@postgrespro.ru", "phone": "+70276659635"}
0005433680679	04D9AC	1675 393415	GALINA KALININA	{"email": "galina.kalinina12021976@postgrespro.ru", "phone": "+70320420872"}
0005433680680	563C1B	5672 137393	LILIYA PETROVA	{"email": "liliya_petrova-1971@postgrespro.ru", "phone": "+70004006612"}
0005433680681	A65546	0848 680643	SVETLANA LOGINOVA	{"phone": "+70510253886"}
0005433680682	BCFF3B	9506 398692	MARIYA EGOROVA	{"phone": "+70314621186"}
0005433680683	3FCF1A	3890 590135	IVAN ALEKSEEV	{"phone": "+70465360118"}
0005433680684	3FCF1A	8003 156647	LYUDMILA VOLKOVA	{"phone": "+70070756935"}
0005433680685	68A3ED	0727 008526	LYUBOV ALEKSEEVA	{"email": "l-alekseeva.101967@postgrespro.ru", "phone": "+70056786700"}
0005433680686	8022B0	7704 463944	IVAN KUZMIN	{"email": "kuzmin_ivan1967@postgrespro.ru", "phone": "+70434954757"}
0005433680687	080DB5	6077 379485	EGOR KUZNECOV	{"phone": "+70301787985"}
0005433680688	741722	7865 143442	ZINAIDA NIKITINA	{"email": "nikitina.zinaida.1988@postgrespro.ru", "phone": "+70321929903"}
0005433680689	52AF59	7083 966576	VYACHESLAV SHEVCHENKO	{"phone": "+70271848782"}
0005433680690	2BC580	6902 719779	OKSANA SERGEEVA	{"phone": "+70679302144"}
0005433680691	2BC580	7691 001062	NATALIYA MARTYNOVA	{"phone": "+70896400932"}
0005433680692	3D36C6	6263 947415	OLGA SERGEEVA	{"phone": "+70645424827"}
0005433680693	3D36C6	6140 871163	LYUBOV SOLOVEVA	{"phone": "+70824531724"}
0005433680694	3D36C6	6424 805383	IVAN ZAKHAROV	{"email": "zakharov-ivan25031968@postgrespro.ru", "phone": "+70643047907"}
0005433680695	9368C2	3321 012703	TAMARA IVANOVA	{"email": "t-ivanova.1967@postgrespro.ru", "phone": "+70773871201"}
0005433680696	9368C2	6204 111123	ALEKSANDR PAVLOV	{"email": "pavlov-a_121973@postgrespro.ru", "phone": "+70116176624"}
0005433680697	8267D9	3076 173270	SERGEY KUZNECOV	{"email": "kuznecov-s_1985@postgrespro.ru", "phone": "+70846463829"}
0005433680698	B7CFEC	3374 095187	VIKTOR VOLKOV	{"email": "viktorvolkov03111966@postgrespro.ru", "phone": "+70476115377"}
0005433680699	D1F38D	1482 812986	VIKTOR FROLOV	{"phone": "+70851686400"}
0005433680700	D1F38D	4352 246534	EKATERINA KUZNECOVA	{"email": "e_kuznecova061988@postgrespro.ru", "phone": "+70632133333"}
0005433680701	7BE7C6	9957 129284	SERGEY SMIRNOV	{"email": "smirnovs031963@postgrespro.ru", "phone": "+70447156672"}
0005433680702	CF1EE4	2294 493374	TATYANA TITOVA	{"phone": "+70056226344"}
0005433680703	C674C2	8042 078903	IGOR ZAYCEV	{"email": "igor_zaycev27021968@postgrespro.ru", "phone": "+70471837881"}
0005433680704	0DD828	3956 534344	VALERIY MAKAROV	{"email": "v.makarov_03111962@postgrespro.ru", "phone": "+70432194153"}
0005433680705	E6CEF8	9235 445902	ANNA MOROZOVA	{"email": "morozova_anna-061976@postgrespro.ru", "phone": "+70640080055"}
0005433680706	E6CEF8	8813 486417	YULIYA SAVELEVA	{"phone": "+70277656216"}
0005433680707	6CE254	5521 980137	ANDREY MARTYNOV	{"email": "amartynov_29071959@postgrespro.ru", "phone": "+70246693455"}
0005433680708	6CE254	4415 324041	FEDOR ZAYCEV	{"email": "zaycev.f-1976@postgrespro.ru", "phone": "+70265753226"}
0005433680709	11FF63	9276 683794	IVAN KUZNECOV	{"phone": "+70379730734"}
0005433680710	11FF63	1999 972678	SVETLANA FILATOVA	{"phone": "+70442699363"}
0005433680711	91534C	8727 551300	ALEKSEY GERASIMOV	{"email": "gerasimovaleksey1981@postgrespro.ru", "phone": "+70464313620"}
0005433680712	91534C	5062 698072	GENNADIY SCHERBAKOV	{"phone": "+70423387153"}
0005433680713	1FD5B0	5516 465688	ELENA BELYAEVA	{"email": "belyaeva_e_13071983@postgrespro.ru", "phone": "+70030959394"}
0005433680714	784368	2449 548220	NATALYA MOROZOVA	{"email": "morozovan.20111977@postgrespro.ru", "phone": "+70851303757"}
0005433680715	784368	6667 585265	EKATERINA NIKITINA	{"phone": "+70522682436"}
0005433680716	4325C5	4869 977693	VLADISLAV PAVLOV	{"email": "vladislav-pavlov-021973@postgrespro.ru", "phone": "+70557442048"}
0005433680717	5E305F	5244 449015	LIDIYA NIKOLAEVA	{"email": "l_nikolaeva.1975@postgrespro.ru", "phone": "+70023352372"}
0005433680718	5E305F	1587 882970	ARKADIY ANTONOV	{"phone": "+70395895187"}
0005433680719	49B656	7740 927497	LYUBOV ZAYCEVA	{"email": "lyubov-zayceva.041970@postgrespro.ru", "phone": "+70776961092"}
0005433680720	D5C18F	4338 519793	DARYA MARTYNOVA	{"email": "martynovadarya_1970@postgrespro.ru", "phone": "+70934206380"}
0005433680721	6EFE12	7587 260917	LINAR SCHERBAKOV	{"email": "linarscherbakov.091976@postgrespro.ru", "phone": "+70487773743"}
0005433680722	6EFE12	9643 895614	NADEZHDA DENISOVA	{"email": "nadezhdadenisova_10101977@postgrespro.ru", "phone": "+70463769872"}
0005433680723	D91E5B	8576 274394	ANNA EFIMOVA	{"phone": "+70510056644"}
0005433680724	DB84CF	4596 342394	ANTONINA BOGDANOVA	{"email": "bogdanovaantonina_1970@postgrespro.ru", "phone": "+70062844282"}
0005433680725	5A0D87	2131 423983	ZINAIDA KUZNECOVA	{"email": "kuznecovazinaida.081970@postgrespro.ru", "phone": "+70864379312"}
0005433680726	B88DE4	2422 754621	RUSLAN ALEKSEEV	{"email": "alekseevr.1969@postgrespro.ru", "phone": "+70750856795"}
0005433680727	87FFE5	1304 088388	DENIS KUZMIN	{"email": "deniskuzmin.1976@postgrespro.ru", "phone": "+70871102593"}
0005433680728	C08D52	5890 333651	VLADIMIR SOROKIN	{"phone": "+70095212926"}
0005433680729	C08D52	4297 757688	VALERIY POPOV	{"email": "popov_valeriy.04061965@postgrespro.ru", "phone": "+70826279504"}
0005433680730	F716F1	5867 097818	EVGENIY SOKOLOV	{"phone": "+70570278501"}
0005433680731	F716F1	0442 688913	ALEKSANDR KISELEV	{"email": "aleksandr_kiselev_071967@postgrespro.ru", "phone": "+70068409254"}
0005433680732	C495BB	2385 586849	ANNA ORLOVA	{"phone": "+70776533024"}
0005433680733	5AFB91	6349 500622	LIDIYA ALEKSANDROVA	{"email": "aleksandrova-l-1969@postgrespro.ru", "phone": "+70822410212"}
0005433680734	5AFB91	2871 442931	ALEKSEY VLASOV	{"phone": "+70363314300"}
0005433680735	89C82E	9684 882372	NATALYA SEMENOVA	{"email": "semenova_natalya.23111974@postgrespro.ru", "phone": "+70675515732"}
0005433680736	4F1B5A	6263 723329	OLGA ORLOVA	{"phone": "+70432027241"}
0005433680737	4F1B5A	6717 637468	ALEKSANDR BONDARENKO	{"email": "bondarenko_a-1983@postgrespro.ru", "phone": "+70666475099"}
0005433680738	3F8E7F	8772 360543	VIKTORIYA ZHUKOVA	{"email": "zhukova-v031977@postgrespro.ru", "phone": "+70052250417"}
0005433680739	3F8E7F	0775 418747	TATYANA MAKSIMOVA	{"email": "t.maksimova-1975@postgrespro.ru", "phone": "+70886144378"}
0005433680740	9E9A19	0844 335506	ANNA PETROVA	{"phone": "+70535851680"}
0005433680741	CADC0D	2838 235298	EVGENIY DMITRIEV	{"phone": "+70629652153"}
0005433680742	B0EF9A	7512 011339	IRINA ILINA	{"email": "ilina_i1977@postgrespro.ru", "phone": "+70977868419"}
0005433680743	B0EF9A	9939 953725	NAILYA KISELEVA	{"email": "kiselevan101976@postgrespro.ru", "phone": "+70984396946"}
0005433680744	4801A8	8196 399958	VITALIY PAVLOV	{"email": "vitaliy_pavlov011966@postgrespro.ru", "phone": "+70439833383"}
0005433680745	C453E2	2352 276585	NATALYA SOLOVEVA	{"phone": "+70850341352"}
0005433680746	A8BD0C	2741 117123	OLGA VLASOVA	{"email": "o_vlasova-031984@postgrespro.ru", "phone": "+70293022993"}
0005433680747	003272	0732 068755	NATALYA KOZLOVA	{"email": "kozlova.n.021966@postgrespro.ru", "phone": "+70945980898"}
0005433680748	003272	9362 819662	MARIYA FEDOROVA	{"phone": "+70548806868"}
0005433680749	724283	3806 293456	NINA SOROKINA	{"phone": "+70507245288"}
0005433680750	724283	9131 992439	NIKOLAY PAVLOV	{"email": "nikolay_pavlov-041965@postgrespro.ru", "phone": "+70228501616"}
0005433680751	8E7014	7032 039260	OLGA ZHURAVLEVA	{"phone": "+70448380931"}
0005433680752	808793	7805 682127	STANISLAV DMITRIEV	{"email": "sdmitriev-121968@postgrespro.ru", "phone": "+70008290422"}
0005433680753	42AFF1	7608 290587	LEONID TARASOV	{"email": "l.tarasov.08081976@postgrespro.ru", "phone": "+70085584115"}
0005433680754	42AFF1	8867 531322	MARIYA MOISEEVA	{"email": "moiseeva.mariya-1979@postgrespro.ru", "phone": "+70043746724"}
0005433680755	831326	6364 338396	TATYANA MIKHAYLOVA	{"phone": "+70603330870"}
0005433680756	BD7695	9034 524575	NINA MATVEEVA	{"email": "matveeva.nina.1978@postgrespro.ru", "phone": "+70316774899"}
0005433680757	3D7E43	1162 435155	IVAN GRIGOREV	{"phone": "+70128163398"}
0005433680758	C1AD4B	4896 772387	ANASTASIYA KONOVALOVA	{"phone": "+70657288637"}
0005433680759	45BCFB	0282 847168	ALEKSEY FEDOROV	{"email": "aleksey-fedorov.02101966@postgrespro.ru", "phone": "+70599805677"}
0005433680760	5C5FF2	7319 075673	LIDIYA ROMANOVA	{"email": "romanova.lidiya.051971@postgrespro.ru", "phone": "+70970815762"}
0005433680761	5C5FF2	6643 283893	OKSANA ROMANOVA	{"email": "oksanaromanova_04101972@postgrespro.ru", "phone": "+70314735887"}
0005433680762	620773	0489 577256	VYACHESLAV KULIKOV	{"phone": "+70374031928"}
0005433680763	35C5D9	5948 772252	EKATERINA KOROLEVA	{"email": "e_koroleva031970@postgrespro.ru", "phone": "+70075744462"}
0005433680764	35C5D9	7403 809164	MARFA KISELEVA	{"email": "kiseleva.marfa.19121964@postgrespro.ru", "phone": "+70403256170"}
0005433680765	596EE4	3652 162480	IVAN MIKHAYLOV	{"phone": "+70270205527"}
0005433680766	1CB3D2	0643 836361	IGOR SCHERBAKOV	{"email": "scherbakovi-051979@postgrespro.ru", "phone": "+70464241834"}
0005433680767	1CB3D2	1856 291498	IRINA ANDREEVA	{"email": "irina-andreeva.02061975@postgrespro.ru", "phone": "+70693567801"}
0005433680768	56DE4C	7999 877582	EGOR DAVYDOV	{"phone": "+70815893595"}
0005433680769	56DE4C	7220 078931	ALEKSANDRA KALININA	{"email": "kalinina.a-15051956@postgrespro.ru", "phone": "+70897183817"}
0005433680770	BFD1A6	2309 939071	ANTON ISAEV	{"email": "anton_isaev-03011962@postgrespro.ru", "phone": "+70182865429"}
0005433680771	BFD1A6	0246 651666	IVAN KRASNOV	{"phone": "+70923224957"}
0005433680772	650E6A	6749 973479	KLAVDIYA SEMENOVA	{"phone": "+70244918234"}
0005433680773	8909AA	8490 342738	GEORGIY ORLOV	{"email": "georgiy.orlov-1965@postgrespro.ru", "phone": "+70346816534"}
0005433680774	022ACE	0912 094688	MIKHAIL KUZNECOV	{"phone": "+70918544009"}
0005433680775	541E34	4862 570497	LILIYA TIKHONOVA	{"phone": "+70470619241"}
0005433680776	5C70AB	2747 707760	DENIS POPOV	{"phone": "+70513815190"}
0005433680777	5C70AB	2326 106592	ANNA KUDRYASHOVA	{"email": "a_kudryashova_1976@postgrespro.ru", "phone": "+70126296211"}
0005433680778	C30D49	3548 925284	ALEKSANDR KUZNECOV	{"phone": "+70171551669"}
0005433680779	C30D49	3710 875133	EVGENIY MEDVEDEV	{"email": "e.medvedev1986@postgrespro.ru", "phone": "+70601088844"}
0005433680780	C30D49	5728 161859	ALEKSANDR GERASIMOV	{"phone": "+70393894534"}
0005433680781	0DB886	7038 736323	SERGEY KONOVALOV	{"phone": "+70941163544"}
0005433680782	0DB886	2161 677507	VITALIY AFANASEV	{"email": "vitaliy-afanasev19111969@postgrespro.ru", "phone": "+70407328365"}
0005433680783	8CD987	9007 662968	ANDREY SERGEEV	{"email": "a_sergeev_101972@postgrespro.ru", "phone": "+70130803829"}
0005433680784	E74D5D	5357 151121	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov071971@postgrespro.ru", "phone": "+70671185146"}
0005433680785	E74D5D	9257 537994	IVAN KONOVALOV	{"email": "konovalov-i.051959@postgrespro.ru", "phone": "+70593134849"}
0005433680786	1A5777	5805 153602	IBRAGIM BELOV	{"phone": "+70616843283"}
0005433680787	C0287C	7306 937481	ALEKSEY KULIKOV	{"email": "akulikov-021978@postgrespro.ru", "phone": "+70672341742"}
0005433680788	C0287C	6439 621215	SERGEY FEDOTOV	{"email": "fedotov.s-26011974@postgrespro.ru", "phone": "+70932915149"}
0005433680789	C0287C	1186 017566	NIKOLAY MATVEEV	{"phone": "+70184093843"}
0005433680790	5F9AE9	6153 768785	VALERIY TIKHONOV	{"email": "valeriy-tikhonov_08051969@postgrespro.ru", "phone": "+70836470522"}
0005433680791	5F9AE9	5528 972838	EVGENIY MOISEEV	{"phone": "+70018933661"}
0005433680792	FC8FF0	5635 409556	SERGEY MATVEEV	{"email": "sergey.matveev_1968@postgrespro.ru", "phone": "+70438344168"}
0005433680793	FC8FF0	2759 583967	KARINA MOROZOVA	{"phone": "+70538341166"}
0005433680794	A94BA2	7233 166009	VLADIMIR MAKAROV	{"email": "makarov_v111963@postgrespro.ru", "phone": "+70987228308"}
0005433680795	09AB6E	0662 793409	OLGA KUZNECOVA	{"phone": "+70335582783"}
0005433680796	FD862F	0517 120458	INNA POPOVA	{"email": "i.popova.1967@postgrespro.ru", "phone": "+70292548344"}
0005433680797	FD862F	0954 563628	NIKOLAY KONOVALOV	{"email": "konovalov-nikolay-20051965@postgrespro.ru", "phone": "+70608143591"}
0005433680798	D867C7	1212 776157	ILYA KUDRYASHOV	{"phone": "+70772442882"}
0005433680799	BA2B72	8162 988827	VIKTOR DAVYDOV	{"phone": "+70015046405"}
0005433680800	BA2B72	0889 222544	VALERIYA EGOROVA	{"email": "egorova_v101967@postgrespro.ru", "phone": "+70780634739"}
0005433680801	8A6747	6469 171019	TATYANA NAUMOVA	{"email": "tatyana.naumova-25081974@postgrespro.ru", "phone": "+70797572057"}
0005433680802	8A6747	4450 152366	EKATERINA VOROBEVA	{"email": "ekaterina_vorobeva1972@postgrespro.ru", "phone": "+70062875813"}
0005433680803	217FCD	7994 450835	LEONID SOLOVEV	{"email": "solovevleonid.1967@postgrespro.ru", "phone": "+70808882128"}
0005433680804	D46F9B	4785 994784	LYUBOV MARTYNOVA	{"email": "lyubov.martynova-121971@postgrespro.ru", "phone": "+70544115171"}
0005433680805	47973F	0093 039875	ELENA POLYAKOVA	{"phone": "+70247154684"}
0005433680806	47973F	5742 824679	NIKOLAY AFANASEV	{"phone": "+70638402763"}
0005433680807	47973F	5383 266291	LYUDMILA ORLOVA	{"phone": "+70160603394"}
0005433680808	6F9B9C	7448 106578	SVETLANA BORISOVA	{"email": "borisova_svetlana.26011980@postgrespro.ru", "phone": "+70947006709"}
0005433680809	46D8BD	0663 162522	SVETLANA ANDREEVA	{"phone": "+70776704322"}
0005433680810	198E3B	0589 818399	ELENA SOROKINA	{"email": "sorokinae_30091967@postgrespro.ru", "phone": "+70594667736"}
0005433680811	B3109C	1093 675817	VIKTOR ISAEV	{"phone": "+70286228685"}
0005433680812	CA939A	9442 478435	ALEKSANDR FEDOROV	{"phone": "+70192972400"}
0005433680813	CA939A	6491 677463	DMITRIY PETROV	{"phone": "+70813616748"}
0005433680814	D743E9	4407 016755	DENIS PAVLOV	{"email": "pavlovd-06061966@postgrespro.ru", "phone": "+70905429847"}
0005433680815	158B3D	4748 979955	LARISA KULIKOVA	{"email": "kulikova-larisa_08081962@postgrespro.ru", "phone": "+70317715280"}
0005433680816	158B3D	3266 040183	OLEG KOZLOV	{"email": "kozlov_oleg1960@postgrespro.ru", "phone": "+70592452042"}
0005433680817	A9FEF9	5105 316746	MARGARITA MOROZOVA	{"email": "m_morozova_1970@postgrespro.ru", "phone": "+70844245582"}
0005433680818	A9FEF9	7951 335271	NINA SIDOROVA	{"phone": "+70000603046"}
0005433680819	50DA3D	6848 717799	MARIYA ZAKHAROVA	{"email": "zakharova-mariya.1967@postgrespro.ru", "phone": "+70293436830"}
0005433680820	FD4EB1	9020 948876	YURIY ZHUKOV	{"email": "yuriyzhukov071972@postgrespro.ru", "phone": "+70615258904"}
0005433680821	480F1C	3666 730599	VLADIMIR STEPANOV	{"phone": "+70874468491"}
0005433680822	480F1C	3662 116854	NATALYA NIKOLAEVA	{"email": "natalya_nikolaeva-13091959@postgrespro.ru", "phone": "+70518192136"}
0005433680823	2056B6	8576 969639	ALEKSANDR SOROKIN	{"email": "a_sorokin_1987@postgrespro.ru", "phone": "+70438715317"}
0005433680824	A55329	9959 216880	IRINA NESTEROVA	{"email": "nesterova.irina_1965@postgrespro.ru", "phone": "+70851727368"}
0005433680825	5990A4	3524 759073	VIKTORIYA DAVYDOVA	{"phone": "+70906451985"}
0005433680826	5990A4	5009 078770	EVDOKIYA LUKYANOVA	{"email": "lukyanova.e_021964@postgrespro.ru", "phone": "+70035951800"}
0005433680827	5FF1D4	5741 300996	VLADIMIR MOISEEV	{"phone": "+70904377715"}
0005433680828	10DD11	2271 366972	ANASTASIYA KUZNECOVA	{"phone": "+70903933609"}
0005433680829	10DD11	4126 739646	OLGA DAVYDOVA	{"phone": "+70315445247"}
0005433680830	05D967	6341 792129	ANASTASIYA LAZAREVA	{"email": "a-lazareva30051976@postgrespro.ru", "phone": "+70212966630"}
0005433680831	F5C18B	2490 162497	ALEKSANDR VASILEV	{"phone": "+70103546716"}
0005433680832	F5C18B	6710 156504	KONSTANTIN KISELEV	{"phone": "+70987038443"}
0005433680833	F5C18B	3531 268297	TATYANA VOLKOVA	{"email": "volkova.t031973@postgrespro.ru", "phone": "+70017934915"}
0005433680834	A566F9	8014 872732	LILIYA SERGEEVA	{"email": "sergeeva-l-1979@postgrespro.ru", "phone": "+70658862114"}
0005433680835	F3B74C	7868 047571	ANDREY IVANOV	{"email": "ivanov_a07011978@postgrespro.ru", "phone": "+70695817985"}
0005433680836	9A4905	7909 935557	TATYANA PETROVA	{"phone": "+70136360427"}
0005433680837	2AC0C3	0450 376373	SVETLANA YUDINA	{"phone": "+70460895529"}
0005433680838	65537F	9966 855757	OLGA POLYAKOVA	{"email": "olga_polyakova_19061967@postgrespro.ru", "phone": "+70081673113"}
0005433680839	65537F	5382 819537	ANNA AKIMOVA	{"phone": "+70761948583"}
0005433680840	CBADA8	7303 869544	DMITRIY BORISOV	{"email": "dborisov_081971@postgrespro.ru", "phone": "+70636669189"}
0005433680841	C94FB0	5851 341013	LYUDMILA GORBUNOVA	{"phone": "+70082932604"}
0005433680842	C94FB0	2107 877281	ANTONINA POPOVA	{"email": "popova-antonina.071970@postgrespro.ru", "phone": "+70908042416"}
0005433680843	AB6B67	8081 698618	DMITRIY SIDOROV	{"phone": "+70116941789"}
0005433680844	AD3713	4063 281539	IRINA SOKOLOVA	{"phone": "+70075612785"}
0005433680845	E56B4E	2021 659007	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev-13111981@postgrespro.ru", "phone": "+70325305019"}
0005433680846	7CB958	3806 293766	ALEVTINA IVANOVA	{"phone": "+70157039187"}
0005433680847	CA9D11	1667 550662	MAKSIM GRIGOREV	{"email": "maksim.grigorev.1978@postgrespro.ru", "phone": "+70793063452"}
0005433680848	11BB58	5550 737420	ANNA DAVYDOVA	{"phone": "+70736346978"}
0005433680849	CF9747	4898 089616	GALINA ANISIMOVA	{"email": "anisimova-g1975@postgrespro.ru", "phone": "+70445412540"}
0005433680850	09865C	2860 878122	KLAVDIYA ARKHIPOVA	{"email": "arkhipova-klavdiya.101976@postgrespro.ru", "phone": "+70442237769"}
0005433680851	BBBF96	7468 062174	OKSANA MOISEEVA	{"email": "moiseeva_o.101979@postgrespro.ru", "phone": "+70576856353"}
0005433680852	BBBF96	0430 593285	VERA NIKOLAEVA	{"phone": "+70307331641"}
0005433680853	E1F8A9	2786 052512	ZINAIDA ROMANOVA	{"email": "romanova_zinaida.1989@postgrespro.ru", "phone": "+70583270388"}
0005433680854	C499D1	4294 378088	SVETLANA MOROZOVA	{"email": "svetlana-morozova-25091969@postgrespro.ru", "phone": "+70137939803"}
0005433680855	312E6B	5690 615096	NIKOLAY VOROBEV	{"phone": "+70332389594"}
0005433680856	3C0EFF	2097 070497	ANATOLIY ILIN	{"email": "ilinanatoliy061959@postgrespro.ru", "phone": "+70604229098"}
0005433680857	0945FE	5247 142943	TATYANA MARTYNOVA	{"phone": "+70902356939"}
0005433680858	E79DAC	9541 758653	ARTEM KAZAKOV	{"phone": "+70335694674"}
0005433680859	7A7B6F	0727 595434	BORIS PAVLOV	{"email": "b_pavlov011982@postgrespro.ru", "phone": "+70787238934"}
0005433680860	B7EB54	7090 673494	NIKOLAY MELNIKOV	{"phone": "+70326165800"}
0005433680861	47E18F	8827 686365	ANDREY KOZLOV	{"email": "kozlov-andrey_31081964@postgrespro.ru", "phone": "+70873695885"}
0005433680862	95BC4A	4223 981569	MARINA SMIRNOVA	{"email": "smirnovam1972@postgrespro.ru", "phone": "+70512202122"}
0005433680863	95BC4A	6571 692425	EKATERINA VLASOVA	{"email": "ekaterina.vlasova-011968@postgrespro.ru", "phone": "+70803756586"}
0005433680864	95BC4A	8721 233638	ELIZAVETA MAKAROVA	{"email": "makarova-e-021985@postgrespro.ru", "phone": "+70695956456"}
0005433680865	2B64E7	0611 228304	DMITRIY MIRONOV	{"phone": "+70162726893"}
0005433680866	2B64E7	6258 240712	ALEKSANDR GAVRILOV	{"email": "gavrilov.aleksandr_1976@postgrespro.ru", "phone": "+70773301969"}
0005433680867	A5432E	0422 699921	MAKSIM CHERNOV	{"email": "chernov.maksim_081960@postgrespro.ru", "phone": "+70906873699"}
0005433680868	A5432E	0680 016662	TAMARA MOROZOVA	{"phone": "+70390570185"}
0005433680869	0ACDEE	8727 009317	IRINA POPOVA	{"email": "popova_irina021980@postgrespro.ru", "phone": "+70394044503"}
0005433680870	DBC526	1139 723238	MARINA MEDVEDEVA	{"phone": "+70579848768"}
0005433680871	DBC526	6637 855563	ELENA KOVALEVA	{"phone": "+70624913276"}
0005433680872	8E6F27	1776 781684	MIKHAIL KONOVALOV	{"email": "konovalovmikhail-1967@postgrespro.ru", "phone": "+70338141119"}
0005433680873	974DBA	6975 450793	IVAN ROMANOV	{"phone": "+70122690788"}
0005433680874	218065	1825 408761	YURIY KUZNECOV	{"email": "y_kuznecov_071981@postgrespro.ru", "phone": "+70840773975"}
0005433680875	218065	5567 772681	MARIYA ROMANOVA	{"email": "romanova-m121968@postgrespro.ru", "phone": "+70928871842"}
0005433680930	F323B3	9086 188026	BORIS KARPOV	{"phone": "+70375655252"}
0005433680876	A3EDCD	2355 538102	NADEZHDA GRISHINA	{"email": "grishina_nadezhda091976@postgrespro.ru", "phone": "+70352848624"}
0005433680877	A3EDCD	1536 267773	LIYA ZHUKOVA	{"email": "zhukova.liya121983@postgrespro.ru", "phone": "+70719326040"}
0005433680878	E248F1	5216 305494	VALERIY VOROBEV	{"phone": "+70067240054"}
0005433680879	E248F1	8797 855381	IRINA LAZAREVA	{"email": "lazarevairina.121973@postgrespro.ru", "phone": "+70846017044"}
0005433680880	D8E238	5838 399617	OLGA KOZLOVA	{"phone": "+70487956642"}
0005433680881	92DDDE	8515 392035	OLEG KOZLOV	{"email": "kozlov.oleg_1967@postgrespro.ru", "phone": "+70155574715"}
0005433680882	2EC769	0639 922254	EKATERINA LEBEDEVA	{"email": "lebedeva-ekaterina.041969@postgrespro.ru", "phone": "+70137310477"}
0005433680883	11AFB6	4540 431922	SERGEY SCHERBAKOV	{"phone": "+70227146781"}
0005433680884	CF4F03	6223 141112	VLADIMIR BORISOV	{"email": "vborisov_1963@postgrespro.ru", "phone": "+70764298392"}
0005433680885	CF4F03	4383 757191	ZAKHAR ROMANOV	{"email": "z_romanov_22111963@postgrespro.ru", "phone": "+70696976615"}
0005433680886	D02DDF	7121 789634	ZOYA VASILEVA	{"email": "zoya_vasileva.041982@postgrespro.ru", "phone": "+70510218507"}
0005433680887	7EA53F	6078 338026	DMITRIY VASILEV	{"email": "d-vasilev_1968@postgrespro.ru", "phone": "+70410411601"}
0005433680888	4F1FA6	5154 130809	STANISLAV SOKOLOV	{"email": "sokolov.s.021969@postgrespro.ru", "phone": "+70416098004"}
0005433680889	52C4BA	3988 729302	NATALYA KOROLEVA	{"email": "n-koroleva_1978@postgrespro.ru", "phone": "+70122028111"}
0005433680890	52C4BA	1263 665301	YAROSLAV SIDOROV	{"email": "sidorov_y-051987@postgrespro.ru", "phone": "+70144853431"}
0005433680891	E04106	9749 091360	VALENTINA VOLKOVA	{"email": "v-volkova-1988@postgrespro.ru", "phone": "+70698666928"}
0005433680892	B1BF0A	8267 453827	MARAT TIKHONOV	{"email": "mtikhonov-02071978@postgrespro.ru", "phone": "+70322160168"}
0005433680893	4457FE	8887 620886	NIKOLAY FEDOTOV	{"phone": "+70643408558"}
0005433680894	81A764	1620 315802	GALINA MAKAROVA	{"email": "g_makarova1965@postgrespro.ru", "phone": "+70500391549"}
0005433680895	A99F9C	2392 762813	SERGEY POPOV	{"phone": "+70874867112"}
0005433680896	0AF1B9	9157 293807	NATALYA VASILEVA	{"email": "vasileva.natalya-1972@postgrespro.ru", "phone": "+70132930102"}
0005433680897	0AF1B9	7316 328105	IVAN CHERNOV	{"phone": "+70473930243"}
0005433680898	0AF1B9	2125 072465	SERGEY IVANOV	{"phone": "+70825408101"}
0005433680899	D14381	2952 482861	ILDAR SOKOLOV	{"email": "sokolov-ildar-05041959@postgrespro.ru", "phone": "+70230260986"}
0005433680900	F5A9E4	3298 605400	VADIM ZHURAVLEV	{"email": "zhuravlev_v-1977@postgrespro.ru", "phone": "+70887573177"}
0005433680901	F5A9E4	6276 503478	EGOR NIKITIN	{"email": "nikitin-e.1975@postgrespro.ru", "phone": "+70203491417"}
0005433680902	A4BFFA	0633 816842	KSENIYA FILIPPOVA	{"email": "filippova-kseniya1981@postgrespro.ru", "phone": "+70195068235"}
0005433680903	8DB8F4	4247 780248	VIKTOR KUZNECOV	{"phone": "+70941348364"}
0005433680904	92D510	9394 779708	MARIYA KISELEVA	{"email": "kiselevamariya.081979@postgrespro.ru", "phone": "+70346502108"}
0005433680905	ACDC3E	6734 850880	MIKHAIL IVANOV	{"email": "mikhail_ivanov.07111978@postgrespro.ru", "phone": "+70253504816"}
0005433680906	F6FDE3	6215 329469	ZINAIDA IVANOVA	{"email": "ivanova.z.1959@postgrespro.ru", "phone": "+70395116675"}
0005433680907	F6FDE3	7137 778654	OLGA KOROLEVA	{"phone": "+70100708223"}
0005433680908	F6FDE3	7631 323893	ANDREY DMITRIEV	{"email": "dmitriev.andrey_041976@postgrespro.ru", "phone": "+70306875631"}
0005433680909	72AA26	5059 102508	ALEKSANDR MIKHAYLOV	{"phone": "+70959646943"}
0005433680910	7A01B6	3597 497094	ANDREY IVANOV	{"email": "a.ivanov-041977@postgrespro.ru", "phone": "+70771543582"}
0005433680911	D0B36D	4110 648760	DMITRIY NIKITIN	{"email": "nikitin-d31011974@postgrespro.ru", "phone": "+70872777367"}
0005433680912	49BE56	0707 829315	ALEKSANDR ROMANOV	{"email": "aromanov.041961@postgrespro.ru", "phone": "+70112627644"}
0005433680913	6DAB75	7969 958109	ANATOLIY EGOROV	{"email": "egorov_a-17101978@postgrespro.ru", "phone": "+70355879100"}
0005433680914	A0C5D0	5721 764666	SOFIYA MOROZOVA	{"email": "sofiya_morozova041970@postgrespro.ru", "phone": "+70741318110"}
0005433680915	6DE4B3	3606 493393	ANATOLIY SCHERBAKOV	{"email": "scherbakov-anatoliy-031968@postgrespro.ru", "phone": "+70821448899"}
0005433680916	6DE4B3	5040 090524	FEDOR SIDOROV	{"email": "sidorov-f.23041968@postgrespro.ru", "phone": "+70783733611"}
0005433680917	25A10E	0222 694469	ARTEM ZAYCEV	{"phone": "+70855963846"}
0005433680918	25A10E	9147 692722	IRINA KULIKOVA	{"phone": "+70719760921"}
0005433680919	5AA9AA	0800 791305	ELENA CHERNOVA	{"email": "chernova.elena-27081966@postgrespro.ru", "phone": "+70872512007"}
0005433680920	5AA9AA	6824 731808	OLEG BORISOV	{"email": "borisov-oleg_1971@postgrespro.ru", "phone": "+70434382174"}
0005433680921	C775EF	2269 696651	EVGENIYA KRASNOVA	{"email": "evgeniyakrasnova20081975@postgrespro.ru", "phone": "+70612703513"}
0005433680922	058BB5	3616 679522	ANASTASIYA FEDOROVA	{"email": "fedorovaa_1968@postgrespro.ru", "phone": "+70570989051"}
0005433680923	058BB5	0163 109019	TATYANA SMIRNOVA	{"phone": "+70885759243"}
0005433680924	0B2DCB	8996 698360	YURIY MOROZOV	{"phone": "+70552132960"}
0005433680925	FE5D2A	7130 087830	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1982@postgrespro.ru", "phone": "+70906949655"}
0005433680926	FE5D2A	3421 262610	TATYANA NIKIFOROVA	{"email": "nikiforova-t011978@postgrespro.ru", "phone": "+70506352735"}
0005433680927	2BF6E0	6672 692825	VALENTINA ZAYCEVA	{"email": "valentinazayceva.1967@postgrespro.ru", "phone": "+70054651511"}
0005433680928	70C610	0178 502042	GRIGORIY NIKOLAEV	{"email": "grigoriynikolaev121970@postgrespro.ru", "phone": "+70404233838"}
0005433680929	338EED	3710 670821	DARYA PETROVA	{"email": "darya-petrova_031972@postgrespro.ru", "phone": "+70003079547"}
0005433680931	F323B3	4178 134573	YULIYA KAZAKOVA	{"email": "yuliya-kazakova-1968@postgrespro.ru", "phone": "+70690410097"}
0005433680932	F323B3	7162 617416	YURIY TIKHONOV	{"email": "y-tikhonov.27121970@postgrespro.ru", "phone": "+70055375503"}
0005433680933	8F4F64	6246 398427	MIKHAIL ROMANOV	{"email": "m_romanov-14071964@postgrespro.ru", "phone": "+70981565989"}
0005433680934	A94A74	2355 226545	VIKTORIYA BORISOVA	{"phone": "+70512608544"}
0005433680935	A94A74	1911 490086	YULIYA IVANOVA	{"phone": "+70925273369"}
0005433680936	A94A74	9102 267614	MIKHAIL ORLOV	{"email": "morlov.26061974@postgrespro.ru", "phone": "+70564108048"}
0005433680937	578F9A	1501 281535	VLADA SMIRNOVA	{"phone": "+70304863185"}
0005433680938	578F9A	6467 242737	NIKOLAY GAVRILOV	{"email": "gavrilov.n-011966@postgrespro.ru", "phone": "+70378072341"}
0005433680939	FE1C33	7058 634096	ILYA FROLOV	{"email": "i.frolov.03011958@postgrespro.ru", "phone": "+70463294564"}
0005433680940	FE1C33	7604 586273	KONSTANTIN KUZNECOV	{"email": "kkuznecov09081959@postgrespro.ru", "phone": "+70935194340"}
0005433680941	EF9B49	2613 839612	ANASTASIYA NOVIKOVA	{"email": "anastasiyanovikova-1973@postgrespro.ru", "phone": "+70491117793"}
0005433680942	62AB06	6367 339806	NADEZHDA RYABOVA	{"email": "nryabova.09011976@postgrespro.ru", "phone": "+70571881176"}
0005433680943	3E111D	8184 989332	OKSANA NOVIKOVA	{"phone": "+70318116077"}
0005433680944	B867AA	0353 877379	ALEKSANDR DMITRIEV	{"email": "dmitriev_a.071973@postgrespro.ru", "phone": "+70530868631"}
0005433680945	B867AA	7234 843662	MIKHAIL OSIPOV	{"email": "osipov-m-1976@postgrespro.ru", "phone": "+70030618718"}
0005433680946	06A4D6	9894 574219	OLGA POTAPOVA	{"email": "olga_potapova_16061973@postgrespro.ru", "phone": "+70298997170"}
0005433680947	06A4D6	7238 686206	VYACHESLAV BORISOV	{"phone": "+70963406166"}
0005433680948	9308E5	5881 546536	SVETLANA KOMAROVA	{"email": "s-komarova20021970@postgrespro.ru", "phone": "+70331873733"}
0005433680949	B791E1	8227 308234	SVETLANA SOKOLOVA	{"email": "sokolovasvetlana.27071990@postgrespro.ru", "phone": "+70742137780"}
0005433680950	8924AE	7218 957904	ARINA BELOVA	{"email": "arina_belova091975@postgrespro.ru", "phone": "+70364081833"}
0005433680951	8924AE	3876 011899	ANASTASIYA EFIMOVA	{"email": "efimovaa_02031980@postgrespro.ru", "phone": "+70482433275"}
0005433680952	8924AE	2996 356931	PAVEL TIKHONOV	{"phone": "+70400056331"}
0005433680953	279CD8	5431 781322	DIANA FILATOVA	{"phone": "+70703565757"}
0005433680954	279CD8	4434 654982	VIKTOR ZAKHAROV	{"email": "v.zakharov-121962@postgrespro.ru", "phone": "+70734511943"}
0005433680955	18C039	3201 935152	ALEKSANDRA TITOVA	{"email": "titova-a.1979@postgrespro.ru", "phone": "+70567732867"}
0005433680956	0B052E	7380 858465	ALEKSANDR GORBUNOV	{"phone": "+70416477183"}
0005433680957	0B052E	0879 411088	IVAN TIMOFEEV	{"email": "timofeev.i24091970@postgrespro.ru", "phone": "+70009131559"}
0005433680958	A51ED3	9674 639725	GALINA SIDOROVA	{"email": "galinasidorova.121974@postgrespro.ru", "phone": "+70999104308"}
0005433680959	14964D	3213 282743	ALEKSANDR AFANASEV	{"email": "afanasev-a_25021970@postgrespro.ru", "phone": "+70301057562"}
0005433680960	771D63	6004 643200	DARYA KUZNECOVA	{"phone": "+70992241868"}
0005433680961	6919F2	1639 499605	NADEZHDA SOLOVEVA	{"email": "nadezhda_soloveva.08041977@postgrespro.ru", "phone": "+70283340752"}
0005433680962	A98D8B	0625 719527	OLGA AKIMOVA	{"phone": "+70635609885"}
0005433680963	A98D8B	5227 937606	MARIYA SOLOVEVA	{"email": "soloveva-m_041975@postgrespro.ru", "phone": "+70608283679"}
0005433680964	8CC573	9517 937669	YURIY PETROV	{"email": "ypetrov_1973@postgrespro.ru", "phone": "+70210399535"}
0005433680965	0F9C2E	7785 886194	NADEZHDA SMIRNOVA	{"email": "smirnova.nadezhda.1981@postgrespro.ru", "phone": "+70304178452"}
0005433680966	0F9C2E	7689 389895	TATYANA EGOROVA	{"phone": "+70539096969"}
0005433680967	42D04D	5146 617363	NADEZHDA MEDVEDEVA	{"email": "medvedevanadezhda_10061969@postgrespro.ru", "phone": "+70240273065"}
0005433680968	42D04D	3145 706486	OLGA BORISOVA	{"phone": "+70218923073"}
0005433680969	2B8534	9180 128026	ALEKSANDR FROLOV	{"phone": "+70643355277"}
0005433680970	2B8534	9177 116470	ALEKSEY IVANOV	{"email": "ivanov.aleksey-061978@postgrespro.ru", "phone": "+70249846625"}
0005433680971	55187E	7818 716573	VITALIY MAKAROV	{"email": "makarovv.31101973@postgrespro.ru", "phone": "+70089931562"}
0005433680972	FC75C2	0383 566377	KIRILL KUZNECOV	{"phone": "+70530541814"}
0005433680973	FC75C2	3997 702433	ILYA SMIRNOV	{"email": "ilya_smirnov-09021977@postgrespro.ru", "phone": "+70855791637"}
0005433680974	825C06	7251 523138	VIKTORIYA YUDINA	{"phone": "+70973516060"}
0005433680975	A3DFE4	8935 034436	ALEKSEY FEDOROV	{"email": "a_fedorov1984@postgrespro.ru", "phone": "+70323906951"}
0005433680976	15E744	4533 029066	NATALYA VLASOVA	{"phone": "+70882273168"}
0005433680977	15E744	5831 818388	VITALIY ZAYCEV	{"phone": "+70278745108"}
0005433680978	EE6D59	0644 703311	BORIS MATVEEV	{"email": "matveev-boris.09031980@postgrespro.ru", "phone": "+70536704539"}
0005433680979	C905A8	9559 917538	DMITRIY KUZNECOV	{"phone": "+70121238110"}
0005433680980	EABBF1	1545 736201	ALEVTINA KOMAROVA	{"phone": "+70782718050"}
0005433680981	34B566	6585 563719	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya07011979@postgrespro.ru", "phone": "+70680504015"}
0005433680982	8813AB	8398 737498	VARVARA RYABOVA	{"phone": "+70460699548"}
0005433680983	51D5E8	8314 002166	SERGEY MEDVEDEV	{"phone": "+70958264698"}
0005433680984	796777	0544 373116	VADIM ORLOV	{"phone": "+70424801995"}
0005433680985	796777	5716 589633	OLGA EGOROVA	{"phone": "+70366796623"}
0005433680986	E81228	0994 416858	OLGA AKIMOVA	{"email": "o_akimova-011960@postgrespro.ru", "phone": "+70936594532"}
0005433680987	E81228	7233 924072	IRINA KOROLEVA	{"phone": "+70245088632"}
0005433680988	783C6B	2170 247396	MIKHAIL GORBUNOV	{"phone": "+70585557735"}
0005433680989	85FF20	1455 461047	NIKOLAY CHERNOV	{"phone": "+70121125317"}
0005433680990	85FF20	3957 517487	TATYANA FADEEVA	{"email": "tatyana.fadeeva_041974@postgrespro.ru", "phone": "+70330313842"}
0005433680991	2E47BE	0317 426081	ALEKSANDR POPOV	{"email": "popov-aleksandr-1991@postgrespro.ru", "phone": "+70314123958"}
0005433680992	4B3A17	6843 203303	ALEKSANDR STEPANOV	{"phone": "+70802429099"}
0005433680993	4B3A17	5327 236332	SERGEY MELNIKOV	{"phone": "+70584817069"}
0005433680994	4B3A17	3402 703183	YURIY IVANOV	{"phone": "+70389647317"}
0005433680995	2E5016	3429 264396	IVAN RODIONOV	{"email": "i_rodionov111970@postgrespro.ru", "phone": "+70582381470"}
0005433680996	EF6789	0354 310117	EKATERINA DAVYDOVA	{"email": "ekaterina-davydova_081971@postgrespro.ru", "phone": "+70489393106"}
0005433680997	28C367	7260 031900	EVGENIY SOKOLOV	{"phone": "+70681078100"}
0005433680998	23E12B	0509 784352	IRINA SEMENOVA	{"phone": "+70706329584"}
0005433680999	9D82EB	2726 858616	LYUDMILA ZAYCEVA	{"email": "zaycevalyudmila-05021975@postgrespro.ru", "phone": "+70485832715"}
0005433681000	9D82EB	1115 579576	VIKTORIYA IVANOVA	{"email": "ivanova_v-1963@postgrespro.ru", "phone": "+70463737021"}
0005433681001	21AF98	2180 590762	ELENA KOROLEVA	{"email": "koroleva.e.1977@postgrespro.ru", "phone": "+70651974335"}
0005433681002	33A701	8065 683229	ELMIRA KARPOVA	{"phone": "+70641518749"}
0005433681003	33A701	4329 397877	ANNA TARASOVA	{"email": "tarasova-anna-13091962@postgrespro.ru", "phone": "+70036027144"}
0005433681004	570788	7182 944839	VIKTOR SMIRNOV	{"email": "smirnovv-1970@postgrespro.ru", "phone": "+70717648440"}
0005433681005	570788	0975 951094	GALINA MIRONOVA	{"email": "mironova.galina011969@postgrespro.ru", "phone": "+70516475805"}
0005433681006	728D58	8981 086117	ALEKSANDR VLASOV	{"email": "vlasovaleksandr.1976@postgrespro.ru", "phone": "+70366308172"}
0005433681007	728D58	1014 448725	ROMAN BELOV	{"email": "belov.r-1974@postgrespro.ru", "phone": "+70357002744"}
0005433681008	EFCA04	3068 679687	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-121970@postgrespro.ru", "phone": "+70783664892"}
0005433681009	5CEB4C	2640 782865	NATALIYA MELNIKOVA	{"email": "n-melnikova-041967@postgrespro.ru", "phone": "+70685078646"}
0005433681010	E092D8	3665 866978	OLGA DAVYDOVA	{"phone": "+70882746712"}
0005433681011	3B2599	1589 648518	ALEKSANDR CHERNOV	{"email": "a_chernov.041977@postgrespro.ru", "phone": "+70145214614"}
0005433681012	32C7B5	5836 771847	LYUDMILA ANDREEVA	{"phone": "+70287599583"}
0005433681013	32C7B5	6721 235631	EVGENIY VOLKOV	{"phone": "+70755258068"}
0005433681014	EFF43C	2080 286659	TATYANA FOMINA	{"phone": "+70926799866"}
0005433681015	EFF43C	7434 180366	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr111977@postgrespro.ru", "phone": "+70592162416"}
0005433681016	8B49EE	0079 365870	PAVEL BARANOV	{"email": "baranov_p_071977@postgrespro.ru", "phone": "+70686176285"}
0005433681017	8B49EE	8311 545802	NATALYA ILINA	{"phone": "+70507761536"}
0005433681018	C021F4	0055 963416	VALERIY GRIGOREV	{"email": "valeriy.grigorev1972@postgrespro.ru", "phone": "+70252613139"}
0005433681019	E287BD	8185 966872	DMITRIY BONDARENKO	{"phone": "+70642010451"}
0005433681020	E287BD	1950 378892	IRINA NIKOLAEVA	{"email": "i-nikolaeva-011985@postgrespro.ru", "phone": "+70144114220"}
0005433681021	15EB19	7738 090534	VYACHESLAV SHEVCHENKO	{"phone": "+70972060748"}
0005433681022	894294	2857 831867	ANASTASIYA BELYAEVA	{"phone": "+70458086104"}
0005433681023	E83015	2734 684944	VALENTINA ROMANOVA	{"email": "romanovav-1966@postgrespro.ru", "phone": "+70388997951"}
0005433681024	E83015	5971 692449	SVETLANA LUKYANOVA	{"phone": "+70887836253"}
0005433681025	AD0836	6662 452256	NIKOLAY GUSEV	{"email": "gusev-nikolay.13101979@postgrespro.ru", "phone": "+70553396269"}
0005433681026	7A035F	3672 352362	NADEZHDA NAZAROVA	{"phone": "+70868709429"}
0005433681027	7A035F	0977 228390	MARGARITA POPOVA	{"email": "margarita.popova.021964@postgrespro.ru", "phone": "+70415376650"}
0005433681028	490405	6144 153280	ALEKSANDR FROLOV	{"phone": "+70041976934"}
0005433681029	6DF29B	6075 428493	VIKTOR DAVYDOV	{"email": "v.davydov07071964@postgrespro.ru", "phone": "+70080228562"}
0005433681030	6DF29B	4431 817528	VALERIY MOISEEV	{"email": "moiseev.v-19111971@postgrespro.ru", "phone": "+70085106197"}
0005433681031	592A69	3710 013622	OLGA SAVELEVA	{"phone": "+70409500820"}
0005433681032	592A69	1929 152249	ELIZAVETA NESTEROVA	{"phone": "+70290238096"}
0005433681033	C9F684	9199 122686	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey_1971@postgrespro.ru", "phone": "+70417646919"}
0005433681034	17D67D	7109 316616	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin_091969@postgrespro.ru", "phone": "+70121937735"}
0005433681035	7462C5	0333 762459	LYUDMILA MELNIKOVA	{"phone": "+70464989918"}
0005433681036	B14499	9332 175624	NIKOLAY ANTONOV	{"phone": "+70233426979"}
0005433681037	C7D1AC	1759 364579	MARINA ALEKSEEVA	{"phone": "+70774410874"}
0005433681038	BFA0D5	0703 488510	MIKHAIL SERGEEV	{"email": "sergeev_mikhail-1985@postgrespro.ru", "phone": "+70459025759"}
0005433681039	22BE21	0961 550004	IVAN EGOROV	{"phone": "+70110407807"}
0005433681040	22BE21	7012 169650	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr-121977@postgrespro.ru", "phone": "+70273107219"}
0005433681041	22BE21	8893 393232	VALERIY ABRAMOV	{"phone": "+70518691177"}
0005433681042	86D69E	3892 515714	NATALYA MASLOVA	{"email": "nmaslova-03061970@postgrespro.ru", "phone": "+70704944353"}
0005433681043	5D2BAB	2819 675550	DANILA DMITRIEV	{"phone": "+70693976505"}
0005433681044	5D2BAB	0940 268494	MIKHAIL ROMANOV	{"email": "m_romanov-051974@postgrespro.ru", "phone": "+70931257205"}
0005433681045	05D32E	0014 865698	LARISA POPOVA	{"phone": "+70468180017"}
0005433681046	C5E4F5	1373 963970	KSENIYA BORISOVA	{"phone": "+70388274125"}
0005433681047	2BFDA2	7567 491729	ELIZAVETA LEBEDEVA	{"email": "e.lebedeva30061961@postgrespro.ru", "phone": "+70005736490"}
0005433681048	BE5B52	2731 525179	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_v.15091971@postgrespro.ru", "phone": "+70331537255"}
0005433681049	BE5B52	2238 311648	ELENA FILIPPOVA	{"phone": "+70472804042"}
0005433681050	8979A9	9057 305496	MIKHAIL TARASOV	{"email": "tarasov-m.29091975@postgrespro.ru", "phone": "+70977319733"}
0005433681051	F8F008	6466 771431	VALENTINA SMIRNOVA	{"email": "valentina.smirnova_051970@postgrespro.ru", "phone": "+70318410054"}
0005433681052	F8F008	5250 553088	ANNA KOZLOVA	{"phone": "+70644845327"}
0005433681053	176AA7	6546 996617	IRAIDA YUDINA	{"phone": "+70642215683"}
0005433681054	71399E	0783 730655	DANIL BARANOV	{"email": "baranov.danil-16121966@postgrespro.ru", "phone": "+70109777373"}
0005433681055	FF1160	8978 177036	NIKITA MAKAROV	{"phone": "+70134642316"}
0005433681056	33EFB2	2426 879689	ALEKSANDR ABRAMOV	{"phone": "+70586872440"}
0005433681057	66ABD0	4264 672006	IRINA SERGEEVA	{"phone": "+70462918653"}
0005433681058	4DC50D	3537 233595	VALENTINA RODIONOVA	{"phone": "+70165664473"}
0005433681059	4DC50D	7307 595479	TAMARA LOGINOVA	{"phone": "+70358545217"}
0005433681060	4DC50D	1037 266274	ELENA NIKOLAEVA	{"phone": "+70833483147"}
0005433681061	FA6EEA	7040 927403	ANATOLIY MELNIKOV	{"phone": "+70127569720"}
0005433681062	FA6EEA	9643 392471	SERGEY MIRONOV	{"email": "s-mironov_1970@postgrespro.ru", "phone": "+70655653029"}
0005433681063	E0ABF6	5879 061568	NIKOLAY GORBUNOV	{"email": "nikolay-gorbunov-101973@postgrespro.ru", "phone": "+70508164746"}
0005433681064	E0ABF6	5785 933263	ALEKSANDR BELOV	{"email": "belov.a1986@postgrespro.ru", "phone": "+70363594942"}
0005433681065	2C6496	4681 775746	VLADIMIR OSIPOV	{"email": "osipov.v_1978@postgrespro.ru", "phone": "+70589864720"}
0005433681066	D60BCC	0411 135943	TATYANA ZOTOVA	{"phone": "+70485611571"}
0005433681067	7419A4	1433 834781	IVAN DAVYDOV	{"phone": "+70429388975"}
0005433681068	7419A4	3178 213688	ALLA BELOVA	{"email": "a_belova.1957@postgrespro.ru", "phone": "+70195622642"}
0005433681069	AE6093	6632 946764	OKSANA SOLOVEVA	{"phone": "+70346245255"}
0005433681070	AE6093	4060 043217	EKATERINA MATVEEVA	{"phone": "+70508063973"}
0005433681071	2784B8	5949 568208	ALEKSANDR DMITRIEV	{"email": "dmitriev-aleksandr_081977@postgrespro.ru", "phone": "+70466620357"}
0005433681072	2784B8	3169 777182	SVETLANA SEMENOVA	{"email": "semenovas_041964@postgrespro.ru", "phone": "+70970047140"}
0005433681073	598D3A	6079 538010	DANILA SOLOVEV	{"email": "d.solovev-16091974@postgrespro.ru", "phone": "+70596821651"}
0005433681074	48C3C6	0863 774096	ALEKSANDR ALEKSANDROV	{"phone": "+70459036037"}
0005433681075	48C3C6	4279 385926	ELENA PAVLOVA	{"email": "elena_pavlova111985@postgrespro.ru", "phone": "+70445650842"}
0005433681076	B1F7E5	7602 042347	OLGA KISELEVA	{"email": "o-kiseleva1968@postgrespro.ru", "phone": "+70392857647"}
0005433681077	F5002F	8666 691314	ALEKSANDRA GERASIMOVA	{"phone": "+70267095315"}
0005433681078	F5002F	7233 947357	OLGA ZHURAVLEVA	{"phone": "+70607026624"}
0005433681079	034E7D	8817 150142	SERGEY TARASOV	{"email": "tarasov.s-1974@postgrespro.ru", "phone": "+70026959220"}
0005433681080	034E7D	6768 099678	GENNADIY SIDOROV	{"email": "sidorov_g1972@postgrespro.ru", "phone": "+70017365150"}
0005433681081	237C6F	2786 254807	DMITRIY ROMANOV	{"email": "romanov-d08051968@postgrespro.ru", "phone": "+70376535733"}
0005433681082	022777	0130 847185	IGOR POPOV	{"phone": "+70259947381"}
0005433681083	3C1D8D	5816 852597	VALERIY KUZNECOV	{"phone": "+70263584561"}
0005433681084	D4F1F7	9861 369935	RAVIL TIMOFEEV	{"phone": "+70397958094"}
0005433681085	8F839A	4824 587343	SERGEY SOKOLOV	{"phone": "+70570671734"}
0005433681086	711378	0300 591942	ELENA STEPANOVA	{"email": "elena.stepanova_21091974@postgrespro.ru", "phone": "+70011999138"}
0005433681087	19BA35	3030 172005	IVAN SOKOLOV	{"email": "ivan.sokolov_1981@postgrespro.ru", "phone": "+70680896178"}
0005433681088	BC51DE	9409 225728	VITALIY TIKHONOV	{"email": "v-tikhonov071968@postgrespro.ru", "phone": "+70172569118"}
0005433681089	BC51DE	2813 478551	IGOR ZHUKOV	{"email": "zhukovi_1978@postgrespro.ru", "phone": "+70816271465"}
0005433681090	64D952	6789 760829	NATALYA PETROVA	{"phone": "+70357873587"}
0005433681091	767F41	5430 998875	GALINA DANILOVA	{"phone": "+70883346844"}
0005433681092	7A5B29	1951 642792	ANTON KISELEV	{"email": "a_kiselev-071970@postgrespro.ru", "phone": "+70354495524"}
0005433681093	495199	6187 887594	VLADIMIR ANDREEV	{"phone": "+70559923694"}
0005433681094	495199	0224 322700	ALEKSANDR BORISOV	{"phone": "+70871138659"}
0005433681095	3CAB50	3840 354472	OLGA KRASNOVA	{"email": "krasnova_o-04081971@postgrespro.ru", "phone": "+70727436159"}
0005433681096	3CAB50	4345 746682	YAROSLAV DMITRIEV	{"email": "dmitrievyaroslav.27121972@postgrespro.ru", "phone": "+70046849043"}
0005433681097	CD4F04	3504 152757	NINA SOKOLOVA	{"phone": "+70761921115"}
0005433681098	671E7B	6339 305525	ANNA FILATOVA	{"phone": "+70799729771"}
0005433681099	460AFB	6870 655672	LIDIYA MELNIKOVA	{"email": "lidiyamelnikova_121969@postgrespro.ru", "phone": "+70710044916"}
0005433681100	460AFB	7607 203218	NIKITA VOROBEV	{"email": "nvorobev091965@postgrespro.ru", "phone": "+70074975613"}
0005433681101	6A021D	8115 587180	VENERA SEMENOVA	{"phone": "+70907559897"}
0005433681102	FD6448	5731 075500	VERA LUKYANOVA	{"phone": "+70169585221"}
0005433681103	134F37	1952 567448	ANDREY KAZAKOV	{"phone": "+70963039466"}
0005433681104	CE4B70	8859 727489	VALERIY MAKSIMOV	{"phone": "+70311957388"}
0005433681105	FEEAC4	4715 523573	ALEKSANDRA STEPANOVA	{"email": "stepanova.aleksandra.041970@postgrespro.ru", "phone": "+70364395638"}
0005433681106	FEEAC4	7242 758838	ANATOLIY VASILEV	{"email": "a.vasilev.01031978@postgrespro.ru", "phone": "+70035806684"}
0005433681107	FA5C5D	9356 956352	DMITRIY PETROV	{"phone": "+70077257905"}
0005433681108	420373	7134 306937	SVETLANA BOGDANOVA	{"phone": "+70597056902"}
0005433681109	420373	9863 178907	VASILIY ORLOV	{"phone": "+70269472657"}
0005433681110	9A3DBA	7032 959452	SVETLANA IVANOVA	{"phone": "+70027945466"}
0005433681111	DCC41E	6513 671620	ALEKSANDR KUZNECOV	{"phone": "+70955274790"}
0005433681112	9AC234	4465 256171	ANASTASIYA ANTONOVA	{"phone": "+70266826777"}
0005433681113	9AC234	2672 690236	RAISA MATVEEVA	{"phone": "+70939008038"}
0005433681114	A83917	1041 699092	NINA KRASNOVA	{"email": "n.krasnova1977@postgrespro.ru", "phone": "+70861051673"}
0005433681115	4130CA	7114 967513	NATALYA GORBUNOVA	{"phone": "+70820247656"}
0005433681116	DF591B	7260 353553	EDUARD MAKAROV	{"phone": "+70245039914"}
0005433681117	0795F8	4044 035695	VYACHESLAV BELOV	{"email": "vyacheslav.belov_031975@postgrespro.ru", "phone": "+70764385980"}
0005433681118	929102	1034 274967	ANNA ZAYCEVA	{"email": "anna.zayceva.11031973@postgrespro.ru", "phone": "+70481305665"}
0005433681119	929102	0478 688141	ANNA KOMAROVA	{"phone": "+70859432889"}
0005433681120	A0187C	5073 421872	SVETLANA IVANOVA	{"phone": "+70848792862"}
0005433681121	A0187C	1812 034866	SERGEY SOKOLOV	{"phone": "+70155459773"}
0005433681122	225576	5946 169968	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana_021966@postgrespro.ru", "phone": "+70125623546"}
0005433681123	57FDB8	9233 239960	VERONIKA KULIKOVA	{"email": "kulikova-v1980@postgrespro.ru", "phone": "+70607169289"}
0005433681124	FD4C71	1653 791385	EDUARD NIKITIN	{"phone": "+70191950264"}
0005433681125	24A8C2	6481 658088	RAMILYA STEPANOVA	{"phone": "+70415852153"}
0005433681126	24A8C2	9013 040894	TATYANA ANTONOVA	{"phone": "+70933831139"}
0005433681127	D41776	6827 068109	SERGEY FROLOV	{"email": "frolov.s_1977@postgrespro.ru", "phone": "+70054060190"}
0005433681128	D41776	1029 755524	DMITRIY ZHURAVLEV	{"email": "zhuravlev.dmitriy_25041976@postgrespro.ru", "phone": "+70426776075"}
0005433681129	75D5EF	4449 861405	TATYANA SAVELEVA	{"phone": "+70200626215"}
0005433681130	FF1383	5143 427943	GENNADIY PETROV	{"email": "petrov_g_21121968@postgrespro.ru", "phone": "+70307349611"}
0005433681131	FF1383	3289 176420	DENIS BORISOV	{"phone": "+70038364173"}
0005433681132	1EBAE5	4248 233612	EGOR GAVRILOV	{"email": "egavrilov-1974@postgrespro.ru", "phone": "+70673219300"}
0005433681133	FB03B1	5140 950751	MARINA MAKAROVA	{"email": "m.makarova01111969@postgrespro.ru", "phone": "+70998868711"}
0005433681134	FB03B1	6294 218879	ALEKSEY KRASNOV	{"email": "krasnov-aleksey.1973@postgrespro.ru", "phone": "+70793581718"}
0005433681135	ACA4FF	0930 743172	MARIYA MOISEEVA	{"email": "mariya-moiseeva_051973@postgrespro.ru", "phone": "+70225881756"}
0005433681136	76E021	0649 544698	ARTEM MOROZOV	{"email": "morozov.a.29071963@postgrespro.ru", "phone": "+70910319009"}
0005433681137	76E021	0547 314152	NINA DMITRIEVA	{"phone": "+70226864326"}
0005433681138	E9AF5B	7919 380642	VALERIYA VOLKOVA	{"phone": "+70778095522"}
0005433681139	F296B4	5515 102243	LYUDMILA ZAKHAROVA	{"email": "lyudmilazakharova-24021970@postgrespro.ru", "phone": "+70332205067"}
0005433681140	77A53F	1186 573467	NATALYA IVANOVA	{"email": "n.ivanova-08111965@postgrespro.ru", "phone": "+70801346027"}
0005433681141	82810A	6765 699822	IRINA IVANOVA	{"phone": "+70486540687"}
0005433681142	1954B7	5117 292220	OLEG VOLKOV	{"phone": "+70295792266"}
0005433681143	1954B7	3145 184850	EVGENIY FILIPPOV	{"email": "e-filippov24071964@postgrespro.ru", "phone": "+70328418618"}
0005433681144	87AE63	3112 341352	VIKTOR KUZNECOV	{"email": "viktor.kuznecov-02041975@postgrespro.ru", "phone": "+70458952704"}
0005433681145	87AE63	6457 016796	NIKOLAY BELOV	{"email": "n_belov-1966@postgrespro.ru", "phone": "+70599913899"}
0005433681146	F8CDC0	2291 316329	VERA MAKAROVA	{"phone": "+70096100231"}
0005433681147	E53AC3	4444 140424	NATALYA GERASIMOVA	{"email": "natalyagerasimova_23021976@postgrespro.ru", "phone": "+70391287615"}
0005433681148	E53AC3	9291 651692	LIDIYA FEDOROVA	{"email": "lidiya_fedorova.08031987@postgrespro.ru", "phone": "+70765066835"}
0005433681149	86D9C2	9142 470134	OLEG KOZLOV	{"phone": "+70667835438"}
0005433681150	86D9C2	6981 378423	YULIYA GORBUNOVA	{"phone": "+70040092087"}
0005433681151	57A2EE	6748 340067	DENIS EGOROV	{"phone": "+70427970261"}
0005433681152	720805	4976 053975	TATYANA KUZMINA	{"email": "t-kuzmina.1980@postgrespro.ru", "phone": "+70136200780"}
0005433681153	6063E7	0668 790345	IVAN PAVLOV	{"email": "ipavlov-1974@postgrespro.ru", "phone": "+70992465120"}
0005433681154	0A9D42	4068 550713	BORIS KAZAKOV	{"email": "boris_kazakov_1973@postgrespro.ru", "phone": "+70465978202"}
0005433681155	0A9D42	9700 046574	ANNA FROLOVA	{"email": "afrolova_06071962@postgrespro.ru", "phone": "+70975368307"}
0005433681379	ABDC2D	4801 751451	NATALYA OSIPOVA	{"phone": "+70968983287"}
0005433681156	CD52B2	7362 730676	VIKTOR VLASOV	{"email": "v.vlasov.061989@postgrespro.ru", "phone": "+70329782100"}
0005433681157	CD52B2	4948 032875	VERA KUZNECOVA	{"email": "vkuznecova_031968@postgrespro.ru", "phone": "+70062776452"}
0005433681158	E86154	8549 753452	ARTEM MARTYNOV	{"email": "artem.martynov19081971@postgrespro.ru", "phone": "+70317597579"}
0005433681159	42FAA6	0007 015103	LYUBOV AFANASEVA	{"phone": "+70781833549"}
0005433681160	42FAA6	2578 686356	SVETLANA IVANOVA	{"phone": "+70891943225"}
0005433681161	42FAA6	6369 592763	KLAVDIYA SMIRNOVA	{"phone": "+70680224003"}
0005433681162	42FAA6	0039 875088	VASILIY ZAKHAROV	{"phone": "+70870522207"}
0005433681163	3482C8	2354 398797	ANDREY CHERNOV	{"email": "chernov-a_30041974@postgrespro.ru", "phone": "+70717096933"}
0005433681164	3482C8	0792 077200	ANASTASIYA KOMAROVA	{"email": "komarovaanastasiya-061971@postgrespro.ru", "phone": "+70272824760"}
0005433681165	0D043E	7920 949028	TATYANA FADEEVA	{"email": "t_fadeeva_1965@postgrespro.ru", "phone": "+70717016477"}
0005433681166	82DFC6	7326 560439	NATALYA ILINA	{"email": "nilina1968@postgrespro.ru", "phone": "+70480898074"}
0005433681167	82DFC6	7497 291807	KLAVDIYA YUDINA	{"email": "k-yudina.051974@postgrespro.ru", "phone": "+70498416272"}
0005433681168	5B22E6	3891 551377	MARIYA GERASIMOVA	{"email": "gerasimova-m-061985@postgrespro.ru", "phone": "+70810718299"}
0005433681169	ACEA02	5547 222660	IRINA KUZMINA	{"phone": "+70471783353"}
0005433681170	ACEA02	5000 980199	TATYANA TITOVA	{"email": "titova-tatyana-18101975@postgrespro.ru", "phone": "+70610790148"}
0005433681171	ACEA02	0214 907491	SVETLANA KRASNOVA	{"phone": "+70489817129"}
0005433681172	A4AF31	6759 594805	PAVEL NIKITIN	{"phone": "+70306347062"}
0005433681173	B03544	9856 082452	ILYA FOMIN	{"phone": "+70349905153"}
0005433681174	B03544	1585 381835	MIKHAIL MATVEEV	{"phone": "+70369374175"}
0005433681175	664CA8	0404 504302	IRINA TIKHONOVA	{"phone": "+70829661892"}
0005433681176	52C5F5	3768 939861	VYACHESLAV TARASOV	{"phone": "+70956447599"}
0005433681177	809277	6679 518936	EKATERINA FROLOVA	{"phone": "+70368403896"}
0005433681178	598088	9614 784755	VALENTINA IVANOVA	{"phone": "+70745665182"}
0005433681179	60CA05	3659 029222	VERA FROLOVA	{"phone": "+70652441889"}
0005433681180	B7A5CF	1559 127839	EVGENIYA FEDOROVA	{"phone": "+70908581905"}
0005433681181	B7A5CF	9955 746478	EKATERINA LEBEDEVA	{"phone": "+70674503945"}
0005433681182	B7A5CF	6941 690999	ALINA STEPANOVA	{"phone": "+70505001308"}
0005433681183	39054E	1992 662912	OLEG TIKHONOV	{"phone": "+70502502362"}
0005433681184	39054E	0960 050908	NIKOLAY STEPANOV	{"phone": "+70053550740"}
0005433681185	39054E	5295 691451	VLADIMIR VASILEV	{"email": "vladimir.vasilev-1979@postgrespro.ru", "phone": "+70094732541"}
0005433681186	951898	4703 533560	ALEKSEY EGOROV	{"email": "a_egorov.29081974@postgrespro.ru", "phone": "+70885701280"}
0005433681187	951898	2934 398012	VALENTINA NIKOLAEVA	{"phone": "+70868363622"}
0005433681188	69917E	3204 888955	POLINA ANISIMOVA	{"email": "p-anisimova-29031970@postgrespro.ru", "phone": "+70154908688"}
0005433681189	94CE3E	3752 668367	LEONID FILIPPOV	{"email": "leonid_filippov.28111972@postgrespro.ru", "phone": "+70632286714"}
0005433681190	995B21	4669 385607	RUSLAN ROMANOV	{"phone": "+70164333365"}
0005433681191	9360D2	6726 867670	LYUDMILA ZAYCEVA	{"email": "lyudmila_zayceva081967@postgrespro.ru", "phone": "+70534943274"}
0005433681192	9A93FE	3989 000882	NINA VLASOVA	{"phone": "+70421403677"}
0005433681193	211662	2659 451566	VALERIY MOROZOV	{"email": "valeriy_morozov_051966@postgrespro.ru", "phone": "+70865033677"}
0005433681194	5EF50B	9898 991823	ALEKSANDR MIKHAYLOV	{"phone": "+70991154113"}
0005433681195	5EF50B	4371 438941	RAISA BOGDANOVA	{"email": "bogdanova_raisa121975@postgrespro.ru", "phone": "+70987024645"}
0005433681196	5EF50B	1213 616126	YULIYA NIKOLAEVA	{"email": "nikolaeva_y-06071976@postgrespro.ru", "phone": "+70048901896"}
0005433681197	1BCA49	4258 666918	ANNA FROLOVA	{"email": "frolova_anna_06041979@postgrespro.ru", "phone": "+70225130094"}
0005433681198	101968	2509 733204	ANDREY FROLOV	{"email": "frolov.andrey_1969@postgrespro.ru", "phone": "+70866771325"}
0005433681199	101968	4120 110019	OLEG NIKOLAEV	{"email": "nikolaev_oleg-11111973@postgrespro.ru", "phone": "+70157649059"}
0005433681200	F522BD	2031 201476	LIDIYA NAZAROVA	{"phone": "+70951855025"}
0005433681201	F522BD	0316 397040	NIKOLAY SIDOROV	{"email": "nikolay_sidorov-121975@postgrespro.ru", "phone": "+70752998825"}
0005433681202	C0F2EC	6666 335231	ARINA ROMANOVA	{"phone": "+70014129192"}
0005433681203	C0F2EC	5467 467216	ANATOLIY SOKOLOV	{"phone": "+70839884086"}
0005433681204	661F06	1713 015286	STANISLAV FEDOROV	{"phone": "+70618715002"}
0005433681205	8E6BA6	4814 565797	ANTONINA NAUMOVA	{"email": "naumova-antonina-111970@postgrespro.ru", "phone": "+70838884707"}
0005433681206	80154F	9589 619064	KIRILL MAKAROV	{"email": "k_makarov.30041975@postgrespro.ru", "phone": "+70001102814"}
0005433681207	CB6B06	5267 381314	VIKTOR FROLOV	{"phone": "+70893439926"}
0005433681208	CB6B06	2043 491576	INNA KULIKOVA	{"email": "kulikova.inna_03021973@postgrespro.ru", "phone": "+70705501332"}
0005433681209	7C45D5	1653 284438	DENIS NIKOLAEV	{"phone": "+70533431436"}
0005433681210	6221F0	7141 497111	MARINA MELNIKOVA	{"phone": "+70109381172"}
0005433681211	38C2A2	4178 304505	DENIS TARASOV	{"phone": "+70190593305"}
0005433681212	FBE65C	0235 031154	RASHID ANDREEV	{"email": "rashid-andreev1964@postgrespro.ru", "phone": "+70171902561"}
0005433681213	4A4B36	1191 316876	BOGDAN MAKAROV	{"email": "bogdan_makarov.1976@postgrespro.ru", "phone": "+70927313190"}
0005433681214	4A4B36	4059 031493	VITALIY SAVELEV	{"phone": "+70802197520"}
0005433681215	070133	2283 949355	NIKOLAY SAVELEV	{"email": "nikolay.savelev.1966@postgrespro.ru", "phone": "+70092721720"}
0005433681216	070133	5227 916505	DMITRIY MAKSIMOV	{"phone": "+70713723272"}
0005433681217	070133	1690 766000	TAMARA ANTONOVA	{"email": "tantonova.1963@postgrespro.ru", "phone": "+70570924563"}
0005433681218	070133	6672 488843	MIKHAIL OSIPOV	{"phone": "+70944535176"}
0005433681219	070133	5157 948134	MARIYA KARPOVA	{"phone": "+70448100310"}
0005433681220	ABA84F	1983 096637	NATALYA MELNIKOVA	{"email": "nmelnikova.121965@postgrespro.ru", "phone": "+70149248800"}
0005433681221	FF1B07	8783 697331	DIANA GUSEVA	{"phone": "+70575058034"}
0005433681222	FF1B07	5910 948442	VIKTORIYA ILINA	{"email": "ilina-viktoriya_041968@postgrespro.ru", "phone": "+70027672876"}
0005433681223	93A326	7771 134436	VLADIMIR POPOV	{"phone": "+70432653899"}
0005433681224	A3726C	5786 038540	EKATERINA KISELEVA	{"email": "kiseleva-ekaterina11111979@postgrespro.ru", "phone": "+70597401374"}
0005433681225	7E7E46	2185 298534	MIKHAIL MOROZOV	{"email": "morozovm.16081974@postgrespro.ru", "phone": "+70431155405"}
0005433681226	E28543	4324 791803	ANNA GUSEVA	{"email": "anna-guseva-04031971@postgrespro.ru", "phone": "+70020965611"}
0005433681227	95A19F	0501 718629	STANISLAV NIKOLAEV	{"email": "stanislav-nikolaev_1969@postgrespro.ru", "phone": "+70843153570"}
0005433681228	581C51	7186 615082	GULSHAT LEBEDEVA	{"phone": "+70860646481"}
0005433681229	66FC3F	4127 562282	VLADIMIR ORLOV	{"phone": "+70515811128"}
0005433681230	127EC7	8078 707609	ELIZAVETA TROFIMOVA	{"phone": "+70532796914"}
0005433681231	A95D43	3450 030839	LYUDMILA MEDVEDEVA	{"phone": "+70314089614"}
0005433681232	286949	3803 971978	LYUBOV BELOVA	{"email": "beloval.061980@postgrespro.ru", "phone": "+70626589528"}
0005433681233	286949	9169 870335	OLEG NIKITIN	{"email": "olegnikitin.04101974@postgrespro.ru", "phone": "+70466149663"}
0005433681234	286949	9559 602414	MARIYA IVANOVA	{"email": "ivanova.m111971@postgrespro.ru", "phone": "+70789562816"}
0005433681235	286949	9605 918054	NINA BELYAEVA	{"email": "belyaevan.1968@postgrespro.ru", "phone": "+70953715174"}
0005433681236	BDEA00	3472 265314	RAISA GUSEVA	{"phone": "+70309842534"}
0005433681237	BDEA00	5414 889941	ILYA POPOV	{"email": "ipopov.03031972@postgrespro.ru", "phone": "+70540487817"}
0005433681238	BDEA00	0360 723735	EKATERINA DANILOVA	{"phone": "+70395758881"}
0005433681239	472EBC	4955 884814	VLADIMIR MAKSIMOV	{"email": "maksimov-v-03091979@postgrespro.ru", "phone": "+70346310925"}
0005433681240	0FFBBE	6204 368699	DARYA BOGDANOVA	{"email": "darya-bogdanova_031982@postgrespro.ru", "phone": "+70934512623"}
0005433681241	C3D0DE	2956 540248	OLGA TIKHONOVA	{"email": "olgatikhonova-17011978@postgrespro.ru", "phone": "+70713178228"}
0005433681242	98B7AA	5228 462889	NADEZHDA TIMOFEEVA	{"email": "n-timofeeva.19101975@postgrespro.ru", "phone": "+70500506241"}
0005433681243	E95AE2	4447 067314	ALENA FILATOVA	{"email": "afilatova_26061969@postgrespro.ru", "phone": "+70778633954"}
0005433681244	AF95C5	5838 739138	SVETLANA BELOVA	{"phone": "+70211926238"}
0005433681245	AF95C5	1144 304571	ARTEM PAVLOV	{"phone": "+70943199322"}
0005433681246	790846	9381 563115	SVETLANA LUKYANOVA	{"phone": "+70748568184"}
0005433681247	790846	0628 923196	SERGEY MAKAROV	{"email": "sergey_makarov_05091977@postgrespro.ru", "phone": "+70330600066"}
0005433681248	2508BC	6903 774571	VLADIMIR FEDOROV	{"email": "fedorov.v.021975@postgrespro.ru", "phone": "+70439938824"}
0005433681249	75B9B6	4574 198441	PELAGEYA KULIKOVA	{"email": "kulikova-pelageya-30011966@postgrespro.ru", "phone": "+70133853943"}
0005433681250	9CD32E	4693 896491	IGOR CHERNOV	{"email": "chernovigor-1972@postgrespro.ru", "phone": "+70207551330"}
0005433681251	D4F499	6387 373761	ELENA FROLOVA	{"email": "frolova.e-04101970@postgrespro.ru", "phone": "+70661676048"}
0005433681252	D4F499	3463 372852	ALEKSANDR FEDOROV	{"email": "afedorov_15101974@postgrespro.ru", "phone": "+70320693917"}
0005433681253	D4F499	4368 767408	FLYURA ZHUKOVA	{"email": "f.zhukova29101969@postgrespro.ru", "phone": "+70126769991"}
0005433681254	5F2604	1049 883900	DMITRIY TIMOFEEV	{"email": "d_timofeev_06011969@postgrespro.ru", "phone": "+70539473671"}
0005433681255	297B97	8834 701610	DANIIL GERASIMOV	{"email": "gerasimov_d.1965@postgrespro.ru", "phone": "+70262342990"}
0005433681256	E04D67	2354 418356	VIKTORIYA KOROLEVA	{"email": "v_koroleva.13051965@postgrespro.ru", "phone": "+70093114575"}
0005433681257	E04D67	9333 958144	VASILIY IVANOV	{"phone": "+70562744423"}
0005433681258	95D8DF	3912 022705	VLADISLAV FOMIN	{"phone": "+70673270226"}
0005433681259	95D8DF	8314 010283	SERGEY AFANASEV	{"phone": "+70075883607"}
0005433681260	E9F70F	5958 545813	VYACHESLAV ILIN	{"phone": "+70618651554"}
0005433681261	85A031	6936 412892	IVAN MIRONOV	{"email": "i.mironov_06011966@postgrespro.ru", "phone": "+70020891627"}
0005433681262	06682D	1576 420243	ANGELINA PAVLOVA	{"phone": "+70096894444"}
0005433681263	CA341F	0983 117708	ALEKSANDR OSIPOV	{"phone": "+70700839945"}
0005433681264	CA341F	8018 589448	ROMAN AFANASEV	{"phone": "+70162192821"}
0005433681265	A4CB9B	6297 804525	LYUDMILA SOKOLOVA	{"email": "sokolova-lyudmila.01111983@postgrespro.ru", "phone": "+70788693420"}
0005433681266	3AB48F	2148 221926	DARYA IVANOVA	{"email": "daryaivanova.01101984@postgrespro.ru", "phone": "+70654754557"}
0005433681267	3AB48F	5548 659224	ANNA ROMANOVA	{"phone": "+70023001155"}
0005433681492	6DE051	0319 176086	FEDOR VASILEV	{"phone": "+70212311206"}
0005433681268	578DCD	1580 322470	SANIYA ORLOVA	{"email": "orlova.saniya_29081970@postgrespro.ru", "phone": "+70861870033"}
0005433681269	578DCD	1508 980205	MIKHAIL TIMOFEEV	{"phone": "+70555935097"}
0005433681270	03226E	6901 098199	VIKTOR BORISOV	{"phone": "+70809960274"}
0005433681271	03226E	8188 542950	NATALIYA SOLOVEVA	{"email": "nataliyasoloveva_30011990@postgrespro.ru", "phone": "+70753597807"}
0005433681272	DF9A08	9645 878943	TATYANA GRISHINA	{"email": "grishinatatyana_1970@postgrespro.ru", "phone": "+70886171467"}
0005433681273	DF9A08	0080 381187	VALENTINA DMITRIEVA	{"email": "dmitrieva-valentina_25071979@postgrespro.ru", "phone": "+70435690673"}
0005433681274	0E583F	4444 981750	ARSENIY ZAKHAROV	{"phone": "+70019236150"}
0005433681275	0E583F	0783 535043	ALEKSANDR MIRONOV	{"email": "a-mironov_26081962@postgrespro.ru", "phone": "+70454432585"}
0005433681276	D36321	3189 457852	VERA ILINA	{"email": "v-ilina_061971@postgrespro.ru", "phone": "+70609683739"}
0005433681277	D36321	2678 915509	OLGA FROLOVA	{"email": "frolova-o.1971@postgrespro.ru", "phone": "+70729432132"}
0005433681278	2284E3	8885 556434	DMITRIY YAKOVLEV	{"phone": "+70549383673"}
0005433681279	6F4D79	4993 296749	SERGEY AFANASEV	{"phone": "+70013216886"}
0005433681280	EC0AE7	6123 654746	EKATERINA KUZNECOVA	{"email": "ekaterina-kuznecova_1969@postgrespro.ru", "phone": "+70617399691"}
0005433681281	B8645A	0626 146227	EKATERINA CHERNOVA	{"phone": "+70478456186"}
0005433681282	DE87E4	4797 303954	VLADIMIR BELOV	{"email": "belov_vladimir_1975@postgrespro.ru", "phone": "+70170186058"}
0005433681283	538AA5	4039 237542	VALENTINA VOROBEVA	{"phone": "+70853479350"}
0005433681284	538AA5	1135 479664	OLEG ILIN	{"email": "ilin-o_08111971@postgrespro.ru", "phone": "+70013292626"}
0005433681285	B24DE5	2557 703924	VERA ANTONOVA	{"phone": "+70317065622"}
0005433681286	64967A	1255 358440	MIKHAIL BARANOV	{"phone": "+70501091599"}
0005433681287	592757	8162 090906	ANDREY MAKAROV	{"email": "makarov_andrey-26031968@postgrespro.ru", "phone": "+70286983888"}
0005433681288	BF483A	1619 929383	ROMAN SCHERBAKOV	{"phone": "+70806855587"}
0005433681289	2F6F48	6466 094317	YULIYA KUZNECOVA	{"phone": "+70276761195"}
0005433681290	2F6F48	0297 390946	ALEKSEY NAUMOV	{"phone": "+70785358281"}
0005433681291	6ECDF5	8426 833341	SVETLANA PETROVA	{"phone": "+70788636315"}
0005433681292	6DA9AD	6269 312081	VLADISLAV ZAYCEV	{"phone": "+70548196580"}
0005433681293	1B6950	7628 065372	KONSTANTIN ZHUKOV	{"email": "zhukovkonstantin24051963@postgrespro.ru", "phone": "+70950632740"}
0005433681294	1B6950	2185 038755	NAILYA NIKITINA	{"email": "nailyanikitina1962@postgrespro.ru", "phone": "+70215768692"}
0005433681295	F2A674	2383 885240	NINA NESTEROVA	{"phone": "+70124203137"}
0005433681296	73A871	4825 331822	LYUBOV NIKITINA	{"email": "nikitina_lyubov17031969@postgrespro.ru", "phone": "+70281514991"}
0005433681297	F8BA7B	3673 376537	SOFYA ABRAMOVA	{"phone": "+70369905493"}
0005433681298	6371D8	7339 825288	VLADIMIR TARASOV	{"phone": "+70361860718"}
0005433681299	C5EA75	9937 667750	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr.25111960@postgrespro.ru", "phone": "+70890506261"}
0005433681300	C5EA75	5404 389028	ZHANNA KOROLEVA	{"email": "koroleva_z071970@postgrespro.ru", "phone": "+70654169790"}
0005433681301	E817A4	9946 501713	VLADIMIR TIKHONOV	{"phone": "+70173733107"}
0005433681302	E817A4	7704 839177	MIKHAIL SAVELEV	{"email": "savelevm-1974@postgrespro.ru", "phone": "+70566366562"}
0005433681303	FE3FE6	2236 126261	ALEKSEY ALEKSEEV	{"phone": "+70375013576"}
0005433681304	0F62ED	9649 861417	ANDREY EGOROV	{"email": "a-egorov.011975@postgrespro.ru", "phone": "+70062986741"}
0005433681305	0F62ED	4754 330677	ILYA VOLKOV	{"phone": "+70645455271"}
0005433681306	9F7BF9	3830 934033	DAMIR PAVLOV	{"email": "pavlov.damir.121978@postgrespro.ru", "phone": "+70137079034"}
0005433681307	6B7273	1048 771850	OLEG POPOV	{"phone": "+70040961225"}
0005433681308	B4430F	5039 620727	ELENA ALEKSANDROVA	{"email": "e_aleksandrova.071979@postgrespro.ru", "phone": "+70786532350"}
0005433681309	7D881E	6465 641997	SERGEY PAVLOV	{"email": "s-pavlov.1962@postgrespro.ru", "phone": "+70648763795"}
0005433681310	B652E1	8672 478792	EGOR KISELEV	{"email": "e-kiselev1978@postgrespro.ru", "phone": "+70979049783"}
0005433681311	105758	8345 347010	ANDREY KUZNECOV	{"phone": "+70702079284"}
0005433681312	A1AC5A	5187 094378	SAMIR DMITRIEV	{"email": "s_dmitriev1983@postgrespro.ru", "phone": "+70887163026"}
0005433681313	86FE9B	7596 598108	NINA BARANOVA	{"email": "baranova-nina051963@postgrespro.ru", "phone": "+70633466414"}
0005433681314	14C581	8410 771993	ANTONINA SMIRNOVA	{"email": "smirnovaantonina-1968@postgrespro.ru", "phone": "+70087424269"}
0005433681315	14C581	0601 767935	LYUDMILA DMITRIEVA	{"phone": "+70723065537"}
0005433681316	8BBB19	3272 815583	TATYANA FILIPPOVA	{"email": "t_filippova_18041974@postgrespro.ru", "phone": "+70457956705"}
0005433681317	8BBB19	9362 330062	ANNA GUSEVA	{"phone": "+70868933762"}
0005433681318	8BBB19	8526 005184	ANNA MAKAROVA	{"phone": "+70546087397"}
0005433681319	AFFD62	3213 440263	NIKOLAY OSIPOV	{"phone": "+70774294759"}
0005433681320	5EEA47	4632 726537	INNA CHERNOVA	{"email": "inna-chernova_29051970@postgrespro.ru", "phone": "+70799527554"}
0005433681321	5EEA47	3413 030154	ANASTASIYA EFREMOVA	{"email": "anastasiya.efremova_1977@postgrespro.ru", "phone": "+70150570732"}
0005433681322	9D49E1	1455 325859	ELENA LAZAREVA	{"phone": "+70867027394"}
0005433681323	E1E6FC	8664 980110	ZOYA PAVLOVA	{"email": "z.pavlova.01091968@postgrespro.ru", "phone": "+70886576606"}
0005433681324	EB818C	3647 129310	KONSTANTIN SOROKIN	{"email": "sorokinkonstantin.05061970@postgrespro.ru", "phone": "+70423345145"}
0005433681325	EB818C	6984 957289	NIKOLAY ZAKHAROV	{"email": "nzakharov-1967@postgrespro.ru", "phone": "+70827341028"}
0005433681326	521597	7783 869610	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova07101977@postgrespro.ru", "phone": "+70381655412"}
0005433681327	C30925	9160 047492	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova.1971@postgrespro.ru", "phone": "+70184281642"}
0005433681328	92686C	3928 111621	ILYA GRIGOREV	{"phone": "+70335808471"}
0005433681329	B2D53B	8791 472450	RAISA MOROZOVA	{"email": "morozova_r_1973@postgrespro.ru", "phone": "+70011056760"}
0005433681330	9D1BE4	3467 609179	OLGA POPOVA	{"email": "o.popova.06011964@postgrespro.ru", "phone": "+70929662810"}
0005433681331	4360C9	5207 124474	IVAN ANTONOV	{"email": "i_antonov-081976@postgrespro.ru", "phone": "+70244341943"}
0005433681332	1E0AC1	0228 775362	VLADIMIR SCHERBAKOV	{"phone": "+70426669068"}
0005433681333	0ED5CC	5324 775239	ELENA GAVRILOVA	{"phone": "+70271078177"}
0005433681334	0ED5CC	1073 435119	YURIY SHEVCHENKO	{"email": "shevchenko-yuriy_24041970@postgrespro.ru", "phone": "+70868243611"}
0005433681335	B4A1BD	8855 617369	VALENTINA BELOVA	{"email": "belova_v-28091974@postgrespro.ru", "phone": "+70399303879"}
0005433681336	5C13A2	9744 938280	MIKHAIL MEDVEDEV	{"email": "medvedev.mikhail021982@postgrespro.ru", "phone": "+70833080987"}
0005433681337	5C13A2	4966 276355	BOGDAN SERGEEV	{"phone": "+70394345249"}
0005433681338	06A69E	8945 292902	VYACHESLAV KISELEV	{"phone": "+70607854320"}
0005433681339	06A69E	5266 917917	TAMARA MAKSIMOVA	{"email": "t.maksimova.02031980@postgrespro.ru", "phone": "+70827357893"}
0005433681340	303063	0547 130760	ELIZAVETA SMIRNOVA	{"phone": "+70911127159"}
0005433681341	237F7F	0888 198561	ALEVTINA MALYSHEVA	{"phone": "+70136029833"}
0005433681342	958597	7130 950616	RUSTAM KUZNECOV	{"phone": "+70263959055"}
0005433681343	958597	3531 517264	IGOR VOROBEV	{"phone": "+70462344065"}
0005433681344	CC2AAC	0279 549148	TAISIYA GORBUNOVA	{"phone": "+70462221327"}
0005433681345	64C365	5244 096678	ANNA KOVALEVA	{"email": "a-kovaleva.26041975@postgrespro.ru", "phone": "+70387932305"}
0005433681346	EB01B6	8775 279492	ANATOLIY SIDOROV	{"email": "anatoliy-sidorov.17091975@postgrespro.ru", "phone": "+70884798752"}
0005433681347	EB01B6	5602 017377	IRINA ANDREEVA	{"email": "irina-andreeva-1966@postgrespro.ru", "phone": "+70490351636"}
0005433681348	EB01B6	0581 787769	ELENA ZAYCEVA	{"phone": "+70918074595"}
0005433681349	FA5D9E	6606 480088	IVAN ANTONOV	{"email": "iantonov-1960@postgrespro.ru", "phone": "+70116196382"}
0005433681350	FA5D9E	5807 614537	EVGENIY OSIPOV	{"email": "osipov-evgeniy121972@postgrespro.ru", "phone": "+70229377137"}
0005433681351	F4329A	8717 484026	MARIYA SCHERBAKOVA	{"email": "scherbakovamariya.1970@postgrespro.ru", "phone": "+70826928988"}
0005433681352	F4329A	3683 181670	TATYANA KRASNOVA	{"phone": "+70601982039"}
0005433681353	067F3A	3986 052782	ELENA SIDOROVA	{"email": "sidorova-e.19121963@postgrespro.ru", "phone": "+70656385922"}
0005433681354	9E02C3	0022 362844	LARISA POTAPOVA	{"email": "l.potapova-031959@postgrespro.ru", "phone": "+70173642160"}
0005433681355	6AAD50	5524 442670	SVETLANA POPOVA	{"phone": "+70043364000"}
0005433681356	5D2C55	2815 897476	IRINA ALEKSEEVA	{"phone": "+70627587357"}
0005433681357	5D2C55	3954 224819	ANASTASIYA KRASNOVA	{"email": "anastasiya-krasnova_031986@postgrespro.ru", "phone": "+70688313996"}
0005433681358	74CA27	6071 251066	VADIM SIDOROV	{"email": "sidorovv-1974@postgrespro.ru", "phone": "+70988929417"}
0005433681359	886B4B	1308 670167	NIKOLAY MAKSIMOV	{"phone": "+70273545595"}
0005433681360	886B4B	3090 009704	NADEZHDA SOLOVEVA	{"email": "soloveva.nadezhda_1971@postgrespro.ru", "phone": "+70419942222"}
0005433681361	7B2202	0585 740281	ELENA GRISHINA	{"phone": "+70892256548"}
0005433681362	FB2FCE	8962 978584	EKATERINA ROMANOVA	{"phone": "+70822524567"}
0005433681363	B318BA	3968 799385	MIKHAIL OSIPOV	{"email": "osipov-m_121980@postgrespro.ru", "phone": "+70782659550"}
0005433681364	64B98B	4190 654963	ANDREY OSIPOV	{"email": "andrey-osipov-061970@postgrespro.ru", "phone": "+70409229912"}
0005433681365	64B98B	8438 649188	ALIK ROMANOV	{"phone": "+70257949786"}
0005433681366	4DB5EB	7227 784494	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr-14081970@postgrespro.ru", "phone": "+70263946893"}
0005433681367	E93537	3051 362872	VLADIMIR MAKSIMOV	{"email": "maksimov_v_23031962@postgrespro.ru", "phone": "+70786386203"}
0005433681368	C3601D	7411 915042	YAKOV FEDOROV	{"email": "fedorov.y.1976@postgrespro.ru", "phone": "+70729890151"}
0005433681369	FF6CF3	7350 409466	IVAN DAVYDOV	{"email": "ivan-davydov_05021976@postgrespro.ru", "phone": "+70517278771"}
0005433681370	88CE14	7663 212841	TAMARA PAVLOVA	{"phone": "+70340293535"}
0005433681371	AF3C62	9268 212400	GALINA TARASOVA	{"email": "galina.tarasova_04121975@postgrespro.ru", "phone": "+70845017823"}
0005433681372	AF3C62	1236 178590	ELENA EGOROVA	{"email": "egorova-elena.10101973@postgrespro.ru", "phone": "+70322522591"}
0005433681373	AF3C62	7750 618697	SVETLANA MELNIKOVA	{"phone": "+70596161939"}
0005433681374	F34AD5	5894 956268	DMITRIY YAKOVLEV	{"phone": "+70751888683"}
0005433681375	6ED7CC	4070 740970	LYUDMILA DMITRIEVA	{"email": "dmitrieva.lyudmila.051973@postgrespro.ru", "phone": "+70937016468"}
0005433681376	6F4C64	0149 753935	ARTEM KONOVALOV	{"phone": "+70566718253"}
0005433681377	6F4C64	1239 859692	LARISA KUZMINA	{"email": "l_kuzmina031973@postgrespro.ru", "phone": "+70119364442"}
0005433681378	ABDC2D	4075 960129	RIM DMITRIEV	{"email": "rdmitriev121975@postgrespro.ru", "phone": "+70206722315"}
0005433681380	59ACCA	9228 684486	RUMIYA KOZLOVA	{"email": "rkozlova-101978@postgrespro.ru", "phone": "+70047816928"}
0005433681381	E3AF9D	0856 746647	ALIK ANDREEV	{"email": "andreev-alik-111984@postgrespro.ru", "phone": "+70648620492"}
0005433681382	E3AF9D	3114 326066	SERGEY ZAYCEV	{"email": "zaycev-s-041972@postgrespro.ru", "phone": "+70408494052"}
0005433681383	14075B	8052 286918	ELENA KUZNECOVA	{"email": "elenakuznecova-1958@postgrespro.ru", "phone": "+70205700555"}
0005433681384	43E251	1154 232747	MARGARITA ZHUKOVA	{"phone": "+70925123065"}
0005433681385	DBDE01	8098 310133	ARINA VASILEVA	{"phone": "+70843492577"}
0005433681386	02C825	6452 194030	ANDREY EGOROV	{"email": "a_egorov-101968@postgrespro.ru", "phone": "+70160166171"}
0005433681387	86E254	2916 066995	LEONID KOZLOV	{"phone": "+70218413028"}
0005433681388	86E254	1126 928666	VALENTINA GORBUNOVA	{"phone": "+70442675687"}
0005433681389	72B9F8	9880 656170	RUSLAN MIRONOV	{"email": "mironovruslan_11031981@postgrespro.ru", "phone": "+70065192743"}
0005433681390	AFC46C	3551 540136	VADIM FEDOROV	{"email": "vfedorov051973@postgrespro.ru", "phone": "+70115431728"}
0005433681391	9E8B2E	8651 283060	KONSTANTIN KISELEV	{"phone": "+70481270868"}
0005433681392	E29A82	0232 973629	VASILIY PETROV	{"phone": "+70351578308"}
0005433681393	6B2BAE	7656 025613	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy_1967@postgrespro.ru", "phone": "+70464663845"}
0005433681394	485275	1748 439859	YURIY MARTYNOV	{"phone": "+70418312238"}
0005433681395	750B41	0247 850704	DARYA MELNIKOVA	{"email": "melnikova.darya-011973@postgrespro.ru", "phone": "+70087230931"}
0005433681396	750B41	7260 990103	LYUDMILA IVANOVA	{"email": "livanova-071977@postgrespro.ru", "phone": "+70462151707"}
0005433681397	FEBBE1	3459 435918	YURIY FEDOROV	{"email": "yfedorov29051970@postgrespro.ru", "phone": "+70415474088"}
0005433681398	518BE5	9150 230682	ARKADIY MOROZOV	{"email": "arkadiymorozov_06121970@postgrespro.ru", "phone": "+70505043339"}
0005433681399	E68E55	4702 224691	MARIYA POPOVA	{"phone": "+70870117878"}
0005433681400	369514	1036 303073	ALEKSEY IVANOV	{"email": "a-ivanov1975@postgrespro.ru", "phone": "+70786499277"}
0005433681401	369514	9445 311476	ANTON KUZNECOV	{"phone": "+70840383941"}
0005433681402	369514	5637 651240	MAKSIM POPOV	{"phone": "+70541457470"}
0005433681403	0FFC4D	4997 307031	NADEZHDA BOGDANOVA	{"email": "bogdanovanadezhda.21101977@postgrespro.ru", "phone": "+70291201670"}
0005433681404	0FFC4D	8017 813979	VIKTORIYA SCHERBAKOVA	{"phone": "+70661224507"}
0005433681405	24C32A	8142 491417	ALEKSANDR SIDOROV	{"phone": "+70370811637"}
0005433681406	24C32A	2020 132096	OLEG GRIGOREV	{"phone": "+70417022971"}
0005433681407	2DE3F9	9042 178233	ALSU BELYAEVA	{"phone": "+70498387207"}
0005433681408	575050	9752 861513	SVETLANA DAVYDOVA	{"phone": "+70285006399"}
0005433681409	575050	9469 767215	ANATOLIY PAVLOV	{"email": "pavlov_anatoliy.1973@postgrespro.ru", "phone": "+70656058569"}
0005433681410	1039DA	2603 916883	KRISTINA NAUMOVA	{"email": "kristinanaumova-1962@postgrespro.ru", "phone": "+70713053931"}
0005433681411	BC7497	4916 622004	TAMARA FROLOVA	{"email": "tfrolova04021971@postgrespro.ru", "phone": "+70902208511"}
0005433681412	BC7497	6887 435434	ELENA VOLKOVA	{"email": "volkova-e.1975@postgrespro.ru", "phone": "+70441839476"}
0005433681413	7B0658	3545 227891	SERGEY ANDREEV	{"phone": "+70893266080"}
0005433681414	D30622	7334 823236	EGOR PAVLOV	{"email": "e-pavlov.1973@postgrespro.ru", "phone": "+70052585851"}
0005433681415	D30622	8633 426136	MARGARITA KALININA	{"phone": "+70742181743"}
0005433681416	75CCE8	5873 745007	TATYANA SIDOROVA	{"email": "tatyana_sidorova.071963@postgrespro.ru", "phone": "+70740708386"}
0005433681417	EEDDE6	3866 873201	VERA MAKAROVA	{"email": "makarova.vera_19081964@postgrespro.ru", "phone": "+70523551933"}
0005433681418	C6C8D6	8980 512969	OLESYA EGOROVA	{"email": "egorova.o.021973@postgrespro.ru", "phone": "+70928619012"}
0005433681419	C57FCC	3357 369179	ALENA IVANOVA	{"email": "alena.ivanova.1973@postgrespro.ru", "phone": "+70986843565"}
0005433681420	47A1D0	1897 669590	DMITRIY ILIN	{"email": "ilin.d-1965@postgrespro.ru", "phone": "+70775238487"}
0005433681421	47A1D0	1036 215264	SOFIYA GERASIMOVA	{"phone": "+70426194778"}
0005433681422	B48539	9988 145803	NATALYA KARPOVA	{"phone": "+70621252823"}
0005433681423	B48539	1174 534688	NADEZHDA KOVALEVA	{"email": "kovalevanadezhda29111975@postgrespro.ru", "phone": "+70317248939"}
0005433681424	05F8D3	1801 415469	LEONID POPOV	{"phone": "+70396748437"}
0005433681425	05F8D3	3658 024303	ANATOLIY FOMIN	{"phone": "+70910746763"}
0005433681426	3695B0	7829 623002	GALINA VASILEVA	{"phone": "+70948070621"}
0005433681427	D148D3	1579 849211	NIKOLAY NIKOLAEV	{"phone": "+70378201247"}
0005433681428	D148D3	3836 210380	VALERIY KAZAKOV	{"phone": "+70707444441"}
0005433681429	D65D7D	0004 720423	ANDREY DAVYDOV	{"phone": "+70653733212"}
0005433681430	D65D7D	9231 381622	LIDIYA ANISIMOVA	{"email": "lanisimova-01091972@postgrespro.ru", "phone": "+70226901738"}
0005433681431	D65D7D	1405 792698	ALEKSEY MOROZOV	{"phone": "+70934488274"}
0005433681432	56EDB9	6360 024176	ANNA BOGDANOVA	{"phone": "+70541295149"}
0005433681433	56EDB9	2064 658451	IRINA FEDOROVA	{"phone": "+70678127827"}
0005433681434	48B41D	1819 934327	OLGA MOROZOVA	{"email": "omorozova.1974@postgrespro.ru", "phone": "+70798019931"}
0005433681435	48B41D	4486 675862	OLGA BARANOVA	{"phone": "+70545951915"}
0005433681548	AA63DB	4999 990419	ROMAN SHEVCHENKO	{"phone": "+70058772642"}
0005433681436	2D408B	0105 757728	TAMARA EFREMOVA	{"email": "t-efremova_1966@postgrespro.ru", "phone": "+70664466513"}
0005433681437	06CAEB	9570 009008	VLADIMIR KOZLOV	{"email": "kozlov.v_111973@postgrespro.ru", "phone": "+70909728221"}
0005433681438	5E8851	4158 593170	VLADIMIR IVANOV	{"phone": "+70584189610"}
0005433681439	121022	4092 152134	SERGEY KONOVALOV	{"phone": "+70215406974"}
0005433681440	A54BDD	6219 519386	POLINA MALYSHEVA	{"phone": "+70093044568"}
0005433681441	24EF01	6014 548120	ANDREY NAUMOV	{"phone": "+70379805730"}
0005433681442	C191C8	6424 374468	NIKITA SOKOLOV	{"email": "n_sokolov-16011978@postgrespro.ru", "phone": "+70086100135"}
0005433681443	C191C8	6706 408544	ZINAIDA RODIONOVA	{"email": "zinaida-rodionova.1964@postgrespro.ru", "phone": "+70457571790"}
0005433681444	E321FE	0295 737173	EVGENIY ANTONOV	{"email": "antonov.evgeniy_1966@postgrespro.ru", "phone": "+70096291958"}
0005433681445	E321FE	4998 266995	OLGA BELYAEVA	{"email": "o_belyaeva_111965@postgrespro.ru", "phone": "+70945248216"}
0005433681446	74F27F	0442 758007	LILIYA MATVEEVA	{"phone": "+70751522332"}
0005433681447	74F27F	4176 971156	ALEKSEY KOZLOV	{"email": "aleksey.kozlov14061963@postgrespro.ru", "phone": "+70783079057"}
0005433681448	DD533C	1090 454950	VALERIY PETROV	{"phone": "+70320780002"}
0005433681449	52100E	3695 091321	NINA IVANOVA	{"email": "nivanova.29061974@postgrespro.ru", "phone": "+70339452003"}
0005433681450	3F2116	3761 697931	VLADIMIR BARANOV	{"phone": "+70946914379"}
0005433681451	3F2116	6919 697891	YULIYA DAVYDOVA	{"phone": "+70347980521"}
0005433681452	EB7CF0	9981 799412	KIRA FILATOVA	{"email": "filatova_k08121974@postgrespro.ru", "phone": "+70841808465"}
0005433681453	EB7CF0	2766 616268	VERA RODIONOVA	{"phone": "+70475656192"}
0005433681454	60EACA	0552 320345	SVETLANA MOISEEVA	{"phone": "+70138149617"}
0005433681455	60EACA	8164 813718	VLADIMIR POPOV	{"email": "popov_v.021968@postgrespro.ru", "phone": "+70264820119"}
0005433681456	AE6445	2875 579600	LYUDMILA SOROKINA	{"email": "sorokina-l.1972@postgrespro.ru", "phone": "+70376606883"}
0005433681457	4770E8	6489 626944	SOFYA EGOROVA	{"email": "s-egorova.10101968@postgrespro.ru", "phone": "+70739076247"}
0005433681458	6DE7EB	2811 800772	DMITRIY KOROLEV	{"email": "d.korolev1982@postgrespro.ru", "phone": "+70882681277"}
0005433681459	97C2E2	1796 619874	VALERIY SOKOLOV	{"email": "valeriy-sokolov_1957@postgrespro.ru", "phone": "+70563677364"}
0005433681460	FDDC53	1303 271332	VIKTOR MAKAROV	{"email": "makarov-v121970@postgrespro.ru", "phone": "+70993917070"}
0005433681461	FDDC53	4065 446430	DMITRIY SOLOVEV	{"email": "solovev.d.111976@postgrespro.ru", "phone": "+70262005110"}
0005433681462	A4EA01	5870 336514	ELENA LAZAREVA	{"phone": "+70208789845"}
0005433681463	A4EA01	7847 980333	OLEG ZHURAVLEV	{"phone": "+70201194997"}
0005433681464	8A3E7D	6334 361868	VITALIY KUZMIN	{"phone": "+70779663287"}
0005433681465	635FCD	1887 402633	STANISLAV KRASNOV	{"phone": "+70812987275"}
0005433681466	635FCD	6469 771837	VITALIY ZAYCEV	{"email": "vitaliyzaycev-121961@postgrespro.ru", "phone": "+70984347596"}
0005433681467	99BFB4	9044 343283	ALEKSANDR CHERNOV	{"phone": "+70727378781"}
0005433681468	99BFB4	7436 624071	ANASTASIYA MELNIKOVA	{"email": "a-melnikova051983@postgrespro.ru", "phone": "+70767420912"}
0005433681469	99BFB4	8325 270916	VLADIMIR VASILEV	{"phone": "+70785955823"}
0005433681470	9DA5D6	7926 382277	ANATOLIY TARASOV	{"phone": "+70825300051"}
0005433681471	9DA5D6	3152 912578	VIKTOR DMITRIEV	{"email": "viktor_dmitriev.1980@postgrespro.ru", "phone": "+70529200634"}
0005433681472	0014C1	5310 270984	ELENA KOROLEVA	{"email": "koroleva.e_041966@postgrespro.ru", "phone": "+70604788202"}
0005433681473	0014C1	0647 423409	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr_30081976@postgrespro.ru", "phone": "+70673123655"}
0005433681474	253B38	1334 912529	EGOR KISELEV	{"phone": "+70829986937"}
0005433681475	253B38	9837 887143	ALLA IVANOVA	{"email": "allaivanova_07091973@postgrespro.ru", "phone": "+70738530755"}
0005433681476	AD8179	4886 048435	OLEG PAVLOV	{"email": "pavlovo_1967@postgrespro.ru", "phone": "+70499826995"}
0005433681477	AD8179	6295 138627	GALINA VOLKOVA	{"phone": "+70153562381"}
0005433681478	AD8179	1557 660725	VALERIYA NIKITINA	{"phone": "+70107262251"}
0005433681479	BB4022	7623 668959	VERONIKA SCHERBAKOVA	{"phone": "+70988587221"}
0005433681480	BB4022	2358 755273	VALENTINA OVCHINNIKOVA	{"phone": "+70329831990"}
0005433681481	BB4022	5483 101363	VERONIKA ZAYCEVA	{"phone": "+70941462996"}
0005433681482	0E3252	8087 271971	MARIYA LUKYANOVA	{"email": "lukyanovamariya-061977@postgrespro.ru", "phone": "+70243667636"}
0005433681483	0E3252	9938 545258	NIKOLAY POPOV	{"phone": "+70959330397"}
0005433681484	0E3252	9167 659931	ARTEM SMIRNOV	{"phone": "+70293853491"}
0005433681485	8FEFDC	3737 342244	GALINA PETROVA	{"email": "petrovagalina-1970@postgrespro.ru", "phone": "+70774170873"}
0005433681486	FB016E	8841 767358	ALEKSEY FROLOV	{"email": "frolovaleksey121977@postgrespro.ru", "phone": "+70094191127"}
0005433681487	FB016E	0313 879344	NIKOLAY KUZMIN	{"email": "kuzmin.n1968@postgrespro.ru", "phone": "+70930567152"}
0005433681488	FB016E	0842 305638	ALEKSEY BORISOV	{"email": "borisov.aleksey.1973@postgrespro.ru", "phone": "+70427801624"}
0005433681489	040535	6908 670998	DMITRIY FROLOV	{"email": "frolov_d-1969@postgrespro.ru", "phone": "+70635523706"}
0005433681490	22E3CB	1534 187119	OKSANA KONOVALOVA	{"email": "konovalova.o.1974@postgrespro.ru", "phone": "+70106594362"}
0005433681491	6DE051	8401 640968	VLADIMIR ISAEV	{"email": "isaev-vladimir_1967@postgrespro.ru", "phone": "+70204284295"}
0005433681493	DC039D	0090 994042	ELENA ISAEVA	{"email": "isaeva_e-101981@postgrespro.ru", "phone": "+70825586039"}
0005433681494	DC039D	4367 526241	ANDREY KAZAKOV	{"email": "a_kazakov.101963@postgrespro.ru", "phone": "+70681325058"}
0005433681495	DC039D	9249 022133	EVGENIY MIRONOV	{"phone": "+70013561121"}
0005433681496	4FD39A	7532 759071	ZOYA AKIMOVA	{"email": "akimova.zoya_03011971@postgrespro.ru", "phone": "+70813689645"}
0005433681497	4FD39A	7127 647749	BORIS FOMIN	{"phone": "+70288404706"}
0005433681498	6A7102	4230 736110	MARINA SOKOLOVA	{"email": "sokolovam1968@postgrespro.ru", "phone": "+70364338765"}
0005433681499	20F1E1	2128 321302	EVDOKIYA POTAPOVA	{"email": "potapova.evdokiya.031968@postgrespro.ru", "phone": "+70138820596"}
0005433681500	20F1E1	0384 352787	VLADIMIR ANDREEV	{"email": "andreev.v_051970@postgrespro.ru", "phone": "+70734386854"}
0005433681501	E268D2	8088 229299	OLGA IVANOVA	{"email": "oivanova_1969@postgrespro.ru", "phone": "+70328965770"}
0005433681502	C90751	2776 257236	IVAN KUZNECOV	{"email": "kuznecov.ivan.1967@postgrespro.ru", "phone": "+70054592135"}
0005433681503	C90751	0964 958469	KLAVDIYA VASILEVA	{"phone": "+70959389393"}
0005433681504	91FE28	3409 245430	OLGA POPOVA	{"email": "olga_popova-08081971@postgrespro.ru", "phone": "+70324441728"}
0005433681505	91FE28	7069 430228	GALINA CHERNOVA	{"email": "chernova_g.051980@postgrespro.ru", "phone": "+70566726102"}
0005433681506	CB1FAA	0283 134454	ILYA ROMANOV	{"email": "romanov.ilya.1982@postgrespro.ru", "phone": "+70795165093"}
0005433681507	CB1FAA	9672 809057	ILDAR MAKSIMOV	{"phone": "+70106091041"}
0005433681508	2D31C9	9840 074328	ROMAN GRIGOREV	{"email": "r.grigorev_16111961@postgrespro.ru", "phone": "+70202588561"}
0005433681509	95F9B7	0781 543049	RODION DMITRIEV	{"email": "dmitriev-rodion_02101966@postgrespro.ru", "phone": "+70010457742"}
0005433681510	95F9B7	3866 125659	VYACHESLAV ZHURAVLEV	{"email": "zhuravlev-v-081973@postgrespro.ru", "phone": "+70145071331"}
0005433681511	87A62A	6098 881591	YULIYA MELNIKOVA	{"phone": "+70804062407"}
0005433681512	FF188E	5330 957889	ANATOLIY MIKHAYLOV	{"phone": "+70041426461"}
0005433681513	ECAA08	9190 986690	TIMOFEY AFANASEV	{"email": "tafanasev1976@postgrespro.ru", "phone": "+70538890270"}
0005433681514	C95278	5588 776765	ANASTASIYA GERASIMOVA	{"email": "gerasimova-anastasiya.16051972@postgrespro.ru", "phone": "+70181231350"}
0005433681515	16E0EA	0353 232981	SANIYA SOKOLOVA	{"email": "s.sokolova.1965@postgrespro.ru", "phone": "+70982368397"}
0005433681516	62978A	9002 328988	ELENA VOLKOVA	{"email": "e.volkova_011972@postgrespro.ru", "phone": "+70986630068"}
0005433681517	844A8F	0780 270220	ALEKSANDR KISELEV	{"email": "a_kiselev-1980@postgrespro.ru", "phone": "+70227744532"}
0005433681518	0C0DCF	3871 593164	ANTONINA MASLOVA	{"phone": "+70041241287"}
0005433681519	5A8BDE	3360 621093	SERGEY ZHUKOV	{"email": "zhukov-sergey1964@postgrespro.ru", "phone": "+70840774428"}
0005433681520	5A8BDE	3331 227283	TAMARA ZOTOVA	{"email": "t_zotova_1983@postgrespro.ru", "phone": "+70166678797"}
0005433681521	6C91EA	1744 289823	YURIY ORLOV	{"email": "y.orlov021974@postgrespro.ru", "phone": "+70953306571"}
0005433681522	6C91EA	3890 349810	RADIK VOLKOV	{"email": "volkov-radik1970@postgrespro.ru", "phone": "+70012010451"}
0005433681523	88A11B	7826 868643	DMITRIY NAZAROV	{"phone": "+70695649885"}
0005433681524	88A11B	2945 897169	MAKSIM MAKAROV	{"email": "m_makarov.1977@postgrespro.ru", "phone": "+70983000854"}
0005433681525	92914C	3834 341470	IVAN SEMENOV	{"email": "semenov_i.28031965@postgrespro.ru", "phone": "+70880296767"}
0005433681526	EBDB21	9584 354983	VIKTOR KUZNECOV	{"email": "kuznecov_v-011963@postgrespro.ru", "phone": "+70448516272"}
0005433681527	35E8A3	0248 875350	LILIYA NIKITINA	{"email": "liliya-nikitina1970@postgrespro.ru", "phone": "+70155060691"}
0005433681528	D049BA	5982 808278	MAKSIM NIKOLAEV	{"phone": "+70847972242"}
0005433681529	D4C2E7	8019 521364	NINA NIKITINA	{"email": "n_nikitina.011979@postgrespro.ru", "phone": "+70835819261"}
0005433681530	C7DDA6	1885 676294	OLEG ZAKHAROV	{"phone": "+70922426719"}
0005433681531	6A7333	3688 265862	ARINA PETROVA	{"email": "petrova-arina.091966@postgrespro.ru", "phone": "+70581164057"}
0005433681532	F5E7B8	3496 947825	NATALIYA KAZAKOVA	{"phone": "+70709913512"}
0005433681533	F5E7B8	5811 410187	FARID KISELEV	{"phone": "+70141298074"}
0005433681534	84F4D8	9923 299064	GENNADIY VASILEV	{"phone": "+70585091522"}
0005433681535	FE44C6	4880 395007	ANNA AFANASEVA	{"email": "afanaseva.anna_031972@postgrespro.ru", "phone": "+70095719877"}
0005433681536	13DFDC	3333 839317	VLADIMIR BONDARENKO	{"email": "bondarenko-v.22071974@postgrespro.ru", "phone": "+70983002923"}
0005433681537	A4676E	4584 921752	MIKHAIL SCHERBAKOV	{"email": "m.scherbakov-14041982@postgrespro.ru", "phone": "+70409361944"}
0005433681538	485BC8	8405 027243	MIKHAIL KUDRYASHOV	{"phone": "+70147672259"}
0005433681539	485BC8	0775 472646	IRINA ZOTOVA	{"email": "izotova1969@postgrespro.ru", "phone": "+70637808767"}
0005433681540	DEA476	5349 200497	GALINA YAKOVLEVA	{"phone": "+70359415614"}
0005433681541	483E26	5812 083244	YULIYA KISELEVA	{"email": "kiseleva.y_031979@postgrespro.ru", "phone": "+70750490648"}
0005433683337	B9255A	3019 309333	NATALYA ARKHIPOVA	{"phone": "+70982268761"}
0005433681542	E2C424	5184 127611	ELENA TARASOVA	{"email": "e_tarasova_021971@postgrespro.ru", "phone": "+70877723627"}
0005433681543	96AFFA	5345 983520	OLGA DAVYDOVA	{"email": "o-davydova_121976@postgrespro.ru", "phone": "+70406092457"}
0005433681544	D90831	0900 375596	IRINA GAVRILOVA	{"email": "gavrilovai1985@postgrespro.ru", "phone": "+70855529058"}
0005433681545	347A28	0059 114377	ELENA KULIKOVA	{"phone": "+70572792672"}
0005433681546	657A60	5156 726660	VALENTIN ALEKSANDROV	{"email": "valeksandrov_20041969@postgrespro.ru", "phone": "+70377135493"}
0005433681547	5C76BC	7760 452499	NATALYA ZHURAVLEVA	{"phone": "+70356350468"}
0005433681549	D1028B	6781 034140	STANISLAV ORLOV	{"email": "stanislav-orlov-1978@postgrespro.ru", "phone": "+70099262120"}
0005433681550	D1028B	8531 383605	ALEKSANDRA NIKOLAEVA	{"phone": "+70594448032"}
0005433681551	716705	1700 890182	EKATERINA EFIMOVA	{"email": "e.efimova1969@postgrespro.ru", "phone": "+70791891671"}
0005433681552	A9D342	9736 405361	ANASTASIYA BORISOVA	{"phone": "+70584973814"}
0005433681553	5F49FB	7582 339151	VENERA ALEKSANDROVA	{"phone": "+70915428816"}
0005433681554	2222C6	0474 799516	EKATERINA ANISIMOVA	{"phone": "+70598149246"}
0005433681555	2222C6	0055 791261	TATYANA SOKOLOVA	{"phone": "+70709283848"}
0005433681556	02F0B5	5146 962873	ANNA NESTEROVA	{"phone": "+70932806765"}
0005433681557	02F0B5	4986 270590	IRINA NIKITINA	{"email": "irina-nikitina_1969@postgrespro.ru", "phone": "+70222683504"}
0005433681558	BDC0F0	2472 142527	SVETLANA IVANOVA	{"phone": "+70759533265"}
0005433681559	CE4D7B	2203 993917	ALEKSANDR SOLOVEV	{"phone": "+70875870251"}
0005433681560	D4DB59	0113 681591	ANATOLIY SOKOLOV	{"phone": "+70596882533"}
0005433681561	2C5A92	0078 599717	ELENA RYABOVA	{"phone": "+70356501997"}
0005433681562	A1EE35	5468 124497	ARTEM IVANOV	{"email": "artemivanov_28031959@postgrespro.ru", "phone": "+70901126332"}
0005433681563	ADE43D	0196 859048	TATYANA STEPANOVA	{"email": "stepanova_t071968@postgrespro.ru", "phone": "+70200384335"}
0005433681564	A0263A	9573 575972	ELENA NAUMOVA	{"phone": "+70549893358"}
0005433681565	C8ADBF	4239 259006	LARISA FILATOVA	{"phone": "+70948517562"}
0005433681566	EA9740	3718 497475	ELENA FROLOVA	{"phone": "+70974503880"}
0005433681567	EA9740	5297 608841	ALIYA TIKHONOVA	{"phone": "+70370509799"}
0005433681568	40CB9E	1702 803271	ALEKSEY MAKSIMOV	{"email": "maksimova.031972@postgrespro.ru", "phone": "+70692033204"}
0005433681569	033E82	9575 080299	ALEKSANDR MAKAROV	{"phone": "+70003947531"}
0005433681570	BEA297	5253 268458	ELENA ARKHIPOVA	{"email": "e.arkhipova-28031972@postgrespro.ru", "phone": "+70663693767"}
0005433681571	BEA297	2805 250126	NIKITA KAZAKOV	{"phone": "+70380815643"}
0005433681572	47671B	4637 683475	OLESYA CHERNOVA	{"phone": "+70616035345"}
0005433681573	FFD9C5	0223 264300	ALEKSANDR TIMOFEEV	{"email": "a.timofeev09061983@postgrespro.ru", "phone": "+70502461776"}
0005433681630	AE1640	8341 990738	MARIYA NAZAROVA	{"phone": "+70220820542"}
0005433681574	3327D2	8552 142451	ELENA MOROZOVA	{"email": "e-morozova_101983@postgrespro.ru", "phone": "+70570914509"}
0005433681575	3327D2	0327 708182	GALINA ANDREEVA	{"phone": "+70626553044"}
0005433681576	34A625	9916 966359	LYUBOV POPOVA	{"email": "l_popova1967@postgrespro.ru", "phone": "+70602056126"}
0005433681577	B8E7DB	0446 103498	MARINA VOLKOVA	{"email": "m-volkova1973@postgrespro.ru", "phone": "+70729319998"}
0005433681578	3290E3	0053 492535	YURIY EGOROV	{"phone": "+70500717210"}
0005433681579	3290E3	6309 636712	DENIS MAKSIMOV	{"email": "denis-maksimov.091960@postgrespro.ru", "phone": "+70865430314"}
0005433681580	43A765	7978 580408	ANNA ABRAMOVA	{"email": "a_abramova-1973@postgrespro.ru", "phone": "+70781103413"}
0005433681581	43A765	2830 023324	POLINA MOROZOVA	{"email": "p_morozova1985@postgrespro.ru", "phone": "+70390033368"}
0005433681582	A54D02	6697 188638	NATALIYA MELNIKOVA	{"phone": "+70399366117"}
0005433681583	A54D02	4494 919330	YULIYA IVANOVA	{"phone": "+70827140874"}
0005433681584	B8E2BE	9213 821711	YURIY FILIPPOV	{"email": "yfilippov_28121974@postgrespro.ru", "phone": "+70500246571"}
0005433681585	B8E2BE	3352 349926	NIKITA GUSEV	{"phone": "+70244840972"}
0005433681586	C9552C	4093 300235	VLADIMIR ORLOV	{"email": "v_orlov-021968@postgrespro.ru", "phone": "+70439399561"}
0005433681587	FA6924	0872 783330	LYUBOV IVANOVA	{"phone": "+70058936227"}
0005433681588	5C432F	5586 032725	ALEKSEY TARASOV	{"email": "tarasovaleksey.24121979@postgrespro.ru", "phone": "+70440007458"}
0005433681589	D01465	7766 455522	EVGENIY CHERNOV	{"email": "e-chernov-1966@postgrespro.ru", "phone": "+70199273106"}
0005433681590	52CC15	9274 261522	OLGA POPOVA	{"email": "olgapopova_06031964@postgrespro.ru", "phone": "+70703084462"}
0005433681591	919FF6	9416 045416	ANTON MARTYNOV	{"email": "martynov_anton_1976@postgrespro.ru", "phone": "+70263560110"}
0005433681592	3A82E2	8557 764730	ALEKSANDR NOVIKOV	{"phone": "+70836378318"}
0005433681593	3A82E2	7578 301311	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov061970@postgrespro.ru", "phone": "+70285935093"}
0005433681594	F7025B	1599 430845	ANDREY ILIN	{"phone": "+70791189113"}
0005433681595	F7025B	4683 541143	KSENIYA NESTEROVA	{"phone": "+70947800286"}
0005433681596	260418	0395 822785	ROSTISLAV KRASNOV	{"email": "krasnov-r.09091957@postgrespro.ru", "phone": "+70574850185"}
0005433681597	789D88	2268 382212	VENIAMIN MAKAROV	{"phone": "+70232048243"}
0005433681598	789D88	2743 356884	ELENA VASILEVA	{"email": "evasileva_1983@postgrespro.ru", "phone": "+70706463139"}
0005433681599	828901	7850 816244	NINA PAVLOVA	{"phone": "+70915100797"}
0005433681600	34FE20	7632 302658	SERGEY DENISOV	{"phone": "+70132790469"}
0005433681601	34FE20	2986 604989	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr.031970@postgrespro.ru", "phone": "+70464940394"}
0005433681602	FEE153	3462 705421	GALINA OSIPOVA	{"email": "osipova.g14061972@postgrespro.ru", "phone": "+70273700083"}
0005433681603	42E3A7	6489 624563	KSENIYA LOGINOVA	{"email": "kseniyaloginova-1973@postgrespro.ru", "phone": "+70504792594"}
0005433681604	843414	4051 520214	NIKOLAY TIMOFEEV	{"phone": "+70179253601"}
0005433681605	843414	5095 213775	SVETLANA POPOVA	{"email": "popova-svetlana_1983@postgrespro.ru", "phone": "+70205343843"}
0005433681606	63BD9E	7162 729401	VALENTINA GERASIMOVA	{"email": "valentina-gerasimova-12021976@postgrespro.ru", "phone": "+70031892188"}
0005433681607	63BD9E	3199 005091	VIKTOR KOZLOV	{"phone": "+70497004184"}
0005433681608	E7145D	7147 032555	ALEKSANDR KUZNECOV	{"email": "a_kuznecov_061973@postgrespro.ru", "phone": "+70721414357"}
0005433681609	3F3974	2934 111641	ALEKSEY EGOROV	{"phone": "+70415091500"}
0005433681610	D63C8A	6366 050989	SERGEY BORISOV	{"email": "borisov_s.061967@postgrespro.ru", "phone": "+70096181619"}
0005433681611	23E182	8860 843798	GALINA SERGEEVA	{"email": "galina-sergeeva-081960@postgrespro.ru", "phone": "+70932857995"}
0005433681612	358E91	3555 098745	KARINA GERASIMOVA	{"email": "k_gerasimova-031971@postgrespro.ru", "phone": "+70756884695"}
0005433681613	6515BA	9817 532436	ELENA KUDRYASHOVA	{"phone": "+70528126964"}
0005433681614	6515BA	6101 882582	MARIYA KULIKOVA	{"phone": "+70749959685"}
0005433681615	EE588F	1826 819418	NIKITA DMITRIEV	{"phone": "+70216198269"}
0005433681616	8F2D87	1120 124970	EVGENIY ROMANOV	{"email": "e-romanov-021975@postgrespro.ru", "phone": "+70625096667"}
0005433681617	8F2D87	3569 597153	YULIYA FADEEVA	{"email": "y_fadeeva17061966@postgrespro.ru", "phone": "+70861299527"}
0005433681618	60EE36	3585 376316	NIKOLAY VASILEV	{"email": "vasilev.nikolay-1970@postgrespro.ru", "phone": "+70262857068"}
0005433681619	898E07	3245 716726	MARIYA LAZAREVA	{"phone": "+70354540594"}
0005433681620	339DB0	7174 172271	DMITRIY DMITRIEV	{"phone": "+70484515733"}
0005433681621	CFC3B0	3522 814842	ELENA NIKOLAEVA	{"phone": "+70800299658"}
0005433681622	CFC3B0	2163 805021	VALENTINA ANDREEVA	{"email": "andreeva.valentina_1977@postgrespro.ru", "phone": "+70480862288"}
0005433681623	F51829	2237 027352	VALERIY KOZLOV	{"phone": "+70639483627"}
0005433681624	F51829	1545 654842	SERGEY SMIRNOV	{"phone": "+70565826975"}
0005433681625	9ED09B	0179 772647	ILYA SOKOLOV	{"email": "sokolov_i15011979@postgrespro.ru", "phone": "+70398087262"}
0005433681626	9ED09B	9786 559798	OKSANA GRISHINA	{"email": "oksana_grishina1984@postgrespro.ru", "phone": "+70880871384"}
0005433681627	D66FF4	4293 607913	EKATERINA NOVIKOVA	{"email": "e_novikova-10061962@postgrespro.ru", "phone": "+70588850250"}
0005433681628	EB0F2F	9160 689085	DMITRIY KAZAKOV	{"email": "dmitriykazakov021965@postgrespro.ru", "phone": "+70035842610"}
0005433681629	6F4D88	5978 805177	LYUDMILA IVANOVA	{"email": "ivanova_l-23091969@postgrespro.ru", "phone": "+70149828518"}
0005433681631	AE1640	6785 389759	LYUDMILA NIKOLAEVA	{"phone": "+70205593914"}
0005433681632	129DFB	1574 001392	ALEKSEY MATVEEV	{"email": "matveev-a-011962@postgrespro.ru", "phone": "+70465586011"}
0005433681633	07570E	7816 701662	ALEKSEY GRIGOREV	{"phone": "+70870917217"}
0005433681634	68A8B0	5643 407885	VLADIMIR VASILEV	{"email": "vasilev_vladimir-1970@postgrespro.ru", "phone": "+70237205721"}
0005433681635	B3919B	9865 286004	OLGA AFANASEVA	{"phone": "+70632986564"}
0005433681636	E3EF0A	6639 708236	ALLA ANISIMOVA	{"email": "a_anisimova.14091967@postgrespro.ru", "phone": "+70308140618"}
0005433681637	E87D92	7546 104326	ALEKSEY SEMENOV	{"phone": "+70880220119"}
0005433681638	E87D92	5364 401890	ANTONINA MAKSIMOVA	{"phone": "+70302813619"}
0005433681639	414EDC	7516 459545	LYUBOV PAVLOVA	{"email": "lyubov-pavlova-101965@postgrespro.ru", "phone": "+70565441885"}
0005433681640	2E8DA8	3232 565467	ALINA DANILOVA	{"email": "danilova-alina.041967@postgrespro.ru", "phone": "+70519714399"}
0005433681641	2E8DA8	5498 939918	MARINA EFREMOVA	{"phone": "+70189029878"}
0005433681642	1E39ED	6122 551431	IGOR SOKOLOV	{"phone": "+70226962455"}
0005433681643	B4C4C0	4953 457347	PETR FROLOV	{"phone": "+70989219583"}
0005433681644	0F2595	7492 433251	BORIS VASILEV	{"phone": "+70882888449"}
0005433681645	0F2595	1443 605301	REGINA ILINA	{"email": "rilina_091970@postgrespro.ru", "phone": "+70992677568"}
0005433681646	167739	8697 579274	VALENTINA ANDREEVA	{"phone": "+70736177426"}
0005433681647	C62F9B	4796 515244	ANATOLIY DENISOV	{"email": "a_denisov051975@postgrespro.ru", "phone": "+70068839145"}
0005433681648	C62F9B	9605 409882	ANNA KUZNECOVA	{"phone": "+70180290539"}
0005433681649	333543	0506 822339	MARIYA FROLOVA	{"email": "frolova-m1963@postgrespro.ru", "phone": "+70887579429"}
0005433681650	380F22	7325 114981	YULIYA VLASOVA	{"phone": "+70703083479"}
0005433681651	380F22	8514 006955	NIKOLAY MOROZOV	{"email": "n_morozov18021974@postgrespro.ru", "phone": "+70623793088"}
0005433681652	FE8C3A	8042 075727	ALEKSANDR BARANOV	{"email": "aleksandr_baranov.14011982@postgrespro.ru", "phone": "+70018171942"}
0005433681653	3A2C77	8137 518282	ELENA SEMENOVA	{"phone": "+70537495434"}
0005433681654	FE79C3	0479 148923	IVAN VLASOV	{"email": "i-vlasov12101977@postgrespro.ru", "phone": "+70060327043"}
0005433681655	EC2C42	7276 592479	SERGEY POPOV	{"email": "popovs06011976@postgrespro.ru", "phone": "+70076234253"}
0005433681656	EC2C42	0589 967838	MARGARITA KUZNECOVA	{"email": "kuznecova_margarita_031972@postgrespro.ru", "phone": "+70890589647"}
0005433681657	B6A246	5403 160620	VIKTOR KUZNECOV	{"phone": "+70212211078"}
0005433681658	00DDEA	1173 353885	VALERIY NAUMOV	{"phone": "+70414041011"}
0005433681659	54B391	1083 294126	TAMARA KISELEVA	{"email": "kiseleva-tamara-101973@postgrespro.ru", "phone": "+70822422144"}
0005433681660	54B391	8450 765554	ALEKSANDR EGOROV	{"phone": "+70243310629"}
0005433681661	9A9779	9470 677614	TATYANA BELOVA	{"phone": "+70401502944"}
0005433681662	7DBB5A	6670 706271	IVAN EGOROV	{"phone": "+70252478911"}
0005433681663	7DBB5A	3835 928641	GALINA RYABOVA	{"email": "ryabovagalina-27041973@postgrespro.ru", "phone": "+70088684750"}
0005433681664	45AA1F	7789 007142	VYACHESLAV GUSEV	{"phone": "+70336100698"}
0005433681665	367055	0738 237644	OKSANA KUZNECOVA	{"email": "oksana_kuznecova.1966@postgrespro.ru", "phone": "+70942734601"}
0005433681666	5E9647	8571 672191	VLADIMIR SERGEEV	{"phone": "+70397037660"}
0005433681667	9984E8	2624 271178	EKATERINA KONDRATEVA	{"email": "ekaterina-kondrateva-10061983@postgrespro.ru", "phone": "+70307808440"}
0005433681668	9984E8	8082 367852	EVGENIY MIKHAYLOV	{"email": "mikhaylov-evgeniy.1962@postgrespro.ru", "phone": "+70575691597"}
0005433681669	9984E8	9749 169262	PETR SAVELEV	{"email": "savelev.p_1978@postgrespro.ru", "phone": "+70904628017"}
0005433681670	F7B117	0502 737330	ANNA DAVYDOVA	{"phone": "+70921092689"}
0005433681671	C2A96E	0279 553316	EKATERINA ABRAMOVA	{"email": "abramova_ekaterina1976@postgrespro.ru", "phone": "+70665891478"}
0005433681672	D48BED	5071 805608	DARINA MELNIKOVA	{"phone": "+70475716144"}
0005433681673	D48BED	9331 913033	SVETLANA ILINA	{"email": "svetlana.ilina_1988@postgrespro.ru", "phone": "+70579269565"}
0005433681674	81FF14	4394 817064	OKSANA KAZAKOVA	{"phone": "+70255741376"}
0005433681675	DF2355	0164 803158	MARIYA AFANASEVA	{"email": "afanaseva-m-111972@postgrespro.ru", "phone": "+70350582641"}
0005433681676	4DA885	5398 420755	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov-1969@postgrespro.ru", "phone": "+70000143283"}
0005433681677	4DA885	6559 328883	ALEKSEY MIKHAYLOV	{"phone": "+70310759494"}
0005433681678	BA7863	5024 400622	SERGEY PAVLOV	{"phone": "+70873351221"}
0005433681679	BA7863	7762 628153	SVETLANA KOROLEVA	{"phone": "+70615554840"}
0005433681680	4B0C31	1751 454766	ANDREY PETROV	{"phone": "+70184562840"}
0005433681681	75CBD1	5735 622497	LYUDMILA SMIRNOVA	{"email": "lsmirnova_15121966@postgrespro.ru", "phone": "+70349151172"}
0005433681682	E87FC1	3904 296983	OLGA MOISEEVA	{"phone": "+70847243426"}
0005433681683	51FEC6	4543 410771	ALEKSANDRA MAKAROVA	{"email": "makarova.a_041974@postgrespro.ru", "phone": "+70666157867"}
0005433681684	51FEC6	1891 617288	MARINA SAVELEVA	{"phone": "+70405975156"}
0005433681685	51FEC6	9652 418543	SERGEY VASILEV	{"phone": "+70107312499"}
0005433681686	8487DA	4122 716674	MARIYA STEPANOVA	{"email": "stepanova.mariya_1974@postgrespro.ru", "phone": "+70471680409"}
0005433681687	DFD611	4042 659084	VALENTIN MIKHAYLOV	{"phone": "+70808446578"}
0005433681688	AD582E	3408 444055	NADEZHDA ANDREEVA	{"email": "nadezhdaandreeva1954@postgrespro.ru", "phone": "+70779372501"}
0005433681689	AD582E	1030 756295	DIANA IVANOVA	{"phone": "+70168798947"}
0005433681690	527EDB	4350 441037	ELENA ORLOVA	{"phone": "+70962633811"}
0005433681691	527EDB	5145 188083	EVGENIY BORISOV	{"phone": "+70050430348"}
0005433681692	1F0C72	0498 710496	NAZAR ISAEV	{"email": "nazar_isaev-1973@postgrespro.ru", "phone": "+70601651490"}
0005433681693	1F0C72	7056 175421	SERGEY SOKOLOV	{"phone": "+70520063520"}
0005433681694	C77D30	5114 489121	SERGEY YAKOVLEV	{"phone": "+70873913247"}
0005433681695	143881	4652 560030	ALEKSEY PAVLOV	{"email": "apavlov.011972@postgrespro.ru", "phone": "+70474672071"}
0005433681696	CED0DE	7757 881421	VLADIMIR ALEKSEEV	{"email": "v-alekseev-1981@postgrespro.ru", "phone": "+70291597371"}
0005433681697	6A1B39	4156 138220	ALENA PAVLOVA	{"email": "pavlovaalena061980@postgrespro.ru", "phone": "+70586147075"}
0005433681698	2C5E76	0411 820904	VALERIY KOROLEV	{"phone": "+70781540103"}
0005433681699	AD71F7	4487 577043	ALIYA MALYSHEVA	{"phone": "+70453858066"}
0005433681700	4EFF1E	0421 256239	SVETLANA GERASIMOVA	{"phone": "+70780734622"}
0005433681701	4EFF1E	6258 240667	EKATERINA OSIPOVA	{"phone": "+70192752780"}
0005433681702	856001	0726 002920	ANASTASIYA ANTONOVA	{"phone": "+70468663999"}
0005433681703	D06D1D	1934 142016	EVGENIY KUZNECOV	{"phone": "+70965871223"}
0005433681704	3F9524	6220 320420	VLADIMIR TARASOV	{"email": "v.tarasov101963@postgrespro.ru", "phone": "+70223848336"}
0005433681705	C99C75	3658 012240	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr101978@postgrespro.ru", "phone": "+70122126061"}
0005433681706	83D82E	9273 303646	VALENTINA DENISOVA	{"email": "denisova_v.18121964@postgrespro.ru", "phone": "+70689743532"}
0005433681707	83D82E	7813 495282	ALEKSANDR SERGEEV	{"email": "sergeev-a.1964@postgrespro.ru", "phone": "+70121190134"}
0005433681708	B74B04	4091 548325	ANNA KRASNOVA	{"email": "krasnova_a.061972@postgrespro.ru", "phone": "+70622074768"}
0005433681709	CA822B	8282 480486	YANA KUZMINA	{"phone": "+70692277151"}
0005433681710	0C825D	8187 022407	SERGEY MAKSIMOV	{"phone": "+70588945944"}
0005433681711	DCC520	8011 437555	ANNA KUDRYASHOVA	{"email": "anna-kudryashova_1962@postgrespro.ru", "phone": "+70900125852"}
0005433681712	DF3893	0771 669845	ARTEM NAUMOV	{"phone": "+70767646205"}
0005433681713	DC61ED	7114 054816	EVGENIYA MEDVEDEVA	{"email": "e-medvedeva07111974@postgrespro.ru", "phone": "+70992149120"}
0005433681714	DC61ED	4340 977936	DENIS TARASOV	{"email": "tarasov-d-16091969@postgrespro.ru", "phone": "+70237720312"}
0005433681715	F6E9AC	2949 663440	SERGEY ALEKSANDROV	{"email": "sergeyaleksandrov-1972@postgrespro.ru", "phone": "+70958270539"}
0005433681716	6E469F	4065 810249	SVETLANA KRASNOVA	{"email": "skrasnova1973@postgrespro.ru", "phone": "+70791370522"}
0005433681717	6E469F	8538 495970	GEORGIY SAVELEV	{"phone": "+70613688540"}
0005433681718	8DA2A9	7689 022086	ANNA CHERNOVA	{"email": "chernova_a-28021973@postgrespro.ru", "phone": "+70998421439"}
0005433681719	B00A8E	5601 955430	LYUBOV AFANASEVA	{"email": "afanaseva.l.08011969@postgrespro.ru", "phone": "+70163598999"}
0005433681720	706FC1	3332 740667	NADEZHDA MIRONOVA	{"email": "mironova_n1971@postgrespro.ru", "phone": "+70974459335"}
0005433681721	10FEE0	5499 180002	KLAVDIYA MARTYNOVA	{"email": "martynova-k-1981@postgrespro.ru", "phone": "+70612981306"}
0005433681722	7D71F6	2061 940377	ELENA AFANASEVA	{"email": "afanasevae_051976@postgrespro.ru", "phone": "+70003658168"}
0005433681723	347291	3144 511178	TATYANA ABRAMOVA	{"phone": "+70582445784"}
0005433681724	1E6C43	5095 821502	EVGENIY SOROKIN	{"phone": "+70458717132"}
0005433681725	AF63F5	7283 216217	ALEKSANDR TIMOFEEV	{"email": "atimofeev.14101967@postgrespro.ru", "phone": "+70437135492"}
0005433681726	2EE4C2	2338 626257	DENIS IVANOV	{"phone": "+70068015133"}
0005433681727	8835E0	3757 139682	DARYA PETROVA	{"email": "petrovadarya-081983@postgrespro.ru", "phone": "+70297009084"}
0005433681728	87324F	8546 162044	NATALIYA EGOROVA	{"phone": "+70193622382"}
0005433681729	87324F	9386 978461	ANGELINA PAVLOVA	{"phone": "+70768178099"}
0005433681730	17C163	7688 779599	ANASTASIYA FEDOROVA	{"phone": "+70987505167"}
0005433681731	73C51E	4796 344681	NINA GAVRILOVA	{"email": "gavrilova_n.1966@postgrespro.ru", "phone": "+70733055805"}
0005433681732	CD4B9A	5652 186955	VALENTIN TIKHONOV	{"phone": "+70778808435"}
0005433681733	2E747D	0727 614722	TATYANA KUZNECOVA	{"phone": "+70245910344"}
0005433681734	413B48	4502 720315	OLGA ROMANOVA	{"email": "romanova.o07121979@postgrespro.ru", "phone": "+70495799123"}
0005433681735	5968C3	7220 563111	IRAIDA ANDREEVA	{"email": "andreeva.iraida-19041964@postgrespro.ru", "phone": "+70600736173"}
0005433681736	31744E	9185 622502	ALEKSANDR SAVELEV	{"phone": "+70474200881"}
0005433681737	641F89	8382 543548	EVGENIY GUSEV	{"phone": "+70113100153"}
0005433681738	6B53D7	3507 677702	LIDIYA KUZMINA	{"phone": "+70746321683"}
0005433681739	E6639F	3712 739773	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a-1970@postgrespro.ru", "phone": "+70348064083"}
0005433681740	D43384	6737 125050	SVETLANA KOROLEVA	{"email": "korolevasvetlana_111976@postgrespro.ru", "phone": "+70411244628"}
0005433681741	18EEFE	6770 245405	NADEZHDA VASILEVA	{"email": "vasilevanadezhda1972@postgrespro.ru", "phone": "+70877778250"}
0005433681742	F3B6C1	3869 596264	STANISLAV KONOVALOV	{"email": "s.konovalov1976@postgrespro.ru", "phone": "+70925050224"}
0005433681743	64408C	5097 725642	INNA FROLOVA	{"phone": "+70049581590"}
0005433681744	64408C	2158 562077	ANATOLIY MIKHAYLOV	{"phone": "+70309917429"}
0005433681745	17AC62	3949 315647	TAMARA STEPANOVA	{"phone": "+70263641682"}
0005433681746	B2E44A	0296 525498	ALEKSANDR KUZNECOV	{"email": "kuznecov-a_1968@postgrespro.ru", "phone": "+70620813227"}
0005433681747	7A42BB	8404 368641	TATYANA DAVYDOVA	{"email": "davydovat.02111991@postgrespro.ru", "phone": "+70272710807"}
0005433681748	7374E0	8164 953971	VLADIMIR ANDREEV	{"phone": "+70923841622"}
0005433681749	840C28	7143 647963	VERA ANDREEVA	{"email": "andreeva-v17101970@postgrespro.ru", "phone": "+70166876445"}
0005433681750	DF2B44	8397 837786	ALEKSEY POPOV	{"email": "popov_aleksey.1967@postgrespro.ru", "phone": "+70454281831"}
0005433681751	C9C3D5	5041 612362	ALEKSANDR VASILEV	{"email": "a.vasilev-091973@postgrespro.ru", "phone": "+70646389652"}
0005433681752	C9C3D5	9552 452591	OLGA IVANOVA	{"phone": "+70525150870"}
0005433681753	4A92F2	8771 852259	GENNADIY VOLKOV	{"email": "volkov-g_13031966@postgrespro.ru", "phone": "+70861610052"}
0005433681754	59EEB7	4878 898642	TAMARA NAUMOVA	{"phone": "+70536708577"}
0005433681755	F49E1E	9708 260192	NADEZHDA VASILEVA	{"phone": "+70380413687"}
0005433681756	72A1F3	7070 419203	LYUDMILA IVANOVA	{"phone": "+70490546004"}
0005433681757	72A1F3	7199 549129	LYUDMILA NIKOLAEVA	{"email": "nikolaevalyudmila.12031972@postgrespro.ru", "phone": "+70050330344"}
0005433681758	327E23	2475 316177	DARYA NIKITINA	{"phone": "+70336703310"}
0005433681759	D48F0F	3156 065817	PETR FEDOTOV	{"email": "petr_fedotov.1977@postgrespro.ru", "phone": "+70685501499"}
0005433681760	B8DEBE	7192 533020	MARK TARASOV	{"phone": "+70867097606"}
0005433681761	B8DEBE	3988 036530	ANASTASIYA FADEEVA	{"phone": "+70979602986"}
0005433681762	693BCA	0469 437504	YULIYA NIKOLAEVA	{"phone": "+70833963650"}
0005433681763	693BCA	4407 119165	MARIYA PETROVA	{"phone": "+70163254390"}
0005433681764	234A11	7490 901589	NADEZHDA KOZLOVA	{"phone": "+70503954342"}
0005433681765	234A11	2265 450504	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov.1963@postgrespro.ru", "phone": "+70408194944"}
0005433681766	904250	7641 385273	NIKOLAY TARASOV	{"email": "nikolaytarasov.021962@postgrespro.ru", "phone": "+70967905761"}
0005433681767	904250	9147 283706	GALINA AKIMOVA	{"email": "akimova.galina-1971@postgrespro.ru", "phone": "+70050312644"}
0005433681768	D907A3	1246 456594	REGINA ABRAMOVA	{"phone": "+70690048427"}
0005433681769	30A0D6	4181 294799	TATYANA MATVEEVA	{"email": "matveeva_tatyana.071987@postgrespro.ru", "phone": "+70069934181"}
0005433681770	30A0D6	7571 919326	PAVEL KARPOV	{"email": "karpov.pavel.01011973@postgrespro.ru", "phone": "+70617234315"}
0005433681771	F47603	5000 807501	NADEZHDA TARASOVA	{"phone": "+70385034662"}
0005433681772	B3BBA1	3487 357725	NATALYA SMIRNOVA	{"email": "natalyasmirnova_14121962@postgrespro.ru", "phone": "+70789076252"}
0005433681773	B3BBA1	0424 647478	MIKHAIL SOKOLOV	{"phone": "+70566076849"}
0005433681774	13AA73	1652 495352	RAMIL VASILEV	{"phone": "+70341703250"}
0005433681775	AE8791	8645 498559	RAMIL KUZMIN	{"email": "kuzmin_r_1974@postgrespro.ru", "phone": "+70609683204"}
0005433681776	A526EB	2624 098053	VALENTINA LEBEDEVA	{"phone": "+70252990949"}
0005433681777	E926EE	4402 059853	YULIYA NESTEROVA	{"email": "y.nesterova1969@postgrespro.ru", "phone": "+70422280679"}
0005433681778	2D92FA	4108 953548	TATYANA SMIRNOVA	{"phone": "+70737056841"}
0005433681779	AAB338	5685 540787	SERGEY KRASNOV	{"email": "sergey.krasnov.08061977@postgrespro.ru", "phone": "+70403194108"}
0005433681780	C9C111	4264 025310	MIKHAIL MAKSIMOV	{"email": "maksimov.mikhail.14061968@postgrespro.ru", "phone": "+70853404995"}
0005433681781	C04F6D	1616 034331	NATALYA BARANOVA	{"phone": "+70115426302"}
0005433681782	05A4EE	0200 768243	ELENA NIKITINA	{"email": "nikitina_elena.041980@postgrespro.ru", "phone": "+70347315458"}
0005433681783	7FD470	8184 242592	PETR KOROLEV	{"phone": "+70823853267"}
0005433681784	7FD470	2366 301381	NINA KOROLEVA	{"email": "n.koroleva.14121960@postgrespro.ru", "phone": "+70624938367"}
0005433681785	54FA61	6326 020880	TATYANA SEMENOVA	{"phone": "+70631396459"}
0005433681786	54FA61	7104 724484	ARTEM MAKAROV	{"email": "makarov_a_031977@postgrespro.ru", "phone": "+70755384265"}
0005433681787	5172AA	3671 828247	MARIYA MOROZOVA	{"phone": "+70807378640"}
0005433681788	C55C32	3396 348528	YURIY IVANOV	{"phone": "+70820856869"}
0005433681789	C55C32	2788 259683	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr22011964@postgrespro.ru", "phone": "+70722392115"}
0005433681790	10191B	4108 929399	NATALYA ZAYCEVA	{"phone": "+70847695131"}
0005433681791	10191B	8343 487634	OLGA POTAPOVA	{"email": "olga-potapova-071972@postgrespro.ru", "phone": "+70246934591"}
0005433681792	F7E13F	6308 152186	VIKTOR PAVLOV	{"email": "pavlov-v011982@postgrespro.ru", "phone": "+70578833037"}
0005433681793	F7E13F	5690 852321	ZLATA EFIMOVA	{"phone": "+70888561468"}
0005433681794	F7E13F	5998 543699	ELENA ERMAKOVA	{"phone": "+70667458663"}
0005433681795	0818A4	8356 119566	IGOR KUZNECOV	{"phone": "+70286374438"}
0005433681796	CA13B2	9256 353285	ALEKSEY SEMENOV	{"phone": "+70556638013"}
0005433681797	F48340	9107 583650	SERGEY ISAEV	{"phone": "+70985074946"}
0005433681798	EA079D	2881 084717	RIMMA SERGEEVA	{"email": "r_sergeeva-12041971@postgrespro.ru", "phone": "+70243510162"}
0005433681799	EA079D	9648 859358	LYUBOV FROLOVA	{"phone": "+70900641178"}
0005433681800	8486F8	3922 413223	NINA AFANASEVA	{"phone": "+70767918156"}
0005433681801	203154	3271 002345	YAROSLAV PETROV	{"email": "petrov_y24091970@postgrespro.ru", "phone": "+70627236926"}
0005433681802	203154	5584 190811	NIKOLAY BARANOV	{"email": "baranov-nikolay1978@postgrespro.ru", "phone": "+70860778530"}
0005433681803	203154	3082 752883	VLADIMIR ROMANOV	{"phone": "+70423983190"}
0005433681804	448783	8759 644510	VERA MOISEEVA	{"email": "moiseevav-21121971@postgrespro.ru", "phone": "+70821079672"}
0005433681805	934EEE	6542 365714	MARIYA MAKAROVA	{"email": "makarova.mariya1972@postgrespro.ru", "phone": "+70781480268"}
0005433681806	57CF9E	0484 192624	TATYANA KULIKOVA	{"phone": "+70438560306"}
0005433681807	E48702	6374 481281	DARYA BORISOVA	{"phone": "+70215357895"}
0005433681808	ADA361	3021 191957	KSENIYA FEDOROVA	{"email": "kfedorova_1979@postgrespro.ru", "phone": "+70862300763"}
0005433681809	ADA361	3090 966196	ALEKSEY GUSEV	{"phone": "+70622739707"}
0005433681810	B6F3AB	9267 499313	IRINA STEPANOVA	{"phone": "+70201763766"}
0005433681811	B6F3AB	5226 532737	SERGEY NOVIKOV	{"phone": "+70261847348"}
0005433681812	7C13E4	1941 513649	VASILIY POPOV	{"email": "popov.v_1976@postgrespro.ru", "phone": "+70208934654"}
0005433681813	EF3849	8582 296719	GALINA MIRONOVA	{"email": "g.mironova.1968@postgrespro.ru", "phone": "+70711887182"}
0005433681814	EF3849	5704 413156	TATYANA NIKITINA	{"phone": "+70211981968"}
0005433681815	EF3849	9164 782723	NINA POPOVA	{"email": "popovanina.1980@postgrespro.ru", "phone": "+70421797630"}
0005433681816	3915B1	0267 751867	TAMARA NOVIKOVA	{"email": "novikova-tamara-021965@postgrespro.ru", "phone": "+70453471378"}
0005433681817	C02F2A	3566 358286	YURIY MATVEEV	{"email": "yuriy.matveev1975@postgrespro.ru", "phone": "+70449157942"}
0005433681818	C02F2A	8462 367054	OLEG SOROKIN	{"phone": "+70347954393"}
0005433681819	099441	0489 421973	ALEKSEY TIKHONOV	{"email": "tikhonov.a.081970@postgrespro.ru", "phone": "+70909766649"}
0005433681820	099441	1458 746758	PAVEL KUZNECOV	{"phone": "+70022632819"}
0005433681821	BCB352	5248 466741	EKATERINA FILIPPOVA	{"phone": "+70946780912"}
0005433681822	027C9D	6548 233779	ELENA KOZLOVA	{"phone": "+70841446292"}
0005433681823	027C9D	8570 551322	OLGA SOROKINA	{"phone": "+70408943808"}
0005433681824	B7E980	3654 707224	SERGEY KUZMIN	{"email": "kuzmin-sergey-091966@postgrespro.ru", "phone": "+70188125592"}
0005433681825	B7E980	5499 847629	STANISLAV GRIGOREV	{"phone": "+70369711186"}
0005433681826	30784E	0006 102215	GEVORG PAVLOV	{"phone": "+70374636361"}
0005433681827	E2CBD9	5687 067880	ROZA IVANOVA	{"email": "ivanova.roza_101971@postgrespro.ru", "phone": "+70418230215"}
0005433681828	E2CBD9	9002 977230	IVAN POPOV	{"email": "popov_i101973@postgrespro.ru", "phone": "+70171438731"}
0005433681829	06F078	3192 515674	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov-1972@postgrespro.ru", "phone": "+70544651677"}
0005433681830	78237C	5553 249315	LARISA TIKHONOVA	{"email": "tikhonova-l.071970@postgrespro.ru", "phone": "+70343987259"}
0005433681831	A731D9	9595 707071	VALENTINA MIRONOVA	{"email": "vmironova1981@postgrespro.ru", "phone": "+70382819047"}
0005433681832	449D10	6539 928540	IVAN KONOVALOV	{"email": "konovalov.ivan.091965@postgrespro.ru", "phone": "+70377784653"}
0005433681833	DE1BCE	2357 710692	NADEZHDA SMIRNOVA	{"email": "n_smirnova111971@postgrespro.ru", "phone": "+70172224286"}
0005433681834	F68CE2	9272 937376	SVETLANA PETROVA	{"email": "s-petrova-27121964@postgrespro.ru", "phone": "+70937235985"}
0005433681835	F68CE2	4225 501061	ALEKSEY NIKOLAEV	{"phone": "+70016539378"}
0005433681836	F68CE2	8378 710314	MATVEY ZHUKOV	{"email": "matveyzhukov_16051969@postgrespro.ru", "phone": "+70789992446"}
0005433681837	2D0FC4	3608 558091	SERGEY BORISOV	{"email": "borisov.s-20071971@postgrespro.ru", "phone": "+70803809418"}
0005433681838	2D0FC4	0359 036564	NADEZHDA AFANASEVA	{"email": "n.afanaseva14061971@postgrespro.ru", "phone": "+70092655761"}
0005433681839	892EBD	6439 333123	IRINA ALEKSANDROVA	{"email": "irinaaleksandrova02101972@postgrespro.ru", "phone": "+70974612616"}
0005433681840	892EBD	9795 274413	TATYANA MAKAROVA	{"email": "makarova-tatyana.101966@postgrespro.ru", "phone": "+70387597812"}
0005433681841	69D2A1	9442 445829	SOFYA KUZNECOVA	{"email": "sofyakuznecova02011960@postgrespro.ru", "phone": "+70400248771"}
0005433681842	1E356A	0002 955219	VERA SOLOVEVA	{"email": "soloveva_vera.091969@postgrespro.ru", "phone": "+70976823156"}
0005433681843	1E356A	5373 998702	YAKOV ORLOV	{"email": "yorlov.27021971@postgrespro.ru", "phone": "+70729741201"}
0005433681844	F0D1C3	9690 763189	LYUBOV KOMAROVA	{"email": "komaroval_1971@postgrespro.ru", "phone": "+70803456549"}
0005433681845	7B3DBA	8042 233784	MAKSIM ZAKHAROV	{"phone": "+70690895659"}
0005433681846	7B3DBA	3354 987390	ZOYA ORLOVA	{"email": "orlova_zoya-14051976@postgrespro.ru", "phone": "+70862058459"}
0005433681847	2D91BB	0383 732076	NADEZHDA SOLOVEVA	{"phone": "+70120990867"}
0005433681848	3DE893	0170 672133	NIKOLAY BORISOV	{"email": "borisov_n1970@postgrespro.ru", "phone": "+70639429479"}
0005433681849	1EFE92	8458 078686	SVETLANA GAVRILOVA	{"phone": "+70870874172"}
0005433681850	90A252	3664 638018	EGOR KUZNECOV	{"phone": "+70089908003"}
0005433681851	90A252	4848 900223	ILDAR KUZNECOV	{"phone": "+70653601240"}
0005433681852	D14B0D	2558 482389	EKATERINA BOGDANOVA	{"email": "ekaterinabogdanova-09101981@postgrespro.ru", "phone": "+70270129465"}
0005433681853	A068FA	2895 221399	NIKOLAY FROLOV	{"email": "frolov-nikolay_1971@postgrespro.ru", "phone": "+70865902594"}
0005433681854	E06F8F	3636 427967	VLADIMIR PETROV	{"phone": "+70789939592"}
0005433681855	E06F8F	1577 412675	ANDREY SIDOROV	{"email": "sidorova_031966@postgrespro.ru", "phone": "+70773861764"}
0005433681856	E06F8F	9174 849518	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_1967@postgrespro.ru", "phone": "+70075063345"}
0005433681857	A66BEF	9033 895184	LYUBOV YAKOVLEVA	{"email": "l-yakovleva.1972@postgrespro.ru", "phone": "+70731251493"}
0005433681858	BB0DED	7662 602288	ELENA ALEKSANDROVA	{"phone": "+70689879620"}
0005433681859	BB0DED	2111 027085	EVGENIY MAKAROV	{"email": "e.makarov.111971@postgrespro.ru", "phone": "+70507638533"}
0005433681860	AB2E5D	1611 280491	VIKTOR GAVRILOV	{"phone": "+70028782037"}
0005433681861	B2E90B	3064 129861	TATYANA MASLOVA	{"phone": "+70564630349"}
0005433681862	A74387	5874 678508	VASILIY VOLKOV	{"phone": "+70596679992"}
0005433681863	A74387	6804 654961	TATYANA KULIKOVA	{"email": "t-kulikova_1965@postgrespro.ru", "phone": "+70091088708"}
0005433681864	1C763B	6341 823201	ALEKSEY KONOVALOV	{"email": "konovalov.a.011980@postgrespro.ru", "phone": "+70154843375"}
0005433681865	B3E64A	6932 558775	LYUBOV ZAYCEVA	{"phone": "+70874371775"}
0005433681866	54C028	6172 418557	VERA PETROVA	{"phone": "+70168156821"}
0005433681867	E1453F	7930 758260	MARINA GAVRILOVA	{"phone": "+70419718779"}
0005433681868	E1453F	2000 396386	LARISA VLASOVA	{"email": "larisavlasova.03061989@postgrespro.ru", "phone": "+70205161348"}
0005433681869	5B9E5E	2977 157446	ANTONINA EFIMOVA	{"email": "antonina-efimova-27011975@postgrespro.ru", "phone": "+70876196906"}
0005433681870	DBAB2D	8233 011735	ALEKSEY KRASNOV	{"phone": "+70819332468"}
0005433681871	450AFF	1125 564700	ANTON ZAKHAROV	{"phone": "+70543248793"}
0005433681872	450AFF	1686 045794	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina011997@postgrespro.ru", "phone": "+70111049378"}
0005433681873	450AFF	3557 153590	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova.121967@postgrespro.ru", "phone": "+70521279789"}
0005433681874	5AF761	0861 471992	IGOR IVANOV	{"email": "igorivanov-1969@postgrespro.ru", "phone": "+70304383046"}
0005433681875	4B9589	9248 024572	YURIY EGOROV	{"phone": "+70669934062"}
0005433681876	4B9589	9889 816448	SERGEY SOROKIN	{"phone": "+70119773121"}
0005433681877	62BCCE	8370 551864	GENNADIY STEPANOV	{"phone": "+70562320246"}
0005433681878	3F9031	0691 115923	ALEKSEY MOISEEV	{"email": "moiseev.a_14081976@postgrespro.ru", "phone": "+70966377105"}
0005433681879	3F9031	7907 602035	ALEKSANDR ANDREEV	{"phone": "+70016796025"}
0005433681880	77FA3C	0907 612633	TAMARA KUZMINA	{"phone": "+70631967296"}
0005433681881	785969	2550 734114	ANATOLIY CHERNOV	{"email": "anatoliy_chernov.081979@postgrespro.ru", "phone": "+70660666660"}
0005433681882	785969	0053 465801	ANATOLIY MIRONOV	{"phone": "+70261149276"}
0005433681883	C52265	3186 025178	RAISA POPOVA	{"phone": "+70548970388"}
0005433681884	E409ED	0535 550544	YANA GERASIMOVA	{"email": "gerasimova.y_021966@postgrespro.ru", "phone": "+70917592840"}
0005433681885	E409ED	6967 848886	SVETLANA AFANASEVA	{"phone": "+70503273675"}
0005433681886	AA9D0C	6998 272507	TATYANA KAZAKOVA	{"phone": "+70983233750"}
0005433681887	9BAE39	2376 713375	PAVEL STEPANOV	{"phone": "+70526165901"}
0005433681888	BEF82C	3722 884262	ANASTASIYA NAZAROVA	{"phone": "+70351113562"}
0005433681889	BEF82C	5619 415549	ROMAN GORBUNOV	{"email": "romangorbunov_10011975@postgrespro.ru", "phone": "+70998860155"}
0005433681890	9E32B8	7441 846177	OLGA FROLOVA	{"phone": "+70819206703"}
0005433681891	9E32B8	3960 846228	GALINA BELYAEVA	{"email": "belyaeva-galina-051977@postgrespro.ru", "phone": "+70174063750"}
0005433681892	0E27C0	5019 226782	VYACHESLAV SOKOLOV	{"phone": "+70738923195"}
0005433681893	523AF1	0926 422334	ALEKSANDR PETROV	{"email": "a-petrov1972@postgrespro.ru", "phone": "+70972423710"}
0005433681894	523AF1	5067 390532	LYUBOV TARASOVA	{"email": "lyubov-tarasova_06051971@postgrespro.ru", "phone": "+70537237345"}
0005433681895	C9DC88	5537 276561	TATYANA KONOVALOVA	{"email": "tatyanakonovalova.1969@postgrespro.ru", "phone": "+70678254312"}
0005433681896	EA2841	6229 797509	INESSA PETROVA	{"phone": "+70406617568"}
0005433681897	EA2841	0052 148418	ALEKSANDRA ILINA	{"email": "ailina_1969@postgrespro.ru", "phone": "+70870926624"}
0005433681898	50A7AA	2384 416536	GALINA ZAKHAROVA	{"email": "g_zakharova-041974@postgrespro.ru", "phone": "+70357393485"}
0005433681899	50A7AA	4421 154981	ANDREY TIKHONOV	{"phone": "+70144319192"}
0005433681900	50A7AA	2470 752332	OLGA NIKOLAEVA	{"phone": "+70324065837"}
0005433681901	40EA4D	2162 970511	EVGENIY BELOV	{"email": "ebelov-09121964@postgrespro.ru", "phone": "+70359677557"}
0005433681902	E2F807	5892 082078	ALEKSANDR ANDREEV	{"phone": "+70263563873"}
0005433681903	E2F807	3608 193645	LYUDMILA NIKOLAEVA	{"phone": "+70730770829"}
0005433681904	2C8ED9	3563 885224	IRINA BORISOVA	{"email": "borisova.irina.08081978@postgrespro.ru", "phone": "+70065542682"}
0005433681905	2C8ED9	8075 947064	OLGA ANDREEVA	{"email": "oandreeva-19071979@postgrespro.ru", "phone": "+70532639494"}
0005433681906	F02133	5303 351084	SVETLANA IVANOVA	{"email": "svetlanaivanova_041983@postgrespro.ru", "phone": "+70997825647"}
0005433681907	F02133	4240 335773	SERGEY KOROLEV	{"email": "sergeykorolev1966@postgrespro.ru", "phone": "+70523875555"}
0005433681908	969477	9436 768171	KSENIYA GRISHINA	{"phone": "+70231749694"}
0005433681909	5F1D57	7051 064409	KRISTINA KISELEVA	{"email": "kiselevakristina-1974@postgrespro.ru", "phone": "+70307868991"}
0005433681910	728DCE	0994 097993	VALERIY BORISOV	{"phone": "+70832741452"}
0005433681911	05C5F9	2815 479082	NIKITA RODIONOV	{"email": "nikitarodionov-09061974@postgrespro.ru", "phone": "+70158154859"}
0005433681912	33A61E	0392 260563	ANASTASIYA TARASOVA	{"phone": "+70377718277"}
0005433681913	33A61E	5306 509974	NATALYA LAZAREVA	{"email": "lazareva.n.1962@postgrespro.ru", "phone": "+70880533206"}
0005433681914	7CE4F9	1499 223267	VLADIMIR KUZNECOV	{"email": "kuznecov.v.16041976@postgrespro.ru", "phone": "+70781473246"}
0005433681915	7CE4F9	9624 571720	IRINA ORLOVA	{"email": "orlova-irina_04031970@postgrespro.ru", "phone": "+70493120861"}
0005433681916	6BFD7B	6353 396282	SERGEY SOLOVEV	{"email": "solovevsergey011961@postgrespro.ru", "phone": "+70065361867"}
0005433681917	6BFD7B	5787 829533	MATVEY ABRAMOV	{"email": "mabramov.16081969@postgrespro.ru", "phone": "+70865616276"}
0005433681918	E43903	7376 467512	DMITRIY GERASIMOV	{"email": "d-gerasimov-081982@postgrespro.ru", "phone": "+70836755435"}
0005433681919	A1748D	6419 934485	ROZA EGOROVA	{"email": "egorova_r_1973@postgrespro.ru", "phone": "+70991880450"}
0005433681920	2525EE	4885 956943	VYACHESLAV SIDOROV	{"phone": "+70993698654"}
0005433681921	2525EE	6029 519479	ANNA SAVELEVA	{"email": "anna-saveleva.1966@postgrespro.ru", "phone": "+70350208441"}
0005433681922	FB4103	6749 590940	RAISA PETROVA	{"email": "petrova_r071970@postgrespro.ru", "phone": "+70058204718"}
0005433681923	A9471C	3225 853919	SERGEY KRASNOV	{"phone": "+70252071479"}
0005433681924	B656A5	6975 056251	IRINA KISELEVA	{"phone": "+70698446242"}
0005433681925	012466	2965 469960	VASILIY MOROZOV	{"email": "morozovvasiliy-1970@postgrespro.ru", "phone": "+70984600121"}
0005433681926	94E6E9	5945 516022	YAROSLAV KUZNECOV	{"phone": "+70143106495"}
0005433681927	3EB8FC	0829 885406	EKATERINA NIKOLAEVA	{"phone": "+70173448129"}
0005433681928	F52A7F	7730 205648	NIKOLAY FEDOTOV	{"email": "fedotov_n-041976@postgrespro.ru", "phone": "+70075898467"}
0005433681929	0BE2F8	4980 992522	SERGEY GORBUNOV	{"phone": "+70923031715"}
0005433681930	0BE2F8	2386 252478	YULIYA MASLOVA	{"phone": "+70459347416"}
0005433681931	290347	0765 342701	ALSU BELOVA	{"email": "belova-a-1967@postgrespro.ru", "phone": "+70008088103"}
0005433681932	290347	7045 694054	ALEKSANDR ZAYCEV	{"phone": "+70562925312"}
0005433681933	FC5162	7280 437240	ALEKSANDR OSIPOV	{"phone": "+70232640644"}
0005433681934	FC5162	3981 744254	MARINA KOZLOVA	{"phone": "+70540242776"}
0005433681935	FC5162	5062 414212	IRINA LEBEDEVA	{"email": "lebedeva.irina-1974@postgrespro.ru", "phone": "+70702181550"}
0005433681936	D3B218	3937 812135	ELENA PAVLOVA	{"phone": "+70787092173"}
0005433681937	D3B218	0878 747901	DMITRIY ROMANOV	{"email": "dmitriy.romanov-27121977@postgrespro.ru", "phone": "+70338537706"}
0005433681938	4C78CD	5340 129773	YURIY NIKITIN	{"email": "yuriy_nikitin031977@postgrespro.ru", "phone": "+70279386917"}
0005433681939	4C78CD	8218 699082	GALINA IVANOVA	{"email": "ivanova.galina_011983@postgrespro.ru", "phone": "+70619441318"}
0005433681940	4C78CD	1347 340953	DARYA LAZAREVA	{"email": "daryalazareva1974@postgrespro.ru", "phone": "+70805313999"}
0005433681941	275B1C	9409 057065	ELENA IVANOVA	{"email": "ivanova.elena.1964@postgrespro.ru", "phone": "+70234870072"}
0005433681942	275B1C	7463 101368	IVAN KISELEV	{"email": "i-kiselev.1981@postgrespro.ru", "phone": "+70962320991"}
0005433681943	C5A924	8013 686811	MAKSIM KULIKOV	{"phone": "+70745945711"}
0005433681944	8D0F0E	8051 745763	MAKSIM DAVYDOV	{"email": "davydovmaksim-17071971@postgrespro.ru", "phone": "+70531280345"}
0005433681945	7DE69F	0162 813537	ALEKSANDR ABRAMOV	{"phone": "+70212449188"}
0005433681946	609E6E	1191 564758	ASIYA ANDREEVA	{"phone": "+70185910459"}
0005433681947	B887D2	0175 259473	OLEG OSIPOV	{"email": "osipov_o-1976@postgrespro.ru", "phone": "+70355378426"}
0005433681948	B887D2	1425 006983	VIKTOR SMIRNOV	{"phone": "+70972075707"}
0005433681949	CCB4F6	1264 810855	RAFIK NIKOLAEV	{"phone": "+70942704721"}
0005433681950	CD0083	1815 064553	LYUDMILA KRASNOVA	{"email": "krasnoval-1972@postgrespro.ru", "phone": "+70843364052"}
0005433681951	9BE80A	5923 719048	VIKTOR SERGEEV	{"email": "sergeev-viktor.1969@postgrespro.ru", "phone": "+70963168053"}
0005433681952	812720	5364 248022	NIKOLAY MELNIKOV	{"phone": "+70268531639"}
0005433681953	3E70C2	2802 042079	KONSTANTIN FEDOROV	{"phone": "+70274115056"}
0005433681954	3E70C2	7962 404627	LYUDMILA SIDOROVA	{"email": "lyudmila-sidorova-1978@postgrespro.ru", "phone": "+70779483205"}
0005433681955	64BC48	8163 060320	YURIY ALEKSEEV	{"email": "alekseev.y_1969@postgrespro.ru", "phone": "+70641019544"}
0005433681956	2FAD2A	1043 025422	ALEKSANDR KOROLEV	{"phone": "+70227567482"}
0005433681957	A9A00B	0085 397128	MIKHAIL ZAYCEV	{"phone": "+70859530605"}
0005433681958	A9A00B	9350 820158	VIKTOR KARPOV	{"phone": "+70627241862"}
0005433681959	854748	7493 292643	IRINA FROLOVA	{"phone": "+70137821863"}
0005433681960	854748	7344 424334	STEPAN KOZLOV	{"phone": "+70419087624"}
0005433681961	854748	7518 526491	ALEKSANDR FEDOTOV	{"phone": "+70596278651"}
0005433681962	E5DE79	5084 415948	VIKTOR VOLKOV	{"phone": "+70666547875"}
0005433681963	D55E50	0074 929948	SEMEN ROMANOV	{"phone": "+70627937810"}
0005433681964	F95C58	5672 204494	LYUDMILA LOGINOVA	{"phone": "+70753217723"}
0005433681965	4EA2FB	2297 596512	OLEG PAVLOV	{"email": "pavlov.o_07051976@postgrespro.ru", "phone": "+70648503835"}
0005433681966	0FEB25	9942 647701	OLGA GORBUNOVA	{"phone": "+70609863003"}
0005433681967	7F4DA9	1724 908311	VLADIMIR ZAKHAROV	{"phone": "+70097810774"}
0005433681968	7ED5A3	6299 834967	POLINA ERMAKOVA	{"email": "ermakova-polina_1968@postgrespro.ru", "phone": "+70904383379"}
0005433681969	7ED5A3	4848 096598	GALINA ZHUKOVA	{"phone": "+70149293460"}
0005433681970	F0310D	2374 954036	EKATERINA ANISIMOVA	{"email": "anisimova_e-1977@postgrespro.ru", "phone": "+70925107688"}
0005433681971	F0310D	3888 079545	MARIYA ANDREEVA	{"phone": "+70672227983"}
0005433681972	0F009D	5165 978817	KONSTANTIN ILIN	{"email": "kilin.061975@postgrespro.ru", "phone": "+70484589653"}
0005433681973	50CA60	7626 658273	NIKITA NAUMOV	{"phone": "+70406202364"}
0005433681974	7197DB	6396 048349	ELENA TIKHONOVA	{"email": "tikhonova.elena-081972@postgrespro.ru", "phone": "+70285769536"}
0005433681975	B2D1E0	9106 079495	VASILIY MOROZOV	{"email": "v-morozov-1955@postgrespro.ru", "phone": "+70069905826"}
0005433681976	B2D1E0	5327 587118	NATALYA DAVYDOVA	{"email": "davydovan24101970@postgrespro.ru", "phone": "+70864361469"}
0005433681977	3CD4EE	2522 086844	ELENA ALEKSANDROVA	{"email": "e-aleksandrova-12071967@postgrespro.ru", "phone": "+70170000842"}
0005433681978	FA196E	3210 591256	ANDREY PETROV	{"email": "a_petrov.1975@postgrespro.ru", "phone": "+70054493737"}
0005433681979	FA196E	4360 597427	YURIY TIKHONOV	{"email": "yuriytikhonov.1970@postgrespro.ru", "phone": "+70517258115"}
0005433683290	8E5314	0489 794288	VIKTOR FROLOV	{"email": "frolov-v21101973@postgrespro.ru", "phone": "+70411010153"}
0005433683291	8E5314	8126 916801	SVETLANA NOVIKOVA	{"email": "svetlana_novikova-1963@postgrespro.ru", "phone": "+70895378723"}
0005433683292	F1A819	0992 116164	VIOLETTA IVANOVA	{"email": "ivanova.v-05061965@postgrespro.ru", "phone": "+70064497109"}
0005433683293	F1A819	1944 104953	ARTEM NIKITIN	{"email": "artem_nikitin-1975@postgrespro.ru", "phone": "+70986042246"}
0005433683294	AF1F5B	4002 307812	VALERIY ANTONOV	{"email": "antonov_valeriy-1978@postgrespro.ru", "phone": "+70220969973"}
0005433683295	FC9A8A	4130 071955	TATYANA SEMENOVA	{"email": "tatyanasemenova-1978@postgrespro.ru", "phone": "+70879833860"}
0005433683296	FC9A8A	6164 868732	NATALYA MATVEEVA	{"email": "n.matveeva.101974@postgrespro.ru", "phone": "+70242020739"}
0005433683297	ECF8B2	2216 311905	RUFIYA NAUMOVA	{"email": "naumova.rufiya1973@postgrespro.ru", "phone": "+70224216016"}
0005433683298	F90F03	5770 018915	VIOLETTA KONOVALOVA	{"email": "konovalovavioletta_091970@postgrespro.ru", "phone": "+70402743308"}
0005433683299	F90F03	1217 992584	SERGEY PAVLOV	{"phone": "+70360716592"}
0005433683300	7F65D8	5198 305113	ALEKSANDR BONDARENKO	{"email": "a_bondarenko_18011979@postgrespro.ru", "phone": "+70032910679"}
0005433683301	B1EC3C	9471 295940	DMITRIY ORLOV	{"phone": "+70485658708"}
0005433683302	DC760A	4376 575617	VIOLETTA NAZAROVA	{"phone": "+70450313372"}
0005433683303	A515B0	6029 369225	MARIYA FEDOROVA	{"phone": "+70815576521"}
0005433683304	A515B0	0629 468832	MIKHAIL MOISEEV	{"email": "m-moiseev-1966@postgrespro.ru", "phone": "+70053699468"}
0005433683305	A1B6A9	5265 667285	IVAN KUZNECOV	{"phone": "+70037840175"}
0005433683306	A1B6A9	3669 992996	OLEG ABRAMOV	{"phone": "+70232108322"}
0005433683307	52044A	4166 636583	NINA YAKOVLEVA	{"email": "yakovleva-n_08011971@postgrespro.ru", "phone": "+70317157902"}
0005433683308	1180C5	6867 760132	ALINA KAZAKOVA	{"email": "kazakovaalina-30031972@postgrespro.ru", "phone": "+70792204043"}
0005433683309	1180C5	9247 964749	NADEZHDA MOISEEVA	{"email": "moiseeva-nadezhda091960@postgrespro.ru", "phone": "+70547545933"}
0005433683310	1180C5	0501 312122	TATYANA EGOROVA	{"phone": "+70627739809"}
0005433683311	41E532	3275 557962	VALERIY MIKHAYLOV	{"phone": "+70527904266"}
0005433683312	7753FC	8141 759957	MIKHAIL KARPOV	{"email": "karpov.mikhail-081976@postgrespro.ru", "phone": "+70378651647"}
0005433683313	024170	4996 281647	OLGA KOVALEVA	{"email": "kovaleva.o_091975@postgrespro.ru", "phone": "+70683730188"}
0005433683314	5F8BB2	6457 421267	DMITRIY PETROV	{"phone": "+70474448541"}
0005433683315	964A13	0587 729192	VALENTINA BELOVA	{"phone": "+70300359489"}
0005433683316	FEDFCD	3090 599778	SVETLANA BORISOVA	{"phone": "+70149765875"}
0005433683317	7A3CA2	2352 538187	SOFIYA KOZLOVA	{"email": "sofiya_kozlova.101963@postgrespro.ru", "phone": "+70895340761"}
0005433683318	2A5163	7721 464003	DMITRIY FROLOV	{"email": "dfrolov.1981@postgrespro.ru", "phone": "+70483113203"}
0005433683319	40E0DB	5110 134142	NIKOLAY NOVIKOV	{"email": "nikolay.novikov1979@postgrespro.ru", "phone": "+70396263790"}
0005433683320	72D1A8	2464 871548	GALINA KUZNECOVA	{"phone": "+70091035080"}
0005433683321	72D1A8	0971 360776	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr.011980@postgrespro.ru", "phone": "+70490788461"}
0005433683322	C7A411	2854 062225	ANTONINA KUZNECOVA	{"phone": "+70580379753"}
0005433683323	02755D	2766 855066	YURIY TIMOFEEV	{"phone": "+70323337123"}
0005433683324	536243	9686 370322	DANIIL EGOROV	{"email": "d-egorov10111971@postgrespro.ru", "phone": "+70474805878"}
0005433683325	536243	7349 708678	IVAN ABRAMOV	{"email": "abramov.ivan_101971@postgrespro.ru", "phone": "+70671748709"}
0005433683326	536243	2835 957927	NADEZHDA SEMENOVA	{"email": "semenova_nadezhda021967@postgrespro.ru", "phone": "+70988998099"}
0005433683327	2ADD40	4678 721643	ANDREY CHERNOV	{"phone": "+70366392204"}
0005433683328	7ED335	7549 768718	ALEKSEY VASILEV	{"email": "vasilev.aleksey031972@postgrespro.ru", "phone": "+70486801131"}
0005433683329	5B117B	6142 898948	EKATERINA ZAKHAROVA	{"phone": "+70033198111"}
0005433683330	C2D8B9	7603 273196	VIKTOR KARPOV	{"phone": "+70411951972"}
0005433683331	C2D8B9	2109 069780	VERONIKA RYABOVA	{"phone": "+70004746854"}
0005433683332	B5609D	3415 085485	VLADIMIR DENISOV	{"email": "v.denisov.1972@postgrespro.ru", "phone": "+70194077260"}
0005433683333	68AD61	3136 452744	ELENA VLASOVA	{"phone": "+70003391486"}
0005433683334	753391	9365 158710	ANDREY ZAYCEV	{"phone": "+70285308266"}
0005433683335	D30FC2	0543 305459	ALEKSEY DENISOV	{"email": "denisov_aleksey_021971@postgrespro.ru", "phone": "+70233277412"}
0005433683336	B9255A	4783 945207	BORIS POPOV	{"phone": "+70419916537"}
0005433683338	5BEC36	3857 479402	KARINA KOLESNIKOVA	{"email": "karina-kolesnikova09041970@postgrespro.ru", "phone": "+70963938931"}
0005433683339	5BEC36	6631 706419	SVETLANA VASILEVA	{"phone": "+70649486176"}
0005433683340	5BEC36	0224 084248	NIKOLAY FROLOV	{"email": "frolov.nikolay.071973@postgrespro.ru", "phone": "+70600610524"}
0005433683341	E836A0	4586 715125	ELENA KOZLOVA	{"email": "e-kozlova-02011980@postgrespro.ru", "phone": "+70008289220"}
0005433683342	2E6EE4	8440 204271	MARGARITA ANDREEVA	{"email": "andreevam30071967@postgrespro.ru", "phone": "+70061287720"}
0005433683343	9608F9	6586 168381	DENIS ZAKHAROV	{"email": "zakharov.denis.30061973@postgrespro.ru", "phone": "+70702695278"}
0005433683344	9608F9	1211 795747	ROZA IVANOVA	{"phone": "+70951216995"}
0005433683345	9608F9	8720 750323	ARTEMIY KUZNECOV	{"phone": "+70839176144"}
0005433683346	148FA4	1454 140802	LYUBOV FEDOROVA	{"phone": "+70437783034"}
0005433683347	148FA4	3641 194301	YULIYA SOLOVEVA	{"phone": "+70073259176"}
0005433683348	8497B9	3283 082267	ANNA TIKHONOVA	{"email": "a.tikhonova.111964@postgrespro.ru", "phone": "+70213681496"}
0005433683349	7E3D36	7165 198532	MAKSIM ZAYCEV	{"phone": "+70115348061"}
0005433683350	DB6116	5453 262906	LYUBOV KOMAROVA	{"phone": "+70856441287"}
0005433683351	DB6116	8175 440152	SVETLANA ALEKSEEVA	{"email": "alekseeva_s.19121974@postgrespro.ru", "phone": "+70058652912"}
0005433683352	5B6B46	2053 980384	VALERIY VASILEV	{"email": "vasilev-v_04111974@postgrespro.ru", "phone": "+70968421711"}
0005433683353	10B56E	2263 899322	IRINA KOROLEVA	{"phone": "+70086993283"}
0005433683354	A759AE	9375 291509	ANASTASIYA SOLOVEVA	{"email": "asoloveva1966@postgrespro.ru", "phone": "+70443839649"}
0005433683355	25AAF7	1580 644733	ALEKSANDR VOROBEV	{"phone": "+70870364753"}
0005433683356	25AAF7	7111 053206	MARIYA ZHUKOVA	{"email": "mariya_zhukova.1973@postgrespro.ru", "phone": "+70668272653"}
0005433683357	573B23	9107 091178	ARKADIY IVANOV	{"phone": "+70858356874"}
0005433683358	573B23	0163 652893	NATALYA KRASNOVA	{"phone": "+70380419780"}
0005433683359	B60F34	3648 039281	DMITRIY MIRONOV	{"email": "d-mironov061963@postgrespro.ru", "phone": "+70722680521"}
0005433683360	E3EA9B	1355 933308	DARYA DAVYDOVA	{"email": "d-davydova19121964@postgrespro.ru", "phone": "+70222715648"}
0005433683361	6B6B64	8588 841620	LYUBOV KARPOVA	{"email": "karpova_l-08051969@postgrespro.ru", "phone": "+70639264790"}
0005433683362	6B6B64	2649 347991	VIKTOR IVANOV	{"email": "viktor_ivanov121981@postgrespro.ru", "phone": "+70217349857"}
0005433683363	6B6B64	3842 033858	DENIS BELOV	{"phone": "+70178913376"}
0005433683364	04FDC8	0283 976781	VLADIMIR GORBUNOV	{"phone": "+70241184165"}
0005433683365	04FDC8	3848 400621	TAMARA BELOVA	{"phone": "+70036667287"}
0005433683366	299006	3385 707525	GLEB NAZAROV	{"email": "nazarov-g021971@postgrespro.ru", "phone": "+70322191930"}
0005433683367	299006	1005 465826	TATYANA PETROVA	{"phone": "+70099687270"}
0005433683368	5EF4E2	0927 557929	VSEVOLOD POPOV	{"email": "popov_v_061963@postgrespro.ru", "phone": "+70691214885"}
0005433683369	5EF4E2	5721 970903	ALEKSANDRA FEDOROVA	{"phone": "+70501847104"}
0005433683370	5EF4E2	0366 277944	MARIYA BELOVA	{"phone": "+70352217011"}
0005433683371	6AD4B8	4490 998236	EVGENIY SERGEEV	{"phone": "+70409162499"}
0005433683372	FC2168	6247 136649	LEV STEPANOV	{"phone": "+70006089114"}
0005433683373	C227FF	8708 142269	VITALIY MIKHAYLOV	{"email": "mikhaylov.vitaliy1968@postgrespro.ru", "phone": "+70892680844"}
0005433683374	1AD92E	9284 330135	DENIS KOZLOV	{"phone": "+70506550193"}
0005433683375	EDFE04	7088 069278	VIKTORIYA OSIPOVA	{"email": "viktoriya.osipova_101966@postgrespro.ru", "phone": "+70399020791"}
0005433683376	EDFE04	1622 612843	SERGEY TARASOV	{"email": "tarasov-sergey121964@postgrespro.ru", "phone": "+70656504879"}
0005433683377	2CCAAB	0162 692665	DENIS KUZNECOV	{"phone": "+70559685233"}
0005433683378	2CCAAB	3675 195777	MIKHAIL MOROZOV	{"email": "m-morozov-121966@postgrespro.ru", "phone": "+70548396427"}
0005433683379	BC956C	4337 168534	DMITRIY ANTONOV	{"phone": "+70475722090"}
0005433683380	F23D27	5096 581176	ANNA KUZNECOVA	{"email": "a_kuznecova_061976@postgrespro.ru", "phone": "+70742205859"}
0005433683381	51FD02	8583 510252	LARISA VOROBEVA	{"email": "l.vorobeva_11061966@postgrespro.ru", "phone": "+70595717556"}
0005433683382	181CE5	8574 891471	ELENA FEDOROVA	{"email": "fedorova-elena-16081962@postgrespro.ru", "phone": "+70386167218"}
0005433683383	C0BADC	4855 121801	DMITRIY POPOV	{"email": "popov.dmitriy09121979@postgrespro.ru", "phone": "+70262330844"}
0005433683384	C0BADC	4906 728428	VERA VASILEVA	{"phone": "+70876833421"}
0005433683385	CADB8A	8742 451836	NINA MARTYNOVA	{"email": "martynovanina-011969@postgrespro.ru", "phone": "+70577750407"}
0005433683386	CADB8A	3419 576223	LILIYA SAVELEVA	{"phone": "+70340045542"}
0005433683387	ACCF98	3496 735980	ALEKSEY MATVEEV	{"phone": "+70563949130"}
0005433683388	24CF79	4792 701657	IVAN SEMENOV	{"phone": "+70052003227"}
0005433683389	1469FD	2176 093650	LYUDMILA LEBEDEVA	{"phone": "+70758931950"}
0005433683390	1469FD	4107 441943	VIKTOR MARTYNOV	{"email": "martynov-v1977@postgrespro.ru", "phone": "+70090774112"}
0005433683391	6C2F00	7629 474936	VALERIY SMIRNOV	{"phone": "+70066852855"}
0005433683392	6C2F00	2305 645633	MARIYA KUZMINA	{"phone": "+70625156180"}
0005433683393	BA2E95	2462 421899	LILIYA ABRAMOVA	{"phone": "+70022469502"}
0005433683394	926F40	5557 427219	SERGEY ALEKSANDROV	{"email": "aleksandrov.sergey_05071975@postgrespro.ru", "phone": "+70196480852"}
0005433683395	926F40	4345 329102	VLADIMIR DAVYDOV	{"phone": "+70270736310"}
0005433683396	3CACE3	7951 084085	ZARINA VOLKOVA	{"phone": "+70572272061"}
0005433683397	4944E2	3168 414727	ANATOLIY KISELEV	{"phone": "+70252022975"}
0005433683398	325BBE	6281 053354	MARIYA PAVLOVA	{"email": "pavlova_m06101963@postgrespro.ru", "phone": "+70697717172"}
0005433683399	325BBE	1250 150920	PETR ANDREEV	{"phone": "+70938533308"}
0005433683400	EA597B	9446 978545	MARAT SIDOROV	{"email": "marat_sidorov.31031969@postgrespro.ru", "phone": "+70615679328"}
0005433683401	C1FBD3	9232 694868	ALEKSANDR KUZNECOV	{"email": "akuznecov27051974@postgrespro.ru", "phone": "+70187984721"}
0005433683402	0827BE	7490 712091	NADEZHDA NESTEROVA	{"email": "nesterovanadezhda.28111972@postgrespro.ru", "phone": "+70760553858"}
0005433683403	0827BE	8785 610505	ALEKSANDR FOMIN	{"email": "fomin-aleksandr-111990@postgrespro.ru", "phone": "+70668954718"}
0005433683404	F0A148	0227 860328	NIKOLAY KRASNOV	{"phone": "+70823947230"}
0005433683405	B97058	9946 901131	EKATERINA TROFIMOVA	{"email": "trofimova.ekaterina091971@postgrespro.ru", "phone": "+70035241759"}
0005433683406	B97058	4030 685744	VYACHESLAV MAKAROV	{"email": "v-makarov.26031967@postgrespro.ru", "phone": "+70917638835"}
0005433683407	DF3CC2	2973 935200	ILYA KOZLOV	{"phone": "+70942300741"}
0005433683408	3B5378	7373 451647	ROMAN ISAEV	{"phone": "+70861367002"}
0005433683409	DCCBB5	5642 413747	ANISA RYABOVA	{"email": "ryabova_a_31031971@postgrespro.ru", "phone": "+70607140332"}
0005433683410	7B7A49	8657 752255	VLADIMIR NIKOLAEV	{"email": "nikolaev-vladimir-1973@postgrespro.ru", "phone": "+70055927710"}
0005433683411	96D86C	5742 535620	EKATERINA GRISHINA	{"email": "e_grishina_01021969@postgrespro.ru", "phone": "+70080523489"}
0005433683412	FD7511	3368 135640	PETR MAKSIMOV	{"phone": "+70519360437"}
0005433683413	FD7511	9372 181595	VLADIMIR VASILEV	{"phone": "+70129137035"}
0005433683414	2BF092	7189 053613	VLADIMIR SOLOVEV	{"email": "vladimirsolovev-121975@postgrespro.ru", "phone": "+70345029435"}
0005433683415	AE5EBA	9680 235181	NIKOLAY KISELEV	{"phone": "+70383188119"}
0005433683416	AE5EBA	3823 836635	VALERIY STEPANOV	{"email": "v_stepanov.061969@postgrespro.ru", "phone": "+70809384351"}
0005433683417	73204F	3531 857631	EKATERINA FOMINA	{"phone": "+70959675747"}
0005433683418	73204F	6482 041745	EVGENIY CHERNOV	{"email": "chernov_e.21021978@postgrespro.ru", "phone": "+70414179125"}
0005433684384	18E43D	9005 752722	PAVEL SERGEEV	{"email": "sergeev-p_1966@postgrespro.ru", "phone": "+70563910269"}
0005433684385	D8DE1F	0017 173886	NADEZHDA MOROZOVA	{"email": "n.morozova-061965@postgrespro.ru", "phone": "+70092286725"}
0005433684386	A84580	1446 522776	ALLA SMIRNOVA	{"email": "asmirnova_081965@postgrespro.ru", "phone": "+70626534197"}
0005433684387	0E352D	8438 391668	ANTON FEDOROV	{"email": "a-fedorov-1967@postgrespro.ru", "phone": "+70382545466"}
0005433684388	0E352D	1469 829449	VYACHESLAV SOKOLOV	{"phone": "+70689318136"}
0005433684389	7AC910	9462 680672	ELENA VOLKOVA	{"phone": "+70026348869"}
0005433684390	E3C35E	2403 723184	ANASTASIYA DMITRIEVA	{"email": "a.dmitrieva_1978@postgrespro.ru", "phone": "+70486991514"}
0005433684391	0BEB19	7630 021604	TATYANA KOVALEVA	{"email": "tkovaleva.18121984@postgrespro.ru", "phone": "+70079658030"}
0005433684392	A184AD	7937 374549	IVAN PAVLOV	{"email": "pavlov_ivan.1972@postgrespro.ru", "phone": "+70331163593"}
0005433684393	B35FCD	8729 725146	VIKTOR POPOV	{"phone": "+70965719068"}
0005433684394	5B7880	9934 852209	OKSANA PETROVA	{"phone": "+70164160062"}
0005433684395	4E50DE	4694 752763	DMITRIY NOVIKOV	{"email": "novikov_dmitriy_01121977@postgrespro.ru", "phone": "+70696842866"}
0005433684396	4E50DE	9545 904385	OLGA KOZLOVA	{"email": "kozlova_o.101975@postgrespro.ru", "phone": "+70487722437"}
0005433684397	6F4DE6	0824 092508	OLGA TITOVA	{"email": "titova-olga.041975@postgrespro.ru", "phone": "+70148470948"}
0005433684398	6F4DE6	0354 841451	TATYANA KOVALEVA	{"email": "kovaleva_tatyana-11091976@postgrespro.ru", "phone": "+70079176494"}
0005433684399	0AF39B	0901 110082	TAMARA IVANOVA	{"email": "tamara.ivanova_1962@postgrespro.ru", "phone": "+70313604586"}
0005433684400	B6E626	2445 968801	ALEKSANDR ILIN	{"email": "ailin.1977@postgrespro.ru", "phone": "+70939962677"}
0005433684401	BC10C2	7388 925549	EVDOKIYA FEDOROVA	{"phone": "+70581564936"}
0005433684402	BC10C2	6492 668285	NIKOLAY ANDREEV	{"email": "andreevnikolay.031964@postgrespro.ru", "phone": "+70344693178"}
0005433684403	724F8D	9108 732113	OLEG MIKHAYLOV	{"phone": "+70503969088"}
0005433684404	DD1D31	3525 384235	PAVEL VOROBEV	{"email": "p-vorobev-03031971@postgrespro.ru", "phone": "+70407860000"}
0005433684405	DD1D31	5982 753628	SVETLANA PAVLOVA	{"phone": "+70188123641"}
0005433684406	DD6A8D	3104 620477	DANIIL IVANOV	{"phone": "+70006417811"}
0005433684407	3BF4B2	1370 081718	ALEKSANDR ANTONOV	{"email": "a.antonov1983@postgrespro.ru", "phone": "+70159849951"}
0005433684408	D1F16A	0430 593636	EVGENIY KOZLOV	{"email": "evgeniykozlov.1988@postgrespro.ru", "phone": "+70057407381"}
0005433684409	D1F16A	3522 504178	NIKOLAY ABRAMOV	{"email": "abramov_n.1966@postgrespro.ru", "phone": "+70787905100"}
0005433684410	089AD0	4276 680340	TATYANA EGOROVA	{"phone": "+70830082976"}
0005433684411	B06F3E	1323 951664	VYACHESLAV CHERNOV	{"phone": "+70680989336"}
0005433684412	B06F3E	5887 703057	TATYANA KULIKOVA	{"email": "kulikovat.081985@postgrespro.ru", "phone": "+70925348810"}
0005433684413	EA1A06	2997 702540	IGOR KUDRYASHOV	{"email": "kudryashovigor051980@postgrespro.ru", "phone": "+70228843345"}
0005433684414	35EBCA	2003 994277	ELENA STEPANOVA	{"email": "elena.stepanova.1972@postgrespro.ru", "phone": "+70408091915"}
0005433684415	753297	6492 023562	IGNAT SEMENOV	{"email": "semenov_i-01111968@postgrespro.ru", "phone": "+70722244653"}
0005433684416	B469E9	9217 758341	KARINA POPOVA	{"email": "kpopova021966@postgrespro.ru", "phone": "+70242521715"}
0005433684417	71CE85	0472 974046	DMITRIY FEDOTOV	{"email": "fedotov-dmitriy_1956@postgrespro.ru", "phone": "+70042500672"}
0005433684418	71CE85	8681 626829	ROMAN FEDOROV	{"email": "r_fedorov1964@postgrespro.ru", "phone": "+70704325804"}
0005433684419	BEBC0A	5175 399976	ARTEMIY MOISEEV	{"email": "moiseev-artemiy_121978@postgrespro.ru", "phone": "+70664890974"}
0005433684420	BEBC0A	6962 862094	ROZA MOROZOVA	{"phone": "+70762453538"}
0005433684421	DA3C16	0058 565365	ALEKSEY IVANOV	{"phone": "+70513971394"}
0005433684481	50EEF5	0725 419401	STANISLAV VASILEV	{"phone": "+70820976597"}
0005433684422	BD2E39	0381 550198	KSENIYA VOLKOVA	{"email": "k-volkova_1970@postgrespro.ru", "phone": "+70116160995"}
0005433684423	A225E5	5953 371897	NATALYA VOROBEVA	{"email": "n-vorobeva.02081981@postgrespro.ru", "phone": "+70858459647"}
0005433684424	754CA3	8746 354070	YURIY KONOVALOV	{"phone": "+70315893732"}
0005433684425	FBB6B0	7243 667904	PAVEL KUZNECOV	{"phone": "+70275982656"}
0005433684426	FBB6B0	4230 169343	EGOR VASILEV	{"email": "vasilev.e.011966@postgrespro.ru", "phone": "+70710737970"}
0005433684427	7EB9C7	1515 570565	TAMARA SMIRNOVA	{"email": "t_smirnova-27051970@postgrespro.ru", "phone": "+70641149538"}
0005433684428	7EB9C7	5863 045001	VASILIY SIDOROV	{"email": "vasiliy-sidorov08081965@postgrespro.ru", "phone": "+70629894526"}
0005433684429	433BF6	7781 837558	VASILIY BORISOV	{"email": "borisovvasiliy1971@postgrespro.ru", "phone": "+70689100093"}
0005433684430	433BF6	8839 238373	GALINA MAKAROVA	{"email": "makarova.g.20091971@postgrespro.ru", "phone": "+70652529182"}
0005433684431	D06D60	9719 956982	LEONID SCHERBAKOV	{"phone": "+70177744345"}
0005433684432	3F17DA	9227 433885	VLADIMIR KRASNOV	{"phone": "+70296329531"}
0005433684433	AD59FE	2342 658611	ALEKSEY ILIN	{"email": "ailin_081981@postgrespro.ru", "phone": "+70817439427"}
0005433684434	197D04	1572 826451	YURIY FEDOTOV	{"phone": "+70289356082"}
0005433684435	1E799E	6406 132994	YULIYA SIDOROVA	{"phone": "+70612002831"}
0005433684436	53C705	4617 310318	VYACHESLAV ROMANOV	{"email": "romanov-v_30071960@postgrespro.ru", "phone": "+70417468168"}
0005433684437	53C705	5552 765498	ANASTASIYA BOGDANOVA	{"phone": "+70217478594"}
0005433684438	53C705	5702 051170	IRINA KISELEVA	{"email": "ikiseleva_101973@postgrespro.ru", "phone": "+70443025055"}
0005433684439	6B6707	4013 110120	OLEG KUZMIN	{"phone": "+70020223714"}
0005433684440	14ACEA	4925 026879	KLAVDIYA FADEEVA	{"email": "fadeeva_klavdiya-17081972@postgrespro.ru", "phone": "+70528844811"}
0005433684441	02EE23	3158 520298	VLADIMIR FOMIN	{"phone": "+70763963138"}
0005433684442	238901	1089 057893	ROMAN IVANOV	{"email": "ivanov-roman071972@postgrespro.ru", "phone": "+70973485653"}
0005433684443	AB48F2	6516 011080	IVAN PETROV	{"email": "ivan-petrov_051972@postgrespro.ru", "phone": "+70616061223"}
0005433684444	46BD44	4162 942720	ALISA GORBUNOVA	{"phone": "+70399274468"}
0005433684445	6E40AC	7684 235564	MARGARITA TIMOFEEVA	{"phone": "+70629975506"}
0005433684446	B57E26	4184 896465	EVGENIY BARANOV	{"phone": "+70530505851"}
0005433684447	00662A	5658 560206	PETR FEDOROV	{"email": "fedorovpetr.26011972@postgrespro.ru", "phone": "+70725711623"}
0005433684448	FC46DB	1499 347582	VLADIMIR IVANOV	{"email": "vladimir.ivanov_29031970@postgrespro.ru", "phone": "+70525544752"}
0005433684449	FC46DB	8224 146536	EKATERINA ZHUKOVA	{"phone": "+70990296549"}
0005433684450	E72AAF	4198 044418	ALFIYA KALININA	{"email": "kalininaalfiya.1972@postgrespro.ru", "phone": "+70039364239"}
0005433684451	98CB06	6851 244956	VLADIMIR SAVELEV	{"email": "savelev_vladimir021971@postgrespro.ru", "phone": "+70243903282"}
0005433684452	41DC01	6392 294413	VLADIMIR MIKHAYLOV	{"phone": "+70662235727"}
0005433684453	41DC01	1179 152802	EVGENIYA KOROLEVA	{"email": "evgeniyakoroleva15091953@postgrespro.ru", "phone": "+70961819448"}
0005433684454	A035CD	1844 984389	VYACHESLAV FROLOV	{"email": "frolovvyacheslav-1974@postgrespro.ru", "phone": "+70250665951"}
0005433684455	0D1291	1041 755469	ANNA POPOVA	{"phone": "+70634936362"}
0005433684456	0D1291	9906 841739	RAISA STEPANOVA	{"phone": "+70271037524"}
0005433684457	6EFCE3	7313 431912	NATALYA EFIMOVA	{"email": "efimova_n_1977@postgrespro.ru", "phone": "+70335799005"}
0005433684458	B42455	4799 285496	YULIYA VLASOVA	{"phone": "+70618668525"}
0005433684459	54E886	6931 155016	ALEKSANDR PETROV	{"email": "aleksandr_petrov1977@postgrespro.ru", "phone": "+70074523380"}
0005433684460	DE3C92	4162 485644	VLADISLAV BORISOV	{"phone": "+70129102681"}
0005433684461	DE3C92	6672 285675	KSENIYA GUSEVA	{"email": "guseva_kseniya1982@postgrespro.ru", "phone": "+70307653452"}
0005433684462	7950E5	8006 498797	ANTONINA SEMENOVA	{"email": "semenova.a_1958@postgrespro.ru", "phone": "+70961467095"}
0005433684463	A15602	5233 277741	SVETLANA ANDREEVA	{"email": "svetlana.andreeva.071965@postgrespro.ru", "phone": "+70619853667"}
0005433684464	C67651	8302 214021	ANDREY KUZMIN	{"email": "kuzmina.071980@postgrespro.ru", "phone": "+70415261957"}
0005433684465	C67651	8749 846236	SERGEY MIKHAYLOV	{"email": "s_mikhaylov_1978@postgrespro.ru", "phone": "+70574048730"}
0005433684466	D45BFB	0460 739552	LIDIYA EGOROVA	{"phone": "+70711363854"}
0005433684467	0C6DC3	1467 165867	VASILIY KOROLEV	{"email": "v_korolev-02011966@postgrespro.ru", "phone": "+70573892598"}
0005433684468	F38723	5527 888011	EKATERINA KUDRYASHOVA	{"email": "ekaterina-kudryashova051964@postgrespro.ru", "phone": "+70691307412"}
0005433684469	11E6E8	8044 041847	EVGENIY ANTONOV	{"email": "e-antonov_1970@postgrespro.ru", "phone": "+70891066391"}
0005433684470	11E6E8	7436 423076	NIKOLAY FEDOROV	{"email": "fedorov.n.02011968@postgrespro.ru", "phone": "+70873680276"}
0005433684471	0FB190	2519 607819	TATYANA NAUMOVA	{"email": "t-naumova.121978@postgrespro.ru", "phone": "+70808307459"}
0005433684472	0F9ECA	1752 895313	VLADIMIR PAVLOV	{"phone": "+70156699344"}
0005433684473	C921D6	4444 527935	PAVEL ZAKHAROV	{"phone": "+70134906356"}
0005433684474	E0A167	6221 788143	OLGA KUZNECOVA	{"email": "olga.kuznecova_22121978@postgrespro.ru", "phone": "+70123659928"}
0005433684475	E0A167	4546 237150	SVETLANA GAVRILOVA	{"phone": "+70745474591"}
0005433684476	E05F71	8752 838377	IVAN GAVRILOV	{"email": "i-gavrilov_27011973@postgrespro.ru", "phone": "+70057891159"}
0005433684477	219A9A	6323 391049	DMITRIY POPOV	{"email": "popov.d-1974@postgrespro.ru", "phone": "+70070678943"}
0005433684478	5461D7	2140 394442	VASILIY ZAYCEV	{"email": "vasiliy_zaycev1983@postgrespro.ru", "phone": "+70652019879"}
0005433684479	50EEF5	5299 525561	EVGENIY KUZMIN	{"phone": "+70477277181"}
0005433684480	50EEF5	5620 794320	VIKTOR PETROV	{"phone": "+70828958349"}
0005433684482	5439DA	9380 319163	PAVEL ROMANOV	{"phone": "+70071882892"}
0005433685504	64D832	4070 877451	KSENIYA KOROLEVA	{"phone": "+70024625180"}
0005433685491	60CCE9	7422 941275	ALEKSEY SIDOROV	{"email": "sidorov.aleksey071968@postgrespro.ru", "phone": "+70964154920"}
0005433685492	4FB217	3241 529738	MIKHAIL BORISOV	{"phone": "+70601505710"}
0005433685493	A06870	2068 103718	NIKOLAY NIKOLAEV	{"phone": "+70377094483"}
0005433685494	5922A2	5314 425666	YURIY NAUMOV	{"phone": "+70967287824"}
0005433685495	C725F6	7946 814323	VLADIMIR STEPANOV	{"phone": "+70493422225"}
0005433685496	C725F6	6791 860749	ALEKSEY IVANOV	{"email": "ivanov_a_101974@postgrespro.ru", "phone": "+70650615104"}
0005433685497	B5DFD2	0488 500091	RAISA ZHURAVLEVA	{"email": "zhuravleva.raisa_111979@postgrespro.ru", "phone": "+70629939427"}
0005433685498	8F3E05	1027 540748	NIKOLAY BONDARENKO	{"phone": "+70499104051"}
0005433685499	8F3E05	1719 212225	NINA IVANOVA	{"phone": "+70977543692"}
0005433685500	F15278	9283 332763	ALEKSANDR NIKITIN	{"phone": "+70283829071"}
0005433685501	7D796F	1966 596591	YURIY MEDVEDEV	{"email": "medvedevy1978@postgrespro.ru", "phone": "+70286353451"}
0005433685502	7D796F	8560 890767	ZINAIDA POPOVA	{"email": "popova_zinaida101966@postgrespro.ru", "phone": "+70280468928"}
0005433685503	64D832	8276 137910	NIKOLAY SAVELEV	{"email": "nikolay-savelev.031975@postgrespro.ru", "phone": "+70949277296"}
0005433685505	655974	9594 709517	ANASTASIYA SCHERBAKOVA	{"email": "scherbakova-anastasiya_27011974@postgrespro.ru", "phone": "+70913009976"}
0005433685506	655974	0971 336283	SERGEY POPOV	{"email": "s.popov031974@postgrespro.ru", "phone": "+70979758886"}
0005433685507	6A3D5C	3534 363361	ELIZAVETA BARANOVA	{"email": "elizaveta-baranova_23071964@postgrespro.ru", "phone": "+70711215863"}
0005433685508	6A3D5C	7223 534920	LYUDMILA KOLESNIKOVA	{"phone": "+70795447361"}
0005433685509	8CFF39	0602 854530	SVETLANA MAKAROVA	{"phone": "+70657237203"}
0005433685510	8CFF39	2398 644357	ROMAN ALEKSEEV	{"phone": "+70955748868"}
0005433685511	8CFF39	3081 675413	VLADISLAV SEMENOV	{"phone": "+70959658251"}
0005433685512	925AEA	7551 460115	KIRILL TIMOFEEV	{"email": "timofeevk-19041975@postgrespro.ru", "phone": "+70397910496"}
0005433685513	925AEA	8030 910742	GALINA SOROKINA	{"email": "sorokina_g111978@postgrespro.ru", "phone": "+70123532552"}
0005433685514	925AEA	5315 636434	VIKTOR ANDREEV	{"email": "viktorandreev1968@postgrespro.ru", "phone": "+70889076971"}
0005433685515	88169F	4126 151739	VITALIY SCHERBAKOV	{"email": "scherbakov-v.031974@postgrespro.ru", "phone": "+70343461405"}
0005433685516	88169F	0276 210953	ALEKSANDR DMITRIEV	{"phone": "+70844673984"}
0005433685517	C7789E	2768 159738	NIKOLAY MOISEEV	{"email": "n_moiseev_28031980@postgrespro.ru", "phone": "+70104358729"}
0005433685518	C7789E	1703 309042	ARTEM BORISOV	{"phone": "+70374427950"}
0005433685519	D87929	5838 165839	ANDREY MIRONOV	{"phone": "+70494446580"}
0005433685520	A50A1E	9983 275666	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr.031954@postgrespro.ru", "phone": "+70335348062"}
0005433685521	CD9DD0	2916 845140	ARTEM SHEVCHENKO	{"phone": "+70998077864"}
0005433685522	CD9DD0	7677 515424	ARTEM SOROKIN	{"email": "sorokin.artem_1975@postgrespro.ru", "phone": "+70968735452"}
0005433685523	CD9DD0	9900 858913	ALENA GRISHINA	{"email": "alena_grishina_1971@postgrespro.ru", "phone": "+70232259507"}
0005433685524	92A919	1880 308216	ANNA GAVRILOVA	{"phone": "+70544791964"}
0005433685525	386BE9	1784 556467	ALEKSANDR FEDOTOV	{"phone": "+70390405634"}
0005433685526	FEAEE4	0970 699099	ELENA NIKITINA	{"email": "nikitina-elena041974@postgrespro.ru", "phone": "+70991565215"}
0005433685527	A40C44	9421 782592	SERGEY STEPANOV	{"phone": "+70086752893"}
0005433685528	87CFE5	2823 112574	PETR ANDREEV	{"phone": "+70975534167"}
0005433685529	62368A	5455 772030	STEPAN PAVLOV	{"email": "stepan-pavlov.061975@postgrespro.ru", "phone": "+70412282793"}
0005433685530	62368A	4612 455350	TATYANA MEDVEDEVA	{"phone": "+70759523298"}
0005433685531	62368A	4933 458707	DANILA DENISOV	{"phone": "+70656712534"}
0005433685532	065131	2389 895690	MIKHAIL ZAKHAROV	{"phone": "+70468281751"}
0005433685533	065131	2150 903282	AMIR SEMENOV	{"email": "semenov_amir_1980@postgrespro.ru", "phone": "+70804814232"}
0005433685534	01A4CB	3018 268501	SOFYA ORLOVA	{"email": "sofya_orlova1969@postgrespro.ru", "phone": "+70408110189"}
0005433685535	F43775	6089 605694	VLADIMIR ZHURAVLEV	{"phone": "+70395958235"}
0005433685536	2021E0	2774 013884	NADEZHDA MAKSIMOVA	{"phone": "+70690418887"}
0005433685537	2021E0	4226 266974	SERGEY KUZMIN	{"phone": "+70190071532"}
0005433685538	CCADA6	6008 220352	SVETLANA EFREMOVA	{"email": "efremovasvetlana-05101973@postgrespro.ru", "phone": "+70610748668"}
0005433685539	B8EE98	2900 069272	NIKOLAY MAKAROV	{"phone": "+70122225617"}
0005433685540	37AB08	1379 743076	YURIY BELOV	{"phone": "+70739667872"}
0005433685541	8C5F8A	6010 260198	ALEKSANDR NAZAROV	{"phone": "+70308247869"}
0005433685542	8C5F8A	4520 164354	OLEG TARASOV	{"phone": "+70066189535"}
0005433685543	871BD9	7208 588535	ARTEM NIKOLAEV	{"email": "artem_nikolaev_1978@postgrespro.ru", "phone": "+70459767093"}
0005433685544	1DB973	9199 556599	VALENTIN BORISOV	{"email": "vborisov.121975@postgrespro.ru", "phone": "+70715668452"}
0005433685545	D1A2A6	6820 531677	MARGARITA BORISOVA	{"email": "borisovamargarita_12081964@postgrespro.ru", "phone": "+70815587838"}
0005433685546	6117A9	6489 916070	ZINAIDA EFIMOVA	{"phone": "+70998772994"}
0005433685547	6117A9	4402 897940	ELVIRA IVANOVA	{"email": "e.ivanova16101968@postgrespro.ru", "phone": "+70841707879"}
0005433685548	DD9468	6683 331233	ELENA ROMANOVA	{"phone": "+70995772166"}
0005433685549	DD9468	4622 106721	ANATOLIY VOROBEV	{"email": "avorobev-1971@postgrespro.ru", "phone": "+70059440210"}
0005433685550	065149	4419 196617	NIKITA KOZLOV	{"email": "kozlovn.1972@postgrespro.ru", "phone": "+70867871420"}
0005433685551	065149	7134 541385	VERA BELOVA	{"email": "vera_belova-031977@postgrespro.ru", "phone": "+70662507755"}
0005433685552	B99CBA	3743 258267	VASILIY MATVEEV	{"email": "matveevvasiliy101954@postgrespro.ru", "phone": "+70737061928"}
0005433685553	B99CBA	4451 665088	PETR GUSEV	{"email": "gusev_p091967@postgrespro.ru", "phone": "+70102495653"}
0005433685554	DAD7A0	1097 972796	ANNA LEBEDEVA	{"email": "lebedeva.a_051972@postgrespro.ru", "phone": "+70564367480"}
0005433685555	F37357	1442 076023	ELENA SOLOVEVA	{"email": "soloveva-elena_29011969@postgrespro.ru", "phone": "+70997776000"}
0005433685556	F37357	2153 377714	OLGA SOLOVEVA	{"phone": "+70459418310"}
0005433685557	7CDDAB	6445 953540	ALEKSANDRA ZAKHAROVA	{"email": "zakharova.aleksandra_091973@postgrespro.ru", "phone": "+70618891088"}
0005433685558	7CDDAB	8453 162090	MIKHAIL ISAEV	{"phone": "+70140726212"}
0005433685559	7CDDAB	3524 169418	ANDREY ORLOV	{"email": "orlov_andrey-081974@postgrespro.ru", "phone": "+70329519870"}
0005433685560	9E90A7	6711 713551	VIKTOR AFANASEV	{"email": "v_afanasev.031966@postgrespro.ru", "phone": "+70541783866"}
0005433685561	9E90A7	0109 393176	LEONID SCHERBAKOV	{"email": "scherbakov_leonid.021983@postgrespro.ru", "phone": "+70044130869"}
0005433685562	6177DC	2701 084008	OLGA BELYAEVA	{"email": "olga-belyaeva-091966@postgrespro.ru", "phone": "+70413675431"}
0005433685563	755ACF	6916 041342	ARTEM GUSEV	{"email": "gusev_artem-1977@postgrespro.ru", "phone": "+70032774041"}
0005433685564	755ACF	4659 682112	NIKOLAY FROLOV	{"email": "frolov.n091970@postgrespro.ru", "phone": "+70042762654"}
0005433685565	FE2929	6093 458866	ANNA IVANOVA	{"phone": "+70157924038"}
0005433685566	2E5BC0	1019 784683	IRINA DENISOVA	{"email": "irina_denisova-1977@postgrespro.ru", "phone": "+70820684792"}
0005433685567	894C13	0058 166246	ELENA ARKHIPOVA	{"email": "arkhipovae.25051970@postgrespro.ru", "phone": "+70687604130"}
0005433685568	894C13	3725 417627	ALEKSEY MIKHAYLOV	{"email": "amikhaylov06011974@postgrespro.ru", "phone": "+70668349840"}
0005433685569	894C13	0356 800714	ALEKSANDR MAKAROV	{"phone": "+70529969016"}
0005433685570	E3DFA8	0522 757981	ANNA GAVRILOVA	{"phone": "+70171317806"}
0005433685571	AF6203	0382 488748	NINA ABRAMOVA	{"phone": "+70662433501"}
0005433685572	AF6203	5731 148636	ALLA VOLKOVA	{"email": "a-volkova071966@postgrespro.ru", "phone": "+70161293753"}
0005433685573	2F28AB	9094 420122	TATYANA VOLKOVA	{"phone": "+70208776683"}
0005433685574	9996ED	8201 919524	PAVEL SERGEEV	{"phone": "+70755019143"}
0005433685575	0B8A38	9660 828646	ANTON GRIGOREV	{"email": "grigoreva-041970@postgrespro.ru", "phone": "+70206107616"}
0005433685576	0B8A38	3364 558143	VLADISLAV KONOVALOV	{"phone": "+70974103042"}
0005433685577	61085F	3136 510465	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_v_1964@postgrespro.ru", "phone": "+70783190917"}
0005433685578	106736	2118 707594	REGINA KONOVALOVA	{"email": "konovalova.r_12041958@postgrespro.ru", "phone": "+70073012908"}
0005433685579	D2D51A	7554 101789	VLADIMIR DENISOV	{"phone": "+70785456910"}
0005433685580	24339B	9331 271544	MARINA MAKAROVA	{"email": "makarovam.121976@postgrespro.ru", "phone": "+70896410105"}
0005433685581	7B9E97	9198 900718	OLEG KOROLEV	{"email": "okorolev-30081984@postgrespro.ru", "phone": "+70468989159"}
0005433685582	7B9E97	2645 059148	MARIYA NOVIKOVA	{"phone": "+70124803413"}
0005433685583	D5D44B	8478 749086	EVGENIYA ANTONOVA	{"email": "evgeniya.antonova1967@postgrespro.ru", "phone": "+70589403353"}
0005433685584	3309EA	2410 577897	SERGEY BORISOV	{"email": "borisovsergey_1965@postgrespro.ru", "phone": "+70950908517"}
0005433685585	3309EA	8348 571773	LYUDMILA MAKAROVA	{"phone": "+70721592930"}
0005433685586	3309EA	9750 368112	EVGENIY NIKOLAEV	{"phone": "+70715064993"}
0005433685587	03A200	7428 948392	OLGA PETROVA	{"email": "petrova.o_29121966@postgrespro.ru", "phone": "+70675931900"}
0005433685588	F8E598	3982 732832	EKATERINA EFIMOVA	{"phone": "+70157440134"}
0005433685589	F8E598	1353 615645	VADIM PAVLOV	{"phone": "+70167563595"}
0005433685590	22BD4C	7544 062870	NATALYA ZHURAVLEVA	{"phone": "+70283420850"}
0005433685591	F855D7	9776 269888	SVETLANA RODIONOVA	{"phone": "+70981118911"}
0005433685592	F855D7	8410 772596	OKSANA KARPOVA	{"email": "oksana-karpova_1970@postgrespro.ru", "phone": "+70143704913"}
0005433685593	2DD1DE	0515 314034	IRINA KUZNECOVA	{"phone": "+70072868960"}
0005433686696	89B549	3170 176408	ANNA FILATOVA	{"phone": "+70351804020"}
0005433686602	E668BA	4349 691261	TAISA ORLOVA	{"phone": "+70487943987"}
0005433686603	748052	0917 648823	VIKTOR MIKHAYLOV	{"email": "v_mikhaylov101965@postgrespro.ru", "phone": "+70761382839"}
0005433686604	A8FAE6	9489 716708	OLGA ALEKSEEVA	{"phone": "+70479051418"}
0005433686605	A8FAE6	2611 605357	NIKOLAY PETROV	{"email": "petrov_nikolay-061970@postgrespro.ru", "phone": "+70974408274"}
0005433686606	71AD4B	0768 222530	OLESYA KOROLEVA	{"email": "olesyakoroleva-11041965@postgrespro.ru", "phone": "+70290609028"}
0005433686607	71AD4B	2294 907722	MAKSIM GORBUNOV	{"email": "gorbunov.maksim1974@postgrespro.ru", "phone": "+70894267917"}
0005433686608	CD4AEF	8531 528993	EVGENIYA KOZLOVA	{"email": "kozlovaevgeniya_011975@postgrespro.ru", "phone": "+70454832460"}
0005433686609	E220E2	3418 945952	YANA POPOVA	{"phone": "+70719917965"}
0005433686610	1910A4	1819 422792	ALEKSANDR IVANOV	{"phone": "+70630111985"}
0005433686611	1910A4	5705 791963	VALERIY DENISOV	{"phone": "+70800198154"}
0005433686612	EF4718	8824 580711	ILDAR KUZNECOV	{"phone": "+70683872351"}
0005433686613	EF4718	2189 740247	DMITRIY GERASIMOV	{"email": "dgerasimov-09031979@postgrespro.ru", "phone": "+70552317239"}
0005433686614	F31855	4896 076514	ALEKSANDR ABRAMOV	{"email": "abramov-aleksandr071965@postgrespro.ru", "phone": "+70380640037"}
0005433686615	60E146	7923 053655	IVAN SERGEEV	{"email": "sergeev-ivan1983@postgrespro.ru", "phone": "+70839815054"}
0005433686616	3666BF	7381 647414	ALEKSEY SMIRNOV	{"phone": "+70150871117"}
0005433686617	BCC3B3	3414 886656	OLEG TARASOV	{"email": "otarasov-061973@postgrespro.ru", "phone": "+70252043066"}
0005433686618	208795	2591 809551	MIKHAIL SIDOROV	{"phone": "+70923617309"}
0005433686619	304FE4	4935 067470	ALEKSEY GRIGOREV	{"email": "grigorev-aleksey.1963@postgrespro.ru", "phone": "+70860702613"}
0005433686620	E16371	3088 454628	PETR TARASOV	{"phone": "+70096681602"}
0005433686621	FF3E9C	3887 211447	EVGENIY MOROZOV	{"email": "e.morozov_18061977@postgrespro.ru", "phone": "+70970509930"}
0005433686622	2B5616	3422 450735	TATYANA LAZAREVA	{"email": "tlazareva20011975@postgrespro.ru", "phone": "+70066155775"}
0005433686623	BCCC07	5337 295406	IRINA AFANASEVA	{"phone": "+70380529642"}
0005433686624	BCCC07	9343 759895	MARINA KUZNECOVA	{"phone": "+70565106949"}
0005433686625	B043A0	0501 662284	DARYA POTAPOVA	{"phone": "+70784215434"}
0005433686626	180C4A	8553 855163	NATALYA MELNIKOVA	{"phone": "+70343016866"}
0005433686627	D1992C	5649 949048	DANILA PAVLOV	{"email": "pavlovd-29121976@postgrespro.ru", "phone": "+70370204408"}
0005433686628	F1ACBB	8568 336579	LYUBOV NIKITINA	{"email": "lyubov_nikitina-03011982@postgrespro.ru", "phone": "+70047970342"}
0005433686629	240F05	5110 142755	VASILIY SOKOLOV	{"email": "v_sokolov-121972@postgrespro.ru", "phone": "+70576465367"}
0005433686630	240F05	3090 954127	VALENTINA TARASOVA	{"email": "valentina.tarasova.071968@postgrespro.ru", "phone": "+70097941058"}
0005433686631	2D5206	8387 661384	ANNA ROMANOVA	{"phone": "+70060491256"}
0005433686632	2D5206	3058 713457	OKSANA SIDOROVA	{"phone": "+70206570312"}
0005433686633	AFDA50	6372 722398	VITALIY PETROV	{"email": "vitaliy-petrov.051968@postgrespro.ru", "phone": "+70070411353"}
0005433686634	AFDA50	1622 528526	REGINA POPOVA	{"email": "regina-popova-031974@postgrespro.ru", "phone": "+70486879921"}
0005433686635	AFDA50	3980 999754	PELAGEYA KOROLEVA	{"email": "pelageyakoroleva021975@postgrespro.ru", "phone": "+70361250368"}
0005433686636	5BF84D	2174 352994	TAMARA NAZAROVA	{"phone": "+70197704126"}
0005433686637	5BF84D	2258 938236	VALENTINA ANISIMOVA	{"phone": "+70470635219"}
0005433686638	5BF84D	0852 699073	TATYANA GERASIMOVA	{"email": "tatyana_gerasimova_28031986@postgrespro.ru", "phone": "+70087655024"}
0005433686639	CE7C80	1611 050436	ALEKSANDR DENISOV	{"phone": "+70950054637"}
0005433686640	CE7C80	8400 017215	MARINA PAVLOVA	{"phone": "+70715681452"}
0005433686641	123C93	5106 880663	IRINA NESTEROVA	{"email": "irinanesterova_101982@postgrespro.ru", "phone": "+70972051245"}
0005433686642	123C93	7255 049233	RODION DMITRIEV	{"email": "r-dmitriev-1966@postgrespro.ru", "phone": "+70194341031"}
0005433686643	CEE06F	1465 639641	NADEZHDA ZHUKOVA	{"phone": "+70369581306"}
0005433686644	EE5A88	7981 774912	NATALYA VOLKOVA	{"email": "volkovanatalya12121974@postgrespro.ru", "phone": "+70386827776"}
0005433686645	EE5A88	2691 295945	VYACHESLAV ZAKHAROV	{"email": "vyacheslav.zakharov_121975@postgrespro.ru", "phone": "+70034614540"}
0005433686646	473278	5780 965114	ELENA MAKAROVA	{"phone": "+70162715380"}
0005433686647	959A69	1314 078721	VALERIY ROMANOV	{"phone": "+70341843449"}
0005433686648	959A69	8472 235265	GENNADIY OSIPOV	{"email": "gennadiy-osipov_061968@postgrespro.ru", "phone": "+70774496335"}
0005433686649	7CE8BB	0014 277793	ALEKSEY BORISOV	{"email": "borisov_aleksey_101970@postgrespro.ru", "phone": "+70092913301"}
0005433686650	DE339C	4354 636740	ALFIYA MAKSIMOVA	{"phone": "+70727180842"}
0005433686651	45F57B	6127 196128	LYUBOV ANTONOVA	{"phone": "+70478790694"}
0005433686652	810770	3357 680147	VASILIY SERGEEV	{"phone": "+70303547694"}
0005433686653	810770	0444 013878	LYUDMILA AFANASEVA	{"email": "l.afanaseva041977@postgrespro.ru", "phone": "+70572799318"}
0005433686654	810770	7263 546723	NINA MAKSIMOVA	{"email": "n_maksimova051978@postgrespro.ru", "phone": "+70667340890"}
0005433686655	BA2418	6369 432615	ALINA NOVIKOVA	{"email": "novikova_a_011983@postgrespro.ru", "phone": "+70511803950"}
0005433686656	BA2418	9515 833421	KSENIYA TIKHONOVA	{"phone": "+70829079193"}
0005433686657	BA2418	1487 752630	OLEG RODIONOV	{"phone": "+70511429961"}
0005433686658	4E398E	4827 702899	ANASTASIYA BORISOVA	{"phone": "+70198766059"}
0005433686659	4E398E	5373 636604	RAISA FEDOROVA	{"email": "rfedorova.1975@postgrespro.ru", "phone": "+70680277970"}
0005433686660	909353	1077 653757	IGOR VASILEV	{"email": "igor_vasilev071971@postgrespro.ru", "phone": "+70190827674"}
0005433686661	B34927	6349 169765	EVGENIYA ALEKSEEVA	{"email": "alekseeva-e_05031996@postgrespro.ru", "phone": "+70638740918"}
0005433686662	3815E0	1101 512107	DMITRIY FEDOTOV	{"phone": "+70408323571"}
0005433686663	37D92A	0167 896823	TATYANA ALEKSEEVA	{"email": "alekseeva_tatyana-10081967@postgrespro.ru", "phone": "+70898787618"}
0005433686664	81E56C	0257 651491	ANATOLIY KRASNOV	{"phone": "+70081247060"}
0005433686665	81E56C	7348 501719	GRIGORIY SEMENOV	{"phone": "+70884195628"}
0005433686666	342AD9	4013 438466	IRINA LUKYANOVA	{"phone": "+70736233197"}
0005433686667	342AD9	5445 839840	MARIYA MIRONOVA	{"email": "mironova.mariya1971@postgrespro.ru", "phone": "+70783656129"}
0005433686668	AB4FA3	7241 125811	IGOR IVANOV	{"phone": "+70504594826"}
0005433686669	78DC87	2830 974288	VIKTORIYA NIKITINA	{"email": "nikitina.v-13011966@postgrespro.ru", "phone": "+70483412687"}
0005433686670	0A7245	8866 727841	NIKOLAY ZHUKOV	{"phone": "+70904682009"}
0005433686671	F846BB	5578 122729	MARIYA KOROLEVA	{"email": "mariya.koroleva.081977@postgrespro.ru", "phone": "+70107580033"}
0005433686672	F846BB	4409 541907	IGOR SEMENOV	{"email": "isemenov1966@postgrespro.ru", "phone": "+70420244950"}
0005433686673	EFA645	0413 773001	IRINA SEMENOVA	{"phone": "+70166200391"}
0005433686674	EFA645	7768 531090	VALENTINA ILINA	{"email": "v-ilina_15121974@postgrespro.ru", "phone": "+70755110028"}
0005433686675	EFA645	7596 330122	ANNA ZOTOVA	{"email": "zotovaanna051981@postgrespro.ru", "phone": "+70525595182"}
0005433686676	D6419B	9600 117814	VYACHESLAV YAKOVLEV	{"email": "vyacheslav-yakovlev_041981@postgrespro.ru", "phone": "+70170812463"}
0005433686677	D6419B	1447 190384	SERGEY PAVLOV	{"email": "sergey_pavlov1975@postgrespro.ru", "phone": "+70465889306"}
0005433686678	B690C8	4109 811346	VALERIY MAKSIMOV	{"email": "valeriy.maksimov_111970@postgrespro.ru", "phone": "+70923344500"}
0005433686679	B690C8	0268 633035	ANNA ZAKHAROVA	{"email": "annazakharova111965@postgrespro.ru", "phone": "+70666806364"}
0005433686680	B690C8	8478 830382	ZHANNA NIKIFOROVA	{"email": "z-nikiforova.1970@postgrespro.ru", "phone": "+70564673315"}
0005433686681	BB0DAE	6455 615631	IGOR IVANOV	{"phone": "+70589882419"}
0005433686682	08D68C	7007 615025	YURIY MIKHAYLOV	{"phone": "+70382527331"}
0005433686683	B45014	9195 257408	ANDREY NAUMOV	{"email": "naumovandrey13091975@postgrespro.ru", "phone": "+70258595891"}
0005433686684	B45014	5884 969802	DMITRIY KONOVALOV	{"email": "d_konovalov.11041968@postgrespro.ru", "phone": "+70434494327"}
0005433686685	6F778B	7898 631704	NATALIYA BELOVA	{"email": "belova_nataliya.111965@postgrespro.ru", "phone": "+70060781320"}
0005433686686	6F778B	3519 584798	MARINA VOROBEVA	{"email": "vorobeva-m_07031968@postgrespro.ru", "phone": "+70649124419"}
0005433686687	6F778B	0639 876864	VLADIMIR IVANOV	{"phone": "+70088648805"}
0005433686688	12B0F9	2407 910543	OLGA ORLOVA	{"email": "orlova.o-1962@postgrespro.ru", "phone": "+70719375739"}
0005433686689	12B0F9	1874 749448	ARTEM KAZAKOV	{"email": "kazakov_artem.111974@postgrespro.ru", "phone": "+70198398281"}
0005433686690	12B0F9	4848 424325	VADIM NOVIKOV	{"phone": "+70188406325"}
0005433686691	8F1434	7045 366410	ELENA KONDRATEVA	{"email": "elena-kondrateva1971@postgrespro.ru", "phone": "+70441883851"}
0005433686692	8F1434	3404 746319	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova.071972@postgrespro.ru", "phone": "+70864196800"}
0005433686693	8536CB	2279 128157	NADEZHDA NIKIFOROVA	{"phone": "+70428942785"}
0005433686694	8536CB	8702 280099	ALEKSANDR NAZAROV	{"phone": "+70138453326"}
0005433686695	D2B0D8	8167 615864	SERGEY PETROV	{"email": "petrov.s-1970@postgrespro.ru", "phone": "+70227608750"}
0005433686697	89B549	7299 904507	DMITRIY MIKHAYLOV	{"phone": "+70221650282"}
0005433686698	9DDE52	5032 185092	MIKHAIL NIKOLAEV	{"phone": "+70936047096"}
0005433686699	D1D5FA	1776 614550	NATALYA IVANOVA	{"phone": "+70291506892"}
0005433686700	EFDF72	1740 955739	DENIS NAUMOV	{"email": "naumov.denis-031968@postgrespro.ru", "phone": "+70224707445"}
0005433686701	EFDF72	6060 961480	VLADIMIR ZHURAVLEV	{"phone": "+70784641881"}
0005433686702	EFDF72	2501 374678	NATALYA VASILEVA	{"email": "vasileva_natalya.06021966@postgrespro.ru", "phone": "+70730715094"}
0005433687675	F84F45	5050 686267	IRINA EGOROVA	{"email": "egorova.irina-111985@postgrespro.ru", "phone": "+70473784861"}
0005433687676	0F0613	7761 758901	GENNADIY ORLOV	{"email": "orlovg_111969@postgrespro.ru", "phone": "+70924593301"}
0005433687677	0F0613	0149 929553	VIKTOR ILIN	{"phone": "+70030216383"}
0005433687678	71C4F6	5828 949174	KONSTANTIN VOLKOV	{"email": "volkov_konstantin-1978@postgrespro.ru", "phone": "+70044116275"}
0005433687679	71C4F6	1867 057562	GALINA ABRAMOVA	{"phone": "+70393062926"}
0005433687680	57D5B8	4466 843093	EVGENIY FEDOTOV	{"email": "efedotov-25091968@postgrespro.ru", "phone": "+70902078015"}
0005433687681	085EDF	4929 771091	YURIY PETROV	{"phone": "+70357349687"}
0005433687682	BB61BA	3222 324495	PLATON AFANASEV	{"phone": "+70485234329"}
0005433687683	4C494D	9607 369498	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.n.1976@postgrespro.ru", "phone": "+70609603159"}
0005433687684	1717B5	8076 983554	VIKTOR STEPANOV	{"email": "stepanovviktor03051971@postgrespro.ru", "phone": "+70323281950"}
0005433687685	1717B5	4597 049039	ELIZAVETA ANTONOVA	{"email": "elizaveta-antonova.23101969@postgrespro.ru", "phone": "+70087848750"}
0005433687686	13263B	1509 679602	KLAVDIYA EGOROVA	{"email": "klavdiya.egorova_20111952@postgrespro.ru", "phone": "+70874568787"}
0005433687687	13263B	2201 731143	ALEKSEY DENISOV	{"email": "aleksey.denisov.18091978@postgrespro.ru", "phone": "+70277970302"}
0005433687688	CEB159	0312 490164	PAVEL ROMANOV	{"email": "pavel-romanov_121979@postgrespro.ru", "phone": "+70331611957"}
0005433687689	5E82AF	5734 239703	ANATOLIY KOZLOV	{"email": "anatoliykozlov-1959@postgrespro.ru", "phone": "+70016646659"}
0005433687690	46C2F4	6211 952581	GULNAZ FILIPPOVA	{"email": "filippovagulnaz.25111979@postgrespro.ru", "phone": "+70923511177"}
0005433687691	46C2F4	6946 217340	ALEKSEY TIMOFEEV	{"email": "timofeeva15121982@postgrespro.ru", "phone": "+70647463276"}
0005433687692	56814B	7244 085007	VALERIY SEMENOV	{"email": "semenov.v.121970@postgrespro.ru", "phone": "+70240022179"}
0005433687693	68FDF2	6773 505333	KONSTANTIN BELOV	{"phone": "+70518410989"}
0005433687694	E220FF	4595 090188	EVDOKIYA ALEKSEEVA	{"phone": "+70199855281"}
0005433687695	E220FF	3224 312598	TATYANA KAZAKOVA	{"phone": "+70831045954"}
0005433687696	545C44	4164 006623	KONSTANTIN ROMANOV	{"phone": "+70326609461"}
0005433687697	79CADC	3708 340587	IRINA VOROBEVA	{"phone": "+70888625292"}
0005433687698	D4E5E0	2517 685703	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey.081965@postgrespro.ru", "phone": "+70630280532"}
0005433687699	D4E5E0	6855 596936	VALERIY MARTYNOV	{"email": "martynov_v-27121978@postgrespro.ru", "phone": "+70216374942"}
0005433687700	D4E5E0	5210 002210	ALEKSANDR SOKOLOV	{"email": "sokolovaleksandr_26041970@postgrespro.ru", "phone": "+70755916590"}
0005433687701	45C1D6	6585 317751	DMITRIY MARTYNOV	{"email": "dmitriy-martynov.081969@postgrespro.ru", "phone": "+70638189426"}
0005433687702	45C1D6	0179 168193	ELENA GORBUNOVA	{"phone": "+70646506034"}
0005433687703	54C0EA	1975 886292	KLAVDIYA DENISOVA	{"email": "kdenisova_1970@postgrespro.ru", "phone": "+70278441439"}
0005433687704	F199C3	5575 222880	ARTUR BARANOV	{"phone": "+70061587383"}
0005433687705	812013	4248 666301	LYUBOV ORLOVA	{"phone": "+70126980277"}
0005433687706	70E19A	9158 747069	ALEKSANDR KISELEV	{"phone": "+70670138763"}
0005433687707	61F1A1	1156 036449	NIKOLAY ALEKSANDROV	{"email": "naleksandrov_19121980@postgrespro.ru", "phone": "+70676474619"}
0005433687708	FFE94B	0270 826107	ALEKSANDR TIKHONOV	{"phone": "+70811575897"}
0005433687709	FFE94B	4586 355182	ARTEM TIKHONOV	{"phone": "+70318850809"}
0005433687710	5ACF10	3632 196852	MARIYA SEMENOVA	{"email": "semenova_mariya1964@postgrespro.ru", "phone": "+70833747259"}
0005433687711	8E01C3	8615 672295	NATALYA SOROKINA	{"email": "n-sorokina-041975@postgrespro.ru", "phone": "+70023879327"}
0005433687712	8E01C3	3410 595988	ANNA IVANOVA	{"email": "a-ivanova_1984@postgrespro.ru", "phone": "+70233775261"}
0005433687713	75D7A6	6572 363322	DAMIR ABRAMOV	{"email": "d.abramov.14041978@postgrespro.ru", "phone": "+70500703969"}
0005433687714	683C82	0510 899875	VIKTOR SMIRNOV	{"phone": "+70557485834"}
0005433687715	3F7FDF	5494 521004	VALENTINA OVCHINNIKOVA	{"phone": "+70614414054"}
0005433687716	3F7FDF	9539 030892	YURIY TARASOV	{"phone": "+70297589370"}
0005433687717	FAA5F1	3752 410895	VLADIMIR FROLOV	{"phone": "+70353362461"}
0005433687718	FAA5F1	2243 329761	ALEKSANDR KOZLOV	{"phone": "+70785826703"}
0005433687719	AB8C8B	3836 466511	ALEKSANDRA NOVIKOVA	{"email": "novikova-a-15091972@postgrespro.ru", "phone": "+70515600412"}
0005433687720	AB8C8B	4293 705430	ALEKSEY DMITRIEV	{"phone": "+70004233955"}
0005433687721	5C07D1	9640 203604	MIKHAIL PAVLOV	{"email": "pavlov.m_29071960@postgrespro.ru", "phone": "+70071449579"}
0005433687722	BF32F4	5127 027822	DENIS ZAYCEV	{"phone": "+70265889563"}
0005433687723	0C5C4E	2201 080208	OLEG ANDREEV	{"phone": "+70105473490"}
0005433687724	0C5C4E	0939 323937	ANDREY KONOVALOV	{"phone": "+70064691163"}
0005433687725	0D0722	1478 028167	ANASTASIYA KAZAKOVA	{"phone": "+70927533280"}
0005433687726	F7AA68	6266 950166	ANASTASIYA ZHUKOVA	{"email": "anastasiya.zhukova071959@postgrespro.ru", "phone": "+70414033209"}
0005433687727	F7AA68	9521 212344	VALENTINA BELOVA	{"phone": "+70799604006"}
0005433687728	75E877	1318 284082	MURAT ANDREEV	{"email": "m_andreev.021984@postgrespro.ru", "phone": "+70012907107"}
0005433687729	420D66	1224 050059	DMITRIY RODIONOV	{"email": "d.rodionov.1963@postgrespro.ru", "phone": "+70634692378"}
0005433687730	9974B4	6107 281536	TATYANA GAVRILOVA	{"email": "t-gavrilova1964@postgrespro.ru", "phone": "+70149947502"}
0005433687731	0A9CF7	1747 646611	YULIYA BORISOVA	{"phone": "+70520181118"}
0005433687732	0ECC53	2253 399791	ANDREY POPOV	{"email": "andreypopov031986@postgrespro.ru", "phone": "+70976499177"}
0005433687733	0ECC53	5185 414405	LEONID DENISOV	{"email": "denisov_leonid-1966@postgrespro.ru", "phone": "+70998936043"}
0005433687734	41D5AF	0312 024863	PAVEL TARASOV	{"email": "pavel_tarasov.1980@postgrespro.ru", "phone": "+70792576276"}
0005433687735	4A26DC	1615 156075	SVETLANA ZHUKOVA	{"phone": "+70636769841"}
0005433687736	BF2E02	5767 503218	VALENTINA VOLKOVA	{"phone": "+70610937719"}
0005433687737	939C14	8978 495026	ALEKSANDR ILIN	{"email": "a.ilin-1976@postgrespro.ru", "phone": "+70286468115"}
0005433687738	115BC1	9951 016901	EVGENIY FEDOROV	{"email": "evgeniy.fedorov.06091976@postgrespro.ru", "phone": "+70989707924"}
0005433687739	115BC1	9451 663431	NATALYA ORLOVA	{"phone": "+70760880127"}
0005433687740	F2194F	5678 230151	TATYANA ZOTOVA	{"phone": "+70333461133"}
0005433687741	846113	8660 348655	VLADISLAV GRIGOREV	{"email": "grigorev.v-1974@postgrespro.ru", "phone": "+70559520969"}
0005433687742	C6D81D	7002 264735	ALEKSANDR VOLKOV	{"email": "volkov.a04041971@postgrespro.ru", "phone": "+70151047668"}
0005433687743	C6D81D	6772 448470	LILIYA ABRAMOVA	{"email": "abramoval26041967@postgrespro.ru", "phone": "+70149866453"}
0005433687744	744754	9206 451395	EVGENIY BORISOV	{"phone": "+70012523580"}
0005433687745	605CA1	1281 329029	NATALYA EFREMOVA	{"phone": "+70009620119"}
0005433687746	0FA5D2	1616 632537	GALINA NAZAROVA	{"email": "galina_nazarova.28061965@postgrespro.ru", "phone": "+70715872213"}
0005433687747	322DA4	7603 131660	ANNA IVANOVA	{"phone": "+70127411124"}
0005433687748	06BE24	4772 278122	OLGA KONOVALOVA	{"phone": "+70073857641"}
0005433687749	0D5A9F	1863 386636	ANTON IVANOV	{"phone": "+70147163875"}
0005433687750	350BBA	8610 235263	MIKHAIL SHEVCHENKO	{"email": "mikhail.shevchenko_1964@postgrespro.ru", "phone": "+70971856373"}
0005433687751	B2A141	6710 093097	MARIYA STEPANOVA	{"phone": "+70262280909"}
0005433687752	15C94F	0062 672461	OLGA NOVIKOVA	{"phone": "+70825287165"}
0005433687753	F76CCD	7735 580076	IVAN KUZMIN	{"email": "ikuzmin.08031969@postgrespro.ru", "phone": "+70497477761"}
0005433687754	BCDA6A	6569 899081	MARIYA EGOROVA	{"email": "mariya.egorova1972@postgrespro.ru", "phone": "+70276921057"}
0005433687755	80FF71	4792 526774	VALENTINA FROLOVA	{"phone": "+70752173751"}
0005433687756	80FF71	0915 438155	NATALYA PETROVA	{"email": "petrova_n1972@postgrespro.ru", "phone": "+70409912340"}
0005433687757	80FF71	2407 620363	ALEKSANDR KUZNECOV	{"phone": "+70568215732"}
0005433687758	15B108	2795 032298	MIKHAIL POPOV	{"phone": "+70562898949"}
0005433687759	C99289	7733 196448	NIKOLAY SAVELEV	{"email": "savelev-nikolay_15111983@postgrespro.ru", "phone": "+70589226550"}
0005433687760	C99289	1272 168536	RINAT SMIRNOV	{"phone": "+70268210759"}
0005433687761	2CDAD5	8982 733485	EKATERINA NOVIKOVA	{"phone": "+70855896460"}
0005433687762	2CDAD5	2281 568648	OLGA YAKOVLEVA	{"phone": "+70874038525"}
0005433687763	09365B	9593 372856	ANATOLIY VLASOV	{"email": "vlasov-a.25051978@postgrespro.ru", "phone": "+70246651740"}
0005433687764	617B1B	1681 411249	VYACHESLAV SEMENOV	{"email": "semenovv.05091977@postgrespro.ru", "phone": "+70181801758"}
0005433688773	6DA490	0739 464105	RAFIK SOROKIN	{"phone": "+70849093172"}
0005433688774	2F8D09	3014 780804	KSENIYA FEDOROVA	{"email": "fedorovak-23071964@postgrespro.ru", "phone": "+70111194326"}
0005433688775	2F8D09	2100 504704	SERGEY PETROV	{"email": "sergey_petrov24061969@postgrespro.ru", "phone": "+70539393932"}
0005433688776	2414D9	1260 004719	DMITRIY TIKHONOV	{"email": "tikhonov.d1971@postgrespro.ru", "phone": "+70839136409"}
0005433688777	AD1F02	6635 992660	GALINA GRISHINA	{"email": "grishina.g011972@postgrespro.ru", "phone": "+70028455248"}
0005433688778	AD1F02	3450 767288	MARIYA KRASNOVA	{"email": "krasnova_mariya_1970@postgrespro.ru", "phone": "+70644484559"}
0005433688779	955674	2678 046727	GALINA GORBUNOVA	{"phone": "+70386493535"}
0005433688780	955674	7189 868424	VLADISLAV POPOV	{"email": "vladislav-popov_1974@postgrespro.ru", "phone": "+70570610737"}
0005433688781	955674	1946 884805	ELENA TIKHONOVA	{"phone": "+70664167701"}
0005433688782	69CA93	3789 834326	SERGEY KULIKOV	{"phone": "+70327112587"}
0005433688783	69CA93	7848 733032	ALEKSANDR GUSEV	{"phone": "+70611480473"}
0005433688784	2345DE	6091 625668	VALERIYA LAZAREVA	{"phone": "+70437792586"}
0005433688785	033385	8385 625720	OLEG ZHURAVLEV	{"email": "ozhuravlev.25051971@postgrespro.ru", "phone": "+70246584936"}
0005433688786	A4F0D1	3194 716856	TATYANA TITOVA	{"phone": "+70690213966"}
0005433688787	796CEB	0161 515594	EGOR KOZLOV	{"email": "egor_kozlov-021977@postgrespro.ru", "phone": "+70587662806"}
0005433688788	809B0B	2824 668233	RAISA AFANASEVA	{"email": "raisa-afanaseva031974@postgrespro.ru", "phone": "+70652445983"}
0005433688789	809B0B	4626 483907	ANDREY KUZNECOV	{"phone": "+70385927431"}
0005433688790	4D4498	6361 793651	DMITRIY SOKOLOV	{"phone": "+70429056207"}
0005433688791	880C69	9893 602365	TAMARA DENISOVA	{"phone": "+70109380559"}
0005433688792	E88024	0934 646543	VERA ALEKSEEVA	{"email": "alekseeva-v_21081960@postgrespro.ru", "phone": "+70917625368"}
0005433688793	6A7CE8	2341 203056	SANIYA KUZNECOVA	{"phone": "+70651426282"}
0005433688794	6A7CE8	8451 680180	ALEKSANDR ALEKSEEV	{"email": "a.alekseev.02121964@postgrespro.ru", "phone": "+70072309448"}
0005433688795	51E9CD	3086 801353	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr16121973@postgrespro.ru", "phone": "+70385198292"}
0005433688796	51E9CD	8104 244935	VLADIMIR ROMANOV	{"email": "romanov-v-1972@postgrespro.ru", "phone": "+70398539254"}
0005433688797	CCDA88	3513 654637	OLEG ZAKHAROV	{"email": "zakharov-o_25031972@postgrespro.ru", "phone": "+70347271169"}
0005433688798	F9A98A	1611 464788	EKATERINA MATVEEVA	{"phone": "+70659041477"}
0005433688799	5AF415	0485 093261	IDA GRISHINA	{"email": "ida.grishina.121973@postgrespro.ru", "phone": "+70444172842"}
0005433688800	F06EF7	2425 491679	GULSHAT KUZMINA	{"phone": "+70416523170"}
0005433688801	F06EF7	0273 211576	SVETLANA ALEKSEEVA	{"email": "svetlanaalekseeva_27051969@postgrespro.ru", "phone": "+70204061264"}
0005433688802	0923FD	4738 295816	ARINA SAVELEVA	{"email": "savelevaa-1977@postgrespro.ru", "phone": "+70280871496"}
0005433688803	0923FD	3809 510841	ALEKSANDR ISAEV	{"email": "isaeva08061960@postgrespro.ru", "phone": "+70109885597"}
0005433688804	BE6C13	5269 285957	DIANA ABRAMOVA	{"email": "abramova_d02071971@postgrespro.ru", "phone": "+70571719644"}
0005433688805	A80183	3644 592108	VLADIMIR ILIN	{"email": "vladimir_ilin_18011969@postgrespro.ru", "phone": "+70259627516"}
0005433688806	23E66A	2874 678362	FEDOR KUDRYASHOV	{"email": "f-kudryashov.021974@postgrespro.ru", "phone": "+70766062285"}
0005433688807	23E66A	1736 891529	ELENA LEBEDEVA	{"phone": "+70521560707"}
0005433688808	8270D2	6315 365785	NADEZHDA BARANOVA	{"phone": "+70771700062"}
0005433688809	8270D2	2995 938480	ALEKSANDR PAVLOV	{"phone": "+70426983115"}
0005433688810	7CC51B	1528 121938	VLADIMIR IVANOV	{"phone": "+70942943463"}
0005433688811	C15162	3033 507416	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda-051983@postgrespro.ru", "phone": "+70250730261"}
0005433688812	C15162	8715 817443	NIKOLAY RODIONOV	{"email": "rodionovnikolay.071968@postgrespro.ru", "phone": "+70823790555"}
0005433688813	97DCBD	1045 276349	RAISA KALININA	{"email": "kalininaraisa-12111979@postgrespro.ru", "phone": "+70974583647"}
0005433688814	97DCBD	4786 110127	MARIYA SERGEEVA	{"email": "mariya_sergeeva_01091985@postgrespro.ru", "phone": "+70784693428"}
0005433688815	168BF4	6049 295970	DMITRIY ILIN	{"email": "ilin_dmitriy_22061973@postgrespro.ru", "phone": "+70337132407"}
0005433688816	168BF4	8273 720519	VADIM KAZAKOV	{"phone": "+70249096687"}
0005433688817	309D6F	8452 122560	MIKHAIL SOKOLOV	{"email": "m_sokolov101974@postgrespro.ru", "phone": "+70250267471"}
0005433688818	881718	1206 694167	OLGA KOROLEVA	{"email": "koroleva_olga_121984@postgrespro.ru", "phone": "+70115566844"}
0005433688819	BE72A9	2451 160792	ILYA AFANASEV	{"phone": "+70314429212"}
0005433688820	BE72A9	2069 140384	LARISA POTAPOVA	{"phone": "+70761016559"}
0005433688821	DD1928	8841 768675	SVETLANA KUZNECOVA	{"phone": "+70171666089"}
0005433688822	25E6BA	0167 704825	LYUBOV CHERNOVA	{"email": "lchernova-1979@postgrespro.ru", "phone": "+70456822135"}
0005433688823	25E6BA	7617 343285	VIKTOR SOROKIN	{"email": "v-sorokin-03061978@postgrespro.ru", "phone": "+70850653233"}
0005433688824	056A10	1834 259765	DMITRIY SOROKIN	{"phone": "+70240936164"}
0005433688825	8163C8	9930 317825	RAISA MIRONOVA	{"email": "r_mironova-12051968@postgrespro.ru", "phone": "+70801143542"}
0005433688826	8163C8	0272 851608	ANNA KOZLOVA	{"email": "kozlova.anna-1965@postgrespro.ru", "phone": "+70750192782"}
0005433688827	5CA177	6994 312121	ELENA VOROBEVA	{"email": "vorobevae_041975@postgrespro.ru", "phone": "+70349214605"}
0005433688828	9428C0	2567 691908	LYUBOV TIKHONOVA	{"email": "l-tikhonova-31071973@postgrespro.ru", "phone": "+70483756148"}
0005433688829	760B3C	8312 184118	VALENTINA YAKOVLEVA	{"email": "v-yakovleva_21101961@postgrespro.ru", "phone": "+70204443378"}
0005433688830	8FBE5C	1892 807848	VIKTORIYA NIKOLAEVA	{"email": "v_nikolaeva_1969@postgrespro.ru", "phone": "+70557027119"}
0005433688831	ED4801	1961 178336	ALEKSANDR NIKOLAEV	{"email": "nikolaev_aleksandr1959@postgrespro.ru", "phone": "+70341572058"}
0005433688832	ED4801	8712 000049	ALEKSANDR ISAEV	{"email": "isaev.a-111965@postgrespro.ru", "phone": "+70815126877"}
0005433688833	ED4801	6746 020199	NINA LOGINOVA	{"phone": "+70708700346"}
0005433688834	7EC10F	3419 866557	LIDIYA OVCHINNIKOVA	{"phone": "+70016307442"}
0005433688835	7EC10F	1188 740671	ELIZAVETA VASILEVA	{"email": "vasileva-elizaveta-051982@postgrespro.ru", "phone": "+70873799914"}
0005433688836	32C59C	7619 884240	VYACHESLAV NOVIKOV	{"email": "vyacheslavnovikov_1969@postgrespro.ru", "phone": "+70860987426"}
0005433688837	32C59C	6588 110991	SOFIYA MEDVEDEVA	{"email": "s.medvedeva101982@postgrespro.ru", "phone": "+70999371493"}
0005433688838	50841B	7111 959753	ANDREY FEDOROV	{"email": "fedorovandrey.1969@postgrespro.ru", "phone": "+70194573967"}
0005433688839	7754AB	8647 019287	ALINA POPOVA	{"phone": "+70361255293"}
0005433688840	7754AB	5771 677363	TARAS ABRAMOV	{"email": "tabramov-19031972@postgrespro.ru", "phone": "+70039268726"}
0005433688841	7754AB	0462 692124	EVGENIY MATVEEV	{"phone": "+70615600428"}
0005433688842	8DC3F5	3350 686545	ANATOLIY SEMENOV	{"email": "anatoliy-semenov.22051980@postgrespro.ru", "phone": "+70003130905"}
0005433688843	D4F981	6733 332010	IRINA NOVIKOVA	{"phone": "+70632274889"}
0005433688844	54F5F9	9482 767938	YURIY BELOV	{"email": "belov-yuriy-121964@postgrespro.ru", "phone": "+70798669434"}
0005433688845	54F5F9	4375 451133	RAISA IVANOVA	{"phone": "+70423069431"}
0005433688846	17BE71	6583 737986	NATALYA PAVLOVA	{"email": "pavlova_natalya22061962@postgrespro.ru", "phone": "+70872639060"}
0005433688847	17BE71	1142 451910	EVGENIY KUZMIN	{"email": "e_kuzmin1975@postgrespro.ru", "phone": "+70145162294"}
0005433688848	37B82F	1508 272149	KONSTANTIN PETROV	{"email": "konstantinpetrov-11071980@postgrespro.ru", "phone": "+70610128688"}
0005433688849	37B82F	2817 375414	DENIS SEMENOV	{"email": "denis_semenov1975@postgrespro.ru", "phone": "+70263957107"}
0005433688850	37B82F	1653 714467	NIKOLAY MEDVEDEV	{"phone": "+70562669553"}
0005433688851	CFD85D	5992 708089	IRINA KOROLEVA	{"email": "koroleva-i-101963@postgrespro.ru", "phone": "+70139575955"}
0005433688852	4DAF0F	1468 559240	VALENTINA KUDRYASHOVA	{"phone": "+70886276888"}
0005433688853	D11C2E	9147 324375	YURIY ZAKHAROV	{"email": "zakharov.yuriy.1971@postgrespro.ru", "phone": "+70083808034"}
0005433688854	9004C1	9862 902233	YURIY KONOVALOV	{"phone": "+70767711609"}
0005433688855	BEEA63	8129 173152	ELENA SAVELEVA	{"phone": "+70334425030"}
0005433688856	950F88	2340 489147	VITALIY MIRONOV	{"email": "vitaliy.mironov_1954@postgrespro.ru", "phone": "+70312293323"}
0005433688857	B4E68F	0728 753863	YURIY FEDOTOV	{"phone": "+70541040711"}
0005433688858	B4E68F	6605 712202	TATYANA GORBUNOVA	{"phone": "+70358244323"}
0005433688859	4F12CF	0712 894770	ALEKSANDRA MELNIKOVA	{"email": "melnikovaa_08111960@postgrespro.ru", "phone": "+70773769937"}
0005433688860	4F12CF	0763 074348	IRINA ZOTOVA	{"email": "zotova_irina23121969@postgrespro.ru", "phone": "+70649112995"}
0005433688861	770A93	3116 587635	OLEG KUZNECOV	{"phone": "+70511116183"}
0005433688862	770A93	4788 328706	VALERIY PAVLOV	{"email": "pavlov.v031983@postgrespro.ru", "phone": "+70919392205"}
0005433688863	C245C9	2777 358231	ALEKSEY NIKITIN	{"phone": "+70406559389"}
0005433688864	C245C9	9534 419573	GALINA NIKIFOROVA	{"phone": "+70484258468"}
0005433688865	D89468	2671 711646	DARYA TARASOVA	{"email": "tarasova_d061958@postgrespro.ru", "phone": "+70153070113"}
0005433688866	36CC7D	8070 908273	OLEG SAVELEV	{"email": "savelev.oleg-1973@postgrespro.ru", "phone": "+70874298761"}
0005433688867	36CC7D	4886 799875	OLGA VOLKOVA	{"phone": "+70701103616"}
0005433689967	105914	3314 897928	VALENTINA IVANOVA	{"phone": "+70706767384"}
0005433689874	CDE786	5162 007791	ANATOLIY FOMIN	{"email": "fominanatoliy.101977@postgrespro.ru", "phone": "+70314619082"}
0005433689875	1D0944	6529 794256	SERGEY ZAYCEV	{"phone": "+70400226353"}
0005433689876	8B33FD	3556 273449	VERA KUZNECOVA	{"email": "kuznecovav.081970@postgrespro.ru", "phone": "+70081404021"}
0005433689877	3F45D5	6553 046763	ANNA ANISIMOVA	{"phone": "+70225421930"}
0005433689878	69A8F7	7006 881891	OLGA RODIONOVA	{"email": "rodionova.olga-02071979@postgrespro.ru", "phone": "+70854948133"}
0005433689879	69A8F7	4164 085234	OLGA MIRONOVA	{"email": "olga-mironova-1990@postgrespro.ru", "phone": "+70830058735"}
0005433689880	522286	6880 754422	ALEKSANDR SAVELEV	{"email": "savelev-aleksandr121986@postgrespro.ru", "phone": "+70057458208"}
0005433689881	522286	6448 147767	ELENA FEDOROVA	{"email": "fedorovaelena-1975@postgrespro.ru", "phone": "+70737132593"}
0005433689882	EB964A	3871 080660	ALEKSANDRA MIKHAYLOVA	{"email": "a-mikhaylova_22121990@postgrespro.ru", "phone": "+70393249642"}
0005433689883	EB964A	0271 838817	YULIYA MAKAROVA	{"email": "makarova-y.021965@postgrespro.ru", "phone": "+70040249211"}
0005433689884	4B99D5	2091 085580	SERGEY ZHURAVLEV	{"email": "s-zhuravlev-20071966@postgrespro.ru", "phone": "+70002604755"}
0005433689885	0BF7B4	8650 531796	NIKOLAY VASILEV	{"phone": "+70507084059"}
0005433689886	5C7FEC	4982 584902	LYUDMILA ANDREEVA	{"email": "andreeva_l.05091981@postgrespro.ru", "phone": "+70907922980"}
0005433689887	ADA1E4	7783 351952	SOFYA GAVRILOVA	{"email": "gavrilova-sofya-27051966@postgrespro.ru", "phone": "+70724302192"}
0005433689888	500E4A	9130 875216	SERGEY BONDARENKO	{"phone": "+70377512803"}
0005433689889	C2723A	9372 853486	VIKTOR FILIPPOV	{"email": "filippovviktor-1977@postgrespro.ru", "phone": "+70607062460"}
0005433689890	EE6D3C	6964 791647	VADIM VLASOV	{"phone": "+70174846068"}
0005433689891	5244E6	5457 346955	VALENTINA LOGINOVA	{"email": "vloginova-071972@postgrespro.ru", "phone": "+70413090902"}
0005433689892	57DEF2	7627 105448	LYUDMILA POTAPOVA	{"email": "potapova-l.1959@postgrespro.ru", "phone": "+70318652244"}
0005433689893	2B2290	6628 265849	TAMARA GAVRILOVA	{"email": "gavrilova.tamara_101981@postgrespro.ru", "phone": "+70458324281"}
0005433689894	AA196A	2249 503966	ALEKSEY BONDARENKO	{"email": "bondarenkoa-12091955@postgrespro.ru", "phone": "+70504857789"}
0005433689895	959AD1	9436 672154	EVGENIY ZHUKOV	{"phone": "+70009870091"}
0005433689896	959AD1	5068 783279	RAISA BORISOVA	{"phone": "+70148088047"}
0005433689897	AE3E3D	7797 381847	OLGA KOZLOVA	{"email": "olga-kozlova04031976@postgrespro.ru", "phone": "+70403586589"}
0005433689898	A346EE	2377 587824	OLGA KUZNECOVA	{"email": "olga_kuznecova.111972@postgrespro.ru", "phone": "+70544792666"}
0005433689899	A346EE	2847 377988	VENIAMIN KUZNECOV	{"email": "kuznecov.v121975@postgrespro.ru", "phone": "+70594357037"}
0005433689900	4BD1EA	1651 694688	ILYA KUZMIN	{"email": "ilya.kuzmin_1968@postgrespro.ru", "phone": "+70457457871"}
0005433689901	FFB9D5	8097 371031	YULIYA KONOVALOVA	{"email": "yuliya_konovalova_1961@postgrespro.ru", "phone": "+70089745074"}
0005433689902	0981AB	0622 303362	ANZHELA GAVRILOVA	{"phone": "+70134948142"}
0005433689903	0981AB	8088 071366	MIKHAIL MELNIKOV	{"phone": "+70910311030"}
0005433689904	0981AB	1248 041879	TATYANA NAZAROVA	{"email": "tatyana_nazarova-24021977@postgrespro.ru", "phone": "+70736199052"}
0005433689905	993FA2	7486 122961	MARINA SOKOLOVA	{"phone": "+70297328237"}
0005433689906	7E7D1B	2631 010937	VASILISA ZOTOVA	{"email": "zotovav_27091967@postgrespro.ru", "phone": "+70622086981"}
0005433689907	7E7D1B	0924 081969	GALINA KOZLOVA	{"phone": "+70978932220"}
0005433689908	BF0B02	5360 375180	MIKHAIL SOROKIN	{"phone": "+70156630369"}
0005433689909	EC67CD	7604 920088	ALEKSANDR MARTYNOV	{"email": "martynov.a.1986@postgrespro.ru", "phone": "+70096966180"}
0005433689910	EC67CD	3450 285023	LILIYA IVANOVA	{"phone": "+70328216417"}
0005433689911	1B1F55	8179 517142	VALERIY PAVLOV	{"email": "valeriy.pavlov.021981@postgrespro.ru", "phone": "+70610245818"}
0005433689912	B4031E	6363 901369	LIDIYA TARASOVA	{"phone": "+70934064497"}
0005433689913	881CBA	4763 265802	VALENTINA AKIMOVA	{"phone": "+70456563014"}
0005433689914	7631E6	5104 945142	IVAN POPOV	{"phone": "+70400562777"}
0005433689915	A0C6E3	7825 923992	ALEKSEY DAVYDOV	{"email": "davydov.a06021992@postgrespro.ru", "phone": "+70286380006"}
0005433689916	A0C6E3	3259 832737	MAKSIM VOROBEV	{"phone": "+70038564363"}
0005433689917	A8F676	2482 414211	VALENTINA MARTYNOVA	{"email": "martynova_valentina-02031966@postgrespro.ru", "phone": "+70634051956"}
0005433689918	784D3F	4185 879238	ALBINA MAKSIMOVA	{"email": "amaksimova.16041963@postgrespro.ru", "phone": "+70119503622"}
0005433689919	1F8187	5466 242204	NADEZHDA ZAKHAROVA	{"email": "nadezhda_zakharova091970@postgrespro.ru", "phone": "+70490529807"}
0005433689920	A4148F	0939 017318	ARTEM MATVEEV	{"email": "artem.matveev_1971@postgrespro.ru", "phone": "+70858991117"}
0005433689921	C014BB	2250 960996	ANNA IVANOVA	{"phone": "+70500804524"}
0005433689922	EDCD42	3967 904217	LYUBOV GRISHINA	{"email": "lyubovgrishina.25071978@postgrespro.ru", "phone": "+70729005630"}
0005433689923	305ECC	8823 150751	VIKTOR DMITRIEV	{"email": "dmitriev_viktor.11071974@postgrespro.ru", "phone": "+70701866328"}
0005433689924	B03423	0950 506660	YURIY SAVELEV	{"email": "savelevy-24021973@postgrespro.ru", "phone": "+70102164910"}
0005433689925	800C8E	4991 267427	IRINA SAVELEVA	{"phone": "+70545595126"}
0005433689926	99D4F5	6094 552676	VLADIMIR BONDARENKO	{"email": "v-bondarenko.1974@postgrespro.ru", "phone": "+70357154944"}
0005433689927	99D4F5	6741 344951	VALERIYA ERMAKOVA	{"email": "ermakova_valeriya.1977@postgrespro.ru", "phone": "+70984002373"}
0005433689928	393E36	4876 977628	LYUBOV KUZNECOVA	{"phone": "+70159592991"}
0005433689929	E15FAB	5631 825799	DMITRIY NAZAROV	{"phone": "+70797555615"}
0005433689930	8F57DE	7392 716968	ALEKSANDR SMIRNOV	{"phone": "+70041364540"}
0005433689931	91A850	2835 458530	DENIS KRASNOV	{"phone": "+70677387863"}
0005433689932	91A850	8136 003627	NAIL IVANOV	{"phone": "+70266006279"}
0005433689933	91A850	2022 021492	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey.07011985@postgrespro.ru", "phone": "+70288803821"}
0005433689934	C141FC	6025 709578	MARINA TIKHONOVA	{"email": "tikhonovamarina.061974@postgrespro.ru", "phone": "+70209336909"}
0005433689935	CBE133	4343 333370	VALENTINA SIDOROVA	{"email": "vsidorova.1977@postgrespro.ru", "phone": "+70130227321"}
0005433689936	D47A93	2090 085006	LYUDMILA ANTONOVA	{"email": "lyudmilaantonova1975@postgrespro.ru", "phone": "+70111484107"}
0005433689937	D47A93	6888 600102	IVAN KAZAKOV	{"email": "kazakovi_031978@postgrespro.ru", "phone": "+70558490350"}
0005433689938	A50829	5965 958736	SVETLANA ILINA	{"phone": "+70747969433"}
0005433689939	A48987	5240 864609	YURIY MAKSIMOV	{"phone": "+70333391493"}
0005433689940	A48987	0024 147019	ANDREY MARTYNOV	{"phone": "+70481568419"}
0005433689941	1588DF	9133 012120	TAMARA KUZNECOVA	{"phone": "+70138723110"}
0005433689942	1588DF	7575 167480	ILYAS PETROV	{"phone": "+70747790762"}
0005433689943	CB1450	1453 662671	YURIY SAVELEV	{"email": "yuriy.savelev-081963@postgrespro.ru", "phone": "+70014081199"}
0005433689944	CB1450	6265 571496	MARIYA ISAEVA	{"phone": "+70682776836"}
0005433689945	41E2C5	6740 329525	ALEKSANDRA DAVYDOVA	{"phone": "+70465879642"}
0005433689946	4D2DD6	6651 126765	SVETLANA KOROLEVA	{"phone": "+70002262121"}
0005433689947	4D2DD6	5255 782343	NATALIYA KUZNECOVA	{"email": "nataliya-kuznecova.071968@postgrespro.ru", "phone": "+70477824253"}
0005433689948	6C90AF	8785 004709	NIKITA MAKAROV	{"phone": "+70996865103"}
0005433689949	6C90AF	3971 439220	ALEKSANDR VLASOV	{"email": "vlasov_a.22011975@postgrespro.ru", "phone": "+70237872673"}
0005433689950	E72E04	0549 551382	ANDREY MOISEEV	{"email": "moiseev.a_101979@postgrespro.ru", "phone": "+70896988024"}
0005433689951	8890CF	2981 675211	ALEKSEY MAKAROV	{"phone": "+70730907065"}
0005433689952	8890CF	9751 090314	ELENA KAZAKOVA	{"phone": "+70034831511"}
0005433689953	805EC7	8708 035427	ANDREY KARPOV	{"email": "karpov_a-1974@postgrespro.ru", "phone": "+70471735085"}
0005433689954	8B6DE8	0808 078024	OLGA KOLESNIKOVA	{"phone": "+70661416871"}
0005433689955	CD65FE	3075 485469	TATYANA FROLOVA	{"phone": "+70418688590"}
0005433689956	C3D829	1247 270961	IRINA ZHUKOVA	{"email": "zhukova-i.1968@postgrespro.ru", "phone": "+70984378143"}
0005433689957	908E7A	7729 069439	VASILIY VOLKOV	{"email": "vvolkov111981@postgrespro.ru", "phone": "+70798399200"}
0005433690936	FF0774	4571 328325	ALINA EGOROVA	{"phone": "+70370903301"}
0005433689958	908E7A	3750 720839	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya1986@postgrespro.ru", "phone": "+70593620454"}
0005433689959	E958DC	8039 545844	YULIYA KUZNECOVA	{"phone": "+70771749637"}
0005433689960	172085	1418 030115	VITALIY VASILEV	{"email": "vasilev-vitaliy_24011973@postgrespro.ru", "phone": "+70702318750"}
0005433689961	F344DF	0960 245666	ALEKSANDR OSIPOV	{"email": "a.osipov_121978@postgrespro.ru", "phone": "+70196537256"}
0005433689962	6E2C63	6846 539132	ALEKSANDR NIKITIN	{"email": "nikitin_a.08111971@postgrespro.ru", "phone": "+70915278946"}
0005433689963	AD7647	3455 930522	EGOR PETROV	{"email": "egor_petrov-25031959@postgrespro.ru", "phone": "+70486886728"}
0005433689964	A2002F	7471 670640	ULYANA PAVLOVA	{"email": "ulyana-pavlova-29101961@postgrespro.ru", "phone": "+70551913916"}
0005433689965	BE8F66	1932 265535	ELENA TARASOVA	{"email": "tarasova.elena-16031959@postgrespro.ru", "phone": "+70923647991"}
0005433689966	D68078	8668 130512	YURIY SMIRNOV	{"email": "ysmirnov_121973@postgrespro.ru", "phone": "+70380506481"}
0005433689968	105914	2676 456955	EVGENIY STEPANOV	{"email": "stepanove.051971@postgrespro.ru", "phone": "+70939714607"}
0005433689969	3F57A7	8246 535794	DMITRIY ANDREEV	{"phone": "+70333644356"}
0005433690890	FC3CED	8849 283465	VALENTINA POPOVA	{"email": "popovav13091974@postgrespro.ru", "phone": "+70340839312"}
0005433690891	B99356	7543 658700	VLADISLAV ANTONOV	{"phone": "+70326895743"}
0005433690892	B99356	7363 498664	ANDREY GORBUNOV	{"phone": "+70032185213"}
0005433690893	06B7AA	5341 656058	ALEKSEY SMIRNOV	{"email": "aleksey_smirnov_1979@postgrespro.ru", "phone": "+70660659264"}
0005433690894	50C310	1586 205260	NINA GRISHINA	{"phone": "+70701327467"}
0005433690895	84F518	1097 445998	ROMAN NIKOLAEV	{"phone": "+70665078601"}
0005433690896	84F518	1843 152950	LIDIYA ANDREEVA	{"email": "andreeva-lidiya_021975@postgrespro.ru", "phone": "+70866822384"}
0005433690897	2E2CF2	2092 050708	IRINA IVANOVA	{"email": "ivanova.irina.22031971@postgrespro.ru", "phone": "+70141156327"}
0005433690898	2E2CF2	8494 225389	ALEKSANDRA KOLESNIKOVA	{"phone": "+70041273258"}
0005433690899	060C90	8227 909541	RIMMA ARKHIPOVA	{"phone": "+70455764215"}
0005433690900	8CD722	8223 463628	TATYANA ANISIMOVA	{"phone": "+70659492200"}
0005433690901	39910E	5305 134258	YAN KRASNOV	{"phone": "+70858732499"}
0005433690902	39910E	6407 468623	ANDREY ANDREEV	{"email": "andreev-a.1965@postgrespro.ru", "phone": "+70224174587"}
0005433690903	89E3C7	8693 146240	ANTON NIKITIN	{"email": "anton.nikitin1974@postgrespro.ru", "phone": "+70410206055"}
0005433690904	8344F7	4718 664022	DARYA VOLKOVA	{"phone": "+70834568542"}
0005433690905	614C23	5312 000614	SERGEY ZHUKOV	{"phone": "+70984881192"}
0005433690906	B81891	4610 475245	NIKOLAY IVANOV	{"phone": "+70238121522"}
0005433690907	E626F2	0151 610453	TATYANA MELNIKOVA	{"email": "tatyanamelnikova_121968@postgrespro.ru", "phone": "+70137984298"}
0005433690908	AA72CB	5186 137148	ALEKSANDRA OSIPOVA	{"email": "osipovaa_081987@postgrespro.ru", "phone": "+70609387472"}
0005433690909	12D45A	3111 731064	YULIANA TARASOVA	{"email": "yulianatarasova-091976@postgrespro.ru", "phone": "+70711459367"}
0005433690910	5F8E69	3221 366461	GALINA VOROBEVA	{"email": "galinavorobeva_17091970@postgrespro.ru", "phone": "+70842455406"}
0005433690911	5F8E69	1689 160052	VALENTINA KONDRATEVA	{"email": "kondratevav-1975@postgrespro.ru", "phone": "+70844799189"}
0005433690912	2593C7	1085 219667	SERGEY NIKOLAEV	{"email": "sergey.nikolaev-071974@postgrespro.ru", "phone": "+70831532933"}
0005433690913	2593C7	5918 025527	SERGEY BORISOV	{"phone": "+70090380211"}
0005433690914	69D3B2	6300 813549	ZOYA SEMENOVA	{"email": "zsemenova_28101972@postgrespro.ru", "phone": "+70076927806"}
0005433690915	69D3B2	3064 639852	VYACHESLAV PAVLOV	{"email": "pavlovv.091971@postgrespro.ru", "phone": "+70706562553"}
0005433690916	69D3B2	5093 537384	LYUBOV NIKOLAEVA	{"email": "nikolaeva_lyubov_1968@postgrespro.ru", "phone": "+70904271052"}
0005433690917	D8745A	0140 963248	OLEG DAVYDOV	{"email": "o_davydov-1976@postgrespro.ru", "phone": "+70476454140"}
0005433690918	D8745A	0520 572932	SVETLANA ALEKSANDROVA	{"phone": "+70378490385"}
0005433690919	87195B	0873 944676	ANATOLIY DENISOV	{"email": "denisov.a1977@postgrespro.ru", "phone": "+70938702710"}
0005433690920	87195B	7273 380449	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr101969@postgrespro.ru", "phone": "+70324452578"}
0005433690921	87195B	6686 993005	OLGA KUZNECOVA	{"phone": "+70307036706"}
0005433690922	7BC58E	3159 447637	LYUBOV IVANOVA	{"email": "ivanova_lyubov_041976@postgrespro.ru", "phone": "+70008486015"}
0005433690923	AB6400	0931 215663	ANTONINA DANILOVA	{"email": "danilova-a_051972@postgrespro.ru", "phone": "+70852192592"}
0005433690924	AB6400	2676 052852	ALEKSEY PAVLOV	{"email": "aleksey_pavlov_121974@postgrespro.ru", "phone": "+70470056400"}
0005433690925	28604D	0319 940151	VLADIMIR KRASNOV	{"email": "v-krasnov.1964@postgrespro.ru", "phone": "+70425506615"}
0005433690926	28604D	0923 191312	ALEKSANDRA OSIPOVA	{"phone": "+70031176046"}
0005433690927	BBEB25	5409 967578	NATALYA VLASOVA	{"phone": "+70054389499"}
0005433690928	BBEB25	9746 295803	SERGEY FILIPPOV	{"phone": "+70111948121"}
0005433690929	B18CAA	6872 122410	DMITRIY SERGEEV	{"email": "sergeev.d-03091974@postgrespro.ru", "phone": "+70036708599"}
0005433690930	69F0F6	9940 597730	SERGEY MIKHAYLOV	{"email": "mikhaylov.sergey30101975@postgrespro.ru", "phone": "+70856726373"}
0005433690931	7B1BD5	9141 562092	NADEZHDA SOLOVEVA	{"email": "n-soloveva-1974@postgrespro.ru", "phone": "+70874728901"}
0005433690932	4A2363	5505 568319	ALEKSANDR PETROV	{"email": "aleksandr.petrov.30111969@postgrespro.ru", "phone": "+70577591829"}
0005433690933	AA2545	5892 287071	ALEKSANDR PAVLOV	{"email": "a-pavlov-121971@postgrespro.ru", "phone": "+70247459760"}
0005433690934	AA2545	9545 633781	TATYANA RYABOVA	{"email": "ryabova.t-1979@postgrespro.ru", "phone": "+70561016213"}
0005433690935	FF0774	0552 258608	PETR SEMENOV	{"email": "petr-semenov.111982@postgrespro.ru", "phone": "+70747444085"}
0005433690937	5A0D23	4068 244198	DARYA MAKAROVA	{"email": "makarova.darya.061975@postgrespro.ru", "phone": "+70245900267"}
0005433690938	5A0D23	1315 623324	VALENTINA VASILEVA	{"phone": "+70348438183"}
0005433690939	A40171	7877 416967	OLEG ALEKSEEV	{"phone": "+70822308783"}
0005433690940	891ED8	8218 870377	RASHIT STEPANOV	{"email": "rashitstepanov-19121959@postgrespro.ru", "phone": "+70042640213"}
0005433690941	59C9D5	7979 819962	VYACHESLAV CHERNOV	{"phone": "+70246364215"}
0005433690942	5389D0	1763 877738	OLGA GRISHINA	{"email": "o-grishina-071983@postgrespro.ru", "phone": "+70226625129"}
0005433690943	B50FDC	0844 601067	ILYA KOZLOV	{"phone": "+70120290971"}
0005433690944	B50FDC	8629 803338	SVETLANA MOROZOVA	{"phone": "+70739141727"}
0005433690945	4900E7	4154 891376	KIRILL FROLOV	{"email": "frolov_kirill-12041975@postgrespro.ru", "phone": "+70607079815"}
0005433690946	4900E7	3603 077327	VALENTINA NOVIKOVA	{"email": "valentina-novikova_071968@postgrespro.ru", "phone": "+70164648579"}
0005433690947	0BE43C	5980 136743	KSENIYA BORISOVA	{"phone": "+70105985522"}
0005433690948	05719B	1472 336013	ELENA NOVIKOVA	{"phone": "+70872594619"}
0005433690949	591002	4850 685526	VLADIMIR MAKSIMOV	{"phone": "+70411283406"}
0005433690950	1EE56D	3298 934543	PAVEL SAVELEV	{"phone": "+70458899490"}
0005433690951	BC8BF8	2802 270637	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya_021967@postgrespro.ru", "phone": "+70284593997"}
0005433690952	1D0A26	5445 161728	KIRILL BELOV	{"phone": "+70307181487"}
0005433690953	D8D087	0727 565336	ALEKSANDR SEMENOV	{"email": "a_semenov-041959@postgrespro.ru", "phone": "+70620171463"}
0005433690954	C8C4EF	8965 213858	VLADIMIR SEMENOV	{"email": "semenov-v_23061981@postgrespro.ru", "phone": "+70754272715"}
0005433690955	FC7B1D	5348 396746	MATVEY SIDOROV	{"email": "sidorov_matvey_1968@postgrespro.ru", "phone": "+70326838957"}
0005433690956	FEDB91	9243 464014	ALEKSEY SOKOLOV	{"phone": "+70564554191"}
0005433690957	18122F	2279 487131	LYUDMILA BORISOVA	{"email": "lyudmila.borisova.17021968@postgrespro.ru", "phone": "+70920611774"}
0005433690958	103E0E	2235 629262	ALENA NAZAROVA	{"phone": "+70828717792"}
0005433690959	925B85	7394 124931	IRINA SERGEEVA	{"phone": "+70693014365"}
0005433690960	267BEA	3469 844639	NIKOLAY ALEKSEEV	{"email": "alekseev.n-02121983@postgrespro.ru", "phone": "+70034164250"}
0005433690961	A0785F	3428 526006	ANDREY SHEVCHENKO	{"email": "shevchenko.andrey-011967@postgrespro.ru", "phone": "+70492802059"}
0005433690962	8501C0	8724 970065	ALEKSANDR FEDOTOV	{"email": "fedotov.a.091975@postgrespro.ru", "phone": "+70272794629"}
0005433690963	FD0A99	7773 884184	ROMAN GAVRILOV	{"phone": "+70955316650"}
0005433690964	FD0A99	6782 208009	NINA SMIRNOVA	{"phone": "+70183209320"}
0005433690965	A12DDB	6825 466427	VLADIMIR VASILEV	{"phone": "+70343178216"}
0005433690966	2E7679	9883 616299	ALEKSEY RODIONOV	{"email": "aleksey-rodionov_01041971@postgrespro.ru", "phone": "+70084646803"}
0005433690967	49AC8C	7569 837984	ARTEM SMIRNOV	{"phone": "+70271957393"}
0005433690968	0981D9	4174 900934	NIKOLAY ANDREEV	{"email": "nikolayandreev28051969@postgrespro.ru", "phone": "+70792153597"}
0005433690969	BF29F0	9595 421665	ZINAIDA FROLOVA	{"phone": "+70748463594"}
0005433690970	E5E690	5919 329867	INNA KOZLOVA	{"email": "inna_kozlova-1961@postgrespro.ru", "phone": "+70118145906"}
0005433690971	E5E690	3923 358974	GALINA MIKHAYLOVA	{"phone": "+70513445996"}
0005433690972	16A942	5810 050775	TATYANA MAKSIMOVA	{"phone": "+70607829532"}
0005433690973	018DCA	1213 028128	ALEKSANDR SOKOLOV	{"email": "sokolov.aleksandr1978@postgrespro.ru", "phone": "+70914610860"}
0005433690974	544F2B	3573 220884	DARYA VASILEVA	{"phone": "+70760674416"}
0005433690975	64C3A4	7203 534403	ALEKSEY NIKOLAEV	{"email": "aleksey-nikolaev011968@postgrespro.ru", "phone": "+70033925174"}
0005433690976	C86547	3527 719497	TATYANA ANISIMOVA	{"phone": "+70843945596"}
0005433690977	6A031D	2475 074130	EKATERINA VASILEVA	{"email": "evasileva-051965@postgrespro.ru", "phone": "+70203234152"}
0005433690978	E7B714	8291 263872	DMITRIY PETROV	{"email": "petrov.dmitriy_051976@postgrespro.ru", "phone": "+70169419565"}
0005433690979	975500	0310 874501	MIKHAIL KUZNECOV	{"phone": "+70846989623"}
0005433690980	88F142	1015 246292	NATALYA KALININA	{"email": "kalinina.natalya-24021965@postgrespro.ru", "phone": "+70320957466"}
0005433690981	D841FF	9746 139737	MARINA NAZAROVA	{"phone": "+70188452911"}
0005433690982	D841FF	1073 895229	VALERIY KULIKOV	{"email": "kulikovv031970@postgrespro.ru", "phone": "+70867910785"}
0005433690983	82149F	9598 285433	MIKHAIL MARTYNOV	{"phone": "+70857343022"}
0005433690984	E58685	7787 153964	MIKHAIL NIKITIN	{"phone": "+70591315607"}
0005433690985	CE81F5	9072 763824	RAISA PETROVA	{"email": "petrovar06101969@postgrespro.ru", "phone": "+70404044221"}
0005433690986	CE81F5	3236 679636	SERGEY VASILEV	{"email": "sergey_vasilev.09021983@postgrespro.ru", "phone": "+70773578529"}
0005433690987	78F24A	1578 448462	ANASTASIYA ALEKSANDROVA	{"phone": "+70917329240"}
0005433690988	D38395	9050 778622	MIKHAIL VLASOV	{"email": "m_vlasov-101983@postgrespro.ru", "phone": "+70422938050"}
0005433690989	3288F1	0805 891581	MARAT ANDREEV	{"email": "marat-andreev1969@postgrespro.ru", "phone": "+70730695905"}
0005433690990	BB7613	0994 718181	ANATOLIY PAVLOV	{"phone": "+70818108900"}
0005433690991	BB7613	4459 718503	ALEKSANDRA GRISHINA	{"email": "grishina-aleksandra.121973@postgrespro.ru", "phone": "+70725255685"}
0005433690992	99AD30	4609 093383	LYUBOV AKIMOVA	{"email": "lyubov_akimova081975@postgrespro.ru", "phone": "+70411953804"}
0005433690993	99AD30	8746 534285	VLADISLAV TIKHONOV	{"email": "vladislavtikhonov-1986@postgrespro.ru", "phone": "+70088953804"}
0005433715072	8B3EFA	7603 487590	VALENTINA NIKOLAEVA	{"phone": "+70217881535"}
0005433715067	E54BB1	5331 516122	EKATERINA GRISHINA	{"phone": "+70321143541"}
0005433715068	6DCF24	2688 808510	PAVEL KRASNOV	{"email": "pavel_krasnov-1977@postgrespro.ru", "phone": "+70556103466"}
0005433715069	61B4D2	4791 147181	NIKOLAY ZHUKOV	{"email": "zhukovnikolay_04031980@postgrespro.ru", "phone": "+70762719795"}
0005433715070	F90F85	8868 563375	LEONID GUSEV	{"email": "l-gusev_1966@postgrespro.ru", "phone": "+70296428526"}
0005433715071	F90F85	3272 217661	VLADISLAV SCHERBAKOV	{"email": "vladislavscherbakov-041979@postgrespro.ru", "phone": "+70739367966"}
0005433715073	8B3EFA	0757 634420	GENNADIY MAKAROV	{"phone": "+70555426185"}
0005433715074	DE67CE	2735 839956	ALEKSANDR ANDREEV	{"phone": "+70189850730"}
0005433715075	DE67CE	6780 050168	EKATERINA MAKAROVA	{"phone": "+70287172722"}
0005433715076	F7F708	9682 258342	VALENTINA GORBUNOVA	{"phone": "+70182822155"}
0005433715077	19EAD2	1363 118797	LARISA TIMOFEEVA	{"phone": "+70844086700"}
0005433715078	B46A78	4390 955842	ELENA FROLOVA	{"phone": "+70271859171"}
0005433715079	FA1D10	0879 840123	TATYANA SEMENOVA	{"phone": "+70871508986"}
0005433715080	186942	0766 329557	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-1964@postgrespro.ru", "phone": "+70088873449"}
0005433715081	A2D867	0726 830771	DMITRIY RODIONOV	{"phone": "+70020741183"}
0005433715082	A2D867	9864 871033	PRASKOVYA PETROVA	{"phone": "+70989936966"}
0005433715083	A2D867	7781 852085	DINA VOROBEVA	{"email": "dina.vorobeva1973@postgrespro.ru", "phone": "+70390286599"}
0005433715084	AE07A6	4455 118209	VALENTINA LEBEDEVA	{"phone": "+70886775744"}
0005433715085	9EC413	1536 147543	OLEG IVANOV	{"email": "ivanov-oleg_21071984@postgrespro.ru", "phone": "+70776535431"}
0005433715086	4C1819	6305 629537	SVETLANA BARANOVA	{"email": "baranova_svetlana_13071968@postgrespro.ru", "phone": "+70375356337"}
0005433715087	C87F4B	6305 861763	ANATOLIY IVANOV	{"phone": "+70701655319"}
0005433715088	B764DC	4444 591078	VENIAMIN VOLKOV	{"email": "veniamin_volkov-20091965@postgrespro.ru", "phone": "+70247285441"}
0005433715089	2ACDFD	0500 481040	ANTONINA TIKHONOVA	{"email": "tikhonovaa-1962@postgrespro.ru", "phone": "+70749025493"}
0005433715090	73F266	4559 165549	ELIZAVETA VASILEVA	{"phone": "+70736174532"}
0005433715091	73F266	6056 078571	AZAT TARASOV	{"phone": "+70661337499"}
0005433715092	FE54B8	8133 600744	NATALYA TIMOFEEVA	{"email": "timofeeva_n1968@postgrespro.ru", "phone": "+70542549702"}
0005433715093	06759C	4114 213206	VALENTIN TARASOV	{"email": "tarasov-valentin_101958@postgrespro.ru", "phone": "+70826560330"}
0005433715094	43A4AD	9359 405040	SVETLANA ABRAMOVA	{"email": "abramova-s.1962@postgrespro.ru", "phone": "+70385003669"}
0005433715095	43A4AD	8743 180238	OLGA ABRAMOVA	{"email": "olga_abramova1974@postgrespro.ru", "phone": "+70361503649"}
0005433715096	396FE0	3450 469718	ALEKSANDRA KOROLEVA	{"phone": "+70415604067"}
0005433715097	0BE432	4761 733045	GALINA MELNIKOVA	{"phone": "+70587914739"}
0005433715098	0C93E8	7819 405278	NIKOLAY GUSEV	{"phone": "+70329786779"}
0005433715099	CBE54F	0082 183427	NADEZHDA ILINA	{"email": "ilina-n011963@postgrespro.ru", "phone": "+70838481896"}
0005433715212	276953	5104 012857	LYUBOV KUZNECOVA	{"phone": "+70649123437"}
0005433715100	04CB2C	3327 543195	YULIYA SOLOVEVA	{"email": "soloveva-yuliya16051978@postgrespro.ru", "phone": "+70771885229"}
0005433715101	04CB2C	0818 902144	YULIYA ZHURAVLEVA	{"phone": "+70892310970"}
0005433715102	78C821	9823 681804	VALENTINA OSIPOVA	{"email": "osipova.valentina05031970@postgrespro.ru", "phone": "+70526556427"}
0005433715103	18AE1B	2449 588290	KIRILL VASILEV	{"email": "k.vasilev101955@postgrespro.ru", "phone": "+70355799258"}
0005433715104	18AE1B	2561 512882	IVAN ROMANOV	{"email": "romanovi-1977@postgrespro.ru", "phone": "+70473919964"}
0005433715105	18AE1B	2910 875449	SERGEY MOROZOV	{"phone": "+70632316446"}
0005433715106	FD43D0	2918 378227	KRISTINA SOLOVEVA	{"email": "soloveva-kristina-10061971@postgrespro.ru", "phone": "+70550734017"}
0005433715107	FD43D0	1253 719424	IRINA DENISOVA	{"phone": "+70949805580"}
0005433715108	CBE830	5768 399171	KLAVDIYA KARPOVA	{"email": "karpova-klavdiya.17091966@postgrespro.ru", "phone": "+70908924490"}
0005433715109	CBE830	6012 586776	ALEKSANDR BORISOV	{"email": "borisov_a_031978@postgrespro.ru", "phone": "+70604828246"}
0005433715110	D24278	2917 800869	NINA OSIPOVA	{"phone": "+70844980264"}
0005433715111	B52BA0	8822 611658	YULIYA AFANASEVA	{"phone": "+70654790498"}
0005433715112	B4DD44	2489 949477	KONSTANTIN PAVLOV	{"email": "konstantinpavlov_1968@postgrespro.ru", "phone": "+70504640936"}
0005433715113	FEC9A7	0059 283681	NATALYA VASILEVA	{"email": "vasilevanatalya_26051977@postgrespro.ru", "phone": "+70081975519"}
0005433715114	FEC9A7	3425 530685	OLGA NIKOLAEVA	{"phone": "+70506085088"}
0005433715115	DC8933	0263 774324	SERGEY ZAKHAROV	{"phone": "+70769030029"}
0005433715116	234FDB	0818 456444	IRINA AFANASEVA	{"phone": "+70681298074"}
0005433715117	E984E0	4680 530765	LYUBOV PAVLOVA	{"email": "pavlova_lyubov.091965@postgrespro.ru", "phone": "+70188491892"}
0005433715118	E6266E	8528 892811	VASILIY NIKOLAEV	{"email": "vasiliy.nikolaev.081972@postgrespro.ru", "phone": "+70768724591"}
0005433715119	ED281C	4399 394328	ANNA SOROKINA	{"email": "annasorokina1968@postgrespro.ru", "phone": "+70927141902"}
0005433715120	CBB2DA	6175 466531	MAKSIM NIKOLAEV	{"email": "nikolaevm.22081983@postgrespro.ru", "phone": "+70611182684"}
0005433715121	CBB2DA	0086 455399	VALENTINA ALEKSEEVA	{"email": "v-alekseeva_121973@postgrespro.ru", "phone": "+70211742797"}
0005433715122	CBB2DA	2162 195025	NATALYA MALYSHEVA	{"phone": "+70558229793"}
0005433715123	92DB3C	9744 334594	TATYANA SOLOVEVA	{"phone": "+70724947233"}
0005433715124	92DB3C	6508 059424	POLINA YUDINA	{"phone": "+70723706161"}
0005433715125	9D6901	9547 798858	ANDREY SEMENOV	{"phone": "+70388062064"}
0005433715126	9D6901	4146 229150	IGOR ABRAMOV	{"phone": "+70880327271"}
0005433715127	A413F1	0504 726563	ALEKSANDR KUZNECOV	{"phone": "+70970026236"}
0005433715128	F92B73	4783 756636	EMMA NIKITINA	{"email": "nikitina_e08041977@postgrespro.ru", "phone": "+70929725893"}
0005433715129	B0E6F1	4815 180673	KONSTANTIN NOVIKOV	{"phone": "+70250571377"}
0005433715130	7103A7	5071 728181	RAFAIL SOKOLOV	{"phone": "+70041263689"}
0005433715131	7103A7	3764 311782	VIKTOR SIDOROV	{"phone": "+70398191717"}
0005433715132	FFB371	4617 431596	YANA TIKHONOVA	{"email": "yanatikhonova-01031993@postgrespro.ru", "phone": "+70953513307"}
0005433715133	BA59C2	2329 906377	VALENTINA ERMAKOVA	{"phone": "+70102393028"}
0005433715134	EE969D	8744 359292	VADIM FEDOROV	{"phone": "+70962482522"}
0005433715135	882537	6567 993254	VLADIMIR ANDREEV	{"phone": "+70232331668"}
0005433715136	882537	2444 040576	DMITRIY KUDRYASHOV	{"email": "kudryashov-dmitriy061972@postgrespro.ru", "phone": "+70807363682"}
0005433715137	ED4151	4381 684231	ROMAN GERASIMOV	{"phone": "+70459219467"}
0005433715138	C06DFC	7556 533089	IRINA KUZNECOVA	{"email": "ikuznecova_031973@postgrespro.ru", "phone": "+70796821918"}
0005433715139	C06DFC	2690 950914	VLADISLAV PAVLOV	{"phone": "+70023811177"}
0005433715140	8EC952	8240 020834	ALEKSANDR KARPOV	{"phone": "+70486099015"}
0005433715141	8EC952	9928 890744	VIKTORIYA GAVRILOVA	{"email": "vgavrilova011970@postgrespro.ru", "phone": "+70917062317"}
0005433715142	611A71	2612 939157	VLADIMIR SHEVCHENKO	{"email": "shevchenko-vladimir.081975@postgrespro.ru", "phone": "+70249937688"}
0005433715143	1507E0	6858 953640	VIKTOR IVANOV	{"phone": "+70964331505"}
0005433715144	1507E0	1604 548795	MARIYA IVANOVA	{"email": "ivanova_m.1964@postgrespro.ru", "phone": "+70835219697"}
0005433715145	BDECFF	8194 255133	SVETLANA YUDINA	{"phone": "+70617796248"}
0005433715146	BDECFF	2237 117885	YURIY ISAEV	{"email": "isaev-yuriy041969@postgrespro.ru", "phone": "+70055404381"}
0005433715147	A9A704	1129 192919	EVGENIYA DANILOVA	{"email": "danilovaevgeniya-1974@postgrespro.ru", "phone": "+70023647528"}
0005433715148	A9A704	0589 941143	NADEZHDA KUZNECOVA	{"email": "nkuznecova_021975@postgrespro.ru", "phone": "+70806680184"}
0005433715149	A9A704	3722 824294	GEORGIY KISELEV	{"email": "georgiy-kiselev.04041968@postgrespro.ru", "phone": "+70021529607"}
0005433715150	3BC38E	2622 236004	ZHANNA MOROZOVA	{"phone": "+70355600700"}
0005433715151	3BC38E	9225 030540	KARINA SIDOROVA	{"email": "sidorova.karina-121965@postgrespro.ru", "phone": "+70202034835"}
0005433715152	8CBE1D	1150 078042	IVAN IVANOV	{"phone": "+70944641485"}
0005433715153	A1D041	0069 623798	OLESYA STEPANOVA	{"email": "stepanovaolesya_061964@postgrespro.ru", "phone": "+70430861647"}
0005433715154	A1D041	9426 518983	ALEKSANDR MEDVEDEV	{"phone": "+70843534880"}
0005433715155	FA8688	2715 087731	VLADIMIR PETROV	{"phone": "+70006448544"}
0005433715156	C7C38B	1172 441483	VALENTINA MELNIKOVA	{"email": "valentina_melnikova_1970@postgrespro.ru", "phone": "+70685859402"}
0005433715157	DA5A04	1535 390360	EVGENIYA KULIKOVA	{"phone": "+70507275854"}
0005433715158	F09F0F	8790 268669	TATYANA TIMOFEEVA	{"phone": "+70702078527"}
0005433715159	2059DC	8310 469567	OLGA KRASNOVA	{"email": "o-krasnova_081958@postgrespro.ru", "phone": "+70930308627"}
0005433715160	8C65FF	3980 926321	VLADIMIR KUZMIN	{"email": "vladimir.kuzmin.1978@postgrespro.ru", "phone": "+70719520467"}
0005433715161	DE2307	3143 494312	ALENA GAVRILOVA	{"email": "gavrilova_alena101976@postgrespro.ru", "phone": "+70569076703"}
0005433715162	DE2307	5572 054963	DMITRIY NIKITIN	{"email": "nikitind.1962@postgrespro.ru", "phone": "+70653312604"}
0005433715163	FD750C	8654 888495	MARINA KUZNECOVA	{"email": "marinakuznecova.1966@postgrespro.ru", "phone": "+70578986917"}
0005433715164	FD750C	0737 838695	RAFAEL NIKOLAEV	{"phone": "+70286879141"}
0005433715165	4634B3	7172 497549	ANASTASIYA PETROVA	{"phone": "+70236536259"}
0005433715166	63D056	6680 622625	LYUDMILA SOKOLOVA	{"phone": "+70494318320"}
0005433715167	63D056	7701 455200	YULIYA MAKSIMOVA	{"phone": "+70221298529"}
0005433715168	2CF000	7591 402483	SERGEY BARANOV	{"phone": "+70338247151"}
0005433715169	9B003F	3570 261363	ANDREY KUZNECOV	{"email": "a-kuznecov-1985@postgrespro.ru", "phone": "+70590491094"}
0005433715170	9B003F	9045 904894	OKSANA BELOVA	{"email": "belova.o.091970@postgrespro.ru", "phone": "+70074278358"}
0005433715171	D6F98D	6485 324477	ALEKSANDR TARASOV	{"email": "atarasov_041981@postgrespro.ru", "phone": "+70652830901"}
0005433715172	D6F98D	4101 774102	ANTONINA TARASOVA	{"email": "antonina_tarasova03041966@postgrespro.ru", "phone": "+70511275925"}
0005433715173	8D0D5D	4939 492577	ANNA LEBEDEVA	{"phone": "+70841677887"}
0005433715174	8D0D5D	4915 773315	SERGEY SCHERBAKOV	{"phone": "+70695299888"}
0005433715175	C73CFA	3367 583325	TATYANA RYABOVA	{"phone": "+70928607535"}
0005433715176	459FD3	3768 947269	OLGA MAKAROVA	{"email": "o-makarova061989@postgrespro.ru", "phone": "+70453265541"}
0005433715177	520AC4	4314 606650	SVETLANA KONDRATEVA	{"email": "s.kondrateva.091989@postgrespro.ru", "phone": "+70545770734"}
0005433715178	520AC4	6017 411573	EKATERINA ISAEVA	{"email": "ekaterina_isaeva-021976@postgrespro.ru", "phone": "+70039490209"}
0005433715179	520AC4	6085 374803	EKATERINA TROFIMOVA	{"email": "ekaterina.trofimova_1969@postgrespro.ru", "phone": "+70809099313"}
0005433715180	885631	8426 355571	ALEKSANDR YAKOVLEV	{"phone": "+70455348656"}
0005433715181	0C1568	6944 040511	NATALIYA SOLOVEVA	{"email": "nataliya.soloveva-1968@postgrespro.ru", "phone": "+70816126997"}
0005433715182	64C6A3	0824 552179	GALINA ROMANOVA	{"phone": "+70042683086"}
0005433715183	64C6A3	4197 730879	MAKSIM MIRONOV	{"email": "maksim_mironov27091963@postgrespro.ru", "phone": "+70440887466"}
0005433715184	8A1020	7968 671401	TATYANA KOROLEVA	{"email": "t-koroleva-1975@postgrespro.ru", "phone": "+70643477473"}
0005433715185	8857C1	5238 063729	ZINAIDA KRASNOVA	{"email": "krasnova.z-20021967@postgrespro.ru", "phone": "+70646057597"}
0005433715186	8857C1	8831 285257	ELENA BELOVA	{"email": "elena-belova.24101968@postgrespro.ru", "phone": "+70485474467"}
0005433715187	8857C1	2656 371518	NINA SERGEEVA	{"phone": "+70841186240"}
0005433715188	4721D9	3573 119022	YURIY KOZLOV	{"email": "kozlov_y_24021983@postgrespro.ru", "phone": "+70989587441"}
0005433715189	FFF8EF	2312 840869	ALEKSANDR NIKOLAEV	{"phone": "+70184071335"}
0005433715190	EEAA2A	1953 543621	EVGENIY MOROZOV	{"email": "evgeniymorozov.021970@postgrespro.ru", "phone": "+70764392610"}
0005433715191	FC07CA	6082 872162	ILDAR MOISEEV	{"phone": "+70187064678"}
0005433715192	FC07CA	0005 989292	MARIYA MAKAROVA	{"email": "m-makarova-30061970@postgrespro.ru", "phone": "+70369459052"}
0005433715193	FC07CA	4960 566543	ELENA OVCHINNIKOVA	{"email": "ovchinnikova_elena-21011966@postgrespro.ru", "phone": "+70990421356"}
0005433715194	F72D14	0603 573306	DMITRIY BONDARENKO	{"phone": "+70579663099"}
0005433715195	F72D14	2464 219293	MIKHAIL FOMIN	{"phone": "+70017996469"}
0005433715196	2D273B	5362 612893	SERGEY KOZLOV	{"phone": "+70813615131"}
0005433715197	2D273B	6777 208267	OLGA KUZMINA	{"phone": "+70144135006"}
0005433715198	A93791	5829 691122	NINA KOROLEVA	{"email": "koroleva.nina1969@postgrespro.ru", "phone": "+70007035726"}
0005433715199	A93791	8977 534120	TATYANA SMIRNOVA	{"email": "tsmirnova-30101969@postgrespro.ru", "phone": "+70126732932"}
0005433715200	7AAE0D	7486 974742	SVETLANA MASLOVA	{"email": "s-maslova_1978@postgrespro.ru", "phone": "+70952783332"}
0005433715201	FF516F	7117 251743	EKATERINA NESTEROVA	{"phone": "+70903798742"}
0005433715202	6DD38C	2633 451657	INESSA CHERNOVA	{"phone": "+70392706720"}
0005433715203	012AA8	7829 026869	GALINA KISELEVA	{"phone": "+70012781756"}
0005433715204	012AA8	4284 106970	VERA NESTEROVA	{"phone": "+70620016846"}
0005433715205	2C7A2A	2914 749951	LARISA ZAKHAROVA	{"email": "zakharoval011968@postgrespro.ru", "phone": "+70524957114"}
0005433715206	2C7A2A	9704 984628	ALEKSANDR KUZMIN	{"email": "a_kuzmin_081969@postgrespro.ru", "phone": "+70741021471"}
0005433715207	2C7A2A	9682 289545	ELENA OSIPOVA	{"email": "elena_osipova-041973@postgrespro.ru", "phone": "+70994138035"}
0005433715208	02693E	7802 080549	ALEKSANDR EGOROV	{"phone": "+70689553005"}
0005433715209	02693E	9880 390575	BORIS RODIONOV	{"phone": "+70912568586"}
0005433715210	02693E	0262 970190	ANDREY MIRONOV	{"phone": "+70326758608"}
0005433715211	276953	2006 371579	NIKITA GAVRILOV	{"email": "gavrilovn.27041982@postgrespro.ru", "phone": "+70598975215"}
0005433715213	9A3442	8708 714244	ELENA STEPANOVA	{"email": "e.stepanova-08111966@postgrespro.ru", "phone": "+70467256263"}
0005433715214	21BCC6	2966 387997	VERA SMIRNOVA	{"phone": "+70094148966"}
0005433715215	6DCE34	0884 141647	VLADIMIR MOISEEV	{"email": "v-moiseev071975@postgrespro.ru", "phone": "+70939380775"}
0005433715216	61A852	3350 656737	MARIYA KUDRYASHOVA	{"email": "kudryashova.mariya_07021970@postgrespro.ru", "phone": "+70450451421"}
0005433715217	F2B326	3165 317389	OKSANA KONOVALOVA	{"phone": "+70221731342"}
0005433715218	B2DD72	0786 489798	VLADIMIR KUZMIN	{"email": "kuzmin_v_1967@postgrespro.ru", "phone": "+70256887013"}
0005433715219	B2DD72	6505 681676	NADEZHDA KONDRATEVA	{"phone": "+70509870038"}
0005433715220	717801	3083 984648	SVETLANA NAZAROVA	{"phone": "+70296401172"}
0005433715221	BF99AD	2979 466247	MARINA NOVIKOVA	{"phone": "+70829316924"}
0005433715222	6C8152	1695 385290	ALEKSEY SHEVCHENKO	{"email": "alekseyshevchenko_1957@postgrespro.ru", "phone": "+70479540101"}
0005433715223	6C8152	6355 234853	DMITRIY KAZAKOV	{"phone": "+70959791914"}
0005433715224	91A7E4	0189 322297	LYUDMILA NAZAROVA	{"phone": "+70522914449"}
0005433715225	AA6F48	1043 243451	VLADIMIR DMITRIEV	{"email": "dmitriev.v121976@postgrespro.ru", "phone": "+70887044962"}
0005433715226	AA6F48	7570 325936	OLGA KARPOVA	{"phone": "+70033812764"}
0005433715227	7450B9	6437 733089	SERGEY KULIKOV	{"phone": "+70880586339"}
0005433715228	3D2814	5296 690259	PETR VASILEV	{"phone": "+70467116994"}
0005433715229	C07D0B	5338 135361	VALENTINA MOISEEVA	{"email": "moiseeva_valentina_031973@postgrespro.ru", "phone": "+70735038360"}
0005433715230	CB512D	0218 805988	YULIYA VASILEVA	{"phone": "+70939309864"}
0005433715231	FBB0DC	6643 338081	VYACHESLAV POPOV	{"email": "vpopov.041969@postgrespro.ru", "phone": "+70136548256"}
0005433715232	FE05E4	1012 663377	VLADIMIR ANDREEV	{"phone": "+70781211371"}
0005433715233	DFD003	2203 870081	KIRILL POPOV	{"email": "popov_kirill-091969@postgrespro.ru", "phone": "+70950900211"}
0005433715234	DFD003	8151 393845	KSENIYA KOMAROVA	{"email": "komarovakseniya_071970@postgrespro.ru", "phone": "+70661263553"}
0005433715235	8037F4	6365 307526	ANDREY SEMENOV	{"email": "a-semenov_24011975@postgrespro.ru", "phone": "+70087871420"}
0005433715236	01447C	3865 514260	VALENTINA IVANOVA	{"phone": "+70605442256"}
0005433715237	01447C	1629 339066	ANASTASIYA SAVELEVA	{"phone": "+70340562687"}
0005433715238	8BA953	5997 000072	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila17051973@postgrespro.ru", "phone": "+70077371306"}
0005433715239	024163	5783 949698	IGOR SOKOLOV	{"phone": "+70471995573"}
0005433715240	BA4B90	0569 697978	LEONID FROLOV	{"email": "leonidfrolov1974@postgrespro.ru", "phone": "+70280198509"}
0005433715296	9D9BED	1261 209983	VALERIYA VOROBEVA	{"phone": "+70522370606"}
0005433715241	36129A	6336 927426	OLGA SERGEEVA	{"email": "sergeeva_o_081965@postgrespro.ru", "phone": "+70938039862"}
0005433715242	37B8A4	5805 324921	VASILIY PETROV	{"email": "petrov_vasiliy031966@postgrespro.ru", "phone": "+70733279645"}
0005433715243	4FFE1A	4737 380414	NINA DENISOVA	{"email": "denisova_nina_29101969@postgrespro.ru", "phone": "+70250879027"}
0005433715244	310EF4	4618 689751	ALEKSANDRA KUDRYASHOVA	{"phone": "+70109992304"}
0005433715245	29596B	7727 008562	LEONID KOROLEV	{"phone": "+70558858305"}
0005433715246	81F56C	3493 551215	NATALYA MIKHAYLOVA	{"phone": "+70636660916"}
0005433715247	81F56C	0068 675923	ELENA GAVRILOVA	{"email": "elena.gavrilova-16101967@postgrespro.ru", "phone": "+70353469894"}
0005433715248	1CF9AF	4745 861817	STANISLAV ZHURAVLEV	{"email": "zhuravlev-s-071985@postgrespro.ru", "phone": "+70317609564"}
0005433715249	DB89B6	0351 982415	DMITRIY IVANOV	{"phone": "+70335603830"}
0005433715250	E6BF82	8729 397178	LARISA GUSEVA	{"email": "larisaguseva_111981@postgrespro.ru", "phone": "+70725299141"}
0005433715251	20AA36	3540 560352	SERGEY VOLKOV	{"email": "svolkov.08061974@postgrespro.ru", "phone": "+70574888234"}
0005433715252	B7A079	2562 804860	DMITRIY KONOVALOV	{"phone": "+70092232404"}
0005433715253	FDAB93	7285 801115	NIKOLAY POPOV	{"phone": "+70072496295"}
0005433715254	10DFBC	5623 818880	ELMIRA MALYSHEVA	{"email": "elmira-malysheva-1980@postgrespro.ru", "phone": "+70978461748"}
0005433715255	10DFBC	5130 962164	ALEKSEY SHEVCHENKO	{"phone": "+70314650418"}
0005433715256	6D8341	9982 577463	KRISTINA ZAKHAROVA	{"email": "k-zakharova.1970@postgrespro.ru", "phone": "+70193571928"}
0005433715257	6D8341	7373 457079	VERA KULIKOVA	{"email": "kulikova_vera.12021972@postgrespro.ru", "phone": "+70747815542"}
0005433715258	18B59E	2972 620472	YURIY KUZNECOV	{"email": "y-kuznecov.11091964@postgrespro.ru", "phone": "+70626719605"}
0005433715259	3DE23D	1025 626610	NADEZHDA AFANASEVA	{"email": "afanasevan.121981@postgrespro.ru", "phone": "+70881898173"}
0005433715260	3DE23D	8572 929110	ALEKSANDR FOMIN	{"email": "fomin.aleksandr_111973@postgrespro.ru", "phone": "+70635609278"}
0005433715261	49B2D2	1898 370240	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr-19031978@postgrespro.ru", "phone": "+70720057613"}
0005433715262	49B2D2	9977 023998	DMITRIY BARANOV	{"email": "d_baranov071973@postgrespro.ru", "phone": "+70465025364"}
0005433715263	D07D26	5088 369829	EGOR VOLKOV	{"phone": "+70148104473"}
0005433715264	D07D26	4076 414800	MAKSIM YAKOVLEV	{"email": "yakovlevmaksim_10111952@postgrespro.ru", "phone": "+70578023547"}
0005433715265	CF1DE3	5497 530685	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr-1974@postgrespro.ru", "phone": "+70019216872"}
0005433715266	D29C7A	9076 824114	VLADIMIR SOKOLOV	{"email": "sokolov.v-041976@postgrespro.ru", "phone": "+70381841940"}
0005433715267	D29C7A	5441 448733	OLEG SEMENOV	{"email": "semenov_oleg091969@postgrespro.ru", "phone": "+70401954162"}
0005433715268	E6A903	3413 604241	VLADIMIR ROMANOV	{"phone": "+70435389033"}
0005433715269	98D99E	8096 351005	VALERIYA MATVEEVA	{"email": "matveeva.valeriya-31071981@postgrespro.ru", "phone": "+70614210750"}
0005433715270	98D99E	0245 334754	VALENTINA ZHUKOVA	{"email": "zhukova-v.23101960@postgrespro.ru", "phone": "+70576045038"}
0005433715271	579384	2137 844503	EVGENIY EGOROV	{"phone": "+70031478639"}
0005433715272	6F0405	4486 467466	TATYANA DENISOVA	{"phone": "+70463435782"}
0005433715273	C1CDB2	1494 963668	VLADIMIR DAVYDOV	{"phone": "+70063464061"}
0005433715274	BC1749	7645 975338	DENIS FEDOROV	{"email": "fedorovd.091967@postgrespro.ru", "phone": "+70762867226"}
0005433715275	76BD89	4962 045832	LYUDMILA ILINA	{"phone": "+70342668553"}
0005433715276	4C2F03	8006 775617	IRINA DENISOVA	{"email": "denisovairina-041970@postgrespro.ru", "phone": "+70156163717"}
0005433715277	3F63E4	4225 759956	VIKTORIYA VASILEVA	{"phone": "+70304466896"}
0005433715278	3F63E4	1568 018452	ALEKSEY VLASOV	{"phone": "+70940540730"}
0005433715279	5AE9CB	4931 049162	EKATERINA KUZNECOVA	{"phone": "+70695935366"}
0005433715280	109594	0104 880975	DMITRIY SERGEEV	{"email": "sergeev-d.28121975@postgrespro.ru", "phone": "+70459292324"}
0005433715281	6C5AD8	7717 342261	LARISA SOROKINA	{"phone": "+70029396550"}
0005433715282	4B914E	4451 436548	ANTONINA FADEEVA	{"phone": "+70855147389"}
0005433715283	4B914E	9381 010756	MIKHAIL FEDOROV	{"email": "mikhail-fedorov.061972@postgrespro.ru", "phone": "+70770254299"}
0005433715284	B4AB3F	8752 723719	MARINA KRASNOVA	{"email": "krasnova_m_091972@postgrespro.ru", "phone": "+70288489955"}
0005433715285	B4AB3F	2906 816048	LYUBOV MEDVEDEVA	{"phone": "+70192943678"}
0005433715286	398D56	6582 334747	DMITRIY ILIN	{"phone": "+70900730167"}
0005433715287	DE018C	9979 097361	EKATERINA AKIMOVA	{"email": "e.akimova.20091965@postgrespro.ru", "phone": "+70705415539"}
0005433715288	C345AA	1099 307628	ANASTASIYA PETROVA	{"phone": "+70746600217"}
0005433715289	B6E4BF	7570 814471	SOFYA DENISOVA	{"email": "denisova_s-091973@postgrespro.ru", "phone": "+70735995481"}
0005433715290	54755F	3740 446863	IRINA KUZNECOVA	{"phone": "+70541365745"}
0005433715291	54755F	4323 682529	ANATOLIY MOROZOV	{"email": "amorozov.041977@postgrespro.ru", "phone": "+70089493249"}
0005433715292	EC4D64	4252 497901	ZINAIDA IVANOVA	{"email": "z.ivanova_08021972@postgrespro.ru", "phone": "+70615412102"}
0005433715293	EC4D64	5123 303680	ELMIRA MOROZOVA	{"phone": "+70742875145"}
0005433715294	331B87	6842 098008	DENIS SIDOROV	{"email": "sidorov_d_29061967@postgrespro.ru", "phone": "+70117399088"}
0005433715295	F82CA3	3564 272101	GALINA GAVRILOVA	{"email": "g_gavrilova-25101964@postgrespro.ru", "phone": "+70536713447"}
0005433715297	9D9BED	9434 841730	OLEG VOROBEV	{"phone": "+70368759119"}
0005433715298	9D9BED	4320 317363	GALINA MIKHAYLOVA	{"phone": "+70592594312"}
0005433715299	FEF4B0	8804 438555	YURIY SMIRNOV	{"phone": "+70105923460"}
0005433715300	DC968D	5022 791933	LYUDMILA SERGEEVA	{"email": "sergeeva_l_011974@postgrespro.ru", "phone": "+70284953377"}
0005433715301	2CE1A5	2381 499867	ANDREY ORLOV	{"email": "orlov-a.071976@postgrespro.ru", "phone": "+70636640964"}
0005433715302	2CE1A5	9049 819169	ELENA KONOVALOVA	{"email": "elena.konovalova051984@postgrespro.ru", "phone": "+70252765185"}
0005433715303	2CE1A5	8035 996766	NADEZHDA EFREMOVA	{"email": "efremovanadezhda_24021975@postgrespro.ru", "phone": "+70894822085"}
0005433715304	DC83AE	4689 553846	TATYANA SOKOLOVA	{"email": "sokolova_t021959@postgrespro.ru", "phone": "+70858947006"}
0005433715305	E35B15	6107 471396	OLGA ALEKSEEVA	{"phone": "+70656338762"}
0005433715306	3770CE	3152 950040	ALBINA ALEKSEEVA	{"email": "alekseevaalbina.121978@postgrespro.ru", "phone": "+70917823624"}
0005433715307	9FF818	2431 771072	TATYANA KAZAKOVA	{"phone": "+70151410700"}
0005433715308	CE5CF1	7162 168383	ANNA MIKHAYLOVA	{"email": "mikhaylova-anna-111989@postgrespro.ru", "phone": "+70556593964"}
0005433715309	ECBA04	5758 046558	NIKOLAY IVANOV	{"email": "nikolay-ivanov-12011970@postgrespro.ru", "phone": "+70619278056"}
0005433715432	DB7671	3096 915201	INESSA POLYAKOVA	{"phone": "+70759467033"}
0005433715310	CEECAF	4095 115591	ALEKSEY YAKOVLEV	{"email": "aleksey.yakovlev-091967@postgrespro.ru", "phone": "+70504059802"}
0005433715311	CEECAF	8562 230673	SVETLANA MOISEEVA	{"phone": "+70946997467"}
0005433715312	72E76C	2144 547219	ALEKSANDR SOKOLOV	{"email": "asokolov-1963@postgrespro.ru", "phone": "+70126860233"}
0005433715313	2E88EC	5744 436615	SERGEY MELNIKOV	{"phone": "+70121739354"}
0005433715314	9BF7AE	7070 625952	DMITRIY NIKITIN	{"email": "dmitriy-nikitin.24071967@postgrespro.ru", "phone": "+70983115681"}
0005433715315	9BF7AE	1760 112084	NINA IVANOVA	{"phone": "+70199389034"}
0005433715316	2E0B32	0502 387922	GENNADIY SMIRNOV	{"email": "smirnov.gennadiy.16091979@postgrespro.ru", "phone": "+70819955013"}
0005433715317	10ABF3	0117 304398	NIKITA IVANOV	{"phone": "+70053741089"}
0005433715318	688A2E	0317 517058	ANDREY PAVLOV	{"email": "andrey_pavlov_1975@postgrespro.ru", "phone": "+70845029097"}
0005433715319	688A2E	8925 417828	ANTON VASILEV	{"phone": "+70041396511"}
0005433715320	7D49A6	6038 141877	SVETLANA YUDINA	{"phone": "+70323098853"}
0005433715321	7D49A6	2205 462117	OKSANA KUDRYASHOVA	{"phone": "+70854684381"}
0005433715322	DA2751	7588 515845	ALENA FOMINA	{"phone": "+70360440060"}
0005433715323	DA2751	7799 307438	ARTEM SMIRNOV	{"phone": "+70134046165"}
0005433715324	9F13C6	8717 127530	NATALYA MELNIKOVA	{"phone": "+70838508724"}
0005433715325	9F13C6	2465 318714	TATYANA MATVEEVA	{"email": "matveevat.12121987@postgrespro.ru", "phone": "+70246223339"}
0005433715326	BD6E7B	0833 883133	ANDREY MAKSIMOV	{"phone": "+70329319229"}
0005433715327	A1E73F	4061 153486	MAKSIM NAZAROV	{"email": "nazarov-maksim31081969@postgrespro.ru", "phone": "+70845856816"}
0005433715328	2E02C7	2169 942165	NATALYA PETROVA	{"email": "petrova_natalya061973@postgrespro.ru", "phone": "+70010679707"}
0005433715329	8BC5F8	9800 031928	ANNA KUZNECOVA	{"email": "anna_kuznecova_15021975@postgrespro.ru", "phone": "+70633729852"}
0005433715330	8BC5F8	4124 712180	EKATERINA OSIPOVA	{"email": "osipovae-011973@postgrespro.ru", "phone": "+70567032880"}
0005433715331	4D95F4	5737 370145	NATALYA BARANOVA	{"email": "n.baranova.101970@postgrespro.ru", "phone": "+70394017377"}
0005433715332	B6FB20	5527 349141	MARIYA ZAKHAROVA	{"email": "mariya.zakharova_051978@postgrespro.ru", "phone": "+70931353878"}
0005433715333	B6FB20	4775 613797	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov_19041973@postgrespro.ru", "phone": "+70043669959"}
0005433715334	4FB553	0631 252600	NIKITA KUZNECOV	{"email": "n_kuznecov.16081971@postgrespro.ru", "phone": "+70691397319"}
0005433715335	E02A72	4381 482421	ALEKSANDR KARPOV	{"phone": "+70000106764"}
0005433715336	E02A72	0185 676615	ELENA STEPANOVA	{"phone": "+70826418380"}
0005433715337	490D18	7900 529982	NINA PAVLOVA	{"email": "pavlova.nina-1975@postgrespro.ru", "phone": "+70555704353"}
0005433715338	85F352	3548 006701	ANTON FILIPPOV	{"phone": "+70338021907"}
0005433715339	85F352	2501 533209	IGOR NAUMOV	{"phone": "+70102307745"}
0005433715340	85F352	1632 998687	ELENA NOVIKOVA	{"email": "e.novikova.031963@postgrespro.ru", "phone": "+70916960667"}
0005433715341	85F352	9472 564597	OLGA FEDOROVA	{"email": "ofedorova.1974@postgrespro.ru", "phone": "+70554948912"}
0005433715342	48D6A8	0799 496384	SERGEY ALEKSANDROV	{"phone": "+70520115743"}
0005433715343	48D6A8	4570 503731	VALENTINA FILATOVA	{"phone": "+70339639767"}
0005433715344	B25DEB	1038 361085	ALEKSANDR AFANASEV	{"phone": "+70430552409"}
0005433715345	E90132	2073 480844	LYUBOV KUZMINA	{"email": "kuzminalyubov-121979@postgrespro.ru", "phone": "+70144273101"}
0005433715346	737920	0611 168115	VERA KONDRATEVA	{"email": "kondratevavera021974@postgrespro.ru", "phone": "+70546220754"}
0005433715347	A34653	4247 070712	ROZALIYA IVANOVA	{"phone": "+70861506162"}
0005433715348	A34653	8150 763766	SVETLANA MAKAROVA	{"phone": "+70271670573"}
0005433715349	6311C8	0828 232631	ELENA DAVYDOVA	{"phone": "+70631766659"}
0005433715350	289646	2733 632945	RAISA FILATOVA	{"phone": "+70200632377"}
0005433715351	7F7F77	2254 147118	MIKHAIL BELOV	{"phone": "+70682562810"}
0005433715352	7F7F77	1020 725489	SAVELIY MAKAROV	{"email": "makarov.saveliy-071968@postgrespro.ru", "phone": "+70160989013"}
0005433715353	81CC1F	7053 109070	EVGENIY SIDOROV	{"email": "sidorovevgeniy20091972@postgrespro.ru", "phone": "+70590960277"}
0005433715354	81CC1F	0442 143911	ELENA KUZNECOVA	{"phone": "+70040382503"}
0005433715355	A99D77	3079 621592	EVGENIY KUZMIN	{"phone": "+70849458366"}
0005433715356	9718EF	1158 915876	EVGENIY ILIN	{"email": "e.ilin-1964@postgrespro.ru", "phone": "+70126964102"}
0005433715357	9718EF	0206 680568	NATALYA NESTEROVA	{"phone": "+70734662337"}
0005433715358	7E17B2	8771 823863	SERGEY NIKOLAEV	{"email": "snikolaev_051967@postgrespro.ru", "phone": "+70121864438"}
0005433715359	7EA079	4575 100414	SERGEY IVANOV	{"email": "s_ivanov-031970@postgrespro.ru", "phone": "+70902562950"}
0005433715360	7EA079	3429 317289	SERGEY KOROLEV	{"phone": "+70449917405"}
0005433715361	1F2207	9728 553864	ALEKSANDR MOROZOV	{"phone": "+70655789956"}
0005433715362	6FEDCC	3916 198839	IVAN NOVIKOV	{"email": "i-novikov.11081973@postgrespro.ru", "phone": "+70700454349"}
0005433715363	435A98	4604 865044	EKATERINA SAVELEVA	{"email": "ekaterina.saveleva.18061970@postgrespro.ru", "phone": "+70131415196"}
0005433715364	435A98	5486 482505	SERGEY SOROKIN	{"phone": "+70095330252"}
0005433715365	508902	0154 847205	OKSANA IVANOVA	{"email": "ivanovao.1977@postgrespro.ru", "phone": "+70523985346"}
0005433715366	B28A4B	2202 985978	ELENA KOVALEVA	{"phone": "+70450430029"}
0005433715367	374415	9492 330945	ALEKSANDRA MELNIKOVA	{"email": "aleksandra-melnikova_01031973@postgrespro.ru", "phone": "+70135207065"}
0005433715368	C3FEF3	1710 258683	ANNA ISAEVA	{"phone": "+70139103726"}
0005433715369	1124E8	4745 984150	INNA BARANOVA	{"email": "i_baranova29041974@postgrespro.ru", "phone": "+70424854759"}
0005433715370	908C31	3945 647523	DIANA ZHUKOVA	{"phone": "+70733538729"}
0005433715371	66E681	7822 307779	KIRILL KAZAKOV	{"email": "kazakovk_30041976@postgrespro.ru", "phone": "+70823346360"}
0005433715372	66E681	5027 397458	YURIY DAVYDOV	{"phone": "+70194767579"}
0005433715373	B3ED3C	7916 175318	ANTON KOZLOV	{"phone": "+70438149340"}
0005433715374	B3ED3C	4612 962505	VITALIY PETROV	{"phone": "+70391105529"}
0005433715375	A80E5B	3075 334758	DMITRIY ZAYCEV	{"email": "dmitriy_zaycev011973@postgrespro.ru", "phone": "+70897716771"}
0005433715376	CC44C7	2750 156382	ALEKSANDR PETROV	{"email": "apetrov_1966@postgrespro.ru", "phone": "+70048018902"}
0005433715377	775223	8016 169493	GALINA KALININA	{"phone": "+70865314336"}
0005433715378	574D08	6966 697067	ELENA YAKOVLEVA	{"email": "eyakovleva_051984@postgrespro.ru", "phone": "+70887374660"}
0005433715379	C1C345	0840 133891	ALEKSANDR BORISOV	{"email": "a.borisov_09061970@postgrespro.ru", "phone": "+70795708789"}
0005433715380	309B0D	9635 647601	TATYANA KARPOVA	{"phone": "+70958616988"}
0005433715381	1E447F	1572 052590	ULYANA MALYSHEVA	{"email": "umalysheva-1975@postgrespro.ru", "phone": "+70207621623"}
0005433715382	CACE75	2392 579015	ILYA KUZNECOV	{"email": "ilya.kuznecov.111981@postgrespro.ru", "phone": "+70147986783"}
0005433715383	92CF5E	8517 627281	EKATERINA BELYAEVA	{"email": "e-belyaeva_081982@postgrespro.ru", "phone": "+70466994806"}
0005433715384	1FA0AC	2549 547804	LYUDMILA FILIPPOVA	{"email": "filippova-lyudmila-23071984@postgrespro.ru", "phone": "+70307105625"}
0005433715385	51710F	9590 942242	MARAT ANTONOV	{"phone": "+70498164572"}
0005433715386	51710F	9779 280474	GULFIYA STEPANOVA	{"email": "stepanova-g-07071983@postgrespro.ru", "phone": "+70564715505"}
0005433715387	74656D	0279 649617	VERA FILIPPOVA	{"phone": "+70786586770"}
0005433715388	2B5DD5	3816 962362	ANATOLIY BARANOV	{"phone": "+70951631774"}
0005433715389	2B5DD5	0938 772426	VALERIY NOVIKOV	{"phone": "+70381344181"}
0005433715390	2B5DD5	5920 237333	EVGENIY KUZNECOV	{"email": "kuznecov.e_29031981@postgrespro.ru", "phone": "+70515626425"}
0005433715391	8B7EC5	7857 837646	LARISA TIKHONOVA	{"email": "larisa.tikhonova-1970@postgrespro.ru", "phone": "+70280422464"}
0005433715392	7D7BEA	0891 114366	VYACHESLAV VASILEV	{"email": "v.vasilev_121973@postgrespro.ru", "phone": "+70108911541"}
0005433715393	7D7BEA	5698 066909	ALEKSANDR ZAYCEV	{"email": "zaycev_a081962@postgrespro.ru", "phone": "+70281864754"}
0005433715394	907310	6134 253230	VLADIMIR NIKOLAEV	{"phone": "+70723658096"}
0005433715395	94FA10	5191 553339	ANNA SOLOVEVA	{"email": "a_soloveva081983@postgrespro.ru", "phone": "+70360400247"}
0005433715396	94FA10	5070 605069	LYUBOV ZAKHAROVA	{"phone": "+70991942733"}
0005433715397	EB5CB2	9455 575780	OLGA ZAYCEVA	{"email": "o-zayceva.031974@postgrespro.ru", "phone": "+70110823750"}
0005433715398	C27F52	9041 101551	OLGA PAVLOVA	{"phone": "+70606465003"}
0005433715399	6D13BB	5324 464716	RAFAEL ANTONOV	{"phone": "+70386106771"}
0005433715400	EB2C55	9390 731376	DANIL KUZMIN	{"email": "danil-kuzmin-1975@postgrespro.ru", "phone": "+70445468723"}
0005433715401	085514	7349 024435	NADEZHDA ALEKSEEVA	{"phone": "+70511329048"}
0005433715402	66A382	9310 070718	ALEKSEY MAKAROV	{"email": "a.makarov.091978@postgrespro.ru", "phone": "+70337955611"}
0005433715403	04B969	2155 585785	ARTEM KOZLOV	{"phone": "+70335688075"}
0005433715404	33B7B6	3994 202824	EVGENIY KARPOV	{"phone": "+70403985996"}
0005433715405	14BFC6	4562 872505	ALEKSANDR DENISOV	{"email": "aleksandrdenisov021969@postgrespro.ru", "phone": "+70512280735"}
0005433715406	14BFC6	6860 991239	GRIGORIY DMITRIEV	{"phone": "+70272035642"}
0005433715407	14BFC6	6506 413936	ALENA SOKOLOVA	{"email": "asokolova14031973@postgrespro.ru", "phone": "+70456242962"}
0005433715408	B810EF	7740 048733	VERA TARASOVA	{"phone": "+70342907828"}
0005433715409	05B8CB	7097 437522	SERGEY KRASNOV	{"email": "s-krasnov121978@postgrespro.ru", "phone": "+70306068626"}
0005433715410	05B8CB	8504 516229	OLGA SOKOLOVA	{"email": "olgasokolova_1969@postgrespro.ru", "phone": "+70047307059"}
0005433715411	123997	7614 248561	TAMARA TIMOFEEVA	{"email": "timofeeva_t.21121968@postgrespro.ru", "phone": "+70535847825"}
0005433715412	123997	4601 031062	YURIY ANDREEV	{"phone": "+70185226803"}
0005433715413	C48F0F	8315 032701	SERGEY ZAYCEV	{"email": "sergey-zaycev-14061979@postgrespro.ru", "phone": "+70805181713"}
0005433715414	236459	0225 807554	ELENA SIDOROVA	{"phone": "+70074773364"}
0005433715415	236459	5812 611352	ANDREY SEMENOV	{"phone": "+70084817688"}
0005433715416	D49208	1764 711193	ELENA KRASNOVA	{"phone": "+70892735681"}
0005433715417	D49208	4693 567978	DMITRIY IVANOV	{"phone": "+70547019401"}
0005433715418	76DCDF	1790 120392	SERGEY MOROZOV	{"phone": "+70538983914"}
0005433715419	82EFED	3874 558003	VLADIMIR ZHUKOV	{"phone": "+70386767524"}
0005433715420	122440	3300 940152	VARVARA FEDOROVA	{"phone": "+70476041347"}
0005433715421	122440	7820 161549	GALINA MAKAROVA	{"email": "makarova-galina_121964@postgrespro.ru", "phone": "+70981559574"}
0005433715422	411FFD	1882 956681	TATYANA NESTEROVA	{"phone": "+70470601969"}
0005433715423	411FFD	4350 180377	KONSTANTIN MIRONOV	{"phone": "+70899861241"}
0005433715424	B6F2ED	9519 531332	BORIS ILIN	{"phone": "+70033925952"}
0005433715425	87E475	1989 635247	NINA LUKYANOVA	{"email": "lukyanova_nina_1976@postgrespro.ru", "phone": "+70449328127"}
0005433715426	E9F535	2791 946120	EGOR BONDARENKO	{"email": "bondarenko_e_31071977@postgrespro.ru", "phone": "+70184384962"}
0005433715427	A873BB	3084 991633	SERGEY DAVYDOV	{"phone": "+70792788179"}
0005433715428	A873BB	3194 402320	TATYANA BARANOVA	{"email": "tatyana-baranova_01031977@postgrespro.ru", "phone": "+70285483616"}
0005433715429	D7DDB0	6298 137035	VLADISLAV EGOROV	{"email": "v_egorov041973@postgrespro.ru", "phone": "+70768297123"}
0005433715430	D7DDB0	7008 677578	TAMARA TIMOFEEVA	{"email": "timofeeva_tamara041975@postgrespro.ru", "phone": "+70355597264"}
0005433715431	8CB44A	7867 389669	VLADIMIR KUZNECOV	{"phone": "+70755306647"}
0005433715433	E83352	3864 385664	ANTON KUZNECOV	{"phone": "+70745994897"}
0005433715434	8F1CC8	6142 242848	DIANA FADEEVA	{"email": "diana_fadeeva_071965@postgrespro.ru", "phone": "+70458407631"}
0005433715435	F9E91F	3404 622416	ALEKSANDR KARPOV	{"phone": "+70844216113"}
0005433715436	9C978C	0645 400867	IRINA SMIRNOVA	{"email": "i.smirnova1976@postgrespro.ru", "phone": "+70907969551"}
0005433715493	DFFC02	6661 626509	ANDREY GERASIMOV	{"phone": "+70619599925"}
0005433715437	9C978C	0872 658430	NADEZHDA KOVALEVA	{"email": "nadezhda-kovaleva051978@postgrespro.ru", "phone": "+70590490566"}
0005433715438	9C978C	5802 642926	DMITRIY MATVEEV	{"phone": "+70766930746"}
0005433715439	68B3C5	7886 087249	EVGENIY KRASNOV	{"email": "krasnov-evgeniy_02051973@postgrespro.ru", "phone": "+70642888621"}
0005433715440	C81E7C	8835 594205	ELIZAVETA SOKOLOVA	{"phone": "+70620485486"}
0005433715441	67E77B	3637 814860	GALINA TROFIMOVA	{"email": "galina_trofimova_16091978@postgrespro.ru", "phone": "+70210804620"}
0005433715442	749096	8955 901417	YULIYA VOROBEVA	{"phone": "+70560437162"}
0005433715443	749096	4809 309774	YULIYA FILATOVA	{"email": "filatova-y1965@postgrespro.ru", "phone": "+70934481350"}
0005433715444	749096	3638 577040	ALEKSEY IVANOV	{"phone": "+70343179891"}
0005433715445	65DFA9	5715 225398	NIKOLAY MOISEEV	{"phone": "+70961441071"}
0005433715446	9B0507	9958 240614	VLADISLAV MELNIKOV	{"phone": "+70066574340"}
0005433715447	AD711D	0436 373908	KLAVDIYA FROLOVA	{"email": "frolova-klavdiya02121969@postgrespro.ru", "phone": "+70014790688"}
0005433715448	B62FF0	6817 326014	MIKHAIL SOROKIN	{"phone": "+70854141281"}
0005433715449	B62FF0	7843 479083	SERGEY STEPANOV	{"email": "stepanov-sergey-1975@postgrespro.ru", "phone": "+70758692102"}
0005433715450	91C923	5749 916727	KIRILL SEMENOV	{"email": "k.semenov-14071971@postgrespro.ru", "phone": "+70230448087"}
0005433715451	6DF8E9	8162 853986	ZOYA KUZNECOVA	{"phone": "+70068555499"}
0005433715452	F1CC47	9549 898500	ALEKSANDR DENISOV	{"phone": "+70123227464"}
0005433715453	F1CC47	8136 882102	PAVEL MOISEEV	{"phone": "+70983732600"}
0005433715454	A1D3C0	2472 552939	EVGENIYA GUSEVA	{"email": "guseva_e031981@postgrespro.ru", "phone": "+70210043915"}
0005433715455	A1D3C0	7629 612327	NADEZHDA OSIPOVA	{"phone": "+70569364367"}
0005433715456	0EC3FA	7029 050482	EVDOKIYA YAKOVLEVA	{"phone": "+70654284090"}
0005433715457	0EC3FA	4637 149129	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova1987@postgrespro.ru", "phone": "+70600559765"}
0005433715458	10879C	1888 380307	ILYA ZHURAVLEV	{"phone": "+70865254658"}
0005433715459	395CC3	1979 193222	ALEKSANDRA KOZLOVA	{"email": "kozlovaaleksandra1970@postgrespro.ru", "phone": "+70534636543"}
0005433715460	395CC3	4538 616654	ALEKSANDR VLASOV	{"email": "avlasov_121976@postgrespro.ru", "phone": "+70027288545"}
0005433715461	3CB960	1108 934278	SERGEY STEPANOV	{"phone": "+70733928975"}
0005433715462	3CB960	2097 689873	ANASTASIYA DMITRIEVA	{"email": "a-dmitrieva11101964@postgrespro.ru", "phone": "+70122166916"}
0005433715463	50C00B	5253 621748	VASILIY SHEVCHENKO	{"phone": "+70679041982"}
0005433715464	50C00B	4805 988319	TAMARA ORLOVA	{"phone": "+70744678895"}
0005433715465	040547	0092 680581	VIKTOR MATVEEV	{"email": "matveev-viktor011978@postgrespro.ru", "phone": "+70308448709"}
0005433715466	F9C289	8593 272041	IGOR ZHUKOV	{"email": "igor_zhukov.07111966@postgrespro.ru", "phone": "+70806067546"}
0005433715467	BA90C9	1060 173101	ALEKSEY SEMENOV	{"phone": "+70985100510"}
0005433715468	BA90C9	0708 949347	KSENIYA IVANOVA	{"email": "kseniya_ivanova-29041973@postgrespro.ru", "phone": "+70104550665"}
0005433715469	BA90C9	7018 812974	ARSENIY MARTYNOV	{"email": "arseniymartynov.15051976@postgrespro.ru", "phone": "+70047411022"}
0005433715470	9E2071	0870 412432	ALEKSANDRA FEDOROVA	{"phone": "+70343705727"}
0005433715471	1584B4	8338 814457	ANNA EGOROVA	{"email": "annaegorova_03101977@postgrespro.ru", "phone": "+70888813187"}
0005433715472	7DE180	5832 912927	ANDREY KULIKOV	{"phone": "+70289274318"}
0005433715473	7DE180	8619 199698	ANTONINA ERMAKOVA	{"phone": "+70381005061"}
0005433715474	4A915D	8546 881817	GEORGIY FEDOTOV	{"email": "georgiy.fedotov.1974@postgrespro.ru", "phone": "+70313642972"}
0005433715475	19C407	9567 990059	YURIY ANDREEV	{"email": "andreev_yuriy_091970@postgrespro.ru", "phone": "+70969887202"}
0005433715476	19C407	2087 700031	MAKSIM VASILEV	{"email": "maksimvasilev-081972@postgrespro.ru", "phone": "+70846663732"}
0005433715477	DC07DE	8430 626890	ILYA VASILEV	{"email": "ivasilev_25061968@postgrespro.ru", "phone": "+70671574210"}
0005433715478	CA5E51	4402 585712	ANATOLIY KOZLOV	{"phone": "+70372302284"}
0005433715479	CA5E51	9771 841578	NIKOLAY KOZLOV	{"email": "nikolaykozlov_21021969@postgrespro.ru", "phone": "+70985826595"}
0005433715480	EC28B6	2282 886258	OLEG VASILEV	{"phone": "+70118611105"}
0005433715481	EC28B6	6608 919180	ANATOLIY KULIKOV	{"email": "kulikov_anatoliy_101980@postgrespro.ru", "phone": "+70291546714"}
0005433715482	C6CCF1	1177 026710	ANNA ZAKHAROVA	{"phone": "+70330837387"}
0005433715483	C6CCF1	3518 335308	EVGENIYA ERMAKOVA	{"email": "ermakova_evgeniya1970@postgrespro.ru", "phone": "+70516480306"}
0005433715484	C6CCF1	7437 638392	YULIYA MARTYNOVA	{"email": "martynovay.021980@postgrespro.ru", "phone": "+70200237699"}
0005433715485	5B8918	4963 515746	LIDIYA ZAKHAROVA	{"phone": "+70168245808"}
0005433715486	5B8918	2801 801222	ALEKSEY SIDOROV	{"phone": "+70347208602"}
0005433715487	539030	6180 299289	VIKTORIYA MIKHAYLOVA	{"phone": "+70677934045"}
0005433715488	B72ADC	4766 494532	VALENTINA SERGEEVA	{"phone": "+70999199312"}
0005433715489	B72ADC	4732 408578	IVAN NIKOLAEV	{"email": "i.nikolaev.021983@postgrespro.ru", "phone": "+70127720669"}
0005433715490	6ED064	0160 526156	SERGEY SMIRNOV	{"phone": "+70374612501"}
0005433715491	8027CF	0465 191128	POLINA TITOVA	{"phone": "+70577812829"}
0005433715492	44272D	6064 135527	VASILIY ANDREEV	{"phone": "+70558498279"}
0005433715494	07A39D	2206 075900	TAISA MAKSIMOVA	{"email": "maksimova.taisa1981@postgrespro.ru", "phone": "+70025935797"}
0005433715495	2D2994	4644 485973	MIKHAIL RODIONOV	{"phone": "+70551371433"}
0005433715496	2D2994	0175 177433	OLEG VOLKOV	{"phone": "+70162189538"}
0005433715497	2D2994	1575 722135	NIKOLAY GORBUNOV	{"email": "gorbunovnikolay_021973@postgrespro.ru", "phone": "+70611080768"}
0005433715498	2D2994	4362 531988	ZHANNA FOMINA	{"phone": "+70857254239"}
0005433715499	D956E0	3112 365812	VIKTOR FROLOV	{"email": "vfrolov.08081974@postgrespro.ru", "phone": "+70083527210"}
0005433715500	D956E0	0759 322816	OKSANA KONDRATEVA	{"email": "okondrateva-05101967@postgrespro.ru", "phone": "+70983707988"}
0005433715501	3B117B	0144 040222	MARINA STEPANOVA	{"email": "marinastepanova041969@postgrespro.ru", "phone": "+70724124397"}
0005433715502	FED27C	5643 758275	OLGA SOLOVEVA	{"email": "olgasoloveva_081979@postgrespro.ru", "phone": "+70539236668"}
0005433715503	21EFAA	1061 485141	YULIYA ARKHIPOVA	{"email": "arkhipovay1958@postgrespro.ru", "phone": "+70704057131"}
0005433715504	D83BD5	5644 980455	NATALIYA MIKHAYLOVA	{"phone": "+70416954878"}
0005433715505	9D428A	8826 225611	SERGEY ALEKSEEV	{"phone": "+70936064228"}
0005433715506	9D428A	5856 120440	NATALYA NOVIKOVA	{"phone": "+70208628292"}
0005433715507	9D428A	6916 164962	DANIYA KUZMINA	{"email": "daniya-kuzmina-1968@postgrespro.ru", "phone": "+70715838966"}
0005433715508	090ABA	5519 047416	ANTONINA SMIRNOVA	{"email": "antonina.smirnova-03061979@postgrespro.ru", "phone": "+70426378844"}
0005433715509	D72F61	1632 488476	TATYANA IVANOVA	{"phone": "+70616605399"}
0005433715510	DC2A01	9497 993466	LYUBOV SOROKINA	{"email": "sorokina-lyubov-081976@postgrespro.ru", "phone": "+70626440447"}
0005433715511	DC2A01	2326 143896	LIDIYA KUZNECOVA	{"email": "kuznecova.lidiya1973@postgrespro.ru", "phone": "+70115648103"}
0005433715512	30D925	6886 031307	ALFIYA LOGINOVA	{"email": "alfiyaloginova_1984@postgrespro.ru", "phone": "+70086686588"}
0005433715513	B7ED1B	2714 851008	NIKOLAY MOROZOV	{"email": "nmorozov.101967@postgrespro.ru", "phone": "+70617642255"}
0005433715514	97D427	5136 228060	NIKITA CHERNOV	{"phone": "+70568976654"}
0005433715515	97D427	5127 611858	DENIS MAKAROV	{"email": "makarov_denis-121973@postgrespro.ru", "phone": "+70909234680"}
0005433715516	C8D39C	1675 434779	ALEKSANDR SEMENOV	{"phone": "+70531152108"}
0005433715517	A3CA41	5394 178222	ZINAIDA KARPOVA	{"phone": "+70674159567"}
0005433715518	A3CA41	5786 524804	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr-1966@postgrespro.ru", "phone": "+70131904852"}
0005433715519	34925B	3915 696054	DMITRIY IVANOV	{"phone": "+70152841633"}
0005433715520	4D22CB	2007 819802	NIKOLAY NAUMOV	{"phone": "+70247805239"}
0005433715521	6567AA	5339 320793	NATALYA LOGINOVA	{"email": "loginova-natalya_25061975@postgrespro.ru", "phone": "+70257988190"}
0005433715522	59996A	3382 614658	KONSTANTIN VOROBEV	{"email": "k_vorobev031978@postgrespro.ru", "phone": "+70061984544"}
0005433715523	59996A	7286 338058	ARTEM KUZNECOV	{"email": "artem.kuznecov021978@postgrespro.ru", "phone": "+70804929110"}
0005433715524	D10BAD	5499 313205	MIKHAIL KAZAKOV	{"email": "kazakov.mikhail_31121964@postgrespro.ru", "phone": "+70975217420"}
0005433715525	FB7A12	6878 995074	NADEZHDA LAZAREVA	{"email": "lazareva.nadezhda_041990@postgrespro.ru", "phone": "+70262344868"}
0005433715526	FB7A12	8470 260342	VERA AFANASEVA	{"email": "afanaseva_v-1972@postgrespro.ru", "phone": "+70712679781"}
0005433715527	6F8EB1	3085 521854	VLADIMIR KARPOV	{"email": "vladimir.karpov1972@postgrespro.ru", "phone": "+70830570284"}
0005433715528	2318F3	1974 053284	ANTONINA KUZNECOVA	{"email": "antoninakuznecova.1976@postgrespro.ru", "phone": "+70078710529"}
0005433715529	6758E7	2879 213185	LYUDMILA SIDOROVA	{"phone": "+70965711083"}
0005433715530	9577D4	5042 883152	IVAN VLASOV	{"email": "i.vlasov.041987@postgrespro.ru", "phone": "+70783686421"}
0005433715531	58DDC9	2486 561284	ILYA NIKOLAEV	{"email": "ilya_nikolaev111975@postgrespro.ru", "phone": "+70482239196"}
0005433715532	312CC7	0437 395601	VIKTOR SMIRNOV	{"email": "viktor_smirnov.1964@postgrespro.ru", "phone": "+70892942378"}
0005433715533	972BCB	5078 816520	SERGEY GORBUNOV	{"email": "gorbunov_s.011975@postgrespro.ru", "phone": "+70563448531"}
0005433715534	ACE097	3846 682584	ALEKSANDR ORLOV	{"phone": "+70638146875"}
0005433715535	ACE097	4740 393569	SVETLANA VOROBEVA	{"email": "vorobevasvetlana1977@postgrespro.ru", "phone": "+70578522226"}
0005433715536	AA1280	7526 061942	YULIYA KOLESNIKOVA	{"email": "kolesnikova-yuliya_1971@postgrespro.ru", "phone": "+70095569878"}
0005433715537	1B9A41	3420 554415	ANDREY SOKOLOV	{"phone": "+70081452684"}
0005433715538	1B9A41	1234 672517	RUSLAN ROMANOV	{"email": "romanovruslan_1970@postgrespro.ru", "phone": "+70270835579"}
0005433715539	7D2428	9037 608900	SERGEY ZHUKOV	{"email": "zhukov.s_1977@postgrespro.ru", "phone": "+70913152896"}
0005433715540	26381A	9937 257677	ARTUR POPOV	{"email": "a_popov_14021969@postgrespro.ru", "phone": "+70133479373"}
0005433715541	26381A	1463 496024	NATALIYA EGOROVA	{"phone": "+70590740127"}
0005433715542	26381A	7011 328081	DMITRIY FROLOV	{"phone": "+70411718725"}
0005433715543	3F9844	2992 704131	ARTUR EGOROV	{"phone": "+70118606830"}
0005433715544	99E7DD	2707 398574	PETR KOZLOV	{"email": "p-kozlov.081968@postgrespro.ru", "phone": "+70712977145"}
0005433715545	1E9E0D	8531 428347	ALEKSEY ZAYCEV	{"email": "a.zaycev.05061978@postgrespro.ru", "phone": "+70867731737"}
0005433715546	9E8A67	7150 472554	OLGA KAZAKOVA	{"email": "kazakova-olga_081977@postgrespro.ru", "phone": "+70205451618"}
0005433715547	106FB0	9523 798707	ALENA NAZAROVA	{"email": "a_nazarova041986@postgrespro.ru", "phone": "+70950060927"}
0005433715548	106FB0	8392 008358	PAVEL MIRONOV	{"email": "mironovp121967@postgrespro.ru", "phone": "+70069964288"}
0005433715549	7D9B55	6707 959625	VALERIYA STEPANOVA	{"email": "stepanova.v.011977@postgrespro.ru", "phone": "+70000741251"}
0005433715550	8643BE	0632 561056	MARIYA MALYSHEVA	{"phone": "+70726489815"}
0005433715551	8643BE	4351 687309	MARIYA POPOVA	{"email": "m_popova_11071973@postgrespro.ru", "phone": "+70205159305"}
0005433715552	F1AE25	8007 652230	TATYANA TITOVA	{"phone": "+70290208645"}
0005433715553	03A125	9682 291713	ELENA KUZNECOVA	{"email": "elena.kuznecova1973@postgrespro.ru", "phone": "+70910348157"}
0005433715554	DED0FF	2913 638661	YURIY SAVELEV	{"email": "savelevy21091965@postgrespro.ru", "phone": "+70530546371"}
0005433715555	9BCAA7	7569 589885	ALEKSANDR MAKAROV	{"email": "makarov_a061973@postgrespro.ru", "phone": "+70095559059"}
0005433715556	A653D2	3057 756833	TATYANA IVANOVA	{"phone": "+70829915428"}
0005433715557	4BDA64	2039 353037	ANATOLIY KRASNOV	{"email": "krasnovanatoliy1970@postgrespro.ru", "phone": "+70552936203"}
0005433715558	E36FE7	8372 127654	NINA PAVLOVA	{"phone": "+70126429806"}
0005433715559	6A0787	2344 872566	OLGA ZAKHAROVA	{"phone": "+70565114554"}
0005433715560	E0E84D	9722 899361	VALENTINA NAUMOVA	{"email": "v_naumova_041968@postgrespro.ru", "phone": "+70865521744"}
0005433715561	21EA2C	0635 844830	TATYANA ANTONOVA	{"phone": "+70338391689"}
0005433715562	E64947	1309 083613	LYUBOV GRISHINA	{"phone": "+70189160435"}
0005433715563	E026C4	3073 052785	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev.1977@postgrespro.ru", "phone": "+70773734245"}
0005433715564	0F7738	1784 721691	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-121970@postgrespro.ru", "phone": "+70562620991"}
0005433715565	60AEEE	0388 238011	TAMARA STEPANOVA	{"phone": "+70930616676"}
0005433715566	FB2040	0556 704667	PAVEL BONDARENKO	{"email": "pbondarenko1965@postgrespro.ru", "phone": "+70898296665"}
0005433715567	FB2040	9028 627683	OLGA ALEKSEEVA	{"phone": "+70960155831"}
0005433715568	3EAB90	0233 758128	ALEKSEY NIKOLAEV	{"email": "aleksey.nikolaev05101968@postgrespro.ru", "phone": "+70643995760"}
0005433715569	3EAB90	1602 806680	SERGEY ILIN	{"email": "sergey_ilin.041974@postgrespro.ru", "phone": "+70188724504"}
0005433715570	25D544	4281 520491	ALEKSEY FEDOTOV	{"phone": "+70493318809"}
0005433715571	25D544	9795 930920	ALEKSEY FEDOROV	{"phone": "+70035897080"}
0005433715572	AE0763	6368 614323	NINA POPOVA	{"email": "popova-nina.1978@postgrespro.ru", "phone": "+70156428943"}
0005433715573	AE0763	4550 758194	EVGENIY ALEKSANDROV	{"phone": "+70852459904"}
0005433715574	12506B	8276 772294	ALEKSANDR MIRONOV	{"phone": "+70843097831"}
0005433715575	12506B	7838 251766	OKSANA KUZMINA	{"phone": "+70813068076"}
0005433715576	593B0E	6287 139061	IVAN MAKAROV	{"email": "makarov_ivan-1975@postgrespro.ru", "phone": "+70188814092"}
0005433715577	AE7454	1731 527116	ILYA SEMENOV	{"email": "semenov.i_091967@postgrespro.ru", "phone": "+70456683943"}
0005433715578	AE7454	8721 285382	EKATERINA MOROZOVA	{"phone": "+70321136477"}
0005433715579	D44B06	8631 438308	ARTEM BORISOV	{"email": "borisov_artem_1984@postgrespro.ru", "phone": "+70672282595"}
0005433715580	287265	8158 651490	ALENA ALEKSANDROVA	{"email": "aleksandrova-alena011961@postgrespro.ru", "phone": "+70207652876"}
0005433715581	1C46D9	4472 089903	ANDREY AFANASEV	{"email": "afanasev.andrey1974@postgrespro.ru", "phone": "+70222566453"}
0005433715582	2D22F1	8022 782381	ALEKSANDR SOLOVEV	{"phone": "+70961956077"}
0005433715583	12614C	8982 951349	STANISLAV KULIKOV	{"email": "kulikov.s041971@postgrespro.ru", "phone": "+70736561931"}
0005433715584	A3D8E3	3207 155031	VLADIMIR KAZAKOV	{"phone": "+70957811370"}
0005433715585	6C5585	9250 367893	MIKHAIL ZAKHAROV	{"phone": "+70051866214"}
0005433715586	548F9F	2709 794084	YURIY ANTONOV	{"email": "yuriy-antonov.03101968@postgrespro.ru", "phone": "+70264370400"}
0005433715587	679BD9	5108 396786	LYUBOV TARASOVA	{"email": "tarasovalyubov.1976@postgrespro.ru", "phone": "+70764604956"}
0005433715588	625D4C	7486 774815	OLGA MATVEEVA	{"phone": "+70501398022"}
0005433715589	625D4C	8565 458706	ALEKSANDR SOROKIN	{"email": "sorokin-a-051975@postgrespro.ru", "phone": "+70941604013"}
0005433715590	625D4C	9450 238428	VALENTINA BOGDANOVA	{"email": "bogdanovav.13101968@postgrespro.ru", "phone": "+70304846398"}
0005433715591	C0FDE9	1216 207429	GRIGORIY MEDVEDEV	{"email": "grigoriy_medvedev.27121984@postgrespro.ru", "phone": "+70883997823"}
0005433715592	95103F	6543 339786	LYUBOV BOGDANOVA	{"email": "bogdanoval1971@postgrespro.ru", "phone": "+70396681787"}
0005433715593	95103F	6030 966548	GEORGIY DMITRIEV	{"email": "georgiy.dmitriev.041984@postgrespro.ru", "phone": "+70351972248"}
0005433715594	412C6D	0943 008900	OKSANA SMIRNOVA	{"email": "smirnova-o-031980@postgrespro.ru", "phone": "+70108968454"}
0005433715595	8D4DED	0078 783904	PAVEL PAVLOV	{"phone": "+70186442845"}
0005433715596	33DF89	8566 987004	TAMARA ANTONOVA	{"phone": "+70553491098"}
0005433715597	33DF89	8383 766225	SVETLANA AKIMOVA	{"email": "akimova_svetlana1977@postgrespro.ru", "phone": "+70302867621"}
0005433715598	72C835	6803 914709	LARISA KOVALEVA	{"email": "kovaleval1977@postgrespro.ru", "phone": "+70567252649"}
0005433715599	6CC36A	8103 165697	EVGENIYA ROMANOVA	{"email": "romanova_e-20071967@postgrespro.ru", "phone": "+70062836826"}
0005433715600	7BB62E	6166 042688	SVETLANA MAKAROVA	{"email": "svetlana-makarova_07041968@postgrespro.ru", "phone": "+70362673062"}
0005433715601	4F74C1	7596 825073	TATYANA OSIPOVA	{"email": "t-osipova-25111969@postgrespro.ru", "phone": "+70010470853"}
0005433715602	2427FB	0188 504636	ANDREY NIKOLAEV	{"email": "andrey_nikolaev-1978@postgrespro.ru", "phone": "+70889554740"}
0005433715603	2B8503	3362 813912	SERGEY SIDOROV	{"email": "sergeysidorov.1971@postgrespro.ru", "phone": "+70606210468"}
0005433715604	DC6FC5	5967 487337	ALEKSANDR ORLOV	{"phone": "+70489551657"}
0005433715605	CC4876	8668 171371	ANASTASIYA KISELEVA	{"email": "kiseleva_a1981@postgrespro.ru", "phone": "+70617805037"}
0005433715606	F5A83D	0000 643004	ELENA KOZLOVA	{"phone": "+70100802364"}
0005433715607	846509	7902 164544	SERGEY MATVEEV	{"email": "matveev-sergey1980@postgrespro.ru", "phone": "+70381854914"}
0005433715608	846509	5288 241607	VALENTINA NAZAROVA	{"phone": "+70598057118"}
0005433715671	CB9EB4	8242 035907	ALEKSEY GUSEV	{"phone": "+70372609441"}
0005433715609	211FA6	8083 094666	IGOR IVANOV	{"email": "iivanov_01011986@postgrespro.ru", "phone": "+70922990885"}
0005433715610	A09D21	4119 230808	TAMARA MAKAROVA	{"phone": "+70980847672"}
0005433715611	A09D21	3252 400112	DMITRIY STEPANOV	{"email": "stepanovd.031974@postgrespro.ru", "phone": "+70407173815"}
0005433715612	3CF9B2	3833 781430	ALEKSANDR RODIONOV	{"phone": "+70893215474"}
0005433715613	3CF9B2	5694 744052	VALERIY AFANASEV	{"phone": "+70140761109"}
0005433715614	3F1D91	9967 467441	ANNA SIDOROVA	{"email": "anna-sidorova.1972@postgrespro.ru", "phone": "+70017098261"}
0005433715615	B36631	3370 601893	ANDREY SHEVCHENKO	{"email": "andrey-shevchenko.071958@postgrespro.ru", "phone": "+70060433021"}
0005433715616	3DE1BD	5910 189583	DMITRIY PETROV	{"phone": "+70196280918"}
0005433715617	3DE1BD	9826 079072	ILNUR OSIPOV	{"phone": "+70937702496"}
0005433715618	CA2842	1322 456610	ROMAN KUZNECOV	{"phone": "+70116726229"}
0005433715619	CA2842	0568 806706	VALERIY KUZNECOV	{"phone": "+70694654841"}
0005433715620	38496B	3942 679606	IRINA GAVRILOVA	{"phone": "+70846626090"}
0005433715621	38496B	9652 204258	NATALYA ORLOVA	{"email": "n-orlova_23121965@postgrespro.ru", "phone": "+70079021155"}
0005433715622	38496B	6721 918431	NIKOLAY MAKSIMOV	{"phone": "+70839546898"}
0005433715623	63DE40	9818 851751	TATYANA MARTYNOVA	{"email": "martynova.tatyana-101970@postgrespro.ru", "phone": "+70551188380"}
0005433715624	BDC5E9	2469 663267	NIKOLAY SERGEEV	{"phone": "+70374387941"}
0005433715625	55EF0A	7043 411396	OLGA AFANASEVA	{"phone": "+70961334104"}
0005433715626	F9AE06	1651 943958	DMITRIY ZAKHAROV	{"email": "zakharovdmitriy_28081974@postgrespro.ru", "phone": "+70007365230"}
0005433715627	F9AE06	7008 926702	ALEKSANDR ANDREEV	{"email": "andreev_a_30101968@postgrespro.ru", "phone": "+70793142379"}
0005433715628	5336BB	5242 012276	PAVEL MOROZOV	{"email": "pavel_morozov_061973@postgrespro.ru", "phone": "+70509027437"}
0005433715629	5336BB	8744 490804	SERGEY SEMENOV	{"email": "semenov-sergey.041981@postgrespro.ru", "phone": "+70448760787"}
0005433715630	2141A7	2144 485768	ALEKSEY GERASIMOV	{"email": "aleksey.gerasimov-051969@postgrespro.ru", "phone": "+70592505893"}
0005433715631	2141A7	0162 935770	IGOR SCHERBAKOV	{"phone": "+70161053521"}
0005433715632	E49B79	1742 728675	PAVEL NAZAROV	{"email": "nazarovpavel.1982@postgrespro.ru", "phone": "+70529725040"}
0005433715633	E2E467	4287 527960	NIKOLAY VOROBEV	{"email": "n_vorobev.011954@postgrespro.ru", "phone": "+70851051734"}
0005433715634	E2E467	6402 670303	VENERA STEPANOVA	{"phone": "+70495686135"}
0005433715635	E2E467	3776 798319	DARYA SIDOROVA	{"phone": "+70163372366"}
0005433715636	206323	0423 497704	ANNA BELOVA	{"phone": "+70870538193"}
0005433715637	7B65F0	7121 176002	ALLA LOGINOVA	{"phone": "+70877328856"}
0005433715638	DF35AB	3627 036679	EVGENIY ANDREEV	{"phone": "+70385283000"}
0005433715639	DF35AB	5914 488133	TATYANA AKIMOVA	{"email": "akimova_tatyana.031970@postgrespro.ru", "phone": "+70229939097"}
0005433715640	127BAE	0620 851624	ROMAN MOROZOV	{"phone": "+70263672055"}
0005433715641	71F2D2	4896 223619	ZINAIDA ZHUKOVA	{"email": "zinaidazhukova101977@postgrespro.ru", "phone": "+70055791277"}
0005433715642	0430AE	3827 260044	MIKHAIL SOKOLOV	{"phone": "+70406994253"}
0005433715643	6725D4	1124 882103	KRISTINA KUZNECOVA	{"phone": "+70615580535"}
0005433715644	ABADC2	1299 214643	GENNADIY KUZNECOV	{"email": "g-kuznecov1984@postgrespro.ru", "phone": "+70287468863"}
0005433715645	B69DBE	5413 522403	ALEKSEY DMITRIEV	{"phone": "+70149711828"}
0005433715646	B69DBE	3894 121800	DMITRIY MARTYNOV	{"phone": "+70282920802"}
0005433715647	FE5726	5639 096961	NINA NOVIKOVA	{"email": "novikova.n.27011974@postgrespro.ru", "phone": "+70959167051"}
0005433715648	AC29D2	6971 486286	IGOR ANTONOV	{"phone": "+70193449152"}
0005433715649	13D0A1	2135 470240	ANTONINA ALEKSANDROVA	{"phone": "+70558426344"}
0005433715650	1EA914	0513 519347	DARYA MIRONOVA	{"email": "mironova.d_1973@postgrespro.ru", "phone": "+70859183404"}
0005433715651	8ABDB8	4319 196326	ANASTASIYA KRASNOVA	{"email": "a.krasnova_1968@postgrespro.ru", "phone": "+70112327489"}
0005433715652	DB076B	3883 078866	RENAT MELNIKOV	{"phone": "+70028781059"}
0005433715653	6FFC9A	9316 529346	OKSANA IVANOVA	{"email": "oivanova.111962@postgrespro.ru", "phone": "+70149631065"}
0005433715654	C38651	6136 353558	MAKSIM DMITRIEV	{"email": "maksim-dmitriev_051971@postgrespro.ru", "phone": "+70810701697"}
0005433715655	1B2EB2	1576 002522	NIKOLAY FROLOV	{"email": "frolov.nikolay.28061975@postgrespro.ru", "phone": "+70626141279"}
0005433715656	1B2EB2	3535 787944	OLESYA ZHUKOVA	{"phone": "+70402110364"}
0005433715657	1B2EB2	6263 671089	ARTEM KUZNECOV	{"email": "kuznecov_artem.011973@postgrespro.ru", "phone": "+70049042106"}
0005433715658	2C2A58	9056 574091	OLGA RODIONOVA	{"phone": "+70528654194"}
0005433715659	88A513	9802 500670	LUIZA KUZNECOVA	{"phone": "+70599605874"}
0005433715660	88A513	7073 033931	YURIY SERGEEV	{"phone": "+70041131988"}
0005433715661	598BE6	3645 469566	ANATOLIY FOMIN	{"phone": "+70483737605"}
0005433715662	808DB4	2158 857490	ARTEM KONOVALOV	{"email": "konovalova011968@postgrespro.ru", "phone": "+70878448287"}
0005433715663	808DB4	9921 410332	IRINA BORISOVA	{"email": "i-borisova_06091973@postgrespro.ru", "phone": "+70491760549"}
0005433715664	223320	5325 078018	MIKHAIL KUZMIN	{"email": "mikhail_kuzmin_17101970@postgrespro.ru", "phone": "+70863254847"}
0005433715665	4B5D57	0149 886568	NATALYA ZAKHAROVA	{"phone": "+70892784528"}
0005433715666	4B5D57	0528 563275	EVGENIY FEDOROV	{"phone": "+70950399458"}
0005433715667	11B4BD	3842 688375	VASILIY SOROKIN	{"phone": "+70991511799"}
0005433715668	C57F8A	4301 451928	GRIGORIY MEDVEDEV	{"email": "g_medvedev.041983@postgrespro.ru", "phone": "+70439750891"}
0005433715669	BC82CA	9082 760610	IRINA PETROVA	{"phone": "+70601552114"}
0005433715670	EEA121	2007 490251	TATYANA ANDREEVA	{"phone": "+70511172701"}
0005433715672	A17F52	0690 788649	VLADIMIR POPOV	{"phone": "+70883656933"}
0005433715673	A17F52	4681 256761	ALIYA KOROLEVA	{"email": "koroleva.a021977@postgrespro.ru", "phone": "+70055581605"}
0005433715674	F5063A	6820 266667	VALENTINA POPOVA	{"phone": "+70357010428"}
0005433715675	3C4F49	9872 106239	ELIZAVETA KUZNECOVA	{"email": "kuznecova_e_19081980@postgrespro.ru", "phone": "+70754662052"}
0005433715676	05BA88	1816 417153	VERA NIKITINA	{"email": "nikitinavera-1981@postgrespro.ru", "phone": "+70321504212"}
0005433715677	9D9F0A	3968 999787	LIDIYA VLASOVA	{"email": "lidiyavlasova081981@postgrespro.ru", "phone": "+70473038655"}
0005433715678	9D9F0A	4021 346509	ELENA ORLOVA	{"phone": "+70577891952"}
0005433715679	0B9D7B	0721 364030	ZAKHAR NIKOLAEV	{"email": "nikolaev_zakhar-011974@postgrespro.ru", "phone": "+70070404289"}
0005433715680	9D8060	2186 285670	VALENTINA ZOTOVA	{"email": "v.zotova_1953@postgrespro.ru", "phone": "+70125197891"}
0005433715681	9D8060	1765 419505	VADIM VLASOV	{"email": "vlasov.vadim.1975@postgrespro.ru", "phone": "+70341998971"}
0005433715682	BB3C0D	7924 013346	MAKSIM ABRAMOV	{"email": "maksim-abramov061976@postgrespro.ru", "phone": "+70794766946"}
0005433715683	A0DA26	3491 861929	IVAN MEDVEDEV	{"phone": "+70687725519"}
0005433715684	741EED	6453 550703	ILNAR MAKSIMOV	{"phone": "+70276974513"}
0005433715685	61C71F	9962 474236	SERGEY SERGEEV	{"email": "s_sergeev-031966@postgrespro.ru", "phone": "+70035089938"}
0005433715686	441D33	1742 425415	NIKOLAY PETROV	{"email": "petrov-nikolay_09081976@postgrespro.ru", "phone": "+70729632106"}
0005433715687	0751FA	6454 952955	LILIYA NOVIKOVA	{"email": "novikova.liliya_22121967@postgrespro.ru", "phone": "+70924663179"}
0005433715688	13F2ED	3928 430271	LARISA KRASNOVA	{"email": "l-krasnova1966@postgrespro.ru", "phone": "+70259535075"}
0005433715689	13F2ED	0573 171129	EKATERINA ZOTOVA	{"email": "e-zotova.1973@postgrespro.ru", "phone": "+70931254060"}
0005433715690	65651F	9975 008825	MIKHAIL SERGEEV	{"phone": "+70628536856"}
0005433715691	65651F	1998 405052	VALERIY FEDOTOV	{"phone": "+70932298237"}
0005433715692	EDDC06	4584 044216	MAKSIM SIDOROV	{"email": "sidorov.m-101967@postgrespro.ru", "phone": "+70770808286"}
0005433715693	420611	4377 554754	OKSANA ARKHIPOVA	{"email": "oksana.arkhipova_1979@postgrespro.ru", "phone": "+70528321570"}
0005433715694	420611	0311 533904	SANIYA IVANOVA	{"email": "sivanova.23031970@postgrespro.ru", "phone": "+70504856184"}
0005433715695	0DB5F1	1103 196702	IVAN GUSEV	{"email": "gusev.ivan-1971@postgrespro.ru", "phone": "+70759504900"}
0005433715696	0DB5F1	0741 472370	VALENTINA SOROKINA	{"email": "sorokina.valentina-121981@postgrespro.ru", "phone": "+70442409743"}
0005433715697	0DB5F1	0172 643625	KRISTINA MALYSHEVA	{"email": "k_malysheva.21091965@postgrespro.ru", "phone": "+70538975928"}
0005433715698	9A546B	0816 792153	IRINA ZAKHAROVA	{"phone": "+70710959495"}
0005433715699	9A546B	3571 624356	ANNA KUZMINA	{"phone": "+70369503546"}
0005433715700	7004F0	3214 039508	MIKHAIL EGOROV	{"phone": "+70089636024"}
0005433715701	E427F2	9904 769580	RASHIT PETROV	{"email": "r.petrov_28021980@postgrespro.ru", "phone": "+70687367356"}
0005433715702	E427F2	8573 161224	OLGA BORISOVA	{"phone": "+70172822108"}
0005433715703	B84328	5214 280095	ALEKSANDR GUSEV	{"email": "gusev_aleksandr.011978@postgrespro.ru", "phone": "+70438694220"}
0005433715704	45CFAF	7467 584534	TATYANA STEPANOVA	{"email": "stepanovatatyana-081959@postgrespro.ru", "phone": "+70494452266"}
0005433715705	D66DF1	8119 965622	TATYANA KUZNECOVA	{"phone": "+70444289330"}
0005433715706	D99513	7533 778312	IGOR KOZLOV	{"phone": "+70414788619"}
0005433715707	D99513	6209 757434	VLADISLAV MAKAROV	{"phone": "+70176178862"}
0005433715708	DB94B3	4915 638585	ALEKSEY SCHERBAKOV	{"phone": "+70821479584"}
0005433715709	AF9318	1425 036609	ELENA STEPANOVA	{"phone": "+70282921508"}
0005433715710	AF9318	2505 830455	NADEZHDA FEDOROVA	{"phone": "+70206051851"}
0005433715711	0FF3C7	2235 983231	ZHANNA OVCHINNIKOVA	{"phone": "+70498831684"}
0005433715712	C926B2	3534 666782	SERGEY SCHERBAKOV	{"phone": "+70521155865"}
0005433715713	01D2B2	2709 496766	VLADIMIR BORISOV	{"email": "borisov_vladimir-1979@postgrespro.ru", "phone": "+70249811693"}
0005433715714	72E269	7214 990945	YURIY ALEKSEEV	{"email": "alekseev.yuriy24121975@postgrespro.ru", "phone": "+70138196032"}
0005433715715	18F001	3129 350867	ANNA ABRAMOVA	{"email": "abramova.anna_12041969@postgrespro.ru", "phone": "+70077793610"}
0005433715716	8132CE	8690 860778	PAVEL MOISEEV	{"email": "pavelmoiseev.23041955@postgrespro.ru", "phone": "+70134100201"}
0005433715717	60721D	5207 984763	ANNA MOROZOVA	{"email": "a_morozova_021982@postgrespro.ru", "phone": "+70675920729"}
0005433715718	8EB8D7	4238 219836	DANIIL POPOV	{"email": "popov-d.081967@postgrespro.ru", "phone": "+70575033257"}
0005433715719	8EB8D7	9793 105492	GALINA NESTEROVA	{"email": "nesterova_galina.051971@postgrespro.ru", "phone": "+70995646037"}
0005433715720	95B838	4321 867649	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov121972@postgrespro.ru", "phone": "+70443345200"}
0005433715721	38E72D	5848 323928	ELENA KONDRATEVA	{"email": "kondrateva_elena.1967@postgrespro.ru", "phone": "+70349010250"}
0005433715722	2B6EB0	8890 233250	TATYANA KONDRATEVA	{"email": "t_kondrateva101961@postgrespro.ru", "phone": "+70673669748"}
0005433715723	37A94C	8000 493241	LEONTIY CHERNOV	{"phone": "+70485914389"}
0005433715724	FF3EBE	6368 142254	NURIYA MASLOVA	{"email": "n.maslova_1973@postgrespro.ru", "phone": "+70790306933"}
0005433715725	0F2CA0	1172 108119	KIRILL IVANOV	{"email": "kirill.ivanov-08011965@postgrespro.ru", "phone": "+70521249124"}
0005433715726	B88A0E	2941 806754	MARIYA ALEKSANDROVA	{"email": "m.aleksandrova-101973@postgrespro.ru", "phone": "+70164008331"}
0005433715727	B3350B	4067 131574	ALEKSANDRA MEDVEDEVA	{"email": "medvedeva.aleksandra_041978@postgrespro.ru", "phone": "+70017826848"}
0005433715728	08DD85	6560 914749	SVETLANA SCHERBAKOVA	{"phone": "+70628543898"}
0005433715729	08DD85	9097 167131	LYUDMILA ANDREEVA	{"phone": "+70139820542"}
0005433715730	4ADB5E	0379 401457	MARIYA MATVEEVA	{"email": "m_matveeva-1969@postgrespro.ru", "phone": "+70911365137"}
0005433715731	904188	2230 301322	ALEKSANDR MOISEEV	{"email": "moiseev.a051968@postgrespro.ru", "phone": "+70171604676"}
0005433715732	904188	2905 223385	BORIS PETROV	{"phone": "+70821394708"}
0005433715733	904188	5397 991753	ALEKSANDR ROMANOV	{"phone": "+70944393965"}
0005433715734	560F56	1038 962614	IVAN GERASIMOV	{"email": "i-gerasimov-1973@postgrespro.ru", "phone": "+70351300740"}
0005433715735	3FBA21	3248 031749	NADEZHDA KOZLOVA	{"phone": "+70038616860"}
0005433715736	DAE56E	5550 710458	NINA ILINA	{"email": "n-ilina_09121976@postgrespro.ru", "phone": "+70745792982"}
0005433715737	E29C77	4836 690683	ELENA ISAEVA	{"email": "isaevae.051977@postgrespro.ru", "phone": "+70593780336"}
0005433715738	E29C77	6472 015149	ANNA MALYSHEVA	{"phone": "+70462782671"}
0005433715739	371221	5451 019920	VALENTINA STEPANOVA	{"email": "vstepanova.041973@postgrespro.ru", "phone": "+70740702201"}
0005433715740	EC0A94	0541 052596	OLGA NAZAROVA	{"email": "nazarova.olga.1963@postgrespro.ru", "phone": "+70988568061"}
0005433715741	4769EB	6058 227852	EKATERINA BELOVA	{"phone": "+70682388733"}
0005433715742	4769EB	2599 900747	DMITRIY MAKAROV	{"email": "dmakarov_091973@postgrespro.ru", "phone": "+70537098121"}
0005433715743	E6718A	2627 661267	MATVEY SOKOLOV	{"phone": "+70641605421"}
0005433715744	E6718A	7228 916677	ANATOLIY ROMANOV	{"phone": "+70156739548"}
0005433715745	18BD85	2376 980213	OLGA KOROLEVA	{"email": "okoroleva.031971@postgrespro.ru", "phone": "+70566408617"}
0005433715746	C4C844	4612 487627	ANATOLIY BONDARENKO	{"email": "bondarenko.a-24051972@postgrespro.ru", "phone": "+70592013791"}
0005433715747	204F66	0449 554268	ALEKSANDR MIKHAYLOV	{"phone": "+70611192253"}
0005433715748	63B2D7	2759 608667	DMITRIY FROLOV	{"phone": "+70326565809"}
0005433715749	63B2D7	9246 827765	SERGEY KOZLOV	{"email": "sergey_kozlov-1964@postgrespro.ru", "phone": "+70972067789"}
0005433715750	DE2492	0015 854052	NATALYA KONOVALOVA	{"phone": "+70225018755"}
0005433715751	DE2492	8090 399019	ALBINA KUZNECOVA	{"email": "kuznecova-a-061962@postgrespro.ru", "phone": "+70628366338"}
0005433715752	588368	9695 169762	VLADIMIR SAVELEV	{"phone": "+70798740871"}
0005433715753	2FABA2	9002 042669	VYACHESLAV ZAKHAROV	{"email": "vzakharov.21091966@postgrespro.ru", "phone": "+70077422075"}
0005433715754	2FABA2	9246 670277	YURIY IVANOV	{"email": "ivanov_yuriy_091972@postgrespro.ru", "phone": "+70097529653"}
0005433715755	2169D0	6017 532848	YURIY MAKAROV	{"phone": "+70635479395"}
0005433715756	2169D0	0104 000027	VALENTINA NIKOLAEVA	{"phone": "+70308289759"}
0005433715757	C24AE0	6614 026177	KLAVDIYA PAVLOVA	{"email": "k.pavlova.1974@postgrespro.ru", "phone": "+70556831438"}
0005433715758	1C2FD2	9268 917059	SERGEY POPOV	{"email": "popov_sergey.13041975@postgrespro.ru", "phone": "+70916813090"}
0005433715759	1C2FD2	8175 834446	SVETLANA NAZAROVA	{"email": "nazarova_s-081963@postgrespro.ru", "phone": "+70262437159"}
0005433715760	E5AB3C	5111 452081	LEV ROMANOV	{"phone": "+70440183979"}
0005433715761	E5AB3C	0943 609169	DENIS GRIGOREV	{"email": "denis_grigorev_1973@postgrespro.ru", "phone": "+70372721268"}
0005433715762	E5AB3C	4785 832654	VALENTIN ZAKHAROV	{"phone": "+70304626651"}
0005433715763	B40566	9538 268848	ANDREY VOLKOV	{"email": "volkov-andrey-061968@postgrespro.ru", "phone": "+70579365087"}
0005433715764	CFE033	4136 529599	IRINA ABRAMOVA	{"email": "abramova_i-12061967@postgrespro.ru", "phone": "+70822579302"}
0005433715765	CFE033	2866 623557	SERGEY TIKHONOV	{"email": "s.tikhonov_1984@postgrespro.ru", "phone": "+70664162111"}
0005433715766	0A0895	2870 735943	ALEKSEY TIMOFEEV	{"email": "timofeev_aleksey_26051968@postgrespro.ru", "phone": "+70325309755"}
0005433715767	18A2E1	0690 096425	ANNA SERGEEVA	{"email": "sergeeva_anna_081976@postgrespro.ru", "phone": "+70801854964"}
0005433715768	3FB49C	9004 206475	ALEKSEY MIRONOV	{"email": "mironov-aleksey.051976@postgrespro.ru", "phone": "+70910199190"}
0005433715769	D7093F	7758 942058	VLADIMIR SMIRNOV	{"email": "smirnov-v-07011980@postgrespro.ru", "phone": "+70138700955"}
0005433715770	D7093F	8796 743213	VLADIMIR SMIRNOV	{"email": "vladimirsmirnov011976@postgrespro.ru", "phone": "+70986419655"}
0005433715771	1F20AB	8984 204624	SERGEY FEDOTOV	{"email": "fedotov-sergey_051977@postgrespro.ru", "phone": "+70429757293"}
0005433715772	728E40	9853 724671	SVETLANA SAVELEVA	{"phone": "+70847032556"}
0005433715773	728E40	7697 544983	RUSTAM ALEKSEEV	{"email": "r.alekseev_09101975@postgrespro.ru", "phone": "+70799470613"}
0005433715774	756684	0508 322315	ANTON NAZAROV	{"phone": "+70159104037"}
0005433715775	12B8AB	3554 692108	YULIYA MAKAROVA	{"email": "makarova-y.1971@postgrespro.ru", "phone": "+70779679937"}
0005433715776	70F7DB	3674 830734	EVGENIYA MOISEEVA	{"email": "e-moiseeva_101969@postgrespro.ru", "phone": "+70389175003"}
0005433715777	70F7DB	7018 643349	MIKHAIL NAUMOV	{"email": "mikhail-naumov101975@postgrespro.ru", "phone": "+70628051295"}
0005433715778	6BE568	3313 462077	ALEKSANDR ANTONOV	{"email": "antonovaleksandr11121962@postgrespro.ru", "phone": "+70093811174"}
0005433715779	FACBF1	9019 676225	ANDREY GORBUNOV	{"phone": "+70307790320"}
0005433715780	F83019	7147 105410	NIKOLAY GAVRILOV	{"phone": "+70899755724"}
0005433715781	F83019	5929 309151	YANA CHERNOVA	{"email": "y.chernova.061975@postgrespro.ru", "phone": "+70519764879"}
0005433715782	44643E	8618 918368	VITALIY MOROZOV	{"phone": "+70404643226"}
0005433715783	DF56E2	2773 445049	VALERIY KUZMIN	{"phone": "+70133590753"}
0005433715784	DF56E2	4658 142781	RUSTAM ROMANOV	{"email": "romanov_r.1970@postgrespro.ru", "phone": "+70904866725"}
0005433715785	373544	6356 882709	ALEKSANDR SIDOROV	{"phone": "+70252799581"}
0005433715786	F50F1C	8200 921177	MARIYA DMITRIEVA	{"email": "dmitrievam031964@postgrespro.ru", "phone": "+70241160247"}
0005433715787	82FA6C	1229 095455	ALEKSANDR SIDOROV	{"phone": "+70290641231"}
0005433715788	B26156	2556 024329	TAMARA SOLOVEVA	{"phone": "+70005979749"}
0005433715789	8B0335	0202 133480	ANNA MARTYNOVA	{"email": "annamartynova19071974@postgrespro.ru", "phone": "+70479324191"}
0005433715790	84DF2F	0861 555625	ALEKSANDR PAVLOV	{"email": "a_pavlov_061964@postgrespro.ru", "phone": "+70313401586"}
0005433715791	2A3402	8033 793787	OLGA STEPANOVA	{"phone": "+70008467272"}
0005433715792	2A3402	5245 245818	IRINA KOROLEVA	{"email": "irina.koroleva-21041978@postgrespro.ru", "phone": "+70285972148"}
0005433715793	2A3402	1733 532016	NIKOLAY IVANOV	{"email": "n-ivanov_1972@postgrespro.ru", "phone": "+70462836665"}
0005433715794	152346	7371 280173	RAUZA MIRONOVA	{"phone": "+70685272571"}
0005433715795	6383CF	1452 364388	ANASTASIYA ANTONOVA	{"email": "a-antonova051980@postgrespro.ru", "phone": "+70383527550"}
0005433715796	6383CF	5021 541553	VIKTORIYA ORLOVA	{"email": "orlova.viktoriya_121962@postgrespro.ru", "phone": "+70458535692"}
0005433715797	8D8C22	2686 620951	ANTONINA PETROVA	{"email": "antoninapetrova1975@postgrespro.ru", "phone": "+70803652212"}
0005433715798	8D8C22	2120 768303	LILIYA STEPANOVA	{"phone": "+70916236164"}
0005433715799	1425D4	9177 833112	TATYANA GUSEVA	{"phone": "+70376635347"}
0005433715800	1425D4	0842 076897	ALIYA PETROVA	{"phone": "+70223759558"}
0005433715801	1425D4	8155 567014	TATYANA YUDINA	{"email": "tatyana-yudina.051972@postgrespro.ru", "phone": "+70941816285"}
0005433715802	48331B	1933 027017	MARGARITA ANISIMOVA	{"phone": "+70763553902"}
0005433715803	48331B	4672 305421	VLADISLAV FILIPPOV	{"phone": "+70974735806"}
0005433715804	48331B	7370 802528	OLEG ZAKHAROV	{"phone": "+70242975468"}
0005433715805	F96957	4876 237172	ANTON VLASOV	{"email": "a_vlasov071967@postgrespro.ru", "phone": "+70049254107"}
0005433715806	F96957	8510 022353	IVAN SIDOROV	{"email": "sidorovivan20091968@postgrespro.ru", "phone": "+70190435444"}
0005433715807	D86874	2804 860812	OLGA NOVIKOVA	{"email": "o-novikova.091972@postgrespro.ru", "phone": "+70350346156"}
0005433715808	122A16	8459 674436	TATYANA FADEEVA	{"email": "t.fadeeva-081976@postgrespro.ru", "phone": "+70581011964"}
0005433715809	FC1467	3225 671407	YURIY GORBUNOV	{"email": "gorbunov-yuriy111973@postgrespro.ru", "phone": "+70398443511"}
0005433715810	C3A14C	6321 452148	STANISLAV ZAYCEV	{"phone": "+70606812117"}
0005433715811	9A9B2E	1355 951264	RAISA NIKITINA	{"phone": "+70186573850"}
0005433715812	9A9B2E	6046 234218	VLADIMIR NAUMOV	{"phone": "+70696424684"}
0005433715813	B481B4	4034 726715	NATALYA PAVLOVA	{"phone": "+70631638868"}
0005433715814	133B0E	9604 782826	ALEKSANDRA BELOVA	{"email": "aleksandra-belova-1966@postgrespro.ru", "phone": "+70444068254"}
0005433715815	133B0E	3949 226492	LYUBOV KOLESNIKOVA	{"email": "l_kolesnikova011966@postgrespro.ru", "phone": "+70044792044"}
0005433715816	A57C5F	9365 490017	DENIS ZAYCEV	{"phone": "+70526899898"}
0005433715817	334AAB	0135 131418	ANASTASIYA DENISOVA	{"email": "adenisova-071963@postgrespro.ru", "phone": "+70677384714"}
0005433715818	367ED8	3179 285780	OLGA MALYSHEVA	{"email": "malysheva_olga061969@postgrespro.ru", "phone": "+70758468044"}
0005433715819	E12F21	8014 723838	SVETLANA NOVIKOVA	{"phone": "+70557996346"}
0005433715820	E12F21	2396 604003	VIKTORIYA VOROBEVA	{"email": "viktoriyavorobeva20021971@postgrespro.ru", "phone": "+70536969801"}
0005433715821	2B1187	0002 580885	ANNA GUSEVA	{"phone": "+70164846868"}
0005433715822	D0DFCD	9788 589579	IVAN MAKAROV	{"email": "makarov_ivan_11021967@postgrespro.ru", "phone": "+70367994852"}
0005433715823	7F7B3C	3704 874921	MARIYA PAVLOVA	{"email": "mariya-pavlova02021971@postgrespro.ru", "phone": "+70489914150"}
0005433715824	4ED817	9945 726334	ALEKSEY OSIPOV	{"email": "osipov-aleksey-081966@postgrespro.ru", "phone": "+70727008188"}
0005433715825	4ED817	8709 223682	MARINA IVANOVA	{"email": "marinaivanova_071974@postgrespro.ru", "phone": "+70077079180"}
0005433715826	0CFC82	6103 310014	RINAT PETROV	{"email": "petrov_r-1979@postgrespro.ru", "phone": "+70240536254"}
0005433715827	7F353A	4656 853334	PETR VOLKOV	{"email": "volkov.p.21021965@postgrespro.ru", "phone": "+70897153757"}
0005433715828	2B0448	4071 753498	ALLA KISELEVA	{"email": "a_kiseleva1960@postgrespro.ru", "phone": "+70772673288"}
0005433715829	87F355	7607 560523	SERGEY KOZLOV	{"phone": "+70685101254"}
0005433715830	F55457	0919 721402	ELENA NIKITINA	{"email": "nikitinaelena_1970@postgrespro.ru", "phone": "+70961628113"}
0005433715831	013AA2	0377 044178	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov1973@postgrespro.ru", "phone": "+70067395515"}
0005433715832	F155AC	4374 386363	ISLAM GUSEV	{"email": "gusevislam-011974@postgrespro.ru", "phone": "+70299755185"}
0005433715833	F155AC	3224 248936	SERGEY ROMANOV	{"email": "romanovs.051968@postgrespro.ru", "phone": "+70218882200"}
0005433715834	B3A3C6	2470 475104	VYACHESLAV MAKAROV	{"email": "v-makarov_02021976@postgrespro.ru", "phone": "+70777349846"}
0005433715835	3591B7	6200 899355	KSENIYA KISELEVA	{"email": "kseniya_kiseleva.011966@postgrespro.ru", "phone": "+70965055263"}
0005433715836	3591B7	3853 193911	TATYANA SERGEEVA	{"email": "t_sergeeva_101981@postgrespro.ru", "phone": "+70947592887"}
0005433715837	E36486	3237 985120	EDUARD FROLOV	{"email": "frolov_eduard.1977@postgrespro.ru", "phone": "+70424760350"}
0005433715838	E36486	0515 684337	VLADIMIR SOLOVEV	{"phone": "+70730126511"}
0005433715839	4E1A1D	8354 787173	GENNADIY PAVLOV	{"phone": "+70267899279"}
0005433715840	4E1A1D	6990 237032	NATALYA LAZAREVA	{"phone": "+70194504602"}
0005433715841	91B0CC	0469 206910	OLGA KALININA	{"phone": "+70155605938"}
0005433715842	EC0435	0550 069197	TATYANA ZHUKOVA	{"phone": "+70232545961"}
0005433715843	715D65	6946 246521	NADEZHDA FILIPPOVA	{"phone": "+70781434310"}
0005433715844	715D65	7222 067764	TATYANA YAKOVLEVA	{"phone": "+70820318331"}
0005433715845	F3B3EE	7867 597874	NELLI KUZMINA	{"email": "n-kuzmina.03051976@postgrespro.ru", "phone": "+70550857722"}
0005433715846	F3B3EE	0228 694519	MARIYA KUZNECOVA	{"email": "mariya_kuznecova.1966@postgrespro.ru", "phone": "+70383022209"}
0005433715847	44A009	0083 291266	EVGENIYA FOMINA	{"email": "evgeniya_fomina031963@postgrespro.ru", "phone": "+70994518799"}
0005433715848	EC4117	1179 707766	VYACHESLAV PAVLOV	{"phone": "+70686871497"}
0005433715849	EC4117	4494 079837	TAMARA MAKSIMOVA	{"phone": "+70924688995"}
0005433715850	213D60	0970 869890	NATALYA KISELEVA	{"email": "natalya.kiseleva-29101967@postgrespro.ru", "phone": "+70282643674"}
0005433715851	34D728	0315 574519	DMITRIY PAVLOV	{"phone": "+70197906534"}
0005433715852	73E14B	6624 311547	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr.01111971@postgrespro.ru", "phone": "+70207090720"}
0005433715853	CB5448	3574 230294	ELENA RODIONOVA	{"phone": "+70413649923"}
0005433715854	293190	5958 090173	OLGA NIKITINA	{"email": "nikitinao-18071976@postgrespro.ru", "phone": "+70503796330"}
0005433715855	E3ED23	6680 985430	ALEKSANDR EGOROV	{"phone": "+70732374909"}
0005433715856	89917D	7236 311680	FANIL SIDOROV	{"email": "fsidorov_30041982@postgrespro.ru", "phone": "+70317633433"}
0005433715857	414770	6956 358692	MIKHAIL ZHUKOV	{"phone": "+70449398350"}
0005433715858	414770	4243 663238	ALENA EFIMOVA	{"email": "alena_efimova.1978@postgrespro.ru", "phone": "+70781866463"}
0005433715859	20F545	1159 483378	LYUBOV STEPANOVA	{"phone": "+70544742906"}
0005433715860	E42C66	2815 995815	ANDREY SOROKIN	{"email": "andrey.sorokin26121975@postgrespro.ru", "phone": "+70806521146"}
0005433715861	7AD1BC	1030 337715	ELIZAVETA IVANOVA	{"email": "ivanova.elizaveta-041980@postgrespro.ru", "phone": "+70856465038"}
0005433715862	A06980	8953 356965	TAMARA VASILEVA	{"email": "tamaravasileva_1984@postgrespro.ru", "phone": "+70434622745"}
0005433715863	A06980	9575 271971	OLGA MATVEEVA	{"phone": "+70166758604"}
0005433715864	058F7B	8040 675699	ALEKSANDR ZAYCEV	{"email": "zaycev_a_111975@postgrespro.ru", "phone": "+70794314773"}
0005433715865	058F7B	2757 178845	ELENA TROFIMOVA	{"email": "trofimovaelena-25021974@postgrespro.ru", "phone": "+70168860253"}
0005433715866	96384D	1690 370261	OKSANA SOKOLOVA	{"phone": "+70145034695"}
0005433715867	96384D	6454 684688	VLADIMIR PAVLOV	{"email": "v.pavlov1962@postgrespro.ru", "phone": "+70194152305"}
0005433715868	436900	0962 046170	VLADIMIR MATVEEV	{"phone": "+70772287804"}
0005433715869	436900	7169 867016	SERGEY SERGEEV	{"phone": "+70331824356"}
0005433715870	9EA0DE	5969 968904	ELIZAVETA SMIRNOVA	{"email": "e_smirnova24111980@postgrespro.ru", "phone": "+70738222481"}
0005433715871	3E6325	5671 318433	YAROSLAV DAVYDOV	{"email": "y_davydov07111973@postgrespro.ru", "phone": "+70347619853"}
0005433715872	B46989	3663 931295	ROMAN ALEKSEEV	{"email": "romanalekseev-1974@postgrespro.ru", "phone": "+70339225293"}
0005433715873	210BB8	9550 337521	SERGEY FROLOV	{"phone": "+70713923072"}
0005433715874	17AF53	1164 277378	KRISTINA POPOVA	{"email": "kristina_popova.031975@postgrespro.ru", "phone": "+70737255510"}
0005433715875	0E23F4	9641 550939	ALEKSANDR NAUMOV	{"email": "naumov_aleksandr19051979@postgrespro.ru", "phone": "+70213281752"}
0005433715876	31ACA2	2890 703908	SVETLANA NOVIKOVA	{"email": "novikovasvetlana23041971@postgrespro.ru", "phone": "+70043954881"}
0005433715877	956E9D	8015 134859	OLGA ZOTOVA	{"phone": "+70924034888"}
0005433715878	E2C767	1609 553049	VLADISLAV MAKSIMOV	{"email": "maksimov-vladislav_1976@postgrespro.ru", "phone": "+70069609612"}
0005433715879	42E53A	8062 941037	ANASTASIYA SCHERBAKOVA	{"email": "a.scherbakova.1979@postgrespro.ru", "phone": "+70862667829"}
0005433715880	42E53A	7893 957144	YULIYA ZHURAVLEVA	{"phone": "+70285371796"}
0005433715881	B6844D	9852 552390	IRINA ZAYCEVA	{"phone": "+70307920722"}
0005433715882	D558E2	9834 463679	OLEG ABRAMOV	{"email": "abramovoleg121970@postgrespro.ru", "phone": "+70468414599"}
0005433715883	BC95C8	7144 164789	IRINA ROMANOVA	{"email": "romanova.irina.091978@postgrespro.ru", "phone": "+70770408746"}
0005433715884	4FB4ED	7185 630099	VALENTINA VASILEVA	{"email": "vasileva.v.1975@postgrespro.ru", "phone": "+70642252250"}
0005433715885	4FB4ED	3753 333761	DMITRIY FILIPPOV	{"email": "filippovd.1972@postgrespro.ru", "phone": "+70613813189"}
0005433715886	56CF99	7653 036526	ANASTASIYA DENISOVA	{"phone": "+70310523499"}
0005433715887	DDEFFC	6962 578233	SVETLANA KONDRATEVA	{"phone": "+70648360747"}
0005433715888	4AEEA8	1599 381340	ANATOLIY ZAYCEV	{"email": "anatoliyzaycev14051970@postgrespro.ru", "phone": "+70365024715"}
0005433715889	4AEEA8	3344 095816	EVGENIY STEPANOV	{"email": "estepanov-1974@postgrespro.ru", "phone": "+70079908943"}
0005433715890	44DB45	1878 843229	TATYANA SEMENOVA	{"email": "tatyana.semenova_12121963@postgrespro.ru", "phone": "+70731027311"}
0005433715891	6851F1	8252 338857	YULIYA EGOROVA	{"email": "y.egorova.051986@postgrespro.ru", "phone": "+70004486980"}
0005433715892	A4749D	1315 553266	ANATOLIY TIMOFEEV	{"email": "a-timofeev041966@postgrespro.ru", "phone": "+70361193326"}
0005433715893	F71701	5552 858518	ALEKSEY KISELEV	{"phone": "+70315094657"}
0005433715894	BE4EF7	1111 861704	VALENTINA SMIRNOVA	{"email": "v_smirnova.1976@postgrespro.ru", "phone": "+70747600479"}
0005433715895	BE4EF7	9164 803424	IRINA ZHURAVLEVA	{"phone": "+70585367534"}
0005433715896	ECE402	6099 258642	ANATOLIY YAKOVLEV	{"phone": "+70900413609"}
0005433715897	ECE402	6869 618934	YURIY MAKAROV	{"email": "y.makarov.111978@postgrespro.ru", "phone": "+70421312041"}
0005433715898	265748	3008 753526	SERGEY POPOV	{"phone": "+70335659546"}
0005433715899	265748	1859 592661	RUSLAN VOLKOV	{"phone": "+70726473788"}
0005433715900	CF33F7	0669 957435	VASILIY CHERNOV	{"email": "chernovvasiliy_101967@postgrespro.ru", "phone": "+70485943594"}
0005433715901	CF33F7	6543 585201	OLGA VLASOVA	{"phone": "+70851828917"}
0005433715902	56A411	1874 707223	ANDREY POPOV	{"phone": "+70018766761"}
0005433715903	E9C8ED	1162 527234	VLADIMIR MEDVEDEV	{"phone": "+70899752788"}
0005433715904	FFDBF5	7637 388212	RAFAIL MATVEEV	{"email": "matveev.rafail.071960@postgrespro.ru", "phone": "+70096647146"}
0005433715905	8D8DE5	2431 562660	DENIS KAZAKOV	{"email": "kazakov-d081972@postgrespro.ru", "phone": "+70584055901"}
0005433715906	8D8DE5	2237 177756	TATYANA ZAKHAROVA	{"email": "zakharova.t02121980@postgrespro.ru", "phone": "+70137228662"}
0005433715907	48EE48	6224 459689	SERGEY KISELEV	{"email": "kiselev-sergey1965@postgrespro.ru", "phone": "+70213974162"}
0005433715908	C269E5	9615 866730	IRINA KOZLOVA	{"email": "kozlova_i-071968@postgrespro.ru", "phone": "+70068718713"}
0005433715909	C269E5	5284 785493	ANNA MALYSHEVA	{"phone": "+70821393315"}
0005433715910	A0CBFB	3040 611168	SERGEY BORISOV	{"email": "sborisov1970@postgrespro.ru", "phone": "+70266385758"}
0005433715911	A0CBFB	8797 222723	ARTEM ANDREEV	{"email": "artemandreev.031973@postgrespro.ru", "phone": "+70690694764"}
0005433715912	A0CBFB	6058 891122	LIDIYA POPOVA	{"email": "lidiya-popova.1970@postgrespro.ru", "phone": "+70733972662"}
0005433715913	D04E8C	4763 245522	DMITRIY OSIPOV	{"phone": "+70363259313"}
0005433715914	D04E8C	7768 783200	NIKOLAY BELOV	{"phone": "+70336820523"}
0005433715915	6C9C71	8077 287453	OLGA FILIPPOVA	{"phone": "+70880683795"}
0005433715916	F28326	1851 933076	VIOLETTA PAVLOVA	{"phone": "+70525808628"}
0005433715917	F28326	9240 187184	LARISA BELOVA	{"email": "belova-l-1967@postgrespro.ru", "phone": "+70877470736"}
0005433715918	F28326	6409 657879	OKSANA ALEKSEEVA	{"phone": "+70805185012"}
0005433715919	283FD5	4102 759047	DENIS ALEKSEEV	{"email": "alekseevdenis-061982@postgrespro.ru", "phone": "+70017841507"}
0005433715920	C6E641	9323 037725	RAISA KOVALEVA	{"phone": "+70518067199"}
0005433715921	A09408	4234 782714	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail1971@postgrespro.ru", "phone": "+70001380615"}
0005433715922	4C7264	9136 698677	LYUBOV LEBEDEVA	{"email": "lebedeva_lyubov-1963@postgrespro.ru", "phone": "+70416425129"}
0005433715923	001C89	5490 522567	ANATOLIY SEMENOV	{"email": "a_semenov.1979@postgrespro.ru", "phone": "+70138157299"}
0005433715924	E33DA0	4821 402775	IGOR KOZLOV	{"phone": "+70562357762"}
0005433715925	E74BA2	9092 814113	TATYANA NAUMOVA	{"email": "naumova-tatyana-091979@postgrespro.ru", "phone": "+70812917854"}
0005433715926	259320	8300 658509	ANASTASIYA DMITRIEVA	{"phone": "+70735280170"}
0005433715927	259320	6735 615573	ALLA NOVIKOVA	{"email": "a.novikova_1975@postgrespro.ru", "phone": "+70367958666"}
0005433715928	ABC6A0	1961 834352	LARISA NOVIKOVA	{"email": "larisa.novikova-101975@postgrespro.ru", "phone": "+70665016772"}
0005433715929	C51E31	9973 749495	YULIYA BARANOVA	{"email": "baranova-y.13121966@postgrespro.ru", "phone": "+70077472566"}
0005433715930	C51E31	2487 522788	ARTEM NIKOLAEV	{"phone": "+70329053407"}
0005433715931	E44E71	7826 996829	GALINA NIKITINA	{"phone": "+70549138511"}
0005433715932	E44E71	3845 480386	ANNA ROMANOVA	{"phone": "+70240424317"}
0005433715933	1EA9A2	4382 822665	LARISA FILATOVA	{"email": "filatova.l.1974@postgrespro.ru", "phone": "+70204188064"}
0005433715934	1EA9A2	0969 950533	YURIY ROMANOV	{"email": "romanovy-1960@postgrespro.ru", "phone": "+70266888480"}
0005433715935	7995C7	3447 732827	SVETLANA KOROLEVA	{"email": "svetlanakoroleva-081979@postgrespro.ru", "phone": "+70997948709"}
0005433715936	ABF0FB	4662 953182	TATYANA YAKOVLEVA	{"phone": "+70020506905"}
0005433715937	953651	0880 259582	OLGA KOLESNIKOVA	{"phone": "+70081280687"}
0005433715938	6C85AF	7555 830928	VLADIMIR IVANOV	{"phone": "+70291189837"}
0005433715939	173AFA	2148 728374	ALEKSANDR ISAEV	{"email": "isaev-a-1977@postgrespro.ru", "phone": "+70269541979"}
0005433715940	367780	1252 954857	EVGENIY MAKAROV	{"phone": "+70339756038"}
0005433715941	17418B	2915 131233	SERGEY ALEKSANDROV	{"phone": "+70384707822"}
0005433715942	CCCE59	6514 538882	IRINA FILATOVA	{"email": "filatova_i.1972@postgrespro.ru", "phone": "+70260755550"}
0005433715943	CC5215	0722 137240	VIKTORIYA EGOROVA	{"email": "egorova_viktoriya.061969@postgrespro.ru", "phone": "+70243177147"}
0005433715944	841780	6467 819880	ANASTASIYA CHERNOVA	{"email": "chernova-anastasiya_1966@postgrespro.ru", "phone": "+70166860460"}
0005433715945	AC1BF6	0552 145036	KSENIYA MOROZOVA	{"phone": "+70074284690"}
0005433715946	9E4684	6438 787707	ELENA MOROZOVA	{"email": "emorozova-1968@postgrespro.ru", "phone": "+70749627029"}
0005433715947	9E4684	0971 258797	VIKTOR SERGEEV	{"phone": "+70001984855"}
0005433715948	12D45D	7749 461036	ALEKSANDR CHERNOV	{"phone": "+70371325710"}
0005433715949	C9DBC2	9458 448093	ANTON IVANOV	{"email": "anton.ivanov071965@postgrespro.ru", "phone": "+70373772764"}
0005433715950	40A0E8	9452 622648	RAVILYA ALEKSEEVA	{"email": "alekseeva-ravilya10061982@postgrespro.ru", "phone": "+70818424928"}
0005433715951	C55AFB	2545 594739	ALEKSANDR PETROV	{"phone": "+70642730607"}
0005433715952	D9D27B	0181 136819	OLGA STEPANOVA	{"email": "stepanova_o-071980@postgrespro.ru", "phone": "+70707514472"}
0005433715953	2DC70C	9107 686475	ILYA SAVELEV	{"phone": "+70020975489"}
0005433715954	2DC70C	3770 909980	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr.041974@postgrespro.ru", "phone": "+70244491891"}
0005433715955	F7CD3B	4111 120406	KIRILL TARASOV	{"phone": "+70023315897"}
0005433715956	F7CD3B	3626 608891	NADEZHDA KONOVALOVA	{"email": "n.konovalova-081974@postgrespro.ru", "phone": "+70073630534"}
0005433715957	D658FE	3007 314951	RAVILYA MIRONOVA	{"phone": "+70491449289"}
0005433715958	485732	5702 885044	STANISLAV BELOV	{"email": "stanislav_belov_06101972@postgrespro.ru", "phone": "+70851933652"}
0005433715959	2A3500	3321 669025	EGOR BARANOV	{"phone": "+70665667094"}
0005433715960	376A01	8131 612810	EGOR CHERNOV	{"email": "chernov-e_1975@postgrespro.ru", "phone": "+70008047493"}
0005433715961	560965	2200 429699	SVETLANA AKIMOVA	{"phone": "+70873087162"}
0005433715962	860D2B	9261 288350	DMITRIY SEMENOV	{"phone": "+70564550449"}
0005433715963	D38379	3691 374297	ANTONINA PETROVA	{"phone": "+70284860764"}
0005433715964	1EA1DB	1127 434946	VIOLETTA SEMENOVA	{"email": "v-semenova.031958@postgrespro.ru", "phone": "+70219092388"}
0005433715965	1EA1DB	6804 784270	VADIM DMITRIEV	{"phone": "+70405289498"}
0005433715966	44C2EE	5335 673951	TATYANA MAKSIMOVA	{"email": "maksimova-tatyana031980@postgrespro.ru", "phone": "+70556728449"}
0005433716085	D48237	1409 719013	EMMA NOVIKOVA	{"phone": "+70664505945"}
0005433715967	829E2C	6286 264992	YULIYA NAZAROVA	{"email": "y-nazarova_121976@postgrespro.ru", "phone": "+70435901054"}
0005433715968	829E2C	4512 611913	TATYANA VOLKOVA	{"phone": "+70904908238"}
0005433715969	8014F6	5680 794562	IRINA NESTEROVA	{"phone": "+70267261830"}
0005433715970	EA3B55	1446 549945	ELENA MAKSIMOVA	{"phone": "+70091222452"}
0005433715971	A99CC1	5163 560774	IRINA ERMAKOVA	{"email": "ermakova_i_101964@postgrespro.ru", "phone": "+70105685836"}
0005433715972	725B95	1105 880592	ALENA ROMANOVA	{"email": "a_romanova-1962@postgrespro.ru", "phone": "+70453121818"}
0005433715973	725B95	3565 136998	VLADIMIR KOZLOV	{"phone": "+70628642921"}
0005433715974	22EE5F	9978 181975	TATYANA ZOTOVA	{"email": "t_zotova.09051979@postgrespro.ru", "phone": "+70895296541"}
0005433715975	E829CF	1750 615154	EKATERINA YUDINA	{"phone": "+70019164684"}
0005433715976	D2F740	8545 286582	IGOR DAVYDOV	{"email": "igor_davydov021965@postgrespro.ru", "phone": "+70968567298"}
0005433715977	D2F740	6872 836836	ANNA LAZAREVA	{"phone": "+70780036421"}
0005433715978	8D605B	2945 247432	VASILIY IVANOV	{"phone": "+70878105194"}
0005433715979	0497B0	0190 594618	TATYANA ARKHIPOVA	{"email": "arkhipova.tatyana-1963@postgrespro.ru", "phone": "+70232818255"}
0005433715980	54D34A	7369 766073	EVGENIYA FROLOVA	{"email": "evgeniyafrolova_20081969@postgrespro.ru", "phone": "+70127895957"}
0005433715981	0F4393	3911 070769	ALEKSEY ZHUKOV	{"email": "azhukov.1974@postgrespro.ru", "phone": "+70059390909"}
0005433715982	A37B56	4659 182730	IGOR SMIRNOV	{"email": "igorsmirnov_27091961@postgrespro.ru", "phone": "+70444541742"}
0005433715983	A37B56	6948 558902	VALENTINA SMIRNOVA	{"phone": "+70167907705"}
0005433715984	A37B56	7280 147339	MAKSIM VOROBEV	{"email": "mvorobev_061977@postgrespro.ru", "phone": "+70425748057"}
0005433715985	0EDE4C	8582 629762	MIKHAIL PAVLOV	{"email": "pavlov-mikhail_18051976@postgrespro.ru", "phone": "+70571860295"}
0005433715986	0EDE4C	4638 567640	VLADISLAV PETROV	{"email": "vpetrov.091980@postgrespro.ru", "phone": "+70835980527"}
0005433715987	23EB8D	9204 907649	NATALYA MOROZOVA	{"email": "morozova.natalya-17071972@postgrespro.ru", "phone": "+70043561586"}
0005433715988	279A9E	1492 653825	DARYA ZAYCEVA	{"email": "darya.zayceva10061970@postgrespro.ru", "phone": "+70907206364"}
0005433715989	87CC40	5156 157094	MARIYA ROMANOVA	{"email": "romanova-mariya_061969@postgrespro.ru", "phone": "+70011668181"}
0005433715990	87CC40	7544 714467	VLADISLAV KUZNECOV	{"email": "kuznecov.v.111968@postgrespro.ru", "phone": "+70751707383"}
0005433715991	468618	7241 152414	LYUDMILA EGOROVA	{"email": "egoroval-101973@postgrespro.ru", "phone": "+70534247720"}
0005433715992	BB18B8	2210 472824	KLAVDIYA GERASIMOVA	{"email": "gerasimova_k.1982@postgrespro.ru", "phone": "+70309867690"}
0005433715993	BB18B8	7301 757938	NADEZHDA GERASIMOVA	{"email": "ngerasimova_04021967@postgrespro.ru", "phone": "+70039745042"}
0005433715994	34AC6F	2082 903898	SVETLANA DANILOVA	{"phone": "+70689888454"}
0005433715995	34AC6F	8043 100914	ANZHELA LOGINOVA	{"phone": "+70892451670"}
0005433715996	8CD2D7	8553 588656	SERGEY PETROV	{"phone": "+70781351775"}
0005433715997	4ED225	9219 380220	BOGDAN KUZNECOV	{"phone": "+70177183249"}
0005433715998	4ED225	5566 768583	ALEKSEY KULIKOV	{"email": "kulikov_a12021977@postgrespro.ru", "phone": "+70966273740"}
0005433715999	B0BFE9	5191 660213	DMITRIY ABRAMOV	{"email": "abramov.dmitriy_1959@postgrespro.ru", "phone": "+70702635744"}
0005433716000	B0BFE9	1203 354433	LYUDMILA MIRONOVA	{"email": "l-mironova1968@postgrespro.ru", "phone": "+70795278684"}
0005433716001	6F23CB	3417 965476	VALENTINA EFIMOVA	{"phone": "+70444563096"}
0005433716002	6F23CB	5496 647349	NIKOLAY EGOROV	{"phone": "+70162976867"}
0005433716003	B78EBB	7230 886338	ALEKSEY NAUMOV	{"phone": "+70398603964"}
0005433716004	73384B	4731 072815	ALEKSANDRA TARASOVA	{"phone": "+70956102710"}
0005433716005	124571	8298 068153	NIKOLAY FOMIN	{"phone": "+70202324380"}
0005433716006	C2683F	0033 172579	ANGELINA LUKYANOVA	{"phone": "+70444686001"}
0005433716007	B3C741	2416 397026	DARYA FEDOROVA	{"phone": "+70922130570"}
0005433716008	B3C741	2030 319791	ANASTASIYA IVANOVA	{"email": "a_ivanova-1985@postgrespro.ru", "phone": "+70486087591"}
0005433716009	252D8D	9010 909206	TAMARA BELOVA	{"email": "t.belova061959@postgrespro.ru", "phone": "+70490372574"}
0005433716010	6D6778	2774 691688	BORIS SMIRNOV	{"phone": "+70485902184"}
0005433716011	529B8E	6462 989609	ELIZAVETA KISELEVA	{"email": "e-kiseleva_08061978@postgrespro.ru", "phone": "+70453122231"}
0005433716012	28D672	3778 132759	NATALYA ISAEVA	{"email": "isaeva-n-021955@postgrespro.ru", "phone": "+70462956356"}
0005433716013	28D672	1727 674538	SERGEY FOMIN	{"email": "fomin_s_20111969@postgrespro.ru", "phone": "+70864653012"}
0005433716014	28D672	2344 690698	ROZALIYA ZHUKOVA	{"phone": "+70287939178"}
0005433716015	5F95CA	3276 830375	VIKTOR SOROKIN	{"email": "v-sorokin.13061972@postgrespro.ru", "phone": "+70640526917"}
0005433716016	8E67C0	9193 272264	ROMAN ANTONOV	{"phone": "+70626766424"}
0005433716017	8E67C0	1721 233525	ALBERT RODIONOV	{"email": "albert-rodionov-14121966@postgrespro.ru", "phone": "+70249817789"}
0005433716018	0546CC	3801 776831	ELENA BARANOVA	{"email": "baranova-e05081984@postgrespro.ru", "phone": "+70365857816"}
0005433716019	636803	5886 074517	ALEKSANDR MAKAROV	{"email": "makarov-a.1982@postgrespro.ru", "phone": "+70910149271"}
0005433716020	ABA6BD	0498 975770	YULIYA ISAEVA	{"email": "isaeva.y.111976@postgrespro.ru", "phone": "+70767502819"}
0005433716021	ABA6BD	6524 188162	ALEKSEY FROLOV	{"email": "frolov_aleksey031982@postgrespro.ru", "phone": "+70596354412"}
0005433716022	A1A8B2	7283 864550	RINAT IVANOV	{"email": "rinat-ivanov-1981@postgrespro.ru", "phone": "+70818228354"}
0005433716023	A1A8B2	5112 262462	NAIL PETROV	{"email": "petrov.n.101975@postgrespro.ru", "phone": "+70606372782"}
0005433716024	D33C9E	5563 409952	VLADIMIR ANDREEV	{"email": "andreevvladimir.1965@postgrespro.ru", "phone": "+70685551744"}
0005433716025	1EAF08	8338 978706	DMITRIY MATVEEV	{"phone": "+70418416421"}
0005433716026	1EAF08	4730 604109	GALINA POPOVA	{"email": "g_popova_14111973@postgrespro.ru", "phone": "+70043148865"}
0005433716027	AFB10F	4684 026970	TATYANA SIDOROVA	{"email": "tatyana-sidorova.111980@postgrespro.ru", "phone": "+70430868298"}
0005433716028	AFB10F	3551 988847	VIKTOR SOLOVEV	{"email": "solovev.viktor-111975@postgrespro.ru", "phone": "+70515496809"}
0005433716029	6C9D49	7259 076166	ANDREY ALEKSANDROV	{"email": "aleksandrov.a_1975@postgrespro.ru", "phone": "+70632660516"}
0005433716030	6C9D49	0856 480745	TIMUR KUDRYASHOV	{"phone": "+70592079222"}
0005433716031	D8A8F7	9575 782227	MARINA SAVELEVA	{"phone": "+70178020390"}
0005433716032	046D08	9894 444395	VLADIMIR SOKOLOV	{"email": "v.sokolov.1972@postgrespro.ru", "phone": "+70449692029"}
0005433716033	1A7C2F	0595 536593	LIDIYA VOLKOVA	{"email": "lidiya-volkova_1969@postgrespro.ru", "phone": "+70531571200"}
0005433716034	1A7C2F	1356 392516	PAVEL ISAEV	{"phone": "+70407187638"}
0005433716035	2C1381	4638 325886	TATYANA BOGDANOVA	{"email": "bogdanova-tatyana.111971@postgrespro.ru", "phone": "+70111809471"}
0005433716036	482530	4616 509310	NADEZHDA ARKHIPOVA	{"email": "n-arkhipova.1962@postgrespro.ru", "phone": "+70590859616"}
0005433716037	AC806C	6049 415787	MAKSIM YAKOVLEV	{"email": "yakovlevm.101972@postgrespro.ru", "phone": "+70954718052"}
0005433716038	AC806C	4351 174152	PETR TIKHONOV	{"email": "p_tikhonov-1967@postgrespro.ru", "phone": "+70717538985"}
0005433716039	521F85	9531 073703	ALEKSANDRA DAVYDOVA	{"phone": "+70462137761"}
0005433716040	521F85	8610 885749	ANASTASIYA KUZNECOVA	{"email": "akuznecova_011975@postgrespro.ru", "phone": "+70234554505"}
0005433716041	A87235	4478 185174	VLADIMIR ILIN	{"email": "ilin_v-26041972@postgrespro.ru", "phone": "+70142835052"}
0005433716042	DD8E76	4948 717308	NIKOLAY SOLOVEV	{"email": "nikolay_solovev.111972@postgrespro.ru", "phone": "+70859061663"}
0005433716043	DD8E76	1831 787720	VALENTINA PETROVA	{"email": "petrova_valentina-25051970@postgrespro.ru", "phone": "+70338778033"}
0005433716044	E7A214	4544 766753	LYUBOV DENISOVA	{"email": "denisova-l-05101972@postgrespro.ru", "phone": "+70272093285"}
0005433716045	E7A214	4143 520644	NADEZHDA BELOVA	{"phone": "+70337837215"}
0005433716046	233224	6131 120292	RAISA MOROZOVA	{"email": "morozovaraisa.1968@postgrespro.ru", "phone": "+70886386470"}
0005433716047	233224	8529 834491	YULIYA TIKHONOVA	{"phone": "+70298097662"}
0005433716048	233224	9203 653877	NIKITA VOLKOV	{"phone": "+70914965150"}
0005433716049	233224	0443 055740	EVGENIY YAKOVLEV	{"phone": "+70897516865"}
0005433716050	68C75E	7600 786527	VASILIY ZHURAVLEV	{"email": "zhuravlevv101971@postgrespro.ru", "phone": "+70534155465"}
0005433716051	68C75E	3942 305902	LYUDMILA SAVELEVA	{"phone": "+70252942807"}
0005433716052	A9E700	1193 428556	SVETLANA PAVLOVA	{"phone": "+70304091746"}
0005433716053	A9E700	6214 679042	DMITRIY KOROLEV	{"email": "d.korolev_1960@postgrespro.ru", "phone": "+70246187893"}
0005433716054	3F342F	7723 716345	ALEKSANDR DAVYDOV	{"phone": "+70682393415"}
0005433716055	6EA089	6387 034763	VALENTINA ILINA	{"phone": "+70302775415"}
0005433716056	7D2559	6308 982338	IVAN IVANOV	{"email": "ivan-ivanov.31121974@postgrespro.ru", "phone": "+70788872448"}
0005433716057	C4BB79	7716 004521	ALEKSANDR NIKOLAEV	{"phone": "+70655603592"}
0005433716058	C4BB79	6214 991051	SERGEY FILIPPOV	{"email": "sergeyfilippov_21111966@postgrespro.ru", "phone": "+70476559766"}
0005433716059	BB3508	4426 458085	NINA TIKHONOVA	{"phone": "+70756207736"}
0005433716060	BB3508	4185 001747	TATYANA POTAPOVA	{"phone": "+70421862354"}
0005433716061	BB3508	1741 009226	NATALYA KUZNECOVA	{"phone": "+70247357297"}
0005433716062	2FE11F	5086 041475	NIKOLAY MOISEEV	{"phone": "+70480823706"}
0005433716063	46D2E7	5825 472552	VALENTINA ZAYCEVA	{"email": "valentinazayceva_01031966@postgrespro.ru", "phone": "+70421479096"}
0005433716064	46D2E7	2944 134910	STANISLAV BORISOV	{"email": "borisov-s_021965@postgrespro.ru", "phone": "+70089563566"}
0005433716065	93D568	7898 044615	GENNADIY KULIKOV	{"email": "kulikov_gennadiy.111960@postgrespro.ru", "phone": "+70138045484"}
0005433716066	93D568	1797 092470	NIKOLAY MOISEEV	{"email": "nikolay.moiseev28041968@postgrespro.ru", "phone": "+70659551014"}
0005433716067	F95C3A	2552 106918	EVGENIYA MOISEEVA	{"email": "evgeniya_moiseeva-29091975@postgrespro.ru", "phone": "+70249825247"}
0005433716068	ACF0E9	7914 860413	ANTON ZAKHAROV	{"phone": "+70688148491"}
0005433716069	B802AE	1751 050996	ALEKSEY IVANOV	{"phone": "+70841334920"}
0005433716070	B802AE	0635 659566	MARGARITA MAKAROVA	{"phone": "+70989690190"}
0005433716071	064B8C	8364 319904	GEORGIY IVANOV	{"email": "georgiy-ivanov.1973@postgrespro.ru", "phone": "+70418669163"}
0005433716072	064B8C	4849 488265	DENIS MATVEEV	{"email": "matveev.denis021974@postgrespro.ru", "phone": "+70004126540"}
0005433716073	1E4D39	6240 239925	ANNA SMIRNOVA	{"email": "smirnova.a_1962@postgrespro.ru", "phone": "+70409326585"}
0005433716074	E0669D	4591 838642	KSENIYA YUDINA	{"phone": "+70351886731"}
0005433716075	2A8F2C	9065 098708	PAVEL TARASOV	{"phone": "+70347088375"}
0005433716076	2A8F2C	6968 840219	OLESYA NAUMOVA	{"email": "naumova-olesya_20061969@postgrespro.ru", "phone": "+70041596898"}
0005433716077	2A8F2C	1757 173572	VALENTINA MAKAROVA	{"phone": "+70784044945"}
0005433716078	A56E17	0110 904605	ALEKSANDR POPOV	{"email": "apopov.17111970@postgrespro.ru", "phone": "+70563491346"}
0005433716079	6CCAD3	3204 615918	MAKSIM POPOV	{"email": "m-popov-071970@postgrespro.ru", "phone": "+70441361648"}
0005433716080	B5A4BB	3367 929115	IGOR TARASOV	{"email": "tarasov_i1969@postgrespro.ru", "phone": "+70304768777"}
0005433716081	65912B	3218 937149	IVAN FOMIN	{"phone": "+70618500020"}
0005433716082	65912B	3937 310460	KAMIL POPOV	{"email": "kamil_popov-1976@postgrespro.ru", "phone": "+70463306429"}
0005433716083	1D1E36	8914 662526	ANNA RYABOVA	{"phone": "+70963854324"}
0005433716084	D48237	0521 134982	OLESYA KALININA	{"email": "olesya-kalinina-12011977@postgrespro.ru", "phone": "+70220776600"}
0005433716086	DEB7BD	0866 570503	LIDIYA ROMANOVA	{"phone": "+70359670019"}
0005433716087	12FA1B	5858 760244	ALEKSEY NOVIKOV	{"email": "anovikov.021969@postgrespro.ru", "phone": "+70455494279"}
0005433716088	12FA1B	9481 900582	MAKSIM MAKAROV	{"email": "makarov_maksim-101970@postgrespro.ru", "phone": "+70333230851"}
0005433716089	A75D43	1204 011314	NATALYA KISELEVA	{"email": "n-kiseleva-051979@postgrespro.ru", "phone": "+70838239153"}
0005433716090	A75D43	7088 402646	VITALIY TARASOV	{"email": "tarasov_v011971@postgrespro.ru", "phone": "+70455573541"}
0005433716091	6C2941	5346 762129	ALEKSANDR SMIRNOV	{"phone": "+70414713066"}
0005433716092	9CA653	7981 591078	LYUDMILA SOLOVEVA	{"email": "lyudmila-soloveva_09111967@postgrespro.ru", "phone": "+70880011797"}
0005433716093	BC5E24	6749 566446	EVDOKIYA EFREMOVA	{"email": "efremova_e051976@postgrespro.ru", "phone": "+70019290037"}
0005433716094	C222AA	3903 792665	MAKSIM TARASOV	{"phone": "+70992294414"}
0005433716095	1530B7	6245 181002	NIKOLAY BELOV	{"phone": "+70892413693"}
0005433716096	F9C584	7421 533036	LIDIYA ANDREEVA	{"email": "lidiya_andreeva081990@postgrespro.ru", "phone": "+70146608552"}
0005433716097	EBF67F	0722 302915	VLADISLAV FEDOTOV	{"phone": "+70789657734"}
0005433716098	EBF67F	5718 416162	PETR DAVYDOV	{"email": "davydov.petr-13061967@postgrespro.ru", "phone": "+70187824737"}
0005433716099	EBF67F	0278 173702	SVETLANA SEMENOVA	{"email": "semenova-svetlana.101972@postgrespro.ru", "phone": "+70214729490"}
0005433716100	771BA7	5827 397312	VALERIYA SEMENOVA	{"email": "semenovavaleriya-1979@postgrespro.ru", "phone": "+70822958694"}
0005433716101	64EBFD	8866 196665	OLGA KAZAKOVA	{"phone": "+70160700627"}
0005433716102	64EBFD	0212 907419	KRISTINA KISELEVA	{"email": "kristina.kiseleva_07101971@postgrespro.ru", "phone": "+70453837615"}
0005433716103	B39586	2204 046615	VLADIMIR SOROKIN	{"phone": "+70671593318"}
0005433716104	470551	9850 577269	IRINA NAZAROVA	{"phone": "+70190317347"}
0005433716105	3810C0	8533 293512	VALERIY KAZAKOV	{"phone": "+70611634745"}
0005433716106	3810C0	9677 755593	SVETLANA SIDOROVA	{"phone": "+70422287474"}
0005433716107	3810C0	1618 128194	IRINA ZHUKOVA	{"phone": "+70057125928"}
0005433716108	EB8AB8	5427 073770	EVGENIY DAVYDOV	{"phone": "+70221614713"}
0005433716109	CD749D	0841 318473	NIKITA VASILEV	{"email": "vasilev_n04011963@postgrespro.ru", "phone": "+70356301222"}
0005433716110	78BE11	0190 771239	ZOYA TITOVA	{"email": "titova.z.121962@postgrespro.ru", "phone": "+70908884437"}
0005433716111	998CAF	6414 152635	OLGA KOMAROVA	{"email": "komarova-o.111971@postgrespro.ru", "phone": "+70061933725"}
0005433716112	CCAB23	6262 285653	YULIYA MOROZOVA	{"email": "yuliya_morozova-091972@postgrespro.ru", "phone": "+70262884579"}
0005433716113	9504AD	5509 245328	MIKHAIL DMITRIEV	{"email": "mikhail_dmitriev.24101975@postgrespro.ru", "phone": "+70730844032"}
0005433716114	12A8A2	8667 909213	MIKHAIL PAVLOV	{"email": "pavlovmikhail27091990@postgrespro.ru", "phone": "+70224987782"}
0005433716115	12A8A2	7330 604913	ANASTASIYA MIRONOVA	{"phone": "+70499461543"}
0005433716116	762DA8	0419 052613	VIKTORIYA PAVLOVA	{"phone": "+70113549756"}
0005433716117	C4EA3F	7213 510051	SVETLANA MARTYNOVA	{"email": "martynovasvetlana_1968@postgrespro.ru", "phone": "+70842346554"}
0005433716118	F1AB95	6082 303078	IVAN SAVELEV	{"phone": "+70868602349"}
0005433716119	16FC5E	7465 506453	ANNA DMITRIEVA	{"email": "dmitrieva-a-17081964@postgrespro.ru", "phone": "+70213602837"}
0005433716120	16FC5E	0789 222873	ALEKSANDRA SERGEEVA	{"phone": "+70021169636"}
0005433716121	21629D	6369 167400	SVETLANA GORBUNOVA	{"email": "gorbunova-s-101968@postgrespro.ru", "phone": "+70801679168"}
0005433716122	68C91A	3122 104494	PAVEL GORBUNOV	{"phone": "+70989403457"}
0005433716123	B28616	0667 385711	VALERIY MIRONOV	{"phone": "+70966642843"}
0005433716124	534654	6590 443160	PETR ISAEV	{"email": "isaev.p_101971@postgrespro.ru", "phone": "+70889972317"}
0005433716125	BCD845	9068 966770	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr091976@postgrespro.ru", "phone": "+70004768727"}
0005433716126	BCD845	7220 162708	GALINA FROLOVA	{"email": "frolova.g_06021966@postgrespro.ru", "phone": "+70505020201"}
0005433716127	BCD845	7211 459307	NADEZHDA SMIRNOVA	{"email": "nsmirnova_24011980@postgrespro.ru", "phone": "+70613516341"}
0005433716128	A0B6E2	9690 010051	VASILIY PAVLOV	{"email": "pavlov-vasiliy26041969@postgrespro.ru", "phone": "+70069897472"}
0005433716129	A0B6E2	4665 697747	VALERIYA POTAPOVA	{"phone": "+70977334497"}
0005433716130	B4F4EF	8701 422067	ZOYA SOKOLOVA	{"phone": "+70616675633"}
0005433716131	9AFE91	5819 937266	EDUARD ALEKSEEV	{"phone": "+70468521777"}
0005433716132	9AFE91	8337 873318	VALERIY VLASOV	{"email": "vlasov-v_1971@postgrespro.ru", "phone": "+70688334777"}
0005433716133	891FB7	7411 242425	ELENA MEDVEDEVA	{"phone": "+70394581127"}
0005433716134	3223AF	7000 492560	OLGA TITOVA	{"email": "titova-o-21071980@postgrespro.ru", "phone": "+70659738954"}
0005433716135	3223AF	0858 768936	ANDREY NOVIKOV	{"phone": "+70451279399"}
0005433716136	EB4BFD	4739 842109	DANIIL OSIPOV	{"email": "osipovdaniil-071987@postgrespro.ru", "phone": "+70547852807"}
0005433716137	C0F685	1163 808985	YULIYA KISELEVA	{"phone": "+70818786453"}
0005433716138	53119E	1878 163452	VLADIMIR FEDOTOV	{"email": "fedotov_vladimir_1962@postgrespro.ru", "phone": "+70651163906"}
0005433716139	53119E	5172 462816	LARISA SMIRNOVA	{"phone": "+70056334370"}
0005433716140	8E393D	4219 376726	YULIYA STEPANOVA	{"email": "stepanova.y_21031986@postgrespro.ru", "phone": "+70349818306"}
0005433716141	8E393D	6305 524614	ALEVTINA KULIKOVA	{"phone": "+70771245281"}
0005433716142	797A65	9384 005610	PAVEL KUZNECOV	{"phone": "+70911979318"}
0005433716143	797A65	2949 994046	RAFAEL ANDREEV	{"phone": "+70195700109"}
0005433716144	DDC2ED	6986 134174	IRINA CHERNOVA	{"email": "ichernova-071972@postgrespro.ru", "phone": "+70504406129"}
0005433716145	6B8D48	2208 088821	NATALYA ERMAKOVA	{"email": "n_ermakova1975@postgrespro.ru", "phone": "+70515184242"}
0005433716146	6B8D48	8675 558168	YULIYA IVANOVA	{"phone": "+70153345545"}
0005433716147	6B8D48	6015 645151	NATALYA KUDRYASHOVA	{"phone": "+70152420157"}
0005433716148	AC714A	6732 624198	SERGEY GAVRILOV	{"email": "sergeygavrilov.1975@postgrespro.ru", "phone": "+70360628652"}
0005433716149	F76852	1873 878995	TATYANA KUZNECOVA	{"phone": "+70593198285"}
0005433716150	E400FC	8461 948013	ELENA NIKITINA	{"phone": "+70395517652"}
0005433716151	E400FC	4869 326008	NATALYA KUZNECOVA	{"phone": "+70249675545"}
0005433716152	DE406A	6599 696859	NIKOLAY FILIPPOV	{"phone": "+70502643966"}
0005433716153	D249A9	4963 708681	NATALIYA KUZNECOVA	{"email": "kuznecova_nataliya_09111971@postgrespro.ru", "phone": "+70865565763"}
0005433716154	BFA610	3306 306118	VITALIY KUZNECOV	{"email": "vitaliy_kuznecov_081963@postgrespro.ru", "phone": "+70736446619"}
0005433716155	BFA610	8316 973457	ALEKSANDR GUSEV	{"email": "aleksandr.gusev09041969@postgrespro.ru", "phone": "+70477614092"}
0005433716156	0914D9	2624 665051	STANISLAV NAZAROV	{"phone": "+70087665669"}
0005433716157	9EFC62	0437 322144	LIDIYA MEDVEDEVA	{"email": "medvedeval081982@postgrespro.ru", "phone": "+70497843563"}
0005433716158	71F9C9	1942 622376	ALEKSEY SCHERBAKOV	{"email": "scherbakov-a-1976@postgrespro.ru", "phone": "+70844545984"}
0005433716159	F987F0	7700 087029	DMITRIY IVANOV	{"phone": "+70041200008"}
0005433716160	F987F0	0413 618081	NATALIYA GUSEVA	{"email": "guseva.nataliya_1973@postgrespro.ru", "phone": "+70900110188"}
0005433716161	89E2D4	5122 934216	VSEVOLOD ZAKHAROV	{"email": "zakharov.vsevolod_1966@postgrespro.ru", "phone": "+70174366741"}
0005433716162	30AF12	9622 099120	ALEKSEY KUZNECOV	{"phone": "+70056386554"}
0005433716163	7C2112	4134 597223	SERGEY CHERNOV	{"email": "s_chernov.20091973@postgrespro.ru", "phone": "+70805232881"}
0005433716164	6BC491	3216 412138	VITALIY ZAYCEV	{"email": "zaycev_vitaliy-1976@postgrespro.ru", "phone": "+70748632395"}
0005433716165	682C7D	2388 659741	NIKITA VOLKOV	{"email": "volkov_n.011975@postgrespro.ru", "phone": "+70240067825"}
0005433716166	682C7D	9138 771616	VLADIMIR MOISEEV	{"phone": "+70455082188"}
0005433716167	682C7D	1772 722426	VALENTINA MEDVEDEVA	{"email": "medvedeva_valentina.091970@postgrespro.ru", "phone": "+70952243936"}
0005433716168	D1A3E3	4990 126576	IVAN KUZMIN	{"email": "kuzmin-ivan_19111960@postgrespro.ru", "phone": "+70204943891"}
0005433716169	1BA786	9306 849428	ANGELINA BORISOVA	{"email": "borisovaa-14051980@postgrespro.ru", "phone": "+70670340993"}
0005433716170	3F0FA1	7472 972855	ALEKSANDR GAVRILOV	{"email": "gavrilov-aleksandr08071972@postgrespro.ru", "phone": "+70470913696"}
0005433716171	F171D6	0569 317015	NIKOLAY GERASIMOV	{"email": "nikolaygerasimov081982@postgrespro.ru", "phone": "+70565924908"}
0005433716172	F171D6	3888 358303	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov.051955@postgrespro.ru", "phone": "+70594327580"}
0005433716173	39B0E8	1306 256068	DMITRIY FILIPPOV	{"email": "dmitriyfilippov21111967@postgrespro.ru", "phone": "+70215815611"}
0005433716174	9E19BF	5479 296346	LYUBOV POTAPOVA	{"phone": "+70909393456"}
0005433716175	9E19BF	5546 587151	ELIZAVETA FOMINA	{"email": "elizavetafomina_011975@postgrespro.ru", "phone": "+70005007913"}
0005433716176	48F88A	6202 886256	ALEKSANDR VOLKOV	{"phone": "+70940231315"}
0005433716177	48F88A	7354 255784	VLADIMIR GORBUNOV	{"email": "v-gorbunov20061964@postgrespro.ru", "phone": "+70876393603"}
0005433716178	913959	9873 016367	DMITRIY ALEKSANDROV	{"email": "aleksandrov.dmitriy-071972@postgrespro.ru", "phone": "+70302044209"}
0005433716179	19F2FC	3246 515261	ALEKSANDR GAVRILOV	{"phone": "+70257457580"}
0005433716180	19F2FC	4394 621279	VALENTINA ILINA	{"phone": "+70609413354"}
0005433716181	01BD41	1087 864754	ZULFIYA NIKOLAEVA	{"email": "znikolaeva-081965@postgrespro.ru", "phone": "+70351509306"}
0005433716182	E94A4D	1500 667824	VLADIMIR ANTONOV	{"phone": "+70210918147"}
0005433716183	279897	5888 386974	EVGENIYA SIDOROVA	{"email": "e_sidorova_051977@postgrespro.ru", "phone": "+70573142979"}
0005433716184	D021D5	4918 023061	DIANA MOISEEVA	{"phone": "+70174753631"}
0005433716185	75A3F4	0139 372462	ZHANNA PETROVA	{"email": "petrova-zhanna-071959@postgrespro.ru", "phone": "+70051464340"}
0005433716186	38E399	0804 705794	SERGEY EGOROV	{"email": "egorovs-1975@postgrespro.ru", "phone": "+70374856418"}
0005433716187	38E399	8888 068177	IRINA MOROZOVA	{"email": "imorozova-1970@postgrespro.ru", "phone": "+70057210205"}
0005433716188	19B065	5021 568525	NIKITA MARTYNOV	{"email": "nikita_martynov.1970@postgrespro.ru", "phone": "+70485808938"}
0005433716189	C3C59F	8090 959698	LARISA BELYAEVA	{"phone": "+70072832027"}
0005433716190	0CCAE7	2179 489595	ALEKSANDR SOLOVEV	{"email": "solovev_a-1972@postgrespro.ru", "phone": "+70793215380"}
0005433716191	F72534	3403 374829	LYUDMILA POPOVA	{"email": "lyudmila-popova_1978@postgrespro.ru", "phone": "+70046511444"}
0005433716192	34F5F4	4058 845349	VIKTOR BARANOV	{"phone": "+70622956870"}
0005433716193	49EFE3	0135 541489	VYACHESLAV NAZAROV	{"email": "nazarov-v_1979@postgrespro.ru", "phone": "+70627142272"}
0005433716194	49EFE3	7281 771867	ALEKSANDR AFANASEV	{"phone": "+70685709104"}
0005433716195	F92803	5623 595421	ANTON KUZNECOV	{"phone": "+70886033313"}
0005433716196	F6D3AD	0724 534298	TATYANA MIRONOVA	{"email": "tatyanamironova_071982@postgrespro.ru", "phone": "+70822959307"}
0005433716197	6D6237	7536 935136	IGOR MIKHAYLOV	{"email": "i_mikhaylov_011980@postgrespro.ru", "phone": "+70998902178"}
0005433716198	6D6237	6159 726620	GENNADIY ALEKSANDROV	{"phone": "+70882865341"}
0005433716199	17A96A	0414 675353	SERGEY SERGEEV	{"email": "sergeev_sergey-041981@postgrespro.ru", "phone": "+70803671325"}
0005433716200	413F5E	9753 291913	SVETLANA KUZMINA	{"phone": "+70704365389"}
0005433716201	07C242	1593 257944	NIKOLAY POPOV	{"phone": "+70280458647"}
0005433716202	07C242	4074 531889	VALENTINA MOROZOVA	{"phone": "+70953968977"}
0005433716203	CC9500	1133 679743	DENIS ZAKHAROV	{"email": "deniszakharov.12011965@postgrespro.ru", "phone": "+70022275409"}
0005433716204	CC9500	8307 955724	ELENA MALYSHEVA	{"phone": "+70211784187"}
0005433716205	CC9500	4931 138047	ILSHAT DAVYDOV	{"phone": "+70545458620"}
0005433716206	2CB560	4638 267577	NADEZHDA ZAKHAROVA	{"phone": "+70317162734"}
0005433716207	4E1694	3566 155576	ANNA NESTEROVA	{"email": "nesterova-anna-1984@postgrespro.ru", "phone": "+70327398845"}
0005433716208	DEF5D1	0088 766413	ALEKSANDR VASILEV	{"phone": "+70742430313"}
0005433716209	DEF5D1	6150 548930	LIDIYA SAVELEVA	{"email": "saveleva.lidiya_28091967@postgrespro.ru", "phone": "+70296829174"}
0005433716210	2D184E	5031 752324	SVETLANA SEMENOVA	{"email": "svetlana-semenova1968@postgrespro.ru", "phone": "+70801334356"}
0005433716211	B797AC	2117 295218	LYUBOV NAZAROVA	{"phone": "+70686565800"}
0005433716212	AAD458	8796 521103	LYUBOV SOLOVEVA	{"phone": "+70109986899"}
0005433716213	FEC1D1	5761 197057	ROMAN BARANOV	{"email": "romanbaranov.02041963@postgrespro.ru", "phone": "+70895269798"}
0005433716214	FEC1D1	5859 604182	OKSANA OSIPOVA	{"phone": "+70604739747"}
0005433716215	54C69D	0234 741839	NADEZHDA KOVALEVA	{"email": "kovaleva_nadezhda.13041970@postgrespro.ru", "phone": "+70215205978"}
0005433716216	298696	5202 407828	TATYANA FILATOVA	{"phone": "+70161033966"}
0005433716217	B4736D	4141 648937	ALEKSANDR GERASIMOV	{"email": "gerasimov-a31071978@postgrespro.ru", "phone": "+70120498075"}
0005433716218	D35535	2591 391483	VLADIMIR ANDREEV	{"phone": "+70988417901"}
0005433716219	D35535	9408 359825	SERGEY FEDOTOV	{"phone": "+70165311150"}
0005433716220	040AB2	0447 199281	TIMUR KAZAKOV	{"phone": "+70707320654"}
0005433716221	6D6ABC	3963 275312	ANASTASIYA EFREMOVA	{"email": "efremovaanastasiya051966@postgrespro.ru", "phone": "+70096593531"}
0005433716222	A4E2D2	3095 176463	ANDREY KONOVALOV	{"email": "andreykonovalov-06091962@postgrespro.ru", "phone": "+70814935386"}
0005433716223	A4E2D2	6250 447571	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr22011986@postgrespro.ru", "phone": "+70178584417"}
0005433716224	8406BA	9631 925892	MARGARITA KOZLOVA	{"phone": "+70724150169"}
0005433716225	AE9F1C	1771 724251	ALEVTINA SMIRNOVA	{"email": "smirnova_alevtina-1980@postgrespro.ru", "phone": "+70823500205"}
0005433716226	AE9F1C	8485 038848	DENIS ZHURAVLEV	{"phone": "+70620419290"}
0005433716227	DAFA4B	0284 053545	DENIS VASILEV	{"email": "d-vasilev.05101978@postgrespro.ru", "phone": "+70326065823"}
0005433716228	DAFA4B	4013 665010	ALEKSANDRA SIDOROVA	{"phone": "+70623145325"}
0005433716229	C6CF44	9979 372235	PAVEL SMIRNOV	{"phone": "+70761287982"}
0005433716230	627899	8478 620133	OLGA GAVRILOVA	{"email": "o.gavrilova.01011976@postgrespro.ru", "phone": "+70135720831"}
0005433716231	9F9A38	6835 742787	VIKTOR OSIPOV	{"email": "vosipov-1975@postgrespro.ru", "phone": "+70070052882"}
0005433716232	115EC1	5705 961680	ALEKSEY IVANOV	{"phone": "+70118712771"}
0005433716233	115EC1	2967 276138	ZLATA MALYSHEVA	{"phone": "+70361985851"}
0005433716234	BE7F5D	8337 614189	ANATOLIY ORLOV	{"phone": "+70471987489"}
0005433716235	D83460	6348 893591	NADEZHDA ANDREEVA	{"phone": "+70325396084"}
0005433716236	2B89FA	2741 102293	ARTEM ALEKSANDROV	{"email": "artem.aleksandrov-1976@postgrespro.ru", "phone": "+70806026383"}
0005433716237	06CB5F	2077 546255	ANDREY KOZLOV	{"phone": "+70788833094"}
0005433716238	C91D64	5475 229079	DARYA MATVEEVA	{"email": "darya-matveeva_14051974@postgrespro.ru", "phone": "+70159876007"}
0005433716239	AE40B6	7361 035291	ELENA ZAYCEVA	{"email": "e-zayceva31121979@postgrespro.ru", "phone": "+70282823860"}
0005433716240	F01E3A	7093 400210	GERMAN VOLKOV	{"phone": "+70851842558"}
0005433716241	133498	8372 529784	ANATOLIY ROMANOV	{"email": "romanovanatoliy.1972@postgrespro.ru", "phone": "+70380984133"}
0005433716242	133498	8704 573715	SERGEY DMITRIEV	{"email": "dmitrievsergey-24061980@postgrespro.ru", "phone": "+70027690118"}
0005433716243	A67E03	3002 793537	LIDIYA BARANOVA	{"phone": "+70957025477"}
0005433716244	4740F2	0361 553557	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila.1976@postgrespro.ru", "phone": "+70886775486"}
0005433716245	3B4E46	0016 785687	YAROSLAV SAVELEV	{"email": "savelev_y_111975@postgrespro.ru", "phone": "+70404658900"}
0005433716246	3B4E46	0355 147145	VLADIMIR KAZAKOV	{"email": "kazakovv04071962@postgrespro.ru", "phone": "+70116472698"}
0005433716247	80DF56	4552 980244	VIKTOR IVANOV	{"phone": "+70979291950"}
0005433716248	80DF56	4817 738782	SVETLANA ROMANOVA	{"email": "sromanova.10031969@postgrespro.ru", "phone": "+70994319414"}
0005433716249	80DF56	1835 243178	SERGEY KONOVALOV	{"phone": "+70467590890"}
0005433716250	75D544	3857 380491	GALINA BARANOVA	{"phone": "+70928631151"}
0005433716251	8BEFAA	9613 039239	LYUDMILA POTAPOVA	{"email": "lpotapova_02081968@postgrespro.ru", "phone": "+70203944724"}
0005433716252	E9F973	9437 665160	TATYANA GAVRILOVA	{"phone": "+70461452598"}
0005433716253	10D13F	6017 073154	OLGA KULIKOVA	{"phone": "+70679338156"}
0005433716254	ED974E	9983 387574	ALEKSEY SOLOVEV	{"email": "aleksey.solovev-1968@postgrespro.ru", "phone": "+70386159961"}
0005433716255	ED974E	5946 932028	IVAN GERASIMOV	{"email": "i.gerasimov.17101980@postgrespro.ru", "phone": "+70808729719"}
0005433716256	16E98F	1546 844160	MARAT SEMENOV	{"phone": "+70570642951"}
0005433716257	69B444	8317 269825	SERGEY OSIPOV	{"email": "sergeyosipov051968@postgrespro.ru", "phone": "+70066329156"}
0005433716258	5B481D	9308 647065	IRINA SIDOROVA	{"phone": "+70696943720"}
0005433716259	5B481D	1160 692030	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov_1981@postgrespro.ru", "phone": "+70026361167"}
0005433716260	0F4F83	4895 202181	ALEKSANDR BELOV	{"email": "belov_a.1972@postgrespro.ru", "phone": "+70749425544"}
0005433716261	235872	1599 937890	ALEKSANDR ZAYCEV	{"email": "azaycev-081978@postgrespro.ru", "phone": "+70829194677"}
0005433716262	B9C1E5	3035 828850	PAVEL MIRONOV	{"email": "pavelmironov_1971@postgrespro.ru", "phone": "+70330266448"}
0005433716263	B9C1E5	0921 200052	IVAN MATVEEV	{"email": "ivan_matveev-101965@postgrespro.ru", "phone": "+70042450902"}
0005433716264	A3BB2F	7658 754956	MARINA MOROZOVA	{"email": "morozovamarina.101971@postgrespro.ru", "phone": "+70456812342"}
0005433716265	5F813E	4496 434859	VALENTINA BARANOVA	{"email": "v_baranova.17041967@postgrespro.ru", "phone": "+70347828229"}
0005433716266	E6AFF8	1679 508445	VALENTINA BOGDANOVA	{"email": "valentina_bogdanova_05011978@postgrespro.ru", "phone": "+70832741040"}
0005433716267	833C14	3536 481573	ANATOLIY VOLKOV	{"email": "anatoliy-volkov-13121962@postgrespro.ru", "phone": "+70343905954"}
0005433716268	833C14	4931 106334	VIKTOR AFANASEV	{"phone": "+70933461920"}
0005433716269	9A9145	7298 723771	NELLI FILIPPOVA	{"phone": "+70816559214"}
0005433716270	9A9145	2381 487727	NATALYA DENISOVA	{"email": "natalya-denisova-1980@postgrespro.ru", "phone": "+70694358827"}
0005433716271	C74F45	7976 866613	ALEKSANDR OSIPOV	{"email": "a-osipov23041967@postgrespro.ru", "phone": "+70611243601"}
0005433716272	B7FB9B	6772 259371	MARINA SOLOVEVA	{"email": "m.soloveva051989@postgrespro.ru", "phone": "+70020286968"}
0005433716273	B7FB9B	3307 719711	DMITRIY GERASIMOV	{"email": "dmitriygerasimov.24121965@postgrespro.ru", "phone": "+70922200347"}
0005433716274	BCFFD7	5302 317249	IRINA ANTONOVA	{"email": "antonova-i121975@postgrespro.ru", "phone": "+70646687244"}
0005433716275	F982BF	1578 224113	ALEKSANDR DENISOV	{"email": "aleksandr.denisov-1973@postgrespro.ru", "phone": "+70133193079"}
0005433716276	E9B1B1	4515 411914	VLADIMIR VLASOV	{"phone": "+70483072068"}
0005433716277	329534	7113 057795	VLADIMIR SAVELEV	{"phone": "+70145875419"}
0005433716278	329534	4122 803770	VYACHESLAV ANTONOV	{"phone": "+70704409824"}
0005433716279	9DAECE	1632 616732	YULIYA PAVLOVA	{"email": "yuliya_pavlova_051959@postgrespro.ru", "phone": "+70168787941"}
0005433716280	9DAECE	7369 735349	YULIYA DENISOVA	{"phone": "+70835422129"}
0005433716281	9DAECE	3190 857874	LYUDMILA SOLOVEVA	{"phone": "+70821484817"}
0005433716282	79C336	5106 199021	MARINA MIKHAYLOVA	{"email": "marina-mikhaylova.24041968@postgrespro.ru", "phone": "+70718554512"}
0005433716283	79C336	4624 955328	ALEKSANDR FEDOTOV	{"email": "aleksandr_fedotov-04101978@postgrespro.ru", "phone": "+70661178430"}
0005433716284	EE2E18	3903 813736	VLADIMIR ALEKSEEV	{"phone": "+70305135938"}
0005433716285	B413A0	7425 681477	VASILIY NAZAROV	{"phone": "+70864967329"}
0005433716286	B625B7	0840 097463	VITALIY MAKSIMOV	{"phone": "+70269335948"}
0005433716287	5B918E	5043 502689	SVETLANA ROMANOVA	{"phone": "+70790767630"}
0005433716288	5B918E	6433 893200	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_31081971@postgrespro.ru", "phone": "+70436993202"}
0005433716289	10FD66	4870 581625	ANDREY RODIONOV	{"phone": "+70307395543"}
0005433716290	73E446	9700 107041	NIKOLAY MAKAROV	{"email": "nikolay_makarov101972@postgrespro.ru", "phone": "+70161870644"}
0005433716291	A073A5	2313 330990	DMITRIY STEPANOV	{"email": "stepanovd_25121978@postgrespro.ru", "phone": "+70234656186"}
0005433716292	A073A5	5004 717594	OLGA CHERNOVA	{"email": "chernova-olga_1970@postgrespro.ru", "phone": "+70170086232"}
0005433716293	868B1D	0193 877202	ANTON MOISEEV	{"email": "anton_moiseev_1960@postgrespro.ru", "phone": "+70059299739"}
0005433716294	868B1D	2778 275871	ELIZAVETA MELNIKOVA	{"email": "elizaveta_melnikova031982@postgrespro.ru", "phone": "+70426739709"}
0005433716295	020F66	2706 497258	GALINA FOMINA	{"email": "g.fomina081984@postgrespro.ru", "phone": "+70476741866"}
0005433716296	3949D6	0118 452346	ANATOLIY FILIPPOV	{"email": "anatoliy-filippov.111969@postgrespro.ru", "phone": "+70178145960"}
0005433716466	AF3D8F	0409 651376	MARIYA DENISOVA	{"phone": "+70760819878"}
0005433716297	0D4C5D	3279 163672	ANDREY STEPANOV	{"email": "andrey-stepanov_081972@postgrespro.ru", "phone": "+70890491931"}
0005433716298	0118A7	4838 790333	VERA STEPANOVA	{"email": "vera_stepanova.04081976@postgrespro.ru", "phone": "+70774784959"}
0005433716299	CDF6BB	8659 724098	VLADIMIR PAVLOV	{"email": "pavlovv091980@postgrespro.ru", "phone": "+70396299813"}
0005433716300	8D4657	3446 338873	LARISA VASILEVA	{"email": "larisa.vasileva.071977@postgrespro.ru", "phone": "+70850055620"}
0005433716301	0A110F	6408 944942	NATALYA KOMAROVA	{"phone": "+70071899187"}
0005433716302	0A110F	7919 610463	ALEKSANDR GRIGOREV	{"email": "aleksandrgrigorev26121973@postgrespro.ru", "phone": "+70427313761"}
0005433716303	5718D1	6412 996568	VALENTIN MIRONOV	{"phone": "+70731591169"}
0005433716304	DAC27F	3778 574301	VERA KONDRATEVA	{"email": "vera_kondrateva-071982@postgrespro.ru", "phone": "+70057274636"}
0005433716305	CD7512	3382 596854	MARINA MASLOVA	{"phone": "+70870861257"}
0005433716306	031B2A	4033 448656	LYUBOV AFANASEVA	{"phone": "+70309989569"}
0005433716307	755F80	0787 095393	NATALYA EFIMOVA	{"email": "efimovan05041978@postgrespro.ru", "phone": "+70694093001"}
0005433716308	755F80	5703 416644	VASILIY VOROBEV	{"email": "vorobev.vasiliy_1969@postgrespro.ru", "phone": "+70069705278"}
0005433716309	D67B32	9361 835123	DMITRIY ZAYCEV	{"email": "zaycev-d_27031968@postgrespro.ru", "phone": "+70753193274"}
0005433716310	D67B32	7735 737911	EVGENIY EGOROV	{"email": "egorov.e_10031977@postgrespro.ru", "phone": "+70165896250"}
0005433716311	054638	1680 377158	ILYA FILIPPOV	{"phone": "+70961256702"}
0005433716312	054638	4313 823212	TATYANA PETROVA	{"phone": "+70029058922"}
0005433716313	CAEF4E	6559 110324	MIKHAIL NIKOLAEV	{"email": "mikhail_nikolaev.16121976@postgrespro.ru", "phone": "+70093847658"}
0005433716314	E09D62	7356 308058	MARINA KUZMINA	{"email": "kuzmina.marina_12041984@postgrespro.ru", "phone": "+70402479421"}
0005433716315	E09D62	0483 072448	YURIY KUZNECOV	{"phone": "+70021396195"}
0005433716316	8CED77	9050 095663	VIKTOR SMIRNOV	{"email": "smirnovviktor1975@postgrespro.ru", "phone": "+70676106621"}
0005433716317	1C11BB	9135 020681	MARIYA MALYSHEVA	{"phone": "+70383084094"}
0005433716318	2258C3	4275 241260	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr27081970@postgrespro.ru", "phone": "+70307016219"}
0005433716319	80D48E	8956 499008	ALEKSANDR IVANOV	{"email": "ivanova_23051971@postgrespro.ru", "phone": "+70318645264"}
0005433716320	C88E62	3325 491544	YURIY FROLOV	{"email": "yuriy_frolov14021969@postgrespro.ru", "phone": "+70067813008"}
0005433716321	C88E62	0134 096483	NADEZHDA NAUMOVA	{"phone": "+70207598837"}
0005433716322	C88E62	6731 984142	VIKTORIYA KUZNECOVA	{"phone": "+70037582285"}
0005433716323	3B3534	1305 974358	GALINA DENISOVA	{"email": "g-denisova18031975@postgrespro.ru", "phone": "+70031885392"}
0005433716324	CF5F81	3056 522321	ELENA SOLOVEVA	{"email": "e_soloveva_1974@postgrespro.ru", "phone": "+70383561743"}
0005433716381	549782	5983 938611	MARIYA FOMINA	{"phone": "+70309132354"}
0005433716325	8F389E	0502 263273	ANDREY MAKAROV	{"email": "andreymakarov091980@postgrespro.ru", "phone": "+70136192186"}
0005433716326	8F389E	4932 630563	KAROLINA KUDRYASHOVA	{"email": "kudryashovakarolina.01101978@postgrespro.ru", "phone": "+70323850492"}
0005433716327	D8C024	0017 743723	SERGEY ANDREEV	{"phone": "+70159363745"}
0005433716328	D725F8	1310 289435	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr12121957@postgrespro.ru", "phone": "+70150074812"}
0005433716329	0C1284	5100 715604	GALINA PETROVA	{"email": "galina_petrova.121973@postgrespro.ru", "phone": "+70186648155"}
0005433716330	EAC103	1743 124952	ALEKSANDR ISAEV	{"email": "aleksandr.isaev.1954@postgrespro.ru", "phone": "+70991091850"}
0005433716331	7FE94B	6161 370586	DENIS KUZNECOV	{"email": "denis_kuznecov-1969@postgrespro.ru", "phone": "+70864440232"}
0005433716332	8DF692	2585 344591	MIKHAIL FEDOROV	{"phone": "+70169584246"}
0005433716333	8DF692	0739 306461	PAVEL FROLOV	{"email": "frolov.pavel1972@postgrespro.ru", "phone": "+70691397683"}
0005433716334	3C4855	8848 246490	VALENTIN DMITRIEV	{"email": "vdmitriev.09021980@postgrespro.ru", "phone": "+70483866726"}
0005433716335	E1CB63	5029 828755	TATYANA KOROLEVA	{"phone": "+70756540527"}
0005433716336	E1CB63	2509 607463	LYUDMILA LUKYANOVA	{"email": "lyudmilalukyanova_1977@postgrespro.ru", "phone": "+70213883526"}
0005433716337	E1CB63	4614 202358	PAVEL SOKOLOV	{"phone": "+70834056609"}
0005433716338	168CCB	5878 460330	SERGEY DAVYDOV	{"phone": "+70070029574"}
0005433716339	168CCB	9737 640359	ALEKSEY NAZAROV	{"phone": "+70366822311"}
0005433716340	153970	7149 184393	IRINA SOKOLOVA	{"email": "irinasokolova.12091975@postgrespro.ru", "phone": "+70478206136"}
0005433716341	153970	1639 912693	SERGEY ZAKHAROV	{"phone": "+70020174722"}
0005433716342	BB2FB1	0586 101670	MARIYA POPOVA	{"email": "m-popova-27091971@postgrespro.ru", "phone": "+70828393831"}
0005433716343	BAB3F8	0651 835493	ILYA MOISEEV	{"phone": "+70672208356"}
0005433716344	40FFAF	8709 392988	NATALIYA KALININA	{"phone": "+70339826195"}
0005433716345	065B9E	5882 098371	ALEKSEY YAKOVLEV	{"email": "aleksey_yakovlev10011972@postgrespro.ru", "phone": "+70438206123"}
0005433716346	CD80CF	0785 876992	INNA POPOVA	{"phone": "+70844986013"}
0005433716347	7A304B	2407 629708	TAMARA NIKOLAEVA	{"phone": "+70807012494"}
0005433716348	51D667	5645 797878	OLGA DAVYDOVA	{"phone": "+70236003686"}
0005433716349	D5C262	9189 968076	DMITRIY SOLOVEV	{"phone": "+70137143915"}
0005433716350	39B215	1723 972155	VLADIMIR MELNIKOV	{"phone": "+70735945167"}
0005433716467	0CBA6B	8060 305783	TAMARA KUZMINA	{"phone": "+70860504486"}
0005433716351	39B215	7815 709790	VLADIMIR MATVEEV	{"email": "v.matveev.1978@postgrespro.ru", "phone": "+70140395285"}
0005433716352	8D53CF	2669 471595	ALEKSANDR KARPOV	{"phone": "+70556619485"}
0005433716353	8D53CF	4864 932033	ELENA NESTEROVA	{"phone": "+70263721946"}
0005433716354	94833C	2118 088006	NADEZHDA KOZLOVA	{"phone": "+70057822943"}
0005433716355	94833C	8209 196659	RAMIL KOROLEV	{"email": "korolevramil-1969@postgrespro.ru", "phone": "+70925984207"}
0005433716356	94833C	5855 610842	TATYANA TARASOVA	{"email": "tarasovat_26051968@postgrespro.ru", "phone": "+70396022321"}
0005433716357	C2E542	5033 896802	MIKHAIL POPOV	{"phone": "+70073721936"}
0005433716358	C2E542	0516 565677	SERGEY CHERNOV	{"email": "chernov_sergey17101961@postgrespro.ru", "phone": "+70342946002"}
0005433716359	A4D9EA	9598 905320	SVETLANA ANISIMOVA	{"email": "anisimovasvetlana_1974@postgrespro.ru", "phone": "+70983020700"}
0005433716360	A4D9EA	0823 570049	EVGENIYA KOZLOVA	{"phone": "+70515375894"}
0005433716361	A4D9EA	7937 869569	POLINA ISAEVA	{"email": "isaevap1973@postgrespro.ru", "phone": "+70630259331"}
0005433716362	9FE27C	0304 665606	ALEKSANDR BARANOV	{"phone": "+70625912762"}
0005433716363	37E112	8841 484415	ELENA SMIRNOVA	{"phone": "+70422122945"}
0005433716364	37E112	8459 168162	TATYANA IVANOVA	{"email": "ivanovatatyana_011982@postgrespro.ru", "phone": "+70128499316"}
0005433716365	B39AE0	8259 552436	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova-lyudmila031961@postgrespro.ru", "phone": "+70233650976"}
0005433716366	600D4E	4272 410364	GENNADIY ROMANOV	{"phone": "+70563385304"}
0005433716367	600D4E	3499 780777	LYUDMILA KONOVALOVA	{"phone": "+70320770678"}
0005433716368	A795CD	5662 485972	LYUDMILA FROLOVA	{"phone": "+70869994285"}
0005433716369	0CAE20	6240 570322	VALERIYA MIRONOVA	{"phone": "+70556262955"}
0005433716370	0CAE20	8747 103543	RAISA MAKAROVA	{"email": "r-makarova-1973@postgrespro.ru", "phone": "+70282128265"}
0005433716371	D6D01A	3292 403433	ALEKSANDR KISELEV	{"phone": "+70910374451"}
0005433716372	6ECA18	4741 396049	PELAGEYA LEBEDEVA	{"email": "pelageyalebedeva_17011981@postgrespro.ru", "phone": "+70104624175"}
0005433716373	6ECA18	6548 499917	TATYANA KARPOVA	{"phone": "+70652965066"}
0005433716374	21A0E6	8437 977605	RAISA NIKOLAEVA	{"email": "raisanikolaeva.091967@postgrespro.ru", "phone": "+70811491460"}
0005433716375	723E0D	8185 714819	TATYANA ZAKHAROVA	{"phone": "+70482296434"}
0005433716376	723E0D	3590 576894	NATALYA DENISOVA	{"email": "denisova-natalya.121967@postgrespro.ru", "phone": "+70426089212"}
0005433716377	910024	9929 779345	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev_1973@postgrespro.ru", "phone": "+70930530194"}
0005433716378	910024	8841 920536	OLGA ISAEVA	{"phone": "+70562878600"}
0005433716379	CF6DBD	5661 811308	SERGEY SMIRNOV	{"email": "smirnov_s-24091979@postgrespro.ru", "phone": "+70068840064"}
0005433716380	BF2BF9	4170 859091	IRINA KUZNECOVA	{"phone": "+70832894641"}
0005433716382	549782	5625 320732	SERGEY PAVLOV	{"phone": "+70454545194"}
0005433716383	355E5E	9103 830332	OLGA RYABOVA	{"phone": "+70682473396"}
0005433716384	355E5E	5085 187937	NIKOLAY SERGEEV	{"email": "sergeev-nikolay091991@postgrespro.ru", "phone": "+70422702931"}
0005433716385	CA4376	1931 725560	ALEKSANDR IVANOV	{"phone": "+70337946034"}
0005433716386	CA4376	5044 327959	PETR VOROBEV	{"email": "p.vorobev08121981@postgrespro.ru", "phone": "+70814855339"}
0005433716387	145830	0846 292622	SOFIYA NESTEROVA	{"email": "sofiya-nesterova17011971@postgrespro.ru", "phone": "+70316679074"}
0005433716388	615A47	9494 273471	YULIYA VASILEVA	{"phone": "+70515278206"}
0005433716389	231582	0559 462288	DMITRIY IVANOV	{"email": "d-ivanov.031966@postgrespro.ru", "phone": "+70270509068"}
0005433716390	359DC2	9585 494971	SERGEY MIKHAYLOV	{"phone": "+70307574042"}
0005433716391	C148D1	5033 536939	VLADIMIR GORBUNOV	{"email": "v-gorbunov-25051976@postgrespro.ru", "phone": "+70613156004"}
0005433716392	4CBA16	4574 179353	RISHAT KUDRYASHOV	{"phone": "+70241577974"}
0005433716393	0DC66E	6206 276838	ALEKSANDR ZAKHAROV	{"email": "zakharova1977@postgrespro.ru", "phone": "+70995710698"}
0005433716394	0DC66E	8799 405670	MARGARITA FEDOROVA	{"phone": "+70241131275"}
0005433716395	D39447	1394 457380	EVGENIY AFANASEV	{"phone": "+70615265172"}
0005433716396	EE8C01	8941 853720	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov_29021968@postgrespro.ru", "phone": "+70576119572"}
0005433716397	0A7C3F	0904 094611	YURIY BORISOV	{"email": "yuriy.borisov.091968@postgrespro.ru", "phone": "+70475231703"}
0005433716398	0A7C3F	6692 158408	ELENA MASLOVA	{"email": "emaslova1968@postgrespro.ru", "phone": "+70264851908"}
0005433716399	0A7C3F	3375 921000	VALENTINA NIKOLAEVA	{"phone": "+70832059594"}
0005433716400	02A75E	8537 436767	KHALIDA ROMANOVA	{"email": "romanova-k23061984@postgrespro.ru", "phone": "+70181151541"}
0005433716401	FF98B8	4196 325635	SVETLANA ROMANOVA	{"email": "romanova.s041981@postgrespro.ru", "phone": "+70518897117"}
0005433716402	24BC9A	5648 210429	LYUDMILA KOVALEVA	{"email": "kovaleva_lyudmila-31121965@postgrespro.ru", "phone": "+70184197822"}
0005433716403	24BC9A	5147 554084	NINA NOVIKOVA	{"phone": "+70139770445"}
0005433716404	CB75D3	0471 105948	SERGEY RODIONOV	{"phone": "+70037528822"}
0005433716405	CB75D3	2224 980577	VLADIMIR SOROKIN	{"phone": "+70060060824"}
0005433716406	6B6489	7285 182723	LARISA SMIRNOVA	{"email": "larisa.smirnova.1970@postgrespro.ru", "phone": "+70663677607"}
0005433716407	ABC968	1701 932341	LYUBOV KRASNOVA	{"phone": "+70431043332"}
0005433716408	ABC968	1794 191617	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya_1969@postgrespro.ru", "phone": "+70443506830"}
0005433716409	77EC6F	0329 119313	ALEKSANDR KOZLOV	{"phone": "+70989598328"}
0005433716410	25B1EC	6365 758059	GALINA DAVYDOVA	{"phone": "+70608094280"}
0005433716411	25B1EC	3099 687895	VALENTINA GUSEVA	{"phone": "+70483094106"}
0005433716412	99DA66	1798 160321	VIKTORIYA DANILOVA	{"email": "danilova-v-04091958@postgrespro.ru", "phone": "+70121908907"}
0005433716413	99DA66	4950 650887	TATYANA ORLOVA	{"phone": "+70185606715"}
0005433716414	4679E1	1322 759925	ILYA ZAKHAROV	{"email": "i.zakharov.30091980@postgrespro.ru", "phone": "+70414562001"}
0005433716415	D1C658	5115 993234	SHAMIL IVANOV	{"phone": "+70923683149"}
0005433716416	F1EB8A	9645 862061	VYACHESLAV ZAKHAROV	{"phone": "+70221884338"}
0005433716417	CB8108	9200 362610	ALEKSANDR TIMOFEEV	{"email": "a_timofeev061972@postgrespro.ru", "phone": "+70502744193"}
0005433716418	CB8108	4403 562619	VASILIY VLASOV	{"phone": "+70731783201"}
0005433716419	CB8108	2391 575743	LEYLA GAVRILOVA	{"phone": "+70548514706"}
0005433716420	D06471	1020 806221	IGOR BELOV	{"phone": "+70241641599"}
0005433716421	D06471	5252 589046	NADEZHDA KUZNECOVA	{"email": "kuznecova-nadezhda-121971@postgrespro.ru", "phone": "+70188862362"}
0005433716422	979CD5	4423 937245	ALEKSEY BONDARENKO	{"phone": "+70474552085"}
0005433716423	EA6995	9345 244778	ANDREY MOROZOV	{"phone": "+70248965418"}
0005433716424	04F4A6	8739 270694	NADEZHDA TITOVA	{"email": "titova-nadezhda_091976@postgrespro.ru", "phone": "+70744748940"}
0005433716425	04F4A6	7045 055575	RAIS BORISOV	{"phone": "+70546240931"}
0005433716426	04F4A6	9682 679164	LYUBOV DENISOVA	{"email": "l.denisova-25031970@postgrespro.ru", "phone": "+70452435351"}
0005433716427	556342	0310 780683	VALENTINA KOMAROVA	{"phone": "+70115673586"}
0005433716428	556342	2434 007880	OLGA PETROVA	{"email": "olgapetrova_1953@postgrespro.ru", "phone": "+70469746845"}
0005433716429	F042A6	7173 336625	GENNADIY GUSEV	{"phone": "+70945634354"}
0005433716430	F042A6	7179 137799	VLADIMIR GRIGOREV	{"email": "v_grigorev_1961@postgrespro.ru", "phone": "+70974171433"}
0005433716431	AD64CE	7924 362243	VLADIMIR SOROKIN	{"phone": "+70543151456"}
0005433716432	6C1A22	1001 248396	NATALYA MIKHAYLOVA	{"phone": "+70395197858"}
0005433716433	37A49B	9595 241186	DANIL KAZAKOV	{"email": "kazakov_danil-21101977@postgrespro.ru", "phone": "+70986659285"}
0005433716434	37A49B	3776 663113	NATALIYA MALYSHEVA	{"phone": "+70562326330"}
0005433716435	4BE2EB	5095 876722	OLGA FILIPPOVA	{"email": "filippova-o_28111971@postgrespro.ru", "phone": "+70525219699"}
0005433716436	73DC21	0997 334653	VALERIY KUZNECOV	{"phone": "+70264114527"}
0005433716437	32BC7F	7183 322529	ALEKSEY PETROV	{"email": "a.petrov.051972@postgrespro.ru", "phone": "+70869933408"}
0005433716438	8F4A56	5450 216300	DMITRIY KOROLEV	{"phone": "+70271980739"}
0005433716439	B32237	0025 251473	ALEKSANDR STEPANOV	{"phone": "+70515701694"}
0005433716440	F7C677	2699 159177	GALINA MAKSIMOVA	{"phone": "+70768565682"}
0005433716441	F7C677	2174 799102	TATYANA TITOVA	{"email": "titova_tatyana-08041970@postgrespro.ru", "phone": "+70252625970"}
0005433716442	A33D7D	3654 774582	NADEZHDA RODIONOVA	{"phone": "+70513438574"}
0005433716443	0E614A	3356 107725	IVAN KAZAKOV	{"phone": "+70085106999"}
0005433716444	BF582B	4942 006866	FEDOR NAUMOV	{"phone": "+70318721368"}
0005433716445	6A7800	5584 065626	VLADIMIR KOZLOV	{"phone": "+70101085356"}
0005433716446	6629EE	2695 325658	SERGEY SMIRNOV	{"phone": "+70005759276"}
0005433716447	77B2DC	3219 730538	ANTONINA EGOROVA	{"email": "antonina.egorova-081970@postgrespro.ru", "phone": "+70465344454"}
0005433716448	EE7B85	4059 871867	LYUBOV MALYSHEVA	{"email": "malysheva.lyubov.1971@postgrespro.ru", "phone": "+70976500855"}
0005433716449	2EFD9C	4466 683807	DMITRIY POPOV	{"email": "popovdmitriy-071976@postgrespro.ru", "phone": "+70361022960"}
0005433716450	F92180	6115 484257	MARIYA KUZNECOVA	{"email": "mariyakuznecova_1971@postgrespro.ru", "phone": "+70075737690"}
0005433716451	5ECEAA	0254 960477	RAMIL KUZNECOV	{"phone": "+70514107348"}
0005433716452	5ECEAA	2202 420969	VLADIMIR FROLOV	{"phone": "+70457737818"}
0005433716453	D0FDEE	2152 806081	OKSANA ZOTOVA	{"phone": "+70895577005"}
0005433716454	190E2A	8820 627970	NADEZHDA POPOVA	{"phone": "+70534507633"}
0005433716455	D3B9C0	0110 360359	IVAN VOROBEV	{"phone": "+70148926236"}
0005433716456	F463E5	9517 666528	RAISA GUSEVA	{"phone": "+70450972298"}
0005433716457	CD50AC	3096 353823	VITALIY SMIRNOV	{"email": "vitaliy.smirnov.1976@postgrespro.ru", "phone": "+70041147441"}
0005433716458	CD50AC	0919 917268	MARINA MAKAROVA	{"email": "marinamakarova22081969@postgrespro.ru", "phone": "+70526854245"}
0005433716459	20A0C2	7509 034111	LYUDMILA FEDOROVA	{"email": "fedoroval28031975@postgrespro.ru", "phone": "+70726107565"}
0005433716460	E419DF	6347 847248	NIKITA KUZNECOV	{"phone": "+70757334655"}
0005433716461	1D6A3F	5323 457129	ANDREY ZHURAVLEV	{"email": "zhuravlev-a.1966@postgrespro.ru", "phone": "+70415466539"}
0005433716462	C0FD1B	5725 513825	SERGEY MIRONOV	{"phone": "+70567271456"}
0005433716463	C0FD1B	4946 494968	TATYANA POPOVA	{"phone": "+70364765410"}
0005433716464	A4A389	5652 485833	ANNA VASILEVA	{"phone": "+70117453127"}
0005433716465	0EA13C	5188 850101	MIKHAIL KUDRYASHOV	{"phone": "+70360211356"}
0005433716468	0CBA6B	4969 088478	TAMARA EGOROVA	{"phone": "+70906029647"}
0005433716469	53A135	5668 007736	VYACHESLAV GORBUNOV	{"phone": "+70742981972"}
0005433716470	F6D4CC	5583 842820	NADEZHDA SCHERBAKOVA	{"email": "nscherbakova-28101971@postgrespro.ru", "phone": "+70152473969"}
0005433716471	B61925	4463 208273	VASILIY GUSEV	{"email": "vasiliygusev-021966@postgrespro.ru", "phone": "+70539151680"}
0005433716472	3E1C8A	4355 214926	NADEZHDA DMITRIEVA	{"email": "dmitrieva.n_1965@postgrespro.ru", "phone": "+70711577204"}
0005433716473	0D3206	2825 686314	VLADIMIR SEMENOV	{"email": "semenov.vladimir_1981@postgrespro.ru", "phone": "+70387384697"}
0005433716474	0D3206	4278 096547	VLADIMIR ORLOV	{"email": "v.orlov_121981@postgrespro.ru", "phone": "+70108288708"}
0005433716475	E49DCF	7235 720738	IGOR IVANOV	{"phone": "+70437082745"}
0005433716476	E49DCF	0609 169956	NINA TIKHONOVA	{"email": "tikhonova.nina121965@postgrespro.ru", "phone": "+70281108570"}
0005433716477	E49DCF	7737 958246	ALEKSANDR NAZAROV	{"email": "nazarov.a.21021967@postgrespro.ru", "phone": "+70976194318"}
0005433716478	291D56	4327 593710	EVGENIY KONOVALOV	{"phone": "+70685873747"}
0005433716479	291D56	4036 248245	ANGELINA FEDOROVA	{"email": "a.fedorova1961@postgrespro.ru", "phone": "+70479171973"}
0005433716480	53D04D	9716 229600	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr.02031962@postgrespro.ru", "phone": "+70965348394"}
0005433716481	53D04D	3391 231768	NATALYA BELYAEVA	{"email": "belyaeva-n071968@postgrespro.ru", "phone": "+70361801572"}
0005433716482	E8A765	1013 007097	VLADIMIR SERGEEV	{"email": "vladimirsergeev121973@postgrespro.ru", "phone": "+70037196548"}
0005433716483	E8A765	2279 911866	NADEZHDA YUDINA	{"email": "yudina_nadezhda1970@postgrespro.ru", "phone": "+70577890077"}
0005433716484	DE5F3A	6396 109566	YULIYA FEDOROVA	{"email": "fedorova_yuliya.04101975@postgrespro.ru", "phone": "+70164822933"}
0005433716485	AEE059	0366 937554	OKSANA FILATOVA	{"email": "filatova_o-051983@postgrespro.ru", "phone": "+70914727913"}
0005433716486	AE6FD7	3992 554484	NATALYA POPOVA	{"phone": "+70919424128"}
0005433716487	C88427	5662 507217	YURIY ILIN	{"email": "y.ilin.121971@postgrespro.ru", "phone": "+70386025545"}
0005433716488	18D9D2	5498 227563	SERGEY SEMENOV	{"email": "ssemenov-031969@postgrespro.ru", "phone": "+70311029959"}
0005433716489	18D9D2	3947 837461	ANTON EGOROV	{"phone": "+70275455169"}
0005433716490	3780F2	3268 843156	NIKOLAY SOROKIN	{"email": "nikolaysorokin_27071982@postgrespro.ru", "phone": "+70074240043"}
0005433716491	615F60	5157 538941	ANASTASIYA KOROLEVA	{"email": "korolevaanastasiya-121972@postgrespro.ru", "phone": "+70743641447"}
0005433716492	B05F3A	7839 051695	TATYANA KOROLEVA	{"email": "tatyanakoroleva.1977@postgrespro.ru", "phone": "+70720739197"}
0005433716493	B05F3A	8483 817792	DMITRIY CHERNOV	{"email": "dchernov_07091977@postgrespro.ru", "phone": "+70303714887"}
0005433716494	8A5CCD	3781 847539	ALEKSANDR KRASNOV	{"phone": "+70066352006"}
0005433716495	E777A2	9167 047082	MARIYA ZAKHAROVA	{"phone": "+70098005651"}
0005433716496	EF2228	0459 551254	DENIS ISAEV	{"phone": "+70707328429"}
0005433716497	22E9B9	7885 677459	VLADIMIR MEDVEDEV	{"email": "medvedev_v1985@postgrespro.ru", "phone": "+70298061392"}
0005433716498	853615	1378 600574	NATALYA KOZLOVA	{"phone": "+70801843780"}
0005433716499	74B78F	1020 850751	LYUBOV PAVLOVA	{"phone": "+70853897593"}
0005433716500	C57085	8002 611985	GLEB ZAKHAROV	{"phone": "+70595194259"}
0005433716501	F61B68	4466 831501	VLADIMIR KONOVALOV	{"phone": "+70695605912"}
0005433716502	CA817C	7530 009132	MARINA PETROVA	{"email": "petrova_m.15091973@postgrespro.ru", "phone": "+70874299507"}
0005433716503	211104	6657 892750	ANASTASIYA PETROVA	{"phone": "+70633170130"}
0005433716504	7D18EB	1844 168494	TATYANA PAVLOVA	{"email": "tatyanapavlova-041961@postgrespro.ru", "phone": "+70264654806"}
0005433716505	7D18EB	6897 995143	SERGEY GUSEV	{"phone": "+70089905529"}
0005433716506	E1BA39	8380 131341	SERGEY MAKAROV	{"phone": "+70270727471"}
0005433716507	C7F3AE	2297 253657	NIKOLAY KUZNECOV	{"email": "nkuznecov.1965@postgrespro.ru", "phone": "+70429972380"}
0005433716508	3DC319	2505 438468	VLADIMIR GRIGOREV	{"email": "v-grigorev.21091975@postgrespro.ru", "phone": "+70552604803"}
0005433716509	3DC319	7153 191138	LEONID BELOV	{"email": "leonid-belov-1988@postgrespro.ru", "phone": "+70893203066"}
0005433716510	5E48A7	2992 572599	MARIYA PAVLOVA	{"email": "mariya.pavlova-1973@postgrespro.ru", "phone": "+70458254617"}
0005433716511	E79ABE	1193 007597	NATALYA POPOVA	{"phone": "+70424942282"}
0005433716512	E79ABE	0399 608385	ELENA DMITRIEVA	{"email": "elenadmitrieva12111972@postgrespro.ru", "phone": "+70740957794"}
0005433716513	853E28	7608 901501	ALEKSANDR ABRAMOV	{"phone": "+70783318653"}
0005433716514	B5F7BB	3401 967675	ANTONINA RODIONOVA	{"email": "rodionova_antonina-121972@postgrespro.ru", "phone": "+70929650057"}
0005433716515	A5E668	5669 993685	KSENIYA EFIMOVA	{"email": "k-efimova.03021976@postgrespro.ru", "phone": "+70139738454"}
0005433716516	A5E668	9065 129567	VASILIY KUZNECOV	{"email": "kuznecov.vasiliy-121971@postgrespro.ru", "phone": "+70556088824"}
0005433716517	833557	8263 041550	ANNA EGOROVA	{"phone": "+70160805006"}
0005433716518	833557	8103 473358	PAVEL EGOROV	{"phone": "+70883039568"}
0005433716519	F89752	7696 211227	IRINA GRISHINA	{"email": "i.grishina-051976@postgrespro.ru", "phone": "+70683954002"}
0005433716520	E78DB1	4285 662146	LILIYA NESTEROVA	{"phone": "+70157235577"}
0005433716521	E78DB1	4429 206329	ELENA KOZLOVA	{"email": "ekozlova_02021975@postgrespro.ru", "phone": "+70040613705"}
0005433716522	096C81	4860 043782	VLADIMIR MIRONOV	{"phone": "+70860024407"}
0005433716523	1980E6	7379 380350	GENNADIY MOROZOV	{"phone": "+70365198168"}
0005433716524	8B8ADC	6099 165583	TATYANA FEDOROVA	{"email": "fedorova_tatyana121963@postgrespro.ru", "phone": "+70208063879"}
0005433716525	8B8ADC	4789 508815	OLEG KUDRYASHOV	{"email": "o-kudryashov_1975@postgrespro.ru", "phone": "+70695440691"}
0005433716526	8ADEC5	2164 923231	KIRILL OSIPOV	{"phone": "+70313448620"}
0005433716527	8ADEC5	3504 345764	OLESYA VOROBEVA	{"phone": "+70819626172"}
0005433716528	628D27	4165 874570	SERGEY ALEKSEEV	{"email": "alekseev_sergey031975@postgrespro.ru", "phone": "+70590149473"}
0005433716529	D2287E	8749 822867	NINEL ZAYCEVA	{"email": "zaycevan.12091977@postgrespro.ru", "phone": "+70546308273"}
0005433716530	D2287E	8212 977953	OLGA SEMENOVA	{"email": "semenovaolga_09061966@postgrespro.ru", "phone": "+70564438373"}
0005433716531	0CC348	5420 114452	ANDREY POPOV	{"email": "popova04021960@postgrespro.ru", "phone": "+70231333181"}
0005433716532	5E6857	1262 607452	VLADIMIR MEDVEDEV	{"phone": "+70285878628"}
0005433716533	9B8BBB	6238 289713	NATALYA KALININA	{"email": "n.kalinina.13101976@postgrespro.ru", "phone": "+70374218609"}
0005433716534	2B6024	4613 957883	POLINA VASILEVA	{"phone": "+70111034403"}
0005433716535	2B6024	3310 266594	VALENTINA PAVLOVA	{"email": "pavlovav-11081962@postgrespro.ru", "phone": "+70795085986"}
0005433716536	A18AB4	7631 998640	KIRILL BELOV	{"phone": "+70882871313"}
0005433716537	891B73	3161 861670	BORIS KARPOV	{"email": "karpovb.19051970@postgrespro.ru", "phone": "+70407086360"}
0005433716538	11F098	6009 273644	ALEKSANDR VASILEV	{"phone": "+70502841658"}
0005433716539	11F098	2688 669354	SERGEY KOROLEV	{"phone": "+70134609112"}
0005433716540	D1C145	5952 666331	IRINA KUZNECOVA	{"email": "kuznecovairina.1958@postgrespro.ru", "phone": "+70718247268"}
0005433716541	D1C145	0342 228703	IRINA VASILEVA	{"phone": "+70527089875"}
0005433716542	769751	1068 821571	MIKHAIL TIMOFEEV	{"email": "m.timofeev_1971@postgrespro.ru", "phone": "+70557988331"}
0005433716543	769751	8555 021088	NATALYA SCHERBAKOVA	{"email": "scherbakovan_1971@postgrespro.ru", "phone": "+70918444477"}
0005433716544	F6A93C	2165 278038	VALENTINA KAZAKOVA	{"phone": "+70172808645"}
0005433716545	F6A93C	1157 933985	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr_1962@postgrespro.ru", "phone": "+70835514079"}
0005433716546	F9E4EE	6779 325988	ELENA FROLOVA	{"email": "frolovaelena_011970@postgrespro.ru", "phone": "+70186224475"}
0005433716547	40056A	4805 167054	YULIYA POPOVA	{"email": "popovayuliya05021970@postgrespro.ru", "phone": "+70052087582"}
0005433716548	40056A	2173 116593	PAVEL MIKHAYLOV	{"phone": "+70434688945"}
0005433716549	21CDC9	5062 162080	RAISA NAZAROVA	{"phone": "+70069321621"}
0005433716550	21CDC9	9170 647420	ALEKSANDR TARASOV	{"email": "tarasovaleksandr.021979@postgrespro.ru", "phone": "+70657447043"}
0005433716551	21CDC9	1638 348108	TAMARA KUZNECOVA	{"phone": "+70058526821"}
0005433716552	21CDC9	7908 797837	ILYA ROMANOV	{"email": "romanov.ilya.1972@postgrespro.ru", "phone": "+70286300371"}
0005433716553	908C59	9983 665037	EVGENIY KOROLEV	{"phone": "+70405973752"}
0005433716554	908C59	9965 061990	NATALYA SEMENOVA	{"email": "natalya.semenova-25021968@postgrespro.ru", "phone": "+70487699916"}
0005433716555	38471F	0497 043124	ANASTASIYA YAKOVLEVA	{"phone": "+70870173741"}
0005433716556	3D1937	1051 876581	ANNA IVANOVA	{"email": "ivanova_a-081968@postgrespro.ru", "phone": "+70802648079"}
0005433716557	EF4170	4437 686679	VYACHESLAV SOLOVEV	{"email": "solovev-v-081959@postgrespro.ru", "phone": "+70164126565"}
0005433716558	82BC3A	6525 229307	VALERIY KOZLOV	{"phone": "+70174735315"}
0005433716559	9F6595	0129 697825	SERGEY VOLKOV	{"phone": "+70655178309"}
0005433716560	6EB224	4850 491018	SVETLANA SOKOLOVA	{"phone": "+70100533653"}
0005433716561	6EB224	8115 652930	VITALIY ROMANOV	{"email": "vitaliy-romanov-21121974@postgrespro.ru", "phone": "+70278822275"}
0005433716562	2B4778	2020 892293	TATYANA DAVYDOVA	{"phone": "+70283253297"}
0005433716563	2B4778	0606 910212	ALEKSEY ZAKHAROV	{"email": "aleksey.zakharov-051982@postgrespro.ru", "phone": "+70324844500"}
0005433716564	41EC89	3233 759875	OLGA KISELEVA	{"email": "olga.kiseleva_1963@postgrespro.ru", "phone": "+70279723723"}
0005433716565	BC569E	2435 144196	MAKSIM FILIPPOV	{"email": "filippovm-1971@postgrespro.ru", "phone": "+70384232832"}
0005433716566	BC569E	7199 692313	ANDREY NIKOLAEV	{"phone": "+70368696107"}
0005433716567	4A5DE6	4277 711760	KIRILL YAKOVLEV	{"phone": "+70806677823"}
0005433716568	4A5DE6	5188 698083	OLGA IVANOVA	{"email": "ivanova.olga29101957@postgrespro.ru", "phone": "+70790248737"}
0005433716569	093E50	0276 522730	VIKTOR PETROV	{"email": "v_petrov_011976@postgrespro.ru", "phone": "+70100858626"}
0005433716570	6ED468	0242 204753	ALEKSANDR IVANOV	{"email": "aleksandrivanov.1961@postgrespro.ru", "phone": "+70687463265"}
0005433716571	D69063	8664 665320	ALEKSANDR KOZLOV	{"phone": "+70630688539"}
0005433716572	9AFC27	2662 969715	VALERIY BARANOV	{"phone": "+70250729774"}
0005433716573	9AFC27	1369 343698	GENNADIY VOLKOV	{"phone": "+70503551571"}
0005433716574	7B1011	3927 193533	NIKITA ANDREEV	{"email": "nandreev-1976@postgrespro.ru", "phone": "+70600701341"}
0005433716575	5C20FF	6620 474904	VYACHESLAV DAVYDOV	{"email": "davydov-v.031962@postgrespro.ru", "phone": "+70610619162"}
0005433716576	5C20FF	2115 535772	VALENTINA LUKYANOVA	{"phone": "+70143293755"}
0005433716577	35E8BE	2359 206670	OKSANA KOVALEVA	{"email": "kovaleva-oksana.12011980@postgrespro.ru", "phone": "+70245128647"}
0005433716578	E95D31	1004 019629	NATALYA KOLESNIKOVA	{"phone": "+70609671887"}
0005433716579	2EBF03	9877 805416	NINA BORISOVA	{"phone": "+70544962600"}
0005433716580	682510	0810 925224	LYUBOV ALEKSANDROVA	{"phone": "+70059613913"}
0005433716581	5480E0	8082 142712	NIKOLAY VASILEV	{"phone": "+70042594015"}
0005433716582	5480E0	3343 127866	ANNA ZAKHAROVA	{"phone": "+70140738006"}
0005433716583	5480E0	6503 372777	LYUDMILA ISAEVA	{"phone": "+70307913844"}
0005433716584	608A51	5250 240501	ANDREY FEDOTOV	{"phone": "+70858441886"}
0005433716585	2EA763	4850 799014	KLAVDIYA KAZAKOVA	{"phone": "+70550050052"}
0005433716586	2EA763	8640 419576	ANATOLIY SOKOLOV	{"phone": "+70740531712"}
0005433716587	F00347	2291 054150	BORIS IVANOV	{"email": "b.ivanov20011979@postgrespro.ru", "phone": "+70766251984"}
0005433716588	4A2BCC	1999 187745	VLADIMIR NAUMOV	{"email": "naumov-v_1964@postgrespro.ru", "phone": "+70238749184"}
0005433716589	E94460	3585 706409	GALINA MOROZOVA	{"phone": "+70473821653"}
0005433716590	FA90A1	9406 783503	SERGEY ANDREEV	{"phone": "+70956466645"}
0005433716591	D37D42	1381 875527	ALENA BARANOVA	{"phone": "+70548451078"}
0005433716592	D37D42	5613 125451	TATYANA NESTEROVA	{"email": "nesterovat_12031969@postgrespro.ru", "phone": "+70764601182"}
0005433716593	E9DD2D	9640 863853	RAVIL PAVLOV	{"phone": "+70663054651"}
0005433716594	80A799	4788 470203	NIKITA SOKOLOV	{"email": "nikitasokolov1965@postgrespro.ru", "phone": "+70292431857"}
0005433716595	50FA60	8323 982274	TATYANA VASILEVA	{"email": "t-vasileva.30071965@postgrespro.ru", "phone": "+70112870751"}
0005433716596	D55A3D	2400 003750	DMITRIY RODIONOV	{"phone": "+70896556025"}
0005433716597	5CDFFE	5498 892814	SERGEY SOKOLOV	{"phone": "+70437764114"}
0005433716598	5CDFFE	9777 045109	DARYA IVANOVA	{"phone": "+70188921384"}
0005433716599	5CDFFE	4785 182159	IVAN ZAKHAROV	{"email": "i_zakharov.071968@postgrespro.ru", "phone": "+70943155196"}
0005433716600	A16D2A	1323 131777	IRINA POLYAKOVA	{"phone": "+70080690107"}
0005433716601	A16D2A	5580 792668	ZOYA KOROLEVA	{"email": "zkoroleva_1973@postgrespro.ru", "phone": "+70955617516"}
0005433716602	98A0D8	0431 516781	GENNADIY PAVLOV	{"phone": "+70183240643"}
0005433716603	59A1FF	5262 408471	MAKSIM YAKOVLEV	{"email": "maksim-yakovlev.1972@postgrespro.ru", "phone": "+70045751901"}
0005433716604	9EFAF4	1985 044786	TATYANA IVANOVA	{"phone": "+70236104948"}
0005433716605	9EFAF4	5488 654101	EKATERINA SCHERBAKOVA	{"email": "ekaterina_scherbakova.1984@postgrespro.ru", "phone": "+70915414340"}
0005433716606	5A1E3A	3654 989775	IVAN DMITRIEV	{"email": "dmitriev.ivan.1978@postgrespro.ru", "phone": "+70016330514"}
0005433716607	81998D	1348 265867	NIKOLAY BORISOV	{"email": "borisov_nikolay041971@postgrespro.ru", "phone": "+70763663388"}
0005433716608	38B990	2106 696620	DMITRIY GRIGOREV	{"phone": "+70504787416"}
0005433716609	74C648	3657 427068	ANGELINA ALEKSEEVA	{"phone": "+70630840269"}
0005433716610	128A18	7790 816881	MARIYA GERASIMOVA	{"phone": "+70311481553"}
0005433716611	128A18	5403 611787	SERGEY VASILEV	{"phone": "+70220935625"}
0005433716612	FAB9A4	0982 105634	RUSTAM IVANOV	{"email": "ivanov.r1979@postgrespro.ru", "phone": "+70952467703"}
0005433716613	FAB9A4	9403 810028	VLADISLAV VOLKOV	{"email": "v.volkov.031985@postgrespro.ru", "phone": "+70710166005"}
0005433716614	6C7E60	4689 364000	TATYANA DANILOVA	{"phone": "+70269484440"}
0005433716615	703100	2077 575582	NIKOLAY TIMOFEEV	{"email": "n.timofeev1967@postgrespro.ru", "phone": "+70864792104"}
0005433716616	D87AB5	3530 007248	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr29091970@postgrespro.ru", "phone": "+70782180690"}
0005433716617	DF7372	9408 093251	VLADIMIR BELOV	{"phone": "+70886537246"}
0005433716618	1A0CB3	3851 427643	KONSTANTIN RODIONOV	{"phone": "+70810367232"}
0005433716619	1A0CB3	7500 349263	IRINA GUSEVA	{"phone": "+70695236987"}
0005433716620	4E9666	1785 101617	EVA FADEEVA	{"email": "fadeeva_e-1965@postgrespro.ru", "phone": "+70879684845"}
0005433716621	C3ADCD	8131 520428	DARYA KUZMINA	{"phone": "+70304500216"}
0005433716622	796404	7656 293483	ALEKSANDR SERGEEV	{"phone": "+70075238220"}
0005433716623	5CA720	1142 872149	YAKOV ABRAMOV	{"phone": "+70625256894"}
0005433716624	B47D99	8640 634473	OLGA KAZAKOVA	{"email": "kazakova.olga.25051975@postgrespro.ru", "phone": "+70821627154"}
0005433716625	E84D93	0201 637430	ELIZAVETA GUSEVA	{"email": "elizavetaguseva.1972@postgrespro.ru", "phone": "+70114411425"}
0005433716626	99304B	3163 157282	MAKSIM ILIN	{"email": "ilin_m.1975@postgrespro.ru", "phone": "+70310379196"}
0005433716627	62F024	4658 848579	EVGENIY ZAKHAROV	{"phone": "+70295716048"}
0005433716628	62F024	7252 301103	DANILA DAVYDOV	{"email": "d_davydov.1970@postgrespro.ru", "phone": "+70977641637"}
0005433716629	ECDC96	4552 774059	NINA MOROZOVA	{"phone": "+70926310156"}
0005433716630	2094BE	0942 730278	VLADIMIR POPOV	{"email": "popov.vladimir18031967@postgrespro.ru", "phone": "+70219738035"}
0005433716631	91A71E	7579 440640	KIRILL BORISOV	{"email": "k.borisov_021981@postgrespro.ru", "phone": "+70193311280"}
0005433716632	CCEFB5	9590 213989	YULIYA IVANOVA	{"email": "y.ivanova.091978@postgrespro.ru", "phone": "+70115914279"}
0005433716633	D9231C	7932 069282	VALENTINA SERGEEVA	{"phone": "+70446820494"}
0005433716634	786B98	0096 382535	OLGA ABRAMOVA	{"phone": "+70358782205"}
0005433716635	786B98	9247 537647	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova.s1968@postgrespro.ru", "phone": "+70331756764"}
0005433716636	F18760	7823 546688	VALENTINA STEPANOVA	{"email": "valentina-stepanova.111971@postgrespro.ru", "phone": "+70516420929"}
0005433716637	F18760	8768 696632	EVGENIY MOROZOV	{"email": "evgeniymorozov11091967@postgrespro.ru", "phone": "+70778834736"}
0005433716638	46C562	6287 906236	VENERA IVANOVA	{"phone": "+70125545912"}
0005433716639	C7ED87	7611 049489	KONSTANTIN IVANOV	{"email": "konstantin-ivanov-1983@postgrespro.ru", "phone": "+70168448578"}
0005433716640	C7ED87	7454 011264	IRINA NOVIKOVA	{"phone": "+70456677465"}
0005433716641	7CECF6	4052 557195	IRINA POLYAKOVA	{"email": "polyakovairina_17011975@postgrespro.ru", "phone": "+70948137628"}
0005433716642	7CECF6	1498 100278	ANNA IVANOVA	{"email": "a_ivanova_1976@postgrespro.ru", "phone": "+70689656549"}
0005433716643	EF82A2	6537 202438	ALBERT VASILEV	{"email": "vasilevalbert.1977@postgrespro.ru", "phone": "+70799842363"}
0005433716644	2D3D33	4350 502847	TAMARA DMITRIEVA	{"phone": "+70359663259"}
0005433716645	2D3D33	0474 799849	ILYA NAUMOV	{"phone": "+70958725346"}
0005433716646	D24B5C	4781 221945	ANDREY SCHERBAKOV	{"email": "ascherbakov.1978@postgrespro.ru", "phone": "+70468377903"}
0005433716647	D24B5C	7981 509773	EVGENIYA KULIKOVA	{"email": "ekulikova_1971@postgrespro.ru", "phone": "+70718122844"}
0005433716648	310456	1094 170763	NATALYA MAKAROVA	{"phone": "+70292659503"}
0005433716649	60B979	6374 288479	DMITRIY NAZAROV	{"phone": "+70880834932"}
0005433716650	B42B7B	7451 051008	NINA MAKAROVA	{"email": "nina_makarova.1977@postgrespro.ru", "phone": "+70783303455"}
0005433716651	073616	8806 075955	PAVEL NOVIKOV	{"email": "p-novikov_09031979@postgrespro.ru", "phone": "+70509897945"}
0005433716652	073616	2005 975029	OLGA VASILEVA	{"email": "vasileva_olga041973@postgrespro.ru", "phone": "+70226078623"}
0005433716653	016D8C	8363 510514	OLGA ZAKHAROVA	{"email": "zakharovaolga_111955@postgrespro.ru", "phone": "+70623321001"}
0005433716654	016D8C	1267 293613	TATYANA YAKOVLEVA	{"phone": "+70091892698"}
0005433716655	5C5506	2974 537533	GENNADIY NIKOLAEV	{"email": "g-nikolaev_12081964@postgrespro.ru", "phone": "+70462134284"}
0005433716656	5C5506	7279 835114	IGOR SEMENOV	{"email": "semenov_igor-19041973@postgrespro.ru", "phone": "+70315472365"}
0005433716657	5C5506	8499 215582	TIMOFEY KULIKOV	{"email": "t-kulikov091971@postgrespro.ru", "phone": "+70173449894"}
0005433716658	D3603E	0845 003549	EVGENIY ALEKSEEV	{"email": "alekseev.e-011978@postgrespro.ru", "phone": "+70278552401"}
0005433716659	CC1950	3560 015340	VALERIY NAUMOV	{"phone": "+70165451336"}
0005433716660	119C4B	9410 211635	LIDIYA FROLOVA	{"email": "l-frolova-031982@postgrespro.ru", "phone": "+70702298105"}
0005433716661	119C4B	9103 266885	TATYANA KUZNECOVA	{"phone": "+70413662633"}
0005433716662	789F1F	4803 382323	TAMARA ILINA	{"phone": "+70031227212"}
0005433716663	789F1F	7858 059948	PETR MAKSIMOV	{"phone": "+70436277946"}
0005433716664	EDF596	7072 335929	SVETLANA FOMINA	{"phone": "+70421020064"}
0005433716665	77BDC2	6577 729158	ALEKSEY ALEKSEEV	{"email": "alekseev-a-1972@postgrespro.ru", "phone": "+70247540384"}
0005433716666	77BDC2	8097 374430	DMITRIY TARASOV	{"email": "tarasov_dmitriy1974@postgrespro.ru", "phone": "+70279732766"}
0005433716667	5959A2	6908 459981	ANDREY MIKHAYLOV	{"email": "mikhaylov-a121975@postgrespro.ru", "phone": "+70527263078"}
0005433716668	5959A2	5145 360895	LYUBOV DENISOVA	{"phone": "+70556359430"}
0005433716669	3349CE	7406 443588	VYACHESLAV MEDVEDEV	{"phone": "+70840915387"}
0005433716670	7A2642	2385 882397	ANASTASIYA SOROKINA	{"phone": "+70628880512"}
0005433716671	FAF0B5	9614 677117	SVETLANA SOKOLOVA	{"phone": "+70662033871"}
0005433716672	EB1C4F	8205 604473	VALERIY ANDREEV	{"phone": "+70862253613"}
0005433716673	269138	3759 629400	VIKTOR SOKOLOV	{"email": "v_sokolov-09071966@postgrespro.ru", "phone": "+70391294710"}
0005433716674	441691	6446 694268	OLGA VOLKOVA	{"phone": "+70465777372"}
0005433716675	441691	5575 470952	IGOR ISAEV	{"phone": "+70348084109"}
0005433716676	E3FB22	2058 042455	TATYANA DENISOVA	{"email": "denisova-t1970@postgrespro.ru", "phone": "+70304295262"}
0005433716677	E3FB22	1611 613486	TAMARA ZAKHAROVA	{"phone": "+70441179937"}
0005433716678	CA52ED	3218 957328	PETR KAZAKOV	{"phone": "+70413815885"}
0005433716679	D4064A	9128 495152	SERGEY IVANOV	{"phone": "+70180160922"}
0005433716680	D4064A	4461 244553	ANATOLIY ZAKHAROV	{"phone": "+70785564560"}
0005433716681	B98BDE	5455 744862	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a12121970@postgrespro.ru", "phone": "+70062969714"}
0005433716682	316F03	3020 200852	ELENA POPOVA	{"email": "e.popova011973@postgrespro.ru", "phone": "+70534319337"}
0005433716683	316F03	4702 539259	MARIYA BOGDANOVA	{"phone": "+70996513421"}
0005433716684	FEF7F7	5632 675213	IVAN KUZNECOV	{"phone": "+70523311462"}
0005433716685	FEF7F7	3957 851294	VLADIMIR OSIPOV	{"email": "vladimir-osipov14061971@postgrespro.ru", "phone": "+70469163822"}
0005433716686	1D55EA	8127 265063	MARINA MELNIKOVA	{"email": "melnikova-marina071966@postgrespro.ru", "phone": "+70398576358"}
0005433716687	1D55EA	5027 478274	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-m28051965@postgrespro.ru", "phone": "+70089221521"}
0005433716688	E7C47E	6262 802806	BOGDAN MAKSIMOV	{"phone": "+70336410475"}
0005433716689	E7C47E	0362 605258	ELDAR NOVIKOV	{"phone": "+70835200657"}
0005433716690	1D1F84	9121 683321	TAMARA ERMAKOVA	{"phone": "+70774386825"}
0005433716691	1D1F84	1208 631274	VLADIMIR CHERNOV	{"phone": "+70000874881"}
0005433716692	737E99	5996 960040	EKATERINA EFIMOVA	{"phone": "+70923174235"}
0005433716693	5A81A8	1972 243025	NATALYA IVANOVA	{"email": "ivanovanatalya-28091972@postgrespro.ru", "phone": "+70799815530"}
0005433716694	026F3A	2129 222588	YULIYA VLASOVA	{"phone": "+70904637464"}
0005433716695	80731C	4682 294452	ANNA SERGEEVA	{"phone": "+70296339613"}
0005433716696	6F4FB2	4703 242087	KIRILL DENISOV	{"email": "denisov_k091964@postgrespro.ru", "phone": "+70398260436"}
0005433716697	78865A	3427 142328	SEMEN KARPOV	{"phone": "+70932424292"}
0005433716698	78865A	0477 660733	SERGEY POPOV	{"email": "sergey-popov_011969@postgrespro.ru", "phone": "+70225033318"}
0005433716699	6DEABF	5154 238739	GALINA BOGDANOVA	{"email": "bogdanova-g1987@postgrespro.ru", "phone": "+70098515711"}
0005433716700	6DEABF	8064 423084	OLEG KUZNECOV	{"email": "kuznecov.oleg_1969@postgrespro.ru", "phone": "+70292403225"}
0005433716701	305F87	3928 947859	VALENTINA DENISOVA	{"phone": "+70438202869"}
0005433716702	023CAA	1866 247657	POLINA ZAKHAROVA	{"phone": "+70317740617"}
0005433716703	9A6B40	2646 593020	NATALYA MAKAROVA	{"email": "n-makarova.1973@postgrespro.ru", "phone": "+70430009448"}
0005433716704	9A6B40	1492 120864	ZINAIDA KUDRYASHOVA	{"phone": "+70699013256"}
0005433716705	5B0B11	4220 620104	SERGEY NIKITIN	{"email": "s.nikitin-061980@postgrespro.ru", "phone": "+70733733431"}
0005433716706	E561B2	5465 086866	EVGENIY DAVYDOV	{"phone": "+70957744120"}
0005433716707	8EFF2D	4174 705393	YURIY GRIGOREV	{"phone": "+70023102762"}
0005433716708	8EFF2D	8595 029567	YULIYA VASILEVA	{"email": "vasileva.yuliya15041979@postgrespro.ru", "phone": "+70947817935"}
0005433716709	5581C0	4267 309612	EGOR OSIPOV	{"email": "osipov.e-15021974@postgrespro.ru", "phone": "+70993562395"}
0005433716710	FABB20	6159 270117	KLAVDIYA ZAYCEVA	{"email": "klavdiya.zayceva_121964@postgrespro.ru", "phone": "+70239853982"}
0005433716711	40B466	6306 853968	RAISA ISAEVA	{"email": "raisa_isaeva.1972@postgrespro.ru", "phone": "+70421968916"}
0005433716712	1C7559	5700 402154	ANNA ZAYCEVA	{"phone": "+70787650608"}
0005433716713	1C7559	5374 403588	TAMARA POTAPOVA	{"email": "potapovatamara081963@postgrespro.ru", "phone": "+70205584421"}
0005433716714	8C0591	9249 301375	DARYA LUKYANOVA	{"phone": "+70538432764"}
0005433716715	042B2D	3092 429370	RAISA DANILOVA	{"email": "r.danilova-1984@postgrespro.ru", "phone": "+70423268095"}
0005433716716	7DE03D	6647 873840	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov.09121969@postgrespro.ru", "phone": "+70877516937"}
0005433716717	63A9B0	2178 187774	ALEKSANDRA KOZLOVA	{"email": "aleksandrakozlova_30111970@postgrespro.ru", "phone": "+70575785692"}
0005433716718	63A9B0	4974 997818	IVAN KUZMIN	{"email": "kuzminivan101966@postgrespro.ru", "phone": "+70584292678"}
0005433716719	CC28E2	2965 603388	SVETLANA ZOTOVA	{"email": "svetlanazotova_19081979@postgrespro.ru", "phone": "+70609244410"}
0005433716720	D86016	8844 082087	VITALIY BELOV	{"phone": "+70588168152"}
0005433716721	1D0C2D	1216 308180	ALEKSEY MIKHAYLOV	{"email": "a_mikhaylov.1967@postgrespro.ru", "phone": "+70286351950"}
0005433716722	1D0C2D	5859 827597	SVETLANA SIDOROVA	{"phone": "+70932318968"}
0005433716723	4600E7	8024 616481	ELENA MIRONOVA	{"email": "mironova.e121979@postgrespro.ru", "phone": "+70090929953"}
0005433716724	525570	4520 711751	ULYANA ISAEVA	{"email": "isaeva_u091972@postgrespro.ru", "phone": "+70630978722"}
0005433716725	525570	4942 457581	VALERIY PETROV	{"email": "petrov_v1980@postgrespro.ru", "phone": "+70641851577"}
0005433716726	63CD7B	0660 655590	DANIIL KAZAKOV	{"email": "daniil.kazakov1975@postgrespro.ru", "phone": "+70845588805"}
0005433716727	63CD7B	6472 366540	OLEG BELOV	{"email": "oleg-belov.071969@postgrespro.ru", "phone": "+70879789424"}
0005433716728	63CD7B	8170 495034	NATALYA ALEKSANDROVA	{"phone": "+70426138492"}
0005433716729	A8B622	4799 175244	EVGENIY OSIPOV	{"phone": "+70183029003"}
0005433716730	42EC86	1727 389287	ANDREY ANTONOV	{"phone": "+70048139112"}
0005433716731	42EC86	8052 356287	MARIYA MARTYNOVA	{"email": "mariya-martynova.20021972@postgrespro.ru", "phone": "+70530333126"}
0005433716732	66F329	4495 810419	DMITRIY OSIPOV	{"email": "dmitriyosipov121965@postgrespro.ru", "phone": "+70195606742"}
0005433716733	66F329	4700 785697	VASILIY ANDREEV	{"phone": "+70730040973"}
0005433716734	DA5484	8639 834093	VITALIY ANTONOV	{"email": "vantonov12021973@postgrespro.ru", "phone": "+70027880680"}
0005433716735	13D3CB	7041 136826	VALERIY SOROKIN	{"email": "sorokin_v041983@postgrespro.ru", "phone": "+70472840763"}
0005433716736	4A5B42	5305 953012	NIKOLAY NIKOLAEV	{"email": "nikolay-nikolaev.1976@postgrespro.ru", "phone": "+70086724954"}
0005433716737	8A23AC	0203 979344	VLADIMIR ANDREEV	{"phone": "+70272289950"}
0005433716738	D8504C	8368 579041	ALINA AFANASEVA	{"email": "afanaseva_alina1984@postgrespro.ru", "phone": "+70909551269"}
0005433716739	D8504C	3149 521115	TATYANA KUZNECOVA	{"phone": "+70741288899"}
0005433716740	5E2DC6	7789 513014	YURIY STEPANOV	{"phone": "+70197230948"}
0005433716741	5E2DC6	0390 495740	MARINA POPOVA	{"email": "popova_m_041962@postgrespro.ru", "phone": "+70876144428"}
0005433716742	31FFDE	0040 636921	ANASTASIYA POPOVA	{"email": "popova.anastasiya_041977@postgrespro.ru", "phone": "+70865113453"}
0005433716743	32F152	9197 512937	DMITRIY YAKOVLEV	{"email": "dmitriy-yakovlev_19031965@postgrespro.ru", "phone": "+70116593437"}
0005433716744	0758D6	8242 304625	NIKOLAY FOMIN	{"phone": "+70316611801"}
0005433716745	81742F	9120 404234	ALEKSANDR MIRONOV	{"phone": "+70906844663"}
0005433716746	8E04BA	9270 084181	DENIS TIMOFEEV	{"email": "denis-timofeev_021964@postgrespro.ru", "phone": "+70249730280"}
0005433716747	CB08F7	7699 178577	LYUDMILA SMIRNOVA	{"phone": "+70432239135"}
0005433716748	6E3DAF	0057 170611	GLEB CHERNOV	{"phone": "+70203806454"}
0005433716749	C3D3B8	3045 403677	ALEKSANDR SOKOLOV	{"phone": "+70842972073"}
0005433716750	979189	9465 395459	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov.021972@postgrespro.ru", "phone": "+70623360261"}
0005433716751	41060C	8544 199201	LEONID NAZAROV	{"phone": "+70581265071"}
0005433716752	41060C	5975 694787	IRINA ILINA	{"phone": "+70814251621"}
0005433716753	1EBC13	2438 769833	VASILIY VOLKOV	{"email": "vvolkov.06091971@postgrespro.ru", "phone": "+70174307008"}
0005433716754	1EBC13	6014 547935	EVDOKIYA MELNIKOVA	{"email": "emelnikova-1956@postgrespro.ru", "phone": "+70154162717"}
0005433716755	6E9AB4	4210 159493	YANA SERGEEVA	{"email": "yana.sergeeva-02111966@postgrespro.ru", "phone": "+70663419541"}
0005433716756	403070	9873 693267	OLGA MAKSIMOVA	{"phone": "+70624476230"}
0005433716757	1A7DAE	4860 338772	ANASTASIYA EFREMOVA	{"phone": "+70107988342"}
0005433716758	1A7DAE	6130 325788	LEONID ILIN	{"email": "lilin1956@postgrespro.ru", "phone": "+70042294906"}
0005433716759	3A69A2	6496 322455	TATYANA DENISOVA	{"phone": "+70529487929"}
0005433716760	3A69A2	8556 961771	ALEKSANDR BELOV	{"phone": "+70131515217"}
0005433716761	4261C5	0979 963984	NATALYA ABRAMOVA	{"email": "n_abramova.051970@postgrespro.ru", "phone": "+70902533218"}
0005433716762	4261C5	0231 611281	VLADIMIR EGOROV	{"email": "egorov_vladimir.02051983@postgrespro.ru", "phone": "+70037437513"}
0005433716763	979793	5656 140987	DMITRIY KULIKOV	{"email": "dmitriykulikov1970@postgrespro.ru", "phone": "+70045032561"}
0005433716764	3F39F1	8930 257222	NADEZHDA NAUMOVA	{"email": "naumova.n_16091966@postgrespro.ru", "phone": "+70234816644"}
0005433716765	3F39F1	7394 471838	ARTEM VOROBEV	{"phone": "+70902911188"}
0005433716766	3F39F1	8798 803152	YULIYA DAVYDOVA	{"phone": "+70372270876"}
0005433716767	3F39F1	6164 700841	VENIAMIN ALEKSANDROV	{"email": "aleksandrov_veniamin.071974@postgrespro.ru", "phone": "+70061089117"}
0005433716768	43A5F5	3841 499482	PAVEL NAUMOV	{"phone": "+70277644199"}
0005433716769	43A5F5	5642 144839	VITALIY KULIKOV	{"phone": "+70595189961"}
0005433716770	9A69ED	8445 973006	DENIS POPOV	{"phone": "+70361238159"}
0005433716771	2F6B07	0968 262650	ANATOLIY FILIPPOV	{"phone": "+70876767715"}
0005433716772	AC6437	1934 229674	ANASTASIYA NIKITINA	{"email": "nikitina.anastasiya-051967@postgrespro.ru", "phone": "+70660101840"}
0005433716773	229055	7974 402307	OLESYA MOROZOVA	{"phone": "+70536346235"}
0005433716774	7E8537	3825 667848	ALEKSANDR IVANOV	{"email": "ivanov_a.1977@postgrespro.ru", "phone": "+70992372682"}
0005433716775	7E8537	2920 527587	KRISTINA NESTEROVA	{"email": "k_nesterova_091963@postgrespro.ru", "phone": "+70783924427"}
0005433716776	7E8537	8154 713365	NIKOLAY MEDVEDEV	{"email": "nikolaymedvedev16091966@postgrespro.ru", "phone": "+70810325345"}
0005433716777	419448	6087 307383	SEMEN ALEKSANDROV	{"email": "semen.aleksandrov1970@postgrespro.ru", "phone": "+70373530092"}
0005433716778	34422F	7532 365296	EKATERINA KUZMINA	{"email": "kuzmina-ekaterina-1965@postgrespro.ru", "phone": "+70543107991"}
0005433716779	1EC4E9	8998 706035	VIOLETTA IVANOVA	{"email": "ivanova_v_091982@postgrespro.ru", "phone": "+70632802923"}
0005433716780	27818C	2920 120752	LYUDMILA SOROKINA	{"email": "l_sorokina02081966@postgrespro.ru", "phone": "+70036395796"}
0005433716781	B733EE	6191 743206	ALEKSEY SAVELEV	{"phone": "+70510885055"}
0005433716782	89FB76	9457 464053	PETR IVANOV	{"phone": "+70136677133"}
0005433716783	26930C	1336 755122	SERGEY FEDOROV	{"email": "s.fedorov01021964@postgrespro.ru", "phone": "+70934305252"}
0005433716784	D5E5C3	1051 654313	MARIYA ANDREEVA	{"email": "andreeva-mariya-1972@postgrespro.ru", "phone": "+70123785048"}
0005433716785	FF0C2A	8217 505912	VASILIY DMITRIEV	{"email": "vdmitriev_23081962@postgrespro.ru", "phone": "+70372069772"}
0005433716786	D2620B	8340 325589	EKATERINA NESTEROVA	{"email": "nesterovae-25081981@postgrespro.ru", "phone": "+70785885670"}
0005433716787	517F0B	5168 381808	IRINA KOMAROVA	{"email": "irina_komarova-061976@postgrespro.ru", "phone": "+70414837734"}
0005433716788	4ABE8B	1936 699751	ALEKSEY NIKITIN	{"phone": "+70864904671"}
0005433716789	4ABE8B	8501 503367	LYUDMILA LEBEDEVA	{"email": "lyudmila-lebedeva_01121971@postgrespro.ru", "phone": "+70298442951"}
0005433716790	E3DCD6	6068 504946	FAINA DAVYDOVA	{"phone": "+70813254494"}
0005433716791	54879D	8468 608748	MARINA ISAEVA	{"phone": "+70396783288"}
0005433716792	54879D	7648 780697	ANASTASIYA MARTYNOVA	{"phone": "+70697002928"}
0005433716793	85C568	0847 587611	VADIM MAKAROV	{"email": "makarov.v_1985@postgrespro.ru", "phone": "+70211522036"}
0005433716794	58BE7C	4991 443019	NIKOLAY KRASNOV	{"phone": "+70121215910"}
0005433716795	F85A0B	1876 822346	NINA POPOVA	{"phone": "+70112519748"}
0005433716796	E5CD20	2849 201019	KONSTANTIN FROLOV	{"email": "konstantin_frolov-1964@postgrespro.ru", "phone": "+70196354585"}
0005433716797	E5CD20	7113 386456	SERGEY SERGEEV	{"email": "sergeev-s_1975@postgrespro.ru", "phone": "+70164973287"}
0005433716798	929C46	6619 270337	MARGARITA ERMAKOVA	{"email": "margarita_ermakova111971@postgrespro.ru", "phone": "+70983077520"}
0005433716799	648826	6900 023910	ANDREY SAVELEV	{"email": "a-savelev101965@postgrespro.ru", "phone": "+70317419914"}
0005433716800	648826	8350 047642	VERA NAZAROVA	{"phone": "+70382881378"}
0005433716801	4B0C49	5617 526172	VALENTINA NESTEROVA	{"email": "valentinanesterova.05071966@postgrespro.ru", "phone": "+70786546128"}
0005433716802	41C52F	3422 356880	ALEKSEY KUZNECOV	{"email": "kuznecov.a03081977@postgrespro.ru", "phone": "+70996673672"}
0005433716803	BA7382	2959 664552	FEDOR SEMENOV	{"email": "semenov_f08111969@postgrespro.ru", "phone": "+70436403172"}
0005433716804	1FF275	8714 092407	OLGA YAKOVLEVA	{"phone": "+70121890115"}
0005433716805	AD388F	1531 594330	ANATOLIY ISAEV	{"phone": "+70813032183"}
0005433716806	D3E2CD	3299 256429	ANTONINA ROMANOVA	{"phone": "+70413534217"}
0005433716807	1F57F0	2153 253443	VIKTOR FEDOTOV	{"email": "fedotov-viktor.1978@postgrespro.ru", "phone": "+70386390843"}
0005433716808	3F379F	4748 978736	ANATOLIY NAZAROV	{"phone": "+70953255334"}
0005433716809	B6EE1A	8316 115918	VIKTOR STEPANOV	{"phone": "+70245626655"}
0005433716810	0103D8	3846 890527	MIKHAIL TIKHONOV	{"email": "m-tikhonov_1976@postgrespro.ru", "phone": "+70615321600"}
0005433716811	EF31E2	8236 448593	ROZA AFANASEVA	{"phone": "+70799519516"}
0005433716812	EF31E2	2117 565633	NINA KUDRYASHOVA	{"phone": "+70811842694"}
0005433716813	970406	5404 132416	TATYANA OVCHINNIKOVA	{"phone": "+70941774212"}
0005433716814	970406	5392 888708	IRINA TIMOFEEVA	{"email": "timofeeva_i16021967@postgrespro.ru", "phone": "+70608487386"}
0005433716815	E24E0F	7735 307308	ALEKSANDR POPOV	{"email": "aleksandrpopov.071976@postgrespro.ru", "phone": "+70340704998"}
0005433716816	BB5DDD	8064 354646	ELENA SEMENOVA	{"email": "elenasemenova.061982@postgrespro.ru", "phone": "+70320713272"}
0005433716817	BB5DDD	7812 530494	RUSTAM MELNIKOV	{"email": "melnikovrustam09061986@postgrespro.ru", "phone": "+70818254364"}
0005433716818	AD6121	4035 025480	VLADIMIR MOISEEV	{"email": "moiseev_vladimir.28101982@postgrespro.ru", "phone": "+70975849470"}
0005433716819	553052	3044 003890	EVGENIY KOZLOV	{"email": "evgeniy_kozlov1976@postgrespro.ru", "phone": "+70393299719"}
0005433716820	553052	1453 639800	OLGA POLYAKOVA	{"phone": "+70052378599"}
0005433716821	2F656B	2047 717088	ALEKSEY GAVRILOV	{"phone": "+70147867934"}
0005433716822	363D89	7686 533814	NADEZHDA NAZAROVA	{"phone": "+70835115641"}
0005433716823	363D89	7070 604025	DINA MALYSHEVA	{"email": "malysheva.dina.121963@postgrespro.ru", "phone": "+70361788746"}
0005433716824	933893	8923 988955	VIKTORIYA ILINA	{"email": "ilina_v_11031964@postgrespro.ru", "phone": "+70463231388"}
0005433716825	933893	8055 828699	VLADIMIR GERASIMOV	{"phone": "+70884773843"}
0005433716826	80B000	6956 154211	IVAN SOKOLOV	{"email": "sokolov-ivan_07021963@postgrespro.ru", "phone": "+70705977736"}
0005433716827	CF1BB5	9907 894090	LYUBOV NESTEROVA	{"phone": "+70068259119"}
0005433716828	392065	6147 173148	SVETLANA POPOVA	{"phone": "+70012860848"}
0005433716829	392065	8214 677266	NATALYA STEPANOVA	{"email": "stepanovan-081967@postgrespro.ru", "phone": "+70206886851"}
0005433716830	312CF2	4315 508231	YURIY KUDRYASHOV	{"email": "kudryashov_y.21021967@postgrespro.ru", "phone": "+70197604057"}
0005433716831	0955A6	1010 411617	YURIY ANTONOV	{"phone": "+70596745047"}
0005433716832	BCD465	1882 954009	TATYANA MOISEEVA	{"email": "moiseevatatyana.111965@postgrespro.ru", "phone": "+70134246503"}
0005433716833	E653DC	4146 951100	ALEKSANDR KUZNECOV	{"phone": "+70538082639"}
0005433716834	3B33DB	4034 233888	MIKHAIL ANTONOV	{"phone": "+70026518156"}
0005433716835	3B33DB	2388 554546	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-041973@postgrespro.ru", "phone": "+70894202965"}
0005433716836	530179	6955 647417	VALENTINA MIKHAYLOVA	{"email": "vmikhaylova_16061969@postgrespro.ru", "phone": "+70838491550"}
0005433716837	641597	5114 183807	NINA BELYAEVA	{"phone": "+70943641205"}
0005433716838	C3E76B	5672 886471	PAVEL PAVLOV	{"email": "pavlov_p1982@postgrespro.ru", "phone": "+70247309111"}
0005433716839	C3E76B	8478 654866	NATALYA KONOVALOVA	{"phone": "+70561281975"}
0005433716840	965DFD	0836 492145	IRINA KOZLOVA	{"phone": "+70682052085"}
0005433716841	965DFD	1822 614359	YULIYA OSIPOVA	{"email": "yuliya-osipova-1971@postgrespro.ru", "phone": "+70915986374"}
0005433716842	C1444F	3985 438891	EKATERINA ZHUKOVA	{"phone": "+70217448199"}
0005433716843	C1444F	6753 387496	VASILIY FEDOROV	{"phone": "+70050885681"}
0005433716844	A9D412	7496 845264	MARINA POPOVA	{"phone": "+70551640293"}
0005433716845	236BCF	4927 094549	RAISA SMIRNOVA	{"email": "r-smirnova071970@postgrespro.ru", "phone": "+70694097897"}
0005433716846	236BCF	7476 912289	OKSANA MARTYNOVA	{"phone": "+70741593329"}
0005433716847	236BCF	4085 656993	OLGA KUZMINA	{"phone": "+70246009212"}
0005433716848	CD5812	0665 030726	VLADIMIR CHERNOV	{"phone": "+70483468124"}
0005433716849	CD5812	6426 690180	LYUBOV YUDINA	{"phone": "+70402761076"}
0005433716850	30233D	3144 739263	STANISLAV PAVLOV	{"phone": "+70231902455"}
0005433716851	30233D	5565 359486	SVETLANA MAKSIMOVA	{"email": "svetlana-maksimova.1975@postgrespro.ru", "phone": "+70616555040"}
0005433716852	229165	5797 602851	OLEG CHERNOV	{"phone": "+70385092665"}
0005433716853	229165	6046 795864	OLGA KONOVALOVA	{"email": "olga-konovalova_041970@postgrespro.ru", "phone": "+70887135556"}
0005433716854	32E5EA	4926 994228	OLGA PETROVA	{"email": "o-petrova011990@postgrespro.ru", "phone": "+70393793955"}
0005433716855	469FE7	7062 928602	TAMARA PETROVA	{"phone": "+70958910779"}
0005433716856	1E0ED7	7065 232872	ANDREY KULIKOV	{"email": "kulikovandrey.1981@postgrespro.ru", "phone": "+70854707891"}
0005433716857	EC9C32	1186 091834	YULIYA KAZAKOVA	{"email": "kazakova.y_1968@postgrespro.ru", "phone": "+70162706797"}
0005433716858	11EB8E	6881 055963	SERGEY BELOV	{"phone": "+70095533562"}
0005433716859	AC7FE6	5218 006856	NIKOLAY MARTYNOV	{"phone": "+70807411822"}
0005433716860	8E53F2	8429 267296	IRINA KARPOVA	{"email": "karpovai1957@postgrespro.ru", "phone": "+70208868334"}
0005433716861	B374BE	7034 598464	ARINA RYABOVA	{"phone": "+70579087391"}
0005433716862	B62DF4	1071 147607	ANDREY SCHERBAKOV	{"phone": "+70889568534"}
0005433716863	B62DF4	5073 191869	VLADISLAV FEDOROV	{"phone": "+70926192659"}
0005433716864	F7ADC1	9920 866069	ANNA FADEEVA	{"phone": "+70161051113"}
0005433716865	BDA6AC	8329 985401	IVAN PETROV	{"phone": "+70873020475"}
0005433716866	6D4267	1108 926438	ALEKSANDR SOKOLOV	{"phone": "+70418888774"}
0005433717103	A63A9B	3461 684761	ANASTASIYA PAVLOVA	{"phone": "+70176851954"}
0005433716867	6D4267	0471 166574	VALENTINA KUZNECOVA	{"email": "v-kuznecova1977@postgrespro.ru", "phone": "+70179000159"}
0005433716868	FFEB24	7552 836104	VLADIMIR DENISOV	{"phone": "+70032399325"}
0005433716869	27D208	5970 263113	LYUBOV NESTEROVA	{"email": "l_nesterova-051983@postgrespro.ru", "phone": "+70179878531"}
0005433716870	43DFA1	3643 341031	NINA PETROVA	{"phone": "+70754209090"}
0005433716871	43DFA1	4676 739917	LYUDMILA LEBEDEVA	{"email": "lebedeva.lyudmila1965@postgrespro.ru", "phone": "+70648046979"}
0005433716872	43DFA1	7084 688358	VIKTOR DAVYDOV	{"phone": "+70218921010"}
0005433716873	F68B39	1611 434330	ALEKSANDR KOZLOV	{"phone": "+70987867691"}
0005433716874	F68B39	7348 462054	OLGA EGOROVA	{"phone": "+70314906071"}
0005433716875	AC4FAD	7304 602255	VIKTOR VASILEV	{"phone": "+70897390431"}
0005433716876	A91B66	9931 816820	SERGEY GERASIMOV	{"phone": "+70658594962"}
0005433716877	10CBC7	5224 934860	EKATERINA KALININA	{"email": "kalinina-e-121965@postgrespro.ru", "phone": "+70207987836"}
0005433716878	10CBC7	4998 404323	ZINAIDA ISAEVA	{"phone": "+70532579240"}
0005433716879	0EFF19	0673 659966	ALEKSEY PETROV	{"email": "petrov_aleksey.021972@postgrespro.ru", "phone": "+70280371861"}
0005433716880	329636	0442 115301	OLESYA KOZLOVA	{"email": "o.kozlova.061963@postgrespro.ru", "phone": "+70616454323"}
0005433716881	1C6326	9892 655539	TATYANA TIKHONOVA	{"phone": "+70777609349"}
0005433716882	1C6326	2713 164220	NATALYA SERGEEVA	{"phone": "+70515769540"}
0005433716883	1C6326	3104 404408	NIKITA ILIN	{"phone": "+70957291123"}
0005433716884	00F915	2375 764268	ANNA OSIPOVA	{"email": "osipova_anna1975@postgrespro.ru", "phone": "+70772921748"}
0005433716885	00F915	9414 719754	EVGENIYA FROLOVA	{"email": "frolova.e061977@postgrespro.ru", "phone": "+70925794594"}
0005433716886	CB4B82	7497 307014	VLADISLAV BELOV	{"email": "belovv-121978@postgrespro.ru", "phone": "+70069486459"}
0005433716887	BFEED9	6570 221700	NIKOLAY ALEKSANDROV	{"phone": "+70286030354"}
0005433716888	F1F989	0027 676236	TATYANA ARKHIPOVA	{"email": "arkhipova.tatyana_30061976@postgrespro.ru", "phone": "+70087653424"}
0005433716889	64D0E6	7554 539731	DENIS MAKAROV	{"email": "makarov.denis.06051968@postgrespro.ru", "phone": "+70986243349"}
0005433716890	BDDA05	6613 593967	VITALIY PETROV	{"phone": "+70593127450"}
0005433716891	972C21	1718 785142	YURIY ABRAMOV	{"email": "abramov-y-05011971@postgrespro.ru", "phone": "+70780884646"}
0005433716892	972C21	0557 702096	ELIZAVETA POLYAKOVA	{"phone": "+70173992645"}
0005433716893	1C189F	9415 665174	DMITRIY PETROV	{"email": "dmitriy.petrov.29021976@postgrespro.ru", "phone": "+70932134996"}
0005433716894	1C189F	8495 453766	SOFYA DANILOVA	{"email": "danilova-sofya_15121971@postgrespro.ru", "phone": "+70323544517"}
0005433716895	0680C8	8048 451596	VIKTOR MIKHAYLOV	{"email": "viktor.mikhaylov111965@postgrespro.ru", "phone": "+70514249889"}
0005433716896	7EF3EE	8678 523720	NATALYA YAKOVLEVA	{"email": "yakovleva_natalya_1980@postgrespro.ru", "phone": "+70671125486"}
0005433716897	7EF3EE	7899 894993	POLINA KOROLEVA	{"phone": "+70096556467"}
0005433716898	5918AF	9942 634602	VLADIMIR GERASIMOV	{"email": "vgerasimov.15111972@postgrespro.ru", "phone": "+70122558388"}
0005433716899	5918AF	0578 190863	INNA IVANOVA	{"phone": "+70534480735"}
0005433716900	E9A525	1726 118806	ANNA RYABOVA	{"phone": "+70867446048"}
0005433716901	48A5A2	4507 385292	IGOR SOROKIN	{"email": "sorokin-i101970@postgrespro.ru", "phone": "+70512051541"}
0005433716902	48A5A2	2517 861934	ROMAN POPOV	{"email": "romanpopov-041977@postgrespro.ru", "phone": "+70793051968"}
0005433716903	878A11	7981 845874	VLADISLAV MIKHAYLOV	{"email": "mikhaylov_vladislav_071974@postgrespro.ru", "phone": "+70396938638"}
0005433716904	878A11	3260 004624	VIKTOR BELOV	{"email": "vbelov.21021988@postgrespro.ru", "phone": "+70157468855"}
0005433716905	878A11	4164 793650	NATALYA BARANOVA	{"email": "baranova.n_25061974@postgrespro.ru", "phone": "+70028733484"}
0005433716906	BC7243	8157 335662	ILNUR PAVLOV	{"email": "ilnur_pavlov.1960@postgrespro.ru", "phone": "+70283467985"}
0005433716907	B6F2C5	1041 690151	ALEKSANDRA ZHURAVLEVA	{"email": "a-zhuravleva-061980@postgrespro.ru", "phone": "+70272904198"}
0005433716908	B6F2C5	7335 044951	TAISIYA KULIKOVA	{"phone": "+70649027374"}
0005433716909	B6F2C5	6792 317762	VASILIY ANTONOV	{"phone": "+70083396705"}
0005433716910	A003E9	9765 750266	ROZA SCHERBAKOVA	{"phone": "+70125839425"}
0005433716911	B49DF0	0158 401426	LYUDMILA POTAPOVA	{"email": "l-potapova.121963@postgrespro.ru", "phone": "+70662037968"}
0005433716912	A89E6D	8067 519686	NIKOLAY TARASOV	{"email": "nikolay-tarasov-1972@postgrespro.ru", "phone": "+70216522194"}
0005433716913	CF5AC9	0534 552169	SVETLANA PAVLOVA	{"email": "pavlovas.17051978@postgrespro.ru", "phone": "+70533854745"}
0005433716914	E459E9	2264 120467	NIKOLAY ROMANOV	{"phone": "+70318654913"}
0005433716915	D80166	5105 852327	ANTONINA DANILOVA	{"phone": "+70426698946"}
0005433716916	D80166	8227 343463	IVAN KUZNECOV	{"phone": "+70557159898"}
0005433716917	F07971	9049 296766	GALINA NIKIFOROVA	{"phone": "+70079275968"}
0005433716918	999B87	1214 956845	LIDIYA ILINA	{"email": "ilina_lidiya02061988@postgrespro.ru", "phone": "+70447512692"}
0005433716919	999B87	5752 547324	VALENTINA NESTEROVA	{"email": "nesterovav.22011968@postgrespro.ru", "phone": "+70054406778"}
0005433716920	999B87	8833 716504	ALEKSANDRA KOVALEVA	{"phone": "+70597051934"}
0005433716921	999B87	3489 156877	YURIY SOROKIN	{"phone": "+70714122389"}
0005433716922	C17E43	3730 645394	VALENTIN NIKOLAEV	{"email": "valentinnikolaev.1965@postgrespro.ru", "phone": "+70667241095"}
0005433716923	E06373	9680 280875	ARTUR NIKOLAEV	{"email": "a.nikolaev_031968@postgrespro.ru", "phone": "+70305560046"}
0005433716924	F0185A	1917 484431	LARISA DMITRIEVA	{"email": "dmitrieva.larisa.1980@postgrespro.ru", "phone": "+70118875752"}
0005433716925	94871C	3001 939929	NATALYA MOROZOVA	{"phone": "+70970844358"}
0005433717403	502F9D	0774 490927	PAVEL IVANOV	{"phone": "+70187018516"}
0005433716926	513BF6	5977 859876	NATALYA SOLOVEVA	{"email": "soloveva-natalya.121972@postgrespro.ru", "phone": "+70503982853"}
0005433716927	E2C1EE	8571 659751	DARYA NESTEROVA	{"email": "d_nesterova_1963@postgrespro.ru", "phone": "+70433946801"}
0005433716928	E2C1EE	4180 823963	ALEKSANDR MARTYNOV	{"email": "martynov.a1971@postgrespro.ru", "phone": "+70224873250"}
0005433716929	67727F	2401 878541	ASKAR VASILEV	{"phone": "+70024322277"}
0005433716930	84ACDB	6184 281900	NIKOLAY TARASOV	{"phone": "+70293065456"}
0005433716931	84ACDB	2214 442841	STEPAN FILIPPOV	{"phone": "+70120967908"}
0005433716932	519613	6507 327069	VIKTORIYA DANILOVA	{"email": "danilova-viktoriya081968@postgrespro.ru", "phone": "+70082285723"}
0005433716933	519613	5515 797706	ANDREY SOLOVEV	{"email": "andrey-solovev.061969@postgrespro.ru", "phone": "+70022251972"}
0005433716934	7ABC03	6810 015898	VASILIY SMIRNOV	{"email": "smirnov_v-121962@postgrespro.ru", "phone": "+70904512544"}
0005433716935	33E9D5	3985 665090	NINA SOKOLOVA	{"phone": "+70380168250"}
0005433716936	7689FF	3360 158674	SVETLANA MALYSHEVA	{"phone": "+70472675196"}
0005433716937	032783	6862 373665	VALERIY BARANOV	{"email": "baranov-valeriy1976@postgrespro.ru", "phone": "+70717968177"}
0005433716938	C8FDF2	5083 183592	LARISA DMITRIEVA	{"email": "dmitrieval_121961@postgrespro.ru", "phone": "+70175469656"}
0005433716939	424676	7714 657844	DANILA IVANOV	{"email": "d-ivanov.20081963@postgrespro.ru", "phone": "+70978005882"}
0005433716940	FE464E	2459 105244	EKATERINA BORISOVA	{"email": "borisova_e-011979@postgrespro.ru", "phone": "+70596865173"}
0005433716941	FE464E	4346 945583	OKSANA FEDOROVA	{"phone": "+70172126316"}
0005433716942	A3B3A9	4811 249858	ANDREY NAUMOV	{"email": "naumovandrey1968@postgrespro.ru", "phone": "+70118094382"}
0005433716943	BEED05	4300 430113	ANATOLIY PETROV	{"email": "petrov.anatoliy121974@postgrespro.ru", "phone": "+70237595171"}
0005433716944	BEED05	2376 813741	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov05111972@postgrespro.ru", "phone": "+70494031427"}
0005433716945	180511	7243 251517	MARIYA AFANASEVA	{"phone": "+70010804673"}
0005433716946	D2B1F4	0434 504017	IGOR DAVYDOV	{"phone": "+70402311479"}
0005433716947	D2B1F4	6987 450743	LYUDMILA LEBEDEVA	{"email": "lyudmila-lebedeva05051970@postgrespro.ru", "phone": "+70293378232"}
0005433716948	AD5500	7683 450513	VLADIMIR NAZAROV	{"phone": "+70075074388"}
0005433716949	2314E6	8314 928803	NATALYA MEDVEDEVA	{"email": "natalya_medvedeva.08041968@postgrespro.ru", "phone": "+70710010012"}
0005433716950	3B1B2F	9216 739668	SVETLANA FILATOVA	{"email": "filatova_svetlana-11081979@postgrespro.ru", "phone": "+70284558256"}
0005433716951	BAC7FC	5377 650985	ALEKSANDR ALEKSEEV	{"email": "alekseev.a1973@postgrespro.ru", "phone": "+70816334055"}
0005433716952	343FAD	9720 499224	ELVIRA YAKOVLEVA	{"email": "yakovleva-elvira.121965@postgrespro.ru", "phone": "+70573484218"}
0005433716953	343FAD	5197 101915	GALINA MAKAROVA	{"phone": "+70564589055"}
0005433716954	CFD037	1840 595393	LIDIYA SOKOLOVA	{"email": "sokolova-l1978@postgrespro.ru", "phone": "+70248334059"}
0005433716955	CFD037	4730 481591	NATALYA PETROVA	{"email": "n_petrova_1963@postgrespro.ru", "phone": "+70026569715"}
0005433716956	2E6C65	1753 467606	ALEKSEY TIKHONOV	{"phone": "+70289641610"}
0005433716957	96CBD9	6438 906011	VERA ANDREEVA	{"email": "andreeva-vera_011979@postgrespro.ru", "phone": "+70520940491"}
0005433716958	7CF07C	1354 200467	TATYANA POTAPOVA	{"phone": "+70524872319"}
0005433716959	E678A5	1025 971175	IRINA KUZNECOVA	{"email": "i.kuznecova-101971@postgrespro.ru", "phone": "+70726335470"}
0005433716960	E678A5	0615 798474	VALENTINA ZOTOVA	{"email": "zotova-v081960@postgrespro.ru", "phone": "+70687406075"}
0005433716961	8BEA77	6210 623423	ELENA MIKHAYLOVA	{"email": "mikhaylovaelena091981@postgrespro.ru", "phone": "+70690026659"}
0005433716962	24FC4D	0111 586760	RAVIL KISELEV	{"phone": "+70321000914"}
0005433716963	0E9EB5	8998 973784	LYUBOV IVANOVA	{"email": "ivanova.lyubov.22091975@postgrespro.ru", "phone": "+70324206203"}
0005433716964	0195F5	8851 322110	YAROSLAV VASILEV	{"email": "vasilev.y_1959@postgrespro.ru", "phone": "+70106501209"}
0005433716965	2012E0	4129 928769	ZHANNA TARASOVA	{"phone": "+70331738500"}
0005433716966	FA50B6	0235 581268	GENNADIY POPOV	{"email": "popov.g_09111974@postgrespro.ru", "phone": "+70930598504"}
0005433716967	FA50B6	6478 845722	DMITRIY MIKHAYLOV	{"phone": "+70339608443"}
0005433716968	42A390	7715 725292	VALENTINA MAKSIMOVA	{"email": "v.maksimova-1964@postgrespro.ru", "phone": "+70860377866"}
0005433716969	D2CEBA	6910 630417	ROMAN ANDREEV	{"email": "andreevr_1965@postgrespro.ru", "phone": "+70907507191"}
0005433716970	EDDF27	5280 283428	OLGA MIRONOVA	{"email": "olga_mironova-1969@postgrespro.ru", "phone": "+70516926301"}
0005433716971	E7AAE3	2826 157745	DANIIL ZAYCEV	{"email": "zaycev-d-021981@postgrespro.ru", "phone": "+70460096585"}
0005433716972	E7AAE3	0766 143718	EKATERINA VOROBEVA	{"email": "vorobeva.e1959@postgrespro.ru", "phone": "+70619992324"}
0005433717028	A8B0EE	3187 437172	GALINA KISELEVA	{"phone": "+70059813147"}
0005433716973	F7265F	9946 173049	IRINA IVANOVA	{"email": "ivanovairina.16061962@postgrespro.ru", "phone": "+70891295790"}
0005433716974	F7265F	1442 767842	LARISA NAUMOVA	{"phone": "+70698418763"}
0005433716975	D95D38	7123 279381	NIKOLAY ZAKHAROV	{"phone": "+70926085252"}
0005433716976	C977D9	1499 416784	SVETLANA FOMINA	{"email": "fomina_svetlana-1972@postgrespro.ru", "phone": "+70683266601"}
0005433716977	C977D9	9322 479676	VIKTOR SMIRNOV	{"phone": "+70579408917"}
0005433716978	159A70	8497 900451	NINA NIKITINA	{"email": "nina.nikitina1973@postgrespro.ru", "phone": "+70491733473"}
0005433716979	6A8FFE	3589 852767	ALEKSANDR BELOV	{"email": "belov_aleksandr-22081969@postgrespro.ru", "phone": "+70263537068"}
0005433716980	BB17B8	0560 239329	TATYANA TIMOFEEVA	{"phone": "+70378342714"}
0005433716981	C14DA3	1743 072648	IRINA MARTYNOVA	{"phone": "+70611735593"}
0005433716982	C14DA3	4214 621219	ANASTASIYA FILIPPOVA	{"email": "filippovaanastasiya-1974@postgrespro.ru", "phone": "+70712043574"}
0005433716983	4E454B	3914 140675	VIKTOR IVANOV	{"email": "vivanov-06101980@postgrespro.ru", "phone": "+70771449561"}
0005433716984	774595	8843 142534	SVETLANA NIKITINA	{"phone": "+70724203078"}
0005433716985	774595	3563 621712	VLADIMIR FROLOV	{"email": "v_frolov_19031979@postgrespro.ru", "phone": "+70872495283"}
0005433716986	982732	3303 379511	IRINA YUDINA	{"phone": "+70110683271"}
0005433716987	58FDBD	0775 466452	ANNA BARANOVA	{"phone": "+70211673173"}
0005433716988	3B3F07	8007 838266	STANISLAV ZHUKOV	{"email": "s.zhukov-1977@postgrespro.ru", "phone": "+70546258225"}
0005433716989	3B3F07	7235 531483	ANNA MIRONOVA	{"email": "mironova.anna051970@postgrespro.ru", "phone": "+70117578414"}
0005433716990	1F45F4	4185 342529	OLGA KOZLOVA	{"email": "kozlova-olga-1964@postgrespro.ru", "phone": "+70543692376"}
0005433716991	48813A	0557 843317	EVGENIY MAKSIMOV	{"email": "maksimove.12091964@postgrespro.ru", "phone": "+70116519070"}
0005433716992	EC2624	9731 680085	MARIYA SOKOLOVA	{"phone": "+70261194430"}
0005433716993	073C87	1665 223266	ALEKSANDRA VOROBEVA	{"phone": "+70595793276"}
0005433716994	D84492	9534 878387	VIKTOR FOMIN	{"phone": "+70948656366"}
0005433716995	3969FF	7221 028025	EVGENIYA SOKOLOVA	{"phone": "+70054522855"}
0005433716996	3969FF	0605 696602	NADEZHDA DAVYDOVA	{"phone": "+70530423466"}
0005433716997	38962F	5469 748315	ALEKSANDR SMIRNOV	{"email": "smirnov_a-09051976@postgrespro.ru", "phone": "+70798816529"}
0005433716998	C3F6F9	9574 392221	OLESYA SMIRNOVA	{"email": "smirnova_olesya.16071982@postgrespro.ru", "phone": "+70242940682"}
0005433716999	C3F6F9	4878 008188	NIKOLAY NIKITIN	{"phone": "+70464537490"}
0005433717112	6FFE3C	7597 653400	VIKTORIYA SEMENOVA	{"phone": "+70522021581"}
0005433717000	455F44	6097 446128	VENIAMIN PETROV	{"email": "petrov.veniamin_07121974@postgrespro.ru", "phone": "+70334208034"}
0005433717001	455F44	9251 405004	LYUBOV SCHERBAKOVA	{"email": "lyubovscherbakova_011967@postgrespro.ru", "phone": "+70624019754"}
0005433717002	75B7FA	7210 596295	YULIYA GERASIMOVA	{"email": "gerasimova-yuliya01031967@postgrespro.ru", "phone": "+70987218356"}
0005433717003	51BECF	3974 204808	TATYANA IVANOVA	{"email": "ivanovat_14051974@postgrespro.ru", "phone": "+70275745856"}
0005433717004	51BECF	8000 044012	NATALYA EFIMOVA	{"phone": "+70328043970"}
0005433717005	51BECF	0160 651985	OLGA KISELEVA	{"phone": "+70627710346"}
0005433717006	9371A9	8399 628167	TAMARA VASILEVA	{"email": "tvasileva-121979@postgrespro.ru", "phone": "+70871206089"}
0005433717007	06E5CD	2033 686097	OLGA KONOVALOVA	{"email": "konovalovaolga.17061984@postgrespro.ru", "phone": "+70312193958"}
0005433717008	3129A1	0665 226455	TATYANA MAKSIMOVA	{"email": "maksimova-t-29111965@postgrespro.ru", "phone": "+70388297663"}
0005433717009	3129A1	7091 277438	VALENTINA KONDRATEVA	{"email": "valentina.kondrateva_071976@postgrespro.ru", "phone": "+70439536788"}
0005433717010	3129A1	0672 275417	SERGEY VOROBEV	{"email": "vorobev_sergey_051969@postgrespro.ru", "phone": "+70202637745"}
0005433717011	2A3EEA	4716 125811	TATYANA YAKOVLEVA	{"email": "yakovleva_tatyana_121982@postgrespro.ru", "phone": "+70413677465"}
0005433717012	F86967	7782 214580	ANATOLIY SIDOROV	{"email": "a.sidorov_05091975@postgrespro.ru", "phone": "+70146041963"}
0005433717013	752714	6715 791545	ALEKSANDR KRASNOV	{"phone": "+70313672514"}
0005433717014	30C6D0	8504 602171	VALENTINA LEBEDEVA	{"email": "valentinalebedeva.061980@postgrespro.ru", "phone": "+70693621603"}
0005433717015	C01E99	4231 441143	RUSLAN SCHERBAKOV	{"email": "scherbakov_ruslan-25111976@postgrespro.ru", "phone": "+70636707914"}
0005433717016	C5F837	8146 808537	VIKTOR NAZAROV	{"phone": "+70952041908"}
0005433717017	70FEBE	7279 125000	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_03021967@postgrespro.ru", "phone": "+70511752688"}
0005433717018	BD0EB3	0473 262878	ANDREY FILIPPOV	{"phone": "+70510515801"}
0005433717019	BD0EB3	2029 129844	IGOR TIMOFEEV	{"email": "igortimofeev-19081980@postgrespro.ru", "phone": "+70578866161"}
0005433717020	BFCF20	1705 710844	ARTEM VOROBEV	{"phone": "+70748262380"}
0005433717021	B7FA1F	7137 778787	LYUDMILA MIRONOVA	{"phone": "+70010496448"}
0005433717022	9E19DB	1323 067033	TATYANA DAVYDOVA	{"phone": "+70074655386"}
0005433717023	2015BE	4231 151256	MIKHAIL MIKHAYLOV	{"phone": "+70981906354"}
0005433717024	5C9AFD	0570 617394	GALINA MEDVEDEVA	{"email": "gmedvedeva-1966@postgrespro.ru", "phone": "+70253377267"}
0005433717025	0630DC	3781 955284	VIKTORIYA POPOVA	{"phone": "+70359490716"}
0005433717026	D8B041	4648 938497	NINA LAZAREVA	{"phone": "+70736016066"}
0005433717027	A8B0EE	6772 671441	VLADIMIR PAVLOV	{"phone": "+70642098332"}
0005433717029	A8B0EE	7207 194605	VERONIKA IVANOVA	{"phone": "+70003035170"}
0005433717030	F4682C	2977 346736	ALEKSEY SMIRNOV	{"phone": "+70188328272"}
0005433717031	90A174	6772 016172	ALENA ALEKSEEVA	{"phone": "+70936664865"}
0005433717032	EC3EDD	6977 616218	ELENA MARTYNOVA	{"email": "martynova-elena01111972@postgrespro.ru", "phone": "+70888785067"}
0005433717033	EC3EDD	2621 345762	IRINA IVANOVA	{"phone": "+70885186375"}
0005433717034	08A5C7	6199 347785	LYUDMILA GERASIMOVA	{"phone": "+70982324927"}
0005433717035	70985B	2986 402655	VIKTOR VASILEV	{"phone": "+70543846150"}
0005433717036	D63B2F	3793 795910	KIRILL MAKAROV	{"email": "kirill.makarov101970@postgrespro.ru", "phone": "+70530190682"}
0005433717037	236ADD	9545 548795	LYUDMILA FROLOVA	{"phone": "+70563754824"}
0005433717038	236ADD	6774 431297	ZOYA ANTONOVA	{"email": "antonovaz-17031976@postgrespro.ru", "phone": "+70878104193"}
0005433717039	63418D	7329 111380	TATYANA KOROLEVA	{"email": "tatyana.koroleva08041970@postgrespro.ru", "phone": "+70659276048"}
0005433717040	9761C6	1261 491595	FARIDA GAVRILOVA	{"phone": "+70818921959"}
0005433717041	2FB274	9164 481641	ALSU KUZNECOVA	{"phone": "+70043662952"}
0005433717042	BF774E	9229 641116	MARIANNA RODIONOVA	{"phone": "+70764632435"}
0005433719171	D8D3FD	4925 801091	ALENA KUZNECOVA	{"phone": "+70404598697"}
0005433717043	BF774E	7693 624744	ANASTASIYA MEDVEDEVA	{"email": "medvedevaa.081974@postgrespro.ru", "phone": "+70305266686"}
0005433717044	8CF8D9	9481 830174	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova-1960@postgrespro.ru", "phone": "+70586187089"}
0005433717045	CBF6F4	2953 410169	OLGA ANDREEVA	{"phone": "+70641320754"}
0005433717046	077F10	6186 077699	EVGENIY KUZNECOV	{"email": "kuznecov-e081978@postgrespro.ru", "phone": "+70635305914"}
0005433717047	077F10	5688 505115	ELENA BARANOVA	{"phone": "+70143339475"}
0005433717048	D580DF	7653 723828	GALINA SIDOROVA	{"phone": "+70055267237"}
0005433717049	D580DF	0940 958902	OLEG DENISOV	{"email": "denisovo_1960@postgrespro.ru", "phone": "+70468975968"}
0005433717050	85DA62	6194 549980	SOFYA OSIPOVA	{"email": "s_osipova_1983@postgrespro.ru", "phone": "+70254278299"}
0005433717051	85DA62	6518 303009	VALERIYA ROMANOVA	{"email": "valeriya.romanova_051981@postgrespro.ru", "phone": "+70892130804"}
0005433717052	499AD8	1399 724201	EVDOKIYA SOROKINA	{"phone": "+70666843372"}
0005433717053	499AD8	1844 464706	ARTUR KUZNECOV	{"email": "kuznecov.a-20031970@postgrespro.ru", "phone": "+70467554727"}
0005433717054	DF3783	1635 198434	NADEZHDA ANISIMOVA	{"phone": "+70606721329"}
0005433717055	2AD2BA	1530 326266	SVETLANA EFIMOVA	{"email": "sefimova121974@postgrespro.ru", "phone": "+70375085013"}
0005433717056	F5D024	1949 360813	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov-1973@postgrespro.ru", "phone": "+70262119991"}
0005433717057	F379BE	9603 559825	NADEZHDA FEDOROVA	{"email": "fedorovan.1972@postgrespro.ru", "phone": "+70585922533"}
0005433717058	FC202D	9285 216905	ELENA KUZMINA	{"phone": "+70021714238"}
0005433717059	FC202D	5492 508890	NATALYA VLASOVA	{"phone": "+70421251787"}
0005433717060	1997D6	6530 941163	POLINA SERGEEVA	{"phone": "+70656146386"}
0005433717061	3C828F	1762 894823	SVETLANA TROFIMOVA	{"email": "s-trofimova-1972@postgrespro.ru", "phone": "+70967346081"}
0005433717062	2F99C6	8002 257968	SERGEY MOROZOV	{"email": "morozovsergey-30061962@postgrespro.ru", "phone": "+70100547544"}
0005433717063	EEA9D6	0069 133080	EVGENIY ABRAMOV	{"email": "e_abramov-1971@postgrespro.ru", "phone": "+70955028082"}
0005433717064	EEA9D6	2422 303607	ALEKSANDR FOMIN	{"email": "fominaleksandr.1958@postgrespro.ru", "phone": "+70500913190"}
0005433717065	98C830	5796 710515	ARINA EFIMOVA	{"email": "efimova.arina061987@postgrespro.ru", "phone": "+70700301497"}
0005433717066	D2AC3B	1671 102975	ANTONINA PETROVA	{"email": "antonina_petrova1976@postgrespro.ru", "phone": "+70849799542"}
0005433717067	477E32	5598 295851	SVETLANA SIDOROVA	{"phone": "+70273659335"}
0005433717068	477E32	4320 697166	NATALYA ZAYCEVA	{"email": "zaycevanatalya_1979@postgrespro.ru", "phone": "+70716853040"}
0005433717069	477E32	4754 881013	ALEKSANDR SAVELEV	{"email": "savelev-aleksandr_20041972@postgrespro.ru", "phone": "+70514493440"}
0005433717070	C70AD7	6413 224828	ARTEM ZHUKOV	{"phone": "+70670892500"}
0005433717071	707329	3896 076236	ALEKSEY MAKAROV	{"phone": "+70629166471"}
0005433717072	707329	0290 471227	KSENIYA ZHUKOVA	{"phone": "+70700978976"}
0005433717073	707329	3487 611547	VASILIY KONOVALOV	{"phone": "+70979457903"}
0005433717074	2893C8	0662 491201	LIDIYA NAUMOVA	{"email": "lnaumova-1969@postgrespro.ru", "phone": "+70109383111"}
0005433717075	0E69AA	8183 093403	YULIYA KOZLOVA	{"phone": "+70226854772"}
0005433717076	4D9368	4002 255133	MARGARITA ORLOVA	{"phone": "+70312559646"}
0005433717077	B51BE4	7352 726786	NIKOLAY MIRONOV	{"email": "mironov-n07011974@postgrespro.ru", "phone": "+70405955077"}
0005433717078	FE3279	7431 850566	ZLATA STEPANOVA	{"phone": "+70846973345"}
0005433717079	A0F973	5647 582255	SVETLANA KOLESNIKOVA	{"phone": "+70980618157"}
0005433717080	A0F973	0418 512998	SERGEY BARANOV	{"phone": "+70741547523"}
0005433717081	C6DA5B	9695 436459	VALENTINA POPOVA	{"email": "popova_v.1983@postgrespro.ru", "phone": "+70265651154"}
0005433717082	91E938	5319 337046	ALEKSEY KULIKOV	{"phone": "+70410254632"}
0005433717083	825A78	7770 986056	NIKOLAY MIKHAYLOV	{"phone": "+70567209747"}
0005433717084	5F294B	5505 678976	IRINA ROMANOVA	{"email": "i.romanova_071979@postgrespro.ru", "phone": "+70670857950"}
0005433717085	5A957C	6806 133755	NADEZHDA KONDRATEVA	{"phone": "+70544410928"}
0005433717086	D2DA9A	4919 282701	PAVEL KUZNECOV	{"phone": "+70603755268"}
0005433717087	D2DA9A	3201 054240	VYACHESLAV VOLKOV	{"phone": "+70644332938"}
0005433717088	CFD3BB	1602 480975	VIKTORIYA ANDREEVA	{"email": "andreeva_viktoriya091965@postgrespro.ru", "phone": "+70572167863"}
0005433717089	CFD3BB	7969 705552	ALEKSANDR SOKOLOV	{"phone": "+70997370637"}
0005433717090	CFD3BB	0009 273479	KLAVDIYA KOZLOVA	{"phone": "+70515618288"}
0005433717091	8A92DF	4534 095680	IVAN CHERNOV	{"email": "ichernov_29011974@postgrespro.ru", "phone": "+70708904975"}
0005433717092	DCCB14	8289 411675	ALEKSANDR MOROZOV	{"email": "morozovaleksandr1977@postgrespro.ru", "phone": "+70613821998"}
0005433717093	910B35	4631 623869	ARTEM SERGEEV	{"phone": "+70794311279"}
0005433717094	910B35	5138 113318	ALEKSANDR VLASOV	{"email": "a.vlasov.031974@postgrespro.ru", "phone": "+70285629116"}
0005433717095	FD01D2	8034 948930	VERONIKA ZHUKOVA	{"email": "v-zhukova18061962@postgrespro.ru", "phone": "+70000268750"}
0005433717096	B0EF14	6927 203173	ANATOLIY ZHURAVLEV	{"email": "anatoliy.zhuravlev-1979@postgrespro.ru", "phone": "+70686739363"}
0005433717097	12E412	1757 452853	EKATERINA NAUMOVA	{"email": "naumova_ekaterina_1958@postgrespro.ru", "phone": "+70644888334"}
0005433717098	578A88	0191 667912	RUSLAN TIKHONOV	{"phone": "+70978031365"}
0005433717099	97DC29	8967 610408	NATALYA KAZAKOVA	{"email": "n.kazakova.1978@postgrespro.ru", "phone": "+70461976567"}
0005433717100	97DC29	6785 679712	NATALYA MELNIKOVA	{"email": "natalya_melnikova_1988@postgrespro.ru", "phone": "+70336296181"}
0005433717101	D594BC	1222 915715	ALEKSANDR KUZNECOV	{"phone": "+70014591861"}
0005433717102	D594BC	1780 697919	TAISIYA GUSEVA	{"phone": "+70134664252"}
0005433717104	53B162	2223 819526	YULIYA MATVEEVA	{"email": "matveevay.02031955@postgrespro.ru", "phone": "+70745015502"}
0005433717105	62211B	8560 510814	LIDIYA DAVYDOVA	{"email": "davydova-lidiya_1973@postgrespro.ru", "phone": "+70031195719"}
0005433717106	62211B	3959 191882	VLADIMIR PETROV	{"email": "vladimir_petrov_1969@postgrespro.ru", "phone": "+70965510393"}
0005433717107	62211B	7712 307077	ELENA SCHERBAKOVA	{"phone": "+70644319829"}
0005433717108	3DD262	1840 200495	SEMEN MELNIKOV	{"phone": "+70159282738"}
0005433717109	3DD262	1150 501224	SVETLANA YUDINA	{"phone": "+70323193134"}
0005433717110	93F0BE	5592 023868	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_a_25091975@postgrespro.ru", "phone": "+70256073066"}
0005433717111	93F0BE	0855 987744	GENNADIY DMITRIEV	{"phone": "+70944904510"}
0005433717113	553F93	5814 919053	TAMARA EFREMOVA	{"email": "tamaraefremova-06081966@postgrespro.ru", "phone": "+70164723636"}
0005433717114	764BBF	2754 442947	NINA BOGDANOVA	{"email": "bogdanova.n-1979@postgrespro.ru", "phone": "+70128574082"}
0005433717115	764BBF	7340 884128	TATYANA GORBUNOVA	{"phone": "+70280844057"}
0005433717116	413233	6113 565285	SERGEY FILIPPOV	{"email": "filippov.s1978@postgrespro.ru", "phone": "+70127365081"}
0005433717117	0D9B5A	1470 253584	ALEKSANDR SAVELEV	{"email": "savelevaleksandr.011976@postgrespro.ru", "phone": "+70833503664"}
0005433717118	0D9B5A	3333 076216	ANTONINA SOKOLOVA	{"phone": "+70463394103"}
0005433717119	9E4C4E	9661 183518	MARIYA IVANOVA	{"phone": "+70985879799"}
0005433717120	867564	8531 627124	ALEKSANDR SERGEEV	{"email": "sergeev.aleksandr.21081983@postgrespro.ru", "phone": "+70664731050"}
0005433717121	EF2CE6	8315 331876	ALENA FEDOROVA	{"phone": "+70055905190"}
0005433717122	EF2CE6	8350 868204	VLADIMIR SOROKIN	{"email": "sorokin.vladimir.021968@postgrespro.ru", "phone": "+70190968525"}
0005433717123	D07FAC	4895 431023	EGOR IVANOV	{"email": "ivanove-1972@postgrespro.ru", "phone": "+70133670383"}
0005433717124	254AF3	6463 480362	ALBINA SIDOROVA	{"email": "albina.sidorova101966@postgrespro.ru", "phone": "+70642644860"}
0005433717125	7BD711	9189 426760	ALEKSEY NOVIKOV	{"phone": "+70938653160"}
0005433717126	6CC26B	2743 744891	EVGENIY SOROKIN	{"phone": "+70608419282"}
0005433717127	2C475F	3849 875560	VYACHESLAV ISAEV	{"email": "vyacheslavisaev-041975@postgrespro.ru", "phone": "+70749712239"}
0005433717128	61F538	2713 243451	SVETLANA FROLOVA	{"phone": "+70734674786"}
0005433717129	E93A36	5105 978185	VIKTORIYA BARANOVA	{"phone": "+70810772129"}
0005433717130	E93A36	5481 286215	VASILIY MATVEEV	{"phone": "+70527933490"}
0005433717131	370598	4560 402461	ANDREY KISELEV	{"phone": "+70338318596"}
0005433717132	3F85D1	1642 468782	EKATERINA NIKITINA	{"email": "ekaterina.nikitina101968@postgrespro.ru", "phone": "+70103279798"}
0005433717133	3F85D1	6038 424477	LIDIYA ISAEVA	{"phone": "+70595267135"}
0005433717134	A546DC	1536 194186	ALEKSANDRA SERGEEVA	{"phone": "+70513996454"}
0005433717135	D414D0	0237 819078	VIKTOR EGOROV	{"email": "v-egorov_1977@postgrespro.ru", "phone": "+70620639436"}
0005433717136	D414D0	5417 577865	ALEKSEY KULIKOV	{"phone": "+70236839528"}
0005433717137	D414D0	3381 436613	OLGA EGOROVA	{"phone": "+70648351952"}
0005433717138	D414D0	5999 571828	LIDIYA MAKAROVA	{"phone": "+70125237502"}
0005433717139	06E264	2559 635778	VITALIY SMIRNOV	{"email": "vsmirnov.1973@postgrespro.ru", "phone": "+70677683361"}
0005433717140	6DF8D1	1685 422331	YURIY MOROZOV	{"email": "morozov_y_1974@postgrespro.ru", "phone": "+70148750931"}
0005433717141	17203C	2842 528168	ARTEM STEPANOV	{"email": "stepanovartem_101976@postgrespro.ru", "phone": "+70564962508"}
0005433717142	7AE39C	3839 499208	NINA KUZNECOVA	{"phone": "+70316196097"}
0005433717143	CC0C45	1457 715331	ZHANNA NESTEROVA	{"phone": "+70916188061"}
0005433717144	CC0C45	6460 668400	VERONIKA NIKOLAEVA	{"phone": "+70193542523"}
0005433717145	F861E1	4818 644425	ELVIRA PAVLOVA	{"email": "elvira-pavlova-101972@postgrespro.ru", "phone": "+70263776386"}
0005433717146	F861E1	2761 232877	OLESYA LAZAREVA	{"email": "olesya-lazareva_071981@postgrespro.ru", "phone": "+70424686262"}
0005433717147	B0D69D	3166 808946	DMITRIY SMIRNOV	{"email": "smirnov.d.29111969@postgrespro.ru", "phone": "+70930895130"}
0005433717148	B0D69D	3666 024634	IGOR POPOV	{"phone": "+70747468204"}
0005433717149	CC960A	7197 852013	MAKSIM ZHUKOV	{"phone": "+70179081585"}
0005433717150	54B5A5	5946 686277	MATVEY SCHERBAKOV	{"phone": "+70538235100"}
0005433717151	54B5A5	6764 665258	GRIGORIY STEPANOV	{"phone": "+70010599235"}
0005433717152	54B5A5	6843 633767	ROMAN MAKAROV	{"email": "makarov-r1977@postgrespro.ru", "phone": "+70460206429"}
0005433717153	54B5A5	9926 593419	KIRILL POPOV	{"email": "popov.kirill-1967@postgrespro.ru", "phone": "+70941177115"}
0005433717154	D56296	9385 114221	LYUBOV GERASIMOVA	{"phone": "+70440276574"}
0005433717155	D56296	3500 836303	ELENA DANILOVA	{"email": "edanilova-1988@postgrespro.ru", "phone": "+70926007470"}
0005433717156	4E8B5E	4550 519760	ALEKSEY FEDOROV	{"email": "a.fedorov-051973@postgrespro.ru", "phone": "+70091947993"}
0005433717157	FB8682	8641 969386	SVETLANA ALEKSANDROVA	{"phone": "+70616089663"}
0005433717158	360EC6	4218 008482	LYUDMILA KALININA	{"phone": "+70159712761"}
0005433717159	360EC6	3367 285088	MARIYA IVANOVA	{"email": "m.ivanova011975@postgrespro.ru", "phone": "+70956667640"}
0005433717160	C72634	5487 514646	YULIYA FILATOVA	{"email": "yuliya.filatova-26091967@postgrespro.ru", "phone": "+70503560634"}
0005433717161	C72634	5661 566679	VALERIY GUSEV	{"phone": "+70497103883"}
0005433717162	79E339	0047 789604	ANNA PETROVA	{"phone": "+70433543152"}
0005433717163	74D2FD	4295 095402	IRINA NIKOLAEVA	{"phone": "+70142665033"}
0005433717164	76F23F	5565 522869	VIKTOR VASILEV	{"email": "v.vasilev_24071975@postgrespro.ru", "phone": "+70950034294"}
0005433717165	031F4A	1765 353506	VLADIMIR PETROV	{"email": "vladimir_petrov.27121971@postgrespro.ru", "phone": "+70258713950"}
0005433717166	031F4A	5977 473048	OLGA SOROKINA	{"email": "sorokina-o.30051968@postgrespro.ru", "phone": "+70917955422"}
0005433717167	91743F	3381 562155	NIKOLAY MELNIKOV	{"email": "melnikovn-10101969@postgrespro.ru", "phone": "+70388984752"}
0005433717168	752D2F	5059 247200	NADEZHDA KUZMINA	{"phone": "+70643393558"}
0005433717280	7BAA04	3450 456456	ALEKSANDR SOROKIN	{"phone": "+70708657019"}
0005433717169	752D2F	1341 492849	VLADIMIR OSIPOV	{"email": "osipov-v_011978@postgrespro.ru", "phone": "+70989012432"}
0005433717170	E9347E	4088 010425	MIKHAIL ALEKSEEV	{"email": "malekseev-111969@postgrespro.ru", "phone": "+70957987184"}
0005433717171	E9347E	1311 863363	TATYANA KARPOVA	{"phone": "+70729354963"}
0005433717172	B8B89A	2322 737198	OLESYA KULIKOVA	{"email": "olesya_kulikova-1966@postgrespro.ru", "phone": "+70748042204"}
0005433717173	D9D620	3723 592006	OLGA POPOVA	{"phone": "+70262049804"}
0005433717174	7ABB81	6488 823181	VALENTINA NESTEROVA	{"email": "valentina-nesterova_1971@postgrespro.ru", "phone": "+70514058995"}
0005433717175	7ABB81	5296 066134	GALINA ZHURAVLEVA	{"phone": "+70708931058"}
0005433717176	F991BC	2492 170286	SERGEY KUZNECOV	{"email": "sergey_kuznecov.111963@postgrespro.ru", "phone": "+70084269511"}
0005433717177	F73220	4730 388692	ANASTASIYA KAZAKOVA	{"phone": "+70389800569"}
0005433717178	3548E9	4941 150036	OKSANA GRISHINA	{"phone": "+70226872804"}
0005433717179	E14614	0892 665505	NIKOLAY OSIPOV	{"email": "n.osipov_1963@postgrespro.ru", "phone": "+70091053066"}
0005433717180	EC8CBA	5485 234913	ANTONINA FILIPPOVA	{"phone": "+70739201899"}
0005433717181	EC8CBA	8375 293303	NIKITA NIKITIN	{"phone": "+70356230342"}
0005433717182	566FA6	8081 910666	MARINA MASLOVA	{"email": "maslovamarina.05061972@postgrespro.ru", "phone": "+70589284377"}
0005433717183	9D0B74	5317 785279	NIKOLAY ALEKSANDROV	{"phone": "+70943876227"}
0005433717184	47D446	8255 905759	TATYANA KRASNOVA	{"email": "krasnova-t.071972@postgrespro.ru", "phone": "+70502146148"}
0005433717185	385C73	6006 712588	VALENTINA ANDREEVA	{"email": "valentina-andreeva_24071976@postgrespro.ru", "phone": "+70928885687"}
0005433717186	385C73	5349 838870	VLADIMIR KULIKOV	{"email": "vladimir_kulikov.021980@postgrespro.ru", "phone": "+70012631040"}
0005433717187	BAC9E7	7608 846072	OLGA YUDINA	{"email": "o-yudina_1965@postgrespro.ru", "phone": "+70274307140"}
0005433717188	7838A4	2898 537855	TATYANA ILINA	{"phone": "+70365181402"}
0005433717189	7838A4	3905 168363	NADEZHDA ZHUKOVA	{"phone": "+70784975702"}
0005433717190	E5315D	0942 183147	ILYA GORBUNOV	{"email": "gorbunovi-18081963@postgrespro.ru", "phone": "+70866159903"}
0005433717191	E5315D	6559 092872	IRINA FILIPPOVA	{"phone": "+70946641494"}
0005433717192	AA5053	9518 777557	ELENA SMIRNOVA	{"email": "smirnova-elena_22011981@postgrespro.ru", "phone": "+70486742205"}
0005433717193	AA5053	9655 237176	ANATOLIY KULIKOV	{"email": "akulikov_23061981@postgrespro.ru", "phone": "+70787458552"}
0005433717194	589AED	8987 833621	SVETLANA KARPOVA	{"phone": "+70881843892"}
0005433717195	589AED	3943 012051	ANTON DENISOV	{"email": "a.denisov_21011967@postgrespro.ru", "phone": "+70147324751"}
0005433717196	F35E0C	3325 869537	MAKSIM FEDOTOV	{"email": "fedotov_maksim31081983@postgrespro.ru", "phone": "+70730065103"}
0005433717197	F35E0C	7905 823221	ALEKSEY SCHERBAKOV	{"email": "scherbakov-a_01021975@postgrespro.ru", "phone": "+70428328597"}
0005433717198	DA51E9	8778 538767	NADEZHDA GORBUNOVA	{"email": "gorbunovan_24101967@postgrespro.ru", "phone": "+70953156867"}
0005433717199	8B3199	3420 513683	EVGENIY ALEKSEEV	{"phone": "+70301670003"}
0005433717200	8B3199	4193 964540	NADEZHDA SIDOROVA	{"email": "n-sidorova.18061973@postgrespro.ru", "phone": "+70761465269"}
0005433717201	0A0C2F	9452 713543	ALEKSANDR ILIN	{"phone": "+70935900009"}
0005433717202	0A0C2F	5580 550790	OLGA BELOVA	{"email": "belova-o.1969@postgrespro.ru", "phone": "+70125386653"}
0005433717203	5E6D23	5336 908283	IRINA NOVIKOVA	{"email": "novikova-irina-1973@postgrespro.ru", "phone": "+70586351508"}
0005433717204	5E6D23	2002 674194	OLGA MIKHAYLOVA	{"email": "mikhaylova-o-1989@postgrespro.ru", "phone": "+70714009995"}
0005433717205	F2CA50	2742 198645	ANNA FEDOROVA	{"phone": "+70660960807"}
0005433717206	F2CA50	2808 741735	ILYA DENISOV	{"email": "ilya-denisov_21121967@postgrespro.ru", "phone": "+70093729065"}
0005433717207	BF7A39	1708 870905	RIMA SERGEEVA	{"phone": "+70230457102"}
0005433717208	BF7A39	1215 796127	VASILIY IVANOV	{"email": "ivanov_v03021959@postgrespro.ru", "phone": "+70231291388"}
0005433717209	A4EBA0	9582 272820	EVGENIY VOLKOV	{"phone": "+70020872028"}
0005433717210	877ABF	5206 760997	NATALYA KONOVALOVA	{"email": "nkonovalova021958@postgrespro.ru", "phone": "+70850555295"}
0005433717211	877ABF	5546 879409	YURIY TIMOFEEV	{"email": "timofeev.yuriy.17021977@postgrespro.ru", "phone": "+70302736739"}
0005433717212	8ED739	6922 580323	KONSTANTIN FROLOV	{"phone": "+70059937730"}
0005433717213	C92207	7472 950018	EVGENIY KONOVALOV	{"email": "evgeniy_konovalov1971@postgrespro.ru", "phone": "+70912133466"}
0005433717214	FA43A1	8101 637757	YURIY GRIGOREV	{"phone": "+70881840454"}
0005433717215	B3947A	1347 685329	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov05041971@postgrespro.ru", "phone": "+70935443354"}
0005433717216	B3947A	0184 928068	NATALYA ZAKHAROVA	{"email": "zakharova-natalya_1968@postgrespro.ru", "phone": "+70036380215"}
0005433717217	B3947A	1318 890049	ILYA MIKHAYLOV	{"email": "i_mikhaylov.051979@postgrespro.ru", "phone": "+70751331214"}
0005433717218	38BD0E	8219 829450	MAKSIM FOMIN	{"phone": "+70814012839"}
0005433717219	94CDDF	0967 423206	ALEKSANDRA KUDRYASHOVA	{"email": "aleksandra.kudryashova_101976@postgrespro.ru", "phone": "+70587826875"}
0005433717220	E0B8DC	4746 818041	ELENA SERGEEVA	{"email": "e.sergeeva-28071984@postgrespro.ru", "phone": "+70982882971"}
0005433717221	591DDE	5633 629253	NATALYA ILINA	{"phone": "+70819490361"}
0005433717222	591DDE	6078 023945	ALEKSANDR SHEVCHENKO	{"phone": "+70844711547"}
0005433717223	5109D2	7263 022171	ALEKSEY ZAKHAROV	{"phone": "+70261615066"}
0005433717224	B5CF0D	0889 344422	ELENA LUKYANOVA	{"email": "lukyanovae_091969@postgrespro.ru", "phone": "+70787003429"}
0005433717225	408AC8	6210 259414	POLINA ALEKSEEVA	{"phone": "+70614086628"}
0005433717226	408AC8	9151 487420	KSENIYA DENISOVA	{"phone": "+70159364415"}
0005433717227	A40C14	9888 233584	SERGEY GAVRILOV	{"email": "gavrilov.sergey-24111980@postgrespro.ru", "phone": "+70442547948"}
0005433717228	D4B45A	4328 429960	EKATERINA SCHERBAKOVA	{"phone": "+70888009914"}
0005433717229	D4B45A	5442 328699	EVGENIYA KULIKOVA	{"email": "e.kulikova_22121973@postgrespro.ru", "phone": "+70717169574"}
0005433717230	A4C445	3424 962656	ANDREY ALEKSEEV	{"email": "andrey-alekseev.1961@postgrespro.ru", "phone": "+70609158973"}
0005433717231	C70632	3092 566428	DMITRIY MIKHAYLOV	{"phone": "+70023356526"}
0005433717232	B07DD4	5024 955861	SVETLANA NAUMOVA	{"phone": "+70453257372"}
0005433717233	461C17	0116 644235	GENNADIY IVANOV	{"phone": "+70364298028"}
0005433717234	342732	8548 222201	MAYA VLASOVA	{"email": "vlasova.maya.26081967@postgrespro.ru", "phone": "+70553126720"}
0005433717235	73788B	2897 154555	OLESYA PETROVA	{"email": "petrova.olesya.051967@postgrespro.ru", "phone": "+70639186110"}
0005433717236	88A009	0100 575604	YULIYA BORISOVA	{"email": "yuliya.borisova17051968@postgrespro.ru", "phone": "+70729479628"}
0005433717237	FA6229	3555 212163	VIOLETTA MAKSIMOVA	{"email": "violettamaksimova_081980@postgrespro.ru", "phone": "+70926662790"}
0005433717238	3DE982	5629 168051	TATYANA ALEKSEEVA	{"phone": "+70156620432"}
0005433717239	3DE982	7949 199338	LYUDMILA OSIPOVA	{"phone": "+70185242914"}
0005433717240	81D37F	8173 386319	MARIYA ABRAMOVA	{"email": "mariyaabramova101964@postgrespro.ru", "phone": "+70040787717"}
0005433717241	C0C8D0	7410 765599	ANNA KISELEVA	{"email": "anna.kiseleva031975@postgrespro.ru", "phone": "+70732714490"}
0005433717242	10D20B	9051 420388	POLINA EGOROVA	{"phone": "+70601869577"}
0005433717243	7577AB	2510 803512	ANASTASIYA YUDINA	{"email": "yudina-anastasiya.1976@postgrespro.ru", "phone": "+70303767798"}
0005433717244	7577AB	8206 669988	YULIYA ZAYCEVA	{"phone": "+70403113437"}
0005433717245	1D62DC	6976 683460	EVGENIY KUZMIN	{"phone": "+70215928562"}
0005433717246	98FB18	8903 889907	TATYANA FEDOROVA	{"phone": "+70495560407"}
0005433717247	B16EB8	2976 157417	ALEKSANDR BORISOV	{"email": "aleksandr_borisov-011977@postgrespro.ru", "phone": "+70602341685"}
0005433717248	B16EB8	3081 874205	YULIYA IVANOVA	{"email": "ivanova.y-1956@postgrespro.ru", "phone": "+70409876956"}
0005433717249	3D1F54	3840 249482	LILIYA KARPOVA	{"phone": "+70324182260"}
0005433717250	B16394	5961 269834	DMITRIY GORBUNOV	{"email": "gorbunovdmitriy1987@postgrespro.ru", "phone": "+70396028109"}
0005433717251	B16394	9128 909936	YULIYA SOROKINA	{"phone": "+70496076721"}
0005433717252	B16394	3075 170035	ANTON BORISOV	{"email": "anton.borisov1976@postgrespro.ru", "phone": "+70077045670"}
0005433717253	7F37C1	2876 795511	ALEKSANDR GAVRILOV	{"phone": "+70820362761"}
0005433717254	7F37C1	8053 098701	NINA MIKHAYLOVA	{"phone": "+70439705887"}
0005433717255	1F5EE3	2057 454469	MARIYA NOVIKOVA	{"phone": "+70141755027"}
0005433717256	ED3A1C	3196 977388	ALEKSANDRA MEDVEDEVA	{"email": "medvedeva.aleksandra_17021977@postgrespro.ru", "phone": "+70680975068"}
0005433717257	ED3A1C	3398 245685	IVAN KUZNECOV	{"phone": "+70039250352"}
0005433717258	B111C0	2167 481611	ANTON VASILEV	{"phone": "+70044488500"}
0005433717259	D447C8	6970 676899	SERGEY MEDVEDEV	{"phone": "+70701803471"}
0005433717260	F3D2A5	6268 689154	SVETLANA BORISOVA	{"email": "svetlanaborisova-16061981@postgrespro.ru", "phone": "+70347350836"}
0005433717261	1216B3	7503 678763	TATYANA POPOVA	{"phone": "+70537990757"}
0005433717262	1216B3	7937 173549	ANNA BELYAEVA	{"email": "belyaevaa_26121959@postgrespro.ru", "phone": "+70479272265"}
0005433717263	620A68	5237 013761	IVAN ORLOV	{"email": "ivan.orlov091984@postgrespro.ru", "phone": "+70656950333"}
0005433717264	902A77	5740 482752	VLADISLAV STEPANOV	{"phone": "+70686421431"}
0005433717265	902A77	4007 337321	SERGEY SIDOROV	{"email": "sergey.sidorov.051979@postgrespro.ru", "phone": "+70554314082"}
0005433717266	36EF09	8122 370911	ALEKSEY SMIRNOV	{"phone": "+70776974657"}
0005433717267	36EF09	5542 941740	VENIAMIN ALEKSEEV	{"email": "alekseevveniamin1973@postgrespro.ru", "phone": "+70328837351"}
0005433717268	9F878D	4601 386869	EVGENIY IVANOV	{"phone": "+70837856907"}
0005433717269	8FBF1B	5902 573173	TATYANA NAZAROVA	{"email": "nazarovat.1970@postgrespro.ru", "phone": "+70064083192"}
0005433717270	8FBF1B	2088 010986	NATALIYA SOLOVEVA	{"email": "soloveva.n121975@postgrespro.ru", "phone": "+70181501007"}
0005433717271	CC030F	1515 514681	KSENIYA MOROZOVA	{"email": "morozova-k_16011980@postgrespro.ru", "phone": "+70922427829"}
0005433717272	33A061	2501 544833	ELENA ANISIMOVA	{"phone": "+70330773004"}
0005433717273	33A061	6010 935785	ELIZAVETA GORBUNOVA	{"phone": "+70195651698"}
0005433717274	5DB617	5985 986672	IRINA NIKITINA	{"phone": "+70653745860"}
0005433717275	5DB617	9648 992703	NIKOLAY ANTONOV	{"email": "nikolay.antonov_1977@postgrespro.ru", "phone": "+70908921156"}
0005433717276	0C49E1	3207 159015	VYACHESLAV GRIGOREV	{"email": "grigorev.vyacheslav08121974@postgrespro.ru", "phone": "+70151464120"}
0005433717277	0C49E1	8349 518619	VYACHESLAV VASILEV	{"phone": "+70672664449"}
0005433717278	228585	9296 842637	VLADIMIR NIKITIN	{"email": "nikitin_vladimir-011973@postgrespro.ru", "phone": "+70689492926"}
0005433717279	228585	6621 649779	GALINA EGOROVA	{"email": "egorovagalina-07081978@postgrespro.ru", "phone": "+70139007908"}
0005433717281	5E153A	4168 251824	TATYANA VOLKOVA	{"email": "tatyana-volkova_1977@postgrespro.ru", "phone": "+70424540420"}
0005433717282	2EDA30	4062 951346	DMITRIY MELNIKOV	{"phone": "+70443839807"}
0005433717283	80DF0F	7449 373858	YAROSLAV MAKSIMOV	{"email": "y.maksimov-25111955@postgrespro.ru", "phone": "+70933950671"}
0005433717284	80DF0F	5964 934491	NIKOLAY BELOV	{"phone": "+70303513638"}
0005433717285	FB3E8A	8133 926270	NINA MOROZOVA	{"email": "morozova.nina_17101978@postgrespro.ru", "phone": "+70639940119"}
0005433717286	2AA346	5215 737442	ELENA FILIPPOVA	{"email": "filippova_e_18011969@postgrespro.ru", "phone": "+70358855129"}
0005433717287	2AA346	0303 812976	VYACHESLAV KUZNECOV	{"email": "kuznecov.vyacheslav1975@postgrespro.ru", "phone": "+70364994103"}
0005433717288	4FC2CC	8073 286603	LYUBOV MALYSHEVA	{"phone": "+70038822226"}
0005433717289	4FC2CC	2933 012696	LIDIYA POPOVA	{"email": "l_popova091969@postgrespro.ru", "phone": "+70512499279"}
0005433717290	4FC2CC	2294 851200	YURIY SAVELEV	{"email": "y-savelev1957@postgrespro.ru", "phone": "+70965436473"}
0005433717291	793706	7704 736583	AYRAT SIDOROV	{"email": "a_sidorov1972@postgrespro.ru", "phone": "+70445392909"}
0005433717292	6DEB03	2874 118391	VIKTOR NIKOLAEV	{"email": "nikolaev.v-1962@postgrespro.ru", "phone": "+70884868113"}
0005433717293	C3A67A	2478 634355	ELENA BORISOVA	{"email": "borisova.elena_21011971@postgrespro.ru", "phone": "+70863662356"}
0005433717294	378865	9211 498749	TAMARA KRASNOVA	{"phone": "+70211726269"}
0005433717295	02664D	6888 411605	IGOR KUDRYASHOV	{"phone": "+70067350746"}
0005433717296	F68F9F	5949 072949	IRINA PETROVA	{"email": "irinapetrova031970@postgrespro.ru", "phone": "+70124452256"}
0005433717297	DB1754	1072 336405	VALENTINA IVANOVA	{"phone": "+70419832154"}
0005433717298	1C75B9	0917 725834	NATALYA NIKOLAEVA	{"email": "n-nikolaeva_14111976@postgrespro.ru", "phone": "+70701999069"}
0005433717299	3F3A51	6383 090183	EVGENIY POPOV	{"phone": "+70126568612"}
0005433717300	3F3A51	1133 625178	ELENA MATVEEVA	{"email": "elena_matveeva-031979@postgrespro.ru", "phone": "+70809731781"}
0005433717301	3F3A51	3029 353114	KSENIYA MARTYNOVA	{"phone": "+70707690681"}
0005433717302	3801C3	7608 434896	SERGEY SERGEEV	{"phone": "+70034770986"}
0005433717303	3801C3	5859 455244	EVGENIYA VASILEVA	{"email": "evasileva-1978@postgrespro.ru", "phone": "+70054984697"}
0005433717304	913E6F	1502 926113	DMITRIY SMIRNOV	{"email": "smirnov-dmitriy_1978@postgrespro.ru", "phone": "+70968179272"}
0005433717305	06CD26	2301 090369	ALEKSANDR ANDREEV	{"phone": "+70509923590"}
0005433717306	71820E	3382 701832	TATYANA KOMAROVA	{"phone": "+70042908767"}
0005433717307	71820E	3537 939674	VALERIY PETROV	{"email": "valeriypetrov.1972@postgrespro.ru", "phone": "+70545335677"}
0005433717308	71820E	6695 033090	ANDREY FEDOROV	{"email": "fedorov_andrey.16061976@postgrespro.ru", "phone": "+70745792985"}
0005433717420	B8CF42	1562 546897	LYUDMILA YUDINA	{"phone": "+70187201161"}
0005433717309	5CACDE	1153 641796	TATYANA NESTEROVA	{"email": "nesterova_t_04101964@postgrespro.ru", "phone": "+70553311152"}
0005433717310	FF27D5	0841 454674	NINA TARASOVA	{"email": "tarasova.n-20061974@postgrespro.ru", "phone": "+70782163527"}
0005433717311	FF27D5	0179 572572	IRINA KONOVALOVA	{"phone": "+70347812379"}
0005433717312	F3AC38	6349 686808	YULIYA GRISHINA	{"email": "yuliyagrishina_10111968@postgrespro.ru", "phone": "+70185400796"}
0005433717313	F8DC94	9085 750270	YURIY BARANOV	{"phone": "+70749586680"}
0005433717314	9874D3	0998 119377	VERA STEPANOVA	{"phone": "+70879911144"}
0005433717315	A6D630	7591 016225	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_1979@postgrespro.ru", "phone": "+70237468312"}
0005433717316	A6D630	6925 585061	FEDOR MOROZOV	{"email": "fedor.morozov-12101978@postgrespro.ru", "phone": "+70489571666"}
0005433717317	C92885	8961 940123	MARINA SERGEEVA	{"email": "m_sergeeva.27021974@postgrespro.ru", "phone": "+70844580094"}
0005433717318	07D01D	4964 776599	SERGEY POPOV	{"phone": "+70705704711"}
0005433717319	58CDFB	6454 047351	GRIGORIY SIDOROV	{"email": "grigoriysidorov.071975@postgrespro.ru", "phone": "+70825714380"}
0005433717320	58CDFB	1051 232533	SERGEY SMIRNOV	{"email": "smirnovsergey26071976@postgrespro.ru", "phone": "+70489825845"}
0005433717321	7FA4C2	5413 417130	VALERIY SOKOLOV	{"email": "valeriysokolov_021959@postgrespro.ru", "phone": "+70510294489"}
0005433717322	7FA4C2	8237 460008	PAVEL MIKHAYLOV	{"email": "pavelmikhaylov08031968@postgrespro.ru", "phone": "+70593883828"}
0005433717323	17530A	7425 665188	ALEKSEY VOLKOV	{"phone": "+70122220601"}
0005433717324	55B3BA	4800 849119	MARIYA KONOVALOVA	{"phone": "+70232088797"}
0005433717325	55B3BA	7996 203535	ALEKSANDR POPOV	{"email": "popov_aleksandr.081968@postgrespro.ru", "phone": "+70286511784"}
0005433717326	220B24	2779 971482	ALEKSANDR MATVEEV	{"phone": "+70559758564"}
0005433717327	220B24	5014 161954	KIRILL SCHERBAKOV	{"phone": "+70282076315"}
0005433717328	1896B9	6278 316129	NIKITA STEPANOV	{"phone": "+70879653236"}
0005433717329	1896B9	3523 312864	VITALIY DAVYDOV	{"email": "v.davydov.31121971@postgrespro.ru", "phone": "+70037776810"}
0005433717330	17E68E	6131 169601	EKATERINA KOLESNIKOVA	{"phone": "+70419170870"}
0005433717331	7FA775	8311 303280	ELENA KOROLEVA	{"phone": "+70442085613"}
0005433717332	7FA775	6203 915789	LYUDMILA SERGEEVA	{"email": "lyudmila-sergeeva-1965@postgrespro.ru", "phone": "+70964928704"}
0005433717333	1B4D12	6649 564356	TATYANA NOVIKOVA	{"email": "tatyananovikova01051977@postgrespro.ru", "phone": "+70472618394"}
0005433717334	E86C73	9313 141260	SERGEY NOVIKOV	{"email": "sergey-novikov_1972@postgrespro.ru", "phone": "+70682407208"}
0005433717335	3DC885	5054 364289	GALINA BORISOVA	{"email": "galina.borisova30101988@postgrespro.ru", "phone": "+70309407071"}
0005433717336	A3F817	4370 902633	NINA LAZAREVA	{"phone": "+70971417838"}
0005433717337	34084F	5798 601661	OLEG KARPOV	{"email": "okarpov.23021975@postgrespro.ru", "phone": "+70232750953"}
0005433717338	660580	4443 630967	VERONIKA GRISHINA	{"email": "grishina-v.27111980@postgrespro.ru", "phone": "+70609809360"}
0005433717339	660580	7461 890952	PAVEL SHEVCHENKO	{"email": "pavel.shevchenko_121973@postgrespro.ru", "phone": "+70028570514"}
0005433717340	E55886	1806 833782	SVETLANA BARANOVA	{"email": "baranova.svetlana.1962@postgrespro.ru", "phone": "+70382978373"}
0005433717341	E4B278	7267 120424	LYUBOV ZAKHAROVA	{"email": "zakharova.l_101964@postgrespro.ru", "phone": "+70160995662"}
0005433717342	256C92	0315 101480	VLADIMIR SAVELEV	{"email": "savelevv20041975@postgrespro.ru", "phone": "+70179476977"}
0005433717343	58C416	3225 172997	VALENTIN AFANASEV	{"email": "afanasev.valentin.1967@postgrespro.ru", "phone": "+70442760971"}
0005433717344	A16AE7	4819 162525	EGOR ALEKSEEV	{"phone": "+70132942098"}
0005433717345	A16AE7	0518 550032	EVGENIYA NESTEROVA	{"email": "e.nesterova031968@postgrespro.ru", "phone": "+70939942453"}
0005433717346	F90F1E	3185 772152	SERGEY NOVIKOV	{"email": "novikov.sergey041969@postgrespro.ru", "phone": "+70830857179"}
0005433717347	22D577	9448 821300	BOGDAN KUZNECOV	{"phone": "+70769752263"}
0005433717348	691B22	0449 404820	IVAN KUZMIN	{"phone": "+70692070379"}
0005433717349	538ACA	9190 840491	ELENA TITOVA	{"email": "titova-e_05081974@postgrespro.ru", "phone": "+70337677883"}
0005433717350	538ACA	2352 952331	TAMARA SEMENOVA	{"email": "semenova_tamara.03041967@postgrespro.ru", "phone": "+70257953547"}
0005433717351	3027C3	7996 378988	PETR IVANOV	{"phone": "+70270696331"}
0005433717352	3027C3	8064 130214	IGOR MOISEEV	{"phone": "+70960591912"}
0005433717353	3542E4	3386 505566	OLGA FOMINA	{"email": "olga_fomina14111982@postgrespro.ru", "phone": "+70612894066"}
0005433717354	678CED	0048 386185	ELENA ROMANOVA	{"phone": "+70335411067"}
0005433717355	678CED	6515 369228	ANATOLIY PAVLOV	{"email": "anatoliy.pavlov.101980@postgrespro.ru", "phone": "+70025253505"}
0005433717356	18B1A3	8521 324823	NATALYA KUZNECOVA	{"phone": "+70638947339"}
0005433717357	18B1A3	7906 613685	ALEKSANDR DMITRIEV	{"phone": "+70805407905"}
0005433717358	18B1A3	9248 285990	MIKHAIL GERASIMOV	{"phone": "+70641013646"}
0005433717359	C9FD1B	0602 253167	ANNA KOLESNIKOVA	{"email": "kolesnikova_a.26011970@postgrespro.ru", "phone": "+70401459361"}
0005433717360	C39606	5954 595676	TATYANA ABRAMOVA	{"phone": "+70653007055"}
0005433717361	C39606	8945 708923	ALEKSEY ZAYCEV	{"phone": "+70247678567"}
0005433717362	C39606	0095 700235	LILIYA KOROLEVA	{"email": "lkoroleva-1959@postgrespro.ru", "phone": "+70894110998"}
0005433717363	1536EF	1418 794270	TATYANA PETROVA	{"phone": "+70937624055"}
0005433717421	B8CF42	1776 113848	LYUBOV YUDINA	{"phone": "+70697829879"}
0005433717364	1536EF	8582 968866	LYUDMILA SMIRNOVA	{"email": "smirnova_lyudmila-1976@postgrespro.ru", "phone": "+70536239438"}
0005433717365	1536EF	7403 521904	ANNA KRASNOVA	{"email": "a-krasnova.091978@postgrespro.ru", "phone": "+70348742626"}
0005433717366	566B6A	6395 898425	MARINA TITOVA	{"phone": "+70048827266"}
0005433717367	63F5FA	1395 752451	EVGENIY KAZAKOV	{"phone": "+70280131375"}
0005433717368	63F5FA	0747 828897	LIDIYA ALEKSEEVA	{"email": "alekseeva-l.1979@postgrespro.ru", "phone": "+70239562318"}
0005433717369	856A29	6775 712732	OLGA SIDOROVA	{"phone": "+70992293523"}
0005433717370	856A29	9315 014928	SERGEY MOROZOV	{"email": "morozovs-01061973@postgrespro.ru", "phone": "+70054656423"}
0005433717371	8491C2	0670 224928	POLINA OVCHINNIKOVA	{"email": "ovchinnikovap_021968@postgrespro.ru", "phone": "+70997036674"}
0005433717372	3EA0B4	8508 710798	LIDIYA VOROBEVA	{"phone": "+70773792101"}
0005433717373	15A25C	0806 241892	ALEKSANDRA NAUMOVA	{"phone": "+70097456784"}
0005433717374	15A25C	7837 231248	TATYANA TROFIMOVA	{"phone": "+70453860253"}
0005433717375	6B1778	8004 057273	SVETLANA BELYAEVA	{"phone": "+70665559121"}
0005433717376	EE55D6	6543 776231	TATYANA ANTONOVA	{"phone": "+70538434595"}
0005433717377	5C8582	9258 764765	ELENA ROMANOVA	{"phone": "+70806622531"}
0005433717378	5C8582	3978 974138	ARTEM ZHURAVLEV	{"phone": "+70761902473"}
0005433717379	EE3506	5860 630398	LIDIYA NIKOLAEVA	{"phone": "+70199698884"}
0005433717380	EE3506	6118 369342	VIKTOR VASILEV	{"phone": "+70384450297"}
0005433717381	3EB770	4898 531165	YULIYA GERASIMOVA	{"phone": "+70131414624"}
0005433717382	3EB770	0562 479478	ILYA YAKOVLEV	{"phone": "+70637823803"}
0005433717383	3EB770	9610 252467	TATYANA SOROKINA	{"phone": "+70575609566"}
0005433717384	B033D2	6930 271525	VALENTINA SEMENOVA	{"phone": "+70928509242"}
0005433717385	B033D2	5116 251650	GENNADIY OSIPOV	{"email": "gennadiyosipov011976@postgrespro.ru", "phone": "+70048233035"}
0005433717386	172F67	5723 946027	VENIAMIN ZAKHAROV	{"email": "v_zakharov_061959@postgrespro.ru", "phone": "+70134255094"}
0005433717387	172F67	1343 841025	EGOR KRASNOV	{"phone": "+70321705226"}
0005433717388	07C628	5666 891934	MARIYA AFANASEVA	{"phone": "+70063778472"}
0005433717389	F23F34	6161 806513	ALEKSANDR IVANOV	{"phone": "+70183992805"}
0005433717390	6C0C34	2729 078193	NINA KRASNOVA	{"email": "n-krasnova_1983@postgrespro.ru", "phone": "+70656001721"}
0005433717391	5901CB	8443 313709	VERONIKA VASILEVA	{"email": "veronika.vasileva-20041969@postgrespro.ru", "phone": "+70339131555"}
0005433717392	5901CB	5245 920030	VALENTINA POPOVA	{"email": "valentina-popova.08051971@postgrespro.ru", "phone": "+70644088837"}
0005433717393	7172A9	1539 570371	EVGENIY VOROBEV	{"email": "evgeniy.vorobev.1966@postgrespro.ru", "phone": "+70728867716"}
0005433717394	8ABC5F	5869 025379	MIKHAIL MATVEEV	{"email": "matveev.m01041961@postgrespro.ru", "phone": "+70501051693"}
0005433717395	C37452	0668 786711	KIRILL SOKOLOV	{"email": "sokolov.k.16071972@postgrespro.ru", "phone": "+70582896812"}
0005433717396	A9B4FE	1011 748532	VYACHESLAV ALEKSANDROV	{"phone": "+70728904070"}
0005433717397	A9B4FE	9517 718083	YAROSLAV MATVEEV	{"phone": "+70019613274"}
0005433717398	1B254C	0081 629230	ANNA BELYAEVA	{"email": "belyaeva.a.09051969@postgrespro.ru", "phone": "+70923958398"}
0005433717399	6A8CD6	5266 782187	KONSTANTIN KONOVALOV	{"email": "k_konovalov_071974@postgrespro.ru", "phone": "+70914814522"}
0005433717400	469E65	0187 922344	ALEKSANDR FEDOROV	{"phone": "+70919220368"}
0005433717401	469E65	3865 312382	YULIYA VASILEVA	{"phone": "+70364278240"}
0005433717402	469E65	8082 112566	ELIZAVETA EFREMOVA	{"email": "elizaveta_efremova-101974@postgrespro.ru", "phone": "+70608793712"}
0005433717404	502F9D	1569 399990	TAISIYA IVANOVA	{"email": "t.ivanova_051969@postgrespro.ru", "phone": "+70391420586"}
0005433717405	F55587	1074 482826	VALENTINA POPOVA	{"email": "popova.valentina.26121979@postgrespro.ru", "phone": "+70787374322"}
0005433717406	A59374	4129 053621	ALLA KOMAROVA	{"email": "komarova-alla.23121961@postgrespro.ru", "phone": "+70302526298"}
0005433717407	9D3A52	3304 806875	ANDREY MIKHAYLOV	{"phone": "+70693601175"}
0005433717408	0DCB62	4788 655967	ELENA PAVLOVA	{"email": "pavlova.e_101964@postgrespro.ru", "phone": "+70480246787"}
0005433717409	5BD0B3	5252 194968	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy-081970@postgrespro.ru", "phone": "+70416131480"}
0005433717410	5BD0B3	5332 443842	NATALYA TARASOVA	{"email": "tarasovanatalya12071974@postgrespro.ru", "phone": "+70962954935"}
0005433717411	15E6C0	8279 574394	OLGA LEBEDEVA	{"email": "lebedeva.o.081971@postgrespro.ru", "phone": "+70042805930"}
0005433717412	8BA34E	0691 776963	VLADISLAV KOZLOV	{"phone": "+70241427550"}
0005433717413	B36A36	1455 729232	ALEKSANDR BELOV	{"email": "aleksandr-belov-1980@postgrespro.ru", "phone": "+70368694549"}
0005433717414	84F10F	7492 921826	OLGA VOLKOVA	{"phone": "+70189295564"}
0005433717415	7B669D	3730 358980	MARIYA KUZNECOVA	{"email": "m-kuznecova.011973@postgrespro.ru", "phone": "+70836125917"}
0005433717416	9AB3D9	7330 627582	ZINAIDA NAZAROVA	{"email": "nazarova_zinaida_071985@postgrespro.ru", "phone": "+70586514135"}
0005433717417	9AB3D9	9910 217199	VLADIMIR DAVYDOV	{"phone": "+70846334118"}
0005433717418	3FBF1D	3591 394454	ALEKSANDR FEDOTOV	{"email": "a_fedotov-27061969@postgrespro.ru", "phone": "+70161083163"}
0005433717419	B8CF42	1807 056083	OLGA GUSEVA	{"email": "o.guseva08031962@postgrespro.ru", "phone": "+70154183981"}
0005433717422	F5A34E	2246 136806	VALENTINA AFANASEVA	{"email": "afanaseva_v17091977@postgrespro.ru", "phone": "+70283118345"}
0005433717423	DF013B	6719 458642	NATALIYA SOLOVEVA	{"phone": "+70365836228"}
0005433717424	9B782C	5362 445021	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov-041969@postgrespro.ru", "phone": "+70374685188"}
0005433717425	A44748	6287 633455	MAKSIM KUZNECOV	{"phone": "+70383467601"}
0005433717426	03525E	6135 737526	LYUDMILA FILIPPOVA	{"phone": "+70022609760"}
0005433717427	317B58	3636 157815	SERGEY GUSEV	{"phone": "+70283802916"}
0005433717428	72084B	0196 971816	VALENTINA VOROBEVA	{"phone": "+70463538280"}
0005433717429	2AFB36	8107 392972	NATALYA NESTEROVA	{"email": "nesterova.natalya27121969@postgrespro.ru", "phone": "+70979255607"}
0005433717430	F225D4	4049 904896	ALEKSANDR KUZNECOV	{"phone": "+70553173575"}
0005433717431	956975	9223 931489	NADEZHDA MAKAROVA	{"email": "makarova-n_1969@postgrespro.ru", "phone": "+70835136055"}
0005433717432	7D6595	4274 832020	VIKTOR FEDOROV	{"phone": "+70004284344"}
0005433719080	68D4E2	4220 750285	ALEKSEY KUZMIN	{"email": "kuzmin_a_1985@postgrespro.ru", "phone": "+70060292560"}
0005433719081	8F2347	2576 782001	PAVEL STEPANOV	{"email": "p_stepanov_22021970@postgrespro.ru", "phone": "+70967475557"}
0005433719082	58E2E0	2212 881507	PETR SAVELEV	{"phone": "+70452165921"}
0005433719083	FD78C1	0000 649862	TATYANA KUZMINA	{"email": "kuzmina_t.061977@postgrespro.ru", "phone": "+70007522146"}
0005433719084	5BE038	3273 919083	SVETLANA NESTEROVA	{"phone": "+70724510051"}
0005433719085	EDE1DE	1324 255574	VIKTOR NAUMOV	{"phone": "+70238130869"}
0005433719086	3B800E	8147 753442	SERGEY POPOV	{"email": "s_popov.07101961@postgrespro.ru", "phone": "+70255977745"}
0005433719087	3B800E	4137 677852	IVAN GUSEV	{"email": "i.gusev.1966@postgrespro.ru", "phone": "+70889635791"}
0005433719088	014F67	8525 143429	GALINA SCHERBAKOVA	{"email": "galina.scherbakova101975@postgrespro.ru", "phone": "+70328659747"}
0005433719089	A082F5	6249 196168	ALEKSANDR BORISOV	{"email": "aleksandr.borisov_021972@postgrespro.ru", "phone": "+70788456935"}
0005433719090	70B528	9373 684510	RAIS KARPOV	{"email": "rais.karpov.1968@postgrespro.ru", "phone": "+70833463327"}
0005433719091	70B528	8063 595950	IRINA KUZNECOVA	{"email": "i.kuznecova-1979@postgrespro.ru", "phone": "+70974634950"}
0005433719092	742760	7220 551177	SHAMIL DAVYDOV	{"phone": "+70618592913"}
0005433719093	742760	1255 839399	LARISA FILATOVA	{"email": "larisa.filatova.101980@postgrespro.ru", "phone": "+70524011256"}
0005433719094	5EB3B6	9607 718360	ROMAN KUZNECOV	{"phone": "+70347262651"}
0005433719095	75890C	8813 123812	MAKSIM STEPANOV	{"phone": "+70998258859"}
0005433719096	75890C	2280 411804	LYUBOV ABRAMOVA	{"phone": "+70009103742"}
0005433719097	8E3CF1	4236 492885	MIKHAIL MOROZOV	{"phone": "+70537777095"}
0005433719098	C60FC8	5025 470161	NIKOLAY SMIRNOV	{"email": "nikolay.smirnov-1974@postgrespro.ru", "phone": "+70586541167"}
0005433719099	26CFD3	9842 742271	MARIYA OSIPOVA	{"phone": "+70140414553"}
0005433719100	C3C1C0	0802 686831	MARGARITA ANDREEVA	{"phone": "+70758688387"}
0005433719101	EA2239	4984 983034	ALEKSANDRA SMIRNOVA	{"phone": "+70951178485"}
0005433719102	EA2239	9781 685236	GALINA KUZNECOVA	{"email": "g-kuznecova_26071982@postgrespro.ru", "phone": "+70707870055"}
0005433719103	AAAE00	4216 042406	IRINA NAUMOVA	{"email": "inaumova14011975@postgrespro.ru", "phone": "+70864081833"}
0005433719104	E54137	7122 241791	EVGENIYA POPOVA	{"email": "popova-evgeniya-26081974@postgrespro.ru", "phone": "+70268881403"}
0005433719105	04B2B6	6757 432340	VLADIMIR ABRAMOV	{"email": "vladimir-abramov_041980@postgrespro.ru", "phone": "+70016175031"}
0005433719106	433197	1611 184872	ALEKSANDR GUSEV	{"phone": "+70472300374"}
0005433719107	74C03C	0879 438232	IRINA OSIPOVA	{"email": "irinaosipova.071978@postgrespro.ru", "phone": "+70570867977"}
0005433719108	21E7DA	5894 294079	NATALYA ANTONOVA	{"email": "antonovanatalya.081969@postgrespro.ru", "phone": "+70744145962"}
0005433719109	023F85	5194 937542	DARYA KRASNOVA	{"phone": "+70848247330"}
0005433719110	023F85	6987 074121	SERGEY ILIN	{"email": "ilin.s_1976@postgrespro.ru", "phone": "+70599335909"}
0005433719111	265888	4356 211154	RUSLAN SMIRNOV	{"phone": "+70831982148"}
0005433719112	265888	2913 248870	YULIYA IVANOVA	{"email": "ivanovayuliya.031979@postgrespro.ru", "phone": "+70537468789"}
0005433719113	879B2D	9627 733426	OLEG KRASNOV	{"email": "krasnovoleg_1974@postgrespro.ru", "phone": "+70858336136"}
0005433719114	9785A7	0789 128168	SERGEY FILIPPOV	{"email": "sergey.filippov-121980@postgrespro.ru", "phone": "+70834075901"}
0005433719115	E02CDE	5077 845909	PETR SMIRNOV	{"email": "p_smirnov.1982@postgrespro.ru", "phone": "+70880032533"}
0005433719116	CF0FFD	4786 917774	ALEKSANDR KARPOV	{"email": "a.karpov.15021978@postgrespro.ru", "phone": "+70837564296"}
0005433719117	CF0FFD	9900 939439	SVETLANA LUKYANOVA	{"phone": "+70202259187"}
0005433719118	19A0C2	2433 558182	IRAIDA AFANASEVA	{"email": "iraidaafanaseva_051979@postgrespro.ru", "phone": "+70485455226"}
0005433719119	CAA6F0	5940 195303	MARINA SOKOLOVA	{"phone": "+70255495239"}
0005433719120	BCD6C3	0390 004948	TIGRAN BORISOV	{"email": "borisov-tigran_06111978@postgrespro.ru", "phone": "+70005640785"}
0005433719121	BCD6C3	6936 664795	IVAN MIRONOV	{"phone": "+70064851328"}
0005433719122	7AAAFC	4384 136136	YURIY ILIN	{"phone": "+70379941811"}
0005433719123	1E1A03	6768 437574	ZINAIDA OSIPOVA	{"phone": "+70039379812"}
0005433719124	882A3E	7640 174565	SERGEY RODIONOV	{"phone": "+70435052572"}
0005433719125	73903E	8839 762634	ANTONINA KOZLOVA	{"email": "antonina-kozlova_1971@postgrespro.ru", "phone": "+70622181219"}
0005433719126	73903E	2838 958317	ANASTASIYA YAKOVLEVA	{"phone": "+70789247572"}
0005433719127	37BCC9	1757 333258	NIKOLAY NOVIKOV	{"phone": "+70114497222"}
0005433719128	D4EC23	9482 005900	OLGA ARKHIPOVA	{"email": "o.arkhipova.101964@postgrespro.ru", "phone": "+70837916981"}
0005433719129	23101F	5114 528411	ANATOLIY DENISOV	{"email": "anatoliydenisov.23071970@postgrespro.ru", "phone": "+70637047486"}
0005433719130	010FA5	8188 103476	EKATERINA ERMAKOVA	{"email": "ermakova_ekaterina1971@postgrespro.ru", "phone": "+70153363747"}
0005433719131	906B8E	8985 727616	ZINAIDA SERGEEVA	{"phone": "+70759808352"}
0005433719132	906B8E	9169 532139	ALEKSANDR KUZNECOV	{"email": "kuznecov.a051960@postgrespro.ru", "phone": "+70073035305"}
0005433719133	906B8E	3611 383150	IRINA FEDOROVA	{"phone": "+70255499827"}
0005433719134	2F673E	2728 575297	PETR IVANOV	{"phone": "+70652349882"}
0005433719135	0A2571	5870 179382	NATALYA MEDVEDEVA	{"phone": "+70779781507"}
0005433719136	19BD73	3751 631043	ALEKSANDR ZAKHAROV	{"email": "zakharov-a.07101979@postgrespro.ru", "phone": "+70262236698"}
0005433719137	19BD73	1709 333940	ALEKSANDR TARASOV	{"email": "tarasov_a_051969@postgrespro.ru", "phone": "+70054234924"}
0005433719138	66A713	4399 414117	VALERIY PAVLOV	{"phone": "+70807531949"}
0005433719139	E5A475	4700 861560	ANTONINA ALEKSEEVA	{"email": "antonina.alekseeva.08101969@postgrespro.ru", "phone": "+70894240855"}
0005433719140	E9B10A	6212 365606	ANASTASIYA FADEEVA	{"phone": "+70789498889"}
0005433719141	E9B10A	6159 332264	OLGA SOROKINA	{"phone": "+70831223789"}
0005433719142	E9B10A	9959 979930	ALEKSEY BARANOV	{"email": "aleksey-baranov28021975@postgrespro.ru", "phone": "+70165586283"}
0005433719143	8F09E7	7290 753793	NINA SIDOROVA	{"email": "nsidorova.07121978@postgrespro.ru", "phone": "+70679023229"}
0005433719144	E161EE	4189 226656	RUFINA PAVLOVA	{"email": "pavlova_r.05021971@postgrespro.ru", "phone": "+70231667848"}
0005433719145	82AFF3	3105 774340	GALINA SIDOROVA	{"email": "sidorovag091973@postgrespro.ru", "phone": "+70003528492"}
0005433719146	8A4B3A	4301 225726	DMITRIY GERASIMOV	{"email": "gerasimovdmitriy08111968@postgrespro.ru", "phone": "+70070415719"}
0005433719147	C8B8FF	3291 488722	LYUBOV SIDOROVA	{"email": "sidorovalyubov-03081966@postgrespro.ru", "phone": "+70816611804"}
0005433719148	F29B9E	8946 492875	VIKTOR IVANOV	{"phone": "+70125657764"}
0005433719149	BEBBF3	5469 953382	VIKTOR SAVELEV	{"phone": "+70399802742"}
0005433719150	556FB0	1866 230551	NATALYA MEDVEDEVA	{"email": "n.medvedeva.1971@postgrespro.ru", "phone": "+70371612955"}
0005433719151	999CE4	9193 024603	ALEKSANDR SIDOROV	{"email": "asidorov_031970@postgrespro.ru", "phone": "+70176507194"}
0005433719152	8FCC8D	8422 327425	ALEKSANDR NIKITIN	{"phone": "+70801266876"}
0005433719153	2A88E5	4835 573336	NATALYA ANTONOVA	{"email": "natalya_antonova.24061974@postgrespro.ru", "phone": "+70055558542"}
0005433719154	1AE45D	6202 784149	LYUDMILA VOROBEVA	{"email": "vorobevalyudmila-1967@postgrespro.ru", "phone": "+70142183358"}
0005433719155	880D15	9462 319080	NADEZHDA GUSEVA	{"phone": "+70835052923"}
0005433719156	880D15	1945 450859	MIKHAIL NIKOLAEV	{"email": "mikhail-nikolaev_051963@postgrespro.ru", "phone": "+70176233858"}
0005433719157	08F721	1297 212197	SERGEY SOROKIN	{"phone": "+70872607301"}
0005433719158	08F721	8201 864795	NINA KISELEVA	{"phone": "+70291475470"}
0005433719159	E56755	0881 795217	NATALYA ANTONOVA	{"email": "natalya.antonova-11081987@postgrespro.ru", "phone": "+70393481480"}
0005433719160	E56755	5692 384130	GALINA NAZAROVA	{"email": "g_nazarova-01111972@postgrespro.ru", "phone": "+70161421738"}
0005433719161	EEACBD	4427 170508	ANDREY ORLOV	{"email": "orlov-andrey-1973@postgrespro.ru", "phone": "+70089502209"}
0005433719162	0CD66F	3123 841834	ELENA POPOVA	{"email": "epopova-1971@postgrespro.ru", "phone": "+70234651696"}
0005433719163	C9C3E4	3721 193924	MARIYA BARANOVA	{"phone": "+70440227332"}
0005433719164	7ACE09	7858 808083	LYUBOV SIDOROVA	{"phone": "+70342800850"}
0005433719165	7ACE09	8519 233756	VITALIY MIRONOV	{"email": "vitaliymironov-1984@postgrespro.ru", "phone": "+70111679744"}
0005433719166	068A95	9242 334606	DMITRIY BELOV	{"email": "belov-dmitriy-30091989@postgrespro.ru", "phone": "+70881956404"}
0005433719167	6390E0	2841 913392	RAUF BONDARENKO	{"phone": "+70061168547"}
0005433719168	377982	2703 408460	MARAT EGOROV	{"email": "egorov.m-031968@postgrespro.ru", "phone": "+70593737938"}
0005433719169	AB6AA2	9695 403780	NATALYA IVANOVA	{"email": "natalya_ivanova061972@postgrespro.ru", "phone": "+70284886706"}
0005433719170	D8D3FD	2248 053707	DMITRIY PAVLOV	{"phone": "+70078793067"}
0005433719172	768225	1804 755919	IVAN SOKOLOV	{"email": "i_sokolov.1973@postgrespro.ru", "phone": "+70295157372"}
0005433719173	59D3D7	8896 824391	NIKOLAY ANDREEV	{"phone": "+70879351944"}
0005433719174	59D3D7	2060 721441	MARIYA VOLKOVA	{"email": "volkova_m061977@postgrespro.ru", "phone": "+70223455432"}
0005433719175	59D3D7	0594 495847	ALINA ZAKHAROVA	{"phone": "+70841853946"}
0005433719176	192870	5162 265562	ALEKSEY GERASIMOV	{"email": "aleksey.gerasimov_28121977@postgrespro.ru", "phone": "+70120365164"}
0005433719177	7AC954	7456 081399	ANTONIDA MAKAROVA	{"email": "a-makarova.1965@postgrespro.ru", "phone": "+70839758133"}
0005433719178	7AC954	1684 510223	ALEKSANDR VLASOV	{"email": "a-vlasov.21111967@postgrespro.ru", "phone": "+70990556541"}
0005433719179	FF4E6C	4095 163931	PETR DENISOV	{"email": "denisov-p-25081966@postgrespro.ru", "phone": "+70419880839"}
0005433719180	DA1B57	9417 144579	NIKITA PETROV	{"email": "nikita_petrov101977@postgrespro.ru", "phone": "+70972018729"}
0005433719181	DA1B57	2482 005835	MARINA ALEKSANDROVA	{"email": "aleksandrova-marina.20041975@postgrespro.ru", "phone": "+70597587582"}
0005433719182	4B5136	1340 118493	ELENA POPOVA	{"email": "popovae_1957@postgrespro.ru", "phone": "+70178945483"}
0005433719183	4B5136	3968 026134	TAMARA EFIMOVA	{"phone": "+70502008027"}
0005433719184	298FA6	8282 762459	IVAN STEPANOV	{"email": "stepanovivan_101971@postgrespro.ru", "phone": "+70863645585"}
0005433719185	298FA6	1902 928405	SERGEY KAZAKOV	{"email": "s-kazakov23101977@postgrespro.ru", "phone": "+70434045442"}
0005433719186	31F908	1712 297988	ALEKSEY PAVLOV	{"phone": "+70465763666"}
0005433719187	11E925	3615 465035	FANIYA CHERNOVA	{"email": "fchernova_1976@postgrespro.ru", "phone": "+70937210259"}
0005433719188	CB2DEE	2214 531325	MARIYA ZAKHAROVA	{"email": "m.zakharova23061965@postgrespro.ru", "phone": "+70713357932"}
0005433719189	3DB237	1993 395394	MARIYA DAVYDOVA	{"phone": "+70492113581"}
0005433719190	9631FF	1897 828204	PAVEL CHERNOV	{"email": "p-chernov_011966@postgrespro.ru", "phone": "+70491382719"}
0005433719191	3720FC	6817 586025	NINA MELNIKOVA	{"phone": "+70553407551"}
0005433719192	68D26D	7873 899598	SVETLANA ORLOVA	{"phone": "+70761772021"}
0005433719193	13747F	2343 831408	EKATERINA MIKHAYLOVA	{"phone": "+70819810477"}
0005433719194	B5C58B	2383 656671	RADIK ALEKSANDROV	{"phone": "+70579776890"}
0005433719195	B5C58B	0146 596547	YAROSLAV ZAKHAROV	{"phone": "+70808292561"}
0005433719196	C27EF3	6810 869665	YURIY MOROZOV	{"phone": "+70632799706"}
0005433719197	E2E391	3292 705127	ANDREY SMIRNOV	{"phone": "+70578241483"}
0005433719198	E2E391	6252 048027	VERA ERMAKOVA	{"phone": "+70313180024"}
0005433719199	DD885F	5411 560671	ANNA STEPANOVA	{"phone": "+70442184400"}
0005433719200	DD885F	4783 435405	SVETLANA SERGEEVA	{"phone": "+70102644823"}
0005433719201	E31222	6802 793661	VIKTOR VASILEV	{"phone": "+70752223976"}
0005433719202	E31222	1080 470078	MIKHAIL KUDRYASHOV	{"phone": "+70407691182"}
0005433719203	90A4CF	5030 645799	ALEVTINA SOKOLOVA	{"email": "a-sokolova-031970@postgrespro.ru", "phone": "+70740364005"}
0005433719204	9250DC	6190 828508	ALEKSANDR MEDVEDEV	{"phone": "+70981839533"}
0005433719205	ECF2D9	8245 900887	VALENTINA BORISOVA	{"email": "borisova-v071984@postgrespro.ru", "phone": "+70595356139"}
0005433719206	EBBCC8	7869 110844	LIDIYA GORBUNOVA	{"phone": "+70515935779"}
0005433719207	3415CC	1570 752970	ANDREY KUZNECOV	{"email": "kuznecov.andrey1958@postgrespro.ru", "phone": "+70361853187"}
0005433719208	FC4565	8671 289935	KSENIYA MELNIKOVA	{"phone": "+70863238120"}
0005433719209	BA7362	5778 974915	ILNUR MARTYNOV	{"phone": "+70047645861"}
0005433719210	622229	6711 472039	NIKOLAY IVANOV	{"phone": "+70221360007"}
0005433719211	133989	8690 314957	SERGEY ALEKSEEV	{"phone": "+70446832635"}
0005433719212	502547	4088 812554	ANDREY STEPANOV	{"email": "andrey-stepanov-04101972@postgrespro.ru", "phone": "+70686894239"}
0005433719213	1BAD1C	7551 756528	GALINA MATVEEVA	{"email": "galina_matveeva08041977@postgrespro.ru", "phone": "+70071774776"}
0005433719214	4CED69	6108 463387	EKATERINA SEMENOVA	{"email": "semenova.e.011967@postgrespro.ru", "phone": "+70899021670"}
0005433719215	389B29	7710 698505	MARINA BORISOVA	{"phone": "+70963859780"}
0005433719216	389B29	8193 468368	DENIS ILIN	{"phone": "+70674621132"}
0005433719217	389B29	3775 608303	ALEKSEY SOKOLOV	{"email": "sokolov.a.091989@postgrespro.ru", "phone": "+70079335615"}
0005433719218	E91917	8743 188520	TATYANA GUSEVA	{"email": "guseva-tatyana_1974@postgrespro.ru", "phone": "+70636069816"}
0005433719219	C25109	3888 275585	EKATERINA FILIPPOVA	{"phone": "+70895793461"}
0005433719220	642FE1	1996 295137	GENNADIY SERGEEV	{"phone": "+70686144303"}
0005433719221	18AE82	1719 449764	ARTEM SOKOLOV	{"phone": "+70705737289"}
0005433719222	FE635F	4665 465446	DARYA KUZNECOVA	{"phone": "+70397339434"}
0005433719223	CA7538	6167 576402	VERA KARPOVA	{"phone": "+70417880928"}
0005433719224	E9722E	9103 540684	NADEZHDA SOLOVEVA	{"email": "soloveva.n-061968@postgrespro.ru", "phone": "+70634171678"}
0005433719225	E9722E	4943 375616	SERGEY MELNIKOV	{"email": "sergey-melnikov.091976@postgrespro.ru", "phone": "+70255457269"}
0005433719226	5471C7	0576 580898	VERA MIKHAYLOVA	{"email": "v-mikhaylova-1969@postgrespro.ru", "phone": "+70679317737"}
0005433719227	8E3753	6023 305137	ANTONINA MASLOVA	{"phone": "+70814756137"}
0005433719228	F714D8	5709 442345	GRIGORIY MIRONOV	{"phone": "+70001908549"}
0005433719229	B39122	4371 198327	ALEKSANDRA ROMANOVA	{"email": "romanovaaleksandra_031969@postgrespro.ru", "phone": "+70896218181"}
0005433719230	E9BBC3	2721 784064	TAMARA RODIONOVA	{"email": "tamara.rodionova-30051979@postgrespro.ru", "phone": "+70147254674"}
0005433719231	0205FA	3131 479630	ELENA ROMANOVA	{"phone": "+70047939164"}
0005433719232	E7674E	3092 573635	ANASTASIYA KALININA	{"email": "kalininaanastasiya_101978@postgrespro.ru", "phone": "+70326930158"}
0005433719233	7BD17F	0395 018061	VALERIYA IVANOVA	{"phone": "+70228101619"}
0005433719234	7BD17F	9998 246350	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov-111971@postgrespro.ru", "phone": "+70211719952"}
0005433719235	A02949	0322 244221	MARIYA DANILOVA	{"email": "mariya_danilova-19091973@postgrespro.ru", "phone": "+70208142387"}
0005433719236	43FDC9	0323 293498	MIKHAIL CHERNOV	{"phone": "+70211327697"}
0005433719237	3F7450	7244 574338	TIMUR FEDOROV	{"email": "t.fedorov1977@postgrespro.ru", "phone": "+70363223354"}
0005433719238	3F7450	2816 856943	MARINA ZAKHAROVA	{"email": "zakharova_marina041961@postgrespro.ru", "phone": "+70380483856"}
0005433719239	C07F4F	8233 800507	ANATOLIY GAVRILOV	{"email": "a.gavrilov.1967@postgrespro.ru", "phone": "+70881202593"}
0005433719240	A6AB79	7921 611040	MARINA MOROZOVA	{"phone": "+70327099223"}
0005433719241	5DBC31	9827 533968	GALINA ANISIMOVA	{"email": "anisimova.galina14071976@postgrespro.ru", "phone": "+70963938839"}
0005433719242	655144	6954 323588	VSEVOLOD GORBUNOV	{"email": "vsevolod-gorbunov1980@postgrespro.ru", "phone": "+70832025192"}
0005433722102	067EDB	6085 025605	NIKOLAY MATVEEV	{"phone": "+70932717545"}
0005433722103	EF10B0	0433 851813	ILDAR KOZLOV	{"phone": "+70781764536"}
0005433722104	276650	9595 007845	ALEKSANDR MEDVEDEV	{"phone": "+70528602031"}
0005433722105	4E5F06	9010 146386	ELENA KOZLOVA	{"phone": "+70430496533"}
0005433722106	44D0BD	9269 159176	ANATOLIY MAKAROV	{"phone": "+70968504966"}
0005433722107	D7DEDA	9007 311769	VALENTINA ZHUKOVA	{"phone": "+70122266162"}
0005433722108	A9099C	1050 989563	OLGA EFREMOVA	{"email": "efremovao28031972@postgrespro.ru", "phone": "+70227934720"}
0005433722109	D6863D	3654 616074	YULIYA ALEKSEEVA	{"email": "yuliya-alekseeva.04061983@postgrespro.ru", "phone": "+70345097234"}
0005433722110	D6863D	5211 746336	ELVIRA BELOVA	{"phone": "+70961652430"}
0005433722111	CE306A	2010 820555	TATYANA NIKOLAEVA	{"phone": "+70209883129"}
0005433722112	CE306A	0091 789195	MAKSIM KOZLOV	{"email": "mkozlov_061964@postgrespro.ru", "phone": "+70462949397"}
0005433722113	7D8B9A	4456 846349	ALEKSEY DENISOV	{"phone": "+70368010003"}
0005433722114	7D8B9A	0589 026876	MIKHAIL MAKAROV	{"email": "m-makarov.22021972@postgrespro.ru", "phone": "+70071675369"}
0005433722115	763A57	3825 859031	LYUDMILA KOMAROVA	{"phone": "+70181406387"}
0005433722116	1C8DA1	1218 162089	DENIS KARPOV	{"phone": "+70425179408"}
0005433722117	14C1D5	7370 043818	IRINA MAKAROVA	{"phone": "+70754661984"}
0005433722118	9E6A9C	3316 200883	ELENA OSIPOVA	{"email": "osipova-e041965@postgrespro.ru", "phone": "+70332957754"}
0005433722119	9E6A9C	7945 957323	OLGA MOROZOVA	{"email": "olgamorozova1979@postgrespro.ru", "phone": "+70690094834"}
0005433722120	1665A7	5320 856966	TATYANA ZHURAVLEVA	{"phone": "+70522789027"}
0005433722121	4436C4	7817 099917	INGA NIKIFOROVA	{"email": "inganikiforova-25111981@postgrespro.ru", "phone": "+70649116268"}
0005433722122	670EEB	7478 280395	MARIYA GORBUNOVA	{"email": "mariya.gorbunova.081980@postgrespro.ru", "phone": "+70223435980"}
0005433722123	CF6886	1451 870075	OLESYA YUDINA	{"email": "o.yudina_03121970@postgrespro.ru", "phone": "+70098919867"}
0005433722124	E0491F	6632 334691	ANTON TARASOV	{"email": "antontarasov_051978@postgrespro.ru", "phone": "+70049067622"}
0005433722125	BA6E66	2082 545492	VALENTINA GAVRILOVA	{"email": "valentina.gavrilova-071981@postgrespro.ru", "phone": "+70408382729"}
0005433722126	BA6E66	1541 373164	KSENIYA RODIONOVA	{"email": "kseniyarodionova-041972@postgrespro.ru", "phone": "+70702236034"}
0005433722127	8579C0	7181 313298	NATALYA ANDREEVA	{"email": "andreeva.natalya18091967@postgrespro.ru", "phone": "+70607045823"}
0005433722128	C88058	7834 121792	ELEONORA TIKHONOVA	{"email": "tikhonova.e_10051963@postgrespro.ru", "phone": "+70561718467"}
0005433722129	F704C1	9804 665126	MIKHAIL GUSEV	{"email": "gusev.m.1965@postgrespro.ru", "phone": "+70940601173"}
0005433722130	32A8ED	9496 134404	EVGENIY KOZLOV	{"email": "kozlov-e09061968@postgrespro.ru", "phone": "+70351168741"}
0005433722131	A420C0	0391 395461	MARIYA IVANOVA	{"email": "ivanova_mariya-1962@postgrespro.ru", "phone": "+70415465299"}
0005433722132	0DEFDE	3498 180452	ALEKSANDRA ZHURAVLEVA	{"phone": "+70236103365"}
0005433722133	FE8000	7061 003537	IVAN FOMIN	{"email": "ifomin_101977@postgrespro.ru", "phone": "+70862371639"}
0005433722134	557D7B	2826 663413	NIKOLAY NIKITIN	{"email": "n.nikitin_04091960@postgrespro.ru", "phone": "+70219921230"}
0005433722135	557D7B	1029 310146	OLESYA VASILEVA	{"phone": "+70609757545"}
0005433722136	2C9325	9395 583394	SERGEY ANDREEV	{"email": "sandreev-1981@postgrespro.ru", "phone": "+70594598058"}
0005433722137	38A66D	4857 903021	ANATOLIY ALEKSEEV	{"email": "a-alekseev_15091975@postgrespro.ru", "phone": "+70903697532"}
0005433722138	730448	7361 939824	NIKOLAY POPOV	{"phone": "+70682511433"}
0005433722139	750B0C	0837 911279	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_valentina_24051976@postgrespro.ru", "phone": "+70311509158"}
0005433722309	50786C	2528 149734	YULIYA NOVIKOVA	{"phone": "+70713379839"}
0005433722140	02E2C9	9686 763622	IRINA SERGEEVA	{"email": "irina.sergeeva-031969@postgrespro.ru", "phone": "+70823668510"}
0005433722141	CEF29D	5598 467375	LEONID STEPANOV	{"email": "leonid.stepanov14111979@postgrespro.ru", "phone": "+70921729168"}
0005433722142	561262	0333 097326	VIKTOR ABRAMOV	{"phone": "+70084620547"}
0005433722143	EDDD86	7128 751881	SERGEY DAVYDOV	{"email": "s.davydov-101963@postgrespro.ru", "phone": "+70973125044"}
0005433722144	EDDD86	8461 296428	VYACHESLAV OSIPOV	{"phone": "+70581382361"}
0005433722145	EDDD86	8395 363549	ALENA OSIPOVA	{"phone": "+70426279703"}
0005433722146	A51A64	7701 780690	ALEKSANDR ORLOV	{"phone": "+70202918076"}
0005433722147	2762AE	3165 223538	ELENA KONDRATEVA	{"phone": "+70597598925"}
0005433722148	2762AE	1064 144910	ELIZAVETA MOROZOVA	{"email": "e.morozova-1961@postgrespro.ru", "phone": "+70650108480"}
0005433722149	41B719	6635 547858	NIKOLAY AFANASEV	{"phone": "+70091767502"}
0005433722150	CCB236	6805 751126	NAZAR MIRONOV	{"email": "mironov_n.14101978@postgrespro.ru", "phone": "+70726955248"}
0005433722151	67C9C6	8246 590047	ALEKSANDRA YAKOVLEVA	{"email": "a.yakovleva_111970@postgrespro.ru", "phone": "+70657156463"}
0005433722152	C36DF4	0921 415678	EKATERINA KULIKOVA	{"email": "ekulikova-121978@postgrespro.ru", "phone": "+70732231372"}
0005433722153	C36DF4	6695 302769	OLGA EFIMOVA	{"email": "efimova_o061980@postgrespro.ru", "phone": "+70926855973"}
0005433722154	5061B2	1086 199867	OKSANA ROMANOVA	{"email": "romanova_oksana.1971@postgrespro.ru", "phone": "+70223326099"}
0005433722155	3DE837	2085 680353	PAVEL ZAYCEV	{"phone": "+70012022584"}
0005433722156	7539A9	5779 871851	YULIYA NOVIKOVA	{"phone": "+70862343848"}
0005433722157	7539A9	8755 227327	VALERIY MAKSIMOV	{"phone": "+70093272238"}
0005433722158	478C38	7795 037259	LIDIYA ZAYCEVA	{"email": "l.zayceva-071981@postgrespro.ru", "phone": "+70823230338"}
0005433722159	478C38	9867 213298	YURIY PETROV	{"email": "y.petrov-1976@postgrespro.ru", "phone": "+70887844601"}
0005433722160	8E04E5	1538 009331	NIKOLAY MAKAROV	{"phone": "+70026797426"}
0005433722161	8E04E5	0662 117244	LIDIYA IVANOVA	{"phone": "+70617097697"}
0005433722162	FEDA92	2281 712082	NIKOLAY VOROBEV	{"phone": "+70037571025"}
0005433722163	3DDAB1	4841 902528	VASILIY ZHUKOV	{"email": "vasiliyzhukov_09061973@postgrespro.ru", "phone": "+70586467434"}
0005433722164	54B03B	5057 114333	ANDREY DENISOV	{"phone": "+70437484823"}
0005433722165	54B03B	2539 579486	TATYANA PAVLOVA	{"phone": "+70792274287"}
0005433722166	CD1639	6767 472077	OLGA ARKHIPOVA	{"phone": "+70779421839"}
0005433722167	EEEAEB	4671 307575	TAMARA KUZMINA	{"phone": "+70807084619"}
0005433722168	FB9422	8819 299389	NADEZHDA MOROZOVA	{"phone": "+70455965728"}
0005433722169	49184F	7656 100277	KLAVDIYA GUSEVA	{"email": "guseva_k-091974@postgrespro.ru", "phone": "+70822521964"}
0005433722170	05D8DB	1930 528362	VALERIY KUZNECOV	{"email": "valeriy_kuznecov011973@postgrespro.ru", "phone": "+70432318585"}
0005433722171	69A4BC	9946 259855	NIKOLAY FOMIN	{"email": "fominnikolay1965@postgrespro.ru", "phone": "+70822503789"}
0005433722172	69A4BC	1787 118836	EVGENIYA LAZAREVA	{"phone": "+70851232359"}
0005433722173	B7AB12	3904 861563	TATYANA GERASIMOVA	{"email": "tgerasimova19081983@postgrespro.ru", "phone": "+70018973289"}
0005433722174	B7AB12	0977 670709	LINAR YAKOVLEV	{"email": "yakovlev_linar-1965@postgrespro.ru", "phone": "+70480019628"}
0005433722175	2144A0	8108 383547	NIKOLAY POPOV	{"email": "n.popov.31121976@postgrespro.ru", "phone": "+70996756077"}
0005433722176	2144A0	3667 690610	DARYA ZAKHAROVA	{"email": "zakharova_darya.19021982@postgrespro.ru", "phone": "+70375498254"}
0005433722177	6032EF	2069 473289	ALSU LOGINOVA	{"email": "loginovaalsu_091969@postgrespro.ru", "phone": "+70295677882"}
0005433722178	ECC7BE	2835 855214	DARYA ISAEVA	{"email": "isaevad_10031971@postgrespro.ru", "phone": "+70912801827"}
0005433722179	893B47	6352 654687	DMITRIY KOROLEV	{"phone": "+70358217406"}
0005433722180	893B47	0677 957673	KIRILL PAVLOV	{"phone": "+70683566063"}
0005433722181	893B47	9022 337121	MARIYA KARPOVA	{"email": "karpova_mariya_101970@postgrespro.ru", "phone": "+70586964405"}
0005433722182	A7BA6B	5673 843673	ALENA FILIPPOVA	{"email": "filippova-alena.06021980@postgrespro.ru", "phone": "+70064454947"}
0005433722183	675FAC	0780 856089	OLEG TARASOV	{"phone": "+70959161096"}
0005433722184	859244	7658 031720	ELENA KUZNECOVA	{"phone": "+70684404131"}
0005433722185	859244	4675 558853	NATALYA KUZNECOVA	{"email": "kuznecova.n081972@postgrespro.ru", "phone": "+70621735956"}
0005433722186	4BAEAD	0061 425079	ELENA MIRONOVA	{"phone": "+70264430962"}
0005433722187	E8D07D	2370 438283	ALEKSEY SHEVCHENKO	{"phone": "+70399584335"}
0005433722188	A801D4	3823 963207	NIKOLAY FEDOROV	{"email": "fedorov_nikolay-16101959@postgrespro.ru", "phone": "+70545973405"}
0005433722189	A801D4	2845 252319	ANASTASIYA BOGDANOVA	{"email": "bogdanova.a1965@postgrespro.ru", "phone": "+70443843959"}
0005433722190	2FE8BF	0788 148950	VALENTINA DAVYDOVA	{"email": "davydova.valentina_1962@postgrespro.ru", "phone": "+70763000198"}
0005433722191	206B1F	4937 316363	VLADIMIR ZHUKOV	{"email": "vladimir-zhukov_1964@postgrespro.ru", "phone": "+70031872175"}
0005433722192	009C80	8708 852273	SERGEY GAVRILOV	{"email": "s.gavrilov071971@postgrespro.ru", "phone": "+70821678061"}
0005433722193	009C80	5468 587399	ALEKSANDR TIMOFEEV	{"phone": "+70331545134"}
0005433722194	C0C458	2920 699023	VALERIY ZHURAVLEV	{"email": "v.zhuravlev-111983@postgrespro.ru", "phone": "+70822043352"}
0005433722195	CCFD99	1211 248715	ANDREY MEDVEDEV	{"email": "a_medvedev081976@postgrespro.ru", "phone": "+70215105940"}
0005433722196	4867F5	8700 244399	SERGEY ISAEV	{"email": "sergey_isaev05081977@postgrespro.ru", "phone": "+70181706253"}
0005433722197	1DCBB7	5506 175606	VLADIMIR SOLOVEV	{"phone": "+70059841761"}
0005433722198	1DCBB7	5549 619004	OLGA LEBEDEVA	{"email": "o.lebedeva_041970@postgrespro.ru", "phone": "+70635933938"}
0005433722199	B71740	6774 411151	OLEG KISELEV	{"phone": "+70502441531"}
0005433722200	AE683A	8957 101874	STANISLAV KONOVALOV	{"email": "stanislav.konovalov.061979@postgrespro.ru", "phone": "+70503045610"}
0005433722201	7283CA	7435 348891	OLEG VOROBEV	{"phone": "+70105443356"}
0005433722202	7283CA	5943 876859	DMITRIY MIRONOV	{"phone": "+70202613874"}
0005433722203	2B1E22	0610 103533	VLADIMIR SOKOLOV	{"phone": "+70512652389"}
0005433722204	502A12	1576 941632	ILDAR FEDOROV	{"phone": "+70191502950"}
0005433722205	502A12	9779 819776	IGOR VOLKOV	{"email": "volkov-i-22041965@postgrespro.ru", "phone": "+70225260974"}
0005433722206	E7FD24	8969 236555	OLEG NIKITIN	{"email": "o-nikitin-24121985@postgrespro.ru", "phone": "+70276140143"}
0005433722207	E42786	8918 167029	ELIZAVETA KISELEVA	{"phone": "+70183972729"}
0005433722208	E42786	9971 006393	GRIGORIY SOKOLOV	{"phone": "+70313586675"}
0005433722209	3D81C5	9545 778678	EKATERINA YAKOVLEVA	{"phone": "+70960160443"}
0005433722210	15D1C7	6568 988730	VLADIMIR KONOVALOV	{"email": "vladimir.konovalov_041963@postgrespro.ru", "phone": "+70099925784"}
0005433722211	2C7D73	2593 891283	ANASTASIYA SMIRNOVA	{"email": "smirnova.a_021978@postgrespro.ru", "phone": "+70377298749"}
0005433722212	2C7D73	7758 132325	SERGEY KOZLOV	{"email": "sergeykozlov.1970@postgrespro.ru", "phone": "+70974815901"}
0005433722213	3CAA57	3020 095682	VERA CHERNOVA	{"phone": "+70836621264"}
0005433722214	3CAA57	8679 807765	MARIYA LOGINOVA	{"email": "loginova_m-071974@postgrespro.ru", "phone": "+70025560612"}
0005433722215	27639D	3193 793050	YULIYA ERMAKOVA	{"email": "yermakova_1966@postgrespro.ru", "phone": "+70224728167"}
0005433722216	27639D	9346 594856	DMITRIY ZHURAVLEV	{"phone": "+70064852795"}
0005433722217	451C40	0978 394472	ANTON MOROZOV	{"email": "a_morozov-1961@postgrespro.ru", "phone": "+70362305821"}
0005433722218	F210D6	1667 674200	NADEZHDA MASLOVA	{"email": "maslova-nadezhda1977@postgrespro.ru", "phone": "+70160096240"}
0005433722219	F210D6	1385 396721	YURIY POPOV	{"email": "ypopov_16111961@postgrespro.ru", "phone": "+70298528097"}
0005433722220	F210D6	6191 359009	ELENA ALEKSEEVA	{"email": "elenaalekseeva041977@postgrespro.ru", "phone": "+70190505809"}
0005433722221	CC18F1	6451 674115	ANATOLIY EGOROV	{"phone": "+70536901925"}
0005433722222	A51CE2	5012 584401	ANASTASIYA MAKAROVA	{"phone": "+70224468118"}
0005433722447	A9296D	9307 138425	SERGEY ZAKHAROV	{"phone": "+70387686543"}
0005433722223	A51CE2	7457 828145	DANIIL BONDARENKO	{"email": "d_bondarenko_09111965@postgrespro.ru", "phone": "+70434111634"}
0005433722224	3D23A2	5904 594084	ANDREY KULIKOV	{"email": "kulikov-a.22051972@postgrespro.ru", "phone": "+70561045049"}
0005433722225	225734	2380 504737	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov.041969@postgrespro.ru", "phone": "+70751926491"}
0005433722226	A96E85	7305 869229	VLADIMIR FROLOV	{"phone": "+70273648474"}
0005433722227	421A71	0537 863367	KSENIYA ORLOVA	{"phone": "+70038232381"}
0005433722228	9A3FC6	8331 614435	ALEKSANDRA DENISOVA	{"email": "aleksandra.denisova_15101974@postgrespro.ru", "phone": "+70878063398"}
0005433722229	51AE73	0391 929125	EVDOKIYA PAVLOVA	{"email": "pavlova.evdokiya-1970@postgrespro.ru", "phone": "+70633804799"}
0005433722230	45F9A7	0190 253571	ELENA TIKHONOVA	{"phone": "+70307577555"}
0005433722231	45F9A7	2061 786141	NADEZHDA KOVALEVA	{"phone": "+70331718388"}
0005433722232	08CA5E	4089 558614	GALIYA KUZNECOVA	{"phone": "+70323147501"}
0005433722233	08CA5E	6115 001126	OLEG KAZAKOV	{"phone": "+70373643715"}
0005433722234	EF0DAF	2338 815994	VALENTINA ILINA	{"email": "valentina-ilina081970@postgrespro.ru", "phone": "+70579535419"}
0005433722235	EF0DAF	7777 298571	YURIY DENISOV	{"email": "denisov_yuriy_051971@postgrespro.ru", "phone": "+70941001178"}
0005433722236	EF0DAF	9032 247309	GULNARA FADEEVA	{"phone": "+70232755246"}
0005433722237	318A58	9405 136549	VLADIMIR NAZAROV	{"phone": "+70255868759"}
0005433722238	318A58	2858 125120	ALENA KONOVALOVA	{"email": "alenakonovalova28011969@postgrespro.ru", "phone": "+70642929920"}
0005433722239	AE2A74	9369 887211	ELENA CHERNOVA	{"phone": "+70962293373"}
0005433722240	E62879	3519 852436	IGOR GUSEV	{"email": "gusev_igor_1976@postgrespro.ru", "phone": "+70686992674"}
0005433722241	E62879	2460 138865	NADEZHDA POPOVA	{"phone": "+70104285023"}
0005433722242	049AF3	1273 204853	VLADIMIR IVANOV	{"email": "ivanov-vladimir1966@postgrespro.ru", "phone": "+70581398170"}
0005433722243	C508CC	5631 492965	VIKTORIYA KUDRYASHOVA	{"phone": "+70243078979"}
0005433722244	C508CC	2041 665088	MIKHAIL SCHERBAKOV	{"phone": "+70530190833"}
0005433722245	0345CA	3033 100171	OLGA NIKOLAEVA	{"email": "onikolaeva-101978@postgrespro.ru", "phone": "+70858508854"}
0005433722246	5A44D3	4420 675383	SVETLANA SOLOVEVA	{"email": "ssoloveva121972@postgrespro.ru", "phone": "+70017408581"}
0005433722247	5D6E31	1723 352365	NIKOLAY KUDRYASHOV	{"email": "n.kudryashov.1965@postgrespro.ru", "phone": "+70517896871"}
0005433722248	5D6E31	7317 469370	MIKHAIL SCHERBAKOV	{"email": "scherbakov-mikhail_20091973@postgrespro.ru", "phone": "+70508766250"}
0005433722249	1E244B	3619 703160	EVGENIY ROMANOV	{"phone": "+70530558951"}
0005433722250	D6AD93	9722 968920	LYUDMILA POPOVA	{"email": "popova.lyudmila-09071971@postgrespro.ru", "phone": "+70207420765"}
0005433722251	BA88DE	2567 751592	TATYANA KUZMINA	{"phone": "+70175084227"}
0005433722252	0DDEA6	1808 021275	ALEKSEY FROLOV	{"email": "aleksey.frolov071972@postgrespro.ru", "phone": "+70098842055"}
0005433722253	2FC1C3	1442 221452	TATYANA MAKAROVA	{"phone": "+70464561360"}
0005433722254	4D6DA0	1513 354061	KSENIYA IVANOVA	{"phone": "+70330620941"}
0005433722255	4D6DA0	5218 169471	VALENTINA AFANASEVA	{"phone": "+70152163443"}
0005433722256	4D6DA0	1513 082505	MARIYA POPOVA	{"phone": "+70587272983"}
0005433722257	81A488	0070 575727	NINA SERGEEVA	{"email": "sergeeva_n.18111980@postgrespro.ru", "phone": "+70426082400"}
0005433722258	81A488	5060 057900	ALEKSEY MOISEEV	{"email": "a_moiseev09111973@postgrespro.ru", "phone": "+70924005482"}
0005433722259	1C82B9	1387 707845	DARYA BELOVA	{"phone": "+70706814827"}
0005433722260	957FFE	6635 313541	IRINA KOZLOVA	{"phone": "+70568607513"}
0005433722261	F9A47C	9433 660752	GENNADIY MAKSIMOV	{"email": "gmaksimov1964@postgrespro.ru", "phone": "+70946516531"}
0005433722262	F9A47C	1898 794599	TATYANA KOVALEVA	{"phone": "+70758030801"}
0005433722263	4C6809	9185 873456	GALINA NIKITINA	{"email": "nikitina-galina-1973@postgrespro.ru", "phone": "+70903498399"}
0005433722264	4C6809	9694 347712	NATALYA SIDOROVA	{"phone": "+70856117897"}
0005433722265	D4757E	2587 218836	TAMARA MAKAROVA	{"email": "t.makarova03021968@postgrespro.ru", "phone": "+70872634263"}
0005433722266	3BA37A	2610 613581	LIDIYA MIRONOVA	{"email": "mironova_lidiya_011970@postgrespro.ru", "phone": "+70063468240"}
0005433722267	3BA37A	9593 133609	EVGENIY ANDREEV	{"phone": "+70228000371"}
0005433722268	511030	2423 896990	DANILA GERASIMOV	{"email": "gerasimov_d021966@postgrespro.ru", "phone": "+70669076643"}
0005433722269	86AA24	1982 803588	LIDIYA ABRAMOVA	{"phone": "+70839560730"}
0005433722270	158C70	5542 626582	ELENA KOLESNIKOVA	{"phone": "+70039835923"}
0005433722271	7EF38F	8802 822194	ALEKSEY VOLKOV	{"email": "volkov-a.1973@postgrespro.ru", "phone": "+70516019788"}
0005433722272	60D627	2758 233967	ALEKSANDR VOLKOV	{"email": "a_volkov-28061967@postgrespro.ru", "phone": "+70609558937"}
0005433722273	BF05EA	1843 703308	TAMARA YUDINA	{"phone": "+70180569207"}
0005433722274	ED329E	2550 747002	VITALIY IVANOV	{"phone": "+70511866437"}
0005433722275	ED329E	8471 345800	MARINA IVANOVA	{"email": "m.ivanova13121984@postgrespro.ru", "phone": "+70401070125"}
0005433722276	046023	0405 376056	TATYANA VOLKOVA	{"email": "volkova_tatyana071971@postgrespro.ru", "phone": "+70472207658"}
0005433722277	669C0B	0035 740489	SEMEN PETROV	{"phone": "+70894632819"}
0005433722278	669C0B	1489 830084	MAKSIM KARPOV	{"email": "mkarpov_24041964@postgrespro.ru", "phone": "+70691275042"}
0005433722279	35D604	3100 729654	RAISA RODIONOVA	{"email": "rodionova.r_071977@postgrespro.ru", "phone": "+70831098985"}
0005433722280	57EA57	0665 016602	SERGEY VLASOV	{"phone": "+70719206486"}
0005433722281	C151B8	5737 726450	VADIM SERGEEV	{"phone": "+70958605029"}
0005433722282	2E84E3	3886 481681	VITALIY SOROKIN	{"phone": "+70652194574"}
0005433722283	2E84E3	6269 490350	LILIYA FEDOROVA	{"email": "fedorova_liliya18071981@postgrespro.ru", "phone": "+70458145533"}
0005433722284	ED2625	2291 154628	YULIYA IVANOVA	{"email": "y_ivanova101974@postgrespro.ru", "phone": "+70653207213"}
0005433722285	93AFA2	1734 657419	YURIY KUZMIN	{"email": "kuzmin_yuriy1968@postgrespro.ru", "phone": "+70581160577"}
0005433722286	B60220	5664 325420	TATYANA TIKHONOVA	{"email": "tikhonova_t_101973@postgrespro.ru", "phone": "+70351982288"}
0005433722287	B60220	7688 376038	LYUBOV POTAPOVA	{"phone": "+70235297352"}
0005433722288	B2C151	3526 064791	DARYA SOROKINA	{"phone": "+70032293136"}
0005433722289	CD64A5	5227 493155	MARINA MOROZOVA	{"phone": "+70044405843"}
0005433722290	CD64A5	0524 606089	PAVEL ZAYCEV	{"email": "zaycevp_1978@postgrespro.ru", "phone": "+70835198859"}
0005433722291	ED8A8C	4305 646246	ELEONORA KOMAROVA	{"email": "ekomarova-1984@postgrespro.ru", "phone": "+70247820629"}
0005433722292	5EE21E	9210 550559	OLGA GAVRILOVA	{"phone": "+70659244622"}
0005433722293	DABB84	3051 342677	LIDIYA VLASOVA	{"email": "vlasovalidiya1973@postgrespro.ru", "phone": "+70333605328"}
0005433722294	B35DCE	9833 634260	VADIM SOROKIN	{"phone": "+70494782608"}
0005433722295	B35DCE	4620 126545	ANTONINA ZAKHAROVA	{"phone": "+70747065986"}
0005433722296	DE7C74	3421 521048	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko-081965@postgrespro.ru", "phone": "+70572429933"}
0005433722297	DE7C74	1642 808907	ANDREY YAKOVLEV	{"email": "yakovlev.a_111975@postgrespro.ru", "phone": "+70104283444"}
0005433722298	7C1394	6423 619822	OLGA FILATOVA	{"email": "filatova_olga-16091967@postgrespro.ru", "phone": "+70431790150"}
0005433722299	7C1394	7915 466579	OLEG MIRONOV	{"email": "oleg_mironov-1964@postgrespro.ru", "phone": "+70304462588"}
0005433722300	E9A4DD	0327 817292	NINA PAVLOVA	{"email": "pavlova.nina.011973@postgrespro.ru", "phone": "+70178994632"}
0005433722301	CAA61C	4349 029290	EDUARD IVANOV	{"email": "e.ivanov.071977@postgrespro.ru", "phone": "+70233748174"}
0005433722302	9E5E80	4193 936623	NATALIYA YAKOVLEVA	{"phone": "+70903328250"}
0005433722303	394E83	6599 061473	ELENA SOROKINA	{"email": "sorokina-e1971@postgrespro.ru", "phone": "+70077507351"}
0005433722304	B4D7A5	7163 069926	IBRAGIM PAVLOV	{"phone": "+70735276581"}
0005433722305	02AC8A	8722 868927	ALEKSANDR IVANOV	{"phone": "+70283251802"}
0005433722306	A29F64	4397 142442	GALINA MELNIKOVA	{"phone": "+70956292209"}
0005433722307	DF39EB	6345 649416	EKATERINA ZOTOVA	{"phone": "+70932309167"}
0005433722308	DF39EB	5247 389184	YURIY GERASIMOV	{"phone": "+70517486910"}
0005433722310	8A6431	7890 320880	ALEKSEY NOVIKOV	{"email": "a-novikov011970@postgrespro.ru", "phone": "+70686647192"}
0005433722311	8A6431	5290 882349	MARINA YAKOVLEVA	{"email": "marina_yakovleva-12071974@postgrespro.ru", "phone": "+70732636107"}
0005433722312	E2933E	4130 153706	GLEB NIKOLAEV	{"phone": "+70367300256"}
0005433722313	5212E3	1770 764389	TATYANA MAKSIMOVA	{"email": "maksimova-t061969@postgrespro.ru", "phone": "+70504991035"}
0005433722314	0F5E05	7646 718696	ELENA KOROLEVA	{"email": "korolevae021985@postgrespro.ru", "phone": "+70566316734"}
0005433722315	3EA185	2605 326244	ANATOLIY SOKOLOV	{"email": "sokolov.anatoliy_1979@postgrespro.ru", "phone": "+70295769854"}
0005433722316	FEC516	4558 813004	SERGEY ZAKHAROV	{"phone": "+70044474156"}
0005433722317	258A71	1357 744140	NATALYA LUKYANOVA	{"phone": "+70947331263"}
0005433722318	258A71	8756 634596	ALEKSANDR MIRONOV	{"phone": "+70345633322"}
0005433722319	037712	6465 830543	NIKOLAY SAVELEV	{"email": "savelev_n31071972@postgrespro.ru", "phone": "+70377145489"}
0005433722320	037712	6725 319589	MARGARITA FEDOROVA	{"email": "fedorova-m1972@postgrespro.ru", "phone": "+70607405370"}
0005433722321	86903A	2665 462863	VALERIY NOVIKOV	{"phone": "+70817495010"}
0005433722322	468C87	1027 768873	DMITRIY KISELEV	{"phone": "+70295992348"}
0005433722323	468C87	3640 277923	ANASTASIYA BORISOVA	{"phone": "+70084467380"}
0005433722324	16C710	2266 067851	TAMARA OSIPOVA	{"email": "osipova-tamara.26071973@postgrespro.ru", "phone": "+70800982853"}
0005433722325	00BAB4	7954 243792	NATALIYA KAZAKOVA	{"phone": "+70798890817"}
0005433722326	43AD02	7054 354129	SERGEY NIKITIN	{"phone": "+70105220906"}
0005433722327	CCDE76	0852 300071	IVAN AFANASEV	{"email": "i_afanasev_1983@postgrespro.ru", "phone": "+70462159211"}
0005433722328	72AC94	0259 434592	NADEZHDA BORISOVA	{"email": "borisovanadezhda.1980@postgrespro.ru", "phone": "+70699256161"}
0005433722329	72AC94	1423 357502	ADELINA POPOVA	{"email": "popova_a_1978@postgrespro.ru", "phone": "+70274749116"}
0005433722330	ADDE5F	9283 776352	FAINA TROFIMOVA	{"phone": "+70757286025"}
0005433722389	BC85F6	8547 034328	TATYANA DANILOVA	{"phone": "+70761001049"}
0005433722331	DF951E	2572 645324	SALAVAT ANDREEV	{"email": "salavat-andreev-101969@postgrespro.ru", "phone": "+70591257629"}
0005433722332	6671AF	5444 848646	ANNA IVANOVA	{"email": "anna-ivanova.02111962@postgrespro.ru", "phone": "+70791526660"}
0005433722333	D1F648	3294 778251	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov.20111968@postgrespro.ru", "phone": "+70523790217"}
0005433722334	5AA909	1338 846517	NADEZHDA IVANOVA	{"phone": "+70302223645"}
0005433722335	13AE86	0564 826275	ARTEM MAKAROV	{"phone": "+70043189819"}
0005433722336	13AE86	0874 447001	MARIYA FILATOVA	{"email": "m.filatova_051965@postgrespro.ru", "phone": "+70500561032"}
0005433722337	BD6545	2460 050793	SVETLANA PAVLOVA	{"phone": "+70380380179"}
0005433722338	BD6545	2697 178368	VLADISLAV KUZNECOV	{"email": "kuznecov.vladislav.1969@postgrespro.ru", "phone": "+70694318302"}
0005433722339	BD6545	5676 191597	SERGEY SERGEEV	{"email": "sergeev_s-1965@postgrespro.ru", "phone": "+70883950683"}
0005433722340	C2B8C0	3849 911542	SVYATOSLAV KUZNECOV	{"phone": "+70647195584"}
0005433722341	D127A2	6476 506259	YURIY EGOROV	{"phone": "+70716959349"}
0005433722342	CE9075	1520 164013	VLADIMIR ROMANOV	{"email": "vladimir_romanov_011975@postgrespro.ru", "phone": "+70011971354"}
0005433722343	F1D3DA	3546 810721	TATYANA YUDINA	{"email": "yudina.tatyana-1977@postgrespro.ru", "phone": "+70223888287"}
0005433722344	F1D3DA	1605 838630	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_031973@postgrespro.ru", "phone": "+70971486552"}
0005433722345	3026C8	7338 324590	MARIYA POPOVA	{"email": "popovamariya23101968@postgrespro.ru", "phone": "+70459574658"}
0005433722346	3026C8	8473 108942	NIKOLAY MOROZOV	{"email": "morozov.nikolay.14041971@postgrespro.ru", "phone": "+70946483342"}
0005433722347	D0F115	3047 572671	RUSLAN TIKHONOV	{"email": "ruslan.tikhonov03111977@postgrespro.ru", "phone": "+70835661565"}
0005433722348	33E0EE	5150 362294	ALEKSEY MAKAROV	{"email": "makarov_aleksey_1965@postgrespro.ru", "phone": "+70516545067"}
0005433722349	8E8ECF	4252 115093	MARIYA FILATOVA	{"email": "mariya-filatova-14051965@postgrespro.ru", "phone": "+70003776124"}
0005433722350	9CA187	9752 265275	DENIS KUDRYASHOV	{"phone": "+70948787252"}
0005433722351	D4BD31	4321 592962	GRIGORIY VASILEV	{"phone": "+70462545643"}
0005433722352	AA548D	1234 748313	TATYANA FEDOROVA	{"email": "tatyana-fedorova-041969@postgrespro.ru", "phone": "+70307793964"}
0005433722353	1D013F	2363 844950	VADIM RODIONOV	{"phone": "+70096134912"}
0005433722354	1EB12E	9233 576755	VIKTOR POPOV	{"email": "vpopov_1961@postgrespro.ru", "phone": "+70203164314"}
0005433722355	5CEA1A	9863 377273	NADEZHDA KISELEVA	{"phone": "+70145449353"}
0005433722356	602B58	2750 530442	DMITRIY IVANOV	{"phone": "+70608397921"}
0005433722357	4DEEC3	5845 106187	LYUDMILA VOLKOVA	{"email": "volkova.l-22111983@postgrespro.ru", "phone": "+70928794402"}
0005433722358	351053	5309 873831	IGOR ALEKSANDROV	{"email": "i.aleksandrov121986@postgrespro.ru", "phone": "+70170012178"}
0005433722359	351053	7472 462768	EVGENIYA VASILEVA	{"email": "vasileva_evgeniya.1961@postgrespro.ru", "phone": "+70871084979"}
0005433722360	351053	0747 856583	ASIYA OVCHINNIKOVA	{"phone": "+70321948030"}
0005433722361	BEAD3F	4082 663587	ROMAN ZHUKOV	{"email": "roman.zhukov_061965@postgrespro.ru", "phone": "+70560751124"}
0005433722362	BEAD3F	6645 779958	ANDREY POPOV	{"phone": "+70538296949"}
0005433722363	979B81	3083 665680	NATALYA KUZNECOVA	{"phone": "+70115223289"}
0005433722364	979B81	4320 412793	SERGEY PETROV	{"email": "petrov_sergey_111964@postgrespro.ru", "phone": "+70041032628"}
0005433722365	5553A5	8441 315891	EVGENIYA MOROZOVA	{"email": "morozova.evgeniya1975@postgrespro.ru", "phone": "+70269257650"}
0005433722366	5553A5	4640 646555	VALENTINA KOROLEVA	{"phone": "+70217916394"}
0005433722367	462F54	4669 203594	VIKTORIYA TARASOVA	{"phone": "+70787272044"}
0005433722368	462F54	9705 317590	ANDREY VASILEV	{"email": "vasileva_011981@postgrespro.ru", "phone": "+70218401743"}
0005433722369	462F54	7455 765985	ALLA DENISOVA	{"email": "alla.denisova_17051976@postgrespro.ru", "phone": "+70855615646"}
0005433722370	A1FDD7	1848 389714	GALINA DENISOVA	{"email": "galina.denisova.1980@postgrespro.ru", "phone": "+70831474876"}
0005433722371	9D2B0E	0024 553626	MARIYA ZHURAVLEVA	{"phone": "+70783315595"}
0005433722372	845BA7	6863 322982	VLADIMIR SOLOVEV	{"email": "v_solovev1974@postgrespro.ru", "phone": "+70788208977"}
0005433722373	845BA7	8345 448751	ARINA ILINA	{"phone": "+70221155570"}
0005433722374	5A70B5	1592 136865	ARINA KOZLOVA	{"email": "kozlova.a1971@postgrespro.ru", "phone": "+70586824676"}
0005433722375	181469	7566 390195	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev_02111974@postgrespro.ru", "phone": "+70297784115"}
0005433722376	181469	8674 246215	SVETLANA NESTEROVA	{"phone": "+70082824052"}
0005433722377	D84C5F	0595 323705	GALINA FOMINA	{"email": "fomina.galina.021980@postgrespro.ru", "phone": "+70575956974"}
0005433722378	6AE557	7430 985424	ROMAN FROLOV	{"phone": "+70688534024"}
0005433722379	6AE557	7671 591385	VLADIMIR KULIKOV	{"phone": "+70251403963"}
0005433722380	B235B7	1116 342429	ZINAIDA MIRONOVA	{"email": "z_mironova-03021971@postgrespro.ru", "phone": "+70977921679"}
0005433722381	D79AB9	4922 992515	KONSTANTIN ANTONOV	{"phone": "+70150706978"}
0005433722382	D79AB9	0065 169290	MARIYA ZAKHAROVA	{"phone": "+70796822063"}
0005433722383	BC1CB5	0465 583442	DMITRIY CHERNOV	{"email": "chernov.dmitriy-03021971@postgrespro.ru", "phone": "+70817316117"}
0005433722384	255F9F	7959 069244	OLGA DENISOVA	{"email": "o.denisova_18081963@postgrespro.ru", "phone": "+70066361408"}
0005433722385	52918F	4800 699406	YULIYA SMIRNOVA	{"email": "y.smirnova-08081971@postgrespro.ru", "phone": "+70651959240"}
0005433722386	52918F	2161 880455	TATYANA NAUMOVA	{"email": "tatyana_naumova.1970@postgrespro.ru", "phone": "+70667943687"}
0005433722387	52918F	6259 874945	ALEKSANDR KUZNECOV	{"email": "a.kuznecov_1970@postgrespro.ru", "phone": "+70094387691"}
0005433722388	EF8D67	4260 246875	VLADIMIR MEDVEDEV	{"phone": "+70349699476"}
0005433722390	BC85F6	1841 306808	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov28121976@postgrespro.ru", "phone": "+70047461443"}
0005433722391	60C4D0	0001 021206	OLEG BORISOV	{"email": "olegborisov14041976@postgrespro.ru", "phone": "+70656979340"}
0005433722392	60C4D0	1880 526460	NINA MAKSIMOVA	{"email": "n_maksimova.29041975@postgrespro.ru", "phone": "+70345231290"}
0005433722393	07ED5D	9807 312894	ALEKSANDR IVANOV	{"phone": "+70638943862"}
0005433722394	07ED5D	4579 078550	MARIYA IVANOVA	{"email": "m_ivanova1967@postgrespro.ru", "phone": "+70639164825"}
0005433722395	07ED5D	5035 482425	NADEZHDA ALEKSEEVA	{"phone": "+70523789265"}
0005433722396	5E7F1C	8174 400129	ANNA ZHURAVLEVA	{"email": "zhuravlevaa_121965@postgrespro.ru", "phone": "+70416941433"}
0005433722397	5702D9	6981 503836	SERGEY ILIN	{"phone": "+70286968578"}
0005433722398	4BCA16	9723 859760	SERGEY SOROKIN	{"phone": "+70532088270"}
0005433722399	4BCA16	5357 152865	EVELINA NIKITINA	{"email": "evelina_nikitina121980@postgrespro.ru", "phone": "+70747538037"}
0005433722400	000AB3	8424 028768	LYUDMILA NIKOLAEVA	{"email": "nikolaeva-lyudmila_19091980@postgrespro.ru", "phone": "+70518553750"}
0005433722401	649B34	3000 910897	RUDOLF NOVIKOV	{"email": "novikov-rudolf_1965@postgrespro.ru", "phone": "+70377502459"}
0005433722402	8A2482	3265 490608	MIKHAIL MAKSIMOV	{"phone": "+70822812289"}
0005433722403	C43A78	9662 029295	VYACHESLAV IVANOV	{"phone": "+70480046124"}
0005433722404	875D4C	9469 887558	GALINA KONOVALOVA	{"email": "galinakonovalova061980@postgrespro.ru", "phone": "+70573515124"}
0005433722405	A6D5C5	0175 820105	ELIZAVETA SERGEEVA	{"phone": "+70860583973"}
0005433722406	A6D5C5	6617 040532	TATYANA ABRAMOVA	{"email": "abramova-tatyana.111980@postgrespro.ru", "phone": "+70746598489"}
0005433722407	5B044B	9560 502510	ALEKSANDR KOZLOV	{"phone": "+70851949444"}
0005433722408	75F54C	4997 100390	KSENIYA SMIRNOVA	{"phone": "+70445140913"}
0005433722409	1E09A5	4034 550797	NATALIYA KOMAROVA	{"phone": "+70196619637"}
0005433722410	879BB8	5935 894780	VADIM ORLOV	{"email": "orlov.vadim-30011982@postgrespro.ru", "phone": "+70830837965"}
0005433722411	B062C6	4254 542326	GALINA ZHUKOVA	{"email": "zhukova_g.1975@postgrespro.ru", "phone": "+70538582899"}
0005433722412	130C1C	3048 307745	ALEKSANDR ALEKSANDROV	{"phone": "+70258652594"}
0005433722413	BDBF37	5332 893639	VYACHESLAV IVANOV	{"email": "v-ivanov111980@postgrespro.ru", "phone": "+70837261538"}
0005433722414	43E018	2840 464868	LARISA ROMANOVA	{"email": "romanova.l-1962@postgrespro.ru", "phone": "+70813639036"}
0005433722415	5B3EC7	7253 012752	NINA IVANOVA	{"phone": "+70472898142"}
0005433722416	25F68B	4446 319930	RUSLAN KONOVALOV	{"phone": "+70031009888"}
0005433722417	25F68B	3252 105525	IVAN NIKITIN	{"email": "i.nikitin.1966@postgrespro.ru", "phone": "+70967749343"}
0005433722418	25F68B	8268 189582	OLGA ABRAMOVA	{"phone": "+70504026597"}
0005433722419	4EC0E2	6814 639642	EVGENIY ALEKSEEV	{"email": "alekseev_e-15021969@postgrespro.ru", "phone": "+70946614234"}
0005433722420	7FAB56	1302 644053	NADEZHDA SEMENOVA	{"phone": "+70325687246"}
0005433722421	15EB06	5612 975302	PAVEL FILIPPOV	{"email": "p.filippov.111976@postgrespro.ru", "phone": "+70353790015"}
0005433722422	CEC9E4	2191 454409	SERGEY EGOROV	{"email": "sergey.egorov-1971@postgrespro.ru", "phone": "+70641700070"}
0005433722423	70B676	3855 631657	GALINA TIKHONOVA	{"phone": "+70721857618"}
0005433722424	70B676	3485 826504	OLGA PAVLOVA	{"phone": "+70140407084"}
0005433722425	1B8409	3647 562023	ANDREY SHEVCHENKO	{"email": "a.shevchenko-121976@postgrespro.ru", "phone": "+70517190289"}
0005433722426	8341DF	3240 437763	MIKHAIL MATVEEV	{"phone": "+70393114818"}
0005433722427	B99644	0311 298305	DMITRIY NAZAROV	{"email": "d-nazarov1981@postgrespro.ru", "phone": "+70155508490"}
0005433722428	F2A665	8722 482039	KLAVDIYA TIKHONOVA	{"email": "k_tikhonova_08021981@postgrespro.ru", "phone": "+70306546102"}
0005433722429	F2A665	0774 756471	VADIM ILIN	{"email": "vadimilin_061974@postgrespro.ru", "phone": "+70091937798"}
0005433722430	21CF85	2004 589293	ALEKSANDR VOLKOV	{"phone": "+70537862615"}
0005433722431	153EC2	6271 100050	IRINA SIDOROVA	{"email": "i_sidorova_1984@postgrespro.ru", "phone": "+70348677799"}
0005433722432	3A4A8C	0099 703067	MIKHAIL PAVLOV	{"email": "mikhail-pavlov.18091955@postgrespro.ru", "phone": "+70112369529"}
0005433722433	F101BF	7851 242496	ELIZAVETA SMIRNOVA	{"phone": "+70561092034"}
0005433722434	F101BF	1529 195313	NATALYA LUKYANOVA	{"email": "lukyanova_natalya_1968@postgrespro.ru", "phone": "+70490094769"}
0005433722435	560F13	9324 202875	MIKHAIL MAKAROV	{"email": "makarov.mikhail_21051979@postgrespro.ru", "phone": "+70095080582"}
0005433722436	928EE3	5722 641572	TATYANA MELNIKOVA	{"email": "melnikovatatyana-111975@postgrespro.ru", "phone": "+70484597616"}
0005433722437	78B908	6854 431824	ALEKSANDR MATVEEV	{"phone": "+70490286604"}
0005433722438	78B908	3738 358709	ALENA ZAYCEVA	{"email": "a-zayceva1972@postgrespro.ru", "phone": "+70017386760"}
0005433722439	A74889	0622 890965	NINA AFANASEVA	{"phone": "+70257705643"}
0005433722440	A74889	9372 964812	ALEKSANDR ZAKHAROV	{"email": "zakharov-a1953@postgrespro.ru", "phone": "+70962879832"}
0005433722441	CF0C41	6382 972723	ALFIYA FOMINA	{"phone": "+70678694659"}
0005433722442	CF0C41	5136 528974	GUZEL FILATOVA	{"phone": "+70792638068"}
0005433722443	91D35B	4354 090762	ALEKSANDRA FILIPPOVA	{"email": "filippova.a081976@postgrespro.ru", "phone": "+70917940399"}
0005433722444	EBADB5	8340 307061	VIKTOR NIKITIN	{"phone": "+70214609958"}
0005433722445	93BE2C	1255 414680	YURIY FROLOV	{"phone": "+70938069570"}
0005433722446	93BE2C	3931 083315	RASHIT ANTONOV	{"email": "antonov-rashit121981@postgrespro.ru", "phone": "+70567905787"}
0005433722448	90ED8D	8200 000961	SVETLANA MIRONOVA	{"email": "s_mironova1966@postgrespro.ru", "phone": "+70122720974"}
0005433722449	082D50	8738 939062	NIKITA KAZAKOV	{"email": "nikita.kazakov_091966@postgrespro.ru", "phone": "+70031805593"}
0005433722450	082D50	1747 446693	ARKADIY MATVEEV	{"email": "matveev-arkadiy17121968@postgrespro.ru", "phone": "+70158542276"}
0005433722451	BADD0F	9511 731386	VADIM NAUMOV	{"email": "v-naumov_031978@postgrespro.ru", "phone": "+70730031988"}
0005433722452	62FC0B	1782 887464	IVAN ILIN	{"email": "iilin1986@postgrespro.ru", "phone": "+70715703808"}
0005433722453	23FA10	9305 611676	NARIMAN SAVELEV	{"email": "n-savelev-31121961@postgrespro.ru", "phone": "+70909525902"}
0005433722454	C88E58	0537 479000	ANDREY ISAEV	{"phone": "+70467709295"}
0005433722455	C05BD9	3841 722955	SVETLANA POPOVA	{"email": "popova.s051983@postgrespro.ru", "phone": "+70816811977"}
0005433722456	C05BD9	3043 558217	OLGA PAVLOVA	{"phone": "+70661151323"}
0005433722457	2972B2	5230 565324	ANNA ANTONOVA	{"phone": "+70522041721"}
0005433722458	2972B2	7373 895081	SERGEY ZHUKOV	{"phone": "+70254151420"}
0005433722459	B4BC2A	3940 431957	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey-05011970@postgrespro.ru", "phone": "+70720207365"}
0005433722460	AE17DA	8480 060098	YURIY KUZNECOV	{"email": "kuznecov_yuriy.041963@postgrespro.ru", "phone": "+70132259543"}
0005433722461	4A2E5C	2864 169740	DMITRIY DAVYDOV	{"phone": "+70150191613"}
0005433722462	50EEAF	1986 968957	SVETLANA TARASOVA	{"phone": "+70250994015"}
0005433722463	50EEAF	0856 394628	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr.10121976@postgrespro.ru", "phone": "+70016102813"}
0005433722464	28A9C8	1036 531094	NADEZHDA KUZMINA	{"email": "kuzminan_21031978@postgrespro.ru", "phone": "+70161549325"}
0005433722465	702286	5693 098807	VALERIY IVANOV	{"email": "valeriy.ivanov_081980@postgrespro.ru", "phone": "+70013933889"}
0005433722466	702286	9126 578463	SERGEY SEMENOV	{"phone": "+70479954912"}
0005433722467	F859C1	9547 917026	VALENTINA IVANOVA	{"email": "ivanova.valentina1973@postgrespro.ru", "phone": "+70063166630"}
0005433722468	F859C1	3771 832818	VASILIY SCHERBAKOV	{"phone": "+70078691209"}
0005433722469	8AEEA9	0737 535374	TIMOFEY PETROV	{"email": "petrov_timofey_30091972@postgrespro.ru", "phone": "+70228325119"}
0005433722470	364456	3031 330901	IRINA GORBUNOVA	{"email": "gorbunova.i-14021979@postgrespro.ru", "phone": "+70475519749"}
0005433722471	364456	7503 503211	DANILA POPOV	{"email": "popov_danila011978@postgrespro.ru", "phone": "+70423114998"}
0005433722472	35F557	0743 257956	IVAN ZAYCEV	{"email": "zaycev-i051970@postgrespro.ru", "phone": "+70958845261"}
0005433722473	55AF88	3651 890172	ANASTASIYA RYABOVA	{"phone": "+70138268199"}
0005433722474	0F791A	3177 032517	NIKOLAY CHERNOV	{"phone": "+70496207185"}
0005433722475	0F791A	6019 350684	SERGEY NIKOLAEV	{"email": "nikolaev.sergey01051959@postgrespro.ru", "phone": "+70382132577"}
0005433722476	7A3DB0	4885 589618	GALINA BOGDANOVA	{"email": "galinabogdanova-1963@postgrespro.ru", "phone": "+70552605945"}
0005433722477	EECEDB	7836 332258	GRIGORIY DENISOV	{"email": "denisov-g_081975@postgrespro.ru", "phone": "+70896841655"}
0005433722478	46EFA1	8396 727424	VALENTINA ZAYCEVA	{"phone": "+70232813560"}
0005433722479	46EFA1	7510 781164	ALEKSANDRA STEPANOVA	{"email": "stepanovaaleksandra.1979@postgrespro.ru", "phone": "+70349537180"}
0005433722480	13C2F6	0182 228685	YURIY MAKSIMOV	{"phone": "+70645312110"}
0005433722481	3FCFFC	5329 852750	ELIZAVETA LAZAREVA	{"phone": "+70556184348"}
0005433722482	3FCFFC	5469 875755	ALEKSANDR IVANOV	{"email": "ivanovaleksandr_13031972@postgrespro.ru", "phone": "+70693879132"}
0005433722483	023D00	5355 688064	VITALIY POPOV	{"email": "popovvitaliy09051984@postgrespro.ru", "phone": "+70157816395"}
0005433722484	5EEDCD	8009 871785	LYUBOV EGOROVA	{"phone": "+70736641493"}
0005433722485	67F336	4940 179043	EVGENIYA SMIRNOVA	{"phone": "+70229212565"}
0005433722486	66AB86	9120 400706	ALEKSANDR FEDOTOV	{"phone": "+70563706003"}
0005433722487	66AB86	2467 231529	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov_23111972@postgrespro.ru", "phone": "+70437220609"}
0005433722488	F2FBC9	9904 653939	KIRILL BORISOV	{"phone": "+70725469464"}
0005433722489	7A61B5	8381 096774	ALEKSANDR FEDOROV	{"email": "fedorova111983@postgrespro.ru", "phone": "+70506793201"}
0005433722490	7A61B5	3208 446735	ELENA ZAKHAROVA	{"email": "zakharovae.22061968@postgrespro.ru", "phone": "+70875164909"}
0005433722491	61D5F4	1547 248733	NIKOLAY SCHERBAKOV	{"email": "scherbakov_nikolay.051975@postgrespro.ru", "phone": "+70585011330"}
0005433722492	7C01A8	9814 658921	ZLATA BELOVA	{"email": "z_belova-1968@postgrespro.ru", "phone": "+70003426615"}
0005433722493	7C01A8	1818 320720	ELIZAVETA NIKITINA	{"phone": "+70167571416"}
0005433722494	7C01A8	7531 236119	DANIIL NIKOLAEV	{"email": "nikolaevdaniil_18081983@postgrespro.ru", "phone": "+70896403217"}
0005433722495	C2075F	0953 041005	VALENTINA POPOVA	{"phone": "+70284464796"}
0005433722496	A6F2BC	9443 297298	IVAN KUZMIN	{"phone": "+70428628263"}
0005433722497	A6F2BC	1264 826159	LARISA PAVLOVA	{"email": "pavloval-1976@postgrespro.ru", "phone": "+70980035549"}
0005433722498	A6F2BC	7499 670447	LIDIYA AFANASEVA	{"phone": "+70809969150"}
0005433722499	4260B8	6476 481636	ANGELINA STEPANOVA	{"phone": "+70479325144"}
0005433722500	4260B8	7139 856404	ANASTASIYA SMIRNOVA	{"phone": "+70886321581"}
0005433722501	2AF0AA	7231 141496	GALINA RYABOVA	{"email": "gryabova-011965@postgrespro.ru", "phone": "+70203801185"}
0005433722502	96FFDB	8023 848280	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr-021979@postgrespro.ru", "phone": "+70844515637"}
0005433722503	E4C818	5828 609446	ANDREY GERASIMOV	{"email": "a-gerasimov1983@postgrespro.ru", "phone": "+70887924984"}
0005433722504	E56D46	5927 762529	NADEZHDA LOGINOVA	{"phone": "+70032975061"}
0005433722505	3E4E1E	0709 566132	NADEZHDA NESTEROVA	{"phone": "+70776345912"}
0005433722506	338529	7657 908629	IRINA MOISEEVA	{"phone": "+70902328176"}
0005433722507	FE7149	6315 432417	GALINA VOLKOVA	{"email": "volkova_g101972@postgrespro.ru", "phone": "+70084166359"}
0005433722508	FD1828	0461 253179	NADEZHDA LUKYANOVA	{"phone": "+70026457360"}
0005433722509	1DFE17	4731 125068	SERGEY MAKSIMOV	{"phone": "+70801735440"}
0005433722510	B822F7	2559 184085	ELENA FEDOROVA	{"phone": "+70819403355"}
0005433722511	B822F7	2053 742905	IGOR SERGEEV	{"email": "sergeev_igor.26071980@postgrespro.ru", "phone": "+70693328739"}
0005433722512	9DB73E	2724 730314	VIKTOR SCHERBAKOV	{"email": "viktor_scherbakov.041973@postgrespro.ru", "phone": "+70517530179"}
0005433722513	F9E585	7566 613748	VLADIMIR YAKOVLEV	{"phone": "+70404591814"}
0005433722514	F9E585	3063 161920	GRIGORIY MIRONOV	{"email": "mironov-g.041981@postgrespro.ru", "phone": "+70441177257"}
0005433722515	09B22C	8346 526417	ANDREY VOLKOV	{"email": "andrey_volkov.1974@postgrespro.ru", "phone": "+70677872229"}
0005433724724	5961C9	4090 900584	VIKTORIYA VLASOVA	{"email": "vvlasova15071967@postgrespro.ru", "phone": "+70585107875"}
0005433724725	5FD1F3	0456 636591	SERGEY RODIONOV	{"phone": "+70746753194"}
0005433724726	B884A2	6193 160087	VLADIMIR OSIPOV	{"email": "vladimir-osipov.121972@postgrespro.ru", "phone": "+70879716507"}
0005433724727	B884A2	8894 466798	TATYANA MALYSHEVA	{"phone": "+70366333807"}
0005433724728	264FD7	6407 216168	NADEZHDA DENISOVA	{"email": "ndenisova.08021977@postgrespro.ru", "phone": "+70670964052"}
0005433724729	264FD7	5764 692604	VERA MOISEEVA	{"phone": "+70053683668"}
0005433724730	48DEAE	2245 793083	VALENTINA SAVELEVA	{"email": "valentina-saveleva-1969@postgrespro.ru", "phone": "+70749722535"}
0005433724731	41F2C1	1090 167398	NATALYA BELOVA	{"phone": "+70471390433"}
0005433724732	322F59	0768 814875	SVETLANA GAVRILOVA	{"phone": "+70468103355"}
0005433724733	C2D8E2	5990 070685	OLESYA POTAPOVA	{"email": "potapova-olesya-15041972@postgrespro.ru", "phone": "+70804252734"}
0005433724734	1784E1	2487 069740	ANNA KOMAROVA	{"phone": "+70856757453"}
0005433724735	AF1CAB	3930 094000	IRINA KOROLEVA	{"email": "irinakoroleva1981@postgrespro.ru", "phone": "+70746954109"}
0005433724736	7C544D	2738 284640	NIKOLAY YAKOVLEV	{"phone": "+70830871496"}
0005433724737	2B1EFC	7433 864164	ANNA BARANOVA	{"email": "baranova_anna-051973@postgrespro.ru", "phone": "+70671037756"}
0005433724738	2B1EFC	1641 099272	YURIY RODIONOV	{"email": "y.rodionov_1975@postgrespro.ru", "phone": "+70582763079"}
0005433724739	B201E2	7913 297965	ELENA ROMANOVA	{"phone": "+70556032699"}
0005433724740	93F133	8823 393304	TATYANA MAKAROVA	{"email": "t_makarova-26041975@postgrespro.ru", "phone": "+70782397427"}
0005433724741	BED990	8182 716426	OKSANA GORBUNOVA	{"email": "gorbunovao_1978@postgrespro.ru", "phone": "+70637856064"}
0005433724742	BED990	4663 949989	VLADIMIR VOLKOV	{"phone": "+70946892222"}
0005433724743	FA1DFC	8667 045847	OLGA MOROZOVA	{"email": "morozova-olga.1974@postgrespro.ru", "phone": "+70872965841"}
0005433724744	127DAF	9687 665191	VALENTIN DMITRIEV	{"email": "valentin_dmitriev1976@postgrespro.ru", "phone": "+70798486035"}
0005433724745	127DAF	3758 338519	DENIS ALEKSANDROV	{"phone": "+70471377342"}
0005433724746	127DAF	4530 945453	VASILIY TIKHONOV	{"email": "tikhonov.vasiliy081976@postgrespro.ru", "phone": "+70541671573"}
0005433724747	561D85	9994 517672	TATYANA NAZAROVA	{"email": "nazarova_t_111967@postgrespro.ru", "phone": "+70370767985"}
0005433724748	E46753	1974 963971	ALEKSANDR GAVRILOV	{"email": "agavrilov011974@postgrespro.ru", "phone": "+70004071022"}
0005433724749	246A1C	5529 153496	SERGEY CHERNOV	{"phone": "+70152616533"}
0005433724750	246A1C	9409 413628	ALFIYA IVANOVA	{"email": "ivanova_alfiya-08031977@postgrespro.ru", "phone": "+70168829856"}
0005433724751	3A7ACB	2999 393938	ALEKSANDRA KAZAKOVA	{"email": "kazakovaaleksandra_1967@postgrespro.ru", "phone": "+70918954262"}
0005433724752	3A7ACB	7531 255036	ALENA VASILEVA	{"email": "vasileva_alena.111980@postgrespro.ru", "phone": "+70313142062"}
0005433724753	C26B6F	0907 032744	EKATERINA LAZAREVA	{"email": "ekaterinalazareva_12091973@postgrespro.ru", "phone": "+70734184922"}
0005433724754	C26B6F	5043 380049	RAVIL FOMIN	{"phone": "+70623531778"}
0005433724755	E28475	4300 185639	LYUDMILA ANTONOVA	{"email": "antonoval-061965@postgrespro.ru", "phone": "+70876325999"}
0005433724756	1483C5	2371 237655	EGOR GERASIMOV	{"email": "e.gerasimov1978@postgrespro.ru", "phone": "+70488353847"}
0005433724757	CA0136	3674 196219	ANZHELIKA MOROZOVA	{"email": "anzhelika_morozova1965@postgrespro.ru", "phone": "+70769181857"}
0005433724758	CA0136	3757 830952	ANNA DENISOVA	{"phone": "+70599997708"}
0005433724759	B02609	3535 609010	NINA MARTYNOVA	{"phone": "+70343136171"}
0005433724760	9D7235	3930 404955	NINA CHERNOVA	{"phone": "+70389565614"}
0005433724761	EF3CE1	7499 134506	ALEKSANDR POPOV	{"phone": "+70893420380"}
0005433724762	EF3CE1	0232 095710	ILYA NIKOLAEV	{"phone": "+70635673908"}
0005433724763	4BF6C4	4872 787817	SERGEY SCHERBAKOV	{"email": "s-scherbakov.08021966@postgrespro.ru", "phone": "+70461892483"}
0005433724764	4BF6C4	8414 214217	LYUBOV FILIPPOVA	{"email": "lfilippova21121964@postgrespro.ru", "phone": "+70669378856"}
0005433724765	4BF6C4	0150 550778	LYUBOV EGOROVA	{"phone": "+70068307753"}
0005433724766	1CBA6D	1878 246832	INNA SEMENOVA	{"email": "inna.semenova_021977@postgrespro.ru", "phone": "+70782034409"}
0005433724767	A56553	6970 929791	IGOR SMIRNOV	{"email": "smirnov_i071988@postgrespro.ru", "phone": "+70921598815"}
0005433724768	26C64D	9283 536210	VYACHESLAV VOLKOV	{"phone": "+70340847431"}
0005433724769	7D52C7	7420 342778	TATYANA STEPANOVA	{"phone": "+70366086093"}
0005433724770	7D52C7	1935 978814	LILIYA BARANOVA	{"email": "baranova-liliya_27081966@postgrespro.ru", "phone": "+70626440714"}
0005433724771	7D52C7	3524 916307	NINA BOGDANOVA	{"email": "bogdanova.nina031960@postgrespro.ru", "phone": "+70679615067"}
0005433724772	B1A01D	1758 135131	ALLA LAZAREVA	{"phone": "+70952882734"}
0005433724773	E028AB	4096 939977	ALEKSANDR ANDREEV	{"email": "a-andreev-061969@postgrespro.ru", "phone": "+70971168585"}
0005433724774	1B712A	2202 695346	MIKHAIL ZHURAVLEV	{"email": "zhuravlev.m13051984@postgrespro.ru", "phone": "+70497514125"}
0005433724775	7D088C	9094 537956	VERA KOZLOVA	{"email": "v-kozlova_1963@postgrespro.ru", "phone": "+70122783774"}
0005433724776	7D088C	3181 047935	MIKHAIL SERGEEV	{"email": "sergeev_m1989@postgrespro.ru", "phone": "+70829587268"}
0005433724777	96826E	5885 455301	ALEKSEY MOISEEV	{"email": "moiseev.a.02061969@postgrespro.ru", "phone": "+70236392102"}
0005433724778	625D6B	5010 169752	ANDREY NAZAROV	{"phone": "+70518967644"}
0005433724779	D475A7	8155 196211	NADEZHDA FADEEVA	{"email": "nadezhda.fadeeva_1985@postgrespro.ru", "phone": "+70143988082"}
0005433724780	D475A7	9510 239314	VALENTINA KISELEVA	{"email": "kiselevav_21121973@postgrespro.ru", "phone": "+70783022318"}
0005433724781	F132F9	3877 847797	ALEKSANDR IVANOV	{"phone": "+70030515436"}
0005433724782	10B62C	2166 810805	KIRILL YAKOVLEV	{"email": "yakovlev_kirill.1958@postgrespro.ru", "phone": "+70505080879"}
0005433724783	10B62C	9730 256523	GALINA KUZNECOVA	{"phone": "+70206117959"}
0005433724784	0D0F9A	0344 237061	KIRILL POPOV	{"phone": "+70809010069"}
0005433724785	0D0F9A	1059 465481	FATIMA PETROVA	{"email": "fatimapetrova_1970@postgrespro.ru", "phone": "+70843085455"}
0005433724786	17F075	9583 267110	GALINA EGOROVA	{"phone": "+70736399439"}
0005433724787	9D65E2	7644 308629	ALEKSANDR KRASNOV	{"phone": "+70084339575"}
0005433724788	7F24B8	3877 132206	VLADIMIR FEDOROV	{"email": "v-fedorov05021976@postgrespro.ru", "phone": "+70128802616"}
0005433724789	64C357	6543 462546	VALENTINA ZAYCEVA	{"email": "vzayceva-11081971@postgrespro.ru", "phone": "+70785857566"}
0005433724790	64C357	0639 028079	SOFYA NESTEROVA	{"email": "sofya_nesterova-21031970@postgrespro.ru", "phone": "+70642176321"}
0005433724791	17850D	7182 482673	OLGA SCHERBAKOVA	{"phone": "+70005169073"}
0005433724792	1FF24F	8314 798909	KLAVDIYA MOROZOVA	{"phone": "+70611455894"}
0005433724793	1FF24F	9638 459713	ILYA SOKOLOV	{"email": "isokolov1960@postgrespro.ru", "phone": "+70761677997"}
0005433724794	850D3A	8069 501993	LIDIYA NIKITINA	{"email": "nikitina_l071970@postgrespro.ru", "phone": "+70765228759"}
0005433724795	53F3EF	8763 369456	PAVEL ANTONOV	{"email": "p_antonov011977@postgrespro.ru", "phone": "+70912435979"}
0005433724796	C7A8AE	2715 483363	MIKHAIL SEMENOV	{"phone": "+70342655940"}
0005433724797	C7A8AE	8682 261148	ALEKSANDR AFANASEV	{"phone": "+70507691761"}
0005433724798	AF863C	2320 342291	NATALIYA SIDOROVA	{"phone": "+70979170286"}
0005433724799	AF863C	8465 607064	ANDREY ROMANOV	{"phone": "+70339108003"}
0005433724800	24427D	9689 903016	KAMIL GERASIMOV	{"phone": "+70035306920"}
0005433724801	24427D	4982 746853	ALEKSANDRA SMIRNOVA	{"phone": "+70628238361"}
0005433724802	3A6E1E	2390 544388	ALEKSANDR MATVEEV	{"email": "matveev_a.1966@postgrespro.ru", "phone": "+70333687507"}
0005433724803	D14B68	0786 323651	VYACHESLAV NOVIKOV	{"phone": "+70046581399"}
0005433724804	D14B68	1953 739029	ASIYA PAVLOVA	{"email": "asiya.pavlova-29111968@postgrespro.ru", "phone": "+70371971581"}
0005433724805	D14B68	9693 228754	ALBINA POPOVA	{"phone": "+70576265595"}
0005433724806	315DC1	0390 266459	ARTEM POPOV	{"phone": "+70879361986"}
0005433724807	ABC3E5	3209 438562	MARIYA ZAKHAROVA	{"email": "mariya-zakharova-25121981@postgrespro.ru", "phone": "+70292890850"}
0005433724808	4F4CB3	9494 553742	KSENIYA BORISOVA	{"email": "k-borisova-26031973@postgrespro.ru", "phone": "+70657184418"}
0005433724809	4F4CB3	8822 750275	SERGEY MIKHAYLOV	{"phone": "+70421662816"}
0005433724810	3F56D4	1292 075304	EKATERINA KUZMINA	{"email": "kuzmina-e-17101969@postgrespro.ru", "phone": "+70579814671"}
0005433724811	3F56D4	5179 961437	IGOR SIDOROV	{"phone": "+70368167764"}
0005433724812	7863BF	4092 761081	ALEKSANDR SHEVCHENKO	{"phone": "+70456527175"}
0005433724813	409442	8769 421659	VERA BELYAEVA	{"phone": "+70141817950"}
0005433724814	409442	6266 476591	YAROSLAV BORISOV	{"phone": "+70795846219"}
0005433724815	72517D	6909 881845	OLEG SERGEEV	{"phone": "+70545018033"}
0005433724816	8C8687	8557 777655	VENIAMIN DENISOV	{"email": "v_denisov.111970@postgrespro.ru", "phone": "+70129103158"}
0005433724817	93978B	6196 132481	NATALYA FILIPPOVA	{"email": "filippova_n081974@postgrespro.ru", "phone": "+70344961208"}
0005433724818	4C734D	7654 143076	ALEKSANDR VASILEV	{"phone": "+70280555257"}
0005433724819	4108CA	5555 150603	VLADIMIR ZHUKOV	{"email": "vladimirzhukov-101971@postgrespro.ru", "phone": "+70128625845"}
0005433724820	4108CA	2549 378690	SERGEY ILIN	{"phone": "+70527217662"}
0005433724821	680765	8592 983465	NADEZHDA FROLOVA	{"email": "frolova.n14031974@postgrespro.ru", "phone": "+70125588634"}
0005433724822	D3D044	8164 040005	ZINAIDA ORLOVA	{"phone": "+70314922735"}
0005433724823	18284E	6483 930767	MARINA BARANOVA	{"email": "marinabaranova-28041975@postgrespro.ru", "phone": "+70207085477"}
0005433724824	4F17B5	8110 899291	TAMARA DANILOVA	{"phone": "+70441062504"}
0005433724825	4F17B5	3066 569162	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov1951@postgrespro.ru", "phone": "+70511154256"}
0005433724826	A80401	1380 599971	NATALYA ROMANOVA	{"phone": "+70292713101"}
0005433724827	B7B0AA	1662 697861	VLADISLAV KUZNECOV	{"phone": "+70932729556"}
0005433724828	9146AC	5490 926566	VALENTINA VOLKOVA	{"email": "v_volkova-27091967@postgrespro.ru", "phone": "+70762385426"}
0005433724829	A18054	6822 213286	ANDREY FROLOV	{"phone": "+70559400620"}
0005433724830	A18054	0541 884044	NATALYA ZAKHAROVA	{"phone": "+70572211279"}
0005433724831	067ADE	3736 217921	ANDREY FROLOV	{"phone": "+70493437989"}
0005433724832	8B6A8F	9788 418977	REGINA ANDREEVA	{"email": "r-andreeva-1969@postgrespro.ru", "phone": "+70307214490"}
0005433724833	D83B0A	2388 481844	LIDIYA PAVLOVA	{"phone": "+70905127003"}
0005433724834	5D26F4	6899 172448	LARISA SERGEEVA	{"phone": "+70405991886"}
0005433724835	C5BE4F	2476 505517	VALENTINA ISAEVA	{"email": "valentina_isaeva.071965@postgrespro.ru", "phone": "+70129136570"}
0005433724836	946925	4835 323685	ANTONINA SOLOVEVA	{"email": "soloveva.antonina.24061983@postgrespro.ru", "phone": "+70136592607"}
0005433724837	946925	3594 197857	OLEG VASILEV	{"phone": "+70915789533"}
0005433724838	05452A	6902 206185	DANILA EGOROV	{"phone": "+70074095317"}
0005433724839	0BC628	2659 428853	MARIYA ZHUKOVA	{"phone": "+70092998865"}
0005433724840	0BC628	8398 438175	VALERIY MAKAROV	{"email": "makarovvaleriy091967@postgrespro.ru", "phone": "+70631820107"}
0005433724841	0BC628	4939 352150	KIRA POPOVA	{"email": "kpopova_041968@postgrespro.ru", "phone": "+70080719783"}
0005433724842	E8D286	5379 463097	NINA ANISIMOVA	{"email": "ninaanisimova.1971@postgrespro.ru", "phone": "+70353050398"}
0005433724843	2D0E19	3997 916301	VLADISLAV ILIN	{"email": "ilin_vladislav.1984@postgrespro.ru", "phone": "+70422618721"}
0005433724844	D330CD	5439 756489	VIKTORIYA SOLOVEVA	{"phone": "+70215601783"}
0005433724845	D330CD	6060 724880	EKATERINA KRASNOVA	{"phone": "+70390014947"}
0005433724846	263981	8615 708046	EKATERINA ROMANOVA	{"email": "e.romanova_10091980@postgrespro.ru", "phone": "+70057139929"}
0005433724847	98E97F	7656 587607	EVGENIY BELOV	{"email": "belov_e.03111975@postgrespro.ru", "phone": "+70482659899"}
0005433724848	6C8B52	8654 389646	EVGENIY MEDVEDEV	{"phone": "+70525798543"}
0005433724849	747778	3172 961804	LYUDMILA PETROVA	{"email": "petrova.l_26121974@postgrespro.ru", "phone": "+70160633315"}
0005433724850	747778	2059 567433	YULIYA BELOVA	{"phone": "+70735788683"}
0005433724851	DB1726	5101 090879	GENNADIY CHERNOV	{"phone": "+70978317155"}
0005433724852	DB1726	6640 904924	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina-11111972@postgrespro.ru", "phone": "+70044999494"}
0005433724853	622E81	0966 608017	MARIYA VASILEVA	{"phone": "+70122939594"}
0005433724854	758168	2538 824598	LIDIYA NAZAROVA	{"email": "nazarova.l.09081976@postgrespro.ru", "phone": "+70617670676"}
0005433724855	939319	3932 405183	ANTON PETROV	{"email": "anton.petrov091965@postgrespro.ru", "phone": "+70376614540"}
0005433724856	73A3FE	3749 035297	EVGENIYA ALEKSEEVA	{"email": "e_alekseeva-1974@postgrespro.ru", "phone": "+70788041783"}
0005433724857	B504FA	9755 418739	LARISA GAVRILOVA	{"email": "gavrilova_l-1984@postgrespro.ru", "phone": "+70026050802"}
0005433724858	9F09D7	7451 260208	ALEKSANDR MOROZOV	{"phone": "+70633240125"}
0005433724859	9F09D7	9136 879028	VALERIYA ROMANOVA	{"email": "v.romanova-11061959@postgrespro.ru", "phone": "+70562646829"}
0005433724860	9F09D7	6699 363252	MIKHAIL NIKOLAEV	{"email": "nikolaev-mikhail_1981@postgrespro.ru", "phone": "+70537849885"}
0005433724861	525968	0399 232747	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov-1966@postgrespro.ru", "phone": "+70315490655"}
0005433724862	525968	6625 759270	TAMARA VASILEVA	{"phone": "+70088169427"}
0005433724863	A85EF4	9231 062262	NINA ZHUKOVA	{"email": "n.zhukova-111957@postgrespro.ru", "phone": "+70420237079"}
0005433724864	6F20B5	9285 418931	IRINA MIKHAYLOVA	{"phone": "+70549939668"}
0005433724865	A97596	9327 245620	ALEKSANDR CHERNOV	{"phone": "+70981005720"}
0005433724866	BCAA97	6055 587991	ALEKSANDR MAKAROV	{"email": "a_makarov-08041972@postgrespro.ru", "phone": "+70975211824"}
0005433724867	BCAA97	8235 519601	MAKSIM NIKOLAEV	{"phone": "+70670955330"}
0005433724868	67007A	1550 782801	NIKOLAY SAVELEV	{"phone": "+70912447454"}
0005433724869	5726E2	8441 359949	ROMAN SCHERBAKOV	{"email": "scherbakov_r01021969@postgrespro.ru", "phone": "+70769562677"}
0005433724870	F46A9A	2687 398341	OLGA KALININA	{"email": "o.kalinina.14081986@postgrespro.ru", "phone": "+70659663388"}
0005433724871	F46A9A	4294 391778	ELENA OSIPOVA	{"email": "osipova-e.031972@postgrespro.ru", "phone": "+70546487942"}
0005433724872	3DAE48	7930 787617	OKSANA GUSEVA	{"phone": "+70165042949"}
0005433724873	3DAE48	2365 270089	SERGEY KUZMIN	{"phone": "+70623422316"}
0005433724874	3AACE1	8342 472021	ROMAN VOROBEV	{"email": "vorobevr_1979@postgrespro.ru", "phone": "+70116556728"}
0005433724875	4F78C0	0760 015157	ANDREY MAKAROV	{"phone": "+70281387904"}
0005433724876	1DF108	8170 426577	EGOR FROLOV	{"phone": "+70187005694"}
0005433724877	84DE05	8103 805132	MARINA ZAKHAROVA	{"phone": "+70964219108"}
0005433724878	84DE05	7342 725696	MIKHAIL VOLKOV	{"phone": "+70715238565"}
0005433724879	84DE05	8981 737008	TAMARA LAZAREVA	{"phone": "+70914626551"}
0005433724936	207CA3	9858 632116	NATALYA ZHURAVLEVA	{"phone": "+70199691465"}
0005433724880	EE15E7	9611 798630	TATYANA BELOVA	{"email": "belova-t-14051968@postgrespro.ru", "phone": "+70989599789"}
0005433724881	2C5B3C	3032 275668	GALINA ERMAKOVA	{"phone": "+70079249488"}
0005433724882	2C5B3C	8850 330922	NIKOLAY PETROV	{"phone": "+70798051605"}
0005433724883	D28BFE	8306 788327	DMITRIY ABRAMOV	{"phone": "+70968119581"}
0005433724884	D28BFE	6939 717373	MARGARITA ANDREEVA	{"phone": "+70411877273"}
0005433724885	932DB1	9435 408474	EGOR VLASOV	{"phone": "+70529123727"}
0005433724886	4D4962	6755 637944	OLEG MAKAROV	{"email": "omakarov1966@postgrespro.ru", "phone": "+70802952932"}
0005433724887	4D4962	4114 143154	IRINA POPOVA	{"email": "irina.popova-1958@postgrespro.ru", "phone": "+70502195496"}
0005433724888	28348E	8547 867794	ZULFIYA MELNIKOVA	{"phone": "+70198386242"}
0005433724889	83C28B	2837 119220	NATALIYA OVCHINNIKOVA	{"email": "novchinnikova-1975@postgrespro.ru", "phone": "+70071430694"}
0005433724890	DCFAAD	8969 838540	GALINA STEPANOVA	{"phone": "+70501322230"}
0005433724891	DCFAAD	1748 700567	LIDIYA PETROVA	{"email": "petroval-021968@postgrespro.ru", "phone": "+70472495914"}
0005433724892	1686F1	5397 724893	IVAN MIRONOV	{"phone": "+70287996953"}
0005433724893	BFC675	1041 733964	DANIIL KARPOV	{"phone": "+70735597569"}
0005433724894	DF212A	9567 586947	EVGENIY YAKOVLEV	{"phone": "+70690753010"}
0005433724895	DF212A	1234 099744	YAROSLAV DMITRIEV	{"email": "dmitriev-yaroslav-23031979@postgrespro.ru", "phone": "+70666064616"}
0005433724896	2CFE7B	7160 259701	LYUBOV BELOVA	{"phone": "+70344673510"}
0005433724897	B89896	0449 471463	NIKOLAY TARASOV	{"phone": "+70860442749"}
0005433724898	B89896	6760 493634	SERGEY GERASIMOV	{"email": "gerasimovs_051971@postgrespro.ru", "phone": "+70952123017"}
0005433724899	39D347	6511 129465	ALBINA KOZLOVA	{"phone": "+70084512275"}
0005433724900	7748E6	7809 665672	ANATOLIY ZAKHAROV	{"phone": "+70456070751"}
0005433724901	7748E6	6561 280273	LIDIYA BORISOVA	{"email": "lborisova_19021976@postgrespro.ru", "phone": "+70790550786"}
0005433724902	E0CD0C	5097 491538	YULIYA LEBEDEVA	{"email": "yuliya_lebedeva061976@postgrespro.ru", "phone": "+70854923556"}
0005433724903	E0CD0C	7503 982380	STANISLAV KUZMIN	{"email": "s_kuzmin1965@postgrespro.ru", "phone": "+70328917406"}
0005433724904	93F486	2084 343959	VASILIY VOLKOV	{"email": "vvolkov.051973@postgrespro.ru", "phone": "+70831141057"}
0005433724905	212B64	3904 624671	NATALYA ANTONOVA	{"phone": "+70871096302"}
0005433724906	0C2FEB	2936 793198	ANDREY KUZNECOV	{"phone": "+70174764649"}
0005433724907	EF8D0C	9396 438987	MIKHAIL ILIN	{"email": "m-ilin.07011965@postgrespro.ru", "phone": "+70640101156"}
0005433724908	D510E0	3620 384246	NATALIYA KOZLOVA	{"email": "nataliya-kozlova27011977@postgrespro.ru", "phone": "+70437890633"}
0005433724909	C55FCF	4398 073219	VITALIY KUDRYASHOV	{"phone": "+70901712843"}
0005433724910	C98058	2483 381922	LYUDMILA BELYAEVA	{"email": "belyaevalyudmila.011983@postgrespro.ru", "phone": "+70586676800"}
0005433724911	C98058	9918 486329	MARIYA ANDREEVA	{"email": "mandreeva-041969@postgrespro.ru", "phone": "+70484850978"}
0005433724912	19062F	0024 306948	ANDREY FEDOROV	{"email": "andreyfedorov_10091975@postgrespro.ru", "phone": "+70208285459"}
0005433724913	7B03F7	5683 569024	VLADIMIR BARANOV	{"email": "vbaranov-071980@postgrespro.ru", "phone": "+70572338714"}
0005433724914	7B03F7	6745 178522	RIMMA KISELEVA	{"phone": "+70310654578"}
0005433724915	B70DBA	4063 714229	NADEZHDA SERGEEVA	{"phone": "+70632497504"}
0005433724916	B70DBA	6536 537628	LYUBOV SOLOVEVA	{"email": "lyubov.soloveva.22041985@postgrespro.ru", "phone": "+70120068489"}
0005433724917	B70DBA	5750 061477	OLGA BELOVA	{"email": "o-belova18111976@postgrespro.ru", "phone": "+70923152902"}
0005433724918	650D78	6469 580939	GENNADIY STEPANOV	{"phone": "+70923487901"}
0005433724919	650D78	5340 018212	DANILA MATVEEV	{"email": "danilamatveev_1976@postgrespro.ru", "phone": "+70902574223"}
0005433724920	37416F	2091 433927	BORIS IVANOV	{"phone": "+70797885989"}
0005433724921	52D939	4523 615222	NADEZHDA KOROLEVA	{"phone": "+70433109000"}
0005433724922	52D939	8577 177652	NATALYA LEBEDEVA	{"email": "natalyalebedeva_041967@postgrespro.ru", "phone": "+70172297679"}
0005433724923	D5AFE3	5553 770876	VLADIMIR MELNIKOV	{"phone": "+70473148663"}
0005433724924	5D97DF	9706 529432	YULIYA NIKOLAEVA	{"phone": "+70290827695"}
0005433724925	A79598	0237 724484	VIKTOR KOZLOV	{"email": "vkozlov_121972@postgrespro.ru", "phone": "+70750794929"}
0005433724926	DE5A26	3877 755132	MIKHAIL MARTYNOV	{"email": "mikhailmartynov.081980@postgrespro.ru", "phone": "+70935283980"}
0005433724927	E16B88	0898 757762	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr16091967@postgrespro.ru", "phone": "+70736948049"}
0005433724928	26A267	7869 857641	MARIYA ALEKSANDROVA	{"phone": "+70465202880"}
0005433724929	26A267	1837 870612	TATYANA ROMANOVA	{"phone": "+70910099053"}
0005433724930	FB5676	1022 545339	RIMMA TROFIMOVA	{"email": "trofimova.rimma_19071963@postgrespro.ru", "phone": "+70189659637"}
0005433724931	FB5676	5335 992460	EKATERINA SAVELEVA	{"email": "ekaterinasaveleva.1970@postgrespro.ru", "phone": "+70125183595"}
0005433724932	4E1F1D	0175 689607	POLINA POTAPOVA	{"phone": "+70689675827"}
0005433724933	272129	1438 725566	KLAVDIYA MIRONOVA	{"email": "mironovaklavdiya.10081962@postgrespro.ru", "phone": "+70516805202"}
0005433724934	272129	7790 540235	VERA ANDREEVA	{"phone": "+70394652845"}
0005433724935	16C78E	0789 264934	ALEKSANDR POPOV	{"email": "a_popov.29031962@postgrespro.ru", "phone": "+70950901986"}
0005433724937	BE0E90	7981 906637	EVGENIY SERGEEV	{"email": "e.sergeev_071965@postgrespro.ru", "phone": "+70334254302"}
0005433724938	E014DE	2772 771611	EVGENIY KARPOV	{"email": "evgeniy_karpov_101953@postgrespro.ru", "phone": "+70416275357"}
0005433724939	E014DE	2034 994260	VALERIY KOZLOV	{"email": "kozlov_v_111986@postgrespro.ru", "phone": "+70197016994"}
0005433724940	A352D7	7804 220942	VIKTOR MEDVEDEV	{"email": "v.medvedev-011976@postgrespro.ru", "phone": "+70949203248"}
0005433726063	467CD4	1332 934564	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a.14031972@postgrespro.ru", "phone": "+70081774652"}
0005433726064	D08369	6812 317333	YURIY ROMANOV	{"phone": "+70531021331"}
0005433726065	D08369	1699 319838	VLADIMIR NIKOLAEV	{"phone": "+70724036109"}
0005433726066	0DAC88	0457 844118	MAKSIM FILIPPOV	{"email": "filippov-maksim-31011964@postgrespro.ru", "phone": "+70082563824"}
0005433726067	C2FB11	2265 880217	ILDAR FOMIN	{"email": "ildarfomin-11041972@postgrespro.ru", "phone": "+70297951044"}
0005433726068	C2FB11	9772 721574	ELENA FROLOVA	{"email": "frolova-elena_011968@postgrespro.ru", "phone": "+70670164898"}
0005433726069	C2FB11	9813 720687	SVETLANA ANISIMOVA	{"email": "anisimova.s-1977@postgrespro.ru", "phone": "+70129262125"}
0005433726070	A5321B	2541 901363	KLAVDIYA BELOVA	{"email": "belovaklavdiya-1961@postgrespro.ru", "phone": "+70041046023"}
0005433726071	72757B	3384 865981	VLADIMIR ANTONOV	{"email": "antonovvladimir-031976@postgrespro.ru", "phone": "+70889152306"}
0005433726072	72757B	9169 621919	YURIY PAVLOV	{"phone": "+70365091253"}
0005433726073	5972D5	0940 895988	MARINA VOROBEVA	{"email": "m_vorobeva.111990@postgrespro.ru", "phone": "+70117760567"}
0005433726074	5972D5	0456 917568	NINA KOROLEVA	{"phone": "+70089102906"}
0005433726075	5972D5	0880 429797	VLADIMIR POPOV	{"phone": "+70299326957"}
0005433726076	8E252D	2189 072279	LYUDMILA MAKSIMOVA	{"phone": "+70590698466"}
0005433726077	A024C4	2607 254684	LYUDMILA KULIKOVA	{"email": "kulikova-lyudmila_1973@postgrespro.ru", "phone": "+70969412754"}
0005433726078	1EF793	1082 264134	VALENTINA POPOVA	{"email": "valentina.popova_031975@postgrespro.ru", "phone": "+70266222187"}
0005433726079	7353E1	2208 288608	OLGA AKIMOVA	{"email": "oakimova-07121966@postgrespro.ru", "phone": "+70320293749"}
0005433726080	96C2A0	7941 647960	DMITRIY ISAEV	{"phone": "+70539026514"}
0005433726081	96C2A0	9960 096984	ZAKHAR ANDREEV	{"phone": "+70816419388"}
0005433726082	BE058B	2183 817130	IGOR MOROZOV	{"email": "i.morozov_18051966@postgrespro.ru", "phone": "+70810883320"}
0005433726083	BE058B	7620 931794	VLADIMIR ANDREEV	{"email": "v.andreev011961@postgrespro.ru", "phone": "+70205918652"}
0005433726084	625514	0874 381882	GALINA ZHUKOVA	{"email": "zhukova-g_101974@postgrespro.ru", "phone": "+70418427078"}
0005433726085	625514	9536 157876	VALERIY MIRONOV	{"email": "mironov-v-101971@postgrespro.ru", "phone": "+70395684272"}
0005433726086	781565	2441 285148	VLADIMIR OSIPOV	{"email": "v-osipov_081972@postgrespro.ru", "phone": "+70191894116"}
0005433726087	619B3F	0193 266187	IGOR NAZAROV	{"email": "i-nazarov031979@postgrespro.ru", "phone": "+70317086823"}
0005433726088	619B3F	3558 905191	OLGA KOLESNIKOVA	{"email": "kolesnikova-olga.15051970@postgrespro.ru", "phone": "+70660288774"}
0005433726089	41D1CD	9328 037197	VADIM AFANASEV	{"email": "vadim_afanasev1976@postgrespro.ru", "phone": "+70014420367"}
0005433726090	0F3F32	9916 419832	GEORGIY IVANOV	{"phone": "+70067353882"}
0005433726091	2243BF	5195 670119	LEONID NIKITIN	{"email": "l_nikitin_21091967@postgrespro.ru", "phone": "+70102701566"}
0005433726092	2243BF	8354 683894	ELENA BORISOVA	{"email": "e.borisova.121975@postgrespro.ru", "phone": "+70786966347"}
0005433726093	B3DE98	4570 642525	VLADIMIR FOMIN	{"phone": "+70128689637"}
0005433726094	84C972	5387 234171	SVETLANA ARKHIPOVA	{"phone": "+70952482583"}
0005433726095	1CC198	4522 104161	FEDOR MOROZOV	{"phone": "+70598761688"}
0005433726096	1CC198	8858 405365	KIRILL MARTYNOV	{"phone": "+70942576560"}
0005433726097	BA6B2C	2086 888021	IRINA KUZNECOVA	{"phone": "+70346042132"}
0005433726098	2639DF	0848 015594	ANTON KISELEV	{"email": "antonkiselev1975@postgrespro.ru", "phone": "+70567636210"}
0005433726099	1E6E27	7026 296983	ANTONINA AKIMOVA	{"email": "akimovaantonina031957@postgrespro.ru", "phone": "+70085637943"}
0005433726100	1E6E27	6144 551980	SERGEY IVANOV	{"email": "sergey_ivanov-021965@postgrespro.ru", "phone": "+70436266406"}
0005433726101	E57AF1	1191 956900	MARIYA SIDOROVA	{"email": "sidorovamariya-031974@postgrespro.ru", "phone": "+70256811026"}
0005433726102	DBBDCD	4470 454492	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr-101974@postgrespro.ru", "phone": "+70844141656"}
0005433726103	3EA5D2	9238 267246	VIKTOR VOROBEV	{"email": "vorobevv.1973@postgrespro.ru", "phone": "+70147731313"}
0005433726104	FE9CF4	3268 203527	ALEKSANDR POPOV	{"email": "apopov-1964@postgrespro.ru", "phone": "+70758271230"}
0005433726105	BC21F2	6020 790821	ALEKSANDR ZAKHAROV	{"email": "zakharov.a.1964@postgrespro.ru", "phone": "+70861135874"}
0005433726106	653A20	5001 379917	POLINA STEPANOVA	{"email": "p_stepanova23101969@postgrespro.ru", "phone": "+70059033202"}
0005433726107	71C259	3545 360788	VIKTOR VOROBEV	{"email": "v-vorobev.02031967@postgrespro.ru", "phone": "+70753616391"}
0005433726108	E781E7	2152 112175	ILYA KULIKOV	{"email": "ilyakulikov1978@postgrespro.ru", "phone": "+70612473208"}
0005433726109	F9EF1B	9449 667484	OLGA ZAYCEVA	{"email": "zaycevao_011965@postgrespro.ru", "phone": "+70316085251"}
0005433726110	F9EF1B	5782 065416	OLGA DMITRIEVA	{"phone": "+70430494176"}
0005433726111	6E56CC	1353 261733	VASILIY GORBUNOV	{"phone": "+70673408810"}
0005433726112	28A891	2468 081390	SVETLANA GERASIMOVA	{"email": "gerasimova-svetlana_1966@postgrespro.ru", "phone": "+70723753662"}
0005433726113	4CF247	3034 448506	EVGENIYA KUZNECOVA	{"phone": "+70856609892"}
0005433726114	45E8E0	5953 245894	VALENTINA GUSEVA	{"phone": "+70924682230"}
0005433726115	45E8E0	8240 093044	OLGA GUSEVA	{"email": "guseva-o-03051977@postgrespro.ru", "phone": "+70659918102"}
0005433726116	291430	2511 403182	VALERIY ZAYCEV	{"email": "vzaycev27081975@postgrespro.ru", "phone": "+70016526894"}
0005433726117	3256BC	2966 258198	OLGA GERASIMOVA	{"email": "o_gerasimova_1973@postgrespro.ru", "phone": "+70434998006"}
0005433726118	C839CE	1771 304933	VIKTOR ZAYCEV	{"phone": "+70055145773"}
0005433726119	3BEA19	3827 858716	ANDREY KUZNECOV	{"phone": "+70813706937"}
0005433726120	C2D09C	5057 481197	ALEKSANDR NOVIKOV	{"phone": "+70308833564"}
0005433726121	C2D09C	1081 417581	DMITRIY MIKHAYLOV	{"email": "mikhaylovdmitriy.111966@postgrespro.ru", "phone": "+70246754795"}
0005433726122	4C8002	4415 059796	LYUBOV VASILEVA	{"email": "vasileval-121984@postgrespro.ru", "phone": "+70968398086"}
0005433726123	745562	3597 857174	OLEG NIKITIN	{"phone": "+70732721313"}
0005433726124	745562	6018 437768	SERGEY VOROBEV	{"email": "vorobev.sergey.081959@postgrespro.ru", "phone": "+70563423159"}
0005433726125	24C3F0	1981 238374	ANASTASIYA BELOVA	{"phone": "+70257430511"}
0005433726126	D62840	0192 268511	ALEKSANDR VLASOV	{"email": "a-vlasov-091966@postgrespro.ru", "phone": "+70025273765"}
0005433726127	434D22	4901 126229	MIKHAIL BARANOV	{"phone": "+70588863585"}
0005433726128	434D22	2867 183512	LIDIYA FILATOVA	{"phone": "+70356757924"}
0005433726129	434D22	3476 777478	NADEZHDA OSIPOVA	{"phone": "+70248036836"}
0005433726130	D4D643	5294 083016	MAKSIM STEPANOV	{"phone": "+70599359964"}
0005433726131	2A042F	3103 799059	VENERA FEDOROVA	{"phone": "+70513929283"}
0005433726132	4F21BC	4677 610129	EDUARD BORISOV	{"phone": "+70263163270"}
0005433726133	EFFAF8	1245 614956	ALEKSANDR SOLOVEV	{"phone": "+70554580216"}
0005433726134	EFFAF8	3128 135925	ANGELINA YAKOVLEVA	{"email": "yakovleva.angelina_111958@postgrespro.ru", "phone": "+70553857838"}
0005433726135	1585A2	0556 680324	VLADIMIR NIKITIN	{"phone": "+70060836724"}
0005433726136	1820B6	7379 363344	ANDREY BORISOV	{"email": "borisov.andrey-051969@postgrespro.ru", "phone": "+70847614106"}
0005433726137	48C912	3283 683585	LYUDMILA NAZAROVA	{"email": "nazarovalyudmila-1960@postgrespro.ru", "phone": "+70073552617"}
0005433726138	35746F	2508 458889	KSENIYA MIRONOVA	{"phone": "+70720297899"}
0005433726139	A6F6FE	8465 690289	ELINA KONDRATEVA	{"email": "e-kondrateva_1974@postgrespro.ru", "phone": "+70284065218"}
0005433726140	45916E	4359 084480	OLGA DENISOVA	{"email": "denisova-olga051970@postgrespro.ru", "phone": "+70021735829"}
0005433726141	BD27D4	1831 714125	SERGEY KOZLOV	{"phone": "+70861264488"}
0005433726142	BD27D4	9131 223866	YURIY EGOROV	{"phone": "+70032167058"}
0005433726143	507FE7	1399 969085	ELENA ABRAMOVA	{"phone": "+70588159010"}
0005433726144	507FE7	8328 535115	VIKTOR BONDARENKO	{"email": "bondarenko_v-1966@postgrespro.ru", "phone": "+70717000231"}
0005433726145	B0FEC7	4176 793701	GALINA EGOROVA	{"email": "egorova_galina031966@postgrespro.ru", "phone": "+70979613669"}
0005433726146	E38E12	9779 594270	ELENA MAKSIMOVA	{"email": "maksimova-elena061973@postgrespro.ru", "phone": "+70747080741"}
0005433726147	2CDB93	2145 312835	ARINA SCHERBAKOVA	{"email": "scherbakovaa.081977@postgrespro.ru", "phone": "+70890494889"}
0005433726148	60FD55	1612 977439	ILYA NAZAROV	{"phone": "+70999412784"}
0005433726149	B24FAD	9502 981124	POLINA AFANASEVA	{"email": "afanaseva.polina.1967@postgrespro.ru", "phone": "+70911289420"}
0005433726150	E1C069	1332 277427	ALEKSEY NOVIKOV	{"phone": "+70728776226"}
0005433726151	E1C069	3285 008275	VALENTINA SCHERBAKOVA	{"email": "scherbakovav.08081980@postgrespro.ru", "phone": "+70555407537"}
0005433726152	885470	9579 861694	VASILIY AFANASEV	{"email": "vafanasev.15031966@postgrespro.ru", "phone": "+70973583394"}
0005433726153	885470	5213 719672	KARINA IVANOVA	{"phone": "+70396040551"}
0005433726154	4958DC	7805 230006	AZAT IVANOV	{"email": "ivanov.azat-28051964@postgrespro.ru", "phone": "+70440358859"}
0005433726155	4958DC	0849 101370	MURAD SCHERBAKOV	{"phone": "+70125390173"}
0005433726156	3AE163	8209 324983	IVAN ALEKSANDROV	{"phone": "+70844828785"}
0005433726157	F40355	1385 316387	DENIS EGOROV	{"phone": "+70280358227"}
0005433726158	F40355	2654 181334	TATYANA NAUMOVA	{"phone": "+70299483552"}
0005433726159	8C9E7C	2419 194727	VLADIMIR POPOV	{"email": "popov.vladimir-041967@postgrespro.ru", "phone": "+70065891482"}
0005433726160	8C9E7C	6859 698847	OLGA NOVIKOVA	{"email": "novikova.olga-1968@postgrespro.ru", "phone": "+70502441224"}
0005433726161	FFA45B	1406 406356	ELENA SIDOROVA	{"phone": "+70169656086"}
0005433726162	C04692	2180 535069	DMITRIY MIKHAYLOV	{"phone": "+70100056503"}
0005433726163	C04692	7329 432661	ANNA MOROZOVA	{"email": "anna_morozova1971@postgrespro.ru", "phone": "+70273609853"}
0005433726164	751B6D	8264 771063	ALEKSANDR ANDREEV	{"email": "a-andreev_22101980@postgrespro.ru", "phone": "+70771816921"}
0005433726165	751B6D	3677 915191	SVETLANA EFREMOVA	{"email": "efremovasvetlana1969@postgrespro.ru", "phone": "+70189692538"}
0005433726166	F06651	9715 869532	NADEZHDA KOZLOVA	{"email": "kozlova.nadezhda-20091968@postgrespro.ru", "phone": "+70042037841"}
0005433726167	F06651	8079 245343	ANATOLIY PETROV	{"email": "petrov.a_081979@postgrespro.ru", "phone": "+70847667592"}
0005433726168	ED8561	8483 809358	VYACHESLAV IVANOV	{"phone": "+70832755803"}
0005433726169	D69768	8388 527028	VLADIMIR DENISOV	{"phone": "+70636538961"}
0005433726170	4054F7	5941 347489	ILYA IVANOV	{"email": "iivanov29111956@postgrespro.ru", "phone": "+70148542356"}
0005433726171	8BDBFB	5367 206631	ALEKSANDR SOKOLOV	{"email": "a-sokolov_1971@postgrespro.ru", "phone": "+70285841322"}
0005433753221	C697A5	8901 413548	NIKOLAY ABRAMOV	{"phone": "+70107595038"}
0005433753222	C697A5	8072 647335	ARSENIY FOMIN	{"phone": "+70365598671"}
0005433753223	D2F0B9	5100 577776	LYUDMILA FEDOROVA	{"email": "lfedorova1973@postgrespro.ru", "phone": "+70971815099"}
0005433753224	62A48D	2053 584381	ZINAIDA KOLESNIKOVA	{"phone": "+70399130075"}
0005433753225	5BCD6D	4827 010303	ALEKSANDR POPOV	{"email": "popov_aleksandr.091967@postgrespro.ru", "phone": "+70371092722"}
0005433753226	5BCD6D	7642 755621	YULIYA MATVEEVA	{"phone": "+70373260261"}
0005433753227	52C7F6	1278 600683	ALINA MOROZOVA	{"phone": "+70678991480"}
0005433753228	2920BD	8756 395120	EKATERINA ROMANOVA	{"email": "e-romanova_29061969@postgrespro.ru", "phone": "+70640464315"}
0005433753229	2920BD	1539 433776	VALENTINA OSIPOVA	{"phone": "+70534631655"}
0005433753230	19356B	2335 335361	ALEKSEY KISELEV	{"email": "kiselev_aleksey_1979@postgrespro.ru", "phone": "+70157150428"}
0005433753231	00C11A	4894 299516	SVETLANA KUZNECOVA	{"email": "svetlana_kuznecova1970@postgrespro.ru", "phone": "+70831745640"}
0005433753232	00C11A	5510 984331	EVGENIY FROLOV	{"phone": "+70007486396"}
0005433753233	00C11A	7226 949388	ALEKSANDRA KONDRATEVA	{"phone": "+70993745627"}
0005433753234	107C2F	5516 920738	VITALIY MIRONOV	{"email": "vitaliy.mironov_111978@postgrespro.ru", "phone": "+70403088676"}
0005433753235	107C2F	4099 896442	TATYANA NAUMOVA	{"email": "naumova_t1968@postgrespro.ru", "phone": "+70873792992"}
0005433753236	E9B92E	8275 172570	EGOR POPOV	{"email": "popov.egor-1984@postgrespro.ru", "phone": "+70056756801"}
0005433753237	E9B92E	9125 189215	SERGEY ZAYCEV	{"email": "szaycev_1976@postgrespro.ru", "phone": "+70776907184"}
0005433753238	2ED6E0	1715 209428	NINA ANTONOVA	{"email": "nina_antonova_011976@postgrespro.ru", "phone": "+70385153790"}
0005433753239	79B684	8510 682021	LYUBOV GRISHINA	{"email": "l_grishina-1959@postgrespro.ru", "phone": "+70761441976"}
0005433753240	79B684	3468 617508	VLADIMIR ZAKHAROV	{"phone": "+70441331825"}
0005433753241	79B684	7610 848388	EVGENIY ANTONOV	{"email": "e-antonov.26031973@postgrespro.ru", "phone": "+70612754019"}
0005433753242	C912E8	2219 796605	NADEZHDA PAVLOVA	{"phone": "+70847014001"}
0005433753243	C912E8	2745 898791	ANATOLIY MAKAROV	{"email": "makarov-a041972@postgrespro.ru", "phone": "+70924350905"}
0005433753244	B38F0F	2233 212986	TAMARA SEMENOVA	{"phone": "+70355454602"}
0005433753245	B38F0F	8886 291220	YULIYA MIRONOVA	{"email": "mironova-yuliya-06071976@postgrespro.ru", "phone": "+70439633528"}
0005433753246	B5F38E	1351 234700	NIKOLAY BELOV	{"phone": "+70086380271"}
0005433753247	18770E	4588 729001	SERGEY ALEKSANDROV	{"email": "sergeyaleksandrov-21101965@postgrespro.ru", "phone": "+70240412437"}
0005433753248	18770E	0671 259260	MARIYA TIKHONOVA	{"phone": "+70803000953"}
0005433753249	18770E	4845 020431	DMITRIY ILIN	{"phone": "+70210808979"}
0005433753250	D38CD0	6077 210804	RASHID IVANOV	{"email": "ivanov.r-11031982@postgrespro.ru", "phone": "+70444470707"}
0005433753251	950A37	2524 437615	MARINA PAVLOVA	{"email": "pavlova_marina_12101983@postgrespro.ru", "phone": "+70810446392"}
0005433753252	950A37	1026 531637	NIKOLAY BORISOV	{"phone": "+70921012796"}
0005433753253	950A37	4738 408516	ALEKSEY MAKAROV	{"phone": "+70980020401"}
0005433753254	241A63	3140 796932	MARIYA STEPANOVA	{"email": "stepanovam.1971@postgrespro.ru", "phone": "+70051644924"}
0005433753255	241A63	2119 332210	LYUDMILA DAVYDOVA	{"email": "davydova.l.23021968@postgrespro.ru", "phone": "+70453960519"}
0005433753256	241A63	7896 115939	NIKOLAY IVANOV	{"email": "ivanov.nikolay.021955@postgrespro.ru", "phone": "+70889846944"}
0005433753257	043F41	0181 708488	ANDREY PAVLOV	{"email": "pavlov_a-18081982@postgrespro.ru", "phone": "+70909442296"}
0005433753258	043F41	5634 547151	YULIYA ORLOVA	{"phone": "+70573650143"}
0005433753259	6A2C21	5799 271581	VLADIMIR SMIRNOV	{"phone": "+70325450924"}
0005433753260	8F71AE	1476 160048	ALINA MOROZOVA	{"phone": "+70657033797"}
0005433753261	3EB67C	9807 315718	ALEKSANDR MARTYNOV	{"phone": "+70271633805"}
0005433753262	A5F6C5	7505 522266	MARINA MOISEEVA	{"email": "marinamoiseeva_13011975@postgrespro.ru", "phone": "+70946553807"}
0005433753263	A5F6C5	7204 537241	SERGEY KONOVALOV	{"email": "s.konovalov_121965@postgrespro.ru", "phone": "+70803552635"}
0005433753264	654244	2741 550362	SERGEY FEDOROV	{"email": "fedorov-sergey.1967@postgrespro.ru", "phone": "+70797894807"}
0005433753265	654244	9647 400901	SVETLANA ALEKSEEVA	{"phone": "+70685242385"}
0005433753266	A55687	3997 869763	NATALIYA SOKOLOVA	{"email": "nataliya.sokolova-1966@postgrespro.ru", "phone": "+70087739462"}
0005433753267	A55687	7474 628059	LEONID KOZLOV	{"email": "lkozlov111981@postgrespro.ru", "phone": "+70226128437"}
0005433753268	118C48	5052 989080	ANDREY NOVIKOV	{"phone": "+70806121445"}
0005433753269	118C48	7534 194979	NADEZHDA STEPANOVA	{"email": "stepanovanadezhda_07061963@postgrespro.ru", "phone": "+70419952269"}
0005433753270	84CBB0	3014 335598	DENIS SHEVCHENKO	{"phone": "+70390459146"}
0005433753271	84CBB0	4252 322552	LYUBOV KOVALEVA	{"email": "lyubov.kovaleva04041974@postgrespro.ru", "phone": "+70086813579"}
0005433753272	614361	0745 987163	NATALYA NIKOLAEVA	{"phone": "+70843283952"}
0005433753273	614361	5071 337202	VALENTINA NAUMOVA	{"phone": "+70209526417"}
0005433753274	01E188	7910 905994	STANISLAV NAZAROV	{"email": "nazarovstanislav29111965@postgrespro.ru", "phone": "+70690233326"}
0005433753275	01E188	0050 686006	ALEKSANDRA SEMENOVA	{"email": "semenova.aleksandra-1975@postgrespro.ru", "phone": "+70734186774"}
0005433753276	01E188	5593 093051	ELENA SERGEEVA	{"email": "sergeevae-121977@postgrespro.ru", "phone": "+70196674750"}
0005433753277	AC5E7F	3901 332184	MAKSIM IVANOV	{"email": "ivanovmaksim_121978@postgrespro.ru", "phone": "+70320829803"}
0005433753278	D605B0	4071 949107	VLADIMIR ANDREEV	{"email": "vandreev.061975@postgrespro.ru", "phone": "+70389433614"}
0005433753279	B47B74	7884 076305	ALFIYA FILIPPOVA	{"email": "filippova.alfiya.1982@postgrespro.ru", "phone": "+70304381737"}
0005433753280	BAD9BC	3171 864726	VLADIMIR MIRONOV	{"phone": "+70821946794"}
0005433753281	176114	4849 865239	IRINA MAKSIMOVA	{"email": "maksimovai-1977@postgrespro.ru", "phone": "+70408853635"}
0005433753282	ACBAEF	6886 892080	OLEG MAKAROV	{"phone": "+70697047599"}
0005433753283	ACBAEF	5977 801339	LARISA KUZNECOVA	{"phone": "+70365111698"}
0005433753284	6300A0	8867 555621	NIKOLAY KISELEV	{"email": "n-kiselev_15021977@postgrespro.ru", "phone": "+70439447614"}
0005433753285	C7D974	3984 981434	VYACHESLAV GAVRILOV	{"phone": "+70978589885"}
0005433753286	C7D974	4334 306978	ALEKSANDR MEDVEDEV	{"email": "a-medvedev1966@postgrespro.ru", "phone": "+70524159533"}
0005433753287	08644E	2927 422274	LYUDMILA KUZNECOVA	{"phone": "+70461910070"}
0005433753288	E8B6AE	7270 047311	TATYANA VOROBEVA	{"email": "vorobevatatyana_121969@postgrespro.ru", "phone": "+70442743634"}
0005433753289	AEB71A	7583 139394	VLADIMIR CHERNOV	{"email": "chernov.v061966@postgrespro.ru", "phone": "+70925689872"}
0005433753290	AEB71A	7423 536313	EVGENIYA DMITRIEVA	{"phone": "+70806321226"}
0005433753291	639498	6686 746166	LYUDMILA KUZMINA	{"email": "l_kuzmina-04071982@postgrespro.ru", "phone": "+70122876857"}
0005433753292	C79D89	1022 587081	MIKHAIL POPOV	{"phone": "+70118716176"}
0005433753293	3BF97C	8518 345866	ANASTASIYA MEDVEDEVA	{"phone": "+70626621338"}
0005433753294	3BF97C	0703 011482	VLADISLAV KOROLEV	{"phone": "+70207866786"}
0005433753295	962594	7418 641332	VASILIY MAKAROV	{"phone": "+70533819901"}
0005433753296	6E3332	4516 429442	GALINA KOZLOVA	{"email": "kozlova_g101975@postgrespro.ru", "phone": "+70572676939"}
0005433753297	22B5CE	4109 695236	SERGEY IVANOV	{"phone": "+70075342873"}
0005433753298	E15FCD	2513 446806	ASIYA VASILEVA	{"email": "vasileva_a.111970@postgrespro.ru", "phone": "+70144458334"}
0005433753299	E15FCD	2480 458055	VLADIMIR TARASOV	{"email": "tarasov.v-1968@postgrespro.ru", "phone": "+70473046665"}
0005433753300	519F52	3538 704999	KSENIYA PETROVA	{"phone": "+70614333658"}
0005433753301	F139D3	6206 198043	SERGEY FEDOTOV	{"phone": "+70698549322"}
0005433753302	F139D3	6171 149190	LIDIYA NIKIFOROVA	{"phone": "+70993787930"}
0005433753303	F139D3	6467 774720	PAVEL KUZNECOV	{"email": "p-kuznecov_111974@postgrespro.ru", "phone": "+70306368480"}
0005433753304	84EC07	5642 651386	LIDIYA ALEKSANDROVA	{"phone": "+70614381849"}
0005433753305	FA1ED9	9274 850580	DMITRIY STEPANOV	{"email": "d.stepanov-011981@postgrespro.ru", "phone": "+70904953573"}
0005433753306	A70A71	4562 643470	VLADIMIR ZHURAVLEV	{"phone": "+70283869852"}
0005433753307	A70A71	1772 156877	TAMARA PETROVA	{"phone": "+70572211420"}
0005433753308	EEF09F	4136 711171	VALENTINA POPOVA	{"phone": "+70143134387"}
0005433753309	EEF09F	1605 904600	LYUDMILA VOLKOVA	{"email": "volkoval_21041971@postgrespro.ru", "phone": "+70448344145"}
0005433753310	9C94BA	7825 311668	OLGA KUZMINA	{"phone": "+70966427323"}
0005433753311	37AFA6	1865 917663	RUSLAN KOROLEV	{"phone": "+70597286831"}
0005433753312	37AFA6	9660 785430	MARIYA IVANOVA	{"email": "mariyaivanova-28011975@postgrespro.ru", "phone": "+70883257097"}
0005433753313	3DE13C	8368 797336	OLGA FROLOVA	{"email": "frolovao-1964@postgrespro.ru", "phone": "+70635305119"}
0005433753314	0A373A	8727 007582	SVETLANA DENISOVA	{"email": "sdenisova.1968@postgrespro.ru", "phone": "+70045718343"}
0005433753315	ACAA61	4219 363415	IGOR PETROV	{"email": "ipetrov_10091982@postgrespro.ru", "phone": "+70529458888"}
0005433753316	2EA316	2639 149033	ALEKSEY KUZMIN	{"email": "a_kuzmin.1980@postgrespro.ru", "phone": "+70277775595"}
0005433753317	2EA316	2696 003786	ALEKSANDR ILIN	{"email": "aleksandr-ilin.1974@postgrespro.ru", "phone": "+70584240096"}
0005433753318	8E6A6D	6438 710008	OLGA MIRONOVA	{"phone": "+70921167004"}
0005433753319	8E6A6D	0216 955102	DENIS ZHURAVLEV	{"phone": "+70639498074"}
0005433753320	8E6A6D	9777 241193	VITALIY VOROBEV	{"phone": "+70089495345"}
0005433753321	72881D	3712 796057	EVGENIY KONOVALOV	{"email": "evgeniy-konovalov_16091969@postgrespro.ru", "phone": "+70154612037"}
0005433753322	72881D	0246 777546	ELIZAVETA KOZLOVA	{"phone": "+70537075439"}
0005433753323	C82935	0661 018530	IRINA ROMANOVA	{"phone": "+70221418931"}
0005433753324	ADB5DE	7808 183181	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko1972@postgrespro.ru", "phone": "+70832638836"}
0005433753325	ADB5DE	9368 456876	NIKOLAY SOKOLOV	{"email": "sokolov_n021969@postgrespro.ru", "phone": "+70387959528"}
0005433753326	ADB5DE	0411 068973	NADEZHDA VOLKOVA	{"phone": "+70282820706"}
0005433753327	DFCE5E	1404 412984	VALENTINA NIKITINA	{"email": "v-nikitina_1962@postgrespro.ru", "phone": "+70436350579"}
0005433753328	0B72F2	7768 781328	VLADISLAV POPOV	{"phone": "+70631094305"}
0005433753329	0B72F2	1603 741498	ANDREY VLASOV	{"email": "vlasov_a-071963@postgrespro.ru", "phone": "+70302152319"}
0005433753330	91E5F7	6953 302983	IRINA YAKOVLEVA	{"phone": "+70395856572"}
0005433753331	16BFBE	2290 208467	LYUBOV FEDOROVA	{"phone": "+70071952614"}
0005433753332	16BFBE	1949 013026	ANASTASIYA LEBEDEVA	{"phone": "+70419873403"}
0005433753333	3802D0	6419 034378	IREK SCHERBAKOV	{"email": "scherbakov.i-14081974@postgrespro.ru", "phone": "+70334084307"}
0005433753334	101170	5093 128498	IRINA LUKYANOVA	{"email": "lukyanova_i-081971@postgrespro.ru", "phone": "+70890983435"}
0005433753335	E72CA8	1483 665455	VLADISLAV ANDREEV	{"email": "v-andreev_081972@postgrespro.ru", "phone": "+70025074241"}
0005433753336	4F003A	8284 970582	TATYANA FROLOVA	{"email": "tatyana.frolova-061984@postgrespro.ru", "phone": "+70468628650"}
0005433753337	4F003A	7557 373685	VERONIKA BELYAEVA	{"email": "belyaeva-v17091968@postgrespro.ru", "phone": "+70832266865"}
0005433753338	6F78DA	4238 160730	LYUDMILA FILIPPOVA	{"email": "lfilippova_021974@postgrespro.ru", "phone": "+70163719464"}
0005433753339	2B4468	3663 712363	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko-21091962@postgrespro.ru", "phone": "+70958183791"}
0005433753340	613FA4	9190 535297	ANDREY NOVIKOV	{"email": "novikov-andrey-081976@postgrespro.ru", "phone": "+70117564767"}
0005433753341	8E3D5E	5889 940931	TAMARA VOLKOVA	{"email": "t.volkova_111970@postgrespro.ru", "phone": "+70572392913"}
0005433753342	8E3D5E	9176 269208	KIRILL TARASOV	{"email": "k-tarasov_04031984@postgrespro.ru", "phone": "+70350537787"}
0005433753343	65C0B0	8924 776207	MAKSIM KUZNECOV	{"email": "m-kuznecov-061978@postgrespro.ru", "phone": "+70829356925"}
0005433753344	9347E5	6460 906225	RAMIL MIKHAYLOV	{"email": "mikhaylov-ramil041979@postgrespro.ru", "phone": "+70984005058"}
0005433753345	DDD8B7	9663 637240	MIKHAIL TIMOFEEV	{"email": "timofeevmikhail.10021970@postgrespro.ru", "phone": "+70742682605"}
0005433753346	24348E	0296 489375	SVETLANA FEDOROVA	{"email": "svetlanafedorova-1977@postgrespro.ru", "phone": "+70846976263"}
0005433753347	24348E	8256 594144	PAVEL NOVIKOV	{"phone": "+70620331109"}
0005433753348	D2116C	9855 638138	DMITRIY OSIPOV	{"phone": "+70387400391"}
0005433753349	D2116C	7761 828922	GALINA IVANOVA	{"phone": "+70753437250"}
0005433753350	36AB55	6452 095733	PAVEL FEDOROV	{"email": "p_fedorov.22051972@postgrespro.ru", "phone": "+70279142700"}
0005433753351	7807E7	4159 938970	KSENIYA KUZNECOVA	{"email": "kuznecova_kseniya-09021964@postgrespro.ru", "phone": "+70797908247"}
0005433753352	FB2D0E	0529 099526	LEONID SHEVCHENKO	{"phone": "+70453606161"}
0005433753353	CD8C63	6207 368699	LYUBOV AFANASEVA	{"phone": "+70025376239"}
0005433753354	B07C7F	7894 718658	ALEKSANDR RODIONOV	{"phone": "+70933580495"}
0005433753355	39A8C7	5476 564902	ALENA MARTYNOVA	{"phone": "+70516044349"}
0005433753356	39A8C7	6194 981402	FLYURA ARKHIPOVA	{"phone": "+70827247232"}
0005433753357	506DE5	1787 984242	TATYANA VASILEVA	{"phone": "+70884696869"}
0005433753358	506DE5	7230 046023	ELENA KUZMINA	{"email": "e_kuzmina-1974@postgrespro.ru", "phone": "+70916372224"}
0005433753359	92E164	4842 653417	ELENA KULIKOVA	{"email": "kulikova_e_27021965@postgrespro.ru", "phone": "+70484738629"}
0005433753360	92E164	4330 138789	LEONID EGOROV	{"phone": "+70410097123"}
0005433753361	B78738	5359 713448	DANIIL STEPANOV	{"phone": "+70313605389"}
0005433753362	B78738	0598 949098	ALBERT ILIN	{"email": "albert.ilin23091968@postgrespro.ru", "phone": "+70085648136"}
0005433753363	60D2E0	8958 409175	ZOYA KOZLOVA	{"email": "kozlovazoya.1966@postgrespro.ru", "phone": "+70759933020"}
0005433753364	55ACBA	2039 771968	NATALYA FEDOROVA	{"email": "fedorova.natalya_011981@postgrespro.ru", "phone": "+70718542472"}
0005433753365	55ACBA	0560 982915	ALLA ARKHIPOVA	{"phone": "+70088501312"}
0005433753366	F2009E	9402 546891	YULIYA FOMINA	{"phone": "+70155923594"}
0005433753367	A59DA4	9527 566007	NATALYA KALININA	{"phone": "+70012486584"}
0005433753368	6797A7	2362 468755	MARINA VOROBEVA	{"email": "vorobeva.m111954@postgrespro.ru", "phone": "+70414178482"}
0005433753369	6797A7	6653 372893	ALEKSANDR OSIPOV	{"phone": "+70155003306"}
0005433753370	B518B3	2489 273441	NIKOLAY KUZNECOV	{"email": "n-kuznecov1983@postgrespro.ru", "phone": "+70926832648"}
0005433753371	A1B203	3744 332643	EVGENIYA FILIPPOVA	{"phone": "+70929881178"}
0005433753372	9CF964	6141 026727	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr_11101988@postgrespro.ru", "phone": "+70348667470"}
0005433753373	3DD583	6060 314619	ELENA ZHURAVLEVA	{"phone": "+70988899979"}
0005433753374	A769AF	3504 333096	DMITRIY KUDRYASHOV	{"email": "kudryashov.dmitriy-19061975@postgrespro.ru", "phone": "+70463297577"}
0005433753375	02E8E1	9741 866172	KIRILL SAVELEV	{"email": "k.savelev_031976@postgrespro.ru", "phone": "+70818459098"}
0005433753376	3B8959	2614 832796	LARISA POPOVA	{"phone": "+70486969950"}
0005433753377	3B8959	5756 714571	NIKOLAY DENISOV	{"email": "denisovnikolay.1960@postgrespro.ru", "phone": "+70515000711"}
0005433753378	A8863B	7122 930511	ROMAN CHERNOV	{"phone": "+70996630379"}
0005433753379	A8863B	4341 816060	MIKHAIL DMITRIEV	{"phone": "+70189182314"}
0005433753380	16743A	7379 584039	NINA YUDINA	{"email": "ninayudina-10121968@postgrespro.ru", "phone": "+70408734010"}
0005433753381	F68E81	4598 583197	ALIYA ZHUKOVA	{"phone": "+70604530459"}
0005433753382	F68E81	6193 971211	ANATOLIY ISAEV	{"email": "a-isaev.081977@postgrespro.ru", "phone": "+70925040656"}
0005433753383	323520	7608 285258	ALEKSANDR VOLKOV	{"phone": "+70013604848"}
0005433753384	68E763	3241 061299	IGOR POPOV	{"email": "i.popov_28041974@postgrespro.ru", "phone": "+70899074458"}
0005433753385	68E763	2402 811459	SERGEY FILIPPOV	{"email": "sfilippov_16111978@postgrespro.ru", "phone": "+70095312965"}
0005433753386	39531A	3423 133454	ROMAN DENISOV	{"email": "r_denisov11051970@postgrespro.ru", "phone": "+70800751720"}
0005433753387	B1D4CA	8648 515990	ALEKSEY FILIPPOV	{"phone": "+70277939381"}
0005433753388	B1D4CA	7978 856246	DARYA NIKITINA	{"email": "darya_nikitina28051973@postgrespro.ru", "phone": "+70968265998"}
0005433753389	20FB6F	7268 535549	YURIY FEDOTOV	{"email": "yuriyfedotov-1985@postgrespro.ru", "phone": "+70203983444"}
0005433753390	598256	1239 896179	TATYANA ZHUKOVA	{"email": "tatyana-zhukova.1973@postgrespro.ru", "phone": "+70887876455"}
0005433753391	598256	7998 883529	VASILIY ABRAMOV	{"phone": "+70209899980"}
0005433753392	9D4F34	3701 208511	ANVAR TARASOV	{"phone": "+70940758881"}
0005433753393	C6C3E6	1166 059495	OLGA VOLKOVA	{"email": "olga.volkova_011968@postgrespro.ru", "phone": "+70710386292"}
0005433753394	23EB7E	4577 417577	RAVIL NAZAROV	{"email": "ravilnazarov.11011987@postgrespro.ru", "phone": "+70036753357"}
0005433753395	47470F	2361 014430	TAMARA LAZAREVA	{"phone": "+70899894140"}
0005433753396	D02032	8799 963177	RAMIL FROLOV	{"phone": "+70995758437"}
0005433753397	D02032	2056 730373	NATALYA KAZAKOVA	{"email": "natalya.kazakova-1974@postgrespro.ru", "phone": "+70903148761"}
0005433753398	E4BAA0	3806 124374	MARIYA MARTYNOVA	{"email": "martynova.mariya.1967@postgrespro.ru", "phone": "+70201149433"}
0005433753399	D1A374	2788 129485	EKATERINA DENISOVA	{"phone": "+70317111137"}
0005433753400	1DE60B	2724 497358	MARINA STEPANOVA	{"email": "mstepanova07021982@postgrespro.ru", "phone": "+70314888680"}
0005433753401	60712D	2856 015683	ZAKHAR STEPANOV	{"phone": "+70011166866"}
0005433753402	171EB2	7620 332932	OLESYA DMITRIEVA	{"email": "o.dmitrieva1984@postgrespro.ru", "phone": "+70192795034"}
0005433753403	1E4AF3	9303 706811	GALINA MIKHAYLOVA	{"email": "mikhaylova_g-05021984@postgrespro.ru", "phone": "+70915551713"}
0005433753404	E4E155	0858 292886	IRINA SEMENOVA	{"email": "semenova-i28081965@postgrespro.ru", "phone": "+70538519783"}
0005433753405	E4E155	7628 087213	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov.1979@postgrespro.ru", "phone": "+70159008338"}
0005433753406	77E277	8797 104777	ALINA ERMAKOVA	{"email": "ermakovaalina.071978@postgrespro.ru", "phone": "+70016638316"}
0005433753407	460F54	8658 356500	ANATOLIY KOZLOV	{"email": "anatoliy_kozlov091982@postgrespro.ru", "phone": "+70741675797"}
0005433753408	460F54	3822 502535	ALEKSANDR GUSEV	{"email": "gusev-a_031968@postgrespro.ru", "phone": "+70548420477"}
0005433753409	460F54	1266 047539	EDUARD ALEKSANDROV	{"email": "e-aleksandrov-091979@postgrespro.ru", "phone": "+70296349649"}
0005433753410	384F3E	0177 448454	PAVEL GRIGOREV	{"phone": "+70160799052"}
0005433753411	553CA8	0213 682383	EKATERINA KUZNECOVA	{"email": "kuznecova.ekaterina-071965@postgrespro.ru", "phone": "+70601205229"}
0005433753412	FE74A2	4114 131375	SERGEY VLASOV	{"phone": "+70908494042"}
0005433753413	627F29	5438 863661	LARISA TIMOFEEVA	{"email": "l.timofeeva_1973@postgrespro.ru", "phone": "+70814809363"}
0005433753414	627F29	1537 007403	ALEKSANDR DMITRIEV	{"email": "a-dmitriev15031965@postgrespro.ru", "phone": "+70153899832"}
0005433753415	9B391B	0634 828434	ALEKSANDR PETROV	{"email": "petrova.30101979@postgrespro.ru", "phone": "+70875229923"}
0005433753416	2F7A4A	7822 124869	PAVEL MIKHAYLOV	{"phone": "+70933998002"}
0005433753417	DAB8FF	9856 621431	GALINA IVANOVA	{"email": "ivanova.galina.1961@postgrespro.ru", "phone": "+70723570797"}
0005433753418	078473	3797 251651	RAIL RODIONOV	{"phone": "+70659184773"}
0005433753419	D2E28D	3375 795493	VLADIMIR GRIGOREV	{"email": "grigorev.vladimir-1979@postgrespro.ru", "phone": "+70441319302"}
0005433753420	1F5F59	7793 733874	ANATOLIY VASILEV	{"phone": "+70974446032"}
0005433753421	1F5F59	6763 219143	ALEKSANDRA MIKHAYLOVA	{"phone": "+70240390952"}
0005433753422	6E0FAB	8898 129441	SVETLANA CHERNOVA	{"email": "schernova.041966@postgrespro.ru", "phone": "+70988157573"}
0005433753423	6E0FAB	4774 702628	YURIY AFANASEV	{"phone": "+70068730869"}
0005433753424	E84662	5404 455788	LIDIYA VLASOVA	{"phone": "+70992428248"}
0005433753425	C719E5	2773 464415	ALEKSANDR VOLKOV	{"phone": "+70524936167"}
0005433753426	C719E5	8964 986161	SERGEY SAVELEV	{"phone": "+70873108178"}
0005433753427	61B1B3	7707 320685	LYUDMILA GAVRILOVA	{"phone": "+70381069210"}
0005433753428	13932B	4857 227398	NATALYA IVANOVA	{"phone": "+70953082034"}
0005433753429	C1B06E	9455 261751	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova_06011975@postgrespro.ru", "phone": "+70493394897"}
0005433753430	C1B06E	4213 238405	NIKITA ROMANOV	{"phone": "+70332098116"}
0005433753431	6624BE	6074 112774	INNA ABRAMOVA	{"email": "abramovainna1979@postgrespro.ru", "phone": "+70938987915"}
0005433753432	6624BE	3138 148223	MARIYA KUZNECOVA	{"email": "mariya_kuznecova07031972@postgrespro.ru", "phone": "+70583127449"}
0005433753433	845FC4	3945 000078	DARINA ANTONOVA	{"phone": "+70399581269"}
0005433753434	EC657A	3995 877687	MIKHAIL VASILEV	{"email": "vasilev_m_1977@postgrespro.ru", "phone": "+70542966197"}
0005433753435	05267E	2937 870969	NINA MAKAROVA	{"phone": "+70813963226"}
0005433753436	05267E	7098 121350	EVGENIYA ALEKSANDROVA	{"email": "e_aleksandrova.1978@postgrespro.ru", "phone": "+70444329222"}
0005433753437	41ED84	5542 715320	DARYA IVANOVA	{"phone": "+70629733621"}
0005433753438	593B03	6635 617524	ALEKSEY DMITRIEV	{"phone": "+70245198476"}
0005433753439	593B03	8470 184600	GALINA NESTEROVA	{"phone": "+70011848955"}
0005433753440	9131F3	4668 981886	YULIYA MIRONOVA	{"phone": "+70420122803"}
0005433753441	22C185	6687 320073	SVETLANA NAUMOVA	{"phone": "+70659603487"}
0005433753442	26FA01	0691 674748	VIKTOR PETROV	{"phone": "+70825218687"}
0005433753443	7EA0D0	4652 907453	NIKOLAY NAZAROV	{"email": "n.nazarov-021981@postgrespro.ru", "phone": "+70440709833"}
0005433753444	A1BD76	1711 557561	ELVIRA STEPANOVA	{"email": "elvirastepanova-1973@postgrespro.ru", "phone": "+70677009498"}
0005433753445	A1BD76	6947 595389	SVETLANA KOZLOVA	{"phone": "+70541825934"}
0005433753446	7A6E3D	9760 356918	RAIS KUZMIN	{"phone": "+70934983485"}
0005433753447	6830AE	2144 990136	NATALYA SOROKINA	{"email": "sorokina.natalya.09041966@postgrespro.ru", "phone": "+70785018782"}
0005433753448	6830AE	2440 405985	EVGENIY GRIGOREV	{"phone": "+70713547798"}
0005433753449	1F5ED7	8287 260544	VYACHESLAV MARTYNOV	{"phone": "+70675577826"}
0005433753450	D22D15	0319 561099	LARISA YAKOVLEVA	{"email": "l.yakovleva-1971@postgrespro.ru", "phone": "+70584799246"}
0005433753451	88C874	2477 528457	ALEKSEY MAKAROV	{"phone": "+70884583665"}
0005433753452	ADEB1A	9368 995022	ALLA DMITRIEVA	{"email": "dmitrieva.alla_1985@postgrespro.ru", "phone": "+70664269329"}
0005433753453	408D9D	7756 706664	ALEKSANDR KULIKOV	{"email": "a.kulikov-021967@postgrespro.ru", "phone": "+70103709881"}
0005433753454	408D9D	6799 720836	GALINA SCHERBAKOVA	{"phone": "+70782794024"}
0005433753455	53EA42	2369 864923	YURIY BORISOV	{"email": "borisov_yuriy-081968@postgrespro.ru", "phone": "+70001315994"}
0005433753456	C9CA08	0155 713827	DINA PAVLOVA	{"email": "d-pavlova-1971@postgrespro.ru", "phone": "+70393372275"}
0005433753457	C9CA08	2377 927289	STEPAN DAVYDOV	{"phone": "+70892928699"}
0005433753458	84E05D	8515 002980	ELENA NIKOLAEVA	{"phone": "+70141575902"}
0005433753459	84E05D	2356 979531	POLINA VLASOVA	{"phone": "+70763808096"}
0005433753460	0F62C5	7223 870249	TAMARA KRASNOVA	{"phone": "+70631845145"}
0005433753461	CA6B23	1239 110041	VALENTINA IVANOVA	{"phone": "+70258864883"}
0005433753462	F971E9	8247 430790	ALEKSANDR NAZAROV	{"email": "nazarov.a-1978@postgrespro.ru", "phone": "+70196969325"}
0005433753463	2838E6	5575 978858	RAISA OSIPOVA	{"phone": "+70537700203"}
0005433753464	2838E6	6462 196391	IRINA SAVELEVA	{"phone": "+70283208569"}
0005433753465	3AF458	7761 680395	ALEKSANDR ZAKHAROV	{"phone": "+70636306540"}
0005433753466	3AF458	1318 249766	NADEZHDA KOROLEVA	{"email": "nadezhda-koroleva_1974@postgrespro.ru", "phone": "+70699821272"}
0005433753467	CD7021	9194 953052	ILYA ZAYCEV	{"email": "zaycev-i-12071966@postgrespro.ru", "phone": "+70992820419"}
0005433753468	4DEA4B	9619 917421	IRINA IVANOVA	{"email": "ivanova_irina111972@postgrespro.ru", "phone": "+70783400381"}
0005433753469	4DEA4B	1407 383849	EVGENIY MAKAROV	{"phone": "+70465261936"}
0005433753470	2BDB98	1792 750154	ZINAIDA MIKHAYLOVA	{"email": "zinaida-mikhaylova.071968@postgrespro.ru", "phone": "+70325991610"}
0005433753471	4071B4	8321 556139	ANNA KOLESNIKOVA	{"phone": "+70613249850"}
0005433753472	768572	5300 920081	OLGA TIKHONOVA	{"phone": "+70851694566"}
0005433753473	768572	5323 767966	MAKSIM IVANOV	{"phone": "+70185119811"}
0005433753474	B667CE	1762 661936	OLGA NOVIKOVA	{"phone": "+70806743627"}
0005433753475	7822E6	8176 701243	MARIYA PETROVA	{"email": "petrovamariya.081970@postgrespro.ru", "phone": "+70361310922"}
0005433753476	A2E6A5	5790 013946	VLADIMIR ROMANOV	{"email": "romanov-vladimir-21091967@postgrespro.ru", "phone": "+70524795800"}
0005433753477	A2E6A5	3042 241184	ANDREY MATVEEV	{"phone": "+70429246828"}
0005433753478	0B7ABE	9594 661746	ALEKSANDRA KISELEVA	{"phone": "+70074359740"}
0005433753479	B5DA72	0285 036130	RUSLAN GERASIMOV	{"email": "ruslangerasimov-1984@postgrespro.ru", "phone": "+70033164081"}
0005433753480	8469CF	0103 767710	VLADIMIR MOROZOV	{"email": "morozov_vladimir-1981@postgrespro.ru", "phone": "+70503502875"}
0005433753481	8469CF	3077 930961	ASKHAT IVANOV	{"phone": "+70900492899"}
0005433753482	0E4D17	4418 654589	NADEZHDA BORISOVA	{"email": "nadezhda.borisova-051975@postgrespro.ru", "phone": "+70943194255"}
0005433753483	0A89B1	7622 243046	TATYANA SMIRNOVA	{"email": "t_smirnova021973@postgrespro.ru", "phone": "+70256434957"}
0005433753484	8935AB	1382 956232	ANATOLIY PAVLOV	{"email": "apavlov_1979@postgrespro.ru", "phone": "+70513574229"}
0005433753485	EBE994	5908 131784	VALERIY TIKHONOV	{"email": "valeriy_tikhonov021974@postgrespro.ru", "phone": "+70581341013"}
0005433753486	788238	1436 724871	VERA NESTEROVA	{"email": "v_nesterova031976@postgrespro.ru", "phone": "+70973081451"}
0005433753487	D9C2C7	8802 966779	ILONA MOROZOVA	{"email": "ilona-morozova.1980@postgrespro.ru", "phone": "+70359527393"}
0005433753488	ECCEF9	7997 025742	ARTEM ALEKSANDROV	{"email": "artem_aleksandrov-30121967@postgrespro.ru", "phone": "+70043824428"}
0005433753489	ECCEF9	0159 295764	NIKOLAY SCHERBAKOV	{"email": "scherbakovn.06021979@postgrespro.ru", "phone": "+70410069358"}
0005433753490	8EBFC3	7064 593434	VALERIYA NIKITINA	{"email": "nikitinav28031985@postgrespro.ru", "phone": "+70509192691"}
0005433753491	A1F0CD	3535 427268	ELENA MASLOVA	{"email": "elenamaslova-081976@postgrespro.ru", "phone": "+70459195053"}
0005433753492	A1F0CD	2511 833450	MARIYA ABRAMOVA	{"phone": "+70120848701"}
0005433753493	A1F0CD	8767 298149	GALINA ZHURAVLEVA	{"email": "zhuravleva.galina.1970@postgrespro.ru", "phone": "+70854771018"}
0005433753494	7C76B6	8898 330130	MARIYA NIKITINA	{"email": "mariya-nikitina-25051975@postgrespro.ru", "phone": "+70880391072"}
0005433753495	0BBD90	4391 671308	IVAN IVANOV	{"email": "ivanivanov_1973@postgrespro.ru", "phone": "+70792828528"}
0005433753496	0BBD90	7809 970894	MARIYA MOROZOVA	{"phone": "+70084730441"}
0005433753497	1997B2	9910 110869	ALLA STEPANOVA	{"email": "alla.stepanova-1959@postgrespro.ru", "phone": "+70554723629"}
0005433753498	015965	5611 674209	YURIY CHERNOV	{"email": "y_chernov-061970@postgrespro.ru", "phone": "+70202251634"}
0005433753499	7E25A4	3345 304887	TATYANA VOROBEVA	{"email": "t.vorobeva20091970@postgrespro.ru", "phone": "+70398723746"}
0005433753500	7E25A4	9797 181872	ANNA SMIRNOVA	{"email": "smirnova-anna_08071971@postgrespro.ru", "phone": "+70627397851"}
0005433753501	895849	7248 544877	ALEKSANDR VASILEV	{"phone": "+70213172177"}
0005433753502	14769C	4820 708468	DMITRIY KISELEV	{"phone": "+70565369461"}
0005433753503	C6A055	2249 120724	GENNADIY SIDOROV	{"email": "sidorov_gennadiy-021978@postgrespro.ru", "phone": "+70222023539"}
0005433753504	BCBEFD	5195 110540	DANIL GAVRILOV	{"email": "danil-gavrilov.10021969@postgrespro.ru", "phone": "+70608348615"}
0005433753505	3C6753	8678 452100	SERGEY BORISOV	{"phone": "+70221023189"}
0005433753506	126F5E	3111 625132	ALEKSANDR NIKITIN	{"phone": "+70642575450"}
0005433753507	DA046A	0208 570638	VERONIKA FOMINA	{"email": "veronika_fomina.091969@postgrespro.ru", "phone": "+70588087359"}
0005433753508	7BEA13	9186 799453	VLADLEN EGOROV	{"phone": "+70824612066"}
0005433753509	7BEA13	2969 102197	SERGEY SCHERBAKOV	{"email": "s-scherbakov-1969@postgrespro.ru", "phone": "+70953970152"}
0005433753510	A3BB35	5427 994466	VLADIMIR SAVELEV	{"email": "savelev_vladimir021976@postgrespro.ru", "phone": "+70399111282"}
0005433753511	D25794	0264 422285	ANASTASIYA FEDOROVA	{"phone": "+70123772609"}
0005433753512	DDCE72	7902 321334	NATALYA FROLOVA	{"email": "nfrolova_12081976@postgrespro.ru", "phone": "+70430914400"}
0005433753513	DDCE72	2554 555936	POLINA ZAKHAROVA	{"email": "polina.zakharova27021962@postgrespro.ru", "phone": "+70922086522"}
0005433753514	8394AD	0354 828806	EVGENIY VOLKOV	{"email": "volkov-evgeniy_27031966@postgrespro.ru", "phone": "+70963304320"}
0005433753515	8394AD	3391 460442	OLGA KOVALEVA	{"phone": "+70207697562"}
0005433753516	F806BD	4877 862870	IVAN GERASIMOV	{"email": "gerasimov_ivan-1975@postgrespro.ru", "phone": "+70992473860"}
0005433753517	88D51A	4214 927977	ALEKSANDRA MAKSIMOVA	{"phone": "+70559761817"}
0005433753518	342E04	6865 822986	ALEKSANDR MIKHAYLOV	{"phone": "+70915641364"}
0005433753519	342E04	8188 156610	DAVID ROMANOV	{"phone": "+70501464365"}
0005433753520	342E04	9049 640664	ARTEM IVANOV	{"email": "ivanovartem.13021970@postgrespro.ru", "phone": "+70826646336"}
0005433753521	8CD09C	0369 515067	IRINA KOZLOVA	{"phone": "+70535030364"}
0005433753522	8CD09C	0891 339550	ALEKSANDR BELOV	{"phone": "+70190257420"}
0005433753523	0D732D	5518 203445	GALINA BELYAEVA	{"phone": "+70262063293"}
0005433753524	002289	4454 198020	GALINA KUZNECOVA	{"email": "kuznecovag_1976@postgrespro.ru", "phone": "+70161755127"}
0005433753525	664F8C	5762 903678	NIKOLAY ABRAMOV	{"phone": "+70540647430"}
0005433753526	664F8C	6604 632664	GENNADIY DAVYDOV	{"email": "davydovgennadiy.101960@postgrespro.ru", "phone": "+70267349664"}
0005433753527	6A4EB5	4822 552456	MAKSIM NOVIKOV	{"phone": "+70709175582"}
0005433753528	6A4EB5	1696 209475	IGOR IVANOV	{"phone": "+70329942622"}
0005433753529	717387	9012 868125	NIKITA ZHUKOV	{"email": "zhukov-nikita-011967@postgrespro.ru", "phone": "+70328089739"}
0005433753530	D47E33	7892 136319	TATYANA DMITRIEVA	{"phone": "+70135884597"}
0005433753531	D47E33	0576 701747	TATYANA PAVLOVA	{"email": "t-pavlova.1969@postgrespro.ru", "phone": "+70599442318"}
0005433753532	BCCE2E	3382 819700	SVETLANA NOVIKOVA	{"email": "novikova-s-1974@postgrespro.ru", "phone": "+70770680611"}
0005433753533	65DDD0	9305 577711	DARYA KARPOVA	{"email": "daryakarpova-28011963@postgrespro.ru", "phone": "+70313104020"}
0005433753534	BD3150	9034 728922	ALEKSANDR BARANOV	{"email": "aleksandr-baranov-24021963@postgrespro.ru", "phone": "+70712663518"}
0005433753535	F339FC	2880 099100	ALEKSEY MOROZOV	{"email": "aleksey_morozov-061973@postgrespro.ru", "phone": "+70926428276"}
0005433753536	2FA6D8	2166 323215	VENIAMIN SERGEEV	{"email": "v-sergeev-20081966@postgrespro.ru", "phone": "+70363673867"}
0005433753537	8A6764	6385 315092	ROZA MIKHAYLOVA	{"email": "rozamikhaylova_14011962@postgrespro.ru", "phone": "+70312312240"}
0005433753538	8A6764	8839 117134	ZHANNA YAKOVLEVA	{"phone": "+70904212235"}
0005433753539	1299F2	3558 936324	NATALYA TROFIMOVA	{"email": "trofimova.n.081960@postgrespro.ru", "phone": "+70722120135"}
0005433753540	E10F4A	4965 398931	SNEZHANA MAKSIMOVA	{"phone": "+70883654283"}
0005433753541	E0B322	1830 748596	IRINA VOROBEVA	{"phone": "+70740888109"}
0005433753542	B8644C	7350 563325	NIKOLAY RODIONOV	{"phone": "+70991600257"}
0005433753543	B8644C	8387 919414	KRISTINA POPOVA	{"phone": "+70634028908"}
0005433753544	1D8956	8805 383836	ANDREY CHERNOV	{"phone": "+70273989907"}
0005433753545	A8A973	1751 450087	SVETLANA DANILOVA	{"phone": "+70707978122"}
0005433753546	39F68C	7615 965327	NATALYA KOROLEVA	{"phone": "+70124046209"}
0005433753547	B153DC	4550 992637	FEDOR SCHERBAKOV	{"email": "f.scherbakov-1981@postgrespro.ru", "phone": "+70113576685"}
0005433753548	248366	1175 022502	GALINA PETROVA	{"phone": "+70811506915"}
0005433753549	887110	5807 273909	OKSANA POTAPOVA	{"phone": "+70647852369"}
0005433753550	887110	9137 188493	SOFYA KONOVALOVA	{"email": "sofya-konovalova19041970@postgrespro.ru", "phone": "+70966914495"}
0005433753551	A73FE5	1754 646680	ELENA ERMAKOVA	{"phone": "+70323677188"}
0005433753552	3A39D7	9539 475407	OLGA CHERNOVA	{"email": "olga_chernova_1978@postgrespro.ru", "phone": "+70255073884"}
0005433753553	3A39D7	5886 918660	MARIYA ZAYCEVA	{"phone": "+70513753798"}
0005433753554	90B9C9	1827 630825	VLADIMIR PETROV	{"email": "vladimir.petrov061978@postgrespro.ru", "phone": "+70240802559"}
0005433753555	E3BC9F	6726 266006	NADEZHDA MALYSHEVA	{"phone": "+70686853285"}
0005433753556	E3BC9F	4314 820540	DENIS GAVRILOV	{"email": "gavrilov.d15121967@postgrespro.ru", "phone": "+70183401919"}
0005433753557	586804	8887 975070	PETR GERASIMOV	{"email": "pgerasimov-1960@postgrespro.ru", "phone": "+70282262748"}
0005433753558	AD37D1	1193 401765	ANTONINA KISELEVA	{"phone": "+70519274413"}
0005433753559	AB1ECD	2063 576844	KONSTANTIN KRASNOV	{"email": "krasnov.konstantin.081968@postgrespro.ru", "phone": "+70421229098"}
0005433753560	A7C290	2500 253156	KONSTANTIN FEDOTOV	{"phone": "+70884765958"}
0005433753561	C944D5	1769 687106	SVETLANA ERMAKOVA	{"email": "s.ermakova1978@postgrespro.ru", "phone": "+70372524045"}
0005433753562	C944D5	5735 117189	ELENA KRASNOVA	{"phone": "+70087066986"}
0005433753563	EF71AC	7157 514115	ARSENIY ALEKSEEV	{"email": "a_alekseev.051967@postgrespro.ru", "phone": "+70214349556"}
0005433753564	EF71AC	0060 983195	MARINA NIKOLAEVA	{"phone": "+70521698023"}
0005433753565	237B50	5566 211868	ASKHAT FOMIN	{"email": "a_fomin09091955@postgrespro.ru", "phone": "+70360594580"}
0005433753566	BFA812	5097 524372	ANASTASIYA NESTEROVA	{"email": "nesterovaa-021966@postgrespro.ru", "phone": "+70708906568"}
0005433753567	BFA812	1120 136106	NIKOLAY POPOV	{"email": "nikolay-popov_1958@postgrespro.ru", "phone": "+70032131223"}
0005433753568	D2F057	6230 146146	KSENIYA FROLOVA	{"email": "frolova_kseniya09031971@postgrespro.ru", "phone": "+70638829746"}
0005433753569	702C0E	7665 121282	ELENA SIDOROVA	{"phone": "+70009145003"}
0005433753570	8053DB	0839 189970	INNA PETROVA	{"phone": "+70455439870"}
0005433753571	CBC189	2160 174610	PETR KULIKOV	{"phone": "+70277299933"}
0005433753572	59442A	7834 788536	TATYANA MASLOVA	{"email": "maslovatatyana-1974@postgrespro.ru", "phone": "+70576301698"}
0005433753573	9A9C70	0716 432025	VITALIY POPOV	{"email": "v-popov01031968@postgrespro.ru", "phone": "+70120800513"}
0005433753574	9A9C70	8143 089435	MARIYA POLYAKOVA	{"email": "mariya_polyakova-031978@postgrespro.ru", "phone": "+70864662157"}
0005433753575	4C1400	5390 710923	YURIY PETROV	{"email": "petrov_yuriy031975@postgrespro.ru", "phone": "+70172643423"}
0005433753576	4C1400	9143 991004	TATYANA ILINA	{"email": "ilinatatyana.061973@postgrespro.ru", "phone": "+70178009539"}
0005433753577	4C1400	3828 812311	TATYANA POLYAKOVA	{"phone": "+70271394484"}
0005433753578	05F158	9816 605334	NIKOLAY VLASOV	{"email": "nikolayvlasov.1965@postgrespro.ru", "phone": "+70545339275"}
0005433753579	16D720	0579 662675	LYUDMILA KULIKOVA	{"email": "kulikova_l_19031975@postgrespro.ru", "phone": "+70287049828"}
0005433753580	4DD418	0627 956046	YURIY ZAYCEV	{"email": "zaycev_y.051986@postgrespro.ru", "phone": "+70970254044"}
0005433753581	281E9F	2491 327472	EVGENIY ALEKSEEV	{"email": "e.alekseev.081971@postgrespro.ru", "phone": "+70268233860"}
0005433753582	281E9F	8786 501961	FARID VASILEV	{"phone": "+70439877710"}
0005433753583	A2BEC0	8316 927267	ELENA PAVLOVA	{"phone": "+70051078133"}
0005433753584	D5DEF1	0282 382180	GALINA NAZAROVA	{"email": "galina_nazarova-031970@postgrespro.ru", "phone": "+70965401022"}
0005433753585	D5DEF1	9823 827093	VALERIY KUZNECOV	{"email": "vkuznecov_08091974@postgrespro.ru", "phone": "+70498775344"}
0005433753697	B34A1B	1119 137451	NINA GERASIMOVA	{"phone": "+70383201377"}
0005433753586	7C042C	2076 563494	VIOLETTA STEPANOVA	{"email": "stepanova_violetta-08101956@postgrespro.ru", "phone": "+70539925285"}
0005433753587	7C042C	8394 022781	ANZHELIKA KUZNECOVA	{"email": "a_kuznecova.1962@postgrespro.ru", "phone": "+70045438666"}
0005433753588	1249A0	1296 441696	GRIGORIY VLASOV	{"email": "vlasov.grigoriy-29101962@postgrespro.ru", "phone": "+70236183348"}
0005433753589	64E7EC	5146 409195	ANDREY IVANOV	{"phone": "+70566313981"}
0005433753590	5D7E7D	6996 602551	KONSTANTIN MIKHAYLOV	{"email": "k-mikhaylov.31051968@postgrespro.ru", "phone": "+70032155708"}
0005433753591	CB1719	8265 809732	TATYANA PETROVA	{"phone": "+70204288641"}
0005433753592	CB1719	3412 431841	VYACHESLAV SAVELEV	{"phone": "+70838171891"}
0005433753593	9E87B1	9346 570684	OLGA IVANOVA	{"email": "olgaivanova.13061978@postgrespro.ru", "phone": "+70297723721"}
0005433753594	9E87B1	2434 938490	DENIS KUZNECOV	{"email": "d.kuznecov1962@postgrespro.ru", "phone": "+70149065086"}
0005433753595	112755	9670 241677	MARINA LAZAREVA	{"email": "lazarevam17121968@postgrespro.ru", "phone": "+70306302999"}
0005433753596	112755	0421 263498	SVETLANA KUDRYASHOVA	{"email": "svetlana-kudryashova031977@postgrespro.ru", "phone": "+70028406381"}
0005433753597	112755	1336 988008	BORIS SOROKIN	{"email": "boris-sorokin-1979@postgrespro.ru", "phone": "+70024076795"}
0005433753598	DBAEFE	7460 529160	MARINA PETROVA	{"email": "petrova.marina1987@postgrespro.ru", "phone": "+70483596262"}
0005433753599	B2B575	3499 868589	GALINA KUZNECOVA	{"phone": "+70736622026"}
0005433753600	115DF9	8862 617536	TATYANA DENISOVA	{"phone": "+70712987544"}
0005433753601	DDB309	9685 164445	OLGA MAKAROVA	{"email": "makarova.olga1964@postgrespro.ru", "phone": "+70091968130"}
0005433753602	8AF4FF	3891 944095	RAISA MAKSIMOVA	{"email": "maksimova.raisa-1966@postgrespro.ru", "phone": "+70397003358"}
0005433753603	EE0C86	0511 153779	PAVEL PETROV	{"email": "petrov.p19021967@postgrespro.ru", "phone": "+70142509612"}
0005433753604	D4516F	4812 918071	ELEONORA VOLKOVA	{"email": "e.volkova-1969@postgrespro.ru", "phone": "+70524152024"}
0005433753605	E7FFF7	8506 806019	NIKITA NIKITIN	{"phone": "+70753532281"}
0005433753606	E7FFF7	4097 522748	VALENTINA EGOROVA	{"phone": "+70436414826"}
0005433753607	252847	5757 623414	IRINA IVANOVA	{"email": "i.ivanova-20101970@postgrespro.ru", "phone": "+70435656840"}
0005433753608	252847	3377 274426	DARYA FADEEVA	{"email": "daryafadeeva-1983@postgrespro.ru", "phone": "+70961687789"}
0005433753609	8E1539	3265 496797	DARYA BORISOVA	{"phone": "+70008298749"}
0005433753610	D4FE61	9667 371619	LIDIYA KUZMINA	{"email": "kuzminalidiya_1974@postgrespro.ru", "phone": "+70287700755"}
0005433753611	7BC6B7	0298 669306	TATYANA ANDREEVA	{"email": "tatyana.andreeva1971@postgrespro.ru", "phone": "+70222323423"}
0005433753612	6E2111	3619 153601	NATALYA SOROKINA	{"phone": "+70180975257"}
0005433753613	6E2111	8844 515014	YANA GAVRILOVA	{"email": "y-gavrilova-24021980@postgrespro.ru", "phone": "+70058131452"}
0005433753614	5F1F86	7428 739115	NATALYA DMITRIEVA	{"email": "dmitrieva.n051965@postgrespro.ru", "phone": "+70265978854"}
0005433753615	2F360E	7005 572114	ALENA MAKAROVA	{"phone": "+70682105942"}
0005433753616	6C4400	2994 968721	NINA MAKAROVA	{"phone": "+70889349210"}
0005433753617	6C4400	8958 243092	ANNA IVANOVA	{"phone": "+70738443561"}
0005433753618	AF51E7	5819 918305	LYUBOV KISELEVA	{"phone": "+70210317729"}
0005433753619	890A47	7698 012049	VLADIMIR ZAKHAROV	{"email": "zakharov-v27061987@postgrespro.ru", "phone": "+70716558992"}
0005433753620	81B95F	0285 004305	SVETLANA NIKOLAEVA	{"phone": "+70676967370"}
0005433753621	991FBE	5203 497383	TATYANA LUKYANOVA	{"phone": "+70672895107"}
0005433753622	B49B8E	0008 201300	VADIM AFANASEV	{"phone": "+70346260277"}
0005433753623	07F13D	4448 862711	NADEZHDA SMIRNOVA	{"phone": "+70830960466"}
0005433753624	2FD731	5340 983172	LYUDMILA RODIONOVA	{"phone": "+70462347733"}
0005433753625	DD1FE3	0893 165037	IGOR BELOV	{"email": "ibelov_08011979@postgrespro.ru", "phone": "+70166664144"}
0005433753626	FDAE8A	5286 395427	DANILA ABRAMOV	{"email": "abramovdanila.081968@postgrespro.ru", "phone": "+70075729947"}
0005433753627	FDAE8A	8937 732591	ELMIRA KARPOVA	{"phone": "+70642044990"}
0005433753628	FDAE8A	2506 673109	NIKOLAY VASILEV	{"email": "vasilev.nikolay.27101955@postgrespro.ru", "phone": "+70702984132"}
0005433753629	BCF39A	0326 021108	MIKHAIL ZHURAVLEV	{"email": "zhuravlev-mikhail.03101975@postgrespro.ru", "phone": "+70845542469"}
0005433753630	BCF39A	8693 772948	ALEKSANDR SERGEEV	{"phone": "+70526930327"}
0005433753631	078117	1534 253531	ANTONINA ABRAMOVA	{"phone": "+70253038492"}
0005433753632	3F35EA	7802 707805	LIDIYA POLYAKOVA	{"email": "lpolyakova.071975@postgrespro.ru", "phone": "+70905719054"}
0005433753633	A0ED3F	4370 040357	GRIGORIY MEDVEDEV	{"phone": "+70923358901"}
0005433753634	7B04CF	6424 927623	ALEKSANDR NOVIKOV	{"email": "novikov_a1972@postgrespro.ru", "phone": "+70612048537"}
0005433753635	7B04CF	9423 851532	NINA CHERNOVA	{"email": "nina.chernova_1973@postgrespro.ru", "phone": "+70286663057"}
0005433753636	1150F8	8637 034669	VERA ERMAKOVA	{"email": "v-ermakova1982@postgrespro.ru", "phone": "+70940624798"}
0005433753637	C1896A	7492 800198	SERGEY IVANOV	{"phone": "+70719166076"}
0005433753638	4EC8CE	0190 395372	NIKOLAY POPOV	{"phone": "+70963450850"}
0005433753639	ECD1F4	2248 629455	ALEKSANDR DAVYDOV	{"phone": "+70313180604"}
0005433753640	B829D8	2574 983357	EKATERINA FOMINA	{"email": "ekaterina-fomina_1985@postgrespro.ru", "phone": "+70232159676"}
0005433753641	C27E36	3438 521901	VITALIY DENISOV	{"email": "v-denisov-05091963@postgrespro.ru", "phone": "+70149419952"}
0005433753642	C27E36	2905 006380	VLADIMIR KRASNOV	{"email": "krasnovvladimir_1974@postgrespro.ru", "phone": "+70999965029"}
0005433753643	C5F5D0	8324 988680	LYUBOV MAKAROVA	{"email": "makarova-lyubov_041976@postgrespro.ru", "phone": "+70645002633"}
0005433753644	4D27B7	8152 802480	OLGA NIKOLAEVA	{"email": "o_nikolaeva1965@postgrespro.ru", "phone": "+70101298467"}
0005433753645	025295	1381 493774	TATYANA KISELEVA	{"phone": "+70525897388"}
0005433753646	6C11D0	6254 879587	IVAN PAVLOV	{"email": "i-pavlov-021972@postgrespro.ru", "phone": "+70075501067"}
0005433753647	6C11D0	1859 877806	ELENA RODIONOVA	{"phone": "+70503254242"}
0005433753648	6C11D0	1998 176919	OLGA BARANOVA	{"email": "o_baranova1962@postgrespro.ru", "phone": "+70204054799"}
0005433753649	5BA715	6518 065636	VASILIY SEMENOV	{"email": "v.semenov1968@postgrespro.ru", "phone": "+70814324638"}
0005433753650	620CBD	2431 802587	DARYA ZHURAVLEVA	{"email": "zhuravlevadarya011971@postgrespro.ru", "phone": "+70540830637"}
0005433753651	5BDA2D	8171 536628	MARIYA SMIRNOVA	{"phone": "+70592455474"}
0005433753652	96BE08	2052 456946	ANTONINA KUZNECOVA	{"email": "a_kuznecova14011967@postgrespro.ru", "phone": "+70225863106"}
0005433753653	9C02B5	5307 673264	VLADIMIR KUZNECOV	{"email": "kuznecov-v_091972@postgrespro.ru", "phone": "+70929289571"}
0005433753654	9C02B5	9878 920418	SERGEY GORBUNOV	{"email": "s_gorbunov03081979@postgrespro.ru", "phone": "+70980966175"}
0005433753655	4C7185	6410 074543	ANASTASIYA TIMOFEEVA	{"phone": "+70011929671"}
0005433753656	0AAC1A	9289 349083	OLGA AKIMOVA	{"phone": "+70504585509"}
0005433753657	0AAC1A	0465 156187	VIKTORIYA SCHERBAKOVA	{"phone": "+70207711432"}
0005433753658	0AAC1A	6517 596044	STANISLAV BELOV	{"email": "belov_stanislav10061969@postgrespro.ru", "phone": "+70951088303"}
0005433753659	76BAA0	2652 740664	SVETLANA POPOVA	{"email": "s.popova.21091964@postgrespro.ru", "phone": "+70379184397"}
0005433753660	5D3E65	3749 256899	RUMIYA ZHUKOVA	{"phone": "+70609801211"}
0005433753661	51143E	7679 134480	LARISA NESTEROVA	{"email": "l-nesterova_111978@postgrespro.ru", "phone": "+70020056955"}
0005433753662	25E351	2190 450758	GALINA YUDINA	{"phone": "+70308639037"}
0005433753663	8CA7CB	4135 817822	SERGEY KULIKOV	{"email": "sergeykulikov-021983@postgrespro.ru", "phone": "+70444185202"}
0005433753664	6B999C	5170 940748	TATYANA KALININA	{"phone": "+70747393289"}
0005433753665	01936B	7518 004488	NATALYA ROMANOVA	{"phone": "+70132696464"}
0005433753666	01936B	4410 086189	RAISA OVCHINNIKOVA	{"email": "r-ovchinnikova1961@postgrespro.ru", "phone": "+70108569091"}
0005433753667	FAC725	4076 196710	MARINA NOVIKOVA	{"email": "m.novikova.23081979@postgrespro.ru", "phone": "+70505798011"}
0005433753668	C5449D	4121 008056	NADEZHDA SIDOROVA	{"email": "sidorova.n_1981@postgrespro.ru", "phone": "+70565468041"}
0005433753669	7BAB50	7102 145117	NATALYA KOVALEVA	{"email": "natalya_kovaleva-011966@postgrespro.ru", "phone": "+70732784018"}
0005433753670	274FC9	2982 952380	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr.1971@postgrespro.ru", "phone": "+70544951506"}
0005433753671	E64CF5	7167 069246	EVGENIYA MAKSIMOVA	{"email": "maksimova.e091971@postgrespro.ru", "phone": "+70359271185"}
0005433753672	8C640D	0018 978923	ALEKSEY MOISEEV	{"email": "aleksey.moiseev_1976@postgrespro.ru", "phone": "+70470037108"}
0005433753673	CA8BD4	6761 262305	ELIZAVETA SOKOLOVA	{"email": "sokolovae.10031966@postgrespro.ru", "phone": "+70198895095"}
0005433753674	9441F5	1845 408385	OKSANA MOISEEVA	{"email": "moiseeva.oksana.21081974@postgrespro.ru", "phone": "+70472416609"}
0005433753675	9441F5	9710 359970	SVETLANA BORISOVA	{"phone": "+70273799616"}
0005433753676	87A9FC	5362 594995	NATALYA SEMENOVA	{"phone": "+70129995912"}
0005433753677	503864	9587 159541	ELENA OSIPOVA	{"phone": "+70311089206"}
0005433753678	298945	3402 563193	ANDREY IVANOV	{"email": "andrey_ivanov.1970@postgrespro.ru", "phone": "+70598427057"}
0005433753679	298945	0406 220536	DMITRIY IVANOV	{"phone": "+70733440695"}
0005433753680	309B48	9471 627480	NINA ROMANOVA	{"phone": "+70746513182"}
0005433753681	19F9A0	4740 520466	DARYA VOLKOVA	{"email": "darya.volkova_18041971@postgrespro.ru", "phone": "+70261384860"}
0005433753682	251F4B	9656 182637	VLADIMIR DENISOV	{"email": "denisov_v_081979@postgrespro.ru", "phone": "+70802982443"}
0005433753683	E8EA74	8967 030669	ALEKSEY SEMENOV	{"phone": "+70559602649"}
0005433753684	E8EA74	6935 788347	ROZA DAVYDOVA	{"email": "davydovaroza_07031973@postgrespro.ru", "phone": "+70257951195"}
0005433753685	877D0F	8640 029008	GEORGIY KAZAKOV	{"email": "kazakov_g061963@postgrespro.ru", "phone": "+70257156551"}
0005433753686	877D0F	6564 794659	ALEKSANDR MAKAROV	{"phone": "+70101789042"}
0005433753687	7FF8E8	8295 119647	MARINA SMIRNOVA	{"email": "m_smirnova1959@postgrespro.ru", "phone": "+70760338708"}
0005433753688	C0788B	1148 792739	ANNA MARTYNOVA	{"phone": "+70931414688"}
0005433753689	C0788B	7880 976317	ALEKSANDRA NIKITINA	{"email": "nikitinaaleksandra-1963@postgrespro.ru", "phone": "+70958198089"}
0005433753690	D2D339	2137 577070	VLADIMIR PETROV	{"phone": "+70456974018"}
0005433753691	91E6B6	7504 638648	ANNA GERASIMOVA	{"email": "gerasimova_anna.07091966@postgrespro.ru", "phone": "+70608141115"}
0005433753692	91E6B6	0539 025817	LARISA KUDRYASHOVA	{"email": "kudryashova.larisa-1971@postgrespro.ru", "phone": "+70177099909"}
0005433753693	2488E0	8858 614958	VLADIMIR KARPOV	{"email": "karpovvladimir.1968@postgrespro.ru", "phone": "+70863788392"}
0005433753694	2488E0	7141 351613	ZINAIDA ROMANOVA	{"email": "romanovazinaida1969@postgrespro.ru", "phone": "+70842201499"}
0005433753695	B34A1B	2896 144957	ALEKSANDR SMIRNOV	{"email": "smirnova_071979@postgrespro.ru", "phone": "+70128069954"}
0005433753696	B34A1B	0202 863000	IRINA SEMENOVA	{"phone": "+70145132661"}
0005433753698	C9B211	1709 440093	ANGELINA TIKHONOVA	{"email": "angelina_tikhonova.061973@postgrespro.ru", "phone": "+70814130506"}
0005433753699	74C50F	1139 952008	RUSTEM STEPANOV	{"phone": "+70654286070"}
0005433753700	74C50F	9271 629681	NIKOLAY VASILEV	{"email": "nikolayvasilev11031975@postgrespro.ru", "phone": "+70217237284"}
0005433753701	73E688	9287 834337	ANDREY BELOV	{"email": "abelov-061982@postgrespro.ru", "phone": "+70237266084"}
0005433753702	73E688	5886 039283	PAVEL KOZLOV	{"email": "pavel_kozlov-04101974@postgrespro.ru", "phone": "+70056186519"}
0005433753703	7199FD	5769 197823	YULIYA BELYAEVA	{"email": "ybelyaeva-1966@postgrespro.ru", "phone": "+70039417037"}
0005433753704	7199FD	1609 737937	EVDOKIYA FILATOVA	{"email": "e.filatova-031970@postgrespro.ru", "phone": "+70766549921"}
0005433753705	7199FD	6409 540080	ZOYA FILATOVA	{"email": "zfilatova_051955@postgrespro.ru", "phone": "+70428485132"}
0005433753706	7199FD	8712 892944	VLADIMIR MEDVEDEV	{"phone": "+70708846460"}
0005433753707	755C62	9870 888326	ANDREY MAKAROV	{"phone": "+70640372957"}
0005433753708	FB0B98	4084 323855	IRINA EGOROVA	{"phone": "+70915517331"}
0005433753709	FB0B98	2387 942771	SVETLANA FEDOROVA	{"phone": "+70370284511"}
0005433753710	290888	0193 600548	ZOYA ANDREEVA	{"phone": "+70934829451"}
0005433753711	0D9B6B	0422 899025	DENIS VOROBEV	{"email": "vorobevd-101969@postgrespro.ru", "phone": "+70867288177"}
0005433753712	6BAF15	5562 517888	VALERIY NOVIKOV	{"email": "valeriy.novikov-1977@postgrespro.ru", "phone": "+70434937978"}
0005433753713	5B8802	2476 490475	LILIYA YAKOVLEVA	{"phone": "+70449899024"}
0005433753714	5B8802	6504 841055	NATALYA IVANOVA	{"phone": "+70181705016"}
0005433753715	ECF00E	2431 719814	VALENTINA KOZLOVA	{"phone": "+70630742163"}
0005433753716	0D6324	2273 438561	VIKTOR VOROBEV	{"email": "vorobev_v_091970@postgrespro.ru", "phone": "+70199478146"}
0005433753717	0D6324	8338 292136	VYACHESLAV SERGEEV	{"email": "v_sergeev_061962@postgrespro.ru", "phone": "+70255028153"}
0005433753718	5FC30D	6114 231838	IVAN BORISOV	{"email": "ivan-borisov_23021968@postgrespro.ru", "phone": "+70006078136"}
0005433753719	5FC30D	5925 425609	ANTON MAKSIMOV	{"email": "maksimov_anton_041987@postgrespro.ru", "phone": "+70169951426"}
0005433753720	012D00	1769 578417	IGOR KUZNECOV	{"phone": "+70539284999"}
0005433753721	39E85E	7760 711353	ANATOLIY ANDREEV	{"email": "andreev-anatoliy-1978@postgrespro.ru", "phone": "+70050081928"}
0005433753722	0648FF	0260 173708	VYACHESLAV SOKOLOV	{"phone": "+70242513371"}
0005433753723	6C2BEE	8936 368557	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr.101970@postgrespro.ru", "phone": "+70367175060"}
0005433753724	C8C336	4111 690715	NADEZHDA ZAKHAROVA	{"email": "zakharova_n-1975@postgrespro.ru", "phone": "+70767967739"}
0005433753725	61C940	4648 736421	DANIIL ORLOV	{"email": "orlov.d031970@postgrespro.ru", "phone": "+70249975449"}
0005433753726	0E25B5	0186 582472	VLADIMIR ZHUKOV	{"email": "vladimirzhukov-1971@postgrespro.ru", "phone": "+70648762542"}
0005433753727	FC07F2	7394 018511	TATYANA SERGEEVA	{"phone": "+70312964954"}
0005433753728	AA41CE	8141 467778	VYACHESLAV ISAEV	{"email": "vyacheslav_isaev041963@postgrespro.ru", "phone": "+70594159117"}
0005433753729	4C3BB9	1551 616494	ELENA ANISIMOVA	{"email": "eanisimova-031970@postgrespro.ru", "phone": "+70301341861"}
0005433753730	B29168	8708 141654	DIANA FILIPPOVA	{"email": "filippova_d_13071966@postgrespro.ru", "phone": "+70326724587"}
0005433753731	229CFA	5740 924567	RUSTEM DENISOV	{"email": "rustem-denisov31051974@postgrespro.ru", "phone": "+70763172898"}
0005433753732	229CFA	1351 767705	TATYANA DMITRIEVA	{"phone": "+70892988711"}
0005433753733	37B6FF	3220 275269	RUSLAN SEMENOV	{"phone": "+70606642845"}
0005433753734	6CE9E5	7066 789804	OLEG IVANOV	{"email": "o-ivanov051987@postgrespro.ru", "phone": "+70920341573"}
0005433753735	7C9F55	5222 938523	LIDIYA TIKHONOVA	{"email": "lidiyatikhonova-1968@postgrespro.ru", "phone": "+70172908771"}
0005433753736	608027	8888 172025	ANATOLIY PETROV	{"email": "apetrov.10121967@postgrespro.ru", "phone": "+70575456202"}
0005433753737	972CA1	1900 162242	RUSLAN ILIN	{"email": "rilin_28101971@postgrespro.ru", "phone": "+70132878692"}
0005433753738	972CA1	3128 617381	NINA CHERNOVA	{"email": "n-chernova.1971@postgrespro.ru", "phone": "+70537989723"}
0005433753739	9D4E6E	4803 107742	TIMOFEY SAVELEV	{"phone": "+70911862128"}
0005433753740	9D4E6E	2549 396518	VALENTINA KUZNECOVA	{"phone": "+70775294649"}
0005433753741	B50C2C	3106 180345	VALERIY BONDARENKO	{"phone": "+70264299903"}
0005433753742	B50C2C	4180 615231	VLADIMIR DENISOV	{"email": "denisov_v041976@postgrespro.ru", "phone": "+70834513801"}
0005433753743	00EF72	2146 929085	TATYANA BOGDANOVA	{"phone": "+70251772013"}
0005433753744	00EF72	6601 571720	NIKOLAY DAVYDOV	{"phone": "+70604344901"}
0005433753745	2CA9BB	8758 812179	VIKTOR MARTYNOV	{"email": "martynov_v.1967@postgrespro.ru", "phone": "+70373104722"}
0005433753746	1EF8D1	9180 471495	IVAN VOLKOV	{"phone": "+70487541034"}
0005433753747	1EF8D1	0555 704306	ALEKSANDR STEPANOV	{"phone": "+70040507605"}
0005433753748	BE2840	6703 957760	ALEKSANDR PETROV	{"phone": "+70924621547"}
0005433753749	BE2840	2847 737340	EVGENIY PAVLOV	{"email": "evgeniy_pavlov_07101980@postgrespro.ru", "phone": "+70334452221"}
0005433753750	B9E2F0	0970 280498	LIDIYA NAUMOVA	{"email": "l-naumova.1965@postgrespro.ru", "phone": "+70391854704"}
0005433753751	8D0DF0	3357 794377	SERGEY PETROV	{"email": "sergey-petrov.1963@postgrespro.ru", "phone": "+70501572982"}
0005433753752	8D0DF0	0649 094039	ANATOLIY KOZLOV	{"phone": "+70984827599"}
0005433753753	9FFA54	5853 368238	TATYANA OVCHINNIKOVA	{"phone": "+70218585141"}
0005433753754	9BC56A	8028 515185	ANNA FROLOVA	{"email": "frolova.a-1963@postgrespro.ru", "phone": "+70027087440"}
0005433753755	9BC56A	4323 515239	LYUDMILA DMITRIEVA	{"phone": "+70439473091"}
0005433753756	3E0C1E	0177 516286	YURIY CHERNOV	{"phone": "+70787503803"}
0005433753757	EDE229	4936 899968	IRINA YAKOVLEVA	{"phone": "+70600105856"}
0005433753758	C0C504	7935 584502	DMITRIY VASILEV	{"email": "dmitriy-vasilev.041972@postgrespro.ru", "phone": "+70150375915"}
0005433753759	B69631	1030 170816	ALENA KOZLOVA	{"email": "kozlova_alena-031978@postgrespro.ru", "phone": "+70888779040"}
0005433753760	D05C40	2845 604548	GRIGORIY GAVRILOV	{"email": "gavrilov.grigoriy.25041974@postgrespro.ru", "phone": "+70812325100"}
0005433753761	D05C40	6538 189310	ZINAIDA VOLKOVA	{"email": "zvolkova_30071967@postgrespro.ru", "phone": "+70080466953"}
0005433753762	05C3F5	4768 097945	DMITRIY VOROBEV	{"email": "vorobev.d.021976@postgrespro.ru", "phone": "+70814381511"}
0005433753763	32B83E	2114 466670	OLGA KONDRATEVA	{"email": "kondrateva_o_1957@postgrespro.ru", "phone": "+70244805340"}
0005433753764	90195A	6388 348611	EVGENIYA SAVELEVA	{"email": "savelevae-031979@postgrespro.ru", "phone": "+70412270318"}
0005433753765	1B8094	5823 820677	IVAN BONDARENKO	{"phone": "+70136293746"}
0005433753766	1B8094	7720 400266	ANTON POPOV	{"email": "popov-anton1978@postgrespro.ru", "phone": "+70089041985"}
0005433753767	1B8094	4149 027195	VALENTINA IVANOVA	{"email": "v_ivanova_031972@postgrespro.ru", "phone": "+70914145554"}
0005433753768	A85479	7600 799278	EVGENIY KAZAKOV	{"phone": "+70713242811"}
0005433753769	A85479	8578 623090	VALENTINA SCHERBAKOVA	{"email": "valentina_scherbakova-31051970@postgrespro.ru", "phone": "+70576726227"}
0005433753770	580FC0	2809 626429	VALENTINA EFREMOVA	{"phone": "+70814129665"}
0005433753771	60EC25	2512 927905	ANASTASIYA KUDRYASHOVA	{"email": "anastasiya.kudryashova031984@postgrespro.ru", "phone": "+70739743482"}
0005433753772	5674EE	8049 396847	NIKOLAY SOKOLOV	{"phone": "+70220641077"}
0005433753773	8E9BCB	1803 496472	SOFYA ZAKHAROVA	{"phone": "+70207328025"}
0005433753774	23102E	6611 200657	LYUDMILA TIMOFEEVA	{"phone": "+70810758697"}
0005433753775	2B3976	7497 957698	MIKHAIL KUZMIN	{"email": "mkuzmin.1966@postgrespro.ru", "phone": "+70156794151"}
0005433753776	2B3976	7511 835167	IGOR ZAYCEV	{"email": "i-zaycev13091977@postgrespro.ru", "phone": "+70726332753"}
0005433753777	978F5B	4913 567210	ANDREY ZAYCEV	{"email": "zaycevandrey_11041975@postgrespro.ru", "phone": "+70493075619"}
0005433753778	CC1AAB	2770 147472	DARYA MAKSIMOVA	{"email": "maksimova_d_1954@postgrespro.ru", "phone": "+70940090055"}
0005433753779	CC1AAB	7099 407719	VARVARA LUKYANOVA	{"phone": "+70525494293"}
0005433753780	707613	1061 087134	ANDREY VASILEV	{"phone": "+70648793475"}
0005433753781	E32882	3533 734598	ANASTASIYA YAKOVLEVA	{"email": "yakovleva-a-17121963@postgrespro.ru", "phone": "+70075411017"}
0005433753782	E32882	9466 145533	TATYANA ZAKHAROVA	{"email": "zakharovatatyana.08111972@postgrespro.ru", "phone": "+70058739417"}
0005433753783	330A83	9639 565727	DMITRIY IVANOV	{"phone": "+70616765447"}
0005433753784	330A83	9059 368765	TATYANA POPOVA	{"phone": "+70953978538"}
0005433753785	4CE4AF	0824 638110	SVETLANA CHERNOVA	{"email": "svetlana-chernova1983@postgrespro.ru", "phone": "+70967548104"}
0005433753786	0FFD3A	4566 901569	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir.021969@postgrespro.ru", "phone": "+70982688151"}
0005433753787	E5051D	1172 848741	MARIYA DAVYDOVA	{"phone": "+70006754816"}
0005433753788	6495A2	0873 669245	POLINA KUZMINA	{"email": "kuzmina_polina-1976@postgrespro.ru", "phone": "+70711401627"}
0005433753789	6495A2	6459 166861	MILENA KOVALEVA	{"phone": "+70910427207"}
0005433753790	6495A2	3184 204386	OKSANA TITOVA	{"phone": "+70870677434"}
0005433753791	6BFB66	7233 806633	PAVEL KUZMIN	{"phone": "+70244930548"}
0005433753792	6BFB66	2596 623082	VLADIMIR ORLOV	{"email": "orlovvladimir06121974@postgrespro.ru", "phone": "+70983873203"}
0005433753793	C3A85D	9126 524653	GALIYA KOZLOVA	{"email": "kozlova_galiya.1982@postgrespro.ru", "phone": "+70933871735"}
0005433753794	057808	0659 104397	BOGDAN SMIRNOV	{"email": "bogdansmirnov-021984@postgrespro.ru", "phone": "+70840226519"}
0005433753795	057808	5777 449171	ANATOLIY SAVELEV	{"phone": "+70533334383"}
0005433753796	55AE22	3198 962081	IVAN TARASOV	{"phone": "+70215125142"}
0005433753797	6E1916	9761 421805	GENNADIY STEPANOV	{"phone": "+70447963292"}
0005433753798	0518D2	1493 775294	IGOR MOROZOV	{"phone": "+70919001750"}
0005433753799	E0E7A2	5781 635502	ANDREY FEDOROV	{"phone": "+70089060710"}
0005433753800	9BD49E	2185 588299	VYACHESLAV YAKOVLEV	{"email": "yakovlev.v.1964@postgrespro.ru", "phone": "+70617401174"}
0005433753801	9BD49E	0849 671364	VLADISLAV SMIRNOV	{"phone": "+70093786056"}
0005433753802	7D20E7	9605 022792	NATALYA STEPANOVA	{"phone": "+70607446661"}
0005433753803	B95209	6304 708009	SERGEY STEPANOV	{"email": "sergey_stepanov121961@postgrespro.ru", "phone": "+70661881416"}
0005433753804	B95209	2780 571984	VALENTINA IVANOVA	{"phone": "+70176031799"}
0005433753805	8981C6	4366 425233	ELENA LAZAREVA	{"phone": "+70486033997"}
0005433753806	29FCD8	4494 256911	ALEKSEY EGOROV	{"phone": "+70862451722"}
0005433753807	29FCD8	3599 032915	DMITRIY NIKOLAEV	{"email": "dnikolaev_091966@postgrespro.ru", "phone": "+70757924979"}
0005433753808	64BE3D	8578 601396	ELIZAVETA ANDREEVA	{"email": "elizaveta_andreeva_1973@postgrespro.ru", "phone": "+70942497009"}
0005433753809	8DEEFB	7099 867489	IVAN POPOV	{"email": "popov-ivan061974@postgrespro.ru", "phone": "+70501749384"}
0005433753810	9F6017	0910 723250	ANDREY SOKOLOV	{"email": "andrey_sokolov_1966@postgrespro.ru", "phone": "+70764353900"}
0005433753811	3013C0	4124 396259	ANASTASIYA DENISOVA	{"email": "denisova-anastasiya.121973@postgrespro.ru", "phone": "+70181275774"}
0005433753812	3013C0	1555 401580	NIKOLAY DENISOV	{"email": "denisov.n_021970@postgrespro.ru", "phone": "+70307633911"}
0005433753813	D19ACA	2763 846692	ILYA PETROV	{"email": "petrovilya-1974@postgrespro.ru", "phone": "+70646054149"}
0005433753814	CA15F4	1142 074973	TAMARA KOROLEVA	{"phone": "+70915915968"}
0005433753815	552BDF	5295 209068	RAMIL VASILEV	{"email": "vasilev.ramil.121977@postgrespro.ru", "phone": "+70696966177"}
0005433753816	FE1388	5106 181179	NIKOLAY POPOV	{"email": "popov_nikolay_08011986@postgrespro.ru", "phone": "+70065844900"}
0005433753817	FE1388	8510 749093	EVGENIYA IVANOVA	{"email": "e.ivanova26021960@postgrespro.ru", "phone": "+70255963845"}
0005433753818	21F77E	3394 164505	ANDREY NIKOLAEV	{"email": "andrey-nikolaev_04091984@postgrespro.ru", "phone": "+70656442122"}
0005433753819	283885	4803 540808	EVGENIY ANDREEV	{"phone": "+70254011895"}
0005433753820	7956E1	8032 709709	MIKHAIL AFANASEV	{"phone": "+70951810179"}
0005433753821	7956E1	8663 432281	VASILIY MOISEEV	{"email": "vasiliy_moiseev.1978@postgrespro.ru", "phone": "+70667175692"}
0005433753822	D28EAD	1677 753871	VIKTOR EGOROV	{"email": "egorov-viktor-021961@postgrespro.ru", "phone": "+70888672777"}
0005433753823	A988C3	6349 381950	MARINA POPOVA	{"email": "popova_m071955@postgrespro.ru", "phone": "+70519964741"}
0005433753824	A988C3	1971 960444	SERGEY ILIN	{"email": "sergey_ilin_1992@postgrespro.ru", "phone": "+70797746013"}
0005433753825	BAC271	6595 748039	LILIYA STEPANOVA	{"phone": "+70116384794"}
0005433753826	92B2BA	3367 126392	YURIY NAZAROV	{"phone": "+70794610772"}
0005433753827	C33169	8389 119547	GALINA EGOROVA	{"phone": "+70568768536"}
0005433753828	47A57B	1763 313967	SERGEY YAKOVLEV	{"phone": "+70294958671"}
0005433753829	717C34	9905 874246	YULIYA NAZAROVA	{"email": "yuliya_nazarova-051966@postgrespro.ru", "phone": "+70531716614"}
0005433753830	D51C61	4616 689483	VYACHESLAV SHEVCHENKO	{"email": "vyacheslav-shevchenko-30071969@postgrespro.ru", "phone": "+70034678158"}
0005433753831	D51C61	0025 874974	NINA EGOROVA	{"phone": "+70880080035"}
0005433753832	DF5AB4	6047 995395	ALEKSANDR ROMANOV	{"phone": "+70493777303"}
0005433753833	2845E7	7023 244253	VIKTORIYA KUZMINA	{"phone": "+70441028983"}
0005433753834	0FA93E	1137 989157	NINA SOLOVEVA	{"email": "n-soloveva.29101976@postgrespro.ru", "phone": "+70104584283"}
0005433753835	04E9C8	3797 094677	VALENTINA KOLESNIKOVA	{"email": "vkolesnikova.071958@postgrespro.ru", "phone": "+70378712885"}
0005433753836	04E9C8	1911 503144	TAMARA FROLOVA	{"email": "frolova_t_1970@postgrespro.ru", "phone": "+70383940188"}
0005433753837	3B75A2	2927 509250	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev1962@postgrespro.ru", "phone": "+70123112310"}
0005433753838	AE5266	0374 844507	PETR STEPANOV	{"email": "p-stepanov-19031968@postgrespro.ru", "phone": "+70655392695"}
0005433753839	9801DE	4981 830660	TAMARA MARTYNOVA	{"phone": "+70534177295"}
0005433753840	5B6042	2560 606791	ANDREY RODIONOV	{"email": "rodionov.a18021969@postgrespro.ru", "phone": "+70964833038"}
0005433753841	242ADF	2302 163601	NIKITA KUZNECOV	{"email": "n_kuznecov.19011978@postgrespro.ru", "phone": "+70973183094"}
0005433753842	A09EBB	5397 035104	ALEKSEY SCHERBAKOV	{"email": "a_scherbakov.11111963@postgrespro.ru", "phone": "+70776962664"}
0005433753843	4B2732	9537 456729	VALENTINA FEDOROVA	{"phone": "+70227143960"}
0005433753844	DE8281	1733 778404	VIKTOR SMIRNOV	{"email": "viktor.smirnov.051967@postgrespro.ru", "phone": "+70106225660"}
0005433753845	DE8281	7663 126349	VALERIY SCHERBAKOV	{"email": "valeriy-scherbakov1968@postgrespro.ru", "phone": "+70176022858"}
0005433753846	E15BB2	6254 462744	KLARA MALYSHEVA	{"email": "k_malysheva-1980@postgrespro.ru", "phone": "+70412465469"}
0005433753847	0D316D	4023 769280	EKATERINA ISAEVA	{"email": "isaevae-1976@postgrespro.ru", "phone": "+70712520048"}
0005433753848	0D316D	7008 055660	MIKHAIL VOROBEV	{"phone": "+70030635965"}
0005433753849	B5FF5E	1874 762832	DMITRIY BARANOV	{"email": "d.baranov_26081987@postgrespro.ru", "phone": "+70650717845"}
0005433753850	B5FF5E	8029 744451	NATALYA IVANOVA	{"email": "nivanova061972@postgrespro.ru", "phone": "+70951562152"}
0005433753851	F8713D	9701 629128	OLGA PETROVA	{"phone": "+70445170302"}
0005433753852	17BAF6	1624 170675	OLEG KUZNECOV	{"phone": "+70990429164"}
0005433753853	671AC8	6505 237540	ALEKSANDR MAKAROV	{"phone": "+70579823221"}
0005433753854	E037BC	5562 853172	SERGEY SOLOVEV	{"email": "solovev.s021976@postgrespro.ru", "phone": "+70882893699"}
0005433753855	E037BC	1548 193643	ELENA CHERNOVA	{"email": "chernovae_27071961@postgrespro.ru", "phone": "+70217440546"}
0005433753856	B35216	0011 019568	SVYATOSLAV ISAEV	{"email": "isaev-svyatoslav.17071975@postgrespro.ru", "phone": "+70639403102"}
0005433753857	FC5F43	5512 818389	LIDIYA SEMENOVA	{"email": "l_semenova-06121963@postgrespro.ru", "phone": "+70665337580"}
0005433753858	6CDF07	9918 476566	EVGENIY IVANOV	{"phone": "+70525552569"}
0005433753859	6CDF07	7719 057369	LARISA ILINA	{"phone": "+70253159267"}
0005433753860	5D35DA	2263 948326	ARMAN SMIRNOV	{"phone": "+70387889298"}
0005433753861	12DD7A	5350 432849	EVGENIY SCHERBAKOV	{"email": "evgeniy.scherbakov051971@postgrespro.ru", "phone": "+70285239021"}
0005433753862	64E191	4925 223857	NATALYA FILIPPOVA	{"email": "filippova_natalya_101973@postgrespro.ru", "phone": "+70665740759"}
0005433753863	D40969	0131 684155	TAMARA MIRONOVA	{"email": "mironova_t.29121975@postgrespro.ru", "phone": "+70145689561"}
0005433753864	D40969	7120 477086	GALINA MIRONOVA	{"email": "mironova-g_09011964@postgrespro.ru", "phone": "+70891037813"}
0005433753865	5A561D	8024 250759	EGOR BONDARENKO	{"phone": "+70241318005"}
0005433753866	5A561D	5828 009814	ANASTASIYA ANDREEVA	{"email": "a.andreeva.031975@postgrespro.ru", "phone": "+70685686943"}
0005433753867	3B1731	9785 070111	DMITRIY MAKAROV	{"email": "makarov-d23091972@postgrespro.ru", "phone": "+70953083435"}
0005433753868	4BF3B2	3533 456861	ANDREY TIKHONOV	{"email": "tikhonov-a.1966@postgrespro.ru", "phone": "+70271604954"}
0005433753869	9A3DFB	8055 368267	BORIS SOKOLOV	{"phone": "+70380531373"}
0005433753870	9A3DFB	6413 995394	VLADISLAV IVANOV	{"phone": "+70289846542"}
0005433753871	589717	4697 968831	OLEG ANDREEV	{"phone": "+70955958488"}
0005433753872	589717	2419 406278	VERA MARTYNOVA	{"email": "martynovavera_041968@postgrespro.ru", "phone": "+70606881765"}
0005433753873	D46AF9	9158 209843	ANTON STEPANOV	{"phone": "+70481485764"}
0005433753874	26D8CF	2204 420941	OLESYA KUDRYASHOVA	{"phone": "+70318836256"}
0005433753875	20A251	1970 461863	NIKOLAY YAKOVLEV	{"email": "yakovlev.nikolay_1969@postgrespro.ru", "phone": "+70920163780"}
0005433753876	338510	9227 866051	MARIYA ANDREEVA	{"phone": "+70782299118"}
0005433753877	338510	6260 280789	TAMARA SOKOLOVA	{"phone": "+70416855022"}
0005433753878	89A289	6536 755917	DARYA STEPANOVA	{"phone": "+70733881889"}
0005433753879	9D98F9	2396 680044	BORIS NAUMOV	{"email": "b.naumov_08121981@postgrespro.ru", "phone": "+70758814108"}
0005433753880	1E13AA	7115 387316	ANTON SOROKIN	{"phone": "+70032153991"}
0005433753881	48C78D	2985 303317	ARKADIY MAKAROV	{"phone": "+70308361834"}
0005433753882	37504C	4764 494025	EVGENIY ANDREEV	{"phone": "+70561324765"}
0005433753883	81BF89	4060 384098	EVGENIYA MARTYNOVA	{"email": "emartynova_24081973@postgrespro.ru", "phone": "+70672202488"}
0005433753884	0D67D0	3958 385783	ALEKSANDR FILIPPOV	{"email": "a-filippov05061974@postgrespro.ru", "phone": "+70572059450"}
0005433753885	BBE359	5076 069033	ANAIT VLASOVA	{"email": "a-vlasova-011978@postgrespro.ru", "phone": "+70666727316"}
0005433753886	4EB95A	5683 162310	EVGENIY DENISOV	{"email": "denisov.evgeniy.1968@postgrespro.ru", "phone": "+70212970649"}
0005433753887	E6639D	1930 751091	ALEKSEY ALEKSANDROV	{"phone": "+70807450435"}
0005433753888	211F30	1569 273687	NINA POLYAKOVA	{"phone": "+70448102618"}
0005433753889	A54696	2546 849205	PETR STEPANOV	{"email": "stepanov_petr-1979@postgrespro.ru", "phone": "+70833385527"}
0005433753890	07E990	0531 053463	NINA FEDOROVA	{"phone": "+70864959348"}
0005433753891	07E990	0769 909718	KIRILL POPOV	{"phone": "+70267830506"}
0005433753892	DA6824	5690 883777	ALSU ANTONOVA	{"phone": "+70332282282"}
0005433753893	7ED6CE	1000 424836	DANILA MOISEEV	{"phone": "+70451373083"}
0005433753894	9C1BA7	1198 638834	VALERIY FILIPPOV	{"phone": "+70566331305"}
0005433753895	4A4D40	3193 772756	NIKITA ORLOV	{"phone": "+70205339460"}
0005433753896	4A4D40	4453 746147	VLADIMIR KRASNOV	{"phone": "+70642324145"}
0005433753897	DFAC7C	3517 318175	ANATOLIY VOLKOV	{"phone": "+70199606555"}
0005433753898	C185B4	7920 064294	DMITRIY KONOVALOV	{"email": "d_konovalov.04041974@postgrespro.ru", "phone": "+70748054702"}
0005433753899	1744FA	5472 408896	EVGENIY GERASIMOV	{"email": "gerasimove-02111977@postgrespro.ru", "phone": "+70543119952"}
0005433753900	691F69	9192 030607	ALEKSANDR ZHUKOV	{"phone": "+70236696788"}
0005433753901	3ECDC4	5049 163125	VYACHESLAV MOISEEV	{"phone": "+70274096339"}
0005433753902	9B8A22	1368 652013	TATYANA YAKOVLEVA	{"email": "yakovlevat_23081975@postgrespro.ru", "phone": "+70726592057"}
0005433753903	737753	4790 191611	DENIS MATVEEV	{"email": "denis.matveev_031979@postgrespro.ru", "phone": "+70148736124"}
0005433753904	737753	5184 707886	ELIZAVETA VASILEVA	{"phone": "+70773128558"}
0005433753905	67DCD4	0653 219374	ANASTASIYA POPOVA	{"phone": "+70345860806"}
0005433753906	58A892	6957 938436	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov_1975@postgrespro.ru", "phone": "+70803564487"}
0005433753907	3922E3	6384 123688	ROMAN TARASOV	{"email": "tarasov-r1963@postgrespro.ru", "phone": "+70752459694"}
0005433753908	1AECF4	6522 252752	IDA TIMOFEEVA	{"email": "timofeeva.ida_121969@postgrespro.ru", "phone": "+70038377406"}
0005433753909	A9DF75	3255 353126	ANTONINA EFIMOVA	{"email": "aefimova-03081965@postgrespro.ru", "phone": "+70719746557"}
0005433753910	A9DF75	3196 657732	ALEKSEY CHERNOV	{"phone": "+70007555881"}
0005433753911	2BEA61	0811 056188	IRINA VASILEVA	{"phone": "+70979820863"}
0005433753912	8A4431	4401 888486	ALENA PETROVA	{"email": "petrova_alena1971@postgrespro.ru", "phone": "+70990517406"}
0005433753913	8A4431	6065 258076	ELENA GORBUNOVA	{"phone": "+70185636444"}
0005433753914	4FC05E	6726 941320	LYUDMILA VLASOVA	{"email": "vlasovalyudmila-02091981@postgrespro.ru", "phone": "+70896078665"}
0005433753915	CD1E1D	0609 723786	IVAN FILIPPOV	{"email": "filippov.ivan.10101959@postgrespro.ru", "phone": "+70313486803"}
0005433753916	CD1E1D	7190 360287	DARYA POTAPOVA	{"email": "potapovadarya1966@postgrespro.ru", "phone": "+70681426464"}
0005433753917	166AC7	3272 300421	IVAN IVANOV	{"email": "ivanovivan_061965@postgrespro.ru", "phone": "+70237303755"}
0005433753918	166AC7	9013 259775	ELENA ANDREEVA	{"phone": "+70546049390"}
0005433753919	ADCD64	2637 567293	OLGA PAVLOVA	{"email": "pavlovaolga011976@postgrespro.ru", "phone": "+70587647828"}
0005433753920	D5A432	9273 849200	NINA VOROBEVA	{"email": "vorobeva_n.1970@postgrespro.ru", "phone": "+70242192167"}
0005433753977	F6C261	3018 859579	VALENTINA DENISOVA	{"phone": "+70543820127"}
0005433753921	4DD98E	1197 354329	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr_26101979@postgrespro.ru", "phone": "+70352256948"}
0005433753922	D4668E	8951 269522	LEONID MOISEEV	{"phone": "+70140169893"}
0005433753923	D4668E	4486 648302	NADEZHDA MIRONOVA	{"email": "mironovan-24051964@postgrespro.ru", "phone": "+70090146223"}
0005433753924	CB0A51	8387 697540	LILIYA NIKIFOROVA	{"phone": "+70768268705"}
0005433753925	0F9C88	3655 933519	EKATERINA ZHUKOVA	{"phone": "+70919781697"}
0005433753926	23EA52	3951 557829	NATALYA TITOVA	{"email": "natalya-titova-041979@postgrespro.ru", "phone": "+70995642790"}
0005433753927	4F2EA5	3335 587910	ELIZAVETA LAZAREVA	{"email": "lazareva-e.17091980@postgrespro.ru", "phone": "+70092907110"}
0005433753928	36A5F1	3289 150868	PAVEL SEMENOV	{"email": "p.semenov081974@postgrespro.ru", "phone": "+70752838494"}
0005433753929	36A5F1	6159 807870	EVGENIYA AFANASEVA	{"email": "evgeniya-afanaseva031978@postgrespro.ru", "phone": "+70472871181"}
0005433753930	5A6491	9177 456473	LYUDMILA FEDOROVA	{"email": "lyudmila-fedorova.1970@postgrespro.ru", "phone": "+70123163370"}
0005433753931	C5F640	5421 562568	IVAN KONOVALOV	{"email": "konovalov.i_1982@postgrespro.ru", "phone": "+70949056910"}
0005433753932	C5F640	4982 016298	OLGA NESTEROVA	{"email": "olganesterova_1971@postgrespro.ru", "phone": "+70099950861"}
0005433753933	CD115F	5926 835347	EVGENIYA ROMANOVA	{"phone": "+70291384600"}
0005433753934	CD115F	6727 245360	IVAN SCHERBAKOV	{"phone": "+70789357525"}
0005433753935	B09974	1359 349827	MAKSIM KAZAKOV	{"email": "maksim.kazakov-16071970@postgrespro.ru", "phone": "+70243182861"}
0005433753936	E8E7A5	5269 613451	TATYANA ISAEVA	{"email": "tatyana_isaeva-041983@postgrespro.ru", "phone": "+70952623726"}
0005433753937	DCEC1B	7771 479573	VITALIY BELOV	{"email": "v_belov18011975@postgrespro.ru", "phone": "+70344808454"}
0005433753938	DCEC1B	4563 973415	OLESYA LAZAREVA	{"email": "olazareva_1974@postgrespro.ru", "phone": "+70440657993"}
0005433753939	2AA43A	9229 145146	ALEKSEY DENISOV	{"phone": "+70360401319"}
0005433753940	2AA43A	4554 012287	EKATERINA DANILOVA	{"phone": "+70843680228"}
0005433753941	A34079	9841 300582	DANIIL DENISOV	{"email": "denisov-d071978@postgrespro.ru", "phone": "+70222554975"}
0005433753942	D5B135	8751 688172	OKSANA KARPOVA	{"phone": "+70227190839"}
0005433753943	D5B135	5163 588375	NATALYA ZHUKOVA	{"email": "nzhukova_1972@postgrespro.ru", "phone": "+70898082746"}
0005433753944	9573F7	2849 411558	ELENA YUDINA	{"phone": "+70181326185"}
0005433753945	D59C4C	5597 774940	ELIZAVETA ANDREEVA	{"phone": "+70502750596"}
0005433753946	D59C4C	3100 270824	SERGEY SOKOLOV	{"email": "sokolovs_091984@postgrespro.ru", "phone": "+70401550475"}
0005433753947	613D31	0970 838043	ZOYA EGOROVA	{"phone": "+70571539376"}
0005433753948	613D31	4084 521745	IVAN BONDARENKO	{"email": "bondarenko.ivan_05091973@postgrespro.ru", "phone": "+70767899909"}
0005433753949	96EFA4	0617 042670	KIRILL VOROBEV	{"email": "kirillvorobev101973@postgrespro.ru", "phone": "+70758759977"}
0005433753950	BA76ED	3459 735485	ELENA EGOROVA	{"email": "elena.egorova.101965@postgrespro.ru", "phone": "+70053188428"}
0005433753951	A649C6	1654 082017	YULIYA FILATOVA	{"phone": "+70104407778"}
0005433753952	FE1FAB	7316 429763	LARISA NIKITINA	{"email": "l.nikitina-1976@postgrespro.ru", "phone": "+70160227796"}
0005433753953	FE1FAB	0180 109548	ALEKSANDR BORISOV	{"phone": "+70880502371"}
0005433753954	A4FDFF	5095 512183	VYACHESLAV MAKSIMOV	{"email": "v.maksimov-011968@postgrespro.ru", "phone": "+70190848080"}
0005433753955	A4FDFF	5504 607054	VIKTOR DAVYDOV	{"phone": "+70819969606"}
0005433753956	FC8B84	6701 105518	ANATOLIY MIRONOV	{"email": "anatoliymironov_12121969@postgrespro.ru", "phone": "+70812574801"}
0005433753957	987013	1990 557320	VLADIMIR SMIRNOV	{"phone": "+70183352494"}
0005433753958	8E05AB	5355 848334	DANIIL KULIKOV	{"email": "dkulikov.03011971@postgrespro.ru", "phone": "+70240622199"}
0005433753959	8E05AB	8002 892723	ALINA GUSEVA	{"phone": "+70177727342"}
0005433753960	BA0840	7423 760896	NIKOLAY FROLOV	{"email": "n.frolov.081973@postgrespro.ru", "phone": "+70008719888"}
0005433753961	AA169E	8429 262640	YULIYA STEPANOVA	{"email": "y_stepanova_1975@postgrespro.ru", "phone": "+70487779399"}
0005433753962	EA607C	2449 403965	DMITRIY FOMIN	{"phone": "+70395791327"}
0005433753963	A7B980	0625 658593	MARINA VOLKOVA	{"phone": "+70303851094"}
0005433753964	A7B980	1902 180511	ANDREY ANTONOV	{"email": "antonov_andrey051971@postgrespro.ru", "phone": "+70123051276"}
0005433753965	436222	5151 816509	ELVINA SCHERBAKOVA	{"phone": "+70718362789"}
0005433753966	2ED3BD	9238 863291	MAKSIM KOZLOV	{"email": "m.kozlov.17111979@postgrespro.ru", "phone": "+70310835701"}
0005433753967	FF2C4B	6510 689633	GALINA SEMENOVA	{"phone": "+70593976498"}
0005433753968	18113D	3342 943418	ANASTASIYA DANILOVA	{"phone": "+70397143776"}
0005433753969	18113D	8937 280638	NATALYA KISELEVA	{"phone": "+70117661897"}
0005433753970	FBA3B5	6467 280379	GULNARA KUZNECOVA	{"email": "kuznecovagulnara_1972@postgrespro.ru", "phone": "+70886928733"}
0005433753971	D0DE77	7423 237319	VLADIMIR MOROZOV	{"phone": "+70119583143"}
0005433753972	48C9FB	9909 859382	ILFAT FROLOV	{"email": "frolov.i_15041971@postgrespro.ru", "phone": "+70372448594"}
0005433753973	48C9FB	5069 303160	ANDREY POPOV	{"phone": "+70443261613"}
0005433753974	585C77	0037 386670	TATYANA SERGEEVA	{"email": "sergeeva_t_1967@postgrespro.ru", "phone": "+70850691027"}
0005433753975	BC9525	8094 921063	MARIYA KOLESNIKOVA	{"phone": "+70381617323"}
0005433753976	F6C261	0901 299436	ANTONINA STEPANOVA	{"phone": "+70214399818"}
0005433753978	06D3D7	5907 967325	VALENTINA STEPANOVA	{"email": "v_stepanova_1967@postgrespro.ru", "phone": "+70215547278"}
0005433753979	0AF67F	3425 598549	SVETLANA SEMENOVA	{"email": "semenova.s071973@postgrespro.ru", "phone": "+70212545286"}
0005433753980	A41C50	8948 754794	MIKHAIL KUZNECOV	{"phone": "+70480251335"}
0005433753981	EE7EFC	4809 322214	MARINA ANDREEVA	{"phone": "+70528081582"}
0005433753982	EE7EFC	5359 250109	VITALIY SEMENOV	{"phone": "+70534109085"}
0005433753983	1ADBF3	0169 827611	ALEKSANDR KARPOV	{"phone": "+70579806711"}
0005433753984	1ADBF3	8571 771709	ALEKSANDR ALEKSEEV	{"phone": "+70744702753"}
0005433753985	6AEC7F	0337 804708	YULIYA NOVIKOVA	{"email": "novikovayuliya-051964@postgrespro.ru", "phone": "+70269225315"}
0005433753986	B3A8B0	6137 288477	MIKHAIL NIKITIN	{"phone": "+70346624302"}
0005433753987	24FE1D	2021 825363	RAMZIYA SEMENOVA	{"email": "r.semenova.031981@postgrespro.ru", "phone": "+70325276357"}
0005433753988	24FE1D	5384 560888	EVGENIY PETROV	{"email": "petrov.e21061977@postgrespro.ru", "phone": "+70418337157"}
0005433753989	AA65CB	8066 861174	SVETLANA PETROVA	{"phone": "+70845624256"}
0005433753990	E2B365	2318 218307	ELENA EFREMOVA	{"email": "e.efremova-011974@postgrespro.ru", "phone": "+70411205775"}
0005433753991	9BD3AE	1194 863056	ILDAR KRASNOV	{"email": "i_krasnov1972@postgrespro.ru", "phone": "+70859237084"}
0005433753992	786F86	3599 036226	NIKITA VOROBEV	{"phone": "+70806248390"}
0005433753993	FB5BE3	9391 434832	NIKOLAY PETROV	{"email": "petrov_nikolay1968@postgrespro.ru", "phone": "+70124231633"}
0005433753994	9609AA	8688 969095	NADEZHDA STEPANOVA	{"phone": "+70722219454"}
0005433753995	16C41D	8800 028927	MARINA KOROLEVA	{"phone": "+70218104798"}
0005433753996	F20536	1470 312855	ALEKSEY MIKHAYLOV	{"phone": "+70175761747"}
0005433753997	F20536	8111 278961	KONSTANTIN MIKHAYLOV	{"email": "k.mikhaylov_1973@postgrespro.ru", "phone": "+70418736063"}
0005433753998	3B2143	3043 294207	ANATOLIY SHEVCHENKO	{"phone": "+70391807414"}
0005433753999	3C5E91	9167 534650	EVGENIY KOZLOV	{"phone": "+70942828613"}
0005433754000	FB71B9	0834 854011	DMITRIY FOMIN	{"email": "fomin.dmitriy09101967@postgrespro.ru", "phone": "+70748047485"}
0005433754001	10D119	5929 713401	NATALYA DENISOVA	{"email": "natalya.denisova1979@postgrespro.ru", "phone": "+70932828926"}
0005433754002	3AB1E8	5105 806059	VLADIMIR MOROZOV	{"phone": "+70725118783"}
0005433754003	3AB1E8	0055 772803	MARIYA KOROLEVA	{"email": "koroleva-mariya-051959@postgrespro.ru", "phone": "+70304983983"}
0005433754004	02A53E	8682 809912	ANNA KOZLOVA	{"email": "kozlova-anna081966@postgrespro.ru", "phone": "+70273110977"}
0005433754005	EC5979	0046 705125	ALLA TARASOVA	{"phone": "+70694051709"}
0005433754006	2EB898	9196 378252	ALEKSANDR OSIPOV	{"email": "a-osipov.1977@postgrespro.ru", "phone": "+70303231076"}
0005433754007	EB0106	1685 675406	SERGEY VOROBEV	{"phone": "+70327747942"}
0005433754008	EB0106	3394 336760	IRINA EFIMOVA	{"email": "i.efimova.1974@postgrespro.ru", "phone": "+70459950384"}
0005433754009	F5C6D0	1215 115108	GENNADIY IVANOV	{"phone": "+70124450269"}
0005433754010	A7BC76	4953 185151	ANNA POLYAKOVA	{"email": "polyakovaa07031978@postgrespro.ru", "phone": "+70902069225"}
0005433754011	05957F	7074 294870	ILSHAT ILIN	{"phone": "+70620805146"}
0005433754012	C125B5	9787 044320	VLADIMIR ZAYCEV	{"email": "v.zaycev04101973@postgrespro.ru", "phone": "+70001568036"}
0005433754013	C125B5	7460 367285	NIKOLAY BARANOV	{"email": "n-baranov051971@postgrespro.ru", "phone": "+70754495017"}
0005433754014	AE158E	4017 223239	ANDREY GAVRILOV	{"phone": "+70245890878"}
0005433754015	AE158E	0871 503388	ALEKSANDR POPOV	{"phone": "+70727688094"}
0005433754016	B55FD9	6213 888969	ALEKSANDR FEDOROV	{"email": "fedorov.a_22071972@postgrespro.ru", "phone": "+70349909764"}
0005433754017	1890EC	7157 418448	LILIYA KUZNECOVA	{"email": "liliya_kuznecova.021969@postgrespro.ru", "phone": "+70338482930"}
0005433754018	77604B	9939 493969	OLGA ZHUKOVA	{"email": "zhukovaolga-1965@postgrespro.ru", "phone": "+70277676805"}
0005433754019	77604B	7161 454632	VLADIMIR MAKAROV	{"email": "makarov_v_1971@postgrespro.ru", "phone": "+70730975836"}
0005433754020	447ADD	5313 265606	VALERIYA ANDREEVA	{"phone": "+70273863945"}
0005433754021	A5E9A2	3017 395336	NIKOLAY ALEKSEEV	{"phone": "+70524655628"}
0005433754022	A5E9A2	8557 894377	ALEKSANDR MATVEEV	{"email": "a.matveev.09031976@postgrespro.ru", "phone": "+70260219957"}
0005433754023	457E59	1665 794335	EVELINA IVANOVA	{"phone": "+70018618893"}
0005433754024	8E4012	8286 864596	DZHAMILYA KUZMINA	{"email": "kuzmina_d1966@postgrespro.ru", "phone": "+70204029660"}
0005433754025	8E4012	8896 200878	ALLA VASILEVA	{"phone": "+70215356471"}
0005433754026	8E4012	0730 381005	TAMARA MALYSHEVA	{"phone": "+70662883551"}
0005433754027	F90B05	0813 505605	NATALYA DANILOVA	{"phone": "+70481345799"}
0005433754028	55B2EC	0603 602849	SERGEY ZAYCEV	{"phone": "+70710855410"}
0005433754029	55B2EC	9299 796206	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr.1967@postgrespro.ru", "phone": "+70726139735"}
0005433754030	EE8B91	0815 725996	IGOR KISELEV	{"email": "igor-kiselev061972@postgrespro.ru", "phone": "+70201565947"}
0005433754031	EE8B91	6267 953562	NINA EGOROVA	{"email": "egorova.n.051964@postgrespro.ru", "phone": "+70953986282"}
0005433754032	BA07F3	5723 506281	VERA ZAKHAROVA	{"email": "vzakharova.09051976@postgrespro.ru", "phone": "+70633792178"}
0005433754033	BA07F3	0099 495721	TATYANA MASLOVA	{"phone": "+70675643838"}
0005433754091	FD4269	1216 597319	VIKTOR SMIRNOV	{"phone": "+70107578173"}
0005433754034	BA07F3	6180 075109	VALENTINA IVANOVA	{"email": "valentina.ivanova.071964@postgrespro.ru", "phone": "+70598325271"}
0005433754035	76B3FA	2465 277287	ZHANNA NAUMOVA	{"email": "zhanna-naumova.091967@postgrespro.ru", "phone": "+70001626877"}
0005433754036	287333	0622 137753	ANDREY GRIGOREV	{"email": "grigorev_a.15111967@postgrespro.ru", "phone": "+70511519166"}
0005433754037	816B80	9758 429624	LYUBOV NIKOLAEVA	{"email": "nikolaeva.l.021973@postgrespro.ru", "phone": "+70183561064"}
0005433754038	946335	5776 818867	ANDREY YAKOVLEV	{"phone": "+70750967018"}
0005433754039	B471C9	4708 509755	VLADIMIR VOLKOV	{"email": "vladimir.volkov.041965@postgrespro.ru", "phone": "+70478999092"}
0005433754040	E7A7A4	9460 427498	SERGEY ALEKSANDROV	{"phone": "+70908567606"}
0005433754041	C64772	0142 601445	ALEKSANDR KUDRYASHOV	{"phone": "+70767540140"}
0005433754042	87ED10	2794 259948	RAISA ZAYCEVA	{"email": "raisa-zayceva.1981@postgrespro.ru", "phone": "+70654824825"}
0005433754043	5187EB	7691 150307	ZOYA ZAYCEVA	{"email": "zayceva_z_1969@postgrespro.ru", "phone": "+70614732392"}
0005433754044	F047E3	1948 459553	EDUARD VOLKOV	{"phone": "+70187217383"}
0005433754045	19163E	2727 861082	NATALYA BOGDANOVA	{"email": "natalya-bogdanova_25041976@postgrespro.ru", "phone": "+70270000385"}
0005433754046	6F3EF8	0903 415223	RAISA TITOVA	{"email": "raisa-titova_031985@postgrespro.ru", "phone": "+70707955302"}
0005433754047	DBB0FF	5520 712047	VALENTINA ROMANOVA	{"email": "romanova.v-26071975@postgrespro.ru", "phone": "+70090071963"}
0005433754048	DBB0FF	8915 140920	TAMARA OSIPOVA	{"email": "osipovatamara-11081962@postgrespro.ru", "phone": "+70163765797"}
0005433754049	B46A6C	3538 530673	LYUBOV SAVELEVA	{"phone": "+70974448791"}
0005433754050	B46A6C	5821 547503	NATALYA ORLOVA	{"phone": "+70071766599"}
0005433754051	B46A6C	9898 931721	POLINA KUZNECOVA	{"phone": "+70051298800"}
0005433754052	2FEF3B	7287 345138	ALEKSANDR SAVELEV	{"email": "saveleva_111957@postgrespro.ru", "phone": "+70183025229"}
0005433754053	B01557	7971 792716	IGOR KAZAKOV	{"email": "ikazakov051968@postgrespro.ru", "phone": "+70302752850"}
0005433754054	B01557	5808 929709	SVETLANA MEDVEDEVA	{"phone": "+70208746909"}
0005433754055	2D260D	4798 279463	TATYANA KOLESNIKOVA	{"phone": "+70929633849"}
0005433754056	178D2A	5420 701070	KSENIYA NIKOLAEVA	{"email": "nikolaevakseniya.041974@postgrespro.ru", "phone": "+70917304482"}
0005433754057	178D2A	1504 316844	MIKHAIL VOLKOV	{"phone": "+70206587759"}
0005433754058	6680FE	5942 956827	VLADIMIR SIDOROV	{"email": "sidorov_v.031982@postgrespro.ru", "phone": "+70895488240"}
0005433754059	21912C	7037 018920	EKATERINA IVANOVA	{"phone": "+70187255733"}
0005433754060	5E5C6B	7800 110787	ANDREY ALEKSEEV	{"phone": "+70498894306"}
0005433754061	0B368D	8329 415743	ELENA KUZNECOVA	{"phone": "+70953007383"}
0005433754062	8FC495	7628 750622	SVETLANA NIKIFOROVA	{"email": "s-nikiforova-1977@postgrespro.ru", "phone": "+70048723383"}
0005433754063	DEF38C	5145 928470	ANATOLIY NOVIKOV	{"phone": "+70623460606"}
0005433754064	98F1E9	2769 051662	TAMARA YAKOVLEVA	{"phone": "+70301478715"}
0005433754065	B6F559	6630 944074	SERGEY GUSEV	{"phone": "+70622513007"}
0005433754066	08285D	1632 421646	LYUDMILA CHERNOVA	{"email": "chernova.l-1974@postgrespro.ru", "phone": "+70947232492"}
0005433754067	51E10C	5943 711608	LYUDMILA VOLKOVA	{"phone": "+70435367128"}
0005433754068	FEBD0A	8218 615418	OLGA GORBUNOVA	{"email": "gorbunovao14011975@postgrespro.ru", "phone": "+70604474547"}
0005433754069	FEBD0A	8575 992951	VADIM MAKSIMOV	{"email": "maksimov_vadim-051976@postgrespro.ru", "phone": "+70215628889"}
0005433754070	AD838D	7282 428396	SVETLANA ABRAMOVA	{"phone": "+70867038462"}
0005433754071	AD838D	4582 378853	VERA AFANASEVA	{"phone": "+70078746508"}
0005433754072	7FD6AD	8112 833597	NIKOLAY ANDREEV	{"phone": "+70180998191"}
0005433754073	38095A	3827 200319	IRINA KUZNECOVA	{"phone": "+70783791084"}
0005433754074	6E84A9	7672 917833	EGOR TARASOV	{"phone": "+70835793741"}
0005433754075	AB42E9	4781 736005	VLADIMIR KOROLEV	{"email": "v.korolev.22101969@postgrespro.ru", "phone": "+70641294692"}
0005433754076	64C4F2	9641 566783	VIKTOR VLASOV	{"phone": "+70988888414"}
0005433754077	3D1223	1331 110208	SERGEY KOZLOV	{"email": "kozlov-s_121964@postgrespro.ru", "phone": "+70295434087"}
0005433754078	3D1223	5824 125825	GALINA TIKHONOVA	{"phone": "+70258267299"}
0005433754079	BBB56C	8473 531821	IRINA NIKITINA	{"email": "inikitina-17101965@postgrespro.ru", "phone": "+70875613882"}
0005433754080	858E12	7254 378313	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov25081974@postgrespro.ru", "phone": "+70193732329"}
0005433754081	6B3DE1	7828 110897	LYUDMILA SCHERBAKOVA	{"phone": "+70674042480"}
0005433754082	9AD376	1146 690326	EVGENIY TARASOV	{"phone": "+70862409080"}
0005433754083	9AD376	2617 212692	VIKTOR NOVIKOV	{"phone": "+70443324907"}
0005433754084	D79BE8	0507 908118	VLADIMIR STEPANOV	{"email": "stepanov.v.12111972@postgrespro.ru", "phone": "+70124701970"}
0005433754085	D79BE8	8628 546727	KSENIYA ILINA	{"email": "k.ilina011964@postgrespro.ru", "phone": "+70736650675"}
0005433754086	7446A8	6334 995282	OLGA KOLESNIKOVA	{"phone": "+70949892872"}
0005433754087	278E61	7344 778632	ELENA IVANOVA	{"email": "elena.ivanova16031970@postgrespro.ru", "phone": "+70479531589"}
0005433754088	1AD95A	4903 563143	NINA KOVALEVA	{"phone": "+70264414244"}
0005433754089	1AD95A	5870 606395	TAMARA ANTONOVA	{"phone": "+70195016690"}
0005433754090	1AD95A	3751 271206	VERA PAVLOVA	{"phone": "+70474807643"}
0005433754092	A8D5EA	0396 918616	ALEKSEY ALEKSEEV	{"email": "aalekseev-021977@postgrespro.ru", "phone": "+70339138791"}
0005433754093	93FFF4	7530 768550	OLGA NAZAROVA	{"email": "nazarova-o101981@postgrespro.ru", "phone": "+70782749446"}
0005433754094	93FFF4	6174 301486	NIKOLAY MOROZOV	{"email": "nikolay.morozov021982@postgrespro.ru", "phone": "+70260066877"}
0005433754095	93FFF4	0117 085585	VERA SOLOVEVA	{"email": "vera-soloveva.1971@postgrespro.ru", "phone": "+70310418371"}
0005433754096	160DB5	6473 064573	SVETLANA SAVELEVA	{"phone": "+70133327246"}
0005433754097	160DB5	1192 457963	ELENA STEPANOVA	{"email": "elenastepanova-06031975@postgrespro.ru", "phone": "+70416560975"}
0005433754098	A8EA62	7058 062618	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova_1962@postgrespro.ru", "phone": "+70935032877"}
0005433754099	BC5EB2	1055 572582	ANATOLIY STEPANOV	{"email": "anatoliystepanov.1974@postgrespro.ru", "phone": "+70625235271"}
0005433754100	DFA249	8075 679955	IVAN KOZLOV	{"email": "kozlov-i-01031971@postgrespro.ru", "phone": "+70606764694"}
0005433754101	157644	4177 432234	VITALIY SMIRNOV	{"email": "smirnov.v-1971@postgrespro.ru", "phone": "+70414902799"}
0005433754102	697488	3103 969257	IGOR SIDOROV	{"phone": "+70116539479"}
0005433754103	D875E3	8148 718598	ANATOLIY TIMOFEEV	{"email": "anatoliytimofeev031973@postgrespro.ru", "phone": "+70755422731"}
0005433754104	9E3C2D	0711 030906	KONSTANTIN SEMENOV	{"phone": "+70519862466"}
0005433754105	6A9F1C	7293 265959	MARIYA AFANASEVA	{"phone": "+70459833287"}
0005433754106	6A9F1C	6563 914041	ANDREY NIKOLAEV	{"email": "nikolaev.andrey_03031986@postgrespro.ru", "phone": "+70453819194"}
0005433754107	41EA3E	1227 186127	SVETLANA VOLKOVA	{"email": "volkovasvetlana-1969@postgrespro.ru", "phone": "+70114097236"}
0005433754108	2EE5E5	9062 327461	PAVEL ZAYCEV	{"email": "zaycev.pavel_011986@postgrespro.ru", "phone": "+70677435733"}
0005433754109	9ED9BF	0464 770726	ANDREY FROLOV	{"phone": "+70646785109"}
0005433754110	9ED9BF	7231 866777	ANASTASIYA MAKSIMOVA	{"email": "maksimova-anastasiya.011970@postgrespro.ru", "phone": "+70343385582"}
0005433754111	9ED9BF	7785 187205	OLEG KISELEV	{"phone": "+70551992371"}
0005433754112	F7FCD0	3662 236315	IGOR MAKSIMOV	{"email": "maksimov-i_101967@postgrespro.ru", "phone": "+70838257873"}
0005433754113	F7FCD0	7769 076565	ELENA POLYAKOVA	{"email": "epolyakova_03091971@postgrespro.ru", "phone": "+70471373306"}
0005433754114	F7FCD0	3730 713075	ALINA DENISOVA	{"phone": "+70349723295"}
0005433754115	68DADE	0427 451548	ROMAN MOISEEV	{"email": "moiseev.r-26011975@postgrespro.ru", "phone": "+70237659283"}
0005433754116	5D9D15	9237 495547	ALEKSANDR MOROZOV	{"email": "a_morozov041987@postgrespro.ru", "phone": "+70444796739"}
0005433754117	5A3AF9	4006 164167	MARIYA FEDOROVA	{"phone": "+70128155045"}
0005433754118	5A3AF9	1957 836471	ELENA ZHUKOVA	{"email": "zhukova-elena_13121962@postgrespro.ru", "phone": "+70202053695"}
0005433754119	440660	2264 219761	KSENIYA MIKHAYLOVA	{"email": "mikhaylova_kseniya121970@postgrespro.ru", "phone": "+70582514623"}
0005433754120	20A029	5453 993152	VADIM MOROZOV	{"email": "vmorozov-1968@postgrespro.ru", "phone": "+70823256299"}
0005433754121	A452E2	6600 622983	MIKHAIL OSIPOV	{"email": "m-osipov-08011974@postgrespro.ru", "phone": "+70390430800"}
0005433754122	188759	0280 108639	ROMAN TIMOFEEV	{"phone": "+70887340383"}
0005433754123	188759	9292 812389	LYUDMILA OSIPOVA	{"phone": "+70403258404"}
0005433754124	D2BDF0	7096 508833	RAFAIL BONDARENKO	{"phone": "+70079842499"}
0005433754125	B1AB6E	0702 950236	ALEKSANDR IVANOV	{"phone": "+70389829214"}
0005433754126	646522	3391 273839	SVETLANA NAZAROVA	{"email": "svetlana_nazarova09031974@postgrespro.ru", "phone": "+70556162795"}
0005433754127	7BE9BD	9732 730419	NIKOLAY POPOV	{"phone": "+70075718181"}
0005433754128	94CA24	1902 387610	TARAS KARPOV	{"email": "karpov.taras.021975@postgrespro.ru", "phone": "+70162208599"}
0005433754129	54CC79	5765 075344	ALEKSANDR FOMIN	{"phone": "+70468788557"}
0005433754130	E63616	0006 138818	NINA MAKAROVA	{"phone": "+70623854975"}
0005433754131	E63616	6274 043411	DENIS KUZMIN	{"phone": "+70519753066"}
0005433754132	40CABE	1376 362565	TATYANA SERGEEVA	{"phone": "+70205023601"}
0005433754133	E61241	3147 673758	TATYANA RODIONOVA	{"phone": "+70373643673"}
0005433754134	4879CA	8300 694592	LYUDMILA IVANOVA	{"email": "ivanoval.041948@postgrespro.ru", "phone": "+70535797770"}
0005433754135	4879CA	4548 100399	LYUBOV MOISEEVA	{"email": "moiseeva.lyubov-1974@postgrespro.ru", "phone": "+70869488722"}
0005433754136	9CBC6D	7174 329015	VLADIMIR VLASOV	{"email": "vlasovv-081975@postgrespro.ru", "phone": "+70492962275"}
0005433754137	2AB8E9	7651 213879	ANNA STEPANOVA	{"email": "stepanovaanna-14111976@postgrespro.ru", "phone": "+70299781255"}
0005433754138	EEF9D1	7228 808681	IVAN DMITRIEV	{"phone": "+70811402938"}
0005433754139	EEF9D1	9225 419585	ASIYA FILATOVA	{"email": "filatovaasiya_08111978@postgrespro.ru", "phone": "+70073373594"}
0005433754140	530F70	8715 711032	ANTONINA IVANOVA	{"email": "ivanova-a-1973@postgrespro.ru", "phone": "+70184996964"}
0005433754141	530F70	9030 971009	VIKTOR SERGEEV	{"email": "v.sergeev_17031975@postgrespro.ru", "phone": "+70045723504"}
0005433754142	D0A070	9533 757626	EKATERINA SOLOVEVA	{"email": "soloveva.e.081987@postgrespro.ru", "phone": "+70833500723"}
0005433754143	18D509	7636 279342	ALEKSEY EGOROV	{"email": "egorov_aleksey.27111964@postgrespro.ru", "phone": "+70286154455"}
0005433754144	80A461	5632 857767	MIKHAIL KISELEV	{"email": "kiselevmikhail1968@postgrespro.ru", "phone": "+70902728791"}
0005433754145	6643BD	3528 636337	ALEKSEY KARPOV	{"email": "karpov_a_1979@postgrespro.ru", "phone": "+70254603358"}
0005433754146	A9E5B0	3685 461656	TATYANA TARASOVA	{"phone": "+70435261894"}
0005433754147	A9E5B0	1697 058674	OLGA VOROBEVA	{"phone": "+70417722424"}
0005433754148	060BE2	5701 726756	ANDREY KUZNECOV	{"email": "kuznecov-andrey041976@postgrespro.ru", "phone": "+70719309639"}
0005433754149	060BE2	6543 158253	MAKSIM TIKHONOV	{"phone": "+70670693448"}
0005433754150	94864C	0472 901939	ROMAN NAZAROV	{"email": "roman-nazarov.10071961@postgrespro.ru", "phone": "+70941079763"}
0005433754151	B5F59E	0989 757149	SOFYA GORBUNOVA	{"email": "s-gorbunova-1969@postgrespro.ru", "phone": "+70684331521"}
0005433754152	73156C	3178 510924	VLADIMIR ANTONOV	{"phone": "+70698316260"}
0005433754153	6A8FB5	5426 324825	EVGENIY ALEKSANDROV	{"phone": "+70997640830"}
0005433754154	175AFE	4525 619460	ANTON MAKAROV	{"email": "makarov_anton1966@postgrespro.ru", "phone": "+70836254417"}
0005433754155	175AFE	3213 305684	ALEKSANDR MELNIKOV	{"phone": "+70332466321"}
0005433754156	594BB5	8616 362794	TATYANA BORISOVA	{"email": "borisovat-04041958@postgrespro.ru", "phone": "+70494880232"}
0005433754157	CEF4C3	7383 118628	NIKOLAY SOLOVEV	{"phone": "+70325784733"}
0005433754158	CEF4C3	1346 035216	EVGENIY SEMENOV	{"email": "semenov.e_23111975@postgrespro.ru", "phone": "+70001356120"}
0005433754159	A3A6AD	9236 638305	NIKOLAY ABRAMOV	{"email": "abramov_nikolay.28041988@postgrespro.ru", "phone": "+70602806023"}
0005433754160	72EF58	7907 363907	TATYANA SMIRNOVA	{"email": "smirnovatatyana101975@postgrespro.ru", "phone": "+70240728589"}
0005433754161	EC8E62	8650 975175	VIKTOR ROMANOV	{"email": "viktor-romanov_1982@postgrespro.ru", "phone": "+70051096348"}
0005433754162	EE5BA1	3878 775190	NATALYA GAVRILOVA	{"phone": "+70980538662"}
0005433754163	83A75F	2239 080854	ELENA GERASIMOVA	{"phone": "+70297000588"}
0005433754164	5C1EDD	5848 190294	IRINA ZOTOVA	{"email": "irina_zotova.12071970@postgrespro.ru", "phone": "+70061455563"}
0005433754165	32F440	1479 570922	IVAN SCHERBAKOV	{"email": "ischerbakov_1986@postgrespro.ru", "phone": "+70177204947"}
0005433754166	32F440	3052 775042	OLGA GRISHINA	{"email": "olga.grishina_1966@postgrespro.ru", "phone": "+70199180741"}
0005433754167	89CC05	5466 612341	NINA EGOROVA	{"phone": "+70466526485"}
0005433754168	6C414A	2299 125842	EKATERINA MOROZOVA	{"phone": "+70040344992"}
0005433754169	719161	7116 063800	ALEKSEY ORLOV	{"email": "a_orlov_091973@postgrespro.ru", "phone": "+70939175128"}
0005433754170	FB7D44	2409 082154	LYUBOV POTAPOVA	{"email": "potapoval.14021974@postgrespro.ru", "phone": "+70195916248"}
0005433754171	35252B	1174 450020	ALEKSEY STEPANOV	{"email": "stepanov-aleksey.121965@postgrespro.ru", "phone": "+70348458450"}
0005433754172	72E77D	8170 061394	NATALIYA BOGDANOVA	{"email": "nataliya.bogdanova-101978@postgrespro.ru", "phone": "+70268369843"}
0005433754173	1D8FB8	8210 966359	GENNADIY KISELEV	{"phone": "+70784946456"}
0005433754174	5A060B	2057 191971	DMITRIY MIKHAYLOV	{"email": "mikhaylov_dmitriy_19051973@postgrespro.ru", "phone": "+70818152405"}
0005433754175	5A060B	7814 997185	DARYA NOVIKOVA	{"email": "dnovikova06121980@postgrespro.ru", "phone": "+70426896433"}
0005433754176	B406C5	3713 289546	LYUDMILA NESTEROVA	{"phone": "+70317674987"}
0005433754177	B406C5	0287 547434	MARINA VOLKOVA	{"phone": "+70926321205"}
0005433754178	5E5B31	1379 574685	GALINA AFANASEVA	{"email": "afanasevagalina1973@postgrespro.ru", "phone": "+70820322496"}
0005433754179	5E5B31	9412 976449	ANFISA SOKOLOVA	{"phone": "+70203484342"}
0005433754180	5E5B31	3515 469307	DMITRIY VOLKOV	{"email": "dmitriy_volkov_1972@postgrespro.ru", "phone": "+70146756024"}
0005433754181	C1287B	6643 020255	VALENTINA MAKAROVA	{"phone": "+70915987818"}
0005433754182	AB5BFB	2062 049165	NIKITA GERASIMOV	{"phone": "+70237816501"}
0005433754183	15EA46	2721 667071	TAMARA STEPANOVA	{"email": "stepanovatamara_1961@postgrespro.ru", "phone": "+70586651633"}
0005433754184	15EA46	4196 351056	VITALIY KISELEV	{"email": "kiselev-v_061969@postgrespro.ru", "phone": "+70151893684"}
0005433754185	7C4D9B	9468 349318	OLEG GUSEV	{"email": "gusev.oleg-021971@postgrespro.ru", "phone": "+70436028325"}
0005433754186	9A7BC0	2837 598819	VYACHESLAV ORLOV	{"email": "orlov-vyacheslav121977@postgrespro.ru", "phone": "+70174500822"}
0005433754187	EA5D30	7742 327531	GALINA BOGDANOVA	{"email": "gbogdanova.1967@postgrespro.ru", "phone": "+70380474619"}
0005433754188	B642A0	8512 060209	KIRILL OSIPOV	{"email": "osipovkirill.13051976@postgrespro.ru", "phone": "+70773107652"}
0005433754189	90A8C1	5176 726281	GENNADIY MELNIKOV	{"phone": "+70956004113"}
0005433754190	BD20FC	3501 212075	VYACHESLAV AFANASEV	{"phone": "+70819889769"}
0005433754191	DA1860	7264 530573	ANDREY VOLKOV	{"phone": "+70592802343"}
0005433754192	41820A	9896 147000	RUSTAM KONOVALOV	{"email": "rkonovalov091971@postgrespro.ru", "phone": "+70215704595"}
0005433754193	2D56DF	7690 525442	VALENTIN MOROZOV	{"phone": "+70697691769"}
0005433754194	F757DD	9578 637518	NIKITA STEPANOV	{"email": "nikita.stepanov051975@postgrespro.ru", "phone": "+70017939357"}
0005433754195	75B775	3602 521875	MIKHAIL MAKAROV	{"phone": "+70581997461"}
0005433754196	125EDF	8631 036781	OLGA SMIRNOVA	{"phone": "+70413199211"}
0005433754197	512805	5497 589121	NINA ROMANOVA	{"email": "romanovanina1977@postgrespro.ru", "phone": "+70176889283"}
0005433754198	EED7C6	5264 517789	LIDIYA GERASIMOVA	{"email": "gerasimovalidiya.121965@postgrespro.ru", "phone": "+70443763805"}
0005433754199	695F29	8032 270007	YULIYA POTAPOVA	{"email": "potapova.y_071966@postgrespro.ru", "phone": "+70725595512"}
0005433754200	922A81	4232 632760	ALEKSEY MOISEEV	{"email": "aleksey.moiseev_041981@postgrespro.ru", "phone": "+70101459779"}
0005433754201	B13E49	1760 607213	DMITRIY FEDOROV	{"phone": "+70803171970"}
0005433754202	46059A	8332 230843	TATYANA AKIMOVA	{"phone": "+70425373720"}
0005433754203	46059A	8762 650901	VERA IVANOVA	{"email": "v-ivanova.13041964@postgrespro.ru", "phone": "+70059380755"}
0005433754204	BD2E3D	4150 427060	VALENTINA ILINA	{"phone": "+70331326305"}
0005433754205	A71A90	4436 099834	ILYA SHEVCHENKO	{"email": "shevchenkoilya_1981@postgrespro.ru", "phone": "+70125838658"}
0005433754206	1C7CD1	8944 937642	IGOR SEMENOV	{"phone": "+70914605802"}
0005433754207	1C7CD1	9553 669922	VALENTINA ROMANOVA	{"email": "valentinaromanova21041981@postgrespro.ru", "phone": "+70877123368"}
0005433754208	362BAB	2486 994939	NATALYA POPOVA	{"email": "n.popova-1965@postgrespro.ru", "phone": "+70222756285"}
0005433754209	394B83	7543 614036	STANISLAV BARANOV	{"phone": "+70700492009"}
0005433754210	A84F27	6480 012263	MIKHAIL GRIGOREV	{"phone": "+70603295533"}
0005433754211	9EE0C0	1227 700139	OLGA ZHURAVLEVA	{"phone": "+70565288707"}
0005433754212	7AE61E	2419 466684	MAKSIM SAVELEV	{"phone": "+70710578252"}
0005433754213	7AE61E	8041 658384	ARTUR MELNIKOV	{"phone": "+70016762521"}
0005433754214	2A9C75	5778 283092	PAVEL MOISEEV	{"email": "p-moiseev.18051980@postgrespro.ru", "phone": "+70168507153"}
0005433754215	3DD089	5422 301148	ALEKSEY MELNIKOV	{"phone": "+70824983685"}
0005433754216	6DF992	2915 445499	ELENA KOMAROVA	{"email": "elenakomarova29121975@postgrespro.ru", "phone": "+70398339346"}
0005433754217	0E8614	2831 921064	NIKOLAY ANDREEV	{"phone": "+70611776734"}
0005433754218	0E8614	3281 695452	IVAN SOLOVEV	{"email": "solovev_ivan-031961@postgrespro.ru", "phone": "+70242425057"}
0005433754219	89D178	9613 170708	MARINA ROMANOVA	{"email": "romanova-m_22071974@postgrespro.ru", "phone": "+70372987243"}
0005433754220	89D178	6409 374806	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.30051978@postgrespro.ru", "phone": "+70131029204"}
0005433754221	2C2705	0383 937807	ALEKSANDR MAKAROV	{"phone": "+70958963698"}
0005433754222	797BBD	6311 966547	EVGENIY KUZNECOV	{"phone": "+70072787493"}
0005433754223	E7D46A	3683 466664	ANTONINA DAVYDOVA	{"email": "antonina_davydova.1979@postgrespro.ru", "phone": "+70725774675"}
0005433754224	105A82	3409 723988	GEORGIY GAVRILOV	{"email": "ggavrilov08121968@postgrespro.ru", "phone": "+70139034898"}
0005433754225	211421	2795 713853	ALEKSANDR MOROZOV	{"phone": "+70346625542"}
0005433754226	194768	2369 309699	YURIY KOROLEV	{"email": "ykorolev_28071970@postgrespro.ru", "phone": "+70060254199"}
0005433754227	694161	0166 021475	MIKHAIL BARANOV	{"phone": "+70313120369"}
0005433754228	4E8477	3849 526682	NATALYA ALEKSANDROVA	{"email": "aleksandrovan-1964@postgrespro.ru", "phone": "+70776475994"}
0005433754229	B40979	8167 311537	GENNADIY SOROKIN	{"email": "sorokin_g-111969@postgrespro.ru", "phone": "+70478962270"}
0005433754230	7A28C3	0525 597150	NIKOLAY OSIPOV	{"phone": "+70214572846"}
0005433754231	7A28C3	8757 362943	YURIY BORISOV	{"phone": "+70850207813"}
0005433754232	9C140C	9977 092232	RUSLAN ALEKSANDROV	{"phone": "+70437682772"}
0005433754233	9C140C	8549 204439	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov-1981@postgrespro.ru", "phone": "+70220517061"}
0005433754234	D6F4FE	0030 405104	NATALYA MAKAROVA	{"email": "natalya_makarova21041970@postgrespro.ru", "phone": "+70325757822"}
0005433754235	D6F4FE	2658 816810	RAMIL ABRAMOV	{"phone": "+70032838558"}
0005433754236	D6F4FE	1021 108418	TATYANA ABRAMOVA	{"phone": "+70211212424"}
0005433754237	D6F4FE	7342 250890	ALEKSEY PETROV	{"phone": "+70258013300"}
0005433754238	BBE225	5788 898271	EVGENIYA ORLOVA	{"phone": "+70632234100"}
0005433754239	6D7946	1900 543178	LYUDMILA MALYSHEVA	{"phone": "+70447619051"}
0005433754240	31EFDB	7159 599015	YURIY POPOV	{"phone": "+70867408954"}
0005433754241	E39FD4	5012 095176	LYUDMILA GUSEVA	{"email": "guseva_lyudmila_02031972@postgrespro.ru", "phone": "+70556601032"}
0005433754242	1633AA	3371 172991	ARSENIY FEDOROV	{"email": "fedorov.arseniy.051974@postgrespro.ru", "phone": "+70577827989"}
0005433754243	761821	5895 932389	VYACHESLAV SMIRNOV	{"phone": "+70441649321"}
0005433754244	6CA4A9	7436 605101	ELIZAVETA IVANOVA	{"email": "ivanova-elizaveta-04071970@postgrespro.ru", "phone": "+70593485518"}
0005433754245	6CA4A9	4849 257901	OLEG MATVEEV	{"email": "omatveev1962@postgrespro.ru", "phone": "+70588378406"}
0005433754246	6CA4A9	6678 890927	VALERIYA GAVRILOVA	{"email": "vgavrilova-20011969@postgrespro.ru", "phone": "+70147135108"}
0005433754247	6CA4A9	3604 578900	ALEKSANDR ZAYCEV	{"phone": "+70095651184"}
0005433754248	2EF728	9147 840415	SERGEY SEMENOV	{"email": "ssemenov111975@postgrespro.ru", "phone": "+70667184297"}
0005433754249	8F3915	0880 396054	SERGEY POPOV	{"phone": "+70471675696"}
0005433754250	0C9F0B	4787 068636	ALEKSANDR KARPOV	{"email": "karpov.aleksandr_04021974@postgrespro.ru", "phone": "+70536163683"}
0005433754251	B6D101	2820 057315	LYUDMILA ILINA	{"phone": "+70150995876"}
0005433754252	BEE5D3	7271 533754	ANDREY NIKOLAEV	{"email": "a.nikolaev.26041978@postgrespro.ru", "phone": "+70463055812"}
0005433754253	C1E6DD	9830 360086	GENNADIY PETROV	{"email": "g-petrov-031959@postgrespro.ru", "phone": "+70073788967"}
0005433754254	FE1169	3665 592620	MARAT ALEKSEEV	{"phone": "+70544083454"}
0005433754255	4376E6	4286 932403	ALENA POLYAKOVA	{"phone": "+70302509422"}
0005433754256	FE0A36	1802 867868	VYACHESLAV DAVYDOV	{"phone": "+70288568013"}
0005433754257	FE0A36	6786 296367	VERA ZHUKOVA	{"email": "vera_zhukova.28111970@postgrespro.ru", "phone": "+70928448271"}
0005433754314	B53286	2577 063674	OLESYA SOROKINA	{"phone": "+70164211387"}
0005433754258	475096	4032 285296	YURIY DMITRIEV	{"email": "dmitriev-y-23031970@postgrespro.ru", "phone": "+70437983570"}
0005433754259	828761	6791 593791	VLADIMIR ZAKHAROV	{"phone": "+70916680636"}
0005433754260	A03712	6000 515376	ARTEM ZHUKOV	{"email": "artem_zhukov-22111982@postgrespro.ru", "phone": "+70122045206"}
0005433754261	0893D1	5238 019567	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_1971@postgrespro.ru", "phone": "+70185810250"}
0005433754262	5BBC07	1287 585120	DENIS KUZNECOV	{"email": "d-kuznecov_21031974@postgrespro.ru", "phone": "+70983777775"}
0005433754263	3289FA	7072 226739	PETR ZHURAVLEV	{"phone": "+70703356391"}
0005433754264	3289FA	2587 740553	VERA CHERNOVA	{"email": "vera-chernova-091969@postgrespro.ru", "phone": "+70868864968"}
0005433754265	3289FA	9639 686915	LARISA VOLKOVA	{"email": "volkova.l.061968@postgrespro.ru", "phone": "+70767284580"}
0005433754266	0CE51B	2333 322643	GALINA MIRONOVA	{"phone": "+70188688629"}
0005433754267	0CE51B	3336 207568	NADEZHDA MELNIKOVA	{"phone": "+70472176306"}
0005433754268	347662	0621 494158	ALBINA ERMAKOVA	{"email": "ermakova.a041964@postgrespro.ru", "phone": "+70870702096"}
0005433754269	8E9756	4003 013038	SVETLANA KUZNECOVA	{"phone": "+70449651071"}
0005433754270	8E9756	7774 039075	VLADIMIR MIRONOV	{"email": "mironov-v_1969@postgrespro.ru", "phone": "+70730713613"}
0005433754271	EC6637	6728 790303	LILIYA EFIMOVA	{"phone": "+70619893605"}
0005433754272	EC6637	5990 760843	YAKOV GAVRILOV	{"email": "gavrilov_y_051971@postgrespro.ru", "phone": "+70106477458"}
0005433754273	D12CFB	9533 242299	OLGA KAZAKOVA	{"email": "o_kazakova-031972@postgrespro.ru", "phone": "+70854456072"}
0005433754274	8B799B	0129 734319	ALEKSANDR MIRONOV	{"email": "mironov-a1981@postgrespro.ru", "phone": "+70130296970"}
0005433754275	64F471	9539 360097	VASILIY SOROKIN	{"phone": "+70401269946"}
0005433754276	65F1F8	4348 749218	ANGELINA ANISIMOVA	{"email": "a_anisimova.1967@postgrespro.ru", "phone": "+70863325450"}
0005433754277	DA4FDC	8903 755657	LYUBOV SCHERBAKOVA	{"phone": "+70761906872"}
0005433754278	42BC21	9158 185042	MAKSIM ZAYCEV	{"phone": "+70968733081"}
0005433754279	42BC21	0628 303915	EVGENIY GAVRILOV	{"email": "e-gavrilov-1976@postgrespro.ru", "phone": "+70688186645"}
0005433754280	D7C1AD	2296 827308	ELENA VASILEVA	{"email": "elenavasileva_041971@postgrespro.ru", "phone": "+70305050253"}
0005433754281	8DF299	6900 521219	EKATERINA VASILEVA	{"email": "e-vasileva_1970@postgrespro.ru", "phone": "+70451893690"}
0005433754282	8DF299	6999 030416	NIKOLAY SAVELEV	{"phone": "+70809504118"}
0005433754283	59EC89	5220 487576	SERGEY FOMIN	{"email": "fomin-sergey_1969@postgrespro.ru", "phone": "+70275236772"}
0005433754284	AC05B3	7860 693355	OLGA ANTONOVA	{"email": "oantonova_091971@postgrespro.ru", "phone": "+70763304235"}
0005433754285	DFB0D5	9918 219919	SERGEY SOROKIN	{"phone": "+70193664515"}
0005433754286	FBB0D7	4989 305515	ANNA FROLOVA	{"phone": "+70970123651"}
0005433754287	FBB0D7	9121 308761	ALEKSEY GERASIMOV	{"phone": "+70462108856"}
0005433754288	625DAB	6831 975960	ANATOLIY VASILEV	{"phone": "+70578261454"}
0005433754289	625DAB	7826 082830	DARYA TROFIMOVA	{"phone": "+70395362307"}
0005433754290	280BD9	8756 435150	EVGENIY KOROLEV	{"phone": "+70795288728"}
0005433754291	280BD9	6154 886900	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n26061979@postgrespro.ru", "phone": "+70914779988"}
0005433754292	9F8D93	2978 027641	NIKOLAY KUDRYASHOV	{"email": "nikolay-kudryashov_05051957@postgrespro.ru", "phone": "+70379043602"}
0005433754293	7CA5DC	5642 579935	NATALYA FADEEVA	{"email": "fadeeva-natalya-051974@postgrespro.ru", "phone": "+70966824407"}
0005433754294	7CA5DC	5541 648862	LILIYA MIKHAYLOVA	{"phone": "+70354942819"}
0005433754295	1A08E0	7366 924614	TATYANA ILINA	{"email": "ilina-tatyana_1970@postgrespro.ru", "phone": "+70596783896"}
0005433754296	5FFFF0	7202 142005	MARGARITA FROLOVA	{"email": "frolova.m_1981@postgrespro.ru", "phone": "+70796012923"}
0005433754297	A70287	6085 433062	INNA POPOVA	{"phone": "+70696835016"}
0005433754298	60C52E	2647 335824	EVGENIYA MIKHAYLOVA	{"email": "mikhaylova.evgeniya1965@postgrespro.ru", "phone": "+70968867123"}
0005433754299	60C52E	3605 875816	ELENA ISAEVA	{"email": "e.isaeva_111970@postgrespro.ru", "phone": "+70941589614"}
0005433754300	939B24	4485 582373	GALINA ILINA	{"email": "galina_ilina.111968@postgrespro.ru", "phone": "+70456063657"}
0005433754301	811C42	0846 543548	OLEG KISELEV	{"email": "kiselev-oleg_081982@postgrespro.ru", "phone": "+70686906469"}
0005433754302	7FDD00	0583 464292	NIKOLAY NAZAROV	{"email": "nazarovn.061977@postgrespro.ru", "phone": "+70011032637"}
0005433754303	AF51BE	8490 438063	SVETLANA GRISHINA	{"phone": "+70353797498"}
0005433754304	01E1E0	9542 695314	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr1964@postgrespro.ru", "phone": "+70135069961"}
0005433754305	FA29DC	3259 831158	YURIY SOKOLOV	{"phone": "+70686511416"}
0005433754306	1DB4B5	6296 401047	OLEG FEDOROV	{"email": "o.fedorov_011975@postgrespro.ru", "phone": "+70649170528"}
0005433754307	B372E8	2943 919350	SERGEY ROMANOV	{"email": "romanov-sergey.01051967@postgrespro.ru", "phone": "+70117635167"}
0005433754308	B372E8	8526 873973	ALEKSANDR KUZNECOV	{"phone": "+70246143863"}
0005433754309	A03EB5	5044 999960	NATALYA ROMANOVA	{"phone": "+70427151597"}
0005433754310	A03EB5	2043 791785	VIKTOR BARANOV	{"phone": "+70354236801"}
0005433754311	327ACA	5316 268276	VLADIMIR BORISOV	{"email": "borisov_vladimir.111968@postgrespro.ru", "phone": "+70255948034"}
0005433754312	327ACA	1957 886184	IRINA PETROVA	{"phone": "+70139313163"}
0005433754313	327ACA	4461 183530	YURIY TIMOFEEV	{"email": "ytimofeev_05041965@postgrespro.ru", "phone": "+70542930384"}
0005433754315	39EDB8	0279 718289	GALINA DENISOVA	{"phone": "+70685158536"}
0005433754316	39EDB8	9038 385479	LYUBOV ZHUKOVA	{"email": "l.zhukova061973@postgrespro.ru", "phone": "+70689862337"}
0005433754317	148FC0	4376 444083	OKSANA NESTEROVA	{"phone": "+70994280080"}
0005433754318	8A08B2	6843 280654	NIKOLAY ILIN	{"phone": "+70018898613"}
0005433754319	8A08B2	8281 882696	DMITRIY PETROV	{"phone": "+70860088500"}
0005433754320	A52C10	5377 897075	IRINA MELNIKOVA	{"email": "melnikovai16031959@postgrespro.ru", "phone": "+70767256462"}
0005433754321	8BF7EB	8500 098385	ANASTASIYA KARPOVA	{"email": "akarpova-1969@postgrespro.ru", "phone": "+70223722508"}
0005433754322	2CC537	4606 086699	VLADIMIR ANDREEV	{"email": "andreev_v1969@postgrespro.ru", "phone": "+70545323173"}
0005433754323	2CC537	3599 140153	TATYANA IVANOVA	{"email": "tivanova.1961@postgrespro.ru", "phone": "+70291921536"}
0005433754324	62B44A	4512 121518	FEDOR POPOV	{"email": "popov_fedor031974@postgrespro.ru", "phone": "+70666256502"}
0005433754325	62B44A	1485 537923	ELENA KUZNECOVA	{"phone": "+70172008986"}
0005433754326	F23B38	9994 113963	IRINA ZAKHAROVA	{"email": "zakharova-irina20091981@postgrespro.ru", "phone": "+70187426064"}
0005433754327	F23B38	2607 248111	ANASTASIYA SAVELEVA	{"email": "asaveleva-1981@postgrespro.ru", "phone": "+70295973714"}
0005433754328	63A73E	4447 053786	VERA ABRAMOVA	{"phone": "+70232908986"}
0005433754329	BC519C	1574 133932	RUSLAN BORISOV	{"phone": "+70829046571"}
0005433754330	B911D6	0704 997738	VLADIMIR SMIRNOV	{"phone": "+70682297990"}
0005433754331	B911D6	6861 235396	VIKTOR FROLOV	{"email": "v_frolov.08111968@postgrespro.ru", "phone": "+70029508666"}
0005433754332	1C5745	0944 536360	ELENA AKIMOVA	{"email": "elena.akimova1979@postgrespro.ru", "phone": "+70509468134"}
0005433754333	D64C60	3492 625608	LYUDMILA BELOVA	{"email": "lyudmilabelova_1980@postgrespro.ru", "phone": "+70337542906"}
0005433754334	5BE511	4140 647863	SERGEY PETROV	{"email": "petrovsergey.21011971@postgrespro.ru", "phone": "+70799232158"}
0005433754335	5BE511	4766 700888	LYUDMILA PAVLOVA	{"phone": "+70109192282"}
0005433754336	197AE7	7683 500535	DMITRIY DMITRIEV	{"phone": "+70653452772"}
0005433754337	197AE7	8420 293800	ELVIRA KUZNECOVA	{"phone": "+70551857576"}
0005433754338	F07B72	8177 368853	TATYANA PETROVA	{"email": "tatyana-petrova-1977@postgrespro.ru", "phone": "+70890807324"}
0005433754339	D3C9E5	8583 892110	ARTEM SERGEEV	{"email": "sergeev-a.29101970@postgrespro.ru", "phone": "+70798851998"}
0005433754340	52AAD3	9623 105231	TATYANA SOROKINA	{"phone": "+70327896193"}
0005433754341	52AAD3	8916 553922	ALEKSANDR STEPANOV	{"phone": "+70995210702"}
0005433754342	627707	8576 403549	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina1972@postgrespro.ru", "phone": "+70658531323"}
0005433754343	343D14	9786 685941	NATALYA SEMENOVA	{"email": "n.semenova.03041962@postgrespro.ru", "phone": "+70753951377"}
0005433754344	343D14	8747 714808	OLEG FEDOTOV	{"email": "o.fedotov-24021962@postgrespro.ru", "phone": "+70859993247"}
0005433754345	CF92B5	5764 675983	ANDREY MATVEEV	{"email": "matveeva.25031964@postgrespro.ru", "phone": "+70693237146"}
0005433754346	6F3BFC	1327 563278	ALENA KAZAKOVA	{"phone": "+70160258447"}
0005433754347	21D507	3378 608905	KSENIYA VOLKOVA	{"phone": "+70420815966"}
0005433754348	C11054	7455 591823	IRINA MASLOVA	{"email": "maslovai-24081960@postgrespro.ru", "phone": "+70763579086"}
0005433754349	9B883D	8938 328761	ANATOLIY NAZAROV	{"email": "nazarov-anatoliy-021975@postgrespro.ru", "phone": "+70313601441"}
0005433754350	9B883D	6937 353360	SERGEY FILIPPOV	{"email": "filippov_s-1979@postgrespro.ru", "phone": "+70606189006"}
0005433754351	5A397D	5444 099466	NATALYA VASILEVA	{"email": "vasileva.natalya.101974@postgrespro.ru", "phone": "+70343488872"}
0005433754352	5A397D	2107 896044	SERGEY VOROBEV	{"phone": "+70970605261"}
0005433754353	BDB4B4	3311 941861	EKATERINA NAZAROVA	{"email": "e.nazarova-02061977@postgrespro.ru", "phone": "+70065133679"}
0005433754354	1FDC8A	1067 035081	NADEZHDA SCHERBAKOVA	{"phone": "+70790591346"}
0005433754355	5FEF2F	6143 968725	OLEG NOVIKOV	{"email": "olegnovikov_06101962@postgrespro.ru", "phone": "+70458625905"}
0005433754356	56C867	1155 697000	LYUDMILA AFANASEVA	{"phone": "+70638086953"}
0005433754357	FCB4A1	9976 690629	ARTEM BORISOV	{"phone": "+70131987195"}
0005433754358	FCB4A1	9037 229253	TIMUR MAKAROV	{"phone": "+70449277373"}
0005433754359	D5939A	7660 729404	VERA MALYSHEVA	{"email": "vera.malysheva_03081990@postgrespro.ru", "phone": "+70814175304"}
0005433754360	D5939A	2975 529995	GALINA IVANOVA	{"email": "galina.ivanova081972@postgrespro.ru", "phone": "+70904813424"}
0005433754361	8C3867	7620 473440	ALEKSANDR TIKHONOV	{"email": "tikhonov.aleksandr-1969@postgrespro.ru", "phone": "+70707358669"}
0005433754362	A663DC	0207 726966	MARIYA BELOVA	{"email": "belovamariya.1969@postgrespro.ru", "phone": "+70424920272"}
0005433754363	A663DC	5934 097316	SERGEY MAKAROV	{"phone": "+70335532057"}
0005433754364	A663DC	0002 744583	NIKOLAY SERGEEV	{"email": "sergeevn09021966@postgrespro.ru", "phone": "+70251800445"}
0005433754365	D6973F	8872 372984	ALEKSEY NOVIKOV	{"phone": "+70815691697"}
0005433754366	9C77D8	7750 103039	LYUDMILA KUDRYASHOVA	{"phone": "+70532249946"}
0005433754367	9BA158	4435 755402	NATALIYA EGOROVA	{"email": "n-egorova121981@postgrespro.ru", "phone": "+70989127101"}
0005433754368	9BA158	9105 974830	LIDIYA KOROLEVA	{"email": "koroleva_l-021969@postgrespro.ru", "phone": "+70847201777"}
0005433754369	683015	5793 462198	PAVEL ZAKHAROV	{"email": "zakharovp_1979@postgrespro.ru", "phone": "+70777328540"}
0005433754370	1C8A08	8221 227836	ANTON RODIONOV	{"phone": "+70310069246"}
0005433754371	1C8A08	1780 635771	MIKHAIL PETROV	{"email": "mikhailpetrov-111961@postgrespro.ru", "phone": "+70812974194"}
0005433754372	8B6D7F	5087 854230	ANTON SAVELEV	{"email": "anton_savelev_1969@postgrespro.ru", "phone": "+70842640987"}
0005433754373	3FA80E	5241 372583	EKATERINA MAKAROVA	{"email": "makarovae_111974@postgrespro.ru", "phone": "+70306575950"}
0005433754374	053476	3780 318477	LARISA DENISOVA	{"phone": "+70159658947"}
0005433754375	053476	2941 529850	ANZHELIKA SIDOROVA	{"email": "anzhelika-sidorova13011980@postgrespro.ru", "phone": "+70626148919"}
0005433754376	630B77	2391 275811	ANNA EFIMOVA	{"phone": "+70300621809"}
0005433754377	91C116	5150 587392	NINA DAVYDOVA	{"phone": "+70338556450"}
0005433754378	79C47B	1242 932759	MAKSIM KUZNECOV	{"phone": "+70573404729"}
0005433754379	44E7D5	5991 195218	GENNADIY ILIN	{"email": "gennadiyilin_16011989@postgrespro.ru", "phone": "+70754548808"}
0005433754380	14C9DD	1027 295907	SVETLANA SMIRNOVA	{"phone": "+70374572978"}
0005433754381	14C9DD	7702 299375	DMITRIY NOVIKOV	{"phone": "+70973086868"}
0005433754382	E558AC	0519 204635	SERGEY VOLKOV	{"phone": "+70267570905"}
0005433754383	1188DB	8849 464657	DAMIR MIKHAYLOV	{"email": "mikhaylov-d_1976@postgrespro.ru", "phone": "+70431456986"}
0005433754384	B1D6B8	0925 440621	ANDREY VASILEV	{"email": "a.vasilev_1975@postgrespro.ru", "phone": "+70608360240"}
0005433754385	9C499A	9988 132886	MARIYA CHERNOVA	{"email": "chernova.mariya.041981@postgrespro.ru", "phone": "+70929036291"}
0005433754386	180843	8519 168823	MARINA NAUMOVA	{"email": "naumova_marina_081972@postgrespro.ru", "phone": "+70731500050"}
0005433754387	2B9377	7554 865082	ANTONINA NOVIKOVA	{"phone": "+70102131230"}
0005433754388	2B9377	8466 573361	DMITRIY SOROKIN	{"phone": "+70426850228"}
0005433754389	F75FC7	5254 672872	NINA BOGDANOVA	{"email": "bogdanovan.14091975@postgrespro.ru", "phone": "+70079887047"}
0005433754390	F75FC7	6251 602310	NIKOLAY IVANOV	{"email": "n-ivanov121977@postgrespro.ru", "phone": "+70093943805"}
0005433754391	4C38C3	7621 149367	NELLYA VOLKOVA	{"email": "nellya.volkova_041981@postgrespro.ru", "phone": "+70620797035"}
0005433754392	4C38C3	3661 434723	MIKHAIL IVANOV	{"email": "m-ivanov.111969@postgrespro.ru", "phone": "+70805307455"}
0005433754393	476926	4871 331845	YURIY OSIPOV	{"email": "yosipov061966@postgrespro.ru", "phone": "+70561053892"}
0005433754394	476926	4253 599918	IRINA MAKAROVA	{"email": "irina-makarova.031978@postgrespro.ru", "phone": "+70234552223"}
0005433754395	AE3C6A	7549 663795	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr.17111977@postgrespro.ru", "phone": "+70174766734"}
0005433754396	426312	5939 460588	LILIYA IVANOVA	{"phone": "+70575467484"}
0005433754397	91B88F	1131 063161	VALENTINA MOISEEVA	{"email": "moiseevavalentina-111982@postgrespro.ru", "phone": "+70415183870"}
0005433754398	91B88F	1906 046809	KIRA KRASNOVA	{"email": "k.krasnova.07101968@postgrespro.ru", "phone": "+70932561510"}
0005433754399	EF2C8F	4270 492867	TAMARA PETROVA	{"phone": "+70376885413"}
0005433754400	05E7BA	4132 859334	YURIY CHERNOV	{"email": "yuriychernov-1974@postgrespro.ru", "phone": "+70397432825"}
0005433754401	4E6FB5	1569 706537	MARINA IVANOVA	{"phone": "+70533600904"}
0005433754402	4DC516	6618 645119	EKATERINA ZAYCEVA	{"email": "zayceva_e-081972@postgrespro.ru", "phone": "+70076148844"}
0005433754403	350E1D	5184 737367	IRINA IVANOVA	{"phone": "+70376504400"}
0005433754404	B418BF	7712 980779	IGOR KUZMIN	{"phone": "+70368902841"}
0005433754405	7CB7BD	5273 650893	MIKHAIL POPOV	{"phone": "+70253613372"}
0005433754406	7CB7BD	3289 195754	ANDREY MIKHAYLOV	{"phone": "+70380883617"}
0005433754407	6D8EDE	4155 066860	ANATOLIY DENISOV	{"email": "denisov.anatoliy-1989@postgrespro.ru", "phone": "+70511686766"}
0005433754408	6D8EDE	3172 486656	MIKHAIL RODIONOV	{"email": "rodionov.mikhail.27031973@postgrespro.ru", "phone": "+70740444046"}
0005433754409	B030A2	5052 989931	GALINA FOMINA	{"email": "fominagalina13011971@postgrespro.ru", "phone": "+70571552718"}
0005433754410	AFD561	0444 245213	NIKOLAY KUDRYASHOV	{"phone": "+70924095230"}
0005433754411	93E60F	3310 981502	MAKSIM DMITRIEV	{"phone": "+70843775966"}
0005433754412	762C3C	3978 917819	ANATOLIY KONOVALOV	{"email": "konovalov_a-1970@postgrespro.ru", "phone": "+70023794747"}
0005433754413	E19B6F	0030 462017	OLEG STEPANOV	{"email": "stepanov-oleg-02121974@postgrespro.ru", "phone": "+70071139958"}
0005433754414	E19B6F	3470 294444	RAVIL IVANOV	{"email": "ravil.ivanov.1965@postgrespro.ru", "phone": "+70890669862"}
0005433754415	E19B6F	8470 619983	VLADIMIR TARASOV	{"email": "tarasov.vladimir.071964@postgrespro.ru", "phone": "+70667977199"}
0005433754416	6ECBB7	9252 141534	VALERIYA FEDOROVA	{"email": "valeriya-fedorova.23041969@postgrespro.ru", "phone": "+70154638576"}
0005433754417	E3454D	0740 814819	ALEKSEY GUSEV	{"email": "guseva-071958@postgrespro.ru", "phone": "+70963693868"}
0005433754418	72BF17	9854 746564	ELENA ZAKHAROVA	{"phone": "+70558457809"}
0005433754419	72BF17	6731 924367	SERGEY MOROZOV	{"email": "s-morozov.051963@postgrespro.ru", "phone": "+70550898422"}
0005433754420	EB9115	7087 588884	LARISA KOZLOVA	{"email": "kozlova-l-081978@postgrespro.ru", "phone": "+70743196818"}
0005433754421	C9B5D8	7933 930197	VLADISLAV MOROZOV	{"phone": "+70257246490"}
0005433754422	7FA7CC	8595 081115	VALERIY MIRONOV	{"email": "mironov-valeriy.1978@postgrespro.ru", "phone": "+70026191555"}
0005433754423	3463AE	3590 969853	NIKOLAY MELNIKOV	{"email": "nmelnikov_1969@postgrespro.ru", "phone": "+70419875230"}
0005433754424	E76E91	1979 649171	TATYANA POLYAKOVA	{"email": "tatyanapolyakova_18061971@postgrespro.ru", "phone": "+70807959767"}
0005433754425	A8C6D1	8165 666627	ROMAN VASILEV	{"email": "vasilev.roman-071972@postgrespro.ru", "phone": "+70505396044"}
0005433754426	A8C6D1	5080 487747	NINA KUZMINA	{"email": "n-kuzmina-29051972@postgrespro.ru", "phone": "+70282634377"}
0005433754427	181EBF	2772 785861	VITALIY NIKITIN	{"email": "nikitin.vitaliy041965@postgrespro.ru", "phone": "+70180425845"}
0005433754428	38D9E9	2340 367372	OKSANA MEDVEDEVA	{"phone": "+70851488624"}
0005433754429	E02BDE	2775 966340	EVGENIY ORLOV	{"phone": "+70921649146"}
0005433754430	4562BC	4008 250970	LIDIYA FOMINA	{"email": "fomina-lidiya.1975@postgrespro.ru", "phone": "+70178224701"}
0005433754431	4562BC	1273 857685	TIMUR SMIRNOV	{"email": "smirnov_t25061976@postgrespro.ru", "phone": "+70155072564"}
0005433754432	2A873D	3604 487464	KIRILL ZHUKOV	{"email": "zhukov-k12041972@postgrespro.ru", "phone": "+70695396220"}
0005433754433	C1E4F5	8894 094277	ALEKSANDRA STEPANOVA	{"email": "stepanova_a.1978@postgrespro.ru", "phone": "+70313223753"}
0005433754434	C1E4F5	0000 035204	VASILIY SIDOROV	{"phone": "+70326240002"}
0005433754435	161656	6110 807076	ANTONINA MALYSHEVA	{"phone": "+70359720105"}
0005433754436	161656	0562 321501	VLADISLAV KISELEV	{"email": "kiselev_vladislav1972@postgrespro.ru", "phone": "+70105570102"}
0005433754437	FC8762	0422 023003	OLGA EGOROVA	{"phone": "+70963596469"}
0005433754438	C8DAF3	3019 338163	ALEKSEY FOMIN	{"phone": "+70780027559"}
0005433754439	87BEA6	2392 564170	ANDREY SEMENOV	{"phone": "+70232707631"}
0005433754440	9F5766	3304 183121	YULIYA MATVEEVA	{"email": "y_matveeva-1974@postgrespro.ru", "phone": "+70604274379"}
0005433754441	B1CE8E	2778 060233	MIKHAIL MOROZOV	{"phone": "+70291660955"}
0005433754442	B1CE8E	6188 616564	VYACHESLAV GUSEV	{"phone": "+70378487587"}
0005433754443	586FB1	8496 654076	RAISA KUZNECOVA	{"email": "kuznecova.raisa31121971@postgrespro.ru", "phone": "+70134648153"}
0005433754444	808C39	0745 718236	ANTON MOROZOV	{"email": "a_morozov.26031969@postgrespro.ru", "phone": "+70864422362"}
0005433754445	04D089	1094 010827	NIKITA BELOV	{"phone": "+70270561992"}
0005433754446	26FD82	2513 432615	IVAN SIDOROV	{"phone": "+70862878832"}
0005433754447	9B2BAD	9725 943296	ZAKHAR MARTYNOV	{"phone": "+70957203793"}
0005433754448	4DC68F	4503 515456	ANATOLIY DMITRIEV	{"phone": "+70406809245"}
0005433754449	4DC68F	8439 636927	ANATOLIY NOVIKOV	{"email": "anatoliy_novikov.02091978@postgrespro.ru", "phone": "+70382469692"}
0005433754450	84CA67	2778 924968	TATYANA BELYAEVA	{"phone": "+70975607201"}
0005433754451	84CA67	9797 205815	EGOR VASILEV	{"email": "vasilev.egor1967@postgrespro.ru", "phone": "+70336678830"}
0005433754452	84CA67	0141 782184	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov.31081982@postgrespro.ru", "phone": "+70449632655"}
0005433754453	A465DF	6435 897458	OLGA MAKSIMOVA	{"phone": "+70848386157"}
0005433754454	329C7D	1382 297559	YURIY MATVEEV	{"phone": "+70432832749"}
0005433754455	621C87	7983 944487	RAVIL ANTONOV	{"email": "antonov.r-1972@postgrespro.ru", "phone": "+70265379089"}
0005433754456	AE4C75	2837 510910	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey_081977@postgrespro.ru", "phone": "+70211642433"}
0005433754457	E69F73	0624 918802	MARIYA KUZNECOVA	{"email": "m_kuznecova.1960@postgrespro.ru", "phone": "+70885591778"}
0005433754458	82FE2B	2472 961069	SERGEY BARANOV	{"phone": "+70670548559"}
0005433754459	E04649	7337 664327	ANNA VOLKOVA	{"email": "a-volkova_051978@postgrespro.ru", "phone": "+70621881200"}
0005433754460	E04649	3450 360323	VALENTINA LUKYANOVA	{"phone": "+70828125623"}
0005433754461	BE3C81	3450 663103	NIKOLAY IVANOV	{"phone": "+70278108602"}
0005433754462	CFC8D6	5086 669200	SERGEY KUZNECOV	{"phone": "+70315445534"}
0005433754463	09FE07	4354 614487	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova_natalya.1988@postgrespro.ru", "phone": "+70961482296"}
0005433754464	B4CC2A	7829 506128	ANASTASIYA POPOVA	{"phone": "+70559329614"}
0005433754465	B4CC2A	2428 463479	DMITRIY IVANOV	{"phone": "+70312893718"}
0005433754466	F84961	3617 068481	VALENTINA NIKIFOROVA	{"phone": "+70812266172"}
0005433754467	AC060E	2787 719975	MIKHAIL KOZLOV	{"email": "kozlovmikhail-1975@postgrespro.ru", "phone": "+70462313160"}
0005433754468	AC060E	6041 883230	LYUDMILA PAVLOVA	{"phone": "+70848107791"}
0005433754469	E28D75	4260 361427	EVGENIY GERASIMOV	{"email": "gerasimov_evgeniy-23071971@postgrespro.ru", "phone": "+70820444813"}
0005433754470	0E06DD	5932 568965	NINA MASLOVA	{"email": "maslova-nina1977@postgrespro.ru", "phone": "+70149483134"}
0005433754471	DC0100	4526 173024	NIKOLAY OSIPOV	{"email": "nikolayosipov_20051964@postgrespro.ru", "phone": "+70744802584"}
0005433754472	619428	1266 890108	IRINA SIDOROVA	{"phone": "+70372738002"}
0005433754473	21E06E	8291 052967	SERGEY MATVEEV	{"phone": "+70643795854"}
0005433754474	21E06E	1206 520293	ALENA ILINA	{"phone": "+70678215588"}
0005433754475	4E0087	7586 812275	PLATON MAKAROV	{"phone": "+70091347340"}
0005433754476	0B46A7	2925 781529	ELENA IVANOVA	{"phone": "+70270188927"}
0005433754477	7057A3	4264 650257	VASILIY KAZAKOV	{"email": "kazakov_v29061972@postgrespro.ru", "phone": "+70513059031"}
0005433754478	7057A3	6821 178910	LYUDMILA NAZAROVA	{"phone": "+70950870087"}
0005433754479	33804C	2486 466789	IRINA EGOROVA	{"email": "egorova_i-051975@postgrespro.ru", "phone": "+70819725470"}
0005433754480	2ACAAB	7245 015988	ALEKSANDR SOLOVEV	{"phone": "+70830535185"}
0005433754481	35AF68	1761 654239	LYUBOV BORISOVA	{"phone": "+70347489984"}
0005433754482	C88E50	3823 378661	RUSLAN ANTONOV	{"phone": "+70876101621"}
0005433754483	E2E8A0	0883 565304	VERA KRASNOVA	{"email": "vera.krasnova.11041962@postgrespro.ru", "phone": "+70144670068"}
0005433754484	F6884D	0104 651951	VIKTOR NIKOLAEV	{"email": "nikolaev_viktor.1969@postgrespro.ru", "phone": "+70684097158"}
0005433754485	45B36C	5617 338325	YURIY ORLOV	{"phone": "+70256151598"}
0005433754486	5629B3	5681 793380	VLADIMIR PETROV	{"phone": "+70385166993"}
0005433754487	2B8172	2184 658430	ALEKSANDR MEDVEDEV	{"email": "aleksandr-medvedev.04101967@postgrespro.ru", "phone": "+70856241186"}
0005433754488	2B8172	8179 951492	ELENA ALEKSEEVA	{"phone": "+70083198607"}
0005433754489	8B1D02	2703 764187	VASILIY ZHURAVLEV	{"email": "vasiliy_zhuravlev-1959@postgrespro.ru", "phone": "+70124913624"}
0005433754490	4C0ABF	4141 536314	SVETLANA AKIMOVA	{"phone": "+70717682191"}
0005433754491	8FF243	0019 453777	ZOYA TARASOVA	{"email": "tarasovaz121977@postgrespro.ru", "phone": "+70182324138"}
0005433754492	8FF243	9551 250716	YURIY ABRAMOV	{"email": "yuriy.abramov.30051965@postgrespro.ru", "phone": "+70155765723"}
0005433754493	564246	1351 496614	MARIYA NIKITINA	{"email": "mariya-nikitina1966@postgrespro.ru", "phone": "+70505832412"}
0005433754494	61E7A0	6118 722537	ILYA MIRONOV	{"email": "mironov_ilya1976@postgrespro.ru", "phone": "+70421508606"}
0005433754495	98537E	7058 760003	EKATERINA MOISEEVA	{"phone": "+70786318843"}
0005433754496	8FF914	5502 408101	OLGA SAVELEVA	{"email": "saveleva-olga.21111978@postgrespro.ru", "phone": "+70557500014"}
0005433754497	F07B3E	7310 232116	TATYANA KUZNECOVA	{"email": "kuznecova.t_24031979@postgrespro.ru", "phone": "+70601599293"}
0005433754498	FF69BE	4272 855506	DENIS SIDOROV	{"phone": "+70012017426"}
0005433754499	FF69BE	2622 660766	VALENTINA NAZAROVA	{"email": "nazarova-v-111969@postgrespro.ru", "phone": "+70559918541"}
0005433754500	1BFECD	4139 527913	NADEZHDA GRISHINA	{"email": "ngrishina-30121967@postgrespro.ru", "phone": "+70010363376"}
0005433754501	00E3E5	4011 590439	SERGEY ANDREEV	{"email": "andreev_sergey_1963@postgrespro.ru", "phone": "+70641133963"}
0005433754502	00E3E5	9862 884953	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina_101971@postgrespro.ru", "phone": "+70477381408"}
0005433754503	A07F6E	0212 561725	MARINA KRASNOVA	{"email": "krasnova-marina.121966@postgrespro.ru", "phone": "+70247392758"}
0005433754504	2F4C2C	0443 224884	ZULFIYA GRISHINA	{"phone": "+70950179791"}
0005433754505	1AF2AA	3559 424314	TATYANA CHERNOVA	{"email": "chernova.t.061973@postgrespro.ru", "phone": "+70295574998"}
0005433754506	C59A80	5860 760181	MARIYA PETROVA	{"email": "mpetrova01071977@postgrespro.ru", "phone": "+70536748557"}
0005433754507	EDD8CE	8520 319035	NATALYA ORLOVA	{"phone": "+70960930250"}
0005433754508	FB8910	4361 460539	YULIYA POPOVA	{"phone": "+70414189061"}
0005433754509	01D877	9028 789717	YURIY BONDARENKO	{"phone": "+70454231220"}
0005433754510	F1C2DD	6838 201067	VLADIMIR KUZNECOV	{"phone": "+70093125299"}
0005433754511	804D21	8847 374344	YURIY NOVIKOV	{"phone": "+70374972492"}
0005433754512	804D21	0369 598166	YURIY FEDOROV	{"phone": "+70699245506"}
0005433754513	BFBDB3	4080 418612	DMITRIY ORLOV	{"email": "d.orlov-31081971@postgrespro.ru", "phone": "+70737215023"}
0005433754514	BFBDB3	7474 316974	NIKOLAY GUSEV	{"phone": "+70702290151"}
0005433754515	4F0AF2	8301 918317	ANATOLIY GERASIMOV	{"phone": "+70821847187"}
0005433754516	A1A5B9	0525 793592	NINA ZHURAVLEVA	{"phone": "+70825117747"}
0005433754517	A1A5B9	1419 598811	SERGEY POPOV	{"email": "sergey-popov101967@postgrespro.ru", "phone": "+70855186573"}
0005433754518	A1A5B9	2495 888807	VALENTINA VOLKOVA	{"email": "v.volkova15091972@postgrespro.ru", "phone": "+70650992136"}
0005433754519	2200EF	8855 357944	ELENA VLASOVA	{"email": "elena_vlasova.22121974@postgrespro.ru", "phone": "+70520322168"}
0005433754520	E8361F	9737 437740	TATYANA FADEEVA	{"phone": "+70511894751"}
0005433754521	E8361F	6292 053362	DARYA ZOTOVA	{"phone": "+70025346086"}
0005433754522	01ED87	9379 044787	EVGENIY VASILEV	{"email": "evgeniyvasilev031981@postgrespro.ru", "phone": "+70384755338"}
0005433754523	738471	4435 698700	SVETLANA FOMINA	{"email": "svetlanafomina_1981@postgrespro.ru", "phone": "+70565328256"}
0005433754524	8455AF	1770 702155	IGOR MOROZOV	{"phone": "+70767016945"}
0005433754525	DF7657	9455 597889	ANASTASIYA YAKOVLEVA	{"phone": "+70181665170"}
0005433754526	DF7657	5842 515632	VALENTINA VASILEVA	{"phone": "+70202799509"}
0005433754527	E34FE9	2647 505163	PAVEL SERGEEV	{"phone": "+70320467121"}
0005433754528	04421C	0003 772702	OLEG OSIPOV	{"phone": "+70882835007"}
0005433754529	7065B9	9082 038455	MAYYA GUSEVA	{"email": "mayyaguseva-02031977@postgrespro.ru", "phone": "+70576145749"}
0005433754530	7065B9	2056 619385	SERGEY MAKAROV	{"phone": "+70215399888"}
0005433754531	4124DE	8160 783562	VARVARA KOZLOVA	{"email": "kozlovavarvara_02061976@postgrespro.ru", "phone": "+70393573699"}
0005433754532	4124DE	0084 559006	DMITRIY KUZNECOV	{"phone": "+70561310600"}
0005433754533	251B1F	6295 800761	ELENA CHERNOVA	{"email": "e_chernova.101971@postgrespro.ru", "phone": "+70011161434"}
0005433754534	E4461F	5269 252757	EVDOKIYA IVANOVA	{"email": "evdokiya_ivanova-22051973@postgrespro.ru", "phone": "+70300740331"}
0005433754535	E4461F	0400 628517	MARIYA LUKYANOVA	{"email": "mlukyanova23041959@postgrespro.ru", "phone": "+70175582451"}
0005433754536	6834DC	0456 857582	VYACHESLAV MAKSIMOV	{"phone": "+70825970593"}
0005433754537	6834DC	9123 653641	EKATERINA ROMANOVA	{"email": "romanova-ekaterina-20091970@postgrespro.ru", "phone": "+70527708117"}
0005433754538	6834DC	4679 873146	ALLA KAZAKOVA	{"email": "kazakova_a.25111967@postgrespro.ru", "phone": "+70998630899"}
0005433754539	F4BAE4	7788 622273	VARVARA EFREMOVA	{"email": "varvaraefremova_1969@postgrespro.ru", "phone": "+70705809782"}
0005433754540	4F8965	2860 331488	VALENTINA GORBUNOVA	{"phone": "+70867212691"}
0005433754541	924B7D	4378 866358	RAISA POPOVA	{"phone": "+70842471478"}
0005433754542	924B7D	8755 187653	VITALIY SAVELEV	{"email": "savelev-vitaliy.10071963@postgrespro.ru", "phone": "+70123500933"}
0005433754543	00967F	3871 047255	ANASTASIYA VLASOVA	{"email": "avlasova_1969@postgrespro.ru", "phone": "+70758596274"}
0005433754544	D7E57A	7610 413450	EKATERINA TIKHONOVA	{"phone": "+70536170918"}
0005433754545	D7E57A	1074 117698	SERGEY MEDVEDEV	{"email": "smedvedev-1961@postgrespro.ru", "phone": "+70959790998"}
0005433754546	6CCCAA	0104 918244	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov.091982@postgrespro.ru", "phone": "+70572262959"}
0005433754547	1D6F8C	1517 190302	NIKOLAY MATVEEV	{"email": "n-matveev_111982@postgrespro.ru", "phone": "+70086218570"}
0005433754548	1D6F8C	9574 283679	LYUBOV FROLOVA	{"email": "lyubovfrolova.1977@postgrespro.ru", "phone": "+70279250817"}
0005433754549	053701	4492 535845	YANA EGOROVA	{"phone": "+70381823725"}
0005433754550	8D82AC	9999 771275	VLADIMIR PETROV	{"phone": "+70323305395"}
0005433754551	EEA293	0332 744577	ALEKSEY ILIN	{"email": "ilin.aleksey-071970@postgrespro.ru", "phone": "+70443683752"}
0005433754552	0E3C75	1352 525029	OLGA RYABOVA	{"phone": "+70560166604"}
0005433754553	7F7D17	4402 991201	SERGEY NIKOLAEV	{"phone": "+70664258796"}
0005433754554	E93EF7	0775 542257	ILYA KUZNECOV	{"email": "kuznecov-i11031965@postgrespro.ru", "phone": "+70527475337"}
0005433754555	A1DEEA	8227 296652	VLADIMIR EGOROV	{"email": "egorovvladimir.1981@postgrespro.ru", "phone": "+70679348304"}
0005433754556	5CA94C	7670 998258	NIKOLAY MARTYNOV	{"email": "martynov.n091973@postgrespro.ru", "phone": "+70922005684"}
0005433754557	57E53B	5402 644700	GALINA SOKOLOVA	{"phone": "+70822953522"}
0005433754558	6FFA69	0569 477918	YURIY GRIGOREV	{"email": "grigorev_yuriy041960@postgrespro.ru", "phone": "+70505397054"}
0005433754559	64AD63	0386 007242	VITALIY YAKOVLEV	{"email": "vyakovlev07041968@postgrespro.ru", "phone": "+70402473523"}
0005433754560	9D5922	4581 081308	ZINAIDA IVANOVA	{"email": "zinaida_ivanova1968@postgrespro.ru", "phone": "+70872237940"}
0005433754561	9D5922	7174 742497	NINA OSIPOVA	{"phone": "+70708662342"}
0005433754562	57A406	4801 598055	EKATERINA TROFIMOVA	{"email": "trofimova_e.12021987@postgrespro.ru", "phone": "+70264340026"}
0005433754563	E1034F	2714 972489	ALEKSANDRA ERMAKOVA	{"email": "aleksandra-ermakova-041976@postgrespro.ru", "phone": "+70691491009"}
0005433754564	C2F0A1	1807 977910	NATALYA SMIRNOVA	{"email": "smirnova-n_1975@postgrespro.ru", "phone": "+70490416948"}
0005433754565	D0B9EF	1489 432250	SVETLANA IVANOVA	{"phone": "+70163901560"}
0005433754566	9DE44E	8787 953208	OKSANA FEDOROVA	{"phone": "+70455953202"}
0005433754567	9DE44E	8671 158934	NATALYA KRASNOVA	{"email": "krasnova_natalya07061967@postgrespro.ru", "phone": "+70055878651"}
0005433754568	2D7502	1227 308494	GEORGIY KUZNECOV	{"email": "g_kuznecov.06061970@postgrespro.ru", "phone": "+70268363838"}
0005433754569	0F07B5	6540 466651	NINA MALYSHEVA	{"email": "malysheva.n091974@postgrespro.ru", "phone": "+70595053693"}
0005433754570	EFAFCD	6089 634933	ALEKSANDR KOZLOV	{"phone": "+70511738447"}
0005433754571	5F0F91	2850 138856	LYUBOV ERMAKOVA	{"email": "ermakova.lyubov.121977@postgrespro.ru", "phone": "+70964045676"}
0005433754572	5F0F91	3256 505242	VIKTOR FROLOV	{"phone": "+70945070563"}
0005433754573	5F0F91	0429 316307	ALEKSEY STEPANOV	{"phone": "+70063945915"}
0005433754574	5F0F91	7096 366778	DANIYA BORISOVA	{"phone": "+70163838503"}
0005433754575	8E53E0	7096 840554	ILYA GERASIMOV	{"email": "ilya-gerasimov_1976@postgrespro.ru", "phone": "+70425158386"}
0005433754576	8E53E0	8433 517759	YURIY SOKOLOV	{"email": "sokolov.yuriy-1985@postgrespro.ru", "phone": "+70096320607"}
0005433754577	1CE4BB	5264 222708	YULIYA KOMAROVA	{"email": "yuliya-komarova_1974@postgrespro.ru", "phone": "+70517991365"}
0005433754578	9A501F	2810 084961	VALERIY STEPANOV	{"email": "v-stepanov_26091979@postgrespro.ru", "phone": "+70244629608"}
0005433754579	6A3167	7510 224684	ALEKSEY ZAYCEV	{"phone": "+70582470863"}
0005433754580	6A3167	2177 675502	YAKOV VASILEV	{"email": "y_vasilev.1973@postgrespro.ru", "phone": "+70027812412"}
0005433754581	E9D7F7	6437 307981	ALIYA MASLOVA	{"email": "aliya_maslova.1969@postgrespro.ru", "phone": "+70065718937"}
0005433754582	E9D7F7	9062 203220	SERGEY AFANASEV	{"phone": "+70248577143"}
0005433754583	CAAACF	2223 676327	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr07021983@postgrespro.ru", "phone": "+70339177163"}
0005433754584	841957	3064 591494	ROMAN RODIONOV	{"phone": "+70620916292"}
0005433754585	841957	3098 427743	MAKSIM FROLOV	{"email": "frolov_maksim-061973@postgrespro.ru", "phone": "+70465705464"}
0005433754586	CC29B8	3845 615852	IRINA EFIMOVA	{"email": "efimova_irina-05021969@postgrespro.ru", "phone": "+70027589159"}
0005433754587	89F8A7	3303 996230	SERGEY NOVIKOV	{"email": "novikovsergey071973@postgrespro.ru", "phone": "+70908221187"}
0005433754588	431B75	3305 385283	MAKSIM SERGEEV	{"email": "sergeev-maksim.1978@postgrespro.ru", "phone": "+70003890053"}
0005433754589	431B75	7865 051256	OLGA MAKAROVA	{"email": "makarovaolga.23091975@postgrespro.ru", "phone": "+70224717497"}
0005433754590	599652	7645 476167	EVGENIY MARTYNOV	{"email": "martynove.31031953@postgrespro.ru", "phone": "+70305324537"}
0005433754591	59AA03	9444 006961	NINA OSIPOVA	{"phone": "+70226852840"}
0005433754592	65C309	0145 579330	EVGENIY ILIN	{"email": "evgeniy-ilin.081975@postgrespro.ru", "phone": "+70656647431"}
0005433754593	048A02	7919 017550	ALEKSANDR ILIN	{"email": "ilin_aleksandr_011955@postgrespro.ru", "phone": "+70542518631"}
0005433754594	E3DF48	1856 097472	NURIYA SOKOLOVA	{"phone": "+70900391705"}
0005433754595	1F61A1	4926 417468	KONSTANTIN ROMANOV	{"phone": "+70080438740"}
0005433754596	685C3D	9004 282512	GENNADIY KUZMIN	{"email": "kuzmin-gennadiy-071969@postgrespro.ru", "phone": "+70566959395"}
0005433754597	C39A46	1498 345460	EVGENIY VOLKOV	{"phone": "+70343884492"}
0005433754598	696735	0611 766439	GENNADIY VASILEV	{"phone": "+70169618534"}
0005433754599	696735	1401 681473	NIKOLAY FEDOROV	{"phone": "+70264980261"}
0005433754600	2BC57F	0492 459676	STANISLAV BORISOV	{"phone": "+70304414403"}
0005433754601	2BC57F	3636 134067	POLINA KULIKOVA	{"email": "kulikova-polina1966@postgrespro.ru", "phone": "+70073085459"}
0005433754602	F5DFF7	2703 210373	ANDREY ZAKHAROV	{"email": "andreyzakharov091970@postgrespro.ru", "phone": "+70168878409"}
0005433754603	F5DFF7	3672 728815	VERA DAVYDOVA	{"email": "davydovav-09121969@postgrespro.ru", "phone": "+70318396290"}
0005433754604	56D570	3738 757219	VLADIMIR CHERNOV	{"email": "vladimir.chernov23051966@postgrespro.ru", "phone": "+70489642183"}
0005433754605	775BC1	3240 296767	KRISTINA DAVYDOVA	{"phone": "+70924606590"}
0005433754606	E17254	0279 526021	VIKTOR BONDARENKO	{"phone": "+70868219805"}
0005433754607	E17254	5845 725696	SERGEY SEMENOV	{"email": "sergeysemenov_1977@postgrespro.ru", "phone": "+70766090781"}
0005433754608	A02A15	5420 359999	OLGA SAVELEVA	{"phone": "+70414382419"}
0005433754609	A02A15	7669 993813	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey_14111965@postgrespro.ru", "phone": "+70402039397"}
0005433754610	A02A15	9716 096446	GALINA POPOVA	{"email": "galina_popova.05071975@postgrespro.ru", "phone": "+70871462629"}
0005433754611	734C58	5776 509223	OLGA ZAYCEVA	{"phone": "+70416202196"}
0005433754612	67643B	3855 998686	NATALYA VOLKOVA	{"email": "volkova-n-24041981@postgrespro.ru", "phone": "+70079251882"}
0005433754613	A0332C	5573 888614	TAMARA KONOVALOVA	{"phone": "+70673744740"}
0005433754614	8FA05E	0253 284236	ALEKSEY PAVLOV	{"phone": "+70000541172"}
0005433754615	AC54F2	3313 487105	ROMAN MIRONOV	{"email": "r.mironov_1962@postgrespro.ru", "phone": "+70597159295"}
0005433754616	976691	6424 616528	ANTON FILIPPOV	{"email": "antonfilippov1968@postgrespro.ru", "phone": "+70763067196"}
0005433754617	976691	1816 960640	VALENTINA DMITRIEVA	{"email": "v-dmitrieva11121979@postgrespro.ru", "phone": "+70623447894"}
0005433754618	9F9B36	7440 780841	IVAN DENISOV	{"phone": "+70131987266"}
0005433754619	D605F2	0034 611407	OLGA FROLOVA	{"phone": "+70348017025"}
0005433754620	B2AAA7	7831 451848	NIKOLAY GERASIMOV	{"phone": "+70720842623"}
0005433754621	1E12EF	9700 201169	TATYANA VOLKOVA	{"email": "volkovatatyana1974@postgrespro.ru", "phone": "+70450782502"}
0005433754622	1E12EF	4175 070841	SERGEY MATVEEV	{"email": "matveev-sergey1975@postgrespro.ru", "phone": "+70172920809"}
0005433754623	AE297F	5578 334174	VLADIMIR CHERNOV	{"phone": "+70362517815"}
0005433754624	D1955F	9073 865489	ANNA FOMINA	{"email": "anna.fomina1968@postgrespro.ru", "phone": "+70243342387"}
0005433754625	D88555	9889 542383	ANTON SAVELEV	{"phone": "+70067541740"}
0005433754626	33403A	0319 913859	SVETLANA YAKOVLEVA	{"email": "yakovlevas-1962@postgrespro.ru", "phone": "+70571173784"}
0005433754627	5A68DF	7840 051093	YULIYA KOROLEVA	{"phone": "+70522861389"}
0005433754628	7512CD	7564 772457	TATYANA SERGEEVA	{"phone": "+70322078406"}
0005433754629	AAC874	0795 606630	LIDIYA ALEKSANDROVA	{"phone": "+70386719627"}
0005433754630	992051	9716 982589	ANNA POPOVA	{"phone": "+70533168604"}
0005433754631	7D158F	2768 371560	VALENTINA TARASOVA	{"email": "tarasovav_1980@postgrespro.ru", "phone": "+70474982060"}
0005433754632	D9BB7B	3364 498566	TATYANA KUZNECOVA	{"phone": "+70241130972"}
0005433754633	747D9E	2005 520122	VITALIY MARTYNOV	{"email": "martynov-v-121969@postgrespro.ru", "phone": "+70253141717"}
0005433754634	747D9E	4414 899675	ANATOLIY CHERNOV	{"phone": "+70521534374"}
0005433754635	5C34A7	6815 820327	SVETLANA MIKHAYLOVA	{"phone": "+70859789433"}
0005433754636	5C34A7	5885 131763	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov-1972@postgrespro.ru", "phone": "+70576030574"}
0005433754637	5DF867	8025 268033	ELENA BARANOVA	{"phone": "+70675050136"}
0005433754638	003974	1458 971205	MARIYA POPOVA	{"phone": "+70952450703"}
0005433754639	003974	5924 270604	EVGENIY OSIPOV	{"email": "e_osipov_021967@postgrespro.ru", "phone": "+70074668656"}
0005433754640	DD9140	8423 839879	YULIYA NOVIKOVA	{"email": "ynovikova111966@postgrespro.ru", "phone": "+70747609510"}
0005433754641	96E1AA	1913 854172	VLADIMIR VOLKOV	{"phone": "+70268639758"}
0005433754642	96E1AA	4819 522728	DMITRIY ZHURAVLEV	{"phone": "+70412046955"}
0005433754643	2F1700	9039 256207	TATYANA ZOTOVA	{"phone": "+70677115000"}
0005433754644	C32A06	8490 716011	VIKTOR IVANOV	{"phone": "+70527849689"}
0005433754645	FBBB6A	8026 999367	NATALYA ROMANOVA	{"phone": "+70733943979"}
0005433754646	2D6FFC	6824 858990	NINA KOMAROVA	{"email": "komarova_n.091973@postgrespro.ru", "phone": "+70660830289"}
0005433754647	461290	9330 679904	BORIS VOLKOV	{"phone": "+70477130538"}
0005433754648	3D61D3	5178 066165	IVAN OSIPOV	{"email": "ivan_osipov_04031986@postgrespro.ru", "phone": "+70651833130"}
0005433754649	147BE1	0374 804508	MARYAM TIKHONOVA	{"phone": "+70121439314"}
0005433754650	147BE1	3669 411255	ALEKSEY KUZNECOV	{"phone": "+70483185954"}
0005433754651	929226	8659 308874	VYACHESLAV VLASOV	{"email": "vvlasov041968@postgrespro.ru", "phone": "+70588245661"}
0005433754652	929226	0986 289270	ELENA EGOROVA	{"email": "elena.egorova-091970@postgrespro.ru", "phone": "+70336543914"}
0005433754653	F9BF0C	3189 257348	LYUBOV MIRONOVA	{"email": "mironova_l.1963@postgrespro.ru", "phone": "+70399270793"}
0005433754654	50CD9A	2221 544262	ROMAN SERGEEV	{"email": "sergeev.roman101980@postgrespro.ru", "phone": "+70445132991"}
0005433754655	0B3947	9143 032050	NURIYA IVANOVA	{"phone": "+70714160997"}
0005433754656	D353E2	8645 614184	LIDIYA LAZAREVA	{"phone": "+70994050643"}
0005433754657	2A421C	2026 483308	IRINA SOKOLOVA	{"phone": "+70902200403"}
0005433754658	429C98	6920 989256	NADEZHDA ISAEVA	{"phone": "+70071544972"}
0005433754659	429C98	8518 633531	VLADIMIR NAZAROV	{"phone": "+70767440500"}
0005433754660	52396B	9405 224732	ANNA KUZMINA	{"email": "kuzminaanna-1976@postgrespro.ru", "phone": "+70024444222"}
0005433754661	52396B	6793 803316	POLINA DENISOVA	{"email": "p.denisova-1969@postgrespro.ru", "phone": "+70225125133"}
0005433754662	6CC1A9	4026 932661	NATALYA KUZNECOVA	{"phone": "+70998074881"}
0005433754663	6CC1A9	3467 411347	ANNA SEMENOVA	{"email": "semenova_a.091981@postgrespro.ru", "phone": "+70369643359"}
0005433754664	6F77FE	0509 045530	GENNADIY ABRAMOV	{"phone": "+70084940908"}
0005433754665	6F77FE	2880 535711	ELENA VOLKOVA	{"email": "volkovaelena1977@postgrespro.ru", "phone": "+70733701659"}
0005433754666	83712D	7746 696316	OKSANA VASILEVA	{"email": "vasilevaoksana-27071971@postgrespro.ru", "phone": "+70022517467"}
0005433754667	83712D	2103 343972	ELENA ZAKHAROVA	{"phone": "+70056129045"}
0005433754668	8661D0	1242 824074	VLADIMIR PETROV	{"email": "petrov_v_20081964@postgrespro.ru", "phone": "+70941346325"}
0005433754669	5ED5BA	1462 519589	YURIY GUSEV	{"email": "gusev_y_1976@postgrespro.ru", "phone": "+70677475484"}
0005433754670	3BD5DE	8733 790297	ALEKSEY ANDREEV	{"phone": "+70666513876"}
0005433754671	3BD5DE	8348 442964	ELENA TITOVA	{"phone": "+70715331845"}
0005433754672	3BD5DE	9208 050466	EVGENIY NAUMOV	{"email": "e-naumov1970@postgrespro.ru", "phone": "+70377019305"}
0005433754673	860D1B	3984 466469	TAMARA TARASOVA	{"email": "t_tarasova_121958@postgrespro.ru", "phone": "+70453505747"}
0005433754674	860D1B	6933 388114	IRINA MIKHAYLOVA	{"phone": "+70945968017"}
0005433754675	4A04F5	6150 033053	VLADA FOMINA	{"phone": "+70522979316"}
0005433754676	565DEB	1647 984199	ANNA BELOVA	{"phone": "+70299246620"}
0005433754677	155BEA	5551 316746	VERONIKA KOLESNIKOVA	{"phone": "+70867719112"}
0005433754678	93C48B	9313 352732	NADEZHDA PETROVA	{"email": "petrova.n.1972@postgrespro.ru", "phone": "+70600464457"}
0005433754679	B1436C	2560 400119	MARIYA NESTEROVA	{"phone": "+70238585571"}
0005433754680	184C1A	2368 584882	YURIY KRASNOV	{"phone": "+70235259529"}
0005433754681	457DE2	2424 897937	IGOR GRIGOREV	{"phone": "+70153500397"}
0005433754682	C62FF4	3592 946951	ALEKSEY FILIPPOV	{"email": "filippov-aleksey.10041968@postgrespro.ru", "phone": "+70994149664"}
0005433754683	C62FF4	2763 117706	ANASTASIYA FILATOVA	{"phone": "+70539999403"}
0005433754684	AF20FA	2472 625826	VLADIMIR ISAEV	{"email": "isaev_v.31081960@postgrespro.ru", "phone": "+70035913197"}
0005433754685	AF20FA	4642 034524	TAGIR KUZNECOV	{"email": "t_kuznecov021982@postgrespro.ru", "phone": "+70031740152"}
0005433754686	AF20FA	7211 383712	ANDREY ZHURAVLEV	{"phone": "+70136099118"}
0005433754687	8997EF	0112 048754	VIKTOR IVANOV	{"email": "ivanov-viktor.1987@postgrespro.ru", "phone": "+70874427725"}
0005433754688	FD62A1	5876 794328	IRINA VASILEVA	{"email": "irina_vasileva121974@postgrespro.ru", "phone": "+70412825101"}
0005433754689	D1A0C4	0947 524476	NATALYA YUDINA	{"phone": "+70617776719"}
0005433754690	577574	1171 025834	ELENA KONOVALOVA	{"email": "konovalova.elena1971@postgrespro.ru", "phone": "+70750117611"}
0005433754691	957700	4122 692082	GALINA MIKHAYLOVA	{"email": "galina_mikhaylova19121969@postgrespro.ru", "phone": "+70648188296"}
0005433754692	170F5C	2331 115555	LYUBOV MOISEEVA	{"phone": "+70434785028"}
0005433754693	8B1095	4241 675466	ELENA MELNIKOVA	{"phone": "+70208877726"}
0005433754694	C86304	8004 747751	EKATERINA KOMAROVA	{"email": "e.komarova-1979@postgrespro.ru", "phone": "+70786721869"}
0005433754695	AC0BEE	3536 063788	ANDREY ABRAMOV	{"email": "andreyabramov081970@postgrespro.ru", "phone": "+70032511824"}
0005433754696	81AF71	3806 185420	ANDREY ALEKSANDROV	{"phone": "+70452553997"}
0005433754697	623007	8742 577787	DENIS VASILEV	{"phone": "+70325321530"}
0005433754698	0BBA58	4040 262023	PETR SHEVCHENKO	{"email": "p-shevchenko-1969@postgrespro.ru", "phone": "+70335678951"}
0005433754699	0BBA58	5013 732525	ALEKSEY VOROBEV	{"email": "vorobev_aleksey_111978@postgrespro.ru", "phone": "+70884323502"}
0005433754700	0BBA58	4367 912391	ALEKSANDR MATVEEV	{"email": "a.matveev13041974@postgrespro.ru", "phone": "+70442940378"}
0005433754701	BA73D0	0705 117207	DANIIL FILIPPOV	{"email": "filippov_daniil-021979@postgrespro.ru", "phone": "+70356049786"}
0005433754702	821AD3	1536 966169	ZINAIDA PAVLOVA	{"phone": "+70526100840"}
0005433754703	821AD3	6591 634716	OLGA MOISEEVA	{"phone": "+70707178246"}
0005433754704	821AD3	9672 084157	EVDOKIYA MOROZOVA	{"email": "emorozova29011971@postgrespro.ru", "phone": "+70566227522"}
0005433754705	D080B1	3819 649480	LIDIYA STEPANOVA	{"phone": "+70935184320"}
0005433754706	D080B1	6838 585029	ARTEM BONDARENKO	{"phone": "+70969874429"}
0005433754707	A72829	1099 445561	ALEKSEY MATVEEV	{"phone": "+70246382309"}
0005433754708	968729	5171 767286	ALEKSANDR SOROKIN	{"email": "a_sorokin_071959@postgrespro.ru", "phone": "+70291144918"}
0005433754709	1E511A	3054 266384	NINA AKIMOVA	{"email": "nakimova-30041967@postgrespro.ru", "phone": "+70703652924"}
0005433754710	1E511A	0607 091074	ROZA KUZNECOVA	{"email": "r-kuznecova-17041966@postgrespro.ru", "phone": "+70573500386"}
0005433754711	1E511A	2395 998811	DMITRIY MAKAROV	{"email": "d.makarov.1976@postgrespro.ru", "phone": "+70693248941"}
0005433754712	C0DD10	7950 086654	KLAVDIYA ILINA	{"email": "k.ilina_1962@postgrespro.ru", "phone": "+70027022592"}
0005433754713	C0DD10	9625 640281	ANDREY IVANOV	{"email": "ivanova_1964@postgrespro.ru", "phone": "+70048323906"}
0005433754714	873860	7049 419682	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov-051974@postgrespro.ru", "phone": "+70627411562"}
0005433754715	627E5C	6034 703276	VLADISLAV SEMENOV	{"phone": "+70742242154"}
0005433754716	627E5C	2506 324968	SERGEY BORISOV	{"email": "sergey.borisov_1969@postgrespro.ru", "phone": "+70403396624"}
0005433754717	627E5C	8788 727820	EKATERINA SERGEEVA	{"email": "sergeeva-ekaterina_1973@postgrespro.ru", "phone": "+70122259356"}
0005433754718	D8B880	0256 947484	ALEKSANDR KARPOV	{"email": "a_karpov-1962@postgrespro.ru", "phone": "+70928525071"}
0005433754719	D8B880	0180 669162	IRINA KOZLOVA	{"phone": "+70797948057"}
0005433754720	20661C	5104 909059	SVYATOSLAV SEMENOV	{"email": "ssemenov.021982@postgrespro.ru", "phone": "+70277549678"}
0005433754721	E0EBE4	9125 196967	NATALIYA SOKOLOVA	{"email": "sokolova_n-03081966@postgrespro.ru", "phone": "+70064765480"}
0005433754722	D5E39A	4470 340377	NADEZHDA ROMANOVA	{"email": "romanova_n.111974@postgrespro.ru", "phone": "+70827178841"}
0005433754723	FB65D8	4300 060907	DMITRIY KUZNECOV	{"email": "kuznecov-d_23101977@postgrespro.ru", "phone": "+70146999624"}
0005433754724	312ECD	1447 297543	GALINA GORBUNOVA	{"email": "galina-gorbunova.18071976@postgrespro.ru", "phone": "+70854395772"}
0005433754725	16DA17	8004 437415	NATALYA ANISIMOVA	{"phone": "+70009317224"}
0005433754726	C6F1A9	2555 171469	ANNA TIKHONOVA	{"email": "anna_tikhonova.02021966@postgrespro.ru", "phone": "+70739433928"}
0005433754727	5FEF23	3569 612284	EVGENIY TIKHONOV	{"email": "e-tikhonov_1970@postgrespro.ru", "phone": "+70686503714"}
0005433754728	5BEB0F	8021 270259	SERGEY MAKAROV	{"email": "makarovs-14091973@postgrespro.ru", "phone": "+70015840905"}
0005433754729	5E4EE5	0382 862007	ALEKSANDRA VOROBEVA	{"email": "a-vorobeva_1991@postgrespro.ru", "phone": "+70509412598"}
0005433754730	9E1457	8035 468402	KIRILL AFANASEV	{"phone": "+70661460861"}
0005433754731	0DE53C	9467 254488	ALEKSANDRA ZOTOVA	{"email": "zotova_aleksandra-07101976@postgrespro.ru", "phone": "+70096296334"}
0005433754732	6A1ADF	8666 550728	LYUDMILA ANTONOVA	{"email": "antonova-l.09021964@postgrespro.ru", "phone": "+70740651951"}
0005433754733	6A1ADF	3522 234947	PETR ORLOV	{"phone": "+70340994775"}
0005433754734	D94741	9952 168179	ALEKSEY NAZAROV	{"email": "aleksey.nazarov-061969@postgrespro.ru", "phone": "+70660111937"}
0005433754735	99D551	5190 503800	LYUBOV NESTEROVA	{"email": "l_nesterova_01091976@postgrespro.ru", "phone": "+70404549644"}
0005433754736	99D551	3279 616623	IRINA ZHUKOVA	{"email": "zhukova_irina-1982@postgrespro.ru", "phone": "+70584178522"}
0005433754737	6EF98E	3553 901207	SVETLANA PETROVA	{"email": "petrova-svetlana-031974@postgrespro.ru", "phone": "+70381085557"}
0005433754738	C1C066	8150 343542	ALEKSEY DMITRIEV	{"email": "a.dmitriev-091977@postgrespro.ru", "phone": "+70012904790"}
0005433754739	C1C066	0486 911968	DMITRIY KUZNECOV	{"phone": "+70559826087"}
0005433754740	93694C	8897 762915	NIKITA KOROLEV	{"email": "korolev.nikita-071965@postgrespro.ru", "phone": "+70015062326"}
0005433754741	57F521	6590 819908	VARVARA GORBUNOVA	{"phone": "+70164499475"}
0005433754742	358916	3630 455911	IRINA VLASOVA	{"email": "vlasova.irina.1988@postgrespro.ru", "phone": "+70913087469"}
0005433754743	1916ED	4378 184734	VALENTINA SEMENOVA	{"phone": "+70131589288"}
0005433754744	1916ED	5448 749470	VIKTOR ISAEV	{"email": "isaev.viktor_1975@postgrespro.ru", "phone": "+70711192849"}
0005433754745	E238E5	8201 838876	DMITRIY ZHURAVLEV	{"email": "zhuravlev.dmitriy08061981@postgrespro.ru", "phone": "+70828630363"}
0005433754746	889304	5563 219293	NIKOLAY DENISOV	{"phone": "+70673669011"}
0005433754747	BFC157	9644 497952	ANATOLIY GAVRILOV	{"phone": "+70909949358"}
0005433754748	BFC157	1366 857836	ELENA KOLESNIKOVA	{"email": "e-kolesnikova041976@postgrespro.ru", "phone": "+70085267940"}
0005433754749	E77BE9	7469 758751	VIKTOR KUZMIN	{"email": "v.kuzmin-1975@postgrespro.ru", "phone": "+70978162842"}
0005433754750	E77BE9	2544 067431	NIKOLAY DMITRIEV	{"email": "nikolay-dmitriev121972@postgrespro.ru", "phone": "+70487864362"}
0005433754751	396011	7938 847722	NATALYA SEMENOVA	{"phone": "+70180281464"}
0005433754752	396011	1454 769666	NATALYA ANTONOVA	{"phone": "+70377614794"}
0005433754753	396011	0993 768988	YULIYA GERASIMOVA	{"email": "y_gerasimova_041970@postgrespro.ru", "phone": "+70581932573"}
0005433754754	09E235	4587 199162	ELENA LEBEDEVA	{"phone": "+70266684910"}
0005433754755	EB295F	3568 683632	NIKOLAY RODIONOV	{"phone": "+70520373058"}
0005433754756	75D9B0	6542 292492	VLADIMIR SOLOVEV	{"email": "solovev_vladimir21041965@postgrespro.ru", "phone": "+70836510290"}
0005433754757	75D9B0	0804 891722	ANASTASIYA VASILEVA	{"phone": "+70071930121"}
0005433754758	510FE9	3679 912465	EVGENIY RODIONOV	{"email": "evgeniy.rodionov011975@postgrespro.ru", "phone": "+70302018902"}
0005433754759	501455	4115 958465	NIKOLAY NIKOLAEV	{"phone": "+70576205292"}
0005433754760	150354	2650 292458	OLEG IVANOV	{"phone": "+70094433932"}
0005433754761	93DC16	7721 616679	ELENA PAVLOVA	{"phone": "+70279599907"}
0005433754762	402B56	0505 383779	KARINA ANDREEVA	{"phone": "+70340924440"}
0005433754763	402B56	0996 635495	TATYANA SERGEEVA	{"email": "tatyana_sergeeva-011970@postgrespro.ru", "phone": "+70370487399"}
0005433754764	F5C83F	3798 899865	VITALIY MARTYNOV	{"phone": "+70516592284"}
0005433754765	F5C83F	9429 536360	NIKITA FROLOV	{"email": "frolov_n121980@postgrespro.ru", "phone": "+70126119750"}
0005433754766	D7D451	1417 786243	LYUDMILA MOROZOVA	{"phone": "+70090097085"}
0005433754767	97A52C	4443 410950	EVGENIY SAVELEV	{"phone": "+70606929242"}
0005433754768	274B0F	3159 526056	ANGELINA ALEKSEEVA	{"email": "alekseevaa.1973@postgrespro.ru", "phone": "+70986948401"}
0005433754769	DBF567	5103 253200	MIKHAIL IVANOV	{"phone": "+70053535333"}
0005433754770	8AD058	6788 407709	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin-081973@postgrespro.ru", "phone": "+70799898131"}
0005433754771	83704C	9112 085502	LYUBOV FILIPPOVA	{"email": "filippovalyubov.111966@postgrespro.ru", "phone": "+70111115119"}
0005433754772	17942D	5013 177827	ALEKSANDR SIDOROV	{"email": "a_sidorov-04121965@postgrespro.ru", "phone": "+70496811935"}
0005433754773	DCD88A	8201 183358	VLADIMIR MOROZOV	{"phone": "+70278925788"}
0005433754774	B2A658	4167 784580	VALERIY ZAYCEV	{"phone": "+70272690671"}
0005433754775	461F73	7353 077485	ROMAN SEMENOV	{"email": "semenov.r.1971@postgrespro.ru", "phone": "+70499994940"}
0005433754776	C8E33E	0150 472529	MARGARITA ALEKSEEVA	{"email": "m_alekseeva.1967@postgrespro.ru", "phone": "+70796809440"}
0005433754777	20873F	2423 312358	LEV VOROBEV	{"email": "l.vorobev_051977@postgrespro.ru", "phone": "+70575343056"}
0005433754778	525A0F	8573 444370	RAIL MATVEEV	{"email": "railmatveev_1970@postgrespro.ru", "phone": "+70428211889"}
0005433754779	55931F	8964 484925	ANATOLIY MIRONOV	{"phone": "+70249624247"}
0005433754780	84EA1D	1985 702930	FILIPP ZHURAVLEV	{"phone": "+70886875418"}
0005433754781	84EA1D	5621 864736	VITALIY ROMANOV	{"phone": "+70821434376"}
0005433754782	5C7614	7819 961280	VIKTOR PAVLOV	{"email": "pavlov_v.041965@postgrespro.ru", "phone": "+70067479925"}
0005433754783	A6DFE6	3567 027196	ELENA FILATOVA	{"email": "filatova.e_1961@postgrespro.ru", "phone": "+70454138842"}
0005433754784	A9C034	6067 581563	MAKSIM STEPANOV	{"email": "maksimstepanov_10021985@postgrespro.ru", "phone": "+70341397836"}
0005433754785	A9C034	2855 932439	EVA KOZLOVA	{"phone": "+70342671454"}
0005433754786	383232	9769 407026	VLADIMIR FROLOV	{"email": "v_frolov_1972@postgrespro.ru", "phone": "+70263893472"}
0005433754787	383232	8488 262886	LYUBOV KAZAKOVA	{"email": "kazakova.l_061976@postgrespro.ru", "phone": "+70949781912"}
0005433754788	8EBAED	2280 212305	ILYA ZAKHAROV	{"phone": "+70211712443"}
0005433754789	8EBAED	2814 828196	LYUBOV POPOVA	{"email": "popova-lyubov-071967@postgrespro.ru", "phone": "+70404484041"}
0005433754790	1DC6AC	7368 140733	NATALYA NESTEROVA	{"email": "nesterova_n-22101984@postgrespro.ru", "phone": "+70313686663"}
0005433754791	5D641B	4327 052391	VLADIMIR IVANOV	{"phone": "+70771634679"}
0005433754792	05B78C	5533 299328	ALEKSANDR NIKOLAEV	{"phone": "+70112107910"}
0005433754793	9E3D84	3801 591596	YURIY MIKHAYLOV	{"email": "mikhaylov-y-1959@postgrespro.ru", "phone": "+70022192549"}
0005433754794	9E3D84	2425 480386	MARIYA ALEKSANDROVA	{"phone": "+70721583930"}
0005433754795	519BB2	4408 204353	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr_1980@postgrespro.ru", "phone": "+70616433734"}
0005433754796	288ADF	9783 222817	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr.19121976@postgrespro.ru", "phone": "+70971880270"}
0005433754797	288ADF	5582 863328	NATALYA POPOVA	{"email": "natalya.popova.111974@postgrespro.ru", "phone": "+70423860915"}
0005433754798	B3302E	4770 987303	ADELINA NAZAROVA	{"phone": "+70062526028"}
0005433754799	4DEED6	3511 145975	VALERIY IVANOV	{"phone": "+70587989655"}
0005433754800	6C6BC0	0350 701482	VALERIYA PAVLOVA	{"email": "valeriya_pavlova.091969@postgrespro.ru", "phone": "+70058740460"}
0005433754801	6C6BC0	6660 408112	VIKTOR CHERNOV	{"email": "chernov.v.011980@postgrespro.ru", "phone": "+70734094441"}
0005433754802	6E99F9	9146 397957	IVAN SOLOVEV	{"email": "solovevi_03071971@postgrespro.ru", "phone": "+70364855090"}
0005433754803	627553	5402 598228	IRINA KOVALEVA	{"phone": "+70934025037"}
0005433754804	627553	1357 460111	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev-1974@postgrespro.ru", "phone": "+70941583310"}
0005433754805	627553	4418 178207	ROMAN PAVLOV	{"phone": "+70728538663"}
0005433754806	E1BE9D	9379 540822	RUSLAN MOROZOV	{"email": "ruslanmorozov.011969@postgrespro.ru", "phone": "+70734390646"}
0005433754807	5070AD	7546 750369	VLADISLAV NOVIKOV	{"email": "novikov_vladislav.011985@postgrespro.ru", "phone": "+70994404010"}
0005433754808	1832A5	1316 408443	ALEKSANDR KUZMIN	{"email": "akuzmin_19041962@postgrespro.ru", "phone": "+70476590910"}
0005433754809	1832A5	7071 613086	ANASTASIYA ZHUKOVA	{"phone": "+70854038608"}
0005433754810	A55A99	7388 457625	SERGEY FOMIN	{"email": "s.fomin-17081973@postgrespro.ru", "phone": "+70760408514"}
0005433754811	C7E68D	3359 418158	LIDIYA POPOVA	{"phone": "+70156271466"}
0005433754812	F959EC	2713 462372	ELENA FILIPPOVA	{"email": "elena.filippova-23091968@postgrespro.ru", "phone": "+70275215821"}
0005433754813	F959EC	0720 032240	OLEG NIKOLAEV	{"phone": "+70104066619"}
0005433754814	F959EC	0021 559937	ROMAN ZHUKOV	{"email": "romanzhukov-1989@postgrespro.ru", "phone": "+70102833470"}
0005433754815	4FB3FF	7909 783185	ALEKSANDR SIDOROV	{"email": "asidorov_10101986@postgrespro.ru", "phone": "+70962095372"}
0005433754816	4FB3FF	7806 400766	EKATERINA ANTONOVA	{"email": "antonova.ekaterina20051965@postgrespro.ru", "phone": "+70395974328"}
0005433754817	455013	7585 723906	IRINA SIDOROVA	{"phone": "+70936096565"}
0005433754818	455013	1912 495864	TAMARA VASILEVA	{"email": "vasileva-tamara.13041964@postgrespro.ru", "phone": "+70207945768"}
0005433754819	76B8ED	7874 883033	DINA BOGDANOVA	{"email": "dina_bogdanova_1977@postgrespro.ru", "phone": "+70469394192"}
0005433754820	76B8ED	4779 875009	SERGEY KUZMIN	{"email": "kuzmin.s061974@postgrespro.ru", "phone": "+70680766310"}
0005433754821	588349	6749 803773	ALEKSANDR ANDREEV	{"phone": "+70014505249"}
0005433754822	588349	6436 494633	NINA ZHURAVLEVA	{"phone": "+70680447671"}
0005433754823	588349	6169 032219	VLADIMIR SCHERBAKOV	{"email": "scherbakovvladimir_11091963@postgrespro.ru", "phone": "+70565732335"}
0005433754824	378DD4	4525 710114	MARINA MATVEEVA	{"phone": "+70566023967"}
0005433754825	378DD4	0726 012380	MARINA MAKAROVA	{"email": "m_makarova-1971@postgrespro.ru", "phone": "+70016582523"}
0005433754826	55DFDB	3932 407766	RAISA MAKAROVA	{"email": "makarova_raisa03071965@postgrespro.ru", "phone": "+70188635513"}
0005433754827	C27E4F	8353 044891	TATYANA NESTEROVA	{"phone": "+70979894781"}
0005433754828	86208D	7975 191420	ILYA NIKITIN	{"email": "nikitin-i.1979@postgrespro.ru", "phone": "+70305935963"}
0005433754829	25C37F	5098 471193	OLGA DENISOVA	{"phone": "+70299069088"}
0005433754830	821A2C	9397 009090	VIKTOR NIKITIN	{"phone": "+70090806709"}
0005433754831	4FDBF5	0918 820064	OLEG SOROKIN	{"email": "osorokin.041978@postgrespro.ru", "phone": "+70639991092"}
0005433754832	E148EE	9022 509497	ANDREY MIKHAYLOV	{"email": "mikhaylov_andrey07031989@postgrespro.ru", "phone": "+70580883465"}
0005433754833	E148EE	3245 528372	VLADIMIR ILIN	{"email": "ilin_v.1967@postgrespro.ru", "phone": "+70434416819"}
0005433754834	8B6AA3	4854 363526	VLADIMIR DMITRIEV	{"email": "dmitriev_vladimir-1978@postgrespro.ru", "phone": "+70463234606"}
0005433754835	4EBCD9	9453 192592	GALINA KAZAKOVA	{"email": "g-kazakova.061970@postgrespro.ru", "phone": "+70939551845"}
0005433754836	CAFD83	6396 157857	VIKTOR SERGEEV	{"email": "sergeevviktor28041980@postgrespro.ru", "phone": "+70283509538"}
0005433754837	EEE1F1	6829 511835	OKSANA MIRONOVA	{"email": "oksanamironova.1963@postgrespro.ru", "phone": "+70361823842"}
0005433754838	8FBBAC	4657 416261	SVETLANA MATVEEVA	{"email": "matveeva.svetlana-1967@postgrespro.ru", "phone": "+70623516184"}
0005433754839	FA3A5C	6474 398482	VIKTOR ALEKSEEV	{"phone": "+70015335031"}
0005433754840	63790A	3256 594696	TATYANA ALEKSEEVA	{"phone": "+70282474980"}
0005433754841	63790A	7243 623253	ANASTASIYA TROFIMOVA	{"email": "anastasiya-trofimova071973@postgrespro.ru", "phone": "+70542206565"}
0005433754842	D9025E	2367 399320	DMITRIY SEMENOV	{"email": "semenov-dmitriy1973@postgrespro.ru", "phone": "+70138425888"}
0005433754843	D9025E	4877 067626	LARISA ZHUKOVA	{"email": "zhukova-l081970@postgrespro.ru", "phone": "+70347750093"}
0005433754844	4B1B2E	9753 664012	ALEKSEY VLASOV	{"email": "vlasov_a.19031967@postgrespro.ru", "phone": "+70428641266"}
0005433754845	4B1B2E	7879 298768	ANDREY NAUMOV	{"email": "naumov-andrey-23031970@postgrespro.ru", "phone": "+70819148084"}
0005433754846	51C5FA	9418 144630	ANNA MEDVEDEVA	{"phone": "+70885020587"}
0005433754847	51C5FA	8960 938092	POLINA AFANASEVA	{"email": "afanasevap.02111971@postgrespro.ru", "phone": "+70926907972"}
0005433754848	51C5FA	7459 736217	EVDOKIYA MAKAROVA	{"email": "makarova-e23091987@postgrespro.ru", "phone": "+70714602297"}
0005433754849	35FDED	7827 761612	ROMAN VASILEV	{"email": "vasilev_roman-04071978@postgrespro.ru", "phone": "+70250766534"}
0005433754850	8573F9	3091 249722	PAVEL ROMANOV	{"email": "pavel.romanov_111984@postgrespro.ru", "phone": "+70260237619"}
0005433754851	8573F9	5741 588091	NATALYA ARKHIPOVA	{"email": "natalya-arkhipova-1966@postgrespro.ru", "phone": "+70026895503"}
0005433754852	F28429	1152 346171	DMITRIY RODIONOV	{"email": "rodionov_d_011978@postgrespro.ru", "phone": "+70653781411"}
0005433754853	245192	4335 478282	IRINA ZAKHAROVA	{"phone": "+70102564128"}
0005433754854	245192	3158 253287	ELENA ALEKSANDROVA	{"email": "e-aleksandrova.1977@postgrespro.ru", "phone": "+70522744949"}
0005433754855	3D56BB	4584 182804	ANNA FEDOROVA	{"phone": "+70761399164"}
0005433754856	3D56BB	0000 430580	VALENTINA ANDREEVA	{"email": "andreeva.v_011967@postgrespro.ru", "phone": "+70334952911"}
0005433754857	398EEA	6119 522031	OLGA NAZAROVA	{"phone": "+70370490753"}
0005433754858	398EEA	7599 612777	ALEKSEY MELNIKOV	{"email": "melnikov-a_1982@postgrespro.ru", "phone": "+70530132015"}
0005433754859	60A8AF	3635 649517	TAMARA KISELEVA	{"phone": "+70538491006"}
0005433754860	A98362	8319 042675	VIKTOR ALEKSEEV	{"email": "alekseev.viktor.071969@postgrespro.ru", "phone": "+70337546366"}
0005433754861	B02169	9102 832411	NINA POLYAKOVA	{"phone": "+70500996239"}
0005433754862	A4EBB4	0379 697655	GALINA KOMAROVA	{"phone": "+70935338830"}
0005433754863	44FED1	6478 733407	IVAN KARPOV	{"email": "i-karpov-111974@postgrespro.ru", "phone": "+70257167556"}
0005433754864	2BBBEE	6734 143975	ANATOLIY KRASNOV	{"phone": "+70916764089"}
0005433754865	2BBBEE	8089 682282	ALEKSEY KOZLOV	{"email": "a_kozlov.031974@postgrespro.ru", "phone": "+70893094468"}
0005433754866	2BBBEE	8115 602309	ANDREY FILIPPOV	{"email": "a_filippov-1971@postgrespro.ru", "phone": "+70060754905"}
0005433754867	6C2F32	5166 333417	IGOR GERASIMOV	{"phone": "+70522106765"}
0005433754868	6C2F32	1067 136490	NIKOLAY ANDREEV	{"phone": "+70509031177"}
0005433754869	6C2F32	3236 189586	DENIS PAVLOV	{"email": "d-pavlov.26081980@postgrespro.ru", "phone": "+70033738319"}
0005433754870	943B09	2974 541128	GRIGORIY FEDOROV	{"email": "g.fedorov041969@postgrespro.ru", "phone": "+70799136160"}
0005433754871	96A8F9	4874 885092	LYUDMILA ORLOVA	{"phone": "+70718882183"}
0005433754872	D57366	3951 375793	OLGA MATVEEVA	{"email": "omatveeva-05091964@postgrespro.ru", "phone": "+70764404290"}
0005433754873	449377	6017 121125	VIKTOR SOLOVEV	{"email": "solovevviktor071989@postgrespro.ru", "phone": "+70828633961"}
0005433754874	449377	2585 585759	ANATOLIY PAVLOV	{"email": "pavlov_anatoliy.1994@postgrespro.ru", "phone": "+70191512164"}
0005433754875	D2F1AD	0920 538365	DMITRIY GRIGOREV	{"phone": "+70934624373"}
0005433754876	D2F1AD	3550 823660	KRISTINA GUSEVA	{"phone": "+70941395575"}
0005433754877	D2F1AD	4945 407407	IVAN NIKITIN	{"email": "nikitin.ivan.31031970@postgrespro.ru", "phone": "+70209303230"}
0005433754878	9AF8A7	5176 358637	ARTEM SOKOLOV	{"phone": "+70169136306"}
0005433754879	9AF8A7	8683 742657	SVETLANA MAKSIMOVA	{"phone": "+70144019312"}
0005433754880	0A1132	3663 618374	MARIANNA KOROLEVA	{"phone": "+70499286289"}
0005433754881	0A1132	7264 284096	NATALYA KISELEVA	{"phone": "+70233241985"}
0005433754882	377B9D	0446 209664	ELENA GERASIMOVA	{"phone": "+70608016074"}
0005433754883	377B9D	3424 614857	DMITRIY VOLKOV	{"email": "volkov.d-1958@postgrespro.ru", "phone": "+70530001778"}
0005433754884	A42F1F	8285 122566	IRINA STEPANOVA	{"phone": "+70921775706"}
0005433754885	A42F1F	0908 883044	VIKTOR BELOV	{"phone": "+70151220371"}
0005433754886	10A681	6808 369967	ANASTASIYA ANDREEVA	{"email": "andreevaa13091978@postgrespro.ru", "phone": "+70205325066"}
0005433754887	1D2358	3753 579175	ANDREY MAKAROV	{"email": "andreymakarov041985@postgrespro.ru", "phone": "+70125194636"}
0005433754888	1D2358	0091 682793	LYUDMILA MIKHAYLOVA	{"phone": "+70702370799"}
0005433754889	5B98DB	1341 307547	ANDREY FOMIN	{"phone": "+70364308323"}
0005433754890	5B98DB	0268 440011	ANTONINA VASILEVA	{"email": "antonina-vasileva-1987@postgrespro.ru", "phone": "+70677769038"}
0005433754891	5D6535	5007 522985	ALEKSANDR KUZNECOV	{"email": "kuznecov-a.021974@postgrespro.ru", "phone": "+70334571347"}
0005433754892	5D6535	6827 042278	ALEKSANDR VOROBEV	{"phone": "+70479222608"}
0005433754893	77EADF	4327 520187	MARIYA YAKOVLEVA	{"email": "yakovlevamariya24021969@postgrespro.ru", "phone": "+70585983916"}
0005433754894	F4EB95	6928 194207	YULIYA SEMENOVA	{"email": "y.semenova071979@postgrespro.ru", "phone": "+70950890823"}
0005433754895	195291	5827 309082	PAVEL SCHERBAKOV	{"email": "pscherbakov.1982@postgrespro.ru", "phone": "+70377244614"}
0005433754896	ED78F6	9342 148778	EVGENIY VASILEV	{"email": "vasilevevgeniy_121984@postgrespro.ru", "phone": "+70454936318"}
0005433754897	ED78F6	8998 881464	EKATERINA NESTEROVA	{"phone": "+70298790822"}
0005433754898	21929B	4987 503108	SERGEY SOLOVEV	{"email": "solovev.sergey_1974@postgrespro.ru", "phone": "+70849905628"}
0005433754899	303F6F	7750 868232	PAVEL PETROV	{"phone": "+70630131602"}
0005433754900	0E0B34	5335 545460	OLGA YUDINA	{"phone": "+70583644195"}
0005433754901	58D339	8522 750113	ARINA MAKAROVA	{"email": "a_makarova-111971@postgrespro.ru", "phone": "+70724173452"}
0005433754902	58D339	4989 676743	KONSTANTIN FILIPPOV	{"phone": "+70270922448"}
0005433754903	4F4723	2001 698339	DIANA NIKOLAEVA	{"phone": "+70506555802"}
0005433754904	43F655	6365 317265	TATYANA BOGDANOVA	{"email": "tatyanabogdanova_1981@postgrespro.ru", "phone": "+70849055810"}
0005433754905	1235A2	3547 167546	RADIK BARANOV	{"email": "radik-baranov.1974@postgrespro.ru", "phone": "+70865793412"}
0005433754906	26A2ED	3094 604021	ILYA OSIPOV	{"email": "osipov.ilya1970@postgrespro.ru", "phone": "+70960330510"}
0005433754907	07B818	3921 978840	VLADIMIR PAVLOV	{"phone": "+70626390212"}
0005433754908	07B818	6042 370842	SERGEY ANTONOV	{"email": "antonovsergey10071980@postgrespro.ru", "phone": "+70966500039"}
0005433754909	CC4E06	4624 106183	ANDREY CHERNOV	{"email": "andrey-chernov011971@postgrespro.ru", "phone": "+70299606543"}
0005433754910	224AC3	1328 931373	ANASTASIYA ILINA	{"email": "ilina_anastasiya.021980@postgrespro.ru", "phone": "+70700356832"}
0005433754911	224AC3	8741 581437	EGOR ABRAMOV	{"phone": "+70991327277"}
0005433754912	224AC3	8259 742280	ALBINA POLYAKOVA	{"email": "apolyakova-091976@postgrespro.ru", "phone": "+70705229826"}
0005433754913	3DD675	4844 213730	ALEKSANDR SMIRNOV	{"phone": "+70321000765"}
0005433754914	77C9DE	8127 174614	GALINA KOZLOVA	{"email": "kozlova_g1973@postgrespro.ru", "phone": "+70866155181"}
0005433754915	51B927	7629 937882	YULIYA TIKHONOVA	{"phone": "+70197309883"}
0005433754916	AA7EEE	6852 344379	ALEKSANDR CHERNOV	{"phone": "+70996786794"}
0005433754917	0E4357	2666 815875	PAVEL TARASOV	{"phone": "+70602158130"}
0005433754918	B33944	4168 464161	ELENA DAVYDOVA	{"phone": "+70796521114"}
0005433754919	C899D0	5725 004068	NATALIYA KARPOVA	{"email": "nataliya_karpova041967@postgrespro.ru", "phone": "+70698437996"}
0005433754920	6FA30B	6047 089498	NATALYA AFANASEVA	{"email": "afanaseva.n_101972@postgrespro.ru", "phone": "+70022742281"}
0005433754921	2FE1D8	6321 501635	NATALYA FEDOROVA	{"phone": "+70183826941"}
0005433754922	2FE1D8	7188 095786	TAISIYA POPOVA	{"email": "popovataisiya-091971@postgrespro.ru", "phone": "+70774365707"}
0005433754923	F21C97	8105 805739	NATALYA MAKAROVA	{"email": "makarova-natalya_051963@postgrespro.ru", "phone": "+70463639195"}
0005433754924	C5A094	1533 243811	RINAT VOLKOV	{"phone": "+70528278456"}
0005433754925	0F63CD	3650 692980	VLADISLAV DMITRIEV	{"phone": "+70406087731"}
0005433754926	0F63CD	9539 485460	STEPAN IVANOV	{"phone": "+70924954621"}
0005433754927	0F63CD	0937 064442	VENERA ZHUKOVA	{"email": "zhukova.venera-01081972@postgrespro.ru", "phone": "+70915675879"}
0005433754928	CBCD58	1096 866403	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov.1977@postgrespro.ru", "phone": "+70906094278"}
0005433754929	D07AC1	3411 686976	EKATERINA ISAEVA	{"email": "e.isaeva-1972@postgrespro.ru", "phone": "+70875915091"}
0005433754930	67F82E	8078 145854	DAMIR SAVELEV	{"email": "savelevdamir121978@postgrespro.ru", "phone": "+70039449472"}
0005433754931	67F82E	6906 905847	VIKTORIYA ANISIMOVA	{"email": "anisimovav_071978@postgrespro.ru", "phone": "+70560807165"}
0005433754932	E53BBD	8384 159027	IRINA MAKAROVA	{"email": "irinamakarova_041978@postgrespro.ru", "phone": "+70356991894"}
0005433754933	BEAE84	4645 265650	NATALYA VOROBEVA	{"email": "n.vorobeva.1966@postgrespro.ru", "phone": "+70573711828"}
0005433754934	BEAE84	7770 697356	VLADISLAV ALEKSANDROV	{"phone": "+70855196227"}
0005433754935	888058	8073 534108	ANTONINA FEDOROVA	{"phone": "+70057365111"}
0005433754936	888058	9399 397940	NIKOLAY DAVYDOV	{"phone": "+70198879555"}
0005433754937	30511C	1018 892790	ALESYA ZAYCEVA	{"email": "a_zayceva_16051974@postgrespro.ru", "phone": "+70118794797"}
0005433754938	30511C	6656 926578	LYUBOV SIDOROVA	{"email": "sidoroval.1974@postgrespro.ru", "phone": "+70015511805"}
0005433754939	444525	3941 279335	ALEKSANDR FEDOROV	{"phone": "+70765123527"}
0005433754940	5F56A5	4941 900149	VALERIY CHERNOV	{"phone": "+70349372270"}
0005433754941	585A58	9198 659139	EVGENIY GERASIMOV	{"email": "gerasimov-evgeniy.011984@postgrespro.ru", "phone": "+70620541912"}
0005433754942	585A58	2422 085315	DMITRIY MAKAROV	{"email": "makarov.d_1973@postgrespro.ru", "phone": "+70605883406"}
0005433754943	D4B0E1	1809 601592	IVAN KARPOV	{"phone": "+70280742348"}
0005433754944	D4B0E1	8818 362302	EVGENIY EGOROV	{"phone": "+70427877409"}
0005433754945	81D48F	2906 224255	MIKHAIL SHEVCHENKO	{"email": "mikhail-shevchenko.1979@postgrespro.ru", "phone": "+70170001307"}
0005433754946	81D48F	1832 504329	NADEZHDA IVANOVA	{"email": "nadezhda-ivanova-1976@postgrespro.ru", "phone": "+70661064099"}
0005433754947	81D48F	5556 377408	DMITRIY FILIPPOV	{"phone": "+70789263582"}
0005433754948	81D48F	2107 761500	OLGA KOZLOVA	{"email": "okozlova-051974@postgrespro.ru", "phone": "+70772747862"}
0005433754949	4705D2	9719 893110	NIKOLAY PAVLOV	{"email": "n.pavlov.14041978@postgrespro.ru", "phone": "+70101591311"}
0005433754950	065B8C	4662 600916	ANATOLIY SAVELEV	{"email": "asavelev10111976@postgrespro.ru", "phone": "+70391581680"}
0005433754951	065B8C	0585 083378	MARIYA PETROVA	{"phone": "+70116836653"}
0005433754952	BA04FA	5926 911101	MARIYA RODIONOVA	{"phone": "+70305789975"}
0005433754953	A97030	5147 707348	GLEB BORISOV	{"phone": "+70829082059"}
0005433754954	A9B50E	1980 532332	IRINA POTAPOVA	{"email": "i.potapova_1981@postgrespro.ru", "phone": "+70957043859"}
0005433754955	028BD6	4575 210527	IRINA MOISEEVA	{"email": "moiseeva_i.101976@postgrespro.ru", "phone": "+70308013270"}
0005433754956	FCFD05	6386 996812	ALEKSEY SCHERBAKOV	{"phone": "+70212859031"}
0005433754957	4A5C61	4079 607823	ELENA ANISIMOVA	{"email": "e.anisimova-26051978@postgrespro.ru", "phone": "+70800988125"}
0005433754958	A72EEC	9846 056838	NIKOLAY ZHURAVLEV	{"phone": "+70377063431"}
0005433754959	A72EEC	3565 267853	NIKOLAY ABRAMOV	{"phone": "+70131461763"}
0005433754960	4C2AAE	1351 366158	OLGA NIKITINA	{"email": "o-nikitina_011966@postgrespro.ru", "phone": "+70694826449"}
0005433754961	189D41	7010 214598	GALINA KRASNOVA	{"phone": "+70496714492"}
0005433754962	7D743A	6953 669607	LIDIYA NOVIKOVA	{"email": "novikova_l-1981@postgrespro.ru", "phone": "+70537775344"}
0005433754963	3F2F71	2294 812541	NATALYA PAVLOVA	{"phone": "+70754236831"}
0005433754964	E2DBAC	8744 571610	MAKSIM SIDOROV	{"phone": "+70073292239"}
0005433754965	22568A	1367 194123	EVGENIYA VOLKOVA	{"phone": "+70065682945"}
0005433754966	CB8A16	8306 706128	NATALYA TITOVA	{"email": "titova_n-1974@postgrespro.ru", "phone": "+70640167073"}
0005433754967	CB8A16	2193 960888	GUZEL ERMAKOVA	{"phone": "+70184523947"}
0005433754968	C167A3	2284 392673	SERGEY IVANOV	{"phone": "+70168036252"}
0005433754969	C167A3	1825 332229	FEDOR NIKOLAEV	{"email": "nikolaev_f-091976@postgrespro.ru", "phone": "+70282146198"}
0005433754970	022586	0209 421128	IRINA POPOVA	{"phone": "+70704419370"}
0005433754971	022586	5365 771298	ALEKSEY BELOV	{"email": "a_belov_30081975@postgrespro.ru", "phone": "+70023127035"}
0005433754972	2C9049	1201 308179	LYUBOV DMITRIEVA	{"phone": "+70385514819"}
0005433754973	2C9049	5259 245744	SERGEY KULIKOV	{"email": "kulikov_s1971@postgrespro.ru", "phone": "+70269867143"}
0005433754974	438263	4482 096539	ELENA ARKHIPOVA	{"phone": "+70543939510"}
0005433754975	2F6ED2	2955 935420	INNA KALININA	{"email": "kalinina_i-23011977@postgrespro.ru", "phone": "+70943987513"}
0005433754976	709506	4841 950413	SVETLANA ZAKHAROVA	{"email": "zakharova_s-14041982@postgrespro.ru", "phone": "+70776017136"}
0005433754977	709506	2363 270638	VIKTOR VASILEV	{"email": "vasilev_viktor_1969@postgrespro.ru", "phone": "+70974627104"}
0005433754978	A7DD54	8085 798970	ELENA MOISEEVA	{"phone": "+70316678422"}
0005433754979	A404BC	0940 650588	ALEKSANDRA FOMINA	{"phone": "+70707000715"}
0005433754980	9D64E3	3997 329991	GEORGIY ILIN	{"email": "ilin.georgiy-041973@postgrespro.ru", "phone": "+70701002505"}
0005433754981	683BA0	5181 603684	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov.061976@postgrespro.ru", "phone": "+70260507332"}
0005433754982	1025E8	2842 526018	ALEKSANDR FOMIN	{"email": "fomin.a-021969@postgrespro.ru", "phone": "+70126373633"}
0005433754983	10268E	6657 755401	ALEKSEY SCHERBAKOV	{"phone": "+70992288581"}
0005433754984	10268E	1243 172481	ALEKSANDR SAVELEV	{"email": "a-savelev031973@postgrespro.ru", "phone": "+70987902525"}
0005433754985	236B5F	1833 150093	ANASTASIYA VOROBEVA	{"phone": "+70208626581"}
0005433754986	DE0823	0668 128690	ALEKSANDR POPOV	{"phone": "+70242746591"}
0005433754987	DE0823	7463 416866	YULIYA VLASOVA	{"phone": "+70971481593"}
0005433754988	AEB6C9	5581 941433	NADEZHDA ROMANOVA	{"phone": "+70756372556"}
0005433754989	3680AF	3726 907684	ALEKSANDR ORLOV	{"phone": "+70841830399"}
0005433754990	16B607	7044 464930	SVETLANA SIDOROVA	{"email": "sidorova.s.041966@postgrespro.ru", "phone": "+70716723900"}
0005433754991	16B607	8430 505921	DMITRIY BORISOV	{"phone": "+70567620099"}
0005433754992	8DA112	4242 619414	IGOR KONOVALOV	{"email": "konovalov-igor_07011964@postgrespro.ru", "phone": "+70199539825"}
0005433754993	8DA112	4933 594203	IRINA PAVLOVA	{"email": "ipavlova_031953@postgrespro.ru", "phone": "+70934396161"}
0005433754994	8DA112	5208 977793	IRINA DENISOVA	{"email": "denisova-irina1975@postgrespro.ru", "phone": "+70632981147"}
0005433754995	8DA112	2276 399355	ALEKSEY FROLOV	{"email": "frolovaleksey.011967@postgrespro.ru", "phone": "+70391829858"}
0005433754996	8DA112	6795 953743	ARTEM TARASOV	{"phone": "+70438796310"}
0005433754997	1F27DA	3271 881839	OLEG FROLOV	{"phone": "+70931650699"}
0005433754998	8C16BA	0848 631743	ANDREY MAKAROV	{"phone": "+70893620738"}
0005433754999	A7E4BD	9947 800631	NIKITA KUZMIN	{"email": "nikitakuzmin_011980@postgrespro.ru", "phone": "+70640617414"}
0005433755000	221E30	8665 761451	VLADIMIR DMITRIEV	{"email": "v.dmitriev-1983@postgrespro.ru", "phone": "+70904563672"}
0005433755001	221E30	7879 107585	TATYANA IVANOVA	{"email": "ivanova-t.18031967@postgrespro.ru", "phone": "+70409902653"}
0005433755002	5910F5	3696 535193	LYUDMILA ALEKSEEVA	{"phone": "+70494315687"}
0005433755003	67FD98	8760 605611	ALEKSANDR MELNIKOV	{"email": "a_melnikov.19051977@postgrespro.ru", "phone": "+70619318309"}
0005433755004	67FD98	0851 625349	EKATERINA POPOVA	{"phone": "+70590388341"}
0005433755005	80E791	5325 783301	VIKTOR BORISOV	{"email": "viktor-borisov.1963@postgrespro.ru", "phone": "+70174528577"}
0005433755115	4A45C5	9642 510134	ALEKSANDR GERASIMOV	{"phone": "+70452809317"}
0005433755006	BD63EA	7268 799240	IRINA DANILOVA	{"email": "idanilova.1970@postgrespro.ru", "phone": "+70878808668"}
0005433755007	E8D3C7	2944 327556	MARIYA ZAKHAROVA	{"email": "zakharova.m_1988@postgrespro.ru", "phone": "+70797865390"}
0005433755008	864C7F	1463 245147	ALINA ZHUKOVA	{"phone": "+70510104728"}
0005433755009	46D5D4	0754 782848	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey_1970@postgrespro.ru", "phone": "+70647756275"}
0005433755010	9EC1D4	8714 126589	RAIL KONOVALOV	{"phone": "+70837679384"}
0005433755011	B2AD9E	6375 655751	ALEKSEY POPOV	{"email": "popov_a-01071967@postgrespro.ru", "phone": "+70904150026"}
0005433755012	B2AD9E	7325 797076	IGOR MOROZOV	{"email": "igormorozov_1977@postgrespro.ru", "phone": "+70530746129"}
0005433755013	DAAD6F	4481 634842	LYUDMILA KALININA	{"phone": "+70994684919"}
0005433755014	42F956	8143 363514	MAKSIM VASILEV	{"email": "vasilev_maksim.1965@postgrespro.ru", "phone": "+70507698932"}
0005433755015	42F956	4703 261845	MARGARITA GRISHINA	{"phone": "+70177865468"}
0005433755016	D24B7F	9420 802363	ALEKSANDR PETROV	{"phone": "+70944592917"}
0005433755017	4FEFD1	5715 844288	DMITRIY SMIRNOV	{"email": "smirnov.d-1966@postgrespro.ru", "phone": "+70671260427"}
0005433755018	BA5B0B	3321 992726	VLADIMIR KARPOV	{"email": "karpov_vladimir-18011967@postgrespro.ru", "phone": "+70172714447"}
0005433755019	BA5B0B	6839 289255	ALBINA SIDOROVA	{"email": "sidorova.albina_091972@postgrespro.ru", "phone": "+70717449260"}
0005433755020	B858E6	5427 414275	LYUBOV ISAEVA	{"email": "isaevalyubov.061972@postgrespro.ru", "phone": "+70085249293"}
0005433755021	9C0BD8	7554 006091	ARTEM NAUMOV	{"phone": "+70329650710"}
0005433755022	BE1E5C	7818 021324	SERGEY GUSEV	{"email": "s-gusev.041968@postgrespro.ru", "phone": "+70013932841"}
0005433755023	BE1E5C	6946 760662	ALEKSANDR NAZAROV	{"email": "nazarova.1968@postgrespro.ru", "phone": "+70757308072"}
0005433755024	963F96	7617 856519	IVAN ANDREEV	{"phone": "+70101918739"}
0005433755025	FEBE6C	1683 012958	VALERIY POPOV	{"email": "popov_valeriy-1972@postgrespro.ru", "phone": "+70205411142"}
0005433755026	FEBE6C	6125 615733	LYUBOV MAKAROVA	{"email": "makarova_lyubov-1977@postgrespro.ru", "phone": "+70904820731"}
0005433755027	B59031	9041 798929	VLADISLAV MIRONOV	{"phone": "+70633727050"}
0005433755028	B59031	6951 712386	IRINA FROLOVA	{"email": "frolova.irina_31071960@postgrespro.ru", "phone": "+70679417031"}
0005433755029	B59031	6396 243714	VLADIMIR BORISOV	{"email": "vladimir-borisov.23121977@postgrespro.ru", "phone": "+70530793356"}
0005433755030	151842	5413 202658	SERGEY ZAKHAROV	{"email": "sergey-zakharov051963@postgrespro.ru", "phone": "+70915079725"}
0005433755031	151842	3442 032779	OLESYA FROLOVA	{"phone": "+70129874647"}
0005433755032	151842	2305 069281	VIKTOR KULIKOV	{"phone": "+70563371742"}
0005433755033	778351	2601 751917	ANASTASIYA KRASNOVA	{"email": "krasnova_a_04061969@postgrespro.ru", "phone": "+70410533788"}
0005433755034	778351	3775 131204	ALEKSANDR FEDOTOV	{"email": "afedotov.1977@postgrespro.ru", "phone": "+70383382138"}
0005433755035	C9B9E9	8247 614535	STANISLAV SEMENOV	{"phone": "+70355108789"}
0005433755036	C9B9E9	2193 340815	ILYA AFANASEV	{"email": "iafanasev.1976@postgrespro.ru", "phone": "+70618338386"}
0005433755037	86098B	6100 227495	ROMAN GAVRILOV	{"email": "roman.gavrilov.09071961@postgrespro.ru", "phone": "+70302506497"}
0005433755038	86098B	5034 000149	VLADLEN SMIRNOV	{"phone": "+70786222267"}
0005433755039	ADD521	1894 088555	YURIY MAKAROV	{"email": "yuriy_makarov-12041984@postgrespro.ru", "phone": "+70544869458"}
0005433755040	BBF08D	1138 958341	KLAVDIYA FEDOROVA	{"email": "fedorova_klavdiya12021967@postgrespro.ru", "phone": "+70402474601"}
0005433755041	BBF08D	5795 043331	VIKTOR ORLOV	{"phone": "+70850640650"}
0005433755042	D070A5	9595 382307	ROMAN ZAYCEV	{"email": "r_zaycev.05121981@postgrespro.ru", "phone": "+70174528262"}
0005433755043	45DA0B	3900 207541	TATYANA VOLKOVA	{"phone": "+70227887254"}
0005433755044	3BFFE4	5862 078390	SOFIYA ZOTOVA	{"phone": "+70523171061"}
0005433755045	C41180	4217 360535	GEORGIY FROLOV	{"phone": "+70536711769"}
0005433755046	AD42F0	1811 042672	NIKOLAY DMITRIEV	{"email": "n_dmitriev.1966@postgrespro.ru", "phone": "+70658715486"}
0005433755047	4AE891	7284 353760	SERGEY MELNIKOV	{"email": "melnikov.s.26071970@postgrespro.ru", "phone": "+70409476490"}
0005433755048	4A97EC	4726 259947	ALEKSANDR NIKITIN	{"email": "nikitin_a1985@postgrespro.ru", "phone": "+70076007277"}
0005433755049	4A97EC	7165 220528	IRINA ANDREEVA	{"email": "andreeva-irina_1968@postgrespro.ru", "phone": "+70490632964"}
0005433755050	E26113	0582 397085	OKSANA FILIPPOVA	{"email": "filippova_o1976@postgrespro.ru", "phone": "+70923142648"}
0005433755051	C65AC1	3503 063864	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr_1976@postgrespro.ru", "phone": "+70344569734"}
0005433755052	C65AC1	1692 263539	ALEKSANDR VASILEV	{"email": "vasilevaleksandr_121965@postgrespro.ru", "phone": "+70208816132"}
0005433755053	C65AC1	6619 379932	YANA PAVLOVA	{"email": "pavlovayana08111969@postgrespro.ru", "phone": "+70118666813"}
0005433755054	41710A	3943 917501	ALINA AFANASEVA	{"phone": "+70083587546"}
0005433755055	706946	2278 326727	ANATOLIY ZHURAVLEV	{"phone": "+70468351445"}
0005433755056	706946	5066 300931	TATYANA GUSEVA	{"email": "gusevat_1977@postgrespro.ru", "phone": "+70165797880"}
0005433755057	7DD284	2419 356550	DANIIL NAUMOV	{"phone": "+70029409233"}
0005433755058	05A8E0	7708 889316	LYUBOV ZHURAVLEVA	{"email": "zhuravleva-lyubov.021967@postgrespro.ru", "phone": "+70579557286"}
0005433755059	E2B008	5530 661777	ALEKSANDR NAZAROV	{"email": "nazarov.aleksandr.03111961@postgrespro.ru", "phone": "+70644678677"}
0005433755060	F8E1E7	0748 518732	MIKHAIL FOMIN	{"phone": "+70562044019"}
0005433755061	F8E1E7	2287 050747	EKATERINA MIRONOVA	{"email": "mironova-ekaterina-30051966@postgrespro.ru", "phone": "+70285134269"}
0005433755062	F8E1E7	7238 112196	OKSANA POTAPOVA	{"email": "oksana.potapova.1973@postgrespro.ru", "phone": "+70504393009"}
0005433755063	6A71B5	8144 545330	VLADIMIR SEMENOV	{"email": "vsemenov_13071986@postgrespro.ru", "phone": "+70129688889"}
0005433755064	6A71B5	7533 370821	SVETLANA MIKHAYLOVA	{"phone": "+70494312253"}
0005433755065	B13987	3656 054718	GALINA MAKAROVA	{"phone": "+70448722797"}
0005433755066	B13987	1585 100146	ALEKSANDR VOLKOV	{"phone": "+70224567432"}
0005433755067	94D802	9048 176302	MARGARITA BELOVA	{"phone": "+70838613477"}
0005433755068	94D802	9986 399515	ARTEM KUZNECOV	{"email": "a.kuznecov.13071975@postgrespro.ru", "phone": "+70786090703"}
0005433755069	94D802	0760 408801	NINA LOGINOVA	{"phone": "+70009357245"}
0005433755070	FACE10	9219 110575	VIKTOR ANTONOV	{"email": "viktor.antonov-1975@postgrespro.ru", "phone": "+70198679747"}
0005433755071	90E157	7490 049806	YURIY GUSEV	{"phone": "+70007922904"}
0005433755072	A32408	2510 870743	VALENTINA MOROZOVA	{"email": "morozova.v-30111963@postgrespro.ru", "phone": "+70446335600"}
0005433755073	4720B1	5232 690109	LYUDMILA YAKOVLEVA	{"email": "l_yakovleva1983@postgrespro.ru", "phone": "+70898312541"}
0005433755074	567DC7	8050 805426	GALINA ROMANOVA	{"email": "gromanova-1971@postgrespro.ru", "phone": "+70014563649"}
0005433755075	40CBFB	7788 589964	VLADIMIR KUZNECOV	{"phone": "+70066791428"}
0005433755076	FD83C9	2970 690088	DMITRIY MAKAROV	{"email": "makarov_d.13111978@postgrespro.ru", "phone": "+70546175375"}
0005433755077	FD83C9	1691 529360	ALENA ZAYCEVA	{"phone": "+70169331780"}
0005433755078	6E2EAE	6234 778437	ILYA KUZNECOV	{"email": "ikuznecov_12101969@postgrespro.ru", "phone": "+70534911636"}
0005433755079	D1260A	1907 026810	TAISIYA ALEKSANDROVA	{"email": "aleksandrova_taisiya.1981@postgrespro.ru", "phone": "+70852483437"}
0005433755080	042BB9	1910 780907	SVETLANA KUZMINA	{"email": "skuzmina-13091974@postgrespro.ru", "phone": "+70510462120"}
0005433755081	584772	6190 314882	ALEKSEY DAVYDOV	{"email": "davydov.a_23071982@postgrespro.ru", "phone": "+70125899397"}
0005433755082	247432	4222 033037	LYUDMILA KONOVALOVA	{"email": "l-konovalova_27081976@postgrespro.ru", "phone": "+70840916745"}
0005433755083	BD1917	7666 748035	VALERIY MATVEEV	{"phone": "+70124938290"}
0005433755084	ED1EFE	3607 934160	MAKSIM MOROZOV	{"email": "maksimmorozov-121969@postgrespro.ru", "phone": "+70808880214"}
0005433755085	ED1EFE	8974 843928	ANTON NAZAROV	{"email": "nazarov.anton09111974@postgrespro.ru", "phone": "+70086680751"}
0005433755086	ED1EFE	6847 932751	ANDREY NIKOLAEV	{"email": "nikolaevandrey-05031985@postgrespro.ru", "phone": "+70479310647"}
0005433755087	ED1EFE	8096 781878	VALENTINA IVANOVA	{"phone": "+70746397037"}
0005433755088	450B06	6005 362845	VIKTOR STEPANOV	{"email": "viktorstepanov_26031975@postgrespro.ru", "phone": "+70773692339"}
0005433755089	450B06	6472 239868	LYUBOV ANDREEVA	{"email": "lyubovandreeva1962@postgrespro.ru", "phone": "+70166547235"}
0005433755090	32C48E	0778 333645	LIDIYA BORISOVA	{"email": "l_borisova.1971@postgrespro.ru", "phone": "+70730847762"}
0005433755091	DF2358	4467 632249	VERA KOZLOVA	{"phone": "+70984658035"}
0005433755092	A127E8	8728 534897	SERGEY BORISOV	{"phone": "+70456308914"}
0005433755093	A127E8	2864 750824	IRINA SOKOLOVA	{"email": "irina.sokolova02121971@postgrespro.ru", "phone": "+70466767669"}
0005433755094	A127E8	0875 963200	VITALIY VASILEV	{"email": "vasilev.v.10091960@postgrespro.ru", "phone": "+70270736591"}
0005433755095	A3C7C4	7619 110677	SERGEY NAUMOV	{"phone": "+70541096823"}
0005433755096	96FC36	1152 394634	IRINA MAKAROVA	{"email": "makarova.irina121971@postgrespro.ru", "phone": "+70552319307"}
0005433755097	96FC36	7913 944736	SERGEY GAVRILOV	{"email": "s_gavrilov.31031973@postgrespro.ru", "phone": "+70070626997"}
0005433755098	B04F73	0225 703705	MIKHAIL EGOROV	{"email": "egorov.m.21081955@postgrespro.ru", "phone": "+70580069584"}
0005433755099	26FDEF	7878 803317	ALEKSANDR VOLKOV	{"email": "volkovaleksandr-1988@postgrespro.ru", "phone": "+70010627952"}
0005433755100	26FDEF	0949 645188	TAISIYA GUSEVA	{"phone": "+70241098083"}
0005433755101	708A75	7980 700371	VIKTOR KOZLOV	{"email": "viktor.kozlov-13021969@postgrespro.ru", "phone": "+70632434987"}
0005433755102	1AF8E6	7614 499620	NATALIYA NIKITINA	{"email": "n_nikitina1974@postgrespro.ru", "phone": "+70103929262"}
0005433755103	6292BD	9052 189236	MIKHAIL BORISOV	{"email": "m.borisov-04081981@postgrespro.ru", "phone": "+70390986581"}
0005433755104	0682DF	6265 201724	ALISA FILATOVA	{"email": "a-filatova-1976@postgrespro.ru", "phone": "+70568108390"}
0005433755105	C0ECCB	9887 652909	ALEKSANDR EGOROV	{"phone": "+70859016235"}
0005433755106	D2B877	8914 668108	NATALYA VASILEVA	{"email": "nvasileva_20101984@postgrespro.ru", "phone": "+70491524667"}
0005433755107	D469D3	8217 118410	VERONIKA IVANOVA	{"email": "ivanova-v_04031979@postgrespro.ru", "phone": "+70218774205"}
0005433755108	D469D3	4846 928357	OLGA KOZLOVA	{"email": "kozlova_o-021964@postgrespro.ru", "phone": "+70062687605"}
0005433755109	F3B001	8828 064959	ILYA KUZNECOV	{"phone": "+70416639922"}
0005433755110	F3B001	8403 621752	DENIS SCHERBAKOV	{"email": "denis_scherbakov.24061981@postgrespro.ru", "phone": "+70208520815"}
0005433755111	2BB173	8844 438915	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova.lyudmila-24061975@postgrespro.ru", "phone": "+70889093002"}
0005433755112	53549F	6932 802477	NINA OVCHINNIKOVA	{"email": "novchinnikova_1975@postgrespro.ru", "phone": "+70113145785"}
0005433755113	7617DA	5243 448451	GALINA FADEEVA	{"phone": "+70345062719"}
0005433755114	7617DA	1391 288021	LIDIYA ISAEVA	{"phone": "+70027167666"}
0005433755116	4A45C5	1835 079664	VERA NIKITINA	{"phone": "+70556533108"}
0005433755117	A024BD	4847 724253	ANNA ANDREEVA	{"email": "andreevaanna-1978@postgrespro.ru", "phone": "+70585344199"}
0005433755118	02290F	1971 859902	ANASTASIYA LUKYANOVA	{"phone": "+70382615764"}
0005433755119	5E369F	9571 633064	VARVARA MIRONOVA	{"phone": "+70325584301"}
0005433755120	E9DB5F	8772 653412	NIKITA KUZNECOV	{"phone": "+70428854694"}
0005433755121	FD4C15	7478 037246	SERGEY CHERNOV	{"email": "chernovs011968@postgrespro.ru", "phone": "+70842253781"}
0005433755122	375F38	7027 201306	ALEKSANDR CHERNOV	{"email": "a-chernov18031977@postgrespro.ru", "phone": "+70596776704"}
0005433755123	AD788D	2992 602758	ANNA OVCHINNIKOVA	{"email": "ovchinnikova-a-1962@postgrespro.ru", "phone": "+70853780442"}
0005433755124	FAEFA5	5107 485916	OLGA EGOROVA	{"phone": "+70784220979"}
0005433755125	9C7D08	8920 900702	ELIZAVETA SERGEEVA	{"email": "sergeeva-elizaveta-20021972@postgrespro.ru", "phone": "+70530107635"}
0005433755126	9C7D08	4150 019658	IRINA BELOVA	{"email": "i-belova1976@postgrespro.ru", "phone": "+70729655978"}
0005433755127	443C76	3389 965465	TAISIYA AFANASEVA	{"email": "t.afanaseva_1972@postgrespro.ru", "phone": "+70076187095"}
0005433755128	BBCDAD	7911 795359	ALEKSANDR ZAKHAROV	{"phone": "+70386286690"}
0005433755129	8D4653	9593 159685	NATALYA SEMENOVA	{"phone": "+70736293994"}
0005433755130	8D4653	1299 129304	GALINA BARANOVA	{"email": "baranova_galina-111963@postgrespro.ru", "phone": "+70855141610"}
0005433755131	8D4653	3911 398457	ZOYA SAVELEVA	{"phone": "+70946830827"}
0005433755132	DEF986	5311 157101	ALENA ORLOVA	{"phone": "+70824403905"}
0005433755133	61067B	9034 394744	SERGEY SHEVCHENKO	{"email": "shevchenkos-01031959@postgrespro.ru", "phone": "+70901858764"}
0005433755134	7A4F99	3568 073091	IRINA DANILOVA	{"phone": "+70968427354"}
0005433755135	7A4F99	7753 204455	EKATERINA POPOVA	{"phone": "+70060838956"}
0005433755136	7A4F99	4875 374498	STANISLAV GRIGOREV	{"email": "grigorevs-101969@postgrespro.ru", "phone": "+70559007530"}
0005433755137	007DF3	9139 706429	IGOR ANTONOV	{"email": "i-antonov121969@postgrespro.ru", "phone": "+70793787992"}
0005433755138	007DF3	3654 764961	TATYANA IVANOVA	{"phone": "+70374792129"}
0005433755139	DDE087	8801 981564	ALEKSANDR NOVIKOV	{"email": "anovikov-1965@postgrespro.ru", "phone": "+70575131763"}
0005433755140	C42D76	5401 737491	ALEKSANDR RODIONOV	{"phone": "+70266974207"}
0005433755141	1F0330	9993 379743	ELENA VASILEVA	{"email": "vasilevaelena_1982@postgrespro.ru", "phone": "+70788551450"}
0005433755142	914E15	7423 605164	ANDREY DMITRIEV	{"phone": "+70720830796"}
0005433755143	CB2DE9	8138 594865	ANATOLIY POPOV	{"email": "popov.anatoliy_08011964@postgrespro.ru", "phone": "+70715731468"}
0005433755144	F51ECA	8809 666583	DMITRIY GORBUNOV	{"email": "d_gorbunov_1968@postgrespro.ru", "phone": "+70274465638"}
0005433755145	451CA6	5618 033353	LYUDMILA IVANOVA	{"phone": "+70673720700"}
0005433755146	4E7B15	1566 523825	KSENIYA MAKAROVA	{"email": "kseniya-makarova-1968@postgrespro.ru", "phone": "+70074728802"}
0005433755147	D88069	6864 320418	TATYANA KOVALEVA	{"phone": "+70351007759"}
0005433755148	66EB06	7560 225421	MARIYA CHERNOVA	{"phone": "+70340385695"}
0005433755149	74ECDE	4376 793842	ANDREY GERASIMOV	{"phone": "+70339005571"}
0005433755150	74ECDE	7979 454877	VERA MOROZOVA	{"phone": "+70570760944"}
0005433755151	C9E6A3	4557 442177	VIKTOR GRIGOREV	{"email": "viktor.grigorev.1983@postgrespro.ru", "phone": "+70066211131"}
0005433755152	111256	1088 713832	RIMMA BELOVA	{"email": "belova.rimma041985@postgrespro.ru", "phone": "+70638025668"}
0005433755153	D977FE	3937 453842	ILYA KUZNECOV	{"phone": "+70196513940"}
0005433755154	A6BFD1	7144 107007	VADIM YAKOVLEV	{"email": "yakovlev-vadim_1966@postgrespro.ru", "phone": "+70761365501"}
0005433755155	FAB903	8714 697178	ZOYA IVANOVA	{"email": "zoya-ivanova_25011968@postgrespro.ru", "phone": "+70120697250"}
0005433755156	750268	5210 534155	OKSANA VOROBEVA	{"email": "o.vorobeva-26111967@postgrespro.ru", "phone": "+70810043324"}
0005433755157	FD5AB1	4962 918871	YULIYA GORBUNOVA	{"email": "ygorbunova-1967@postgrespro.ru", "phone": "+70044984250"}
0005433755158	BF090D	5250 122115	OLGA YAKOVLEVA	{"email": "yakovleva_olga.24071964@postgrespro.ru", "phone": "+70606390038"}
0005433755159	757026	6787 814114	VLADISLAV MATVEEV	{"email": "v-matveev_1973@postgrespro.ru", "phone": "+70312169335"}
0005433755160	757026	7760 021573	ELVIRA SERGEEVA	{"email": "elvira.sergeeva_09021963@postgrespro.ru", "phone": "+70845848726"}
0005433755161	61D713	2077 603913	SVETLANA GUSEVA	{"phone": "+70463798777"}
0005433755162	04C3A4	3707 813994	ANZHELA GAVRILOVA	{"email": "a_gavrilova-1972@postgrespro.ru", "phone": "+70605767947"}
0005433755163	4887AF	6798 996293	PETR NIKITIN	{"phone": "+70746772541"}
0005433755164	0C63E3	5499 226924	PAVEL KARPOV	{"phone": "+70010648534"}
0005433755165	0C63E3	0638 991894	IGOR KONOVALOV	{"email": "konovalov-igor1974@postgrespro.ru", "phone": "+70305374453"}
0005433755166	2C905D	1220 929502	EVGENIYA ZAKHAROVA	{"phone": "+70869505457"}
0005433755167	5DFAA6	2845 848805	ZLATA IVANOVA	{"email": "zlata.ivanova17031980@postgrespro.ru", "phone": "+70586669741"}
0005433755168	38CC32	2130 210118	TATYANA BELYAEVA	{"email": "belyaeva.t.1978@postgrespro.ru", "phone": "+70288955939"}
0005433755169	2012F9	7645 383812	VLADIMIR KUZNECOV	{"email": "v-kuznecov-1984@postgrespro.ru", "phone": "+70477119223"}
0005433755170	2C97F7	0990 817553	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov-011982@postgrespro.ru", "phone": "+70600235476"}
0005433755171	C3ED52	4800 828363	OLGA DANILOVA	{"email": "danilova-o111973@postgrespro.ru", "phone": "+70503443153"}
0005433755172	C3ED52	9455 104525	VLADIMIR MAKAROV	{"email": "vladimirmakarov061966@postgrespro.ru", "phone": "+70537116290"}
0005433755173	0A6781	8214 669430	RUSTYAM IVANOV	{"phone": "+70064819160"}
0005433755174	0A6781	2438 121534	TATYANA VOROBEVA	{"email": "vorobevatatyana_1972@postgrespro.ru", "phone": "+70488161260"}
0005433755175	308317	5900 983750	ELENA ANISIMOVA	{"phone": "+70267057012"}
0005433755176	308317	1955 738008	ANASTASIYA KUZMINA	{"phone": "+70667974567"}
0005433755177	B8B59A	0094 448497	SERGEY TIKHONOV	{"email": "sergey-tikhonov.031977@postgrespro.ru", "phone": "+70169332887"}
0005433755178	A87499	3638 948407	YURIY ISAEV	{"email": "y_isaev_041965@postgrespro.ru", "phone": "+70212867689"}
0005433755179	59F1B4	2552 406518	VYACHESLAV KULIKOV	{"phone": "+70494607338"}
0005433755180	DC78A7	0158 768655	ALEKSEY PAVLOV	{"phone": "+70488897903"}
0005433755181	DC78A7	1950 646189	ALEKSANDR BORISOV	{"email": "borisov.a.20101957@postgrespro.ru", "phone": "+70356480866"}
0005433755182	1944FA	8330 183040	POLINA POTAPOVA	{"phone": "+70371359785"}
0005433755183	1944FA	3023 740558	TATYANA KOLESNIKOVA	{"phone": "+70221703663"}
0005433755184	19B455	6264 914992	DANIIL BORISOV	{"phone": "+70709354897"}
0005433755185	0D0563	5933 068197	MARIYA TIKHONOVA	{"phone": "+70454097214"}
0005433755186	AD3865	4222 404146	TATYANA NIKITINA	{"phone": "+70272577781"}
0005433755187	C64269	2189 671710	ALEKSANDRA MEDVEDEVA	{"phone": "+70049618726"}
0005433755188	6D514B	1231 913294	ALEKSEY VOLKOV	{"email": "volkov_aleksey-14041966@postgrespro.ru", "phone": "+70311546064"}
0005433755189	A1BACF	2253 523835	VLADIMIR MOISEEV	{"email": "v.moiseev-111990@postgrespro.ru", "phone": "+70143000240"}
0005433755190	26C602	9765 214094	LIDIYA NIKOLAEVA	{"email": "lnikolaeva1973@postgrespro.ru", "phone": "+70096291166"}
0005433755191	26C602	3177 752464	OLGA TITOVA	{"phone": "+70529689074"}
0005433755192	26DD1F	1066 680305	ANASTASIYA IVANOVA	{"email": "ivanova.anastasiya-20061977@postgrespro.ru", "phone": "+70308009072"}
0005433755193	0B5658	2660 235275	PAVEL DENISOV	{"email": "denisov-p-1966@postgrespro.ru", "phone": "+70217685325"}
0005433755194	8F2E9B	7725 743890	VYACHESLAV ORLOV	{"phone": "+70634050961"}
0005433755195	8F2E9B	2943 324916	ANNA ANDREEVA	{"email": "andreevaanna1965@postgrespro.ru", "phone": "+70349844318"}
0005433755196	747F84	3994 615948	ANDREY IVANOV	{"email": "ivanov-andrey_02091963@postgrespro.ru", "phone": "+70842290163"}
0005433755197	6086F6	2466 960792	ALEKSANDR GAVRILOV	{"phone": "+70189903996"}
0005433755198	6086F6	6491 405699	MIKHAIL SCHERBAKOV	{"email": "scherbakov-m_021979@postgrespro.ru", "phone": "+70411930064"}
0005433755199	D2493B	1224 290722	SERGEY MATVEEV	{"email": "sergey.matveev111973@postgrespro.ru", "phone": "+70044666381"}
0005433755200	ADDDB9	9740 689172	TATYANA CHERNOVA	{"phone": "+70656050400"}
0005433755201	F62EB8	6548 169108	LIDIYA TIMOFEEVA	{"phone": "+70648280798"}
0005433755202	C076A5	0401 380942	TATYANA ANTONOVA	{"phone": "+70770648859"}
0005433755203	C076A5	8439 205870	VIKTOR VOROBEV	{"email": "v-vorobev-1977@postgrespro.ru", "phone": "+70231705914"}
0005433755204	12EF20	6837 905743	ROZALIYA OSIPOVA	{"email": "rozaliya.osipova-11051975@postgrespro.ru", "phone": "+70788392940"}
0005433755205	EB91FA	9728 422902	SNEZHANA SEMENOVA	{"email": "snezhana-semenova111970@postgrespro.ru", "phone": "+70572581317"}
0005433755206	B19A4A	2377 869382	SERGEY DMITRIEV	{"phone": "+70186673304"}
0005433755207	D2F49F	5668 646614	ELENA MEDVEDEVA	{"phone": "+70302480258"}
0005433755208	2BAE6A	3985 445507	OLEG STEPANOV	{"phone": "+70991745846"}
0005433755209	2BAE6A	7469 233329	EVGENIY ALEKSANDROV	{"phone": "+70997094266"}
0005433755210	F19C09	3956 483771	ANDREY MEDVEDEV	{"email": "andrey.medvedev-02081973@postgrespro.ru", "phone": "+70918758274"}
0005433755211	9D2D62	8415 175045	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova_071969@postgrespro.ru", "phone": "+70576048934"}
0005433755212	9D2D62	4522 955830	SERGEY IVANOV	{"email": "ivanov-s_01071976@postgrespro.ru", "phone": "+70432097176"}
0005433755213	002AF1	3563 196873	DMITRIY KUZMIN	{"email": "d_kuzmin20021977@postgrespro.ru", "phone": "+70794671454"}
0005433755214	3FE355	9952 848845	MAKSIM GORBUNOV	{"email": "gorbunov_maksim1950@postgrespro.ru", "phone": "+70766612877"}
0005433755215	22417A	4074 113628	LEONID MELNIKOV	{"email": "l_melnikov-061978@postgrespro.ru", "phone": "+70219529566"}
0005433755216	22417A	5206 822818	KIRILL SOKOLOV	{"phone": "+70832626315"}
0005433755217	22417A	0808 494964	IRINA IVANOVA	{"phone": "+70025174311"}
0005433755218	521B5B	7681 597957	ELENA KALININA	{"email": "kalinina.elena.1982@postgrespro.ru", "phone": "+70462103482"}
0005433755219	D0E466	1952 486626	LIDIYA BOGDANOVA	{"phone": "+70963088792"}
0005433755220	80E6C7	3497 268842	MARIYA MASLOVA	{"email": "maslova-mariya_14121981@postgrespro.ru", "phone": "+70088064527"}
0005433755221	80E6C7	9094 689660	OLGA BOGDANOVA	{"email": "bogdanova.olga.041970@postgrespro.ru", "phone": "+70370392306"}
0005433755222	7BE93F	3662 768758	EKATERINA MELNIKOVA	{"email": "e_melnikova.1964@postgrespro.ru", "phone": "+70415667027"}
0005433755223	7BE93F	1548 767026	ANTONINA DMITRIEVA	{"phone": "+70411326263"}
0005433755224	55C422	9675 017995	TATYANA MIRONOVA	{"email": "mironova-tatyana_011983@postgrespro.ru", "phone": "+70453201791"}
0005433755225	7F6948	9350 312489	TATYANA ZAKHAROVA	{"email": "t-zakharova_051962@postgrespro.ru", "phone": "+70940104801"}
0005433755226	7F6948	6481 378486	EDUARD ILIN	{"email": "ilin-e-22121977@postgrespro.ru", "phone": "+70415299381"}
0005433755227	7BDB44	5242 998056	VALENTINA YAKOVLEVA	{"phone": "+70067027171"}
0005433755228	7BDB44	7765 650311	VITALIY MOROZOV	{"phone": "+70321497713"}
0005433755229	7BDB44	5812 134529	SERGEY KUZMIN	{"email": "kuzmin.s-041970@postgrespro.ru", "phone": "+70857865218"}
0005433755230	A4F42E	6009 760423	SERGEY DAVYDOV	{"email": "sergeydavydov.10061969@postgrespro.ru", "phone": "+70057693513"}
0005433755231	A4F42E	2370 641258	ALEKSEY RODIONOV	{"email": "aleksey.rodionov-1963@postgrespro.ru", "phone": "+70483076325"}
0005433755232	A4F42E	0158 790564	ILYA GAVRILOV	{"email": "ilyagavrilov.13121983@postgrespro.ru", "phone": "+70182524429"}
0005433755233	87CA55	2165 366944	NIKITA ROMANOV	{"email": "romanovnikita27051971@postgrespro.ru", "phone": "+70924430019"}
0005433755234	87CA55	8502 293163	VLADISLAV NIKOLAEV	{"phone": "+70751867444"}
0005433755235	A09126	4552 796081	MARIYA RODIONOVA	{"email": "rodionovam_25081969@postgrespro.ru", "phone": "+70222059947"}
0005433755236	6C5811	7758 934466	ANNA SOKOLOVA	{"email": "sokolovaa.091981@postgrespro.ru", "phone": "+70194772547"}
0005433755237	D3A839	2710 858429	TAMARA KISELEVA	{"phone": "+70844100583"}
0005433755238	D3A839	8470 384452	LYUDMILA SERGEEVA	{"email": "l.sergeeva1973@postgrespro.ru", "phone": "+70901454489"}
0005433755239	932EF9	3074 815010	SVETLANA DMITRIEVA	{"email": "s_dmitrieva121968@postgrespro.ru", "phone": "+70400942783"}
0005433755240	FDDAAD	4956 195094	ANASTASIYA POTAPOVA	{"phone": "+70272641568"}
0005433755241	FDDAAD	7704 535816	NIKOLAY MOISEEV	{"email": "moiseev.nikolay_1969@postgrespro.ru", "phone": "+70077875600"}
0005433755242	F72983	9800 137286	IGOR SERGEEV	{"email": "sergeev_igor24031977@postgrespro.ru", "phone": "+70024426822"}
0005433755243	F72983	3522 806653	NIKOLAY SERGEEV	{"email": "nsergeev.1960@postgrespro.ru", "phone": "+70037267897"}
0005433755244	EE82E3	0387 245878	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova-11031969@postgrespro.ru", "phone": "+70269631796"}
0005433755245	AFE095	0368 598898	YURIY KRASNOV	{"phone": "+70244989922"}
0005433755246	0ECD43	9776 581346	ANATOLIY KUZMIN	{"email": "a.kuzmin_121962@postgrespro.ru", "phone": "+70875204454"}
0005433755247	672B11	6919 045186	DENIS TIMOFEEV	{"phone": "+70367302713"}
0005433755248	512265	7436 730299	ALEKSANDR FILIPPOV	{"email": "a-filippov-041976@postgrespro.ru", "phone": "+70039747831"}
0005433755249	090930	9182 296522	VALERIY BORISOV	{"email": "borisovv_101962@postgrespro.ru", "phone": "+70269580048"}
0005433755250	D403A7	5061 111124	LYUDMILA BELOVA	{"phone": "+70365833841"}
0005433755251	73B8B2	2391 197529	NATALYA AKIMOVA	{"phone": "+70300760228"}
0005433755252	D49875	7444 096467	OLGA SMIRNOVA	{"email": "o-smirnova-04111965@postgrespro.ru", "phone": "+70734695074"}
0005433755253	D49875	6179 222390	SERGEY VOROBEV	{"email": "vorobevs.23031972@postgrespro.ru", "phone": "+70202418816"}
0005433755254	2FB5B0	7984 458325	ALEKSANDR MOROZOV	{"phone": "+70146832290"}
0005433755255	4617C2	5616 556742	OLGA NIKITINA	{"email": "onikitina16041969@postgrespro.ru", "phone": "+70317439033"}
0005433755256	4617C2	5375 188533	ALEKSEY NIKITIN	{"email": "nikitin_a-08091972@postgrespro.ru", "phone": "+70483778670"}
0005433755257	4D5190	6918 085497	TATYANA KUDRYASHOVA	{"phone": "+70145274564"}
0005433755258	306471	3613 636983	VALENTINA KUZNECOVA	{"phone": "+70125994755"}
0005433755259	5D7341	3571 839153	RAISA KUZMINA	{"phone": "+70291859988"}
0005433755260	79FC55	4624 296768	LIDIYA KONOVALOVA	{"email": "l_konovalova.041976@postgrespro.ru", "phone": "+70960052392"}
0005433755261	21F5A5	4792 662275	ANNA IVANOVA	{"email": "ivanovaa.021969@postgrespro.ru", "phone": "+70352044274"}
0005433755262	21F5A5	0516 875901	EKATERINA YUDINA	{"email": "eyudina-1975@postgrespro.ru", "phone": "+70414696290"}
0005433755263	5BED85	0625 916919	DARYA KULIKOVA	{"email": "daryakulikova.101985@postgrespro.ru", "phone": "+70507336527"}
0005433755264	8EB2F1	2402 741157	LYUDMILA GAVRILOVA	{"email": "gavrilova-l-051973@postgrespro.ru", "phone": "+70153153356"}
0005433755265	9AC082	3023 184316	SERGEY TARASOV	{"phone": "+70258853925"}
0005433755266	9AC082	0159 471089	ANDREY MELNIKOV	{"email": "a-melnikov.021977@postgrespro.ru", "phone": "+70158688854"}
0005433755267	9AC082	7903 383790	ALEKSANDR ALEKSEEV	{"phone": "+70493338760"}
0005433755268	D1079A	6211 303333	IRINA ERMAKOVA	{"phone": "+70835338400"}
0005433755269	D1079A	5310 373374	ANNA SERGEEVA	{"phone": "+70872695289"}
0005433755270	49477E	3417 364826	MARIYA KUZNECOVA	{"email": "m_kuznecova_13041962@postgrespro.ru", "phone": "+70723673914"}
0005433755271	49477E	2818 922949	NIKITA KOZLOV	{"phone": "+70273679550"}
0005433755272	6893D8	6976 452844	ANDREY VOROBEV	{"phone": "+70056133936"}
0005433755273	6893D8	3596 886744	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr071959@postgrespro.ru", "phone": "+70896322338"}
0005433755274	477FB1	7556 849560	ANTONINA NESTEROVA	{"email": "a.nesterova_041977@postgrespro.ru", "phone": "+70618345108"}
0005433755275	7D8362	9039 126207	ARINA TITOVA	{"email": "titova.a_011968@postgrespro.ru", "phone": "+70834327939"}
0005433755276	7C64A2	9689 619874	VLADIMIR VLASOV	{"email": "vlasov_vladimir.08011969@postgrespro.ru", "phone": "+70864076622"}
0005433755277	7C64A2	2399 586806	NIKITA PAVLOV	{"email": "pavlovnikita28081965@postgrespro.ru", "phone": "+70680401045"}
0005433755278	E42561	9288 841019	DMITRIY SIDOROV	{"email": "dsidorov_13031973@postgrespro.ru", "phone": "+70874666516"}
0005433755279	AD47E4	5590 411822	NINA IVANOVA	{"phone": "+70246909008"}
0005433755280	AD47E4	8032 705359	TAMARA BARANOVA	{"email": "tamarabaranova-22041975@postgrespro.ru", "phone": "+70180207007"}
0005433755281	3A3C2E	3450 013991	OLEG SCHERBAKOV	{"phone": "+70809898425"}
0005433755282	3A3C2E	9519 963765	ELENA STEPANOVA	{"phone": "+70503337210"}
0005433755283	7B91B9	4875 264052	ALEKSANDR VASILEV	{"email": "vasilevaleksandr-1976@postgrespro.ru", "phone": "+70532260076"}
0005433755284	11CD63	9424 823902	MARIYA ALEKSEEVA	{"email": "alekseevamariya.1966@postgrespro.ru", "phone": "+70871134131"}
0005433755285	E6BCDB	6915 755580	LYUDMILA IVANOVA	{"email": "l_ivanova27111976@postgrespro.ru", "phone": "+70748737085"}
0005433755286	E6BCDB	3546 006960	VALENTINA ISAEVA	{"phone": "+70276665071"}
0005433755287	F029D2	3881 566445	IVAN MEDVEDEV	{"email": "i_medvedev-1967@postgrespro.ru", "phone": "+70702022908"}
0005433755288	F029D2	8292 717733	MARINA SIDOROVA	{"email": "sidorova.m.30061972@postgrespro.ru", "phone": "+70056158952"}
0005433755289	10385F	2709 932699	DMITRIY ILIN	{"phone": "+70379224792"}
0005433755290	6AA634	0192 137098	PAVEL MAKSIMOV	{"phone": "+70161157015"}
0005433755291	3DA0B9	1860 261702	NIKOLAY VOLKOV	{"email": "nikolay.volkov041981@postgrespro.ru", "phone": "+70311038700"}
0005433755292	3DA0B9	6637 707642	DENIS ANTONOV	{"email": "denis_antonov.1978@postgrespro.ru", "phone": "+70159878766"}
0005433755293	0C9E5E	6998 005994	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova061969@postgrespro.ru", "phone": "+70329394792"}
0005433755294	23AC7C	9497 149975	VYACHESLAV VOROBEV	{"email": "vorobevvyacheslav.20041972@postgrespro.ru", "phone": "+70879703403"}
0005433755295	23AC7C	0138 871316	MIKHAIL NAUMOV	{"phone": "+70561481177"}
0005433755296	23AC7C	4833 729985	LIDIYA NESTEROVA	{"email": "lidiya_nesterova1966@postgrespro.ru", "phone": "+70481958055"}
0005433755297	D57541	4611 841922	GALINA VOLKOVA	{"phone": "+70216534597"}
0005433755298	D57541	5645 916152	EKATERINA MEDVEDEVA	{"phone": "+70511538437"}
0005433755299	F6E4C4	8137 950555	VITALIY VLASOV	{"email": "vlasov-v.091968@postgrespro.ru", "phone": "+70726783016"}
0005433755300	F6E4C4	1216 360361	GALINA KUZMINA	{"email": "kuzminag.24091980@postgrespro.ru", "phone": "+70110826602"}
0005433755301	662C6E	6113 141669	OLGA POPOVA	{"email": "popovao_05031973@postgrespro.ru", "phone": "+70325680361"}
0005433755302	184BDF	9395 189297	SERGEY SCHERBAKOV	{"phone": "+70462220049"}
0005433755303	249904	7774 442132	ALEKSANDR KISELEV	{"phone": "+70832513312"}
0005433755304	DE842F	3848 953417	EVGENIY MATVEEV	{"email": "matveev-evgeniy-031976@postgrespro.ru", "phone": "+70961125694"}
0005433755305	D24301	1409 779372	IVAN SEMENOV	{"email": "semenovi-1967@postgrespro.ru", "phone": "+70881473829"}
0005433755306	3BC8A6	1395 183108	VALENTINA MIRONOVA	{"email": "valentina.mironova-011968@postgrespro.ru", "phone": "+70779415153"}
0005433755307	3BC8A6	5739 619738	LYUDMILA KUZNECOVA	{"phone": "+70298957586"}
0005433755308	4DD5D3	4371 460941	NATALYA PETROVA	{"phone": "+70391494115"}
0005433755309	C3A231	9779 155394	ELENA NIKITINA	{"phone": "+70075123687"}
0005433755310	A8338D	3262 634419	MAKSIM MOROZOV	{"email": "maksimmorozov_1972@postgrespro.ru", "phone": "+70293814683"}
0005433755311	A8338D	8635 639806	ALEKSANDR IVANOV	{"email": "ivanovaleksandr041963@postgrespro.ru", "phone": "+70963335535"}
0005433755312	4209EF	4941 932845	DMITRIY ZHUKOV	{"phone": "+70609264852"}
0005433755313	32C0DE	4930 970539	LYUDMILA ABRAMOVA	{"email": "abramova_lyudmila081963@postgrespro.ru", "phone": "+70072376465"}
0005433755314	32C0DE	7651 879326	NINA KOMAROVA	{"phone": "+70974118554"}
0005433755315	6E7081	2449 810979	ANNA ROMANOVA	{"phone": "+70476236567"}
0005433755316	C300B7	1238 175294	DMITRIY KOZLOV	{"email": "kozlov_d.061956@postgrespro.ru", "phone": "+70601296611"}
0005433755317	9D90B1	4363 561844	SVETLANA PETROVA	{"email": "s-petrova_091972@postgrespro.ru", "phone": "+70861247969"}
0005433755318	66D344	1959 087927	VIKTOR MARTYNOV	{"email": "v-martynov1962@postgrespro.ru", "phone": "+70056230722"}
0005433755319	66D344	9557 779534	NADEZHDA EGOROVA	{"email": "egorova_n041979@postgrespro.ru", "phone": "+70342948102"}
0005433755320	66D344	8103 231293	ELENA MARTYNOVA	{"email": "martynova_elena06041980@postgrespro.ru", "phone": "+70039401177"}
0005433755321	FED8F1	6542 103999	NIKOLAY MAKAROV	{"email": "nikolay_makarov1963@postgrespro.ru", "phone": "+70246116274"}
0005433755322	F4BD0D	3692 570189	MAKAR VLASOV	{"email": "makar_vlasov1965@postgrespro.ru", "phone": "+70548260357"}
0005433755323	D9753C	5204 126404	SVETLANA KAZAKOVA	{"phone": "+70953392311"}
0005433755324	255241	1109 161776	ILNAR ORLOV	{"phone": "+70026103454"}
0005433755325	878642	9466 249535	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr_101977@postgrespro.ru", "phone": "+70561818485"}
0005433755326	26F528	7941 959463	TATYANA ANDREEVA	{"phone": "+70340402536"}
0005433755327	26F528	8029 992271	VALENTINA PAVLOVA	{"email": "pavlova.v.15101982@postgrespro.ru", "phone": "+70749195412"}
0005433755328	26F528	0417 462048	ALENA KUZNECOVA	{"phone": "+70972652601"}
0005433755329	26A536	7458 966778	VALENTINA EGOROVA	{"phone": "+70376687968"}
0005433755330	603902	6845 542046	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov.10031983@postgrespro.ru", "phone": "+70315455536"}
0005433755331	84AA07	6740 030249	DENIS STEPANOV	{"email": "denis-stepanov081979@postgrespro.ru", "phone": "+70640954437"}
0005433755332	F30DC1	6901 089540	GALINA NAUMOVA	{"email": "galina.naumova_1972@postgrespro.ru", "phone": "+70409588441"}
0005433755333	F30DC1	8335 822540	MARIYA MOROZOVA	{"phone": "+70142391182"}
0005433755334	C41203	0142 538339	NIKITA SERGEEV	{"email": "n.sergeev.061974@postgrespro.ru", "phone": "+70059864290"}
0005433755335	C41203	0811 124451	PETR NIKITIN	{"phone": "+70627479342"}
0005433755336	327B98	4191 531996	NIKOLAY ORLOV	{"email": "nikolay.orlov.121971@postgrespro.ru", "phone": "+70853389157"}
0005433755337	8B8160	2906 711648	VALENTINA KOMAROVA	{"email": "komarovavalentina_011966@postgrespro.ru", "phone": "+70108356891"}
0005433755338	8B8160	0456 330088	OLGA YAKOVLEVA	{"email": "yakovleva.o-1963@postgrespro.ru", "phone": "+70782495259"}
0005433755339	81D16F	6437 592889	IVAN KUZNECOV	{"phone": "+70607084924"}
0005433755340	81D16F	0649 809484	MIKHAIL OSIPOV	{"email": "mosipov-1970@postgrespro.ru", "phone": "+70361780567"}
0005433755341	564B4C	8477 581695	VLADIMIR MARTYNOV	{"phone": "+70811461869"}
0005433755342	E30DF3	1082 445331	NADEZHDA VOLKOVA	{"email": "n_volkova.1979@postgrespro.ru", "phone": "+70874048790"}
0005433755343	E30DF3	0383 922144	VERA VOLKOVA	{"email": "volkova-v.02021972@postgrespro.ru", "phone": "+70137896813"}
0005433755344	2E3F41	5125 393184	VIKTOR ZHUKOV	{"email": "viktor-zhukov-111978@postgrespro.ru", "phone": "+70283853523"}
0005433755345	814162	5034 457376	YURIY VOLKOV	{"email": "volkov-y_1972@postgrespro.ru", "phone": "+70416089127"}
0005433755346	8A0FCA	8477 722213	DIANA DMITRIEVA	{"phone": "+70203648647"}
0005433755347	EEA027	8907 785001	IGOR MELNIKOV	{"phone": "+70145794384"}
0005433755348	EEA027	1752 455564	VALENTIN BORISOV	{"phone": "+70191413900"}
0005433755349	EEA027	4774 110791	ALEKSEY ZHUKOV	{"email": "a.zhukov.30121975@postgrespro.ru", "phone": "+70269048522"}
0005433755350	858150	0343 401576	ARTUR ZAKHAROV	{"email": "a.zakharov27061978@postgrespro.ru", "phone": "+70746746376"}
0005433755351	858150	0641 672184	MARIYA GRISHINA	{"email": "grishinamariya02091973@postgrespro.ru", "phone": "+70198384854"}
0005433755352	858150	3252 716775	EVGENIY STEPANOV	{"phone": "+70682751717"}
0005433755353	96AFAB	7476 402288	ZULFIYA MEDVEDEVA	{"email": "medvedeva-z.1970@postgrespro.ru", "phone": "+70328067999"}
0005433755354	AD53F4	6439 835718	ELENA ARKHIPOVA	{"phone": "+70987555808"}
0005433755355	AD53F4	6474 513070	DMITRIY GRIGOREV	{"email": "d_grigorev1979@postgrespro.ru", "phone": "+70247276277"}
0005433755356	DED8DC	2479 282571	BORIS FILIPPOV	{"email": "filippovb.29121966@postgrespro.ru", "phone": "+70212786212"}
0005433755357	DED8DC	8943 107982	GALINA AFANASEVA	{"email": "galina-afanaseva_121974@postgrespro.ru", "phone": "+70424483964"}
0005433755358	F261FA	6032 678401	ELENA SOKOLOVA	{"email": "sokolova_e_05121969@postgrespro.ru", "phone": "+70751590756"}
0005433755359	F261FA	9226 531194	ANTONINA OSIPOVA	{"email": "osipova-antonina_021981@postgrespro.ru", "phone": "+70636520564"}
0005433755360	17EBAF	7970 941003	VLADISLAV FROLOV	{"email": "frolov_v.091972@postgrespro.ru", "phone": "+70339249225"}
0005433755361	F3BF57	5262 851186	LYUDMILA VASILEVA	{"email": "l_vasileva-1978@postgrespro.ru", "phone": "+70921889273"}
0005433755362	D0E53E	5415 757068	ANTONINA ALEKSEEVA	{"email": "alekseeva_a091971@postgrespro.ru", "phone": "+70955564543"}
0005433755363	6F3916	6319 790411	YULIYA MAKSIMOVA	{"phone": "+70263139558"}
0005433755364	235884	2600 525562	MIKHAIL PAVLOV	{"phone": "+70209268824"}
0005433755365	235884	2109 792356	RAISA MELNIKOVA	{"phone": "+70055352505"}
0005433755366	F942ED	2370 330772	EVGENIY NAZAROV	{"email": "evgeniy.nazarov16101973@postgrespro.ru", "phone": "+70161767700"}
0005433755367	F942ED	6852 410954	TIMOFEY ABRAMOV	{"phone": "+70167495581"}
0005433755368	E28C85	1062 886124	TATYANA MELNIKOVA	{"email": "tatyanamelnikova_021967@postgrespro.ru", "phone": "+70438022666"}
0005433755369	3A11E8	2607 485884	ALEKSANDR ORLOV	{"email": "aleksandrorlov_1976@postgrespro.ru", "phone": "+70732241593"}
0005433755370	3A11E8	7192 639997	ROMAN ZAKHAROV	{"email": "zakharov.roman.051973@postgrespro.ru", "phone": "+70672850965"}
0005433755371	0285BC	0275 953712	SERGEY EGOROV	{"phone": "+70695919200"}
0005433755372	0285BC	8912 988660	IVAN VOLKOV	{"email": "volkov.i111981@postgrespro.ru", "phone": "+70153018174"}
0005433755373	E75FC9	0370 738695	IRINA SAVELEVA	{"email": "i-saveleva_101971@postgrespro.ru", "phone": "+70144790230"}
0005433755374	E75FC9	5223 036962	DENIS ZAYCEV	{"email": "zaycev.d.1966@postgrespro.ru", "phone": "+70061421031"}
0005433755375	6C3A4F	7647 328236	YURIY GORBUNOV	{"phone": "+70296252931"}
0005433755376	6C3A4F	3133 270961	SVETLANA KUZNECOVA	{"phone": "+70502532099"}
0005433755377	59B3CE	0218 027556	VALERIY DAVYDOV	{"phone": "+70965995406"}
0005433755378	7EC32E	3187 040705	VLADISLAV KUZMIN	{"phone": "+70274634849"}
0005433755379	7EC32E	2800 359379	OLGA ERMAKOVA	{"phone": "+70043729143"}
0005433755380	7BAED2	1752 370701	IVAN ROMANOV	{"phone": "+70343948191"}
0005433755381	4DC13D	2318 649376	EVGENIY SEMENOV	{"phone": "+70338214335"}
0005433755382	0E401D	5396 212038	RAISA NESTEROVA	{"phone": "+70564809541"}
0005433755383	0E401D	9094 512405	IGOR ALEKSEEV	{"phone": "+70094970328"}
0005433755384	F7FD9C	1297 281452	VASILIY CHERNOV	{"email": "v_chernov021984@postgrespro.ru", "phone": "+70415056550"}
0005433755385	C68AC9	6271 097720	YULIYA MAKSIMOVA	{"phone": "+70401295841"}
0005433755386	C27E96	8498 598654	GEORGIY MOROZOV	{"phone": "+70005809028"}
0005433755387	4B6038	7550 553095	NINA GERASIMOVA	{"email": "gerasimovan.01061982@postgrespro.ru", "phone": "+70889216935"}
0005433755388	4B6038	2370 309772	SERGEY MOISEEV	{"email": "moiseev.s19051964@postgrespro.ru", "phone": "+70360342856"}
0005433755389	9AD31C	3484 077544	VITALIY EGOROV	{"email": "v.egorov30071967@postgrespro.ru", "phone": "+70499816122"}
0005433755390	F47A25	1068 134997	ALEKSANDR EGOROV	{"email": "aleksandr-egorov.03051965@postgrespro.ru", "phone": "+70021801839"}
0005433755391	D5D3E2	4619 420381	MARIYA DAVYDOVA	{"phone": "+70070975751"}
0005433755392	D5D3E2	1271 170274	NATALYA ROMANOVA	{"phone": "+70176912614"}
0005433755393	6A00FB	1561 836402	RAFAEL ILIN	{"email": "ilin-r_1981@postgrespro.ru", "phone": "+70934485638"}
0005433755394	A49809	4618 786112	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov1974@postgrespro.ru", "phone": "+70728265486"}
0005433755395	A49809	6844 817959	VALENTINA ZHURAVLEVA	{"email": "zhuravleva.valentina051984@postgrespro.ru", "phone": "+70666961816"}
0005433755396	454EA7	7958 782539	ANASTASIYA IVANOVA	{"email": "ivanova.a.20011977@postgrespro.ru", "phone": "+70321313495"}
0005433755397	41732E	1451 341162	LYUBOV ILINA	{"email": "ilina-lyubov-1978@postgrespro.ru", "phone": "+70650115088"}
0005433755398	41732E	4489 052445	LYUBOV GAVRILOVA	{"phone": "+70256686736"}
0005433755399	FEECFA	8920 024167	DARYA MOISEEVA	{"email": "darya.moiseeva-051979@postgrespro.ru", "phone": "+70602677655"}
0005433755400	FEECFA	1479 399441	DMITRIY GRIGOREV	{"email": "d_grigorev-06031959@postgrespro.ru", "phone": "+70119563744"}
0005433755401	22DB51	7979 280207	NATALYA NAZAROVA	{"email": "nazarova.natalya.1961@postgrespro.ru", "phone": "+70384144813"}
0005433755402	31D7DE	0922 651206	TATYANA KUDRYASHOVA	{"phone": "+70500766867"}
0005433755403	31D7DE	3121 021377	YULIYA KALININA	{"phone": "+70847938421"}
0005433755404	1DF1B0	3109 577789	GALINA ROMANOVA	{"email": "g_romanova_111965@postgrespro.ru", "phone": "+70450557671"}
0005433755405	C4AE99	9606 368942	SERGEY VASILEV	{"phone": "+70232278898"}
0005433755406	734E98	7867 330151	TATYANA NAUMOVA	{"email": "naumova.t1971@postgrespro.ru", "phone": "+70640159923"}
0005433755407	EC28F3	1161 785381	MIKHAIL GORBUNOV	{"email": "m_gorbunov.14091967@postgrespro.ru", "phone": "+70942160909"}
0005433755408	EC28F3	3452 975124	ALEKSANDRA ABRAMOVA	{"email": "abramovaa16021968@postgrespro.ru", "phone": "+70189027722"}
0005433755409	9BEE01	3144 707074	IRINA AKIMOVA	{"phone": "+70596235763"}
0005433755410	306295	3254 934892	MARIYA IVANOVA	{"phone": "+70896205358"}
0005433755411	306295	9160 892564	ALEKSANDR RODIONOV	{"email": "rodionov_a-091979@postgrespro.ru", "phone": "+70018194596"}
0005433755412	FA8BF5	3316 695545	VALENTINA MEDVEDEVA	{"email": "v_medvedeva_15031967@postgrespro.ru", "phone": "+70545139713"}
0005433755413	FA8BF5	1237 661078	ANATOLIY KRASNOV	{"phone": "+70744107196"}
0005433755414	59D64B	8934 768812	POLINA GAVRILOVA	{"phone": "+70635807549"}
0005433755415	61F777	5933 668148	VIKTOR KUDRYASHOV	{"phone": "+70948298453"}
0005433755416	9D533E	0775 211860	VLADIMIR BORISOV	{"phone": "+70085084088"}
0005433755417	68052F	7558 720349	VIKTOR MATVEEV	{"email": "matveevviktor.121973@postgrespro.ru", "phone": "+70821472411"}
0005433755418	B01B04	7037 478774	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey18051974@postgrespro.ru", "phone": "+70814931131"}
0005433755419	B01B04	4358 510470	TATYANA KUZMINA	{"email": "kuzminat_02031978@postgrespro.ru", "phone": "+70597505937"}
0005433755420	E4DA88	1625 434152	ANTON SMIRNOV	{"email": "a.smirnov1969@postgrespro.ru", "phone": "+70739768534"}
0005433755421	E4DA88	1017 068069	ANATOLIY KAZAKOV	{"phone": "+70639906925"}
0005433755422	E4DA88	0886 993201	SVETLANA KOVALEVA	{"email": "kovaleva.s031971@postgrespro.ru", "phone": "+70203217560"}
0005433755423	E7BAF4	5576 748790	ALEKSANDR GERASIMOV	{"phone": "+70838801903"}
0005433755424	67763B	8473 005375	ILMIRA ILINA	{"phone": "+70769462641"}
0005433755425	786E1A	9254 912326	MARAT GERASIMOV	{"email": "gerasimovm_011973@postgrespro.ru", "phone": "+70448226961"}
0005433755426	D150F0	8490 186375	ANTON MELNIKOV	{"email": "antonmelnikov_1968@postgrespro.ru", "phone": "+70910754919"}
0005433755427	D150F0	0087 295988	GALINA NESTEROVA	{"phone": "+70370837410"}
0005433755428	4E1A89	9354 453716	MARIYA ANDREEVA	{"phone": "+70982328508"}
0005433755429	4E1A89	8021 867900	VYACHESLAV ZHURAVLEV	{"phone": "+70742532127"}
0005433755430	61B67B	8147 467612	VIKTOR SCHERBAKOV	{"email": "scherbakov_v.21081971@postgrespro.ru", "phone": "+70085169351"}
0005433755431	B2CDBE	7866 077007	LIDIYA ROMANOVA	{"email": "l.romanova_09051975@postgrespro.ru", "phone": "+70476579345"}
0005433755432	7730B5	9748 537693	SERGEY SOROKIN	{"email": "sorokin_sergey.091976@postgrespro.ru", "phone": "+70196227049"}
0005433755433	76F9DF	1546 568189	ALEKSEY ALEKSANDROV	{"email": "a-aleksandrov-1971@postgrespro.ru", "phone": "+70614956534"}
0005433755434	7E0F12	8454 299519	ALEKSANDR AFANASEV	{"phone": "+70321549658"}
0005433755435	7E0F12	0381 763793	NATALYA KRASNOVA	{"phone": "+70808025956"}
0005433755436	E04B9B	7215 549013	ALEKSANDRA KUZNECOVA	{"email": "a-kuznecova16031978@postgrespro.ru", "phone": "+70412484557"}
0005433755437	E04B9B	6267 006775	NIKOLAY VASILEV	{"phone": "+70578087685"}
0005433755438	8C0B96	4310 707180	TATYANA GRISHINA	{"phone": "+70759481878"}
0005433755439	3082CC	4867 546864	DMITRIY NOVIKOV	{"email": "novikov.dmitriy_19021971@postgrespro.ru", "phone": "+70759300807"}
0005433755440	CDF4BC	9329 941218	MAKSIM PETROV	{"email": "m-petrov.08071973@postgrespro.ru", "phone": "+70567860448"}
0005433755441	CDF4BC	2560 217078	ALEKSANDR EGOROV	{"phone": "+70738710022"}
0005433755442	CD72AA	1899 700335	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.051971@postgrespro.ru", "phone": "+70818466437"}
0005433755443	CD72AA	3790 257039	NINA GORBUNOVA	{"email": "nina.gorbunova.071973@postgrespro.ru", "phone": "+70452929242"}
0005433755444	9B0E0C	8409 332265	YANA IVANOVA	{"phone": "+70149118070"}
0005433755445	EDEDF0	3893 223610	MARIYA KOMAROVA	{"email": "mariyakomarova.111970@postgrespro.ru", "phone": "+70976547794"}
0005433755446	1AF226	7197 439632	DMITRIY FEDOROV	{"email": "fedorovd-01071975@postgrespro.ru", "phone": "+70137990830"}
0005433755447	1AF226	0650 622962	IRINA TIKHONOVA	{"phone": "+70236400581"}
0005433755448	1AF226	8987 403789	ANDREY FEDOROV	{"phone": "+70476654885"}
0005433755449	C18514	5559 804226	OKSANA IVANOVA	{"phone": "+70999538797"}
0005433755450	7E9230	5346 790919	SVETLANA MAKAROVA	{"email": "s_makarova_13111978@postgrespro.ru", "phone": "+70729263141"}
0005433755451	85C317	3581 608433	EKATERINA EGOROVA	{"email": "e-egorova_1963@postgrespro.ru", "phone": "+70510226262"}
0005433755452	EE579A	9772 062479	ARSENIY MOISEEV	{"email": "a-moiseev.031989@postgrespro.ru", "phone": "+70527667222"}
0005433755453	31CE3C	6374 004078	VYACHESLAV FEDOROV	{"phone": "+70648073443"}
0005433755454	CEC13A	5825 057887	VALERIYA KARPOVA	{"email": "v_karpova.071977@postgrespro.ru", "phone": "+70428415249"}
0005433755455	CEC13A	7582 332897	VALENTINA MIKHAYLOVA	{"email": "mikhaylovavalentina-27041966@postgrespro.ru", "phone": "+70518102377"}
0005433755456	FDDFAE	8683 125931	LYUBOV ERMAKOVA	{"email": "ermakova-lyubov.051976@postgrespro.ru", "phone": "+70547703375"}
0005433755457	4C852A	1496 911722	VLADISLAV FILIPPOV	{"email": "vladislav-filippov031966@postgrespro.ru", "phone": "+70156820505"}
0005433755458	1162EC	8519 724407	DMITRIY RODIONOV	{"phone": "+70964378287"}
0005433755459	1162EC	7556 767139	SERGEY NIKITIN	{"email": "snikitin101963@postgrespro.ru", "phone": "+70081977096"}
0005433755460	BF112B	6865 887106	DENIS BELOV	{"email": "belov_d1976@postgrespro.ru", "phone": "+70041002183"}
0005433755461	0D1192	9474 028858	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a-061978@postgrespro.ru", "phone": "+70279984568"}
0005433755462	0D1192	0247 036159	GEORGIY KUZNECOV	{"email": "georgiykuznecov-031973@postgrespro.ru", "phone": "+70341239833"}
0005433755463	8A3FE7	4128 559087	DANIIL TARASOV	{"phone": "+70790520261"}
0005433755464	54DDC5	5061 831122	VALENTINA KRASNOVA	{"email": "valentina-krasnova071983@postgrespro.ru", "phone": "+70906534027"}
0005433755465	18FCBE	9428 838085	TIMUR MEDVEDEV	{"phone": "+70784387820"}
0005433755466	133065	3344 371469	DMITRIY YAKOVLEV	{"phone": "+70710390329"}
0005433755467	2738F0	2768 321054	ZLATA KAZAKOVA	{"phone": "+70816119097"}
0005433755468	516820	7586 531297	TAMARA GAVRILOVA	{"phone": "+70580709300"}
0005433755469	E25057	6810 856167	LYUDMILA MIKHAYLOVA	{"phone": "+70522890466"}
0005433755470	842D42	6550 725639	ANASTASIYA LOGINOVA	{"phone": "+70442183149"}
0005433755471	35DCEB	6848 883051	ROMAN FEDOROV	{"phone": "+70127670739"}
0005433755472	E82C8D	3533 654775	SVETLANA ARKHIPOVA	{"phone": "+70972094885"}
0005433755473	1B9C12	8449 703968	GENNADIY SOLOVEV	{"email": "gennadiy-solovev.19021971@postgrespro.ru", "phone": "+70525524458"}
0005433755474	B5670F	4079 777325	ANGELINA FOMINA	{"email": "a-fomina-17021988@postgrespro.ru", "phone": "+70767295436"}
0005433755475	B5670F	6407 266243	MIKHAIL KUZNECOV	{"phone": "+70092797481"}
0005433755476	C12FF9	6953 857077	ELENA MELNIKOVA	{"email": "elenamelnikova.051975@postgrespro.ru", "phone": "+70449822910"}
0005433755477	C12FF9	1198 915269	EVGENIY KUZMIN	{"email": "kuzmin_e_051963@postgrespro.ru", "phone": "+70970955655"}
0005433755478	C29777	0540 588415	KONSTANTIN SAVELEV	{"phone": "+70538370911"}
0005433755479	7FE8B5	0628 828549	ARINA VOLKOVA	{"email": "a_volkova.28021976@postgrespro.ru", "phone": "+70262965040"}
0005433755480	7FE8B5	6657 495234	MARIYA POPOVA	{"phone": "+70941764768"}
0005433755481	C3B599	9900 350595	ELENA ALEKSEEVA	{"email": "alekseeva-e04091976@postgrespro.ru", "phone": "+70035914126"}
0005433755482	90332F	7076 248366	VALENTINA MAKSIMOVA	{"phone": "+70978808116"}
0005433755483	E340C9	7163 128061	PAVEL KUZMIN	{"phone": "+70971519711"}
0005433755484	CC8C68	1209 284351	IGOR SOROKIN	{"phone": "+70320836521"}
0005433755485	FBA02F	7152 629703	NATALYA EGOROVA	{"email": "egorovan_121966@postgrespro.ru", "phone": "+70927794341"}
0005433755486	FBA02F	2812 615777	VLADIMIR IVANOV	{"email": "ivanov_v1980@postgrespro.ru", "phone": "+70104233768"}
0005433755487	188184	7123 102451	ELENA VASILEVA	{"email": "vasileva_elena_21071967@postgrespro.ru", "phone": "+70561372996"}
0005433755488	33B5E6	9415 762509	ALEKSANDR GERASIMOV	{"email": "aleksandrgerasimov1974@postgrespro.ru", "phone": "+70732838137"}
0005433755489	9679E6	2870 086528	VYACHESLAV MEDVEDEV	{"email": "medvedev.vyacheslav-13101973@postgrespro.ru", "phone": "+70378567487"}
0005433755490	63B7E6	8547 837255	VYACHESLAV SERGEEV	{"phone": "+70890300520"}
0005433755491	63B7E6	6595 025227	ALEKSEY YAKOVLEV	{"phone": "+70517145408"}
0005433755492	F95099	4471 207382	OLGA KRASNOVA	{"email": "olga_krasnova_12021972@postgrespro.ru", "phone": "+70105831715"}
0005433755493	DE9175	2124 376478	ALEKSEY MOROZOV	{"phone": "+70661330868"}
0005433755494	5515C9	0828 131212	DMITRIY KONOVALOV	{"email": "konovalov_d-021964@postgrespro.ru", "phone": "+70691231156"}
0005433755495	5515C9	0131 809932	KLAVDIYA IVANOVA	{"phone": "+70877594019"}
0005433755496	5BF16E	2360 995441	ALEKSANDR VASILEV	{"email": "avasilev.16051981@postgrespro.ru", "phone": "+70391604770"}
0005433755497	C1D70B	5692 428802	MARIYA SEMENOVA	{"phone": "+70089200088"}
0005433755498	C1D70B	5833 876162	ANDREY ZHUKOV	{"phone": "+70272847977"}
0005433755499	91DAEA	9588 086408	IRINA ZHUKOVA	{"phone": "+70161594678"}
0005433755500	286B4C	7415 349519	ROMAN ZAKHAROV	{"email": "zakharov-r.31031976@postgrespro.ru", "phone": "+70782683223"}
0005433755501	286B4C	0186 345783	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev_25101977@postgrespro.ru", "phone": "+70971252681"}
0005433755502	A037F7	4820 396912	NIKOLAY KISELEV	{"phone": "+70654413122"}
0005433755503	A037F7	6571 957176	VLADISLAV KOZLOV	{"email": "kozlov-vladislav1973@postgrespro.ru", "phone": "+70182880999"}
0005433755504	1B928A	9775 223789	SERGEY KUZNECOV	{"email": "kuznecov-s-031968@postgrespro.ru", "phone": "+70395389479"}
0005433755505	3C0A00	3186 904126	ALINA KALININA	{"phone": "+70243208930"}
0005433755506	626DEB	4434 285793	ANASTASIYA MOROZOVA	{"email": "morozovaanastasiya17051964@postgrespro.ru", "phone": "+70493071321"}
0005433755507	626DEB	0892 517558	EVGENIY VOROBEV	{"email": "vorobev_e22091981@postgrespro.ru", "phone": "+70059720150"}
0005433755508	ED58C2	6972 612539	SVETLANA TIKHONOVA	{"phone": "+70451574709"}
0005433755509	ED58C2	7494 724011	VASILIY KISELEV	{"email": "vkiselev-021968@postgrespro.ru", "phone": "+70480513730"}
0005433755510	ED58C2	8767 255935	VARVARA KUZNECOVA	{"email": "v-kuznecova-23051978@postgrespro.ru", "phone": "+70110359611"}
0005433755511	5421A1	6825 591555	VALERIY FROLOV	{"phone": "+70848707684"}
0005433755512	5421A1	3944 712586	ANASTASIYA LUKYANOVA	{"email": "lukyanova.anastasiya_14011978@postgrespro.ru", "phone": "+70348006355"}
0005433755513	19B46D	8622 741467	EVGENIY SOROKIN	{"phone": "+70100103663"}
0005433755514	B5A792	4881 267416	ELIZAVETA NESTEROVA	{"email": "elizaveta-nesterova.1962@postgrespro.ru", "phone": "+70859645326"}
0005433755515	D889A2	1248 009974	ELENA SOKOLOVA	{"phone": "+70225722834"}
0005433755516	76FCAD	4439 791979	EKATERINA PAVLOVA	{"email": "pavlovaekaterina_1964@postgrespro.ru", "phone": "+70529842632"}
0005433755517	42E0B4	1351 992251	NIKOLAY SEMENOV	{"phone": "+70847142305"}
0005433755518	F0503B	3436 472100	OLGA KARPOVA	{"phone": "+70334951967"}
0005433755519	F0503B	7567 110113	NADEZHDA SCHERBAKOVA	{"email": "scherbakova.nadezhda_12031978@postgrespro.ru", "phone": "+70373615650"}
0005433755520	56132A	3467 107479	ALEKSANDR NAUMOV	{"phone": "+70611689143"}
0005433755521	1469A6	1943 631641	SERGEY SCHERBAKOV	{"phone": "+70366098724"}
0005433755522	3CD67D	9849 040403	VIKTORIYA POLYAKOVA	{"email": "polyakova-v14051981@postgrespro.ru", "phone": "+70306421134"}
0005433755523	26ABE3	5774 611940	ANASTASIYA ANDREEVA	{"email": "andreeva-anastasiya.1971@postgrespro.ru", "phone": "+70541121753"}
0005433755524	21D87C	9978 896468	LARISA KUZNECOVA	{"phone": "+70102154186"}
0005433755525	865A78	0153 740612	YURIY ALEKSANDROV	{"phone": "+70283650559"}
0005433755526	2A2C38	7069 457940	MAKSIM POPOV	{"email": "maksim_popov.24041984@postgrespro.ru", "phone": "+70345393095"}
0005433755527	2A2C38	6386 982549	ANTONINA GRISHINA	{"email": "grishinaa-1971@postgrespro.ru", "phone": "+70901617041"}
0005433755528	9D8EFD	4447 442955	YULIYA IVANOVA	{"email": "yuliyaivanova_1978@postgrespro.ru", "phone": "+70660846173"}
0005433755529	9D8EFD	3175 670082	NATALYA ABRAMOVA	{"email": "natalya-abramova1968@postgrespro.ru", "phone": "+70224520781"}
0005433755530	9D8EFD	3186 845382	SERGEY PETROV	{"phone": "+70792891294"}
0005433755531	83ACB8	7472 024532	NINA GAVRILOVA	{"phone": "+70961196911"}
0005433755532	AB05F4	8030 111023	SERGEY VOLKOV	{"email": "sergey.volkov-031976@postgrespro.ru", "phone": "+70770612038"}
0005433755533	6278BB	4483 987415	NATALYA DAVYDOVA	{"email": "davydova-n-11081979@postgrespro.ru", "phone": "+70861051435"}
0005433755534	6278BB	5229 126563	ALISA TIKHONOVA	{"email": "atikhonova25081977@postgrespro.ru", "phone": "+70208527895"}
0005433755535	6278BB	3279 232920	YULIYA DANILOVA	{"email": "yuliya-danilova-1968@postgrespro.ru", "phone": "+70782406956"}
0005433755536	6F2D28	3518 997004	MARIYA ANTONOVA	{"email": "mantonova1968@postgrespro.ru", "phone": "+70478088324"}
0005433755537	2EFB71	0843 788586	TATYANA PAVLOVA	{"email": "tatyana-pavlova.031971@postgrespro.ru", "phone": "+70563019578"}
0005433755538	2EFB71	7488 736701	EVGENIY NIKOLAEV	{"phone": "+70808972897"}
0005433755539	24E3D0	1323 246793	VENERA GRISHINA	{"phone": "+70393621961"}
0005433755540	2DCD35	3370 039972	ALEKSANDR BONDARENKO	{"phone": "+70645137151"}
0005433755541	A37BF8	5704 120008	LYUBOV EGOROVA	{"phone": "+70001156095"}
0005433755542	A37BF8	6202 906587	MIKHAIL KONOVALOV	{"phone": "+70778559678"}
0005433755543	D9D758	7711 892326	DARYA ALEKSANDROVA	{"email": "daryaaleksandrova06091974@postgrespro.ru", "phone": "+70559026229"}
0005433755544	E67409	7756 814279	VALERIY SERGEEV	{"email": "v.sergeev121973@postgrespro.ru", "phone": "+70195113978"}
0005433755545	E67409	8122 296141	ALLA POPOVA	{"phone": "+70358646263"}
0005433755546	16D356	4592 632955	ILYA ALEKSANDROV	{"phone": "+70071829927"}
0005433755547	16D356	0960 279272	TATYANA MAKSIMOVA	{"phone": "+70787706033"}
0005433755548	2C80B9	0733 798108	VALENTINA MOISEEVA	{"phone": "+70980972885"}
0005433755549	2C80B9	4939 203813	ALEKSANDR KRASNOV	{"phone": "+70749753054"}
0005433755550	D33661	8876 555061	ALBINA POLYAKOVA	{"email": "polyakova_a-1964@postgrespro.ru", "phone": "+70458551333"}
0005433755551	D33661	5565 746954	EVGENIY DENISOV	{"email": "evgeniy_denisov-23061974@postgrespro.ru", "phone": "+70088011019"}
0005433755552	D33661	1628 874522	VYACHESLAV KRASNOV	{"phone": "+70987628267"}
0005433755553	E7A117	7593 446300	LYUDMILA POLYAKOVA	{"email": "polyakova-l.121972@postgrespro.ru", "phone": "+70750053884"}
0005433755554	3E71A0	2206 332292	ALEKSEY IVANOV	{"phone": "+70460074338"}
0005433755555	1FB0A2	6572 557736	SVETLANA LAZAREVA	{"phone": "+70399886248"}
0005433755556	A1B233	2900 416403	EVGENIY SEMENOV	{"phone": "+70077334914"}
0005433755557	A1B233	1859 315384	MARINA NESTEROVA	{"email": "nesterova_m_071964@postgrespro.ru", "phone": "+70097953076"}
0005433755558	AE8890	8361 600364	VYACHESLAV SIDOROV	{"email": "v.sidorov101982@postgrespro.ru", "phone": "+70050733419"}
0005433755559	AE8890	5814 917498	ALEKSANDR KOZLOV	{"phone": "+70730358875"}
0005433755560	8980A5	9492 254003	NATALIYA IVANOVA	{"phone": "+70737961747"}
0005433755561	8980A5	5922 117542	LIDIYA POPOVA	{"email": "popovalidiya.1978@postgrespro.ru", "phone": "+70779039430"}
0005433755562	D92F08	3039 471322	DMITRIY PETROV	{"phone": "+70273213536"}
0005433755563	64D51C	7689 534217	OKSANA FILIPPOVA	{"phone": "+70367094667"}
0005433755564	029742	2022 264322	SVETLANA KUZNECOVA	{"phone": "+70379562173"}
0005433755565	449F9B	6570 138396	ELENA KISELEVA	{"email": "kiseleva-e_1973@postgrespro.ru", "phone": "+70933979752"}
0005433755566	ECB3F1	2527 282599	ELENA DENISOVA	{"email": "denisova_elena.20021976@postgrespro.ru", "phone": "+70323097187"}
0005433755567	A4922E	1144 746209	DMITRIY VOLKOV	{"email": "d.volkov_1976@postgrespro.ru", "phone": "+70085409304"}
0005433755568	5284FF	5887 663856	NIKOLAY GUSEV	{"email": "nikolay.gusev-26061965@postgrespro.ru", "phone": "+70410022589"}
0005433755569	9D1EB5	5065 695551	PETR IVANOV	{"phone": "+70582397870"}
0005433755570	911012	7771 980971	ELENA AKIMOVA	{"email": "akimovaelena_27021968@postgrespro.ru", "phone": "+70707463692"}
0005433755571	911012	4131 393493	VALENTINA ALEKSANDROVA	{"email": "v.aleksandrova-24021964@postgrespro.ru", "phone": "+70426276570"}
0005433755572	5630E5	8903 417587	ALEKSEY SHEVCHENKO	{"phone": "+70643929101"}
0005433755573	5630E5	0951 853233	SERGEY KONOVALOV	{"phone": "+70785633773"}
0005433755574	14AE3E	5746 067133	VLADIMIR SMIRNOV	{"phone": "+70164237831"}
0005433755575	14AE3E	5365 364542	VIKTORIYA LUKYANOVA	{"phone": "+70478461900"}
0005433755576	6A05F4	8450 817057	OLGA MEDVEDEVA	{"phone": "+70726408944"}
0005433755577	E74E03	3693 024457	VADIM KUZNECOV	{"email": "vkuznecov24111958@postgrespro.ru", "phone": "+70442884621"}
0005433755578	643D5D	0133 461463	YURIY NIKITIN	{"phone": "+70003988882"}
0005433755579	643D5D	1751 163115	KONSTANTIN KUDRYASHOV	{"email": "kudryashov_konstantin.31081970@postgrespro.ru", "phone": "+70383114698"}
0005433755580	FE99D4	9207 950147	ELENA NIKITINA	{"email": "nikitina-e10021958@postgrespro.ru", "phone": "+70218413628"}
0005433755581	ECCC26	2813 771330	SERGEY IVANOV	{"email": "ivanov-sergey_1968@postgrespro.ru", "phone": "+70592632427"}
0005433755582	ECCC26	2559 909430	TATYANA KAZAKOVA	{"phone": "+70982122972"}
0005433755583	ECCC26	7958 121382	LIDIYA IVANOVA	{"email": "ivanova-lidiya071967@postgrespro.ru", "phone": "+70522960477"}
0005433755584	DC1D9C	7346 067432	ELENA MOISEEVA	{"phone": "+70765769528"}
0005433755585	726F07	3966 064117	ANATOLIY IVANOV	{"email": "ivanov_anatoliy051962@postgrespro.ru", "phone": "+70959908651"}
0005433755586	542B93	7369 298519	VIKTORIYA IVANOVA	{"email": "ivanovaviktoriya.1967@postgrespro.ru", "phone": "+70910684126"}
0005433755587	B968C4	9249 531731	ALENA PAVLOVA	{"phone": "+70225473728"}
0005433755588	722F23	1132 964210	LARISA PETROVA	{"email": "petrova_larisa15091973@postgrespro.ru", "phone": "+70996546162"}
0005433755589	722F23	7278 394917	SOFIYA NIKOLAEVA	{"email": "s.nikolaeva06041960@postgrespro.ru", "phone": "+70152465794"}
0005433755590	BFB047	9089 305324	ELENA SCHERBAKOVA	{"email": "elena_scherbakova.091978@postgrespro.ru", "phone": "+70199159699"}
0005433755591	BFB047	5921 879036	LYUDMILA SAVELEVA	{"email": "lsaveleva.15031970@postgrespro.ru", "phone": "+70157174796"}
0005433755592	BFB047	6702 508191	VASILIY MIRONOV	{"phone": "+70621729217"}
0005433755593	A534FA	8768 635539	NATALYA GAVRILOVA	{"phone": "+70281282216"}
0005433755594	EAC846	1512 607514	SVETLANA DANILOVA	{"email": "sdanilova081970@postgrespro.ru", "phone": "+70624404226"}
0005433755595	095FEC	8779 714031	ANNA KOZLOVA	{"phone": "+70706927155"}
0005433755596	63ED7E	8672 053618	EDUARD FROLOV	{"email": "eduard-frolov.03051970@postgrespro.ru", "phone": "+70896678132"}
0005433755597	8B3E17	1081 839945	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay-1974@postgrespro.ru", "phone": "+70785073679"}
0005433755598	8B3E17	7873 086997	ELENA MOROZOVA	{"email": "elena-morozova.04061979@postgrespro.ru", "phone": "+70717729942"}
0005433755599	CAD032	8758 095068	OKSANA ANISIMOVA	{"phone": "+70839719468"}
0005433755600	3815C6	0400 554647	ELENA ZHUKOVA	{"phone": "+70766041272"}
0005433755601	74E59F	4353 323469	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_081969@postgrespro.ru", "phone": "+70632590819"}
0005433755602	74E59F	4541 953991	EVGENIY ORLOV	{"email": "orlov-e_02051965@postgrespro.ru", "phone": "+70923847253"}
0005433755603	DB54F6	9080 509418	ZINAIDA MIKHAYLOVA	{"phone": "+70078018131"}
0005433755604	6FD187	5524 121692	SERGEY NOVIKOV	{"phone": "+70394863218"}
0005433755605	525FA6	7174 565664	YANA IVANOVA	{"phone": "+70688207543"}
0005433755606	525FA6	8745 229064	ELENA KOROLEVA	{"email": "e-koroleva-17011971@postgrespro.ru", "phone": "+70107975588"}
0005433755607	5C4B9E	1160 427648	ANASTASIYA TITOVA	{"phone": "+70438049306"}
0005433755608	5C4B9E	4294 495018	ANNA KUDRYASHOVA	{"email": "kudryashovaa_081975@postgrespro.ru", "phone": "+70197593531"}
0005433755609	348073	1231 356327	ANATOLIY NIKOLAEV	{"email": "anatoliy.nikolaev-20101970@postgrespro.ru", "phone": "+70967656045"}
0005433755610	6E794B	4705 928425	ANNA KUZMINA	{"email": "a-kuzmina_23041970@postgrespro.ru", "phone": "+70497055784"}
0005433755611	49D1CE	2327 200671	MARINA DMITRIEVA	{"phone": "+70072936641"}
0005433755612	49D1CE	7883 013807	LYUBOV SOROKINA	{"phone": "+70658179727"}
0005433755613	6AF5D7	1642 036075	TATYANA MAKSIMOVA	{"email": "maksimovat.17121984@postgrespro.ru", "phone": "+70230894157"}
0005433755614	6AF5D7	5003 371455	NADEZHDA GRISHINA	{"phone": "+70938234471"}
0005433755615	DD789F	1566 641961	LYUBOV IVANOVA	{"phone": "+70604435899"}
0005433755616	DD789F	5789 452799	ANDREY MAKSIMOV	{"phone": "+70025544315"}
0005433755617	EC4693	4635 195931	ELENA FILIPPOVA	{"phone": "+70319087791"}
0005433755618	C8D336	4137 476715	YURIY SEMENOV	{"phone": "+70376477451"}
0005433755619	781EA7	7811 224799	ANVAR ILIN	{"email": "ilina07081971@postgrespro.ru", "phone": "+70515932518"}
0005433755620	5773B0	8356 716111	EVGENIY TIKHONOV	{"phone": "+70944612929"}
0005433755621	1BCEBB	8631 948737	OLGA ZAKHAROVA	{"email": "zakharovao031959@postgrespro.ru", "phone": "+70628000703"}
0005433755622	ABD1F3	2968 066024	VALENTINA ILINA	{"phone": "+70286727996"}
0005433755623	A475DC	8563 816134	YURIY ANDREEV	{"email": "y-andreev121977@postgrespro.ru", "phone": "+70509604706"}
0005433755624	7DF5C7	1390 208158	NINA SOROKINA	{"phone": "+70904251156"}
0005433755625	58B781	5720 684725	SERGEY SERGEEV	{"email": "sergeysergeev-051974@postgrespro.ru", "phone": "+70025280614"}
0005433755626	3B4E14	1789 048642	VLADIMIR SOLOVEV	{"email": "v.solovev.1966@postgrespro.ru", "phone": "+70841655623"}
0005433755627	46B698	1541 131632	SERGEY FOMIN	{"phone": "+70970336585"}
0005433755628	46B698	3302 912920	VERA SOROKINA	{"phone": "+70872332498"}
0005433755629	762936	5159 772724	NATALYA PAVLOVA	{"phone": "+70669526722"}
0005433755630	1C9F7F	5591 033720	ALEKSANDR YAKOVLEV	{"email": "yakovleva1975@postgrespro.ru", "phone": "+70990422507"}
0005433755631	E3A5DB	8487 230742	EVGENIYA SMIRNOVA	{"email": "smirnova_evgeniya_061971@postgrespro.ru", "phone": "+70106821560"}
0005433755632	E3A5DB	8550 107767	ANNA NIKOLAEVA	{"email": "a.nikolaeva.051973@postgrespro.ru", "phone": "+70545279894"}
0005433755633	6DCE3B	1404 754458	FEDOR VOROBEV	{"email": "vorobev-f-14081970@postgrespro.ru", "phone": "+70307884294"}
0005433755634	6DCE3B	5162 876161	ALEKSANDR YAKOVLEV	{"phone": "+70240048324"}
0005433755635	E82AE3	6592 033084	ANDREY ROMANOV	{"phone": "+70794039773"}
0005433755636	7B13E4	9156 631259	NINA IVANOVA	{"phone": "+70783998706"}
0005433755637	5CBAA0	9483 701879	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.04081963@postgrespro.ru", "phone": "+70182302855"}
0005433755638	5CBAA0	6046 581078	OLGA LUKYANOVA	{"phone": "+70593345881"}
0005433755639	A3C35E	0987 106491	VLADIMIR POPOV	{"phone": "+70876998980"}
0005433755640	A3C35E	7053 461479	TATYANA STEPANOVA	{"email": "t-stepanova.19041978@postgrespro.ru", "phone": "+70077166379"}
0005433755641	6CA5F8	3088 452331	RAISA TIMOFEEVA	{"phone": "+70559460532"}
0005433755642	1F3847	6479 521276	LIDIYA KRASNOVA	{"email": "lidiya.krasnova_01011968@postgrespro.ru", "phone": "+70051212630"}
0005433755643	7BCE49	1161 483963	IVAN IVANOV	{"phone": "+70424959440"}
0005433755644	C7A71C	8246 742957	ANDREY SOKOLOV	{"email": "a-sokolov-1968@postgrespro.ru", "phone": "+70348002635"}
0005433755645	F5F5B4	6704 899701	VADIM GAVRILOV	{"phone": "+70968025584"}
0005433755646	F5F5B4	8483 047181	VLADIMIR PAVLOV	{"email": "vladimir.pavlov_011979@postgrespro.ru", "phone": "+70400234752"}
0005433755647	6324DE	5611 146257	VLADIMIR FILIPPOV	{"phone": "+70230916622"}
0005433755648	6324DE	3274 959195	EKATERINA EFREMOVA	{"email": "efremova-ekaterina121969@postgrespro.ru", "phone": "+70241166513"}
0005433755649	98499C	1861 258986	ELENA GORBUNOVA	{"email": "gorbunova_elena-1968@postgrespro.ru", "phone": "+70928582636"}
0005433755650	7E7CE7	7201 094594	LYUBOV ANDREEVA	{"phone": "+70226850843"}
0005433755651	EF9271	5381 098918	YULIYA ALEKSEEVA	{"email": "y.alekseeva041966@postgrespro.ru", "phone": "+70248036561"}
0005433755652	AA57D3	7639 671445	POLINA LOGINOVA	{"email": "loginova.polina_061974@postgrespro.ru", "phone": "+70578335683"}
0005433755653	335054	0020 321108	ROMAN POPOV	{"email": "r-popov-1972@postgrespro.ru", "phone": "+70337233713"}
0005433755654	682677	4111 443666	VLADIMIR ROMANOV	{"phone": "+70673133371"}
0005433755655	682677	2643 217066	VLADIMIR ALEKSANDROV	{"email": "vladimiraleksandrov.071973@postgrespro.ru", "phone": "+70313176511"}
0005433755656	F6C53C	4736 671227	VLADIMIR SCHERBAKOV	{"email": "vladimir_scherbakov-03121966@postgrespro.ru", "phone": "+70220793537"}
0005433755657	F6C53C	3761 368703	SERGEY TARASOV	{"email": "tarasovs08091970@postgrespro.ru", "phone": "+70144657586"}
0005433755658	A9FE04	4053 862726	NINA AFANASEVA	{"phone": "+70386818080"}
0005433755659	DCD7AF	5669 871229	KSENIYA MAKSIMOVA	{"phone": "+70936777185"}
0005433755660	DCD7AF	1756 390711	OLEG TARASOV	{"phone": "+70392158632"}
0005433755661	9215B8	5960 786247	DMITRIY ANDREEV	{"phone": "+70430374689"}
0005433755662	2CBC6A	9162 857720	MIKHAIL MOISEEV	{"phone": "+70360039651"}
0005433755663	2CBC6A	5198 901944	EKATERINA ANTONOVA	{"email": "e.antonova17121972@postgrespro.ru", "phone": "+70602529030"}
0005433755664	835C35	6421 587669	ARTEMIY KOZLOV	{"email": "artemiy.kozlov.091978@postgrespro.ru", "phone": "+70629403627"}
0005433755665	835C35	8808 793607	ANATOLIY KUZMIN	{"email": "akuzmin_25061970@postgrespro.ru", "phone": "+70926170983"}
0005433755666	C90488	7870 818786	NIKITA POPOV	{"email": "npopov061968@postgrespro.ru", "phone": "+70616604859"}
0005433755667	2352FF	0126 410001	DMITRIY DMITRIEV	{"phone": "+70525495128"}
0005433755668	B3868C	4917 649992	KRISTINA BOGDANOVA	{"phone": "+70916976490"}
0005433755669	A5635A	6086 506770	ROMAN BARANOV	{"phone": "+70893596991"}
0005433755670	A5635A	4794 585340	RAISA POPOVA	{"email": "popova.r121969@postgrespro.ru", "phone": "+70577309656"}
0005433755671	91FA8E	7658 244371	PAVEL SOROKIN	{"phone": "+70686822100"}
0005433755672	6B828F	0199 875531	ANATOLIY PAVLOV	{"phone": "+70945763531"}
0005433755673	6AA5DF	1160 775252	ALEKSANDR MATVEEV	{"email": "aleksandr.matveev-1981@postgrespro.ru", "phone": "+70685110143"}
0005433755674	E37652	7634 359867	GALINA KOROLEVA	{"phone": "+70542751088"}
0005433755675	FF2794	0225 628813	EKATERINA KOVALEVA	{"email": "e_kovaleva.17091977@postgrespro.ru", "phone": "+70452231507"}
0005433755676	FF2794	8169 498660	EKATERINA NIKITINA	{"phone": "+70419886443"}
0005433755677	AD038E	7800 211428	ALEKSANDR DMITRIEV	{"email": "a-dmitriev23081972@postgrespro.ru", "phone": "+70112843440"}
0005433755678	D9B488	7185 929073	MARIYA GERASIMOVA	{"phone": "+70748346580"}
0005433755679	D9B488	8830 832682	ANTONINA ZAKHAROVA	{"email": "zakharova.antonina-081965@postgrespro.ru", "phone": "+70933988149"}
0005433755680	CF0BB4	3740 149761	ANATOLIY POPOV	{"email": "popovanatoliy.05081976@postgrespro.ru", "phone": "+70113017260"}
0005433755681	CF0BB4	4110 897099	YULIYA KOMAROVA	{"phone": "+70013114209"}
0005433755682	00F054	2179 073304	YULIYA RODIONOVA	{"phone": "+70257829729"}
0005433755683	F24A59	2347 096165	EKATERINA FOMINA	{"phone": "+70371744676"}
0005433755684	F24A59	8354 786031	LARISA NAZAROVA	{"phone": "+70372473830"}
0005433755685	5B0279	3961 885655	ANDREY ILIN	{"phone": "+70707866458"}
0005433755686	690568	8353 153751	ELENA MOROZOVA	{"email": "morozova-e_26121977@postgrespro.ru", "phone": "+70581541272"}
0005433755687	07851D	7350 719405	ANTONINA KOLESNIKOVA	{"phone": "+70391405285"}
0005433755688	D71B30	6178 838407	MIKHAIL MOROZOV	{"email": "m_morozov.041969@postgrespro.ru", "phone": "+70098445850"}
0005433755689	082301	9759 840423	TATYANA KUDRYASHOVA	{"phone": "+70516693972"}
0005433755690	CE2E95	3882 543297	SERGEY SEMENOV	{"phone": "+70706771674"}
0005433755691	054D83	7206 562205	VLADIMIR MIKHAYLOV	{"phone": "+70047833450"}
0005433755692	054D83	5959 241965	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga_03091966@postgrespro.ru", "phone": "+70367162992"}
0005433755693	054D83	1353 189770	VALENTINA IVANOVA	{"phone": "+70314234757"}
0005433755694	054D83	2014 791155	MIKHAIL EGOROV	{"phone": "+70451388175"}
0005433755695	6DD129	5432 801289	NATALYA ZOTOVA	{"email": "natalya.zotova_1962@postgrespro.ru", "phone": "+70247573422"}
0005433755696	9FFC5E	6556 435108	VALENTINA LEBEDEVA	{"email": "v-lebedeva.16101967@postgrespro.ru", "phone": "+70637515269"}
0005433755697	03432F	0331 562644	EVGENIY GUSEV	{"email": "e-gusev_081983@postgrespro.ru", "phone": "+70018027847"}
0005433755698	95512F	5733 650578	VALENTIN ZAKHAROV	{"phone": "+70997472678"}
0005433755699	FC3A8B	6837 210917	VLADIMIR AFANASEV	{"phone": "+70299225501"}
0005433755700	691E35	7254 384614	TATYANA KOZLOVA	{"email": "t-kozlova-28101975@postgrespro.ru", "phone": "+70884081437"}
0005433755701	691E35	2516 870438	ELENA KUZNECOVA	{"phone": "+70941039982"}
0005433755702	1AC98F	5097 147935	ALEKSEY FROLOV	{"phone": "+70734858882"}
0005433755703	AE7F3F	9224 813153	TATYANA AKIMOVA	{"phone": "+70021969254"}
0005433755704	AE7F3F	2453 494232	EKATERINA LUKYANOVA	{"email": "lukyanova_e-30091971@postgrespro.ru", "phone": "+70244508581"}
0005433755705	AE7F3F	7544 573086	NATALYA STEPANOVA	{"email": "n-stepanova.09111974@postgrespro.ru", "phone": "+70346988698"}
0005433755706	D47ECF	0489 049815	IGOR MIKHAYLOV	{"phone": "+70805667608"}
0005433755707	1E194D	3831 803202	IRAIDA PAVLOVA	{"email": "i_pavlova-17021970@postgrespro.ru", "phone": "+70663332047"}
0005433755708	1E194D	7727 117014	VALENTINA ILINA	{"phone": "+70513900895"}
0005433755709	69CA94	5747 190372	ANASTASIYA BELOVA	{"phone": "+70324182938"}
0005433755710	75129C	4077 083708	RAVIL PETROV	{"phone": "+70437625468"}
0005433755711	6D9DD5	3800 309442	RAISA LOGINOVA	{"email": "raisa-loginova.19101975@postgrespro.ru", "phone": "+70143927094"}
0005433755712	3B181F	2129 255971	VALENTINA BOGDANOVA	{"phone": "+70373529390"}
0005433755713	632181	0628 791430	YULIYA VASILEVA	{"phone": "+70754009084"}
0005433755714	632181	1507 119807	STANISLAV KUZNECOV	{"phone": "+70690569741"}
0005433755715	97E338	0778 076048	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy_10021977@postgrespro.ru", "phone": "+70298221865"}
0005433755716	97E338	9383 116522	VLADIMIR SEMENOV	{"email": "vladimirsemenov_081969@postgrespro.ru", "phone": "+70262374594"}
0005433755717	E6D10B	9079 283665	ANNA FADEEVA	{"phone": "+70208315525"}
0005433755718	1482DC	2253 886181	ANDREY GAVRILOV	{"email": "andrey_gavrilov-22061966@postgrespro.ru", "phone": "+70162791505"}
0005433755719	A94D40	8904 892280	NADEZHDA SOKOLOVA	{"phone": "+70983326099"}
0005433755720	F94384	3832 945766	SERGEY DMITRIEV	{"phone": "+70799386307"}
0005433755721	012C85	3096 495891	KIRILL MAKSIMOV	{"email": "kirill_maksimov.19041965@postgrespro.ru", "phone": "+70889970972"}
0005433755722	012C85	2893 179522	KIRILL ZHURAVLEV	{"email": "kirillzhuravlev021978@postgrespro.ru", "phone": "+70267298838"}
0005433755723	23DB7E	5094 735552	IRINA TARASOVA	{"email": "tarasova_irina15111967@postgrespro.ru", "phone": "+70425304452"}
0005433755724	23DB7E	2833 167765	STANISLAV RODIONOV	{"email": "stanislav-rodionov_1970@postgrespro.ru", "phone": "+70563849154"}
0005433755725	FCA40D	4767 702868	SABINA MOROZOVA	{"phone": "+70675279048"}
0005433755726	6C4BF2	5223 508453	ALEKSEY KUZMIN	{"phone": "+70676586463"}
0005433755727	6C4BF2	9503 333094	ELENA ZHURAVLEVA	{"email": "ezhuravleva-041958@postgrespro.ru", "phone": "+70201692631"}
0005433755728	E66CAA	3511 737935	ELENA IVANOVA	{"phone": "+70758074847"}
0005433755729	5C8724	9931 046300	LYUDMILA POPOVA	{"phone": "+70901869018"}
0005433755730	5C8724	4229 283443	KSENIYA ZAYCEVA	{"email": "k_zayceva-081965@postgrespro.ru", "phone": "+70616275608"}
0005433755731	5C8724	5791 030400	NATALYA KOLESNIKOVA	{"email": "kolesnikovanatalya_021954@postgrespro.ru", "phone": "+70878538165"}
0005433755732	40B936	5340 241256	TATYANA PETROVA	{"email": "petrova.tatyana.071975@postgrespro.ru", "phone": "+70815804077"}
0005433755733	4EF07D	3797 355923	VIKTOR ZAYCEV	{"email": "viktor-zaycev-051969@postgrespro.ru", "phone": "+70773912779"}
0005433755734	27DE02	6376 523314	MARIYA MASLOVA	{"phone": "+70983958954"}
0005433755735	27DE02	2355 961104	ZHANNA NAZAROVA	{"email": "nazarova.zhanna_1977@postgrespro.ru", "phone": "+70341872186"}
0005433755736	5D0895	4252 392202	SERGEY FILIPPOV	{"email": "filippovsergey1981@postgrespro.ru", "phone": "+70302163690"}
0005433755737	5D0895	8653 943791	TATYANA NIKITINA	{"email": "tnikitina.1960@postgrespro.ru", "phone": "+70703336931"}
0005433755738	0A7B53	2623 538976	FEDOR MOISEEV	{"phone": "+70113893128"}
0005433755739	0A7B53	9591 393180	VALENTINA SCHERBAKOVA	{"email": "v_scherbakova_07111969@postgrespro.ru", "phone": "+70054412365"}
0005433755740	0A7B53	3508 316257	ALEKSEY VOROBEV	{"phone": "+70927503755"}
0005433755741	0A7B53	4480 257176	MARINA GUSEVA	{"email": "m-guseva.091972@postgrespro.ru", "phone": "+70815792973"}
0005433755742	3FA50E	0240 423175	VIKTOR ORLOV	{"phone": "+70677416645"}
0005433755743	4E1C73	8202 946556	MIKHAIL SOROKIN	{"email": "sorokin-mikhail_1981@postgrespro.ru", "phone": "+70896987516"}
0005433755744	DD98FB	1404 374487	MARYAM FEDOROVA	{"phone": "+70279885393"}
0005433755745	DD98FB	1768 025365	TATYANA MOROZOVA	{"email": "morozova_t_1974@postgrespro.ru", "phone": "+70529571197"}
0005433755746	EFC475	1831 876189	NIKITA KOROLEV	{"phone": "+70242372163"}
0005433755747	83AD6A	8734 026401	SERGEY POPOV	{"phone": "+70289175353"}
0005433755748	BB0B02	9815 363448	IRINA EFIMOVA	{"phone": "+70304788477"}
0005433755749	A92358	5218 964474	KONSTANTIN GORBUNOV	{"email": "konstantin.gorbunov31031967@postgrespro.ru", "phone": "+70783848634"}
0005433755750	A92358	5619 521664	MARINA MAKAROVA	{"phone": "+70447879643"}
0005433755751	41CC3D	4792 523256	EVGENIY MOROZOV	{"email": "morozov.e-091958@postgrespro.ru", "phone": "+70138199191"}
0005433755752	92F01C	7604 168992	ANNA KRASNOVA	{"email": "akrasnova.06071962@postgrespro.ru", "phone": "+70287567365"}
0005433755753	DE8B16	4608 028524	GENNADIY STEPANOV	{"email": "gennadiy.stepanov_071973@postgrespro.ru", "phone": "+70543566075"}
0005433755754	A70AD4	7586 797344	ALEKSANDR KUDRYASHOV	{"phone": "+70032531400"}
0005433755755	503A86	0966 776277	IRINA IVANOVA	{"phone": "+70929038846"}
0005433755756	1B5927	8263 022743	RAISA KOROLEVA	{"email": "koroleva_raisa_14111970@postgrespro.ru", "phone": "+70350010376"}
0005433755757	3FA388	6595 541994	IVAN KULIKOV	{"phone": "+70383853440"}
0005433755758	29F443	5687 569491	VLADIMIR VOROBEV	{"email": "vorobevv18041973@postgrespro.ru", "phone": "+70094848563"}
0005433755759	7C43BD	6237 380116	EVGENIY ZHUKOV	{"email": "evgeniyzhukov.02121972@postgrespro.ru", "phone": "+70412014644"}
0005433755760	440055	6357 847492	MARIYA BORISOVA	{"email": "borisova.mariya17061961@postgrespro.ru", "phone": "+70165126302"}
0005433755761	253F86	8488 090679	GALINA EFIMOVA	{"phone": "+70075578141"}
0005433755762	51DD1F	3551 877686	TATYANA LEBEDEVA	{"phone": "+70399587756"}
0005433755763	95B2F1	6020 212358	SVETLANA MAKAROVA	{"phone": "+70322851945"}
0005433755764	BAFA53	3869 199808	VERA EGOROVA	{"phone": "+70353735698"}
0005433755765	BAFA53	2560 205669	ALEKSANDR MAKSIMOV	{"phone": "+70853424703"}
0005433755766	F5633E	2522 751464	OLGA IVANOVA	{"email": "olgaivanova-051969@postgrespro.ru", "phone": "+70141888844"}
0005433755767	D972D7	0054 368548	OLGA MIKHAYLOVA	{"phone": "+70733682199"}
0005433755768	D972D7	6932 136552	ANDREY YAKOVLEV	{"phone": "+70873635451"}
0005433755769	A153F5	6375 429715	ELENA NIKIFOROVA	{"email": "nikiforova_e1980@postgrespro.ru", "phone": "+70817364889"}
0005433755770	93998C	1277 031798	ELENA PETROVA	{"email": "petrova.elena-1981@postgrespro.ru", "phone": "+70372315744"}
0005433755771	3456B6	5553 004801	NATALYA NIKOLAEVA	{"email": "nikolaeva-n_14031968@postgrespro.ru", "phone": "+70366213086"}
0005433755772	3456B6	7481 921240	NIKOLAY SIDOROV	{"phone": "+70790552887"}
0005433755773	19BCB4	6258 368113	ALEKSEY VOLKOV	{"email": "aleksey_volkov_081978@postgrespro.ru", "phone": "+70030760012"}
0005433755774	19BCB4	6391 509051	NINA RYABOVA	{"phone": "+70620854693"}
0005433755775	53E21B	6975 901127	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev.1964@postgrespro.ru", "phone": "+70904425037"}
0005433755776	3D0C3B	8748 062544	MARIYA MIRONOVA	{"email": "mironova.m-15121972@postgrespro.ru", "phone": "+70781379607"}
0005433755777	B962FC	0676 419673	TAMARA NOVIKOVA	{"phone": "+70721842217"}
0005433755778	B962FC	1581 228461	VALERIY DAVYDOV	{"email": "v_davydov.081976@postgrespro.ru", "phone": "+70098555465"}
0005433755779	B962FC	3238 449721	ALEKSANDR NIKITIN	{"email": "a_nikitin-30091976@postgrespro.ru", "phone": "+70265684665"}
0005433755780	E79665	6834 425499	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov-20111966@postgrespro.ru", "phone": "+70268456989"}
0005433755781	E0B536	8045 582585	IVAN VOROBEV	{"phone": "+70256942932"}
0005433755782	F5D5B1	3667 131091	PAVEL POPOV	{"phone": "+70235320005"}
0005433755783	A6FD61	4701 117764	ELENA EGOROVA	{"email": "egorovae061971@postgrespro.ru", "phone": "+70202920131"}
0005433755784	A6FD61	8483 504755	ALEKSEY ZAYCEV	{"email": "alekseyzaycev.27061968@postgrespro.ru", "phone": "+70821365581"}
0005433755785	E69CD5	4862 567272	LYUBOV LAZAREVA	{"email": "lazareva.l_1974@postgrespro.ru", "phone": "+70095751334"}
0005433755786	E69CD5	9946 592010	MARIYA SCHERBAKOVA	{"email": "mariya.scherbakova21121970@postgrespro.ru", "phone": "+70643369923"}
0005433755787	33B55A	3981 714761	MIKHAIL PAVLOV	{"email": "pavlovm-1978@postgrespro.ru", "phone": "+70463039525"}
0005433755788	33B55A	5348 865753	VIKTOR SAVELEV	{"email": "savelev_v.06031982@postgrespro.ru", "phone": "+70871672748"}
0005433755789	0EE8CE	7301 303979	ELENA TITOVA	{"email": "titova.elena-06121971@postgrespro.ru", "phone": "+70493225490"}
0005433755790	76BF2E	2162 650140	EKATERINA DANILOVA	{"email": "ekaterinadanilova_041975@postgrespro.ru", "phone": "+70912526607"}
0005433755791	73B1BE	6024 220418	ELENA POPOVA	{"phone": "+70718849550"}
0005433755792	56039C	8427 160411	MARINA SAVELEVA	{"phone": "+70933876318"}
0005433755793	56039C	0818 125940	ALEKSANDR MIRONOV	{"phone": "+70485554192"}
0005433755794	6880C5	3367 232321	SERGEY BONDARENKO	{"email": "bondarenko-s-16091979@postgrespro.ru", "phone": "+70474379030"}
0005433755795	6880C5	5821 317302	DMITRIY STEPANOV	{"email": "dstepanov021969@postgrespro.ru", "phone": "+70955796075"}
0005433755796	19F918	1750 654386	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr1979@postgrespro.ru", "phone": "+70052506442"}
0005433755797	19F918	9297 181810	VIKTOR FEDOROV	{"phone": "+70121018633"}
0005433755798	0C98FB	7197 506454	VALENTINA RODIONOVA	{"email": "v.rodionova-04091966@postgrespro.ru", "phone": "+70885205265"}
0005433755799	0C98FB	2267 265074	DMITRIY SERGEEV	{"email": "dmitriy.sergeev021970@postgrespro.ru", "phone": "+70724879943"}
0005433755800	33A345	8489 775802	ROMAN TIKHONOV	{"email": "rtikhonov101981@postgrespro.ru", "phone": "+70349060097"}
0005433755801	833DFE	4248 868150	NINA GRISHINA	{"email": "nina-grishina-1972@postgrespro.ru", "phone": "+70866979536"}
0005433755802	833DFE	4086 972546	VITALIY SOROKIN	{"phone": "+70125662259"}
0005433755803	A87F66	7548 609215	LYUDMILA MEDVEDEVA	{"phone": "+70449319170"}
0005433755804	CC1445	2254 965004	ALEKSANDR VASILEV	{"email": "aleksandrvasilev-13021984@postgrespro.ru", "phone": "+70632960721"}
0005433755805	CC1445	8135 239224	SERGEY YAKOVLEV	{"email": "yakovlev-s-1974@postgrespro.ru", "phone": "+70226360863"}
0005433755806	CC1445	1835 290958	KSENIYA DANILOVA	{"email": "kdanilova121977@postgrespro.ru", "phone": "+70594029216"}
0005433755807	E43C15	4994 635447	VALENTIN DAVYDOV	{"email": "v.davydov_021966@postgrespro.ru", "phone": "+70787959486"}
0005433755808	0D6962	3312 332826	MURAT OSIPOV	{"email": "osipov_murat111968@postgrespro.ru", "phone": "+70119509183"}
0005433755809	3FEB55	3604 637370	VADIM VOLKOV	{"phone": "+70546277301"}
0005433755810	E1AC88	6725 666243	ANNA STEPANOVA	{"email": "stepanova.a14021969@postgrespro.ru", "phone": "+70263617862"}
0005433755811	E1AC88	1430 288292	IVAN GERASIMOV	{"email": "gerasimov-ivan25021969@postgrespro.ru", "phone": "+70541879011"}
0005433755812	342204	4267 871360	NAIL SCHERBAKOV	{"email": "scherbakov_nail.1971@postgrespro.ru", "phone": "+70193020940"}
0005433755813	E8739A	8233 504035	NIKITA ALEKSEEV	{"phone": "+70183493169"}
0005433755814	DB7D5C	4763 039838	LILIYA MAKSIMOVA	{"email": "maksimova-l.17021975@postgrespro.ru", "phone": "+70976567587"}
0005433755815	45AF02	8010 657372	TAMARA SEMENOVA	{"email": "semenova-tamara.14011971@postgrespro.ru", "phone": "+70652850518"}
0005433755816	45AF02	5959 712464	VIKTOR KUZNECOV	{"email": "viktor.kuznecov-29111978@postgrespro.ru", "phone": "+70234786352"}
0005433755817	616D72	9654 558005	MIKHAIL SMIRNOV	{"email": "mikhail.smirnov041982@postgrespro.ru", "phone": "+70751035109"}
0005433755818	A5DEE5	3377 403461	VLADIMIR MAKAROV	{"email": "vladimir_makarov.091974@postgrespro.ru", "phone": "+70809886396"}
0005433755819	A5DEE5	5892 114822	FEDOR KUZMIN	{"phone": "+70505358424"}
0005433755820	01571A	8113 385348	ANNA EGOROVA	{"phone": "+70043188147"}
0005433755821	A3460D	2810 043680	ALEKSEY BARANOV	{"phone": "+70611341904"}
0005433755822	0AC1D2	7722 935647	NIKOLAY VOROBEV	{"email": "vorobev.n.051961@postgrespro.ru", "phone": "+70341819600"}
0005433755823	F15214	4685 708041	KAROLINA KARPOVA	{"phone": "+70135133663"}
0005433755824	649BE4	5194 517647	OLGA KOROLEVA	{"email": "okoroleva011969@postgrespro.ru", "phone": "+70867577453"}
0005433755825	649BE4	7694 876617	TAMARA POPOVA	{"phone": "+70464662573"}
0005433755826	2CE944	0339 550390	YURIY VOLKOV	{"email": "volkovy.121978@postgrespro.ru", "phone": "+70190164730"}
0005433755827	2CE944	3333 976390	NIKOLAY GERASIMOV	{"email": "nikolay-gerasimov1976@postgrespro.ru", "phone": "+70595602032"}
0005433755828	7E9633	5087 078004	VALENTINA MIRONOVA	{"email": "v-mironova29091971@postgrespro.ru", "phone": "+70049492417"}
0005433755829	E469B2	2124 594026	IRINA SERGEEVA	{"phone": "+70262472035"}
0005433755830	E469B2	8735 405226	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev081968@postgrespro.ru", "phone": "+70913175569"}
0005433755831	AACDF2	7384 889814	VERA BELYAEVA	{"phone": "+70233643133"}
0005433755832	703A33	8663 626686	ANGELINA VASILEVA	{"email": "vasileva-a.1973@postgrespro.ru", "phone": "+70509599504"}
0005433755833	46D7BB	2020 973655	YURIY POPOV	{"email": "yuriy_popov28051976@postgrespro.ru", "phone": "+70886994979"}
0005433755834	46D7BB	4444 650595	GRIGORIY CHERNOV	{"email": "chernov-g.30101964@postgrespro.ru", "phone": "+70785847023"}
0005433755835	016695	9507 465766	IRINA SCHERBAKOVA	{"phone": "+70265644584"}
0005433755836	6BFF9F	6337 855032	SVETLANA DANILOVA	{"email": "danilova-s_1974@postgrespro.ru", "phone": "+70946438489"}
0005433755837	0EBD7C	2631 869281	LARISA OSIPOVA	{"phone": "+70502670059"}
0005433755838	0EBD7C	6308 300007	YURIY NIKITIN	{"phone": "+70043530396"}
0005433755839	0EBD7C	1691 032289	NADEZHDA SOKOLOVA	{"phone": "+70747454339"}
0005433755840	10BAF5	3024 663261	VLADIMIR KOZLOV	{"phone": "+70537126137"}
0005433755841	44B01F	7472 822079	LILIYA MAKAROVA	{"email": "l_makarova.011974@postgrespro.ru", "phone": "+70571884901"}
0005433755842	44B01F	5851 517404	MAKSIM SCHERBAKOV	{"phone": "+70858461721"}
0005433755843	73247F	9729 822534	IRINA KUZMINA	{"phone": "+70544434539"}
0005433755844	A36129	1438 989017	DMITRIY AFANASEV	{"phone": "+70658485758"}
0005433755845	6A4FA9	2646 346862	VIKTOR ANTONOV	{"phone": "+70763675206"}
0005433755846	39F739	5714 403512	GALINA SMIRNOVA	{"phone": "+70836164345"}
0005433755847	8F85C6	7979 634479	EVGENIYA NIKOLAEVA	{"phone": "+70943305095"}
0005433755848	8F85C6	4280 164503	ALESYA SIDOROVA	{"email": "sidorova-alesya.111978@postgrespro.ru", "phone": "+70449053267"}
0005433755849	2B0DE1	1034 768364	ANDREY POPOV	{"email": "a-popov_1985@postgrespro.ru", "phone": "+70956756628"}
0005433755850	2B0DE1	1543 702027	ALEKSEY GAVRILOV	{"phone": "+70271320149"}
0005433755851	2B0DE1	1515 573226	DENIS SERGEEV	{"email": "sergeev_denis_1976@postgrespro.ru", "phone": "+70650597362"}
0005433755852	CE79ED	7851 110980	ELENA TARASOVA	{"phone": "+70971640710"}
0005433755853	CE79ED	5209 355803	NATALYA ZHUKOVA	{"phone": "+70785253606"}
0005433755854	18AAE1	7816 542370	DMITRIY FILIPPOV	{"phone": "+70433872797"}
0005433755855	30995D	3078 826249	VLADIMIR SHEVCHENKO	{"phone": "+70047532409"}
0005433755856	30995D	6563 057029	TATYANA KOVALEVA	{"email": "kovaleva.t_1983@postgrespro.ru", "phone": "+70537213554"}
0005433755857	30995D	9581 939924	VALERIY FOMIN	{"phone": "+70798959205"}
0005433755858	D27056	8110 207687	ANDREY MAKAROV	{"email": "a_makarov.061956@postgrespro.ru", "phone": "+70078472958"}
0005433755859	D27056	8142 887903	LIDIYA POTAPOVA	{"email": "potapova_lidiya121975@postgrespro.ru", "phone": "+70329403720"}
0005433755860	D27056	1869 473857	VALENTINA IVANOVA	{"email": "v.ivanova-09041975@postgrespro.ru", "phone": "+70095569080"}
0005433755861	811193	8188 941177	DARYA NIKOLAEVA	{"email": "nikolaeva-darya17081976@postgrespro.ru", "phone": "+70255546451"}
0005433755862	3D8482	2502 828973	NATALYA VOLKOVA	{"phone": "+70739647837"}
0005433755863	9B09FC	7132 248260	NATALYA DMITRIEVA	{"phone": "+70421868961"}
0005433755864	8F2E0C	2850 387246	NURIYA ZAKHAROVA	{"email": "nuriyazakharova.1990@postgrespro.ru", "phone": "+70959208238"}
0005433755865	8F2E0C	0644 783714	IRINA RODIONOVA	{"email": "irodionova14061972@postgrespro.ru", "phone": "+70310874983"}
0005433755866	8F2E0C	4181 429923	NIKOLAY TIMOFEEV	{"phone": "+70719576871"}
0005433755867	499C3A	1028 113917	IRINA KRASNOVA	{"phone": "+70868351871"}
0005433755868	FCFBC3	1250 199618	ALEKSEY YAKOVLEV	{"email": "yakovlev_aleksey30051967@postgrespro.ru", "phone": "+70434685443"}
0005433755869	FCFBC3	9406 446204	OLGA MIKHAYLOVA	{"phone": "+70055337098"}
0005433763097	EFBB09	8977 449749	ANDREY ANDREEV	{"phone": "+70337094099"}
0005433755870	FD866D	6056 133881	EKATERINA GORBUNOVA	{"email": "ekaterinagorbunova.08021971@postgrespro.ru", "phone": "+70196701160"}
0005433755871	104DA3	2575 586935	RUSLAN NIKITIN	{"email": "nikitin.r-1984@postgrespro.ru", "phone": "+70450438587"}
0005433755872	104DA3	0146 743535	SERGEY PETROV	{"email": "sergey_petrov021966@postgrespro.ru", "phone": "+70364362564"}
0005433755873	BC8108	1531 790539	DMITRIY SERGEEV	{"phone": "+70888583988"}
0005433755874	A2A941	5530 516264	SERGEY MAKAROV	{"email": "sergey_makarov.011965@postgrespro.ru", "phone": "+70812903675"}
0005433755875	5A07C9	4919 790727	IRINA VOROBEVA	{"phone": "+70946590233"}
0005433755876	5A07C9	8951 564494	ELENA EFREMOVA	{"phone": "+70694772305"}
0005433755877	481E91	9996 324068	VYACHESLAV NOVIKOV	{"email": "vyacheslavnovikov-011983@postgrespro.ru", "phone": "+70698637827"}
0005433755878	481E91	4678 183806	ALEKSANDR MIKHAYLOV	{"phone": "+70174255750"}
0005433755879	481E91	7485 434792	NATALYA RYABOVA	{"phone": "+70573549294"}
0005433755880	F71668	0934 706516	GALINA MAKAROVA	{"email": "makarovagalina1958@postgrespro.ru", "phone": "+70800973418"}
0005433755881	F71668	8102 373821	ELENA CHERNOVA	{"email": "chernova-e.09061969@postgrespro.ru", "phone": "+70105622129"}
0005433755882	A68A5D	3931 681490	MIKHAIL MAKSIMOV	{"phone": "+70582615228"}
0005433755883	A68A5D	7259 598292	EKATERINA PAVLOVA	{"email": "e-pavlova28061977@postgrespro.ru", "phone": "+70025159066"}
0005433755884	1E7C58	9114 861909	IGOR NAZAROV	{"phone": "+70560305736"}
0005433755885	1BB101	1168 951545	KRISTINA KONDRATEVA	{"email": "k-kondrateva_05051983@postgrespro.ru", "phone": "+70547799779"}
0005433755886	3AF003	7067 703713	LADA LUKYANOVA	{"phone": "+70674596070"}
0005433755887	42E210	1698 465016	SERGEY FEDOROV	{"phone": "+70688452560"}
0005433755888	4B64C6	6670 324330	DMITRIY SMIRNOV	{"phone": "+70916021591"}
0005433762942	764D25	2789 591636	VIKTOR MIRONOV	{"email": "mironov.viktor091971@postgrespro.ru", "phone": "+70338321662"}
0005433762943	6206B2	3479 075222	SERGEY TIMOFEEV	{"phone": "+70950736465"}
0005433762944	6206B2	2109 521309	ILYA MOROZOV	{"email": "morozov.i_101979@postgrespro.ru", "phone": "+70156970086"}
0005433762945	A7C1AC	5870 926696	LILIYA FEDOROVA	{"email": "liliyafedorova28101971@postgrespro.ru", "phone": "+70851525612"}
0005433762946	A7C1AC	8920 925291	EKATERINA KISELEVA	{"email": "kiseleva.ekaterina-1978@postgrespro.ru", "phone": "+70887166892"}
0005433762947	E56B81	9619 128749	ANATOLIY PAVLOV	{"email": "anatoliy.pavlov.1963@postgrespro.ru", "phone": "+70542514508"}
0005433762948	EA7F0A	2641 547381	VERA DENISOVA	{"phone": "+70651826015"}
0005433762949	A7F9BD	0877 911232	NATALYA ROMANOVA	{"email": "romanova-n.091963@postgrespro.ru", "phone": "+70107091033"}
0005433762950	BF3FD8	0210 164022	ARTEM ANDREEV	{"phone": "+70615264971"}
0005433762951	2B20DE	7775 384539	IGOR NAZAROV	{"email": "nazarov-i_021982@postgrespro.ru", "phone": "+70969731911"}
0005433762952	9E385A	0356 181315	OLESYA TIKHONOVA	{"email": "tikhonovao.1972@postgrespro.ru", "phone": "+70602804877"}
0005433762953	810B2F	2720 619774	TATYANA ORLOVA	{"phone": "+70849288714"}
0005433762954	5E83B4	5354 468132	VIKTOR STEPANOV	{"phone": "+70192522525"}
0005433762955	5E83B4	0538 214051	ALEKSANDR KONOVALOV	{"phone": "+70167450025"}
0005433762956	FBD168	3336 086700	ANATOLIY OSIPOV	{"phone": "+70812479920"}
0005433762957	ABA90C	9032 131438	MIKHAIL STEPANOV	{"phone": "+70596441013"}
0005433762958	D2C4A6	8057 496573	ELENA ARKHIPOVA	{"phone": "+70440732027"}
0005433762959	D2C4A6	1660 470383	SERGEY POPOV	{"email": "sergey-popov_051973@postgrespro.ru", "phone": "+70136648960"}
0005433762960	9CADA1	9501 681768	VLADIMIR SOROKIN	{"email": "sorokin_v12121984@postgrespro.ru", "phone": "+70608547358"}
0005433762961	9CADA1	0769 425637	VIKTOR SOLOVEV	{"phone": "+70302614744"}
0005433762962	203F82	4179 014152	ANNA NIKOLAEVA	{"phone": "+70150259069"}
0005433762963	203F82	6076 024243	VALERIY SEMENOV	{"phone": "+70512587138"}
0005433762964	203F82	1018 093764	MARINA GORBUNOVA	{"email": "marina_gorbunova.1972@postgrespro.ru", "phone": "+70443313744"}
0005433762965	B23DED	6066 976715	DANIL ALEKSEEV	{"email": "alekseev_d-1978@postgrespro.ru", "phone": "+70304726165"}
0005433762966	B23DED	5730 330760	VLADIMIR VOROBEV	{"email": "vladimir_vorobev-16101969@postgrespro.ru", "phone": "+70222377774"}
0005433762967	668C86	7469 144318	ARSENIY GUSEV	{"phone": "+70533493357"}
0005433762968	6BF2CD	4050 133495	ALEKSEY SOROKIN	{"phone": "+70331290523"}
0005433762969	A92B38	2347 282720	ANTONINA ROMANOVA	{"email": "a_romanova26111970@postgrespro.ru", "phone": "+70493222328"}
0005433762970	A92B38	9990 226518	SVETLANA OSIPOVA	{"email": "osipova_s.1968@postgrespro.ru", "phone": "+70403196497"}
0005433762971	FD6D44	0976 982818	OKSANA VOLKOVA	{"email": "oksana_volkova-05061969@postgrespro.ru", "phone": "+70747381201"}
0005433762972	FD6D44	2770 386554	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy-25101965@postgrespro.ru", "phone": "+70389395600"}
0005433762973	BF1E23	5437 228324	NINA SEMENOVA	{"email": "semenova.nina_02081962@postgrespro.ru", "phone": "+70132205296"}
0005433762974	BF1E23	1939 539789	NINA SCHERBAKOVA	{"email": "scherbakova-nina1963@postgrespro.ru", "phone": "+70268548756"}
0005433762975	CF9F56	1955 233401	PAVEL IVANOV	{"email": "ivanov.pavel_121982@postgrespro.ru", "phone": "+70684172725"}
0005433762976	DB26E7	2616 247929	SERGEY OSIPOV	{"email": "osipov_s101987@postgrespro.ru", "phone": "+70050785877"}
0005433762977	8A5385	2703 366273	IRINA PAVLOVA	{"email": "pavlova.irina-011973@postgrespro.ru", "phone": "+70173675123"}
0005433762978	237D6B	7653 754626	TAMARA ROMANOVA	{"phone": "+70493277510"}
0005433762979	49F146	4592 072373	OLGA MAKAROVA	{"phone": "+70876465840"}
0005433762980	A3CBEE	3745 691700	ANDREY NIKITIN	{"phone": "+70294987166"}
0005433762981	A3CBEE	7674 182070	DMITRIY DENISOV	{"email": "denisov-dmitriy-1977@postgrespro.ru", "phone": "+70411003091"}
0005433762982	428A13	8585 702829	GRIGORIY KAZAKOV	{"phone": "+70323744182"}
0005433762983	F54F6D	9317 439168	NADEZHDA EGOROVA	{"email": "nadezhdaegorova_1980@postgrespro.ru", "phone": "+70678641728"}
0005433762984	07CABC	5672 506358	EVGENIYA DAVYDOVA	{"phone": "+70149073301"}
0005433762985	D688AA	9115 394076	ZINAIDA SOLOVEVA	{"email": "zinaida.soloveva_27101975@postgrespro.ru", "phone": "+70529938910"}
0005433762986	2A93FF	3430 664780	ANNA TIMOFEEVA	{"phone": "+70178858175"}
0005433762987	98CC15	5868 421308	ELENA GORBUNOVA	{"phone": "+70189860430"}
0005433762988	2803B8	8165 402724	VIKTOR KUZMIN	{"email": "kuzmin_viktor.081976@postgrespro.ru", "phone": "+70352186405"}
0005433762989	6125AA	4925 735470	ALEKSANDRA EFREMOVA	{"email": "a-efremova.13051973@postgrespro.ru", "phone": "+70568034565"}
0005433762990	6125AA	8097 171253	EGOR MIKHAYLOV	{"email": "emikhaylov.101977@postgrespro.ru", "phone": "+70354694235"}
0005433762991	02AF07	2870 098629	MAKSIM CHERNOV	{"email": "chernovm_101969@postgrespro.ru", "phone": "+70609144530"}
0005433762992	DF0B72	1022 356901	RAISA POPOVA	{"email": "popova_raisa021986@postgrespro.ru", "phone": "+70480049320"}
0005433762993	DF0B72	6793 654897	MARINA ZAYCEVA	{"phone": "+70006207184"}
0005433762994	841C92	7032 213579	ANTONINA FILATOVA	{"email": "filatova_a.1977@postgrespro.ru", "phone": "+70198186553"}
0005433762995	5FBC9C	8785 258354	YURIY SAVELEV	{"email": "savelev_y.1982@postgrespro.ru", "phone": "+70600995189"}
0005433762996	5FBC9C	6393 680795	NADEZHDA NOVIKOVA	{"email": "novikova_n-08091965@postgrespro.ru", "phone": "+70941264839"}
0005433762997	DEA356	3213 289085	VARVARA DANILOVA	{"phone": "+70416617462"}
0005433762998	E6B955	6947 877736	RIFAT ABRAMOV	{"email": "abramovrifat12011968@postgrespro.ru", "phone": "+70253175715"}
0005433762999	E6B955	4729 383017	EKATERINA KAZAKOVA	{"phone": "+70166964736"}
0005433763000	33811A	4622 058787	DENIS BELOV	{"email": "belov_denis_1967@postgrespro.ru", "phone": "+70799092816"}
0005433763001	33811A	3617 947191	VALERIY PETROV	{"phone": "+70537994633"}
0005433763002	5C521D	8201 064487	RAMIL SERGEEV	{"email": "sergeev-r-071975@postgrespro.ru", "phone": "+70607881689"}
0005433763003	9E3339	8828 209872	TATYANA ANTONOVA	{"email": "antonova_t-1968@postgrespro.ru", "phone": "+70335452475"}
0005433763004	84B9D0	8227 176745	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev_1982@postgrespro.ru", "phone": "+70356093590"}
0005433763005	84B9D0	9476 126474	SERGEY OSIPOV	{"email": "sergey-osipov_20041971@postgrespro.ru", "phone": "+70241889105"}
0005433763006	F8859A	1047 295516	ANASTASIYA ANTONOVA	{"email": "a-antonova.06031975@postgrespro.ru", "phone": "+70477521502"}
0005433763007	F8859A	7494 929966	MARIYA NOVIKOVA	{"email": "mariya_novikova.101983@postgrespro.ru", "phone": "+70535256921"}
0005433763008	D96BD9	2163 577321	ANDREY KUZNECOV	{"phone": "+70646973823"}
0005433763009	D96BD9	4287 284062	IRINA YUDINA	{"email": "i_yudina-30121970@postgrespro.ru", "phone": "+70948314872"}
0005433763010	6C5C68	8173 042629	LEONID MIRONOV	{"email": "mironov-l061977@postgrespro.ru", "phone": "+70141851483"}
0005433763011	50A736	3568 159038	ANATOLIY ZAYCEV	{"phone": "+70733482044"}
0005433763012	87B6A4	3712 838340	SVETLANA KOMAROVA	{"email": "s.komarova.111965@postgrespro.ru", "phone": "+70191880511"}
0005433763013	87B6A4	1201 667509	ALEKSEY GAVRILOV	{"phone": "+70986651919"}
0005433763014	3BF40F	7675 499591	SARIYA SIDOROVA	{"email": "sidorova_sariya091970@postgrespro.ru", "phone": "+70057688353"}
0005433763015	58D8E1	7451 261059	ANATOLIY NAZAROV	{"phone": "+70546346913"}
0005433763016	C97CBD	6374 057021	VLADIMIR MAKAROV	{"email": "makarov_vladimir_04111979@postgrespro.ru", "phone": "+70555327482"}
0005433763017	170834	7622 075057	NIKOLAY VASILEV	{"email": "vasilev.n1972@postgrespro.ru", "phone": "+70987648635"}
0005433763018	CE0E84	5672 224194	OLGA IVANOVA	{"email": "ivanova_olga_30071975@postgrespro.ru", "phone": "+70944880646"}
0005433763019	CE0E84	6409 168889	IGOR PAVLOV	{"phone": "+70584618459"}
0005433763020	FFBA46	7618 844642	ALEKSANDR ANDREEV	{"phone": "+70820397058"}
0005433763021	83E7CC	9624 167309	PAVEL KOROLEV	{"email": "korolev.pavel1984@postgrespro.ru", "phone": "+70495200760"}
0005433763022	9E87F6	0929 954370	VIKTOR KUZNECOV	{"phone": "+70359750326"}
0005433763023	88DB9C	4048 090372	OLGA PETROVA	{"email": "petrova_olga_111975@postgrespro.ru", "phone": "+70579851986"}
0005433763024	0816D4	7681 010520	ANATOLIY ANTONOV	{"email": "antonovanatoliy25101967@postgrespro.ru", "phone": "+70033253314"}
0005433763025	DF0FF5	3963 361148	VYACHESLAV KOZLOV	{"phone": "+70888800904"}
0005433763026	DF0FF5	7325 263935	MARIYA TIKHONOVA	{"email": "mariya-tikhonova-041974@postgrespro.ru", "phone": "+70496202532"}
0005433763027	2759D3	0532 504694	YURIY KAZAKOV	{"phone": "+70563826521"}
0005433763028	2759D3	7574 014894	VITALIY NIKOLAEV	{"email": "nikolaev.vitaliy12051996@postgrespro.ru", "phone": "+70932913709"}
0005433763029	8C26FD	6606 039504	DARYA NESTEROVA	{"phone": "+70688641579"}
0005433763030	3C635D	1648 077002	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey1961@postgrespro.ru", "phone": "+70323046207"}
0005433763031	495947	6546 389828	EVGENIY KUZNECOV	{"phone": "+70942996750"}
0005433763032	495947	2026 780498	EKATERINA POTAPOVA	{"phone": "+70845397383"}
0005433763033	43189D	0178 070066	VYACHESLAV FOMIN	{"email": "v_fomin.19081976@postgrespro.ru", "phone": "+70817543115"}
0005433763034	00138A	4795 398010	LIDIYA FEDOROVA	{"email": "fedorova.lidiya.22091976@postgrespro.ru", "phone": "+70854276511"}
0005433763035	00138A	5846 970791	NATALYA CHERNOVA	{"phone": "+70139025616"}
0005433763036	C75D11	2374 577190	MAKSIM MARTYNOV	{"phone": "+70216029219"}
0005433763037	C75D11	9784 755064	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr_021981@postgrespro.ru", "phone": "+70507420974"}
0005433763038	A27BC7	5341 288514	OLEG MATVEEV	{"email": "oleg-matveev-18021969@postgrespro.ru", "phone": "+70270294561"}
0005433763039	E34A3B	1267 340661	LEONID TARASOV	{"email": "ltarasov.1970@postgrespro.ru", "phone": "+70365960811"}
0005433763040	E34A3B	4416 358191	SEMEN ANTONOV	{"email": "antonov_s_1978@postgrespro.ru", "phone": "+70823332140"}
0005433763041	DF749A	4530 470542	VYACHESLAV MAKAROV	{"email": "v.makarov.23121969@postgrespro.ru", "phone": "+70346583843"}
0005433763042	DF749A	6605 123787	NADEZHDA GERASIMOVA	{"phone": "+70508770509"}
0005433763043	9A1E63	1135 695021	SVETLANA NIKOLAEVA	{"email": "nikolaeva_s29111963@postgrespro.ru", "phone": "+70836678340"}
0005433763044	249597	2926 252348	ANZHELA PAVLOVA	{"email": "pavlova.a.26041975@postgrespro.ru", "phone": "+70952064144"}
0005433763045	249597	3384 456837	ALEKSANDR STEPANOV	{"email": "aleksandrstepanov.011981@postgrespro.ru", "phone": "+70440345938"}
0005433763046	0E26AA	6119 806121	ALEKSEY OSIPOV	{"email": "aleksey_osipov28061976@postgrespro.ru", "phone": "+70516381407"}
0005433763047	6BAFEE	2119 496165	NIKOLAY MATVEEV	{"email": "matveev-n-011972@postgrespro.ru", "phone": "+70150946686"}
0005433763048	A8240D	1386 806630	ALEKSANDR SOROKIN	{"email": "a_sorokin_1967@postgrespro.ru", "phone": "+70194823103"}
0005433763049	A8240D	1415 000089	SVETLANA MIKHAYLOVA	{"email": "mikhaylova-svetlana05121966@postgrespro.ru", "phone": "+70449253835"}
0005433763050	053B46	0204 463052	DENIS IVANOV	{"email": "ivanov-d-15011974@postgrespro.ru", "phone": "+70335426986"}
0005433763051	053B46	3600 861352	ALEKSANDR KAZAKOV	{"phone": "+70910546707"}
0005433763052	651B71	6061 588374	NIKOLAY NIKOLAEV	{"email": "n-nikolaev.1982@postgrespro.ru", "phone": "+70054256754"}
0005433763053	560AE3	9395 400951	NATALYA ERMAKOVA	{"email": "ermakova_natalya_1971@postgrespro.ru", "phone": "+70400775454"}
0005433763054	5B24D1	5958 269438	MARINA EFREMOVA	{"email": "m_efremova_1990@postgrespro.ru", "phone": "+70589405334"}
0005433763055	5B24D1	8476 399639	IRINA ILINA	{"phone": "+70405946087"}
0005433763056	CD6092	2612 625082	MATVEY KUZNECOV	{"phone": "+70612275774"}
0005433763057	CD6092	6487 100239	VALENTINA MOROZOVA	{"phone": "+70578956863"}
0005433763058	0619A9	2402 666178	ALINA ZAKHAROVA	{"phone": "+70779810515"}
0005433763059	0619A9	5111 681116	LYUBOV MEDVEDEVA	{"email": "medvedeva_lyubov_09021978@postgrespro.ru", "phone": "+70419720737"}
0005433763060	BD145A	5252 218245	NIKITA ORLOV	{"email": "n_orlov.1970@postgrespro.ru", "phone": "+70048945763"}
0005433763061	9E562B	6177 671066	NIKOLAY STEPANOV	{"email": "stepanov-nikolay-051976@postgrespro.ru", "phone": "+70150690294"}
0005433763062	9E562B	6945 026218	NATALYA SEMENOVA	{"email": "semenovan-03051971@postgrespro.ru", "phone": "+70508149046"}
0005433763063	5A2D56	3871 356036	ALEKSANDR VOLKOV	{"email": "a.volkov-25101980@postgrespro.ru", "phone": "+70605527429"}
0005433763064	3D52D4	7351 866974	EVGENIYA KUZMINA	{"email": "evgeniya_kuzmina.091973@postgrespro.ru", "phone": "+70838873004"}
0005433763065	6C3BF8	9023 229906	VALENTINA SAVELEVA	{"email": "saveleva-valentina23101979@postgrespro.ru", "phone": "+70843718403"}
0005433763066	E09B7E	9432 069104	ALEKSANDR SCHERBAKOV	{"phone": "+70338145245"}
0005433763067	7476F4	7361 268843	ALEKSANDR ILIN	{"email": "ilin_a051968@postgrespro.ru", "phone": "+70141235831"}
0005433763068	7476F4	6486 047807	YULIYA STEPANOVA	{"email": "stepanova_yuliya_041958@postgrespro.ru", "phone": "+70999997993"}
0005433763069	7476F4	1277 451778	ELENA PAVLOVA	{"email": "pavlova_e-25011977@postgrespro.ru", "phone": "+70566568945"}
0005433763070	D5B3D1	9132 725302	ANNA POPOVA	{"phone": "+70075091865"}
0005433763071	3CC6B8	0498 530889	NIKOLAY FILIPPOV	{"email": "nikolay-filippov.30031968@postgrespro.ru", "phone": "+70092489554"}
0005433763072	468829	4689 359515	SVETLANA DANILOVA	{"email": "danilova_svetlana-04051972@postgrespro.ru", "phone": "+70172721730"}
0005433763073	6018D1	9332 963777	EVGENIY MIRONOV	{"email": "e.mironov_1967@postgrespro.ru", "phone": "+70680813971"}
0005433763074	2E5774	1151 215199	RUSLAN VASILEV	{"phone": "+70742856968"}
0005433763075	83FEE5	2391 732016	OLGA BORISOVA	{"email": "borisova-o.28071979@postgrespro.ru", "phone": "+70082911595"}
0005433763076	AD11F7	8189 943965	LYUDMILA ROMANOVA	{"email": "romanoval-051963@postgrespro.ru", "phone": "+70412174443"}
0005433763077	6DAFE5	8513 180201	MARIYA MELNIKOVA	{"email": "melnikova-m.22031966@postgrespro.ru", "phone": "+70946816249"}
0005433763078	FCD3C0	6024 599200	ANASTASIYA VOROBEVA	{"phone": "+70788411465"}
0005433763079	2E94E1	4164 310752	YULIYA NIKOLAEVA	{"phone": "+70756201026"}
0005433763080	CFB6CC	4291 844302	VIKTOR VASILEV	{"email": "v_vasilev18091974@postgrespro.ru", "phone": "+70523453703"}
0005433763081	15679E	7401 612041	GALINA MARTYNOVA	{"phone": "+70570857491"}
0005433763082	598B97	8354 389152	TATYANA NIKITINA	{"email": "tatyananikitina-25031977@postgrespro.ru", "phone": "+70640702048"}
0005433763083	598B97	2752 717813	YURIY FEDOTOV	{"phone": "+70402995517"}
0005433763084	F07B8D	2663 548779	NIKITA POPOV	{"phone": "+70467586709"}
0005433763085	E33486	4995 310267	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov08051974@postgrespro.ru", "phone": "+70384517068"}
0005433763086	E33486	3637 479824	VITALIY KARPOV	{"email": "karpov.vitaliy-04041975@postgrespro.ru", "phone": "+70486893260"}
0005433763087	586F54	6763 186669	VLADIMIR PETROV	{"email": "petrov.vladimir.011966@postgrespro.ru", "phone": "+70250302760"}
0005433763088	567179	5707 921730	TATYANA NIKIFOROVA	{"phone": "+70435969139"}
0005433763089	567179	2508 684985	ALEKSEY IVANOV	{"email": "ivanova1960@postgrespro.ru", "phone": "+70656032559"}
0005433763090	1E0315	9385 210146	VALENTINA IVANOVA	{"email": "ivanovav.091984@postgrespro.ru", "phone": "+70172533787"}
0005433763091	1E0315	0063 361686	YANA KULIKOVA	{"email": "y-kulikova.1968@postgrespro.ru", "phone": "+70117519457"}
0005433763092	C701F6	2896 245088	EKATERINA NIKIFOROVA	{"email": "nikiforovaekaterina1979@postgrespro.ru", "phone": "+70306765217"}
0005433763093	34DB6C	0828 081161	VALERIY VOLKOV	{"phone": "+70643799928"}
0005433763094	E09D3C	7852 490163	DARYA MEDVEDEVA	{"email": "daryamedvedeva1978@postgrespro.ru", "phone": "+70455702310"}
0005433763095	CAF21E	1188 020939	RAISA TARASOVA	{"email": "tarasova_r_10101972@postgrespro.ru", "phone": "+70121678614"}
0005433763096	EFBB09	6316 996133	VLADIMIR SCHERBAKOV	{"email": "scherbakovv.011984@postgrespro.ru", "phone": "+70212235470"}
0005433763098	5B7EF5	0176 070706	LYUBOV LEBEDEVA	{"phone": "+70149482097"}
0005433763099	EFD75F	7356 148552	ALEKSEY GUSEV	{"email": "gusevaleksey.081979@postgrespro.ru", "phone": "+70652190704"}
0005433763100	90F8DA	4348 811732	FANIS SHEVCHENKO	{"email": "shevchenko.f-03031979@postgrespro.ru", "phone": "+70414487666"}
0005433763101	23D4BB	6739 319176	ANASTASIYA FILIPPOVA	{"email": "a.filippova_091961@postgrespro.ru", "phone": "+70580720364"}
0005433763102	23D4BB	4751 500864	PAVEL FEDOTOV	{"phone": "+70066948225"}
0005433763103	A12CFB	5576 790272	VENERA NIKOLAEVA	{"phone": "+70485180798"}
0005433763104	A12CFB	4366 131568	LYUDMILA ZAKHAROVA	{"phone": "+70117798278"}
0005433763105	8F0283	9177 416033	IVAN FROLOV	{"phone": "+70269166841"}
0005433763106	6A64CF	7996 025333	YURIY KOZLOV	{"email": "kozlov-y-011954@postgrespro.ru", "phone": "+70654133993"}
0005433763107	6A64CF	0998 519928	ELENA KUZNECOVA	{"phone": "+70756441022"}
0005433763108	AEABD2	8604 502796	IVAN KISELEV	{"email": "ivankiselev.031977@postgrespro.ru", "phone": "+70082203436"}
0005433763109	7152F9	0539 202114	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.041976@postgrespro.ru", "phone": "+70686364098"}
0005433763110	7152F9	6409 866842	GENNADIY VLASOV	{"phone": "+70840787628"}
0005433763111	AA4BE8	5868 374484	KIRILL ROMANOV	{"phone": "+70441991300"}
0005433763112	DB81B2	2484 180046	ANDREY KONOVALOV	{"phone": "+70513818823"}
0005433763113	A5EEE2	4863 647373	YAROSLAV OSIPOV	{"phone": "+70009150910"}
0005433763114	2FBA05	5463 316508	EVELINA SAVELEVA	{"email": "e-saveleva.04071976@postgrespro.ru", "phone": "+70724651404"}
0005433763115	3C44F9	4534 522204	ANATOLIY ABRAMOV	{"phone": "+70658453711"}
0005433763116	26A131	8181 734793	GALINA SEMENOVA	{"phone": "+70387655555"}
0005433763117	54514F	5844 121601	EGOR MARTYNOV	{"email": "e_martynov-031965@postgrespro.ru", "phone": "+70660191975"}
0005433763118	288098	5947 836685	MARINA RODIONOVA	{"phone": "+70661656024"}
0005433763119	288098	2401 848688	NIKITA IVANOV	{"email": "ivanov_n051976@postgrespro.ru", "phone": "+70034946178"}
0005433763120	BEE3DB	8310 337196	ANATOLIY NAZAROV	{"phone": "+70208120610"}
0005433763121	66B3CC	6696 772344	ELVIRA FEDOROVA	{"phone": "+70270179094"}
0005433763122	69CC3A	8375 872895	LEV FEDOTOV	{"phone": "+70366756417"}
0005433763123	69CC3A	2272 811256	IRAIDA NAUMOVA	{"email": "i_naumova.101971@postgrespro.ru", "phone": "+70811874074"}
0005433763124	2E0B8D	4067 497829	ALEKSANDR MARTYNOV	{"email": "aleksandr_martynov-1961@postgrespro.ru", "phone": "+70984133273"}
0005433763125	48FBA8	7232 425392	OLGA BELOVA	{"phone": "+70196857667"}
0005433763126	48FBA8	5372 570000	NATALYA ORLOVA	{"email": "n.orlova061976@postgrespro.ru", "phone": "+70840432857"}
0005433763127	DBCCF1	1625 687771	ALEKSANDR BORISOV	{"email": "borisov-aleksandr-28061965@postgrespro.ru", "phone": "+70633224455"}
0005433763128	2F5D23	5080 467068	VIKTOR MELNIKOV	{"phone": "+70923678894"}
0005433763129	2F5D23	3764 444071	NATALYA IVANOVA	{"phone": "+70535990869"}
0005433763130	B1E1AC	6562 923205	NIKITA SEMENOV	{"phone": "+70049027273"}
0005433763131	F46FDA	1891 944075	DMITRIY ZAKHAROV	{"email": "dmitriy.zakharov1971@postgrespro.ru", "phone": "+70435344811"}
0005433763132	D1C8A7	6274 449613	IGOR YAKOVLEV	{"phone": "+70671606419"}
0005433763133	3B3D41	6780 248525	OLGA OVCHINNIKOVA	{"phone": "+70428258255"}
0005433763134	9A197E	1802 784722	ANTONINA MELNIKOVA	{"email": "melnikovaa.121963@postgrespro.ru", "phone": "+70592368910"}
0005433763135	18A23C	1641 375403	IRINA MASLOVA	{"email": "irina.maslova-1972@postgrespro.ru", "phone": "+70242040629"}
0005433763136	F2269D	7332 821088	ROZA KUZNECOVA	{"email": "roza-kuznecova.111975@postgrespro.ru", "phone": "+70572337854"}
0005433763137	EEEC6C	8605 427404	ZINAIDA DAVYDOVA	{"phone": "+70363273051"}
0005433763138	14DFC1	8104 951178	SVETLANA FILIPPOVA	{"email": "filippova-svetlana.061966@postgrespro.ru", "phone": "+70602032775"}
0005433763139	B46EC4	2244 451404	EVGENIY IVANOV	{"email": "e.ivanov_1977@postgrespro.ru", "phone": "+70286580622"}
0005433763140	518478	1509 828028	ILYA KUZNECOV	{"email": "kuznecov.i_1981@postgrespro.ru", "phone": "+70018028135"}
0005433763141	8552D0	1669 089761	IVAN SOROKIN	{"phone": "+70867184941"}
0005433763142	4531F6	8147 846761	DMITRIY EGOROV	{"email": "dmitriyegorov.1980@postgrespro.ru", "phone": "+70045503043"}
0005433763143	60798C	0513 671359	ALEKSANDR FOMIN	{"email": "afomin031974@postgrespro.ru", "phone": "+70954718657"}
0005433763144	B7D67D	4627 680769	GALINA PETROVA	{"phone": "+70866574003"}
0005433763145	B7D67D	8622 511145	ALEKSANDRA SIDOROVA	{"phone": "+70992804528"}
0005433763146	607C17	1813 807955	LYUBOV SOLOVEVA	{"email": "soloveva_lyubov.011983@postgrespro.ru", "phone": "+70979810180"}
0005433763147	607C17	3035 300515	ANNA KALININA	{"phone": "+70746244330"}
0005433763148	E66C0D	3108 725036	OLGA LEBEDEVA	{"email": "o_lebedeva_06011978@postgrespro.ru", "phone": "+70585427476"}
0005433763149	E66C0D	4944 553291	TATYANA FEDOROVA	{"phone": "+70129956954"}
0005433763150	4FE382	7638 879808	OLGA SOKOLOVA	{"phone": "+70754124943"}
0005433763151	BE05DE	5708 405794	IRINA ZAKHAROVA	{"email": "zakharova-i021968@postgrespro.ru", "phone": "+70895574158"}
0005433763152	5A2D76	4446 923613	YULIYA MELNIKOVA	{"phone": "+70681406580"}
0005433763153	04DBD2	4106 123042	OKSANA TROFIMOVA	{"phone": "+70948101581"}
0005433763154	FFF474	1100 389007	LILIYA MAKSIMOVA	{"email": "maksimova-liliya02061970@postgrespro.ru", "phone": "+70945999949"}
0005433763155	3D1EA9	9530 359613	MARIANNA ZAKHAROVA	{"phone": "+70974104353"}
0005433763156	7308ED	7090 093865	LYUBOV GORBUNOVA	{"phone": "+70065713839"}
0005433763157	63DD8D	0893 424432	DARYA KRASNOVA	{"phone": "+70671788958"}
0005433763158	8ED86D	7368 392136	ALEKSEY ILIN	{"phone": "+70436745478"}
0005433763159	C6B753	2897 472003	OLGA KUZMINA	{"phone": "+70769117670"}
0005433763160	4D26F9	3785 721629	YURIY KUZNECOV	{"phone": "+70055644096"}
0005433763161	6B29D3	1460 497593	VALERIY SEMENOV	{"email": "semenovv-101961@postgrespro.ru", "phone": "+70144071538"}
0005433763162	B454DA	5345 995249	VLADIMIR CHERNOV	{"email": "v_chernov19081968@postgrespro.ru", "phone": "+70437280952"}
0005433763163	316D05	9732 215695	MARIYA OSIPOVA	{"email": "m_osipova_101975@postgrespro.ru", "phone": "+70477309815"}
0005433763164	5272EA	6889 313101	EKATERINA KUZNECOVA	{"email": "ekaterina.kuznecova.091972@postgrespro.ru", "phone": "+70779246130"}
0005433763165	E9EC1C	1228 950922	VLADIMIR FROLOV	{"email": "frolovv.111974@postgrespro.ru", "phone": "+70990815236"}
0005433763166	452D4A	2999 292918	NINA KOROLEVA	{"email": "nina_koroleva30051967@postgrespro.ru", "phone": "+70154661551"}
0005433763167	F737EA	0714 449221	ANATOLIY BONDARENKO	{"email": "anatoliy-bondarenko-011975@postgrespro.ru", "phone": "+70585121828"}
0005433763168	F737EA	1040 903408	ELENA FEDOROVA	{"phone": "+70600444026"}
0005433763169	0E9823	5797 220850	ALEKSANDR NAZAROV	{"email": "a-nazarov.121966@postgrespro.ru", "phone": "+70717389810"}
0005433763170	0E9823	8098 495619	ALEKSEY FROLOV	{"phone": "+70241344090"}
0005433763171	0E9823	1247 393662	LYUDMILA TROFIMOVA	{"phone": "+70408615437"}
0005433763172	901BE3	1377 348060	PETR ILIN	{"email": "ilin-petr_1982@postgrespro.ru", "phone": "+70708541855"}
0005433763173	F0831E	1197 506109	LYUDMILA KONDRATEVA	{"email": "kondrateva-lyudmila.081972@postgrespro.ru", "phone": "+70439959106"}
0005433763174	BDFE4C	8293 879763	OLGA IVANOVA	{"phone": "+70745364849"}
0005433763175	BDFE4C	0803 117955	LYUDMILA SIDOROVA	{"phone": "+70703022335"}
0005433763176	186ECD	5900 281050	YULIYA FOMINA	{"email": "yuliya-fomina-25101967@postgrespro.ru", "phone": "+70978031733"}
0005433763177	C1F001	2348 149234	VERA STEPANOVA	{"phone": "+70597353815"}
0005433763178	8D1FBF	5514 175020	ANATOLIY ILIN	{"phone": "+70112337794"}
0005433763179	AC5768	1250 365252	EKATERINA KRASNOVA	{"email": "e.krasnova.051960@postgrespro.ru", "phone": "+70488958463"}
0005433763180	215391	8523 826368	ANATOLIY FEDOROV	{"email": "fedorov.a.021968@postgrespro.ru", "phone": "+70269406964"}
0005433763181	F71A6B	0093 819927	GALINA POTAPOVA	{"phone": "+70691042671"}
0005433763182	7B58D0	7353 160189	NATALYA ALEKSANDROVA	{"phone": "+70339583993"}
0005433763183	0E9969	1930 192833	VIKTORIYA SCHERBAKOVA	{"phone": "+70633934112"}
0005433763184	0E9969	1074 879709	ANDREY KUDRYASHOV	{"phone": "+70872696970"}
0005433763185	526C8C	9192 469302	OLGA KUZNECOVA	{"email": "o.kuznecova.26061965@postgrespro.ru", "phone": "+70731686216"}
0005433763186	E16F94	7903 315907	RAISA TIKHONOVA	{"email": "tikhonova-raisa.1964@postgrespro.ru", "phone": "+70555079297"}
0005433763187	CA5482	1172 805030	RAISA MIKHAYLOVA	{"email": "r_mikhaylova.19111970@postgrespro.ru", "phone": "+70471174657"}
0005433763188	8606C0	2887 353243	DMITRIY IVANOV	{"email": "ivanov.d_1962@postgrespro.ru", "phone": "+70273960195"}
0005433763189	6DC37A	0938 826956	ELENA IVANOVA	{"email": "ivanovaelena-10081963@postgrespro.ru", "phone": "+70703520086"}
0005433763190	B33FCF	6750 429325	VENERA MEDVEDEVA	{"email": "medvedeva-v_051974@postgrespro.ru", "phone": "+70143132794"}
0005433763191	B33FCF	1183 907998	MARIYA KULIKOVA	{"email": "kulikovam1973@postgrespro.ru", "phone": "+70752935922"}
0005433763192	8DD2FC	3817 926726	GENNADIY KUZNECOV	{"phone": "+70268893175"}
0005433763193	29AE19	4005 630993	ALEKSEY PAVLOV	{"phone": "+70239546758"}
0005433763194	29AE19	9139 496011	NATALYA VLASOVA	{"phone": "+70237003689"}
0005433763195	0E6324	5346 490539	VALENTINA MIKHAYLOVA	{"email": "v_mikhaylova.1972@postgrespro.ru", "phone": "+70100251820"}
0005433763196	D2A22D	2424 065038	NINA PAVLOVA	{"phone": "+70611622798"}
0005433763197	D2A22D	2264 173754	MIKHAIL EGOROV	{"phone": "+70012643878"}
0005433763198	D2A22D	6926 057556	LEONTIY KUZMIN	{"email": "l.kuzmin03041970@postgrespro.ru", "phone": "+70542572925"}
0005433763199	BE9735	0039 296778	ELENA SIDOROVA	{"email": "elena-sidorova.16101976@postgrespro.ru", "phone": "+70506052473"}
0005433763200	BE9735	6159 189407	SERGEY KAZAKOV	{"phone": "+70494016791"}
0005433763201	BE9735	9194 318676	VLADIMIR PETROV	{"email": "petrov.vladimir1986@postgrespro.ru", "phone": "+70116997888"}
0005433763202	360925	3991 836883	NIKOLAY MOISEEV	{"phone": "+70037354023"}
0005433763203	000ADA	6346 427699	VALERIY ZAYCEV	{"email": "zaycevvaleriy-14031967@postgrespro.ru", "phone": "+70443167463"}
0005433763204	EF55E9	1554 440120	DMITRIY OSIPOV	{"phone": "+70794859909"}
0005433763205	77E2D0	6459 454342	DMITRIY KULIKOV	{"email": "d-kulikov.1975@postgrespro.ru", "phone": "+70463592910"}
0005433763206	44A8CF	7061 420482	SERGEY KOZLOV	{"phone": "+70732523510"}
0005433763207	44A8CF	0716 448192	VIKTOR MELNIKOV	{"phone": "+70133846139"}
0005433763208	44A8CF	0667 537256	ZINAIDA ALEKSANDROVA	{"phone": "+70202138183"}
0005433763209	32AA8F	5697 314923	KSENIYA NAUMOVA	{"email": "naumova_k_1977@postgrespro.ru", "phone": "+70438861407"}
0005433763210	32AA8F	4030 392093	ANASTASIYA SOLOVEVA	{"email": "asoloveva011976@postgrespro.ru", "phone": "+70127247558"}
0005433763211	FB4BDC	8731 922669	MAYYA MELNIKOVA	{"phone": "+70925997949"}
0005433763212	FB4BDC	7334 462353	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-25101986@postgrespro.ru", "phone": "+70423091811"}
0005433763213	640A2E	7657 609541	VYACHESLAV ANDREEV	{"phone": "+70053383186"}
0005433763214	640A2E	7735 299506	VALENTINA NIKIFOROVA	{"email": "valentina-nikiforova-1968@postgrespro.ru", "phone": "+70375963320"}
0005433763215	AC7A52	8034 243829	VALERIY SOROKIN	{"phone": "+70503028845"}
0005433763216	3FBCED	1307 481480	ANATOLIY DAVYDOV	{"email": "anatoliy.davydov.111965@postgrespro.ru", "phone": "+70445894750"}
0005433763217	8AF9FE	0555 878654	ANASTASIYA NIKITINA	{"email": "nikitinaa18081978@postgrespro.ru", "phone": "+70370701737"}
0005433763218	101F4C	6043 781294	VIKTORIYA FILATOVA	{"phone": "+70813375490"}
0005433763219	101F4C	7423 834530	GALINA KISELEVA	{"phone": "+70763243149"}
0005433763220	F528C4	0665 127337	VYACHESLAV GRIGOREV	{"phone": "+70451270939"}
0005433763221	F528C4	7139 998705	GALINA PAVLOVA	{"phone": "+70956755356"}
0005433763222	33E345	3054 652744	DENIS IVANOV	{"phone": "+70910226152"}
0005433763223	33E345	7040 571366	NADEZHDA CHERNOVA	{"phone": "+70508744222"}
0005433763224	33E345	1853 622208	MARGARITA MARTYNOVA	{"phone": "+70138204603"}
0005433763225	674334	7287 869488	VIKTOR ALEKSANDROV	{"phone": "+70018111258"}
0005433763226	674334	2156 796109	ANDREY STEPANOV	{"phone": "+70792835291"}
0005433763227	C37D48	9750 947350	VIKTOR MEDVEDEV	{"phone": "+70766472820"}
0005433763228	C37D48	7887 239816	SVETLANA IVANOVA	{"phone": "+70517086139"}
0005433763229	E07227	1053 577359	NIKITA ZAKHAROV	{"email": "zakharov.nikita28021981@postgrespro.ru", "phone": "+70369994043"}
0005433763230	E07227	2047 505654	ALEKSANDR ANDREEV	{"phone": "+70076798270"}
0005433763231	CD749B	4988 380340	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana-121968@postgrespro.ru", "phone": "+70662561806"}
0005433763232	CD749B	6832 911993	BORIS POPOV	{"email": "popov-b.24121966@postgrespro.ru", "phone": "+70110979560"}
0005433763233	CD749B	0303 260392	GENNADIY KOZLOV	{"email": "g.kozlov-16071960@postgrespro.ru", "phone": "+70768746917"}
0005433763234	6F84A7	4060 462358	VASILIY KRASNOV	{"email": "vasiliy-krasnov1959@postgrespro.ru", "phone": "+70773847112"}
0005433763235	6361C6	4421 106827	ALEKSANDRA MELNIKOVA	{"email": "a_melnikova26071964@postgrespro.ru", "phone": "+70070338651"}
0005433763236	6361C6	6693 473217	VLADIMIR GORBUNOV	{"phone": "+70065429444"}
0005433763237	CE66D6	7616 318956	ANNA ROMANOVA	{"email": "anna-romanova1972@postgrespro.ru", "phone": "+70281019033"}
0005433763238	CE66D6	8437 677773	TATYANA VOLKOVA	{"email": "tatyana_volkova.09021976@postgrespro.ru", "phone": "+70132309784"}
0005433763239	79868D	0827 396620	VADIM IVANOV	{"phone": "+70634095089"}
0005433763240	79868D	7496 201247	OLGA FROLOVA	{"phone": "+70838034376"}
0005433763241	66C287	6969 747476	VALERIY NAUMOV	{"phone": "+70886869034"}
0005433763242	66C287	2449 121560	VALERIY VASILEV	{"phone": "+70394644374"}
0005433763243	C54901	4947 512428	ARTEM MAKSIMOV	{"email": "maksimov-a_01041972@postgrespro.ru", "phone": "+70769918501"}
0005433763244	250000	0187 964495	ANNA SEMENOVA	{"phone": "+70989301222"}
0005433763245	250000	9423 826676	VALENTIN CHERNOV	{"email": "chernov.v-14041975@postgrespro.ru", "phone": "+70866221203"}
0005433763246	250000	9476 090947	DENIS OSIPOV	{"phone": "+70968372730"}
0005433763247	A60F1B	3939 384733	NATALYA NIKIFOROVA	{"phone": "+70606386754"}
0005433763248	E0B0B1	6681 093284	NATALYA EFIMOVA	{"email": "natalya_efimova_071976@postgrespro.ru", "phone": "+70230513480"}
0005433763249	04281D	4969 230475	ALEKSEY YAKOVLEV	{"email": "yakovlev.a_21091961@postgrespro.ru", "phone": "+70934498921"}
0005433763250	412C1D	6671 222983	TATYANA ALEKSEEVA	{"email": "alekseeva-t_28031959@postgrespro.ru", "phone": "+70552208088"}
0005433763251	412C1D	6886 613919	FEDOR VOROBEV	{"phone": "+70110123516"}
0005433763252	412C1D	8746 781461	NATALYA OVCHINNIKOVA	{"phone": "+70303812164"}
0005433763253	C19F81	5521 681439	PETR SERGEEV	{"phone": "+70896066641"}
0005433763254	C19F81	2838 868184	DMITRIY ABRAMOV	{"email": "abramov_d_021958@postgrespro.ru", "phone": "+70177189813"}
0005433763255	BB42B8	0317 880501	IVAN KUZMIN	{"email": "ivan-kuzmin.27101966@postgrespro.ru", "phone": "+70299196291"}
0005433763256	BB42B8	3741 210098	YAN BORISOV	{"email": "borisov-yan-11021969@postgrespro.ru", "phone": "+70922033148"}
0005433763257	CADAB9	0904 986759	MARINA BOGDANOVA	{"email": "bogdanova_m_1971@postgrespro.ru", "phone": "+70956231735"}
0005433763258	CADAB9	1615 803524	ANATOLIY KUZNECOV	{"email": "anatoliy_kuznecov_1973@postgrespro.ru", "phone": "+70423266114"}
0005433763259	471417	4329 700556	ELENA NIKOLAEVA	{"phone": "+70618332789"}
0005433763260	96535F	3667 612442	EGOR IVANOV	{"email": "ivanov.egor_1964@postgrespro.ru", "phone": "+70658929570"}
0005433763261	314505	0007 381088	MARINA FILATOVA	{"email": "mfilatova1969@postgrespro.ru", "phone": "+70577735342"}
0005433763262	46FD8E	0636 304307	NIKOLAY ISAEV	{"email": "n.isaev_26101975@postgrespro.ru", "phone": "+70933263599"}
0005433763263	3C42D8	2559 854496	SERGEY CHERNOV	{"email": "chernov-s-041980@postgrespro.ru", "phone": "+70853811074"}
0005433763264	3C42D8	6747 628808	VERA SAVELEVA	{"phone": "+70562356975"}
0005433763265	F5B9E4	6747 496639	IGOR ZAYCEV	{"phone": "+70760462440"}
0005433763266	279D32	8934 575560	ANASTASIYA MOISEEVA	{"email": "a.moiseeva101976@postgrespro.ru", "phone": "+70990526889"}
0005433763267	1B30E4	8392 513913	NINA EGOROVA	{"phone": "+70970896133"}
0005433763268	098238	1262 555420	ELMIRA VOLKOVA	{"email": "elmira.volkova-091978@postgrespro.ru", "phone": "+70311977336"}
0005433763269	9929F1	2868 669558	ELENA BELYAEVA	{"email": "elena-belyaeva_011977@postgrespro.ru", "phone": "+70236940715"}
0005433763270	9929F1	8969 696734	ZINAIDA STEPANOVA	{"email": "stepanovazinaida1962@postgrespro.ru", "phone": "+70568290524"}
0005433763271	6EB037	7973 437896	AYRAT VASILEV	{"email": "ayrat_vasilev.1971@postgrespro.ru", "phone": "+70272857987"}
0005433763272	D400FF	3598 560018	MARYAM TROFIMOVA	{"email": "m.trofimova-1970@postgrespro.ru", "phone": "+70832892222"}
0005433763273	D400FF	3018 748121	GALINA MARTYNOVA	{"email": "martynova-g1976@postgrespro.ru", "phone": "+70875805517"}
0005433763274	D82DDF	2986 740441	TATYANA EFREMOVA	{"email": "tatyana.efremova.08061966@postgrespro.ru", "phone": "+70387674503"}
0005433763275	1A5EFE	5897 973386	NADEZHDA EFREMOVA	{"email": "n_efremova.31011971@postgrespro.ru", "phone": "+70673099870"}
0005433763276	3C2CE8	0130 841646	EVGENIY GAVRILOV	{"email": "evgeniy_gavrilov-1980@postgrespro.ru", "phone": "+70549299482"}
0005433763277	3C2CE8	9449 637603	NATALYA FEDOROVA	{"email": "fedorova-n_1977@postgrespro.ru", "phone": "+70044670132"}
0005433763278	32E6E6	3207 240399	EVGENIY IVANOV	{"email": "eivanov_29091952@postgrespro.ru", "phone": "+70642217805"}
0005433763279	335CE8	2907 520215	RAMIS GORBUNOV	{"email": "gorbunov_ramis_041975@postgrespro.ru", "phone": "+70614560164"}
0005433763280	3A73C6	6586 923021	MIKHAIL DENISOV	{"phone": "+70600937955"}
0005433763281	C0AD08	4850 125571	OLGA LUKYANOVA	{"email": "olga-lukyanova_16111968@postgrespro.ru", "phone": "+70154014205"}
0005433763282	E63168	4050 468588	ELENA YAKOVLEVA	{"phone": "+70845262903"}
0005433763283	D02347	7724 854523	IVAN FEDOROV	{"email": "ifedorov_1968@postgrespro.ru", "phone": "+70455707539"}
0005433763284	790D05	0722 401945	LYUDMILA STEPANOVA	{"phone": "+70930751949"}
0005433763285	D2FE99	4681 465869	ANNA TITOVA	{"email": "titova-a-24011976@postgrespro.ru", "phone": "+70891324898"}
0005433763286	D2FE99	9478 057340	MARINA KULIKOVA	{"phone": "+70394212687"}
0005433763287	F6D81D	4584 696051	ARTUR MOISEEV	{"email": "a.moiseev_30081984@postgrespro.ru", "phone": "+70221806497"}
0005433763288	EFC045	5973 171447	EVGENIY MAKAROV	{"email": "makarovevgeniy_101974@postgrespro.ru", "phone": "+70929709809"}
0005433763289	50B6D6	7633 908306	NATALYA MALYSHEVA	{"email": "malysheva-natalya081980@postgrespro.ru", "phone": "+70212507604"}
0005433763290	96D0F7	0907 268277	VLADIMIR POPOV	{"email": "vladimir.popov-1963@postgrespro.ru", "phone": "+70963860434"}
0005433763291	9D6DAC	0627 744948	OLEG PAVLOV	{"phone": "+70985476462"}
0005433763292	D62BFB	5012 639923	NINA TARASOVA	{"email": "ntarasova091963@postgrespro.ru", "phone": "+70643831499"}
0005433763293	D62BFB	4544 856685	VASILIY DENISOV	{"email": "vasiliy_denisov041975@postgrespro.ru", "phone": "+70945604871"}
0005433763294	F152C5	9522 695007	GRIGORIY SERGEEV	{"phone": "+70197303178"}
0005433763295	F152C5	7904 710019	NIKOLAY FROLOV	{"email": "frolov_n-031974@postgrespro.ru", "phone": "+70846222810"}
0005433763296	C91F0D	3914 613304	NATALYA ISAEVA	{"email": "isaeva.n_011981@postgrespro.ru", "phone": "+70936733251"}
0005433763297	AF89D8	3831 230235	ARTEM SMIRNOV	{"email": "asmirnov1972@postgrespro.ru", "phone": "+70340348782"}
0005433763298	5D03C1	5130 242924	YURIY NOVIKOV	{"email": "yuriy-novikov-121982@postgrespro.ru", "phone": "+70432278783"}
0005433763299	18ECE1	7530 901955	EDUARD ZAYCEV	{"email": "eduard_zaycev1969@postgrespro.ru", "phone": "+70644551485"}
0005433763300	9FADC2	9521 954225	VLADIMIR VOLKOV	{"phone": "+70441857793"}
0005433763301	9FADC2	0244 143210	OKSANA ZAKHAROVA	{"email": "zakharova_oksana_1983@postgrespro.ru", "phone": "+70536347311"}
0005433763302	E4D5BC	4381 144914	ALEKSEY FOMIN	{"email": "fomin_aleksey121968@postgrespro.ru", "phone": "+70256151417"}
0005433763303	632BC8	6509 787554	PETR MARTYNOV	{"phone": "+70766893630"}
0005433763304	1FF01D	3683 833457	VIKTOR FROLOV	{"phone": "+70301722558"}
0005433763305	BA09E5	8207 391077	TATYANA ZHURAVLEVA	{"phone": "+70841549645"}
0005433763306	DDC877	2130 717200	TAMARA NAZAROVA	{"email": "nazarova.t01031983@postgrespro.ru", "phone": "+70060445376"}
0005433763307	4AAFBD	9425 872422	ALEKSANDR RODIONOV	{"phone": "+70711258901"}
0005433763308	F770F2	2581 633596	SVETLANA MARTYNOVA	{"email": "martynova_svetlana.061971@postgrespro.ru", "phone": "+70582279305"}
0005433763309	FF0489	0387 329950	VALERIYA TIKHONOVA	{"phone": "+70609195929"}
0005433763310	1CE25E	0617 191004	DANILA POPOV	{"email": "d-popov031968@postgrespro.ru", "phone": "+70884172042"}
0005433763311	C29BB8	1823 946609	PAVEL ALEKSEEV	{"email": "alekseevp-121978@postgrespro.ru", "phone": "+70514270875"}
0005433763312	4CCA10	2747 910639	GENNADIY MAKAROV	{"phone": "+70840956712"}
0005433763313	72EB21	1633 359744	VALENTINA NIKITINA	{"email": "vnikitina1977@postgrespro.ru", "phone": "+70485358768"}
0005433763314	61478E	8843 180644	DARYA POTAPOVA	{"phone": "+70255255558"}
0005433763315	8C063F	1044 186966	RAFAIL KUZNECOV	{"email": "kuznecov.r_03031968@postgrespro.ru", "phone": "+70124129185"}
0005433763316	FC9046	0055 087073	VLADIMIR ZAYCEV	{"phone": "+70715324553"}
0005433763317	B07A42	5488 879400	ANISA YAKOVLEVA	{"email": "a.yakovleva-1982@postgrespro.ru", "phone": "+70047422286"}
0005433763318	7AAA78	9630 779863	RASHID KULIKOV	{"phone": "+70885318751"}
0005433763319	89EF66	9227 901972	VIKTOR ROMANOV	{"email": "vromanov.081985@postgrespro.ru", "phone": "+70596125696"}
0005433763320	9C5F76	4474 867402	PAVEL KARPOV	{"email": "p_karpov-1976@postgrespro.ru", "phone": "+70016162363"}
0005433763321	280504	3290 532038	ALEKSANDRA KUZMINA	{"email": "a_kuzmina-121977@postgrespro.ru", "phone": "+70608574814"}
0005433763322	4FDDA2	1267 459900	ARTEM KUZNECOV	{"email": "kuznecov-a.011976@postgrespro.ru", "phone": "+70739906624"}
0005433763323	4FDDA2	1663 963946	ALEKSEY BELOV	{"phone": "+70666597255"}
0005433763324	4FDDA2	3849 553261	SOFIYA OVCHINNIKOVA	{"phone": "+70584369436"}
0005433763325	CEEC58	4240 733081	YURIY NIKOLAEV	{"email": "yuriy.nikolaev.011978@postgrespro.ru", "phone": "+70180443214"}
0005433763326	B5F722	9743 623067	OLGA PETROVA	{"phone": "+70559262311"}
0005433763327	453421	8126 096057	SOFYA SAVELEVA	{"email": "s-saveleva041973@postgrespro.ru", "phone": "+70357601834"}
0005433763328	329EB0	2299 497948	YANA KONOVALOVA	{"email": "konovalovay-111973@postgrespro.ru", "phone": "+70582744443"}
0005433763329	43000F	1848 683042	VLADIMIR BARANOV	{"phone": "+70736164370"}
0005433763330	43000F	0749 920729	PELAGEYA KUZNECOVA	{"email": "kuznecova.p.1968@postgrespro.ru", "phone": "+70549311276"}
0005433763331	0356C2	2413 334105	MARIYA TARASOVA	{"phone": "+70360349221"}
0005433763332	589942	1163 145409	ANNA SMIRNOVA	{"phone": "+70922199658"}
0005433763333	589942	2512 123419	VITALIY ROMANOV	{"email": "romanovv-1973@postgrespro.ru", "phone": "+70115294191"}
0005433763334	F40414	6760 113859	OLESYA GRISHINA	{"phone": "+70365656686"}
0005433763335	0B8A73	4054 943732	ANTON GUSEV	{"phone": "+70333578474"}
0005433763336	B3C648	7862 008740	LARISA NESTEROVA	{"phone": "+70773154479"}
0005433763337	48A409	9568 573230	ARSENIY DMITRIEV	{"email": "arseniy_dmitriev.25071978@postgrespro.ru", "phone": "+70894037386"}
0005433763578	474C00	0822 342253	SVETLANA KUZNECOVA	{"phone": "+70861336690"}
0005433763338	6A5ABE	4284 685043	MIKHAIL MIRONOV	{"email": "mikhail-mironov14031982@postgrespro.ru", "phone": "+70574122978"}
0005433763339	6A5ABE	5921 094174	DMITRIY FOMIN	{"email": "dmitriyfomin.071986@postgrespro.ru", "phone": "+70134960668"}
0005433763340	6A5ABE	4147 373846	NADEZHDA FROLOVA	{"phone": "+70738520543"}
0005433763341	A7140E	7933 203103	OLEG SAVELEV	{"email": "savelevoleg1965@postgrespro.ru", "phone": "+70010833702"}
0005433763342	A7140E	2240 967562	VIKTOR SCHERBAKOV	{"phone": "+70645539370"}
0005433763343	21B984	5773 598963	VERA SOLOVEVA	{"phone": "+70401634939"}
0005433763344	21B984	0403 081618	ELENA NIKITINA	{"phone": "+70171963511"}
0005433763345	9EF2C1	1819 159235	MARGARITA KARPOVA	{"phone": "+70460840128"}
0005433763346	9B2177	2357 551488	NATALYA FEDOROVA	{"email": "natalya.fedorova.20101969@postgrespro.ru", "phone": "+70373680629"}
0005433763347	9B2177	2915 527710	ZINAIDA VLASOVA	{"email": "z.vlasova02081980@postgrespro.ru", "phone": "+70037155780"}
0005433763348	233B13	4108 251721	SERAFIMA LOGINOVA	{"email": "serafima.loginova05091975@postgrespro.ru", "phone": "+70014028523"}
0005433763349	F81C0C	3351 118468	ROMAN FEDOROV	{"email": "fedorov-roman18121974@postgrespro.ru", "phone": "+70822224310"}
0005433763350	1125A3	3152 045330	VASILIY POPOV	{"email": "vasiliypopov_051973@postgrespro.ru", "phone": "+70632803031"}
0005433763351	70B232	5627 246122	KRISTINA FOMINA	{"phone": "+70919673549"}
0005433763352	96EBA6	3493 655390	DANIL MELNIKOV	{"phone": "+70069358796"}
0005433763353	96EBA6	8201 424236	MARIYA ABRAMOVA	{"phone": "+70018465836"}
0005433763354	3006E1	9429 423058	ZOYA DANILOVA	{"email": "zdanilova.051964@postgrespro.ru", "phone": "+70375067671"}
0005433763355	3006E1	0112 762288	ULYANA EFREMOVA	{"email": "efremova_u29101971@postgrespro.ru", "phone": "+70104763237"}
0005433763356	3006E1	5187 149525	FARIT ORLOV	{"phone": "+70179624325"}
0005433763357	18F3BB	5284 225999	MARIYA OSIPOVA	{"phone": "+70218697977"}
0005433763358	3DDF6F	9744 792331	NADEZHDA BOGDANOVA	{"phone": "+70060140407"}
0005433763359	E56231	5380 138992	PAVEL CHERNOV	{"phone": "+70557211132"}
0005433763360	E56231	7251 237075	ALEKSANDR IVANOV	{"phone": "+70732193103"}
0005433763361	79A481	3793 373288	ROMAN TARASOV	{"email": "tarasov.roman.19121979@postgrespro.ru", "phone": "+70488707655"}
0005433763362	CFF99D	9650 708811	VLADIMIR KUZNECOV	{"phone": "+70985154612"}
0005433763363	5F13DD	0874 033889	NIKOLAY SMIRNOV	{"email": "nsmirnov_28021968@postgrespro.ru", "phone": "+70348493071"}
0005433763364	0294CB	2661 522256	VALERIY NAZAROV	{"email": "valeriy.nazarov-14081967@postgrespro.ru", "phone": "+70735990425"}
0005433763365	0B29F3	6639 417470	LEONID PAVLOV	{"email": "l_pavlov30061969@postgrespro.ru", "phone": "+70324291811"}
0005433763366	0B29F3	2223 645314	EVGENIY FEDOROV	{"email": "fedorov.evgeniy_1980@postgrespro.ru", "phone": "+70372840133"}
0005433763367	E5280C	3435 672412	KSENIYA POPOVA	{"email": "k_popova.17091968@postgrespro.ru", "phone": "+70005088720"}
0005433763368	E5280C	5137 301161	OLGA VASILEVA	{"email": "vasileva.olga1982@postgrespro.ru", "phone": "+70490720274"}
0005433763369	E5280C	3117 752115	OLGA MIKHAYLOVA	{"email": "mikhaylovaolga_1974@postgrespro.ru", "phone": "+70821917511"}
0005433763370	65CDB4	4579 466075	YURIY KOROLEV	{"email": "korolev_yuriy-29071970@postgrespro.ru", "phone": "+70819993926"}
0005433763371	D5CF59	1033 545718	TAISIYA KOROLEVA	{"phone": "+70543997648"}
0005433763372	D5CF59	4459 382375	VLADIMIR KOZLOV	{"phone": "+70644171077"}
0005433763373	1F1907	2353 100992	SEMEN BORISOV	{"email": "borisov_semen.19051966@postgrespro.ru", "phone": "+70281312701"}
0005433763374	8D0D46	5243 871525	LIDIYA MARTYNOVA	{"email": "lmartynova.1978@postgrespro.ru", "phone": "+70129920641"}
0005433763375	8D0D46	5491 987681	VLADA KAZAKOVA	{"email": "kazakovav_16031970@postgrespro.ru", "phone": "+70752970497"}
0005433763376	2D0AFF	2829 189900	GALINA VLASOVA	{"email": "galina-vlasova.1973@postgrespro.ru", "phone": "+70667449541"}
0005433763377	4ECD70	7069 577051	RUSLAN OSIPOV	{"phone": "+70028673075"}
0005433763378	F650C9	2613 482234	ANASTASIYA FEDOROVA	{"email": "fedorovaa.26111971@postgrespro.ru", "phone": "+70198883265"}
0005433763379	F650C9	8911 930001	EKATERINA VOLKOVA	{"email": "e_volkova.19031968@postgrespro.ru", "phone": "+70521048410"}
0005433763380	5F2FAA	5012 694266	ANATOLIY FEDOROV	{"email": "fedorov.a.1975@postgrespro.ru", "phone": "+70435876386"}
0005433763381	982C7D	2494 773465	SERGEY KULIKOV	{"email": "s_kulikov-1971@postgrespro.ru", "phone": "+70647426831"}
0005433763382	71690D	5501 712858	ELENA PAVLOVA	{"email": "pavlova.e-1971@postgrespro.ru", "phone": "+70644277597"}
0005433763383	F1522D	2435 591367	OLGA ANTONOVA	{"phone": "+70344995229"}
0005433763384	8BF6FA	5290 470634	SERGEY RODIONOV	{"phone": "+70411728745"}
0005433763385	591998	3743 291847	ALEKSANDR ZAKHAROV	{"email": "zakharov-a051981@postgrespro.ru", "phone": "+70011859605"}
0005433763386	591998	0309 002200	PETR NOVIKOV	{"phone": "+70248983821"}
0005433763387	8491FC	0017 557073	NIKOLAY PETROV	{"phone": "+70020511362"}
0005433763388	6ED674	4199 947119	ALEKSANDR EGOROV	{"email": "egorov.a-061962@postgrespro.ru", "phone": "+70473416853"}
0005433763389	D71800	7688 473908	SOFIYA ANISIMOVA	{"email": "sofiyaanisimova_1966@postgrespro.ru", "phone": "+70589922682"}
0005433763390	39842B	4261 504522	VYACHESLAV CHERNOV	{"email": "chernov-vyacheslav-1966@postgrespro.ru", "phone": "+70257264204"}
0005433763391	39842B	5064 519834	PAVEL MOROZOV	{"phone": "+70218694871"}
0005433763392	E9F5D1	0592 926313	ANASTASIYA ABRAMOVA	{"phone": "+70506487149"}
0005433763393	E9F5D1	4654 553044	VIKTORIYA KOZLOVA	{"email": "kozlova.viktoriya1965@postgrespro.ru", "phone": "+70272188190"}
0005433763394	E9F5D1	2342 017787	IVAN GERASIMOV	{"phone": "+70999019666"}
0005433763395	F60DD2	7168 163300	DMITRIY NAZAROV	{"phone": "+70097936625"}
0005433763396	130710	8147 763141	TATYANA IVANOVA	{"email": "tatyanaivanova1974@postgrespro.ru", "phone": "+70556990486"}
0005433763397	DCBDA2	4951 883244	PAVEL MAKAROV	{"email": "makarov.pavel051965@postgrespro.ru", "phone": "+70432371802"}
0005433763398	7217F0	8313 939245	TATYANA MALYSHEVA	{"email": "malyshevat-051985@postgrespro.ru", "phone": "+70767495051"}
0005433763399	910FF8	1154 531638	ANASTASIYA VASILEVA	{"email": "vasileva.a-1983@postgrespro.ru", "phone": "+70038450228"}
0005433763400	910FF8	5784 528037	VIKTOR ZAKHAROV	{"phone": "+70692671009"}
0005433763401	0EF38A	2161 038749	OLGA FEDOROVA	{"phone": "+70873209814"}
0005433763402	E00875	4273 628714	NIKITA NIKITIN	{"phone": "+70306623099"}
0005433763403	E00875	8250 916831	VLADISLAV NOVIKOV	{"phone": "+70338655828"}
0005433763404	7131D3	3274 271027	PRASKOVYA EFREMOVA	{"email": "pefremova.071971@postgrespro.ru", "phone": "+70059074199"}
0005433763405	7131D3	7649 172531	SERGEY MIKHAYLOV	{"email": "sergey.mikhaylov051981@postgrespro.ru", "phone": "+70613622193"}
0005433763406	7131D3	7767 918964	NATALYA TARASOVA	{"email": "tarasova_n_01021970@postgrespro.ru", "phone": "+70971221226"}
0005433763407	2FE4B1	1695 985447	PAVEL PAVLOV	{"email": "pavel-pavlov.121972@postgrespro.ru", "phone": "+70229006474"}
0005433763408	2FE4B1	0568 369205	MARIYA KUDRYASHOVA	{"phone": "+70193733546"}
0005433763409	57B49F	1889 994606	LYUDMILA PETROVA	{"phone": "+70181903759"}
0005433763410	78D7F5	5220 652501	ZINAIDA KALININA	{"email": "z-kalinina_101967@postgrespro.ru", "phone": "+70012335411"}
0005433763411	78D7F5	6024 461523	ALEKSEY YAKOVLEV	{"email": "yakovlev_a061960@postgrespro.ru", "phone": "+70226904880"}
0005433763412	142896	1802 364016	DENIS KUZNECOV	{"phone": "+70842662864"}
0005433763413	2AEE7E	0908 715852	BULAT TIMOFEEV	{"email": "timofeev-bulat-1957@postgrespro.ru", "phone": "+70006482738"}
0005433763414	420886	1068 505962	VALENTINA AFANASEVA	{"phone": "+70695930225"}
0005433763415	FF9184	7593 903842	RADIK NIKOLAEV	{"email": "nikolaev_r-101982@postgrespro.ru", "phone": "+70876943424"}
0005433763416	600E15	8048 590241	VLADIMIR KARPOV	{"email": "vladimirkarpov-1974@postgrespro.ru", "phone": "+70268186435"}
0005433763417	A5EAE7	0845 491226	GRIGORIY TARASOV	{"email": "tarasov_grigoriy-03121974@postgrespro.ru", "phone": "+70739566557"}
0005433763418	917EBC	1334 303267	NELYA GAVRILOVA	{"email": "ngavrilova-091977@postgrespro.ru", "phone": "+70492765028"}
0005433763419	917EBC	0839 778952	VERA KOVALEVA	{"email": "vkovaleva.011972@postgrespro.ru", "phone": "+70690310358"}
0005433763420	AC0010	4558 753591	EKATERINA NESTEROVA	{"phone": "+70629963372"}
0005433763421	AC0010	1220 250834	ELENA EFIMOVA	{"email": "elena_efimova.101971@postgrespro.ru", "phone": "+70942010768"}
0005433763422	714AAD	2475 343870	NINA EFIMOVA	{"email": "n_efimova-1968@postgrespro.ru", "phone": "+70035435382"}
0005433763423	772EF7	2930 321307	MARINA BELYAEVA	{"email": "marinabelyaeva.121972@postgrespro.ru", "phone": "+70192848037"}
0005433763424	8EEA5D	3960 506639	EKATERINA PAVLOVA	{"email": "pavlovaekaterina_06101978@postgrespro.ru", "phone": "+70255279570"}
0005433763425	8EEA5D	4355 406807	IRINA TIMOFEEVA	{"phone": "+70118744085"}
0005433763426	815628	1464 754977	NIKOLAY BORISOV	{"phone": "+70908520244"}
0005433763427	01A646	0638 367716	EVGENIY MIKHAYLOV	{"phone": "+70553820877"}
0005433763428	01A646	4340 110174	YURIY BELOV	{"email": "belov_y1970@postgrespro.ru", "phone": "+70916807784"}
0005433763429	0D6270	9102 031686	DIANA KOROLEVA	{"phone": "+70446983498"}
0005433763430	0D6270	9992 510283	VITALIY IVANOV	{"phone": "+70008385108"}
0005433763431	B6C33C	1652 568940	ELENA BELOVA	{"email": "e_belova-1964@postgrespro.ru", "phone": "+70457821170"}
0005433763432	950E7F	5648 184428	VERA DMITRIEVA	{"phone": "+70565813586"}
0005433763433	89E843	1220 975650	EVGENIY MOROZOV	{"email": "morozove.15111976@postgrespro.ru", "phone": "+70979981093"}
0005433763434	89E843	9523 470858	SAVELIY SIDOROV	{"phone": "+70153950829"}
0005433763435	AE9DBA	4136 722411	TATYANA DANILOVA	{"phone": "+70075232800"}
0005433763436	AE9DBA	7080 092586	ALEKSANDR PETROV	{"email": "petrova.111975@postgrespro.ru", "phone": "+70096279055"}
0005433763437	F4A8BE	1037 511659	VALENTINA POLYAKOVA	{"email": "polyakova.v-08101967@postgrespro.ru", "phone": "+70289903768"}
0005433763438	4AE787	3233 876383	ALENA ROMANOVA	{"phone": "+70162470499"}
0005433763439	9D3B9B	5436 998748	DMITRIY VASILEV	{"phone": "+70746392547"}
0005433763440	9D3B9B	7251 207074	VALENTINA SEMENOVA	{"email": "valentinasemenova_20031971@postgrespro.ru", "phone": "+70413916520"}
0005433763441	74EED1	1934 392209	OLGA BELYAEVA	{"phone": "+70427933010"}
0005433763442	C455EC	4263 749714	MARIYA KUDRYASHOVA	{"email": "mariya_kudryashova.121963@postgrespro.ru", "phone": "+70392459528"}
0005433763443	434066	6598 061943	ALEKSANDR PAVLOV	{"phone": "+70979893095"}
0005433763444	434066	8819 084785	SERGEY MAKSIMOV	{"email": "maksimov_sergey.1969@postgrespro.ru", "phone": "+70948759251"}
0005433763445	434066	3230 166446	ANDREY MARTYNOV	{"phone": "+70406311720"}
0005433763446	977B08	4570 745746	VLADIMIR GERASIMOV	{"email": "gerasimovv.01031969@postgrespro.ru", "phone": "+70932553163"}
0005433763447	7836B2	4429 713842	ALEKSANDRA PETROVA	{"phone": "+70024582013"}
0005433763448	2A6FA9	4254 714458	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir.11021981@postgrespro.ru", "phone": "+70199292592"}
0005433763449	0038C7	2378 156456	RIMMA OSIPOVA	{"phone": "+70863103751"}
0005433763450	E0C829	0150 717265	MARIYA PETROVA	{"email": "m_petrova-08071977@postgrespro.ru", "phone": "+70060470750"}
0005433763451	3E564E	2756 765594	EKATERINA MAKSIMOVA	{"email": "emaksimova_23061976@postgrespro.ru", "phone": "+70675684092"}
0005433763452	BD3CCD	7579 882909	ANDREY MOROZOV	{"phone": "+70866183662"}
0005433763453	F74B64	2631 141108	LYUBOV PETROVA	{"email": "petrova_l_23111964@postgrespro.ru", "phone": "+70868499896"}
0005433763454	F74B64	8415 977458	NINA KUZMINA	{"email": "kuzmina_nina_1984@postgrespro.ru", "phone": "+70009936267"}
0005433763455	CD049E	1076 084944	VLADIMIR KONOVALOV	{"email": "konovalovvladimir.031982@postgrespro.ru", "phone": "+70826137084"}
0005433763456	D41225	3372 043588	LYUBOV SAVELEVA	{"email": "saveleva-l.17091969@postgrespro.ru", "phone": "+70203716127"}
0005433763457	D41225	5270 248328	VLADISLAV ANDREEV	{"phone": "+70676132645"}
0005433763458	D37F85	1376 503332	VLADIMIR SEMENOV	{"phone": "+70169793781"}
0005433763459	D37F85	0094 334239	NIKOLAY NAZAROV	{"phone": "+70526039014"}
0005433763460	D37F85	1881 363285	OKSANA CHERNOVA	{"email": "o-chernova-061970@postgrespro.ru", "phone": "+70839201702"}
0005433763461	348A5E	0235 051043	NINA FEDOROVA	{"email": "fedorovanina_1986@postgrespro.ru", "phone": "+70439587341"}
0005433763462	76FE5E	9622 074509	NATALYA LOGINOVA	{"email": "natalya.loginova-1963@postgrespro.ru", "phone": "+70886135724"}
0005433763463	76FE5E	9511 103906	ALEKSANDR POPOV	{"phone": "+70469626500"}
0005433763464	9C9CF2	8073 757154	MIKHAIL TIMOFEEV	{"email": "mikhailtimofeev03031984@postgrespro.ru", "phone": "+70717497184"}
0005433763465	36405F	5539 087638	DANIIL BARANOV	{"phone": "+70584100252"}
0005433763466	931ADE	0032 661129	ANASTASIYA SERGEEVA	{"phone": "+70749327638"}
0005433763467	401B83	8527 467392	OLGA KUDRYASHOVA	{"email": "kudryashova-olga24061978@postgrespro.ru", "phone": "+70752616961"}
0005433763468	DA2046	4736 567073	IGOR KUZNECOV	{"phone": "+70257806079"}
0005433763469	B83504	3503 610362	ALINA IVANOVA	{"phone": "+70481658206"}
0005433763470	D61F4D	2274 614324	MARINA EGOROVA	{"phone": "+70920394279"}
0005433763471	3610C9	4940 521650	GALINA KUZMINA	{"email": "gkuzmina_12051968@postgrespro.ru", "phone": "+70048848757"}
0005433763472	60C70E	2655 223965	LEONID POPOV	{"phone": "+70955733229"}
0005433763473	EC304E	4145 565496	ALENA KISELEVA	{"phone": "+70688663168"}
0005433763474	EC304E	5216 126443	MARIYA VOLKOVA	{"phone": "+70833704383"}
0005433763475	A6CA0F	3903 651003	EVGENIYA VLASOVA	{"email": "e-vlasova-071967@postgrespro.ru", "phone": "+70490943674"}
0005433763476	63E37B	5889 814882	NATALYA TROFIMOVA	{"phone": "+70038367432"}
0005433763477	778A2F	1322 116708	PAVEL KUZNECOV	{"phone": "+70825542593"}
0005433763478	778A2F	2056 443287	LILIYA SIDOROVA	{"phone": "+70996915738"}
0005433763479	0304C4	3055 436459	VASILIY SOKOLOV	{"phone": "+70768619244"}
0005433763480	0304C4	1812 708030	MARIYA ARKHIPOVA	{"phone": "+70657220903"}
0005433763481	E49D60	2257 979192	ELENA BELOVA	{"phone": "+70779070570"}
0005433763482	785AA8	3853 604917	PAVEL ZAYCEV	{"phone": "+70290393248"}
0005433763483	B138AF	5589 959750	VYACHESLAV ZAKHAROV	{"email": "zakharov_v_1985@postgrespro.ru", "phone": "+70779613274"}
0005433763484	B138AF	7297 627368	OLGA DAVYDOVA	{"email": "davydova_o081970@postgrespro.ru", "phone": "+70811954143"}
0005433763485	991D02	1132 174441	ALEKSEY MEDVEDEV	{"email": "medvedev-aleksey-03101969@postgrespro.ru", "phone": "+70614810057"}
0005433763486	9B6A3D	4914 504129	EGOR SERGEEV	{"email": "egor-sergeev_1971@postgrespro.ru", "phone": "+70993713301"}
0005433763487	F1EF27	7669 682439	RUSLAN POPOV	{"email": "rpopov16101975@postgrespro.ru", "phone": "+70272058785"}
0005433763488	F3A36B	5831 479064	NINA EFIMOVA	{"phone": "+70469681443"}
0005433763489	17301A	0644 363072	VIKTORIYA KUZNECOVA	{"phone": "+70468015860"}
0005433763490	2519FF	9475 328900	VADIM DAVYDOV	{"phone": "+70341010971"}
0005433763491	118BD8	7733 709086	MIKHAIL MOROZOV	{"email": "mikhail.morozov081967@postgrespro.ru", "phone": "+70374491590"}
0005433763492	CB0836	4357 554292	MAYA FADEEVA	{"email": "maya.fadeeva-111966@postgrespro.ru", "phone": "+70453810383"}
0005433763493	368D40	1718 206390	VLADISLAV BELOV	{"phone": "+70969488498"}
0005433763494	A195B5	8216 989685	ARTEM MIRONOV	{"phone": "+70603273671"}
0005433763495	23DFF9	1601 806683	ALEKSANDR SMIRNOV	{"phone": "+70710005795"}
0005433763496	D60A44	6627 344978	TAMARA MAKSIMOVA	{"phone": "+70682779141"}
0005433763497	6BD90F	8250 494916	TATYANA ANTONOVA	{"email": "antonovatatyana_24031983@postgrespro.ru", "phone": "+70676084772"}
0005433763498	6BD90F	9110 810787	VLADIMIR STEPANOV	{"phone": "+70330944429"}
0005433763499	299324	0992 224961	ARMEN VASILEV	{"email": "armen-vasilev_1961@postgrespro.ru", "phone": "+70924096585"}
0005433763500	299324	9609 892920	ANNA FILATOVA	{"phone": "+70071310655"}
0005433763501	DC5645	5316 020181	VIKTOR TIMOFEEV	{"email": "viktor.timofeev_1977@postgrespro.ru", "phone": "+70368659190"}
0005433763502	DC5645	5025 720667	SVETLANA MIRONOVA	{"email": "s_mironova03021978@postgrespro.ru", "phone": "+70453342058"}
0005433763503	B954FE	5717 481199	SERGEY MOROZOV	{"email": "s-morozov-1960@postgrespro.ru", "phone": "+70942350661"}
0005433763504	DD8C99	4957 393870	NADEZHDA GRISHINA	{"phone": "+70898809672"}
0005433763505	DD8C99	8041 007482	LYUBOV ALEKSEEVA	{"email": "alekseeva-lyubov_101964@postgrespro.ru", "phone": "+70092478866"}
0005433763506	46EDF8	7211 020955	NATALYA ISAEVA	{"email": "isaeva-natalya.041973@postgrespro.ru", "phone": "+70621663646"}
0005433763507	46EDF8	3489 744798	NINA ANISIMOVA	{"phone": "+70945659761"}
0005433763508	46EDF8	8709 262130	SERGEY FILIPPOV	{"email": "filippovs111968@postgrespro.ru", "phone": "+70964334874"}
0005433763509	651B0A	8715 452082	YURIY VLASOV	{"phone": "+70125409873"}
0005433763510	43E705	6138 728794	ALENA KOZLOVA	{"email": "kozlova_alena09091972@postgrespro.ru", "phone": "+70396846308"}
0005433763511	E1D2C9	1555 501324	ALEKSEY KUZMIN	{"phone": "+70375221178"}
0005433763512	E1D2C9	6672 627883	SVETLANA SAVELEVA	{"phone": "+70492919942"}
0005433763513	F9DDF3	3486 699530	ALBINA SMIRNOVA	{"email": "a.smirnova1970@postgrespro.ru", "phone": "+70781186876"}
0005433763514	8C649F	9599 469311	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov.111964@postgrespro.ru", "phone": "+70376367879"}
0005433763515	F5B803	6204 705391	GENNADIY SOROKIN	{"phone": "+70350011134"}
0005433763516	0094C4	8471 190335	ANATOLIY POPOV	{"phone": "+70601296585"}
0005433763517	0094C4	4285 517872	SERGEY BELOV	{"phone": "+70934720750"}
0005433763518	D69A51	1877 477079	MAKSIM CHERNOV	{"email": "chernov.maksim.1974@postgrespro.ru", "phone": "+70779810031"}
0005433763519	2C9C38	1986 907440	SVETLANA KISELEVA	{"phone": "+70456820373"}
0005433763520	740356	5554 738166	LARISA LAZAREVA	{"email": "lazareval1981@postgrespro.ru", "phone": "+70250043875"}
0005433763521	FEE30E	5899 836183	GULFIYA BORISOVA	{"phone": "+70532254758"}
0005433763522	1FDE97	0551 726124	LARISA EGOROVA	{"phone": "+70533614873"}
0005433763523	1FDE97	3609 197434	OLGA NIKOLAEVA	{"email": "olga-nikolaeva1972@postgrespro.ru", "phone": "+70280982847"}
0005433763524	0D7881	0610 267905	TAMARA EGOROVA	{"phone": "+70444753183"}
0005433763525	14DA35	2230 832347	ALBERT TARASOV	{"phone": "+70013952858"}
0005433763526	A46EE9	9657 651365	MAKSIM AFANASEV	{"email": "mafanasev_13081978@postgrespro.ru", "phone": "+70494026930"}
0005433763527	1EFA33	6147 138235	NATALYA VLASOVA	{"phone": "+70402004891"}
0005433763528	5F5C0C	8960 404109	IGOR ALEKSEEV	{"phone": "+70171863481"}
0005433763529	3A5F16	2473 900271	TATYANA STEPANOVA	{"phone": "+70978625237"}
0005433763530	3A5F16	8430 798284	LYUDMILA BORISOVA	{"email": "borisova.l15051963@postgrespro.ru", "phone": "+70551775902"}
0005433763531	934F28	1071 597916	DMITRIY VLASOV	{"email": "vlasovdmitriy_1974@postgrespro.ru", "phone": "+70939471737"}
0005433763532	934F28	6666 696826	OLGA STEPANOVA	{"phone": "+70260318072"}
0005433763533	08AF12	9895 329351	NATALYA KONOVALOVA	{"phone": "+70193683205"}
0005433763534	81A6E0	9553 860458	SERGEY OSIPOV	{"email": "osipov-sergey-091973@postgrespro.ru", "phone": "+70746845936"}
0005433763535	79CE08	7294 219819	TATYANA VLASOVA	{"phone": "+70856206810"}
0005433763536	79CE08	1831 994268	STANISLAV NIKOLAEV	{"email": "s_nikolaev-111977@postgrespro.ru", "phone": "+70090311401"}
0005433763537	1B80E4	3232 963300	MARYAM MOROZOVA	{"email": "maryam.morozova-04061961@postgrespro.ru", "phone": "+70533271879"}
0005433763538	35BC52	5696 385668	KRISTINA BELOVA	{"email": "kristina_belova_13061961@postgrespro.ru", "phone": "+70202379274"}
0005433763539	35BC52	7690 983268	ALEKSEY DENISOV	{"email": "denisov-aleksey-29031972@postgrespro.ru", "phone": "+70662427504"}
0005433763540	5D8B31	1076 951865	ELENA FROLOVA	{"email": "elenafrolova.061988@postgrespro.ru", "phone": "+70714846529"}
0005433763541	5D8B31	6731 677725	VLADISLAV STEPANOV	{"phone": "+70687651683"}
0005433763542	D926C2	2184 473477	DARYA ANTONOVA	{"phone": "+70989780022"}
0005433763543	D926C2	7838 655701	NATALYA ZAYCEVA	{"phone": "+70802994100"}
0005433763544	9C599B	6360 123022	SERGEY KUZNECOV	{"phone": "+70425473899"}
0005433763545	ADE45B	6591 603695	PETR FOMIN	{"email": "petr_fomin.041972@postgrespro.ru", "phone": "+70513702374"}
0005433763546	EE43B3	2179 990603	NARIMAN KUZNECOV	{"email": "n-kuznecov_011965@postgrespro.ru", "phone": "+70332274225"}
0005433763547	5D827F	5949 527848	ALEKSANDR IVANOV	{"phone": "+70985809780"}
0005433763548	5D827F	3800 377511	ELENA KONOVALOVA	{"email": "konovalova-elena.111966@postgrespro.ru", "phone": "+70437513268"}
0005433763549	5D827F	2663 350712	NIKOLAY KUZMIN	{"phone": "+70756535552"}
0005433763550	B9FEF8	8765 459844	ALEKSEY SOROKIN	{"email": "sorokin.aleksey011984@postgrespro.ru", "phone": "+70371012004"}
0005433763551	648E43	5429 496744	ALEVTINA VASILEVA	{"email": "vasileva_alevtina_17041974@postgrespro.ru", "phone": "+70818320232"}
0005433763552	648E43	5427 132013	PAVEL DENISOV	{"email": "pdenisov_041968@postgrespro.ru", "phone": "+70256614072"}
0005433763553	E062D3	3449 094806	ALEKSEY SIDOROV	{"email": "aleksey_sidorov-03051967@postgrespro.ru", "phone": "+70555326610"}
0005433763554	9D9E09	6256 593083	SERGEY SOKOLOV	{"phone": "+70473738637"}
0005433763555	FEF91F	6411 252864	VERONIKA POPOVA	{"email": "popova_veronika_031968@postgrespro.ru", "phone": "+70737523310"}
0005433763556	FEF91F	7153 739498	LYUBOV OSIPOVA	{"phone": "+70927491515"}
0005433763557	671FA2	0507 873987	SERGEY PAVLOV	{"email": "pavlovsergey-08061973@postgrespro.ru", "phone": "+70570641568"}
0005433763558	24F1EA	6466 461569	ALEKSANDR GORBUNOV	{"phone": "+70983968533"}
0005433763559	707917	2204 081171	TATYANA VOROBEVA	{"phone": "+70279302852"}
0005433763560	9AD9D0	7140 864474	NADEZHDA ANISIMOVA	{"email": "nadezhda-anisimova-1996@postgrespro.ru", "phone": "+70993196674"}
0005433763561	6C41A8	1109 112398	RAMIL KUZNECOV	{"phone": "+70044440493"}
0005433763562	90775F	6022 243885	SVETLANA OSIPOVA	{"phone": "+70860019878"}
0005433763563	9B2F03	4350 379546	IVAN RODIONOV	{"email": "rodionovivan17041968@postgrespro.ru", "phone": "+70269182971"}
0005433763564	49D228	0288 043976	ELENA MIKHAYLOVA	{"email": "mikhaylova.elena-031964@postgrespro.ru", "phone": "+70694206591"}
0005433763565	FC3844	7414 428443	ELENA KUZNECOVA	{"phone": "+70546899844"}
0005433763566	F873D3	5857 366188	SERGEY ISAEV	{"email": "sisaev_091975@postgrespro.ru", "phone": "+70335375369"}
0005433763567	8DF87D	3281 140860	RAFIK NIKOLAEV	{"email": "nikolaev.rafik-1968@postgrespro.ru", "phone": "+70995189003"}
0005433763568	8A0C43	9821 111067	DILYARA MAKSIMOVA	{"email": "maksimova_dilyara_041983@postgrespro.ru", "phone": "+70523448513"}
0005433763569	7D1D3C	2252 205801	LIDIYA BORISOVA	{"email": "l_borisova-1968@postgrespro.ru", "phone": "+70873137903"}
0005433763570	BD1BAD	4766 551398	GALINA KOVALEVA	{"phone": "+70561494661"}
0005433763571	7156AC	8473 924297	VALENTINA KOLESNIKOVA	{"email": "v.kolesnikova-12101985@postgrespro.ru", "phone": "+70793073320"}
0005433763572	7156AC	3924 150862	EVGENIY ABRAMOV	{"email": "evgeniy-abramov071954@postgrespro.ru", "phone": "+70028009168"}
0005433763573	4274D7	2600 398267	ELENA KUZNECOVA	{"email": "e_kuznecova-111973@postgrespro.ru", "phone": "+70557244238"}
0005433763574	7ACE95	5503 845067	TATYANA SMIRNOVA	{"email": "smirnova-tatyana_051969@postgrespro.ru", "phone": "+70459866608"}
0005433763575	BB2E27	4649 688691	ANNA MALYSHEVA	{"phone": "+70037716025"}
0005433763576	12F090	5583 437722	POLINA SOKOLOVA	{"email": "sokolovap071981@postgrespro.ru", "phone": "+70683322823"}
0005433763577	FDA589	1851 214203	VALERIY SMIRNOV	{"phone": "+70899282932"}
0005433763579	A34353	4563 028635	ARTEM MELNIKOV	{"phone": "+70397834071"}
0005433763580	A34353	3257 860627	ELENA KULIKOVA	{"email": "elenakulikova24051967@postgrespro.ru", "phone": "+70678321134"}
0005433763581	88123F	2440 684503	OKSANA EFREMOVA	{"phone": "+70218579866"}
0005433763582	8EE597	1750 326303	IGOR SOROKIN	{"phone": "+70497106200"}
0005433763583	570E1B	9402 242065	VLADIMIR IVANOV	{"phone": "+70916223776"}
0005433763584	570E1B	5193 849731	VENERA MIRONOVA	{"phone": "+70702991335"}
0005433763585	53CEE0	2309 644534	VIKTOR POPOV	{"email": "viktor.popov18121981@postgrespro.ru", "phone": "+70606873170"}
0005433763586	587A10	6829 680208	VLADIMIR DENISOV	{"email": "denisov-v1965@postgrespro.ru", "phone": "+70659731334"}
0005433763587	01E23B	6651 721218	GALINA VOROBEVA	{"email": "vorobeva.galina.1969@postgrespro.ru", "phone": "+70495005780"}
0005433763588	D84C7E	8455 532876	VADIM MEDVEDEV	{"phone": "+70294411218"}
0005433763589	DF073B	5210 591418	NATALYA MOROZOVA	{"phone": "+70546783335"}
0005433763590	DF073B	3774 294939	ANDREY PAVLOV	{"email": "pavlov_a08121981@postgrespro.ru", "phone": "+70154330365"}
0005433763591	DF073B	5162 450394	ALEKSEY FILIPPOV	{"phone": "+70312524717"}
0005433763592	DB598D	9762 690648	NIKOLAY PAVLOV	{"email": "n.pavlov051976@postgrespro.ru", "phone": "+70254796205"}
0005433763593	A3BD8F	4952 927296	VLADIMIR FOMIN	{"email": "fomin_v_02101972@postgrespro.ru", "phone": "+70671016519"}
0005433763594	A3BD8F	6724 459628	IGOR SAVELEV	{"email": "savelev-i18011960@postgrespro.ru", "phone": "+70485841555"}
0005433763595	E8B83D	8244 293481	VLADIMIR VOLKOV	{"phone": "+70794620658"}
0005433763596	0F59B7	6987 659441	LIDIYA NESTEROVA	{"phone": "+70999561778"}
0005433763597	0F59B7	3332 833726	ANDREY NIKITIN	{"email": "andrey-nikitin1969@postgrespro.ru", "phone": "+70140935220"}
0005433763598	8326CF	6881 625682	ANDREY NAZAROV	{"email": "nazarov.andrey.031969@postgrespro.ru", "phone": "+70280269387"}
0005433763599	8F72E5	0668 232874	LYUBOV GORBUNOVA	{"email": "gorbunova_lyubov.121950@postgrespro.ru", "phone": "+70190995000"}
0005433763600	901D3B	9267 239821	VLADIMIR KRASNOV	{"email": "krasnov-v_021968@postgrespro.ru", "phone": "+70946149809"}
0005433763601	371F5C	1130 337874	VLADIMIR NAUMOV	{"email": "vladimir.naumov1962@postgrespro.ru", "phone": "+70279626841"}
0005433763602	AD094A	6086 146936	VALERIY IVANOV	{"phone": "+70223152328"}
0005433763603	AD094A	6384 487127	NADEZHDA IVANOVA	{"email": "n.ivanova.18041978@postgrespro.ru", "phone": "+70630763853"}
0005433763604	AD094A	7613 081893	ILYA SIDOROV	{"phone": "+70169569557"}
0005433763605	C96BAD	8027 571573	MAKSIM NAZAROV	{"phone": "+70191514424"}
0005433763606	FCA418	4536 300060	IVAN KUZMIN	{"phone": "+70490766533"}
0005433763607	7F11A9	4494 455540	EKATERINA MIRONOVA	{"phone": "+70696516265"}
0005433763608	CA52AC	7258 287418	ANASTASIYA CHERNOVA	{"phone": "+70486190832"}
0005433763609	CA52AC	5749 548000	TATYANA ANTONOVA	{"phone": "+70094432811"}
0005433763610	CA52AC	2331 987304	MARIYA ZAYCEVA	{"email": "zaycevam_1991@postgrespro.ru", "phone": "+70532875993"}
0005433763611	CDB821	9211 036647	EKATERINA SAVELEVA	{"phone": "+70489463374"}
0005433763612	33B775	9490 260113	ALEKSANDR VOLKOV	{"phone": "+70272188579"}
0005433763613	33B775	4047 754443	ROMAN NAUMOV	{"email": "r-naumov_1970@postgrespro.ru", "phone": "+70250272437"}
0005433763614	FA24D0	7292 658366	LYUDMILA VOLKOVA	{"email": "volkoval.051980@postgrespro.ru", "phone": "+70397826001"}
0005433763615	2D96C5	1744 324197	VLADIMIR MEDVEDEV	{"phone": "+70910535463"}
0005433763616	2D96C5	2120 024673	SERGEY MEDVEDEV	{"email": "s-medvedev1969@postgrespro.ru", "phone": "+70894750454"}
0005433763617	EACC64	1327 044685	NIKOLAY ILIN	{"phone": "+70895673398"}
0005433763618	EACC64	6095 176224	ALEKSANDR SEMENOV	{"phone": "+70025030714"}
0005433763619	283FE0	1021 931196	LILIYA KONOVALOVA	{"email": "liliya-konovalova.16121978@postgrespro.ru", "phone": "+70849447996"}
0005433763620	4BCAF3	5596 219264	NIKITA FILIPPOV	{"phone": "+70403868079"}
0005433763621	4BCAF3	8123 713458	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr_1969@postgrespro.ru", "phone": "+70280209094"}
0005433763622	4BCAF3	4581 466002	MARINA KOLESNIKOVA	{"email": "kolesnikova.marina-10101974@postgrespro.ru", "phone": "+70544047643"}
0005433763623	A6EEB0	6423 577792	DARYA NOVIKOVA	{"email": "d.novikova-06031967@postgrespro.ru", "phone": "+70765438405"}
0005433763624	A6EEB0	2174 450106	VIKTOR PAVLOV	{"phone": "+70990500559"}
0005433763625	B38854	2924 825291	NATALYA ALEKSEEVA	{"email": "n.alekseeva.16011971@postgrespro.ru", "phone": "+70481879927"}
0005433763626	B38854	6943 834704	YAROSLAV AFANASEV	{"email": "afanasev-y-29061978@postgrespro.ru", "phone": "+70003823660"}
0005433763627	ACED1F	5501 425340	SERGEY MIRONOV	{"email": "mironov.s.02061966@postgrespro.ru", "phone": "+70133282780"}
0005433763628	ACED1F	6918 568569	NINA PAVLOVA	{"email": "npavlova121985@postgrespro.ru", "phone": "+70681512853"}
0005433763629	ACED1F	8790 286811	PAVEL BELOV	{"phone": "+70138423960"}
0005433763630	565592	7961 351906	RUSLAN KUZNECOV	{"phone": "+70053520133"}
0005433764643	A5269B	9836 695463	SERGEY PETROV	{"email": "sergeypetrov_071964@postgrespro.ru", "phone": "+70055741875"}
0005433764644	036115	7782 119840	NADEZHDA NAUMOVA	{"email": "nadezhdanaumova01011976@postgrespro.ru", "phone": "+70269517143"}
0005433764645	A03C7F	7603 453200	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov_091966@postgrespro.ru", "phone": "+70207867196"}
0005433764646	A03C7F	7902 490979	NIKOLAY SMIRNOV	{"phone": "+70744618778"}
0005433764647	D0ABBD	4170 658763	SVETLANA TIKHONOVA	{"email": "tikhonova-svetlana-1954@postgrespro.ru", "phone": "+70036057983"}
0005433764648	D0ABBD	2908 257283	NATALYA MAKAROVA	{"email": "n-makarova_071970@postgrespro.ru", "phone": "+70463252917"}
0005433764649	D0ABBD	7953 188397	NELLYA KUDRYASHOVA	{"phone": "+70774236917"}
0005433764650	101E64	4658 639590	TATYANA NIKITINA	{"email": "tnikitina13011973@postgrespro.ru", "phone": "+70750768301"}
0005433764651	DA2DAF	2502 293521	VYACHESLAV SHEVCHENKO	{"phone": "+70118976904"}
0005433764652	473FB1	6454 381474	KSENIYA ALEKSANDROVA	{"phone": "+70238364333"}
0005433764653	473FB1	7086 212816	VLADIMIR KOZLOV	{"phone": "+70415773509"}
0005433764654	3288AC	2075 044760	ARTEM KRASNOV	{"phone": "+70793633973"}
0005433764655	FD3B5D	4500 636942	MIKHAIL FEDOROV	{"email": "fedorov_mikhail101967@postgrespro.ru", "phone": "+70996735850"}
0005433764656	66B079	1410 887999	NATALYA SAVELEVA	{"email": "n-saveleva111967@postgrespro.ru", "phone": "+70520866315"}
0005433764657	66B079	9340 860707	ANNA NIKITINA	{"email": "nikitina-anna_17011976@postgrespro.ru", "phone": "+70905747209"}
0005433764658	6D507A	1144 538847	TATYANA KARPOVA	{"email": "tkarpova.06041963@postgrespro.ru", "phone": "+70241110442"}
0005433764659	FC3E2B	9648 653851	OLGA ANISIMOVA	{"email": "olgaanisimova011980@postgrespro.ru", "phone": "+70887600860"}
0005433764660	07AD55	1987 858004	ALEKSANDR BARANOV	{"email": "baranov-aleksandr_25041982@postgrespro.ru", "phone": "+70742287318"}
0005433764661	07AD55	1411 721561	SERGEY TARASOV	{"phone": "+70756997424"}
0005433764662	BB9671	9026 079962	IVAN KOZLOV	{"phone": "+70562391457"}
0005433764663	FE2BAF	0945 650643	GENNADIY KUZMIN	{"phone": "+70199321008"}
0005433764664	5872B8	7814 303349	MAYYA MASLOVA	{"email": "mmaslova_071967@postgrespro.ru", "phone": "+70941717198"}
0005433764665	5B1A38	6869 623867	VIKTOR MELNIKOV	{"email": "viktor-melnikov-1962@postgrespro.ru", "phone": "+70931990050"}
0005433764666	5B1A38	5578 710159	ANASTASIYA SCHERBAKOVA	{"phone": "+70571930073"}
0005433764667	6F506D	0707 632024	ANTONINA RYABOVA	{"phone": "+70889171197"}
0005433764668	6F506D	9134 080087	VITALIY SAVELEV	{"email": "vsavelev-1975@postgrespro.ru", "phone": "+70038440855"}
0005433764669	105E61	2233 423698	FARIDA KUZNECOVA	{"phone": "+70306248883"}
0005433764670	105E61	5088 833373	MAKSIM KUZNECOV	{"email": "kuznecovm25061967@postgrespro.ru", "phone": "+70198876351"}
0005433764671	BCB4B1	8286 256580	ELVIRA ZAYCEVA	{"email": "elvirazayceva.1972@postgrespro.ru", "phone": "+70225171974"}
0005433764672	BCB4B1	5281 733922	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova_06061979@postgrespro.ru", "phone": "+70229707536"}
0005433764673	BCB4B1	0295 361261	ALEKSANDR SIDOROV	{"phone": "+70532110503"}
0005433764674	452F2F	4533 294921	SVETLANA KOLESNIKOVA	{"email": "s-kolesnikova-091971@postgrespro.ru", "phone": "+70007265645"}
0005433764675	C3BE17	3136 700993	ALEKSANDR MAKAROV	{"phone": "+70745555703"}
0005433764676	54752C	7449 250830	SERGEY MIKHAYLOV	{"phone": "+70224181587"}
0005433764677	CC7B60	0766 327158	MAKSIM BELOV	{"phone": "+70078312818"}
0005433764678	E57C9D	4669 147274	RAISA ANDREEVA	{"email": "raisa.andreeva_1964@postgrespro.ru", "phone": "+70605134907"}
0005433764679	E57C9D	3084 192292	VALENTINA KUZNECOVA	{"email": "kuznecova_valentina101967@postgrespro.ru", "phone": "+70636172683"}
0005433764680	C67E3B	8403 743252	VITALIY ALEKSEEV	{"email": "vitaliy.alekseev14061969@postgrespro.ru", "phone": "+70614269090"}
0005433764681	5BADD4	1161 918688	GENNADIY GERASIMOV	{"phone": "+70738135134"}
0005433764682	5BADD4	4220 192040	DMITRIY FOMIN	{"email": "dmitriyfomin_011978@postgrespro.ru", "phone": "+70643466849"}
0005433764683	88A910	7967 436455	VLADIMIR SMIRNOV	{"email": "smirnovvladimir-16111975@postgrespro.ru", "phone": "+70515798598"}
0005433764684	88A910	5921 348897	ILYA SMIRNOV	{"email": "smirnov-ilya-04071979@postgrespro.ru", "phone": "+70520841550"}
0005433764685	542DB5	9442 835880	GULFIYA TARASOVA	{"email": "tarasova.g.1979@postgrespro.ru", "phone": "+70838124314"}
0005433764686	EDD01C	2281 016351	SERGEY SHEVCHENKO	{"email": "sergey.shevchenko_071964@postgrespro.ru", "phone": "+70423956111"}
0005433764687	EDD01C	0861 697599	ELVIRA SCHERBAKOVA	{"email": "scherbakovae.1977@postgrespro.ru", "phone": "+70010038278"}
0005433764688	491B1B	0135 964857	VALERIY IVANOV	{"email": "v_ivanov.121979@postgrespro.ru", "phone": "+70226056104"}
0005433764689	260D61	7033 210125	EKATERINA KOVALEVA	{"phone": "+70387409019"}
0005433764690	154A99	0438 770299	ALEKSEY DMITRIEV	{"phone": "+70320775183"}
0005433764691	154A99	1561 613201	FARIDA ZAYCEVA	{"phone": "+70075568649"}
0005433764692	B6ADF0	6433 146157	MARIYA KRASNOVA	{"email": "krasnova_m1976@postgrespro.ru", "phone": "+70022921007"}
0005433764693	07B803	2831 054178	LYUBOV ZHUKOVA	{"phone": "+70475963236"}
0005433764694	93D50E	2576 764218	GALINA STEPANOVA	{"email": "g-stepanova1976@postgrespro.ru", "phone": "+70339063541"}
0005433764695	2F7967	8200 837294	KONSTANTIN TIMOFEEV	{"phone": "+70461067846"}
0005433764696	691451	5724 020883	YULIYA KOROLEVA	{"phone": "+70732099178"}
0005433764697	91F05A	5236 750153	VIKTOR BONDARENKO	{"email": "bondarenko-v27011975@postgrespro.ru", "phone": "+70660486942"}
0005433764698	91F05A	1498 926633	NADEZHDA VOLKOVA	{"phone": "+70564900774"}
0005433764699	851259	2394 716661	EVGENIYA MOROZOVA	{"phone": "+70609249612"}
0005433764700	851259	2010 889637	ELENA RODIONOVA	{"email": "e-rodionova.1980@postgrespro.ru", "phone": "+70047191380"}
0005433764701	AF5487	8668 229348	GENNADIY MIRONOV	{"email": "g_mironov-12011981@postgrespro.ru", "phone": "+70985750269"}
0005433764702	AF5487	7331 233291	DMITRIY NAUMOV	{"email": "naumov_d_051976@postgrespro.ru", "phone": "+70036746086"}
0005433764703	576775	4665 405912	ANASTASIYA MAKAROVA	{"phone": "+70534009836"}
0005433764704	88AE43	9949 793730	ELENA PAVLOVA	{"email": "elena.pavlova1980@postgrespro.ru", "phone": "+70002039687"}
0005433764705	88AE43	5643 246291	NIKOLAY SHEVCHENKO	{"email": "nshevchenko27021971@postgrespro.ru", "phone": "+70358141855"}
0005433764706	88AE43	8564 900499	DMITRIY SCHERBAKOV	{"email": "scherbakov-d-111978@postgrespro.ru", "phone": "+70066273867"}
0005433764707	2276C3	1117 664933	VADIM MAKSIMOV	{"email": "maksimov.vadim-061983@postgrespro.ru", "phone": "+70104794716"}
0005433764708	FCBC66	2562 201199	OKSANA FEDOROVA	{"email": "fedorova_oksana.061970@postgrespro.ru", "phone": "+70343132400"}
0005433764709	59350E	3215 689433	VARVARA ZAKHAROVA	{"phone": "+70571588433"}
0005433764710	59350E	1138 003734	IRINA VASILEVA	{"phone": "+70379619925"}
0005433764711	9350DA	4238 017159	NIKOLAY MEDVEDEV	{"phone": "+70392626626"}
0005433764712	DF5682	5644 405351	TATYANA VASILEVA	{"email": "tatyana_vasileva_28101965@postgrespro.ru", "phone": "+70583049039"}
0005433764713	E9DF8D	7358 316063	SERGEY CHERNOV	{"phone": "+70802471995"}
0005433764714	302773	4369 897191	VIKTOR BELOV	{"email": "belov.viktor09091972@postgrespro.ru", "phone": "+70029378624"}
0005433764715	87DA7B	4585 225702	MARINA FEDOROVA	{"email": "fedorovam_24111977@postgrespro.ru", "phone": "+70748251769"}
0005433764716	811F23	1974 052876	YULIYA ALEKSANDROVA	{"email": "yaleksandrova24031965@postgrespro.ru", "phone": "+70614040766"}
0005433764717	811F23	5748 918049	GENNADIY NIKOLAEV	{"email": "nikolaev.gennadiy.1967@postgrespro.ru", "phone": "+70459710194"}
0005433764718	96B6F6	6006 419300	VLADISLAV SAVELEV	{"email": "v_savelev.24061965@postgrespro.ru", "phone": "+70227866193"}
0005433764719	D745D5	7214 997170	ALEKSANDR EGOROV	{"phone": "+70805283493"}
0005433764720	D745D5	3344 905314	ANDREY KOROLEV	{"email": "andrey.korolev_1974@postgrespro.ru", "phone": "+70705251173"}
0005433764721	E3A2DA	7662 986474	ANNA SOLOVEVA	{"phone": "+70263108763"}
0005433764722	0D5D94	4198 961622	ANASTASIYA MAKAROVA	{"phone": "+70621055360"}
0005433764723	6EB787	7158 755566	ELENA FEDOROVA	{"phone": "+70639974338"}
0005433764724	D926B5	5069 800459	EKATERINA TROFIMOVA	{"email": "ekaterina.trofimova27121969@postgrespro.ru", "phone": "+70468077827"}
0005433764725	9C333D	4616 250165	TATYANA BELOVA	{"email": "tatyanabelova_061986@postgrespro.ru", "phone": "+70619859141"}
0005433764726	9C333D	6338 715350	VERONIKA EGOROVA	{"email": "egorova_v.1970@postgrespro.ru", "phone": "+70205474703"}
0005433764727	389E67	5924 647029	MIKHAIL NIKITIN	{"phone": "+70180546133"}
0005433764728	84036D	5699 441168	MARIYA RODIONOVA	{"email": "rodionova-mariya.22091961@postgrespro.ru", "phone": "+70231921207"}
0005433764729	BD5EA3	4024 260826	NIKITA ANDREEV	{"email": "nikitaandreev.1970@postgrespro.ru", "phone": "+70613675164"}
0005433764730	27C543	1157 876131	NADEZHDA NIKITINA	{"email": "nadezhdanikitina-061968@postgrespro.ru", "phone": "+70600129025"}
0005433764731	27C543	9874 245108	OLESYA FROLOVA	{"phone": "+70435151167"}
0005433764732	49F6BD	7114 356068	ANNA ISAEVA	{"email": "aisaeva_1964@postgrespro.ru", "phone": "+70947262717"}
0005433764733	934CDD	5115 462928	YAKOV DMITRIEV	{"email": "dmitriev.yakov_1972@postgrespro.ru", "phone": "+70394039217"}
0005433764734	9679B8	9124 238248	IRINA NESTEROVA	{"phone": "+70526241234"}
0005433764735	D098D5	8848 790380	NATALYA PAVLOVA	{"phone": "+70393108644"}
0005433766660	8CEFE1	9217 127253	OLGA ABRAMOVA	{"phone": "+70720919499"}
0005433766572	E04DA0	1021 041278	ZHANNA MEDVEDEVA	{"email": "zmedvedeva.031980@postgrespro.ru", "phone": "+70777367442"}
0005433766573	574AC7	3779 370300	IRINA VOROBEVA	{"phone": "+70720262112"}
0005433766574	574AC7	0053 854340	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_valentina.091976@postgrespro.ru", "phone": "+70548019270"}
0005433766575	574AC7	6405 290105	LYUDMILA SIDOROVA	{"phone": "+70197256392"}
0005433766576	045B1F	4145 007929	ANASTASIYA VOROBEVA	{"email": "anastasiya-vorobeva-101972@postgrespro.ru", "phone": "+70948640705"}
0005433766577	CE8084	4879 091137	ELENA MOROZOVA	{"phone": "+70700906598"}
0005433766578	CE8084	5896 153522	IRINA CHERNOVA	{"email": "i.chernova_021970@postgrespro.ru", "phone": "+70757012712"}
0005433766579	A49BF9	8213 253702	OLGA POLYAKOVA	{"email": "olga_polyakova-19121965@postgrespro.ru", "phone": "+70166059953"}
0005433766580	A49BF9	3973 165626	OLEG GORBUNOV	{"phone": "+70577256148"}
0005433766581	EA02B2	0803 880281	LYUDMILA ALEKSANDROVA	{"phone": "+70621518704"}
0005433766582	4AD57B	3294 280705	EVGENIYA IVANOVA	{"email": "ivanovaevgeniya.19071963@postgrespro.ru", "phone": "+70097055970"}
0005433766583	E801E6	7936 431673	OKSANA RODIONOVA	{"email": "rodionova_oksana1970@postgrespro.ru", "phone": "+70177038204"}
0005433766584	E801E6	4672 990864	RINAT SEMENOV	{"email": "semenov.r1969@postgrespro.ru", "phone": "+70661547739"}
0005433766585	50D266	6976 656593	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr.041972@postgrespro.ru", "phone": "+70861711094"}
0005433766586	AEC2EA	6256 886442	MARIYA IVANOVA	{"email": "mariyaivanova20071968@postgrespro.ru", "phone": "+70883798234"}
0005433766587	C934A3	4129 742261	ANNA NIKOLAEVA	{"phone": "+70625406746"}
0005433766588	C05061	6542 753407	LYUDMILA NIKITINA	{"email": "nikitina_lyudmila_011962@postgrespro.ru", "phone": "+70306945675"}
0005433766589	C05061	3691 256292	LYUDMILA LEBEDEVA	{"email": "lebedeva_l.031972@postgrespro.ru", "phone": "+70233703019"}
0005433766590	23C8C1	0633 319468	GENNADIY MIRONOV	{"email": "mironov.gennadiy-31011963@postgrespro.ru", "phone": "+70665219432"}
0005433766591	7EBAEE	6764 696906	NATALYA GERASIMOVA	{"email": "n-gerasimova1959@postgrespro.ru", "phone": "+70320442903"}
0005433766592	7EBAEE	9240 701083	NATALYA KULIKOVA	{"phone": "+70634634575"}
0005433766593	C86B19	8186 026408	VALENTIN KARPOV	{"phone": "+70915458267"}
0005433766594	3C4B8F	9279 887740	NATALYA RYABOVA	{"email": "n-ryabova091960@postgrespro.ru", "phone": "+70703605935"}
0005433766595	806DCC	0568 467189	SERGEY KUDRYASHOV	{"email": "sergey.kudryashov031966@postgrespro.ru", "phone": "+70740550159"}
0005433766596	A84822	0644 573402	SERGEY MATVEEV	{"phone": "+70227403591"}
0005433766597	CC912D	8902 115287	DENIS TIMOFEEV	{"phone": "+70102187685"}
0005433766598	625F1B	8939 308022	NATALYA EGOROVA	{"phone": "+70242166864"}
0005433766599	7E459F	9804 668950	EVGENIY OSIPOV	{"email": "evgeniy_osipov041970@postgrespro.ru", "phone": "+70536084285"}
0005433766600	F3898D	0649 167732	SERGEY KUZNECOV	{"email": "sergey.kuznecov03101967@postgrespro.ru", "phone": "+70872389446"}
0005433766601	B13339	2332 673023	VYACHESLAV SERGEEV	{"phone": "+70302805944"}
0005433766602	3B7224	9619 443923	VERA TIMOFEEVA	{"email": "timofeeva-vera-1974@postgrespro.ru", "phone": "+70499896786"}
0005433766603	CDF950	7911 022863	ALENA SMIRNOVA	{"phone": "+70320448997"}
0005433766604	CDF950	3008 471735	ANDREY IVANOV	{"email": "ivanov-andrey-081986@postgrespro.ru", "phone": "+70982959786"}
0005433766605	CDF950	3790 491893	YURIY MAKAROV	{"phone": "+70319016535"}
0005433766606	4B662B	4676 530419	OLGA KOLESNIKOVA	{"email": "kolesnikovaolga1972@postgrespro.ru", "phone": "+70051679105"}
0005433766607	4B662B	1937 617639	VITALIY PAVLOV	{"phone": "+70121354953"}
0005433766608	84323A	4517 799951	DARYA MEDVEDEVA	{"email": "darya-medvedeva-011963@postgrespro.ru", "phone": "+70735412542"}
0005433766609	BDB75B	2912 593664	NIKOLAY TIKHONOV	{"email": "tikhonov-nikolay03111973@postgrespro.ru", "phone": "+70784352993"}
0005433766610	BAB5A7	4292 510428	PAVEL PETROV	{"phone": "+70050120520"}
0005433766611	89B14A	2217 941278	IVAN KISELEV	{"email": "kiselev-i_24101958@postgrespro.ru", "phone": "+70057593622"}
0005433766612	3A00D4	8898 147415	MARINA ALEKSANDROVA	{"phone": "+70373290928"}
0005433766613	2F000A	8455 104926	NIKITA VOLKOV	{"phone": "+70430496010"}
0005433766614	0B5E5C	8273 520514	TAMARA ZOTOVA	{"phone": "+70658455613"}
0005433766615	4309E3	7158 809792	VLADISLAV TARASOV	{"email": "vtarasov_17101979@postgrespro.ru", "phone": "+70915485090"}
0005433766616	4309E3	6521 550077	YURIY SOKOLOV	{"phone": "+70315248566"}
0005433766617	A66F76	7807 012895	ANDREY ANDREEV	{"email": "andrey.andreev-16091976@postgrespro.ru", "phone": "+70357278326"}
0005433766618	D83E4A	1338 027862	LILIYA STEPANOVA	{"email": "liliya-stepanova.15041963@postgrespro.ru", "phone": "+70549694856"}
0005433766619	D2EE60	4848 656104	NATALYA OSIPOVA	{"phone": "+70755562873"}
0005433766620	D2EE60	3098 974120	ANTON KONOVALOV	{"email": "konovalov_anton021972@postgrespro.ru", "phone": "+70814906070"}
0005433766621	8A7109	3574 683913	SVETLANA SOLOVEVA	{"phone": "+70667554077"}
0005433766622	8A7109	2007 418071	LIDIYA BELYAEVA	{"phone": "+70817318934"}
0005433766623	FD17B2	7230 583691	NATALYA MOISEEVA	{"email": "natalya.moiseeva011976@postgrespro.ru", "phone": "+70997488252"}
0005433766624	648740	2672 538820	VITALIY ZAKHAROV	{"phone": "+70450598136"}
0005433766625	BE5E5A	0023 380946	LYUDMILA ANDREEVA	{"phone": "+70990186759"}
0005433766626	F6AB9F	4190 033587	ALEKSANDR IVANOV	{"email": "ivanov.a_31031983@postgrespro.ru", "phone": "+70391994194"}
0005433766627	F6AB9F	8452 676715	TATYANA ANTONOVA	{"email": "antonova.t_28091978@postgrespro.ru", "phone": "+70572930665"}
0005433766628	842DBE	9599 817462	RAISA ANDREEVA	{"email": "raisaandreeva_041980@postgrespro.ru", "phone": "+70395946492"}
0005433766629	05867D	3770 203996	SERGEY BARANOV	{"email": "baranov-sergey23011969@postgrespro.ru", "phone": "+70354392246"}
0005433766630	ED911B	5497 979692	TAMARA KUZNECOVA	{"email": "t.kuznecova20091971@postgrespro.ru", "phone": "+70016802411"}
0005433766631	54AD1F	6920 719622	IRINA SCHERBAKOVA	{"email": "i.scherbakova-1967@postgrespro.ru", "phone": "+70340283953"}
0005433766632	54AD1F	4074 313885	VLADIMIR ANDREEV	{"email": "andreev.v-061973@postgrespro.ru", "phone": "+70767609180"}
0005433766633	67ABE0	3089 533982	ALEKSEY GUSEV	{"phone": "+70840776530"}
0005433766634	67ABE0	3862 604992	ANDREY KUZNECOV	{"phone": "+70790729650"}
0005433766635	ACD1AD	1748 683114	VIKTOR KUZMIN	{"phone": "+70314262051"}
0005433766636	14B846	9723 431385	ALEKSANDR PETROV	{"email": "a_petrov_13031967@postgrespro.ru", "phone": "+70128103959"}
0005433766637	14B846	2860 025864	FARID POPOV	{"phone": "+70451269956"}
0005433766638	51BCC9	1842 146942	POLINA ERMAKOVA	{"phone": "+70305234021"}
0005433766639	50CDBB	6734 333075	KARINA BORISOVA	{"email": "kborisova_111966@postgrespro.ru", "phone": "+70648208959"}
0005433766640	50CDBB	6918 822998	OLGA SAVELEVA	{"email": "osaveleva_1964@postgrespro.ru", "phone": "+70748206558"}
0005433766641	67ABC7	2619 188857	OKSANA POPOVA	{"email": "oksana-popova-1968@postgrespro.ru", "phone": "+70859186352"}
0005433766642	8901BA	8686 040041	SVETLANA YUDINA	{"phone": "+70073959849"}
0005433766643	400EBF	0613 718967	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr_1969@postgrespro.ru", "phone": "+70790243524"}
0005433766644	400EBF	6103 676314	GENNADIY NIKOLAEV	{"phone": "+70636190064"}
0005433766645	D9EF07	5023 762555	SERGEY VOLKOV	{"email": "sergey_volkov15071976@postgrespro.ru", "phone": "+70736950303"}
0005433766646	D9EF07	5006 473760	NAIL PAVLOV	{"phone": "+70915559816"}
0005433766647	44FC46	9906 874535	OLGA KOZLOVA	{"email": "olga-kozlova1965@postgrespro.ru", "phone": "+70124598233"}
0005433766648	BCF581	0341 325312	ANNA FEDOROVA	{"phone": "+70713983522"}
0005433766649	BCF581	8220 168420	OLEG VOLKOV	{"phone": "+70775819000"}
0005433766650	DF23D4	7852 266854	DMITRIY ISAEV	{"phone": "+70233020172"}
0005433766651	DF23D4	9816 596854	VLADISLAV ROMANOV	{"phone": "+70568931287"}
0005433766652	327CF9	3570 990789	ANASTASIYA VOLKOVA	{"email": "volkova.a101967@postgrespro.ru", "phone": "+70161788724"}
0005433766653	117FC8	2430 941449	DMITRIY FOMIN	{"email": "fomin.dmitriy_1971@postgrespro.ru", "phone": "+70007636211"}
0005433766654	E6E51E	6661 159676	IGOR SMIRNOV	{"email": "smirnov_igor.1969@postgrespro.ru", "phone": "+70816688729"}
0005433766655	E6E51E	9130 927839	DARYA IVANOVA	{"email": "divanova-1960@postgrespro.ru", "phone": "+70984953626"}
0005433766656	8E1D96	0353 657575	TATYANA KISELEVA	{"email": "kiseleva-t-12081975@postgrespro.ru", "phone": "+70998006688"}
0005433766657	A1B798	4564 235173	GALINA KUZNECOVA	{"email": "g.kuznecova.1972@postgrespro.ru", "phone": "+70326033402"}
0005433766658	A1B798	0516 627006	ANASTASIYA SCHERBAKOVA	{"phone": "+70594072329"}
0005433766659	8CEFE1	0471 382596	NINA FROLOVA	{"email": "n.frolova_16081975@postgrespro.ru", "phone": "+70774356716"}
0005433766661	E6945D	5542 098269	IRINA NESTEROVA	{"email": "nesterova-irina.101974@postgrespro.ru", "phone": "+70934374365"}
0005433766662	CFA697	6483 682387	ELENA DENISOVA	{"email": "denisova-e_081959@postgrespro.ru", "phone": "+70374884186"}
0005433766663	E02DA0	7517 470054	ELENA SERGEEVA	{"email": "e.sergeeva_1980@postgrespro.ru", "phone": "+70554557817"}
0005433766664	E02DA0	1238 785497	GENNADIY DENISOV	{"phone": "+70458618567"}
0005433766665	3A3EB9	4923 310038	STEPAN SEMENOV	{"email": "semenov-s1974@postgrespro.ru", "phone": "+70187776568"}
0005433766666	08F7A0	4793 181109	ELENA KAZAKOVA	{"phone": "+70216015336"}
0005433766667	08F7A0	6268 401318	ANNA CHERNOVA	{"email": "anna.chernova_27101963@postgrespro.ru", "phone": "+70622577198"}
0005433766668	4D2EC1	0201 879619	ALEKSANDR BARANOV	{"phone": "+70461192875"}
0005433766669	A873CD	3244 573755	MIKHAIL GUSEV	{"phone": "+70151135664"}
0005433766670	8DEB58	4982 092814	VIKTOR NIKITIN	{"email": "nikitin_viktor-1969@postgrespro.ru", "phone": "+70339267222"}
0005433766671	8DEB58	1765 647300	OLEG PAVLOV	{"email": "pavlov-o.101956@postgrespro.ru", "phone": "+70139596985"}
0005433766672	BD473D	1250 678274	ZAKHAR SAVELEV	{"phone": "+70183648521"}
0005433766673	FD434E	6284 658040	LYUBOV ROMANOVA	{"email": "l-romanova-12041969@postgrespro.ru", "phone": "+70856825493"}
0005433766674	A16761	5358 184654	ELENA PAVLOVA	{"email": "epavlova-1959@postgrespro.ru", "phone": "+70600273440"}
0005433766675	32D2AE	5701 062390	TATYANA PETROVA	{"phone": "+70045776506"}
0005433766676	8814F0	3059 585119	VLADIMIR ANTONOV	{"phone": "+70720376544"}
0005433766677	8814F0	7142 239192	ANATOLIY VASILEV	{"email": "anatoliy-vasilev_25071978@postgrespro.ru", "phone": "+70198112796"}
0005433766678	7132A9	2149 695018	LARISA BOGDANOVA	{"phone": "+70045890624"}
0005433766679	6766A7	1264 905681	TATYANA EFREMOVA	{"email": "efremova-tatyana061965@postgrespro.ru", "phone": "+70072735839"}
0005433766680	6766A7	7949 754968	TAMARA CHERNOVA	{"email": "t_chernova-1961@postgrespro.ru", "phone": "+70583113892"}
0005433766681	241573	1805 481578	YURIY GUSEV	{"email": "y.gusev_1976@postgrespro.ru", "phone": "+70816074211"}
0005433766682	3B3708	0606 394210	ZINAIDA SMIRNOVA	{"email": "smirnova_zinaida.091971@postgrespro.ru", "phone": "+70597448321"}
0005433766683	239C03	0395 208091	DMITRIY DENISOV	{"email": "denisov.d07061976@postgrespro.ru", "phone": "+70024366833"}
0005433766684	0F18DB	5097 386880	RENAT SEMENOV	{"email": "renat_semenov.1975@postgrespro.ru", "phone": "+70326268911"}
0005433766685	0F18DB	3393 526777	IRINA KOVALEVA	{"phone": "+70607061180"}
0005433766686	291CB0	4249 615551	TATYANA KULIKOVA	{"phone": "+70855212029"}
0005433766687	912823	2234 167333	GULNARA VASILEVA	{"phone": "+70613251574"}
0005433766688	CDDE25	4744 266937	NINA KUZNECOVA	{"email": "kuznecova-nina.111973@postgrespro.ru", "phone": "+70937978741"}
0005433766689	CDDE25	8228 241157	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev.011965@postgrespro.ru", "phone": "+70101750261"}
0005433766690	C45602	5022 783852	MARINA BORISOVA	{"email": "borisovam-1972@postgrespro.ru", "phone": "+70302601379"}
0005433766691	D81E2A	9110 203679	ANATOLIY ANDREEV	{"email": "andreeva_041974@postgrespro.ru", "phone": "+70384949680"}
0005433766692	4B18D1	3597 270009	TATYANA ANISIMOVA	{"email": "t-anisimova1967@postgrespro.ru", "phone": "+70762849950"}
0005433766693	4B18D1	8766 955942	DMITRIY SMIRNOV	{"email": "smirnov.d.061976@postgrespro.ru", "phone": "+70215447352"}
0005433766694	538EAC	6941 490613	ANTONINA GORBUNOVA	{"phone": "+70425738021"}
0005433766695	3B0A61	1725 450429	RAISA MAKAROVA	{"email": "r_makarova1974@postgrespro.ru", "phone": "+70720940617"}
0005433766696	3B0A61	7469 471410	TAMARA BELYAEVA	{"email": "belyaeva-t_1974@postgrespro.ru", "phone": "+70334024787"}
0005433766697	998E76	2499 655852	ALBERT KOROLEV	{"phone": "+70487658760"}
0005433766698	998E76	4832 811504	ANNA LAZAREVA	{"email": "lazareva_anna_05021991@postgrespro.ru", "phone": "+70726862111"}
0005433766699	998E76	8554 149770	LYUDMILA KISELEVA	{"phone": "+70387098350"}
0005433766700	C006D2	7653 382724	ALI GAVRILOV	{"email": "gavrilovali-19081975@postgrespro.ru", "phone": "+70182360310"}
0005433766701	C006D2	1193 290155	ZHANNA SAVELEVA	{"email": "savelevazhanna11021962@postgrespro.ru", "phone": "+70946509314"}
0005433766702	67CF7E	1068 207895	NATALYA VASILEVA	{"email": "natalya.vasileva-1970@postgrespro.ru", "phone": "+70449993481"}
0005433766703	6AD0B4	1643 986233	ANDREY SOKOLOV	{"email": "sokolov_andrey.1971@postgrespro.ru", "phone": "+70070575937"}
0005433766704	AAE771	4879 302053	ARTEM ZAKHAROV	{"phone": "+70053044451"}
0005433766705	52001B	7554 378365	SVETLANA SIDOROVA	{"email": "svetlana-sidorova.10041977@postgrespro.ru", "phone": "+70511632072"}
0005433766706	52001B	1968 641395	NINA CHERNOVA	{"email": "chernova.nina-21061974@postgrespro.ru", "phone": "+70965878696"}
0005433766707	FF35B7	4560 742177	SERGEY ALEKSANDROV	{"phone": "+70016099372"}
0005433766708	FF35B7	6081 762599	NIKOLAY FROLOV	{"email": "frolov_n021969@postgrespro.ru", "phone": "+70172402666"}
0005433766709	FF35B7	0962 637076	VALENTIN VOROBEV	{"email": "vorobevvalentin-11051968@postgrespro.ru", "phone": "+70559587048"}
0005433766710	38039A	9006 168938	TATYANA KUDRYASHOVA	{"email": "tatyana_kudryashova_18021980@postgrespro.ru", "phone": "+70735878439"}
0005433766711	B7C511	4056 646619	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr.1982@postgrespro.ru", "phone": "+70670628920"}
0005433766712	EF1924	4060 605293	NIKOLAY PAVLOV	{"phone": "+70703817181"}
0005433766713	C01B14	5217 505745	SNEZHANA MATVEEVA	{"phone": "+70787509390"}
0005433766714	75CEC3	1877 880408	ALEKSEY ZAKHAROV	{"phone": "+70541947633"}
0005433766715	75CEC3	0704 755339	MAKSIM KUZMIN	{"email": "kuzmin.m.06121981@postgrespro.ru", "phone": "+70340621628"}
0005433766716	5CB215	2791 273886	DMITRIY RODIONOV	{"email": "dmitriy_rodionov-03021973@postgrespro.ru", "phone": "+70498890420"}
0005433766717	BC06C6	5050 501871	TIKHON NAZAROV	{"email": "nazarov_tikhon011972@postgrespro.ru", "phone": "+70433525802"}
0005433766718	5AE90B	2018 338828	IDA ANTONOVA	{"phone": "+70862973611"}
0005433766719	0C9EC7	8026 503162	VALERIY KUZMIN	{"phone": "+70338778332"}
0005433766720	EDBE56	3490 568422	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda061972@postgrespro.ru", "phone": "+70060631659"}
0005433766721	2162A9	7989 921932	NIKITA MELNIKOV	{"email": "nmelnikov_121978@postgrespro.ru", "phone": "+70048974213"}
0005433766722	D5832F	8313 318476	MARIYA ALEKSANDROVA	{"phone": "+70359478469"}
0005433766723	FCE039	1836 884917	KAPITALINA DENISOVA	{"email": "denisovakapitalina_28111967@postgrespro.ru", "phone": "+70218688492"}
0005433766724	E743A9	6913 919233	PAVEL SOKOLOV	{"phone": "+70629289657"}
0005433766725	C16FBE	8776 940304	NATALYA SOROKINA	{"phone": "+70442722870"}
0005433766726	C16FBE	9710 189946	MARIYA LOGINOVA	{"email": "m.loginova071975@postgrespro.ru", "phone": "+70222543143"}
0005433766727	C16FBE	4165 069820	GALINA KUDRYASHOVA	{"email": "g-kudryashova_041973@postgrespro.ru", "phone": "+70595989816"}
0005433766728	DBAB78	4979 871342	NIKOLAY KRASNOV	{"phone": "+70166273396"}
0005433766729	DBAB78	9273 402580	EKATERINA MEDVEDEVA	{"email": "medvedevae_1963@postgrespro.ru", "phone": "+70265608315"}
0005433766730	C076D9	5926 944380	ILYA SOROKIN	{"phone": "+70038133456"}
0005433766731	C3AD8D	3113 591291	ANASTASIYA IVANOVA	{"email": "a-ivanova29111961@postgrespro.ru", "phone": "+70547554210"}
0005433766732	C3AD8D	5268 632454	EVGENIYA KUZNECOVA	{"email": "kuznecova_evgeniya_111972@postgrespro.ru", "phone": "+70909323329"}
0005433766733	75E4A2	6489 929475	ALEKSEY SCHERBAKOV	{"email": "scherbakov_a.1988@postgrespro.ru", "phone": "+70670131454"}
0005433766734	75E4A2	3814 960022	KIRILL NIKOLAEV	{"email": "k-nikolaev1972@postgrespro.ru", "phone": "+70826621408"}
0005433766735	75E4A2	0906 537153	VLADIMIR ALEKSANDROV	{"phone": "+70884494285"}
0005433766736	223E63	6436 721135	OLGA SEMENOVA	{"email": "semenova_o-02011965@postgrespro.ru", "phone": "+70820029905"}
0005433766737	92D1F7	8522 564128	NATALYA OSIPOVA	{"phone": "+70736603229"}
0005433766738	B0C291	0310 377428	ILNUR IVANOV	{"phone": "+70257184112"}
0005433766739	9B294B	4731 486603	YURIY KUZNECOV	{"phone": "+70688715219"}
0005433766740	9B294B	6953 886861	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov-25101974@postgrespro.ru", "phone": "+70457952121"}
0005433766741	AFD4A4	4820 527812	MARIANNA TROFIMOVA	{"phone": "+70605568764"}
0005433766742	29722F	3815 507793	ALEKSANDR IVANOV	{"email": "aleksandrivanov1954@postgrespro.ru", "phone": "+70714656890"}
0005433766743	BA6426	6608 044798	NIKOLAY SOKOLOV	{"email": "nikolay.sokolov23091965@postgrespro.ru", "phone": "+70641383417"}
0005433766744	BA6426	9645 543517	IRINA ANTONOVA	{"phone": "+70163882501"}
0005433766745	D0B353	6198 329857	ANDREY ABRAMOV	{"email": "aabramov.1962@postgrespro.ru", "phone": "+70715058907"}
0005433766746	3F93E3	5464 727104	NATALYA ZAYCEVA	{"email": "zaycevan.1971@postgrespro.ru", "phone": "+70181824066"}
0005433766747	32E4C6	9908 637156	VIKTOR NOVIKOV	{"phone": "+70979673813"}
0005433766748	E17918	6858 231206	IRINA ANTONOVA	{"phone": "+70042392804"}
0005433766749	E17918	8998 204666	ILYA GAVRILOV	{"email": "ilyagavrilov11091965@postgrespro.ru", "phone": "+70202438503"}
0005433766750	36EBDC	4671 425051	TATYANA NIKOLAEVA	{"phone": "+70922484474"}
0005433766751	B589FD	7201 086833	YURIY ZAYCEV	{"email": "zaycevy021971@postgrespro.ru", "phone": "+70831975773"}
0005433766752	B57F21	0467 948733	SERGEY PAVLOV	{"email": "sergey-pavlov-15091974@postgrespro.ru", "phone": "+70507372919"}
0005433766753	87A38C	7197 651552	NATALYA NAZAROVA	{"email": "nazarova-n_21021974@postgrespro.ru", "phone": "+70936433541"}
0005433766754	0C024F	3338 915483	TAMARA SOROKINA	{"email": "tamara.sorokina031972@postgrespro.ru", "phone": "+70867927748"}
0005433766755	0C024F	7698 367616	LIDIYA FILATOVA	{"email": "filatova.lidiya.011978@postgrespro.ru", "phone": "+70642484125"}
0005433766756	2E6A21	8801 856873	MARAT BARANOV	{"email": "maratbaranov_091978@postgrespro.ru", "phone": "+70529326876"}
0005433766757	322B25	7097 183913	OLGA FILIPPOVA	{"email": "olgafilippova_081978@postgrespro.ru", "phone": "+70414892756"}
0005433766758	75A31C	1283 669727	YURIY SAVELEV	{"email": "y-savelev_021967@postgrespro.ru", "phone": "+70780043347"}
0005433766759	75A31C	6347 500026	ALINA ILINA	{"email": "ilina-alina_051968@postgrespro.ru", "phone": "+70648413867"}
0005433766760	75A31C	3810 745614	ALEKSANDR MOROZOV	{"phone": "+70880319450"}
0005433766761	1EBE9A	0006 765631	ELENA VASILEVA	{"phone": "+70310713716"}
0005433766762	29812B	9388 457288	VERA KUZMINA	{"phone": "+70058693832"}
0005433766763	29812B	9673 521385	LYUDMILA DANILOVA	{"phone": "+70519530704"}
0005433766764	24D810	1153 693722	VLADIMIR MOISEEV	{"email": "vladimirmoiseev1973@postgrespro.ru", "phone": "+70690886727"}
0005433766765	4FB7B6	8975 756571	ALEKSANDR SERGEEV	{"phone": "+70277733646"}
0005433766766	4FB7B6	9173 748136	TAISIYA KOZLOVA	{"phone": "+70925827053"}
0005433766767	DF1661	6706 554336	ANGELINA KUDRYASHOVA	{"email": "angelina-kudryashova_1976@postgrespro.ru", "phone": "+70299065742"}
0005433766768	F88101	4993 858123	ANNA KARPOVA	{"email": "anna_karpova_1978@postgrespro.ru", "phone": "+70556309399"}
0005433784329	6E7F4A	1547 735148	MIKHAIL KISELEV	{"phone": "+70542366221"}
0005433784292	2DE2CB	3231 344423	RINAT YAKOVLEV	{"phone": "+70581624284"}
0005433784293	5C43DB	7015 192359	VLADISLAV KUZNECOV	{"email": "vladislav-kuznecov.1982@postgrespro.ru", "phone": "+70821166818"}
0005433784294	5C43DB	5085 991218	LYUDMILA ILINA	{"phone": "+70561436932"}
0005433784295	5C43DB	6977 143621	TAMARA YAKOVLEVA	{"email": "tyakovleva_12061975@postgrespro.ru", "phone": "+70228402498"}
0005433784296	23CB72	5541 486969	ALEKSEY KISELEV	{"email": "aleksey.kiselev-1967@postgrespro.ru", "phone": "+70168037079"}
0005433784297	1CD4FC	6753 972568	ELENA BELOVA	{"email": "elena-belova.17111955@postgrespro.ru", "phone": "+70305726484"}
0005433784298	1CD4FC	9169 339651	DARYA KRASNOVA	{"phone": "+70968086964"}
0005433784299	BC21B0	2369 932671	EKATERINA KOROLEVA	{"email": "ekaterina.koroleva.1967@postgrespro.ru", "phone": "+70409712091"}
0005433784300	E4252A	4296 228968	EVGENIY MATVEEV	{"phone": "+70797013476"}
0005433784301	E79FD2	1192 956038	KARINA POTAPOVA	{"phone": "+70863754551"}
0005433784302	90DB58	8976 376541	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov_25111970@postgrespro.ru", "phone": "+70125276784"}
0005433784303	9E09A2	7533 850789	VALERIY MOROZOV	{"email": "morozov-valeriy_1969@postgrespro.ru", "phone": "+70733764839"}
0005433784304	9E09A2	3729 421351	OLGA IVANOVA	{"phone": "+70697408957"}
0005433784305	507591	7801 288140	OLGA GAVRILOVA	{"phone": "+70695179672"}
0005433784306	3E50E5	8475 697013	OKSANA VASILEVA	{"phone": "+70503651015"}
0005433784307	0B2BA7	8346 613721	NINA AKIMOVA	{"email": "akimova-n.14091981@postgrespro.ru", "phone": "+70241651676"}
0005433784308	9ECE5B	9437 929623	ALEKSANDR POPOV	{"email": "popov-a-051975@postgrespro.ru", "phone": "+70664464651"}
0005433784309	FDDE69	9686 054871	VYACHESLAV ZAYCEV	{"phone": "+70189078009"}
0005433784310	DC5456	6483 330766	ASIYA BARANOVA	{"phone": "+70386924796"}
0005433784311	DC5456	7881 557034	YULIYA NIKOLAEVA	{"phone": "+70178041520"}
0005433784312	CBBCAF	2423 877360	OLGA ABRAMOVA	{"email": "oabramova1967@postgrespro.ru", "phone": "+70900117926"}
0005433784313	802CBF	8651 244155	NINA DAVYDOVA	{"phone": "+70425038400"}
0005433784314	802CBF	0805 603302	POLINA SCHERBAKOVA	{"email": "polinascherbakova-1970@postgrespro.ru", "phone": "+70265276190"}
0005433784315	802CBF	1260 695197	LYUDMILA IVANOVA	{"phone": "+70423943556"}
0005433784316	7A0780	3951 273237	NINA KOROLEVA	{"phone": "+70031468941"}
0005433784317	11D428	9909 567653	ALEKSEY SHEVCHENKO	{"phone": "+70258241572"}
0005433784318	E6A7EF	5221 800627	IVAN ZAKHAROV	{"phone": "+70955440826"}
0005433784319	156ABC	4566 070986	RADMIR FOMIN	{"phone": "+70783987352"}
0005433784320	156ABC	0550 705835	MARIYA KUDRYASHOVA	{"phone": "+70715890753"}
0005433784321	7794C0	0214 154802	TAMARA DANILOVA	{"email": "danilova_tamara061970@postgrespro.ru", "phone": "+70998073054"}
0005433784322	7794C0	9545 672088	ALEKSANDR PAVLOV	{"phone": "+70526820790"}
0005433784323	345103	3544 367578	KONSTANTIN BARANOV	{"phone": "+70916026925"}
0005433784324	345103	3095 594954	ANDREY SIDOROV	{"email": "sidorov.a.031971@postgrespro.ru", "phone": "+70147684935"}
0005433784325	E60B5B	9346 192070	IGOR EGOROV	{"email": "igor.egorov051965@postgrespro.ru", "phone": "+70101927998"}
0005433784326	53C20E	8586 610657	MAKSIM ABRAMOV	{"email": "abramovm12111974@postgrespro.ru", "phone": "+70486699022"}
0005433784327	AE586D	6818 765911	SVETLANA KUDRYASHOVA	{"email": "skudryashova.22101975@postgrespro.ru", "phone": "+70292561260"}
0005433784328	ACE11E	1658 253854	ALEKSANDR FEDOROV	{"phone": "+70182283042"}
0005433784330	7BB88B	0005 684548	VYACHESLAV MIRONOV	{"email": "mironov.vyacheslav.26101969@postgrespro.ru", "phone": "+70763060837"}
0005433784331	7BB88B	6581 406171	KSENIYA FEDOROVA	{"phone": "+70194675881"}
0005433784332	7BB88B	7540 818267	OLGA IVANOVA	{"email": "olgaivanova031962@postgrespro.ru", "phone": "+70512149914"}
0005433784333	CDA5CC	3846 627243	IRINA MIRONOVA	{"email": "mironova.i_1978@postgrespro.ru", "phone": "+70386743443"}
0005433784334	DD7D96	3042 405704	VIKTOR CHERNOV	{"email": "v_chernov.1971@postgrespro.ru", "phone": "+70192750182"}
0005433784335	C3FCB3	2836 824658	SVETLANA SERGEEVA	{"phone": "+70970811805"}
0005433784336	C3FCB3	3817 362823	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-061968@postgrespro.ru", "phone": "+70878701603"}
0005433784337	6DC4BD	3396 523102	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr.1963@postgrespro.ru", "phone": "+70862180223"}
0005433784338	6DC4BD	9693 578928	EKATERINA GERASIMOVA	{"email": "ekaterinagerasimova_24111972@postgrespro.ru", "phone": "+70111451800"}
0005433784339	D72D31	4792 195498	ALEKSANDR SMIRNOV	{"phone": "+70183546490"}
0005433784340	F60DAB	3572 394331	GALINA KAZAKOVA	{"phone": "+70347442301"}
0005433784341	2D75CE	9377 844514	GALINA FADEEVA	{"email": "fadeeva-g-07091976@postgrespro.ru", "phone": "+70893133645"}
0005433784342	1A1911	4288 758600	ALEKSANDR KARPOV	{"phone": "+70592888764"}
0005433784343	1A1911	4922 088077	ELENA PAVLOVA	{"phone": "+70002811388"}
0005433784344	0EA564	4330 830270	ANASTASIYA MOROZOVA	{"email": "morozova.anastasiya121975@postgrespro.ru", "phone": "+70451471840"}
0005433784345	0EA564	8644 510332	NIKOLAY BORISOV	{"phone": "+70013484018"}
0005433784346	41C522	6261 726461	GENNADIY NIKITIN	{"phone": "+70700255515"}
0005433784347	53E99A	5719 602160	VLADIMIR MARTYNOV	{"phone": "+70131054944"}
0005433784348	8D75D0	3797 829694	GALINA KALININA	{"email": "kalininagalina-21071964@postgrespro.ru", "phone": "+70966593342"}
0005433784349	8D75D0	7823 804581	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova_1957@postgrespro.ru", "phone": "+70232695242"}
0005433784350	A34E02	9424 316870	ANATOLIY KRASNOV	{"phone": "+70755700202"}
0005433784351	D4DF91	1273 712254	ALEKSANDR POPOV	{"email": "a-popov_071970@postgrespro.ru", "phone": "+70445765428"}
0005433784352	80E5BD	3331 507326	EKATERINA ANDREEVA	{"email": "andreeva_ekaterina_13071982@postgrespro.ru", "phone": "+70562584796"}
0005433784353	80E5BD	0502 683669	SVETLANA ISAEVA	{"phone": "+70526261718"}
0005433784354	FC33BA	1927 501170	DMITRIY ZAKHAROV	{"phone": "+70241694448"}
0005433784355	A37FD6	1874 171930	PAVEL ROMANOV	{"email": "romanov-p.091982@postgrespro.ru", "phone": "+70508741652"}
0005433784356	726890	4757 198696	LYUDMILA VASILEVA	{"email": "lyudmila-vasileva-1980@postgrespro.ru", "phone": "+70364863829"}
0005433784357	FA2EE2	9148 504035	SERGEY NIKOLAEV	{"phone": "+70510616950"}
0005433784358	FA2EE2	7699 428173	DANILA PETROV	{"email": "petrovdanila1980@postgrespro.ru", "phone": "+70261457120"}
0005433784359	FA2EE2	3206 370682	ZINAIDA EFIMOVA	{"email": "efimova-z.071970@postgrespro.ru", "phone": "+70734632354"}
0005433784360	03C620	8643 104498	ZULFIYA KUZMINA	{"email": "kuzminaz_091982@postgrespro.ru", "phone": "+70332990256"}
0005433784361	03C620	3179 038225	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr.26101964@postgrespro.ru", "phone": "+70716411787"}
0005433784362	B5646C	8773 631727	ZINAIDA KOROLEVA	{"phone": "+70869122077"}
0005433784363	8B86F8	4968 176827	VERA NESTEROVA	{"phone": "+70139451183"}
0005433784422	44CFFF	9322 717778	SVETLANA MIKHAYLOVA	{"phone": "+70610141025"}
0005433784364	F48A2B	8295 501826	KLAVDIYA ANTONOVA	{"email": "antonova_k1977@postgrespro.ru", "phone": "+70078514213"}
0005433784365	F48A2B	3870 798386	NATALYA FADEEVA	{"phone": "+70611879725"}
0005433784366	F841A5	6546 140805	PAVEL NAZAROV	{"phone": "+70781392129"}
0005433784367	D562DA	5105 099382	TATYANA KUZMINA	{"phone": "+70024421478"}
0005433784368	D562DA	0378 407153	YURIY VASILEV	{"email": "vasilev.y_1977@postgrespro.ru", "phone": "+70020890076"}
0005433784369	5F3953	0024 554171	TAMARA KOZLOVA	{"email": "tamara_kozlova.28011968@postgrespro.ru", "phone": "+70434419659"}
0005433784370	5F3953	9594 652302	RINAT MAKAROV	{"phone": "+70610785683"}
0005433784371	6BEE89	5344 421423	SERAFIMA MAKAROVA	{"email": "serafima-makarova061974@postgrespro.ru", "phone": "+70256597134"}
0005433784372	6BEE89	6713 439193	ALEKSEY ABRAMOV	{"phone": "+70678074814"}
0005433784373	2EB834	7226 655371	VIKTOR MOROZOV	{"email": "viktor-morozov1961@postgrespro.ru", "phone": "+70433481119"}
0005433784374	A801A5	8382 591055	LYUBOV KOZLOVA	{"email": "l-kozlova08011964@postgrespro.ru", "phone": "+70591834847"}
0005433784375	B1F9DB	5730 548871	YURIY POPOV	{"email": "popov_y-11061981@postgrespro.ru", "phone": "+70171871407"}
0005433784376	B1F9DB	1886 989244	ILYA MIKHAYLOV	{"email": "mikhaylov.ilya.28021964@postgrespro.ru", "phone": "+70110357386"}
0005433784377	91E1D6	5694 187020	ARTUR TARASOV	{"email": "tarasov-artur111979@postgrespro.ru", "phone": "+70612408246"}
0005433784378	8F954E	9363 267535	ELENA PETROVA	{"phone": "+70070002055"}
0005433784379	2A00F3	3211 181418	SERGEY GAVRILOV	{"email": "gavrilov.sergey.051963@postgrespro.ru", "phone": "+70795607494"}
0005433784380	496828	5518 018462	ANNA STEPANOVA	{"email": "a.stepanova.091966@postgrespro.ru", "phone": "+70119936593"}
0005433784381	496828	6221 613609	TATYANA ARKHIPOVA	{"phone": "+70297423393"}
0005433784382	88A03C	7019 926388	VLADIMIR FOMIN	{"phone": "+70252041760"}
0005433784383	7ABF44	5716 330852	NATALYA KALININA	{"phone": "+70291081537"}
0005433784384	5615C0	2776 779473	OLGA STEPANOVA	{"phone": "+70854523223"}
0005433784385	7DE8AD	4476 299339	TATYANA RODIONOVA	{"email": "tatyanarodionova_101967@postgrespro.ru", "phone": "+70592355149"}
0005433784386	7DE8AD	1080 154700	ARTEM ANDREEV	{"phone": "+70040106847"}
0005433784387	06142D	2439 950289	ALISA KOZLOVA	{"phone": "+70545030920"}
0005433784388	7210CB	8419 521233	ALEKSANDR VASILEV	{"phone": "+70887048626"}
0005433784389	7210CB	4442 064989	NINA KRASNOVA	{"email": "nkrasnova-20031978@postgrespro.ru", "phone": "+70955175056"}
0005433784390	7210CB	6185 592908	SVETLANA MALYSHEVA	{"phone": "+70872039991"}
0005433784391	BD4691	1868 879691	VYACHESLAV IVANOV	{"email": "vyacheslavivanov_26031962@postgrespro.ru", "phone": "+70659125654"}
0005433784392	5317F4	0484 015587	DENIS KUZNECOV	{"email": "d_kuznecov22111970@postgrespro.ru", "phone": "+70627335984"}
0005433784393	048056	0127 718571	KRISTINA NESTEROVA	{"email": "kristina-nesterova-031968@postgrespro.ru", "phone": "+70817586964"}
0005433784394	DFDAC8	0064 665763	VALENTINA ZHUKOVA	{"email": "v_zhukova.11111967@postgrespro.ru", "phone": "+70183959333"}
0005433784395	9E7F94	6753 293799	VYACHESLAV KUZNECOV	{"email": "vyacheslavkuznecov_031971@postgrespro.ru", "phone": "+70473116228"}
0005433784396	9E7F94	3015 149119	ALEKSANDR FROLOV	{"phone": "+70959918995"}
0005433784397	9F3AA7	6990 973018	ANASTASIYA KONDRATEVA	{"email": "anastasiya.kondrateva30121974@postgrespro.ru", "phone": "+70677089549"}
0005433784398	7523A5	5479 701781	IVAN MIKHAYLOV	{"email": "mikhaylovi1965@postgrespro.ru", "phone": "+70700597767"}
0005433784399	ECB5E9	8773 615943	ALEKSANDR ISAEV	{"phone": "+70916696663"}
0005433784400	640ACE	5132 814342	GALINA MIRONOVA	{"email": "mironova-galina.1972@postgrespro.ru", "phone": "+70085982658"}
0005433784401	7F8C72	5002 958410	TATYANA TARASOVA	{"email": "tarasova_t_031975@postgrespro.ru", "phone": "+70788487792"}
0005433784402	A4294C	7994 895051	NATALIYA IVANOVA	{"email": "ivanova-n021979@postgrespro.ru", "phone": "+70876713843"}
0005433784403	A4294C	4836 158719	NATALYA FEDOROVA	{"phone": "+70655769823"}
0005433784404	A4294C	0364 293757	GALINA LUKYANOVA	{"phone": "+70012998290"}
0005433784405	2C61E6	0386 323825	OLGA ARKHIPOVA	{"phone": "+70901445648"}
0005433784406	7D4CF9	4558 491857	MARIYA VASILEVA	{"email": "mariya-vasileva17081971@postgrespro.ru", "phone": "+70002662384"}
0005433784407	2F0684	8419 259191	ALEKSANDR SMIRNOV	{"phone": "+70129528195"}
0005433784408	262F69	5769 985927	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov-031970@postgrespro.ru", "phone": "+70614014073"}
0005433784409	112F22	8212 925111	ZINAIDA SERGEEVA	{"email": "sergeeva-zinaida_071978@postgrespro.ru", "phone": "+70000681210"}
0005433784410	88DC75	8508 419033	SAMIRA KULIKOVA	{"phone": "+70152309144"}
0005433784411	575625	5533 161964	EKATERINA GUSEVA	{"email": "e-guseva.061981@postgrespro.ru", "phone": "+70507130718"}
0005433784412	575625	1609 762223	SVETLANA DMITRIEVA	{"email": "dmitrieva-svetlana-101961@postgrespro.ru", "phone": "+70512239138"}
0005433784413	2BF9C8	8013 343155	YULIYA BELYAEVA	{"email": "yuliya_belyaeva-1967@postgrespro.ru", "phone": "+70788917047"}
0005433784414	18891E	2789 265452	VIKTOR SCHERBAKOV	{"email": "v.scherbakov.25021982@postgrespro.ru", "phone": "+70100104146"}
0005433784415	C73EB3	5353 729617	IVAN STEPANOV	{"phone": "+70922142297"}
0005433784416	C73EB3	7659 758457	DMITRIY ANTONOV	{"email": "antonov.dmitriy.061970@postgrespro.ru", "phone": "+70119521466"}
0005433784417	09CB34	8256 023307	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr.111956@postgrespro.ru", "phone": "+70189459265"}
0005433784418	09CB34	1716 115043	NIKOLAY AFANASEV	{"email": "nikolay.afanasev_091976@postgrespro.ru", "phone": "+70347824250"}
0005433784419	41364C	1865 039791	YURIY VOROBEV	{"email": "yuriy_vorobev-011984@postgrespro.ru", "phone": "+70216672447"}
0005433784420	313FD9	7298 498344	DARYA KUZNECOVA	{"phone": "+70326044734"}
0005433784421	9AC899	5231 333890	NIKOLAY GERASIMOV	{"email": "gerasimov_n.111976@postgrespro.ru", "phone": "+70692069397"}
0005433784423	6963E9	6638 248971	DMITRIY ALEKSEEV	{"email": "dmitriy-alekseev-05111972@postgrespro.ru", "phone": "+70598803629"}
0005433784424	05D662	6134 507151	SERGEY RODIONOV	{"phone": "+70418595656"}
0005433784425	05D662	8799 707847	ILYA ZAKHAROV	{"phone": "+70830742551"}
0005433784426	47625F	4906 881145	DANILA NOVIKOV	{"phone": "+70119554613"}
0005433784427	77A930	0044 222735	ANDREY SHEVCHENKO	{"email": "shevchenko_andrey-061973@postgrespro.ru", "phone": "+70609976083"}
0005433784428	480FA5	9622 001836	OLEG BORISOV	{"phone": "+70437606886"}
0005433784429	ED3F5C	3361 653388	KHASAN KUDRYASHOV	{"phone": "+70157682084"}
0005433784430	6C706F	9704 480387	EKATERINA DAVYDOVA	{"email": "davydova-ekaterina1965@postgrespro.ru", "phone": "+70850401545"}
0005433784431	C479FF	9641 686958	VALENTINA ZAKHAROVA	{"phone": "+70882483003"}
0005433784432	6E4C62	5864 309014	VLADIMIR ANDREEV	{"phone": "+70262386810"}
0005433784433	6E4C62	3181 090127	VASILIY GUSEV	{"email": "v_gusev_011970@postgrespro.ru", "phone": "+70351039043"}
0005433784434	164295	2323 208956	TATYANA KUZNECOVA	{"phone": "+70977134744"}
0005433784435	F55C6D	5396 653123	ROZALIYA ISAEVA	{"email": "isaeva.r-1975@postgrespro.ru", "phone": "+70375906091"}
0005433784436	F7710C	5592 006485	TATYANA KONOVALOVA	{"email": "t.konovalova_1989@postgrespro.ru", "phone": "+70785731755"}
0005433784437	F7710C	8966 420471	ALEKSANDR KRASNOV	{"phone": "+70883100696"}
0005433784438	F007FD	9605 786965	NATALIYA BOGDANOVA	{"email": "bogdanova.nataliya.061961@postgrespro.ru", "phone": "+70215356202"}
0005433784439	AD4E04	8716 034577	VADIM IVANOV	{"phone": "+70614366261"}
0005433784440	D434F5	9096 613587	MARIYA SMIRNOVA	{"email": "m_smirnova.15061967@postgrespro.ru", "phone": "+70448403752"}
0005433784441	992C75	1991 347924	NATALYA NAZAROVA	{"phone": "+70619913452"}
0005433784442	992C75	3491 848500	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov101975@postgrespro.ru", "phone": "+70092886582"}
0005433784443	8CCEE0	0741 431414	MIKHAIL ABRAMOV	{"email": "abramovmikhail09061972@postgrespro.ru", "phone": "+70909451849"}
0005433784444	8CCEE0	9809 958701	SERGEY KUZMIN	{"phone": "+70609615972"}
0005433784445	5F44F0	4767 515152	STEPAN DMITRIEV	{"phone": "+70779756149"}
0005433784446	ED6F2D	4783 848440	OLGA ZAKHAROVA	{"email": "zakharova_olga_08061969@postgrespro.ru", "phone": "+70948874740"}
0005433784447	ED6F2D	8499 924487	YURIY MOROZOV	{"email": "y.morozov_1966@postgrespro.ru", "phone": "+70351939513"}
0005433784448	ED6F2D	1759 953668	DAMIR GORBUNOV	{"phone": "+70479836686"}
0005433784449	497C87	1130 681010	STEPAN MIRONOV	{"email": "mironov_s_30051972@postgrespro.ru", "phone": "+70135565907"}
0005433784450	66C364	9721 398111	SOFYA ANTONOVA	{"phone": "+70413801698"}
0005433784451	0CFDDD	9153 415136	ANTON KOZLOV	{"email": "kozlov_a.031983@postgrespro.ru", "phone": "+70855325418"}
0005433784452	5684F0	1224 250209	ZULFIYA SCHERBAKOVA	{"email": "scherbakova.z_1981@postgrespro.ru", "phone": "+70876567708"}
0005433784453	1872E2	2120 988888	EKATERINA NIKITINA	{"email": "ekaterina.nikitina1974@postgrespro.ru", "phone": "+70073462650"}
0005433784454	02C401	1315 190040	ARTUR MELNIKOV	{"email": "melnikov-artur26041970@postgrespro.ru", "phone": "+70069491428"}
0005433784455	F4D251	5273 809313	GENNADIY MATVEEV	{"email": "gmatveev.09011965@postgrespro.ru", "phone": "+70592932567"}
0005433784456	4C8C60	4244 034545	ELENA OSIPOVA	{"email": "elenaosipova-15091964@postgrespro.ru", "phone": "+70909683124"}
0005433784457	842E60	9276 324782	PAVEL FROLOV	{"email": "pavel.frolov-031976@postgrespro.ru", "phone": "+70798830016"}
0005433784458	25E237	0325 422039	VLADIMIR SCHERBAKOV	{"phone": "+70996757726"}
0005433784459	3D8BEF	9483 164329	ANTON ZAYCEV	{"email": "zaycev-a-16041980@postgrespro.ru", "phone": "+70545266360"}
0005433784460	13E2C8	9608 539537	VLADIMIR EGOROV	{"phone": "+70010915573"}
0005433784461	13E2C8	4071 538746	DENIS GAVRILOV	{"email": "d.gavrilov_121970@postgrespro.ru", "phone": "+70008752231"}
0005433784462	E1ABC9	5764 097587	SERGEY ZAKHAROV	{"phone": "+70307359203"}
0005433784463	E1ABC9	1412 789007	ANNA FADEEVA	{"email": "fadeeva-a_1961@postgrespro.ru", "phone": "+70820723727"}
0005433784464	5083EB	9185 469848	NIKITA CHERNOV	{"email": "chernovnikita.1975@postgrespro.ru", "phone": "+70887578570"}
0005433784465	564784	5970 151026	VALERIY ZAYCEV	{"phone": "+70002055708"}
0005433784466	944EE2	9474 545666	LILIYA MOROZOVA	{"email": "morozova.liliya.1977@postgrespro.ru", "phone": "+70069412223"}
0005433784467	72E81D	0872 053455	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov_1976@postgrespro.ru", "phone": "+70528647675"}
0005433784468	94AD46	1385 374377	ALEKSANDR SAVELEV	{"phone": "+70429731110"}
0005433784469	94AD46	0074 731637	VASILIY DAVYDOV	{"phone": "+70193411014"}
0005433784470	55E985	9643 044530	NATALYA GAVRILOVA	{"phone": "+70010990076"}
0005433784471	065B1C	4885 798261	ANTONINA YAKOVLEVA	{"email": "antonina.yakovleva-1973@postgrespro.ru", "phone": "+70656494986"}
0005433784472	AA2513	0149 491458	NIKOLAY KISELEV	{"email": "kiselevnikolay.27111970@postgrespro.ru", "phone": "+70178032115"}
0005433784473	AA2513	4889 188419	SERGEY CHERNOV	{"phone": "+70428864269"}
0005433784474	61600C	2641 170934	IRINA SOKOLOVA	{"email": "sokolovai1966@postgrespro.ru", "phone": "+70965817346"}
0005433784475	D1FF37	7726 708764	VALENTINA PETROVA	{"phone": "+70223853960"}
0005433784476	D1FF37	3415 826288	NIKOLAY SMIRNOV	{"email": "smirnovnikolay.1969@postgrespro.ru", "phone": "+70221214538"}
0005433784477	0C1347	3035 246935	VLADIMIR ALEKSEEV	{"phone": "+70330376946"}
0005433784478	E957BE	3276 848163	VIKTOR SMIRNOV	{"phone": "+70174895312"}
0005433784479	73DEE9	7955 784959	EVGENIY ZHUKOV	{"email": "zhukov_evgeniy_30101965@postgrespro.ru", "phone": "+70627873075"}
0005433784480	73DEE9	9720 912144	SERGEY KUZNECOV	{"email": "kuznecov-sergey.07021966@postgrespro.ru", "phone": "+70935011496"}
0005433784481	60A29C	1449 975229	VITALIY KAZAKOV	{"email": "kazakovvitaliy.1986@postgrespro.ru", "phone": "+70740297991"}
0005433784482	0D287E	2472 386267	KIRILL SEMENOV	{"email": "semenovkirill_1963@postgrespro.ru", "phone": "+70402210994"}
0005433784483	0D287E	6582 439848	EVGENIY SMIRNOV	{"email": "smirnov.e.1968@postgrespro.ru", "phone": "+70492966544"}
0005433784484	18A053	1428 930295	VLADIMIR KUZNECOV	{"phone": "+70682074365"}
0005433784485	5AB95F	0859 702485	LYUDMILA SIDOROVA	{"phone": "+70180777291"}
0005433784486	CC781D	5307 593155	IVAN FROLOV	{"email": "i-frolov1964@postgrespro.ru", "phone": "+70336967736"}
0005433784487	C00329	5952 643240	DANIIL AFANASEV	{"email": "d_afanasev-20051961@postgrespro.ru", "phone": "+70233994611"}
0005433784488	4DAF99	5822 139653	EGOR PETROV	{"email": "petrov.egor-061969@postgrespro.ru", "phone": "+70503753449"}
0005433784489	D5EE05	4439 920076	ELENA ORLOVA	{"email": "e.orlova.061976@postgrespro.ru", "phone": "+70098481571"}
0005433784490	D56F73	5917 015475	GLEB KISELEV	{"phone": "+70435477822"}
0005433784491	03353C	7411 690342	YURIY MAKAROV	{"phone": "+70399307360"}
0005433784492	550EAC	4823 566380	YURIY PAVLOV	{"phone": "+70390414553"}
0005433784493	0A7A5A	5527 452219	NATALYA BELOVA	{"email": "belova.natalya_29111967@postgrespro.ru", "phone": "+70763867748"}
0005433784494	0A7A5A	6629 095924	YULIYA NAZAROVA	{"phone": "+70149678876"}
0005433784551	5111E8	0845 544515	GENNADIY KAZAKOV	{"phone": "+70794299615"}
0005433784495	9477D3	1598 884122	TATYANA MASLOVA	{"email": "tatyana.maslova.25091964@postgrespro.ru", "phone": "+70665332759"}
0005433784496	9477D3	2937 130636	SERGEY BELOV	{"email": "s-belov-02021969@postgrespro.ru", "phone": "+70005211136"}
0005433784497	FE1F8B	0279 114402	NATALYA VOLKOVA	{"email": "volkovanatalya.061972@postgrespro.ru", "phone": "+70014888074"}
0005433784498	642429	0933 723877	ELENA ALEKSEEVA	{"email": "alekseeva-elena_011973@postgrespro.ru", "phone": "+70347691849"}
0005433784499	8C7181	8742 267908	YULIYA ANDREEVA	{"email": "andreevay_01111969@postgrespro.ru", "phone": "+70673975222"}
0005433784500	FE00D0	8803 510307	IGOR KOROLEV	{"phone": "+70424132567"}
0005433784501	FE00D0	5409 017296	TATYANA KOZLOVA	{"email": "kozlovatatyana121973@postgrespro.ru", "phone": "+70835715269"}
0005433784502	18EA33	5282 107764	ALEKSEY VOLKOV	{"email": "volkov.aleksey.041979@postgrespro.ru", "phone": "+70454107146"}
0005433784503	3919D7	5756 865909	VLADIMIR PETROV	{"email": "petrov-vladimir1960@postgrespro.ru", "phone": "+70520879665"}
0005433784504	C85295	3289 622749	YURIY EGOROV	{"phone": "+70471743796"}
0005433784505	EC8668	1360 374825	SERGEY ABRAMOV	{"phone": "+70780665407"}
0005433784506	A2C5A9	4078 059383	ANASTASIYA ILINA	{"email": "ilina.anastasiya_30081971@postgrespro.ru", "phone": "+70367441788"}
0005433784507	E4CD8F	3739 443320	SERGEY MIKHAYLOV	{"phone": "+70370904823"}
0005433784508	E4CD8F	4434 980578	IRINA SOLOVEVA	{"phone": "+70844188908"}
0005433784509	9B1041	2672 454456	SOFIYA LAZAREVA	{"phone": "+70260334051"}
0005433784510	17D44E	8310 769174	IRINA VOROBEVA	{"phone": "+70540377432"}
0005433784511	97B03D	8494 681819	LYUBOV VASILEVA	{"phone": "+70858102065"}
0005433784512	19F7D2	3471 460216	DMITRIY KULIKOV	{"email": "kulikovd.1974@postgrespro.ru", "phone": "+70198714849"}
0005433784513	19F7D2	0504 626746	SHAMIL KUZMIN	{"phone": "+70754641583"}
0005433784514	B24590	2787 567493	LYUDMILA NIKITINA	{"email": "nikitinalyudmila1974@postgrespro.ru", "phone": "+70255584586"}
0005433784515	231B3E	0931 023653	TATYANA BELOVA	{"email": "belova-t.24021967@postgrespro.ru", "phone": "+70281932596"}
0005433784516	774FB2	8071 836942	ERIK GAVRILOV	{"email": "gavrilov-e_19021980@postgrespro.ru", "phone": "+70552606576"}
0005433784517	774FB2	6669 907089	TATYANA OSIPOVA	{"email": "osipova_t-1969@postgrespro.ru", "phone": "+70812328228"}
0005433784518	D43BB4	8433 254893	MARINA ZAYCEVA	{"email": "marina_zayceva.10101979@postgrespro.ru", "phone": "+70448889399"}
0005433784519	D43BB4	2266 245039	NINA IVANOVA	{"phone": "+70572666141"}
0005433784520	D43BB4	2790 567941	VIKTOR MOROZOV	{"phone": "+70369673315"}
0005433784521	338EB2	0840 625923	SVETLANA ZHUKOVA	{"email": "s-zhukova24011979@postgrespro.ru", "phone": "+70913764901"}
0005433784522	09110B	7274 552909	RINAT MIKHAYLOV	{"email": "mikhaylov-r-1967@postgrespro.ru", "phone": "+70695402889"}
0005433784523	09110B	6528 860098	VIKTOR GUSEV	{"email": "viktor-gusev.15071967@postgrespro.ru", "phone": "+70774266365"}
0005433784524	922A40	7084 973540	DMITRIY ISAEV	{"phone": "+70243266999"}
0005433784525	BAE5CE	6852 796365	VLADIMIR ZHUKOV	{"email": "v-zhukov.1972@postgrespro.ru", "phone": "+70291253029"}
0005433784526	D4533B	4493 911279	ALEKSANDR FILIPPOV	{"phone": "+70260829125"}
0005433784527	E30E50	5350 721953	MARINA KOVALEVA	{"phone": "+70920959050"}
0005433784528	D369FD	3816 724507	MARINA NIKOLAEVA	{"phone": "+70652957384"}
0005433784529	D369FD	3734 103826	ELENA SMIRNOVA	{"phone": "+70946130883"}
0005433784530	B08BC3	4187 309626	VLADIMIR SEMENOV	{"phone": "+70296898163"}
0005433784531	B08BC3	3147 935654	ALFIYA ANTONOVA	{"phone": "+70099588495"}
0005433784532	5D02C7	1747 917476	ALEKSANDR KARPOV	{"phone": "+70263627146"}
0005433784533	17ED8E	0985 256924	ROMAN EGOROV	{"email": "r_egorov-081967@postgrespro.ru", "phone": "+70545980993"}
0005433784534	F8C1A1	2465 055651	PAVEL BONDARENKO	{"phone": "+70405190480"}
0005433784535	F8C1A1	7287 790778	YURIY VOROBEV	{"phone": "+70939017035"}
0005433784536	898A0B	2203 429939	DMITRIY MIKHAYLOV	{"email": "mikhaylov.d_051972@postgrespro.ru", "phone": "+70038335944"}
0005433784537	6F13A8	3724 972613	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr_011981@postgrespro.ru", "phone": "+70102704969"}
0005433784538	4CB18D	3050 850182	NADEZHDA OSIPOVA	{"email": "n.osipova-121978@postgrespro.ru", "phone": "+70624547219"}
0005433784539	4CB18D	4146 133856	NADEZHDA MAKSIMOVA	{"email": "nadezhda_maksimova_01041966@postgrespro.ru", "phone": "+70378049003"}
0005433784540	7F7549	5319 307639	FEDOR SMIRNOV	{"email": "f_smirnov07051964@postgrespro.ru", "phone": "+70423832740"}
0005433784541	637D0E	3181 925528	ELENA YAKOVLEVA	{"phone": "+70513004389"}
0005433784542	3B2F09	3152 744539	EKATERINA ALEKSANDROVA	{"phone": "+70770904388"}
0005433784543	9BF50E	5515 184218	NATALYA PAVLOVA	{"phone": "+70454729570"}
0005433784544	F4CE1D	6893 965645	POLINA ANDREEVA	{"phone": "+70534639147"}
0005433784545	F4CE1D	5109 886557	VLADIMIR SIDOROV	{"phone": "+70719387214"}
0005433784546	F4CE1D	0019 057168	ELENA NIKOLAEVA	{"phone": "+70754410834"}
0005433784547	A0B706	7850 879114	SABINA NIKOLAEVA	{"email": "nikolaeva_sabina-1973@postgrespro.ru", "phone": "+70687080335"}
0005433784548	0B3FF5	7963 742832	VLADIMIR POPOV	{"email": "popovvladimir.07081976@postgrespro.ru", "phone": "+70920407412"}
0005433784549	0DF7A4	0924 369872	TATYANA LEBEDEVA	{"phone": "+70727460530"}
0005433784550	B1BF47	4349 927369	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev_111964@postgrespro.ru", "phone": "+70362472933"}
0005433784552	2E07B7	3249 400607	IRINA KUZNECOVA	{"email": "kuznecova-irina.1977@postgrespro.ru", "phone": "+70152345065"}
0005433784553	32AEED	3799 828120	ANNA LOGINOVA	{"email": "a.loginova-27071968@postgrespro.ru", "phone": "+70992115443"}
0005433784554	891ACE	1782 730952	LYUDMILA KUZNECOVA	{"email": "l-kuznecova_031974@postgrespro.ru", "phone": "+70407073327"}
0005433784555	FD6A31	7694 877337	ELIZAVETA KUZNECOVA	{"phone": "+70700314108"}
0005433784556	011DBD	4592 781246	ALEKSANDR ANDREEV	{"phone": "+70671685813"}
0005433784557	6A0540	5223 417204	EVGENIY KONOVALOV	{"phone": "+70883189284"}
0005433784558	6A0540	3668 071990	OLGA ABRAMOVA	{"phone": "+70305597613"}
0005433784559	FFC70F	2775 946890	VLADIMIR ZHUKOV	{"phone": "+70484180987"}
0005433784560	BCAAF9	2390 278343	ELIZAVETA POPOVA	{"phone": "+70750529070"}
0005433784561	BCAAF9	4654 334653	VLADIMIR POPOV	{"email": "popov.vladimir-20121968@postgrespro.ru", "phone": "+70960449041"}
0005433784562	CD25DA	0852 406047	NINA POPOVA	{"email": "n.popova.1974@postgrespro.ru", "phone": "+70489702858"}
0005433784563	CD25DA	5430 935612	ALEKSANDR KISELEV	{"phone": "+70814280821"}
0005433784564	47638D	1378 238892	VIKTOR SIDOROV	{"phone": "+70147911259"}
0005433784565	47638D	8855 807440	TATYANA ISAEVA	{"phone": "+70779680582"}
0005433784566	C107AE	5339 506741	ANASTASIYA VASILEVA	{"phone": "+70337462557"}
0005433784567	0BE532	9759 307260	ANTONINA ZAKHAROVA	{"phone": "+70343534515"}
0005433784568	E664DD	2877 976889	ANDREY MAKSIMOV	{"email": "andrey-maksimov-25031974@postgrespro.ru", "phone": "+70641405900"}
0005433784569	3FE088	1899 383749	ANASTASIYA MALYSHEVA	{"phone": "+70275657000"}
0005433784570	260694	3220 610399	VALENTINA ANDREEVA	{"email": "andreeva_valentina24021977@postgrespro.ru", "phone": "+70312804745"}
0005433784571	E80CFE	6676 309226	KRISTINA ALEKSANDROVA	{"email": "kristina_aleksandrova1975@postgrespro.ru", "phone": "+70235796973"}
0005433784572	E80CFE	1914 629790	FANIL POPOV	{"email": "f.popov_121968@postgrespro.ru", "phone": "+70303130903"}
0005433784573	E80CFE	5876 151667	RAIL TIKHONOV	{"phone": "+70135218632"}
0005433784574	3826AC	4007 538346	ANDREY KISELEV	{"email": "a_kiselev.061981@postgrespro.ru", "phone": "+70908717561"}
0005433784575	3826AC	6986 844092	VIKTOR GERASIMOV	{"email": "gerasimov-viktor_1974@postgrespro.ru", "phone": "+70932274301"}
0005433784576	A92C12	5577 506541	GALINA LOGINOVA	{"email": "loginovag-091970@postgrespro.ru", "phone": "+70874149226"}
0005433784577	057371	8344 663172	MARINA BORISOVA	{"phone": "+70839704011"}
0005433784578	0ABBFC	3050 942175	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr011972@postgrespro.ru", "phone": "+70529515992"}
0005433784579	287487	5712 507497	ANDREY VASILEV	{"phone": "+70448640547"}
0005433784580	287487	0978 238581	MARGARITA EFREMOVA	{"email": "efremova_m_1959@postgrespro.ru", "phone": "+70333731020"}
0005433784581	8F98CA	6680 358864	OLEG KUZMIN	{"email": "oleg-kuzmin19041978@postgrespro.ru", "phone": "+70723198088"}
0005433784582	7D3034	8434 757143	VADIM MELNIKOV	{"phone": "+70654601564"}
0005433784583	BB81C9	7605 854549	LYUBOV POLYAKOVA	{"phone": "+70171020414"}
0005433784584	F31DB2	7441 410759	RUSLAN KUZNECOV	{"email": "r-kuznecov021970@postgrespro.ru", "phone": "+70656387213"}
0005433784585	8F25FA	8938 525685	IRINA BELOVA	{"phone": "+70401211796"}
0005433784586	8F25FA	8521 491545	ALEKSEY SAVELEV	{"phone": "+70856714938"}
0005433784587	9052FA	8844 546231	GALINA GAVRILOVA	{"email": "gavrilova.g30051968@postgrespro.ru", "phone": "+70171292239"}
0005433784588	9052FA	1554 627343	ANTON VOLKOV	{"email": "antonvolkov.29071969@postgrespro.ru", "phone": "+70893069538"}
0005433784589	9052FA	2296 397522	MARIYA ANISIMOVA	{"email": "anisimova_mariya.01031964@postgrespro.ru", "phone": "+70517738640"}
0005433784590	1E7EFE	3908 115927	IRINA FADEEVA	{"phone": "+70965682205"}
0005433784591	3FA67C	1444 842061	KIRILL SMIRNOV	{"phone": "+70642618254"}
0005433784592	0B2E7E	4439 941864	YURIY NIKOLAEV	{"email": "yuriy-nikolaev-1965@postgrespro.ru", "phone": "+70957911787"}
0005433784593	38E09B	7760 079061	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_v-27081979@postgrespro.ru", "phone": "+70814276484"}
0005433784594	91A4F1	1337 472277	GRIGORIY ISAEV	{"phone": "+70459342240"}
0005433784595	E98EB4	8715 503613	VIKTOR ANTONOV	{"email": "antonov-viktor-121980@postgrespro.ru", "phone": "+70827885383"}
0005433784596	87B9B4	8800 665666	STANISLAV ANTONOV	{"phone": "+70732634039"}
0005433784597	87B9B4	7722 031517	VIKTOR KUZNECOV	{"email": "kuznecov_v_19061977@postgrespro.ru", "phone": "+70249323186"}
0005433784598	89C69D	2353 086856	TATYANA ABRAMOVA	{"email": "abramova-t.14061966@postgrespro.ru", "phone": "+70433417932"}
0005433784599	8B3AC7	3341 581692	SERGEY OSIPOV	{"email": "sergey_osipov-051977@postgrespro.ru", "phone": "+70800755902"}
0005433784600	ADA29E	8251 273264	NATALYA MOROZOVA	{"email": "morozova.natalya.1980@postgrespro.ru", "phone": "+70830188786"}
0005433784601	D2B51E	3792 083028	VIKTOR EGOROV	{"email": "egorov.viktor-11101972@postgrespro.ru", "phone": "+70978344929"}
0005433784602	78D508	0436 619276	AMIR SEMENOV	{"email": "semenovamir_091971@postgrespro.ru", "phone": "+70948455446"}
0005433784603	78D508	0426 235610	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a_081966@postgrespro.ru", "phone": "+70267814532"}
0005433784604	6F8D9D	3413 423660	VERA FROLOVA	{"phone": "+70933326734"}
0005433784605	31DC10	0469 374912	YANA MIKHAYLOVA	{"phone": "+70415280680"}
0005433784606	79B708	0090 762887	OLGA DANILOVA	{"phone": "+70175561690"}
0005433784607	79B708	9030 248717	ZINAIDA CHERNOVA	{"phone": "+70901015494"}
0005433784608	F89DA3	0472 256942	NIKOLAY SIDOROV	{"phone": "+70210983482"}
0005433784609	C3EEF8	4881 122271	SERGEY KUZNECOV	{"phone": "+70110421094"}
0005433784610	B7D7B4	4685 559948	DIANA KISELEVA	{"email": "dianakiseleva_121978@postgrespro.ru", "phone": "+70659886570"}
0005433784611	FD9751	9274 043299	EVDOKIYA ARKHIPOVA	{"email": "arkhipovaevdokiya_091972@postgrespro.ru", "phone": "+70119567776"}
0005433784612	FD9751	2215 889127	VIKTOR GRIGOREV	{"phone": "+70077347526"}
0005433784613	137926	0421 853969	EVGENIY IVANOV	{"phone": "+70795757071"}
0005433784614	CF14B3	6535 386490	DENIS KONOVALOV	{"email": "konovalovd-23011963@postgrespro.ru", "phone": "+70526892061"}
0005433784615	CF14B3	1924 230962	SERGEY STEPANOV	{"phone": "+70253902558"}
0005433784616	CF14B3	3410 568470	NINA ISAEVA	{"phone": "+70811855274"}
0005433784617	7D2BFE	3847 029739	DARYA DAVYDOVA	{"phone": "+70336686443"}
0005433784618	F792E1	6720 006665	OKSANA MEDVEDEVA	{"email": "medvedeva.o-10101974@postgrespro.ru", "phone": "+70814929033"}
0005433784619	FD42A9	3702 999348	GALINA ISAEVA	{"phone": "+70862125589"}
0005433784620	EB689E	8233 617755	OKSANA KOROLEVA	{"email": "oksana_koroleva.091966@postgrespro.ru", "phone": "+70446024032"}
0005433784621	EB689E	9337 505588	MIKHAIL ILIN	{"email": "ilin_m.16101974@postgrespro.ru", "phone": "+70228590101"}
0005433784622	96A139	8158 404957	IVAN SAVELEV	{"email": "savelevi1966@postgrespro.ru", "phone": "+70562418260"}
0005433784623	59696E	2023 107424	PAVEL TIKHONOV	{"email": "tikhonov_p_12091969@postgrespro.ru", "phone": "+70175062643"}
0005433784624	EAF531	5455 707662	NATALYA LUKYANOVA	{"email": "lukyanova_natalya-121975@postgrespro.ru", "phone": "+70366341336"}
0005433784625	68C671	2108 382117	SERGEY RODIONOV	{"phone": "+70370139860"}
0005433784626	FE9AB2	4601 402950	OLEG PETROV	{"email": "oleg-petrov-011981@postgrespro.ru", "phone": "+70289533876"}
0005433784627	3FBC71	4396 754150	OLGA TARASOVA	{"phone": "+70893243694"}
0005433784628	6EE6AF	7763 671811	VALENTINA TARASOVA	{"email": "tarasova-valentina-011976@postgrespro.ru", "phone": "+70082185595"}
0005433784629	E3DBEE	2973 896910	SVETLANA VASILEVA	{"email": "vasileva_svetlana-1974@postgrespro.ru", "phone": "+70599703850"}
0005433784630	C1E988	7622 948474	MIKHAIL ALEKSEEV	{"email": "m_alekseev_1965@postgrespro.ru", "phone": "+70175250031"}
0005433784631	C1E988	7488 614668	GALINA VOLKOVA	{"phone": "+70312277971"}
0005433784632	72C777	4582 118603	ALEKSEY SMIRNOV	{"phone": "+70450130540"}
0005433784633	72C777	8358 992989	OLGA AFANASEVA	{"email": "afanaseva_o091968@postgrespro.ru", "phone": "+70895770875"}
0005433784634	D9FB63	1870 834813	YULIYA MOROZOVA	{"phone": "+70820495369"}
0005433784635	B21B7E	4312 352131	ANDREY KONOVALOV	{"phone": "+70278356406"}
0005433784636	B21B7E	0137 632523	MARIYA SOLOVEVA	{"email": "msoloveva-061982@postgrespro.ru", "phone": "+70280612556"}
0005433784637	1225DB	5707 039925	EKATERINA VLASOVA	{"phone": "+70538078775"}
0005433784638	92D54A	9153 184242	ALEKSANDRA STEPANOVA	{"email": "stepanova.aleksandra-06021974@postgrespro.ru", "phone": "+70920172733"}
0005433784639	92D54A	7861 691649	RAFAIL FILIPPOV	{"email": "rafail-filippov_1963@postgrespro.ru", "phone": "+70663251707"}
0005433784640	A87B9C	3872 361054	ARTEM GERASIMOV	{"phone": "+70751570178"}
0005433784641	A87B9C	4698 526228	TATYANA FILIPPOVA	{"phone": "+70196606365"}
0005433784642	8D5766	0276 505127	GALINA VOROBEVA	{"phone": "+70242577222"}
0005433784643	8D5766	4794 167070	ARTEM ILIN	{"phone": "+70779884114"}
0005433784644	524A93	6513 310263	TAMARA IVANOVA	{"phone": "+70844715239"}
0005433784645	1100A8	7513 282743	ALEKSEY GAVRILOV	{"email": "gavrilov_aleksey-071968@postgrespro.ru", "phone": "+70987223972"}
0005433784646	EBE28F	7082 823584	VLADIMIR YAKOVLEV	{"phone": "+70831779430"}
0005433784647	334C54	1824 705191	NADEZHDA MIRONOVA	{"phone": "+70451616383"}
0005433784648	334C54	0357 077211	VERA SOROKINA	{"email": "vera.sorokina-041975@postgrespro.ru", "phone": "+70449286772"}
0005433784649	6B27DE	7920 058654	OLGA KOROLEVA	{"phone": "+70573225993"}
0005433784650	6B27DE	8199 862003	TATYANA BELOVA	{"email": "tatyana_belova-12031977@postgrespro.ru", "phone": "+70272319571"}
0005433784651	6B27DE	3096 129786	YURIY NAZAROV	{"email": "nazarovyuriy_051965@postgrespro.ru", "phone": "+70778647429"}
0005433784652	98C336	0758 326751	SERGEY VASILEV	{"email": "s-vasilev.27111972@postgrespro.ru", "phone": "+70501555275"}
0005433784653	A9D71F	9959 211763	YANA KOROLEVA	{"phone": "+70285329162"}
0005433784654	E8E3C7	5702 799612	IGOR SCHERBAKOV	{"email": "scherbakov_i-08041970@postgrespro.ru", "phone": "+70641543778"}
0005433784655	E8E3C7	1961 927466	OKSANA LUKYANOVA	{"phone": "+70764783163"}
0005433784656	E8E3C7	5164 898454	LYUDMILA KRASNOVA	{"phone": "+70139656236"}
0005433784657	13BEB4	1592 642019	ALENA FOMINA	{"phone": "+70660471058"}
0005433784658	13BEB4	9653 426438	SVETLANA NIKIFOROVA	{"email": "s_nikiforova1970@postgrespro.ru", "phone": "+70858892646"}
0005433784659	527B21	8583 453736	ARTEM MOROZOV	{"email": "a_morozov.17121969@postgrespro.ru", "phone": "+70116770418"}
0005433784660	CE4D59	0581 778536	YURIY ISAEV	{"email": "y_isaev1982@postgrespro.ru", "phone": "+70813300491"}
0005433784661	0F04DD	4063 268083	EVGENIY ANDREEV	{"phone": "+70406425805"}
0005433784662	0F04DD	5742 989500	ALEKSEY RODIONOV	{"email": "a_rodionov-011966@postgrespro.ru", "phone": "+70218303701"}
0005433784663	D821B3	3034 817319	ALEKSEY ZAKHAROV	{"phone": "+70116493450"}
0005433784664	C87AF8	9070 767074	ELENA NESTEROVA	{"phone": "+70666285881"}
0005433784665	8FA8C1	8857 216196	TIMOFEY BARANOV	{"phone": "+70636864228"}
0005433784666	8FA8C1	3515 918893	IVAN KULIKOV	{"phone": "+70695995377"}
0005433784667	457C7E	8498 813018	TATYANA FADEEVA	{"email": "tatyana-fadeeva-111974@postgrespro.ru", "phone": "+70978807738"}
0005433784668	8737FD	3710 129608	NADEZHDA KOROLEVA	{"email": "koroleva_nadezhda_1978@postgrespro.ru", "phone": "+70252037601"}
0005433784669	8737FD	6864 086933	TATYANA SEMENOVA	{"phone": "+70239569381"}
0005433784670	4ED0B0	7149 191803	TATYANA SIDOROVA	{"phone": "+70693210791"}
0005433784671	E9510C	3979 804199	MIKHAIL ROMANOV	{"phone": "+70581315919"}
0005433784672	93CDEE	3927 496926	VERA KRASNOVA	{"email": "vkrasnova-24041974@postgrespro.ru", "phone": "+70815297415"}
0005433784673	6C87B4	9120 805969	ZINAIDA DMITRIEVA	{"email": "z.dmitrieva11051985@postgrespro.ru", "phone": "+70842340685"}
0005433784674	6C87B4	8471 469574	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr1959@postgrespro.ru", "phone": "+70077956428"}
0005433784675	B0A04B	2042 860673	TATYANA IVANOVA	{"phone": "+70948047061"}
0005433784676	B0A04B	2605 831247	ALEKSEY VOROBEV	{"email": "vorobev-aleksey_011984@postgrespro.ru", "phone": "+70196679622"}
0005433784677	183C23	0544 703615	OLGA RODIONOVA	{"phone": "+70227006852"}
0005433784678	808237	7966 097975	EDUARD ZHUKOV	{"phone": "+70860719003"}
0005433784679	808237	3617 379102	VALERIYA KUZNECOVA	{"phone": "+70005664856"}
0005433784680	960843	3127 502114	EKATERINA ALEKSEEVA	{"email": "ekaterina.alekseeva24041972@postgrespro.ru", "phone": "+70845527407"}
0005433784681	9ACC38	7966 465934	SVETLANA MAKSIMOVA	{"phone": "+70371765050"}
0005433784682	A5F7E4	2355 311790	STANISLAV VASILEV	{"phone": "+70163456879"}
0005433784683	220540	6228 780365	NATALIYA SERGEEVA	{"email": "n-sergeeva-13091978@postgrespro.ru", "phone": "+70971224184"}
0005433784684	662FD1	0777 739004	VLADISLAV NIKITIN	{"phone": "+70879083039"}
0005433784685	6B58AB	1617 032910	EVGENIYA TROFIMOVA	{"email": "trofimova-e.021975@postgrespro.ru", "phone": "+70375896498"}
0005433784686	6B58AB	3785 843672	NADEZHDA BARANOVA	{"email": "baranovanadezhda_021975@postgrespro.ru", "phone": "+70230314224"}
0005433784687	643A27	4215 171438	NATALYA EGOROVA	{"phone": "+70001506474"}
0005433784688	24158E	8165 368558	NATALIYA KISELEVA	{"email": "n.kiseleva.1971@postgrespro.ru", "phone": "+70162454008"}
0005433784689	FF785E	7382 794949	SOFYA KUZNECOVA	{"phone": "+70960946521"}
0005433784690	7C1C51	0682 900559	VALENTINA PETROVA	{"email": "v_petrova-071964@postgrespro.ru", "phone": "+70530715695"}
0005433784691	7C1C51	4479 691980	YULIYA KOROLEVA	{"email": "koroleva-y_111984@postgrespro.ru", "phone": "+70727102555"}
0005433784692	75B170	7256 371742	ELENA SERGEEVA	{"email": "sergeeva-e_1971@postgrespro.ru", "phone": "+70304179646"}
0005433784693	E625D4	0164 399202	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr.29081964@postgrespro.ru", "phone": "+70956528992"}
0005433784694	54C8E1	1472 891171	YURIY ANDREEV	{"email": "y-andreev-25071963@postgrespro.ru", "phone": "+70167895485"}
0005433784695	A4DDBC	6787 663743	ELENA ERMAKOVA	{"email": "eermakova-111967@postgrespro.ru", "phone": "+70648682712"}
0005433784696	A4DDBC	3662 330047	INNA OSIPOVA	{"phone": "+70162307570"}
0005433784697	B00DEE	4182 326192	GALINA ANTONOVA	{"phone": "+70309819672"}
0005433784698	9C69D6	8274 157887	LYUDMILA ERMAKOVA	{"email": "lyudmila_ermakova-10121974@postgrespro.ru", "phone": "+70647633053"}
0005433784699	DA4963	7753 720865	ALEKSEY NIKITIN	{"phone": "+70529321339"}
0005433784700	8BD03F	3523 477234	ALEKSEY TIKHONOV	{"phone": "+70189812742"}
0005433784701	5024BE	7935 730947	VIKTORIYA MEDVEDEVA	{"phone": "+70859289877"}
0005433784702	4511F5	7215 671263	ANTONINA KOZLOVA	{"email": "a_kozlova051969@postgrespro.ru", "phone": "+70897381059"}
0005433784703	722BDC	6347 457641	ROMAN SIDOROV	{"phone": "+70155608339"}
0005433784704	45A572	1255 024341	ALEKSEY MOISEEV	{"email": "moiseev_a_1970@postgrespro.ru", "phone": "+70720989732"}
0005433784705	51BC6B	8143 805661	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov_021975@postgrespro.ru", "phone": "+70188190241"}
0005433784706	178812	7785 999535	VLADIMIR NIKOLAEV	{"phone": "+70689141436"}
0005433784707	178812	5547 177106	VERA MELNIKOVA	{"email": "vera.melnikova-13121964@postgrespro.ru", "phone": "+70398296610"}
0005433784708	9DC6E5	4248 646978	PAVEL ANDREEV	{"email": "pavelandreev021980@postgrespro.ru", "phone": "+70730427165"}
0005433784709	DE87AC	9680 506749	GALINA SOROKINA	{"email": "sorokina.galina-1969@postgrespro.ru", "phone": "+70516515604"}
0005433784710	777956	8657 418069	ANASTASIYA EGOROVA	{"email": "anastasiya-egorova.1978@postgrespro.ru", "phone": "+70991320442"}
0005433784711	777956	3090 920583	ANNA SERGEEVA	{"phone": "+70950502544"}
0005433784712	09A480	0689 734670	ELINA BELOVA	{"email": "e.belova_081974@postgrespro.ru", "phone": "+70484833418"}
0005433784713	FBB3E2	6178 830663	IRINA STEPANOVA	{"email": "istepanova-031986@postgrespro.ru", "phone": "+70783266941"}
0005433784714	13463C	2952 711786	ELENA KULIKOVA	{"email": "kulikova.e.18071978@postgrespro.ru", "phone": "+70988077932"}
0005433784715	13463C	5212 781213	SERGEY KUZMIN	{"email": "kuzminsergey_051967@postgrespro.ru", "phone": "+70144364686"}
0005433784716	13463C	8603 479774	VALERIY PAVLOV	{"phone": "+70621920265"}
0005433784717	80C0CE	2978 073551	EKATERINA DAVYDOVA	{"email": "e_davydova-1970@postgrespro.ru", "phone": "+70383264590"}
0005433784718	EEC420	1048 017449	INNA SOROKINA	{"email": "inna.sorokina-1975@postgrespro.ru", "phone": "+70106463110"}
0005433784719	EEC420	9452 436685	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov.091975@postgrespro.ru", "phone": "+70962223420"}
0005433784720	948586	3494 884437	VALENTINA ABRAMOVA	{"phone": "+70868475034"}
0005433784721	052591	4777 468914	IRINA SIDOROVA	{"phone": "+70593011122"}
0005433784722	9DE7B1	9981 530093	NIKOLAY KUZNECOV	{"email": "kuznecov_n.1970@postgrespro.ru", "phone": "+70393227214"}
0005433784723	9DE7B1	0011 706029	SERGEY PETROV	{"phone": "+70593546275"}
0005433784724	9F3938	1863 286958	VIOLETTA VOLKOVA	{"email": "violetta.volkova.07091969@postgrespro.ru", "phone": "+70587322139"}
0005433784725	9F3938	8205 087658	ANATOLIY POPOV	{"email": "a-popov_021965@postgrespro.ru", "phone": "+70584621937"}
0005433784726	FF83F1	0335 652978	ALEKSANDR MAKSIMOV	{"email": "aleksandrmaksimov_051979@postgrespro.ru", "phone": "+70465596878"}
0005433784727	FF83F1	1801 030693	SVETLANA KUZMINA	{"email": "kuzmina-svetlana-1957@postgrespro.ru", "phone": "+70212795913"}
0005433784728	95152F	2956 063092	KIRILL ANDREEV	{"email": "k_andreev1968@postgrespro.ru", "phone": "+70026049862"}
0005433784729	36426B	3804 836505	PAVEL RODIONOV	{"phone": "+70654878052"}
0005433784730	36426B	1660 450074	NATALYA TIKHONOVA	{"email": "natalya_tikhonova.17031970@postgrespro.ru", "phone": "+70722440121"}
0005433784731	1AFF6D	4119 586513	VERA EFREMOVA	{"phone": "+70642806633"}
0005433784732	1AC980	3806 827411	ELENA EFIMOVA	{"email": "efimovae.23101969@postgrespro.ru", "phone": "+70566408800"}
0005433784733	FFE998	3914 050014	ROZA RYABOVA	{"email": "r-ryabova-29031982@postgrespro.ru", "phone": "+70023000600"}
0005433784734	FE6533	8584 987515	YURIY AFANASEV	{"email": "y_afanasev-071976@postgrespro.ru", "phone": "+70600466083"}
0005433784735	FE6533	4068 022237	ALEKSANDR ZHUKOV	{"email": "a-zhukov_1966@postgrespro.ru", "phone": "+70639232473"}
0005433784736	FE6533	0780 719805	VLADIMIR ORLOV	{"email": "vladimir.orlov1984@postgrespro.ru", "phone": "+70846337921"}
0005433784737	F464F8	0352 368638	NATALYA KOROLEVA	{"email": "koroleva-natalya1971@postgrespro.ru", "phone": "+70482311125"}
0005433784738	F464F8	4952 193676	NADEZHDA MIKHAYLOVA	{"email": "nadezhda.mikhaylova-1970@postgrespro.ru", "phone": "+70053648641"}
0005433784739	972937	0556 016120	SERGEY ZAKHAROV	{"phone": "+70983002943"}
0005433784740	3013B5	0481 170547	LYUDMILA DAVYDOVA	{"phone": "+70833404363"}
0005433784741	8B977C	1741 672301	EVGENIYA KAZAKOVA	{"phone": "+70412593114"}
0005433784742	8B977C	1149 383214	MARSEL PAVLOV	{"phone": "+70329988506"}
0005433784743	D31B05	2450 370097	VLADIMIR NOVIKOV	{"email": "vnovikov1983@postgrespro.ru", "phone": "+70145585674"}
0005433784744	34A3B3	0097 376713	NATALYA NIKITINA	{"email": "nikitina-natalya_121981@postgrespro.ru", "phone": "+70376037237"}
0005433784745	F0AE95	0876 717392	DMITRIY ZAYCEV	{"phone": "+70477685920"}
0005433784746	0CACD7	0203 242620	ALEKSANDR VASILEV	{"email": "avasilev1970@postgrespro.ru", "phone": "+70886855313"}
0005433784747	0CACD7	1441 722171	VERA KULIKOVA	{"phone": "+70809407998"}
0005433784748	5202B1	0614 391321	VALENTINA PETROVA	{"phone": "+70465440520"}
0005433784749	5202B1	1371 680656	ELENA YAKOVLEVA	{"phone": "+70606254650"}
0005433784750	1414F8	7180 988685	ANNA VOLKOVA	{"email": "anna.volkova101976@postgrespro.ru", "phone": "+70843262336"}
0005433784751	68473A	0418 257201	ANASTASIYA POLYAKOVA	{"phone": "+70745369215"}
0005433784752	3D9513	0518 074801	TARAS ZAYCEV	{"email": "zaycev.taras1961@postgrespro.ru", "phone": "+70294479516"}
0005433784753	E8E6A5	0404 220515	VALERIY ZAKHAROV	{"email": "zakharov.valeriy-1975@postgrespro.ru", "phone": "+70753329545"}
0005433784754	E8E6A5	3215 193130	ARTEM MAKAROV	{"email": "makarova-091981@postgrespro.ru", "phone": "+70145358049"}
0005433784755	E8E6A5	5372 531805	PETR GERASIMOV	{"email": "gerasimovp-1967@postgrespro.ru", "phone": "+70499074959"}
0005433784756	E8E6A5	7507 956176	ALEKSANDR KISELEV	{"email": "a-kiselev01011963@postgrespro.ru", "phone": "+70630612203"}
0005433784757	6FCBE0	3005 045356	EKATERINA GUSEVA	{"phone": "+70509817956"}
0005433784758	236DB9	8599 858217	ANNA MAKAROVA	{"email": "a-makarova.12091972@postgrespro.ru", "phone": "+70098250156"}
0005433784759	236DB9	1915 788391	ELENA KUZNECOVA	{"phone": "+70487094455"}
0005433784760	C70C8C	6665 900091	ELENA FOMINA	{"email": "elenafomina-021980@postgrespro.ru", "phone": "+70693137733"}
0005433784761	862537	4976 816587	VIKTORIYA MATVEEVA	{"phone": "+70792681620"}
0005433784762	862537	3860 245344	NIKOLAY BARANOV	{"email": "baranovnikolay-011968@postgrespro.ru", "phone": "+70062258104"}
0005433784763	0CCA18	8387 041926	ALEKSANDR KAZAKOV	{"email": "a_kazakov09041972@postgrespro.ru", "phone": "+70693140870"}
0005433784764	0CCA18	9635 432829	SERGEY ANDREEV	{"email": "andreev_sergey_15071971@postgrespro.ru", "phone": "+70048715300"}
0005433784765	100030	8416 311096	TATYANA ROMANOVA	{"email": "tromanova.1959@postgrespro.ru", "phone": "+70475039788"}
0005433784766	100030	3608 564392	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov-1981@postgrespro.ru", "phone": "+70400342937"}
0005433784767	AD30BA	4952 906147	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir-031970@postgrespro.ru", "phone": "+70930639792"}
0005433784768	98402C	9105 888726	VERA RYABOVA	{"phone": "+70763913987"}
0005433784769	FD7E39	1457 892212	NATALYA IVANOVA	{"email": "ivanova_n.27011973@postgrespro.ru", "phone": "+70260762495"}
0005433784770	FD7E39	8207 573525	ANDREY VLASOV	{"email": "a-vlasov_1957@postgrespro.ru", "phone": "+70368254997"}
0005433784771	371099	1621 040600	SVETLANA ZHUKOVA	{"email": "zhukova-svetlana_1974@postgrespro.ru", "phone": "+70198655748"}
0005433784772	F47A6C	2171 583829	EVGENIY TIKHONOV	{"phone": "+70246740978"}
0005433784773	3178F6	5264 659485	TAMARA KOROLEVA	{"email": "korolevatamara.10081963@postgrespro.ru", "phone": "+70611398331"}
0005433784774	3178F6	4588 720382	VALENTINA DANILOVA	{"email": "vdanilova_1971@postgrespro.ru", "phone": "+70040889029"}
0005433784775	450E25	8263 984673	PRASKOVYA ROMANOVA	{"email": "p.romanova-04111971@postgrespro.ru", "phone": "+70456551501"}
0005433784776	450E25	9627 163452	VIKTOR VOROBEV	{"email": "vorobevviktor.1971@postgrespro.ru", "phone": "+70859824495"}
0005433784777	74C7B0	7926 914672	NATALYA SEMENOVA	{"email": "nsemenova31031971@postgrespro.ru", "phone": "+70400859987"}
0005433785072	ECC05B	7819 432672	VLADIMIR MAKAROV	{"phone": "+70540496776"}
0005433784778	86F850	4155 507598	POLINA SCHERBAKOVA	{"email": "p.scherbakova_09091969@postgrespro.ru", "phone": "+70481111856"}
0005433784779	CDA8AE	5751 948457	YURIY BORISOV	{"email": "borisov_yuriy051975@postgrespro.ru", "phone": "+70932689234"}
0005433784780	BFF93C	7121 808916	KONSTANTIN GERASIMOV	{"email": "k-gerasimov-111970@postgrespro.ru", "phone": "+70825579180"}
0005433784781	A6B2F0	2020 978429	OLEG KUZNECOV	{"email": "oleg-kuznecov.111969@postgrespro.ru", "phone": "+70402743338"}
0005433784782	A6B2F0	7912 599694	VALERIY IVANOV	{"phone": "+70150849201"}
0005433784783	8067F7	8278 366379	ALEKSANDR SOKOLOV	{"phone": "+70436935001"}
0005433784784	8067F7	6516 664731	VYACHESLAV GERASIMOV	{"email": "gerasimov_vyacheslav.021965@postgrespro.ru", "phone": "+70207455459"}
0005433784785	3352FD	9690 686219	EVA BELOVA	{"email": "belovae081963@postgrespro.ru", "phone": "+70995184662"}
0005433784786	01A805	4156 816958	TATYANA SMIRNOVA	{"phone": "+70906310924"}
0005433784787	08BF54	0344 859275	ZOYA OSIPOVA	{"email": "osipova_z.10021964@postgrespro.ru", "phone": "+70811253818"}
0005433784788	8D2385	3222 337039	NINA VOLKOVA	{"email": "volkova.nina.1968@postgrespro.ru", "phone": "+70172394859"}
0005433784789	8D2385	2011 550581	GALINA FOMINA	{"email": "gfomina_1967@postgrespro.ru", "phone": "+70396703390"}
0005433784790	8D2385	8285 669276	TATYANA SMIRNOVA	{"email": "tsmirnova_16011979@postgrespro.ru", "phone": "+70421643421"}
0005433784791	78D1CA	4263 928931	RAISA KONOVALOVA	{"email": "raisa.konovalova02121970@postgrespro.ru", "phone": "+70704339043"}
0005433784792	F4D796	2025 847255	TATYANA MAKAROVA	{"email": "makarova-tatyana-1964@postgrespro.ru", "phone": "+70129987764"}
0005433784793	331572	2399 098371	IRINA MATVEEVA	{"email": "irina-matveeva.1965@postgrespro.ru", "phone": "+70881061131"}
0005433784794	F8D1BC	0865 412359	ANNA BELYAEVA	{"phone": "+70206491956"}
0005433784795	C9CC55	1533 938959	ANNA SIDOROVA	{"email": "asidorova_051978@postgrespro.ru", "phone": "+70488317612"}
0005433784796	C9CC55	4995 481115	VLADIMIR DMITRIEV	{"email": "v.dmitriev_1960@postgrespro.ru", "phone": "+70158725096"}
0005433784797	19BA86	4218 907319	NATALYA SOROKINA	{"email": "sorokina-n.1971@postgrespro.ru", "phone": "+70752655283"}
0005433784798	56BAF6	4763 361479	MARIYA IVANOVA	{"phone": "+70960845588"}
0005433784799	56BAF6	7353 000683	ALEKSANDRA KUZNECOVA	{"phone": "+70414752231"}
0005433784800	8BA9DB	1835 199033	EKATERINA ZHURAVLEVA	{"phone": "+70905840833"}
0005433784801	E7C42B	6609 020796	NADEZHDA MIRONOVA	{"email": "mironova_nadezhda27041971@postgrespro.ru", "phone": "+70601143655"}
0005433784802	E7C42B	2805 153752	VYACHESLAV SEMENOV	{"phone": "+70926498181"}
0005433784803	F960B6	3768 290478	DMITRIY KAZAKOV	{"email": "dkazakov.081970@postgrespro.ru", "phone": "+70049953893"}
0005433784804	4106BC	5054 328460	SERGEY MAKAROV	{"email": "sergey-makarov_101964@postgrespro.ru", "phone": "+70617548112"}
0005433784805	4106BC	3438 493649	YANA RYABOVA	{"phone": "+70054760981"}
0005433784806	18C917	9415 210615	ANTON SCHERBAKOV	{"email": "ascherbakov-1978@postgrespro.ru", "phone": "+70340634915"}
0005433784807	82ADAF	7096 035482	NIKOLAY MOROZOV	{"phone": "+70973965355"}
0005433784808	0BD152	6307 196657	DANIIL ROMANOV	{"email": "d_romanov-101972@postgrespro.ru", "phone": "+70313504372"}
0005433784809	B0B80A	5160 010309	ALEKSANDRA OVCHINNIKOVA	{"email": "ovchinnikova.a.011968@postgrespro.ru", "phone": "+70455146840"}
0005433784810	54AA92	1450 327891	PRASKOVYA KOZLOVA	{"phone": "+70693541664"}
0005433784811	2EAAD8	9745 301189	OKSANA MIKHAYLOVA	{"email": "oksanamikhaylova04101977@postgrespro.ru", "phone": "+70834927180"}
0005433784812	2EAAD8	1066 184887	VLADIMIR KARPOV	{"email": "vladimirkarpov11061987@postgrespro.ru", "phone": "+70398880357"}
0005433784813	DD2F1D	2381 473134	MARIYA KUZNECOVA	{"email": "kuznecova_m.1975@postgrespro.ru", "phone": "+70715521061"}
0005433784814	E26003	2170 771314	DARYA KALININA	{"email": "kalinina_d20041980@postgrespro.ru", "phone": "+70183652136"}
0005433784815	E26003	9568 342807	ELENA DAVYDOVA	{"email": "e-davydova-02061967@postgrespro.ru", "phone": "+70741129739"}
0005433784816	E26003	6895 334995	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva011986@postgrespro.ru", "phone": "+70118843306"}
0005433784817	B36EC4	2787 622972	POLINA KOLESNIKOVA	{"phone": "+70668901483"}
0005433784818	7A6AB2	2647 266842	VASILIY SAVELEV	{"phone": "+70186670383"}
0005433784819	DDAA87	6017 245138	TAMARA KUZMINA	{"phone": "+70907942250"}
0005433784820	7EF082	4917 468707	MARIYA VASILEVA	{"phone": "+70238830540"}
0005433784821	62E55B	6540 571622	ILGIZ TARASOV	{"email": "i-tarasov14081973@postgrespro.ru", "phone": "+70202764653"}
0005433784822	2770E8	1286 452151	ELIZAVETA NAZAROVA	{"phone": "+70585164732"}
0005433784823	DF33DF	4682 601510	VLADIMIR PAVLOV	{"email": "pavlov.vladimir1977@postgrespro.ru", "phone": "+70020447091"}
0005433784824	355D59	5898 807723	VERONIKA EFREMOVA	{"email": "efremova_veronika.05061974@postgrespro.ru", "phone": "+70296032994"}
0005433784825	355D59	4825 465711	SVYATOSLAV PETROV	{"phone": "+70554902814"}
0005433784826	CCF6AA	4657 195504	ALEKSANDR MATVEEV	{"email": "matveev_a_121970@postgrespro.ru", "phone": "+70598951313"}
0005433784827	8F55F5	8442 430880	DENIS ZAKHAROV	{"email": "zakharovdenis-29061963@postgrespro.ru", "phone": "+70547659534"}
0005433784828	5D907D	3784 512928	SERGEY CHERNOV	{"email": "chernov_sergey.101973@postgrespro.ru", "phone": "+70044128162"}
0005433784829	5D907D	9242 900510	ELENA GRISHINA	{"phone": "+70054554401"}
0005433784830	7E7B21	1614 490985	VENIAMIN SERGEEV	{"email": "sergeev.veniamin.011965@postgrespro.ru", "phone": "+70613400291"}
0005433784831	31AD6F	1798 691420	ALEKSEY GUSEV	{"email": "gusev_aleksey.1978@postgrespro.ru", "phone": "+70459243685"}
0005433784832	F5A9EB	8807 611508	ALEKSANDR ALEKSEEV	{"email": "alekseeva.1962@postgrespro.ru", "phone": "+70455897226"}
0005433784833	AE47ED	6561 268444	MIKHAIL IVANOV	{"email": "ivanov_mikhail_1974@postgrespro.ru", "phone": "+70436226818"}
0005433785135	B15E3D	7858 821642	NAIL ANDREEV	{"phone": "+70506869856"}
0005433784834	2C89F6	9969 367383	VASILIY TARASOV	{"email": "tarasov_v_12091966@postgrespro.ru", "phone": "+70281526319"}
0005433784835	2C89F6	7641 784676	VALERIYA LUKYANOVA	{"phone": "+70125580479"}
0005433784836	2C89F6	1760 802798	TATYANA SOLOVEVA	{"phone": "+70106794024"}
0005433784837	1782A0	4431 106751	LYUDMILA FILIPPOVA	{"email": "lyudmilafilippova.1969@postgrespro.ru", "phone": "+70298115163"}
0005433784894	38B414	8233 869123	MIKHAIL FEDOTOV	{"phone": "+70333952785"}
0005433784838	1782A0	3647 596562	TATYANA NESTEROVA	{"email": "t_nesterova-1982@postgrespro.ru", "phone": "+70216733428"}
0005433784839	5443EB	7128 494658	MAKSIM POPOV	{"phone": "+70056541257"}
0005433784840	5443EB	2323 424811	VYACHESLAV GORBUNOV	{"email": "gorbunovvyacheslav.081981@postgrespro.ru", "phone": "+70246944923"}
0005433784841	F0A215	3611 090690	ANNA MATVEEVA	{"email": "matveeva-anna_1974@postgrespro.ru", "phone": "+70434208252"}
0005433784842	314D0B	7122 769887	IGOR PAVLOV	{"phone": "+70982345743"}
0005433784843	A0C949	8610 976098	YAROSLAV TIKHONOV	{"phone": "+70661479940"}
0005433784844	D35F9F	6428 851422	IVAN SAVELEV	{"phone": "+70526061224"}
0005433784845	D35F9F	2553 781053	PAVEL CHERNOV	{"email": "chernov-p-1962@postgrespro.ru", "phone": "+70039895748"}
0005433784846	D35F9F	3204 905507	KIRA PETROVA	{"email": "k-petrova.061972@postgrespro.ru", "phone": "+70717044756"}
0005433784847	4FD979	1883 789594	YURIY OSIPOV	{"phone": "+70567441474"}
0005433784848	4FD979	7746 313311	ANDREY BELOV	{"email": "belov-a.071971@postgrespro.ru", "phone": "+70402646339"}
0005433784849	F1B5E6	9493 595934	ANNA GUSEVA	{"email": "annaguseva_1968@postgrespro.ru", "phone": "+70859174859"}
0005433784850	F1B5E6	6249 255464	NINA ANDREEVA	{"phone": "+70671661710"}
0005433784851	1F0F5C	7954 931104	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov101985@postgrespro.ru", "phone": "+70828461930"}
0005433784852	FEDF61	6341 560242	SVETLANA BOGDANOVA	{"phone": "+70798635158"}
0005433784853	FEDF61	5176 101203	YURIY ISAEV	{"email": "yisaev-09071975@postgrespro.ru", "phone": "+70199987820"}
0005433784854	09AE79	7900 467145	VLADIMIR KRASNOV	{"email": "krasnov_v_021974@postgrespro.ru", "phone": "+70125035818"}
0005433784855	1E75B7	8476 995522	MARIYA YAKOVLEVA	{"phone": "+70924645569"}
0005433784856	1E75B7	0559 131466	TAISIYA AKIMOVA	{"email": "akimovataisiya-08111962@postgrespro.ru", "phone": "+70862746863"}
0005433784857	1E75B7	5895 256288	ELENA NIKOLAEVA	{"email": "e_nikolaeva-1964@postgrespro.ru", "phone": "+70845600285"}
0005433784858	C1ACFA	3106 230481	ANDREY MATVEEV	{"phone": "+70906382674"}
0005433784859	D4C394	3248 069025	LARISA ILINA	{"email": "ilinalarisa_011970@postgrespro.ru", "phone": "+70253765863"}
0005433784860	DBFF75	9067 901248	SERGEY MIKHAYLOV	{"email": "s_mikhaylov.1980@postgrespro.ru", "phone": "+70263224409"}
0005433784861	DBFF75	4887 490023	DMITRIY ANTONOV	{"email": "antonov_d_14031973@postgrespro.ru", "phone": "+70279528543"}
0005433784862	308A4E	8143 687031	ZINAIDA PETROVA	{"phone": "+70780747032"}
0005433784863	9B8D75	2220 115367	NIKOLAY SCHERBAKOV	{"phone": "+70228422224"}
0005433784864	18F445	1940 464676	KLAVDIYA VASILEVA	{"email": "vasileva_k03031975@postgrespro.ru", "phone": "+70841503872"}
0005433784865	41B293	8459 684566	KLAVDIYA MARTYNOVA	{"email": "martynova_klavdiya-1975@postgrespro.ru", "phone": "+70626840127"}
0005433784866	41B293	9926 150769	PAVEL VASILEV	{"email": "vasilev_p.031976@postgrespro.ru", "phone": "+70951253113"}
0005433784867	CD865F	3839 335688	GALINA BORISOVA	{"phone": "+70482390991"}
0005433784868	CD865F	7636 057563	VYACHESLAV FOMIN	{"email": "fomin.vyacheslav1974@postgrespro.ru", "phone": "+70377149841"}
0005433784869	CD865F	6847 304038	EKATERINA LAZAREVA	{"phone": "+70061952188"}
0005433784870	853FA8	4367 890883	GLEB SCHERBAKOV	{"email": "scherbakov.g.081973@postgrespro.ru", "phone": "+70172264677"}
0005433784871	BCF796	7182 405316	VIKTOR ZAKHAROV	{"email": "zakharov_v.26031971@postgrespro.ru", "phone": "+70954314831"}
0005433784872	F48DB6	6355 879241	SEMEN NIKOLAEV	{"email": "s_nikolaev.071973@postgrespro.ru", "phone": "+70884967076"}
0005433784873	F48DB6	6264 537925	TATYANA DANILOVA	{"email": "danilova-t1973@postgrespro.ru", "phone": "+70617178869"}
0005433784874	84C424	4296 310040	VIKTOR KUZNECOV	{"email": "v-kuznecov-22111960@postgrespro.ru", "phone": "+70673991199"}
0005433784875	54059D	8106 486455	DMITRIY ORLOV	{"email": "orlov-d041982@postgrespro.ru", "phone": "+70862148052"}
0005433784876	25B752	4274 689787	SVETLANA ERMAKOVA	{"phone": "+70263779887"}
0005433784877	6228CD	1237 535358	MIKHAIL TIMOFEEV	{"phone": "+70898834730"}
0005433784878	C9FB56	4649 867271	SHAMIL PETROV	{"phone": "+70454689101"}
0005433784879	9EF5D1	1960 410469	SVETLANA TARASOVA	{"email": "svetlanatarasova.1977@postgrespro.ru", "phone": "+70721137056"}
0005433784880	9EF5D1	7045 642572	IRINA NIKITINA	{"phone": "+70763515033"}
0005433784881	4EFE12	2728 658821	IGOR FEDOTOV	{"phone": "+70319711941"}
0005433784882	4EFE12	7252 869684	ALEKSANDR EGOROV	{"phone": "+70592818508"}
0005433784883	4EFE12	0332 461871	ELENA NIKITINA	{"email": "nikitinae-081968@postgrespro.ru", "phone": "+70756813528"}
0005433784884	EEF097	8672 348404	ALEKSEY CHERNOV	{"email": "chernovaleksey-29061970@postgrespro.ru", "phone": "+70575102264"}
0005433784885	EEF097	5415 555957	YURIY MAKAROV	{"phone": "+70522236097"}
0005433784886	55FC79	7353 189086	VERA PETROVA	{"email": "petrova.vera-11041971@postgrespro.ru", "phone": "+70267550786"}
0005433784887	859338	0715 703476	DARYA KOVALEVA	{"phone": "+70866356126"}
0005433784888	F43827	6356 085692	RUSTEM FILIPPOV	{"email": "filippov.r_28091981@postgrespro.ru", "phone": "+70173318136"}
0005433784889	838C63	6042 010896	IRINA KOROLEVA	{"phone": "+70877250460"}
0005433784890	9442E8	4873 299363	MARINA KOMAROVA	{"email": "komarova_marina_1975@postgrespro.ru", "phone": "+70516672684"}
0005433784891	9442E8	6023 557338	ANASTASIYA FROLOVA	{"phone": "+70429580593"}
0005433785136	5BCB46	4142 847594	IGOR ZHUKOV	{"phone": "+70322336758"}
0005433784892	9EE3A5	5295 233026	LYUDMILA ILINA	{"email": "ilina.lyudmila-08031964@postgrespro.ru", "phone": "+70948014541"}
0005433784893	9EE3A5	1713 472678	VIKTOR KULIKOV	{"email": "v-kulikov.121971@postgrespro.ru", "phone": "+70081100664"}
0005433784895	303A94	3012 954681	NATALYA MAKSIMOVA	{"phone": "+70422658042"}
0005433784896	1DC413	4152 855886	VLADIMIR SIDOROV	{"email": "v-sidorov_021970@postgrespro.ru", "phone": "+70386921127"}
0005433784897	28F97B	3853 810308	VIKTOR IVANOV	{"phone": "+70434672762"}
0005433784898	28F97B	2369 149457	VADIM SAVELEV	{"email": "vadim-savelev-1973@postgrespro.ru", "phone": "+70277507271"}
0005433784899	21D22E	9069 558033	INNA SEMENOVA	{"email": "innasemenova06061969@postgrespro.ru", "phone": "+70757621213"}
0005433784900	5950BA	9753 468676	EKATERINA KARPOVA	{"phone": "+70237593376"}
0005433784901	4656E6	4303 182557	VALENTINA GUSEVA	{"email": "valentina-guseva-1966@postgrespro.ru", "phone": "+70831814049"}
0005433784902	0DC31F	3793 323631	DARINA VLASOVA	{"email": "d.vlasova.1968@postgrespro.ru", "phone": "+70289956612"}
0005433784903	55A0AD	0302 066949	MARIYA ZAKHAROVA	{"phone": "+70634289920"}
0005433784904	55A0AD	4625 528855	IGOR DENISOV	{"email": "denisov.igor.081976@postgrespro.ru", "phone": "+70046159345"}
0005433784905	37BF15	4071 963071	MAKSIM KRASNOV	{"email": "krasnov_maksim.021969@postgrespro.ru", "phone": "+70715009952"}
0005433784906	36E582	5233 872257	NIKOLAY POPOV	{"email": "popov_n.1968@postgrespro.ru", "phone": "+70407270099"}
0005433784907	36E582	7600 195755	ELENA ALEKSANDROVA	{"email": "aleksandrova_elena1973@postgrespro.ru", "phone": "+70786172466"}
0005433784908	B04F97	9213 751386	NATALYA LAZAREVA	{"phone": "+70222237880"}
0005433784909	E95BFF	3544 870786	YURIY BELOV	{"email": "yuriy_belov021973@postgrespro.ru", "phone": "+70619416538"}
0005433784910	BF2AA6	6642 616424	VALERIY DENISOV	{"email": "valeriy-denisov051969@postgrespro.ru", "phone": "+70395670937"}
0005433784911	4E4A4A	5153 563877	VALERIY STEPANOV	{"email": "stepanovv-30091974@postgrespro.ru", "phone": "+70837213409"}
0005433784912	891190	2771 586497	INNA MELNIKOVA	{"email": "imelnikova_04071977@postgrespro.ru", "phone": "+70924995310"}
0005433784913	FF3D8C	4851 525492	AMIR IVANOV	{"email": "ivanov.amir.1979@postgrespro.ru", "phone": "+70281662736"}
0005433784914	FF3D8C	3390 848514	MARIYA ZAKHAROVA	{"phone": "+70575085477"}
0005433784915	D469FB	5508 578764	NINA BELOVA	{"phone": "+70580473369"}
0005433784916	B8BF1F	7528 414114	VIKTOR ANTONOV	{"email": "antonovviktor.081975@postgrespro.ru", "phone": "+70358042955"}
0005433784917	35BC1C	8794 546951	PETR VASILEV	{"phone": "+70397449197"}
0005433784918	9D9835	7731 433195	TATYANA KUZMINA	{"email": "t.kuzmina30041968@postgrespro.ru", "phone": "+70586782462"}
0005433784919	9D9835	4861 456419	VIKTOR EGOROV	{"email": "egorov-viktor_031980@postgrespro.ru", "phone": "+70615594268"}
0005433784920	1CE46E	2684 011003	ALEKSANDR MIKHAYLOV	{"phone": "+70234924499"}
0005433784921	079E86	5945 541625	MIKHAIL SHEVCHENKO	{"phone": "+70914145395"}
0005433784922	079E86	4651 643001	ELENA ALEKSEEVA	{"phone": "+70182192294"}
0005433784923	64127B	7080 925684	YULIYA LEBEDEVA	{"email": "yuliyalebedeva08031981@postgrespro.ru", "phone": "+70656299801"}
0005433784924	0C1E40	9652 655237	MARIYA SEMENOVA	{"email": "m-semenova.02031979@postgrespro.ru", "phone": "+70179736144"}
0005433784925	0C1E40	5475 412665	ALEKSEY KOROLEV	{"email": "koroleva11041982@postgrespro.ru", "phone": "+70573464460"}
0005433784926	0C1E40	3276 877667	ALEKSEY CHERNOV	{"phone": "+70803129374"}
0005433784927	42A639	2013 494772	MARIYA IVANOVA	{"phone": "+70566077739"}
0005433784928	42A639	8762 322626	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr.19121970@postgrespro.ru", "phone": "+70363019926"}
0005433784929	8AD3FC	0120 842905	EKATERINA TIKHONOVA	{"phone": "+70877602607"}
0005433784930	A1ABCF	3159 363839	ALEKSANDR OSIPOV	{"phone": "+70886073858"}
0005433784931	9CFF8D	8998 207992	LYUDMILA AKIMOVA	{"email": "akimoval_1987@postgrespro.ru", "phone": "+70383546831"}
0005433784932	9CFF8D	7626 746544	DMITRIY VOLKOV	{"email": "dmitriyvolkov18101968@postgrespro.ru", "phone": "+70922584580"}
0005433784933	D6EAF8	0290 230172	ALEVTINA NIKITINA	{"email": "a_nikitina1980@postgrespro.ru", "phone": "+70334501434"}
0005433784934	8DCCD7	3926 095982	MIKHAIL VLASOV	{"phone": "+70333732297"}
0005433784935	F4BB92	8523 983868	ANATOLIY NIKOLAEV	{"phone": "+70741730364"}
0005433784936	F4BB92	2850 352543	ANDREY ALEKSEEV	{"email": "aalekseev.111962@postgrespro.ru", "phone": "+70342070580"}
0005433784937	3CDB36	0873 083393	KRISTINA ROMANOVA	{"email": "k-romanova111976@postgrespro.ru", "phone": "+70338892904"}
0005433784938	F1B624	8919 301248	EKATERINA BELOVA	{"email": "ekaterinabelova_081978@postgrespro.ru", "phone": "+70227644667"}
0005433784939	F47887	8872 415533	VALERIY EGOROV	{"phone": "+70774535118"}
0005433784940	3F0B87	4511 944680	TAMARA IVANOVA	{"email": "tamaraivanova_17101972@postgrespro.ru", "phone": "+70403037664"}
0005433784941	16A753	3044 301183	PAVEL ZAKHAROV	{"phone": "+70419578433"}
0005433784942	16A753	5316 705843	ALEKSANDR SOKOLOV	{"phone": "+70498185386"}
0005433784943	3C0E2C	8924 767211	TATYANA MASLOVA	{"phone": "+70931700086"}
0005433784944	A1041B	7093 746260	YURIY NIKOLAEV	{"email": "y-nikolaev_30051976@postgrespro.ru", "phone": "+70448910909"}
0005433784945	0D3B2F	7563 175225	NATALYA SEMENOVA	{"phone": "+70111804798"}
0005433784946	0A467C	4487 849171	ALENA SCHERBAKOVA	{"email": "scherbakovaalena-021978@postgrespro.ru", "phone": "+70818966047"}
0005433784947	41CBE2	3446 265339	DAMIR MIKHAYLOV	{"phone": "+70092229115"}
0005433784948	F14868	5847 686050	YULIYA DANILOVA	{"email": "yuliya-danilova1968@postgrespro.ru", "phone": "+70570805304"}
0005433784949	FD69DD	2844 944345	EKATERINA ANTONOVA	{"phone": "+70977495890"}
0005433784950	BFD580	6327 580094	ANTONINA GERASIMOVA	{"phone": "+70354884378"}
0005433784951	AB581F	1779 578543	LYUBOV GERASIMOVA	{"phone": "+70566986089"}
0005433784952	5E17B9	2339 662135	ANATOLIY MIRONOV	{"email": "mironov_a.011962@postgrespro.ru", "phone": "+70621993819"}
0005433784953	5E17B9	9130 161768	LIDIYA MOROZOVA	{"email": "lidiya-morozova1971@postgrespro.ru", "phone": "+70881552466"}
0005433784954	ACB105	6548 980134	MARIYA FILIPPOVA	{"phone": "+70742222124"}
0005433784955	6BC80E	8977 912538	NADEZHDA SOROKINA	{"email": "nadezhdasorokina_18031972@postgrespro.ru", "phone": "+70178878712"}
0005433784956	4672BC	5868 082789	ALEKSANDRA POPOVA	{"phone": "+70104853356"}
0005433784957	4672BC	0567 544845	ELENA MAKAROVA	{"phone": "+70654830717"}
0005433784958	08C56B	9129 747108	NATALYA RODIONOVA	{"phone": "+70988328395"}
0005433784959	08C56B	1641 256403	ARTEM SMIRNOV	{"email": "a_smirnov15061955@postgrespro.ru", "phone": "+70663434117"}
0005433784960	931815	2680 904874	ELENA KUZNECOVA	{"email": "elena_kuznecova_051986@postgrespro.ru", "phone": "+70478518144"}
0005433784961	931815	8992 900377	EKATERINA SIDOROVA	{"phone": "+70731479057"}
0005433784962	6E62B0	5907 814056	ALEKSANDRA NESTEROVA	{"phone": "+70720916722"}
0005433784963	6E62B0	0845 952216	SERGEY FOMIN	{"email": "fomin-s_1977@postgrespro.ru", "phone": "+70473283289"}
0005433784964	724018	2122 629314	SERGEY BONDARENKO	{"phone": "+70035640132"}
0005433784965	E7F956	3105 937703	ALI IVANOV	{"email": "ivanov-ali-1971@postgrespro.ru", "phone": "+70854851875"}
0005433784966	46AFD7	1577 242371	DMITRIY KRASNOV	{"phone": "+70383441134"}
0005433784967	7DDAA0	0819 789521	YURIY POPOV	{"email": "y_popov_1972@postgrespro.ru", "phone": "+70126770510"}
0005433784968	C84344	0087 822730	IRINA STEPANOVA	{"phone": "+70660474644"}
0005433784969	C84344	2687 562871	ALEKSANDR MIKHAYLOV	{"phone": "+70480676815"}
0005433784970	C3D512	4875 034112	DIANA MOROZOVA	{"phone": "+70443245560"}
0005433784971	FECF2D	8837 013464	ILYA SCHERBAKOV	{"email": "scherbakov.i-071971@postgrespro.ru", "phone": "+70722049275"}
0005433784972	B1C111	9363 256713	VASILIY EGOROV	{"email": "egorov_vasiliy.1977@postgrespro.ru", "phone": "+70257640282"}
0005433784973	74621C	1016 077553	OLGA PETROVA	{"phone": "+70195851607"}
0005433784974	CCAF31	4839 875941	OLGA FEDOROVA	{"phone": "+70242458746"}
0005433784975	336A24	0903 287115	ANTONINA VOROBEVA	{"email": "vorobeva.a101970@postgrespro.ru", "phone": "+70119052698"}
0005433784976	336A24	1117 932604	ANNA ISAEVA	{"phone": "+70297006197"}
0005433784977	5ABAAA	9277 343128	SERGEY MOROZOV	{"phone": "+70951417858"}
0005433784978	2219A8	2208 353715	ALEKSANDR KONOVALOV	{"phone": "+70016821715"}
0005433784979	037B16	4913 511718	MARIYA KOZLOVA	{"email": "mariya_kozlova1979@postgrespro.ru", "phone": "+70399000088"}
0005433784980	037B16	9964 686202	SERGEY SERGEEV	{"email": "sergeev.sergey_1976@postgrespro.ru", "phone": "+70137138164"}
0005433784981	3B59E4	3589 614514	NATALYA FILIPPOVA	{"phone": "+70121840297"}
0005433784982	97FA31	5386 181112	MIKHAIL KULIKOV	{"phone": "+70303938963"}
0005433784983	E16C51	7122 912942	BORIS KUDRYASHOV	{"email": "boris-kudryashov.16101975@postgrespro.ru", "phone": "+70603553060"}
0005433784984	E16C51	8964 799017	VIKTOR VASILEV	{"phone": "+70236956924"}
0005433784985	164977	6024 793641	VLADIMIR GUSEV	{"phone": "+70808554084"}
0005433784986	EC4318	8862 828274	LIDIYA GAVRILOVA	{"email": "l-gavrilova-121966@postgrespro.ru", "phone": "+70140927778"}
0005433784987	EC4318	9126 840003	ZINAIDA NIKOLAEVA	{"email": "z-nikolaeva07081969@postgrespro.ru", "phone": "+70303783220"}
0005433784988	E3CA85	8199 044526	DENIS ANDREEV	{"phone": "+70153919703"}
0005433784989	15CDEF	8714 887135	IRINA BORISOVA	{"email": "irinaborisova_30061967@postgrespro.ru", "phone": "+70078442739"}
0005433784990	AF8AF6	5603 925622	FEDOR KRASNOV	{"phone": "+70199197916"}
0005433784991	0EABFE	0373 912698	ANATOLIY MIRONOV	{"email": "anatoliy.mironov.081972@postgrespro.ru", "phone": "+70204708450"}
0005433784992	2E4F4A	7461 096001	LARISA STEPANOVA	{"email": "stepanova_l1964@postgrespro.ru", "phone": "+70780205080"}
0005433784993	0A2642	7449 184834	NIKOLAY GUSEV	{"phone": "+70148571100"}
0005433784994	0A2642	1313 003941	ALEKSEY RODIONOV	{"email": "arodionov.021968@postgrespro.ru", "phone": "+70589587791"}
0005433784995	D8FF54	9711 841748	ALEKSANDR ZHUKOV	{"phone": "+70090793043"}
0005433784996	E87FF4	8173 563850	VERA PAVLOVA	{"phone": "+70438829409"}
0005433784997	6EC0AB	2095 077566	ANDREY FROLOV	{"email": "frolova-1963@postgrespro.ru", "phone": "+70121034591"}
0005433784998	1E0BB0	7919 830637	EVGENIY SOKOLOV	{"email": "e_sokolov.26101963@postgrespro.ru", "phone": "+70978597457"}
0005433784999	2C0162	9031 712502	VADIM EGOROV	{"phone": "+70502509059"}
0005433785000	2C0162	9242 064430	MARINA BOGDANOVA	{"phone": "+70226079149"}
0005433785001	26CAA6	5151 145178	GENNADIY MAKAROV	{"phone": "+70288880761"}
0005433785002	846AE5	7451 390798	RADIK SOKOLOV	{"email": "sokolovradik021971@postgrespro.ru", "phone": "+70485348572"}
0005433785003	846AE5	6289 632658	VALENTINA SOROKINA	{"email": "valentina.sorokina_1956@postgrespro.ru", "phone": "+70631444786"}
0005433785004	789780	7455 671243	YULIYA MOISEEVA	{"email": "y-moiseeva_1975@postgrespro.ru", "phone": "+70928710830"}
0005433785005	789780	4678 647912	ZINAIDA EGOROVA	{"email": "egorova_zinaida-1961@postgrespro.ru", "phone": "+70297965632"}
0005433785006	789780	4856 105690	ALEKSEY PAVLOV	{"email": "pavlov_aleksey-1969@postgrespro.ru", "phone": "+70844386499"}
0005433785397	CE4454	6981 198634	ANDREY VOLKOV	{"phone": "+70320671744"}
0005433785007	06FED0	8171 118468	DMITRIY MARTYNOV	{"email": "martynovdmitriy.101972@postgrespro.ru", "phone": "+70659136482"}
0005433785008	D64B73	0277 152903	ELDAR MIKHAYLOV	{"phone": "+70668610127"}
0005433785009	43651F	5140 313821	VIKTOR BORISOV	{"email": "viktor.borisov.011987@postgrespro.ru", "phone": "+70499920464"}
0005433785010	599A5D	7709 408342	EVGENIY MAKAROV	{"phone": "+70555903693"}
0005433785011	43C321	6119 317500	YULIYA KARPOVA	{"email": "y.karpova041966@postgrespro.ru", "phone": "+70438470821"}
0005433785012	43C321	1350 768033	EKATERINA NIKITINA	{"email": "nikitina.ekaterina20081965@postgrespro.ru", "phone": "+70175887529"}
0005433785013	F377E5	5539 737423	LEV VOROBEV	{"phone": "+70376478924"}
0005433785014	4F5CAA	5580 703433	VIKTOR SCHERBAKOV	{"email": "viktorscherbakov071974@postgrespro.ru", "phone": "+70025936014"}
0005433785015	84C3F5	1401 299450	ANDREY FILIPPOV	{"email": "a-filippov.1964@postgrespro.ru", "phone": "+70774015673"}
0005433785016	7734A5	3934 121698	ALEKSEY EGOROV	{"phone": "+70567443848"}
0005433785017	7734A5	5562 764345	SVETLANA SIDOROVA	{"phone": "+70135650773"}
0005433785018	7734A5	3427 922602	ALEKSANDR ANTONOV	{"phone": "+70500837048"}
0005433785019	7734A5	1117 996797	MIKHAIL IVANOV	{"email": "mikhail-ivanov.101964@postgrespro.ru", "phone": "+70548364930"}
0005433785020	7734A5	9867 829246	SVETLANA IVANOVA	{"phone": "+70415515725"}
0005433785021	3A7D09	5121 510940	DENIS DMITRIEV	{"email": "denis-dmitriev-1975@postgrespro.ru", "phone": "+70510945946"}
0005433785022	1FA166	4703 936858	VALENTIN CHERNOV	{"phone": "+70106629845"}
0005433785023	FCE5F0	1820 519002	ALEKSEY KUZNECOV	{"phone": "+70116665074"}
0005433785024	CFCD53	7459 697583	VALERIY KUZNECOV	{"email": "kuznecovvaleriy1968@postgrespro.ru", "phone": "+70481705742"}
0005433785025	CAC440	9288 822450	ANDREY GRIGOREV	{"phone": "+70892988286"}
0005433785026	55A325	6529 891100	VLADIMIR GUSEV	{"phone": "+70964676079"}
0005433785027	55A325	0107 289921	VLADIMIR EGOROV	{"phone": "+70439458361"}
0005433785028	478426	8006 118846	ELENA IVANOVA	{"phone": "+70708538395"}
0005433785029	287FD2	9139 646068	TAISIYA KONDRATEVA	{"phone": "+70697390896"}
0005433785030	287FD2	9853 428951	ARTEM SOLOVEV	{"email": "artem-solovev-22021973@postgrespro.ru", "phone": "+70416799266"}
0005433785031	CDC9FE	8062 254963	AZAT SERGEEV	{"phone": "+70216451720"}
0005433785032	CDC9FE	2376 670163	NINA NIKIFOROVA	{"email": "ninanikiforova061972@postgrespro.ru", "phone": "+70615055375"}
0005433785033	DB3D08	3454 700567	ALEKSEY FILIPPOV	{"email": "aleksey-filippov_1975@postgrespro.ru", "phone": "+70781730295"}
0005433785034	43EEA0	8256 259508	ZINAIDA ROMANOVA	{"email": "zinaidaromanova021965@postgrespro.ru", "phone": "+70686961220"}
0005433785035	1AE9BE	2684 876378	NATALYA AKIMOVA	{"phone": "+70975219848"}
0005433785036	1AE9BE	9696 239754	KLAVDIYA VLASOVA	{"phone": "+70548153195"}
0005433785037	1AE9BE	1166 397783	IVAN TIKHONOV	{"phone": "+70841173177"}
0005433785038	02B183	6246 145443	ILYA RODIONOV	{"email": "irodionov_1969@postgrespro.ru", "phone": "+70871642543"}
0005433785039	89FB79	8093 035848	ANDREY SIDOROV	{"email": "andrey-sidorov1968@postgrespro.ru", "phone": "+70417964389"}
0005433785040	89FB79	6874 301888	ALEKSEY ZAYCEV	{"email": "zaycev-aleksey_011978@postgrespro.ru", "phone": "+70675869950"}
0005433785041	731817	0016 972174	PAVEL GERASIMOV	{"phone": "+70166907421"}
0005433785042	F467C9	7397 461161	EVGENIY OSIPOV	{"phone": "+70884792051"}
0005433785043	E37106	0901 066211	ALEKSANDR DENISOV	{"email": "aleksandrdenisov_091983@postgrespro.ru", "phone": "+70506783109"}
0005433785044	8C8314	3857 883295	ANDREY KONOVALOV	{"email": "konovalov.a06081967@postgrespro.ru", "phone": "+70277799583"}
0005433785045	446419	4241 899878	NATALYA SMIRNOVA	{"phone": "+70802819443"}
0005433785046	446419	7700 333160	VIKTOR SOKOLOV	{"email": "viktor-sokolov_031972@postgrespro.ru", "phone": "+70780608564"}
0005433785047	CDE50D	5313 862298	ANNA MOROZOVA	{"email": "morozova_a061965@postgrespro.ru", "phone": "+70495380899"}
0005433785048	4FE768	4040 198287	SERGEY TIKHONOV	{"phone": "+70426514622"}
0005433785049	055B1A	7063 571460	DANILA ISAEV	{"phone": "+70833474049"}
0005433785050	055B1A	0812 946530	ANDREY DAVYDOV	{"email": "davydov_a_31031964@postgrespro.ru", "phone": "+70371492220"}
0005433785051	055B1A	2045 620487	ALINA KISELEVA	{"email": "alina.kiseleva-011970@postgrespro.ru", "phone": "+70272986231"}
0005433785052	9F404A	2001 207029	ANNA ROMANOVA	{"phone": "+70612061949"}
0005433785053	8C1B5A	2856 748959	OLEG SOROKIN	{"email": "sorokin-oleg-121973@postgrespro.ru", "phone": "+70283437571"}
0005433785054	8C1B5A	5619 992947	ANATOLIY FEDOTOV	{"email": "a_fedotov-1967@postgrespro.ru", "phone": "+70304014452"}
0005433785055	7429BC	3207 991011	TATYANA CHERNOVA	{"phone": "+70392297249"}
0005433785056	E54CB5	1404 608527	NIKOLAY NIKOLAEV	{"phone": "+70586182560"}
0005433785057	A80D18	6138 239985	ANDREY KUZNECOV	{"email": "kuznecov_andrey.22011965@postgrespro.ru", "phone": "+70117775598"}
0005433785058	D3C499	1615 059600	ANDREY SEMENOV	{"email": "semenov.andrey.1971@postgrespro.ru", "phone": "+70248028643"}
0005433785059	B91748	9200 971430	TATYANA LUKYANOVA	{"phone": "+70350571717"}
0005433785060	61EDFC	4649 438510	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.051976@postgrespro.ru", "phone": "+70592396875"}
0005433785061	58B025	9330 047608	RAISA SAVELEVA	{"email": "saveleva-r_051968@postgrespro.ru", "phone": "+70622322261"}
0005433785062	58B025	5334 349042	LYUBOV AKIMOVA	{"email": "akimova.lyubov.20061975@postgrespro.ru", "phone": "+70538259347"}
0005433785063	43BC03	4432 424172	ANASTASIYA PETROVA	{"email": "petrova-anastasiya_01071971@postgrespro.ru", "phone": "+70117934348"}
0005433785064	3790AB	7457 634019	ALEKSEY EGOROV	{"phone": "+70571820459"}
0005433785065	CB4FE1	3348 266877	EVDOKIYA DANILOVA	{"email": "danilova_evdokiya-091968@postgrespro.ru", "phone": "+70479766070"}
0005433785066	CB4FE1	9335 129371	TATYANA KOROLEVA	{"phone": "+70947779734"}
0005433785067	62B0C1	2325 706377	YURIY VLASOV	{"phone": "+70648570836"}
0005433785068	0F761E	1842 687835	VLADIMIR NAZAROV	{"email": "vladimirnazarov1970@postgrespro.ru", "phone": "+70325461288"}
0005433785069	A8193B	1012 264266	YULIYA FEDOROVA	{"email": "fedorovay_081972@postgrespro.ru", "phone": "+70139921398"}
0005433785070	E78070	7899 311610	ALEKSANDR RODIONOV	{"phone": "+70281589951"}
0005433785071	ECC05B	0296 273429	VITALIY KUZNECOV	{"email": "kuznecov_v-07021976@postgrespro.ru", "phone": "+70002175566"}
0005433785073	ECC05B	4703 580586	EKATERINA RODIONOVA	{"email": "rodionova_e-051965@postgrespro.ru", "phone": "+70653715263"}
0005433785074	AB4D15	2014 874216	POLINA MIRONOVA	{"phone": "+70125993429"}
0005433785075	F84CB7	2579 884504	OLGA PAVLOVA	{"email": "pavlova.olga-14121968@postgrespro.ru", "phone": "+70525274615"}
0005433785076	6BF384	5957 656022	VLADIMIR IVANOV	{"phone": "+70459138981"}
0005433785077	5B9D7B	7290 129467	RINAT VASILEV	{"email": "rinat-vasilev-25121976@postgrespro.ru", "phone": "+70103154144"}
0005433785078	83E065	2299 574821	NIKOLAY DENISOV	{"email": "nikolay.denisov-1966@postgrespro.ru", "phone": "+70576252860"}
0005433785079	F3F1B8	2797 329567	ALEKSANDRA TIMOFEEVA	{"phone": "+70519976524"}
0005433785080	CC47CD	2357 192730	BORIS ROMANOV	{"phone": "+70758257913"}
0005433785081	5F67FC	4983 253349	ALEKSANDR SERGEEV	{"email": "a_sergeev.04061965@postgrespro.ru", "phone": "+70146767838"}
0005433785082	1B2B1C	3413 604408	SERGEY SIDOROV	{"email": "sidorov-s1976@postgrespro.ru", "phone": "+70366098383"}
0005433785083	2197F3	8048 405354	VERA KOVALEVA	{"email": "kovaleva-v1977@postgrespro.ru", "phone": "+70229266732"}
0005433785084	69E1C3	3643 623117	ANDREY NIKOLAEV	{"phone": "+70289393970"}
0005433785085	2E50A3	9673 498616	YULIYA AKIMOVA	{"email": "akimova.y.051971@postgrespro.ru", "phone": "+70411837314"}
0005433785086	14B7FA	2460 982080	DENIS TIKHONOV	{"phone": "+70210386428"}
0005433785087	C6C213	9239 348804	STANISLAV ZAYCEV	{"phone": "+70251017820"}
0005433785088	269339	3105 864086	MARIYA TIKHONOVA	{"phone": "+70739817241"}
0005433785089	269339	5524 190831	MIKHAIL NOVIKOV	{"phone": "+70920517316"}
0005433785090	8BF93B	6822 312135	MIKHAIL FILIPPOV	{"phone": "+70793730625"}
0005433785091	2CDC8E	9294 185054	ANASTASIYA ARKHIPOVA	{"email": "arkhipova.a_09051980@postgrespro.ru", "phone": "+70047198673"}
0005433785092	0854E7	7990 376421	SOFYA FROLOVA	{"phone": "+70680082736"}
0005433785093	B61743	8114 373243	SERGEY CHERNOV	{"phone": "+70318131164"}
0005433785094	002F39	1908 609778	SERGEY NIKITIN	{"phone": "+70624648554"}
0005433785095	7A7B29	3647 704904	LIDIYA IVANOVA	{"phone": "+70241188787"}
0005433785096	168915	2198 101632	DANIYA ZAKHAROVA	{"phone": "+70878307895"}
0005433785097	36BF8E	2768 047068	ARTEM BORISOV	{"email": "borisova20031984@postgrespro.ru", "phone": "+70974297825"}
0005433785098	36BF8E	1520 401903	LIDIYA ALEKSEEVA	{"phone": "+70338457042"}
0005433785099	296D8F	0942 093724	ANASTASIYA PAVLOVA	{"phone": "+70429174054"}
0005433785100	296D8F	4599 554544	VLADISLAV EGOROV	{"email": "vegorov.041967@postgrespro.ru", "phone": "+70581325922"}
0005433785101	90E19C	3577 040567	YANA LUKYANOVA	{"phone": "+70657939467"}
0005433785102	90E19C	9315 954288	LIDIYA MELNIKOVA	{"phone": "+70018314607"}
0005433785103	90E19C	5474 711589	ANTONINA MELNIKOVA	{"phone": "+70736048874"}
0005433785104	82FC22	7866 927410	SERGEY NIKOLAEV	{"phone": "+70721850251"}
0005433785105	CF9344	0075 544332	SERGEY SCHERBAKOV	{"email": "sscherbakov.091962@postgrespro.ru", "phone": "+70537463807"}
0005433785106	CF9344	1852 280672	VLADIMIR ORLOV	{"phone": "+70344551520"}
0005433785107	E0F17A	9803 571127	SVETLANA KUZNECOVA	{"phone": "+70869719537"}
0005433785108	73EDA4	2405 238504	ERIK MIKHAYLOV	{"email": "mikhaylov.e.071977@postgrespro.ru", "phone": "+70336675125"}
0005433785109	F696CF	5576 319223	YULIYA ZAKHAROVA	{"phone": "+70388593658"}
0005433785110	85EB2A	3741 056672	LIDIYA ABRAMOVA	{"phone": "+70408496452"}
0005433785111	7D1A6A	5554 466872	IVAN ZAKHAROV	{"email": "zakharov.ivan-021963@postgrespro.ru", "phone": "+70370654963"}
0005433785112	7F9E56	7070 170330	PETR DMITRIEV	{"email": "dmitriev_petr-12061979@postgrespro.ru", "phone": "+70834473250"}
0005433785113	7F9E56	4137 105137	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr021981@postgrespro.ru", "phone": "+70543105600"}
0005433785114	41216B	1805 830927	VALERIY ANDREEV	{"phone": "+70122082193"}
0005433785115	96165B	7379 150789	ALEKSANDR EGOROV	{"email": "egorov.aleksandr-21061984@postgrespro.ru", "phone": "+70432418522"}
0005433785116	96165B	0823 559344	OKSANA KUZMINA	{"email": "kuzminao-22111967@postgrespro.ru", "phone": "+70829797890"}
0005433785117	96165B	1765 129362	EGOR FEDOTOV	{"email": "fedotov.e14121985@postgrespro.ru", "phone": "+70958609464"}
0005433785118	2AFEAB	1651 387120	NINA SOKOLOVA	{"email": "nina-sokolova041958@postgrespro.ru", "phone": "+70285504302"}
0005433785119	7659F2	1817 087758	GALINA GERASIMOVA	{"email": "gerasimova.galina.30011975@postgrespro.ru", "phone": "+70475749387"}
0005433785120	1B1BB2	0129 217535	VLADIMIR ZHUKOV	{"email": "vladimir_zhukov-1967@postgrespro.ru", "phone": "+70895825673"}
0005433785121	A2A562	9824 852992	GALINA MAKAROVA	{"phone": "+70838095541"}
0005433785122	E1DB5D	6900 329511	NIKOLAY NIKOLAEV	{"phone": "+70828629795"}
0005433785123	DEFEC8	3043 474786	NATALYA MAKSIMOVA	{"email": "maksimovan1972@postgrespro.ru", "phone": "+70275009770"}
0005433785124	29E58E	3629 720682	EKATERINA ANTONOVA	{"email": "ekaterina-antonova-19041972@postgrespro.ru", "phone": "+70033254794"}
0005433785125	29E58E	7070 412974	DMITRIY POPOV	{"phone": "+70415602935"}
0005433785126	476906	0172 925546	VALERIY FOMIN	{"email": "fomin_v1981@postgrespro.ru", "phone": "+70642771300"}
0005433785127	022887	4365 356081	GALINA TROFIMOVA	{"email": "galina.trofimova1978@postgrespro.ru", "phone": "+70529659792"}
0005433785128	B8AEA0	8305 696108	IRINA SIDOROVA	{"phone": "+70673144951"}
0005433785129	0C24CB	9410 068580	SVETLANA AKIMOVA	{"phone": "+70874820240"}
0005433785130	6F6D69	7782 896675	ALEKSEY VOLKOV	{"phone": "+70718381888"}
0005433785131	6F6D69	9600 974622	VALENTINA SAVELEVA	{"phone": "+70769680654"}
0005433785132	EA7451	9522 699769	ZINAIDA EFREMOVA	{"email": "efremova-zinaida1964@postgrespro.ru", "phone": "+70102864761"}
0005433785133	E9D599	3166 714843	GALINA SEMENOVA	{"email": "g-semenova18041979@postgrespro.ru", "phone": "+70640544394"}
0005433785134	E9D599	7522 480216	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov031974@postgrespro.ru", "phone": "+70520579152"}
0005433785137	D6E245	6680 408782	GALINA PAVLOVA	{"phone": "+70007616904"}
0005433785138	7BD95A	9071 560495	OKSANA DANILOVA	{"phone": "+70777483806"}
0005433785139	679208	6814 580315	EVGENIYA ILINA	{"phone": "+70165157398"}
0005433785140	D97F20	8542 262594	VALENTIN ORLOV	{"email": "orlov.v31051972@postgrespro.ru", "phone": "+70591121458"}
0005433785141	DBF51B	3139 418048	SERGEY FOMIN	{"email": "sergey.fomin.07101966@postgrespro.ru", "phone": "+70361401252"}
0005433785142	9D5C72	5332 571610	ALEKSANDR ANTONOV	{"email": "a_antonov1960@postgrespro.ru", "phone": "+70715396303"}
0005433785143	A170A9	2186 980235	NAIL EGOROV	{"email": "egorov.n051970@postgrespro.ru", "phone": "+70653520242"}
0005433785144	19BF9D	8809 316155	PAVEL KRASNOV	{"email": "pavel_krasnov-071975@postgrespro.ru", "phone": "+70518213884"}
0005433785145	9002A3	7310 022709	OLGA KONOVALOVA	{"email": "olgakonovalova-1970@postgrespro.ru", "phone": "+70804814773"}
0005433785146	BA5E05	3781 575084	TAMARA SIDOROVA	{"email": "t-sidorova_1968@postgrespro.ru", "phone": "+70698022922"}
0005433785147	EF2F3C	5123 773286	DMITRIY TIMOFEEV	{"email": "timofeev.dmitriy.1971@postgrespro.ru", "phone": "+70044099330"}
0005433785148	D2A710	6635 223088	NADEZHDA PAVLOVA	{"email": "n-pavlova061976@postgrespro.ru", "phone": "+70841296787"}
0005433785149	D2A710	4373 109697	EVGENIY FEDOTOV	{"phone": "+70595672477"}
0005433785150	093EAF	9155 266217	VADIM TIKHONOV	{"phone": "+70971789030"}
0005433785151	DF5990	8110 988203	MIKHAIL FILIPPOV	{"email": "filippov-mikhail081979@postgrespro.ru", "phone": "+70442223751"}
0005433785152	68CA89	9258 874895	TAMARA SEMENOVA	{"email": "t_semenova_061970@postgrespro.ru", "phone": "+70532411748"}
0005433785153	E72BFD	9004 271546	ELENA PETROVA	{"email": "elena.petrova091973@postgrespro.ru", "phone": "+70227418575"}
0005433785154	E72BFD	5911 876539	NADEZHDA SAVELEVA	{"email": "saveleva_nadezhda.041974@postgrespro.ru", "phone": "+70959779922"}
0005433785155	D4FC0D	5651 976527	ANTONINA EGOROVA	{"email": "antoninaegorova_101983@postgrespro.ru", "phone": "+70074480287"}
0005433785156	0BC534	5611 860482	SERGEY ROMANOV	{"email": "sergeyromanov-081983@postgrespro.ru", "phone": "+70267831423"}
0005433785157	72250D	9339 247519	VIKTOR CHERNOV	{"email": "chernovviktor.1976@postgrespro.ru", "phone": "+70685812351"}
0005433785158	72250D	4028 151669	ZHANNA NOVIKOVA	{"email": "novikova.z021973@postgrespro.ru", "phone": "+70593254936"}
0005433785159	FBB6C5	6125 688992	VALERIY MIRONOV	{"email": "valeriy.mironov1973@postgrespro.ru", "phone": "+70133109585"}
0005433785160	FBB6C5	9613 677977	EKATERINA NIKOLAEVA	{"email": "ekaterina-nikolaeva_041976@postgrespro.ru", "phone": "+70498821022"}
0005433785161	FB9A71	7290 018551	OKSANA KAZAKOVA	{"phone": "+70403740777"}
0005433785217	E56A36	7489 757549	PAVEL KUZNECOV	{"phone": "+70686480054"}
0005433785162	FA69FF	7916 313584	VALENTINA CHERNOVA	{"email": "v-chernova16121965@postgrespro.ru", "phone": "+70146255839"}
0005433785163	516F1B	2809 417657	MARIYA SOLOVEVA	{"email": "mariyasoloveva05101972@postgrespro.ru", "phone": "+70372724602"}
0005433785164	F68EE0	5133 566912	TATYANA MAKAROVA	{"phone": "+70771362391"}
0005433785165	0C1120	8204 757342	MARIYA FROLOVA	{"phone": "+70735367903"}
0005433785166	834E26	4686 217555	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr31101981@postgrespro.ru", "phone": "+70377935516"}
0005433785167	834E26	2150 661551	IGOR NIKITIN	{"phone": "+70935766427"}
0005433785168	6C2C47	8835 758688	OLGA DENISOVA	{"email": "denisova-o-15121963@postgrespro.ru", "phone": "+70202571005"}
0005433785169	AECF8B	6609 205281	NINA FROLOVA	{"phone": "+70620626861"}
0005433785170	AECF8B	8008 154928	NATALYA SOROKINA	{"phone": "+70893467793"}
0005433785171	B23E68	9718 530006	SVETLANA ISAEVA	{"email": "s-isaeva_09011980@postgrespro.ru", "phone": "+70540451677"}
0005433785172	3FF1F3	0700 814123	VLADISLAV NOVIKOV	{"email": "vladislavnovikov051963@postgrespro.ru", "phone": "+70784982642"}
0005433785173	A229D9	7630 425927	GALIYA KUZMINA	{"email": "kuzmina_galiya_1965@postgrespro.ru", "phone": "+70455812220"}
0005433785174	6FD817	5538 512102	TIMUR SCHERBAKOV	{"phone": "+70448379396"}
0005433785175	62102E	6650 413970	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-ekaterina.1963@postgrespro.ru", "phone": "+70233860003"}
0005433785176	4AF8DD	9708 569635	ANTONINA BELYAEVA	{"email": "a_belyaeva111988@postgrespro.ru", "phone": "+70677617977"}
0005433785177	4AF8DD	3886 182140	OLEG KUDRYASHOV	{"email": "oleg_kudryashov.03091982@postgrespro.ru", "phone": "+70317492696"}
0005433785178	1F723C	3492 861940	OLGA AFANASEVA	{"phone": "+70856556382"}
0005433785179	1F723C	4261 183308	VALERIY BARANOV	{"email": "v_baranov.091984@postgrespro.ru", "phone": "+70283094765"}
0005433785180	B39B1A	9677 040156	YANINA ALEKSEEVA	{"email": "alekseevay091974@postgrespro.ru", "phone": "+70750805960"}
0005433785181	3F3492	2452 649704	EKATERINA KUZNECOVA	{"phone": "+70227826251"}
0005433785182	3F3492	4120 872774	KONSTANTIN OSIPOV	{"email": "osipov.konstantin1967@postgrespro.ru", "phone": "+70252985105"}
0005433785183	599B9B	3751 276081	VLADIMIR PETROV	{"phone": "+70348790527"}
0005433785184	07E23F	7299 086765	OLGA SOROKINA	{"phone": "+70677357014"}
0005433785185	07E23F	1732 395342	ALEKSEY FOMIN	{"phone": "+70408370447"}
0005433785186	540029	8041 745674	VLADIMIR STEPANOV	{"phone": "+70228959748"}
0005433785187	4C7362	9143 210478	ANNA EGOROVA	{"phone": "+70212448888"}
0005433785188	8791FE	6188 717789	ANASTASIYA VOLKOVA	{"email": "anastasiya-volkova.031967@postgrespro.ru", "phone": "+70548094940"}
0005433785189	C58FD6	2958 451851	ELENA NAUMOVA	{"email": "elenanaumova091969@postgrespro.ru", "phone": "+70968542565"}
0005433785190	B154D7	6647 356704	ARTEM VASILEV	{"email": "artemvasilev_1971@postgrespro.ru", "phone": "+70737917419"}
0005433785191	0E35DF	2483 598665	ELENA GUSEVA	{"email": "elenaguseva13081961@postgrespro.ru", "phone": "+70308579994"}
0005433785192	D4FAF4	1581 730420	NATALYA KISELEVA	{"email": "nkiseleva-011976@postgrespro.ru", "phone": "+70065536893"}
0005433785193	488322	1225 055760	ANASTASIYA ZHUKOVA	{"email": "anastasiyazhukova1959@postgrespro.ru", "phone": "+70807130992"}
0005433785194	6EEFED	6412 548723	RAILYA FADEEVA	{"phone": "+70390696808"}
0005433785195	6EEFED	4018 758803	PELAGEYA ERMAKOVA	{"email": "p_ermakova_011980@postgrespro.ru", "phone": "+70342979422"}
0005433785196	C39DAD	9049 224576	NATALYA FEDOROVA	{"email": "n.fedorova-121971@postgrespro.ru", "phone": "+70205603777"}
0005433785197	72C5E9	5287 807752	OLGA ZHURAVLEVA	{"phone": "+70401797860"}
0005433785198	73D33C	1582 117484	KLAVDIYA GUSEVA	{"phone": "+70484219993"}
0005433785199	3F9B4E	6485 626013	PAVEL MARTYNOV	{"phone": "+70469170085"}
0005433785200	59906C	2199 303747	EVDOKIYA TIKHONOVA	{"email": "etikhonova091977@postgrespro.ru", "phone": "+70365935266"}
0005433785201	CA9E6E	5812 826524	IRAIDA MELNIKOVA	{"phone": "+70977570162"}
0005433785202	350F27	9209 493515	ARTEM POPOV	{"email": "a.popov_19111965@postgrespro.ru", "phone": "+70300785900"}
0005433785203	5176C7	6456 263357	STEPAN GERASIMOV	{"email": "gerasimov-s-1965@postgrespro.ru", "phone": "+70909363655"}
0005433785204	A3518C	5304 848452	VASILIY SOLOVEV	{"email": "solovev.v-1975@postgrespro.ru", "phone": "+70701937037"}
0005433785205	BD2479	6919 120009	ANNA KRASNOVA	{"email": "anna_krasnova_1970@postgrespro.ru", "phone": "+70141770269"}
0005433785206	BD2479	8289 919677	ELIZAVETA FEDOROVA	{"phone": "+70388806947"}
0005433785207	BD2479	3827 676008	NADEZHDA PAVLOVA	{"email": "npavlova101967@postgrespro.ru", "phone": "+70467628812"}
0005433785208	E64172	8050 768969	AMIR DENISOV	{"phone": "+70415690442"}
0005433785209	FED6EB	3866 668913	VASILIY ALEKSANDROV	{"email": "aleksandrov-vasiliy_02031970@postgrespro.ru", "phone": "+70356249685"}
0005433785210	C5B08D	4619 825237	ANDREY DENISOV	{"email": "a.denisov-02091985@postgrespro.ru", "phone": "+70383676137"}
0005433785211	C5B08D	9668 493824	LYUDMILA ZAKHAROVA	{"phone": "+70053724517"}
0005433785212	BA8C98	6461 732171	ALEKSANDR ZAKHAROV	{"phone": "+70944600704"}
0005433785213	D1C6E1	7861 423174	LYUBOV IVANOVA	{"email": "lyubov-ivanova_21061972@postgrespro.ru", "phone": "+70666867221"}
0005433785214	D1C6E1	3699 366431	VIKTOR KUZNECOV	{"email": "v.kuznecov-1958@postgrespro.ru", "phone": "+70780488249"}
0005433785215	CFB5C3	3557 798540	MARINA POPOVA	{"email": "popova-m-1960@postgrespro.ru", "phone": "+70141148765"}
0005433785216	5DB92D	3924 858466	LYUDMILA BARANOVA	{"email": "baranova.lyudmila-1969@postgrespro.ru", "phone": "+70545897278"}
0005433785218	03B988	9514 031729	LARISA POLYAKOVA	{"email": "polyakova-l24081968@postgrespro.ru", "phone": "+70857195759"}
0005433785219	76FE1B	9212 141857	ALIYA POLYAKOVA	{"email": "polyakova_a.051974@postgrespro.ru", "phone": "+70574032338"}
0005433785220	76FE1B	7900 870874	NIKOLAY KARPOV	{"phone": "+70915113160"}
0005433785221	9C16EE	3447 892487	ELENA CHERNOVA	{"email": "elena_chernova1978@postgrespro.ru", "phone": "+70558533818"}
0005433785222	568F68	7210 812507	MARINA VASILEVA	{"email": "vasileva_m.13111967@postgrespro.ru", "phone": "+70015339195"}
0005433785223	20330B	3918 541179	MAKSIM ALEKSEEV	{"phone": "+70199176111"}
0005433785224	20330B	6435 322294	MARIYA VOROBEVA	{"phone": "+70885847431"}
0005433785225	20330B	8795 351494	OKSANA NAUMOVA	{"email": "oksananaumova1987@postgrespro.ru", "phone": "+70640323502"}
0005433785226	C014F1	8506 967972	VLADISLAV VASILEV	{"email": "v-vasilev_1978@postgrespro.ru", "phone": "+70684669372"}
0005433785227	C0C589	0229 289044	NIKOLAY SMIRNOV	{"email": "n-smirnov-1969@postgrespro.ru", "phone": "+70675420154"}
0005433785228	FE090E	1176 024094	PAVEL MEDVEDEV	{"email": "medvedev.pavel_1971@postgrespro.ru", "phone": "+70961365152"}
0005433785229	FE090E	8738 946315	VERA ABRAMOVA	{"email": "vera.abramova.17111969@postgrespro.ru", "phone": "+70929773435"}
0005433785230	9F971C	8931 875603	DMITRIY NIKOLAEV	{"email": "d.nikolaev_1976@postgrespro.ru", "phone": "+70755955276"}
0005433785231	0572AE	4644 880311	VLADIMIR SOKOLOV	{"email": "sokolovv-1977@postgrespro.ru", "phone": "+70006892209"}
0005433785232	B013BE	8832 930950	TATYANA VLASOVA	{"phone": "+70037157699"}
0005433785233	E6FD52	9098 121791	NATALYA FROLOVA	{"phone": "+70443012697"}
0005433785234	E6FD52	7870 593709	SERGEY NAUMOV	{"email": "naumovs.25031965@postgrespro.ru", "phone": "+70395922252"}
0005433785235	508CF4	0464 650219	ALEKSANDR VASILEV	{"phone": "+70204604638"}
0005433785236	508CF4	3474 372534	NIKOLAY AFANASEV	{"email": "afanasev-nikolay_041975@postgrespro.ru", "phone": "+70610781402"}
0005433785237	19B053	5351 819387	NADEZHDA NOVIKOVA	{"phone": "+70205189054"}
0005433785238	7662AF	7752 733830	IVAN SMIRNOV	{"phone": "+70182001977"}
0005433785239	346FB9	8409 845091	ALEKSANDR MOROZOV	{"phone": "+70484308212"}
0005433785240	237C54	1683 528824	NIKITA TIKHONOV	{"phone": "+70057355593"}
0005433785241	2BA7B3	3843 628383	SERGEY STEPANOV	{"email": "stepanov-sergey_02031977@postgrespro.ru", "phone": "+70746491482"}
0005433785242	2973DB	9354 540082	EVGENIY EGOROV	{"email": "egorov.evgeniy.1965@postgrespro.ru", "phone": "+70001057695"}
0005433785243	2973DB	1719 621896	ALEKSEY ZAYCEV	{"email": "aleksey-zaycev13011964@postgrespro.ru", "phone": "+70234534317"}
0005433785244	A8BA72	6212 420662	LYUDMILA EFIMOVA	{"email": "efimova_lyudmila1976@postgrespro.ru", "phone": "+70114816260"}
0005433785245	2B557D	7813 863696	YULIYA GRISHINA	{"email": "grishina_y_1969@postgrespro.ru", "phone": "+70785626973"}
0005433785246	2B557D	7357 467063	NIKOLAY KONOVALOV	{"email": "konovalov.n-08011962@postgrespro.ru", "phone": "+70847869877"}
0005433785247	8C8E4E	5422 878457	DMITRIY IVANOV	{"phone": "+70094023498"}
0005433785248	8C8E4E	6749 254275	BORIS IVANOV	{"phone": "+70487635284"}
0005433785249	D60FA8	2478 100643	IRINA MELNIKOVA	{"phone": "+70431667538"}
0005433785250	633D97	4154 998312	RAISA KOMAROVA	{"email": "komarova.raisa.1965@postgrespro.ru", "phone": "+70452982146"}
0005433785251	5392B7	3249 441151	SERGEY AFANASEV	{"email": "sergeyafanasev-081970@postgrespro.ru", "phone": "+70217638797"}
0005433785252	5989A5	9029 793708	TATYANA SOKOLOVA	{"email": "tatyanasokolova-1970@postgrespro.ru", "phone": "+70374156777"}
0005433785253	5989A5	0308 476756	KIRILL ABRAMOV	{"email": "abramov_kirill_051981@postgrespro.ru", "phone": "+70153518191"}
0005433785254	5989A5	9135 420209	RAUF SOKOLOV	{"phone": "+70513804976"}
0005433785255	0F6694	2043 532551	NIKOLAY SEMENOV	{"email": "semenov.n-011964@postgrespro.ru", "phone": "+70600118258"}
0005433785256	0F6694	5550 951472	ALEKSANDR MARTYNOV	{"email": "amartynov.10081972@postgrespro.ru", "phone": "+70035922004"}
0005433785257	DD4C11	9661 365396	NATALYA KUZNECOVA	{"email": "nkuznecova-011979@postgrespro.ru", "phone": "+70164043072"}
0005433785258	2142DF	3026 040884	IGOR KAZAKOV	{"phone": "+70448724625"}
0005433785259	2C5ED8	1062 575478	TATYANA LUKYANOVA	{"phone": "+70213679609"}
0005433785260	3BC946	0517 020454	SERGEY NIKOLAEV	{"phone": "+70707260430"}
0005433785261	53A973	4455 083406	OKSANA NIKITINA	{"phone": "+70061669756"}
0005433785262	879606	9405 884873	YULIYA KOROLEVA	{"email": "koroleva_y091980@postgrespro.ru", "phone": "+70584909970"}
0005433785263	879606	0196 992117	ANDREY KUZNECOV	{"phone": "+70930309853"}
0005433785264	074CC4	1124 597523	EKATERINA NOVIKOVA	{"phone": "+70650602780"}
0005433785265	074CC4	7258 329709	NIKITA PAVLOV	{"phone": "+70467345097"}
0005433785266	721B0D	5538 663008	MARINA VLASOVA	{"phone": "+70424791002"}
0005433785267	721B0D	7954 575242	VASILISA NIKIFOROVA	{"email": "v_nikiforova011967@postgrespro.ru", "phone": "+70219757742"}
0005433785268	426C4D	3355 743629	DENIS POPOV	{"phone": "+70265365161"}
0005433785269	889F77	8979 943829	GENNADIY SMIRNOV	{"email": "g.smirnov.1967@postgrespro.ru", "phone": "+70962581593"}
0005433785270	889F77	5581 572054	GALINA MATVEEVA	{"phone": "+70665429450"}
0005433785271	51A777	5280 869068	MARAT KRASNOV	{"email": "mkrasnov1972@postgrespro.ru", "phone": "+70180082979"}
0005433785272	319A04	9579 137217	VITALIY MAKSIMOV	{"email": "vitaliy-maksimov-1965@postgrespro.ru", "phone": "+70595374785"}
0005433785273	5F1AF5	4021 546170	ALEKSEY ZAYCEV	{"phone": "+70562128154"}
0005433785274	5F1AF5	5472 762883	NATALYA GAVRILOVA	{"email": "natalya-gavrilova-041970@postgrespro.ru", "phone": "+70467767187"}
0005433785275	651B39	4307 565292	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev.061967@postgrespro.ru", "phone": "+70035102161"}
0005433785276	75A558	0613 410415	MIKHAIL GORBUNOV	{"email": "m_gorbunov_111983@postgrespro.ru", "phone": "+70869206128"}
0005433785277	334EEF	8523 223019	LYUBOV FOMINA	{"phone": "+70793756712"}
0005433785278	2DC5F2	4542 024660	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov_16031969@postgrespro.ru", "phone": "+70102755076"}
0005433785279	40B56D	8737 486649	DANIIL ALEKSANDROV	{"phone": "+70114454702"}
0005433785280	8BCBD6	3810 440088	TATYANA FOMINA	{"email": "tatyana_fomina.18071971@postgrespro.ru", "phone": "+70784726573"}
0005433785281	8BCBD6	6862 156934	OLGA SERGEEVA	{"phone": "+70385549663"}
0005433785282	EFAA4D	1821 631875	GALINA SMIRNOVA	{"email": "smirnovag_1984@postgrespro.ru", "phone": "+70407383013"}
0005433785283	EFAA4D	5888 250758	YULIYA ORLOVA	{"email": "orlovay_03071966@postgrespro.ru", "phone": "+70974527770"}
0005433785284	AA6086	0736 001752	GALINA ABRAMOVA	{"email": "abramova-g1976@postgrespro.ru", "phone": "+70810164788"}
0005433785285	AA6086	4171 177127	MARINA KUZNECOVA	{"phone": "+70583088206"}
0005433785286	6AFC1A	0367 061859	LYUDMILA FOMINA	{"email": "lyudmilafomina-09071981@postgrespro.ru", "phone": "+70990791555"}
0005433785287	617716	7582 112797	NADEZHDA BOGDANOVA	{"email": "bogdanovanadezhda_1978@postgrespro.ru", "phone": "+70823580192"}
0005433785288	617716	5021 674814	VALENTINA GORBUNOVA	{"phone": "+70637580261"}
0005433785289	64563E	7136 987639	ALEKSANDR SOKOLOV	{"email": "a_sokolov_021974@postgrespro.ru", "phone": "+70582655780"}
0005433785290	7F2B29	8271 285325	NATALYA MALYSHEVA	{"phone": "+70784351474"}
0005433785291	EDF648	6537 363170	LYUBOV VOROBEVA	{"phone": "+70649328591"}
0005433785292	6217F3	2555 276941	ANATOLIY PETROV	{"email": "petrov_anatoliy-1974@postgrespro.ru", "phone": "+70651436323"}
0005433785293	028316	6710 277990	ALLA MARTYNOVA	{"email": "a_martynova-1978@postgrespro.ru", "phone": "+70127413488"}
0005433785294	F2C202	4448 382497	MARIYA NIKITINA	{"email": "nikitinamariya.08101983@postgrespro.ru", "phone": "+70604931436"}
0005433785295	2BCFA5	3897 296272	NATALYA ABRAMOVA	{"phone": "+70368837600"}
0005433785296	FABD91	2255 237664	ANNA NOVIKOVA	{"email": "anna.novikova10041969@postgrespro.ru", "phone": "+70558494841"}
0005433785297	FABD91	2150 708334	VLADIMIR ANTONOV	{"phone": "+70378545388"}
0005433785298	B1333A	3639 231680	ELISEY GERASIMOV	{"phone": "+70108544858"}
0005433785299	B1333A	3404 953798	IRINA POPOVA	{"email": "irina.popova1964@postgrespro.ru", "phone": "+70705154331"}
0005433785300	B1333A	4486 057146	PETR NAZAROV	{"email": "nazarov-p1978@postgrespro.ru", "phone": "+70856707065"}
0005433785301	9612AA	1026 890481	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov.1967@postgrespro.ru", "phone": "+70555226419"}
0005433785302	9612AA	2349 965827	TATYANA MELNIKOVA	{"phone": "+70518131840"}
0005433785303	3DABFE	6324 443906	ALEKSEY PAVLOV	{"email": "alekseypavlov-02091973@postgrespro.ru", "phone": "+70853183002"}
0005433785304	29FBC9	6777 748675	SERGEY KOROLEV	{"email": "korolevs_12111980@postgrespro.ru", "phone": "+70934213237"}
0005433785305	E3C32C	1625 795896	VIKTOR VOLKOV	{"email": "vvolkov_15121964@postgrespro.ru", "phone": "+70921372892"}
0005433785306	7DB025	3901 837902	NIKOLAY IVANOV	{"email": "n-ivanov23111970@postgrespro.ru", "phone": "+70166182416"}
0005433785307	68594C	0464 137243	EKATERINA PETROVA	{"email": "petrova_ekaterina_02011964@postgrespro.ru", "phone": "+70974331820"}
0005433785308	144318	2678 984710	ALEKSEY STEPANOV	{"phone": "+70598562497"}
0005433785309	386618	1502 825561	GALINA SMIRNOVA	{"phone": "+70565170447"}
0005433785310	DE9D6E	7074 297898	ALEKSEY NAZAROV	{"email": "nazarov_aleksey_08071965@postgrespro.ru", "phone": "+70784686804"}
0005433785311	DE9D6E	8473 279989	IVAN GRIGOREV	{"phone": "+70535872547"}
0005433785312	FE6CDD	5954 720082	ANATOLIY SOKOLOV	{"email": "asokolov.05011972@postgrespro.ru", "phone": "+70788429141"}
0005433785313	11C1B3	3377 746760	RAIL NIKOLAEV	{"phone": "+70247403744"}
0005433785314	A9FD2F	9910 878555	IVAN SERGEEV	{"email": "ivan-sergeev_1963@postgrespro.ru", "phone": "+70897762514"}
0005433785315	A9FD2F	2855 412431	EVGENIY MAKAROV	{"email": "emakarov_051985@postgrespro.ru", "phone": "+70686922288"}
0005433785316	75F42C	1214 285041	OKSANA SOLOVEVA	{"phone": "+70122357017"}
0005433785317	448A9C	3559 772332	ANTON ZAKHAROV	{"email": "anton.zakharov1972@postgrespro.ru", "phone": "+70900490736"}
0005433785318	E418E5	8594 371760	VLADISLAV ANDREEV	{"phone": "+70134159542"}
0005433785319	707728	7892 533040	NADEZHDA MAKAROVA	{"phone": "+70482611167"}
0005433785320	E61253	2221 647289	DMITRIY ANTONOV	{"phone": "+70427088682"}
0005433785321	A06D54	0625 156874	IGOR STEPANOV	{"phone": "+70294572605"}
0005433785322	BDAB7F	9982 586947	ALEKSANDR ANDREEV	{"phone": "+70794040116"}
0005433785323	8B76E6	4768 845804	TAMARA ANDREEVA	{"phone": "+70627089929"}
0005433785324	BB7943	0540 539065	NIKITA MIKHAYLOV	{"phone": "+70475015163"}
0005433785325	75F5A0	4631 695011	VLADIMIR SCHERBAKOV	{"phone": "+70695979575"}
0005433785326	074E86	2997 578186	MARIYA SOROKINA	{"phone": "+70102299140"}
0005433785327	4ECFDB	9280 002144	EKATERINA GORBUNOVA	{"email": "e_gorbunova_011972@postgrespro.ru", "phone": "+70949623682"}
0005433785328	FB6E4E	2482 801694	ZINAIDA KUZNECOVA	{"email": "kuznecova-zinaida-081969@postgrespro.ru", "phone": "+70465628708"}
0005433785383	2AF443	2192 638898	RAISA MELNIKOVA	{"phone": "+70914249505"}
0005433785329	50344E	2430 058380	SERGEY GUSEV	{"email": "sergey.gusev-041977@postgrespro.ru", "phone": "+70137741847"}
0005433785330	50344E	8101 620342	GALINA RODIONOVA	{"phone": "+70370986750"}
0005433785331	751DFE	6792 673669	PAVEL VASILEV	{"email": "vasilev_pavel1964@postgrespro.ru", "phone": "+70399884011"}
0005433785332	380C8F	8686 378083	EMILIYA SOLOVEVA	{"email": "e_soloveva_1962@postgrespro.ru", "phone": "+70134470208"}
0005433785333	34C3F2	5636 062894	ANATOLIY PETROV	{"phone": "+70940783243"}
0005433785334	9A0951	0748 891109	KONSTANTIN SCHERBAKOV	{"email": "scherbakov_konstantin06071958@postgrespro.ru", "phone": "+70651877908"}
0005433785335	9A0951	1761 221737	RUSTAM SMIRNOV	{"email": "smirnov-rustam-1975@postgrespro.ru", "phone": "+70265983785"}
0005433785336	9592AD	1275 672757	NADEZHDA SOKOLOVA	{"phone": "+70917580214"}
0005433785337	98B7F6	2606 990442	DARYA IVANOVA	{"email": "ivanova.d1965@postgrespro.ru", "phone": "+70399281369"}
0005433785338	A8A43E	8766 062144	ALEKSANDR TIKHONOV	{"email": "a_tikhonov041988@postgrespro.ru", "phone": "+70041618745"}
0005433785339	1647FA	2553 303074	ALENA AFANASEVA	{"email": "a-afanaseva_061975@postgrespro.ru", "phone": "+70045456907"}
0005433785340	7BB6B1	4023 533440	ALEKSANDRA SOLOVEVA	{"email": "a.soloveva-1962@postgrespro.ru", "phone": "+70652991920"}
0005433785398	1064B9	5114 283178	MARGARITA ROMANOVA	{"phone": "+70342066685"}
0005433785341	7BB6B1	6459 163070	ELENA VLASOVA	{"email": "e_vlasova_11031988@postgrespro.ru", "phone": "+70374124719"}
0005433785342	7BB6B1	7801 515809	YANA MAKSIMOVA	{"email": "maksimova.y-121976@postgrespro.ru", "phone": "+70151136122"}
0005433785343	64E57F	4118 248792	VLADIMIR GAVRILOV	{"email": "v_gavrilov1971@postgrespro.ru", "phone": "+70314059875"}
0005433785344	97E197	6923 862263	ALEKSANDR ROMANOV	{"email": "a-romanov-061984@postgrespro.ru", "phone": "+70081370337"}
0005433785345	670ECB	5140 955097	ALEKSANDRA ZOTOVA	{"phone": "+70545812595"}
0005433785346	670ECB	0036 939649	ANTON MARTYNOV	{"email": "martynov.anton1976@postgrespro.ru", "phone": "+70367976662"}
0005433785347	BDF3C3	6298 358609	PAVEL BARANOV	{"phone": "+70773937370"}
0005433785348	BDF3C3	9509 207670	LYUDMILA KOZLOVA	{"phone": "+70184288432"}
0005433785349	BDF3C3	1456 424828	DMITRIY KAZAKOV	{"phone": "+70363704453"}
0005433785350	B35577	0419 247952	VLADIMIR STEPANOV	{"email": "stepanovv-1975@postgrespro.ru", "phone": "+70615705740"}
0005433785351	3F0B2A	6911 607891	ANDREY ILIN	{"phone": "+70239128401"}
0005433785352	6C31B2	1685 744565	KIRILL ZHURAVLEV	{"email": "kirillzhuravlev_01111973@postgrespro.ru", "phone": "+70497070964"}
0005433785353	B6B5C2	1237 699761	EVGENIY SERGEEV	{"phone": "+70371332360"}
0005433785354	1C8695	9852 204281	STANISLAV SOROKIN	{"email": "stanislav-sorokin1973@postgrespro.ru", "phone": "+70324383351"}
0005433785355	1F4A3E	6839 751954	IRINA OSIPOVA	{"phone": "+70983360516"}
0005433785356	1F4A3E	2126 342715	VALERIY ZAKHAROV	{"email": "zakharovv_27111971@postgrespro.ru", "phone": "+70364071860"}
0005433785357	12E13D	4954 042050	VLADIMIR ORLOV	{"phone": "+70017156036"}
0005433785358	E3CEE8	8982 577699	NIKOLAY KOZLOV	{"email": "kozlov-n.27041965@postgrespro.ru", "phone": "+70588966350"}
0005433785359	43F3A0	1732 399326	RUSLAN KAZAKOV	{"phone": "+70826326213"}
0005433785360	43F3A0	4846 257574	VALENTINA FILIPPOVA	{"email": "filippova-valentina_1967@postgrespro.ru", "phone": "+70537315411"}
0005433785361	43F3A0	4638 598907	ANTONINA NIKOLAEVA	{"phone": "+70643962617"}
0005433785362	32AD5F	2423 721674	TATYANA EGOROVA	{"phone": "+70572640124"}
0005433785363	863DA4	6074 774137	KONSTANTIN NAZAROV	{"phone": "+70354204859"}
0005433785364	224831	3803 095016	VERA VOLKOVA	{"phone": "+70587621326"}
0005433785365	224831	5388 870230	DMITRIY PAVLOV	{"email": "pavlovdmitriy.30011974@postgrespro.ru", "phone": "+70848712277"}
0005433785366	1FAAFF	5711 345440	NATALYA KRASNOVA	{"email": "krasnova.n061979@postgrespro.ru", "phone": "+70163039922"}
0005433785367	C29C68	0379 619156	ANNA KOLESNIKOVA	{"phone": "+70083642251"}
0005433785368	6C61FA	3816 834385	VALERIY VOLKOV	{"email": "volkov-valeriy-29031969@postgrespro.ru", "phone": "+70635833664"}
0005433785369	6C61FA	0117 552084	IRINA OSIPOVA	{"email": "osipova-irina_101969@postgrespro.ru", "phone": "+70286186677"}
0005433785370	41AF59	7851 766610	DMITRIY GERASIMOV	{"email": "gerasimov.dmitriy_07101972@postgrespro.ru", "phone": "+70382468444"}
0005433785371	D215F1	5237 630245	ROMAN IVANOV	{"phone": "+70481991343"}
0005433785372	D215F1	4847 623916	ANATOLIY PETROV	{"phone": "+70420724797"}
0005433785373	D215F1	4855 780405	NATALYA SOROKINA	{"phone": "+70808886257"}
0005433785374	471A88	8804 482551	EVGENIY SMIRNOV	{"email": "e.smirnov_04051977@postgrespro.ru", "phone": "+70950403719"}
0005433785375	956973	3069 800324	ELIZAVETA PETROVA	{"email": "elizaveta-petrova091973@postgrespro.ru", "phone": "+70579016884"}
0005433785376	B8BF3E	6635 444303	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr.08081963@postgrespro.ru", "phone": "+70568534123"}
0005433785377	B8BF3E	8985 033152	KONSTANTIN IVANOV	{"email": "konstantin-ivanov_1974@postgrespro.ru", "phone": "+70727162456"}
0005433785378	8F8383	8718 679767	ANASTASIYA TITOVA	{"phone": "+70019600395"}
0005433785379	8F8383	9822 488982	KSENIYA TIMOFEEVA	{"email": "timofeeva_kseniya_031975@postgrespro.ru", "phone": "+70662036008"}
0005433785380	E9A14A	9151 571003	OLGA PETROVA	{"email": "petrova.o.31031982@postgrespro.ru", "phone": "+70618495413"}
0005433785381	E9A14A	7257 446882	IGOR NIKOLAEV	{"email": "nikolaevigor1982@postgrespro.ru", "phone": "+70236589771"}
0005433785382	953B3B	4822 198440	VIKTORIYA FEDOROVA	{"email": "viktoriya-fedorova-091968@postgrespro.ru", "phone": "+70288221397"}
0005433785384	2AF443	4406 771281	NADEZHDA KARPOVA	{"phone": "+70138298625"}
0005433785385	31D3CA	5902 507193	IRINA FILIPPOVA	{"email": "filippova_irina.26021971@postgrespro.ru", "phone": "+70100244579"}
0005433785386	E3E5A1	7856 805097	TATYANA SIDOROVA	{"email": "t.sidorova-08051969@postgrespro.ru", "phone": "+70465319332"}
0005433785387	E3E5A1	8510 517881	ANASTASIYA TITOVA	{"phone": "+70848740349"}
0005433785388	E3E5A1	7986 132107	SERGEY ILIN	{"phone": "+70604134031"}
0005433785389	B82948	8373 388804	LYUDMILA POPOVA	{"email": "popova-l.1979@postgrespro.ru", "phone": "+70672623921"}
0005433785390	B82948	6308 203586	ANDREY SEMENOV	{"phone": "+70872140377"}
0005433785391	6037F6	8101 516456	ALENA IVANOVA	{"phone": "+70124159216"}
0005433785392	20C10F	4791 499576	TAMARA MAKSIMOVA	{"phone": "+70975363242"}
0005433785393	A2DEB9	9445 383635	ALEKSANDRA PETROVA	{"phone": "+70380861386"}
0005433785394	A2DEB9	7508 569381	ANDREY MAKAROV	{"phone": "+70282059624"}
0005433785395	651DB3	5488 254433	LYUDMILA MIRONOVA	{"email": "mironoval-1963@postgrespro.ru", "phone": "+70988777262"}
0005433785396	651DB3	5126 960258	ELENA KUZNECOVA	{"phone": "+70087054684"}
0005433785399	1064B9	3601 126638	TAMARA KULIKOVA	{"email": "t-kulikova-10111971@postgrespro.ru", "phone": "+70137876834"}
0005433785400	1064B9	5927 387209	POLINA FOMINA	{"email": "p.fomina101965@postgrespro.ru", "phone": "+70950982581"}
0005433785401	ECF861	1796 085066	MARINA GUSEVA	{"phone": "+70724640278"}
0005433785402	CC4480	1154 883079	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova-1969@postgrespro.ru", "phone": "+70548674718"}
0005433785403	313BB0	2425 290918	ALEKSEY ZHURAVLEV	{"phone": "+70966353900"}
0005433785404	19DFAE	2572 304024	NATALYA ANISIMOVA	{"email": "anisimova_natalya08071972@postgrespro.ru", "phone": "+70024999654"}
0005433785405	19DFAE	1794 741609	ALEKSANDR VASILEV	{"email": "avasilev_071972@postgrespro.ru", "phone": "+70782289380"}
0005433785406	E8C32D	4964 372407	TATYANA IVANOVA	{"email": "tatyanaivanova1960@postgrespro.ru", "phone": "+70110154904"}
0005433785407	2C1937	1453 783689	YURIY POPOV	{"email": "popov-y081968@postgrespro.ru", "phone": "+70602674422"}
0005433785408	5BD6D0	2166 586645	NATALYA ZAKHAROVA	{"email": "zakharova_n16071975@postgrespro.ru", "phone": "+70263120126"}
0005433785409	5BD6D0	9179 421086	OLGA KUDRYASHOVA	{"email": "olga-kudryashova_24031969@postgrespro.ru", "phone": "+70419984796"}
0005433785410	9B8AC6	1632 318801	NADEZHDA CHERNOVA	{"phone": "+70596422362"}
0005433785411	84E317	0410 902999	MARIYA MARTYNOVA	{"phone": "+70767338830"}
0005433785412	84E317	9986 934221	ALEKSEY KUZNECOV	{"phone": "+70475569557"}
0005433785413	B5DF9D	1217 670155	SERGEY EGOROV	{"email": "egorov_s-111973@postgrespro.ru", "phone": "+70200479093"}
0005433785414	B5DF9D	7828 229353	MIKHAIL STEPANOV	{"email": "m_stepanov-1978@postgrespro.ru", "phone": "+70400061818"}
0005433785415	0A0460	9629 772300	ALEKSANDR POPOV	{"phone": "+70651763516"}
0005433785416	8DB1AB	2249 948973	IVAN KOZLOV	{"email": "i-kozlov-091968@postgrespro.ru", "phone": "+70300136089"}
0005433785417	2FDC45	5857 123322	TATYANA ALEKSEEVA	{"phone": "+70208279434"}
0005433785418	917F24	5118 101867	MARIYA TITOVA	{"email": "titova-m.09021978@postgrespro.ru", "phone": "+70393639603"}
0005433785419	890221	9049 723678	OLGA ROMANOVA	{"email": "romanova.olga_1962@postgrespro.ru", "phone": "+70542155481"}
0005433785420	890221	8409 672830	VALENTINA OSIPOVA	{"email": "osipova-valentina.011963@postgrespro.ru", "phone": "+70161490818"}
0005433785421	890221	7599 846848	MARGARITA DENISOVA	{"phone": "+70946552330"}
0005433785422	D4F792	3421 507609	TATYANA OSIPOVA	{"email": "t-osipova_021968@postgrespro.ru", "phone": "+70364819993"}
0005433785423	A122BF	4205 051233	VERA SMIRNOVA	{"email": "v_smirnova_1971@postgrespro.ru", "phone": "+70803146788"}
0005433785424	48A6DC	3112 761767	INESSA MIKHAYLOVA	{"phone": "+70378423815"}
0005433785425	C85BC9	0072 967370	ALEKSANDR KUZMIN	{"email": "kuzmin_a_01041980@postgrespro.ru", "phone": "+70547692250"}
0005433785426	DA4E99	8728 140937	OLGA MOROZOVA	{"email": "o-morozova021990@postgrespro.ru", "phone": "+70995421231"}
0005433785427	ACDD55	2132 377016	ALEKSEY NAZAROV	{"email": "a_nazarov-1974@postgrespro.ru", "phone": "+70362573971"}
0005433785428	CD3A29	2918 469327	VASILISA TIMOFEEVA	{"email": "timofeevavasilisa_1969@postgrespro.ru", "phone": "+70908984341"}
0005433785429	CD3A29	5146 980082	ZINAIDA KUDRYASHOVA	{"phone": "+70753775337"}
0005433785430	922655	1040 121095	GALINA KUZNECOVA	{"email": "galina_kuznecova-021992@postgrespro.ru", "phone": "+70759295877"}
0005433785431	E75843	4120 770641	ANTONINA SERGEEVA	{"phone": "+70393533358"}
0005433785432	901B3A	1995 762356	ANNA MAKSIMOVA	{"email": "maksimova_anna-07041977@postgrespro.ru", "phone": "+70834808839"}
0005433785433	5DB0FF	3702 575828	VLADIMIR KISELEV	{"email": "kiselev_vladimir_17041971@postgrespro.ru", "phone": "+70341919110"}
0005433785434	3B979D	8412 561283	SERGEY KAZAKOV	{"email": "kazakov.sergey_1959@postgrespro.ru", "phone": "+70366526056"}
0005433785435	3B979D	5888 649535	LYUDMILA KULIKOVA	{"email": "l.kulikova.091971@postgrespro.ru", "phone": "+70278891595"}
0005433785436	53DD49	8588 148250	STANISLAV GERASIMOV	{"phone": "+70304566268"}
0005433785437	53DD49	6518 890301	VADIM ZHUKOV	{"phone": "+70491952350"}
0005433785438	BB7500	2329 916059	MARFA OSIPOVA	{"email": "osipova.m.16061981@postgrespro.ru", "phone": "+70804398827"}
0005433785439	BB7500	3643 732888	KSENIYA KUZNECOVA	{"phone": "+70890827038"}
0005433785440	F663CD	5957 003939	KLAVDIYA POLYAKOVA	{"email": "polyakova_klavdiya_1973@postgrespro.ru", "phone": "+70876667927"}
0005433785441	B680AF	4334 070779	MIKHAIL NIKOLAEV	{"email": "m_nikolaev.09081980@postgrespro.ru", "phone": "+70755992531"}
0005433785442	B680AF	0224 634621	YURIY KAZAKOV	{"email": "kazakov.y1965@postgrespro.ru", "phone": "+70033604086"}
0005433785443	D320AA	5674 116187	YURIY IVANOV	{"phone": "+70682254267"}
0005433785444	2A0B1D	4934 877671	ANTONINA ALEKSANDROVA	{"email": "aleksandrova_a-1974@postgrespro.ru", "phone": "+70952893556"}
0005433785445	2A0B1D	9084 200851	IRINA KONOVALOVA	{"email": "konovalovai_11021975@postgrespro.ru", "phone": "+70265527672"}
0005433785446	2CFD4A	6393 067175	NATALYA ANDREEVA	{"phone": "+70292644706"}
0005433785447	ED6533	3554 926449	VALENTIN KUZMIN	{"email": "v_kuzmin_20051973@postgrespro.ru", "phone": "+70553642069"}
0005433785448	ED6533	5375 957341	SVETLANA FROLOVA	{"email": "svetlana-frolova_1965@postgrespro.ru", "phone": "+70942231650"}
0005433785449	ED3377	8356 597135	NIKITA POPOV	{"phone": "+70965667028"}
0005433785450	C40033	8608 323901	YULIYA NAUMOVA	{"email": "yuliya.naumova_081971@postgrespro.ru", "phone": "+70595378501"}
0005433785451	C40033	0665 195051	DARINA KUZMINA	{"email": "d-kuzmina.09101965@postgrespro.ru", "phone": "+70595403626"}
0005433785452	462968	1182 889131	OLEG EGOROV	{"phone": "+70401934310"}
0005433785453	462968	8328 594356	SVETLANA SOLOVEVA	{"phone": "+70054019876"}
0005433785454	34F249	4575 737615	EVGENIYA STEPANOVA	{"email": "stepanova.evgeniya_121965@postgrespro.ru", "phone": "+70259466403"}
0005433785455	4147D1	6916 259333	ALEKSANDR NOVIKOV	{"email": "anovikov-14051961@postgrespro.ru", "phone": "+70222931745"}
0005433785456	E4B07F	2940 061084	ALEKSANDR NOVIKOV	{"email": "novikovaleksandr.1992@postgrespro.ru", "phone": "+70923756254"}
0005433785457	1583D2	2342 591226	ANASTASIYA GERASIMOVA	{"email": "gerasimovaa_04091971@postgrespro.ru", "phone": "+70274040151"}
0005433785458	1583D2	6955 286170	TIMOFEY EGOROV	{"email": "timofey_egorov.041981@postgrespro.ru", "phone": "+70750811148"}
0005433785459	0AA584	2747 212623	LYUDMILA NIKITINA	{"email": "lnikitina-071976@postgrespro.ru", "phone": "+70427787127"}
0005433785460	AA2A25	3242 811085	GALIYA SOLOVEVA	{"phone": "+70117931529"}
0005433785461	4A2EDC	3091 882091	PETR SEMENOV	{"phone": "+70191682679"}
0005433785462	9E750F	4566 472818	SERGEY KUZNECOV	{"email": "skuznecov_20101979@postgrespro.ru", "phone": "+70664313849"}
0005433785463	12DD9E	6380 914325	NIKOLAY BONDARENKO	{"phone": "+70122284788"}
0005433785464	2EBD7E	1518 938881	ALEKSEY IVANOV	{"email": "a.ivanov1973@postgrespro.ru", "phone": "+70137998296"}
0005433785465	4FC6FB	3099 482593	NIKOLAY BARANOV	{"email": "nikolay_baranov_1976@postgrespro.ru", "phone": "+70762635130"}
0005433785466	4FC6FB	9771 778002	STANISLAV MATVEEV	{"email": "matveev-s09091964@postgrespro.ru", "phone": "+70622331737"}
0005433785467	0D59F2	5328 990740	ALEKSEY ABRAMOV	{"phone": "+70684780913"}
0005433785468	375EC0	9433 714000	DMITRIY CHERNOV	{"phone": "+70081868453"}
0005433785469	FA0531	9784 461498	BORIS BONDARENKO	{"phone": "+70687396025"}
0005433785470	94E561	4982 881365	TATYANA KONDRATEVA	{"email": "tatyanakondrateva_1985@postgrespro.ru", "phone": "+70346500884"}
0005433785471	438C37	1605 977968	NINA NIKOLAEVA	{"email": "nikolaeva.nina031978@postgrespro.ru", "phone": "+70465982732"}
0005433785472	63C3C3	2542 955267	TATYANA SOKOLOVA	{"phone": "+70453407105"}
0005433785473	63C3C3	5442 747137	ALEKSANDR DENISOV	{"phone": "+70564854314"}
0005433785474	BD1649	8530 693198	EVGENIY FOMIN	{"email": "fominevgeniy061977@postgrespro.ru", "phone": "+70258040121"}
0005433785475	8A0095	4010 681597	ANTON NAZAROV	{"phone": "+70247364483"}
0005433785476	150FA3	1157 447761	OLGA SOROKINA	{"phone": "+70264106568"}
0005433785477	150FA3	6986 565856	TATYANA MEDVEDEVA	{"email": "medvedeva_tatyana031974@postgrespro.ru", "phone": "+70966770818"}
0005433785478	8E62B9	5536 758173	YULIYA AFANASEVA	{"phone": "+70702691745"}
0005433785479	DDB498	1605 048753	RAISA NESTEROVA	{"email": "r-nesterova_1972@postgrespro.ru", "phone": "+70765585972"}
0005433785480	781ED1	7115 696921	VASILIY ILIN	{"phone": "+70366655690"}
0005433785481	7E9C83	6546 615816	YANA GUSEVA	{"phone": "+70146285261"}
0005433785482	7E9C83	1793 002439	TATYANA KRASNOVA	{"email": "krasnovatatyana-03071986@postgrespro.ru", "phone": "+70918324608"}
0005433785483	F8B6F1	5391 030802	BOGDAN GORBUNOV	{"email": "gorbunov-b.30101966@postgrespro.ru", "phone": "+70900155802"}
0005433785484	5781C4	8666 897551	GALINA VASILEVA	{"email": "vasileva.galina.081959@postgrespro.ru", "phone": "+70257904269"}
0005433785485	5781C4	7872 380806	YULIYA SMIRNOVA	{"email": "ysmirnova_21101964@postgrespro.ru", "phone": "+70269320441"}
0005433785486	105318	4424 633981	VIKTOR ALEKSEEV	{"phone": "+70343779408"}
0005433785487	105318	6439 784714	LYUDMILA SCHERBAKOVA	{"email": "scherbakova_lyudmila_021967@postgrespro.ru", "phone": "+70028003854"}
0005433785488	B58BF5	0684 798209	ALEKSANDRA VOLKOVA	{"phone": "+70249118764"}
0005433785489	C1DE1A	9227 817172	STEPAN KOZLOV	{"email": "s-kozlov.041976@postgrespro.ru", "phone": "+70643903273"}
0005433785490	F5C1B5	0902 505615	VLADIMIR ZAKHAROV	{"phone": "+70730438235"}
0005433785491	C98192	8714 633578	LARISA KARPOVA	{"email": "l-karpova1974@postgrespro.ru", "phone": "+70240048942"}
0005433785492	DF34AB	1078 201454	LIDIYA KISELEVA	{"phone": "+70371481917"}
0005433785493	EE53B0	7559 945736	TATYANA NAZAROVA	{"email": "nazarova_t_1967@postgrespro.ru", "phone": "+70711473368"}
0005433785494	DF46B5	0214 570831	ELENA KUZMINA	{"email": "kuzmina-elena1969@postgrespro.ru", "phone": "+70200344926"}
0005433785495	2E957F	6797 957536	EVGENIY MAKAROV	{"phone": "+70933145418"}
0005433785716	316FAC	2879 971901	VALENTINA AFANASEVA	{"phone": "+70339495549"}
0005433785496	2E957F	0008 913307	EKATERINA KRASNOVA	{"email": "krasnova-e.03081979@postgrespro.ru", "phone": "+70505231613"}
0005433785497	AEF65E	1316 405655	ANDREY ROMANOV	{"phone": "+70541164393"}
0005433785498	C64627	4967 031372	NINA ISAEVA	{"email": "isaeva-n1972@postgrespro.ru", "phone": "+70562421213"}
0005433785499	C6F8D0	8974 027885	ALEKSEY BONDARENKO	{"phone": "+70408806483"}
0005433785500	F5733E	0620 627899	DMITRIY IVANOV	{"phone": "+70620533835"}
0005433785501	85869F	7565 755552	SERGEY AFANASEV	{"email": "afanasev-sergey-1976@postgrespro.ru", "phone": "+70487566854"}
0005433785502	FA4D14	1772 323484	LIDIYA SOKOLOVA	{"email": "sokolova_lidiya061969@postgrespro.ru", "phone": "+70757815020"}
0005433785503	FA4D14	1357 741572	ALEKSEY DAVYDOV	{"phone": "+70981780322"}
0005433785504	B59A27	8263 307118	EVDOKIYA YAKOVLEVA	{"phone": "+70703651519"}
0005433785505	19023E	8543 957354	TATYANA FEDOROVA	{"email": "fedorova_t-1960@postgrespro.ru", "phone": "+70384385788"}
0005433785506	19023E	8501 514931	EVGENIYA MOROZOVA	{"phone": "+70398332622"}
0005433785507	C1DAAF	0072 824400	RAISA NAZAROVA	{"phone": "+70388047596"}
0005433785508	C1DAAF	8873 695856	EKATERINA KOLESNIKOVA	{"email": "ekaterina.kolesnikova-121982@postgrespro.ru", "phone": "+70629035241"}
0005433785786	2959FF	0810 647787	NADEZHDA ALEKSEEVA	{"phone": "+70557659873"}
0005433785509	7F8376	1625 129304	ILYA KUZNECOV	{"email": "i-kuznecov-011979@postgrespro.ru", "phone": "+70865633975"}
0005433785510	0E4E41	7419 601056	DMITRIY VASILEV	{"phone": "+70712293554"}
0005433785511	919185	6648 966930	RADIK GRIGOREV	{"email": "grigorev.radik101979@postgrespro.ru", "phone": "+70003752330"}
0005433785512	A71022	6587 071107	LYUBOV KRASNOVA	{"email": "lyubov_krasnova.15071983@postgrespro.ru", "phone": "+70320697265"}
0005433785513	F5E72E	2565 606507	VLADIMIR YAKOVLEV	{"email": "vyakovlev061968@postgrespro.ru", "phone": "+70473738933"}
0005433785514	106F99	9248 866442	DENIS VASILEV	{"email": "vasilevdenis_1983@postgrespro.ru", "phone": "+70205800670"}
0005433785515	D364AE	6936 046589	MARIYA GAVRILOVA	{"phone": "+70790635639"}
0005433785516	D364AE	4523 901906	NINA KUZNECOVA	{"phone": "+70122095188"}
0005433785517	1148D8	4264 841941	LARISA IVANOVA	{"phone": "+70698279982"}
0005433785518	056165	1759 858988	ALEKSEY ZHUKOV	{"email": "aleksey.zhukov25071972@postgrespro.ru", "phone": "+70164872820"}
0005433785519	617543	1495 860528	RAISA LOGINOVA	{"email": "loginova-r031974@postgrespro.ru", "phone": "+70825103883"}
0005433785520	617543	0691 206270	ALEKSEY ROMANOV	{"phone": "+70038696823"}
0005433785521	6C761B	2047 939192	ANASTASIYA MALYSHEVA	{"email": "malysheva_anastasiya_18121966@postgrespro.ru", "phone": "+70571509827"}
0005433785522	3B03AA	9564 483961	KSENIYA OVCHINNIKOVA	{"email": "k_ovchinnikova-121982@postgrespro.ru", "phone": "+70560365460"}
0005433785523	82486B	7618 044362	VLADIMIR NIKITIN	{"phone": "+70833481716"}
0005433785524	82486B	2030 838357	TATYANA NIKITINA	{"email": "nikitinatatyana_27111977@postgrespro.ru", "phone": "+70665870374"}
0005433785525	BC4AA4	5876 896026	ALENA KONOVALOVA	{"email": "akonovalova071967@postgrespro.ru", "phone": "+70124920732"}
0005433785526	8B90E1	6431 955380	TATYANA MASLOVA	{"phone": "+70756092743"}
0005433785527	9F5C7D	2314 143087	NIKITA BELOV	{"phone": "+70747514823"}
0005433785528	9F5C7D	8979 265975	RAISA KOLESNIKOVA	{"phone": "+70653948513"}
0005433785529	9F5C7D	7143 130479	VALENTINA ZOTOVA	{"email": "zotova_valentina.08091970@postgrespro.ru", "phone": "+70484992377"}
0005433785530	9F705F	1638 799799	YULIYA PETROVA	{"phone": "+70409868424"}
0005433785531	00C2E1	8850 364492	VITALIY VOLKOV	{"email": "vvolkov_09061972@postgrespro.ru", "phone": "+70939019758"}
0005433785532	E60BEC	8125 532704	VASILIY DENISOV	{"email": "denisov.v-31051968@postgrespro.ru", "phone": "+70637674853"}
0005433785533	E60BEC	8583 797669	ALENA MIRONOVA	{"email": "a-mironova-1984@postgrespro.ru", "phone": "+70140355518"}
0005433785534	3CA968	8825 341857	DARYA FADEEVA	{"phone": "+70644199692"}
0005433785535	594110	7601 004291	IVAN NIKITIN	{"phone": "+70969195896"}
0005433785536	1255F8	3571 393786	EKATERINA ANDREEVA	{"phone": "+70180521857"}
0005433785537	1255F8	7533 415887	TATYANA KUZNECOVA	{"phone": "+70992989752"}
0005433785538	87C698	6014 731783	ALEKSEY ZHUKOV	{"email": "aleksey_zhukov_18051972@postgrespro.ru", "phone": "+70227564071"}
0005433785539	37F5E9	7199 198970	NIKOLAY MATVEEV	{"phone": "+70072483793"}
0005433785540	37F5E9	9404 062505	ANASTASIYA SOKOLOVA	{"email": "anastasiya-sokolova1961@postgrespro.ru", "phone": "+70391304928"}
0005433785541	946B64	3683 839999	YURIY VOLKOV	{"email": "y.volkov111961@postgrespro.ru", "phone": "+70663105245"}
0005433785542	2736F3	7358 610829	VALERIY SMIRNOV	{"phone": "+70753180446"}
0005433785543	2736F3	3580 077793	ALISA KOROLEVA	{"email": "alisa_koroleva.051970@postgrespro.ru", "phone": "+70468554754"}
0005433785544	7FD0CC	1363 980704	GALINA PAVLOVA	{"email": "pavlova-g-1975@postgrespro.ru", "phone": "+70353855158"}
0005433785545	BBEC68	4765 281757	YURIY FEDOROV	{"phone": "+70929448572"}
0005433785546	1D33C6	0982 701832	MAKSIM CHERNOV	{"email": "maksim_chernov_31101979@postgrespro.ru", "phone": "+70844891988"}
0005433785547	5858F1	2612 386557	ELENA VOLKOVA	{"email": "volkova_elena.31101968@postgrespro.ru", "phone": "+70764768952"}
0005433785548	A078D0	8298 713456	OLGA FOMINA	{"phone": "+70616725965"}
0005433785549	A078D0	7719 053829	EKATERINA MAKSIMOVA	{"email": "e.maksimova101974@postgrespro.ru", "phone": "+70860652136"}
0005433785550	FADD51	2427 873022	ANNA RODIONOVA	{"phone": "+70745670513"}
0005433785551	05020C	3989 652517	ANASTASIYA BARANOVA	{"email": "a_baranova_101973@postgrespro.ru", "phone": "+70430895049"}
0005433785552	05020C	0025 660902	DIANA IVANOVA	{"phone": "+70599300595"}
0005433785553	C29A6C	7652 487877	EKATERINA ISAEVA	{"email": "ekaterina_isaeva.091971@postgrespro.ru", "phone": "+70420778436"}
0005433785554	666972	9915 046155	OLGA EGOROVA	{"email": "o-egorova011972@postgrespro.ru", "phone": "+70664622655"}
0005433785555	0824D4	8001 745205	ALEKSANDR VOLKOV	{"email": "a.volkov-05051976@postgrespro.ru", "phone": "+70973866928"}
0005433785556	0824D4	3392 102179	NINA VASILEVA	{"phone": "+70111360320"}
0005433785557	02A214	2800 822204	MAKSIM SCHERBAKOV	{"email": "m.scherbakov-061979@postgrespro.ru", "phone": "+70112887272"}
0005433785558	188447	1752 887964	OLEG MOROZOV	{"phone": "+70016245088"}
0005433785559	115255	4626 965307	VIKTOR ZHUKOV	{"phone": "+70913137866"}
0005433785560	0F36A3	0502 604749	MARTA RODIONOVA	{"email": "marta.rodionova.091970@postgrespro.ru", "phone": "+70056441492"}
0005433785561	7E5A9A	2358 398809	MAKSIM NAUMOV	{"phone": "+70566610763"}
0005433785562	A6E280	5226 156661	NATALYA ISAEVA	{"phone": "+70905586468"}
0005433785563	2B7655	6830 840771	OLGA NIKOLAEVA	{"phone": "+70369645952"}
0005433785564	5525B5	7840 983759	SNEZHANA MAKSIMOVA	{"phone": "+70671806359"}
0005433785565	5525B5	5540 921151	PETR KOZLOV	{"email": "petr-kozlov.1976@postgrespro.ru", "phone": "+70707130133"}
0005433785566	A48492	8120 292459	KRISTINA ALEKSEEVA	{"email": "alekseevakristina-27031973@postgrespro.ru", "phone": "+70015068533"}
0005433785567	A48492	4897 546737	ELENA VOLKOVA	{"email": "volkova-e_1978@postgrespro.ru", "phone": "+70996200815"}
0005433785568	A48492	4712 094305	RASIM IVANOV	{"email": "rasim.ivanov.061965@postgrespro.ru", "phone": "+70280318036"}
0005433785569	1FFB0F	9849 154557	VLADIMIR DENISOV	{"phone": "+70612745107"}
0005433785570	1FFB0F	1522 167338	ZINAIDA LUKYANOVA	{"email": "lukyanova_z_1970@postgrespro.ru", "phone": "+70208406576"}
0005433785571	AF573B	4788 434017	TATYANA KALININA	{"phone": "+70449523089"}
0005433785572	138969	6376 076436	ELENA BARANOVA	{"email": "e.baranova.111967@postgrespro.ru", "phone": "+70698084071"}
0005433785573	F4C953	6633 452566	ALEKSEY VOLKOV	{"email": "alekseyvolkov.17091975@postgrespro.ru", "phone": "+70410886259"}
0005433785574	6E8642	1368 534225	GENNADIY SCHERBAKOV	{"email": "scherbakov-g_111983@postgrespro.ru", "phone": "+70558503059"}
0005433785575	6E8642	7648 827285	VERA NIKITINA	{"phone": "+70167135039"}
0005433785576	573E5D	1599 696693	DARYA KOZLOVA	{"phone": "+70942684683"}
0005433785577	0F8C4C	1400 517239	LYUBOV KOZLOVA	{"phone": "+70957733577"}
0005433785578	834181	1969 025511	SERGEY CHERNOV	{"phone": "+70260376710"}
0005433785579	834181	8459 263536	NINA ZAYCEVA	{"phone": "+70104065085"}
0005433785580	1D206E	6144 288963	IRINA ZAKHAROVA	{"email": "i_zakharova1967@postgrespro.ru", "phone": "+70146179140"}
0005433785581	16B6B6	4409 802065	ILFAT BONDARENKO	{"email": "bondarenko.ilfat_1973@postgrespro.ru", "phone": "+70493675544"}
0005433785582	F397C8	1345 603151	VIKTOR VASILEV	{"email": "viktor_vasilev-1969@postgrespro.ru", "phone": "+70461086067"}
0005433785583	F397C8	3694 935273	IVAN SERGEEV	{"phone": "+70108520159"}
0005433785584	636459	2042 776541	MIKHAIL SOROKIN	{"phone": "+70920972498"}
0005433785585	E4CAC9	7751 253554	ROMAN VASILEV	{"phone": "+70050368578"}
0005433785586	A21ED9	8065 490718	DENIS KUZNECOV	{"email": "denis.kuznecov111963@postgrespro.ru", "phone": "+70123571820"}
0005433785587	87B310	3594 598601	ELIZAVETA POTAPOVA	{"email": "epotapova121968@postgrespro.ru", "phone": "+70892238901"}
0005433785588	DF507A	0996 215992	EKATERINA MOROZOVA	{"email": "morozova-e.24061966@postgrespro.ru", "phone": "+70406012977"}
0005433785589	4137DC	2220 117782	VALERIY IVANOV	{"phone": "+70752734672"}
0005433785590	FEFDA0	7997 896279	GEORGIY KRASNOV	{"phone": "+70440016318"}
0005433785591	8ABA80	4147 032690	GALINA NAZAROVA	{"phone": "+70170340014"}
0005433785592	8ABA80	7487 932810	MAKSIM CHERNOV	{"email": "chernov_maksim101962@postgrespro.ru", "phone": "+70711213592"}
0005433785593	8ABA80	7941 205021	NIKOLAY SOKOLOV	{"phone": "+70122133768"}
0005433785594	C7CC88	5130 490171	ALEKSEY ANTONOV	{"phone": "+70774502586"}
0005433785595	927E44	6092 100691	SVETLANA MOROZOVA	{"email": "morozova-svetlana_011973@postgrespro.ru", "phone": "+70503358043"}
0005433785596	9201E6	6090 506123	NADEZHDA AKIMOVA	{"email": "akimovanadezhda091982@postgrespro.ru", "phone": "+70018798658"}
0005433785597	A6D4ED	3014 849772	EVGENIY GERASIMOV	{"email": "gerasimov-evgeniy-22081970@postgrespro.ru", "phone": "+70871488396"}
0005433785598	A6D4ED	2822 640039	VIKTOR OSIPOV	{"email": "v-osipov-011966@postgrespro.ru", "phone": "+70035262793"}
0005433785599	5561E7	8410 522622	YURIY IVANOV	{"email": "ivanov_yuriy21111975@postgrespro.ru", "phone": "+70097661172"}
0005433785600	5561E7	6468 786631	LIDIYA EFREMOVA	{"email": "efremova.lidiya_1972@postgrespro.ru", "phone": "+70755878608"}
0005433785601	C917D5	9506 056393	ANNA NESTEROVA	{"email": "anesterova-031965@postgrespro.ru", "phone": "+70216095480"}
0005433785602	E7609A	3343 515996	VIKTOR NIKOLAEV	{"phone": "+70862775740"}
0005433785603	D47319	1520 760656	ALEKSEY FROLOV	{"email": "a-frolov.1968@postgrespro.ru", "phone": "+70579204906"}
0005433785604	D47319	2902 043869	ALEKSANDR SEMENOV	{"email": "a-semenov_1984@postgrespro.ru", "phone": "+70297866492"}
0005433785605	F83E6B	8392 128203	NADEZHDA POPOVA	{"phone": "+70970043106"}
0005433785606	D0210F	1294 022031	VLADIMIR GERASIMOV	{"phone": "+70256513838"}
0005433785607	43434A	9870 743924	VIKTOR STEPANOV	{"email": "stepanov_viktor-061972@postgrespro.ru", "phone": "+70317345474"}
0005433785608	EE31BB	0198 435866	DMITRIY SEMENOV	{"phone": "+70788401334"}
0005433785609	BAC5B7	7466 394847	NINA ZHURAVLEVA	{"email": "zhuravleva-nina.1987@postgrespro.ru", "phone": "+70742013448"}
0005433785610	BAC5B7	7297 182605	ANNA AKIMOVA	{"phone": "+70415119225"}
0005433785611	A6B42B	5986 494048	EVGENIY VOROBEV	{"email": "vorobev.e.091970@postgrespro.ru", "phone": "+70114252780"}
0005433785612	A6B42B	3939 917257	LYUBOV VASILEVA	{"email": "vasileva.lyubov_121970@postgrespro.ru", "phone": "+70828005879"}
0005433785613	95164C	5454 064727	SERGEY MOISEEV	{"phone": "+70184465486"}
0005433785614	ADEF12	6126 115432	IVAN NIKOLAEV	{"email": "nikolaevi011981@postgrespro.ru", "phone": "+70924433148"}
0005433785615	821B2B	9207 475697	VITALIY IVANOV	{"email": "vitaliy-ivanov17021974@postgrespro.ru", "phone": "+70718308184"}
0005433785616	821B2B	2996 980182	DMITRIY FOMIN	{"email": "fomin-dmitriy-011977@postgrespro.ru", "phone": "+70172341821"}
0005433785617	EE323B	7897 151261	VALERIY KULIKOV	{"phone": "+70472872655"}
0005433785618	EE323B	9455 811581	VLADISLAV SMIRNOV	{"email": "smirnovvladislav_01041974@postgrespro.ru", "phone": "+70080406799"}
0005433785619	D9EAF3	3544 608830	NIKITA SEMENOV	{"phone": "+70965914986"}
0005433785620	364AEF	5091 281632	NINA ZHURAVLEVA	{"phone": "+70509054155"}
0005433785621	082C86	6951 124321	NATALYA ZHUKOVA	{"email": "natalya_zhukova.071962@postgrespro.ru", "phone": "+70156741958"}
0005433785622	88A9F1	6025 566972	ALISA NAUMOVA	{"phone": "+70332949338"}
0005433785623	BA5365	4027 620164	MARIYA ZHUKOVA	{"email": "zhukovamariya-1969@postgrespro.ru", "phone": "+70446984363"}
0005433785624	39D399	3232 478351	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr.041966@postgrespro.ru", "phone": "+70220310372"}
0005433785625	39D399	8596 125286	DARYA GRISHINA	{"email": "grishina.darya.1963@postgrespro.ru", "phone": "+70727013958"}
0005433785626	920A5B	8961 053943	ANDREY MAKAROV	{"phone": "+70738121798"}
0005433785627	920A5B	7840 331458	YURIY ZAYCEV	{"phone": "+70179387068"}
0005433785628	7C90F2	0132 737951	SERGEY ZAYCEV	{"email": "zaycev_sergey-081987@postgrespro.ru", "phone": "+70589084465"}
0005433785629	4DE9B9	1896 556753	ALEKSANDR MOROZOV	{"phone": "+70025194831"}
0005433785630	0CA92A	6333 739242	NATALYA EGOROVA	{"email": "egorova_natalya_04101963@postgrespro.ru", "phone": "+70215761151"}
0005433785631	E06D26	8732 871995	OLGA ZHUKOVA	{"email": "zhukova-o-13111962@postgrespro.ru", "phone": "+70192735553"}
0005433785632	E0607C	2638 258356	IVAN KUZMIN	{"email": "kuzmin-ivan1959@postgrespro.ru", "phone": "+70626438166"}
0005433785633	BB71AA	9717 355571	LIDIYA BORISOVA	{"email": "l_borisova_1969@postgrespro.ru", "phone": "+70485172233"}
0005433785634	BB71AA	3790 555163	EVGENIY ANDREEV	{"email": "andreev-e-1969@postgrespro.ru", "phone": "+70291720434"}
0005433785635	BB71AA	5636 790714	SVETLANA YUDINA	{"email": "yudinasvetlana.021972@postgrespro.ru", "phone": "+70811813903"}
0005433785636	DEF260	7105 274923	NATALYA BELOVA	{"phone": "+70890727753"}
0005433785637	AB7D73	6590 014575	VALERIY KUZNECOV	{"email": "valeriy_kuznecov-27011975@postgrespro.ru", "phone": "+70898579994"}
0005433785638	AB7D73	4569 605379	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov30101971@postgrespro.ru", "phone": "+70449259883"}
0005433785639	153A20	9199 633673	VALENTINA PETROVA	{"phone": "+70074069623"}
0005433785640	405BE4	3956 069193	YULIYA MIKHAYLOVA	{"email": "mikhaylova_yuliya_1966@postgrespro.ru", "phone": "+70609656369"}
0005433785641	C70CDF	2291 293296	VERA DANILOVA	{"phone": "+70071063937"}
0005433785642	C70CDF	1859 023283	YULIYA SEMENOVA	{"phone": "+70377554490"}
0005433785643	40A691	7695 476145	LYUDMILA MOROZOVA	{"email": "lmorozova-011966@postgrespro.ru", "phone": "+70955777049"}
0005433785644	40A691	2146 445234	LYUBOV GRISHINA	{"phone": "+70446097758"}
0005433785645	5216FA	9222 003582	BORIS KAZAKOV	{"email": "kazakov-b_20081947@postgrespro.ru", "phone": "+70265266964"}
0005433785646	5216FA	8253 333993	NADEZHDA OSIPOVA	{"email": "nadezhda_osipova.091975@postgrespro.ru", "phone": "+70175114706"}
0005433785647	DA3793	7825 062684	MATVEY KONOVALOV	{"email": "konovalov.matvey-1966@postgrespro.ru", "phone": "+70143266499"}
0005433785648	4352C3	8335 442088	MARIYA AFANASEVA	{"email": "mariya-afanaseva.101969@postgrespro.ru", "phone": "+70617775826"}
0005433785649	303D6B	7946 491994	GULNAZ DMITRIEVA	{"email": "dmitrievagulnaz25101969@postgrespro.ru", "phone": "+70701522726"}
0005433785650	303D6B	0648 015236	GEORGIY GORBUNOV	{"email": "ggorbunov-1970@postgrespro.ru", "phone": "+70186914118"}
0005433785651	2FDA6B	2324 654143	VALENTINA EFIMOVA	{"email": "valentina.efimova_14051975@postgrespro.ru", "phone": "+70854697171"}
0005433785652	B9C918	9259 042857	EVGENIY GRIGOREV	{"phone": "+70977357420"}
0005433785653	B9C918	1372 204378	ANNA KONOVALOVA	{"email": "akonovalova.061980@postgrespro.ru", "phone": "+70129315922"}
0005433785654	E5DBF1	5348 503552	LARISA IVANOVA	{"email": "ivanova-larisa.23011975@postgrespro.ru", "phone": "+70269222523"}
0005433785655	E5DBF1	0462 073419	GENNADIY BONDARENKO	{"email": "bondarenko.gennadiy02121972@postgrespro.ru", "phone": "+70933425440"}
0005433785656	C8A595	6605 050888	ALEKSANDR ANDREEV	{"phone": "+70512460322"}
0005433785657	3C48C5	9177 227366	EKATERINA SAVELEVA	{"phone": "+70666663763"}
0005433785658	99EF49	1984 166361	NATALYA POPOVA	{"email": "natalya.popova091977@postgrespro.ru", "phone": "+70917578791"}
0005433785659	99EF49	1689 933112	MARIYA STEPANOVA	{"email": "stepanovam16061970@postgrespro.ru", "phone": "+70587775547"}
0005433785660	1736A7	4793 076037	EDUARD VOLKOV	{"email": "eduard_volkov-1974@postgrespro.ru", "phone": "+70879909231"}
0005433785661	1BCBA5	8679 378434	TATYANA KUZNECOVA	{"email": "t_kuznecova20031971@postgrespro.ru", "phone": "+70931630387"}
0005433785662	EA72E3	9715 298583	TATYANA VASILEVA	{"phone": "+70511098658"}
0005433785663	F27BD8	3241 009686	ANATOLIY DMITRIEV	{"phone": "+70843248564"}
0005433785664	74F2AE	3921 077169	VLADIMIR ANDREEV	{"email": "andreev.v_021975@postgrespro.ru", "phone": "+70516421281"}
0005433785665	DBCD0F	5327 710316	GALINA ORLOVA	{"phone": "+70856800913"}
0005433785666	DBCD0F	7049 301209	ANDREY KUZNECOV	{"email": "kuznecov_a.071973@postgrespro.ru", "phone": "+70574993705"}
0005433785667	4DF803	8360 488491	VALENTINA IVANOVA	{"email": "ivanovavalentina_061986@postgrespro.ru", "phone": "+70800322059"}
0005433785668	4DF803	5459 053594	ALEKSEY VOROBEV	{"phone": "+70043932846"}
0005433785669	473ABB	3962 371852	ALEKSEY NIKOLAEV	{"phone": "+70198303974"}
0005433785670	473ABB	2273 652352	NIKITA SMIRNOV	{"phone": "+70167570934"}
0005433785671	9F7D1C	4714 321179	ALEKSEY ALEKSANDROV	{"email": "a-aleksandrov_01091975@postgrespro.ru", "phone": "+70777629031"}
0005433785672	A1776D	6535 267110	MARGARITA OSIPOVA	{"email": "osipova.m-081979@postgrespro.ru", "phone": "+70664831337"}
0005433785673	6A3662	2155 022113	OLGA ILINA	{"email": "ilina_o.1961@postgrespro.ru", "phone": "+70556170918"}
0005433785674	E01A31	8102 990036	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey1976@postgrespro.ru", "phone": "+70293650827"}
0005433785675	E01A31	3684 149556	IVAN TIKHONOV	{"email": "tikhonov-i-101982@postgrespro.ru", "phone": "+70216356869"}
0005433785676	A0811B	0542 647372	KSENIYA ROMANOVA	{"email": "romanova.k_12021970@postgrespro.ru", "phone": "+70834738739"}
0005433785677	9C5C63	0017 721730	DARYA KISELEVA	{"phone": "+70354626684"}
0005433785678	21EB76	0410 974159	MARINA ARKHIPOVA	{"email": "arkhipova-m121975@postgrespro.ru", "phone": "+70686941193"}
0005433785679	6A3D3A	4506 564657	SVETLANA TARASOVA	{"email": "s_tarasova_1974@postgrespro.ru", "phone": "+70553716136"}
0005433785680	56C6FD	5116 068261	ALEKSANDR PAVLOV	{"email": "pavlov_a081981@postgrespro.ru", "phone": "+70026387001"}
0005433785681	362D81	6246 064647	LARISA SCHERBAKOVA	{"email": "larisa_scherbakova1966@postgrespro.ru", "phone": "+70617870744"}
0005433785682	59BB22	6283 517022	OLGA IVANOVA	{"email": "olga_ivanova.121973@postgrespro.ru", "phone": "+70009002576"}
0005433785683	59BB22	1379 916216	IVAN KARPOV	{"email": "karpovi1964@postgrespro.ru", "phone": "+70560459102"}
0005433785684	6F7944	5174 329894	SERGEY GUSEV	{"email": "gusev.s-04061974@postgrespro.ru", "phone": "+70428369866"}
0005433785685	6F7944	9890 888321	YURIY KARPOV	{"email": "yuriy.karpov-121974@postgrespro.ru", "phone": "+70596248403"}
0005433785686	80CE4C	9437 614977	ROMAN ZHUKOV	{"email": "zhukov_r.24041976@postgrespro.ru", "phone": "+70096123359"}
0005433785687	80CE4C	0271 099047	MARIYA KULIKOVA	{"phone": "+70101728120"}
0005433785688	0D5495	7823 571029	BOGDAN ALEKSEEV	{"email": "b-alekseev.1971@postgrespro.ru", "phone": "+70743052304"}
0005433785689	0D5495	7979 647249	TATYANA MAKAROVA	{"email": "makarovatatyana18051973@postgrespro.ru", "phone": "+70619735917"}
0005433785690	865FD7	2387 456630	LYUBOV KUZNECOVA	{"phone": "+70671117733"}
0005433785691	634EC6	5591 716135	OLGA NESTEROVA	{"phone": "+70638700026"}
0005433785692	634EC6	7307 064083	ARTEM IVANOV	{"email": "a.ivanov-061983@postgrespro.ru", "phone": "+70334398494"}
0005433785693	DE66CF	1939 357583	VALENTINA ZAKHAROVA	{"email": "v_zakharova1962@postgrespro.ru", "phone": "+70004650850"}
0005433785694	D3C266	0526 738991	VALENTINA ALEKSEEVA	{"phone": "+70001042906"}
0005433785695	D3C266	4348 553221	TAMARA LOGINOVA	{"email": "loginovatamara-03021973@postgrespro.ru", "phone": "+70227853695"}
0005433785696	CC1251	1541 652766	MIKHAIL KOZLOV	{"email": "kozlov-m-1967@postgrespro.ru", "phone": "+70614202325"}
0005433785697	CC1251	6106 204129	YURIY ZAKHAROV	{"email": "yuriyzakharov_11021969@postgrespro.ru", "phone": "+70767054131"}
0005433785698	9FF7EA	2677 748558	NIKOLAY VASILEV	{"email": "n-vasilev051977@postgrespro.ru", "phone": "+70592626461"}
0005433785699	2B1CC0	3805 310498	ALEKSEY SMIRNOV	{"email": "aleksey_smirnov.1981@postgrespro.ru", "phone": "+70694717850"}
0005433785700	6846A9	0997 087123	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov011973@postgrespro.ru", "phone": "+70815350817"}
0005433785701	6846A9	9097 467940	NIKOLAY ZAKHAROV	{"phone": "+70187627938"}
0005433785702	A9A6FC	4098 208360	VALENTINA KULIKOVA	{"email": "kulikova-valentina.11101969@postgrespro.ru", "phone": "+70932125150"}
0005433785703	A9A6FC	6358 308210	ALEKSEY FROLOV	{"phone": "+70655410181"}
0005433785704	129FA4	2275 114456	VALERIY IVANOV	{"phone": "+70748179276"}
0005433785705	E429CD	2113 036335	RAVIL KONOVALOV	{"phone": "+70131569508"}
0005433785706	2CD41B	3743 163685	EVGENIY ZAKHAROV	{"email": "ezakharov28041971@postgrespro.ru", "phone": "+70521898031"}
0005433785707	F766FC	4566 119471	VLADISLAV OSIPOV	{"phone": "+70358072272"}
0005433785708	F766FC	4045 192321	ELENA VLASOVA	{"email": "vlasova.e_30101976@postgrespro.ru", "phone": "+70295089003"}
0005433785709	D2B94E	8475 429962	VIKTOR SMIRNOV	{"email": "smirnov_v.03061980@postgrespro.ru", "phone": "+70023050420"}
0005433785710	C50807	9927 080920	IGOR EGOROV	{"email": "i.egorov1959@postgrespro.ru", "phone": "+70047232618"}
0005433785711	46B9E1	9547 567142	IVAN ZAYCEV	{"phone": "+70902725670"}
0005433785712	DECD88	0186 423649	ELENA IVANOVA	{"phone": "+70707317032"}
0005433785713	DECD88	7216 136825	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a051967@postgrespro.ru", "phone": "+70034480033"}
0005433785714	C6706E	9870 938743	OLGA DENISOVA	{"email": "o.denisova-1973@postgrespro.ru", "phone": "+70552568517"}
0005433785715	C6706E	2524 144915	ANASTASIYA POLYAKOVA	{"email": "apolyakova_04111972@postgrespro.ru", "phone": "+70941271217"}
0005433785717	A2387C	8876 710967	MAKSIM CHERNOV	{"email": "m-chernov-111970@postgrespro.ru", "phone": "+70598468925"}
0005433785718	3F82CB	1451 597844	ANDREY PAVLOV	{"phone": "+70649105600"}
0005433785719	50E0D2	5762 670507	ALENA IVANOVA	{"email": "alena-ivanova011973@postgrespro.ru", "phone": "+70826339153"}
0005433785720	50E0D2	2025 366855	LYUBOV KOZLOVA	{"phone": "+70476068423"}
0005433785721	4E3A49	5963 062658	DIANA VOLKOVA	{"email": "d.volkova.29011977@postgrespro.ru", "phone": "+70420611462"}
0005433785722	4E3A49	6937 982617	YULIYA LEBEDEVA	{"phone": "+70371621387"}
0005433785723	99AB3C	5843 816530	ANGELINA MEDVEDEVA	{"phone": "+70536887686"}
0005433785724	9986BC	8921 392038	ALEKSANDR KRASNOV	{"phone": "+70462202161"}
0005433785725	1CA885	3911 471971	VASILIY OSIPOV	{"email": "v-osipov1968@postgrespro.ru", "phone": "+70109690091"}
0005433785726	3D9ECB	7439 760714	LYUDMILA KOZLOVA	{"email": "kozloval_121976@postgrespro.ru", "phone": "+70453933309"}
0005433785727	B06B3C	3445 244848	MARGARITA VASILEVA	{"email": "margaritavasileva_1970@postgrespro.ru", "phone": "+70214981375"}
0005433785728	B06B3C	8473 660951	ZOYA MAKAROVA	{"phone": "+70009618067"}
0005433785729	B06B3C	1321 672670	VALENTINA ERMAKOVA	{"phone": "+70809740016"}
0005433785730	66D8D9	8003 928779	SVETLANA LEBEDEVA	{"email": "lebedeva_s1975@postgrespro.ru", "phone": "+70786113396"}
0005433785731	815BD8	8379 948653	SERGEY SIDOROV	{"email": "sidorov-s-1969@postgrespro.ru", "phone": "+70915863211"}
0005433785732	228E28	9332 452321	ELENA AFANASEVA	{"phone": "+70656957150"}
0005433785733	48FFEC	7397 697517	TATYANA MAKAROVA	{"email": "makarova_tatyana_111976@postgrespro.ru", "phone": "+70999743696"}
0005433785734	48FFEC	5730 168782	TATYANA KUZNECOVA	{"email": "kuznecova_t.1970@postgrespro.ru", "phone": "+70734697604"}
0005433785735	798F53	2695 881979	ALEKSANDR BORISOV	{"email": "borisov_aleksandr.1968@postgrespro.ru", "phone": "+70492005741"}
0005433785736	798F53	8579 506481	VALENTINA NIKIFOROVA	{"phone": "+70426570513"}
0005433785737	96E5BF	1307 608198	NINA BOGDANOVA	{"phone": "+70926611293"}
0005433785738	9F98C4	5682 342424	RINAT IVANOV	{"phone": "+70108879002"}
0005433785739	9F98C4	1315 435871	ELENA NOVIKOVA	{"email": "novikova_e.101975@postgrespro.ru", "phone": "+70957899419"}
0005433785740	700E8A	4873 252962	GALINA KRASNOVA	{"email": "galinakrasnova-06011978@postgrespro.ru", "phone": "+70274554174"}
0005433785741	C9C1E0	0180 920176	VALENTINA KARPOVA	{"phone": "+70786742387"}
0005433785742	C9C1E0	9890 838260	IGOR TIKHONOV	{"phone": "+70404863847"}
0005433785743	7E082B	1023 799735	ELVINA BORISOVA	{"email": "borisovae_1960@postgrespro.ru", "phone": "+70838993317"}
0005433785744	0E9595	8953 700748	SERGEY ROMANOV	{"phone": "+70935900595"}
0005433785745	0E9595	2738 159543	LARISA KUZNECOVA	{"phone": "+70146737583"}
0005433785746	0DE8D6	1024 506178	ALEKSANDR CHERNOV	{"phone": "+70759562843"}
0005433785747	489A82	8108 016544	OLEG ZHUKOV	{"phone": "+70112264189"}
0005433785748	F6268D	7171 044114	SERGEY NOVIKOV	{"email": "novikovs.061967@postgrespro.ru", "phone": "+70361429114"}
0005433785749	F6268D	0777 858701	NIKOLAY VASILEV	{"email": "vasilev_nikolay1980@postgrespro.ru", "phone": "+70047930771"}
0005433785750	B921C6	2719 103956	VIKTOR BORISOV	{"email": "viktor_borisov_07031976@postgrespro.ru", "phone": "+70902010662"}
0005433785751	12AAF9	9065 996830	IRINA POTAPOVA	{"email": "potapovai111974@postgrespro.ru", "phone": "+70916985105"}
0005433785752	561D9B	4037 317507	NATALYA BARANOVA	{"phone": "+70046858730"}
0005433785753	548278	8125 179543	RINAT TARASOV	{"phone": "+70117701210"}
0005433785754	548278	6366 013199	OLGA AKIMOVA	{"email": "akimovao-1968@postgrespro.ru", "phone": "+70675487612"}
0005433785755	7AB361	2832 815242	NATALYA BOGDANOVA	{"email": "natalya.bogdanova.02091973@postgrespro.ru", "phone": "+70259030665"}
0005433785756	1510EA	7842 937319	ALEKSANDRA ZHURAVLEVA	{"phone": "+70309469727"}
0005433785757	000374	6547 193021	VALENTINA PAVLOVA	{"phone": "+70021949335"}
0005433785758	0CAF47	6175 294761	ANNA LUKYANOVA	{"email": "annalukyanova_24051971@postgrespro.ru", "phone": "+70182485899"}
0005433785759	3063D7	7675 258599	ANDREY KRASNOV	{"phone": "+70095360956"}
0005433785760	F9C8DF	9482 171812	TAMARA OSIPOVA	{"phone": "+70918355684"}
0005433785761	68DAF7	1547 672402	ALEKSEY BORISOV	{"phone": "+70007269688"}
0005433785762	9B7110	7214 324285	ANATOLIY RODIONOV	{"phone": "+70046731777"}
0005433785763	214E9F	2352 792830	OLGA ZAYCEVA	{"phone": "+70795398835"}
0005433785764	214E9F	6220 603834	LYUBOV SMIRNOVA	{"email": "smirnovalyubov-051974@postgrespro.ru", "phone": "+70270386388"}
0005433785765	882357	5691 686460	DENIS ANDREEV	{"email": "andreev-denis-1969@postgrespro.ru", "phone": "+70104459626"}
0005433785766	F96983	5026 521113	DENIS POPOV	{"phone": "+70698717265"}
0005433785767	F96983	5781 317283	DMITRIY MIKHAYLOV	{"phone": "+70430511024"}
0005433785768	C4278F	0313 020799	SERGEY ZHUKOV	{"phone": "+70999921609"}
0005433785769	C4278F	6369 395237	NAZAR SEMENOV	{"email": "semenov.nazar.111961@postgrespro.ru", "phone": "+70896959323"}
0005433785770	DA7599	3018 342674	NATALYA VASILEVA	{"phone": "+70580879253"}
0005433785771	51F91F	8703 325057	MIKHAIL KAZAKOV	{"phone": "+70337860536"}
0005433785772	B9D0A4	2129 308157	ALEKSANDRA ALEKSEEVA	{"email": "a-alekseeva-071976@postgrespro.ru", "phone": "+70698064734"}
0005433785773	010DF1	9855 300110	IRINA SERGEEVA	{"email": "sergeevairina.1974@postgrespro.ru", "phone": "+70330894338"}
0005433785774	010DF1	9250 999905	MARIYA POLYAKOVA	{"email": "polyakova.mariya-1973@postgrespro.ru", "phone": "+70782861205"}
0005433785775	60A913	5016 107991	VALENTINA TIKHONOVA	{"phone": "+70120790062"}
0005433785776	5B7F05	5049 141000	LYUBOV SERGEEVA	{"email": "lsergeeva1968@postgrespro.ru", "phone": "+70964571178"}
0005433785777	56FCE9	5022 002017	MILENA ANDREEVA	{"phone": "+70533988461"}
0005433785778	C3187C	8027 339559	MARIYA ILINA	{"email": "ilina-mariya_16021975@postgrespro.ru", "phone": "+70686095456"}
0005433785779	C3187C	5809 194245	LYUDMILA MELNIKOVA	{"email": "lyudmila_melnikova_081971@postgrespro.ru", "phone": "+70429424264"}
0005433785780	C3187C	5492 280265	OLGA KUZNECOVA	{"email": "olga-kuznecova-24041974@postgrespro.ru", "phone": "+70475132685"}
0005433785781	26FA63	8025 477939	PRASKOVYA ALEKSEEVA	{"email": "praskovya_alekseeva.06111988@postgrespro.ru", "phone": "+70006171062"}
0005433785782	322905	8953 752168	TATYANA ALEKSEEVA	{"email": "alekseeva_tatyana.031984@postgrespro.ru", "phone": "+70895473611"}
0005433785783	4986A7	4103 207768	YAROSLAV EGOROV	{"email": "egorovy.111971@postgrespro.ru", "phone": "+70400713428"}
0005433785784	11EFB1	3287 464898	MIKHAIL KOZLOV	{"email": "kozlov_mikhail1977@postgrespro.ru", "phone": "+70563417306"}
0005433785785	FF9C44	5680 210673	ALEKSEY KAZAKOV	{"email": "alekseykazakov_12011967@postgrespro.ru", "phone": "+70661403954"}
0005433785787	4AD051	8276 664816	NATALYA AKIMOVA	{"phone": "+70303991072"}
0005433785788	8F67C9	6443 646394	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-051960@postgrespro.ru", "phone": "+70597543889"}
0005433785789	245742	0133 109503	YURIY MOROZOV	{"phone": "+70715834952"}
0005433785790	F3B57C	4257 483386	ELENA MAKSIMOVA	{"phone": "+70494188622"}
0005433785791	43F5A3	8353 672247	ELENA STEPANOVA	{"email": "stepanova-e_1974@postgrespro.ru", "phone": "+70052712027"}
0005433785792	43F5A3	5060 004661	ANGELINA SOROKINA	{"email": "sorokina_a051959@postgrespro.ru", "phone": "+70564558324"}
0005433785793	1E6695	5003 403684	IVAN ZAKHAROV	{"email": "zakharov.ivan-031971@postgrespro.ru", "phone": "+70802599231"}
0005433785794	1E6695	3195 634313	OLGA GAVRILOVA	{"phone": "+70683763291"}
0005433785795	C7E19A	4016 390025	LYUBOV FEDOROVA	{"phone": "+70851179778"}
0005433785796	C7E19A	0869 615442	ALEKSEY NIKITIN	{"email": "alekseynikitin.17081967@postgrespro.ru", "phone": "+70258038872"}
0005433785797	59CEA9	8519 683407	LYUDMILA KOZLOVA	{"email": "lkozlova-15121985@postgrespro.ru", "phone": "+70432974415"}
0005433785798	936BAF	6475 812888	LILIYA ZAKHAROVA	{"email": "lzakharova-20091983@postgrespro.ru", "phone": "+70723781217"}
0005433785799	E16E9C	7833 441323	NATALYA GERASIMOVA	{"phone": "+70904534001"}
0005433785800	E16E9C	2190 047064	VLADIMIR SOKOLOV	{"email": "sokolov-vladimir-30031980@postgrespro.ru", "phone": "+70666247995"}
0005433785801	E16E9C	7983 918780	RAMIL MARTYNOV	{"phone": "+70475012969"}
0005433785802	3C0258	9993 994696	OKSANA VOLKOVA	{"email": "oksana_volkova-30101972@postgrespro.ru", "phone": "+70948716260"}
0005433785803	CA6CB6	3170 971275	ALEKSANDR MIKHAYLOV	{"phone": "+70508518906"}
0005433785804	8247D9	2337 949999	EVGENIY BARANOV	{"phone": "+70915380560"}
0005433785805	4AD375	7558 946157	YURIY KOZLOV	{"phone": "+70062740043"}
0005433785806	B38059	1868 299500	NATALIYA ABRAMOVA	{"email": "nataliya-abramova10021979@postgrespro.ru", "phone": "+70986609035"}
0005433785807	B38059	1780 083577	VLADISLAV ZHUKOV	{"email": "v.zhukov-1964@postgrespro.ru", "phone": "+70556332329"}
0005433785808	B38059	3858 608008	OLGA FADEEVA	{"phone": "+70970169732"}
0005433785809	6ADB8E	5720 865990	ALEKSEY DMITRIEV	{"phone": "+70756963557"}
0005433785810	888CF2	7110 570652	MARINA IVANOVA	{"phone": "+70477246061"}
0005433785811	888CF2	9130 008627	ROMAN PETROV	{"phone": "+70621613998"}
0005433785812	62BB66	7058 198047	OLGA EFREMOVA	{"phone": "+70625960413"}
0005433785813	D925BB	4558 216782	PAVEL ANDREEV	{"phone": "+70507593861"}
0005433785814	0DEC34	4343 205001	NADEZHDA ISAEVA	{"phone": "+70290473373"}
0005433785815	0DEC34	2555 362953	LYUBOV MASLOVA	{"phone": "+70900610026"}
0005433785816	4CEE3F	7343 678950	ROZA ZAKHAROVA	{"email": "roza-zakharova-1974@postgrespro.ru", "phone": "+70593847882"}
0005433785817	7C62BB	9631 079157	VLADIMIR NIKITIN	{"phone": "+70020434631"}
0005433785818	7C62BB	3874 229766	VLADISLAV FILIPPOV	{"email": "filippov.v25041968@postgrespro.ru", "phone": "+70385511105"}
0005433785819	671BBA	6419 199370	NATALIYA PETROVA	{"phone": "+70597500276"}
0005433785820	51DFE2	2239 179134	DMITRIY FOMIN	{"email": "fomind031965@postgrespro.ru", "phone": "+70189370956"}
0005433785821	C34F6A	8948 208918	DMITRIY ABRAMOV	{"email": "dmitriyabramov.1973@postgrespro.ru", "phone": "+70874023262"}
0005433785822	C34F6A	6922 572725	TATYANA SMIRNOVA	{"phone": "+70341203004"}
0005433785823	A21E95	7896 411656	YURIY KARPOV	{"email": "ykarpov-051964@postgrespro.ru", "phone": "+70652775323"}
0005433785824	A21E95	2017 072421	VERA ZHUKOVA	{"email": "v_zhukova_061978@postgrespro.ru", "phone": "+70314625673"}
0005433785825	A21E95	5503 224633	MARIYA LUKYANOVA	{"email": "lukyanova-mariya.041970@postgrespro.ru", "phone": "+70313763810"}
0005433785826	AEFD6A	4055 055983	OLEG KUZNECOV	{"phone": "+70856495683"}
0005433785827	E81717	4833 097920	MARIYA IVANOVA	{"email": "m-ivanova_1981@postgrespro.ru", "phone": "+70051144635"}
0005433785828	B0C6E0	0239 347410	ANTON DAVYDOV	{"email": "anton.davydov-031970@postgrespro.ru", "phone": "+70940197468"}
0005433785829	F4BB0A	8039 058712	TATYANA VOROBEVA	{"email": "t-vorobeva.17121982@postgrespro.ru", "phone": "+70985586844"}
0005433785886	A5B711	8633 282841	GENNADIY FEDOTOV	{"phone": "+70993537038"}
0005433785830	F88717	3825 913601	BORIS MIRONOV	{"email": "bmironov.20101956@postgrespro.ru", "phone": "+70880423013"}
0005433785831	F88717	8606 373829	ANASTASIYA GERASIMOVA	{"email": "anastasiya-gerasimova-1962@postgrespro.ru", "phone": "+70563803800"}
0005433785832	741B12	5814 380245	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr.26121979@postgrespro.ru", "phone": "+70998884498"}
0005433785833	741B12	4796 263460	ANASTASIYA ZOTOVA	{"phone": "+70822784533"}
0005433785834	EB4FC0	7565 185298	VALENTINA SMIRNOVA	{"email": "smirnova_valentina_13021963@postgrespro.ru", "phone": "+70643709373"}
0005433785835	5B4EB6	7986 151918	OLEG KONOVALOV	{"phone": "+70704538243"}
0005433785836	5B4EB6	8738 789547	VIKTOR GRIGOREV	{"email": "viktor_grigorev-25081965@postgrespro.ru", "phone": "+70412715398"}
0005433785837	9EA431	0902 086973	OLGA VLASOVA	{"phone": "+70932862661"}
0005433785838	A6206B	4802 088350	MARINA ARKHIPOVA	{"phone": "+70815560629"}
0005433785839	CFC101	9098 878827	NADEZHDA KOZLOVA	{"phone": "+70313350469"}
0005433785840	2D2D2A	3154 191239	TATYANA GAVRILOVA	{"phone": "+70121061591"}
0005433785841	2D2D2A	3994 728474	VLADIMIR KRASNOV	{"phone": "+70292362901"}
0005433785842	47ECFF	4112 098599	VYACHESLAV ZAYCEV	{"email": "zaycev_v_091963@postgrespro.ru", "phone": "+70262153586"}
0005433785843	47ECFF	3716 971674	ILNUR PETROV	{"phone": "+70227151840"}
0005433785844	47ECFF	2162 147615	GRIGORIY IVANOV	{"phone": "+70215980248"}
0005433785845	A43257	2758 657650	NATALIYA YAKOVLEVA	{"email": "n.yakovleva.051970@postgrespro.ru", "phone": "+70276771425"}
0005433785846	1E0666	9355 269484	LYUDMILA PAVLOVA	{"phone": "+70272776182"}
0005433785847	1E0666	3943 570787	MIKHAIL GRIGOREV	{"phone": "+70055560243"}
0005433785848	1E0666	0273 659821	SERGEY GRIGOREV	{"email": "grigorevsergey.05111967@postgrespro.ru", "phone": "+70632332750"}
0005433785849	DF85C9	9578 920651	IRINA YAKOVLEVA	{"phone": "+70683098330"}
0005433785850	DF85C9	6932 614100	OLEG TARASOV	{"phone": "+70788297231"}
0005433785851	2F0ABF	5652 146890	ALEKSANDR POPOV	{"phone": "+70241470830"}
0005433785852	D8EB02	3074 664364	SVETLANA IVANOVA	{"phone": "+70703831523"}
0005433785853	34F94F	3509 698379	DMITRIY SIDOROV	{"email": "sidorov.dmitriy_031976@postgrespro.ru", "phone": "+70003917497"}
0005433785854	4ABFD8	9142 658949	ELENA DANILOVA	{"email": "e_danilova_121977@postgrespro.ru", "phone": "+70661004116"}
0005433785855	4ABFD8	9235 645863	ELIZAVETA KARPOVA	{"email": "karpova.elizaveta_031986@postgrespro.ru", "phone": "+70645217672"}
0005433785856	065464	8436 905491	RAIS NIKOLAEV	{"phone": "+70996787426"}
0005433785857	065464	0242 191690	LILIYA SEMENOVA	{"phone": "+70947713141"}
0005433785858	D7FFF1	8289 427052	FARIDA KUZMINA	{"phone": "+70375110980"}
0005433785859	D7FFF1	0975 227830	ANASTASIYA MARTYNOVA	{"email": "anastasiya-martynova1975@postgrespro.ru", "phone": "+70892443782"}
0005433785860	72F63F	5511 976358	ALEKSEY DAVYDOV	{"phone": "+70491939726"}
0005433785861	FD2BB8	9786 126389	STANISLAV KOZLOV	{"phone": "+70917541552"}
0005433785862	FD2BB8	7763 310875	ALEKSANDRA RODIONOVA	{"phone": "+70295686162"}
0005433785863	ABA091	0229 731534	ALEKSANDR ZAKHAROV	{"email": "zakharov.a_15021968@postgrespro.ru", "phone": "+70184175993"}
0005433785864	71843A	0118 404152	VIKTOR IVANOV	{"phone": "+70006717466"}
0005433785865	77E94D	2030 937080	KSENIYA MEDVEDEVA	{"email": "medvedeva.kseniya01071964@postgrespro.ru", "phone": "+70109839068"}
0005433785866	77E94D	7829 011250	TATYANA MEDVEDEVA	{"phone": "+70018407704"}
0005433785867	7E07F7	3119 957347	YULIYA MEDVEDEVA	{"phone": "+70949031134"}
0005433785868	7E07F7	9625 128869	NATALYA TROFIMOVA	{"phone": "+70234200282"}
0005433785869	E40CD0	8554 258804	VERA TITOVA	{"email": "titova.v_111964@postgrespro.ru", "phone": "+70473183420"}
0005433785870	A537D0	9217 164901	TATYANA PAVLOVA	{"phone": "+70095402777"}
0005433785871	463E60	3448 565352	SERGEY ZAYCEV	{"email": "s.zaycev1977@postgrespro.ru", "phone": "+70553883541"}
0005433785872	463E60	9216 828053	TATYANA IVANOVA	{"email": "ivanova_t_1967@postgrespro.ru", "phone": "+70979557870"}
0005433785873	7CD23B	1438 948262	KONSTANTIN NIKOLAEV	{"phone": "+70606922964"}
0005433785874	4F95A7	9122 927329	VLADIMIR IVANOV	{"email": "vladimir.ivanov.1977@postgrespro.ru", "phone": "+70948729815"}
0005433785875	A12258	2611 585308	NIKOLAY BORISOV	{"email": "n_borisov_021974@postgrespro.ru", "phone": "+70894291139"}
0005433785876	9F5D72	3021 039326	IRINA KONOVALOVA	{"email": "konovalova.irina_111970@postgrespro.ru", "phone": "+70195919503"}
0005433785877	4D1EE4	6772 150342	ALEKSANDRA RODIONOVA	{"phone": "+70881609043"}
0005433785878	AA424F	6058 432211	SERGEY MATVEEV	{"phone": "+70115433646"}
0005433785879	AA424F	8960 512896	VASILIY DENISOV	{"email": "v_denisov_031963@postgrespro.ru", "phone": "+70376548230"}
0005433785880	AA424F	4773 324266	MAKSIM STEPANOV	{"phone": "+70149354818"}
0005433785881	14477C	3338 627510	DANIIL SCHERBAKOV	{"phone": "+70197712755"}
0005433785882	AF66DF	1992 108640	ANATOLIY NIKITIN	{"email": "nikitin.anatoliy-17051980@postgrespro.ru", "phone": "+70710401441"}
0005433785883	8027FA	1104 555465	ANTONINA EFREMOVA	{"email": "efremovaantonina-20061969@postgrespro.ru", "phone": "+70491325667"}
0005433785884	DD5307	1405 836501	NINA ANISIMOVA	{"email": "anisimova.nina-30111970@postgrespro.ru", "phone": "+70631839722"}
0005433785885	A5B711	5842 904248	ANASTASIYA ERMAKOVA	{"email": "anastasiya-ermakova.011956@postgrespro.ru", "phone": "+70575061210"}
0005433785887	7912B3	1418 919417	MARGARITA ALEKSEEVA	{"email": "m.alekseeva-051971@postgrespro.ru", "phone": "+70474989630"}
0005433785888	7912B3	5336 996822	ANDREY KULIKOV	{"email": "andrey.kulikov.07021970@postgrespro.ru", "phone": "+70964009531"}
0005433785889	CAF5E9	8489 607968	GALINA POPOVA	{"phone": "+70717557218"}
0005433785890	0F20A1	0050 490213	VLADIMIR EGOROV	{"email": "egorov-v-1978@postgrespro.ru", "phone": "+70900079720"}
0005433785891	B30034	4078 637283	ALEVTINA KUZNECOVA	{"phone": "+70420730517"}
0005433785892	85C760	9673 050412	EVGENIYA KUZNECOVA	{"email": "e-kuznecova1966@postgrespro.ru", "phone": "+70365328375"}
0005433785893	85C760	7011 684880	ALEKSANDR KUZNECOV	{"phone": "+70362902018"}
0005433785894	85C760	0956 561627	SOFIYA MOROZOVA	{"email": "morozovasofiya-1972@postgrespro.ru", "phone": "+70113986420"}
0005433785895	440794	6510 302786	ALEKSEY NOVIKOV	{"email": "novikov-aleksey.09011968@postgrespro.ru", "phone": "+70395798477"}
0005433785896	CA8C39	4199 303900	LYUDMILA KONDRATEVA	{"phone": "+70206755546"}
0005433785897	CA8C39	2097 721919	ALENA NAZAROVA	{"phone": "+70160903863"}
0005433785898	E56563	2852 811073	VASILIY IVANOV	{"phone": "+70450302863"}
0005433785899	E56563	7863 624062	VASILIY CHERNOV	{"email": "chernovv-14091974@postgrespro.ru", "phone": "+70386864610"}
0005433785900	E56563	7852 298887	LYUDMILA KAZAKOVA	{"email": "lyudmila_kazakova051975@postgrespro.ru", "phone": "+70513350764"}
0005433785901	D960E5	2474 108631	VIKTOR SERGEEV	{"phone": "+70328831709"}
0005433785902	D0046D	4678 271205	VALENTINA VOLKOVA	{"email": "v.volkova_03111973@postgrespro.ru", "phone": "+70230886082"}
0005433785903	D0046D	7728 243907	ILYA CHERNOV	{"email": "chernov_i021970@postgrespro.ru", "phone": "+70409842509"}
0005433785904	CAAAB8	3615 173297	VLADISLAV GUSEV	{"email": "v_gusev.17051967@postgrespro.ru", "phone": "+70704100710"}
0005433785905	9942F4	0361 197996	DMITRIY EGOROV	{"email": "dmitriy-egorov1981@postgrespro.ru", "phone": "+70713993026"}
0005433785906	D4F25D	0840 694093	VALENTIN POPOV	{"phone": "+70014690692"}
0005433785907	D4F25D	0983 696693	OLGA KUZMINA	{"phone": "+70960042559"}
0005433785908	D4F25D	1738 077588	ELENA ALEKSEEVA	{"email": "elena.alekseeva1980@postgrespro.ru", "phone": "+70765292481"}
0005433785909	58E6D7	0764 382986	LYUCIYA POPOVA	{"email": "l.popova-111975@postgrespro.ru", "phone": "+70951438622"}
0005433785910	58E6D7	0499 059080	EKATERINA NIKIFOROVA	{"phone": "+70844179165"}
0005433785911	52B368	2737 262604	ALEKSANDR SAVELEV	{"email": "a_savelev.081973@postgrespro.ru", "phone": "+70871226923"}
0005433785912	52B368	3611 693156	KSENIYA PAVLOVA	{"email": "kseniya_pavlova_1966@postgrespro.ru", "phone": "+70654223455"}
0005433785913	EA17F2	2850 939738	SERGEY FEDOTOV	{"email": "sergey.fedotov121972@postgrespro.ru", "phone": "+70810834439"}
0005433785914	1B4253	2517 324175	DENIS MELNIKOV	{"phone": "+70585294912"}
0005433785915	F6B1A7	5509 366314	GALINA MOROZOVA	{"email": "g_morozova-23051977@postgrespro.ru", "phone": "+70286336018"}
0005433785916	3CA9B9	7539 529550	MADINA MIKHAYLOVA	{"phone": "+70648500700"}
0005433785917	E4F81F	4744 970772	YURIY DENISOV	{"phone": "+70499465970"}
0005433785918	069E27	1299 922781	VALENTINA NOVIKOVA	{"phone": "+70112499455"}
0005433785919	68C178	1470 590149	KRISTINA ORLOVA	{"email": "k-orlova021966@postgrespro.ru", "phone": "+70837791757"}
0005433785920	9103E7	6134 990660	MARINA KOROLEVA	{"phone": "+70795370130"}
0005433785921	9103E7	3053 547444	MAKSIM FEDOTOV	{"phone": "+70350922619"}
0005433785922	B8BC77	7905 737087	VALENTINA IVANOVA	{"phone": "+70310039914"}
0005433785923	031803	1169 753220	NIKOLAY ZHURAVLEV	{"phone": "+70452575279"}
0005433785924	B3C45A	2005 176326	ARTEM STEPANOV	{"phone": "+70945464666"}
0005433785925	301674	2401 797729	ANDREY SOROKIN	{"phone": "+70903486229"}
0005433785926	301674	9837 004379	VLADIMIR VOLKOV	{"phone": "+70882082145"}
0005433785927	0CBDB0	0095 114618	MARINA DMITRIEVA	{"email": "dmitrieva-marina.081970@postgrespro.ru", "phone": "+70912753748"}
0005433785928	0CBDB0	8390 800796	VALERIY SEMENOV	{"email": "valeriy-semenov-16031975@postgrespro.ru", "phone": "+70032116023"}
0005433785929	897119	1210 716529	ANATOLIY YAKOVLEV	{"email": "a.yakovlev-121980@postgrespro.ru", "phone": "+70075457227"}
0005433785930	897119	5122 582423	NATALIYA EGOROVA	{"email": "nataliya.egorova_1967@postgrespro.ru", "phone": "+70417228703"}
0005433785931	210C5C	4301 959064	TAMARA MAKAROVA	{"email": "makarovatamara-1970@postgrespro.ru", "phone": "+70833551020"}
0005433785932	0D42F9	6071 065473	ZINAIDA ERMAKOVA	{"phone": "+70796803023"}
0005433785933	0D42F9	2842 386315	NADEZHDA EFREMOVA	{"email": "efremovan021981@postgrespro.ru", "phone": "+70508465152"}
0005433785934	C7AF50	4176 427643	VERA SEMENOVA	{"phone": "+70356452602"}
0005433785935	6968B7	6476 383413	ALISA VLASOVA	{"email": "vlasova-a-021979@postgrespro.ru", "phone": "+70373716870"}
0005433785936	A6AA18	9299 381036	TATYANA VLASOVA	{"email": "vlasova.tatyana_04101965@postgrespro.ru", "phone": "+70939576848"}
0005433785937	D7A456	0154 321247	VIKTORIYA MIKHAYLOVA	{"phone": "+70675898782"}
0005433785938	E1452F	1555 734544	VIKTOR AFANASEV	{"email": "viktorafanasev_081983@postgrespro.ru", "phone": "+70777885876"}
0005433785939	B02FFE	5004 416390	ILYA ZAKHAROV	{"phone": "+70828426200"}
0005433785940	B02FFE	3783 942204	VLADIMIR GAVRILOV	{"email": "v-gavrilov_1962@postgrespro.ru", "phone": "+70147171905"}
0005433785941	2802EB	0031 960397	ELIZAVETA MELNIKOVA	{"phone": "+70347794988"}
0005433785942	6A3D19	9513 841219	IRINA TIMOFEEVA	{"phone": "+70593548730"}
0005433785943	6A3D19	5682 612091	ELENA NIKOLAEVA	{"phone": "+70158870831"}
0005433785944	C4089B	3646 541960	IVAN OSIPOV	{"phone": "+70564232823"}
0005433785945	8EC0A9	3968 687075	MAKSIM SOLOVEV	{"phone": "+70739478612"}
0005433785946	525F5F	1261 393131	MARINA SOLOVEVA	{"phone": "+70824919434"}
0005433785947	50C191	0935 932237	ANNA STEPANOVA	{"phone": "+70560831398"}
0005433785948	50C191	3865 426808	ALEKSANDR DENISOV	{"phone": "+70026662169"}
0005433785949	88DE1F	1462 074098	ROMAN BORISOV	{"email": "borisov-roman-121967@postgrespro.ru", "phone": "+70940091444"}
0005433785950	2051CB	9972 025251	ANASTASIYA PETROVA	{"phone": "+70037629981"}
0005433785951	2051CB	8028 421826	OLGA DAVYDOVA	{"phone": "+70719981038"}
0005433785952	5B6AC6	2533 246226	MARIYA MAKSIMOVA	{"email": "mmaksimova.1961@postgrespro.ru", "phone": "+70598537595"}
0005433785953	D9F92B	1121 801204	ANTON SCHERBAKOV	{"phone": "+70445950297"}
0005433785954	D9F92B	3057 789563	ANASTASIYA KUZNECOVA	{"phone": "+70598543283"}
0005433785955	476EEE	1985 827413	IDA FEDOROVA	{"email": "i.fedorova_111973@postgrespro.ru", "phone": "+70575853214"}
0005433785956	F9A104	6885 576566	VLADIMIR MATVEEV	{"phone": "+70163749256"}
0005433785957	05FB31	3475 395723	ALEKSANDR IVANOV	{"email": "ivanov-a-051968@postgrespro.ru", "phone": "+70086799695"}
0005433785958	D279F6	8442 283707	IRINA NIKITINA	{"phone": "+70908386116"}
0005433785959	047942	7663 762110	MARIYA NIKITINA	{"phone": "+70085595150"}
0005433785960	047942	7300 020985	SEMEN KUZNECOV	{"phone": "+70564191106"}
0005433785961	41F937	3415 740055	LYUBOV MASLOVA	{"email": "maslovalyubov1982@postgrespro.ru", "phone": "+70211973586"}
0005433785962	41F937	1444 894478	NIKOLAY NAUMOV	{"email": "n-naumov1973@postgrespro.ru", "phone": "+70185642950"}
0005433785963	41F937	0335 025352	VADIM ZAKHAROV	{"phone": "+70683403984"}
0005433785964	EE1C9D	3478 682399	SERGEY SOROKIN	{"email": "sorokins_22081962@postgrespro.ru", "phone": "+70946382688"}
0005433785965	EE1C9D	8794 316689	LYUDMILA KULIKOVA	{"phone": "+70693033886"}
0005433785966	9A4E49	4485 824097	VLADIMIR FEDOTOV	{"phone": "+70854008207"}
0005433785967	0BCADD	1542 074386	ANTONINA SERGEEVA	{"phone": "+70311053352"}
0005433785968	B43FBC	2957 896546	ALINA IVANOVA	{"email": "ivanova_alina091978@postgrespro.ru", "phone": "+70460133875"}
0005433785969	C1137A	0196 566966	POLINA FROLOVA	{"email": "frolovap111963@postgrespro.ru", "phone": "+70110493120"}
0005433785970	379CAB	5138 441987	ALENA BORISOVA	{"email": "aborisova1974@postgrespro.ru", "phone": "+70715207878"}
0005433785971	9E2D93	7263 265404	DMITRIY KOROLEV	{"email": "korolev_d_1961@postgrespro.ru", "phone": "+70996504764"}
0005433785972	9E2D93	5591 915002	IVAN SOLOVEV	{"phone": "+70401307346"}
0005433785973	E98A70	8433 236066	ANNA SEMENOVA	{"email": "anna-semenova.031965@postgrespro.ru", "phone": "+70294248322"}
0005433785974	6861A9	3188 757652	VLADIMIR POPOV	{"phone": "+70715536838"}
0005433785975	74DF55	2082 764704	VSEVOLOD KUZMIN	{"email": "v_kuzmin-1979@postgrespro.ru", "phone": "+70965151631"}
0005433785976	74DF55	6081 584172	NATALYA GORBUNOVA	{"phone": "+70679051786"}
0005433785977	F8B8F2	3779 053373	OLGA ARKHIPOVA	{"phone": "+70182776671"}
0005433785978	F8B8F2	3926 665446	PAVEL KOZLOV	{"phone": "+70629121923"}
0005433785979	E0165B	5382 908807	GALINA ERMAKOVA	{"email": "ermakova-g06061973@postgrespro.ru", "phone": "+70602858486"}
0005433785980	D5483F	3813 610068	NATALYA ANDREEVA	{"email": "andreeva_natalya1964@postgrespro.ru", "phone": "+70695560188"}
0005433785981	F9790A	7998 204823	OLGA ANISIMOVA	{"phone": "+70568002322"}
0005433785982	F9790A	2891 874742	IGOR POPOV	{"phone": "+70268786394"}
0005433785983	00E743	9196 390454	IGOR MAKSIMOV	{"phone": "+70070113927"}
0005433785984	F26F2C	9425 801773	VLADIMIR SHEVCHENKO	{"phone": "+70003314349"}
0005433785985	F26F2C	5542 881984	NIKOLAY SMIRNOV	{"phone": "+70599220598"}
0005433785986	63E8C5	5501 094343	ANTON ALEKSEEV	{"email": "alekseev-a.08011974@postgrespro.ru", "phone": "+70172352447"}
0005433785987	63E8C5	9198 993616	VSEVOLOD SERGEEV	{"email": "sergeev-vsevolod-23021981@postgrespro.ru", "phone": "+70301130955"}
0005433785988	697A24	9275 775181	VALERIY KUZMIN	{"email": "kuzmin-valeriy1985@postgrespro.ru", "phone": "+70225465346"}
0005433785989	B9B049	7064 652766	ANNA SOROKINA	{"phone": "+70738330783"}
0005433785990	A71FD2	9293 567929	ELIZAVETA KULIKOVA	{"email": "e_kulikova.071969@postgrespro.ru", "phone": "+70886588662"}
0005433785991	A71FD2	1642 773699	ANNA SOROKINA	{"email": "sorokina.anna-081976@postgrespro.ru", "phone": "+70602814490"}
0005433785992	A71FD2	7695 734941	ELENA POTAPOVA	{"phone": "+70807604307"}
0005433785993	A71FD2	0081 895843	YULIYA PETROVA	{"phone": "+70685955307"}
0005433785994	5E24FA	7837 851225	VALENTINA ISAEVA	{"phone": "+70215234430"}
0005433785995	5E24FA	8913 284559	REGINA GRISHINA	{"phone": "+70958089029"}
0005433785996	39FE3D	9912 706922	PETR ORLOV	{"phone": "+70581618635"}
0005433785997	A9E6F5	1766 040229	VLADIMIR ILIN	{"email": "ilin.v.25081965@postgrespro.ru", "phone": "+70055554040"}
0005433785998	A9E6F5	3360 412894	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.021960@postgrespro.ru", "phone": "+70421450325"}
0005433785999	947368	2445 317225	VLADIMIR KUZMIN	{"email": "kuzmin_v30031976@postgrespro.ru", "phone": "+70148058030"}
0005433786000	A3BB91	6403 411891	GALINA MIRONOVA	{"email": "mironova-galina.071971@postgrespro.ru", "phone": "+70070669232"}
0005433786001	A3BB91	1825 117227	TATYANA KONOVALOVA	{"email": "konovalova-t1971@postgrespro.ru", "phone": "+70871323382"}
0005433786002	08A968	3743 186447	ELENA MATVEEVA	{"phone": "+70549821534"}
0005433786003	911984	1486 687172	MARINA NAZAROVA	{"email": "nazarova_m.061969@postgrespro.ru", "phone": "+70505056577"}
0005433786004	84A2C8	2469 040983	OLEG ROMANOV	{"email": "romanovo-28081970@postgrespro.ru", "phone": "+70991002835"}
0005433786005	FD3930	6176 572712	DMITRIY ZHUKOV	{"phone": "+70421237881"}
0005433786006	FD3930	5424 585349	VALENTINA SEMENOVA	{"phone": "+70048241731"}
0005433786007	BA40A1	8525 977146	VASILIY KUZNECOV	{"email": "v-kuznecov-1981@postgrespro.ru", "phone": "+70202594956"}
0005433786008	BA40A1	2249 777027	ILYA CHERNOV	{"phone": "+70975680667"}
0005433786009	AD9CF1	8113 393267	VIKTORIYA MAKSIMOVA	{"email": "v_maksimova_1977@postgrespro.ru", "phone": "+70774772114"}
0005433786010	AD9CF1	3357 623428	ELENA IVANOVA	{"email": "ivanova-e.29081971@postgrespro.ru", "phone": "+70752984870"}
0005433786011	1DF62B	6480 535645	ALEKSANDR MOISEEV	{"phone": "+70526793972"}
0005433786012	1DF62B	3960 796654	IRINA AKIMOVA	{"email": "akimova_irina_031980@postgrespro.ru", "phone": "+70464226846"}
0005433786013	C754BE	7802 225767	TIMOFEY ZAKHAROV	{"email": "t.zakharov.22091957@postgrespro.ru", "phone": "+70178265092"}
0005433786014	0866AC	4745 236967	VLADISLAV SMIRNOV	{"email": "vsmirnov.031971@postgrespro.ru", "phone": "+70195694275"}
0005433786015	0866AC	3565 209104	ANDREY ZAYCEV	{"email": "zaycev_a_101974@postgrespro.ru", "phone": "+70427432775"}
0005433786016	A23DE2	1348 881334	PAVEL POPOV	{"email": "popov-pavel111960@postgrespro.ru", "phone": "+70427651394"}
0005433786017	58966B	6744 801559	NIKOLAY IVANOV	{"phone": "+70136314597"}
0005433786018	366863	1002 018036	TATYANA NIKOLAEVA	{"phone": "+70128041127"}
0005433786019	366863	0673 754086	SVETLANA KOLESNIKOVA	{"email": "kolesnikova-svetlana12031958@postgrespro.ru", "phone": "+70403103962"}
0005433786020	ED46C8	6172 854644	DMITRIY ANTONOV	{"email": "dantonov011979@postgrespro.ru", "phone": "+70449073261"}
0005433786021	ED46C8	4206 378278	TATYANA POTAPOVA	{"email": "potapova-t.22011969@postgrespro.ru", "phone": "+70313983412"}
0005433786022	7E9485	2964 082204	KLAVDIYA GUSEVA	{"email": "guseva.k-011970@postgrespro.ru", "phone": "+70465698438"}
0005433786023	7E9485	1041 960064	ANNA BORISOVA	{"email": "anna_borisova_1966@postgrespro.ru", "phone": "+70538488752"}
0005433786024	BA1C5C	9417 012165	GALINA KISELEVA	{"phone": "+70711036067"}
0005433786025	BA1C5C	7025 160477	VLADIMIR IVANOV	{"email": "ivanov_v111982@postgrespro.ru", "phone": "+70731577225"}
0005433786026	CF3F4F	0947 323074	TATYANA PAVLOVA	{"phone": "+70995330896"}
0005433788143	6887E8	9633 053014	MIKHAIL ANTONOV	{"phone": "+70279158113"}
0005433786027	CF3F4F	2203 156159	ANASTASIYA RYABOVA	{"email": "a.ryabova-18021973@postgrespro.ru", "phone": "+70467745805"}
0005433786028	0DEE93	6041 835385	ALEKSANDR ZAKHAROV	{"email": "a.zakharov-1985@postgrespro.ru", "phone": "+70407096376"}
0005433786029	D28461	1997 465031	GALINA GORBUNOVA	{"email": "gorbunova_galina.1965@postgrespro.ru", "phone": "+70240902465"}
0005433786030	D28461	4788 353081	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr.1970@postgrespro.ru", "phone": "+70743377259"}
0005433786031	B1DF30	3827 000439	LYUBOV ORLOVA	{"email": "orlova.l-19111967@postgrespro.ru", "phone": "+70805981316"}
0005433786032	B1DF30	2127 257175	OKSANA VASILEVA	{"phone": "+70779936894"}
0005433786033	8E93D1	3579 889484	YULIYA ROMANOVA	{"email": "romanova_yuliya_081976@postgrespro.ru", "phone": "+70515505462"}
0005433786034	57E187	3704 618158	VERA GORBUNOVA	{"phone": "+70606362642"}
0005433786035	57E187	0385 376799	MIKHAIL STEPANOV	{"email": "stepanovmikhail_17111965@postgrespro.ru", "phone": "+70228442231"}
0005433786036	186FC4	4367 591953	EVGENIYA VOLKOVA	{"phone": "+70167569571"}
0005433786037	186FC4	9364 869300	ANDREY CHERNOV	{"email": "chernov_andrey1976@postgrespro.ru", "phone": "+70214542494"}
0005433786038	3ECB2B	6824 247947	ALEKSEY SOKOLOV	{"email": "a_sokolov.22071958@postgrespro.ru", "phone": "+70471940302"}
0005433786039	3ECB2B	2338 193963	ALEKSANDR KOZLOV	{"email": "kozlov-a1973@postgrespro.ru", "phone": "+70251825659"}
0005433786040	747614	1252 905877	TIMUR MATVEEV	{"phone": "+70407387947"}
0005433786041	923864	1193 516497	OKSANA MAKAROVA	{"email": "makarova-o.081971@postgrespro.ru", "phone": "+70324226602"}
0005433786042	923864	3487 520201	LYUBOV NAZAROVA	{"email": "nazaroval-25061961@postgrespro.ru", "phone": "+70551738344"}
0005433786043	923864	5880 941120	IGOR ISAEV	{"email": "igor_isaev01051973@postgrespro.ru", "phone": "+70826398710"}
0005433786044	BD3C1C	4775 301244	VALERIY KUZNECOV	{"phone": "+70077320217"}
0005433786045	BB0E3C	8376 001728	VITALIY SIDOROV	{"email": "v_sidorov02081973@postgrespro.ru", "phone": "+70831686050"}
0005433786046	BB0E3C	8122 580390	OLGA TIKHONOVA	{"email": "tikhonovaolga.10071969@postgrespro.ru", "phone": "+70687202640"}
0005433786047	BB0E3C	0499 580819	YAROSLAVA MAKAROVA	{"email": "yaroslavamakarova11051967@postgrespro.ru", "phone": "+70748419922"}
0005433786048	99C7B6	4961 559866	VALERIY POPOV	{"phone": "+70451960580"}
0005433786049	13350D	0709 337546	OLGA AFANASEVA	{"phone": "+70497431016"}
0005433786050	0BCEAB	7004 678780	ALEKSEY FEDOROV	{"phone": "+70804022505"}
0005433786051	0BCEAB	4310 921259	SERGEY MAKAROV	{"phone": "+70953472662"}
0005433786052	093106	7387 000678	IGOR IVANOV	{"email": "igor-ivanov1963@postgrespro.ru", "phone": "+70928119613"}
0005433786053	093106	2642 900147	NIKOLAY VASILEV	{"email": "nvasilev-15061970@postgrespro.ru", "phone": "+70145813589"}
0005433786054	9E7475	5213 645445	SERGEY MOROZOV	{"phone": "+70908085693"}
0005433786055	B49E23	7132 589022	FATIMA DENISOVA	{"email": "denisova_f_1985@postgrespro.ru", "phone": "+70829471610"}
0005433786056	59C83F	9219 173572	YULIYA NAZAROVA	{"phone": "+70266636151"}
0005433786057	59C83F	9029 621978	ALENA FROLOVA	{"email": "frolova.alena-05041980@postgrespro.ru", "phone": "+70168236035"}
0005433786058	D28884	5108 880070	EVGENIY NOVIKOV	{"phone": "+70391471007"}
0005433786059	48B064	3964 090946	TATYANA GAVRILOVA	{"phone": "+70735931138"}
0005433786060	48B064	3194 167115	ILYAS MAKAROV	{"email": "makarov.ilyas051980@postgrespro.ru", "phone": "+70394707229"}
0005433786061	48B064	5367 951193	ANASTASIYA GUSEVA	{"email": "anastasiyaguseva1969@postgrespro.ru", "phone": "+70754501877"}
0005433786062	48B064	8674 225899	LIDIYA KULIKOVA	{"email": "kulikova_l-091978@postgrespro.ru", "phone": "+70907150420"}
0005433786063	312EEE	6081 144880	SVETLANA GRISHINA	{"email": "grishina.svetlana1971@postgrespro.ru", "phone": "+70604612934"}
0005433786064	68543A	8114 882964	ALEKSANDR ORLOV	{"phone": "+70018254144"}
0005433786065	710B18	9755 545943	VALENTIN GRIGOREV	{"phone": "+70335960672"}
0005433786066	710B18	2968 280998	VLADIMIR MAKSIMOV	{"phone": "+70177616254"}
0005433786067	6167DB	9109 470521	ANTON BARANOV	{"email": "baranova1963@postgrespro.ru", "phone": "+70651784308"}
0005433786068	6167DB	5198 925066	ELIZAVETA VOLKOVA	{"phone": "+70629370975"}
0005433786069	A71390	9288 647731	ALEVTINA ANDREEVA	{"email": "andreeva_alevtina23081969@postgrespro.ru", "phone": "+70566310223"}
0005433786070	10EA89	9242 513308	RAISA MEDVEDEVA	{"phone": "+70040658007"}
0005433786071	A1CE5E	2863 685078	ANTONINA ARKHIPOVA	{"phone": "+70285039434"}
0005433786072	A1CE5E	4536 254033	TATYANA MAKAROVA	{"phone": "+70490883760"}
0005433786073	363C00	6445 679800	POLINA KOVALEVA	{"email": "p.kovaleva-16041976@postgrespro.ru", "phone": "+70440705688"}
0005433786074	5D8AE1	1681 971727	EDUARD FOMIN	{"email": "e-fomin.1977@postgrespro.ru", "phone": "+70072748981"}
0005433786075	5D8AE1	5975 265883	MARIYA NAZAROVA	{"phone": "+70620189125"}
0005433786076	A5EEFE	0330 527599	VALERIY POPOV	{"phone": "+70698656371"}
0005433786077	A5EEFE	1584 401657	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr20041962@postgrespro.ru", "phone": "+70000027751"}
0005433786078	5FAC7E	4004 727089	VIKTOR TIMOFEEV	{"email": "viktortimofeev1977@postgrespro.ru", "phone": "+70820521713"}
0005433786079	5FAC7E	3988 171863	NINA GUSEVA	{"email": "ninaguseva-19081978@postgrespro.ru", "phone": "+70014598042"}
0005433786080	83DC8D	7342 875295	PELAGEYA NIKITINA	{"phone": "+70478740832"}
0005433786081	91C4FD	7603 710156	VALENTINA SAVELEVA	{"email": "valentina.saveleva_08011983@postgrespro.ru", "phone": "+70346445063"}
0005433786082	3275BB	4888 407162	VALERIY NAZAROV	{"phone": "+70728239357"}
0005433786083	4443C7	3882 660216	TATYANA NOVIKOVA	{"phone": "+70313254251"}
0005433786084	4443C7	1322 996191	ALINA CHERNOVA	{"email": "chernovaa_1967@postgrespro.ru", "phone": "+70106981130"}
0005433786085	A510DD	1053 282718	VITALIY IVANOV	{"email": "vitaliy-ivanov_11081974@postgrespro.ru", "phone": "+70105948177"}
0005433786086	4A5BD3	9858 388135	ALEKSANDR GORBUNOV	{"email": "a.gorbunov.081981@postgrespro.ru", "phone": "+70250292819"}
0005433786087	4A5BD3	8151 536113	NELLI BELOVA	{"email": "nbelova.28081978@postgrespro.ru", "phone": "+70971361578"}
0005433786088	99F69A	9947 955111	IVAN NIKITIN	{"email": "ivan.nikitin.27051973@postgrespro.ru", "phone": "+70924126340"}
0005433786089	99F69A	4167 968404	MIKHAIL GUSEV	{"phone": "+70154381315"}
0005433786090	7F0521	8370 010658	LYUBOV TIKHONOVA	{"phone": "+70402668866"}
0005433786091	7F0521	8613 931862	NATALYA NIKITINA	{"email": "nikitina_natalya_1973@postgrespro.ru", "phone": "+70736983753"}
0005433786092	44AA55	3638 109532	NIKOLAY ORLOV	{"email": "orlov_n27091968@postgrespro.ru", "phone": "+70050449691"}
0005433786093	44AA55	3294 069404	MARK FROLOV	{"phone": "+70207613283"}
0005433786094	CACF41	3809 626317	LYUBOV CHERNOVA	{"email": "chernoval.13051985@postgrespro.ru", "phone": "+70950202545"}
0005433786095	B0A2B3	0833 359486	NATALYA DANILOVA	{"email": "natalya_danilova.061978@postgrespro.ru", "phone": "+70826802830"}
0005433786096	ED8780	5146 770851	ANATOLIY SOKOLOV	{"email": "sokolov.anatoliy_1963@postgrespro.ru", "phone": "+70383591809"}
0005433786097	F79FCA	9548 220106	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr15121983@postgrespro.ru", "phone": "+70519995247"}
0005433786098	B8F1B7	1375 601562	ANASTASIYA KISELEVA	{"phone": "+70619168488"}
0005433786099	2CD895	4948 863247	NINA FROLOVA	{"phone": "+70031575931"}
0005433786100	2CD895	7265 134513	VLADIMIR SERGEEV	{"phone": "+70285448966"}
0005433786101	3A25D6	6090 873799	ARTUR NAUMOV	{"email": "artur.naumov.26041973@postgrespro.ru", "phone": "+70772074028"}
0005433786102	7D46E3	6902 531733	VALENTINA NAUMOVA	{"phone": "+70800279872"}
0005433786103	34B32E	5122 170380	ALEKSANDR KRASNOV	{"phone": "+70567696915"}
0005433786104	4E454A	7595 196545	PETR BORISOV	{"phone": "+70423662222"}
0005433786105	4E454A	1140 844656	EVGENIYA FADEEVA	{"email": "efadeeva.26031973@postgrespro.ru", "phone": "+70159956823"}
0005433786106	492DEA	6111 918590	ANDREY SERGEEV	{"phone": "+70396812842"}
0005433786107	8319E1	8847 862863	SANIYA DENISOVA	{"email": "denisovasaniya_021981@postgrespro.ru", "phone": "+70859800271"}
0005433786108	9B40D9	7571 907487	DANIIL SHEVCHENKO	{"phone": "+70987841295"}
0005433786109	ABDA8A	6791 539840	RUSTAM EGOROV	{"email": "r-egorov.031964@postgrespro.ru", "phone": "+70670326174"}
0005433786110	270A77	8723 693982	ANNA VLASOVA	{"email": "avlasova021973@postgrespro.ru", "phone": "+70100421199"}
0005433786111	270A77	5897 088935	DMITRIY MOISEEV	{"email": "dmoiseev.031969@postgrespro.ru", "phone": "+70883166804"}
0005433786112	4C7959	9773 315361	GRIGORIY IVANOV	{"email": "g_ivanov.07071967@postgrespro.ru", "phone": "+70632270047"}
0005433786113	0335D2	3814 669674	KLAVDIYA ORLOVA	{"phone": "+70707183896"}
0005433786114	0335D2	2561 204593	LYUBOV BOGDANOVA	{"email": "bogdanova.lyubov06031971@postgrespro.ru", "phone": "+70264006420"}
0005433786115	BE032C	9053 193226	LYUDMILA ANTONOVA	{"email": "l_antonova-101975@postgrespro.ru", "phone": "+70806502816"}
0005433786116	A645C4	1803 362892	VLADIMIR KOZLOV	{"email": "vladimirkozlov-1963@postgrespro.ru", "phone": "+70100600525"}
0005433786117	A645C4	4603 119756	IGOR PAVLOV	{"phone": "+70211192682"}
0005433786118	C5D144	3159 711753	VALENTINA PETROVA	{"phone": "+70770991744"}
0005433786119	C5D144	5737 550258	VLADIMIR KULIKOV	{"phone": "+70315297861"}
0005433786120	8991ED	0599 897219	LYAYSAN NIKOLAEVA	{"email": "nikolaeva.l.1972@postgrespro.ru", "phone": "+70573177872"}
0005433786121	C5E608	9598 420885	OLGA MOROZOVA	{"email": "morozova-o_1977@postgrespro.ru", "phone": "+70480126264"}
0005433786122	8F311E	0621 523825	TALGAT NIKOLAEV	{"phone": "+70465866216"}
0005433786123	AC8E68	0047 594031	ELENA LEBEDEVA	{"phone": "+70389024057"}
0005433786124	AC8E68	2294 820072	ALEKSEY SOKOLOV	{"phone": "+70519859760"}
0005433786125	AC8E68	9609 384719	PETR DAVYDOV	{"email": "pdavydov_041964@postgrespro.ru", "phone": "+70326194252"}
0005433786126	AC8E68	7809 245347	ALEKSEY MOROZOV	{"email": "a_morozov1967@postgrespro.ru", "phone": "+70494311558"}
0005433786127	6A594F	7943 286346	EVGENIY MATVEEV	{"phone": "+70328634800"}
0005433786128	928A61	7651 270188	INNA EFIMOVA	{"phone": "+70568499976"}
0005433786129	C35974	8360 941748	OLEG ILIN	{"email": "ilin.oleg23021970@postgrespro.ru", "phone": "+70354578153"}
0005433786130	C35974	1636 689669	EDUARD SEMENOV	{"phone": "+70232947881"}
0005433786131	738E3D	5761 172848	ROZALIYA NAZAROVA	{"email": "nazarova-r-17051972@postgrespro.ru", "phone": "+70572059539"}
0005433786132	738E3D	4517 087998	YULIYA NOVIKOVA	{"phone": "+70582050180"}
0005433786133	738E3D	2680 181760	VALERIY NAUMOV	{"email": "valeriynaumov-03061975@postgrespro.ru", "phone": "+70956223739"}
0005433786134	0AC076	6116 301976	YULIYA TITOVA	{"email": "titovay_051967@postgrespro.ru", "phone": "+70937942949"}
0005433786135	2FD2CC	9047 578517	LARISA MEDVEDEVA	{"phone": "+70311829749"}
0005433786136	72B383	0147 521902	YULIYA MOROZOVA	{"email": "yuliyamorozova_04041971@postgrespro.ru", "phone": "+70057527009"}
0005433786137	BC9663	3645 757127	DMITRIY VLASOV	{"email": "d.vlasov.11091961@postgrespro.ru", "phone": "+70479165949"}
0005433786138	F439B9	6170 454533	ALEKSANDR ORLOV	{"email": "aleksandr-orlov121960@postgrespro.ru", "phone": "+70329325540"}
0005433786139	F439B9	2863 245055	INNA NAZAROVA	{"email": "inna.nazarova.19031968@postgrespro.ru", "phone": "+70014494899"}
0005433786140	5A33DD	6445 570307	VIKTOR SOLOVEV	{"phone": "+70738779553"}
0005433786141	EA23B2	1717 837814	KSENIYA TIMOFEEVA	{"phone": "+70387122924"}
0005433786142	7AD58D	8596 918584	ALEKSEY PAVLOV	{"email": "pavlov_aleksey_1963@postgrespro.ru", "phone": "+70847323312"}
0005433786143	B79A71	2824 627671	VLADIMIR PETROV	{"email": "petrov_v_051987@postgrespro.ru", "phone": "+70919016491"}
0005433786144	A31D0F	4116 513288	EKATERINA MIRONOVA	{"email": "mironova-e_02061981@postgrespro.ru", "phone": "+70123400592"}
0005433786145	C79732	2497 057322	NADEZHDA NOVIKOVA	{"email": "nadezhda_novikova-16051972@postgrespro.ru", "phone": "+70987057772"}
0005433786146	2EC17A	9363 062283	OLGA SOROKINA	{"phone": "+70659923849"}
0005433786147	00314B	1142 561029	MARIYA TIKHONOVA	{"email": "tikhonova_m.1973@postgrespro.ru", "phone": "+70471045228"}
0005433786148	00314B	4273 812130	OLGA MATVEEVA	{"email": "matveeva_o091970@postgrespro.ru", "phone": "+70653210530"}
0005433786149	C40A3C	8733 804347	LYUBOV MATVEEVA	{"phone": "+70274798625"}
0005433786150	8C22CF	9384 376126	TAISA AKIMOVA	{"email": "akimovataisa.091976@postgrespro.ru", "phone": "+70061704474"}
0005433786151	8C22CF	1572 555814	DMITRIY ILIN	{"email": "ilin_dmitriy_021976@postgrespro.ru", "phone": "+70385830325"}
0005433786152	845D03	9524 710741	SERGEY KOZLOV	{"email": "kozlov-sergey1966@postgrespro.ru", "phone": "+70779118048"}
0005433786153	845D03	7227 536131	SVETLANA LUKYANOVA	{"phone": "+70370896824"}
0005433786154	DCA9AE	1100 789039	YANA SAVELEVA	{"email": "saveleva-y031973@postgrespro.ru", "phone": "+70117446298"}
0005433786155	9A7DFF	5516 718514	ELENA NIKIFOROVA	{"phone": "+70668015762"}
0005433786156	9A7DFF	6392 720341	IVAN FROLOV	{"email": "ivan.frolov28061966@postgrespro.ru", "phone": "+70240855658"}
0005433786157	9A7DFF	3627 501478	MIKHAIL MOROZOV	{"phone": "+70694934588"}
0005433786158	880DCD	4217 439409	SERGEY VOROBEV	{"email": "vorobev_s.1964@postgrespro.ru", "phone": "+70455688379"}
0005433786159	880DCD	4159 311807	IRINA KUZMINA	{"phone": "+70813692812"}
0005433786160	9A7F7C	2442 804333	ALEKSANDR ORLOV	{"phone": "+70995322546"}
0005433786161	9EEB65	2325 380537	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr_1968@postgrespro.ru", "phone": "+70352540555"}
0005433786162	3A009F	6087 177528	ANTON GAVRILOV	{"email": "gavrilov-a.24041963@postgrespro.ru", "phone": "+70360763919"}
0005433786163	3A009F	5990 710995	ELENA DANILOVA	{"email": "danilova.e-1953@postgrespro.ru", "phone": "+70581575695"}
0005433786164	BA1B27	2538 488550	DMITRIY VOLKOV	{"email": "dmitriy.volkov1975@postgrespro.ru", "phone": "+70547981835"}
0005433786165	9C3B9E	0444 276829	DANILA VASILEV	{"email": "d-vasilev-1967@postgrespro.ru", "phone": "+70530019485"}
0005433786166	9C3B9E	4639 086248	SOFYA STEPANOVA	{"phone": "+70836331433"}
0005433786167	A75D3D	5440 109889	OKSANA VLASOVA	{"email": "vlasovaoksana-1962@postgrespro.ru", "phone": "+70281649032"}
0005433786168	A75D3D	5633 194292	IGOR ZAYCEV	{"phone": "+70085639729"}
0005433786169	05EB41	3687 447095	SVETLANA POTAPOVA	{"email": "potapovasvetlana_1965@postgrespro.ru", "phone": "+70409291139"}
0005433786170	64C176	9806 096769	OLGA LOGINOVA	{"phone": "+70411251654"}
0005433786171	64C176	3985 945069	ALBINA KISELEVA	{"phone": "+70652994313"}
0005433786172	527F44	5310 420695	SERGEY EGOROV	{"phone": "+70085396536"}
0005433786173	527F44	9599 364201	OLGA EGOROVA	{"email": "olgaegorova091960@postgrespro.ru", "phone": "+70382711822"}
0005433786174	11C559	3565 154909	LIDIYA TROFIMOVA	{"phone": "+70238272363"}
0005433786175	11C559	6663 333110	SVETLANA STEPANOVA	{"email": "stepanova.svetlana_1977@postgrespro.ru", "phone": "+70990596891"}
0005433786176	11C559	3152 134165	DANIIL KONOVALOV	{"phone": "+70890192846"}
0005433786177	11C559	7659 116871	IRINA NAZAROVA	{"phone": "+70868321505"}
0005433786178	B344B9	1568 687592	STANISLAV DENISOV	{"phone": "+70495978895"}
0005433786179	348E3D	2170 700522	KSENIYA FADEEVA	{"email": "fadeeva_kseniya-051980@postgrespro.ru", "phone": "+70364921581"}
0005433786180	348E3D	3999 396708	SERGEY KRASNOV	{"phone": "+70954181550"}
0005433786181	47E28A	1518 063687	SERGEY IVANOV	{"phone": "+70981950702"}
0005433786182	0E1806	9722 856439	NINA VASILEVA	{"email": "vasileva_nina_1968@postgrespro.ru", "phone": "+70129357396"}
0005433786183	0E1806	6031 403814	NADEZHDA DENISOVA	{"phone": "+70610271149"}
0005433786184	8879EB	7290 892671	VALENTINA ILINA	{"phone": "+70633740869"}
0005433786185	C19C9D	5788 100556	ANDREY MAKAROV	{"email": "makarov.andrey_1974@postgrespro.ru", "phone": "+70014119141"}
0005433786186	F61F59	7013 002386	DARYA GAVRILOVA	{"email": "d_gavrilova22031973@postgrespro.ru", "phone": "+70938362598"}
0005433786187	C2F68B	4516 995059	EVGENIY SOLOVEV	{"phone": "+70415440286"}
0005433786188	5B87AC	0339 766471	PAVEL KOZLOV	{"phone": "+70443339106"}
0005433786189	8ECE83	4962 428276	NADEZHDA NOVIKOVA	{"phone": "+70903769293"}
0005433786190	F96818	1557 392714	YURIY FEDOROV	{"email": "fedorovyuriy-121960@postgrespro.ru", "phone": "+70115936589"}
0005433786191	248B9E	9534 589347	SVETLANA FILIPPOVA	{"email": "filippova-svetlana-26081972@postgrespro.ru", "phone": "+70160872579"}
0005433786192	CF3E30	4965 828550	ALEKSANDR RODIONOV	{"phone": "+70451060712"}
0005433786193	CF3E30	2161 380332	ANTONINA TARASOVA	{"phone": "+70924745327"}
0005433786194	22FDD3	1884 734311	ANNA SCHERBAKOVA	{"phone": "+70784421416"}
0005433786195	0C4432	1219 158417	MIKHAIL MARTYNOV	{"phone": "+70669053562"}
0005433786196	0C4432	0712 688030	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a051965@postgrespro.ru", "phone": "+70478398902"}
0005433786197	A67F9A	5174 094980	ALEKSANDR NAZAROV	{"email": "anazarov_05101968@postgrespro.ru", "phone": "+70535800027"}
0005433786198	B9AB5A	2455 964804	GALINA TIKHONOVA	{"email": "tikhonova_galina-10061981@postgrespro.ru", "phone": "+70891034325"}
0005433786199	72AC19	4094 290392	TAMARA EGOROVA	{"email": "tamara-egorova_12061977@postgrespro.ru", "phone": "+70778155451"}
0005433786200	56DAAC	7680 619222	SERGEY BORISOV	{"phone": "+70377729737"}
0005433786201	56DAAC	9351 333891	MARINA ZOTOVA	{"phone": "+70016521500"}
0005433788140	5AA922	8156 542471	VIKTOR MAKSIMOV	{"email": "viktor_maksimov-031971@postgrespro.ru", "phone": "+70979451818"}
0005433788141	E037E4	2458 068216	VALENTINA EGOROVA	{"email": "valentina-egorova.28071986@postgrespro.ru", "phone": "+70265295939"}
0005433788142	E037E4	9045 676495	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.101972@postgrespro.ru", "phone": "+70869651738"}
0005433788144	2CF268	0429 540004	ALEKSANDR ALEKSANDROV	{"email": "aleksandrova_1961@postgrespro.ru", "phone": "+70637922769"}
0005433788145	DCB0D4	1034 988485	ELENA SMIRNOVA	{"phone": "+70331426127"}
0005433788146	DCB0D4	4072 423397	YURIY KULIKOV	{"phone": "+70748499412"}
0005433788147	DCB0D4	5214 355840	EVGENIY NIKITIN	{"email": "nikitine-121976@postgrespro.ru", "phone": "+70040786274"}
0005433788148	3C75D6	1481 088391	IVAN PETROV	{"email": "i-petrov.1955@postgrespro.ru", "phone": "+70579472577"}
0005433788149	1DBCDC	9624 438291	GALINA MAKAROVA	{"email": "galina_makarova.02021965@postgrespro.ru", "phone": "+70916788365"}
0005433788150	7F6E6E	7586 230699	KLAVDIYA ORLOVA	{"email": "orlovak_02111978@postgrespro.ru", "phone": "+70395573417"}
0005433788151	7F6E6E	6920 961651	GENNADIY ZAKHAROV	{"phone": "+70162513267"}
0005433788152	D0697D	7339 987811	SERGEY MIKHAYLOV	{"email": "s-mikhaylov.011967@postgrespro.ru", "phone": "+70680520363"}
0005433788153	7497A8	2298 103235	ELENA KOMAROVA	{"email": "komarovae.20041981@postgrespro.ru", "phone": "+70276359078"}
0005433788154	C1145B	2818 019776	NIKOLAY MAKSIMOV	{"email": "nikolay-maksimov_1966@postgrespro.ru", "phone": "+70844071505"}
0005433788155	7EE448	9284 047628	GLEB MAKSIMOV	{"email": "maksimov.gleb.1967@postgrespro.ru", "phone": "+70813157144"}
0005433788156	7EE448	6543 383317	ALEKSANDR GAVRILOV	{"phone": "+70107621724"}
0005433788157	AD290A	7072 670660	IGOR ILIN	{"email": "ilin_i.121970@postgrespro.ru", "phone": "+70869564054"}
0005433788158	AC356A	0003 964697	ALEKSANDRA EFIMOVA	{"email": "a_efimova_071967@postgrespro.ru", "phone": "+70710668342"}
0005433788159	B62FAD	6182 981588	ELENA KUZNECOVA	{"phone": "+70986326356"}
0005433788160	500B84	9822 359391	NIKOLAY TIMOFEEV	{"email": "nikolay-timofeev-01081968@postgrespro.ru", "phone": "+70217075938"}
0005433788161	2FAB5B	0166 357895	TAMARA KULIKOVA	{"email": "t_kulikova-1972@postgrespro.ru", "phone": "+70379112991"}
0005433788162	2FAB5B	4746 795300	NIKOLAY DENISOV	{"email": "denisovnikolay091978@postgrespro.ru", "phone": "+70737564741"}
0005433788163	852656	9737 855444	LARISA ARKHIPOVA	{"email": "arkhipova_l-091975@postgrespro.ru", "phone": "+70836005848"}
0005433788164	852656	3780 133981	TATYANA NOVIKOVA	{"email": "t.novikova.1971@postgrespro.ru", "phone": "+70657062768"}
0005433788165	E0314C	2886 061453	LYUDMILA ROMANOVA	{"email": "l.romanova1966@postgrespro.ru", "phone": "+70083904275"}
0005433788166	19E6D5	8436 142005	EVGENIYA KUDRYASHOVA	{"phone": "+70768475131"}
0005433788167	39AED0	1299 104541	ARKADIY ROMANOV	{"phone": "+70410588397"}
0005433788168	39AED0	5015 987450	VALENTINA MIKHAYLOVA	{"phone": "+70789909671"}
0005433788169	40B013	0359 977743	NATALYA MAKAROVA	{"phone": "+70996464592"}
0005433788170	427EEE	8276 009037	LEV VOLKOV	{"phone": "+70861669278"}
0005433788171	427EEE	9913 405141	OLGA TROFIMOVA	{"phone": "+70443627534"}
0005433788172	939604	4050 297904	YURIY MOISEEV	{"phone": "+70524692080"}
0005433788173	031BD4	9731 819056	MIKHAIL IVANOV	{"phone": "+70132626130"}
0005433788174	ED82EB	1223 735684	RAISA KUZMINA	{"email": "kuzmina.raisa-1963@postgrespro.ru", "phone": "+70701853559"}
0005433788175	ED82EB	1537 406177	VLADIMIR SCHERBAKOV	{"phone": "+70444897871"}
0005433788176	DBF0CC	4752 346883	IRINA MEDVEDEVA	{"email": "i.medvedeva.021980@postgrespro.ru", "phone": "+70620154882"}
0005433788177	1ECB4A	4399 178403	ALBINA STEPANOVA	{"email": "a.stepanova_051959@postgrespro.ru", "phone": "+70125832519"}
0005433788178	E07CED	3021 450982	SERGEY KUZNECOV	{"phone": "+70722975626"}
0005433788179	BC930C	6125 245994	IVAN MIKHAYLOV	{"phone": "+70315936039"}
0005433788180	BC930C	2930 582843	ELENA FOMINA	{"phone": "+70857392758"}
0005433788181	A135D3	8783 134732	VALERIY KUZNECOV	{"phone": "+70922837201"}
0005433788182	A135D3	5732 507273	YURIY ILIN	{"email": "iliny-1966@postgrespro.ru", "phone": "+70580835672"}
0005433788183	D6890E	2873 571180	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir_1976@postgrespro.ru", "phone": "+70573651184"}
0005433788184	D6890E	5468 537880	ANDREY BELOV	{"phone": "+70961576251"}
0005433788185	CC6784	6982 887425	SERGEY FEDOTOV	{"phone": "+70342896174"}
0005433788186	CC6784	5791 152608	NATALIYA OSIPOVA	{"email": "osipovanataliya-111981@postgrespro.ru", "phone": "+70521719764"}
0005433788187	CC6784	0679 531532	NATALIYA SCHERBAKOVA	{"phone": "+70507068774"}
0005433788188	E9FFC4	4207 440782	IVAN FOMIN	{"email": "fomin-i.1971@postgrespro.ru", "phone": "+70408416994"}
0005433788189	5492CD	4605 626367	NIKOLAY KUZNECOV	{"phone": "+70919124360"}
0005433788190	A45F33	8241 470488	VLADIMIR OSIPOV	{"email": "vladimir_osipov_17061976@postgrespro.ru", "phone": "+70025967927"}
0005433788191	F15EE2	9590 087678	TATYANA GERASIMOVA	{"email": "t_gerasimova1974@postgrespro.ru", "phone": "+70137226460"}
0005433788192	8B0FE9	5418 989776	ANDREY KUZNECOV	{"email": "kuznecov_andrey.06051984@postgrespro.ru", "phone": "+70166032491"}
0005433788193	8B0FE9	7544 923928	IVAN BORISOV	{"phone": "+70283762081"}
0005433788194	F8AA25	7158 234554	OLGA LUKYANOVA	{"email": "lukyanovaolga-14011979@postgrespro.ru", "phone": "+70286051643"}
0005433788195	F8AA25	5084 971133	MAKSIM IVANOV	{"email": "ivanov.m-1965@postgrespro.ru", "phone": "+70414699286"}
0005433788196	A432AD	1347 451217	ANNA PETROVA	{"phone": "+70682273573"}
0005433788197	FD0295	0315 816141	SERGEY SMIRNOV	{"phone": "+70846390226"}
0005433788198	10D9D5	4293 451921	YULIYA ANTONOVA	{"email": "y-antonova_22041965@postgrespro.ru", "phone": "+70276518373"}
0005433788199	10D9D5	0804 045736	SERGEY MAKAROV	{"email": "makarovs-1973@postgrespro.ru", "phone": "+70107193714"}
0005433788200	5DE071	7750 696779	VASILIY KAZAKOV	{"email": "vkazakov.051980@postgrespro.ru", "phone": "+70139406672"}
0005433788201	868538	5607 473136	ILYA ABRAMOV	{"phone": "+70444279958"}
0005433788202	868538	5822 001086	LYUDMILA KUZNECOVA	{"phone": "+70190642114"}
0005433788203	868538	6378 489262	SVETLANA EGOROVA	{"phone": "+70023586236"}
0005433788204	3ECD94	1235 395322	VITALIY KUZMIN	{"email": "vitaliy.kuzmin.1969@postgrespro.ru", "phone": "+70836683511"}
0005433788205	7F22FC	3577 873114	SVETLANA DANILOVA	{"email": "s-danilova06021968@postgrespro.ru", "phone": "+70606280414"}
0005433788206	ED240C	2103 703566	MAKSIM ALEKSEEV	{"email": "alekseev_maksim-1978@postgrespro.ru", "phone": "+70581829946"}
0005433788207	C99B07	9180 329291	ALEKSEY GORBUNOV	{"email": "gorbunov-a-1967@postgrespro.ru", "phone": "+70972901058"}
0005433788208	C99B07	2784 421159	IGOR ORLOV	{"email": "igor-orlov_1973@postgrespro.ru", "phone": "+70219049984"}
0005433788209	8C7637	4682 079039	ANATOLIY MATVEEV	{"phone": "+70163750161"}
0005433788210	8C7637	0497 246364	SVETLANA GERASIMOVA	{"phone": "+70571293161"}
0005433788211	18DD27	6513 087272	NADEZHDA VASILEVA	{"email": "vasileva.n.11041970@postgrespro.ru", "phone": "+70962803625"}
0005433788212	482D57	3714 447961	YURIY TIMOFEEV	{"phone": "+70221177086"}
0005433788213	F0CB24	7290 749403	ALEKSEY ABRAMOV	{"email": "alekseyabramov061961@postgrespro.ru", "phone": "+70398691313"}
0005433788214	F0CB24	9228 204305	VLADIMIR IVANOV	{"phone": "+70687813053"}
0005433788215	F0CB24	7239 171860	ILYA IVANOV	{"email": "i_ivanov1974@postgrespro.ru", "phone": "+70891274721"}
0005433788216	04EFCB	1459 916688	VLADIMIR TARASOV	{"phone": "+70943325988"}
0005433788217	04EFCB	7716 119563	NIKOLAY ROMANOV	{"email": "romanov-nikolay-081970@postgrespro.ru", "phone": "+70115241578"}
0005433788218	95C366	4567 163884	LYAYSAN STEPANOVA	{"phone": "+70787722692"}
0005433788219	A440FA	4317 268516	SERGEY VOROBEV	{"email": "s_vorobev-071968@postgrespro.ru", "phone": "+70470318991"}
0005433788220	A440FA	7279 450787	NATALYA FROLOVA	{"email": "frolova_natalya-1978@postgrespro.ru", "phone": "+70781101804"}
0005433788221	75CBA7	5970 218866	DMITRIY ILIN	{"email": "ilind-1969@postgrespro.ru", "phone": "+70530340302"}
0005433788222	B2F1C1	8445 633433	TIKHON DMITRIEV	{"email": "dmitriev.tikhon-051966@postgrespro.ru", "phone": "+70747313334"}
0005433788223	1CB608	7101 736102	DMITRIY SOKOLOV	{"email": "dmitriy.sokolov_08071969@postgrespro.ru", "phone": "+70692297173"}
0005433788224	1AD7A3	2048 926287	ROMAN MELNIKOV	{"email": "r.melnikov-1983@postgrespro.ru", "phone": "+70089252823"}
0005433788225	9ED3A3	0532 282755	TATYANA EGOROVA	{"phone": "+70576482192"}
0005433788226	3D2DE3	0773 714481	ALEKSANDR NIKITIN	{"email": "a_nikitin.081983@postgrespro.ru", "phone": "+70025273846"}
0005433788227	FCF689	2697 609440	NADEZHDA EFIMOVA	{"phone": "+70527438986"}
0005433788228	5009C7	8824 683932	POLINA DMITRIEVA	{"email": "p-dmitrieva_21061955@postgrespro.ru", "phone": "+70734145455"}
0005433788229	93F5DF	0657 344481	ALEKSANDRA VASILEVA	{"email": "vasileva_aleksandra_081977@postgrespro.ru", "phone": "+70944592178"}
0005433788230	96F6B2	1154 458916	VADIM YAKOVLEV	{"phone": "+70060113426"}
0005433788231	96F6B2	2695 059574	DARYA EFREMOVA	{"phone": "+70184721720"}
0005433788232	96F6B2	6844 114861	DMITRIY ABRAMOV	{"email": "abramov-d-12121974@postgrespro.ru", "phone": "+70632756543"}
0005433788233	C2FDE9	4162 024779	YURIY KUZNECOV	{"email": "y-kuznecov.13041975@postgrespro.ru", "phone": "+70756741335"}
0005433788234	400AF1	1190 602336	SERGEY FILIPPOV	{"email": "filippov-sergey1967@postgrespro.ru", "phone": "+70280055740"}
0005433788235	BE1A65	6703 262240	SERGEY STEPANOV	{"phone": "+70522746357"}
0005433788236	E06DA9	0639 264555	SERGEY GAVRILOV	{"phone": "+70924669907"}
0005433788237	356874	3565 926653	ELENA TIKHONOVA	{"email": "e_tikhonova-04021977@postgrespro.ru", "phone": "+70706876414"}
0005433788238	FB7138	4892 779757	ARKADIY MIRONOV	{"email": "mironova-22111965@postgrespro.ru", "phone": "+70084578510"}
0005433788239	883435	4820 119379	OLGA KOZLOVA	{"email": "olga-kozlova.1969@postgrespro.ru", "phone": "+70765388216"}
0005433788240	2D65D5	8831 382053	ALEKSANDR YAKOVLEV	{"phone": "+70890600353"}
0005433788241	84D9CF	7984 865064	SERGEY KUZNECOV	{"email": "sergey_kuznecov.16031963@postgrespro.ru", "phone": "+70513627736"}
0005433788242	09D6C6	8036 533582	VIKTOR ANTONOV	{"phone": "+70005122661"}
0005433788243	E0570B	9301 935502	RUSLAN PAVLOV	{"phone": "+70392608446"}
0005433788244	E0570B	3216 688479	SVETLANA RODIONOVA	{"phone": "+70944356077"}
0005433788300	832F9A	0002 374790	KIRILL IVANOV	{"phone": "+70503322359"}
0005433788245	89C1A9	8201 146601	VALERIYA VLASOVA	{"email": "vlasova.valeriya_1967@postgrespro.ru", "phone": "+70659222209"}
0005433788246	3ED080	4946 786858	IRINA ZAKHAROVA	{"email": "zakharova-irina1975@postgrespro.ru", "phone": "+70471709162"}
0005433788247	3ED080	8100 801093	DANILA PETROV	{"phone": "+70987407547"}
0005433788248	3ED080	4152 928488	IRINA SMIRNOVA	{"phone": "+70087009188"}
0005433788249	254857	2276 105932	MIKHAIL ISAEV	{"email": "m_isaev_30091975@postgrespro.ru", "phone": "+70687650828"}
0005433788250	9162E0	6835 629930	DMITRIY NAUMOV	{"phone": "+70887326810"}
0005433788251	B82A4F	0891 336644	ANDREY FROLOV	{"email": "a_frolov.1969@postgrespro.ru", "phone": "+70175202804"}
0005433788252	B71752	3138 796985	ELENA MAKAROVA	{"email": "elena-makarova_15011967@postgrespro.ru", "phone": "+70144796801"}
0005433788253	B71752	4689 073435	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova.061975@postgrespro.ru", "phone": "+70985839958"}
0005433788254	738708	4871 052212	YURIY NAUMOV	{"phone": "+70736328837"}
0005433788255	738708	7689 768572	NADEZHDA KONOVALOVA	{"email": "konovalovanadezhda.1972@postgrespro.ru", "phone": "+70411021611"}
0005433788256	738708	9695 090942	VIKTOR MAKAROV	{"email": "viktor.makarov-28021978@postgrespro.ru", "phone": "+70245496857"}
0005433788257	94AFE9	3964 116478	DMITRIY FROLOV	{"email": "dmitriy_frolov_1965@postgrespro.ru", "phone": "+70604037976"}
0005433788258	BD3767	9790 893963	PAVEL KUDRYASHOV	{"email": "kudryashov.pavel_1973@postgrespro.ru", "phone": "+70063282409"}
0005433788259	8E7248	4931 937861	ARTUR TIKHONOV	{"phone": "+70721910638"}
0005433788260	532C8B	1943 706602	ILYA POPOV	{"email": "popov.i1961@postgrespro.ru", "phone": "+70701720681"}
0005433788261	532C8B	8999 244226	ALEKSANDR KUZNECOV	{"email": "akuznecov-13121976@postgrespro.ru", "phone": "+70636030503"}
0005433788262	245602	5763 178764	FAINA KULIKOVA	{"email": "kulikova.f-1970@postgrespro.ru", "phone": "+70987395062"}
0005433788263	245602	3901 712212	ALEKSANDR KOZLOV	{"email": "a_kozlov-1974@postgrespro.ru", "phone": "+70815308110"}
0005433788264	87C809	6925 589058	MATVEY PETROV	{"email": "matvey_petrov22011981@postgrespro.ru", "phone": "+70885098688"}
0005433788265	F405CA	7261 156210	MARINA STEPANOVA	{"email": "m_stepanova.041978@postgrespro.ru", "phone": "+70201013834"}
0005433788266	B099E6	8398 623820	ELENA ABRAMOVA	{"phone": "+70938131101"}
0005433788267	B099E6	0194 381691	YULIYA SMIRNOVA	{"email": "yuliya_smirnova-031972@postgrespro.ru", "phone": "+70891791118"}
0005433788268	3EA689	2697 387419	ALEKSANDR KUDRYASHOV	{"phone": "+70331593580"}
0005433788269	3EA689	2025 518177	MIKHAIL KUZNECOV	{"phone": "+70309211590"}
0005433788270	583B14	3754 596146	TATYANA KOZLOVA	{"phone": "+70986509443"}
0005433788271	583B14	6851 431931	TATYANA MOROZOVA	{"email": "morozova-t.101969@postgrespro.ru", "phone": "+70134340068"}
0005433788272	C84C8D	5154 644671	ALINA FILIPPOVA	{"phone": "+70537292029"}
0005433788273	66AEA1	8062 149084	VLADIMIR TARASOV	{"phone": "+70911560815"}
0005433788274	B33DCD	6629 599487	VITALIY VOLKOV	{"phone": "+70931219221"}
0005433788275	B33DCD	3566 381670	GENNADIY VOLKOV	{"phone": "+70607344162"}
0005433788276	E844EC	2118 439204	INNA ARKHIPOVA	{"phone": "+70288906470"}
0005433788277	E81413	5626 754199	NIKITA IVANOV	{"email": "ivanov_nikita1976@postgrespro.ru", "phone": "+70798686631"}
0005433788278	64EB17	3170 974661	POLINA BOGDANOVA	{"phone": "+70848452093"}
0005433788279	64EB17	7262 933679	ANDREY MOROZOV	{"email": "morozov-andrey.1964@postgrespro.ru", "phone": "+70250844833"}
0005433788280	6E9931	5280 208178	KLAVDIYA MOROZOVA	{"phone": "+70739134411"}
0005433788281	6E9931	2882 651501	FILIPP FEDOTOV	{"phone": "+70833943390"}
0005433788282	184A19	5720 216986	MARIYA YAKOVLEVA	{"email": "yakovleva-m.29071969@postgrespro.ru", "phone": "+70650580748"}
0005433788283	B47464	4019 591758	ROZA CHERNOVA	{"email": "chernova_r.101970@postgrespro.ru", "phone": "+70190796134"}
0005433788284	418B3C	4423 100461	EKATERINA VOROBEVA	{"email": "ekaterina-vorobeva1956@postgrespro.ru", "phone": "+70521414766"}
0005433788285	B51E0F	4371 053555	TATYANA KOROLEVA	{"phone": "+70651815430"}
0005433788286	1BCF0F	8816 008301	ZINAIDA OVCHINNIKOVA	{"email": "z_ovchinnikova.07111977@postgrespro.ru", "phone": "+70992397045"}
0005433788287	1BCF0F	8105 929661	ANNA TARASOVA	{"email": "a_tarasova-061968@postgrespro.ru", "phone": "+70843392858"}
0005433788288	1DA0E7	8137 695263	DMITRIY ROMANOV	{"email": "romanov_dmitriy1986@postgrespro.ru", "phone": "+70816286922"}
0005433788289	3E87CC	4994 197848	ARTEM KOROLEV	{"phone": "+70380963252"}
0005433788290	3E87CC	2354 955541	ARTEM NIKITIN	{"email": "nikitin-a-111973@postgrespro.ru", "phone": "+70389839390"}
0005433788291	BD4CC8	7333 487493	EGOR CHERNOV	{"email": "echernov031969@postgrespro.ru", "phone": "+70320030114"}
0005433788292	BBC09B	6890 979140	ELENA BORISOVA	{"email": "e-borisova-1960@postgrespro.ru", "phone": "+70743068291"}
0005433788293	BBC09B	5600 238296	VENERA SIDOROVA	{"email": "venerasidorova-041972@postgrespro.ru", "phone": "+70503695185"}
0005433788294	77EA73	2673 357558	ALEKSEY KOZLOV	{"email": "kozlov.aleksey.09111980@postgrespro.ru", "phone": "+70519870864"}
0005433788295	F90DF5	4684 286027	YURIY FEDOROV	{"email": "y.fedorov23121970@postgrespro.ru", "phone": "+70745322840"}
0005433788296	8E5DD8	3207 927018	ALEKSEY IVANOV	{"email": "ivanovaleksey-21011970@postgrespro.ru", "phone": "+70909823804"}
0005433788297	71892F	9771 422223	ARINA ROMANOVA	{"phone": "+70965410835"}
0005433788298	68AA1B	9142 989023	ALEKSANDR SAVELEV	{"phone": "+70028734516"}
0005433788299	12D004	0760 672213	VADIM FILIPPOV	{"email": "vfilippov031971@postgrespro.ru", "phone": "+70990349387"}
0005433788301	096334	7075 528990	VASILIY FROLOV	{"email": "frolovvasiliy-021971@postgrespro.ru", "phone": "+70853038361"}
0005433788302	096334	6801 948355	GENNADIY NOVIKOV	{"phone": "+70977685514"}
0005433788303	C40238	6709 868428	VLADIMIR OSIPOV	{"email": "vladimir-osipov_1971@postgrespro.ru", "phone": "+70236664692"}
0005433788304	C40238	7157 788238	EVGENIY SOKOLOV	{"phone": "+70241205051"}
0005433788305	5845F9	7397 929366	VALENTINA DAVYDOVA	{"phone": "+70993988352"}
0005433788306	8E3C5A	6107 441987	SERGEY TIMOFEEV	{"phone": "+70387876295"}
0005433788307	5160A9	5314 902537	SERGEY NIKOLAEV	{"phone": "+70805296142"}
0005433788308	5160A9	2334 175023	OLGA KISELEVA	{"email": "olga.kiseleva_14081967@postgrespro.ru", "phone": "+70360324809"}
0005433788309	042230	7044 871439	EGOR PETROV	{"email": "e_petrov071961@postgrespro.ru", "phone": "+70348631564"}
0005433788310	7C0F40	3876 420524	STANISLAV KAZAKOV	{"phone": "+70184576483"}
0005433788311	7C0F40	3175 333504	KIRILL ZHUKOV	{"email": "zhukov_k.25061974@postgrespro.ru", "phone": "+70807508311"}
0005433788312	8E8D8A	5667 905644	ANNA EFIMOVA	{"phone": "+70083979863"}
0005433788313	0C9E72	5569 179065	VYACHESLAV SIDOROV	{"email": "v-sidorov_071976@postgrespro.ru", "phone": "+70587644909"}
0005433788314	A0EB76	6410 972336	DENIS BONDARENKO	{"phone": "+70543815622"}
0005433788315	A0EB76	0561 746978	TAMARA KUZNECOVA	{"phone": "+70792072844"}
0005433788316	2EAA2A	4944 826999	KLAVDIYA TARASOVA	{"phone": "+70177922295"}
0005433788317	2EAA2A	9806 729577	SERGEY NIKITIN	{"phone": "+70083463193"}
0005433788318	B5822B	9409 396011	EVGENIYA MOROZOVA	{"email": "morozova.e_1983@postgrespro.ru", "phone": "+70339835407"}
0005433788319	ABC61E	0909 632639	MARAT NIKOLAEV	{"email": "nikolaev-m-1979@postgrespro.ru", "phone": "+70658780420"}
0005433788320	42DDC5	7269 573576	ALEKSEY NIKOLAEV	{"phone": "+70630653466"}
0005433788321	480C4D	6882 402849	ANNA ANDREEVA	{"phone": "+70510897255"}
0005433804944	D4B7F5	3494 280149	IVAN ILIN	{"phone": "+70067907952"}
0005433788322	31BE6B	4164 747763	ANNA ROMANOVA	{"email": "romanova-anna27101965@postgrespro.ru", "phone": "+70712140015"}
0005433788323	516974	8869 774247	MAKSIM MIRONOV	{"phone": "+70007758896"}
0005433788324	01B32E	8823 633655	VLADIMIR ISAEV	{"email": "isaevv_04121977@postgrespro.ru", "phone": "+70414552719"}
0005433788325	4BF430	7861 421456	ELENA MAKSIMOVA	{"phone": "+70058765607"}
0005433788326	0E4666	4168 012783	SERGEY GORBUNOV	{"phone": "+70115540877"}
0005433788327	0E4666	5843 380032	YURIY SCHERBAKOV	{"email": "scherbakovy061980@postgrespro.ru", "phone": "+70640944181"}
0005433788328	0E4666	4686 200846	ANDREY KOROLEV	{"phone": "+70541559587"}
0005433788329	EB0821	2166 829306	ELENA SMIRNOVA	{"phone": "+70766502136"}
0005433788330	EB0821	6422 345834	KIRILL KUZNECOV	{"phone": "+70555032420"}
0005433788331	B908DA	7587 073557	EVGENIY NOVIKOV	{"email": "evgeniy_novikov_24021972@postgrespro.ru", "phone": "+70060099657"}
0005433788332	B908DA	4137 133930	ELENA TROFIMOVA	{"email": "elena.trofimova.22011962@postgrespro.ru", "phone": "+70462141637"}
0005433788333	B908DA	9451 364619	EVDOKIYA KUZNECOVA	{"phone": "+70601269388"}
0005433788334	44FB89	0195 533008	NIKOLAY VASILEV	{"phone": "+70363293027"}
0005433788335	CE96B5	8165 856324	NATALYA SEMENOVA	{"email": "natalya_semenova24101975@postgrespro.ru", "phone": "+70826430881"}
0005433804777	EDA905	5342 330154	NIKITA BARANOV	{"phone": "+70846478626"}
0005433804778	EDA905	7356 782669	VASILIY SOKOLOV	{"email": "v_sokolov.041974@postgrespro.ru", "phone": "+70185322180"}
0005433804779	CE3B7A	7476 780836	VIKTORIYA KOVALEVA	{"email": "viktoriyakovaleva1968@postgrespro.ru", "phone": "+70241469250"}
0005433804780	CE3B7A	8333 363957	TATYANA GERASIMOVA	{"phone": "+70621477453"}
0005433804781	F1FC6D	8670 700061	SERGEY KUZMIN	{"email": "sergey_kuzmin121977@postgrespro.ru", "phone": "+70218821629"}
0005433804782	AE1063	0802 675894	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov-021965@postgrespro.ru", "phone": "+70522831282"}
0005433804783	4F62BD	9976 006140	KSENIYA IVANOVA	{"email": "kseniya.ivanova_1972@postgrespro.ru", "phone": "+70052732672"}
0005433804784	D4D7E3	5448 937541	ALEKSANDRA ALEKSANDROVA	{"phone": "+70857979596"}
0005433804785	D4D7E3	9604 585574	ALINA EGOROVA	{"email": "egorova_a-18071972@postgrespro.ru", "phone": "+70224359109"}
0005433804786	895420	3071 881172	EKATERINA ERMAKOVA	{"email": "ermakova_ekaterina_1965@postgrespro.ru", "phone": "+70472053041"}
0005433804787	B6F920	3451 846895	OLGA PETROVA	{"email": "opetrova1972@postgrespro.ru", "phone": "+70880541907"}
0005433804788	B6F920	9710 799090	LIDIYA ANDREEVA	{"email": "l-andreeva.071984@postgrespro.ru", "phone": "+70497947395"}
0005433804789	7A0538	3474 511030	POLINA ORLOVA	{"phone": "+70160345807"}
0005433804790	D71F4C	5241 359740	NINA MOISEEVA	{"phone": "+70599155758"}
0005433804791	CE0BC5	4960 056180	TATYANA VOLKOVA	{"phone": "+70574091908"}
0005433804792	C5FA2D	9896 563846	DENIS CHERNOV	{"phone": "+70686028360"}
0005433804793	E56C55	6184 590391	VLADIMIR MOROZOV	{"email": "morozov-vladimir25061970@postgrespro.ru", "phone": "+70063931825"}
0005433804794	7F21EC	1430 177094	ELIZAVETA FILIPPOVA	{"email": "filippova_e1978@postgrespro.ru", "phone": "+70576545857"}
0005433804795	7F21EC	3057 194087	VYACHESLAV GUSEV	{"phone": "+70280550069"}
0005433804796	4AA4B1	2242 674695	OLEG ANTONOV	{"phone": "+70352084211"}
0005433804797	3A7B03	1931 792961	OLGA GORBUNOVA	{"email": "gorbunova.o-1971@postgrespro.ru", "phone": "+70685348685"}
0005433804798	FF8EEB	0928 196868	VALENTINA IVANOVA	{"email": "v.ivanova.08071987@postgrespro.ru", "phone": "+70192785065"}
0005433804799	1655B5	7763 095580	DARYA SOLOVEVA	{"email": "soloveva-darya-121977@postgrespro.ru", "phone": "+70909387189"}
0005433804800	1655B5	8779 320651	EKATERINA SOKOLOVA	{"email": "sokolova_ekaterina_051978@postgrespro.ru", "phone": "+70226940775"}
0005433804801	57C9CD	7445 984655	KONSTANTIN PAVLOV	{"phone": "+70200499076"}
0005433804802	86B3A9	5380 728252	ELENA NIKITINA	{"email": "nikitina-elena-011972@postgrespro.ru", "phone": "+70493472713"}
0005433804803	253924	4011 621877	OLGA PAVLOVA	{"email": "opavlova17021976@postgrespro.ru", "phone": "+70655435158"}
0005433804804	5C3EF6	6847 286158	TATYANA FOMINA	{"phone": "+70744438324"}
0005433804805	132CF9	9558 506567	EVDOKIYA MAKSIMOVA	{"phone": "+70404950395"}
0005433804806	E3ECE9	6136 342870	NIKITA KOZLOV	{"phone": "+70604147211"}
0005433804807	28386C	6218 816290	VIKTOR MATVEEV	{"phone": "+70132459157"}
0005433804808	7A5FF0	9061 350461	ALEKSANDR ANTONOV	{"phone": "+70393270959"}
0005433804809	0BF1CE	7796 392369	ROMAN MIRONOV	{"email": "r.mironov_1979@postgrespro.ru", "phone": "+70777865322"}
0005433804810	0BF1CE	8747 643514	STANISLAV KUZNECOV	{"email": "stanislavkuznecov16021970@postgrespro.ru", "phone": "+70230522971"}
0005433804811	0BF1CE	2018 923755	LIDIYA NIKOLAEVA	{"phone": "+70790989954"}
0005433804812	40EEA6	0025 930308	DENIS POPOV	{"email": "d.popov_1970@postgrespro.ru", "phone": "+70971436002"}
0005433804813	36F307	5728 882501	YULIYA SCHERBAKOVA	{"phone": "+70074002563"}
0005433804814	6B98B0	4483 219925	ELENA ZOTOVA	{"phone": "+70401013977"}
0005433804815	60E694	9330 896524	MAKSIM ZHURAVLEV	{"email": "maksim.zhuravlev-13081970@postgrespro.ru", "phone": "+70874117215"}
0005433804816	8A547E	6274 129072	MIKHAIL MOROZOV	{"phone": "+70025713724"}
0005433804817	8A547E	4642 700290	ANATOLIY MIKHAYLOV	{"email": "mikhaylova-111966@postgrespro.ru", "phone": "+70285177249"}
0005433804818	1253C1	3960 041937	NADEZHDA KUZNECOVA	{"email": "n-kuznecova.031971@postgrespro.ru", "phone": "+70333657940"}
0005433804819	030284	0391 536151	SNEZHANA YAKOVLEVA	{"email": "s_yakovleva-061969@postgrespro.ru", "phone": "+70073146486"}
0005433804820	B712FD	0470 747192	VALENTINA NIKITINA	{"email": "v_nikitina.28011965@postgrespro.ru", "phone": "+70350783673"}
0005433804821	B437D4	3869 346433	NIKOLAY KARPOV	{"email": "nikolay_karpov1961@postgrespro.ru", "phone": "+70307445512"}
0005433804822	C33F6E	3110 698372	VYACHESLAV GRIGOREV	{"phone": "+70656603356"}
0005433804823	8486BC	1314 562216	ANTONINA FADEEVA	{"email": "antoninafadeeva.1972@postgrespro.ru", "phone": "+70774091887"}
0005433804824	B325FD	4950 741393	NATALYA NESTEROVA	{"phone": "+70507390394"}
0005433804825	EEC431	7049 307195	LYUDMILA DAVYDOVA	{"phone": "+70226850687"}
0005433804826	EEC431	2330 109077	RAISA MIKHAYLOVA	{"phone": "+70890224477"}
0005433804827	26548D	6693 095249	DARYA POPOVA	{"phone": "+70607574419"}
0005433804828	C086DF	4986 740159	PETR PAVLOV	{"email": "pavlov.p1972@postgrespro.ru", "phone": "+70033704547"}
0005433804829	3B35B4	1472 616706	TATYANA IVANOVA	{"phone": "+70202171922"}
0005433804830	428B37	5627 273543	VALENTINA MATVEEVA	{"phone": "+70728066866"}
0005433804831	BF3145	9032 119484	ELENA YUDINA	{"phone": "+70008350448"}
0005433804832	658601	8454 552811	NIKOLAY GRIGOREV	{"phone": "+70088286755"}
0005433804833	91E8FC	3136 080699	NINA KUZNECOVA	{"phone": "+70774150199"}
0005433804834	C32835	9863 741377	YAN TIMOFEEV	{"email": "yan_timofeev.1971@postgrespro.ru", "phone": "+70868424405"}
0005433804835	C32835	5239 525359	TATYANA NAUMOVA	{"phone": "+70026075768"}
0005433804836	F04A66	5076 966916	NATALYA KONOVALOVA	{"email": "konovalova_n-06101973@postgrespro.ru", "phone": "+70229635980"}
0005433804837	B6E38A	8681 131255	MARIYA VOLKOVA	{"phone": "+70886352990"}
0005433804838	99346F	9808 747210	LYUDMILA NIKITINA	{"email": "lnikitina_15121979@postgrespro.ru", "phone": "+70260027216"}
0005433804839	99346F	4732 521692	ANDREY KUZNECOV	{"phone": "+70339260526"}
0005433804840	AEC6EF	6916 935441	LILIYA BELOVA	{"phone": "+70731399586"}
0005433804841	D77EAE	9176 203048	MAKSIM KUZNECOV	{"email": "kuznecov-m18061973@postgrespro.ru", "phone": "+70467149988"}
0005433804842	D77EAE	8853 077741	ANASTASIYA DAVYDOVA	{"email": "anastasiyadavydova_20051981@postgrespro.ru", "phone": "+70926497552"}
0005433804843	FB0B4D	5567 816576	PAVEL VASILEV	{"phone": "+70897395134"}
0005433804844	3F170F	4443 738246	LYUBOV YUDINA	{"email": "yudina.l_15081973@postgrespro.ru", "phone": "+70257800624"}
0005433804845	8FF7CD	6497 480246	LYUBOV KISELEVA	{"phone": "+70633058740"}
0005433804846	D065A5	3020 986619	MARINA NESTEROVA	{"phone": "+70692060074"}
0005433804847	C585F4	6035 846441	NATALYA IVANOVA	{"email": "nivanova031980@postgrespro.ru", "phone": "+70058895089"}
0005433804848	433989	9545 335742	LYUDMILA POPOVA	{"phone": "+70319453939"}
0005433804849	4D6C46	2569 403495	NADEZHDA TITOVA	{"email": "n-titova.091974@postgrespro.ru", "phone": "+70057828325"}
0005433804850	B070B5	7226 672093	VLADIMIR GORBUNOV	{"email": "gorbunov-v-1963@postgrespro.ru", "phone": "+70566642145"}
0005433804851	DFE7CA	9391 622948	ELENA GRISHINA	{"email": "e_grishina.16121955@postgrespro.ru", "phone": "+70369795323"}
0005433804852	DB7266	6306 195135	ELENA IVANOVA	{"email": "ivanovaelena_011971@postgrespro.ru", "phone": "+70474765737"}
0005433804853	365494	9608 544786	ANDREY NIKOLAEV	{"phone": "+70357497273"}
0005433804854	D70FCB	0477 424197	LYUDMILA LEBEDEVA	{"email": "lebedeva_l-13051954@postgrespro.ru", "phone": "+70284090018"}
0005433804855	D70FCB	9598 317941	DMITRIY SAVELEV	{"email": "savelev_dmitriy.1977@postgrespro.ru", "phone": "+70663852001"}
0005433804856	B03A8B	2467 992974	NINA EGOROVA	{"email": "egorova_n1978@postgrespro.ru", "phone": "+70564977976"}
0005433804857	69AE49	4148 336298	ELIZAVETA BORISOVA	{"email": "borisovae.11081974@postgrespro.ru", "phone": "+70661512871"}
0005433804858	EEB70B	0049 284900	VALENTINA VASILEVA	{"phone": "+70407176446"}
0005433804859	03C6E1	3927 321285	VIKTOR AFANASEV	{"email": "afanasevviktor-04091975@postgrespro.ru", "phone": "+70618477169"}
0005433804860	364B94	1356 771826	ILYA SOROKIN	{"phone": "+70354400850"}
0005433804861	65C9CC	7190 192960	ALEKSANDR RODIONOV	{"email": "rodionov_a-1971@postgrespro.ru", "phone": "+70341189680"}
0005433804862	3A3E77	4708 583334	ROMAN ZHUKOV	{"email": "zhukov_roman20051976@postgrespro.ru", "phone": "+70146847763"}
0005433804863	52D41B	9010 710308	ALEKSEY KOZLOV	{"email": "kozlov_aleksey-11041962@postgrespro.ru", "phone": "+70990355220"}
0005433804864	1118B3	8129 711125	NADEZHDA KOVALEVA	{"email": "nadezhda-kovaleva_31011965@postgrespro.ru", "phone": "+70245668395"}
0005433804865	253508	0418 942105	NINA EFREMOVA	{"phone": "+70044631172"}
0005433804866	9E9A94	7727 579076	NIKITA ZAKHAROV	{"email": "zakharov-n-071978@postgrespro.ru", "phone": "+70456762643"}
0005433804867	9E9A94	7858 135799	SERGEY KULIKOV	{"phone": "+70121180733"}
0005433804868	BB2BB8	6482 279702	NADEZHDA ILINA	{"phone": "+70453464873"}
0005433804869	21D2C7	6673 726737	NADEZHDA KUZNECOVA	{"email": "kuznecovan.1963@postgrespro.ru", "phone": "+70190910221"}
0005433804870	21D2C7	4116 718983	LYUBOV IVANOVA	{"phone": "+70274485540"}
0005433804871	21D2C7	1159 190248	LYUDMILA ROMANOVA	{"email": "romanovalyudmila.21041969@postgrespro.ru", "phone": "+70239328417"}
0005433804872	A390CB	4502 751210	KIRILL MOROZOV	{"phone": "+70653251000"}
0005433804873	A390CB	1083 210076	OLGA MOROZOVA	{"phone": "+70026092123"}
0005433804874	8BD396	4947 082929	ELENA FEDOROVA	{"phone": "+70221230641"}
0005433804875	AE60B8	6118 153534	YAROSLAV GORBUNOV	{"email": "yaroslav-gorbunov.061970@postgrespro.ru", "phone": "+70707251772"}
0005433804876	AE60B8	0878 316454	LYUBOV MIKHAYLOVA	{"email": "mikhaylova_lyubov-1970@postgrespro.ru", "phone": "+70211482252"}
0005433804877	906DD6	3792 674806	IVAN BORISOV	{"email": "borisov-ivan-28101968@postgrespro.ru", "phone": "+70061220431"}
0005433804878	906DD6	0904 523857	VALERIY KUZNECOV	{"phone": "+70435844370"}
0005433804879	7D9939	1860 709586	ALBINA ANDREEVA	{"phone": "+70058471798"}
0005433804880	974CC7	2988 908224	ANDREY KUZNECOV	{"email": "a.kuznecov071973@postgrespro.ru", "phone": "+70544522865"}
0005433804881	5CB458	9788 375777	YULIYA KOVALEVA	{"email": "yuliya.kovaleva_1976@postgrespro.ru", "phone": "+70184362211"}
0005433804882	84EF16	2059 768754	YURIY DAVYDOV	{"phone": "+70626157986"}
0005433804883	84EF16	7246 139760	GENNADIY TIKHONOV	{"phone": "+70006340695"}
0005433804884	D68DDD	4814 151066	LIDIYA EFREMOVA	{"email": "lidiya-efremova_1983@postgrespro.ru", "phone": "+70885413970"}
0005433804885	D68DDD	2556 250239	VLADIMIR ZAKHAROV	{"phone": "+70309069492"}
0005433804886	51ECB0	5166 776062	IGOR DMITRIEV	{"email": "dmitrievigor.061981@postgrespro.ru", "phone": "+70574852507"}
0005433804887	4BFA30	9857 009020	DENIS KUZNECOV	{"phone": "+70038221097"}
0005433804888	6614D5	8204 375985	MARAT SERGEEV	{"email": "sergeev-marat-14121975@postgrespro.ru", "phone": "+70626648383"}
0005433804889	896AB5	9063 700978	RAISA SERGEEVA	{"email": "sergeeva-raisa.17051974@postgrespro.ru", "phone": "+70778802026"}
0005433804890	697AF5	8297 215393	VLADIMIR BELOV	{"email": "belovv051975@postgrespro.ru", "phone": "+70226209403"}
0005433804891	6AC07B	9777 116087	BORIS ORLOV	{"email": "b.orlov1972@postgrespro.ru", "phone": "+70208698109"}
0005433804892	6AC07B	4818 284650	LIDIYA PAVLOVA	{"phone": "+70455412592"}
0005433804893	5B2B79	4766 958678	ELENA ZAYCEVA	{"phone": "+70407304652"}
0005433804894	5B2B79	1290 528051	EVGENIY GORBUNOV	{"phone": "+70274473786"}
0005433804895	1078A3	1380 672492	VERA SOROKINA	{"email": "v.sorokina_13091969@postgrespro.ru", "phone": "+70197556688"}
0005433804896	2AE788	4208 735284	SERGEY MEDVEDEV	{"phone": "+70281554231"}
0005433804897	7CF26B	5250 640546	VITALIY FILIPPOV	{"phone": "+70888273352"}
0005433804898	DB34D0	7018 634732	NIKITA ALEKSANDROV	{"phone": "+70479450042"}
0005433804899	127C94	3938 958339	VYACHESLAV BORISOV	{"email": "v-borisov_09101982@postgrespro.ru", "phone": "+70677233590"}
0005433804900	EA2041	6467 536837	SVETLANA FILIPPOVA	{"phone": "+70745555080"}
0005433804901	4C57A6	0152 867641	IVAN STEPANOV	{"email": "ivan-stepanov-101976@postgrespro.ru", "phone": "+70345823522"}
0005433804902	4C57A6	4567 537491	KSENIYA BARANOVA	{"phone": "+70469134042"}
0005433804903	E79103	8329 622752	LYUDMILA EGOROVA	{"email": "lyudmilaegorova.1983@postgrespro.ru", "phone": "+70922870962"}
0005433804904	E79103	7004 923239	NATALYA ZHURAVLEVA	{"phone": "+70880731315"}
0005433804905	A26C97	2165 943093	LYUBOV POPOVA	{"email": "lyubov.popova121978@postgrespro.ru", "phone": "+70772682248"}
0005433804906	E4496C	5605 181032	ROZALIYA NIKITINA	{"email": "nikitina_r.30041976@postgrespro.ru", "phone": "+70102442449"}
0005433804907	E4496C	4096 935811	NINA KONDRATEVA	{"phone": "+70061932080"}
0005433804908	E4496C	1391 117022	YULIYA KOVALEVA	{"email": "yuliya.kovaleva-21021980@postgrespro.ru", "phone": "+70436871513"}
0005433804909	D63F1F	8402 868371	TAISA KISELEVA	{"email": "kiselevat_04071974@postgrespro.ru", "phone": "+70844067254"}
0005433804910	D63F1F	8454 421892	VALENTINA GRISHINA	{"email": "v.grishina.17071962@postgrespro.ru", "phone": "+70281855593"}
0005433804911	64EA1B	4575 517741	KSENIYA RYABOVA	{"email": "ryabova.kseniya_08061972@postgrespro.ru", "phone": "+70670241105"}
0005433804912	64EA1B	6650 988851	SERGEY CHERNOV	{"email": "s.chernov-021972@postgrespro.ru", "phone": "+70141275596"}
0005433804913	D86F88	2925 784453	NATALYA ZHUKOVA	{"phone": "+70324710161"}
0005433804914	9759B3	5453 311134	OLGA BORISOVA	{"email": "borisovaolga.07111983@postgrespro.ru", "phone": "+70838261047"}
0005433804915	D150E5	3185 726963	NADEZHDA ABRAMOVA	{"email": "nadezhda_abramova101978@postgrespro.ru", "phone": "+70542209143"}
0005433804916	A46F6B	3617 143460	NIKOLAY ANTONOV	{"email": "nikolay.antonov-101969@postgrespro.ru", "phone": "+70558770655"}
0005433804917	C02684	7525 942778	ALEKSEY FEDOTOV	{"phone": "+70740266653"}
0005433804918	C02684	8137 014389	ALEKSANDR DAVYDOV	{"email": "davydov_a021974@postgrespro.ru", "phone": "+70419070110"}
0005433804919	375682	5649 300478	IVAN ALEKSANDROV	{"phone": "+70777906372"}
0005433804920	447174	2289 301999	OLEG IVANOV	{"email": "ivanov_oleg.051981@postgrespro.ru", "phone": "+70518317695"}
0005433804921	8F3FB7	0866 707816	IRINA SOLOVEVA	{"email": "soloveva-irina04031971@postgrespro.ru", "phone": "+70015574669"}
0005433804922	D25BA8	5994 255143	SERGEY MAKSIMOV	{"email": "s-maksimov-08021979@postgrespro.ru", "phone": "+70490464390"}
0005433804923	183641	9359 351147	MARINA BARANOVA	{"phone": "+70560970967"}
0005433804924	14D924	0452 037716	ELENA IVANOVA	{"phone": "+70434239285"}
0005433804925	D5E4D2	7633 552196	VLADIMIR OSIPOV	{"email": "osipov-vladimir_021970@postgrespro.ru", "phone": "+70744640397"}
0005433804926	7B2481	3142 849828	MARIYA KUDRYASHOVA	{"phone": "+70708465019"}
0005433804927	7B2481	6819 473379	LYUBOV AFANASEVA	{"email": "lafanaseva_22121965@postgrespro.ru", "phone": "+70870509909"}
0005433804928	6455C3	3694 120138	TATYANA VOLKOVA	{"email": "tatyana.volkova.24051970@postgrespro.ru", "phone": "+70982955814"}
0005433804929	F59F8D	2403 749266	NATALIYA TIMOFEEVA	{"email": "nataliya.timofeeva.24071970@postgrespro.ru", "phone": "+70539627258"}
0005433804930	F9AEE6	3957 448266	OLGA ISAEVA	{"phone": "+70441986059"}
0005433804931	242035	9134 646731	MARIYA ILINA	{"phone": "+70586830271"}
0005433804932	615042	4805 651939	BOGDAN DMITRIEV	{"phone": "+70449511075"}
0005433804933	E83278	2704 994739	VASILISA MAKSIMOVA	{"phone": "+70694402875"}
0005433804934	5F4CF1	4169 256662	ANNA KOROLEVA	{"phone": "+70073705333"}
0005433804935	5F4CF1	2842 157165	VALERIYA FEDOROVA	{"email": "valeriya.fedorova041970@postgrespro.ru", "phone": "+70155992755"}
0005433804936	842D32	4549 723568	LILIYA TITOVA	{"email": "titova.liliya.10111971@postgrespro.ru", "phone": "+70299715624"}
0005433804937	2E9338	6641 159446	DARYA ARKHIPOVA	{"phone": "+70874131759"}
0005433804938	52A5A6	5925 014773	MIKHAIL ROMANOV	{"phone": "+70562983753"}
0005433804939	A89392	8322 769132	RIMMA KALININA	{"phone": "+70898707858"}
0005433804940	2D922E	9827 171650	NATALYA TIKHONOVA	{"phone": "+70602486082"}
0005433804941	660988	5261 258671	ROMAN SOKOLOV	{"phone": "+70362455367"}
0005433804942	5BA063	9118 361282	DARYA ZAKHAROVA	{"phone": "+70253800490"}
0005433804943	3CB7BB	1843 947792	MIKHAIL KUZNECOV	{"email": "m_kuznecov121965@postgrespro.ru", "phone": "+70960536267"}
0005433804945	D4B7F5	9445 963867	SERGEY SOKOLOV	{"phone": "+70023604101"}
0005433804946	7AC7E5	5413 642836	VLADIMIR FROLOV	{"email": "frolov-v071971@postgrespro.ru", "phone": "+70575023193"}
0005433804947	8B7790	0279 108168	OLEG AFANASEV	{"phone": "+70612322049"}
0005433804948	8B7790	7832 909575	SVETLANA RYABOVA	{"email": "s-ryabova-031977@postgrespro.ru", "phone": "+70272519822"}
0005433804949	70EF0B	3995 214393	VALENTINA ARKHIPOVA	{"phone": "+70992590656"}
0005433804950	63C754	3444 081017	ALEKSANDR FROLOV	{"phone": "+70031163039"}
0005433804951	63C754	7159 047324	RUSLAN ABRAMOV	{"phone": "+70574002882"}
0005433804952	63C754	5370 367738	NINA AFANASEVA	{"phone": "+70498637430"}
0005433804953	F896D4	4561 992673	ANASTASIYA KONOVALOVA	{"phone": "+70507545617"}
0005433804954	F896D4	9332 839782	MARIYA KOZLOVA	{"phone": "+70357407663"}
0005433804955	C6D591	9455 965191	ANDREY ROMANOV	{"phone": "+70461230021"}
0005433804956	DC1100	8494 153018	IRINA PAVLOVA	{"phone": "+70061220212"}
0005433804957	DC1100	6955 736104	ELENA KUZNECOVA	{"email": "kuznecova_e02071962@postgrespro.ru", "phone": "+70802421060"}
0005433804958	52C777	9902 763063	VITALIY KUZNECOV	{"email": "kuznecov-vitaliy_20071984@postgrespro.ru", "phone": "+70640876816"}
0005433804959	52C777	8939 427800	OKSANA FROLOVA	{"phone": "+70982453261"}
0005433804960	6D173F	4495 073351	IGOR AFANASEV	{"phone": "+70152927235"}
0005433804961	6D173F	7039 100461	YURIY GERASIMOV	{"email": "yuriygerasimov1969@postgrespro.ru", "phone": "+70399944090"}
0005433804962	E8180C	0561 471429	IRINA KUZMINA	{"email": "i_kuzmina14031977@postgrespro.ru", "phone": "+70933138572"}
0005433804963	2EB65B	7304 669355	EVGENIY ANDREEV	{"phone": "+70969482109"}
0005433804964	D9021A	6556 131324	ANNA IVANOVA	{"phone": "+70416163330"}
0005433804965	4F7191	1866 336311	MARIYA DMITRIEVA	{"phone": "+70645249946"}
0005433804966	4F7191	7295 934421	ROMAN SCHERBAKOV	{"email": "r.scherbakov.1967@postgrespro.ru", "phone": "+70889148902"}
0005433804967	4F7191	4174 293030	SERGEY GRIGOREV	{"email": "grigorev-sergey-03091970@postgrespro.ru", "phone": "+70278364122"}
0005433804968	0C5A4C	6140 155345	TAMARA BORISOVA	{"email": "t-borisova18121966@postgrespro.ru", "phone": "+70421684491"}
0005433804969	E03378	8135 138980	ANNA IVANOVA	{"phone": "+70728020976"}
0005433804970	4750B7	5998 665987	VIKTORIYA FADEEVA	{"phone": "+70305583321"}
0005433804971	4750B7	9571 808527	ELENA RODIONOVA	{"email": "rodionova.e_051969@postgrespro.ru", "phone": "+70115756615"}
0005433804972	D70B25	7206 068791	VALERIY MOROZOV	{"phone": "+70036265128"}
0005433804973	E1AA85	1269 248528	ANASTASIYA NIKIFOROVA	{"phone": "+70237046633"}
0005433804974	6B2D48	7823 253047	MARINA BOGDANOVA	{"email": "bogdanova.m1972@postgrespro.ru", "phone": "+70666811694"}
0005433804975	7792F3	3455 055016	VIKTOR IVANOV	{"phone": "+70653141577"}
0005433804976	B987A9	9034 235542	EKATERINA DENISOVA	{"phone": "+70048817482"}
0005433804977	B987A9	2900 555489	ALEKSANDR SOROKIN	{"phone": "+70641626226"}
0005433804978	B987A9	2568 765759	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov.26071973@postgrespro.ru", "phone": "+70259860213"}
0005433804979	FEC46F	3431 709282	NIKOLAY KOZLOV	{"phone": "+70729638730"}
0005433804980	804EF7	0242 964179	VLADIMIR SOLOVEV	{"phone": "+70700104961"}
0005433804981	5553B2	2361 038809	TATYANA SEMENOVA	{"phone": "+70284898756"}
0005433804982	095A49	8478 120765	ANATOLIY PETROV	{"email": "anatoliy_petrov.1979@postgrespro.ru", "phone": "+70771270769"}
0005433804983	095A49	4197 958720	ARTEM KOROLEV	{"phone": "+70537977847"}
0005433804984	EF5E06	4919 112516	NINA MEDVEDEVA	{"email": "medvedeva.nina_29091981@postgrespro.ru", "phone": "+70122847375"}
0005433804985	EF5E06	5111 513554	OLGA GAVRILOVA	{"phone": "+70750492575"}
0005433804986	EF5E06	2501 147265	TAISIYA EFREMOVA	{"phone": "+70873049902"}
0005433804987	3B08C0	2725 535471	ALEFTINA VOROBEVA	{"phone": "+70723997378"}
0005433804988	4BEF65	0591 287329	VERA KOMAROVA	{"email": "vera.komarova_011977@postgrespro.ru", "phone": "+70770448749"}
0005433804989	7C8A43	7372 149506	OLGA DMITRIEVA	{"email": "dmitrieva-olga-29051970@postgrespro.ru", "phone": "+70103962810"}
0005433804990	7C8A43	0104 661282	ALEKSANDR IVANOV	{"phone": "+70606767988"}
0005433804991	C45746	7800 308793	VLADISLAV BELOV	{"email": "v_belov-1976@postgrespro.ru", "phone": "+70967900184"}
0005433804992	6A8315	1721 442964	VERA ANTONOVA	{"phone": "+70857339862"}
0005433804993	A7C6B5	7210 194646	POLINA BORISOVA	{"email": "polina.borisova111965@postgrespro.ru", "phone": "+70277171084"}
0005433804994	249B08	1494 794036	NADEZHDA PAVLOVA	{"email": "pavlova.n.1974@postgrespro.ru", "phone": "+70298838764"}
0005433804995	249B08	2996 862151	ELENA ZOTOVA	{"email": "zotovae.02031980@postgrespro.ru", "phone": "+70966500795"}
0005433804996	FAA0B1	1283 278660	RAISA RODIONOVA	{"phone": "+70124913961"}
0005433804997	56B79F	5095 607566	ELMIRA NIKITINA	{"email": "e-nikitina_09091963@postgrespro.ru", "phone": "+70352630686"}
0005433804998	56B79F	0909 136958	YURIY GORBUNOV	{"phone": "+70864662857"}
0005433804999	56B79F	7069 688610	NINA DENISOVA	{"phone": "+70433266806"}
0005433805000	61DFD9	2284 664475	ALEKSANDR STEPANOV	{"phone": "+70825111817"}
0005433805001	3C1101	2696 176917	NIKOLAY EGOROV	{"email": "egorovnikolay-20021973@postgrespro.ru", "phone": "+70085178728"}
0005433805002	22A515	2511 300095	ELIZAVETA MOISEEVA	{"phone": "+70665598372"}
0005433805003	22A515	1246 188385	VADIM KOZLOV	{"phone": "+70397985064"}
0005433805004	D4F872	9636 543599	ILYA NAZAROV	{"email": "i.nazarov.09011968@postgrespro.ru", "phone": "+70621273939"}
0005433805005	D4F872	5592 017741	MARINA KOLESNIKOVA	{"phone": "+70211217987"}
0005433805006	9FF445	0579 499402	ZLATA KRASNOVA	{"email": "krasnova-z_051963@postgrespro.ru", "phone": "+70374731831"}
0005433805007	B0AE07	7339 642929	ANNA BELOVA	{"email": "belova.anna-08051974@postgrespro.ru", "phone": "+70557440946"}
0005433805008	B0AE07	4931 138804	NATALYA IVANOVA	{"email": "natalya_ivanova-011970@postgrespro.ru", "phone": "+70708408347"}
0005433805009	BB2C0A	4753 946097	EKATERINA TITOVA	{"phone": "+70066898998"}
0005433805010	BB2C0A	9173 245683	ALEKSANDR ALEKSANDROV	{"email": "aleksandr.aleksandrov-1980@postgrespro.ru", "phone": "+70756131184"}
0005433805011	BF7A4A	7577 854981	ALEVTINA MIKHAYLOVA	{"phone": "+70654776160"}
0005433805012	A67C53	8425 237399	VLADIMIR KUZNECOV	{"phone": "+70165526320"}
0005433805013	6CC5F1	9275 081498	NIKITA SIDOROV	{"phone": "+70994748763"}
0005433805014	E111E9	6772 388411	SERGEY ZAKHAROV	{"phone": "+70425869626"}
0005433805015	7B432A	3913 384073	YURIY VASILEV	{"email": "yuriy.vasilev_1976@postgrespro.ru", "phone": "+70546266253"}
0005433805016	2490CF	4982 342918	MIKHAIL ILIN	{"email": "ilin.m-1970@postgrespro.ru", "phone": "+70396481857"}
0005433805017	3630F2	6886 428188	FAINA ARKHIPOVA	{"phone": "+70035766339"}
0005433805018	9EB3EA	6176 370161	ANDREY DAVYDOV	{"email": "davydov.andrey_1972@postgrespro.ru", "phone": "+70841046739"}
0005433805019	9EB3EA	3573 227647	VLADIMIR SEMENOV	{"phone": "+70021805170"}
0005433805020	E6B533	8174 553486	VALENTIN KUZMIN	{"phone": "+70756606317"}
0005433805021	E6B533	5404 115918	NATALYA VOLKOVA	{"email": "volkova_n_01061964@postgrespro.ru", "phone": "+70907517822"}
0005433805022	819D76	0506 750824	GEORGIY KOZLOV	{"email": "kozlov.g-1975@postgrespro.ru", "phone": "+70954953096"}
0005433805023	819D76	3094 770713	OLGA SIDOROVA	{"email": "olgasidorova.091979@postgrespro.ru", "phone": "+70237349539"}
0005433805024	9BE785	7515 347286	ALEKSANDR KONOVALOV	{"phone": "+70299215901"}
0005433805025	9BE785	4015 692239	GALINA SERGEEVA	{"phone": "+70231147219"}
0005433805026	9BE785	2341 068275	EVGENIY KOZLOV	{"email": "ekozlov-061960@postgrespro.ru", "phone": "+70111911051"}
0005433805027	E2346E	3958 964504	TATYANA VOLKOVA	{"phone": "+70311446042"}
0005433805028	F9FC6E	5940 686021	NINA AFANASEVA	{"email": "nafanaseva-20051981@postgrespro.ru", "phone": "+70991404359"}
0005433805029	F9FC6E	1082 547596	IRINA ROMANOVA	{"phone": "+70329464084"}
0005433805030	F3D203	5007 390375	ILYA SOROKIN	{"phone": "+70245167810"}
0005433805031	2123CC	2049 093446	TATYANA POPOVA	{"email": "popovat.111968@postgrespro.ru", "phone": "+70078596557"}
0005433805032	A5B2D4	2135 846297	DAMIR KOZLOV	{"phone": "+70058677393"}
0005433805033	A8E7FD	5506 164161	GENNADIY SOKOLOV	{"phone": "+70684090633"}
0005433805034	A8E7FD	1152 200676	SVETLANA FOMINA	{"email": "sfomina-101970@postgrespro.ru", "phone": "+70565400024"}
0005433805035	F5BCC7	9917 259585	MAKSIM SEMENOV	{"email": "m-semenov.12101982@postgrespro.ru", "phone": "+70779274033"}
0005433805036	FEB8EA	8242 856264	MAKSIM FEDOROV	{"email": "fedorov_m.1970@postgrespro.ru", "phone": "+70514717045"}
0005433805037	01730F	2018 558466	VLADIMIR GUSEV	{"email": "gusevv041975@postgrespro.ru", "phone": "+70565308054"}
0005433805038	B8A024	4432 262881	SERGEY IVANOV	{"email": "sergey.ivanov1971@postgrespro.ru", "phone": "+70433793284"}
0005433805039	0B6DC0	5382 499552	SVETLANA EFREMOVA	{"phone": "+70292635352"}
0005433805040	2848A1	5250 354503	ALEKSANDR POPOV	{"email": "popov.a-1985@postgrespro.ru", "phone": "+70538198690"}
0005433805041	A406AE	2760 648613	MIKHAIL FEDOTOV	{"email": "fedotov.mikhail121973@postgrespro.ru", "phone": "+70623496136"}
0005433805042	D7CECC	8072 584486	IRINA ILINA	{"email": "iilina-071982@postgrespro.ru", "phone": "+70891965163"}
0005433805043	D7CECC	4556 794398	ANNA SEMENOVA	{"phone": "+70747931772"}
0005433805044	62D94B	1495 128757	SERGEY VOROBEV	{"phone": "+70046091998"}
0005433805045	CC8A55	2615 803351	ANASTASIYA ALEKSEEVA	{"phone": "+70170098483"}
0005433805046	CC8A55	6045 110406	DMITRIY PAVLOV	{"phone": "+70653562018"}
0005433805047	5D608B	9692 640815	MARIYA KOROLEVA	{"phone": "+70496285907"}
0005433805048	362C14	6624 660288	ALEKSEY STEPANOV	{"email": "stepanov-aleksey19111979@postgrespro.ru", "phone": "+70398973800"}
0005433805049	C31092	4539 240132	IVAN KUZNECOV	{"email": "ikuznecov-061975@postgrespro.ru", "phone": "+70980920156"}
0005433805050	87BE0F	7726 353260	ALEKSANDR POPOV	{"phone": "+70352589745"}
0005433805051	87BE0F	6623 662053	INNA CHERNOVA	{"phone": "+70200707261"}
0005433805052	3AC5DE	2924 029790	GALINA ALEKSANDROVA	{"phone": "+70416919198"}
0005433805053	3AC5DE	4870 452551	ALEKSEY GRIGOREV	{"email": "alekseygrigorev.111970@postgrespro.ru", "phone": "+70670686391"}
0005433805054	91BA3C	5351 212923	SERGEY SCHERBAKOV	{"email": "sergey_scherbakov.121975@postgrespro.ru", "phone": "+70171481767"}
0005433805055	C3D4C8	9185 669961	VLADIMIR VASILEV	{"email": "vvasilev-111975@postgrespro.ru", "phone": "+70184671899"}
0005433805056	C3D4C8	0359 772742	ALEKSANDRA MAKAROVA	{"email": "aleksandra_makarova1975@postgrespro.ru", "phone": "+70234428017"}
0005433805057	CA6E1E	5569 562099	ALEKSANDR BARANOV	{"email": "baranovaleksandr.111982@postgrespro.ru", "phone": "+70640781559"}
0005433805058	CA6E1E	2272 821722	VYACHESLAV KOZLOV	{"email": "vyacheslavkozlov_10061969@postgrespro.ru", "phone": "+70785377482"}
0005433805059	3C8D58	0798 882359	MARINA TROFIMOVA	{"phone": "+70329690967"}
0005433805060	3C8D58	9714 156087	ZINAIDA FILIPPOVA	{"email": "filippovaz-1975@postgrespro.ru", "phone": "+70252902168"}
0005433805061	C81BCB	1388 572269	LIDIYA KALININA	{"email": "lidiyakalinina_1970@postgrespro.ru", "phone": "+70338481573"}
0005433805062	C81BCB	5070 569642	MARGARITA LEBEDEVA	{"phone": "+70593657655"}
0005433805063	E89E32	1750 631033	LARISA MATVEEVA	{"phone": "+70226642065"}
0005433805064	7D1D9A	8191 755589	NADEZHDA NAUMOVA	{"email": "naumova-nadezhda_30051970@postgrespro.ru", "phone": "+70702176384"}
0005433805065	FE7666	5054 466547	SERGEY GUSEV	{"phone": "+70801589545"}
0005433805066	FE7666	2781 374612	DANIIL GUSEV	{"phone": "+70886442337"}
0005433805067	EF94CE	8098 611165	OKSANA ZAKHAROVA	{"phone": "+70651692482"}
0005433805068	EF94CE	1448 059783	OLGA IVANOVA	{"phone": "+70556683070"}
0005433805069	A4D7C7	9446 135941	AMIR MAKSIMOV	{"phone": "+70859080508"}
0005433805070	389E8F	5935 432787	NIKITA IVANOV	{"email": "ivanov-n1965@postgrespro.ru", "phone": "+70970117704"}
0005433805071	389E8F	3590 819856	TATYANA FOMINA	{"email": "fominat.101967@postgrespro.ru", "phone": "+70515520364"}
0005433805072	20F8C3	1280 693079	ELENA POLYAKOVA	{"phone": "+70098777168"}
0005433805073	20F8C3	9973 606038	MARIYA KUDRYASHOVA	{"phone": "+70284311184"}
0005433805074	52FE6F	7098 908766	ALEKSEY KUZNECOV	{"phone": "+70369622628"}
0005433805075	FD7F96	7982 670549	GALINA POPOVA	{"phone": "+70547177568"}
0005433805076	A33C62	1265 967923	VADIM KUZMIN	{"phone": "+70974111426"}
0005433805077	A2489A	9614 797749	EKATERINA IVANOVA	{"phone": "+70088439952"}
0005433805078	38DF20	6346 485294	ALEKSANDR POPOV	{"email": "apopov.19091974@postgrespro.ru", "phone": "+70684423360"}
0005433805079	D1A4EA	0430 120377	PETR SERGEEV	{"phone": "+70122932303"}
0005433805080	83CA8C	4551 394505	GALINA SIDOROVA	{"phone": "+70474063032"}
0005433805081	54370A	1305 802535	ELIZAVETA DANILOVA	{"email": "danilovaelizaveta24081974@postgrespro.ru", "phone": "+70958949798"}
0005433805082	01A3D0	5098 702968	ALEKSANDR TIMOFEEV	{"email": "a.timofeev_041974@postgrespro.ru", "phone": "+70294984021"}
0005433805083	03134A	3794 383750	MIKHAIL KISELEV	{"phone": "+70764710698"}
0005433805084	03134A	9289 008033	ELENA IVANOVA	{"email": "elena-ivanova-121979@postgrespro.ru", "phone": "+70975331327"}
0005433805085	1C9DE1	1771 325621	SVETLANA AKIMOVA	{"phone": "+70362517633"}
0005433805086	7BDEC8	5980 937939	NATALYA OSIPOVA	{"email": "osipovan.1981@postgrespro.ru", "phone": "+70818775004"}
0005433805087	84FDB2	5528 217826	IRINA AFANASEVA	{"email": "iafanaseva_08111980@postgrespro.ru", "phone": "+70869785271"}
0005433805088	84FDB2	8636 068716	VLADIMIR IVANOV	{"email": "v.ivanov-091977@postgrespro.ru", "phone": "+70476098743"}
0005433805089	1A0AEC	6488 979641	OLGA STEPANOVA	{"email": "stepanova-olga-041976@postgrespro.ru", "phone": "+70426848231"}
0005433805090	19FB44	2987 513502	ANATOLIY KUZMIN	{"phone": "+70648599933"}
0005433805091	19FB44	5141 726194	VALENTINA ROMANOVA	{"phone": "+70058525220"}
0005433805092	767B45	9722 333430	ZOYA BORISOVA	{"phone": "+70885862174"}
0005433805093	767B45	7376 009181	ANTON KOROLEV	{"email": "korolev.anton.021958@postgrespro.ru", "phone": "+70702914534"}
0005433805094	2E47C5	7598 101537	EKATERINA VASILEVA	{"email": "vasileva-e31121965@postgrespro.ru", "phone": "+70511900486"}
0005433805095	9A55BB	0537 850193	EVGENIYA CHERNOVA	{"phone": "+70145161387"}
0005433805096	9A55BB	9938 680783	ILONA DAVYDOVA	{"email": "davydovailona06071973@postgrespro.ru", "phone": "+70498823681"}
0005433805097	917C2F	1294 037087	LYUDMILA ORLOVA	{"phone": "+70894616736"}
0005433805098	917C2F	1018 073123	VALENTINA NIKIFOROVA	{"email": "nikiforova.v_1964@postgrespro.ru", "phone": "+70061432033"}
0005433805099	5C5532	4676 417113	ANASTASIYA ZAKHAROVA	{"phone": "+70952362301"}
0005433805100	4AC79C	5375 080160	ELENA KOROLEVA	{"phone": "+70915936650"}
0005433805101	DE7880	7831 672299	IRINA DANILOVA	{"phone": "+70632567644"}
0005433805102	DE7880	4925 793452	OLEG ALEKSANDROV	{"phone": "+70998131282"}
0005433805103	DE7880	0477 413433	NATALIYA IVANOVA	{"email": "nataliya_ivanova.26081967@postgrespro.ru", "phone": "+70066945966"}
0005433805104	FEEA87	3395 319301	MILANA KARPOVA	{"phone": "+70565339014"}
0005433805105	FC8501	1613 744910	ALEKSANDR ZHUKOV	{"phone": "+70277138830"}
0005433805106	F9869E	7835 670723	OLGA KISELEVA	{"phone": "+70127801806"}
0005433805107	54B131	1215 866105	VLADIMIR YAKOVLEV	{"email": "yakovlev-vladimir-091963@postgrespro.ru", "phone": "+70950794654"}
0005433805108	992340	3040 631262	IRINA NESTEROVA	{"email": "nesterova-i.031975@postgrespro.ru", "phone": "+70850231917"}
0005433805109	86E22A	3585 339114	MARIYA MIRONOVA	{"phone": "+70157297591"}
0005433805110	86E22A	2569 838516	VIKTORIYA TIKHONOVA	{"email": "v-tikhonova_011974@postgrespro.ru", "phone": "+70813858634"}
0005433805111	86E22A	9188 448892	OLGA MATVEEVA	{"email": "o_matveeva.051968@postgrespro.ru", "phone": "+70959058596"}
0005433805112	53D68E	6273 798409	DARYA SOLOVEVA	{"email": "soloveva.d021976@postgrespro.ru", "phone": "+70540624350"}
0005433805113	53D68E	2450 549523	ANASTASIYA FOMINA	{"phone": "+70633569949"}
0005433805114	24E1DC	0005 494920	ALEKSEY IVANOV	{"email": "aleksey-ivanov.041972@postgrespro.ru", "phone": "+70357867097"}
0005433805115	A90D4F	0578 052972	ANATOLIY MOROZOV	{"phone": "+70263776705"}
0005433805116	DB5594	1802 676402	ANDREY FOMIN	{"email": "andrey_fomin_061972@postgrespro.ru", "phone": "+70484238300"}
0005433805117	910B0D	5316 360258	MAKSIM NAZAROV	{"phone": "+70795567105"}
0005433805118	910B0D	4297 949335	ALEKSEY VASILEV	{"phone": "+70763412768"}
0005433805119	8AB335	0985 873685	VLADIMIR VASILEV	{"phone": "+70354540604"}
0005433805120	0BC740	5662 007721	SVETLANA MOISEEVA	{"phone": "+70042443277"}
0005433805121	ACAE82	4129 032626	SERGEY KARPOV	{"email": "s_karpov_03031975@postgrespro.ru", "phone": "+70606385403"}
0005433805122	ACAE82	3872 764311	IRINA IVANOVA	{"email": "irinaivanova-03051983@postgrespro.ru", "phone": "+70279353701"}
0005433805123	85D03E	8630 649696	KLAVDIYA KARPOVA	{"email": "karpova_klavdiya-021982@postgrespro.ru", "phone": "+70237319898"}
0005433805124	F1DDC1	3438 113111	YURIY OSIPOV	{"email": "yosipov.1971@postgrespro.ru", "phone": "+70727531853"}
0005433805125	F1DDC1	1120 305466	VERA KONOVALOVA	{"email": "vera-konovalova.061970@postgrespro.ru", "phone": "+70445408277"}
0005433805126	F1370F	0225 932810	ANASTASIYA GAVRILOVA	{"phone": "+70604078738"}
0005433805127	B8A05D	9165 035036	DANIIL DAVYDOV	{"phone": "+70925487468"}
0005433805128	B8A05D	3971 639946	ANNA POPOVA	{"email": "popova-a.12081961@postgrespro.ru", "phone": "+70301990529"}
0005433805129	B8A05D	9334 719668	YULIYA EGOROVA	{"email": "egorova_yuliya11081979@postgrespro.ru", "phone": "+70349302775"}
0005433805130	0E715E	6812 251540	ARTEM CHERNOV	{"phone": "+70855412147"}
0005433805131	9F21E8	8676 052627	ALEKSEY ZAYCEV	{"email": "zaycevaleksey-05101965@postgrespro.ru", "phone": "+70125340969"}
0005433805132	A2334A	7558 374560	VITALIY POPOV	{"email": "popov_v_091976@postgrespro.ru", "phone": "+70837153145"}
0005433805133	DABC12	8990 335730	OKSANA ZAKHAROVA	{"phone": "+70861105803"}
0005433805134	10E808	8046 789639	DMITRIY SERGEEV	{"email": "d_sergeev091968@postgrespro.ru", "phone": "+70881935980"}
0005433805135	5561E2	9788 373145	NADEZHDA SCHERBAKOVA	{"phone": "+70031443201"}
0005433805136	122A1C	8625 117103	VALENTINA ZAYCEVA	{"phone": "+70195294765"}
0005433805137	9255AC	3404 750835	OKSANA KOZLOVA	{"email": "oksana.kozlova.17111973@postgrespro.ru", "phone": "+70347588098"}
0005433805138	22F32E	9587 162587	ELIZAVETA KUZMINA	{"email": "kuzmina-elizaveta-1983@postgrespro.ru", "phone": "+70660001298"}
0005433805139	CFE5E0	8300 616219	SVETLANA MALYSHEVA	{"email": "malyshevasvetlana_021981@postgrespro.ru", "phone": "+70270545588"}
0005433805140	FDE42F	8173 834954	ELENA NIKOLAEVA	{"email": "enikolaeva_1982@postgrespro.ru", "phone": "+70875886750"}
0005433805141	75926D	9386 502700	MARAT PETROV	{"phone": "+70673415418"}
0005433805142	75926D	8279 914406	TAMARA PETROVA	{"email": "tamara-petrova_1960@postgrespro.ru", "phone": "+70094407980"}
0005433805143	7D2E92	9282 132639	VERA PAVLOVA	{"phone": "+70248931928"}
0005433805144	7D2E92	0727 531391	LARISA NIKOLAEVA	{"email": "nikolaeva.l-121983@postgrespro.ru", "phone": "+70076948413"}
0005433805145	A1CE85	7010 529408	LYUDMILA TIKHONOVA	{"email": "lyudmila_tikhonova.02081978@postgrespro.ru", "phone": "+70666181996"}
0005433805146	AA104A	8367 626707	SERGEY KRASNOV	{"phone": "+70649587346"}
0005433805147	AA104A	6654 351163	ILNAR KOZLOV	{"email": "ilnar-kozlov.061969@postgrespro.ru", "phone": "+70962830390"}
0005433805148	B4BC7E	2725 064399	ALEKSEY TARASOV	{"email": "tarasov-aleksey.31011967@postgrespro.ru", "phone": "+70756877948"}
0005433805149	11B60A	2200 489362	NATALYA VASILEVA	{"email": "vasileva-n_1972@postgrespro.ru", "phone": "+70654530496"}
0005433805150	7916D7	2112 230538	NIKITA ZAYCEV	{"phone": "+70959632472"}
0005433805151	7916D7	5357 670156	VIKTOR FROLOV	{"phone": "+70295221463"}
0005433805152	14C1DE	7564 594380	DMITRIY PAVLOV	{"email": "d_pavlov-091960@postgrespro.ru", "phone": "+70298627935"}
0005433805153	0AA586	2362 862386	YURIY VOLKOV	{"phone": "+70233922620"}
0005433805154	736C12	4273 503143	ALEVTINA SEMENOVA	{"phone": "+70688308548"}
0005433805155	C5F009	8550 456710	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov.101960@postgrespro.ru", "phone": "+70983777072"}
0005433805156	66BC29	6627 793562	YURIY ABRAMOV	{"phone": "+70432314142"}
0005433805157	98044F	2420 967700	ELENA IVANOVA	{"email": "ivanova-elena101964@postgrespro.ru", "phone": "+70251830240"}
0005433805270	2D8E1B	8820 932323	ANATOLIY KUZNECOV	{"phone": "+70603470388"}
0005433805158	18021D	3357 405205	LYUBOV KUZNECOVA	{"email": "kuznecova_l.1967@postgrespro.ru", "phone": "+70655905095"}
0005433805159	F018C2	8962 425250	OLEG KUZNECOV	{"phone": "+70928520876"}
0005433805160	347184	2089 255143	DMITRIY FEDOROV	{"email": "d.fedorov.101977@postgrespro.ru", "phone": "+70912629006"}
0005433805161	5DAAA9	8635 272712	DENIS PETROV	{"phone": "+70463539651"}
0005433805162	9CE3D8	8887 751094	ALEKSEY FEDOROV	{"email": "fedorova_26111987@postgrespro.ru", "phone": "+70760089219"}
0005433805163	9CE3D8	7183 746719	TIMUR NOVIKOV	{"phone": "+70891986126"}
0005433805164	37D126	6864 047068	YURIY SOKOLOV	{"email": "yuriy-sokolov-10091962@postgrespro.ru", "phone": "+70502766328"}
0005433805165	0C4045	8403 281551	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova.1983@postgrespro.ru", "phone": "+70089677013"}
0005433805166	BC2207	6115 192168	ELENA EFREMOVA	{"email": "elena.efremova14081973@postgrespro.ru", "phone": "+70484732661"}
0005433805167	BC2207	2240 971175	NIKOLAY CHERNOV	{"email": "chernovnikolay05091979@postgrespro.ru", "phone": "+70672346807"}
0005433805168	DCED33	2678 010255	VLADIMIR ALEKSANDROV	{"email": "aleksandrov_v091971@postgrespro.ru", "phone": "+70304040936"}
0005433805169	DCED33	5534 603381	LIDIYA ZAYCEVA	{"email": "zayceva.lidiya.1965@postgrespro.ru", "phone": "+70565346817"}
0005433805170	55D990	0346 166586	SERGEY FROLOV	{"phone": "+70891819376"}
0005433805171	55D990	8602 085274	ALENA KUZNECOVA	{"email": "a-kuznecova.21021960@postgrespro.ru", "phone": "+70759765595"}
0005433805172	B20ADE	1714 241610	DARYA ABRAMOVA	{"phone": "+70413065603"}
0005433805173	B20ADE	3560 628655	OLGA MATVEEVA	{"phone": "+70553691514"}
0005433805174	5E26D8	1191 607004	ELIZAVETA DMITRIEVA	{"email": "dmitrievae.20011981@postgrespro.ru", "phone": "+70786166812"}
0005433805175	FAD792	3602 852371	ANASTASIYA DANILOVA	{"phone": "+70482001512"}
0005433805176	2BC1AA	4225 425151	INESSA LOGINOVA	{"phone": "+70923371797"}
0005433805177	DF3B43	5527 634076	MARIANNA NIKOLAEVA	{"email": "m-nikolaeva.13041976@postgrespro.ru", "phone": "+70743834579"}
0005433805178	DF3B43	5947 901867	EKATERINA NESTEROVA	{"email": "nesterova-ekaterina.021964@postgrespro.ru", "phone": "+70491688084"}
0005433805179	3272D6	3403 834585	ELIZAVETA KUZNECOVA	{"phone": "+70289092885"}
0005433805180	925CB9	5564 122357	VIKTORIYA KARPOVA	{"email": "karpova_viktoriya.1976@postgrespro.ru", "phone": "+70663464287"}
0005433805181	82459A	9752 068112	VALENTINA ERMAKOVA	{"phone": "+70607788005"}
0005433805182	5C1CA3	7611 790876	ANASTASIYA SIDOROVA	{"phone": "+70568042499"}
0005433805183	31C41D	4208 728262	ALEKSANDR BARANOV	{"phone": "+70209725513"}
0005433805184	BEE52B	7492 645910	IVAN SMIRNOV	{"email": "smirnovivan.101969@postgrespro.ru", "phone": "+70693930865"}
0005433805185	DE9A88	9868 764162	ALEKSANDR FROLOV	{"phone": "+70170228700"}
0005433805186	DE9A88	7508 695537	VLADIMIR SCHERBAKOV	{"phone": "+70304592029"}
0005433805187	242567	7727 439841	ELENA NOVIKOVA	{"phone": "+70598019892"}
0005433805188	242567	1396 419671	ALEKSEY SCHERBAKOV	{"phone": "+70446894355"}
0005433805189	F08A88	3574 576290	VIKTOR POPOV	{"email": "vpopov.051976@postgrespro.ru", "phone": "+70828210563"}
0005433805190	F08A88	9839 866491	ALEKSANDR POPOV	{"phone": "+70186169373"}
0005433805191	38E467	8537 430944	EVGENIYA MOROZOVA	{"phone": "+70658235900"}
0005433805192	38E467	8057 217277	MARGARITA EGOROVA	{"phone": "+70676754407"}
0005433805193	186CF0	9193 902216	LYUBOV GERASIMOVA	{"email": "gerasimova.lyubov-09011968@postgrespro.ru", "phone": "+70915356876"}
0005433805194	1670B4	6095 470936	VYACHESLAV KAZAKOV	{"phone": "+70300554663"}
0005433805195	3A4FA7	7414 403087	ARTEM MIRONOV	{"email": "mironov.artem.1968@postgrespro.ru", "phone": "+70389260393"}
0005433805196	3A4FA7	6855 749933	LIDIYA VOROBEVA	{"phone": "+70392832451"}
0005433805197	D7BA89	0496 580708	ELENA SEMENOVA	{"phone": "+70217463881"}
0005433805198	1383FF	2846 539513	OLGA MALYSHEVA	{"phone": "+70320838552"}
0005433805199	1383FF	1609 451644	DMITRIY ANTONOV	{"email": "dmitriy_antonov_02101968@postgrespro.ru", "phone": "+70862846775"}
0005433805200	1383FF	6014 995138	NATALYA SAVELEVA	{"phone": "+70623526186"}
0005433805201	A5904B	8780 133903	TATYANA VASILEVA	{"email": "vasileva-tatyana.1978@postgrespro.ru", "phone": "+70551715568"}
0005433805202	A5904B	6640 992797	ROSTISLAV MAKSIMOV	{"email": "r_maksimov.20101971@postgrespro.ru", "phone": "+70686906542"}
0005433805203	A5904B	4087 683311	VALERIY VOROBEV	{"phone": "+70809230580"}
0005433805204	944384	1435 019218	YULIYA FILIPPOVA	{"email": "y-filippova041969@postgrespro.ru", "phone": "+70326850425"}
0005433805205	0780D2	1218 740252	DARYA GAVRILOVA	{"phone": "+70814932347"}
0005433805206	0780D2	9606 277532	LYUBOV FEDOROVA	{"email": "lfedorova27031973@postgrespro.ru", "phone": "+70598042535"}
0005433805207	0780D2	6560 892234	ANTONINA BELOVA	{"email": "antonina_belova.23111986@postgrespro.ru", "phone": "+70157098700"}
0005433805208	6602AF	3085 636935	NIKOLAY TIMOFEEV	{"email": "timofeev_n1972@postgrespro.ru", "phone": "+70686022402"}
0005433805209	265AD4	8094 971244	VYACHESLAV RODIONOV	{"phone": "+70314566815"}
0005433805210	265AD4	1097 461491	OLESYA STEPANOVA	{"phone": "+70571238664"}
0005433805211	422103	5086 035502	NINA KOZLOVA	{"phone": "+70943846790"}
0005433805212	100A2D	7667 099034	OLGA MATVEEVA	{"phone": "+70281683035"}
0005433805213	F61B20	1921 524021	ARTEM ANDREEV	{"email": "andreevartem-22031971@postgrespro.ru", "phone": "+70753529803"}
0005433805214	C9CA34	5641 192514	DMITRIY MOROZOV	{"email": "dmitriy_morozov1968@postgrespro.ru", "phone": "+70888250214"}
0005433805215	C9CA34	5429 477325	ALENA SERGEEVA	{"email": "alena-sergeeva1981@postgrespro.ru", "phone": "+70534947761"}
0005433805216	907569	2956 593550	ANNA FOMINA	{"phone": "+70372719570"}
0005433805217	301918	8234 315569	DMITRIY KUZMIN	{"email": "dmitriy-kuzmin1984@postgrespro.ru", "phone": "+70275595852"}
0005433805218	877B41	8074 837801	ALLA STEPANOVA	{"phone": "+70570708936"}
0005433805219	A6037C	1387 614376	MIKHAIL PAVLOV	{"email": "m.pavlov_09091969@postgrespro.ru", "phone": "+70028101861"}
0005433805220	4A5DD7	5530 514091	ELENA TIMOFEEVA	{"phone": "+70387189292"}
0005433805221	4A5DD7	1421 378114	ARTEMIY KUZNECOV	{"phone": "+70491679504"}
0005433805222	B3FF8D	9085 797178	SOFYA TITOVA	{"email": "titova-sofya05031973@postgrespro.ru", "phone": "+70829270178"}
0005433805223	5603F4	1512 784707	NADEZHDA ARKHIPOVA	{"phone": "+70896389732"}
0005433805224	0B16FF	0630 856122	GENNADIY BORISOV	{"email": "g-borisov1970@postgrespro.ru", "phone": "+70431711066"}
0005433805225	0B16FF	8233 409644	VIKTOR GUSEV	{"phone": "+70323633790"}
0005433805226	0B16FF	3741 918817	REGINA AKIMOVA	{"phone": "+70081148935"}
0005433805227	F8495A	8971 957194	STANISLAV KISELEV	{"email": "kiselev.stanislav_1964@postgrespro.ru", "phone": "+70761776652"}
0005433805228	F8495A	3807 800631	VALERIY KARPOV	{"email": "karpovv_051959@postgrespro.ru", "phone": "+70372564135"}
0005433805229	9CA606	1547 275128	DARYA IVANOVA	{"email": "ivanova.d_08051978@postgrespro.ru", "phone": "+70370139000"}
0005433805230	47FFA1	6976 060419	ALEKSEY POPOV	{"email": "popov.aleksey-091982@postgrespro.ru", "phone": "+70761054469"}
0005433805231	B9E4A4	2108 446122	TAMARA KUZNECOVA	{"phone": "+70474413638"}
0005433805232	B9E4A4	6018 007323	OLGA EFIMOVA	{"email": "efimovaolga041961@postgrespro.ru", "phone": "+70495073211"}
0005433805233	15CF8F	7334 978792	LYUBOV NESTEROVA	{"email": "l_nesterova.1974@postgrespro.ru", "phone": "+70516551925"}
0005433805234	706FF8	7847 675356	VALENTINA KOMAROVA	{"email": "vkomarova-1963@postgrespro.ru", "phone": "+70332313563"}
0005433805235	1466D0	8709 918449	EGOR ANTONOV	{"phone": "+70537884212"}
0005433805236	1466D0	5774 117084	OLGA CHERNOVA	{"email": "chernova.olga-30011983@postgrespro.ru", "phone": "+70019516498"}
0005433805237	B14BAC	3512 254621	EVGENIY POPOV	{"email": "popov-e28061974@postgrespro.ru", "phone": "+70669393680"}
0005433805238	49E80F	0561 867125	LYUBOV KUZNECOVA	{"email": "l.kuznecova13091990@postgrespro.ru", "phone": "+70189237067"}
0005433805239	49E80F	2804 677553	VLADIMIR FEDOTOV	{"email": "v_fedotov1980@postgrespro.ru", "phone": "+70611450703"}
0005433805240	D62C38	2445 336487	ALEKSANDR DAVYDOV	{"phone": "+70829633921"}
0005433805241	D62C38	9000 506560	ALENA ZOTOVA	{"email": "zotovaa_1971@postgrespro.ru", "phone": "+70488328502"}
0005433805242	78C776	6693 087446	ALEKSEY MELNIKOV	{"email": "aleksey.melnikov.051972@postgrespro.ru", "phone": "+70186621142"}
0005433805243	0F1517	3048 478080	LILIYA OSIPOVA	{"email": "osipova-l01111968@postgrespro.ru", "phone": "+70576042728"}
0005433805244	0F1517	8959 137485	ANATOLIY GRIGOREV	{"phone": "+70465794455"}
0005433805245	0F1517	7943 295325	ALEKSANDR CHERNOV	{"email": "a-chernov13091967@postgrespro.ru", "phone": "+70820053163"}
0005433805246	9B49D9	7536 349749	VLADIMIR KISELEV	{"email": "kiselev-vladimir.25081980@postgrespro.ru", "phone": "+70354967809"}
0005433805247	AC551D	8298 480929	GALINA BELOVA	{"phone": "+70354097721"}
0005433805248	A6A270	7996 788957	ROZA MASLOVA	{"email": "maslova_roza-101964@postgrespro.ru", "phone": "+70579292639"}
0005433805249	183F3F	4962 109106	ANASTASIYA KOZLOVA	{"email": "anastasiya_kozlova.15061963@postgrespro.ru", "phone": "+70765483520"}
0005433805250	2E591B	8612 833319	GENNADIY KARPOV	{"phone": "+70540137819"}
0005433805251	2E591B	3307 930935	ELENA POPOVA	{"phone": "+70143473269"}
0005433805252	BF7829	8660 882258	IRINA ALEKSEEVA	{"email": "irina.alekseeva.17011980@postgrespro.ru", "phone": "+70316221103"}
0005433805253	F9CEEA	6340 272412	IGOR MOROZOV	{"phone": "+70358107762"}
0005433805254	801EB2	9897 141508	LIDIYA MATVEEVA	{"phone": "+70527725256"}
0005433805255	801EB2	8058 522169	ANATOLIY DAVYDOV	{"phone": "+70473825162"}
0005433805256	8AB215	0264 472287	VLADIMIR NIKOLAEV	{"phone": "+70514366950"}
0005433805257	8303D7	4467 808631	VALENTIN SMIRNOV	{"email": "smirnovv.19101981@postgrespro.ru", "phone": "+70816371168"}
0005433805258	9BB43F	9109 286902	TATYANA TARASOVA	{"email": "t-tarasova_1977@postgrespro.ru", "phone": "+70580649427"}
0005433805259	086EBA	0701 755635	VITALIY DENISOV	{"email": "vitaliydenisov26041965@postgrespro.ru", "phone": "+70300503700"}
0005433805260	EF43DB	1519 686757	VYACHESLAV MAKAROV	{"phone": "+70812075988"}
0005433805261	F5A26E	1733 995223	SERGEY MAKAROV	{"email": "sergey.makarov1970@postgrespro.ru", "phone": "+70943181935"}
0005433805262	F5A26E	1130 371997	IRINA NIKOLAEVA	{"phone": "+70504180497"}
0005433805263	A51879	7083 628395	ILYA CHERNOV	{"email": "chernov_i-13061984@postgrespro.ru", "phone": "+70917572868"}
0005433805264	349418	9244 780186	MARIYA PETROVA	{"phone": "+70554583087"}
0005433805265	77C5CA	1830 701395	SERGEY BORISOV	{"email": "borisov.sergey1963@postgrespro.ru", "phone": "+70771746408"}
0005433805266	77C5CA	3641 809227	ALEKSEY KUZMIN	{"phone": "+70380771987"}
0005433805267	589D07	4329 783955	EVGENIYA NAUMOVA	{"email": "naumova-evgeniya-10071972@postgrespro.ru", "phone": "+70249269776"}
0005433805268	F2BC44	2497 942032	MIKHAIL KRASNOV	{"email": "krasnovm121968@postgrespro.ru", "phone": "+70122162727"}
0005433805269	2D8E1B	1743 395835	IRINA FADEEVA	{"email": "fadeeva_irina.07031957@postgrespro.ru", "phone": "+70834585716"}
0005433805271	E864D0	2227 911034	VALENTINA CHERNOVA	{"email": "chernova.valentina.091965@postgrespro.ru", "phone": "+70865001244"}
0005433805272	AEEE0B	0090 999416	VLADIMIR KULIKOV	{"email": "v_kulikov.23111970@postgrespro.ru", "phone": "+70339743723"}
0005433805273	AEEE0B	2688 401918	KONSTANTIN SEMENOV	{"email": "konstantin.semenov041977@postgrespro.ru", "phone": "+70170069779"}
0005433805274	ECC9F9	8959 439921	MARIYA POPOVA	{"phone": "+70439425030"}
0005433805275	52A85B	2459 686212	ALEKSANDR GRIGOREV	{"phone": "+70080895119"}
0005433805276	EC4F2B	8132 160478	NATALIYA FROLOVA	{"phone": "+70978244961"}
0005433805277	EA7D84	1465 118608	OLGA BORISOVA	{"email": "o_borisova.1968@postgrespro.ru", "phone": "+70177642126"}
0005433805278	FE4B6B	3097 563158	LYUBOV ERMAKOVA	{"email": "lyubovermakova30061978@postgrespro.ru", "phone": "+70296023455"}
0005433805279	FE4B6B	7466 469516	NIKOLAY FROLOV	{"phone": "+70438267717"}
0005433805280	503CC3	9862 168666	ALENA NOVIKOVA	{"email": "novikova_alena031978@postgrespro.ru", "phone": "+70145851913"}
0005433805281	77961F	6082 839852	IRINA GRISHINA	{"phone": "+70176530057"}
0005433805282	77961F	2452 656664	TATYANA MOROZOVA	{"email": "tmorozova.1972@postgrespro.ru", "phone": "+70523933368"}
0005433805283	72A5B4	7383 336351	NINA SEMENOVA	{"email": "nina_semenova_021972@postgrespro.ru", "phone": "+70964400784"}
0005433805284	4A2454	4479 664103	MAKSIM EGOROV	{"email": "egorovmaksim111970@postgrespro.ru", "phone": "+70116071612"}
0005433805285	489175	9622 829644	MARIYA NOVIKOVA	{"email": "m_novikova-04111961@postgrespro.ru", "phone": "+70713213893"}
0005433805286	F7A5F6	4073 212877	ROMAN EGOROV	{"phone": "+70762987721"}
0005433805287	D39A65	5913 962225	ANDREY NAUMOV	{"email": "naumov-andrey061972@postgrespro.ru", "phone": "+70338418469"}
0005433805288	D39A65	4920 451232	SVETLANA MATVEEVA	{"email": "matveeva_s.071969@postgrespro.ru", "phone": "+70656652211"}
0005433805289	D39A65	9275 568677	VLADIMIR BARANOV	{"phone": "+70971143418"}
0005433805290	81FF6A	4601 608741	OLGA ALEKSEEVA	{"phone": "+70398449773"}
0005433805291	D5554B	5696 274953	ALEKSANDRA KUZMINA	{"phone": "+70630525516"}
0005433805292	D5554B	2703 333421	TAMARA TIMOFEEVA	{"email": "timofeeva_tamara1978@postgrespro.ru", "phone": "+70402610926"}
0005433805293	F16950	6124 257588	VALERIY KAZAKOV	{"email": "v.kazakov-021966@postgrespro.ru", "phone": "+70051516683"}
0005433805294	F16950	7526 968900	ANDREY SOKOLOV	{"phone": "+70699982963"}
0005433805295	A74714	4077 337957	ELENA STEPANOVA	{"phone": "+70818153932"}
0005433805296	7A4E83	5408 228398	YULIYA SERGEEVA	{"email": "sergeeva.yuliya-21071976@postgrespro.ru", "phone": "+70766964203"}
0005433805297	AF263F	2310 567696	GULNARA POPOVA	{"phone": "+70426238586"}
0005433805298	38A815	1181 879362	VERA FROLOVA	{"email": "verafrolova_1969@postgrespro.ru", "phone": "+70530631736"}
0005433805299	0A7575	2098 555145	ANNA ALEKSANDROVA	{"phone": "+70468082467"}
0005433805300	5F8636	5538 656868	ALEKSANDR GAVRILOV	{"email": "aleksandr_gavrilov-20081978@postgrespro.ru", "phone": "+70933237486"}
0005433805301	5F8636	4270 134011	ARTEM POPOV	{"phone": "+70876162843"}
0005433805302	0811C1	8250 159299	DANILA MELNIKOV	{"phone": "+70615585779"}
0005433805303	0811C1	5236 460628	DMITRIY NIKOLAEV	{"email": "nikolaev.d-071970@postgrespro.ru", "phone": "+70722471503"}
0005433805304	67DDE4	2713 412956	SERGEY KUZNECOV	{"phone": "+70770558232"}
0005433805305	67DDE4	2773 122239	ANDREY FOMIN	{"email": "a_fomin.1979@postgrespro.ru", "phone": "+70246415754"}
0005433805306	DAC9A5	5190 261791	VITALIY MOROZOV	{"email": "v-morozov.1983@postgrespro.ru", "phone": "+70339247863"}
0005433805307	DAC9A5	7862 752091	IGOR BORISOV	{"phone": "+70486048992"}
0005433805308	6C6046	3949 338776	TATYANA BELYAEVA	{"email": "tbelyaeva1969@postgrespro.ru", "phone": "+70790919119"}
0005433805309	6C6046	3181 580321	SOFIYA PETROVA	{"phone": "+70742036453"}
0005433805310	1DF90A	0837 947274	NATALYA NIKOLAEVA	{"email": "nikolaeva.n071968@postgrespro.ru", "phone": "+70764042639"}
0005433805311	77037D	4620 159945	ELISEY GUSEV	{"email": "gusev_e_031973@postgrespro.ru", "phone": "+70699516020"}
0005433805312	060A44	5984 188487	LYUBOV SERGEEVA	{"email": "lyubov-sergeeva1979@postgrespro.ru", "phone": "+70834390707"}
0005433805313	060A44	0369 362096	VALERIYA VASILEVA	{"email": "vasilevavaleriya.1979@postgrespro.ru", "phone": "+70345805198"}
0005433805314	32BF03	7553 369830	OLGA MELNIKOVA	{"email": "o-melnikova-1979@postgrespro.ru", "phone": "+70754613629"}
0005433805315	260706	8856 039726	VYACHESLAV ZAYCEV	{"email": "vzaycev_30031960@postgrespro.ru", "phone": "+70093322091"}
0005433805316	AC6A11	3282 014230	ALEKSANDR MAKAROV	{"phone": "+70257283138"}
0005433805317	2100F4	0799 876558	NAILYA KOZLOVA	{"email": "n.kozlova-01081983@postgrespro.ru", "phone": "+70355581049"}
0005433805318	94C6C7	9981 890159	MARINA ERMAKOVA	{"phone": "+70020159457"}
0005433805319	D86D9A	7182 867297	OLGA KOROLEVA	{"email": "koroleva.o_1995@postgrespro.ru", "phone": "+70684741131"}
0005433805320	80E6A3	0512 105511	IVAN SMIRNOV	{"phone": "+70087814382"}
0005433805321	80E6A3	3073 241731	DMITRIY MIKHAYLOV	{"email": "dmitriy_mikhaylov-07111974@postgrespro.ru", "phone": "+70371014680"}
0005433805322	9E06FB	1174 609579	OLGA MALYSHEVA	{"email": "olgamalysheva-16121975@postgrespro.ru", "phone": "+70506281835"}
0005433805323	2A34B2	8034 891242	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr_1981@postgrespro.ru", "phone": "+70583107683"}
0005433805324	EE236F	0215 666912	TATYANA GUSEVA	{"email": "guseva.t_05011969@postgrespro.ru", "phone": "+70544953070"}
0005433805325	9C8AA4	1083 714559	MARIYA SEMENOVA	{"phone": "+70911792272"}
0005433805437	11C057	0795 349919	MAKSIM KUZMIN	{"phone": "+70971995734"}
0005433805326	136D64	8054 350289	NIKOLAY KONOVALOV	{"email": "konovalov_nikolay16081967@postgrespro.ru", "phone": "+70862486621"}
0005433805327	697B11	4466 772674	SVETLANA ZAYCEVA	{"email": "svetlana-zayceva.1975@postgrespro.ru", "phone": "+70562840345"}
0005433805328	BD5407	9373 600797	ALEKSANDR KUZMIN	{"email": "kuzmin.a_1971@postgrespro.ru", "phone": "+70797682178"}
0005433805329	96EE5A	7199 027224	ANVAR DENISOV	{"phone": "+70585776602"}
0005433805330	1E3709	6373 968939	IRINA NOVIKOVA	{"email": "irina-novikova_101979@postgrespro.ru", "phone": "+70437871401"}
0005433805331	FC87AB	1056 179568	MARIYA KOROLEVA	{"email": "korolevamariya.02091962@postgrespro.ru", "phone": "+70181782038"}
0005433805332	FC87AB	3060 320098	ALENA YAKOVLEVA	{"email": "alenayakovleva_1971@postgrespro.ru", "phone": "+70685867683"}
0005433805333	9E542B	7975 808787	OLGA NOVIKOVA	{"email": "novikovao-061971@postgrespro.ru", "phone": "+70700342200"}
0005433805334	9E542B	8229 176859	TATYANA ANTONOVA	{"phone": "+70622977785"}
0005433805335	767C5F	0318 388602	VALERIY FOMIN	{"phone": "+70767286357"}
0005433805336	767C5F	9357 202799	TAMARA NESTEROVA	{"email": "tamara-nesterova18011975@postgrespro.ru", "phone": "+70592537395"}
0005433805337	8C0F0F	0085 327097	DENIS FROLOV	{"phone": "+70140004356"}
0005433805338	67ABDD	7047 520457	ELIZAVETA GORBUNOVA	{"email": "gorbunovae.1970@postgrespro.ru", "phone": "+70344095519"}
0005433805339	D929E9	7684 937494	MARIYA TARASOVA	{"email": "tarasova_m.28121967@postgrespro.ru", "phone": "+70302417572"}
0005433805340	D19D0A	5617 262194	VIKTOR SOLOVEV	{"phone": "+70262025098"}
0005433805341	AA87DE	0057 401661	TATYANA TIKHONOVA	{"phone": "+70890897132"}
0005433805342	F2CCE0	4775 963936	GALINA KUZNECOVA	{"email": "kuznecova.galina.19101969@postgrespro.ru", "phone": "+70283483161"}
0005433805343	F2CCE0	0853 149812	TAMARA KOZLOVA	{"phone": "+70804169252"}
0005433805344	01DBE9	6120 181700	EKATERINA MAKSIMOVA	{"phone": "+70847509098"}
0005433805345	01DBE9	2424 073682	DAVID YAKOVLEV	{"phone": "+70152029717"}
0005433805346	01DBE9	8944 076695	IRINA OSIPOVA	{"email": "osipova.i.031976@postgrespro.ru", "phone": "+70994657650"}
0005433805347	3D09A9	1954 947445	ALEKSEY ANDREEV	{"phone": "+70212608991"}
0005433805348	2C5E74	3710 107088	OLGA NESTEROVA	{"phone": "+70911845446"}
0005433805349	CACFAA	7494 582030	VALENTINA NESTEROVA	{"email": "nesterova-v1975@postgrespro.ru", "phone": "+70929975137"}
0005433805350	CACFAA	9190 432543	ROMAN PAVLOV	{"phone": "+70948031945"}
0005433805351	E29109	5491 007425	YURIY NAZAROV	{"email": "yuriy_nazarov1970@postgrespro.ru", "phone": "+70693145062"}
0005433805352	E29109	8257 235725	ROZALIYA KUZNECOVA	{"phone": "+70589958643"}
0005433805353	1DD6B6	9519 499924	ANDREY NIKITIN	{"phone": "+70646566235"}
0005433805354	1DD6B6	1377 549626	TATYANA BARANOVA	{"phone": "+70496761333"}
0005433805355	B1582B	3121 232564	OLGA GAVRILOVA	{"email": "olga-gavrilova-04081985@postgrespro.ru", "phone": "+70404340125"}
0005433805356	E47D12	8145 653122	ANASTASIYA NOVIKOVA	{"phone": "+70218085612"}
0005433805357	17EC82	6587 320085	ANDREY PAVLOV	{"email": "pavlov.a_23121970@postgrespro.ru", "phone": "+70000368999"}
0005433805358	20F1CC	4677 327161	ALEKSANDR SCHERBAKOV	{"phone": "+70700817084"}
0005433805359	B22CB6	3168 795938	LEV KOROLEV	{"email": "korolev.l_30071973@postgrespro.ru", "phone": "+70094733058"}
0005433805360	B22CB6	1747 838051	ARTEM MELNIKOV	{"phone": "+70753106637"}
0005433805361	998AC4	1852 564867	GALINA FADEEVA	{"email": "fadeevagalina-31031976@postgrespro.ru", "phone": "+70098039119"}
0005433805362	3AC5C9	8005 991819	YURIY NOVIKOV	{"email": "ynovikov-27091969@postgrespro.ru", "phone": "+70522460977"}
0005433805363	392821	2293 225415	VALERIYA RODIONOVA	{"email": "rodionova.v-091971@postgrespro.ru", "phone": "+70602366356"}
0005433805364	4D145A	0820 934496	ALEKSANDR BARANOV	{"email": "abaranov_15101974@postgrespro.ru", "phone": "+70937803784"}
0005433805365	4D145A	5815 291656	VLADIMIR TIKHONOV	{"phone": "+70063625703"}
0005433805366	4D145A	7764 428395	ANDREY KISELEV	{"email": "a.kiselev.1967@postgrespro.ru", "phone": "+70740105924"}
0005433805367	985797	9309 688088	OLGA BOGDANOVA	{"phone": "+70346353890"}
0005433805368	04CD6E	9177 504047	SERGEY FILIPPOV	{"email": "s_filippov.1961@postgrespro.ru", "phone": "+70294160480"}
0005433805369	303CDC	1334 964878	VERA MATVEEVA	{"email": "vera.matveeva_101976@postgrespro.ru", "phone": "+70794073785"}
0005433805370	5A996E	2512 645497	ALIYA SMIRNOVA	{"phone": "+70489611958"}
0005433805371	5A996E	4219 849811	NIKOLAY MATVEEV	{"email": "matveev_n.031970@postgrespro.ru", "phone": "+70497748548"}
0005433805372	63BC7D	5588 766521	NIKOLAY RODIONOV	{"phone": "+70693729284"}
0005433805373	B5C885	1314 075383	LYUDMILA PETROVA	{"email": "l-petrova_111978@postgrespro.ru", "phone": "+70260890218"}
0005433805374	87448B	9713 184845	TAISIYA ABRAMOVA	{"email": "tabramova051977@postgrespro.ru", "phone": "+70673121761"}
0005433805375	BF159D	4862 353533	NATALYA TIKHONOVA	{"phone": "+70589308981"}
0005433805376	26A203	7487 414495	ANDREY KOZLOV	{"phone": "+70229055856"}
0005433805377	26A203	8920 641772	ALEKSANDR DMITRIEV	{"email": "dmitrieva.1989@postgrespro.ru", "phone": "+70841420474"}
0005433805378	FD4D2D	8281 009636	ANDREY GRIGOREV	{"email": "grigorev_a.25061966@postgrespro.ru", "phone": "+70231320340"}
0005433805379	0C0FE0	9886 325359	EMILIYA ZAKHAROVA	{"email": "zakharova_e1970@postgrespro.ru", "phone": "+70438551872"}
0005433805380	1E3F39	3923 424544	IRINA ALEKSANDROVA	{"phone": "+70599063892"}
0005433805381	1E3F39	6226 293608	EVGENIY KOZLOV	{"email": "kozlov.evgeniy031987@postgrespro.ru", "phone": "+70256013302"}
0005433805382	17ECC6	2594 851065	LEV ROMANOV	{"email": "romanovl-071988@postgrespro.ru", "phone": "+70489203300"}
0005433805383	0CB00B	7978 427386	SOFYA LAZAREVA	{"email": "lazareva-s-081983@postgrespro.ru", "phone": "+70803471536"}
0005433805384	0CB00B	8041 193740	TAMARA MAKAROVA	{"email": "t_makarova1982@postgrespro.ru", "phone": "+70937645410"}
0005433805385	91CF3C	7548 286236	TATYANA TIKHONOVA	{"email": "t_tikhonova-1963@postgrespro.ru", "phone": "+70487700697"}
0005433805386	91CF3C	2228 115688	NATALYA FILIPPOVA	{"email": "filippovanatalya_031973@postgrespro.ru", "phone": "+70317372378"}
0005433805387	1D8770	3367 769542	KIRILL MOISEEV	{"phone": "+70578927636"}
0005433805388	1D8770	9159 469630	VALERIYA ROMANOVA	{"email": "v-romanova_121976@postgrespro.ru", "phone": "+70358526387"}
0005433805389	1D8770	8666 158792	ALEKSANDRA ORLOVA	{"email": "orlova-aleksandra-18021981@postgrespro.ru", "phone": "+70263109682"}
0005433805390	A27A15	7804 342549	OLEG KUZNECOV	{"phone": "+70426940303"}
0005433805391	9EAE6E	2454 673579	TATYANA SMIRNOVA	{"email": "tatyana.smirnova1975@postgrespro.ru", "phone": "+70546904624"}
0005433805392	6DC3FE	3552 777839	ANDREY ALEKSEEV	{"phone": "+70048900484"}
0005433805393	6DC3FE	6439 235467	MATVEY NOVIKOV	{"email": "m-novikov-1982@postgrespro.ru", "phone": "+70086274485"}
0005433805394	572029	6320 038091	ANNA SOROKINA	{"phone": "+70494324212"}
0005433805395	572029	1570 503930	MARAT KARPOV	{"phone": "+70876116946"}
0005433805396	4F6682	6945 477123	VLADISLAV DENISOV	{"email": "denisov_v10101966@postgrespro.ru", "phone": "+70296279620"}
0005433805397	B37066	5600 803706	ANATOLIY SOKOLOV	{"email": "a.sokolov_121974@postgrespro.ru", "phone": "+70732161862"}
0005433805398	F6C546	0656 917983	ALENA ZAKHAROVA	{"email": "zakharova-alena1978@postgrespro.ru", "phone": "+70851766956"}
0005433805399	9A91C5	5177 201206	VALERIY VOLKOV	{"email": "v_volkov_041965@postgrespro.ru", "phone": "+70109346544"}
0005433805400	4859F8	6896 585580	ALEKSANDR SIDOROV	{"phone": "+70518401820"}
0005433805401	4859F8	6706 755933	GALINA ROMANOVA	{"email": "g.romanova09121977@postgrespro.ru", "phone": "+70865042447"}
0005433805402	8EC58E	5710 053076	MIKHAIL KISELEV	{"email": "m.kiselev-1972@postgrespro.ru", "phone": "+70380674536"}
0005433805403	387469	6480 162709	PETR PETROV	{"email": "ppetrov-1962@postgrespro.ru", "phone": "+70288213149"}
0005433805404	387469	8761 473124	SVETLANA EGOROVA	{"phone": "+70412733220"}
0005433805405	387469	0518 065181	MARIYA KONDRATEVA	{"email": "mariya.kondrateva-011971@postgrespro.ru", "phone": "+70280673946"}
0005433805406	F643A3	5457 947583	VALERIY VASILEV	{"email": "valeriy-vasilev061969@postgrespro.ru", "phone": "+70127338852"}
0005433805407	F643A3	6580 166211	RAFAIL MIKHAYLOV	{"phone": "+70940686638"}
0005433805408	C62392	3909 648471	SVETLANA EFREMOVA	{"phone": "+70803921109"}
0005433805409	69DA7D	1897 560891	TAMARA KOMAROVA	{"email": "komarova-tamara18041978@postgrespro.ru", "phone": "+70289002675"}
0005433805410	A2A9DC	2740 212607	ALEKSANDR NIKOLAEV	{"phone": "+70765965517"}
0005433805411	D23BA9	8602 678745	NIKOLAY BORISOV	{"email": "nborisov_121966@postgrespro.ru", "phone": "+70217966506"}
0005433805412	51290F	6765 344620	ANATOLIY POPOV	{"email": "popov-a-08081970@postgrespro.ru", "phone": "+70741534319"}
0005433805413	01FEF0	3066 208468	VLADISLAV DENISOV	{"email": "denisov_v1963@postgrespro.ru", "phone": "+70242495092"}
0005433805414	400F62	1323 655711	GALINA IVANOVA	{"email": "ivanova-galina_041983@postgrespro.ru", "phone": "+70973704152"}
0005433805415	912FA1	0747 764098	TAMARA EGOROVA	{"phone": "+70455188253"}
0005433805416	912FA1	6449 232807	YULIYA ARKHIPOVA	{"phone": "+70162523082"}
0005433805417	A6A631	4125 325631	VALENTINA VASILEVA	{"phone": "+70963158969"}
0005433805418	87CC6A	8354 132556	ELENA GAVRILOVA	{"phone": "+70053459377"}
0005433805419	87CC6A	0682 953383	SNEZHANA NIKOLAEVA	{"email": "snezhana-nikolaeva_011971@postgrespro.ru", "phone": "+70301947073"}
0005433805420	87CC6A	5133 465751	ALEKSANDR MELNIKOV	{"email": "a_melnikov.1975@postgrespro.ru", "phone": "+70237838707"}
0005433805421	521939	4491 970062	YULIYA SCHERBAKOVA	{"email": "y.scherbakova_1973@postgrespro.ru", "phone": "+70906808826"}
0005433805422	CBF6F2	7269 236188	RAISA KUZNECOVA	{"phone": "+70724272499"}
0005433805423	98870E	9600 158409	ANASTASIYA FROLOVA	{"email": "anastasiya_frolova1967@postgrespro.ru", "phone": "+70075459688"}
0005433805424	091DFD	1837 022801	NAILYA IVANOVA	{"email": "nailyaivanova.091970@postgrespro.ru", "phone": "+70072933308"}
0005433805425	B5D82B	8884 241975	NELLI KARPOVA	{"phone": "+70216303459"}
0005433805426	8F3DF0	5227 482453	EKATERINA KARPOVA	{"phone": "+70295647725"}
0005433805427	F80C0C	5179 053063	NATALYA SOKOLOVA	{"phone": "+70481098627"}
0005433805428	FBED40	8271 283704	IRINA LAZAREVA	{"email": "i.lazareva_1967@postgrespro.ru", "phone": "+70398743235"}
0005433805429	FBED40	8745 687066	TIMUR KOZLOV	{"phone": "+70345927458"}
0005433805430	BCBC65	3922 824567	TATYANA KARPOVA	{"phone": "+70655011006"}
0005433805431	431E7A	2159 455859	ANASTASIYA ANTONOVA	{"email": "antonova.anastasiya.091965@postgrespro.ru", "phone": "+70151071390"}
0005433805432	1C12A0	3857 511345	SEMEN KISELEV	{"phone": "+70015333522"}
0005433805433	1C12A0	2098 226202	MARTA IVANOVA	{"email": "ivanova-marta04121969@postgrespro.ru", "phone": "+70185934960"}
0005433805434	FF523E	8776 255761	SERGEY PAVLOV	{"email": "pavlov-s.1974@postgrespro.ru", "phone": "+70044972824"}
0005433805435	FF523E	3732 861406	KSENIYA NAUMOVA	{"email": "k.naumova-1968@postgrespro.ru", "phone": "+70853913102"}
0005433805436	5576CF	7745 525506	ALEKSANDR GUSEV	{"email": "gusevaleksandr.19101965@postgrespro.ru", "phone": "+70649384017"}
0005433805438	16C59A	7204 428539	VALENTIN KARPOV	{"email": "valentin-karpov061967@postgrespro.ru", "phone": "+70493844425"}
0005433805439	16C59A	8598 095231	VASILIY PETROV	{"phone": "+70899587060"}
0005433805440	16C59A	1143 509128	NADEZHDA EFREMOVA	{"email": "n-efremova_13081994@postgrespro.ru", "phone": "+70430361998"}
0005433805441	CF7D71	1401 594690	LEV MAKAROV	{"phone": "+70715838446"}
0005433805442	CF7D71	9777 926298	KIRILL BORISOV	{"phone": "+70733597545"}
0005433805443	C4648E	2559 577153	MAKSIM MIKHAYLOV	{"phone": "+70103181898"}
0005433805444	3233C9	5415 995083	VITALIY KUZNECOV	{"email": "kuznecov-v091971@postgrespro.ru", "phone": "+70513719505"}
0005433805445	9A2881	7224 461750	NATALYA NOVIKOVA	{"email": "natalyanovikova-1975@postgrespro.ru", "phone": "+70586054440"}
0005433805446	893B8D	6251 013280	LIDIYA FEDOROVA	{"email": "fedorova_lidiya.031974@postgrespro.ru", "phone": "+70548641295"}
0005433805447	D52D82	7743 931577	NATALYA MATVEEVA	{"phone": "+70965043203"}
0005433805448	194A78	5156 510824	EKATERINA KULIKOVA	{"phone": "+70348538039"}
0005433805449	3C9EC1	6878 421354	NATALYA MALYSHEVA	{"email": "malysheva-n-1969@postgrespro.ru", "phone": "+70909657742"}
0005433805450	096DFB	7470 092821	VASILIY ZAYCEV	{"email": "vasiliyzaycev08021971@postgrespro.ru", "phone": "+70696088415"}
0005433805451	096DFB	4797 007755	MATVEY SCHERBAKOV	{"phone": "+70547516439"}
0005433805452	8283EE	9793 568884	DENIS GORBUNOV	{"email": "d_gorbunov-16031972@postgrespro.ru", "phone": "+70967878478"}
0005433805453	73A5B9	5103 929611	PETR NAZAROV	{"phone": "+70877372317"}
0005433805454	D373AA	8909 172103	VERA DMITRIEVA	{"phone": "+70489527918"}
0005433805455	1A5450	3568 217972	NATALIYA BORISOVA	{"email": "n_borisova-29071973@postgrespro.ru", "phone": "+70532307073"}
0005433805456	454DDE	6944 346322	VALENTINA KULIKOVA	{"phone": "+70870337675"}
0005433805457	454DDE	5749 522312	SERGEY ANTONOV	{"email": "antonovs.111968@postgrespro.ru", "phone": "+70828593898"}
0005433805458	30A86C	5008 505513	ELENA KOROLEVA	{"email": "e.koroleva10091969@postgrespro.ru", "phone": "+70033579893"}
0005433805459	B7B3F0	6840 359660	YULIYA GRISHINA	{"email": "grishina.yuliya.1981@postgrespro.ru", "phone": "+70969576543"}
0005433805460	460818	4383 506615	YULIYA POPOVA	{"email": "popova-y_021975@postgrespro.ru", "phone": "+70408914517"}
0005433805461	460818	8566 478294	VLADIMIR POPOV	{"phone": "+70797138554"}
0005433805462	CF9C64	3322 242672	ELENA MAKSIMOVA	{"email": "elena.maksimova.05041966@postgrespro.ru", "phone": "+70199567781"}
0005433805463	C4184D	5357 346177	ALEKSEY ZAKHAROV	{"email": "azakharov.27101973@postgrespro.ru", "phone": "+70485153040"}
0005433805464	C5643B	4692 296902	VALENTINA KRASNOVA	{"phone": "+70778960929"}
0005433805465	D43205	4511 017153	ALEKSANDR IVANOV	{"phone": "+70507956389"}
0005433805466	6AA4D9	5179 444535	VLADIMIR MOISEEV	{"email": "vladimir-moiseev.16121971@postgrespro.ru", "phone": "+70596544940"}
0005433805467	542C00	8323 646387	MARIYA FILIPPOVA	{"phone": "+70865010313"}
0005433805468	FFFB18	1761 542466	OKSANA KOLESNIKOVA	{"phone": "+70600425113"}
0005433805469	3504E0	1187 660241	VALENTINA ZAYCEVA	{"email": "v-zayceva.031965@postgrespro.ru", "phone": "+70960622034"}
0005433805470	4CE21C	9507 394591	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-a_26021974@postgrespro.ru", "phone": "+70226386891"}
0005433805471	B3B9FA	0176 674517	MARIYA NOVIKOVA	{"phone": "+70880486356"}
0005433805472	D51501	3287 363374	KAMIL IVANOV	{"phone": "+70651022303"}
0005433805473	904862	1067 089438	NIKITA KRASNOV	{"email": "n.krasnov.081976@postgrespro.ru", "phone": "+70299909205"}
0005433805474	904862	2133 678302	ROZA NAUMOVA	{"phone": "+70936409834"}
0005433805475	FAE3A9	0135 821933	VIKTOR MOROZOV	{"phone": "+70094701233"}
0005433805476	FAE3A9	8301 995459	IVAN GERASIMOV	{"phone": "+70587943465"}
0005433805477	CA01BC	7273 215048	IGOR BARANOV	{"phone": "+70002446007"}
0005433805478	6901E7	3617 971954	ALENA MAKAROVA	{"email": "alena-makarova_04101967@postgrespro.ru", "phone": "+70952499948"}
0005433805479	6901E7	5882 403381	ELENA ISAEVA	{"phone": "+70317538829"}
0005433805480	1683FF	6744 251107	VLADIMIR SIDOROV	{"email": "sidorov.vladimir-091972@postgrespro.ru", "phone": "+70350146941"}
0005433805481	2C92B8	3726 090460	NIKOLAY MELNIKOV	{"email": "melnikov_n051969@postgrespro.ru", "phone": "+70819358017"}
0005433805482	2C92B8	4632 255046	LIDIYA LEBEDEVA	{"phone": "+70289816838"}
0005433805483	44BD83	4897 676749	ANASTASIYA NIKITINA	{"email": "nikitina_anastasiya-101961@postgrespro.ru", "phone": "+70748709508"}
0005433805484	3B0B40	3197 661635	ZOYA NIKIFOROVA	{"email": "z-nikiforova_14041981@postgrespro.ru", "phone": "+70673169264"}
0005433805485	43542E	4807 724417	NIKOLAY NIKITIN	{"phone": "+70234160303"}
0005433805486	43542E	3339 980789	ALLA MELNIKOVA	{"email": "a-melnikova_28051966@postgrespro.ru", "phone": "+70603465006"}
0005433805487	331BDD	2538 919862	ANATOLIY SOLOVEV	{"phone": "+70369896957"}
0005433805488	331BDD	1835 195931	LYUBOV VASILEVA	{"email": "lyubovvasileva031967@postgrespro.ru", "phone": "+70170688170"}
0005433805489	331BDD	4101 658051	VALENTINA LUKYANOVA	{"phone": "+70762775321"}
0005433805490	95A004	0927 417509	ALEKSEY KUZNECOV	{"phone": "+70335685355"}
0005433805491	2EAA3A	9833 375886	KONSTANTIN POPOV	{"email": "popov_k_031985@postgrespro.ru", "phone": "+70596547581"}
0005433805492	1F031C	1459 203976	VERA MAKSIMOVA	{"phone": "+70269765544"}
0005433805493	0E38E3	4237 108894	DMITRIY ABRAMOV	{"email": "abramov.dmitriy.061979@postgrespro.ru", "phone": "+70326093531"}
0005433805494	DB8E7F	3156 734128	VALERIY ILIN	{"email": "ilin.v_1966@postgrespro.ru", "phone": "+70489921530"}
0005433805495	EB18AD	8541 192826	IGOR VOROBEV	{"email": "igorvorobev_051981@postgrespro.ru", "phone": "+70766392244"}
0005433805496	21AA61	4044 215049	IVAN ANTONOV	{"email": "antonovi031978@postgrespro.ru", "phone": "+70899079006"}
0005433805497	C9A8D5	5177 590780	LYUBOV VASILEVA	{"phone": "+70731155034"}
0005433805498	AC269D	2596 229677	ALEKSEY KISELEV	{"phone": "+70652378995"}
0005433805499	846BAF	3159 850980	GEORGIY TIKHONOV	{"email": "g.tikhonov.1975@postgrespro.ru", "phone": "+70207776932"}
0005433805500	846BAF	2090 294353	SVETLANA EFREMOVA	{"email": "s.efremova_20071983@postgrespro.ru", "phone": "+70469757458"}
0005433805501	4319DF	2117 969021	ALENA KRASNOVA	{"email": "alena.krasnova.071968@postgrespro.ru", "phone": "+70653627985"}
0005433805502	F65FB9	9055 824060	PETR CHERNOV	{"phone": "+70878449231"}
0005433805503	231327	9657 875839	TATYANA MATVEEVA	{"phone": "+70513829257"}
0005433805504	918CAF	9540 305894	STANISLAV KUDRYASHOV	{"email": "kudryashov_s-121962@postgrespro.ru", "phone": "+70839361237"}
0005433805505	918CAF	3924 660758	DARYA MAKSIMOVA	{"email": "maksimova_darya.1968@postgrespro.ru", "phone": "+70346173022"}
0005433805506	C81CA9	0709 788606	STANISLAV SEMENOV	{"phone": "+70590500144"}
0005433805507	C81CA9	0549 627153	ILYA GERASIMOV	{"email": "gerasimov_i_071976@postgrespro.ru", "phone": "+70286822781"}
0005433805508	912012	9649 479426	SVETLANA NIKIFOROVA	{"phone": "+70827899251"}
0005433805509	18020B	1156 815289	VLADIMIR MAKAROV	{"phone": "+70053572104"}
0005433805510	A26C81	7005 734188	YULIYA FROLOVA	{"email": "y.frolova-081979@postgrespro.ru", "phone": "+70178718482"}
0005433805511	4AC67F	9734 728042	IVAN POPOV	{"email": "i-popov_111978@postgrespro.ru", "phone": "+70791602867"}
0005433805512	695711	0195 275188	IVAN GORBUNOV	{"email": "i.gorbunov-1960@postgrespro.ru", "phone": "+70511200230"}
0005433805513	695711	9842 721249	VALERIY KONOVALOV	{"phone": "+70763540947"}
0005433805514	B79832	0209 044005	LYUBOV PETROVA	{"email": "petrovalyubov.011970@postgrespro.ru", "phone": "+70400547299"}
0005433805515	B79832	7895 305018	DANIIL ILIN	{"phone": "+70705847560"}
0005433805516	19B7D7	1553 738132	VIKTOR EGOROV	{"email": "viktor.egorov-1973@postgrespro.ru", "phone": "+70826430088"}
0005433805517	A5A3F8	3192 089649	AMIR GUSEV	{"email": "amir_gusev-02121962@postgrespro.ru", "phone": "+70029857880"}
0005433805518	278C1A	1937 264415	EKATERINA TARASOVA	{"email": "etarasova_23021961@postgrespro.ru", "phone": "+70195920207"}
0005433805519	278C1A	2432 890912	NINA ALEKSANDROVA	{"phone": "+70574758932"}
0005433805520	278C1A	6832 583448	LYUBOV VOROBEVA	{"email": "vorobeva.lyubov.03111967@postgrespro.ru", "phone": "+70148158227"}
0005433805521	45515F	8972 814844	SERGEY BORISOV	{"phone": "+70515973840"}
0005433805522	45515F	3072 901481	SOFYA KUZNECOVA	{"email": "sofyakuznecova.1974@postgrespro.ru", "phone": "+70515315832"}
0005433805523	CED4A6	3638 682565	TAISIYA ANTONOVA	{"email": "antonova_taisiya_1971@postgrespro.ru", "phone": "+70027904427"}
0005433805524	CED4A6	1561 386169	NATALYA NOVIKOVA	{"email": "natalyanovikova_17091968@postgrespro.ru", "phone": "+70073034677"}
0005433805525	884A30	0089 161474	VALENTINA DANILOVA	{"phone": "+70797533422"}
0005433805526	D1BD68	6670 882642	NADEZHDA KOVALEVA	{"email": "nadezhda-kovaleva.1978@postgrespro.ru", "phone": "+70759464682"}
0005433805527	D1BD68	4989 106062	GERMAN MIRONOV	{"email": "g.mironov_1965@postgrespro.ru", "phone": "+70805976102"}
0005433805528	180A61	4268 987553	ANNA DAVYDOVA	{"phone": "+70322836608"}
0005433805529	AD4287	0058 332658	RAISA FROLOVA	{"phone": "+70474359724"}
0005433805530	FA6F05	1490 474467	ELENA RODIONOVA	{"email": "rodionova_elena041967@postgrespro.ru", "phone": "+70395907953"}
0005433805531	CA63E9	9892 103569	VASILIY MOROZOV	{"email": "morozovv-1977@postgrespro.ru", "phone": "+70974260361"}
0005433805532	CA63E9	4470 237293	MIKHAIL BELOV	{"email": "m-belov05071979@postgrespro.ru", "phone": "+70876596484"}
0005433805533	285893	9720 018261	NADEZHDA ILINA	{"email": "ilina_n.27121957@postgrespro.ru", "phone": "+70923524985"}
0005433805534	285893	4147 740824	NATALYA MAKSIMOVA	{"phone": "+70668669646"}
0005433805535	028F10	2461 828692	TATYANA PAVLOVA	{"email": "tpavlova.081964@postgrespro.ru", "phone": "+70628159007"}
0005433805536	B3CCB9	7612 731675	ALEKSEY SEMENOV	{"phone": "+70308584325"}
0005433805537	B8C3C4	2209 327270	DMITRIY VLASOV	{"phone": "+70188147567"}
0005433805538	DEBB74	6829 304228	SERGEY MARTYNOV	{"phone": "+70534506989"}
0005433805539	04117B	0980 698295	IRINA KISELEVA	{"phone": "+70034368193"}
0005433805540	AAF820	7380 842088	GALINA TIKHONOVA	{"email": "galina-tikhonova-1974@postgrespro.ru", "phone": "+70078503745"}
0005433805541	4E6C17	3799 359225	ALEKSANDR KULIKOV	{"phone": "+70188566905"}
0005433805542	AB8EBC	3210 867117	SERGEY ORLOV	{"email": "orlov.s.1970@postgrespro.ru", "phone": "+70603377848"}
0005433805543	DF8ECE	1033 134152	SOFIYA KOROLEVA	{"phone": "+70745929220"}
0005433805544	DF8ECE	2792 978089	TAMARA DENISOVA	{"email": "denisovat03111970@postgrespro.ru", "phone": "+70032527761"}
0005433805545	9BF1E2	1922 026814	RIMMA LEBEDEVA	{"email": "lebedevar-25101958@postgrespro.ru", "phone": "+70642666012"}
0005433805546	9BF1E2	1386 954121	IRINA MAKAROVA	{"email": "makarova_irina-011976@postgrespro.ru", "phone": "+70676914895"}
0005433805547	DDD859	1585 581261	OLGA MAKAROVA	{"phone": "+70384923200"}
0005433805548	B70303	3834 315174	ANASTASIYA VOLKOVA	{"email": "volkovaanastasiya1973@postgrespro.ru", "phone": "+70188882154"}
0005433805605	DF82D4	5780 932461	VALENTINA FROLOVA	{"phone": "+70502577823"}
0005433805549	057DDA	4695 438177	OLEG STEPANOV	{"email": "o-stepanov_1978@postgrespro.ru", "phone": "+70267311717"}
0005433805550	81F0E5	3000 705424	SERGEY ANTONOV	{"email": "antonov-sergey-031969@postgrespro.ru", "phone": "+70320631547"}
0005433805551	139C63	0404 109299	ALEKSANDR KRASNOV	{"email": "akrasnov011982@postgrespro.ru", "phone": "+70632244640"}
0005433805552	8653A5	2163 708385	MIKHAIL MEDVEDEV	{"email": "m_medvedev111965@postgrespro.ru", "phone": "+70407592622"}
0005433805553	E3A578	4602 951261	SERGEY VOROBEV	{"email": "sergeyvorobev_011973@postgrespro.ru", "phone": "+70914614265"}
0005433805554	E3A578	6953 611573	ALEKSANDR SHEVCHENKO	{"phone": "+70174996449"}
0005433805555	F37458	7166 434350	ALEKSANDR KONOVALOV	{"email": "aleksandr.konovalov_011978@postgrespro.ru", "phone": "+70978321354"}
0005433805556	69F3E6	8268 336653	KONSTANTIN TARASOV	{"email": "ktarasov_1972@postgrespro.ru", "phone": "+70628349637"}
0005433805557	8BCA25	8491 524259	SERGEY ANTONOV	{"email": "s-antonov_1980@postgrespro.ru", "phone": "+70745259148"}
0005433805558	0C3204	2230 209173	ALEKSANDR PETROV	{"email": "a.petrov-111977@postgrespro.ru", "phone": "+70467197773"}
0005433805559	D8144D	7414 855611	DENIS KISELEV	{"phone": "+70009966055"}
0005433805560	6992D6	0954 520247	SVETLANA ZAKHAROVA	{"email": "zakharovas09121967@postgrespro.ru", "phone": "+70882001208"}
0005433805561	6992D6	3967 463871	RAISA GUSEVA	{"email": "r-guseva-22061967@postgrespro.ru", "phone": "+70464106873"}
0005433805562	733AB6	4297 778475	MARIYA ILINA	{"email": "m_ilina1972@postgrespro.ru", "phone": "+70786969738"}
0005433805563	733AB6	9659 209943	SOFYA SIDOROVA	{"email": "sidorova.sofya-05091971@postgrespro.ru", "phone": "+70815580253"}
0005433805564	C9D4C9	2256 039372	VLADIMIR NAZAROV	{"phone": "+70522067111"}
0005433805565	24F563	0241 327747	OLGA KUZNECOVA	{"phone": "+70772503106"}
0005433805566	A078D5	2366 712294	MARIYA TIKHONOVA	{"phone": "+70736106563"}
0005433805567	7C217B	8667 866277	DANIIL ZAKHAROV	{"phone": "+70023310505"}
0005433805568	7C217B	3789 674963	OLGA RYABOVA	{"email": "olga_ryabova_1968@postgrespro.ru", "phone": "+70618783354"}
0005433805569	77AC6E	0842 256169	IRINA KOZLOVA	{"phone": "+70433334252"}
0005433805570	77AC6E	4261 664799	VLADIMIR MEDVEDEV	{"email": "medvedevv101989@postgrespro.ru", "phone": "+70306993333"}
0005433805571	C6A69D	9343 980336	ALEKSANDR FEDOROV	{"phone": "+70586319960"}
0005433805572	5EEAAF	9555 849323	VLADIMIR SMIRNOV	{"phone": "+70077165722"}
0005433805573	4695C9	0940 179816	ANNA NIKOLAEVA	{"email": "nikolaeva_anna_1967@postgrespro.ru", "phone": "+70740065901"}
0005433805574	210432	4650 601545	ALEKSANDR BORISOV	{"email": "borisov_a_071975@postgrespro.ru", "phone": "+70926088512"}
0005433805575	EA46E4	7986 058851	EKATERINA NOVIKOVA	{"email": "novikova-e.021974@postgrespro.ru", "phone": "+70196024803"}
0005433805576	AB14CC	1380 520333	GALINA NAZAROVA	{"email": "galina-nazarova-21061969@postgrespro.ru", "phone": "+70055574385"}
0005433805577	10412B	1654 667041	LYUDMILA MELNIKOVA	{"email": "melnikova-lyudmila_1974@postgrespro.ru", "phone": "+70867615581"}
0005433805578	10412B	7146 665910	EGOR KOROLEV	{"email": "koroleve051974@postgrespro.ru", "phone": "+70521773875"}
0005433805579	10412B	2930 639233	RENAT ZAYCEV	{"email": "renatzaycev_1972@postgrespro.ru", "phone": "+70478960209"}
0005433805580	10412B	4109 256929	ANNA ZHURAVLEVA	{"phone": "+70540654208"}
0005433805581	C5C318	6861 990424	EKATERINA KUZMINA	{"phone": "+70072864499"}
0005433805582	C5C318	5558 874168	ANNA ANISIMOVA	{"phone": "+70776242999"}
0005433805583	B1F415	0158 764739	NATALYA KUZNECOVA	{"email": "n-kuznecova-11091975@postgrespro.ru", "phone": "+70353413764"}
0005433805584	AB85FE	5050 192336	KIRILL SOLOVEV	{"email": "solovevkirill-061978@postgrespro.ru", "phone": "+70983529853"}
0005433805585	3826D9	7187 219010	GALINA KONOVALOVA	{"email": "galinakonovalova051979@postgrespro.ru", "phone": "+70209711242"}
0005433805586	102018	9832 533449	NIKOLAY FROLOV	{"phone": "+70026411478"}
0005433805587	102018	8844 891374	OLEG KRASNOV	{"phone": "+70638320574"}
0005433805588	A8A9CF	2797 765560	TATYANA GAVRILOVA	{"email": "tatyana-gavrilova-13071967@postgrespro.ru", "phone": "+70152974865"}
0005433805589	5F08CE	9079 689022	NINA ANDREEVA	{"phone": "+70892987746"}
0005433805590	5F08CE	3136 335737	YANA DANILOVA	{"phone": "+70913603632"}
0005433805591	D8A6A0	0140 819984	ALEKSANDR KONOVALOV	{"phone": "+70981235962"}
0005433805592	821D16	0390 234461	YURIY ANDREEV	{"phone": "+70323759470"}
0005433805593	821D16	9075 925447	KRISTINA DENISOVA	{"email": "denisova-k.25081967@postgrespro.ru", "phone": "+70610541334"}
0005433805594	51F063	9769 471269	PETR KUZMIN	{"email": "p.kuzmin_071969@postgrespro.ru", "phone": "+70915830514"}
0005433805595	40276B	6222 935631	ELENA CHERNOVA	{"phone": "+70025144600"}
0005433805596	40276B	9391 034910	ALEKSANDR KARPOV	{"email": "a-karpov21011964@postgrespro.ru", "phone": "+70450336238"}
0005433805597	CB010F	5072 727844	TAMARA EFIMOVA	{"email": "efimova_t_1973@postgrespro.ru", "phone": "+70247941509"}
0005433805598	13E7E7	6374 885553	NIKOLAY NIKITIN	{"email": "n.nikitin-1970@postgrespro.ru", "phone": "+70940955115"}
0005433805599	722CD5	5126 024745	SVETLANA KUZMINA	{"phone": "+70519549707"}
0005433805600	A0CAAA	5075 005821	ANASTASIYA SEMENOVA	{"email": "semenovaa31121973@postgrespro.ru", "phone": "+70130718161"}
0005433805601	A0CAAA	6026 907955	ELEONORA BOGDANOVA	{"phone": "+70465107259"}
0005433805602	0A1840	5502 295194	OLGA ILINA	{"phone": "+70850432287"}
0005433805603	23CE0E	3834 062096	SERGEY YAKOVLEV	{"phone": "+70259668885"}
0005433805604	DF82D4	5317 060004	LYUDMILA KONDRATEVA	{"email": "lkondrateva-1962@postgrespro.ru", "phone": "+70450405998"}
0005433805606	FC8476	1091 595493	DENIS ALEKSEEV	{"email": "alekseev_denis081954@postgrespro.ru", "phone": "+70575495819"}
0005433805607	FC8476	9713 091716	NIKOLAY DMITRIEV	{"phone": "+70159010536"}
0005433805608	38FBF6	0538 151001	VLADIMIR KUZNECOV	{"phone": "+70553264773"}
0005433805609	38FBF6	9575 511535	VERA TIMOFEEVA	{"phone": "+70847741166"}
0005433805610	6DA5F1	9770 105964	ILYA ALEKSANDROV	{"email": "aleksandrov-ilya19041965@postgrespro.ru", "phone": "+70133571966"}
0005433805611	B35D0F	3528 459485	SERGEY KARPOV	{"phone": "+70050586364"}
0005433805612	E3EB27	2522 946417	NINA NIKOLAEVA	{"phone": "+70200061478"}
0005433805613	5141B0	8092 866733	VYACHESLAV FOMIN	{"phone": "+70016923881"}
0005433805725	C97A25	2511 527324	VLADIMIR KISELEV	{"phone": "+70340689672"}
0005433805614	509A66	9200 760672	ANDREY ANTONOV	{"email": "antonovandrey.1967@postgrespro.ru", "phone": "+70459421652"}
0005433805615	509A66	1680 158441	LIDIYA GRISHINA	{"email": "lidiya.grishina-1961@postgrespro.ru", "phone": "+70464963085"}
0005433805616	3BEA69	6547 826402	NIKOLAY PETROV	{"phone": "+70745930180"}
0005433805617	3BEA69	6941 142234	TATYANA KARPOVA	{"phone": "+70641262631"}
0005433805618	30C897	4099 257659	ALBINA KUZNECOVA	{"phone": "+70032743838"}
0005433805619	BBB811	6411 781233	VALENTINA NIKOLAEVA	{"phone": "+70804000821"}
0005433805620	BBB811	2477 624508	DANILA BONDARENKO	{"email": "bondarenko_d-1978@postgrespro.ru", "phone": "+70937319668"}
0005433805621	790CBD	2258 567690	ALEKSEY KOROLEV	{"email": "aleksey-korolev-1965@postgrespro.ru", "phone": "+70355451788"}
0005433805622	ECB258	5828 123359	IVAN KUZNECOV	{"email": "i-kuznecov-15011971@postgrespro.ru", "phone": "+70246730821"}
0005433805623	D3DAD7	4164 727431	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov_1975@postgrespro.ru", "phone": "+70352588071"}
0005433805624	D3DAD7	9040 864364	TAMARA ZAKHAROVA	{"email": "zakharova.t_061989@postgrespro.ru", "phone": "+70414956791"}
0005433805625	0CEB0C	8193 193178	BORIS ORLOV	{"email": "borlov.1977@postgrespro.ru", "phone": "+70245136513"}
0005433805626	8AE7CE	2633 780816	EKATERINA ANDREEVA	{"phone": "+70879021547"}
0005433805627	47BF36	9712 361722	ANASTASIYA SOLOVEVA	{"email": "soloveva_anastasiya-10111975@postgrespro.ru", "phone": "+70371380344"}
0005433805628	0FD388	1724 714424	ANZHELA ROMANOVA	{"phone": "+70940706612"}
0005433805629	8CE9AD	2299 939763	OKSANA ALEKSANDROVA	{"email": "aleksandrova-oksana_041977@postgrespro.ru", "phone": "+70573777921"}
0005433805630	4FBEC6	1618 719497	VITALIY KISELEV	{"email": "vitaliy_kiselev-111974@postgrespro.ru", "phone": "+70649137279"}
0005433805631	4FBEC6	7209 907738	NIKOLAY KOZLOV	{"phone": "+70299053399"}
0005433805632	C734A4	2168 344400	GALINA IVANOVA	{"phone": "+70122208082"}
0005433805633	5362C2	3794 913676	DARYA KONOVALOVA	{"email": "darya.konovalova_08021967@postgrespro.ru", "phone": "+70236511358"}
0005433805634	13634F	9611 295087	OLGA KOROLEVA	{"email": "koroleva_olga.30051968@postgrespro.ru", "phone": "+70302207769"}
0005433805635	774E91	5479 616197	ANDREY PETROV	{"phone": "+70238197940"}
0005433805636	774E91	6475 722266	MAKSIM SERGEEV	{"phone": "+70680073645"}
0005433805637	7E8BF0	3203 834050	OLGA POLYAKOVA	{"email": "o-polyakova.111969@postgrespro.ru", "phone": "+70194744222"}
0005433805638	C17DAE	7102 260624	ANATOLIY MARTYNOV	{"phone": "+70259481077"}
0005433805639	848C78	6150 695819	MIKHAIL FOMIN	{"email": "fomin_mikhail-1976@postgrespro.ru", "phone": "+70557774908"}
0005433805640	848C78	1390 627128	TATYANA NIKITINA	{"email": "t.nikitina.031973@postgrespro.ru", "phone": "+70731743894"}
0005433805641	4101CB	5375 060932	SVETLANA ANDREEVA	{"phone": "+70442519795"}
0005433805642	4101CB	6362 491587	ANDREY STEPANOV	{"email": "stepanovandrey-101975@postgrespro.ru", "phone": "+70800141286"}
0005433805643	CCB957	6797 723354	ANATOLIY IVANOV	{"email": "ivanov_a_071968@postgrespro.ru", "phone": "+70966512876"}
0005433805644	0B2A87	1055 037543	TAMARA ALEKSEEVA	{"email": "t_alekseeva1977@postgrespro.ru", "phone": "+70299233421"}
0005433805645	B98A57	8740 809696	TATYANA TIMOFEEVA	{"email": "ttimofeeva.041973@postgrespro.ru", "phone": "+70716441522"}
0005433805646	60C0A8	3920 445385	MIKHAIL MELNIKOV	{"phone": "+70337390501"}
0005433805647	897244	8955 915279	LARISA BORISOVA	{"email": "borisova.larisa-101974@postgrespro.ru", "phone": "+70852128897"}
0005433805648	B60E8B	4728 248113	IGOR FEDOTOV	{"email": "ifedotov.15071968@postgrespro.ru", "phone": "+70770527402"}
0005433805649	9D47F1	9458 386638	ALEKSEY TIMOFEEV	{"phone": "+70206231670"}
0005433805650	776C1B	4581 242393	RUSTEM NIKITIN	{"phone": "+70644165628"}
0005433805651	CE4E41	9100 026706	ALEKSANDR ABRAMOV	{"phone": "+70181673273"}
0005433805652	E8C881	3970 308903	IRINA VOLKOVA	{"email": "ivolkova.121970@postgrespro.ru", "phone": "+70368819572"}
0005433805653	C48D73	5645 849896	ANNA DENISOVA	{"phone": "+70050228566"}
0005433805654	640AB7	9968 975380	OLESYA FEDOROVA	{"phone": "+70098853871"}
0005433805655	0A3DA5	8028 304994	EVGENIYA KUZMINA	{"email": "evgeniya-kuzmina-051964@postgrespro.ru", "phone": "+70000822815"}
0005433805656	0A3DA5	7912 412210	MARINA MIRONOVA	{"email": "mironova-marina_081974@postgrespro.ru", "phone": "+70994003499"}
0005433805657	4DDD6C	9984 248490	DAVID POPOV	{"email": "dpopov_1961@postgrespro.ru", "phone": "+70440330781"}
0005433805658	589391	8695 582864	OLGA DMITRIEVA	{"phone": "+70798364480"}
0005433805659	2B873E	1577 960298	VLADIMIR YAKOVLEV	{"phone": "+70234583196"}
0005433805660	E4FC30	2460 043765	EDUARD BORISOV	{"email": "e-borisov061967@postgrespro.ru", "phone": "+70854634128"}
0005433805661	36A2B7	8876 326366	NATALYA MAKAROVA	{"email": "makarova_natalya101974@postgrespro.ru", "phone": "+70571553042"}
0005433805662	36A2B7	0849 828433	ANATOLIY FEDOROV	{"phone": "+70582568316"}
0005433805663	36A2B7	8340 752919	SERGEY ALEKSEEV	{"phone": "+70427256378"}
0005433805664	36A2B7	2130 981070	DMITRIY STEPANOV	{"email": "d-stepanov_04051967@postgrespro.ru", "phone": "+70589191410"}
0005433805665	B42F2D	1057 758985	NIKOLAY KARPOV	{"phone": "+70810361445"}
0005433805666	B42F2D	2664 737436	YURIY KUZNECOV	{"phone": "+70081908311"}
0005433805667	B42F2D	5287 426445	MARGARITA VASILEVA	{"email": "vasilevam-1975@postgrespro.ru", "phone": "+70160497153"}
0005433805668	B42F2D	0736 647627	ANTON MIKHAYLOV	{"email": "mikhaylovanton111976@postgrespro.ru", "phone": "+70707416380"}
0005433805781	86441A	4177 174318	OLEG NAZAROV	{"phone": "+70097393897"}
0005433805669	155D3D	7890 538910	ILYA MAKAROV	{"email": "ilya.makarov01081967@postgrespro.ru", "phone": "+70923571546"}
0005433805670	E1A82B	3616 829707	ANNA KUZMINA	{"phone": "+70006031576"}
0005433805671	6BBE9E	4744 567027	VALENTIN GUSEV	{"email": "valentin-gusev1971@postgrespro.ru", "phone": "+70690701017"}
0005433805672	6BBE9E	8283 569550	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov-1962@postgrespro.ru", "phone": "+70852029906"}
0005433805673	6BBE9E	4835 283057	SVETLANA POPOVA	{"phone": "+70381832552"}
0005433805674	C4A803	7774 590642	FELIKS VASILEV	{"phone": "+70298517138"}
0005433805675	789989	6566 373520	NIKITA GRIGOREV	{"phone": "+70144149386"}
0005433805676	789989	7481 935721	LYUDMILA VOLKOVA	{"email": "l-volkova.28071966@postgrespro.ru", "phone": "+70395690742"}
0005433805677	B08621	6782 421509	FARID KONOVALOV	{"email": "konovalov-f_10011978@postgrespro.ru", "phone": "+70761631042"}
0005433805678	B08621	7156 340021	MAKSIM VASILEV	{"phone": "+70121008896"}
0005433805679	11B87D	2452 946556	GALINA MARTYNOVA	{"email": "martynova.galina-26081981@postgrespro.ru", "phone": "+70407752379"}
0005433805680	11B87D	0347 160380	IGOR BONDARENKO	{"phone": "+70259151862"}
0005433805681	800710	0321 116254	MARIYA NOVIKOVA	{"email": "novikova-mariya_14031971@postgrespro.ru", "phone": "+70054735255"}
0005433805682	A9F54E	7573 235834	MARIYA KOLESNIKOVA	{"email": "kolesnikova_m_1970@postgrespro.ru", "phone": "+70310897461"}
0005433805683	A9F54E	8755 585498	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov-1979@postgrespro.ru", "phone": "+70550040240"}
0005433805684	64BE5F	8518 568524	ANASTASIYA ALEKSEEVA	{"email": "alekseeva-a04051969@postgrespro.ru", "phone": "+70161711730"}
0005433805685	3DDAFD	0665 543963	ALENA DAVYDOVA	{"phone": "+70420276755"}
0005433805686	3DDAFD	8139 222515	TAMARA KULIKOVA	{"phone": "+70603587693"}
0005433805687	1E1D62	7326 340487	SERAFIMA KAZAKOVA	{"email": "skazakova16081977@postgrespro.ru", "phone": "+70414513468"}
0005433805688	1E1D62	9408 357228	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov1965@postgrespro.ru", "phone": "+70993113672"}
0005433805689	DE2D01	1182 406193	VALENTINA ZHURAVLEVA	{"phone": "+70566526471"}
0005433805690	D4F313	7094 623835	NATALYA ANDREEVA	{"email": "andreeva-natalya-071969@postgrespro.ru", "phone": "+70261030809"}
0005433805691	2FBB8F	2430 099805	MARIYA EGOROVA	{"email": "m.egorova-04061962@postgrespro.ru", "phone": "+70824568786"}
0005433805692	9FBE03	3668 985739	NIKOLAY ABRAMOV	{"email": "nabramov_1980@postgrespro.ru", "phone": "+70279388127"}
0005433805693	9FBE03	4711 812496	ALEKSANDR MARTYNOV	{"phone": "+70567930263"}
0005433805694	9FBE03	3494 141445	VIKTOR PETROV	{"email": "petrov-v.031981@postgrespro.ru", "phone": "+70639219852"}
0005433805695	348F6A	9220 966296	ZINAIDA TARASOVA	{"email": "zinaida-tarasova-011973@postgrespro.ru", "phone": "+70237029130"}
0005433805696	348F6A	5156 860946	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov_1973@postgrespro.ru", "phone": "+70515487293"}
0005433805697	60B80A	5066 734408	MIKHAIL IVANOV	{"phone": "+70273972054"}
0005433805698	96AB34	5529 989941	YURIY KUDRYASHOV	{"phone": "+70470003969"}
0005433805699	1523F2	4812 819367	LYUBOV MOROZOVA	{"email": "lmorozova_121981@postgrespro.ru", "phone": "+70788625092"}
0005433805700	1523F2	0812 901526	VALERIYA IVANOVA	{"phone": "+70029729860"}
0005433805701	ACF228	4655 659180	GALINA KISELEVA	{"phone": "+70328816735"}
0005433805702	ACF228	6265 371805	SVETLANA ZHUKOVA	{"email": "zhukova.s-1967@postgrespro.ru", "phone": "+70730712936"}
0005433805703	FD34F5	9600 998591	YULIYA ZAYCEVA	{"phone": "+70534728665"}
0005433805704	A3F78E	4304 321088	VLADIMIR IVANOV	{"phone": "+70229996024"}
0005433805705	A3F78E	4074 130994	IGOR YAKOVLEV	{"phone": "+70817708379"}
0005433805706	A3F78E	2973 659821	MARIYA EGOROVA	{"email": "egorovamariya-051965@postgrespro.ru", "phone": "+70691194508"}
0005433805707	745CE0	0009 226108	SERGEY KUZNECOV	{"phone": "+70465508615"}
0005433805708	745CE0	6111 195035	SERGEY MATVEEV	{"email": "s_matveev.1976@postgrespro.ru", "phone": "+70073412906"}
0005433805709	3D1A63	1708 093744	DMITRIY ALEKSEEV	{"phone": "+70310239439"}
0005433805710	3D1A63	3779 002570	VYACHESLAV ALEKSEEV	{"email": "alekseev_vyacheslav1975@postgrespro.ru", "phone": "+70829500342"}
0005433805711	AE85C8	5314 475760	ALEKSANDR KISELEV	{"phone": "+70454668469"}
0005433805712	AE85C8	0817 422941	ROMAN KOZLOV	{"phone": "+70879701620"}
0005433805713	138746	4056 851525	IVAN GORBUNOV	{"email": "gorbunov.ivan_1970@postgrespro.ru", "phone": "+70164641754"}
0005433805714	3E8F88	6351 759229	VASILIY NAZAROV	{"email": "vasiliynazarov.1977@postgrespro.ru", "phone": "+70980313973"}
0005433805715	0E6FB0	0844 626065	NIKOLAY FEDOROV	{"email": "nfedorov_111979@postgrespro.ru", "phone": "+70228167919"}
0005433805716	E9D064	4429 910649	PETR ANTONOV	{"email": "antonovp_21011977@postgrespro.ru", "phone": "+70271315273"}
0005433805717	E9D064	2859 830064	ANNA DMITRIEVA	{"phone": "+70747593869"}
0005433805718	9925BA	7984 915763	MARINA SERGEEVA	{"email": "sergeeva.marina_1970@postgrespro.ru", "phone": "+70098460727"}
0005433805719	826B49	8947 973744	EVGENIY KAZAKOV	{"phone": "+70506631810"}
0005433805720	826B49	5377 060895	REGINA LEBEDEVA	{"email": "lebedeva.regina-1963@postgrespro.ru", "phone": "+70391307108"}
0005433805721	254878	2801 415196	IVAN ZAYCEV	{"email": "izaycev_1979@postgrespro.ru", "phone": "+70720483225"}
0005433805722	254878	3549 905010	ELENA KARPOVA	{"phone": "+70362966111"}
0005433805723	13F7D5	1793 008514	SVETLANA STEPANOVA	{"email": "stepanova.s.031970@postgrespro.ru", "phone": "+70280422388"}
0005433805724	13F7D5	3395 117112	LYUBOV TIMOFEEVA	{"email": "l-timofeeva_1977@postgrespro.ru", "phone": "+70960147202"}
0005433805726	75FDB3	8482 033992	ARTEM AFANASEV	{"email": "afanaseva14081969@postgrespro.ru", "phone": "+70963519965"}
0005433805727	3BEF71	0149 260863	LIDIYA STEPANOVA	{"phone": "+70195292409"}
0005433805728	3BEF71	1148 100928	VLADIMIR MEDVEDEV	{"email": "vladimir_medvedev.20081972@postgrespro.ru", "phone": "+70740018771"}
0005433805729	DC8937	8498 420295	ZOYA PAVLOVA	{"email": "zpavlova_16101960@postgrespro.ru", "phone": "+70019277623"}
0005433805730	DE1E87	8537 477561	SOFIYA PAVLOVA	{"email": "pavlovas-03041975@postgrespro.ru", "phone": "+70368107891"}
0005433805731	0BC513	7835 745894	ANASTASIYA PAVLOVA	{"email": "pavlova-anastasiya24061960@postgrespro.ru", "phone": "+70894328886"}
0005433805732	DF3E86	3900 151202	SVETLANA PETROVA	{"email": "petrova-s_18091973@postgrespro.ru", "phone": "+70235740888"}
0005433805733	B69359	2996 068823	NINA EGOROVA	{"email": "ninaegorova.041974@postgrespro.ru", "phone": "+70257292645"}
0005433805734	3E5332	5069 127456	SVETLANA MIRONOVA	{"phone": "+70259645799"}
0005433805735	3E5332	7830 060741	LILIYA SEMENOVA	{"phone": "+70838419864"}
0005433805736	3ECE13	8249 953672	ELENA GUSEVA	{"phone": "+70565549931"}
0005433805737	3ECE13	7173 840750	VLADIMIR NIKOLAEV	{"phone": "+70330481789"}
0005433805738	9596D8	1007 014600	ELENA ALEKSANDROVA	{"email": "elenaaleksandrova1980@postgrespro.ru", "phone": "+70237382920"}
0005433805739	7968E3	8643 498479	SVETLANA NIKOLAEVA	{"phone": "+70780237743"}
0005433805740	3F2635	7707 347473	NIKOLAY MIRONOV	{"email": "nikolay.mironov-1974@postgrespro.ru", "phone": "+70714584697"}
0005433805741	C20A72	9984 560731	MIKHAIL AFANASEV	{"phone": "+70532595160"}
0005433805742	C20A72	6879 334129	ANNA GORBUNOVA	{"email": "anna.gorbunova-081967@postgrespro.ru", "phone": "+70634336598"}
0005433805743	4985A7	0800 670442	VERA FEDOROVA	{"email": "fedorova.vera_1980@postgrespro.ru", "phone": "+70451406382"}
0005433805744	4985A7	5944 205028	LEONID KONOVALOV	{"email": "leonidkonovalov_101978@postgrespro.ru", "phone": "+70117787253"}
0005433805745	02D02B	7690 819018	TATYANA FEDOROVA	{"phone": "+70734037683"}
0005433805746	AF6E73	2490 587099	ALEKSEY FEDOROV	{"email": "fedorovaleksey.1952@postgrespro.ru", "phone": "+70903485937"}
0005433805747	AF6E73	1239 649115	ALEKSEY EGOROV	{"phone": "+70543805540"}
0005433805748	C55140	3656 552168	VIKTOR GERASIMOV	{"phone": "+70809681326"}
0005433805749	3D4BB6	8498 651188	NADEZHDA SMIRNOVA	{"phone": "+70746592494"}
0005433805750	57F5EB	5077 111546	YULIYA PAVLOVA	{"email": "yuliya_pavlova03111969@postgrespro.ru", "phone": "+70785107969"}
0005433805751	57F5EB	6929 716792	ANASTASIYA FILIPPOVA	{"email": "filippova.anastasiya.061979@postgrespro.ru", "phone": "+70664076210"}
0005433805752	B57A54	7841 793291	GALINA ISAEVA	{"email": "isaevag.101971@postgrespro.ru", "phone": "+70283937647"}
0005433805753	B57A54	3982 409892	ANTONINA IVANOVA	{"email": "ivanova.a.1975@postgrespro.ru", "phone": "+70718836775"}
0005433805754	F45B25	9755 081764	MARIYA ZAYCEVA	{"phone": "+70298920143"}
0005433805755	F45B25	5457 427193	OLGA KUZNECOVA	{"phone": "+70168398665"}
0005433805756	F45B25	4029 603384	ALEKSANDR NOVIKOV	{"email": "novikov-a-04081976@postgrespro.ru", "phone": "+70531815563"}
0005433805757	1789CE	0731 341078	NINA KUZNECOVA	{"email": "kuznecova.n.01111972@postgrespro.ru", "phone": "+70969430826"}
0005433805758	B201AE	7512 169110	GALINA NAUMOVA	{"phone": "+70230358675"}
0005433805759	B201AE	0230 947511	ELENA MELNIKOVA	{"email": "melnikova-elena_1969@postgrespro.ru", "phone": "+70002048527"}
0005433805760	92C80B	6667 784497	VALENTINA KALININA	{"phone": "+70638024930"}
0005433805761	B913F9	4236 198314	TAMARA KAZAKOVA	{"phone": "+70998390223"}
0005433805762	4C1687	9025 927195	ANATOLIY PETROV	{"email": "petrov_anatoliy-111977@postgrespro.ru", "phone": "+70564468581"}
0005433805763	AD228F	9751 992380	EVGENIY IVANOV	{"email": "e_ivanov.28011969@postgrespro.ru", "phone": "+70159601005"}
0005433805764	1E7E54	1857 134514	MARIYA ABRAMOVA	{"email": "abramova.m1971@postgrespro.ru", "phone": "+70176756320"}
0005433805765	20C10E	3958 970605	SVETLANA KRASNOVA	{"phone": "+70998441746"}
0005433805766	803C40	1131 625953	EVGENIY KUZMIN	{"email": "kuzmine-28061960@postgrespro.ru", "phone": "+70376815851"}
0005433805767	C9CE2B	2353 781768	DMITRIY FILIPPOV	{"email": "filippov_dmitriy09111966@postgrespro.ru", "phone": "+70764204479"}
0005433805768	C9CE2B	0629 692421	YURIY TARASOV	{"phone": "+70578564796"}
0005433805769	46A444	4651 894212	VERA ANDREEVA	{"email": "andreeva-vera04031968@postgrespro.ru", "phone": "+70227492193"}
0005433805770	78D835	6246 860933	OLGA VOLKOVA	{"phone": "+70966331026"}
0005433805771	EDB0BB	6965 027433	NINA TIKHONOVA	{"email": "tikhonova-n_29101974@postgrespro.ru", "phone": "+70267430000"}
0005433805772	643C34	3009 825940	TATYANA FILIPPOVA	{"phone": "+70041928581"}
0005433805773	DCE39E	4776 932973	NINA KONDRATEVA	{"email": "nina.kondrateva-06121974@postgrespro.ru", "phone": "+70525957210"}
0005433805774	EC3B02	5563 909179	NIKOLAY ROMANOV	{"email": "romanov-nikolay061970@postgrespro.ru", "phone": "+70440163794"}
0005433805775	EC3B02	1070 961124	OLGA POPOVA	{"email": "popova-o.1974@postgrespro.ru", "phone": "+70887445157"}
0005433805776	1A5748	1180 899395	ANASTASIYA VOLKOVA	{"phone": "+70965491180"}
0005433805777	718135	1439 570357	ARTEM GORBUNOV	{"email": "gorbunovartem.011970@postgrespro.ru", "phone": "+70654949448"}
0005433805778	7B116E	5306 950091	YURIY STEPANOV	{"email": "yuriystepanov-021969@postgrespro.ru", "phone": "+70896584935"}
0005433805779	38E2E7	0751 544346	LIDIYA ZAYCEVA	{"email": "zayceva-l.1985@postgrespro.ru", "phone": "+70409714612"}
0005433805780	12A3FE	0979 443857	IRINA MAKSIMOVA	{"email": "i.maksimova.091971@postgrespro.ru", "phone": "+70915470090"}
0005433805782	A697C3	8909 842964	ZINAIDA SOLOVEVA	{"email": "z.soloveva_13101958@postgrespro.ru", "phone": "+70404339113"}
0005433805783	A697C3	9143 452241	ALEKSEY ROMANOV	{"email": "romanova.021963@postgrespro.ru", "phone": "+70002391240"}
0005433805784	016602	2525 138832	LYUDMILA NIKOLAEVA	{"email": "nikolaeva_lyudmila28111979@postgrespro.ru", "phone": "+70249740900"}
0005433805785	4C4D9D	8924 349310	VLADIMIR STEPANOV	{"phone": "+70437423038"}
0005433805786	CDCDC4	5946 902269	VALENTINA KUZNECOVA	{"phone": "+70898861285"}
0005433805787	CDCDC4	8657 005782	IRINA VLASOVA	{"email": "vlasova_irina.111981@postgrespro.ru", "phone": "+70242653360"}
0005433805788	C41F86	0244 603642	ALINA KONDRATEVA	{"email": "kondratevaalina_101971@postgrespro.ru", "phone": "+70533656153"}
0005433805789	EDCFDD	1361 559833	SERGEY VLASOV	{"email": "svlasov_011966@postgrespro.ru", "phone": "+70907048424"}
0005433805790	EDCFDD	0027 589468	ELENA NIKIFOROVA	{"email": "e_nikiforova-011972@postgrespro.ru", "phone": "+70090007578"}
0005433805791	A43336	6376 165807	NINA EFIMOVA	{"email": "efimova-nina.1974@postgrespro.ru", "phone": "+70085968434"}
0005433805792	6F800E	5965 530663	GALINA SOROKINA	{"phone": "+70527325230"}
0005433805793	DC15C3	8021 229329	ELMIRA FEDOROVA	{"phone": "+70853703062"}
0005433805794	3D09F7	4819 441083	DINARA GERASIMOVA	{"email": "d-gerasimova1968@postgrespro.ru", "phone": "+70962302702"}
0005433805795	3D09F7	0107 711334	FEDOR IVANOV	{"phone": "+70083893558"}
0005433805796	5DAE56	9109 260678	VIKTORIYA GUSEVA	{"phone": "+70786397968"}
0005433805797	5DAE56	5970 303128	ALEKSEY BORISOV	{"phone": "+70278830163"}
0005433805798	943520	5264 024411	ANZHELIKA KUDRYASHOVA	{"phone": "+70011295209"}
0005433805799	943520	2572 658737	OKSANA NOVIKOVA	{"email": "o_novikova.061970@postgrespro.ru", "phone": "+70740183272"}
0005433805800	2436B2	4626 161686	NATALYA KULIKOVA	{"phone": "+70118228187"}
0005433805801	9BEC8D	6052 193990	VADIM GERASIMOV	{"email": "vadim_gerasimov-1968@postgrespro.ru", "phone": "+70838928533"}
0005433805802	70289E	3248 499160	ELENA KARPOVA	{"email": "karpovaelena_19021976@postgrespro.ru", "phone": "+70040992262"}
0005433805803	108C6F	8098 759889	ANDREY POPOV	{"email": "popov-andrey.091972@postgrespro.ru", "phone": "+70153961730"}
0005433805804	AA6B24	5416 415595	DMITRIY DENISOV	{"phone": "+70096519240"}
0005433805805	AA6B24	1257 503328	STANISLAV FILIPPOV	{"email": "filippovstanislav-081982@postgrespro.ru", "phone": "+70546533494"}
0005433805806	AA6B24	4671 832306	SERGEY MAKAROV	{"phone": "+70387291616"}
0005433805807	FACE90	8767 714431	ALEKSANDRA VOLKOVA	{"email": "avolkova_1988@postgrespro.ru", "phone": "+70370390872"}
0005433805808	E9129B	2703 404120	ANTON ALEKSEEV	{"email": "alekseevanton1970@postgrespro.ru", "phone": "+70525671746"}
0005433805809	E9129B	1486 704682	IRINA MATVEEVA	{"email": "i-matveeva.061969@postgrespro.ru", "phone": "+70611883606"}
0005433805810	AEB2F8	8157 118041	DMITRIY AFANASEV	{"phone": "+70497767904"}
0005433805811	AEB2F8	5579 873185	VIKTOR POPOV	{"phone": "+70565462812"}
0005433805812	984770	8202 938584	NIKOLAY SCHERBAKOV	{"phone": "+70319490776"}
0005433805813	984770	5203 886213	SERGEY NIKOLAEV	{"phone": "+70073031963"}
0005433805814	9B4087	4852 997219	ARTEM KUZNECOV	{"email": "kuznecov-a17111980@postgrespro.ru", "phone": "+70438115202"}
0005433805815	D2E04B	8930 985693	MARIYA ANDREEVA	{"phone": "+70136940573"}
0005433805816	8162CE	3613 769532	PETR KUZNECOV	{"phone": "+70224332698"}
0005433805817	8E4370	9495 882923	NATALYA MOISEEVA	{"email": "moiseeva.n_11061975@postgrespro.ru", "phone": "+70174309738"}
0005433805818	8E4370	9098 231477	IVAN VASILEV	{"phone": "+70420663745"}
0005433805819	8E4370	4398 828403	GENNADIY GRIGOREV	{"phone": "+70335139916"}
0005433805820	8E4370	5305 441300	ANDREY PETROV	{"email": "a-petrov-031977@postgrespro.ru", "phone": "+70679631327"}
0005433805821	35CEC4	7865 354057	MARINA AFANASEVA	{"email": "marina_afanaseva.19061971@postgrespro.ru", "phone": "+70691820216"}
0005433805822	485C84	6616 942222	ALEKSANDR MOROZOV	{"email": "a-morozov-1968@postgrespro.ru", "phone": "+70416115318"}
0005433805823	95A463	8576 571992	ELENA NIKITINA	{"phone": "+70786099810"}
0005433805824	95A463	3120 848586	ELIZAVETA KISELEVA	{"email": "e.kiseleva19111971@postgrespro.ru", "phone": "+70156980424"}
0005433805825	1E6447	3604 968236	KRISTINA CHERNOVA	{"email": "chernova_k.05021973@postgrespro.ru", "phone": "+70358176534"}
0005433805826	255A31	5674 568933	YURIY VOLKOV	{"email": "volkov-y_08041973@postgrespro.ru", "phone": "+70457759242"}
0005433805827	255A31	7036 418729	KLAVDIYA MAKAROVA	{"phone": "+70054871251"}
0005433805828	1A989F	4419 735955	LIDIYA VASILEVA	{"phone": "+70973992064"}
0005433805829	1A989F	3849 014460	ALEKSEY SEMENOV	{"email": "alekseysemenov-031977@postgrespro.ru", "phone": "+70338059712"}
0005433805830	0E3B9F	0651 156620	TAISIYA KUZMINA	{"phone": "+70764662684"}
0005433805831	0E3B9F	2692 826657	LEV ALEKSEEV	{"phone": "+70066751127"}
0005433805832	0E3B9F	2114 634817	ALEKSEY SOKOLOV	{"email": "sokolovaleksey.1965@postgrespro.ru", "phone": "+70867978705"}
0005433805833	A2AA7F	4054 679344	ARTEM VLASOV	{"email": "vlasovartem_11091976@postgrespro.ru", "phone": "+70859222790"}
0005433805834	63D515	1450 767528	OKSANA SAVELEVA	{"phone": "+70551077419"}
0005433805835	63D515	8541 246971	MIKHAIL KONOVALOV	{"email": "konovalov_m.04061968@postgrespro.ru", "phone": "+70456581764"}
0005433805836	E11A8E	1408 766862	OLGA ZAYCEVA	{"email": "o.zayceva.19121969@postgrespro.ru", "phone": "+70651699916"}
0005433805837	B1CEA6	0560 846863	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey.1986@postgrespro.ru", "phone": "+70747347919"}
0005433805838	281FE1	5074 547785	YURIY FILIPPOV	{"email": "filippov_yuriy_091964@postgrespro.ru", "phone": "+70401297813"}
0005433805839	E70F05	5437 844494	ALEKSEY KUZMIN	{"phone": "+70287421089"}
0005433805840	E70F05	6945 374285	YURIY AFANASEV	{"email": "afanasev_yuriy1975@postgrespro.ru", "phone": "+70032876175"}
0005433806020	274426	0888 603467	YULIYA IVANOVA	{"phone": "+70840163634"}
0005433805841	68DF6B	1556 766931	VIKTOR ANTONOV	{"email": "antonov-v.20051980@postgrespro.ru", "phone": "+70227979176"}
0005433805842	68DF6B	1647 626573	ALEKSEY GORBUNOV	{"phone": "+70385555982"}
0005433805843	AC09C6	1597 506346	VALERIYA KRASNOVA	{"email": "v-krasnova.071984@postgrespro.ru", "phone": "+70980881202"}
0005433805844	17211C	8592 524784	OLGA KUZNECOVA	{"email": "olga_kuznecova-1974@postgrespro.ru", "phone": "+70838938605"}
0005433805845	17211C	3834 452766	SERGEY MAKSIMOV	{"email": "maksimov.s-091967@postgrespro.ru", "phone": "+70298410163"}
0005433805846	73009C	7856 275190	ROMAN STEPANOV	{"phone": "+70368097343"}
0005433805847	FE61C6	9472 417201	VYACHESLAV SERGEEV	{"phone": "+70961496806"}
0005433805848	78FAF5	0321 153480	IGOR SAVELEV	{"phone": "+70147575992"}
0005433805849	9FED04	4809 606367	GALINA KALININA	{"phone": "+70334470061"}
0005433805850	9FED04	0519 943425	TATYANA POLYAKOVA	{"phone": "+70504362945"}
0005433805851	F5419F	4148 450226	LIDIYA NESTEROVA	{"email": "nesterova.lidiya_1985@postgrespro.ru", "phone": "+70993057261"}
0005433805852	F5419F	7004 927462	SERGEY SEMENOV	{"email": "sergey-semenov_101970@postgrespro.ru", "phone": "+70819513536"}
0005433805853	F5419F	9208 085803	SVETLANA ALEKSEEVA	{"email": "alekseeva.s10051964@postgrespro.ru", "phone": "+70677012051"}
0005433805854	7073F6	4603 467171	ANNA TARASOVA	{"email": "tarasovaanna_1970@postgrespro.ru", "phone": "+70763309474"}
0005433805855	B8FC9D	2554 591081	DIANA SIDOROVA	{"phone": "+70677532582"}
0005433805856	B8FC9D	7098 422033	DARYA MALYSHEVA	{"phone": "+70411347580"}
0005433805857	F3A3C2	2598 482786	NIKOLAY BORISOV	{"phone": "+70245910636"}
0005433805858	F3A3C2	3269 750723	VERA MOROZOVA	{"phone": "+70915509605"}
0005433805859	0931E7	9715 002164	MARIYA SIDOROVA	{"email": "m.sidorova15111971@postgrespro.ru", "phone": "+70342848290"}
0005433805860	BC1377	2594 215318	TATYANA BORISOVA	{"email": "borisova-tatyana-10041975@postgrespro.ru", "phone": "+70888625403"}
0005433805861	C9A11A	7666 267419	VASILIY KOZLOV	{"email": "kozlov_vasiliy.03041970@postgrespro.ru", "phone": "+70084279150"}
0005433805862	0187C0	6634 935770	OLGA ILINA	{"email": "oilina_09071961@postgrespro.ru", "phone": "+70320942604"}
0005433805863	702146	6130 917820	VERA SAVELEVA	{"phone": "+70670611448"}
0005433805864	702146	2053 747039	VALERIY STEPANOV	{"phone": "+70284939161"}
0005433805865	0A9A8F	6874 475337	LIDIYA EFREMOVA	{"email": "efremova-l061964@postgrespro.ru", "phone": "+70737013174"}
0005433805866	0A9A8F	7408 186930	MARIYA ANTONOVA	{"email": "m.antonova-1982@postgrespro.ru", "phone": "+70402559946"}
0005433805867	73E260	2634 983380	OLGA MELNIKOVA	{"email": "olga_melnikova-1967@postgrespro.ru", "phone": "+70296037685"}
0005433805868	A85C81	1339 388425	SVETLANA VASILEVA	{"email": "s-vasileva12061966@postgrespro.ru", "phone": "+70641139627"}
0005433805869	41D1C2	7944 437432	PAVEL SAVELEV	{"phone": "+70175824318"}
0005433805870	41D1C2	6469 919911	TATYANA KISELEVA	{"email": "tkiseleva-1970@postgrespro.ru", "phone": "+70773020483"}
0005433805871	A346A9	6132 709276	ILYA GORBUNOV	{"email": "i-gorbunov_1971@postgrespro.ru", "phone": "+70091927601"}
0005433805872	F4D4F7	7186 420761	OLGA KAZAKOVA	{"email": "kazakova-o-1973@postgrespro.ru", "phone": "+70776172657"}
0005433805873	A9B27C	4812 199267	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_aleksandr.22101967@postgrespro.ru", "phone": "+70137299775"}
0005433805874	A9B27C	3454 928186	TATYANA KULIKOVA	{"email": "tkulikova.11111971@postgrespro.ru", "phone": "+70826614087"}
0005433805875	387321	9399 747829	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr.26101965@postgrespro.ru", "phone": "+70260381472"}
0005433805876	87799F	7601 167845	YURIY SEMENOV	{"phone": "+70394291172"}
0005433805877	87799F	3489 833979	NIKITA KRASNOV	{"phone": "+70894753819"}
0005433805878	311F5D	4567 261840	NIKOLAY ISAEV	{"phone": "+70523838874"}
0005433805879	202106	3037 778408	LYUDMILA VASILEVA	{"phone": "+70019520385"}
0005433805880	ADA9CF	0026 189792	ANATOLIY ZAYCEV	{"email": "zayceva.01031969@postgrespro.ru", "phone": "+70842821213"}
0005433805881	ADA9CF	0374 362498	NINA FADEEVA	{"phone": "+70054792788"}
0005433805882	ADA9CF	7366 106204	ALEKSEY BELOV	{"phone": "+70105282868"}
0005433805883	C7D2D6	8577 731523	ALBINA ABRAMOVA	{"email": "abramova-a29091962@postgrespro.ru", "phone": "+70924605600"}
0005433805884	C7D2D6	3181 719894	ALEKSANDR GAVRILOV	{"email": "agavrilov.1976@postgrespro.ru", "phone": "+70141114216"}
0005433805885	46175E	8937 450418	ANNA KRASNOVA	{"phone": "+70594603679"}
0005433805886	46175E	8164 430298	ZULFIYA POPOVA	{"phone": "+70549482683"}
0005433805887	41FC86	6684 046902	NATALYA GRISHINA	{"phone": "+70111397411"}
0005433805888	41FC86	5580 448491	ROMAN KAZAKOV	{"phone": "+70353766561"}
0005433805889	41FC86	2604 062833	ANNA MARTYNOVA	{"phone": "+70484402887"}
0005433805890	37BF6D	5208 591346	NATALYA OSIPOVA	{"phone": "+70404744539"}
0005433805891	F8808D	8771 884197	ALEKSEY SOROKIN	{"email": "sorokin.aleksey.31031976@postgrespro.ru", "phone": "+70320825366"}
0005433805892	F8808D	3583 172820	LYUBOV TROFIMOVA	{"email": "lyubov.trofimova1974@postgrespro.ru", "phone": "+70900063690"}
0005433805893	CF6909	9961 863970	VALENTINA POPOVA	{"phone": "+70980866858"}
0005433805894	CF6909	6441 908740	NADEZHDA BORISOVA	{"email": "borisovanadezhda_17011977@postgrespro.ru", "phone": "+70455329319"}
0005433805895	4CF4D8	3725 223797	ALEKSANDR FOMIN	{"phone": "+70737897818"}
0005433805896	4CF4D8	3299 052618	PAVEL KARPOV	{"email": "karpov-p.021972@postgrespro.ru", "phone": "+70608094081"}
0005433805897	4CF4D8	2765 355888	ANTONINA MEDVEDEVA	{"email": "a.medvedeva27011972@postgrespro.ru", "phone": "+70167875636"}
0005433805898	AFD0AC	9140 349603	DINA PAVLOVA	{"phone": "+70103639967"}
0005433805899	4FF278	3619 733652	OLGA KOZLOVA	{"email": "kozlova-o_1962@postgrespro.ru", "phone": "+70400741757"}
0005433805900	DA1AEA	8538 295556	MAKSIM NIKITIN	{"phone": "+70993157481"}
0005433810690	018215	3087 262520	TATYANA KOMAROVA	{"phone": "+70953955179"}
0005433805901	672330	8772 191889	DMITRIY NIKOLAEV	{"email": "nikolaev-dmitriy-12071976@postgrespro.ru", "phone": "+70110527445"}
0005433805902	45B9D4	5752 469113	LYUBOV SOROKINA	{"phone": "+70489527879"}
0005433805903	45B9D4	1651 688390	ZAKHAR SEMENOV	{"email": "zsemenov-051970@postgrespro.ru", "phone": "+70977446337"}
0005433805904	45B9D4	1740 148459	PAVEL SOROKIN	{"email": "sorokin.pavel.17021974@postgrespro.ru", "phone": "+70915520560"}
0005433805905	E9B5B4	2902 498952	VLADIMIR ALEKSEEV	{"phone": "+70337587066"}
0005433805906	E9B5B4	6752 831339	SOFYA MOISEEVA	{"email": "sofyamoiseeva.1975@postgrespro.ru", "phone": "+70244119457"}
0005433805907	D92A4B	9717 205351	NAIL BELOV	{"email": "n.belov.09051976@postgrespro.ru", "phone": "+70631599639"}
0005433805908	F0E940	9749 338421	ANASTASIYA MELNIKOVA	{"email": "amelnikova.1969@postgrespro.ru", "phone": "+70666403995"}
0005433805909	82E32A	2401 403820	NIKOLAY ALEKSANDROV	{"email": "n_aleksandrov.1971@postgrespro.ru", "phone": "+70432882770"}
0005433805910	207778	0756 738576	ANNA KRASNOVA	{"email": "krasnova-a1981@postgrespro.ru", "phone": "+70761876084"}
0005433805911	207778	8321 743231	ELENA DENISOVA	{"email": "elenadenisova-091979@postgrespro.ru", "phone": "+70503102632"}
0005433805912	0F0EBE	1413 362092	ANDREY KUZNECOV	{"email": "kuznecov_a051968@postgrespro.ru", "phone": "+70283282406"}
0005433805913	65D03B	7965 945523	ARTEM CHERNOV	{"phone": "+70117509364"}
0005433805914	EE8DB3	0590 087097	POLINA FEDOROVA	{"phone": "+70235098995"}
0005433805915	AABC30	5283 324139	YURIY ZAKHAROV	{"email": "y.zakharov1974@postgrespro.ru", "phone": "+70649509013"}
0005433805916	325569	0760 853662	VASILIY KUZNECOV	{"email": "kuznecov_vasiliy1976@postgrespro.ru", "phone": "+70226902406"}
0005433805917	FAAD7C	9853 282966	NADEZHDA BELYAEVA	{"email": "belyaeva.n1967@postgrespro.ru", "phone": "+70255662435"}
0005433805918	FAAD7C	4650 456991	SERGEY TIKHONOV	{"email": "sergey.tikhonov1975@postgrespro.ru", "phone": "+70929407365"}
0005433805919	C51700	2470 866619	SANIYA GERASIMOVA	{"email": "saniyagerasimova29081963@postgrespro.ru", "phone": "+70546357345"}
0005433805920	C51700	1755 588959	SERGEY GRIGOREV	{"phone": "+70127748758"}
0005433805921	C51700	1550 757312	YULIYA KOVALEVA	{"phone": "+70458556092"}
0005433805922	C6DF69	8589 971235	TATYANA KAZAKOVA	{"email": "kazakovatatyana-111976@postgrespro.ru", "phone": "+70147541187"}
0005433805923	C6DF69	9505 432708	MARIYA SERGEEVA	{"phone": "+70287736368"}
0005433805924	ACCB29	8063 743348	IRINA SERGEEVA	{"email": "sergeevairina.19061971@postgrespro.ru", "phone": "+70980700305"}
0005433805925	3278A5	9734 195887	ANDREY IVANOV	{"phone": "+70964798383"}
0005433805926	3278A5	9525 773821	RADIK KISELEV	{"email": "kiselev_r_1985@postgrespro.ru", "phone": "+70848384239"}
0005433805927	3278A5	8490 655302	IVAN FEDOTOV	{"email": "ifedotov111968@postgrespro.ru", "phone": "+70775841070"}
0005433805928	751C95	0361 195548	LYUDMILA LAZAREVA	{"email": "l.lazareva_1964@postgrespro.ru", "phone": "+70244006643"}
0005433805929	D5A5F9	3602 000816	ANNA VOLKOVA	{"email": "volkova_anna-071976@postgrespro.ru", "phone": "+70152837982"}
0005433805930	519D43	9293 015254	ANATOLIY ZAYCEV	{"phone": "+70976472801"}
0005433805931	519D43	4015 593063	GALINA MAKAROVA	{"email": "g-makarova_27071975@postgrespro.ru", "phone": "+70817625101"}
0005433805932	3B84E4	9563 183110	MAKSIM NOVIKOV	{"phone": "+70651337995"}
0005433805933	3B84E4	4302 261308	NADEZHDA LEBEDEVA	{"phone": "+70799244845"}
0005433805934	663006	6246 150713	SVETLANA STEPANOVA	{"email": "stepanova-s-1973@postgrespro.ru", "phone": "+70234061362"}
0005433805935	F89CD2	7704 961953	YURIY ILIN	{"phone": "+70746146226"}
0005433805936	F89CD2	4320 420996	DENIS MOROZOV	{"phone": "+70745751217"}
0005433805937	F89CD2	9553 088535	SERGEY KOROLEV	{"email": "korolevsergey031979@postgrespro.ru", "phone": "+70840808641"}
0005433805938	05C511	1383 644847	NIKOLAY NIKOLAEV	{"phone": "+70973545289"}
0005433805939	1ED008	8611 955625	TAMARA NIKOLAEVA	{"phone": "+70991200369"}
0005433805940	1ED008	8666 028740	ANASTASIYA GERASIMOVA	{"email": "agerasimova.03051970@postgrespro.ru", "phone": "+70362046339"}
0005433805941	1ED008	3296 577081	VLADISLAV TIKHONOV	{"email": "tikhonovvladislav.21051976@postgrespro.ru", "phone": "+70551247404"}
0005433805942	AF8D27	1918 510980	EKATERINA KOLESNIKOVA	{"email": "kolesnikova_e_04031963@postgrespro.ru", "phone": "+70563473954"}
0005433805943	17DA68	0354 430470	ARTEM POPOV	{"email": "popov.a08021971@postgrespro.ru", "phone": "+70108028937"}
0005433805944	26491F	7920 292851	VITALIY NAZAROV	{"email": "vitaliy.nazarov-1984@postgrespro.ru", "phone": "+70107841046"}
0005433805945	7F115C	0869 555608	DARYA FILATOVA	{"email": "d_filatova_011973@postgrespro.ru", "phone": "+70726330440"}
0005433805946	7F115C	0537 899385	MIKHAIL KARPOV	{"phone": "+70037380430"}
0005433805947	67743E	5970 557512	ELENA TARASOVA	{"phone": "+70263591215"}
0005433805948	DECA1B	5384 246510	NATALYA ZAKHAROVA	{"email": "zakharova-n04041972@postgrespro.ru", "phone": "+70816799916"}
0005433805949	DECA1B	1793 787550	ELENA ZAKHAROVA	{"phone": "+70716334643"}
0005433805950	DECA1B	8905 758957	PAVEL NIKITIN	{"email": "pavelnikitin.031977@postgrespro.ru", "phone": "+70510058413"}
0005433805951	F9C8CB	3043 157147	SERGEY KAZAKOV	{"email": "sergey_kazakov1974@postgrespro.ru", "phone": "+70076838525"}
0005433805952	BDAFBC	3110 212160	ALEKSEY KRASNOV	{"email": "aleksey_krasnov_1976@postgrespro.ru", "phone": "+70322029536"}
0005433805953	BDAFBC	2999 730312	ADELINA LUKYANOVA	{"email": "lukyanovaa09111970@postgrespro.ru", "phone": "+70113158305"}
0005433805954	669C18	0892 617393	VALERIYA VASILEVA	{"phone": "+70654296212"}
0005433805955	06086E	5715 227640	OKSANA ANTONOVA	{"phone": "+70798932478"}
0005433805956	F8E096	0520 480932	ANFISA OVCHINNIKOVA	{"phone": "+70681912553"}
0005433805957	6E18AB	5407 395365	NINA POPOVA	{"email": "popova-nina_11111976@postgrespro.ru", "phone": "+70845544304"}
0005433805958	3FD111	4904 006591	DMITRIY CHERNOV	{"phone": "+70938438705"}
0005433810691	E025EC	6472 213212	KRISTINA MAKAROVA	{"phone": "+70412309028"}
0005433805959	3FD111	1418 718318	SVETLANA VASILEVA	{"email": "vasileva-s_17011976@postgrespro.ru", "phone": "+70303023128"}
0005433805960	600E46	0745 724525	ELENA ILINA	{"phone": "+70244600596"}
0005433805961	600E46	6110 329413	NADEZHDA PETROVA	{"email": "n_petrova.101972@postgrespro.ru", "phone": "+70454593541"}
0005433805962	FE1119	6424 925743	ANAIT PETROVA	{"phone": "+70435198877"}
0005433805963	FE1119	1137 642997	ANTON POPOV	{"phone": "+70240864535"}
0005433805964	370D37	8991 241895	DMITRIY YAKOVLEV	{"phone": "+70755349266"}
0005433805965	CA4EBB	8059 770770	MARIYA VLASOVA	{"phone": "+70120170049"}
0005433805966	7BBC9E	2963 372437	IRINA ANDREEVA	{"email": "andreeva-i.21051986@postgrespro.ru", "phone": "+70474068227"}
0005433805967	7BBC9E	4940 462674	DINARA FEDOROVA	{"phone": "+70342283933"}
0005433805968	C71C85	7474 582834	NIKOLAY NIKITIN	{"phone": "+70532990630"}
0005433805969	C71C85	2366 937078	NATALYA KRASNOVA	{"phone": "+70003172249"}
0005433805970	8A7AE5	4125 030490	AYRAT FOMIN	{"email": "fomin.ayrat1977@postgrespro.ru", "phone": "+70533713836"}
0005433805971	991CE5	4654 802170	NIKOLAY OSIPOV	{"phone": "+70441762406"}
0005433805972	991CE5	7789 083651	MAKSIM NIKOLAEV	{"email": "m.nikolaev-03061974@postgrespro.ru", "phone": "+70892531428"}
0005433805973	352266	8840 720045	MARIYA LEBEDEVA	{"phone": "+70310806876"}
0005433805974	AD0645	2103 877699	GULNARA EFIMOVA	{"email": "efimovag_14111971@postgrespro.ru", "phone": "+70133403411"}
0005433805975	AD0645	1740 036354	LYUDMILA VASILEVA	{"phone": "+70559265837"}
0005433805976	95B109	2526 446851	VASILIY KARPOV	{"email": "karpov-v-26051964@postgrespro.ru", "phone": "+70113351721"}
0005433805977	95B109	1417 455472	LYUBOV RODIONOVA	{"phone": "+70090733624"}
0005433805978	F9C988	3910 642009	ILYA MOISEEV	{"email": "i.moiseev_1979@postgrespro.ru", "phone": "+70055838897"}
0005433805979	B4190B	0919 485357	PAVEL MIKHAYLOV	{"email": "mikhaylov.pavel_1970@postgrespro.ru", "phone": "+70246920270"}
0005433805980	CF4418	2787 481844	TAMARA ROMANOVA	{"phone": "+70093370965"}
0005433805981	608FC2	1902 279588	ALEKSANDR POPOV	{"email": "aleksandr.popov.18021957@postgrespro.ru", "phone": "+70697285273"}
0005433805982	608FC2	2223 378412	ALEKSEY VLASOV	{"phone": "+70043916425"}
0005433805983	608FC2	0355 041507	NIKOLAY ORLOV	{"email": "n.orlov.1965@postgrespro.ru", "phone": "+70132949651"}
0005433805984	7CFCB9	2441 463523	ELVIRA DENISOVA	{"email": "elvira-denisova_1978@postgrespro.ru", "phone": "+70338192284"}
0005433805985	530F2B	2949 318012	SVETLANA SCHERBAKOVA	{"email": "scherbakova.s-1964@postgrespro.ru", "phone": "+70327262846"}
0005433805986	FB35D5	5516 370432	NIKOLAY ANDREEV	{"phone": "+70120119722"}
0005433805987	FB35D5	4266 585577	IRINA MATVEEVA	{"email": "matveeva.i.081974@postgrespro.ru", "phone": "+70552476670"}
0005433805988	E5CD10	8153 624499	ANATOLIY SHEVCHENKO	{"email": "shevchenko.anatoliy011971@postgrespro.ru", "phone": "+70048183318"}
0005433805989	8F6F2C	4105 866556	POLINA KOLESNIKOVA	{"email": "polina_kolesnikova-1963@postgrespro.ru", "phone": "+70436984945"}
0005433805990	5A305C	3728 981377	DARYA SIDOROVA	{"phone": "+70162964234"}
0005433805991	5A305C	5142 303349	VLADIMIR MIRONOV	{"email": "mironov.vladimir1967@postgrespro.ru", "phone": "+70149203190"}
0005433805992	5646E6	3779 799902	VERA KOVALEVA	{"phone": "+70243187258"}
0005433805993	5646E6	4251 624010	MARIYA LOGINOVA	{"phone": "+70992669940"}
0005433805994	65A0B8	3406 711785	VLADIMIR SERGEEV	{"email": "vladimirsergeev-16031976@postgrespro.ru", "phone": "+70018446747"}
0005433805995	65A0B8	4007 289252	VLADIMIR NIKITIN	{"phone": "+70528135068"}
0005433805996	C722A7	9834 042049	LARISA LUKYANOVA	{"phone": "+70702428014"}
0005433805997	C722A7	1775 977394	RAFAIL SOLOVEV	{"email": "r-solovev1963@postgrespro.ru", "phone": "+70079018433"}
0005433805998	77C080	3038 188069	VLADIMIR ALEKSANDROV	{"phone": "+70048834537"}
0005433805999	670C68	1478 937345	VIKTOR ALEKSANDROV	{"phone": "+70302948101"}
0005433806000	783E16	8648 737769	LYUBOV IVANOVA	{"email": "ivanova-l-111977@postgrespro.ru", "phone": "+70597243775"}
0005433806001	395BAE	7892 299696	ANDREY KOZLOV	{"email": "kozlov_a_29051968@postgrespro.ru", "phone": "+70097791352"}
0005433806002	972A15	8781 095407	GALINA VASILEVA	{"email": "galina-vasileva-28031957@postgrespro.ru", "phone": "+70767647495"}
0005433806003	972A15	7320 767586	DENIS KUZNECOV	{"phone": "+70874049767"}
0005433806004	9B28D1	4964 221600	PAVEL ANDREEV	{"phone": "+70451501225"}
0005433806005	9B28D1	3240 438663	MARIYA FEDOROVA	{"email": "mariya.fedorova_06091972@postgrespro.ru", "phone": "+70541425021"}
0005433806006	0E874F	4171 693826	ANATOLIY MARTYNOV	{"email": "anatoliy.martynov031969@postgrespro.ru", "phone": "+70867572729"}
0005433806007	F83047	3083 502831	MIKHAIL MAKAROV	{"phone": "+70977584509"}
0005433806008	78C70F	2360 204450	IVAN VASILEV	{"phone": "+70180031587"}
0005433806009	E201D3	4378 639452	ALEKSEY AFANASEV	{"email": "afanasev-a.1974@postgrespro.ru", "phone": "+70400810188"}
0005433806010	B4F732	5813 997350	DMITRIY ISAEV	{"phone": "+70145786603"}
0005433806011	FE4E0A	2587 358680	MIKHAIL GRIGOREV	{"email": "grigorev-m_01121983@postgrespro.ru", "phone": "+70590068263"}
0005433806012	8374DF	2420 265738	ALEKSANDR KRASNOV	{"email": "krasnov-a.1982@postgrespro.ru", "phone": "+70310762584"}
0005433806013	C78BE8	0306 127803	RADIK FEDOTOV	{"email": "radik.fedotov.111975@postgrespro.ru", "phone": "+70866249294"}
0005433806014	C36C1E	6141 014889	EKATERINA SAVELEVA	{"phone": "+70297480904"}
0005433806015	C36C1E	9457 027564	VALENTINA EFIMOVA	{"email": "valentina.efimova01111969@postgrespro.ru", "phone": "+70407468695"}
0005433806016	072B30	8122 660983	TATYANA YAKOVLEVA	{"email": "yakovleva-t-071956@postgrespro.ru", "phone": "+70912918782"}
0005433806017	072B30	7085 804133	NINA KUZNECOVA	{"phone": "+70731432115"}
0005433806018	7108D1	4197 329627	ANDREY NIKITIN	{"phone": "+70668581084"}
0005433806019	274426	8032 504663	VALERIY ZHUKOV	{"email": "valeriy-zhukov_08081976@postgrespro.ru", "phone": "+70068902791"}
0005433806021	7F4625	7496 900517	VALERIYA SOKOLOVA	{"email": "sokolova-v-061974@postgrespro.ru", "phone": "+70203631662"}
0005433806022	7F4625	5495 214664	ELIZAVETA KOROLEVA	{"phone": "+70718586536"}
0005433806023	7F4625	9379 291948	GALINA STEPANOVA	{"phone": "+70853293615"}
0005433806024	C33982	3595 192164	PAVEL DMITRIEV	{"email": "dmitrievpavel.27071974@postgrespro.ru", "phone": "+70551530925"}
0005433806025	D01A59	1798 181917	DMITRIY BONDARENKO	{"phone": "+70911791621"}
0005433806026	1A9FCE	8218 395801	NATALYA AFANASEVA	{"email": "n.afanaseva_19041975@postgrespro.ru", "phone": "+70583233244"}
0005433806027	D42756	4949 235386	IGOR MIKHAYLOV	{"phone": "+70573978275"}
0005433806028	D42756	3637 165655	NATALYA ABRAMOVA	{"email": "abramova.n-12121966@postgrespro.ru", "phone": "+70026379000"}
0005433806029	BA559E	7138 015000	LILIYA MATVEEVA	{"email": "matveeva-liliya30071983@postgrespro.ru", "phone": "+70247091543"}
0005433806030	51BCB1	8541 265146	VERA ROMANOVA	{"phone": "+70846677490"}
0005433806031	1E6CB5	4908 905716	VLADIMIR MIRONOV	{"phone": "+70598549845"}
0005433806032	1E6CB5	0927 140248	ALEKSEY STEPANOV	{"phone": "+70725271049"}
0005433806033	D253B3	4547 828914	MIKHAIL FOMIN	{"email": "m-fomin_101977@postgrespro.ru", "phone": "+70472997682"}
0005433806034	D253B3	7444 744373	GALINA NAZAROVA	{"phone": "+70817277690"}
0005433806035	1C53F4	9573 262305	YURIY NIKITIN	{"email": "y_nikitin14091974@postgrespro.ru", "phone": "+70452348809"}
0005433806036	1C53F4	2217 752203	LYUDMILA PETROVA	{"email": "petrova-lyudmila051977@postgrespro.ru", "phone": "+70550658590"}
0005433806037	E8A10F	5868 355132	VLADIMIR KAZAKOV	{"email": "vladimir.kazakov1972@postgrespro.ru", "phone": "+70392534936"}
0005433806038	DFDA5C	7492 290556	ARINA NIKITINA	{"phone": "+70066268464"}
0005433806039	5C2D4C	3987 051588	SERGEY ZAYCEV	{"phone": "+70266770476"}
0005433806040	AA30A0	3065 492525	OLEG PAVLOV	{"phone": "+70246049879"}
0005433806041	68C3EE	0070 419702	ANDREY DAVYDOV	{"email": "davydov_andrey-10101975@postgrespro.ru", "phone": "+70676493048"}
0005433806042	076B8B	1021 564292	ELENA SERGEEVA	{"phone": "+70836492114"}
0005433806043	076B8B	2040 985624	NADEZHDA NOVIKOVA	{"email": "nadezhdanovikova_051973@postgrespro.ru", "phone": "+70604315204"}
0005433806044	AAF038	2626 815855	LIDIYA GORBUNOVA	{"phone": "+70169689127"}
0005433806045	3DAE92	0187 523315	SERGEY PAVLOV	{"email": "spavlov-01091969@postgrespro.ru", "phone": "+70532704598"}
0005433806046	FBEE38	8686 894639	IGOR MOROZOV	{"email": "morozov-igor_26081971@postgrespro.ru", "phone": "+70927496901"}
0005433806047	FBEE38	8402 981994	ALEKSANDR IVANOV	{"email": "ivanov-a061960@postgrespro.ru", "phone": "+70463635605"}
0005433806048	79323A	1945 272553	MARIYA TARASOVA	{"phone": "+70306102706"}
0005433806049	79323A	3000 269977	ANDREY KAZAKOV	{"email": "kazakov_andrey081965@postgrespro.ru", "phone": "+70322841468"}
0005433806050	AE3D68	1947 493360	IVAN NOVIKOV	{"email": "novikov.i081976@postgrespro.ru", "phone": "+70082679408"}
0005433806051	AE3D68	4288 939631	OLGA NAUMOVA	{"phone": "+70631753388"}
0005433806052	0758AB	9300 494011	MARINA GAVRILOVA	{"email": "m.gavrilova04121985@postgrespro.ru", "phone": "+70892394864"}
0005433806053	5A5EC6	8637 230279	VASILIY GORBUNOV	{"email": "gorbunov.v.22081974@postgrespro.ru", "phone": "+70941948367"}
0005433806054	B2DD9A	2380 383195	MARINA MOROZOVA	{"phone": "+70722633498"}
0005433806055	B2DD9A	3724 090429	ELENA ANISIMOVA	{"email": "anisimovae15091983@postgrespro.ru", "phone": "+70807505934"}
0005433806056	5D6AFB	3367 026073	MARIYA MIRONOVA	{"phone": "+70546189068"}
0005433806057	A7919A	0140 546952	TATYANA KOVALEVA	{"email": "tatyana-kovaleva.1967@postgrespro.ru", "phone": "+70443872031"}
0005433806058	CB0D8B	7728 417202	RAISA BOGDANOVA	{"email": "bogdanovaraisa1964@postgrespro.ru", "phone": "+70926024595"}
0005433806059	CB0D8B	9090 299859	ROZA NAZAROVA	{"phone": "+70284970185"}
0005433806060	A5E1CB	4722 434400	ALEKSANDR NOVIKOV	{"email": "a-novikov_17091974@postgrespro.ru", "phone": "+70830713597"}
0005433806061	A5E1CB	5705 217487	ALEKSEY BORISOV	{"phone": "+70912191535"}
0005433806062	D6B1D4	7033 223613	EVDOKIYA SEMENOVA	{"email": "semenova_e_01101972@postgrespro.ru", "phone": "+70676940841"}
0005433806063	96A9C8	5743 338774	TAMARA KRASNOVA	{"phone": "+70709561337"}
0005433806064	96A9C8	7558 387059	SERGEY MELNIKOV	{"phone": "+70164810805"}
0005433806065	950608	9831 726166	ALEKSANDRA VLASOVA	{"phone": "+70760370418"}
0005433806066	950608	5085 519972	VLADIMIR NOVIKOV	{"email": "vladimir_novikov_1974@postgrespro.ru", "phone": "+70945043160"}
0005433806067	032D09	6955 828511	MARINA FEDOROVA	{"email": "fedorovam_19041974@postgrespro.ru", "phone": "+70588882784"}
0005433806068	214BF1	6814 794289	KIRILL KAZAKOV	{"email": "kazakov-k.081981@postgrespro.ru", "phone": "+70161810029"}
0005433806069	214BF1	1060 305220	ANNA SMIRNOVA	{"phone": "+70970984320"}
0005433806070	EEE6CF	5996 633723	VITALIY ZAKHAROV	{"email": "v.zakharov.051973@postgrespro.ru", "phone": "+70718018633"}
0005433806071	EEE6CF	1943 583154	EVGENIY SMIRNOV	{"email": "evgeniy-smirnov-1977@postgrespro.ru", "phone": "+70839916646"}
0005433806072	EEE6CF	7839 557909	LILIYA EGOROVA	{"phone": "+70760630029"}
0005433806073	46BB87	7815 244405	GALINA KARPOVA	{"phone": "+70565437423"}
0005433806074	46BB87	2606 742950	VLADIMIR ANDREEV	{"phone": "+70640083519"}
0005433806075	A0CE4F	2506 268443	VLADIMIR FOMIN	{"email": "v-fomin-1965@postgrespro.ru", "phone": "+70485624155"}
0005433806076	A0CE4F	7548 183350	PAVEL KULIKOV	{"email": "p_kulikov.03081981@postgrespro.ru", "phone": "+70220520418"}
0005433806077	980FFD	7826 076672	SERGEY AFANASEV	{"email": "afanasev.sergey_1973@postgrespro.ru", "phone": "+70823555207"}
0005433806078	652CB6	9997 162182	NINA KUZNECOVA	{"email": "kuznecova-n-06041974@postgrespro.ru", "phone": "+70406903257"}
0005433806079	652CB6	0336 818151	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr_091978@postgrespro.ru", "phone": "+70037428544"}
0005433810692	CF4ED2	6078 158024	ANDREY TIMOFEEV	{"phone": "+70908569970"}
0005433806080	0ABA81	6597 316925	VIKTOR NAUMOV	{"email": "viktornaumov-021977@postgrespro.ru", "phone": "+70612993024"}
0005433806081	0ABA81	0317 338090	GEORGIY SCHERBAKOV	{"email": "g-scherbakov.1981@postgrespro.ru", "phone": "+70444053350"}
0005433806082	D42CC3	3307 105825	RINAT NAUMOV	{"email": "r_naumov_1979@postgrespro.ru", "phone": "+70217170547"}
0005433806083	7A9A09	0562 929497	NIKOLAY VOLKOV	{"phone": "+70176770933"}
0005433806084	7A9A09	7008 607844	LARISA KISELEVA	{"email": "kiseleva_larisa041981@postgrespro.ru", "phone": "+70509473132"}
0005433806085	7A9A09	7019 486022	EVGENIYA NAZAROVA	{"email": "nazarova_e-25071974@postgrespro.ru", "phone": "+70809022804"}
0005433806086	6BA4E6	1086 159662	LYUDMILA GRISHINA	{"email": "lyudmilagrishina_1975@postgrespro.ru", "phone": "+70450661311"}
0005433806087	6BA4E6	1883 841866	SERGEY GORBUNOV	{"phone": "+70136379113"}
0005433806088	4068FA	9056 323763	GALINA FOMINA	{"email": "fomina_galina-1966@postgrespro.ru", "phone": "+70167229492"}
0005433806089	C92AE2	7324 860739	LYUDMILA SOROKINA	{"email": "lyudmilasorokina.1968@postgrespro.ru", "phone": "+70228394781"}
0005433806090	C92AE2	7652 425320	ANDREY DENISOV	{"email": "denisovandrey1970@postgrespro.ru", "phone": "+70244835462"}
0005433806091	146263	3024 200490	GENNADIY BELOV	{"email": "belovg.1963@postgrespro.ru", "phone": "+70464462541"}
0005433806092	146263	8028 308172	SVETLANA GAVRILOVA	{"phone": "+70549421949"}
0005433806093	0C1EA7	8737 904745	LYUBOV KUZNECOVA	{"phone": "+70021889490"}
0005433806094	EFE41C	3480 457288	DMITRIY ROMANOV	{"email": "romanov-dmitriy_1971@postgrespro.ru", "phone": "+70169695843"}
0005433806095	BCADCA	6288 777978	MARINA FILATOVA	{"email": "filatova_marina_1975@postgrespro.ru", "phone": "+70645966762"}
0005433806096	BCADCA	4121 006078	ANASTASIYA MAKSIMOVA	{"phone": "+70655816209"}
0005433806097	362678	9770 386367	KAPITALINA FEDOROVA	{"phone": "+70262844395"}
0005433806098	362678	0747 225245	EVGENIY NIKITIN	{"phone": "+70516748036"}
0005433806099	98C935	9740 268701	IGOR IVANOV	{"email": "ivanovi-27021974@postgrespro.ru", "phone": "+70227327813"}
0005433806100	A20B49	2640 869912	MARINA RODIONOVA	{"phone": "+70169122854"}
0005433806101	C024A9	9184 997242	TATYANA ALEKSEEVA	{"email": "tatyana.alekseeva-091969@postgrespro.ru", "phone": "+70348248634"}
0005433806102	744C0A	9206 721436	ANATOLIY ROMANOV	{"email": "anatoliyromanov.111974@postgrespro.ru", "phone": "+70476255403"}
0005433806103	E1AFE8	7382 774714	NIKOLAY ANDREEV	{"email": "andreev.nikolay-1971@postgrespro.ru", "phone": "+70625693709"}
0005433806104	E1AFE8	9151 874485	TATYANA VLASOVA	{"email": "tatyanavlasova1966@postgrespro.ru", "phone": "+70954100190"}
0005433806105	E1AFE8	6265 853749	NATALYA MASLOVA	{"phone": "+70114080464"}
0005433806106	7D0FFB	6631 469435	TATYANA FROLOVA	{"phone": "+70173583371"}
0005433806107	7D0FFB	4528 876580	VIKTORIYA BELYAEVA	{"phone": "+70893215156"}
0005433806108	7D0FFB	2202 665604	ELENA KISELEVA	{"email": "elena-kiseleva_1972@postgrespro.ru", "phone": "+70485426721"}
0005433806109	CF7F5F	3532 345152	IVAN IVANOV	{"phone": "+70154854445"}
0005433806110	CF7F5F	3668 382341	ELENA POLYAKOVA	{"email": "polyakova_e1977@postgrespro.ru", "phone": "+70307541945"}
0005433806111	0D8A2C	8115 366541	OLGA MATVEEVA	{"phone": "+70526105587"}
0005433806112	F626C7	4709 225255	ILYA ROMANOV	{"email": "i-romanov08061972@postgrespro.ru", "phone": "+70102099172"}
0005433806113	F626C7	8079 584383	VERA KUZNECOVA	{"email": "kuznecova.v1979@postgrespro.ru", "phone": "+70273279199"}
0005433806114	F626C7	5367 775172	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova_041971@postgrespro.ru", "phone": "+70875815745"}
0005433806115	E346C9	3936 226586	MARINA IVANOVA	{"email": "ivanova_m-1962@postgrespro.ru", "phone": "+70017586368"}
0005433806116	599EC6	7028 776832	IRINA FILATOVA	{"email": "ifilatova_25011968@postgrespro.ru", "phone": "+70245308896"}
0005433806117	44BEB5	3965 584874	OLGA FEDOROVA	{"phone": "+70198579789"}
0005433806118	44BEB5	7989 922552	VALENTINA KALININA	{"phone": "+70620437846"}
0005433806119	44BEB5	5785 382482	GALINA KUZNECOVA	{"phone": "+70538029223"}
0005433806120	6F4ABE	7686 900773	EVGENIY POPOV	{"email": "popov.e_121968@postgrespro.ru", "phone": "+70507435886"}
0005433806121	9F048E	6163 216771	LIDIYA FILIPPOVA	{"email": "lidiya.filippova.031979@postgrespro.ru", "phone": "+70982362940"}
0005433806122	9F048E	7890 879484	YANA YUDINA	{"email": "y_yudina.26101971@postgrespro.ru", "phone": "+70116012294"}
0005433806123	EBCBDF	6702 237811	ANNA KRASNOVA	{"email": "annakrasnova_041983@postgrespro.ru", "phone": "+70625166512"}
0005433806124	F485F4	1207 255643	OLGA YAKOVLEVA	{"phone": "+70469329562"}
0005433806125	5C5244	0916 349757	DMITRIY IVANOV	{"email": "ivanov.dmitriy_07101955@postgrespro.ru", "phone": "+70188648593"}
0005433806126	5CE36E	3397 351816	ALINA POPOVA	{"email": "popova.a-041973@postgrespro.ru", "phone": "+70937534263"}
0005433806127	061E78	0896 512683	OLGA KARPOVA	{"phone": "+70420479960"}
0005433806128	8C703A	9596 580765	ANASTASIYA ZHURAVLEVA	{"email": "anastasiyazhuravleva_11061971@postgrespro.ru", "phone": "+70570411296"}
0005433806129	8C703A	6584 202942	RAFAIL SCHERBAKOV	{"email": "r.scherbakov_1970@postgrespro.ru", "phone": "+70753310215"}
0005433806130	4B2FC4	8945 368853	GULNAZ PAVLOVA	{"email": "g-pavlova_051964@postgrespro.ru", "phone": "+70405899227"}
0005433806131	4B2FC4	1857 032979	ANDREY IVANOV	{"phone": "+70832524332"}
0005433806132	4B2FC4	9328 419261	TATYANA POPOVA	{"email": "t-popova.07121988@postgrespro.ru", "phone": "+70561213660"}
0005433806133	1C79E0	1481 373868	MARIYA POPOVA	{"phone": "+70861456971"}
0005433806134	1C79E0	5208 236189	IGOR VOROBEV	{"email": "vorobev.igor_1966@postgrespro.ru", "phone": "+70121265011"}
0005433806135	9E2482	9662 290399	DMITRIY MIKHAYLOV	{"phone": "+70917693648"}
0005433806136	C111C0	7430 254332	BOGDAN ZAYCEV	{"phone": "+70261663611"}
0005433806137	4BEEB0	4202 876781	VIKTOR FEDOROV	{"email": "viktor.fedorov1962@postgrespro.ru", "phone": "+70689482951"}
0005433806138	13E6A8	5425 894622	VLADIMIR TARASOV	{"phone": "+70376644284"}
0005433806139	B07653	7932 958910	SERGEY ANTONOV	{"email": "s_antonov_1960@postgrespro.ru", "phone": "+70348046260"}
0005433806140	A00BCB	7426 340792	NATALYA MIKHAYLOVA	{"email": "mikhaylova_n1969@postgrespro.ru", "phone": "+70346133278"}
0005433806141	A00BCB	3677 968779	DMITRIY SERGEEV	{"phone": "+70179702188"}
0005433806142	C1FE81	6853 208559	ALEKSANDR KISELEV	{"email": "aleksandrkiselev-22061963@postgrespro.ru", "phone": "+70085206647"}
0005433806143	F5B220	6161 979603	VALERIY MAKAROV	{"phone": "+70211365605"}
0005433806144	D9C357	5042 227379	EVGENIY ZHURAVLEV	{"phone": "+70652257980"}
0005433806145	18AC2D	0788 944400	ANATOLIY ZAYCEV	{"email": "zaycev_a25031978@postgrespro.ru", "phone": "+70007368293"}
0005433806146	F93EDA	9317 458246	ALEKSANDR GUSEV	{"email": "a.gusev_1973@postgrespro.ru", "phone": "+70230555476"}
0005433806147	15B8BF	5209 329415	NADEZHDA IVANOVA	{"email": "ivanova.n1969@postgrespro.ru", "phone": "+70642077529"}
0005433806148	AF7FC0	3618 264826	GERMAN MIRONOV	{"phone": "+70947083745"}
0005433806149	1D21BC	2392 736942	EKATERINA RYABOVA	{"phone": "+70591276540"}
0005433806150	1D21BC	2721 100981	ALEKSEY MOROZOV	{"email": "a.morozov_011965@postgrespro.ru", "phone": "+70905298377"}
0005433806151	BC4B3A	9296 968082	ARTUR EGOROV	{"phone": "+70726689902"}
0005433806152	3667CF	4449 769114	DENIS POPOV	{"phone": "+70491612347"}
0005433806153	5EE8D0	8804 599089	OLGA IVANOVA	{"email": "olga-ivanova.091958@postgrespro.ru", "phone": "+70003525603"}
0005433806154	7CADD1	0047 496356	NINA SMIRNOVA	{"email": "smirnova_nina_031975@postgrespro.ru", "phone": "+70582480274"}
0005433806155	7CADD1	1494 063182	LYUDMILA SIDOROVA	{"email": "sidoroval_1961@postgrespro.ru", "phone": "+70844519772"}
0005433806156	7CADD1	6171 938869	ANTONIDA KISELEVA	{"phone": "+70935985147"}
0005433806157	048E31	0790 169831	ELENA BELOVA	{"phone": "+70674518275"}
0005433806158	E39688	6680 141935	NATALYA OVCHINNIKOVA	{"email": "ovchinnikovan-1966@postgrespro.ru", "phone": "+70952451387"}
0005433806159	D004F6	7541 505736	TATYANA MIKHAYLOVA	{"phone": "+70463540602"}
0005433806160	96DA0A	3677 180918	VALERIY KAZAKOV	{"phone": "+70709957528"}
0005433806161	C9075A	0388 123065	OLESYA MEDVEDEVA	{"email": "medvedeva-olesya1971@postgrespro.ru", "phone": "+70117032365"}
0005433806162	9CB7FF	3505 756322	ANDREY ISAEV	{"phone": "+70078808056"}
0005433806163	27B3D2	7807 037370	ARINA MIKHAYLOVA	{"phone": "+70015171367"}
0005433806164	27B3D2	7757 001529	YANA MEDVEDEVA	{"email": "yana-medvedeva23061968@postgrespro.ru", "phone": "+70819144532"}
0005433806165	D19D9B	4013 805296	TAMARA KUZNECOVA	{"email": "kuznecovatamara.03021980@postgrespro.ru", "phone": "+70569851686"}
0005433806166	D732D1	3495 003562	VYACHESLAV TIKHONOV	{"email": "tikhonov_v_011968@postgrespro.ru", "phone": "+70890687393"}
0005433806167	E56D2B	3081 019129	ANDREY SOROKIN	{"email": "sorokin.a-16121973@postgrespro.ru", "phone": "+70969668716"}
0005433806168	F2FC46	6091 702104	SVETLANA SOKOLOVA	{"phone": "+70360337962"}
0005433806169	F2FC46	3368 292542	EDUARD SEMENOV	{"phone": "+70780472619"}
0005433806170	6C8CC5	8720 729122	DMITRIY MEDVEDEV	{"phone": "+70724215519"}
0005433806171	830AD7	0985 700181	EVGENIYA KULIKOVA	{"email": "evgeniya-kulikova-1967@postgrespro.ru", "phone": "+70477931127"}
0005433806172	000BFF	9704 964069	VYACHESLAV BORISOV	{"email": "borisov_vyacheslav-051981@postgrespro.ru", "phone": "+70233230557"}
0005433806173	B8E7AC	7424 717922	SERGEY SOLOVEV	{"email": "s.solovev_1965@postgrespro.ru", "phone": "+70549395161"}
0005433806174	556549	4592 812665	NIKITA SOKOLOV	{"phone": "+70861762770"}
0005433806175	556549	8696 617273	LYUDMILA GERASIMOVA	{"email": "lgerasimova10031968@postgrespro.ru", "phone": "+70860067152"}
0005433806176	81E3FD	9248 335415	LEONID VOLKOV	{"email": "volkovleonid-1971@postgrespro.ru", "phone": "+70846363412"}
0005433806177	81E3FD	1680 357508	VLADIMIR NOVIKOV	{"phone": "+70506688378"}
0005433806178	A3AC00	2838 758835	ANTONINA POTAPOVA	{"email": "potapova.antonina_27101974@postgrespro.ru", "phone": "+70180607345"}
0005433806179	A3AC00	9047 666927	IRINA ZOTOVA	{"email": "irina.zotova.1983@postgrespro.ru", "phone": "+70111731818"}
0005433806180	C52913	3297 599447	VERA CHERNOVA	{"phone": "+70445841805"}
0005433806181	C0F493	2905 970555	SERGEY SMIRNOV	{"phone": "+70545923735"}
0005433806182	C0F493	5886 159176	VERA SMIRNOVA	{"phone": "+70118743582"}
0005433806183	ADFFFE	1904 815900	ALEKSANDR MIKHAYLOV	{"phone": "+70223187266"}
0005433806184	576E8E	8444 965502	ALEKSANDRA VASILEVA	{"email": "aleksandra-vasileva_121967@postgrespro.ru", "phone": "+70705500398"}
0005433806185	576E8E	5570 765703	INESSA CHERNOVA	{"phone": "+70176680499"}
0005433806186	576E8E	7617 902603	NATALYA POPOVA	{"phone": "+70933442712"}
0005433806187	72E1C9	5023 808576	VALERIY ZAKHAROV	{"email": "valeriyzakharov_29121984@postgrespro.ru", "phone": "+70656508138"}
0005433806188	62D5D3	8469 166890	ANDREY EGOROV	{"phone": "+70931129120"}
0005433806189	3F1B4E	3103 079140	ANNA EFREMOVA	{"email": "a_efremova1973@postgrespro.ru", "phone": "+70542187189"}
0005433806190	3F1B4E	4461 666310	VLADIMIR KAZAKOV	{"phone": "+70854069182"}
0005433806191	0DF184	3868 876660	ELISEY MAKAROV	{"phone": "+70872565537"}
0005433806192	DD2275	9568 161595	NIKITA KULIKOV	{"phone": "+70614487880"}
0005433806193	DD2275	6076 554361	NINA KUZNECOVA	{"email": "kuznecova_n.1968@postgrespro.ru", "phone": "+70569202893"}
0005433806194	91CB22	9065 589922	VIKTOR VOLKOV	{"phone": "+70711199619"}
0005433806195	E21974	4513 310292	ROMAN MIRONOV	{"email": "roman-mironov01101980@postgrespro.ru", "phone": "+70143027069"}
0005433806196	E21974	0230 657837	ALINA NESTEROVA	{"phone": "+70742614798"}
0005433806197	3B55C7	1653 988089	NIKOLAY IVANOV	{"phone": "+70218765515"}
0005433806198	3B55C7	3258 837268	TATYANA ILINA	{"email": "ilinat071967@postgrespro.ru", "phone": "+70143762089"}
0005433806199	BB02BA	6179 771522	NATALYA RODIONOVA	{"email": "nrodionova.1963@postgrespro.ru", "phone": "+70875294899"}
0005433806200	D5790E	6353 885425	EKATERINA ALEKSANDROVA	{"email": "e-aleksandrova1971@postgrespro.ru", "phone": "+70556195062"}
0005433806201	C66831	6757 946980	YANA NAUMOVA	{"email": "y-naumova_12091974@postgrespro.ru", "phone": "+70329748111"}
0005433806202	08A6D4	1245 438900	SERGEY SOROKIN	{"phone": "+70803854077"}
0005433806203	08A6D4	4059 488692	VLADIMIR MOISEEV	{"email": "vladimirmoiseev_20101979@postgrespro.ru", "phone": "+70407419738"}
0005433806204	631609	0180 102822	VERA IVANOVA	{"email": "v-ivanova-1980@postgrespro.ru", "phone": "+70550103737"}
0005433806205	C617C1	7136 248511	IVAN IVANOV	{"email": "ivanov.ivan1959@postgrespro.ru", "phone": "+70848159995"}
0005433806206	C617C1	2410 121525	KSENIYA ZHURAVLEVA	{"phone": "+70107353349"}
0005433806207	2CAFB1	2000 493154	SOFYA KOZLOVA	{"email": "sofyakozlova-091966@postgrespro.ru", "phone": "+70528858103"}
0005433806208	E05293	5370 142520	VIKTOR MAKSIMOV	{"email": "maksimov.v24121966@postgrespro.ru", "phone": "+70022423315"}
0005433806209	EF8A47	9209 301016	VLADIMIR POPOV	{"phone": "+70095289097"}
0005433806210	33EC97	2600 007264	SVETLANA LAZAREVA	{"phone": "+70080149076"}
0005433806211	33EC97	9579 669708	STANISLAV ISAEV	{"email": "isaev-s.1972@postgrespro.ru", "phone": "+70847074867"}
0005433806212	A46397	0964 703090	PETR TIMOFEEV	{"email": "ptimofeev_1968@postgrespro.ru", "phone": "+70413932233"}
0005433806213	A46397	9079 957109	VALERIY GERASIMOV	{"email": "v_gerasimov041978@postgrespro.ru", "phone": "+70992237584"}
0005433806214	D8D366	6299 496472	NATALYA ZHURAVLEVA	{"email": "n-zhuravleva-09081975@postgrespro.ru", "phone": "+70401963862"}
0005433806215	CF19FA	0184 554713	LIDIYA KOZLOVA	{"phone": "+70643199235"}
0005433806216	CF19FA	0231 271119	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya1976@postgrespro.ru", "phone": "+70902526266"}
0005433806217	362512	6307 608864	VERA MATVEEVA	{"email": "vera_matveeva.27111970@postgrespro.ru", "phone": "+70817407624"}
0005433806218	83D816	6754 210903	ALEKSANDR OSIPOV	{"phone": "+70189869790"}
0005433806219	88FF8E	3793 133070	ANNA MELNIKOVA	{"email": "anna_melnikova111978@postgrespro.ru", "phone": "+70734695718"}
0005433806220	88FF8E	9976 651510	OLGA ANTONOVA	{"email": "olga.antonova.29091979@postgrespro.ru", "phone": "+70728603404"}
0005433806221	F58472	4078 421807	RAISA KUZNECOVA	{"email": "r_kuznecova-011984@postgrespro.ru", "phone": "+70049291910"}
0005433806222	F58472	5997 956262	ALEKSANDRA LAZAREVA	{"phone": "+70120878719"}
0005433806223	3933C5	5232 080890	BORIS CHERNOV	{"phone": "+70150396218"}
0005433806224	B890D8	7183 864678	STEPAN MEDVEDEV	{"phone": "+70294873181"}
0005433806225	1B9903	6196 186755	TATYANA BELOVA	{"email": "belovatatyana-1969@postgrespro.ru", "phone": "+70580623603"}
0005433806226	657EC7	8513 071761	ASIYA BORISOVA	{"email": "a.borisova_1956@postgrespro.ru", "phone": "+70459680778"}
0005433806227	A3674C	8635 210096	VIOLETTA NIKITINA	{"phone": "+70196518262"}
0005433806228	EFC693	7516 981734	ALEKSEY ANDREEV	{"email": "aandreev_1966@postgrespro.ru", "phone": "+70276979135"}
0005433806229	EFC693	0461 878739	SERGEY KUZNECOV	{"phone": "+70743223904"}
0005433806230	7EBCDF	5092 823003	MARIYA MEDVEDEVA	{"email": "m_medvedeva1968@postgrespro.ru", "phone": "+70173141465"}
0005433806231	7EBCDF	4892 665109	VALENTINA STEPANOVA	{"phone": "+70703082521"}
0005433806232	8A3D30	3494 334904	AIDA BOGDANOVA	{"phone": "+70022871411"}
0005433806233	F66EEA	9023 733135	ALEKSANDRA YUDINA	{"phone": "+70023471769"}
0005433806234	F66EEA	3098 114275	LYUDMILA KONOVALOVA	{"phone": "+70942715848"}
0005433806235	76D40C	8087 403453	DMITRIY FROLOV	{"phone": "+70064002335"}
0005433806236	617091	3327 377952	NADEZHDA KOROLEVA	{"phone": "+70196834198"}
0005433806237	DC16A3	5374 609500	VLADISLAV PAVLOV	{"phone": "+70004654251"}
0005433806238	F90C7F	9027 413087	EDGAR NAZAROV	{"phone": "+70984528177"}
0005433806239	51FCA0	2986 684037	VLADIMIR GRIGOREV	{"email": "v.grigorev-07051979@postgrespro.ru", "phone": "+70571720555"}
0005433806240	932389	9431 086481	YURIY KUZNECOV	{"email": "yuriy.kuznecov-18091978@postgrespro.ru", "phone": "+70639302363"}
0005433806241	99526F	2047 681767	POLINA KALININA	{"phone": "+70387238079"}
0005433806242	315CC4	1461 566476	ALEKSANDR RODIONOV	{"phone": "+70934086960"}
0005433806243	315CC4	8530 209234	IRINA KULIKOVA	{"phone": "+70175850634"}
0005433806244	650303	3959 581766	SERGEY ILIN	{"email": "ilins_1965@postgrespro.ru", "phone": "+70422610548"}
0005433806245	3E72B8	1145 375148	SERGEY BELOV	{"phone": "+70971522515"}
0005433806246	A97E34	4465 639112	NIKOLAY KULIKOV	{"phone": "+70898135083"}
0005433806247	EA0D80	3270 190624	VLADISLAV STEPANOV	{"email": "vladislav_stepanov-07091968@postgrespro.ru", "phone": "+70095011815"}
0005433806248	C21206	6654 745236	MIKHAIL DENISOV	{"email": "mikhail.denisov-1980@postgrespro.ru", "phone": "+70201409348"}
0005433806249	C21206	5152 122001	TATYANA AFANASEVA	{"email": "afanaseva-tatyana_061968@postgrespro.ru", "phone": "+70883150544"}
0005433806250	C21206	9173 726317	RINAT ISAEV	{"email": "r_isaev-1983@postgrespro.ru", "phone": "+70907239453"}
0005433806251	0ABE36	4905 743103	ALEKSEY MATVEEV	{"email": "aleksey_matveev1968@postgrespro.ru", "phone": "+70226193836"}
0005433806252	5D66E9	6682 475462	GALINA EGOROVA	{"phone": "+70807789542"}
0005433806253	AA06B9	4842 464062	YURIY ZAYCEV	{"email": "yuriy_zaycev-091970@postgrespro.ru", "phone": "+70342286989"}
0005433806254	AA06B9	9508 263012	ALEKSANDR GORBUNOV	{"email": "a.gorbunov.09021975@postgrespro.ru", "phone": "+70786887276"}
0005433806255	6EAD9F	8496 733440	ANATOLIY VASILEV	{"phone": "+70063671100"}
0005433806256	8C2199	5313 513402	VLADIMIR FEDOROV	{"email": "fedorov-vladimir-16071972@postgrespro.ru", "phone": "+70237334842"}
0005433806257	8C2199	3108 312580	IRINA PETROVA	{"phone": "+70462715034"}
0005433806258	E54CE4	5074 419811	ELVIRA GRISHINA	{"email": "elviragrishina_1976@postgrespro.ru", "phone": "+70642693563"}
0005433806259	65757A	1586 557126	ALEKSANDR CHERNOV	{"email": "chernov_a07111965@postgrespro.ru", "phone": "+70650077524"}
0005433806260	1C0D82	8965 895833	VALENTIN CHERNOV	{"email": "vchernov-081982@postgrespro.ru", "phone": "+70876187638"}
0005433806261	94EE49	2462 627833	NIKITA VOROBEV	{"phone": "+70468607346"}
0005433806262	94EE49	6516 437728	ANNA NIKOLAEVA	{"phone": "+70834625160"}
0005433806263	9BDC2B	8587 348355	RUMIYA MOISEEVA	{"email": "rmoiseeva021967@postgrespro.ru", "phone": "+70945720916"}
0005433806264	9BDC2B	9230 410762	VALENTIN MAKAROV	{"phone": "+70128299840"}
0005433806265	159744	9933 570345	ANATOLIY SMIRNOV	{"email": "smirnovanatoliy-1973@postgrespro.ru", "phone": "+70375245452"}
0005433806266	8FA9D7	8497 049059	SANIYA ALEKSEEVA	{"email": "alekseeva-saniya021969@postgrespro.ru", "phone": "+70348888243"}
0005433806267	A66111	9195 852548	VIKTOR TIKHONOV	{"email": "tikhonov-viktor_15051983@postgrespro.ru", "phone": "+70305010101"}
0005433806268	9561E9	1761 291664	ANTONINA KOVALEVA	{"phone": "+70290708725"}
0005433806269	9561E9	2570 584411	TATYANA VLASOVA	{"email": "vlasova_t-24101961@postgrespro.ru", "phone": "+70807621668"}
0005433806270	8AEA27	0306 499656	ARTEM GAVRILOV	{"phone": "+70098463330"}
0005433806271	8AEA27	6188 490212	ELENA NIKITINA	{"email": "e-nikitina_04101964@postgrespro.ru", "phone": "+70203474588"}
0005433806272	AB5729	1335 081441	VALERIY PETROV	{"phone": "+70830794367"}
0005433806273	AB5729	1095 287708	NINA NESTEROVA	{"email": "n-nesterova1982@postgrespro.ru", "phone": "+70605539275"}
0005433806274	AB5729	3386 255806	MAKSIM IVANOV	{"phone": "+70362293708"}
0005433806275	46386D	4166 528584	MARIYA KISELEVA	{"phone": "+70252628079"}
0005433806276	C8D5CD	3265 291304	SVETLANA KAZAKOVA	{"phone": "+70041688473"}
0005433806277	C8D5CD	8665 439290	LYUDMILA FEDOROVA	{"phone": "+70109124842"}
0005433806278	647E5A	8657 440814	ELENA FOMINA	{"email": "fomina_e.24031980@postgrespro.ru", "phone": "+70713435895"}
0005433806279	FAACAB	8336 823509	LYUBOV FROLOVA	{"email": "frolova_lyubov18071976@postgrespro.ru", "phone": "+70919831506"}
0005433806280	FAACAB	7298 765860	RAISA VLASOVA	{"phone": "+70820627824"}
0005433806281	2276E7	8556 582156	ANTONINA RODIONOVA	{"email": "rodionova-antonina-081983@postgrespro.ru", "phone": "+70222805874"}
0005433806282	665F26	4039 334407	OKSANA EGOROVA	{"phone": "+70851006600"}
0005433806283	665F26	3438 900226	NADEZHDA POPOVA	{"phone": "+70428775874"}
0005433806284	D5B520	1990 616485	NINA BORISOVA	{"phone": "+70000382034"}
0005433806285	D5B520	4173 385587	OLGA GAVRILOVA	{"phone": "+70986822346"}
0005433806286	B22A3B	0289 520796	YULIYA KRASNOVA	{"phone": "+70394786972"}
0005433806287	B22A3B	9415 557969	VIKTOR YAKOVLEV	{"email": "viktor-yakovlev_1968@postgrespro.ru", "phone": "+70489772682"}
0005433806288	671E9B	7271 579466	MARIYA FEDOROVA	{"email": "fedorova-mariya20101970@postgrespro.ru", "phone": "+70080805884"}
0005433806289	91BC5C	1637 091361	NIKOLAY FOMIN	{"email": "fomin-nikolay101978@postgrespro.ru", "phone": "+70141449288"}
0005433806290	91BC5C	5718 132935	SERGEY SOKOLOV	{"phone": "+70409594295"}
0005433806291	91BC5C	1564 736733	ALEKSANDR SOKOLOV	{"email": "sokolova-031966@postgrespro.ru", "phone": "+70017672556"}
0005433806292	91BC5C	1276 910319	SERGEY KISELEV	{"phone": "+70147251843"}
0005433806293	A2F63E	7443 615706	ILYA NAZAROV	{"email": "nazarov-ilya-12041967@postgrespro.ru", "phone": "+70102223523"}
0005433806294	A2F63E	0407 064672	TATYANA SOLOVEVA	{"phone": "+70222426850"}
0005433806295	0DD40E	4314 986765	VALERIY BONDARENKO	{"phone": "+70420028345"}
0005433806296	60C7D3	3311 567909	GALINA BORISOVA	{"email": "gborisova.17101964@postgrespro.ru", "phone": "+70608556952"}
0005433806297	403A4A	4473 086654	DARYA SOLOVEVA	{"email": "soloveva-d.15021978@postgrespro.ru", "phone": "+70265073918"}
0005433806298	403A4A	3549 619811	VIKTOR SOROKIN	{"phone": "+70281120237"}
0005433806299	403A4A	4418 724961	ANDREY ABRAMOV	{"phone": "+70557819639"}
0005433806300	FE45F1	6882 085682	NADEZHDA ROMANOVA	{"email": "nadezhdaromanova.24051958@postgrespro.ru", "phone": "+70583259471"}
0005433806301	088880	5866 160346	ALEKSEY MARTYNOV	{"email": "martynov-aleksey_101976@postgrespro.ru", "phone": "+70893469012"}
0005433806302	088880	7000 800295	SVETLANA KONOVALOVA	{"phone": "+70112817670"}
0005433806303	3D27F4	8422 579080	NELLI GORBUNOVA	{"email": "gorbunova_nelli.1974@postgrespro.ru", "phone": "+70990605570"}
0005433806304	6DFC54	1565 941995	IRINA LEBEDEVA	{"phone": "+70522753944"}
0005433806305	6DFC54	2174 658461	LARISA PAVLOVA	{"email": "larisa.pavlova.021963@postgrespro.ru", "phone": "+70613444505"}
0005433806306	CF9E0A	5985 585181	IGOR KOZLOV	{"email": "igor_kozlov.1968@postgrespro.ru", "phone": "+70343464892"}
0005433806307	C374A5	7775 450776	ALEKSANDR BONDARENKO	{"email": "a.bondarenko_1980@postgrespro.ru", "phone": "+70071770763"}
0005433806308	CC70B1	3162 764219	NADEZHDA FROLOVA	{"phone": "+70760312151"}
0005433806309	CC70B1	7886 044206	YURIY GORBUNOV	{"phone": "+70315822067"}
0005433806310	C91B3C	4570 843036	ALEKSEY SERGEEV	{"email": "sergeeva1981@postgrespro.ru", "phone": "+70531203265"}
0005433806311	C91B3C	5339 610937	GENNADIY SOKOLOV	{"email": "sokolovg.22091970@postgrespro.ru", "phone": "+70796486460"}
0005433806312	35402D	3248 115269	TATYANA BARANOVA	{"email": "tatyana_baranova21081969@postgrespro.ru", "phone": "+70655071357"}
0005433806313	35402D	0712 385923	SVETLANA GORBUNOVA	{"phone": "+70855129260"}
0005433806314	56AD31	3399 104892	ELENA NIKOLAEVA	{"email": "nikolaeva-e.111964@postgrespro.ru", "phone": "+70011541221"}
0005433806315	0C3998	8100 972592	ANNA ORLOVA	{"phone": "+70903863813"}
0005433806316	3F23A7	7454 960477	SVETLANA VASILEVA	{"email": "vasileva-svetlana-04031974@postgrespro.ru", "phone": "+70985556166"}
0005433806317	827645	1571 403128	NIKITA TARASOV	{"phone": "+70461736244"}
0005433806318	739D6F	4884 995714	TATYANA VOROBEVA	{"email": "tatyanavorobeva1980@postgrespro.ru", "phone": "+70640819565"}
0005433806319	BA6536	8524 737954	ALEKSEY VASILEV	{"phone": "+70079865922"}
0005433810693	8941AB	6117 164265	ALEKSANDR CHERNOV	{"phone": "+70209609536"}
0005433806320	ED3644	9956 121224	YULIYA ALEKSEEVA	{"email": "yalekseeva-041968@postgrespro.ru", "phone": "+70705327370"}
0005433806321	8849E2	7148 391779	NIKOLAY ILIN	{"phone": "+70675127051"}
0005433806322	8849E2	4157 735033	ANASTASIYA MOISEEVA	{"phone": "+70376585808"}
0005433806323	6F3AD1	2701 088698	RINAT OSIPOV	{"email": "osipov_r.091976@postgrespro.ru", "phone": "+70326135141"}
0005433806324	6F3AD1	5241 572734	VYACHESLAV RODIONOV	{"email": "rodionov.vyacheslav.121973@postgrespro.ru", "phone": "+70364819532"}
0005433806325	F8E5D2	4935 707863	MARIYA MAKAROVA	{"phone": "+70439173625"}
0005433806326	F8E5D2	5550 228163	FARID MARTYNOV	{"email": "farid.martynov_12121964@postgrespro.ru", "phone": "+70331098941"}
0005433806327	E1EE06	4219 204007	MARINA SOKOLOVA	{"email": "m-sokolova13111972@postgrespro.ru", "phone": "+70163642251"}
0005433806328	E1EE06	3492 127717	ALEKSEY VOROBEV	{"email": "avorobev.23041966@postgrespro.ru", "phone": "+70570458346"}
0005433806329	08A568	0843 355044	EVGENIYA KUZMINA	{"email": "kuzmina-e_1972@postgrespro.ru", "phone": "+70933528035"}
0005433806330	08A568	5466 266881	BORIS SOROKIN	{"phone": "+70916723850"}
0005433806331	D7845E	0503 885921	ALEKSEY BORISOV	{"email": "borisov.a1973@postgrespro.ru", "phone": "+70557182761"}
0005433806332	AF0EF8	5949 961929	RUSTEM PAVLOV	{"email": "r.pavlov.1973@postgrespro.ru", "phone": "+70285593743"}
0005433806333	CFCF75	8681 883027	SVETLANA NAUMOVA	{"email": "naumova_svetlana.20121967@postgrespro.ru", "phone": "+70832706768"}
0005433806334	EDA960	4106 802527	TATYANA PAVLOVA	{"phone": "+70202643970"}
0005433806335	4A6505	2532 520690	RADMIR ANTONOV	{"email": "antonov-r011976@postgrespro.ru", "phone": "+70251535004"}
0005433806336	E9B1A6	9220 710458	VLADIMIR SIDOROV	{"email": "vsidorov.1981@postgrespro.ru", "phone": "+70900476700"}
0005433806337	5B71D8	4423 373675	LIDIYA GERASIMOVA	{"phone": "+70693281024"}
0005433806338	1814FB	6123 113013	EVGENIY ZAKHAROV	{"phone": "+70602304955"}
0005433806339	314C8F	4198 606923	ALEKSANDR FEDOTOV	{"email": "a.fedotov-19101974@postgrespro.ru", "phone": "+70453139249"}
0005433806340	314C8F	6178 456794	VALENTINA SOROKINA	{"phone": "+70519793406"}
0005433806341	9F680E	2064 727303	SEMEN ISAEV	{"phone": "+70877193580"}
0005433806342	9F680E	5516 912369	NIKOLAY EGOROV	{"phone": "+70919986590"}
0005433806343	DEF1E9	9439 946538	RASIM IVANOV	{"phone": "+70325277364"}
0005433806344	5EC19F	1721 420689	RAISA ILINA	{"email": "ilina-r11121974@postgrespro.ru", "phone": "+70210718219"}
0005433806345	5EC19F	8360 563138	MARINA NOVIKOVA	{"email": "novikova.marina.07051978@postgrespro.ru", "phone": "+70829454375"}
0005433806346	DCF205	1477 262264	SVETLANA FROLOVA	{"phone": "+70468567805"}
0005433806347	DCF205	3496 800211	MARGARITA KONDRATEVA	{"email": "kondrateva-margarita_21011965@postgrespro.ru", "phone": "+70184148065"}
0005433806348	F9BD59	7211 770543	ANNA MOISEEVA	{"phone": "+70377657320"}
0005433806349	E22D08	7422 464668	MARIYA ANTONOVA	{"email": "mariya-antonova.21011972@postgrespro.ru", "phone": "+70983977923"}
0005433806350	E22D08	4002 700742	TATYANA STEPANOVA	{"phone": "+70516611945"}
0005433806351	492AF6	0841 718325	OLEG VASILEV	{"email": "oleg.vasilev-04061959@postgrespro.ru", "phone": "+70417777924"}
0005433806352	492AF6	6099 347677	ILYA GERASIMOV	{"email": "i_gerasimov.11101965@postgrespro.ru", "phone": "+70263619876"}
0005433806353	A277D9	3880 582528	KONSTANTIN NIKITIN	{"phone": "+70495559307"}
0005433806354	A277D9	5718 973186	EVGENIY CHERNOV	{"phone": "+70158116994"}
0005433806355	A277D9	3266 020878	ALEKSEY BORISOV	{"email": "borisov.aleksey_1978@postgrespro.ru", "phone": "+70456901901"}
0005433806356	38B75D	9006 397293	SERGEY MIRONOV	{"phone": "+70918311526"}
0005433806357	E7EAF4	2360 489051	LILIYA VOLKOVA	{"phone": "+70797788990"}
0005433806358	538540	9569 535866	ALEKSANDR TARASOV	{"email": "tarasova.07091974@postgrespro.ru", "phone": "+70930926638"}
0005433806359	538540	7788 337663	EGOR ROMANOV	{"phone": "+70248626412"}
0005433806360	F4487D	9887 584344	VLADIMIR FROLOV	{"email": "frolovv07091972@postgrespro.ru", "phone": "+70870548700"}
0005433806361	C0BDBF	8051 754527	TAMARA KUZNECOVA	{"phone": "+70975137678"}
0005433806362	5E8528	1692 602306	ANDREY BONDARENKO	{"phone": "+70614295245"}
0005433806363	5E8528	8081 205948	MARIYA KUDRYASHOVA	{"email": "m_kudryashova.041962@postgrespro.ru", "phone": "+70435328781"}
0005433806364	7D0BC5	7274 760834	ELENA BOGDANOVA	{"email": "bogdanova.elena.1972@postgrespro.ru", "phone": "+70649172239"}
0005433806365	7D0BC5	8114 249032	ANASTASIYA MEDVEDEVA	{"email": "medvedeva_anastasiya061977@postgrespro.ru", "phone": "+70448421581"}
0005433806366	D55F8C	9609 121020	ALEKSANDR GERASIMOV	{"email": "gerasimov.a_1973@postgrespro.ru", "phone": "+70597251131"}
0005433806367	8EFBF4	3058 610241	ALEKSANDR BORISOV	{"phone": "+70948421073"}
0005433806368	6F4425	6173 844033	INNA ERMAKOVA	{"email": "inna.ermakova_121965@postgrespro.ru", "phone": "+70112831741"}
0005433806369	40926C	8991 693861	ANATOLIY SCHERBAKOV	{"phone": "+70383492041"}
0005433806370	FD03CF	2763 833627	MARINA KRASNOVA	{"phone": "+70589578401"}
0005433806371	FD03CF	6046 279868	ELENA DENISOVA	{"email": "e.denisova041987@postgrespro.ru", "phone": "+70892804475"}
0005433806372	D8AC19	7181 926434	ARTEM DENISOV	{"email": "denisova_051975@postgrespro.ru", "phone": "+70092009164"}
0005433806373	D8AC19	9713 576275	NATALYA ROMANOVA	{"phone": "+70976806846"}
0005433806374	B741AA	7854 634600	ILYA KOZLOV	{"email": "kozlov_i-031967@postgrespro.ru", "phone": "+70130926562"}
0005433806375	915123	9835 942866	FARIT ISAEV	{"email": "f-isaev.1967@postgrespro.ru", "phone": "+70516465377"}
0005433806376	5BBD75	5295 132312	TAGIR DENISOV	{"phone": "+70341421603"}
0005433806377	ED43F4	9708 707060	ANATOLIY KRASNOV	{"phone": "+70158357268"}
0005433806378	0A5547	4429 574064	TATYANA SEMENOVA	{"phone": "+70080531164"}
0005433806379	57C6A8	6240 059506	KLAVDIYA MIRONOVA	{"email": "klavdiya_mironova21111971@postgrespro.ru", "phone": "+70286563763"}
0005433806380	8D1A46	5209 823630	GALINA KULIKOVA	{"email": "g-kulikova.1969@postgrespro.ru", "phone": "+70651163180"}
0005433806381	48482E	2340 741703	VALERIY ROMANOV	{"email": "valeriy.romanov_1977@postgrespro.ru", "phone": "+70116595517"}
0005433806382	CE50AE	8185 329718	EVGENIYA PETROVA	{"email": "epetrova-19091964@postgrespro.ru", "phone": "+70225102514"}
0005433806383	99694E	5100 604088	EVGENIY KOZLOV	{"email": "e.kozlov-021975@postgrespro.ru", "phone": "+70322899201"}
0005433806384	7FA7BC	1702 859654	GALINA SERGEEVA	{"phone": "+70048548165"}
0005433806385	E28091	1277 295516	ANTON BARANOV	{"email": "baranovanton1977@postgrespro.ru", "phone": "+70694638966"}
0005433806386	EE9CB0	7590 870769	SERGEY ZHURAVLEV	{"phone": "+70210007319"}
0005433806387	01801D	6464 145357	VLADIMIR CHERNOV	{"phone": "+70065488800"}
0005433806388	06E918	6081 375448	VALENTIN FOMIN	{"phone": "+70153963014"}
0005433806389	06E918	0767 205787	VERA OVCHINNIKOVA	{"email": "vera_ovchinnikova111969@postgrespro.ru", "phone": "+70445082748"}
0005433806390	F0D707	4993 946660	LYUDMILA KARPOVA	{"phone": "+70406594355"}
0005433806391	DFB9E5	6815 137035	VERA OSIPOVA	{"email": "osipovav.111967@postgrespro.ru", "phone": "+70818476812"}
0005433806392	DFB9E5	0541 394224	MIKHAIL IVANOV	{"email": "m_ivanov-031975@postgrespro.ru", "phone": "+70223551464"}
0005433806393	9BFEBB	6055 009188	VIKTOR SEMENOV	{"email": "viktor_semenov1969@postgrespro.ru", "phone": "+70323133187"}
0005433806394	5AEA8C	2443 581485	IVAN PETROV	{"email": "petrov-ivan_1980@postgrespro.ru", "phone": "+70526601753"}
0005433806395	5AEA8C	2204 562298	SERGEY MELNIKOV	{"phone": "+70793029087"}
0005433806396	4D611A	2449 253783	SOFIYA KUZMINA	{"phone": "+70599504355"}
0005433806397	1C046C	7734 099141	SVETLANA KOLESNIKOVA	{"email": "kolesnikova-svetlana1969@postgrespro.ru", "phone": "+70053299179"}
0005433806398	B222A7	5397 291584	ALEKSANDR DAVYDOV	{"email": "a.davydov051977@postgrespro.ru", "phone": "+70136153469"}
0005433806399	A522FF	3468 386459	ZINAIDA TITOVA	{"email": "titova_zinaida-07041967@postgrespro.ru", "phone": "+70612205575"}
0005433806400	EC53CE	4598 367115	OKSANA ZAKHAROVA	{"email": "zakharova.o_051974@postgrespro.ru", "phone": "+70823737196"}
0005433806401	EC53CE	9709 819024	ALINA SMIRNOVA	{"email": "smirnova_alina-15121966@postgrespro.ru", "phone": "+70477496397"}
0005433806402	348269	3143 843839	SERGEY KUZNECOV	{"email": "sergey.kuznecov_27021973@postgrespro.ru", "phone": "+70386702036"}
0005433806403	348269	3883 287705	KRISTINA IVANOVA	{"phone": "+70588226400"}
0005433806404	AD9AB7	5222 570256	ALEKSANDR ALEKSEEV	{"phone": "+70589387302"}
0005433806405	AD9AB7	7228 348260	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova.aleksandra01101976@postgrespro.ru", "phone": "+70636281675"}
0005433806406	AE09E0	2205 950915	MAKSIM IVANOV	{"email": "maksim.ivanov.071971@postgrespro.ru", "phone": "+70205922228"}
0005433806407	773B52	2379 791336	ANASTASIYA ALEKSEEVA	{"email": "alekseeva_a-1971@postgrespro.ru", "phone": "+70060540992"}
0005433806408	773B52	8737 596759	POLINA MEDVEDEVA	{"phone": "+70373530104"}
0005433806409	AA2C32	9831 381118	VLADIMIR STEPANOV	{"phone": "+70958326132"}
0005433806410	3DA8E2	8056 996177	OLGA SOLOVEVA	{"phone": "+70718027944"}
0005433806411	FEA98A	8028 826629	SERGEY NAZAROV	{"email": "nazarovs31121967@postgrespro.ru", "phone": "+70952451150"}
0005433806412	4FC1D8	2542 979175	DIANA GORBUNOVA	{"email": "gorbunova-diana.1972@postgrespro.ru", "phone": "+70733890789"}
0005433808304	E7506A	1244 378331	OLGA KUZNECOVA	{"phone": "+70612465389"}
0005433808305	E7506A	3588 330419	ALEKSANDR SERGEEV	{"phone": "+70095687210"}
0005433808306	0BB4DC	8455 624381	OLGA LUKYANOVA	{"phone": "+70234357630"}
0005433808307	11DA82	4147 695173	MAKSIM ISAEV	{"phone": "+70579700799"}
0005433808308	11DA82	0693 751205	GENNADIY SOROKIN	{"email": "g_sorokin16041986@postgrespro.ru", "phone": "+70393152804"}
0005433808309	11DA82	0786 896861	SERGEY SEMENOV	{"phone": "+70267488732"}
0005433808310	FEA1D3	6950 251000	IRINA KOLESNIKOVA	{"email": "kolesnikova-irina_03051973@postgrespro.ru", "phone": "+70423321853"}
0005433808311	D380C5	8489 579053	LYUBOV BORISOVA	{"email": "borisova_l.14011964@postgrespro.ru", "phone": "+70603484749"}
0005433808312	AE0F44	9409 067266	OLESYA ALEKSEEVA	{"phone": "+70375330844"}
0005433808313	AE0F44	3177 885212	LYUBOV NAZAROVA	{"email": "nazarova-l1969@postgrespro.ru", "phone": "+70828727783"}
0005433808314	12AE85	8424 744784	IRINA FROLOVA	{"email": "frolova.irina_1962@postgrespro.ru", "phone": "+70138638648"}
0005433808315	12AE85	2942 643435	STANISLAV OSIPOV	{"phone": "+70414120951"}
0005433808316	EE8747	6836 975789	OLGA IVANOVA	{"phone": "+70787627688"}
0005433808317	E496AC	5423 820400	DARYA PAVLOVA	{"phone": "+70516335655"}
0005433808318	0854A8	8931 083488	ALEKSANDRA DAVYDOVA	{"email": "a_davydova_111963@postgrespro.ru", "phone": "+70786706958"}
0005433808319	42885E	4961 177449	VIKTORIYA VOROBEVA	{"email": "vorobeva_v-041977@postgrespro.ru", "phone": "+70896252835"}
0005433808320	0DDF74	5460 275859	ALEKSEY MAKAROV	{"email": "makarov.aleksey.011973@postgrespro.ru", "phone": "+70384794998"}
0005433808321	7C1D7E	7593 510439	DMITRIY VLASOV	{"email": "dmitriyvlasov121980@postgrespro.ru", "phone": "+70015212173"}
0005433808322	7C1D7E	6394 795651	NATALYA GRISHINA	{"email": "grishina.n-1970@postgrespro.ru", "phone": "+70241925030"}
0005433808323	C42427	9232 872034	ALEKSANDR OSIPOV	{"phone": "+70119335110"}
0005433808324	588469	1439 439594	MADINA NIKITINA	{"email": "m-nikitina-16121978@postgrespro.ru", "phone": "+70069232932"}
0005433808325	588469	5544 173550	NINA VOLKOVA	{"phone": "+70197512386"}
0005433808326	C6F305	6729 355061	SERGEY KOROLEV	{"phone": "+70045016963"}
0005433808327	3593A0	5492 098814	EKATERINA PAVLOVA	{"phone": "+70177951010"}
0005433808328	BCD0F3	5431 376407	NIKOLAY MIRONOV	{"email": "mironov.n_1969@postgrespro.ru", "phone": "+70702157883"}
0005433808329	4EEB74	4992 663855	ALBINA EFREMOVA	{"phone": "+70805107319"}
0005433808330	6C269D	4218 230237	VENIAMIN GAVRILOV	{"email": "veniamin-gavrilov26031974@postgrespro.ru", "phone": "+70279167624"}
0005433808331	237CDE	8125 704666	ELLA TIMOFEEVA	{"email": "timofeeva.ella1975@postgrespro.ru", "phone": "+70325720198"}
0005433808332	237CDE	5635 054369	GALINA MIKHAYLOVA	{"phone": "+70638956119"}
0005433808333	9F0D16	3089 693534	ALEKSANDR SOKOLOV	{"phone": "+70984919553"}
0005433808334	7BE3E8	7101 392305	LILIYA ARKHIPOVA	{"email": "liliya-arkhipova15051977@postgrespro.ru", "phone": "+70757453233"}
0005433808335	7BE3E8	1726 314098	VIKTORIYA SCHERBAKOVA	{"email": "vscherbakova081977@postgrespro.ru", "phone": "+70818710001"}
0005433808336	A62880	9576 975375	KLAVDIYA LEBEDEVA	{"phone": "+70268895640"}
0005433808337	8A82B5	0155 494109	VALERIY BORISOV	{"phone": "+70021941852"}
0005433808338	856C02	2489 681875	NADEZHDA NOVIKOVA	{"phone": "+70121054218"}
0005433808339	FD39B3	4438 738519	NIKITA MELNIKOV	{"email": "nikita-melnikov-1978@postgrespro.ru", "phone": "+70451616273"}
0005433808340	FD39B3	0823 919882	ALEKSEY STEPANOV	{"phone": "+70299859875"}
0005433808341	FD39B3	3735 800721	STANISLAV ISAEV	{"phone": "+70230839633"}
0005433808342	43F2AF	4629 335371	TAMARA IVANOVA	{"email": "t-ivanova-10111970@postgrespro.ru", "phone": "+70209788822"}
0005433808343	E5B1FE	3160 269314	NADEZHDA NAUMOVA	{"email": "naumova-n.12011984@postgrespro.ru", "phone": "+70476212797"}
0005433808344	7D7036	9667 019890	EVGENIY IVANOV	{"email": "evgeniyivanov.19061968@postgrespro.ru", "phone": "+70557448451"}
0005433808345	FC2D84	4189 594921	NINA SEMENOVA	{"phone": "+70279393861"}
0005433808346	FC2D84	6431 576365	ALEKSANDR KUZNECOV	{"phone": "+70010155771"}
0005433808347	CBAC77	1241 111066	MARIYA TIMOFEEVA	{"phone": "+70379008678"}
0005433808348	5AE597	0339 833454	GEORGIY DENISOV	{"email": "denisov_georgiy_091973@postgrespro.ru", "phone": "+70624944542"}
0005433808349	E5F83F	9280 423281	LILIYA ABRAMOVA	{"email": "l_abramova.02121974@postgrespro.ru", "phone": "+70274187505"}
0005433808350	5762E4	5906 209016	SERGEY ORLOV	{"phone": "+70174346023"}
0005433808351	F57266	0800 510381	VLADIMIR TARASOV	{"email": "vladimir.tarasov_27051966@postgrespro.ru", "phone": "+70373472591"}
0005433808352	F57266	9307 063198	ANDREY POPOV	{"phone": "+70327137281"}
0005433808353	4DAA97	7715 039397	DMITRIY NAZAROV	{"phone": "+70228351569"}
0005433808354	4DAA97	7038 316849	VITALIY KUZNECOV	{"phone": "+70426425125"}
0005433808355	204E70	0162 287412	VYACHESLAV IVANOV	{"email": "vyacheslav_ivanov.1979@postgrespro.ru", "phone": "+70048271290"}
0005433808356	5B7AFD	4634 532863	YURIY TIMOFEEV	{"email": "y_timofeev_05101970@postgrespro.ru", "phone": "+70893872951"}
0005433808357	3459DE	5013 726458	NIKOLAY SMIRNOV	{"phone": "+70716926049"}
0005433808358	55C0CD	8130 943927	GENNADIY TIKHONOV	{"phone": "+70908791982"}
0005433808359	92CC95	9684 478564	VERA MARTYNOVA	{"phone": "+70812902340"}
0005433808360	92CC95	6360 263859	FARID POPOV	{"email": "popov-farid_09031975@postgrespro.ru", "phone": "+70285147050"}
0005433808361	92CC95	9669 043882	INNA TIMOFEEVA	{"email": "timofeeva_i_051961@postgrespro.ru", "phone": "+70752726228"}
0005433808362	F8EE39	1869 109173	VALENTIN SAVELEV	{"email": "v-savelev.031959@postgrespro.ru", "phone": "+70139096369"}
0005433808363	F8EE39	9793 022696	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov_111985@postgrespro.ru", "phone": "+70783532836"}
0005433808364	2D7853	4012 558681	TATYANA NIKITINA	{"phone": "+70133564925"}
0005433808365	C1B59E	8719 130568	VIKTOR VASILEV	{"phone": "+70334979087"}
0005433808366	99FF5E	7614 994721	IRINA CHERNOVA	{"email": "chernova_i.111969@postgrespro.ru", "phone": "+70449761212"}
0005433808367	B4ABC7	2866 551351	VIKTOR AFANASEV	{"email": "viktor.afanasev_1973@postgrespro.ru", "phone": "+70570798516"}
0005433808368	B66430	1302 921947	ANDREY MEDVEDEV	{"email": "andreymedvedev.021969@postgrespro.ru", "phone": "+70160315621"}
0005433808369	8B8A8F	4105 005528	NINA PAVLOVA	{"phone": "+70407505282"}
0005433808370	3B27FD	2551 531232	VYACHESLAV BORISOV	{"email": "borisovvyacheslav.28041970@postgrespro.ru", "phone": "+70378953605"}
0005433808371	4C4ACE	5863 874924	DMITRIY MAKSIMOV	{"phone": "+70548666593"}
0005433808372	4C4ACE	3894 861840	OLGA VLASOVA	{"phone": "+70961498182"}
0005433808373	759FE1	4316 386310	LIDIYA ANDREEVA	{"email": "andreeva.lidiya.22031977@postgrespro.ru", "phone": "+70405982854"}
0005433808374	759FE1	8357 323323	VLADIMIR NOVIKOV	{"email": "v_novikov-1966@postgrespro.ru", "phone": "+70242375857"}
0005433808375	759FE1	8480 390333	ANTON BELOV	{"phone": "+70475934379"}
0005433808376	5486E8	4702 531227	SERGEY GRIGOREV	{"email": "sergeygrigorev1967@postgrespro.ru", "phone": "+70293708070"}
0005433808377	5486E8	7904 084236	IVAN FROLOV	{"email": "frolov.ivan-1980@postgrespro.ru", "phone": "+70622925218"}
0005433808378	5486E8	7177 218200	ALEKSANDR TIKHONOV	{"phone": "+70742531747"}
0005433808379	F62E99	5083 961944	TAMARA AKIMOVA	{"email": "akimova.t-101970@postgrespro.ru", "phone": "+70338470520"}
0005433808380	C413D0	1518 404330	ALEKSEY SAVELEV	{"phone": "+70052096883"}
0005433808381	74CFDD	3003 283758	EVGENIYA YUDINA	{"email": "yudina_e.05031978@postgrespro.ru", "phone": "+70185987393"}
0005433808382	5AFBE5	0129 995398	VALENTINA MEDVEDEVA	{"phone": "+70462330341"}
0005433808383	996D80	4535 550126	ANDREY ABRAMOV	{"phone": "+70956254901"}
0005433808384	996D80	3435 934139	LYUBOV TIMOFEEVA	{"phone": "+70229332680"}
0005433808385	333037	4308 780586	IGOR AFANASEV	{"phone": "+70722462461"}
0005433808386	4DE8B1	4424 188318	LYUDMILA NIKOLAEVA	{"email": "nikolaeva-l_061968@postgrespro.ru", "phone": "+70735012006"}
0005433808387	4DE8B1	0658 210272	TATYANA PAVLOVA	{"email": "pavlova_t.041966@postgrespro.ru", "phone": "+70470623384"}
0005433808388	B009A4	5611 215701	YURIY SCHERBAKOV	{"email": "scherbakov-yuriy_1962@postgrespro.ru", "phone": "+70772142771"}
0005433808389	B009A4	7530 113135	OLGA ROMANOVA	{"phone": "+70042993871"}
0005433808390	94441C	6370 122704	NATALYA FILATOVA	{"email": "filatova.natalya081964@postgrespro.ru", "phone": "+70167817464"}
0005433808391	2F2DC3	6798 164671	NIKITA IVANOV	{"phone": "+70978146458"}
0005433808392	26B9F4	7296 892892	EGOR ILIN	{"phone": "+70442625110"}
0005433808393	5AB2B4	4302 319209	VERONIKA SIDOROVA	{"phone": "+70441896245"}
0005433808394	CA0E77	3306 232488	MIKHAIL IVANOV	{"email": "ivanov-m-011969@postgrespro.ru", "phone": "+70020874354"}
0005433808395	D66D6A	6420 828062	ANASTASIYA MELNIKOVA	{"phone": "+70636022123"}
0005433808396	0D459E	8761 610936	DMITRIY MIKHAYLOV	{"email": "mikhaylovdmitriy10031975@postgrespro.ru", "phone": "+70752610178"}
0005433808397	AD9F07	0882 852591	VERA FOMINA	{"phone": "+70706518936"}
0005433808398	C9F590	5948 224290	VYACHESLAV KULIKOV	{"email": "kulikov_vyacheslav.091970@postgrespro.ru", "phone": "+70354899053"}
0005433808399	048E34	6913 507305	ELENA MALYSHEVA	{"phone": "+70087100669"}
0005433808400	9C4C78	0670 876837	VALENTINA VOLKOVA	{"email": "v_volkova16041982@postgrespro.ru", "phone": "+70553993612"}
0005433808401	9C4C78	0214 702857	EVGENIY VLASOV	{"phone": "+70637695452"}
0005433808402	05F2F4	5409 647344	VALENTINA GORBUNOVA	{"phone": "+70573852734"}
0005433808403	05A9AB	5545 241675	VALERIY BARANOV	{"phone": "+70269362092"}
0005433808404	9A5260	5164 809510	ALEKSANDR NIKOLAEV	{"phone": "+70785792974"}
0005433808405	A3DF29	6587 640751	ALEKSEY GUSEV	{"phone": "+70093131161"}
0005433808406	81E227	0211 983005	VASILIY EGOROV	{"email": "egorov.v.1971@postgrespro.ru", "phone": "+70788758735"}
0005433808407	232A10	6052 665812	NIKOLAY SOROKIN	{"email": "sorokinnikolay_081975@postgrespro.ru", "phone": "+70359419037"}
0005433808408	6E4EE8	6755 867346	EVGENIYA SEMENOVA	{"email": "semenova_e.101977@postgrespro.ru", "phone": "+70849743285"}
0005433808409	0A378B	5705 861549	SVETLANA PETROVA	{"phone": "+70263219277"}
0005433808410	79AF26	0701 097837	ALEKSANDR PETROV	{"phone": "+70290318053"}
0005433808411	79AF26	6228 152509	ANDREY KUZMIN	{"phone": "+70509624623"}
0005433808412	EFB18E	5938 780180	FEDOR ANDREEV	{"email": "andreevf18121973@postgrespro.ru", "phone": "+70216500578"}
0005433808413	EFB18E	8211 695239	VLADIMIR PAVLOV	{"phone": "+70714916686"}
0005433808414	908F9B	8211 098512	ALINA SAVELEVA	{"phone": "+70203078182"}
0005433808415	7E1EF1	6380 720706	POLINA BELYAEVA	{"email": "polina-belyaeva-041985@postgrespro.ru", "phone": "+70889725776"}
0005433808416	F5B2B8	0353 933558	STANISLAV VASILEV	{"phone": "+70896028361"}
0005433808417	F5B2B8	5510 468412	VIKTORIYA SOLOVEVA	{"phone": "+70437597486"}
0005433808418	F5B2B8	6623 009321	PAVEL KARPOV	{"email": "pavel_karpov081963@postgrespro.ru", "phone": "+70557633177"}
0005433808419	BCFD8F	7974 039077	ALEKSEY MIKHAYLOV	{"email": "aleksey.mikhaylov.121962@postgrespro.ru", "phone": "+70797558461"}
0005433808420	A5CDF4	9105 465122	GRIGORIY POPOV	{"email": "popovg-111975@postgrespro.ru", "phone": "+70277436575"}
0005433808421	A5CDF4	0094 563631	TATYANA SCHERBAKOVA	{"phone": "+70767450325"}
0005433808422	A34714	9294 118321	OLGA ZAYCEVA	{"email": "zaycevaolga_19081965@postgrespro.ru", "phone": "+70608594550"}
0005433808423	A34714	2267 292643	GALINA MEDVEDEVA	{"phone": "+70038001567"}
0005433808424	A795EA	3498 836083	VALENTINA ANTONOVA	{"email": "antonova_valentina.18041976@postgrespro.ru", "phone": "+70251301510"}
0005433808425	A795EA	2515 767916	MARGARITA ALEKSANDROVA	{"email": "aleksandrova.m1956@postgrespro.ru", "phone": "+70277638674"}
0005433808426	A795EA	6168 249841	ELENA DAVYDOVA	{"email": "elena_davydova-05021973@postgrespro.ru", "phone": "+70901363326"}
0005433808427	84C6C1	3275 955395	IRINA MELNIKOVA	{"email": "melnikova.i_051978@postgrespro.ru", "phone": "+70709418524"}
0005433808428	B20010	6834 080628	RODION NOVIKOV	{"phone": "+70469180934"}
0005433808429	F57431	0982 679955	ANATOLIY STEPANOV	{"phone": "+70237279668"}
0005433808430	8EE085	8267 567994	TATYANA FOMINA	{"phone": "+70057061227"}
0005433808431	383797	1205 504258	ALISA BARANOVA	{"phone": "+70825140552"}
0005433808432	7936B9	2818 768664	ELENA SIDOROVA	{"email": "elena-sidorova_1977@postgrespro.ru", "phone": "+70671518314"}
0005433808433	100B26	8265 011949	YULIYA MIKHAYLOVA	{"email": "yuliya-mikhaylova_1971@postgrespro.ru", "phone": "+70734546338"}
0005433808434	100B26	5055 332973	GALINA KOROLEVA	{"phone": "+70053125773"}
0005433808435	947AFD	1116 058010	EVGENIY SOLOVEV	{"email": "soloveve-27041971@postgrespro.ru", "phone": "+70931077452"}
0005433808436	CBAAD2	1973 475136	YURIY SEMENOV	{"email": "yuriysemenov.1983@postgrespro.ru", "phone": "+70970813413"}
0005433808437	CBAAD2	0546 022813	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy.061986@postgrespro.ru", "phone": "+70915610179"}
0005433808438	CBAAD2	4856 923270	SERGEY OSIPOV	{"phone": "+70728424911"}
0005433808439	0FF7F3	9248 576696	ARTEM ZAYCEV	{"email": "zaycev-artem-041967@postgrespro.ru", "phone": "+70703625731"}
0005433808440	798220	6750 298896	NIKOLAY PAVLOV	{"email": "pavlovn_1957@postgrespro.ru", "phone": "+70896112559"}
0005433808441	811293	9587 593214	ALEKSANDRA VOROBEVA	{"phone": "+70601905908"}
0005433808442	811293	9048 417010	ALEKSANDR KULIKOV	{"phone": "+70452445973"}
0005433808443	811293	3950 098015	ANATOLIY NIKITIN	{"email": "a.nikitin051981@postgrespro.ru", "phone": "+70839081070"}
0005433808444	6ED89C	9682 340158	VALENTINA EGOROVA	{"email": "egorova.valentina-051966@postgrespro.ru", "phone": "+70352098355"}
0005433808445	6ED89C	2049 533312	VLADIMIR MAKSIMOV	{"phone": "+70136387442"}
0005433808446	E0B163	9382 601050	NIKOLAY MATVEEV	{"email": "matveevnikolay-101968@postgrespro.ru", "phone": "+70779571827"}
0005433808447	7C36ED	8288 249294	IRINA ERMAKOVA	{"phone": "+70951918075"}
0005433808448	C835A4	7730 335055	NIKITA OSIPOV	{"phone": "+70787739513"}
0005433808449	C835A4	2841 356629	ELENA KUZMINA	{"email": "elena-kuzmina.1969@postgrespro.ru", "phone": "+70700345041"}
0005433810754	7809B0	3757 976130	ANTON ROMANOV	{"phone": "+70034946163"}
0005433808450	E8A638	8417 853875	ALEKSANDR TARASOV	{"email": "tarasovaleksandr091975@postgrespro.ru", "phone": "+70994008355"}
0005433808451	B2E5BF	8861 087157	ANTONINA PAVLOVA	{"phone": "+70809282557"}
0005433808452	77EDC6	5506 218428	LIDIYA KAZAKOVA	{"phone": "+70554168297"}
0005433808453	75428E	7020 735275	VLADIMIR SCHERBAKOV	{"email": "scherbakovv1970@postgrespro.ru", "phone": "+70350240981"}
0005433808454	75428E	8813 079466	VLADIMIR BORISOV	{"email": "borisovv.11111964@postgrespro.ru", "phone": "+70999803689"}
0005433808455	638897	5867 829696	NATALYA MELNIKOVA	{"email": "n-melnikova.011977@postgrespro.ru", "phone": "+70121667113"}
0005433808456	6296F3	2177 374317	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev_111969@postgrespro.ru", "phone": "+70499305543"}
0005433808457	6296F3	2574 444680	LYUDMILA BELYAEVA	{"phone": "+70856958859"}
0005433808458	BEB103	2002 140604	GALINA BORISOVA	{"email": "g.borisova_01021981@postgrespro.ru", "phone": "+70308532312"}
0005433808459	C6EBAC	6664 483957	VALERIY TARASOV	{"phone": "+70188852704"}
0005433808460	6103EB	8593 706706	FANIYA KOZLOVA	{"phone": "+70671739340"}
0005433808461	0750C7	7832 163083	VLADIMIR MEDVEDEV	{"email": "medvedev-vladimir-1974@postgrespro.ru", "phone": "+70432045000"}
0005433808462	0750C7	4815 767473	VERONIKA LUKYANOVA	{"email": "lukyanova.veronika1976@postgrespro.ru", "phone": "+70618357456"}
0005433808463	E96750	6654 091186	NINA FILIPPOVA	{"email": "filippova-n.08121966@postgrespro.ru", "phone": "+70308998280"}
0005433808464	861689	8777 626210	ANASTASIYA LOGINOVA	{"email": "loginova.a-1977@postgrespro.ru", "phone": "+70140221261"}
0005433808465	AC55A6	9291 842366	EVGENIY TIMOFEEV	{"email": "evgeniy.timofeev18091968@postgrespro.ru", "phone": "+70178474990"}
0005433808466	B45518	9461 407751	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov071972@postgrespro.ru", "phone": "+70618021179"}
0005433808467	B45518	5132 541653	SERGEY FILIPPOV	{"phone": "+70947664316"}
0005433808468	B45518	2073 305506	NATALYA CHERNOVA	{"phone": "+70026197992"}
0005433808469	B45518	8455 412964	NATALYA NIKIFOROVA	{"phone": "+70811972335"}
0005433808470	C1DC4A	0287 563084	ANATOLIY KONOVALOV	{"phone": "+70043460984"}
0005433808471	B1B0E8	7953 822501	VIKTORIYA NESTEROVA	{"phone": "+70612354491"}
0005433808472	B1B0E8	0373 578982	OLEG VASILEV	{"phone": "+70731533117"}
0005433808473	732793	9723 235433	VYACHESLAV FROLOV	{"email": "vyacheslav_frolov-1972@postgrespro.ru", "phone": "+70203429749"}
0005433808474	19BB91	8886 236337	TATYANA SIDOROVA	{"phone": "+70396408978"}
0005433808475	19BB91	1481 805380	DMITRIY VASILEV	{"email": "vasilev_dmitriy26071982@postgrespro.ru", "phone": "+70175526554"}
0005433808476	15EAFD	4507 413517	RUSLAN MATVEEV	{"email": "matveev.r-1971@postgrespro.ru", "phone": "+70065197917"}
0005433808477	15EAFD	0929 322977	NADEZHDA DENISOVA	{"email": "denisova.n1970@postgrespro.ru", "phone": "+70176112638"}
0005433808478	D4E8BE	4337 539139	VALERIY POPOV	{"phone": "+70084459178"}
0005433808479	F8DCDE	9125 903265	SVETLANA DAVYDOVA	{"email": "sdavydova-011962@postgrespro.ru", "phone": "+70360350733"}
0005433808480	32E6F6	3446 406568	ANDREY IVANOV	{"email": "andrey.ivanov.28081973@postgrespro.ru", "phone": "+70494692629"}
0005433808481	F7A675	3307 812308	ALINA ABRAMOVA	{"phone": "+70276558579"}
0005433808482	F7A675	1868 042767	SERGEY VOLKOV	{"email": "s-volkov-041977@postgrespro.ru", "phone": "+70693677314"}
0005433808483	687F55	9783 906746	LEONID NOVIKOV	{"phone": "+70833107813"}
0005433808484	CC8D50	1578 426099	GALINA IVANOVA	{"phone": "+70698230249"}
0005433808485	D72E4B	0003 454740	SOFIYA KOLESNIKOVA	{"email": "sofiyakolesnikova_1986@postgrespro.ru", "phone": "+70848068881"}
0005433808486	D2165D	2164 750423	IRINA KALININA	{"email": "irinakalinina.021975@postgrespro.ru", "phone": "+70659654115"}
0005433810519	FFC1D9	5568 594592	MARINA MEDVEDEVA	{"phone": "+70467814762"}
0005433810488	B6D6E0	2812 957645	IRINA BELYAEVA	{"email": "belyaeva_i_26051984@postgrespro.ru", "phone": "+70032858311"}
0005433810489	321497	3093 601159	LYUBOV FILATOVA	{"email": "filatova.l.18071973@postgrespro.ru", "phone": "+70148056836"}
0005433810490	768326	5013 975043	EVGENIY KISELEV	{"email": "kiselevevgeniy1972@postgrespro.ru", "phone": "+70695560159"}
0005433810491	EA8888	8818 314108	VITALIY ALEKSANDROV	{"email": "vitaliy-aleksandrov17021974@postgrespro.ru", "phone": "+70003800470"}
0005433810492	50C1F5	5027 698077	VIKTOR KUZNECOV	{"phone": "+70191946057"}
0005433810493	18525A	3746 836117	GALINA LUKYANOVA	{"email": "g.lukyanova-21091971@postgrespro.ru", "phone": "+70754938026"}
0005433810494	962F54	8058 768998	VALENTINA GERASIMOVA	{"phone": "+70827259171"}
0005433810495	FA7004	4091 682721	ANNA SEMENOVA	{"phone": "+70545530774"}
0005433810496	AC5DA7	5480 028753	ANASTASIYA NIKOLAEVA	{"phone": "+70862142885"}
0005433810497	0D1F2A	0195 924061	ALEKSANDRA SCHERBAKOVA	{"email": "a.scherbakova.1969@postgrespro.ru", "phone": "+70000656239"}
0005433810498	0D1F2A	8612 082437	MIKHAIL EGOROV	{"email": "mikhailegorov-07071979@postgrespro.ru", "phone": "+70933471640"}
0005433810499	F53AF4	5013 676599	NATALYA KRASNOVA	{"email": "krasnova_n-1983@postgrespro.ru", "phone": "+70657707149"}
0005433810500	F53AF4	6300 333444	ALEKSANDR GORBUNOV	{"phone": "+70478601092"}
0005433810501	F53AF4	4041 276946	OLEG GRIGOREV	{"email": "grigorev_oleg.011974@postgrespro.ru", "phone": "+70878357338"}
0005433810502	233D09	5513 793994	IGOR VOLKOV	{"phone": "+70126168243"}
0005433810503	CC715C	6064 238441	NINA SOKOLOVA	{"phone": "+70348432242"}
0005433810504	69A7ED	3198 001672	OKSANA VOROBEVA	{"phone": "+70620787045"}
0005433810505	69A7ED	9991 592823	ANNA VOROBEVA	{"phone": "+70046345504"}
0005433810506	272448	7347 900798	ALEKSANDR PETROV	{"email": "petrova.031972@postgrespro.ru", "phone": "+70292930093"}
0005433810507	1DD6D1	6404 801760	LYUBOV CHERNOVA	{"phone": "+70472763237"}
0005433810508	4CFE48	5115 754649	OLGA MELNIKOVA	{"email": "melnikova-olga-02111974@postgrespro.ru", "phone": "+70865430470"}
0005433810509	6256B4	3482 484592	NADEZHDA TROFIMOVA	{"phone": "+70915005751"}
0005433810510	119CFD	1698 054510	IVAN MEDVEDEV	{"email": "ivan_medvedev.1977@postgrespro.ru", "phone": "+70618295761"}
0005433810511	8E5352	3630 920680	NATALYA VOROBEVA	{"email": "n-vorobeva.1981@postgrespro.ru", "phone": "+70572701674"}
0005433810512	9388E3	5776 764358	TATYANA SMIRNOVA	{"email": "smirnova_tatyana.101976@postgrespro.ru", "phone": "+70595856024"}
0005433810513	9388E3	6015 545872	ANATOLIY FILIPPOV	{"email": "filippov_a.08091976@postgrespro.ru", "phone": "+70189626499"}
0005433810514	10927C	2826 289076	YURIY KUZMIN	{"email": "kuzmin_yuriy_1975@postgrespro.ru", "phone": "+70710832334"}
0005433810515	EE779B	6166 948439	ELENA MALYSHEVA	{"email": "elena_malysheva.121980@postgrespro.ru", "phone": "+70064890204"}
0005433810516	EE779B	1167 130384	NATALYA EGOROVA	{"email": "natalya.egorova-091961@postgrespro.ru", "phone": "+70280560959"}
0005433810517	7DD894	2860 423502	ANNA FOMINA	{"email": "fominaa25071972@postgrespro.ru", "phone": "+70611444800"}
0005433810518	FFC1D9	2785 654775	VLADIMIR MEDVEDEV	{"phone": "+70678861510"}
0005433810520	8BAF4A	4030 951669	KSENIYA FEDOROVA	{"email": "fedorova_k111976@postgrespro.ru", "phone": "+70121354842"}
0005433810521	89E287	3141 326583	STANISLAV GERASIMOV	{"email": "stanislav-gerasimov-24111963@postgrespro.ru", "phone": "+70098487254"}
0005433810522	4BD9CD	3657 635538	ALEKSEY GRIGOREV	{"email": "grigoreva-17101974@postgrespro.ru", "phone": "+70238439326"}
0005433810523	A9CA7B	5902 813516	ELENA MOROZOVA	{"phone": "+70499972632"}
0005433810524	FC7055	6169 108237	SVETLANA MELNIKOVA	{"phone": "+70509821195"}
0005433810525	FC7055	8612 028377	GENNADIY IVANOV	{"phone": "+70333800126"}
0005433810526	9447AC	2782 193583	ALEKSANDR GUSEV	{"email": "a_gusev.081962@postgrespro.ru", "phone": "+70604142688"}
0005433810527	ECE48B	6789 900893	SERGEY FILIPPOV	{"phone": "+70356710362"}
0005433810528	848912	6488 339547	ANNA ZHUKOVA	{"phone": "+70471318565"}
0005433810529	9257FF	5311 768695	SVETLANA NIKOLAEVA	{"phone": "+70093285346"}
0005433810530	2C4209	6839 914337	YANA VOLKOVA	{"phone": "+70037782553"}
0005433810531	D53B35	9955 128401	ILYA BORISOV	{"phone": "+70088417399"}
0005433810532	D53B35	9372 142216	NATALYA BOGDANOVA	{"phone": "+70603207270"}
0005433810533	5D98A6	4461 392870	POLINA BELOVA	{"phone": "+70958303134"}
0005433810534	EC4D73	5527 560748	PAVEL YAKOVLEV	{"email": "pavel-yakovlev-1969@postgrespro.ru", "phone": "+70782761054"}
0005433810535	E59AF2	6708 913615	ANATOLIY ISAEV	{"email": "anatoliy-isaev_1975@postgrespro.ru", "phone": "+70737585739"}
0005433810536	1EA615	7872 044568	VENIAMIN GRIGOREV	{"phone": "+70825856304"}
0005433810537	A4388D	1876 344616	IRINA KOZLOVA	{"email": "i.kozlova.021975@postgrespro.ru", "phone": "+70173078751"}
0005433810538	6F3928	5240 320082	VIKTOR KUZMIN	{"phone": "+70737398848"}
0005433810539	6F3928	3712 819840	ALEKSANDR SAVELEV	{"email": "saveleva_14121975@postgrespro.ru", "phone": "+70516951288"}
0005433810540	6F3928	9566 435462	VASILIY PAVLOV	{"phone": "+70733426218"}
0005433810541	994864	5378 977662	VLADISLAV SOKOLOV	{"email": "sokolov-vladislav.031977@postgrespro.ru", "phone": "+70127434717"}
0005433810542	C1768D	5017 624625	ULYANA SIDOROVA	{"phone": "+70987334348"}
0005433810543	832B5E	1002 453930	ILYA KUZNECOV	{"phone": "+70967944630"}
0005433810544	0A12FA	8638 108926	SERGEY KUZMIN	{"email": "kuzminsergey.05031969@postgrespro.ru", "phone": "+70056516209"}
0005433810545	0A12FA	5885 177899	VERA NOVIKOVA	{"phone": "+70382238083"}
0005433810546	3A03AE	3753 489242	GALIYA IVANOVA	{"email": "ivanova_g-1972@postgrespro.ru", "phone": "+70657599052"}
0005433810547	3366FD	0835 523364	ALENA SCHERBAKOVA	{"email": "alena.scherbakova.25031970@postgrespro.ru", "phone": "+70331753680"}
0005433810548	C9823C	1335 545939	EVGENIYA KONOVALOVA	{"email": "e_konovalova_03101965@postgrespro.ru", "phone": "+70178471938"}
0005433810549	C9823C	7395 666292	ZULFIYA MELNIKOVA	{"phone": "+70583698698"}
0005433810550	C65B54	0107 064822	ALEKSANDR SMIRNOV	{"phone": "+70889324198"}
0005433810551	BC94A0	3968 186786	VIKTOR KOZLOV	{"phone": "+70302421104"}
0005433810552	BC94A0	5245 016439	ROMAN MAKAROV	{"email": "r.makarov111975@postgrespro.ru", "phone": "+70129245784"}
0005433810553	143731	1797 564113	EKATERINA VOLKOVA	{"phone": "+70377256534"}
0005433810554	B9D8B8	7838 179057	VALENTINA ALEKSANDROVA	{"email": "aleksandrova_valentina30061978@postgrespro.ru", "phone": "+70166646894"}
0005433810555	4743DA	2837 247118	TATYANA SEMENOVA	{"email": "tatyana-semenova021971@postgrespro.ru", "phone": "+70460069881"}
0005433810556	B8CF31	6155 705862	VIKTORIYA KRASNOVA	{"email": "krasnova-viktoriya20041982@postgrespro.ru", "phone": "+70909966854"}
0005433810557	CC2D67	4820 715666	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva-lyudmila.16081975@postgrespro.ru", "phone": "+70338515162"}
0005433810558	13B265	1507 303909	DMITRIY NAZAROV	{"phone": "+70622246536"}
0005433810559	AAEBCF	5723 149177	YANA TROFIMOVA	{"email": "yana_trofimova.121981@postgrespro.ru", "phone": "+70914214191"}
0005433810560	CFC52A	9336 043718	NELLI GUSEVA	{"email": "nguseva1979@postgrespro.ru", "phone": "+70412036545"}
0005433810561	CFC52A	7555 785784	LUIZA ABRAMOVA	{"phone": "+70219310800"}
0005433810562	E7709F	5835 252861	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov-31051980@postgrespro.ru", "phone": "+70251093260"}
0005433810563	E7709F	0841 388434	MAKSIM KARPOV	{"phone": "+70055614557"}
0005433810564	9B834E	0584 738499	VLADIMIR PAVLOV	{"email": "pavlov.v_08061977@postgrespro.ru", "phone": "+70622647621"}
0005433810565	53EC66	4262 641436	DARINA OVCHINNIKOVA	{"email": "darina-ovchinnikova18041978@postgrespro.ru", "phone": "+70578383026"}
0005433810566	70A8D6	4450 206711	GALINA BORISOVA	{"email": "borisovag_18081973@postgrespro.ru", "phone": "+70357015983"}
0005433810567	68C4D3	7970 936470	KRISTINA YAKOVLEVA	{"phone": "+70178681175"}
0005433810568	389311	7117 789935	VERA KOROLEVA	{"email": "korolevav-22021971@postgrespro.ru", "phone": "+70080060643"}
0005433810755	AAE60C	4813 851594	VALERIY SHEVCHENKO	{"phone": "+70943618727"}
0005433810569	E9684C	1218 428039	DARYA ANTONOVA	{"email": "antonova_darya-27021977@postgrespro.ru", "phone": "+70247504206"}
0005433810570	E51A9E	9625 863152	SERGEY KUZNECOV	{"email": "kuznecov_sergey-011983@postgrespro.ru", "phone": "+70159034881"}
0005433810571	E51A9E	5109 064031	NATALYA ANDREEVA	{"email": "andreeva.natalya_1963@postgrespro.ru", "phone": "+70940162617"}
0005433810572	DDD172	2535 712851	VALERIY TIKHONOV	{"phone": "+70755341112"}
0005433810573	DDD172	8265 353406	NADEZHDA GAVRILOVA	{"phone": "+70907354666"}
0005433810574	185BC7	0615 016552	BORIS KAZAKOV	{"email": "kazakovb_1975@postgrespro.ru", "phone": "+70975018493"}
0005433810575	F1D972	5818 093976	VLADIMIR BELOV	{"email": "belov.v16091980@postgrespro.ru", "phone": "+70917524296"}
0005433810576	539E04	3311 006792	LYUDMILA VOLKOVA	{"email": "lyudmila.volkova1971@postgrespro.ru", "phone": "+70265387905"}
0005433810577	539E04	0787 423811	IRINA GORBUNOVA	{"phone": "+70459761992"}
0005433810578	770E5A	8701 652905	ZINAIDA GAVRILOVA	{"email": "zinaida.gavrilova.03101982@postgrespro.ru", "phone": "+70874368038"}
0005433810579	DAC2AA	5724 110353	ANTONINA ANTONOVA	{"phone": "+70091553847"}
0005433810580	5C2B40	3331 667234	ROMAN ISAEV	{"email": "romanisaev1967@postgrespro.ru", "phone": "+70354779114"}
0005433810581	2C5305	5630 352370	MARGARITA SAVELEVA	{"email": "msaveleva1965@postgrespro.ru", "phone": "+70841189458"}
0005433810582	2C5305	9956 502609	ELENA YAKOVLEVA	{"phone": "+70162340747"}
0005433810583	30C746	9225 796696	LYUBOV MOROZOVA	{"email": "morozoval041969@postgrespro.ru", "phone": "+70383400059"}
0005433810584	45A26F	4277 847726	DANIIL ORLOV	{"phone": "+70849963017"}
0005433810585	6716C6	8371 979925	NATALYA ILINA	{"phone": "+70635359391"}
0005433810586	0C0B2E	7788 117307	PAVEL IVANOV	{"phone": "+70562779944"}
0005433810587	0ACDE3	5824 912722	ELENA FEDOROVA	{"email": "e.fedorova-08011979@postgrespro.ru", "phone": "+70897587025"}
0005433810588	0ACDE3	8610 949211	VLADISLAV DENISOV	{"email": "denisov_v041973@postgrespro.ru", "phone": "+70218078772"}
0005433810589	F95496	4227 031468	NINA TARASOVA	{"email": "tarasova-nina061973@postgrespro.ru", "phone": "+70160595724"}
0005433810590	480031	0095 322483	TAMARA MASLOVA	{"email": "maslova-tamara.051972@postgrespro.ru", "phone": "+70231402947"}
0005433810591	BA35BB	5309 802069	ANDREY MELNIKOV	{"email": "a_melnikov16111973@postgrespro.ru", "phone": "+70377192080"}
0005433810592	BA35BB	7763 648375	MAKSIM FROLOV	{"phone": "+70635815862"}
0005433810593	CC76A6	3198 716276	IVAN ILIN	{"phone": "+70845676601"}
0005433810594	CC76A6	5550 263049	IGOR POPOV	{"phone": "+70594362160"}
0005433810595	92D47A	1110 715048	OLGA NAZAROVA	{"email": "nazarova-o-22121970@postgrespro.ru", "phone": "+70935099577"}
0005433810596	92D47A	0884 163826	MARIYA ANDREEVA	{"email": "andreeva.mariya-1968@postgrespro.ru", "phone": "+70264403800"}
0005433810597	6EBE40	4266 550794	BULAT MOROZOV	{"email": "bulat-morozov_041975@postgrespro.ru", "phone": "+70391230594"}
0005433810598	6F7352	8003 357585	PAVEL FROLOV	{"email": "p.frolov.051978@postgrespro.ru", "phone": "+70323662705"}
0005433810599	6F7352	3563 413045	OLGA SEMENOVA	{"phone": "+70272726583"}
0005433810600	1293E7	7286 173074	NATALYA KOROLEVA	{"email": "korolevanatalya07121977@postgrespro.ru", "phone": "+70292844378"}
0005433810601	1293E7	6282 800459	ROMAN KISELEV	{"phone": "+70643151908"}
0005433810602	1293E7	6469 629962	NATALYA MIRONOVA	{"email": "n_mironova-1973@postgrespro.ru", "phone": "+70620270973"}
0005433810603	1293E7	5987 890836	TATYANA KUZNECOVA	{"phone": "+70571643817"}
0005433810604	56B131	1090 043672	NINA DAVYDOVA	{"email": "davydovan-031976@postgrespro.ru", "phone": "+70019628090"}
0005433810605	56B131	7877 545420	MIKHAIL TIKHONOV	{"phone": "+70157124933"}
0005433810606	BD8076	0639 845157	OLEG NAUMOV	{"email": "onaumov1962@postgrespro.ru", "phone": "+70617356657"}
0005433810607	22542F	8163 252965	ANATOLIY SCHERBAKOV	{"phone": "+70677464753"}
0005433810608	0018E5	0700 394647	ALEKSANDR KUZNECOV	{"phone": "+70566885280"}
0005433810609	1F20CA	8114 052583	ALEKSANDR NIKOLAEV	{"phone": "+70373240177"}
0005433810610	291EBB	6581 740419	NATALYA KUZMINA	{"phone": "+70177414101"}
0005433810611	291EBB	0069 186491	NATALYA NAUMOVA	{"phone": "+70219560477"}
0005433810612	DF4E9B	5806 569634	LYUBOV SCHERBAKOVA	{"phone": "+70757277288"}
0005433810613	DF4E9B	7294 453123	ELENA IVANOVA	{"phone": "+70790879240"}
0005433810614	68494A	9475 118766	DMITRIY IVANOV	{"email": "d.ivanov_041970@postgrespro.ru", "phone": "+70118300297"}
0005433810615	7D1B9A	1304 792681	ROMAN KUZNECOV	{"email": "r.kuznecov_26121973@postgrespro.ru", "phone": "+70708353113"}
0005433810616	D6281E	4517 161151	GALINA NOVIKOVA	{"email": "g-novikova17041979@postgrespro.ru", "phone": "+70217429167"}
0005433810617	D6281E	4379 792775	SERGEY NIKITIN	{"email": "nikitinsergey18011968@postgrespro.ru", "phone": "+70665397383"}
0005433810618	99ECB6	0703 840271	ROMAN ILIN	{"phone": "+70383966207"}
0005433810619	99ECB6	5422 412915	GALINA FILATOVA	{"phone": "+70685461105"}
0005433810620	99ECB6	7792 171279	ANDREY MAKAROV	{"phone": "+70257722302"}
0005433810621	C68794	7117 895184	VERA GAVRILOVA	{"email": "v-gavrilova27061973@postgrespro.ru", "phone": "+70826938152"}
0005433810622	E2F781	7595 310861	EKATERINA NIKITINA	{"email": "nikitina_ekaterina1963@postgrespro.ru", "phone": "+70396534191"}
0005433810623	F4E419	9446 892474	VYACHESLAV GAVRILOV	{"phone": "+70181315652"}
0005433810624	82D900	0212 334026	IGOR NIKOLAEV	{"email": "igor.nikolaev_011978@postgrespro.ru", "phone": "+70322877075"}
0005433810625	82D900	4450 197855	ALEKSEY SOROKIN	{"phone": "+70335038785"}
0005433810626	82D900	4330 822965	NIKOLAY ABRAMOV	{"phone": "+70961191757"}
0005433810627	CB3FC4	2040 974178	NIKITA CHERNOV	{"email": "n-chernov061967@postgrespro.ru", "phone": "+70529096727"}
0005433810628	0DF77F	7488 611295	IVAN MIRONOV	{"email": "ivan_mironov_041973@postgrespro.ru", "phone": "+70661082470"}
0005433810629	0DF77F	5353 124300	ILYAS SERGEEV	{"email": "sergeev.i.15111970@postgrespro.ru", "phone": "+70742291720"}
0005433810630	246936	0746 672352	SERGEY FEDOROV	{"email": "fedorov.sergey-1973@postgrespro.ru", "phone": "+70266965160"}
0005433810631	7CE3F4	7370 292275	GULFIYA SCHERBAKOVA	{"phone": "+70885749709"}
0005433810632	098DF3	3278 151620	ILYA SCHERBAKOV	{"phone": "+70458137019"}
0005433810633	DAA040	9380 939315	POLINA DMITRIEVA	{"phone": "+70804480609"}
0005433810634	DAA040	4635 818951	NINA VASILEVA	{"email": "nina.vasileva.1980@postgrespro.ru", "phone": "+70440090837"}
0005433810635	48B72A	1047 889764	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova_061957@postgrespro.ru", "phone": "+70425971164"}
0005433810636	EA50B7	7836 183317	VLADIMIR KOZLOV	{"email": "kozlov-v.08081968@postgrespro.ru", "phone": "+70712164780"}
0005433810637	BC55E7	7482 726589	IGOR MEDVEDEV	{"phone": "+70627498446"}
0005433810638	CA741F	0161 023689	EKATERINA BORISOVA	{"email": "borisovae.1974@postgrespro.ru", "phone": "+70170945318"}
0005433810639	20ED68	2559 739414	SHAMIL SOROKIN	{"phone": "+70071455712"}
0005433810640	5552EB	3672 326868	NATALIYA BELYAEVA	{"phone": "+70853018159"}
0005433810641	5552EB	4528 198152	VLADIMIR PETROV	{"email": "v.petrov.09081976@postgrespro.ru", "phone": "+70278206238"}
0005433810642	85DF90	7687 225994	ANDREY FEDOROV	{"email": "fedorov_a-23021973@postgrespro.ru", "phone": "+70137967084"}
0005433810643	1C71C3	2995 083130	RISHAT CHERNOV	{"email": "rishat-chernov-031971@postgrespro.ru", "phone": "+70632865609"}
0005433810644	982E7D	6759 068452	VASILIY PETROV	{"phone": "+70294011495"}
0005433810645	5C72AB	7320 636950	LIDIYA IVANOVA	{"phone": "+70888022636"}
0005433810646	1CA332	8801 037210	ANNA SAVELEVA	{"email": "a-saveleva1975@postgrespro.ru", "phone": "+70587445194"}
0005433810647	ABB9D2	2466 281063	BOGDAN NAZAROV	{"email": "nazarov.bogdan.26051972@postgrespro.ru", "phone": "+70549198101"}
0005433810648	E56532	3172 929161	TIMUR EGOROV	{"phone": "+70684146945"}
0005433810649	E56532	9771 775396	PAVEL VASILEV	{"phone": "+70221052916"}
0005433810650	C13BD8	0975 440792	IRINA SOKOLOVA	{"email": "sokolova_irina.10061979@postgrespro.ru", "phone": "+70617321508"}
0005433810651	C13BD8	1623 361719	LYUDMILA VASILEVA	{"phone": "+70513528550"}
0005433810652	553B70	4284 279885	ANASTASIYA ANDREEVA	{"phone": "+70674678153"}
0005433810653	B5168D	1687 858887	KRISTINA KUZMINA	{"email": "kkuzmina.08041959@postgrespro.ru", "phone": "+70328104123"}
0005433810654	B42599	3925 114047	ANNA KUZMINA	{"phone": "+70642970817"}
0005433810655	1A208F	8645 664739	DANIL VOLKOV	{"email": "dvolkov.20081977@postgrespro.ru", "phone": "+70945273016"}
0005433810656	560861	1718 787882	SERGEY EGOROV	{"phone": "+70540671183"}
0005433810657	B43044	7467 512621	PAVEL NOVIKOV	{"phone": "+70629549550"}
0005433810658	75280C	9577 094950	OLEG ZHURAVLEV	{"phone": "+70380103240"}
0005433810659	1DF605	0644 566402	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav_08081979@postgrespro.ru", "phone": "+70398562480"}
0005433810660	1DF605	1895 249994	LARISA NESTEROVA	{"email": "nesterova-larisa29101976@postgrespro.ru", "phone": "+70296147866"}
0005433810661	FC8855	7778 863458	ELENA AFANASEVA	{"phone": "+70785679042"}
0005433810662	FC8855	7069 209011	VIKTORIYA PAVLOVA	{"phone": "+70049092622"}
0005433810663	D8A505	2062 014121	YURIY VASILEV	{"email": "y_vasilev_1970@postgrespro.ru", "phone": "+70723023174"}
0005433810664	6F01E4	8637 325042	NATALYA GRISHINA	{"email": "grishina_n.041976@postgrespro.ru", "phone": "+70116970844"}
0005433810665	6F01E4	8390 476118	LYUBOV VASILEVA	{"phone": "+70324961244"}
0005433810666	6F01E4	5141 955194	KSENIYA DANILOVA	{"phone": "+70887594042"}
0005433810667	08A5E3	2225 673211	ANNA GUSEVA	{"email": "anna.guseva_26051970@postgrespro.ru", "phone": "+70082848075"}
0005433810668	876B0F	3204 255708	VIKTOR POPOV	{"phone": "+70116210279"}
0005433810669	876B0F	1624 354166	STEPAN ORLOV	{"phone": "+70107259172"}
0005433810670	E5DA1B	8383 438591	VLADIMIR ZHUKOV	{"phone": "+70655812706"}
0005433810671	622E63	2191 340152	ANNA SOKOLOVA	{"phone": "+70016283745"}
0005433810672	622E63	8323 484565	NIKOLAY GUSEV	{"email": "gusev-nikolay_1967@postgrespro.ru", "phone": "+70049225156"}
0005433810673	E9EBB6	0185 497357	IRINA IVANOVA	{"phone": "+70862597187"}
0005433810674	9F2B62	5127 781088	ARTEM OSIPOV	{"email": "a-osipov.30041975@postgrespro.ru", "phone": "+70081756227"}
0005433810675	A0BCF2	3101 697762	MAKSIM YAKOVLEV	{"email": "yakovlev.maksim-14061976@postgrespro.ru", "phone": "+70339149545"}
0005433810676	C3FCDE	1015 359826	NATALYA POPOVA	{"phone": "+70849026064"}
0005433810677	C3FCDE	9973 736480	ALEKSEY SEMENOV	{"phone": "+70829269862"}
0005433810678	B49CBF	3406 606941	VALENTINA VOLKOVA	{"email": "volkova_v1960@postgrespro.ru", "phone": "+70770436724"}
0005433810679	038A89	2034 838561	DANILA SCHERBAKOV	{"email": "d-scherbakov-081980@postgrespro.ru", "phone": "+70320238779"}
0005433810680	038A89	5007 540008	DARYA MAKAROVA	{"phone": "+70165941047"}
0005433810681	3BC599	1270 689495	EVGENIY EGOROV	{"email": "e.egorov1968@postgrespro.ru", "phone": "+70666035183"}
0005433810682	F83A2C	4256 363454	RUSLAN KONOVALOV	{"phone": "+70760082329"}
0005433810683	F83A2C	7577 895436	ANDREY KISELEV	{"phone": "+70091438008"}
0005433810684	465AC7	6208 973550	ZINAIDA IVANOVA	{"email": "ivanova.zinaida.01061980@postgrespro.ru", "phone": "+70919435323"}
0005433810685	BA6993	6680 528287	EKATERINA GERASIMOVA	{"email": "egerasimova_071974@postgrespro.ru", "phone": "+70594644254"}
0005433810686	0ADE44	3644 794805	ANNA GUSEVA	{"email": "anna_guseva23091978@postgrespro.ru", "phone": "+70111484386"}
0005433810687	24F477	6207 675088	LARISA BELYAEVA	{"email": "lbelyaeva-121976@postgrespro.ru", "phone": "+70648946974"}
0005433810688	24F477	9743 062007	MARIYA EGOROVA	{"phone": "+70696861577"}
0005433810689	018215	2958 959741	VALENTINA SEMENOVA	{"email": "valentina-semenova_09021977@postgrespro.ru", "phone": "+70776792952"}
0005433810694	A006DE	8129 995825	DMITRIY NIKITIN	{"email": "dmitriy_nikitin30031977@postgrespro.ru", "phone": "+70982567756"}
0005433810695	A006DE	4525 322041	NINA MEDVEDEVA	{"email": "n-medvedeva19101971@postgrespro.ru", "phone": "+70380506848"}
0005433810696	5B3FF0	3613 711686	YURIY MIRONOV	{"email": "y-mironov22061978@postgrespro.ru", "phone": "+70122895119"}
0005433810697	5B3FF0	9589 924099	ARTEM FROLOV	{"email": "artem_frolov-1987@postgrespro.ru", "phone": "+70886939478"}
0005433810698	5B3FF0	8185 648864	VYACHESLAV ZAYCEV	{"email": "vyacheslavzaycev.071964@postgrespro.ru", "phone": "+70284270031"}
0005433810699	3A9609	1536 687611	ELENA FILIPPOVA	{"phone": "+70727602228"}
0005433810700	F11B39	4009 076121	ALEKSANDR TIKHONOV	{"phone": "+70153694352"}
0005433810701	46FA76	9857 900009	VALENTINA KOMAROVA	{"email": "komarovav.031970@postgrespro.ru", "phone": "+70231787894"}
0005433810702	4B5D5A	5017 872844	VASILIY ILIN	{"phone": "+70260490858"}
0005433810703	4B5D5A	9299 479232	KIRA NESTEROVA	{"phone": "+70461240573"}
0005433810704	C16193	1986 019518	LYUDMILA VLASOVA	{"email": "vlasovalyudmila_081968@postgrespro.ru", "phone": "+70202069964"}
0005433810705	24C365	7721 865093	DMITRIY SIDOROV	{"email": "sidorovd-08111968@postgrespro.ru", "phone": "+70769982212"}
0005433810706	E02256	9870 072791	ANDREY IVANOV	{"email": "andrey-ivanov-25061983@postgrespro.ru", "phone": "+70747605969"}
0005433810707	FBE5D2	8097 978311	ALEKSANDR KUZNECOV	{"phone": "+70957334920"}
0005433810708	FBE5D2	4055 103071	ALEKSANDR FROLOV	{"email": "frolovaleksandr.011980@postgrespro.ru", "phone": "+70562287663"}
0005433810709	1591A9	5764 861674	ALEKSANDR DMITRIEV	{"email": "aleksandrdmitriev_1958@postgrespro.ru", "phone": "+70903618332"}
0005433810710	2EAB6E	6540 964868	IGOR YAKOVLEV	{"phone": "+70558762057"}
0005433810711	0BD2C0	6440 346864	ALEKSANDR MOROZOV	{"email": "morozov.a1961@postgrespro.ru", "phone": "+70751480757"}
0005433810712	ABC3DD	8686 364270	SVETLANA SIDOROVA	{"phone": "+70936418932"}
0005433810713	ABC3DD	4593 202223	VALENTINA DMITRIEVA	{"email": "vdmitrieva041961@postgrespro.ru", "phone": "+70505541693"}
0005433810714	ABC3DD	6741 100080	EVA PAVLOVA	{"phone": "+70639577324"}
0005433810715	9305E0	4216 688105	YANA KULIKOVA	{"phone": "+70528423388"}
0005433810716	9305E0	2406 083115	LYUBOV GUSEVA	{"email": "l.guseva_10111973@postgrespro.ru", "phone": "+70429515456"}
0005433810717	48C46A	3959 978597	VASILIY KAZAKOV	{"email": "vasiliy.kazakov.081974@postgrespro.ru", "phone": "+70655028938"}
0005433810718	48C46A	4014 015958	KLAVDIYA ILINA	{"phone": "+70775582263"}
0005433810719	1855B8	0206 634614	VLADIMIR SEMENOV	{"phone": "+70653667008"}
0005433810720	F63E01	7716 186747	NATALYA ISAEVA	{"phone": "+70745726543"}
0005433810721	F63E01	7804 273210	ELENA SMIRNOVA	{"phone": "+70135252999"}
0005433810722	3D4B9B	4351 742875	ALEKSANDR SCHERBAKOV	{"phone": "+70455546851"}
0005433810723	3D4B9B	7457 824959	NATALYA KOZLOVA	{"phone": "+70625747544"}
0005433810724	82CA78	5599 354074	NIKITA TIMOFEEV	{"email": "timofeevn_101976@postgrespro.ru", "phone": "+70573360585"}
0005433810725	4FF40F	7431 510587	KRISTINA FROLOVA	{"phone": "+70063476104"}
0005433810726	E8C221	1152 000698	VASILIY IVANOV	{"email": "vivanov_14031973@postgrespro.ru", "phone": "+70173613964"}
0005433810727	4166C7	9522 015145	PETR IVANOV	{"phone": "+70648604876"}
0005433810728	A4CB67	2276 698227	YURIY KUZNECOV	{"email": "yuriykuznecov121959@postgrespro.ru", "phone": "+70731795554"}
0005433810729	A4CB67	7219 068961	SERGEY SERGEEV	{"phone": "+70106903302"}
0005433810730	BEB560	1274 028088	MARIYA BORISOVA	{"email": "borisova-mariya081970@postgrespro.ru", "phone": "+70439290758"}
0005433810731	494453	1065 910130	VERA RYABOVA	{"phone": "+70232317503"}
0005433810732	494453	1034 468678	ANATOLIY ALEKSANDROV	{"email": "aaleksandrov061973@postgrespro.ru", "phone": "+70119762072"}
0005433810733	F1266A	2204 425986	YURIY ILIN	{"email": "yuriy_ilin.12011978@postgrespro.ru", "phone": "+70154186126"}
0005433810734	F1266A	4205 771960	SERGEY NAZAROV	{"email": "sergey_nazarov.1971@postgrespro.ru", "phone": "+70669430035"}
0005433810735	544D1B	2536 069908	ALEKSANDR ZAKHAROV	{"phone": "+70840902943"}
0005433810736	ECC6E6	7709 338377	ELENA KUZMINA	{"phone": "+70759640125"}
0005433810737	103D99	3570 458015	DMITRIY KOZLOV	{"email": "kozlov.dmitriy_081983@postgrespro.ru", "phone": "+70146144572"}
0005433810738	9D2FCF	4205 377173	DARYA ANTONOVA	{"phone": "+70654267073"}
0005433810739	9D2FCF	9992 302924	VLADISLAV MIRONOV	{"email": "v_mironov.041968@postgrespro.ru", "phone": "+70529054486"}
0005433810740	67BEB1	9329 483914	SERGEY OSIPOV	{"phone": "+70165825989"}
0005433810741	67BEB1	6659 952901	OLGA YAKOVLEVA	{"email": "yakovlevaolga-1971@postgrespro.ru", "phone": "+70432369702"}
0005433810742	67BEB1	4689 893131	OLGA FOMINA	{"email": "fomina.olga_121966@postgrespro.ru", "phone": "+70960823789"}
0005433810743	3497F3	9919 739502	VIKTORIYA NIKIFOROVA	{"phone": "+70328704735"}
0005433810744	B2C73F	2925 907450	DENIS ANTONOV	{"email": "antonov-denis_091981@postgrespro.ru", "phone": "+70576886990"}
0005433810745	B2C73F	7746 390911	NATALIYA BOGDANOVA	{"email": "bogdanova-n_031973@postgrespro.ru", "phone": "+70298459398"}
0005433810746	694190	2278 869582	ALEKSANDR KULIKOV	{"email": "kulikov.a_23021982@postgrespro.ru", "phone": "+70212278166"}
0005433810747	17C138	6045 088706	ELENA LEBEDEVA	{"phone": "+70036821067"}
0005433810748	17C138	5798 099385	NATALYA EGOROVA	{"phone": "+70572987729"}
0005433810749	24E266	6012 975883	KLAVDIYA NESTEROVA	{"email": "nesterova_k_071979@postgrespro.ru", "phone": "+70067322847"}
0005433810750	B68E1C	9632 098819	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova26071969@postgrespro.ru", "phone": "+70796453034"}
0005433810751	B68E1C	1342 867997	NADEZHDA KULIKOVA	{"email": "kulikova-nadezhda1969@postgrespro.ru", "phone": "+70264885570"}
0005433810752	B93B20	9071 110836	YANA ALEKSANDROVA	{"phone": "+70148949057"}
0005433810753	B93B20	4503 954109	NADEZHDA ERMAKOVA	{"phone": "+70555284157"}
0005433810756	2612C4	6361 796717	LYUDMILA NIKITINA	{"email": "l_nikitina.071967@postgrespro.ru", "phone": "+70000223646"}
0005433810757	2612C4	1614 929168	SERGEY EGOROV	{"email": "segorov_061988@postgrespro.ru", "phone": "+70786447587"}
0005433810758	C45B54	8251 511873	DENIS FEDOTOV	{"email": "dfedotov_1977@postgrespro.ru", "phone": "+70558913477"}
0005433810759	73FB00	4838 095587	ALEKSANDRA ZAKHAROVA	{"email": "zakharova.aleksandra.1982@postgrespro.ru", "phone": "+70930510630"}
0005433810760	7C794B	9377 854509	LARISA GORBUNOVA	{"phone": "+70230531659"}
0005433810761	D4D073	9929 118198	GALINA FROLOVA	{"phone": "+70277758113"}
0005433810762	F8F6E1	7620 288666	IVAN ANTONOV	{"email": "ivanantonov.1979@postgrespro.ru", "phone": "+70195970915"}
0005433810763	D8593C	4501 460440	IVAN PAVLOV	{"email": "i_pavlov_041971@postgrespro.ru", "phone": "+70736646389"}
0005433810764	6D657B	8268 559585	TATYANA BELOVA	{"phone": "+70766986738"}
0005433810765	4D0F85	0779 215227	MARINA STEPANOVA	{"email": "stepanova-marina_15011977@postgrespro.ru", "phone": "+70400667344"}
0005433810766	48F74B	3693 118912	ALEKSEY SMIRNOV	{"email": "smirnovaleksey-121969@postgrespro.ru", "phone": "+70294974277"}
0005433810767	0B253E	3851 048790	VALERIY VOLKOV	{"email": "volkovvaleriy051977@postgrespro.ru", "phone": "+70781237874"}
0005433810768	7EF150	9040 750297	ALEKSEY OSIPOV	{"email": "osipova.051969@postgrespro.ru", "phone": "+70380168463"}
0005433810769	7EF150	4587 220638	NATALYA TIKHONOVA	{"email": "tikhonova_natalya.111969@postgrespro.ru", "phone": "+70411694937"}
0005433810770	1F4A84	0401 627307	GALINA VLASOVA	{"phone": "+70495324319"}
0005433810771	1F4A84	6043 288055	ZHANNA IVANOVA	{"email": "z_ivanova_11031973@postgrespro.ru", "phone": "+70001204906"}
0005433810772	A465F9	9197 093117	MIKHAIL GORBUNOV	{"phone": "+70809229519"}
0005433810773	2A80FB	6849 368192	TATYANA FEDOROVA	{"phone": "+70380415996"}
0005433810774	9A6F88	6661 852977	IRINA KONOVALOVA	{"email": "konovalova.irina-111969@postgrespro.ru", "phone": "+70040952785"}
0005433810775	08AB54	0684 198900	SERGEY FEDOTOV	{"email": "sergey_fedotov_1963@postgrespro.ru", "phone": "+70392293450"}
0005433810776	08AB54	1200 039722	VLADIMIR FEDOTOV	{"email": "v_fedotov_081974@postgrespro.ru", "phone": "+70378537892"}
0005433810777	F18F95	1360 741724	MIKHAIL POPOV	{"phone": "+70678341708"}
0005433810778	F7953A	9480 635066	EVGENIY SERGEEV	{"email": "sergeev-e1973@postgrespro.ru", "phone": "+70631752958"}
0005433810779	CAE347	8906 400556	VALERIY NIKOLAEV	{"email": "nikolaev.v1966@postgrespro.ru", "phone": "+70651999141"}
0005433810780	CAE347	7430 125846	NADEZHDA PETROVA	{"phone": "+70034551911"}
0005433810781	C4DE8B	0072 500999	NINA GRISHINA	{"phone": "+70514007795"}
0005433810782	E40525	1021 374704	NIKOLAY SERGEEV	{"phone": "+70198810622"}
0005433810783	4B00BD	0879 220029	VASILIY FROLOV	{"phone": "+70473072167"}
0005433810784	43CD13	3795 956694	VLADIMIR IVANOV	{"email": "vladimir-ivanov_12051974@postgrespro.ru", "phone": "+70942844778"}
0005433810785	48976C	8728 455335	MARIYA ROMANOVA	{"email": "m.romanova081965@postgrespro.ru", "phone": "+70888220671"}
0005433810786	48976C	2385 013686	DMITRIY KUZNECOV	{"phone": "+70635762738"}
0005433810787	D6252D	5842 874347	TATYANA ISAEVA	{"email": "isaeva.tatyana.08031969@postgrespro.ru", "phone": "+70624750437"}
0005433810788	5E0ED5	4279 957938	ANASTASIYA SOLOVEVA	{"email": "soloveva_a031978@postgrespro.ru", "phone": "+70302415431"}
0005433810789	5E0ED5	0889 622086	VITALIY FEDOROV	{"email": "vitaliy.fedorov_051975@postgrespro.ru", "phone": "+70038513788"}
0005433810790	5E0ED5	7246 356934	SERGEY CHERNOV	{"email": "sergey-chernov-15061965@postgrespro.ru", "phone": "+70921593885"}
0005433810791	A524C0	0955 707029	DIANA RODIONOVA	{"email": "dianarodionova_071975@postgrespro.ru", "phone": "+70611184699"}
0005433810792	CF3DF8	0323 241722	LYUBOV VASILEVA	{"email": "lvasileva_061974@postgrespro.ru", "phone": "+70512854643"}
0005433810793	00EE6E	3732 227044	VLADIMIR KONOVALOV	{"email": "vladimirkonovalov061980@postgrespro.ru", "phone": "+70133629598"}
0005433810794	00EE6E	4289 532174	ELVIRA MEDVEDEVA	{"phone": "+70697019995"}
0005433810795	00EE6E	4233 932039	YURIY GORBUNOV	{"phone": "+70567169260"}
0005433810796	00EE6E	8556 369049	SVETLANA KUZNECOVA	{"phone": "+70950566340"}
0005433810797	F8E28D	9047 386105	DENIS GERASIMOV	{"email": "d.gerasimov.12091971@postgrespro.ru", "phone": "+70959475797"}
0005433810798	663C34	3154 147344	DMITRIY KULIKOV	{"phone": "+70942496857"}
0005433810799	87BE7E	0706 114013	DMITRIY ZHUKOV	{"email": "dmitriy-zhukov_15071983@postgrespro.ru", "phone": "+70168137280"}
0005433810800	87BE7E	0636 502929	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr06101972@postgrespro.ru", "phone": "+70252136669"}
0005433810801	ED923B	2020 076146	SERGEY TARASOV	{"email": "tarasov.sergey091973@postgrespro.ru", "phone": "+70000002481"}
0005433810802	ED923B	5960 789182	KARINA AKIMOVA	{"email": "k_akimova-121970@postgrespro.ru", "phone": "+70261147182"}
0005433810803	7173D6	4772 450441	NATALYA KULIKOVA	{"email": "kulikova_n.101963@postgrespro.ru", "phone": "+70330032291"}
0005433810804	501609	7929 096233	PAVEL KUDRYASHOV	{"email": "p.kudryashov061976@postgrespro.ru", "phone": "+70778735791"}
0005433810805	A29C08	0022 872560	GENNADIY NOVIKOV	{"email": "novikov.g021975@postgrespro.ru", "phone": "+70946985822"}
0005433810806	A29C08	8405 661181	NIKOLAY IVANOV	{"phone": "+70864137689"}
0005433810807	0DA9D3	1340 331442	EVGENIYA POPOVA	{"phone": "+70380062641"}
0005433810808	0DA9D3	5763 017549	ALEKSEY MEDVEDEV	{"phone": "+70638487971"}
0005433810809	7237D5	0619 851056	LYUDMILA MIKHAYLOVA	{"email": "lmikhaylova.1966@postgrespro.ru", "phone": "+70014300066"}
0005433810810	B66AFE	8110 958655	ROMAN ZAYCEV	{"email": "r_zaycev031972@postgrespro.ru", "phone": "+70038682721"}
0005433810811	B4333A	2291 326109	VLADIMIR EGOROV	{"email": "vladimir_egorov.1979@postgrespro.ru", "phone": "+70268130390"}
0005433810812	B4333A	5493 252965	SERGEY SMIRNOV	{"phone": "+70449127755"}
0005433810813	B4333A	0725 793449	GEORGIY ABRAMOV	{"phone": "+70996921325"}
0005433810814	0D9E81	8030 781965	VLADIMIR PETROV	{"email": "v_petrov.081984@postgrespro.ru", "phone": "+70902918458"}
0005433810815	90F639	4813 259309	MARGARITA TIKHONOVA	{"phone": "+70467993851"}
0005433810816	90F639	4180 110612	ELENA NOVIKOVA	{"email": "e.novikova.121977@postgrespro.ru", "phone": "+70217429090"}
0005433810817	724F07	9718 842576	ALEKSEY ZAKHAROV	{"phone": "+70377186374"}
0005433810818	724F07	8496 419123	SERGEY SERGEEV	{"email": "sergeev_s_09011964@postgrespro.ru", "phone": "+70382287969"}
0005433810819	792A6E	4902 476881	ALEKSANDR GORBUNOV	{"email": "gorbunov_aleksandr-031979@postgrespro.ru", "phone": "+70820807391"}
0005433810820	9E9638	7663 416319	ALEKSANDR ALEKSEEV	{"email": "aalekseev.041973@postgrespro.ru", "phone": "+70563190028"}
0005433810821	9E9638	3730 161165	NATALYA ORLOVA	{"email": "orlovan-07081971@postgrespro.ru", "phone": "+70676066414"}
0005433810822	9E9638	6038 935991	ALEKSANDR FOMIN	{"phone": "+70197590616"}
0005433811610	1C963D	0704 297430	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova.n_26081975@postgrespro.ru", "phone": "+70444252702"}
0005433811611	1C963D	7089 224784	RAMIS ANDREEV	{"phone": "+70668781280"}
0005433811612	B65899	7495 140016	VYACHESLAV SIDOROV	{"email": "sidorovvyacheslav1981@postgrespro.ru", "phone": "+70133130972"}
0005433811613	B65899	9872 442409	OLGA FOMINA	{"phone": "+70483706015"}
0005433811614	B65899	6824 381690	NADEZHDA ABRAMOVA	{"email": "n_abramova-061967@postgrespro.ru", "phone": "+70709721819"}
0005433811615	20FF75	4509 462216	ANNA SEMENOVA	{"email": "a-semenova101967@postgrespro.ru", "phone": "+70113753287"}
0005433811616	757F4D	8896 517936	VITALIY POPOV	{"email": "v_popov-10081968@postgrespro.ru", "phone": "+70839241436"}
0005433811617	8F5E7A	9521 267685	VALENTINA CHERNOVA	{"phone": "+70818479185"}
0005433811618	79D580	3368 147494	VALENTINA ZAKHAROVA	{"email": "valentina_zakharova.02021974@postgrespro.ru", "phone": "+70646885137"}
0005433811619	79D580	1016 907872	TATYANA NIKIFOROVA	{"email": "nikiforovat-1965@postgrespro.ru", "phone": "+70894559961"}
0005433811620	79D580	2030 232615	MARIYA YAKOVLEVA	{"email": "m_yakovleva021970@postgrespro.ru", "phone": "+70892472051"}
0005433811621	DE3CCB	5196 067336	BORIS SCHERBAKOV	{"email": "b-scherbakov_081975@postgrespro.ru", "phone": "+70969934724"}
0005433811622	DE3CCB	9259 879711	IRINA NIKITINA	{"email": "nikitinai1978@postgrespro.ru", "phone": "+70675674970"}
0005433811623	49E82E	6703 625440	OLGA NIKITINA	{"phone": "+70108146969"}
0005433811624	34626B	1446 166423	ILYA SCHERBAKOV	{"email": "i_scherbakov1971@postgrespro.ru", "phone": "+70008158595"}
0005433811625	34626B	3454 707709	KONSTANTIN SEMENOV	{"email": "k-semenov041977@postgrespro.ru", "phone": "+70660605102"}
0005433811626	E2F272	4048 765598	OLGA SOLOVEVA	{"email": "soloveva_o_101976@postgrespro.ru", "phone": "+70279789576"}
0005433811627	E2F272	0620 788371	ANATOLIY KAZAKOV	{"email": "anatoliy.kazakov_011974@postgrespro.ru", "phone": "+70877359432"}
0005433811628	87F3CF	8961 996189	KSENIYA POPOVA	{"phone": "+70594556174"}
0005433811629	F4DD99	9036 536226	DARYA LEBEDEVA	{"phone": "+70718724056"}
0005433811630	9D5B34	7160 208208	IGOR GERASIMOV	{"email": "gerasimov.igor_011972@postgrespro.ru", "phone": "+70751955556"}
0005433811631	4A0F4A	0196 820175	ANATOLIY KOZLOV	{"email": "anatoliy.kozlov-1967@postgrespro.ru", "phone": "+70771050602"}
0005433811632	97825E	9115 408831	EKATERINA KUZMINA	{"phone": "+70692466977"}
0005433811633	4990DE	2110 037072	FANIYA KRASNOVA	{"phone": "+70485249028"}
0005433811634	4A20B1	7372 600177	VALERIY GAVRILOV	{"email": "v-gavrilov041969@postgrespro.ru", "phone": "+70117746057"}
0005433811635	1E2736	7253 197564	SERGEY SIDOROV	{"phone": "+70163632942"}
0005433811636	1E2736	8219 342839	SVETLANA MIKHAYLOVA	{"phone": "+70729585843"}
0005433811637	1E2736	9005 004532	NATALYA RYABOVA	{"email": "n.ryabova.06121973@postgrespro.ru", "phone": "+70602370627"}
0005433811638	C47CF7	8280 901994	MARINA POTAPOVA	{"email": "marinapotapova.17031968@postgrespro.ru", "phone": "+70256556961"}
0005433811639	A03A4B	8426 913716	VITALIY VASILEV	{"phone": "+70831291077"}
0005433811640	6A4144	1433 498094	MARINA MOROZOVA	{"email": "morozova_marina_051977@postgrespro.ru", "phone": "+70253675321"}
0005433811641	3ED485	2277 772063	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda_021972@postgrespro.ru", "phone": "+70176230654"}
0005433811642	3ED485	2816 976560	OLEG KOZLOV	{"email": "kozlov.o-1968@postgrespro.ru", "phone": "+70284843154"}
0005433811643	7BB7AA	9730 618061	LILIYA PETROVA	{"phone": "+70009737796"}
0005433811644	38CBA9	6620 562752	VLADIMIR DAVYDOV	{"phone": "+70075766062"}
0005433811645	D5E33F	8071 643702	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko_091988@postgrespro.ru", "phone": "+70570140038"}
0005433811646	1230A5	7092 385211	ANDREY GAVRILOV	{"email": "gavrilov-a-1973@postgrespro.ru", "phone": "+70648302225"}
0005433811647	886C68	0523 512899	DARYA BOGDANOVA	{"phone": "+70877405084"}
0005433811648	3D92BC	4794 138775	VLADIMIR ORLOV	{"phone": "+70514592075"}
0005433811649	92E235	3466 033526	TATYANA KULIKOVA	{"phone": "+70682963820"}
0005433811650	07B65C	7888 871789	RAMIL GUSEV	{"phone": "+70731001499"}
0005433811651	768413	2503 128525	MARIYA POTAPOVA	{"email": "mariya-potapova.1971@postgrespro.ru", "phone": "+70580606611"}
0005433811652	0C646F	7468 355695	ANNA EFREMOVA	{"email": "aefremova.031981@postgrespro.ru", "phone": "+70258142604"}
0005433811653	49FA3D	8259 528838	ANTONINA BORISOVA	{"phone": "+70524717979"}
0005433811654	ED847A	0344 793808	VALERIY SOKOLOV	{"email": "sokolov.valeriy_1973@postgrespro.ru", "phone": "+70785865094"}
0005433811655	ED847A	2970 963453	NINA OVCHINNIKOVA	{"email": "ovchinnikova.n-02071970@postgrespro.ru", "phone": "+70269415967"}
0005433811656	5C8DBF	8413 925732	ALEKSANDRA SCHERBAKOVA	{"email": "a.scherbakova_071977@postgrespro.ru", "phone": "+70890536360"}
0005433811657	C8139B	8939 564635	SVETLANA KUZNECOVA	{"phone": "+70269644461"}
0005433811658	3C1AD9	0391 151303	MAKSIM KOROLEV	{"phone": "+70758537249"}
0005433811659	A71962	7427 412174	ALINA IVANOVA	{"phone": "+70028187935"}
0005433811660	432F33	3819 326808	GALINA KONDRATEVA	{"phone": "+70995501887"}
0005433811661	81E1F9	8229 217538	MARIYA NAZAROVA	{"email": "nazarova.m1958@postgrespro.ru", "phone": "+70177148188"}
0005433811662	8578B7	1829 807647	LYUDMILA SEMENOVA	{"phone": "+70481175529"}
0005433811663	32F776	6494 801166	ANNA EGOROVA	{"email": "egorovaanna-1965@postgrespro.ru", "phone": "+70582276293"}
0005433811664	7EFF12	2938 359573	NIKOLAY SIDOROV	{"phone": "+70875947643"}
0005433811665	12DC59	7116 772053	NIKOLAY SAVELEV	{"phone": "+70940733418"}
0005433811666	C10546	4141 360759	VARVARA ERMAKOVA	{"phone": "+70440930683"}
0005433811667	173DFE	4057 862106	NATALYA YUDINA	{"phone": "+70690841911"}
0005433811668	173DFE	8798 367309	ELENA SEMENOVA	{"email": "e-semenova.1987@postgrespro.ru", "phone": "+70658397488"}
0005433811669	5EB65C	9748 018750	NINA SEMENOVA	{"email": "semenova_nina011972@postgrespro.ru", "phone": "+70917528747"}
0005433811670	5EB65C	4067 408899	VASILIY SERGEEV	{"phone": "+70529189806"}
0005433811671	C0852A	5911 181477	ALEKSANDR BONDARENKO	{"phone": "+70384158202"}
0005433811672	C0852A	6040 647670	ELENA NESTEROVA	{"phone": "+70065146787"}
0005433811673	BD1D07	3082 789705	SERGEY POPOV	{"phone": "+70502507116"}
0005433811674	453BF2	7561 026800	RAISA FOMINA	{"phone": "+70435752119"}
0005433811675	291980	7728 694485	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail.29121974@postgrespro.ru", "phone": "+70095004978"}
0005433811676	F853B4	1746 694445	OLEG IVANOV	{"phone": "+70356565042"}
0005433811677	2EF0B0	9698 747915	EKATERINA BELOVA	{"email": "e_belova.1978@postgrespro.ru", "phone": "+70484195823"}
0005433811678	CAECA7	2809 446356	TATYANA SIDOROVA	{"email": "tatyana-sidorova.1967@postgrespro.ru", "phone": "+70470572851"}
0005433811679	CAECA7	1116 451561	DENIS KUZMIN	{"email": "d_kuzmin_1971@postgrespro.ru", "phone": "+70487499460"}
0005433811680	851553	0504 513189	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.071979@postgrespro.ru", "phone": "+70234011811"}
0005433811681	3720F7	6436 199131	TAISIYA MAKAROVA	{"phone": "+70085700530"}
0005433811682	3720F7	3936 120850	NIKOLAY KOROLEV	{"email": "korolev_n_1973@postgrespro.ru", "phone": "+70716420596"}
0005433811683	964515	3738 417586	DENIS GORBUNOV	{"email": "denis-gorbunov.21101980@postgrespro.ru", "phone": "+70841551055"}
0005433811684	74FB83	3315 421698	ALEKSANDR KUZMIN	{"phone": "+70026132877"}
0005433811685	A66AE8	0490 186825	LIDIYA KOZLOVA	{"phone": "+70900780637"}
0005433811686	EA31AE	0434 567949	NATALYA KUZNECOVA	{"email": "kuznecovan1980@postgrespro.ru", "phone": "+70521651135"}
0005433811687	2A11C8	6094 906940	VYACHESLAV SERGEEV	{"phone": "+70723839190"}
0005433811688	2A11C8	1285 600198	SERGEY NIKITIN	{"email": "nikitin_s-26021978@postgrespro.ru", "phone": "+70437597370"}
0005433811689	81C8C6	9285 803194	MARIYA TIMOFEEVA	{"email": "timofeeva-mariya_1979@postgrespro.ru", "phone": "+70985619127"}
0005433811690	AB9076	4883 627640	GENNADIY ANDREEV	{"phone": "+70496489882"}
0005433811691	BC2476	8209 746542	RADIK GUSEV	{"email": "gusev-radik.031983@postgrespro.ru", "phone": "+70573221781"}
0005433812857	7F257C	3879 411404	IGOR SCHERBAKOV	{"phone": "+70678653209"}
0005433812858	A59C08	2316 472215	SNEZHANA KUZNECOVA	{"phone": "+70606670214"}
0005433812859	A59C08	8828 102696	VERA SAVELEVA	{"email": "saveleva-vera_31121970@postgrespro.ru", "phone": "+70940451041"}
0005433812860	9542EF	8333 862727	VLADIMIR PAVLOV	{"phone": "+70898533167"}
0005433812861	AC8853	7381 360313	GENNADIY DENISOV	{"phone": "+70015376065"}
0005433812862	36E7AE	8111 830611	DMITRIY AFANASEV	{"email": "dmitriy_afanasev.1964@postgrespro.ru", "phone": "+70057561155"}
0005433812863	49713E	9256 029871	ANDREY MOROZOV	{"email": "morozov_a.29081984@postgrespro.ru", "phone": "+70595168319"}
0005433812864	F06DAE	4168 877133	LYUBOV ZAYCEVA	{"phone": "+70911672077"}
0005433812865	F06DAE	0178 117517	PETR PAVLOV	{"email": "p_pavlov061976@postgrespro.ru", "phone": "+70612770306"}
0005433812866	B4927E	5928 217073	VLADIMIR SCHERBAKOV	{"phone": "+70069290697"}
0005433812867	5FDD82	4466 667350	MARIYA EFREMOVA	{"phone": "+70684868578"}
0005433812868	7C3CD6	1142 156429	PAVEL OSIPOV	{"phone": "+70780005069"}
0005433812869	3FEDDE	7871 412823	VALERIY MAKAROV	{"email": "v.makarov26021973@postgrespro.ru", "phone": "+70824306948"}
0005433812870	C46A4F	1651 240058	VITALIY PETROV	{"phone": "+70314869148"}
0005433812871	C46A4F	2391 175058	NIKOLAY MATVEEV	{"email": "nmatveev-24011978@postgrespro.ru", "phone": "+70415377359"}
0005433812872	C22B18	1810 254839	ALEKSEY MAKAROV	{"phone": "+70765768308"}
0005433812873	2ABD85	1983 526456	NADEZHDA KOZLOVA	{"email": "kozlovanadezhda20051978@postgrespro.ru", "phone": "+70986184949"}
0005433812874	D339D8	9637 054475	VLADIMIR KOZLOV	{"phone": "+70512769089"}
0005433812875	D339D8	8697 880789	VERA GORBUNOVA	{"phone": "+70095992322"}
0005433812876	375DF1	8209 316075	LYUBOV ILINA	{"phone": "+70543006529"}
0005433812877	375DF1	6379 184699	VALERIY ROMANOV	{"email": "romanov.v_1963@postgrespro.ru", "phone": "+70213371652"}
0005433812878	AC384A	5940 326366	YURIY SIDOROV	{"email": "y.sidorov_031971@postgrespro.ru", "phone": "+70219562503"}
0005433812879	AC384A	1755 480585	IRINA ZAKHAROVA	{"email": "i-zakharova05121967@postgrespro.ru", "phone": "+70848905997"}
0005433812880	AC384A	5312 221821	NINA CHERNOVA	{"phone": "+70626697866"}
0005433812881	7BEE05	8568 439301	ELVIRA NESTEROVA	{"email": "nesterovae_041967@postgrespro.ru", "phone": "+70603178081"}
0005433812882	2E6BE8	9234 144293	ELVIRA DMITRIEVA	{"email": "e_dmitrieva-1980@postgrespro.ru", "phone": "+70561733582"}
0005433812883	2CEA87	8353 980583	IVAN SIDOROV	{"email": "ivan-sidorov_1971@postgrespro.ru", "phone": "+70120282709"}
0005433812884	FA6006	8872 276617	LYUDMILA LEBEDEVA	{"email": "lyudmilalebedeva_1981@postgrespro.ru", "phone": "+70251647227"}
0005433812885	FA6006	1736 573568	LYUDMILA ILINA	{"email": "ilina.l_011966@postgrespro.ru", "phone": "+70495614027"}
0005433812886	CF2741	2911 274055	POLINA FILATOVA	{"email": "filatova.polina.1972@postgrespro.ru", "phone": "+70384023134"}
0005433812887	CF2741	1155 096010	ALEKSANDRA SIDOROVA	{"email": "a_sidorova.10051964@postgrespro.ru", "phone": "+70927569294"}
0005433812888	E0EC20	9774 699831	ANTONINA CHERNOVA	{"email": "a.chernova_021977@postgrespro.ru", "phone": "+70406094227"}
0005433812889	E0EC20	1681 661514	DAMIR ANTONOV	{"email": "damir_antonov_01011967@postgrespro.ru", "phone": "+70549644032"}
0005433812890	81796C	3182 684657	ELENA KUZMINA	{"email": "kuzmina-e-1966@postgrespro.ru", "phone": "+70702989078"}
0005433812891	81796C	9462 387779	NATALYA VLASOVA	{"phone": "+70329689967"}
0005433812892	31040A	7668 101306	DMITRIY PETROV	{"phone": "+70397592835"}
0005433812893	E7C10E	3768 736412	EVDOKIYA NOVIKOVA	{"phone": "+70498083781"}
0005433812894	145CD0	8959 525219	SOFIYA POPOVA	{"email": "popova.sofiya1980@postgrespro.ru", "phone": "+70573881227"}
0005433812895	669864	1831 450807	ALEKSEY SEMENOV	{"email": "semenov_aleksey.031975@postgrespro.ru", "phone": "+70297538113"}
0005433812896	B7B994	3280 628324	YURIY KUZNECOV	{"email": "yuriy-kuznecov.1973@postgrespro.ru", "phone": "+70730554083"}
0005433812897	B7B994	5113 870582	ALEKSANDR SEMENOV	{"email": "asemenov-111979@postgrespro.ru", "phone": "+70682337970"}
0005433812898	BEDE43	6704 003615	RUSLAN FEDOROV	{"phone": "+70678448800"}
0005433812899	E15238	3255 650659	TAMARA SCHERBAKOVA	{"phone": "+70723795046"}
0005433812900	C0F3A7	8837 859685	ANDREY KISELEV	{"phone": "+70239242716"}
0005433812901	6CFFA7	1240 304925	NINA MEDVEDEVA	{"email": "medvedevanina_1964@postgrespro.ru", "phone": "+70631514033"}
0005433812902	6CFFA7	7778 075111	OLGA MAKSIMOVA	{"phone": "+70529273318"}
0005433812903	3EE15F	3335 346251	OLGA KOLESNIKOVA	{"email": "o-kolesnikova-1966@postgrespro.ru", "phone": "+70326105288"}
0005433812904	F8C871	1854 890038	NIKOLAY DMITRIEV	{"phone": "+70671739916"}
0005433812905	08BCF3	7999 913512	ANATOLIY SOKOLOV	{"phone": "+70463896479"}
0005433812906	D5F749	6499 852961	ALEKSANDR POPOV	{"email": "popovaleksandr021972@postgrespro.ru", "phone": "+70561946374"}
0005433812907	15DC32	2384 588399	ARTEM KUZNECOV	{"email": "akuznecov_1967@postgrespro.ru", "phone": "+70001143277"}
0005433812908	15DC32	9478 923090	ARINA YAKOVLEVA	{"phone": "+70733347830"}
0005433812909	15DC32	9393 859359	PETR KUZNECOV	{"email": "kuznecov.p-021958@postgrespro.ru", "phone": "+70740936153"}
0005433812910	8B4DFC	4695 658597	ALBINA GUSEVA	{"email": "guseva.albina.16051973@postgrespro.ru", "phone": "+70142370857"}
0005433812911	483015	5150 583200	ALFIYA SERGEEVA	{"phone": "+70259879760"}
0005433812912	483015	4233 286893	GALINA KOROLEVA	{"email": "koroleva_g.041978@postgrespro.ru", "phone": "+70896915999"}
0005433812913	716996	8417 537670	ALSU POPOVA	{"email": "alsu-popova_1962@postgrespro.ru", "phone": "+70381482344"}
0005433812914	381119	7915 214569	ELENA ANISIMOVA	{"email": "elena_anisimova-11041967@postgrespro.ru", "phone": "+70797911642"}
0005433812915	462BEA	4125 798804	NATALYA ZHUKOVA	{"phone": "+70951536492"}
0005433812916	1896CB	7666 291010	NATALYA MATVEEVA	{"phone": "+70854948589"}
0005433812917	D3019E	1718 098333	IRINA ORLOVA	{"phone": "+70262870313"}
0005433812918	EF430D	4206 315953	ALEKSEY ABRAMOV	{"email": "a_abramov.27011971@postgrespro.ru", "phone": "+70906594117"}
0005433812919	31B1C5	8174 794994	OLGA MOROZOVA	{"phone": "+70606961927"}
0005433812920	8728F5	6507 692187	PAVEL KOROLEV	{"email": "pavelkorolev1973@postgrespro.ru", "phone": "+70059623210"}
0005433812921	9DAD0B	4867 771188	EVGENIY SOLOVEV	{"phone": "+70555996630"}
0005433812922	71A674	2342 121184	REGINA NESTEROVA	{"phone": "+70471536260"}
0005433812923	162CCF	4621 390680	VENERA VASILEVA	{"phone": "+70069599061"}
0005433812924	E11A30	3092 278057	NIKITA MOROZOV	{"email": "n_morozov.02081973@postgrespro.ru", "phone": "+70797671333"}
0005433812925	58336C	6393 534674	OLEG MELNIKOV	{"email": "omelnikov.29061982@postgrespro.ru", "phone": "+70137197290"}
0005433812926	B0FD9C	3193 183790	NATALYA SIDOROVA	{"email": "sidorovan121972@postgrespro.ru", "phone": "+70875602452"}
0005433812927	BE6834	9184 234533	LYUDMILA BARANOVA	{"email": "lyudmila_baranova26051964@postgrespro.ru", "phone": "+70597032642"}
0005433812928	7E7403	7514 921709	TATYANA MARTYNOVA	{"email": "martynova_t30091967@postgrespro.ru", "phone": "+70608707139"}
0005433812929	178FC4	0795 543378	ELENA KONOVALOVA	{"phone": "+70624884619"}
0005433812930	178FC4	0481 222238	NATALIYA NOVIKOVA	{"email": "novikova_n_22071973@postgrespro.ru", "phone": "+70179879457"}
0005433812931	178FC4	5426 690356	GRIGORIY STEPANOV	{"email": "stepanov.g.1979@postgrespro.ru", "phone": "+70315075105"}
0005433812932	4CA8F1	8128 436486	LARISA CHERNOVA	{"email": "l_chernova.19031966@postgrespro.ru", "phone": "+70612160744"}
0005433812933	4CA8F1	1055 843658	ELENA KRASNOVA	{"phone": "+70086668816"}
0005433812934	56235D	5171 720485	RIMMA ILINA	{"phone": "+70914992015"}
0005433812935	1F029E	2037 477850	LYUBOV IVANOVA	{"phone": "+70188796125"}
0005433812936	422700	6528 446080	VIKTOR NOVIKOV	{"email": "viktor_novikov.07111962@postgrespro.ru", "phone": "+70387501647"}
0005433812937	C0F709	5956 676153	MARIYA GUSEVA	{"email": "guseva_mariya-011966@postgrespro.ru", "phone": "+70194543185"}
0005433812938	C0F709	2561 817143	VITALIY SOROKIN	{"phone": "+70166070886"}
0005433812939	F5CA85	0719 643622	ANTON SMIRNOV	{"email": "smirnov_anton121975@postgrespro.ru", "phone": "+70623769092"}
0005433812940	F5CA85	2061 314359	ANTONINA DANILOVA	{"email": "a-danilova-061978@postgrespro.ru", "phone": "+70695094846"}
0005433812941	DABCCE	9637 431832	ANATOLIY MIKHAYLOV	{"email": "anatoliymikhaylov.061973@postgrespro.ru", "phone": "+70350176789"}
0005433812942	DABCCE	8473 137566	EGOR FILIPPOV	{"email": "efilippov091964@postgrespro.ru", "phone": "+70938221476"}
0005433812943	DABCCE	7239 789484	MARIYA BORISOVA	{"email": "borisova.m-1961@postgrespro.ru", "phone": "+70829534176"}
0005433812944	B9FEC3	8662 606758	OLEG MARTYNOV	{"email": "martynov.o1977@postgrespro.ru", "phone": "+70999117101"}
0005433812945	B9FEC3	2431 730856	MARIYA BELOVA	{"email": "belovamariya08061976@postgrespro.ru", "phone": "+70449624091"}
0005433812946	EC06C7	1417 676576	NIKOLAY GRIGOREV	{"phone": "+70816403953"}
0005433812947	AAC4F7	5517 571030	ELENA IVANOVA	{"email": "elena.ivanova.1955@postgrespro.ru", "phone": "+70039406460"}
0005433812948	2EAEAF	5680 627857	NADIYA POPOVA	{"email": "nadiya_popova_1974@postgrespro.ru", "phone": "+70397969034"}
0005433812949	B929D3	0370 391660	ALEKSANDR ORLOV	{"email": "orlov-a-021979@postgrespro.ru", "phone": "+70839613112"}
0005433812950	C60D5C	4375 883851	ELENA MIKHAYLOVA	{"phone": "+70313266926"}
0005433812951	C60D5C	9017 864805	YURIY IVANOV	{"email": "ivanov-yuriy-051970@postgrespro.ru", "phone": "+70763336394"}
0005433812952	B1B546	1009 156694	VLADIMIR ISAEV	{"email": "vladimir_isaev-041962@postgrespro.ru", "phone": "+70511382906"}
0005433812953	781908	9083 842632	ALEKSANDR ROMANOV	{"email": "a.romanov021973@postgrespro.ru", "phone": "+70947465531"}
0005433812954	9A497D	9983 116164	ALEKSEY MAKAROV	{"phone": "+70012372476"}
0005433812955	7D5D49	0325 594992	VLADIMIR KUZNECOV	{"phone": "+70622205351"}
0005433812956	D3BFB1	0842 069880	VIKTOR DAVYDOV	{"email": "viktor_davydov.121967@postgrespro.ru", "phone": "+70555975007"}
0005433812957	D3BFB1	7036 253301	GENNADIY KOROLEV	{"email": "g-korolev07091967@postgrespro.ru", "phone": "+70266735521"}
0005433812958	D3BFB1	3825 474174	OLGA KOZLOVA	{"email": "o_kozlova.091966@postgrespro.ru", "phone": "+70383850082"}
0005433812959	33CF06	1076 594856	SERGEY DENISOV	{"phone": "+70891375894"}
0005433812960	51F72F	1562 758616	DARYA MAKAROVA	{"phone": "+70741390233"}
0005433812961	51F72F	9412 970191	SERGEY KUZNECOV	{"email": "kuznecov-s-1969@postgrespro.ru", "phone": "+70281748146"}
0005433812962	4360C6	3544 629956	VYACHESLAV MIKHAYLOV	{"email": "vyacheslavmikhaylov_20011955@postgrespro.ru", "phone": "+70664554743"}
0005433812963	D85E79	0799 189419	DMITRIY DAVYDOV	{"phone": "+70147674883"}
0005433812964	D85E79	8016 843088	OLGA KUZNECOVA	{"email": "o.kuznecova-1980@postgrespro.ru", "phone": "+70312731157"}
0005433812965	5A0B88	7890 872101	POLINA VOROBEVA	{"phone": "+70908173786"}
0005433812966	B8BEBF	5779 605926	DARYA BARANOVA	{"email": "baranovadarya_1981@postgrespro.ru", "phone": "+70559202830"}
0005433812967	0BBAE0	7373 527784	IRINA DAVYDOVA	{"phone": "+70400788141"}
0005433812968	753462	3203 670341	ELENA MATVEEVA	{"phone": "+70470746494"}
0005433815300	BB40CF	0012 666383	SOFYA SOKOLOVA	{"email": "sokolova-sofya_101951@postgrespro.ru", "phone": "+70055025426"}
0005433815301	71867F	2721 465637	MIKHAIL TARASOV	{"email": "mikhailtarasov_03071978@postgrespro.ru", "phone": "+70507817983"}
0005433815302	71867F	9843 909644	PAVEL KULIKOV	{"phone": "+70462822962"}
0005433815303	7528BA	4400 051327	INNA IVANOVA	{"phone": "+70665953942"}
0005433815304	7D5F07	0581 311720	NIKITA SIDOROV	{"email": "n_sidorov-071975@postgrespro.ru", "phone": "+70339054861"}
0005433815305	7D5F07	1037 032313	IRINA MAKSIMOVA	{"phone": "+70436521452"}
0005433815306	A18447	0538 351623	VIKTOR IVANOV	{"phone": "+70034209602"}
0005433815307	A03DE9	1707 897601	SERGEY FEDOROV	{"phone": "+70312176280"}
0005433815308	13E68E	7185 878946	TATYANA ROMANOVA	{"phone": "+70780520843"}
0005433815309	A3E3EC	1294 735139	ANDREY MOROZOV	{"email": "morozov_andrey1975@postgrespro.ru", "phone": "+70686026682"}
0005433815310	337155	7544 413863	DANILA SOROKIN	{"phone": "+70275946346"}
0005433815311	9F5E9E	2725 487876	ANTON ALEKSANDROV	{"phone": "+70800148578"}
0005433815312	F2FEC6	6211 432086	OLESYA PETROVA	{"phone": "+70136814087"}
0005433815313	F2FEC6	7027 567194	INNA VLASOVA	{"phone": "+70028394801"}
0005433815314	C88041	4523 032036	TATYANA KUZNECOVA	{"phone": "+70452554826"}
0005433815315	349365	7789 000816	ANNA SAVELEVA	{"email": "saveleva_a_071969@postgrespro.ru", "phone": "+70021470512"}
0005433815316	349365	3076 224928	MAKSIM SHEVCHENKO	{"email": "m_shevchenko_091965@postgrespro.ru", "phone": "+70782582927"}
0005433815317	845A43	0191 049611	GRIGORIY MAKAROV	{"phone": "+70271088430"}
0005433815318	845A43	3061 861136	ALEKSEY ANDREEV	{"email": "aandreev-091982@postgrespro.ru", "phone": "+70353881211"}
0005433815319	5D5253	6616 993195	EVGENIYA SIDOROVA	{"phone": "+70974564773"}
0005433815320	181C44	4900 714321	MIKHAIL RODIONOV	{"phone": "+70408176347"}
0005433815321	181C44	9563 747497	LARISA POPOVA	{"phone": "+70194769456"}
0005433815322	55E4B8	6519 903111	SERGEY SAVELEV	{"email": "s.savelev.1974@postgrespro.ru", "phone": "+70247882644"}
0005433815323	74C20F	1265 957753	VLADIMIR IVANOV	{"phone": "+70639723832"}
0005433815324	956C73	5343 107141	ALEKSANDR VOLKOV	{"email": "aleksandrvolkov-01021978@postgrespro.ru", "phone": "+70915885526"}
0005433815325	CA8DA5	2400 962466	EVGENIY SOROKIN	{"phone": "+70004973142"}
0005433815326	0DD2BB	1484 143980	ANASTASIYA LUKYANOVA	{"phone": "+70241029455"}
0005433815327	A36297	8295 839101	ANASTASIYA FROLOVA	{"email": "frolova_a_1972@postgrespro.ru", "phone": "+70921545352"}
0005433815328	A36297	4533 788338	ALEKSEY TIMOFEEV	{"email": "atimofeev-1967@postgrespro.ru", "phone": "+70648203347"}
0005433815329	CCA7B2	7265 763302	NADEZHDA CHERNOVA	{"email": "chernova-nadezhda-16121965@postgrespro.ru", "phone": "+70933465599"}
0005433815330	FD374D	5504 735203	TATYANA FROLOVA	{"phone": "+70285830885"}
0005433815331	FD374D	0012 321900	OLGA PAVLOVA	{"phone": "+70110810342"}
0005433815332	FD374D	8632 818127	VYACHESLAV MARTYNOV	{"email": "v-martynov_02071972@postgrespro.ru", "phone": "+70035883512"}
0005433815333	7FEAC1	5063 773379	SERGEY DMITRIEV	{"phone": "+70696961117"}
0005433815334	73C5B1	1692 158694	INNA KOVALEVA	{"phone": "+70571028533"}
0005433815335	73C5B1	0250 091789	NATALYA MATVEEVA	{"email": "matveeva-natalya1971@postgrespro.ru", "phone": "+70836108811"}
0005433815336	352E45	0105 403334	ALEKSANDR VASILEV	{"phone": "+70240234464"}
0005433815337	02A0C6	5170 589066	NAIL SOKOLOV	{"email": "nail.sokolov_13071979@postgrespro.ru", "phone": "+70496478770"}
0005433815338	17B8A6	8946 193299	ALEKSANDR IVANOV	{"email": "aivanov1966@postgrespro.ru", "phone": "+70356072511"}
0005433815339	F94A4C	1462 317776	NIKOLAY MARTYNOV	{"email": "martynov-n.1964@postgrespro.ru", "phone": "+70104728919"}
0005433815340	D7AA95	2927 915219	ALEKSANDR POPOV	{"email": "aleksandr_popov061968@postgrespro.ru", "phone": "+70441303026"}
0005433815341	D7AA95	7595 414372	NATALYA DANILOVA	{"email": "n-danilova-051974@postgrespro.ru", "phone": "+70261267371"}
0005433815342	2901DC	0461 069579	EVGENIY ISAEV	{"email": "isaev.evgeniy_05031960@postgrespro.ru", "phone": "+70917115108"}
0005433815343	2901DC	8095 415250	LYUDMILA NIKITINA	{"email": "l-nikitina.21041961@postgrespro.ru", "phone": "+70658314631"}
0005433815344	C85C75	2918 838749	VLADIMIR ROMANOV	{"phone": "+70796983172"}
0005433815345	B47DF6	1971 239605	ANATOLIY ILIN	{"email": "a-ilin_061972@postgrespro.ru", "phone": "+70809690759"}
0005433815346	B47DF6	9496 876613	OLEG POPOV	{"email": "o_popov1958@postgrespro.ru", "phone": "+70255391070"}
0005433815347	3E51C3	7560 349608	MIKHAIL KOZLOV	{"phone": "+70152366252"}
0005433815348	E62053	0504 561774	IRINA POPOVA	{"email": "i_popova-1972@postgrespro.ru", "phone": "+70682799055"}
0005433815349	305209	6488 690788	ANNA ZHUKOVA	{"email": "anna.zhukova-20071982@postgrespro.ru", "phone": "+70863043348"}
0005433815350	305209	4304 392058	OLGA TIMOFEEVA	{"phone": "+70345065471"}
0005433815351	8E981B	2248 981764	LYUDMILA KUZMINA	{"email": "lyudmila.kuzmina-041981@postgrespro.ru", "phone": "+70719315315"}
0005433815352	5FA68A	5228 894991	ANNA BORISOVA	{"phone": "+70749481563"}
0005433815353	5FA68A	5517 315065	IRAIDA IVANOVA	{"email": "ivanova.iraida_1968@postgrespro.ru", "phone": "+70603097945"}
0005433815354	4B2234	6305 282435	SVETLANA ZOTOVA	{"email": "zotovas011983@postgrespro.ru", "phone": "+70589622929"}
0005433815355	402695	8987 463823	VYACHESLAV MIKHAYLOV	{"phone": "+70919124583"}
0005433815356	3DFC7F	7365 041210	ALEKSANDRA ZOTOVA	{"email": "zotova_aleksandra-041974@postgrespro.ru", "phone": "+70752351617"}
0005433815357	4E6021	2215 989518	VLADIMIR ILIN	{"phone": "+70526923650"}
0005433815358	4E6021	9183 273125	ANNA MIKHAYLOVA	{"phone": "+70166987400"}
0005433815359	1933AA	5084 026434	ALLA AFANASEVA	{"email": "afanaseva.a_23111968@postgrespro.ru", "phone": "+70346391593"}
0005433815360	CA1245	0088 257843	EKATERINA POPOVA	{"email": "popova_e061980@postgrespro.ru", "phone": "+70091895486"}
0005433815361	AFCF8C	4607 540989	VALERIY ZAKHAROV	{"email": "valeriy-zakharov_051982@postgrespro.ru", "phone": "+70037136750"}
0005433815362	864C41	7348 076247	SVETLANA DENISOVA	{"email": "denisova-s.071967@postgrespro.ru", "phone": "+70067931159"}
0005433815363	286BAA	8123 311859	ELENA ANISIMOVA	{"email": "e-anisimova_1959@postgrespro.ru", "phone": "+70859143222"}
0005433815364	E9FFA4	9729 666754	VALENTINA NESTEROVA	{"phone": "+70937896749"}
0005433815365	220C47	5556 804531	ALEKSANDR SMIRNOV	{"email": "a.smirnov1981@postgrespro.ru", "phone": "+70709292369"}
0005433815366	F85462	4733 760366	LIDIYA SMIRNOVA	{"email": "smirnovalidiya-1976@postgrespro.ru", "phone": "+70587049184"}
0005433815367	1C06C3	5544 486365	YULIYA NOVIKOVA	{"email": "yuliyanovikova_041976@postgrespro.ru", "phone": "+70931000939"}
0005433815368	B0D38F	4250 269789	NATALYA KUZMINA	{"phone": "+70793734721"}
0005433815369	B0D38F	1783 012391	DMITRIY KOZLOV	{"email": "kozlovdmitriy-1977@postgrespro.ru", "phone": "+70388811535"}
0005433815370	8F275C	1883 450540	ALINA GUSEVA	{"email": "gusevaa1974@postgrespro.ru", "phone": "+70731815391"}
0005433815371	8F275C	0681 265368	NADEZHDA MARTYNOVA	{"phone": "+70088294726"}
0005433815372	8F275C	5690 826903	IGOR DENISOV	{"phone": "+70436389268"}
0005433815373	8F275C	2727 632957	ALEKSEY ROMANOV	{"email": "aleksey.romanov.1975@postgrespro.ru", "phone": "+70699763444"}
0005433815374	2CE4C5	1490 558956	OLGA IVANOVA	{"email": "ivanovaolga_1983@postgrespro.ru", "phone": "+70832792882"}
0005433815375	ABD35C	6064 682374	IVAN FROLOV	{"email": "frolov_i_11081980@postgrespro.ru", "phone": "+70401132060"}
0005433815376	DAB2C7	7411 750827	ALEKSANDR BELOV	{"phone": "+70608253661"}
0005433815377	E76BFC	3853 024579	LYUDMILA DAVYDOVA	{"phone": "+70191572633"}
0005433815378	AF891C	6344 116429	DMITRIY BONDARENKO	{"email": "bondarenko.dmitriy.011973@postgrespro.ru", "phone": "+70439853124"}
0005433815379	AF891C	3898 360445	ANASTASIYA ZHURAVLEVA	{"phone": "+70975911160"}
0005433815380	92781B	9831 800969	IRINA IVANOVA	{"email": "iivanova1962@postgrespro.ru", "phone": "+70160873821"}
0005433815381	197A67	2869 839207	EKATERINA ALEKSEEVA	{"email": "alekseeva.e.121977@postgrespro.ru", "phone": "+70345043211"}
0005433815382	197A67	6145 531648	ANTON ZAYCEV	{"phone": "+70543266336"}
0005433815383	EA19FD	0045 074570	OLGA MOROZOVA	{"phone": "+70886834483"}
0005433815384	2825BC	0759 065663	ALEKSANDR KONOVALOV	{"phone": "+70574248837"}
0005433815385	2825BC	6626 349966	NATALYA FOMINA	{"phone": "+70733498897"}
0005433815386	011F0B	6952 681898	ALEKSANDR NAUMOV	{"email": "naumov.a_1965@postgrespro.ru", "phone": "+70677788545"}
0005433815387	932FDD	6656 675113	TATYANA VASILEVA	{"email": "tatyanavasileva.1966@postgrespro.ru", "phone": "+70331730591"}
0005433815388	932FDD	9925 500915	VLADIMIR VLASOV	{"email": "vlasov-v.121976@postgrespro.ru", "phone": "+70206540015"}
0005433815389	52DAD2	7939 383411	TATYANA POLYAKOVA	{"email": "tatyana.polyakova-121973@postgrespro.ru", "phone": "+70476110623"}
0005433815390	A104EA	7360 633742	SERGEY ALEKSANDROV	{"phone": "+70640845295"}
0005433815391	14CF6D	5489 930954	ALINA ANDREEVA	{"phone": "+70622144810"}
0005433815392	492BF7	4311 921331	MIKHAIL EGOROV	{"phone": "+70395933975"}
0005433815393	492BF7	2549 952630	ILONA BOGDANOVA	{"email": "bogdanovailona.061968@postgrespro.ru", "phone": "+70216482507"}
0005433815394	492BF7	0983 897218	VLADIMIR KUZMIN	{"phone": "+70124207059"}
0005433815454	63A4F0	5025 251904	OLESYA KUZNECOVA	{"phone": "+70472104429"}
0005433815395	492BF7	8256 673005	MARINA NIKOLAEVA	{"email": "mnikolaeva-011985@postgrespro.ru", "phone": "+70504635052"}
0005433815396	59978D	1474 354649	KHASAN DMITRIEV	{"phone": "+70669697446"}
0005433815397	5D31BB	6592 504156	MIKHAIL FILIPPOV	{"phone": "+70289264051"}
0005433815398	EFA362	6077 031684	VYACHESLAV SMIRNOV	{"phone": "+70397773260"}
0005433815399	EFA362	2560 265842	PAVEL GORBUNOV	{"email": "gorbunov-pavel.13111962@postgrespro.ru", "phone": "+70119388970"}
0005433815400	3E521C	1443 185215	VALENTINA KUDRYASHOVA	{"email": "kudryashova.v.10071972@postgrespro.ru", "phone": "+70462241060"}
0005433815401	53A256	7801 063443	NADEZHDA KUZNECOVA	{"phone": "+70317931716"}
0005433815402	53A256	9273 648431	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev.1978@postgrespro.ru", "phone": "+70120537437"}
0005433815403	4CDC7A	6524 979562	RAISA LEBEDEVA	{"email": "rlebedeva041983@postgrespro.ru", "phone": "+70032252824"}
0005433815404	A08873	3191 769731	IRINA ZHUKOVA	{"phone": "+70847738047"}
0005433815405	70D346	4348 520180	EKATERINA TIKHONOVA	{"email": "tikhonova_ekaterina_1978@postgrespro.ru", "phone": "+70166239951"}
0005433815406	DABD04	6843 217516	RAISA ABRAMOVA	{"phone": "+70119551970"}
0005433815407	846D5A	1108 179699	ALEKSANDRA EGOROVA	{"phone": "+70804659198"}
0005433815408	846D5A	4204 473568	ALEKSANDR MAKAROV	{"phone": "+70426005916"}
0005433815409	8F8298	5814 829325	TATYANA KOROLEVA	{"phone": "+70226560305"}
0005433815410	8F8298	1951 313134	YURIY MARTYNOV	{"email": "martynov-yuriy_1965@postgrespro.ru", "phone": "+70345817951"}
0005433815411	F49E3A	0293 138587	ANDREY KOZLOV	{"phone": "+70871989333"}
0005433815412	E459FF	4003 307153	ALEKSANDR FOMIN	{"email": "afomin22051966@postgrespro.ru", "phone": "+70436160095"}
0005433815413	67EF61	3901 008225	SERGEY SERGEEV	{"phone": "+70204820940"}
0005433815414	E15807	5701 568305	ANASTASIYA SOROKINA	{"email": "sorokina-anastasiya_07061975@postgrespro.ru", "phone": "+70372338910"}
0005433815415	E15807	5376 709099	ANDREY VOLKOV	{"phone": "+70144527277"}
0005433815416	5A1A89	7010 069753	LYUDMILA ORLOVA	{"email": "orlova_lyudmila.02101986@postgrespro.ru", "phone": "+70475637522"}
0005433815417	5A1A89	0076 231008	ELMIRA PAVLOVA	{"email": "e_pavlova-1965@postgrespro.ru", "phone": "+70777527450"}
0005433815418	3211CF	6322 600951	IRINA MELNIKOVA	{"phone": "+70653623961"}
0005433815419	3211CF	4564 669647	BORIS MIKHAYLOV	{"phone": "+70471972101"}
0005433815420	B74ECB	5652 591310	IGOR SMIRNOV	{"phone": "+70280405900"}
0005433815421	BA315C	4114 580601	ALEKSANDR SHEVCHENKO	{"phone": "+70462798130"}
0005433815422	111FFD	9453 769635	ALEKSEY FROLOV	{"email": "aleksey.frolov1973@postgrespro.ru", "phone": "+70329448937"}
0005433815423	111FFD	6183 205921	NATALYA POTAPOVA	{"email": "potapova-natalya041967@postgrespro.ru", "phone": "+70333870512"}
0005433815424	111FFD	3304 002212	EKATERINA VOROBEVA	{"phone": "+70058015892"}
0005433815425	B4678D	7476 162671	EKATERINA ZAYCEVA	{"email": "e.zayceva-12031972@postgrespro.ru", "phone": "+70032914023"}
0005433815426	B6C6EB	7719 468175	GALINA ORLOVA	{"email": "galina.orlova-1965@postgrespro.ru", "phone": "+70080639567"}
0005433815427	B6C6EB	3608 897686	ALEKSANDR SAVELEV	{"phone": "+70837232952"}
0005433815428	77AC7D	6223 697834	LYUDMILA GRISHINA	{"email": "l.grishina111972@postgrespro.ru", "phone": "+70299504677"}
0005433815429	A9C561	5692 659870	ELENA TIKHONOVA	{"phone": "+70112889652"}
0005433815430	A81D2C	7399 629125	VADIM DMITRIEV	{"email": "v_dmitriev.091972@postgrespro.ru", "phone": "+70569903834"}
0005433815431	CE9C51	3811 697280	VALENTINA FILATOVA	{"email": "valentina-filatova05011969@postgrespro.ru", "phone": "+70655189858"}
0005433815432	CE9C51	2413 105107	ALEKSANDR GAVRILOV	{"phone": "+70365250192"}
0005433815433	45B5F2	9585 099412	LIDIYA NAZAROVA	{"email": "nazarova.lidiya-061979@postgrespro.ru", "phone": "+70694074979"}
0005433815434	E55265	7120 975659	ALEKSEY SEMENOV	{"phone": "+70726934479"}
0005433815435	B4DA81	1664 736178	ZINAIDA DMITRIEVA	{"email": "zinaida_dmitrieva.09041977@postgrespro.ru", "phone": "+70326905079"}
0005433815436	B4DA81	4432 199531	MIKHAIL VOLKOV	{"email": "mikhail.volkov10051974@postgrespro.ru", "phone": "+70440386099"}
0005433815437	762DD6	2163 174921	ALEKSANDR ZAYCEV	{"email": "aleksandrzaycev021971@postgrespro.ru", "phone": "+70003025512"}
0005433815438	8570DC	7894 022311	GALINA SOROKINA	{"email": "g_sorokina031965@postgrespro.ru", "phone": "+70250795135"}
0005433815439	8570DC	5731 032363	VYACHESLAV DMITRIEV	{"email": "vdmitriev.051960@postgrespro.ru", "phone": "+70995124394"}
0005433815440	A55FDB	6850 018728	ZOYA IVANOVA	{"email": "z-ivanova041983@postgrespro.ru", "phone": "+70253203827"}
0005433815441	507551	9101 415244	LIDIYA PETROVA	{"email": "petrova-l-011982@postgrespro.ru", "phone": "+70456884753"}
0005433815442	507551	2180 340667	DMITRIY POPOV	{"email": "dmitriy-popov.29081977@postgrespro.ru", "phone": "+70658848328"}
0005433815443	160FC6	3554 909749	FARIT KUZNECOV	{"phone": "+70249296715"}
0005433815444	0586EA	3452 769758	SVETLANA KUZMINA	{"phone": "+70873764138"}
0005433815445	C4EC13	2006 191419	OLGA MIKHAYLOVA	{"phone": "+70173268900"}
0005433815446	5D4D02	5098 555239	MAKSIM YAKOVLEV	{"email": "maksimyakovlev05081962@postgrespro.ru", "phone": "+70856856164"}
0005433815447	5D4D02	4665 633103	OLESYA EFIMOVA	{"email": "efimovaolesya-1973@postgrespro.ru", "phone": "+70588858330"}
0005433815448	0F7B9B	8024 058441	TATYANA POLYAKOVA	{"phone": "+70547924444"}
0005433815449	77B554	7315 579254	TATYANA SOROKINA	{"email": "sorokina_t_061967@postgrespro.ru", "phone": "+70249338640"}
0005433815450	77B554	2644 764349	NADEZHDA KUZMINA	{"phone": "+70975623125"}
0005433815451	A825AC	6343 459607	VLADIMIR DMITRIEV	{"phone": "+70523554547"}
0005433815452	746991	7761 806675	ELIZAVETA NESTEROVA	{"email": "elizavetanesterova.16111962@postgrespro.ru", "phone": "+70095523364"}
0005433815453	3A96A8	4411 076175	DMITRIY SMIRNOV	{"email": "smirnovd_1976@postgrespro.ru", "phone": "+70681841461"}
0005433815455	C838F9	2912 749420	NIKOLAY SMIRNOV	{"phone": "+70072348331"}
0005433815456	6011E5	8707 630442	ROMAN IVANOV	{"email": "r-ivanov-1970@postgrespro.ru", "phone": "+70703547982"}
0005433815457	22CACA	2755 002756	VALERIY VASILEV	{"phone": "+70282257029"}
0005433815458	22CACA	7443 260310	ANVAR SOLOVEV	{"phone": "+70900014791"}
0005433815459	22CACA	7901 225431	VYACHESLAV DENISOV	{"phone": "+70127144295"}
0005433815460	B18FC7	3006 737138	ANATOLIY TIKHONOV	{"phone": "+70662757109"}
0005433815461	B18FC7	5767 222971	ALEKSANDRA CHERNOVA	{"phone": "+70471711653"}
0005433815462	E1AF9D	6189 947614	ALEKSANDR POPOV	{"email": "a-popov111965@postgrespro.ru", "phone": "+70150939484"}
0005433815463	74481F	8497 189114	ELIZAVETA ZAYCEVA	{"email": "zayceva.e.1978@postgrespro.ru", "phone": "+70616123683"}
0005433815464	425717	4282 389506	TAMARA KRASNOVA	{"phone": "+70275995716"}
0005433815465	26F9FD	0636 445023	VLADIMIR NAZAROV	{"email": "vladimirnazarov_1966@postgrespro.ru", "phone": "+70833512587"}
0005433815466	63B060	6999 013155	SERGEY ANTONOV	{"phone": "+70571809493"}
0005433815467	D8F5FC	9195 398246	PAVEL ZAYCEV	{"phone": "+70730185448"}
0005433815468	0507D4	2119 559900	NADEZHDA NIKITINA	{"phone": "+70336857740"}
0005433815469	0507D4	2640 057747	SERGEY BARANOV	{"phone": "+70354013733"}
0005433815470	0507D4	6658 298071	ANDREY STEPANOV	{"email": "stepanov.a_06091983@postgrespro.ru", "phone": "+70373122027"}
0005433815471	EABA94	7206 428629	SERGEY CHERNOV	{"email": "chernovsergey_1975@postgrespro.ru", "phone": "+70498910068"}
0005433815472	EABA94	6795 514679	YULIYA KISELEVA	{"email": "kiseleva_yuliya15081967@postgrespro.ru", "phone": "+70847648073"}
0005433815473	EABA94	6688 688458	GALINA VOLKOVA	{"email": "galina_volkova.1976@postgrespro.ru", "phone": "+70961076960"}
0005433815474	AE7D67	1805 399587	LYUBOV KAZAKOVA	{"email": "kazakova.l-17031977@postgrespro.ru", "phone": "+70722170849"}
0005433815475	AE7D67	5293 516180	VALENTINA GORBUNOVA	{"email": "gorbunova-valentina-14091970@postgrespro.ru", "phone": "+70847020490"}
0005433815476	8B4188	1406 024476	NATALYA POPOVA	{"email": "popovan.1964@postgrespro.ru", "phone": "+70845156105"}
0005433815477	5BE290	2588 650088	YURIY NIKOLAEV	{"email": "nikolaevyuriy10091982@postgrespro.ru", "phone": "+70259973142"}
0005433815478	BAF6E8	9430 121284	PAVEL KARPOV	{"phone": "+70852021130"}
0005433815479	B68863	8773 370541	OLEG OSIPOV	{"email": "oleg-osipov-21021975@postgrespro.ru", "phone": "+70628942907"}
0005433815480	B68863	3707 396335	MARINA FADEEVA	{"phone": "+70321583704"}
0005433815481	424877	1896 905417	EKATERINA PAVLOVA	{"phone": "+70492123843"}
0005433815482	424877	3785 984139	SERGEY SOLOVEV	{"email": "sergey.solovev.19091965@postgrespro.ru", "phone": "+70596278457"}
0005433815483	AA8345	1009 410716	MIKHAIL NIKITIN	{"phone": "+70192939434"}
0005433815484	AA8345	3020 847021	VLADIMIR BELOV	{"email": "vbelov.1968@postgrespro.ru", "phone": "+70804466832"}
0005433815485	E96EE8	8423 164911	NIKOLAY ANDREEV	{"phone": "+70759477136"}
0005433815486	356EE5	1797 651060	DMITRIY PETROV	{"email": "d-petrov02101973@postgrespro.ru", "phone": "+70800846209"}
0005433815487	A52A84	6004 797184	EVGENIY SEMENOV	{"phone": "+70634832689"}
0005433815488	3279A0	2705 368417	DANILA ORLOV	{"phone": "+70711717212"}
0005433815489	F62916	5232 677750	YULIYA NIKIFOROVA	{"email": "y.nikiforova-071971@postgrespro.ru", "phone": "+70006079108"}
0005433815490	97A934	3661 406228	SERGEY MEDVEDEV	{"phone": "+70493127056"}
0005433815491	1E8247	7370 320275	ALEKSEY SOKOLOV	{"phone": "+70861076210"}
0005433815492	C5F866	5662 100787	VERA EFREMOVA	{"phone": "+70591441931"}
0005433815493	C5F866	5401 742754	OKSANA KARPOVA	{"email": "o-karpova.21051966@postgrespro.ru", "phone": "+70377325828"}
0005433815494	16CA75	5655 037078	EVGENIY ABRAMOV	{"email": "abramov-e_031965@postgrespro.ru", "phone": "+70036418611"}
0005433815495	EE1035	9205 375676	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev-02041970@postgrespro.ru", "phone": "+70234699208"}
0005433815496	6EF5EC	2584 716400	TAKHIR FEDOROV	{"phone": "+70150344044"}
0005433815497	6D7B44	8048 443674	SERGEY KUDRYASHOV	{"email": "s.kudryashov-13081971@postgrespro.ru", "phone": "+70935367984"}
0005433815498	FDEC17	1530 970701	VASILIY KARPOV	{"phone": "+70085702894"}
0005433815499	395C6F	2640 354969	DAVID VASILEV	{"phone": "+70685241222"}
0005433815500	F5967C	4185 298452	EDUARD ANDREEV	{"email": "eduardandreev.31081975@postgrespro.ru", "phone": "+70360553183"}
0005433815501	F5967C	3480 665851	VIKTORIYA KARPOVA	{"phone": "+70059753252"}
0005433815502	C89E64	7905 733406	SERGEY VOLKOV	{"phone": "+70997815049"}
0005433815503	5713A0	7958 999298	NATALYA NOVIKOVA	{"phone": "+70087862885"}
0005433815504	5713A0	8123 551180	AMIR FROLOV	{"phone": "+70200234142"}
0005433815505	784F83	9809 361992	TATYANA RODIONOVA	{"email": "rodionovat.111973@postgrespro.ru", "phone": "+70217709078"}
0005433815506	E49FB6	8855 911392	TIMOFEY NIKITIN	{"phone": "+70370911952"}
0005433815507	E49FB6	9199 122576	MARINA STEPANOVA	{"phone": "+70685866374"}
0005433815508	C4BAF2	5070 375883	POLINA BORISOVA	{"email": "borisova_polina.071968@postgrespro.ru", "phone": "+70952813807"}
0005433815509	79E3A7	6876 966933	LEONID SERGEEV	{"email": "leonidsergeev.111975@postgrespro.ru", "phone": "+70836014282"}
0005433815510	E7D712	8725 326266	ANASTASIYA SOROKINA	{"email": "sorokina.a1973@postgrespro.ru", "phone": "+70813717962"}
0005433815511	064A76	4052 930061	NIKOLAY EGOROV	{"phone": "+70245142548"}
0005433815512	57CBA9	0034 024919	OLGA MELNIKOVA	{"email": "olga.melnikova-18051960@postgrespro.ru", "phone": "+70909224717"}
0005433815513	3596BA	6055 577222	VLADIMIR PETROV	{"email": "v_petrov-11021962@postgrespro.ru", "phone": "+70907510333"}
0005433815514	7E30C9	9113 599279	LYUDMILA IVANOVA	{"phone": "+70594708776"}
0005433815515	646B6F	0419 404797	TATYANA SERGEEVA	{"email": "tatyanasergeeva_31081971@postgrespro.ru", "phone": "+70514213416"}
0005433815516	2C6FBA	3333 897065	MIKHAIL SEMENOV	{"phone": "+70904924006"}
0005433815517	2C6FBA	1503 442881	ELENA MIKHAYLOVA	{"email": "mikhaylova_e.111985@postgrespro.ru", "phone": "+70025424834"}
0005433815518	FE130D	9187 126280	ELZA FILIPPOVA	{"email": "elza-filippova-041983@postgrespro.ru", "phone": "+70357666394"}
0005433815519	FE130D	6107 354166	MIKHAIL KARPOV	{"email": "mikhailkarpov_13071977@postgrespro.ru", "phone": "+70204611080"}
0005433815520	D93624	6688 214214	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr.29031969@postgrespro.ru", "phone": "+70539093596"}
0005433815521	1F2D8C	5140 971123	GEORGIY KOROLEV	{"email": "korolev_georgiy-051978@postgrespro.ru", "phone": "+70066858317"}
0005433815522	72810B	6277 103571	KIRILL VOLKOV	{"email": "kvolkov_041964@postgrespro.ru", "phone": "+70436743659"}
0005433815523	72810B	4854 416795	VLADIMIR SIDOROV	{"email": "v-sidorov.041981@postgrespro.ru", "phone": "+70532542451"}
0005433815524	326697	7454 666700	PETR KARPOV	{"phone": "+70893819949"}
0005433815525	CECC6D	0336 244174	MARINA DENISOVA	{"email": "m-denisova.021969@postgrespro.ru", "phone": "+70825811694"}
0005433815526	CECC6D	9103 958172	LIDIYA KOMAROVA	{"email": "lidiya_komarova10101964@postgrespro.ru", "phone": "+70573879701"}
0005433815527	EF3AB5	3818 718048	VYACHESLAV VLASOV	{"email": "vyacheslav_vlasov_1963@postgrespro.ru", "phone": "+70453358001"}
0005433815536	A58ADF	3497 224454	ALENA EGOROVA	{"email": "egorova_a.051973@postgrespro.ru", "phone": "+70730119697"}
0005433815537	2A29D4	5198 004760	ANTONINA EFREMOVA	{"email": "a.efremova041971@postgrespro.ru", "phone": "+70337852060"}
0005433815538	B53C6D	3448 838993	VALENTINA POLYAKOVA	{"email": "polyakovav_031969@postgrespro.ru", "phone": "+70200806352"}
0005433815539	DC5616	1307 629729	NADEZHDA VLASOVA	{"phone": "+70255436881"}
0005433815540	DC5616	8040 009867	STEPAN KARPOV	{"phone": "+70882533815"}
0005433815541	DC5616	8411 922115	OLGA RODIONOVA	{"email": "olgarodionova_1970@postgrespro.ru", "phone": "+70497104272"}
0005433815542	52CC29	0870 615646	NIKOLAY POPOV	{"email": "popov_n-06021975@postgrespro.ru", "phone": "+70116770642"}
0005433815543	471408	4305 957425	VLADIMIR VOLKOV	{"phone": "+70112430847"}
0005433815544	471408	3515 933117	ALEKSEY KUZMIN	{"phone": "+70022744952"}
0005433815545	471408	1447 023200	VALENTINA NESTEROVA	{"email": "valentina_nesterova.081969@postgrespro.ru", "phone": "+70507474336"}
0005433815546	183F6E	2354 389653	OLGA MAKAROVA	{"phone": "+70450956620"}
0005433815547	EE5579	7350 017764	RUMIYA SOROKINA	{"phone": "+70997728296"}
0005433815548	EE5579	5535 835210	SERGEY MELNIKOV	{"email": "smelnikov.26081983@postgrespro.ru", "phone": "+70635761194"}
0005433815549	38B136	5905 452228	OKSANA PAVLOVA	{"email": "oksana-pavlova.1970@postgrespro.ru", "phone": "+70430169717"}
0005433815550	38B136	4046 540119	VLADIMIR TIMOFEEV	{"email": "v_timofeev-1969@postgrespro.ru", "phone": "+70827545686"}
0005433815551	29B9A7	1551 961062	ILYA MOROZOV	{"email": "morozovi.13041965@postgrespro.ru", "phone": "+70977871645"}
0005433815552	40E603	4699 787474	VIKTORIYA KUZMINA	{"email": "kuzmina-v-17111975@postgrespro.ru", "phone": "+70380245970"}
0005433815553	40E603	5311 065987	GALINA STEPANOVA	{"phone": "+70191358608"}
0005433815554	F4DB32	5121 092132	VLADIMIR SOKOLOV	{"phone": "+70621437386"}
0005433815555	AECB0A	6401 959244	DANILA POPOV	{"phone": "+70658444260"}
0005433815556	EF84B6	3134 997334	BULAT GAVRILOV	{"email": "gavrilov_bulat22061975@postgrespro.ru", "phone": "+70065431392"}
0005433815557	F9FDD1	8103 949336	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir_1969@postgrespro.ru", "phone": "+70403805798"}
0005433815558	2C40CC	2605 175092	EVGENIY VOLKOV	{"email": "volkove.111974@postgrespro.ru", "phone": "+70866022214"}
0005433815559	2C40CC	9465 938747	IRINA MELNIKOVA	{"email": "melnikova-irina_1982@postgrespro.ru", "phone": "+70120491679"}
0005433815560	D5D6C6	8185 081996	MIKHAIL STEPANOV	{"email": "stepanov_mikhail_02021977@postgrespro.ru", "phone": "+70487018553"}
0005433815561	D5D6C6	9699 311585	KSENIYA KALININA	{"email": "k.kalinina_1976@postgrespro.ru", "phone": "+70311286164"}
0005433815562	4538D6	5140 326500	YURIY PAVLOV	{"email": "pavlov-yuriy.121967@postgrespro.ru", "phone": "+70509636814"}
0005433815563	4661CF	1910 269757	ANNA ARKHIPOVA	{"email": "arkhipova_a.1967@postgrespro.ru", "phone": "+70298239123"}
0005433815564	38F4D6	0399 242224	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov09021977@postgrespro.ru", "phone": "+70725054456"}
0005433815565	D80CA6	9535 434158	ELENA NIKITINA	{"email": "elena_nikitina-17031974@postgrespro.ru", "phone": "+70290679310"}
0005433815566	D80CA6	2833 952697	YURIY SOLOVEV	{"email": "solovevy-1972@postgrespro.ru", "phone": "+70125049813"}
0005433815567	F98F0E	6463 838946	VALENTINA ZAYCEVA	{"email": "zayceva.valentina_26091964@postgrespro.ru", "phone": "+70880449744"}
0005433815574	206EE9	4036 522944	GENNADIY ISAEV	{"email": "isaev.gennadiy-121975@postgrespro.ru", "phone": "+70428650646"}
0005433815575	C350D7	2923 871004	PETR IVANOV	{"phone": "+70208602893"}
0005433815576	23D6F9	1913 956982	SVETLANA POPOVA	{"phone": "+70449982843"}
0005433815577	23D6F9	4762 249845	VALENTINA PETROVA	{"email": "valentina_petrova_011981@postgrespro.ru", "phone": "+70895334688"}
0005433815578	B26329	4282 304518	SERGEY GAVRILOV	{"email": "gavrilov_s21041980@postgrespro.ru", "phone": "+70150482815"}
0005433815579	E23A53	1930 472238	NELLI SERGEEVA	{"phone": "+70999304506"}
0005433815580	E23A53	1479 923781	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila.031961@postgrespro.ru", "phone": "+70878143862"}
0005433815581	86F31B	9836 321262	GALIYA IVANOVA	{"email": "ivanova.galiya-21051978@postgrespro.ru", "phone": "+70396943218"}
0005433815582	BB2E26	0575 802833	YURIY VOROBEV	{"phone": "+70653655051"}
0005433815583	2C648F	3530 721276	ALEKSANDR NAZAROV	{"phone": "+70360292704"}
0005433815584	9319EF	9349 524590	IGOR DENISOV	{"email": "i-denisov.17051968@postgrespro.ru", "phone": "+70647802027"}
0005433815585	C520F6	5381 049877	ARTEM GORBUNOV	{"phone": "+70095383713"}
0005433817404	7C16F5	5729 729046	ILYA KUZMIN	{"phone": "+70467843757"}
0005433817405	5E8A27	3789 689925	VYACHESLAV BORISOV	{"email": "vborisov051971@postgrespro.ru", "phone": "+70091052496"}
0005433817406	02F1EC	4155 916849	EKATERINA IVANOVA	{"phone": "+70930479144"}
0005433817407	02F1EC	5231 041534	IRINA POTAPOVA	{"phone": "+70188541911"}
0005433817408	773964	3769 243724	LYUDMILA EGOROVA	{"phone": "+70705249639"}
0005433817409	773964	5896 131171	ALEKSEY ALEKSEEV	{"phone": "+70716386871"}
0005433817410	F8CF27	7753 580155	SERGEY KUZNECOV	{"phone": "+70050525109"}
0005433817411	F8CF27	1375 311712	EVDOKIYA MAKAROVA	{"phone": "+70854436504"}
0005433817412	0550F4	8878 584798	SVETLANA SMIRNOVA	{"phone": "+70023064810"}
0005433817413	0550F4	7540 927750	MATVEY ZAKHAROV	{"phone": "+70161576035"}
0005433817414	872D56	4180 592524	OLGA ZOTOVA	{"email": "olga.zotova.13121963@postgrespro.ru", "phone": "+70909750198"}
0005433817415	F82618	2800 707280	IGOR GRIGOREV	{"email": "grigorevi031970@postgrespro.ru", "phone": "+70123275704"}
0005433817416	F82618	6142 577793	ANASTASIYA MIKHAYLOVA	{"phone": "+70153048218"}
0005433817417	F82618	3565 489962	DMITRIY GAVRILOV	{"email": "gavrilov-d041965@postgrespro.ru", "phone": "+70898047745"}
0005433817418	1E9D98	6322 044052	YULIYA EGOROVA	{"phone": "+70993304748"}
0005433817419	103013	8185 814545	ELENA VOLKOVA	{"email": "elena.volkova.1970@postgrespro.ru", "phone": "+70936502358"}
0005433817420	103013	8559 323900	NIKOLAY PETROV	{"phone": "+70134965191"}
0005433817421	103013	5624 984411	LIDIYA KOROLEVA	{"email": "lidiya_koroleva-1969@postgrespro.ru", "phone": "+70945902278"}
0005433817422	9F6942	6776 448706	EKATERINA STEPANOVA	{"phone": "+70637018930"}
0005433817423	DA63BA	2191 955906	IVAN POPOV	{"email": "ivanpopov-1960@postgrespro.ru", "phone": "+70741036458"}
0005433817424	DA63BA	8806 979954	DMITRIY STEPANOV	{"email": "stepanov.dmitriy_1979@postgrespro.ru", "phone": "+70530227956"}
0005433817425	E2A9D0	3023 770741	IVAN SAVELEV	{"phone": "+70551724599"}
0005433817426	E2A9D0	9730 726390	VALENTINA MIRONOVA	{"phone": "+70912258410"}
0005433817427	319208	8635 599512	VIKTOR GAVRILOV	{"phone": "+70380430087"}
0005433817428	959955	7815 545651	MARIYA ALEKSEEVA	{"email": "alekseevam.1966@postgrespro.ru", "phone": "+70241285539"}
0005433817429	BBE47E	8301 100008	GEORGIY ILIN	{"email": "georgiyilin.07041969@postgrespro.ru", "phone": "+70859377088"}
0005433817430	BBE47E	9698 498348	SVETLANA GORBUNOVA	{"email": "svetlana-gorbunova.121967@postgrespro.ru", "phone": "+70594853844"}
0005433817431	4183D5	4929 352613	NATALYA SIDOROVA	{"phone": "+70526413187"}
0005433817432	4183D5	5430 068923	ALEKSEY MIRONOV	{"email": "a.mironov-1971@postgrespro.ru", "phone": "+70598237516"}
0005433817433	C1D21B	9060 588226	VLADIMIR YAKOVLEV	{"phone": "+70399445205"}
0005433817434	C1D21B	6890 819269	TATYANA DMITRIEVA	{"phone": "+70117655714"}
0005433817435	2B98A2	1545 858887	MARIYA DAVYDOVA	{"phone": "+70845614231"}
0005433817436	4F50AA	9571 006483	VITALIY NAUMOV	{"phone": "+70106289482"}
0005433817437	4F50AA	1876 480151	SOFIYA GORBUNOVA	{"phone": "+70791763088"}
0005433817438	87DD90	7055 185454	ELENA ZAKHAROVA	{"email": "zakharovae.041971@postgrespro.ru", "phone": "+70680544832"}
0005433817439	87DD90	6933 857843	MIKHAIL FROLOV	{"phone": "+70437828098"}
0005433817440	97713E	7284 711003	OLGA FROLOVA	{"phone": "+70582785524"}
0005433817441	7AC4A8	4445 217196	TAMARA ZAYCEVA	{"phone": "+70602534133"}
0005433817442	43007C	6928 506181	YULIYA PETROVA	{"phone": "+70818098482"}
0005433817443	4110EE	5197 169412	IGOR VOROBEV	{"email": "vorobev.i_1977@postgrespro.ru", "phone": "+70449061411"}
0005433817444	95BE08	2116 698792	ALIYA SMIRNOVA	{"email": "a.smirnova-051972@postgrespro.ru", "phone": "+70514492417"}
0005433817445	EDDB8D	3080 154524	VLADA KULIKOVA	{"email": "kulikovav-011973@postgrespro.ru", "phone": "+70634549468"}
0005433817446	7284CA	0314 291402	IRINA ZAYCEVA	{"phone": "+70071903032"}
0005433817447	7284CA	8027 710495	ANASTASIYA KOZLOVA	{"phone": "+70308120839"}
0005433817448	251867	8840 237862	SERGEY KUZNECOV	{"email": "sergey_kuznecov_1984@postgrespro.ru", "phone": "+70452509635"}
0005433817449	320BF8	3792 572721	ANATOLIY PETROV	{"email": "a_petrov-1968@postgrespro.ru", "phone": "+70347980613"}
0005433817450	F59371	3613 438060	FEDOR ZHUKOV	{"phone": "+70555309910"}
0005433817451	F59371	2301 794234	ALEKSANDR ZAKHAROV	{"phone": "+70909029287"}
0005433817452	E60191	7488 540488	SVETLANA ISAEVA	{"email": "isaeva.s.1985@postgrespro.ru", "phone": "+70312940676"}
0005433817453	E60191	5267 329075	LYUBOV NOVIKOVA	{"email": "novikova-lyubov_111965@postgrespro.ru", "phone": "+70421761572"}
0005433817454	E60191	6884 298874	TATYANA NAUMOVA	{"email": "tatyana_naumova.19021974@postgrespro.ru", "phone": "+70397014900"}
0005433817455	C43277	8900 562060	NINA KUZMINA	{"email": "n-kuzmina.01041965@postgrespro.ru", "phone": "+70038910207"}
0005433817456	5ACFD9	0644 049807	VERA KOROLEVA	{"phone": "+70366903478"}
0005433817457	5ACFD9	1113 811827	YURIY ANDREEV	{"email": "andreev.yuriy-051973@postgrespro.ru", "phone": "+70404850083"}
0005433817458	4FB342	3497 515981	NIKOLAY SCHERBAKOV	{"phone": "+70158831242"}
0005433817459	5248E5	1762 132735	SVETLANA VOLKOVA	{"phone": "+70644243343"}
0005433817460	5248E5	9845 087994	OLGA POPOVA	{"email": "opopova.1972@postgrespro.ru", "phone": "+70072444056"}
0005433817461	E8593E	3158 252246	MARINA VLASOVA	{"email": "marina.vlasova-18121969@postgrespro.ru", "phone": "+70086282742"}
0005433817462	FFE581	3356 023371	GALINA BELYAEVA	{"email": "galinabelyaeva_081973@postgrespro.ru", "phone": "+70037091107"}
0005433817463	FDC839	1305 611849	OLESYA ANTONOVA	{"email": "olesyaantonova-031959@postgrespro.ru", "phone": "+70291911102"}
0005433817464	8CBEB7	7920 654613	EKATERINA FADEEVA	{"email": "fadeeva_ekaterina.051980@postgrespro.ru", "phone": "+70315302174"}
0005433817465	3A3762	1304 406777	ILYA KUZNECOV	{"email": "i.kuznecov29101965@postgrespro.ru", "phone": "+70274882027"}
0005433817466	3A3762	3147 352576	ZUKHRA KOZLOVA	{"phone": "+70563217613"}
0005433817467	3D3B6B	6632 926355	MARGARITA OSIPOVA	{"phone": "+70988829990"}
0005433817468	146655	5477 442476	DENIS FROLOV	{"email": "frolov-d.23111973@postgrespro.ru", "phone": "+70410550924"}
0005433817469	146655	0968 933546	VADIM PAVLOV	{"email": "vadimpavlov051982@postgrespro.ru", "phone": "+70776345982"}
0005433817470	9F4CB8	6889 082132	MAKSIM FROLOV	{"email": "frolov_maksim_1962@postgrespro.ru", "phone": "+70537669462"}
0005433817471	A5A34B	2731 394395	NADEZHDA FEDOROVA	{"email": "nfedorova041975@postgrespro.ru", "phone": "+70292179959"}
0005433817472	A5A34B	4178 362312	LYUDMILA PETROVA	{"email": "petrova-lyudmila051974@postgrespro.ru", "phone": "+70437575318"}
0005433817473	E4CEE7	2060 054002	ANTON FOMIN	{"phone": "+70093096585"}
0005433817474	D15EF4	0325 480572	TAMARA EGOROVA	{"email": "tamara-egorova-111972@postgrespro.ru", "phone": "+70120599690"}
0005433817475	8FA69D	3128 290248	VALENTINA KULIKOVA	{"email": "kulikova-v_1979@postgrespro.ru", "phone": "+70596897133"}
0005433817476	A0E8B7	8965 538727	SERGEY ZAKHAROV	{"phone": "+70509634896"}
0005433817477	A0E8B7	9378 838983	OLGA NIKOLAEVA	{"email": "o_nikolaeva-041977@postgrespro.ru", "phone": "+70641228409"}
0005433817478	F7101D	4156 223439	LYUDMILA PAVLOVA	{"phone": "+70541067075"}
0005433817479	5BD47B	5237 556908	LYUBOV SERGEEVA	{"phone": "+70737181119"}
0005433817480	B5AFCD	4769 356986	ANNA EGOROVA	{"phone": "+70630811317"}
0005433817481	8B9F59	2247 111990	EKATERINA TROFIMOVA	{"email": "ekaterina-trofimova_09031963@postgrespro.ru", "phone": "+70169002119"}
0005433817482	6E85BB	2965 725175	AMINA STEPANOVA	{"phone": "+70648420859"}
0005433817483	3B139F	4401 330346	RUSLAN GUSEV	{"phone": "+70431159329"}
0005433817484	3B139F	7389 478674	LYUDMILA KOZLOVA	{"phone": "+70519507679"}
0005433817485	B5DFE2	7117 170267	ZINAIDA IVANOVA	{"phone": "+70854622014"}
0005433817486	4291BF	1951 359208	MAKSIM STEPANOV	{"email": "stepanovm.14011964@postgrespro.ru", "phone": "+70876869952"}
0005433817487	BE5B84	8353 897369	NADEZHDA IVANOVA	{"phone": "+70434289385"}
0005433817488	944511	1098 903083	ANDREY POPOV	{"phone": "+70542769018"}
0005433817489	944511	0286 711982	DMITRIY KUZNECOV	{"email": "d_kuznecov1986@postgrespro.ru", "phone": "+70733651350"}
0005433817490	F3628A	3809 325991	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov-1977@postgrespro.ru", "phone": "+70652238873"}
0005433817491	70A3BA	2494 776853	VALENTIN PETROV	{"phone": "+70748452858"}
0005433817492	48B22C	1884 321735	TATYANA NAUMOVA	{"email": "naumova-t1975@postgrespro.ru", "phone": "+70789211800"}
0005433817493	6A3CC0	6646 768439	SERAFIMA KONOVALOVA	{"email": "konovalova-s1966@postgrespro.ru", "phone": "+70943794871"}
0005433817494	86B203	5576 877539	KONSTANTIN FROLOV	{"phone": "+70689283465"}
0005433817495	C7A5AD	8284 712593	MARIYA PAVLOVA	{"email": "m-pavlova-11071973@postgrespro.ru", "phone": "+70535237906"}
0005433817496	688C4E	9026 781592	VLADIMIR AFANASEV	{"email": "afanasev-vladimir06071981@postgrespro.ru", "phone": "+70246441685"}
0005433817497	688C4E	6644 206004	ILYA SHEVCHENKO	{"phone": "+70377330246"}
0005433817498	2D3FD1	7088 484018	ALENA VLASOVA	{"email": "a_vlasova24051970@postgrespro.ru", "phone": "+70535721764"}
0005433817499	235E1C	0238 848410	YURIY MELNIKOV	{"phone": "+70324403507"}
0005433817500	235E1C	8462 922741	OLGA KRASNOVA	{"phone": "+70810470275"}
0005433817501	235E1C	6683 066802	SERGEY KUZNECOV	{"email": "sergey-kuznecov-06041974@postgrespro.ru", "phone": "+70097713072"}
0005433817502	9FE0C7	5499 746061	YURIY ILIN	{"email": "ilin-y_071971@postgrespro.ru", "phone": "+70376301285"}
0005433817503	B2CB67	5751 556716	YURIY EGOROV	{"email": "egorovyuriy121974@postgrespro.ru", "phone": "+70885714341"}
0005433817504	7F2772	6898 231147	EKATERINA MASLOVA	{"phone": "+70688775153"}
0005433817505	E26A00	0030 613795	IRINA LOGINOVA	{"email": "loginova.irina.111974@postgrespro.ru", "phone": "+70663593160"}
0005433817506	2A75FC	3066 028558	VIKTOR VOLKOV	{"email": "viktorvolkov-041980@postgrespro.ru", "phone": "+70672689405"}
0005433817507	498EDD	2192 198480	NINA PAVLOVA	{"phone": "+70191259616"}
0005433817508	07F13A	7620 278814	ALEKSANDR ORLOV	{"email": "orlov-aleksandr20041969@postgrespro.ru", "phone": "+70006604907"}
0005433817509	B7D5ED	6739 989108	IVAN BELOV	{"email": "belov-ivan071965@postgrespro.ru", "phone": "+70795507354"}
0005433817510	3D0A00	9781 957558	ELENA BORISOVA	{"phone": "+70996860364"}
0005433817511	23BDBD	2754 013346	ALEKSEY SMIRNOV	{"email": "alekseysmirnov12121967@postgrespro.ru", "phone": "+70416924241"}
0005433817512	23BDBD	0075 499556	YURIY KULIKOV	{"phone": "+70163242002"}
0005433817513	D187EA	7385 387834	ALEKSEY NAZAROV	{"email": "anazarov.1961@postgrespro.ru", "phone": "+70417123765"}
0005433817514	D35493	9604 203987	ALEKSANDR ZAKHAROV	{"phone": "+70418725217"}
0005433817515	C7DC9C	3631 870009	PAVEL MAKAROV	{"phone": "+70939930054"}
0005433817516	ACB222	4746 955988	LYUDMILA STEPANOVA	{"phone": "+70829685633"}
0005433817517	A7DAC2	9887 877606	ELENA POLYAKOVA	{"phone": "+70913337186"}
0005433817518	8572FE	4352 147657	ALBERT DENISOV	{"email": "albert-denisov-1983@postgrespro.ru", "phone": "+70789755486"}
0005433817519	079F61	1447 814918	YURIY GRIGOREV	{"phone": "+70486052291"}
0005433817520	611006	0484 961475	VLADISLAV ABRAMOV	{"phone": "+70986207407"}
0005433817521	88916C	1381 998459	NIKOLAY BORISOV	{"email": "borisov.n-15051965@postgrespro.ru", "phone": "+70720039715"}
0005433817522	6C7AC0	8509 475026	ALEKSANDR SMIRNOV	{"email": "smirnov_a_17081977@postgrespro.ru", "phone": "+70219251759"}
0005433817523	05AC46	3740 674271	DMITRIY MIRONOV	{"email": "mironov-dmitriy08081963@postgrespro.ru", "phone": "+70533416975"}
0005433817524	05AC46	7338 630557	NATALYA SEMENOVA	{"phone": "+70770155313"}
0005433817525	CB01C8	3268 607734	ANNA FEDOROVA	{"phone": "+70731971374"}
0005433817526	B54DA6	7700 394557	ALBINA NIKOLAEVA	{"phone": "+70497358098"}
0005433817527	DD5ED1	1605 552613	MARINA NAUMOVA	{"phone": "+70811140138"}
0005433817528	F722C2	9122 803500	NIKOLAY VOLKOV	{"email": "volkov-n-101971@postgrespro.ru", "phone": "+70473988385"}
0005433817529	B3978D	3000 246589	YURIY IVANOV	{"phone": "+70104977243"}
0005433817530	B3978D	7234 781751	ANTON SCHERBAKOV	{"email": "anton-scherbakov1971@postgrespro.ru", "phone": "+70060054717"}
0005433817531	D1B732	9862 418187	LYUBOV RODIONOVA	{"phone": "+70656645848"}
0005433817532	4D6270	8248 231758	ALEKSANDR BORISOV	{"phone": "+70178355328"}
0005433817533	75F991	3841 485598	YULIYA SOKOLOVA	{"email": "sokolova_yuliya.18061969@postgrespro.ru", "phone": "+70207943366"}
0005433817534	6127A8	1747 589894	NIKOLAY KISELEV	{"email": "kiselev_n_1969@postgrespro.ru", "phone": "+70924465738"}
0005433817535	6127A8	5764 853770	PETR ORLOV	{"email": "orlovpetr.10051964@postgrespro.ru", "phone": "+70765397780"}
0005433817536	5405F1	2147 503441	NINA NOVIKOVA	{"phone": "+70886288927"}
0005433817537	0C6457	0467 122329	SERGEY KOROLEV	{"email": "s_korolev-1973@postgrespro.ru", "phone": "+70144320354"}
0005433817538	AD121C	7544 534216	ALLA RYABOVA	{"email": "aryabova.011980@postgrespro.ru", "phone": "+70093421747"}
0005433817539	E416E5	5301 485369	GALINA AKIMOVA	{"phone": "+70437639852"}
0005433817540	9DD8B9	7502 414302	ANNA SERGEEVA	{"email": "sergeeva-a.031963@postgrespro.ru", "phone": "+70368629121"}
0005433817541	73FBE3	5480 758391	LYUBOV ZOTOVA	{"email": "lyubovzotova101973@postgrespro.ru", "phone": "+70994638068"}
0005433817542	73FBE3	8535 937522	NATALYA ANDREEVA	{"phone": "+70767673190"}
0005433817543	3113EB	9935 116637	ZHANNA NOVIKOVA	{"email": "novikova_zhanna1956@postgrespro.ru", "phone": "+70004348268"}
0005433817544	C4971F	9306 702467	DARYA POPOVA	{"email": "darya-popova091970@postgrespro.ru", "phone": "+70341984300"}
0005433817545	6BA323	3323 208205	ANNA LEBEDEVA	{"email": "lebedeva.a-1959@postgrespro.ru", "phone": "+70775157307"}
0005433817546	6BA323	5296 571455	IRINA ZAKHAROVA	{"email": "zakharovairina_041971@postgrespro.ru", "phone": "+70106863623"}
0005433817547	046391	6940 885545	ELENA DAVYDOVA	{"phone": "+70912504577"}
0005433817548	D8214A	2043 390285	IGOR MAKSIMOV	{"email": "maksimov.i_1971@postgrespro.ru", "phone": "+70998005552"}
0005433817549	AF3C5D	7164 313447	LILIYA EFREMOVA	{"phone": "+70918229803"}
0005433817550	AF3C5D	4213 181801	ALEKSANDR ZHUKOV	{"phone": "+70239862319"}
0005433817551	EF2CBC	0551 754179	ELENA MELNIKOVA	{"phone": "+70589651318"}
0005433817552	33C0E9	3247 909711	NATALIYA ANTONOVA	{"phone": "+70190760093"}
0005433817553	33C0E9	9945 148175	RINAT NAUMOV	{"email": "naumovrinat.061970@postgrespro.ru", "phone": "+70722963882"}
0005433817554	85D470	1253 475519	VASILIY NIKOLAEV	{"email": "v_nikolaev.031977@postgrespro.ru", "phone": "+70293893292"}
0005433817555	DC3AB9	3715 693405	DMITRIY ALEKSANDROV	{"email": "aleksandrov-d.111971@postgrespro.ru", "phone": "+70693562652"}
0005433817556	DC3AB9	3808 255476	ELENA IVANOVA	{"email": "ivanovae021973@postgrespro.ru", "phone": "+70132075111"}
0005433817557	B3C9C8	5538 298988	DMITRIY SAVELEV	{"phone": "+70923197026"}
0005433817558	361170	7424 172868	VALERIY KOZLOV	{"phone": "+70917136600"}
0005433817559	361170	7424 299743	VITALIY PETROV	{"email": "v.petrov_041986@postgrespro.ru", "phone": "+70677941759"}
0005433817560	9EDF97	1300 500305	RAVIL FEDOROV	{"phone": "+70138264589"}
0005433817561	F2B7C7	1407 862277	ARTEM POPOV	{"email": "a-popov_19011973@postgrespro.ru", "phone": "+70979889223"}
0005433817562	F2B7C7	1098 129505	ANTONINA OVCHINNIKOVA	{"phone": "+70368574587"}
0005433817563	AACCB1	0112 383697	SERGEY SEMENOV	{"phone": "+70467074777"}
0005433817564	AACCB1	9284 097469	MARIYA TROFIMOVA	{"phone": "+70825721450"}
0005433817565	AACCB1	8314 132810	NINA BORISOVA	{"email": "borisovan.24101969@postgrespro.ru", "phone": "+70235869927"}
0005433817566	8AA548	9533 802211	PAVEL TARASOV	{"phone": "+70871035975"}
0005433817567	0E90B8	2671 075481	YURIY SMIRNOV	{"phone": "+70247273465"}
0005433817568	8E5DC6	9225 745631	VLADIMIR SOLOVEV	{"email": "v.solovev_1972@postgrespro.ru", "phone": "+70036643613"}
0005433817569	E42BF8	4789 935546	GALINA ISAEVA	{"phone": "+70397279960"}
0005433817570	1F5AC6	4301 522801	IVAN KONOVALOV	{"email": "ivan-konovalov081981@postgrespro.ru", "phone": "+70800141734"}
0005433817571	1F5AC6	1972 396953	OKSANA FROLOVA	{"email": "o_frolova-1981@postgrespro.ru", "phone": "+70208980680"}
0005433817572	0A28AC	5517 590725	ANATOLIY ALEKSEEV	{"phone": "+70162139916"}
0005433817573	2D51DC	5835 721666	NATALYA FILIPPOVA	{"phone": "+70607443291"}
0005433817574	69A29E	0941 041051	RUSLAN FROLOV	{"email": "r.frolov-11011983@postgrespro.ru", "phone": "+70928396312"}
0005433817575	21AD68	3569 002112	LYUDMILA SMIRNOVA	{"email": "lyudmilasmirnova-25121972@postgrespro.ru", "phone": "+70250204499"}
0005433817576	538109	2810 980367	YULIYA MAKSIMOVA	{"email": "y.maksimova.05051971@postgrespro.ru", "phone": "+70883229946"}
0005433817577	538109	0096 757404	EVGENIY IVANOV	{"email": "ivanove_19011980@postgrespro.ru", "phone": "+70407993148"}
0005433845663	9FC8B8	5632 699414	IRINA ANDREEVA	{"phone": "+70409199915"}
0005433845664	6E5D51	9276 559858	VLADIMIR IVANOV	{"phone": "+70663078777"}
0005433845665	6F153C	7404 657716	ELIZAVETA YAKOVLEVA	{"email": "yakovleva.e1975@postgrespro.ru", "phone": "+70278692502"}
0005433845666	6F153C	1224 713948	ELENA VOROBEVA	{"email": "vorobeva-elena16121962@postgrespro.ru", "phone": "+70745266144"}
0005433845667	9D7514	7074 523582	PAVEL MOISEEV	{"phone": "+70380307147"}
0005433845668	DB0A94	8933 055744	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail041967@postgrespro.ru", "phone": "+70702183613"}
0005433845669	DB0A94	9822 019645	MARIYA MOISEEVA	{"phone": "+70503743785"}
0005433845670	8CCDCF	2613 106977	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov28091975@postgrespro.ru", "phone": "+70581110420"}
0005433845671	8CCDCF	7239 339713	ANDREY PETROV	{"email": "petrovandrey-22031979@postgrespro.ru", "phone": "+70184205720"}
0005433845672	8CCDCF	4544 350766	ILYA TIKHONOV	{"phone": "+70794589384"}
0005433845673	8CCDCF	6016 379456	KONSTANTIN TIMOFEEV	{"phone": "+70488152629"}
0005433845674	6F0577	5119 889359	KSENIYA ILINA	{"email": "k-ilina081965@postgrespro.ru", "phone": "+70940437578"}
0005433845675	820EFF	4882 876964	VLADIMIR TIKHONOV	{"phone": "+70847421436"}
0005433845676	005C0B	5485 744733	VYACHESLAV SOROKIN	{"email": "sorokinvyacheslav.051974@postgrespro.ru", "phone": "+70716435718"}
0005433845677	005C0B	4065 817047	ANNA SERGEEVA	{"phone": "+70472372032"}
0005433845678	005C0B	6968 556049	MIKHAIL IVANOV	{"phone": "+70919370328"}
0005433845679	79A9DB	4319 769022	ALINA SCHERBAKOVA	{"email": "scherbakova.a-051964@postgrespro.ru", "phone": "+70987111214"}
0005433845680	79A9DB	0941 698682	VALENTINA SERGEEVA	{"email": "valentinasergeeva30061969@postgrespro.ru", "phone": "+70713713058"}
0005433845681	79A9DB	0265 924444	NIKOLAY POPOV	{"email": "popov-nikolay1986@postgrespro.ru", "phone": "+70755432269"}
0005433845682	180304	0292 138053	NATALIYA IVANOVA	{"email": "ivanovan021960@postgrespro.ru", "phone": "+70744394373"}
0005433845683	CD7FE4	2128 092989	SERGEY GORBUNOV	{"email": "gorbunovs.17081976@postgrespro.ru", "phone": "+70169040466"}
0005433845684	B1A579	1786 815816	GRIGORIY ANDREEV	{"phone": "+70788227803"}
0005433845685	B1A579	4375 503971	ALEKSANDR POPOV	{"email": "popova-03051977@postgrespro.ru", "phone": "+70889318196"}
0005433845686	E556FD	0989 075893	KLAVDIYA YAKOVLEVA	{"email": "klavdiya_yakovleva.1968@postgrespro.ru", "phone": "+70281670247"}
0005433845687	107450	3654 383417	TATYANA KRASNOVA	{"phone": "+70948469617"}
0005433845688	B96E30	7641 188937	ELENA YUDINA	{"phone": "+70783127460"}
0005433845689	B96E30	4146 927723	VALERIY NOVIKOV	{"email": "valeriynovikov.27071970@postgrespro.ru", "phone": "+70852167911"}
0005433845690	D53BF5	5716 145532	VIKTOR BELOV	{"email": "belov.viktor-08061979@postgrespro.ru", "phone": "+70126823888"}
0005433845691	D53BF5	2587 563804	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev_08101983@postgrespro.ru", "phone": "+70147945331"}
0005433845692	D53BF5	5334 902691	VALERIY VASILEV	{"email": "vvasilev_091973@postgrespro.ru", "phone": "+70335024388"}
0005433845693	5007ED	0450 870288	VYACHESLAV GAVRILOV	{"phone": "+70614464560"}
0005433845694	E66504	4336 758272	MIKHAIL SCHERBAKOV	{"phone": "+70903256248"}
0005433845695	DFC90B	3826 987954	ANDREY DMITRIEV	{"email": "dmitriev.a_1976@postgrespro.ru", "phone": "+70081637170"}
0005433845696	693540	2072 966044	GALINA ANDREEVA	{"email": "andreeva_g_1977@postgrespro.ru", "phone": "+70402851997"}
0005433845697	693540	3792 701471	PAVEL KISELEV	{"phone": "+70313654911"}
0005433845698	FEA551	3362 119562	ANATOLIY TIKHONOV	{"email": "tikhonov-anatoliy_06061973@postgrespro.ru", "phone": "+70080126047"}
0005433845699	1F4364	8912 915865	VALENTINA ALEKSANDROVA	{"phone": "+70994501457"}
0005433845700	DBEC1D	3338 363855	EKATERINA KUZNECOVA	{"phone": "+70457292583"}
0005433845701	6B2827	0852 693276	FANIYA MELNIKOVA	{"phone": "+70771098788"}
0005433845702	6B2827	5272 127751	ALEKSANDR ALEKSANDROV	{"phone": "+70239267542"}
0005433845703	3E73C3	4497 347351	LYUBOV KUZMINA	{"phone": "+70018133453"}
0005433845704	45696A	1501 270063	ALEKSEY SOLOVEV	{"email": "soloveva_081962@postgrespro.ru", "phone": "+70185076190"}
0005433845705	BF60F8	1380 623960	PETR POPOV	{"email": "popovpetr041974@postgrespro.ru", "phone": "+70544176090"}
0005433845706	782FFB	1297 200967	YULIYA NOVIKOVA	{"email": "novikova-y-04121977@postgrespro.ru", "phone": "+70055746291"}
0005433845707	782FFB	0862 120121	ELIZAVETA STEPANOVA	{"email": "elizaveta-stepanova22031969@postgrespro.ru", "phone": "+70987158006"}
0005433845708	B4129D	1890 930648	TATYANA ALEKSEEVA	{"phone": "+70800232382"}
0005433845709	632F26	3512 071601	IRINA KISELEVA	{"phone": "+70353250885"}
0005433845710	53F915	3505 956148	NINA GUSEVA	{"email": "gusevanina_11091975@postgrespro.ru", "phone": "+70737367258"}
0005433845711	45C1D2	8486 701453	ALEKSANDR NOVIKOV	{"phone": "+70510524846"}
0005433845712	45C1D2	5402 721126	LYUDMILA KOVALEVA	{"phone": "+70440403468"}
0005433845713	45C1D2	9794 858673	TAMARA TIKHONOVA	{"email": "tikhonova.tamara-071978@postgrespro.ru", "phone": "+70146022513"}
0005433845714	45C1D2	7125 934609	VLADISLAV SHEVCHENKO	{"email": "vladislav-shevchenko101976@postgrespro.ru", "phone": "+70802092034"}
0005433845715	58A5E5	4712 233591	ARTEM FEDOROV	{"email": "afedorov10101982@postgrespro.ru", "phone": "+70282167816"}
0005433845716	45DD43	0239 895925	ELENA BELYAEVA	{"phone": "+70246111511"}
0005433845717	45DD43	3374 689816	ALEKSANDR RODIONOV	{"phone": "+70075852341"}
0005433845718	08C9C5	5284 685886	ANNA KUDRYASHOVA	{"email": "kudryashova-anna14031976@postgrespro.ru", "phone": "+70859979683"}
0005433845719	5E095A	8264 921975	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr06051970@postgrespro.ru", "phone": "+70314285722"}
0005433845720	83A7F1	3260 516425	ALEKSANDR ILIN	{"email": "ilin-a.30051970@postgrespro.ru", "phone": "+70987469052"}
0005433845721	83A7F1	9399 359750	ANTON SIDOROV	{"phone": "+70534792325"}
0005433845722	6219B0	3683 939607	EVGENIYA SIDOROVA	{"email": "sidorova-evgeniya.111976@postgrespro.ru", "phone": "+70089735685"}
0005433845723	222777	1388 643653	ELENA SIDOROVA	{"phone": "+70661311272"}
0005433845724	C44081	8229 576402	ANDREY ALEKSEEV	{"email": "a_alekseev1968@postgrespro.ru", "phone": "+70178610893"}
0005433845725	769D85	3421 322884	VIKTOR BELOV	{"email": "belov_viktor021971@postgrespro.ru", "phone": "+70975404685"}
0005433845726	769D85	1398 168349	NIKOLAY GUSEV	{"email": "nikolay-gusev_1969@postgrespro.ru", "phone": "+70348353967"}
0005433845727	0562D8	1326 523988	GENNADIY MIKHAYLOV	{"phone": "+70181933568"}
0005433845728	B58E85	1503 944919	ROMAN BELOV	{"phone": "+70130645667"}
0005433845729	72C7D8	0002 048918	ANDREY BELOV	{"phone": "+70977569198"}
0005433845730	304779	7103 658050	NIKOLAY FOMIN	{"phone": "+70147868129"}
0005433845731	46CC37	2435 345939	ANDREY MAKSIMOV	{"email": "maksimova_20021963@postgrespro.ru", "phone": "+70627459313"}
0005433845732	66BFF6	2806 606072	YURIY GUSEV	{"email": "yuriy-gusev-13111962@postgrespro.ru", "phone": "+70655295190"}
0005433845733	66BFF6	6528 110579	ALEKSANDR POPOV	{"email": "a_popov_03081972@postgrespro.ru", "phone": "+70865273081"}
0005433845734	94E453	0696 186508	ANDREY ALEKSEEV	{"email": "alekseevandrey031976@postgrespro.ru", "phone": "+70902382377"}
0005433845735	94E453	0046 701958	LYUDMILA OSIPOVA	{"email": "l.osipova1972@postgrespro.ru", "phone": "+70044335139"}
0005433845736	F28423	1304 784030	NINA MAKAROVA	{"phone": "+70713610385"}
0005433845737	8FF84D	8332 174435	LYUDMILA ALEKSANDROVA	{"phone": "+70035650681"}
0005433845738	CA15D4	4553 297712	IGOR KUZNECOV	{"phone": "+70101929552"}
0005433845739	CA15D4	9394 183637	VALENTINA ZAYCEVA	{"phone": "+70054454874"}
0005433845740	601C3F	2904 361433	SVETLANA FROLOVA	{"email": "sfrolova.1977@postgrespro.ru", "phone": "+70527203036"}
0005433845741	B2F55F	5171 190384	EKATERINA GUSEVA	{"phone": "+70020561131"}
0005433845742	79A5CB	5856 729159	FAINA GORBUNOVA	{"phone": "+70465221180"}
0005433845743	84D46A	2907 943651	DMITRIY FEDOROV	{"phone": "+70820233178"}
0005433845744	C9445D	1132 921160	LYUDMILA TITOVA	{"phone": "+70673301009"}
0005433845745	A55994	2449 011597	IRINA KUZNECOVA	{"email": "kuznecovai_021974@postgrespro.ru", "phone": "+70758807663"}
0005433845746	A55994	4870 143961	LYUDMILA IVANOVA	{"email": "ivanova_l-16101988@postgrespro.ru", "phone": "+70650546063"}
0005433845747	A55994	3176 269985	ANNA MAKSIMOVA	{"phone": "+70022696736"}
0005433845748	866716	8658 031808	VLADIMIR IVANOV	{"email": "v-ivanov-04081968@postgrespro.ru", "phone": "+70833459891"}
0005433845749	45DC7B	5129 769023	VITALIY SOKOLOV	{"email": "vitaliy_sokolov_10041976@postgrespro.ru", "phone": "+70496655115"}
0005433845750	45DC7B	1655 248937	MAKSIM SMIRNOV	{"phone": "+70780018143"}
0005433845751	D3587F	1262 182304	NIKOLAY SHEVCHENKO	{"phone": "+70394178283"}
0005433845752	9D61D6	7173 051555	VALERIYA IVANOVA	{"email": "valeriyaivanova-021970@postgrespro.ru", "phone": "+70223401534"}
0005433845753	9D61D6	7762 201372	IVAN MAKSIMOV	{"phone": "+70315710751"}
0005433845754	AB55F5	4002 831029	DANIIL GORBUNOV	{"email": "gorbunovdaniil-10071977@postgrespro.ru", "phone": "+70865359321"}
0005433845755	2DCED3	4799 480297	VERA MASLOVA	{"phone": "+70182099738"}
0005433845756	9E793B	2214 110087	VASILIY MATVEEV	{"email": "matveevv-071969@postgrespro.ru", "phone": "+70329086153"}
0005433845757	2E42B4	6666 354599	LILIYA VASILEVA	{"email": "liliya.vasileva_1977@postgrespro.ru", "phone": "+70225028169"}
0005433845758	2E42B4	4354 670317	DARYA NAZAROVA	{"phone": "+70445846091"}
0005433845759	57748E	7274 828973	MURAD ALEKSANDROV	{"phone": "+70473115486"}
0005433845760	49EDB6	9425 740949	DENIS OSIPOV	{"phone": "+70739835069"}
0005433845761	2DCC15	3512 809183	ALEKSANDR SMIRNOV	{"email": "asmirnov.21061979@postgrespro.ru", "phone": "+70114067684"}
0005433845762	2DCC15	1862 240568	DMITRIY KUZNECOV	{"phone": "+70835417723"}
0005433845763	290557	3742 819380	LYUBOV LUKYANOVA	{"phone": "+70288026126"}
0005433845764	290557	0629 877732	GENNADIY PETROV	{"email": "gennadiypetrov.26101973@postgrespro.ru", "phone": "+70541750542"}
0005433845765	9C835D	7914 322284	ANTONINA ANTONOVA	{"phone": "+70513575583"}
0005433845766	430FE8	3142 126918	EVGENIY GUSEV	{"email": "gusev_evgeniy_05021972@postgrespro.ru", "phone": "+70192877630"}
0005433845767	430FE8	6314 505161	NADEZHDA NAUMOVA	{"phone": "+70344659452"}
0005433845768	7572FB	4432 557648	ELENA SAVELEVA	{"email": "elenasaveleva011969@postgrespro.ru", "phone": "+70775357294"}
0005433845769	4056A9	4527 445281	ANDREY SIDOROV	{"email": "andrey-sidorov1983@postgrespro.ru", "phone": "+70092038045"}
0005433845770	9B2BFF	8249 109383	OLGA VLASOVA	{"email": "vlasova.o011969@postgrespro.ru", "phone": "+70665943632"}
0005433845771	2C2BC2	4423 268591	NIKOLAY BORISOV	{"email": "n-borisov.21091965@postgrespro.ru", "phone": "+70909495807"}
0005433845772	2C2BC2	6966 712728	ELENA POPOVA	{"phone": "+70567374102"}
0005433845773	FD9632	9676 554418	ANNA MATVEEVA	{"email": "anna-matveeva.1966@postgrespro.ru", "phone": "+70892128604"}
0005433845774	3E1B74	7478 888652	NAIL MOISEEV	{"phone": "+70177753631"}
0005433845775	EDB01E	5536 837380	ANTONINA SERGEEVA	{"email": "antonina-sergeeva_091971@postgrespro.ru", "phone": "+70625302898"}
0005433845776	E10C65	6267 224294	SVETLANA MIRONOVA	{"phone": "+70618856906"}
0005433845777	E10C65	6032 403643	IVAN GORBUNOV	{"phone": "+70311983124"}
0005433845778	CA3A16	8200 859756	SERGEY MAKAROV	{"phone": "+70449219869"}
0005433845779	9280CF	2784 991255	ELENA RYABOVA	{"email": "ryabova.e021965@postgrespro.ru", "phone": "+70065125549"}
0005433845780	9280CF	6447 306196	LARISA EGOROVA	{"phone": "+70441779472"}
0005433845781	9280CF	7307 124895	MARIYA VLASOVA	{"phone": "+70949883823"}
0005433845782	5B7ABF	8740 193800	RIMMA NESTEROVA	{"phone": "+70577418739"}
0005433845783	BB3D0D	4178 755833	VERA SOLOVEVA	{"email": "vera-soloveva04061968@postgrespro.ru", "phone": "+70117360118"}
0005433845784	5871E4	0338 966848	VLADIMIR IVANOV	{"email": "ivanov_vladimir02091976@postgrespro.ru", "phone": "+70781655303"}
0005433845785	FBE486	6321 797324	EVGENIYA VASILEVA	{"email": "vasileva-e_1972@postgrespro.ru", "phone": "+70756029038"}
0005433845786	74AA08	7200 611136	GENNADIY NOVIKOV	{"phone": "+70570053413"}
0005433845787	74AA08	6372 555912	ANATOLIY MAKAROV	{"email": "anatoliy.makarov1991@postgrespro.ru", "phone": "+70533447425"}
0005433845788	D404CE	7470 101683	TATYANA IVANOVA	{"email": "tatyana-ivanova23031978@postgrespro.ru", "phone": "+70495736986"}
0005433845789	D404CE	2287 186159	ANDREY PETROV	{"email": "petrova.13121976@postgrespro.ru", "phone": "+70541233576"}
0005433845790	EE7F40	1830 663946	VLADISLAV NIKITIN	{"email": "v_nikitin-03031975@postgrespro.ru", "phone": "+70916678300"}
0005433845791	675D72	1506 942957	LYUBOV KUZNECOVA	{"email": "kuznecova.l1968@postgrespro.ru", "phone": "+70265842143"}
0005433845792	675D72	2219 642057	ANNA SIDOROVA	{"phone": "+70876937714"}
0005433845793	74C193	2446 147172	ELIZAVETA EGOROVA	{"phone": "+70006461126"}
0005433845794	4ABB81	9055 318982	ELENA MOISEEVA	{"email": "elena-moiseeva-121966@postgrespro.ru", "phone": "+70281626556"}
0005433845795	F08032	6888 957927	TATYANA YAKOVLEVA	{"phone": "+70123943693"}
0005433845796	F08032	7714 313062	OLEG ANTONOV	{"email": "antonov-oleg-03011972@postgrespro.ru", "phone": "+70959223775"}
0005433845797	67B3E8	8622 379558	SERGEY KUZNECOV	{"phone": "+70868773548"}
0005433845798	67B3E8	3497 478549	VALENTINA ZAYCEVA	{"phone": "+70166622013"}
0005433845799	57B294	4406 256909	GENNADIY IVANOV	{"phone": "+70606521123"}
0005433845800	6A642B	2967 503910	NATALIYA LOGINOVA	{"phone": "+70431632125"}
0005433845801	1BBFBA	8049 822396	SERGEY ILIN	{"phone": "+70302221199"}
0005433845802	667057	2105 614474	SERGEY KUZNECOV	{"email": "kuznecov.sergey10081981@postgrespro.ru", "phone": "+70423220253"}
0005433845803	65EF89	8409 164132	RAMIL SMIRNOV	{"phone": "+70513432617"}
0005433845804	65EF89	6449 762787	TATYANA ORLOVA	{"phone": "+70998558309"}
0005433845805	17D47D	4715 419689	NATALYA SEMENOVA	{"email": "semenova-natalya.041984@postgrespro.ru", "phone": "+70661977047"}
0005433845806	F7FD3B	3420 387487	SERGEY MAKAROV	{"phone": "+70940400252"}
0005433845807	1CACD5	6906 129028	MARIYA MAKAROVA	{"email": "makarova.m.04081969@postgrespro.ru", "phone": "+70326645852"}
0005433845808	752EA4	7708 938843	NINA PETROVA	{"phone": "+70072119155"}
0005433845809	3EF5F0	2014 069121	SERGEY POPOV	{"phone": "+70926912576"}
0005433845810	9C1D7F	1266 031950	VLADIMIR ZAYCEV	{"phone": "+70286618521"}
0005433845811	9C1D7F	8084 711991	IRINA SOROKINA	{"email": "i-sorokina.121971@postgrespro.ru", "phone": "+70947404632"}
0005433845812	9C1D7F	9367 439403	OLEG KOROLEV	{"email": "korolevo_091981@postgrespro.ru", "phone": "+70912950911"}
0005433845813	9C1D7F	4711 960942	OLEG SEMENOV	{"phone": "+70281376414"}
0005433845814	999CAD	7114 043744	GEORGIY DAVYDOV	{"email": "g_davydov_17101971@postgrespro.ru", "phone": "+70885904354"}
0005433845815	47AB12	2637 931545	YULIYA KUZNECOVA	{"phone": "+70179212205"}
0005433845816	2C089C	7369 885027	ANNA KULIKOVA	{"email": "kulikovaa-03041970@postgrespro.ru", "phone": "+70081363968"}
0005433845817	49A986	6227 723262	ARTEM ANTONOV	{"email": "aantonov-1964@postgrespro.ru", "phone": "+70367571190"}
0005433845818	4674D2	8683 363562	NADEZHDA FROLOVA	{"email": "n-frolova1970@postgrespro.ru", "phone": "+70625099964"}
0005433845819	4674D2	1898 179670	VALENTINA KRASNOVA	{"email": "krasnova_valentina_06091977@postgrespro.ru", "phone": "+70551284848"}
0005433845820	5E0BDB	5816 381193	VLADIMIR KARPOV	{"phone": "+70514311273"}
0005433845821	4E60A1	8665 957610	MARIYA ZOTOVA	{"email": "zotova_mariya021964@postgrespro.ru", "phone": "+70527127003"}
0005433845822	94E763	0385 404344	EKATERINA NAZAROVA	{"phone": "+70975780702"}
0005433845823	94E763	0482 380591	ELENA OSIPOVA	{"phone": "+70272199840"}
0005433845824	5C93DF	0888 324352	GERMAN VOROBEV	{"phone": "+70844797687"}
0005433845825	06627E	2686 974998	OLGA ROMANOVA	{"phone": "+70938249629"}
0005433845826	06627E	4945 948250	LYUDMILA ISAEVA	{"email": "isaeva_l_091966@postgrespro.ru", "phone": "+70908383768"}
0005433845827	3B8326	3004 296363	NATALYA POLYAKOVA	{"phone": "+70884800590"}
0005433845828	A70AAF	2526 877142	YULIYA ROMANOVA	{"phone": "+70608144167"}
0005433845829	85BFDE	5531 111525	IGOR NIKITIN	{"phone": "+70377761081"}
0005433845830	EBC4F5	5128 093211	NINA LEBEDEVA	{"phone": "+70767617209"}
0005433845831	4F4BBB	4504 952862	TATYANA FEDOROVA	{"phone": "+70705560711"}
0005433845832	FCFB7E	1300 969266	SERGEY KAZAKOV	{"phone": "+70411995168"}
0005433845833	88E668	5373 371373	ALEKSANDR KOZLOV	{"phone": "+70856571156"}
0005433845834	88E668	6266 086833	VERA MALYSHEVA	{"phone": "+70630024684"}
0005433845835	88E668	2319 993348	DARYA SOROKINA	{"email": "sorokina-darya.16011970@postgrespro.ru", "phone": "+70095645083"}
0005433845836	2317CD	2761 124293	NINA MIKHAYLOVA	{"phone": "+70034723268"}
0005433845837	2317CD	7344 263404	RAISA FILIPPOVA	{"phone": "+70784817486"}
0005433845838	7FCD22	0048 514116	LYUDMILA KOROLEVA	{"email": "koroleva.l-01101965@postgrespro.ru", "phone": "+70636468276"}
0005433845839	072346	3445 478439	DMITRIY IVANOV	{"phone": "+70059492854"}
0005433845840	072346	8830 660235	EVGENIY ZAYCEV	{"phone": "+70368588342"}
0005433845841	F0484B	4926 858278	OKSANA NIKOLAEVA	{"phone": "+70176479106"}
0005433845842	CB155D	7579 611921	ALEKSANDRA SEMENOVA	{"email": "asemenova16121970@postgrespro.ru", "phone": "+70263195613"}
0005433845843	DD2DCC	9412 671704	GENNADIY MOROZOV	{"phone": "+70862824495"}
0005433845844	DD2DCC	0765 315410	ALIYA SEMENOVA	{"phone": "+70503426497"}
0005433845845	2409D2	5212 580299	RAISA IVANOVA	{"email": "ivanova_r1979@postgrespro.ru", "phone": "+70632506655"}
0005433845846	72047C	6856 652982	ALEKSANDR SIDOROV	{"phone": "+70345200628"}
0005433845847	72047C	5484 738443	ANDREY MELNIKOV	{"phone": "+70519668001"}
0005433845848	A188BE	3381 531520	KARINA KUZNECOVA	{"email": "k-kuznecova1971@postgrespro.ru", "phone": "+70244760175"}
0005433845849	297932	9868 442576	VIKTOR ZAKHAROV	{"email": "zakharov_viktor_071987@postgrespro.ru", "phone": "+70530156641"}
0005433845850	297932	0675 360677	KLAVDIYA SOROKINA	{"phone": "+70023663968"}
0005433845851	297932	3115 843537	OLGA KUDRYASHOVA	{"phone": "+70876827399"}
0005433845852	F2152D	7812 359435	KLAVDIYA EGOROVA	{"phone": "+70805876160"}
0005433845853	0F34F2	5655 797602	LYUDMILA BARANOVA	{"phone": "+70735711798"}
0005433845854	0F34F2	8596 685622	ELENA NESTEROVA	{"email": "elenanesterova03101972@postgrespro.ru", "phone": "+70377539051"}
0005433845855	8BA22D	5229 274220	ANDREY NAZAROV	{"phone": "+70130593393"}
0005433845856	B599D8	1319 347740	TAMARA SEMENOVA	{"email": "tamara-semenova061978@postgrespro.ru", "phone": "+70117510922"}
0005433845857	A2A854	6061 718987	TATYANA YAKOVLEVA	{"email": "t.yakovleva.091970@postgrespro.ru", "phone": "+70187613396"}
0005433845858	96DC92	3395 066971	EVGENIYA SOROKINA	{"phone": "+70932994772"}
0005433845859	8434B8	7765 008220	LYUBOV DENISOVA	{"phone": "+70773458219"}
0005433845860	8B789E	7633 812327	ELENA PETROVA	{"email": "petrova.elena-01051972@postgrespro.ru", "phone": "+70419545188"}
0005433845861	8C4B55	4031 325713	VALENTINA ERMAKOVA	{"email": "ermakova.v-1965@postgrespro.ru", "phone": "+70957350721"}
0005433845862	95A6F5	0422 403196	NIKITA GRIGOREV	{"email": "grigorev.n-121969@postgrespro.ru", "phone": "+70879723216"}
0005433845863	95A6F5	2281 567863	NATALIYA MEDVEDEVA	{"email": "medvedevan-061972@postgrespro.ru", "phone": "+70462523090"}
0005433845864	AF1A00	1575 024284	EKATERINA SMIRNOVA	{"email": "ekaterinasmirnova-1961@postgrespro.ru", "phone": "+70155346981"}
0005433845865	AF1A00	8843 151064	ANDREY FROLOV	{"phone": "+70920612379"}
0005433845866	AF1A00	9563 473319	ZLATA OVCHINNIKOVA	{"email": "z_ovchinnikova_1978@postgrespro.ru", "phone": "+70282843304"}
0005433845867	F41E33	7926 978001	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_1968@postgrespro.ru", "phone": "+70334379843"}
0005433845868	F41E33	1935 183554	ZULFIYA PETROVA	{"phone": "+70223171755"}
0005433845869	A12EEA	9740 342535	GRIGORIY IVANOV	{"phone": "+70026524582"}
0005433845870	A12EEA	8688 919198	MIKHAIL SERGEEV	{"phone": "+70865403734"}
0005433845871	A12EEA	4851 403246	IRINA GERASIMOVA	{"email": "irina_gerasimova_031979@postgrespro.ru", "phone": "+70618589215"}
0005433845872	59520B	4745 073797	VIKTOR KUZNECOV	{"email": "kuznecov-viktor_111965@postgrespro.ru", "phone": "+70203822792"}
0005433845873	6C4081	8771 294366	ZINAIDA RYABOVA	{"phone": "+70185418704"}
0005433845874	41DD22	9620 005889	OLEG MELNIKOV	{"phone": "+70368937994"}
0005433845875	2DCFE0	1145 468408	VALERIY GORBUNOV	{"phone": "+70091095428"}
0005433845876	02CD34	8501 718612	ALEKSANDR KRASNOV	{"phone": "+70841477386"}
0005433845877	02CD34	7425 274604	ANATOLIY VASILEV	{"phone": "+70317457988"}
0005433845878	28D014	6511 361686	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr-111971@postgrespro.ru", "phone": "+70240350304"}
0005433845879	28D014	1227 186558	OKSANA KUZNECOVA	{"phone": "+70223923531"}
0005433845880	1FE1DD	7669 522521	LIDIYA KOZLOVA	{"email": "l-kozlova-1978@postgrespro.ru", "phone": "+70871104556"}
0005433845881	69DC58	3543 828374	ALEKSANDR SMIRNOV	{"phone": "+70354182471"}
0005433845882	D15368	6726 756242	NADEZHDA SOLOVEVA	{"email": "soloveva.nadezhda.091955@postgrespro.ru", "phone": "+70380933253"}
0005433845883	D15368	0367 549322	OLEG VOLKOV	{"email": "oleg_volkov_18061973@postgrespro.ru", "phone": "+70916098992"}
0005433845884	264CA3	8967 697783	NIKOLAY EGOROV	{"phone": "+70020451799"}
0005433845885	264CA3	3386 215102	OLGA KULIKOVA	{"phone": "+70580404693"}
0005433845886	DB7FB9	5896 467806	BORIS KUZMIN	{"phone": "+70518135901"}
0005433845887	C3D891	7789 956418	MARGARITA MOROZOVA	{"phone": "+70051346059"}
0005433845888	C3D891	1271 737596	RUSTEM BARANOV	{"email": "rustembaranov_03011981@postgrespro.ru", "phone": "+70395943200"}
0005433845889	6DBCA1	5601 852008	GENNADIY CHERNOV	{"email": "chernovgennadiy_29031978@postgrespro.ru", "phone": "+70595417377"}
0005433845890	CA61C7	2589 343841	GALINA STEPANOVA	{"phone": "+70210153173"}
0005433845891	0998B5	8599 851270	NINA MIKHAYLOVA	{"email": "mikhaylova_nina_031981@postgrespro.ru", "phone": "+70361681564"}
0005433845892	0998B5	0732 096227	ANATOLIY BELOV	{"phone": "+70435257142"}
0005433845893	F645D2	4363 286211	OLGA GORBUNOVA	{"email": "gorbunova-o-081976@postgrespro.ru", "phone": "+70933951215"}
0005433845894	A5C18E	8303 846376	VITALIY DMITRIEV	{"phone": "+70326880084"}
0005433845895	34E849	1416 898715	ALEKSEY MOROZOV	{"phone": "+70610865661"}
0005433845896	34E849	8891 590052	VALENTINA ANTONOVA	{"phone": "+70961317915"}
0005433845897	34E849	4876 110933	VLADIMIR PAVLOV	{"phone": "+70410273674"}
0005433845898	1380E6	0863 251005	ALEKSANDR VLASOV	{"email": "a_vlasov.051974@postgrespro.ru", "phone": "+70095498533"}
0005433845899	1380E6	6106 135055	PETR TARASOV	{"email": "p_tarasov-30101982@postgrespro.ru", "phone": "+70569720213"}
0005433845900	22A59E	5595 082640	MAKSIM NAUMOV	{"email": "naumovm.021975@postgrespro.ru", "phone": "+70994456102"}
0005433845901	41766F	0272 862987	SERGEY SCHERBAKOV	{"phone": "+70254040677"}
0005433845902	41766F	2078 622121	EKATERINA LAZAREVA	{"email": "lazareva_e-31031967@postgrespro.ru", "phone": "+70759676136"}
0005433845903	E3CEB3	5816 326216	ALEKSANDR SMIRNOV	{"email": "a-smirnov1979@postgrespro.ru", "phone": "+70469875122"}
0005433845904	E3CEB3	8666 132586	SERGEY POPOV	{"phone": "+70926220984"}
0005433845905	5DAEC2	0685 168102	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr.1966@postgrespro.ru", "phone": "+70564129940"}
0005433845906	7AA53F	0397 702906	MAKSIM FROLOV	{"email": "frolovm.18111981@postgrespro.ru", "phone": "+70971321986"}
0005433845907	1B60ED	4557 674855	ARTEM GORBUNOV	{"phone": "+70353063222"}
0005433845908	1B60ED	5482 609366	LYUBOV CHERNOVA	{"email": "chernova_l.1972@postgrespro.ru", "phone": "+70479810262"}
0005433845909	A109F6	0546 293432	SERGEY MOROZOV	{"phone": "+70980949527"}
0005433845910	6B2727	0819 247795	ALEKSEY ANDREEV	{"email": "aleksey.andreev_30081970@postgrespro.ru", "phone": "+70678253007"}
0005433845911	E149A4	5641 314237	VLADIMIR PAVLOV	{"phone": "+70568213624"}
0005433845912	D874DB	9424 909550	IGOR MIKHAYLOV	{"email": "mikhaylovi051979@postgrespro.ru", "phone": "+70270473671"}
0005433845913	7E9D9F	9458 601146	VLADIMIR POPOV	{"phone": "+70673143686"}
0005433845914	B3BD74	5004 946280	VLADIMIR AFANASEV	{"email": "afanasev-v_06061960@postgrespro.ru", "phone": "+70893763864"}
0005433845915	A157B7	1296 286971	LYUDMILA FILIPPOVA	{"phone": "+70974705333"}
0005433845916	1E51E4	7158 069135	ELENA LEBEDEVA	{"email": "lebedevae_15021975@postgrespro.ru", "phone": "+70483771097"}
0005433845917	DD53EF	1636 127485	ALEKSANDR MIKHAYLOV	{"phone": "+70670820137"}
0005433845918	DE7809	8848 894364	KARINA IVANOVA	{"email": "ivanova_karina_20091977@postgrespro.ru", "phone": "+70682206383"}
0005433845919	EF5091	6566 693671	NIKOLAY PAVLOV	{"phone": "+70842792230"}
0005433845920	EF5091	7513 664867	ANASTASIYA MIRONOVA	{"phone": "+70320501824"}
0005433845921	210FF7	8504 807859	GALINA SOLOVEVA	{"phone": "+70038861697"}
0005433845922	B3EF2C	4931 728973	ANASTASIYA LEBEDEVA	{"email": "a-lebedeva1974@postgrespro.ru", "phone": "+70072441743"}
0005433845923	AA35A4	2825 869605	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila.20071977@postgrespro.ru", "phone": "+70542894999"}
0005433845924	AA35A4	4172 968324	YULIYA BOGDANOVA	{"email": "y_bogdanova_1964@postgrespro.ru", "phone": "+70474417049"}
0005433845925	0BE91C	2981 087510	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov.1969@postgrespro.ru", "phone": "+70805452255"}
0005433845926	8754CE	9294 349977	PAVEL SOKOLOV	{"email": "sokolov-pavel091973@postgrespro.ru", "phone": "+70937583695"}
0005433845927	951525	3437 130010	SERGEY EGOROV	{"phone": "+70836447577"}
0005433845928	951525	4719 085782	ARINA KOROLEVA	{"phone": "+70320950611"}
0005433845929	60235C	0735 238153	ELENA KISELEVA	{"phone": "+70869893558"}
0005433845930	25DD0E	6941 185493	ALEKSANDRA YUDINA	{"email": "a.yudina021962@postgrespro.ru", "phone": "+70840935988"}
0005433845931	26BCEA	1994 627161	YULIYA NESTEROVA	{"phone": "+70493506476"}
0005433845932	BADF17	9382 513893	GALINA FROLOVA	{"email": "g.frolova-091958@postgrespro.ru", "phone": "+70470798593"}
0005433845933	BADF17	5340 153323	VIKTOR SHEVCHENKO	{"phone": "+70976146710"}
0005433845934	9CD96B	8245 642017	GENNADIY KAZAKOV	{"email": "g-kazakov_08111976@postgrespro.ru", "phone": "+70569514914"}
0005433845935	27EB6D	2227 444845	IRINA KUZMINA	{"email": "kuzminai.11031972@postgrespro.ru", "phone": "+70305442420"}
0005433845936	11E11A	8493 166579	ALEKSANDR POPOV	{"email": "a.popov_1967@postgrespro.ru", "phone": "+70345055259"}
0005433845937	118DE2	3867 377239	GALINA ZAKHAROVA	{"phone": "+70159289983"}
0005433845938	98B6E2	8322 204694	LYUDMILA GRISHINA	{"email": "l_grishina.1973@postgrespro.ru", "phone": "+70215958720"}
0005433845939	57EC10	1100 851544	MARINA KUZNECOVA	{"phone": "+70418732588"}
0005433845940	A52F8E	5979 156195	MARINA VOROBEVA	{"phone": "+70802426224"}
0005433845941	3D04C2	1240 995695	MARIYA ZAYCEVA	{"phone": "+70953174504"}
0005433845942	3D04C2	3246 885263	PETR MELNIKOV	{"phone": "+70382599460"}
0005433845943	D05C75	2744 610272	ALEKSEY BONDARENKO	{"phone": "+70793118890"}
0005433845944	00B09E	9685 868736	VITALIY IVANOV	{"phone": "+70973484939"}
0005433845945	3E8069	4937 039290	IRINA ZHURAVLEVA	{"phone": "+70710527096"}
0005433845946	625EFD	3958 645523	DARYA FADEEVA	{"phone": "+70370525312"}
0005433845947	4D0049	8655 626250	RUSLAN SIDOROV	{"phone": "+70650893124"}
0005433845948	984540	4757 416914	EKATERINA ANDREEVA	{"email": "eandreeva_1977@postgrespro.ru", "phone": "+70044415500"}
0005433845949	970A85	7915 566208	DZHAMILYA KUDRYASHOVA	{"phone": "+70475206136"}
0005433845950	9634A5	8419 738218	RAISA MELNIKOVA	{"email": "melnikova.raisa-081964@postgrespro.ru", "phone": "+70736515142"}
0005433845951	DEE650	0563 959080	MAKSIM NIKITIN	{"email": "m-nikitin_1962@postgrespro.ru", "phone": "+70590673914"}
0005433845952	84570F	8840 406861	STANISLAV SHEVCHENKO	{"phone": "+70259346081"}
0005433845953	84570F	6509 061310	SERGEY MAKSIMOV	{"phone": "+70455742388"}
0005433845954	02630C	2897 571038	NATALYA MATVEEVA	{"phone": "+70563808726"}
0005433845955	17582B	1247 803795	PAVEL FOMIN	{"email": "fomin-pavel.27041974@postgrespro.ru", "phone": "+70915413677"}
0005433845956	A936B6	9369 225262	ALEKSANDR PAVLOV	{"email": "a-pavlov.25021968@postgrespro.ru", "phone": "+70096155100"}
0005433845957	B981F9	0549 777522	ELENA YAKOVLEVA	{"email": "elena.yakovleva_22111970@postgrespro.ru", "phone": "+70658378954"}
0005433845958	B981F9	6953 118637	MARINA OSIPOVA	{"email": "m.osipova-1989@postgrespro.ru", "phone": "+70712665150"}
0005433845959	0CD022	7475 446343	VLADIMIR IVANOV	{"email": "v.ivanov30091974@postgrespro.ru", "phone": "+70808385731"}
0005433845960	0CD022	0543 563162	ALLA KOZLOVA	{"phone": "+70868099539"}
0005433845961	4BD12A	2243 848257	DMITRIY POPOV	{"email": "d.popov-081975@postgrespro.ru", "phone": "+70888818371"}
0005433845962	0D0776	5439 078257	KONSTANTIN BARANOV	{"email": "baranov_konstantin1964@postgrespro.ru", "phone": "+70681402434"}
0005433845963	030A99	4454 693416	SERGEY SERGEEV	{"email": "sergeev.s.01061972@postgrespro.ru", "phone": "+70466893185"}
0005433845964	C5F91D	6548 526087	MARIYA BORISOVA	{"email": "m-borisova1968@postgrespro.ru", "phone": "+70479288779"}
0005433845965	44484E	7762 726197	VASILIY PETROV	{"phone": "+70533866756"}
0005433845966	852A8D	7886 152414	ANDREY KRASNOV	{"email": "krasnov.andrey111972@postgrespro.ru", "phone": "+70223052810"}
0005433845967	72BE22	3159 400537	VITALIY MOROZOV	{"phone": "+70382285419"}
0005433845968	5AEA13	2683 353878	ANNA KUZNECOVA	{"email": "anna-kuznecova.031974@postgrespro.ru", "phone": "+70567392875"}
0005433845969	16F412	1822 390000	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov.18111973@postgrespro.ru", "phone": "+70734979388"}
0005433845970	F4A515	3527 773037	ANATOLIY FEDOROV	{"phone": "+70509658530"}
0005433845971	5BA186	5574 081611	DMITRIY KAZAKOV	{"email": "kazakov.d_17031968@postgrespro.ru", "phone": "+70476966877"}
0005433845972	5BA186	1865 694619	EVGENIY BARANOV	{"email": "baranov-evgeniy091960@postgrespro.ru", "phone": "+70156748773"}
0005433845973	5BA186	9039 679740	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr.26041977@postgrespro.ru", "phone": "+70697169607"}
0005433845974	BCBA49	8035 788535	VLADIMIR SEMENOV	{"phone": "+70639448848"}
0005433845975	1628BA	7965 956873	ELENA ZOTOVA	{"email": "zotovaelena-1980@postgrespro.ru", "phone": "+70239353065"}
0005433845976	CDF7BC	1573 516397	ROBERT SIDOROV	{"phone": "+70577810141"}
0005433845977	F002E7	5441 599289	KIRILL ILIN	{"email": "ilinkirill1964@postgrespro.ru", "phone": "+70263179111"}
0005433845978	231D0C	6443 274111	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov.101974@postgrespro.ru", "phone": "+70446288256"}
0005433845979	231D0C	7187 664629	VLADIMIR OSIPOV	{"phone": "+70120254540"}
0005433845980	0AB48C	6814 933145	VARVARA ANDREEVA	{"phone": "+70260332566"}
0005433845981	FD4033	5010 035084	PAVEL BORISOV	{"phone": "+70604502218"}
0005433845982	FD4033	8360 162333	IRINA NIKOLAEVA	{"phone": "+70447791984"}
0005433845983	85C8E1	1729 198517	ALEKSANDR SHEVCHENKO	{"email": "aleksandr.shevchenko.111964@postgrespro.ru", "phone": "+70511848033"}
0005433845984	85C8E1	1512 389310	NIKOLAY RODIONOV	{"phone": "+70345187343"}
0005433845985	AA4B6B	3905 873690	KSENIYA DANILOVA	{"email": "kseniyadanilova.23071971@postgrespro.ru", "phone": "+70673684380"}
0005433845986	AA4B6B	6771 143901	NATALYA NAZAROVA	{"email": "nazarovanatalya121970@postgrespro.ru", "phone": "+70753147003"}
0005433845987	CEA78E	2480 658025	YULIANA MAKAROVA	{"email": "makarovay.1974@postgrespro.ru", "phone": "+70266825720"}
0005433845988	4B556B	9709 532187	ANNA SERGEEVA	{"phone": "+70852660805"}
0005433845989	4B556B	3042 408690	ELENA ALEKSEEVA	{"email": "elena-alekseeva.071975@postgrespro.ru", "phone": "+70357612551"}
0005433845990	4B556B	7465 121226	VASILIY PETROV	{"email": "petrov_vasiliy_1977@postgrespro.ru", "phone": "+70793793968"}
0005433845991	AFD8EB	5101 592307	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a_031978@postgrespro.ru", "phone": "+70283125450"}
0005433845992	C9159F	3928 007022	GALINA KOMAROVA	{"phone": "+70264091644"}
0005433845993	C9159F	6206 694872	MIKHAIL KOZLOV	{"email": "m_kozlov1974@postgrespro.ru", "phone": "+70010076622"}
0005433845994	E2EBDA	6260 933539	YULIYA MAKAROVA	{"phone": "+70551241089"}
0005433845995	AF1D12	6108 187508	VIOLETTA BARANOVA	{"phone": "+70683161068"}
0005433845996	AF1D12	8804 999814	RISHAT POPOV	{"email": "r-popov-071960@postgrespro.ru", "phone": "+70723846926"}
0005433845997	46BC77	4939 403368	ALEKSANDR MAKSIMOV	{"phone": "+70255768986"}
0005433845998	E0E699	4743 446668	VYACHESLAV ABRAMOV	{"phone": "+70687003695"}
0005433845999	E0E699	1673 787449	DARYA BOGDANOVA	{"phone": "+70367080363"}
0005433846000	5580CB	6131 675296	YAROSLAV SOLOVEV	{"phone": "+70183194705"}
0005433846001	903967	3764 553117	KONSTANTIN SMIRNOV	{"email": "smirnov.konstantin_011970@postgrespro.ru", "phone": "+70078299199"}
0005433846002	31F2AF	4430 281953	VLADIMIR TIKHONOV	{"phone": "+70403437258"}
0005433846003	253F05	5088 259617	STANISLAV SHEVCHENKO	{"phone": "+70453147495"}
0005433846004	283C6C	8165 018123	LYUDMILA MAKAROVA	{"email": "l-makarova021983@postgrespro.ru", "phone": "+70566532950"}
0005433846005	283C6C	7612 163704	ROMAN SMIRNOV	{"email": "smirnovr051970@postgrespro.ru", "phone": "+70029121823"}
0005433846006	4EF196	4180 917600	OLGA KULIKOVA	{"phone": "+70076707313"}
0005433846007	4EF196	2560 385437	YURIY SCHERBAKOV	{"phone": "+70822582478"}
0005433846008	375CED	2467 342011	SVETLANA CHERNOVA	{"phone": "+70717621730"}
0005433846009	F9C7C0	8297 949446	ANNA GRISHINA	{"phone": "+70535951835"}
0005433846010	FA7D7E	7513 155148	RAVIL SOKOLOV	{"phone": "+70898619297"}
0005433846011	54EA52	5284 478880	EVGENIY SEMENOV	{"email": "e.semenov.28031974@postgrespro.ru", "phone": "+70232625878"}
0005433846012	BCEF12	4485 046864	ALEKSANDR DENISOV	{"email": "denisov.a_1971@postgrespro.ru", "phone": "+70213923773"}
0005433846013	12029C	6927 475815	RAISA KRASNOVA	{"phone": "+70944298848"}
0005433846014	B1EAB4	7575 299531	VIKTORIYA ZHUKOVA	{"email": "zhukova_v051968@postgrespro.ru", "phone": "+70592750120"}
0005433846015	EAEA7F	1676 788868	PAVEL GORBUNOV	{"email": "gorbunov.pavel-051969@postgrespro.ru", "phone": "+70608285010"}
0005433846016	EAEA7F	0694 540028	SERGEY EGOROV	{"email": "egorov-s1977@postgrespro.ru", "phone": "+70784549762"}
0005433846017	A3F411	9211 426105	OLEG ORLOV	{"phone": "+70259430524"}
0005433846018	A3F411	6253 696569	IRINA ANDREEVA	{"email": "andreeva.irina1982@postgrespro.ru", "phone": "+70901972788"}
0005433846019	51C626	8801 210315	DMITRIY FEDOROV	{"email": "fedorov-dmitriy051978@postgrespro.ru", "phone": "+70267132058"}
0005433846020	7A89B9	2430 267774	VALENTINA DENISOVA	{"email": "denisova-valentina-25081971@postgrespro.ru", "phone": "+70283792231"}
0005433846021	C3E75B	7492 384117	RAISA SEMENOVA	{"phone": "+70804999870"}
0005433846022	76F143	5025 264063	DARYA FILATOVA	{"phone": "+70025384260"}
0005433846023	B1FA5E	9834 579991	GALINA SERGEEVA	{"email": "galina_sergeeva-13011984@postgrespro.ru", "phone": "+70123321831"}
0005433846024	89BF0E	5463 427270	VLADISLAV MAKSIMOV	{"email": "vmaksimov.07061973@postgrespro.ru", "phone": "+70306441062"}
0005433846025	4DCDEC	4571 785858	EKATERINA FILATOVA	{"phone": "+70806183784"}
0005433846026	E77357	8893 431366	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a1970@postgrespro.ru", "phone": "+70492820918"}
0005433846027	76DA31	1923 132668	SVETLANA BORISOVA	{"email": "borisova_s.1965@postgrespro.ru", "phone": "+70988924157"}
0005433846028	76DA31	1019 729349	ALENA NIKOLAEVA	{"email": "a_nikolaeva05071966@postgrespro.ru", "phone": "+70836456368"}
0005433846029	25AF4E	9929 362883	ALEVTINA ANISIMOVA	{"email": "anisimova-alevtina1964@postgrespro.ru", "phone": "+70170516417"}
0005433846030	FBAB63	3794 253773	ELENA MOROZOVA	{"email": "elena-morozova.021970@postgrespro.ru", "phone": "+70157672371"}
0005433846031	8AA18B	3627 960930	VIKTOR KRASNOV	{"phone": "+70966912845"}
0005433846032	8AA18B	3071 520811	NIKOLAY VOLKOV	{"email": "volkovnikolay_1971@postgrespro.ru", "phone": "+70185068318"}
0005433846033	8F73EA	3894 058321	VALENTIN SHEVCHENKO	{"phone": "+70191669448"}
0005433846034	8F73EA	3267 167454	RIMMA IVANOVA	{"phone": "+70436104229"}
0005433846035	8F73EA	8174 476155	GENNADIY DMITRIEV	{"phone": "+70544191654"}
0005433846036	0C4442	4591 080913	OLGA KULIKOVA	{"email": "kulikovaolga_11121976@postgrespro.ru", "phone": "+70392293892"}
0005433846037	13F1C2	2044 293959	ELENA ZAKHAROVA	{"email": "elena-zakharova-1978@postgrespro.ru", "phone": "+70416643638"}
0005433846038	13F1C2	1824 389976	NIKOLAY KUZNECOV	{"phone": "+70930379803"}
0005433846039	88524C	5900 996131	NINA KUZMINA	{"phone": "+70145322183"}
0005433846040	570098	8564 333998	DANILA DENISOV	{"phone": "+70224065933"}
0005433846041	F7DDEB	5819 132729	EVGENIY MELNIKOV	{"phone": "+70256580608"}
0005433846042	F7DDEB	6248 189828	ANATOLIY FROLOV	{"phone": "+70249872507"}
0005433846043	C683BD	9261 672772	GALINA YAKOVLEVA	{"phone": "+70818482667"}
0005433846044	D68DCF	3711 520905	VALENTINA KUZMINA	{"phone": "+70939871193"}
0005433846045	D68DCF	5930 854316	IGOR NIKITIN	{"email": "igor-nikitin_1975@postgrespro.ru", "phone": "+70225574141"}
0005433846046	D68DCF	8761 806993	GALINA BORISOVA	{"email": "borisova-g-1962@postgrespro.ru", "phone": "+70334882749"}
0005433846047	D3A426	4424 674302	ELENA MAKAROVA	{"phone": "+70081554185"}
0005433846048	CAF291	6950 453696	ALEKSANDR KARPOV	{"phone": "+70751519342"}
0005433846049	CAF291	8795 309287	ANASTASIYA POPOVA	{"email": "popovaanastasiya.20091976@postgrespro.ru", "phone": "+70046066983"}
0005433846050	B083FF	3350 771450	RAIL IVANOV	{"email": "railivanov-19061982@postgrespro.ru", "phone": "+70047123351"}
0005433846051	469737	2907 105121	IRINA NIKITINA	{"phone": "+70226894512"}
0005433846052	469737	1163 626976	NIKOLAY ORLOV	{"email": "n-orlov_1968@postgrespro.ru", "phone": "+70661897233"}
0005433846053	DF89B9	3958 432515	ANNA SMIRNOVA	{"phone": "+70748166429"}
0005433846054	DF89B9	5169 119761	ALEKSEY MAKAROV	{"phone": "+70025866420"}
0005433846055	DF89B9	6024 203719	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov09101971@postgrespro.ru", "phone": "+70839561984"}
0005433846056	E9E20A	3148 519640	SERGEY GRIGOREV	{"email": "s_grigorev_1975@postgrespro.ru", "phone": "+70570060399"}
0005433846057	E9E20A	3078 569190	IVAN KAZAKOV	{"email": "kazakov-i_1970@postgrespro.ru", "phone": "+70962541799"}
0005433846058	3C63FD	4785 011269	ANASTASIYA OSIPOVA	{"phone": "+70699694098"}
0005433846059	3C63FD	2988 602435	EKATERINA MAKAROVA	{"email": "makarova.e.21041966@postgrespro.ru", "phone": "+70700196681"}
0005433846060	3AB35F	1669 493870	VASILIY NOVIKOV	{"phone": "+70028212363"}
0005433846061	75BC6E	3951 710336	VALERIYA BARANOVA	{"email": "v.baranova.31011978@postgrespro.ru", "phone": "+70673029069"}
0005433846062	494A32	9515 429289	ALEKSANDR SAVELEV	{"phone": "+70720765168"}
0005433846063	9177F8	1417 576972	IRINA KUZNECOVA	{"phone": "+70393109814"}
0005433846064	6F0376	3736 313588	VLADIMIR IVANOV	{"email": "ivanov-v.10111981@postgrespro.ru", "phone": "+70510265310"}
0005433846065	D42571	5773 081476	ALEKSANDR BONDARENKO	{"phone": "+70905028271"}
0005433846066	C95D37	3014 646060	IRINA YUDINA	{"phone": "+70910139244"}
0005433846067	A7A333	0233 243243	DMITRIY MELNIKOV	{"phone": "+70390248194"}
0005433846068	0B2688	7908 381798	RINAT GORBUNOV	{"email": "gorbunov-r_091977@postgrespro.ru", "phone": "+70809651381"}
0005433846069	5A4EDC	7711 642397	LYUBOV KUDRYASHOVA	{"email": "l.kudryashova.24051972@postgrespro.ru", "phone": "+70161264932"}
0005433846070	90B363	6614 236957	MARINA MEDVEDEVA	{"email": "medvedeva-marina121965@postgrespro.ru", "phone": "+70191307565"}
0005433846071	1E12AC	2226 097338	ELENA AKIMOVA	{"email": "akimova_e_081977@postgrespro.ru", "phone": "+70320924548"}
0005433846072	67AA48	0262 099885	NATALYA MAKAROVA	{"email": "makarovan-20101969@postgrespro.ru", "phone": "+70439839563"}
0005433846073	4A7957	5954 892589	VIKTOR SOROKIN	{"email": "v.sorokin-21101975@postgrespro.ru", "phone": "+70668190282"}
0005433846074	B4EC81	0768 614932	NIKOLAY ORLOV	{"email": "orlov-nikolay_26081965@postgrespro.ru", "phone": "+70580907483"}
0005433846075	E25A8A	8863 084977	DENIS KARPOV	{"phone": "+70489316841"}
0005433846076	E25A8A	4454 289223	GALINA NAUMOVA	{"email": "naumova-g.29051982@postgrespro.ru", "phone": "+70591058751"}
0005433846077	7B0749	7619 622573	ELENA MARTYNOVA	{"phone": "+70635899948"}
0005433846078	C15144	6123 066016	ALEKSEY SAVELEV	{"email": "savelevaleksey1968@postgrespro.ru", "phone": "+70605184861"}
0005433846079	E901BF	2708 552038	SERGEY KAZAKOV	{"phone": "+70328834028"}
0005433846080	86B7A5	9227 010622	ANTONINA NIKOLAEVA	{"email": "nikolaeva_a-111973@postgrespro.ru", "phone": "+70220496412"}
0005433846081	FB46C2	3738 065867	KLAVDIYA MIRONOVA	{"email": "mironovak28061972@postgrespro.ru", "phone": "+70794487816"}
0005433846082	01AE68	7743 075352	ANDREY SOLOVEV	{"phone": "+70398433690"}
0005433846083	DCF6F0	8460 046863	ALEKSANDR VOLKOV	{"phone": "+70553971645"}
0005433846084	CBF314	1150 526748	VERA ZAYCEVA	{"phone": "+70784845732"}
0005433846085	9D8ED1	7237 223165	IRINA MAKAROVA	{"email": "irina-makarova071965@postgrespro.ru", "phone": "+70440409624"}
0005433846086	5A0FD5	6937 495864	ANZHELA KULIKOVA	{"email": "kulikova.a.051982@postgrespro.ru", "phone": "+70912956016"}
0005433846087	2BDE06	5116 229347	ROMAN ZAYCEV	{"email": "r_zaycev.1979@postgrespro.ru", "phone": "+70742952540"}
0005433846088	715DB2	7581 933936	ANDREY KONOVALOV	{"email": "a.konovalov1967@postgrespro.ru", "phone": "+70852858242"}
0005433846089	715DB2	3617 393038	LIDIYA NIKITINA	{"email": "lidiya.nikitina.26111972@postgrespro.ru", "phone": "+70307145680"}
0005433846090	4BA44A	7736 055707	ELENA ZHURAVLEVA	{"phone": "+70923019438"}
0005433846091	5FA960	4201 797272	EKATERINA IVANOVA	{"phone": "+70323072112"}
0005433846092	98636E	0797 811635	NINA MIRONOVA	{"email": "mironovan-1977@postgrespro.ru", "phone": "+70893506287"}
0005433846093	F22017	9596 534405	MARGARITA BORISOVA	{"phone": "+70383435315"}
0005433846094	551851	9153 252284	VLADIMIR NAZAROV	{"phone": "+70751097675"}
0005433846095	551851	4908 966428	SERGEY KOROLEV	{"email": "korolev_s1975@postgrespro.ru", "phone": "+70317263191"}
0005433846096	8F1B53	7265 353612	ALEKSEY KUZNECOV	{"phone": "+70903845734"}
0005433846097	8F1B53	5967 318987	OLGA BELOVA	{"email": "belova_olga.1970@postgrespro.ru", "phone": "+70726655807"}
0005433846098	378ECD	5746 467258	NINA KOZLOVA	{"phone": "+70903369157"}
0005433846099	177023	9940 986740	DARYA FROLOVA	{"email": "frolova.darya.101976@postgrespro.ru", "phone": "+70590872156"}
0005433846100	73F53C	9706 540571	VASILIY ZHURAVLEV	{"email": "zhuravlevvasiliy-1974@postgrespro.ru", "phone": "+70264157217"}
0005433846101	73F53C	1910 006634	VALENTINA ANISIMOVA	{"email": "anisimova_v.1969@postgrespro.ru", "phone": "+70013256625"}
0005433846102	CA0EE4	4767 641073	ALEKSEY SCHERBAKOV	{"phone": "+70679952492"}
0005433846103	46659D	5764 187934	ANDREY VOLKOV	{"phone": "+70908829761"}
0005433846104	070EA7	7428 283781	SERGEY GERASIMOV	{"phone": "+70259948531"}
0005433846105	23DF46	0692 045647	ALEKSANDR KARPOV	{"phone": "+70566175245"}
0005433846106	753406	8896 953641	ANDREY KUDRYASHOV	{"email": "kudryashov_andrey.21041985@postgrespro.ru", "phone": "+70374900640"}
0005433846107	71BDA6	3371 724418	SERGEY IVANOV	{"phone": "+70212327465"}
0005433846108	4E8E7D	7515 709572	YURIY FILIPPOV	{"phone": "+70050854393"}
0005433846109	4E8E7D	6743 721564	IRINA LOGINOVA	{"email": "loginova_i-1974@postgrespro.ru", "phone": "+70841557044"}
0005433846110	4E8E7D	9143 845576	NIKOLAY FEDOROV	{"email": "fedorov_nikolay-051973@postgrespro.ru", "phone": "+70040556746"}
0005433846111	22CCB2	5666 412564	MIKHAIL ANTONOV	{"email": "mikhailantonov.1973@postgrespro.ru", "phone": "+70733046796"}
0005433846112	22CCB2	2311 033287	NATALYA VOROBEVA	{"email": "n-vorobeva-12061972@postgrespro.ru", "phone": "+70497043502"}
0005433846113	D839F7	8775 184769	SVETLANA BORISOVA	{"email": "borisova_svetlana-1979@postgrespro.ru", "phone": "+70597438253"}
0005433846114	D839F7	1363 078293	NATALYA ANISIMOVA	{"phone": "+70120001968"}
0005433846115	D839F7	9033 498129	VLADIMIR SEMENOV	{"phone": "+70311553408"}
0005433846116	48991D	7325 240217	YURIY GUSEV	{"email": "gusevy-071981@postgrespro.ru", "phone": "+70198516351"}
0005433846117	48991D	3947 781469	EVGENIY STEPANOV	{"email": "evgeniy-stepanov-1983@postgrespro.ru", "phone": "+70014025826"}
0005433846118	48991D	4739 643590	ANDREY GRIGOREV	{"phone": "+70623173688"}
0005433846119	4B760B	8513 320724	EKATERINA IVANOVA	{"phone": "+70348836899"}
0005433846120	4B760B	8018 752074	ALEKSANDR BONDARENKO	{"phone": "+70534484242"}
0005433846121	799236	7165 406167	TATYANA NOVIKOVA	{"phone": "+70146399610"}
0005433846122	799236	3127 649586	VALENTINA ANTONOVA	{"phone": "+70750941994"}
0005433846123	799236	8806 976169	MARIYA IVANOVA	{"email": "m-ivanova.061970@postgrespro.ru", "phone": "+70106594799"}
0005433846124	AC00A5	1974 159546	IVAN DENISOV	{"phone": "+70656643494"}
0005433846125	C38B6D	9159 132623	EKATERINA GAVRILOVA	{"phone": "+70165159211"}
0005433846126	88F544	6830 686337	SERGEY SOLOVEV	{"email": "solovev-s1972@postgrespro.ru", "phone": "+70071510931"}
0005433846127	57FD2D	4922 221095	RAISA IVANOVA	{"phone": "+70902685737"}
0005433846128	F68A4B	5937 616354	DMITRIY VOLKOV	{"phone": "+70572294373"}
0005433846129	388EBD	9556 818075	SERGEY TIKHONOV	{"email": "tikhonovs.1967@postgrespro.ru", "phone": "+70698673230"}
0005433846130	388EBD	9188 073999	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila_021964@postgrespro.ru", "phone": "+70505555290"}
0005433846131	70E7EE	6429 866607	ALEKSEY KOZLOV	{"email": "aleksey.kozlov-1970@postgrespro.ru", "phone": "+70913997442"}
0005433846132	1EEBD8	5533 838796	ALEKSANDR ZAKHAROV	{"email": "zakharov-a_23041977@postgrespro.ru", "phone": "+70862140332"}
0005433846133	1EEBD8	3326 475449	IRINA BORISOVA	{"phone": "+70344036977"}
0005433846134	1EEBD8	5044 644576	OLGA MELNIKOVA	{"phone": "+70804657232"}
0005433846135	9E0DBA	1145 045098	EKATERINA FILIPPOVA	{"email": "filippova.e.101960@postgrespro.ru", "phone": "+70781923616"}
0005433846136	C1CBD4	1543 888934	TAMARA ABRAMOVA	{"phone": "+70336748567"}
0005433846137	7A4FFD	6119 782188	TATYANA POTAPOVA	{"phone": "+70321281028"}
0005433846138	7A4FFD	0640 290193	ANDREY KUZNECOV	{"email": "kuznecovandrey07091980@postgrespro.ru", "phone": "+70766005708"}
0005433846139	DC8E66	9627 479967	TAMARA FEDOROVA	{"email": "tamara_fedorova_121968@postgrespro.ru", "phone": "+70353919187"}
0005433846140	DC8E66	3805 374202	LYUDMILA BELYAEVA	{"email": "belyaeva.l_1977@postgrespro.ru", "phone": "+70706262351"}
0005433846141	14F431	7422 497727	NELYA KUZNECOVA	{"phone": "+70854051591"}
0005433846142	14F431	8403 581370	NADEZHDA KUDRYASHOVA	{"email": "kudryashova_n_09031973@postgrespro.ru", "phone": "+70955197774"}
0005433846143	3CA545	3131 332085	OLGA VOROBEVA	{"phone": "+70223906998"}
0005433846144	F0E879	7125 960086	ALEKSANDR KUZMIN	{"email": "kuzmin-a1972@postgrespro.ru", "phone": "+70560954742"}
0005433846145	6D5892	3316 688371	OLGA MIRONOVA	{"email": "olga.mironova.18091966@postgrespro.ru", "phone": "+70615324957"}
0005433846146	6D5892	3597 828004	TATYANA ZHUKOVA	{"email": "zhukova-t011972@postgrespro.ru", "phone": "+70115568895"}
0005433846147	AD9A12	2553 079309	TATYANA FROLOVA	{"email": "frolovatatyana-1962@postgrespro.ru", "phone": "+70745996248"}
0005433846148	AD9A12	1649 720468	OLGA ALEKSEEVA	{"email": "olga_alekseeva051978@postgrespro.ru", "phone": "+70369836433"}
0005433846149	AD9A12	6262 386875	MARGARITA ERMAKOVA	{"email": "ermakova_margarita-021965@postgrespro.ru", "phone": "+70138536650"}
0005433846150	66616E	5432 331202	ANASTASIYA PAVLOVA	{"email": "pavlova-a_051980@postgrespro.ru", "phone": "+70722137588"}
0005433846151	AEC8FE	2675 828696	EKATERINA KOROLEVA	{"phone": "+70794372667"}
0005433846152	DDADA7	0831 363164	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr1969@postgrespro.ru", "phone": "+70353478948"}
0005433846153	16915E	7585 799766	ANDREY IVANOV	{"email": "a_ivanov_031963@postgrespro.ru", "phone": "+70369257272"}
0005433846154	67DBDF	3003 486465	OLGA KOROLEVA	{"email": "koroleva-olga_13111973@postgrespro.ru", "phone": "+70395998123"}
0005433846155	83FB40	4185 042633	NINA FILIPPOVA	{"phone": "+70470650140"}
0005433846156	83FB40	0126 557741	MARIYA NAZAROVA	{"email": "nazarova.mariya-051973@postgrespro.ru", "phone": "+70998798282"}
0005433846157	4AFE7A	0628 620214	ALEKSEY MIKHAYLOV	{"phone": "+70160077897"}
0005433846158	6FD687	2627 459469	FEDOR VLASOV	{"email": "vlasov.f-29121973@postgrespro.ru", "phone": "+70063022783"}
0005433846159	96F76B	6998 524861	GERMAN ZAKHAROV	{"email": "german-zakharov_1966@postgrespro.ru", "phone": "+70014105130"}
0005433846160	9921BE	8565 745923	POLINA SIDOROVA	{"email": "sidorova-polina.1977@postgrespro.ru", "phone": "+70482128864"}
0005433846161	CF2C81	3705 591714	ELENA KUZNECOVA	{"email": "e.kuznecova-1951@postgrespro.ru", "phone": "+70899471262"}
0005433846162	9D3F56	6491 110852	SERGEY DENISOV	{"email": "denisov-sergey061969@postgrespro.ru", "phone": "+70253056972"}
0005433846163	D35568	4649 609015	TATYANA YAKOVLEVA	{"phone": "+70238729887"}
0005433846164	63365E	0707 265625	YANA VOLKOVA	{"phone": "+70565725802"}
0005433846165	DF4B01	4799 338992	PETR FROLOV	{"phone": "+70754776384"}
0005433846166	A69EC0	9548 580939	EVA SAVELEVA	{"email": "saveleva-e.121970@postgrespro.ru", "phone": "+70114928103"}
0005433846167	B7C523	5921 904185	VIKTOR DENISOV	{"email": "denisovv.041966@postgrespro.ru", "phone": "+70271977691"}
0005433846168	B7C523	5552 901973	NINA BORISOVA	{"email": "borisovan121965@postgrespro.ru", "phone": "+70419845184"}
0005433846169	14BF1A	5771 430310	ALEKSEY ROMANOV	{"email": "romanov-a-091972@postgrespro.ru", "phone": "+70210204688"}
0005433846170	79A15C	0799 290347	NATALYA AKIMOVA	{"email": "akimova_n.27051977@postgrespro.ru", "phone": "+70731831043"}
0005433846171	C005B3	1503 854163	NATALYA KUZMINA	{"phone": "+70283664457"}
0005433846172	4CA2E1	2669 798683	LIDIYA ANTONOVA	{"email": "l.antonova.121965@postgrespro.ru", "phone": "+70703561917"}
0005433846173	F420DF	4480 586970	SERGEY KUZNECOV	{"email": "sergey_kuznecov_1973@postgrespro.ru", "phone": "+70320581251"}
0005433846174	3D9A9E	2273 985025	ALEKSEY ALEKSEEV	{"phone": "+70897088900"}
0005433846175	3D9A9E	2705 432032	ALEKSANDR KUZNECOV	{"phone": "+70379151157"}
0005433846176	EE5613	1557 069080	ALEKSEY SOKOLOV	{"email": "sokolov_aleksey_22011970@postgrespro.ru", "phone": "+70844502675"}
0005433846177	D8206D	7940 374936	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.svetlana_1966@postgrespro.ru", "phone": "+70853981718"}
0005433846178	D8206D	0445 109493	KSENIYA SOROKINA	{"email": "sorokina-kseniya.08111965@postgrespro.ru", "phone": "+70950271585"}
0005433846179	E6CCAF	9226 274759	ALEKSEY ZAYCEV	{"phone": "+70485404296"}
0005433846180	B34673	8917 305456	ANDREY FEDOTOV	{"phone": "+70842199455"}
0005433846181	D038D2	3593 223688	ANNA KISELEVA	{"phone": "+70529694510"}
0005433846182	D038D2	6556 512052	EKATERINA POTAPOVA	{"email": "ekaterina-potapova-1961@postgrespro.ru", "phone": "+70589780840"}
0005433846183	1D900A	6449 418361	ROMAN TARASOV	{"phone": "+70996690099"}
0005433846184	57AF81	0680 508310	MARIYA DAVYDOVA	{"email": "davydova.mariya.23061959@postgrespro.ru", "phone": "+70537049261"}
0005433846185	E66DA8	3490 171539	DARYA KOROLEVA	{"phone": "+70506328811"}
0005433846186	E66DA8	9537 697487	SVETLANA DENISOVA	{"phone": "+70668695800"}
0005433846187	3EFB24	4971 456371	EKATERINA MOROZOVA	{"phone": "+70520805261"}
0005433846188	BEC3C7	5031 926764	OLGA VASILEVA	{"email": "vasileva-olga-18061972@postgrespro.ru", "phone": "+70573474532"}
0005433846189	BEC3C7	6624 893961	YULIYA KRASNOVA	{"phone": "+70728163913"}
0005433846190	BEC3C7	4982 082957	ELENA VASILEVA	{"email": "vasileva_e.081962@postgrespro.ru", "phone": "+70864210578"}
0005433846191	345129	4626 952941	MILENA FROLOVA	{"email": "mfrolova071980@postgrespro.ru", "phone": "+70684527563"}
0005433846192	E8BAA9	3108 541045	SERGEY GRIGOREV	{"email": "grigorevsergey-1964@postgrespro.ru", "phone": "+70273688179"}
0005433846193	2E841B	3474 158672	VLADIMIR NAZAROV	{"email": "nazarov_v_1970@postgrespro.ru", "phone": "+70475989501"}
0005433846194	81EC8B	5358 707466	SERGEY IVANOV	{"phone": "+70971282300"}
0005433846195	E64528	5660 022311	ALEKSANDR ROMANOV	{"phone": "+70492866544"}
0005433846196	E64528	1366 123011	ALEKSANDR ABRAMOV	{"email": "a_abramov_091974@postgrespro.ru", "phone": "+70391219688"}
0005433846197	B538E8	0545 297024	VALENTINA EFIMOVA	{"email": "valentinaefimova-26011976@postgrespro.ru", "phone": "+70714154048"}
0005433846198	03BEBE	0596 650317	SOFYA KUZNECOVA	{"email": "kuznecova-sofya.1975@postgrespro.ru", "phone": "+70514845410"}
0005433846199	03BEBE	1287 876744	IVAN VOLKOV	{"phone": "+70821463058"}
0005433846200	03BEBE	6458 428190	TATYANA ALEKSEEVA	{"email": "t_alekseeva_22061973@postgrespro.ru", "phone": "+70184157185"}
0005433846201	DF2050	6707 201638	ELENA KUZMINA	{"phone": "+70459579826"}
0005433846202	DF2050	1185 281877	VIKTOR POPOV	{"email": "popovviktor-01091973@postgrespro.ru", "phone": "+70975563529"}
0005433846203	0BB51D	0133 528422	MIKHAIL NIKITIN	{"phone": "+70420530498"}
0005433846204	4C56C7	8364 851548	NIKITA MAKAROV	{"phone": "+70291112457"}
0005433846205	4C56C7	8013 284419	ANDREY TIKHONOV	{"email": "andreytikhonov-24031966@postgrespro.ru", "phone": "+70324812636"}
0005433846206	6BF9A4	5639 804797	DENIS GRIGOREV	{"phone": "+70024486221"}
0005433846207	D3CFC6	3398 956564	DENIS KUZNECOV	{"phone": "+70003797243"}
0005433846208	D3CFC6	4530 513573	EKATERINA CHERNOVA	{"email": "chernova.e_031969@postgrespro.ru", "phone": "+70767363685"}
0005433846209	46B46D	9015 930448	KIRILL EGOROV	{"email": "egorovkirill.1973@postgrespro.ru", "phone": "+70155600615"}
0005433846210	46B46D	0921 195066	GALINA KOROLEVA	{"email": "g.koroleva_121974@postgrespro.ru", "phone": "+70743786529"}
0005433846211	E27BB0	3254 559718	LIDIYA GUSEVA	{"email": "lidiyaguseva.1970@postgrespro.ru", "phone": "+70732191568"}
0005433846212	E27BB0	2530 811657	VIKTOR SCHERBAKOV	{"email": "scherbakov.viktor.1976@postgrespro.ru", "phone": "+70915868106"}
0005433846213	F0FEEB	3701 184178	ANASTASIYA TIMOFEEVA	{"email": "timofeeva_a-051983@postgrespro.ru", "phone": "+70851540983"}
0005433846214	BFAE2B	9280 210947	ALEKSANDR TIKHONOV	{"phone": "+70958623914"}
0005433846215	319F3B	1597 860368	OLGA AFANASEVA	{"email": "oafanaseva-091971@postgrespro.ru", "phone": "+70390828508"}
0005433846216	1EA059	6773 827495	OLGA EGOROVA	{"phone": "+70922434689"}
0005433846217	68ADEC	4914 148085	MIKHAIL FILIPPOV	{"email": "filippov_mikhail.18031977@postgrespro.ru", "phone": "+70285254295"}
0005433846218	DC285B	3146 132930	GULNARA KOVALEVA	{"phone": "+70118691263"}
0005433846219	DC285B	1194 987901	DANILA SMIRNOV	{"phone": "+70659773482"}
0005433846220	676C3C	7643 050701	IRINA MEDVEDEVA	{"phone": "+70283458751"}
0005433846221	9603E5	0755 716938	NATALYA MOISEEVA	{"email": "natalyamoiseeva.1969@postgrespro.ru", "phone": "+70409218068"}
0005433846222	673B70	1026 590441	VIKTOR ZAKHAROV	{"email": "zakharov-viktor_01121972@postgrespro.ru", "phone": "+70247857214"}
0005433846223	673B70	3299 453493	NIKOLAY NIKITIN	{"email": "nikitinn_021977@postgrespro.ru", "phone": "+70377045785"}
0005433846224	20D69F	0629 098374	NATALIYA ISAEVA	{"phone": "+70994008566"}
0005433846225	0A0C47	2541 616053	ALLA MAKAROVA	{"phone": "+70916941089"}
0005433846226	588F3F	2656 842013	EKATERINA BELYAEVA	{"phone": "+70682558027"}
0005433846227	815E56	2052 742644	MAKSIM GRIGOREV	{"phone": "+70206115037"}
0005433846228	815E56	5318 993590	LIDIYA POPOVA	{"phone": "+70965654184"}
0005433846229	BFAA76	6194 000227	SVETLANA VOLKOVA	{"email": "svetlanavolkova.051969@postgrespro.ru", "phone": "+70469588639"}
0005433846230	B45298	0431 467956	VALERIY ANDREEV	{"email": "vandreev-031982@postgrespro.ru", "phone": "+70556482867"}
0005433846231	102D1B	1346 475152	LYUDMILA NESTEROVA	{"email": "nesterova.lyudmila_051961@postgrespro.ru", "phone": "+70850184675"}
0005433846232	44DFA9	9882 765745	NINA YAKOVLEVA	{"phone": "+70145108177"}
0005433846233	44DFA9	3054 149209	ALEKSANDR GORBUNOV	{"phone": "+70793836319"}
0005433846234	6F5A20	7107 358506	MARINA LEBEDEVA	{"email": "mlebedeva03041973@postgrespro.ru", "phone": "+70893087745"}
0005433846235	7F85F8	9869 133014	VLADIMIR VOLKOV	{"email": "v.volkov1978@postgrespro.ru", "phone": "+70478328293"}
0005433846236	DC2CC1	1491 082678	KHALIDA ZAKHAROVA	{"phone": "+70378920292"}
0005433846237	711CFF	5718 213979	ANDREY RODIONOV	{"email": "rodionov.a.111964@postgrespro.ru", "phone": "+70382861201"}
0005433846238	4D8DDE	2412 819496	DMITRIY MAKAROV	{"phone": "+70924662015"}
0005433846239	D998BC	2984 990299	VASILIY FOMIN	{"phone": "+70388311578"}
0005433846240	CFF4DE	5407 504735	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov1961@postgrespro.ru", "phone": "+70956735906"}
0005433846241	55FFF4	3642 931818	VADIM MAKSIMOV	{"phone": "+70334486541"}
0005433846242	13C524	6827 628479	SERGEY KRASNOV	{"email": "s.krasnov.03011966@postgrespro.ru", "phone": "+70942494521"}
0005433846243	13C524	4517 701679	GENNADIY IVANOV	{"phone": "+70970952202"}
0005433846244	E46B3D	2927 927686	VALENTIN IVANOV	{"email": "ivanov-valentin15061974@postgrespro.ru", "phone": "+70386643512"}
0005433846245	B4F714	7937 899255	ELENA KOROLEVA	{"email": "koroleva_elena_101966@postgrespro.ru", "phone": "+70170737755"}
0005433846246	B4F714	7431 884159	VASILIY ALEKSANDROV	{"email": "vasiliyaleksandrov041975@postgrespro.ru", "phone": "+70596518674"}
0005433846247	84C334	9612 487754	ALSU MAKAROVA	{"phone": "+70692143963"}
0005433846248	E5FE9A	4498 190889	DMITRIY CHERNOV	{"email": "chernov_dmitriy_1969@postgrespro.ru", "phone": "+70572280075"}
0005433846249	E5FE9A	5697 259827	KSENIYA MELNIKOVA	{"email": "melnikova-kseniya-061963@postgrespro.ru", "phone": "+70921305620"}
0005433846250	04A616	5204 631246	YURIY MAKSIMOV	{"email": "maksimovy.04091963@postgrespro.ru", "phone": "+70180586192"}
0005433846251	04A616	5493 996280	NIKITA ORLOV	{"email": "orlovn-1969@postgrespro.ru", "phone": "+70043735386"}
0005433846252	953B80	0785 630412	TATYANA YUDINA	{"email": "t_yudina.041973@postgrespro.ru", "phone": "+70461106200"}
0005433846253	953B80	4510 936360	EGOR BELOV	{"phone": "+70186703125"}
0005433846254	953B80	7235 642001	DINARA POPOVA	{"phone": "+70193463531"}
0005433846255	B5C6A8	2619 456411	OLGA MOROZOVA	{"email": "morozova_o.27011969@postgrespro.ru", "phone": "+70956257026"}
0005433846256	B5C6A8	9753 185466	LYUDMILA KOZLOVA	{"phone": "+70914622939"}
0005433846257	293DE7	1292 540255	DMITRIY FEDOTOV	{"email": "fedotovdmitriy.11031969@postgrespro.ru", "phone": "+70133956040"}
0005433846258	9BF28D	5122 314531	NATALYA SERGEEVA	{"phone": "+70039156326"}
0005433846259	3F9841	7962 276114	VASILIY ANTONOV	{"phone": "+70441768165"}
0005433846260	8E050D	4393 312424	TATYANA KUZNECOVA	{"email": "kuznecova.t_15091975@postgrespro.ru", "phone": "+70448142980"}
0005433846261	8E050D	3997 587279	ZOYA BOGDANOVA	{"phone": "+70634047590"}
0005433846262	9F9A77	7126 856454	DMITRIY KRASNOV	{"phone": "+70654304262"}
0005433846263	9F9A77	0490 067055	ZOYA ALEKSEEVA	{"email": "zoyaalekseeva-1965@postgrespro.ru", "phone": "+70134870491"}
0005433846264	73B698	6783 706102	VALENTINA SERGEEVA	{"email": "v-sergeeva_1959@postgrespro.ru", "phone": "+70845458506"}
0005433846265	73B698	3625 249629	ALINA ORLOVA	{"phone": "+70941801564"}
0005433846266	1863B3	4743 601428	VLADIMIR NIKOLAEV	{"phone": "+70959563997"}
0005433846267	88BAF3	7296 313412	ELENA ANDREEVA	{"email": "andreeva_elena13071973@postgrespro.ru", "phone": "+70950981146"}
0005433846268	B6C062	3572 118655	ANATOLIY SERGEEV	{"email": "sergeev_anatoliy.06091964@postgrespro.ru", "phone": "+70372776113"}
0005433846269	BC4A6C	6061 282633	VALERIY SOROKIN	{"phone": "+70553285833"}
0005433846270	F7CD0B	9058 093389	TATYANA KOROLEVA	{"phone": "+70129027500"}
0005433846271	EE1268	1809 628772	SERGEY MIKHAYLOV	{"email": "s.mikhaylov-09051967@postgrespro.ru", "phone": "+70791469240"}
0005433846272	53D3CA	5920 493673	ADELINA KAZAKOVA	{"email": "kazakova-adelina.07081973@postgrespro.ru", "phone": "+70082358916"}
0005433846273	53D3CA	4024 578259	NATALYA VOLKOVA	{"email": "volkovanatalya-1974@postgrespro.ru", "phone": "+70319536184"}
0005433846274	ECEEFB	2643 338219	ALEKSANDR SEMENOV	{"phone": "+70124800602"}
0005433846275	ECEEFB	8297 782377	MARIYA PAVLOVA	{"phone": "+70617864336"}
0005433846276	ECEEFB	1483 592136	TIGRAN SMIRNOV	{"phone": "+70261467496"}
0005433846277	B2F664	4287 122776	ELENA KUZNECOVA	{"phone": "+70850517011"}
0005433846278	04AC8A	3972 524903	KONSTANTIN NIKITIN	{"phone": "+70697616878"}
0005433846279	04AC8A	2809 459375	YURIY VLASOV	{"phone": "+70317295797"}
0005433846280	812CD3	4636 759885	NATALYA TIKHONOVA	{"email": "ntikhonova-18091974@postgrespro.ru", "phone": "+70336249636"}
0005433846281	812CD3	0420 707083	VLADIMIR POPOV	{"phone": "+70067214078"}
0005433846282	B6E899	9665 624185	MIKHAIL CHERNOV	{"email": "chernov_m-021977@postgrespro.ru", "phone": "+70241359543"}
0005433846283	B6E899	7782 621343	VIOLETTA GUSEVA	{"email": "guseva-v.28111965@postgrespro.ru", "phone": "+70093997828"}
0005433846284	5C0F68	5034 859190	TATYANA KISELEVA	{"phone": "+70892385980"}
0005433846285	2A5436	7754 867029	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_a061968@postgrespro.ru", "phone": "+70532085946"}
0005433846286	26CA8C	2794 087424	SVETLANA KISELEVA	{"email": "kiselevasvetlana1980@postgrespro.ru", "phone": "+70677681665"}
0005433846287	F89449	6983 932159	SVETLANA MIRONOVA	{"email": "smironova.051972@postgrespro.ru", "phone": "+70152176724"}
0005433846288	8DF69F	9707 648377	SERGEY ILIN	{"email": "s_ilin.081973@postgrespro.ru", "phone": "+70666092907"}
0005433846289	7A7A9B	8047 750391	VALERIY MAKAROV	{"email": "makarov-v.1973@postgrespro.ru", "phone": "+70654659977"}
0005433846290	7A7A9B	2987 804338	DMITRIY KUZMIN	{"phone": "+70833059000"}
0005433846291	7A7A9B	9356 636108	LEONTIY NOVIKOV	{"phone": "+70777276525"}
0005433846292	B7CC79	5940 387492	ELENA EGOROVA	{"email": "elena_egorova.10011965@postgrespro.ru", "phone": "+70920641149"}
0005433846293	618AA0	7295 063863	RASHIT FILIPPOV	{"email": "filippov-rashit_1969@postgrespro.ru", "phone": "+70464604007"}
0005433846294	39C21D	6015 330336	ALEKSEY ALEKSEEV	{"email": "a_alekseev-07081972@postgrespro.ru", "phone": "+70736288582"}
0005433846295	DF6483	7046 490619	NIKOLAY STEPANOV	{"email": "stepanov-nikolay_15111984@postgrespro.ru", "phone": "+70023935864"}
0005433846296	DF6483	9871 612773	STEPAN BORISOV	{"email": "borisov.s-10071967@postgrespro.ru", "phone": "+70596574688"}
0005433846297	C3164F	0374 696643	TATYANA MIKHAYLOVA	{"phone": "+70999925454"}
0005433846298	C026BF	1653 396422	GALINA RODIONOVA	{"email": "rodionova_g.01101968@postgrespro.ru", "phone": "+70421306036"}
0005433846299	5659C0	2003 654432	INNA DANILOVA	{"email": "danilova-i101970@postgrespro.ru", "phone": "+70304895649"}
0005433846300	DDD6A0	3392 988817	DANIIL KISELEV	{"email": "kiselev_daniil_05011977@postgrespro.ru", "phone": "+70825311292"}
0005433846301	76EF41	1673 607137	IRINA NIKITINA	{"email": "irina-nikitina_1981@postgrespro.ru", "phone": "+70409613845"}
0005433846302	3275B4	6439 477406	ROMAN ZHUKOV	{"phone": "+70130073448"}
0005433846303	3275B4	0205 637396	TATYANA ALEKSEEVA	{"phone": "+70676443506"}
0005433846304	3FBFB9	1207 524423	VERONIKA YAKOVLEVA	{"email": "veronika-yakovleva101964@postgrespro.ru", "phone": "+70514118971"}
0005433846305	3FBFB9	5427 362421	ALEKSANDR BONDARENKO	{"phone": "+70343330804"}
0005433846306	24AF7F	9290 193071	VLADISLAV SMIRNOV	{"email": "smirnov.v_1978@postgrespro.ru", "phone": "+70758047022"}
0005433846307	24AF7F	4897 002415	RUSLAN FOMIN	{"phone": "+70140733084"}
0005433846308	05E901	7477 610104	POLINA KUZMINA	{"phone": "+70663042388"}
0005433846309	05E901	2658 465248	LYUBOV MELNIKOVA	{"phone": "+70167971427"}
0005433846310	7BED4B	2919 903562	LYUBOV DANILOVA	{"email": "l_danilova_07031973@postgrespro.ru", "phone": "+70415156003"}
0005433846311	7BED4B	3338 727818	IGOR IVANOV	{"phone": "+70447457407"}
0005433846312	039ED9	9037 537179	YURIY SOKOLOV	{"phone": "+70026835313"}
0005433846313	D73165	9328 816587	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_111961@postgrespro.ru", "phone": "+70493504927"}
0005433846314	087F05	8276 304113	ALEKSEY MIRONOV	{"phone": "+70813593159"}
0005433846315	087F05	3310 893422	YURIY MARTYNOV	{"phone": "+70977873992"}
0005433846316	087F05	7668 101320	OKSANA BARANOVA	{"email": "baranova-o.17011983@postgrespro.ru", "phone": "+70446108304"}
0005433846317	82B625	3099 008207	ALEKSANDR RODIONOV	{"email": "rodionova-24031976@postgrespro.ru", "phone": "+70094148725"}
0005433846318	82B625	8063 234089	MARIYA LAZAREVA	{"email": "mariya_lazareva.13111963@postgrespro.ru", "phone": "+70460483212"}
0005433846319	ABD3F2	6277 855522	OLGA LEBEDEVA	{"phone": "+70549452868"}
0005433846320	ABD3F2	7961 072669	GENNADIY ZAKHAROV	{"email": "gennadiy-zakharov-12011975@postgrespro.ru", "phone": "+70806869733"}
0005433846321	732562	2813 072831	GRIGORIY YAKOVLEV	{"phone": "+70855246088"}
0005433846322	280D9E	9249 134828	MARGARITA POTAPOVA	{"email": "potapova-m.19021968@postgrespro.ru", "phone": "+70449430667"}
0005433846323	FC2C74	2576 353053	VIKTOR DMITRIEV	{"phone": "+70829465082"}
0005433846324	972184	4552 749701	NELLI SAVELEVA	{"email": "saveleva_nelli-11041982@postgrespro.ru", "phone": "+70632607519"}
0005433846325	972184	2442 268823	ALESYA KULIKOVA	{"phone": "+70522603994"}
0005433846326	FDAB60	8735 409559	ALEKSANDR NAZAROV	{"phone": "+70952299448"}
0005433846327	8D17E8	4685 073739	NIKOLAY EGOROV	{"phone": "+70230760625"}
0005433846328	C18021	6190 723764	LYUBOV KOROLEVA	{"phone": "+70478722706"}
0005433846329	C18021	4950 562237	KLAVDIYA ZHUKOVA	{"email": "zhukova-klavdiya-061971@postgrespro.ru", "phone": "+70680820914"}
0005433846330	30F5A3	9200 834213	VLADIMIR ROMANOV	{"phone": "+70759390641"}
0005433846331	6E690A	4031 541537	ELENA NIKIFOROVA	{"phone": "+70302975820"}
0005433846332	C35864	5771 534151	ANTON EGOROV	{"email": "anton-egorov_091976@postgrespro.ru", "phone": "+70999193340"}
0005433846333	3FC4A8	3833 515789	ELENA DAVYDOVA	{"email": "davydova_elena.02071964@postgrespro.ru", "phone": "+70470530039"}
0005433846334	3FC4A8	1447 866889	ALEKSANDR NIKITIN	{"email": "nikitin_a_1971@postgrespro.ru", "phone": "+70664975811"}
0005433846335	7C0341	3333 860973	YURIY VOLKOV	{"email": "yuriy-volkov_1971@postgrespro.ru", "phone": "+70115974912"}
0005433846336	2661B6	0396 893979	NIKOLAY SEMENOV	{"email": "semenov-nikolay-16021976@postgrespro.ru", "phone": "+70821138524"}
0005433846337	68B036	0568 049767	ALEKSANDR BELOV	{"email": "a.belov041977@postgrespro.ru", "phone": "+70710507302"}
0005433846338	ED689D	9248 987183	NATALYA NIKOLAEVA	{"phone": "+70946382715"}
0005433846339	ED689D	5971 352451	MIKHAIL NIKITIN	{"phone": "+70358786309"}
0005433846340	DEA2CF	3744 873989	TAMARA LAZAREVA	{"phone": "+70064209849"}
0005433846341	B46CD9	0219 267385	LIDIYA LOGINOVA	{"phone": "+70804986436"}
0005433846342	45DACB	8345 872876	ALEKSEY IVANOV	{"email": "ivanov_aleksey01081976@postgrespro.ru", "phone": "+70758003986"}
0005433846343	DCD7B9	2675 667342	EVGENIY MELNIKOV	{"phone": "+70832992067"}
0005433846344	DCD7B9	0268 831803	GENNADIY ZHURAVLEV	{"phone": "+70574440916"}
0005433846345	7D0EBE	7859 148736	ILYA YAKOVLEV	{"phone": "+70429294054"}
0005433846346	53EDC8	5167 776717	TATYANA ZAKHAROVA	{"email": "zakharova.t.011970@postgrespro.ru", "phone": "+70602563696"}
0005433846347	CF07F2	8492 209428	PETR NIKOLAEV	{"email": "nikolaevpetr.1965@postgrespro.ru", "phone": "+70231169199"}
0005433846348	AB5ED9	8314 167787	IGOR ROMANOV	{"email": "iromanov-1978@postgrespro.ru", "phone": "+70659212188"}
0005433846349	D12BB7	3069 444312	NIKITA FOMIN	{"email": "fominn.1981@postgrespro.ru", "phone": "+70594393862"}
0005433846350	D12BB7	1171 780441	OLGA LAZAREVA	{"phone": "+70945228783"}
0005433846351	D12BB7	0305 389671	RAIL IVANOV	{"email": "r-ivanov_18041972@postgrespro.ru", "phone": "+70543117578"}
0005433846352	ED9415	8981 313667	ELENA TITOVA	{"phone": "+70939576332"}
0005433846353	ED9415	0490 088149	ALIYA ERMAKOVA	{"phone": "+70097014319"}
0005433846354	2DBE76	8669 053948	SERGEY FILIPPOV	{"phone": "+70628284660"}
0005433846355	FB67DB	4593 105352	PRASKOVYA NAUMOVA	{"email": "praskovyanaumova.011970@postgrespro.ru", "phone": "+70279342684"}
0005433846356	9D2647	5507 409309	MIKHAIL SMIRNOV	{"phone": "+70060929590"}
0005433846357	9D2647	3298 123507	SERGEY MAKSIMOV	{"email": "maksimov-sergey081967@postgrespro.ru", "phone": "+70971283030"}
0005433846358	3443A5	1130 884451	NINA SEMENOVA	{"email": "semenova-nina1969@postgrespro.ru", "phone": "+70936700706"}
0005433846359	8633BE	6572 263507	ALEKSEY ZAYCEV	{"email": "zaycev_a-21091975@postgrespro.ru", "phone": "+70936833149"}
0005433846360	D10323	5822 798992	ALENA BORISOVA	{"phone": "+70672631158"}
0005433846361	D10323	6538 639386	ELENA KUZNECOVA	{"phone": "+70115404171"}
0005433846362	A064F4	9289 085277	KONSTANTIN KAZAKOV	{"phone": "+70265336840"}
0005433846363	C10C13	8506 272955	YURIY MIKHAYLOV	{"email": "mikhaylov_yuriy.121964@postgrespro.ru", "phone": "+70691495484"}
0005433846364	96DC77	7273 580374	OLEG BELOV	{"email": "belov_o121974@postgrespro.ru", "phone": "+70046986431"}
0005433846365	EA9DFF	5411 289462	ANDREY FROLOV	{"phone": "+70882849053"}
0005433846366	422736	3727 449524	NELYA NIKITINA	{"phone": "+70720560598"}
0005433846367	0EAD8E	3810 037860	ARTEM BORISOV	{"email": "a_borisov-1971@postgrespro.ru", "phone": "+70347388167"}
0005433846368	0EAD8E	3340 810406	ALEKSANDR ILIN	{"phone": "+70131591096"}
0005433846369	53CFCD	2786 105174	DINARA NESTEROVA	{"email": "dinara-nesterova061972@postgrespro.ru", "phone": "+70594716307"}
0005433846370	D8DFCC	2652 437565	REGINA YUDINA	{"email": "r-yudina-091960@postgrespro.ru", "phone": "+70634035826"}
0005433846371	4D68FA	8123 029604	NIKOLAY TIKHONOV	{"email": "tikhonov-n-23101956@postgrespro.ru", "phone": "+70752668222"}
0005433846372	FC88F4	3921 977716	MIKHAIL IVANOV	{"email": "mikhail-ivanov-1972@postgrespro.ru", "phone": "+70710757084"}
0005433846373	9C263D	4404 959030	RAVIL MATVEEV	{"email": "matveev-r.23121974@postgrespro.ru", "phone": "+70147898019"}
0005433846374	9C263D	4756 806574	VALENTINA KULIKOVA	{"email": "kulikova_valentina_1971@postgrespro.ru", "phone": "+70414633923"}
0005433846375	3CE097	3762 771755	LIDIYA ZAYCEVA	{"email": "l.zayceva-14041969@postgrespro.ru", "phone": "+70334531368"}
0005433846376	6D077D	2868 058135	NATALYA EGOROVA	{"email": "natalya.egorova_1967@postgrespro.ru", "phone": "+70582194478"}
0005433846377	6D077D	4463 409113	DENIS SMIRNOV	{"phone": "+70996335426"}
0005433846378	E3D369	0188 714390	ALEKSANDR DENISOV	{"phone": "+70497119248"}
0005433846379	17D0CB	9181 796522	NINA RODIONOVA	{"phone": "+70457008815"}
0005433846380	DDBEF9	9479 961655	NATALYA POPOVA	{"email": "popova.n.051970@postgrespro.ru", "phone": "+70656381771"}
0005433846381	475952	8582 869191	TIMUR ANDREEV	{"phone": "+70607800469"}
0005433846382	475952	5901 430803	YAN BONDARENKO	{"phone": "+70181991301"}
0005433846383	993DEE	6948 442946	MIKHAIL SOLOVEV	{"email": "m_solovev_05071968@postgrespro.ru", "phone": "+70106573350"}
0005433846384	993DEE	4953 518833	LYUDMILA BOGDANOVA	{"email": "bogdanova.lyudmila15031982@postgrespro.ru", "phone": "+70576507291"}
0005433846385	8784B0	8248 958388	ANNA KOLESNIKOVA	{"phone": "+70266283149"}
0005433846386	61DC5D	3052 978635	EGOR SEMENOV	{"email": "egor_semenov-1961@postgrespro.ru", "phone": "+70804501744"}
0005433846387	4C0016	8740 541944	GULIYA ALEKSEEVA	{"email": "alekseeva.guliya-1973@postgrespro.ru", "phone": "+70911723319"}
0005433846388	D034DE	2122 392724	VLADIMIR KONOVALOV	{"phone": "+70917760214"}
0005433846389	D034DE	7787 571449	MAKSIM KOZLOV	{"phone": "+70967324503"}
0005433846390	D034DE	9102 983134	TATYANA MEDVEDEVA	{"email": "medvedevatatyana1967@postgrespro.ru", "phone": "+70800658379"}
0005433846391	1F3D3E	8655 551174	ALINA YAKOVLEVA	{"phone": "+70777021001"}
0005433846392	CF107E	2293 958042	OKSANA MEDVEDEVA	{"email": "o.medvedeva15021965@postgrespro.ru", "phone": "+70684320627"}
0005433846393	2849BB	1822 283451	BORIS CHERNOV	{"email": "chernov.boris.16021970@postgrespro.ru", "phone": "+70418744588"}
0005433846394	946E66	5860 007233	VASILIY VOLKOV	{"phone": "+70795611850"}
0005433846395	C2E583	3937 994701	ANATOLIY MOISEEV	{"phone": "+70091976967"}
0005433846396	C2E583	5775 350595	ZHANNA ROMANOVA	{"phone": "+70599013261"}
0005433846397	74C866	0584 327452	MIKHAIL MOISEEV	{"phone": "+70210446680"}
0005433846398	61CEEA	2900 432934	DMITRIY MAKSIMOV	{"email": "maksimov.dmitriy08051976@postgrespro.ru", "phone": "+70130052598"}
0005433846399	61CEEA	9396 588443	SERGEY SMIRNOV	{"phone": "+70935583430"}
0005433846400	245EC0	9155 116555	VITALIY FEDOROV	{"email": "fedorovvitaliy1965@postgrespro.ru", "phone": "+70682328762"}
0005433846401	245EC0	6121 987678	SVETLANA STEPANOVA	{"email": "sstepanova081961@postgrespro.ru", "phone": "+70392595601"}
0005433846402	CC2B15	7291 792122	EKATERINA ANTONOVA	{"phone": "+70871725409"}
0005433846403	9DA540	4205 388188	ELENA GORBUNOVA	{"email": "egorbunova.22051971@postgrespro.ru", "phone": "+70927719462"}
0005433846404	E03A56	2294 737735	MAKSIM IVANOV	{"email": "maksim-ivanov.28091977@postgrespro.ru", "phone": "+70482905766"}
0005433846405	D2955E	9562 664565	DENIS FOMIN	{"email": "denis-fomin.021983@postgrespro.ru", "phone": "+70241732123"}
0005433846406	D2955E	8091 961309	ALEKSEY SIDOROV	{"email": "sidorov.a021977@postgrespro.ru", "phone": "+70731762352"}
0005433846407	7DAFED	2041 578613	VALENTINA KALININA	{"phone": "+70629956002"}
0005433846408	7DAFED	3415 651370	OLESYA BOGDANOVA	{"email": "bogdanova-olesya.021970@postgrespro.ru", "phone": "+70882383017"}
0005433846409	FCD821	2327 611508	VLADISLAV CHERNOV	{"email": "v_chernov26111966@postgrespro.ru", "phone": "+70586115865"}
0005433846410	0FEEB6	8380 861801	ALEKSANDR FOMIN	{"email": "fomina.11071967@postgrespro.ru", "phone": "+70933323358"}
0005433846411	0FEEB6	3823 244445	ALEKSANDR SEMENOV	{"phone": "+70014991152"}
0005433846412	B5131A	6675 203084	IVAN MIRONOV	{"phone": "+70502494703"}
0005433846413	22090F	9647 626898	ALEKSEY IVANOV	{"email": "aleksey_ivanov1971@postgrespro.ru", "phone": "+70769133812"}
0005433846414	3098BB	2082 201290	LARISA MOROZOVA	{"email": "larisamorozova091960@postgrespro.ru", "phone": "+70278458521"}
0005433846415	D7F208	6968 012347	MARINA KOZLOVA	{"email": "marina-kozlova.061975@postgrespro.ru", "phone": "+70041021360"}
0005433846416	837D86	1747 875061	VYACHESLAV ILIN	{"email": "ilin_v-071981@postgrespro.ru", "phone": "+70665804153"}
0005433846417	6F383F	1772 253203	MIKHAIL ALEKSANDROV	{"phone": "+70554988324"}
0005433846418	DB95BE	7806 844156	YULIYA NIKITINA	{"phone": "+70915231031"}
0005433846419	5724B6	7072 512324	EVGENIYA MOROZOVA	{"phone": "+70836811258"}
0005433846420	0CAAD6	0948 544712	VIKTOR VASILEV	{"phone": "+70036977901"}
0005433846421	AEE0C0	7739 337804	NIKITA KUZNECOV	{"email": "n.kuznecov_041968@postgrespro.ru", "phone": "+70509858549"}
0005433846422	1CE92E	4840 235674	OKSANA KOZLOVA	{"phone": "+70142702121"}
0005433846423	446F86	9214 046016	VLADIMIR ROMANOV	{"email": "vladimirromanov_061978@postgrespro.ru", "phone": "+70955356752"}
0005433846424	1CCD1F	6829 247822	ANASTASIYA ILINA	{"phone": "+70438951218"}
0005433846425	9E3FC3	3771 562698	ANASTASIYA ZAKHAROVA	{"phone": "+70643580329"}
0005433846426	AC0F75	0604 727342	ALEKSEY ZAKHAROV	{"phone": "+70366826255"}
0005433846427	AC0F75	5689 909622	NIKOLAY ZHURAVLEV	{"phone": "+70826416458"}
0005433846428	496A48	5679 015529	ELENA MOROZOVA	{"phone": "+70321340921"}
0005433846429	67F554	7485 437360	YULIYA KOLESNIKOVA	{"phone": "+70778276926"}
0005433846430	7BB205	1187 833677	YURIY KOZLOV	{"email": "yuriy.kozlov_19061971@postgrespro.ru", "phone": "+70492391193"}
0005433846431	531EE2	1749 755570	ANASTASIYA GRISHINA	{"email": "grishinaanastasiya1964@postgrespro.ru", "phone": "+70737952497"}
0005433846432	EC3C6B	3953 947994	EKATERINA GRISHINA	{"email": "ekaterina.grishina_041976@postgrespro.ru", "phone": "+70829836552"}
0005433846433	EC3C6B	3680 585175	MARIYA CHERNOVA	{"email": "chernova.m_081965@postgrespro.ru", "phone": "+70413454934"}
0005433846434	363555	9838 236365	NIKOLAY KUDRYASHOV	{"email": "kudryashov-nikolay_111969@postgrespro.ru", "phone": "+70844876729"}
0005433846435	F410D9	6711 561979	VLADIMIR ILIN	{"phone": "+70191947967"}
0005433846436	FC7449	1800 407792	ANATOLIY BORISOV	{"phone": "+70720154073"}
0005433846437	A99E88	4843 002901	ZINAIDA DAVYDOVA	{"email": "davydovazinaida_1972@postgrespro.ru", "phone": "+70599653738"}
0005433846438	B4BFA7	0529 090599	VERA MIKHAYLOVA	{"phone": "+70420005480"}
0005433846439	D84225	6151 865327	VALENTINA ILINA	{"phone": "+70389037771"}
0005433846440	4F81B9	8506 357831	VLADIMIR GORBUNOV	{"email": "v.gorbunov-18111979@postgrespro.ru", "phone": "+70036124456"}
0005433846441	4F81B9	7103 021367	YULIYA MAKSIMOVA	{"phone": "+70884533009"}
0005433846442	617177	6165 104199	NATALYA ZHUKOVA	{"email": "n-zhukova-091966@postgrespro.ru", "phone": "+70603568668"}
0005433846443	CA1F17	9238 073792	ANNA BELOVA	{"email": "belovaa.081980@postgrespro.ru", "phone": "+70637047564"}
0005433846444	CA1F17	3764 171966	PAVEL ABRAMOV	{"email": "pavel-abramov011981@postgrespro.ru", "phone": "+70079010527"}
0005433846445	9C5547	6354 067121	NIKITA KUZNECOV	{"phone": "+70148456412"}
0005433846446	006BFD	6888 370718	SERGEY MARTYNOV	{"phone": "+70648639887"}
0005433846447	006BFD	8766 896683	SERGEY MAKAROV	{"phone": "+70494207489"}
0005433846448	4E59C5	7115 323785	ILYA STEPANOV	{"email": "ilyastepanov25051965@postgrespro.ru", "phone": "+70408351713"}
0005433846449	191472	6167 251284	ANTON BONDARENKO	{"email": "bondarenko.anton-1978@postgrespro.ru", "phone": "+70830167917"}
0005433846450	191472	5263 912666	ILYA DAVYDOV	{"email": "i_davydov15111965@postgrespro.ru", "phone": "+70882626517"}
0005433846451	200E5D	5599 866739	OLGA DENISOVA	{"phone": "+70246786362"}
0005433846452	A604B6	0537 247138	DMITRIY DMITRIEV	{"phone": "+70689778231"}
0005433846453	BBCE27	6340 562209	TATYANA YUDINA	{"phone": "+70616497381"}
0005433846454	0FEE52	9632 696456	ANATOLIY GORBUNOV	{"phone": "+70136523271"}
0005433846455	0FEE52	7433 347718	IVAN SEMENOV	{"email": "semenov_ivan_041970@postgrespro.ru", "phone": "+70291071826"}
0005433846456	420615	9670 176118	ZINAIDA BELOVA	{"phone": "+70584360385"}
0005433846457	E08910	1588 909004	ANTONINA EFREMOVA	{"phone": "+70001081090"}
0005433846458	E08910	3227 477990	NIKOLAY NOVIKOV	{"phone": "+70995862306"}
0005433846459	0C2ED6	6598 489418	GALINA TIKHONOVA	{"email": "g_tikhonova_101971@postgrespro.ru", "phone": "+70174503371"}
0005433846460	0C2ED6	9362 618685	DARYA ALEKSEEVA	{"email": "alekseeva-darya-01061978@postgrespro.ru", "phone": "+70148358592"}
0005433846461	C2D718	0730 564965	SERGEY SAVELEV	{"email": "s_savelev.28011963@postgrespro.ru", "phone": "+70068078635"}
0005433846462	E7096E	2126 106091	ALEKSANDR GRIGOREV	{"email": "grigorev-aleksandr.031961@postgrespro.ru", "phone": "+70476679686"}
0005433846463	E7096E	2209 760462	ANTONINA SERGEEVA	{"phone": "+70002968467"}
0005433846464	22CD57	3549 498377	ARTEM SCHERBAKOV	{"email": "a.scherbakov.24031963@postgrespro.ru", "phone": "+70633013793"}
0005433846465	AB30A1	0128 513609	ALEKSEY YAKOVLEV	{"email": "a-yakovlev_1974@postgrespro.ru", "phone": "+70317285674"}
0005433846466	AB30A1	8820 070006	VIKTOR ROMANOV	{"email": "vromanov-16031973@postgrespro.ru", "phone": "+70711630607"}
0005433846467	125AB4	0605 781303	VYACHESLAV ALEKSEEV	{"phone": "+70539704596"}
0005433846468	5F5645	0698 656061	TATYANA PETROVA	{"email": "tatyana_petrova081977@postgrespro.ru", "phone": "+70777062361"}
0005433846469	5F5645	8312 240514	VLADIMIR EGOROV	{"email": "egorov_vladimir.1961@postgrespro.ru", "phone": "+70660409132"}
0005433846470	D80266	4707 913966	VALERIY SEMENOV	{"email": "semenov-v1976@postgrespro.ru", "phone": "+70841406409"}
0005433846471	500707	6705 014552	VALENTINA PETROVA	{"phone": "+70701091455"}
0005433846472	2E8351	6950 554641	ZINAIDA SIDOROVA	{"email": "zinaida-sidorova_051977@postgrespro.ru", "phone": "+70080058916"}
0005433846473	808D92	8589 723972	IRINA BARANOVA	{"phone": "+70365823468"}
0005433846474	B45BE6	6278 289686	NADEZHDA MAKSIMOVA	{"phone": "+70976520494"}
0005433846475	883997	7298 304742	SERGEY KUZNECOV	{"email": "kuznecov_sergey061968@postgrespro.ru", "phone": "+70733690844"}
0005433846476	057227	7719 886332	IRINA SAVELEVA	{"email": "i.saveleva-041975@postgrespro.ru", "phone": "+70464090456"}
0005433846477	846363	1665 655327	EGOR POPOV	{"phone": "+70261779773"}
0005433846478	8104AB	6921 614956	DMITRIY SOLOVEV	{"phone": "+70267619180"}
0005433846479	8104AB	4388 113308	TATYANA SOKOLOVA	{"email": "sokolova.tatyana_16041983@postgrespro.ru", "phone": "+70964263469"}
0005433846480	C371C6	5313 294138	ELENA MEDVEDEVA	{"email": "elena.medvedeva_1981@postgrespro.ru", "phone": "+70649297283"}
0005433846481	C53F32	7287 602261	NIKOLAY KRASNOV	{"phone": "+70166078932"}
0005433846482	73D48C	0529 695076	LIDIYA GORBUNOVA	{"phone": "+70430214174"}
0005433846483	6EEB93	1999 681820	SERGEY FROLOV	{"phone": "+70374401784"}
0005433846484	255EE5	4612 099485	TATYANA PAVLOVA	{"email": "pavlovat.12081975@postgrespro.ru", "phone": "+70371055707"}
0005433846485	405992	0107 618384	ARTEM BORISOV	{"email": "a_borisov_05071967@postgrespro.ru", "phone": "+70785852859"}
0005433846486	000F74	2731 202399	NIKOLAY ISAEV	{"email": "nisaev12091965@postgrespro.ru", "phone": "+70740370257"}
0005433846487	320695	8524 234165	LYUDMILA ZHURAVLEVA	{"phone": "+70785727054"}
0005433846488	CFA067	3926 461453	ANNA FROLOVA	{"email": "a_frolova_031964@postgrespro.ru", "phone": "+70294093222"}
0005433846489	CFA067	2651 609275	IRINA NIKOLAEVA	{"phone": "+70415536797"}
0005433846490	C3A27C	7519 977491	MAKSIM FEDOROV	{"phone": "+70901977388"}
0005433846491	48A8E8	4674 631933	OLGA FROLOVA	{"phone": "+70273006634"}
0005433846492	56EA26	5827 210685	IRINA ERMAKOVA	{"email": "irina.ermakova_1978@postgrespro.ru", "phone": "+70940649506"}
0005433846493	EDA99B	5446 107092	NADEZHDA ISAEVA	{"phone": "+70979173696"}
0005433846494	F23245	3877 082477	VALENTINA TITOVA	{"phone": "+70959278261"}
0005433846495	482039	9486 381050	ALEKSANDR VOROBEV	{"phone": "+70316978887"}
0005433846496	B16212	3551 212915	NIKOLAY GAVRILOV	{"phone": "+70421981668"}
0005433846497	334991	3402 726666	VALENTINA ALEKSANDROVA	{"phone": "+70141470742"}
0005433846498	334991	0684 345865	DMITRIY KUZMIN	{"email": "d-kuzmin.01021973@postgrespro.ru", "phone": "+70265555927"}
0005433846499	9C275A	5831 274107	MIKHAIL GUSEV	{"phone": "+70051798032"}
0005433846500	9BFB04	1565 206441	IRINA SIDOROVA	{"phone": "+70512134429"}
0005433846501	1BB43E	0552 926510	PAVEL ANTONOV	{"email": "antonov_pavel041970@postgrespro.ru", "phone": "+70541132198"}
0005433846502	1BB43E	0102 403722	VLADIMIR ZAKHAROV	{"email": "v.zakharov.15091968@postgrespro.ru", "phone": "+70258402861"}
0005433846503	A20D0E	8196 870791	TATYANA BORISOVA	{"email": "t-borisova_25081971@postgrespro.ru", "phone": "+70815458247"}
0005433846504	4C8FC5	0605 226564	LYUBOV DANILOVA	{"email": "lyubov_danilova.11121968@postgrespro.ru", "phone": "+70216214253"}
0005433846505	1A256F	9781 457453	YURIY DENISOV	{"phone": "+70632968044"}
0005433846506	1A256F	5913 948437	NADEZHDA FILATOVA	{"phone": "+70569620118"}
0005433846507	7C1F4A	1776 923363	SERGEY DMITRIEV	{"phone": "+70974231614"}
0005433846508	6967B4	7785 521702	GALINA DAVYDOVA	{"email": "davydova_g_071972@postgrespro.ru", "phone": "+70542496081"}
0005433846509	EDDE9F	0040 351435	NIKOLAY ROMANOV	{"phone": "+70176160521"}
0005433846510	1CAFFD	8933 800267	VLADIMIR STEPANOV	{"email": "vstepanov.01101978@postgrespro.ru", "phone": "+70023367714"}
0005433846511	0F9532	6928 924120	ANDREY IVANOV	{"phone": "+70142819359"}
0005433846512	0F9532	4812 617953	PAVEL NAZAROV	{"email": "nazarov-pavel1974@postgrespro.ru", "phone": "+70079599212"}
0005433846513	0F9532	4869 564809	NATALYA KULIKOVA	{"email": "natalya_kulikova16101987@postgrespro.ru", "phone": "+70040092033"}
0005433846514	436E91	6755 658985	OLEG VOLKOV	{"email": "ovolkov.07041968@postgrespro.ru", "phone": "+70174219248"}
0005433846515	10562E	2553 308009	LIDIYA RODIONOVA	{"email": "rodionova_lidiya-19061980@postgrespro.ru", "phone": "+70823467176"}
0005433846516	6AD2E2	8137 349876	STANISLAV MEDVEDEV	{"phone": "+70307720568"}
0005433846517	4BD895	4546 432601	ANATOLIY MEDVEDEV	{"email": "a_medvedev_28051975@postgrespro.ru", "phone": "+70188211254"}
0005433846518	4BD895	5564 715168	IRINA ZAYCEVA	{"phone": "+70820531792"}
0005433846519	84FC82	4044 841936	EVGENIY DAVYDOV	{"phone": "+70121227077"}
0005433846520	84FC82	1489 936219	RIMA FILIPPOVA	{"email": "filippova-r-06041973@postgrespro.ru", "phone": "+70988093193"}
0005433846521	E7344F	5433 462413	TATYANA YAKOVLEVA	{"phone": "+70547002423"}
0005433846522	D77DA1	8840 916293	OLGA VASILEVA	{"phone": "+70452145551"}
0005433846523	BFDF04	7341 140177	ANTONINA ANDREEVA	{"email": "andreeva.antonina.071972@postgrespro.ru", "phone": "+70800687293"}
0005433846524	A0CBD0	8399 546091	IVAN SIDOROV	{"phone": "+70117636903"}
0005433846525	800227	9828 186341	DMITRIY POPOV	{"email": "dmitriy.popov.031972@postgrespro.ru", "phone": "+70042936297"}
0005433846526	28A793	6665 266286	ANDREY KARPOV	{"phone": "+70737600818"}
0005433846527	EB8B04	9329 422828	YAN KUZNECOV	{"phone": "+70577397814"}
0005433846528	EB8B04	6473 720876	SERGEY BORISOV	{"phone": "+70145746663"}
0005433846529	C6D9F7	9805 820023	KLAVDIYA SEMENOVA	{"email": "semenova.klavdiya_17071975@postgrespro.ru", "phone": "+70433056161"}
0005433846530	9FBB43	0202 581384	VALERIY DAVYDOV	{"phone": "+70869434568"}
0005433846531	9FBB43	8354 186618	ROMAN OSIPOV	{"phone": "+70889830016"}
0005433846532	B541F3	4926 795778	ANATOLIY GAVRILOV	{"email": "gavrilov-a30041975@postgrespro.ru", "phone": "+70710917180"}
0005433846533	B541F3	6292 088042	ALEKSANDR DMITRIEV	{"email": "admitriev1964@postgrespro.ru", "phone": "+70339884983"}
0005433846534	8D0E6B	6426 117647	MARIYA MIKHAYLOVA	{"email": "mikhaylova.m051968@postgrespro.ru", "phone": "+70531099364"}
0005433846535	790745	8353 639518	SERGEY SMIRNOV	{"phone": "+70778330399"}
0005433846536	348C17	4427 755704	ANASTASIYA ZAKHAROVA	{"phone": "+70107452810"}
0005433846537	348C17	4948 232826	ALSU IVANOVA	{"email": "ivanovaalsu-021977@postgrespro.ru", "phone": "+70114757114"}
0005433846538	2908EE	7481 673180	VIKTOR FROLOV	{"email": "frolov-v-031981@postgrespro.ru", "phone": "+70923591612"}
0005433846539	1DA265	3751 684811	OLGA KONOVALOVA	{"email": "konovalova.olga-07011970@postgrespro.ru", "phone": "+70701186460"}
0005433846540	F09A7B	2350 703016	FILIPP SERGEEV	{"phone": "+70907628251"}
0005433846541	2F6105	3159 428623	LYUDMILA ILINA	{"email": "ilinal091982@postgrespro.ru", "phone": "+70050238708"}
0005433846542	2F6105	6062 987008	IRINA IVANOVA	{"phone": "+70440524955"}
0005433846543	716B56	3168 166626	NIKOLAY ABRAMOV	{"email": "n-abramov_18031968@postgrespro.ru", "phone": "+70140977713"}
0005433846544	716B56	2650 897657	YULIYA NIKOLAEVA	{"email": "y.nikolaeva-07011969@postgrespro.ru", "phone": "+70843414941"}
0005433846545	CE9D06	2193 321633	NINA OSIPOVA	{"email": "osipovanina_1976@postgrespro.ru", "phone": "+70428914530"}
0005433846546	17F738	5092 513288	ALEKSANDR KONOVALOV	{"phone": "+70549154734"}
0005433846547	17F738	3568 919838	VALERIY GERASIMOV	{"phone": "+70667604707"}
0005433846548	17F738	3017 126490	ALISA STEPANOVA	{"phone": "+70868187791"}
0005433846549	4A920B	3993 128049	GALINA SMIRNOVA	{"phone": "+70816672343"}
0005433846550	B2F590	5154 143676	EVGENIY KUZMIN	{"email": "evgeniy.kuzmin08071977@postgrespro.ru", "phone": "+70807785768"}
0005433846551	B2F590	5997 281807	IRINA KOROLEVA	{"email": "koroleva_i_1967@postgrespro.ru", "phone": "+70973772969"}
0005433846552	B2F590	7239 756284	OKSANA ZAYCEVA	{"phone": "+70847576883"}
0005433846553	1BF07D	0949 442324	NIKOLAY DENISOV	{"phone": "+70088586581"}
0005433846554	1BF07D	1410 447082	EKATERINA GUSEVA	{"phone": "+70211658938"}
0005433846555	C80E52	0045 147262	VLADIMIR GAVRILOV	{"email": "vladimir-gavrilov-13121963@postgrespro.ru", "phone": "+70425877203"}
0005433846556	C80E52	6032 128950	ANASTASIYA MELNIKOVA	{"phone": "+70018832454"}
0005433846557	FEEF5E	5460 044854	DMITRIY PAVLOV	{"email": "pavlov.dmitriy_121968@postgrespro.ru", "phone": "+70794415238"}
0005433846558	97F609	6960 333468	INNA BELYAEVA	{"email": "belyaeva-i-01081964@postgrespro.ru", "phone": "+70209659867"}
0005433846559	97F609	3136 365439	ELENA NESTEROVA	{"email": "nesterova.elena-121975@postgrespro.ru", "phone": "+70317741154"}
0005433846560	3DACFC	8675 475932	NIKOLAY POPOV	{"phone": "+70778851758"}
0005433846561	177366	6283 642827	EDUARD IVANOV	{"email": "ivanov-eduard.1970@postgrespro.ru", "phone": "+70375392628"}
0005433846562	177366	8791 909475	EKATERINA MASLOVA	{"email": "maslova.e021976@postgrespro.ru", "phone": "+70229757157"}
0005433846563	898801	4612 955395	IRINA POPOVA	{"email": "irinapopova071973@postgrespro.ru", "phone": "+70320302473"}
0005433846564	898801	6033 738081	RAFIK FROLOV	{"email": "frolov.r.24031967@postgrespro.ru", "phone": "+70852456947"}
0005433846565	898801	2503 400631	MARINA DANILOVA	{"phone": "+70936691990"}
0005433846566	937698	5840 072405	LYUDMILA MAKSIMOVA	{"email": "l_maksimova18121972@postgrespro.ru", "phone": "+70275116503"}
0005433846567	937698	4374 372601	NATALYA VASILEVA	{"phone": "+70357900786"}
0005433846568	2D6BFC	0230 814300	ALEKSANDR VOLKOV	{"phone": "+70428312268"}
0005433846569	407D68	0918 213785	DANIL KOROLEV	{"phone": "+70432616354"}
0005433846570	C99E8C	7199 464852	TATYANA POPOVA	{"phone": "+70023046614"}
0005433846571	C99E8C	8614 724910	NIKOLAY TIMOFEEV	{"phone": "+70700797792"}
0005433846572	C99E8C	5023 234316	KONSTANTIN VOROBEV	{"email": "vorobevk13111980@postgrespro.ru", "phone": "+70145794085"}
0005433846573	018C66	3450 916247	MARIYA DANILOVA	{"email": "mariya-danilova.1966@postgrespro.ru", "phone": "+70924448458"}
0005433846574	2C2C5E	2103 276771	TIMUR FROLOV	{"email": "frolovtimur-031979@postgrespro.ru", "phone": "+70771970223"}
0005433846575	F81BE5	4649 954946	LYUDMILA DENISOVA	{"phone": "+70859116544"}
0005433846576	9C7EC0	2602 639094	IVAN GERASIMOV	{"email": "igerasimov1983@postgrespro.ru", "phone": "+70009599157"}
0005433846577	C309CC	3091 029677	MIKHAIL KUZMIN	{"email": "mikhailkuzmin_1969@postgrespro.ru", "phone": "+70617970190"}
0005433846578	562E61	7919 440198	DANILA ZAKHAROV	{"email": "dzakharov-041983@postgrespro.ru", "phone": "+70170939002"}
0005433846579	562E61	6544 098139	LARISA PAVLOVA	{"email": "pavlova_l03051965@postgrespro.ru", "phone": "+70788526490"}
0005433846580	562E61	8351 101325	BOGDAN KRASNOV	{"email": "krasnovb.24121961@postgrespro.ru", "phone": "+70207681927"}
0005433846581	2BFB19	3069 831916	SERGEY GORBUNOV	{"phone": "+70877554089"}
0005433846582	50C06A	3123 480622	NINA KOZLOVA	{"email": "kozlovanina_1964@postgrespro.ru", "phone": "+70713972796"}
0005433846583	333391	2402 439714	OLEG NIKITIN	{"phone": "+70663576162"}
0005433846584	83C824	2582 643125	SERGEY MEDVEDEV	{"phone": "+70504364813"}
0005433846585	83C824	4435 311041	ALEKSEY IVANOV	{"email": "a_ivanov.15061970@postgrespro.ru", "phone": "+70529228903"}
0005433846586	3EF45C	4836 549013	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova.a.05121980@postgrespro.ru", "phone": "+70403857624"}
0005433846587	6BE6DD	5757 221556	GENNADIY ABRAMOV	{"phone": "+70746582823"}
0005433846588	42CE59	6015 574812	NIKITA GERASIMOV	{"email": "nikitagerasimov.04111967@postgrespro.ru", "phone": "+70922920175"}
0005433846589	42CE59	9005 686795	MAKSIM ILIN	{"email": "ilinm_13051976@postgrespro.ru", "phone": "+70460113467"}
0005433846590	42CE59	8947 393258	DENIS STEPANOV	{"email": "stepanov.d1971@postgrespro.ru", "phone": "+70513114322"}
0005433846591	65B195	3583 421090	SVETLANA SAVELEVA	{"email": "saveleva_svetlana-041977@postgrespro.ru", "phone": "+70521573757"}
0005433846592	AFFC8B	2939 053881	ILNAR IVANOV	{"email": "ivanovi20031977@postgrespro.ru", "phone": "+70155187690"}
0005433846593	EB941F	4886 553139	RINAT FILIPPOV	{"email": "filippov_rinat.14011964@postgrespro.ru", "phone": "+70195788336"}
0005433846594	1646C9	5483 159196	PETR ZAKHAROV	{"email": "zakharov.petr_1974@postgrespro.ru", "phone": "+70491482918"}
0005433846595	1646C9	3563 359408	TATYANA ILINA	{"email": "t_ilina_111961@postgrespro.ru", "phone": "+70928475722"}
0005433846596	03380C	3099 969584	SVETLANA PETROVA	{"phone": "+70176926188"}
0005433846597	5DB261	6681 637383	SERGEY VOLKOV	{"email": "svolkov-1981@postgrespro.ru", "phone": "+70188753472"}
0005433846598	CC9DF5	2456 121088	SERGEY PETROV	{"phone": "+70103948144"}
0005433846599	CC9DF5	0611 078335	LIDIYA ZHURAVLEVA	{"email": "zhuravleval.1977@postgrespro.ru", "phone": "+70369082470"}
0005433846600	89343E	4095 613871	YULIYA GERASIMOVA	{"email": "y-gerasimova.091980@postgrespro.ru", "phone": "+70212680783"}
0005433846601	BE3DFA	5244 799673	MAKSIM NAZAROV	{"email": "nazarov-m1966@postgrespro.ru", "phone": "+70704079620"}
0005433846602	F55E83	1821 675692	MAKSIM POPOV	{"phone": "+70265770478"}
0005433846603	E6659C	1144 164166	MAKSIM TIMOFEEV	{"email": "maksim_timofeev_1980@postgrespro.ru", "phone": "+70364670898"}
0005433846604	48550A	4300 422320	IRINA MAKAROVA	{"email": "makarova.i_051983@postgrespro.ru", "phone": "+70456439294"}
0005433846605	005355	1908 857127	DMITRIY FEDOTOV	{"phone": "+70047143340"}
0005433846606	5307E5	2975 604804	VALENTINA MIKHAYLOVA	{"phone": "+70719306245"}
0005433846607	05DC9F	9050 862294	ALEKSANDR DAVYDOV	{"phone": "+70495223543"}
0005433846608	05DC9F	7470 169545	ALEKSEY TIMOFEEV	{"phone": "+70977464769"}
0005433846609	E6981B	8908 625397	VALERIY IVANOV	{"email": "ivanov_valeriy.13031978@postgrespro.ru", "phone": "+70320973582"}
0005433846610	18039D	8812 276935	TAISA ILINA	{"email": "ilina_taisa_111961@postgrespro.ru", "phone": "+70321479499"}
0005433846611	50267A	8370 864015	GALINA LEBEDEVA	{"email": "lebedeva_g-17101980@postgrespro.ru", "phone": "+70165063792"}
0005433846612	342B29	5485 736828	ALEKSANDR ABRAMOV	{"phone": "+70887885031"}
0005433846613	342B29	4195 110706	LARISA BELOVA	{"phone": "+70048848293"}
0005433846614	342B29	7375 664015	NINA KUDRYASHOVA	{"phone": "+70798722978"}
0005433846615	4F2B98	8185 553526	ILYA TIMOFEEV	{"phone": "+70000777329"}
0005433846616	B0B342	4720 104349	ELENA SOROKINA	{"email": "elenasorokina.1979@postgrespro.ru", "phone": "+70689306016"}
0005433846617	639A59	8344 587512	OLGA MIKHAYLOVA	{"phone": "+70555960486"}
0005433846618	639A59	8114 099548	VALENTINA POPOVA	{"email": "v_popova-061974@postgrespro.ru", "phone": "+70518758006"}
0005433846619	CFF8ED	7357 728587	DMITRIY NOVIKOV	{"phone": "+70296807488"}
0005433846620	74261E	2796 895060	VIKTORIYA VASILEVA	{"phone": "+70741247454"}
0005433846621	F6D16B	0785 952817	RODION SOROKIN	{"phone": "+70287602577"}
0005433846622	36CD17	6386 924289	KONSTANTIN KUZNECOV	{"phone": "+70184399012"}
0005433846623	D3FA09	6396 607697	LIDIYA YAKOVLEVA	{"email": "yakovlevalidiya101975@postgrespro.ru", "phone": "+70320621898"}
0005433846624	BD397E	8125 777381	ALEKSANDR BELOV	{"email": "belovaleksandr-1976@postgrespro.ru", "phone": "+70135726874"}
0005433846625	BD397E	9749 347221	NATALYA PETROVA	{"email": "natalya.petrova-111972@postgrespro.ru", "phone": "+70701096241"}
0005433846626	571A79	6910 834947	ALEKSANDR BONDARENKO	{"email": "bondarenko.a_03071978@postgrespro.ru", "phone": "+70020936569"}
0005433846627	571A79	7864 493097	ALEKSANDR SMIRNOV	{"phone": "+70516274509"}
0005433846628	D62550	8903 433163	BOGDAN VOLKOV	{"email": "bogdan.volkov1959@postgrespro.ru", "phone": "+70863998209"}
0005433846629	43163E	8058 249862	ALEKSANDR PETROV	{"phone": "+70575156140"}
0005433846630	8B60D7	5755 674230	ANATOLIY ALEKSEEV	{"email": "aalekseev-051989@postgrespro.ru", "phone": "+70952210422"}
0005433846631	94A022	0762 149375	YULIYA KOLESNIKOVA	{"email": "y-kolesnikova07061983@postgrespro.ru", "phone": "+70260604804"}
0005433846632	4E92F4	7789 108529	MIKHAIL RODIONOV	{"email": "mikhail.rodionov111979@postgrespro.ru", "phone": "+70010353664"}
0005433846633	AB50C1	6437 266853	RAMIL SOKOLOV	{"phone": "+70631249988"}
0005433846694	FA7188	6725 460064	VIKTOR NIKOLAEV	{"phone": "+70923694104"}
0005433846634	3C5FAD	5297 599846	TATYANA MALYSHEVA	{"email": "malysheva_t_31101980@postgrespro.ru", "phone": "+70497840130"}
0005433846635	3C5FAD	2761 402289	PETR MOISEEV	{"phone": "+70820377660"}
0005433846636	EFA40A	4527 270954	ANASTASIYA GERASIMOVA	{"email": "gerasimova-anastasiya_30061971@postgrespro.ru", "phone": "+70920132447"}
0005433846637	95786F	1122 106370	VIKTOR SAVELEV	{"email": "viktor-savelev-1969@postgrespro.ru", "phone": "+70460391883"}
0005433846638	B252A5	6317 128914	ANNA NOVIKOVA	{"email": "anna_novikova121980@postgrespro.ru", "phone": "+70674584364"}
0005433846639	F14F90	5391 626826	MARIYA ANTONOVA	{"email": "m.antonova-1966@postgrespro.ru", "phone": "+70510732171"}
0005433846640	F14F90	2727 672484	OLGA NIKOLAEVA	{"phone": "+70045034071"}
0005433846641	AECF01	9651 225804	ALEKSANDR KAZAKOV	{"phone": "+70723090674"}
0005433846642	AECF01	7868 748354	LARISA ABRAMOVA	{"email": "abramovalarisa_26011978@postgrespro.ru", "phone": "+70464527960"}
0005433846643	1606E2	0213 693990	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr-101963@postgrespro.ru", "phone": "+70336154619"}
0005433846644	1606E2	2921 035537	SERGEY VASILEV	{"phone": "+70242947278"}
0005433846645	195587	5644 550341	MIKHAIL SMIRNOV	{"email": "msmirnov1974@postgrespro.ru", "phone": "+70512784609"}
0005433846646	195587	2508 500084	IRINA KAZAKOVA	{"email": "ikazakova_01041980@postgrespro.ru", "phone": "+70665794395"}
0005433846647	5DFDAC	9138 277799	TAMARA FEDOROVA	{"phone": "+70717969562"}
0005433846648	5DFDAC	0669 877459	SERGEY IVANOV	{"phone": "+70828013486"}
0005433846649	305C05	8305 736696	VALENTINA NIKIFOROVA	{"phone": "+70872836859"}
0005433846650	2CF7D2	3271 615971	OLGA NAZAROVA	{"phone": "+70705454622"}
0005433846651	4A61B2	7794 326713	MARIYA IVANOVA	{"email": "mariya_ivanova05051966@postgrespro.ru", "phone": "+70254146713"}
0005433846652	38FF3D	1492 774824	ALEKSEY POPOV	{"phone": "+70704890363"}
0005433846653	A154B0	2362 970750	RUDOLF ORLOV	{"phone": "+70686810534"}
0005433846654	85DA0E	3711 811692	ALEKSANDR NOVIKOV	{"email": "a-novikov_21021972@postgrespro.ru", "phone": "+70982384969"}
0005433846655	606219	7188 056288	VLADIMIR VOROBEV	{"email": "vladimir_vorobev-1969@postgrespro.ru", "phone": "+70184188272"}
0005433846656	22BDBB	4944 875674	ARTUR KONOVALOV	{"email": "konovalov-a.021981@postgrespro.ru", "phone": "+70500515266"}
0005433846657	99B4D7	0378 887050	ALEKSANDRA IVANOVA	{"email": "a-ivanova.15011976@postgrespro.ru", "phone": "+70469858990"}
0005433846658	E9320A	8283 359504	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova091977@postgrespro.ru", "phone": "+70498583650"}
0005433846659	2A487A	4631 637510	ALEKSANDR CHERNOV	{"phone": "+70594021142"}
0005433846660	2A487A	5784 323085	MARGARITA POPOVA	{"phone": "+70371020222"}
0005433846661	9D330C	9638 687227	IGOR KOZLOV	{"phone": "+70869120076"}
0005433846662	9D330C	5425 441505	NIKOLAY POPOV	{"email": "n-popov_021971@postgrespro.ru", "phone": "+70151145134"}
0005433846663	9D330C	7312 039619	TAMARA ZAYCEVA	{"email": "zayceva_tamara07071968@postgrespro.ru", "phone": "+70087115528"}
0005433846664	B6779C	4137 340686	VIKTOR MAKSIMOV	{"phone": "+70796535660"}
0005433846665	F4662B	4476 684258	VASILIY SAVELEV	{"email": "savelev.vasiliy.03111975@postgrespro.ru", "phone": "+70209673681"}
0005433846666	F4662B	8921 630638	SERGEY RODIONOV	{"email": "sergey-rodionov_18021975@postgrespro.ru", "phone": "+70329251159"}
0005433846667	2891FF	3093 323850	ANASTASIYA AFANASEVA	{"phone": "+70052011691"}
0005433846668	2891FF	1455 373772	ELENA FILIPPOVA	{"email": "elena-filippova_27091973@postgrespro.ru", "phone": "+70380853320"}
0005433846669	2891FF	8071 717898	ANNA KRASNOVA	{"email": "krasnova.anna_11111972@postgrespro.ru", "phone": "+70421594732"}
0005433846670	F394CE	6706 765041	OLGA ZAYCEVA	{"phone": "+70612534187"}
0005433846671	4F3053	4584 809243	NADEZHDA TIMOFEEVA	{"phone": "+70650114110"}
0005433846672	4F3053	7215 012023	ALEKSEY KUZNECOV	{"email": "kuznecov_a_15121967@postgrespro.ru", "phone": "+70258336240"}
0005433846673	3FEC0A	3800 747985	NIKITA MIRONOV	{"phone": "+70427949397"}
0005433846674	3FEC0A	4449 475271	TATYANA LEBEDEVA	{"email": "lebedeva_tatyana_041981@postgrespro.ru", "phone": "+70778860369"}
0005433846675	3FEC0A	5167 753069	IRINA POPOVA	{"phone": "+70951874730"}
0005433846676	5BDBE3	3273 645653	ALEKSANDRA POPOVA	{"email": "apopova-26051981@postgrespro.ru", "phone": "+70417976717"}
0005433846677	DBD72F	4286 788352	NIKOLAY SOKOLOV	{"email": "sokolov_n_1970@postgrespro.ru", "phone": "+70363789528"}
0005433846678	DA53F6	8045 924266	VLADIMIR KUDRYASHOV	{"email": "kudryashov-vladimir.1978@postgrespro.ru", "phone": "+70592161328"}
0005433846679	DA53F6	5966 756951	VLADIMIR AFANASEV	{"phone": "+70321730765"}
0005433846680	CFB43E	7055 884345	SERGEY IVANOV	{"phone": "+70204524704"}
0005433846681	CFB43E	8716 615512	ANNA TIKHONOVA	{"email": "anna_tikhonova.13121964@postgrespro.ru", "phone": "+70331123214"}
0005433846682	59367B	3441 439487	ALEKSEY VOROBEV	{"email": "vorobev_aleksey041965@postgrespro.ru", "phone": "+70733585937"}
0005433846683	811B88	3532 291791	YULIYA SOLOVEVA	{"email": "solovevay_1966@postgrespro.ru", "phone": "+70427130213"}
0005433846684	811B88	8865 847989	EKATERINA NAZAROVA	{"phone": "+70502166773"}
0005433846685	DA8F63	8893 853313	VALENTINA KOLESNIKOVA	{"phone": "+70836444529"}
0005433846686	DA8F63	8782 956128	MARAT AFANASEV	{"phone": "+70181863707"}
0005433846687	C80F44	5685 262463	RAISA KUZMINA	{"email": "kuzmina-r_16061966@postgrespro.ru", "phone": "+70600869312"}
0005433846688	C13FF2	3908 098376	MARIYA PETROVA	{"phone": "+70533146050"}
0005433846689	1DDB7F	4529 859343	YURIY VOROBEV	{"phone": "+70461626157"}
0005433846690	1DDB7F	2958 532111	VALENTINA FROLOVA	{"phone": "+70624646067"}
0005433846691	B26DCB	9786 427897	TATYANA STEPANOVA	{"phone": "+70034950099"}
0005433846692	B421B9	6927 562711	ALEKSANDR ZAYCEV	{"email": "zaycev.aleksandr031978@postgrespro.ru", "phone": "+70103945608"}
0005433846693	FA7188	4075 410492	VYACHESLAV NAZAROV	{"phone": "+70744251151"}
0005433846695	8B7FF9	7141 256525	LIDIYA MOISEEVA	{"phone": "+70770405892"}
0005433846696	9164AD	9201 084882	EKATERINA MIRONOVA	{"email": "ekaterina-mironova1982@postgrespro.ru", "phone": "+70672488726"}
0005433846697	9164AD	8151 373720	YURIY BORISOV	{"email": "y_borisov.121981@postgrespro.ru", "phone": "+70335359831"}
0005433846698	2D815C	4053 367221	MARINA KONDRATEVA	{"email": "kondrateva_m-24051970@postgrespro.ru", "phone": "+70379907403"}
0005433846699	E64295	3809 560747	OLGA KOROLEVA	{"email": "koroleva_o_13051973@postgrespro.ru", "phone": "+70406973961"}
0005433846700	E64295	6403 142745	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov.091981@postgrespro.ru", "phone": "+70101083304"}
0005433846701	21238F	1990 415453	LYUDMILA FEDOROVA	{"email": "fedorova-l13021968@postgrespro.ru", "phone": "+70829464626"}
0005433846702	E2CDFB	9044 022454	NATALIYA ANDREEVA	{"email": "nataliyaandreeva_061969@postgrespro.ru", "phone": "+70238016395"}
0005433846703	586BC5	5243 473646	LYUBOV ZOTOVA	{"phone": "+70405536745"}
0005433846704	77AF5A	4414 020377	ELENA VOLKOVA	{"phone": "+70898035089"}
0005433846705	6FB75B	1556 864102	ELVIRA IVANOVA	{"phone": "+70965458078"}
0005433846706	6FB75B	2080 892195	EVGENIY ANDREEV	{"phone": "+70170773230"}
0005433846707	69AE10	8736 528740	SVETLANA STEPANOVA	{"email": "sstepanova.071971@postgrespro.ru", "phone": "+70276816607"}
0005433846708	A1FBFA	1242 700225	IGOR SERGEEV	{"email": "igor-sergeev-12011971@postgrespro.ru", "phone": "+70969315741"}
0005433846709	A1FBFA	5114 127309	DMITRIY ZAKHAROV	{"phone": "+70258767691"}
0005433846710	A1FBFA	2071 629053	NINA EFIMOVA	{"email": "n-efimova07081975@postgrespro.ru", "phone": "+70985194834"}
0005433846711	D49184	4167 140620	OLGA GERASIMOVA	{"phone": "+70552153458"}
0005433846712	51C361	6301 316064	VLADIMIR SIDOROV	{"phone": "+70107176557"}
0005433846713	51C361	5292 304148	ALEKSANDR KUZNECOV	{"phone": "+70536957230"}
0005433846714	A2D885	2493 423300	RENAT TIMOFEEV	{"email": "timofeev-r_1972@postgrespro.ru", "phone": "+70005851883"}
0005433846715	A2D885	4904 033686	ALEKSANDRA NESTEROVA	{"email": "nesterovaa.101977@postgrespro.ru", "phone": "+70329819139"}
0005433846716	24516E	3258 117141	ELENA SEMENOVA	{"phone": "+70393313795"}
0005433846717	6CBCF2	8993 132625	LEV SERGEEV	{"phone": "+70152217518"}
0005433846718	6EF60B	8200 869551	EKATERINA NOVIKOVA	{"email": "novikova.e021968@postgrespro.ru", "phone": "+70093808852"}
0005433846719	54A6D3	3640 300319	OKSANA KUZNECOVA	{"phone": "+70424108087"}
0005433846720	54A6D3	6154 518430	SERGEY ROMANOV	{"email": "romanov-sergey.051966@postgrespro.ru", "phone": "+70387658834"}
0005433846721	283E43	3416 406002	MARIYA KULIKOVA	{"email": "kulikova.m_1978@postgrespro.ru", "phone": "+70224338365"}
0005433846722	8EBD24	1783 777897	NIKITA ANTONOV	{"phone": "+70165858937"}
0005433846723	E18F75	8609 347794	BORIS ALEKSANDROV	{"email": "aleksandrovb1977@postgrespro.ru", "phone": "+70191813160"}
0005433846724	2B649E	1074 509513	ALEKSANDR ZAYCEV	{"email": "a-zaycev-1984@postgrespro.ru", "phone": "+70935070491"}
0005433846725	0D1807	4293 413318	VALERIYA RODIONOVA	{"email": "valeriya-rodionova.1975@postgrespro.ru", "phone": "+70553086496"}
0005433846726	0D1807	7713 788101	ALMIRA ZHUKOVA	{"phone": "+70689354917"}
0005433846727	0D1807	1534 036713	NATALYA EFREMOVA	{"email": "n.efremova-011961@postgrespro.ru", "phone": "+70561821740"}
0005433846728	85EA6D	7344 097752	YURIY DENISOV	{"email": "yuriy-denisov031980@postgrespro.ru", "phone": "+70946906978"}
0005433846729	A50096	7963 513541	ELENA ANDREEVA	{"phone": "+70210341045"}
0005433846730	AC9A97	8719 741286	YULIYA VOROBEVA	{"email": "vorobeva-yuliya1970@postgrespro.ru", "phone": "+70290617093"}
0005433846731	D37E87	1577 531452	NINA KUZNECOVA	{"email": "kuznecova.n_011977@postgrespro.ru", "phone": "+70493238252"}
0005433846732	9E5FA9	4563 931661	EVGENIY SAVELEV	{"phone": "+70456598013"}
0005433846733	499451	2058 520235	IGOR SMIRNOV	{"email": "smirnov-igor.1970@postgrespro.ru", "phone": "+70314680854"}
0005433846734	85987B	9937 594923	SVETLANA KOROLEVA	{"phone": "+70612343627"}
0005433846735	AE423D	1601 984122	IRINA IVANOVA	{"phone": "+70999937042"}
0005433846736	7E8B69	5789 256823	ALBERT PAVLOV	{"phone": "+70159932485"}
0005433846737	318F9D	5940 164976	NATALIYA IVANOVA	{"email": "ivanova_n29101962@postgrespro.ru", "phone": "+70371531154"}
0005433846738	22FA91	6645 710877	PAVEL FEDOROV	{"phone": "+70890632292"}
0005433846739	30D4D3	6872 073723	OLGA GERASIMOVA	{"email": "gerasimova_olga-25121977@postgrespro.ru", "phone": "+70936660665"}
0005433846740	30D4D3	3460 426110	LIDIYA SIDOROVA	{"phone": "+70833042897"}
0005433846741	097848	3175 357108	DMITRIY FEDOTOV	{"phone": "+70872927606"}
0005433846742	88F0C2	8126 627628	VYACHESLAV MIRONOV	{"email": "v-mironov1960@postgrespro.ru", "phone": "+70649929828"}
0005433846743	8ADB40	2331 826850	DANIIL POPOV	{"email": "d.popov.1977@postgrespro.ru", "phone": "+70160726612"}
0005433846744	8ADB40	4973 529824	TATYANA TARASOVA	{"email": "tarasova_t-1966@postgrespro.ru", "phone": "+70716304763"}
0005433846745	1D3EBC	9019 251021	KARINA EGOROVA	{"email": "egorova.k01061968@postgrespro.ru", "phone": "+70012188096"}
0005433846746	BEB881	3797 290060	ELIZAVETA SMIRNOVA	{"phone": "+70798860527"}
0005433846747	BEB881	7586 085076	OLGA KALININA	{"phone": "+70983251091"}
0005433846748	7FD0A1	8658 392191	YURIY KAZAKOV	{"phone": "+70640994990"}
0005433846749	BF8AB5	3273 678413	LARISA NIKIFOROVA	{"phone": "+70266061397"}
0005433846750	A4EC06	1192 792019	ANASTASIYA KALININA	{"phone": "+70411786291"}
0005433846751	726A0E	4189 065469	MARIYA ERMAKOVA	{"phone": "+70354420063"}
0005433846752	D362D7	3752 007723	GAGIK SEMENOV	{"phone": "+70682655946"}
0005433846753	A299B4	9945 148103	ALEKSEY PAVLOV	{"phone": "+70021266657"}
0005433846754	4D7CD4	3884 750979	ELEONORA KUZNECOVA	{"phone": "+70333737718"}
0005433846755	01F80E	6462 126304	IVAN TARASOV	{"email": "tarasov-i-051965@postgrespro.ru", "phone": "+70751101187"}
0005433846756	4D2E08	1320 806491	IGOR SEMENOV	{"phone": "+70500855249"}
0005433846757	78D90D	6834 647654	ALEKSANDR GAVRILOV	{"phone": "+70268981870"}
0005433846758	78D90D	4689 976936	ALEKSANDR PETROV	{"email": "petrov.a.1972@postgrespro.ru", "phone": "+70524252265"}
0005433846759	474EF5	5218 895228	VASILIY SCHERBAKOV	{"phone": "+70007451477"}
0005433846760	474EF5	1037 984364	MIKHAIL PAVLOV	{"email": "mikhail_pavlov.111972@postgrespro.ru", "phone": "+70202525044"}
0005433846761	8CC472	8564 415392	ZOYA SOROKINA	{"email": "sorokina_zoya.15121973@postgrespro.ru", "phone": "+70369698066"}
0005433846762	8CC472	0158 588157	OLGA KALININA	{"phone": "+70429467556"}
0005433846763	40934A	9448 314718	DZHAMILYA YAKOVLEVA	{"email": "yakovleva.dzhamilya.1963@postgrespro.ru", "phone": "+70930454234"}
0005433846764	B451F2	0769 912337	TATYANA SCHERBAKOVA	{"phone": "+70749971715"}
0005433846765	C61B7F	6490 623438	ALEKSEY STEPANOV	{"email": "stepanov.a.091970@postgrespro.ru", "phone": "+70101129291"}
0005433846766	493741	0178 736916	LILIYA RYABOVA	{"email": "liliya_ryabova.11041975@postgrespro.ru", "phone": "+70481518876"}
0005433846767	3A3FCA	7916 520234	SVETLANA BOGDANOVA	{"email": "bogdanovasvetlana20071969@postgrespro.ru", "phone": "+70473412214"}
0005433846768	3A3FCA	1722 080802	ELENA KRASNOVA	{"email": "krasnovaelena.1974@postgrespro.ru", "phone": "+70189100546"}
0005433846769	B9BA5B	7823 024176	DENIS KONOVALOV	{"email": "konovalov_d08061965@postgrespro.ru", "phone": "+70980530046"}
0005433846770	41D5FC	8790 468335	DENIS EGOROV	{"phone": "+70544346928"}
0005433846771	6966DB	4563 931581	NATALYA STEPANOVA	{"email": "nstepanova_1966@postgrespro.ru", "phone": "+70288848218"}
0005433846772	05C2F1	3453 220877	YURIY ANDREEV	{"email": "andreev.yuriy-1973@postgrespro.ru", "phone": "+70583137853"}
0005433846773	E54D1F	4636 607977	VALENTINA ZAYCEVA	{"phone": "+70150454031"}
0005433846774	541170	9892 687832	SERGEY ZAKHAROV	{"phone": "+70844212312"}
0005433846775	541170	2605 808841	ALBINA ANTONOVA	{"phone": "+70792135488"}
0005433846776	95A05A	0470 065918	TATYANA TROFIMOVA	{"email": "trofimovat121972@postgrespro.ru", "phone": "+70601256841"}
0005433846777	95A05A	6714 221877	NATALYA SOKOLOVA	{"phone": "+70720355657"}
0005433846778	95A05A	7466 075156	SERGEY SHEVCHENKO	{"email": "shevchenko_s21071971@postgrespro.ru", "phone": "+70948845482"}
0005433846779	E516FB	9058 036438	SVETLANA ZHURAVLEVA	{"email": "s-zhuravleva.1973@postgrespro.ru", "phone": "+70817288891"}
0005433846780	E516FB	6155 327712	TATYANA SEMENOVA	{"phone": "+70519036773"}
0005433846781	A16DF9	6498 820534	VALERIY KUZNECOV	{"email": "v_kuznecov1962@postgrespro.ru", "phone": "+70584639511"}
0005433846782	A16DF9	2053 288409	MARINA ZHURAVLEVA	{"email": "zhuravleva.m081969@postgrespro.ru", "phone": "+70487717918"}
0005433846783	506A1B	5432 691541	NATALYA EFIMOVA	{"phone": "+70043541249"}
0005433846784	9E0BA7	1571 847375	KIRILL NAUMOV	{"phone": "+70419704744"}
0005433846785	9E0BA7	5251 979406	MARIYA NOVIKOVA	{"email": "novikova_m-021985@postgrespro.ru", "phone": "+70367048456"}
0005433846786	4A50F5	4216 992347	SAID KAZAKOV	{"phone": "+70098217765"}
0005433846787	4A50F5	5907 297786	ANDREY KONOVALOV	{"email": "a_konovalov1974@postgrespro.ru", "phone": "+70229807559"}
0005433846788	4A50F5	5482 911788	MARINA MAKAROVA	{"phone": "+70997889527"}
0005433846789	9323CA	4060 498173	IGOR IVANOV	{"email": "igor.ivanov1963@postgrespro.ru", "phone": "+70567543400"}
0005433846790	9323CA	4742 753068	ROMAN GERASIMOV	{"email": "gerasimov_r.1968@postgrespro.ru", "phone": "+70321379859"}
0005433846791	6B6B86	8860 064563	NIKOLAY VLASOV	{"email": "nvlasov-111976@postgrespro.ru", "phone": "+70652280707"}
0005433846792	8022BC	7794 128606	NATALIYA MIKHAYLOVA	{"phone": "+70654779477"}
0005433846793	8022BC	2127 302351	VIKTOR OSIPOV	{"email": "viktor.osipov.021964@postgrespro.ru", "phone": "+70635566979"}
0005433846794	E5DD68	4753 187737	DMITRIY MARTYNOV	{"email": "dmartynov29071969@postgrespro.ru", "phone": "+70730970476"}
0005433846795	BB1EEB	2111 076964	TATYANA SERGEEVA	{"email": "t_sergeeva06041978@postgrespro.ru", "phone": "+70865820417"}
0005433846796	B14290	7588 605961	GALINA STEPANOVA	{"email": "stepanova_g-121971@postgrespro.ru", "phone": "+70133621931"}
0005433846797	6E6945	2343 630336	SERGEY STEPANOV	{"phone": "+70416888256"}
0005433846798	D13CA8	9673 952441	TATYANA POPOVA	{"phone": "+70838347170"}
0005433846799	D13CA8	4117 763549	ANATOLIY KUZMIN	{"email": "kuzmin-a10021972@postgrespro.ru", "phone": "+70374015364"}
0005433846800	E86860	7967 384287	SERGEY ZAKHAROV	{"phone": "+70436612326"}
0005433846801	476CCD	5680 077443	SERGEY KOROLEV	{"phone": "+70312155085"}
0005433846802	F2D58D	7940 473226	YULIYA TIMOFEEVA	{"phone": "+70726092255"}
0005433846803	70B539	8234 982621	NATALYA KOLESNIKOVA	{"phone": "+70182239094"}
0005433846804	D3EDB3	4380 799792	ELENA DANILOVA	{"phone": "+70232003686"}
0005433846805	D9546C	4022 429876	DARINA KOZLOVA	{"email": "darina-kozlova_031969@postgrespro.ru", "phone": "+70637506251"}
0005433846806	585892	7901 328972	EVGENIY TARASOV	{"email": "e-tarasov051982@postgrespro.ru", "phone": "+70254894421"}
0005433846807	46AA07	4012 247343	LYUDMILA IVANOVA	{"phone": "+70029543705"}
0005433846808	6879BE	5950 679667	ARINA SEMENOVA	{"phone": "+70355634665"}
0005433846809	6C0DD0	3600 705302	RINAT NIKITIN	{"email": "nikitin.r111972@postgrespro.ru", "phone": "+70363100961"}
0005433846810	6C0DD0	1248 657676	IRINA BORISOVA	{"phone": "+70561894511"}
0005433846811	C97554	9284 281995	EVGENIY KUZMIN	{"email": "kuzmin-e.081962@postgrespro.ru", "phone": "+70761323735"}
0005433846812	EC3846	3457 220222	SVETLANA STEPANOVA	{"phone": "+70115440532"}
0005433846813	A38BD9	6266 134767	IRINA ANISIMOVA	{"phone": "+70444846373"}
0005433846814	1AB49D	4820 541789	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov_08091973@postgrespro.ru", "phone": "+70184506412"}
0005433846815	1AB49D	5100 246169	VADIM FEDOTOV	{"phone": "+70615732351"}
0005433846816	C96B69	4056 845847	VYACHESLAV KUZNECOV	{"phone": "+70364787225"}
0005433846817	C96B69	9070 724326	TAMARA KUZNECOVA	{"phone": "+70371907766"}
0005433846818	139BB4	1074 286673	VERA PAVLOVA	{"phone": "+70578103512"}
0005433846819	23DEC8	2675 364625	YAROSLAV YAKOVLEV	{"email": "yakovlev.yaroslav_121961@postgrespro.ru", "phone": "+70344733901"}
0005433846820	B72A83	8238 319127	ANASTASIYA ZAYCEVA	{"phone": "+70316938031"}
0005433846821	B72A83	5853 446443	ARTEM VOROBEV	{"email": "vorobev.a071977@postgrespro.ru", "phone": "+70976640563"}
0005433846822	D7D9F1	0707 222203	VALERIY GAVRILOV	{"phone": "+70900629022"}
0005433846823	022309	0637 873338	LYUDMILA DAVYDOVA	{"email": "davydova.lyudmila.1983@postgrespro.ru", "phone": "+70422108883"}
0005433846824	022309	2609 793632	YURIY FOMIN	{"email": "y.fomin_011972@postgrespro.ru", "phone": "+70575536672"}
0005433846825	73256B	3194 118315	ROMAN NAZAROV	{"phone": "+70972514882"}
0005433846826	73256B	8366 001342	VASILIY TIKHONOV	{"phone": "+70819368706"}
0005433846827	73256B	8444 433672	KAROLINA MEDVEDEVA	{"phone": "+70214730334"}
0005433846828	73256B	2927 886732	LIDIYA NESTEROVA	{"phone": "+70626291330"}
0005433846829	69AA07	2816 088626	VLADIMIR TIKHONOV	{"email": "vladimir-tikhonov.24101973@postgrespro.ru", "phone": "+70255612539"}
0005433846830	EDF8C9	9397 505327	ALEKSANDR ANDREEV	{"phone": "+70138120800"}
0005433846831	EDF8C9	0392 434675	NADEZHDA VLASOVA	{"email": "vlasova_nadezhda.26121981@postgrespro.ru", "phone": "+70083388245"}
0005433846832	EDF8C9	0404 646834	DMITRIY ORLOV	{"email": "dmitriyorlov.101974@postgrespro.ru", "phone": "+70905912753"}
0005433846833	B99865	1878 717778	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov1975@postgrespro.ru", "phone": "+70119254102"}
0005433846834	C43BAC	8724 665397	RUSLAN MEDVEDEV	{"email": "medvedev_ruslan_031969@postgrespro.ru", "phone": "+70554721907"}
0005433846835	A79E06	6541 871093	VALENTINA KUZNECOVA	{"phone": "+70309230103"}
0005433846836	B5B3CB	0210 843325	EVGENIY POPOV	{"email": "popov_evgeniy_071975@postgrespro.ru", "phone": "+70694048696"}
0005433846837	90AF9F	6650 270436	EVGENIYA ZAKHAROVA	{"email": "zakharova-evgeniya_081965@postgrespro.ru", "phone": "+70887239871"}
0005433846838	814932	4861 403717	MARGARITA EFIMOVA	{"email": "efimova.margarita.051985@postgrespro.ru", "phone": "+70388044065"}
0005433846839	814932	6796 392537	VALERIY KUZNECOV	{"email": "valeriy.kuznecov27081972@postgrespro.ru", "phone": "+70722717603"}
0005433846840	06DC3F	7272 029791	LYUBOV EGOROVA	{"email": "l_egorova071965@postgrespro.ru", "phone": "+70667990971"}
0005433846841	B0512F	9374 205053	OLEG ANTONOV	{"email": "oleg-antonov1968@postgrespro.ru", "phone": "+70954567988"}
0005433846842	B02979	5201 857147	TATYANA VASILEVA	{"phone": "+70011116413"}
0005433846843	4E43F8	3428 222647	ANASTASIYA VOROBEVA	{"phone": "+70768128848"}
0005433846844	A7207B	8141 327185	EVGENIY KULIKOV	{"phone": "+70053881911"}
0005433846845	A7207B	3532 990120	ILYA VOROBEV	{"phone": "+70472100869"}
0005433846846	446ABB	4052 067987	SERGEY FOMIN	{"email": "fomins_1979@postgrespro.ru", "phone": "+70312236575"}
0005433846847	0C9668	1207 751109	TAMARA POPOVA	{"phone": "+70508791308"}
0005433846848	0C9668	5088 952514	ANASTASIYA BELYAEVA	{"phone": "+70448913644"}
0005433846849	D1B82E	1998 074956	STANISLAV FILIPPOV	{"email": "filippov.stanislav-011974@postgrespro.ru", "phone": "+70767503550"}
0005433846850	D1B82E	7176 624848	EVGENIY FEDOROV	{"phone": "+70288858448"}
0005433846907	51586F	6566 533509	GENNADIY EGOROV	{"phone": "+70785335435"}
0005433846851	D1B82E	2952 943196	LIDIYA ERMAKOVA	{"email": "ermakoval_07051966@postgrespro.ru", "phone": "+70940099663"}
0005433846852	117E1D	1606 549976	DANILA MAKSIMOV	{"phone": "+70615210563"}
0005433846853	117E1D	3685 629720	ANNA GORBUNOVA	{"email": "gorbunova_anna-041977@postgrespro.ru", "phone": "+70615581361"}
0005433846854	29279A	9776 780363	ALEKSANDRA KOROLEVA	{"email": "korolevaaleksandra071983@postgrespro.ru", "phone": "+70255644244"}
0005433846855	281FCA	9147 853793	VERA KOROLEVA	{"phone": "+70489115957"}
0005433846856	281FCA	9957 043657	DARYA MARTYNOVA	{"phone": "+70875750490"}
0005433846857	BDD8CE	9397 629521	MARINA FADEEVA	{"email": "mfadeeva-1966@postgrespro.ru", "phone": "+70138651729"}
0005433846858	BDD8CE	3267 642600	IGOR KOROLEV	{"phone": "+70360915298"}
0005433846859	6FBCD5	8603 167924	VIKTOR NOVIKOV	{"email": "viktor_novikov_05061970@postgrespro.ru", "phone": "+70768701674"}
0005433846860	717D20	0851 932381	NINA ANDREEVA	{"phone": "+70772835726"}
0005433846861	717D20	2840 362260	ANNA VOLKOVA	{"phone": "+70804448265"}
0005433846862	717D20	0498 601627	LYUBOV KOLESNIKOVA	{"phone": "+70674347930"}
0005433846863	0D6F7C	8932 936286	ALENA ALEKSEEVA	{"phone": "+70859262296"}
0005433846864	6A7C96	0810 175589	OLGA FEDOROVA	{"email": "olga-fedorova.21031967@postgrespro.ru", "phone": "+70896375871"}
0005433846865	A0B76A	2852 698440	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev09111975@postgrespro.ru", "phone": "+70089518553"}
0005433846866	BBF91F	2549 603615	YURIY ALEKSANDROV	{"email": "yuriy.aleksandrov121978@postgrespro.ru", "phone": "+70605695982"}
0005433846867	DD2268	2175 069114	VLADIMIR ABRAMOV	{"phone": "+70788870520"}
0005433846868	DD2268	5384 276797	VALENTINA KOROLEVA	{"email": "v-koroleva_27041966@postgrespro.ru", "phone": "+70316119611"}
0005433846869	F9111B	1369 179098	ALISA MOROZOVA	{"email": "morozova.a.061982@postgrespro.ru", "phone": "+70529091522"}
0005433846870	F9111B	0123 201698	LYUBOV KULIKOVA	{"email": "kulikova-lyubov.15081974@postgrespro.ru", "phone": "+70666678166"}
0005433846871	F9111B	3240 977541	ELENA NAUMOVA	{"email": "naumovaelena_1967@postgrespro.ru", "phone": "+70270203527"}
0005433846872	C5EF6A	4968 721682	INNA ORLOVA	{"email": "innaorlova-20111964@postgrespro.ru", "phone": "+70770966553"}
0005433846873	601DDE	0615 944975	IRINA LOGINOVA	{"phone": "+70629344130"}
0005433846874	96BBD7	1831 345308	ANNA SIDOROVA	{"phone": "+70232116831"}
0005433846875	96BBD7	3909 594498	TATYANA ZAKHAROVA	{"email": "t_zakharova-041966@postgrespro.ru", "phone": "+70602914561"}
0005433846876	0ABED7	5209 892596	LYUDMILA VLASOVA	{"phone": "+70400449539"}
0005433846877	4705AF	5963 473035	DENIS MELNIKOV	{"phone": "+70087336984"}
0005433846878	184BE6	5675 757790	OLGA STEPANOVA	{"phone": "+70300784693"}
0005433846879	184BE6	8619 955299	GALINA NIKOLAEVA	{"phone": "+70430349986"}
0005433846880	E480E2	0166 126550	ANTONINA MEDVEDEVA	{"email": "a-medvedeva_27101977@postgrespro.ru", "phone": "+70532995343"}
0005433846881	0671A8	0403 423683	INNA KOZLOVA	{"email": "ikozlova15101972@postgrespro.ru", "phone": "+70272146986"}
0005433846882	0671A8	6727 140408	SERGEY DAVYDOV	{"email": "davydov_sergey-1977@postgrespro.ru", "phone": "+70123901592"}
0005433846883	237996	1100 441787	ALEKSANDR PETROV	{"phone": "+70402369186"}
0005433846884	09DB45	1726 172790	SERGEY MARTYNOV	{"phone": "+70336309706"}
0005433846885	E0D022	3028 481446	GENNADIY DENISOV	{"email": "denisovgennadiy-10121971@postgrespro.ru", "phone": "+70396639679"}
0005433846886	E0D022	6701 182282	NIKOLAY FILIPPOV	{"email": "filippov_nikolay_041973@postgrespro.ru", "phone": "+70556732058"}
0005433846887	F738B3	7739 396888	VASILIY PETROV	{"phone": "+70432313698"}
0005433846888	96FEB1	2099 635645	NADEZHDA SIDOROVA	{"phone": "+70291585578"}
0005433846889	EC018E	2881 119632	ALEKSEY MEDVEDEV	{"phone": "+70561207646"}
0005433846890	537494	9021 235687	VALENTINA TARASOVA	{"email": "tarasova-v_1976@postgrespro.ru", "phone": "+70235179036"}
0005433846891	DC3E8C	9378 092424	NATALYA FEDOROVA	{"email": "natalyafedorova.051970@postgrespro.ru", "phone": "+70206523965"}
0005433846892	60680A	5011 256423	ARTEM IVANOV	{"email": "ivanov.artem011979@postgrespro.ru", "phone": "+70354756826"}
0005433846893	A21FD7	2900 742626	NADEZHDA FEDOROVA	{"email": "nadezhda.fedorova.101979@postgrespro.ru", "phone": "+70806312215"}
0005433846894	27AFEC	1215 927334	RIMA MIKHAYLOVA	{"phone": "+70423622638"}
0005433846895	27AFEC	4101 445318	NADEZHDA DENISOVA	{"phone": "+70273821420"}
0005433846896	B6C63B	1831 025608	ANTON NAUMOV	{"email": "antonnaumov.25081982@postgrespro.ru", "phone": "+70825493817"}
0005433846897	B6C63B	6320 596440	ALEKSEY SAVELEV	{"email": "savelev-a-1970@postgrespro.ru", "phone": "+70057932533"}
0005433846898	748174	6014 697185	ANASTASIYA CHERNOVA	{"email": "chernovaa.101960@postgrespro.ru", "phone": "+70985852044"}
0005433846899	61F01F	6058 444835	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov.1983@postgrespro.ru", "phone": "+70430479126"}
0005433846900	6592E5	8305 054526	IRINA KUDRYASHOVA	{"phone": "+70872516679"}
0005433846901	470367	1946 915476	VALENTINA ZHURAVLEVA	{"phone": "+70079245433"}
0005433846902	470367	2978 833869	ANATOLIY EGOROV	{"email": "anatoliy_egorov01091972@postgrespro.ru", "phone": "+70518253546"}
0005433846903	2EB717	8833 418428	DMITRIY ANTONOV	{"email": "dmitriy-antonov-081973@postgrespro.ru", "phone": "+70138824517"}
0005433846904	2EB717	3168 857681	ANATOLIY SOKOLOV	{"phone": "+70559175147"}
0005433846905	248C79	8938 027859	VIKTOR ZAYCEV	{"phone": "+70213295755"}
0005433846906	51586F	6259 477826	YURIY KULIKOV	{"phone": "+70070113614"}
0005433846908	51586F	4387 199849	VITALIY ANTONOV	{"phone": "+70231290577"}
0005433846909	531356	5304 573538	VLADISLAV SIDOROV	{"email": "vladislav-sidorov.071979@postgrespro.ru", "phone": "+70942466340"}
0005433846910	1C1148	5634 487416	LYUBOV ABRAMOVA	{"email": "l_abramova12111966@postgrespro.ru", "phone": "+70357753775"}
0005433846911	1C1148	8544 382334	ARTEM MAKAROV	{"email": "makarovartem.06081974@postgrespro.ru", "phone": "+70089600692"}
0005433846912	4D54C7	6594 271621	LARISA MAKAROVA	{"email": "larisa.makarova28101974@postgrespro.ru", "phone": "+70705868480"}
0005433846913	4D54C7	6096 438065	OLGA PETROVA	{"phone": "+70547944379"}
0005433846914	032044	4694 401248	YURIY SEMENOV	{"email": "y_semenov.051971@postgrespro.ru", "phone": "+70813614653"}
0005433846915	032044	0372 750436	RUSLAN ISAEV	{"phone": "+70852740373"}
0005433846916	D7B1E3	7952 398577	LIDIYA GAVRILOVA	{"email": "lidiya_gavrilova_1975@postgrespro.ru", "phone": "+70638981887"}
0005433846917	4DDBB8	9084 816130	ALEVTINA SERGEEVA	{"phone": "+70001085568"}
0005433846918	17AABF	2561 095573	LIDIYA KUZNECOVA	{"email": "kuznecova.l-021969@postgrespro.ru", "phone": "+70775653573"}
0005433846919	65DC8D	6368 950079	VERONIKA CHERNOVA	{"email": "vchernova1970@postgrespro.ru", "phone": "+70294635625"}
0005433846920	AC5692	3471 245625	YULIYA VOLKOVA	{"phone": "+70981521786"}
0005433846921	AD0D00	2475 411333	ALENA ZHUKOVA	{"email": "alena_zhukova_1975@postgrespro.ru", "phone": "+70186202250"}
0005433846922	AD0D00	6388 496489	ALEKSANDR ISAEV	{"phone": "+70458820137"}
0005433846923	45079E	1315 794993	NATALYA FROLOVA	{"email": "n-frolova1966@postgrespro.ru", "phone": "+70653176246"}
0005433846924	45079E	1179 277161	TATYANA POPOVA	{"email": "t.popova_051972@postgrespro.ru", "phone": "+70755852411"}
0005433846925	29270A	4329 573648	RINAT BONDARENKO	{"email": "bondarenko_r121971@postgrespro.ru", "phone": "+70447140055"}
0005433846926	29270A	3126 117473	TATYANA FROLOVA	{"phone": "+70997435887"}
0005433846927	29270A	9221 795018	TATYANA VASILEVA	{"phone": "+70676836551"}
0005433846928	941FCF	1198 289360	KONSTANTIN ZHURAVLEV	{"phone": "+70676352562"}
0005433846929	91777B	4878 265932	DMITRIY DAVYDOV	{"phone": "+70249377325"}
0005433846930	48735A	6715 763059	VITALIY IVANOV	{"phone": "+70849052604"}
0005433846931	48735A	1795 177529	VIKTOR ALEKSEEV	{"phone": "+70051680677"}
0005433846932	FCAF56	6379 686473	ILYA MOROZOV	{"email": "ilyamorozov_07041982@postgrespro.ru", "phone": "+70194441955"}
0005433846933	5B2FC7	3784 339056	VALERIY IVANOV	{"phone": "+70411813851"}
0005433846934	9B83FA	6494 131800	DANIIL ROMANOV	{"email": "romanov-daniil_1958@postgrespro.ru", "phone": "+70307997074"}
0005433846935	9B83FA	9745 957175	ANATOLIY MIKHAYLOV	{"phone": "+70971125200"}
0005433846936	F9D137	3606 833442	SERGEY KONOVALOV	{"phone": "+70256801176"}
0005433846937	7E5257	7550 206754	MIKHAIL NIKITIN	{"email": "mikhailnikitin_021968@postgrespro.ru", "phone": "+70824627944"}
0005433846938	7E5257	1879 497534	BORIS KAZAKOV	{"email": "kazakov.b_1969@postgrespro.ru", "phone": "+70239597134"}
0005433846939	7E5257	8757 534516	LYUBOV KAZAKOVA	{"phone": "+70771880699"}
0005433846940	F664A4	5885 213332	ANASTASIYA GUSEVA	{"phone": "+70309706231"}
0005433846941	EFED27	8500 826711	ARTEM IVANOV	{"phone": "+70802988321"}
0005433846942	0EB554	3182 784748	LARISA KOZLOVA	{"phone": "+70381059503"}
0005433846943	0EB554	6711 476430	ELENA FILIPPOVA	{"email": "filippovaelena_031970@postgrespro.ru", "phone": "+70404648651"}
0005433846944	AD6E86	7129 085314	YULIYA BORISOVA	{"phone": "+70882032548"}
0005433846945	BCFA63	4080 018450	SERGEY KONOVALOV	{"phone": "+70583005787"}
0005433846946	BCFA63	4074 586736	EVGENIY POPOV	{"phone": "+70046606601"}
0005433846947	3FB32C	7121 037945	NIKITA SOROKIN	{"email": "n-sorokin121969@postgrespro.ru", "phone": "+70320909100"}
0005433846948	90CA82	7108 468763	IGOR GORBUNOV	{"email": "igor.gorbunov.081981@postgrespro.ru", "phone": "+70821853634"}
0005433846949	EDAE32	4781 448379	VALENTINA VOROBEVA	{"email": "valentina-vorobeva011967@postgrespro.ru", "phone": "+70730587905"}
0005433846950	0A2361	7221 539158	DMITRIY ALEKSEEV	{"phone": "+70824580971"}
0005433846951	89811E	3549 776595	OLGA NESTEROVA	{"email": "nesterovaolga02061977@postgrespro.ru", "phone": "+70549449267"}
0005433846952	C7EDEE	3977 378328	YURIY MATVEEV	{"email": "matveev.yuriy11031962@postgrespro.ru", "phone": "+70834465033"}
0005433846953	EBB6C6	2330 552314	GEORGIY BELOV	{"phone": "+70874293147"}
0005433846954	EBB6C6	5895 446937	SVETLANA FILATOVA	{"phone": "+70262622541"}
0005433846955	EBB6C6	1118 537094	NIKOLAY STEPANOV	{"phone": "+70434269253"}
0005433846956	994584	4545 181524	OLGA BORISOVA	{"phone": "+70890012842"}
0005433846957	DE937F	9312 951161	IVAN PETROV	{"email": "ivanpetrov_1979@postgrespro.ru", "phone": "+70105201360"}
0005433846958	DE937F	6592 009439	VLADISLAV ZAKHAROV	{"phone": "+70305086059"}
0005433846959	53237B	0494 782533	TIMUR FROLOV	{"email": "tfrolov_06041980@postgrespro.ru", "phone": "+70887130976"}
0005433846960	70FAD8	7719 084297	IRINA FOMINA	{"phone": "+70253708311"}
0005433846961	DB5218	8585 030821	ALEKSANDRA GUSEVA	{"email": "a_guseva_21101974@postgrespro.ru", "phone": "+70449210754"}
0005433846962	63B0CF	9077 626104	TAMARA STEPANOVA	{"email": "stepanovatamara-28061969@postgrespro.ru", "phone": "+70177791502"}
0005433846963	63B0CF	8057 607623	ANASTASIYA MAKAROVA	{"phone": "+70748550282"}
0005433846964	D28E4D	7285 919342	YURIY FEDOROV	{"phone": "+70509754680"}
0005433846965	BF8167	6037 296637	VERA KUZMINA	{"email": "kuzmina.v.1983@postgrespro.ru", "phone": "+70475546087"}
0005433846966	5D0C24	3762 605085	ALEKSANDR GORBUNOV	{"phone": "+70806723675"}
0005433846967	C9636C	4442 178010	NADEZHDA ZAKHAROVA	{"email": "zakharovan24011972@postgrespro.ru", "phone": "+70889846219"}
0005433846968	17E12E	2830 213480	VLADIMIR POPOV	{"phone": "+70604139400"}
0005433846969	51D7FB	4744 442109	FILIPP KAZAKOV	{"phone": "+70031409693"}
0005433846970	2A2A42	3335 881033	VLADIMIR SOROKIN	{"email": "sorokin-vladimir-091976@postgrespro.ru", "phone": "+70117764964"}
0005433846971	2A2A42	1784 111107	EVGENIY VASILEV	{"phone": "+70448184318"}
0005433846972	41E215	9166 100765	ILMIR MIKHAYLOV	{"phone": "+70543203450"}
0005433846973	A29B55	8300 921629	VLADIMIR RODIONOV	{"phone": "+70579775290"}
0005433846974	59676A	7401 357791	VIKTOR FROLOV	{"phone": "+70526857687"}
0005433846975	59676A	9778 622094	EKATERINA VASILEVA	{"email": "ekaterina.vasileva_031975@postgrespro.ru", "phone": "+70544011079"}
0005433846976	362CA9	6163 855777	ANDREY YAKOVLEV	{"phone": "+70142115109"}
0005433846977	362CA9	0701 843826	TATYANA MOROZOVA	{"phone": "+70628769045"}
0005433846978	212846	4866 152725	ALEKSANDR NAUMOV	{"email": "naumov-a051956@postgrespro.ru", "phone": "+70581213945"}
0005433846979	212846	9052 595447	MARIYA NAZAROVA	{"phone": "+70198324480"}
0005433846980	1000F7	4472 818798	ALEKSEY SCHERBAKOV	{"email": "a_scherbakov.25121986@postgrespro.ru", "phone": "+70056607896"}
0005433846981	8C935C	6733 987001	IRINA TROFIMOVA	{"phone": "+70516376565"}
0005433846982	79370B	9902 570185	ZOYA VOLKOVA	{"email": "volkova-zoya_1971@postgrespro.ru", "phone": "+70877469380"}
0005433846983	D8AEC3	3813 653599	IVAN PETROV	{"phone": "+70395388925"}
0005433846984	C4079C	3334 125334	RINAT KOROLEV	{"phone": "+70062572427"}
0005433846985	C23C48	1972 689443	YANA CHERNOVA	{"email": "chernovayana-101980@postgrespro.ru", "phone": "+70561478688"}
0005433846986	161A02	7097 399596	ELENA DENISOVA	{"phone": "+70552637916"}
0005433846987	161A02	5936 048486	ILYA MIKHAYLOV	{"email": "ilya-mikhaylov.071969@postgrespro.ru", "phone": "+70943054809"}
0005433846988	7FADDE	3801 864018	VLADIMIR SOKOLOV	{"email": "v-sokolov-03101958@postgrespro.ru", "phone": "+70512933551"}
0005433846989	11CA41	3273 402897	SERGEY GUSEV	{"email": "gusev.sergey.1972@postgrespro.ru", "phone": "+70004743137"}
0005433846990	4338C0	3308 410975	VIKTOR MELNIKOV	{"email": "melnikov_v111976@postgrespro.ru", "phone": "+70238773089"}
0005433846991	4338C0	2129 548763	DMITRIY ANDREEV	{"email": "dmitriyandreev_27091971@postgrespro.ru", "phone": "+70226212383"}
0005433846992	9E77CA	7233 029567	ZINAIDA MATVEEVA	{"phone": "+70234935661"}
0005433846993	0FCF47	0055 411540	VLADISLAV TARASOV	{"email": "tarasov-v-23111961@postgrespro.ru", "phone": "+70671165578"}
0005433846994	49F2E0	8280 538284	LILIYA SMIRNOVA	{"email": "smirnova-l-07031982@postgrespro.ru", "phone": "+70188183229"}
0005433846995	8CC5C1	6185 062028	NIKOLAY GERASIMOV	{"email": "n-gerasimov_14051966@postgrespro.ru", "phone": "+70726483345"}
0005433846996	8CC5C1	7699 250070	LIDIYA ZHURAVLEVA	{"email": "zhuravleva-lidiya_1960@postgrespro.ru", "phone": "+70261375564"}
0005433846997	AD7D0A	8871 803207	ROMAN VOROBEV	{"phone": "+70189068824"}
0005433846998	5D0AAA	9656 089799	SERGEY KUZMIN	{"phone": "+70950439193"}
0005433847059	9C2EC9	0444 542852	VIKTOR KUZNECOV	{"phone": "+70494859364"}
0005433846999	5D0AAA	0848 287235	TATYANA TARASOVA	{"email": "tatyana-tarasova-061966@postgrespro.ru", "phone": "+70693841149"}
0005433847000	8091CF	3070 306585	ANATOLIY SCHERBAKOV	{"email": "scherbakov-a.09041973@postgrespro.ru", "phone": "+70661611133"}
0005433847001	8091CF	7677 896728	ALEKSEY ANTONOV	{"email": "aleksey-antonov_011975@postgrespro.ru", "phone": "+70751018768"}
0005433847002	353851	1466 423062	ELENA GAVRILOVA	{"phone": "+70232552035"}
0005433847003	FE1299	0577 347671	ANNA KISELEVA	{"phone": "+70920872877"}
0005433847004	63B3F9	6039 960049	SERGEY GUSEV	{"phone": "+70691780750"}
0005433847005	817E78	6951 438249	TATYANA KOROLEVA	{"phone": "+70889592373"}
0005433847006	817E78	4877 889209	VALENTINA AFANASEVA	{"phone": "+70775933714"}
0005433847007	817E78	6743 214450	EKATERINA VOLKOVA	{"phone": "+70983285509"}
0005433847008	D756DE	8527 505439	IBRAGIM KUZNECOV	{"email": "kuznecovibragim_25061976@postgrespro.ru", "phone": "+70001647111"}
0005433847009	8FF1C0	5186 095020	VALENTINA BELOVA	{"phone": "+70765351148"}
0005433847010	1C0745	2123 308956	ANASTASIYA BARANOVA	{"phone": "+70359849244"}
0005433847011	1C0745	9669 675336	NADEZHDA KOZLOVA	{"email": "kozlova_nadezhda.051983@postgrespro.ru", "phone": "+70731362074"}
0005433847012	8A271E	6728 161055	ARTEM KONOVALOV	{"email": "akonovalov.1980@postgrespro.ru", "phone": "+70953396268"}
0005433847013	0AA7B1	7181 714980	MIKHAIL ROMANOV	{"phone": "+70741890895"}
0005433847014	0393E2	7214 309620	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev071960@postgrespro.ru", "phone": "+70509711315"}
0005433847015	3A530F	8732 695271	EVGENIY ANTONOV	{"email": "evgeniy_antonov17041971@postgrespro.ru", "phone": "+70115086140"}
0005433847016	CD2693	0580 815062	NATALYA EFIMOVA	{"phone": "+70549851552"}
0005433847017	CD2693	5938 453104	KAMIL SOLOVEV	{"phone": "+70039838862"}
0005433847018	E201B3	4914 045571	VIKTORIYA ABRAMOVA	{"email": "vabramova_17121962@postgrespro.ru", "phone": "+70310681813"}
0005433847019	E201B3	9810 700443	ALEKSANDR KUZNECOV	{"email": "a_kuznecov121978@postgrespro.ru", "phone": "+70719339484"}
0005433847020	95F371	5099 737148	IGOR MELNIKOV	{"phone": "+70868114894"}
0005433847021	95F371	1877 264488	DMITRIY MARTYNOV	{"email": "martynov_dmitriy_1970@postgrespro.ru", "phone": "+70562774010"}
0005433847022	197D2A	4607 865393	ALEKSANDRA MATVEEVA	{"email": "aleksandra-matveeva.081972@postgrespro.ru", "phone": "+70062496297"}
0005433847023	5AE1A7	1358 060253	DMITRIY MAKAROV	{"phone": "+70871956423"}
0005433847024	5AE1A7	8646 601824	ANASTASIYA MATVEEVA	{"email": "matveeva_a.021968@postgrespro.ru", "phone": "+70120370122"}
0005433847025	CF6347	2270 585667	EKATERINA IVANOVA	{"phone": "+70735384930"}
0005433847026	8C9324	9325 028117	SERGEY ZAYCEV	{"email": "zaycev.sergey_15031971@postgrespro.ru", "phone": "+70712615745"}
0005433847027	9E16C1	4284 265172	ILYA KUZNECOV	{"phone": "+70264599375"}
0005433847028	7A88AF	3122 324792	ARTEM SOKOLOV	{"phone": "+70797551230"}
0005433847029	7A88AF	4938 459683	TATYANA KARPOVA	{"phone": "+70399441138"}
0005433847030	D152D4	6988 447932	ARTEM DENISOV	{"phone": "+70256668425"}
0005433847031	D152D4	2183 569426	VLADIMIR BELOV	{"phone": "+70255678098"}
0005433847032	7432F3	0453 870686	EVGENIYA ANISIMOVA	{"phone": "+70375768465"}
0005433847033	B5CEC7	0836 334728	NADEZHDA KAZAKOVA	{"email": "kazakova-nadezhda121966@postgrespro.ru", "phone": "+70636968137"}
0005433847034	B5CEC7	4526 904893	RUSTAM KRASNOV	{"phone": "+70757410858"}
0005433847035	1B2146	3308 742803	DMITRIY MEDVEDEV	{"phone": "+70542460993"}
0005433847036	9C631F	2391 900724	OLGA KUZMINA	{"email": "olgakuzmina.11061968@postgrespro.ru", "phone": "+70525489259"}
0005433847037	A3691B	3376 960539	EVGENIY SCHERBAKOV	{"email": "scherbakov.e_15121984@postgrespro.ru", "phone": "+70450879359"}
0005433847038	6389CD	9490 575224	FAIL DMITRIEV	{"phone": "+70335354827"}
0005433847039	DE4E61	6560 488758	VALENTINA TARASOVA	{"email": "tarasovavalentina.111965@postgrespro.ru", "phone": "+70958339199"}
0005433847040	281F76	9294 273509	ANGELINA KOROLEVA	{"email": "angelina.koroleva_1979@postgrespro.ru", "phone": "+70656978481"}
0005433847041	281F76	8460 454785	OLGA KOMAROVA	{"phone": "+70798065600"}
0005433847042	B5209F	7560 553173	IRINA LEBEDEVA	{"phone": "+70148129082"}
0005433847043	ABFEA8	6543 271874	VERA KONOVALOVA	{"email": "vkonovalova051972@postgrespro.ru", "phone": "+70085305199"}
0005433847044	E1687D	5417 468818	ALEKSANDR DMITRIEV	{"phone": "+70652022318"}
0005433847045	E1687D	8636 767243	EGOR KOZLOV	{"email": "ekozlov-1974@postgrespro.ru", "phone": "+70234969146"}
0005433847046	BA2CAD	2325 106005	TATYANA VASILEVA	{"phone": "+70030731802"}
0005433847047	4081E3	8754 147816	ANASTASIYA FROLOVA	{"email": "anastasiya_frolova19021974@postgrespro.ru", "phone": "+70011820452"}
0005433847048	060BCF	5235 724462	IRINA DENISOVA	{"email": "i.denisova.23011981@postgrespro.ru", "phone": "+70857420070"}
0005433847049	435EE2	2777 887279	SERGEY ZHURAVLEV	{"phone": "+70737056992"}
0005433847050	E83F1F	2457 718122	ARSENIY VLASOV	{"email": "vlasov-arseniy.1972@postgrespro.ru", "phone": "+70278399283"}
0005433847051	E83F1F	9980 934699	ELENA MAKAROVA	{"email": "makarova_elena_011985@postgrespro.ru", "phone": "+70380093957"}
0005433847052	5BB16C	7612 922540	VLADIMIR SOLOVEV	{"phone": "+70410055665"}
0005433847053	5BB16C	1012 903176	GALINA LAZAREVA	{"email": "galina_lazareva091969@postgrespro.ru", "phone": "+70028721674"}
0005433847054	586C78	8005 261662	ANNA KOZLOVA	{"email": "kozlova.a.1978@postgrespro.ru", "phone": "+70509537095"}
0005433847055	586C78	5356 534535	LYUBOV FEDOROVA	{"phone": "+70344601169"}
0005433847056	586C78	8401 050918	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov-071972@postgrespro.ru", "phone": "+70599666566"}
0005433847057	9C2EC9	4727 703725	YULIYA MOROZOVA	{"email": "morozova.y101967@postgrespro.ru", "phone": "+70616352716"}
0005433847058	9C2EC9	4061 680962	NATALYA KOROLEVA	{"email": "n.koroleva051966@postgrespro.ru", "phone": "+70176191880"}
0005433847060	AAF8EE	8768 902875	ALEKSANDR ORLOV	{"phone": "+70541021500"}
0005433847061	5B6170	0369 577579	VLADIMIR ABRAMOV	{"phone": "+70094405232"}
0005433847062	7CAC3C	4307 609569	SHAVKAT KUZNECOV	{"phone": "+70565004806"}
0005433847063	97B908	2939 142045	POLINA MARTYNOVA	{"email": "martynova-p.20091984@postgrespro.ru", "phone": "+70266951616"}
0005433847064	97B908	6468 620578	NIKITA GERASIMOV	{"phone": "+70994221546"}
0005433847065	6F6BB7	0921 137433	VSEVOLOD EGOROV	{"phone": "+70973837667"}
0005433847066	EE1D79	1827 731576	MARIYA DENISOVA	{"email": "mariya.denisova_1983@postgrespro.ru", "phone": "+70821478897"}
0005433847067	F107B7	1992 891018	PETR NAUMOV	{"email": "pnaumov_19071981@postgrespro.ru", "phone": "+70967421881"}
0005433847068	05BC37	0719 100284	NINA VOLKOVA	{"phone": "+70693672585"}
0005433847069	5092F6	7060 876030	VALENTINA TARASOVA	{"email": "v_tarasova.011965@postgrespro.ru", "phone": "+70984684908"}
0005433847070	AA4A0E	2034 211480	TATYANA ZOTOVA	{"phone": "+70086973197"}
0005433847071	80FD16	3487 011740	ROZALIYA NOVIKOVA	{"phone": "+70500304458"}
0005433847072	80FD16	4922 364226	GALINA KRASNOVA	{"email": "galina_krasnova071972@postgrespro.ru", "phone": "+70203645020"}
0005433847073	80FD16	8520 318584	ALEKSEY VASILEV	{"email": "vasilev-a1969@postgrespro.ru", "phone": "+70697189413"}
0005433847074	279D46	7826 458477	VALERIY ANTONOV	{"email": "antonov.v.041973@postgrespro.ru", "phone": "+70965779988"}
0005433847075	5537FE	0906 084163	VALENTINA KISELEVA	{"email": "kiselevav021979@postgrespro.ru", "phone": "+70234334226"}
0005433847076	5537FE	4535 854940	MIKHAIL PETROV	{"phone": "+70074049519"}
0005433847077	1B592E	6721 244466	SERGEY NAUMOV	{"email": "sergey_naumov1972@postgrespro.ru", "phone": "+70858970303"}
0005433847078	580A18	5027 046189	ARTEM IVANOV	{"phone": "+70391430029"}
0005433847079	580A18	1125 631040	SERGEY IVANOV	{"email": "ivanovs.15081971@postgrespro.ru", "phone": "+70852276572"}
0005433847080	7EB8BF	6947 418739	VLADIMIR BELOV	{"email": "vladimir-belov24011975@postgrespro.ru", "phone": "+70412950063"}
0005433847081	7EB8BF	8872 396037	OLGA SCHERBAKOVA	{"phone": "+70359376724"}
0005433847082	84499E	5338 657025	DANIIL POPOV	{"email": "popov_daniil-041967@postgrespro.ru", "phone": "+70683102982"}
0005433847083	84499E	4701 603627	ALEKSEY STEPANOV	{"phone": "+70348481440"}
0005433847084	84499E	9673 831287	YURIY MAKAROV	{"phone": "+70933158997"}
0005433847085	0D9B93	7884 560811	VALENTINA FROLOVA	{"email": "frolovavalentina.121983@postgrespro.ru", "phone": "+70032313469"}
0005433847086	0D9B93	5702 808025	ANASTASIYA ZOTOVA	{"email": "zotova_anastasiya-1976@postgrespro.ru", "phone": "+70940236904"}
0005433847087	0D9B93	1077 163208	KRISTINA DENISOVA	{"email": "denisova_kristina-05111972@postgrespro.ru", "phone": "+70519254778"}
0005433847088	D4EAB6	6649 141755	ANNA PAVLOVA	{"email": "pavlova.anna-07021973@postgrespro.ru", "phone": "+70181053061"}
0005433847089	63807E	9644 246327	ALEKSEY SOLOVEV	{"email": "solovev-aleksey_06021956@postgrespro.ru", "phone": "+70132262604"}
0005433847090	63807E	2763 750472	OLGA BOGDANOVA	{"phone": "+70080041034"}
0005433847091	F5FBF1	5859 750873	POLINA NIKITINA	{"email": "p.nikitina021962@postgrespro.ru", "phone": "+70155751101"}
0005433847092	F5FBF1	9022 536541	SERGEY ABRAMOV	{"email": "abramov-sergey-1970@postgrespro.ru", "phone": "+70304777164"}
0005433847093	A1FFAA	3399 833420	VIKTOR SEMENOV	{"phone": "+70246822053"}
0005433847094	9794BF	1086 450240	KRISTINA YUDINA	{"email": "kristina-yudina_041978@postgrespro.ru", "phone": "+70450410008"}
0005433847095	74982E	3172 852665	ALEKSANDR MOROZOV	{"phone": "+70283833860"}
0005433847096	0FE66C	1874 439575	KAMIL MOISEEV	{"email": "kamilmoiseev.1976@postgrespro.ru", "phone": "+70393440346"}
0005433847097	D61740	9987 250676	VERA ARKHIPOVA	{"email": "arkhipova_vera-041973@postgrespro.ru", "phone": "+70552220329"}
0005433847098	86A349	2424 308262	ANASTASIYA PETROVA	{"phone": "+70127895006"}
0005433847099	383AF9	6130 115098	ALEKSEY KRASNOV	{"phone": "+70059007243"}
0005433847100	383AF9	7843 920218	MAKSIM SOKOLOV	{"email": "sokolov.m-011965@postgrespro.ru", "phone": "+70277105018"}
0005433847101	234428	1439 583948	MARIYA ZAKHAROVA	{"email": "zakharovamariya-22101966@postgrespro.ru", "phone": "+70953681157"}
0005433847102	D1ACD5	9569 145954	EGOR GAVRILOV	{"email": "e-gavrilov-1969@postgrespro.ru", "phone": "+70363928639"}
0005433847103	D1ACD5	0245 159685	OLGA SERGEEVA	{"email": "olga_sergeeva1970@postgrespro.ru", "phone": "+70017989356"}
0005433847104	FB300B	9987 779777	DMITRIY NIKITIN	{"email": "d_nikitin-16041966@postgrespro.ru", "phone": "+70829985824"}
0005433847105	0273BC	6759 361776	YURIY PETROV	{"email": "y-petrov_1972@postgrespro.ru", "phone": "+70335031445"}
0005433847106	B3D685	0409 581573	MARIYA KOVALEVA	{"email": "kovaleva-mariya-101974@postgrespro.ru", "phone": "+70629165774"}
0005433847107	31E4AF	4908 827839	EGOR TIMOFEEV	{"phone": "+70551821101"}
0005433847108	F30973	2192 784927	MARIYA ALEKSEEVA	{"email": "m-alekseeva.1974@postgrespro.ru", "phone": "+70650823046"}
0005433847109	2B6E47	8107 529227	ANDREY KUZMIN	{"phone": "+70494720968"}
0005433847110	A1AA5E	8700 377739	ALEKSANDR STEPANOV	{"phone": "+70590429396"}
0005433847111	A1AA5E	2961 414063	VIKTOR ZAKHAROV	{"phone": "+70609979624"}
0005433847112	A5880A	0240 611860	VLADISLAV BORISOV	{"phone": "+70578072346"}
0005433847113	563A2E	8315 814319	SVETLANA VOLKOVA	{"email": "s-volkova.1972@postgrespro.ru", "phone": "+70139188951"}
0005433847114	4A4211	6915 814759	DMITRIY SIDOROV	{"email": "sidorovdmitriy_081982@postgrespro.ru", "phone": "+70151817193"}
0005433847115	4A4211	2151 465247	VLADIMIR MAKSIMOV	{"email": "v-maksimov081975@postgrespro.ru", "phone": "+70639032144"}
0005433847116	9C51D0	8524 839998	EVGENIY SMIRNOV	{"phone": "+70146828032"}
0005433847117	9C51D0	1632 010796	TATYANA ZAYCEVA	{"email": "tatyana-zayceva.021957@postgrespro.ru", "phone": "+70156103116"}
0005433847118	F43D22	4354 983076	SVETLANA SMIRNOVA	{"email": "smirnovas.1972@postgrespro.ru", "phone": "+70138676412"}
0005433847119	F43D22	4975 303866	OLGA ISAEVA	{"email": "isaeva-o.101976@postgrespro.ru", "phone": "+70849303565"}
0005433847120	5B8436	3169 763098	ALEKSANDRA MAKAROVA	{"phone": "+70588998553"}
0005433847121	C33585	9841 289828	SERGEY MEDVEDEV	{"phone": "+70860354203"}
0005433847122	CCF37C	8721 975866	VLADIMIR DENISOV	{"phone": "+70450050556"}
0005433847123	D02D1E	3717 513923	VERA OSIPOVA	{"phone": "+70198814483"}
0005433847124	F7E226	1474 102235	RUDOLF ZHUKOV	{"email": "zhukov-r.1965@postgrespro.ru", "phone": "+70118759290"}
0005433847125	F7E226	1992 942538	NATALYA PETROVA	{"phone": "+70471193716"}
0005433847126	F7E226	3844 213048	ALEKSEY DAVYDOV	{"phone": "+70106893396"}
0005433847127	B4CDB3	2221 383940	IVAN TARASOV	{"phone": "+70267257517"}
0005433847128	185EC8	4332 171298	NATALYA GAVRILOVA	{"phone": "+70972568798"}
0005433847129	299842	6666 275897	ANDREY IVANOV	{"email": "ivanovandrey_1978@postgrespro.ru", "phone": "+70896808604"}
0005433847130	F4DB91	5406 223979	SERGEY SOLOVEV	{"phone": "+70153795102"}
0005433847131	B871FA	6193 135736	TAMARA KISELEVA	{"phone": "+70620372177"}
0005433847132	218CB8	8393 446203	ALEKSANDRA GERASIMOVA	{"phone": "+70197372492"}
0005433847133	C47CAB	3300 351775	YURIY KUZNECOV	{"phone": "+70816411007"}
0005433847134	C89FED	5311 047738	ELENA MIRONOVA	{"email": "mironovaelena.14091974@postgrespro.ru", "phone": "+70425404830"}
0005433847135	580D22	1714 539867	SERGEY BARANOV	{"phone": "+70766476190"}
0005433847136	7E2273	8663 402927	NIKOLAY KUZNECOV	{"email": "nkuznecov.121964@postgrespro.ru", "phone": "+70907047430"}
0005433847137	C3C940	6831 423986	DENIS SHEVCHENKO	{"phone": "+70284216311"}
0005433847138	C3C940	5509 809929	VLADIMIR VASILEV	{"phone": "+70946459601"}
0005433847139	9212BD	0862 593417	SERGEY MAKSIMOV	{"email": "maksimov.s10061970@postgrespro.ru", "phone": "+70066902130"}
0005433847140	658A26	4312 970725	GALINA KARPOVA	{"email": "galina-karpova.02021967@postgrespro.ru", "phone": "+70976610005"}
0005433847141	3303FE	4938 291093	MARINA MOROZOVA	{"phone": "+70492063884"}
0005433847142	FC87B5	5226 189274	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-1970@postgrespro.ru", "phone": "+70759101184"}
0005433847143	FC87B5	0345 959267	KAPITALINA MOROZOVA	{"phone": "+70235019869"}
0005433847144	FC87B5	5742 902596	OLGA SERGEEVA	{"phone": "+70437316722"}
0005433847145	97C7B4	1904 207809	MARIYA EFREMOVA	{"phone": "+70507290297"}
0005433847146	B9E4D0	4593 621412	NADEZHDA YAKOVLEVA	{"phone": "+70499186264"}
0005433847147	E98E26	3880 701400	ARSENIY VASILEV	{"email": "a_vasilev_121971@postgrespro.ru", "phone": "+70505686850"}
0005433847148	E98E26	3848 218071	VALENTINA DMITRIEVA	{"email": "dmitrieva_valentina1979@postgrespro.ru", "phone": "+70752384324"}
0005433847149	E98E26	0630 875220	YULIYA KOROLEVA	{"phone": "+70753563933"}
0005433847150	6B42A5	5753 272434	VIKTOR ZAKHAROV	{"email": "zakharov.v-10021972@postgrespro.ru", "phone": "+70807526511"}
0005433847151	184EDA	1650 369771	OLGA KOZLOVA	{"email": "o-kozlova101983@postgrespro.ru", "phone": "+70019666119"}
0005433847152	184EDA	6417 096003	ANDREY PETROV	{"email": "petrova.071974@postgrespro.ru", "phone": "+70523762317"}
0005433847153	F6A4F9	6880 250510	MAKSIM KONOVALOV	{"phone": "+70658711549"}
0005433847154	F6A4F9	9968 369450	VLADIMIR FEDOROV	{"phone": "+70722949495"}
0005433847155	AB63D1	5453 276036	TATYANA TIKHONOVA	{"phone": "+70884649350"}
0005433847156	38948A	6815 165805	NADEZHDA NIKOLAEVA	{"phone": "+70471029935"}
0005433847157	84E053	3159 021624	TATYANA KONDRATEVA	{"email": "kondrateva_tatyana.091968@postgrespro.ru", "phone": "+70027100204"}
0005433847158	ECB57A	6285 643055	LYUDMILA KOLESNIKOVA	{"phone": "+70420658183"}
0005433847159	ECB57A	5333 374434	EGOR GORBUNOV	{"phone": "+70972642234"}
0005433847160	100B56	0879 638053	SERGEY ANTONOV	{"email": "s.antonov_051976@postgrespro.ru", "phone": "+70035773587"}
0005433847161	69DD66	9747 394118	ALEKSANDRA PAVLOVA	{"phone": "+70777121509"}
0005433847162	69DD66	1380 299995	NATALYA MOROZOVA	{"phone": "+70343491555"}
0005433847163	B95EBD	6192 858788	NIKOLAY IVANOV	{"email": "ivanovnikolay.081969@postgrespro.ru", "phone": "+70383535238"}
0005433847164	B95EBD	6161 418381	KSENIYA SCHERBAKOVA	{"email": "kseniya.scherbakova051963@postgrespro.ru", "phone": "+70324448129"}
0005433847165	52E36B	0523 991165	MARIYA BORISOVA	{"email": "borisovam.081974@postgrespro.ru", "phone": "+70379871590"}
0005433847166	1E9DD8	3878 613875	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov.1962@postgrespro.ru", "phone": "+70999363049"}
0005433847167	2D72A9	6167 265364	ANDREY FROLOV	{"email": "frolov.a_29061976@postgrespro.ru", "phone": "+70219480772"}
0005433847168	2D72A9	4893 103162	VALERIY NOVIKOV	{"email": "novikov_v.11041970@postgrespro.ru", "phone": "+70713793150"}
0005433847169	BD40F9	3495 492490	ANASTASIYA SOKOLOVA	{"phone": "+70688782583"}
0005433847170	EAFEA7	7393 316947	VALERIY NIKOLAEV	{"phone": "+70474814118"}
0005433847171	2AC4D0	1312 730820	KLAVDIYA KAZAKOVA	{"email": "kazakova_klavdiya_081967@postgrespro.ru", "phone": "+70120640617"}
0005433847172	D1A680	0983 535604	ANASTASIYA FROLOVA	{"phone": "+70550640815"}
0005433847173	4A17D6	6029 294556	ANDREY ILIN	{"phone": "+70132853503"}
0005433847174	59C4EE	1038 322547	ALENA TIMOFEEVA	{"email": "a.timofeeva1966@postgrespro.ru", "phone": "+70699447824"}
0005433847175	59C4EE	9500 664097	ELENA KUZNECOVA	{"email": "kuznecova.e.111965@postgrespro.ru", "phone": "+70747618435"}
0005433847176	0488DA	9929 778144	VIKTOR MOISEEV	{"email": "viktor-moiseev_041974@postgrespro.ru", "phone": "+70672077714"}
0005433847177	87999E	9202 661974	ALEKSANDR KOROLEV	{"email": "koroleva.1965@postgrespro.ru", "phone": "+70716354803"}
0005433847178	7DDA62	6641 754802	ALEKSEY BELOV	{"phone": "+70763871626"}
0005433847179	7DDA62	7521 811222	ANDREY SIDOROV	{"email": "a.sidorov.1973@postgrespro.ru", "phone": "+70041546904"}
0005433847180	7DDA62	9910 388988	ALEKSANDR GUSEV	{"phone": "+70936523192"}
0005433847181	401AFB	2602 959796	LYUDMILA RODIONOVA	{"phone": "+70807692396"}
0005433847182	AB6C9C	6797 359217	MARIYA ROMANOVA	{"phone": "+70267798123"}
0005433847183	36772A	6744 907596	DAMIR GORBUNOV	{"phone": "+70490332830"}
0005433847184	3BB419	1039 434715	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov-12011981@postgrespro.ru", "phone": "+70177801615"}
0005433847185	DEBF38	0317 624237	EGOR SMIRNOV	{"phone": "+70788883699"}
0005433847186	57CF31	1018 330306	ALEKSANDR FEDOTOV	{"email": "afedotov.101983@postgrespro.ru", "phone": "+70377192027"}
0005433847187	E10221	5426 427185	TATYANA DANILOVA	{"phone": "+70544084329"}
0005433847188	775311	9522 315650	DARYA EGOROVA	{"email": "egorova.darya1972@postgrespro.ru", "phone": "+70355706571"}
0005433847189	775311	2220 911268	MIKHAIL SCHERBAKOV	{"email": "mscherbakov_1985@postgrespro.ru", "phone": "+70466645819"}
0005433847190	66BD15	0333 882064	TATYANA DMITRIEVA	{"email": "dmitrievat-021983@postgrespro.ru", "phone": "+70923424571"}
0005433847191	BC4280	9678 732999	ELENA GERASIMOVA	{"phone": "+70513621793"}
0005433847192	BC4280	3749 711513	DMITRIY ISAEV	{"email": "d_isaev.011969@postgrespro.ru", "phone": "+70612029828"}
0005433847193	93FCC5	1970 776485	LYUDMILA SAVELEVA	{"phone": "+70329139056"}
0005433847194	93FCC5	1984 177360	NINA KONDRATEVA	{"email": "kondrateva_n.10031981@postgrespro.ru", "phone": "+70440644814"}
0005433847195	0F93D7	9144 052847	GALINA ILINA	{"phone": "+70668249644"}
0005433847196	5E9EED	4385 265461	NINA TIMOFEEVA	{"email": "ntimofeeva.031956@postgrespro.ru", "phone": "+70099559064"}
0005433847197	5E9EED	3370 334067	DANILA SEMENOV	{"phone": "+70181815978"}
0005433847198	836A53	4314 287927	ALEKSEY SCHERBAKOV	{"phone": "+70009577720"}
0005433847199	836A53	3577 281828	DARINA MIKHAYLOVA	{"phone": "+70794802220"}
0005433847200	133F81	7368 256629	ELENA SIDOROVA	{"phone": "+70911168353"}
0005433847201	49CE42	6984 943106	EVGENIYA MOROZOVA	{"email": "evgeniya_morozova_09061971@postgrespro.ru", "phone": "+70511919888"}
0005433847202	49CE42	0243 323920	OLGA SIDOROVA	{"phone": "+70161112729"}
0005433847203	F45503	5415 063085	LIDIYA ANTONOVA	{"email": "antonoval-28011971@postgrespro.ru", "phone": "+70608655348"}
0005433847204	F22C8D	3497 264912	NADEZHDA ZOTOVA	{"email": "zotovanadezhda.1968@postgrespro.ru", "phone": "+70100078650"}
0005433847205	25AF97	7464 072356	YURIY BORISOV	{"email": "borisov-yuriy17091978@postgrespro.ru", "phone": "+70022093892"}
0005433847206	9DC8CD	0076 518789	ELENA IVANOVA	{"phone": "+70160155467"}
0005433847207	9DC8CD	4336 600803	ANNA ANDREEVA	{"email": "a_andreeva-061970@postgrespro.ru", "phone": "+70087634825"}
0005433847208	ADC613	8930 707895	KRISTINA AFANASEVA	{"phone": "+70649782237"}
0005433847209	8CE558	4256 517728	VALENTINA FOMINA	{"email": "fomina.valentina_031976@postgrespro.ru", "phone": "+70755244519"}
0005433847210	C192C5	4793 141306	LYUBOV SOROKINA	{"phone": "+70240758415"}
0005433847211	260F58	0285 637295	LYUDMILA ISAEVA	{"email": "isaeva_lyudmila.101958@postgrespro.ru", "phone": "+70118990377"}
0005433847212	7560F1	6307 910324	VALERIY MARTYNOV	{"phone": "+70550879725"}
0005433847213	7560F1	3419 832980	ALEKSEY MAKSIMOV	{"email": "a_maksimov021982@postgrespro.ru", "phone": "+70480842693"}
0005433847214	95353B	0424 340660	ANTONINA TARASOVA	{"email": "tarasovaa.02091972@postgrespro.ru", "phone": "+70812294983"}
0005433847215	4BD229	7005 606683	NIKOLAY FEDOROV	{"phone": "+70261548491"}
0005433847216	294084	6053 855528	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev_101978@postgrespro.ru", "phone": "+70512176797"}
0005433847217	294084	5827 393153	VYACHESLAV PETROV	{"email": "petrov-v031971@postgrespro.ru", "phone": "+70784587635"}
0005433847218	C7F5B2	7972 710564	ANDREY ROMANOV	{"phone": "+70101071438"}
0005433847219	3AFE43	9929 792497	DANIIL ANDREEV	{"email": "d-andreev_18111989@postgrespro.ru", "phone": "+70277381697"}
0005433847220	6C3344	8169 385284	ARINA KARPOVA	{"phone": "+70806143220"}
0005433847221	6C3344	8966 531460	ELENA KOZLOVA	{"email": "kozlova.elena.10111977@postgrespro.ru", "phone": "+70806005842"}
0005433847222	C5D73B	4893 494588	NINA VASILEVA	{"email": "n-vasileva_13101975@postgrespro.ru", "phone": "+70672667043"}
0005433847223	411E57	4993 441364	VIKTOR IVANOV	{"phone": "+70771580521"}
0005433847224	9AE87E	2684 730939	SVETLANA SOROKINA	{"phone": "+70465773459"}
0005433847225	9AE87E	3933 367198	ELENA MIRONOVA	{"email": "e-mironova_17061968@postgrespro.ru", "phone": "+70843581952"}
0005433847226	EDA962	8979 101701	EKATERINA LAZAREVA	{"phone": "+70514915541"}
0005433847227	CE535C	3148 287073	EVGENIY VLASOV	{"phone": "+70068175904"}
0005433847228	CE535C	0234 256145	RAISA ANTONOVA	{"email": "r-antonova-1973@postgrespro.ru", "phone": "+70423663244"}
0005433847229	EF0FC0	7393 610048	VALERIY MIRONOV	{"email": "mironovvaleriy1969@postgrespro.ru", "phone": "+70928437028"}
0005433847230	29DCC8	5513 619578	SNEZHANA NESTEROVA	{"phone": "+70594497054"}
0005433847231	29DCC8	0275 137056	VLADIMIR SEMENOV	{"phone": "+70162753370"}
0005433847232	75BF81	3501 076391	ALINA STEPANOVA	{"phone": "+70870086231"}
0005433847233	59B91B	4877 921804	ANASTASIYA NIKIFOROVA	{"email": "a-nikiforova-021975@postgrespro.ru", "phone": "+70370108174"}
0005433847234	D53D45	2540 663055	IVAN SAVELEV	{"phone": "+70178178943"}
0005433847235	D53D45	0062 662566	ANTON MIKHAYLOV	{"email": "anton-mikhaylov.021965@postgrespro.ru", "phone": "+70623441441"}
0005433847236	1A20DA	0518 913892	PAVEL PETROV	{"email": "petrovpavel051978@postgrespro.ru", "phone": "+70094813726"}
0005433847237	1A20DA	1508 047949	EVGENIY SOKOLOV	{"email": "sokolove-1974@postgrespro.ru", "phone": "+70335324707"}
0005433847238	1A20DA	6450 045198	ALENA KOLESNIKOVA	{"email": "kolesnikova.alena1964@postgrespro.ru", "phone": "+70992491333"}
0005433847239	337938	0337 514088	SERGEY SOROKIN	{"email": "s-sorokin_12021962@postgrespro.ru", "phone": "+70361839364"}
0005433847240	337938	6609 144915	NATALYA TIKHONOVA	{"email": "tikhonova_n_011974@postgrespro.ru", "phone": "+70497991031"}
0005433847241	17E6AE	7509 075993	YURIY SERGEEV	{"email": "sergeev_y_041975@postgrespro.ru", "phone": "+70048539249"}
0005433847242	17E6AE	6244 037055	OLESYA DAVYDOVA	{"email": "o-davydova.101973@postgrespro.ru", "phone": "+70197712378"}
0005433847243	BB7726	3749 969785	ALEKSEY MAKSIMOV	{"phone": "+70604844836"}
0005433847244	BB7726	7761 347940	NINA SEMENOVA	{"email": "n_semenova_1966@postgrespro.ru", "phone": "+70951724688"}
0005433847245	BB7726	0025 224257	YANA SMIRNOVA	{"email": "y_smirnova21061980@postgrespro.ru", "phone": "+70472658992"}
0005433847246	8D7EEE	6198 640071	VALENTINA ISAEVA	{"email": "isaeva-v_111974@postgrespro.ru", "phone": "+70355214326"}
0005433847247	8D7EEE	6582 707958	NADEZHDA KRASNOVA	{"phone": "+70704356510"}
0005433847248	8D7EEE	4607 309407	TAMARA LUKYANOVA	{"email": "lukyanova_tamara.1985@postgrespro.ru", "phone": "+70122289083"}
0005433847249	2FDE32	0504 643062	LYUBOV ALEKSEEVA	{"phone": "+70207867337"}
0005433847250	8C9BC5	0656 538212	ANTONINA KOZLOVA	{"email": "kozlova_antonina_1978@postgrespro.ru", "phone": "+70396370033"}
0005433847251	A1BC03	9671 849038	NAILYA NIKIFOROVA	{"phone": "+70590453669"}
0005433847252	1D70E0	0024 874677	GALINA BORISOVA	{"phone": "+70671210752"}
0005433847253	764338	8069 813866	SERGEY PAVLOV	{"phone": "+70741482103"}
0005433847254	764338	6414 185657	GALINA SOROKINA	{"phone": "+70212205210"}
0005433847255	880399	7532 870589	OLGA VASILEVA	{"email": "vasileva_o_031972@postgrespro.ru", "phone": "+70528313593"}
0005433847256	880399	7996 556368	ANZHELA NESTEROVA	{"phone": "+70962195741"}
0005433847257	71696F	4358 799037	LEONID GRIGOREV	{"phone": "+70392174609"}
0005433847258	94E669	0478 970162	YAROSLAV SAVELEV	{"email": "yaroslav_savelev_011976@postgrespro.ru", "phone": "+70490907729"}
0005433847259	F7C87C	7658 911018	EVGENIY SERGEEV	{"phone": "+70285564057"}
0005433847260	F7C87C	8126 625057	ELENA MOROZOVA	{"email": "e-morozova1969@postgrespro.ru", "phone": "+70427876740"}
0005433847261	931A29	6577 946805	NINA FILATOVA	{"email": "filatova_n031975@postgrespro.ru", "phone": "+70373252954"}
0005433847262	1AE961	4215 695332	ELENA FEDOROVA	{"email": "efedorova091978@postgrespro.ru", "phone": "+70883616773"}
0005433847263	A385C1	6676 221601	ELENA FROLOVA	{"email": "elena_frolova-111979@postgrespro.ru", "phone": "+70605882140"}
0005433847264	876F9C	8034 854629	ILNUR ZHUKOV	{"phone": "+70864420753"}
0005433847265	876F9C	8315 201088	OLGA MIRONOVA	{"email": "mironova.olga1985@postgrespro.ru", "phone": "+70916351627"}
0005433847266	0E2409	9135 856874	DMITRIY KUZMIN	{"email": "kuzmin.d.071983@postgrespro.ru", "phone": "+70350054077"}
0005433847267	69EA37	8445 254372	MARIYA MIKHAYLOVA	{"phone": "+70684145482"}
0005433847268	69EA37	9833 475379	SVETLANA KOROLEVA	{"phone": "+70784632866"}
0005433847269	69EA37	0989 463046	ANASTASIYA DAVYDOVA	{"email": "anastasiya-davydova-1973@postgrespro.ru", "phone": "+70239749882"}
0005433847270	392DB6	0073 117546	SERGEY AFANASEV	{"email": "afanasev_s21101961@postgrespro.ru", "phone": "+70652323855"}
0005433847271	DA3C00	0942 702818	ARSENIY FROLOV	{"phone": "+70496931487"}
0005433847272	4620C6	2627 019895	VALERIY TIMOFEEV	{"phone": "+70010295883"}
0005433847273	4620C6	6565 678835	SVETLANA KONOVALOVA	{"email": "konovalova_svetlana.041974@postgrespro.ru", "phone": "+70689018837"}
0005433847274	3F1707	5181 938167	LILIYA KOROLEVA	{"email": "lkoroleva.10091977@postgrespro.ru", "phone": "+70145313225"}
0005433847275	EE30C3	8746 504057	ZINAIDA IVANOVA	{"email": "ivanovaz1987@postgrespro.ru", "phone": "+70848429367"}
0005433847276	7A431A	5668 360409	DARYA NIKIFOROVA	{"email": "darya_nikiforova-1957@postgrespro.ru", "phone": "+70843988196"}
0005433847277	7C464C	4981 857512	VALENTINA SERGEEVA	{"phone": "+70985790139"}
0005433847278	4D68AB	3131 164913	MARIYA MASLOVA	{"email": "mariya.maslova.1974@postgrespro.ru", "phone": "+70120818971"}
0005433847279	0BB186	3263 763476	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov-1966@postgrespro.ru", "phone": "+70109240388"}
0005433847280	52324A	6119 351319	ANNA ILINA	{"email": "ailina101976@postgrespro.ru", "phone": "+70428480982"}
0005433847281	8B7CA9	0360 574275	EVGENIY ABRAMOV	{"phone": "+70668670349"}
0005433847282	60DC16	7564 856097	ANDREY DENISOV	{"phone": "+70510538734"}
0005433847283	C0DF39	2704 606098	NATALYA FEDOROVA	{"email": "fedorova.n.03101973@postgrespro.ru", "phone": "+70991590771"}
0005433847284	FB7E53	4235 492853	ROMAN BARANOV	{"email": "baranov.roman_24121973@postgrespro.ru", "phone": "+70734786095"}
0005433847285	5C0FA6	1479 292154	NATALYA YUDINA	{"phone": "+70745047301"}
0005433847286	414EE0	0100 569114	SVETLANA ZAYCEVA	{"email": "svetlana-zayceva.061969@postgrespro.ru", "phone": "+70071817192"}
0005433847287	414EE0	7472 401336	ROMAN KUZNECOV	{"email": "r.kuznecov.061976@postgrespro.ru", "phone": "+70353226319"}
0005433847288	58B443	7294 275413	DMITRIY KOROLEV	{"email": "d_korolev-1972@postgrespro.ru", "phone": "+70036387455"}
0005433847289	8EF920	0650 251585	VASILIY BORISOV	{"email": "vasiliy-borisov.17021962@postgrespro.ru", "phone": "+70180131483"}
0005433847290	D7B618	4644 320169	ELENA EGOROVA	{"email": "e-egorova_051974@postgrespro.ru", "phone": "+70599357128"}
0005433847291	59A393	8213 837115	OLEG SERGEEV	{"email": "osergeev-1970@postgrespro.ru", "phone": "+70573963576"}
0005433847292	0B0638	1158 823203	ROMAN EGOROV	{"email": "egorov.roman091976@postgrespro.ru", "phone": "+70616528021"}
0005433847293	8B8355	4907 947946	MIKHAIL ORLOV	{"phone": "+70120298560"}
0005433847294	59F847	3552 051310	NIKOLAY MEDVEDEV	{"email": "nikolay-medvedev-11011969@postgrespro.ru", "phone": "+70370295370"}
0005433847295	BD6403	8633 879820	ZOYA ANISIMOVA	{"phone": "+70320039988"}
0005433847296	BD6403	3303 956930	NADEZHDA KUZNECOVA	{"email": "kuznecova-n071987@postgrespro.ru", "phone": "+70359498226"}
0005433847297	B3EC74	2585 680426	VALENTINA SCHERBAKOVA	{"phone": "+70532338445"}
0005433847298	88F7AD	8896 296403	ANTONINA MAKAROVA	{"email": "makarova_antonina.051974@postgrespro.ru", "phone": "+70801798553"}
0005433847299	851B1C	4778 373635	SERGEY SOKOLOV	{"email": "s_sokolov.01121968@postgrespro.ru", "phone": "+70327053587"}
0005433847300	851B1C	7508 363539	MAKSIM SERGEEV	{"phone": "+70471605084"}
0005433847301	62B38F	0369 667846	TATYANA VOROBEVA	{"email": "vorobeva-tatyana.30031973@postgrespro.ru", "phone": "+70721520259"}
0005433847302	B0FA0A	0760 453214	NATALYA FROLOVA	{"email": "frolova-natalya071964@postgrespro.ru", "phone": "+70868257050"}
0005433847303	C4F002	8860 917000	ELENA MOROZOVA	{"phone": "+70886348717"}
0005433847304	F94804	1879 941512	MARIYA ILINA	{"email": "ilina-m_031972@postgrespro.ru", "phone": "+70667165831"}
0005433847305	973E41	8127 973230	ELENA NIKIFOROVA	{"email": "elenanikiforova_1986@postgrespro.ru", "phone": "+70476775068"}
0005433847306	A82E98	6064 853821	OLGA MAKAROVA	{"email": "olgamakarova-1970@postgrespro.ru", "phone": "+70664897910"}
0005433847307	C24016	5835 246767	IRINA PETROVA	{"email": "petrova.irina_21021971@postgrespro.ru", "phone": "+70431521128"}
0005433847308	47513C	2346 034680	ALEKSANDR NIKOLAEV	{"phone": "+70426301028"}
0005433847309	47513C	6889 411103	ELENA SERGEEVA	{"email": "elena.sergeeva-1967@postgrespro.ru", "phone": "+70013940406"}
0005433847310	47513C	6670 650083	IGOR NIKOLAEV	{"phone": "+70110762056"}
0005433847311	BBC62E	2834 407298	NIKOLAY ZHUKOV	{"email": "zhukov.n_14091962@postgrespro.ru", "phone": "+70153125807"}
0005433847312	BBC62E	5781 503698	NATALYA SCHERBAKOVA	{"phone": "+70756538126"}
0005433847313	74D8EC	2293 606923	SVETLANA ZAYCEVA	{"email": "szayceva-10071980@postgrespro.ru", "phone": "+70493652505"}
0005433847314	C8C045	9452 105303	KSENIYA LOGINOVA	{"email": "k-loginova.1975@postgrespro.ru", "phone": "+70698550428"}
0005433847315	FBADBD	4886 349656	MIKHAIL ZHURAVLEV	{"email": "m_zhuravlev-121971@postgrespro.ru", "phone": "+70129523481"}
0005433847316	D4AD7A	3160 999306	VALENTINA FILIPPOVA	{"phone": "+70054521347"}
0005433847317	9CB3E4	3983 325189	ANTONINA IVANOVA	{"email": "antoninaivanova.30101983@postgrespro.ru", "phone": "+70782595601"}
0005433847318	18BD96	2363 345278	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay_1978@postgrespro.ru", "phone": "+70339643152"}
0005433847319	DB9B01	4293 962157	PETR ISAEV	{"phone": "+70569362434"}
0005433847320	DB9B01	5127 188913	SERGEY SOKOLOV	{"email": "ssokolov-07061983@postgrespro.ru", "phone": "+70500472651"}
0005433847321	B7FD75	3670 260411	MARIYA KAZAKOVA	{"email": "mkazakova_101956@postgrespro.ru", "phone": "+70663080721"}
0005433847322	61860D	9784 277199	LYUBOV POPOVA	{"email": "popova-lyubov-041970@postgrespro.ru", "phone": "+70768636059"}
0005433847323	6BB3C7	6933 628336	ALEKSEY TARASOV	{"phone": "+70263777999"}
0005433847324	6BB3C7	2449 519083	LYUDMILA KOVALEVA	{"phone": "+70241976146"}
0005433847325	CFCDAC	3045 050713	ALENA MELNIKOVA	{"phone": "+70478596996"}
0005433847326	FACB1D	5838 139517	MARIYA MOISEEVA	{"phone": "+70448601243"}
0005433847327	FACB1D	0304 029935	ALEKSEY ZAKHAROV	{"phone": "+70789333351"}
0005433847328	83FE67	2204 601187	BULAT MIRONOV	{"email": "mironovb.1989@postgrespro.ru", "phone": "+70294872930"}
0005433847329	657C45	4122 953659	SERGEY ZHURAVLEV	{"email": "zhuravlevsergey.041977@postgrespro.ru", "phone": "+70300445010"}
0005433847330	A5A774	3643 555895	SERGEY PETROV	{"phone": "+70331473011"}
0005433847331	A5A774	5520 864148	TATYANA CHERNOVA	{"email": "t_chernova_051979@postgrespro.ru", "phone": "+70051735571"}
0005433847332	3FDDF3	7140 491137	ANATOLIY TIKHONOV	{"phone": "+70935445736"}
0005433847333	3FDDF3	6440 310919	LYUDMILA BELYAEVA	{"email": "belyaeva_lyudmila_27061979@postgrespro.ru", "phone": "+70447249127"}
0005433847334	06CA73	8177 674341	TATYANA SAVELEVA	{"email": "t-saveleva_1986@postgrespro.ru", "phone": "+70075093620"}
0005433847335	06CA73	8961 494951	SVETLANA ZAYCEVA	{"phone": "+70773598532"}
0005433847336	EFF0E0	7500 167091	TATYANA KOZLOVA	{"email": "kozlova.tatyana1971@postgrespro.ru", "phone": "+70824136366"}
0005433847337	EFF0E0	5000 580451	OLGA KOROLEVA	{"email": "olga-koroleva.18021959@postgrespro.ru", "phone": "+70534966469"}
0005433847338	C2ACB8	3240 218656	ELENA GRISHINA	{"phone": "+70736431677"}
0005433847339	C2ACB8	0261 047455	NINA TIMOFEEVA	{"email": "n_timofeeva091968@postgrespro.ru", "phone": "+70684946111"}
0005433847340	D35FB1	8934 283566	SERGEY NOVIKOV	{"phone": "+70969161259"}
0005433847341	D35FB1	1443 767166	LYUBOV NIKITINA	{"email": "l-nikitina_1966@postgrespro.ru", "phone": "+70614236419"}
0005433847342	FC3CA4	0424 917258	MARINA ZHURAVLEVA	{"email": "marina.zhuravleva.28061975@postgrespro.ru", "phone": "+70359512461"}
0005433847343	74CBB9	8293 108419	ALEKSANDR SCHERBAKOV	{"phone": "+70990631979"}
0005433847344	74CBB9	3070 870453	TATYANA IVANOVA	{"email": "tatyanaivanova.1966@postgrespro.ru", "phone": "+70639899406"}
0005433847345	D4D2F4	0416 434793	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov041970@postgrespro.ru", "phone": "+70851735113"}
0005433847346	D4D2F4	7334 833173	NATALYA PAVLOVA	{"phone": "+70480844817"}
0005433847347	D4D2F4	1139 490328	VIKTOR MATVEEV	{"email": "v_matveev_081982@postgrespro.ru", "phone": "+70891572889"}
0005433847348	B13166	0123 480874	LILIYA ZHURAVLEVA	{"phone": "+70616193207"}
0005433847349	47C2EE	3259 345913	VALERIY KISELEV	{"email": "kiselev_v1978@postgrespro.ru", "phone": "+70855360189"}
0005433847350	47C2EE	5395 827065	LIDIYA POPOVA	{"email": "lidiyapopova.021972@postgrespro.ru", "phone": "+70205521306"}
0005433847351	47C2EE	0103 441862	SEMEN MELNIKOV	{"phone": "+70119150630"}
0005433847352	589EE6	5771 735612	LYUDMILA YUDINA	{"email": "lyudmilayudina1982@postgrespro.ru", "phone": "+70654575845"}
0005433847353	589EE6	3890 472666	EVGENIY MAKSIMOV	{"email": "e.maksimov071974@postgrespro.ru", "phone": "+70566534219"}
0005433847354	B58B89	4621 711290	EVA TROFIMOVA	{"phone": "+70136805830"}
0005433847355	B58B89	3071 831184	LYUDMILA RODIONOVA	{"email": "lyudmilarodionova-16111964@postgrespro.ru", "phone": "+70124553091"}
0005433847356	C8ACAD	9190 168008	YURIY PETROV	{"email": "yuriypetrov_041982@postgrespro.ru", "phone": "+70165773376"}
0005433847357	CE9BE8	3364 894269	ELENA TARASOVA	{"email": "etarasova_08051977@postgrespro.ru", "phone": "+70881884307"}
0005433847358	5234FD	1395 742214	MAKSIM SERGEEV	{"phone": "+70825217496"}
0005433847359	D7415F	7329 618066	TAMARA KOROLEVA	{"email": "t-koroleva18091976@postgrespro.ru", "phone": "+70189067991"}
0005433847360	F4E7CD	9911 816224	EVGENIY KUZNECOV	{"email": "kuznecov-e_1982@postgrespro.ru", "phone": "+70881759497"}
0005433847361	6F8BA4	7247 813934	MARAT PAVLOV	{"phone": "+70082526968"}
0005433847362	6F8BA4	9381 728157	EKATERINA NOVIKOVA	{"email": "e-novikova_04011974@postgrespro.ru", "phone": "+70772549286"}
0005433847363	0B90EB	6401 173085	LYUDMILA AKIMOVA	{"phone": "+70443111571"}
0005433847364	654E1C	1201 875462	ROMAN KARPOV	{"email": "karpov-r.111966@postgrespro.ru", "phone": "+70506955543"}
0005433847365	EB4B89	7968 486315	GENNADIY DMITRIEV	{"email": "dmitriev.g081969@postgrespro.ru", "phone": "+70417235835"}
0005433847366	EB4B89	8694 551392	MARIYA BOGDANOVA	{"phone": "+70431067732"}
0005433847367	37EC46	9473 921172	IREK ANDREEV	{"email": "andreev_i25011966@postgrespro.ru", "phone": "+70529988333"}
0005433847368	FB766D	1435 309117	TATYANA BELOVA	{"phone": "+70133116179"}
0005433847369	DD36F8	7270 576270	LARISA ZHURAVLEVA	{"phone": "+70598641060"}
0005433847370	DD36F8	7429 192631	ANATOLIY FEDOTOV	{"phone": "+70280785681"}
0005433847371	9C02D2	2921 279193	VIKTOR IVANOV	{"phone": "+70136333656"}
0005433847372	9C1F7C	4980 499304	MAKSIM KUZNECOV	{"phone": "+70620809157"}
0005433847373	072A02	8530 065827	DMITRIY BORISOV	{"email": "dborisov1974@postgrespro.ru", "phone": "+70023697465"}
0005433847374	5BC69F	5219 370836	NATALYA LAZAREVA	{"email": "lazareva-n071960@postgrespro.ru", "phone": "+70609187259"}
0005433847375	F48A3E	5402 381069	SERGEY ISAEV	{"phone": "+70528707263"}
0005433847376	953CBB	2896 480339	YURIY VLASOV	{"phone": "+70403410693"}
0005433847377	20543E	4569 683642	MARTA FILIPPOVA	{"email": "m-filippova.15121970@postgrespro.ru", "phone": "+70334481996"}
0005433847378	20543E	9961 829988	GALINA FROLOVA	{"phone": "+70229085576"}
0005433847379	FB4CF1	8005 931748	IVAN MOROZOV	{"phone": "+70879000977"}
0005433847380	FB4CF1	5238 676600	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova_12091971@postgrespro.ru", "phone": "+70746706811"}
0005433847381	DEF6D3	5280 463917	LYUDMILA ORLOVA	{"phone": "+70726943593"}
0005433847382	DEF6D3	5317 269324	REGINA ZHUKOVA	{"phone": "+70913004228"}
0005433847383	0410AC	4696 020413	NURLAN KUZMIN	{"phone": "+70189466400"}
0005433847384	252746	4215 963445	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.12021977@postgrespro.ru", "phone": "+70854766697"}
0005433847385	34D7FE	0397 862313	ANGELINA NIKIFOROVA	{"phone": "+70177628586"}
0005433847386	120C19	7712 413795	LYUDMILA EGOROVA	{"email": "egorova_l_051974@postgrespro.ru", "phone": "+70457111009"}
0005433847387	9F6306	8509 224585	ANATOLIY KOZLOV	{"phone": "+70185551690"}
0005433847388	9F6306	4217 150079	ANDREY GAVRILOV	{"email": "andrey.gavrilov-12111970@postgrespro.ru", "phone": "+70925200100"}
0005433847389	C02EBD	9478 074937	SERGEY GRIGOREV	{"phone": "+70453752000"}
0005433847390	C02EBD	7497 643902	MARIYA DAVYDOVA	{"phone": "+70051891076"}
0005433847391	C02EBD	6823 343367	OLEG BORISOV	{"phone": "+70321249579"}
0005433847392	2AB522	7240 490384	ELIZAVETA MIKHAYLOVA	{"email": "e.mikhaylova_16041980@postgrespro.ru", "phone": "+70721214352"}
0005433847393	281DE3	9617 309570	VERONIKA NOVIKOVA	{"email": "vnovikova.26041973@postgrespro.ru", "phone": "+70647950997"}
0005433847394	1DB3FB	0186 931911	VITALIY TIMOFEEV	{"email": "timofeev-v-1971@postgrespro.ru", "phone": "+70110787245"}
0005433847395	6FCE01	8823 301932	TAISIYA CHERNOVA	{"email": "tchernova_091978@postgrespro.ru", "phone": "+70180497985"}
0005433847396	AF4626	2778 735047	NATALYA SAVELEVA	{"email": "saveleva-natalya28061970@postgrespro.ru", "phone": "+70237861213"}
0005433847397	AF4626	2612 585774	EKATERINA KUZNECOVA	{"phone": "+70443694175"}
0005433847398	AF4626	9504 457198	ALEKSANDR FOMIN	{"email": "fominaleksandr1966@postgrespro.ru", "phone": "+70111357740"}
0005433847399	AAAD5B	3972 934440	ALEKSANDRA PETROVA	{"phone": "+70976621216"}
0005433847400	AAAD5B	6697 861614	RAFAIL AFANASEV	{"email": "afanasev_rafail_091980@postgrespro.ru", "phone": "+70970661754"}
0005433847401	CE0023	1515 534121	EVGENIY MATVEEV	{"phone": "+70874578621"}
0005433847402	641515	1721 183120	GALINA ANTONOVA	{"email": "antonova.g101979@postgrespro.ru", "phone": "+70326984057"}
0005433847403	C4D8B6	0563 151146	YURIY POPOV	{"email": "popov.yuriy.041974@postgrespro.ru", "phone": "+70619250034"}
0005433847404	C4D8B6	1234 800132	VALENTINA AKIMOVA	{"phone": "+70644765412"}
0005433847405	C4D8B6	8659 759824	IGOR VLASOV	{"phone": "+70012391237"}
0005433847406	412DC2	3246 813403	SERGEY ZAYCEV	{"email": "zaycev_s-1956@postgrespro.ru", "phone": "+70419695750"}
0005433847407	6A6D71	7556 337699	LYUDMILA KISELEVA	{"email": "lyudmilakiseleva-101970@postgrespro.ru", "phone": "+70454937785"}
0005433847408	9DCFF1	7311 042711	ALEKSEY PAVLOV	{"phone": "+70460404846"}
0005433847409	0ACD53	8957 308475	IRINA SIDOROVA	{"phone": "+70494254374"}
0005433847410	31467D	5097 964917	LYUBOV POLYAKOVA	{"phone": "+70608497257"}
0005433847411	31467D	0524 745972	ELENA KOMAROVA	{"phone": "+70013885047"}
0005433847412	FAF580	1416 984470	VIKTOR VOLKOV	{"phone": "+70080080970"}
0005433847413	FAF580	4429 307020	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e-041967@postgrespro.ru", "phone": "+70791458616"}
0005433847414	7BDA50	3257 894688	YURIY GUSEV	{"email": "gusevyuriy091971@postgrespro.ru", "phone": "+70369785761"}
0005433847415	7972B8	3277 236828	EKATERINA NESTEROVA	{"email": "e.nesterova1985@postgrespro.ru", "phone": "+70792910454"}
0005433847416	E16977	7008 203955	ALEKSEY VOLKOV	{"email": "aleksey.volkov.081983@postgrespro.ru", "phone": "+70870572683"}
0005433847417	E16977	0214 681272	VYACHESLAV ROMANOV	{"phone": "+70138912155"}
0005433847418	E16977	5409 427493	LYUDMILA ZAKHAROVA	{"email": "zakharova.lyudmila-011975@postgrespro.ru", "phone": "+70226185935"}
0005433847419	D1D4A3	2290 014293	ANNA KUZNECOVA	{"phone": "+70434108661"}
0005433847420	B67842	0160 318689	LARISA PETROVA	{"email": "larisapetrova1974@postgrespro.ru", "phone": "+70970957931"}
0005433847421	B67842	4897 922154	MAKSIM NOVIKOV	{"phone": "+70747614322"}
0005433847422	F21DED	4035 457571	NIKOLAY MIRONOV	{"phone": "+70237749351"}
0005433847423	F21DED	5710 261528	VLADIMIR MATVEEV	{"email": "matveev_vladimir1976@postgrespro.ru", "phone": "+70290313202"}
0005433847424	743973	8274 294096	VASILIY MATVEEV	{"email": "matveevv.091963@postgrespro.ru", "phone": "+70929511921"}
0005433847425	6C18D4	4904 062264	OLGA FILIPPOVA	{"email": "filippova.o1962@postgrespro.ru", "phone": "+70491119005"}
0005433847426	3E89E8	8060 768438	VIKTOR VASILEV	{"email": "vasilev_viktor_11061959@postgrespro.ru", "phone": "+70944278396"}
0005433847427	3E89E8	2898 003626	KIRILL GRIGOREV	{"phone": "+70636289930"}
0005433847428	0D35FA	7840 139816	EVGENIYA ZAKHAROVA	{"email": "zakharova-e-09091979@postgrespro.ru", "phone": "+70710387550"}
0005433847429	0D35FA	7170 664407	ANTON ROMANOV	{"email": "romanov.anton_1963@postgrespro.ru", "phone": "+70436770310"}
0005433847430	7208A2	1606 709759	NATALYA FILATOVA	{"email": "n-filatova.1960@postgrespro.ru", "phone": "+70925149827"}
0005433847431	EF44C2	5995 441768	IRINA KUZNECOVA	{"email": "kuznecova-i.1983@postgrespro.ru", "phone": "+70133802183"}
0005433847432	EF44C2	2798 317976	KLAVDIYA CHERNOVA	{"email": "chernova_k-1959@postgrespro.ru", "phone": "+70662897775"}
0005433847433	FA7291	8557 665488	ELENA OSIPOVA	{"phone": "+70060242508"}
0005433847434	FA7291	4254 712026	IRINA VOLKOVA	{"phone": "+70566585570"}
0005433847435	B840B8	5451 160149	VALERIY PAVLOV	{"phone": "+70525060888"}
0005433847436	CBF822	0223 318272	SERGEY KAZAKOV	{"email": "sergey.kazakov_27051966@postgrespro.ru", "phone": "+70856887148"}
0005433847437	6DA4A7	7190 881156	VALERIY NAZAROV	{"email": "valeriy_nazarov-1980@postgrespro.ru", "phone": "+70184457221"}
0005433847438	6DA4A7	9608 239183	LEONID ABRAMOV	{"phone": "+70219430196"}
0005433847439	6DA4A7	9517 711728	PETR SOROKIN	{"email": "sorokinpetr-011966@postgrespro.ru", "phone": "+70897340784"}
0005433847440	35BDDC	1719 618693	SVETLANA FROLOVA	{"email": "frolova.svetlana.30111967@postgrespro.ru", "phone": "+70759536637"}
0005433847441	C3E8B6	5241 010941	TIMOFEY EGOROV	{"email": "egorov_timofey-091981@postgrespro.ru", "phone": "+70059459049"}
0005433847442	27A02A	1854 076849	ANNA ZHURAVLEVA	{"email": "annazhuravleva29071973@postgrespro.ru", "phone": "+70902866682"}
0005433847443	021617	4589 876534	VALERIY SIDOROV	{"email": "v_sidorov-07101970@postgrespro.ru", "phone": "+70354303117"}
0005433847444	021617	8267 635625	ANNA DENISOVA	{"email": "anna.denisova1972@postgrespro.ru", "phone": "+70454456180"}
0005433847445	03EEBB	0899 520951	EVGENIY BORISOV	{"email": "borisov-evgeniy1982@postgrespro.ru", "phone": "+70068841319"}
0005433847446	03EEBB	7339 690323	NATALIYA VLASOVA	{"phone": "+70866095800"}
0005433847447	03EEBB	1838 742568	VERA MAKAROVA	{"email": "v-makarova-05061974@postgrespro.ru", "phone": "+70192691004"}
0005433847448	D43AC2	5912 598069	ALEKSEY VASILEV	{"email": "vasilev.a_121972@postgrespro.ru", "phone": "+70276503130"}
0005433847449	325B7B	4387 653636	VLADIMIR ISAEV	{"email": "v-isaev021977@postgrespro.ru", "phone": "+70469688561"}
0005433847450	325B7B	7296 330501	VLADIMIR ALEKSANDROV	{"phone": "+70730790824"}
0005433847451	013E2E	6933 865238	TATYANA EGOROVA	{"phone": "+70296231998"}
0005433847452	013E2E	4858 594731	VERA IVANOVA	{"phone": "+70075412024"}
0005433847453	62F4A5	3199 644668	SERGEY VOROBEV	{"email": "vorobev.sergey-031977@postgrespro.ru", "phone": "+70915513408"}
0005433847454	6982A3	1014 205130	VLADIMIR FEDOROV	{"email": "v-fedorov.11021982@postgrespro.ru", "phone": "+70613145780"}
0005433847455	161F52	5024 270569	RAISA KOROLEVA	{"email": "koroleva-raisa_1977@postgrespro.ru", "phone": "+70353351050"}
0005433847456	161F52	7798 219210	VERA CHERNOVA	{"email": "chernova-vera_1959@postgrespro.ru", "phone": "+70433978019"}
0005433847457	D0BB07	0399 404090	ALEKSANDR MOROZOV	{"email": "morozov.a_041972@postgrespro.ru", "phone": "+70902457484"}
0005433847458	52811B	2305 424131	OLGA EGOROVA	{"email": "egorova.o_081974@postgrespro.ru", "phone": "+70643099894"}
0005433847459	C16975	6558 399303	VASILIY OSIPOV	{"phone": "+70351742070"}
0005433847460	C16975	5930 425331	LYUDMILA MASLOVA	{"phone": "+70353144649"}
0005433847461	4C3AB7	3391 389074	IRINA MIRONOVA	{"phone": "+70023027724"}
0005433847462	4C3AB7	5664 780569	KONSTANTIN DMITRIEV	{"phone": "+70125019093"}
0005433847463	4C3AB7	1778 246227	SERGEY NIKOLAEV	{"email": "sergey.nikolaev031972@postgrespro.ru", "phone": "+70170205474"}
0005433847464	0B5331	1713 211512	DANIL MOISEEV	{"email": "danil-moiseev-111972@postgrespro.ru", "phone": "+70704417229"}
0005433847465	00B2FC	1382 462541	TAMARA GERASIMOVA	{"email": "gerasimova.t-1965@postgrespro.ru", "phone": "+70727969036"}
0005433847466	D166B3	7773 142488	VLADIMIR ZAKHAROV	{"phone": "+70027667668"}
0005433847467	E5F6EA	8575 244202	MARGARITA FROLOVA	{"email": "frolova-margarita091974@postgrespro.ru", "phone": "+70763676273"}
0005433847468	E5F6EA	8366 897835	DANIL FOMIN	{"email": "danil.fomin05041966@postgrespro.ru", "phone": "+70073672764"}
0005433847469	E5F6EA	5964 016700	TAMARA KARPOVA	{"phone": "+70150482453"}
0005433847470	CF4912	0531 659549	SVETLANA OSIPOVA	{"email": "osipova_svetlana.24091972@postgrespro.ru", "phone": "+70684733405"}
0005433847471	CF4912	2955 062254	ALEKSANDR MATVEEV	{"phone": "+70637218545"}
0005433847472	66FA2E	4163 602229	LILIYA SOLOVEVA	{"email": "soloveva.liliya_14071959@postgrespro.ru", "phone": "+70343656291"}
0005433847473	D6030E	8704 164406	MARINA KUZNECOVA	{"email": "kuznecovam051976@postgrespro.ru", "phone": "+70998910613"}
0005433847474	33810C	5903 526521	ANZHELIKA IVANOVA	{"phone": "+70474637350"}
0005433847711	A19888	2448 643071	EVGENIY NIKITIN	{"phone": "+70926802028"}
0005433847475	4D3267	0529 744786	OLGA ZOTOVA	{"email": "zotova-olga-13091977@postgrespro.ru", "phone": "+70485210947"}
0005433847476	5CB3A0	7091 704593	LYUBOV STEPANOVA	{"phone": "+70714486581"}
0005433847477	8F4798	3255 528786	EKATERINA ZAKHAROVA	{"phone": "+70006104201"}
0005433847478	85B14D	3793 038315	VLADIMIR BONDARENKO	{"email": "bondarenko_v_09091965@postgrespro.ru", "phone": "+70567050804"}
0005433847479	85B14D	7234 142861	SERGEY AFANASEV	{"email": "s_afanasev-111958@postgrespro.ru", "phone": "+70300017805"}
0005433847480	85B14D	6407 384046	ALISA TIKHONOVA	{"phone": "+70271139503"}
0005433847481	BD3760	5665 377283	ALINA MOROZOVA	{"phone": "+70159120422"}
0005433847482	CB9094	4319 368398	MARIYA KRASNOVA	{"phone": "+70821160707"}
0005433847483	019757	0009 398265	YURIY FEDOROV	{"email": "fedorovy_21091975@postgrespro.ru", "phone": "+70871101836"}
0005433847484	787DDC	6647 845547	ELENA FADEEVA	{"phone": "+70412726092"}
0005433847485	787DDC	7263 945395	NATALYA VOROBEVA	{"email": "vorobeva.natalya.041963@postgrespro.ru", "phone": "+70188718608"}
0005433847486	787DDC	0259 240043	SERGEY SOROKIN	{"email": "sorokin-s17061971@postgrespro.ru", "phone": "+70925699839"}
0005433847487	B1193F	2417 884223	IGOR MIRONOV	{"phone": "+70155101819"}
0005433847488	B1193F	1270 493829	GALIYA CHERNOVA	{"email": "chernovagaliya-031960@postgrespro.ru", "phone": "+70491302592"}
0005433847489	B1193F	9956 478948	SERGEY SMIRNOV	{"email": "s-smirnov021983@postgrespro.ru", "phone": "+70105851293"}
0005433847490	1ADCA4	2289 475484	NADEZHDA MOROZOVA	{"phone": "+70465534908"}
0005433847491	7EDE95	9236 172177	IGOR ZHUKOV	{"phone": "+70626312741"}
0005433847492	7E1367	4808 397743	MARIYA ANDREEVA	{"phone": "+70770939844"}
0005433847493	E9E836	0664 420261	ZAKHAR MIKHAYLOV	{"phone": "+70232578635"}
0005433847494	1D4B6F	7463 343402	SERGEY MEDVEDEV	{"phone": "+70063008604"}
0005433847495	1D4B6F	3690 749192	NADEZHDA ZAYCEVA	{"email": "nadezhda_zayceva.28121981@postgrespro.ru", "phone": "+70494839125"}
0005433847496	D23B87	4983 239134	TATYANA ZHUKOVA	{"phone": "+70342022224"}
0005433847497	42D95E	7482 788945	ANASTASIYA MIKHAYLOVA	{"phone": "+70687331086"}
0005433847498	42D95E	4629 229921	ALEKSEY TIMOFEEV	{"phone": "+70421934872"}
0005433847499	7544CA	4717 191573	VIKTORIYA ZHUKOVA	{"email": "zhukova.v_1981@postgrespro.ru", "phone": "+70695531978"}
0005433847500	8C230C	6584 782617	YURIY DAVYDOV	{"phone": "+70138193537"}
0005433847501	FCDB68	7302 415930	PETR DENISOV	{"email": "petrdenisov1969@postgrespro.ru", "phone": "+70992796362"}
0005433847502	BC30E4	4994 966953	YURIY MIRONOV	{"email": "mironov.yuriy-1972@postgrespro.ru", "phone": "+70148543364"}
0005433847503	FC2889	6537 718721	GALINA SERGEEVA	{"email": "sergeeva-g-02071981@postgrespro.ru", "phone": "+70601256904"}
0005433847504	2272AA	3810 444307	ALEKSEY MATVEEV	{"phone": "+70081827625"}
0005433847505	25306E	3745 539629	ROMAN KISELEV	{"email": "kiselev_roman_1976@postgrespro.ru", "phone": "+70419029022"}
0005433847506	1AAFB6	2696 443458	LYUDMILA ZAYCEVA	{"email": "lzayceva18011985@postgrespro.ru", "phone": "+70569634157"}
0005433847507	F5676A	4906 642631	SVETLANA SOROKINA	{"phone": "+70261223045"}
0005433847508	39E792	1460 231486	EKATERINA VLASOVA	{"email": "e.vlasova-011978@postgrespro.ru", "phone": "+70021368391"}
0005433847509	39E792	6755 793668	PETR ABRAMOV	{"phone": "+70730976517"}
0005433847510	D7B506	7132 920745	VLADIMIR MOROZOV	{"email": "v.morozov31071969@postgrespro.ru", "phone": "+70581669470"}
0005433847511	BF73E0	7264 698636	LIDIYA IVANOVA	{"phone": "+70605848512"}
0005433847512	73F453	0221 444464	ANDREY DENISOV	{"phone": "+70272862029"}
0005433847513	73F453	2574 598418	ALEKSANDR ABRAMOV	{"email": "abramov.a.27121970@postgrespro.ru", "phone": "+70992090914"}
0005433847514	7B5685	4107 374039	DARYA GERASIMOVA	{"email": "d_gerasimova.1967@postgrespro.ru", "phone": "+70371987231"}
0005433847515	7B5685	8722 451172	NINA ISAEVA	{"email": "n.isaeva-1975@postgrespro.ru", "phone": "+70657325473"}
0005433847516	7B5685	6588 649494	NIKOLAY BELOV	{"email": "n_belov_13081968@postgrespro.ru", "phone": "+70230498219"}
0005433847517	6556BA	3210 126814	ALEKSANDR MIKHAYLOV	{"phone": "+70256068381"}
0005433847518	8B50D8	2424 931270	IRINA MELNIKOVA	{"email": "melnikova-i-071977@postgrespro.ru", "phone": "+70475856908"}
0005433847519	D19277	1166 946885	ALENA KOLESNIKOVA	{"phone": "+70351332417"}
0005433847520	1F41BA	5632 077576	VLADIMIR KRASNOV	{"email": "krasnov_vladimir.011981@postgrespro.ru", "phone": "+70813450208"}
0005433847521	615A6D	4767 210846	ANASTASIYA AFANASEVA	{"email": "afanaseva_anastasiya1971@postgrespro.ru", "phone": "+70046532835"}
0005433847522	6302B6	2226 949428	KSENIYA AKIMOVA	{"email": "akimova-kseniya.1981@postgrespro.ru", "phone": "+70401695122"}
0005433847523	FE87FD	8872 572762	MAKSIM SMIRNOV	{"email": "maksimsmirnov081969@postgrespro.ru", "phone": "+70568259507"}
0005433847524	76EC8B	4456 607502	ALEKSANDRA ISAEVA	{"phone": "+70386699618"}
0005433847525	9B95C8	0871 456182	MARINA FILIPPOVA	{"phone": "+70543667548"}
0005433847526	9B95C8	1213 411604	NIKOLAY MIKHAYLOV	{"phone": "+70978656123"}
0005433847527	AB080E	1612 916358	VIKTOR NOVIKOV	{"email": "novikov_v051965@postgrespro.ru", "phone": "+70299516424"}
0005433847528	AB080E	3170 577060	ANDREY BORISOV	{"phone": "+70981106941"}
0005433847529	EBC4CB	0501 300133	SERGEY ALEKSEEV	{"phone": "+70744848969"}
0005433847530	EBC4CB	4851 540880	NIKOLAY FROLOV	{"phone": "+70631769377"}
0005433847531	2D832C	7533 021009	ALEKSEY GAVRILOV	{"email": "gavrilov_aleksey.14041972@postgrespro.ru", "phone": "+70704091436"}
0005433847532	854268	2395 395418	VIKTOR ROMANOV	{"email": "romanovv_061975@postgrespro.ru", "phone": "+70763171482"}
0005433847533	F7DE66	8167 105591	LARISA TIKHONOVA	{"email": "tikhonova_larisa_16111983@postgrespro.ru", "phone": "+70359343664"}
0005433847534	F7DE66	9113 336849	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaaleksandra041980@postgrespro.ru", "phone": "+70385066651"}
0005433847535	61017A	2109 000167	SVETLANA TIKHONOVA	{"email": "svetlana_tikhonova.1967@postgrespro.ru", "phone": "+70286536062"}
0005433847536	61017A	1001 200884	ANDREY SEMENOV	{"email": "andreysemenov1970@postgrespro.ru", "phone": "+70274899750"}
0005433847537	0FD444	5851 079879	ADELINA POPOVA	{"email": "adelina.popova_1966@postgrespro.ru", "phone": "+70862949423"}
0005433847538	72A2C7	2003 389797	VALERIY MOROZOV	{"phone": "+70286608446"}
0005433847539	08BE07	0257 880854	YURIY EGOROV	{"email": "yegorov011971@postgrespro.ru", "phone": "+70413243298"}
0005433847540	08BE07	5027 328198	ARKADIY DAVYDOV	{"email": "arkadiy_davydov_011978@postgrespro.ru", "phone": "+70806462764"}
0005433847541	87305C	6488 980752	ANZHELIKA ZOTOVA	{"email": "zotova-anzhelika-081972@postgrespro.ru", "phone": "+70156773111"}
0005433847542	4E4FD7	4510 393326	IGOR SOLOVEV	{"email": "isolovev.071976@postgrespro.ru", "phone": "+70380033984"}
0005433847543	50116F	1673 750931	ANDREY SOKOLOV	{"email": "sokolov.andrey101976@postgrespro.ru", "phone": "+70107294389"}
0005433847544	6EC622	0082 336500	EVGENIY KUDRYASHOV	{"email": "evgeniy-kudryashov1959@postgrespro.ru", "phone": "+70889409162"}
0005433847545	6EC622	7047 517196	ALEKSANDR IVANOV	{"phone": "+70340031840"}
0005433847546	6EC622	3875 326896	VALENTINA ROMANOVA	{"phone": "+70475504275"}
0005433847547	EF4EDD	2320 439059	ANASTASIYA SIDOROVA	{"phone": "+70389641767"}
0005433847548	8941A1	2485 261206	VIKTOR GAVRILOV	{"email": "gavrilovviktor021980@postgrespro.ru", "phone": "+70558580723"}
0005433847549	607A30	5392 025511	ALLA LUKYANOVA	{"email": "alukyanova-29111994@postgrespro.ru", "phone": "+70471417772"}
0005433847550	A2E6D7	0865 647533	LYUDMILA EGOROVA	{"phone": "+70277998383"}
0005433847551	A3ECF3	4158 462709	RAISA STEPANOVA	{"email": "stepanovaraisa021960@postgrespro.ru", "phone": "+70191911478"}
0005433847552	A3ECF3	5538 542692	ELENA VLASOVA	{"email": "elena-vlasova-081980@postgrespro.ru", "phone": "+70122183918"}
0005433847553	F680B1	6212 858455	DMITRIY YAKOVLEV	{"phone": "+70448312348"}
0005433847554	F680B1	1042 420769	MARINA TARASOVA	{"email": "m.tarasova.061963@postgrespro.ru", "phone": "+70192863943"}
0005433847555	531283	0166 142504	VLADIMIR KOZLOV	{"email": "kozlov-vladimir021982@postgrespro.ru", "phone": "+70361284774"}
0005433847556	14CF0F	5977 467847	EGOR KRASNOV	{"email": "egorkrasnov-1976@postgrespro.ru", "phone": "+70363181439"}
0005433847557	4ACF40	2855 927576	TAMARA GRISHINA	{"email": "grishina_t-081961@postgrespro.ru", "phone": "+70916564734"}
0005433847558	4F4999	5155 703055	ALEKSEY MOISEEV	{"email": "aleksey-moiseev_091965@postgrespro.ru", "phone": "+70963270514"}
0005433847559	4F4999	1344 113895	ALEKSANDR GERASIMOV	{"phone": "+70311806392"}
0005433847560	4F4999	0097 039248	ALEKSANDR ILIN	{"email": "ailin.28101975@postgrespro.ru", "phone": "+70393691705"}
0005433847561	F52F70	0424 700110	IVAN ANDREEV	{"email": "andreevi.1974@postgrespro.ru", "phone": "+70516216795"}
0005433847562	CC1592	0470 230734	MARIYA IVANOVA	{"email": "ivanova_m_011966@postgrespro.ru", "phone": "+70226836586"}
0005433847563	9586B0	7215 473858	VLADISLAV RODIONOV	{"email": "rodionov-v.1955@postgrespro.ru", "phone": "+70436887050"}
0005433847564	72BE2E	2272 300943	VERA DENISOVA	{"email": "denisova-v-09091979@postgrespro.ru", "phone": "+70255268024"}
0005433847565	72BE2E	3975 993576	DINA KUZMINA	{"phone": "+70274649417"}
0005433847566	BA34A7	5137 715673	OLGA LEBEDEVA	{"email": "o-lebedeva_02011971@postgrespro.ru", "phone": "+70171177130"}
0005433847567	BA34A7	8558 522733	DIANA EGOROVA	{"email": "egorova_diana081973@postgrespro.ru", "phone": "+70812529874"}
0005433847568	D86C14	7997 537671	NIKITA SMIRNOV	{"email": "smirnov-nikita041972@postgrespro.ru", "phone": "+70023755634"}
0005433847569	4FDEAC	9242 296308	ALEKSEY OSIPOV	{"email": "osipov-a.24021973@postgrespro.ru", "phone": "+70775473570"}
0005433847570	3FD205	6095 500810	YULIYA MAKSIMOVA	{"email": "y_maksimova-17091975@postgrespro.ru", "phone": "+70924749812"}
0005433847571	1731AF	4767 853209	NATALYA NESTEROVA	{"email": "natalyanesterova-1976@postgrespro.ru", "phone": "+70987362096"}
0005433847572	1731AF	9632 623654	SERGEY SOKOLOV	{"phone": "+70018006875"}
0005433847573	2B5D12	3770 362466	VERA IVANOVA	{"phone": "+70927054097"}
0005433847574	2B5D12	1817 966533	GALIYA BARANOVA	{"phone": "+70833259467"}
0005433847575	89772D	1384 978491	ALEKSEY FILIPPOV	{"phone": "+70017091876"}
0005433847576	89772D	4513 754855	GALINA SMIRNOVA	{"phone": "+70375433786"}
0005433847577	B79923	0231 094930	NINA MASLOVA	{"email": "maslova_n.091982@postgrespro.ru", "phone": "+70676357627"}
0005433847578	B79923	0176 812388	YURIY DMITRIEV	{"phone": "+70069019112"}
0005433847579	82536D	4546 693581	NINA ZHURAVLEVA	{"phone": "+70347202152"}
0005433847580	8E3778	0829 014949	EVGENIY BELOV	{"phone": "+70560172437"}
0005433847581	6034F5	5680 213688	OLEG BORISOV	{"email": "o.borisov_011969@postgrespro.ru", "phone": "+70194019026"}
0005433847582	03EC56	2890 946083	ANTON KUZNECOV	{"email": "akuznecov-24071966@postgrespro.ru", "phone": "+70136764951"}
0005433847583	A539EE	0474 982761	TATYANA ISAEVA	{"email": "tatyanaisaeva06041978@postgrespro.ru", "phone": "+70507821548"}
0005433847584	874EE1	8440 974043	DANIIL FILIPPOV	{"phone": "+70748557420"}
0005433847585	2A81EA	9620 420783	ALBINA PETROVA	{"email": "petrovaalbina1967@postgrespro.ru", "phone": "+70134364105"}
0005433847586	E44CC8	2089 994987	ALEKSEY ZAKHAROV	{"email": "zakharov_aleksey.021986@postgrespro.ru", "phone": "+70465277522"}
0005433847587	E44CC8	2624 620071	IVAN ZAKHAROV	{"email": "zakharov.i29081973@postgrespro.ru", "phone": "+70655501328"}
0005433847588	E44CC8	8425 739145	ANATOLIY KULIKOV	{"phone": "+70538661974"}
0005433847589	34CBB5	4229 071962	ALEKSANDR BORISOV	{"email": "borisova-1974@postgrespro.ru", "phone": "+70311429034"}
0005433847590	34CBB5	0571 691750	DANIL SAVELEV	{"phone": "+70845802826"}
0005433847591	D96687	2755 690385	VIKTOR VLASOV	{"email": "v.vlasov_051975@postgrespro.ru", "phone": "+70268374001"}
0005433847592	D96687	5862 990609	ANNA BELOVA	{"phone": "+70790606772"}
0005433847593	3621EA	3538 323955	VLADIMIR BARANOV	{"email": "baranov.vladimir.1974@postgrespro.ru", "phone": "+70489019119"}
0005433847594	F37E0F	5265 345199	SERGEY FEDOROV	{"email": "fedorovsergey-09071974@postgrespro.ru", "phone": "+70178064635"}
0005433847595	77BAE5	7368 959151	IGOR MAKAROV	{"email": "imakarov-20111981@postgrespro.ru", "phone": "+70992993039"}
0005433847596	AC2769	7716 453300	ALEKSANDR YAKOVLEV	{"phone": "+70594626959"}
0005433847597	45D61F	2115 264714	ANNA ZAYCEVA	{"email": "zayceva-anna.1961@postgrespro.ru", "phone": "+70287917454"}
0005433847598	83FD28	1594 741037	ALENA DANILOVA	{"email": "danilova.alena-26021977@postgrespro.ru", "phone": "+70319462245"}
0005433847599	83FD28	2540 534995	SERGEY IVANOV	{"email": "ivanov.s-25021964@postgrespro.ru", "phone": "+70420643954"}
0005433847600	CBED00	0043 368676	IVAN SCHERBAKOV	{"email": "scherbakov.i.28071966@postgrespro.ru", "phone": "+70207456386"}
0005433847601	42C111	7377 148554	VLADIMIR SMIRNOV	{"email": "v-smirnov_041974@postgrespro.ru", "phone": "+70891782369"}
0005433847602	0586B0	3715 354385	VALENTINA NOVIKOVA	{"email": "valentina_novikova1968@postgrespro.ru", "phone": "+70359323802"}
0005433847603	076F1C	1037 269592	NIKOLAY NAZAROV	{"phone": "+70615617316"}
0005433847604	076F1C	6621 584659	VLADIMIR ANDREEV	{"phone": "+70211330739"}
0005433847605	076F1C	2729 116448	DARYA GERASIMOVA	{"email": "gerasimova_d-30011967@postgrespro.ru", "phone": "+70847507072"}
0005433847606	CC115D	2688 518260	ALEKSEY CHERNOV	{"phone": "+70782876348"}
0005433847607	9BC39F	3987 828790	ELENA LUKYANOVA	{"phone": "+70522808996"}
0005433847608	541529	6389 507571	VERA SMIRNOVA	{"phone": "+70990499994"}
0005433847609	F7E1C0	5960 846943	VALERIYA EFIMOVA	{"email": "v-efimova25041976@postgrespro.ru", "phone": "+70343884038"}
0005433847610	EDD4C5	7695 489088	INNA DMITRIEVA	{"email": "dmitrievainna.21011987@postgrespro.ru", "phone": "+70393263744"}
0005433847611	3B5E14	2981 955174	YANA PETROVA	{"email": "petrova_y_1970@postgrespro.ru", "phone": "+70354428834"}
0005433847612	3B5E14	1406 208791	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov-051975@postgrespro.ru", "phone": "+70433633999"}
0005433847613	909799	0283 881129	DMITRIY MIKHAYLOV	{"email": "d_mikhaylov-031975@postgrespro.ru", "phone": "+70589696381"}
0005433847614	887A15	5587 421935	TAMARA LAZAREVA	{"phone": "+70287183459"}
0005433847615	887A15	1319 209636	VLADIMIR STEPANOV	{"email": "v_stepanov_041978@postgrespro.ru", "phone": "+70530772810"}
0005433847616	362A84	8272 848334	ARTEM NIKITIN	{"email": "artemnikitin_081964@postgrespro.ru", "phone": "+70385469661"}
0005433847617	D03FE3	8711 505650	ANATOLIY BORISOV	{"phone": "+70815193254"}
0005433847618	40E0AB	9839 650356	OLEG NIKOLAEV	{"phone": "+70049808336"}
0005433847619	918A18	0813 891669	LYUBOV ANTONOVA	{"email": "antonova.l.061970@postgrespro.ru", "phone": "+70349013615"}
0005433847620	39FDBD	3009 761602	GERMAN VLASOV	{"phone": "+70776942859"}
0005433847621	39FDBD	9254 819361	ALEKSANDR MIKHAYLOV	{"phone": "+70914358495"}
0005433847622	E7726F	8496 037400	MIKHAIL KUZMIN	{"email": "m_kuzmin_041968@postgrespro.ru", "phone": "+70404760462"}
0005433847623	4D4F46	7611 578843	EVGENIY ZAKHAROV	{"email": "evgeniy_zakharov_17111971@postgrespro.ru", "phone": "+70991135164"}
0005433847624	9BF306	6258 643865	ELENA MALYSHEVA	{"email": "malysheva_e1960@postgrespro.ru", "phone": "+70033990128"}
0005433847625	9BF306	5128 795552	OLEG MELNIKOV	{"email": "o-melnikov14021969@postgrespro.ru", "phone": "+70496606865"}
0005433847626	41564D	9738 496532	TAISA ABRAMOVA	{"email": "taisa_abramova.041976@postgrespro.ru", "phone": "+70576465411"}
0005433847627	E36939	3277 159271	NATALYA STEPANOVA	{"phone": "+70643044348"}
0005433847628	3D73A1	5270 035184	MIKHAIL GRIGOREV	{"email": "m.grigorev_1970@postgrespro.ru", "phone": "+70854021128"}
0005433847629	285672	8879 811624	ZINAIDA MELNIKOVA	{"phone": "+70632042469"}
0005433847630	285672	0227 028258	ELENA ALEKSEEVA	{"email": "alekseevae021969@postgrespro.ru", "phone": "+70426455278"}
0005433847631	28EBE9	5401 716968	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov.061970@postgrespro.ru", "phone": "+70636966360"}
0005433847632	E53598	3036 668940	ANTON SIDOROV	{"phone": "+70746608737"}
0005433847633	E53598	5584 127137	IVAN VASILEV	{"email": "vasilev.i03051969@postgrespro.ru", "phone": "+70269580156"}
0005433847634	3A150A	1256 914068	RAISA KONOVALOVA	{"email": "raisakonovalova-1971@postgrespro.ru", "phone": "+70257152484"}
0005433847635	3A150A	4451 380648	NINA KULIKOVA	{"phone": "+70306460598"}
0005433847636	84D290	3926 922109	ALINA LUKYANOVA	{"email": "lukyanovaa-071978@postgrespro.ru", "phone": "+70205148790"}
0005433847637	6A441B	6357 026005	ALEKSANDRA NESTEROVA	{"phone": "+70626653402"}
0005433847638	9356A4	9600 697242	IVAN ZAKHAROV	{"phone": "+70554396194"}
0005433847639	9356A4	1965 414860	RUSLAN DMITRIEV	{"phone": "+70505504176"}
0005433847640	D3B9A3	1589 826920	ELENA VASILEVA	{"phone": "+70358881846"}
0005433847641	A40437	5883 755796	ILYA PETROV	{"phone": "+70101518252"}
0005433847642	A40437	2488 274300	GEORGIY ZAKHAROV	{"email": "zakharov-georgiy-111970@postgrespro.ru", "phone": "+70292712809"}
0005433847643	A40437	7968 240064	MARIYA DMITRIEVA	{"phone": "+70579734294"}
0005433847757	8E32BF	1105 473989	ANDREY KOZLOV	{"phone": "+70665361031"}
0005433847644	4EBA93	4295 685916	TAMARA ZOTOVA	{"email": "t.zotova_051972@postgrespro.ru", "phone": "+70949545582"}
0005433847645	ECDEDD	1192 224875	VALERIY NOVIKOV	{"email": "novikov.v-101980@postgrespro.ru", "phone": "+70258444550"}
0005433847646	39857B	5188 482927	IGOR PETROV	{"phone": "+70015680764"}
0005433847647	39857B	4526 233393	MAKSIM NIKITIN	{"phone": "+70116143496"}
0005433847648	60EC57	5888 358618	TATYANA ERMAKOVA	{"phone": "+70115873891"}
0005433847649	8D7214	3044 595217	SERGEY MIKHAYLOV	{"phone": "+70361536264"}
0005433847650	DE31C9	7500 659182	PAVEL BORISOV	{"email": "borisov.pavel1968@postgrespro.ru", "phone": "+70061209097"}
0005433847651	DE31C9	0373 184965	NATALYA IVANOVA	{"email": "ivanova.n_01101978@postgrespro.ru", "phone": "+70290378562"}
0005433847652	51E448	9987 757791	LYUDMILA VASILEVA	{"email": "vasileva.l-1963@postgrespro.ru", "phone": "+70006176429"}
0005433847653	1CAFF3	3458 930250	VLADIMIR KRASNOV	{"email": "krasnov-vladimir10111967@postgrespro.ru", "phone": "+70890474294"}
0005433847654	1CAFF3	0772 955982	TAMARA FILIPPOVA	{"phone": "+70952926689"}
0005433847655	3C4658	4502 038441	ANDREY KUZNECOV	{"email": "andreykuznecov13081976@postgrespro.ru", "phone": "+70119045801"}
0005433847656	3C4658	3944 979089	SVETLANA DAVYDOVA	{"phone": "+70896505702"}
0005433847657	DD41A9	5880 413189	ELENA KUDRYASHOVA	{"phone": "+70377815723"}
0005433847658	DD41A9	6224 782138	NINA MOISEEVA	{"phone": "+70067460717"}
0005433847659	DD41A9	5964 412086	VIKTOR MIRONOV	{"email": "mironov_viktor_051969@postgrespro.ru", "phone": "+70484375270"}
0005433847660	E5E8E5	2678 922892	DARYA POPOVA	{"email": "popovadarya.03071967@postgrespro.ru", "phone": "+70785994043"}
0005433847661	A6DEAF	5572 167418	IRINA POLYAKOVA	{"phone": "+70571353033"}
0005433847662	A6DEAF	6879 175762	ANASTASIYA NESTEROVA	{"email": "anesterova09031961@postgrespro.ru", "phone": "+70810792512"}
0005433847663	A6DEAF	0681 849030	VLADIMIR NAZAROV	{"phone": "+70648057324"}
0005433847664	7AD090	6299 388047	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov-01121969@postgrespro.ru", "phone": "+70146322972"}
0005433847665	38418D	6090 415205	NATALYA ANDREEVA	{"phone": "+70958565808"}
0005433847666	B28A97	5943 549944	LYUDMILA DMITRIEVA	{"email": "dmitrieval121985@postgrespro.ru", "phone": "+70057496084"}
0005433847667	5F8F59	2021 332908	VLADIMIR MIKHAYLOV	{"phone": "+70916265965"}
0005433847668	FFA751	0396 351069	OLGA ANTONOVA	{"email": "oantonova-20081968@postgrespro.ru", "phone": "+70880941206"}
0005433847669	FFA751	9567 216756	TATYANA FILATOVA	{"phone": "+70259793557"}
0005433847670	D1439A	8111 507690	VALENTINA DMITRIEVA	{"phone": "+70049832271"}
0005433847671	D1439A	6867 771689	MAKSIM ANDREEV	{"phone": "+70071377881"}
0005433847672	2DA4BF	1039 544652	LILIYA FILATOVA	{"phone": "+70583786572"}
0005433847673	2DA4BF	8296 008387	VITALIY VASILEV	{"phone": "+70192763061"}
0005433847674	460E30	8035 602330	MARIYA STEPANOVA	{"phone": "+70916590625"}
0005433847675	460E30	7903 786081	OLEG ANTONOV	{"email": "olegantonov-081966@postgrespro.ru", "phone": "+70689158838"}
0005433847676	2C2AC0	6385 103240	LARISA AFANASEVA	{"phone": "+70928917875"}
0005433847677	2C2AC0	9081 124821	MARGARITA NOVIKOVA	{"email": "margarita_novikova_1963@postgrespro.ru", "phone": "+70569713872"}
0005433847678	ACEF00	9244 246098	LARISA ALEKSEEVA	{"phone": "+70106322254"}
0005433847679	ACEF00	2971 369151	SERGEY GUSEV	{"email": "s.gusev_1970@postgrespro.ru", "phone": "+70231884518"}
0005433847680	CDFE0E	7522 693683	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir.1981@postgrespro.ru", "phone": "+70464578902"}
0005433847681	7151FD	6066 791448	TATYANA KAZAKOVA	{"email": "kazakova_tatyana_051972@postgrespro.ru", "phone": "+70491720760"}
0005433847682	8DAB52	9774 691053	ANATOLIY SIDOROV	{"phone": "+70938683402"}
0005433847683	8DAB52	8771 613696	TATYANA SAVELEVA	{"phone": "+70391712312"}
0005433847684	97AC34	6092 301624	ELENA PETROVA	{"email": "elenapetrova.1977@postgrespro.ru", "phone": "+70828048230"}
0005433847685	92EEC6	8628 855676	IRINA VASILEVA	{"email": "vasileva-irina_25041971@postgrespro.ru", "phone": "+70510347974"}
0005433847686	E5791B	6360 641223	ALEKSEY PAVLOV	{"email": "a-pavlov_02021983@postgrespro.ru", "phone": "+70394229614"}
0005433847687	41A397	9612 948677	MARIYA KARPOVA	{"email": "mariya_karpova1970@postgrespro.ru", "phone": "+70906378296"}
0005433847688	41A397	0494 442860	GALINA TIKHONOVA	{"phone": "+70782636725"}
0005433847689	0AE0D7	6525 127701	ARTEM MOISEEV	{"phone": "+70897117489"}
0005433847690	925697	9978 822302	EDUARD ALEKSANDROV	{"email": "aleksandrov-eduard.07031980@postgrespro.ru", "phone": "+70662830421"}
0005433847691	294F77	5552 725794	GENNADIY GAVRILOV	{"email": "gavrilovgennadiy_31101961@postgrespro.ru", "phone": "+70190236259"}
0005433847692	1D838D	9029 917859	PETR FEDOROV	{"email": "fedorov_petr_1980@postgrespro.ru", "phone": "+70928200545"}
0005433847693	78B9CF	8148 193875	TAISIYA KOZLOVA	{"phone": "+70632856063"}
0005433847694	78B9CF	8031 221339	YULIYA MIKHAYLOVA	{"phone": "+70602309521"}
0005433847695	6C449D	1786 225861	ALEKSANDRA VOLKOVA	{"email": "a-volkova-1969@postgrespro.ru", "phone": "+70635496090"}
0005433847696	9ECAFF	4968 302116	EKATERINA MAKSIMOVA	{"email": "maksimova.e18011972@postgrespro.ru", "phone": "+70241227720"}
0005433847697	633F8B	3872 199702	TATYANA ZAKHAROVA	{"email": "t-zakharova_061980@postgrespro.ru", "phone": "+70026017511"}
0005433847698	E3B2F4	7635 792147	PETR STEPANOV	{"email": "stepanovpetr_021978@postgrespro.ru", "phone": "+70293981941"}
0005433847699	E3B2F4	4770 683855	TATYANA VASILEVA	{"phone": "+70299989299"}
0005433847700	1904C4	0080 504016	VALENTINA PAVLOVA	{"email": "pavlova_valentina_04051979@postgrespro.ru", "phone": "+70644502256"}
0005433847701	E516F0	6188 875012	VYACHESLAV MOROZOV	{"phone": "+70410318087"}
0005433847702	ED0CC4	0295 358532	TATYANA PAVLOVA	{"email": "tatyana_pavlova-041970@postgrespro.ru", "phone": "+70202757682"}
0005433847703	9A7DF7	0775 346781	ALEKSANDR KOZLOV	{"email": "kozlov_a_10121964@postgrespro.ru", "phone": "+70644307433"}
0005433847704	AA2413	5207 358761	LYUDMILA MOISEEVA	{"phone": "+70280930266"}
0005433847705	86F58C	3200 998316	SERGEY KISELEV	{"phone": "+70036997313"}
0005433847706	20BEDB	5955 842396	LYUDMILA MAKAROVA	{"email": "lyudmila.makarova.1977@postgrespro.ru", "phone": "+70069017030"}
0005433847707	20BEDB	0014 841191	ELENA GERASIMOVA	{"phone": "+70529140617"}
0005433847708	AB7258	7487 854949	VALENTINA ZAKHAROVA	{"phone": "+70258020829"}
0005433847709	FE28B0	1719 712845	GALINA KUZMINA	{"phone": "+70533553678"}
0005433847710	C33ECD	3855 258645	ELENA DENISOVA	{"email": "edenisova1963@postgrespro.ru", "phone": "+70349239621"}
0005433847712	50B0DA	9148 224030	LYUDMILA MAKAROVA	{"email": "makaroval-1965@postgrespro.ru", "phone": "+70791828286"}
0005433847713	50B0DA	2851 089878	NINA KONDRATEVA	{"phone": "+70343486897"}
0005433847714	ACC747	0878 729092	MIKHAIL ZAYCEV	{"email": "mikhail.zaycev-18091970@postgrespro.ru", "phone": "+70836872102"}
0005433847715	F6973E	2430 481630	DANIIL KOZLOV	{"email": "daniil_kozlov.26041977@postgrespro.ru", "phone": "+70455603318"}
0005433847716	0B003F	1662 406959	NIKOLAY CHERNOV	{"email": "chernov.nikolay12061963@postgrespro.ru", "phone": "+70315086678"}
0005433847717	94035D	2843 483677	ELENA FROLOVA	{"phone": "+70243906045"}
0005433847718	94035D	5804 089943	ROMAN NOVIKOV	{"phone": "+70292001924"}
0005433847719	BBE0E4	2191 547286	DMITRIY MAKAROV	{"phone": "+70494994386"}
0005433847720	B0D695	7304 679377	LYUDMILA RODIONOVA	{"phone": "+70808491353"}
0005433847721	B0D695	6796 219079	IVAN KUZNECOV	{"phone": "+70991140279"}
0005433847722	B0D695	1499 977219	NATALYA MATVEEVA	{"phone": "+70972809740"}
0005433847723	06B60C	7604 502426	ANDREY KUZNECOV	{"phone": "+70186042034"}
0005433847724	06B60C	2606 866491	ANDREY SOLOVEV	{"phone": "+70932397296"}
0005433847725	228066	2383 312452	IRINA ALEKSANDROVA	{"email": "irina.aleksandrova_1983@postgrespro.ru", "phone": "+70618097087"}
0005433847726	228066	3396 443427	EVGENIY GORBUNOV	{"phone": "+70627854492"}
0005433847727	228066	5365 456383	NIKOLAY GAVRILOV	{"phone": "+70129923694"}
0005433847728	25910D	2008 074799	PRASKOVYA VOROBEVA	{"email": "vorobeva-praskovya.1972@postgrespro.ru", "phone": "+70984985607"}
0005433847729	083AE4	7470 396255	IVAN RODIONOV	{"email": "rodionov_ivan_101967@postgrespro.ru", "phone": "+70140087160"}
0005433847730	921439	9143 180743	DAMIR VASILEV	{"phone": "+70262435009"}
0005433847731	22D651	3821 247732	TATYANA SERGEEVA	{"phone": "+70470521461"}
0005433847732	22D651	7266 202940	LARISA KOZLOVA	{"email": "larisakozlova.1957@postgrespro.ru", "phone": "+70619737794"}
0005433847733	CDF718	9435 744530	TATYANA STEPANOVA	{"phone": "+70596543193"}
0005433847734	0AAE0E	8675 640606	ALEKSANDR MELNIKOV	{"phone": "+70154712995"}
0005433847735	50E19B	3207 263225	ANATOLIY BELOV	{"phone": "+70048453955"}
0005433847736	B80480	7110 576680	LARISA IVANOVA	{"phone": "+70941718496"}
0005433847737	B80480	9322 310377	LARISA ZHUKOVA	{"email": "larisa.zhukova051978@postgrespro.ru", "phone": "+70059344438"}
0005433847738	FFFA98	0218 654781	OKSANA KOZLOVA	{"phone": "+70685369524"}
0005433847739	FFFA98	7022 732880	TATYANA GERASIMOVA	{"email": "t.gerasimova1973@postgrespro.ru", "phone": "+70317246819"}
0005433847740	EBBC08	3255 420333	TATYANA FADEEVA	{"phone": "+70622723027"}
0005433847741	7D3390	7283 327816	ALEKSANDR OSIPOV	{"phone": "+70602802109"}
0005433847742	39623B	6708 086627	ARTEM ISAEV	{"phone": "+70863460851"}
0005433847743	C9C6BA	5253 402999	ELENA ZOTOVA	{"email": "zotova.e-31051969@postgrespro.ru", "phone": "+70442392069"}
0005433847744	1BB931	2965 984719	DENIS MOISEEV	{"email": "d-moiseev_1967@postgrespro.ru", "phone": "+70812177394"}
0005433847745	1BB931	8711 741519	VALENTINA DMITRIEVA	{"phone": "+70632738701"}
0005433847746	6A9DA9	6359 585834	ALEKSANDR MOISEEV	{"phone": "+70051688744"}
0005433847747	15A618	0417 892635	ALEKSANDR TARASOV	{"phone": "+70726231699"}
0005433847748	BEFBB2	5584 843849	ALEKSANDR GORBUNOV	{"email": "gorbunov_a_081967@postgrespro.ru", "phone": "+70975691894"}
0005433847749	BEFBB2	6835 871303	ROMAN GUSEV	{"phone": "+70228705619"}
0005433847750	10B927	5695 312077	TATYANA MIKHAYLOVA	{"email": "mikhaylova_tatyana.1970@postgrespro.ru", "phone": "+70024576835"}
0005433847751	C24FF8	6880 293470	GALINA ANTONOVA	{"email": "antonova.galina.021985@postgrespro.ru", "phone": "+70014214421"}
0005433847752	C24FF8	2947 367871	MARIYA ZAKHAROVA	{"email": "mzakharova-31051972@postgrespro.ru", "phone": "+70796327700"}
0005433847753	96C067	0585 096443	VLADIMIR FROLOV	{"email": "vladimir.frolov.1967@postgrespro.ru", "phone": "+70408125080"}
0005433847754	AC3B87	5696 080542	PAVEL KUZNECOV	{"email": "kuznecovpavel09051952@postgrespro.ru", "phone": "+70780860407"}
0005433847755	4789C2	4293 507843	SERGEY FEDOROV	{"phone": "+70442319769"}
0005433847756	346148	7595 996852	DMITRIY YAKOVLEV	{"phone": "+70047478976"}
0005433847758	DAD790	2432 836650	LYUDMILA MOROZOVA	{"email": "l-morozova_22031975@postgrespro.ru", "phone": "+70509725689"}
0005433847759	58EA67	1430 494964	VIKTOR NIKITIN	{"email": "vnikitin_07031983@postgrespro.ru", "phone": "+70381797819"}
0005433847760	DD1C06	0369 571204	ALEKSANDR KISELEV	{"phone": "+70443721345"}
0005433847761	0A6B39	3864 836114	VLADIMIR KAZAKOV	{"phone": "+70234180955"}
0005433847762	0A6B39	6042 101303	VLADIMIR ANDREEV	{"phone": "+70137024636"}
0005433847763	A77859	0545 922162	RAISA DAVYDOVA	{"email": "r.davydova-12011964@postgrespro.ru", "phone": "+70662383527"}
0005433847764	A77859	3711 821422	DENIS GRIGOREV	{"phone": "+70103698418"}
0005433847765	0CC95E	1774 131763	BORIS SOROKIN	{"phone": "+70895812962"}
0005433847766	4DCC9D	5213 232089	ELENA MARTYNOVA	{"email": "elenamartynova15021975@postgrespro.ru", "phone": "+70999659375"}
0005433847767	2B4BFC	3321 340980	VLADIMIR BONDARENKO	{"phone": "+70647964789"}
0005433847768	5CFD5D	0349 830844	OLESYA POLYAKOVA	{"email": "polyakovao-1957@postgrespro.ru", "phone": "+70642473748"}
0005433847769	3CDCB5	3652 121793	ANDREY VOLKOV	{"email": "a.volkov.1976@postgrespro.ru", "phone": "+70326911578"}
0005433847770	3CDCB5	5529 271127	ALEKSANDR ABRAMOV	{"email": "abramov-a_041969@postgrespro.ru", "phone": "+70496990443"}
0005433847771	9550F8	5868 306439	VALENTINA BORISOVA	{"phone": "+70992425203"}
0005433847772	317F8A	1653 344767	DMITRIY TIMOFEEV	{"email": "d.timofeev_1982@postgrespro.ru", "phone": "+70786619121"}
0005433847773	1BC6AA	7638 511235	ALENA POPOVA	{"email": "popovaalena_03061986@postgrespro.ru", "phone": "+70458850095"}
0005433847774	5F6F92	9291 271304	ANASTASIYA ZHUKOVA	{"email": "a_zhukova_041990@postgrespro.ru", "phone": "+70102065395"}
0005433847775	38145A	3042 484557	DMITRIY ANTONOV	{"email": "antonov.d1972@postgrespro.ru", "phone": "+70720559670"}
0005433847776	22357F	1697 845250	ALEKSANDR IVANOV	{"phone": "+70910734619"}
0005433847777	6B8912	3255 530430	OLESYA MASLOVA	{"phone": "+70736174799"}
0005433847778	D4364E	6877 922456	ALISA MOROZOVA	{"email": "alisamorozova-021978@postgrespro.ru", "phone": "+70849890393"}
0005433847779	694C69	4300 250976	YURIY RODIONOV	{"email": "rodionov_y.26061958@postgrespro.ru", "phone": "+70202034968"}
0005433847780	264DF1	5951 190436	IVAN NIKITIN	{"email": "i.nikitin1963@postgrespro.ru", "phone": "+70502769852"}
0005433847781	264DF1	7505 020616	IRINA DENISOVA	{"phone": "+70598649330"}
0005433847782	EBF1BE	5895 482792	GALINA GRISHINA	{"email": "galina.grishina1966@postgrespro.ru", "phone": "+70873841941"}
0005433847783	EBF1BE	5943 286723	EVGENIY VASILEV	{"email": "vasilev.e.031974@postgrespro.ru", "phone": "+70264122047"}
0005433847784	EBF1BE	2762 551152	DMITRIY OSIPOV	{"phone": "+70475177364"}
0005433847785	9CA46A	5604 421556	IVAN ABRAMOV	{"email": "abramovi1978@postgrespro.ru", "phone": "+70743113731"}
0005433847786	FC0F67	1435 872639	IVAN ILIN	{"phone": "+70886750565"}
0005433847787	E12F57	9284 975581	SERGEY POPOV	{"email": "s.popov08061974@postgrespro.ru", "phone": "+70411717183"}
0005433847788	A5529E	8156 573720	NAIL MEDVEDEV	{"phone": "+70808370392"}
0005433847789	700D84	6744 070032	PAVEL ILIN	{"email": "ilin-pavel-20021984@postgrespro.ru", "phone": "+70248359899"}
0005433847790	531EF1	6012 159965	MARINA MAKSIMOVA	{"email": "maksimova_m-12101967@postgrespro.ru", "phone": "+70321102266"}
0005433847791	66A352	8301 997876	ILYA IVANOV	{"email": "ivanov.ilya-05021995@postgrespro.ru", "phone": "+70324377078"}
0005433847792	0BCC2F	2205 806964	NIKOLAY ZHUKOV	{"email": "zhukov.nikolay_1965@postgrespro.ru", "phone": "+70209758521"}
0005433847793	C1B56E	2339 671701	DMITRIY EGOROV	{"email": "d.egorov-051963@postgrespro.ru", "phone": "+70849582393"}
0005433847794	F1FA1F	3684 957364	VALERIY SERGEEV	{"phone": "+70825982733"}
0005433847795	7054EB	7569 291345	ALEKSANDR POPOV	{"phone": "+70337224246"}
0005433847796	445D7F	3675 635214	ANDREY KOZLOV	{"phone": "+70430962227"}
0005433847797	DB8C22	2598 306830	PAVEL KRASNOV	{"email": "pavel_krasnov_031977@postgrespro.ru", "phone": "+70336532721"}
0005433847798	DB8C22	8884 931121	MARINA MIKHAYLOVA	{"phone": "+70237544377"}
0005433847799	A8952D	4834 551860	KIRA TROFIMOVA	{"phone": "+70817521272"}
0005433847800	3DA949	3804 380737	TAMARA KOROLEVA	{"email": "tamarakoroleva_01091971@postgrespro.ru", "phone": "+70829289493"}
0005433847801	3DA949	9496 191523	ALEKSANDR KUZNECOV	{"email": "a-kuznecov_24091965@postgrespro.ru", "phone": "+70183750882"}
0005433847802	112175	6334 251216	SERGEY MOROZOV	{"email": "morozov-s-061974@postgrespro.ru", "phone": "+70876538802"}
0005433847803	EB578A	1841 459508	SERGEY CHERNOV	{"email": "sergey-chernov.061972@postgrespro.ru", "phone": "+70780216171"}
0005433847804	EB578A	8207 530499	OLGA ROMANOVA	{"email": "romanova-olga_1974@postgrespro.ru", "phone": "+70549037715"}
0005433847805	35CBF7	6269 694012	ELIZAVETA SOKOLOVA	{"email": "sokolovae021963@postgrespro.ru", "phone": "+70509597338"}
0005433847806	94407A	7619 535090	EVDOKIYA PAVLOVA	{"phone": "+70716140749"}
0005433847807	83A000	3878 549834	ANNA NOVIKOVA	{"email": "anna.novikova1976@postgrespro.ru", "phone": "+70521182805"}
0005433847808	83A000	0781 458153	VLADIMIR MIRONOV	{"email": "mironov_v-13101961@postgrespro.ru", "phone": "+70846268691"}
0005433847809	D94081	9233 762067	ANASTASIYA POPOVA	{"email": "apopova_021976@postgrespro.ru", "phone": "+70706943839"}
0005433847810	8C2ACB	7244 667450	ANASTASIYA AKIMOVA	{"phone": "+70582556207"}
0005433847811	F75C74	7468 099210	OLGA BARANOVA	{"email": "o_baranova.1974@postgrespro.ru", "phone": "+70941424235"}
0005433847812	F3D0EF	0219 191285	NATALYA ROMANOVA	{"email": "nromanova_021973@postgrespro.ru", "phone": "+70964378218"}
0005433847813	C5A108	1811 502783	ALEKSANDR ALEKSANDROV	{"phone": "+70956800925"}
0005433847814	A3BC4C	8165 782855	ALEKSEY EGOROV	{"email": "a.egorov_121972@postgrespro.ru", "phone": "+70591690335"}
0005433847815	A3BC4C	6684 869617	KLARA KUZMINA	{"email": "k.kuzmina_091976@postgrespro.ru", "phone": "+70327570417"}
0005433847816	CBA1A1	0970 444745	DMITRIY KULIKOV	{"phone": "+70437248253"}
0005433847817	7C5EFF	2118 244291	ANATOLIY MAKAROV	{"email": "makarov-anatoliy071976@postgrespro.ru", "phone": "+70909023819"}
0005433847818	7C5EFF	9573 623459	FARIT KAZAKOV	{"email": "farit_kazakov20021964@postgrespro.ru", "phone": "+70308893313"}
0005433847819	C43EB3	2415 764683	SERGEY IVANOV	{"phone": "+70840225657"}
0005433847820	EE0A0A	1983 928216	ALEKSANDR MATVEEV	{"phone": "+70578225933"}
0005433847821	EE0A0A	1299 010257	YURIY MATVEEV	{"phone": "+70910277252"}
0005433847822	ED0B8A	4831 394005	NADEZHDA GERASIMOVA	{"phone": "+70823417093"}
0005433847823	1124C8	7754 518772	NATALYA MOISEEVA	{"email": "moiseeva_n-121964@postgrespro.ru", "phone": "+70041794843"}
0005433847824	0E27C3	0169 937899	YULIYA KUZNECOVA	{"email": "y.kuznecova.1979@postgrespro.ru", "phone": "+70912990649"}
0005433847825	6EF41D	4346 458969	LYUDMILA SCHERBAKOVA	{"phone": "+70685887480"}
0005433847826	90B0B0	5635 505877	PAVEL VASILEV	{"phone": "+70177063562"}
0005433847827	90B0B0	1190 225086	ANNA KOROLEVA	{"email": "korolevaa_091977@postgrespro.ru", "phone": "+70138608029"}
0005433847828	06E9FC	6180 459362	LYUBOV PETROVA	{"phone": "+70895395098"}
0005433847829	B963D3	4761 047440	SERGEY GAVRILOV	{"phone": "+70389456448"}
0005433847830	B963D3	3318 656771	MIKHAIL GORBUNOV	{"email": "mikhail_gorbunov_1963@postgrespro.ru", "phone": "+70280792097"}
0005433847831	097761	1625 619804	ANNA ROMANOVA	{"email": "romanova-anna.011974@postgrespro.ru", "phone": "+70574808874"}
0005433847832	FB2E52	6023 940068	MAKSIM KUZNECOV	{"phone": "+70946861805"}
0005433847833	3EDD6D	2842 994824	VASILIY NIKOLAEV	{"phone": "+70304597726"}
0005433847834	464657	1949 009415	NINA KOVALEVA	{"email": "nina_kovaleva_08021982@postgrespro.ru", "phone": "+70358941140"}
0005433847835	87E1C6	0195 145469	RAISA SMIRNOVA	{"phone": "+70390753947"}
0005433847836	725EF5	6592 806745	ANNA LAZAREVA	{"phone": "+70531634467"}
0005433847837	32FFD7	1238 005336	ALEKSANDR ISAEV	{"email": "aleksandrisaev_18011979@postgrespro.ru", "phone": "+70295338203"}
0005433847838	32FFD7	0089 698832	ALEKSEY ROMANOV	{"phone": "+70321675774"}
0005433847839	BB9F68	2009 004433	SERGEY SOLOVEV	{"phone": "+70476526989"}
0005433847840	7940CE	9605 858935	EKATERINA GERASIMOVA	{"email": "e.gerasimova.051968@postgrespro.ru", "phone": "+70941748029"}
0005433847841	7940CE	0117 904949	LARISA VOLKOVA	{"phone": "+70064380556"}
0005433847842	560BB0	6823 762133	DENIS TARASOV	{"email": "dtarasov.081978@postgrespro.ru", "phone": "+70596239937"}
0005433847843	A0E9FD	6097 378990	VYACHESLAV DAVYDOV	{"phone": "+70606880587"}
0005433847844	4C1417	8940 322263	ALSU GERASIMOVA	{"phone": "+70694226082"}
0005433847845	BD5CB6	2366 799998	LYUBOV FROLOVA	{"email": "frolova-lyubov-20041964@postgrespro.ru", "phone": "+70039200489"}
0005433847846	6B392D	4444 072160	SVETLANA TIKHONOVA	{"email": "s_tikhonova_1972@postgrespro.ru", "phone": "+70761398680"}
0005433847847	0D4638	8949 910053	OLEG ORLOV	{"phone": "+70905690613"}
0005433847848	F71E46	1461 385537	SOFYA ILINA	{"email": "sofya_ilina-021965@postgrespro.ru", "phone": "+70975114833"}
0005433847849	9FCAFF	2171 825311	ALEKSANDR PETROV	{"email": "apetrov07081975@postgrespro.ru", "phone": "+70739224276"}
0005433847850	9FCAFF	0639 680941	KSENIYA SIDOROVA	{"email": "k.sidorova.101975@postgrespro.ru", "phone": "+70531607244"}
0005433847851	8B2274	8805 477679	VALENTINA KUZNECOVA	{"phone": "+70264729584"}
0005433847852	9BF173	4675 042323	NADEZHDA EFREMOVA	{"email": "nadezhda-efremova-20021972@postgrespro.ru", "phone": "+70953948130"}
0005433847853	59D81C	1428 691865	IRINA FILATOVA	{"email": "filatova-i.03061971@postgrespro.ru", "phone": "+70317344161"}
0005433847854	5BE954	5177 167815	VASILIY ZHURAVLEV	{"phone": "+70702246707"}
0005433847855	5BE954	7004 327155	SERGEY ABRAMOV	{"email": "s-abramov021975@postgrespro.ru", "phone": "+70101185502"}
0005433847856	E6CC82	7374 411548	TATYANA RYABOVA	{"phone": "+70711892368"}
0005433847857	91C5CF	4674 791815	VALERIY GUSEV	{"email": "valeriy.gusev.121965@postgrespro.ru", "phone": "+70944735563"}
0005433847858	28CAA3	3065 487138	ALEKSEY VOROBEV	{"phone": "+70197104291"}
0005433847859	E52D5D	7280 977417	STANISLAV FEDOROV	{"phone": "+70299563126"}
0005433847860	9B41BC	7468 920683	GALINA DENISOVA	{"phone": "+70658320203"}
0005433847861	9CB46B	8217 587903	VLADISLAV BELOV	{"phone": "+70388281612"}
0005433847862	A1639A	9400 868046	SERGEY KUZNECOV	{"email": "s.kuznecov_1970@postgrespro.ru", "phone": "+70942084744"}
0005433847863	A1639A	3613 620410	ANASTASIYA MOISEEVA	{"email": "moiseeva_a-061983@postgrespro.ru", "phone": "+70728864419"}
0005433847864	6DD253	0831 921609	IRINA STEPANOVA	{"phone": "+70336631027"}
0005433847865	6DD253	8698 774743	TATYANA NAUMOVA	{"email": "tatyana_naumova.091990@postgrespro.ru", "phone": "+70882015070"}
0005433847866	2762E2	6089 283691	MARIYA MAKAROVA	{"email": "mariya_makarova.011978@postgrespro.ru", "phone": "+70810361327"}
0005433847867	2762E2	2713 674679	DMITRIY KARPOV	{"phone": "+70804973346"}
0005433847868	2762E2	7440 128798	ANTONINA SERGEEVA	{"email": "sergeeva.antonina_10071978@postgrespro.ru", "phone": "+70832554810"}
0005433847869	D365F3	9438 049259	ALEKSANDR MAKAROV	{"phone": "+70380590830"}
0005433847870	A5E9A1	3408 352419	MIKHAIL BONDARENKO	{"phone": "+70695475516"}
0005433847871	A181B1	9553 687217	MIKHAIL VOLKOV	{"email": "mikhailvolkov02081977@postgrespro.ru", "phone": "+70453393446"}
0005433847872	5B9AE9	5795 357162	ANDREY MAKSIMOV	{"phone": "+70827225875"}
0005433847873	4320CD	4997 610228	ALBERT OSIPOV	{"phone": "+70096359047"}
0005433847874	2753D3	2921 166659	KSENIYA SMIRNOVA	{"email": "kseniya.smirnova-1963@postgrespro.ru", "phone": "+70336426492"}
0005433847875	2753D3	2977 508672	IVAN GERASIMOV	{"email": "gerasimov.i_121969@postgrespro.ru", "phone": "+70878310532"}
0005433847876	FC128D	2441 578435	YULIYA ERMAKOVA	{"phone": "+70523507458"}
0005433847877	C687D1	0221 133884	NINA NAZAROVA	{"phone": "+70308321937"}
0005433847878	F5A333	1096 973731	ANNA YAKOVLEVA	{"email": "anna.yakovleva.1970@postgrespro.ru", "phone": "+70424310756"}
0005433847879	F5A333	7775 201447	ANASTASIYA ZAYCEVA	{"phone": "+70038505087"}
0005433847880	C61F54	6426 488970	MARINA FEDOROVA	{"phone": "+70395517995"}
0005433847881	3E2C1F	8818 659946	ALEKSANDR DMITRIEV	{"phone": "+70580585812"}
0005433847882	6607B0	3206 800597	YURIY BONDARENKO	{"email": "yuriy-bondarenko-24041973@postgrespro.ru", "phone": "+70492536921"}
0005433847883	EDF3F7	5271 620785	VIKTOR KONOVALOV	{"phone": "+70730170619"}
0005433847884	A39C96	3589 425289	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov_1969@postgrespro.ru", "phone": "+70170705846"}
0005433847885	BC6706	9964 831911	NATALYA ALEKSANDROVA	{"email": "aleksandrovan-111978@postgrespro.ru", "phone": "+70810338049"}
0005433847886	CC11C4	7140 197205	ALEKSANDR STEPANOV	{"phone": "+70831576370"}
0005433847887	E6C64C	8894 737530	IGOR BELOV	{"email": "belov-igor-30081974@postgrespro.ru", "phone": "+70439922242"}
0005433847888	AD0922	2803 876629	OLGA SOROKINA	{"email": "o_sorokina-14041978@postgrespro.ru", "phone": "+70901366666"}
0005433847889	AD0922	6007 821390	VALENTINA PAVLOVA	{"email": "pavlovav_12101974@postgrespro.ru", "phone": "+70056131589"}
0005433847890	02DC5E	4645 088554	DENIS MIKHAYLOV	{"phone": "+70965409504"}
0005433847891	6B8774	6615 908516	SOFYA ZHURAVLEVA	{"email": "sofyazhuravleva-06021966@postgrespro.ru", "phone": "+70843604966"}
0005433847892	6B8774	5015 218735	YULIYA NIKOLAEVA	{"phone": "+70380416535"}
0005433847893	8297E4	6420 410676	EVGENIY GUSEV	{"phone": "+70307335962"}
0005433847894	0AE518	1284 967234	ANNA KOLESNIKOVA	{"phone": "+70260605822"}
0005433847895	91D97A	9279 140540	PAVEL MOROZOV	{"phone": "+70837821712"}
0005433847896	DB3B95	9019 959052	NATALIYA ERMAKOVA	{"phone": "+70709845620"}
0005433847897	58AD8B	1657 834854	EKATERINA SCHERBAKOVA	{"email": "ekaterina-scherbakova.111963@postgrespro.ru", "phone": "+70406844047"}
0005433847898	58AD8B	6209 885811	DANILA GRIGOREV	{"email": "grigorev_d091980@postgrespro.ru", "phone": "+70595092870"}
0005433847899	A15CF2	1710 089874	VASILIY SOKOLOV	{"email": "sokolovv_1972@postgrespro.ru", "phone": "+70926711388"}
0005433847900	A15CF2	5547 748949	GENNADIY MOISEEV	{"phone": "+70128113808"}
0005433847901	9026ED	9366 504293	ELENA KUZNECOVA	{"email": "kuznecova_e.011975@postgrespro.ru", "phone": "+70836999435"}
0005433847902	6B8CAD	6263 756424	TAMARA STEPANOVA	{"email": "tamara_stepanova_20021967@postgrespro.ru", "phone": "+70868853357"}
0005433847903	6B8CAD	0262 915871	ELENA AFANASEVA	{"email": "elenaafanaseva25061963@postgrespro.ru", "phone": "+70977295579"}
0005433847904	D6DB1F	8941 031604	ANNA KUDRYASHOVA	{"email": "anna_kudryashova-1976@postgrespro.ru", "phone": "+70921389380"}
0005433847905	571F04	3381 417116	NATALYA GORBUNOVA	{"phone": "+70188394176"}
0005433847906	C7CFE1	5339 262786	GALINA ALEKSANDROVA	{"email": "aleksandrova-g.1971@postgrespro.ru", "phone": "+70214589479"}
0005433847907	2099BF	2585 621648	ALEKSEY NAZAROV	{"email": "a_nazarov17011970@postgrespro.ru", "phone": "+70191796449"}
0005433847908	3E2B2E	8630 678380	VALERIYA SOKOLOVA	{"email": "valeriya_sokolova.05101970@postgrespro.ru", "phone": "+70706531009"}
0005433847909	3E2B2E	3526 372262	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev-16071977@postgrespro.ru", "phone": "+70111908414"}
0005433847910	0602E3	1272 241799	NIKOLAY MELNIKOV	{"phone": "+70373640279"}
0005433847911	0602E3	0216 209733	OLEG ROMANOV	{"phone": "+70545775797"}
0005433847912	2A0D6C	1659 344605	EVGENIY KUZMIN	{"email": "kuzmin-evgeniy_1982@postgrespro.ru", "phone": "+70572627076"}
0005433847913	A98737	2589 648815	ALEKSEY IVANOV	{"phone": "+70811664449"}
0005433847914	A98737	7233 415459	OLGA KULIKOVA	{"email": "o-kulikova_12101983@postgrespro.ru", "phone": "+70650497043"}
0005433847915	531AB2	2107 272563	VALENTINA MIRONOVA	{"email": "vmironova.1968@postgrespro.ru", "phone": "+70493182862"}
0005433847916	55FB5D	4713 853658	ELIZAVETA RYABOVA	{"phone": "+70867672465"}
0005433847917	7EE1CA	7698 294002	VIKTORIYA ISAEVA	{"phone": "+70976948325"}
0005433847918	20612D	8004 028979	VIKTOR MAKAROV	{"phone": "+70237762204"}
0005433847919	9B0C96	7093 384948	OLGA SERGEEVA	{"email": "sergeeva-o11061973@postgrespro.ru", "phone": "+70194613157"}
0005433847920	322718	1037 473495	VERA SOROKINA	{"email": "sorokinav_021970@postgrespro.ru", "phone": "+70608284803"}
0005433847921	322718	5000 845852	ARTEM BONDARENKO	{"email": "a_bondarenko051972@postgrespro.ru", "phone": "+70139473583"}
0005433847922	792DDE	1297 696971	ANDREY BORISOV	{"email": "a-borisov.061980@postgrespro.ru", "phone": "+70636812816"}
0005433847923	792DDE	5775 891039	OLGA FEDOROVA	{"phone": "+70390004839"}
0005433847924	E9BFB7	6871 683061	ELENA FEDOROVA	{"phone": "+70878935031"}
0005433847925	A6AFB3	8029 051644	NINA KOMAROVA	{"phone": "+70718768751"}
0005433847926	BD4529	0949 283890	NADEZHDA AKIMOVA	{"email": "nadezhda_akimova-23061972@postgrespro.ru", "phone": "+70708294409"}
0005433847927	BD4529	1928 148659	LEONID PETROV	{"phone": "+70994325942"}
0005433847928	4221FC	6111 242065	YURIY MATVEEV	{"phone": "+70145427264"}
0005433847929	716A1A	5933 887512	ANTON GUSEV	{"phone": "+70259300160"}
0005433847930	716A1A	5577 759494	IRINA TIKHONOVA	{"email": "irina.tikhonova.1967@postgrespro.ru", "phone": "+70858540637"}
0005433847931	11AF09	0605 333459	SERGEY VOLKOV	{"email": "volkov-s_031968@postgrespro.ru", "phone": "+70802958235"}
0005433847932	08E1A3	2332 856438	KONSTANTIN DAVYDOV	{"phone": "+70299937780"}
0005433847933	149B0F	0919 855602	LYUBOV ALEKSEEVA	{"email": "lalekseeva.17101970@postgrespro.ru", "phone": "+70306098556"}
0005433847934	AB02C7	8649 944955	DMITRIY MEDVEDEV	{"phone": "+70053236412"}
0005433847935	079DCA	3764 506140	NINA ANISIMOVA	{"phone": "+70217718678"}
0005433847936	DBC84C	7703 311577	GENNADIY PETROV	{"phone": "+70329734967"}
0005433847937	1E0300	2414 134343	EGOR IVANOV	{"phone": "+70895833659"}
0005433847938	4B65EB	3759 676513	VLADIMIR FROLOV	{"email": "frolov-v031962@postgrespro.ru", "phone": "+70595679878"}
0005433847939	DEE77D	6690 456120	VALENTINA SIDOROVA	{"email": "sidorova-valentina25071975@postgrespro.ru", "phone": "+70457035793"}
0005433847940	5B95BC	8705 911650	ANDREY KRASNOV	{"email": "andrey_krasnov1971@postgrespro.ru", "phone": "+70531716675"}
0005433847941	5B95BC	5798 115667	MARIYA VLASOVA	{"phone": "+70693120948"}
0005433847942	A9AB3B	4702 868919	IVAN NOVIKOV	{"phone": "+70022977987"}
0005433847943	2E6E39	1347 875739	MILANA YUDINA	{"email": "milana-yudina.26091964@postgrespro.ru", "phone": "+70598483931"}
0005433847944	2E6E39	9637 548367	SERGEY BORISOV	{"email": "sergey_borisov.1980@postgrespro.ru", "phone": "+70079053050"}
0005433847945	A7E120	7592 860989	OKSANA MAKAROVA	{"phone": "+70619251070"}
0005433847946	3ED396	7478 003819	ALEKSANDR SOROKIN	{"phone": "+70480033605"}
0005433847947	199DA2	1491 629585	VALERIY FROLOV	{"email": "frolovvaleriy.1965@postgrespro.ru", "phone": "+70567434954"}
0005433847948	3480FD	9702 504429	SERGEY ROMANOV	{"email": "s.romanov_1969@postgrespro.ru", "phone": "+70510518195"}
0005433847949	3480FD	6410 124607	SERGEY POPOV	{"phone": "+70935546587"}
0005433847950	75D7F2	1057 914913	ANNA RYABOVA	{"phone": "+70940522941"}
0005433847951	441230	2625 612547	PETR FEDOROV	{"phone": "+70530594877"}
0005433847952	EB97E2	7259 577643	ALIYA BOGDANOVA	{"phone": "+70939770315"}
0005433847953	331F06	7913 471055	VALENTINA MOROZOVA	{"email": "v_morozova_1979@postgrespro.ru", "phone": "+70366954728"}
0005433847954	A7865C	3614 603576	ALEKSANDR MOISEEV	{"phone": "+70561697594"}
0005433848312	086FDD	6832 527638	ANGELINA KUZMINA	{"phone": "+70053894042"}
0005433847955	ED5CE4	3212 602786	DARYA POLYAKOVA	{"email": "d-polyakova_1970@postgrespro.ru", "phone": "+70296399632"}
0005433847956	7F9CD7	5247 585209	SVETLANA AKIMOVA	{"phone": "+70783275451"}
0005433847957	7F9CD7	2971 788693	ELENA SMIRNOVA	{"phone": "+70594630593"}
0005433847958	4F30CF	6510 838725	VALENTINA NIKITINA	{"email": "nikitina.valentina17061973@postgrespro.ru", "phone": "+70757965140"}
0005433847959	4F30CF	6450 166544	YURIY SOKOLOV	{"email": "y_sokolov.091974@postgrespro.ru", "phone": "+70780345267"}
0005433847960	3BB212	6470 968251	VIKTOR VASILEV	{"phone": "+70312637819"}
0005433847961	F7CAD8	0905 438836	KONSTANTIN FOMIN	{"phone": "+70870838273"}
0005433847962	F9F93C	1512 976784	VITALIY TARASOV	{"phone": "+70546294398"}
0005433847963	22C07F	9015 940597	MARINA FEDOROVA	{"email": "fedorova_m-071964@postgrespro.ru", "phone": "+70296568633"}
0005433847964	687FDD	7678 560575	BULAT ALEKSEEV	{"email": "b-alekseev.1964@postgrespro.ru", "phone": "+70175959955"}
0005433847965	687FDD	4031 038846	SERGEY BELOV	{"email": "sergey_belov091979@postgrespro.ru", "phone": "+70417873112"}
0005433847966	17976D	0880 856572	ALEKSANDR SOKOLOV	{"phone": "+70080797110"}
0005433847967	A24E22	1488 526252	LYUBOV IVANOVA	{"email": "ivanovalyubov.1970@postgrespro.ru", "phone": "+70766026286"}
0005433847968	64F151	1511 839399	VIKTOR SMIRNOV	{"email": "smirnovv.101962@postgrespro.ru", "phone": "+70294500168"}
0005433847969	64F151	9213 167285	NADEZHDA GAVRILOVA	{"email": "gavrilovan_051982@postgrespro.ru", "phone": "+70011965839"}
0005433847970	64F151	7029 269105	MARINA SCHERBAKOVA	{"email": "scherbakova_marina.071971@postgrespro.ru", "phone": "+70116339859"}
0005433847971	798340	1915 847863	VITALIY IVANOV	{"phone": "+70922431958"}
0005433847972	798340	6957 429366	MARIYA KUZNECOVA	{"email": "mariya.kuznecova-09051972@postgrespro.ru", "phone": "+70982188719"}
0005433847973	680077	7247 956646	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov1974@postgrespro.ru", "phone": "+70769065804"}
0005433847974	DEFB0E	2836 424518	NIKOLAY ANDREEV	{"phone": "+70225997544"}
0005433847975	39CBAB	4209 933338	SERGEY ISAEV	{"email": "isaevs_071973@postgrespro.ru", "phone": "+70162011349"}
0005433847976	9CFF2D	4606 130458	TATYANA NIKOLAEVA	{"phone": "+70396415321"}
0005433847977	D10CB1	4359 544158	ANATOLIY ABRAMOV	{"email": "abramovanatoliy_25061973@postgrespro.ru", "phone": "+70345526414"}
0005433847978	D10CB1	2233 319378	VASILIY GAVRILOV	{"email": "vgavrilov-09061974@postgrespro.ru", "phone": "+70503532524"}
0005433847979	21590F	9712 861045	NATALYA KAZAKOVA	{"phone": "+70421491636"}
0005433847980	5C2E0B	0209 887285	OLGA ORLOVA	{"phone": "+70233245503"}
0005433847981	99BD93	4964 569109	VIKTOR VOLKOV	{"email": "volkov_viktor_1967@postgrespro.ru", "phone": "+70693579626"}
0005433847982	947384	0058 928364	VIKTOR KOZLOV	{"phone": "+70504578717"}
0005433847983	F50B04	4445 138105	IGOR MOISEEV	{"email": "moiseevi-021980@postgrespro.ru", "phone": "+70195946486"}
0005433847984	110528	7170 173645	ELENA BARANOVA	{"phone": "+70397430883"}
0005433847985	14BF74	8081 388875	NINA DAVYDOVA	{"email": "davydovanina.121961@postgrespro.ru", "phone": "+70340572390"}
0005433847986	14BF74	1374 130188	DMITRIY CHERNOV	{"email": "dmitriy_chernov011979@postgrespro.ru", "phone": "+70648769857"}
0005433847987	14BF74	7444 173046	ALEKSANDR KUZMIN	{"email": "a_kuzmin.1986@postgrespro.ru", "phone": "+70363220460"}
0005433847988	4E0336	9672 902360	EKATERINA ZAKHAROVA	{"email": "ekaterina.zakharova.1975@postgrespro.ru", "phone": "+70096155449"}
0005433847989	679457	6170 262409	TATYANA MAKSIMOVA	{"email": "tatyana-maksimova_1975@postgrespro.ru", "phone": "+70556805301"}
0005433847990	D8B487	3559 340508	SERGEY ANDREEV	{"email": "andreev.sergey_051976@postgrespro.ru", "phone": "+70379861794"}
0005433847991	A7B59B	1938 174070	NATALYA YAKOVLEVA	{"phone": "+70553673993"}
0005433847992	F39D34	8887 318348	ELENA NOVIKOVA	{"email": "e.novikova-011970@postgrespro.ru", "phone": "+70785978411"}
0005433847993	F39D34	2037 015062	ALEKSEY FROLOV	{"email": "frolov_a.031968@postgrespro.ru", "phone": "+70902842948"}
0005433847994	97D34F	3110 628413	ANNA KUZMINA	{"phone": "+70733161197"}
0005433847995	97D34F	5408 226484	ALEKSANDRA SOLOVEVA	{"phone": "+70356281453"}
0005433847996	AA13A9	7156 178077	VALERIY SHEVCHENKO	{"email": "shevchenko-valeriy.31121966@postgrespro.ru", "phone": "+70710882997"}
0005433847997	AA13A9	8694 443407	VLADIMIR NIKITIN	{"email": "v.nikitin23011952@postgrespro.ru", "phone": "+70200861605"}
0005433847998	8F4484	3223 610419	ALEKSANDR SHEVCHENKO	{"phone": "+70616587525"}
0005433847999	A6E6FD	6898 953239	ANATOLIY PETROV	{"phone": "+70015329750"}
0005433848000	A6E6FD	5815 494444	NATALIYA SOKOLOVA	{"phone": "+70826583829"}
0005433848001	EBC4A3	8956 382512	DENIS VOROBEV	{"email": "vorobev-d03091971@postgrespro.ru", "phone": "+70068670379"}
0005433848002	EBC4A3	8291 592999	MIKHAIL SMIRNOV	{"email": "smirnovmikhail.111977@postgrespro.ru", "phone": "+70217346759"}
0005433848003	643328	8641 337510	TATYANA IVANOVA	{"phone": "+70440117183"}
0005433848004	065CB4	7876 683140	VIKTORIYA ARKHIPOVA	{"email": "arkhipova-viktoriya.1956@postgrespro.ru", "phone": "+70769636365"}
0005433848005	28809A	4677 022443	ANDREY ANDREEV	{"email": "andreevandrey121987@postgrespro.ru", "phone": "+70816267577"}
0005433848006	4F050C	8445 008824	LYUBOV MAKAROVA	{"email": "lyubovmakarova.06111976@postgrespro.ru", "phone": "+70221213320"}
0005433848007	637542	6480 676722	YANA KONDRATEVA	{"email": "yanakondrateva.101964@postgrespro.ru", "phone": "+70209153965"}
0005433848008	B48A7C	5894 085573	MILENA ZAYCEVA	{"email": "zayceva-m.11091981@postgrespro.ru", "phone": "+70288670845"}
0005433848009	B48A7C	8381 334775	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr021963@postgrespro.ru", "phone": "+70199294034"}
0005433848010	1CB97C	9819 955330	YURIY PETROV	{"phone": "+70830649418"}
0005433848011	1CB97C	3731 775052	VLADIMIR OSIPOV	{"phone": "+70258234420"}
0005433848012	D43178	5062 548638	MARGARITA ALEKSEEVA	{"phone": "+70930555829"}
0005433848013	642C4D	1239 943269	NATALYA BOGDANOVA	{"email": "natalya_bogdanova.1981@postgrespro.ru", "phone": "+70192844067"}
0005433848014	C1A7A8	5373 013387	ELENA KRASNOVA	{"phone": "+70403529070"}
0005433848015	C1A7A8	5479 706954	DMITRIY SOROKIN	{"email": "dsorokin-051965@postgrespro.ru", "phone": "+70274798876"}
0005433848016	D863A9	5108 520768	OLEG TARASOV	{"email": "olegtarasov041971@postgrespro.ru", "phone": "+70193945684"}
0005433848017	D863A9	1678 505009	VALENTINA ROMANOVA	{"phone": "+70950236267"}
0005433848018	E7ACF5	2977 092673	TIMOFEY KARPOV	{"phone": "+70473217356"}
0005433848019	C41900	7309 951117	RAISA SEMENOVA	{"email": "raisa_semenova-20101978@postgrespro.ru", "phone": "+70321332374"}
0005433848020	CDD012	8107 991388	EVGENIY ROMANOV	{"phone": "+70350007810"}
0005433848021	CDD012	0551 659211	VENIAMIN MAKAROV	{"phone": "+70850919561"}
0005433848022	A0DF24	1801 835196	NATALYA MASLOVA	{"email": "maslovan-041976@postgrespro.ru", "phone": "+70234787063"}
0005433848023	A64F28	7158 846664	IVAN ALEKSEEV	{"email": "alekseev-i-19101979@postgrespro.ru", "phone": "+70287994115"}
0005433848024	A64F28	0981 984473	ALEKSEY FEDOROV	{"phone": "+70809481097"}
0005433848025	A80743	1416 282510	EVDOKIYA KUZMINA	{"email": "evdokiya.kuzmina.11061981@postgrespro.ru", "phone": "+70748778392"}
0005433848026	6F06FA	7467 598086	VLADIMIR STEPANOV	{"email": "stepanovvladimir04031971@postgrespro.ru", "phone": "+70617076936"}
0005433848027	A9236D	8130 958772	NIKOLAY MAKAROV	{"email": "nikolay_makarov_031979@postgrespro.ru", "phone": "+70968414339"}
0005433848028	F348B4	7949 167038	IVAN BARANOV	{"email": "baranovivan-091977@postgrespro.ru", "phone": "+70420389819"}
0005433848029	F348B4	3477 293341	LEONID SOROKIN	{"email": "leonid-sorokin-1978@postgrespro.ru", "phone": "+70480505282"}
0005433848030	DF3FF6	6455 468040	ANDREY CHERNOV	{"email": "chernov-andrey_26121985@postgrespro.ru", "phone": "+70833743712"}
0005433848031	06DC9C	7642 509833	MADINA OSIPOVA	{"phone": "+70503627527"}
0005433848032	BDA1CF	3982 468465	NATALYA FOMINA	{"email": "fomina.n_31011966@postgrespro.ru", "phone": "+70673009673"}
0005433848033	BDA1CF	1216 870401	ANGELINA ZOTOVA	{"email": "angelina-zotova_091968@postgrespro.ru", "phone": "+70395251979"}
0005433848034	08A93D	4985 269033	ELENA KALININA	{"email": "e-kalinina10111967@postgrespro.ru", "phone": "+70383274672"}
0005433848035	779624	8811 265395	ZINAIDA KOROLEVA	{"email": "zinaidakoroleva-1970@postgrespro.ru", "phone": "+70145614119"}
0005433848036	B7DCD2	2882 675889	NADEZHDA KUZNECOVA	{"phone": "+70178216799"}
0005433848037	47EDA6	3201 090413	GENNADIY SOLOVEV	{"phone": "+70059721706"}
0005433848038	FFD0C2	2493 193853	ANDREY SOROKIN	{"phone": "+70124640576"}
0005433848039	087523	0434 884700	ALEKSANDR MIRONOV	{"email": "mironov_a03031985@postgrespro.ru", "phone": "+70791871898"}
0005433848040	087523	1100 376703	TARAS NOVIKOV	{"email": "taras_novikov_1979@postgrespro.ru", "phone": "+70877005925"}
0005433848041	F0083E	5047 270136	EVGENIY KULIKOV	{"email": "kulikov-evgeniy-21031968@postgrespro.ru", "phone": "+70223273415"}
0005433848042	F0083E	6597 883745	ELENA KUZNECOVA	{"phone": "+70777841740"}
0005433848043	F0083E	3570 315161	VIKTOR KUZNECOV	{"email": "viktorkuznecov.01041978@postgrespro.ru", "phone": "+70450705844"}
0005433848044	D2444F	4012 164448	SERGEY NAZAROV	{"email": "nazarovsergey14061970@postgrespro.ru", "phone": "+70941185141"}
0005433848045	70990F	0880 575205	VALENTINA TITOVA	{"phone": "+70212134400"}
0005433848046	8D80D2	7930 481976	GALINA KRASNOVA	{"email": "g_krasnova25121975@postgrespro.ru", "phone": "+70887666099"}
0005433848047	175A76	5299 629811	ANDREY FEDOTOV	{"email": "a-fedotov.061959@postgrespro.ru", "phone": "+70355454465"}
0005433848048	57BB20	7173 895296	RUSLAN KUZNECOV	{"phone": "+70109979821"}
0005433848049	F2282A	7785 023643	FEDOR KOZLOV	{"phone": "+70498435187"}
0005433848050	E21C4E	8514 783167	OLEG KUDRYASHOV	{"email": "okudryashov26061972@postgrespro.ru", "phone": "+70268779055"}
0005433848051	996C16	0805 327048	VIKTOR KUZNECOV	{"email": "viktor-kuznecov.17011976@postgrespro.ru", "phone": "+70428476059"}
0005433848052	A6BD64	2016 158316	GENNADIY ANTONOV	{"email": "antonovg-1971@postgrespro.ru", "phone": "+70640748946"}
0005433848053	F61809	6635 073359	VERA FOMINA	{"email": "fomina.vera-05051961@postgrespro.ru", "phone": "+70143727561"}
0005433848054	2820D5	8505 802465	ALBINA VOLKOVA	{"email": "volkovaalbina_15121973@postgrespro.ru", "phone": "+70607146127"}
0005433848055	2820D5	5091 720822	ALEKSANDR VLASOV	{"phone": "+70051102400"}
0005433848056	240BE1	0914 239327	MARIYA BELOVA	{"email": "mbelova-071977@postgrespro.ru", "phone": "+70059080715"}
0005433848057	1D0EB6	0631 395491	TAMARA ANISIMOVA	{"phone": "+70250012135"}
0005433848058	1D0EB6	4403 157424	ALEKSANDR TARASOV	{"phone": "+70245254865"}
0005433848059	DAED6E	3928 119336	ANNA EGOROVA	{"email": "egorovaa29091974@postgrespro.ru", "phone": "+70201624322"}
0005433848060	4FEB2F	5240 737374	TATYANA KOLESNIKOVA	{"email": "tatyana.kolesnikova1973@postgrespro.ru", "phone": "+70097567487"}
0005433848061	4FEB2F	7097 499705	YULIYA DENISOVA	{"phone": "+70105711473"}
0005433848062	4D1D00	2542 206803	ALEKSANDRA ALEKSANDROVA	{"phone": "+70011839496"}
0005433848063	4D1D00	0243 929604	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr-13101968@postgrespro.ru", "phone": "+70668528792"}
0005433848064	52FF1D	2811 899159	IRINA AKIMOVA	{"phone": "+70646888187"}
0005433848065	52FF1D	1188 257826	LYUBOV ZHUKOVA	{"phone": "+70230219555"}
0005433848066	7B267A	4288 706707	EVGENIY MAKAROV	{"phone": "+70953232228"}
0005433848067	0FBAC6	5124 019226	SERGEY ZAKHAROV	{"phone": "+70735124828"}
0005433848068	3DB14B	8446 116996	DMITRIY ZAKHAROV	{"phone": "+70998374343"}
0005433848069	9205CD	2205 115960	ANATOLIY SIDOROV	{"email": "sidorov-anatoliy_1961@postgrespro.ru", "phone": "+70308245713"}
0005433848070	9205CD	7214 798546	BORIS BONDARENKO	{"email": "b-bondarenko-30011980@postgrespro.ru", "phone": "+70978317003"}
0005433848071	A0C2E2	3960 736369	LYUBOV CHERNOVA	{"phone": "+70516750834"}
0005433848072	A0C2E2	0161 556717	SERGEY KRASNOV	{"email": "s-krasnov-051974@postgrespro.ru", "phone": "+70045671785"}
0005433848073	BDA0D9	2440 415668	VASILIY KARPOV	{"phone": "+70416584648"}
0005433848074	BDA0D9	7948 084313	YURIY POPOV	{"phone": "+70770400341"}
0005433848075	BDA0D9	0893 503193	ZAKHAR GRIGOREV	{"email": "grigorevz1979@postgrespro.ru", "phone": "+70175271534"}
0005433848076	09A013	8432 906210	NATALYA FEDOROVA	{"email": "fedorovanatalya31071972@postgrespro.ru", "phone": "+70235162095"}
0005433848077	88534D	4457 326988	DANIIL KUZNECOV	{"email": "d.kuznecov.1973@postgrespro.ru", "phone": "+70471921741"}
0005433848078	9543F4	2657 586123	SVETLANA KOROLEVA	{"email": "korolevas01121970@postgrespro.ru", "phone": "+70575582274"}
0005433848079	AB8653	8812 924631	ALEKSEY KUZMIN	{"email": "kuzmin_a.27021978@postgrespro.ru", "phone": "+70472023533"}
0005433848080	90630D	2011 408785	VYACHESLAV STEPANOV	{"phone": "+70148724834"}
0005433848081	6AF884	6623 395177	YULIYA OVCHINNIKOVA	{"email": "ovchinnikovayuliya_1976@postgrespro.ru", "phone": "+70851751937"}
0005433848082	8F73DC	5820 092430	DMITRIY BORISOV	{"phone": "+70308577692"}
0005433848083	57CA71	0026 576820	NADEZHDA MIKHAYLOVA	{"phone": "+70489443269"}
0005433848084	881DDE	7049 522655	VLADIMIR ZAKHAROV	{"phone": "+70410923217"}
0005433848085	BC3829	6425 370610	ALENA KOZLOVA	{"email": "a.kozlova-03061973@postgrespro.ru", "phone": "+70784590800"}
0005433848086	8559D1	3163 807577	MIKHAIL PETROV	{"phone": "+70295124901"}
0005433848087	8559D1	9048 805256	OLGA MOROZOVA	{"email": "olgamorozova_11031972@postgrespro.ru", "phone": "+70673557645"}
0005433848088	DE145E	2513 547766	VYACHESLAV KUZNECOV	{"email": "kuznecov_vyacheslav29111970@postgrespro.ru", "phone": "+70587347851"}
0005433848089	DE145E	8034 525916	PAVEL NAZAROV	{"phone": "+70629510189"}
0005433848090	8C4A94	6752 874653	TAMARA DENISOVA	{"phone": "+70317909117"}
0005433848091	2D0EE9	8511 679013	SERGEY KUDRYASHOV	{"phone": "+70990060095"}
0005433848092	5CE0CC	8449 300807	YULIYA MAKAROVA	{"email": "ymakarova-18051976@postgrespro.ru", "phone": "+70490031757"}
0005433848093	405A3C	5969 599112	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-aleksandr041966@postgrespro.ru", "phone": "+70765905780"}
0005433848094	30F1CC	3432 628371	ALEKSANDR FILIPPOV	{"phone": "+70784720765"}
0005433848095	0816FA	4468 943044	GALINA NESTEROVA	{"email": "nesterova-galina051978@postgrespro.ru", "phone": "+70269096245"}
0005433848096	D5CD50	1957 074608	ANATOLIY VOROBEV	{"email": "vorobev-a_30031959@postgrespro.ru", "phone": "+70183282860"}
0005433848097	61FE43	2781 343683	ALEKSANDR MIRONOV	{"email": "mironov.a.16011971@postgrespro.ru", "phone": "+70891985667"}
0005433848098	61FE43	2879 334554	GEORGIY IVANOV	{"email": "ivanov_georgiy_1960@postgrespro.ru", "phone": "+70132606599"}
0005433848099	61FE43	0434 147773	ANATOLIY VASILEV	{"phone": "+70862926536"}
0005433848100	61FE43	4833 583887	ALBERT KUZNECOV	{"email": "a.kuznecov041960@postgrespro.ru", "phone": "+70682061672"}
0005433848101	2C71B8	6015 178221	ARTUR KUZMIN	{"phone": "+70677508472"}
0005433848102	7EB35D	4989 643041	EKATERINA LAZAREVA	{"phone": "+70076748784"}
0005433848103	7EB35D	6325 744869	ALEKSANDR POPOV	{"email": "a_popov.031968@postgrespro.ru", "phone": "+70203522250"}
0005433848104	3E9FDE	5206 030413	SVETLANA OSIPOVA	{"phone": "+70591406112"}
0005433848105	02E513	0750 940411	ANTONINA SMIRNOVA	{"phone": "+70016411596"}
0005433848106	3B4C63	5102 390636	DMITRIY PETROV	{"email": "d.petrov-1971@postgrespro.ru", "phone": "+70983070844"}
0005433848107	02E4E0	1438 125097	TATYANA POPOVA	{"phone": "+70372538144"}
0005433848108	02E4E0	8022 244537	MARINA NESTEROVA	{"email": "marinanesterova.031970@postgrespro.ru", "phone": "+70352381557"}
0005433848109	4F731B	1572 116778	VASILIY KUZNECOV	{"email": "vasiliy_kuznecov.09051972@postgrespro.ru", "phone": "+70845931880"}
0005433848110	E1CF56	5885 805211	PAVEL TIKHONOV	{"email": "tikhonovpavel_101972@postgrespro.ru", "phone": "+70006399451"}
0005433848111	5BE96A	3932 303397	VIKTORIYA SEMENOVA	{"email": "viktoriyasemenova_071964@postgrespro.ru", "phone": "+70140520743"}
0005433848112	3E37FC	9057 606961	TATYANA ANISIMOVA	{"phone": "+70725732616"}
0005433848113	4A9125	0496 137711	VLADIMIR VASILEV	{"phone": "+70339699992"}
0005433848114	2BDE43	2117 995580	NATALYA POPOVA	{"phone": "+70194281945"}
0005433848115	2888BA	4075 006136	ANASTASIYA SEMENOVA	{"email": "semenova.anastasiya01111965@postgrespro.ru", "phone": "+70623155312"}
0005433848116	A15A25	9200 291096	TATYANA MIKHAYLOVA	{"email": "tatyana-mikhaylova_021969@postgrespro.ru", "phone": "+70824100978"}
0005433848117	436E17	0987 769089	VLADIMIR KOZLOV	{"phone": "+70363770924"}
0005433848118	436E17	4688 653239	KRISTINA POPOVA	{"phone": "+70350134962"}
0005433848119	441255	9547 739705	DMITRIY PETROV	{"phone": "+70252803834"}
0005433848120	AABBB3	4444 854184	EGOR KISELEV	{"email": "kiselev.e_1982@postgrespro.ru", "phone": "+70435070584"}
0005433848121	2CAA9E	6484 291647	RAISA TITOVA	{"phone": "+70409695396"}
0005433848122	AF88B7	3602 296463	ALEKSEY KUZNECOV	{"phone": "+70788956683"}
0005433848123	F51E8F	7952 121663	ALEKSANDR KARPOV	{"email": "aleksandr_karpov.091967@postgrespro.ru", "phone": "+70522338163"}
0005433848124	E30841	7131 384479	NATALYA KOROLEVA	{"email": "koroleva.natalya-121970@postgrespro.ru", "phone": "+70086911401"}
0005433848125	E30841	5194 033614	DENIS ANDREEV	{"email": "d_andreev071968@postgrespro.ru", "phone": "+70742190839"}
0005433848126	E9B9A1	6377 196580	LYUBOV SCHERBAKOVA	{"phone": "+70160574701"}
0005433848127	E1B68C	5454 224835	VITALIY EGOROV	{"email": "egorov.vitaliy_30111966@postgrespro.ru", "phone": "+70009582285"}
0005433848128	3D0A28	4660 595543	VALENTINA GERASIMOVA	{"email": "v-gerasimova.081979@postgrespro.ru", "phone": "+70539965956"}
0005433848129	3D0A28	6235 882348	ALEKSANDR BORISOV	{"email": "borisov_aleksandr.29041970@postgrespro.ru", "phone": "+70339115073"}
0005433848130	E3716C	1200 535178	NATALYA SOLOVEVA	{"phone": "+70394096331"}
0005433848131	78F25E	4477 847668	EVGENIYA MEDVEDEVA	{"email": "evgeniya_medvedeva-021969@postgrespro.ru", "phone": "+70716267219"}
0005433848132	01D271	6015 238910	OLESYA BORISOVA	{"email": "o_borisova-1984@postgrespro.ru", "phone": "+70752323898"}
0005433848133	01D271	8238 721679	VLADIMIR IVANOV	{"phone": "+70352075044"}
0005433848134	01D271	8314 852295	EVGENIY VOLKOV	{"phone": "+70157147758"}
0005433848135	A90532	2523 515940	GRIGORIY MAKSIMOV	{"email": "maksimovg_24021970@postgrespro.ru", "phone": "+70345104859"}
0005433848136	53BEEA	8924 138836	VIKTOR NIKITIN	{"phone": "+70323136790"}
0005433848137	53BEEA	5964 744847	MIKHAIL SHEVCHENKO	{"phone": "+70035076078"}
0005433848138	CA620E	5991 261654	KRISTINA SOKOLOVA	{"email": "sokolova-kristina111967@postgrespro.ru", "phone": "+70549349684"}
0005433848139	0B473E	0696 206700	SERGEY KOZLOV	{"phone": "+70634514158"}
0005433848140	0B473E	0789 093186	NATALYA IVANOVA	{"email": "ivanovanatalya.29091977@postgrespro.ru", "phone": "+70996983592"}
0005433848141	8533D5	5936 090705	ANDREY KUZNECOV	{"email": "kuznecovandrey_01021962@postgrespro.ru", "phone": "+70315236423"}
0005433848142	55BCB1	1620 247282	OLESYA DMITRIEVA	{"email": "dmitrieva_o_1976@postgrespro.ru", "phone": "+70161048788"}
0005433848143	CED8FB	7682 730756	RUSLAN DMITRIEV	{"email": "rdmitriev.30031967@postgrespro.ru", "phone": "+70004756613"}
0005433848144	9E759C	4938 184459	ANTONINA MIRONOVA	{"phone": "+70254142262"}
0005433848145	0D0397	0465 517303	TAMARA RODIONOVA	{"email": "tamara-rodionova091973@postgrespro.ru", "phone": "+70608730277"}
0005433848146	D4B060	6162 762178	VLADIMIR GORBUNOV	{"email": "gorbunovv_1969@postgrespro.ru", "phone": "+70758618611"}
0005433848147	6845F0	8676 015859	OLGA SAVELEVA	{"phone": "+70028889952"}
0005433848148	84F674	9794 248759	NIKOLAY GRIGOREV	{"email": "ngrigorev.1968@postgrespro.ru", "phone": "+70965623814"}
0005433848149	84F674	9080 604524	VYACHESLAV KOROLEV	{"email": "korolev_vyacheslav081977@postgrespro.ru", "phone": "+70448947690"}
0005433848150	0CE93F	7259 336146	EKATERINA KOLESNIKOVA	{"phone": "+70354600481"}
0005433848151	E483D5	5164 667696	LYUDMILA DANILOVA	{"email": "danilovalyudmila1981@postgrespro.ru", "phone": "+70501211577"}
0005433848152	162A8A	2298 641243	MIKHAIL ANDREEV	{"phone": "+70475858128"}
0005433848153	76DFCB	5337 552966	ANASTASIYA TIKHONOVA	{"phone": "+70459725158"}
0005433848154	76DFCB	3049 382451	VASILIY ANDREEV	{"phone": "+70206807185"}
0005433848155	C94E66	2340 565513	BORIS STEPANOV	{"phone": "+70335769432"}
0005433848156	F2903A	6266 529737	MIKHAIL BORISOV	{"phone": "+70999112891"}
0005433848157	F2903A	2328 559733	VLADIMIR NOVIKOV	{"email": "vnovikov.091970@postgrespro.ru", "phone": "+70259952104"}
0005433848158	F2903A	8225 178646	NINA MELNIKOVA	{"phone": "+70596267503"}
0005433848159	9FF0D0	9871 983156	DANIIL MOROZOV	{"phone": "+70452490454"}
0005433848160	815CA9	4965 975875	NATALYA SEMENOVA	{"phone": "+70408342735"}
0005433848161	815CA9	2689 891694	NIKOLAY STEPANOV	{"phone": "+70062629757"}
0005433848162	2662BD	7206 307847	OLEG MELNIKOV	{"email": "o_melnikov1976@postgrespro.ru", "phone": "+70328015669"}
0005433848163	5A55AC	3620 455799	LIDIYA BOGDANOVA	{"phone": "+70956116008"}
0005433848164	F3C6C5	9681 256616	TATYANA NOVIKOVA	{"phone": "+70786022273"}
0005433848165	F3C6C5	1508 714515	VIKTOR MOROZOV	{"email": "morozov.viktor.071966@postgrespro.ru", "phone": "+70397134583"}
0005433848166	68830B	1153 543646	KIRILL MEDVEDEV	{"email": "kirill-medvedev23121973@postgrespro.ru", "phone": "+70287398960"}
0005433848167	BBDDB6	1288 370326	NIKOLAY ANTONOV	{"email": "nikolayantonov_011977@postgrespro.ru", "phone": "+70488197146"}
0005433848168	AFBAF7	0916 651130	ARINA KOROLEVA	{"email": "korolevaa_031974@postgrespro.ru", "phone": "+70533595193"}
0005433848169	65B1EB	1083 535566	MIKHAIL GORBUNOV	{"email": "gorbunov.mikhail.1971@postgrespro.ru", "phone": "+70409383789"}
0005433848170	37266F	4649 902134	VIKTOR MOROZOV	{"email": "morozov.v-15101978@postgrespro.ru", "phone": "+70364233433"}
0005433848171	7CCABF	1488 680247	NATALYA KARPOVA	{"phone": "+70168031488"}
0005433848172	A3D3A7	1988 872596	VLADIMIR ZAKHAROV	{"phone": "+70444522052"}
0005433848173	2C3FE4	3627 076905	VADIM SHEVCHENKO	{"email": "shevchenko_vadim_021983@postgrespro.ru", "phone": "+70919389632"}
0005433848174	2C3FE4	6007 776493	NINA KULIKOVA	{"email": "kulikova_n_30061977@postgrespro.ru", "phone": "+70909150890"}
0005433848175	CF130F	5951 466450	IVAN BORISOV	{"email": "borisov-i_1965@postgrespro.ru", "phone": "+70103247729"}
0005433848176	CF130F	0345 000540	KONSTANTIN BONDARENKO	{"email": "k-bondarenko.1973@postgrespro.ru", "phone": "+70390429427"}
0005433848177	6AB7AC	0902 164333	RAFIK SEMENOV	{"email": "r-semenov.121988@postgrespro.ru", "phone": "+70561270720"}
0005433848178	6AB7AC	5171 247539	TATYANA OSIPOVA	{"phone": "+70213982005"}
0005433848179	6AB7AC	1987 397028	IRINA ZAKHAROVA	{"email": "zakharova.irina.1958@postgrespro.ru", "phone": "+70487108044"}
0005433848180	7C78A0	5236 623343	VASILISA EFREMOVA	{"email": "v_efremova-01061973@postgrespro.ru", "phone": "+70374236442"}
0005433848181	17953D	8190 798774	VLADIMIR KUZNECOV	{"phone": "+70747707650"}
0005433848182	535F50	0745 765387	VYACHESLAV ALEKSEEV	{"phone": "+70603273287"}
0005433848183	FE7F02	5021 522262	DMITRIY SEMENOV	{"phone": "+70594649038"}
0005433848184	D1333C	2519 751855	VIKTOR IVANOV	{"phone": "+70404064483"}
0005433848185	CDAD15	4498 449048	SERGEY MIRONOV	{"phone": "+70302323930"}
0005433848186	5AD149	6983 662918	VADIM SOKOLOV	{"phone": "+70790596936"}
0005433848187	33DD40	4293 645584	OLGA NIKITINA	{"phone": "+70700874201"}
0005433848188	33DD40	9449 760535	STANISLAV SOKOLOV	{"phone": "+70755420962"}
0005433848189	50FBF5	5577 311450	ELENA ANTONOVA	{"phone": "+70616736344"}
0005433848190	8B34E3	0916 714309	NIKOLAY KUDRYASHOV	{"phone": "+70283568046"}
0005433848191	C83F2C	7629 668840	ALEKSEY KUDRYASHOV	{"email": "a-kudryashov-111973@postgrespro.ru", "phone": "+70076313164"}
0005433848192	3C440E	1897 882504	NIKOLAY ALEKSEEV	{"email": "alekseev_n_1986@postgrespro.ru", "phone": "+70872817657"}
0005433848193	801312	0570 721717	DENIS YAKOVLEV	{"email": "yakovlevdenis_041975@postgrespro.ru", "phone": "+70953212096"}
0005433848194	E03876	6431 371771	NIKITA SEMENOV	{"email": "nikita-semenov.071975@postgrespro.ru", "phone": "+70803972892"}
0005433848195	E87E8A	9595 931858	NIKOLAY VOROBEV	{"email": "vorobevnikolay1973@postgrespro.ru", "phone": "+70947150276"}
0005433848196	F18FFC	5681 165746	MIKHAIL ISAEV	{"email": "mikhail.isaev_1987@postgrespro.ru", "phone": "+70522504193"}
0005433848197	45F9A6	6099 582503	ALEKSANDRA MAKAROVA	{"phone": "+70622089857"}
0005433848198	45F9A6	6526 489355	ARTEM KUZMIN	{"phone": "+70721670145"}
0005433848199	53FD78	9607 759920	ANATOLIY MATVEEV	{"phone": "+70489035489"}
0005433848200	53FD78	6571 023504	ALBERT KARPOV	{"phone": "+70886501789"}
0005433848201	2BFFF5	7092 609163	TAISIYA ZAKHAROVA	{"email": "t-zakharova-1967@postgrespro.ru", "phone": "+70210997941"}
0005433848202	2BFFF5	9169 256717	VLADIMIR TIMOFEEV	{"phone": "+70608312671"}
0005433848203	8A81EA	3800 675935	SERGEY SHEVCHENKO	{"email": "s_shevchenko091971@postgrespro.ru", "phone": "+70284100157"}
0005433848204	AE8EF5	4445 002733	OLESYA FADEEVA	{"email": "olesyafadeeva-1963@postgrespro.ru", "phone": "+70434184373"}
0005433848205	6697C3	5578 470722	BOGDAN MEDVEDEV	{"email": "bogdan_medvedev011974@postgrespro.ru", "phone": "+70093170040"}
0005433848206	FF7E80	8436 235425	SERGEY VASILEV	{"phone": "+70062913635"}
0005433848207	501922	7717 650179	LIDIYA MOROZOVA	{"phone": "+70502637278"}
0005433848208	572671	9169 155238	GRIGORIY ABRAMOV	{"email": "grigoriyabramov_27031958@postgrespro.ru", "phone": "+70529680946"}
0005433848209	572671	6248 992448	NADEZHDA VOROBEVA	{"phone": "+70828992426"}
0005433848210	1071D8	3530 661492	ALINA NAUMOVA	{"phone": "+70832217872"}
0005433848211	CEF4B9	2570 390472	ANNA FOMINA	{"email": "fomina.anna08071966@postgrespro.ru", "phone": "+70629791105"}
0005433848212	CEF4B9	8750 938146	ANATOLIY SOLOVEV	{"phone": "+70715365810"}
0005433848213	CEF4B9	1418 019104	ALEKSEY SIDOROV	{"phone": "+70030594878"}
0005433848214	948CC9	8965 320836	ANNA GERASIMOVA	{"phone": "+70419648833"}
0005433848215	E7D04E	1458 774209	ALEKSEY NIKITIN	{"phone": "+70894181215"}
0005433848216	E7D04E	0906 252804	EVGENIY TIMOFEEV	{"email": "e-timofeev10121982@postgrespro.ru", "phone": "+70115817402"}
0005433848217	04EB36	7006 439425	ELENA DAVYDOVA	{"phone": "+70570009529"}
0005433848218	FBC58F	4235 074952	NINA POTAPOVA	{"phone": "+70474912566"}
0005433848219	BEF36B	2238 901941	EVGENIY DENISOV	{"email": "edenisov-21041984@postgrespro.ru", "phone": "+70219526291"}
0005433848220	BEF36B	1668 594796	GLEB ZAKHAROV	{"phone": "+70473540226"}
0005433848221	456F03	3327 948829	SVETLANA NAUMOVA	{"phone": "+70331579306"}
0005433848222	B1C3A0	9541 214726	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr_22101965@postgrespro.ru", "phone": "+70355297208"}
0005433848223	925CC7	6363 067185	ALEKSEY SERGEEV	{"phone": "+70760033522"}
0005433848224	904AA2	5145 223752	RUSLAN TIKHONOV	{"email": "rtikhonov031978@postgrespro.ru", "phone": "+70568874628"}
0005433848225	904AA2	7249 909434	EKATERINA SMIRNOVA	{"email": "smirnova_e-03051978@postgrespro.ru", "phone": "+70950373760"}
0005433848226	B8EECE	7124 008619	MARINA EGOROVA	{"email": "egorova.marina-07031965@postgrespro.ru", "phone": "+70499032784"}
0005433848227	B8EECE	2777 864304	OLGA SOLOVEVA	{"email": "olga-soloveva1964@postgrespro.ru", "phone": "+70138018617"}
0005433848228	ADFD3B	7762 640026	DMITRIY SEMENOV	{"phone": "+70513260678"}
0005433848229	ADFD3B	6915 929314	YURIY VASILEV	{"phone": "+70688744361"}
0005433848230	F0C52E	0492 111351	NIKITA GAVRILOV	{"email": "n_gavrilov22081979@postgrespro.ru", "phone": "+70035915602"}
0005433848231	9E96F1	4312 689954	EVGENIY BARANOV	{"phone": "+70769043534"}
0005433848232	774CC6	5152 161027	TATYANA MATVEEVA	{"phone": "+70284591355"}
0005433848233	774CC6	2041 971205	NATALYA GERASIMOVA	{"email": "n-gerasimova_091969@postgrespro.ru", "phone": "+70971338820"}
0005433848234	E3B04B	3868 840268	NELLI EFREMOVA	{"phone": "+70573048184"}
0005433848235	E3B04B	4770 648944	NIKITA GORBUNOV	{"email": "gorbunov_n13041976@postgrespro.ru", "phone": "+70399715211"}
0005433848236	CEB9CA	5781 778776	EKATERINA ALEKSANDROVA	{"phone": "+70600955192"}
0005433848237	CEB9CA	3133 431202	TATYANA MARTYNOVA	{"email": "martynova-tatyana_10031978@postgrespro.ru", "phone": "+70706680375"}
0005433848238	A1C8A0	5443 026050	LYUDMILA ZAKHAROVA	{"phone": "+70695305244"}
0005433848239	A1C8A0	9418 947257	DARYA IVANOVA	{"phone": "+70756793709"}
0005433848240	D399B3	9329 110509	YURIY MAKAROV	{"email": "yuriy.makarov29121961@postgrespro.ru", "phone": "+70633380653"}
0005433848241	DB21C4	4451 330509	ANDREY SAVELEV	{"phone": "+70369670625"}
0005433848242	DB21C4	3703 790261	VIKTOR PETROV	{"email": "petrov_viktor_1971@postgrespro.ru", "phone": "+70933175715"}
0005433848243	A02633	2603 034130	ALEKSANDR IVANOV	{"email": "aivanov03081973@postgrespro.ru", "phone": "+70360850946"}
0005433848244	324B8A	0956 133870	ELENA PETROVA	{"phone": "+70992020363"}
0005433848245	D9FADE	4040 803920	IRINA SMIRNOVA	{"phone": "+70161734749"}
0005433848246	3D6D57	1669 717794	IRINA BARANOVA	{"email": "irina_baranova-041970@postgrespro.ru", "phone": "+70807950104"}
0005433848247	3D6D57	9791 585690	EVGENIY ZAYCEV	{"email": "zaycev_evgeniy14121972@postgrespro.ru", "phone": "+70098643296"}
0005433848248	CB3C86	9691 089328	RAMIL MATVEEV	{"phone": "+70928587209"}
0005433848249	CB3C86	8102 374441	NATALYA KAZAKOVA	{"email": "natalya.kazakova.091979@postgrespro.ru", "phone": "+70662357468"}
0005433848250	05D485	6948 079562	SERGEY MATVEEV	{"phone": "+70356731205"}
0005433848251	CF362B	1039 314246	SERGEY ORLOV	{"email": "orlov-sergey1977@postgrespro.ru", "phone": "+70151153275"}
0005433848252	C42D88	0297 674824	EVGENIY IVANOV	{"phone": "+70876903800"}
0005433848253	4F1C43	1143 509754	ELENA POTAPOVA	{"email": "potapovaelena_05111974@postgrespro.ru", "phone": "+70927666405"}
0005433848254	D0E410	8275 133279	VLADIMIR KOROLEV	{"phone": "+70317178686"}
0005433848255	194ED3	7126 691600	SERGEY SMIRNOV	{"email": "smirnov_s-051977@postgrespro.ru", "phone": "+70480464708"}
0005433848256	3E74E2	1859 456231	NADEZHDA RYABOVA	{"email": "ryabova_n_03101970@postgrespro.ru", "phone": "+70192701656"}
0005433848257	D8B5FF	9446 492813	VIKTORIYA FEDOROVA	{"email": "fedorova_v-1976@postgrespro.ru", "phone": "+70343347484"}
0005433848258	9E5E20	9553 950358	VLADIMIR FEDOTOV	{"email": "v-fedotov-09061974@postgrespro.ru", "phone": "+70071945472"}
0005433848259	E8F9CD	2533 059793	NATALYA FOMINA	{"email": "fomina-n-011964@postgrespro.ru", "phone": "+70407303869"}
0005433848260	6D51E2	4911 058293	VIKTOR SERGEEV	{"phone": "+70525945701"}
0005433848261	6D51E2	0741 694057	NATALYA VLASOVA	{"email": "nvlasova15041975@postgrespro.ru", "phone": "+70352371968"}
0005433848262	931234	5853 525420	ANASTASIYA IVANOVA	{"phone": "+70957330334"}
0005433848263	72CF2B	1088 242042	DMITRIY ZHUKOV	{"email": "dmitriy-zhukov_1980@postgrespro.ru", "phone": "+70109771039"}
0005433848264	3712DA	4447 542743	LYUBOV LOGINOVA	{"email": "lyubov.loginova_081983@postgrespro.ru", "phone": "+70082617297"}
0005433848265	4672D1	7714 286354	EKATERINA KOZLOVA	{"email": "e.kozlova_121979@postgrespro.ru", "phone": "+70175913479"}
0005433848266	803705	8929 927559	TATYANA FEDOROVA	{"email": "fedorova-t.1983@postgrespro.ru", "phone": "+70480357745"}
0005433848267	803705	7267 082794	ANTON VLASOV	{"email": "vlasov.a-1985@postgrespro.ru", "phone": "+70313389973"}
0005433848268	DB2127	6874 029123	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov.22111965@postgrespro.ru", "phone": "+70133929977"}
0005433848269	DB2127	9311 100109	LYUDMILA SOROKINA	{"email": "l_sorokina031976@postgrespro.ru", "phone": "+70378609772"}
0005433848270	30C1D5	6429 688222	MARINA RODIONOVA	{"email": "rodionova-m_1971@postgrespro.ru", "phone": "+70004737634"}
0005433848271	063533	0789 246718	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev-1971@postgrespro.ru", "phone": "+70313113328"}
0005433848272	063533	7113 866990	ELENA SMIRNOVA	{"email": "elena-smirnova.16101971@postgrespro.ru", "phone": "+70768674715"}
0005433848273	3A26C3	5505 775235	VERA ZOTOVA	{"phone": "+70760182155"}
0005433848274	3A26C3	8076 623695	MARIYA KUZNECOVA	{"email": "kuznecova-mariya-21111964@postgrespro.ru", "phone": "+70913519491"}
0005433848275	E5A57D	8300 780748	MARGARITA FOMINA	{"email": "fomina-margarita_121972@postgrespro.ru", "phone": "+70683343718"}
0005433848276	0DADA1	7627 104232	ELENA TIKHONOVA	{"phone": "+70298058057"}
0005433848277	32129D	7679 810484	NATALYA PETROVA	{"email": "petrovanatalya1942@postgrespro.ru", "phone": "+70410581441"}
0005433848278	E4DB69	4163 586670	POLINA NAZAROVA	{"phone": "+70175006395"}
0005433848279	412766	0986 213169	NIKOLAY FILIPPOV	{"phone": "+70317088445"}
0005433848280	412766	5330 738630	AYRAT MOROZOV	{"phone": "+70958973446"}
0005433848281	412766	8999 366008	KSENIYA NIKITINA	{"email": "kseniyanikitina-1978@postgrespro.ru", "phone": "+70019751576"}
0005433848282	81075A	7433 095148	ANATOLIY KULIKOV	{"phone": "+70274756189"}
0005433848283	2E2031	0492 082549	TATYANA KOZLOVA	{"phone": "+70656627384"}
0005433848284	EBF9B7	1622 885416	DMITRIY MELNIKOV	{"phone": "+70691786023"}
0005433848285	EBF9B7	1544 877343	ALEKSANDR SMIRNOV	{"phone": "+70131846344"}
0005433848286	6D8DDA	9779 165698	ROZA GAVRILOVA	{"email": "r_gavrilova-02041975@postgrespro.ru", "phone": "+70117068981"}
0005433848287	444C7A	5038 958074	VIKTOR KISELEV	{"phone": "+70134739820"}
0005433848288	444C7A	2991 177693	OLEG IVANOV	{"phone": "+70849927824"}
0005433848289	444C7A	3526 431984	ANDREY BELOV	{"email": "belov-andrey021980@postgrespro.ru", "phone": "+70544108268"}
0005433848290	5C6452	7557 647743	ALEKSEY ROMANOV	{"phone": "+70600268941"}
0005433848291	36C2AC	3770 689528	ANNA KUZNECOVA	{"phone": "+70648625054"}
0005433848292	36C2AC	7341 680029	NINA MIKHAYLOVA	{"email": "n.mikhaylova.1970@postgrespro.ru", "phone": "+70012402065"}
0005433848293	C93207	0233 208052	SERGEY SIDOROV	{"email": "sidorov_s-011974@postgrespro.ru", "phone": "+70260676714"}
0005433848294	104550	6202 852988	MARGARITA KUZNECOVA	{"phone": "+70458431675"}
0005433848295	104550	2518 667215	NIKOLAY ANTONOV	{"email": "nikolay_antonov_1978@postgrespro.ru", "phone": "+70155357292"}
0005433848296	E7ECDC	0051 063733	MARINA PETROVA	{"email": "petrova.m15081974@postgrespro.ru", "phone": "+70125522187"}
0005433848297	E7ECDC	3516 166194	ANATOLIY KUZMIN	{"email": "kuzmin-anatoliy20101975@postgrespro.ru", "phone": "+70366366294"}
0005433848298	E65012	5195 866426	IDA STEPANOVA	{"phone": "+70176869704"}
0005433848299	AD6569	2230 418118	ELENA PAVLOVA	{"phone": "+70785750534"}
0005433848300	AD6569	7823 403242	ANDREY MIRONOV	{"phone": "+70583269619"}
0005433848301	404ACA	0324 269582	ANASTASIYA SAVELEVA	{"email": "saveleva_a-021957@postgrespro.ru", "phone": "+70755908010"}
0005433848302	76F5D5	4325 990798	LYUDMILA MASLOVA	{"email": "masloval-21021972@postgrespro.ru", "phone": "+70029487026"}
0005433848303	76F5D5	6873 702082	LYUBOV AKIMOVA	{"phone": "+70661078335"}
0005433848304	91C323	6629 622268	GALINA KONDRATEVA	{"email": "kondrateva_galina121972@postgrespro.ru", "phone": "+70529620004"}
0005433848305	5D403F	2006 518869	NATALYA NAZAROVA	{"phone": "+70190882423"}
0005433848306	A84FE1	0546 938196	ALEKSANDR PETROV	{"email": "a.petrov.30071972@postgrespro.ru", "phone": "+70931290294"}
0005433848307	E2D03C	5633 579928	ALEKSEY FEDOROV	{"email": "fedorov-aleksey.111971@postgrespro.ru", "phone": "+70366892910"}
0005433848308	D0C5EA	6995 427219	MARIYA CHERNOVA	{"phone": "+70375275124"}
0005433848309	6CC2C2	7064 750223	VLADISLAV GAVRILOV	{"phone": "+70014086961"}
0005433848310	6CC2C2	4715 910779	SERGEY KUZMIN	{"email": "kuzmin_sergey-08081966@postgrespro.ru", "phone": "+70319733897"}
0005433848311	B994D4	5516 473638	VALERIYA YUDINA	{"email": "yudina.v-1976@postgrespro.ru", "phone": "+70545725061"}
0005433848313	42D900	1598 879756	NATALYA DENISOVA	{"phone": "+70802127075"}
0005433848314	42D900	3882 798629	VLADIMIR PETROV	{"phone": "+70645550644"}
0005433848315	F915B0	5318 275894	ALEKSANDR SHEVCHENKO	{"phone": "+70590459532"}
0005433848316	F915B0	2279 566236	DANILA MARTYNOV	{"email": "danila_martynov.1981@postgrespro.ru", "phone": "+70408882071"}
0005433848317	F915B0	9755 027541	NINA PETROVA	{"email": "petrova-n.05011974@postgrespro.ru", "phone": "+70141052438"}
0005433848318	6BD745	5536 223435	KIRILL IVANOV	{"phone": "+70453607712"}
0005433848319	6BD745	9748 400196	OLGA ANTONOVA	{"phone": "+70499450936"}
0005433848320	2F2D45	0309 625424	VALENTINA GAVRILOVA	{"phone": "+70146336581"}
0005433848321	2F2D45	8715 164590	DMITRIY STEPANOV	{"email": "stepanov.d-081970@postgrespro.ru", "phone": "+70241531464"}
0005433848322	362C2B	0159 308912	YULIYA ZAKHAROVA	{"phone": "+70814906659"}
0005433848323	4B2942	2705 497013	MAKSIM ALEKSANDROV	{"email": "maleksandrov.21091972@postgrespro.ru", "phone": "+70619752575"}
0005433848324	CFC315	6219 932198	LYUDMILA PAVLOVA	{"email": "pavlova.lyudmila26041962@postgrespro.ru", "phone": "+70498295942"}
0005433848325	2CB456	1494 857252	VLADIMIR MATVEEV	{"email": "matveev_vladimir_061975@postgrespro.ru", "phone": "+70583967426"}
0005433848326	2CB456	0355 125486	ALEKSANDR GERASIMOV	{"email": "gerasimov.a.1968@postgrespro.ru", "phone": "+70504880686"}
0005433848327	35D915	0341 201250	ALEKSEY FROLOV	{"email": "aleksey.frolov.1978@postgrespro.ru", "phone": "+70053193894"}
0005433848328	D3A596	5170 378235	ANDREY GUSEV	{"phone": "+70790088844"}
0005433848329	FEC04A	3745 452600	VERA AFANASEVA	{"email": "afanaseva_v-31051974@postgrespro.ru", "phone": "+70139401992"}
0005433848330	BBE059	1588 926516	LYUDMILA POPOVA	{"email": "l.popova-1960@postgrespro.ru", "phone": "+70266714842"}
0005433848331	73CA71	6465 237179	SERGEY MOROZOV	{"email": "morozov-s_1964@postgrespro.ru", "phone": "+70869792234"}
0005433848332	73CA71	2313 267370	VALENTINA MELNIKOVA	{"email": "v_melnikova_111976@postgrespro.ru", "phone": "+70100057420"}
0005433848333	42D868	0311 415905	TAMARA RYABOVA	{"phone": "+70761461180"}
0005433848334	42D868	5489 703336	ANNA MELNIKOVA	{"email": "a-melnikova_01041970@postgrespro.ru", "phone": "+70511670227"}
0005433848335	CB402C	2758 670985	NATALYA TARASOVA	{"phone": "+70528499254"}
0005433848336	CB402C	7611 035215	VALENTINA SCHERBAKOVA	{"email": "valentinascherbakova-11011980@postgrespro.ru", "phone": "+70862886217"}
0005433848337	6C1666	5831 450472	EGOR SHEVCHENKO	{"email": "egor_shevchenko.111971@postgrespro.ru", "phone": "+70207101554"}
0005433848338	A3AD93	0744 712339	ANDREY KOZLOV	{"phone": "+70954514652"}
0005433848339	328534	8087 006798	OLGA ILINA	{"email": "oilina051974@postgrespro.ru", "phone": "+70291449972"}
0005433848340	CDDD05	9398 113351	NAILYA IVANOVA	{"email": "n.ivanova_19071976@postgrespro.ru", "phone": "+70668298791"}
0005433848341	43635D	0392 550832	OLGA BELYAEVA	{"phone": "+70330829902"}
0005433848342	932F2B	1470 455765	ILYA MAKAROV	{"phone": "+70371788470"}
0005433848343	932F2B	8310 773513	ANGELINA ZHURAVLEVA	{"email": "zhuravleva-angelina02121972@postgrespro.ru", "phone": "+70957278269"}
0005433848344	4E6574	2948 945190	TATYANA EFIMOVA	{"phone": "+70405400738"}
0005433848345	4E6574	8957 186640	VYACHESLAV KOZLOV	{"phone": "+70134366065"}
0005433848346	5410E6	3656 635931	TATYANA POPOVA	{"email": "popova-t.041987@postgrespro.ru", "phone": "+70798215898"}
0005433848347	5410E6	3675 438205	NATALYA MALYSHEVA	{"phone": "+70667183346"}
0005433848348	49C636	4185 099867	LIDIYA FILIPPOVA	{"phone": "+70185563844"}
0005433848349	69A724	0844 090160	DENIS RODIONOV	{"phone": "+70557938942"}
0005433848350	D93DB6	6909 758796	NATALYA IVANOVA	{"email": "ivanovan_1977@postgrespro.ru", "phone": "+70394748397"}
0005433848351	A29B53	3300 778156	KLAVDIYA VASILEVA	{"email": "vasileva-k101984@postgrespro.ru", "phone": "+70783663676"}
0005433848352	A29B53	2803 252331	PETR PAVLOV	{"email": "petr-pavlov_20091967@postgrespro.ru", "phone": "+70565415779"}
0005433848353	5AF2B7	6407 336818	KSENIYA ISAEVA	{"email": "isaeva-k_1977@postgrespro.ru", "phone": "+70009671977"}
0005433848354	48F033	1921 356687	SOFYA SERGEEVA	{"email": "sofyasergeeva.01121977@postgrespro.ru", "phone": "+70076520469"}
0005433848355	48F033	2439 053878	ANTONINA ISAEVA	{"phone": "+70412265382"}
0005433848356	55CB27	4895 880347	ALEVTINA IVANOVA	{"email": "ivanova-alevtina.1974@postgrespro.ru", "phone": "+70605698318"}
0005433848357	0FCC6C	2792 992664	ALEKSANDR MATVEEV	{"phone": "+70859943531"}
0005433848358	6C9D0F	7742 333554	NATALYA FILIPPOVA	{"email": "natalyafilippova.061975@postgrespro.ru", "phone": "+70007891219"}
0005433848359	6C9D0F	5504 956935	ANATOLIY VOLKOV	{"email": "volkovanatoliy_061973@postgrespro.ru", "phone": "+70096168505"}
0005433848360	4ADE53	1553 443249	KSENIYA KISELEVA	{"phone": "+70661868043"}
0005433848361	4A2A61	8530 067057	NADEZHDA FILIPPOVA	{"phone": "+70285264893"}
0005433848362	666A3B	9283 605009	VADIM BONDARENKO	{"phone": "+70078602171"}
0005433848363	95F828	7167 958711	TATYANA NAZAROVA	{"email": "nazarova_t.23101982@postgrespro.ru", "phone": "+70806102961"}
0005433848364	95F828	4832 140891	ANTONINA TIKHONOVA	{"phone": "+70283326159"}
0005433848365	95F828	2519 544589	MIKHAIL NAZAROV	{"email": "nazarovmikhail_28021976@postgrespro.ru", "phone": "+70939654578"}
0005433848366	BFE8B0	3917 303355	DMITRIY ZAYCEV	{"email": "dmitriy_zaycev-1973@postgrespro.ru", "phone": "+70156621522"}
0005433848367	BFE8B0	7706 437085	YURIY PAVLOV	{"email": "pavlovyuriy-041976@postgrespro.ru", "phone": "+70183981895"}
0005433848368	CFE1CB	2619 341937	TATYANA SOKOLOVA	{"phone": "+70951295865"}
0005433848369	7AAFC9	7912 478376	LYUBOV GORBUNOVA	{"email": "gorbunova.lyubov_03041961@postgrespro.ru", "phone": "+70748201146"}
0005433848370	7AAFC9	1845 999320	ANTON SAVELEV	{"email": "anton-savelev.08041973@postgrespro.ru", "phone": "+70575652484"}
0005433848371	FB59BC	3550 644186	LILIYA BELOVA	{"phone": "+70858645490"}
0005433848372	DE8B3C	4276 855347	LIDIYA ALEKSEEVA	{"phone": "+70109461964"}
0005433848373	A86078	3819 893238	VLADIMIR DENISOV	{"email": "denisov.vladimir-19031979@postgrespro.ru", "phone": "+70225889557"}
0005433848374	2B186F	8426 335476	ALEKSEY NIKITIN	{"email": "a-nikitin_101984@postgrespro.ru", "phone": "+70323499685"}
0005433848375	FC52D6	8914 545529	ANATOLIY KRASNOV	{"phone": "+70166273065"}
0005433848376	916C2E	2816 627177	MAKSIM ILIN	{"email": "m-ilin-14051970@postgrespro.ru", "phone": "+70647038505"}
0005433848377	F9B67A	5526 763035	TIMUR SCHERBAKOV	{"email": "t-scherbakov-31081969@postgrespro.ru", "phone": "+70037828108"}
0005433848378	F9B67A	3252 296492	SERGEY FEDOROV	{"phone": "+70014979906"}
0005433848379	BB06BE	0831 107295	EKATERINA PETROVA	{"email": "petrova_e12071968@postgrespro.ru", "phone": "+70379408199"}
0005433848380	684A64	9779 187372	VERA POLYAKOVA	{"email": "polyakova-v-1970@postgrespro.ru", "phone": "+70569920596"}
0005433848381	258151	1628 692595	ANATOLIY SCHERBAKOV	{"email": "anatoliy-scherbakov1977@postgrespro.ru", "phone": "+70694732310"}
0005433848382	258151	3265 318604	KRISTINA ABRAMOVA	{"email": "k-abramova_081976@postgrespro.ru", "phone": "+70347056307"}
0005433848383	354114	9837 296621	ANASTASIYA TARASOVA	{"email": "tarasovaa_1980@postgrespro.ru", "phone": "+70131144711"}
0005433848384	354114	5890 497917	ALEKSANDR PETROV	{"email": "petrov-a091988@postgrespro.ru", "phone": "+70172731308"}
0005433848385	2F073A	0765 082871	SERGEY IVANOV	{"email": "ivanov_sergey_10061969@postgrespro.ru", "phone": "+70099937316"}
0005433848386	FB9103	0786 790119	ANNA SEMENOVA	{"phone": "+70207007812"}
0005433848387	F9C8E7	7059 086962	ZHANNA GRISHINA	{"phone": "+70498385668"}
0005433848388	94F595	9466 871843	VLADIMIR ABRAMOV	{"email": "v.abramov-081981@postgrespro.ru", "phone": "+70986282959"}
0005433848389	3ACDF0	1017 023388	EVGENIY ZAKHAROV	{"email": "zakharov_e1965@postgrespro.ru", "phone": "+70992163075"}
0005433848390	52CDFA	0084 010399	VIKTOR DAVYDOV	{"email": "davydov-viktor.20011968@postgrespro.ru", "phone": "+70064850959"}
0005433848391	B24FE9	6881 340536	NATALYA OSIPOVA	{"phone": "+70238031054"}
0005433848392	369FF5	3852 585334	ALEKSANDR PETROV	{"email": "aleksandr-petrov-20031973@postgrespro.ru", "phone": "+70207516180"}
0005433848393	369FF5	9736 247358	ALEKSEY KOROLEV	{"email": "koroleva-22111967@postgrespro.ru", "phone": "+70771354805"}
0005433848394	F9AF32	6598 237392	SERGEY POPOV	{"phone": "+70850917093"}
0005433848395	27C5E7	4836 511246	VERA ABRAMOVA	{"phone": "+70666578630"}
0005433848396	27C5E7	4696 608727	DMITRIY ALEKSEEV	{"email": "alekseev_d-1968@postgrespro.ru", "phone": "+70893977759"}
0005433848397	3D83A0	5134 954571	EVGENIY VASILEV	{"phone": "+70298679021"}
0005433848398	3D83A0	7525 017858	IGOR MAKAROV	{"phone": "+70628455573"}
0005433848399	4D4345	8318 204822	PAVEL IVANOV	{"email": "ivanov_pavel.1983@postgrespro.ru", "phone": "+70010990637"}
0005433848400	AFD117	2851 796722	VALERIY IVANOV	{"phone": "+70933813205"}
0005433848401	AFD117	1444 296512	NAIL ZHURAVLEV	{"phone": "+70190093141"}
0005433848402	AFD117	3188 186220	TATYANA MAKAROVA	{"email": "makarova_tatyana091966@postgrespro.ru", "phone": "+70541420569"}
0005433848403	F4C9E4	1033 980207	ALEKSANDR BORISOV	{"email": "borisov.a_13071956@postgrespro.ru", "phone": "+70069570980"}
0005433848404	F4C9E4	2437 552354	SERGEY IVANOV	{"email": "ivanovsergey-101989@postgrespro.ru", "phone": "+70760184334"}
0005433848405	473D90	0036 023936	ANATOLIY KOZLOV	{"phone": "+70844001094"}
0005433848406	588BCF	9286 870009	ZOYA ISAEVA	{"email": "isaeva.zoya.29071973@postgrespro.ru", "phone": "+70288067003"}
0005433848407	75CF83	3153 127697	VALENTINA MIKHAYLOVA	{"email": "valentinamikhaylova-1973@postgrespro.ru", "phone": "+70262020935"}
0005433848408	62DDC4	3805 696376	IRINA CHERNOVA	{"email": "ichernova-21121986@postgrespro.ru", "phone": "+70769514215"}
0005433848409	3153FA	5019 511282	DAVID DAVYDOV	{"phone": "+70903435814"}
0005433848410	8E98F0	5921 568240	YURIY KUZNECOV	{"email": "kuznecovyuriy.121982@postgrespro.ru", "phone": "+70999699049"}
0005433848411	3E4964	5834 335277	VLADIMIR MELNIKOV	{"phone": "+70631664434"}
0005433848412	3E4964	4095 199364	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.1970@postgrespro.ru", "phone": "+70264938904"}
0005433867821	3E0199	6286 862490	TATYANA ROMANOVA	{"phone": "+70378064232"}
0005433867727	1A4F98	3779 319020	ZINAIDA KUZMINA	{"email": "z-kuzmina-081961@postgrespro.ru", "phone": "+70527649957"}
0005433867728	7B7BB5	5706 394457	NINA TARASOVA	{"email": "ninatarasova071968@postgrespro.ru", "phone": "+70055907232"}
0005433867729	BB9536	1845 451377	LYUBOV KAZAKOVA	{"email": "kazakova-lyubov-31011962@postgrespro.ru", "phone": "+70078921627"}
0005433867730	BB9536	5840 929800	ALEKSEY IVANOV	{"email": "aleksey.ivanov_24101970@postgrespro.ru", "phone": "+70357770650"}
0005433867731	949E06	5642 072387	GULFIYA STEPANOVA	{"email": "stepanova_g.1973@postgrespro.ru", "phone": "+70880890674"}
0005433867732	E0BC28	6525 373320	SERGEY PETROV	{"phone": "+70686889442"}
0005433867733	487E33	3705 906253	NELLI DANILOVA	{"phone": "+70296733061"}
0005433867734	68C83B	3750 914943	VALERIY MAKAROV	{"email": "v-makarov.091973@postgrespro.ru", "phone": "+70093332064"}
0005433867735	D47205	5830 315636	TIMOFEY GORBUNOV	{"phone": "+70646428078"}
0005433867736	D47205	5339 090535	MARGARITA TIMOFEEVA	{"phone": "+70239650044"}
0005433867737	B638D2	6798 432926	ANDREY KUZNECOV	{"email": "kuznecov_andrey1966@postgrespro.ru", "phone": "+70962366310"}
0005433867738	B638D2	2130 413057	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov021968@postgrespro.ru", "phone": "+70260730408"}
0005433867739	916530	0286 522537	ANATOLIY EGOROV	{"phone": "+70843592164"}
0005433867740	88DFD8	9217 219629	ANDREY KRASNOV	{"email": "andreykrasnov091971@postgrespro.ru", "phone": "+70315266284"}
0005433867741	94149F	8715 550397	DENIS BORISOV	{"phone": "+70651215754"}
0005433867742	94149F	1845 399440	ALEKSEY POPOV	{"email": "alekseypopov_1990@postgrespro.ru", "phone": "+70669740568"}
0005433867743	8A832C	1015 154607	LILIYA NIKITINA	{"email": "l-nikitina071966@postgrespro.ru", "phone": "+70319869276"}
0005433867744	8A832C	9611 853474	VLADIMIR IVANOV	{"phone": "+70664190897"}
0005433867745	1825F6	1911 894963	DMITRIY NIKOLAEV	{"phone": "+70471689530"}
0005433867746	6187E3	1729 894190	TATYANA KOROLEVA	{"email": "koroleva_tatyana_021957@postgrespro.ru", "phone": "+70527340139"}
0005433867747	C08951	1507 304665	DMITRIY PAVLOV	{"email": "pavlov_dmitriy.09081973@postgrespro.ru", "phone": "+70761267533"}
0005433867748	D7C753	6744 419656	YURIY KUZNECOV	{"email": "yuriy-kuznecov.1974@postgrespro.ru", "phone": "+70249966926"}
0005433867749	14B0B2	2173 811682	RADMIR POPOV	{"email": "radmir_popov-20111974@postgrespro.ru", "phone": "+70081542469"}
0005433867750	14B0B2	7718 175617	VALERIY ANDREEV	{"email": "valeriyandreev021977@postgrespro.ru", "phone": "+70222574013"}
0005433867751	FB51C0	0656 280000	SERGEY DMITRIEV	{"email": "dmitriev.sergey1966@postgrespro.ru", "phone": "+70389750255"}
0005433867752	FB51C0	2385 317870	IRINA EGOROVA	{"email": "i.egorova.27101975@postgrespro.ru", "phone": "+70191256335"}
0005433867753	2D4BDF	9141 119890	LYUDMILA FEDOROVA	{"phone": "+70026153773"}
0005433867754	3FC6C5	8046 134550	ANDREY MEDVEDEV	{"email": "medvedev_a_1962@postgrespro.ru", "phone": "+70318541073"}
0005433867755	8F4AA8	4207 068089	ELENA VASILEVA	{"phone": "+70439635786"}
0005433867756	76815D	3366 381764	VADIM ZAYCEV	{"phone": "+70249807640"}
0005433867757	76815D	9213 569384	MAKSIM ANDREEV	{"email": "maksim_andreev-041975@postgrespro.ru", "phone": "+70650693983"}
0005433867758	73B653	0785 548241	NIKOLAY KUZNECOV	{"phone": "+70016074064"}
0005433867759	73B653	8490 035775	TATYANA MIRONOVA	{"email": "mironova_tatyana.11031973@postgrespro.ru", "phone": "+70299674024"}
0005433867760	73B653	4525 750684	ALLA PETROVA	{"email": "petrovaalla1964@postgrespro.ru", "phone": "+70891718385"}
0005433867761	0D904E	7768 766976	NIKOLAY PAVLOV	{"email": "pavlov_n-121970@postgrespro.ru", "phone": "+70575846472"}
0005433867762	0D904E	2313 992677	ANDREY SCHERBAKOV	{"phone": "+70544661904"}
0005433867763	0D904E	6032 128041	NATALYA NIKOLAEVA	{"email": "natalya-nikolaeva-24011961@postgrespro.ru", "phone": "+70186026519"}
0005433867764	618A87	0802 345562	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr-1973@postgrespro.ru", "phone": "+70702423835"}
0005433867765	E748C7	2219 631045	SVETLANA NOVIKOVA	{"phone": "+70028818112"}
0005433867766	600781	5427 138191	OLEG GAVRILOV	{"email": "gavrilov.o_31121978@postgrespro.ru", "phone": "+70176412816"}
0005433867767	E48D40	0815 166023	TATYANA RODIONOVA	{"phone": "+70954313660"}
0005433867768	E48D40	8788 732115	ELENA EGOROVA	{"email": "e.egorova.041974@postgrespro.ru", "phone": "+70024135398"}
0005433867769	E48D40	9456 167147	SERGEY KARPOV	{"phone": "+70085028974"}
0005433867770	B9FC0E	4845 013636	VASILIY GORBUNOV	{"phone": "+70009757540"}
0005433867884	AEB7B5	6713 585991	ALEKSEY SMIRNOV	{"phone": "+70180942751"}
0005433867771	CEF94E	6766 468856	EVGENIYA ANDREEVA	{"email": "evgeniya_andreeva1969@postgrespro.ru", "phone": "+70063208989"}
0005433867772	CEF94E	8113 288258	DENIS ALEKSEEV	{"email": "alekseev.d.1969@postgrespro.ru", "phone": "+70991275320"}
0005433867773	A520FB	5363 587667	TATYANA MALYSHEVA	{"email": "t_malysheva-1964@postgrespro.ru", "phone": "+70596232685"}
0005433867774	A09316	7912 601337	EVGENIY KUDRYASHOV	{"email": "kudryashovevgeniy08051981@postgrespro.ru", "phone": "+70826546346"}
0005433867775	A09316	0849 049105	EVGENIY ALEKSANDROV	{"phone": "+70138914048"}
0005433867776	000B77	2116 608557	EVGENIY MARTYNOV	{"phone": "+70069471104"}
0005433867777	6C943A	7219 899687	RAZIYA NIKIFOROVA	{"email": "raziya-nikiforova_061973@postgrespro.ru", "phone": "+70924838968"}
0005433867778	6C943A	7660 638789	IRINA KULIKOVA	{"email": "i-kulikova.051975@postgrespro.ru", "phone": "+70110713696"}
0005433867779	6C943A	7032 513128	ANTON AFANASEV	{"phone": "+70790927922"}
0005433867780	AE591F	4054 168558	KSENIYA MOROZOVA	{"email": "morozova_kseniya1989@postgrespro.ru", "phone": "+70764376490"}
0005433867781	E2735E	8720 147887	GENNADIY MOROZOV	{"email": "morozovgennadiy_061976@postgrespro.ru", "phone": "+70929651091"}
0005433867782	E2735E	8025 939670	IVAN FROLOV	{"phone": "+70388221825"}
0005433867783	7069C1	2385 763244	NINA ERMAKOVA	{"email": "n_ermakova.1970@postgrespro.ru", "phone": "+70051729041"}
0005433867784	7069C1	5568 279595	DMITRIY KUZMIN	{"email": "kuzmin_d101975@postgrespro.ru", "phone": "+70322886834"}
0005433867785	7069C1	3603 002040	GENNADIY FOMIN	{"phone": "+70762816760"}
0005433867786	8B0D21	3948 837653	ALEKSEY ISAEV	{"phone": "+70288115192"}
0005433867787	EB5E41	1140 946574	DMITRIY NAZAROV	{"email": "dmitriynazarov_031977@postgrespro.ru", "phone": "+70418303273"}
0005433867788	7BFF6A	4307 002274	ZOYA KARPOVA	{"phone": "+70325640624"}
0005433867789	7BFF6A	2863 225158	TATYANA POLYAKOVA	{"email": "polyakova_t-111977@postgrespro.ru", "phone": "+70510737434"}
0005433867790	9F5B95	2508 636560	ELENA ERMAKOVA	{"email": "ermakovae_1982@postgrespro.ru", "phone": "+70356637403"}
0005433867791	9F5B95	5678 650003	SVETLANA MIRONOVA	{"phone": "+70362034114"}
0005433867792	7D02D2	7964 027362	OLGA KARPOVA	{"phone": "+70661919099"}
0005433867793	BEBDBE	4577 942886	LYUDMILA SIDOROVA	{"phone": "+70988735930"}
0005433867794	E88E1A	2000 802648	NINA SIDOROVA	{"email": "sidorova_n-1960@postgrespro.ru", "phone": "+70370227537"}
0005433867795	55C376	5062 976269	MIKHAIL YAKOVLEV	{"email": "mikhail-yakovlev.19081974@postgrespro.ru", "phone": "+70952114831"}
0005433867796	91FA0F	4547 257265	DMITRIY STEPANOV	{"phone": "+70958375364"}
0005433867797	91FA0F	1400 267802	OLGA BORISOVA	{"email": "borisovaolga-101963@postgrespro.ru", "phone": "+70834351734"}
0005433867798	1016F0	1204 752840	ANTONINA ZAKHAROVA	{"phone": "+70823112281"}
0005433867799	282679	4265 055220	NIKITA NOVIKOV	{"phone": "+70344358348"}
0005433867800	282679	6532 145669	DENIS NOVIKOV	{"email": "denis-novikov-1975@postgrespro.ru", "phone": "+70316141984"}
0005433867801	282679	3511 736839	ANASTASIYA FILATOVA	{"phone": "+70772068091"}
0005433867802	8F522D	3365 661468	OLEG SHEVCHENKO	{"email": "shevchenko.o1970@postgrespro.ru", "phone": "+70121968711"}
0005433867803	25C675	5066 994675	ANTON KOROLEV	{"email": "korolev_a_1968@postgrespro.ru", "phone": "+70926300854"}
0005433867804	EBCE0D	4223 068685	VIKTOR AFANASEV	{"email": "afanasev-v-1969@postgrespro.ru", "phone": "+70736397914"}
0005433867805	3D5598	7159 075441	LEYLA FADEEVA	{"phone": "+70569398161"}
0005433867806	857369	2128 803332	NIKITA KUZMIN	{"phone": "+70577981189"}
0005433867807	DF8833	0246 039400	PETR ORLOV	{"phone": "+70554310279"}
0005433867808	DF8833	5207 802775	NATALYA SMIRNOVA	{"phone": "+70097160895"}
0005433867809	FEBB6A	8714 954186	ARTEM KARPOV	{"email": "artem.karpov111969@postgrespro.ru", "phone": "+70424518896"}
0005433867810	FF9C4C	2070 617567	SVETLANA BOGDANOVA	{"email": "svetlana_bogdanova-1971@postgrespro.ru", "phone": "+70595609336"}
0005433867811	2484BD	7177 947118	ZOYA ZHUKOVA	{"phone": "+70075268700"}
0005433867812	2484BD	4527 281740	EKATERINA ZHURAVLEVA	{"email": "zhuravleva-e101966@postgrespro.ru", "phone": "+70133703025"}
0005433867813	5AFF56	2988 734612	KARINA ISAEVA	{"email": "karinaisaeva_1985@postgrespro.ru", "phone": "+70725287040"}
0005433867814	2F27BD	1559 490679	NIKOLAY KOZLOV	{"phone": "+70038120587"}
0005433867815	2F27BD	7310 677003	ALEKSANDR KUZNECOV	{"phone": "+70468886715"}
0005433867816	B27BF2	1491 706355	ZOYA VASILEVA	{"email": "zoya_vasileva-121977@postgrespro.ru", "phone": "+70942591088"}
0005433867817	B27BF2	5366 090042	EKATERINA MIKHAYLOVA	{"email": "mikhaylovaekaterina021977@postgrespro.ru", "phone": "+70144500190"}
0005433867818	5CFE8E	1941 142092	KRISTINA KUZNECOVA	{"email": "kuznecova.k.29121976@postgrespro.ru", "phone": "+70990859311"}
0005433867819	EB0FB2	1217 895357	SERGEY TIMOFEEV	{"email": "timofeevsergey_061971@postgrespro.ru", "phone": "+70974087846"}
0005433867820	E31751	2560 624426	ALEKSEY KOROLEV	{"email": "korolev-a_24011968@postgrespro.ru", "phone": "+70025029184"}
0005433867822	179A9C	2037 188486	ILDUS MATVEEV	{"email": "matveev_ildus-121969@postgrespro.ru", "phone": "+70681724374"}
0005433867823	179A9C	5155 423192	OLGA DENISOVA	{"phone": "+70732981153"}
0005433867824	2E8BB5	7369 858767	OLEG NAZAROV	{"email": "nazarov_oleg041970@postgrespro.ru", "phone": "+70883681557"}
0005433867825	C84E31	2121 539119	OLEG GRIGOREV	{"phone": "+70366492110"}
0005433867826	5A024C	7516 972510	VASILIY MOROZOV	{"email": "vmorozov-05101976@postgrespro.ru", "phone": "+70435929649"}
0005433867827	535DE9	5227 141253	ALEKSANDR SAVELEV	{"email": "savelev-a-1961@postgrespro.ru", "phone": "+70907168043"}
0005433867828	C9454E	5488 677251	ALEKSANDR TIKHONOV	{"phone": "+70828938025"}
0005433867829	7B386B	6440 260442	OLEG STEPANOV	{"email": "olegstepanov_111963@postgrespro.ru", "phone": "+70062982112"}
0005433867830	2FB554	5610 854757	SERGEY IVANOV	{"email": "sergeyivanov_111972@postgrespro.ru", "phone": "+70001903653"}
0005433867831	2FB554	4156 783270	ANASTASIYA TIMOFEEVA	{"phone": "+70570411580"}
0005433867832	2FB554	6437 873597	PETR ZAKHAROV	{"email": "p-zakharov-021975@postgrespro.ru", "phone": "+70917509550"}
0005433867833	76F60B	3835 027093	NIKOLAY MAKSIMOV	{"email": "n-maksimov.29081981@postgrespro.ru", "phone": "+70743859389"}
0005433867834	76F60B	0583 995031	EDUARD KRASNOV	{"email": "krasnoveduard_1974@postgrespro.ru", "phone": "+70359820643"}
0005433867835	B5170C	7420 558216	MIKHAIL KAZAKOV	{"phone": "+70171890723"}
0005433867836	47B21B	2047 724364	MAKSIM MOISEEV	{"phone": "+70205755094"}
0005433867837	47B21B	8998 775178	ANDREY KARPOV	{"email": "karpova041977@postgrespro.ru", "phone": "+70483862006"}
0005433867838	47B21B	4365 075522	GALINA FOMINA	{"phone": "+70251527705"}
0005433867839	481F89	0817 353926	SVETLANA EFREMOVA	{"email": "s-efremova1974@postgrespro.ru", "phone": "+70722049196"}
0005433867840	A8F5AC	1710 942696	ELENA TITOVA	{"phone": "+70501711587"}
0005433867841	266B38	3283 616288	VLADIMIR ZHURAVLEV	{"phone": "+70534753891"}
0005433867842	2A461F	7460 984818	PAVEL VOROBEV	{"phone": "+70593067380"}
0005433867843	2A461F	6001 515147	ALENA SERGEEVA	{"phone": "+70263259925"}
0005433867844	3BB31F	7225 851992	RAISA RYABOVA	{"phone": "+70589631475"}
0005433867845	3BB31F	5908 130773	VALERIY SOKOLOV	{"phone": "+70975201072"}
0005433867846	97E9BF	2056 963019	VALERIY BELOV	{"email": "belov.valeriy1970@postgrespro.ru", "phone": "+70804180079"}
0005433867847	97E9BF	6905 017435	TATYANA AFANASEVA	{"email": "tatyana-afanaseva-20121975@postgrespro.ru", "phone": "+70528164314"}
0005433867848	C51EBF	9377 256100	SERGEY IVANOV	{"phone": "+70260412717"}
0005433867849	242D17	5379 377626	IVAN NIKITIN	{"email": "nikitini1968@postgrespro.ru", "phone": "+70162999521"}
0005433867850	242D17	3150 836844	SERGEY MEDVEDEV	{"phone": "+70991887469"}
0005433867851	7189CC	6601 326515	VLADIMIR SOKOLOV	{"email": "vladimirsokolov_09101974@postgrespro.ru", "phone": "+70023995603"}
0005433867852	3D19F9	5722 217171	YULIYA ALEKSANDROVA	{"phone": "+70385810921"}
0005433867853	556C78	4665 703884	LEONID BORISOV	{"phone": "+70207002127"}
0005433867854	30C920	3410 354512	NATALYA KULIKOVA	{"phone": "+70656007165"}
0005433867855	30C920	7475 496422	ALEKSANDR PETROV	{"phone": "+70185168241"}
0005433867856	04CE07	4960 464757	ANNA FEDOROVA	{"email": "fedorova.a-04101964@postgrespro.ru", "phone": "+70102638536"}
0005433867857	E93149	2180 957073	ALEKSANDRA PETROVA	{"phone": "+70995968610"}
0005433867858	D60D22	7993 609848	OLGA FEDOROVA	{"email": "o.fedorova011962@postgrespro.ru", "phone": "+70216879827"}
0005433867859	685CC8	9737 656532	NATALYA FILATOVA	{"email": "natalya_filatova-18101969@postgrespro.ru", "phone": "+70241089790"}
0005433867860	DAF349	7390 180112	VIKTOR MOISEEV	{"email": "viktor_moiseev.1971@postgrespro.ru", "phone": "+70387186768"}
0005433867861	D17A9B	1483 858854	DENIS SOLOVEV	{"email": "solovevdenis-25061963@postgrespro.ru", "phone": "+70885058588"}
0005433867862	D17A9B	2014 823719	NATALIYA DAVYDOVA	{"email": "davydova.n1983@postgrespro.ru", "phone": "+70085419972"}
0005433867863	0A3B14	5456 687722	DMITRIY SOLOVEV	{"phone": "+70535111975"}
0005433867864	0A3B14	6851 974413	ANNA BORISOVA	{"phone": "+70949351406"}
0005433867865	0AFCF2	4682 911533	MAKSIM POPOV	{"phone": "+70676919790"}
0005433867866	0AFCF2	6386 065621	VERA KUZNECOVA	{"phone": "+70698371831"}
0005433867867	F3CFD9	0881 095590	LYUDMILA POTAPOVA	{"email": "potapova.lyudmila_13121969@postgrespro.ru", "phone": "+70992434853"}
0005433867868	F3CFD9	0237 529025	KONSTANTIN FEDOROV	{"email": "konstantin-fedorov-1961@postgrespro.ru", "phone": "+70343997050"}
0005433867869	9DB919	2325 676745	MARIYA KUDRYASHOVA	{"phone": "+70266650075"}
0005433867870	9DB919	1919 684816	LYUDMILA ZAKHAROVA	{"phone": "+70281550257"}
0005433867871	49A205	9780 230169	TATYANA PETROVA	{"phone": "+70762357661"}
0005433867872	3B9741	1942 752955	DARYA YAKOVLEVA	{"email": "d.yakovleva-061967@postgrespro.ru", "phone": "+70944854124"}
0005433867873	3B9741	1346 625150	LYUDMILA ANDREEVA	{"phone": "+70472729976"}
0005433867874	A93F6D	3858 391532	PETR VLASOV	{"email": "vlasov.petr_1969@postgrespro.ru", "phone": "+70874289070"}
0005433867875	2BCD74	7481 858509	OLGA LAZAREVA	{"email": "lazareva.olga_1972@postgrespro.ru", "phone": "+70091488786"}
0005433867876	E2F913	2761 568323	ALEKSANDRA ZAKHAROVA	{"email": "azakharova-1974@postgrespro.ru", "phone": "+70181335390"}
0005433867877	51AC95	4908 543132	VALERIY TIKHONOV	{"email": "tikhonovvaleriy-1969@postgrespro.ru", "phone": "+70794741882"}
0005433867878	51AC95	3879 621458	ANASTASIYA SCHERBAKOVA	{"phone": "+70345900733"}
0005433867879	51AC95	7464 863684	LYUBOV KISELEVA	{"phone": "+70529595584"}
0005433867880	FD5ED1	8233 666000	LYUDMILA DMITRIEVA	{"phone": "+70868791925"}
0005433867881	0BB9CE	1308 393400	EDUARD SOROKIN	{"email": "sorokin-eduard101960@postgrespro.ru", "phone": "+70234606750"}
0005433867882	DFE63E	1736 363837	ANNA NIKOLAEVA	{"phone": "+70067368155"}
0005433867883	9A6397	0558 051595	NINA MAKAROVA	{"phone": "+70402812754"}
0005433867885	766317	6087 476166	MARINA VASILEVA	{"phone": "+70304014075"}
0005433867886	F4ED94	8601 938712	YAROSLAV ROMANOV	{"email": "yaroslav.romanov-11091972@postgrespro.ru", "phone": "+70884748846"}
0005433867887	1E8A54	1588 305845	ZINAIDA SEMENOVA	{"email": "semenova.z_12121971@postgrespro.ru", "phone": "+70821879753"}
0005433867888	6806C7	0815 639293	IRINA SOKOLOVA	{"email": "sokolovairina.1972@postgrespro.ru", "phone": "+70775637003"}
0005433867889	CB0217	2665 061150	EKATERINA EFIMOVA	{"phone": "+70903234959"}
0005433867890	DA944F	2698 522629	SVETLANA FROLOVA	{"email": "svetlana_frolova08111962@postgrespro.ru", "phone": "+70324042015"}
0005433867891	38388C	8652 979841	NIKOLAY MIRONOV	{"phone": "+70907758073"}
0005433867892	E12F96	7505 562637	SERGEY SOLOVEV	{"email": "solovev_sergey.22041969@postgrespro.ru", "phone": "+70830558356"}
0005433867893	E12F96	1974 220056	KONSTANTIN SOLOVEV	{"phone": "+70239381512"}
0005433867894	7F87DF	3475 807937	NADEZHDA ANISIMOVA	{"email": "nadezhda.anisimova031964@postgrespro.ru", "phone": "+70066156899"}
0005433867895	7F87DF	4175 410228	NATALYA NAZAROVA	{"email": "natalya_nazarova.06021965@postgrespro.ru", "phone": "+70749710189"}
0005433867896	03926F	5738 182482	NADEZHDA KUZNECOVA	{"email": "kuznecova.n121974@postgrespro.ru", "phone": "+70698169973"}
0005433867897	03926F	6248 515554	DMITRIY KUZNECOV	{"phone": "+70294698452"}
0005433867898	82867B	1107 790309	SERGEY ANTONOV	{"email": "sergeyantonov1964@postgrespro.ru", "phone": "+70977444864"}
0005433867899	87C959	8562 582738	MIKHAIL KUZNECOV	{"email": "m.kuznecov_091978@postgrespro.ru", "phone": "+70934203844"}
0005433867900	EF3D5A	2549 993851	ALEKSANDR MELNIKOV	{"email": "melnikov_a-07101968@postgrespro.ru", "phone": "+70670850214"}
0005433867901	0BB80A	5056 133080	SERGEY KUZMIN	{"email": "kuzmin.sergey111970@postgrespro.ru", "phone": "+70258960888"}
0005433867902	522F17	6655 524361	VERA STEPANOVA	{"phone": "+70145548748"}
0005433867903	522F17	9658 928576	VLADIMIR ZHURAVLEV	{"phone": "+70261938701"}
0005433867904	3FC504	8433 696081	ANTON KULIKOV	{"email": "kulikov.a-02081972@postgrespro.ru", "phone": "+70351075358"}
0005433867905	0F7A45	0047 037866	ALEKSANDR KONOVALOV	{"phone": "+70904677538"}
0005433867906	0F7A45	8253 149096	DENIS BORISOV	{"email": "denisborisov1972@postgrespro.ru", "phone": "+70832207119"}
0005433867907	03E82E	6214 712933	DMITRIY BONDARENKO	{"email": "bondarenko.dmitriy_051984@postgrespro.ru", "phone": "+70050179819"}
0005433867908	67A0AB	7930 139483	MARINA MIKHAYLOVA	{"email": "mikhaylova_marina1969@postgrespro.ru", "phone": "+70561493894"}
0005433867909	C9300D	0800 007011	SERGEY SAVELEV	{"phone": "+70388138570"}
0005433867910	79D763	9632 801445	RAISA KULIKOVA	{"email": "kulikova.r.071973@postgrespro.ru", "phone": "+70658403340"}
0005433867911	6F381A	4177 310501	VLADIMIR SERGEEV	{"phone": "+70114225262"}
0005433867912	6F381A	4068 809408	YURIY KAZAKOV	{"email": "kazakovy.1971@postgrespro.ru", "phone": "+70488575948"}
0005433867913	45A3EF	8229 659354	ANTONINA OVCHINNIKOVA	{"phone": "+70097520033"}
0005433867914	3AFAB8	7777 921080	ROZA MATVEEVA	{"phone": "+70568700341"}
0005433867915	3AFAB8	8978 885242	SVETLANA KOVALEVA	{"phone": "+70625836151"}
0005433867916	635E56	0019 954561	POLINA RODIONOVA	{"phone": "+70132470528"}
0005433867917	635E56	6366 394755	ANNA OSIPOVA	{"phone": "+70708530250"}
0005433867918	2751AD	2338 950013	IVAN GUSEV	{"email": "gusev.i1960@postgrespro.ru", "phone": "+70044279127"}
0005433867919	2751AD	9246 396192	NINA VLASOVA	{"phone": "+70003148446"}
0005433867920	0C213B	6118 627035	MARINA DMITRIEVA	{"phone": "+70835037928"}
0005433867921	845E5C	2467 780124	NIKOLAY SERGEEV	{"phone": "+70559837727"}
0005433867922	D3E681	4554 848314	SVETLANA ISAEVA	{"phone": "+70479963291"}
0005433867923	D3E681	8154 305754	TAMARA POPOVA	{"email": "popova-tamara.1972@postgrespro.ru", "phone": "+70632167437"}
0005433867924	651A47	1521 414435	KLAVDIYA SEMENOVA	{"email": "semenova_k-1962@postgrespro.ru", "phone": "+70335120608"}
0005433867925	557BA1	1662 788960	YULIYA KUZNECOVA	{"email": "y.kuznecova_1966@postgrespro.ru", "phone": "+70970263591"}
0005433867926	557BA1	8171 931472	ALEKSANDR KRASNOV	{"phone": "+70773367896"}
0005433867927	ABFC4F	0063 846917	YULIYA ALEKSEEVA	{"phone": "+70894249735"}
0005433867928	ABFC4F	7200 145231	LYUBOV SMIRNOVA	{"phone": "+70916233503"}
0005433867929	ABFC4F	8304 450433	RAISA PETROVA	{"phone": "+70690175533"}
0005433867930	3955F6	1649 289170	ELENA GAVRILOVA	{"email": "e_gavrilova_051970@postgrespro.ru", "phone": "+70898973053"}
0005433867931	8766C7	3423 765492	NIKOLAY STEPANOV	{"email": "n.stepanov071968@postgrespro.ru", "phone": "+70745570734"}
0005433867932	FA02E9	5282 803526	IGOR VOROBEV	{"phone": "+70874768086"}
0005433867933	375C49	5948 940383	OKSANA KUZNECOVA	{"phone": "+70297865741"}
0005433867934	DAE652	9580 194662	ANNA OVCHINNIKOVA	{"phone": "+70101127120"}
0005433868102	0ED358	6951 102479	DANILA KUZMIN	{"phone": "+70937023273"}
0005433867935	3A6BCC	8479 550276	LYUDMILA LOGINOVA	{"email": "lyudmila-loginova.041964@postgrespro.ru", "phone": "+70890738200"}
0005433867936	AA0971	6997 558665	SVETLANA GRISHINA	{"email": "grishina-svetlana-09111972@postgrespro.ru", "phone": "+70489974192"}
0005433867937	AA0971	3109 920517	NADEZHDA KOROLEVA	{"phone": "+70785212232"}
0005433867938	43CA2A	2175 154573	ANASTASIYA MOROZOVA	{"phone": "+70155803363"}
0005433867939	A14B1C	0352 349305	VERA MELNIKOVA	{"email": "v-melnikova-25031966@postgrespro.ru", "phone": "+70011161194"}
0005433867940	A14B1C	0351 042669	NADEZHDA ANTONOVA	{"phone": "+70588582835"}
0005433867941	574801	6158 231264	ALEKSANDR KAZAKOV	{"phone": "+70137631223"}
0005433867942	574801	6825 540100	NIKOLAY SEMENOV	{"email": "semenov-nikolay-061980@postgrespro.ru", "phone": "+70175844580"}
0005433867943	9D0FAB	6136 965987	IRINA OSIPOVA	{"phone": "+70200060065"}
0005433867944	9D0FAB	8512 780404	LEONID SAVELEV	{"email": "savelev-leonid.041979@postgrespro.ru", "phone": "+70016801089"}
0005433867945	31712D	9030 446860	DMITRIY GORBUNOV	{"email": "gorbunov_d-28031981@postgrespro.ru", "phone": "+70230818281"}
0005433867946	07CF22	6046 683175	ANTON KUZNECOV	{"phone": "+70831762181"}
0005433867947	2A3EC7	5362 577127	OLGA SOROKINA	{"email": "o-sorokina_24061975@postgrespro.ru", "phone": "+70790749650"}
0005433867948	1EDB87	9324 158111	DENIS ORLOV	{"email": "orlov_denis24041974@postgrespro.ru", "phone": "+70526209690"}
0005433867949	78BFB4	8499 916019	OLEG KOZLOV	{"email": "kozlov-oleg091983@postgrespro.ru", "phone": "+70371278398"}
0005433867950	0909A5	7427 597271	NIKOLAY BONDARENKO	{"phone": "+70661929805"}
0005433867951	0909A5	8368 806479	EKATERINA POPOVA	{"phone": "+70013999886"}
0005433867952	BA96B7	8412 080994	MIKHAIL RODIONOV	{"email": "rodionov_m-1965@postgrespro.ru", "phone": "+70560167304"}
0005433867953	21F245	5916 406794	DANILA VLASOV	{"phone": "+70066105880"}
0005433867954	B2EC7D	4138 093145	LYUBOV KARPOVA	{"email": "karpova_lyubov041954@postgrespro.ru", "phone": "+70239562289"}
0005433867955	C0C64C	0789 827181	ILSHAT ALEKSEEV	{"email": "i-alekseev.1969@postgrespro.ru", "phone": "+70113562017"}
0005433867956	9F19FA	6161 362346	NIKOLAY BORISOV	{"email": "borisov-nikolay1977@postgrespro.ru", "phone": "+70948720597"}
0005433867957	FC4175	8992 073503	NADEZHDA OVCHINNIKOVA	{"phone": "+70635173369"}
0005433867958	FC4175	9142 517111	LEONID ABRAMOV	{"phone": "+70858125230"}
0005433867959	E78278	6363 237691	VALENTINA KOLESNIKOVA	{"phone": "+70003778002"}
0005433867960	5334AC	0928 677059	VLADISLAV ROMANOV	{"phone": "+70778066378"}
0005433867961	65FE7C	7425 134390	PAVEL AFANASEV	{"phone": "+70371920877"}
0005433867962	9E8F62	5779 634395	MARGARITA NIKITINA	{"phone": "+70498538733"}
0005433867963	C63239	1293 483557	LYUDMILA GERASIMOVA	{"phone": "+70014391933"}
0005433867964	96051A	5522 893063	ALEKSEY ANTONOV	{"email": "antonov_aleksey.021968@postgrespro.ru", "phone": "+70914654917"}
0005433867965	96051A	4110 481347	NIKOLAY GERASIMOV	{"email": "gerasimov-n.16021971@postgrespro.ru", "phone": "+70143943562"}
0005433867966	0CAF5D	3677 870483	NADEZHDA OSIPOVA	{"email": "osipova-nadezhda1969@postgrespro.ru", "phone": "+70529938585"}
0005433867967	2BFF01	7660 426775	LYUBOV RYABOVA	{"email": "l-ryabova.021982@postgrespro.ru", "phone": "+70933086346"}
0005433867968	904531	4133 669109	ANDREY ALEKSEEV	{"email": "alekseeva031975@postgrespro.ru", "phone": "+70869408626"}
0005433867969	1942A6	6119 441886	ANATOLIY KRASNOV	{"phone": "+70673390935"}
0005433867970	34A6A1	0147 473188	OLGA TROFIMOVA	{"phone": "+70609503370"}
0005433867971	3F0C47	5500 048550	TATYANA EFREMOVA	{"phone": "+70396394109"}
0005433867972	B73DFF	7540 490180	PETR ANTONOV	{"email": "p_antonov-1959@postgrespro.ru", "phone": "+70878319732"}
0005433867973	7AF607	1053 593425	OLEG SEMENOV	{"email": "semenov.oleg.1973@postgrespro.ru", "phone": "+70128985241"}
0005433867974	781C53	0788 457366	NINA SOROKINA	{"email": "n.sorokina_011974@postgrespro.ru", "phone": "+70182138109"}
0005433867975	781C53	8655 217359	EKATERINA ISAEVA	{"email": "isaevae_101974@postgrespro.ru", "phone": "+70345914452"}
0005433867976	34B915	6109 240099	ALEKSANDR DMITRIEV	{"phone": "+70160976961"}
0005433867977	636443	8029 895042	NATALYA SERGEEVA	{"email": "sergeevanatalya.071961@postgrespro.ru", "phone": "+70444896555"}
0005433867978	CF753C	1156 022728	RAMIL GERASIMOV	{"email": "rgerasimov.1976@postgrespro.ru", "phone": "+70626211378"}
0005433867979	E37363	4466 214210	VLADIMIR NOVIKOV	{"email": "vladimir.novikov-031979@postgrespro.ru", "phone": "+70236076972"}
0005433867980	E37363	0059 009009	VALENTIN TARASOV	{"phone": "+70897326995"}
0005433867981	B894DF	0966 116290	NATALYA IVANOVA	{"phone": "+70369556083"}
0005433867982	99E421	3503 674293	ALLA CHERNOVA	{"phone": "+70057844585"}
0005433867983	99E421	9330 660979	ALLA BARANOVA	{"phone": "+70659885694"}
0005433867984	F05436	5614 975972	VIKTORIYA ILINA	{"email": "ilinav.101970@postgrespro.ru", "phone": "+70213074253"}
0005433867985	F05436	6946 322625	ZINAIDA NIKIFOROVA	{"phone": "+70333627648"}
0005433867986	05588D	7509 507080	VLADIMIR ALEKSEEV	{"phone": "+70060648862"}
0005433867987	07C572	4697 995356	VLADA IVANOVA	{"phone": "+70600647643"}
0005433867988	07C572	5896 403349	EVGENIY GRIGOREV	{"email": "grigorev_e.071970@postgrespro.ru", "phone": "+70708780215"}
0005433867989	6DF490	5073 165708	SERGEY DENISOV	{"email": "sdenisov11081978@postgrespro.ru", "phone": "+70908703145"}
0005433867990	E32633	6888 642635	VIKTOR PAVLOV	{"email": "viktor-pavlov081973@postgrespro.ru", "phone": "+70052269553"}
0005433867991	95EF4D	1536 275941	MARIYA MEDVEDEVA	{"email": "medvedeva_m.061972@postgrespro.ru", "phone": "+70764910130"}
0005433867992	95EF4D	5814 496218	TAGIR KAZAKOV	{"phone": "+70800635396"}
0005433867993	41DA2D	2674 962001	MARIYA SEMENOVA	{"email": "semenova.m-061964@postgrespro.ru", "phone": "+70635540813"}
0005433867994	DE45C9	5658 500679	ALEKSEY ANDREEV	{"email": "andreevaleksey-02111971@postgrespro.ru", "phone": "+70508910364"}
0005433867995	D70CDF	8042 230486	SERGEY GAVRILOV	{"phone": "+70490044444"}
0005433867996	4B101B	5156 512510	DENIS NAUMOV	{"phone": "+70629806232"}
0005433867997	8B87F9	0505 682019	MARINA KONOVALOVA	{"email": "konovalovamarina_1971@postgrespro.ru", "phone": "+70961286242"}
0005433867998	1EA987	4615 415793	MAKSIM AFANASEV	{"phone": "+70508710177"}
0005433867999	1AA0BD	9638 115911	TATYANA SIDOROVA	{"phone": "+70640049467"}
0005433868000	E48B83	7629 081200	YULIYA ANDREEVA	{"email": "andreeva.yuliya.21091978@postgrespro.ru", "phone": "+70773499486"}
0005433868001	E48B83	4514 097487	EVGENIY ANTONOV	{"email": "e_antonov_20061964@postgrespro.ru", "phone": "+70999970864"}
0005433868002	E48B83	7341 602033	GALINA PETROVA	{"email": "galina.petrova.1967@postgrespro.ru", "phone": "+70102749926"}
0005433868003	4A5B2F	2942 432640	OKSANA GERASIMOVA	{"email": "gerasimova-oksana_06101978@postgrespro.ru", "phone": "+70469884192"}
0005433868004	4D6B55	8572 125253	TATYANA ZAYCEVA	{"email": "tatyana.zayceva-1974@postgrespro.ru", "phone": "+70390922121"}
0005433868005	85A371	6579 158549	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir051985@postgrespro.ru", "phone": "+70862430835"}
0005433868006	5A9669	8981 551007	LYUBOV SEMENOVA	{"email": "lsemenova.23061978@postgrespro.ru", "phone": "+70697458659"}
0005433868007	03605B	2152 723760	MARIYA IVANOVA	{"phone": "+70064607995"}
0005433868008	DBD4FF	3577 668645	LIDIYA DENISOVA	{"phone": "+70551673975"}
0005433868009	6F15F8	5984 932229	SOFIYA PETROVA	{"email": "s_petrova_07051981@postgrespro.ru", "phone": "+70136543972"}
0005433868010	6F15F8	9852 036916	ELENA SMIRNOVA	{"email": "e-smirnova1964@postgrespro.ru", "phone": "+70648165553"}
0005433868011	AEFBD2	7627 136923	GRIGORIY ZHUKOV	{"email": "zhukov_grigoriy_1966@postgrespro.ru", "phone": "+70532209462"}
0005433868012	51BEAD	4948 433458	ALEKSEY SMIRNOV	{"email": "smirnova.12041962@postgrespro.ru", "phone": "+70443560761"}
0005433868013	3F5227	0272 758420	SERGEY PAVLOV	{"phone": "+70994132780"}
0005433868014	29CDA4	8578 616375	VERA ZOTOVA	{"phone": "+70929875839"}
0005433868015	31D2AA	4563 434970	NELLI ANTONOVA	{"email": "nelli_antonova.1975@postgrespro.ru", "phone": "+70446500782"}
0005433868016	31D2AA	0013 776842	EGOR KUZNECOV	{"email": "kuznecov-e-041973@postgrespro.ru", "phone": "+70522992706"}
0005433868017	A01FA3	1816 332877	MARINA BELOVA	{"email": "marinabelova-18031966@postgrespro.ru", "phone": "+70877903701"}
0005433868018	0B6813	5373 934926	MIKHAIL VOROBEV	{"phone": "+70939649416"}
0005433868019	2F7428	5063 131908	VALENTINA EFREMOVA	{"phone": "+70750143539"}
0005433868020	C16EA8	9714 282456	ANTONINA FOMINA	{"email": "fomina_antonina.1973@postgrespro.ru", "phone": "+70379618980"}
0005433868021	C16EA8	7496 696791	ALEKSANDR FEDOTOV	{"phone": "+70693400150"}
0005433868022	FFF3B4	4605 575108	LILIYA SOLOVEVA	{"email": "soloveva-liliya_20031984@postgrespro.ru", "phone": "+70232679145"}
0005433868023	1A2D6B	7522 477906	OLGA VASILEVA	{"email": "vasileva-olga.02101966@postgrespro.ru", "phone": "+70820274288"}
0005433868024	EF8D81	3956 317780	LIDIYA NIKOLAEVA	{"phone": "+70677703748"}
0005433868025	EF8D81	2170 811326	VADIM TARASOV	{"email": "tarasov.v.111978@postgrespro.ru", "phone": "+70789935692"}
0005433868026	415019	1081 776161	MARINA SEMENOVA	{"phone": "+70957437020"}
0005433868027	212B4D	3888 894813	EDUARD ZHUKOV	{"email": "zhukov-e_24021976@postgrespro.ru", "phone": "+70976761625"}
0005433868028	E32DF9	2829 605779	SOFIYA SIDOROVA	{"email": "sofiya-sidorova_1971@postgrespro.ru", "phone": "+70231076361"}
0005433868029	0CA4C8	8154 012218	OLEG SHEVCHENKO	{"email": "shevchenkooleg-08021963@postgrespro.ru", "phone": "+70623250336"}
0005433868030	F4FCB8	1237 310273	GALINA TITOVA	{"phone": "+70028548881"}
0005433868031	77B729	6488 869064	VALENTINA ZAYCEVA	{"email": "zayceva_valentina.1976@postgrespro.ru", "phone": "+70353578428"}
0005433868032	77B729	0083 727681	EVGENIY MEDVEDEV	{"phone": "+70605800891"}
0005433868033	EB829C	4023 511706	EKATERINA LOGINOVA	{"phone": "+70868507732"}
0005433868034	EB829C	1246 011261	ALINA PETROVA	{"phone": "+70713823724"}
0005433868035	C2AD91	2228 226333	LYUBOV MIKHAYLOVA	{"email": "lyubov.mikhaylova.06011974@postgrespro.ru", "phone": "+70219500926"}
0005433868036	C2AD91	0695 969246	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya_1971@postgrespro.ru", "phone": "+70755236110"}
0005433868037	523A6A	1523 653052	DMITRIY GERASIMOV	{"email": "gerasimovd-1976@postgrespro.ru", "phone": "+70438519017"}
0005433868038	60D750	7233 416056	EVGENIYA SMIRNOVA	{"phone": "+70752584604"}
0005433868039	A9E1DE	6593 387764	MARGARITA ERMAKOVA	{"phone": "+70188942561"}
0005433868040	AF43BC	1715 905159	ANDREY MIRONOV	{"phone": "+70743630105"}
0005433868041	82916A	3974 003437	GEORGIY IVANOV	{"phone": "+70777975332"}
0005433868042	82916A	9060 532545	ELENA YAKOVLEVA	{"email": "yakovleva-e.081967@postgrespro.ru", "phone": "+70205384192"}
0005433868043	D379C3	1995 996820	MARINA IVANOVA	{"email": "mivanova_081975@postgrespro.ru", "phone": "+70486451330"}
0005433868044	D379C3	8496 529115	ANZHELA MATVEEVA	{"email": "matveevaa_1973@postgrespro.ru", "phone": "+70622457877"}
0005433868045	3778F4	5107 955833	ALEKSEY MAKAROV	{"phone": "+70751846069"}
0005433868046	C45515	1474 827067	VLADIMIR VOLKOV	{"email": "vladimirvolkov_16121975@postgrespro.ru", "phone": "+70724707174"}
0005433868047	885AB5	2865 526167	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.031966@postgrespro.ru", "phone": "+70743630944"}
0005433868048	885AB5	0048 359126	DMITRIY KUZMIN	{"phone": "+70373730774"}
0005433868049	4A58D3	5862 153863	ALEKSANDR SCHERBAKOV	{"phone": "+70082449983"}
0005433868050	8CE4D4	2134 592630	MARGARITA EGOROVA	{"email": "egorova-margarita_26061976@postgrespro.ru", "phone": "+70954820364"}
0005433868051	C3DEA1	2983 327180	VIKTOR IVANOV	{"email": "ivanov_v-11011981@postgrespro.ru", "phone": "+70607241288"}
0005433868052	C3DEA1	4021 019833	ANATOLIY POPOV	{"email": "popov-a.031962@postgrespro.ru", "phone": "+70803375652"}
0005433868053	D4CA74	5782 210169	ILYA GAVRILOV	{"email": "gavrilov_i011969@postgrespro.ru", "phone": "+70524899001"}
0005433868054	BE26BE	9029 701109	EVGENIYA POPOVA	{"phone": "+70361149366"}
0005433868055	51B679	6811 604966	ALEKSANDR SOKOLOV	{"phone": "+70357831317"}
0005433868056	2C8249	7438 121115	FARIT MATVEEV	{"email": "matveev.f31081967@postgrespro.ru", "phone": "+70658121321"}
0005433868057	5FC43B	9773 719755	NATALYA ROMANOVA	{"phone": "+70014635600"}
0005433868058	5FC43B	8618 057960	POLINA NIKITINA	{"email": "pnikitina_1971@postgrespro.ru", "phone": "+70533191242"}
0005433868059	B65DD5	6886 227005	VIKTOR KUZMIN	{"phone": "+70953857216"}
0005433868060	B65DD5	0366 294549	MAKSIM IVANOV	{"email": "ivanov_m_06061977@postgrespro.ru", "phone": "+70068275784"}
0005433868061	6512FE	8655 162934	NADEZHDA KOROLEVA	{"email": "nadezhda.koroleva_071966@postgrespro.ru", "phone": "+70462499086"}
0005433868062	ACB5BF	4003 398918	NIKOLAY RODIONOV	{"email": "rodionov-nikolay_24021968@postgrespro.ru", "phone": "+70426787870"}
0005433868063	989E04	4215 328738	TATYANA BOGDANOVA	{"email": "bogdanovatatyana_121980@postgrespro.ru", "phone": "+70464572508"}
0005433868064	989E04	0665 536323	VERA VOROBEVA	{"email": "veravorobeva.01101964@postgrespro.ru", "phone": "+70137258164"}
0005433868065	66B99A	4668 210674	DENIS NAUMOV	{"email": "naumov-d_20101978@postgrespro.ru", "phone": "+70787191209"}
0005433868066	ECD90B	3231 418715	ARSENIY KOZLOV	{"phone": "+70291074563"}
0005433868067	5EE93D	6383 029568	ALEKSANDR TARASOV	{"phone": "+70025987445"}
0005433868068	B450DF	1421 347299	ANATOLIY ROMANOV	{"phone": "+70430332330"}
0005433868069	B450DF	1488 414668	TATYANA LOGINOVA	{"email": "loginova-t-15041978@postgrespro.ru", "phone": "+70092699757"}
0005433868070	BD3C2A	2627 072526	TATYANA ANDREEVA	{"email": "tandreeva-16121974@postgrespro.ru", "phone": "+70473040874"}
0005433868071	7EF53E	6421 050306	ALEKSEY DAVYDOV	{"email": "davydov-aleksey.26071964@postgrespro.ru", "phone": "+70907925964"}
0005433868072	3D5C14	8155 249879	TAMARA TARASOVA	{"phone": "+70987607626"}
0005433868073	28B842	4804 065090	ALEKSANDRA FADEEVA	{"email": "fadeeva.aleksandra-1969@postgrespro.ru", "phone": "+70206641255"}
0005433868074	28B842	6470 488871	FEDOR ALEKSANDROV	{"email": "f_aleksandrov.1973@postgrespro.ru", "phone": "+70262791775"}
0005433868075	28B842	4308 386693	VIKTOR SEMENOV	{"phone": "+70907106196"}
0005433868076	76C383	5596 543138	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev.13101963@postgrespro.ru", "phone": "+70753190045"}
0005433868077	76C383	9205 323896	ANDREY YAKOVLEV	{"phone": "+70507293797"}
0005433868078	78D5FB	8561 463501	EGOR FEDOROV	{"phone": "+70729141993"}
0005433868079	93A469	5769 261234	ALENA ANDREEVA	{"email": "andreeva.a1974@postgrespro.ru", "phone": "+70587915965"}
0005433868080	7441AE	6752 325941	ANZHELA SIDOROVA	{"phone": "+70709830741"}
0005433868081	238BB1	9220 156123	NINA VOLKOVA	{"email": "n_volkova051965@postgrespro.ru", "phone": "+70396446423"}
0005433868082	27A062	1410 897323	ALEVTINA ISAEVA	{"email": "isaevaalevtina_15071975@postgrespro.ru", "phone": "+70418701168"}
0005433868083	92F57E	0649 808747	VALENTINA KAZAKOVA	{"phone": "+70881532997"}
0005433868084	92F57E	6384 915735	NATALYA GAVRILOVA	{"phone": "+70657789817"}
0005433868085	FE9C51	1222 770217	GALINA SMIRNOVA	{"phone": "+70835149777"}
0005433868086	16BE9F	3781 649256	ANDREY FILIPPOV	{"phone": "+70861025186"}
0005433868087	9C2684	9913 017763	TATYANA ISAEVA	{"email": "tatyanaisaeva.061973@postgrespro.ru", "phone": "+70962804423"}
0005433868088	11EAE2	1397 049816	IOSIF ZHUKOV	{"email": "zhukov_i031957@postgrespro.ru", "phone": "+70477759137"}
0005433868089	11EAE2	1110 258020	ALEKSANDR ZAKHAROV	{"email": "a.zakharov_17061976@postgrespro.ru", "phone": "+70269020147"}
0005433868090	C83FA0	8727 498247	LYUDMILA AKIMOVA	{"email": "akimova_l-041975@postgrespro.ru", "phone": "+70350287997"}
0005433868091	38B40B	2758 946918	ANATOLIY STEPANOV	{"phone": "+70073217008"}
0005433868092	BAD1D4	3102 052825	ALINA MAKSIMOVA	{"phone": "+70551616610"}
0005433868093	BAD1D4	5650 338582	LARISA PAVLOVA	{"phone": "+70787913991"}
0005433868094	C41E55	1740 023061	VLADIMIR GRIGOREV	{"email": "grigorev_vladimir.041969@postgrespro.ru", "phone": "+70010358803"}
0005433868095	0134CC	9551 374653	VALERIY KUZNECOV	{"phone": "+70149116860"}
0005433868096	86812C	6570 914081	VALERIY SOROKIN	{"email": "valeriysorokin_1969@postgrespro.ru", "phone": "+70224809568"}
0005433868097	86812C	3805 199110	ROMAN SOROKIN	{"phone": "+70292482606"}
0005433868098	D6512B	8797 600241	VASILIY VOLKOV	{"email": "volkov_vasiliy.23051965@postgrespro.ru", "phone": "+70670732571"}
0005433868099	DE7DFD	1656 174884	MIKHAIL IVANOV	{"phone": "+70610070757"}
0005433868100	DE7DFD	0124 594676	KARINA STEPANOVA	{"phone": "+70063599560"}
0005433868101	DD9AC6	6867 072926	DMITRIY MAKAROV	{"phone": "+70149903516"}
0005433868280	6F90B7	0085 374897	ANATOLIY ALEKSEEV	{"phone": "+70696744590"}
0005433868103	0ED358	9861 807787	VSEVOLOD DMITRIEV	{"email": "dmitriev_vsevolod-041977@postgrespro.ru", "phone": "+70180346608"}
0005433868104	1263A7	3118 653226	ANATOLIY AFANASEV	{"email": "afanasev.anatoliy_1961@postgrespro.ru", "phone": "+70963449246"}
0005433868105	2D5526	9716 060602	TATYANA KOLESNIKOVA	{"phone": "+70299435686"}
0005433868106	79D4AF	1805 341948	KLAVDIYA KOZLOVA	{"email": "k_kozlova101980@postgrespro.ru", "phone": "+70118503780"}
0005433868107	79D4AF	3290 064490	TIMUR TIKHONOV	{"email": "tikhonov-timur_121989@postgrespro.ru", "phone": "+70806195052"}
0005433868108	7B1EC9	9193 824490	RENAT KARPOV	{"phone": "+70641440715"}
0005433868109	537F50	3488 367051	VIKTORIYA GRISHINA	{"phone": "+70800208115"}
0005433868110	537F50	5951 791293	MARK GRIGOREV	{"email": "grigorev_m_111971@postgrespro.ru", "phone": "+70275193531"}
0005433868111	EF3B72	8526 847986	ZINAIDA MIKHAYLOVA	{"email": "mikhaylova_z26051962@postgrespro.ru", "phone": "+70693046593"}
0005433868112	EF3B72	4934 210843	MIKHAIL MELNIKOV	{"email": "m-melnikov-041962@postgrespro.ru", "phone": "+70704240278"}
0005433868113	877CF8	7612 006366	ALEKSANDR POPOV	{"email": "popov.a.081972@postgrespro.ru", "phone": "+70897600706"}
0005433868114	877CF8	6371 981150	ALINA LEBEDEVA	{"phone": "+70488398868"}
0005433868115	4D0F6B	4971 364642	ANTONINA SOROKINA	{"phone": "+70458100973"}
0005433868116	AA283E	9363 329386	ALEKSANDR BARANOV	{"phone": "+70194721727"}
0005433868117	AC93B2	8110 721966	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr-15111972@postgrespro.ru", "phone": "+70675596210"}
0005433868118	B8BF4D	3286 963689	ALEKSANDR GERASIMOV	{"phone": "+70252218671"}
0005433868119	B8BF4D	8315 111570	MAKSIM SOKOLOV	{"email": "sokolov_maksim.081981@postgrespro.ru", "phone": "+70280583468"}
0005433868120	31441A	3967 058048	VALENTINA KRASNOVA	{"email": "vkrasnova_011979@postgrespro.ru", "phone": "+70853113701"}
0005433868121	8CED70	7078 187490	KSENIYA SOROKINA	{"email": "ksorokina1985@postgrespro.ru", "phone": "+70200091074"}
0005433868122	03A285	0920 608513	VLADIMIR KOZLOV	{"phone": "+70216457063"}
0005433868123	282446	2745 038121	EVGENIYA KUZNECOVA	{"email": "kuznecovaevgeniya.1984@postgrespro.ru", "phone": "+70888732807"}
0005433868124	91F394	9663 082910	GRIGORIY NIKOLAEV	{"email": "nikolaevg061975@postgrespro.ru", "phone": "+70438640780"}
0005433868125	EE297A	9058 049846	NIKOLAY TIMOFEEV	{"email": "timofeev_n-111981@postgrespro.ru", "phone": "+70807220306"}
0005433868126	132670	5662 338462	VENIAMIN MOROZOV	{"email": "morozov_veniamin.101989@postgrespro.ru", "phone": "+70374698855"}
0005433868127	D77426	3263 416902	TATYANA SOKOLOVA	{"email": "sokolova.t.021976@postgrespro.ru", "phone": "+70517886134"}
0005433868128	35D823	2908 062151	NATALYA KUZNECOVA	{"phone": "+70503428046"}
0005433868129	9E1621	6017 538076	ELENA NOVIKOVA	{"email": "novikovaelena.1977@postgrespro.ru", "phone": "+70933955924"}
0005433868130	F7C0A1	0926 639973	NIKOLAY SIDOROV	{"phone": "+70607548361"}
0005433868131	EFBC18	6130 739942	OLEG KISELEV	{"email": "o.kiselev30031970@postgrespro.ru", "phone": "+70735401436"}
0005433868132	CDE037	0016 642766	INNA ILINA	{"phone": "+70043104885"}
0005433868133	CDE037	0325 151364	DMITRIY PETROV	{"email": "petrov.d-051978@postgrespro.ru", "phone": "+70276516239"}
0005433868134	ADAC12	6903 597183	VIKTOR NIKITIN	{"email": "v_nikitin_1976@postgrespro.ru", "phone": "+70145923204"}
0005433868135	ADAC12	6872 056969	YULIYA MAKSIMOVA	{"email": "maksimovay_03061978@postgrespro.ru", "phone": "+70163585346"}
0005433868136	6A5248	2965 741868	IGOR MOROZOV	{"email": "imorozov.04061970@postgrespro.ru", "phone": "+70100117159"}
0005433868137	18DA29	6390 667657	MIKHAIL ORLOV	{"email": "orlov.m-04121965@postgrespro.ru", "phone": "+70973432460"}
0005433868138	7D77B3	7174 036268	ALEKSANDRA NIKOLAEVA	{"email": "nikolaeva_aleksandra1965@postgrespro.ru", "phone": "+70012791271"}
0005433868139	7D77B3	3518 694616	ALEKSEY NAUMOV	{"email": "naumova.1958@postgrespro.ru", "phone": "+70056852184"}
0005433868140	75E2A7	3028 857860	NADEZHDA KONDRATEVA	{"email": "n.kondrateva_1970@postgrespro.ru", "phone": "+70144591428"}
0005433868141	0F7425	7844 948403	DMITRIY RODIONOV	{"email": "dmitriy.rodionov.1969@postgrespro.ru", "phone": "+70596555023"}
0005433868142	1111C9	2384 103138	IVAN KOZLOV	{"email": "i-kozlov.1968@postgrespro.ru", "phone": "+70805681574"}
0005433868143	1111C9	7131 578902	DMITRIY SCHERBAKOV	{"phone": "+70792304922"}
0005433868144	4CAAFB	9170 975866	ALEKSEY SOKOLOV	{"phone": "+70194920145"}
0005433868145	762D05	7670 386105	ELENA KUZNECOVA	{"phone": "+70089206144"}
0005433868146	F52782	0590 170896	SERGEY IVANOV	{"phone": "+70450098087"}
0005433868147	F52782	2094 205644	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva.1959@postgrespro.ru", "phone": "+70918452129"}
0005433868148	6CC473	6464 029145	KLAVDIYA KOROLEVA	{"email": "k_koroleva-051977@postgrespro.ru", "phone": "+70157291054"}
0005433868149	9F48AF	9135 134886	ALEKSEY KARPOV	{"email": "karpovaleksey.061976@postgrespro.ru", "phone": "+70926103830"}
0005433868150	F21E03	5054 080080	ELIZAVETA VOLKOVA	{"email": "volkova-e-17071970@postgrespro.ru", "phone": "+70433285272"}
0005433868151	E2C92E	2184 545528	ROMAN NIKITIN	{"email": "nikitin_r1975@postgrespro.ru", "phone": "+70631133356"}
0005433868152	E69441	3209 415949	ALEKSEY VOROBEV	{"phone": "+70052044242"}
0005433868153	E69441	6622 054895	SERGEY TIMOFEEV	{"phone": "+70944242174"}
0005433868154	037586	8475 683209	ALEKSANDR ZHUKOV	{"phone": "+70122722262"}
0005433868155	BC063E	8871 368135	ALEKSANDR MELNIKOV	{"phone": "+70092165547"}
0005433868156	BC063E	5137 419027	ALEKSANDR BARANOV	{"email": "aleksandrbaranov021975@postgrespro.ru", "phone": "+70758397906"}
0005433868157	CDCE71	7058 529436	LEONID PAVLOV	{"phone": "+70059849952"}
0005433868158	CDCE71	6653 299260	ALEKSEY POPOV	{"phone": "+70458142262"}
0005433868159	CDCE71	6995 279799	SVETLANA GUSEVA	{"email": "sguseva-1969@postgrespro.ru", "phone": "+70313352990"}
0005433868160	C306AA	4755 490536	ANATOLIY MAKSIMOV	{"email": "anatoliy.maksimov_061979@postgrespro.ru", "phone": "+70928424140"}
0005433868161	1377A9	1803 534542	RAISA ZAKHAROVA	{"email": "r.zakharova_09101980@postgrespro.ru", "phone": "+70835114160"}
0005433868162	62BDCA	2760 194747	VIKTORIYA KRASNOVA	{"email": "krasnova_viktoriya061974@postgrespro.ru", "phone": "+70711414688"}
0005433868163	62BDCA	6388 787534	VASILIY ZHURAVLEV	{"phone": "+70601094526"}
0005433868164	62BDCA	9768 513974	POLINA KUZNECOVA	{"phone": "+70088458387"}
0005433868165	F84F07	0067 413495	SVETLANA GORBUNOVA	{"phone": "+70835296610"}
0005433868166	2ED48D	6287 454297	ANATOLIY SIDOROV	{"email": "anatoliy.sidorov20071977@postgrespro.ru", "phone": "+70810046023"}
0005433868167	150411	1415 134055	ALEKSANDR POPOV	{"email": "popov.aleksandr_041975@postgrespro.ru", "phone": "+70933131718"}
0005433868168	150411	2411 405568	KONSTANTIN KOZLOV	{"phone": "+70617717883"}
0005433868169	19DF52	9674 538946	VALENTINA KALININA	{"email": "valentina.kalinina071972@postgrespro.ru", "phone": "+70226536272"}
0005433868170	19DF52	2129 109808	ALENA MALYSHEVA	{"phone": "+70327612348"}
0005433868171	38612C	1251 665732	KSENIYA KONOVALOVA	{"email": "konovalova_k1976@postgrespro.ru", "phone": "+70635004908"}
0005433868172	180F46	0320 317667	SERGEY PETROV	{"email": "petrov_sergey.041973@postgrespro.ru", "phone": "+70242232506"}
0005433868173	149D97	6261 049736	YURIY ZHURAVLEV	{"email": "y-zhuravlev.091979@postgrespro.ru", "phone": "+70921164046"}
0005433868174	149D97	5164 252899	TATYANA ORLOVA	{"phone": "+70221994890"}
0005433868175	149D97	1623 107743	SVETLANA LEBEDEVA	{"phone": "+70567255836"}
0005433868176	D6AF4C	9105 522977	ELENA EFIMOVA	{"email": "efimova_e_1976@postgrespro.ru", "phone": "+70102663914"}
0005433868177	0EE00E	1742 389092	RUSLAN ZHURAVLEV	{"email": "zhuravlev.r061977@postgrespro.ru", "phone": "+70341776804"}
0005433868178	414AD1	0190 084927	NATALIYA SMIRNOVA	{"phone": "+70172641893"}
0005433868179	F25AFF	9275 908958	VIKTORIYA RYABOVA	{"phone": "+70088069791"}
0005433868180	F25AFF	1688 651573	ALEKSANDR FEDOROV	{"email": "fedorova081971@postgrespro.ru", "phone": "+70596178738"}
0005433868181	96172B	8905 453522	IRINA NIKITINA	{"phone": "+70401168844"}
0005433868182	EA7591	6664 000280	GALINA KRASNOVA	{"email": "galina.krasnova1978@postgrespro.ru", "phone": "+70367192946"}
0005433868183	EA7591	0003 908677	ANATOLIY AFANASEV	{"phone": "+70902570194"}
0005433868184	18B9F0	1444 342984	LYUDMILA ANDREEVA	{"email": "andreeva_lyudmila-121977@postgrespro.ru", "phone": "+70232706795"}
0005433868185	18B9F0	4466 526830	IRINA IVANOVA	{"email": "i-ivanova1978@postgrespro.ru", "phone": "+70534400616"}
0005433868186	C72870	1945 558679	ZAKHAR KUZNECOV	{"phone": "+70412612830"}
0005433868187	835F36	9192 308410	SVETLANA VOROBEVA	{"email": "svetlana-vorobeva1973@postgrespro.ru", "phone": "+70010191968"}
0005433868188	797B42	0381 799052	ZAKHAR KUZMIN	{"phone": "+70140275795"}
0005433868189	38D751	9356 298842	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr-1961@postgrespro.ru", "phone": "+70912302413"}
0005433868190	38D751	7289 750967	VIKTOR ROMANOV	{"email": "romanov.v-1961@postgrespro.ru", "phone": "+70721809889"}
0005433868191	28C807	7238 520200	MARIYA GORBUNOVA	{"phone": "+70275144860"}
0005433868192	421A29	2438 544756	EVDOKIYA OSIPOVA	{"email": "osipova.evdokiya1967@postgrespro.ru", "phone": "+70855391418"}
0005433868193	BBDEC1	5303 761217	ALEKSANDR KUZNECOV	{"email": "a_kuznecov-041971@postgrespro.ru", "phone": "+70339992647"}
0005433868194	4D7EEF	4067 279063	NELLI ZAYCEVA	{"phone": "+70010636894"}
0005433868195	C91469	2009 075941	MARINA VASILEVA	{"phone": "+70072756399"}
0005433868196	C91469	3660 356567	LYUBOV VASILEVA	{"email": "vasileva-lyubov_051964@postgrespro.ru", "phone": "+70019805159"}
0005433868197	8A3AD7	7725 212541	FAINA ILINA	{"email": "ilina_f071966@postgrespro.ru", "phone": "+70341596139"}
0005433868198	5EFDE0	1896 497219	SVETLANA EGOROVA	{"email": "egorova_svetlana_07011971@postgrespro.ru", "phone": "+70050632332"}
0005433868199	B25FB9	3402 122212	VALENTIN ZHURAVLEV	{"phone": "+70888800687"}
0005433868200	EFBDBD	9144 557402	VADIM RODIONOV	{"email": "v.rodionov.16111976@postgrespro.ru", "phone": "+70489522630"}
0005433868201	EFBDBD	3195 477760	ALLA DENISOVA	{"phone": "+70757531792"}
0005433868202	18F625	9203 451390	VLADIMIR CHERNOV	{"email": "chernov_vladimir.091975@postgrespro.ru", "phone": "+70665412746"}
0005433868203	E35AD3	2518 224262	NIKITA KOROLEV	{"email": "n_korolev22071992@postgrespro.ru", "phone": "+70682692564"}
0005433868204	401786	2882 665797	LIDIYA ZHUKOVA	{"phone": "+70729905781"}
0005433868205	C44B67	4753 028678	ALEKSANDR ABRAMOV	{"phone": "+70875232397"}
0005433868206	56DFB4	1514 967062	VALENTINA VLASOVA	{"email": "vlasova.valentina_051968@postgrespro.ru", "phone": "+70972637914"}
0005433868207	307C20	5884 555528	MAYYA GORBUNOVA	{"phone": "+70662530642"}
0005433868208	307C20	7355 320537	OLEG BELOV	{"phone": "+70880745255"}
0005433868209	307C20	9643 074899	LARISA POPOVA	{"phone": "+70007035697"}
0005433868210	00355C	3563 886920	ALENA SEMENOVA	{"email": "semenova-alena28101974@postgrespro.ru", "phone": "+70727399997"}
0005433868211	277A6E	1669 336478	SERGEY IVANOV	{"phone": "+70079424783"}
0005433868212	277A6E	9384 352581	LIDIYA KOZLOVA	{"email": "lidiya-kozlova111973@postgrespro.ru", "phone": "+70557981056"}
0005433868213	E122CB	0352 696801	MIKHAIL SAVELEV	{"phone": "+70702144529"}
0005433868214	E122CB	3470 810141	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov_081978@postgrespro.ru", "phone": "+70023902422"}
0005433868215	4A9063	9267 722029	ELENA KARPOVA	{"phone": "+70500939079"}
0005433868216	BFABD2	6028 282231	EKATERINA FEDOROVA	{"email": "efedorova.1971@postgrespro.ru", "phone": "+70254486890"}
0005433868217	2071CA	7283 604247	NINA ZHURAVLEVA	{"email": "n-zhuravleva_101959@postgrespro.ru", "phone": "+70531576627"}
0005433868218	D16201	1930 007639	ELENA PETROVA	{"phone": "+70075534499"}
0005433868219	77BE9C	1988 913993	NIKOLAY MELNIKOV	{"email": "melnikov.n-14081958@postgrespro.ru", "phone": "+70308390455"}
0005433868220	77BE9C	0676 339051	ALEKSANDRA VASILEVA	{"email": "vasileva.a.06071966@postgrespro.ru", "phone": "+70338262111"}
0005433868221	D2E3F2	7492 428313	ALENA BORISOVA	{"email": "alena.borisova-1981@postgrespro.ru", "phone": "+70391786724"}
0005433868222	011179	6841 426490	VITALIY DMITRIEV	{"phone": "+70853788545"}
0005433868223	A3D390	1165 878357	YURIY VOLKOV	{"email": "volkov_y25011977@postgrespro.ru", "phone": "+70691748500"}
0005433868224	A3D390	7695 269439	ALEKSANDR NAZAROV	{"phone": "+70752964118"}
0005433868225	21127F	0194 754870	SERGEY ALEKSEEV	{"email": "sergey-alekseev.1970@postgrespro.ru", "phone": "+70205034587"}
0005433868226	21127F	7357 345739	ALEKSANDR VASILEV	{"email": "a-vasilev.1964@postgrespro.ru", "phone": "+70904863424"}
0005433868227	70EB52	9378 870908	DMITRIY SAVELEV	{"phone": "+70415998309"}
0005433868228	0ABE9A	3610 722046	ILYA BELOV	{"phone": "+70881001565"}
0005433868229	724021	2399 496768	NINA SOKOLOVA	{"phone": "+70047400326"}
0005433868230	724021	4455 838460	GALINA CHERNOVA	{"email": "galina_chernova_011963@postgrespro.ru", "phone": "+70095567859"}
0005433868231	4883F9	4033 210550	GALINA MATVEEVA	{"phone": "+70729914478"}
0005433868232	4883F9	9088 549686	DARYA SMIRNOVA	{"email": "smirnova-d.29061959@postgrespro.ru", "phone": "+70056693120"}
0005433868233	4883F9	1449 939845	VALENTINA NIKITINA	{"email": "nikitinav-1968@postgrespro.ru", "phone": "+70673805137"}
0005433868234	4883F9	7879 784408	IRINA POLYAKOVA	{"phone": "+70877220894"}
0005433868235	931E2A	7752 528871	ALEKSANDR SAVELEV	{"phone": "+70391160183"}
0005433868236	DB7B6C	8062 275229	MARIYA NAUMOVA	{"email": "naumova-m21081975@postgrespro.ru", "phone": "+70250574551"}
0005433868237	A0DF9F	7298 316266	SVETLANA DMITRIEVA	{"email": "s.dmitrieva_12031973@postgrespro.ru", "phone": "+70407685602"}
0005433868238	A0DF9F	8172 395597	ELENA ANDREEVA	{"phone": "+70581524573"}
0005433868239	C3EC1B	5524 714052	ANNA VASILEVA	{"email": "anna-vasileva-22051982@postgrespro.ru", "phone": "+70584245503"}
0005433868240	C3EC1B	4132 086384	ANNA EGOROVA	{"email": "egorova_a-17031971@postgrespro.ru", "phone": "+70932914781"}
0005433868241	557C2B	3233 101076	NATALYA MATVEEVA	{"email": "matveeva.n.16071975@postgrespro.ru", "phone": "+70989044146"}
0005433868242	557C2B	8069 043966	SERGEY VOLKOV	{"email": "sergey.volkov_03041967@postgrespro.ru", "phone": "+70932945311"}
0005433868243	B02F11	3626 731540	KARINA ALEKSANDROVA	{"phone": "+70943738733"}
0005433868244	84872B	6296 936284	MARIYA ZAKHAROVA	{"email": "mariyazakharova25011973@postgrespro.ru", "phone": "+70296319558"}
0005433868245	9BC211	7642 089254	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov16111967@postgrespro.ru", "phone": "+70056377136"}
0005433868246	9BC211	7244 317452	VLADIMIR PAVLOV	{"email": "pavlov_vladimir_011972@postgrespro.ru", "phone": "+70836999309"}
0005433868247	C3F812	5122 268282	NIKOLAY NAUMOV	{"phone": "+70984368376"}
0005433868248	C3F812	6264 011874	VLADISLAV FEDOROV	{"email": "fedorov.vladislav.101978@postgrespro.ru", "phone": "+70320859122"}
0005433868249	6C98EC	9897 134589	DMITRIY SOLOVEV	{"phone": "+70542704125"}
0005433868250	95F0CC	8799 134910	IRINA BORISOVA	{"email": "irina.borisova-011975@postgrespro.ru", "phone": "+70516757732"}
0005433868251	BCA2D4	1830 684725	MARGARITA LAZAREVA	{"email": "m.lazareva-17021968@postgrespro.ru", "phone": "+70553763200"}
0005433868252	0B7BA8	2449 597398	STEPAN GUSEV	{"email": "gusevstepan.23061971@postgrespro.ru", "phone": "+70830619345"}
0005433868253	462493	8720 031391	MIKHAIL KUZMIN	{"phone": "+70227701436"}
0005433868254	797CF4	7556 971723	ALEKSANDR POPOV	{"phone": "+70902420890"}
0005433868255	797CF4	9844 022597	PETR IVANOV	{"phone": "+70053155208"}
0005433868256	B23B2B	3143 699815	ANNA DENISOVA	{"phone": "+70827536555"}
0005433868257	87D504	4690 678851	GALINA KARPOVA	{"phone": "+70925506619"}
0005433868258	78C964	4990 557239	EVGENIY FOMIN	{"email": "evgeniy.fomin.05081973@postgrespro.ru", "phone": "+70575800560"}
0005433868259	78C964	0573 602739	ANDREY EGOROV	{"email": "egorov_andrey.1984@postgrespro.ru", "phone": "+70593438931"}
0005433868260	2284F1	7614 416308	ANASTASIYA BARANOVA	{"phone": "+70819192113"}
0005433868261	2284F1	9128 200767	LYUBOV KOROLEVA	{"phone": "+70401724274"}
0005433868262	75A305	2956 105072	OKSANA DENISOVA	{"phone": "+70907769735"}
0005433868263	05CD5C	4686 729052	NIKOLAY SCHERBAKOV	{"phone": "+70684317850"}
0005433868264	FE6AA8	6508 031956	TATYANA ILINA	{"phone": "+70268521187"}
0005433868265	FE6AA8	7521 753409	KLAVDIYA SMIRNOVA	{"email": "smirnova.klavdiya_1971@postgrespro.ru", "phone": "+70419622047"}
0005433868266	FE6AA8	0338 418470	DENIS ORLOV	{"phone": "+70963480752"}
0005433868267	5C7BA6	4296 353256	ALEKSANDR IVANOV	{"email": "ivanov_a011971@postgrespro.ru", "phone": "+70043453545"}
0005433868268	5C7BA6	4744 155808	TATYANA KUZNECOVA	{"phone": "+70234925932"}
0005433868269	41A3F6	6119 349640	MARIYA DENISOVA	{"phone": "+70704890537"}
0005433868270	0FAAA7	5144 737067	EMIL NIKOLAEV	{"phone": "+70301965602"}
0005433868271	D0233E	4524 807823	ISLAM MAKSIMOV	{"email": "maksimov_islam.101967@postgrespro.ru", "phone": "+70054820516"}
0005433868272	D0233E	3415 113429	DMITRIY ILIN	{"email": "ilin_d.051982@postgrespro.ru", "phone": "+70364565779"}
0005433868273	8777C9	1978 476360	NIKOLAY VOLKOV	{"phone": "+70027137389"}
0005433868274	8777C9	9036 015597	ELENA BOGDANOVA	{"phone": "+70040466000"}
0005433868275	97E03B	1207 384842	LYUDMILA MIRONOVA	{"email": "mironova.l.051976@postgrespro.ru", "phone": "+70881047849"}
0005433868276	97E03B	0619 805144	ANATOLIY NAUMOV	{"email": "anatoliynaumov-061973@postgrespro.ru", "phone": "+70376391529"}
0005433868277	4EA4B4	0346 861924	YULIYA POPOVA	{"email": "yuliya.popova-1975@postgrespro.ru", "phone": "+70742824602"}
0005433868278	99746F	5006 755424	KONSTANTIN MAKAROV	{"email": "makarov.k.1971@postgrespro.ru", "phone": "+70695162773"}
0005433868279	99746F	5709 455161	VERA VLASOVA	{"phone": "+70420328647"}
0005433868281	34D444	8135 828131	YULIYA EGOROVA	{"phone": "+70654138689"}
0005433868282	AFBFEE	0387 565430	ILYA EGOROV	{"phone": "+70300909746"}
0005433868283	AFBFEE	9812 762761	YANA POTAPOVA	{"email": "potapova-y_16051963@postgrespro.ru", "phone": "+70699154906"}
0005433868284	AFBFEE	9826 625291	MARIYA SMIRNOVA	{"email": "smirnovam-1980@postgrespro.ru", "phone": "+70777640911"}
0005433868285	1A326F	0451 043602	DENIS KUZMIN	{"phone": "+70455098786"}
0005433868286	1562CD	5578 504960	GALINA KOZLOVA	{"phone": "+70743759252"}
0005433868287	1562CD	1969 210742	VALERIYA YAKOVLEVA	{"email": "vyakovleva_15111967@postgrespro.ru", "phone": "+70966141233"}
0005433868288	CA45B9	8353 880796	IRINA GUSEVA	{"email": "irina.guseva051966@postgrespro.ru", "phone": "+70744761186"}
0005433868289	CA45B9	0913 305269	ALEKSANDR CHERNOV	{"phone": "+70109388355"}
0005433868290	C04C05	7412 856823	VITALIY DMITRIEV	{"email": "dmitriev-v.24021972@postgrespro.ru", "phone": "+70528530511"}
0005433868291	C04C05	1279 818473	LYUDMILA ANDREEVA	{"email": "l.andreeva-1961@postgrespro.ru", "phone": "+70224017227"}
0005433868292	64C3EE	0887 868545	VLADISLAV VOROBEV	{"phone": "+70126995604"}
0005433868293	FCEADC	5582 732208	MARIYA IVANOVA	{"email": "mariyaivanova.121963@postgrespro.ru", "phone": "+70636945856"}
0005433868294	FCEADC	7572 670385	MAKSIM NIKOLAEV	{"phone": "+70938226205"}
0005433868295	1379C3	2900 637441	DENIS KUZMIN	{"phone": "+70664049821"}
0005433868296	FFA930	9534 031715	ALEKSEY POPOV	{"email": "aleksey_popov1965@postgrespro.ru", "phone": "+70975055243"}
0005433868297	43F4BF	0742 306969	DMITRIY ZAKHAROV	{"email": "d_zakharov031976@postgrespro.ru", "phone": "+70612801927"}
0005433868298	0E8ABA	5195 694446	VYACHESLAV NAUMOV	{"phone": "+70742754226"}
0005433868299	7CE454	2669 173342	ELENA KUDRYASHOVA	{"email": "kudryashova.elena_011970@postgrespro.ru", "phone": "+70636913149"}
0005433868300	BBD858	4457 106182	EGOR KOROLEV	{"email": "korolev_e051962@postgrespro.ru", "phone": "+70278997538"}
0005433868301	4923CE	2750 952202	SERGEY ROMANOV	{"phone": "+70685143782"}
0005433868302	4923CE	8501 273358	ZINAIDA MOISEEVA	{"email": "zmoiseeva_061974@postgrespro.ru", "phone": "+70576991031"}
0005433868303	96B399	0576 187533	ILDAR MATVEEV	{"phone": "+70605922828"}
0005433868304	96B399	2086 478654	ALEKSANDRA LOGINOVA	{"phone": "+70277390147"}
0005433868305	3F4D77	7947 797386	ALEKSEY FILIPPOV	{"phone": "+70144430800"}
0005433868306	899E52	9390 995953	DMITRIY TIKHONOV	{"email": "tikhonovdmitriy17071968@postgrespro.ru", "phone": "+70932093889"}
0005433868307	3C717B	5258 473739	VALENTIN SAVELEV	{"email": "v-savelev_1974@postgrespro.ru", "phone": "+70880188147"}
0005433868308	CCBE3F	1848 998877	VYACHESLAV IVANOV	{"phone": "+70052461076"}
0005433868309	F0FE07	3801 204413	MIKHAIL BORISOV	{"phone": "+70633437335"}
0005433868310	EB6F6D	1761 405398	ZOYA MELNIKOVA	{"email": "zoya-melnikova27081983@postgrespro.ru", "phone": "+70219677360"}
0005433868311	BD05F7	5752 560964	PETR KAZAKOV	{"phone": "+70757393458"}
0005433868312	00E725	4910 452806	DMITRIY OSIPOV	{"email": "osipov.dmitriy1971@postgrespro.ru", "phone": "+70971943866"}
0005433868313	00E725	4787 802812	ELENA POLYAKOVA	{"phone": "+70298620824"}
0005433868314	07D484	2679 716482	TATYANA SERGEEVA	{"phone": "+70314640375"}
0005433868315	8F4E71	4891 642980	VLADIMIR KONOVALOV	{"email": "konovalovvladimir_07041975@postgrespro.ru", "phone": "+70560248835"}
0005433868316	B42C90	1548 439356	ALEKSEY ANDREEV	{"email": "andreev-aleksey-03101968@postgrespro.ru", "phone": "+70324473273"}
0005433868317	E67282	3204 426163	ILYA MAKSIMOV	{"email": "maksimov.ilya.1968@postgrespro.ru", "phone": "+70937570889"}
0005433868318	6E1994	8488 954541	NATALYA KULIKOVA	{"email": "natalyakulikova1974@postgrespro.ru", "phone": "+70791377953"}
0005433868319	C369A0	3284 985597	NINA CHERNOVA	{"phone": "+70664129214"}
0005433868320	DD2DEB	9808 785777	VLADIMIR ABRAMOV	{"email": "vladimir_abramov-05021982@postgrespro.ru", "phone": "+70728449595"}
0005433868321	DEC305	9349 503356	SVETLANA SIDOROVA	{"phone": "+70135021022"}
0005433868322	DEC305	3773 801223	OLGA TIMOFEEVA	{"phone": "+70235631110"}
0005433868323	DEC305	8996 664784	GALINA GAVRILOVA	{"phone": "+70860083011"}
0005433868324	512AA6	2429 195392	VLADIMIR ANDREEV	{"email": "andreev_v_011968@postgrespro.ru", "phone": "+70268736631"}
0005433868325	512AA6	1714 675916	VERONIKA MIKHAYLOVA	{"phone": "+70467220188"}
0005433868381	AAB939	7570 248972	SERGEY OSIPOV	{"phone": "+70773521501"}
0005433868326	34FA74	2474 302391	YULIYA MOISEEVA	{"email": "yuliyamoiseeva121971@postgrespro.ru", "phone": "+70598250373"}
0005433868327	34FA74	9057 095515	LYUBOV ARKHIPOVA	{"email": "l.arkhipova.25051964@postgrespro.ru", "phone": "+70990606292"}
0005433868328	9F0E8E	4163 238379	ANDREY MIKHAYLOV	{"phone": "+70991595565"}
0005433868329	A40674	9098 242970	ANASTASIYA FILIPPOVA	{"phone": "+70782353450"}
0005433868330	CFB976	8953 654208	SERGEY FILIPPOV	{"email": "sfilippov_121977@postgrespro.ru", "phone": "+70794283363"}
0005433868331	CEC8C8	7633 827023	ANZHELIKA SAVELEVA	{"email": "saveleva-anzhelika_23071973@postgrespro.ru", "phone": "+70360718415"}
0005433868332	9DD2DF	6988 562718	SABINA MELNIKOVA	{"email": "melnikova_s111974@postgrespro.ru", "phone": "+70701671379"}
0005433868333	849218	8552 547098	VLADISLAV FEDOTOV	{"email": "fedotovvladislav031976@postgrespro.ru", "phone": "+70699370434"}
0005433868334	849218	0786 919465	SERGEY POPOV	{"email": "popov.sergey_1966@postgrespro.ru", "phone": "+70225307921"}
0005433868335	C8089D	0088 590592	VASILIY KARPOV	{"phone": "+70739675619"}
0005433868336	8A9A25	3785 795312	NINA DAVYDOVA	{"phone": "+70142585960"}
0005433868337	AB8031	4669 794463	VALERIY KUZNECOV	{"phone": "+70719690153"}
0005433868338	3D6905	6924 016004	GENNADIY VOLKOV	{"email": "volkov-gennadiy.03051973@postgrespro.ru", "phone": "+70009573422"}
0005433868339	3D6905	3196 402411	ANDREY KRASNOV	{"phone": "+70788848484"}
0005433868340	35EFDB	3591 194913	SVETLANA PETROVA	{"phone": "+70252370636"}
0005433868341	38EB35	1786 695078	NATALYA DANILOVA	{"email": "natalya_danilova.07051961@postgrespro.ru", "phone": "+70969836236"}
0005433868342	4E8FFB	6104 867011	EKATERINA ANTONOVA	{"phone": "+70647373531"}
0005433868343	4E8FFB	5235 572024	SERGEY ILIN	{"email": "ilin.s.08081977@postgrespro.ru", "phone": "+70159631565"}
0005433868344	5B0C09	9377 040027	ELENA ZAKHAROVA	{"email": "zakharova_elena1984@postgrespro.ru", "phone": "+70640951576"}
0005433868345	5B0C09	4058 523313	YURIY NAZAROV	{"phone": "+70996262639"}
0005433868346	8166A8	7204 109014	SERGEY FOMIN	{"email": "fomins_21081978@postgrespro.ru", "phone": "+70969424453"}
0005433868347	8166A8	5433 712315	OLGA IVANOVA	{"phone": "+70036366142"}
0005433868348	2D45CA	4061 685569	ELENA BELOVA	{"email": "elenabelova-28021980@postgrespro.ru", "phone": "+70506665480"}
0005433868349	2D8E6D	6037 390717	VERA MOROZOVA	{"email": "veramorozova.061976@postgrespro.ru", "phone": "+70417803997"}
0005433868350	C08C50	6795 255511	NINA KOMAROVA	{"email": "komarovanina.1979@postgrespro.ru", "phone": "+70849745488"}
0005433868351	C08C50	6320 366383	ANNA PAVLOVA	{"email": "apavlova.1959@postgrespro.ru", "phone": "+70769231632"}
0005433868352	D2D000	6611 728135	EKATERINA ROMANOVA	{"phone": "+70043294475"}
0005433868353	D2D000	6483 038086	YULIYA AKIMOVA	{"email": "akimova.yuliya.29081976@postgrespro.ru", "phone": "+70014250213"}
0005433868354	76885E	7642 763686	IVAN NOVIKOV	{"email": "ivan_novikov091966@postgrespro.ru", "phone": "+70725903467"}
0005433868355	76885E	2456 323658	VLADISLAV ZAKHAROV	{"email": "vladislavzakharov.1968@postgrespro.ru", "phone": "+70671905929"}
0005433868356	1EDB9F	2302 850464	ALEKSANDR STEPANOV	{"phone": "+70086986171"}
0005433868357	60354A	8464 395732	SVETLANA KAZAKOVA	{"phone": "+70816853668"}
0005433868358	B947DC	2183 307960	ELENA GUSEVA	{"email": "guseva-e021970@postgrespro.ru", "phone": "+70270955189"}
0005433868359	CE64C2	9461 910451	LARISA MIKHAYLOVA	{"email": "mikhaylova.larisa01071963@postgrespro.ru", "phone": "+70635272984"}
0005433868360	CE64C2	8810 805216	OLGA KOZLOVA	{"email": "olga_kozlova-29051971@postgrespro.ru", "phone": "+70581008084"}
0005433868361	E85797	1266 072534	LYUDMILA SOKOLOVA	{"phone": "+70121978336"}
0005433868362	C3D974	5106 146895	VASILIY FROLOV	{"email": "vasiliy_frolov-07101976@postgrespro.ru", "phone": "+70950401218"}
0005433868363	C3D974	9460 687139	PAVEL ROMANOV	{"email": "promanov_061961@postgrespro.ru", "phone": "+70206736216"}
0005433868364	5F73C2	3342 466368	YULIYA ORLOVA	{"email": "orlovayuliya_1971@postgrespro.ru", "phone": "+70953300485"}
0005433868365	2963AF	4908 656051	ALEKSANDRA NIKOLAEVA	{"phone": "+70714733598"}
0005433868366	2963AF	8998 178195	ANTON MAKAROV	{"email": "a_makarov-121964@postgrespro.ru", "phone": "+70867013893"}
0005433868367	FA3D4E	1119 233893	VYACHESLAV VASILEV	{"email": "vasilev-v.25051964@postgrespro.ru", "phone": "+70414391142"}
0005433868368	FA3D4E	7582 388868	SERGEY ROMANOV	{"email": "sergeyromanov10061981@postgrespro.ru", "phone": "+70317799031"}
0005433868369	A661F5	7625 746057	GALINA NAZAROVA	{"phone": "+70597297939"}
0005433868370	8F5195	4378 360957	TATYANA SIDOROVA	{"phone": "+70785490999"}
0005433868371	8AB669	5040 725060	EVGENIYA KOMAROVA	{"email": "e.komarova_1976@postgrespro.ru", "phone": "+70046938583"}
0005433868372	100597	4114 222476	IGOR MAKAROV	{"phone": "+70168114471"}
0005433868373	D59BCE	4560 510375	YURIY OSIPOV	{"email": "osipovy.071965@postgrespro.ru", "phone": "+70814950206"}
0005433868374	D59BCE	2615 026825	MAKSIM VASILEV	{"phone": "+70801615769"}
0005433868375	D59BCE	8780 780619	GALINA GUSEVA	{"phone": "+70372627563"}
0005433868376	5529F0	0976 485341	VALERIY ANTONOV	{"email": "vantonov-051973@postgrespro.ru", "phone": "+70027305538"}
0005433868377	AD8528	3982 144542	SVETLANA KISELEVA	{"email": "s-kiseleva02031974@postgrespro.ru", "phone": "+70939384634"}
0005433868378	187FDE	1464 047507	VIKTOR ANTONOV	{"phone": "+70945290644"}
0005433868379	79E5E5	5025 187785	YULIYA KOZLOVA	{"phone": "+70814101057"}
0005433868380	C79D7B	0495 299373	ANTONIDA KONOVALOVA	{"email": "konovalovaa1972@postgrespro.ru", "phone": "+70008565429"}
0005433868382	FCB17C	8425 982793	ROZA SCHERBAKOVA	{"email": "roza-scherbakova.041972@postgrespro.ru", "phone": "+70494956606"}
0005433868383	4B795C	5289 727934	NADEZHDA VASILEVA	{"email": "nadezhda.vasileva10061971@postgrespro.ru", "phone": "+70892395992"}
0005433868384	4B795C	7834 309715	ARINA SEMENOVA	{"email": "arinasemenova061968@postgrespro.ru", "phone": "+70799150735"}
0005433868385	10B573	8006 557106	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.galina.25061967@postgrespro.ru", "phone": "+70491733782"}
0005433868386	10B573	8502 023693	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova1971@postgrespro.ru", "phone": "+70241489583"}
0005433868387	10B573	9826 896962	VIKTORIYA NIKOLAEVA	{"phone": "+70097044179"}
0005433868388	82395D	1051 809228	ELENA SOLOVEVA	{"email": "esoloveva1967@postgrespro.ru", "phone": "+70369496508"}
0005433868389	82395D	2229 244893	SVETLANA EFREMOVA	{"phone": "+70437405309"}
0005433868390	82395D	7952 168850	ELENA GORBUNOVA	{"phone": "+70211723844"}
0005433868391	ABC395	8313 085319	IRINA POPOVA	{"phone": "+70207271893"}
0005433868392	ABC395	0365 888452	ELENA KOZLOVA	{"email": "ekozlova_091975@postgrespro.ru", "phone": "+70051114228"}
0005433868393	C2B407	7071 365644	KARIM SCHERBAKOV	{"phone": "+70443197769"}
0005433868394	DC56FD	9645 761044	DAVID ALEKSANDROV	{"email": "david.aleksandrov1970@postgrespro.ru", "phone": "+70963395121"}
0005433868395	009814	4441 423968	MIKHAIL IVANOV	{"email": "ivanov.mikhail.111962@postgrespro.ru", "phone": "+70451784897"}
0005433868396	009814	0065 471016	GALINA STEPANOVA	{"phone": "+70506110781"}
0005433868397	B89B71	0039 878081	IRINA STEPANOVA	{"phone": "+70235790406"}
0005433868398	B89B71	1450 854310	ANATOLIY KUZNECOV	{"phone": "+70628922868"}
0005433868399	DF1379	8548 809289	VLADISLAV BELOV	{"email": "vladislav-belov21101983@postgrespro.ru", "phone": "+70265454757"}
0005433868400	932E0C	7476 858545	ALENA KOROLEVA	{"phone": "+70919065866"}
0005433868401	932E0C	2378 457846	LYUDMILA KOZLOVA	{"email": "l_kozlova_01071964@postgrespro.ru", "phone": "+70661227784"}
0005433868402	42917A	3371 949488	EKATERINA LAZAREVA	{"email": "ekaterina_lazareva071970@postgrespro.ru", "phone": "+70473279791"}
0005433868403	F9804B	7635 754453	VYACHESLAV STEPANOV	{"phone": "+70519638285"}
0005433868404	F9804B	0813 671726	ELENA IVANOVA	{"email": "e.ivanova20091966@postgrespro.ru", "phone": "+70674580788"}
0005433868405	F9804B	6900 757599	NINA KUZNECOVA	{"email": "nina_kuznecova_1968@postgrespro.ru", "phone": "+70332292933"}
0005433868406	7225FE	1061 485898	GALINA MIRONOVA	{"email": "mironova.galina24041983@postgrespro.ru", "phone": "+70388991751"}
0005433868407	566D02	6751 183882	VASILIY NAZAROV	{"phone": "+70496121956"}
0005433868408	DBB6CB	6826 082553	ALENA DMITRIEVA	{"phone": "+70848027829"}
0005433868409	3EB4B1	4075 811297	TAMARA KUZNECOVA	{"email": "kuznecovatamara-07081979@postgrespro.ru", "phone": "+70986939962"}
0005433868410	6C4E7C	1061 242987	ALEKSANDR KOZLOV	{"phone": "+70979144674"}
0005433868411	1D6C0C	6375 595970	DENIS ISAEV	{"email": "isaev-denis-051982@postgrespro.ru", "phone": "+70284284526"}
0005433868412	4013A2	2535 700341	INNA SERGEEVA	{"phone": "+70093595880"}
0005433868413	DAF79E	9619 165673	VYACHESLAV MOROZOV	{"email": "morozov-vyacheslav_1965@postgrespro.ru", "phone": "+70001649446"}
0005433868414	40649A	8478 606453	ZARINA ANDREEVA	{"email": "andreevaz_14081967@postgrespro.ru", "phone": "+70951168785"}
0005433868415	1F33FE	1999 711500	EKATERINA NIKIFOROVA	{"phone": "+70745048545"}
0005433868416	C4A4F5	7127 274426	SVETLANA BARANOVA	{"phone": "+70873173592"}
0005433868417	C4A4F5	6925 573360	MARINA EGOROVA	{"phone": "+70655315682"}
0005433868418	E974FE	1706 025790	DMITRIY BORISOV	{"phone": "+70823770129"}
0005433868419	3C0F60	4620 016226	YULIYA MARTYNOVA	{"email": "y.martynova-19111976@postgrespro.ru", "phone": "+70681075322"}
0005433868420	B681BB	4295 522666	YURIY EGOROV	{"email": "y.egorov061974@postgrespro.ru", "phone": "+70852790819"}
0005433868421	D8FB8F	8777 171659	ALSU PAVLOVA	{"phone": "+70584991509"}
0005433868422	D8FB8F	0071 723208	YURIY SIDOROV	{"phone": "+70921586874"}
0005433868423	A172A5	3274 940124	VITALIY SIDOROV	{"email": "vitaliy.sidorov.111987@postgrespro.ru", "phone": "+70857660881"}
0005433868424	A172A5	0450 778427	MARINA ZAYCEVA	{"phone": "+70250470823"}
0005433868425	9AAA87	9890 984767	OLGA SMIRNOVA	{"phone": "+70468036336"}
0005433868426	9AAA87	1784 027301	VALERIY PAVLOV	{"phone": "+70010235479"}
0005433868427	C069A4	2454 529946	EDGAR MELNIKOV	{"phone": "+70560474258"}
0005433868428	7EE88E	5506 527384	LARISA MELNIKOVA	{"email": "melnikovalarisa.1966@postgrespro.ru", "phone": "+70862170476"}
0005433868429	7C1CB7	6183 325757	YULIYA MASLOVA	{"phone": "+70278462765"}
0005433868430	7C1CB7	3044 492509	LARISA KRASNOVA	{"phone": "+70277915624"}
0005433868431	321519	1741 738248	TATYANA SEMENOVA	{"phone": "+70881020468"}
0005433868432	24539D	6183 591112	VLADIMIR MAKSIMOV	{"email": "maksimovvladimir-22121972@postgrespro.ru", "phone": "+70493911158"}
0005433868433	3526EF	4754 278396	NIKOLAY NAUMOV	{"phone": "+70074807152"}
0005433868434	DCAC01	9133 467257	MIKHAIL POPOV	{"email": "popov.m-021973@postgrespro.ru", "phone": "+70811732889"}
0005433868435	1582E9	7789 791147	VIKTORIYA KOVALEVA	{"email": "viktoriya.kovaleva.111964@postgrespro.ru", "phone": "+70789423966"}
0005433868436	7CDFED	4731 486253	KSENIYA ZHUKOVA	{"phone": "+70511260913"}
0005433868437	22DF3F	5268 255597	LIDIYA GAVRILOVA	{"phone": "+70125791142"}
0005433868438	F67BF6	9920 966838	EKATERINA ORLOVA	{"email": "orlova.ekaterina111966@postgrespro.ru", "phone": "+70417791937"}
0005433868439	8301DE	3325 082820	MARINA VLASOVA	{"phone": "+70746261101"}
0005433868440	6B5B8C	4984 032352	VLADISLAV BELOV	{"phone": "+70886443394"}
0005433868441	F5AA85	3900 730918	VLADIMIR ANTONOV	{"email": "antonovv-1959@postgrespro.ru", "phone": "+70140149906"}
0005433868442	8C9B40	8576 006356	ALEKSEY STEPANOV	{"email": "stepanova-1974@postgrespro.ru", "phone": "+70483690712"}
0005433868443	8C9B40	4123 176446	LARISA KULIKOVA	{"email": "l_kulikova_09011968@postgrespro.ru", "phone": "+70783691539"}
0005433868444	36146D	2882 617030	POLINA POPOVA	{"email": "polinapopova-081974@postgrespro.ru", "phone": "+70756271407"}
0005433868445	36146D	9342 181086	NATALYA MELNIKOVA	{"email": "natalya-melnikova21051978@postgrespro.ru", "phone": "+70765982451"}
0005433868446	A20595	5250 726033	NATALYA PETROVA	{"phone": "+70091067747"}
0005433868447	A20595	5012 863874	GENNADIY KUZMIN	{"email": "gkuzmin-011970@postgrespro.ru", "phone": "+70295935755"}
0005433868448	30F5E1	5561 341263	KIRILL OSIPOV	{"email": "k.osipov16071979@postgrespro.ru", "phone": "+70870347481"}
0005433868449	02D614	2685 598066	OLGA NIKITINA	{"email": "nikitina_olga_04081970@postgrespro.ru", "phone": "+70091579814"}
0005433868450	C98F59	7789 904505	NIKITA NIKOLAEV	{"phone": "+70340817594"}
0005433868451	56E9BF	8105 424032	ANDREY KAZAKOV	{"phone": "+70014913659"}
0005433868452	D1131A	8164 350450	VLADIMIR BONDARENKO	{"phone": "+70533849653"}
0005433868453	D5460A	2906 690964	MARINA MOISEEVA	{"phone": "+70916774712"}
0005433868454	D64091	4066 118854	ANDREY POPOV	{"phone": "+70305871244"}
0005433868455	8FFDCF	1467 302631	IRINA SEMENOVA	{"email": "semenova-irina1972@postgrespro.ru", "phone": "+70744673644"}
0005433868456	903480	9332 311956	NADEZHDA KOROLEVA	{"email": "n-koroleva-30041984@postgrespro.ru", "phone": "+70393947633"}
0005433868457	903480	1818 684691	VLADIMIR VOLKOV	{"phone": "+70535282314"}
0005433868458	D7F946	5285 204962	SVETLANA FADEEVA	{"email": "fadeeva-svetlana.041964@postgrespro.ru", "phone": "+70847575404"}
0005433868459	D7F946	9403 187728	DENIS OSIPOV	{"phone": "+70659682949"}
0005433868460	C599EA	0039 494074	NINA GAVRILOVA	{"phone": "+70406523295"}
0005433868461	C599EA	5722 496372	ALEKSANDR KUZNECOV	{"email": "kuznecova_1972@postgrespro.ru", "phone": "+70833818910"}
0005433868462	647119	7611 246450	ANDREY NIKOLAEV	{"email": "nikolaev.andrey1973@postgrespro.ru", "phone": "+70051949369"}
0005433868463	9F7C07	1442 690971	EKATERINA ANDREEVA	{"email": "andreeva_e-031977@postgrespro.ru", "phone": "+70113382190"}
0005433868464	1F9062	3327 665420	YULIYA KUDRYASHOVA	{"phone": "+70904293706"}
0005433868465	1F9062	5953 440581	YURIY ORLOV	{"email": "orlov-yuriy.1987@postgrespro.ru", "phone": "+70676550823"}
0005433868466	0794E7	8492 550929	VLADIMIR KUZNECOV	{"phone": "+70129395098"}
0005433868467	0794E7	0409 647739	ALEKSANDRA MELNIKOVA	{"phone": "+70550928998"}
0005433868468	5E0695	9447 092232	NINA NESTEROVA	{"phone": "+70799346261"}
0005433868469	A30BB7	0673 688568	ALEKSANDR ZHURAVLEV	{"phone": "+70831067535"}
0005433868470	48CBA6	5574 484171	DMITRIY MELNIKOV	{"phone": "+70441518001"}
0005433868471	48CBA6	5847 163963	ANNA MIKHAYLOVA	{"phone": "+70213368592"}
0005433868472	48CBA6	4900 950437	ANDREY TARASOV	{"phone": "+70884292553"}
0005433868473	ACC3B0	9594 840223	VLADIMIR CHERNOV	{"email": "v.chernov_1974@postgrespro.ru", "phone": "+70043430904"}
0005433868474	ACC3B0	6602 047362	TATYANA MALYSHEVA	{"email": "malysheva_tatyana031973@postgrespro.ru", "phone": "+70667331727"}
0005433868475	36681F	6572 152073	VLADIMIR KULIKOV	{"phone": "+70197862814"}
0005433868476	36681F	4562 877384	EVGENIY ALEKSANDROV	{"email": "evgeniy_aleksandrov-28091966@postgrespro.ru", "phone": "+70610897603"}
0005433868477	E6A78F	0122 528573	TATYANA DAVYDOVA	{"email": "tdavydova071977@postgrespro.ru", "phone": "+70818405306"}
0005433868478	330A25	9430 702959	EKATERINA PAVLOVA	{"email": "ekaterina.pavlova_071961@postgrespro.ru", "phone": "+70241196249"}
0005433868479	0277BB	5934 639312	KSENIYA ARKHIPOVA	{"phone": "+70051887065"}
0005433868480	2F71AF	5188 664371	EVGENIYA KOMAROVA	{"email": "e_komarova_1979@postgrespro.ru", "phone": "+70813528502"}
0005433868481	1DEAF4	5548 871474	TATYANA GERASIMOVA	{"email": "gerasimova_tatyana_1979@postgrespro.ru", "phone": "+70656411330"}
0005433868482	AA0F4C	0684 105211	EMIL VOLKOV	{"email": "volkov-e_1971@postgrespro.ru", "phone": "+70588310000"}
0005433868483	CCD029	0920 409413	PETR NAZAROV	{"phone": "+70858099277"}
0005433868484	CCD029	7700 745722	ALEKSANDR VOROBEV	{"phone": "+70174373712"}
0005433868485	749332	1809 886549	LYUDMILA MAKSIMOVA	{"email": "maksimovalyudmila.04111962@postgrespro.ru", "phone": "+70782220233"}
0005433868486	749332	4065 856169	ARTEM DAVYDOV	{"phone": "+70251476760"}
0005433868487	749332	1039 246720	IVAN SEMENOV	{"phone": "+70959045681"}
0005433868488	749332	5246 568194	ALEKSEY POPOV	{"email": "apopov_111966@postgrespro.ru", "phone": "+70872824389"}
0005433868489	104D6A	9846 664552	POLINA KUZNECOVA	{"email": "pkuznecova_1966@postgrespro.ru", "phone": "+70167967865"}
0005433868490	104D6A	4064 341714	DENIS ZHURAVLEV	{"email": "zhuravlev-denis-121975@postgrespro.ru", "phone": "+70811327032"}
0005433868491	77A46E	8522 522553	YURIY SCHERBAKOV	{"phone": "+70536305411"}
0005433868492	77A46E	5413 687770	ROMAN SHEVCHENKO	{"phone": "+70787671814"}
0005433868493	6D2258	0402 948972	SERGEY MAKAROV	{"email": "makarov.sergey_1972@postgrespro.ru", "phone": "+70472753783"}
0005433868494	E69915	1117 007683	BOGDAN KUZNECOV	{"email": "b.kuznecov021974@postgrespro.ru", "phone": "+70869532797"}
0005433868495	E69915	2008 200302	NATALYA POPOVA	{"phone": "+70162518100"}
0005433868496	411BB5	0068 384711	ALEKSANDR MEDVEDEV	{"phone": "+70796931761"}
0005433868497	27769F	8095 851406	DAMIR KONOVALOV	{"phone": "+70429210732"}
0005433868498	DEC475	6702 017685	SERGEY MELNIKOV	{"email": "melnikov_s_17091973@postgrespro.ru", "phone": "+70810181264"}
0005433868499	DEC475	9490 440671	ARTEM POPOV	{"phone": "+70189178574"}
0005433868500	0AED6C	5839 542002	SVETLANA ISAEVA	{"phone": "+70975887563"}
0005433868501	6D5C08	1235 100264	VALENTINA KONOVALOVA	{"email": "konovalovav-101972@postgrespro.ru", "phone": "+70285425677"}
0005433868502	6D5C08	4646 294460	OLEG KISELEV	{"phone": "+70102150278"}
0005433868503	067749	1722 330927	IGOR PAVLOV	{"email": "i_pavlov.081965@postgrespro.ru", "phone": "+70903765725"}
0005433868504	067749	7061 931033	GALINA POPOVA	{"phone": "+70160403181"}
0005433868505	75E5F0	5993 012830	ANATOLIY ILIN	{"email": "a-ilin13011963@postgrespro.ru", "phone": "+70511240726"}
0005433868506	15B0EB	1450 908949	ANDREY PAVLOV	{"phone": "+70587230322"}
0005433868507	15B0EB	0425 393287	NATALYA EFREMOVA	{"email": "nefremova_1966@postgrespro.ru", "phone": "+70797041566"}
0005433868508	15B0EB	1017 955479	YURIY IVANOV	{"phone": "+70084076848"}
0005433868509	700B29	9138 535487	EVDOKIYA KOVALEVA	{"email": "kovalevae_031962@postgrespro.ru", "phone": "+70524735068"}
0005433868510	700B29	0650 269200	YURIY ROMANOV	{"phone": "+70303214009"}
0005433868511	036A28	3320 353231	NADEZHDA MEDVEDEVA	{"email": "medvedeva-nadezhda21011962@postgrespro.ru", "phone": "+70901459731"}
0005433868512	087FB6	6230 860572	DMITRIY MOROZOV	{"phone": "+70941768368"}
0005433868513	CCB162	8020 756755	VASILIY YAKOVLEV	{"email": "vyakovlev1980@postgrespro.ru", "phone": "+70397423857"}
0005433868514	CCB162	7962 948181	LIDIYA NESTEROVA	{"email": "nesterova_lidiya.23111972@postgrespro.ru", "phone": "+70243028774"}
0005433868515	33C36F	5816 425050	NATALYA ANTONOVA	{"email": "natalya.antonova_071970@postgrespro.ru", "phone": "+70769780836"}
0005433868516	33C36F	0490 887785	TATYANA OVCHINNIKOVA	{"email": "tatyana_ovchinnikova-011964@postgrespro.ru", "phone": "+70311915220"}
0005433868517	D7D85C	4931 789307	VALENTINA MALYSHEVA	{"email": "malysheva_valentina-1970@postgrespro.ru", "phone": "+70473450445"}
0005433868518	D7D85C	0492 151359	SVETLANA PAVLOVA	{"email": "s.pavlova-071976@postgrespro.ru", "phone": "+70100169621"}
0005433868519	DA1751	2815 997388	NATALYA KUZNECOVA	{"email": "n.kuznecova-26121968@postgrespro.ru", "phone": "+70502494010"}
0005433868520	EBF899	8809 015431	NINA VASILEVA	{"phone": "+70965653098"}
0005433868521	2A23EE	4450 118316	MAKSIM ABRAMOV	{"email": "m_abramov_091962@postgrespro.ru", "phone": "+70686315058"}
0005433868522	83F4A8	2794 856195	VALERIY BONDARENKO	{"email": "bondarenkovaleriy_02111968@postgrespro.ru", "phone": "+70748208317"}
0005433868523	6D3A0D	7955 916417	VALERIYA KOLESNIKOVA	{"email": "kolesnikova_valeriya.17061959@postgrespro.ru", "phone": "+70477984988"}
0005433868524	807F3E	3135 039592	MAKSIM BELOV	{"email": "m-belov_01021974@postgrespro.ru", "phone": "+70756411175"}
0005433868525	807F3E	5608 286205	VLADIMIR STEPANOV	{"email": "vstepanov.041974@postgrespro.ru", "phone": "+70365786233"}
0005433868526	D94387	0686 465409	EGOR YAKOVLEV	{"email": "yakovlev-egor_071974@postgrespro.ru", "phone": "+70158783645"}
0005433868527	480980	4877 422764	YULIYA BARANOVA	{"phone": "+70649534830"}
0005433868528	0667FC	3699 125864	VYACHESLAV GAVRILOV	{"phone": "+70699927716"}
0005433868529	B56AFE	7097 786443	ANTON MOISEEV	{"phone": "+70219729524"}
0005433868530	B56AFE	1202 693099	VASILIY MOROZOV	{"phone": "+70887555668"}
0005433868531	D4D0E4	0454 344291	LYUBOV SEMENOVA	{"phone": "+70145045370"}
0005433868532	5D2054	0925 647036	EVGENIYA ANISIMOVA	{"email": "anisimova-e_15061971@postgrespro.ru", "phone": "+70114188546"}
0005433868533	2C4EAF	5720 497598	MARIYA NAUMOVA	{"email": "naumovamariya02031962@postgrespro.ru", "phone": "+70479445833"}
0005433868534	E0E173	2298 577914	DARYA NIKOLAEVA	{"email": "daryanikolaeva_061982@postgrespro.ru", "phone": "+70483619936"}
0005433868535	FD703F	1576 803166	NIKOLAY BORISOV	{"email": "n_borisov_1974@postgrespro.ru", "phone": "+70492518358"}
0005433868536	13CEB1	2437 156383	YURIY BORISOV	{"email": "yborisov10041971@postgrespro.ru", "phone": "+70147029212"}
0005433868537	13CEB1	0054 782182	IVAN NIKOLAEV	{"email": "i-nikolaev1981@postgrespro.ru", "phone": "+70629154763"}
0005433868538	10A6F9	5001 473888	NIKOLAY EGOROV	{"email": "nikolay_egorov.27031968@postgrespro.ru", "phone": "+70237993191"}
0005433868539	1C0E5C	8444 717773	NATALYA ARKHIPOVA	{"phone": "+70998147592"}
0005433868540	1C0E5C	5671 224956	NATALYA POPOVA	{"email": "natalya_popova_1980@postgrespro.ru", "phone": "+70423800982"}
0005433868541	111E3D	9287 198012	ANNA MIRONOVA	{"email": "mironova-a21041968@postgrespro.ru", "phone": "+70115643354"}
0005433868542	B02CC8	3857 073343	ELENA GRISHINA	{"phone": "+70464458775"}
0005433868543	B02CC8	1932 643102	VALENTINA NIKITINA	{"email": "valentina_nikitina_071966@postgrespro.ru", "phone": "+70152016916"}
0005433868544	BBB795	6822 748680	GALINA KUZNECOVA	{"phone": "+70665896320"}
0005433868545	F1638F	4425 861133	VITALIY GORBUNOV	{"email": "gorbunov.vitaliy.1963@postgrespro.ru", "phone": "+70723397489"}
0005433868546	B1B024	8553 052710	EVGENIY FOMIN	{"phone": "+70464777299"}
0005433868547	03BAE2	1618 571682	NATALYA KRASNOVA	{"email": "krasnovanatalya13011972@postgrespro.ru", "phone": "+70231008532"}
0005433868548	03BAE2	7120 535682	ARTUR KUZNECOV	{"email": "artur.kuznecov_041966@postgrespro.ru", "phone": "+70692778018"}
0005433868549	F6063A	4916 228914	DARYA NIKOLAEVA	{"email": "nikolaevad.101978@postgrespro.ru", "phone": "+70199164466"}
0005433868550	AF3570	9195 213052	ALEKSEY FROLOV	{"email": "frolov_aleksey1980@postgrespro.ru", "phone": "+70456838651"}
0005433868551	AF3570	8284 985624	OLEG POPOV	{"phone": "+70538235944"}
0005433868552	B28303	5040 758818	LARISA NIKOLAEVA	{"phone": "+70836813354"}
0005433868553	B28303	4231 247672	LYUDMILA POPOVA	{"phone": "+70218628806"}
0005433868554	252FB1	2618 761535	OLGA MAKSIMOVA	{"phone": "+70933560882"}
0005433868555	4A2B53	3389 800919	OLGA SERGEEVA	{"phone": "+70296798910"}
0005433868556	4A2B53	4503 917602	ALEKSEY MIKHAYLOV	{"phone": "+70499210510"}
0005433868557	503BC2	2588 966012	OLGA PETROVA	{"email": "olga-petrova_18121974@postgrespro.ru", "phone": "+70707578668"}
0005433868558	503BC2	2153 123050	TATYANA NESTEROVA	{"email": "tatyana_nesterova12051973@postgrespro.ru", "phone": "+70561817569"}
0005433868559	FC963F	6344 778140	ARTEM PETROV	{"phone": "+70519433694"}
0005433868560	C74F8D	6634 005221	TATYANA KUZMINA	{"phone": "+70830785914"}
0005433868561	0E2BF3	2766 916053	ALEKSEY FEDOTOV	{"email": "fedotov.aleksey_26041972@postgrespro.ru", "phone": "+70385333548"}
0005433868562	0E2BF3	0989 664738	DMITRIY IVANOV	{"email": "ivanov-d_091971@postgrespro.ru", "phone": "+70201107543"}
0005433868563	4CCDF9	8458 091371	VALENTINA POPOVA	{"email": "valentina_popova-091961@postgrespro.ru", "phone": "+70580208000"}
0005433868564	DC9B7B	1341 302118	YULIYA DMITRIEVA	{"phone": "+70234860467"}
0005433868565	DC9B7B	7808 151326	VADIM GRIGOREV	{"email": "grigorevv071976@postgrespro.ru", "phone": "+70098497933"}
0005433868566	03FFC2	6261 316423	VIKTOR MIRONOV	{"email": "mironovviktor.21111969@postgrespro.ru", "phone": "+70199121025"}
0005433868567	9AFA63	8377 314353	OLGA IVANOVA	{"phone": "+70539626911"}
0005433868568	9AFA63	5165 342066	TIMOFEY ROMANOV	{"email": "romanovt_041972@postgrespro.ru", "phone": "+70670103557"}
0005433868569	8835CA	6923 557968	ANNA EGOROVA	{"phone": "+70256105203"}
0005433868570	4A462F	4308 399949	ANNA TIKHONOVA	{"email": "tikhonovaa091977@postgrespro.ru", "phone": "+70549496313"}
0005433868571	7CA253	4610 851524	VIKTOR GERASIMOV	{"phone": "+70243562330"}
0005433868572	4F1A79	9471 710513	ARTEM SIDOROV	{"email": "sidorova.1975@postgrespro.ru", "phone": "+70311964320"}
0005433868573	94DC09	6663 697028	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a021987@postgrespro.ru", "phone": "+70341668964"}
0005433868574	928E89	6243 110061	VASILIY POPOV	{"phone": "+70912209476"}
0005433868575	E3FDC3	7522 385784	DMITRIY SOLOVEV	{"email": "d-solovev_30061975@postgrespro.ru", "phone": "+70567794840"}
0005433868576	9F382F	8075 364798	KSENIYA BARANOVA	{"phone": "+70649413741"}
0005433868577	9F382F	7013 285161	LYUBOV GUSEVA	{"email": "guseva.lyubov1967@postgrespro.ru", "phone": "+70617579129"}
0005433868578	AD484F	8793 558042	SERGEY SIDOROV	{"phone": "+70383443230"}
0005433868579	427653	8488 120906	ELENA MELNIKOVA	{"email": "elena_melnikova1978@postgrespro.ru", "phone": "+70686126895"}
0005433868580	44B0B5	9569 374159	OLESYA NAUMOVA	{"phone": "+70850793742"}
0005433868581	44B0B5	2284 794340	OLGA FOMINA	{"email": "fomina_o01091973@postgrespro.ru", "phone": "+70222989164"}
0005433868582	43E6DE	8542 009625	VIKTOR ANDREEV	{"email": "viktor-andreev.18051972@postgrespro.ru", "phone": "+70866967767"}
0005433868583	329F36	4503 379773	ANNA SERGEEVA	{"email": "sergeeva-a121972@postgrespro.ru", "phone": "+70397467024"}
0005433868584	C1A04C	0160 785267	ANNA GAVRILOVA	{"email": "gavrilova.anna_091958@postgrespro.ru", "phone": "+70933732902"}
0005433868585	B76344	9428 655095	ALEKSEY SAVELEV	{"email": "savelev_a-07031965@postgrespro.ru", "phone": "+70201105936"}
0005433868586	681D9B	7079 867558	YURIY FILIPPOV	{"phone": "+70854230367"}
0005433868587	681D9B	7720 807992	RAMIL SCHERBAKOV	{"email": "ramil-scherbakov.021973@postgrespro.ru", "phone": "+70615966398"}
0005433868588	681D9B	1407 356033	ELENA MIKHAYLOVA	{"phone": "+70024640241"}
0005433868589	4F7512	5951 553956	NATALYA TIMOFEEVA	{"phone": "+70626992915"}
0005433868590	4F7512	7246 601701	NADEZHDA IVANOVA	{"email": "ivanovanadezhda_1966@postgrespro.ru", "phone": "+70143075053"}
0005433868591	672B86	3213 853064	IRINA BORISOVA	{"email": "irinaborisova-1970@postgrespro.ru", "phone": "+70158021985"}
0005433868592	932E1B	7457 497755	NATALYA MOROZOVA	{"phone": "+70694629996"}
0005433868593	26D7D4	9574 367839	KSENIYA MAKSIMOVA	{"phone": "+70987624404"}
0005433868594	672D91	9748 659478	TATYANA KONOVALOVA	{"phone": "+70608553196"}
0005433868595	376DF7	0395 527248	RAISA VASILEVA	{"phone": "+70344332791"}
0005433868596	B2BC9B	2898 520863	YURIY POPOV	{"phone": "+70914687768"}
0005433868597	7855C9	2316 782556	KSENIYA GAVRILOVA	{"phone": "+70131917606"}
0005433868598	BB4490	0545 393390	EKATERINA NAZAROVA	{"phone": "+70525222312"}
0005433868599	8058AF	1808 146449	GLEB VOLKOV	{"phone": "+70859551988"}
0005433868600	5C10AE	7865 202839	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov-19021979@postgrespro.ru", "phone": "+70978572256"}
0005433868601	670471	9026 308736	ANATOLIY SMIRNOV	{"phone": "+70367448247"}
0005433868602	9F8FB2	7229 876188	VLADIMIR KULIKOV	{"email": "kulikov.v_081972@postgrespro.ru", "phone": "+70213005430"}
0005433868603	9F8FB2	4144 657042	LEONID SIDOROV	{"email": "l.sidorov_051972@postgrespro.ru", "phone": "+70348334151"}
0005433868604	65235A	0344 279335	MIKHAIL MEDVEDEV	{"phone": "+70173089980"}
0005433868883	ACF818	5023 824336	ELENA GUSEVA	{"phone": "+70191035690"}
0005433868605	65235A	4403 366539	ELENA ALEKSEEVA	{"email": "elena-alekseeva.081972@postgrespro.ru", "phone": "+70385872906"}
0005433868606	C47026	3455 185680	EKATERINA DANILOVA	{"email": "e_danilova.28061992@postgrespro.ru", "phone": "+70320823345"}
0005433868607	C47026	5752 749151	MIKHAIL IVANOV	{"email": "ivanov.m-01111966@postgrespro.ru", "phone": "+70308214691"}
0005433868608	2BB8B6	4709 029238	NINA GUSEVA	{"email": "gusevanina-021974@postgrespro.ru", "phone": "+70687975246"}
0005433868609	08E28D	7208 511940	EVGENIY IVANOV	{"email": "evgeniy_ivanov1981@postgrespro.ru", "phone": "+70444283293"}
0005433868610	E45A05	3548 271496	ALEKSANDR SOKOLOV	{"phone": "+70212966939"}
0005433868611	E2F7FA	2604 702100	ALEKSANDR NOVIKOV	{"phone": "+70952883243"}
0005433868612	E2F7FA	6335 117302	TATYANA SERGEEVA	{"phone": "+70945542124"}
0005433868613	E2F7FA	3364 869222	TATYANA NIKIFOROVA	{"phone": "+70511951717"}
0005433868614	C876EA	5432 695808	ANDREY KONOVALOV	{"email": "konovalova.041963@postgrespro.ru", "phone": "+70435416704"}
0005433868615	29B403	7486 995301	IRINA STEPANOVA	{"phone": "+70969743726"}
0005433868616	1B447D	3243 937939	GALINA MOROZOVA	{"phone": "+70685011539"}
0005433868617	1B447D	5480 981854	EVGENIY SOROKIN	{"email": "evgeniy-sorokin27011976@postgrespro.ru", "phone": "+70434072580"}
0005433868618	67D4DE	9269 047243	VERA MATVEEVA	{"phone": "+70306715755"}
0005433868619	2A999F	3472 611984	LYUBOV SOLOVEVA	{"phone": "+70779968939"}
0005433868620	2A999F	6748 560544	ANATOLIY TIMOFEEV	{"phone": "+70776248596"}
0005433868621	7169C8	6533 971780	VYACHESLAV AFANASEV	{"phone": "+70606623190"}
0005433868622	FCAAC3	5137 798717	OLEG SERGEEV	{"phone": "+70403899800"}
0005433868623	D1BFA5	2410 410740	OLGA SCHERBAKOVA	{"email": "o_scherbakova1980@postgrespro.ru", "phone": "+70161906983"}
0005433868624	6028B2	4506 301633	VLADIMIR DENISOV	{"email": "denisovv041976@postgrespro.ru", "phone": "+70744803132"}
0005433868625	6028B2	3021 676510	ROMAN PETROV	{"email": "petrov-roman-041977@postgrespro.ru", "phone": "+70844212114"}
0005433868626	F8DECD	0409 117508	OLGA ERMAKOVA	{"email": "olga_ermakova.091978@postgrespro.ru", "phone": "+70416609780"}
0005433868627	C7ED51	5628 111005	EGOR PETROV	{"email": "epetrov081981@postgrespro.ru", "phone": "+70154256770"}
0005433868628	4A51A5	8429 628490	ALEKSANDR FOMIN	{"phone": "+70584097273"}
0005433868629	380DA5	6090 427072	ANTONINA CHERNOVA	{"email": "antonina_chernova_1990@postgrespro.ru", "phone": "+70694508473"}
0005433868630	1EB9DE	7561 061829	GENNADIY ANTONOV	{"email": "gennadiy-antonov-1986@postgrespro.ru", "phone": "+70500998582"}
0005433868631	1EB9DE	3079 739858	GLEB PETROV	{"email": "g.petrov_031976@postgrespro.ru", "phone": "+70166537108"}
0005433868632	82D177	7482 313739	VLADIMIR PAVLOV	{"phone": "+70668417023"}
0005433868633	9E2A32	1087 447050	RUMIYA ARKHIPOVA	{"email": "r_arkhipova-111973@postgrespro.ru", "phone": "+70567398951"}
0005433868634	9E2A32	8123 915716	NATALYA ANDREEVA	{"email": "andreevanatalya-1963@postgrespro.ru", "phone": "+70314611676"}
0005433868635	9E2A32	6651 658241	NATALYA POPOVA	{"email": "popova-natalya.011981@postgrespro.ru", "phone": "+70543452750"}
0005433868636	6F7F01	6312 084215	ANASTASIYA KAZAKOVA	{"phone": "+70207155750"}
0005433868637	6F7F01	3065 840137	MARGARITA NAZAROVA	{"phone": "+70915905428"}
0005433868638	472F28	2914 551242	MIKHAIL ALEKSANDROV	{"phone": "+70219914720"}
0005433868639	C79963	1398 404185	LARISA POPOVA	{"email": "popova.l_16081974@postgrespro.ru", "phone": "+70278783419"}
0005433868640	C79963	9927 325589	PETR KOZLOV	{"email": "kozlov.p_061980@postgrespro.ru", "phone": "+70332293539"}
0005433868641	009A73	8707 452151	ELENA IVANOVA	{"email": "e_ivanova011975@postgrespro.ru", "phone": "+70311842400"}
0005433868642	009A73	6035 274778	NIKOLAY DAVYDOV	{"email": "n-davydov13041969@postgrespro.ru", "phone": "+70289822986"}
0005433868643	E9DD65	3561 986856	TAMARA BOGDANOVA	{"email": "bogdanova.tamara_1977@postgrespro.ru", "phone": "+70115953904"}
0005433868644	E9DD65	3422 161219	ALEKSANDR KARPOV	{"email": "karpova-1974@postgrespro.ru", "phone": "+70855216593"}
0005433868645	E9DD65	7529 799344	GALINA ANDREEVA	{"email": "gandreeva_061977@postgrespro.ru", "phone": "+70759721209"}
0005433868646	008BBC	8105 016568	YURIY GORBUNOV	{"phone": "+70673285852"}
0005433868647	008BBC	3539 493530	GALINA BORISOVA	{"phone": "+70330842235"}
0005433868648	C6FF69	5886 970381	SERGEY MOISEEV	{"email": "moiseev.sergey121962@postgrespro.ru", "phone": "+70583767360"}
0005433868649	E390C4	8853 332047	IRINA BORISOVA	{"email": "i.borisova_05041981@postgrespro.ru", "phone": "+70861308427"}
0005433868650	C92537	3128 041397	LARISA KUZNECOVA	{"email": "kuznecova-larisa-091981@postgrespro.ru", "phone": "+70458167512"}
0005433868651	C92537	7598 752420	NATALYA FEDOROVA	{"phone": "+70866582772"}
0005433868652	B893DA	3480 230214	ANATOLIY GORBUNOV	{"email": "a_gorbunov12051966@postgrespro.ru", "phone": "+70829416375"}
0005433868653	B893DA	1595 803348	ALINA MOISEEVA	{"email": "a-moiseeva30071967@postgrespro.ru", "phone": "+70645465853"}
0005433868654	1607A7	4071 397522	NIKOLAY MELNIKOV	{"email": "n-melnikov.041983@postgrespro.ru", "phone": "+70044668943"}
0005433868655	FF9069	0175 756420	TAMARA OSIPOVA	{"email": "tamara.osipova071980@postgrespro.ru", "phone": "+70599240535"}
0005433868656	B7C03A	4458 045445	MARIYA IVANOVA	{"email": "m_ivanova_1977@postgrespro.ru", "phone": "+70636346785"}
0005433868657	B7C03A	7378 558866	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.24121965@postgrespro.ru", "phone": "+70830090045"}
0005433868658	CFA36C	2327 029476	RUMIYA MARTYNOVA	{"email": "martynova_rumiya1973@postgrespro.ru", "phone": "+70994711633"}
0005433868659	CFA36C	5604 839595	IRINA SIDOROVA	{"email": "irina.sidorova_30121986@postgrespro.ru", "phone": "+70105032939"}
0005433868660	BD7604	3224 928908	KSENIYA DMITRIEVA	{"email": "kdmitrieva-02111975@postgrespro.ru", "phone": "+70187927118"}
0005433868661	BD7604	9573 848822	SERGEY TIMOFEEV	{"phone": "+70729315044"}
0005433868662	696934	6302 061502	VASILIY DMITRIEV	{"email": "dmitriev_v_05101969@postgrespro.ru", "phone": "+70909825882"}
0005433868663	2EB374	2389 744823	VLADISLAV SIDOROV	{"email": "vladislavsidorov-121976@postgrespro.ru", "phone": "+70812110683"}
0005433868664	2EB374	1342 979021	ANASTASIYA NESTEROVA	{"email": "nesterova_anastasiya_051979@postgrespro.ru", "phone": "+70556557484"}
0005433868665	DC74A7	1372 793166	OLGA YUDINA	{"phone": "+70090221738"}
0005433868666	1CF820	9907 019646	ANATOLIY ROMANOV	{"phone": "+70838636255"}
0005433868667	1CF820	7677 627927	EKATERINA BOGDANOVA	{"phone": "+70161506655"}
0005433868668	F6FE28	1466 446279	IRINA FILATOVA	{"phone": "+70307586925"}
0005433868669	F6FE28	2854 359666	VLADIMIR YAKOVLEV	{"phone": "+70365896744"}
0005433868670	32B705	6351 702749	VALENTIN CHERNOV	{"phone": "+70932714260"}
0005433868671	F5854B	3713 117419	IVAN DENISOV	{"email": "idenisov-1973@postgrespro.ru", "phone": "+70099815555"}
0005433868672	F5854B	0189 912553	VIKTOR BARANOV	{"email": "vbaranov.06021977@postgrespro.ru", "phone": "+70649875393"}
0005433868673	314373	8142 088794	SVETLANA EGOROVA	{"phone": "+70718008331"}
0005433868674	5EEF3B	2425 814314	SVETLANA POPOVA	{"email": "svetlana-popova-29091979@postgrespro.ru", "phone": "+70282167277"}
0005433868675	8DDD14	2019 438206	ALSU SEMENOVA	{"email": "semenova-a-1964@postgrespro.ru", "phone": "+70160864564"}
0005433868676	8DDD14	0616 087868	YULIYA RODIONOVA	{"email": "y.rodionova-1976@postgrespro.ru", "phone": "+70366193089"}
0005433868677	64F295	6649 036941	NATALIYA KARPOVA	{"email": "karpova.nataliya_1969@postgrespro.ru", "phone": "+70243590752"}
0005433868678	64F295	5162 408327	OLGA PETROVA	{"email": "opetrova.1959@postgrespro.ru", "phone": "+70341935194"}
0005433868679	64F295	6272 767092	MAKSIM ABRAMOV	{"phone": "+70106119270"}
0005433868680	196474	7632 069885	IVAN KUZNECOV	{"phone": "+70175089780"}
0005433868681	196474	5166 912021	EVGENIYA GAVRILOVA	{"email": "e-gavrilova-1971@postgrespro.ru", "phone": "+70809998132"}
0005433868682	18B1E1	7929 227900	SERGEY TIMOFEEV	{"email": "stimofeev_101966@postgrespro.ru", "phone": "+70153349293"}
0005433868683	7F98C4	6995 755142	NIKOLAY PAVLOV	{"email": "pavlov-nikolay_1971@postgrespro.ru", "phone": "+70575190468"}
0005433868684	7F98C4	9101 305379	LYUDMILA CHERNOVA	{"email": "lyudmila-chernova1972@postgrespro.ru", "phone": "+70517158875"}
0005433868685	2013F6	0561 175373	MAKSIM MAKAROV	{"email": "makarov.maksim.06041966@postgrespro.ru", "phone": "+70618587757"}
0005433868686	2013F6	7244 921826	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov_1977@postgrespro.ru", "phone": "+70868898905"}
0005433868687	D42222	5440 395719	ANASTASIYA ROMANOVA	{"email": "romanovaanastasiya09031964@postgrespro.ru", "phone": "+70330207852"}
0005433868688	ADCBAC	3820 984659	VALERIY SOKOLOV	{"phone": "+70262393691"}
0005433868689	ADCBAC	2552 752036	MIKHAIL VASILEV	{"phone": "+70069114972"}
0005433868690	E6D9FB	2554 354545	YURIY KUZNECOV	{"phone": "+70432345549"}
0005433868691	8BA652	7055 500514	IRINA NIKITINA	{"email": "nikitina.irina.1962@postgrespro.ru", "phone": "+70238190177"}
0005433868692	8BA652	6221 088116	LYUBOV MARTYNOVA	{"phone": "+70852989587"}
0005433868693	2D6E19	2102 325376	TATYANA SIDOROVA	{"phone": "+70642190863"}
0005433868694	584E1D	8835 511326	ALEKSANDR TIMOFEEV	{"phone": "+70203555219"}
0005433868695	9A8266	3119 787380	VALERIY AFANASEV	{"phone": "+70230049908"}
0005433868696	0875A6	1182 623617	ALEKSANDR EGOROV	{"email": "aleksandregorov_1968@postgrespro.ru", "phone": "+70162084618"}
0005433868697	EFD89E	4254 799210	ANTONINA RYABOVA	{"phone": "+70864079415"}
0005433868698	F0084C	9628 726950	ALEKSANDR PAVLOV	{"email": "a_pavlov031968@postgrespro.ru", "phone": "+70774070132"}
0005433868699	FEC19E	2722 168078	RIMMA MOISEEVA	{"phone": "+70876307612"}
0005433868700	E6AF73	8646 840990	VALENTINA EGOROVA	{"email": "v-egorova.10101964@postgrespro.ru", "phone": "+70044021332"}
0005433868701	17FBD6	3001 858392	NATALYA ISAEVA	{"email": "nisaeva.051984@postgrespro.ru", "phone": "+70766407049"}
0005433868702	1BE4EE	2608 634413	MIKHAIL MAKAROV	{"phone": "+70764810002"}
0005433868703	CEE78E	3686 526771	ANATOLIY IVANOV	{"phone": "+70285700069"}
0005433868704	94DF2A	8811 038827	TATYANA NAUMOVA	{"phone": "+70704518730"}
0005433868705	94DF2A	1369 455626	VALENTINA SERGEEVA	{"phone": "+70194921878"}
0005433868706	9D819F	0442 779663	ANASTASIYA OSIPOVA	{"phone": "+70416851833"}
0005433868707	40820A	8228 525206	ANASTASIYA KISELEVA	{"phone": "+70641075432"}
0005433868708	CD2223	0395 651608	MILENA ZAYCEVA	{"phone": "+70521593305"}
0005433868709	995C6B	2875 914711	MARIYA TARASOVA	{"phone": "+70706377822"}
0005433868710	995C6B	9598 893138	LYUDMILA PETROVA	{"email": "petrova-l.1968@postgrespro.ru", "phone": "+70586987158"}
0005433868711	FE4688	6855 707318	OLGA BELYAEVA	{"email": "belyaeva_olga051977@postgrespro.ru", "phone": "+70198827820"}
0005433868712	B86831	0604 657999	ALEKSANDR MIRONOV	{"phone": "+70695540777"}
0005433868713	B86831	9125 926710	VIKTORIYA KUZNECOVA	{"email": "v.kuznecova13051969@postgrespro.ru", "phone": "+70824602963"}
0005433868714	931B92	1791 549035	ANNA MOISEEVA	{"phone": "+70183274633"}
0005433868715	931B92	3777 408772	ALEKSEY NOVIKOV	{"email": "alekseynovikov.071974@postgrespro.ru", "phone": "+70946306572"}
0005433868716	5B9A52	6284 238306	DENIS ORLOV	{"email": "orlov_d-1964@postgrespro.ru", "phone": "+70036290602"}
0005433868717	652FF0	0672 529691	ELENA SERGEEVA	{"phone": "+70982625338"}
0005433868718	352673	5664 354121	VLADIMIR KULIKOV	{"email": "vladimirkulikov.14021972@postgrespro.ru", "phone": "+70264805198"}
0005433868719	598ACC	0621 940821	IGOR KAZAKOV	{"email": "kazakov-i-28071973@postgrespro.ru", "phone": "+70586486020"}
0005433868720	8F4DC9	8141 416119	MAKSIM FILIPPOV	{"phone": "+70846222457"}
0005433868721	468038	5586 352807	ALEKSANDR VOROBEV	{"phone": "+70008171732"}
0005433868722	468038	9236 727257	VALENTINA KUDRYASHOVA	{"phone": "+70275365557"}
0005433868723	95E914	5275 858619	OLGA POTAPOVA	{"phone": "+70886610011"}
0005433868724	C38F3D	0677 531002	EVGENIY MAKAROV	{"email": "evgeniy_makarov-091967@postgrespro.ru", "phone": "+70119341684"}
0005433868725	11BC51	3867 611244	ANNA TARASOVA	{"email": "tarasova_anna.1967@postgrespro.ru", "phone": "+70956478132"}
0005433868726	11BC51	2437 888211	SERGEY KRASNOV	{"email": "sergey.krasnov_1959@postgrespro.ru", "phone": "+70829562158"}
0005433868727	9AC83B	5274 177309	OLGA MAKAROVA	{"phone": "+70797978163"}
0005433868728	025F01	2631 624425	ANTONIDA DAVYDOVA	{"email": "a-davydova-18061976@postgrespro.ru", "phone": "+70660941454"}
0005433868729	096880	7491 357467	ANNA TIKHONOVA	{"phone": "+70072757830"}
0005433868730	8D03E7	7480 336710	PETR ILIN	{"phone": "+70338590535"}
0005433868731	8D03E7	0705 795259	VIKTOR FROLOV	{"phone": "+70900694526"}
0005433868732	987B6B	9804 378709	NADEZHDA BORISOVA	{"phone": "+70625046254"}
0005433868733	62A5AA	8695 813730	SVETLANA PETROVA	{"email": "petrovas011967@postgrespro.ru", "phone": "+70316931519"}
0005433868734	D8B38A	4276 000935	VITALIY NAZAROV	{"phone": "+70627307783"}
0005433868735	C6B3C3	1951 022043	ANDREY ISAEV	{"phone": "+70939115839"}
0005433868736	80CB65	0360 004785	TATYANA TIMOFEEVA	{"email": "t-timofeeva-21091967@postgrespro.ru", "phone": "+70617380398"}
0005433868737	5FCE8A	9241 797043	TATYANA KOMAROVA	{"email": "tatyana-komarova081977@postgrespro.ru", "phone": "+70608890069"}
0005433868738	647E8C	4621 020656	TATYANA LOGINOVA	{"phone": "+70264479489"}
0005433868739	1AC087	2076 765706	IGOR KULIKOV	{"phone": "+70849146561"}
0005433868740	D29940	5574 051446	VALERIY BONDARENKO	{"phone": "+70457717720"}
0005433868741	D29940	5309 723637	VIKTOR SIDOROV	{"phone": "+70359591526"}
0005433868742	5ADEB7	5440 453210	ALBINA GORBUNOVA	{"email": "gorbunova.a17051970@postgrespro.ru", "phone": "+70157815699"}
0005433868743	01846A	8472 885061	OLGA SAVELEVA	{"email": "savelevaolga_1969@postgrespro.ru", "phone": "+70377494293"}
0005433868744	34109D	3837 040047	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov-021971@postgrespro.ru", "phone": "+70655023026"}
0005433868745	3D7A2A	6476 204470	NINA IVANOVA	{"email": "ivanova_nina-091984@postgrespro.ru", "phone": "+70882974048"}
0005433868746	3D7A2A	9038 712853	VALENTINA KONDRATEVA	{"email": "kondrateva.valentina_1978@postgrespro.ru", "phone": "+70617134951"}
0005433868747	0D345A	4487 892360	ALBINA TIMOFEEVA	{"email": "timofeevaa_08121969@postgrespro.ru", "phone": "+70249606247"}
0005433868748	33CFC9	1221 211345	NIKOLAY OSIPOV	{"phone": "+70415752259"}
0005433868749	693BA5	8907 390306	SERGEY PAVLOV	{"email": "pavlovsergey_1969@postgrespro.ru", "phone": "+70231291252"}
0005433868750	0A6A88	3132 172905	PAVEL SIDOROV	{"email": "sidorovp-1976@postgrespro.ru", "phone": "+70479300812"}
0005433868751	699CC4	6870 730554	TATYANA SIDOROVA	{"email": "sidorova_tatyana-111972@postgrespro.ru", "phone": "+70832330017"}
0005433868752	ED3100	1470 347751	ALEKSANDR KISELEV	{"phone": "+70034247630"}
0005433868753	DFEE63	5895 004888	ELENA POPOVA	{"email": "popova_e.021969@postgrespro.ru", "phone": "+70983581286"}
0005433868754	25ADAC	1598 272952	IRINA DANILOVA	{"phone": "+70750949517"}
0005433868755	25ADAC	7254 255995	ANNA SERGEEVA	{"phone": "+70072723682"}
0005433868756	AA15F2	0900 492990	VITALIY GAVRILOV	{"email": "gavrilov-v-1964@postgrespro.ru", "phone": "+70903772954"}
0005433868757	AA15F2	1584 988323	EKATERINA PAVLOVA	{"phone": "+70518665994"}
0005433868758	4DC867	5553 416030	EVGENIY KULIKOV	{"phone": "+70861794421"}
0005433868759	69635D	5183 105746	ALEKSANDR PAVLOV	{"phone": "+70995561745"}
0005433868760	CF05B9	7920 966250	MAKSIM KUZNECOV	{"email": "kuznecov-m.28091973@postgrespro.ru", "phone": "+70808732763"}
0005433868761	155CFD	4456 694319	NATALYA FILATOVA	{"email": "filatovan-1970@postgrespro.ru", "phone": "+70905915937"}
0005433868762	BB7298	9025 951579	YULIYA ERMAKOVA	{"phone": "+70151818138"}
0005433868763	2DA046	6851 745529	ALEKSEY IVANOV	{"email": "ivanov-aleksey1975@postgrespro.ru", "phone": "+70249200313"}
0005433868764	B0937E	9670 072963	OLGA ORLOVA	{"email": "orlova_o-1967@postgrespro.ru", "phone": "+70832408058"}
0005433868765	23D461	8652 978413	VERA POLYAKOVA	{"phone": "+70269827354"}
0005433868766	23D461	8892 852719	OLGA ARKHIPOVA	{"email": "arkhipovao.28041974@postgrespro.ru", "phone": "+70559065157"}
0005433868767	99DA24	3589 725331	VITALIY CHERNOV	{"email": "chernovvitaliy_07091979@postgrespro.ru", "phone": "+70375531048"}
0005433868768	99DA24	6352 207145	IRINA FROLOVA	{"phone": "+70312221977"}
0005433868769	F81E43	6236 425626	ILYA ALEKSANDROV	{"email": "aleksandrov_ilya1971@postgrespro.ru", "phone": "+70712497412"}
0005433868770	52D763	1542 745136	ALEKSEY GORBUNOV	{"phone": "+70493449734"}
0005433868771	6F5C07	9126 347522	DMITRIY GERASIMOV	{"email": "gerasimovdmitriy041963@postgrespro.ru", "phone": "+70096894746"}
0005433868772	833A1A	6851 825329	SERGEY SAVELEV	{"email": "savelev.sergey_1960@postgrespro.ru", "phone": "+70481312922"}
0005433868773	64FC26	0603 489692	MARIYA KISELEVA	{"email": "kiselevam_07081969@postgrespro.ru", "phone": "+70576834386"}
0005433868774	F77714	6593 517514	YURIY ZAYCEV	{"phone": "+70839719147"}
0005433868775	38F885	3859 575377	SVETLANA SEMENOVA	{"email": "semenova.svetlana1973@postgrespro.ru", "phone": "+70200755634"}
0005433868776	38F885	1881 022234	ALEKSANDR KUZMIN	{"email": "kuzmin_a23101969@postgrespro.ru", "phone": "+70495802811"}
0005433868777	F4792F	3660 926177	IGOR GORBUNOV	{"phone": "+70545235434"}
0005433868778	A8A4E1	9440 065801	EDUARD NIKOLAEV	{"email": "nikolaev.eduard111967@postgrespro.ru", "phone": "+70046514679"}
0005433868779	A8A4E1	5759 548406	VYACHESLAV ROMANOV	{"phone": "+70813266000"}
0005433868780	2E70D2	8851 341302	ALEKSEY VASILEV	{"phone": "+70684869752"}
0005433868781	656998	2720 247760	ALEKSEY DMITRIEV	{"phone": "+70590724048"}
0005433868782	22CEE3	8242 997122	VLADISLAV SOKOLOV	{"email": "sokolov-v_08071974@postgrespro.ru", "phone": "+70429920550"}
0005433868783	FA1C81	3669 853039	ANDREY IVANOV	{"phone": "+70315104341"}
0005433868784	FA1C81	8868 308356	IRAIDA BORISOVA	{"email": "borisova_iraida.10021982@postgrespro.ru", "phone": "+70465022202"}
0005433868785	94E088	0708 682605	PELAGEYA ILINA	{"email": "pelageya-ilina.1969@postgrespro.ru", "phone": "+70797199159"}
0005433868786	94E088	2715 785428	ALEKSEY PETROV	{"email": "alekseypetrov-1967@postgrespro.ru", "phone": "+70053874883"}
0005433868787	A4DAAE	5543 386408	RAVIL ZAYCEV	{"phone": "+70383179781"}
0005433868788	9C476A	0313 430520	ANATOLIY ILIN	{"email": "ilin.anatoliy-11031963@postgrespro.ru", "phone": "+70541339003"}
0005433868789	16658E	1092 156052	YULIYA MALYSHEVA	{"email": "malysheva_y.26101967@postgrespro.ru", "phone": "+70630981155"}
0005433868790	249404	1616 139338	NIKOLAY FEDOTOV	{"email": "fedotov.nikolay_1980@postgrespro.ru", "phone": "+70101969112"}
0005433868791	249404	3070 968849	ALEKSEY KISELEV	{"phone": "+70853285908"}
0005433868792	32104B	5724 642730	IRINA POPOVA	{"email": "ipopova.051962@postgrespro.ru", "phone": "+70857717015"}
0005433868793	DAB702	2541 274284	MARIYA MAKSIMOVA	{"phone": "+70480908409"}
0005433868794	0D77F9	4988 793727	NATALYA ANISIMOVA	{"email": "anisimova-natalya-19021962@postgrespro.ru", "phone": "+70595611332"}
0005433868795	0D77F9	4777 384567	GULNARA KOROLEVA	{"email": "gulnarakoroleva-021970@postgrespro.ru", "phone": "+70932910359"}
0005433868796	0D77F9	3094 905601	TATYANA MAKAROVA	{"phone": "+70251887481"}
0005433868797	FA75E6	1837 934792	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr10011982@postgrespro.ru", "phone": "+70642787997"}
0005433868798	98025D	2411 831607	YURIY MAKAROV	{"phone": "+70378865344"}
0005433868799	BF91B1	4705 935229	ILYA ZAKHAROV	{"email": "zakharov-ilya_1983@postgrespro.ru", "phone": "+70654385864"}
0005433868800	0522A0	8607 580469	VIKTORIYA MIRONOVA	{"phone": "+70690716739"}
0005433868801	C833CF	6993 605954	NATALYA OSIPOVA	{"phone": "+70867667247"}
0005433868802	EA1F20	8894 209522	TATYANA LAZAREVA	{"email": "tatyana.lazareva.021976@postgrespro.ru", "phone": "+70014019136"}
0005433868803	EA1F20	1758 867893	TATYANA MOROZOVA	{"email": "morozova-tatyana.1964@postgrespro.ru", "phone": "+70436294542"}
0005433868804	BED6D1	2747 687148	EVGENIY MAKAROV	{"email": "makarov-evgeniy_101973@postgrespro.ru", "phone": "+70795460633"}
0005433868805	24ED2D	1177 491487	VLADIMIR SOKOLOV	{"phone": "+70311993647"}
0005433868806	B7A67D	3685 736919	ALEKSEY SOKOLOV	{"email": "a.sokolov_27011967@postgrespro.ru", "phone": "+70138277171"}
0005433868807	B7A67D	4290 148539	DARYA VASILEVA	{"email": "vasilevadarya17051973@postgrespro.ru", "phone": "+70578943708"}
0005433868808	B2D613	0838 958720	VALENTINA SCHERBAKOVA	{"phone": "+70598619517"}
0005433868809	B3B3D5	1189 519907	MARINA KUZMINA	{"email": "kuzmina_m-111968@postgrespro.ru", "phone": "+70359964591"}
0005433868810	8C3A25	3518 173033	ALEKSANDR SEMENOV	{"email": "asemenov.07051964@postgrespro.ru", "phone": "+70311938938"}
0005433868811	4F2FD4	3425 876089	ULYANA SAVELEVA	{"phone": "+70782999659"}
0005433868812	BF096B	4918 488120	OLESYA EGOROVA	{"email": "egorovao091968@postgrespro.ru", "phone": "+70904902849"}
0005433868813	BF096B	6531 910349	DMITRIY YAKOVLEV	{"phone": "+70646726593"}
0005433868814	E95171	6115 711752	SVETLANA KUZMINA	{"email": "kuzminas_22071967@postgrespro.ru", "phone": "+70225152951"}
0005433868815	E95171	8613 175139	PAVEL KISELEV	{"email": "pavel-kiselev.13071974@postgrespro.ru", "phone": "+70269503229"}
0005433868816	335A62	2444 642918	ELENA BELOVA	{"email": "belovaelena-101980@postgrespro.ru", "phone": "+70634891079"}
0005433868817	6BDC5F	0353 620965	ALEKSANDR BARANOV	{"phone": "+70752386643"}
0005433868818	4C9A1B	9937 833713	ANASTASIYA NIKITINA	{"phone": "+70715808192"}
0005433868819	00613D	0159 023847	VLADIMIR ZHUKOV	{"phone": "+70531550872"}
0005433868820	6B6529	5950 228755	MARINA KOROLEVA	{"email": "mkoroleva1962@postgrespro.ru", "phone": "+70190965208"}
0005433868821	6B6529	8755 327413	VERA FOMINA	{"email": "fomina_vera_1970@postgrespro.ru", "phone": "+70174176351"}
0005433868822	714BCD	2421 098953	NIKOLAY GRIGOREV	{"email": "n-grigorev-061988@postgrespro.ru", "phone": "+70153700435"}
0005433868823	714BCD	0917 991252	ALEKSEY SMIRNOV	{"email": "a.smirnov_12071961@postgrespro.ru", "phone": "+70118986259"}
0005433868824	C928AD	3231 286137	VIKTOR KUZNECOV	{"email": "kuznecov-viktor_1973@postgrespro.ru", "phone": "+70046805624"}
0005433868825	C928AD	2913 484842	ANATOLIY DMITRIEV	{"phone": "+70395079694"}
0005433868826	AD468E	0551 373023	YULIYA SMIRNOVA	{"phone": "+70569632300"}
0005433868827	DDC167	5202 175836	MARINA BORISOVA	{"email": "borisova.m_1973@postgrespro.ru", "phone": "+70942231050"}
0005433868828	DDC167	4775 580821	ALEKSANDR MELNIKOV	{"phone": "+70194327665"}
0005433868829	FB1A00	9331 418055	PAVEL SIDOROV	{"phone": "+70252955740"}
0005433868830	AFB328	3303 645928	PETR ALEKSEEV	{"phone": "+70410270021"}
0005433868831	EEB6FB	6179 543732	NIKITA FOMIN	{"email": "nikita.fomin_1974@postgrespro.ru", "phone": "+70063968885"}
0005433868832	EEB6FB	2242 835761	LYUDMILA PAVLOVA	{"phone": "+70982065084"}
0005433868833	EEB6FB	1663 605388	ALLA PETROVA	{"email": "a.petrova.1979@postgrespro.ru", "phone": "+70006074809"}
0005433868834	B14FA3	0260 413314	VYACHESLAV ROMANOV	{"phone": "+70059458062"}
0005433868835	74B61D	4853 475703	VALENTIN GRIGOREV	{"email": "grigorev.v-031974@postgrespro.ru", "phone": "+70088746001"}
0005433868836	1BE651	2612 965782	DMITRIY MAKAROV	{"email": "d-makarov15101978@postgrespro.ru", "phone": "+70977870577"}
0005433868837	E67710	9345 323638	VALENTINA SIDOROVA	{"phone": "+70847114555"}
0005433868838	C10B5F	1449 061833	VALERIY ISAEV	{"phone": "+70272512685"}
0005433868839	9BDAF4	7570 983820	ALINA BARANOVA	{"email": "alina_baranova.021971@postgrespro.ru", "phone": "+70225646228"}
0005433868840	9BDAF4	9792 270270	TATYANA CHERNOVA	{"email": "tatyana_chernova_1973@postgrespro.ru", "phone": "+70594346299"}
0005433868841	E0955C	1010 721020	ALEKSANDR ALEKSEEV	{"email": "aalekseev111963@postgrespro.ru", "phone": "+70961636066"}
0005433868842	E0955C	3139 252084	TATYANA ANDREEVA	{"email": "andreevat-01081970@postgrespro.ru", "phone": "+70181022702"}
0005433868843	3CDF9F	1286 080979	MIKHAIL DAVYDOV	{"email": "davydov_m01071975@postgrespro.ru", "phone": "+70089380254"}
0005433868844	A52C4F	7234 162972	KSENIYA NOVIKOVA	{"phone": "+70843653577"}
0005433868845	A52C4F	4186 153317	ELENA ANDREEVA	{"phone": "+70212613357"}
0005433868846	55D7FC	9924 421722	ALEKSANDR KULIKOV	{"phone": "+70542074585"}
0005433868847	FFC96E	7825 915924	NIKOLAY ANTONOV	{"phone": "+70195030237"}
0005433868848	293463	2202 937727	SERGEY IVANOV	{"email": "ivanov.s041983@postgrespro.ru", "phone": "+70510700720"}
0005433868849	293463	9930 175390	VLADIMIR FILIPPOV	{"email": "filippov-vladimir-051995@postgrespro.ru", "phone": "+70753258617"}
0005433868850	293463	3687 501616	NADEZHDA KRASNOVA	{"email": "krasnova_n.1972@postgrespro.ru", "phone": "+70276497659"}
0005433868851	EE3702	6879 190880	VALENTINA SAVELEVA	{"email": "valentina.saveleva-091962@postgrespro.ru", "phone": "+70678291093"}
0005433868852	EE3702	9919 745991	SERGEY SOKOLOV	{"email": "s.sokolov_1971@postgrespro.ru", "phone": "+70171989593"}
0005433868853	43F46E	8449 064546	ALEKSANDR MARTYNOV	{"email": "a_martynov_021974@postgrespro.ru", "phone": "+70376459519"}
0005433868854	99B0CD	0859 408716	GRIGORIY PETROV	{"phone": "+70412575690"}
0005433868855	581B7E	0150 238339	TATYANA LOGINOVA	{"phone": "+70228547650"}
0005433868856	B3AF00	9109 720779	EKATERINA SCHERBAKOVA	{"email": "scherbakova.e111971@postgrespro.ru", "phone": "+70009597889"}
0005433868857	B3AF00	7362 875226	OLGA AFANASEVA	{"phone": "+70837422741"}
0005433868858	D348F0	4193 115036	VLADIMIR FILIPPOV	{"phone": "+70814539867"}
0005433868859	D348F0	4894 029041	ANDREY VASILEV	{"email": "vasilev_andrey_061957@postgrespro.ru", "phone": "+70425515544"}
0005433868860	19DFF6	8317 810894	ANASTASIYA MOROZOVA	{"email": "anastasiya-morozova11091984@postgrespro.ru", "phone": "+70221823199"}
0005433868861	0E6580	7507 801695	ALEKSEY VOLKOV	{"phone": "+70391981240"}
0005433868862	005F35	2213 370809	ANATOLIY PAVLOV	{"phone": "+70638753967"}
0005433868863	F14377	9576 284498	VALERIY DAVYDOV	{"phone": "+70538082195"}
0005433868864	E718D2	0577 954564	SOFIYA PAVLOVA	{"email": "spavlova.101967@postgrespro.ru", "phone": "+70204568857"}
0005433868865	E718D2	7974 860606	MIKHAIL MIKHAYLOV	{"phone": "+70958492030"}
0005433868866	445667	8355 707768	KLAVDIYA NIKITINA	{"email": "nikitinak.11061966@postgrespro.ru", "phone": "+70223431855"}
0005433868867	3FEA27	3736 288069	ANNA NAUMOVA	{"phone": "+70437516658"}
0005433868868	1921A7	5366 402610	VIKTOR KRASNOV	{"phone": "+70051844577"}
0005433868869	0B1645	4802 316454	YURIY FEDOTOV	{"phone": "+70780303847"}
0005433868870	219479	5428 586321	ANNA MAKSIMOVA	{"phone": "+70312882618"}
0005433868871	C0960E	9622 834237	SVETLANA RODIONOVA	{"email": "rodionova-svetlana-20111963@postgrespro.ru", "phone": "+70674914894"}
0005433868872	263AFB	7167 898793	MARINA LAZAREVA	{"phone": "+70455992671"}
0005433868873	263AFB	1929 958683	YULIYA TARASOVA	{"email": "tarasova-y.041972@postgrespro.ru", "phone": "+70718284766"}
0005433868874	193D07	3938 647301	EVGENIY SCHERBAKOV	{"email": "e-scherbakov_051969@postgrespro.ru", "phone": "+70457860219"}
0005433868875	923A77	7368 131318	DANIIL KOZLOV	{"phone": "+70622977900"}
0005433868876	921DE9	2740 989509	DMITRIY ZAKHAROV	{"email": "d-zakharov-041962@postgrespro.ru", "phone": "+70206810103"}
0005433868877	7EFD26	5358 925605	LYUBOV SEMENOVA	{"phone": "+70796531573"}
0005433868939	5270A0	8752 966837	EKATERINA KALININA	{"phone": "+70356996007"}
0005433868878	0ADF8B	2710 764421	RAISA MALYSHEVA	{"email": "malyshevaraisa_1965@postgrespro.ru", "phone": "+70080239812"}
0005433868879	0ADF8B	8391 422773	ANTON PAVLOV	{"phone": "+70254096062"}
0005433868880	CB304D	5405 515820	ELIZAVETA LUKYANOVA	{"email": "e-lukyanova041980@postgrespro.ru", "phone": "+70053677140"}
0005433868881	1FE5F6	4955 989644	OLESYA FEDOROVA	{"phone": "+70116166114"}
0005433868882	BC6A0A	8825 368426	ALENA STEPANOVA	{"email": "a.stepanova_22021966@postgrespro.ru", "phone": "+70957912085"}
0005433868884	48DB1B	7866 111606	ELENA FEDOROVA	{"email": "fedorova.e111968@postgrespro.ru", "phone": "+70440799638"}
0005433868885	48DB1B	2776 812064	VLADIMIR KOZLOV	{"phone": "+70752953153"}
0005433868886	48DB1B	1490 716741	ELIZAVETA EGOROVA	{"phone": "+70512892904"}
0005433868887	01EC07	2686 692841	LYUDMILA ISAEVA	{"email": "isaeva-l-061978@postgrespro.ru", "phone": "+70291473418"}
0005433868888	01EC07	4489 062555	DMITRIY NAZAROV	{"email": "dmitriy-nazarov17101969@postgrespro.ru", "phone": "+70762920188"}
0005433868889	B71E6E	9266 998583	RAISA VOLKOVA	{"phone": "+70724936575"}
0005433868890	B71E6E	7916 538838	ROMAN KOROLEV	{"phone": "+70975302224"}
0005433868891	314BAA	9402 660267	SVETLANA KOROLEVA	{"email": "skoroleva-011968@postgrespro.ru", "phone": "+70909628877"}
0005433868892	0057D4	7034 175475	LIDIYA KAZAKOVA	{"email": "lkazakova24031965@postgrespro.ru", "phone": "+70479229140"}
0005433868893	0057D4	8062 928317	MAKSIM SHEVCHENKO	{"email": "maksimshevchenko_1976@postgrespro.ru", "phone": "+70532926724"}
0005433868894	0057D4	1375 242752	ALISA KUZNECOVA	{"email": "a-kuznecova.13021977@postgrespro.ru", "phone": "+70137526826"}
0005433868895	275F26	7313 343307	SERGEY GERASIMOV	{"email": "gerasimov.s08091967@postgrespro.ru", "phone": "+70122627134"}
0005433868896	988545	1102 663796	TIMOFEY GRIGOREV	{"email": "grigorev_t_1967@postgrespro.ru", "phone": "+70393311320"}
0005433868897	4EDE5E	8671 771067	VLADISLAV NIKITIN	{"email": "vladislav-nikitin_061979@postgrespro.ru", "phone": "+70033049224"}
0005433868898	049235	5604 589994	NADEZHDA KARPOVA	{"phone": "+70478194078"}
0005433868899	4CBF16	8045 706169	LILIYA MASLOVA	{"email": "maslova_liliya1978@postgrespro.ru", "phone": "+70866948367"}
0005433868900	5958FC	0604 437464	MIKHAIL PETROV	{"email": "petrov_m011973@postgrespro.ru", "phone": "+70180960334"}
0005433868901	3ABC75	5304 743561	KIRILL ZAKHAROV	{"phone": "+70930026730"}
0005433868902	B45A75	0319 898282	MARIYA GORBUNOVA	{"email": "gorbunovamariya.1975@postgrespro.ru", "phone": "+70973997347"}
0005433868903	985BAE	7658 767348	SERGEY ZAKHAROV	{"phone": "+70766579122"}
0005433868904	F0CB69	9024 565127	NIKOLAY KUZNECOV	{"phone": "+70160903780"}
0005433868905	F0CB69	8207 261063	ELENA KOROLEVA	{"phone": "+70004112018"}
0005433868906	90A8BD	8510 393338	DENIS SAVELEV	{"email": "denissavelev_111974@postgrespro.ru", "phone": "+70620240540"}
0005433868907	2AE01E	7889 126762	NATALYA PETROVA	{"email": "petrova_natalya-1975@postgrespro.ru", "phone": "+70778089224"}
0005433868908	6D9713	8741 649996	DMITRIY CHERNOV	{"email": "chernov.dmitriy1972@postgrespro.ru", "phone": "+70854864157"}
0005433868909	D69003	5825 907739	LIDIYA VOLKOVA	{"phone": "+70110788435"}
0005433868910	D69003	0137 562806	NINA GRISHINA	{"email": "nina.grishina_1992@postgrespro.ru", "phone": "+70729068000"}
0005433868911	D69003	4835 322078	ALEKSEY SOKOLOV	{"email": "aleksey.sokolov-041971@postgrespro.ru", "phone": "+70106571650"}
0005433868912	FD41B3	6932 146329	DMITRIY VLASOV	{"phone": "+70606307623"}
0005433868913	FD41B3	2801 095312	NIKOLAY MATVEEV	{"phone": "+70431269420"}
0005433868914	6F9720	3525 940350	DAMIR RODIONOV	{"email": "rodionov.d.111975@postgrespro.ru", "phone": "+70703915979"}
0005433868915	6F9720	8792 292439	ANTONINA ROMANOVA	{"email": "romanovaantonina.091970@postgrespro.ru", "phone": "+70567153588"}
0005433868916	C10D98	3712 341861	ALEKSANDR IVANOV	{"phone": "+70986678512"}
0005433868917	FA4B33	5603 875836	SVETLANA IVANOVA	{"phone": "+70487802367"}
0005433868918	FA4B33	5215 287847	EDUARD FOMIN	{"phone": "+70465540902"}
0005433868919	C27844	5048 883079	MIKHAIL KOROLEV	{"phone": "+70278090110"}
0005433868920	78CF27	4924 494428	ANDREY FEDOROV	{"phone": "+70491436783"}
0005433868921	F4ACD3	8372 238590	NIKOLAY GORBUNOV	{"email": "nikolay.gorbunov_071954@postgrespro.ru", "phone": "+70711247281"}
0005433868922	F4ACD3	3779 684600	DENIS GAVRILOV	{"phone": "+70978556761"}
0005433868923	D4731F	8832 509871	YURIY SMIRNOV	{"phone": "+70974185119"}
0005433868924	53B2B9	5787 296757	GALINA MIRONOVA	{"phone": "+70162048781"}
0005433868925	6F2EFF	5661 074303	RIMMA CHERNOVA	{"email": "chernova_r011972@postgrespro.ru", "phone": "+70895030481"}
0005433868926	CE556C	4302 582586	VLADIMIR ABRAMOV	{"email": "v_abramov.24021976@postgrespro.ru", "phone": "+70372875104"}
0005433868927	CE556C	1504 397949	ANDREY ALEKSANDROV	{"email": "a.aleksandrov.05101971@postgrespro.ru", "phone": "+70311423981"}
0005433868928	1F358D	4095 539749	ALEKSANDR BONDARENKO	{"phone": "+70103574056"}
0005433868929	1F358D	4133 031047	TAISIYA ZHURAVLEVA	{"email": "zhuravleva_t.02091985@postgrespro.ru", "phone": "+70220914155"}
0005433868930	72E8AB	3852 085394	IRINA ARKHIPOVA	{"phone": "+70248937794"}
0005433868931	EFBFA2	0014 647632	ELENA MOROZOVA	{"email": "emorozova.071966@postgrespro.ru", "phone": "+70171927095"}
0005433868932	324698	3148 189819	OLGA VOLKOVA	{"email": "o_volkova-031975@postgrespro.ru", "phone": "+70988542724"}
0005433868933	2FCBA0	3798 450038	EVGENIY FOMIN	{"email": "evgeniy-fomin.1963@postgrespro.ru", "phone": "+70446964808"}
0005433868934	D5E3DB	7716 565665	LYUBOV POPOVA	{"email": "l_popova-27101973@postgrespro.ru", "phone": "+70253430516"}
0005433868935	48963C	2372 543713	ILYA ALEKSEEV	{"phone": "+70166482622"}
0005433868936	128D07	3022 590600	VLADIMIR GRIGOREV	{"email": "v-grigorev.121966@postgrespro.ru", "phone": "+70119091565"}
0005433868937	128D07	0260 033691	MARGARITA KOMAROVA	{"phone": "+70055952965"}
0005433868938	867C41	9443 325238	NATALYA MOROZOVA	{"phone": "+70543853158"}
0005433868940	88DD24	8148 018370	DMITRIY AFANASEV	{"email": "afanasev-dmitriy_07101981@postgrespro.ru", "phone": "+70996898172"}
0005433868941	88DD24	3629 044150	DMITRIY POPOV	{"phone": "+70957844104"}
0005433868942	48232C	4775 636339	VASILIY MIRONOV	{"email": "v_mironov_03081965@postgrespro.ru", "phone": "+70655544369"}
0005433868943	BFC213	7692 395751	ANNA NESTEROVA	{"phone": "+70621840188"}
0005433868944	F286DD	7953 803443	RUSTAM DMITRIEV	{"email": "r.dmitriev-1975@postgrespro.ru", "phone": "+70834488247"}
0005433868945	053F5D	9714 602598	OLEG VASILEV	{"phone": "+70379403781"}
0005433868946	1B02DA	9701 011897	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov1981@postgrespro.ru", "phone": "+70436046110"}
0005433868947	47CAB4	3012 931217	ZOYA KUZNECOVA	{"phone": "+70205643648"}
0005433868948	21F2B4	1842 747798	VYACHESLAV ABRAMOV	{"email": "abramov.vyacheslav-061968@postgrespro.ru", "phone": "+70129526449"}
0005433868949	8BF052	4789 529533	ELENA KONOVALOVA	{"email": "elenakonovalova.27111973@postgrespro.ru", "phone": "+70560206871"}
0005433868950	8BF052	2415 440612	YULIYA MIRONOVA	{"email": "yuliya.mironova-13011971@postgrespro.ru", "phone": "+70055570393"}
0005433868951	8BF052	3804 251387	SVETLANA PAVLOVA	{"phone": "+70021985824"}
0005433868952	B2EB6B	2381 079911	EVGENIYA VASILEVA	{"phone": "+70982969762"}
0005433868953	E13420	4136 364124	TATYANA CHERNOVA	{"email": "chernova-t.1974@postgrespro.ru", "phone": "+70579329237"}
0005433868954	E13420	1958 055969	YURIY KOZLOV	{"email": "kozlov.yuriy.1969@postgrespro.ru", "phone": "+70867025462"}
0005433868955	AA739E	7419 732223	ALEKSANDR GRIGOREV	{"phone": "+70029198504"}
0005433868956	BA25BF	6495 484715	NATALYA VOLKOVA	{"phone": "+70785704147"}
0005433868957	5F591C	4347 179506	VLADIMIR ROMANOV	{"phone": "+70148600661"}
0005433868958	51A1E1	0559 904165	ROMAN VLASOV	{"email": "r_vlasov1972@postgrespro.ru", "phone": "+70162110721"}
0005433868959	F4808D	2546 842370	ELIZAVETA POTAPOVA	{"email": "potapovae28031963@postgrespro.ru", "phone": "+70987463185"}
0005433868960	865BC2	0535 102198	ZOYA NIKOLAEVA	{"phone": "+70940444010"}
0005433868961	865BC2	8362 804003	ELENA SIDOROVA	{"phone": "+70566826604"}
0005433868962	D26AF4	2643 458719	VLADIMIR FROLOV	{"email": "frolov-v_041971@postgrespro.ru", "phone": "+70574884977"}
0005433868963	D26AF4	3664 149761	NIKOLAY CHERNOV	{"phone": "+70597005167"}
0005433868964	D26AF4	0435 522204	VERA VOLKOVA	{"email": "volkovavera.111970@postgrespro.ru", "phone": "+70067805319"}
0005433868965	9F7377	7983 703489	MARIYA BELOVA	{"email": "m.belova24051974@postgrespro.ru", "phone": "+70657582800"}
0005433868966	BFD411	7923 348922	MARIYA ZHUKOVA	{"email": "mariya.zhukova-091975@postgrespro.ru", "phone": "+70186435650"}
0005433868967	D8C109	6656 314699	ALEKSEY POPOV	{"phone": "+70513791252"}
0005433868968	1E4E79	1114 218266	LEONID POPOV	{"phone": "+70809109451"}
0005433868969	1E4E79	7446 494106	ELIZAVETA SMIRNOVA	{"email": "e_smirnova-101969@postgrespro.ru", "phone": "+70869887553"}
0005433868970	0F80BE	8912 809185	POLINA KUZMINA	{"email": "pkuzmina.071975@postgrespro.ru", "phone": "+70115535864"}
0005433868971	0F80BE	4517 746232	ANTONINA DMITRIEVA	{"email": "dmitrieva_antonina.091975@postgrespro.ru", "phone": "+70000878171"}
0005433868972	0F80BE	4689 514471	NIKITA POPOV	{"email": "npopov.30031966@postgrespro.ru", "phone": "+70623212057"}
0005433868973	EE3DF5	4390 737887	DMITRIY SHEVCHENKO	{"email": "shevchenko-dmitriy041967@postgrespro.ru", "phone": "+70211360686"}
0005433868974	AA690D	3754 317867	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov1969@postgrespro.ru", "phone": "+70097085901"}
0005433868975	DBB2D7	8624 800788	ANNA FROLOVA	{"phone": "+70367495952"}
0005433868976	EA2707	7330 203855	IRINA KUDRYASHOVA	{"phone": "+70415054628"}
0005433868977	EA2707	4464 590540	NATALYA NOVIKOVA	{"email": "novikovan1972@postgrespro.ru", "phone": "+70469251803"}
0005433868978	442726	5225 769826	IGOR VASILEV	{"email": "vasilev_igor26101971@postgrespro.ru", "phone": "+70634519587"}
0005433868979	68D7EA	6834 270290	SVETLANA MAKSIMOVA	{"phone": "+70726727657"}
0005433868980	8592B1	4836 106579	ALEKSANDR ISAEV	{"email": "aleksandrisaev.101971@postgrespro.ru", "phone": "+70255811334"}
0005433868981	8592B1	8754 683955	NATALYA MARTYNOVA	{"email": "martynova_natalya-31071984@postgrespro.ru", "phone": "+70249537048"}
0005433868982	7F62AF	2582 263721	NINA TIMOFEEVA	{"email": "timofeeva_n.07071964@postgrespro.ru", "phone": "+70059503312"}
0005433868983	19F174	7317 146894	MAKSIM MOISEEV	{"phone": "+70462274298"}
0005433868984	366F02	8591 130669	MARIYA GUSEVA	{"phone": "+70970772894"}
0005433868985	FF75EF	8208 370713	SVETLANA ISAEVA	{"email": "svetlanaisaeva25051976@postgrespro.ru", "phone": "+70633832194"}
0005433868986	D26247	7406 974987	ANNA MIKHAYLOVA	{"email": "mikhaylova.a-1969@postgrespro.ru", "phone": "+70886277103"}
0005433868987	EFD9EB	8802 570665	OLGA ANTONOVA	{"phone": "+70744706227"}
0005433868988	EFD9EB	6134 371094	LYUDMILA POLYAKOVA	{"phone": "+70253693994"}
0005433868989	8CED4A	1879 074012	ALEKSANDR GRIGOREV	{"email": "a-grigorev-15091967@postgrespro.ru", "phone": "+70761310807"}
0005433868990	B1B76C	1533 033139	VYACHESLAV SCHERBAKOV	{"phone": "+70651256748"}
0005433868991	B1B76C	9220 491282	ELENA STEPANOVA	{"phone": "+70961405476"}
0005433868992	CCB242	8412 317870	LYUBOV AFANASEVA	{"email": "afanaseva.lyubov14061968@postgrespro.ru", "phone": "+70396164495"}
0005433868993	264355	9901 933618	VERONIKA BORISOVA	{"email": "borisova-v_101963@postgrespro.ru", "phone": "+70863484714"}
0005433868994	A122A3	6916 810717	VLADIMIR ALEKSANDROV	{"email": "aleksandrov.v-1971@postgrespro.ru", "phone": "+70961733067"}
0005433868995	A122A3	2653 358373	MIKHAIL POPOV	{"phone": "+70363070494"}
0005433868996	6DB7EB	3183 173336	OLGA SOROKINA	{"phone": "+70533799823"}
0005433868997	6DB7EB	9525 055912	INNA KUZNECOVA	{"email": "ikuznecova.24081969@postgrespro.ru", "phone": "+70821394207"}
0005433868998	6DB7EB	4387 952878	LIDIYA CHERNOVA	{"email": "lidiya-chernova_061968@postgrespro.ru", "phone": "+70364577321"}
0005433868999	F47AB8	1679 522686	ELENA MOISEEVA	{"phone": "+70199416556"}
0005433869000	F47AB8	6878 281446	VLADIMIR MIRONOV	{"email": "vladimir_mironov_011972@postgrespro.ru", "phone": "+70711454464"}
0005433869001	F47AB8	8571 968514	ANATOLIY NIKITIN	{"email": "a.nikitin-1964@postgrespro.ru", "phone": "+70831501328"}
0005433869002	B2DEF5	6785 609962	ZINAIDA KUZNECOVA	{"phone": "+70317050848"}
0005433869003	EB203B	5153 222635	OLGA ARKHIPOVA	{"phone": "+70408469722"}
0005433869004	B4F877	6124 726060	KLAVDIYA STEPANOVA	{"phone": "+70412919129"}
0005433869005	DEE1DA	8668 745905	VASILIY NIKITIN	{"phone": "+70612966614"}
0005433869006	70CE87	7384 392202	KSENIYA YAKOVLEVA	{"email": "k.yakovleva071970@postgrespro.ru", "phone": "+70196944225"}
0005433869007	177027	8709 640984	VLADIMIR SOROKIN	{"phone": "+70090090852"}
0005433869008	AC5032	1141 411788	OLEG IVANOV	{"email": "oleg.ivanov_1981@postgrespro.ru", "phone": "+70064525454"}
0005433869009	17E325	1054 417039	NIKITA PETROV	{"email": "petrov.nikita.30081980@postgrespro.ru", "phone": "+70659922791"}
0005433869010	A9587E	7359 519405	IRINA MEDVEDEVA	{"phone": "+70407145826"}
0005433869011	A9587E	8146 361269	ALEKSEY SIDOROV	{"phone": "+70733938884"}
0005433869012	2FF5EF	9484 158030	SERGEY DENISOV	{"email": "denisovsergey_29101968@postgrespro.ru", "phone": "+70364218557"}
0005433869013	2FF5EF	9271 100162	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_v_121964@postgrespro.ru", "phone": "+70584617160"}
0005433869014	090962	0275 761002	FANIYA VASILEVA	{"email": "vasileva_faniya-111970@postgrespro.ru", "phone": "+70869632215"}
0005433869015	090962	9313 764572	ALEKSANDR MELNIKOV	{"phone": "+70835034509"}
0005433869016	1220E0	5026 582459	ALEKSEY KUDRYASHOV	{"phone": "+70142698183"}
0005433869017	1220E0	8126 886962	ANASTASIYA MOISEEVA	{"email": "moiseeva-anastasiya.121980@postgrespro.ru", "phone": "+70316587401"}
0005433869018	E56AF0	8419 921017	ALEKSANDR NIKOLAEV	{"phone": "+70400778396"}
0005433869019	DB5DE0	0902 570896	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov_15051967@postgrespro.ru", "phone": "+70327175556"}
0005433869020	94C4F3	8042 240136	LILIYA NIKOLAEVA	{"email": "liliya_nikolaeva1966@postgrespro.ru", "phone": "+70441413614"}
0005433869021	7F531A	3081 364285	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr_13101978@postgrespro.ru", "phone": "+70272966908"}
0005433869022	7F531A	0467 042088	IRINA PETROVA	{"email": "irina.petrova_21041969@postgrespro.ru", "phone": "+70231093640"}
0005433869023	12DA00	5077 148985	KSENIYA LEBEDEVA	{"email": "lebedevakseniya.051979@postgrespro.ru", "phone": "+70844576873"}
0005433869024	12DA00	4270 507872	NIKOLAY KULIKOV	{"email": "kulikov-n.25031985@postgrespro.ru", "phone": "+70469118273"}
0005433869025	318AB5	8015 788126	ANATOLIY STEPANOV	{"phone": "+70969016341"}
0005433869026	CD9353	1920 371063	ALENA YAKOVLEVA	{"phone": "+70057073619"}
0005433869027	CD9353	1758 668359	IGOR FEDOROV	{"phone": "+70342653022"}
0005433869028	CD9353	9311 020696	NIKOLAY SHEVCHENKO	{"email": "shevchenko-n_12051975@postgrespro.ru", "phone": "+70744415894"}
0005433869029	4D8A2F	0724 221817	SERGEY MARTYNOV	{"email": "martynov.s_1977@postgrespro.ru", "phone": "+70645213005"}
0005433869030	4D8A2F	9318 484636	ANASTASIYA MIRONOVA	{"email": "a-mironova.041967@postgrespro.ru", "phone": "+70551404773"}
0005433869031	4D8A2F	7609 401919	ELENA SOLOVEVA	{"phone": "+70325596260"}
0005433869032	7987FB	8014 991087	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana16041978@postgrespro.ru", "phone": "+70582629667"}
0005433869033	7987FB	0858 433302	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy1973@postgrespro.ru", "phone": "+70116106327"}
0005433869034	F162DC	6597 006122	VIKTORIYA KULIKOVA	{"phone": "+70207915845"}
0005433869035	73E8FC	4940 071064	VALERIYA YAKOVLEVA	{"phone": "+70350809210"}
0005433869036	E7EA9F	3856 844559	ALEKSANDRA NOVIKOVA	{"email": "anovikova061984@postgrespro.ru", "phone": "+70765964149"}
0005433869037	E7EA9F	3122 821393	IVAN MARTYNOV	{"phone": "+70497471882"}
0005433869038	9B78B6	4385 814256	IGOR GAVRILOV	{"email": "igorgavrilov.101979@postgrespro.ru", "phone": "+70575127602"}
0005433869039	71505F	6299 823944	RAMIL GERASIMOV	{"phone": "+70807606572"}
0005433869040	71505F	2973 503092	OKSANA IVANOVA	{"email": "ivanova.o.091975@postgrespro.ru", "phone": "+70251915739"}
0005433869041	71505F	4711 248794	MARIYA NIKIFOROVA	{"phone": "+70447074706"}
0005433869042	392BF5	0184 848268	VYACHESLAV PETROV	{"email": "petrov-v_1961@postgrespro.ru", "phone": "+70776802635"}
0005433869043	AEE6D1	4482 907515	NIKOLAY KUDRYASHOV	{"email": "kudryashov.n.17111965@postgrespro.ru", "phone": "+70207005894"}
0005433869044	5EB5E7	6441 904306	SERGEY BORISOV	{"phone": "+70807525299"}
0005433869045	5EB5E7	3787 607694	ANTONINA KUZMINA	{"email": "akuzmina.1966@postgrespro.ru", "phone": "+70608375808"}
0005433869046	00D138	4456 450852	EDUARD EGOROV	{"email": "eduard.egorov_081981@postgrespro.ru", "phone": "+70548250087"}
0005433869047	509E54	5739 288262	VIKTOR SOKOLOV	{"phone": "+70235352739"}
0005433869048	B68A1C	6950 625288	ELENA SIDOROVA	{"phone": "+70881649657"}
0005433869049	53CB63	5832 200142	TATYANA NOVIKOVA	{"email": "tatyana-novikova-16021982@postgrespro.ru", "phone": "+70753177265"}
0005433869050	53CB63	7872 463317	ALEKSANDR NIKOLAEV	{"phone": "+70377279614"}
0005433869051	ADCDE5	1411 113704	RADIK IVANOV	{"email": "ivanov.radik_11081970@postgrespro.ru", "phone": "+70055283414"}
0005433869052	426983	6311 180747	OLEG MATVEEV	{"email": "matveev.oleg1979@postgrespro.ru", "phone": "+70286705745"}
0005433869053	B4C819	0611 472040	VALENTINA BELOVA	{"phone": "+70338154738"}
0005433869054	F1A5F3	5308 797895	IGOR ROMANOV	{"phone": "+70868271693"}
0005433869055	8D2EB7	8205 714393	OLEG ABRAMOV	{"phone": "+70417125681"}
0005433869056	EAD2F1	0027 173684	ELENA BELOVA	{"email": "ebelova_09121971@postgrespro.ru", "phone": "+70249719916"}
0005433869057	EAD2F1	3920 990075	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey101975@postgrespro.ru", "phone": "+70726589853"}
0005433869058	B452E2	2982 746349	YULIYA FILATOVA	{"email": "filatova.yuliya101976@postgrespro.ru", "phone": "+70243820112"}
0005433869059	B452E2	4631 772053	OLGA OSIPOVA	{"email": "osipova.o_1965@postgrespro.ru", "phone": "+70702432611"}
0005433869060	B452E2	5323 312069	ALEKSANDR MEDVEDEV	{"email": "medvedev-a-31011989@postgrespro.ru", "phone": "+70012022779"}
0005433869061	4C42E1	2540 832108	ELENA DAVYDOVA	{"phone": "+70483788202"}
0005433869062	C2798F	8104 496565	SERGEY VASILEV	{"email": "sergey.vasilev1987@postgrespro.ru", "phone": "+70347108123"}
0005433869063	19EFDD	7383 724246	IRINA DAVYDOVA	{"email": "irina_davydova_1983@postgrespro.ru", "phone": "+70890500007"}
0005433869064	0004E1	8443 520906	EGOR PAVLOV	{"phone": "+70551493403"}
0005433869065	0004E1	2243 683151	NATALYA DANILOVA	{"email": "danilova-natalya1965@postgrespro.ru", "phone": "+70275318845"}
0005433869066	54542F	4528 468733	LARISA KISELEVA	{"phone": "+70928570687"}
0005433869067	54542F	8417 876836	EVGENIY SERGEEV	{"phone": "+70347723057"}
0005433869068	890954	2885 150153	BORIS FILIPPOV	{"email": "borisfilippov101988@postgrespro.ru", "phone": "+70153997484"}
0005433869069	890954	9412 906888	RAILYA DAVYDOVA	{"phone": "+70335532013"}
0005433869070	8130C1	2085 577864	MAKSIM ZHURAVLEV	{"email": "mzhuravlev091974@postgrespro.ru", "phone": "+70878744233"}
0005433869071	B1F2E0	0872 606924	NINA FROLOVA	{"email": "nfrolova.12021961@postgrespro.ru", "phone": "+70374420266"}
0005433869072	F8E758	2432 441265	TATYANA KISELEVA	{"email": "kiselevat.1969@postgrespro.ru", "phone": "+70238512690"}
0005433869073	B6A7E8	4601 983022	NADEZHDA TITOVA	{"email": "n.titova.091970@postgrespro.ru", "phone": "+70898137794"}
0005433869074	8295E6	8381 696501	LIDIYA IVANOVA	{"email": "lidiyaivanova061953@postgrespro.ru", "phone": "+70455548581"}
0005433869075	8295E6	4429 389007	ALEKSEY ALEKSEEV	{"email": "aleksey_alekseev.27061972@postgrespro.ru", "phone": "+70831413714"}
0005433869076	B1506A	4488 602551	DMITRIY FOMIN	{"phone": "+70685986694"}
0005433869077	75EECB	2443 178852	MARINA KOLESNIKOVA	{"email": "m-kolesnikova071962@postgrespro.ru", "phone": "+70322490224"}
0005433869078	82D597	0756 592838	ALEKSANDRA VOROBEVA	{"phone": "+70994537918"}
0005433869079	A8DA34	8662 369391	VLADIMIR ALEKSEEV	{"phone": "+70129552205"}
0005433869080	307568	7059 716371	ALEVTINA VOLKOVA	{"phone": "+70324124994"}
0005433869081	307568	1128 645345	YULIYA ABRAMOVA	{"email": "abramovay.09071969@postgrespro.ru", "phone": "+70855615734"}
0005433869082	DA56C5	4603 762574	EDUARD DMITRIEV	{"email": "dmitriev-e071964@postgrespro.ru", "phone": "+70985352295"}
0005433869083	C671DF	3587 529507	GENNADIY VOLKOV	{"email": "volkov_g.1972@postgrespro.ru", "phone": "+70423260497"}
0005433869084	C671DF	2883 973147	VIKTOR ZAYCEV	{"email": "viktor.zaycev041976@postgrespro.ru", "phone": "+70119557601"}
0005433869085	588C67	6213 149017	OLGA ORLOVA	{"phone": "+70792754067"}
0005433869086	588C67	4080 394309	MARINA VASILEVA	{"phone": "+70814460058"}
0005433869087	B0111F	1824 251319	VALENTINA IVANOVA	{"phone": "+70032314467"}
0005433869088	B0111F	2673 140131	LYUDMILA POLYAKOVA	{"phone": "+70331811789"}
0005433869089	B3C5E9	6486 091623	ARTEM KONOVALOV	{"email": "konovalov_a21091973@postgrespro.ru", "phone": "+70156516623"}
0005433869090	1D3B8D	2548 218215	ALEKSANDR KUZNECOV	{"email": "a_kuznecov-18121979@postgrespro.ru", "phone": "+70152336688"}
0005433869091	122CE1	9115 038808	ELMIRA ALEKSANDROVA	{"phone": "+70391909535"}
0005433869092	FF3BEE	5199 931878	VERA ZAKHAROVA	{"phone": "+70980913626"}
0005433869093	035785	8619 062346	SVETLANA MATVEEVA	{"email": "s-matveeva24051983@postgrespro.ru", "phone": "+70080748437"}
0005433869094	6B7960	3195 184386	ALEKSANDR BONDARENKO	{"phone": "+70914001397"}
0005433869095	6B7960	1924 150846	NIKOLAY RODIONOV	{"phone": "+70851307934"}
0005433869096	3FDF30	6996 354393	MAKSIM MAKSIMOV	{"phone": "+70629183564"}
0005433869097	8C0452	6492 130928	VLADIMIR GAVRILOV	{"phone": "+70816827013"}
0005433869098	DB14E9	1098 331941	ALENA IVANOVA	{"email": "a-ivanova.1979@postgrespro.ru", "phone": "+70130069611"}
0005433869099	75683D	3056 421623	ALEKSEY ALEKSEEV	{"email": "alekseeva_101967@postgrespro.ru", "phone": "+70174149037"}
0005433869100	B9315F	6832 197137	MARIYA MOROZOVA	{"phone": "+70367399418"}
0005433869101	B9315F	2307 766268	TARAS SOROKIN	{"email": "sorokin.taras1966@postgrespro.ru", "phone": "+70238315378"}
0005433869102	B20D0B	0787 253747	SERGEY SOKOLOV	{"email": "sokolov-s051968@postgrespro.ru", "phone": "+70518408957"}
0005433869103	14A192	7849 310404	VERA TITOVA	{"email": "titova.v-1969@postgrespro.ru", "phone": "+70305328520"}
0005433869104	14A192	4823 729501	NATALIYA MIKHAYLOVA	{"email": "mikhaylova_nataliya-24121974@postgrespro.ru", "phone": "+70656737789"}
0005433869105	15659E	7199 095088	NATALYA MARTYNOVA	{"email": "nmartynova-1970@postgrespro.ru", "phone": "+70311154852"}
0005433869106	6B359C	0633 825804	EVGENIY TARASOV	{"email": "e.tarasov-041983@postgrespro.ru", "phone": "+70341995176"}
0005433869107	6B359C	6772 540400	NIKOLAY ROMANOV	{"email": "nikolay.romanov-1962@postgrespro.ru", "phone": "+70113952525"}
0005433869108	07BF52	3694 774379	SERGEY ALEKSEEV	{"phone": "+70849241303"}
0005433869109	FB9FF1	6493 086037	TATYANA IVANOVA	{"phone": "+70509594200"}
0005433869110	FB2F5A	0519 090747	LIDIYA ZAYCEVA	{"email": "zayceval1973@postgrespro.ru", "phone": "+70894138007"}
0005433869111	53FB7D	6668 442264	VALERIY KOROLEV	{"email": "korolevvaleriy-1971@postgrespro.ru", "phone": "+70483464620"}
0005433869168	5D75B1	6144 537942	GULIYA CHERNOVA	{"phone": "+70172589307"}
0005433869112	938EE6	9242 524234	SERGEY NAUMOV	{"email": "s-naumov-031976@postgrespro.ru", "phone": "+70889207063"}
0005433869113	938EE6	9606 129176	DMITRIY SIDOROV	{"phone": "+70132659560"}
0005433869114	331134	5077 242755	DMITRIY NOVIKOV	{"phone": "+70440545882"}
0005433869115	331134	1848 167161	MIKHAIL BORISOV	{"email": "borisov.mikhail-09031982@postgrespro.ru", "phone": "+70662046469"}
0005433869116	D6D8C4	8184 022220	LARISA MIKHAYLOVA	{"phone": "+70487089341"}
0005433869117	D6D8C4	8412 122856	ELENA BORISOVA	{"email": "eborisova1980@postgrespro.ru", "phone": "+70283935941"}
0005433869118	BD00E7	1883 225886	VIKTOR SMIRNOV	{"email": "viktor.smirnov.10021978@postgrespro.ru", "phone": "+70757841723"}
0005433869119	C02BF1	8217 127342	ALEKSANDR MOROZOV	{"phone": "+70297509342"}
0005433869120	666712	4411 883040	ANDREY KUZNECOV	{"phone": "+70211140480"}
0005433869121	F71CB3	5643 545855	OKSANA PETROVA	{"email": "petrova_oksana.031971@postgrespro.ru", "phone": "+70819669150"}
0005433869122	DF95B3	0699 588635	TATYANA PETROVA	{"email": "tatyana_petrova03021976@postgrespro.ru", "phone": "+70655479558"}
0005433869123	872203	5464 882078	NIKOLAY KUDRYASHOV	{"phone": "+70872304830"}
0005433869124	A49129	3637 974788	TATYANA GORBUNOVA	{"phone": "+70073576241"}
0005433869125	749D6F	3315 148038	ANASTASIYA SOLOVEVA	{"phone": "+70480919337"}
0005433869126	0D7B98	8105 563139	VIKTOR KUZNECOV	{"email": "kuznecovv_1969@postgrespro.ru", "phone": "+70740684898"}
0005433869127	0D7B98	8297 000280	NIKOLAY PAVLOV	{"email": "pavlov_nikolay_31011973@postgrespro.ru", "phone": "+70952866610"}
0005433869128	5B3947	5125 425041	PETR NAZAROV	{"email": "nazarov.petr-1971@postgrespro.ru", "phone": "+70618954148"}
0005433869129	5B93D5	8262 615001	VLADISLAV ALEKSEEV	{"email": "alekseev.vladislav.071964@postgrespro.ru", "phone": "+70781288845"}
0005433869130	CA28C8	9819 962885	ELENA FADEEVA	{"email": "e.fadeeva_111974@postgrespro.ru", "phone": "+70455442827"}
0005433869131	CA28C8	3229 245196	ANDREY SAVELEV	{"email": "andrey.savelev_091975@postgrespro.ru", "phone": "+70413410658"}
0005433869132	12FE99	7823 072976	VALENTINA SOLOVEVA	{"email": "soloveva-valentina.03101967@postgrespro.ru", "phone": "+70091810621"}
0005433869133	1BA617	7382 815463	ELENA KULIKOVA	{"phone": "+70493030954"}
0005433869134	1BA617	6404 383990	MARINA ABRAMOVA	{"email": "m_abramova.24071973@postgrespro.ru", "phone": "+70370586647"}
0005433869135	2085B9	5130 636008	ALLA STEPANOVA	{"email": "a-stepanova.21031967@postgrespro.ru", "phone": "+70331003676"}
0005433869136	2085B9	9117 525158	EVGENIY ZAYCEV	{"phone": "+70731841561"}
0005433869137	8844E8	7055 807454	ALEKSANDR NIKITIN	{"phone": "+70139961537"}
0005433869138	8844E8	8793 042230	VLADIMIR GRIGOREV	{"phone": "+70090780303"}
0005433869139	D30378	9816 501586	ELENA SEMENOVA	{"email": "semenovaelena01011977@postgrespro.ru", "phone": "+70586350629"}
0005433869140	D30378	5676 262126	PETR KOZLOV	{"phone": "+70031227035"}
0005433869141	4DCC00	2628 314536	LYUDMILA KOROLEVA	{"phone": "+70516217080"}
0005433869142	DD8722	1081 424439	RINAT FILIPPOV	{"email": "filippov-r.23121981@postgrespro.ru", "phone": "+70607139186"}
0005433869143	DD8722	5203 122789	PETR KUDRYASHOV	{"phone": "+70505207435"}
0005433869144	BA59E9	6489 453502	VADIM MOISEEV	{"phone": "+70734716634"}
0005433869145	1DAE8B	1123 067189	IGOR TARASOV	{"phone": "+70317134715"}
0005433869146	A47ABF	7608 496643	MAKSIM VOROBEV	{"phone": "+70978507288"}
0005433869147	F987D8	9343 004327	LARISA DMITRIEVA	{"phone": "+70359654847"}
0005433869148	F987D8	1081 348656	DANIIL DMITRIEV	{"email": "daniil.dmitriev071970@postgrespro.ru", "phone": "+70234190524"}
0005433869149	931112	1181 238582	ANDREY KOZLOV	{"email": "a_kozlov_1959@postgrespro.ru", "phone": "+70931145870"}
0005433869150	931112	5540 178872	ANDREY VLASOV	{"email": "vlasov-andrey.17011972@postgrespro.ru", "phone": "+70078134407"}
0005433869151	094F17	1518 443975	ALEKSANDR POPOV	{"email": "aleksandr-popov.1976@postgrespro.ru", "phone": "+70100280884"}
0005433869152	094F17	2696 027570	VERA BELYAEVA	{"email": "belyaevav121973@postgrespro.ru", "phone": "+70868427818"}
0005433869153	A2255C	6841 019591	ALEKSANDR BORISOV	{"email": "aleksandr_borisov_06101968@postgrespro.ru", "phone": "+70860036380"}
0005433869154	A2255C	6484 490335	FEDOR POPOV	{"phone": "+70539895557"}
0005433869155	0DE565	1430 538520	ALEKSANDR DAVYDOV	{"phone": "+70342818972"}
0005433869156	3C90B1	5254 833254	YULIYA KUZNECOVA	{"email": "kuznecova.yuliya-121963@postgrespro.ru", "phone": "+70136026486"}
0005433869157	EBEE0B	2164 468996	VALERIY GRIGOREV	{"email": "valeriygrigorev-1988@postgrespro.ru", "phone": "+70092699655"}
0005433869158	CF7832	4319 942271	VERA SOKOLOVA	{"phone": "+70848214052"}
0005433869159	48BE45	2119 740022	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov1983@postgrespro.ru", "phone": "+70516477216"}
0005433869160	43208D	8986 719386	ALEKSEY NIKITIN	{"phone": "+70129316127"}
0005433869161	F6617E	3507 627161	ALEKSEY KUDRYASHOV	{"phone": "+70033559357"}
0005433869162	F6617E	8359 865223	ANATOLIY PETROV	{"email": "petrov.a-041976@postgrespro.ru", "phone": "+70658798757"}
0005433869163	F6617E	1207 937018	GRIGORIY DENISOV	{"phone": "+70938062164"}
0005433869164	B84086	8718 490335	VALENTINA OSIPOVA	{"phone": "+70616651301"}
0005433869165	CDB92A	5602 242973	VALENTINA ALEKSEEVA	{"email": "valentina_alekseeva101980@postgrespro.ru", "phone": "+70879393520"}
0005433869166	29D9B0	5668 749250	MAYYA MEDVEDEVA	{"email": "mayya_medvedeva.19041970@postgrespro.ru", "phone": "+70275069148"}
0005433869167	29D9B0	5447 085071	NATALYA GERASIMOVA	{"email": "n.gerasimova-111978@postgrespro.ru", "phone": "+70323540721"}
0005433869169	5D75B1	3588 150022	EVGENIYA MELNIKOVA	{"email": "emelnikova_05031975@postgrespro.ru", "phone": "+70845801387"}
0005433869170	FB4492	8114 080430	FARIT PAVLOV	{"phone": "+70655174844"}
0005433869171	E00CFA	1845 378794	ALEKSANDR EGOROV	{"phone": "+70955267529"}
0005433869172	E00CFA	0718 199822	MARGARITA KONOVALOVA	{"email": "margaritakonovalova-011972@postgrespro.ru", "phone": "+70208214437"}
0005433869173	3A3BE9	3476 592188	VIKTORIYA BELYAEVA	{"email": "viktoriyabelyaeva1973@postgrespro.ru", "phone": "+70815907495"}
0005433869174	CE4467	0081 606388	ALINA MARTYNOVA	{"email": "martynovaalina.1990@postgrespro.ru", "phone": "+70533401466"}
0005433869175	CE4467	3005 265435	MAKSIM MOROZOV	{"phone": "+70911613787"}
0005433869176	CB1C93	8159 393012	KAPITALINA MOROZOVA	{"phone": "+70238435260"}
0005433869177	79920B	6417 815839	SERGEY ZAYCEV	{"email": "s_zaycev_041969@postgrespro.ru", "phone": "+70991486643"}
0005433869178	79920B	0556 974641	YURIY MOISEEV	{"email": "moiseev.yuriy03101980@postgrespro.ru", "phone": "+70237816026"}
0005433869179	199AFC	6838 410443	MARINA VASILEVA	{"email": "vasileva_m.08071966@postgrespro.ru", "phone": "+70199773010"}
0005433869180	89E4CC	9291 970009	KSENIYA KUZNECOVA	{"phone": "+70952386145"}
0005433869181	89E4CC	5895 258535	ANNA KUZMINA	{"email": "annakuzmina071985@postgrespro.ru", "phone": "+70203170927"}
0005433869182	DBD5B6	0774 706511	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov.031978@postgrespro.ru", "phone": "+70538679761"}
0005433869183	DBD5B6	9076 163507	VALENTINA MIKHAYLOVA	{"email": "valentina_mikhaylova-05031980@postgrespro.ru", "phone": "+70513170500"}
0005433869184	BBB8F7	3164 198128	VALENTINA ALEKSEEVA	{"email": "alekseeva_valentina-07061971@postgrespro.ru", "phone": "+70148229411"}
0005433869185	A81FC1	3645 433879	YAROSLAVA BARANOVA	{"phone": "+70659131656"}
0005433869186	78D8C0	4812 197592	ALEKSEY ANDREEV	{"email": "andreev-aleksey1966@postgrespro.ru", "phone": "+70589840342"}
0005433869187	4D86F4	1616 051815	VALENTINA OSIPOVA	{"email": "osipova.v-1966@postgrespro.ru", "phone": "+70700885576"}
0005433869188	880E21	5742 711994	NATALYA SOROKINA	{"phone": "+70233868547"}
0005433869189	880E21	1501 683190	GALIYA NESTEROVA	{"email": "g-nesterova22021980@postgrespro.ru", "phone": "+70588518390"}
0005433869190	7ACB0A	7586 795532	NATALYA VASILEVA	{"phone": "+70300599874"}
0005433869191	AE7FDB	7544 928911	ELENA MOROZOVA	{"email": "morozova.elena.021973@postgrespro.ru", "phone": "+70836286192"}
0005433869192	E7264E	6304 193534	VLADIMIR CHERNOV	{"phone": "+70035382705"}
0005433869193	F3D96C	3159 477285	ALEKSANDRA VLASOVA	{"phone": "+70236111422"}
0005433869194	E20F09	7538 341588	NATALYA ZHURAVLEVA	{"phone": "+70827383319"}
0005433869195	D39E0E	7787 062863	MARTA ZAYCEVA	{"phone": "+70756346489"}
0005433869196	D48501	1435 546030	LYUDMILA STEPANOVA	{"email": "l_stepanova-16091976@postgrespro.ru", "phone": "+70018784310"}
0005433869197	D48501	9432 530082	VYACHESLAV DMITRIEV	{"phone": "+70318173215"}
0005433869198	F6EB4A	7786 995084	LIDIYA SAVELEVA	{"phone": "+70595800420"}
0005433869199	F6EB4A	2617 694726	MARIYA SIDOROVA	{"phone": "+70950397659"}
0005433869200	1EAFAD	2892 508641	IRINA OSIPOVA	{"phone": "+70569915244"}
0005433869201	1EAFAD	9243 924750	ANDREY TIKHONOV	{"phone": "+70141613904"}
0005433869202	78BFD0	7361 725625	ALEKSEY SOLOVEV	{"email": "solovev-aleksey-081972@postgrespro.ru", "phone": "+70999779655"}
0005433869203	1E06E9	3492 350486	ALEKSANDR KOZLOV	{"phone": "+70007644654"}
0005433869204	1E06E9	4295 163128	NIKOLAY TIKHONOV	{"phone": "+70208304025"}
0005433869205	6A8F2D	7817 748474	NIKITA PETROV	{"phone": "+70291176185"}
0005433869206	BDCA74	9154 303052	VIKTORIYA TIMOFEEVA	{"email": "timofeeva-v.08071973@postgrespro.ru", "phone": "+70952175604"}
0005433869207	01D9E4	1904 382281	GALINA ERMAKOVA	{"email": "g-ermakova051970@postgrespro.ru", "phone": "+70850851638"}
0005433869208	01D9E4	5300 685624	GRIGORIY KULIKOV	{"email": "g.kulikov_1969@postgrespro.ru", "phone": "+70770352713"}
0005433869209	682512	8247 259014	TATYANA MOROZOVA	{"phone": "+70068016752"}
0005433869210	CC22D6	2961 915336	EVGENIY SAVELEV	{"email": "evgeniy-savelev071974@postgrespro.ru", "phone": "+70294370780"}
0005433869211	CC22D6	3030 094841	GLEB MATVEEV	{"phone": "+70056768806"}
0005433869212	A32F33	7585 472239	OLGA GORBUNOVA	{"email": "gorbunova_olga-21111971@postgrespro.ru", "phone": "+70609844989"}
0005433869213	749C96	2334 623135	TAISA IVANOVA	{"email": "ivanovat-041975@postgrespro.ru", "phone": "+70749131563"}
0005433869214	942D4F	6084 118040	NIKOLAY FEDOROV	{"phone": "+70352839010"}
0005433869215	8991D0	1794 577384	ARTUR ILIN	{"phone": "+70205360702"}
0005433869216	8991D0	6196 061689	ANASTASIYA KUZNECOVA	{"phone": "+70428206666"}
0005433869217	8BE72A	2780 523761	MARINA IVANOVA	{"email": "marinaivanova.09121973@postgrespro.ru", "phone": "+70916898866"}
0005433869218	07B93F	9661 602841	NATALYA SIDOROVA	{"phone": "+70662761490"}
0005433869219	07B93F	9462 076145	IGOR FEDOROV	{"phone": "+70086127786"}
0005433869220	5451DB	9469 408410	NADEZHDA VOROBEVA	{"email": "vorobeva-nadezhda-02031973@postgrespro.ru", "phone": "+70693236059"}
0005433869221	5451DB	5452 208287	IVAN ILIN	{"phone": "+70442139880"}
0005433869222	747C77	7206 728127	MARGARITA KISELEVA	{"phone": "+70677436112"}
0005433869223	186B76	8276 952509	BOGDAN SEMENOV	{"email": "b.semenov.28121956@postgrespro.ru", "phone": "+70489402534"}
0005433869224	447D6B	6842 999722	MARIYA CHERNOVA	{"email": "mchernova_1959@postgrespro.ru", "phone": "+70637261862"}
0005433869225	F8132C	1027 482496	ANATOLIY KOROLEV	{"phone": "+70658761160"}
0005433869226	55C6E1	3159 997949	OLEG POPOV	{"email": "oleg.popov-111978@postgrespro.ru", "phone": "+70653750245"}
0005433869227	9B5B38	1533 909800	ROMAN SEMENOV	{"phone": "+70740657535"}
0005433869228	A5ECCA	4495 031461	OLGA KUDRYASHOVA	{"email": "kudryashova-o24111964@postgrespro.ru", "phone": "+70032242428"}
0005433869229	DE2751	2918 891189	PETR ALEKSEEV	{"phone": "+70829169671"}
0005433869230	049555	5801 181610	ALEKSANDR ANDREEV	{"email": "andreeva.061968@postgrespro.ru", "phone": "+70043365134"}
0005433869231	049555	9261 361561	MAKSIM KOZLOV	{"email": "mkozlov-17111973@postgrespro.ru", "phone": "+70810026197"}
0005433869232	AD40FD	3079 380450	POLINA IVANOVA	{"phone": "+70801940317"}
0005433869233	B875C6	0043 872988	VERONIKA KOLESNIKOVA	{"email": "kolesnikova.v-101971@postgrespro.ru", "phone": "+70981435921"}
0005433869234	B875C6	4765 629452	RUSTAM BELOV	{"email": "rbelov.28011981@postgrespro.ru", "phone": "+70563823097"}
0005433869235	2D28C5	6569 165837	DANIIL SIDOROV	{"email": "dsidorov.121974@postgrespro.ru", "phone": "+70160849435"}
0005433869236	543F34	5938 956064	IRINA KUZNECOVA	{"email": "kuznecovai031972@postgrespro.ru", "phone": "+70421420622"}
0005433869237	4C64A4	1561 923901	VYACHESLAV IVANOV	{"email": "ivanovv_1974@postgrespro.ru", "phone": "+70969500791"}
0005433869238	C35140	1941 354853	NIKOLAY VOROBEV	{"email": "vorobev-n1969@postgrespro.ru", "phone": "+70762337291"}
0005433869239	C35140	4196 832271	ALEKSANDR SOKOLOV	{"phone": "+70720665361"}
0005433869240	9B9D20	5779 415852	ELENA KUZNECOVA	{"email": "elena-kuznecova-101967@postgrespro.ru", "phone": "+70175037948"}
0005433869241	96B3F1	9905 156773	NATALYA EFIMOVA	{"email": "natalya_efimova_1970@postgrespro.ru", "phone": "+70665788390"}
0005433869242	96B3F1	5346 346567	DANIIL TIMOFEEV	{"phone": "+70762832374"}
0005433869243	96B3F1	3875 922676	NADEZHDA KARPOVA	{"email": "karpova_nadezhda-1988@postgrespro.ru", "phone": "+70797509521"}
0005433869244	7D93E5	8911 715298	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova-10101970@postgrespro.ru", "phone": "+70883104661"}
0005433869245	FD34B8	4375 603544	ALEKSEY KUZMIN	{"phone": "+70214987428"}
0005433869246	FD34B8	0450 062452	KLAVDIYA NAZAROVA	{"email": "nazarova_k101968@postgrespro.ru", "phone": "+70745657653"}
0005433869247	33D636	3162 965626	LYUDMILA MASLOVA	{"phone": "+70979620796"}
0005433869248	326F08	5620 386074	ANDREY DENISOV	{"phone": "+70855946091"}
0005433869249	326F08	8951 012407	ALEKSANDRA DANILOVA	{"phone": "+70347149833"}
0005433869250	B81127	1013 774998	LYUDMILA KUDRYASHOVA	{"email": "kudryashova_lyudmila_1976@postgrespro.ru", "phone": "+70108674078"}
0005433869251	2B6E8F	7419 869983	LIDIYA MATVEEVA	{"email": "l-matveeva-1962@postgrespro.ru", "phone": "+70464341540"}
0005433869252	C2666F	0192 638234	EVGENIY VOROBEV	{"email": "e.vorobev.061971@postgrespro.ru", "phone": "+70766282130"}
0005433869253	C2666F	5492 770963	ALEKSANDR VLASOV	{"phone": "+70911793127"}
0005433869254	899B63	7890 957719	NIKOLAY MARTYNOV	{"email": "nikolaymartynov-14121975@postgrespro.ru", "phone": "+70329270664"}
0005433869255	68D8AF	5024 924606	AYRAT KARPOV	{"email": "karpov_ayrat_1967@postgrespro.ru", "phone": "+70961150959"}
0005433869256	528069	3399 542342	YURIY ANTONOV	{"email": "antonov-yuriy-041978@postgrespro.ru", "phone": "+70757976113"}
0005433869257	C1AFE3	7389 986059	LARISA NOVIKOVA	{"email": "novikovalarisa_10091970@postgrespro.ru", "phone": "+70481931128"}
0005433869258	C1AFE3	9985 291004	VYACHESLAV GERASIMOV	{"email": "gerasimovvyacheslav071975@postgrespro.ru", "phone": "+70950562651"}
0005433869259	F65A21	2695 733195	MARINA OVCHINNIKOVA	{"email": "ovchinnikova_marina.021980@postgrespro.ru", "phone": "+70998123064"}
0005433869260	6BE826	2757 546663	NATALYA DANILOVA	{"phone": "+70547184244"}
0005433869261	9E2AE7	6850 606196	MAKSIM KAZAKOV	{"email": "kazakov-maksim.101983@postgrespro.ru", "phone": "+70527289285"}
0005433869262	9E2AE7	7130 744851	DMITRIY KUZNECOV	{"phone": "+70529643579"}
0005433869263	BCD926	3374 038493	NADEZHDA MAKAROVA	{"email": "makarova.nadezhda1965@postgrespro.ru", "phone": "+70350275424"}
0005433869264	7F9FC9	8886 922003	VERA BOGDANOVA	{"email": "verabogdanova.1970@postgrespro.ru", "phone": "+70312976325"}
0005433869265	94C736	8489 833502	MARGARITA NIKOLAEVA	{"email": "nikolaevam-081964@postgrespro.ru", "phone": "+70444451856"}
0005433869266	C74A57	8770 293938	LYUDMILA KUZNECOVA	{"phone": "+70374548115"}
0005433869267	24BB2C	0156 235206	VIKTOR SERGEEV	{"email": "v_sergeev-1974@postgrespro.ru", "phone": "+70817295185"}
0005433869268	5558E0	3259 332878	TATYANA NIKITINA	{"email": "tatyana.nikitina_051975@postgrespro.ru", "phone": "+70253335239"}
0005433869269	5558E0	7287 759628	EKATERINA IVANOVA	{"email": "ekaterina.ivanova.081979@postgrespro.ru", "phone": "+70742956496"}
0005433869270	5558E0	4903 796994	MAKSIM KOZLOV	{"email": "mkozlov-1981@postgrespro.ru", "phone": "+70446441935"}
0005433869271	AEEF95	7645 960784	EMILIYA NESTEROVA	{"email": "emiliyanesterova18051971@postgrespro.ru", "phone": "+70745787636"}
0005433869272	04A3C7	4231 598555	NADEZHDA VOLKOVA	{"phone": "+70108915739"}
0005433869273	04A3C7	1891 266675	ANNA ANDREEVA	{"phone": "+70057942656"}
0005433869274	D52F47	6650 510090	ALINA IVANOVA	{"email": "ivanovaa_05041983@postgrespro.ru", "phone": "+70811578954"}
0005433869275	D52F47	6806 574904	PETR MIKHAYLOV	{"email": "pmikhaylov-05041978@postgrespro.ru", "phone": "+70443798883"}
0005433869276	B384EE	2980 545708	SERGEY SHEVCHENKO	{"phone": "+70886902206"}
0005433869277	4C2309	9615 239358	VLADIMIR IVANOV	{"email": "ivanov-vladimir1984@postgrespro.ru", "phone": "+70485180391"}
0005433869278	4C2309	3259 682464	DMITRIY KULIKOV	{"email": "kulikov.d11111972@postgrespro.ru", "phone": "+70771183279"}
0005433869279	812BB9	9033 139541	EKATERINA VOROBEVA	{"email": "vorobevae.05031962@postgrespro.ru", "phone": "+70179850792"}
0005433869280	812BB9	3159 238095	TIMUR SAVELEV	{"email": "savelev-t.1972@postgrespro.ru", "phone": "+70918310383"}
0005433869281	4E8F78	3712 355653	YULIYA VOROBEVA	{"email": "vorobeva_y-071982@postgrespro.ru", "phone": "+70455673031"}
0005433869282	09B0FE	5599 644181	ELENA FROLOVA	{"email": "e.frolova_1964@postgrespro.ru", "phone": "+70328147050"}
0005433869283	BD7B46	3927 694813	BORIS IVANOV	{"phone": "+70180316411"}
0005433869284	F63D10	6583 694354	DMITRIY RODIONOV	{"email": "d_rodionov-1970@postgrespro.ru", "phone": "+70054189810"}
0005433869285	5855BE	2343 256018	VALENTINA KUZNECOVA	{"email": "kuznecovav_011975@postgrespro.ru", "phone": "+70664907344"}
0005433869286	5855BE	3304 051597	ALEKSANDRA NIKITINA	{"phone": "+70829983100"}
0005433869287	F5C002	2912 333538	REGINA NIKIFOROVA	{"email": "r.nikiforova-1972@postgrespro.ru", "phone": "+70742742367"}
0005433869288	815DDD	2618 772283	YULIYA IVANOVA	{"phone": "+70097445344"}
0005433869289	A03862	4094 376593	KONSTANTIN SOLOVEV	{"phone": "+70122380160"}
0005433869290	A03862	4088 193356	ALEKSEY NAZAROV	{"email": "nazarov.a_06071959@postgrespro.ru", "phone": "+70054726611"}
0005433869291	7A5F2A	6515 979135	ALEKSANDR NOVIKOV	{"phone": "+70362545260"}
0005433869292	B2ECAD	5996 462945	BORIS CHERNOV	{"email": "boris_chernov.21081971@postgrespro.ru", "phone": "+70915418650"}
0005433869293	29E0E0	5011 211932	OLGA FROLOVA	{"email": "o_frolova.12051972@postgrespro.ru", "phone": "+70415699314"}
0005433869294	2398B8	0284 735029	SERGEY SOKOLOV	{"email": "sergey.sokolov-27121964@postgrespro.ru", "phone": "+70137574569"}
0005433869295	AA8246	5641 514858	OLGA IVANOVA	{"email": "o-ivanova_1971@postgrespro.ru", "phone": "+70012489191"}
0005433869296	AA8246	7650 170559	ARTEM NAUMOV	{"email": "artem.naumov_051971@postgrespro.ru", "phone": "+70143746255"}
0005433869297	C4FE7A	9635 727097	SVETLANA ILINA	{"email": "s-ilina-1956@postgrespro.ru", "phone": "+70262481841"}
0005433869298	C4FE7A	7627 067825	VIKTOR MIKHAYLOV	{"email": "v.mikhaylov.22071966@postgrespro.ru", "phone": "+70952573622"}
0005433869299	4337AA	3946 958133	VLADISLAV SHEVCHENKO	{"phone": "+70994423511"}
0005433869300	E3DF6D	7310 857361	STANISLAV GUSEV	{"email": "stanislavgusev_1968@postgrespro.ru", "phone": "+70275798327"}
0005433869301	229BF6	5605 505329	EVGENIY ORLOV	{"email": "orlov-evgeniy-1976@postgrespro.ru", "phone": "+70957023761"}
0005433869302	BDA0DB	5478 956585	IVAN IVANOV	{"phone": "+70226936174"}
0005433869303	35B252	6915 098216	TATYANA KISELEVA	{"email": "kiselevatatyana.1958@postgrespro.ru", "phone": "+70245219038"}
0005433869304	35B252	6909 570891	ZULFIYA DMITRIEVA	{"phone": "+70879999613"}
0005433869305	E3FEDA	7382 639403	ELENA MIRONOVA	{"email": "elena-mironova.091976@postgrespro.ru", "phone": "+70112934254"}
0005433869306	93372A	3727 506197	DANILA TIKHONOV	{"phone": "+70045438065"}
0005433869307	507AC6	7721 602224	ALEKSANDR VASILEV	{"phone": "+70110884832"}
0005433869308	8EB9CB	9498 527906	LYUDMILA EGOROVA	{"email": "egorova.l.25051971@postgrespro.ru", "phone": "+70070230749"}
0005433869309	B5B995	4086 901478	KRISTINA FEDOROVA	{"phone": "+70292271232"}
0005433869310	B5B995	4898 851861	ANNA KAZAKOVA	{"phone": "+70823499515"}
0005433869311	BCFC3B	7485 188420	ELENA TIMOFEEVA	{"phone": "+70997495753"}
0005433869312	BCFC3B	5745 766520	KSENIYA STEPANOVA	{"phone": "+70335855128"}
0005433869313	9CC8CE	7430 719740	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov-1975@postgrespro.ru", "phone": "+70722343969"}
0005433869314	51E513	4936 073352	ELIZAVETA FROLOVA	{"email": "elizaveta_frolova_03071987@postgrespro.ru", "phone": "+70017472459"}
0005433869315	B2C396	8002 063149	VASILIY MAKAROV	{"email": "vasiliy-makarov.30051967@postgrespro.ru", "phone": "+70490759955"}
0005433869316	B2C396	5154 846628	VLADIMIR DENISOV	{"email": "vladimir.denisov_071974@postgrespro.ru", "phone": "+70282847429"}
0005433869317	531D25	6329 202377	LYUDMILA ANDREEVA	{"email": "andreevalyudmila-1965@postgrespro.ru", "phone": "+70533014173"}
0005433869318	71EE68	6275 476996	ANTON MAKAROV	{"email": "anton-makarov.1976@postgrespro.ru", "phone": "+70304014580"}
0005433869319	71EE68	1901 583889	SERGEY IVANOV	{"phone": "+70284416743"}
0005433869320	51D5B6	1749 444300	VIKTOR SOKOLOV	{"email": "viktorsokolov.1982@postgrespro.ru", "phone": "+70788563100"}
0005433869321	51D5B6	0539 634705	LYUDMILA RODIONOVA	{"email": "rodionova-l_041980@postgrespro.ru", "phone": "+70645517345"}
0005433869322	51D5B6	1297 673799	GENNADIY KUZMIN	{"phone": "+70653939023"}
0005433869323	E59C07	5019 170039	MARGARITA ORLOVA	{"email": "m-orlova.081976@postgrespro.ru", "phone": "+70972516600"}
0005433869324	FB4128	1319 353570	GALINA KARPOVA	{"phone": "+70553578121"}
0005433869325	238046	7764 495344	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-011971@postgrespro.ru", "phone": "+70408280128"}
0005433869326	705236	2201 649127	ELENA SOROKINA	{"email": "elena_sorokina.1982@postgrespro.ru", "phone": "+70411893778"}
0005433869327	5DF55A	0216 310613	VLADIMIR ZAYCEV	{"email": "zaycev_vladimir_1987@postgrespro.ru", "phone": "+70375620602"}
0005433869328	5DF55A	7036 711050	NIKOLAY SIDOROV	{"phone": "+70490722566"}
0005433869329	5DF55A	5690 646689	EVGENIY NAZAROV	{"phone": "+70106583848"}
0005433869330	941B6B	8301 849397	VALERIYA ABRAMOVA	{"email": "abramova.valeriya111979@postgrespro.ru", "phone": "+70646129019"}
0005433869331	941B6B	7283 328838	LYUDMILA MAKSIMOVA	{"phone": "+70820234032"}
0005433869332	512ACD	0969 683870	VALENTINA OVCHINNIKOVA	{"phone": "+70678364180"}
0005433869333	512ACD	5535 673913	DENIS MATVEEV	{"email": "matveev.d.071979@postgrespro.ru", "phone": "+70315989083"}
0005433869334	F962AC	2763 947614	VALENTINA ZAKHAROVA	{"email": "zakharova-valentina-071980@postgrespro.ru", "phone": "+70719043217"}
0005433869335	F962AC	7347 361095	MIROSLAV VLASOV	{"email": "miroslav_vlasov_121971@postgrespro.ru", "phone": "+70803209611"}
0005433869336	D7D1BF	7761 279132	NATALYA VASILEVA	{"email": "vasileva-natalya.19101962@postgrespro.ru", "phone": "+70005048818"}
0005433869337	D7D1BF	1368 193484	SERGEY FOMIN	{"email": "fomin_s_15021973@postgrespro.ru", "phone": "+70654009640"}
0005433869338	7D5FF9	8458 672396	MARINA LEBEDEVA	{"phone": "+70597454601"}
0005433869339	6E1265	9088 988515	SERGEY ALEKSANDROV	{"phone": "+70329821553"}
0005433869340	A9D82E	9426 321134	VLADIMIR NAUMOV	{"phone": "+70684257029"}
0005433869341	7EDDDE	8646 789601	ALIYA KUZNECOVA	{"email": "kuznecovaa1977@postgrespro.ru", "phone": "+70736917589"}
0005433869342	7EDDDE	5084 123261	DMITRIY SEMENOV	{"email": "d.semenov.15101966@postgrespro.ru", "phone": "+70114774651"}
0005433869343	50DD83	5230 619101	TATYANA MOROZOVA	{"email": "tatyana_morozova1981@postgrespro.ru", "phone": "+70948363218"}
0005433869344	50DD83	2849 899181	GALINA GRISHINA	{"phone": "+70731347172"}
0005433869345	ADFEFE	3309 430172	VYACHESLAV ILIN	{"phone": "+70183288978"}
0005433869346	82BB2A	6149 046362	MARIYA IVANOVA	{"email": "mariya_ivanova-1967@postgrespro.ru", "phone": "+70729804006"}
0005433869347	0E04E4	5145 720242	NIKOLAY VLASOV	{"email": "nikolay-vlasov071968@postgrespro.ru", "phone": "+70749990794"}
0005433869348	097AE3	8051 306718	SEMEN ZAKHAROV	{"phone": "+70697845825"}
0005433869349	B2E72A	1704 404534	TAMARA NAZAROVA	{"email": "tamaranazarova-041975@postgrespro.ru", "phone": "+70279592913"}
0005433869350	B2E72A	0677 996287	NIKOLAY NAUMOV	{"email": "naumov-n24061979@postgrespro.ru", "phone": "+70173601499"}
0005433869351	B4B28B	6155 374764	MIKHAIL KISELEV	{"email": "mikhail.kiselev-1981@postgrespro.ru", "phone": "+70676106984"}
0005433869352	31153D	3979 192890	OLEG OSIPOV	{"email": "osipov-o-16071967@postgrespro.ru", "phone": "+70144040960"}
0005433869353	31153D	9269 218385	DIANA GAVRILOVA	{"email": "d.gavrilova.23021967@postgrespro.ru", "phone": "+70607522475"}
0005433869354	ABD270	0191 078404	OLGA ALEKSEEVA	{"phone": "+70689697975"}
0005433869355	49B2EB	1119 558613	GENNADIY VOROBEV	{"phone": "+70165831377"}
0005433869356	4B85EE	1328 467642	LYUBOV KONOVALOVA	{"email": "konovalova.l-091972@postgrespro.ru", "phone": "+70540625214"}
0005433869357	3A61F2	4169 733061	NINA BARANOVA	{"phone": "+70491912758"}
0005433869358	AF2C54	5908 089665	GALINA FILIPPOVA	{"email": "galinafilippova25091976@postgrespro.ru", "phone": "+70626910639"}
0005433869359	373BAA	0908 932573	OLGA SOROKINA	{"phone": "+70740298765"}
0005433869360	B74BA1	2854 189622	IRINA MOISEEVA	{"email": "irinamoiseeva1974@postgrespro.ru", "phone": "+70119422150"}
0005433869361	B74BA1	7140 720850	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov.19021979@postgrespro.ru", "phone": "+70458640011"}
0005433869362	089D47	8336 178230	DMITRIY PETROV	{"email": "petrov-d_14121976@postgrespro.ru", "phone": "+70897261864"}
0005433869363	089D47	4576 416746	ALINA SOROKINA	{"email": "a.sorokina.06101968@postgrespro.ru", "phone": "+70705920278"}
0005433869364	15E8B2	3832 070641	OLGA SERGEEVA	{"email": "sergeeva.olga.21091974@postgrespro.ru", "phone": "+70237478619"}
0005433869365	15E8B2	3827 824537	YURIY EGOROV	{"email": "egorovyuriy-1976@postgrespro.ru", "phone": "+70361692078"}
0005433869366	5FDD8D	2433 928226	VLADIMIR SOKOLOV	{"phone": "+70540160690"}
0005433869367	14EE6A	5875 699759	SVETLANA POLYAKOVA	{"phone": "+70904763538"}
0005433869368	14EE6A	2487 489034	OLEG KOZLOV	{"phone": "+70646531542"}
0005433869369	4ACD3F	7975 077451	SERGEY FROLOV	{"phone": "+70859685128"}
0005433869370	4ACD3F	9400 552933	TATYANA SOLOVEVA	{"email": "tatyana.soloveva-18031963@postgrespro.ru", "phone": "+70705233368"}
0005433869371	1C89A5	1101 951233	ALEKSEY GRIGOREV	{"email": "grigorev_a101971@postgrespro.ru", "phone": "+70326510283"}
0005433869372	BB50A5	1048 302722	ALENA SIDOROVA	{"email": "sidorova.alena16111966@postgrespro.ru", "phone": "+70020902207"}
0005433869373	E1C81C	9208 902669	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr-15071963@postgrespro.ru", "phone": "+70792245532"}
0005433869374	930A08	1510 089243	TATYANA ARKHIPOVA	{"phone": "+70980099414"}
0005433869375	930A08	1442 003851	KSENIYA SOKOLOVA	{"email": "sokolova_kseniya-1968@postgrespro.ru", "phone": "+70431400200"}
0005433869376	C8BEFD	8415 729317	VALERIY SEMENOV	{"email": "valeriy.semenov.09101974@postgrespro.ru", "phone": "+70667032022"}
0005433869377	C8BEFD	8459 502745	NATALYA ZAKHAROVA	{"email": "natalya.zakharova-28091962@postgrespro.ru", "phone": "+70469394438"}
0005433869378	F4A0EB	9955 272498	NIKITA MAKSIMOV	{"phone": "+70438720960"}
0005433869379	8EDE60	6906 947258	NINA VLASOVA	{"phone": "+70626517689"}
0005433869380	172FB8	6800 428566	YULIYA PETROVA	{"email": "petrova.yuliya_111969@postgrespro.ru", "phone": "+70730210287"}
0005433869381	9818A8	2945 033151	NIKOLAY ISAEV	{"email": "isaev_nikolay031980@postgrespro.ru", "phone": "+70553552696"}
0005433869382	CD5B27	2058 606373	VERA NESTEROVA	{"phone": "+70920404151"}
0005433869383	CD5B27	8618 371124	TATYANA KUZNECOVA	{"phone": "+70426287900"}
0005433869384	27D29F	1829 221042	YURIY POPOV	{"phone": "+70619385844"}
0005433869385	ED332A	9479 265499	RAISA KONOVALOVA	{"phone": "+70766624936"}
0005433869386	ED332A	4860 450428	NATALYA EGOROVA	{"phone": "+70127205499"}
0005433869387	DC3CA3	5320 747971	ELENA DENISOVA	{"email": "elena_denisova1975@postgrespro.ru", "phone": "+70517487553"}
0005433869388	C78902	4630 265098	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir.16051966@postgrespro.ru", "phone": "+70171905345"}
0005433869389	EC35B2	9362 283315	VLADIMIR FOMIN	{"email": "vladimir-fomin1970@postgrespro.ru", "phone": "+70382741502"}
0005433869390	4A4B7C	7895 297591	LEONID SOKOLOV	{"phone": "+70900792646"}
0005433869391	4A4B7C	0779 038254	VERA FOMINA	{"email": "verafomina101962@postgrespro.ru", "phone": "+70849379614"}
0005433869392	66B2E1	5309 460251	VALERIYA ANTONOVA	{"email": "v-antonova23071968@postgrespro.ru", "phone": "+70810181137"}
0005433869393	35C05A	0384 948410	KONSTANTIN KUDRYASHOV	{"email": "k_kudryashov-08011972@postgrespro.ru", "phone": "+70622172085"}
0005433869394	9F384E	4570 777444	VLADIMIR IVANOV	{"email": "vladimirivanov_1968@postgrespro.ru", "phone": "+70663279047"}
0005433869395	98266C	6529 130766	DARYA KRASNOVA	{"phone": "+70098783374"}
0005433869396	8DE55E	1579 560992	LILIYA IVANOVA	{"phone": "+70914231478"}
0005433869397	EAB68A	9725 075981	DMITRIY KUDRYASHOV	{"phone": "+70904381545"}
0005433869398	CECE5C	2298 588745	NIKOLAY RODIONOV	{"email": "rodionovnikolay.041976@postgrespro.ru", "phone": "+70763163070"}
0005433869399	DB7856	2758 674808	LIDIYA STEPANOVA	{"email": "stepanova_l-12041978@postgrespro.ru", "phone": "+70668534564"}
0005433869400	162FA7	8524 897558	MAKSIM ALEKSEEV	{"phone": "+70661128301"}
0005433869401	162FA7	1312 983434	TIMUR FEDOROV	{"email": "fedorov-timur.1970@postgrespro.ru", "phone": "+70541385758"}
0005433869402	D1F093	3028 104028	SERGEY YAKOVLEV	{"email": "s_yakovlev_10021975@postgrespro.ru", "phone": "+70533544227"}
0005433869403	D1F093	2740 693791	ROMAN VLASOV	{"email": "roman_vlasov_051978@postgrespro.ru", "phone": "+70567332115"}
0005433869404	DBB9B5	3116 077711	IRINA KUZNECOVA	{"email": "kuznecova_i_041979@postgrespro.ru", "phone": "+70772025099"}
0005433869405	893E1E	8177 433300	TAMARA ANISIMOVA	{"email": "anisimova-t_1968@postgrespro.ru", "phone": "+70949923678"}
0005433869406	893E1E	1889 107290	ELENA BOGDANOVA	{"phone": "+70192301870"}
0005433869407	62D654	1967 330678	VALENTINA POPOVA	{"email": "popova_valentina13011965@postgrespro.ru", "phone": "+70239947073"}
0005433869408	62D654	0072 478286	VALENTINA NIKOLAEVA	{"email": "v.nikolaeva_20111973@postgrespro.ru", "phone": "+70249174574"}
0005433869409	2B1C64	8159 945283	MARIYA NOVIKOVA	{"email": "mnovikova1977@postgrespro.ru", "phone": "+70795208157"}
0005433869410	FBDF9E	0194 581157	VLADIMIR ALEKSEEV	{"email": "v.alekseev_1977@postgrespro.ru", "phone": "+70477862674"}
0005433869411	AFD59B	1741 231881	PAVEL GRIGOREV	{"email": "p-grigorev_021971@postgrespro.ru", "phone": "+70330930565"}
0005433869412	949849	5262 919123	ALEKSANDRA KUZNECOVA	{"email": "aleksandra_kuznecova23021970@postgrespro.ru", "phone": "+70012804398"}
0005433869413	445F1D	4787 450598	NATALYA VOROBEVA	{"email": "natalya-vorobeva-05081970@postgrespro.ru", "phone": "+70271284343"}
0005433869414	794048	6252 406412	EVGENIY TIKHONOV	{"email": "evgeniy.tikhonov_1970@postgrespro.ru", "phone": "+70885542972"}
0005433869415	236533	3376 075135	NATALYA MOISEEVA	{"phone": "+70590626643"}
0005433869416	236533	4598 464904	LYUDMILA KONOVALOVA	{"phone": "+70528529048"}
0005433869417	917CFB	3956 539792	IVAN NIKOLAEV	{"phone": "+70411419354"}
0005433869418	552409	1273 555912	SVETLANA ARKHIPOVA	{"phone": "+70213051389"}
0005433869419	28FE82	6557 228372	SVETLANA SEMENOVA	{"phone": "+70762354478"}
0005433869420	28FE82	6050 192583	TATYANA DMITRIEVA	{"phone": "+70794044551"}
0005433869421	3FC1CE	9778 084622	TAMARA GORBUNOVA	{"phone": "+70704148544"}
0005433869422	0C9532	7348 507018	TATYANA ROMANOVA	{"email": "tatyana_romanova_021978@postgrespro.ru", "phone": "+70476969662"}
0005433869423	04EE53	5815 395429	IVAN MAKSIMOV	{"phone": "+70978216431"}
0005433869424	04EE53	6395 333210	RUSTAM NIKITIN	{"email": "nikitin-rustam.081978@postgrespro.ru", "phone": "+70088130986"}
0005433869425	37B647	9857 629301	NATALYA POPOVA	{"email": "popovan-13011973@postgrespro.ru", "phone": "+70855203639"}
0005433869426	EDCF11	7228 616037	ELENA PETROVA	{"email": "elena.petrova-1958@postgrespro.ru", "phone": "+70979887132"}
0005433869427	256B48	5971 697797	ALEKSEY ALEKSANDROV	{"email": "aleksandrovaleksey08121961@postgrespro.ru", "phone": "+70715869639"}
0005433869428	256B48	4845 329605	ROMAN SOKOLOV	{"email": "rsokolov_24081975@postgrespro.ru", "phone": "+70601652933"}
0005433869429	63A4D6	6932 863790	ANNA ZOTOVA	{"email": "a_zotova-31081970@postgrespro.ru", "phone": "+70262472207"}
0005433869430	560243	3950 681228	VLADIMIR SCHERBAKOV	{"phone": "+70892834395"}
0005433869431	1A3347	6810 510525	NATALIYA NAUMOVA	{"phone": "+70403485440"}
0005433869432	1A3347	8417 590857	ELENA POTAPOVA	{"email": "elena_potapova.1978@postgrespro.ru", "phone": "+70887959658"}
0005433869433	822A9E	1116 091591	YURIY MOROZOV	{"email": "yuriy_morozov-1974@postgrespro.ru", "phone": "+70067341089"}
0005433869434	822A9E	7029 110250	ANTON PAVLOV	{"phone": "+70095526418"}
0005433869435	334576	4030 511801	VALERIY SMIRNOV	{"email": "v_smirnov.1973@postgrespro.ru", "phone": "+70404377762"}
0005433869436	0AC349	9475 850949	ARTEM ANDREEV	{"email": "andreev.artem1977@postgrespro.ru", "phone": "+70315651076"}
0005433869437	EBB594	6645 319196	IRINA KARPOVA	{"email": "irina.karpova.091973@postgrespro.ru", "phone": "+70910546616"}
0005433869438	BC36FA	0576 222984	DMITRIY SOKOLOV	{"email": "dmitriy-sokolov03021976@postgrespro.ru", "phone": "+70279332474"}
0005433869439	E14606	7374 185471	NELLI NIKITINA	{"phone": "+70529472226"}
0005433869440	E14606	8493 580053	NIKOLAY NIKITIN	{"email": "nikolay.nikitin.1963@postgrespro.ru", "phone": "+70036834100"}
0005433869441	E14606	2864 791284	VALENTINA ALEKSANDROVA	{"phone": "+70495322077"}
0005433869442	1DEEB0	8770 658486	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey_021986@postgrespro.ru", "phone": "+70770107879"}
0005433869443	E96363	2539 264532	OLGA MALYSHEVA	{"email": "malysheva_o_1986@postgrespro.ru", "phone": "+70208900413"}
0005433869444	853D31	4855 239906	ARTEM MELNIKOV	{"email": "artem.melnikov_061974@postgrespro.ru", "phone": "+70360213023"}
0005433869445	853D31	8666 027868	VLADIMIR IVANOV	{"phone": "+70779789904"}
0005433869446	2658BC	1065 423325	IRINA FOMINA	{"email": "irina.fomina-22111983@postgrespro.ru", "phone": "+70554091142"}
0005433869447	88357D	7787 489517	ALEKSEY SMIRNOV	{"phone": "+70783712943"}
0005433869448	E8E3F4	8312 371545	GALINA VLASOVA	{"email": "vlasova-galina1974@postgrespro.ru", "phone": "+70361267452"}
0005433869449	E8E3F4	1274 906867	ANNA POPOVA	{"email": "a.popova.21011975@postgrespro.ru", "phone": "+70168939298"}
0005433869450	E8E3F4	0830 564492	DARYA KUZNECOVA	{"phone": "+70736249274"}
0005433869451	E1C9B1	5003 793060	TAMARA KUZNECOVA	{"email": "tamara_kuznecova.041981@postgrespro.ru", "phone": "+70864184087"}
0005433869452	B3FC38	4012 590986	LYUBOV LUKYANOVA	{"email": "lukyanova_lyubov1971@postgrespro.ru", "phone": "+70637999278"}
0005433869453	DFBB42	6464 116923	SERGEY GRIGOREV	{"email": "grigorev_s.121971@postgrespro.ru", "phone": "+70617112855"}
0005433869454	F3BDC1	0580 076833	MIKHAIL KONOVALOV	{"phone": "+70670807392"}
0005433869455	9ADC39	0743 560616	SVETLANA FILATOVA	{"phone": "+70905208510"}
0005433869456	643832	8053 004174	TATYANA ORLOVA	{"phone": "+70571788243"}
0005433869457	E04788	6769 115813	SERGEY MIKHAYLOV	{"email": "mikhaylov-s08101979@postgrespro.ru", "phone": "+70055401095"}
0005433869458	D65916	3372 355293	ALEKSANDR KOROLEV	{"email": "korolevaleksandr.071964@postgrespro.ru", "phone": "+70282221656"}
0005433869459	14F801	1727 361930	ALFIYA FEDOROVA	{"email": "a-fedorova-17061967@postgrespro.ru", "phone": "+70681065022"}
0005433869460	14F801	4970 501902	OKSANA ISAEVA	{"phone": "+70165223232"}
0005433869461	7F79FF	3381 839742	MARSEL SERGEEV	{"phone": "+70752668936"}
0005433869462	7F79FF	4428 002288	NIKOLAY KUZNECOV	{"phone": "+70595738244"}
0005433869463	7F79FF	6733 540943	ARINA BOGDANOVA	{"phone": "+70665698771"}
0005433869464	F00D8F	9437 838119	YULIYA ANISIMOVA	{"phone": "+70527147293"}
0005433869465	C002F4	4785 205118	MAKSIM POPOV	{"phone": "+70769524757"}
0005433869466	5627A6	6457 806331	VIKTOR ALEKSANDROV	{"email": "aleksandrovviktor.1974@postgrespro.ru", "phone": "+70131819656"}
0005433869467	43619A	7600 218825	EGOR SOROKIN	{"email": "sorokin.egor01071974@postgrespro.ru", "phone": "+70385923966"}
0005433869468	C78341	2215 910821	NATALYA NIKIFOROVA	{"phone": "+70269494231"}
0005433869469	CCA2AF	3244 094854	MAKSIM GERASIMOV	{"email": "gerasimov_m_23021971@postgrespro.ru", "phone": "+70590624927"}
0005433869470	CCA2AF	4358 223572	SERGEY FEDOROV	{"phone": "+70180276862"}
0005433869471	11B9DD	4101 931541	KRISTINA GUSEVA	{"email": "guseva_k-30041978@postgrespro.ru", "phone": "+70995097175"}
0005433869472	EFED65	4811 658976	ROZA KUZMINA	{"email": "kuzmina.r061972@postgrespro.ru", "phone": "+70997060037"}
0005433869473	EEE145	5724 311501	YAROSLAV SCHERBAKOV	{"phone": "+70900665207"}
0005433869474	C34C56	8073 426263	KONSTANTIN NIKOLAEV	{"email": "nikolaev.konstantin.1987@postgrespro.ru", "phone": "+70706226589"}
0005433869475	B175DB	5632 528803	ROMAN SOKOLOV	{"phone": "+70466987305"}
0005433869476	B175DB	9124 691390	DMITRIY ALEKSEEV	{"phone": "+70831526181"}
0005433869477	3085C1	7347 817858	YURIY ZAKHAROV	{"phone": "+70549865666"}
0005433869478	77380E	2820 424277	ELIZAVETA SMIRNOVA	{"phone": "+70827322759"}
0005433869479	77380E	8610 441479	ALEKSANDR ISAEV	{"phone": "+70148372854"}
0005433869480	8EA35A	7210 007337	LEONID POPOV	{"email": "popovl_03021977@postgrespro.ru", "phone": "+70968241821"}
0005433869481	8EA35A	3693 934857	ALEKSANDR TIMOFEEV	{"phone": "+70942727141"}
0005433869482	86DE0C	8819 514536	ANASTASIYA YAKOVLEVA	{"email": "a-yakovleva.051976@postgrespro.ru", "phone": "+70536622014"}
0005433869483	86DE0C	5601 599733	TATYANA KUZNECOVA	{"email": "kuznecova-t11081970@postgrespro.ru", "phone": "+70016041916"}
0005433869484	86DE0C	5643 957803	ALEKSANDR POPOV	{"email": "a.popov.081969@postgrespro.ru", "phone": "+70075368988"}
0005433869485	F0CF47	6355 926083	KSENIYA KALININA	{"email": "kalinina-k081973@postgrespro.ru", "phone": "+70361972420"}
0005433869486	F0CF47	3951 451245	VALERIY MAKAROV	{"email": "makarov_v-1957@postgrespro.ru", "phone": "+70884538435"}
0005433869487	FFFC75	3669 360481	SERGEY ISAEV	{"email": "sergey-isaev.071970@postgrespro.ru", "phone": "+70721850289"}
0005433869488	06CF9D	4365 570106	DANIIL IVANOV	{"email": "daniil-ivanov_1973@postgrespro.ru", "phone": "+70154979923"}
0005433869489	FE6A24	9883 442438	KIRILL MAKAROV	{"phone": "+70115165257"}
0005433869490	8E189E	8756 306543	EDUARD KRASNOV	{"phone": "+70365085558"}
0005433869491	8E189E	2155 412582	ALEKSEY VLASOV	{"phone": "+70136768181"}
0005433869492	204F90	7021 916566	ALEKSANDRA NESTEROVA	{"phone": "+70923879607"}
0005433869493	25EB4B	5838 158585	IGOR ALEKSANDROV	{"email": "aleksandrov.igor.071976@postgrespro.ru", "phone": "+70286892410"}
0005433869494	25EB4B	5083 655096	TATYANA ZHURAVLEVA	{"email": "zhuravleva_t.09071969@postgrespro.ru", "phone": "+70460279342"}
0005433869495	D6CD2A	8313 904649	SERGEY ALEKSEEV	{"phone": "+70148328391"}
0005433869496	D6CD2A	5319 224507	SVETLANA SIDOROVA	{"email": "s_sidorova_1985@postgrespro.ru", "phone": "+70981203435"}
0005433869497	6DBA56	2161 047054	NADEZHDA ZHUKOVA	{"phone": "+70055705172"}
0005433869498	4FB9D2	4900 709740	MARIYA AKIMOVA	{"email": "akimova.m_01011974@postgrespro.ru", "phone": "+70292851533"}
0005433869499	7049D3	9702 309102	PAVEL NOVIKOV	{"email": "p-novikov18021984@postgrespro.ru", "phone": "+70046403403"}
0005433869500	F28BDE	1941 134559	NAIL CHERNOV	{"phone": "+70145275519"}
0005433869501	8BD33F	8910 949624	NATALYA KUZNECOVA	{"email": "kuznecova-natalya.031982@postgrespro.ru", "phone": "+70294702319"}
0005433869502	C20167	0865 963833	SERGEY POPOV	{"phone": "+70107828240"}
0005433869503	B7D651	4878 077682	VALENTINA SOLOVEVA	{"phone": "+70926574482"}
0005433869504	D6892C	3153 092370	IGOR ILIN	{"phone": "+70697631330"}
0005433869505	D6892C	8133 105876	NADEZHDA KALININA	{"email": "kalinina-n071973@postgrespro.ru", "phone": "+70015513518"}
0005433869506	3BFE22	3539 514315	LYUBOV IVANOVA	{"phone": "+70577872945"}
0005433869507	CABA67	4917 168373	ALEKSANDR KRASNOV	{"phone": "+70046091297"}
0005433869508	BBB885	9704 745547	OLEG MAKSIMOV	{"email": "omaksimov10081975@postgrespro.ru", "phone": "+70129691660"}
0005433869509	6FFEF2	8097 739376	ILYA MIKHAYLOV	{"email": "i.mikhaylov.09081981@postgrespro.ru", "phone": "+70868666918"}
0005433869510	6FFEF2	9972 383023	NADEZHDA SCHERBAKOVA	{"phone": "+70434063394"}
0005433869511	D3C989	2667 013047	LYUDMILA OVCHINNIKOVA	{"email": "lovchinnikova_10011970@postgrespro.ru", "phone": "+70413264342"}
0005433869512	D3C989	1092 132893	NIKOLAY IVANOV	{"email": "ivanovnikolay-021963@postgrespro.ru", "phone": "+70668135011"}
0005433869513	6C1FCF	8672 528682	NATALYA DENISOVA	{"email": "denisova_n.111972@postgrespro.ru", "phone": "+70262204079"}
0005433869514	B67BC3	3374 438764	SOFYA BARANOVA	{"phone": "+70181995365"}
0005433869515	727300	3746 426271	SERGEY SERGEEV	{"phone": "+70880374636"}
0005433869516	8183D5	3397 143238	SERGEY KAZAKOV	{"phone": "+70498848290"}
0005433869517	8183D5	0484 104060	GALINA ALEKSEEVA	{"email": "alekseeva.galina_1973@postgrespro.ru", "phone": "+70549546125"}
0005433869518	18447C	3192 506719	VIKTOR IVANOV	{"email": "v.ivanov-04091962@postgrespro.ru", "phone": "+70363952052"}
0005433869519	4ED14D	5850 774886	DENIS DENISOV	{"email": "denis.denisov_081977@postgrespro.ru", "phone": "+70751145648"}
0005433869520	017159	9713 944069	YURIY ROMANOV	{"phone": "+70628507034"}
0005433869521	017159	4853 870583	ELENA BELYAEVA	{"email": "belyaeva-e-081971@postgrespro.ru", "phone": "+70222323015"}
0005433869522	78CFDE	2594 743633	TATYANA LAZAREVA	{"email": "tatyana.lazareva_1970@postgrespro.ru", "phone": "+70096096943"}
0005433869523	DBEF0F	5159 702650	ALEKSEY STEPANOV	{"phone": "+70211974068"}
0005433869524	EE5C83	7153 339194	MIKHAIL FEDOROV	{"email": "m-fedorov_14121977@postgrespro.ru", "phone": "+70726410434"}
0005433869525	4EC505	4723 757089	ANDREY SEMENOV	{"phone": "+70115749388"}
0005433869526	4EC505	9482 531207	NATALYA TIKHONOVA	{"phone": "+70794322946"}
0005433869527	C9279C	0360 157246	PAVEL NIKITIN	{"email": "pavel-nikitin-26061982@postgrespro.ru", "phone": "+70427397569"}
0005433869528	C9279C	2503 148061	ALEKSANDR IVANOV	{"email": "a-ivanov_08021965@postgrespro.ru", "phone": "+70656099339"}
0005433869529	8599EB	1962 373349	ARTEM BELOV	{"email": "belovartem041976@postgrespro.ru", "phone": "+70336584599"}
0005433869530	76785C	4886 349538	IRINA VASILEVA	{"phone": "+70093369038"}
0005433869531	69E99F	7978 644643	VALENTINA NOVIKOVA	{"email": "valentina-novikova.051977@postgrespro.ru", "phone": "+70904469286"}
0005433869532	2E9BFF	6237 171880	IRINA ROMANOVA	{"phone": "+70054845922"}
0005433869533	FBD838	6322 416503	ALEKSANDR FEDOROV	{"phone": "+70988845003"}
0005433869534	FBD838	9503 088640	ULYANA IVANOVA	{"phone": "+70743066369"}
0005433869535	0693FE	4059 280302	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov_24121983@postgrespro.ru", "phone": "+70655041195"}
0005433869536	0693FE	7973 334985	ILYA MELNIKOV	{"phone": "+70274543148"}
0005433869537	8EF568	4166 542000	ALEKSEY ISAEV	{"phone": "+70570217212"}
0005433869538	41C165	2616 602973	VLADIMIR CHERNOV	{"phone": "+70653139566"}
0005433869539	F43095	8248 713265	SVETLANA KISELEVA	{"phone": "+70919672053"}
0005433869540	F43095	2167 969348	POLINA LAZAREVA	{"phone": "+70557151238"}
0005433869541	71C517	3651 196265	IRINA RYABOVA	{"phone": "+70933284256"}
0005433869542	348ACC	8930 297391	EVGENIYA POPOVA	{"email": "e.popova_021975@postgrespro.ru", "phone": "+70471083613"}
0005433869543	348ACC	4059 824033	RAISA EFIMOVA	{"email": "efimovaraisa-061963@postgrespro.ru", "phone": "+70451360030"}
0005433869544	AF50B1	8380 997322	VALERIY KISELEV	{"phone": "+70695781110"}
0005433869545	ED7572	6104 795682	YANA MOISEEVA	{"phone": "+70388457447"}
0005433869546	5CAD57	6528 079510	ALLA EFIMOVA	{"email": "efimovaalla19081978@postgrespro.ru", "phone": "+70514311893"}
0005433869547	6A4A0E	4816 974420	SERGEY IVANOV	{"phone": "+70684412694"}
0005433869548	4ED68D	4126 617361	VERA GRISHINA	{"phone": "+70439854522"}
0005433869549	4ED68D	7816 163434	KONSTANTIN KISELEV	{"phone": "+70385637246"}
0005433869550	56BA52	4261 320162	VASILIY IVANOV	{"phone": "+70839513440"}
0005433869551	56BA52	3501 538908	PAVEL MAKAROV	{"email": "makarov_pavel-1978@postgrespro.ru", "phone": "+70403695532"}
0005433869552	8C2AC7	6046 482704	MARIYA ANDREEVA	{"email": "mariya.andreeva.07021971@postgrespro.ru", "phone": "+70535645011"}
0005433869553	84A8E5	0464 776685	ASKAR SOROKIN	{"phone": "+70893517836"}
0005433869554	84A8E5	0419 586512	OLEG BELOV	{"phone": "+70825974767"}
0005433869555	537F15	0479 716624	DMITRIY BONDARENKO	{"email": "bondarenkod-18051976@postgrespro.ru", "phone": "+70025551743"}
0005433869556	177967	5229 962930	ANNA DAVYDOVA	{"phone": "+70053210654"}
0005433869557	E9AB32	2306 676855	YULIYA FEDOROVA	{"email": "y_fedorova1978@postgrespro.ru", "phone": "+70569894925"}
0005433869558	4464EC	7185 944276	ANNA SERGEEVA	{"email": "sergeevaanna_071974@postgrespro.ru", "phone": "+70620151821"}
0005433869559	4464EC	0723 221973	EVGENIYA GUSEVA	{"email": "guseva_e-20111967@postgrespro.ru", "phone": "+70214147245"}
0005433869560	4464EC	1734 358459	ANDREY KOROLEV	{"phone": "+70632001530"}
0005433869561	5538F1	3392 808345	VITALIY SOROKIN	{"email": "v_sorokin.1970@postgrespro.ru", "phone": "+70587854947"}
0005433869562	5538F1	4930 197525	VALENTINA POPOVA	{"phone": "+70037049255"}
0005433869563	49C35F	3174 247883	SERGEY BARANOV	{"phone": "+70745779878"}
0005433869564	30AB14	0417 733084	TATYANA FILIPPOVA	{"phone": "+70122353041"}
0005433869565	BC1B52	3808 200555	ANASTASIYA NESTEROVA	{"email": "a_nesterova021975@postgrespro.ru", "phone": "+70858899458"}
0005433869566	273E07	3274 803886	ANTON KONOVALOV	{"email": "a_konovalov021969@postgrespro.ru", "phone": "+70481338536"}
0005433869567	273E07	5937 374175	ALEKSANDR MOROZOV	{"email": "aleksandr-morozov061972@postgrespro.ru", "phone": "+70997943100"}
0005433869568	9D29A8	4790 659601	ALEKSANDR KUZMIN	{"phone": "+70720188528"}
0005433869569	786A14	1286 901330	GALINA KUDRYASHOVA	{"email": "kudryashovag_1977@postgrespro.ru", "phone": "+70103157675"}
0005433869570	F278B0	0687 704680	TAMARA BORISOVA	{"phone": "+70780391383"}
0005433869571	2746EC	1594 551912	MARINA DENISOVA	{"email": "marina.denisova-101987@postgrespro.ru", "phone": "+70414993958"}
0005433869572	A2688E	4356 102965	ILYA MEDVEDEV	{"phone": "+70405397182"}
0005433869573	4FFD67	1773 548788	ANASTASIYA KUZNECOVA	{"email": "a_kuznecova1978@postgrespro.ru", "phone": "+70453568428"}
0005433869574	932018	2153 193327	VERA MOROZOVA	{"email": "v_morozova111976@postgrespro.ru", "phone": "+70387053482"}
0005433869575	932018	0440 981804	VLADIMIR KUZMIN	{"email": "kuzmin_v-10051977@postgrespro.ru", "phone": "+70802491338"}
0005433869576	142749	7195 910140	YURIY NAUMOV	{"phone": "+70698595111"}
0005433869577	5F7161	3674 214697	YAROSLAV BARANOV	{"phone": "+70348330866"}
0005433869578	5F7161	7075 434910	BORIS KUDRYASHOV	{"email": "kudryashov.boris-091978@postgrespro.ru", "phone": "+70678304538"}
0005433869579	5F7161	1345 753753	RAISA PAVLOVA	{"phone": "+70108196901"}
0005433869580	5A9589	3328 218762	ANDREY KULIKOV	{"email": "andrey-kulikov-101979@postgrespro.ru", "phone": "+70346432446"}
0005433869581	3559CF	5328 287910	NATALYA SOROKINA	{"phone": "+70232605869"}
0005433869582	3559CF	2468 884096	ANNA NAUMOVA	{"phone": "+70167426923"}
0005433869583	9F021A	3383 288734	ALEKSANDR NAZAROV	{"email": "nazarov-a.081963@postgrespro.ru", "phone": "+70712273168"}
0005433869584	6B69E0	6209 388067	ALEKSEY GRIGOREV	{"email": "grigorev-aleksey_021976@postgrespro.ru", "phone": "+70111173689"}
0005433869585	611BC4	6971 451154	ALEKSEY MELNIKOV	{"email": "amelnikov08041967@postgrespro.ru", "phone": "+70114038966"}
0005433869586	1DA8CA	8531 258778	ALEKSANDR MELNIKOV	{"email": "melnikov-a051960@postgrespro.ru", "phone": "+70616059130"}
0005433869587	1DA8CA	0695 137173	NADEZHDA NOVIKOVA	{"phone": "+70441336133"}
0005433869588	584416	7465 956643	NADEZHDA ANDREEVA	{"email": "n.andreeva-22091977@postgrespro.ru", "phone": "+70499485551"}
0005433869589	F39CD2	5206 179193	OLGA FADEEVA	{"phone": "+70568614131"}
0005433869590	AB8BB0	4365 021833	VALENTINA KRASNOVA	{"email": "v-krasnova-10111973@postgrespro.ru", "phone": "+70884275876"}
0005433869591	043551	1416 549706	ANTONINA KONDRATEVA	{"phone": "+70496854798"}
0005433869592	B84098	5384 116745	VALENTINA VLASOVA	{"phone": "+70674006654"}
0005433869593	B4A83F	6682 847746	EVGENIY GUSEV	{"email": "e.gusev-03071969@postgrespro.ru", "phone": "+70550055249"}
0005433869594	B4A83F	1191 386463	NADEZHDA ILINA	{"email": "nadezhda.ilina_1966@postgrespro.ru", "phone": "+70987297239"}
0005433869595	B4A83F	7992 524151	DENIS EGOROV	{"phone": "+70858045063"}
0005433869596	CF0992	0598 777109	SERGEY IVANOV	{"email": "ivanov.s_011987@postgrespro.ru", "phone": "+70531939646"}
0005433869597	95E7AC	3548 391195	SERGEY ORLOV	{"phone": "+70815192486"}
0005433869598	2EBC30	1815 753975	ALEKSANDR SEMENOV	{"phone": "+70220324786"}
0005433869599	8A1273	3531 981102	VALENTINA FROLOVA	{"email": "frolova-valentina.051976@postgrespro.ru", "phone": "+70830885913"}
0005433869600	C065BD	7614 893750	SERGEY PAVLOV	{"phone": "+70124618772"}
0005433869601	7FC415	4620 806197	SVETLANA SOLOVEVA	{"email": "soloveva_s-121971@postgrespro.ru", "phone": "+70737817328"}
0005433869602	DFC278	7327 649957	ELENA MALYSHEVA	{"email": "elena_malysheva.101977@postgrespro.ru", "phone": "+70770189715"}
0005433869603	99C7A3	5742 442380	VIKTOR EGOROV	{"email": "egorovviktor1978@postgrespro.ru", "phone": "+70982398907"}
0005433869604	88902A	0178 821704	RAUF MIRONOV	{"phone": "+70917349718"}
0005433869605	88902A	7462 483230	MIKHAIL VOROBEV	{"phone": "+70691980564"}
0005433869606	4D5BD5	0192 806167	DARYA KUZMINA	{"email": "kuzmina_d.041961@postgrespro.ru", "phone": "+70814309119"}
0005433869607	4D5BD5	2452 876331	YULIYA KOZLOVA	{"email": "y_kozlova.1984@postgrespro.ru", "phone": "+70639730193"}
0005433869608	6124C0	9271 376478	OLEG SOKOLOV	{"phone": "+70351572278"}
0005433869609	AD81C4	3713 120156	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev.20061981@postgrespro.ru", "phone": "+70147568368"}
0005433869610	AD81C4	7330 853588	EKATERINA SEMENOVA	{"email": "semenova_ekaterina_07041972@postgrespro.ru", "phone": "+70476353091"}
0005433869611	AD81C4	7887 431313	EVGENIY POPOV	{"phone": "+70509849128"}
0005433869612	BAEDD9	7183 278687	ZINAIDA VASILEVA	{"email": "zinaida.vasileva.111976@postgrespro.ru", "phone": "+70679005469"}
0005433869613	BAEDD9	2307 995895	IRINA ROMANOVA	{"email": "romanova.irina1974@postgrespro.ru", "phone": "+70073747810"}
0005433869614	275159	6973 023066	ELENA SEMENOVA	{"email": "elenasemenova_111977@postgrespro.ru", "phone": "+70305978211"}
0005433869615	8ECF1A	3308 033557	TATYANA KUZNECOVA	{"email": "t-kuznecova.051967@postgrespro.ru", "phone": "+70800140247"}
0005433869616	E69C34	6146 777984	TATYANA SOROKINA	{"phone": "+70906405259"}
0005433869617	E69C34	6675 754209	PETR ANDREEV	{"phone": "+70792679115"}
0005433870691	7142A8	5622 983260	ROMAN VASILEV	{"email": "vasilevr-17021979@postgrespro.ru", "phone": "+70011755721"}
0005433870692	7142A8	2972 256280	ZINAIDA CHERNOVA	{"email": "chernova.zinaida-1963@postgrespro.ru", "phone": "+70842915643"}
0005433870693	855662	3156 139186	ILYA SHEVCHENKO	{"email": "shevchenko-ilya.1968@postgrespro.ru", "phone": "+70572149284"}
0005433870694	855662	0508 917498	NATALIYA ANDREEVA	{"phone": "+70620021287"}
0005433870695	8B7BE8	8543 135702	MARINA PETROVA	{"phone": "+70407719933"}
0005433870696	329452	6232 900349	VALERIY SOKOLOV	{"email": "v_sokolov28051975@postgrespro.ru", "phone": "+70455572883"}
0005433870697	329452	5657 830291	ALSU KARPOVA	{"email": "alsu_karpova_22031980@postgrespro.ru", "phone": "+70932859869"}
0005433870698	329452	4324 104519	ANATOLIY MAKAROV	{"email": "makarov_anatoliy-1964@postgrespro.ru", "phone": "+70488473366"}
0005433870699	81CF7A	5090 622311	EVGENIY SMIRNOV	{"phone": "+70931180665"}
0005433870700	AA348B	3780 130716	SERGEY IVANOV	{"email": "ivanov_s041967@postgrespro.ru", "phone": "+70258618747"}
0005433870701	62248E	6792 699728	EVDOKIYA POPOVA	{"email": "e-popova_1975@postgrespro.ru", "phone": "+70053884953"}
0005433870702	62248E	7952 067722	PAVEL KUZNECOV	{"phone": "+70685336518"}
0005433870703	9510F1	9342 288760	MARIYA ZHUKOVA	{"phone": "+70843547161"}
0005433870704	9510F1	6739 808183	EVGENIY SOLOVEV	{"email": "solovev-e.051968@postgrespro.ru", "phone": "+70749025544"}
0005433870705	34D79B	2832 946775	NATALYA BORISOVA	{"email": "borisova_natalya_1977@postgrespro.ru", "phone": "+70680264386"}
0005433870706	34D79B	4240 963150	LYUDMILA ALEKSEEVA	{"email": "lyudmila_alekseeva.10081967@postgrespro.ru", "phone": "+70192175213"}
0005433870707	681FA4	3078 096195	EKATERINA MEDVEDEVA	{"email": "e.medvedeva-29081967@postgrespro.ru", "phone": "+70811635874"}
0005433870708	B9B6FF	4455 979026	MARIYA BORISOVA	{"email": "borisova_mariya.061972@postgrespro.ru", "phone": "+70187437938"}
0005433870709	3587CA	0426 295020	ALEKSANDRA VASILEVA	{"phone": "+70563714813"}
0005433870710	5F5157	0205 352220	ANTONINA SMIRNOVA	{"email": "smirnova_antonina-26121965@postgrespro.ru", "phone": "+70125971870"}
0005433870711	7567DE	7914 169249	ARINA ZHURAVLEVA	{"email": "a.zhuravleva.11041966@postgrespro.ru", "phone": "+70701708638"}
0005433870712	7567DE	8914 878785	ALEKSANDRA ORLOVA	{"email": "aleksandraorlova1973@postgrespro.ru", "phone": "+70853968915"}
0005433870713	335F68	7295 746553	SERGEY NOVIKOV	{"phone": "+70955613567"}
0005433870714	10CE6F	1802 598154	TATYANA ANISIMOVA	{"phone": "+70481313390"}
0005433870715	10CE6F	9331 831509	VALERIY FILIPPOV	{"email": "valeriy-filippov_17061970@postgrespro.ru", "phone": "+70544531463"}
0005433870716	57BA9D	5217 244838	DARYA POLYAKOVA	{"email": "d-polyakova031962@postgrespro.ru", "phone": "+70784147076"}
0005433870717	35123A	0979 053597	ALEKSEY STEPANOV	{"email": "a.stepanov.19071966@postgrespro.ru", "phone": "+70122494504"}
0005433870718	53D340	7343 179038	DENIS KULIKOV	{"email": "kulikov_d-1969@postgrespro.ru", "phone": "+70650461827"}
0005433870719	53D340	4889 628697	KIRILL VOROBEV	{"phone": "+70532561702"}
0005433870720	227435	8155 764478	TAMARA SMIRNOVA	{"phone": "+70224947662"}
0005433870721	DD210D	4038 115714	SERGEY NIKITIN	{"email": "nikitin-sergey011971@postgrespro.ru", "phone": "+70099834958"}
0005433870722	DD210D	7275 011919	ZINAIDA MAKSIMOVA	{"email": "maksimovaz_1970@postgrespro.ru", "phone": "+70262272319"}
0005433870723	5B1BFE	9918 424068	ARTEM PETROV	{"email": "petrovartem061985@postgrespro.ru", "phone": "+70816440072"}
0005433870724	7C452E	3133 989910	LEV BARANOV	{"phone": "+70262990953"}
0005433870725	2320C7	9734 933084	TATYANA MARTYNOVA	{"email": "martynova-tatyana_1982@postgrespro.ru", "phone": "+70106233316"}
0005433870726	3221F3	7306 364047	SVETLANA ROMANOVA	{"phone": "+70275105147"}
0005433870727	DF27A8	5802 051176	TATYANA DAVYDOVA	{"email": "tatyana-davydova29021964@postgrespro.ru", "phone": "+70421663647"}
0005433870728	DF27A8	8639 993761	VADIM MATVEEV	{"email": "matveevvadim1980@postgrespro.ru", "phone": "+70294902836"}
0005433870729	1A9C0E	0515 154396	DARYA MAKAROVA	{"email": "daryamakarova.111975@postgrespro.ru", "phone": "+70576813632"}
0005433870730	1A9C0E	6327 402822	IRINA LUKYANOVA	{"email": "ilukyanova-17081975@postgrespro.ru", "phone": "+70539535886"}
0005433870731	D7BA46	2777 771483	VIKTOR MIKHAYLOV	{"email": "viktor.mikhaylov-22061974@postgrespro.ru", "phone": "+70710950503"}
0005433870732	E9346E	3316 930187	OLEG KUZNECOV	{"phone": "+70152820895"}
0005433870733	E9346E	0817 181083	ALEKSANDR EGOROV	{"phone": "+70409957459"}
0005433870734	46685B	4432 220408	VALENTINA VLASOVA	{"email": "v.vlasova-1976@postgrespro.ru", "phone": "+70004763885"}
0005433870735	46685B	0762 598031	NADEZHDA VASILEVA	{"phone": "+70908080340"}
0005433870736	D90852	3326 112025	ALEKSANDR FOMIN	{"phone": "+70940539661"}
0005433870737	D90852	3121 329633	RIMMA FOMINA	{"email": "rimma.fomina-061965@postgrespro.ru", "phone": "+70138047812"}
0005433870738	F420D4	0030 453470	NADEZHDA IVANOVA	{"phone": "+70743055129"}
0005433870739	D45675	6363 404705	ANNA YAKOVLEVA	{"phone": "+70121447632"}
0005433870740	0390C2	2146 907926	YURIY VOLKOV	{"email": "volkov_y.24041961@postgrespro.ru", "phone": "+70679703472"}
0005433870741	0390C2	3268 068960	LIDIYA SEMENOVA	{"email": "semenova_l_1982@postgrespro.ru", "phone": "+70556391135"}
0005433870742	454CBC	1532 913804	ANDREY FOMIN	{"phone": "+70692581598"}
0005433870743	B92595	7440 962121	ANTONINA KUDRYASHOVA	{"email": "a_kudryashova1986@postgrespro.ru", "phone": "+70812673780"}
0005433870744	F7DD35	7178 947151	NATALIYA ERMAKOVA	{"email": "ermakova_nataliya08011971@postgrespro.ru", "phone": "+70978676267"}
0005433870745	A426EA	0111 963408	TATYANA MOROZOVA	{"email": "morozova-t1981@postgrespro.ru", "phone": "+70218000795"}
0005433870746	F2AA41	8329 470744	PETR IVANOV	{"phone": "+70751268494"}
0005433870747	9DBB51	9519 366400	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev-021977@postgrespro.ru", "phone": "+70288656119"}
0005433870748	4F0375	9317 170215	SVETLANA FILATOVA	{"email": "s-filatova26101973@postgrespro.ru", "phone": "+70445576218"}
0005433870749	382363	8699 142656	DMITRIY KUDRYASHOV	{"email": "kudryashov_dmitriy-02061965@postgrespro.ru", "phone": "+70199124193"}
0005433870750	8CFDA9	0471 903263	YURIY SOKOLOV	{"email": "sokolov_y-1970@postgrespro.ru", "phone": "+70979150161"}
0005433870751	1A4F57	0518 417554	ANTON SHEVCHENKO	{"phone": "+70543582380"}
0005433870752	9D5F0A	3150 732633	RAISA YAKOVLEVA	{"phone": "+70886091193"}
0005433870753	A12B6A	4927 713106	ANATOLIY ORLOV	{"email": "orlovanatoliy-1970@postgrespro.ru", "phone": "+70209380570"}
0005433870754	5A11CA	7430 039563	MARIYA PAVLOVA	{"phone": "+70431084295"}
0005433870755	3E3031	2007 689933	KSENIYA POLYAKOVA	{"email": "k_polyakova_1965@postgrespro.ru", "phone": "+70087872664"}
0005433870756	3E3031	9822 600836	GALINA DMITRIEVA	{"phone": "+70360901175"}
0005433870757	3F114D	1923 438527	ANDREY KARPOV	{"phone": "+70210597164"}
0005433870758	0410C9	1040 354898	ANNA MOISEEVA	{"email": "moiseeva_anna-1976@postgrespro.ru", "phone": "+70228029245"}
0005433870759	CE922A	1718 168244	YURIY SHEVCHENKO	{"phone": "+70383172736"}
0005433870760	CE922A	3356 227409	MIKHAIL PAVLOV	{"phone": "+70207459677"}
0005433870761	0AE7F9	7735 678798	IRINA SEMENOVA	{"phone": "+70643610215"}
0005433870762	A83DE3	9665 387198	SOFYA MIKHAYLOVA	{"email": "s.mikhaylova1974@postgrespro.ru", "phone": "+70214707647"}
0005433870763	65BBB7	7060 129053	VLADISLAV KONOVALOV	{"email": "konovalov-vladislav-07091956@postgrespro.ru", "phone": "+70067145950"}
0005433870764	31B281	2302 244182	OLEG SEMENOV	{"email": "o_semenov10051965@postgrespro.ru", "phone": "+70275490517"}
0005433870765	11DF20	6396 969438	VITALIY SIDOROV	{"email": "vsidorov-07051962@postgrespro.ru", "phone": "+70609330985"}
0005433870766	67C8C3	0215 771227	NATALIYA VOLKOVA	{"phone": "+70833867784"}
0005433870767	AEE838	4105 756420	ANGELINA IVANOVA	{"phone": "+70860447320"}
0005433870768	D20159	0257 375193	LYUDMILA ABRAMOVA	{"phone": "+70649768988"}
0005433870769	D20159	8701 571642	VADIM RODIONOV	{"email": "rodionov_vadim-041967@postgrespro.ru", "phone": "+70311472421"}
0005433870770	57CAA6	0682 030797	IRINA TARASOVA	{"phone": "+70698767374"}
0005433870771	417CEE	2984 601264	ALEKSANDR TIMOFEEV	{"email": "aleksandr-timofeev101960@postgrespro.ru", "phone": "+70672418662"}
0005433870772	5A2D39	2373 117268	ALENA SERGEEVA	{"email": "sergeevaa_1966@postgrespro.ru", "phone": "+70785510546"}
0005433870773	DDC4F2	9939 235952	EVGENIY NIKOLAEV	{"email": "nikolaeve.08081979@postgrespro.ru", "phone": "+70931970866"}
0005433870774	DDC4F2	3738 263913	ANASTASIYA EGOROVA	{"phone": "+70021887624"}
0005433870775	DDC4F2	6805 871021	SVETLANA EGOROVA	{"email": "egorova.svetlana1979@postgrespro.ru", "phone": "+70963210063"}
0005433870776	C198F0	3361 954139	ANDREY BORISOV	{"email": "a.borisov_091969@postgrespro.ru", "phone": "+70577601685"}
0005433870777	F5AFD3	1470 756150	NATALYA EGOROVA	{"phone": "+70077514838"}
0005433870778	F5AFD3	4329 067719	YURIY PETROV	{"phone": "+70401532755"}
0005433870779	15493E	0955 911174	MAKSIM SERGEEV	{"phone": "+70667159013"}
0005433870780	E9490A	9963 535105	KARINA SOLOVEVA	{"email": "k-soloveva.1968@postgrespro.ru", "phone": "+70911982099"}
0005433870781	85CB99	6755 012593	EVGENIY ABRAMOV	{"email": "abramov_evgeniy.15121969@postgrespro.ru", "phone": "+70327291654"}
0005433870782	2738BB	8084 991558	OLEG NIKITIN	{"phone": "+70992566168"}
0005433870783	2738BB	8648 452996	ILYA ILIN	{"phone": "+70187944393"}
0005433870784	2738BB	7007 403247	SVETLANA KISELEVA	{"phone": "+70814884980"}
0005433870785	87A9AF	1449 063754	OLGA TIMOFEEVA	{"email": "olga.timofeeva.29071979@postgrespro.ru", "phone": "+70276784508"}
0005433870786	78080B	0618 070420	BORIS KUZNECOV	{"email": "boris-kuznecov_14111958@postgrespro.ru", "phone": "+70936911539"}
0005433870787	78080B	9377 743209	LYUDMILA ALEKSANDROVA	{"phone": "+70598217823"}
0005433870788	78080B	8441 543846	VIKTOR MIRONOV	{"email": "v_mironov041975@postgrespro.ru", "phone": "+70727514646"}
0005433870789	9A18C2	7865 165645	NATALYA KULIKOVA	{"email": "n_kulikova_011979@postgrespro.ru", "phone": "+70723115102"}
0005433870790	2FD777	5478 718220	TATYANA TROFIMOVA	{"phone": "+70867800366"}
0005433870791	9825B6	9494 061841	MARIYA BOGDANOVA	{"email": "bogdanovamariya_09091977@postgrespro.ru", "phone": "+70660136483"}
0005433870792	9825B6	6495 594828	VLADISLAV DAVYDOV	{"email": "vladislav.davydov.071980@postgrespro.ru", "phone": "+70477430807"}
0005433870793	4D9713	8228 562335	ANASTASIYA NIKOLAEVA	{"email": "anastasiyanikolaeva27051964@postgrespro.ru", "phone": "+70610776158"}
0005433870794	1A75B5	0356 774117	VLADIMIR MAKSIMOV	{"email": "vladimir_maksimov-1977@postgrespro.ru", "phone": "+70122364587"}
0005433870795	1A75B5	6807 490993	ALEKSANDR NIKITIN	{"email": "nikitin_a-19011981@postgrespro.ru", "phone": "+70665318578"}
0005433870796	1A75B5	6701 940052	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey.1974@postgrespro.ru", "phone": "+70515176146"}
0005433870797	F37A4E	1380 635594	VALENTINA GAVRILOVA	{"email": "gavrilova.valentina_21011965@postgrespro.ru", "phone": "+70588366248"}
0005433870798	CDFCC0	4214 103427	NIKOLAY CHERNOV	{"phone": "+70293143783"}
0005433870799	CDFCC0	1022 184675	SERGEY SIDOROV	{"email": "sidorov_s1965@postgrespro.ru", "phone": "+70341470356"}
0005433870800	AC5F6C	9807 236909	ALEKSANDR FILIPPOV	{"email": "filippov-a_011974@postgrespro.ru", "phone": "+70757263152"}
0005433872426	2EFBFF	6722 554044	ANDREY ZAKHAROV	{"phone": "+70083566492"}
0005433872427	2EFBFF	1465 024474	MATVEY KONOVALOV	{"phone": "+70727027818"}
0005433872428	E93931	4508 529356	ANASTASIYA MAKAROVA	{"email": "makarova-a-041967@postgrespro.ru", "phone": "+70526369233"}
0005433872429	219EBF	3728 836927	ALEKSANDR SAVELEV	{"email": "a_savelev.07051965@postgrespro.ru", "phone": "+70180755466"}
0005433872430	7E4256	1584 233871	ANATOLIY SIDOROV	{"phone": "+70789383084"}
0005433872431	7E4256	2147 120796	NATALYA CHERNOVA	{"email": "natalya.chernova-1970@postgrespro.ru", "phone": "+70470695264"}
0005433872432	086024	2107 988423	SERGEY IVANOV	{"phone": "+70529826238"}
0005433872433	086024	7681 251271	NATALYA MIKHAYLOVA	{"phone": "+70250190740"}
0005433872434	7B0F2E	5934 803025	LARISA DENISOVA	{"phone": "+70619376895"}
0005433872435	059FAF	9125 620696	LYUBOV POPOVA	{"email": "popovalyubov.22071976@postgrespro.ru", "phone": "+70408707645"}
0005433872436	3522C0	6893 427587	LIDIYA SMIRNOVA	{"phone": "+70839267111"}
0005433872437	54B6F0	4159 677942	MAKSIM ALEKSEEV	{"email": "alekseev-maksim1966@postgrespro.ru", "phone": "+70767713217"}
0005433872438	4BDBF5	9603 403977	LYUDMILA KRASNOVA	{"phone": "+70106692541"}
0005433872439	A2E44B	6911 405962	DMITRIY ILIN	{"email": "d.ilin06051961@postgrespro.ru", "phone": "+70864698205"}
0005433872440	7570AA	5609 825367	VERA IVANOVA	{"email": "vera-ivanova.23091973@postgrespro.ru", "phone": "+70394421661"}
0005433872441	7570AA	2168 920104	SERGEY NIKOLAEV	{"phone": "+70227204200"}
0005433872442	D7D6C0	3333 449486	VALERIY VOROBEV	{"email": "v_vorobev_03101974@postgrespro.ru", "phone": "+70042393742"}
0005433872443	0593F4	4372 848529	EKATERINA AFANASEVA	{"phone": "+70946832351"}
0005433872444	110551	3801 337905	ANASTASIYA IVANOVA	{"phone": "+70388533002"}
0005433872445	3472C7	6731 978842	TATYANA EGOROVA	{"phone": "+70992761166"}
0005433872446	3472C7	6848 040812	NATALYA TROFIMOVA	{"phone": "+70607399752"}
0005433872447	6025A6	4796 043667	YURIY FROLOV	{"email": "yuriy_frolov-021965@postgrespro.ru", "phone": "+70668805561"}
0005433872448	48BFBE	6445 329192	VALENTIN VLASOV	{"email": "vlasovvalentin_26061963@postgrespro.ru", "phone": "+70054463369"}
0005433872449	48BFBE	9300 304707	LARISA YUDINA	{"phone": "+70828948562"}
0005433872450	96ABDB	1492 738023	LIDIYA ANISIMOVA	{"email": "lidiyaanisimova.26111965@postgrespro.ru", "phone": "+70294447125"}
0005433872451	96ABDB	4084 643456	DMITRIY ROMANOV	{"email": "romanov.d_02111976@postgrespro.ru", "phone": "+70746742630"}
0005433872452	96ABDB	6322 640840	SVETLANA MARTYNOVA	{"phone": "+70499788545"}
0005433872453	96ABDB	9150 160911	MIKHAIL ZAYCEV	{"email": "zaycev_m-23111963@postgrespro.ru", "phone": "+70645230659"}
0005433872454	975059	2109 709082	KSENIYA FOMINA	{"phone": "+70316820116"}
0005433872455	975059	9607 756735	NELLI ZAKHAROVA	{"phone": "+70067521649"}
0005433872456	4D76DF	4708 702044	ANATOLIY SERGEEV	{"phone": "+70879046150"}
0005433872457	4D76DF	1842 358816	NATALYA OSIPOVA	{"email": "natalyaosipova.081961@postgrespro.ru", "phone": "+70989782219"}
0005433872458	A94557	0846 490212	VALERIY SMIRNOV	{"email": "v.smirnov.29111972@postgrespro.ru", "phone": "+70921005929"}
0005433872459	C04DC9	4670 354211	DMITRIY ZHUKOV	{"email": "dzhukov_101968@postgrespro.ru", "phone": "+70978029800"}
0005433872460	34C002	8933 370835	TAMARA KULIKOVA	{"phone": "+70393649231"}
0005433872461	34C002	9830 386282	OLGA VASILEVA	{"phone": "+70389827427"}
0005433872462	34C002	4796 006838	LYUDMILA KUZMINA	{"email": "lkuzmina_1982@postgrespro.ru", "phone": "+70597323135"}
0005433872463	8F69F1	5050 762930	NADEZHDA ILINA	{"phone": "+70603029676"}
0005433872464	822140	8999 130815	LYUBOV BELOVA	{"phone": "+70724438051"}
0005433872465	822140	1889 227454	IVAN SOROKIN	{"phone": "+70335647207"}
0005433872466	84AAD3	8520 013761	ALEKSEY BARANOV	{"phone": "+70872266402"}
0005433872467	1CBFD8	1291 153851	TATYANA GUSEVA	{"email": "tatyanaguseva.02021957@postgrespro.ru", "phone": "+70057190331"}
0005433872468	1CBFD8	6666 059265	EKATERINA KOZLOVA	{"email": "kozlova_e071967@postgrespro.ru", "phone": "+70835855379"}
0005433872469	91DCFF	3989 520229	IVAN SMIRNOV	{"phone": "+70394723716"}
0005433872470	9EA8A9	3946 230817	GALINA BOGDANOVA	{"phone": "+70116508985"}
0005433872471	9A385D	7781 610107	SERGEY ZHURAVLEV	{"email": "zhuravlev.sergey_1961@postgrespro.ru", "phone": "+70175367032"}
0005433872472	D1A914	3518 381240	VALERIYA VLASOVA	{"email": "v_vlasova-1988@postgrespro.ru", "phone": "+70109666653"}
0005433872473	A9AEEF	4972 696049	KIRILL IVANOV	{"email": "ivanov_k.041966@postgrespro.ru", "phone": "+70913038040"}
0005433872474	5A30C3	4665 300301	VIKTOR BARANOV	{"email": "vbaranov-1971@postgrespro.ru", "phone": "+70698682711"}
0005433872475	71E878	1085 305225	LYUBOV KAZAKOVA	{"email": "kazakova-l.091975@postgrespro.ru", "phone": "+70398650093"}
0005433872476	B5D8D2	2548 847704	TATYANA VOROBEVA	{"email": "t_vorobeva-081974@postgrespro.ru", "phone": "+70386526342"}
0005433872477	F7AA2D	5859 530301	LYUDMILA FROLOVA	{"email": "l-frolova-1964@postgrespro.ru", "phone": "+70429394986"}
0005433872478	5CA2DD	7457 872052	IRINA BELYAEVA	{"email": "belyaeva-irina.14021976@postgrespro.ru", "phone": "+70610420269"}
0005433872479	D565B1	1535 121398	VITALIY KISELEV	{"phone": "+70536504871"}
0005433872480	678AB0	4787 489196	MIKHAIL FILIPPOV	{"phone": "+70258152589"}
0005433872481	678AB0	4936 112894	IGOR IVANOV	{"email": "igor-ivanov.081969@postgrespro.ru", "phone": "+70400162910"}
0005433872482	078F0B	1035 191839	YULIYA SERGEEVA	{"email": "sergeeva.yuliya.1972@postgrespro.ru", "phone": "+70852903812"}
0005433872483	078F0B	4339 797821	EGOR KULIKOV	{"email": "kulikovegor_061974@postgrespro.ru", "phone": "+70576166548"}
0005433872484	328F6D	2222 798607	ARINA POPOVA	{"email": "popova.a.12021969@postgrespro.ru", "phone": "+70699230418"}
0005433872485	72DAAF	6933 780348	MARIYA EFIMOVA	{"email": "mariya-efimova-25021976@postgrespro.ru", "phone": "+70341642145"}
0005433872486	53ADA1	9693 360582	LYUBOV BOGDANOVA	{"phone": "+70245679244"}
0005433872487	2F8EEE	7618 178736	NATALYA BOGDANOVA	{"email": "nbogdanova071970@postgrespro.ru", "phone": "+70108245045"}
0005433872488	28F172	5851 922721	ALINA ALEKSEEVA	{"phone": "+70566997280"}
0005433872489	28F172	8185 476952	EVDOKIYA POPOVA	{"phone": "+70330177172"}
0005433872490	2F11EA	5298 806113	IGOR KISELEV	{"email": "igor_kiselev.21041970@postgrespro.ru", "phone": "+70677681029"}
0005433872491	5D002C	3305 488665	IGOR ILIN	{"email": "igor-ilin1965@postgrespro.ru", "phone": "+70022073285"}
0005433872492	3BC6F0	5247 268406	ALEKSEY NIKOLAEV	{"email": "nikolaev.aleksey-081964@postgrespro.ru", "phone": "+70733696829"}
0005433872493	719BC1	4675 911379	NATALYA IVANOVA	{"phone": "+70631152227"}
0005433872494	6BC056	7054 646191	MARIYA KOMAROVA	{"phone": "+70881268791"}
0005433872495	D4654C	1588 075643	EKATERINA POPOVA	{"email": "popova.ekaterina.1969@postgrespro.ru", "phone": "+70958693063"}
0005433872496	52D5EE	4610 267864	MARIYA PAVLOVA	{"email": "pavlova.m.1975@postgrespro.ru", "phone": "+70250599649"}
0005433872497	F033F4	3850 391039	ANATOLIY PETROV	{"email": "petrov.a.1987@postgrespro.ru", "phone": "+70275076223"}
0005433872498	F033F4	0824 827811	EKATERINA ZOTOVA	{"email": "zotova-ekaterina.1972@postgrespro.ru", "phone": "+70230747807"}
0005433872499	1426E5	5605 508220	POLINA RYABOVA	{"phone": "+70124261740"}
0005433872500	1426E5	4616 941307	MARINA NOVIKOVA	{"phone": "+70653562862"}
0005433872501	7FC080	5957 561444	NIKOLAY KUDRYASHOV	{"phone": "+70447841997"}
0005433872502	7FC080	9119 149238	ALEKSANDR OSIPOV	{"email": "a.osipov-09101972@postgrespro.ru", "phone": "+70334902430"}
0005433872503	7FCA82	2547 359827	EVGENIYA SOKOLOVA	{"email": "evgeniyasokolova1972@postgrespro.ru", "phone": "+70351019812"}
0005433872504	D466B4	5500 588207	NATALYA MASLOVA	{"email": "maslova.natalya.02061967@postgrespro.ru", "phone": "+70671056479"}
0005433872505	457F20	8156 993017	ALEKSANDRA KUZMINA	{"email": "aleksandra.kuzmina.041970@postgrespro.ru", "phone": "+70736275308"}
0005433872506	08A63B	2295 008771	GENNADIY FEDOTOV	{"phone": "+70474751716"}
0005433872507	9E3E87	9898 295582	TATYANA SCHERBAKOVA	{"phone": "+70666617048"}
0005433872508	DB66EE	1606 655358	ARMEN AFANASEV	{"email": "afanasevarmen.1981@postgrespro.ru", "phone": "+70313002643"}
0005433872509	CEF4D7	8470 179761	NADEZHDA FROLOVA	{"phone": "+70788646045"}
0005433872510	CEF4D7	0860 652177	TATYANA MALYSHEVA	{"email": "tatyana.malysheva_17011966@postgrespro.ru", "phone": "+70427928049"}
0005433872511	1BC6C6	9562 888251	ANNA TARASOVA	{"email": "atarasova23051975@postgrespro.ru", "phone": "+70159882382"}
0005433872512	1BC6C6	8523 079547	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov111970@postgrespro.ru", "phone": "+70993662226"}
0005433872513	C6F7BF	4890 534421	VALERIY NIKITIN	{"phone": "+70763276558"}
0005433872514	92973F	2194 949322	RINAT GUSEV	{"email": "rgusev_1974@postgrespro.ru", "phone": "+70889805409"}
0005433872515	D7D5D5	8923 514828	TAISIYA ILINA	{"phone": "+70739488254"}
0005433872516	0EF6DE	2978 578396	ALEKSANDR PAVLOV	{"phone": "+70792066148"}
0005433872517	4566B7	2191 273059	NATALYA KAZAKOVA	{"email": "kazakova.n26111980@postgrespro.ru", "phone": "+70213826261"}
0005433872518	CEA1CA	2375 810833	PETR KONOVALOV	{"phone": "+70997968862"}
0005433872519	05B273	4830 057417	SVETLANA ROMANOVA	{"phone": "+70639543958"}
0005433872520	6ED6D6	7202 119374	OLGA SCHERBAKOVA	{"phone": "+70232745196"}
0005433872521	6ED6D6	6590 552168	ALEKSANDR DMITRIEV	{"phone": "+70845524801"}
0005433872522	BE6CFB	1273 439770	MAKSIM SMIRNOV	{"email": "maksimsmirnov_051977@postgrespro.ru", "phone": "+70586328993"}
0005433872523	5E19E6	4254 325370	ANTON ZAYCEV	{"phone": "+70928009435"}
0005433872524	7DD647	2272 757502	ANDREY VOLKOV	{"phone": "+70038707163"}
0005433872525	D469C6	4989 359662	BOGDAN KOZLOV	{"email": "bogdan.kozlov1977@postgrespro.ru", "phone": "+70744017858"}
0005433872526	D469C6	5424 901649	PAVEL DAVYDOV	{"email": "pavel_davydov081977@postgrespro.ru", "phone": "+70101919295"}
0005433872527	B718F5	8349 323396	SVETLANA KRASNOVA	{"email": "krasnovasvetlana13011977@postgrespro.ru", "phone": "+70824711140"}
0005433872528	DA0DDC	3697 767914	NIKOLAY MATVEEV	{"phone": "+70227444312"}
0005433872529	07CDF2	9196 318383	VLADIMIR SIDOROV	{"phone": "+70276294666"}
0005433872530	E9136B	1470 374328	ROMAN MELNIKOV	{"email": "roman.melnikov_03111970@postgrespro.ru", "phone": "+70659106877"}
0005433872531	D16AFB	3035 347659	ROMAN ALEKSEEV	{"phone": "+70827686966"}
0005433872532	84FEDF	7586 718675	VIKTOR RODIONOV	{"phone": "+70809747353"}
0005433872533	84FEDF	6213 963249	SERGEY ALEKSANDROV	{"email": "aleksandrovs101975@postgrespro.ru", "phone": "+70569007429"}
0005433872534	4C1CEC	4964 125096	KIRILL IVANOV	{"email": "ivanov.k1988@postgrespro.ru", "phone": "+70017571003"}
0005433872535	F0EA44	4393 007968	EKATERINA BELOVA	{"email": "ekaterina_belova.111980@postgrespro.ru", "phone": "+70380483035"}
0005433872536	F0EA44	1923 985741	ALEKSANDR KARPOV	{"phone": "+70424964395"}
0005433872537	B8E59E	7839 763113	LARISA KULIKOVA	{"email": "kulikova-l091967@postgrespro.ru", "phone": "+70717642170"}
0005433872538	B8E59E	0077 712929	VIKTOR NAUMOV	{"email": "viktornaumov051988@postgrespro.ru", "phone": "+70641858454"}
0005433872539	6C95E0	0224 255330	SOFYA ALEKSANDROVA	{"phone": "+70478042617"}
0005433872540	BE5164	6493 224772	LYUDMILA SERGEEVA	{"email": "l_sergeeva1967@postgrespro.ru", "phone": "+70625602360"}
0005433872541	BE5164	6735 544146	NINA MIKHAYLOVA	{"phone": "+70463288602"}
0005433872542	9A9B04	3181 131990	TATYANA ISAEVA	{"email": "isaeva-tatyana14101978@postgrespro.ru", "phone": "+70781801268"}
0005433872543	9A9B04	9978 753161	MIKHAIL ZAYCEV	{"phone": "+70119263879"}
0005433872544	03ADA3	3126 226979	VLADIMIR KAZAKOV	{"email": "kazakov_vladimir_18081982@postgrespro.ru", "phone": "+70959675715"}
0005433872545	03ADA3	5856 358843	GALINA POPOVA	{"phone": "+70414867051"}
0005433872546	7089F9	1859 009334	DARYA MAKSIMOVA	{"phone": "+70651876987"}
0005433872547	A8E7A3	0521 432536	ELENA NIKOLAEVA	{"email": "enikolaeva_1963@postgrespro.ru", "phone": "+70918005195"}
0005433872548	4167D5	3407 040033	EKATERINA KARPOVA	{"email": "e_karpova27091974@postgrespro.ru", "phone": "+70813434418"}
0005433872549	4167D5	8326 889101	VERA KALININA	{"email": "kalinina.vera.1977@postgrespro.ru", "phone": "+70832087080"}
0005433872550	76C948	7674 685493	LYUDMILA GORBUNOVA	{"phone": "+70343581026"}
0005433872551	97B348	5558 811521	ALINA KRASNOVA	{"email": "krasnova_alina.121959@postgrespro.ru", "phone": "+70780584776"}
0005433872552	1722B4	9967 147513	ANASTASIYA ARKHIPOVA	{"phone": "+70026101586"}
0005433872553	27AEB6	6449 997704	ROMAN MATVEEV	{"email": "r_matveev.08051973@postgrespro.ru", "phone": "+70905461906"}
0005433872554	3BA45D	3462 805757	IRINA MIKHAYLOVA	{"email": "mikhaylovairina.25051961@postgrespro.ru", "phone": "+70788537265"}
0005433872555	3BA45D	5635 297478	ANNA TITOVA	{"phone": "+70654481946"}
0005433872556	3BA45D	2361 078429	TATYANA KOMAROVA	{"email": "komarova_tatyana021974@postgrespro.ru", "phone": "+70830795130"}
0005433872557	3BA45D	8757 961194	ALEKSEY MOISEEV	{"email": "moiseevaleksey.23081969@postgrespro.ru", "phone": "+70487577831"}
0005433872558	5E79E7	7693 537239	NADEZHDA ROMANOVA	{"phone": "+70302557781"}
0005433872559	5E79E7	2819 369692	TAISIYA MIKHAYLOVA	{"email": "taisiyamikhaylova_101979@postgrespro.ru", "phone": "+70869391353"}
0005433872560	E778C5	2568 630652	NINA SIDOROVA	{"email": "sidorova.n051975@postgrespro.ru", "phone": "+70346599420"}
0005433872561	A23753	1070 911470	ANNA MOROZOVA	{"email": "morozova.anna_1963@postgrespro.ru", "phone": "+70248122423"}
0005433872562	BE4BCE	2003 116011	ROMAN GAVRILOV	{"email": "roman-gavrilov.1973@postgrespro.ru", "phone": "+70182728773"}
0005433872563	5028BF	5933 954689	ELENA NIKITINA	{"email": "nikitina_e_14021966@postgrespro.ru", "phone": "+70810030017"}
0005433872564	BF2118	8117 593723	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr31101965@postgrespro.ru", "phone": "+70981931085"}
0005433872565	0EF599	8781 680609	ALEKSANDR PETROV	{"email": "aleksandr-petrov1982@postgrespro.ru", "phone": "+70936510579"}
0005433872566	142B1A	5608 958663	DMITRIY SMIRNOV	{"email": "d.smirnov-14091977@postgrespro.ru", "phone": "+70710244423"}
0005433872567	142B1A	0300 726707	DANILA DAVYDOV	{"phone": "+70840222685"}
0005433872568	337E83	3157 141026	VALENTINA KARPOVA	{"email": "karpova.valentina-09041975@postgrespro.ru", "phone": "+70535752683"}
0005433872569	ECA5A9	4122 546236	MIKHAIL ILIN	{"email": "mikhail.ilin.21101960@postgrespro.ru", "phone": "+70164203757"}
0005433872570	B30286	9363 752793	MAKSIM EGOROV	{"email": "m.egorov-1975@postgrespro.ru", "phone": "+70546651881"}
0005433872571	50D5FA	9426 722719	YAROSLAV ZAYCEV	{"phone": "+70312343510"}
0005433872572	785425	5545 546694	VIKTORIYA ORLOVA	{"phone": "+70573270198"}
0005433872573	785425	8295 219922	TAMARA ZAKHAROVA	{"email": "t_zakharova-19021973@postgrespro.ru", "phone": "+70000789868"}
0005433872574	3FDF3E	1025 033235	GENNADIY KUZNECOV	{"email": "g.kuznecov_15101982@postgrespro.ru", "phone": "+70674260911"}
0005433872575	CEE3BB	6669 927384	TATYANA SOROKINA	{"email": "tatyanasorokina-26021964@postgrespro.ru", "phone": "+70099808550"}
0005433872576	E27F43	0155 039968	MAKSIM MIKHAYLOV	{"phone": "+70930284980"}
0005433872577	E27F43	6905 067834	DMITRIY TARASOV	{"phone": "+70812459118"}
0005433872578	14975D	9502 200931	TATYANA BELYAEVA	{"email": "belyaeva.t-21021967@postgrespro.ru", "phone": "+70402991207"}
0005433872579	09EBC7	1259 766897	YULIYA ROMANOVA	{"email": "yuliya_romanova.09091986@postgrespro.ru", "phone": "+70090310708"}
0005433872580	F21457	7284 862966	IGOR YAKOVLEV	{"email": "yakovlev-i1983@postgrespro.ru", "phone": "+70917214383"}
0005433872581	025FDA	4939 328120	DMITRIY ANDREEV	{"phone": "+70687574399"}
0005433872582	8E52DA	6402 390659	VALENTINA AFANASEVA	{"phone": "+70965537208"}
0005433872583	8E52DA	1577 205816	TAMARA RODIONOVA	{"phone": "+70918637645"}
0005433872584	EA06DD	5375 301229	SOFYA VOLKOVA	{"phone": "+70807770595"}
0005433872585	55F36B	6391 135542	GALINA RODIONOVA	{"email": "galina-rodionova08071976@postgrespro.ru", "phone": "+70662843751"}
0005433872586	55F36B	6874 511359	ARTEM MIKHAYLOV	{"phone": "+70733271438"}
0005433872587	55F36B	1458 932309	LYUDMILA PAVLOVA	{"email": "pavlova_lyudmila-13091976@postgrespro.ru", "phone": "+70818891831"}
0005433872588	3B2D7A	9658 161527	YULIYA SEMENOVA	{"email": "semenova-yuliya24051959@postgrespro.ru", "phone": "+70571876790"}
0005433874291	22754A	6587 550867	EKATERINA MIRONOVA	{"phone": "+70536668250"}
0005433874292	22754A	2368 962711	VYACHESLAV NIKOLAEV	{"phone": "+70809957885"}
0005433874293	22E5D7	2300 401510	VALENTINA DAVYDOVA	{"phone": "+70902232809"}
0005433874294	0DC9A3	3988 240584	TATYANA FROLOVA	{"phone": "+70585252337"}
0005433874295	24B422	2383 657138	SERGEY GUSEV	{"email": "s_gusev051979@postgrespro.ru", "phone": "+70541022592"}
0005433874296	3220EA	6996 028130	ANASTASIYA KUZMINA	{"phone": "+70294858668"}
0005433874297	177022	2866 126402	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila.1982@postgrespro.ru", "phone": "+70851108885"}
0005433874298	C196A9	0546 632681	ALEKSEY BORISOV	{"phone": "+70917925002"}
0005433874299	84FB48	8582 920716	MARIYA SIDOROVA	{"email": "sidorovam.081970@postgrespro.ru", "phone": "+70549163726"}
0005433874300	9550E2	0396 836392	LYUDMILA BARANOVA	{"email": "l-baranova.1965@postgrespro.ru", "phone": "+70086274138"}
0005433874301	9550E2	8152 135641	MAKSIM POPOV	{"email": "mpopov-081977@postgrespro.ru", "phone": "+70278997928"}
0005433874302	141FA0	3132 176126	VLADIMIR KUZMIN	{"email": "v_kuzmin101979@postgrespro.ru", "phone": "+70138347849"}
0005433874303	94AF84	3173 626715	EVGENIY ANTONOV	{"email": "evgeniy.antonov13031976@postgrespro.ru", "phone": "+70818119379"}
0005433874304	53AEE6	5923 478297	DMITRIY ANTONOV	{"email": "antonov_dmitriy-041987@postgrespro.ru", "phone": "+70809333090"}
0005433874305	53AEE6	4369 012975	ELENA NIKOLAEVA	{"phone": "+70062232728"}
0005433874306	37BB15	9990 283089	ZINAIDA KUZMINA	{"phone": "+70310972242"}
0005433874307	37BB15	4731 682264	ISLAM SERGEEV	{"phone": "+70254718037"}
0005433874308	9CD49C	2998 803819	MIKHAIL ALEKSANDROV	{"phone": "+70365110060"}
0005433874309	CE298F	4220 617895	VLADIMIR ILIN	{"phone": "+70610627199"}
0005433874310	213395	5126 477716	NATALYA LOGINOVA	{"email": "loginova.n01111972@postgrespro.ru", "phone": "+70000451800"}
0005433874311	49C8DE	9596 050037	VASILIY EGOROV	{"email": "egorov-v.28041978@postgrespro.ru", "phone": "+70159355646"}
0005433874312	49C8DE	6807 873528	ANNA FEDOROVA	{"email": "anna_fedorova18051970@postgrespro.ru", "phone": "+70365366041"}
0005433874313	0BB4A2	4911 322762	IVAN NOVIKOV	{"email": "i-novikov_1974@postgrespro.ru", "phone": "+70365766084"}
0005433874314	B738F0	0936 475734	ELENA SIDOROVA	{"email": "elena.sidorova.061975@postgrespro.ru", "phone": "+70792631825"}
0005433874315	5470E9	6967 510456	ANDREY SIDOROV	{"email": "andrey-sidorov-06111973@postgrespro.ru", "phone": "+70902212523"}
0005433874316	4865BF	1342 793494	KRISTINA DAVYDOVA	{"email": "davydova-k-10051979@postgrespro.ru", "phone": "+70203283857"}
0005433874317	18A344	1699 243294	ARSENIY TIKHONOV	{"phone": "+70146670346"}
0005433874318	318070	9107 236379	ALEKSANDR SOROKIN	{"phone": "+70821859909"}
0005433874319	318070	0430 278730	EVGENIY GRIGOREV	{"email": "evgeniy_grigorev091980@postgrespro.ru", "phone": "+70458787224"}
0005433874320	0BE79F	7086 174927	ZINAIDA DMITRIEVA	{"phone": "+70643152698"}
0005433874321	8F89BF	6762 409686	KLAVDIYA SOLOVEVA	{"email": "soloveva-klavdiya-101981@postgrespro.ru", "phone": "+70755218146"}
0005433874322	3AFB1A	8695 584718	EVGENIY KOROLEV	{"phone": "+70408538009"}
0005433874323	3AFB1A	7872 408841	PAVEL ANDREEV	{"phone": "+70507008449"}
0005433874324	18AB4A	2358 895838	MIKHAIL SEMENOV	{"phone": "+70468381324"}
0005433874325	18AB4A	0508 237269	MARIYA KUZNECOVA	{"phone": "+70657079947"}
0005433874326	560736	9719 796668	ILMIR SERGEEV	{"email": "ilmirsergeev08061972@postgrespro.ru", "phone": "+70237929482"}
0005433874327	229FCB	3534 585177	ANVAR KONOVALOV	{"phone": "+70517676064"}
0005433874328	CC5C59	5352 857790	LYUBOV OSIPOVA	{"phone": "+70326349175"}
0005433874329	089A96	3883 902849	ALBINA MAKAROVA	{"email": "makarova_albina.28011971@postgrespro.ru", "phone": "+70944019749"}
0005433874330	624511	5588 941704	NADEZHDA AFANASEVA	{"email": "afanaseva_nadezhda.1966@postgrespro.ru", "phone": "+70857501004"}
0005433874331	4502B0	6710 631000	DANIIL SEMENOV	{"email": "semenov_daniil1978@postgrespro.ru", "phone": "+70134927292"}
0005433874332	41DE08	3750 832127	VADIM DENISOV	{"email": "denisovv1980@postgrespro.ru", "phone": "+70716864327"}
0005433874333	A935CA	5785 243730	ALEKSEY BARANOV	{"email": "aleksey_baranov-25081962@postgrespro.ru", "phone": "+70578249866"}
0005433874334	A935CA	1124 089883	ANASTASIYA GORBUNOVA	{"phone": "+70711168662"}
0005433874335	91563A	7546 564226	ANNA MALYSHEVA	{"phone": "+70473161645"}
0005433874336	AE1B75	0634 456894	PRASKOVYA CHERNOVA	{"email": "chernova-p17011963@postgrespro.ru", "phone": "+70749427078"}
0005433874337	7B5FA2	8474 771300	SERGEY ANDREEV	{"email": "sergey.andreev12041967@postgrespro.ru", "phone": "+70273827283"}
0005433874338	03E249	4386 608417	ANNA IVANOVA	{"email": "a.ivanova.1967@postgrespro.ru", "phone": "+70225897856"}
0005433874339	03E249	1329 468788	ANNA DANILOVA	{"phone": "+70214176730"}
0005433874340	92CE4E	7657 941252	RUSTAM VOROBEV	{"phone": "+70953369337"}
0005433874341	6B2124	1871 856200	LIDIYA SIDOROVA	{"email": "l_sidorova-1981@postgrespro.ru", "phone": "+70560464918"}
0005433874342	5A2078	7789 293539	ANATOLIY SOKOLOV	{"email": "anatoliy.sokolov_1961@postgrespro.ru", "phone": "+70562102206"}
0005433874343	1EA073	7575 179386	ALINA PETROVA	{"phone": "+70493182552"}
0005433874344	FC7D93	9180 010884	TAMARA TARASOVA	{"email": "tarasovatamara-1973@postgrespro.ru", "phone": "+70512124145"}
0005433874345	6353F0	4901 178922	VIKTOR MEDVEDEV	{"email": "medvedevviktor.101962@postgrespro.ru", "phone": "+70730935373"}
0005433874346	986B4C	3903 516267	SVETLANA NESTEROVA	{"email": "nesterova.svetlana1968@postgrespro.ru", "phone": "+70592234816"}
0005433874347	81D1EB	1786 668257	NADEZHDA FADEEVA	{"phone": "+70171567952"}
0005433874348	D546CC	1120 947296	TATYANA MOISEEVA	{"email": "moiseeva.t-1976@postgrespro.ru", "phone": "+70851678390"}
0005433874349	5B0F03	6555 766172	MAKSIM BARANOV	{"email": "m_baranov.11051976@postgrespro.ru", "phone": "+70741911389"}
0005433874350	FBD586	4365 993060	RUSLAN ABRAMOV	{"phone": "+70889760476"}
0005433874351	FBD586	8124 236868	ANASTASIYA KUZNECOVA	{"email": "kuznecovaa29041974@postgrespro.ru", "phone": "+70537479355"}
0005433874352	FBD586	5586 130705	SERGEY GAVRILOV	{"phone": "+70848105299"}
0005433874353	8E001F	7695 038187	SERGEY FEDOTOV	{"email": "fedotov_s-13031985@postgrespro.ru", "phone": "+70123664601"}
0005433874354	0F6D07	4354 128155	LARISA SOROKINA	{"phone": "+70314771235"}
0005433874355	0383D6	2641 554537	IRINA DANILOVA	{"email": "danilova_irina-20011966@postgrespro.ru", "phone": "+70725667398"}
0005433874356	71A784	0098 391513	VERA ISAEVA	{"email": "isaevavera-101975@postgrespro.ru", "phone": "+70967120658"}
0005433874357	71A784	8263 726335	NINA ALEKSANDROVA	{"phone": "+70461923774"}
0005433874358	2FB17D	5912 584939	TATYANA OVCHINNIKOVA	{"email": "tovchinnikova-021974@postgrespro.ru", "phone": "+70143504295"}
0005433874359	5E9174	1078 728756	ALEKSEY SOROKIN	{"phone": "+70481730680"}
0005433874360	2CA43A	9328 002827	ILYA POPOV	{"email": "popov-ilya-13041966@postgrespro.ru", "phone": "+70573954839"}
0005433874361	2CA43A	6930 327660	ANTONINA IVANOVA	{"phone": "+70818611418"}
0005433874362	2CA43A	9965 182076	EKATERINA SEMENOVA	{"phone": "+70263336790"}
0005433874363	CA43EB	7202 790316	ALEKSEY BONDARENKO	{"phone": "+70054207971"}
0005433874364	CA43EB	1428 100936	ANNA MEDVEDEVA	{"email": "medvedeva-a1985@postgrespro.ru", "phone": "+70403494523"}
0005433874365	877EDB	1236 628403	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr_061984@postgrespro.ru", "phone": "+70713040954"}
0005433874366	8AA2A0	1462 709086	SERGEY MOISEEV	{"email": "moiseev.s011971@postgrespro.ru", "phone": "+70039699870"}
0005433874367	29A1AC	1901 897870	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev-1980@postgrespro.ru", "phone": "+70414446642"}
0005433874368	29A1AC	5876 718119	EKATERINA ANDREEVA	{"email": "andreeva-e_041965@postgrespro.ru", "phone": "+70695932143"}
0005433874369	5BA4AA	3604 813124	ANASTASIYA POPOVA	{"phone": "+70628212121"}
0005433874370	F69C62	1131 003498	NADEZHDA FEDOROVA	{"email": "nfedorova_1965@postgrespro.ru", "phone": "+70236729893"}
0005433874371	F69C62	5204 732929	EDUARD BONDARENKO	{"phone": "+70814723301"}
0005433874372	F69C62	4042 244489	SEMEN RODIONOV	{"email": "rodionov-semen_1972@postgrespro.ru", "phone": "+70062230895"}
0005433874373	708E5F	1903 882633	NATALYA MOROZOVA	{"email": "n-morozova.15121972@postgrespro.ru", "phone": "+70994434325"}
0005433874374	708E5F	4554 035032	ALEKSANDR GRIGOREV	{"phone": "+70630571296"}
0005433874375	708E5F	0804 345698	MIKHAIL AFANASEV	{"phone": "+70261399619"}
0005433874376	0E5311	1509 353538	ELENA AFANASEVA	{"email": "e_afanaseva.24091972@postgrespro.ru", "phone": "+70928795538"}
0005433874377	445F18	5614 841317	IGOR BONDARENKO	{"email": "i_bondarenko.24071965@postgrespro.ru", "phone": "+70610998454"}
0005433874378	31B713	7732 226614	VASILIY PETROV	{"email": "petrov.v011974@postgrespro.ru", "phone": "+70071947498"}
0005433874379	82E22C	1258 797279	EKATERINA ERMAKOVA	{"email": "ekaterina.ermakova_01061976@postgrespro.ru", "phone": "+70231016792"}
0005433874380	81E59A	7309 800016	LYUBOV BELOVA	{"email": "belova.l-1977@postgrespro.ru", "phone": "+70024380446"}
0005433874381	81E59A	2308 094202	IVAN ZHURAVLEV	{"email": "zhuravlevivan.13111970@postgrespro.ru", "phone": "+70966679774"}
0005433874382	F05700	4467 327645	LARISA EFREMOVA	{"phone": "+70592533446"}
0005433874383	827025	0751 088605	OLGA MIKHAYLOVA	{"phone": "+70957659800"}
0005433874384	DE3A59	5317 215706	NIKITA SOKOLOV	{"phone": "+70411722864"}
0005433874385	11E78A	2005 798967	EVGENIYA VASILEVA	{"phone": "+70746334245"}
0005433874386	0A0545	9794 788048	LILIYA LEBEDEVA	{"email": "lebedeva_l041966@postgrespro.ru", "phone": "+70710809431"}
0005433874387	E77835	4517 669747	VIKTOR MATVEEV	{"email": "v.matveev-121976@postgrespro.ru", "phone": "+70176919732"}
0005433874388	EB0023	5350 797222	IGOR BELOV	{"email": "igor.belov.071977@postgrespro.ru", "phone": "+70810397996"}
0005433874389	FF6D15	3815 640642	RUZALIYA ROMANOVA	{"email": "r-romanova-1976@postgrespro.ru", "phone": "+70181877357"}
0005433874390	FF6D15	3959 812132	LEONID KAZAKOV	{"email": "kazakov_l-1976@postgrespro.ru", "phone": "+70279091270"}
0005433874391	FF6D15	8792 957040	PAVEL KUZMIN	{"phone": "+70574730409"}
0005433874392	F38700	0189 392518	LADA IVANOVA	{"email": "ivanova-l.021980@postgrespro.ru", "phone": "+70564967244"}
0005433874393	F38700	2588 594528	IVAN ROMANOV	{"email": "romanov_i-1963@postgrespro.ru", "phone": "+70706918527"}
0005433874394	E9A382	6036 660749	OLEG KISELEV	{"phone": "+70073529667"}
0005433874395	E9A382	7825 071564	VALENTINA KOROLEVA	{"phone": "+70497535752"}
0005433874396	81D0A8	1104 353797	NINA MEDVEDEVA	{"email": "nina.medvedeva-1968@postgrespro.ru", "phone": "+70228995070"}
0005433874397	272B5E	1440 612290	ELENA IVANOVA	{"phone": "+70111921330"}
0005433874398	C21E37	5082 219815	PAVEL MATVEEV	{"phone": "+70167626724"}
0005433874399	9FC76C	4985 678838	ELENA SEMENOVA	{"email": "esemenova.1980@postgrespro.ru", "phone": "+70575762776"}
0005433874400	9FC76C	7474 752960	TAMARA MIKHAYLOVA	{"phone": "+70057901021"}
0005433874401	A21A7F	7416 698348	MARIYA KOLESNIKOVA	{"email": "mariya_kolesnikova-041978@postgrespro.ru", "phone": "+70123827758"}
0005433874402	A21A7F	4842 896549	MAKSIM DENISOV	{"email": "maksimdenisov.02011977@postgrespro.ru", "phone": "+70109979025"}
0005433874403	3C10B8	2542 778441	IGOR MAKAROV	{"email": "igormakarov111964@postgrespro.ru", "phone": "+70034488317"}
0005433874460	790C4B	3414 530990	NADEZHDA NIKITINA	{"phone": "+70163659235"}
0005433874404	E7C8F1	1811 975108	YULIYA MEDVEDEVA	{"email": "ymedvedeva.02091976@postgrespro.ru", "phone": "+70228569298"}
0005433874405	E7C8F1	7976 856097	EVGENIY BORISOV	{"phone": "+70656727293"}
0005433874406	52CFBA	7827 166032	GENNADIY OSIPOV	{"phone": "+70884520562"}
0005433874407	52CFBA	4750 052619	ALEKSEY SOROKIN	{"phone": "+70309811478"}
0005433874408	6C7080	3276 385150	ILYA BORISOV	{"email": "ilyaborisov_1979@postgrespro.ru", "phone": "+70588528981"}
0005433874409	154FC2	7728 741182	YULIYA GORBUNOVA	{"phone": "+70080108508"}
0005433874410	154FC2	2258 168779	VLADIMIR ORLOV	{"email": "orlov.vladimir1969@postgrespro.ru", "phone": "+70240680285"}
0005433874411	F46754	5210 224647	FELIKS KONOVALOV	{"email": "konovalovf-1965@postgrespro.ru", "phone": "+70825925944"}
0005433874412	F812E5	7549 020643	VERA ALEKSEEVA	{"phone": "+70195052294"}
0005433874413	F812E5	5811 117430	MIKHAIL FEDOROV	{"email": "fedorovmikhail.1974@postgrespro.ru", "phone": "+70176734463"}
0005433874414	801339	2657 472020	IGOR OSIPOV	{"email": "osipov-i_18041985@postgrespro.ru", "phone": "+70397331444"}
0005433874415	3C950D	8615 365538	OLEG NIKOLAEV	{"phone": "+70389108904"}
0005433874416	3C950D	8414 870482	EVGENIY ZAYCEV	{"phone": "+70461101035"}
0005433874417	3C950D	6497 330475	DMITRIY MARTYNOV	{"email": "dmitriy.martynov-011969@postgrespro.ru", "phone": "+70641399439"}
0005433874418	9FF8ED	4722 291640	VALENTINA KUZNECOVA	{"phone": "+70764919712"}
0005433874419	662056	3122 976132	DANILA MOROZOV	{"email": "d_morozov.1983@postgrespro.ru", "phone": "+70960619594"}
0005433874420	16196D	7767 529550	NINA BELOVA	{"phone": "+70167342874"}
0005433874421	0959E5	7213 754720	ILYA MIKHAYLOV	{"email": "i_mikhaylov_02021979@postgrespro.ru", "phone": "+70937727050"}
0005433874422	5479CF	8623 010885	IRINA KUZMINA	{"phone": "+70857389809"}
0005433874423	5479CF	9975 384992	VLADISLAV MOROZOV	{"phone": "+70408911556"}
0005433874424	5479CF	7853 633874	VYACHESLAV KARPOV	{"phone": "+70717363057"}
0005433874425	9365F8	6593 242949	VLADIMIR POPOV	{"email": "vpopov_17081974@postgrespro.ru", "phone": "+70386481660"}
0005433874426	8D055F	8819 639241	EVGENIY SERGEEV	{"phone": "+70781148123"}
0005433874427	8D055F	2456 307227	VALENTINA IVANOVA	{"email": "valentina_ivanova_07061980@postgrespro.ru", "phone": "+70632142816"}
0005433874428	01D725	2064 195628	YULIYA NIKITINA	{"phone": "+70620861643"}
0005433874429	01D725	7670 848921	VLADIMIR TIMOFEEV	{"phone": "+70869016919"}
0005433874430	01D725	0857 463611	ALEKSANDR KONOVALOV	{"email": "akonovalov.02101962@postgrespro.ru", "phone": "+70536464818"}
0005433874431	50B6EF	7469 958445	MARGARITA MAKAROVA	{"email": "makarova-m15041977@postgrespro.ru", "phone": "+70051393598"}
0005433874432	50B6EF	7968 371255	EVGENIY SOLOVEV	{"email": "solovevevgeniy_1980@postgrespro.ru", "phone": "+70334861561"}
0005433874433	9303CB	7012 028627	EVGENIY NIKOLAEV	{"email": "enikolaev_121972@postgrespro.ru", "phone": "+70122948026"}
0005433874434	A4039D	1212 398364	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila.1970@postgrespro.ru", "phone": "+70803655729"}
0005433874435	A4039D	7051 281410	YAROSLAV OSIPOV	{"phone": "+70581891940"}
0005433874436	116623	4297 245551	KSENIYA TITOVA	{"phone": "+70927088613"}
0005433874437	116623	2264 224019	VYACHESLAV NAZAROV	{"phone": "+70012096873"}
0005433874438	FF6811	5641 386457	ANTONINA KONOVALOVA	{"email": "akonovalova1974@postgrespro.ru", "phone": "+70687953252"}
0005433874439	FF6811	4833 586695	POLINA NESTEROVA	{"email": "polina.nesterova-1978@postgrespro.ru", "phone": "+70137887356"}
0005433874440	8150C0	4401 278204	SVETLANA RYABOVA	{"email": "s-ryabova05081967@postgrespro.ru", "phone": "+70202731077"}
0005433874441	226C80	3838 074992	ELENA SOROKINA	{"email": "sorokinaelena_121974@postgrespro.ru", "phone": "+70590436603"}
0005433874442	226C80	5275 735679	ELMIRA SCHERBAKOVA	{"phone": "+70292421321"}
0005433874443	9DF165	1892 170058	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova1967@postgrespro.ru", "phone": "+70763691025"}
0005433874444	53A70B	1110 715995	ANATOLIY SERGEEV	{"phone": "+70470259083"}
0005433874445	B1BE4A	9053 183136	ELENA SMIRNOVA	{"email": "smirnova.e_031970@postgrespro.ru", "phone": "+70824757008"}
0005433874446	B1BE4A	1406 317153	ALEKSANDR KOZLOV	{"email": "a_kozlov-011965@postgrespro.ru", "phone": "+70719378803"}
0005433874447	B1BE4A	5514 171340	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a16021982@postgrespro.ru", "phone": "+70265594930"}
0005433874448	718EB8	5802 196367	IRINA MIKHAYLOVA	{"email": "mikhaylova_irina.071973@postgrespro.ru", "phone": "+70053885743"}
0005433874449	4D43A6	9763 529782	VIKTOR ANTONOV	{"phone": "+70977892304"}
0005433874450	4D43A6	8820 385252	NADEZHDA MOISEEVA	{"email": "nmoiseeva19111977@postgrespro.ru", "phone": "+70746963049"}
0005433874451	74F55A	0009 242871	LYUDMILA OSIPOVA	{"phone": "+70824732838"}
0005433874452	74F55A	3437 182846	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir-091975@postgrespro.ru", "phone": "+70095276593"}
0005433874453	A770ED	1522 291032	LYUBOV NIKITINA	{"phone": "+70152026122"}
0005433874454	A770ED	5791 679611	GALINA KOROLEVA	{"email": "gkoroleva_26021963@postgrespro.ru", "phone": "+70694212712"}
0005433874455	0CE636	5448 467956	VYACHESLAV VASILEV	{"phone": "+70197093087"}
0005433874456	94CE16	6370 387376	LEV KUDRYASHOV	{"phone": "+70022835921"}
0005433874457	8BE2A3	5848 755609	NADEZHDA POPOVA	{"email": "popova.n091969@postgrespro.ru", "phone": "+70343879626"}
0005433874458	8E45FD	9616 748579	LYUDMILA POPOVA	{"phone": "+70744576489"}
0005433874459	790C4B	6743 322865	VITALIY NAZAROV	{"email": "vitaliy-nazarov22121960@postgrespro.ru", "phone": "+70838885358"}
0005433875411	7484D8	2941 689964	VALERIY DENISOV	{"phone": "+70554440496"}
0005433874461	790C4B	4077 728402	LARISA KONDRATEVA	{"email": "lkondrateva101974@postgrespro.ru", "phone": "+70854731052"}
0005433875352	F73C8A	6562 888429	VASILIY BORISOV	{"phone": "+70943100598"}
0005433875353	91D377	3147 222846	VERA IVANOVA	{"email": "vera_ivanova-27011961@postgrespro.ru", "phone": "+70557837588"}
0005433875354	91D377	5679 528388	ELENA MAKAROVA	{"email": "e-makarova_1975@postgrespro.ru", "phone": "+70765696898"}
0005433875355	F59673	2183 682585	YANA KRASNOVA	{"phone": "+70366563987"}
0005433875356	F59673	6833 505606	IGOR ZAYCEV	{"phone": "+70236343250"}
0005433875357	DD916F	2735 071842	ALINA SEMENOVA	{"email": "alinasemenova031963@postgrespro.ru", "phone": "+70923624452"}
0005433875358	C10F62	3519 023870	ANZHELA MALYSHEVA	{"phone": "+70345651587"}
0005433875359	2B13C2	2730 831160	GLEB VLASOV	{"phone": "+70031302600"}
0005433875360	A1A54A	7592 636708	ELENA MOROZOVA	{"email": "morozova_elena-051962@postgrespro.ru", "phone": "+70832647389"}
0005433875361	E8136C	5243 281148	RAMILYA MIRONOVA	{"phone": "+70151497816"}
0005433875362	E8136C	2933 202999	NINA DMITRIEVA	{"phone": "+70932037079"}
0005433875363	E8136C	9293 675226	LIDIYA DMITRIEVA	{"email": "dmitrievalidiya-121962@postgrespro.ru", "phone": "+70098755251"}
0005433875364	B73582	4825 011361	ELENA KONDRATEVA	{"phone": "+70549651280"}
0005433875365	483C06	2630 802111	IRINA ZHURAVLEVA	{"email": "i_zhuravleva-12121969@postgrespro.ru", "phone": "+70397549174"}
0005433875366	1BBA49	1212 502372	MARIYA FILIPPOVA	{"email": "filippovamariya1972@postgrespro.ru", "phone": "+70280844047"}
0005433875367	8BEB62	5959 059318	SVETLANA VASILEVA	{"email": "svasileva_14071977@postgrespro.ru", "phone": "+70167859843"}
0005433875368	EBD34D	2862 829782	IRINA LUKYANOVA	{"email": "irina-lukyanova-041973@postgrespro.ru", "phone": "+70776731435"}
0005433875369	EBD34D	6886 326628	SERGEY POPOV	{"email": "sergey.popov_23071968@postgrespro.ru", "phone": "+70739768193"}
0005433875370	FC74AD	3692 599536	ELENA ROMANOVA	{"email": "romanovae28121974@postgrespro.ru", "phone": "+70317084911"}
0005433875371	724026	6147 771735	SERGEY GORBUNOV	{"phone": "+70735140484"}
0005433875372	419B0A	8292 734792	LYUBOV YAKOVLEVA	{"phone": "+70020609689"}
0005433875373	29B25D	3975 860939	TATYANA BORISOVA	{"email": "borisova-tatyana071972@postgrespro.ru", "phone": "+70916773795"}
0005433875374	1AF540	4000 662579	ELENA RYABOVA	{"email": "e-ryabova.111972@postgrespro.ru", "phone": "+70562239634"}
0005433875375	0FDD6B	7923 798844	VIKTOR BONDARENKO	{"email": "bondarenkov-17071961@postgrespro.ru", "phone": "+70404263833"}
0005433875376	0FDD6B	8553 309401	ANATOLIY FROLOV	{"phone": "+70909564847"}
0005433875377	DCAE18	1451 428359	ALLA IVANOVA	{"email": "alla_ivanova-1977@postgrespro.ru", "phone": "+70731738591"}
0005433875378	9C514F	0212 234237	VERA ALEKSANDROVA	{"phone": "+70375660789"}
0005433875379	9C514F	6785 838982	VIKTOR NAZAROV	{"email": "vnazarov1969@postgrespro.ru", "phone": "+70539520371"}
0005433875380	FC0942	5523 839529	BULAT ZHUKOV	{"phone": "+70454087553"}
0005433875381	FC0942	5967 146015	OLGA ILINA	{"email": "o-ilina.091972@postgrespro.ru", "phone": "+70234896194"}
0005433875382	FC0942	1300 334191	INNA POLYAKOVA	{"email": "polyakova_inna-1957@postgrespro.ru", "phone": "+70229142340"}
0005433875383	F797BB	9098 026460	SERGEY SEMENOV	{"email": "s-semenov-1977@postgrespro.ru", "phone": "+70024796614"}
0005433875384	F797BB	2551 771724	NADEZHDA KISELEVA	{"phone": "+70569734806"}
0005433875385	28EAB4	5520 093514	ANNA NAZAROVA	{"phone": "+70564282357"}
0005433875386	28EAB4	7937 582859	EKATERINA IVANOVA	{"phone": "+70306864217"}
0005433875387	B1057F	4093 306337	ANASTASIYA ILINA	{"phone": "+70106240405"}
0005433875388	0DFA75	0484 340328	IVAN KUZNECOV	{"email": "ivankuznecov_1973@postgrespro.ru", "phone": "+70329836865"}
0005433875389	6F1F8D	2046 454317	SVETLANA EFREMOVA	{"email": "efremovasvetlana_1973@postgrespro.ru", "phone": "+70121148461"}
0005433875390	E2D29E	3871 259676	ANASTASIYA KULIKOVA	{"email": "kulikova_anastasiya.1985@postgrespro.ru", "phone": "+70217388927"}
0005433875391	4B2AE3	2282 926381	LARISA VOLKOVA	{"phone": "+70414374813"}
0005433875392	9FC5ED	9950 535287	IRINA ZAYCEVA	{"email": "izayceva.121967@postgrespro.ru", "phone": "+70139091173"}
0005433875393	365E38	3072 637689	DANILA BORISOV	{"phone": "+70343093527"}
0005433875394	D444D6	0408 233584	VYACHESLAV IVANOV	{"email": "vivanov121980@postgrespro.ru", "phone": "+70070969001"}
0005433875395	4D44E8	5152 376564	ANTON ISAEV	{"email": "isaev-anton.031968@postgrespro.ru", "phone": "+70641984680"}
0005433875396	4D44E8	9647 421645	OLESYA VASILEVA	{"phone": "+70381877762"}
0005433875397	B82815	0124 510510	VALERIY BORISOV	{"phone": "+70681525867"}
0005433875398	0F5AF8	2485 385434	ALEKSEY ZAYCEV	{"phone": "+70798619432"}
0005433875399	0F5AF8	8217 730080	ISLAM FROLOV	{"email": "frolovislam_22071976@postgrespro.ru", "phone": "+70763883850"}
0005433875400	C3222E	3828 792634	EVGENIY GRIGOREV	{"email": "grigorevevgeniy_1970@postgrespro.ru", "phone": "+70287043426"}
0005433875401	C3222E	1622 946809	EKATERINA VOLKOVA	{"email": "ekaterina-volkova1962@postgrespro.ru", "phone": "+70122601974"}
0005433875402	D2556B	2984 969514	ANTON SOROKIN	{"phone": "+70575474756"}
0005433875403	0857BD	3202 165146	SERGEY ZAKHAROV	{"phone": "+70393466210"}
0005433875404	C036B2	1257 828138	LYUDMILA GERASIMOVA	{"email": "gerasimovalyudmila081960@postgrespro.ru", "phone": "+70600056211"}
0005433875405	01AAF5	1062 564268	TAMARA VASILEVA	{"phone": "+70931704996"}
0005433875406	01AAF5	4030 747715	OLGA EGOROVA	{"email": "o-egorova-26061978@postgrespro.ru", "phone": "+70442628260"}
0005433875407	01AAF5	4231 463329	ANATOLIY VLASOV	{"email": "vlasov_a-031980@postgrespro.ru", "phone": "+70588713370"}
0005433875408	F39151	0994 988357	MIKHAIL ZAKHAROV	{"phone": "+70588991854"}
0005433875409	F033B8	2133 537132	NIKOLAY SCHERBAKOV	{"phone": "+70861344601"}
0005433875410	F033B8	1550 585257	NATALYA ZAYCEVA	{"email": "zaycevanatalya20101963@postgrespro.ru", "phone": "+70213669566"}
0005433875412	F6365A	8289 147872	TATYANA NOVIKOVA	{"phone": "+70785388750"}
0005433875413	E7AE5D	9287 753682	MARINA POTAPOVA	{"email": "potapova-marina_1974@postgrespro.ru", "phone": "+70756965940"}
0005433875414	AB864D	3872 811639	GENNADIY DENISOV	{"email": "gennadiydenisov-1974@postgrespro.ru", "phone": "+70192253451"}
0005433875415	526968	1742 219482	GRIGORIY ILIN	{"phone": "+70480438535"}
0005433875416	244782	3555 339325	SERGEY KOROLEV	{"phone": "+70112640846"}
0005433875417	F73FD4	7883 167483	SERGEY SOROKIN	{"email": "sorokin-s-1967@postgrespro.ru", "phone": "+70198626760"}
0005433875418	7F8741	7862 831297	PAVEL MIKHAYLOV	{"email": "pavel-mikhaylov-101970@postgrespro.ru", "phone": "+70935194561"}
0005433875419	E894CA	1417 918228	SERGEY GUSEV	{"phone": "+70120399094"}
0005433875420	E894CA	3243 083205	SVETLANA FEDOROVA	{"phone": "+70480906737"}
0005433875421	7531BB	7948 865434	ALEKSEY VASILEV	{"email": "vasileva.06101964@postgrespro.ru", "phone": "+70256576692"}
0005433875422	6DAD71	9613 495551	GENNADIY VOROBEV	{"email": "gennadiyvorobev_111968@postgrespro.ru", "phone": "+70863245169"}
0005433875423	42D906	5044 343519	MIKHAIL KARPOV	{"phone": "+70635840002"}
0005433875424	42D906	8071 114837	ARTUR KUZNECOV	{"email": "kuznecovartur1964@postgrespro.ru", "phone": "+70793140100"}
0005433875425	F8EE89	4265 038875	BORIS KULIKOV	{"email": "boris.kulikov-27021964@postgrespro.ru", "phone": "+70486861773"}
0005433875426	B3C680	6035 947354	OLGA VLASOVA	{"phone": "+70146409836"}
0005433875427	839951	2379 219040	NIKITA DAVYDOV	{"email": "n_davydov13121966@postgrespro.ru", "phone": "+70499679263"}
0005433875428	839951	7003 630734	GALINA DAVYDOVA	{"email": "davydova-galina10101980@postgrespro.ru", "phone": "+70438962177"}
0005433875429	D8F2DA	5359 712455	OLEG KULIKOV	{"phone": "+70645790008"}
0005433875430	F66053	9721 076492	TATYANA KOROLEVA	{"email": "tkoroleva.101972@postgrespro.ru", "phone": "+70593969928"}
0005433875431	F66053	9695 510804	TATYANA NAUMOVA	{"phone": "+70839167448"}
0005433921587	49DA08	8100 566433	NADEZHDA ANDREEVA	{"email": "n_andreeva-22121959@postgrespro.ru", "phone": "+70200800598"}
0005433921588	49DA08	1748 142399	STANISLAV BARANOV	{"phone": "+70385667183"}
0005433921589	49DA08	9473 411341	IVAN NIKOLAEV	{"email": "i.nikolaev.01111977@postgrespro.ru", "phone": "+70242171410"}
0005433921590	A6F67B	2055 393968	ALEKSEY PETROV	{"email": "petrovaleksey-03111964@postgrespro.ru", "phone": "+70412110235"}
0005433921591	DEF2FA	3676 700595	VASILIY MEDVEDEV	{"email": "medvedev_v.11051956@postgrespro.ru", "phone": "+70755129126"}
0005433921592	DEF2FA	3724 989665	ELENA IVANOVA	{"email": "elena-ivanova_13061969@postgrespro.ru", "phone": "+70680867261"}
0005433921593	484305	5196 964346	ALEKSEY PAVLOV	{"email": "a_pavlov05121971@postgrespro.ru", "phone": "+70040896805"}
0005433921594	16524A	3666 858512	VITALIY MAKSIMOV	{"email": "maksimov-vitaliy-071984@postgrespro.ru", "phone": "+70600834546"}
0005433921595	865122	5851 128655	LYUDMILA BORISOVA	{"email": "lyudmila_borisova1969@postgrespro.ru", "phone": "+70894182690"}
0005433921596	57690D	3896 512632	ANDREY KRASNOV	{"email": "akrasnov1975@postgrespro.ru", "phone": "+70141737064"}
0005433921597	57690D	2588 891423	IRINA KOVALEVA	{"email": "kovalevai.08091975@postgrespro.ru", "phone": "+70872597102"}
0005433921598	487AFD	3922 580475	MARINA MAKAROVA	{"email": "makarovam.1979@postgrespro.ru", "phone": "+70547237902"}
0005433921599	F0CDA1	4355 464997	ANNA NESTEROVA	{"email": "anna_nesterova.1968@postgrespro.ru", "phone": "+70204142167"}
0005433921600	6B34F6	1993 540183	NINA OSIPOVA	{"email": "nina-osipova-041972@postgrespro.ru", "phone": "+70140049867"}
0005433921601	27948F	1859 524020	VIKTOR SEMENOV	{"email": "semenovv-09021963@postgrespro.ru", "phone": "+70087079641"}
0005433921602	27948F	3138 614634	DMITRIY KRASNOV	{"email": "krasnov_dmitriy_1969@postgrespro.ru", "phone": "+70417729703"}
0005433921603	892E18	1188 932227	VIKTOR ANTONOV	{"phone": "+70746030995"}
0005433921604	892E18	0457 549950	RUSLAN SAVELEV	{"email": "savelev_r.20111966@postgrespro.ru", "phone": "+70614709775"}
0005433921605	892E18	9598 876354	YULIYA RYABOVA	{"email": "ryabovayuliya.11071970@postgrespro.ru", "phone": "+70909748417"}
0005433921606	D69AC6	1571 331576	ANTONINA MARTYNOVA	{"phone": "+70465727908"}
0005433921607	D69AC6	8614 819527	ALEKSANDR PETROV	{"phone": "+70858008982"}
0005433921608	C0C690	4612 833451	NADEZHDA NIKITINA	{"phone": "+70856631736"}
0005433921609	18D4FE	7968 685898	VALENTINA KARPOVA	{"phone": "+70521857747"}
0005433921610	18D4FE	1228 779163	OLGA AFANASEVA	{"phone": "+70917065857"}
0005433921611	18D4FE	2367 857411	BORIS ROMANOV	{"phone": "+70399548210"}
0005433921612	51EB3B	4831 640492	RODION EGOROV	{"phone": "+70128149262"}
0005433921613	360C06	1510 498558	ANATOLIY KAZAKOV	{"phone": "+70369325372"}
0005433921614	360C06	2404 116654	VIKTORIYA MATVEEVA	{"phone": "+70909941617"}
0005433921615	715C9B	8176 474254	VYACHESLAV MATVEEV	{"phone": "+70627892583"}
0005433921616	715C9B	5130 425133	FEDOR ROMANOV	{"phone": "+70274470486"}
0005433921617	C32B65	0759 280250	ELENA MELNIKOVA	{"phone": "+70226645226"}
0005433921618	B48E76	7643 740577	ELIZAVETA ISAEVA	{"phone": "+70568666430"}
0005433921619	225CF4	9961 165323	VERA EGOROVA	{"phone": "+70482355495"}
0005433921620	D84D5B	5881 222939	IGOR KUZNECOV	{"phone": "+70145389699"}
0005433921621	4BAE8E	4583 432989	EVGENIY VOLKOV	{"email": "volkove_021968@postgrespro.ru", "phone": "+70643160239"}
0005433921622	27419A	1256 122507	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana-07011980@postgrespro.ru", "phone": "+70195175674"}
0005433921623	D8524C	6282 097356	VASILIY KULIKOV	{"email": "kulikov-vasiliy25081967@postgrespro.ru", "phone": "+70639121086"}
0005433921624	88B582	3756 038799	TATYANA PAVLOVA	{"email": "pavlova-t-02031981@postgrespro.ru", "phone": "+70911784351"}
0005433921625	88B582	7884 911223	MIKHAIL KUZNECOV	{"email": "kuznecov_m17111979@postgrespro.ru", "phone": "+70673157466"}
0005433921626	88B582	0872 033103	OLGA OVCHINNIKOVA	{"email": "ovchinnikova.o01051974@postgrespro.ru", "phone": "+70105618332"}
0005433921627	2FADA7	6674 478379	SERGEY KAZAKOV	{"phone": "+70685201373"}
0005433921628	E941AF	4657 017993	YULIYA ROMANOVA	{"phone": "+70951997346"}
0005433921629	293B2E	6098 065923	DMITRIY KOROLEV	{"phone": "+70364972011"}
0005433921630	1E0A52	3877 000318	VIKTOR MAKAROV	{"email": "viktormakarov-18041975@postgrespro.ru", "phone": "+70331857961"}
0005433921631	1E0A52	1761 731957	ELENA RYABOVA	{"phone": "+70114574250"}
0005433921632	9F8DFB	1896 632828	ALEKSANDR ISAEV	{"email": "isaev-aleksandr-05041974@postgrespro.ru", "phone": "+70656948298"}
0005433921633	9F8DFB	1661 433517	VERA RODIONOVA	{"email": "vrodionova-1967@postgrespro.ru", "phone": "+70383479542"}
0005433921634	9F8DFB	5771 770608	MIKHAIL KUZNECOV	{"phone": "+70576495402"}
0005433921635	B29CE4	9874 761873	ANNA MARTYNOVA	{"phone": "+70419489647"}
0005433921636	EF7C20	1859 242864	ANATOLIY ROMANOV	{"email": "romanovanatoliy1974@postgrespro.ru", "phone": "+70050273210"}
0005433921637	6B757C	5111 503734	EVGENIY MIRONOV	{"email": "mironov_e041977@postgrespro.ru", "phone": "+70350940658"}
0005433921638	6B757C	3549 586179	ANATOLIY ILIN	{"email": "anatoliy_ilin.1973@postgrespro.ru", "phone": "+70404370711"}
0005433921639	AA326A	7406 196801	OLGA MIKHAYLOVA	{"email": "mikhaylova_o-051980@postgrespro.ru", "phone": "+70682086284"}
0005433921640	B0DA87	5138 188441	KIRILL ALEKSANDROV	{"phone": "+70835375976"}
0005433921641	5F355D	4971 888056	IVAN OSIPOV	{"email": "iosipov-19041971@postgrespro.ru", "phone": "+70566209566"}
0005433921642	45C880	8144 754008	GERMAN ZHURAVLEV	{"email": "zhuravlevgerman.1971@postgrespro.ru", "phone": "+70243437139"}
0005433921643	95BB24	6294 955117	TATYANA EFREMOVA	{"phone": "+70455472597"}
0005433921644	10C3E0	2114 445710	NATALYA IVANOVA	{"email": "natalya-ivanova.031964@postgrespro.ru", "phone": "+70771918755"}
0005433921645	4F98B7	0451 867525	EVDOKIYA ILINA	{"email": "evdokiyailina-1966@postgrespro.ru", "phone": "+70812081452"}
0005433921646	CCE2BC	4057 997726	MAKSIM IVANOV	{"email": "ivanov_maksim_061972@postgrespro.ru", "phone": "+70775742112"}
0005433921647	CCE2BC	6448 587170	ELENA SOROKINA	{"email": "sorokina.elena.14081978@postgrespro.ru", "phone": "+70260736555"}
0005433921648	5C64A7	4748 093631	EGOR CHERNOV	{"phone": "+70185277606"}
0005433921649	D3D598	7987 151938	IRINA SCHERBAKOVA	{"phone": "+70753260827"}
0005433921650	D3D598	8685 075657	FAINA TROFIMOVA	{"phone": "+70093628813"}
0005433921651	D3D598	8872 134896	VALENTINA KOROLEVA	{"phone": "+70669100695"}
0005433921652	16FB89	1491 207849	SVETLANA EGOROVA	{"email": "egorova_s.1979@postgrespro.ru", "phone": "+70404473456"}
0005433921653	5414D6	0519 659593	SERGEY PAVLOV	{"phone": "+70479980955"}
0005433921654	5414D6	6280 794081	VYACHESLAV BELOV	{"phone": "+70638133659"}
0005433921655	78A389	0088 562492	DMITRIY ANTONOV	{"email": "d-antonov.111979@postgrespro.ru", "phone": "+70549601572"}
0005433921656	AD2C05	0931 814525	VIKTORIYA VOLKOVA	{"email": "volkova.viktoriya.22031977@postgrespro.ru", "phone": "+70186209701"}
0005433921657	AD2C05	1871 869289	EVGENIYA KARPOVA	{"email": "evgeniya.karpova-05051967@postgrespro.ru", "phone": "+70867358359"}
0005433921658	EF8D34	1231 128630	NATALYA ANTONOVA	{"email": "antonova.natalya-17101976@postgrespro.ru", "phone": "+70039701821"}
0005433921659	5AA1F3	6624 232234	SVETLANA KOZLOVA	{"phone": "+70938929013"}
0005433921660	5AA1F3	2294 614412	IGOR DENISOV	{"email": "idenisov-09011975@postgrespro.ru", "phone": "+70115833404"}
0005433921661	B35E0B	6372 766081	VASILIY MOROZOV	{"email": "vasiliymorozov.111962@postgrespro.ru", "phone": "+70567544318"}
0005433921662	1E41E6	1707 708312	OLGA SOROKINA	{"email": "sorokinao.1974@postgrespro.ru", "phone": "+70479695407"}
0005433921663	459843	9909 455422	IRINA ZHURAVLEVA	{"email": "zhuravlevai_01031973@postgrespro.ru", "phone": "+70812260894"}
0005433921664	459843	6687 002741	IRINA BORISOVA	{"email": "borisova-i_16011976@postgrespro.ru", "phone": "+70831422128"}
0005433921665	AD9F25	5602 517623	VALENTINA ABRAMOVA	{"email": "abramovavalentina16031968@postgrespro.ru", "phone": "+70525827012"}
0005433921666	FB058D	6745 982661	KONSTANTIN ZAYCEV	{"phone": "+70319790236"}
0005433921667	838DA0	4855 393685	PAVEL PAVLOV	{"email": "pavlov-pavel-1975@postgrespro.ru", "phone": "+70109344096"}
0005433921668	33C517	0458 794399	OKSANA NESTEROVA	{"phone": "+70171460721"}
0005433921669	3250D9	3263 027985	DARYA BELYAEVA	{"email": "belyaevadarya031987@postgrespro.ru", "phone": "+70257777073"}
0005433921670	1AD757	4698 685655	VALENTINA VLASOVA	{"phone": "+70539302242"}
0005433921671	1AD757	7899 532751	NATALYA DMITRIEVA	{"email": "dmitrieva.n-031973@postgrespro.ru", "phone": "+70505845131"}
0005433921672	B27FFD	5627 808733	IGOR PAVLOV	{"phone": "+70516081962"}
0005433921673	05FEC3	9155 063066	YURIY ALEKSEEV	{"email": "yuriy.alekseev.031979@postgrespro.ru", "phone": "+70810231411"}
0005433921674	E8A3E2	6306 589120	ALEKSEY STEPANOV	{"phone": "+70950377337"}
0005433921675	E8A3E2	1949 939393	FANIL POPOV	{"email": "fanil.popov.1975@postgrespro.ru", "phone": "+70104956800"}
0005433921676	10AE45	2020 031878	VERA RODIONOVA	{"phone": "+70999391388"}
0005433921677	05D9FB	4460 508142	ELENA FOMINA	{"phone": "+70018151014"}
0005433921678	03184C	3341 510590	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova23121974@postgrespro.ru", "phone": "+70274340256"}
0005433921679	03184C	9571 550971	MIKHAIL SCHERBAKOV	{"email": "scherbakov-m-04061970@postgrespro.ru", "phone": "+70214513801"}
0005433921680	03184C	3655 805079	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov04081987@postgrespro.ru", "phone": "+70471837867"}
0005433921681	861DA9	8855 162967	EMILIYA ABRAMOVA	{"phone": "+70699698604"}
0005433921682	861DA9	4851 986059	VASILIY ROMANOV	{"phone": "+70057842589"}
0005433921683	861DA9	2873 369872	LYUBOV KOROLEVA	{"phone": "+70688607428"}
0005433921684	861DA9	2032 048991	GALINA LOGINOVA	{"email": "g_loginova-041964@postgrespro.ru", "phone": "+70304992141"}
0005433921685	3F9B37	4353 318614	ALEKSEY KARPOV	{"email": "karpov_aleksey.08101967@postgrespro.ru", "phone": "+70967464751"}
0005433921686	9F3927	8433 284028	NINA SAVELEVA	{"email": "n_saveleva.011976@postgrespro.ru", "phone": "+70087672151"}
0005433921687	57369A	7353 450712	DMITRIY IVANOV	{"email": "dmitriy.ivanov1982@postgrespro.ru", "phone": "+70015967303"}
0005433921688	C8F85A	6259 130253	VASILIY TIKHONOV	{"email": "tikhonov_v_1966@postgrespro.ru", "phone": "+70311162822"}
0005433921689	C8F85A	1976 680398	EKATERINA SMIRNOVA	{"phone": "+70762401877"}
0005433921690	C55EA5	6833 001298	POLINA GORBUNOVA	{"phone": "+70450715814"}
0005433921691	F7C4B8	9653 015379	IRINA ILINA	{"email": "i.ilina.121984@postgrespro.ru", "phone": "+70808992814"}
0005433921692	F7C4B8	3179 048821	LYUBOV POLYAKOVA	{"email": "lyubov_polyakova071969@postgrespro.ru", "phone": "+70683082859"}
0005433921693	0948BE	9992 230902	OLEG RODIONOV	{"email": "oleg-rodionov_27031966@postgrespro.ru", "phone": "+70261301539"}
0005433921694	0948BE	9442 274234	ALEKSANDR FROLOV	{"phone": "+70956701427"}
0005433921695	D648EF	8867 546769	ELENA MAKSIMOVA	{"email": "elena_maksimova1976@postgrespro.ru", "phone": "+70727851466"}
0005433921696	C6F7A9	7678 686971	ROMAN KOZLOV	{"email": "roman.kozlov-1974@postgrespro.ru", "phone": "+70050208270"}
0005433921697	059B10	6527 842796	ALEKSEY RODIONOV	{"phone": "+70725905805"}
0005433921698	2ADD1D	5404 014907	VIKTOR MELNIKOV	{"phone": "+70232848692"}
0005433921699	C7679C	3841 714980	TAISIYA SMIRNOVA	{"email": "taisiya_smirnova.1983@postgrespro.ru", "phone": "+70465248208"}
0005433921700	C7679C	0137 415758	OLGA POPOVA	{"email": "olga_popova_1981@postgrespro.ru", "phone": "+70852847881"}
0005433921701	142162	9598 869637	YAKOV DENISOV	{"phone": "+70484936684"}
0005433921702	E6F32F	7204 149149	SVETLANA FEDOROVA	{"phone": "+70878694105"}
0005433921703	E6F32F	0692 844917	NIKOLAY ANTONOV	{"phone": "+70761504701"}
0005433921704	2E3D9A	9122 922546	YURIY ANTONOV	{"email": "yuriy-antonov_1972@postgrespro.ru", "phone": "+70969541536"}
0005433921705	7B13EF	3350 799036	NINA ABRAMOVA	{"email": "abramova-n.17021977@postgrespro.ru", "phone": "+70821081284"}
0005433921706	E7C735	9804 130228	DMITRIY FEDOTOV	{"phone": "+70215904444"}
0005433921707	E7C735	7457 479725	ELENA MELNIKOVA	{"phone": "+70346479159"}
0005433921708	08346A	9883 080838	TATYANA KOLESNIKOVA	{"email": "kolesnikova.t.071970@postgrespro.ru", "phone": "+70669065142"}
0005433921709	200D83	2652 041028	VALENTINA KOROLEVA	{"phone": "+70478148082"}
0005433921710	CBE426	2232 446919	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr_01061974@postgrespro.ru", "phone": "+70280469975"}
0005433921711	9BADF4	7329 463265	VLADIMIR IVANOV	{"email": "v_ivanov-071965@postgrespro.ru", "phone": "+70100047884"}
0005433921712	ADF9F9	3346 123067	VLADISLAV GORBUNOV	{"email": "gorbunov_vladislav.081963@postgrespro.ru", "phone": "+70894583280"}
0005433921713	ADF9F9	4451 792740	ALENA IVANOVA	{"phone": "+70308877032"}
0005433921714	F5343B	8084 773790	NATALYA FEDOROVA	{"phone": "+70484779809"}
0005433921715	753855	0091 142734	VLADISLAV KOROLEV	{"phone": "+70755126057"}
0005433921716	5088BA	3447 137032	SERGEY BELOV	{"email": "belov-s_1966@postgrespro.ru", "phone": "+70691483104"}
0005433921717	02217E	1368 450162	TATYANA KUZNECOVA	{"phone": "+70294826646"}
0005433921718	44972E	8356 138454	EKATERINA IVANOVA	{"email": "ekaterina.ivanova.1971@postgrespro.ru", "phone": "+70681940255"}
0005433921719	A80434	0452 736724	MARIYA ARKHIPOVA	{"email": "m_arkhipova111966@postgrespro.ru", "phone": "+70777752865"}
0005433921720	72D159	9631 087066	TATYANA EGOROVA	{"phone": "+70208064328"}
0005433921721	48A064	9031 973588	ALEKSEY NAZAROV	{"email": "nazarov-a091971@postgrespro.ru", "phone": "+70898951527"}
0005433921722	F05EAF	5973 235116	ELENA KOZLOVA	{"email": "elena-kozlova_1964@postgrespro.ru", "phone": "+70270871947"}
0005433921723	F05EAF	7220 038900	GALINA IVANOVA	{"phone": "+70775977223"}
0005433921724	94A28A	0335 900401	LYUDMILA LEBEDEVA	{"phone": "+70454389773"}
0005433921725	17181D	0889 870765	ANASTASIYA TIKHONOVA	{"email": "tikhonova.a05081977@postgrespro.ru", "phone": "+70588095202"}
0005433921726	CCB62E	9490 586291	DMITRIY ROMANOV	{"phone": "+70438185842"}
0005433921727	CCB62E	1122 554857	ILYA KUZNECOV	{"phone": "+70140204844"}
0005433921728	2FA888	6107 080264	MARIYA KOMAROVA	{"email": "m_komarova121972@postgrespro.ru", "phone": "+70160889614"}
0005433921729	2FA888	7308 601746	ELENA ROMANOVA	{"email": "e-romanova_1963@postgrespro.ru", "phone": "+70780898536"}
0005433921730	705F8E	0002 063477	NINEL PETROVA	{"email": "ninel_petrova1968@postgrespro.ru", "phone": "+70451649274"}
0005433921731	705F8E	2491 099516	NIKITA KOROLEV	{"email": "korolev_n_071987@postgrespro.ru", "phone": "+70369943359"}
0005433921732	C5AEED	7553 767204	GRIGORIY MIKHAYLOV	{"phone": "+70765329719"}
0005433921733	3E0BCA	2331 267904	EDUARD FEDOTOV	{"email": "e.fedotov1969@postgrespro.ru", "phone": "+70107498529"}
0005433921734	3E0BCA	8840 073894	EVGENIY EGOROV	{"email": "egorovevgeniy_07121963@postgrespro.ru", "phone": "+70483971505"}
0005433921735	3B98D4	3364 304269	NADEZHDA ZAYCEVA	{"email": "zayceva-n-1980@postgrespro.ru", "phone": "+70075398688"}
0005433921736	4649BC	5997 207318	VASILIY GERASIMOV	{"email": "v_gerasimov-021976@postgrespro.ru", "phone": "+70327538000"}
0005433921737	A7A7F1	2209 074850	ANNA NIKITINA	{"phone": "+70736058809"}
0005433921906	DB0EF2	6154 629320	EKATERINA BORISOVA	{"phone": "+70009629510"}
0005433921738	A7A7F1	0006 066628	NATALYA FROLOVA	{"email": "n-frolova-08071976@postgrespro.ru", "phone": "+70863168331"}
0005433921739	A7A7F1	2606 056439	MARGARITA FROLOVA	{"email": "frolova.m_1970@postgrespro.ru", "phone": "+70372614077"}
0005433921740	73C3D6	7378 972894	YULIYA STEPANOVA	{"email": "stepanova-y24081964@postgrespro.ru", "phone": "+70333905708"}
0005433921741	73C3D6	3920 662877	SVETLANA ABRAMOVA	{"email": "abramova-s061978@postgrespro.ru", "phone": "+70669528384"}
0005433921742	73C3D6	4153 558354	OLGA ERMAKOVA	{"email": "olgaermakova.11071964@postgrespro.ru", "phone": "+70821634228"}
0005433921743	C70C75	8991 485121	NIKOLAY KUZNECOV	{"phone": "+70093134009"}
0005433921744	241617	9597 789721	ZHANNA KOVALEVA	{"phone": "+70762050753"}
0005433921745	036EA2	4647 307343	EVGENIY KISELEV	{"phone": "+70053437826"}
0005433921746	036EA2	1186 185664	IRINA TIKHONOVA	{"phone": "+70878339448"}
0005433921747	036EA2	9890 657226	ANNA TIKHONOVA	{"email": "tikhonova-a071965@postgrespro.ru", "phone": "+70397236287"}
0005433921748	60268A	8542 286613	ZOYA NESTEROVA	{"phone": "+70882561478"}
0005433921749	D48E5E	9592 902341	IRINA ZAYCEVA	{"phone": "+70623809273"}
0005433921750	6ADCD9	8306 654754	MAKSIM KUZNECOV	{"email": "kuznecov_m18021975@postgrespro.ru", "phone": "+70118889059"}
0005433921751	07F00D	1957 304472	VLADIMIR EGOROV	{"email": "vegorov-021969@postgrespro.ru", "phone": "+70994662451"}
0005433921752	7A8E0B	3412 922615	ZLATA ILINA	{"phone": "+70091340858"}
0005433921753	7A8E0B	2172 765605	OLGA KUZMINA	{"email": "kuzmina.olga.1971@postgrespro.ru", "phone": "+70907820037"}
0005433921754	01833A	8124 963099	NIKOLAY VOLKOV	{"phone": "+70820426930"}
0005433921755	EB50C3	0690 280856	MARIYA IVANOVA	{"phone": "+70987155177"}
0005433921756	EA7FD5	7049 942078	TATYANA KUZNECOVA	{"phone": "+70910075550"}
0005433921757	EA7FD5	7733 715854	VALENTINA FROLOVA	{"email": "valentina_frolova_011973@postgrespro.ru", "phone": "+70905888089"}
0005433921758	60FBBE	4870 231864	IRINA GERASIMOVA	{"phone": "+70874362762"}
0005433921759	60FD3F	1764 844512	KRISTINA BELYAEVA	{"email": "belyaeva-k1973@postgrespro.ru", "phone": "+70659064937"}
0005433921760	60FD3F	5786 333322	ANASTASIYA SIDOROVA	{"phone": "+70039992480"}
0005433921761	86FC29	5889 969002	YULIYA MAKSIMOVA	{"email": "maksimova-y_16041974@postgrespro.ru", "phone": "+70528053985"}
0005433921762	ACA1ED	9611 124186	NATALYA MAKSIMOVA	{"phone": "+70675819858"}
0005433921763	4C9461	6979 738091	STANISLAV SOKOLOV	{"phone": "+70649780408"}
0005433921764	4C9461	8561 951057	VALENTINA ZHURAVLEVA	{"phone": "+70094068120"}
0005433921765	4C9461	8261 428243	ANNA RODIONOVA	{"email": "a.rodionova061968@postgrespro.ru", "phone": "+70462200999"}
0005433921766	493C5E	4688 519242	SVETLANA MOISEEVA	{"email": "moiseeva_s.25121974@postgrespro.ru", "phone": "+70368253656"}
0005433921767	6EB77A	6421 109584	OKSANA GORBUNOVA	{"phone": "+70287136810"}
0005433921768	D971E6	5071 985702	ANTONINA LUKYANOVA	{"email": "antonina.lukyanova_041978@postgrespro.ru", "phone": "+70164235393"}
0005433921769	551BDD	0970 646675	TATYANA FILIPPOVA	{"email": "tatyana.filippova_1972@postgrespro.ru", "phone": "+70536820364"}
0005433921770	B532AD	7101 728816	TATYANA NIKITINA	{"phone": "+70188638317"}
0005433921771	0B28CE	9184 096539	ANDREY KUZNECOV	{"phone": "+70648230137"}
0005433921772	52EE68	8464 915498	NADEZHDA ISAEVA	{"phone": "+70583345018"}
0005433921773	52EE68	2986 940276	STANISLAV DENISOV	{"phone": "+70232835536"}
0005433921774	F57AC1	1031 047780	ILYA KUDRYASHOV	{"phone": "+70681091855"}
0005433921775	5A8B02	5557 838074	LYUDMILA MIKHAYLOVA	{"phone": "+70464201065"}
0005433921776	B1DB40	5088 849955	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey-061974@postgrespro.ru", "phone": "+70556999582"}
0005433921777	B1DB40	5528 273992	EKATERINA FADEEVA	{"email": "efadeeva.22021982@postgrespro.ru", "phone": "+70851449336"}
0005433921778	E8EC66	7942 316314	ALEKSANDR KUZNECOV	{"phone": "+70374353181"}
0005433921779	6D7724	6384 453144	ELENA ROMANOVA	{"phone": "+70173612693"}
0005433921780	CC65B4	1651 431481	TAMARA ZAYCEVA	{"email": "t_zayceva23061970@postgrespro.ru", "phone": "+70716666837"}
0005433921781	CC65B4	9686 465738	ANDREY SIDOROV	{"phone": "+70270791439"}
0005433921782	D011AA	2939 979888	ANTONINA TITOVA	{"phone": "+70392283481"}
0005433921783	782737	0102 331919	TATYANA ZHURAVLEVA	{"email": "zhuravlevat.30081966@postgrespro.ru", "phone": "+70125086444"}
0005433921784	7F80B2	2190 792237	OLGA TROFIMOVA	{"phone": "+70779483810"}
0005433921785	7F80B2	4494 770419	YULIYA YUDINA	{"email": "y.yudina_1979@postgrespro.ru", "phone": "+70477587144"}
0005433921786	5AAE62	5838 382597	NINA KUZNECOVA	{"phone": "+70906899426"}
0005433921787	376F00	0350 169250	NATALYA KUZNECOVA	{"email": "n-kuznecova.041973@postgrespro.ru", "phone": "+70842518845"}
0005433921788	47AB24	1833 621579	YULIYA PETROVA	{"email": "ypetrova1972@postgrespro.ru", "phone": "+70530974949"}
0005433921789	7E04D4	3430 048655	VERA BELYAEVA	{"phone": "+70011430001"}
0005433921790	7E04D4	2140 988603	SERGEY SMIRNOV	{"phone": "+70897860049"}
0005433921791	DD4159	3343 924602	VLADIMIR ABRAMOV	{"phone": "+70620747126"}
0005433921792	86B796	3335 871401	ANATOLIY DAVYDOV	{"phone": "+70495271727"}
0005433921793	86B796	2646 821464	YULIYA ISAEVA	{"email": "y_isaeva.26101969@postgrespro.ru", "phone": "+70855879769"}
0005433921794	1DC193	2565 445805	ANATOLIY FOMIN	{"email": "fomina081965@postgrespro.ru", "phone": "+70937367257"}
0005433921795	18C027	6307 734195	ELENA LOGINOVA	{"email": "loginova.e.081972@postgrespro.ru", "phone": "+70467677305"}
0005433921796	18C027	0191 907382	TATYANA MEDVEDEVA	{"email": "medvedeva_t.1968@postgrespro.ru", "phone": "+70659014678"}
0005433921797	D716CA	3459 855962	TAMARA ZAYCEVA	{"email": "zayceva_tamara.1971@postgrespro.ru", "phone": "+70227556422"}
0005433921798	86981C	4923 944650	ALEKSEY MIKHAYLOV	{"phone": "+70923574078"}
0005433921799	FF1B49	5727 504602	EGOR POPOV	{"email": "egor_popov_1971@postgrespro.ru", "phone": "+70322166673"}
0005433921800	3CB732	4910 888802	NATALYA VASILEVA	{"email": "natalya_vasileva14121972@postgrespro.ru", "phone": "+70240397725"}
0005433921801	7312CF	7336 515817	OLEG KUDRYASHOV	{"email": "kudryashov.oleg.1961@postgrespro.ru", "phone": "+70254899169"}
0005433921802	B7DBFF	4311 523277	SERGEY MAKAROV	{"phone": "+70769491037"}
0005433921803	B7DBFF	4845 997643	YULIYA NAUMOVA	{"email": "y.naumova.19041971@postgrespro.ru", "phone": "+70991375871"}
0005433921804	166504	4391 877210	VITALIY BORISOV	{"email": "borisov.v-1965@postgrespro.ru", "phone": "+70923332613"}
0005433921805	51E18E	0929 174325	ALEKSANDR KUZNECOV	{"phone": "+70689338635"}
0005433921806	4F727B	4905 579583	ANATOLIY ZHUKOV	{"email": "zhukov_anatoliy.1974@postgrespro.ru", "phone": "+70715735983"}
0005433921807	C13EAF	7666 238160	VALENTINA EGOROVA	{"email": "valentina.egorova20021977@postgrespro.ru", "phone": "+70144242591"}
0005433921808	FB10CA	1608 647255	MAKSIM BORISOV	{"email": "borisov-m_19091965@postgrespro.ru", "phone": "+70505030029"}
0005433921809	FB10CA	9195 906703	NATALYA ANTONOVA	{"email": "natalyaantonova.26121962@postgrespro.ru", "phone": "+70149394866"}
0005433921810	80D0B0	9741 855055	VALENTINA OSIPOVA	{"phone": "+70692332387"}
0005433921811	AFC34B	4573 226532	DENIS BORISOV	{"phone": "+70735690268"}
0005433921812	598E0A	9297 186502	ANDREY BORISOV	{"phone": "+70224782383"}
0005433921813	77FFCE	7760 347590	ANNA POPOVA	{"phone": "+70464981355"}
0005433921814	89C0EF	0258 748206	KONSTANTIN BELOV	{"phone": "+70298776748"}
0005433921815	6D2334	1977 844224	LYUBOV KUZMINA	{"email": "l-kuzmina13071978@postgrespro.ru", "phone": "+70915713276"}
0005433921816	372292	9481 116316	NIKOLAY NIKOLAEV	{"phone": "+70488575605"}
0005433921817	372292	5165 019939	TATYANA KOLESNIKOVA	{"email": "kolesnikova-tatyana.1977@postgrespro.ru", "phone": "+70302361615"}
0005433921818	D0B200	2438 160600	TATYANA ZAKHAROVA	{"phone": "+70273725794"}
0005433921819	DEFB36	5332 573719	ALEKSEY TARASOV	{"email": "tarasov.aleksey_11081976@postgrespro.ru", "phone": "+70487196392"}
0005433921820	DEFB36	6852 677804	ALEKSANDR IVANOV	{"email": "a.ivanov.111974@postgrespro.ru", "phone": "+70400060017"}
0005433921821	20B37C	5844 179747	VALERIYA VASILEVA	{"email": "valeriya.vasileva121962@postgrespro.ru", "phone": "+70646048290"}
0005433921822	40D390	0943 510970	SERGEY BARANOV	{"email": "baranov-s_031969@postgrespro.ru", "phone": "+70822359647"}
0005433921823	2C893C	9349 785791	PAVEL ANTONOV	{"email": "antonovpavel_23111968@postgrespro.ru", "phone": "+70074660254"}
0005433921824	D16406	6687 144328	ALEKSANDR NIKITIN	{"email": "anikitin.21071972@postgrespro.ru", "phone": "+70118944367"}
0005433921825	D16406	0826 083803	ALEKSANDR FEDOROV	{"phone": "+70149804235"}
0005433921826	F88A2E	3247 055146	RINAT PAVLOV	{"email": "rinat_pavlov-1965@postgrespro.ru", "phone": "+70458029213"}
0005433921827	BFC365	1027 269406	NATALIYA BARANOVA	{"email": "n_baranova_061969@postgrespro.ru", "phone": "+70658966264"}
0005433921828	BFC365	5981 205836	MAKSIM SMIRNOV	{"email": "msmirnov-1975@postgrespro.ru", "phone": "+70031433940"}
0005433921829	66CE1D	1154 873741	NIKOLAY VASILEV	{"phone": "+70827631477"}
0005433921830	66CE1D	8802 209328	ALEKSANDR ZAYCEV	{"phone": "+70225230888"}
0005433921831	FDBE1A	9711 112097	ALENA FILIPPOVA	{"email": "filippova.a-041966@postgrespro.ru", "phone": "+70843433144"}
0005433921832	B620B7	3785 537886	VALERIY DAVYDOV	{"email": "valeriy-davydov.16041979@postgrespro.ru", "phone": "+70848353709"}
0005433921833	1DBC7C	1936 051030	IRINA EFIMOVA	{"phone": "+70836466345"}
0005433921834	158E66	0774 939307	TATYANA KUZMINA	{"email": "tatyana.kuzmina.1961@postgrespro.ru", "phone": "+70569942866"}
0005433921835	DCF12C	0062 562023	LYUBOV ABRAMOVA	{"email": "lyubov_abramova.24071980@postgrespro.ru", "phone": "+70488587301"}
0005433921836	04EE4E	6065 350789	ALEKSANDR BORISOV	{"phone": "+70519921882"}
0005433921837	65A62D	5372 303034	NIKOLAY MATVEEV	{"phone": "+70979050926"}
0005433921838	514AA9	0036 224839	STANISLAV IVANOV	{"email": "ivanov.stanislav.051977@postgrespro.ru", "phone": "+70708405776"}
0005433921839	514AA9	5646 782215	ELMIRA BOGDANOVA	{"email": "bogdanova_elmira-1963@postgrespro.ru", "phone": "+70474261637"}
0005433921840	3EF6D6	4567 009971	TIMOFEY SOROKIN	{"phone": "+70623061118"}
0005433921841	3EF6D6	4047 618946	NATALYA VOLKOVA	{"phone": "+70449268823"}
0005433921842	677D4C	6184 844405	KRISTINA VASILEVA	{"phone": "+70767954956"}
0005433921843	677D4C	4991 797892	GENNADIY SAVELEV	{"phone": "+70348508224"}
0005433921844	5FE2D3	8304 353897	IRINA PETROVA	{"email": "petrova.irina_12021976@postgrespro.ru", "phone": "+70941158682"}
0005433921845	5FE2D3	9496 991545	IGOR EGOROV	{"email": "egorov.i.1966@postgrespro.ru", "phone": "+70156857651"}
0005433921846	7E4CA7	0977 574723	KONSTANTIN NIKOLAEV	{"phone": "+70839769309"}
0005433921847	5FEB02	1060 107151	ELENA KUZNECOVA	{"phone": "+70427289383"}
0005433921848	5FEB02	3915 520419	IVAN KOZLOV	{"phone": "+70465609941"}
0005433921849	5FEB02	6590 702124	ALEKSANDR BARANOV	{"phone": "+70920280494"}
0005433921963	B21CB9	3423 370662	ELENA ORLOVA	{"phone": "+70789327385"}
0005433921850	39AAE6	6911 001703	STANISLAV ROMANOV	{"email": "romanov-stanislav-08111964@postgrespro.ru", "phone": "+70322016095"}
0005433921851	19BBE7	9864 135449	STANISLAV SCHERBAKOV	{"phone": "+70050447474"}
0005433921852	205ECA	3071 601684	OLEG KISELEV	{"phone": "+70019368918"}
0005433921853	205ECA	4768 370912	NATALYA IVANOVA	{"phone": "+70085376239"}
0005433921854	594398	3640 939400	ANATOLIY GRIGOREV	{"email": "anatoliygrigorev_091969@postgrespro.ru", "phone": "+70963894151"}
0005433921855	2FCA92	9258 414805	ALEKSANDR FROLOV	{"email": "frolovaleksandr_28041970@postgrespro.ru", "phone": "+70154993003"}
0005433921856	652B17	5401 640637	MARIYA TIMOFEEVA	{"email": "mariyatimofeeva.1971@postgrespro.ru", "phone": "+70275632692"}
0005433921857	6999E4	5890 403014	ALEKSANDR BARANOV	{"phone": "+70471186502"}
0005433921858	6AAB34	4763 951362	VALENTINA FROLOVA	{"phone": "+70904144672"}
0005433921859	B4D5C4	5272 480699	GEORGIY ZHUKOV	{"phone": "+70661924217"}
0005433921860	5808CA	2050 882469	SVETLANA SEMENOVA	{"email": "semenovasvetlana-27041962@postgrespro.ru", "phone": "+70343052688"}
0005433921861	5808CA	5316 866718	VALERIY MIRONOV	{"phone": "+70999412907"}
0005433921862	355D41	5130 142174	NINA SEMENOVA	{"phone": "+70347051565"}
0005433921863	355D41	3202 877953	SERGEY IVANOV	{"phone": "+70146709266"}
0005433921864	567996	4171 840532	GALINA VOLKOVA	{"email": "volkova.galina.1978@postgrespro.ru", "phone": "+70306468234"}
0005433921865	567996	7356 564987	SOFYA KUZMINA	{"email": "kuzmina_sofya061976@postgrespro.ru", "phone": "+70680275477"}
0005433921866	FD07B0	9829 017195	IVAN FILIPPOV	{"email": "ivanfilippov_071973@postgrespro.ru", "phone": "+70607369616"}
0005433921867	88D8CB	3264 337872	ALEKSANDR MAKSIMOV	{"phone": "+70606525251"}
0005433921868	949516	7620 332670	VLADIMIR SCHERBAKOV	{"email": "vladimir_scherbakov_13091971@postgrespro.ru", "phone": "+70507483668"}
0005433921869	949516	9256 370234	ANNA SOKOLOVA	{"phone": "+70031759485"}
0005433921870	85EA3B	2240 155986	ELENA DMITRIEVA	{"phone": "+70826367732"}
0005433921871	85EA3B	5931 153243	ANATOLIY SOLOVEV	{"email": "solovev.a-28021970@postgrespro.ru", "phone": "+70223241974"}
0005433921872	9099A5	3762 118881	OKSANA IVANOVA	{"email": "oksana.ivanova_11061968@postgrespro.ru", "phone": "+70803729940"}
0005433921873	9099A5	1119 818631	NADEZHDA KOZLOVA	{"email": "kozlova_nadezhda061980@postgrespro.ru", "phone": "+70226728732"}
0005433921874	9099A5	1747 467877	KSENIYA SEMENOVA	{"phone": "+70099795431"}
0005433921875	1974E6	7527 325671	MARINA KISELEVA	{"email": "m-kiseleva1969@postgrespro.ru", "phone": "+70130486379"}
0005433921876	1974E6	9863 969740	ANNA GORBUNOVA	{"phone": "+70842983161"}
0005433921877	74E559	8352 594166	TATYANA NAZAROVA	{"email": "t.nazarova-27021976@postgrespro.ru", "phone": "+70553990798"}
0005433921878	74E559	3305 304753	MIKHAIL MEDVEDEV	{"email": "m_medvedev.1967@postgrespro.ru", "phone": "+70974398994"}
0005433921879	651E2C	3465 626170	SVETLANA SMIRNOVA	{"phone": "+70895481104"}
0005433921880	C667C0	1312 354789	KIRILL KUZMIN	{"email": "kuzmin-k.1982@postgrespro.ru", "phone": "+70207478701"}
0005433921881	C5E275	7514 208693	LIDIYA SIDOROVA	{"phone": "+70714905785"}
0005433921882	C5E275	1358 211423	SERGEY ANDREEV	{"email": "andreev_s-24071969@postgrespro.ru", "phone": "+70509297634"}
0005433921883	70E0E1	0668 426421	ELENA ANDREEVA	{"phone": "+70870826361"}
0005433921884	CB9919	5319 835393	VALENTINA NIKITINA	{"email": "vnikitina_1969@postgrespro.ru", "phone": "+70105123558"}
0005433921885	CB9919	4637 334041	IVAN PETROV	{"phone": "+70268717645"}
0005433921886	AEFE2E	8120 656799	PAVEL FROLOV	{"email": "pavel_frolov.1988@postgrespro.ru", "phone": "+70658479921"}
0005433921887	8A605E	3624 109388	MAKSIM MARTYNOV	{"phone": "+70360074772"}
0005433921888	8A605E	9205 917162	SVETLANA KUZMINA	{"email": "kuzmina.svetlana_1961@postgrespro.ru", "phone": "+70069382427"}
0005433921889	D376BC	3737 160201	SERGEY PETROV	{"phone": "+70589436200"}
0005433921890	D376BC	0122 031744	VALENTINA FEDOROVA	{"phone": "+70730041526"}
0005433921891	D376BC	5809 962529	NIKOLAY NAUMOV	{"email": "n-naumov-091973@postgrespro.ru", "phone": "+70882001695"}
0005433921892	DE66CE	0676 020958	SVETLANA DENISOVA	{"email": "sdenisova_09071977@postgrespro.ru", "phone": "+70700785349"}
0005433921893	DE66CE	2839 480532	GENNADIY BARANOV	{"phone": "+70890974784"}
0005433921894	7201D2	2800 006852	ZINAIDA SOROKINA	{"phone": "+70465616658"}
0005433921895	7201D2	4889 837222	EVGENIYA VOLKOVA	{"email": "evgeniya_volkova16091972@postgrespro.ru", "phone": "+70040263669"}
0005433921896	8EBDA0	4243 469643	TATYANA NAUMOVA	{"phone": "+70386584177"}
0005433921897	8EBDA0	8458 789975	NIKOLAY BORISOV	{"phone": "+70019395202"}
0005433921898	EC22E6	1363 512254	LYUDMILA RODIONOVA	{"email": "rodionova.l.031970@postgrespro.ru", "phone": "+70211704963"}
0005433921899	04E6D8	6005 051447	EVDOKIYA KUZNECOVA	{"email": "ekuznecova.04031969@postgrespro.ru", "phone": "+70390062623"}
0005433921900	04E6D8	0683 605226	VERA PETROVA	{"phone": "+70465131255"}
0005433921901	F36768	2059 953147	VALENTINA LUKYANOVA	{"email": "valentina.lukyanova.1967@postgrespro.ru", "phone": "+70008651449"}
0005433921902	F36768	4288 868914	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov-1972@postgrespro.ru", "phone": "+70972022218"}
0005433921903	F36768	9153 855671	GALINA KOROLEVA	{"phone": "+70548438051"}
0005433921904	9F18B5	6238 407023	ARTEM SMIRNOV	{"email": "smirnovartem_1963@postgrespro.ru", "phone": "+70469183194"}
0005433921905	DB0EF2	4836 873818	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova1963@postgrespro.ru", "phone": "+70033379655"}
0005433921907	E3B995	1211 428050	TATYANA DMITRIEVA	{"email": "dmitrieva-t.21121971@postgrespro.ru", "phone": "+70025408067"}
0005433921908	290C82	7396 676512	YULIYA VLASOVA	{"email": "vlasova-yuliya.11021982@postgrespro.ru", "phone": "+70352633311"}
0005433921909	290C82	3760 115321	KONSTANTIN ZAKHAROV	{"phone": "+70991758366"}
0005433921910	4EF4FD	6072 676182	VALENTINA FROLOVA	{"phone": "+70398567676"}
0005433921911	D8919A	3876 967079	GALINA BORISOVA	{"phone": "+70240733154"}
0005433921912	1FB761	3785 199117	VITALIY GERASIMOV	{"phone": "+70822249295"}
0005433921913	FEA340	1144 925171	ARTEM DENISOV	{"phone": "+70698470346"}
0005433921914	B3136C	6309 579379	OLGA STEPANOVA	{"email": "o-stepanova-1974@postgrespro.ru", "phone": "+70452367103"}
0005433921915	E3B9E4	2956 522352	ALEKSEY GAVRILOV	{"phone": "+70682488657"}
0005433921916	AA01C7	5611 460212	OLGA NAUMOVA	{"email": "naumova-o.1975@postgrespro.ru", "phone": "+70079919048"}
0005433921917	D27047	7025 040336	KSENIYA KRASNOVA	{"email": "krasnova.kseniya.031971@postgrespro.ru", "phone": "+70455710470"}
0005433921918	D27047	8237 170288	YULIYA EGOROVA	{"phone": "+70604554766"}
0005433921919	D27047	7949 383873	VLADIMIR GAVRILOV	{"email": "vgavrilov_20031980@postgrespro.ru", "phone": "+70327558808"}
0005433921920	D27047	7766 949945	OLGA KULIKOVA	{"email": "kulikova-olga-1973@postgrespro.ru", "phone": "+70113057636"}
0005433921921	A0FD07	6846 872533	VALENTINA GERASIMOVA	{"email": "gerasimova.valentina_24081982@postgrespro.ru", "phone": "+70935268336"}
0005433921922	7620C1	1392 726753	ALEKSEY ZAKHAROV	{"phone": "+70958244319"}
0005433921923	7620C1	3516 385145	TATYANA NOVIKOVA	{"email": "novikova_t1983@postgrespro.ru", "phone": "+70081676477"}
0005433921924	7620C1	9484 770827	MARIYA NIKOLAEVA	{"phone": "+70044232533"}
0005433921925	FB7377	1130 305949	ALEKSEY SEMENOV	{"email": "semenovaleksey18071971@postgrespro.ru", "phone": "+70929000003"}
0005433921926	FB7377	0207 860739	ALEKSANDR IVANOV	{"phone": "+70437341425"}
0005433921927	8EBF13	5364 588350	VIKTOR EGOROV	{"email": "viktor_egorov071960@postgrespro.ru", "phone": "+70823578045"}
0005433921928	A7A674	6433 103385	ELENA ANDREEVA	{"email": "e-andreeva.121979@postgrespro.ru", "phone": "+70268745063"}
0005433921929	B99E03	3115 800542	ELENA KUZNECOVA	{"phone": "+70267281809"}
0005433921930	C9331F	1006 029486	ELIZAVETA NIKITINA	{"email": "e.nikitina091970@postgrespro.ru", "phone": "+70711350618"}
0005433921931	A883A6	3853 151627	OLEG CHERNOV	{"phone": "+70198000555"}
0005433921932	A035B6	1590 363148	ZOYA ILINA	{"phone": "+70227796976"}
0005433921933	35FD19	0930 370908	YURIY KAZAKOV	{"phone": "+70248803040"}
0005433921934	DA9961	4858 023038	OLGA ABRAMOVA	{"email": "olgaabramova.19101970@postgrespro.ru", "phone": "+70952304006"}
0005433921935	DA9961	0172 391139	VALERIY MIKHAYLOV	{"email": "mikhaylov.valeriy20041968@postgrespro.ru", "phone": "+70645695873"}
0005433921936	FA08A5	9053 964765	ELENA NIKITINA	{"email": "elenanikitina15101974@postgrespro.ru", "phone": "+70478691094"}
0005433921937	5149D9	1960 757645	ANNA NOVIKOVA	{"phone": "+70741878542"}
0005433921938	3F61D9	4325 369397	KSENIYA SOKOLOVA	{"phone": "+70229323591"}
0005433921939	C354EA	2855 643106	DMITRIY KONOVALOV	{"email": "dmitriy_konovalov22101963@postgrespro.ru", "phone": "+70723836976"}
0005433921940	0FF5F8	7829 023973	NINA SOKOLOVA	{"email": "n_sokolova.1975@postgrespro.ru", "phone": "+70426745983"}
0005433921941	27A086	2571 124744	ALEKSANDR MAKAROV	{"email": "makarovaleksandr_1960@postgrespro.ru", "phone": "+70836569788"}
0005433921942	D4CDB8	1134 551796	ELENA MAKSIMOVA	{"phone": "+70763293124"}
0005433921943	9648C0	3285 968002	VALERIY DMITRIEV	{"phone": "+70099506925"}
0005433921944	50F110	9956 717228	ANDREY DAVYDOV	{"phone": "+70733836022"}
0005433921945	9919F8	2822 138205	LARISA ZHUKOVA	{"email": "l.zhukova_13041958@postgrespro.ru", "phone": "+70875861275"}
0005433921946	25BB33	5618 886109	ANNA ISAEVA	{"email": "aisaeva-071981@postgrespro.ru", "phone": "+70254248123"}
0005433921947	25BB33	2577 051456	VALENTINA POLYAKOVA	{"email": "valentina_polyakova041975@postgrespro.ru", "phone": "+70650476617"}
0005433921948	30D005	4416 471715	KRISTINA SIDOROVA	{"email": "sidorovakristina-121972@postgrespro.ru", "phone": "+70477023011"}
0005433921949	626A5F	7134 405549	EKATERINA STEPANOVA	{"email": "stepanovae_1965@postgrespro.ru", "phone": "+70141343365"}
0005433921950	774012	6051 207314	MARIYA PETROVA	{"phone": "+70760767746"}
0005433921951	143D22	5764 206828	NATALYA NIKITINA	{"phone": "+70172269778"}
0005433921952	ED2404	3867 032830	ALEKSANDR SEMENOV	{"email": "a.semenov31121965@postgrespro.ru", "phone": "+70022804387"}
0005433921953	ECAB8D	7467 205734	NADEZHDA OSIPOVA	{"phone": "+70806938070"}
0005433921954	AFE788	9457 284263	ALEKSANDR MIKHAYLOV	{"phone": "+70442414678"}
0005433921955	E652EB	9242 597300	ALLA FOMINA	{"phone": "+70653847348"}
0005433921956	A9BD3F	3765 095369	DMITRIY ISAEV	{"email": "dmitriy-isaev.08081976@postgrespro.ru", "phone": "+70583764951"}
0005433921957	CCB266	0965 215342	ARTEM KUDRYASHOV	{"phone": "+70877147843"}
0005433921958	CCB266	6094 299631	VALERIY GAVRILOV	{"email": "gavrilovvaleriy-041968@postgrespro.ru", "phone": "+70405227815"}
0005433921959	989C64	5679 652851	VADIM ABRAMOV	{"phone": "+70091670430"}
0005433921960	111DBA	8801 458391	IRINA MOROZOVA	{"email": "morozova.i.1972@postgrespro.ru", "phone": "+70491497171"}
0005433921961	127301	5901 842759	VALENTINA STEPANOVA	{"email": "valentina_stepanova_021970@postgrespro.ru", "phone": "+70030504478"}
0005433921962	073DFE	8181 732193	OLGA STEPANOVA	{"email": "stepanova_olga02091978@postgrespro.ru", "phone": "+70853578176"}
0005433921964	E4AE3E	6589 406643	SERGEY BORISOV	{"phone": "+70296129461"}
0005433921965	E4AE3E	8486 338814	KONSTANTIN IVANOV	{"phone": "+70654816545"}
0005433921966	D41F16	0258 062518	LYUDMILA BELYAEVA	{"email": "belyaeva-l_24121975@postgrespro.ru", "phone": "+70723302439"}
0005433921967	D41F16	4707 378710	DARYA LEBEDEVA	{"phone": "+70545770946"}
0005433921968	216D23	5626 490890	LIDIYA KISELEVA	{"phone": "+70067517232"}
0005433921969	00C82D	8558 264319	NIKOLAY GUSEV	{"phone": "+70334829933"}
0005433921970	E5BD39	2808 404458	ILMIRA PETROVA	{"email": "i_petrova.1974@postgrespro.ru", "phone": "+70684815223"}
0005433921971	E5BD39	5865 646970	LIDIYA PETROVA	{"email": "petrovalidiya-101970@postgrespro.ru", "phone": "+70379382192"}
0005433921972	341A4A	3538 350039	EKATERINA VASILEVA	{"email": "vasileva-e1976@postgrespro.ru", "phone": "+70061765448"}
0005433921973	58D460	8001 091461	YAN MAKAROV	{"email": "makarovyan.1963@postgrespro.ru", "phone": "+70503972010"}
0005433921974	40D718	9386 248573	TATYANA SOROKINA	{"email": "sorokina-t_1982@postgrespro.ru", "phone": "+70663115338"}
0005433921975	A2D03C	1499 764880	MARIYA MASLOVA	{"phone": "+70723762980"}
0005433921976	A2D03C	1834 540629	ANNA STEPANOVA	{"phone": "+70046202548"}
0005433921977	F96332	8951 656784	ALEKSEY BELOV	{"phone": "+70493134984"}
0005433921978	D9A39C	3234 029199	VIKTOR KUZNECOV	{"email": "vkuznecov-19051964@postgrespro.ru", "phone": "+70872391279"}
0005433921979	D9A39C	6460 079275	ARINA KUZNECOVA	{"email": "arina.kuznecova-1971@postgrespro.ru", "phone": "+70629627473"}
0005433921980	0C9BD2	9558 930910	MIKHAIL KUZNECOV	{"phone": "+70927590756"}
0005433921981	0C9BD2	3901 641817	ELIZAVETA KARPOVA	{"phone": "+70226664031"}
0005433921982	5419BD	3180 280645	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov.1963@postgrespro.ru", "phone": "+70169310480"}
0005433921983	4074FC	2797 847489	LEONID TIMOFEEV	{"phone": "+70493838079"}
0005433921984	4074FC	9811 663381	ELENA KUZMINA	{"email": "e.kuzmina-1964@postgrespro.ru", "phone": "+70962222322"}
0005433922044	764961	6549 643908	VIKTOR DMITRIEV	{"phone": "+70634556661"}
0005433921985	FBC20F	4074 044971	YURIY KRASNOV	{"email": "y-krasnov_1983@postgrespro.ru", "phone": "+70086195369"}
0005433921986	148471	3455 159076	OLGA FILATOVA	{"phone": "+70178282983"}
0005433921987	CA99CB	2567 301660	IRINA FILATOVA	{"phone": "+70429467453"}
0005433921988	CA99CB	9663 852326	TATYANA GORBUNOVA	{"phone": "+70764098619"}
0005433921989	5750FB	1939 825633	NATALYA KISELEVA	{"phone": "+70489915034"}
0005433921990	5750FB	9759 017729	SERAFIM TIMOFEEV	{"email": "serafim_timofeev_1982@postgrespro.ru", "phone": "+70764291665"}
0005433921991	0FF288	5762 445852	VIKTOR ALEKSANDROV	{"email": "aleksandrovviktor111972@postgrespro.ru", "phone": "+70088601333"}
0005433921992	0FF288	2544 121697	NINA EGOROVA	{"phone": "+70142111550"}
0005433921993	447AA7	1478 300021	MAKSIM STEPANOV	{"email": "stepanov_m.061975@postgrespro.ru", "phone": "+70223171525"}
0005433921994	A4E91A	8552 913575	DMITRIY NIKITIN	{"email": "nikitin_dmitriy_091970@postgrespro.ru", "phone": "+70798240394"}
0005433921995	A4E91A	7952 417278	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-031984@postgrespro.ru", "phone": "+70738405135"}
0005433921996	806215	4545 416754	ALEKSANDR ALEKSEEV	{"phone": "+70368444453"}
0005433921997	806215	0347 931707	OLEG SOKOLOV	{"email": "oleg-sokolov1975@postgrespro.ru", "phone": "+70200065082"}
0005433921998	5B64F3	4602 739366	NATALYA OSIPOVA	{"phone": "+70193154485"}
0005433921999	5B64F3	4363 872399	TATYANA AKIMOVA	{"email": "tatyanaakimova-09061980@postgrespro.ru", "phone": "+70376141714"}
0005433922000	1EF268	7775 453902	VIKTOR KUZMIN	{"email": "v-kuzmin.031968@postgrespro.ru", "phone": "+70003506072"}
0005433922001	F39636	6173 116009	GENNADIY KUDRYASHOV	{"email": "kudryashovgennadiy-101962@postgrespro.ru", "phone": "+70675914367"}
0005433922002	142E50	4554 669723	ELENA ZOTOVA	{"email": "elena_zotova-1959@postgrespro.ru", "phone": "+70899186364"}
0005433922003	9EC682	9528 261078	RAUF MIRONOV	{"email": "rmironov-091980@postgrespro.ru", "phone": "+70646817802"}
0005433922004	9EC682	8764 045721	ANNA KUZNECOVA	{"email": "kuznecova_anna_1969@postgrespro.ru", "phone": "+70594186911"}
0005433922005	B38AE3	3743 109661	VASILIY KUZMIN	{"email": "kuzmin-v16011969@postgrespro.ru", "phone": "+70159182790"}
0005433922006	DD715B	8031 192082	OKSANA VOROBEVA	{"email": "vorobeva_oksana-25061952@postgrespro.ru", "phone": "+70318341673"}
0005433922007	DD715B	2199 904408	BORIS ZHUKOV	{"email": "boris_zhukov.1976@postgrespro.ru", "phone": "+70724722300"}
0005433922008	118630	9260 496953	IVAN ANDREEV	{"phone": "+70612188209"}
0005433922009	118630	1160 347806	DIANA KOLESNIKOVA	{"phone": "+70544873328"}
0005433922010	94C353	7577 874970	NADEZHDA IVANOVA	{"email": "ivanova-nadezhda-26111964@postgrespro.ru", "phone": "+70701926378"}
0005433922011	251B85	1979 659761	OLEG SAVELEV	{"phone": "+70656983811"}
0005433922012	A698FD	6214 910392	NINA DENISOVA	{"email": "denisova-nina_071964@postgrespro.ru", "phone": "+70857028241"}
0005433922013	A698FD	4295 255571	ALEKSANDRA FROLOVA	{"email": "frolova.aleksandra071975@postgrespro.ru", "phone": "+70716715378"}
0005433922014	E434B6	5126 510105	IGOR NIKITIN	{"email": "i-nikitin_16061972@postgrespro.ru", "phone": "+70369371719"}
0005433922015	E434B6	9758 387323	PAVEL VOLKOV	{"phone": "+70387080961"}
0005433922016	C8D460	3194 992415	NADEZHDA CHERNOVA	{"phone": "+70332158634"}
0005433922017	08DB4C	7153 897027	NADEZHDA PAVLOVA	{"phone": "+70005591992"}
0005433922018	765119	4292 872723	ELENA FROLOVA	{"email": "e.frolova-20061976@postgrespro.ru", "phone": "+70892594924"}
0005433922019	765119	5932 420102	GALINA SOLOVEVA	{"phone": "+70955467016"}
0005433922020	4B9CEB	7644 887996	VLADISLAV ILIN	{"email": "ilin_v.121961@postgrespro.ru", "phone": "+70713342037"}
0005433922021	4B9CEB	8359 036412	OLGA SOROKINA	{"phone": "+70611564158"}
0005433922022	53E99E	5608 632169	OLGA ZAKHAROVA	{"email": "zakharova-olga-031977@postgrespro.ru", "phone": "+70291543933"}
0005433922023	BC4E22	9206 432937	TATYANA GERASIMOVA	{"phone": "+70275831665"}
0005433922024	BC4E22	8516 289918	TATYANA DENISOVA	{"email": "denisova.tatyana-091965@postgrespro.ru", "phone": "+70163526775"}
0005433922025	E17718	8357 797170	IRINA KUZNECOVA	{"phone": "+70379820634"}
0005433922026	8B2422	9622 263418	ALEKSANDR MARTYNOV	{"phone": "+70724739846"}
0005433922027	55708F	0779 735922	VIKTOR PAVLOV	{"email": "pavlov.v_28081970@postgrespro.ru", "phone": "+70518399273"}
0005433922028	80AA58	7692 546400	ALEKSEY MOROZOV	{"phone": "+70032798438"}
0005433922029	0F9B14	6458 298862	VLADIMIR ZAYCEV	{"email": "v_zaycev_071987@postgrespro.ru", "phone": "+70370639581"}
0005433922030	0F9B14	6309 483005	ALEKSANDRA ARKHIPOVA	{"email": "arkhipova.aleksandra-1980@postgrespro.ru", "phone": "+70510072350"}
0005433922031	0F9B14	7088 513156	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova.101977@postgrespro.ru", "phone": "+70863696222"}
0005433922032	0F9B14	4508 536303	VALERIY NAZAROV	{"email": "valeriynazarov17121968@postgrespro.ru", "phone": "+70908988165"}
0005433922033	8F3787	8194 234944	IGOR NAZAROV	{"email": "i.nazarov.101984@postgrespro.ru", "phone": "+70521776619"}
0005433922034	8F3787	2857 259356	GUZEL VOROBEVA	{"phone": "+70809294787"}
0005433922035	8250DF	0737 208393	LYUDMILA NOVIKOVA	{"email": "novikovalyudmila_1979@postgrespro.ru", "phone": "+70325459649"}
0005433922036	A910F5	8073 027535	YULIYA SEMENOVA	{"email": "yuliya.semenova061974@postgrespro.ru", "phone": "+70665713040"}
0005433922037	A910F5	2658 229288	OLEG VOLKOV	{"phone": "+70156598566"}
0005433922038	A910F5	2714 729535	LYUDMILA MAKAROVA	{"email": "makarova_lyudmila_14011975@postgrespro.ru", "phone": "+70920495670"}
0005433922039	F07439	2865 079005	IRINA KUZNECOVA	{"phone": "+70352040485"}
0005433922040	1C63CE	6231 437871	SERGEY MELNIKOV	{"phone": "+70344173422"}
0005433922041	D6C706	6315 490944	NATALYA AKIMOVA	{"phone": "+70756182775"}
0005433922042	AE79DB	9419 260058	LYUDMILA MOROZOVA	{"email": "lyudmilamorozova.17121963@postgrespro.ru", "phone": "+70979333086"}
0005433922043	AE79DB	7091 401646	VADIM AFANASEV	{"phone": "+70347612623"}
0005433922045	C9F260	2726 549688	SERGEY ZAKHAROV	{"email": "s_zakharov-1976@postgrespro.ru", "phone": "+70873207856"}
0005433922046	C9F260	1189 298130	POLINA BORISOVA	{"email": "polina_borisova_01061953@postgrespro.ru", "phone": "+70599186587"}
0005433922047	EB01D2	2333 672723	PAVEL POPOV	{"phone": "+70401724223"}
0005433922048	5C4B77	7741 841365	KAMIL FROLOV	{"email": "kamil-frolov-101967@postgrespro.ru", "phone": "+70144971674"}
0005433922049	5C4B77	9511 585718	ALEKSANDR BORISOV	{"email": "aleksandr.borisov09071980@postgrespro.ru", "phone": "+70674732317"}
0005433922050	41C0CB	2754 768211	GALINA KRASNOVA	{"phone": "+70674040854"}
0005433922051	23354C	3867 893777	SVETLANA MIRONOVA	{"email": "svetlana-mironova18121978@postgrespro.ru", "phone": "+70233531003"}
0005433922052	48BC97	8606 446544	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr_011977@postgrespro.ru", "phone": "+70011409912"}
0005433922053	D65080	7128 047317	VITALIY PAVLOV	{"email": "vitaliy-pavlov_1965@postgrespro.ru", "phone": "+70026186999"}
0005433922054	F9D3A6	3941 841252	ANASTASIYA STEPANOVA	{"email": "anastasiyastepanova-061969@postgrespro.ru", "phone": "+70266784517"}
0005433922055	968600	7476 126228	NATALIYA BELYAEVA	{"email": "belyaevanataliya071968@postgrespro.ru", "phone": "+70917133782"}
0005433922056	E504B3	8057 122303	MARINA KOVALEVA	{"email": "kovaleva-marina1970@postgrespro.ru", "phone": "+70725976537"}
0005433922057	E504B3	7813 371178	PAVEL KARPOV	{"email": "pavelkarpov051980@postgrespro.ru", "phone": "+70621909224"}
0005433922058	B90646	8618 145838	IVAN MARTYNOV	{"email": "ivan.martynov.22101976@postgrespro.ru", "phone": "+70678630305"}
0005433922059	F16AF5	1139 379226	ILYA ORLOV	{"email": "ilyaorlov.1968@postgrespro.ru", "phone": "+70175125001"}
0005433922060	9422AA	3187 919981	MARIYA FILIPPOVA	{"phone": "+70052538290"}
0005433922061	9422AA	8065 014007	ELENA MIRONOVA	{"phone": "+70219379866"}
0005433922062	333AFD	9340 143906	STANISLAV ANDREEV	{"phone": "+70313048560"}
0005433922063	8067BF	1642 573721	IVAN VOROBEV	{"email": "vorobevi10111975@postgrespro.ru", "phone": "+70177401814"}
0005433922064	8067BF	6299 589999	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov-13011981@postgrespro.ru", "phone": "+70025966168"}
0005433922065	4B8D5E	4202 640470	DARYA NIKITINA	{"phone": "+70474265230"}
0005433922066	E1B061	0137 300195	MIKHAIL SCHERBAKOV	{"email": "mikhail-scherbakov27041961@postgrespro.ru", "phone": "+70682849093"}
0005433922067	E1B061	8788 520673	SERGEY FROLOV	{"email": "frolov-sergey-1975@postgrespro.ru", "phone": "+70840817024"}
0005433922068	16DE20	6466 629337	GENNADIY MIRONOV	{"email": "gennadiy_mironov031969@postgrespro.ru", "phone": "+70619045801"}
0005433922069	16DE20	3674 152810	MIKHAIL VASILEV	{"phone": "+70593391222"}
0005433922070	A14BD9	8266 231309	DMITRIY NIKITIN	{"email": "dnikitin_071977@postgrespro.ru", "phone": "+70861678192"}
0005433922071	3A0F6E	5011 872557	ILYA SOKOLOV	{"phone": "+70350258509"}
0005433922072	3A0F6E	9714 419950	ALEKSEY FEDOROV	{"phone": "+70460235806"}
0005433922073	9F69E7	3987 002751	ANATOLIY SIDOROV	{"email": "a-sidorov03061974@postgrespro.ru", "phone": "+70591350163"}
0005433922074	FA7895	2012 250447	LYUBOV DAVYDOVA	{"phone": "+70631843777"}
0005433922075	FA7895	2028 884484	OLGA SEMENOVA	{"phone": "+70366703943"}
0005433922076	A61861	4490 765645	ANASTASIYA YAKOVLEVA	{"email": "yakovlevaa1966@postgrespro.ru", "phone": "+70915508632"}
0005433922077	A61861	0047 910498	MATRENA VOLKOVA	{"phone": "+70832381360"}
0005433922078	4BA063	7533 960073	MILANA SAVELEVA	{"phone": "+70442958781"}
0005433922079	2A5AAB	0506 616599	YURIY MEDVEDEV	{"email": "yuriy_medvedev121983@postgrespro.ru", "phone": "+70618181360"}
0005433922080	2A5AAB	1811 978566	ALEKSANDR MATVEEV	{"email": "matveev-aleksandr-1981@postgrespro.ru", "phone": "+70817556476"}
0005433922081	F112F9	8935 988742	PAVEL ALEKSANDROV	{"email": "pavelaleksandrov1983@postgrespro.ru", "phone": "+70938970607"}
0005433922082	F112F9	7876 663851	EKATERINA KALININA	{"phone": "+70483137128"}
0005433922083	F112F9	0517 882889	NIKOLAY MELNIKOV	{"email": "melnikov_n-061969@postgrespro.ru", "phone": "+70099587164"}
0005433922084	2884D9	7157 579873	DMITRIY OSIPOV	{"email": "d-osipov_03091975@postgrespro.ru", "phone": "+70791102185"}
0005433922085	7041F6	7939 176146	VIKTOR SHEVCHENKO	{"email": "v_shevchenko_1977@postgrespro.ru", "phone": "+70633276596"}
0005433922086	7041F6	7885 175756	VALENTINA VOLKOVA	{"email": "valentinavolkova-11051981@postgrespro.ru", "phone": "+70015401163"}
0005433922087	24E062	8658 718785	GERMAN ALEKSEEV	{"email": "g.alekseev-28081979@postgrespro.ru", "phone": "+70926622412"}
0005433922088	24E062	5654 769716	NATALYA ERMAKOVA	{"email": "natalya.ermakova-081981@postgrespro.ru", "phone": "+70988336922"}
0005433922089	55BEFB	6814 205444	EVGENIYA KUZNECOVA	{"email": "evgeniyakuznecova_11021979@postgrespro.ru", "phone": "+70606635253"}
0005433922090	55BEFB	5535 255196	SVETLANA KOVALEVA	{"phone": "+70634816952"}
0005433922091	63581A	7623 250654	SVETLANA EFIMOVA	{"email": "s.efimova.1969@postgrespro.ru", "phone": "+70043539439"}
0005433922092	63581A	8155 514556	ELENA ANISIMOVA	{"phone": "+70389149934"}
0005433922093	CCF99F	2019 662009	IGOR ALEKSANDROV	{"email": "aleksandrovigor.06091972@postgrespro.ru", "phone": "+70218257344"}
0005433922094	71B932	9391 139362	VLADISLAV NOVIKOV	{"email": "v.novikov.1972@postgrespro.ru", "phone": "+70873109810"}
0005433922095	72D23B	3418 821369	KSENIYA NIKITINA	{"email": "nikitina_kseniya_09091972@postgrespro.ru", "phone": "+70303857372"}
0005433922096	CA3CA7	6981 398598	VADIM SERGEEV	{"email": "vadim.sergeev.07091969@postgrespro.ru", "phone": "+70200649139"}
0005433922097	1E76CA	9388 650879	ANDREY NOVIKOV	{"email": "novikov_andrey.111981@postgrespro.ru", "phone": "+70309010002"}
0005433922098	9D299F	0879 643971	MARYAM KONDRATEVA	{"email": "maryam.kondrateva-1974@postgrespro.ru", "phone": "+70942227366"}
0005433922099	73F1BE	7694 989930	ELENA VASILEVA	{"email": "evasileva-061978@postgrespro.ru", "phone": "+70052373636"}
0005433922100	3F635F	2773 926348	NIKOLAY SCHERBAKOV	{"phone": "+70836280318"}
0005433922101	3F635F	5492 765418	SERAFIMA ISAEVA	{"email": "isaevaserafima-061961@postgrespro.ru", "phone": "+70263288640"}
0005433922102	7C5B4F	6190 137314	TATYANA ZAYCEVA	{"email": "zaycevat031974@postgrespro.ru", "phone": "+70322661141"}
0005433922103	5164CC	2082 848170	TATYANA MAKAROVA	{"phone": "+70292545113"}
0005433922104	756481	1321 046580	ALEKSANDR NAZAROV	{"phone": "+70643428445"}
0005433922105	F040B9	4815 104601	OLEG SOROKIN	{"email": "sorokinoleg_14091974@postgrespro.ru", "phone": "+70520095806"}
0005433922106	F040B9	8188 050887	ELENA SIDOROVA	{"email": "elena_sidorova091965@postgrespro.ru", "phone": "+70213634133"}
0005433922107	52CABC	4664 096154	LYUDMILA FILIPPOVA	{"phone": "+70610883843"}
0005433922108	0FD3DB	5905 280457	OKSANA MAKAROVA	{"email": "o_makarova_1973@postgrespro.ru", "phone": "+70089270346"}
0005433922109	C74AB2	7595 088719	KSENIYA FEDOROVA	{"email": "kfedorova25061976@postgrespro.ru", "phone": "+70971582792"}
0005433922110	C74AB2	2742 755490	POLINA SAVELEVA	{"email": "savelevapolina_1971@postgrespro.ru", "phone": "+70162316226"}
0005433922111	02FDBB	1358 493896	NATALYA IVANOVA	{"email": "ivanova_natalya_051983@postgrespro.ru", "phone": "+70737722433"}
0005433922112	02FDBB	5635 550217	SERGEY PAVLOV	{"phone": "+70031244453"}
0005433922113	C08C95	9023 288403	IGOR ZHUKOV	{"phone": "+70314197846"}
0005433922114	C08C95	9396 751441	EVGENIY GUSEV	{"phone": "+70350998515"}
0005433922115	C08C95	2290 478273	ANASTASIYA ZOTOVA	{"email": "a-zotova_091972@postgrespro.ru", "phone": "+70914451185"}
0005433922116	D2B929	9875 486771	ANDREY SERGEEV	{"email": "sergeev_andrey-29071977@postgrespro.ru", "phone": "+70832394704"}
0005433922117	D2B929	6583 184633	MIKHAIL KISELEV	{"email": "kiselev_mikhail.24051978@postgrespro.ru", "phone": "+70953599810"}
0005433922118	3C89A9	6731 427060	ALEKSEY DENISOV	{"email": "denisovaleksey-14061967@postgrespro.ru", "phone": "+70435670584"}
0005433922119	CD8ADC	4667 576708	MAKSIM ZHUKOV	{"phone": "+70913020386"}
0005433922120	CD8ADC	3053 601735	INNA KRASNOVA	{"phone": "+70721278533"}
0005433922121	38DBF4	1614 376032	ANASTASIYA DMITRIEVA	{"email": "a-dmitrieva-25051976@postgrespro.ru", "phone": "+70478601900"}
0005433922122	38DBF4	8562 935049	YURIY VLASOV	{"email": "vlasov.yuriy-17061961@postgrespro.ru", "phone": "+70809276539"}
0005433922123	0059E8	1894 939168	ARTEM ZHURAVLEV	{"email": "azhuravlev_02021968@postgrespro.ru", "phone": "+70064273886"}
0005433922124	0059E8	1071 551459	NATALYA BOGDANOVA	{"phone": "+70316708178"}
0005433922125	E0F3C6	8721 579012	ANDREY PAVLOV	{"email": "andrey.pavlov081972@postgrespro.ru", "phone": "+70157244735"}
0005433922126	E0F3C6	9436 258732	VALERIYA NIKOLAEVA	{"phone": "+70366685307"}
0005433922127	FA7C06	0482 829994	ZINAIDA NESTEROVA	{"email": "znesterova.10111973@postgrespro.ru", "phone": "+70258915921"}
0005433922128	FA7C06	9472 806529	MARIYA SEMENOVA	{"phone": "+70553888861"}
0005433922129	ADAE8E	7972 465782	SVETLANA GORBUNOVA	{"email": "gorbunova_svetlana.061971@postgrespro.ru", "phone": "+70362775491"}
0005433922130	964C1F	1827 455649	NATALYA KUZMINA	{"phone": "+70989987779"}
0005433922131	F2265B	9823 658399	ALEKSANDR PAVLOV	{"phone": "+70486953930"}
0005433922132	3DEA20	2073 459766	NIKITA SOKOLOV	{"email": "sokolov-n1966@postgrespro.ru", "phone": "+70121785745"}
0005433922133	3DEA20	4301 983601	TATYANA GORBUNOVA	{"email": "gorbunova.tatyana091974@postgrespro.ru", "phone": "+70009591617"}
0005433922134	3DEA20	0197 848719	IRINA ZAKHAROVA	{"email": "irina_zakharova-11011967@postgrespro.ru", "phone": "+70647913834"}
0005433922135	325100	0240 401757	ALEKSEY SCHERBAKOV	{"email": "ascherbakov-1973@postgrespro.ru", "phone": "+70976927171"}
0005433922136	5D2EF1	9524 372028	IVAN KOROLEV	{"phone": "+70350618304"}
0005433922137	5D2EF1	0138 049590	BORIS ILIN	{"phone": "+70986486424"}
0005433922138	D62132	4941 544636	YULIYA IVANOVA	{"phone": "+70665266965"}
0005433922139	B16CDB	7027 360624	NATALYA MARTYNOVA	{"email": "natalya_martynova-1967@postgrespro.ru", "phone": "+70303720732"}
0005433922140	766118	7612 317319	YULIYA BELYAEVA	{"phone": "+70793630982"}
0005433922141	B6CF2F	6094 093662	MAKSIM ILIN	{"phone": "+70997698318"}
0005433922142	B6CF2F	4460 437119	VIKTOR SEMENOV	{"email": "v.semenov16091974@postgrespro.ru", "phone": "+70183023999"}
0005433922143	B6CF2F	7767 174556	IRINA STEPANOVA	{"phone": "+70339808158"}
0005433922144	5F6981	6591 584412	SVETLANA ALEKSANDROVA	{"email": "s.aleksandrova.1969@postgrespro.ru", "phone": "+70665155784"}
0005433922145	5F6981	9116 527834	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev061967@postgrespro.ru", "phone": "+70058069693"}
0005433922146	69257D	6910 120080	ELENA NESTEROVA	{"email": "elena-nesterova.14041966@postgrespro.ru", "phone": "+70465799167"}
0005433922147	211138	7992 890369	SOFYA IVANOVA	{"email": "ivanovas_021978@postgrespro.ru", "phone": "+70971451534"}
0005433922148	663C3E	0465 141554	VALENTINA DMITRIEVA	{"email": "valentinadmitrieva-07091967@postgrespro.ru", "phone": "+70452240619"}
0005433922149	663C3E	5268 767672	ALEKSEY TARASOV	{"phone": "+70966750306"}
0005433922150	7E573E	3417 121573	VALENTINA KOZLOVA	{"email": "kozlova.v_13061975@postgrespro.ru", "phone": "+70842939799"}
0005433922151	2019F6	4872 886185	NADEZHDA KOZLOVA	{"phone": "+70504167354"}
0005433922152	4BB9F7	3436 994319	VALENTINA ALEKSEEVA	{"phone": "+70207580293"}
0005433922153	4BB9F7	9994 011853	ALEKSEY SHEVCHENKO	{"email": "shevchenko.aleksey1972@postgrespro.ru", "phone": "+70299759041"}
0005433922154	208D65	0818 970442	YULIYA STEPANOVA	{"phone": "+70815488893"}
0005433922155	208D65	5024 365469	IRAIDA KOLESNIKOVA	{"email": "kolesnikova_i041963@postgrespro.ru", "phone": "+70636762284"}
0005433922156	832B03	7726 698722	ZHANNA IVANOVA	{"phone": "+70269559508"}
0005433922157	2F3187	6588 202601	VIKTOR SOKOLOV	{"email": "sokolov.viktor-22021968@postgrespro.ru", "phone": "+70162182259"}
0005433922158	2F3187	3329 797344	NIKOLAY FEDOROV	{"phone": "+70545989695"}
0005433922454	60CB50	8199 958531	IVAN PAVLOV	{"phone": "+70624386323"}
0005433922159	BAB019	2787 845521	STANISLAV SEMENOV	{"email": "stanislav-semenov_1969@postgrespro.ru", "phone": "+70955371077"}
0005433922160	C3CBF4	6829 022340	EVGENIY VLASOV	{"email": "e-vlasov21121978@postgrespro.ru", "phone": "+70421732497"}
0005433922161	C3CBF4	3505 102464	NINA ZAYCEVA	{"phone": "+70085224678"}
0005433922162	C2A8CA	6418 577613	NURIYA KONOVALOVA	{"phone": "+70806017871"}
0005433922163	C2A8CA	7011 662601	NINA KONDRATEVA	{"email": "nina.kondrateva-24091971@postgrespro.ru", "phone": "+70839415022"}
0005433922164	848B7A	7439 709762	ALEKSEY YAKOVLEV	{"email": "a.yakovlev.1972@postgrespro.ru", "phone": "+70375025161"}
0005433922165	3E7684	6931 220764	SERGEY RODIONOV	{"phone": "+70428085458"}
0005433922166	3F096C	3975 354949	NATALYA ROMANOVA	{"email": "natalyaromanova061973@postgrespro.ru", "phone": "+70825346273"}
0005433922167	7ACF29	0332 924808	TATYANA LEBEDEVA	{"email": "t-lebedeva.091968@postgrespro.ru", "phone": "+70819033436"}
0005433922168	74BF39	5749 760554	YURIY SOLOVEV	{"email": "solovev_y1976@postgrespro.ru", "phone": "+70363042291"}
0005433922169	74BF39	4692 024692	PAVEL SERGEEV	{"phone": "+70991043473"}
0005433922170	2D179F	9813 040609	IBRAGIM SOROKIN	{"email": "ibragim.sorokin-01111974@postgrespro.ru", "phone": "+70006830906"}
0005433922171	7E7E78	9252 386378	BORIS KUZNECOV	{"email": "kuznecov_boris.1970@postgrespro.ru", "phone": "+70286649711"}
0005433922172	9461DE	0618 223564	VLADIMIR KOZLOV	{"phone": "+70607997026"}
0005433922173	C8C4C5	1025 759471	IRINA NESTEROVA	{"phone": "+70373265120"}
0005433922174	A243F6	3081 481141	OLGA SOLOVEVA	{"email": "soloveva-o-1962@postgrespro.ru", "phone": "+70684360529"}
0005433922175	58567E	1282 974739	IVAN MELNIKOV	{"phone": "+70795113090"}
0005433922176	568FD3	9988 056564	ALEKSANDR ZHURAVLEV	{"phone": "+70813116910"}
0005433922177	B9140A	8849 755736	VALENTINA YUDINA	{"phone": "+70280558098"}
0005433922178	634C54	0817 197760	DENIS ZHUKOV	{"email": "denis_zhukov.25081973@postgrespro.ru", "phone": "+70313840770"}
0005433922179	634C54	1609 508275	MATVEY VOLKOV	{"email": "volkov_matvey_031967@postgrespro.ru", "phone": "+70085427674"}
0005433922180	A1688B	5247 050277	VIKTOR SHEVCHENKO	{"phone": "+70968322407"}
0005433922181	0B481C	7860 249225	RUSLAN SOROKIN	{"phone": "+70531837939"}
0005433922182	449B7C	6354 404592	NIKOLAY VASILEV	{"phone": "+70068803704"}
0005433922183	D77BB1	8900 277091	NINA NAZAROVA	{"phone": "+70065025488"}
0005433922184	BFF9F1	2296 739650	PETR DENISOV	{"email": "denisov_p.04111964@postgrespro.ru", "phone": "+70074865899"}
0005433922185	BFF9F1	9380 985133	RAISA DMITRIEVA	{"email": "dmitrievar-041960@postgrespro.ru", "phone": "+70452151927"}
0005433922186	FD6E7A	3632 743728	ELENA VASILEVA	{"phone": "+70519668911"}
0005433922187	EE22BC	5719 379684	IRINA SMIRNOVA	{"email": "irina-smirnova_11041975@postgrespro.ru", "phone": "+70927993624"}
0005433922188	3AC5CC	2874 828710	MARIYA GUSEVA	{"phone": "+70956566192"}
0005433922189	3833EE	5317 704071	ALEKSANDR PETROV	{"phone": "+70952874675"}
0005433922190	99CA2B	2889 251678	OLEG KULIKOV	{"email": "olegkulikov_27081976@postgrespro.ru", "phone": "+70425404649"}
0005433922191	868F21	2313 271780	ELENA ISAEVA	{"email": "isaeva.elena071970@postgrespro.ru", "phone": "+70987897801"}
0005433922192	91A092	5186 701936	ANNA NIKOLAEVA	{"phone": "+70755569093"}
0005433922193	01AA0C	7824 921856	MARINA GORBUNOVA	{"phone": "+70890591607"}
0005433922194	972E15	4345 731561	VERONIKA DANILOVA	{"email": "v-danilova_14101966@postgrespro.ru", "phone": "+70657316464"}
0005433922195	972E15	4662 147997	ALEKSANDR SERGEEV	{"phone": "+70083419685"}
0005433922196	1784A3	9524 691640	VERA VASILEVA	{"phone": "+70464722063"}
0005433922197	1784A3	8584 078074	ANATOLIY BARANOV	{"email": "baranov_a-31011970@postgrespro.ru", "phone": "+70096300921"}
0005433922198	D402F2	2491 329227	ELENA KUDRYASHOVA	{"email": "kudryashova-elena.1973@postgrespro.ru", "phone": "+70142811081"}
0005433922199	D402F2	7854 559492	DAMIR MEDVEDEV	{"email": "damir_medvedev_15081967@postgrespro.ru", "phone": "+70701383172"}
0005433922200	781723	6660 974004	ALEKSEY TARASOV	{"phone": "+70728339762"}
0005433922201	781723	9302 065860	PAVEL ISAEV	{"email": "p-isaev121971@postgrespro.ru", "phone": "+70454686044"}
0005433922202	FDF9CE	6342 233786	OLGA LUKYANOVA	{"phone": "+70645074643"}
0005433922203	29351F	6014 684205	ZAKHAR MEDVEDEV	{"phone": "+70212004809"}
0005433922204	29351F	7127 164720	NADEZHDA ZAKHAROVA	{"phone": "+70087605398"}
0005433922205	29351F	9604 631293	EVDOKIYA KUZNECOVA	{"email": "kuznecova_e_111962@postgrespro.ru", "phone": "+70672592367"}
0005433922206	C293D1	6682 140714	VITALIY MELNIKOV	{"phone": "+70928962705"}
0005433922207	C293D1	6999 326415	LARISA GUSEVA	{"email": "l_guseva-1978@postgrespro.ru", "phone": "+70887860149"}
0005433922208	9A093C	6078 580998	ELENA NIKOLAEVA	{"email": "e_nikolaeva021973@postgrespro.ru", "phone": "+70785016091"}
0005433922209	41808A	2758 967182	RAMIL SOKOLOV	{"email": "sokolov.ramil1969@postgrespro.ru", "phone": "+70269358570"}
0005433922210	BB18A9	0130 885459	TAISIYA TARASOVA	{"email": "taisiya_tarasova_22091969@postgrespro.ru", "phone": "+70278733518"}
0005433922211	F6C887	3118 741896	YURIY DAVYDOV	{"email": "davydov.y_1982@postgrespro.ru", "phone": "+70467471730"}
0005433922212	0CD1E5	6863 271336	ALEKSANDR PAVLOV	{"phone": "+70252685851"}
0005433922213	D606AF	7130 809215	YANA VOROBEVA	{"phone": "+70837061307"}
0005433922214	FD6538	8104 996775	IRINA IVANOVA	{"email": "irina.ivanova111973@postgrespro.ru", "phone": "+70889704851"}
0005433922215	F5E0D8	2780 673622	ELENA NESTEROVA	{"phone": "+70280366275"}
0005433922216	F5E0D8	7512 851646	TATYANA ANISIMOVA	{"email": "anisimova.tatyana_19061976@postgrespro.ru", "phone": "+70879712664"}
0005433922217	CA73F8	4001 764763	DMITRIY CHERNOV	{"phone": "+70588742925"}
0005433922218	513CCF	1973 698602	VYACHESLAV FEDOTOV	{"email": "fedotov-vyacheslav28011974@postgrespro.ru", "phone": "+70229853260"}
0005433922219	A502AF	7190 838798	GALINA IVANOVA	{"email": "g.ivanova13041975@postgrespro.ru", "phone": "+70282232380"}
0005433922220	8CFDE3	3307 457798	SVETLANA SAVELEVA	{"email": "savelevasvetlana_1976@postgrespro.ru", "phone": "+70269201053"}
0005433922221	8CFDE3	7976 302828	ALEKSEY ROMANOV	{"email": "aleksey.romanov-1979@postgrespro.ru", "phone": "+70589983987"}
0005433922222	5EDD16	7986 822182	SVETLANA VASILEVA	{"phone": "+70499477738"}
0005433922223	2EC0C8	2233 559707	GALINA ISAEVA	{"email": "g.isaeva_1986@postgrespro.ru", "phone": "+70972320782"}
0005433922224	8F2DBB	6956 129406	SVETLANA BARANOVA	{"phone": "+70185972234"}
0005433922225	CEBCAE	6743 656521	DMITRIY MOROZOV	{"email": "morozov_dmitriy-07041969@postgrespro.ru", "phone": "+70428835165"}
0005433922226	CEBCAE	8332 851041	SVETLANA VOLKOVA	{"email": "volkova-s_1968@postgrespro.ru", "phone": "+70352545585"}
0005433922227	CEBCAE	8604 851583	ANATOLIY GERASIMOV	{"email": "a-gerasimov_16041959@postgrespro.ru", "phone": "+70740706062"}
0005433922228	B6A857	5213 201128	PAVEL SMIRNOV	{"email": "p_smirnov.29121963@postgrespro.ru", "phone": "+70221143136"}
0005433922229	9C89D5	8800 581892	ALEKSANDR PAVLOV	{"phone": "+70727418414"}
0005433922230	B6BA78	3519 579086	OLGA NIKIFOROVA	{"email": "nikiforova.o1976@postgrespro.ru", "phone": "+70603728497"}
0005433922231	93D4DF	9380 036379	VIKTOR KUZNECOV	{"email": "kuznecov.viktor-031979@postgrespro.ru", "phone": "+70220351081"}
0005433922232	93D4DF	8077 994750	IVAN GRIGOREV	{"email": "i_grigorev-041980@postgrespro.ru", "phone": "+70347693574"}
0005433922233	93D4DF	9552 366825	OKSANA POPOVA	{"phone": "+70424734418"}
0005433922234	93D4DF	9428 495434	ALISA GAVRILOVA	{"email": "gavrilovaa-111973@postgrespro.ru", "phone": "+70524293483"}
0005433922235	4327C7	6192 764915	VLADIMIR KISELEV	{"phone": "+70271757109"}
0005433922236	4327C7	6072 831785	VIKTOR SERGEEV	{"phone": "+70402063373"}
0005433922237	C669D6	6909 148812	SERGEY VASILEV	{"email": "sergey-vasilev011969@postgrespro.ru", "phone": "+70530415096"}
0005433922238	05B755	3515 793107	NINA GRISHINA	{"phone": "+70899900295"}
0005433922239	736E3B	3896 633318	VIKTOR TIMOFEEV	{"phone": "+70944465670"}
0005433922462	2177F5	8635 083793	SVETLANA SOKOLOVA	{"phone": "+70691212453"}
0005433922240	0F407D	8713 993571	TATYANA GAVRILOVA	{"email": "gavrilova-t.06081973@postgrespro.ru", "phone": "+70374571867"}
0005433922241	0F407D	5351 441303	NINA FOMINA	{"phone": "+70753877292"}
0005433922242	718FF0	1880 028349	TATYANA KONDRATEVA	{"phone": "+70671994286"}
0005433922243	718FF0	2258 131095	VALERIY OSIPOV	{"phone": "+70165449948"}
0005433922244	C591FD	1183 606035	VLADIMIR ANDREEV	{"phone": "+70075176292"}
0005433922245	C591FD	0777 460792	YULIYA YUDINA	{"phone": "+70325578318"}
0005433922246	9379E9	3487 170839	ELENA DANILOVA	{"email": "elenadanilova061982@postgrespro.ru", "phone": "+70971115611"}
0005433922247	E7FEC1	8574 880458	SERGEY CHERNOV	{"phone": "+70752046139"}
0005433922248	7C2C18	7200 627762	TATYANA STEPANOVA	{"email": "stepanovatatyana.081970@postgrespro.ru", "phone": "+70194696502"}
0005433922249	BB8051	6773 241991	MIKHAIL AFANASEV	{"email": "afanasevmikhail121968@postgrespro.ru", "phone": "+70653583962"}
0005433922250	7230EC	3742 470215	KLAVDIYA PETROVA	{"phone": "+70753194376"}
0005433922251	8FD860	7370 808808	OLEG GUSEV	{"email": "gusev_oleg31081973@postgrespro.ru", "phone": "+70580169709"}
0005433922252	0C079B	8515 479134	VLADIMIR VOLKOV	{"email": "volkov_vladimir_1974@postgrespro.ru", "phone": "+70578734932"}
0005433922253	9E4066	0232 793202	ILYA KUDRYASHOV	{"email": "kudryashov.i_1976@postgrespro.ru", "phone": "+70057802207"}
0005433922254	3989DE	1975 506613	VALERIY ILIN	{"email": "vilin1969@postgrespro.ru", "phone": "+70659460832"}
0005433922255	2122FE	3930 498297	GALINA ALEKSEEVA	{"phone": "+70476972017"}
0005433922256	2122FE	3505 508506	VARVARA NIKOLAEVA	{"phone": "+70577740114"}
0005433922257	2122FE	3477 795374	OLGA STEPANOVA	{"email": "o-stepanova_1973@postgrespro.ru", "phone": "+70516933097"}
0005433922258	9B700A	7840 864572	RAFAEL MIKHAYLOV	{"phone": "+70480132007"}
0005433922259	CAC38B	1150 081522	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov1971@postgrespro.ru", "phone": "+70986262431"}
0005433922260	09DCB7	9763 343648	OLGA MAKAROVA	{"email": "makarova_olga_021970@postgrespro.ru", "phone": "+70344635022"}
0005433922261	7784E4	5250 203364	NADEZHDA PETROVA	{"email": "petrovan-091971@postgrespro.ru", "phone": "+70084125742"}
0005433922262	EF27E3	0580 306517	ALEKSANDRA KARPOVA	{"email": "karpova-a.1967@postgrespro.ru", "phone": "+70798255767"}
0005433922263	EF27E3	1688 306518	EVGENIY MATVEEV	{"email": "matveev-e_24021978@postgrespro.ru", "phone": "+70215660681"}
0005433922264	1D8A38	0654 501703	TATYANA SOLOVEVA	{"phone": "+70447394839"}
0005433922265	C0314D	9159 299271	OKSANA KONOVALOVA	{"phone": "+70119581590"}
0005433922266	C0314D	4477 600847	ALEKSANDRA ANDREEVA	{"email": "andreeva-a-051983@postgrespro.ru", "phone": "+70270593736"}
0005433922267	DB022A	3219 156554	IVAN IVANOV	{"phone": "+70013532230"}
0005433922268	60A5E8	0430 200557	DMITRIY ROMANOV	{"phone": "+70720931278"}
0005433922269	FD397F	8883 748746	DARYA OVCHINNIKOVA	{"phone": "+70116735273"}
0005433922270	C111B6	9008 354909	ELENA DENISOVA	{"phone": "+70039227570"}
0005433922271	AD11F1	7544 972774	GULNARA SERGEEVA	{"email": "g_sergeeva_1981@postgrespro.ru", "phone": "+70927636386"}
0005433922272	14C6CB	4532 059659	FAINA DENISOVA	{"email": "denisova-faina_051965@postgrespro.ru", "phone": "+70511016689"}
0005433922273	40A60B	7127 222511	RAISA MOROZOVA	{"email": "r.morozova.101966@postgrespro.ru", "phone": "+70259553827"}
0005433922274	40A60B	3457 563266	DMITRIY VOROBEV	{"email": "vorobev-d_1962@postgrespro.ru", "phone": "+70111291364"}
0005433922275	6F0C84	6658 657579	YANA KUZMINA	{"phone": "+70943551726"}
0005433922276	4C052F	8654 969196	MARINA SERGEEVA	{"phone": "+70405545676"}
0005433922277	4C052F	9054 976369	YURIY KUZNECOV	{"phone": "+70586389886"}
0005433922278	65A89C	7836 270883	KLAVDIYA FILATOVA	{"email": "kfilatova-24011972@postgrespro.ru", "phone": "+70697912545"}
0005433922279	CE070F	0149 602224	ANDREY SERGEEV	{"phone": "+70958744910"}
0005433922280	DDB544	3415 582318	OLGA GRISHINA	{"phone": "+70242708459"}
0005433922281	EC4046	0536 558018	DARYA DENISOVA	{"email": "denisovadarya-16101979@postgrespro.ru", "phone": "+70711797275"}
0005433922282	ED2A44	0196 866788	ANDREY KOZLOV	{"phone": "+70597518783"}
0005433922283	ED2A44	1611 991964	SERGEY NAZAROV	{"email": "snazarov-071970@postgrespro.ru", "phone": "+70814238735"}
0005433922284	2D625F	3930 275512	STANISLAV FEDOROV	{"email": "stanislav-fedorov_29071966@postgrespro.ru", "phone": "+70535010112"}
0005433922285	3024DC	3322 059639	SOFYA ALEKSEEVA	{"phone": "+70305688802"}
0005433922286	3024DC	9865 406430	IGOR PETROV	{"email": "i-petrov.1970@postgrespro.ru", "phone": "+70235879983"}
0005433922287	0E1000	8819 712162	IRINA ZAYCEVA	{"email": "zayceva.i091972@postgrespro.ru", "phone": "+70142637922"}
0005433922288	0E1000	6501 296812	IRINA ARKHIPOVA	{"phone": "+70319144788"}
0005433922289	4BAB61	1644 351791	VYACHESLAV PETROV	{"phone": "+70295062415"}
0005433922290	4BAB61	9308 624194	GALINA MOISEEVA	{"email": "moiseeva.galina-1972@postgrespro.ru", "phone": "+70015668431"}
0005433922291	EAE1D0	1050 282909	NAZIYA IVANOVA	{"phone": "+70361108999"}
0005433922292	51D794	5346 636864	GRIGORIY POPOV	{"email": "popov_g_1972@postgrespro.ru", "phone": "+70425022621"}
0005433922293	A53796	2826 549582	ALEKSEY GUSEV	{"email": "gusev_a.101964@postgrespro.ru", "phone": "+70577777232"}
0005433922349	57F630	3796 850315	MATVEY ISAEV	{"phone": "+70862323468"}
0005433922294	93B966	3198 266621	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr1959@postgrespro.ru", "phone": "+70733751044"}
0005433922463	C4C3B3	5256 804011	DMITRIY VASILEV	{"phone": "+70312672393"}
0005433922295	2AAE32	1152 235232	ANTONINA MELNIKOVA	{"email": "antonina_melnikova-07011974@postgrespro.ru", "phone": "+70085031876"}
0005433922296	0DE233	2472 006865	DENIS IVANOV	{"email": "ivanov_d041963@postgrespro.ru", "phone": "+70995819365"}
0005433922297	5AD3B9	2875 362016	VYACHESLAV KOZLOV	{"phone": "+70243864223"}
0005433922298	392E4D	8068 579156	ELENA SIDOROVA	{"email": "sidorova_elena_1974@postgrespro.ru", "phone": "+70953372690"}
0005433922299	142451	8385 536561	LYAYSAN ISAEVA	{"email": "l.isaeva-28011962@postgrespro.ru", "phone": "+70859893765"}
0005433922300	142451	3246 642133	MARIYA IVANOVA	{"phone": "+70835383063"}
0005433922301	2809DE	7127 389406	ALEKSANDRA BORISOVA	{"phone": "+70114398904"}
0005433922302	AC2111	7613 760586	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_12021968@postgrespro.ru", "phone": "+70616602011"}
0005433922303	D31483	1527 905291	TATYANA MAKAROVA	{"email": "makarova-t.25011976@postgrespro.ru", "phone": "+70194093135"}
0005433922304	118DFE	0955 922462	TATYANA ABRAMOVA	{"email": "abramova_tatyana_101973@postgrespro.ru", "phone": "+70967536452"}
0005433922305	C85E10	8760 748733	ALEKSEY MELNIKOV	{"phone": "+70599115406"}
0005433922306	89A1B3	9490 063262	LIDIYA KARPOVA	{"phone": "+70754546460"}
0005433922307	89A1B3	4095 263584	YULIYA KUZNECOVA	{"email": "y_kuznecova_1971@postgrespro.ru", "phone": "+70815127918"}
0005433922308	E8CC8C	3381 762183	VALERIY IVANOV	{"email": "ivanov_v111965@postgrespro.ru", "phone": "+70327838832"}
0005433922309	E8CC8C	6926 975859	ILYA MATVEEV	{"email": "matveev_ilya1967@postgrespro.ru", "phone": "+70560096014"}
0005433922310	FD69B5	9287 147432	VASILIY SHEVCHENKO	{"email": "shevchenko.v-27051971@postgrespro.ru", "phone": "+70805949487"}
0005433922311	FD69B5	7854 904337	ALEVTINA VOLKOVA	{"phone": "+70216333951"}
0005433922312	FD69B5	1303 898393	GENNADIY MIRONOV	{"email": "gennadiymironov.06081965@postgrespro.ru", "phone": "+70089740945"}
0005433922313	C8E070	3841 833182	YAROSLAV PAVLOV	{"phone": "+70805232011"}
0005433922314	C8E070	0655 354532	TATYANA KUZNECOVA	{"phone": "+70830040405"}
0005433922315	A07D6D	0465 273483	LYUDMILA FOMINA	{"phone": "+70438404365"}
0005433922316	A9FF8F	1061 649093	GRIGORIY GUSEV	{"email": "grigoriy_gusev_041974@postgrespro.ru", "phone": "+70054660672"}
0005433922317	A9FF8F	1658 839671	NATALYA SOKOLOVA	{"email": "natalyasokolova.11091971@postgrespro.ru", "phone": "+70509915009"}
0005433922318	58D750	8728 638417	SVETLANA TIKHONOVA	{"email": "tikhonovasvetlana1954@postgrespro.ru", "phone": "+70537634100"}
0005433922319	590ED8	4339 821688	KARINA MAKSIMOVA	{"email": "maksimovak.1969@postgrespro.ru", "phone": "+70655522578"}
0005433922320	7818B1	2010 483063	MARINA MAKSIMOVA	{"email": "maksimova.m.1971@postgrespro.ru", "phone": "+70618575276"}
0005433922321	7818B1	4937 574611	VITALIY KUZNECOV	{"email": "vitaliy.kuznecov-011974@postgrespro.ru", "phone": "+70148860861"}
0005433922322	7818B1	4124 372582	DMITRIY NOVIKOV	{"email": "dmitriynovikov_22071973@postgrespro.ru", "phone": "+70172279895"}
0005433922323	1319F4	4849 210403	MIKHAIL NIKITIN	{"phone": "+70715843952"}
0005433922324	A53B87	4895 330364	ALEKSEY KONOVALOV	{"email": "a-konovalov16101971@postgrespro.ru", "phone": "+70591427974"}
0005433922325	C57009	5817 526697	VLADIMIR VLASOV	{"phone": "+70925208704"}
0005433922326	005F02	9329 803896	MARINA BARANOVA	{"phone": "+70549209128"}
0005433922327	053FAB	7949 224124	SERGEY FILIPPOV	{"phone": "+70348248623"}
0005433922328	C52784	3513 636804	ALEKSEY ZAKHAROV	{"email": "zakharov.aleksey-1963@postgrespro.ru", "phone": "+70056471697"}
0005433922329	C52784	6781 414241	MARINA VOROBEVA	{"phone": "+70563987328"}
0005433922330	E518A5	2545 193369	ALEKSEY POPOV	{"email": "a.popov.23011972@postgrespro.ru", "phone": "+70553378833"}
0005433922331	E518A5	5237 153836	ANASTASIYA ZAKHAROVA	{"email": "anastasiyazakharova_1967@postgrespro.ru", "phone": "+70738090461"}
0005433922332	E518A5	3509 136463	ILYA NAUMOV	{"phone": "+70887464019"}
0005433922333	67447A	9731 866655	IGOR GRIGOREV	{"email": "grigorev.igor_1974@postgrespro.ru", "phone": "+70051667253"}
0005433922334	7AC86C	8110 639361	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr04041973@postgrespro.ru", "phone": "+70899167400"}
0005433922335	AA6F85	4227 865795	SERGEY KOZLOV	{"email": "sergey.kozlov.26111972@postgrespro.ru", "phone": "+70596445514"}
0005433922336	79CA7C	6566 592758	IVAN KUZMIN	{"email": "i-kuzmin1972@postgrespro.ru", "phone": "+70686808678"}
0005433922337	F9BA74	7760 520994	SVETLANA PETROVA	{"phone": "+70921373231"}
0005433922338	2F4FFB	7629 650392	MIKHAIL TIKHONOV	{"phone": "+70744823315"}
0005433922339	5D338C	4733 476425	VALENTIN KUZNECOV	{"phone": "+70439634845"}
0005433922340	404A7C	2594 592415	NIKITA BONDARENKO	{"email": "bondarenkonikita.19111982@postgrespro.ru", "phone": "+70811375694"}
0005433922341	404A7C	7882 788918	NATALYA FILIPPOVA	{"phone": "+70202633216"}
0005433922342	82E7EF	1086 837657	EVGENIYA BORISOVA	{"email": "borisova.evgeniya.111966@postgrespro.ru", "phone": "+70931127603"}
0005433922343	72C07C	7477 739225	SERGEY KUZNECOV	{"email": "kuznecov_s-10111975@postgrespro.ru", "phone": "+70438630401"}
0005433922344	59DC46	0066 769069	NIKOLAY PETROV	{"email": "petrov-n-1966@postgrespro.ru", "phone": "+70665784898"}
0005433922345	E51192	5841 070905	ELENA FROLOVA	{"phone": "+70323616221"}
0005433922346	95BDC3	9684 740965	EVGENIYA ALEKSANDROVA	{"email": "evgeniya.aleksandrova.1967@postgrespro.ru", "phone": "+70785021538"}
0005433922347	95BDC3	4583 609539	NIKOLAY ZAYCEV	{"phone": "+70880396689"}
0005433922348	57F630	6427 969691	ELENA ILINA	{"email": "elenailina091974@postgrespro.ru", "phone": "+70709676038"}
0005433922350	FECF13	1095 992271	VERA MARTYNOVA	{"email": "vmartynova-121970@postgrespro.ru", "phone": "+70547290331"}
0005433922351	8E60EE	2699 261389	POLINA MOISEEVA	{"email": "polina_moiseeva-041985@postgrespro.ru", "phone": "+70098133688"}
0005433922352	E402A6	3520 218323	DMITRIY FEDOROV	{"phone": "+70101591184"}
0005433922353	39D094	4383 640434	ILYA BONDARENKO	{"email": "ibondarenko.111980@postgrespro.ru", "phone": "+70565364604"}
0005433922354	041D55	1415 109946	ALEKSEY PAVLOV	{"phone": "+70189724142"}
0005433922355	6AB1A9	7325 686493	RUSLAN DENISOV	{"phone": "+70909044095"}
0005433922356	6AB1A9	8553 627195	IGOR KUZNECOV	{"phone": "+70628080500"}
0005433922357	DE268F	9941 784386	IRINA KARPOVA	{"phone": "+70562471255"}
0005433922358	5BEE44	7465 101008	ANDREY ZHUKOV	{"phone": "+70808352380"}
0005433922359	8A88FF	1694 251125	OLGA MAKAROVA	{"email": "olga-makarova-1973@postgrespro.ru", "phone": "+70988504032"}
0005433922360	54FC61	6069 232279	NADEZHDA SOROKINA	{"phone": "+70273319203"}
0005433922361	54FC61	1816 836175	YURIY SHEVCHENKO	{"email": "shevchenko.yuriy1970@postgrespro.ru", "phone": "+70475268860"}
0005433922362	3C3583	4714 109044	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_121968@postgrespro.ru", "phone": "+70054150494"}
0005433922363	B85A52	1610 778435	VLADIMIR ILIN	{"email": "ilin.v-06071974@postgrespro.ru", "phone": "+70389834786"}
0005433922364	3E1CE8	0028 327510	MARINA VOROBEVA	{"phone": "+70230060646"}
0005433922365	57622C	6602 412776	NINA ANTONOVA	{"phone": "+70634484395"}
0005433922366	E0B7E6	0246 427964	ALEKSEY VOROBEV	{"email": "aleksey.vorobev011969@postgrespro.ru", "phone": "+70625326225"}
0005433922367	0EC11C	9999 690135	NATALYA EGOROVA	{"phone": "+70434641961"}
0005433922368	0EC11C	1745 702468	NATALIYA MOROZOVA	{"phone": "+70888022890"}
0005433922369	8D2268	4578 867306	NADEZHDA SMIRNOVA	{"email": "smirnova-n-111976@postgrespro.ru", "phone": "+70456634464"}
0005433922370	B03935	9903 237576	DENIS BORISOV	{"phone": "+70857540663"}
0005433922371	E2E41B	1557 248982	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr-101972@postgrespro.ru", "phone": "+70213203091"}
0005433922372	E2E41B	3780 631509	NATALYA KULIKOVA	{"email": "kulikova_natalya1971@postgrespro.ru", "phone": "+70700422236"}
0005433922373	E2E41B	9841 835505	NIKOLAY BORISOV	{"email": "borisov.nikolay-11081967@postgrespro.ru", "phone": "+70678966034"}
0005433922374	FAFCA9	3610 764378	NIKOLAY KULIKOV	{"email": "nikolay_kulikov_23121980@postgrespro.ru", "phone": "+70383500586"}
0005433922375	423960	5706 396834	ALEKSANDRA MOROZOVA	{"phone": "+70252521803"}
0005433922376	52BF97	8083 658374	ALEKSEY YAKOVLEV	{"email": "aleksey.yakovlev1958@postgrespro.ru", "phone": "+70300236543"}
0005433922377	8D1182	0954 105534	NADEZHDA EGOROVA	{"email": "egorovanadezhda_021970@postgrespro.ru", "phone": "+70377810917"}
0005433922378	8D1182	2487 663248	MARINA KARPOVA	{"phone": "+70856400645"}
0005433922379	52AA7F	8402 366505	NIKOLAY FEDOROV	{"email": "nfedorov_091977@postgrespro.ru", "phone": "+70054286718"}
0005433922380	0F7F1E	9779 946631	BORIS BELOV	{"email": "boris-belov.15111970@postgrespro.ru", "phone": "+70517705319"}
0005433922381	0F7F1E	1901 157865	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov.02011971@postgrespro.ru", "phone": "+70310305458"}
0005433922382	05C2FE	7569 062924	ALINA KUZNECOVA	{"phone": "+70323378354"}
0005433922383	9A49C7	1134 826334	ALEKSANDR BARANOV	{"email": "baranov_a1955@postgrespro.ru", "phone": "+70632401397"}
0005433922384	9FA985	1247 569207	VIKTOR BONDARENKO	{"phone": "+70356681994"}
0005433922385	9FA985	4076 692330	GALINA ANDREEVA	{"email": "galinaandreeva1972@postgrespro.ru", "phone": "+70138430056"}
0005433922386	CF50F6	1867 358086	DMITRIY TIKHONOV	{"email": "dmitriy_tikhonov041977@postgrespro.ru", "phone": "+70407784887"}
0005433922387	EEC8CC	9109 977340	GENNADIY KARPOV	{"phone": "+70563621318"}
0005433922388	EEC8CC	4199 111910	ALEKSEY MEDVEDEV	{"email": "amedvedev_17021967@postgrespro.ru", "phone": "+70595669317"}
0005433922389	9A21E0	8771 650189	VIKTORIYA KRASNOVA	{"phone": "+70841612472"}
0005433922390	72EFDF	2031 450682	SERGEY SAVELEV	{"phone": "+70804218979"}
0005433922391	F64B0F	6761 908767	VLADIMIR KOROLEV	{"email": "korolevv.09071971@postgrespro.ru", "phone": "+70925431121"}
0005433922392	F64B0F	5552 098347	RAFIS FILIPPOV	{"email": "r-filippov-1976@postgrespro.ru", "phone": "+70359519056"}
0005433922393	950B8B	6259 231892	MARGARITA FADEEVA	{"email": "margaritafadeeva-081981@postgrespro.ru", "phone": "+70550308956"}
0005433922394	950B8B	7653 722823	NIKOLAY BORISOV	{"email": "nikolay-borisov.09031974@postgrespro.ru", "phone": "+70912005690"}
0005433922395	0835BA	1985 412229	VERA IVANOVA	{"email": "vivanova_10051977@postgrespro.ru", "phone": "+70479266579"}
0005433922396	440CC1	7114 388022	VLADIMIR MOISEEV	{"email": "vladimir.moiseev.08011977@postgrespro.ru", "phone": "+70437159557"}
0005433922397	A10BD4	2840 003602	ARTUR KRASNOV	{"email": "a-krasnov.20051968@postgrespro.ru", "phone": "+70051216487"}
0005433922398	A10BD4	1683 473853	OKSANA VOLKOVA	{"phone": "+70849578064"}
0005433922399	A10BD4	5289 225432	RINAT BELOV	{"email": "r-belov.04031980@postgrespro.ru", "phone": "+70926978895"}
0005433922400	D6B60B	4622 712251	TATYANA POLYAKOVA	{"email": "tatyana.polyakova.081968@postgrespro.ru", "phone": "+70571729902"}
0005433922401	960986	0609 339813	ELENA KOROLEVA	{"email": "e_koroleva.061973@postgrespro.ru", "phone": "+70818042276"}
0005433922402	960986	4391 183948	ARTEM ANDREEV	{"phone": "+70767057213"}
0005433922403	E88174	1986 306757	NIKOLAY TARASOV	{"phone": "+70500261985"}
0005433922404	4F98C5	8150 077191	EVGENIY PETROV	{"email": "evgeniy.petrov_021985@postgrespro.ru", "phone": "+70451698774"}
0005433922405	9E6F74	2160 553877	KSENIYA SIDOROVA	{"email": "kseniya-sidorova061966@postgrespro.ru", "phone": "+70168001948"}
0005433922406	2F8B62	7625 285836	SERGEY KUZMIN	{"email": "s.kuzmin-1984@postgrespro.ru", "phone": "+70986365118"}
0005433922407	08D6EE	4605 032910	LYUDMILA SERGEEVA	{"phone": "+70817147837"}
0005433922408	C592D3	8306 132233	YULIYA SOKOLOVA	{"phone": "+70313186721"}
0005433922409	381DA5	2332 665869	PAVEL OSIPOV	{"phone": "+70377099111"}
0005433922410	552AE0	3481 177479	LYUDMILA FEDOROVA	{"email": "fedorova-l-12031963@postgrespro.ru", "phone": "+70713847506"}
0005433922411	552AE0	2046 548927	VADIM BARANOV	{"email": "v_baranov.071976@postgrespro.ru", "phone": "+70776438498"}
0005433922412	ACC54C	1021 657267	VASILIY VOLKOV	{"phone": "+70309803675"}
0005433922413	8EF8F9	8624 044383	VIKTORIYA PETROVA	{"email": "petrova-viktoriya.1972@postgrespro.ru", "phone": "+70415097940"}
0005433922414	4078D7	7575 557524	OLGA ALEKSEEVA	{"email": "o_alekseeva-1958@postgrespro.ru", "phone": "+70880431662"}
0005433922415	F1142B	8192 572641	EVGENIY KRASNOV	{"email": "evgeniykrasnov-13041972@postgrespro.ru", "phone": "+70719556222"}
0005433922416	0F49AA	9124 128314	NAIL KAZAKOV	{"phone": "+70827951858"}
0005433922417	81EB3A	4035 253498	VYACHESLAV MAKAROV	{"phone": "+70941009594"}
0005433922418	531CDE	2679 568866	LYUBOV NAZAROVA	{"email": "nazarova.l.27111967@postgrespro.ru", "phone": "+70901759340"}
0005433922419	D6ED72	3541 948640	BORIS KUZNECOV	{"email": "kuznecov.b.1967@postgrespro.ru", "phone": "+70108778800"}
0005433922420	DDCD8A	5122 016548	NINA FOMINA	{"email": "fominanina30051976@postgrespro.ru", "phone": "+70743781186"}
0005433922421	477341	5332 755793	SERGEY KULIKOV	{"email": "sergey.kulikov101968@postgrespro.ru", "phone": "+70860457501"}
0005433922422	5F0233	8472 112836	VASILIY IVANOV	{"phone": "+70882222436"}
0005433922423	AD1655	3194 876872	NADEZHDA KOROLEVA	{"email": "nadezhda-koroleva_071962@postgrespro.ru", "phone": "+70964243482"}
0005433922424	70641E	9155 388134	INNA ILINA	{"phone": "+70519801752"}
0005433922425	660F07	7154 794820	VALENTINA VOROBEVA	{"email": "valentina_vorobeva-1972@postgrespro.ru", "phone": "+70642885715"}
0005433922426	2326B4	5225 267604	NATALYA BARANOVA	{"email": "baranova.n111971@postgrespro.ru", "phone": "+70864370520"}
0005433922427	2326B4	8094 550983	LARISA YAKOVLEVA	{"email": "l.yakovleva.011985@postgrespro.ru", "phone": "+70838787939"}
0005433922428	68CCBF	3366 760635	NADEZHDA PETROVA	{"email": "nadezhda_petrova_051973@postgrespro.ru", "phone": "+70233088728"}
0005433922429	68CCBF	2248 735078	TATYANA SAVELEVA	{"phone": "+70928212523"}
0005433922430	DB8B81	0810 042041	OLEG KUZNECOV	{"phone": "+70003942401"}
0005433922431	6C84A6	5309 398389	SVETLANA BOGDANOVA	{"email": "s_bogdanova-031980@postgrespro.ru", "phone": "+70770813599"}
0005433922432	6C84A6	4422 690306	NATALYA POTAPOVA	{"email": "potapovan.18091974@postgrespro.ru", "phone": "+70737909243"}
0005433922433	0E593C	6118 774226	NATALIYA BELOVA	{"phone": "+70249324944"}
0005433922434	0E593C	6220 326783	OLGA TIKHONOVA	{"email": "o-tikhonova_1967@postgrespro.ru", "phone": "+70862600769"}
0005433922435	094EAE	5873 686643	VIKTOR TIKHONOV	{"phone": "+70750259278"}
0005433922436	E181FB	0144 962860	VLADIMIR MEDVEDEV	{"phone": "+70701869684"}
0005433922437	7BF9B7	5126 735010	ANATOLIY MAKAROV	{"email": "makarov-anatoliy01021971@postgrespro.ru", "phone": "+70721537522"}
0005433922438	3545EE	0238 199122	MARIYA RODIONOVA	{"phone": "+70044458543"}
0005433922439	3545EE	9571 001501	EVELINA SIDOROVA	{"email": "sidorova_e-1969@postgrespro.ru", "phone": "+70135638047"}
0005433922440	63A0A3	9170 469297	LYUBOV KALININA	{"phone": "+70432924241"}
0005433922441	63A0A3	4158 484394	YURIY DMITRIEV	{"phone": "+70925760890"}
0005433922442	63A0A3	7234 078841	VITALIY GORBUNOV	{"phone": "+70347305969"}
0005433922443	470331	5544 376867	VALENTINA SOLOVEVA	{"email": "soloveva-valentina.1973@postgrespro.ru", "phone": "+70192519435"}
0005433922444	470331	7159 967582	NADEZHDA KONOVALOVA	{"email": "konovalova.n121969@postgrespro.ru", "phone": "+70237181456"}
0005433922445	173DAF	5065 014872	VADIM ZHURAVLEV	{"email": "zhuravlev-vadim_1978@postgrespro.ru", "phone": "+70046788977"}
0005433922446	02EC79	7883 209561	GALINA MALYSHEVA	{"phone": "+70498465198"}
0005433922447	02EC79	8503 463159	VLADIMIR POPOV	{"email": "vladimirpopov-101974@postgrespro.ru", "phone": "+70666334288"}
0005433922448	73BE7B	6337 941508	VALENTINA KONDRATEVA	{"email": "kondratevavalentina_081957@postgrespro.ru", "phone": "+70878490790"}
0005433922449	6355EE	0338 098580	YURIY SERGEEV	{"phone": "+70343193311"}
0005433922450	2E1238	0978 786439	ARTUR SMIRNOV	{"email": "a_smirnov-1969@postgrespro.ru", "phone": "+70555063357"}
0005433922451	2E1238	4330 996184	TATYANA BELOVA	{"phone": "+70285383562"}
0005433922452	1F5273	6506 640891	GALINA ZAYCEVA	{"phone": "+70974119784"}
0005433922453	684C5E	9112 852708	ANATOLIY CHERNOV	{"phone": "+70610074382"}
0005433922455	60CB50	0057 767252	NADEZHDA KOROLEVA	{"email": "nkoroleva.021966@postgrespro.ru", "phone": "+70800898275"}
0005433922456	82191D	4577 895346	ARKADIY KARPOV	{"email": "karpov-arkadiy_08031966@postgrespro.ru", "phone": "+70269274979"}
0005433922457	0034BB	4805 240065	ALEKSANDR DMITRIEV	{"email": "a_dmitriev16011973@postgrespro.ru", "phone": "+70237572226"}
0005433922458	0034BB	5836 610501	LYUBOV MALYSHEVA	{"phone": "+70816180094"}
0005433922459	6200B9	8844 534658	ALEKSANDR ZHURAVLEV	{"phone": "+70051630315"}
0005433922460	2177F5	1230 789089	NINA FEDOROVA	{"email": "fedorova.nina_111962@postgrespro.ru", "phone": "+70974191753"}
0005433922461	2177F5	7006 012785	KONSTANTIN ZAYCEV	{"phone": "+70342013604"}
0005433922464	C4C3B3	7061 516268	KSENIYA TARASOVA	{"phone": "+70815318242"}
0005433922465	6359A1	1777 076664	VADIM SCHERBAKOV	{"email": "v.scherbakov07021974@postgrespro.ru", "phone": "+70218254198"}
0005433922466	6359A1	2202 115128	LYUBOV PAVLOVA	{"email": "lyubov-pavlova.071969@postgrespro.ru", "phone": "+70828914326"}
0005433922467	0A0E6D	2220 025395	VLADIMIR DMITRIEV	{"phone": "+70849749796"}
0005433922468	5DB355	2687 428511	SERGEY KUZNECOV	{"phone": "+70572671762"}
0005433922469	75A7BA	9901 072390	KRISTINA ZAKHAROVA	{"phone": "+70805869995"}
0005433922470	446D98	8222 026671	VALENTINA ROMANOVA	{"email": "romanova-v.081970@postgrespro.ru", "phone": "+70257786446"}
0005433922471	FE3211	5104 339196	ANDREY KUZNECOV	{"phone": "+70343707461"}
0005433922472	816D3D	5968 425385	RUSLAN PAVLOV	{"phone": "+70603655458"}
0005433922473	816D3D	2649 585706	KARINA ROMANOVA	{"email": "k-romanova121966@postgrespro.ru", "phone": "+70315935643"}
0005433922474	DE7CCD	6802 850666	ELENA EFIMOVA	{"phone": "+70486926273"}
0005433922475	DE7CCD	2293 189618	NINA NESTEROVA	{"email": "nnesterova-071958@postgrespro.ru", "phone": "+70496504933"}
0005433922476	C0A8B6	7432 923491	ALEKSANDR MAKAROV	{"email": "a_makarov071980@postgrespro.ru", "phone": "+70843277237"}
0005433922477	6A8C45	7014 775910	INNA TARASOVA	{"phone": "+70813146099"}
0005433922478	CA28A9	0500 386698	NIKOLAY IVANOV	{"email": "ivanov.nikolay1962@postgrespro.ru", "phone": "+70701338087"}
0005433922479	82416A	8864 348491	YURIY EGOROV	{"phone": "+70836341286"}
0005433922480	82416A	8651 511908	MARINA MOISEEVA	{"phone": "+70540845179"}
0005433922481	82416A	7395 241078	ANASTASIYA TARASOVA	{"phone": "+70145661661"}
0005433922482	74C739	2496 879358	MIKHAIL POPOV	{"phone": "+70433220974"}
0005433922483	74C739	1637 736219	VIKTOR STEPANOV	{"email": "viktor-stepanov051966@postgrespro.ru", "phone": "+70943708355"}
0005433922484	E35F61	6551 011284	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov_1981@postgrespro.ru", "phone": "+70213415387"}
0005433922485	FF482C	9821 240859	EKATERINA ALEKSEEVA	{"email": "alekseeva.e-1964@postgrespro.ru", "phone": "+70074306174"}
0005433922486	BFC85E	8277 768262	PAVEL CHERNOV	{"phone": "+70115056809"}
0005433922487	BFC85E	2361 704873	ALEKSEY VLASOV	{"email": "a.vlasov-1974@postgrespro.ru", "phone": "+70273265995"}
0005433922488	7B22DF	7721 684970	YURIY IVANOV	{"email": "ivanov_yuriy.11101966@postgrespro.ru", "phone": "+70168899946"}
0005433922489	0E832B	7218 257695	ANTON DMITRIEV	{"phone": "+70024414714"}
0005433922490	1F1D90	1166 940555	VLADIMIR KUZNECOV	{"phone": "+70951824899"}
0005433922491	1F1D90	5860 427351	SERGEY KOZLOV	{"email": "sergeykozlov-24111968@postgrespro.ru", "phone": "+70741402919"}
0005433922492	1F1D90	4277 308629	GALIYA AFANASEVA	{"phone": "+70385671758"}
0005433922493	714580	3033 754710	YURIY GERASIMOV	{"email": "gerasimovy051971@postgrespro.ru", "phone": "+70195891988"}
0005433922494	714580	9379 580169	VLADIMIR MAKAROV	{"email": "v-makarov.31081968@postgrespro.ru", "phone": "+70340680074"}
0005433922495	C39AD1	1196 032597	EVGENIY ZAYCEV	{"phone": "+70727291273"}
0005433922496	61CF48	6309 456450	NIKITA EGOROV	{"email": "egorov-nikita13061981@postgrespro.ru", "phone": "+70900400125"}
0005433922497	2E2720	4417 141302	GALINA GUSEVA	{"phone": "+70616465468"}
0005433922498	1C9ECA	4592 733139	ELENA EGOROVA	{"email": "e.egorova-23081978@postgrespro.ru", "phone": "+70279248068"}
0005433922499	AC1728	0127 912465	ELENA EGOROVA	{"email": "e_egorova14041964@postgrespro.ru", "phone": "+70940156477"}
0005433922500	0120B8	8001 472588	SVETLANA LEBEDEVA	{"email": "s.lebedeva-041965@postgrespro.ru", "phone": "+70062372883"}
0005433922501	29FB1F	3018 935951	LIDIYA KONOVALOVA	{"email": "lidiya.konovalova-08081972@postgrespro.ru", "phone": "+70931940736"}
0005433922502	DF7A1F	2182 707982	EVGENIY IVANOV	{"phone": "+70906157576"}
0005433922503	2BF2C0	9574 766799	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov_091964@postgrespro.ru", "phone": "+70740842839"}
0005433922504	19C41F	8479 143048	YULIYA CHERNOVA	{"phone": "+70458140630"}
0005433922505	19C41F	8163 735386	TIMOFEY SEMENOV	{"phone": "+70064213563"}
0005433922506	36C0D9	9482 276079	LYUBOV RODIONOVA	{"email": "l.rodionova.101959@postgrespro.ru", "phone": "+70687015121"}
0005433922507	991DB5	4857 370188	EMILIYA KRASNOVA	{"email": "emiliya.krasnova_1974@postgrespro.ru", "phone": "+70398417988"}
0005433922508	D7AE6F	5360 853317	SERGEY ZAKHAROV	{"phone": "+70905113027"}
0005433922509	D7AE6F	5676 877706	YURIY GUSEV	{"phone": "+70846368779"}
0005433922510	D7AE6F	7937 248851	VALERIY ANDREEV	{"email": "andreevvaleriy_1966@postgrespro.ru", "phone": "+70076908577"}
0005433922511	0899AB	9805 374298	OLEG SOROKIN	{"email": "sorokinoleg14081979@postgrespro.ru", "phone": "+70099678534"}
0005433922512	425FCC	8301 959255	MARIYA LUKYANOVA	{"phone": "+70166799192"}
0005433922513	CF8B54	9628 461132	GALINA FEDOROVA	{"phone": "+70953045273"}
0005433922514	CF8B54	3262 663690	VLADIMIR SCHERBAKOV	{"phone": "+70714409094"}
0005433922515	09C2D2	2211 616428	LARISA ALEKSANDROVA	{"phone": "+70680544380"}
0005433922516	09C2D2	3958 771008	VALENTINA BELYAEVA	{"email": "v-belyaeva_041968@postgrespro.ru", "phone": "+70807148642"}
0005433922517	02C9F8	0554 301786	FANIL IVANOV	{"email": "ivanov_f-021964@postgrespro.ru", "phone": "+70290879090"}
0005433922518	02C9F8	4588 542384	IRINA MOROZOVA	{"phone": "+70144539450"}
0005433922519	BB063D	2126 265003	DENIS POPOV	{"phone": "+70379292069"}
0005433922520	BB063D	0828 456155	OLEG ALEKSEEV	{"email": "oleg-alekseev.021972@postgrespro.ru", "phone": "+70856988613"}
0005433922521	73B061	7914 083972	EVGENIY ANTONOV	{"phone": "+70154587653"}
0005433922522	EC063C	3683 614521	DMITRIY SOLOVEV	{"email": "dmitriysolovev-21061970@postgrespro.ru", "phone": "+70074763709"}
0005433922523	EC063C	7962 740128	ALEKSANDR KRASNOV	{"email": "aleksandrkrasnov1976@postgrespro.ru", "phone": "+70831522078"}
0005433922524	EC063C	1521 399489	NIKOLAY SMIRNOV	{"phone": "+70037370246"}
0005433922525	6BF561	7410 381378	ALEKSANDRA BORISOVA	{"phone": "+70815557827"}
0005433922526	6BF561	8542 506044	SERGEY IVANOV	{"email": "ivanovs_10061969@postgrespro.ru", "phone": "+70350564768"}
0005433922527	CADC91	6890 424085	INNA GORBUNOVA	{"email": "gorbunova-i.1965@postgrespro.ru", "phone": "+70721342949"}
0005433922528	2A0292	1926 602083	RUSLAN KAZAKOV	{"email": "ruslan.kazakov-1973@postgrespro.ru", "phone": "+70271739618"}
0005433922529	79FE77	4006 453322	EVGENIY KOROLEV	{"email": "e_korolev111973@postgrespro.ru", "phone": "+70284974703"}
0005433922530	664360	2062 305751	VITALIY NIKITIN	{"phone": "+70014271723"}
0005433922531	88F034	9028 330581	KRISTINA KRASNOVA	{"email": "krasnova_kristina_1982@postgrespro.ru", "phone": "+70465556700"}
0005433922532	DBA403	9089 114268	NINA NIKITINA	{"phone": "+70512993227"}
0005433922533	DBA403	2632 448995	VLADIMIR ZHURAVLEV	{"phone": "+70011118732"}
0005433922534	D21C46	8698 599784	ALEKSANDR OSIPOV	{"phone": "+70525322378"}
0005433922535	D21C46	0996 344411	NIKOLAY EGOROV	{"email": "nikolay-egorov_011961@postgrespro.ru", "phone": "+70431707390"}
0005433922536	5F1C16	8402 063771	ALEKSANDR SOKOLOV	{"email": "sokolov.aleksandr.1977@postgrespro.ru", "phone": "+70158130877"}
0005433922537	39AB75	4343 429415	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov121977@postgrespro.ru", "phone": "+70324303215"}
0005433922538	78A3E7	8630 234199	VIKTOR MOISEEV	{"email": "v_moiseev-1982@postgrespro.ru", "phone": "+70396511618"}
0005433922539	C998CB	5341 906488	SANIYA ANISIMOVA	{"email": "anisimovas-071978@postgrespro.ru", "phone": "+70473569717"}
0005433922540	50B418	8315 919443	ANASTASIYA NESTEROVA	{"email": "a-nesterova.111968@postgrespro.ru", "phone": "+70057914858"}
0005433922541	22C84B	7347 144618	IGOR DAVYDOV	{"email": "davydov.igor-1984@postgrespro.ru", "phone": "+70617971199"}
0005433922542	22C84B	8281 913828	PAVEL SOLOVEV	{"phone": "+70083427388"}
0005433922543	CEB665	6638 688752	MAKSIM KULIKOV	{"email": "kulikov-maksim031961@postgrespro.ru", "phone": "+70184808903"}
0005433922544	EE25A5	2023 120433	VALERIYA POPOVA	{"email": "popovav-1965@postgrespro.ru", "phone": "+70080169190"}
0005433922545	EE25A5	4628 453802	NATALYA VOLKOVA	{"phone": "+70644504543"}
0005433922546	06DBCF	9992 010449	VIKTORIYA KOROLEVA	{"phone": "+70561031433"}
0005433922547	D68972	4699 965751	MARINA STEPANOVA	{"email": "stepanova-marina.01031965@postgrespro.ru", "phone": "+70163473154"}
0005433922548	9E89C9	3840 369621	VERA NIKOLAEVA	{"email": "nikolaevavera_091982@postgrespro.ru", "phone": "+70266546690"}
0005433922549	596F47	8322 325293	LYUBOV VASILEVA	{"email": "lyubovvasileva_08121973@postgrespro.ru", "phone": "+70508193203"}
0005433922550	596F47	7124 580519	LYUBOV FOMINA	{"phone": "+70927423116"}
0005433922551	596BF3	1858 195374	EGOR ZAKHAROV	{"email": "zakharov_e_1968@postgrespro.ru", "phone": "+70322806014"}
0005433922552	C0531D	7504 498273	ALEKSANDR SOLOVEV	{"phone": "+70916739318"}
0005433922553	C0531D	2398 675451	VALENTINA FILIPPOVA	{"phone": "+70679605187"}
0005433922554	6DA082	0001 479092	SVETLANA GORBUNOVA	{"email": "s-gorbunova011971@postgrespro.ru", "phone": "+70784389511"}
0005433922555	6DA082	6179 946758	EKATERINA PAVLOVA	{"phone": "+70499785451"}
0005433922556	5962D5	9303 051000	LYUDMILA BELOVA	{"email": "lyudmila-belova.14121962@postgrespro.ru", "phone": "+70885476065"}
0005433922557	83F29C	3112 416806	YURIY PETROV	{"email": "ypetrov-14031974@postgrespro.ru", "phone": "+70093304063"}
0005433922558	B9A1B5	4747 509597	NATALYA POPOVA	{"email": "popova.natalya081977@postgrespro.ru", "phone": "+70576621802"}
0005433922559	B9A1B5	3993 719227	ALEKSEY KARPOV	{"email": "aleksey_karpov1967@postgrespro.ru", "phone": "+70407917026"}
0005433922560	6E125A	9171 427726	GULFIYA SCHERBAKOVA	{"phone": "+70955948141"}
0005433922561	53975D	2026 708304	VLADISLAV FEDOROV	{"phone": "+70190404422"}
0005433922562	C986C7	7187 851264	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov_061976@postgrespro.ru", "phone": "+70738947165"}
0005433922563	FB61D3	9604 510457	LYUDMILA KOZLOVA	{"email": "l-kozlova.041959@postgrespro.ru", "phone": "+70532029193"}
0005433922564	FB61D3	6183 084428	NIKOLAY VOLKOV	{"phone": "+70364143381"}
0005433922565	2ABF9E	2415 365104	TATYANA VASILEVA	{"email": "t_vasileva.121976@postgrespro.ru", "phone": "+70935958409"}
0005433922566	2ABF9E	0103 128771	ANNA ABRAMOVA	{"email": "abramova-a051960@postgrespro.ru", "phone": "+70400646347"}
0005433922567	2ABF9E	0756 991793	OLGA KUZMINA	{"phone": "+70821033699"}
0005433922568	0ED8FF	0499 619968	SVETLANA YAKOVLEVA	{"email": "s.yakovleva-011971@postgrespro.ru", "phone": "+70290518790"}
0005433922569	0ED8FF	9046 236168	DMITRIY SOLOVEV	{"phone": "+70528475538"}
0005433922570	DC5FCF	9714 202428	VASILISA ISAEVA	{"phone": "+70681416482"}
0005433922571	DC5FCF	9118 737073	EKATERINA KISELEVA	{"email": "kiseleva.ekaterina1971@postgrespro.ru", "phone": "+70680661369"}
0005433922572	14D7DF	0705 847849	ANNA POPOVA	{"phone": "+70552002711"}
0005433922573	14D7DF	9895 851482	LIDIYA MOROZOVA	{"email": "lidiya-morozova-28011979@postgrespro.ru", "phone": "+70793373584"}
0005433922574	BE0513	1728 004866	VYACHESLAV GAVRILOV	{"email": "gavrilov-vyacheslav.04101973@postgrespro.ru", "phone": "+70761685866"}
0005433922575	DCE7F5	1643 670201	VIKTOR ZAKHAROV	{"email": "zakharov_v-1976@postgrespro.ru", "phone": "+70682999491"}
0005433922576	A7A53C	0615 035145	GALINA KUZNECOVA	{"phone": "+70473254824"}
0005433922577	4B2EF2	0677 164677	VALENTINA VOROBEVA	{"phone": "+70865718635"}
0005433922578	4B2EF2	9568 732944	VLADIMIR KUDRYASHOV	{"phone": "+70580598220"}
0005433922579	AD3951	1285 406736	ALINA SEMENOVA	{"email": "semenova-a-1980@postgrespro.ru", "phone": "+70346094774"}
0005433922580	AD3951	0703 409858	EVGENIY NIKOLAEV	{"email": "e_nikolaev-1979@postgrespro.ru", "phone": "+70692812288"}
0005433922581	36ADCE	1715 927507	SERGEY BARANOV	{"email": "sergey-baranov_06011978@postgrespro.ru", "phone": "+70204745796"}
0005433922582	36ADCE	6232 441587	ELENA YAKOVLEVA	{"phone": "+70419090023"}
0005433922583	1C9614	4031 102561	ANATOLIY IVANOV	{"phone": "+70268368200"}
0005433922584	9E7FD6	7498 818970	IRINA ZHURAVLEVA	{"phone": "+70003048013"}
0005433922585	9E7FD6	1481 107349	MAKSIM VOROBEV	{"phone": "+70487760336"}
0005433922586	F733DD	6754 720851	MARINA ZAKHAROVA	{"phone": "+70315909919"}
0005433922587	F733DD	1696 981321	VIKTOR MAKAROV	{"phone": "+70235009825"}
0005433922588	E89CC2	1413 031258	DMITRIY MIRONOV	{"email": "d.mironov-081963@postgrespro.ru", "phone": "+70881155453"}
0005433922589	E89CC2	9578 429308	ANTON NIKOLAEV	{"email": "a_nikolaev_111985@postgrespro.ru", "phone": "+70435162698"}
0005433922590	2D9274	3912 626990	ROZALIYA KOROLEVA	{"phone": "+70401512363"}
0005433922591	2D9274	9415 002879	LYUBOV VOLKOVA	{"email": "volkovalyubov_30071980@postgrespro.ru", "phone": "+70250894977"}
0005433922592	2D9274	2919 721393	DENIS PAVLOV	{"phone": "+70438969005"}
0005433922593	A3A4B3	0333 790534	ALIYA SMIRNOVA	{"phone": "+70562496654"}
0005433922594	92D3C3	0062 161049	VLADIMIR MOISEEV	{"email": "moiseev.v-021976@postgrespro.ru", "phone": "+70212062030"}
0005433922595	B4E475	8450 885246	VLADIMIR VOLKOV	{"phone": "+70824172344"}
0005433922596	CCFE45	2867 003899	DMITRIY VOROBEV	{"phone": "+70314378236"}
0005433922597	6A710E	1478 726461	MARINA KONOVALOVA	{"phone": "+70061282123"}
0005433922598	57B4B3	3823 256479	LEONID IVANOV	{"email": "ivanov-l_1974@postgrespro.ru", "phone": "+70419189771"}
0005433922599	0F07BF	0845 501480	VLADIMIR MAKAROV	{"phone": "+70101207202"}
0005433922600	C20728	4960 972862	DMITRIY MAKSIMOV	{"email": "maksimov_d_01121978@postgrespro.ru", "phone": "+70287804122"}
0005433922601	70C8F7	1040 902613	OLGA SOLOVEVA	{"email": "olga-soloveva.021967@postgrespro.ru", "phone": "+70973547989"}
0005433922602	70C8F7	3362 948921	ALEKSANDR MAKAROV	{"email": "makarov_a081973@postgrespro.ru", "phone": "+70567803190"}
0005433922603	0D79E2	5746 164864	ANATOLIY EGOROV	{"phone": "+70829723652"}
0005433922604	A4E340	7076 525203	MARIYA ABRAMOVA	{"email": "abramovamariya.091975@postgrespro.ru", "phone": "+70316595851"}
0005433922605	FEE771	7362 386183	NIKOLAY ILIN	{"email": "n.ilin021969@postgrespro.ru", "phone": "+70596246221"}
0005433922606	BF52AA	3958 460494	ELIZAVETA MOROZOVA	{"email": "e_morozova.07021978@postgrespro.ru", "phone": "+70754894429"}
0005433922607	396DAE	3531 472651	ANNA IVANOVA	{"phone": "+70012713299"}
0005433922608	D68A6B	5935 716492	VALENTINA ZAKHAROVA	{"email": "v-zakharova.071973@postgrespro.ru", "phone": "+70224870944"}
0005433922609	D68A6B	6702 446701	VIKTOR STEPANOV	{"phone": "+70174645993"}
0005433922610	E9E5DE	7874 393228	LARISA NIKIFOROVA	{"email": "larisa.nikiforova1972@postgrespro.ru", "phone": "+70552872130"}
0005433922611	C6DF77	8511 855320	IVAN MIKHAYLOV	{"phone": "+70215377700"}
0005433922612	DCEF39	5488 940727	VLADISLAV CHERNOV	{"phone": "+70904493842"}
0005433922613	4DFC4A	5429 222984	YULIYA ZAYCEVA	{"email": "yuliya_zayceva.27021980@postgrespro.ru", "phone": "+70164227539"}
0005433922614	4DFC4A	6862 798528	LYUBOV VOLKOVA	{"email": "lyubov.volkova-1963@postgrespro.ru", "phone": "+70346586746"}
0005433922615	4DFC4A	7412 203955	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov_26081964@postgrespro.ru", "phone": "+70005180108"}
0005433922616	4E3CCF	4019 670199	ANNA MOROZOVA	{"phone": "+70988839455"}
0005433922617	9B7376	0104 255735	IRINA SERGEEVA	{"phone": "+70670469881"}
0005433922618	9B7376	0825 988230	VASILIY BELOV	{"phone": "+70018292971"}
0005433922619	9D75DB	8352 592860	RAISA KOLESNIKOVA	{"phone": "+70916027335"}
0005433922620	9D75DB	0098 934237	VLADIMIR NIKOLAEV	{"phone": "+70917953794"}
0005433922621	272204	4786 481202	ALEKSEY SOKOLOV	{"phone": "+70428080938"}
0005433922622	4831F7	6818 339623	SERGEY PETROV	{"email": "s.petrov.1973@postgrespro.ru", "phone": "+70327319667"}
0005433922623	4831F7	0766 582960	ALEKSANDR ALEKSANDROV	{"phone": "+70448951872"}
0005433922624	225EBB	6677 728894	YANA IVANOVA	{"phone": "+70388315009"}
0005433922625	A5AAFA	8039 378640	VASILIY BORISOV	{"email": "borisov_v1977@postgrespro.ru", "phone": "+70262971394"}
0005433922626	877F6B	7520 062095	PETR STEPANOV	{"email": "petr.stepanov051973@postgrespro.ru", "phone": "+70004331411"}
0005433922627	877F6B	6504 983444	VIKTOR KAZAKOV	{"email": "kazakov-v.011964@postgrespro.ru", "phone": "+70177691252"}
0005433922628	175CBC	1118 398695	NIKOLAY SMIRNOV	{"phone": "+70646629270"}
0005433922629	552104	6221 871115	RUFIYA DENISOVA	{"phone": "+70358705968"}
0005433922630	D1B1DE	7479 893819	GALINA KALININA	{"phone": "+70280781712"}
0005433922631	D1B1DE	3584 091437	DIANA ROMANOVA	{"phone": "+70977280586"}
0005433922632	D1B1DE	4876 985937	SERGEY FEDOROV	{"phone": "+70614282717"}
0005433922633	B29D49	3070 883393	LYUDMILA KAZAKOVA	{"phone": "+70103202241"}
0005433922634	B29D49	2552 343881	ANZHELA KOLESNIKOVA	{"email": "a-kolesnikova-17091971@postgrespro.ru", "phone": "+70213962870"}
0005433922635	B29D49	4628 275268	SERGEY FILIPPOV	{"phone": "+70243820247"}
0005433922636	CC2531	5633 614641	IRINA NAZAROVA	{"email": "irinanazarova-15011971@postgrespro.ru", "phone": "+70451712408"}
0005433922637	CCEED0	3789 285413	VLADIMIR ALEKSEEV	{"email": "alekseev_v-1975@postgrespro.ru", "phone": "+70945948578"}
0005433922638	0FB1CD	8432 896391	VLADIMIR SMIRNOV	{"email": "v-smirnov_03121975@postgrespro.ru", "phone": "+70332162362"}
0005433922639	0FB1CD	6514 388474	NATALIYA MASLOVA	{"phone": "+70001072195"}
0005433922640	EB6934	8545 572875	MARIYA VASILEVA	{"email": "vasilevamariya1978@postgrespro.ru", "phone": "+70761063316"}
0005433922641	17783F	8687 428096	DMITRIY SERGEEV	{"phone": "+70951815371"}
0005433922642	C382E3	9755 981253	MARIYA EGOROVA	{"email": "m-egorova_11121974@postgrespro.ru", "phone": "+70840687151"}
0005433922643	BA1F4C	1926 686044	VALENTINA SOROKINA	{"email": "sorokina.v051966@postgrespro.ru", "phone": "+70026611280"}
0005433922644	542B71	1977 307141	DENIS ZHURAVLEV	{"email": "denis-zhuravlev.22071969@postgrespro.ru", "phone": "+70330908490"}
0005433922645	33778C	0772 994939	IRINA GUSEVA	{"email": "i-guseva1976@postgrespro.ru", "phone": "+70718474802"}
0005433922646	883227	9290 673484	ALEKSANDR FEDOROV	{"email": "afedorov121970@postgrespro.ru", "phone": "+70601110862"}
0005433922647	814CEE	7144 090049	ANATOLIY VOLKOV	{"phone": "+70484620331"}
0005433922648	814CEE	0199 876008	IVAN ZHUKOV	{"email": "zhukovivan_1972@postgrespro.ru", "phone": "+70259422743"}
0005433922649	891379	7152 419625	OLEG MOROZOV	{"email": "olegmorozov-1983@postgrespro.ru", "phone": "+70783331667"}
0005433922650	891379	6949 442971	MARINA SMIRNOVA	{"email": "marina_smirnova.1969@postgrespro.ru", "phone": "+70425769404"}
0005433922651	307F38	8376 872599	TATYANA TARASOVA	{"phone": "+70157221568"}
0005433922652	D93B76	7775 356844	VALENTINA FILIPPOVA	{"email": "valentina.filippova-12041955@postgrespro.ru", "phone": "+70040947376"}
0005433922653	0A7236	0845 934356	ALEKSEY POPOV	{"phone": "+70488449488"}
0005433922654	8243DA	2716 694589	IVAN IVANOV	{"email": "i.ivanov.09011978@postgrespro.ru", "phone": "+70649824012"}
0005433922655	8243DA	7248 891410	VITALIY KONOVALOV	{"phone": "+70096723886"}
0005433922656	3D3915	4043 514191	VALENTINA MATVEEVA	{"phone": "+70003178137"}
0005433922657	B9CE7F	5922 257900	NIKOLAY MAKAROV	{"email": "makarov_n.14111976@postgrespro.ru", "phone": "+70443686299"}
0005433922658	4B4741	9199 986277	ELENA DENISOVA	{"email": "e_denisova-081966@postgrespro.ru", "phone": "+70765404860"}
0005433922659	4B4741	0145 120230	RINAT STEPANOV	{"email": "stepanov-r1973@postgrespro.ru", "phone": "+70525035943"}
0005433922660	F34D25	4073 471756	LYUBOV VASILEVA	{"email": "vasileva-lyubov_1967@postgrespro.ru", "phone": "+70551121974"}
0005433922661	FAB61B	1574 006999	ALEKSANDRA SERGEEVA	{"phone": "+70997986557"}
0005433922662	8B3EBB	4805 532642	GRIGORIY VLASOV	{"email": "vlasov_g1983@postgrespro.ru", "phone": "+70660932572"}
0005433922663	8B3EBB	6541 129450	ANTON TARASOV	{"phone": "+70475088105"}
0005433922664	C58E31	3746 099348	VALERIY GERASIMOV	{"email": "gerasimov-v1962@postgrespro.ru", "phone": "+70400947861"}
0005433922665	B76B45	0543 734631	MILANA ISAEVA	{"phone": "+70858542127"}
0005433922666	0E81AC	6265 534823	LEONID FILIPPOV	{"email": "l.filippov-121965@postgrespro.ru", "phone": "+70025446575"}
0005433922667	90F24D	6055 928044	ANASTASIYA SIDOROVA	{"phone": "+70192635882"}
0005433922668	7947DE	5961 936949	OLGA NIKITINA	{"phone": "+70103665939"}
0005433922669	2BE969	5579 248805	NATALYA PAVLOVA	{"email": "pavlovanatalya-1974@postgrespro.ru", "phone": "+70142562799"}
0005433922670	7B9941	1734 325536	ANDREY SOLOVEV	{"phone": "+70843907814"}
0005433922671	7B9941	5109 238755	MIKHAIL MIRONOV	{"phone": "+70890567199"}
0005433922672	56E4B2	2229 783722	ELENA FEDOROVA	{"phone": "+70747646652"}
0005433922673	56E4B2	2139 316727	MARAT MIRONOV	{"email": "mironov.m.11031977@postgrespro.ru", "phone": "+70882881235"}
0005433922674	0CC557	4240 254344	ANATOLIY SMIRNOV	{"phone": "+70480321185"}
0005433922675	0CC557	7446 533946	VERA SIDOROVA	{"phone": "+70979718137"}
0005433922676	FD9D3A	7027 615811	NIKITA IVANOV	{"email": "ivanov-nikita24011964@postgrespro.ru", "phone": "+70429748125"}
0005433922677	0E242A	9019 858689	OLEG KUZNECOV	{"email": "kuznecov.o.11011985@postgrespro.ru", "phone": "+70888888443"}
0005433922678	7E2DCE	6307 384776	ELMIRA TITOVA	{"phone": "+70397432188"}
0005433922679	7E2DCE	8358 621796	OLGA KUZNECOVA	{"phone": "+70737811251"}
0005433922680	ADBBEE	0518 569175	MARIYA IVANOVA	{"email": "ivanova.m.071970@postgrespro.ru", "phone": "+70978121606"}
0005433922681	D2ECBF	1906 904449	NATALYA EGOROVA	{"email": "egorova-n-061973@postgrespro.ru", "phone": "+70509701043"}
0005433922682	E2451D	0726 560292	ANATOLIY KONOVALOV	{"email": "konovalov-a_081973@postgrespro.ru", "phone": "+70503805389"}
0005433922683	E2451D	7233 365156	NATALYA SMIRNOVA	{"phone": "+70172760198"}
0005433922684	5B9444	1501 591515	PETR CHERNOV	{"phone": "+70074350502"}
0005433922685	598EBF	3129 704265	EKATERINA SERGEEVA	{"email": "ekaterina.sergeeva-12011976@postgrespro.ru", "phone": "+70177925095"}
0005433922686	598EBF	1884 500249	ROMAN KUZMIN	{"email": "r.kuzmin.1977@postgrespro.ru", "phone": "+70687248915"}
0005433922687	D61C6D	5052 241884	YULIYA KUZMINA	{"phone": "+70925401817"}
0005433922688	D61C6D	5057 425071	ALEKSANDR FOMIN	{"phone": "+70924014791"}
0005433922689	0CC5D8	1850 488112	YULIYA ALEKSEEVA	{"email": "alekseeva.y1977@postgrespro.ru", "phone": "+70170466120"}
0005433922690	FD0515	8365 488642	IGOR EGOROV	{"phone": "+70795556923"}
0005433922691	579A81	9443 789259	EVGENIY ZAKHAROV	{"email": "e-zakharov.1965@postgrespro.ru", "phone": "+70487188739"}
0005433922692	2FD644	2650 647489	ZOYA KUZMINA	{"email": "zoyakuzmina-30081969@postgrespro.ru", "phone": "+70109114534"}
0005433922693	FC2E58	4566 263956	KSENIYA STEPANOVA	{"email": "stepanova-k_111983@postgrespro.ru", "phone": "+70161205086"}
0005433922694	B8046F	7240 655867	GENNADIY ALEKSANDROV	{"phone": "+70434790777"}
0005433922695	9393FB	9012 799909	SOFYA KUZMINA	{"email": "sofya.kuzmina-25111984@postgrespro.ru", "phone": "+70354296803"}
0005433922696	7CFB29	3087 574564	SERGEY FILIPPOV	{"phone": "+70053089635"}
0005433922697	B3C996	0978 972447	MARGARITA STEPANOVA	{"phone": "+70532721349"}
0005433922698	B3C996	0910 124422	ALEKSEY ZHURAVLEV	{"phone": "+70392850062"}
0005433922699	864670	6407 402475	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr-111973@postgrespro.ru", "phone": "+70090150663"}
0005433922700	0FEEF5	0019 323826	LYUBOV NIKITINA	{"phone": "+70531704782"}
0005433922701	0FEEF5	4995 701446	YURIY ALEKSEEV	{"phone": "+70362431348"}
0005433922702	0FEEF5	6717 424075	DANIIL SOROKIN	{"email": "daniil.sorokin-1974@postgrespro.ru", "phone": "+70526998202"}
0005433922703	90066F	3998 016844	YULIYA NESTEROVA	{"phone": "+70175417927"}
0005433922704	B8E93F	0571 936101	MARIYA KUZNECOVA	{"email": "mkuznecova1975@postgrespro.ru", "phone": "+70433433303"}
0005433922705	2976B7	8798 279682	AMINA TARASOVA	{"email": "tarasova_amina.031984@postgrespro.ru", "phone": "+70094611996"}
0005433922706	E26860	6600 066810	LILIYA GAVRILOVA	{"email": "gavrilova_l.1964@postgrespro.ru", "phone": "+70005531335"}
0005433922707	76EF00	1863 954703	EGOR VOLKOV	{"phone": "+70072187131"}
0005433922708	76EF00	5347 852954	NINA NIKOLAEVA	{"email": "nnikolaeva_1974@postgrespro.ru", "phone": "+70795017587"}
0005433922709	895283	5794 856137	VLADIMIR MAKAROV	{"email": "vladimirmakarov1971@postgrespro.ru", "phone": "+70298461107"}
0005433922710	895283	4701 374789	PAVEL FEDOROV	{"phone": "+70519023055"}
0005433922711	23CB6D	4699 204802	ANNA MAKAROVA	{"phone": "+70343575549"}
0005433922712	931A52	2834 060314	VASILIY MARTYNOV	{"email": "v.martynov_031962@postgrespro.ru", "phone": "+70195746533"}
0005433922713	2FBF7D	4617 968135	DMITRIY DENISOV	{"phone": "+70913578013"}
0005433922714	1D8901	6573 064578	OLGA NAZAROVA	{"phone": "+70555965948"}
0005433922715	1D8901	0417 415267	TATYANA AFANASEVA	{"email": "afanaseva_t.14081965@postgrespro.ru", "phone": "+70783298420"}
0005433922716	1D8901	0756 009945	NIKOLAY SEMENOV	{"email": "semenov_nikolay-021979@postgrespro.ru", "phone": "+70780246565"}
0005433922717	16A1B3	2255 252757	VLADIMIR PETROV	{"email": "petrov-vladimir-27031976@postgrespro.ru", "phone": "+70215294866"}
0005433922718	57A82F	2222 031342	LYUBOV LAZAREVA	{"email": "lyubovlazareva11061977@postgrespro.ru", "phone": "+70951434886"}
0005433922719	D52ABB	6951 034226	ALEKSEY DENISOV	{"email": "denisov-a-16011971@postgrespro.ru", "phone": "+70089379285"}
0005433922720	46C215	8114 028283	VIKTOR KOZLOV	{"email": "viktor.kozlov.1980@postgrespro.ru", "phone": "+70877390573"}
0005433922721	46C215	7901 455404	SVETLANA PAVLOVA	{"email": "svetlana-pavlova.09011977@postgrespro.ru", "phone": "+70767875688"}
0005433922722	9C3B91	6387 720376	OLGA PETROVA	{"phone": "+70907235942"}
0005433922723	09198C	6235 900406	NATALYA DAVYDOVA	{"email": "davydova.natalya.121987@postgrespro.ru", "phone": "+70589052540"}
0005433922724	550FFF	9822 225866	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr.09101965@postgrespro.ru", "phone": "+70090764672"}
0005433922725	0D2A80	3794 243201	VIKTOR CHERNOV	{"email": "chernovviktor-21061972@postgrespro.ru", "phone": "+70631227917"}
0005433922726	009091	2720 807598	ALEKSANDR MOISEEV	{"email": "aleksandrmoiseev-091978@postgrespro.ru", "phone": "+70889816996"}
0005433922727	009091	8995 612116	DANILA KOZLOV	{"email": "kozlovdanila-021975@postgrespro.ru", "phone": "+70237262328"}
0005433922728	69C1DA	7435 075913	DENIS SEMENOV	{"email": "d_semenov-071975@postgrespro.ru", "phone": "+70801386968"}
0005433922729	3B8C84	1559 698633	RAMILYA KRASNOVA	{"email": "ramilya.krasnova-051962@postgrespro.ru", "phone": "+70792461237"}
0005433922730	841D2D	9562 520670	INNA MAKAROVA	{"email": "inna.makarova121958@postgrespro.ru", "phone": "+70578272031"}
0005433922731	841D2D	7037 300967	RAISA EFREMOVA	{"email": "efremova.raisa-1971@postgrespro.ru", "phone": "+70443551503"}
0005433922732	F6DCC3	6922 043687	OLGA VASILEVA	{"email": "olga-vasileva051971@postgrespro.ru", "phone": "+70083989661"}
0005433922733	4C5F92	9664 357002	SERGEY BORISOV	{"email": "sborisov_13021971@postgrespro.ru", "phone": "+70875813961"}
0005433922734	EA56DC	2464 098657	ANDREY GERASIMOV	{"email": "andreygerasimov-29071967@postgrespro.ru", "phone": "+70172801811"}
0005433922735	4F8F8C	7273 822571	NATALYA NAUMOVA	{"phone": "+70856793886"}
0005433922736	AB3864	4616 827006	ANDREY MAKAROV	{"phone": "+70623384591"}
0005433922737	AB3864	1983 525635	PETR EGOROV	{"email": "p_egorov1956@postgrespro.ru", "phone": "+70551082830"}
0005433922738	CC1DAF	6999 504279	ELENA SIDOROVA	{"phone": "+70995116361"}
0005433922739	CC1DAF	0289 542117	FAINA KUZNECOVA	{"phone": "+70927772663"}
0005433922740	F1B74D	4894 449292	MARINA ALEKSEEVA	{"email": "alekseeva_m1961@postgrespro.ru", "phone": "+70109141419"}
0005433922741	D2113F	3143 084811	TATYANA VOROBEVA	{"email": "vorobeva.t-1981@postgrespro.ru", "phone": "+70308927978"}
0005433922742	C87D35	4513 883843	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko.13061973@postgrespro.ru", "phone": "+70978372207"}
0005433922798	401AEE	9425 051226	SVETLANA POPOVA	{"phone": "+70155048364"}
0005433922743	C87D35	7653 379056	NIKITA NAUMOV	{"email": "nnaumov12111960@postgrespro.ru", "phone": "+70422109931"}
0005433922744	00EF8D	8943 320736	ANATOLIY SCHERBAKOV	{"email": "anatoliyscherbakov-1961@postgrespro.ru", "phone": "+70863618147"}
0005433922745	4C4037	7644 645820	ALEKSANDR NOVIKOV	{"email": "a_novikov.1965@postgrespro.ru", "phone": "+70883503291"}
0005433922746	837125	4875 552955	VYACHESLAV ISAEV	{"email": "isaev.v.26121972@postgrespro.ru", "phone": "+70301935237"}
0005433922747	837125	2413 030927	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir1983@postgrespro.ru", "phone": "+70305325461"}
0005433922748	F29987	1943 248088	VLADIMIR KUDRYASHOV	{"phone": "+70761094409"}
0005433922749	F29987	8783 299490	IRINA KOLESNIKOVA	{"email": "i_kolesnikova_1985@postgrespro.ru", "phone": "+70348940359"}
0005433922750	F29987	3125 243169	ANZHELIKA ALEKSEEVA	{"phone": "+70649033401"}
0005433922751	11DFE0	5682 801999	VIKTOR GAVRILOV	{"email": "gavrilovviktor1986@postgrespro.ru", "phone": "+70473257082"}
0005433922752	11DFE0	6854 453716	ALEKSANDR TIMOFEEV	{"email": "a.timofeev-19011969@postgrespro.ru", "phone": "+70555609662"}
0005433922753	CA5514	9245 093649	DENIS FEDOTOV	{"phone": "+70484037226"}
0005433922754	CA5514	9262 623027	ARTEM IVANOV	{"phone": "+70587454989"}
0005433922755	18056D	1694 882916	MAKSIM VOROBEV	{"phone": "+70905476429"}
0005433922756	18056D	9915 212878	MARGARITA SOROKINA	{"email": "msorokina21111974@postgrespro.ru", "phone": "+70285897631"}
0005433922757	5865C1	2678 731496	VLADIMIR IVANOV	{"email": "v_ivanov-1988@postgrespro.ru", "phone": "+70982501987"}
0005433922758	5865C1	7235 436903	NIKOLAY VLASOV	{"phone": "+70449519774"}
0005433922759	54F5DF	3675 490147	VASILIY TIMOFEEV	{"email": "v.timofeev_1977@postgrespro.ru", "phone": "+70801044558"}
0005433922760	FAD08F	8020 224609	SERGEY KOZLOV	{"email": "kozlov.sergey-1973@postgrespro.ru", "phone": "+70362880337"}
0005433922761	FAD08F	2264 305845	ANASTASIYA MOROZOVA	{"phone": "+70437876330"}
0005433922762	484A6E	0392 583384	ALEKSANDR MEDVEDEV	{"phone": "+70807458552"}
0005433922763	484A6E	9805 114379	TAMARA AFANASEVA	{"phone": "+70001827040"}
0005433922764	3086C0	1249 825473	ALEKSANDR PAVLOV	{"email": "pavlov-a-23091979@postgrespro.ru", "phone": "+70711460949"}
0005433922765	3086C0	3460 634144	DMITRIY KARPOV	{"email": "karpov_d_1976@postgrespro.ru", "phone": "+70319428397"}
0005433922766	59076A	0292 986198	EKATERINA MAKAROVA	{"email": "makarova.e1980@postgrespro.ru", "phone": "+70862020044"}
0005433922767	59076A	7811 611296	DAMIR MEDVEDEV	{"email": "damir.medvedev_24101976@postgrespro.ru", "phone": "+70663881134"}
0005433922768	859956	9469 964527	EVGENIY IVANOV	{"phone": "+70935726950"}
0005433922769	859956	2675 897757	SVETLANA KRASNOVA	{"email": "krasnova.svetlana.1982@postgrespro.ru", "phone": "+70176918258"}
0005433922770	463456	7482 824981	ALEKSEY STEPANOV	{"email": "a_stepanov101973@postgrespro.ru", "phone": "+70083961232"}
0005433922771	463456	5463 954439	VASILISA PAVLOVA	{"phone": "+70682052396"}
0005433922772	463456	1560 677768	ANATOLIY SERGEEV	{"email": "a_sergeev_061968@postgrespro.ru", "phone": "+70834410670"}
0005433922773	4FE181	0558 334753	NURIYA POPOVA	{"phone": "+70089836255"}
0005433922774	663325	8109 580156	OLEG IVANOV	{"email": "ivanov-oleg-15101966@postgrespro.ru", "phone": "+70139096626"}
0005433922775	663325	2850 851006	ALEKSEY GERASIMOV	{"email": "gerasimov.a.121981@postgrespro.ru", "phone": "+70866040599"}
0005433922776	663325	8723 182305	VALENTINA KUZNECOVA	{"email": "vkuznecova_1971@postgrespro.ru", "phone": "+70379029767"}
0005433922777	195AF6	5222 265394	IVAN POPOV	{"email": "popov_i.22021970@postgrespro.ru", "phone": "+70982799998"}
0005433922778	3EACD0	4463 979487	NINA DENISOVA	{"phone": "+70108295166"}
0005433922779	9D7B70	1523 876775	DMITRIY ANDREEV	{"phone": "+70953867407"}
0005433922780	93FC58	3336 044433	ANDREY ROMANOV	{"phone": "+70515545753"}
0005433922781	93FC58	2754 920015	IRINA ORLOVA	{"email": "iorlova_1974@postgrespro.ru", "phone": "+70901028911"}
0005433922782	24F88B	0896 734861	ALEKSANDR ZAYCEV	{"phone": "+70155993204"}
0005433922783	985A88	8382 646207	ALEKSANDRA NESTEROVA	{"phone": "+70353434470"}
0005433922784	985A88	6664 554283	RUSLAN POPOV	{"phone": "+70582112093"}
0005433922785	BB4515	4320 736207	EVGENIY ABRAMOV	{"phone": "+70476234896"}
0005433922786	BB4515	5029 558185	IVAN FILIPPOV	{"email": "filippovivan-121969@postgrespro.ru", "phone": "+70583501460"}
0005433922787	F53B18	5603 626853	VERONIKA TIKHONOVA	{"phone": "+70798970135"}
0005433922788	9EDB30	9141 524145	ALEKSANDRA EGOROVA	{"phone": "+70880452687"}
0005433922789	9EDB30	4006 787459	VLADIMIR BORISOV	{"phone": "+70280258521"}
0005433922790	C2113D	1719 110394	LIDIYA ISAEVA	{"email": "isaeva.l_26011981@postgrespro.ru", "phone": "+70551133492"}
0005433922791	E51550	2129 547265	MARIYA ANISIMOVA	{"email": "anisimova_mariya031973@postgrespro.ru", "phone": "+70728325914"}
0005433922792	E51550	9592 268274	ARSENIY VASILEV	{"email": "a_vasilev121978@postgrespro.ru", "phone": "+70095911289"}
0005433922793	185CD3	6306 488489	YANA SEMENOVA	{"phone": "+70278200654"}
0005433922794	185CD3	1811 648203	NATALYA MIKHAYLOVA	{"email": "mikhaylova_natalya1980@postgrespro.ru", "phone": "+70827162066"}
0005433922795	061AD1	6366 232528	EKATERINA DENISOVA	{"email": "e.denisova041976@postgrespro.ru", "phone": "+70436678999"}
0005433923021	3A862F	5649 971311	ALEKSEY FOMIN	{"phone": "+70493267905"}
0005433922796	662529	5023 366754	MIKHAIL VASILEV	{"email": "mikhailvasilev-111976@postgrespro.ru", "phone": "+70606304810"}
0005433922797	662529	3290 634448	LYUDMILA SERGEEVA	{"phone": "+70999874531"}
0005433922799	7D3CE2	8057 507702	OKSANA DENISOVA	{"email": "denisovao.26061972@postgrespro.ru", "phone": "+70748858887"}
0005433922800	23E2F0	5467 268026	TATYANA SOKOLOVA	{"email": "tsokolova.05071964@postgrespro.ru", "phone": "+70214424682"}
0005433922801	0B11E6	9647 172085	VALENTIN IVANOV	{"phone": "+70203246097"}
0005433922802	0B11E6	4222 883130	ANDREY ANDREEV	{"email": "andrey_andreev_07111978@postgrespro.ru", "phone": "+70827901001"}
0005433922803	FB9A9F	1582 205483	VLADIMIR KUZNECOV	{"phone": "+70887423035"}
0005433922804	D0C7B9	9712 650437	NINA NAUMOVA	{"phone": "+70861990110"}
0005433922805	3036D4	1152 137596	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov01041979@postgrespro.ru", "phone": "+70223222423"}
0005433922806	3036D4	8195 197667	TATYANA YAKOVLEVA	{"email": "yakovleva.tatyana_22111973@postgrespro.ru", "phone": "+70893120743"}
0005433922807	3BB76F	4135 301150	ALEVTINA SMIRNOVA	{"email": "smirnovaalevtina-021973@postgrespro.ru", "phone": "+70606875754"}
0005433922808	130EE6	4715 083248	NIKOLAY SOROKIN	{"email": "sorokinnikolay-1962@postgrespro.ru", "phone": "+70024545961"}
0005433922809	902975	7039 676989	VLADIMIR MARTYNOV	{"email": "v_martynov-031977@postgrespro.ru", "phone": "+70263460669"}
0005433922810	902975	1423 351378	ALENA ROMANOVA	{"email": "romanovaa1961@postgrespro.ru", "phone": "+70871794019"}
0005433922811	6F3B93	9665 630194	MIKHAIL FEDOROV	{"email": "mikhail_fedorov_02101961@postgrespro.ru", "phone": "+70927094062"}
0005433922812	6F3B93	6671 381041	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov-15111973@postgrespro.ru", "phone": "+70238560853"}
0005433922813	A377C4	6374 289884	EDUARD FEDOTOV	{"email": "e-fedotov16021963@postgrespro.ru", "phone": "+70394585444"}
0005433922814	A377C4	0629 955258	VLADIMIR VLASOV	{"email": "vlasov-v.23121971@postgrespro.ru", "phone": "+70000113852"}
0005433922815	23EE0C	2017 227655	NELLI PETROVA	{"phone": "+70856686810"}
0005433922816	23EE0C	0320 962423	VALENTINA KALININA	{"email": "v-kalinina-101971@postgrespro.ru", "phone": "+70958903685"}
0005433922817	190FF7	2303 774689	YURIY FEDOTOV	{"email": "fedotov.y_04061970@postgrespro.ru", "phone": "+70541582518"}
0005433922818	B8D6FD	7252 976461	ANASTASIYA MOROZOVA	{"email": "a-morozova_1967@postgrespro.ru", "phone": "+70033637502"}
0005433922819	9E27F9	7831 804557	VYACHESLAV FEDOROV	{"phone": "+70578560458"}
0005433922820	A03587	4465 797919	RAIS ANDREEV	{"email": "r.andreev_18101977@postgrespro.ru", "phone": "+70725375559"}
0005433922821	D00A8E	9326 573063	MARAT FEDOROV	{"phone": "+70946115611"}
0005433922822	9F9DBB	6283 797541	IVAN NIKITIN	{"phone": "+70050241002"}
0005433922823	2F0C66	3384 189215	RUSLAN YAKOVLEV	{"email": "ruslanyakovlev_1965@postgrespro.ru", "phone": "+70384256927"}
0005433922824	2F0C66	1644 679685	NIKOLAY PAVLOV	{"email": "pavlov_nikolay_25101974@postgrespro.ru", "phone": "+70684507513"}
0005433922825	592DE7	1092 545316	ILYA KUZMIN	{"phone": "+70205722378"}
0005433922826	2307BB	5418 983226	IGOR KRASNOV	{"email": "i-krasnov.1980@postgrespro.ru", "phone": "+70470461893"}
0005433922827	2307BB	2632 401014	ELENA ROMANOVA	{"phone": "+70625675646"}
0005433922828	61C3E5	5835 479393	ALLA ZHUKOVA	{"phone": "+70176807904"}
0005433922829	61C3E5	8857 168509	MARINA KISELEVA	{"phone": "+70814971021"}
0005433922830	E41D6D	2811 776788	OLGA MAKAROVA	{"email": "makarova.o_15091968@postgrespro.ru", "phone": "+70011325214"}
0005433922831	B4E890	9725 171340	TATYANA FADEEVA	{"phone": "+70004508271"}
0005433922832	069B40	2293 478899	NADEZHDA NAUMOVA	{"phone": "+70582208709"}
0005433922833	C36FD0	4304 456675	VLADIMIR ANDREEV	{"email": "vladimir_andreev1969@postgrespro.ru", "phone": "+70417528268"}
0005433922834	C36FD0	3709 554834	VLADIMIR KAZAKOV	{"phone": "+70241769549"}
0005433922835	92CB1C	1447 702495	VLADIMIR FEDOROV	{"phone": "+70171149089"}
0005433922836	92CB1C	6898 862267	GAGIK BELOV	{"phone": "+70213253850"}
0005433922837	629E5C	1404 625351	ILYAS FEDOROV	{"phone": "+70486465542"}
0005433922838	629E5C	2744 478495	ILMIR DMITRIEV	{"phone": "+70368874250"}
0005433922839	CA3BF4	1298 949102	DAMIR ABRAMOV	{"email": "dabramov-01011975@postgrespro.ru", "phone": "+70857326344"}
0005433922840	00F26D	0902 617985	GALINA ZAKHAROVA	{"email": "g-zakharova021991@postgrespro.ru", "phone": "+70955269662"}
0005433922841	00F26D	1194 907509	YURIY TARASOV	{"email": "y-tarasov1966@postgrespro.ru", "phone": "+70773180489"}
0005433922842	3F898C	2827 599852	MAKSIM NIKOLAEV	{"phone": "+70503159303"}
0005433922843	1E4997	6607 962747	EVGENIYA MAKAROVA	{"phone": "+70645731802"}
0005433922844	1E4997	1827 183044	TAMARA ORLOVA	{"email": "orlova.t_14051956@postgrespro.ru", "phone": "+70067376874"}
0005433922845	F261B0	0774 449578	MARIYA BORISOVA	{"phone": "+70274414855"}
0005433922846	E26E36	2869 333576	GALINA MASLOVA	{"phone": "+70891896105"}
0005433922847	2881B2	5190 534172	VALENTINA ZAYCEVA	{"phone": "+70613047932"}
0005433922848	2881B2	0903 733353	VLADIMIR STEPANOV	{"email": "stepanov-v_101971@postgrespro.ru", "phone": "+70650499219"}
0005433922849	B65AE8	5434 192373	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko_041969@postgrespro.ru", "phone": "+70975193607"}
0005433922850	B65AE8	2109 133861	SVETLANA GRISHINA	{"email": "grishinasvetlana.19051968@postgrespro.ru", "phone": "+70043570602"}
0005433922851	78BC97	4121 273693	DMITRIY PETROV	{"email": "dmitriy.petrov071978@postgrespro.ru", "phone": "+70735839980"}
0005433922852	78BC97	0921 795290	MARINA MOROZOVA	{"email": "mmorozova.121971@postgrespro.ru", "phone": "+70583708195"}
0005433922853	42D57B	2546 069837	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey.1973@postgrespro.ru", "phone": "+70654418591"}
0005433922854	928B6D	9557 753609	SERGEY KOROLEV	{"phone": "+70249112665"}
0005433922855	928B6D	9496 797693	ALEKSANDRA SOLOVEVA	{"phone": "+70120364728"}
0005433922856	EE0C14	7016 579669	VALENTIN BARANOV	{"email": "valentin-baranov.14021967@postgrespro.ru", "phone": "+70522199449"}
0005433922857	03707B	2433 548590	EVDOKIYA KUDRYASHOVA	{"email": "kudryashova-evdokiya_28041981@postgrespro.ru", "phone": "+70485267728"}
0005433922858	13A932	1496 310546	VYACHESLAV KUZNECOV	{"phone": "+70608226729"}
0005433922859	13A932	0730 942692	NINA ROMANOVA	{"email": "romanovanina1975@postgrespro.ru", "phone": "+70545807917"}
0005433922860	FCF3EB	1845 653848	SERGEY MIRONOV	{"phone": "+70123347435"}
0005433922861	FCF3EB	1363 918717	ALEKSANDRA CHERNOVA	{"phone": "+70857862712"}
0005433922862	E980CE	8406 657247	ALEKSANDR OSIPOV	{"email": "osipov-aleksandr051973@postgrespro.ru", "phone": "+70481091175"}
0005433922863	65FA47	5194 846982	LEV KONOVALOV	{"email": "lev_konovalov-1970@postgrespro.ru", "phone": "+70391504510"}
0005433922864	F2057B	0710 336622	VERA KUZNECOVA	{"phone": "+70497810562"}
0005433922865	504562	2337 269609	VALERIYA FEDOROVA	{"email": "valeriya_fedorova_1970@postgrespro.ru", "phone": "+70509708950"}
0005433922866	504562	3906 917194	NATALYA ABRAMOVA	{"phone": "+70832306665"}
0005433922867	8E8F22	9061 813263	NADEZHDA SMIRNOVA	{"phone": "+70740533868"}
0005433922868	2B3536	2498 308202	NATALYA ZAYCEVA	{"email": "zayceva_n_071966@postgrespro.ru", "phone": "+70152613870"}
0005433922869	2B3536	1375 718806	STANISLAV VOLKOV	{"email": "stanislav-volkov_1971@postgrespro.ru", "phone": "+70414487006"}
0005433922870	7E16E9	7009 634343	KSENIYA GUSEVA	{"phone": "+70364261514"}
0005433922871	7E16E9	8096 696702	LARISA KUZMINA	{"email": "larisa_kuzmina_1973@postgrespro.ru", "phone": "+70971166688"}
0005433922872	19AC40	3969 947752	ALEKSANDR MEDVEDEV	{"phone": "+70845828245"}
0005433922873	CE8CAD	9533 539500	EKATERINA KUZNECOVA	{"phone": "+70370715493"}
0005433922874	953F72	0427 194781	NINA MOISEEVA	{"email": "ninamoiseeva.29031975@postgrespro.ru", "phone": "+70947349707"}
0005433922875	E9B89F	3843 423577	NINA OVCHINNIKOVA	{"email": "ovchinnikova-nina.14071979@postgrespro.ru", "phone": "+70232638161"}
0005433922876	1A75DC	1614 100563	EVGENIY YAKOVLEV	{"email": "yakovlev.evgeniy-1978@postgrespro.ru", "phone": "+70055015236"}
0005433922877	1A75DC	6397 518845	OLEG KISELEV	{"phone": "+70767281308"}
0005433922878	83B161	0284 716884	NATALYA OSIPOVA	{"email": "osipovanatalya_24111984@postgrespro.ru", "phone": "+70296245891"}
0005433922879	F28AA0	3053 381882	VLADIMIR ILIN	{"phone": "+70880629994"}
0005433922880	D3CADD	0099 533221	NATALIYA STEPANOVA	{"email": "n_stepanova_06041956@postgrespro.ru", "phone": "+70195989523"}
0005433922881	6CFB8C	0992 179027	NINA ZHUKOVA	{"phone": "+70321120905"}
0005433922882	F3FE79	5884 509462	ALEKSEY DENISOV	{"email": "denisov.aleksey-1968@postgrespro.ru", "phone": "+70372536814"}
0005433922883	8DD932	3077 018363	YULIYA ALEKSANDROVA	{"phone": "+70590680915"}
0005433922884	4DF787	5819 516767	NIKOLAY SIDOROV	{"email": "nikolay_sidorov.30091982@postgrespro.ru", "phone": "+70541043043"}
0005433922885	4DF787	9966 361959	SERGEY DMITRIEV	{"email": "dmitriev_sergey_1971@postgrespro.ru", "phone": "+70291428662"}
0005433922886	1A9E6C	4853 495625	NATALYA FILIPPOVA	{"email": "nfilippova1973@postgrespro.ru", "phone": "+70606472175"}
0005433922887	A55F00	1162 731130	IRINA IVANOVA	{"email": "i.ivanova1959@postgrespro.ru", "phone": "+70739621641"}
0005433922888	A55F00	7602 929633	SERGEY ZHUKOV	{"phone": "+70444487293"}
0005433922889	F8BAC4	0858 177335	VLADIMIR IVANOV	{"phone": "+70835013195"}
0005433922890	3845BA	4310 640380	ANATOLIY SMIRNOV	{"email": "smirnov_a08071970@postgrespro.ru", "phone": "+70334928589"}
0005433922891	499A28	3492 252457	ELENA TARASOVA	{"email": "elena_tarasova.1975@postgrespro.ru", "phone": "+70758691792"}
0005433922892	7DB933	9633 115030	ELENA OSIPOVA	{"phone": "+70682701909"}
0005433922893	65FBAB	7832 188641	MAKSIM BONDARENKO	{"email": "m.bondarenko15061968@postgrespro.ru", "phone": "+70172092949"}
0005433922894	004C3F	6880 177919	ALEKSANDR NIKITIN	{"phone": "+70161148890"}
0005433922895	004C3F	9204 482074	VITALIY SERGEEV	{"phone": "+70368916375"}
0005433922896	A395B3	0832 367742	ILYA ISAEV	{"phone": "+70193897954"}
0005433922897	A395B3	1890 715137	OLGA LEBEDEVA	{"email": "olga_lebedeva_021973@postgrespro.ru", "phone": "+70489427545"}
0005433922898	14BB9C	0609 521048	VLADIMIR MAKAROV	{"email": "vladimir_makarov.1969@postgrespro.ru", "phone": "+70139428895"}
0005433922899	176029	8293 448697	MARINA MAKAROVA	{"phone": "+70258157694"}
0005433922900	176029	3473 747288	VALENTINA LOGINOVA	{"phone": "+70813113942"}
0005433922901	176029	2436 167343	ALEKSANDR BARANOV	{"phone": "+70106221647"}
0005433922902	88ED8E	2163 383272	ANATOLIY PETROV	{"phone": "+70379186899"}
0005433922903	A12990	3917 253020	DMITRIY MIRONOV	{"email": "mironov.d-11011978@postgrespro.ru", "phone": "+70984957975"}
0005433922904	9E9573	7318 157816	OLESYA SAVELEVA	{"phone": "+70270415289"}
0005433922905	9E9573	6328 004093	ALEKSEY TIKHONOV	{"email": "aleksey-tikhonov-23111967@postgrespro.ru", "phone": "+70225769262"}
0005433922906	D5C594	7405 001396	KIRILL MELNIKOV	{"phone": "+70954790737"}
0005433922907	9F0858	4538 145447	VASILIY AFANASEV	{"phone": "+70566202829"}
0005433922908	743748	6149 479152	NADEZHDA ERMAKOVA	{"email": "n_ermakova.1973@postgrespro.ru", "phone": "+70646854755"}
0005433922909	28AB83	9285 242543	VIKTOR MELNIKOV	{"email": "melnikov_v-061961@postgrespro.ru", "phone": "+70091200832"}
0005433922910	28AB83	5171 115507	VALENTINA GUSEVA	{"email": "gusevavalentina_1972@postgrespro.ru", "phone": "+70245921924"}
0005433922911	3CDE18	2818 427002	ANTONINA GRISHINA	{"email": "grishina_antonina1976@postgrespro.ru", "phone": "+70493178838"}
0005433922912	21CF31	8948 074106	TATYANA GERASIMOVA	{"phone": "+70552283697"}
0005433922913	21CF31	2762 084516	EKATERINA ALEKSEEVA	{"phone": "+70061813921"}
0005433922914	85BA6D	8234 423090	ALEKSEY NAUMOV	{"phone": "+70283749881"}
0005433922915	85BA6D	3869 406287	GALINA GRISHINA	{"email": "galina-grishina.081965@postgrespro.ru", "phone": "+70511881498"}
0005433922916	F4075B	7465 663080	OLEG KOROLEV	{"email": "o-korolev_20051971@postgrespro.ru", "phone": "+70947706690"}
0005433922917	BE6159	8681 089719	ALEKSEY SMIRNOV	{"email": "smirnova021974@postgrespro.ru", "phone": "+70702422576"}
0005433922918	C901F2	7319 828245	IVAN IVANOV	{"phone": "+70083621075"}
0005433922919	C901F2	3408 893673	MARINA ALEKSEEVA	{"email": "alekseevamarina-01021983@postgrespro.ru", "phone": "+70218795558"}
0005433922920	008462	0477 054503	MARINA FEDOROVA	{"email": "marina.fedorova_1960@postgrespro.ru", "phone": "+70092495925"}
0005433922921	D54C64	6187 047884	ELENA MOROZOVA	{"email": "e-morozova_26091975@postgrespro.ru", "phone": "+70701229097"}
0005433922922	AF10BD	2827 278091	ARTEM GRIGOREV	{"phone": "+70942894189"}
0005433922923	AF10BD	0911 277417	VERONIKA NESTEROVA	{"email": "veronika.nesterova_26011974@postgrespro.ru", "phone": "+70531753153"}
0005433922924	1D9E90	8146 033384	IVAN SMIRNOV	{"phone": "+70330367640"}
0005433922925	677A4D	4732 877807	ALEKSANDRA GUSEVA	{"email": "a.guseva.1975@postgrespro.ru", "phone": "+70694014818"}
0005433922926	0A865E	4462 102053	VIKTORIYA KONDRATEVA	{"email": "vkondrateva_041988@postgrespro.ru", "phone": "+70421810322"}
0005433922927	15E627	9978 153508	NATALYA SOROKINA	{"email": "natalya-sorokina_1970@postgrespro.ru", "phone": "+70684850073"}
0005433922928	6B450F	6595 262892	ALEKSANDR CHERNOV	{"email": "a_chernov-071970@postgrespro.ru", "phone": "+70813507250"}
0005433922929	6B450F	5321 430786	DMITRIY MOISEEV	{"phone": "+70432946122"}
0005433922930	F09F84	7907 377387	LARISA NAZAROVA	{"phone": "+70587413337"}
0005433922931	F09F84	2028 842494	ELENA FILIPPOVA	{"phone": "+70471054596"}
0005433922932	5926C6	0804 669940	LYUDMILA KOZLOVA	{"phone": "+70139796096"}
0005433922933	C59C94	5328 092364	VLADIMIR EGOROV	{"phone": "+70303619487"}
0005433922934	064A6F	3958 593156	GENNADIY GORBUNOV	{"phone": "+70396957234"}
0005433922935	56BB90	8295 576097	IGOR VASILEV	{"phone": "+70494570785"}
0005433922936	BEA669	2454 016315	RASHIT PETROV	{"phone": "+70483202671"}
0005433922937	BEA669	1371 460513	ALEKSANDR DENISOV	{"email": "denisov.aleksandr.1976@postgrespro.ru", "phone": "+70063084719"}
0005433922938	A6CEE5	5615 284319	ELENA FILIPPOVA	{"email": "filippovae041964@postgrespro.ru", "phone": "+70591244442"}
0005433922939	4C620D	9017 581351	IRINA SOROKINA	{"phone": "+70447149286"}
0005433922940	4C620D	5225 338237	ILNAR STEPANOV	{"phone": "+70870632248"}
0005433922941	DB197B	5546 351435	ALEKSANDR SMIRNOV	{"email": "asmirnov1976@postgrespro.ru", "phone": "+70677668105"}
0005433922942	DB197B	8326 721527	RUSTAM IVANOV	{"email": "rustam_ivanov_1968@postgrespro.ru", "phone": "+70656936913"}
0005433922943	1266B3	0660 189920	ALEKSEY MAKSIMOV	{"phone": "+70633985263"}
0005433922944	EC9E49	4100 191227	DANIL KULIKOV	{"email": "danil_kulikov021977@postgrespro.ru", "phone": "+70548447051"}
0005433922945	125786	7914 938248	YANINA OSIPOVA	{"email": "osipovayanina_22031971@postgrespro.ru", "phone": "+70987384734"}
0005433922946	125786	8867 883038	VERA LOGINOVA	{"phone": "+70478452060"}
0005433922947	9B0379	1821 303713	NINA NESTEROVA	{"phone": "+70826972996"}
0005433922948	9B0379	3427 954114	VALERIY FOMIN	{"phone": "+70192406382"}
0005433922949	78C910	4684 035448	YULIYA ZAYCEVA	{"phone": "+70992639978"}
0005433922950	6B06F9	3092 754668	MARIYA EFREMOVA	{"email": "efremova_m-1982@postgrespro.ru", "phone": "+70077831973"}
0005433922951	8BE3A5	6455 214457	VLADISLAV ABRAMOV	{"email": "v-abramov-011970@postgrespro.ru", "phone": "+70623295184"}
0005433922952	0AE43B	7620 895658	NIKOLAY IVANOV	{"phone": "+70587395620"}
0005433922953	0AE43B	8233 945272	EVGENIY PETROV	{"email": "e_petrov-25101979@postgrespro.ru", "phone": "+70428769053"}
0005433922954	A3ECAA	0238 960206	SERGEY KAZAKOV	{"phone": "+70984568729"}
0005433922955	9B041F	5523 616042	OKSANA FILATOVA	{"email": "filatova.oksana1975@postgrespro.ru", "phone": "+70731293878"}
0005433922956	470A29	2083 196147	IVAN FILIPPOV	{"phone": "+70830319949"}
0005433922957	3773BC	9172 239068	SERGEY MIRONOV	{"email": "sergeymironov1974@postgrespro.ru", "phone": "+70620159357"}
0005433922958	2B7628	8883 752231	GENNADIY SMIRNOV	{"email": "smirnovgennadiy1960@postgrespro.ru", "phone": "+70552552192"}
0005433922959	F1909B	8120 478859	OLGA SEMENOVA	{"email": "semenova-o_051976@postgrespro.ru", "phone": "+70564449107"}
0005433922960	118C25	0672 296313	VASILIY PAVLOV	{"email": "pavlov.v_071977@postgrespro.ru", "phone": "+70408262881"}
0005433922961	118C25	7827 629643	SVETLANA FOMINA	{"email": "fomina.svetlana.111982@postgrespro.ru", "phone": "+70812649102"}
0005433922962	6A33B0	7051 672356	VLADIMIR PETROV	{"phone": "+70601540342"}
0005433922963	6A33B0	1021 433535	OLGA ZAYCEVA	{"phone": "+70413409423"}
0005433922964	807908	2911 690357	ANTONINA MAKAROVA	{"email": "makarova-antonina.121982@postgrespro.ru", "phone": "+70056896172"}
0005433922965	1AAFA1	5743 358926	ALEKSANDR SERGEEV	{"phone": "+70052246192"}
0005433922966	A49969	9256 336416	NADEZHDA BORISOVA	{"email": "borisova.nadezhda.111979@postgrespro.ru", "phone": "+70457533599"}
0005433922967	A49969	8967 871854	IRINA KUZNECOVA	{"phone": "+70302676964"}
0005433922968	3896DC	8694 660897	ROMAN NIKITIN	{"phone": "+70455804900"}
0005433922969	3896DC	0805 080941	VIKTOR NAZAROV	{"phone": "+70581130241"}
0005433922970	EFFC31	2128 048999	GALINA KUZNECOVA	{"phone": "+70159212274"}
0005433922971	ED603F	9312 715488	LARISA KOROLEVA	{"phone": "+70846810489"}
0005433922972	66B2A7	8985 992032	VALENTINA KOZLOVA	{"phone": "+70913184543"}
0005433922973	6FE5CE	7325 843328	ANDREY PAVLOV	{"email": "pavlov_a-28011982@postgrespro.ru", "phone": "+70637235873"}
0005433922974	6FE5CE	6141 088822	LARISA AFANASEVA	{"phone": "+70631810191"}
0005433922975	C67FE9	1880 318257	VERA IVANOVA	{"email": "ivanova_vera.1976@postgrespro.ru", "phone": "+70636730147"}
0005433922976	5424C0	7007 383175	DMITRIY KARPOV	{"phone": "+70209598426"}
0005433922977	5424C0	1648 944777	VLADIMIR ZAYCEV	{"phone": "+70277821479"}
0005433922978	07D1AC	8975 959049	IVAN KOROLEV	{"email": "korolev_i-1959@postgrespro.ru", "phone": "+70702238881"}
0005433922979	A99F3A	4417 122326	ALEKSANDR SHEVCHENKO	{"phone": "+70147412389"}
0005433922980	8BDB72	5279 253032	KRISTINA FOMINA	{"email": "kfomina_1969@postgrespro.ru", "phone": "+70286216658"}
0005433922981	02664B	4818 084733	SERGEY VOLKOV	{"phone": "+70501075447"}
0005433922982	02664B	7498 644763	YAROSLAV KAZAKOV	{"email": "yaroslav.kazakov1974@postgrespro.ru", "phone": "+70330406929"}
0005433922983	A6A488	4544 771887	RAMIL KUZNECOV	{"email": "r_kuznecov19111960@postgrespro.ru", "phone": "+70667692653"}
0005433922984	A6A488	9670 536123	ALEKSANDR PETROV	{"email": "petrova11121974@postgrespro.ru", "phone": "+70601633655"}
0005433922985	456D7D	5865 301432	VLADIMIR PAVLOV	{"email": "pavlov_v_1969@postgrespro.ru", "phone": "+70844225804"}
0005433922986	134711	8050 587001	DMITRIY STEPANOV	{"phone": "+70612283023"}
0005433922987	3E3A0C	8257 237413	MARIYA MASLOVA	{"phone": "+70335384293"}
0005433922988	23E864	2264 939315	VITALIY TARASOV	{"email": "v.tarasov.101974@postgrespro.ru", "phone": "+70910673763"}
0005433922989	DB4931	9591 691411	ELENA KOZLOVA	{"phone": "+70206551146"}
0005433922990	DB4931	7111 781203	LYUBOV SEMENOVA	{"email": "lyubov.semenova-15011974@postgrespro.ru", "phone": "+70717339379"}
0005433922991	229B43	1187 623362	MARIYA PETROVA	{"email": "m_petrova.011968@postgrespro.ru", "phone": "+70963712970"}
0005433922992	C9C9A1	1822 234719	NIKOLAY NAZAROV	{"email": "n.nazarov_09061970@postgrespro.ru", "phone": "+70523847085"}
0005433922993	2E7FDF	2784 623889	SERGEY POPOV	{"phone": "+70507810098"}
0005433922994	846179	3706 644930	TATYANA ZHUKOVA	{"phone": "+70911412871"}
0005433922995	AC4541	2884 091383	KHALIDA KULIKOVA	{"email": "kulikova_khalida-051966@postgrespro.ru", "phone": "+70361439008"}
0005433922996	DE847A	5797 090660	MARIYA NAUMOVA	{"phone": "+70812053572"}
0005433922997	9FD65E	8228 310243	ANTONINA SERGEEVA	{"email": "sergeevaantonina_21061975@postgrespro.ru", "phone": "+70110399081"}
0005433922998	C2A4B7	5971 619168	GENNADIY KUDRYASHOV	{"phone": "+70476360347"}
0005433922999	B75314	2699 210353	ALEKSANDR MOISEEV	{"phone": "+70552635940"}
0005433923000	B75314	7738 124650	MAKSIM KONOVALOV	{"email": "mkonovalov-101977@postgrespro.ru", "phone": "+70365361350"}
0005433923001	EA79A5	9521 569771	LEONID NIKOLAEV	{"phone": "+70028907038"}
0005433923002	EA79A5	5410 468322	VALERIY MATVEEV	{"phone": "+70936286745"}
0005433923003	706B2D	2577 906187	YULIYA ANDREEVA	{"email": "yuliya_andreeva-02061977@postgrespro.ru", "phone": "+70773078331"}
0005433923004	47B95E	7000 465251	ANDREY GERASIMOV	{"phone": "+70889300606"}
0005433923005	47B95E	1419 442032	IVAN MAKAROV	{"phone": "+70330877657"}
0005433923006	24C8F0	7797 545734	ANTON BONDARENKO	{"phone": "+70645121630"}
0005433923007	FF6789	5379 744995	SHAVKAT NIKITIN	{"email": "s.nikitin_04111968@postgrespro.ru", "phone": "+70048884266"}
0005433923008	FF6789	7521 372086	VALENTINA BELOVA	{"phone": "+70596673539"}
0005433923009	186C0D	9779 936340	MARIYA POPOVA	{"phone": "+70041869603"}
0005433923010	186C0D	6580 423724	MAKSIM SOLOVEV	{"email": "solovev_maksim_1978@postgrespro.ru", "phone": "+70323968453"}
0005433923011	C4B09A	3580 282194	EVGENIY ABRAMOV	{"phone": "+70230891383"}
0005433923012	4A5533	5564 142355	VASILIY ABRAMOV	{"phone": "+70589920879"}
0005433923013	206979	8555 402932	DENIS PETROV	{"email": "denis-petrov02011982@postgrespro.ru", "phone": "+70276724380"}
0005433923014	206979	0067 044079	VYACHESLAV SMIRNOV	{"email": "vsmirnov.26051976@postgrespro.ru", "phone": "+70185871565"}
0005433923015	EE0DE4	3553 985918	ELENA NIKITINA	{"email": "nikitina_e051973@postgrespro.ru", "phone": "+70131975663"}
0005433923016	B4683B	6074 789115	NINA KONDRATEVA	{"phone": "+70786492756"}
0005433923017	B4683B	3192 320603	LIDIYA MAKAROVA	{"phone": "+70085014082"}
0005433923018	D417F5	2557 703567	LARISA DMITRIEVA	{"phone": "+70997347112"}
0005433923019	D417F5	0713 443086	VLADIMIR NIKITIN	{"phone": "+70384773393"}
0005433923020	3A862F	6564 650447	SERGEY BORISOV	{"email": "borisov_s_25071971@postgrespro.ru", "phone": "+70193134153"}
0005433923022	136E19	6537 494982	NIKOLAY IVANOV	{"email": "ivanov_nikolay1975@postgrespro.ru", "phone": "+70849798183"}
0005433923023	EB02A8	3278 221726	LYUDMILA ALEKSEEVA	{"email": "alekseevalyudmila_24101979@postgrespro.ru", "phone": "+70032717967"}
0005433923024	336488	4806 788841	POLINA ANTONOVA	{"phone": "+70139928300"}
0005433923025	336488	4972 177162	EKATERINA ALEKSEEVA	{"phone": "+70734721409"}
0005433923026	94BDEB	1414 017745	ARINA BELYAEVA	{"phone": "+70228085959"}
0005433923027	DD5471	3572 535829	NINA KUZNECOVA	{"phone": "+70079407796"}
0005433923028	DD5471	6547 180433	ALEKSANDR TIKHONOV	{"phone": "+70741348676"}
0005433923029	ABE145	3862 967641	EVGENIY OSIPOV	{"phone": "+70818466680"}
0005433923030	11007A	8732 711453	SERGEY FILIPPOV	{"email": "s-filippov_021968@postgrespro.ru", "phone": "+70701774280"}
0005433923031	902163	6000 263455	GRIGORIY SCHERBAKOV	{"email": "scherbakov_g031984@postgrespro.ru", "phone": "+70858751964"}
0005433923032	2ED35D	9253 530528	DARYA LEBEDEVA	{"email": "d_lebedeva.19021965@postgrespro.ru", "phone": "+70511239102"}
0005433923033	74B64E	2195 554454	VLADIMIR TIKHONOV	{"phone": "+70956379989"}
0005433923034	5B1B28	9068 849714	ALEKSANDRA KULIKOVA	{"email": "kulikovaaleksandra_10041958@postgrespro.ru", "phone": "+70724818911"}
0005433923035	AD4F77	6969 411606	VLADIMIR NIKOLAEV	{"phone": "+70771491518"}
0005433923036	AD4F77	9280 312858	DARYA VASILEVA	{"phone": "+70830072656"}
0005433923037	CD9FDF	8785 951315	VITALIY PETROV	{"email": "v-petrov-1971@postgrespro.ru", "phone": "+70166688559"}
0005433923038	E0FCE6	7687 017267	SERGEY SIDOROV	{"email": "sidorov.s.1967@postgrespro.ru", "phone": "+70150908024"}
0005433923039	A36A48	7139 535769	SVETLANA KAZAKOVA	{"email": "s-kazakova081974@postgrespro.ru", "phone": "+70963677913"}
0005433923040	3997B0	2361 912826	NATALYA IVANOVA	{"email": "ivanova_n_121968@postgrespro.ru", "phone": "+70867517292"}
0005433923041	082B65	8122 748993	SERGEY NAZAROV	{"email": "sergeynazarov-1961@postgrespro.ru", "phone": "+70038037917"}
0005433923042	3E05BC	5917 182014	EVGENIY VASILEV	{"email": "vasilev-evgeniy_1961@postgrespro.ru", "phone": "+70944040240"}
0005433923043	3E05BC	4699 370704	LYUBOV STEPANOVA	{"email": "l.stepanova1969@postgrespro.ru", "phone": "+70553857914"}
0005433923044	BC00AC	3531 689033	ELENA KUZNECOVA	{"email": "elena-kuznecova-111964@postgrespro.ru", "phone": "+70098260078"}
0005433923045	AE2DDB	1319 311879	ALEKSANDR SEMENOV	{"phone": "+70174056479"}
0005433923046	E6408F	1650 520774	MARINA VLASOVA	{"email": "m_vlasova-121977@postgrespro.ru", "phone": "+70575918726"}
0005433923047	E6408F	3250 758130	ALEKSEY TARASOV	{"email": "a.tarasov-27071977@postgrespro.ru", "phone": "+70994841081"}
0005433923048	9802D8	2031 616832	GALINA NIKITINA	{"email": "g-nikitina_05101978@postgrespro.ru", "phone": "+70927791900"}
0005433923049	50D51A	2406 913857	ALISA TARASOVA	{"email": "tarasova-alisa_1975@postgrespro.ru", "phone": "+70027115177"}
0005433923050	50D51A	2600 790387	ANASTASIYA NESTEROVA	{"email": "nesterova-a-1964@postgrespro.ru", "phone": "+70791772766"}
0005433923051	063717	8933 767222	TATYANA IVANOVA	{"email": "tatyana-ivanova_01101968@postgrespro.ru", "phone": "+70081973029"}
0005433923052	074CE7	8236 939669	SERGEY TIMOFEEV	{"email": "timofeev_s.23081966@postgrespro.ru", "phone": "+70991037733"}
0005433923053	BD3AE5	7476 470907	ANNA ROMANOVA	{"phone": "+70062169589"}
0005433923054	717DC6	1320 580310	OLGA ZAKHAROVA	{"email": "zakharova_o.031975@postgrespro.ru", "phone": "+70218103203"}
0005433923234	71E05D	1834 548572	YULIYA MAKSIMOVA	{"phone": "+70278871044"}
0005433923055	717DC6	3237 193478	ANDREY KOZLOV	{"email": "andreykozlov_011978@postgrespro.ru", "phone": "+70508369416"}
0005433923056	717DC6	7758 919649	ALEKSANDR IVANOV	{"email": "ivanov-a.081979@postgrespro.ru", "phone": "+70781554445"}
0005433923057	717DC6	3701 032216	DMITRIY ZAYCEV	{"email": "dzaycev.1965@postgrespro.ru", "phone": "+70701361380"}
0005433923058	7D1D3D	3876 873134	POLINA ZHURAVLEVA	{"phone": "+70099303623"}
0005433923059	7D1D3D	1276 645458	VALENTINA ANTONOVA	{"phone": "+70116578640"}
0005433923060	30C720	9241 963021	MARIYA VLASOVA	{"phone": "+70978641091"}
0005433923061	364890	4376 453908	MARAT IVANOV	{"email": "m.ivanov.041969@postgrespro.ru", "phone": "+70962640087"}
0005433923062	888EFF	5691 799276	ELIZAVETA SOKOLOVA	{"email": "sokolova.e.071956@postgrespro.ru", "phone": "+70934569312"}
0005433923063	888EFF	1481 621711	ELENA MAKAROVA	{"email": "elena_makarova-1959@postgrespro.ru", "phone": "+70188565689"}
0005433923064	888EFF	8434 995706	NIKOLAY TARASOV	{"email": "tarasov.n-1968@postgrespro.ru", "phone": "+70426160004"}
0005433923065	888EFF	6290 006040	EVGENIY SEMENOV	{"email": "semenov_evgeniy1970@postgrespro.ru", "phone": "+70857246459"}
0005433923066	888EFF	8363 055283	DMITRIY AFANASEV	{"phone": "+70210281129"}
0005433923067	AA4FFA	4092 757264	SVETLANA VASILEVA	{"phone": "+70986803702"}
0005433923068	BBB917	5264 708126	YURIY ILIN	{"email": "yuriy_ilin.26091970@postgrespro.ru", "phone": "+70096233449"}
0005433923069	D912A4	9020 185921	DANIL DAVYDOV	{"phone": "+70086013242"}
0005433923070	044965	3142 070878	ROMAN KUZNECOV	{"phone": "+70523138749"}
0005433923071	809D46	4096 811223	ZINAIDA VASILEVA	{"email": "zvasileva.031972@postgrespro.ru", "phone": "+70812326202"}
0005433923072	809D46	3924 784084	ELENA DANILOVA	{"phone": "+70796888492"}
0005433923073	7D3D3E	5496 394293	GALINA VOROBEVA	{"phone": "+70972748727"}
0005433923074	5AEC5C	8560 834784	SERGEY MARTYNOV	{"phone": "+70199905678"}
0005433923075	29B4D9	9165 121166	NINA SOROKINA	{"email": "n.sorokina051975@postgrespro.ru", "phone": "+70813266146"}
0005433923076	29B4D9	1348 304422	TAISIYA KUZNECOVA	{"email": "kuznecova_t-1965@postgrespro.ru", "phone": "+70311073711"}
0005433923077	29B4D9	8949 883110	VIOLETTA VOLKOVA	{"phone": "+70379488725"}
0005433923078	29B4D9	3380 535550	NINA RODIONOVA	{"email": "nina_rodionova051961@postgrespro.ru", "phone": "+70599281572"}
0005433923079	868914	0149 097065	KIRA RYABOVA	{"email": "k-ryabova091971@postgrespro.ru", "phone": "+70044654891"}
0005433923080	56B082	4592 310982	VASILIY ZAYCEV	{"email": "vasiliy.zaycev_1966@postgrespro.ru", "phone": "+70978667615"}
0005433923081	A21152	5394 346917	ELIZAVETA OVCHINNIKOVA	{"phone": "+70332231619"}
0005433923082	787C58	9004 868261	YURIY PAVLOV	{"email": "pavlov.y051983@postgrespro.ru", "phone": "+70144307321"}
0005433923083	787C58	8844 354019	ILDAR VASILEV	{"email": "ildar_vasilev.1974@postgrespro.ru", "phone": "+70077582380"}
0005433923084	787C58	2792 153575	TATYANA TIKHONOVA	{"email": "tatyana_tikhonova1969@postgrespro.ru", "phone": "+70448881751"}
0005433923085	AB52D1	6090 432019	NIKOLAY KONOVALOV	{"email": "nikolay.konovalov_19111970@postgrespro.ru", "phone": "+70505268919"}
0005433923086	AB52D1	3723 017792	ANNA DAVYDOVA	{"phone": "+70739874630"}
0005433923087	4EB6B7	5921 304147	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-19121968@postgrespro.ru", "phone": "+70567052694"}
0005433923088	3A6F8D	5758 212477	OLEG ALEKSANDROV	{"email": "olegaleksandrov_101970@postgrespro.ru", "phone": "+70888615998"}
0005433923089	5D7394	7324 110207	YULIYA ERMAKOVA	{"email": "y-ermakova-1970@postgrespro.ru", "phone": "+70519546204"}
0005433923090	5D7394	5194 820349	LILIYA SERGEEVA	{"phone": "+70240084253"}
0005433923091	5D26C7	7658 180339	MIKHAIL GAVRILOV	{"phone": "+70224645298"}
0005433923092	5D26C7	8026 546589	OLGA ANTONOVA	{"phone": "+70232472690"}
0005433923093	54DEBA	6425 357718	ALEKSANDR VOLKOV	{"email": "a.volkov_101970@postgrespro.ru", "phone": "+70471554735"}
0005433923094	54DEBA	6259 046527	YURIY FOMIN	{"phone": "+70763577251"}
0005433923095	C997CC	0294 507908	ELENA EGOROVA	{"email": "elena-egorova-20111976@postgrespro.ru", "phone": "+70858573123"}
0005433923096	C6FED7	1310 693780	VALENTINA FILATOVA	{"email": "v_filatova-1974@postgrespro.ru", "phone": "+70124587585"}
0005433923097	C6FED7	8608 642601	ALEKSANDR KUDRYASHOV	{"phone": "+70617787880"}
0005433923098	BDBE81	1356 628388	MARIYA KOZLOVA	{"email": "kozlova-mariya.1976@postgrespro.ru", "phone": "+70618748723"}
0005433923099	9D3458	7255 204526	IGOR STEPANOV	{"email": "i-stepanov121977@postgrespro.ru", "phone": "+70418045441"}
0005433923100	9D3458	7177 783790	ARTUR VASILEV	{"phone": "+70646847290"}
0005433923101	3B5922	1445 413121	ANASTASIYA KRASNOVA	{"email": "a.krasnova-021976@postgrespro.ru", "phone": "+70504289306"}
0005433923102	3B5922	0850 168221	VLADIMIR VASILEV	{"email": "vasilev_v_031973@postgrespro.ru", "phone": "+70315901230"}
0005433923103	3B5922	8220 223945	ALEKSEY DMITRIEV	{"phone": "+70072270898"}
0005433923104	0E8E04	7969 355508	OLESYA DENISOVA	{"email": "denisovao-10041964@postgrespro.ru", "phone": "+70503958012"}
0005433923105	5EB575	2790 896370	VLADIMIR MAKSIMOV	{"email": "vladimir.maksimov.071965@postgrespro.ru", "phone": "+70254405921"}
0005433923106	F7BC6F	5709 563055	EKATERINA NESTEROVA	{"phone": "+70760020993"}
0005433923107	DB49DC	5787 512881	ANNA POPOVA	{"email": "popova_anna-1974@postgrespro.ru", "phone": "+70869752079"}
0005433923108	EA149A	3822 058359	VLADIMIR ILIN	{"email": "ilin-vladimir_1960@postgrespro.ru", "phone": "+70837767876"}
0005433923109	EA149A	3995 095102	NIKOLAY YAKOVLEV	{"phone": "+70515207118"}
0005433923110	EA149A	9344 241008	ALEKSANDR ORLOV	{"email": "aleksandr.orlov-08051972@postgrespro.ru", "phone": "+70462769418"}
0005433923111	EA149A	0560 405970	LEONID BORISOV	{"phone": "+70316087150"}
0005433923112	080012	4599 998609	LYUDMILA TARASOVA	{"email": "tarasovalyudmila_08091977@postgrespro.ru", "phone": "+70902857329"}
0005433923113	080012	1897 742421	VYACHESLAV KUZNECOV	{"phone": "+70947284674"}
0005433923114	153CAD	8369 508495	ELENA FILIPPOVA	{"email": "filippova-e_18051980@postgrespro.ru", "phone": "+70061158651"}
0005433923115	C4138F	5475 010452	SVETLANA KUZNECOVA	{"email": "kuznecova_s.1994@postgrespro.ru", "phone": "+70262193109"}
0005433923116	C4138F	5593 050253	YURIY NAZAROV	{"phone": "+70215572939"}
0005433923117	09764E	6497 667565	ELENA KUZNECOVA	{"phone": "+70732250777"}
0005433923118	41ED28	4152 161947	ANATOLIY VOLKOV	{"email": "volkov.anatoliy_1972@postgrespro.ru", "phone": "+70466369186"}
0005433923119	E94DFB	4204 765692	NATALYA BARANOVA	{"phone": "+70572898676"}
0005433923120	E94DFB	3811 393827	RAVILYA KOLESNIKOVA	{"email": "r.kolesnikova_22111969@postgrespro.ru", "phone": "+70898769174"}
0005433923121	437D0F	8324 241907	VLADIMIR MAKAROV	{"email": "makarov_vladimir021971@postgrespro.ru", "phone": "+70065441054"}
0005433923122	A2FB37	6999 624795	ANTONINA EGOROVA	{"email": "a.egorova-101971@postgrespro.ru", "phone": "+70241116674"}
0005433923123	56CFBF	8119 421871	IGOR ABRAMOV	{"email": "abramovi.051974@postgrespro.ru", "phone": "+70583726904"}
0005433923124	56CFBF	9732 254030	DANILA MAKAROV	{"phone": "+70553289737"}
0005433923125	DB6031	5603 639199	SERGEY BARANOV	{"phone": "+70922166135"}
0005433923126	DB6031	1090 942520	NIKOLAY STEPANOV	{"email": "stepanov_nikolay-031972@postgrespro.ru", "phone": "+70518107886"}
0005433923127	DB6031	6398 431954	ALEKSANDR YAKOVLEV	{"phone": "+70879211140"}
0005433923128	DC44DF	7112 548409	YAROSLAV POPOV	{"email": "popov-y_111973@postgrespro.ru", "phone": "+70435808028"}
0005433923129	41D56C	4330 986506	SERGEY VASILEV	{"email": "vasilev-sergey_1969@postgrespro.ru", "phone": "+70201912228"}
0005433923130	41D56C	3102 162035	MIKHAIL ANDREEV	{"email": "andreev.mikhail-1970@postgrespro.ru", "phone": "+70458990429"}
0005433923131	41D56C	8800 140362	ALEKSANDR KUZMIN	{"phone": "+70701916060"}
0005433923132	F58AD8	3272 209371	PETR PETROV	{"email": "p_petrov-1962@postgrespro.ru", "phone": "+70318850966"}
0005433923133	89F9A2	6724 207585	ALENA KUZNECOVA	{"phone": "+70018404768"}
0005433923134	FF88BC	7481 820510	SERGEY YAKOVLEV	{"phone": "+70963022062"}
0005433923135	DEA35A	9970 567206	TATYANA FOMINA	{"email": "fomina.t_011967@postgrespro.ru", "phone": "+70534411743"}
0005433923136	35BA9A	3110 405716	VLADISLAV KUZNECOV	{"phone": "+70619908707"}
0005433923137	129CDE	3269 903373	EKATERINA LAZAREVA	{"phone": "+70561057256"}
0005433923138	129CDE	9119 472637	IRINA EFREMOVA	{"email": "efremovairina031972@postgrespro.ru", "phone": "+70933387114"}
0005433923139	24CAA9	6103 314536	DENIS MOISEEV	{"email": "moiseevd.111981@postgrespro.ru", "phone": "+70204549688"}
0005433923140	FCF41C	8429 254014	MIKHAIL PETROV	{"phone": "+70274924224"}
0005433923141	1C32E8	5047 656870	ROMAN NOVIKOV	{"email": "novikov.roman_21011959@postgrespro.ru", "phone": "+70920657130"}
0005433923142	1C32E8	5986 226486	RAFAIL FROLOV	{"email": "rafailfrolov-1988@postgrespro.ru", "phone": "+70421236751"}
0005433923143	8DD327	2707 228593	DARYA MOISEEVA	{"email": "moiseevadarya16051979@postgrespro.ru", "phone": "+70721822923"}
0005433923144	FA1B3F	0705 860242	MIKHAIL KUZNECOV	{"phone": "+70268607158"}
0005433923145	656ACC	6757 512407	ALEKSEY STEPANOV	{"phone": "+70340328872"}
0005433923146	5C295E	2481 012322	ALENA DMITRIEVA	{"email": "a-dmitrieva.1969@postgrespro.ru", "phone": "+70307469937"}
0005433923147	5C295E	2808 872245	ANGELINA KUZNECOVA	{"phone": "+70287220125"}
0005433923148	8611AF	9667 223396	GALINA FROLOVA	{"email": "frolova_g_091984@postgrespro.ru", "phone": "+70754904349"}
0005433923149	550D36	7857 970912	LYUDMILA BORISOVA	{"phone": "+70775746355"}
0005433923150	550D36	3439 277731	ZARINA FILATOVA	{"phone": "+70809462725"}
0005433923151	A35DA0	7870 077402	GULNARA SCHERBAKOVA	{"email": "scherbakova.g_1965@postgrespro.ru", "phone": "+70684728928"}
0005433923152	05C163	7708 755373	VIKTOR SIDOROV	{"email": "v-sidorov.23111969@postgrespro.ru", "phone": "+70382465622"}
0005433923153	C0795D	1616 011084	ALEKSANDR ROMANOV	{"phone": "+70982481715"}
0005433923154	C0795D	1899 761005	DIANA KRASNOVA	{"email": "d_krasnova-22031977@postgrespro.ru", "phone": "+70508532647"}
0005433923155	3A694C	5190 603755	NIKOLAY NIKITIN	{"email": "n.nikitin.091970@postgrespro.ru", "phone": "+70034914796"}
0005433923156	D840FA	2873 760974	EKATERINA KRASNOVA	{"phone": "+70579826112"}
0005433923157	3C84EC	9958 182350	NADEZHDA ABRAMOVA	{"email": "n-abramova-111970@postgrespro.ru", "phone": "+70589718265"}
0005433923158	42C346	1508 040567	NINA STEPANOVA	{"phone": "+70605925948"}
0005433923159	7C8B22	3929 550347	SERGEY MIRONOV	{"email": "sergey_mironov.1979@postgrespro.ru", "phone": "+70435868970"}
0005433923160	E26DAF	3454 024557	DMITRIY ANDREEV	{"phone": "+70432862144"}
0005433923161	A4CDDA	5523 034528	ALEKSEY ZHUKOV	{"phone": "+70440790018"}
0005433923162	71E4CE	0525 130844	LARISA RYABOVA	{"phone": "+70925480319"}
0005433923163	28F17F	2034 131638	GALINA POPOVA	{"email": "popova.galina-1967@postgrespro.ru", "phone": "+70780645989"}
0005433923164	28F17F	7517 981160	TATYANA ROMANOVA	{"email": "romanova.t-26081967@postgrespro.ru", "phone": "+70780450323"}
0005433923165	D2E1B5	2127 455205	NADEZHDA NAUMOVA	{"phone": "+70252240256"}
0005433923166	18F424	9655 415381	ANDREY KRASNOV	{"phone": "+70109692846"}
0005433923167	18F424	0813 063127	IVAN MATVEEV	{"phone": "+70232167177"}
0005433923168	0ECFBA	1558 471203	VLADIMIR MOROZOV	{"phone": "+70119517822"}
0005433923169	527D74	8647 713849	ANDREY NAZAROV	{"phone": "+70805239849"}
0005433923170	1CF447	4374 423241	SERGEY ILIN	{"phone": "+70968854932"}
0005433923171	53D2FE	9014 420886	MARIYA KRASNOVA	{"email": "mariya_krasnova1960@postgrespro.ru", "phone": "+70167427857"}
0005433923172	53D2FE	6630 187570	MIKHAIL VASILEV	{"email": "mikhail_vasilev.10021959@postgrespro.ru", "phone": "+70863468069"}
0005433923173	A298C0	8284 835486	EKATERINA TIKHONOVA	{"phone": "+70843861537"}
0005433923174	A298C0	7245 510473	KRISTINA DMITRIEVA	{"phone": "+70889080727"}
0005433923175	1F17D5	1875 751229	ARTEM SERGEEV	{"email": "sergeev-a-1977@postgrespro.ru", "phone": "+70017892051"}
0005433923176	77BCD3	8621 636125	PAVEL MELNIKOV	{"email": "melnikov.pavel081972@postgrespro.ru", "phone": "+70303728260"}
0005433923177	91DAC3	6592 159440	NINA VASILEVA	{"email": "vasileva_n-1961@postgrespro.ru", "phone": "+70974744588"}
0005433923178	91DAC3	6534 630277	TATYANA MEDVEDEVA	{"email": "medvedeva-t_1975@postgrespro.ru", "phone": "+70763065079"}
0005433923179	91DAC3	0412 514185	VIKTOR PETROV	{"email": "petrovv.1973@postgrespro.ru", "phone": "+70281679220"}
0005433923180	F79752	2479 114073	MIKHAIL FEDOROV	{"email": "fedorov.mikhail.18051967@postgrespro.ru", "phone": "+70170932152"}
0005433923181	2F2662	5300 914372	LEONTIY MIRONOV	{"email": "leontiy-mironov.091974@postgrespro.ru", "phone": "+70872950412"}
0005433923182	2F2662	0328 084726	TAISIYA KUZNECOVA	{"phone": "+70832580622"}
0005433923183	0987C0	3584 025131	KIRILL SOROKIN	{"email": "kirillsorokin-071965@postgrespro.ru", "phone": "+70033243355"}
0005433923184	F41C85	2624 215253	VLADIMIR SEMENOV	{"phone": "+70990115301"}
0005433923185	9F4A8B	6572 931881	VALENTINA NAZAROVA	{"phone": "+70426810007"}
0005433923186	9F4A8B	3735 683589	GALINA KUZNECOVA	{"phone": "+70264508307"}
0005433923187	2EF2F7	6292 145647	PAVEL GUSEV	{"email": "gusev-pavel25061969@postgrespro.ru", "phone": "+70913409336"}
0005433923188	749646	1317 560748	KLAVDIYA MIRONOVA	{"email": "mironova.k_1959@postgrespro.ru", "phone": "+70621376615"}
0005433923189	749646	3636 174883	OKSANA KONDRATEVA	{"email": "kondrateva_o-03071968@postgrespro.ru", "phone": "+70541484536"}
0005433923190	B2D8B5	8468 949942	MARIYA KUZMINA	{"email": "kuzmina.mariya07121976@postgrespro.ru", "phone": "+70812257479"}
0005433923191	10F8E7	2440 312668	LEONID ORLOV	{"phone": "+70946366048"}
0005433923192	784E98	4822 239752	EKATERINA PETROVA	{"phone": "+70917967628"}
0005433923193	784E98	5404 133170	RAVIL NAUMOV	{"email": "naumov.r_071976@postgrespro.ru", "phone": "+70412843071"}
0005433923194	4E3758	0751 834680	SERGEY KUZNECOV	{"email": "kuznecov_sergey.19031980@postgrespro.ru", "phone": "+70493486591"}
0005433923195	6E98D6	2203 584365	STEPAN BARANOV	{"phone": "+70975957444"}
0005433923196	25FD01	4324 517968	GENNADIY FEDOROV	{"email": "g_fedorov1968@postgrespro.ru", "phone": "+70598937046"}
0005433923197	25FD01	0053 360914	TATYANA ABRAMOVA	{"phone": "+70670058900"}
0005433923198	37B650	6991 593759	ALEKSANDR CHERNOV	{"phone": "+70979740219"}
0005433923199	74E3B4	4403 249984	TATYANA SEMENOVA	{"phone": "+70681963582"}
0005433923200	8F4D18	3102 190762	ULYANA KUZNECOVA	{"email": "kuznecovau031965@postgrespro.ru", "phone": "+70120580263"}
0005433923201	C16CF0	1507 467087	NIKOLAY ZHURAVLEV	{"phone": "+70372400290"}
0005433923202	4F00C4	1731 623589	MARIYA POLYAKOVA	{"email": "polyakova_mariya1975@postgrespro.ru", "phone": "+70677025484"}
0005433923203	4F00C4	4400 790309	SVETLANA KOZLOVA	{"email": "skozlova_071976@postgrespro.ru", "phone": "+70665116014"}
0005433923204	EDE45D	5925 591060	ELENA MAKAROVA	{"email": "elena.makarova_1962@postgrespro.ru", "phone": "+70415792009"}
0005433923205	D86A38	5337 281865	OLGA KONDRATEVA	{"email": "okondrateva.1960@postgrespro.ru", "phone": "+70845136801"}
0005433923206	545B40	7707 652868	NADEZHDA MARTYNOVA	{"phone": "+70068593438"}
0005433923207	545B40	8429 525521	OLESYA NAZAROVA	{"phone": "+70478229452"}
0005433923208	33FEE7	6111 733490	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova-a.05091987@postgrespro.ru", "phone": "+70488223856"}
0005433923209	33FEE7	4315 901397	OLGA KOROLEVA	{"email": "koroleva_olga-14071967@postgrespro.ru", "phone": "+70628254646"}
0005433923210	222715	8358 488633	ELENA ANISIMOVA	{"phone": "+70885312235"}
0005433923211	14F02C	8394 136853	LYUBOV MOISEEVA	{"phone": "+70316979116"}
0005433923212	828EF7	2603 549845	VALERIYA EGOROVA	{"email": "egorova-v_1969@postgrespro.ru", "phone": "+70880223595"}
0005433923213	F912B0	5581 825042	VLADIMIR ZAYCEV	{"phone": "+70363888112"}
0005433923214	F912B0	3457 645971	MARIYA ISAEVA	{"email": "mariya.isaeva121970@postgrespro.ru", "phone": "+70563491102"}
0005433923215	BA12FE	1004 180248	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr_04041970@postgrespro.ru", "phone": "+70197413627"}
0005433923216	BA12FE	9107 126342	ALBERT SERGEEV	{"phone": "+70785995744"}
0005433923217	671149	0516 552355	SERGEY ANDREEV	{"email": "sergeyandreev011980@postgrespro.ru", "phone": "+70856524896"}
0005433923218	671149	2041 349554	VALENTINA SCHERBAKOVA	{"phone": "+70843637166"}
0005433923219	C62DBC	5595 025294	IRINA SCHERBAKOVA	{"email": "scherbakova-irina.101974@postgrespro.ru", "phone": "+70240551903"}
0005433923220	C62DBC	1977 577951	GALINA KOVALEVA	{"phone": "+70104949323"}
0005433923221	518EFC	8999 019469	NIKOLAY SEMENOV	{"email": "semenovn.091968@postgrespro.ru", "phone": "+70014186599"}
0005433923222	1A2C67	4778 238339	EVGENIYA PETROVA	{"email": "e_petrova05091979@postgrespro.ru", "phone": "+70983877640"}
0005433923223	1A2C67	2280 455946	PETR MEDVEDEV	{"email": "pmedvedev.1973@postgrespro.ru", "phone": "+70444487915"}
0005433923224	1A2C67	4771 296118	ELENA SOLOVEVA	{"email": "elena_soloveva_03091963@postgrespro.ru", "phone": "+70454087099"}
0005433923225	444329	6893 077988	VASILIY VOROBEV	{"email": "vorobev_v24101965@postgrespro.ru", "phone": "+70847064736"}
0005433923226	444329	9228 679686	ALEKSANDR SIDOROV	{"phone": "+70203993377"}
0005433923227	538CA9	2906 870630	VIKTORIYA MOISEEVA	{"email": "moiseevaviktoriya22091969@postgrespro.ru", "phone": "+70177464391"}
0005433923228	090E54	6707 432955	SERGEY BARANOV	{"email": "sergey-baranov1975@postgrespro.ru", "phone": "+70467351820"}
0005433923229	EE43F5	2878 820001	DARYA DENISOVA	{"phone": "+70524246442"}
0005433923230	E4B7D1	1068 570198	MARYAM CHERNOVA	{"phone": "+70819016752"}
0005433923231	E4B7D1	1079 253314	SERGEY MELNIKOV	{"phone": "+70170498372"}
0005433923232	DB344E	6980 323995	VALENTINA ISAEVA	{"phone": "+70032761348"}
0005433923233	DB344E	3938 315444	ROBERT ZAKHAROV	{"email": "rzakharov.1959@postgrespro.ru", "phone": "+70541257480"}
0005433923235	71E05D	2491 516533	LYUDMILA SOLOVEVA	{"phone": "+70870030322"}
0005433923236	85ED71	8876 819255	ILYA STEPANOV	{"phone": "+70801969759"}
0005433923237	85ED71	8990 519579	ANTON DENISOV	{"email": "anton.denisov_1958@postgrespro.ru", "phone": "+70270903469"}
0005433923238	155F5A	0952 447694	NATALYA NOVIKOVA	{"phone": "+70541671479"}
0005433923239	2515CA	3285 735782	DMITRIY KARPOV	{"phone": "+70019156357"}
0005433923240	B11B3D	2878 720181	IRINA NAZAROVA	{"email": "nazarova.irina_1976@postgrespro.ru", "phone": "+70511217947"}
0005433923241	56FCAB	6266 329614	NATALYA KONOVALOVA	{"phone": "+70765301877"}
0005433923242	56FCAB	0855 337273	EVA EFIMOVA	{"email": "e_efimova.101966@postgrespro.ru", "phone": "+70167956447"}
0005433923243	D7D19D	5016 651692	ANTONINA CHERNOVA	{"phone": "+70249103806"}
0005433923244	D7D19D	0897 470043	EKATERINA SMIRNOVA	{"email": "smirnovaekaterina-1968@postgrespro.ru", "phone": "+70382007589"}
0005433923245	1E5E5A	9657 401941	EDUARD SEMENOV	{"email": "semenov-eduard.011958@postgrespro.ru", "phone": "+70382352494"}
0005433923246	93D048	6206 560719	PAVEL ANTONOV	{"email": "pantonov_05061971@postgrespro.ru", "phone": "+70476729524"}
0005433923247	AFE97B	6663 578671	ANDREY YAKOVLEV	{"phone": "+70619558112"}
0005433923248	AFE97B	0820 034441	EKATERINA KOLESNIKOVA	{"email": "kolesnikova.ekaterina_011980@postgrespro.ru", "phone": "+70315557954"}
0005433923249	73BEE8	2046 617987	MIKHAIL VASILEV	{"phone": "+70771821218"}
0005433923250	720EE8	9299 073049	VYACHESLAV PAVLOV	{"phone": "+70064271147"}
0005433923251	EC3AFA	8000 991250	LIDIYA NIKITINA	{"email": "nikitina_l.08041971@postgrespro.ru", "phone": "+70928303654"}
0005433923252	8A6367	7587 215776	OLGA FILIPPOVA	{"phone": "+70405584728"}
0005433923253	7F7B66	4150 500419	VALENTIN VOROBEV	{"email": "valentin_vorobev.041968@postgrespro.ru", "phone": "+70085841812"}
0005433923254	DDD4AB	0924 558190	VALENTINA SOLOVEVA	{"phone": "+70109341346"}
0005433923255	85AEB6	6099 941248	VASILIY SOROKIN	{"phone": "+70709687059"}
0005433923256	974FD6	0455 005741	TATYANA EGOROVA	{"phone": "+70343921653"}
0005433923257	3B4D8A	9459 626880	NADEZHDA VOROBEVA	{"phone": "+70285162197"}
0005433923258	04EF61	8261 458509	VALENTINA MAKAROVA	{"phone": "+70403756128"}
0005433923259	6E948B	3758 538050	DMITRIY IVANOV	{"phone": "+70499728427"}
0005433923260	E7365D	2352 828872	IRINA ALEKSEEVA	{"phone": "+70665986754"}
0005433923261	E7365D	1368 572619	VYACHESLAV SMIRNOV	{"phone": "+70001292783"}
0005433923262	6D080E	2683 894459	VADIM ANDREEV	{"phone": "+70915047995"}
0005433923263	D0975B	4106 639764	KIRILL PAVLOV	{"phone": "+70407973916"}
0005433923264	BB03EF	4904 710773	ALEKSANDR MIRONOV	{"email": "mironova-04011971@postgrespro.ru", "phone": "+70579025229"}
0005433923265	BB03EF	7148 760110	SVETLANA SIDOROVA	{"phone": "+70967017365"}
0005433923266	3DE0DF	8624 156559	ALEKSANDR PAVLOV	{"email": "pavlov-a-1969@postgrespro.ru", "phone": "+70262098856"}
0005433923267	3DE0DF	9225 771838	RAISA ALEKSANDROVA	{"email": "aleksandrova-raisa1957@postgrespro.ru", "phone": "+70286433915"}
0005433923268	454E9B	8673 327351	EVGENIY BORISOV	{"email": "evgeniy-borisov1975@postgrespro.ru", "phone": "+70467899301"}
0005433923269	454E9B	4693 674555	DAMIR MOROZOV	{"email": "d_morozov-121969@postgrespro.ru", "phone": "+70319653442"}
0005433923270	454E9B	1539 890777	RITA EGOROVA	{"email": "egorova_r-07111976@postgrespro.ru", "phone": "+70948811920"}
0005433923271	454E9B	7593 268167	TATYANA KOZLOVA	{"email": "kozlova.tatyana_1970@postgrespro.ru", "phone": "+70793186044"}
0005433923272	F026B2	3393 948685	LYUBOV ILINA	{"email": "ilina.l1970@postgrespro.ru", "phone": "+70095166532"}
0005433923273	3CA98F	7612 429381	VALENTINA MIRONOVA	{"phone": "+70434962105"}
0005433923274	3CA98F	0080 943405	IVAN SOROKIN	{"phone": "+70739451732"}
0005433923275	F2BAFD	7783 237609	VLADIMIR IVANOV	{"phone": "+70047031112"}
0005433923276	EB68E1	4134 244681	ANVAR POPOV	{"email": "popov-a17081971@postgrespro.ru", "phone": "+70484507102"}
0005433923277	6A12BE	7985 344942	KRISTINA TROFIMOVA	{"phone": "+70369659230"}
0005433923278	8DC4E5	0346 347218	NATALYA KONDRATEVA	{"email": "natalyakondrateva011960@postgrespro.ru", "phone": "+70437881050"}
0005433923279	C4D369	4829 236854	SERGEY KUZNECOV	{"email": "kuznecovsergey12061979@postgrespro.ru", "phone": "+70907173250"}
0005433923280	CD9841	3715 122063	TAISIYA ZAYCEVA	{"email": "taisiyazayceva-121977@postgrespro.ru", "phone": "+70085162965"}
0005433923281	1F66CD	7559 792356	DARINA NIKIFOROVA	{"phone": "+70309298425"}
0005433923282	D0583A	3476 777067	MIKHAIL SERGEEV	{"email": "sergeevmikhail_02071970@postgrespro.ru", "phone": "+70702759592"}
0005433923283	696068	2598 939041	VALERIY RODIONOV	{"phone": "+70568634558"}
0005433923284	CD2598	3186 746926	TIMUR SOLOVEV	{"phone": "+70986690979"}
0005433923285	23E790	4617 084836	VALENTINA GRISHINA	{"email": "grishina.v_03031960@postgrespro.ru", "phone": "+70096251436"}
0005433923286	3D7D92	1252 473842	EKATERINA MALYSHEVA	{"email": "e_malysheva-1967@postgrespro.ru", "phone": "+70432959366"}
0005433923287	3D7D92	6588 522073	ALEKSEY TIMOFEEV	{"email": "a-timofeev.081976@postgrespro.ru", "phone": "+70068127810"}
0005433923288	743127	9136 410782	PAVEL DENISOV	{"phone": "+70134103415"}
0005433923289	5B3C42	6300 428097	YULIYA POPOVA	{"phone": "+70392801889"}
0005433923290	5B3C42	8723 234146	OLEG ZHUKOV	{"email": "oleg_zhukov.17101976@postgrespro.ru", "phone": "+70799168625"}
0005433923291	3B9CC0	0456 455977	YANA ALEKSEEVA	{"email": "alekseeva.y-1979@postgrespro.ru", "phone": "+70348050581"}
0005433923292	0331E8	6936 030246	EKATERINA FILIPPOVA	{"email": "efilippova051973@postgrespro.ru", "phone": "+70293506945"}
0005433923293	18D8D0	8243 049380	NINA KISELEVA	{"email": "n-kiseleva.1969@postgrespro.ru", "phone": "+70865022463"}
0005433923294	A7D8B0	1476 138931	YURIY EGOROV	{"phone": "+70447545187"}
0005433923295	2A41B5	1765 582018	VALERIY KOROLEV	{"email": "valeriy-korolev_1984@postgrespro.ru", "phone": "+70522184507"}
0005433923296	167DCE	3158 314704	SVETLANA IVANOVA	{"email": "ivanovasvetlana1969@postgrespro.ru", "phone": "+70327840649"}
0005433923297	EB317C	5786 513325	LYUBOV KOROLEVA	{"phone": "+70338689586"}
0005433923298	65379B	4713 405247	IVAN YAKOVLEV	{"email": "yakovlev.i031982@postgrespro.ru", "phone": "+70390717187"}
0005433923299	730B7E	1452 887781	VLADIMIR KOROLEV	{"phone": "+70705866767"}
0005433923300	730B7E	7961 151993	DANILA ANDREEV	{"email": "dandreev_08071976@postgrespro.ru", "phone": "+70253377795"}
0005433923301	B85D6E	8451 543858	ANTON KUZNECOV	{"phone": "+70739571373"}
0005433923302	F9D344	7376 101901	TAMARA SERGEEVA	{"email": "sergeeva.t.041970@postgrespro.ru", "phone": "+70360805477"}
0005433923303	BD0649	4509 927942	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr.15101960@postgrespro.ru", "phone": "+70986715527"}
0005433923304	FDDD82	8677 315253	OLEG KOZLOV	{"phone": "+70577055043"}
0005433923305	5C21DB	9195 643490	ALEKSEY GRIGOREV	{"email": "a_grigorev051976@postgrespro.ru", "phone": "+70827214825"}
0005433923306	5C21DB	7457 024604	VALENTINA ZHURAVLEVA	{"email": "zhuravlevavalentina15121959@postgrespro.ru", "phone": "+70109374702"}
0005433923307	B11034	0124 462488	EKATERINA VLASOVA	{"phone": "+70543242966"}
0005433923308	B11034	6178 644239	POLINA MAKAROVA	{"email": "makarovap.051985@postgrespro.ru", "phone": "+70404672922"}
0005433923309	561C35	1080 217024	OLESYA ALEKSEEVA	{"phone": "+70924202838"}
0005433923310	837C27	0462 437023	ANASTASIYA KUZNECOVA	{"email": "kuznecova.anastasiya021979@postgrespro.ru", "phone": "+70109913969"}
0005433923311	837C27	0684 365862	VLADIMIR KUZNECOV	{"phone": "+70751254540"}
0005433923312	2BD5F9	3062 446662	NINA PETROVA	{"phone": "+70498777541"}
0005433923313	8D316E	2025 070233	ALEKSANDRA KALININA	{"phone": "+70967489002"}
0005433923314	614B92	1275 607027	ELENA ANDREEVA	{"email": "andreeva-e12031968@postgrespro.ru", "phone": "+70559889459"}
0005433923315	C0BF33	5434 734771	VLADIMIR ZHUKOV	{"email": "zhukovv1963@postgrespro.ru", "phone": "+70311999811"}
0005433923316	C0BF33	6528 669119	VASILIY BORISOV	{"phone": "+70548221469"}
0005433923317	C0BF33	5921 498654	ELVIRA VOLKOVA	{"email": "volkova_elvira-07051978@postgrespro.ru", "phone": "+70678676890"}
0005433923318	4E8BB1	3467 802653	ANNA SOKOLOVA	{"email": "asokolova-1958@postgrespro.ru", "phone": "+70023578157"}
0005433923319	45E19E	3576 375031	MATVEY MAKAROV	{"phone": "+70726543232"}
0005433923320	80429C	0616 032870	ALEKSEY ALEKSEEV	{"phone": "+70429656004"}
0005433923321	1DA716	0540 148589	GLEB TARASOV	{"phone": "+70134905707"}
0005433923322	D05D8E	1489 763528	ALEKSEY SOKOLOV	{"email": "sokolov_aleksey_1981@postgrespro.ru", "phone": "+70404248262"}
0005433923323	8EAA4D	9546 394096	DMITRIY ROMANOV	{"email": "dmitriy_romanov021967@postgrespro.ru", "phone": "+70600493240"}
0005433923324	B43804	3747 753994	EKATERINA KUZNECOVA	{"phone": "+70609030770"}
0005433923325	F3A321	9157 863081	NIKITA DAVYDOV	{"phone": "+70247706063"}
0005433923326	F3A321	3895 126897	NADEZHDA PAVLOVA	{"phone": "+70547903714"}
0005433923327	F3A321	5370 143954	ANATOLIY KOZLOV	{"phone": "+70477613893"}
0005433923328	0723C5	5782 321200	ALEKSANDR BARANOV	{"email": "baranov.aleksandr_091965@postgrespro.ru", "phone": "+70853094786"}
0005433923329	0723C5	5579 588063	NATALYA EFIMOVA	{"email": "natalya_efimova.12101966@postgrespro.ru", "phone": "+70825994753"}
0005433923330	E69F2C	6137 640240	ILYA MAKSIMOV	{"email": "ilya-maksimov_101975@postgrespro.ru", "phone": "+70887721575"}
0005433923331	8001CE	4204 516727	TIMUR ZAKHAROV	{"phone": "+70958798299"}
0005433923332	65CC9E	1015 225943	YURIY BORISOV	{"phone": "+70655980015"}
0005433923333	61328B	6897 969546	IBRAGIM NIKOLAEV	{"email": "inikolaev_111973@postgrespro.ru", "phone": "+70358030696"}
0005433923334	33BCDB	4638 297902	TATYANA IVANOVA	{"phone": "+70639755007"}
0005433923335	33BCDB	8014 709958	SERGEY EGOROV	{"email": "egorov-s-16101980@postgrespro.ru", "phone": "+70964178162"}
0005433923336	F04A8C	3574 714556	TATYANA KUZNECOVA	{"phone": "+70294812695"}
0005433923337	30E907	0457 926152	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n-10021975@postgrespro.ru", "phone": "+70078553048"}
0005433923338	30E907	4284 266098	SERGEY KUZNECOV	{"phone": "+70901601173"}
0005433923339	4CD15B	3299 953573	OLGA KULIKOVA	{"phone": "+70249150760"}
0005433923340	4CD15B	6366 659460	NATALYA IVANOVA	{"email": "natalyaivanova-22011962@postgrespro.ru", "phone": "+70648164192"}
0005433923341	852473	1792 954257	NATALYA ZHUKOVA	{"email": "zhukova-natalya.1978@postgrespro.ru", "phone": "+70620301873"}
0005433923342	71AA0E	7500 986345	VIKTOR MAKAROV	{"email": "v_makarov18101979@postgrespro.ru", "phone": "+70586895243"}
0005433923343	71AA0E	7594 520715	SERGEY EGOROV	{"email": "segorov13111980@postgrespro.ru", "phone": "+70718993046"}
0005433923344	F8A62D	0081 116609	GALINA KONDRATEVA	{"phone": "+70033715318"}
0005433923345	6CE0C9	4544 208699	ANDREY IVANOV	{"email": "andrey-ivanov_1966@postgrespro.ru", "phone": "+70483683484"}
0005433923346	6CE0C9	4669 214790	MARIYA NIKIFOROVA	{"phone": "+70873503185"}
0005433923347	4F3ABC	8288 622576	EKATERINA KOROLEVA	{"phone": "+70682771771"}
0005433923348	686E80	2396 564233	TAMARA GAVRILOVA	{"phone": "+70445209620"}
0005433923349	78B993	2094 419348	ALEKSEY MAKAROV	{"email": "alekseymakarov_09111974@postgrespro.ru", "phone": "+70956015559"}
0005433923350	1B1BC8	8748 498655	VLADIMIR KAZAKOV	{"phone": "+70252162085"}
0005433923351	FCFD9B	5120 116095	LIDIYA PETROVA	{"phone": "+70902697623"}
0005433923352	FCFD9B	0316 684673	ANATOLIY ZAKHAROV	{"email": "a.zakharov.24111968@postgrespro.ru", "phone": "+70008188252"}
0005433923353	02C346	0984 654791	ALEKSANDR KOZLOV	{"phone": "+70740405574"}
0005433923354	8C97E5	8871 182336	VARVARA ANTONOVA	{"phone": "+70366545288"}
0005433923355	44460C	8836 564442	NATALYA EFIMOVA	{"email": "nefimova_20031971@postgrespro.ru", "phone": "+70569328783"}
0005433923356	0AF98F	0774 821079	ALEKSEY POPOV	{"phone": "+70750677487"}
0005433923357	0AF98F	5780 778033	MIKHAIL MIRONOV	{"phone": "+70431657481"}
0005433923358	DE0138	6875 138426	EVGENIY POPOV	{"phone": "+70314881057"}
0005433923359	411FCC	8468 631962	ZINAIDA ERMAKOVA	{"phone": "+70502433241"}
0005433923360	630C18	6267 972156	MIKHAIL IVANOV	{"email": "ivanov_m_041968@postgrespro.ru", "phone": "+70623879430"}
0005433923361	630C18	0755 321667	NINA PETROVA	{"phone": "+70299026591"}
0005433923362	0C4F3B	5896 301047	ALINA LAZAREVA	{"email": "alinalazareva_1979@postgrespro.ru", "phone": "+70454107493"}
0005433923363	3D80C7	6624 380126	STANISLAV NAUMOV	{"email": "naumovs_1960@postgrespro.ru", "phone": "+70358167636"}
0005433923364	9FB4CF	5120 952933	GALINA ANISIMOVA	{"phone": "+70360871217"}
0005433923365	BDFF7E	0535 996397	MARIYA BORISOVA	{"phone": "+70211121613"}
0005433923366	C6DFEC	0774 910171	ANASTASIYA DAVYDOVA	{"phone": "+70944024931"}
0005433923367	513524	8879 398075	VLADIMIR ZAYCEV	{"phone": "+70881867805"}
0005433923368	1A51C1	2134 061518	DMITRIY MEDVEDEV	{"phone": "+70718098307"}
0005433923369	5BB5D9	0877 166337	GALINA NESTEROVA	{"phone": "+70596961033"}
0005433923370	F735CC	3813 894988	GALINA IVANOVA	{"email": "ivanova-g-101970@postgrespro.ru", "phone": "+70395106642"}
0005433923371	9B527D	0162 371253	DARYA VOLKOVA	{"phone": "+70173832411"}
0005433923372	D1F56B	7047 514291	LARISA MATVEEVA	{"email": "matveeva.larisa_1982@postgrespro.ru", "phone": "+70002168113"}
0005433923373	D1F56B	0973 176263	EVGENIY KUZNECOV	{"phone": "+70793359406"}
0005433923374	CC449D	9817 208462	MIKHAIL PETROV	{"phone": "+70825727385"}
0005433923375	CC449D	2439 698885	TATYANA FROLOVA	{"email": "frolovat-071979@postgrespro.ru", "phone": "+70625981336"}
0005433923376	61D081	0605 195405	LYUBOV MAKAROVA	{"phone": "+70648320788"}
0005433923377	61D081	4435 671729	ALEKSANDR GRIGOREV	{"phone": "+70642120245"}
0005433923378	9EBA5B	3996 962669	IVAN IVANOV	{"phone": "+70617834410"}
0005433923379	7551B5	4242 345416	IRINA SOROKINA	{"phone": "+70283076618"}
0005433923380	7551B5	4125 201077	EVGENIY GERASIMOV	{"phone": "+70751848250"}
0005433923381	85E84F	5683 541013	NADEZHDA KOZLOVA	{"email": "nkozlova021974@postgrespro.ru", "phone": "+70140493282"}
0005433923382	85E84F	4872 780363	YULIYA KUZNECOVA	{"phone": "+70578969980"}
0005433923383	67B25E	2473 011502	EVGENIY PAVLOV	{"email": "pavlovevgeniy-091977@postgrespro.ru", "phone": "+70226781909"}
0005433923384	67B25E	6395 762080	SERGEY TARASOV	{"phone": "+70466906388"}
0005433923385	705706	3151 468697	FEDOR BONDARENKO	{"email": "bondarenko_fedor14021969@postgrespro.ru", "phone": "+70617500439"}
0005433923386	705706	5332 643360	KRISTINA IVANOVA	{"phone": "+70133996500"}
0005433923387	6DD042	2116 933202	EVGENIY MAKAROV	{"email": "makarov.e-19031964@postgrespro.ru", "phone": "+70971458652"}
0005433923388	A1EEAC	8338 703765	NIKITA KOROLEV	{"email": "nikita-korolev_071970@postgrespro.ru", "phone": "+70419859249"}
0005433923389	6558CE	9676 667650	NIKOLAY ZAKHAROV	{"phone": "+70456327744"}
0005433923390	EE9B9B	4310 837574	ZINAIDA SERGEEVA	{"phone": "+70124178217"}
0005433923391	EE9B9B	7935 258852	IVAN IVANOV	{"phone": "+70732412023"}
0005433923392	EE9B9B	2948 648040	SERGEY BORISOV	{"phone": "+70683140653"}
0005433923393	9F0402	6630 078352	TATYANA YUDINA	{"phone": "+70651926339"}
0005433923394	C90E27	7703 074695	NIKOLAY POPOV	{"phone": "+70216619933"}
0005433923395	C90E27	3538 452832	BORIS DAVYDOV	{"phone": "+70479382743"}
0005433923396	911432	7861 834866	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya1971@postgrespro.ru", "phone": "+70680783995"}
0005433923397	6AAD4D	3373 830003	LILIYA SOLOVEVA	{"phone": "+70457406420"}
0005433923398	6AAD4D	2247 717549	GENNADIY ISAEV	{"email": "isaevg.1970@postgrespro.ru", "phone": "+70225841766"}
0005433923399	B0F039	6106 868089	ILGIZ SOKOLOV	{"phone": "+70620825155"}
0005433923400	B0F039	6996 727559	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova_1970@postgrespro.ru", "phone": "+70552448694"}
0005433923401	D24911	6081 269734	SERGEY POPOV	{"email": "spopov_1976@postgrespro.ru", "phone": "+70428420211"}
0005433923402	D24911	4372 086059	ELENA TIMOFEEVA	{"email": "timofeeva_elena1973@postgrespro.ru", "phone": "+70133468020"}
0005433923403	EC01EC	7041 171303	NATALYA ALEKSEEVA	{"email": "natalyaalekseeva1982@postgrespro.ru", "phone": "+70276479138"}
0005433923404	EC01EC	3238 956112	LIDIYA IVANOVA	{"email": "lidiya_ivanova-07081972@postgrespro.ru", "phone": "+70514529236"}
0005433923405	51D1A7	4684 026140	ALEVTINA NAZAROVA	{"email": "a-nazarova.1975@postgrespro.ru", "phone": "+70964807558"}
0005433923406	8AD848	8970 759927	MAKSIM AFANASEV	{"email": "afanasevmaksim1964@postgrespro.ru", "phone": "+70252133942"}
0005433923407	5277B2	3279 287250	DARYA ZAKHAROVA	{"email": "darya-zakharova-1965@postgrespro.ru", "phone": "+70812105021"}
0005433923408	5277B2	9300 793947	KONSTANTIN VOLKOV	{"email": "k.volkov-1969@postgrespro.ru", "phone": "+70893950564"}
0005433923409	9E77BF	0962 991975	MARIYA NIKOLAEVA	{"email": "m.nikolaeva_051958@postgrespro.ru", "phone": "+70328262108"}
0005433923410	138DEB	7266 278274	OLGA FADEEVA	{"phone": "+70059639638"}
0005433923411	C649C3	6325 760707	RADIK STEPANOV	{"phone": "+70751282151"}
0005433923412	C649C3	7530 295317	VALERIYA VOLKOVA	{"phone": "+70850962972"}
0005433923413	C649C3	3078 692598	VALERIYA STEPANOVA	{"phone": "+70931491716"}
0005433923414	01BB50	4269 040037	ALEKSANDR STEPANOV	{"phone": "+70180955456"}
0005433923415	A01548	8919 325544	RIMMA LAZAREVA	{"phone": "+70150774236"}
0005433923416	C74288	4937 477216	EVGENIY TIKHONOV	{"phone": "+70164851070"}
0005433923417	C74288	4904 707776	DMITRIY DMITRIEV	{"email": "dmitrievd-1978@postgrespro.ru", "phone": "+70287886326"}
0005433923418	4D4658	4457 681729	DARYA DANILOVA	{"email": "darya-danilova.14111967@postgrespro.ru", "phone": "+70178038798"}
0005433923419	599DFE	4492 631214	NIKOLAY BORISOV	{"phone": "+70149298092"}
0005433923420	B1010C	9487 505840	MIKHAIL SCHERBAKOV	{"email": "mikhail-scherbakov.071974@postgrespro.ru", "phone": "+70478036911"}
0005433923421	F6D6B3	7238 402578	EVGENIY ALEKSANDROV	{"email": "aleksandrov.evgeniy-1966@postgrespro.ru", "phone": "+70742925482"}
0005433923422	FDCDBB	7993 432695	MIKHAIL MAKSIMOV	{"email": "m_maksimov_1990@postgrespro.ru", "phone": "+70373827315"}
0005433923423	FDCDBB	9094 366062	DENIS FEDOROV	{"phone": "+70649946026"}
0005433923424	2DAAB9	1275 950181	ANASTASIYA MATVEEVA	{"phone": "+70377853463"}
0005433923425	A4D5CC	0521 314476	GENNADIY SEMENOV	{"email": "semenov.gennadiy.091983@postgrespro.ru", "phone": "+70157051653"}
0005433923426	8A3B93	1580 773447	ALENA KUDRYASHOVA	{"phone": "+70524964292"}
0005433923427	8A3B93	4276 510485	ANDREY RODIONOV	{"email": "rodionovandrey_17121967@postgrespro.ru", "phone": "+70900176898"}
0005433923428	C46288	7029 116942	VADIM KUZNECOV	{"email": "kuznecov.v_051972@postgrespro.ru", "phone": "+70983719099"}
0005433923429	49E900	6960 264038	YANA KALININA	{"email": "kalininay-1973@postgrespro.ru", "phone": "+70322826846"}
0005433923430	46A7C0	2778 811560	TATYANA FEDOROVA	{"email": "fedorova-tatyana-1978@postgrespro.ru", "phone": "+70787962515"}
0005433923431	9AB76F	3084 605214	IVAN FEDOTOV	{"phone": "+70907324676"}
0005433923432	91EFA5	3573 964020	NIKOLAY OSIPOV	{"phone": "+70329169638"}
0005433923433	603C01	1943 607516	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_24071972@postgrespro.ru", "phone": "+70252131692"}
0005433923434	8F0602	4370 083413	NIKOLAY GORBUNOV	{"phone": "+70274437158"}
0005433923435	771423	2994 551574	SVETLANA SAVELEVA	{"email": "svetlanasaveleva_1960@postgrespro.ru", "phone": "+70612382627"}
0005433923436	F0496D	3777 762427	TATYANA ROMANOVA	{"phone": "+70479733045"}
0005433923437	575B4F	2355 118055	ELENA NIKIFOROVA	{"email": "e-nikiforova-08091983@postgrespro.ru", "phone": "+70749318311"}
0005433923438	F85F29	4613 920015	EKATERINA ILINA	{"email": "ilina-ekaterina-1971@postgrespro.ru", "phone": "+70900691501"}
0005433923439	B1D9B2	4604 857532	ANASTASIYA FOMINA	{"email": "fomina.anastasiya_1967@postgrespro.ru", "phone": "+70206319936"}
0005433923440	552E94	3361 731190	ALEKSANDR ANTONOV	{"email": "a.antonov-1975@postgrespro.ru", "phone": "+70684149038"}
0005433923441	552E94	2763 419069	ALEKSEY STEPANOV	{"email": "a.stepanov_051981@postgrespro.ru", "phone": "+70959399267"}
0005433923442	EF413E	4666 363072	VYACHESLAV SCHERBAKOV	{"phone": "+70029797671"}
0005433923443	02D88E	3380 877584	YURIY NIKITIN	{"phone": "+70230938704"}
0005433923444	02D88E	2453 182417	ANGELINA MIKHAYLOVA	{"email": "mikhaylovaangelina_021963@postgrespro.ru", "phone": "+70086207478"}
0005433923445	45FCBD	0425 263530	TAMARA PETROVA	{"phone": "+70277429461"}
0005433923446	2BE0A2	5282 838510	TATYANA KONOVALOVA	{"email": "konovalova.tatyana-22051968@postgrespro.ru", "phone": "+70362623814"}
0005433923447	76F99E	0222 903519	SERGEY KOROLEV	{"phone": "+70724192020"}
0005433923448	76F99E	9420 979413	TATYANA ILINA	{"phone": "+70666106640"}
0005433923449	ECA9F0	1094 153880	SERGEY FOMIN	{"phone": "+70190210302"}
0005433923450	693D75	6773 390790	VALERIYA ALEKSANDROVA	{"phone": "+70368368543"}
0005433923451	693D75	8877 309477	SERGEY GUSEV	{"phone": "+70364881894"}
0005433923452	7F1128	4914 108224	OLEG MELNIKOV	{"phone": "+70995353912"}
0005433923453	712363	2779 034956	KRISTINA MAKSIMOVA	{"email": "kristina-maksimova_1969@postgrespro.ru", "phone": "+70355108632"}
0005433923454	712363	2018 713649	ILYA MAKAROV	{"phone": "+70240067097"}
0005433923455	5BD7C9	8836 792518	NADEZHDA NAZAROVA	{"phone": "+70288794849"}
0005433923456	8CFCAD	2944 778801	RUSLAN SERGEEV	{"email": "ruslansergeev1967@postgrespro.ru", "phone": "+70394243342"}
0005433923457	F67B07	0515 532241	NIKITA FEDOROV	{"phone": "+70003430875"}
0005433923458	4E3063	6669 019890	TAISIYA ABRAMOVA	{"phone": "+70112643848"}
0005433923459	4E3063	8390 131898	EVGENIY SAVELEV	{"phone": "+70840179652"}
0005433923460	EE0CE5	6774 676204	ALEKSANDRA ABRAMOVA	{"email": "abramova_a_1978@postgrespro.ru", "phone": "+70622673138"}
0005433923461	E14C06	2704 146018	GENNADIY VASILEV	{"email": "vasilev.gennadiy_1974@postgrespro.ru", "phone": "+70344531248"}
0005433923462	641ECA	5177 267132	ANNA SCHERBAKOVA	{"email": "a-scherbakova.011978@postgrespro.ru", "phone": "+70581497539"}
0005433923463	641ECA	7527 240787	SOFYA GERASIMOVA	{"email": "s.gerasimova_031975@postgrespro.ru", "phone": "+70974301602"}
0005433923464	4DCEC5	9270 775175	TATYANA VOLKOVA	{"phone": "+70255389090"}
0005433923465	369C17	7080 783686	EVGENIYA NOVIKOVA	{"email": "novikova-evgeniya_22021975@postgrespro.ru", "phone": "+70663152771"}
0005433923466	4757F3	6229 265106	VALENTINA NIKITINA	{"email": "v-nikitina.04021967@postgrespro.ru", "phone": "+70487290691"}
0005433923467	2A040B	1952 545063	NADEZHDA MARTYNOVA	{"email": "martynova.nadezhda.1972@postgrespro.ru", "phone": "+70798512127"}
0005433923578	E34070	7093 712727	ZINAIDA TIKHONOVA	{"phone": "+70615858162"}
0005433923468	2A040B	4414 682080	VLADIMIR MATVEEV	{"email": "matveev-v081975@postgrespro.ru", "phone": "+70693733087"}
0005433923469	EA5C5D	0081 160075	SERGEY KOROLEV	{"phone": "+70966446641"}
0005433923470	EA5C5D	2573 940577	VLADIMIR SERGEEV	{"email": "sergeev-v_22011985@postgrespro.ru", "phone": "+70978673631"}
0005433923471	4F8F04	7977 837204	ZAKHAR BARANOV	{"email": "z_baranov.15101979@postgrespro.ru", "phone": "+70058755869"}
0005433923472	4F8F04	2078 932752	IRINA ZHUKOVA	{"email": "zhukova-irina_1968@postgrespro.ru", "phone": "+70319040352"}
0005433923473	6453E7	8213 084071	NATALYA IVANOVA	{"email": "ivanova.n.071978@postgrespro.ru", "phone": "+70356067661"}
0005433923474	2FEA41	2142 790011	GALINA MATVEEVA	{"email": "gmatveeva-08091978@postgrespro.ru", "phone": "+70589439738"}
0005433923475	58A1AB	9019 526272	ALEKSEY MAKSIMOV	{"phone": "+70700845767"}
0005433923476	505E27	3987 963064	ALEKSANDR ANDREEV	{"email": "a-andreev_05121977@postgrespro.ru", "phone": "+70641691035"}
0005433923477	505E27	7261 486355	IVAN VOROBEV	{"phone": "+70766697446"}
0005433923478	316A3E	8672 279328	ELENA KUZMINA	{"email": "kuzminaelena-101960@postgrespro.ru", "phone": "+70653868351"}
0005433923479	316A3E	1086 740313	INNA FEDOROVA	{"phone": "+70777025801"}
0005433923480	5030A4	1835 675125	GEORGIY IVANOV	{"email": "g-ivanov_061960@postgrespro.ru", "phone": "+70190960077"}
0005433923481	5030A4	7502 715574	NADEZHDA STEPANOVA	{"email": "n.stepanova121985@postgrespro.ru", "phone": "+70088611289"}
0005433923482	15843A	2324 362711	OLGA SIDOROVA	{"email": "sidorova_olga.17081975@postgrespro.ru", "phone": "+70340543537"}
0005433923483	F22F41	9886 291159	YURIY ZHURAVLEV	{"email": "zhuravlev-y-1962@postgrespro.ru", "phone": "+70545485935"}
0005433923484	89D237	7968 474825	VIKTOR NIKOLAEV	{"phone": "+70248517137"}
0005433923485	9D61F9	9047 407543	YURIY GERASIMOV	{"phone": "+70535704743"}
0005433923486	699BCD	6349 302329	OLGA MIKHAYLOVA	{"email": "olga.mikhaylova_17041962@postgrespro.ru", "phone": "+70989380222"}
0005433923487	699BCD	2742 942250	VLADIMIR EGOROV	{"email": "vegorov_29071968@postgrespro.ru", "phone": "+70737569070"}
0005433923488	699BCD	2548 176775	SERGEY KULIKOV	{"email": "kulikovsergey-1963@postgrespro.ru", "phone": "+70548691690"}
0005433923489	365FD1	2509 050941	STANISLAV SOKOLOV	{"email": "sokolovstanislav_111981@postgrespro.ru", "phone": "+70778327009"}
0005433923490	D397CD	6392 816035	ANASTASIYA ANDREEVA	{"phone": "+70569433126"}
0005433923491	D397CD	1516 714488	ALEKSANDR YAKOVLEV	{"phone": "+70733581312"}
0005433923492	9F6133	4377 680814	ELENA DENISOVA	{"phone": "+70054376214"}
0005433923493	9F6133	5268 970042	MIKHAIL ROMANOV	{"email": "mikhailromanov_1978@postgrespro.ru", "phone": "+70330206587"}
0005433923494	732FAE	3921 843600	SVETLANA PETROVA	{"phone": "+70553352786"}
0005433923495	BEFCAB	0465 348886	OLEG MIKHAYLOV	{"email": "mikhaylov.o021974@postgrespro.ru", "phone": "+70769064018"}
0005433923496	41C5EF	4066 573231	ANTON VASILEV	{"email": "vasilev-anton091969@postgrespro.ru", "phone": "+70230605307"}
0005433923497	5A7605	8501 964025	OLEG SOROKIN	{"phone": "+70723927068"}
0005433923498	5A7605	8977 922806	DARYA GRISHINA	{"phone": "+70372217748"}
0005433923499	40C973	5391 281513	ALENA MOROZOVA	{"phone": "+70894016474"}
0005433923500	93A3CB	7793 641834	OLGA VOROBEVA	{"phone": "+70795611719"}
0005433923501	50515B	8381 753433	DMITRIY FEDOROV	{"email": "fedorov_d1973@postgrespro.ru", "phone": "+70859775784"}
0005433923502	50515B	8780 895823	MARINA ZAKHAROVA	{"email": "marina-zakharova-04081966@postgrespro.ru", "phone": "+70603481761"}
0005433923503	289995	8641 151668	ALEKSANDR PETROV	{"phone": "+70318210443"}
0005433923504	62F7A9	5886 773182	OLGA KALININA	{"phone": "+70726207980"}
0005433923505	3F8586	9619 229444	VERA ISAEVA	{"email": "v-isaeva05041977@postgrespro.ru", "phone": "+70485689695"}
0005433923506	57AA26	8247 931749	IRINA FILIPPOVA	{"email": "filippova-irina18011969@postgrespro.ru", "phone": "+70854116564"}
0005433923507	57AA26	7454 042117	RUSLAN MATVEEV	{"phone": "+70086022436"}
0005433923508	750D7B	6235 078325	DARYA AFANASEVA	{"email": "afanasevad-1973@postgrespro.ru", "phone": "+70790379596"}
0005433923509	750D7B	0773 755704	ILYA GERASIMOV	{"email": "igerasimov_15031968@postgrespro.ru", "phone": "+70950054004"}
0005433923510	750D7B	6507 156583	ELENA ALEKSEEVA	{"phone": "+70536794567"}
0005433923511	87BEB8	8943 087550	IVAN VLASOV	{"phone": "+70567667023"}
0005433923512	3B721B	3660 787917	GALINA NIKOLAEVA	{"email": "nikolaeva.g-1977@postgrespro.ru", "phone": "+70435071366"}
0005433923513	EE8B71	9489 586739	GALINA VOROBEVA	{"email": "vorobeva_galina13041972@postgrespro.ru", "phone": "+70827770172"}
0005433923514	F6E2AC	0036 772479	VALERIY SOKOLOV	{"phone": "+70408084861"}
0005433923515	6E99E3	6448 436082	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov-15071967@postgrespro.ru", "phone": "+70043818304"}
0005433923516	5F4C0A	5689 452637	ELENA MARTYNOVA	{"email": "martynova.e_17021977@postgrespro.ru", "phone": "+70954945182"}
0005433923517	5F4C0A	4557 557507	IRINA KONDRATEVA	{"phone": "+70532984225"}
0005433923518	F69E1A	0728 409448	LYUDMILA EGOROVA	{"phone": "+70329432372"}
0005433923519	F69E1A	2744 910463	OLGA NIKOLAEVA	{"email": "o-nikolaeva.1962@postgrespro.ru", "phone": "+70232098234"}
0005433923520	F69E1A	0545 193891	DMITRIY KUZMIN	{"email": "d.kuzmin-19021972@postgrespro.ru", "phone": "+70883420244"}
0005433923521	93DDA0	1653 446751	MARGARITA SCHERBAKOVA	{"email": "scherbakovamargarita_091975@postgrespro.ru", "phone": "+70263822986"}
0005433923522	31F2A6	6773 644750	TAMARA DAVYDOVA	{"phone": "+70743303738"}
0005433923523	7F3F49	1842 446598	VALERIYA KOLESNIKOVA	{"email": "v.kolesnikova_27111975@postgrespro.ru", "phone": "+70394055495"}
0005433923524	7F3F49	0091 939635	VLADISLAV ANTONOV	{"email": "vladislav-antonov_091968@postgrespro.ru", "phone": "+70537504215"}
0005433923525	379026	8833 167807	VLADIMIR CHERNOV	{"email": "vladimir.chernov-1981@postgrespro.ru", "phone": "+70981374098"}
0005433923526	0B416D	9448 012409	NIKITA SAVELEV	{"phone": "+70007416301"}
0005433923527	0B416D	6432 514670	ALEKSEY POPOV	{"phone": "+70035183760"}
0005433923528	B8FB94	0871 488273	MAKSIM EGOROV	{"phone": "+70276583476"}
0005433923529	CBF6C5	2207 598714	VARVARA RODIONOVA	{"phone": "+70097392870"}
0005433923530	79A502	8251 829719	MIKHAIL KRASNOV	{"email": "mikhailkrasnov1974@postgrespro.ru", "phone": "+70320908347"}
0005433923531	DAA1AF	5205 423763	IDA LEBEDEVA	{"email": "lebedeva.i.1967@postgrespro.ru", "phone": "+70343193512"}
0005433923532	F837E6	0778 525499	GALIYA IVANOVA	{"phone": "+70703620490"}
0005433923533	F837E6	0829 087647	YURIY ALEKSANDROV	{"email": "aleksandrov-y.011967@postgrespro.ru", "phone": "+70877318235"}
0005433923534	700756	1554 895946	ALINA POLYAKOVA	{"email": "apolyakova-12081961@postgrespro.ru", "phone": "+70905215787"}
0005433923535	700756	5996 271625	ALEKSANDRA VASILEVA	{"email": "aleksandra-vasileva.09061964@postgrespro.ru", "phone": "+70181348397"}
0005433923536	5EC9C5	8408 626689	MARIYA GAVRILOVA	{"phone": "+70474876733"}
0005433923537	4B234A	2539 389123	NATALYA PAVLOVA	{"email": "npavlova04011973@postgrespro.ru", "phone": "+70283063134"}
0005433923538	E649AD	7550 327064	VLADIMIR SERGEEV	{"email": "vsergeev-051972@postgrespro.ru", "phone": "+70979664117"}
0005433923539	E649AD	0212 367559	IRINA MAKSIMOVA	{"phone": "+70667983845"}
0005433923540	196A1D	0177 237824	ANATOLIY MOISEEV	{"phone": "+70483709902"}
0005433923541	196A1D	2050 490531	MARIYA KARPOVA	{"phone": "+70920120840"}
0005433923542	BE85FA	1755 412548	ANATOLIY KRASNOV	{"email": "krasnov-a_1980@postgrespro.ru", "phone": "+70119080131"}
0005433923543	F1B035	0562 652139	OLGA KUDRYASHOVA	{"phone": "+70640832627"}
0005433923544	620DC0	5620 119624	NINA MEDVEDEVA	{"phone": "+70360497126"}
0005433923545	7023D5	1144 475395	VENERA SERGEEVA	{"phone": "+70166119979"}
0005433923546	8F7B8A	9587 382238	GALINA VASILEVA	{"email": "gvasileva-011976@postgrespro.ru", "phone": "+70322805018"}
0005433923547	F3E824	1204 905443	ELENA EFIMOVA	{"phone": "+70252224144"}
0005433923548	2704C6	2564 761912	PAVEL FEDOROV	{"email": "fedorovpavel.1981@postgrespro.ru", "phone": "+70884759806"}
0005433923549	2704C6	7002 409848	EKATERINA MIRONOVA	{"email": "mironova_e-1975@postgrespro.ru", "phone": "+70399409414"}
0005433923550	3A1213	3919 462427	VYACHESLAV POPOV	{"email": "popov.vyacheslav081956@postgrespro.ru", "phone": "+70201849980"}
0005433923551	3A1213	2768 598970	ALEKSANDR SOROKIN	{"phone": "+70937519793"}
0005433923552	4751C3	9650 707007	NATALYA ANDREEVA	{"email": "andreeva-natalya_1965@postgrespro.ru", "phone": "+70527224854"}
0005433923553	A11B3F	0034 612556	VLADISLAV GERASIMOV	{"email": "gerasimov.v_15041965@postgrespro.ru", "phone": "+70081712510"}
0005433923554	FC3B62	4834 039087	OLGA ANDREEVA	{"phone": "+70073950499"}
0005433923555	FC3B62	7892 034217	ALEKSANDR PETROV	{"phone": "+70075926245"}
0005433923556	33D701	7424 427674	PAVEL YAKOVLEV	{"email": "yakovlev-pavel_21071980@postgrespro.ru", "phone": "+70552332110"}
0005433923557	88DF9E	3447 999183	VALENTINA CHERNOVA	{"email": "valentina-chernova111974@postgrespro.ru", "phone": "+70007924360"}
0005433923558	867AA2	2210 002769	MAKSIM EGOROV	{"email": "maksim_egorov_011971@postgrespro.ru", "phone": "+70001014039"}
0005433923559	C1E73D	3154 114683	OLESYA GAVRILOVA	{"email": "gavrilova_o-1979@postgrespro.ru", "phone": "+70194571129"}
0005433923560	7AD46E	5955 073815	MARGARITA SOROKINA	{"email": "msorokina061970@postgrespro.ru", "phone": "+70153302804"}
0005433923561	7AD46E	7394 885928	ANASTASIYA MEDVEDEVA	{"phone": "+70575993202"}
0005433923562	F2333B	5913 228408	LYUDMILA EFREMOVA	{"email": "lefremova-041965@postgrespro.ru", "phone": "+70178759626"}
0005433923563	DA8661	4233 940039	DARYA KONDRATEVA	{"email": "darya.kondrateva_1972@postgrespro.ru", "phone": "+70655026235"}
0005433923564	E862A3	9397 001570	MARIYA SMIRNOVA	{"email": "msmirnova_051975@postgrespro.ru", "phone": "+70615835805"}
0005433923565	1D4CBF	6607 589266	GALINA KUZMINA	{"email": "g_kuzmina.28041967@postgrespro.ru", "phone": "+70510679995"}
0005433923566	1D4CBF	4068 565341	IVAN ZAKHAROV	{"phone": "+70620483279"}
0005433923567	553AA2	9228 288286	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr-1965@postgrespro.ru", "phone": "+70275152294"}
0005433923568	D08D70	3718 517494	KONSTANTIN SHEVCHENKO	{"phone": "+70641881197"}
0005433923569	761C43	9931 227049	DMITRIY MOROZOV	{"email": "dmorozov-1974@postgrespro.ru", "phone": "+70719078439"}
0005433923570	761C43	3681 930243	ALEKSEY VOLKOV	{"email": "a.volkov031963@postgrespro.ru", "phone": "+70980239355"}
0005433923571	F7336E	5917 939982	GALINA NIKITINA	{"email": "g_nikitina1981@postgrespro.ru", "phone": "+70943620963"}
0005433923572	5FD80C	9185 080557	YURIY PETROV	{"email": "yuriy-petrov.12061970@postgrespro.ru", "phone": "+70714638205"}
0005433923573	33DFEF	4301 840044	VYACHESLAV KARPOV	{"phone": "+70242523879"}
0005433923574	0971A7	9480 336134	YURIY TIMOFEEV	{"email": "timofeev-yuriy-1971@postgrespro.ru", "phone": "+70259306826"}
0005433923575	0971A7	4040 067112	NIKOLAY IVANOV	{"phone": "+70229218371"}
0005433923576	0971A7	3820 197453	ANNA RODIONOVA	{"email": "annarodionova.11031972@postgrespro.ru", "phone": "+70655247686"}
0005433923577	F6B04B	7845 113947	EVGENIY PETROV	{"phone": "+70139075482"}
0005433923579	E34070	1097 806640	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev-021981@postgrespro.ru", "phone": "+70015580275"}
0005433923580	2FE308	0900 525875	SERGEY KUZNECOV	{"phone": "+70113321651"}
0005433923581	2FE308	5301 589366	VLADIMIR SAVELEV	{"email": "savelev-vladimir-041969@postgrespro.ru", "phone": "+70024392220"}
0005433923582	7E4811	4492 380568	VLADIMIR GUSEV	{"email": "vladimir.gusev.1977@postgrespro.ru", "phone": "+70600431686"}
0005433923583	8272B2	3769 981273	NATALYA KUZNECOVA	{"phone": "+70458367300"}
0005433923584	247D13	5474 387472	INNA SERGEEVA	{"email": "sergeeva-inna.041968@postgrespro.ru", "phone": "+70445229000"}
0005433923585	247D13	2630 153824	MIKHAIL BONDARENKO	{"email": "m_bondarenko_1969@postgrespro.ru", "phone": "+70895919392"}
0005433923586	F28031	6373 046703	ALEKSEY BONDARENKO	{"email": "bondarenko.aleksey021972@postgrespro.ru", "phone": "+70491459287"}
0005433923587	214076	5594 188620	VLADIMIR IVANOV	{"phone": "+70926611734"}
0005433923588	214076	5697 111278	MURAT MAKAROV	{"email": "makarov_murat-091965@postgrespro.ru", "phone": "+70998538950"}
0005433923589	62CDE6	4371 492716	IVAN SMIRNOV	{"email": "smirnov-i.1968@postgrespro.ru", "phone": "+70522307057"}
0005433923590	295CF6	8095 546510	SOFYA BORISOVA	{"email": "sofya.borisova-011958@postgrespro.ru", "phone": "+70196589407"}
0005433923591	C1EC31	2677 033296	YAROSLAV KOZLOV	{"phone": "+70875049758"}
0005433923592	C951C9	8139 189320	OLEG ZHUKOV	{"email": "zhukovoleg_1986@postgrespro.ru", "phone": "+70845541633"}
0005433923593	94E142	3836 742586	VYACHESLAV VLASOV	{"email": "vlasov_vyacheslav1974@postgrespro.ru", "phone": "+70096980341"}
0005433923594	FE106D	6355 957485	YULIYA EFIMOVA	{"phone": "+70142406719"}
0005433923595	FE106D	6712 617326	ANDREY EGOROV	{"email": "andrey-egorov.1973@postgrespro.ru", "phone": "+70742581418"}
0005433923596	252832	5199 759808	VERA VOLKOVA	{"email": "volkovavera.17101979@postgrespro.ru", "phone": "+70721675787"}
0005433923597	8114CD	3552 793185	GULNARA AKIMOVA	{"email": "gulnaraakimova_1970@postgrespro.ru", "phone": "+70127834130"}
0005433923598	80C80C	6543 428388	IRINA MIRONOVA	{"phone": "+70903749824"}
0005433923599	593630	7825 229534	GULNAZ ZHUKOVA	{"phone": "+70892407249"}
0005433923600	7080C1	7429 580834	OKSANA NAUMOVA	{"phone": "+70461487806"}
0005433923601	36F9F7	1725 653909	NIKOLAY EGOROV	{"phone": "+70995731251"}
0005433923602	36F9F7	9601 825499	VALERIYA EFIMOVA	{"email": "efimova_valeriya_14101970@postgrespro.ru", "phone": "+70474014018"}
0005433923603	F5EFCD	1756 481069	IRINA NESTEROVA	{"email": "nesterova_i-27091974@postgrespro.ru", "phone": "+70904634314"}
0005433923604	A4DDD5	0948 852520	EVGENIY KUZMIN	{"phone": "+70890074661"}
0005433923605	A4DDD5	0545 759386	VIKTOR DMITRIEV	{"email": "viktor.dmitriev1976@postgrespro.ru", "phone": "+70510102932"}
0005433923606	A98395	5063 956698	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey-011973@postgrespro.ru", "phone": "+70140077948"}
0005433923607	4BDC5E	3627 194881	ROMAN KAZAKOV	{"phone": "+70147008847"}
0005433923608	4BDC5E	0673 906988	KSENIYA EGOROVA	{"email": "egorova_kseniya1969@postgrespro.ru", "phone": "+70279540559"}
0005433923609	0E57DC	3369 209169	ANDREY MEDVEDEV	{"email": "medvedev_andrey.051971@postgrespro.ru", "phone": "+70853082985"}
0005433923610	8AE1A2	8087 416377	ALEKSANDR POPOV	{"email": "aleksandr_popov.1965@postgrespro.ru", "phone": "+70749680234"}
0005433923611	8AE1A2	2439 042875	OKSANA KALININA	{"email": "oksanakalinina_1974@postgrespro.ru", "phone": "+70595789902"}
0005433923612	8AE1A2	3758 591347	NIKOLAY IVANOV	{"phone": "+70624511699"}
0005433923613	24683B	4203 193460	NATALYA SOLOVEVA	{"email": "solovevan-23101964@postgrespro.ru", "phone": "+70908818827"}
0005433923614	9C1D06	1576 928454	MIKHAIL KUZNECOV	{"email": "kuznecovm-1972@postgrespro.ru", "phone": "+70271754245"}
0005433923615	9C1D06	6502 466808	SERGEY MAKAROV	{"email": "makarov.s.101968@postgrespro.ru", "phone": "+70763256571"}
0005433923616	A85698	2150 103119	YURIY GAVRILOV	{"email": "yuriy-gavrilov_081991@postgrespro.ru", "phone": "+70890643695"}
0005433923617	A85698	4866 851712	VLADIMIR SOKOLOV	{"phone": "+70633138421"}
0005433923618	F47CF3	9465 438885	TATYANA DMITRIEVA	{"email": "t_dmitrieva-11111971@postgrespro.ru", "phone": "+70187067331"}
0005433923619	F47CF3	6978 461252	IRINA ROMANOVA	{"phone": "+70614319284"}
0005433923620	E84BC6	1918 748927	NIKOLAY KUZNECOV	{"email": "kuznecov-n_1964@postgrespro.ru", "phone": "+70314302884"}
0005433923621	F6AD2A	7811 898917	ANASTASIYA ILINA	{"phone": "+70656576521"}
0005433923622	F6AD2A	0692 498166	VLADISLAV IVANOV	{"phone": "+70973555061"}
0005433923623	DBBBD9	4605 878639	SERGEY MAKAROV	{"email": "s_makarov_1973@postgrespro.ru", "phone": "+70509375808"}
0005433923624	DBBBD9	9428 961598	KIRA VOLKOVA	{"phone": "+70988007701"}
0005433923625	32604D	2479 652440	MARINA LOGINOVA	{"phone": "+70097864814"}
0005433923626	8B93D1	9422 232329	ANDREY TIMOFEEV	{"email": "timofeeva.061963@postgrespro.ru", "phone": "+70206404740"}
0005433923627	8B93D1	9554 806837	ROMAN KUZNECOV	{"phone": "+70524808414"}
0005433923628	8B93D1	9216 734992	VITALIY KAZAKOV	{"email": "vitaliy.kazakov.1976@postgrespro.ru", "phone": "+70707951957"}
0005433923629	E32B78	3807 092973	KLAVDIYA PAVLOVA	{"phone": "+70610551443"}
0005433923630	1A6BF8	5320 072166	ALEKSEY NIKITIN	{"email": "anikitin25121971@postgrespro.ru", "phone": "+70335170135"}
0005433923631	17D17F	0506 290906	TATYANA MAKSIMOVA	{"phone": "+70238425746"}
0005433923632	C4A76A	5675 129729	NAILYA MATVEEVA	{"phone": "+70495404192"}
0005433923633	6239B9	2885 034333	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey.091975@postgrespro.ru", "phone": "+70298042135"}
0005433923634	A6AA3C	1598 394362	EGOR MAKAROV	{"email": "egor.makarov.05121958@postgrespro.ru", "phone": "+70982645881"}
0005433923635	A6AA3C	7305 314074	ELENA POPOVA	{"email": "epopova.1963@postgrespro.ru", "phone": "+70021837137"}
0005433923636	B6FEBD	4412 457644	OLGA NESTEROVA	{"email": "nesterovao.1966@postgrespro.ru", "phone": "+70298054522"}
0005433923637	B6FEBD	7871 840396	MARIYA SOKOLOVA	{"phone": "+70106213663"}
0005433923638	036F49	0329 411815	LYUBOV LEBEDEVA	{"phone": "+70237874475"}
0005433923639	29467E	2371 916305	YURIY ZHURAVLEV	{"email": "yuriy-zhuravlev_20061974@postgrespro.ru", "phone": "+70204385279"}
0005433923640	090C2E	2136 672512	VALENTINA VASILEVA	{"phone": "+70469455022"}
0005433923641	35C9A5	1006 709877	MIKHAIL FROLOV	{"email": "frolovmikhail_1960@postgrespro.ru", "phone": "+70580492470"}
0005433923642	C1E85D	2312 489723	TATYANA DMITRIEVA	{"email": "dmitrieva_tatyana.041975@postgrespro.ru", "phone": "+70623085904"}
0005433923643	C11FE3	4445 520526	ALEKSEY DMITRIEV	{"email": "dmitrievaleksey_101974@postgrespro.ru", "phone": "+70412738716"}
0005433923644	C11FE3	9867 762238	SERGEY PAVLOV	{"phone": "+70056318196"}
0005433923645	C11FE3	6771 188244	VERA ALEKSANDROVA	{"phone": "+70916891326"}
0005433923646	E9806D	8135 255604	DENIS RODIONOV	{"email": "denis_rodionov1975@postgrespro.ru", "phone": "+70694782667"}
0005433923647	B97844	6156 599196	TATYANA NAUMOVA	{"email": "naumova_t-1973@postgrespro.ru", "phone": "+70373119064"}
0005433923648	B97844	4834 790167	DENIS KUDRYASHOV	{"phone": "+70979588583"}
0005433923649	AE8342	1951 412518	ALEKSEY GRIGOREV	{"phone": "+70269958655"}
0005433923650	AE8342	4511 187138	RUSLAN POPOV	{"phone": "+70484077471"}
0005433923651	A6A308	8277 269631	VIKTORIYA NIKIFOROVA	{"phone": "+70056874393"}
0005433923652	A6A308	9822 431867	DARYA IVANOVA	{"email": "ivanova.darya28091975@postgrespro.ru", "phone": "+70235167699"}
0005433923653	7D2492	0600 392171	LIDIYA IVANOVA	{"email": "l_ivanova.091973@postgrespro.ru", "phone": "+70295085633"}
0005433923654	7D2492	0718 978519	ELIZAVETA SIDOROVA	{"email": "esidorova-041967@postgrespro.ru", "phone": "+70994089091"}
0005433923712	30EEEE	4010 818945	NIKOLAY KOZLOV	{"phone": "+70289624573"}
0005433923655	E0D8C2	9791 347951	NINA SOROKINA	{"email": "ninasorokina071984@postgrespro.ru", "phone": "+70635310268"}
0005433923656	7DC674	1279 332840	ANASTASIYA NAUMOVA	{"phone": "+70494826635"}
0005433923657	8FEC3B	2352 386338	LILIYA KUZNECOVA	{"email": "kuznecova.liliya.091969@postgrespro.ru", "phone": "+70255932816"}
0005433923658	882A36	0442 674018	ELINA FEDOROVA	{"email": "elina-fedorova.15101987@postgrespro.ru", "phone": "+70521117145"}
0005433923659	A83BA1	0990 042291	TATYANA KUZMINA	{"email": "tatyana_kuzmina_07051974@postgrespro.ru", "phone": "+70972285682"}
0005433923660	4BD2F6	6498 352077	VASILIY IVANOV	{"phone": "+70743169902"}
0005433923661	73C9C8	3312 020525	ALEKSEY FILIPPOV	{"phone": "+70300999683"}
0005433923662	73C9C8	7307 619377	GALINA SOLOVEVA	{"phone": "+70754627170"}
0005433923663	EFF57A	8483 619725	ALEKSANDR ZAYCEV	{"phone": "+70967236228"}
0005433923664	EFF57A	8868 033503	LYUDMILA KOZLOVA	{"email": "kozlova.lyudmila-12091968@postgrespro.ru", "phone": "+70708547483"}
0005433923665	EFF57A	1007 792879	TAMARA SCHERBAKOVA	{"phone": "+70170035633"}
0005433923666	8CB667	0699 502910	KONSTANTIN SAVELEV	{"phone": "+70531794519"}
0005433923667	5B55E3	5704 614134	GALINA ZHUKOVA	{"email": "zhukovagalina15011975@postgrespro.ru", "phone": "+70898524583"}
0005433923668	5B55E3	0757 702308	YANA BELOVA	{"phone": "+70522948261"}
0005433923669	041521	0948 995439	ZINAIDA ILINA	{"email": "zinaida-ilina1971@postgrespro.ru", "phone": "+70725974625"}
0005433923670	A988AD	1399 580477	TATYANA SCHERBAKOVA	{"phone": "+70206986437"}
0005433923671	298A8A	2806 887993	VALENTINA SEMENOVA	{"email": "semenova_v_1971@postgrespro.ru", "phone": "+70453319003"}
0005433923672	343F7E	0093 865592	SVETLANA VOLKOVA	{"phone": "+70596626201"}
0005433923673	343F7E	7529 192099	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova_a_1979@postgrespro.ru", "phone": "+70090806929"}
0005433923674	CD1EFF	1732 948005	VALENTINA KULIKOVA	{"email": "kulikova.valentina-061974@postgrespro.ru", "phone": "+70763468848"}
0005433923675	CD1EFF	8922 540995	VADIM MOROZOV	{"email": "vadim-morozov1956@postgrespro.ru", "phone": "+70708806443"}
0005433923676	0CEC0C	9543 516659	DARYA EFREMOVA	{"phone": "+70474222198"}
0005433923677	ED3C2D	1211 182519	ELENA YAKOVLEVA	{"email": "e-yakovleva021972@postgrespro.ru", "phone": "+70553845391"}
0005433923678	E1F7FA	5747 640155	OLESYA FOMINA	{"phone": "+70509608818"}
0005433923679	E1F7FA	8527 337985	EVGENIY FROLOV	{"email": "evgeniy.frolov1975@postgrespro.ru", "phone": "+70000330895"}
0005433923680	281E38	2843 534179	VITALIY FEDOTOV	{"phone": "+70390613152"}
0005433923681	4A4C5A	8015 974852	RAISA NIKITINA	{"email": "nikitina-raisa-081959@postgrespro.ru", "phone": "+70347775966"}
0005433923682	4A4C5A	4696 254954	GALINA TIMOFEEVA	{"email": "g.timofeeva01061985@postgrespro.ru", "phone": "+70284462173"}
0005433923683	2692C2	3779 713215	GULNARA SOKOLOVA	{"phone": "+70913843557"}
0005433923684	0B5221	1012 868919	ALSU MAKSIMOVA	{"phone": "+70653228959"}
0005433923685	0B5221	0643 791136	VALENTINA KAZAKOVA	{"email": "valentina-kazakova.21101982@postgrespro.ru", "phone": "+70052237434"}
0005433923686	D7E9D1	1162 693292	EKATERINA EFIMOVA	{"email": "efimova.ekaterina_011966@postgrespro.ru", "phone": "+70258240916"}
0005433923687	D7E9D1	5964 006353	ALEKSANDR PAVLOV	{"phone": "+70009844538"}
0005433923688	E41374	8142 208088	NAIL YAKOVLEV	{"email": "nail.yakovlev091973@postgrespro.ru", "phone": "+70101635906"}
0005433923744	81C535	3973 330903	ALEKSEY GORBUNOV	{"phone": "+70549000689"}
0005433923689	969FB9	5715 777267	VYACHESLAV ZAKHAROV	{"email": "vzakharov27031981@postgrespro.ru", "phone": "+70008111655"}
0005433923746	643B41	5791 727740	ALEKSANDR MAKAROV	{"phone": "+70435623251"}
0005433923690	C90635	4709 440593	IRINA MATVEEVA	{"email": "matveeva_i011959@postgrespro.ru", "phone": "+70627682995"}
0005433923691	08D550	3209 392084	DMITRIY ALEKSEEV	{"phone": "+70661844303"}
0005433923692	E67481	7223 111557	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey-1984@postgrespro.ru", "phone": "+70800830656"}
0005433923693	E67481	0419 690011	OLGA ANTONOVA	{"phone": "+70846196662"}
0005433923694	860278	8507 512845	ELENA MOROZOVA	{"email": "morozovaelena_1984@postgrespro.ru", "phone": "+70970053281"}
0005433923695	860278	8480 761750	EKATERINA EFREMOVA	{"email": "efremova-e_041968@postgrespro.ru", "phone": "+70149930630"}
0005433923696	8F0831	3914 219409	ANNA DAVYDOVA	{"email": "davydova_anna1971@postgrespro.ru", "phone": "+70904208017"}
0005433923697	D58E7A	2209 227929	ANTONINA KARPOVA	{"email": "a_karpova_1968@postgrespro.ru", "phone": "+70373601828"}
0005433923698	63E7D0	3573 160251	ELENA KUZNECOVA	{"email": "kuznecova_elena.1965@postgrespro.ru", "phone": "+70768194075"}
0005433923699	74DB42	3261 425869	PAVEL ORLOV	{"email": "p.orlov.121972@postgrespro.ru", "phone": "+70305102283"}
0005433923700	74DB42	9623 844849	ALEKSANDR EGOROV	{"email": "egorov_a_23031972@postgrespro.ru", "phone": "+70803409372"}
0005433923701	49906C	3118 100006	ALEKSEY PETROV	{"email": "petrova09081974@postgrespro.ru", "phone": "+70330201118"}
0005433923702	49906C	8019 092678	RUSLAN BORISOV	{"email": "borisov_r-28101967@postgrespro.ru", "phone": "+70562047750"}
0005433923703	7B2161	0664 392386	ANTONINA IVANOVA	{"phone": "+70285353838"}
0005433923704	357FCC	8378 939088	MARIYA LUKYANOVA	{"phone": "+70223727966"}
0005433923705	357FCC	5630 564948	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov.vyacheslav1969@postgrespro.ru", "phone": "+70805712677"}
0005433923706	357FCC	3132 363624	TIMOFEY SCHERBAKOV	{"phone": "+70058556044"}
0005433923707	31A581	0257 006883	VYACHESLAV ZAYCEV	{"email": "vyacheslav-zaycev.111966@postgrespro.ru", "phone": "+70317890143"}
0005433923708	12CAC1	3694 071418	ALISA BORISOVA	{"phone": "+70400299631"}
0005433923709	E5816C	0724 214435	VLADIMIR CHERNOV	{"email": "v_chernov-1971@postgrespro.ru", "phone": "+70382013886"}
0005433923710	84CFA8	7346 017350	DINARA GORBUNOVA	{"phone": "+70730641117"}
0005433923711	DE4603	6209 152211	NATALYA ANTONOVA	{"phone": "+70222354888"}
0005433923713	CD11FD	9223 538342	ALEVTINA PETROVA	{"email": "apetrova-1963@postgrespro.ru", "phone": "+70428018618"}
0005433923714	588950	7551 347631	DARYA CHERNOVA	{"email": "chernova-d-1965@postgrespro.ru", "phone": "+70594376605"}
0005433923715	7047B4	4459 448068	VLADIMIR STEPANOV	{"email": "stepanov_v-051979@postgrespro.ru", "phone": "+70521941684"}
0005433923716	00B70C	6928 446144	YULIYA SCHERBAKOVA	{"email": "yscherbakova-04111967@postgrespro.ru", "phone": "+70699681407"}
0005433923717	EE42F5	2603 578716	FARIDA MALYSHEVA	{"phone": "+70135417475"}
0005433923718	74B744	1003 238207	MIKHAIL ANDREEV	{"phone": "+70985485137"}
0005433923719	EABD03	7257 920481	NIKOLAY ILIN	{"email": "nikolay.ilin1971@postgrespro.ru", "phone": "+70625761469"}
0005433923720	A07CFC	4942 374475	ANZHELA ARKHIPOVA	{"phone": "+70640215515"}
0005433923721	D4F500	6321 257931	VLADISLAV IVANOV	{"email": "vladislav_ivanov-011973@postgrespro.ru", "phone": "+70929128226"}
0005433923722	16A5EA	2848 343157	SVETLANA RODIONOVA	{"email": "rodionovasvetlana-01071976@postgrespro.ru", "phone": "+70289313917"}
0005433923723	806F9F	6404 762661	TATYANA FROLOVA	{"email": "t.frolova1969@postgrespro.ru", "phone": "+70138995355"}
0005433923724	806F9F	7030 247311	SERGEY SEMENOV	{"email": "semenovsergey.111971@postgrespro.ru", "phone": "+70961578786"}
0005433923725	5CDB8E	5363 786551	YULIYA FEDOROVA	{"email": "fedorova_y-1964@postgrespro.ru", "phone": "+70145115997"}
0005433923726	F55541	7349 154806	NIKITA ROMANOV	{"phone": "+70451670913"}
0005433923727	F55541	3383 251273	ANDREY SMIRNOV	{"phone": "+70837931114"}
0005433923728	3D66A8	0403 748269	TATYANA MOISEEVA	{"email": "tatyanamoiseeva.19071977@postgrespro.ru", "phone": "+70142053530"}
0005433923729	611CF7	8645 145594	EKATERINA VLASOVA	{"phone": "+70474490495"}
0005433923730	BF136D	9705 114424	SERGEY BELOV	{"phone": "+70935177060"}
0005433923731	4501E1	4393 277435	GENNADIY NAUMOV	{"phone": "+70379582377"}
0005433923732	4C46B3	2739 485856	LYUBOV EGOROVA	{"phone": "+70628266590"}
0005433923733	295BEB	4930 885797	SOFYA IVANOVA	{"email": "ivanova.sofya.1967@postgrespro.ru", "phone": "+70910194270"}
0005433923734	7EA29B	5209 478346	ANNA KOLESNIKOVA	{"email": "kolesnikova-anna.02091968@postgrespro.ru", "phone": "+70658448740"}
0005433923735	7EA29B	5769 550340	ALBINA ROMANOVA	{"email": "a-romanova.1975@postgrespro.ru", "phone": "+70415639876"}
0005433923736	3E71BE	5116 888682	ANNA STEPANOVA	{"email": "a.stepanova-011962@postgrespro.ru", "phone": "+70361837775"}
0005433923737	AA0D79	0864 195223	INESSA BELOVA	{"phone": "+70666002837"}
0005433923738	1431E3	9568 319142	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov-vyacheslav-061971@postgrespro.ru", "phone": "+70139758283"}
0005433923739	0AAEAD	9932 774027	ANASTASIYA IVANOVA	{"email": "ivanovaa091963@postgrespro.ru", "phone": "+70235170430"}
0005433923740	0AAEAD	2734 827660	LYUBOV ORLOVA	{"email": "orlovalyubov.12051976@postgrespro.ru", "phone": "+70874971188"}
0005433923741	5710BB	5591 356314	LIDIYA LOGINOVA	{"email": "loginovalidiya.1965@postgrespro.ru", "phone": "+70365494137"}
0005433923742	C95154	7247 342057	MAKSIM GRIGOREV	{"phone": "+70062301864"}
0005433923743	2EF253	9505 879151	OLEG ILIN	{"phone": "+70485317783"}
0005433923745	FC7CD3	7566 615590	LYUDMILA LEBEDEVA	{"email": "llebedeva_17011970@postgrespro.ru", "phone": "+70516252963"}
0005433923747	643B41	8792 714152	NINA VOROBEVA	{"phone": "+70547942866"}
0005433923748	643B41	7871 185937	SERGEY VASILEV	{"email": "vasilev_sergey_081976@postgrespro.ru", "phone": "+70349467213"}
0005433923749	0844B7	2165 130105	ALEKSANDR YAKOVLEV	{"phone": "+70255296562"}
0005433923750	F6DCB6	0231 100116	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova-l1966@postgrespro.ru", "phone": "+70319087194"}
0005433923751	5A9D51	9991 962383	LIDIYA KALININA	{"phone": "+70098520131"}
0005433923752	5A9D51	5683 082186	GALINA SAVELEVA	{"email": "g-saveleva17101979@postgrespro.ru", "phone": "+70612161766"}
0005433923753	048241	4536 992809	NATALYA PETROVA	{"phone": "+70636608733"}
0005433923754	048241	2682 026285	YURIY SCHERBAKOV	{"email": "scherbakov_yuriy_25101977@postgrespro.ru", "phone": "+70659079609"}
0005433923755	6CE5D7	7577 888322	LARISA MIRONOVA	{"email": "mironova_larisa-111978@postgrespro.ru", "phone": "+70610185920"}
0005433923756	CB1E50	9992 927525	DENIS ORLOV	{"email": "orlov_denis-051976@postgrespro.ru", "phone": "+70659139284"}
0005433923757	AE5710	1029 794629	IVAN BARANOV	{"phone": "+70030239022"}
0005433923758	AE5710	0657 271301	ALEKSANDR PAVLOV	{"email": "a-pavlov.01021969@postgrespro.ru", "phone": "+70185467573"}
0005433923759	A95BFA	9728 233310	ALEKSANDR KUZNECOV	{"phone": "+70200577970"}
0005433923760	A95BFA	5190 255092	LARISA CHERNOVA	{"phone": "+70448009952"}
0005433923761	A95BFA	0780 718241	ANNA TIKHONOVA	{"phone": "+70223384874"}
0005433923762	049A16	9570 653229	ANASTASIYA FROLOVA	{"email": "anastasiya.frolova-1981@postgrespro.ru", "phone": "+70493787314"}
0005433923763	80E4A8	9290 941101	VALENTINA TIKHONOVA	{"phone": "+70530438465"}
0005433923764	80E4A8	8950 220392	ALEKSEY SOKOLOV	{"phone": "+70491634186"}
0005433923765	7777DD	9590 199304	ANASTASIYA MEDVEDEVA	{"phone": "+70037917420"}
0005433923766	7777DD	8979 673287	ANNA KUZNECOVA	{"email": "anna.kuznecova_041973@postgrespro.ru", "phone": "+70404535890"}
0005433923767	930F60	9948 830128	ALEKSANDRA CHERNOVA	{"email": "chernovaa-12021975@postgrespro.ru", "phone": "+70555782596"}
0005433923768	2A192C	8477 222285	NATALYA GUSEVA	{"phone": "+70322056813"}
0005433923769	2A192C	8468 059805	RASHIT ALEKSEEV	{"email": "rashit-alekseev.081977@postgrespro.ru", "phone": "+70686319878"}
0005433923770	2A192C	8241 542967	ELENA KUZNECOVA	{"email": "kuznecova.elena.1969@postgrespro.ru", "phone": "+70173301168"}
0005433923771	B38A4A	2856 621484	VALENTINA SERGEEVA	{"phone": "+70774330078"}
0005433923772	BD74A7	6634 772162	IRINA FILIPPOVA	{"email": "filippova-irina.27011982@postgrespro.ru", "phone": "+70547556231"}
0005433923773	EC71CF	3614 676467	NADEZHDA FROLOVA	{"phone": "+70446549244"}
0005433923774	D0BE3C	1158 429514	VYACHESLAV KARPOV	{"email": "karpov_vyacheslav_26021964@postgrespro.ru", "phone": "+70324874420"}
0005433923775	F5E148	9601 540939	EVGENIY MAKSIMOV	{"email": "evgeniy_maksimov.02061967@postgrespro.ru", "phone": "+70186595357"}
0005433923776	F5E148	8514 304435	TATYANA KOROLEVA	{"email": "tatyana-koroleva1975@postgrespro.ru", "phone": "+70183195903"}
0005433923777	CA88D9	8823 788875	TAMARA FOMINA	{"email": "tamara_fomina_01021972@postgrespro.ru", "phone": "+70682370579"}
0005433923778	CA88D9	2556 025055	RODION GAVRILOV	{"phone": "+70147674741"}
0005433923779	4DACD1	3990 454922	NIKOLAY BONDARENKO	{"phone": "+70116740400"}
0005433923780	4DACD1	7437 401499	LYUDMILA MOISEEVA	{"phone": "+70695318675"}
0005433923781	5C988F	8861 472737	ARTEM BONDARENKO	{"email": "artem-bondarenko_021963@postgrespro.ru", "phone": "+70213802798"}
0005433923782	30B02A	2359 472965	EDUARD POPOV	{"phone": "+70327075488"}
0005433923783	30B02A	6703 332814	ROMAN SERGEEV	{"email": "r.sergeev_1975@postgrespro.ru", "phone": "+70365831272"}
0005433923784	689857	8242 920302	PETR TARASOV	{"phone": "+70958269519"}
0005433923785	689857	8861 672686	ALEKSANDR VOLKOV	{"phone": "+70874028099"}
0005433923786	03E7D4	9218 191443	KLAVDIYA KISELEVA	{"email": "kiselevak.081972@postgrespro.ru", "phone": "+70999155160"}
0005433923787	1A371B	7303 281659	SERGEY CHERNOV	{"phone": "+70675683959"}
0005433923788	5CF4ED	8668 694215	OLEG ZAKHAROV	{"email": "olegzakharov-24031973@postgrespro.ru", "phone": "+70527902657"}
0005433923789	F94575	2800 401628	MATVEY VOLKOV	{"phone": "+70620850791"}
0005433923790	046866	2781 341773	SNEZHANA KUZNECOVA	{"phone": "+70519562385"}
0005433923791	808CCB	6080 735708	TATYANA ILINA	{"phone": "+70858175109"}
0005433923792	690062	4354 319893	NADEZHDA KALININA	{"email": "nkalinina11081951@postgrespro.ru", "phone": "+70387077206"}
0005433923793	A61474	9363 449136	ILYA ANDREEV	{"phone": "+70272602410"}
0005433923794	E12CD6	4520 607618	TATYANA LOGINOVA	{"email": "t-loginova-28051964@postgrespro.ru", "phone": "+70307047288"}
0005433923795	DE1D97	6920 782101	TAMARA MATVEEVA	{"phone": "+70981969820"}
0005433923796	A65F9E	8161 957451	MAKSIM SOROKIN	{"phone": "+70897398439"}
0005433923797	8386CE	8653 408780	LIDIYA VASILEVA	{"email": "lidiya.vasileva-1975@postgrespro.ru", "phone": "+70567966397"}
0005433923798	8386CE	1409 240538	ALENA EFIMOVA	{"phone": "+70595704244"}
0005433923799	EDB43D	3533 834264	YURIY ORLOV	{"phone": "+70393251195"}
0005433923800	EDB43D	5341 302907	TAISIYA NIKOLAEVA	{"email": "tnikolaeva12051987@postgrespro.ru", "phone": "+70152693901"}
0005433923801	75E475	7094 075421	MARGARITA CHERNOVA	{"phone": "+70407580915"}
0005433923802	75E475	7105 617981	PETR KRASNOV	{"email": "krasnov.petr-04011954@postgrespro.ru", "phone": "+70183771174"}
0005433923859	D14021	4816 308780	VERA SCHERBAKOVA	{"phone": "+70562356843"}
0005433923803	CB9D64	6725 227451	NIKITA FILIPPOV	{"email": "filippov_n-1966@postgrespro.ru", "phone": "+70741736724"}
0005433923804	CB9D64	2908 203531	NATALYA POPOVA	{"email": "popovanatalya-011976@postgrespro.ru", "phone": "+70499993177"}
0005433923805	B4E807	1904 389727	VERA TITOVA	{"email": "titova_v_02061960@postgrespro.ru", "phone": "+70710350574"}
0005433923806	DFBE4F	5885 556234	NATALYA SOROKINA	{"phone": "+70262891487"}
0005433923807	65B583	6101 379354	MARIYA SEMENOVA	{"phone": "+70000489138"}
0005433923808	65B583	1229 535590	NATALYA DAVYDOVA	{"phone": "+70632892654"}
0005433923809	81DDBC	2318 753886	YAROSLAV KUZNECOV	{"email": "y-kuznecov071975@postgrespro.ru", "phone": "+70163331287"}
0005433923810	2AED21	3447 029026	LIDIYA MASLOVA	{"email": "masloval_061971@postgrespro.ru", "phone": "+70909500274"}
0005433923811	A75E9A	6004 236204	NATALYA MIKHAYLOVA	{"phone": "+70035312506"}
0005433923812	A75E9A	0865 161296	VALENTINA ZAKHAROVA	{"phone": "+70746915696"}
0005433923813	A75E9A	6476 240620	SERGEY KARPOV	{"email": "s-karpov.27011981@postgrespro.ru", "phone": "+70356544908"}
0005433923814	7A4433	6196 077443	VYACHESLAV PETROV	{"phone": "+70381579115"}
0005433923815	7A4433	4781 505772	OLGA NIKIFOROVA	{"email": "nikiforova.olga.061981@postgrespro.ru", "phone": "+70879446690"}
0005433923816	7A4433	0983 096966	FEDOR FROLOV	{"email": "f_frolov071971@postgrespro.ru", "phone": "+70461494523"}
0005433923817	C2D34A	1700 158358	ARTEM AFANASEV	{"email": "afanasevartem_081972@postgrespro.ru", "phone": "+70681213735"}
0005433923818	E6395E	8649 297448	ANDREY VOLKOV	{"phone": "+70190317293"}
0005433923819	6F760E	2471 814551	ALEKSANDR MAKAROV	{"phone": "+70178019826"}
0005433923820	6F760E	3624 285118	GALINA SERGEEVA	{"email": "galina.sergeeva-111977@postgrespro.ru", "phone": "+70795987640"}
0005433923821	99CFB2	4789 471436	MARIYA BELOVA	{"email": "belova.mariya_1966@postgrespro.ru", "phone": "+70602124085"}
0005433923822	99CFB2	5855 428052	MAKSIM MAKSIMOV	{"phone": "+70437090846"}
0005433923823	99CFB2	6258 167641	ALEKSANDR ANTONOV	{"email": "antonova1975@postgrespro.ru", "phone": "+70843702146"}
0005433923824	BF7FED	8067 057211	ALENA FILIPPOVA	{"email": "alena.filippova20051954@postgrespro.ru", "phone": "+70759836288"}
0005433923825	A551AD	3131 339704	IGOR SHEVCHENKO	{"phone": "+70369433450"}
0005433923826	88BC73	4317 317475	IRINA MEDVEDEVA	{"phone": "+70859291446"}
0005433923827	88BC73	1351 486263	SERGEY STEPANOV	{"email": "stepanovs21051985@postgrespro.ru", "phone": "+70386753010"}
0005433923828	403EEF	3038 807109	TATYANA IVANOVA	{"email": "tatyanaivanova1959@postgrespro.ru", "phone": "+70717000914"}
0005433923829	93515F	9391 881366	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova1988@postgrespro.ru", "phone": "+70741185898"}
0005433923830	B82ED4	9111 092004	KIRILL KISELEV	{"email": "kiselev_k-1978@postgrespro.ru", "phone": "+70788519697"}
0005433923831	FB518B	4301 330413	ANASTASIYA MATVEEVA	{"phone": "+70391580702"}
0005433923832	160136	2031 742717	ALEKSANDRA MALYSHEVA	{"email": "a.malysheva_12081972@postgrespro.ru", "phone": "+70530758637"}
0005433923833	160136	8468 913318	MARGARITA FILIPPOVA	{"email": "margarita-filippova.20121973@postgrespro.ru", "phone": "+70754193059"}
0005433923834	9410DB	5728 522855	GEORGIY ZAKHAROV	{"phone": "+70652794952"}
0005433923835	A8A421	4406 429953	ZINAIDA POTAPOVA	{"phone": "+70086950398"}
0005433923836	A8A421	0512 956042	VALENTINA AKIMOVA	{"email": "akimova.v.1975@postgrespro.ru", "phone": "+70079205226"}
0005433923837	A8A421	6088 704291	IRINA KOVALEVA	{"phone": "+70658767601"}
0005433923838	C03CCF	8014 504510	ANNA MASLOVA	{"email": "maslovaa26121976@postgrespro.ru", "phone": "+70407628404"}
0005433923839	C03CCF	6452 606525	VLADIMIR IVANOV	{"phone": "+70471179039"}
0005433923840	37CB84	0984 489353	LYUDMILA KUZNECOVA	{"email": "kuznecova-l-051973@postgrespro.ru", "phone": "+70263029332"}
0005433923841	37CB84	2686 746051	VITALIY KAZAKOV	{"phone": "+70879868674"}
0005433923842	C69CE8	0444 152895	ALEKSANDR ZAKHAROV	{"phone": "+70674309261"}
0005433923843	7991D6	1943 206012	KONSTANTIN VOROBEV	{"phone": "+70807490339"}
0005433923844	2B9EF5	7844 192015	LARISA NIKIFOROVA	{"email": "larisanikiforova03051967@postgrespro.ru", "phone": "+70404937951"}
0005433923845	2B9EF5	5345 177441	OLEG DMITRIEV	{"phone": "+70942540784"}
0005433923846	271F5C	4714 466258	NINA RODIONOVA	{"email": "n-rodionova.1960@postgrespro.ru", "phone": "+70428948739"}
0005433923847	E07B2E	6228 972008	TATYANA MEDVEDEVA	{"email": "tmedvedeva-27101973@postgrespro.ru", "phone": "+70578358226"}
0005433923848	1C1FC6	0975 461643	LYUDMILA FEDOROVA	{"phone": "+70150439937"}
0005433923849	6C20D9	1879 509563	ALEKSANDR NIKITIN	{"phone": "+70671828208"}
0005433923850	6C20D9	5672 823005	NIKOLAY VOROBEV	{"email": "nikolay_vorobev-22081974@postgrespro.ru", "phone": "+70614566542"}
0005433923851	5EF2C0	0463 205357	VYACHESLAV KUZNECOV	{"email": "v-kuznecov_06021980@postgrespro.ru", "phone": "+70508428509"}
0005433923852	A667EB	1253 483483	IVAN SMIRNOV	{"email": "ismirnov1972@postgrespro.ru", "phone": "+70910367295"}
0005433923853	A667EB	2054 971559	VALENTINA KOROLEVA	{"email": "koroleva-v_071971@postgrespro.ru", "phone": "+70922716575"}
0005433923854	09E8F8	0689 264521	ANASTASIYA KALININA	{"phone": "+70133362206"}
0005433923855	09E8F8	8742 262766	DENIS ZHUKOV	{"phone": "+70902501634"}
0005433923856	3C11EF	3002 241028	GALINA KAZAKOVA	{"email": "gkazakova-1973@postgrespro.ru", "phone": "+70779790799"}
0005433923857	3C11EF	1876 060316	VERA KUZNECOVA	{"phone": "+70227427652"}
0005433923858	FC2324	3380 918447	SVETLANA MELNIKOVA	{"email": "svetlanamelnikova-1959@postgrespro.ru", "phone": "+70931112044"}
0005433923860	D14021	9629 206380	VIKTOR ALEKSEEV	{"phone": "+70887257538"}
0005433923861	B93D3B	7064 266628	SERGEY SCHERBAKOV	{"email": "sscherbakov.29041983@postgrespro.ru", "phone": "+70934452952"}
0005433923862	48FDE6	9352 210113	GALINA FEDOROVA	{"phone": "+70491568386"}
0005433923863	D1E7B1	4522 330713	NADEZHDA MATVEEVA	{"phone": "+70809709349"}
0005433923864	D1E7B1	0780 895250	ANTONINA BELOVA	{"phone": "+70017155705"}
0005433923865	D2D0AC	8002 368346	ALEKSANDR STEPANOV	{"email": "stepanov-a.02111984@postgrespro.ru", "phone": "+70434674208"}
0005433923866	01E6AC	2481 381520	ANNA IVANOVA	{"phone": "+70090527334"}
0005433923867	CD605D	3235 265049	SERGEY MAKSIMOV	{"email": "maksimov.s1976@postgrespro.ru", "phone": "+70467730870"}
0005433923868	8C3CA9	2929 695667	VIKTORIYA SMIRNOVA	{"email": "smirnova_v-20041977@postgrespro.ru", "phone": "+70714676169"}
0005433923869	B496B0	3432 115683	NIKOLAY ALEKSANDROV	{"phone": "+70369665942"}
0005433923870	8A41FA	2281 657011	ELENA KONDRATEVA	{"email": "elena-kondrateva-011979@postgrespro.ru", "phone": "+70909984477"}
0005433923871	8A41FA	2017 607609	DANILA SERGEEV	{"phone": "+70526779124"}
0005433923872	C1093B	3506 277706	ALEKSEY ZHURAVLEV	{"phone": "+70627281536"}
0005433923873	1CEC84	4401 298153	VYACHESLAV ZAYCEV	{"phone": "+70215196157"}
0005433923874	2C11D3	3528 620234	ROMAN NOVIKOV	{"email": "r.novikov-1970@postgrespro.ru", "phone": "+70526714776"}
0005433923875	85FF4B	3251 968385	ANNA POTAPOVA	{"phone": "+70440410332"}
0005433923876	85FF4B	7752 555811	MARIYA AFANASEVA	{"phone": "+70026191041"}
0005433923877	137613	4389 873900	IRINA ROMANOVA	{"phone": "+70867609317"}
0005433923878	C0D5D6	7229 264322	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay.20021986@postgrespro.ru", "phone": "+70931210259"}
0005433923879	C0D5D6	2354 003195	IGOR DAVYDOV	{"email": "davydov-igor_13121970@postgrespro.ru", "phone": "+70240106430"}
0005433923880	988355	8822 492854	NATALYA NIKITINA	{"phone": "+70608647404"}
0005433923881	988355	7722 364190	SVETLANA FILIPPOVA	{"email": "svetlana_filippova.011972@postgrespro.ru", "phone": "+70992658704"}
0005433923882	4F891F	6442 615681	YURIY MAKAROV	{"phone": "+70938287634"}
0005433923883	C69847	2543 992623	VIKTOR TIMOFEEV	{"email": "viktor-timofeev-05051978@postgrespro.ru", "phone": "+70909736221"}
0005433923884	C69847	7144 637827	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr071978@postgrespro.ru", "phone": "+70650471030"}
0005433923885	EBB05B	2199 978094	ALEKSEY GAVRILOV	{"email": "a.gavrilov071973@postgrespro.ru", "phone": "+70726312561"}
0005433923886	EBB05B	2948 656372	ELENA RODIONOVA	{"phone": "+70945559438"}
0005433923887	F3B83D	2037 649095	ILYA MELNIKOV	{"email": "melnikov-i061983@postgrespro.ru", "phone": "+70969912370"}
0005433923888	F3B83D	6894 658029	MARIYA KULIKOVA	{"email": "mariya-kulikova.24011971@postgrespro.ru", "phone": "+70215314283"}
0005433923889	F33DF5	2465 166996	TATYANA SCHERBAKOVA	{"email": "tatyana-scherbakova-27031972@postgrespro.ru", "phone": "+70969108377"}
0005433923890	F843F5	3894 944621	IGOR MAKAROV	{"email": "makarov.i.13071968@postgrespro.ru", "phone": "+70255409522"}
0005433923891	BBEDF8	8521 677456	LYUDMILA KUZNECOVA	{"email": "kuznecovalyudmila_1983@postgrespro.ru", "phone": "+70435145637"}
0005433923892	BBEDF8	4945 477068	NADEZHDA KUZNECOVA	{"phone": "+70086933647"}
0005433923893	BBEDF8	0979 809112	VIKTOR ZHUKOV	{"email": "zhukov-viktor_04081962@postgrespro.ru", "phone": "+70635476981"}
0005433923894	C66B7F	6174 230353	VIKTOR MATVEEV	{"email": "v-matveev_1977@postgrespro.ru", "phone": "+70277361194"}
0005433923895	4B5335	9112 557475	ALEKSEY RODIONOV	{"phone": "+70458045452"}
0005433923896	4278F5	0598 686783	ARTUR MELNIKOV	{"email": "a.melnikov_12041968@postgrespro.ru", "phone": "+70036259947"}
0005433923897	4278F5	5848 247930	ALEKSANDR BONDARENKO	{"email": "bondarenko-a1964@postgrespro.ru", "phone": "+70335923358"}
0005433923898	4278F5	4441 960942	IRINA NIKOLAEVA	{"phone": "+70907209588"}
0005433923899	B7E468	2242 484051	NADEZHDA MASLOVA	{"email": "maslova.n.26011966@postgrespro.ru", "phone": "+70561377239"}
0005433923900	A8332B	9602 474346	VADIM KISELEV	{"phone": "+70030728001"}
0005433923901	D1231F	5364 255224	ANTONINA FOMINA	{"email": "a-fomina_011962@postgrespro.ru", "phone": "+70887993231"}
0005433923902	D1231F	6960 970401	OKSANA FADEEVA	{"phone": "+70192586727"}
0005433923903	82ED38	8595 688394	OLGA DAVYDOVA	{"email": "odavydova28121973@postgrespro.ru", "phone": "+70216454471"}
0005433923904	82ED38	3013 078264	VYACHESLAV SHEVCHENKO	{"phone": "+70958077511"}
0005433923905	6354A9	2533 144239	DIANA RODIONOVA	{"phone": "+70689878264"}
0005433923906	B5B3A4	6171 035743	DMITRIY MOISEEV	{"email": "dmitriy.moiseev19111979@postgrespro.ru", "phone": "+70367930816"}
0005433923907	5F507F	3966 397259	VERA FILATOVA	{"phone": "+70096807930"}
0005433923908	5F507F	5851 104795	ALEKSANDR GRIGOREV	{"phone": "+70606310228"}
0005433923909	6B2455	4566 397993	DARYA TARASOVA	{"email": "tarasova_d18051978@postgrespro.ru", "phone": "+70546919015"}
0005433923910	DEBAF8	3249 880570	LYUBOV SOLOVEVA	{"email": "soloveva_lyubov_061978@postgrespro.ru", "phone": "+70139900370"}
0005433923911	5C0C1A	7080 028610	VALENTINA TITOVA	{"email": "valentina-titova1984@postgrespro.ru", "phone": "+70573106848"}
0005433923912	D0D56A	1701 499153	NATALIYA NOVIKOVA	{"phone": "+70618851775"}
0005433923969	487B14	4741 967281	OLGA SERGEEVA	{"phone": "+70070980516"}
0005433923913	B75917	5203 362656	ARTEM NIKOLAEV	{"email": "a.nikolaev-071981@postgrespro.ru", "phone": "+70343080404"}
0005433924027	169394	2568 998737	NIKOLAY MIKHAYLOV	{"phone": "+70218206887"}
0005433923914	2D9611	4025 877742	MARIYA KOZLOVA	{"email": "m_kozlova.14111964@postgrespro.ru", "phone": "+70998784675"}
0005433923915	353FA8	0453 562864	MARIYA KUDRYASHOVA	{"phone": "+70026741197"}
0005433923916	9E67AC	2229 071263	NATALYA FEDOROVA	{"email": "fedorova-natalya-1970@postgrespro.ru", "phone": "+70282263945"}
0005433923917	A2F246	0593 154857	LIDIYA SEMENOVA	{"phone": "+70965483345"}
0005433923918	34EFA2	9446 186296	ARTEM ANDREEV	{"email": "andreev_a.19101982@postgrespro.ru", "phone": "+70069228342"}
0005433923919	34EFA2	9069 682115	ALEKSANDRA RYABOVA	{"email": "ryabovaa27031986@postgrespro.ru", "phone": "+70396722229"}
0005433923920	785694	7553 845969	SVETLANA CHERNOVA	{"email": "chernovas1966@postgrespro.ru", "phone": "+70126632062"}
0005433923921	785694	8569 862407	TATYANA NESTEROVA	{"email": "tatyana.nesterova-111987@postgrespro.ru", "phone": "+70889067517"}
0005433923922	785694	6609 900637	ANDREY IVANOV	{"phone": "+70146851620"}
0005433923923	D6C17C	6782 482302	TATYANA MAKAROVA	{"email": "makarova.tatyana_1968@postgrespro.ru", "phone": "+70278930668"}
0005433923924	522F32	7067 790254	ALEKSEY MEDVEDEV	{"phone": "+70792644115"}
0005433923925	522F32	3005 331546	ELENA KOROLEVA	{"phone": "+70432434061"}
0005433923926	772F48	5728 589899	DANILA MAKAROV	{"phone": "+70368861121"}
0005433923927	772F48	1604 960168	VERA PETROVA	{"phone": "+70250904062"}
0005433923928	756E8C	5184 986519	ELENA ISAEVA	{"phone": "+70683173474"}
0005433923929	2D81FE	1526 094318	RAFAEL ABRAMOV	{"email": "abramov.r.1974@postgrespro.ru", "phone": "+70523938847"}
0005433923930	D965DC	1230 479874	DARYA VOLKOVA	{"phone": "+70148180142"}
0005433923931	2C2926	3325 323293	ELENA TIMOFEEVA	{"email": "etimofeeva-061973@postgrespro.ru", "phone": "+70669504407"}
0005433923932	2C2926	5746 262271	EVGENIY SEMENOV	{"email": "semenovevgeniy-31011977@postgrespro.ru", "phone": "+70996385355"}
0005433923933	CA6009	7340 540911	ANASTASIYA KOZLOVA	{"phone": "+70200832675"}
0005433923934	CA6009	0980 008475	SOFYA MAKAROVA	{"email": "makarova.s-26101968@postgrespro.ru", "phone": "+70194509625"}
0005433923935	C3CBAE	8304 136245	RUSLAN FEDOROV	{"email": "rfedorov-051981@postgrespro.ru", "phone": "+70059014722"}
0005433923936	C3CBAE	3630 996468	ALEKSANDR SOROKIN	{"phone": "+70998957685"}
0005433923937	C3CBAE	5041 929052	MARIYA KUZNECOVA	{"email": "m-kuznecova-16101970@postgrespro.ru", "phone": "+70298327193"}
0005433923938	FFCBAF	1068 429277	ELIZAVETA MOROZOVA	{"email": "elizaveta_morozova15031973@postgrespro.ru", "phone": "+70430713322"}
0005433923939	FFCBAF	1235 216794	ELENA ISAEVA	{"email": "isaeva_elena_091975@postgrespro.ru", "phone": "+70268766289"}
0005433923940	6517F4	4130 586303	VALERIY IVANOV	{"phone": "+70974776412"}
0005433923941	92AB21	1172 464609	ALEKSEY AFANASEV	{"email": "a_afanasev_1978@postgrespro.ru", "phone": "+70198678877"}
0005433923942	21DE36	2719 290810	VALERIY POPOV	{"email": "valeriypopov.02031966@postgrespro.ru", "phone": "+70302885267"}
0005433923943	A4C9D8	6636 538346	OLEG SAVELEV	{"email": "olegsavelev.051969@postgrespro.ru", "phone": "+70414506535"}
0005433923944	FF96EE	7701 219991	OLGA DAVYDOVA	{"email": "o.davydova1971@postgrespro.ru", "phone": "+70941412385"}
0005433923945	08F995	7855 971782	EKATERINA ABRAMOVA	{"phone": "+70308972901"}
0005433923946	5690ED	7750 138302	IRINA NIKITINA	{"phone": "+70097417348"}
0005433923947	D2D1B4	2759 285183	MARK KRASNOV	{"phone": "+70140640998"}
0005433923948	D2D1B4	6137 077013	YURIY VOLKOV	{"email": "y-volkov_031971@postgrespro.ru", "phone": "+70297965245"}
0005433923949	45D5DD	1548 789092	NIKOLAY KUDRYASHOV	{"email": "n_kudryashov.101960@postgrespro.ru", "phone": "+70729904230"}
0005433923950	382B53	0489 376198	ALEKSANDR IVANOV	{"email": "a.ivanov031983@postgrespro.ru", "phone": "+70066987251"}
0005433923951	EB9253	1488 508097	EKATERINA GRISHINA	{"email": "ekaterina_grishina-25081970@postgrespro.ru", "phone": "+70352219123"}
0005433923952	EB9253	8237 052268	NADEZHDA FILATOVA	{"email": "filatova-n-1978@postgrespro.ru", "phone": "+70005167341"}
0005433923953	7628D3	3890 127505	NIKOLAY ISAEV	{"email": "isaev_nikolay.021973@postgrespro.ru", "phone": "+70970000737"}
0005433923954	3DB759	5751 746972	FEDOR SCHERBAKOV	{"phone": "+70920808332"}
0005433923955	3DB759	8030 768439	ALEKSEY VLASOV	{"email": "vlasovaleksey.031972@postgrespro.ru", "phone": "+70940070376"}
0005433923956	E4C2D7	5249 818892	GALINA POPOVA	{"email": "popova-galina27051981@postgrespro.ru", "phone": "+70026923150"}
0005433923957	E4C2D7	3416 686279	ANDREY FILIPPOV	{"email": "a-filippov.091972@postgrespro.ru", "phone": "+70885344776"}
0005433923958	D5B58C	9559 412655	ELENA SEMENOVA	{"phone": "+70927427683"}
0005433923959	3327E7	7325 150192	ELENA YUDINA	{"phone": "+70842588998"}
0005433923960	3327E7	4666 145172	ANATOLIY ZHURAVLEV	{"phone": "+70711792466"}
0005433923961	654E4C	9021 835424	ILMIRA GRISHINA	{"phone": "+70879343992"}
0005433923962	E63F88	5942 289017	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr-1974@postgrespro.ru", "phone": "+70557888382"}
0005433923963	D68325	5706 039664	VADIM SERGEEV	{"email": "v_sergeev-16101965@postgrespro.ru", "phone": "+70882121208"}
0005433923964	D68325	2076 240051	NIKOLAY POPOV	{"email": "popov.nikolay-101969@postgrespro.ru", "phone": "+70302746174"}
0005433923965	D68325	8761 663744	ELENA ZAKHAROVA	{"phone": "+70575042830"}
0005433923966	1A32FC	2018 890873	VITALIY POPOV	{"phone": "+70611422281"}
0005433923967	AC37CE	2330 433781	OLGA MAKAROVA	{"email": "makarova-olga-23081974@postgrespro.ru", "phone": "+70204643566"}
0005433923968	1EB1A9	1085 556319	TAMARA KUZMINA	{"phone": "+70621468161"}
0005433923970	487B14	4154 895347	VLADIMIR TARASOV	{"email": "vladimir_tarasov-1978@postgrespro.ru", "phone": "+70525484616"}
0005433923971	3E1E3B	3662 337854	GALINA TIMOFEEVA	{"email": "galina-timofeeva_071970@postgrespro.ru", "phone": "+70271398578"}
0005433923972	E05321	5625 581509	TATYANA STEPANOVA	{"email": "tatyanastepanova23041984@postgrespro.ru", "phone": "+70753881708"}
0005433923973	E05321	7472 717730	GLEB OSIPOV	{"email": "g.osipov-11021970@postgrespro.ru", "phone": "+70714100348"}
0005433923974	8D4EB0	4892 587990	LYUDMILA ANISIMOVA	{"email": "lanisimova.1966@postgrespro.ru", "phone": "+70023199183"}
0005433923975	8D4EB0	5497 709361	NIKOLAY ZAKHAROV	{"email": "zakharovn.1978@postgrespro.ru", "phone": "+70284002364"}
0005433923976	AC7FFE	5599 770814	OLEG IVANOV	{"phone": "+70868267730"}
0005433923977	AC7FFE	0216 655475	VLADIMIR POPOV	{"email": "popov_vladimir_1974@postgrespro.ru", "phone": "+70789879522"}
0005433923978	26EBA4	3062 812889	SVETLANA KOROLEVA	{"email": "s-koroleva.1965@postgrespro.ru", "phone": "+70269486983"}
0005433923979	26EBA4	2060 743381	STANISLAV AFANASEV	{"email": "s.afanasev.071972@postgrespro.ru", "phone": "+70728791589"}
0005433923980	86D576	1531 437942	ANATOLIY GERASIMOV	{"email": "gerasimov_a_1963@postgrespro.ru", "phone": "+70136554532"}
0005433923981	86D576	6598 452263	ANASTASIYA VOLKOVA	{"phone": "+70241422818"}
0005433923982	ACF36A	6797 255175	IRINA MARTYNOVA	{"phone": "+70487798236"}
0005433923983	ACF36A	0292 095386	VYACHESLAV CHERNOV	{"phone": "+70544462696"}
0005433923984	AE9528	8220 498452	EKATERINA KISELEVA	{"email": "kiseleva-ekaterina1969@postgrespro.ru", "phone": "+70611568804"}
0005433923985	8A2552	9101 931220	ALEKSANDR MAKAROV	{"phone": "+70107951123"}
0005433923986	FB4E95	6911 057518	IVAN SERGEEV	{"email": "i.sergeev.25111972@postgrespro.ru", "phone": "+70581324479"}
0005433923987	ADA28F	3017 333963	ALENA MATVEEVA	{"phone": "+70619497952"}
0005433923988	E515AF	8877 411401	NATALYA OSIPOVA	{"email": "natalyaosipova_101974@postgrespro.ru", "phone": "+70843405082"}
0005433923989	E515AF	6660 922367	ALEKSEY MIRONOV	{"phone": "+70586773342"}
0005433923990	0C0694	5782 451627	ELENA MOROZOVA	{"phone": "+70113967082"}
0005433923991	34A315	3023 843636	TATYANA SCHERBAKOVA	{"email": "t-scherbakova-15111973@postgrespro.ru", "phone": "+70013903102"}
0005433923992	F5A1B8	1492 425613	TATYANA KARPOVA	{"phone": "+70692714518"}
0005433923993	DF8FCA	0856 577528	SERGEY IVANOV	{"email": "ivanov-s-051967@postgrespro.ru", "phone": "+70211351446"}
0005433923994	7B26B7	0982 992908	ALINA KUZMINA	{"email": "alina.kuzmina.25051969@postgrespro.ru", "phone": "+70665042144"}
0005433923995	F86386	9832 192613	TATYANA ZAKHAROVA	{"email": "zakharova.t071972@postgrespro.ru", "phone": "+70101695867"}
0005433923996	1F8CFA	6358 987558	ALIYA KOVALEVA	{"phone": "+70887077034"}
0005433923997	1F8CFA	7993 608050	OLGA VOLKOVA	{"email": "volkovao1976@postgrespro.ru", "phone": "+70499654389"}
0005433923998	E6FC38	2523 793833	KSENIYA SCHERBAKOVA	{"phone": "+70619674295"}
0005433923999	E6FC38	9672 762302	IVAN ZHURAVLEV	{"email": "zhuravlev.i_28071970@postgrespro.ru", "phone": "+70988037322"}
0005433924000	E6FC38	9665 799183	EVGENIY KOZLOV	{"phone": "+70549705949"}
0005433924001	333372	4554 737416	TATYANA KRASNOVA	{"email": "t-krasnova.10071966@postgrespro.ru", "phone": "+70066630401"}
0005433924002	6118B9	2791 090795	SOFYA ABRAMOVA	{"phone": "+70257115673"}
0005433924003	6118B9	9083 920217	NATALYA KUZNECOVA	{"phone": "+70481845861"}
0005433924004	335CA6	5014 187171	NIKOLAY KUZNECOV	{"phone": "+70705391606"}
0005433924005	8A0031	6563 204984	ANNA SOROKINA	{"email": "a_sorokina.1975@postgrespro.ru", "phone": "+70577655095"}
0005433924006	8A0031	9090 321935	ANASTASIYA BARANOVA	{"phone": "+70783736545"}
0005433924007	673697	4193 581590	VALERIY SEMENOV	{"email": "v-semenov-101970@postgrespro.ru", "phone": "+70371489256"}
0005433924008	C2F255	1902 547138	NATALYA MEDVEDEVA	{"email": "n-medvedeva.09081970@postgrespro.ru", "phone": "+70221780458"}
0005433924009	FAABF1	3757 108604	SERGEY EGOROV	{"phone": "+70982608939"}
0005433924010	83D81E	9561 876765	TATYANA VASILEVA	{"phone": "+70433237945"}
0005433924011	3CD43B	2413 268158	NADEZHDA MIKHAYLOVA	{"phone": "+70357141767"}
0005433924012	2CDFC0	4491 913688	EVGENIY FOMIN	{"email": "e-fomin_091974@postgrespro.ru", "phone": "+70535091115"}
0005433924013	2CDFC0	3497 205556	YURIY GAVRILOV	{"phone": "+70897001742"}
0005433924014	2CDFC0	4583 368092	ANTON KUZNECOV	{"email": "a_kuznecov061971@postgrespro.ru", "phone": "+70179118439"}
0005433924015	07C577	1842 188297	IGOR VOLKOV	{"phone": "+70940911443"}
0005433924016	07C577	0222 709414	VLADIMIR VASILEV	{"phone": "+70775940178"}
0005433924017	A7773F	6199 934937	TATYANA SMIRNOVA	{"phone": "+70725918947"}
0005433924018	BF7E5D	2176 737114	PAVEL FEDOTOV	{"email": "p_fedotov1971@postgrespro.ru", "phone": "+70728281793"}
0005433924019	BF7E5D	4475 678907	FARIT SOKOLOV	{"phone": "+70931546398"}
0005433924020	35CAA8	5926 291634	NINA GERASIMOVA	{"email": "gerasimova-n-22101968@postgrespro.ru", "phone": "+70273067023"}
0005433924021	C38ED0	7995 895184	TATYANA VOLKOVA	{"phone": "+70405212801"}
0005433924022	762FEE	5828 669551	OLGA VOROBEVA	{"email": "olgavorobeva_1976@postgrespro.ru", "phone": "+70436390062"}
0005433924023	5A1B74	5458 393164	VITALIY ROMANOV	{"phone": "+70612887670"}
0005433924024	5B94D4	9761 315623	VIKTOR MEDVEDEV	{"email": "vmedvedev_01121966@postgrespro.ru", "phone": "+70936517566"}
0005433924025	55251F	7879 845389	ELENA CHERNOVA	{"email": "chernovae1977@postgrespro.ru", "phone": "+70166632471"}
0005433924026	CA70C6	1449 167478	NINA MIRONOVA	{"email": "mironova_n-101976@postgrespro.ru", "phone": "+70194002779"}
0005433924028	169394	2381 020548	MARINA ZHUKOVA	{"phone": "+70972047654"}
0005433924029	C6C140	1619 402086	ELENA KONOVALOVA	{"email": "konovalova-elena-11091967@postgrespro.ru", "phone": "+70781036458"}
0005433924030	C6C140	8684 071665	MARIYA TARASOVA	{"email": "tarasova.mariya1970@postgrespro.ru", "phone": "+70947528222"}
0005433924031	5AD2A7	4865 019840	GRIGORIY ZAKHAROV	{"phone": "+70211659395"}
0005433924032	7DA27C	6754 780032	SERGEY PAVLOV	{"email": "sergeypavlov25101975@postgrespro.ru", "phone": "+70706244453"}
0005433924033	F3D456	3459 657871	TATYANA ALEKSANDROVA	{"phone": "+70837975719"}
0005433924034	F3D456	2284 278389	NADEZHDA POPOVA	{"email": "popovan1972@postgrespro.ru", "phone": "+70516988992"}
0005433924035	6B2DB8	9839 667448	ALEKSANDR MOROZOV	{"email": "a.morozov_061976@postgrespro.ru", "phone": "+70498438774"}
0005433924036	6B2DB8	2351 465414	IRINA BELOVA	{"email": "belova.irina.111970@postgrespro.ru", "phone": "+70231927776"}
0005433924037	7B135E	6390 415517	SERGEY EGOROV	{"email": "egorov-sergey_071974@postgrespro.ru", "phone": "+70433102747"}
0005433924038	D4A3BC	5917 131321	TATYANA KULIKOVA	{"email": "kulikova_tatyana_30121972@postgrespro.ru", "phone": "+70891858783"}
0005433924039	6FE78C	6044 334290	VASILIY KUZNECOV	{"email": "vasiliykuznecov061973@postgrespro.ru", "phone": "+70857368201"}
0005433924040	83C62C	1839 915323	ANNA RODIONOVA	{"email": "anna_rodionova011969@postgrespro.ru", "phone": "+70765984346"}
0005433924041	83C62C	4921 427755	SERGEY KOROLEV	{"email": "korolevsergey_011959@postgrespro.ru", "phone": "+70604468421"}
0005433924042	86F545	1859 169573	ELENA ZHUKOVA	{"phone": "+70050723149"}
0005433924043	4725A3	7690 620229	OLGA DMITRIEVA	{"phone": "+70757391751"}
0005433924044	6631F7	6268 860788	ANASTASIYA SERGEEVA	{"phone": "+70338882709"}
0005433924045	6631F7	4629 247584	ALEKSANDR DMITRIEV	{"email": "dmitriev_a_1964@postgrespro.ru", "phone": "+70060453539"}
0005433924046	1850AD	4094 900475	EKATERINA NESTEROVA	{"email": "nesterova.ekaterina_1965@postgrespro.ru", "phone": "+70874092999"}
0005433924047	531593	1004 489085	TATYANA PAVLOVA	{"phone": "+70274520312"}
0005433924048	531593	5266 343584	EKATERINA SERGEEVA	{"phone": "+70936666495"}
0005433924049	917650	8885 064207	IRINA MAKAROVA	{"phone": "+70837586797"}
0005433924050	917650	0562 907159	ANNA MELNIKOVA	{"email": "anna-melnikova-24011970@postgrespro.ru", "phone": "+70796331186"}
0005433924051	C1B5A9	6961 194423	ALEKSANDR ZAYCEV	{"phone": "+70054187582"}
0005433924052	B7455F	3820 543234	YURIY BARANOV	{"phone": "+70191529266"}
0005433924053	1523DB	0766 575030	GYUZEL RODIONOVA	{"phone": "+70768001722"}
0005433924054	1523DB	4502 447976	LYUBOV KALININA	{"phone": "+70754214162"}
0005433924055	688D1F	6586 111896	VALERIY SOROKIN	{"phone": "+70725686105"}
0005433924056	688D1F	8668 778563	IRINA MALYSHEVA	{"phone": "+70704276697"}
0005433924057	688D1F	0560 373234	ALEKSANDR ZAYCEV	{"email": "a_zaycev.17061962@postgrespro.ru", "phone": "+70345711412"}
0005433924058	688D1F	2632 972280	RUSLAN SERGEEV	{"phone": "+70541813911"}
0005433924059	9B1BAD	6723 709321	ALEKSEY FEDOROV	{"email": "aleksey.fedorov-061971@postgrespro.ru", "phone": "+70332691257"}
0005433924060	26C53F	0287 524346	MARIYA ANDREEVA	{"phone": "+70557723041"}
0005433924061	26C53F	7200 225033	SERGEY FEDOTOV	{"email": "sergey_fedotov-26091971@postgrespro.ru", "phone": "+70608803656"}
0005433924062	A0FC4D	0920 723621	ALEKSANDR SCHERBAKOV	{"phone": "+70197321963"}
0005433924063	40948F	3486 100367	NADEZHDA MOROZOVA	{"phone": "+70224640001"}
0005433924064	4FB6BA	7566 536100	NINA SOLOVEVA	{"email": "ninasoloveva03121979@postgrespro.ru", "phone": "+70644683722"}
0005433924065	52D2C0	1894 484940	ARMEN IVANOV	{"email": "ivanovarmen-1972@postgrespro.ru", "phone": "+70141774254"}
0005433924066	EE0097	7910 121325	NADEZHDA AFANASEVA	{"email": "nadezhda_afanaseva-011980@postgrespro.ru", "phone": "+70360839125"}
0005433924067	250BA9	3275 959968	ALEKSANDR MEDVEDEV	{"email": "aleksandr.medvedev.1972@postgrespro.ru", "phone": "+70771371442"}
0005433924068	250BA9	8221 132652	DARYA MOROZOVA	{"email": "d_morozova1982@postgrespro.ru", "phone": "+70346191889"}
0005433924069	DD3084	4817 310878	DMITRIY TIKHONOV	{"phone": "+70983940926"}
0005433924070	DD3084	5857 429460	NADEZHDA VLASOVA	{"email": "vlasovanadezhda.051978@postgrespro.ru", "phone": "+70415631882"}
0005433924071	FD2F78	9130 920579	NADEZHDA SIDOROVA	{"email": "sidorova.n_1975@postgrespro.ru", "phone": "+70082549992"}
0005433924072	FD2F78	8372 346365	OLGA ISAEVA	{"email": "olgaisaeva-061980@postgrespro.ru", "phone": "+70762806076"}
0005433924073	A18031	9596 873693	NATALYA BORISOVA	{"phone": "+70968613615"}
0005433924074	DC54E1	7139 373311	VALENTIN MAKAROV	{"phone": "+70907375171"}
0005433924075	DC54E1	1506 079330	SERGEY CHERNOV	{"email": "sergey.chernov_06041972@postgrespro.ru", "phone": "+70594801792"}
0005433924076	2D7E1C	3378 567391	EKATERINA MOISEEVA	{"phone": "+70883435622"}
0005433924077	2D7E1C	9753 687607	ELENA ZAKHAROVA	{"phone": "+70799105671"}
0005433924078	5929FF	8292 628987	MARIYA KOROLEVA	{"phone": "+70785736102"}
0005433924079	1AAEF8	6159 478005	YURIY MOISEEV	{"email": "moiseevy.081972@postgrespro.ru", "phone": "+70028230537"}
0005433924080	CADD0D	6045 536503	NADEZHDA NIKOLAEVA	{"email": "nadezhdanikolaeva24021976@postgrespro.ru", "phone": "+70968079615"}
0005433924081	2A0770	5899 100848	ELENA POTAPOVA	{"phone": "+70065363147"}
0005433924082	279C02	5204 803216	ALEKSEY POPOV	{"email": "a-popov1963@postgrespro.ru", "phone": "+70448861820"}
0005433924083	2FD756	6718 792013	YURIY ROMANOV	{"email": "romanovyuriy-30011967@postgrespro.ru", "phone": "+70543507546"}
0005433924084	2FD756	2489 457414	TATYANA KOROLEVA	{"email": "t_koroleva-26031962@postgrespro.ru", "phone": "+70934203430"}
0005433924085	C3A1CD	3187 166741	FEDOR IVANOV	{"email": "ivanov-fedor.1960@postgrespro.ru", "phone": "+70496230822"}
0005433924086	244779	2190 569318	DENIS EGOROV	{"phone": "+70321924153"}
0005433924087	AB1A56	3510 091949	NADEZHDA PAVLOVA	{"email": "npavlova071978@postgrespro.ru", "phone": "+70187246073"}
0005433924088	F81E45	4500 985935	RUSLAN FEDOROV	{"phone": "+70023546337"}
0005433924089	F81E45	0228 896678	YURIY PETROV	{"phone": "+70459105976"}
0005433924090	8301BC	7560 294235	OKSANA BOGDANOVA	{"phone": "+70865551017"}
0005433924091	8301BC	6051 495688	ANTONINA SCHERBAKOVA	{"email": "antonina.scherbakova-041967@postgrespro.ru", "phone": "+70042420051"}
0005433924092	C7CD53	4439 533523	NADEZHDA KISELEVA	{"email": "kiseleva_nadezhda-1978@postgrespro.ru", "phone": "+70463177434"}
0005433924093	30DAE4	3345 686978	ALEKSEY ORLOV	{"email": "orlovaleksey.1960@postgrespro.ru", "phone": "+70087680099"}
0005433924094	285771	2572 200782	LYUBOV KUZNECOVA	{"email": "l.kuznecova-05031968@postgrespro.ru", "phone": "+70758097593"}
0005433924095	A7EF57	7121 488907	TAMARA KUZNECOVA	{"email": "t_kuznecova.1974@postgrespro.ru", "phone": "+70153564078"}
0005433924096	A7EF57	4476 582575	GENNADIY MOROZOV	{"email": "morozov_gennadiy-1970@postgrespro.ru", "phone": "+70660271166"}
0005433924097	B97A16	5109 420303	ELENA MELNIKOVA	{"email": "melnikova.e-10121965@postgrespro.ru", "phone": "+70439666520"}
0005433924098	0585A3	8848 681023	GENNADIY MAKAROV	{"email": "makarov_gennadiy.1971@postgrespro.ru", "phone": "+70238783785"}
0005433924099	0585A3	6752 335600	NINA BORISOVA	{"email": "borisova-n.19071967@postgrespro.ru", "phone": "+70829103138"}
0005433924100	DD93C5	0178 731302	NIKOLAY SHEVCHENKO	{"email": "shevchenko.n1989@postgrespro.ru", "phone": "+70848943159"}
0005433924101	DD93C5	1419 370616	KONSTANTIN GRIGOREV	{"phone": "+70699688527"}
0005433924102	FE0BAC	6442 349393	NADEZHDA KUZMINA	{"phone": "+70365574397"}
0005433924103	2A1FF5	7534 835376	NATALYA POPOVA	{"email": "natalya_popova10071976@postgrespro.ru", "phone": "+70682804571"}
0005433924104	F31D9A	0566 880609	KIRILL FROLOV	{"email": "frolov-k.12111973@postgrespro.ru", "phone": "+70161541427"}
0005433924105	D3F4B9	4686 415207	TATYANA FEDOROVA	{"phone": "+70397406674"}
0005433924106	D3F4B9	3669 249240	TIMUR KISELEV	{"phone": "+70248862989"}
0005433924107	BDDE01	4984 123486	SVETLANA STEPANOVA	{"phone": "+70815571296"}
0005433924108	E4E75E	0396 032535	FEDOR FEDOROV	{"email": "fedorovfedor_10011977@postgrespro.ru", "phone": "+70345457215"}
0005433924109	0FA30F	8622 851926	SVETLANA NIKOLAEVA	{"email": "svetlananikolaeva_1988@postgrespro.ru", "phone": "+70568759587"}
0005433924110	EAEBAA	0932 688090	LYUBOV DENISOVA	{"email": "l-denisova-051975@postgrespro.ru", "phone": "+70646926590"}
0005433924111	A8B13A	8633 860814	NADEZHDA IVANOVA	{"email": "n-ivanova-061979@postgrespro.ru", "phone": "+70999964298"}
0005433924112	A8B13A	3416 527147	OLEG STEPANOV	{"phone": "+70439778958"}
0005433924113	C7182C	2599 152462	MIKHAIL IVANOV	{"phone": "+70967274869"}
0005433924114	D66462	4009 521931	OLESYA KOMAROVA	{"email": "olesya.komarova.1979@postgrespro.ru", "phone": "+70005429248"}
0005433924115	66FBE7	9054 989577	VLADIMIR BELOV	{"phone": "+70013917508"}
0005433924116	927B4D	6076 671296	VLADIMIR SOKOLOV	{"phone": "+70659533177"}
0005433924117	C76412	7056 729098	VYACHESLAV BORISOV	{"phone": "+70594662037"}
0005433924118	72D775	4019 149349	LYUDMILA KAZAKOVA	{"email": "kazakova-lyudmila17121966@postgrespro.ru", "phone": "+70794640129"}
0005433924119	58BF76	1581 949752	VLADIMIR POPOV	{"email": "popov.vladimir.051974@postgrespro.ru", "phone": "+70062872504"}
0005433924120	02A4CE	6658 627946	YURIY NAUMOV	{"email": "y.naumov_1971@postgrespro.ru", "phone": "+70731299888"}
0005433924121	03814E	4292 795034	ANTON POPOV	{"phone": "+70522250321"}
0005433924122	03814E	5964 144288	SERGEY MAKAROV	{"phone": "+70018209351"}
0005433924123	8AFA1F	3978 474163	SVETLANA FILIPPOVA	{"email": "filippovasvetlana01101992@postgrespro.ru", "phone": "+70449757399"}
0005433924124	8AFA1F	1043 770559	SERGEY PETROV	{"email": "petrovs051972@postgrespro.ru", "phone": "+70237714403"}
0005433924125	323324	4586 206629	LYUBOV DAVYDOVA	{"email": "l_davydova1977@postgrespro.ru", "phone": "+70808036716"}
0005433924126	323324	4956 804887	OLGA FROLOVA	{"phone": "+70229365963"}
0005433924127	192FAE	4641 730509	VIKTORIYA ANISIMOVA	{"phone": "+70245614200"}
0005433924128	66AFE6	8923 391958	EVGENIY FOMIN	{"phone": "+70282799402"}
0005433924129	66AFE6	1098 705650	TATYANA BOGDANOVA	{"phone": "+70211939128"}
0005433924130	B1EE97	0431 640581	VLADIMIR KOZLOV	{"email": "kozlov_v-08101982@postgrespro.ru", "phone": "+70451273755"}
0005433924131	4BBCF5	5584 413368	SVETLANA SAVELEVA	{"phone": "+70218907699"}
0005433924132	EFC04C	2031 707517	YURIY NAZAROV	{"email": "yuriy-nazarov.1979@postgrespro.ru", "phone": "+70932060004"}
0005433924133	2BEBE6	1132 420266	OLGA GUSEVA	{"email": "o_guseva.03071971@postgrespro.ru", "phone": "+70070956759"}
0005433924134	038421	4917 790621	NINA TIMOFEEVA	{"email": "n_timofeeva.25061973@postgrespro.ru", "phone": "+70665077296"}
0005433924135	96FAF5	4137 920154	ELMIRA BOGDANOVA	{"email": "bogdanovaelmira021984@postgrespro.ru", "phone": "+70770448612"}
0005433924136	CFF47F	0887 496284	ELENA ORLOVA	{"phone": "+70964213102"}
0005433924137	BB7E19	4953 256134	YURIY BELOV	{"email": "y_belov1959@postgrespro.ru", "phone": "+70085157946"}
0005433924138	2F1445	0696 873132	ALEKSANDRA KRASNOVA	{"email": "aleksandra-krasnova_071972@postgrespro.ru", "phone": "+70410506930"}
0005433924139	2F1445	1662 708390	IVAN STEPANOV	{"phone": "+70215013870"}
0005433924140	2F1445	0144 427359	IRINA PAVLOVA	{"email": "pavlova_i13081979@postgrespro.ru", "phone": "+70005742843"}
0005433924141	D8F406	5288 650933	PAVEL TIKHONOV	{"email": "tikhonov_pavel-11041968@postgrespro.ru", "phone": "+70898030930"}
0005433924142	A59B78	0581 685616	ALEKSANDR CHERNOV	{"phone": "+70679098618"}
0005433924143	A59B78	5398 442787	NATALYA SERGEEVA	{"phone": "+70886825007"}
0005433924144	6FBDD9	9365 423143	ALEKSANDR MIKHAYLOV	{"phone": "+70857055485"}
0005433924145	6FBDD9	6008 336300	LARISA POPOVA	{"email": "popova-larisa_16061966@postgrespro.ru", "phone": "+70992855387"}
0005433924146	ADD46D	2236 166398	NIKOLAY PAVLOV	{"phone": "+70174060925"}
0005433924147	DE3669	6844 369477	VALENTINA MAKSIMOVA	{"email": "maksimova_valentina.1982@postgrespro.ru", "phone": "+70284949692"}
0005433924148	B3A090	2535 461731	RAISA AFANASEVA	{"email": "raisaafanaseva-04121971@postgrespro.ru", "phone": "+70618720422"}
0005433924149	E4DBEC	3503 949684	ANATOLIY VASILEV	{"phone": "+70266863823"}
0005433924150	E4DBEC	4740 010950	VADIM GUSEV	{"phone": "+70683466297"}
0005433924151	242EC9	6189 875419	OLGA ABRAMOVA	{"email": "abramovao.111968@postgrespro.ru", "phone": "+70067769796"}
0005433924152	A8CC4C	7885 361472	VITALIY KUDRYASHOV	{"phone": "+70082145845"}
0005433924153	39D84F	9036 847806	ANDREY PAVLOV	{"phone": "+70124696710"}
0005433924154	39D84F	3556 515240	MARIYA KOROLEVA	{"email": "koroleva_m-1963@postgrespro.ru", "phone": "+70058101395"}
0005433924155	C0B8B4	8562 224222	VIKTOR PAVLOV	{"phone": "+70710196584"}
0005433924156	FCCD7A	6229 388995	MARIYA LAZAREVA	{"phone": "+70259731955"}
0005433924157	6CDF0C	6847 086030	MARINA KUZNECOVA	{"email": "kuznecovam.1976@postgrespro.ru", "phone": "+70827706089"}
0005433924158	6CDF0C	1488 689548	SERGEY EGOROV	{"email": "egorov-s_1966@postgrespro.ru", "phone": "+70605495722"}
0005433924159	A90E3A	0501 411318	ERIK GUSEV	{"email": "gusev_e-061976@postgrespro.ru", "phone": "+70728348055"}
0005433924160	8FC69B	2694 107828	LYUBOV KUZMINA	{"email": "lyubov-kuzmina091982@postgrespro.ru", "phone": "+70959704863"}
0005433924161	8FC69B	9854 698543	SVETLANA TIMOFEEVA	{"phone": "+70644335356"}
0005433924162	A81801	0433 705325	NATALIYA NIKITINA	{"email": "n-nikitina091973@postgrespro.ru", "phone": "+70983143795"}
0005433924163	A81801	2747 352628	LIYA NOVIKOVA	{"phone": "+70911609599"}
0005433924164	9F586D	0811 124004	ELENA NIKIFOROVA	{"phone": "+70412383508"}
0005433924165	298DC8	3360 985096	VLADIMIR MELNIKOV	{"email": "melnikovv_1963@postgrespro.ru", "phone": "+70720457643"}
0005433924166	A271CC	0654 584085	ALEKSEY MOROZOV	{"phone": "+70154959748"}
0005433924167	EB1110	2255 062811	ROMAN ZHURAVLEV	{"email": "romanzhuravlev-1970@postgrespro.ru", "phone": "+70162793420"}
0005433924168	EB1110	5384 132510	ANNA MAKAROVA	{"phone": "+70270585122"}
0005433924169	07A05E	8702 359864	LIDIYA VASILEVA	{"phone": "+70704135337"}
0005433924170	775679	9487 158753	ALEKSANDR POPOV	{"email": "popovaleksandr07071964@postgrespro.ru", "phone": "+70380193100"}
0005433924171	87A7D9	3047 102175	VLADIMIR IVANOV	{"email": "vladimirivanov_1978@postgrespro.ru", "phone": "+70230257875"}
0005433924172	87A7D9	1381 058331	VIKTORIYA POLYAKOVA	{"email": "viktoriya_polyakova.1982@postgrespro.ru", "phone": "+70105928671"}
0005433924173	87A7D9	1378 644499	ALEVTINA POTAPOVA	{"phone": "+70333023782"}
0005433924174	E2B4DA	8724 538154	TATYANA NIKITINA	{"phone": "+70345694510"}
0005433924175	F6C326	0482 686336	EGOR FROLOV	{"phone": "+70094210254"}
0005433924176	F6C326	0158 311847	EVGENIY DAVYDOV	{"email": "davydov.evgeniy.091975@postgrespro.ru", "phone": "+70906659300"}
0005433924177	8C4D8C	0510 926915	SERGEY KUZNECOV	{"phone": "+70222041379"}
0005433924178	8C4D8C	7355 891006	VLADIMIR MOROZOV	{"email": "morozov.vladimir111973@postgrespro.ru", "phone": "+70281542270"}
0005433924179	12543D	4891 407191	MAKSIM SERGEEV	{"email": "maksim_sergeev111961@postgrespro.ru", "phone": "+70834158067"}
0005433924180	AC20F1	0439 011948	EVGENIY PETROV	{"phone": "+70278147467"}
0005433924181	7C7EDA	7428 413127	GEORGIY VOROBEV	{"phone": "+70619539385"}
0005433924182	FADD68	2823 432574	VLADIMIR BORISOV	{"phone": "+70982016348"}
0005433924183	FADD68	5558 748570	IVAN ANDREEV	{"email": "i_andreev.02091977@postgrespro.ru", "phone": "+70706863976"}
0005433924184	659AEF	0400 552782	VLADIMIR EGOROV	{"email": "egorovv1976@postgrespro.ru", "phone": "+70821033862"}
0005433924185	659AEF	9104 475183	LYUDMILA KARPOVA	{"email": "lyudmila_karpova.071969@postgrespro.ru", "phone": "+70912788327"}
0005433924186	3446EE	3895 715218	EVGENIY GORBUNOV	{"phone": "+70673752469"}
0005433924187	920117	2004 605510	YULIYA VOROBEVA	{"email": "vorobeva.yuliya.18121982@postgrespro.ru", "phone": "+70421393012"}
0005433924188	8273A2	8545 121394	VIKTOR MIRONOV	{"email": "mironovviktor051981@postgrespro.ru", "phone": "+70235737256"}
0005433924189	CFF296	9261 047030	LIDIYA GAVRILOVA	{"phone": "+70335081697"}
0005433924190	CFF296	5811 581672	NINA MASLOVA	{"phone": "+70211878862"}
0005433924191	90015E	1072 856790	PAVEL ROMANOV	{"phone": "+70347877288"}
0005433924192	9D0530	4962 526749	NADEZHDA ILINA	{"email": "n.ilina-1980@postgrespro.ru", "phone": "+70593599791"}
0005433924193	150DD2	6144 601224	SERGEY ILIN	{"email": "ilin_s-021981@postgrespro.ru", "phone": "+70024255011"}
0005433924194	D943DB	5290 691187	YURIY ISAEV	{"phone": "+70190852793"}
0005433924195	248104	9975 000965	MARIYA NIKOLAEVA	{"phone": "+70410520769"}
0005433924196	EA787D	3349 752445	TATYANA NOVIKOVA	{"email": "tnovikova_041966@postgrespro.ru", "phone": "+70123450643"}
0005433924197	681DB7	3426 645166	MAKSIM ANDREEV	{"email": "andreevmaksim.1964@postgrespro.ru", "phone": "+70827531040"}
0005433924198	681DB7	5560 226031	SERGEY EGOROV	{"email": "sergeyegorov_13071967@postgrespro.ru", "phone": "+70251536119"}
0005433924199	924B41	1971 283544	MARINA MAKSIMOVA	{"email": "maksimova.m-081979@postgrespro.ru", "phone": "+70941550416"}
0005433924200	430065	6948 040301	IGOR ALEKSEEV	{"email": "i.alekseev_24011975@postgrespro.ru", "phone": "+70485867415"}
0005433924201	C7B9CB	8637 856267	VALENTINA BORISOVA	{"phone": "+70656821106"}
0005433924202	F0A3D3	4722 326778	DANIIL NIKOLAEV	{"email": "nikolaev_daniil_26071980@postgrespro.ru", "phone": "+70645207826"}
0005433924203	758119	2714 250060	VALENTINA NAZAROVA	{"phone": "+70549379569"}
0005433924204	B1D30F	8845 422604	ELENA VOLKOVA	{"email": "volkovaelena-111962@postgrespro.ru", "phone": "+70675631729"}
0005433924205	A47A95	9266 302461	ILYA KUZNECOV	{"email": "kuznecov.i.061982@postgrespro.ru", "phone": "+70138040318"}
0005433924206	A879AA	1642 870027	ANNA SOKOLOVA	{"phone": "+70981881053"}
0005433924207	0DB97B	2186 030700	ALEKSANDR ZAYCEV	{"phone": "+70412567380"}
0005433924208	0DB97B	3153 251182	INNA OSIPOVA	{"phone": "+70785395554"}
0005433924209	ED512E	0165 714988	DMITRIY ZAKHAROV	{"phone": "+70556023155"}
0005433924210	94F042	2548 495786	KIRILL IVANOV	{"email": "ivanov_k.03121975@postgrespro.ru", "phone": "+70275469020"}
0005433924211	94F042	3198 491659	ANNA EFREMOVA	{"phone": "+70549426245"}
0005433924212	72DC53	8459 381914	ZINAIDA SMIRNOVA	{"phone": "+70637921809"}
0005433924213	72DC53	7783 541236	ALISA NIKOLAEVA	{"email": "nikolaeva-a-081969@postgrespro.ru", "phone": "+70807962055"}
0005433924214	72DC53	1736 648797	DANIL NAUMOV	{"email": "d-naumov-081971@postgrespro.ru", "phone": "+70892117024"}
0005433924215	DC1552	3895 222972	OKSANA ZAKHAROVA	{"email": "o-zakharova1973@postgrespro.ru", "phone": "+70200251466"}
0005433924216	DC1552	9513 368540	TATYANA GERASIMOVA	{"email": "t-gerasimova-23051965@postgrespro.ru", "phone": "+70521423044"}
0005433924217	F8667C	4946 762630	VLADIMIR MELNIKOV	{"phone": "+70379829838"}
0005433924218	B69098	0714 224083	TATYANA DENISOVA	{"phone": "+70082435657"}
0005433924219	299BE6	6931 648726	LEV FILIPPOV	{"phone": "+70425194098"}
0005433924220	0ED0ED	6330 819751	NINA ALEKSEEVA	{"email": "nina.alekseeva041974@postgrespro.ru", "phone": "+70661474346"}
0005433924221	ACDAAD	9671 902156	ZHANNA POPOVA	{"email": "popova.z08091964@postgrespro.ru", "phone": "+70576977772"}
0005433924222	ACDAAD	2753 802560	VIKTOR ZHURAVLEV	{"email": "v_zhuravlev.041973@postgrespro.ru", "phone": "+70161702535"}
0005433924223	BD8B47	4993 307294	IGOR IVANOV	{"email": "ivanovi_081974@postgrespro.ru", "phone": "+70240832377"}
0005433924224	31CB9D	3739 558800	DMITRIY EGOROV	{"phone": "+70465608211"}
0005433924225	31CB9D	1394 071067	VYACHESLAV BORISOV	{"phone": "+70424824979"}
0005433924226	EBC101	4433 328151	DMITRIY FEDOROV	{"email": "fedorov_dmitriy-121984@postgrespro.ru", "phone": "+70850547324"}
0005433924227	4FC718	3931 347775	IRINA SCHERBAKOVA	{"phone": "+70674644702"}
0005433924228	ABEDBB	9054 779194	BOGDAN MAKSIMOV	{"email": "maksimov.bogdan121970@postgrespro.ru", "phone": "+70159122110"}
0005433924229	ABEDBB	5290 477543	LYUDMILA PAVLOVA	{"phone": "+70018237658"}
0005433924230	8A6406	5159 755800	IRINA DAVYDOVA	{"email": "irina_davydova_061984@postgrespro.ru", "phone": "+70454869250"}
0005433924231	64E6FD	0295 637876	VERA SAVELEVA	{"email": "vera.saveleva111973@postgrespro.ru", "phone": "+70281824525"}
0005433924232	64E6FD	4244 362158	RIMMA KUZNECOVA	{"email": "rimmakuznecova_06101970@postgrespro.ru", "phone": "+70845216655"}
0005433924233	31D3A8	6181 640732	NATALYA KRASNOVA	{"email": "krasnovan-081981@postgrespro.ru", "phone": "+70610548965"}
0005433924234	5CB6A8	3355 593761	OLGA NIKOLAEVA	{"email": "o.nikolaeva31051968@postgrespro.ru", "phone": "+70166845525"}
0005433924235	988F23	9390 340329	DIANA MAKAROVA	{"email": "d_makarova11021962@postgrespro.ru", "phone": "+70726919943"}
0005433924236	9F4FFF	9706 567244	NELLI VLASOVA	{"email": "vlasova_n20011963@postgrespro.ru", "phone": "+70232002653"}
0005433924237	D37186	9557 777910	ALEKSEY FEDOROV	{"email": "fedorov-aleksey_1963@postgrespro.ru", "phone": "+70446674728"}
0005433924238	D37186	5544 461295	MARIANNA IVANOVA	{"phone": "+70669793875"}
0005433924239	09F9A4	7218 706955	ANASTASIYA ISAEVA	{"phone": "+70030322995"}
0005433924240	BC4CFB	0038 751367	KIRILL GUSEV	{"email": "kirillgusev.1978@postgrespro.ru", "phone": "+70995725185"}
0005433924241	BC4CFB	0253 639973	VIKTOR NIKITIN	{"phone": "+70368055673"}
0005433924242	09395D	6995 570675	ANDREY MOROZOV	{"email": "andrey-morozov06101979@postgrespro.ru", "phone": "+70998394219"}
0005433924243	7E554B	0045 178349	OLGA TARASOVA	{"email": "tarasovaolga_16111964@postgrespro.ru", "phone": "+70566761638"}
0005433924244	2DDC65	3507 398931	NADEZHDA GRISHINA	{"email": "nadezhda-grishina_10121969@postgrespro.ru", "phone": "+70083038694"}
0005433924245	2DDC65	8130 097296	ALEKSEY KOROLEV	{"phone": "+70833830014"}
0005433924246	D29ED7	1254 700004	NATALYA KAZAKOVA	{"email": "n.kazakova-1977@postgrespro.ru", "phone": "+70223905407"}
0005433924247	9C6A4A	1617 151034	TAMARA NIKOLAEVA	{"email": "tamara.nikolaeva-1979@postgrespro.ru", "phone": "+70519462222"}
0005433924248	9C6A4A	3291 029125	NATALYA KUZNECOVA	{"phone": "+70900125239"}
0005433924249	1CAD97	4241 740242	LIDIYA KUZNECOVA	{"phone": "+70676044185"}
0005433924250	866004	3970 515336	ANATOLIY OSIPOV	{"email": "osipova1979@postgrespro.ru", "phone": "+70487195145"}
0005433924251	AFB380	2186 976216	VASILIY POPOV	{"email": "popov-v.041975@postgrespro.ru", "phone": "+70484409217"}
0005433924252	08D3DB	9535 457952	GEORGIY GRIGOREV	{"email": "georgiy_grigorev.091976@postgrespro.ru", "phone": "+70065574012"}
0005433924253	08D3DB	5758 672290	ZAKHAR AFANASEV	{"email": "z-afanasev_17021972@postgrespro.ru", "phone": "+70076805810"}
0005433924254	D5788E	0905 370031	VIKTOR MATVEEV	{"email": "matveevviktor_111971@postgrespro.ru", "phone": "+70563108134"}
0005433924255	5BDEF4	4991 069625	VIKTORIYA VOLKOVA	{"email": "volkova.v_1969@postgrespro.ru", "phone": "+70177181541"}
0005433924256	636D9D	6707 922257	ALEKSANDR EGOROV	{"email": "aegorov-28101968@postgrespro.ru", "phone": "+70980289694"}
0005433924257	636D9D	1622 917426	SERGEY NAZAROV	{"phone": "+70410036949"}
0005433924258	636D9D	4327 247337	VLADIMIR VOLKOV	{"phone": "+70634259287"}
0005433924259	7E1141	0668 226235	ELENA TIMOFEEVA	{"email": "timofeeva.e_091972@postgrespro.ru", "phone": "+70541306698"}
0005433924260	5A7D71	0567 910838	DMITRIY GORBUNOV	{"phone": "+70181917034"}
0005433924261	C4D187	4746 454516	OLGA CHERNOVA	{"email": "olga_chernova1979@postgrespro.ru", "phone": "+70302899903"}
0005433924262	C4D187	6475 226505	ALEKSANDRA IVANOVA	{"phone": "+70247981464"}
0005433924263	4CD95E	6657 491445	ALEKSANDR ILIN	{"email": "a.ilin-121966@postgrespro.ru", "phone": "+70414702466"}
0005433924264	511B09	2333 474136	VIKTOR NIKOLAEV	{"email": "nikolaevv_051973@postgrespro.ru", "phone": "+70292715623"}
0005433924265	511B09	2546 342241	MARINA KOZLOVA	{"email": "kozlova-marina-1962@postgrespro.ru", "phone": "+70677438449"}
0005433924266	180393	4833 597043	RUSTAM KISELEV	{"email": "kiselev.rustam-01091980@postgrespro.ru", "phone": "+70363497658"}
0005433924267	180393	8565 416758	ALEKSANDRA YAKOVLEVA	{"phone": "+70185177170"}
0005433924268	DF7FCC	7787 247042	VALENTINA FROLOVA	{"email": "vfrolova.1974@postgrespro.ru", "phone": "+70033493947"}
0005433924269	A9D39C	8140 676655	NATALYA IVANOVA	{"email": "ivanova-n-29061975@postgrespro.ru", "phone": "+70232859415"}
0005433924270	D3D642	5372 729752	VITALIY PAVLOV	{"email": "pavlov_vitaliy06111964@postgrespro.ru", "phone": "+70413568442"}
0005433924271	D3D642	1985 564391	ANDREY FILIPPOV	{"email": "filippov-andrey.02051965@postgrespro.ru", "phone": "+70499208591"}
0005433924272	1EC143	2302 174137	VLADIMIR MAKAROV	{"email": "vladimirmakarov-13051976@postgrespro.ru", "phone": "+70632122934"}
0005433924273	1EC143	6334 097160	IVAN VOLKOV	{"email": "volkovivan-1970@postgrespro.ru", "phone": "+70899067485"}
0005433924274	AC210D	5589 514819	LIDIYA SAVELEVA	{"phone": "+70289537566"}
0005433924275	AC210D	5160 050452	VYACHESLAV DMITRIEV	{"email": "dmitriev.v_1967@postgrespro.ru", "phone": "+70497587345"}
0005433924276	7FF1F2	6231 794061	VLADIMIR KARPOV	{"phone": "+70382492928"}
0005433924277	7FF1F2	6477 245542	EVGENIY MIKHAYLOV	{"email": "mikhaylove-1971@postgrespro.ru", "phone": "+70640296376"}
0005433924278	7FF1F2	2516 400363	OLEG STEPANOV	{"email": "stepanov_o-03011979@postgrespro.ru", "phone": "+70788747705"}
0005433924279	CB8217	4720 897192	ALEKSANDR DENISOV	{"email": "a_denisov-031974@postgrespro.ru", "phone": "+70246204452"}
0005433924280	EE42EE	3454 191349	KLAVDIYA OSIPOVA	{"email": "k-osipova-121971@postgrespro.ru", "phone": "+70939127769"}
0005433924281	EE42EE	4762 780690	NATALYA ZAYCEVA	{"phone": "+70912842973"}
0005433924282	721464	9055 583518	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov071969@postgrespro.ru", "phone": "+70112072036"}
0005433924283	CD1876	2312 396418	VYACHESLAV POPOV	{"phone": "+70106763974"}
0005433924284	BD1012	4762 828727	PAVEL ORLOV	{"email": "orlov_pavel28041976@postgrespro.ru", "phone": "+70857038563"}
0005433924285	BDA1AB	3359 146045	LIDIYA ZOTOVA	{"phone": "+70361645799"}
0005433924286	BDA1AB	9557 409126	NINA MIKHAYLOVA	{"phone": "+70632792288"}
0005433924287	ABE11B	0368 720633	ANNA AKIMOVA	{"email": "anna.akimova.17071976@postgrespro.ru", "phone": "+70897763892"}
0005433924288	F504A7	7758 793967	LYUBOV NAZAROVA	{"phone": "+70645926866"}
0005433924289	96687A	1057 176352	YULIYA ZAKHAROVA	{"phone": "+70904237409"}
0005433924290	B3FF24	8158 495888	NIKOLAY EGOROV	{"email": "egorov-n_30041974@postgrespro.ru", "phone": "+70485696101"}
0005433924291	A32DA0	2973 381048	MARIYA POPOVA	{"email": "m_popova.1976@postgrespro.ru", "phone": "+70549389050"}
0005433924292	A0B02B	6207 541222	SERGEY MOISEEV	{"email": "moiseev-sergey091974@postgrespro.ru", "phone": "+70723635143"}
0005433924293	A0B02B	2269 182935	ALEKSANDR GORBUNOV	{"phone": "+70885017198"}
0005433924294	AD6438	0626 016430	RINAT FOMIN	{"email": "fominrinat1983@postgrespro.ru", "phone": "+70969830196"}
0005433924295	AD6438	6243 977967	MIKHAIL BORISOV	{"phone": "+70684161242"}
0005433924296	AD6438	3718 961413	MARIANNA ISAEVA	{"email": "misaeva.061958@postgrespro.ru", "phone": "+70383784547"}
0005433924297	D33164	1464 426889	VALERIY ILIN	{"phone": "+70423652100"}
0005433924298	A68804	2996 019394	NADEZHDA AKIMOVA	{"email": "akimova-n-06011983@postgrespro.ru", "phone": "+70535614075"}
0005433924299	A68804	1685 819729	NATALYA FILATOVA	{"phone": "+70239307423"}
0005433924300	DD9D97	7903 723054	NIKOLAY SMIRNOV	{"phone": "+70484562970"}
0005433924301	A545EA	7109 054788	INESSA ANDREEVA	{"phone": "+70689720224"}
0005433924302	A545EA	4101 398488	MARINA SOROKINA	{"phone": "+70095083353"}
0005433924303	0B705A	0057 542232	VALENTIN BONDARENKO	{"email": "bondarenko_v-061970@postgrespro.ru", "phone": "+70280005066"}
0005433924304	CC9542	2192 501029	VLADIMIR PETROV	{"email": "v_petrov_031971@postgrespro.ru", "phone": "+70919654672"}
0005433924305	E7CB4A	4968 024832	DANILA SOKOLOV	{"phone": "+70013718529"}
0005433924306	E7CB4A	6813 710834	OKSANA VASILEVA	{"email": "o_vasileva.1980@postgrespro.ru", "phone": "+70837979251"}
0005433924307	AE9383	7714 276119	SVETLANA NIKITINA	{"email": "nikitina_svetlana111973@postgrespro.ru", "phone": "+70775871097"}
0005433924308	263FFF	8272 707739	ANFISA ERMAKOVA	{"email": "ermakova.a.101987@postgrespro.ru", "phone": "+70028457046"}
0005433924309	140743	1419 670981	ANNA SIDOROVA	{"email": "annasidorova.071975@postgrespro.ru", "phone": "+70893164457"}
0005433924310	140743	0854 519181	ARTEM VOROBEV	{"phone": "+70692655022"}
0005433924311	18E789	6662 601075	KLAVDIYA SEMENOVA	{"email": "klavdiya.semenova_1976@postgrespro.ru", "phone": "+70382728381"}
0005433924312	18E789	7155 520199	DANILA SOKOLOV	{"phone": "+70851727343"}
0005433924313	30EB70	7862 978464	ARSENIY ANDREEV	{"phone": "+70656828240"}
0005433924314	BDD6EF	4656 019667	DARYA KUZNECOVA	{"email": "dkuznecova-29091978@postgrespro.ru", "phone": "+70894738544"}
0005433924315	95BAE7	2130 084129	PETR KUDRYASHOV	{"email": "kudryashov-p.09041975@postgrespro.ru", "phone": "+70401088195"}
0005433924316	46C836	6415 880599	DAMIR FEDOROV	{"email": "damir-fedorov.31121964@postgrespro.ru", "phone": "+70045079755"}
0005433924317	E58596	6875 678372	DARYA SOKOLOVA	{"phone": "+70524629922"}
0005433924318	A8C041	8828 025038	ALINA TIMOFEEVA	{"phone": "+70452128018"}
0005433924319	1C6233	7778 676682	KONSTANTIN KUZNECOV	{"email": "k.kuznecov_30101970@postgrespro.ru", "phone": "+70905261326"}
0005433924320	23F65A	6391 986524	ROMAN FOMIN	{"phone": "+70773368837"}
0005433924321	A6989C	9130 397092	ALEKSEY KUDRYASHOV	{"phone": "+70876824171"}
0005433924322	ABA29D	5780 961817	VIKTOR MOISEEV	{"email": "viktormoiseev_081967@postgrespro.ru", "phone": "+70966911372"}
0005433924323	ABA29D	4338 096565	RAISA MARTYNOVA	{"email": "martynova-raisa_1985@postgrespro.ru", "phone": "+70378633003"}
0005433924324	2C11BC	1477 117517	OKSANA FILIPPOVA	{"email": "o-filippova_08021963@postgrespro.ru", "phone": "+70532124494"}
0005433924325	2C11BC	4758 174874	VLADIMIR FEDOROV	{"email": "vladimirfedorov_1971@postgrespro.ru", "phone": "+70741470313"}
0005433924326	EF8582	5459 510542	MARAT FILIPPOV	{"email": "mfilippov041978@postgrespro.ru", "phone": "+70366049619"}
0005433924327	A89DFC	0725 343381	ANNA POPOVA	{"phone": "+70862669852"}
0005433924328	A89DFC	8562 926237	ANNA ANDREEVA	{"phone": "+70021029678"}
0005433924329	93A4AC	7876 129639	ALEKSEY EGOROV	{"phone": "+70494558717"}
0005433924330	F79E27	4480 510868	ALEKSANDR VLASOV	{"phone": "+70093414215"}
0005433924331	F79E27	3231 632020	VERONIKA KUDRYASHOVA	{"phone": "+70342466835"}
0005433924332	8EE8D9	6322 733002	IRINA ANTONOVA	{"phone": "+70847522140"}
0005433924333	8EE8D9	0912 022433	OLGA ZAYCEVA	{"phone": "+70622716980"}
0005433924334	A5E645	4142 592014	EKATERINA VOLKOVA	{"phone": "+70578250686"}
0005433924335	A5E645	6466 890482	ALEKSANDR POPOV	{"phone": "+70505290537"}
0005433924336	1957B1	8230 563036	SVETLANA SEMENOVA	{"email": "svetlana-semenova-03111966@postgrespro.ru", "phone": "+70318032269"}
0005433924337	C2E01B	3697 913683	YULIYA GERASIMOVA	{"email": "y-gerasimova-1978@postgrespro.ru", "phone": "+70167811522"}
0005433924338	791894	5769 108349	NINA VOLKOVA	{"phone": "+70287881389"}
0005433924339	791894	8739 752029	NADEZHDA KAZAKOVA	{"email": "kazakovan1968@postgrespro.ru", "phone": "+70699208028"}
0005433924340	814F28	8233 039847	TATYANA ANDREEVA	{"phone": "+70553973134"}
0005433924341	1C6D7B	8041 248216	VLADISLAV DENISOV	{"email": "vladislav_denisov_1967@postgrespro.ru", "phone": "+70009226435"}
0005433924342	1C6D7B	6516 683445	NIKOLAY PAVLOV	{"phone": "+70434159432"}
0005433924343	8F1F70	6035 309776	ARTEM GUSEV	{"email": "gusev.artem_061970@postgrespro.ru", "phone": "+70658338130"}
0005433924344	FCBE01	7633 245461	ANTONINA POTAPOVA	{"email": "a-potapova.05011968@postgrespro.ru", "phone": "+70428269202"}
0005433924345	8A1533	3095 388827	YURIY IVANOV	{"phone": "+70380691627"}
0005433924346	8A1533	1355 161659	ILYA MIKHAYLOV	{"email": "ilyamikhaylov.17121972@postgrespro.ru", "phone": "+70007094930"}
0005433924347	BED98A	1003 587292	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev20051973@postgrespro.ru", "phone": "+70041518054"}
0005433924348	C68F91	9421 406592	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev041986@postgrespro.ru", "phone": "+70277482615"}
0005433924349	082ADE	6866 367419	DMITRIY RODIONOV	{"phone": "+70757020090"}
0005433924350	3584C2	5870 482318	LEYLA ZAKHAROVA	{"phone": "+70246884679"}
0005433924351	3584C2	9080 678916	OKSANA VLASOVA	{"email": "vlasova.oksana.1966@postgrespro.ru", "phone": "+70017422395"}
0005433924352	7ACBF1	3113 845466	ALEKSANDR KONOVALOV	{"phone": "+70635721182"}
0005433924353	404B5F	0019 598250	VALENTINA ZAYCEVA	{"email": "zayceva-valentina.1965@postgrespro.ru", "phone": "+70230803858"}
0005433924354	8313AE	7721 783810	VASILIY PETROV	{"phone": "+70955012396"}
0005433924355	1A235A	3580 847329	OLEG KONOVALOV	{"email": "konovalov.o-15011968@postgrespro.ru", "phone": "+70574989020"}
0005433924356	1A235A	1282 055331	MARIYA PAVLOVA	{"email": "mariyapavlova_1962@postgrespro.ru", "phone": "+70174124435"}
0005433924357	94D7AB	4604 940777	OLGA ALEKSEEVA	{"phone": "+70691869058"}
0005433924358	36E7D2	6329 720653	ANTONINA POPOVA	{"email": "apopova061965@postgrespro.ru", "phone": "+70285117481"}
0005433924359	B44A3E	3344 831507	SHAMIL MAKSIMOV	{"email": "maksimov-shamil_011971@postgrespro.ru", "phone": "+70635931820"}
0005433924360	26B1B8	6773 282322	VLADIMIR ISAEV	{"email": "vladimir-isaev_16021976@postgrespro.ru", "phone": "+70640811499"}
0005433924361	027B53	7908 270235	IVAN SAVELEV	{"phone": "+70930548512"}
0005433924362	A941AF	5738 617943	OLGA NOVIKOVA	{"phone": "+70885533029"}
0005433924363	A941AF	3224 923060	ANASTASIYA SIDOROVA	{"email": "anastasiyasidorova011971@postgrespro.ru", "phone": "+70221952544"}
0005433924364	44B817	7773 344784	IRINA MELNIKOVA	{"phone": "+70938593543"}
0005433924365	44B817	1137 004816	TATYANA ZAKHAROVA	{"phone": "+70577164747"}
0005433924366	427F4F	7230 473716	TATYANA TIMOFEEVA	{"phone": "+70816996582"}
0005433924367	84EBFA	8350 679327	VALENTINA IVANOVA	{"phone": "+70906859165"}
0005433924368	A47462	7760 219404	VALENTINA MASLOVA	{"email": "valentinamaslova_011970@postgrespro.ru", "phone": "+70103299978"}
0005433924369	A47462	8566 963889	MIKHAIL ZAYCEV	{"email": "zaycev.m_071978@postgrespro.ru", "phone": "+70621576079"}
0005433924370	B63970	2142 599415	ALEKSEY IVANOV	{"phone": "+70264634330"}
0005433924371	72D3AA	3346 191561	ALEKSANDR PETROV	{"phone": "+70665338538"}
0005433924372	5216E5	5479 530227	ANASTASIYA MAKAROVA	{"phone": "+70980049787"}
0005433924373	5216E5	3087 733330	NIKOLAY VASILEV	{"email": "vasilevnikolay_22121973@postgrespro.ru", "phone": "+70519308708"}
0005433924374	46A075	1960 604304	ELENA NAUMOVA	{"email": "naumova-elena-1974@postgrespro.ru", "phone": "+70484128680"}
0005433924375	AEBBD3	2350 483620	LILIYA ANTONOVA	{"email": "antonova.liliya_25081963@postgrespro.ru", "phone": "+70954316242"}
0005433924376	56E0C4	7819 870138	BORIS MOROZOV	{"email": "morozov-b.1981@postgrespro.ru", "phone": "+70289183655"}
0005433924377	2BD3AC	2220 934863	SVETLANA MOROZOVA	{"phone": "+70829199559"}
0005433924378	2BD3AC	2108 714787	VLADISLAV MOROZOV	{"email": "v_morozov_04071974@postgrespro.ru", "phone": "+70038558593"}
0005433924379	CD780F	0154 609435	MARIYA ALEKSEEVA	{"phone": "+70265896714"}
0005433924380	CD780F	4380 185268	ELMIRA NAZAROVA	{"phone": "+70189958784"}
0005433924381	53D929	7604 541870	VYACHESLAV ZHUKOV	{"email": "zhukovvyacheslav1978@postgrespro.ru", "phone": "+70023016059"}
0005433924382	513F1D	2809 000048	MARAT ORLOV	{"email": "m-orlov-1968@postgrespro.ru", "phone": "+70005880121"}
0005433924383	EE177E	9946 945517	VIKTOR NAZAROV	{"email": "nazarov_viktor1970@postgrespro.ru", "phone": "+70952717064"}
0005433924384	CC87C8	4260 704057	ELENA ZAKHAROVA	{"phone": "+70429350107"}
0005433924385	2BDC77	1111 818903	DMITRIY KUZMIN	{"email": "d_kuzmin.18061979@postgrespro.ru", "phone": "+70160175963"}
0005433924386	99CDBE	2181 306924	ANASTASIYA ILINA	{"email": "ilina-anastasiya.1970@postgrespro.ru", "phone": "+70973776351"}
0005433924387	4DD854	5665 403042	ALEKSANDR NOVIKOV	{"email": "a_novikov_1978@postgrespro.ru", "phone": "+70291444573"}
0005433924388	D9F3FD	6756 737701	ALEKSANDR FEDOROV	{"phone": "+70002163113"}
0005433924389	96C21D	0680 766383	STANISLAV KOZLOV	{"email": "kozlov-stanislav.1962@postgrespro.ru", "phone": "+70626413468"}
0005433924390	96C21D	3197 363998	IGOR POPOV	{"email": "igorpopov-1971@postgrespro.ru", "phone": "+70668487344"}
0005433924391	5273E4	4593 714441	RINAT KUZMIN	{"phone": "+70501253284"}
0005433924392	CCA94D	5353 916443	IRINA LEBEDEVA	{"phone": "+70995983190"}
0005433924393	64B2E5	7902 106618	KONSTANTIN MATVEEV	{"email": "matveev-konstantin-071982@postgrespro.ru", "phone": "+70991134877"}
0005433924394	64B2E5	6669 201223	VLADIMIR STEPANOV	{"phone": "+70169585495"}
0005433924395	5044D1	3518 104710	ANASTASIYA POLYAKOVA	{"phone": "+70478030906"}
0005433924396	669FFA	5963 220542	LIDIYA MOISEEVA	{"email": "moiseeva-l1971@postgrespro.ru", "phone": "+70608806047"}
0005433924397	669FFA	1790 095564	LYUDMILA IVANOVA	{"email": "l_ivanova_091976@postgrespro.ru", "phone": "+70874438394"}
0005433924398	8CDCB9	3718 586288	NIKOLAY SOKOLOV	{"email": "sokolov.n-1971@postgrespro.ru", "phone": "+70982702185"}
0005433924399	E9EDEC	8215 177109	MARIYA KONOVALOVA	{"email": "konovalova.mariya1975@postgrespro.ru", "phone": "+70994582775"}
0005433924400	E9EDEC	8971 154824	MARIYA NOVIKOVA	{"email": "novikovamariya.26041964@postgrespro.ru", "phone": "+70785792978"}
0005433924401	6279F2	7695 776876	DANIL KRASNOV	{"phone": "+70950491653"}
0005433924402	E2DC08	7718 107981	MIKHAIL PAVLOV	{"email": "pavlov.mikhail_011979@postgrespro.ru", "phone": "+70812599420"}
0005433924403	FF5E88	8242 219048	ANATOLIY ORLOV	{"phone": "+70644203537"}
0005433924404	154107	4125 444870	ALEKSANDR KUZNECOV	{"phone": "+70742285007"}
0005433924405	073C60	2600 218296	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr-011979@postgrespro.ru", "phone": "+70783948689"}
0005433924406	3A87C6	2220 612350	PAVEL MOISEEV	{"phone": "+70094277612"}
0005433924407	3A87C6	0651 182223	ANDREY EGOROV	{"email": "egorov.a1980@postgrespro.ru", "phone": "+70248101745"}
0005433924408	15CC8D	0157 822985	ALEKSANDRA MARTYNOVA	{"phone": "+70207346380"}
0005433924409	15CC8D	0447 690405	VLADIMIR BELOV	{"email": "belov.v_15081973@postgrespro.ru", "phone": "+70883488429"}
0005433924410	8EE497	0209 070940	ALEKSANDR NIKOLAEV	{"phone": "+70889377308"}
0005433924411	90C50B	4357 405207	VLADIMIR MEDVEDEV	{"email": "medvedevv_18021962@postgrespro.ru", "phone": "+70872370519"}
0005433924412	90C50B	4167 071855	ELENA DAVYDOVA	{"phone": "+70318108718"}
0005433924413	B619A0	6307 002503	VIKTOR VASILEV	{"phone": "+70854582779"}
0005433924414	B619A0	2719 015048	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov16051973@postgrespro.ru", "phone": "+70032657364"}
0005433924415	B619A0	8029 172885	DZHAMILYA KUZNECOVA	{"email": "kuznecova-dzhamilya.041971@postgrespro.ru", "phone": "+70718519871"}
0005433924416	3D997D	9145 051555	ANNA ZAKHAROVA	{"email": "anna.zakharova.1983@postgrespro.ru", "phone": "+70297384525"}
0005433924417	16B027	0414 160303	OKSANA MARTYNOVA	{"email": "o.martynova081964@postgrespro.ru", "phone": "+70359531323"}
0005433924585	7C9827	1209 377200	GALINA GERASIMOVA	{"phone": "+70540828430"}
0005433924418	CFBC03	3648 548809	VLADISLAV FROLOV	{"email": "vladislav-frolov-1972@postgrespro.ru", "phone": "+70634692618"}
0005433924419	32C202	4340 676445	ELENA DAVYDOVA	{"phone": "+70632375968"}
0005433924420	A2D2D8	1931 358974	RAISA OVCHINNIKOVA	{"email": "raisa_ovchinnikova.09011968@postgrespro.ru", "phone": "+70570815906"}
0005433924421	ABE76E	7204 232065	VIKTOR CHERNOV	{"email": "v_chernov-1974@postgrespro.ru", "phone": "+70789673967"}
0005433924422	6BE2C7	4725 012766	SERGEY DMITRIEV	{"email": "dmitriev.sergey-13101977@postgrespro.ru", "phone": "+70814199256"}
0005433924423	904B58	1485 469699	OLGA NESTEROVA	{"phone": "+70746275625"}
0005433924424	B39F58	4114 893234	ALEKSANDRA MELNIKOVA	{"phone": "+70500143535"}
0005433924425	0B5D35	5356 695806	DMITRIY BARANOV	{"email": "baranov_dmitriy.071976@postgrespro.ru", "phone": "+70673823801"}
0005433924426	EBFCB9	6303 163663	NURIYA SIDOROVA	{"email": "sidorova-nuriya-1972@postgrespro.ru", "phone": "+70857515007"}
0005433924427	EBFCB9	1779 774794	KLAVDIYA VOLKOVA	{"email": "volkovaklavdiya_15111976@postgrespro.ru", "phone": "+70056644423"}
0005433924428	937F87	7109 206436	DMITRIY RODIONOV	{"phone": "+70646636839"}
0005433924429	937F87	6974 737762	RAISA NAUMOVA	{"email": "r_naumova.081982@postgrespro.ru", "phone": "+70646266404"}
0005433924430	443CA5	5690 331017	BORIS BORISOV	{"email": "borisov.boris_01121963@postgrespro.ru", "phone": "+70347079090"}
0005433924431	443CA5	3562 160139	NATALYA FROLOVA	{"email": "nfrolova_1972@postgrespro.ru", "phone": "+70464295025"}
0005433924432	91F232	7471 920534	IGOR ANTONOV	{"email": "i-antonov-14111974@postgrespro.ru", "phone": "+70588885445"}
0005433924433	9BDF6A	8493 832765	VIKTORIYA ROMANOVA	{"email": "v-romanova1985@postgrespro.ru", "phone": "+70665657641"}
0005433924434	90FFE8	6295 561033	OLGA MOROZOVA	{"phone": "+70814402072"}
0005433924435	90FFE8	4232 969177	KRISTINA LAZAREVA	{"email": "kristina-lazareva-081982@postgrespro.ru", "phone": "+70736185703"}
0005433924436	B1A300	1057 366202	MARIYA SCHERBAKOVA	{"email": "m.scherbakova_111980@postgrespro.ru", "phone": "+70629925720"}
0005433924437	B1A300	8895 772888	OLGA POPOVA	{"phone": "+70942741118"}
0005433924438	EDB5A1	5084 994381	TATYANA ZHURAVLEVA	{"email": "tzhuravleva_05101975@postgrespro.ru", "phone": "+70792554400"}
0005433924439	EDB5A1	5043 495335	RAFAIL KULIKOV	{"email": "kulikov.rafail.13101976@postgrespro.ru", "phone": "+70166707764"}
0005433924440	B52333	0854 124299	ANNA EGOROVA	{"email": "a_egorova25071970@postgrespro.ru", "phone": "+70613213389"}
0005433924441	BB5D20	1155 979919	ELENA MAKSIMOVA	{"email": "maksimova_elena.1978@postgrespro.ru", "phone": "+70470716536"}
0005433924442	BB5D20	4671 472623	DMITRIY SHEVCHENKO	{"phone": "+70382157184"}
0005433924443	A8226E	6151 129483	SVETLANA MARTYNOVA	{"email": "martynova_svetlana.031972@postgrespro.ru", "phone": "+70976390989"}
0005433924444	B8274D	8609 265523	ROMAN GAVRILOV	{"email": "gavrilov-r_1976@postgrespro.ru", "phone": "+70704074535"}
0005433924445	B8274D	8868 155542	ALEKSEY SEMENOV	{"email": "alekseysemenov-021955@postgrespro.ru", "phone": "+70613360227"}
0005433924446	8E25F1	0403 551202	GALINA VOLKOVA	{"email": "g-volkova.16081971@postgrespro.ru", "phone": "+70544909367"}
0005433924447	A100A6	4090 767833	RAISA OVCHINNIKOVA	{"phone": "+70888169528"}
0005433924448	859883	3909 178013	SVETLANA ANDREEVA	{"phone": "+70408268209"}
0005433924449	859883	7298 033431	VALERIY POPOV	{"phone": "+70693510149"}
0005433924450	B07122	8058 571695	PETR SOLOVEV	{"phone": "+70595639502"}
0005433924451	977D3E	8302 897378	ANATOLIY KUDRYASHOV	{"phone": "+70508054106"}
0005433924452	9B3939	8524 089013	OLESYA NIKOLAEVA	{"email": "olesya.nikolaeva19081967@postgrespro.ru", "phone": "+70508430992"}
0005433924453	90D261	1887 162254	IGOR KAZAKOV	{"email": "i.kazakov-1965@postgrespro.ru", "phone": "+70261264213"}
0005433924454	90D261	1933 570362	VASILIY FOMIN	{"phone": "+70691930736"}
0005433924455	90D261	4381 688384	STANISLAV BARANOV	{"email": "s.baranov_091967@postgrespro.ru", "phone": "+70920126886"}
0005433924456	7EEDA7	2191 767405	ELENA MAKAROVA	{"email": "makarova.e.04061981@postgrespro.ru", "phone": "+70153065325"}
0005433924457	7EEDA7	9437 598817	TATYANA POPOVA	{"phone": "+70168876778"}
0005433924458	55E717	7561 701862	VLADIMIR TARASOV	{"email": "v_tarasov.051964@postgrespro.ru", "phone": "+70643075574"}
0005433924459	4F98AB	6996 207650	OLGA PAVLOVA	{"phone": "+70128785716"}
0005433924460	32FFD8	3626 829365	ANDREY IVANOV	{"email": "andrey.ivanov.04071975@postgrespro.ru", "phone": "+70308519924"}
0005433924461	32FFD8	2726 754921	MARIYA EFREMOVA	{"email": "m.efremova.081971@postgrespro.ru", "phone": "+70666522813"}
0005433924462	CF31C5	8920 790648	ELENA LOGINOVA	{"email": "elena.loginova_021967@postgrespro.ru", "phone": "+70422290563"}
0005433924463	C7CEA9	6994 456799	VALENTINA YUDINA	{"email": "yudina-v.1968@postgrespro.ru", "phone": "+70184057626"}
0005433924464	C7CEA9	9213 824420	DMITRIY KUZMIN	{"phone": "+70930269403"}
0005433924465	C7CEA9	9650 197101	ANATOLIY AFANASEV	{"email": "afanasev.a1980@postgrespro.ru", "phone": "+70145635414"}
0005433924466	E771EC	3141 100055	GENNADIY VOLKOV	{"phone": "+70401154681"}
0005433924467	E771EC	5137 863173	ANTON KUDRYASHOV	{"phone": "+70175105170"}
0005433924468	58B1D9	1067 412206	SVETLANA MOISEEVA	{"phone": "+70200707373"}
0005433924469	58B1D9	5473 208603	OLGA KRASNOVA	{"phone": "+70892449501"}
0005433924470	54869C	2188 881446	NINA BORISOVA	{"email": "borisova-n_121971@postgrespro.ru", "phone": "+70366456905"}
0005433924471	58D2B5	4037 168510	OLGA LAZAREVA	{"phone": "+70980318562"}
0005433924472	FD76E5	8212 825506	YULIYA ISAEVA	{"phone": "+70459780636"}
0005433924473	D6F946	6909 121999	VALENTINA OVCHINNIKOVA	{"email": "valentina_ovchinnikova-1971@postgrespro.ru", "phone": "+70598636409"}
0005433924474	D6F946	6148 708244	SERGEY NOVIKOV	{"phone": "+70596563750"}
0005433924475	1018BC	9516 275935	ALEKSANDR KONOVALOV	{"phone": "+70158492680"}
0005433924476	A3FDA7	2881 142750	ALEKSANDR ANDREEV	{"email": "a.andreev-061970@postgrespro.ru", "phone": "+70547476587"}
0005433924477	714FBA	7199 457837	ELENA MOROZOVA	{"email": "e-morozova.09101984@postgrespro.ru", "phone": "+70194774692"}
0005433924478	714FBA	0418 745822	SERGEY MAKSIMOV	{"email": "s-maksimov-071984@postgrespro.ru", "phone": "+70454095079"}
0005433924479	566C7F	7509 389367	IVAN GUSEV	{"email": "ivangusev101966@postgrespro.ru", "phone": "+70666297413"}
0005433924480	A40CFE	5976 519240	MARIYA MARTYNOVA	{"email": "martynovam051974@postgrespro.ru", "phone": "+70470446127"}
0005433924481	66CDAF	0371 228771	NATALYA TIKHONOVA	{"email": "tikhonova-n.05051974@postgrespro.ru", "phone": "+70474819380"}
0005433924482	66CDAF	8255 909264	ANASTASIYA MATVEEVA	{"phone": "+70110139216"}
0005433924483	676C8B	0382 099169	NIKOLAY AFANASEV	{"phone": "+70698493783"}
0005433924484	C39AD5	8827 067924	ANATOLIY KONOVALOV	{"phone": "+70162213650"}
0005433924485	B8C07B	7261 827819	MIKHAIL VOLKOV	{"email": "m-volkov.26041971@postgrespro.ru", "phone": "+70005630950"}
0005433924486	B8C07B	5343 996070	INNA KULIKOVA	{"email": "kulikova.inna_1968@postgrespro.ru", "phone": "+70446050737"}
0005433924487	C2F17D	6111 527783	OKSANA KOZLOVA	{"phone": "+70059654000"}
0005433924488	D6177E	4800 159386	EKATERINA GUSEVA	{"phone": "+70766060884"}
0005433924489	AADEF4	3847 215053	VIKTORIYA GERASIMOVA	{"email": "viktoriya_gerasimova-10021976@postgrespro.ru", "phone": "+70164365218"}
0005433924490	3CC69F	2474 889239	DMITRIY CHERNOV	{"email": "chernovdmitriy_061974@postgrespro.ru", "phone": "+70280344010"}
0005433924491	A1B957	9715 583232	TATYANA SMIRNOVA	{"email": "smirnovatatyana.021974@postgrespro.ru", "phone": "+70613657759"}
0005433924492	13ECA1	4059 711598	SERGEY DAVYDOV	{"email": "davydov.s.1972@postgrespro.ru", "phone": "+70461141393"}
0005433924493	07A0ED	2155 088591	EVGENIY ALEKSEEV	{"phone": "+70300797945"}
0005433924494	C0C44E	4850 546651	ANATOLIY MARTYNOV	{"email": "martynov-anatoliy_1968@postgrespro.ru", "phone": "+70437612184"}
0005433924495	C0C44E	9077 224227	NATALYA FOMINA	{"email": "n_fomina.091982@postgrespro.ru", "phone": "+70509914895"}
0005433924496	EB0D75	4681 164313	VLADIMIR MOROZOV	{"phone": "+70672140495"}
0005433924497	EB0D75	2102 204907	VALENTINA NIKITINA	{"email": "nikitinavalentina_1964@postgrespro.ru", "phone": "+70793304975"}
0005433924498	60B9EA	8821 734403	VERA MELNIKOVA	{"phone": "+70074702695"}
0005433924499	6D7DF4	9389 537287	VARVARA ZAYCEVA	{"phone": "+70226924561"}
0005433924500	6D7DF4	2516 016381	SERGEY ALEKSEEV	{"email": "alekseevs-09071974@postgrespro.ru", "phone": "+70883783215"}
0005433924501	7725CD	8707 165312	EVGENIYA FILIPPOVA	{"email": "evgeniyafilippova121979@postgrespro.ru", "phone": "+70697800547"}
0005433924502	7725CD	2063 059411	SVETLANA EGOROVA	{"phone": "+70805761843"}
0005433924503	507483	6143 704715	NATALYA MAKAROVA	{"phone": "+70250982386"}
0005433924504	A60622	9613 436208	TATYANA CHERNOVA	{"phone": "+70903908765"}
0005433924505	962C93	6482 815625	PETR KARPOV	{"email": "karpovpetr_031976@postgrespro.ru", "phone": "+70609643018"}
0005433924506	8077B4	7886 455917	ANZHELA ZAKHAROVA	{"email": "zakharova_a-1957@postgrespro.ru", "phone": "+70881071532"}
0005433924507	8077B4	7921 025046	NADEZHDA SIDOROVA	{"email": "sidorova-nadezhda_16041979@postgrespro.ru", "phone": "+70164523199"}
0005433924508	DB2ACE	9148 582675	EKATERINA FILIPPOVA	{"phone": "+70562917540"}
0005433924509	DB2ACE	7668 516895	GALINA PAVLOVA	{"email": "galina_pavlova_20021974@postgrespro.ru", "phone": "+70161041572"}
0005433924510	9804C7	0856 267223	MARIYA YAKOVLEVA	{"email": "yakovleva-mariya_1982@postgrespro.ru", "phone": "+70802446555"}
0005433924511	9804C7	5353 081949	TATYANA KRASNOVA	{"phone": "+70311085538"}
0005433924512	2F0CB1	9334 393775	ULYANA TARASOVA	{"phone": "+70017594968"}
0005433924513	2F0CB1	3025 379412	EVGENIY MELNIKOV	{"email": "evgeniymelnikov1973@postgrespro.ru", "phone": "+70330767772"}
0005433924514	2C4B37	9701 870685	VYACHESLAV SERGEEV	{"email": "sergeev-vyacheslav_1954@postgrespro.ru", "phone": "+70563622405"}
0005433924515	A75FEC	4698 244987	OLESYA GUSEVA	{"email": "o.guseva1969@postgrespro.ru", "phone": "+70944544937"}
0005433924516	54B7BB	8613 923223	SERGEY FILIPPOV	{"phone": "+70060881369"}
0005433924517	50EB0E	7919 717995	IVAN KOZLOV	{"phone": "+70752642971"}
0005433924518	B20513	3519 850129	PRASKOVYA SOKOLOVA	{"email": "sokolova_p26121968@postgrespro.ru", "phone": "+70680935968"}
0005433924519	581907	1222 586479	EKATERINA ROMANOVA	{"email": "romanova_ekaterina-041981@postgrespro.ru", "phone": "+70809919230"}
0005433924520	E8F5CE	0474 676678	VLADIMIR KUZNECOV	{"phone": "+70324862114"}
0005433924521	9BAEA4	7630 879876	ALEKSANDR MOISEEV	{"email": "moiseev-a.1959@postgrespro.ru", "phone": "+70398235988"}
0005433924522	427880	2564 870188	VIKTOR FILIPPOV	{"phone": "+70148246478"}
0005433924523	427880	0640 285776	DARYA VASILEVA	{"email": "d_vasileva-1970@postgrespro.ru", "phone": "+70453269162"}
0005433924524	F16C6F	8701 153637	IRINA PETROVA	{"phone": "+70507071241"}
0005433924525	4A869F	3677 780613	NINA BOGDANOVA	{"phone": "+70666755584"}
0005433924526	527E74	2890 760249	YURIY ANTONOV	{"phone": "+70195422841"}
0005433924584	7C9827	1598 567006	MARINA KOROLEVA	{"phone": "+70405979074"}
0005433924865	08882A	2639 918812	DMITRIY EGOROV	{"phone": "+70400721346"}
0005433924527	527E74	6639 486949	EVGENIY SIDOROV	{"email": "sidorov.evgeniy_1972@postgrespro.ru", "phone": "+70273949268"}
0005433924528	527E74	0500 720057	NIKOLAY NIKOLAEV	{"email": "n_nikolaev08081955@postgrespro.ru", "phone": "+70209380341"}
0005433924529	69B335	2916 855402	MIKHAIL PETROV	{"email": "petrovm01011971@postgrespro.ru", "phone": "+70197148174"}
0005433924530	F68907	3250 265211	ELENA VOROBEVA	{"email": "vorobeva-e-28081976@postgrespro.ru", "phone": "+70210905901"}
0005433924531	D9556F	7517 043935	LEONID SOLOVEV	{"email": "l-solovev-091973@postgrespro.ru", "phone": "+70752812583"}
0005433924532	D9556F	0777 599108	ANDREY ILIN	{"phone": "+70863857123"}
0005433924533	937A88	6905 895120	ANATOLIY KUZNECOV	{"phone": "+70614330681"}
0005433924534	937A88	9105 414718	IRINA IVANOVA	{"email": "ivanova-i_1965@postgrespro.ru", "phone": "+70815777531"}
0005433924535	BC9CFB	4544 499284	ANDREY DAVYDOV	{"phone": "+70973937906"}
0005433924536	908136	0400 546149	INNA EFREMOVA	{"phone": "+70408177391"}
0005433924537	5FD9FD	6781 451071	TATYANA VOLKOVA	{"email": "volkova_tatyana-13021971@postgrespro.ru", "phone": "+70262404997"}
0005433924538	679E9E	6001 967673	VLADIMIR SOKOLOV	{"phone": "+70741352939"}
0005433924539	BCD690	2859 597236	IRINA POPOVA	{"email": "popova-i.30111972@postgrespro.ru", "phone": "+70526789396"}
0005433924540	A13246	8956 791349	ELENA PETROVA	{"email": "petrova_e-1975@postgrespro.ru", "phone": "+70832091316"}
0005433924541	978E72	9185 086746	OLEG VOROBEV	{"phone": "+70808697304"}
0005433924542	978E72	7903 908469	ANASTASIYA MAKAROVA	{"email": "makarova_a-091964@postgrespro.ru", "phone": "+70634035435"}
0005433924543	978E72	5506 455335	LYUDMILA KUZNECOVA	{"phone": "+70578779609"}
0005433924544	ACD496	4945 880876	SVETLANA FOMINA	{"email": "fomina-svetlana-1982@postgrespro.ru", "phone": "+70552472465"}
0005433924545	3A0E39	4489 776105	ELENA OSIPOVA	{"phone": "+70703933235"}
0005433924546	3A0E39	0637 153024	ALEKSANDR PAVLOV	{"email": "a_pavlov-18111964@postgrespro.ru", "phone": "+70067491896"}
0005433924547	25C03C	3485 693558	ANASTASIYA OSIPOVA	{"phone": "+70527757413"}
0005433924548	30D8E1	5255 886420	ALEKSANDRA BOGDANOVA	{"email": "bogdanova.aleksandra071979@postgrespro.ru", "phone": "+70046780183"}
0005433924549	AAB0DE	9954 506997	EVGENIY MOROZOV	{"phone": "+70409006991"}
0005433924550	A20DA0	1240 838568	NATALYA FROLOVA	{"email": "nfrolova.071975@postgrespro.ru", "phone": "+70766349839"}
0005433924551	F5EB6A	3566 633030	DMITRIY NOVIKOV	{"phone": "+70824499637"}
0005433924552	F5EB6A	0412 971871	ANDREY GUSEV	{"email": "gusev-a_06071970@postgrespro.ru", "phone": "+70333030732"}
0005433924553	6DA04B	0671 734592	ALEKSEY GAVRILOV	{"email": "a_gavrilov_27071977@postgrespro.ru", "phone": "+70282567851"}
0005433924554	6DA04B	1582 156685	DENIS VASILEV	{"phone": "+70115911766"}
0005433924555	B7EAAB	3266 577397	LIDIYA SEMENOVA	{"email": "l_semenova-14101982@postgrespro.ru", "phone": "+70898575424"}
0005433924556	7C801B	3555 799679	MARGARITA OVCHINNIKOVA	{"email": "ovchinnikova.margarita.27081971@postgrespro.ru", "phone": "+70968379833"}
0005433924557	C7815E	1218 232693	SVETLANA ZHUKOVA	{"email": "zhukova-s_1965@postgrespro.ru", "phone": "+70905846627"}
0005433924558	6A2E05	8769 218884	ALEKSANDR SOLOVEV	{"email": "soloveva09101964@postgrespro.ru", "phone": "+70869151643"}
0005433924559	6A2E05	9486 331910	ELDAR VOLKOV	{"phone": "+70161391462"}
0005433924560	DCBCDA	9278 295100	RAISA IVANOVA	{"phone": "+70259876406"}
0005433924561	83BDD4	7939 298021	LYUDMILA LUKYANOVA	{"phone": "+70491877262"}
0005433924562	09D847	2073 364061	PAVEL KARPOV	{"phone": "+70414481249"}
0005433924563	22FF87	8835 076412	VYACHESLAV SOLOVEV	{"phone": "+70901581694"}
0005433924564	22FF87	7046 076468	DMITRIY NAUMOV	{"phone": "+70025184473"}
0005433924565	735623	3471 734785	TATYANA LEBEDEVA	{"phone": "+70381159007"}
0005433924566	FACEA6	3248 128836	VIKTOR GAVRILOV	{"email": "vgavrilov051980@postgrespro.ru", "phone": "+70903839478"}
0005433924567	A7B816	6728 455026	ILYA VOROBEV	{"phone": "+70108237553"}
0005433924568	44BCFD	0157 575357	ALEKSANDR BONDARENKO	{"phone": "+70191639434"}
0005433924569	44BCFD	8277 844168	KAROLINA PAVLOVA	{"phone": "+70588828042"}
0005433924570	15550D	8073 972299	NIKOLAY VOROBEV	{"phone": "+70598737618"}
0005433924571	15550D	2476 732142	SERGEY RODIONOV	{"email": "rodionov-sergey17021968@postgrespro.ru", "phone": "+70333755751"}
0005433924572	BD628D	3158 938414	ELENA POPOVA	{"phone": "+70276810520"}
0005433924573	811536	5979 518373	LYUBOV TARASOVA	{"email": "tarasova.l.011978@postgrespro.ru", "phone": "+70760818603"}
0005433924574	5D3BAC	5020 217541	MARIYA ZAYCEVA	{"email": "zayceva.m1967@postgrespro.ru", "phone": "+70300172401"}
0005433924575	F7526C	9849 494549	TAMARA DMITRIEVA	{"email": "dmitrieva_tamara_081973@postgrespro.ru", "phone": "+70528779953"}
0005433924576	F2CC59	1872 415017	ULYANA BOGDANOVA	{"email": "u.bogdanova.1989@postgrespro.ru", "phone": "+70913539197"}
0005433924577	1BD2C3	6381 260774	DMITRIY SEMENOV	{"phone": "+70271597602"}
0005433924578	1BD2C3	0983 416177	VALENTINA TARASOVA	{"phone": "+70084692222"}
0005433924579	1BD2C3	3422 552427	MIKHAIL NIKOLAEV	{"email": "nikolaev-mikhail1985@postgrespro.ru", "phone": "+70449353648"}
0005433924580	7266B2	8887 683299	EVGENIY EGOROV	{"email": "egorov.evgeniy-25061969@postgrespro.ru", "phone": "+70197418036"}
0005433924581	7266B2	1588 598005	MAKSIM AFANASEV	{"phone": "+70258016648"}
0005433924582	F13925	8342 008388	ELENA GERASIMOVA	{"phone": "+70478177156"}
0005433924583	F13925	6481 526287	ANNA MAKAROVA	{"phone": "+70579173086"}
0005433924586	2367A9	4380 819878	LYUDMILA YAKOVLEVA	{"email": "lyudmilayakovleva.051974@postgrespro.ru", "phone": "+70171181171"}
0005433924587	036A15	3867 027660	ANTON MARTYNOV	{"email": "amartynov-051964@postgrespro.ru", "phone": "+70786807143"}
0005433924588	036A15	9398 911231	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov-121981@postgrespro.ru", "phone": "+70479266806"}
0005433924589	036A15	0870 655111	TATYANA TIKHONOVA	{"phone": "+70267667760"}
0005433924590	5BBB43	4302 265364	VALENTINA TIMOFEEVA	{"phone": "+70312171868"}
0005433924591	2F2117	0087 221634	NIKOLAY KOZLOV	{"phone": "+70410424332"}
0005433924592	74EC82	3986 973645	IRINA MOROZOVA	{"phone": "+70177418616"}
0005433924593	7A2743	9170 061387	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr_15021978@postgrespro.ru", "phone": "+70083299253"}
0005433924594	C491F3	4180 492619	ANDREY KUZNECOV	{"email": "andrey.kuznecov_07111970@postgrespro.ru", "phone": "+70088067568"}
0005433924595	C491F3	3063 888943	EVGENIY TIKHONOV	{"phone": "+70112084312"}
0005433924596	59A5DB	8035 595919	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila-17081967@postgrespro.ru", "phone": "+70176401378"}
0005433924597	59A5DB	2720 358620	MIKHAIL IVANOV	{"email": "ivanov-m-30091981@postgrespro.ru", "phone": "+70820701126"}
0005433924598	2B77C3	0364 601831	ANDREY DMITRIEV	{"email": "a-dmitriev-1968@postgrespro.ru", "phone": "+70797580691"}
0005433924599	379CF2	9282 386907	KARINA PAVLOVA	{"phone": "+70118757082"}
0005433924600	B1E346	7659 872651	VALERIY KUZNECOV	{"email": "valeriy-kuznecov-1968@postgrespro.ru", "phone": "+70077278254"}
0005433924601	26751B	7656 602603	ANNA FOMINA	{"email": "fomina.anna.1974@postgrespro.ru", "phone": "+70479606208"}
0005433924602	26751B	7734 521750	IRAIDA PETROVA	{"email": "petrova.i_1975@postgrespro.ru", "phone": "+70218048922"}
0005433924603	26751B	9345 511284	SERGEY FILIPPOV	{"phone": "+70506412901"}
0005433924604	4F2263	3490 406293	VLADIMIR SIDOROV	{"email": "vladimir.sidorov_23041974@postgrespro.ru", "phone": "+70928657159"}
0005433924605	4F2263	0415 276962	SERGEY FOMIN	{"email": "fomin-sergey.12091962@postgrespro.ru", "phone": "+70733764765"}
0005433924606	2D6DF6	5820 555056	ALEKSANDR VOLKOV	{"email": "volkovaleksandr.29121958@postgrespro.ru", "phone": "+70208959834"}
0005433924607	4191F8	0920 522171	NATALYA KUZMINA	{"email": "natalya.kuzmina011979@postgrespro.ru", "phone": "+70485312237"}
0005433924608	B96525	2676 462022	LYUDMILA KISELEVA	{"email": "kiseleva.lyudmila1959@postgrespro.ru", "phone": "+70877660462"}
0005433924609	B96525	8812 825707	DARYA SAVELEVA	{"phone": "+70737307795"}
0005433924610	151964	8036 515954	TAMARA TIKHONOVA	{"phone": "+70351481783"}
0005433924611	151964	8066 921383	NADEZHDA PAVLOVA	{"email": "pavlova.n-1971@postgrespro.ru", "phone": "+70790129338"}
0005433924612	4D4EC5	6989 258084	VYACHESLAV ZAYCEV	{"email": "v.zaycev.101969@postgrespro.ru", "phone": "+70109822967"}
0005433924613	F9A3BE	5412 186931	ANDREY ZAYCEV	{"phone": "+70383829909"}
0005433924614	F9A3BE	8116 162292	MARGARITA ZOTOVA	{"phone": "+70305195939"}
0005433924615	F9A3BE	1402 456830	ALBERT ZAYCEV	{"email": "a-zaycev-031973@postgrespro.ru", "phone": "+70051460283"}
0005433924616	6EABE1	4932 697649	MARIYA ABRAMOVA	{"email": "mariya_abramova25111976@postgrespro.ru", "phone": "+70884145480"}
0005433924617	6EABE1	4904 728904	TATYANA BORISOVA	{"phone": "+70571383662"}
0005433924618	6EABE1	1400 642532	GULFIYA POTAPOVA	{"email": "potapova.g-021965@postgrespro.ru", "phone": "+70275100124"}
0005433924619	8FE8C4	4591 262763	FEDOR FEDOTOV	{"email": "fedotov-f081973@postgrespro.ru", "phone": "+70260182410"}
0005433924620	A1D335	9004 949010	TATYANA ALEKSANDROVA	{"email": "taleksandrova-091982@postgrespro.ru", "phone": "+70830873975"}
0005433924621	DE48FF	8959 869979	VASILIY FROLOV	{"phone": "+70857349876"}
0005433924622	C018EF	9661 183676	PAVEL IVANOV	{"email": "ivanov.pavel-1983@postgrespro.ru", "phone": "+70851250823"}
0005433924623	193774	1069 765843	NATALYA LEBEDEVA	{"email": "natalyalebedeva07071969@postgrespro.ru", "phone": "+70895033781"}
0005433924624	4F96DA	4867 089378	ALEKSANDR ILIN	{"email": "ilina-19021984@postgrespro.ru", "phone": "+70960071391"}
0005433924625	4F96DA	3283 609222	DMITRIY SERGEEV	{"email": "sergeev-d25021973@postgrespro.ru", "phone": "+70217442222"}
0005433924626	4F96DA	6870 329451	VERA SOKOLOVA	{"phone": "+70357787517"}
0005433924627	31827A	2412 605273	LYUBOV SOKOLOVA	{"phone": "+70040745131"}
0005433924628	E64E55	1545 533969	TATYANA SEMENOVA	{"phone": "+70245761975"}
0005433924629	E55542	7259 367728	SERGEY MAKSIMOV	{"email": "maksimov_sergey-021968@postgrespro.ru", "phone": "+70195881728"}
0005433924630	060AD8	2838 116820	VLADIMIR SOLOVEV	{"phone": "+70546039807"}
0005433924631	060AD8	3415 692376	KLAVDIYA TIMOFEEVA	{"email": "timofeeva_k-1966@postgrespro.ru", "phone": "+70104269514"}
0005433924632	516A35	8570 419680	OLGA BELYAEVA	{"phone": "+70822144842"}
0005433924633	0848DF	1309 519302	YULIYA TROFIMOVA	{"email": "trofimova_y.071982@postgrespro.ru", "phone": "+70366394772"}
0005433924634	0848DF	2401 237216	VALENTINA KISELEVA	{"phone": "+70140331198"}
0005433924635	61A017	1758 312648	NINA IVANOVA	{"email": "ivanova.nina1970@postgrespro.ru", "phone": "+70230792643"}
0005433924636	61A017	5333 881829	ALEKSANDRA CHERNOVA	{"phone": "+70633641154"}
0005433924637	98BA58	5202 144844	MAKSIM GORBUNOV	{"email": "gorbunov_m.21061972@postgrespro.ru", "phone": "+70063514497"}
0005433924638	F8A9F5	4043 159186	SERGEY KOZLOV	{"phone": "+70794517273"}
0005433924639	AFE32C	9353 728258	ALSU ZAYCEVA	{"phone": "+70446373605"}
0005433924640	AFE32C	5947 133235	SERGEY ALEKSANDROV	{"email": "sergey-aleksandrov091973@postgrespro.ru", "phone": "+70445176120"}
0005433924641	EF42CD	0851 325304	SERGEY SEMENOV	{"email": "semenov-s.071979@postgrespro.ru", "phone": "+70897318056"}
0005433924642	A55937	2161 421797	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov_1973@postgrespro.ru", "phone": "+70824013759"}
0005433924643	D23962	5772 154245	DARYA ZAKHAROVA	{"email": "zakharova-d_1969@postgrespro.ru", "phone": "+70061462260"}
0005433924644	D23962	2186 213000	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e-041977@postgrespro.ru", "phone": "+70993100836"}
0005433924645	E974E2	9897 533331	LYUDMILA ZAKHAROVA	{"email": "l_zakharova.051981@postgrespro.ru", "phone": "+70956387981"}
0005433924646	EE4EA6	2321 527569	LIDIYA POPOVA	{"phone": "+70303188093"}
0005433924647	13B879	8143 705855	NADEZHDA KARPOVA	{"email": "n.karpova_30051963@postgrespro.ru", "phone": "+70596982561"}
0005433924648	8F11D0	2494 196984	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva_29121974@postgrespro.ru", "phone": "+70703327600"}
0005433924649	8CC109	4917 354355	TATYANA KOZLOVA	{"phone": "+70545898384"}
0005433924650	46B953	7684 227233	NIKOLAY BORISOV	{"email": "borisov.n_1983@postgrespro.ru", "phone": "+70153661650"}
0005433924651	45B481	7716 983239	DMITRIY OSIPOV	{"phone": "+70661416239"}
0005433924652	D5F14A	8898 979286	STEPAN PETROV	{"phone": "+70028164308"}
0005433924653	194A14	2919 532598	IGOR KAZAKOV	{"phone": "+70528968994"}
0005433924654	12E364	9734 900566	STEPAN ZAKHAROV	{"email": "zakharov_s.1973@postgrespro.ru", "phone": "+70127259587"}
0005433924655	12E364	9686 670637	TATYANA ZAKHAROVA	{"phone": "+70825494377"}
0005433924656	37EAD4	9231 214833	DMITRIY ANDREEV	{"phone": "+70480414992"}
0005433924657	5E5928	7099 766164	ALEKSEY VOROBEV	{"email": "avorobev-081976@postgrespro.ru", "phone": "+70538378850"}
0005433924658	A392D0	2585 057431	MARINA ARKHIPOVA	{"email": "marina_arkhipova.12041975@postgrespro.ru", "phone": "+70296639642"}
0005433924659	B8E2C4	5482 903869	LYUBOV VOLKOVA	{"phone": "+70230600283"}
0005433924660	B8E2C4	1378 320075	VYACHESLAV EGOROV	{"phone": "+70257264402"}
0005433924661	C41161	8351 138401	DMITRIY ANTONOV	{"email": "dantonov01091971@postgrespro.ru", "phone": "+70473858772"}
0005433924662	C41161	1392 901703	ILYA VASILEV	{"phone": "+70090576995"}
0005433924663	5ABFCF	9271 777840	SERGEY VASILEV	{"phone": "+70219621866"}
0005433924664	5ABFCF	9213 305201	VLADISLAV TARASOV	{"phone": "+70462569274"}
0005433924665	EC7525	4585 514167	MAKSIM OSIPOV	{"phone": "+70374476776"}
0005433924666	10FB78	2272 157473	ANASTASIYA ZHUKOVA	{"email": "a_zhukova.021969@postgrespro.ru", "phone": "+70236200970"}
0005433924667	F4AC50	7611 585120	ALEKSANDR NOVIKOV	{"email": "a-novikov051975@postgrespro.ru", "phone": "+70046444239"}
0005433924668	F4AC50	5661 818513	EGOR OSIPOV	{"email": "osipov_egor-061971@postgrespro.ru", "phone": "+70423463900"}
0005433924669	D839B8	6719 250981	RUSLAN SOROKIN	{"email": "r_sorokin_071974@postgrespro.ru", "phone": "+70291073410"}
0005433924670	6205D5	7254 204619	ALEKSANDR POPOV	{"phone": "+70044897406"}
0005433924671	6D5F84	0933 645661	SVETLANA SAVELEVA	{"email": "saveleva.svetlana051961@postgrespro.ru", "phone": "+70931734295"}
0005433924672	5F8D3B	7400 190421	PAVEL GAVRILOV	{"phone": "+70497947872"}
0005433924673	1DC114	5897 042467	YULIYA MAKSIMOVA	{"email": "maksimova_yuliya_121970@postgrespro.ru", "phone": "+70755664215"}
0005433924674	4FBA10	4739 664926	VADIM POPOV	{"phone": "+70750700767"}
0005433924675	EBF77A	5825 071233	NINA SAVELEVA	{"email": "savelevan-1971@postgrespro.ru", "phone": "+70861147296"}
0005433924676	36CB76	2048 048340	VLADIMIR ROMANOV	{"email": "v-romanov.07081973@postgrespro.ru", "phone": "+70484966638"}
0005433924677	E6D348	8950 552332	ROMAN KOZLOV	{"email": "kozlov.roman14081965@postgrespro.ru", "phone": "+70960513218"}
0005433924678	4935CA	0209 512327	NIKOLAY ZAYCEV	{"email": "nikolay.zaycev-1963@postgrespro.ru", "phone": "+70301666099"}
0005433924679	9545F1	6213 196212	DANIIL SERGEEV	{"email": "sergeev.d-1976@postgrespro.ru", "phone": "+70300729891"}
0005433924680	1EC602	3739 318263	EGOR GERASIMOV	{"email": "e-gerasimov011976@postgrespro.ru", "phone": "+70294278144"}
0005433924681	D094B4	2614 874239	PAVEL FOMIN	{"email": "pavel-fomin-031973@postgrespro.ru", "phone": "+70255938656"}
0005433924682	DD3D9F	0220 421538	PETR MIKHAYLOV	{"phone": "+70044532454"}
0005433924683	DD3D9F	9710 183987	SVETLANA KUZMINA	{"email": "kuzmina-svetlana.1970@postgrespro.ru", "phone": "+70598885677"}
0005433924684	29AB1C	6668 334607	DMITRIY FEDOROV	{"email": "dmitriy_fedorov_13061978@postgrespro.ru", "phone": "+70881916860"}
0005433924685	E5BEC6	4892 873802	VLADIMIR NAZAROV	{"email": "vladimir-nazarov_16081966@postgrespro.ru", "phone": "+70417471334"}
0005433924686	968085	7916 126239	RAFAEL FEDOROV	{"email": "rafael-fedorov-17081974@postgrespro.ru", "phone": "+70021372602"}
0005433924687	968085	6013 497699	ALI VASILEV	{"phone": "+70004228207"}
0005433924688	AB4A53	7229 160738	VIKTOR KULIKOV	{"phone": "+70222028067"}
0005433924689	AB4A53	1543 202376	KLAVDIYA GAVRILOVA	{"email": "gavrilova_k.1965@postgrespro.ru", "phone": "+70346234275"}
0005433924690	841C01	5808 331275	IRINA OSIPOVA	{"email": "osipovairina15041972@postgrespro.ru", "phone": "+70383433710"}
0005433924691	CB99FC	2088 832709	ANTONINA EFREMOVA	{"phone": "+70713705459"}
0005433924692	104E76	7325 185696	VIKTOR ALEKSANDROV	{"email": "aleksandrovv-04021979@postgrespro.ru", "phone": "+70716061326"}
0005433924693	104E76	7039 928553	DARYA MIRONOVA	{"email": "darya.mironova_1976@postgrespro.ru", "phone": "+70923504229"}
0005433924694	B6355C	9319 302472	NATALYA ALEKSANDROVA	{"email": "aleksandrova-natalya18091976@postgrespro.ru", "phone": "+70437441132"}
0005433924695	2AEE6C	8001 007701	OLGA PETROVA	{"email": "petrova-o-09051988@postgrespro.ru", "phone": "+70159746120"}
0005433924696	5132C2	4551 767233	IRINA TIMOFEEVA	{"email": "timofeeva_i.1978@postgrespro.ru", "phone": "+70046071006"}
0005433924697	5132C2	9619 444972	PELAGEYA KUZNECOVA	{"email": "kuznecova_pelageya1984@postgrespro.ru", "phone": "+70478460826"}
0005433924698	51B9C5	1742 874428	YANA MELNIKOVA	{"phone": "+70411442999"}
0005433924699	51B9C5	5125 691604	IGOR MELNIKOV	{"email": "i.melnikov_01081962@postgrespro.ru", "phone": "+70738273664"}
0005433924700	51B9C5	1477 158584	VITALIY MOISEEV	{"phone": "+70594900816"}
0005433924701	0044FE	6597 939326	NIKITA FILIPPOV	{"email": "filippov-n-1970@postgrespro.ru", "phone": "+70008689624"}
0005433924702	450195	1823 940425	ARINA POPOVA	{"email": "arina_popova.20081985@postgrespro.ru", "phone": "+70247516689"}
0005433924703	2410B3	0994 940112	MAKSIM KOROLEV	{"email": "maksim-korolev08041968@postgrespro.ru", "phone": "+70740223378"}
0005433924704	CCFFB2	3475 089012	SVETLANA TIKHONOVA	{"email": "svetlana_tikhonova.22041991@postgrespro.ru", "phone": "+70118993586"}
0005433924705	2F13C3	7377 126708	ARTEM EGOROV	{"email": "a-egorov-021967@postgrespro.ru", "phone": "+70973468638"}
0005433924706	7F04C6	6372 039996	MIKHAIL KARPOV	{"phone": "+70119548677"}
0005433924707	F328A7	7216 724179	EVGENIYA KONOVALOVA	{"phone": "+70981641440"}
0005433924708	F89C66	7718 320529	OLESYA KAZAKOVA	{"email": "kazakova.o_101967@postgrespro.ru", "phone": "+70905451740"}
0005433924709	F89C66	0745 360394	TAMARA KUZNECOVA	{"email": "tamara.kuznecova.30011984@postgrespro.ru", "phone": "+70175088361"}
0005433924710	F89C66	6725 686863	LYUBOV KOVALEVA	{"email": "l_kovaleva-1972@postgrespro.ru", "phone": "+70912593155"}
0005433924711	5BF33F	0603 651611	OLEG NOVIKOV	{"phone": "+70575063163"}
0005433924712	CC88BA	2875 781769	GALINA ISAEVA	{"email": "galina-isaeva041965@postgrespro.ru", "phone": "+70287643235"}
0005433924713	746CA0	0506 662429	ELIZAVETA VOLKOVA	{"phone": "+70034724032"}
0005433924714	DFDF38	9920 393807	IRINA MAKAROVA	{"email": "imakarova.121975@postgrespro.ru", "phone": "+70184179121"}
0005433924715	FDA86D	4275 977135	ANNA SCHERBAKOVA	{"email": "scherbakova.a-091968@postgrespro.ru", "phone": "+70198507525"}
0005433924716	FDA86D	9324 273165	SVETLANA STEPANOVA	{"email": "stepanovasvetlana021991@postgrespro.ru", "phone": "+70597428646"}
0005433924717	FDA86D	6809 165216	NADIYA BORISOVA	{"email": "borisova-nadiya.1965@postgrespro.ru", "phone": "+70284307589"}
0005433924718	0CAC7D	0849 773460	ALEKSANDRA FOMINA	{"phone": "+70848542685"}
0005433924719	1484F9	2120 182277	FEDOR MOROZOV	{"email": "morozov-f-011970@postgrespro.ru", "phone": "+70758299266"}
0005433924720	32E22F	9506 618015	SERGEY KUZMIN	{"email": "kuzmin-s071974@postgrespro.ru", "phone": "+70270093007"}
0005433924721	3474A4	7266 070215	MARIYA DENISOVA	{"phone": "+70238011223"}
0005433924722	36606F	5612 264069	OLGA POPOVA	{"phone": "+70611604443"}
0005433924723	36606F	9402 188302	OLGA EFREMOVA	{"email": "olgaefremova23061966@postgrespro.ru", "phone": "+70864805587"}
0005433924724	24325E	0152 165578	YURIY SAVELEV	{"email": "yuriysavelev.051969@postgrespro.ru", "phone": "+70237828918"}
0005433924725	6E0FD2	5165 130368	LYUBOV NIKIFOROVA	{"email": "nikiforova.l1970@postgrespro.ru", "phone": "+70192256209"}
0005433924726	F19DAF	8329 356583	VALENTINA YUDINA	{"email": "v_yudina02011968@postgrespro.ru", "phone": "+70349816594"}
0005433924727	02F66C	6987 436864	BOGDAN MELNIKOV	{"phone": "+70922253696"}
0005433924728	C2428C	7253 507317	LILIYA LUKYANOVA	{"email": "lukyanova.l03091976@postgrespro.ru", "phone": "+70369640880"}
0005433924729	16E528	8542 327015	ALEKSEY NIKOLAEV	{"phone": "+70445649548"}
0005433924730	BD43D2	9993 400932	MARK KUZMIN	{"email": "kuzmin-m1968@postgrespro.ru", "phone": "+70181388640"}
0005433924731	13A689	0965 060794	GALINA SCHERBAKOVA	{"email": "gscherbakova-09081969@postgrespro.ru", "phone": "+70324622083"}
0005433924732	13A689	1888 761419	ZINAIDA YUDINA	{"email": "yudinaz081982@postgrespro.ru", "phone": "+70763461953"}
0005433924733	09A9F1	6955 768091	ELENA ZHURAVLEVA	{"email": "zhuravleva-e_18021969@postgrespro.ru", "phone": "+70672201178"}
0005433924734	09A9F1	4586 569672	SVETLANA POTAPOVA	{"phone": "+70384546637"}
0005433924735	E7A6D5	3033 314055	SVETLANA ROMANOVA	{"email": "svetlanaromanova061956@postgrespro.ru", "phone": "+70894938546"}
0005433924736	E7A6D5	6577 001638	IRINA KUZMINA	{"phone": "+70672909024"}
0005433924737	132AD5	1498 666091	NIKOLAY DENISOV	{"email": "denisov_nikolay08121980@postgrespro.ru", "phone": "+70977754850"}
0005433924738	132AD5	2130 549829	ALEKSEY ALEKSEEV	{"phone": "+70830881601"}
0005433924739	045005	2067 095193	YURIY IVANOV	{"phone": "+70149256705"}
0005433924740	23C562	7023 011236	NATALYA FROLOVA	{"email": "frolova_n_1970@postgrespro.ru", "phone": "+70024351512"}
0005433924741	D5997B	5436 313765	SERGEY FILIPPOV	{"email": "s_filippov-05071979@postgrespro.ru", "phone": "+70553687046"}
0005433924742	5069D5	5963 054111	ALEKSEY KOROLEV	{"phone": "+70357435513"}
0005433924743	5069D5	6972 331166	NADEZHDA EGOROVA	{"email": "nadezhda.egorova.16081976@postgrespro.ru", "phone": "+70992363859"}
0005433924744	9DAB6A	2517 136955	VLADIMIR BORISOV	{"phone": "+70085265411"}
0005433924745	E899BC	6034 696593	EKATERINA ALEKSEEVA	{"email": "alekseeva.ekaterina.071971@postgrespro.ru", "phone": "+70463308151"}
0005433924746	E899BC	5687 479708	ALEKSANDRA KOZLOVA	{"phone": "+70829925823"}
0005433924747	24F09A	8546 878282	GALINA GUSEVA	{"email": "guseva.galina_04051980@postgrespro.ru", "phone": "+70542200861"}
0005433924748	544049	0375 522206	NATALYA VOLKOVA	{"phone": "+70731031912"}
0005433924749	1E8959	9296 957423	KRISTINA GAVRILOVA	{"email": "gavrilova-k_111974@postgrespro.ru", "phone": "+70561877590"}
0005433924750	1E8959	0720 803328	ANNA ORLOVA	{"email": "orlovaanna07021968@postgrespro.ru", "phone": "+70025365273"}
0005433924751	BBD06C	8362 224066	EDUARD STEPANOV	{"email": "stepanov-eduard061984@postgrespro.ru", "phone": "+70296353733"}
0005433924752	35BA55	7615 449420	ELIZAVETA KARPOVA	{"email": "karpova_e.18051974@postgrespro.ru", "phone": "+70371963885"}
0005433924753	F2F40C	2064 016383	SERGEY IVANOV	{"phone": "+70427220299"}
0005433924754	F6F8F3	3586 408465	ELENA MARTYNOVA	{"phone": "+70180059186"}
0005433924755	F6F8F3	0341 184676	EVGENIY GERASIMOV	{"phone": "+70453953169"}
0005433924756	F6F8F3	0296 983600	EVGENIY KRASNOV	{"email": "krasnove-051980@postgrespro.ru", "phone": "+70779617088"}
0005433924757	F6F8F3	0574 768182	ELENA ANTONOVA	{"email": "e_antonova051963@postgrespro.ru", "phone": "+70567132700"}
0005433924758	B5D12D	1151 030142	INNA KOVALEVA	{"phone": "+70051144154"}
0005433924759	B5D12D	9661 618299	ELIZAVETA TITOVA	{"phone": "+70226674657"}
0005433924760	EF21C8	7524 787211	ANNA KUZNECOVA	{"email": "anna_kuznecova.06041974@postgrespro.ru", "phone": "+70439790149"}
0005433924761	433165	9067 440571	KONSTANTIN CHERNOV	{"email": "konstantin-chernov-1980@postgrespro.ru", "phone": "+70208187043"}
0005433924762	9BFD38	6847 404165	IVAN POPOV	{"phone": "+70861681349"}
0005433924763	9A5F44	4613 792228	ALEKSANDR ILIN	{"email": "ilin_aleksandr1976@postgrespro.ru", "phone": "+70316619720"}
0005433924764	9D5A2E	5956 762601	DENIS ZHURAVLEV	{"email": "denis.zhuravlev1964@postgrespro.ru", "phone": "+70877178620"}
0005433924765	0BF197	9875 112489	GALINA AFANASEVA	{"phone": "+70659573636"}
0005433924766	3FB1D9	5870 588627	ALENA STEPANOVA	{"phone": "+70071233529"}
0005433924767	6BCC88	8554 528760	LIDIYA KARPOVA	{"phone": "+70228058136"}
0005433924768	991CD0	9809 652578	VLADIMIR MAKAROV	{"phone": "+70907240444"}
0005433924769	991CD0	7626 228269	BOGDAN MATVEEV	{"phone": "+70856220917"}
0005433924770	14DDA9	0777 441324	MIKHAIL NOVIKOV	{"email": "mikhail_novikov-081963@postgrespro.ru", "phone": "+70453100620"}
0005433924771	3045E3	9833 616775	ALEKSANDRA MAKAROVA	{"email": "a_makarova_1974@postgrespro.ru", "phone": "+70886378871"}
0005433924772	3045E3	9121 646192	TAMARA SOKOLOVA	{"email": "tsokolova.08041974@postgrespro.ru", "phone": "+70567433266"}
0005433924773	C416EF	6063 912325	ALEKSEY NAZAROV	{"email": "a_nazarov_1985@postgrespro.ru", "phone": "+70443838623"}
0005433924774	C5497E	2980 871163	MARINA MARTYNOVA	{"phone": "+70845267342"}
0005433924775	C5497E	2740 954357	GALINA SEMENOVA	{"phone": "+70127047824"}
0005433924776	C5497E	5297 548940	OLEG KRASNOV	{"email": "o_krasnov-27101968@postgrespro.ru", "phone": "+70917914151"}
0005433924777	7A9422	7465 495242	OLGA POTAPOVA	{"email": "potapova-o-1964@postgrespro.ru", "phone": "+70680121368"}
0005433924778	47DCAD	9365 207238	VLADIMIR SHEVCHENKO	{"phone": "+70677212950"}
0005433924779	47DCAD	2983 069491	ELVIRA EFREMOVA	{"email": "efremova-elvira-1964@postgrespro.ru", "phone": "+70603179541"}
0005433924780	47DCAD	1448 334756	YULIYA OSIPOVA	{"phone": "+70518795959"}
0005433924781	A3C2E8	2324 689772	LARISA DANILOVA	{"phone": "+70675531804"}
0005433924782	2E9AC8	1232 223494	EVGENIY MIRONOV	{"email": "mironovevgeniy.07021966@postgrespro.ru", "phone": "+70079506631"}
0005433924783	8EDFB2	2557 867585	OLEG VOROBEV	{"email": "vorobev.o.051979@postgrespro.ru", "phone": "+70466343907"}
0005433924784	8EDFB2	4348 017726	ALEKSANDR CHERNOV	{"phone": "+70890270153"}
0005433924785	CB5303	6968 454841	VASILIY KOZLOV	{"phone": "+70674663992"}
0005433924786	CB5303	3790 558010	VYACHESLAV SMIRNOV	{"phone": "+70327201514"}
0005433924787	21F0E9	9978 980150	SERGEY IVANOV	{"email": "ivanov-sergey_1980@postgrespro.ru", "phone": "+70722447238"}
0005433924788	E89715	0119 580407	OLEG PAVLOV	{"email": "oleg-pavlov_21121967@postgrespro.ru", "phone": "+70797792225"}
0005433924789	9299BE	4427 529772	DENIS SAVELEV	{"phone": "+70539840878"}
0005433924790	9299BE	1464 789822	KLAVDIYA NIKOLAEVA	{"phone": "+70970028354"}
0005433924791	CBF89A	3683 935517	TAMARA NIKOLAEVA	{"phone": "+70547507137"}
0005433924792	CBF89A	8089 284407	DMITRIY ROMANOV	{"phone": "+70365711232"}
0005433924793	A70C6A	1468 210875	ELENA KOROLEVA	{"email": "koroleva.e17071970@postgrespro.ru", "phone": "+70410573134"}
0005433924794	F9D813	1236 979751	DANIL SEMENOV	{"phone": "+70406264010"}
0005433924795	DA4311	0895 501759	VLADIMIR SMIRNOV	{"phone": "+70441481447"}
0005433924796	DA4311	2894 658540	ELENA DAVYDOVA	{"phone": "+70677590983"}
0005433924797	8BA2C8	2517 189212	ALEKSANDRA NOVIKOVA	{"email": "novikova-aleksandra_20011979@postgrespro.ru", "phone": "+70066787649"}
0005433924798	8BA2C8	6517 075191	ALEKSEY ISAEV	{"email": "alekseyisaev081980@postgrespro.ru", "phone": "+70839852973"}
0005433924799	FF0D36	5743 495814	GALINA VOROBEVA	{"phone": "+70838634911"}
0005433924800	FF0D36	6967 603372	ANDREY NAUMOV	{"phone": "+70430964062"}
0005433924801	0988E3	8056 166828	LYUDMILA VOROBEVA	{"phone": "+70751868279"}
0005433924802	69A2F7	6283 479049	SERGEY SEMENOV	{"email": "s.semenov_091968@postgrespro.ru", "phone": "+70906898572"}
0005433924803	268C5A	2451 237981	LIDIYA IVANOVA	{"email": "lidiya.ivanova18121976@postgrespro.ru", "phone": "+70239930111"}
0005433924804	F01FF8	6728 706898	NINA IVANOVA	{"email": "ninaivanova_111972@postgrespro.ru", "phone": "+70073592693"}
0005433924805	40722C	3789 457982	LYUCIYA VOROBEVA	{"phone": "+70212412642"}
0005433924806	40722C	6555 947114	IRINA NAZAROVA	{"phone": "+70635964516"}
0005433924807	9D0601	6183 737497	LIDIYA FROLOVA	{"email": "frolova-l.16011986@postgrespro.ru", "phone": "+70241699264"}
0005433924808	8955B0	4368 636804	YURIY TIKHONOV	{"email": "y-tikhonov.1963@postgrespro.ru", "phone": "+70163974208"}
0005433924809	AE7CBB	1027 368182	ALEKSANDR MIRONOV	{"phone": "+70735939640"}
0005433924810	AE7CBB	6360 963848	ALEKSANDR ISAEV	{"phone": "+70616676906"}
0005433924811	028DEB	4544 236328	VALENTINA SMIRNOVA	{"email": "v_smirnova1962@postgrespro.ru", "phone": "+70989559800"}
0005433924812	057258	5618 148908	SERGEY ROMANOV	{"email": "romanov-s_28111967@postgrespro.ru", "phone": "+70985426568"}
0005433924813	057258	9060 597597	OLESYA ANISIMOVA	{"email": "olesya.anisimova.111985@postgrespro.ru", "phone": "+70426844684"}
0005433924814	057258	2741 006471	VLADIMIR SOKOLOV	{"phone": "+70880298993"}
0005433924815	7A027F	7760 382975	ELENA STEPANOVA	{"phone": "+70281124914"}
0005433924816	E3DBE2	0931 682347	DIANA MOROZOVA	{"phone": "+70497411308"}
0005433924817	E3DBE2	2987 900976	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr1968@postgrespro.ru", "phone": "+70811966141"}
0005433924818	E010BE	1960 190972	ALEKSEY POPOV	{"email": "aleksey-popov1970@postgrespro.ru", "phone": "+70051921242"}
0005433924819	41420E	5778 371723	VLADIMIR TARASOV	{"phone": "+70075843871"}
0005433924820	FA4CB1	9671 938912	NATALIYA MAKSIMOVA	{"phone": "+70411156246"}
0005433924821	74B0C6	8680 104158	LIDIYA MIRONOVA	{"email": "lidiya_mironova.1984@postgrespro.ru", "phone": "+70030959759"}
0005433924822	DDB212	4360 960325	MARIYA SOROKINA	{"phone": "+70085279672"}
0005433924823	DDB212	0610 840953	VLADIMIR TIMOFEEV	{"email": "timofeevvladimir.051957@postgrespro.ru", "phone": "+70591154943"}
0005433924824	6C8F3A	6481 246908	YULIYA NESTEROVA	{"phone": "+70125516314"}
0005433924825	51B24B	3238 905853	NIKOLAY MAKSIMOV	{"email": "maksimov-nikolay-1975@postgrespro.ru", "phone": "+70191483145"}
0005433924826	82457F	2436 637883	ZLATA VOROBEVA	{"email": "zlata.vorobeva-1984@postgrespro.ru", "phone": "+70182355656"}
0005433924827	183DCC	1248 963030	TATYANA IVANOVA	{"phone": "+70631690819"}
0005433924828	183DCC	6245 085726	ALEKSANDR NIKITIN	{"phone": "+70701178344"}
0005433924829	C34EBE	8146 720055	YURIY NIKOLAEV	{"phone": "+70706411655"}
0005433924830	C34EBE	7391 394400	IRINA KOLESNIKOVA	{"email": "i_kolesnikova_071980@postgrespro.ru", "phone": "+70289880265"}
0005433924831	F17AD5	7176 597361	OLGA KOMAROVA	{"phone": "+70955930742"}
0005433924832	2859F5	5624 840638	VIKTOR MELNIKOV	{"phone": "+70622085308"}
0005433924833	F09F65	5129 020681	YURIY SIDOROV	{"email": "sidorov_y021972@postgrespro.ru", "phone": "+70591171148"}
0005433924834	F09F65	6207 184196	YULIYA POLYAKOVA	{"email": "polyakova-y-071972@postgrespro.ru", "phone": "+70719084204"}
0005433924835	E62AB5	1817 946222	IBRAGIM KOROLEV	{"email": "ibragimkorolev1977@postgrespro.ru", "phone": "+70065207060"}
0005433924836	CAD5A6	3651 276988	ILGIZ BELOV	{"phone": "+70657261681"}
0005433924837	CAD5A6	7638 543498	KIRILL NIKOLAEV	{"email": "k-nikolaev1966@postgrespro.ru", "phone": "+70380806344"}
0005433924838	389504	0637 074108	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov_081967@postgrespro.ru", "phone": "+70613868828"}
0005433924839	6F7BCC	1644 716340	LYUBOV NOVIKOVA	{"email": "novikovalyubov_041970@postgrespro.ru", "phone": "+70571180802"}
0005433924840	D6D38A	5676 072974	DMITRIY SOKOLOV	{"phone": "+70026683140"}
0005433924841	2174B8	0579 007259	MARINA NIKOLAEVA	{"email": "nikolaeva-m121963@postgrespro.ru", "phone": "+70519385914"}
0005433924842	2174B8	9419 540595	NATALIYA ARKHIPOVA	{"phone": "+70897079674"}
0005433924843	0209FB	0365 597627	GAGIK STEPANOV	{"phone": "+70430098974"}
0005433924844	01ABFC	7000 992621	ELENA POLYAKOVA	{"email": "polyakovaelena.1971@postgrespro.ru", "phone": "+70585927422"}
0005433924845	E496EB	1068 963210	VLADISLAV ALEKSEEV	{"phone": "+70986121234"}
0005433924846	E496EB	1134 264483	VLADIMIR IVANOV	{"email": "ivanov.v_121973@postgrespro.ru", "phone": "+70976427342"}
0005433924847	4E3F23	7777 667090	TAMARA KOLESNIKOVA	{"phone": "+70562591824"}
0005433924848	4E3F23	8468 738010	MARSEL GERASIMOV	{"email": "mgerasimov1961@postgrespro.ru", "phone": "+70629934658"}
0005433924849	4E3F23	8813 888169	ANDREY PETROV	{"phone": "+70861950404"}
0005433924850	F62928	5328 578097	SERGEY BONDARENKO	{"phone": "+70952175183"}
0005433924851	F62928	9128 591113	MARIYA KUZNECOVA	{"email": "kuznecova.m_19111972@postgrespro.ru", "phone": "+70489872190"}
0005433924852	1C0135	8564 520200	NINA TIKHONOVA	{"phone": "+70784989659"}
0005433924853	509234	8255 195113	NATALYA SOLOVEVA	{"phone": "+70250055672"}
0005433924854	469A64	5828 740075	LYUBOV POPOVA	{"phone": "+70610310943"}
0005433924855	7FCDAA	3667 876406	ANNA ZAKHAROVA	{"phone": "+70553672164"}
0005433924856	3A4334	1996 911309	ALEKSANDR SAVELEV	{"email": "a.savelev-091964@postgrespro.ru", "phone": "+70081465285"}
0005433924857	3A4334	1910 763601	TATYANA KUDRYASHOVA	{"phone": "+70700624692"}
0005433924858	93117F	6103 123659	ANATOLIY SAVELEV	{"phone": "+70272448075"}
0005433924859	77C81C	8448 074739	ELZA POLYAKOVA	{"phone": "+70626963164"}
0005433924860	C70AA6	4738 190253	YAKOV ANTONOV	{"phone": "+70997393652"}
0005433924861	C5C73A	8770 622544	ALEKSANDR FROLOV	{"phone": "+70012671822"}
0005433924862	17FA95	1274 565857	VYACHESLAV YAKOVLEV	{"phone": "+70729225579"}
0005433924863	17FA95	6546 759464	SERGEY MELNIKOV	{"email": "s_melnikov_121969@postgrespro.ru", "phone": "+70253342765"}
0005433924864	C91D8B	7033 071754	DINARA TIKHONOVA	{"phone": "+70646272532"}
0005433924866	08882A	5136 017122	YULIYA KUZNECOVA	{"email": "kuznecova_y.1973@postgrespro.ru", "phone": "+70642654673"}
0005433924867	08882A	0657 801776	PAVEL PETROV	{"email": "petrov_pavel.121967@postgrespro.ru", "phone": "+70530208679"}
0005433924868	BA508E	4808 926572	VLADIMIR GERASIMOV	{"phone": "+70891079902"}
0005433924869	ABF674	4775 195694	ELENA NESTEROVA	{"phone": "+70305208227"}
0005433924870	ABF674	7760 774626	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov121969@postgrespro.ru", "phone": "+70305715867"}
0005433924871	33586E	3108 900902	IGOR MEDVEDEV	{"phone": "+70567112678"}
0005433924872	CEF01E	6632 063836	TATYANA KULIKOVA	{"phone": "+70204719622"}
0005433924873	070AA7	0409 609732	ALEKSEY SHEVCHENKO	{"phone": "+70960960990"}
0005433924874	CDDA6F	4866 121136	EVGENIY KOZLOV	{"phone": "+70811071456"}
0005433924875	58B9E5	5367 436746	DMITRIY MELNIKOV	{"phone": "+70062794018"}
0005433924876	58B9E5	8315 411384	YANINA AKIMOVA	{"phone": "+70954299854"}
0005433924877	B39173	7895 634302	YURIY SMIRNOV	{"phone": "+70014866661"}
0005433924878	B39173	7240 801022	ANNA VLASOVA	{"phone": "+70590659227"}
0005433924879	68D24B	3263 013607	KRISTINA KUZNECOVA	{"email": "kuznecova-kristina1970@postgrespro.ru", "phone": "+70822247090"}
0005433924880	F22336	9059 127770	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr14031970@postgrespro.ru", "phone": "+70062845669"}
0005433924881	6D46B5	5176 623801	ANNA MOROZOVA	{"email": "morozovaa_111990@postgrespro.ru", "phone": "+70639909106"}
0005433924882	C1C5D9	4949 082861	SERGEY KUZNECOV	{"phone": "+70969451258"}
0005433924883	902EAF	4379 281066	VERA EGOROVA	{"email": "v_egorova.011975@postgrespro.ru", "phone": "+70941233772"}
0005433924884	902EAF	8234 855008	VALENTINA TITOVA	{"email": "titovavalentina-1966@postgrespro.ru", "phone": "+70304510062"}
0005433924885	E74802	1429 511175	NATALYA KONDRATEVA	{"phone": "+70077579691"}
0005433924886	722711	2996 626365	EKATERINA MELNIKOVA	{"phone": "+70619569659"}
0005433924887	2E7E2E	4384 833845	KLARA LAZAREVA	{"phone": "+70932279049"}
0005433924888	CDDB87	6607 251148	KSENIYA NAUMOVA	{"phone": "+70213247141"}
0005433924889	CDDB87	6469 376508	VLADIMIR KUZMIN	{"phone": "+70073614304"}
0005433924890	B7D540	8031 009386	GALINA IVANOVA	{"phone": "+70370726231"}
0005433924891	F877F7	9267 846727	KIRA NIKITINA	{"email": "kira-nikitina021968@postgrespro.ru", "phone": "+70746896836"}
0005433924892	B6CAE0	2161 381695	TATYANA ZAYCEVA	{"phone": "+70410861428"}
0005433924893	B6CAE0	0932 606465	ANNA ARKHIPOVA	{"email": "arkhipova_a041976@postgrespro.ru", "phone": "+70939400579"}
0005433924894	5C323E	9237 327137	MARINA VOLKOVA	{"email": "m.volkova_1966@postgrespro.ru", "phone": "+70941435181"}
0005433924895	5C323E	4742 463563	YANA BELOVA	{"phone": "+70370279678"}
0005433924896	9F6E67	6970 312124	SVETLANA OVCHINNIKOVA	{"phone": "+70835733053"}
0005433924897	D7C4EE	3269 302953	ANASTASIYA SOROKINA	{"email": "a.sorokina.101985@postgrespro.ru", "phone": "+70139058769"}
0005433924898	353DE0	8346 860042	IRINA SOROKINA	{"email": "i.sorokina1971@postgrespro.ru", "phone": "+70698023954"}
0005433924899	300F4D	3882 177085	RUSHANIYA DAVYDOVA	{"email": "davydova-r-071971@postgrespro.ru", "phone": "+70851371536"}
0005433924900	40BF8D	2762 927008	MIKHAIL MELNIKOV	{"email": "melnikovm_051977@postgrespro.ru", "phone": "+70091531328"}
0005433924901	AA9A0C	9957 365802	LINAR PAVLOV	{"email": "pavlov.linar1963@postgrespro.ru", "phone": "+70923945784"}
0005433924902	AD10BF	5242 768667	VALERIY MIKHAYLOV	{"phone": "+70756421867"}
0005433924903	68128D	1466 796797	NATALYA NESTEROVA	{"email": "nesterova.n.26041971@postgrespro.ru", "phone": "+70003256044"}
0005433924904	68128D	0877 570947	NIKITA ROMANOV	{"phone": "+70960941506"}
0005433924905	D54284	5672 732512	VIKTORIYA AKIMOVA	{"email": "akimova_v.06011967@postgrespro.ru", "phone": "+70505691565"}
0005433924906	D54284	4005 175362	VALENTINA NIKOLAEVA	{"phone": "+70348919398"}
0005433924907	195013	9651 136446	NIKOLAY NIKOLAEV	{"email": "nikolaev-n_24081960@postgrespro.ru", "phone": "+70047505202"}
0005433924908	540342	3848 016406	ALEKSANDRA FEDOROVA	{"email": "fedorova-aleksandra.1975@postgrespro.ru", "phone": "+70195280777"}
0005433924909	540342	9578 192722	ELENA MOISEEVA	{"phone": "+70229519828"}
0005433924910	098C97	2031 863886	ARTEM KUZNECOV	{"phone": "+70235819356"}
0005433924911	0F2237	8552 455492	DMITRIY ZAYCEV	{"email": "zaycev_d_1970@postgrespro.ru", "phone": "+70896137441"}
0005433924912	09EC8A	8394 975550	VITALIY NIKITIN	{"phone": "+70048648021"}
0005433924913	1E7CCE	5176 736887	NIKITA POPOV	{"email": "popov.nikita01061968@postgrespro.ru", "phone": "+70219978347"}
0005433924914	5A1116	3223 207982	GENNADIY SIDOROV	{"email": "sidorov.g-1968@postgrespro.ru", "phone": "+70377285601"}
0005433924915	5A1116	8353 592154	LIDIYA AKIMOVA	{"phone": "+70388303094"}
0005433924916	5A1116	5503 354191	LYUDMILA AFANASEVA	{"email": "lyudmila_afanaseva.05021978@postgrespro.ru", "phone": "+70833091385"}
0005433924917	1548D6	8777 922444	LYUBOV IVANOVA	{"email": "ivanova-l-12121969@postgrespro.ru", "phone": "+70537643660"}
0005433924918	1548D6	1468 828390	NIKOLAY EGOROV	{"email": "egorovnikolay14121970@postgrespro.ru", "phone": "+70141902761"}
0005433924919	B201B9	2402 058682	VALENTINA GAVRILOVA	{"email": "gavrilovavalentina_061986@postgrespro.ru", "phone": "+70986434784"}
0005433924920	87AF2B	5820 774992	EVGENIY DMITRIEV	{"email": "dmitriev.e.1972@postgrespro.ru", "phone": "+70626964127"}
0005433924921	FF4AC8	9447 355784	IGOR MAKSIMOV	{"email": "maksimov-i.1958@postgrespro.ru", "phone": "+70112972023"}
0005433924922	888769	9533 064295	ANZHELA SCHERBAKOVA	{"phone": "+70486661311"}
0005433924923	C6E638	4114 856647	SVETLANA VASILEVA	{"email": "s-vasileva011967@postgrespro.ru", "phone": "+70058189450"}
0005433924924	FB7C12	9252 656440	MARGARITA DANILOVA	{"phone": "+70563120849"}
0005433924925	7EF73C	3184 496964	ALINA BARANOVA	{"email": "a-baranova-1967@postgrespro.ru", "phone": "+70456136116"}
0005433924926	7EF73C	1981 940078	SVETLANA IVANOVA	{"email": "ivanova.svetlana-08111983@postgrespro.ru", "phone": "+70715069859"}
0005433924927	A77B5D	2725 822639	VERA SERGEEVA	{"phone": "+70507522577"}
0005433924928	D552CC	9416 602266	VLADIMIR FEDOROV	{"phone": "+70210479368"}
0005433924929	D552CC	7611 819280	VALERIYA SCHERBAKOVA	{"phone": "+70895319986"}
0005433924930	598261	5516 394269	ZHANNA FROLOVA	{"phone": "+70143281752"}
0005433924931	598261	0191 510542	ILYA ANTONOV	{"email": "i_antonov_1969@postgrespro.ru", "phone": "+70741332206"}
0005433924932	164E97	4986 985647	LYUDMILA ISAEVA	{"email": "isaeva-lyudmila_111965@postgrespro.ru", "phone": "+70599689859"}
0005433924933	651B77	2368 723772	KONSTANTIN VOLKOV	{"email": "k_volkov-1971@postgrespro.ru", "phone": "+70671603998"}
0005433924934	55D691	7708 155680	SVETLANA KOZLOVA	{"email": "svetlanakozlova_1970@postgrespro.ru", "phone": "+70132064797"}
0005433924935	5314F2	4524 742514	BORIS MAKSIMOV	{"email": "boris-maksimov101971@postgrespro.ru", "phone": "+70507736043"}
0005433924936	17FC40	3788 209950	KONSTANTIN ISAEV	{"phone": "+70432710872"}
0005433924937	17FC40	6887 511009	MARK ALEKSEEV	{"phone": "+70735876558"}
0005433924938	9A89F8	4107 985048	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov_051969@postgrespro.ru", "phone": "+70523476498"}
0005433924939	485B58	2657 937495	ZINAIDA SOLOVEVA	{"email": "z_soloveva-061973@postgrespro.ru", "phone": "+70390987332"}
0005433924940	DFA0BF	3111 831196	VALERIYA KUZNECOVA	{"email": "kuznecovavaleriya-1980@postgrespro.ru", "phone": "+70426407044"}
0005433924941	F24692	1013 685671	GALINA TROFIMOVA	{"phone": "+70410303921"}
0005433924942	906A00	7482 048400	RAISA FEDOROVA	{"email": "raisafedorova.051982@postgrespro.ru", "phone": "+70082414837"}
0005433924943	906A00	2531 940309	TATYANA NOVIKOVA	{"phone": "+70931343124"}
0005433924944	87809F	2461 859910	DARYA IVANOVA	{"email": "d.ivanova-31031973@postgrespro.ru", "phone": "+70778455522"}
0005433924945	F192EA	5966 930730	LYUBOV MIKHAYLOVA	{"phone": "+70304476646"}
0005433924946	F192EA	7187 340578	TAMARA DMITRIEVA	{"email": "dmitrieva-t.1959@postgrespro.ru", "phone": "+70365251286"}
0005433924947	6B2BB5	2927 132790	ZOYA ZAKHAROVA	{"email": "zakharova-z_041969@postgrespro.ru", "phone": "+70104548420"}
0005433924948	6B2BB5	6705 377591	RAFIK ILIN	{"email": "ilin_r17011966@postgrespro.ru", "phone": "+70077419685"}
0005433924949	4677AE	0471 011259	NIKOLAY POPOV	{"phone": "+70209589106"}
0005433924950	AF49D5	8623 238277	OLGA PETROVA	{"phone": "+70684162950"}
0005433924951	F312F0	2309 405106	OLGA ROMANOVA	{"email": "romanovao22111963@postgrespro.ru", "phone": "+70481201659"}
0005433924952	D5DD58	9625 015138	VLADIMIR RODIONOV	{"email": "rodionov.v-1978@postgrespro.ru", "phone": "+70111681568"}
0005433924953	20F30D	8926 894258	BORIS SOKOLOV	{"email": "sokolov.boris_09041970@postgrespro.ru", "phone": "+70053284282"}
0005433924954	9F4F79	7587 791045	EVGENIY MIKHAYLOV	{"phone": "+70826532388"}
0005433924955	6E090F	9879 548327	ALEKSEY IVANOV	{"email": "aleksey-ivanov091961@postgrespro.ru", "phone": "+70611213559"}
0005433924956	2FDCC0	3342 881000	MARIYA DAVYDOVA	{"email": "davydova-mariya_021984@postgrespro.ru", "phone": "+70152861358"}
0005433924957	1EDBA8	8554 353995	IRINA MATVEEVA	{"email": "matveeva_i111964@postgrespro.ru", "phone": "+70136466011"}
0005433924958	03FC92	0293 369384	NINA NAUMOVA	{"email": "naumovanina_091977@postgrespro.ru", "phone": "+70547922576"}
0005433924959	03FC92	2150 846150	ALEKSEY SERGEEV	{"phone": "+70998504368"}
0005433924960	FABCFE	2484 023320	OLGA SCHERBAKOVA	{"email": "olgascherbakova1961@postgrespro.ru", "phone": "+70768004692"}
0005433924961	FABCFE	3141 460459	VLADISLAV OSIPOV	{"email": "vladislav-osipov_031973@postgrespro.ru", "phone": "+70778701934"}
0005433924962	EDA8FA	0627 103271	VLADIMIR KONOVALOV	{"email": "vladimirkonovalov.1974@postgrespro.ru", "phone": "+70855100330"}
0005433924963	EDA8FA	1787 809462	OLGA MATVEEVA	{"phone": "+70496018079"}
0005433925022	2C0490	5659 948482	YULIYA ANTONOVA	{"phone": "+70760969639"}
0005433924964	502163	2656 096470	SERGEY VASILEV	{"email": "vasilev_s.02021977@postgrespro.ru", "phone": "+70584867353"}
0005433924965	502163	3814 198907	VALERIY PETROV	{"phone": "+70596910456"}
0005433924966	CCA202	5853 674558	SERGEY KOZLOV	{"phone": "+70836725726"}
0005433924967	CCA202	4995 719214	ELENA FEDOROVA	{"email": "fedorova.elena.121970@postgrespro.ru", "phone": "+70988039757"}
0005433924968	96B874	6360 323167	TATYANA SMIRNOVA	{"email": "smirnova_t1969@postgrespro.ru", "phone": "+70546239881"}
0005433924969	47AA3C	9490 802329	VERA FILIPPOVA	{"phone": "+70375914385"}
0005433924970	47AA3C	1965 994571	DANILA MAKAROV	{"phone": "+70537234873"}
0005433924971	1B21E7	9735 010465	SERGEY MATVEEV	{"email": "matveev-s1977@postgrespro.ru", "phone": "+70273496032"}
0005433924972	2DC586	0557 652867	NATALYA IVANOVA	{"email": "nivanova.09031967@postgrespro.ru", "phone": "+70776866727"}
0005433924973	473BBF	6164 951193	OLESYA NAUMOVA	{"email": "naumova-o-031973@postgrespro.ru", "phone": "+70903845880"}
0005433924974	473BBF	4950 724505	YURIY KUZMIN	{"email": "kuzminyuriy.07081967@postgrespro.ru", "phone": "+70767046057"}
0005433924975	0FF37C	4987 574860	NIKITA NOVIKOV	{"email": "n-novikov_021977@postgrespro.ru", "phone": "+70328181256"}
0005433924976	996A48	3340 386873	ANNA FEDOROVA	{"email": "anna-fedorova_02021970@postgrespro.ru", "phone": "+70892979327"}
0005433924977	BCC1F9	3721 043252	YURIY NOVIKOV	{"phone": "+70548134648"}
0005433924978	BCC1F9	3662 355344	ANDREY AFANASEV	{"phone": "+70141711898"}
0005433924979	DE82DD	2719 364795	ANDREY ANDREEV	{"email": "andreev-a_091973@postgrespro.ru", "phone": "+70019160808"}
0005433924980	4A6910	9492 249582	SERGEY EGOROV	{"email": "segorov111967@postgrespro.ru", "phone": "+70070693267"}
0005433924981	4A6910	6669 968234	YURIY NIKOLAEV	{"email": "nikolaev-yuriy.15031979@postgrespro.ru", "phone": "+70694871201"}
0005433924982	8375BF	4528 005410	MARIYA VOROBEVA	{"phone": "+70056546792"}
0005433924983	5568DB	5557 798589	VLADIMIR ALEKSANDROV	{"email": "vladimiraleksandrov1971@postgrespro.ru", "phone": "+70047643388"}
0005433924984	A77734	6653 936832	SERGEY TIKHONOV	{"email": "sergeytikhonov_1972@postgrespro.ru", "phone": "+70077152732"}
0005433924985	A77734	9051 376789	ZINAIDA SOLOVEVA	{"email": "soloveva.z.041980@postgrespro.ru", "phone": "+70293220782"}
0005433924986	4690AC	4709 469522	TATYANA SMIRNOVA	{"email": "t.smirnova.1960@postgrespro.ru", "phone": "+70800742016"}
0005433924987	9C580F	6400 695736	EKATERINA EFREMOVA	{"email": "ekaterina.efremova02051982@postgrespro.ru", "phone": "+70692644773"}
0005433924988	9C580F	6807 645594	TIMOFEY KUZMIN	{"email": "t.kuzmin.1969@postgrespro.ru", "phone": "+70420581129"}
0005433924989	1CD590	5754 615084	KIRILL PETROV	{"email": "kirill_petrov.10021966@postgrespro.ru", "phone": "+70877774225"}
0005433924990	B799E2	4641 720501	VLADIMIR PAVLOV	{"phone": "+70664229904"}
0005433924991	B799E2	5942 044325	IRINA KAZAKOVA	{"email": "irina_kazakova.02041977@postgrespro.ru", "phone": "+70437840075"}
0005433924992	A6B765	1398 294187	ELENA SMIRNOVA	{"email": "elena_smirnova-1972@postgrespro.ru", "phone": "+70689202097"}
0005433924993	F6D87D	4887 241522	NATALYA BORISOVA	{"email": "natalyaborisova_1961@postgrespro.ru", "phone": "+70642006376"}
0005433924994	F6D87D	9545 977846	OLGA KALININA	{"email": "o-kalinina-05121979@postgrespro.ru", "phone": "+70835096628"}
0005433924995	6D9BAF	1234 602405	IRINA POPOVA	{"phone": "+70113280282"}
0005433924996	68AAF2	2822 137000	ANNA FILATOVA	{"email": "filatovaanna-031969@postgrespro.ru", "phone": "+70042337372"}
0005433924997	D45A93	7456 656555	KIRILL MIKHAYLOV	{"email": "k-mikhaylov.101963@postgrespro.ru", "phone": "+70245825464"}
0005433924998	93167A	9275 788880	NADEZHDA ROMANOVA	{"email": "nromanova-011966@postgrespro.ru", "phone": "+70504958274"}
0005433924999	EF0648	3540 906520	OLGA BORISOVA	{"email": "borisova-o_1969@postgrespro.ru", "phone": "+70646006752"}
0005433925000	EF0648	3814 659477	LARISA EGOROVA	{"email": "larisaegorova_19041966@postgrespro.ru", "phone": "+70288411385"}
0005433925001	83F341	4141 710012	ELENA POPOVA	{"email": "popovaelena011972@postgrespro.ru", "phone": "+70640273689"}
0005433925002	CF919C	8523 899441	ALEKSANDR NAUMOV	{"phone": "+70512552308"}
0005433925003	1B8753	5815 997669	DANIIL ROMANOV	{"email": "romanov-d.041991@postgrespro.ru", "phone": "+70616549966"}
0005433925004	AC58A2	9402 824488	ANNA KOLESNIKOVA	{"email": "anna.kolesnikova-1958@postgrespro.ru", "phone": "+70133106168"}
0005433925005	AC58A2	9071 377036	INGA PETROVA	{"email": "i.petrova1965@postgrespro.ru", "phone": "+70816006776"}
0005433925006	1775A5	1577 181614	PETR FILIPPOV	{"email": "p.filippov27061967@postgrespro.ru", "phone": "+70890979331"}
0005433925007	10BEAA	8092 280925	ANGELINA MOISEEVA	{"email": "moiseeva_a-1970@postgrespro.ru", "phone": "+70378939830"}
0005433925008	175E42	1693 434670	ALEKSANDR KARPOV	{"phone": "+70277926318"}
0005433925009	8DDD7A	0582 075385	SERGEY IVANOV	{"email": "sergeyivanov02041972@postgrespro.ru", "phone": "+70863308098"}
0005433925010	7DA6CA	6565 696104	ANDREY SEMENOV	{"email": "andrey.semenov.1981@postgrespro.ru", "phone": "+70625088674"}
0005433925011	7DA6CA	3148 197638	OLGA IVANOVA	{"phone": "+70136994159"}
0005433925012	D9088F	3903 592637	NINA EGOROVA	{"phone": "+70821628808"}
0005433925013	D9088F	1218 433388	SVETLANA BORISOVA	{"phone": "+70349053836"}
0005433925014	F31CA4	5576 076505	ANDREY ALEKSEEV	{"phone": "+70923676395"}
0005433925015	F31CA4	8722 429518	YULIYA MEDVEDEVA	{"email": "medvedeva-y-031974@postgrespro.ru", "phone": "+70647779541"}
0005433925016	F31CA4	4045 014262	OLEG MATVEEV	{"phone": "+70282217281"}
0005433925017	B8B37B	3304 228566	NINA ROMANOVA	{"email": "romanova-n_05121975@postgrespro.ru", "phone": "+70457466605"}
0005433925018	B8B37B	9163 085445	VIKTOR FROLOV	{"phone": "+70866832792"}
0005433925019	912F5E	3103 273320	MAKSIM IVANOV	{"phone": "+70041025583"}
0005433925020	912F5E	9823 524307	VALENTINA ILINA	{"phone": "+70026787691"}
0005433925021	4FB521	3260 028170	ELENA ORLOVA	{"phone": "+70158315354"}
0005433925023	2C0490	2238 312922	ALEKSANDR DAVYDOV	{"email": "davydova_06051972@postgrespro.ru", "phone": "+70102979341"}
0005433925024	C8DD19	2912 739076	DMITRIY RODIONOV	{"email": "rodionov-dmitriy021967@postgrespro.ru", "phone": "+70248988916"}
0005433925025	FE448A	9482 454065	VIKTOR STEPANOV	{"email": "stepanov_viktor-121976@postgrespro.ru", "phone": "+70236165467"}
0005433925026	FE448A	3868 894271	ALEKSANDRA MIRONOVA	{"email": "mironova.aleksandra.07101963@postgrespro.ru", "phone": "+70605068506"}
0005433925027	B0B2A7	0905 294750	MATVEY MELNIKOV	{"email": "m.melnikov10021980@postgrespro.ru", "phone": "+70342940069"}
0005433925028	C7F58B	9482 046702	ALEKSANDRA RYABOVA	{"email": "a.ryabova-011962@postgrespro.ru", "phone": "+70806569858"}
0005433925029	5B7113	0008 118415	NATALYA BORISOVA	{"email": "n-borisova-011974@postgrespro.ru", "phone": "+70378780791"}
0005433925030	435727	3972 883098	VLADIMIR ANDREEV	{"email": "vladimir.andreev-061977@postgrespro.ru", "phone": "+70935806341"}
0005433925031	079F2F	0455 242478	VIKTOR ISAEV	{"phone": "+70248876699"}
0005433925032	A2F982	6652 908937	ALEKSANDR PETROV	{"phone": "+70167926979"}
0005433925033	A2F982	0881 299086	SERGEY FEDOTOV	{"email": "fedotov.s.1982@postgrespro.ru", "phone": "+70123017327"}
0005433925034	727077	0241 027553	ALENA NOVIKOVA	{"phone": "+70326358324"}
0005433925035	218F48	4113 678549	MARIYA ZOTOVA	{"email": "zotova.m_01091983@postgrespro.ru", "phone": "+70068208536"}
0005433925036	58A54F	3057 330395	ALEKSANDR FEDOROV	{"email": "fedorov_a-02071970@postgrespro.ru", "phone": "+70011463485"}
0005433925037	ED905B	2600 399714	SERGEY DENISOV	{"email": "denisov-s-051972@postgrespro.ru", "phone": "+70988920351"}
0005433925038	ED905B	8335 273816	ANASTASIYA ROMANOVA	{"phone": "+70964201264"}
0005433925039	6C01F2	0231 980353	ALBINA GRISHINA	{"email": "grishina-a1956@postgrespro.ru", "phone": "+70095534152"}
0005433925040	6C01F2	3152 898598	VIKTORIYA NOVIKOVA	{"email": "novikovaviktoriya-1979@postgrespro.ru", "phone": "+70556854816"}
0005433925041	329AC5	7520 970422	EKATERINA VOLKOVA	{"phone": "+70595268485"}
0005433925042	57F639	8458 978020	YULIYA VLASOVA	{"phone": "+70290148865"}
0005433925043	C6D60A	8506 138368	GALINA ZAYCEVA	{"phone": "+70167514757"}
0005433925044	C6D60A	7411 115936	VYACHESLAV SEMENOV	{"phone": "+70120491025"}
0005433925045	4DC0CA	3318 560864	ALENA KOROLEVA	{"email": "koroleva.a.101981@postgrespro.ru", "phone": "+70239954575"}
0005433925046	4DC0CA	6627 149011	RAISA KISELEVA	{"email": "raisakiseleva1974@postgrespro.ru", "phone": "+70377984233"}
0005433925047	6B92F8	4860 618274	DANILA SOKOLOV	{"phone": "+70283152841"}
0005433925048	6B92F8	8524 032009	ANDREY NAUMOV	{"phone": "+70836791646"}
0005433925049	2D0A40	4494 642342	SERGEY SERGEEV	{"email": "sergeev_sergey041968@postgrespro.ru", "phone": "+70605927811"}
0005433925050	96D025	1802 556547	ANATOLIY KOROLEV	{"phone": "+70786179933"}
0005433925051	96D025	8304 427846	GLEB ANTONOV	{"phone": "+70752627149"}
0005433925052	1A7CF8	1824 226453	SERGEY SMIRNOV	{"phone": "+70811599907"}
0005433925053	BA15E0	1426 291699	ALEKSEY ZAYCEV	{"email": "zaycev_aleksey071970@postgrespro.ru", "phone": "+70114758007"}
0005433925054	BA15E0	4200 671173	NIKOLAY DMITRIEV	{"phone": "+70930608085"}
0005433925055	11AA65	7408 365722	YURIY SCHERBAKOV	{"email": "scherbakovyuriy-10021973@postgrespro.ru", "phone": "+70844267178"}
0005433925056	B9BACC	1812 410962	OLGA TARASOVA	{"email": "olgatarasova_1974@postgrespro.ru", "phone": "+70026332785"}
0005433925057	B9BACC	1021 989175	NADEZHDA NIKITINA	{"phone": "+70242710659"}
0005433925058	32BDC6	1241 047888	NINA FILIPPOVA	{"phone": "+70997839249"}
0005433925059	32BDC6	3099 066604	NATALYA DAVYDOVA	{"email": "davydova.natalya.021967@postgrespro.ru", "phone": "+70820575803"}
0005433925060	32BDC6	8720 270883	KSENIYA STEPANOVA	{"phone": "+70128194151"}
0005433925061	92F3FD	3775 958957	NINA MATVEEVA	{"phone": "+70690853139"}
0005433925062	286CC8	6366 504661	GALINA MELNIKOVA	{"phone": "+70828588296"}
0005433925063	286CC8	3698 006175	GALINA LOGINOVA	{"email": "gloginova_30081964@postgrespro.ru", "phone": "+70749247576"}
0005433925064	F758AB	9370 483143	ALEKSEY MAKSIMOV	{"phone": "+70921150693"}
0005433925065	60C293	3617 495425	DMITRIY FEDOROV	{"email": "d.fedorov16091969@postgrespro.ru", "phone": "+70576612795"}
0005433925066	3B5854	6432 587784	ANDREY KUZNECOV	{"email": "a-kuznecov10061966@postgrespro.ru", "phone": "+70293306997"}
0005433925067	3B5854	4276 443472	NATALYA ANDREEVA	{"email": "natalya-andreeva_051979@postgrespro.ru", "phone": "+70083633063"}
0005433925068	C0164A	9649 442290	ANATOLIY FROLOV	{"phone": "+70796841166"}
0005433925069	C0164A	0496 581940	ALEKSANDR POPOV	{"email": "popov.aleksandr27061974@postgrespro.ru", "phone": "+70118136244"}
0005433925070	C0164A	0822 285769	ROMAN NAUMOV	{"phone": "+70417247825"}
0005433925071	3DFBB1	7277 870031	NIKOLAY ZAYCEV	{"email": "n_zaycev-10051978@postgrespro.ru", "phone": "+70079006064"}
0005433925072	3DFBB1	4409 258811	OKSANA MOROZOVA	{"email": "omorozova.01111960@postgrespro.ru", "phone": "+70340748624"}
0005433925073	0C5A82	8351 297887	ELENA KUZNECOVA	{"email": "kuznecova_elena-30061977@postgrespro.ru", "phone": "+70579723133"}
0005433925074	45B46D	9613 280102	GALINA MAKAROVA	{"email": "galina-makarova19031967@postgrespro.ru", "phone": "+70839727464"}
0005433925075	857571	1663 293572	ALEKSANDR SAVELEV	{"phone": "+70454754240"}
0005433925076	EB107C	2460 843134	TATYANA TIKHONOVA	{"phone": "+70878752327"}
0005433925077	CE7287	8408 545985	ALEKSANDRA IVANOVA	{"phone": "+70255313978"}
0005433925078	F81E05	6952 753702	SERGEY IVANOV	{"phone": "+70917931439"}
0005433925079	8D73D5	8960 441255	ALEKSEY VASILEV	{"email": "a.vasilev-081974@postgrespro.ru", "phone": "+70187798347"}
0005433925080	4F35D6	2545 142227	ANDREY FILIPPOV	{"email": "afilippov-121965@postgrespro.ru", "phone": "+70345619739"}
0005433925081	DCDEBD	9436 105404	VASILIY SOROKIN	{"email": "v.sorokin-21021970@postgrespro.ru", "phone": "+70341591547"}
0005433925082	1DEC4F	9773 436660	VLADIMIR ZAKHAROV	{"email": "v-zakharov-1981@postgrespro.ru", "phone": "+70170262672"}
0005433925083	1DEC4F	0466 620497	VIKTOR ZHURAVLEV	{"email": "viktor-zhuravlev-1977@postgrespro.ru", "phone": "+70918253101"}
0005433925084	B79652	1236 227274	ELENA BELYAEVA	{"phone": "+70555998011"}
0005433925085	01C2B6	2093 028575	SERGEY MAKSIMOV	{"email": "sergeymaksimov-18101971@postgrespro.ru", "phone": "+70209636213"}
0005433925086	70B567	4058 858270	NATALIYA MEDVEDEVA	{"phone": "+70637610268"}
0005433925087	D1AC0E	0698 166884	ELENA VASILEVA	{"phone": "+70202030102"}
0005433925088	D1AC0E	6567 532085	TATYANA NESTEROVA	{"email": "tnesterova_071962@postgrespro.ru", "phone": "+70740612847"}
0005433925089	D1AC0E	1988 804519	GRIGORIY MARTYNOV	{"phone": "+70435063546"}
0005433925090	EA82F4	3518 273353	KIRILL MATVEEV	{"phone": "+70032336897"}
0005433925091	705612	3373 838423	EVGENIYA DENISOVA	{"email": "evgeniya_denisova-1966@postgrespro.ru", "phone": "+70446342847"}
0005433925092	705612	4550 401111	VLADIMIR DENISOV	{"email": "denisov_v1971@postgrespro.ru", "phone": "+70153022908"}
0005433925093	4E276E	0765 543289	ELENA OSIPOVA	{"email": "osipova_e.24121972@postgrespro.ru", "phone": "+70294074827"}
0005433925094	4E276E	1847 650698	MARIYA FOMINA	{"phone": "+70526040736"}
0005433925095	1B6165	7527 957646	NIKITA MAKAROV	{"phone": "+70482603165"}
0005433925096	1B6165	6284 800266	SVETLANA ZAKHAROVA	{"email": "s-zakharova1983@postgrespro.ru", "phone": "+70064089217"}
0005433925097	26398B	0262 492197	SVETLANA KUZNECOVA	{"email": "kuznecovas-24051971@postgrespro.ru", "phone": "+70952773286"}
0005433925098	9F77D8	9109 440611	ANATOLIY SOROKIN	{"phone": "+70814622408"}
0005433925099	9F77D8	9953 481245	GALINA PETROVA	{"email": "petrovag25061965@postgrespro.ru", "phone": "+70463798151"}
0005433925100	9F77D8	2699 808094	SERGEY MAKAROV	{"email": "makarov_s.20051976@postgrespro.ru", "phone": "+70307959265"}
0005433925101	9F77D8	8894 399741	ALEKSANDRA PETROVA	{"phone": "+70476301988"}
0005433925102	B60535	9247 188064	ALEKSANDRA KOVALEVA	{"email": "kovalevaa-1956@postgrespro.ru", "phone": "+70915673865"}
0005433925103	3944A5	5558 612768	INNA SOKOLOVA	{"phone": "+70572694476"}
0005433925104	2B632F	7858 683113	LYUBOV MIRONOVA	{"email": "lmironova-22041970@postgrespro.ru", "phone": "+70631111747"}
0005433925105	2B632F	5897 634638	IVAN KUZNECOV	{"phone": "+70626891572"}
0005433925106	ADAA33	9057 750017	VALENTINA NIKOLAEVA	{"email": "valentina.nikolaeva.30121979@postgrespro.ru", "phone": "+70582102265"}
0005433925107	ADAA33	3050 170757	ALEKSANDR KUZNECOV	{"email": "a-kuznecov.081977@postgrespro.ru", "phone": "+70463049905"}
0005433925108	2EBD03	9909 359346	GENNADIY KOZLOV	{"email": "gennadiykozlov.02021984@postgrespro.ru", "phone": "+70458021132"}
0005433925109	5F874B	5782 262452	IRINA ISAEVA	{"phone": "+70951435304"}
0005433925110	5F874B	4069 174811	SVETLANA KISELEVA	{"phone": "+70538750216"}
0005433925111	0695EF	9695 671245	MIKHAIL ANDREEV	{"email": "m_andreev.1967@postgrespro.ru", "phone": "+70743896740"}
0005433925112	6BA824	0952 807256	EVGENIY DMITRIEV	{"phone": "+70436497612"}
0005433925113	6BA824	4137 316176	TATYANA KUZNECOVA	{"phone": "+70589801905"}
0005433925114	857619	0653 740555	VIKTORIYA BELOVA	{"email": "belova.v_1972@postgrespro.ru", "phone": "+70082858998"}
0005433925115	9916B1	6993 516735	ALEKSANDR FROLOV	{"phone": "+70112550262"}
0005433925116	9916B1	6992 339480	VERONIKA KAZAKOVA	{"phone": "+70948803315"}
0005433925117	9916B1	8235 933601	VERA KOLESNIKOVA	{"email": "verakolesnikova121977@postgrespro.ru", "phone": "+70884736895"}
0005433925118	403E0A	7776 959815	KIRA BORISOVA	{"email": "kborisova051964@postgrespro.ru", "phone": "+70542565420"}
0005433925119	403E0A	9266 716243	KRISTINA IVANOVA	{"email": "ivanovakristina_19071978@postgrespro.ru", "phone": "+70679617915"}
0005433925120	BACF0E	1553 275236	FEDOR POPOV	{"email": "popov_f.1978@postgrespro.ru", "phone": "+70496234757"}
0005433925121	BACF0E	9746 706339	OLEG NAUMOV	{"phone": "+70770151669"}
0005433925122	9BF14F	2269 708632	LYUDMILA KOROLEVA	{"phone": "+70911776333"}
0005433925123	93109C	4146 703965	PAVEL CHERNOV	{"email": "chernov.p-061972@postgrespro.ru", "phone": "+70466410095"}
0005433925124	93109C	6306 083256	ANASTASIYA KOROLEVA	{"phone": "+70932602056"}
0005433925125	1AB1BC	5819 262405	ELENA POLYAKOVA	{"email": "elena.polyakova05091977@postgrespro.ru", "phone": "+70623913568"}
0005433925126	03AE61	4438 326151	IVAN SIDOROV	{"phone": "+70067899864"}
0005433925127	03AE61	3649 962985	ANNA FILATOVA	{"email": "annafilatova-041964@postgrespro.ru", "phone": "+70622258055"}
0005433925128	03AE61	7963 539784	VITALIY CHERNOV	{"email": "vchernov_1967@postgrespro.ru", "phone": "+70880007163"}
0005433925129	A038E6	0284 555487	ANZHELIKA SEMENOVA	{"phone": "+70196700725"}
0005433925130	FF3701	4611 718260	SVETLANA ZOTOVA	{"email": "zotova.s_1975@postgrespro.ru", "phone": "+70060242560"}
0005433925131	A220B6	5872 886014	NIKOLAY ALEKSEEV	{"email": "n.alekseev_071972@postgrespro.ru", "phone": "+70087440213"}
0005433925132	6929DE	8902 047058	DMITRIY ISAEV	{"phone": "+70790999174"}
0005433925133	0194BB	8838 636223	DMITRIY IVANOV	{"email": "dmitriy_ivanov_11111967@postgrespro.ru", "phone": "+70833726268"}
0005433925134	6C32AE	2663 368411	GENNADIY KOROLEV	{"phone": "+70597484746"}
0005433925135	6C32AE	5103 314618	MARINA MOISEEVA	{"phone": "+70538179244"}
0005433925136	9A1B10	5037 660752	VALERIY KOZLOV	{"phone": "+70868009372"}
0005433925137	D9EE99	3545 504993	GALINA SOKOLOVA	{"email": "sokolova-galina10101975@postgrespro.ru", "phone": "+70232281111"}
0005433925138	D9EE99	2224 354576	EKATERINA OVCHINNIKOVA	{"email": "e_ovchinnikova-30121968@postgrespro.ru", "phone": "+70539721266"}
0005433925139	654794	7858 073818	ELENA MEDVEDEVA	{"phone": "+70472319103"}
0005433925140	37E88A	6270 252068	ALEKSANDR ORLOV	{"phone": "+70270370176"}
0005433925141	37E88A	3583 756101	VLADIMIR BARANOV	{"phone": "+70713960693"}
0005433925142	F4BA13	5520 029137	NINA EGOROVA	{"email": "n.egorova_051985@postgrespro.ru", "phone": "+70194413227"}
0005433925143	2A2573	4570 715482	ELENA SCHERBAKOVA	{"email": "e.scherbakova031976@postgrespro.ru", "phone": "+70961690073"}
0005433925144	2A2573	0469 597368	MARGARITA SOKOLOVA	{"phone": "+70043055925"}
0005433925145	4DF19C	0666 637702	VERA KOZLOVA	{"email": "v-kozlova1977@postgrespro.ru", "phone": "+70279410767"}
0005433925146	4DF19C	3609 154184	VYACHESLAV AFANASEV	{"phone": "+70932865318"}
0005433925147	4DF19C	9475 201147	FARID EGOROV	{"email": "egorov.f_1971@postgrespro.ru", "phone": "+70037044731"}
0005433925148	4AC49D	0585 449512	VENIAMIN SEMENOV	{"email": "vsemenov.03061980@postgrespro.ru", "phone": "+70227789368"}
0005433925149	4AC49D	6793 497089	SERGEY CHERNOV	{"phone": "+70498086939"}
0005433925150	3BF180	0274 395238	ALEKSANDRA KARPOVA	{"email": "a.karpova1975@postgrespro.ru", "phone": "+70489857563"}
0005433925151	DA8956	2984 850917	NIKOLAY DENISOV	{"email": "n.denisov15071980@postgrespro.ru", "phone": "+70374495083"}
0005433925152	314E40	9227 525416	ALEKSANDR VLASOV	{"email": "vlasov-a_1976@postgrespro.ru", "phone": "+70909604018"}
0005433925153	E72365	1113 531416	ANGELINA ALEKSANDROVA	{"email": "angelinaaleksandrova.1969@postgrespro.ru", "phone": "+70583742964"}
0005433925154	E72365	1864 023496	NIKOLAY AFANASEV	{"phone": "+70105709161"}
0005433925155	488B42	9244 896204	VLADISLAV VASILEV	{"phone": "+70633086976"}
0005433925156	488B42	9768 255016	NATALYA MIKHAYLOVA	{"phone": "+70409199784"}
0005433925157	578BF8	3433 413253	YURIY KULIKOV	{"phone": "+70316734249"}
0005433925158	0C86DD	5863 600512	SERGEY GUSEV	{"email": "s_gusev.071954@postgrespro.ru", "phone": "+70675182186"}
0005433925159	8D4329	7829 424133	RAMIL SERGEEV	{"email": "sergeev.ramil.071972@postgrespro.ru", "phone": "+70673088571"}
0005433925160	8D4329	9810 124576	ELENA DMITRIEVA	{"email": "dmitrieva_e1963@postgrespro.ru", "phone": "+70535904648"}
0005433925161	8D4329	2452 170715	VALERIY KUZNECOV	{"phone": "+70380470828"}
0005433925162	E39962	3000 627133	ANNA KUZMINA	{"phone": "+70365971627"}
0005433925163	2C6D3B	8963 383204	VALENTINA VLASOVA	{"phone": "+70291393176"}
0005433925164	0293C5	5688 026705	VITALIY SIDOROV	{"email": "sidorov.vitaliy.061961@postgrespro.ru", "phone": "+70786232945"}
0005433925165	F9E071	0817 733164	IVAN EGOROV	{"email": "i_egorov.1987@postgrespro.ru", "phone": "+70597013122"}
0005433925166	24FB66	7484 410941	OLGA BORISOVA	{"email": "oborisova1973@postgrespro.ru", "phone": "+70346620162"}
0005433925167	9F89B3	7807 576045	GALINA YUDINA	{"email": "galinayudina05101962@postgrespro.ru", "phone": "+70977215247"}
0005433925168	9F89B3	0762 089501	NIKOLAY BORISOV	{"email": "nikolay.borisov1970@postgrespro.ru", "phone": "+70354005798"}
0005433925169	87D484	4417 492088	ANTON VOLKOV	{"email": "antonvolkov.1981@postgrespro.ru", "phone": "+70711421039"}
0005433925170	F0CFA8	4290 032062	OLGA ERMAKOVA	{"phone": "+70951912996"}
0005433925171	64F021	4072 760567	SERGEY ILIN	{"email": "s.ilin15071971@postgrespro.ru", "phone": "+70097379845"}
0005433925172	054BBF	0300 034665	ALEKSANDR SAVELEV	{"phone": "+70001855665"}
0005433925173	933D23	1453 597539	EKATERINA ORLOVA	{"phone": "+70273890755"}
0005433925174	C17F41	7014 682358	NATALYA KOVALEVA	{"email": "kovaleva_n021973@postgrespro.ru", "phone": "+70718288866"}
0005433925175	C17F41	0333 004506	SERGEY SERGEEV	{"phone": "+70831062830"}
0005433925176	2306EF	8775 729952	YURIY MAKAROV	{"email": "y_makarov_1971@postgrespro.ru", "phone": "+70483561492"}
0005433925177	2306EF	9570 243489	OKSANA OVCHINNIKOVA	{"email": "ovchinnikova_oksana.091966@postgrespro.ru", "phone": "+70679335814"}
0005433925178	E264BB	8046 330962	NADEZHDA KOZLOVA	{"email": "nadezhda.kozlova-1991@postgrespro.ru", "phone": "+70885743943"}
0005433925179	5BB3B3	1820 143545	YULIYA KUZNECOVA	{"email": "yuliyakuznecova1956@postgrespro.ru", "phone": "+70373517507"}
0005433925180	43BEFD	1477 473735	ALEKSANDR ROMANOV	{"email": "a.romanov121966@postgrespro.ru", "phone": "+70667913133"}
0005433925181	012C24	8668 500968	LARISA YAKOVLEVA	{"email": "larisa.yakovleva_031978@postgrespro.ru", "phone": "+70316095777"}
0005433925182	012C24	8247 884397	EKATERINA KALININA	{"email": "e-kalinina_101972@postgrespro.ru", "phone": "+70731664129"}
0005433925183	343ABC	1565 876640	KLAVDIYA DENISOVA	{"email": "denisova.k_1988@postgrespro.ru", "phone": "+70004443458"}
0005433925184	20D093	4571 289263	SERGEY SIDOROV	{"phone": "+70715023247"}
0005433925185	5EA898	0080 044859	RAUZA PAVLOVA	{"phone": "+70164470787"}
0005433925186	06C896	3825 317473	EKATERINA FROLOVA	{"phone": "+70226917413"}
0005433925187	06C896	1475 884052	MARIYA PAVLOVA	{"email": "mariya.pavlova.25051979@postgrespro.ru", "phone": "+70750352321"}
0005433925188	B86C40	5981 116688	MARIYA ZOTOVA	{"phone": "+70389011257"}
0005433925189	673D35	1453 448461	IRINA MELNIKOVA	{"email": "melnikova-irina-061975@postgrespro.ru", "phone": "+70599271072"}
0005433925190	E28F73	8980 697281	TAISIYA KUZMINA	{"email": "t-kuzmina_29081974@postgrespro.ru", "phone": "+70512996406"}
0005433925191	B27406	5924 010467	VIKTOR ANTONOV	{"email": "viktorantonov.1976@postgrespro.ru", "phone": "+70411746807"}
0005433925192	B27406	9397 089699	NINA KUZNECOVA	{"phone": "+70003536379"}
0005433925193	8E24B6	2555 431051	NADEZHDA IVANOVA	{"email": "nadezhdaivanova-12061971@postgrespro.ru", "phone": "+70460003710"}
0005433925194	EE614E	4230 377179	NINA VOROBEVA	{"phone": "+70066216301"}
0005433925195	CE8BD0	7629 672901	VERA OSIPOVA	{"phone": "+70588405303"}
0005433925196	1993F8	4145 439369	DILYARA CHERNOVA	{"email": "chernova-d-18041973@postgrespro.ru", "phone": "+70766750721"}
0005433925197	8E4F29	3729 438116	VLADIMIR IVANOV	{"phone": "+70011584683"}
0005433925198	8E4F29	8326 843906	GALINA ROMANOVA	{"email": "g.romanova1960@postgrespro.ru", "phone": "+70573611678"}
0005433925199	9C2E4F	2430 158736	ALEKSANDR FROLOV	{"phone": "+70213456090"}
0005433925497	190BDF	4776 040073	SERGEY NIKOLAEV	{"phone": "+70945925020"}
0005433925200	9C2E4F	6310 059428	MARIYA ALEKSEEVA	{"email": "alekseeva-mariya111968@postgrespro.ru", "phone": "+70764516500"}
0005433925201	E1672D	4627 038973	OLGA KONOVALOVA	{"phone": "+70138134162"}
0005433925202	E1672D	5872 575962	MARINA KAZAKOVA	{"phone": "+70275691454"}
0005433925203	15C49A	0266 109038	SERGEY DMITRIEV	{"email": "dmitriev_s.15081958@postgrespro.ru", "phone": "+70681532125"}
0005433925204	15C49A	0237 460412	ALEKSEY SEMENOV	{"email": "aleksey-semenov21051964@postgrespro.ru", "phone": "+70338040526"}
0005433925205	1BC50E	2044 069279	VIKTOR MOISEEV	{"phone": "+70041977648"}
0005433925206	BE7E55	8859 488735	YULIYA GRISHINA	{"email": "y-grishina-1963@postgrespro.ru", "phone": "+70946352106"}
0005433925207	BE7E55	3668 970264	ANISA LUKYANOVA	{"phone": "+70328847325"}
0005433925208	6BDA87	6525 106592	DMITRIY ALEKSANDROV	{"phone": "+70901386654"}
0005433925209	6BDA87	3563 656810	SVETLANA BELOVA	{"email": "belovas-1970@postgrespro.ru", "phone": "+70503492643"}
0005433925210	5360C5	9578 820885	NIKOLAY KUZNECOV	{"email": "kuznecovn-26011972@postgrespro.ru", "phone": "+70220692943"}
0005433925211	F7FD95	5499 767619	VIKTOR GERASIMOV	{"email": "v.gerasimov_091983@postgrespro.ru", "phone": "+70410253325"}
0005433925212	1B2AF6	7210 932934	ANASTASIYA SERGEEVA	{"email": "sergeeva_anastasiya.1964@postgrespro.ru", "phone": "+70976368230"}
0005433925213	1B2AF6	1439 919857	ELENA POLYAKOVA	{"phone": "+70362924197"}
0005433925214	1B2AF6	4414 863706	ANNA KALININA	{"email": "kalininaa-021972@postgrespro.ru", "phone": "+70215497346"}
0005433925215	799F90	6018 960185	ALLA KUZMINA	{"phone": "+70842652932"}
0005433925216	466BB0	3856 261483	ALEKSANDR KUZNECOV	{"email": "kuznecov-a.031976@postgrespro.ru", "phone": "+70054186776"}
0005433925217	9D3D20	1884 160797	YURIY MELNIKOV	{"email": "melnikov-yuriy-111971@postgrespro.ru", "phone": "+70919013021"}
0005433925218	939B97	8005 237960	VLADIMIR TARASOV	{"email": "v-tarasov_1964@postgrespro.ru", "phone": "+70767164756"}
0005433925219	DDAD30	1691 579783	MARIYA ALEKSANDROVA	{"email": "mariya_aleksandrova.02081977@postgrespro.ru", "phone": "+70575868674"}
0005433925220	A75460	9392 788970	ALEKSEY AFANASEV	{"email": "aleksey.afanasev1974@postgrespro.ru", "phone": "+70984679458"}
0005433925221	A75460	2257 547567	RAISA FEDOROVA	{"phone": "+70377720740"}
0005433925222	CD3F2F	7575 109159	SERGEY KULIKOV	{"phone": "+70500232823"}
0005433925223	CD3F2F	1130 879124	TATYANA OSIPOVA	{"email": "tatyana_osipova.1975@postgrespro.ru", "phone": "+70501543647"}
0005433925224	B0DEF2	9869 705153	NIKOLAY KONOVALOV	{"email": "nikolay_konovalov.24061972@postgrespro.ru", "phone": "+70727849069"}
0005433925225	FE5302	3778 700101	EKATERINA KARPOVA	{"phone": "+70589876824"}
0005433925226	D37A9C	6898 915088	MARIYA ILINA	{"email": "m-ilina.1971@postgrespro.ru", "phone": "+70947551102"}
0005433925227	8BB518	4645 770872	SERGEY GERASIMOV	{"phone": "+70659720074"}
0005433925228	1B8950	0968 606967	EVDOKIYA MASLOVA	{"email": "evdokiya-maslova.28101975@postgrespro.ru", "phone": "+70313702403"}
0005433925229	1B8950	2451 424650	LYUBOV FILATOVA	{"phone": "+70454528555"}
0005433925230	9A1BAC	2114 197868	ELENA PAVLOVA	{"email": "pavlova.elena1977@postgrespro.ru", "phone": "+70755984757"}
0005433925231	9A1BAC	3454 252819	ALEKSEY KOROLEV	{"email": "a.korolev091962@postgrespro.ru", "phone": "+70148342647"}
0005433925232	916C98	6719 279867	DARYA OVCHINNIKOVA	{"email": "daryaovchinnikova04071964@postgrespro.ru", "phone": "+70060053556"}
0005433925233	BC1A4D	8881 333223	VIKTOR SCHERBAKOV	{"email": "scherbakov_v_011980@postgrespro.ru", "phone": "+70986490012"}
0005433925234	8A0BB1	3050 143380	VLADIMIR FEDOTOV	{"email": "fedotov_v-1974@postgrespro.ru", "phone": "+70944308579"}
0005433925235	850037	9230 747611	LYUDMILA SOROKINA	{"phone": "+70844387638"}
0005433925236	52DA21	0556 849983	DARYA ANISIMOVA	{"email": "daryaanisimova1973@postgrespro.ru", "phone": "+70919362684"}
0005433925237	52DA21	6125 679059	RAFAEL NAUMOV	{"phone": "+70485280725"}
0005433925238	52DA21	1047 728491	MILANA PAVLOVA	{"email": "milanapavlova28061974@postgrespro.ru", "phone": "+70622677373"}
0005433925239	1D9EE9	1143 709356	VLADIMIR SOROKIN	{"phone": "+70033149647"}
0005433925240	1D9EE9	1362 211967	MIKHAIL SOROKIN	{"phone": "+70942962937"}
0005433925241	BC9D19	2508 040351	IRINA GORBUNOVA	{"email": "gorbunova_i011977@postgrespro.ru", "phone": "+70175139369"}
0005433925242	BC9D19	6315 035954	VERA MARTYNOVA	{"phone": "+70522023112"}
0005433925243	AE3744	9489 199755	VALENTINA VOLKOVA	{"email": "v.volkova081971@postgrespro.ru", "phone": "+70681811856"}
0005433925244	6E3788	5567 040284	ANDREY ABRAMOV	{"email": "a_abramov_031968@postgrespro.ru", "phone": "+70858756439"}
0005433925245	6E3788	1987 648276	NIKOLAY MARTYNOV	{"email": "nikolay-martynov_101975@postgrespro.ru", "phone": "+70693358114"}
0005433925246	6E3788	5212 612786	ALEKSEY STEPANOV	{"phone": "+70055509423"}
0005433925247	D082F6	5416 791286	LYUBOV ISAEVA	{"email": "l.isaeva_09051985@postgrespro.ru", "phone": "+70869801077"}
0005433925248	7BD805	5238 989638	DANIS BELOV	{"phone": "+70197227341"}
0005433925249	545FDF	0303 827795	ALEKSEY BORISOV	{"email": "a_borisov.091979@postgrespro.ru", "phone": "+70566168272"}
0005433925250	FA8213	0869 785888	LYUDMILA MAKAROVA	{"phone": "+70060142708"}
0005433925251	691CAD	7466 015117	EGOR FOMIN	{"email": "fominegor1980@postgrespro.ru", "phone": "+70397806686"}
0005433925252	8D2C75	8306 178457	VALERIY VOLKOV	{"phone": "+70115437639"}
0005433925253	723C07	2359 359199	NATALYA ERMAKOVA	{"phone": "+70658820960"}
0005433925254	3D9B6D	0040 734532	ANDREY ANDREEV	{"phone": "+70777148043"}
0005433925255	A0F8BC	5870 703132	NINA TIKHONOVA	{"email": "tikhonova.n091974@postgrespro.ru", "phone": "+70603009506"}
0005433925256	15A6B6	0923 413585	ANDREY SOKOLOV	{"phone": "+70673574504"}
0005433925257	15A6B6	6388 563659	YURIY ISAEV	{"email": "yisaev07091971@postgrespro.ru", "phone": "+70155505362"}
0005433925258	013BF3	5545 699076	ELENA IVANOVA	{"phone": "+70204374055"}
0005433925259	9C3B6A	0597 639528	ALEKSANDR POPOV	{"email": "popov_a_25111980@postgrespro.ru", "phone": "+70081117874"}
0005433925260	8AB15E	5161 437942	NADEZHDA SOROKINA	{"email": "sorokinan-1983@postgrespro.ru", "phone": "+70469252690"}
0005433925261	1D3721	0871 307291	ALEKSANDR DMITRIEV	{"phone": "+70537397039"}
0005433925262	5A0749	1654 623430	VLADISLAV STEPANOV	{"email": "stepanov_vladislav_1969@postgrespro.ru", "phone": "+70180961200"}
0005433925263	5A0749	9557 225963	ELENA MATVEEVA	{"email": "elena.matveeva-24081965@postgrespro.ru", "phone": "+70311928646"}
0005433925264	FC6B67	4433 941896	TATYANA SAVELEVA	{"phone": "+70771723558"}
0005433925265	7E98E1	0209 398087	SVETLANA RODIONOVA	{"email": "rodionovasvetlana_091963@postgrespro.ru", "phone": "+70933880755"}
0005433925266	E94106	2547 892980	YURIY ALEKSANDROV	{"email": "aleksandrov_yuriy_28081981@postgrespro.ru", "phone": "+70767540509"}
0005433925267	E94106	8193 938664	EGOR YAKOVLEV	{"phone": "+70910529037"}
0005433925268	9836AD	1948 804690	LYUDMILA SIDOROVA	{"email": "l-sidorova.071977@postgrespro.ru", "phone": "+70101680327"}
0005433925269	A01163	8882 416478	SOFIYA NESTEROVA	{"phone": "+70747697760"}
0005433925270	0AF96A	5422 559621	KIRILL ABRAMOV	{"email": "abramov-kirill_22031972@postgrespro.ru", "phone": "+70392330496"}
0005433925271	08585B	2241 636679	ZLATA AKIMOVA	{"phone": "+70501693450"}
0005433925272	08585B	1315 833835	PAVEL EGOROV	{"phone": "+70896073227"}
0005433925273	08585B	4528 737052	ALEKSANDR KOZLOV	{"phone": "+70770447397"}
0005433925274	84313B	5436 222192	ALEKSANDR DAVYDOV	{"email": "davydova-091969@postgrespro.ru", "phone": "+70994664201"}
0005433925275	58051C	7260 242393	IVAN SOKOLOV	{"phone": "+70268173806"}
0005433925276	58051C	1060 050236	ALEKSANDR NIKOLAEV	{"phone": "+70148893244"}
0005433925277	812BEE	8922 905561	GUZEL ZHUKOVA	{"phone": "+70427978034"}
0005433925278	812BEE	4173 459246	LIDIYA SOKOLOVA	{"email": "lsokolova_18091974@postgrespro.ru", "phone": "+70735819312"}
0005433925279	8E1114	2349 999832	ALEKSEY FOMIN	{"phone": "+70681808194"}
0005433925280	49842F	5139 809422	ANASTASIYA AFANASEVA	{"email": "afanaseva.a1972@postgrespro.ru", "phone": "+70571994640"}
0005433925281	49842F	8392 744519	VLADIMIR MOROZOV	{"phone": "+70913597966"}
0005433925282	49842F	1640 174042	NADEZHDA ANDREEVA	{"email": "andreevan-14091970@postgrespro.ru", "phone": "+70844486214"}
0005433925283	91B775	6717 748705	YULIYA PETROVA	{"phone": "+70043515906"}
0005433925284	3196C9	7788 641410	MIKHAIL FILIPPOV	{"email": "mikhail.filippov_02101976@postgrespro.ru", "phone": "+70878629150"}
0005433925285	3196C9	8334 938937	YULIYA FILIPPOVA	{"email": "yuliya_filippova.081975@postgrespro.ru", "phone": "+70037071723"}
0005433925286	60DF6A	7631 845850	ALEKSEY POPOV	{"phone": "+70065788334"}
0005433925287	60DF6A	4057 245167	LYUBOV AFANASEVA	{"phone": "+70199292591"}
0005433925288	8E1540	8273 265261	SVETLANA LEBEDEVA	{"phone": "+70768812288"}
0005433925289	8DC018	6376 459355	NIKITA SCHERBAKOV	{"email": "scherbakovnikita-1976@postgrespro.ru", "phone": "+70692707533"}
0005433925290	8565B3	2960 359160	DMITRIY ZAYCEV	{"email": "zaycev-d-1984@postgrespro.ru", "phone": "+70478176406"}
0005433925291	0B927D	4708 576334	MARIYA ALEKSEEVA	{"email": "alekseeva.mariya-121976@postgrespro.ru", "phone": "+70647057129"}
0005433925292	80BC43	1745 435777	VALENTIN KAZAKOV	{"email": "kazakov_v1968@postgrespro.ru", "phone": "+70135878148"}
0005433925293	CBAAAD	8519 759377	EVGENIY NAZAROV	{"email": "nazarovevgeniy.1971@postgrespro.ru", "phone": "+70323980910"}
0005433925294	61972E	4639 800533	IRINA EGOROVA	{"phone": "+70866628939"}
0005433925295	61972E	4420 938740	ELENA MAKAROVA	{"phone": "+70968589007"}
0005433925296	21925B	5401 362444	VLADIMIR FEDOTOV	{"email": "vladimir-fedotov1962@postgrespro.ru", "phone": "+70279170965"}
0005433925297	21925B	1791 962416	VALERIY ZHURAVLEV	{"email": "zhuravlev-valeriy.28101973@postgrespro.ru", "phone": "+70499648733"}
0005433925298	1579AF	5415 262117	NATALIYA NESTEROVA	{"phone": "+70056981744"}
0005433925299	68D07D	8110 595047	ELENA GAVRILOVA	{"phone": "+70630215776"}
0005433925300	DD595A	3079 191530	SVETLANA MARTYNOVA	{"phone": "+70795698870"}
0005433925301	3E8418	6466 669721	ANATOLIY TARASOV	{"phone": "+70559355582"}
0005433925302	3E8418	4754 357354	NATALYA MAKAROVA	{"email": "natalya-makarova_1970@postgrespro.ru", "phone": "+70155866245"}
0005433925303	066CF9	0455 328127	OLEG STEPANOV	{"phone": "+70941962615"}
0005433925304	DDE2A2	2882 099035	NIKOLAY SIDOROV	{"phone": "+70217996692"}
0005433925305	DDE2A2	9297 078332	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov03121972@postgrespro.ru", "phone": "+70643682196"}
0005433925306	F5A794	4158 106178	SERGEY SAVELEV	{"phone": "+70303200079"}
0005433925307	F5A794	3216 015447	SOFYA KONOVALOVA	{"email": "konovalova.s.1964@postgrespro.ru", "phone": "+70716024563"}
0005433925308	8E7DEC	0811 530290	SERGEY VASILEV	{"email": "svasilev-13111966@postgrespro.ru", "phone": "+70885844527"}
0005433925309	9255EF	9009 703105	NATALYA ORLOVA	{"phone": "+70385210665"}
0005433925310	91D89F	6633 363782	NINA ARKHIPOVA	{"phone": "+70695200053"}
0005433925311	91D89F	6193 035881	DMITRIY KOZLOV	{"email": "kozlov.d.17081984@postgrespro.ru", "phone": "+70328751366"}
0005433925312	6C37D6	0452 698266	ALEKSANDR STEPANOV	{"phone": "+70211230666"}
0005433925313	243FD2	0063 390857	NATALYA SMIRNOVA	{"email": "smirnovanatalya-21101973@postgrespro.ru", "phone": "+70452895080"}
0005433925314	243FD2	4873 945664	MARGARITA BELOVA	{"phone": "+70261862252"}
0005433925315	390198	2508 988614	EVGENIYA PAVLOVA	{"phone": "+70872953156"}
0005433925316	B7D147	2083 303798	ARTEM EGOROV	{"phone": "+70550063841"}
0005433925317	C7DBCD	6218 796803	SVETLANA NIKITINA	{"phone": "+70632044257"}
0005433925318	6B3C46	9505 893385	NIKOLAY IVANOV	{"phone": "+70828952737"}
0005433925319	EC5948	5033 920035	ARTEM SOKOLOV	{"phone": "+70717887222"}
0005433925498	317E7F	8669 761897	VALENTINA AFANASEVA	{"phone": "+70880392795"}
0005433925320	E1665E	7164 364437	ROMAN POPOV	{"email": "popov_r.1974@postgrespro.ru", "phone": "+70028010482"}
0005433925321	4A6518	3464 360024	RASHID ZHUKOV	{"email": "zhukov_rashid_031974@postgrespro.ru", "phone": "+70869365208"}
0005433925322	FBE5F0	7110 626988	YURIY POPOV	{"email": "popov.y-17081976@postgrespro.ru", "phone": "+70915034816"}
0005433925323	610A2D	6119 359994	LEONID SMIRNOV	{"phone": "+70019527985"}
0005433925324	709371	4536 871193	OLGA FROLOVA	{"email": "olga-frolova-081972@postgrespro.ru", "phone": "+70884955153"}
0005433925325	CCD2C7	5467 928861	VALENTIN PETROV	{"email": "v-petrov061976@postgrespro.ru", "phone": "+70025901028"}
0005433925326	CCD2C7	4182 974081	EGOR KUZNECOV	{"phone": "+70520019932"}
0005433925327	BAD3AA	7829 899902	SERGEY ANTONOV	{"email": "sergeyantonov_09031964@postgrespro.ru", "phone": "+70062289165"}
0005433925328	ED8D04	3765 897149	ARTEM GUSEV	{"phone": "+70091883825"}
0005433925329	D1DBB1	7293 840276	SVETLANA GUSEVA	{"email": "s_guseva_25041973@postgrespro.ru", "phone": "+70181142564"}
0005433925330	D1DBB1	3456 559808	ANDREY RODIONOV	{"email": "a.rodionov071961@postgrespro.ru", "phone": "+70273818289"}
0005433925331	36D5FB	1818 060384	ROMAN TIKHONOV	{"phone": "+70069171974"}
0005433925332	89331C	7856 253958	VIKTORIYA MAKSIMOVA	{"phone": "+70695860327"}
0005433925333	0C0558	3787 430019	ZINAIDA GORBUNOVA	{"email": "gorbunova-z22111984@postgrespro.ru", "phone": "+70243200412"}
0005433925334	C664A9	9708 392815	OLGA FEDOROVA	{"phone": "+70974386705"}
0005433925335	5456DA	5311 742358	RAISA FOMINA	{"email": "fomina-raisa_1972@postgrespro.ru", "phone": "+70295161903"}
0005433925336	5456DA	0769 557084	VIKTOR GORBUNOV	{"email": "vgorbunov-10021965@postgrespro.ru", "phone": "+70164344992"}
0005433925337	8ED3F3	8050 885267	LYUDMILA VLASOVA	{"email": "lyudmila.vlasova.041988@postgrespro.ru", "phone": "+70358604025"}
0005433925338	22D509	0862 324841	VLADIMIR STEPANOV	{"phone": "+70249313835"}
0005433925339	966A53	8090 961157	VIOLETTA KUZMINA	{"email": "kuzmina-violetta.1967@postgrespro.ru", "phone": "+70943672942"}
0005433925340	966A53	7472 671369	GENNADIY IVANOV	{"email": "gennadiy.ivanov10121966@postgrespro.ru", "phone": "+70011805826"}
0005433925341	CBB772	0980 428321	EKATERINA KUDRYASHOVA	{"phone": "+70493144743"}
0005433925342	CBB772	5963 576193	GALINA ALEKSEEVA	{"email": "galina-alekseeva-1978@postgrespro.ru", "phone": "+70706565822"}
0005433925343	BB6B57	3619 252014	OKSANA BOGDANOVA	{"email": "o.bogdanova-18081993@postgrespro.ru", "phone": "+70120284395"}
0005433925344	BB6B57	2806 608336	MARIYA NOVIKOVA	{"phone": "+70012792713"}
0005433925345	16F667	5214 743195	ANTONINA YAKOVLEVA	{"email": "yakovleva.antonina_17011974@postgrespro.ru", "phone": "+70717024557"}
0005433925346	063CB5	1624 441229	MAKSIM MEDVEDEV	{"phone": "+70046135783"}
0005433925347	001089	2498 775582	ALEVTINA ARKHIPOVA	{"email": "arkhipova.alevtina.1969@postgrespro.ru", "phone": "+70322252339"}
0005433925348	81F87B	5930 086776	ZHANNA NIKIFOROVA	{"phone": "+70225610998"}
0005433925349	95D3C2	0250 186015	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov-02111972@postgrespro.ru", "phone": "+70716941822"}
0005433925350	FB61DF	3703 119785	ANDREY TARASOV	{"phone": "+70016574719"}
0005433925351	50E749	5574 716656	KHALIDA GORBUNOVA	{"email": "khalida_gorbunova.031974@postgrespro.ru", "phone": "+70187464867"}
0005433925352	6BC88F	6792 196018	ALLA ZAYCEVA	{"phone": "+70415241503"}
0005433925353	6BC88F	8480 099723	NINA ZAKHAROVA	{"email": "zakharovanina.051976@postgrespro.ru", "phone": "+70677423704"}
0005433925354	12DAB1	8029 759003	ALEKSEY MOROZOV	{"phone": "+70188319279"}
0005433925355	12DAB1	9450 990044	NADEZHDA TARASOVA	{"email": "ntarasova-081975@postgrespro.ru", "phone": "+70651760109"}
0005433925356	6A8733	0799 147039	TATYANA DAVYDOVA	{"phone": "+70200471689"}
0005433925357	C2DEC0	5259 272940	ANDREY BARANOV	{"email": "baranova.041971@postgrespro.ru", "phone": "+70829167322"}
0005433925358	E70938	6433 765630	EVGENIY OSIPOV	{"email": "osipov.evgeniy_12071972@postgrespro.ru", "phone": "+70348615043"}
0005433925359	681434	4991 061331	VIKTORIYA ZAYCEVA	{"phone": "+70530325717"}
0005433925360	919E5F	8405 738851	LYUBOV MALYSHEVA	{"phone": "+70155131457"}
0005433925361	8FD32F	8008 924120	ARTEM AFANASEV	{"email": "artem.afanasev.10061970@postgrespro.ru", "phone": "+70384462116"}
0005433925362	8FD32F	0637 240635	ELIZAVETA EFREMOVA	{"email": "efremova_elizaveta_121974@postgrespro.ru", "phone": "+70999145026"}
0005433925363	A295F0	6975 911066	ALSU KULIKOVA	{"email": "alsu.kulikova-1968@postgrespro.ru", "phone": "+70925158761"}
0005433925421	9C3991	8302 595961	DANIIL SEMENOV	{"email": "daniil-semenov_011989@postgrespro.ru", "phone": "+70992770582"}
0005433925364	A295F0	3822 506076	ANASTASIYA KULIKOVA	{"email": "anastasiya.kulikova_12091969@postgrespro.ru", "phone": "+70374093728"}
0005433925365	2D64E3	6030 729037	EVGENIY BARANOV	{"email": "baranovevgeniy_031970@postgrespro.ru", "phone": "+70034702148"}
0005433925366	2D64E3	5386 011742	GALINA KOVALEVA	{"phone": "+70620167342"}
0005433925367	BCA972	6318 853029	VALENTINA ZAYCEVA	{"email": "valentina_zayceva_1977@postgrespro.ru", "phone": "+70212709107"}
0005433925368	6790A9	1676 303717	IRAIDA ILINA	{"email": "ilinai_1965@postgrespro.ru", "phone": "+70075509895"}
0005433925369	6790A9	6316 281282	ELENA KOROLEVA	{"phone": "+70641355516"}
0005433925370	47BB30	5478 665612	ALEKSEY ILIN	{"email": "ilinaleksey.111962@postgrespro.ru", "phone": "+70483999361"}
0005433925371	733572	9220 919389	RAMIL GORBUNOV	{"email": "gorbunov.ramil_1964@postgrespro.ru", "phone": "+70631835853"}
0005433925372	733572	9301 950611	ILYA KUZNECOV	{"email": "kuznecov_i_03021971@postgrespro.ru", "phone": "+70789367708"}
0005433925373	B5F9C1	4230 046965	ALEKSANDR SOROKIN	{"phone": "+70878503524"}
0005433925374	236796	8219 764632	MARIYA NOVIKOVA	{"email": "novikovam_1967@postgrespro.ru", "phone": "+70823750135"}
0005433925375	26939A	4364 655822	LARISA CHERNOVA	{"phone": "+70968699802"}
0005433925499	4C2856	2952 473333	ANATOLIY OSIPOV	{"phone": "+70469451147"}
0005433925376	315648	2909 294140	SERGEY MOROZOV	{"email": "sergeymorozov_23041969@postgrespro.ru", "phone": "+70661900674"}
0005433925377	E6762D	5692 565431	LIDIYA SOKOLOVA	{"phone": "+70698780432"}
0005433925378	317AFC	8805 323839	VALENTINA KOMAROVA	{"phone": "+70613333125"}
0005433925379	317AFC	3367 047923	ANASTASIYA PAVLOVA	{"email": "pavlova.anastasiya.1977@postgrespro.ru", "phone": "+70102881322"}
0005433925380	CACBBE	7748 148181	ANATOLIY MARTYNOV	{"phone": "+70136555551"}
0005433925381	CACBBE	1839 492907	VALENTIN RODIONOV	{"phone": "+70214086076"}
0005433925382	EDBCE7	2288 367204	RUSTEM KUDRYASHOV	{"phone": "+70162196741"}
0005433925383	B641D6	9249 452169	LYUBOV NIKOLAEVA	{"email": "nikolaeva-l08051984@postgrespro.ru", "phone": "+70426359306"}
0005433925384	E85C66	3490 607916	ZINAIDA MARTYNOVA	{"email": "z_martynova-121966@postgrespro.ru", "phone": "+70381710681"}
0005433925385	F4B9DB	0064 852589	PAVEL NOVIKOV	{"phone": "+70612064390"}
0005433925386	C8A7C5	7753 331220	VYACHESLAV VOROBEV	{"phone": "+70950763054"}
0005433925387	49CB53	8847 862322	NATALYA ERMAKOVA	{"phone": "+70242370060"}
0005433925388	B7C41F	1198 427822	IGOR DENISOV	{"phone": "+70136156496"}
0005433925389	147B2F	4522 975874	ANDREY ZHURAVLEV	{"phone": "+70169038798"}
0005433925390	147B2F	8978 403256	ANDREY POPOV	{"email": "a_popov_021972@postgrespro.ru", "phone": "+70834017143"}
0005433925391	D395CD	9549 773882	VALERIYA KOZLOVA	{"email": "valeriya_kozlova011973@postgrespro.ru", "phone": "+70872441846"}
0005433925392	D395CD	0437 740910	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov1958@postgrespro.ru", "phone": "+70762145484"}
0005433925393	CE348F	2810 190670	KLAVDIYA NIKIFOROVA	{"phone": "+70230008070"}
0005433925394	9D0FE8	6609 279553	RUSHANIYA MATVEEVA	{"phone": "+70323643185"}
0005433925395	9D0FE8	3262 008027	ALEKSEY MELNIKOV	{"phone": "+70091180070"}
0005433925396	9D0FE8	3032 108410	MIKHAIL ILIN	{"phone": "+70982325171"}
0005433925397	507260	9764 210326	ALEKSANDR KUZMIN	{"phone": "+70086449205"}
0005433925398	507260	9162 595830	ROMAN EGOROV	{"phone": "+70262773271"}
0005433925399	0D4DC2	7431 959383	ALEKSANDRA TARASOVA	{"email": "aleksandra_tarasova-01061957@postgrespro.ru", "phone": "+70652600297"}
0005433925400	9BA8D9	5495 574542	ANASTASIYA OSIPOVA	{"email": "osipova-anastasiya-1976@postgrespro.ru", "phone": "+70777150728"}
0005433925401	B38E6D	2739 746716	NATALYA KOMAROVA	{"phone": "+70004508435"}
0005433925402	B6F5CA	6441 913424	YULIYA VOROBEVA	{"email": "y-vorobeva22091969@postgrespro.ru", "phone": "+70658231977"}
0005433925403	3E308D	0192 044350	GALIYA MEDVEDEVA	{"phone": "+70554991647"}
0005433925404	0DF068	8497 157025	ALEKSANDR SAVELEV	{"phone": "+70333803431"}
0005433925405	B34B56	8348 239171	NATALYA FROLOVA	{"email": "natalya.frolova.1966@postgrespro.ru", "phone": "+70208221341"}
0005433925406	A3E533	2717 127314	MIKHAIL GUSEV	{"email": "gusev_m-14031980@postgrespro.ru", "phone": "+70934094833"}
0005433925407	EE658A	4479 754295	IRINA NOVIKOVA	{"phone": "+70918495261"}
0005433925408	7C76F0	0499 636311	NIKOLAY SERGEEV	{"email": "n_sergeev-05121963@postgrespro.ru", "phone": "+70858210972"}
0005433925409	2820B7	7415 608953	OLEG KUZNECOV	{"phone": "+70416300935"}
0005433925410	0573FC	4233 040330	NATALYA MEDVEDEVA	{"phone": "+70213637306"}
0005433925411	0573FC	2585 209612	ZOYA EGOROVA	{"phone": "+70967998891"}
0005433925412	8CEE74	2421 022736	GENNADIY MAKAROV	{"phone": "+70494979802"}
0005433925413	8CEE74	7234 775826	IVAN ANDREEV	{"phone": "+70874530698"}
0005433925414	5FF1D9	2159 523502	ALINA KAZAKOVA	{"phone": "+70260984985"}
0005433925415	AC9600	8372 558220	LYUDMILA FOMINA	{"email": "lyudmila.fomina.111965@postgrespro.ru", "phone": "+70310681684"}
0005433925416	C17743	2594 236153	OLGA KUZNECOVA	{"email": "kuznecova.o.30051979@postgrespro.ru", "phone": "+70796167537"}
0005433925417	67F49A	2218 317320	MARIYA TIMOFEEVA	{"email": "timofeeva.m.1970@postgrespro.ru", "phone": "+70489166585"}
0005433925418	AA70B6	2995 451761	GALINA NIKITINA	{"phone": "+70194130727"}
0005433925419	0F3884	5984 315748	ELENA TITOVA	{"email": "e.titova.121976@postgrespro.ru", "phone": "+70170625690"}
0005433925420	E321B1	8298 207675	KONSTANTIN IVANOV	{"email": "ivanovk1978@postgrespro.ru", "phone": "+70962724712"}
0005433925422	3D2EE2	5455 434010	ANATOLIY GUSEV	{"email": "guseva01121983@postgrespro.ru", "phone": "+70603551879"}
0005433925423	D65049	0689 221317	VLADIMIR EGOROV	{"email": "egorovvladimir.06061964@postgrespro.ru", "phone": "+70397911350"}
0005433925424	92234F	2996 734517	NIKOLAY KUZNECOV	{"phone": "+70182696565"}
0005433925425	25AC9B	5972 032501	SERGEY POPOV	{"phone": "+70406399657"}
0005433925426	D6F0A0	3595 346887	NINA MIKHAYLOVA	{"phone": "+70611199836"}
0005433925427	5199F3	3390 966880	MATVEY KARPOV	{"email": "karpov.matvey-111973@postgrespro.ru", "phone": "+70662524087"}
0005433925428	0C922A	5087 203121	VALENTINA RYABOVA	{"email": "ryabova_v-17061978@postgrespro.ru", "phone": "+70559529383"}
0005433925429	0C922A	1560 013057	ANATOLIY FOMIN	{"email": "fomina1963@postgrespro.ru", "phone": "+70027239299"}
0005433925430	0C922A	4581 180841	ALEKSANDR KONOVALOV	{"email": "konovalov_a_021982@postgrespro.ru", "phone": "+70614544398"}
0005433925431	76EE17	7430 375207	EVGENIY GORBUNOV	{"phone": "+70737136868"}
0005433925432	76EE17	5894 242747	DANIS IVANOV	{"phone": "+70782567698"}
0005433925433	86F979	6125 971689	SERGEY KISELEV	{"email": "kiselevs-1972@postgrespro.ru", "phone": "+70462706697"}
0005433925434	76A8C7	5814 885169	MAKSIM FILIPPOV	{"email": "filippov.maksim081973@postgrespro.ru", "phone": "+70179386832"}
0005433925435	76A8C7	8897 608792	ELENA KUZNECOVA	{"phone": "+70564861012"}
0005433925436	F573DF	6274 781655	NIKOLAY ALEKSANDROV	{"email": "naleksandrov.1971@postgrespro.ru", "phone": "+70860219786"}
0005433925437	3C5225	2989 605207	MARIYA CHERNOVA	{"phone": "+70544329782"}
0005433925438	3C5225	1452 131087	EGOR KOZLOV	{"email": "kozlove_061967@postgrespro.ru", "phone": "+70177032467"}
0005433925439	1881C2	8186 027917	RUSTAM MIRONOV	{"email": "mironov.r-1982@postgrespro.ru", "phone": "+70560712681"}
0005433925440	1881C2	7477 267579	DARYA LOGINOVA	{"email": "darya-loginova-091972@postgrespro.ru", "phone": "+70124333101"}
0005433925441	9F8684	3345 337756	VERONIKA ALEKSANDROVA	{"phone": "+70516472760"}
0005433925442	F045E2	7835 381632	NADEZHDA NAZAROVA	{"phone": "+70337739538"}
0005433925443	C95830	6947 993257	NATALYA KARPOVA	{"phone": "+70653449058"}
0005433925444	243959	0055 089271	VLADISLAV BORISOV	{"phone": "+70415034630"}
0005433925445	243959	5398 899569	PETR SEMENOV	{"phone": "+70114854950"}
0005433925446	0063B3	2426 917684	DMITRIY POPOV	{"email": "dmitriy.popov-31081979@postgrespro.ru", "phone": "+70222536431"}
0005433925447	0063B3	9500 306242	TATYANA SEMENOVA	{"email": "tatyana-semenova_071983@postgrespro.ru", "phone": "+70545866741"}
0005433925448	7B5E3F	4397 382697	DMITRIY ZAYCEV	{"email": "zaycevdmitriy_041977@postgrespro.ru", "phone": "+70138590075"}
0005433925449	0B7C12	3333 662505	VLADIMIR NIKOLAEV	{"phone": "+70713454019"}
0005433925450	497433	6999 662092	GALINA KULIKOVA	{"email": "gkulikova1974@postgrespro.ru", "phone": "+70773569722"}
0005433925451	497433	5212 677990	NATALYA KUZMINA	{"phone": "+70937113768"}
0005433925452	E81CF6	6856 585144	ANNA YUDINA	{"phone": "+70180160416"}
0005433925453	704D01	4717 093751	DENIS VASILEV	{"phone": "+70164365476"}
0005433925454	887595	8833 331310	VERA MOISEEVA	{"phone": "+70908226077"}
0005433925455	4A19A9	1871 019596	TATYANA SOKOLOVA	{"email": "t_sokolova_07051985@postgrespro.ru", "phone": "+70226276272"}
0005433925456	4A19A9	5159 761755	LYUCIYA SOLOVEVA	{"email": "l.soloveva-08071975@postgrespro.ru", "phone": "+70565914968"}
0005433925457	F6F038	0688 207381	GALINA MAKSIMOVA	{"email": "maksimovagalina.17021976@postgrespro.ru", "phone": "+70028359125"}
0005433925458	6F5CC1	2336 165985	ANDREY SERGEEV	{"email": "sergeev.a051974@postgrespro.ru", "phone": "+70452863219"}
0005433925459	6F5CC1	5596 207603	ELENA MAKAROVA	{"email": "makarova.e.23091968@postgrespro.ru", "phone": "+70876392154"}
0005433925460	D648D6	0385 671213	VALENTINA MOISEEVA	{"email": "valentina_moiseeva-1973@postgrespro.ru", "phone": "+70999184336"}
0005433925461	080DF7	1192 205435	MAKSIM PAVLOV	{"email": "maksim.pavlov-031966@postgrespro.ru", "phone": "+70654299093"}
0005433925462	080DF7	7718 575416	KLAVDIYA KUZNECOVA	{"phone": "+70996769042"}
0005433925463	24257B	5417 902056	INNA MAKAROVA	{"email": "innamakarova.111966@postgrespro.ru", "phone": "+70478902446"}
0005433925464	789490	1793 433074	PETR OSIPOV	{"email": "osipov_petr.06051972@postgrespro.ru", "phone": "+70858297228"}
0005433925465	789490	9624 775652	MARGARITA KUZNECOVA	{"email": "m-kuznecova22021986@postgrespro.ru", "phone": "+70820805516"}
0005433925466	AB95DD	5251 432395	IRINA SIDOROVA	{"email": "i.sidorova-1970@postgrespro.ru", "phone": "+70782788562"}
0005433925467	1F80DD	5236 740759	IVAN NAZAROV	{"phone": "+70644576530"}
0005433925468	B672E9	6042 756922	SERGEY GRIGOREV	{"email": "sgrigorev_111968@postgrespro.ru", "phone": "+70406860101"}
0005433925469	B672E9	2735 852732	SERGEY EGOROV	{"email": "egorov-sergey_061976@postgrespro.ru", "phone": "+70981883336"}
0005433925470	4B2EBC	9637 931183	OLEG YAKOVLEV	{"email": "yakovlevoleg_011985@postgrespro.ru", "phone": "+70304917683"}
0005433925471	1B526D	4655 445441	GENNADIY AFANASEV	{"email": "gennadiy_afanasev_01081973@postgrespro.ru", "phone": "+70202716136"}
0005433925472	1B526D	3476 674117	TATYANA KAZAKOVA	{"phone": "+70499313384"}
0005433925473	1B526D	1841 076569	MARIYA IVANOVA	{"email": "ivanova-mariya27051977@postgrespro.ru", "phone": "+70853054637"}
0005433925474	DC696D	4532 107074	ANDREY CHERNOV	{"phone": "+70695832165"}
0005433925475	39A2CB	7222 217347	DENIS DAVYDOV	{"phone": "+70879897265"}
0005433925476	42B845	6887 361704	SERGEY SHEVCHENKO	{"phone": "+70403298953"}
0005433925477	F0F29B	4246 281878	SVETLANA ZAKHAROVA	{"phone": "+70823832029"}
0005433925478	F0F29B	9066 040467	DENIS POPOV	{"email": "popov_denis_031957@postgrespro.ru", "phone": "+70311322058"}
0005433925479	94BB28	4136 676980	DENIS MEDVEDEV	{"email": "medvedev.d-09101973@postgrespro.ru", "phone": "+70333686450"}
0005433925480	94BB28	2384 929375	YULIYA LAZAREVA	{"email": "y_lazareva.18121968@postgrespro.ru", "phone": "+70572776273"}
0005433925481	AEDB50	7585 024589	EVGENIY SOROKIN	{"email": "e-sorokin12121967@postgrespro.ru", "phone": "+70516001715"}
0005433925482	AEDB50	5808 684627	RINAT STEPANOV	{"email": "rstepanov-17111970@postgrespro.ru", "phone": "+70912956375"}
0005433925483	EB62AF	1544 130820	ROMAN NOVIKOV	{"email": "roman.novikov011976@postgrespro.ru", "phone": "+70377069927"}
0005433925484	8FAFD8	3903 497084	NADEZHDA AKIMOVA	{"phone": "+70913613257"}
0005433925485	8FAFD8	2873 531971	VIKTOR ABRAMOV	{"email": "viktor.abramov_1974@postgrespro.ru", "phone": "+70668390705"}
0005433925486	29CEED	2658 505952	NATALYA NIKOLAEVA	{"email": "nikolaeva_n021973@postgrespro.ru", "phone": "+70410619451"}
0005433925487	F8044F	7523 910452	ELIZAVETA DANILOVA	{"email": "e.danilova-1963@postgrespro.ru", "phone": "+70884616061"}
0005433925488	F8044F	7853 133123	OLGA BELYAEVA	{"email": "olga_belyaeva.121977@postgrespro.ru", "phone": "+70152044964"}
0005433925489	541AA9	0710 449663	PAVEL KOROLEV	{"email": "korolev.p_051978@postgrespro.ru", "phone": "+70140347540"}
0005433925490	884F0C	0885 176606	NATALYA MAKAROVA	{"email": "makarova-natalya-1977@postgrespro.ru", "phone": "+70399268375"}
0005433925491	884F0C	4597 495423	EVGENIY NAUMOV	{"email": "naumov_evgeniy.1967@postgrespro.ru", "phone": "+70806001262"}
0005433925492	884F0C	1320 316065	TATYANA KUZNECOVA	{"phone": "+70250596057"}
0005433925493	BFFFBD	9792 037111	ELENA ILINA	{"phone": "+70026609723"}
0005433925494	036895	1580 396316	ALEKSANDR MOROZOV	{"email": "morozova.1967@postgrespro.ru", "phone": "+70830365761"}
0005433925495	036895	8817 445477	ALINA SEMENOVA	{"phone": "+70285387326"}
0005433925496	B037A8	0064 516841	LIDIYA TARASOVA	{"phone": "+70558904099"}
0005433925500	D65428	6481 047505	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_111971@postgrespro.ru", "phone": "+70568482876"}
0005433925501	35B062	6854 370751	KONSTANTIN KISELEV	{"phone": "+70904343509"}
0005433925502	35B062	8058 154457	ELENA ANDREEVA	{"phone": "+70265748408"}
0005433925503	22966E	9254 010772	MARIYA MIKHAYLOVA	{"email": "mariyamikhaylova_091985@postgrespro.ru", "phone": "+70378799498"}
0005433925504	182B84	9321 251340	LIDIYA MOROZOVA	{"email": "morozova_lidiya.29041967@postgrespro.ru", "phone": "+70831818083"}
0005433925505	341AF6	2655 482116	NIKOLAY TARASOV	{"email": "tarasovn-08061958@postgrespro.ru", "phone": "+70550385621"}
0005433925506	06073A	1855 599250	YURIY SOKOLOV	{"phone": "+70085732981"}
0005433925507	06073A	7367 139984	EKATERINA NESTEROVA	{"phone": "+70108763580"}
0005433925508	1AF594	6621 394410	RAISA IVANOVA	{"email": "ivanova.raisa_1968@postgrespro.ru", "phone": "+70426479678"}
0005433925509	1AF594	4417 405335	ALEKSEY ISAEV	{"email": "isaev_aleksey09091977@postgrespro.ru", "phone": "+70973930715"}
0005433925510	324E4F	4268 481890	ALEKSANDR KOZLOV	{"phone": "+70813997730"}
0005433925511	324E4F	2019 329518	ELENA FEDOROVA	{"phone": "+70614503925"}
0005433925512	A86203	2137 198714	SERGEY MOROZOV	{"phone": "+70434361793"}
0005433925513	A86203	4781 577980	SVETLANA EFIMOVA	{"email": "efimova-s031971@postgrespro.ru", "phone": "+70155163426"}
0005433925514	9823A0	1585 696122	IREK TIKHONOV	{"phone": "+70985637128"}
0005433925515	5DF088	8582 490951	YURIY DAVYDOV	{"email": "yuriydavydov1977@postgrespro.ru", "phone": "+70919834038"}
0005433925516	394BB7	7824 959956	ELENA VOLKOVA	{"phone": "+70366049451"}
0005433925517	1E2B8A	0243 735786	TAMARA POTAPOVA	{"email": "potapovatamara_101990@postgrespro.ru", "phone": "+70756653448"}
0005433925518	6CB61C	2626 797800	VLADIMIR MOISEEV	{"phone": "+70596807304"}
0005433925519	169845	4724 994684	OLGA FILATOVA	{"email": "o-filatova-17021966@postgrespro.ru", "phone": "+70708088699"}
0005433925520	169845	4404 767455	TATYANA SOKOLOVA	{"phone": "+70034658091"}
0005433925521	6DCB4F	3194 691583	VLADIMIR KOROLEV	{"email": "v-korolev_081985@postgrespro.ru", "phone": "+70497922244"}
0005433925522	3D933C	2301 825829	TAMARA ZOTOVA	{"email": "zotova_tamara.16101971@postgrespro.ru", "phone": "+70625630718"}
0005433925523	44233E	3006 466448	BORIS SOROKIN	{"email": "sorokinboris.02041970@postgrespro.ru", "phone": "+70145974718"}
0005433925524	5023DD	7084 659251	LARISA NAUMOVA	{"email": "larisanaumova.021976@postgrespro.ru", "phone": "+70428538790"}
0005433925525	5023DD	0654 331806	ANTON MELNIKOV	{"phone": "+70033134460"}
0005433925526	FF0F34	4601 834750	GLEB MIKHAYLOV	{"phone": "+70511301845"}
0005433925527	FFB33F	4143 436194	LIDIYA POPOVA	{"email": "popoval_1975@postgrespro.ru", "phone": "+70895228196"}
0005433925528	FFB33F	3139 560658	MARIYA ARKHIPOVA	{"email": "mariya_arkhipova-07031970@postgrespro.ru", "phone": "+70879533183"}
0005433925529	FFB33F	6872 639384	SERGEY SOROKIN	{"email": "sergey_sorokin_1980@postgrespro.ru", "phone": "+70025090878"}
0005433925530	223FBE	4068 015656	IRINA ANTONOVA	{"email": "i.antonova1976@postgrespro.ru", "phone": "+70946575539"}
0005433925531	223FBE	3595 386261	LYUDMILA PAVLOVA	{"phone": "+70695894547"}
0005433925532	B35BE4	4075 576643	PETR NIKOLAEV	{"email": "pnikolaev-071971@postgrespro.ru", "phone": "+70075387201"}
0005433925533	2B3319	6562 399092	VIKTOR ORLOV	{"email": "viktor_orlov_16021968@postgrespro.ru", "phone": "+70547055314"}
0005433925534	2B3319	8168 889555	MIKHAIL GUSEV	{"email": "mgusev1967@postgrespro.ru", "phone": "+70485383560"}
0005433925535	1A8F75	4366 678594	VALERIY ANDREEV	{"email": "v-andreev1968@postgrespro.ru", "phone": "+70029158433"}
0005433925536	FE7CB7	1954 615194	VIKTOR BORISOV	{"email": "viktor_borisov_29101976@postgrespro.ru", "phone": "+70799823241"}
0005433925537	9C92BC	5496 091877	ANDREY FROLOV	{"email": "frolov_a_1969@postgrespro.ru", "phone": "+70655825982"}
0005433925538	9C92BC	1870 615124	DANIIL GERASIMOV	{"email": "gerasimov-d.121971@postgrespro.ru", "phone": "+70419028350"}
0005433925539	82867E	6602 784450	MARAT ALEKSANDROV	{"phone": "+70237190935"}
0005433925540	022BA3	7958 496403	VYACHESLAV KUZMIN	{"email": "kuzmin_vyacheslav.1971@postgrespro.ru", "phone": "+70290720232"}
0005433925541	49CAEE	8518 223075	VALERIY KOZLOV	{"email": "valeriykozlov_10091962@postgrespro.ru", "phone": "+70149678278"}
0005433925542	49CAEE	5074 398957	GENNADIY DENISOV	{"phone": "+70605150118"}
0005433925543	7886F9	5052 750279	NADEZHDA KUDRYASHOVA	{"email": "kudryashova.n-011962@postgrespro.ru", "phone": "+70960652451"}
0005433925544	7886F9	5222 116408	EGOR MAKSIMOV	{"email": "maksimov_egor.1972@postgrespro.ru", "phone": "+70680337724"}
0005433925545	7886F9	2461 372706	MIKHAIL MATVEEV	{"email": "m_matveev25081963@postgrespro.ru", "phone": "+70864101047"}
0005433925546	E61DAC	3632 005406	EKATERINA ABRAMOVA	{"email": "e.abramova.1972@postgrespro.ru", "phone": "+70481714697"}
0005433925547	35FBAE	9502 609141	EKATERINA MARTYNOVA	{"email": "martynova_e061969@postgrespro.ru", "phone": "+70713497859"}
0005433925548	35FBAE	7149 513021	VLADIMIR ALEKSEEV	{"email": "alekseevvladimir.28051975@postgrespro.ru", "phone": "+70672821660"}
0005433925549	208086	3833 935254	EVGENIY SOKOLOV	{"phone": "+70114023614"}
0005433925550	B30C94	1001 127409	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov-vyacheslav_1977@postgrespro.ru", "phone": "+70541430725"}
0005433925551	B30C94	5998 147574	ANATOLIY SCHERBAKOV	{"phone": "+70635772362"}
0005433925552	F1CC88	5479 873492	TATYANA SOLOVEVA	{"email": "soloveva_t-031972@postgrespro.ru", "phone": "+70289651470"}
0005433925553	F1CC88	8686 725475	VLADIMIR MELNIKOV	{"phone": "+70676046192"}
0005433925554	765153	9037 857905	LYUDMILA GORBUNOVA	{"email": "gorbunova_l_1972@postgrespro.ru", "phone": "+70650649419"}
0005433925555	F5A7C5	0603 985667	OLEG SAVELEV	{"phone": "+70269382819"}
0005433925556	F5A7C5	6375 085728	SEMEN ANDREEV	{"phone": "+70221254747"}
0005433925557	F5A7C5	2284 799815	NINA SOLOVEVA	{"phone": "+70668573426"}
0005433925558	DE7311	6481 793134	IVAN MOROZOV	{"phone": "+70736831278"}
0005433925559	351A9D	4854 351240	ANATOLIY KAZAKOV	{"phone": "+70716283505"}
0005433925560	6CE295	4644 409584	VLADIMIR NIKITIN	{"phone": "+70184642250"}
0005433925561	669366	3513 998306	SERGEY BORISOV	{"email": "sergey_borisov1978@postgrespro.ru", "phone": "+70355604396"}
0005433925562	669366	9448 805029	LYUDMILA LUKYANOVA	{"phone": "+70195109529"}
0005433925563	02F348	3837 015133	IRINA SIDOROVA	{"phone": "+70343134121"}
0005433925564	2CE6AA	3865 717378	VYACHESLAV TARASOV	{"phone": "+70489507507"}
0005433925565	2AFA69	1680 347219	MARIYA KOROLEVA	{"email": "mkoroleva061975@postgrespro.ru", "phone": "+70655497522"}
0005433925566	FB5056	6192 564000	DMITRIY ILIN	{"email": "ilin.d.111981@postgrespro.ru", "phone": "+70172708435"}
0005433925567	D4BBFC	1503 746807	RAISA SOKOLOVA	{"phone": "+70578506850"}
0005433925568	D4BBFC	5551 253487	VLADIMIR MATVEEV	{"phone": "+70446866850"}
0005433925569	D4BBFC	9454 804288	VIKTOR IVANOV	{"phone": "+70320658893"}
0005433925570	76DE51	5375 099735	RAISA KOZLOVA	{"email": "r.kozlova1969@postgrespro.ru", "phone": "+70903463458"}
0005433925571	76DE51	8274 868324	KSENIYA ABRAMOVA	{"email": "abramova.k.23121972@postgrespro.ru", "phone": "+70877457089"}
0005433925572	76DE51	7850 086181	NATALYA ROMANOVA	{"phone": "+70633503434"}
0005433925573	FA5A64	3457 758496	ALEKSEY ISAEV	{"phone": "+70421631732"}
0005433925574	5F3CB8	7729 060547	SVETLANA LOGINOVA	{"email": "svetlanaloginova_011984@postgrespro.ru", "phone": "+70975286620"}
0005433925575	5F3CB8	2788 511154	NATALYA MELNIKOVA	{"email": "natalyamelnikova_15011963@postgrespro.ru", "phone": "+70347579450"}
0005433925576	83DF38	6309 925766	RUFIYA ANISIMOVA	{"email": "rufiya-anisimova12041969@postgrespro.ru", "phone": "+70159809241"}
0005433925577	83DF38	2789 987422	LIDIYA ANDREEVA	{"phone": "+70805877212"}
0005433925578	FEC0F7	3493 449697	ELENA LAZAREVA	{"email": "elazareva-25011977@postgrespro.ru", "phone": "+70469943797"}
0005433925579	FEC0F7	5405 430129	GALINA ZHURAVLEVA	{"email": "zhuravlevagalina-121970@postgrespro.ru", "phone": "+70666551854"}
0005433925580	781F4D	5529 475125	SERGEY NOVIKOV	{"email": "s_novikov.1975@postgrespro.ru", "phone": "+70123048402"}
0005433925581	42EABA	6029 760889	MAKSIM KUZNECOV	{"email": "kuznecov.m.1971@postgrespro.ru", "phone": "+70220245408"}
0005433925582	41C725	0226 825117	ALEKSANDR VOLKOV	{"phone": "+70270637565"}
0005433925583	EC3E9C	3257 785360	ASIYA IVANOVA	{"phone": "+70791460550"}
0005433925584	B5640A	6557 151267	SERGEY SEMENOV	{"phone": "+70989370547"}
0005433925585	B5640A	1617 065122	ANASTASIYA AKIMOVA	{"email": "akimovaa_081972@postgrespro.ru", "phone": "+70046887561"}
0005433925586	D7CDCF	5775 052407	OLGA CHERNOVA	{"phone": "+70511051948"}
0005433925587	EC89C0	6109 793727	EGOR NAZAROV	{"email": "egor_nazarov-12051964@postgrespro.ru", "phone": "+70728081789"}
0005433925588	EC89C0	2373 084584	VLADISLAV BORISOV	{"phone": "+70032821268"}
0005433925589	687A1D	6668 230059	MARIYA GAVRILOVA	{"email": "mgavrilova_1970@postgrespro.ru", "phone": "+70542843763"}
0005433925590	C05EC7	4281 402341	YULIYA FOMINA	{"phone": "+70887185982"}
0005433925591	79B397	4884 959250	MIKHAIL POPOV	{"email": "mikhail_popov-101967@postgrespro.ru", "phone": "+70646237732"}
0005433925592	657AEF	2959 848175	MARGARITA POPOVA	{"phone": "+70504972492"}
0005433925593	657AEF	6896 742956	ALEKSANDR MIRONOV	{"phone": "+70220877573"}
0005433925594	A108DB	9719 718343	INNA SAVELEVA	{"phone": "+70328577506"}
0005433925595	F2ADA4	5395 067796	LYUBOV ROMANOVA	{"email": "romanova.lyubov_041975@postgrespro.ru", "phone": "+70686415187"}
0005433925596	F2ADA4	5511 556288	ROMAN MELNIKOV	{"email": "melnikov.roman-051983@postgrespro.ru", "phone": "+70213360070"}
0005433925597	F2ADA4	8532 656448	GALINA LEBEDEVA	{"phone": "+70113140538"}
0005433925598	4E3BB1	5220 143916	ANGELINA SERGEEVA	{"email": "asergeeva-11111966@postgrespro.ru", "phone": "+70317294978"}
0005433925599	4E3BB1	3631 469620	IRINA FROLOVA	{"phone": "+70251067930"}
0005433925600	330820	9078 004826	RINAT ZAKHAROV	{"email": "zakharov_r.14071980@postgrespro.ru", "phone": "+70352979950"}
0005433925601	330820	9838 394687	DINARA BORISOVA	{"email": "borisova.dinara-1966@postgrespro.ru", "phone": "+70004658765"}
0005433925602	B55CC4	1109 185136	LYUBOV NIKOLAEVA	{"email": "nikolaeva-lyubov1978@postgrespro.ru", "phone": "+70277102313"}
0005433925603	B55CC4	0999 858368	NATALYA FEDOROVA	{"email": "fedorova_n26081966@postgrespro.ru", "phone": "+70878148236"}
0005433925604	B55CC4	0464 326784	NADEZHDA FOMINA	{"phone": "+70217066324"}
0005433925605	9D7708	1536 257386	VLADLEN NOVIKOV	{"phone": "+70087605999"}
0005433925606	114B0A	5623 458791	ELENA IVANOVA	{"email": "ivanovae071975@postgrespro.ru", "phone": "+70591347576"}
0005433925607	114B0A	2123 184950	ALEKSANDR KOROLEV	{"phone": "+70477582345"}
0005433925608	2C8286	6608 481899	ALEKSANDR ZAYCEV	{"phone": "+70097003397"}
0005433925609	279D0A	9804 972519	GENNADIY ALEKSEEV	{"phone": "+70354246480"}
0005433925610	CC6EE6	9965 358937	NIKOLAY VOROBEV	{"email": "nikolay_vorobev1986@postgrespro.ru", "phone": "+70084394594"}
0005433925611	7CD57E	8764 987605	TAMARA ZAKHAROVA	{"phone": "+70132513317"}
0005433925612	7CD57E	4092 210892	NATALYA AFANASEVA	{"email": "n_afanaseva-1976@postgrespro.ru", "phone": "+70770079087"}
0005433925613	92B5BE	6735 171038	SERGEY ALEKSEEV	{"phone": "+70916553179"}
0005433925614	1A9FC6	2102 055094	DIANA MAKSIMOVA	{"phone": "+70044023761"}
0005433925615	1A9FC6	4960 440549	ANDREY IVANOV	{"email": "ivanov_a_12091974@postgrespro.ru", "phone": "+70238228882"}
0005433925616	13A2F2	2934 126475	EVGENIYA KUZNECOVA	{"phone": "+70848482191"}
0005433925617	1E7808	2882 722627	TATYANA KARPOVA	{"email": "karpova-tatyana30041981@postgrespro.ru", "phone": "+70143637158"}
0005433925618	AD75F4	0738 894094	DMITRIY AFANASEV	{"email": "afanasev.dmitriy_081974@postgrespro.ru", "phone": "+70045571464"}
0005433925619	015400	1523 977910	ELENA MAKAROVA	{"phone": "+70018466650"}
0005433925620	493569	5274 202040	SERGEY FEDOROV	{"phone": "+70347156106"}
0005433925621	1FCA57	9648 315095	SERGEY SHEVCHENKO	{"email": "sergey_shevchenko1970@postgrespro.ru", "phone": "+70730257430"}
0005433925622	3E3BBE	7899 201197	ILDAR ANTONOV	{"email": "antonov_i061979@postgrespro.ru", "phone": "+70209556376"}
0005433925623	E3BB45	5411 101224	VLADIMIR SIDOROV	{"email": "sidorovvladimir.111963@postgrespro.ru", "phone": "+70134935574"}
0005433925624	8CD575	3597 677641	YURIY KOROLEV	{"phone": "+70832735969"}
0005433925625	F5D5CE	8738 828059	NIKOLAY ZHUKOV	{"phone": "+70316449441"}
0005433925626	F5D5CE	2532 738321	VLADISLAV KRASNOV	{"email": "krasnovvladislav_1974@postgrespro.ru", "phone": "+70108252838"}
0005433925627	F5D5CE	2323 833323	DARYA ZAYCEVA	{"email": "zayceva.d-1970@postgrespro.ru", "phone": "+70728735764"}
0005433925628	7D531C	3820 280195	SVETLANA MIKHAYLOVA	{"email": "s.mikhaylova-14081971@postgrespro.ru", "phone": "+70079467026"}
0005433925629	7D531C	8609 360900	KLARA ERMAKOVA	{"phone": "+70172491322"}
0005433925630	2CBE6C	4522 970008	NIKOLAY SEMENOV	{"phone": "+70328936859"}
0005433925631	CA7BAF	0271 446778	NADEZHDA DENISOVA	{"email": "denisovanadezhda_081970@postgrespro.ru", "phone": "+70684441946"}
0005433925632	CA7BAF	2892 059169	NINA POPOVA	{"phone": "+70270269825"}
0005433925633	72A521	7075 783280	VIKTOR KAZAKOV	{"phone": "+70538990590"}
0005433925634	C55BFB	8012 612010	PAVEL POPOV	{"phone": "+70043553077"}
0005433925635	C55BFB	6955 490084	OLGA STEPANOVA	{"email": "o.stepanova051964@postgrespro.ru", "phone": "+70201214433"}
0005433925636	F2339E	7183 050423	DMITRIY GAVRILOV	{"phone": "+70278797294"}
0005433925637	B0183D	9141 533582	MIKHAIL MOROZOV	{"email": "morozov.mikhail-1973@postgrespro.ru", "phone": "+70241387763"}
0005433925638	6EFC9A	0349 737947	SERGEY ROMANOV	{"phone": "+70807756663"}
0005433925639	B2909A	1524 954952	TATYANA MASLOVA	{"email": "tatyana-maslova-29071967@postgrespro.ru", "phone": "+70446366148"}
0005433925640	B2909A	4505 848028	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.a.04111966@postgrespro.ru", "phone": "+70274567885"}
0005433925641	551304	3121 874542	EVDOKIYA KOROLEVA	{"phone": "+70792176515"}
0005433925642	6DD81D	5976 830614	DENIS GORBUNOV	{"phone": "+70197187978"}
0005433925643	7B8971	8370 122787	NIKOLAY KUZNECOV	{"phone": "+70128708261"}
0005433925644	7B8971	4108 086298	ZINAIDA LAZAREVA	{"email": "lazarevazinaida.28021980@postgrespro.ru", "phone": "+70779616178"}
0005433925645	BF2B1B	4659 850890	SERGEY KAZAKOV	{"email": "sergey.kazakov.121983@postgrespro.ru", "phone": "+70980064159"}
0005433925646	2A0C66	3818 832881	NADEZHDA KAZAKOVA	{"phone": "+70422145527"}
0005433925647	2A0C66	1779 318271	KONSTANTIN STEPANOV	{"phone": "+70753578231"}
0005433925648	4ED937	1284 349472	SAMIRA TIMOFEEVA	{"phone": "+70824238564"}
0005433925649	4ED937	0279 740447	MIKHAIL PAVLOV	{"email": "pavlov.mikhail_1979@postgrespro.ru", "phone": "+70358804717"}
0005433925650	7BAA51	5976 806233	OLGA ORLOVA	{"email": "oorlova_30101967@postgrespro.ru", "phone": "+70623957971"}
0005433925651	00A164	4446 197742	NADEZHDA MELNIKOVA	{"email": "melnikovanadezhda_101972@postgrespro.ru", "phone": "+70168013548"}
0005433925652	8D8824	1232 632459	SEMEN ANDREEV	{"phone": "+70036908754"}
0005433925653	8D8824	3625 470650	LYUBOV SCHERBAKOVA	{"email": "scherbakovalyubov_1970@postgrespro.ru", "phone": "+70118507224"}
0005433925654	A3ACC9	5884 857585	KRISTINA KUZMINA	{"email": "kuzmina_kristina071978@postgrespro.ru", "phone": "+70127387283"}
0005433925655	5C1991	1590 524445	EGOR KRASNOV	{"email": "ekrasnov.111983@postgrespro.ru", "phone": "+70162332602"}
0005433925656	84E4A1	0596 659455	LYUDMILA AFANASEVA	{"email": "lyudmila-afanaseva041972@postgrespro.ru", "phone": "+70076683352"}
0005433925657	84E4A1	6906 843869	OLGA FILIPPOVA	{"phone": "+70680102304"}
0005433925658	EBA464	0277 160554	VLADIMIR VASILEV	{"phone": "+70809213515"}
0005433925659	EBA464	8663 081108	ANASTASIYA MAKAROVA	{"phone": "+70662678571"}
0005433925660	623928	8827 104765	NIKOLAY MAKAROV	{"phone": "+70413420909"}
0005433925661	E22F48	1595 353917	ANASTASIYA SOLOVEVA	{"email": "a.soloveva-041962@postgrespro.ru", "phone": "+70322118050"}
0005433925662	6C44DC	5331 953753	LYUBOV TARASOVA	{"phone": "+70996421413"}
0005433925663	6C44DC	9719 309850	PAVEL MELNIKOV	{"email": "melnikovpavel_1970@postgrespro.ru", "phone": "+70827059499"}
0005433925664	C129B1	1905 182001	VYACHESLAV SEMENOV	{"phone": "+70807923139"}
0005433925665	E68CA1	5006 736717	VITALIY VLASOV	{"email": "v.vlasov_11031978@postgrespro.ru", "phone": "+70096383584"}
0005433925666	E68CA1	0539 285640	VIKTOR NIKOLAEV	{"email": "viktornikolaev-1971@postgrespro.ru", "phone": "+70521924398"}
0005433925667	34A9D6	9634 191778	TIMOFEY IVANOV	{"phone": "+70629735880"}
0005433925668	34A9D6	0758 168206	RIMMA CHERNOVA	{"phone": "+70415891649"}
0005433925669	34A9D6	0683 049623	ALEKSANDRA MALYSHEVA	{"email": "a_malysheva-1973@postgrespro.ru", "phone": "+70874417771"}
0005433925670	6AF0A0	6400 433179	OKSANA CHERNOVA	{"email": "chernova.oksana23051967@postgrespro.ru", "phone": "+70081503642"}
0005433925671	6AF0A0	2658 371935	LIDIYA EGOROVA	{"phone": "+70301872084"}
0005433925672	7C8598	8723 947467	ILYA FROLOV	{"phone": "+70376779167"}
0005433925673	E7419F	9563 655197	ALBERT SOLOVEV	{"phone": "+70090536057"}
0005433925674	E7419F	8094 200242	MIKHAIL NIKOLAEV	{"phone": "+70966937371"}
0005433925675	C34141	5117 028711	VLADIMIR SERGEEV	{"phone": "+70266647672"}
0005433925676	4BF6AA	3187 921691	ALEKSANDR ABRAMOV	{"phone": "+70969978894"}
0005433925677	14B619	3420 686771	RAISA MIKHAYLOVA	{"email": "mikhaylova_raisa.061966@postgrespro.ru", "phone": "+70871641822"}
0005433925678	14B619	8380 917822	GALINA ALEKSEEVA	{"email": "galinaalekseeva-071973@postgrespro.ru", "phone": "+70997307840"}
0005433925679	4B3398	3935 986530	IVAN GRIGOREV	{"phone": "+70642941590"}
0005433925680	B6D5DB	0646 234284	NINA KRASNOVA	{"phone": "+70627763764"}
0005433925681	285387	5975 375403	IVAN MATVEEV	{"phone": "+70570603344"}
0005433925682	285387	0026 036680	SERGEY MARTYNOV	{"email": "martynov-s.031977@postgrespro.ru", "phone": "+70052498295"}
0005433925683	1EF00F	0434 858625	SERGEY FEDOROV	{"phone": "+70685702244"}
0005433925684	1EF00F	2659 189262	ELENA MOISEEVA	{"phone": "+70939039348"}
0005433925685	75FE00	2725 758443	VLADISLAV SIDOROV	{"phone": "+70385055677"}
0005433925686	10CF96	9108 212510	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov_1978@postgrespro.ru", "phone": "+70077495305"}
0005433925687	D0E4E8	7758 053412	VLADIMIR ROMANOV	{"phone": "+70420805949"}
0005433925688	D0E4E8	5630 875153	ANDREY SAVELEV	{"email": "savelev.a1961@postgrespro.ru", "phone": "+70376581888"}
0005433925689	D0E4E8	7326 025111	VASILIY TIKHONOV	{"email": "vasiliy_tikhonov081975@postgrespro.ru", "phone": "+70507810756"}
0005433925690	D0A623	6060 697936	NIKOLAY KUZNECOV	{"phone": "+70130177012"}
0005433925691	B9F014	3202 075290	ALEKSANDR MOISEEV	{"email": "a.moiseev041970@postgrespro.ru", "phone": "+70738871701"}
0005433925692	340E59	8331 535556	YULIYA MARTYNOVA	{"phone": "+70583156872"}
0005433925693	99CDE7	1959 300888	VALENTINA POTAPOVA	{"phone": "+70465833794"}
0005433925694	48DF97	9162 278348	LYUDMILA ZOTOVA	{"phone": "+70866686970"}
0005433925695	48DF97	8377 651279	ARTEM ZAYCEV	{"phone": "+70818297807"}
0005433925696	48DF97	8291 814749	MIKHAIL GAVRILOV	{"phone": "+70618986061"}
0005433925697	D57640	2980 257240	ELENA FEDOROVA	{"phone": "+70347426619"}
0005433925698	D57640	3646 528319	DARYA BELOVA	{"email": "belova-darya-1977@postgrespro.ru", "phone": "+70690743390"}
0005433925699	63130F	7323 584298	VERA STEPANOVA	{"email": "v.stepanova-091979@postgrespro.ru", "phone": "+70357142049"}
0005433925700	7FFD20	6173 374809	ANNA DENISOVA	{"phone": "+70012180856"}
0005433925701	F3B324	1973 968941	ANDREY TIKHONOV	{"phone": "+70810441024"}
0005433925702	F3B324	8302 994442	MARIYA PETROVA	{"email": "mariya-petrova.01021970@postgrespro.ru", "phone": "+70659618149"}
0005433925703	77F839	9821 319473	SERGEY ANTONOV	{"phone": "+70974086933"}
0005433925704	77F839	0902 946553	ANNA KRASNOVA	{"email": "anna-krasnova1970@postgrespro.ru", "phone": "+70984199686"}
0005433925705	77F839	2640 407791	DENIS ANTONOV	{"phone": "+70991221358"}
0005433925706	707FDF	7891 320836	ELENA KAZAKOVA	{"phone": "+70930925437"}
0005433925707	8A5F6F	8202 540617	LIDIYA SCHERBAKOVA	{"phone": "+70273979162"}
0005433925708	888746	6628 838014	LARISA DENISOVA	{"email": "larisa-denisova-1976@postgrespro.ru", "phone": "+70572205646"}
0005433925709	215DFD	7447 136602	VITALIY DENISOV	{"email": "v.denisov.14111969@postgrespro.ru", "phone": "+70104466714"}
0005433925710	D8415E	5613 186943	NATALYA FROLOVA	{"phone": "+70554499832"}
0005433925711	EC81C3	0917 310043	VIKTOR IVANOV	{"phone": "+70869524774"}
0005433925712	DF28F6	2217 625054	NIKOLAY GRIGOREV	{"email": "grigorev_nikolay.091978@postgrespro.ru", "phone": "+70515975691"}
0005433925713	DF28F6	2091 553576	VYACHESLAV ANDREEV	{"phone": "+70916888117"}
0005433925714	FD1157	7969 546011	TAMARA FROLOVA	{"email": "t.frolova_051964@postgrespro.ru", "phone": "+70855118400"}
0005433925715	45FE83	7895 291261	LYUBOV VASILEVA	{"phone": "+70600961537"}
0005433925716	85F793	4997 292456	VALENTINA MIKHAYLOVA	{"phone": "+70784870970"}
0005433925717	724521	4308 022397	LYUDMILA KOZLOVA	{"phone": "+70791730724"}
0005433925718	724521	2246 654900	NINA KUZNECOVA	{"phone": "+70342633338"}
0005433925719	31E05C	2250 137747	LYUBOV POPOVA	{"email": "popova.l1975@postgrespro.ru", "phone": "+70858655462"}
0005433925720	73BE3B	0193 313749	LARISA ROMANOVA	{"email": "romanova-larisa.031971@postgrespro.ru", "phone": "+70068286523"}
0005433925721	73BE3B	1267 627933	ANNA ALEKSANDROVA	{"phone": "+70403925185"}
0005433925722	30BB78	8369 153742	RUSTAM ISAEV	{"phone": "+70978520247"}
0005433925723	30BB78	1911 779454	EVGENIY ZAYCEV	{"email": "e-zaycev051985@postgrespro.ru", "phone": "+70214975781"}
0005433925724	A6AA5F	3103 390127	ALEKSANDR NAUMOV	{"phone": "+70419961509"}
0005433925725	A6AA5F	7366 894428	IGOR ZAYCEV	{"phone": "+70988437451"}
0005433925726	EFACF4	8392 131383	MIKHAIL PETROV	{"email": "petrovmikhail-1974@postgrespro.ru", "phone": "+70569650082"}
0005433925727	3135F7	3851 866057	NIKOLAY MARTYNOV	{"email": "martynov_n_1971@postgrespro.ru", "phone": "+70961292426"}
0005433925728	3135F7	3295 578629	ANDREY MIRONOV	{"email": "mironov.a.1965@postgrespro.ru", "phone": "+70731271205"}
0005433925729	430448	7160 148737	SEMEN MIKHAYLOV	{"phone": "+70760250980"}
0005433925730	9EAC0D	0750 827866	GALINA FOMINA	{"phone": "+70709742949"}
0005433925731	2B7258	4500 118147	ANDREY KRASNOV	{"email": "a-krasnov-1953@postgrespro.ru", "phone": "+70176833314"}
0005433925732	2B7258	6500 174236	ANATOLIY ISAEV	{"phone": "+70031004304"}
0005433925733	2B7258	2765 096929	ALEKSANDR VOLKOV	{"phone": "+70785662924"}
0005433925734	2B7258	9279 017017	LYUDMILA ZAYCEVA	{"phone": "+70599897154"}
0005433925735	EAEAC2	8190 663072	IVAN ZAKHAROV	{"phone": "+70781381077"}
0005433925736	6025C5	2520 122801	ANDREY MEDVEDEV	{"email": "a_medvedev1975@postgrespro.ru", "phone": "+70378707982"}
0005433925737	4FF6D5	6469 733108	ALEKSEY BELOV	{"phone": "+70110615050"}
0005433925738	09109C	5501 261068	VYACHESLAV FOMIN	{"email": "fominv-051978@postgrespro.ru", "phone": "+70451790363"}
0005433925739	7E9BFC	0588 847721	ALEKSEY FEDOROV	{"email": "fedorov_aleksey1961@postgrespro.ru", "phone": "+70305021213"}
0005433925740	D29912	1281 955750	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova-081976@postgrespro.ru", "phone": "+70408646912"}
0005433925741	D29912	4233 454620	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov-30121979@postgrespro.ru", "phone": "+70210458873"}
0005433925742	BE3FAB	6729 944380	OLEG VOLKOV	{"email": "o.volkov29011964@postgrespro.ru", "phone": "+70814654956"}
0005433925743	F4BAFC	3604 505358	NIKOLAY KULIKOV	{"email": "nkulikov_1970@postgrespro.ru", "phone": "+70088676492"}
0005433925744	ABF015	8582 687960	LYUDMILA GUSEVA	{"phone": "+70013864743"}
0005433925745	ABF015	3021 779343	KRISTINA IVANOVA	{"email": "ivanova-k081981@postgrespro.ru", "phone": "+70270706197"}
0005433925746	777562	6287 546192	TATYANA CHERNOVA	{"email": "chernova.t-1985@postgrespro.ru", "phone": "+70245982253"}
0005433925747	777562	9749 033163	OKSANA LAZAREVA	{"email": "oksana_lazareva.1969@postgrespro.ru", "phone": "+70315478630"}
0005433925748	19D1F8	2601 278969	DMITRIY VOLKOV	{"email": "dmitriy_volkov-1968@postgrespro.ru", "phone": "+70112496785"}
0005433925749	C856F8	1351 808257	VIKTOR MIKHAYLOV	{"email": "viktormikhaylov041977@postgrespro.ru", "phone": "+70838119858"}
0005433925750	CE7572	3594 287213	ANNA ZOTOVA	{"phone": "+70026236983"}
0005433925751	CE7572	5204 086766	VLADIMIR MATVEEV	{"email": "matveev_vladimir.051972@postgrespro.ru", "phone": "+70440374973"}
0005433925752	4A3E77	4728 533758	IRINA IVANOVA	{"email": "ivanovai_16111963@postgrespro.ru", "phone": "+70226551921"}
0005433925753	5A659E	3917 655978	IVAN KAZAKOV	{"phone": "+70138756824"}
0005433925754	A4C6FF	1283 533503	GALINA DMITRIEVA	{"phone": "+70549837047"}
0005433925755	5DF33D	5309 146971	ALEKSANDR MIKHAYLOV	{"phone": "+70297392626"}
0005433925756	5CD807	8950 696319	MIKHAIL VOROBEV	{"email": "m.vorobev_1979@postgrespro.ru", "phone": "+70738497920"}
0005433925757	CEFFFC	7549 115672	IRINA SMIRNOVA	{"phone": "+70374350320"}
0005433925758	CEFFFC	6650 413675	ELENA MELNIKOVA	{"phone": "+70559786242"}
0005433925759	03F662	4226 117909	NATALYA ZAKHAROVA	{"email": "n-zakharova.071965@postgrespro.ru", "phone": "+70064579167"}
0005433925760	217509	6934 235960	SERGEY GUSEV	{"phone": "+70111863120"}
0005433925761	217509	6192 944942	DMITRIY SAVELEV	{"email": "dmitriysavelev_021967@postgrespro.ru", "phone": "+70820812531"}
0005433925762	A1CD81	1526 953988	YURIY BELOV	{"email": "yuriybelov.02051982@postgrespro.ru", "phone": "+70716595982"}
0005433925763	C44E5B	8566 118980	ANAIT VOLKOVA	{"email": "volkova.anait_091962@postgrespro.ru", "phone": "+70498270958"}
0005433925764	E54EF5	5143 089541	TALGAT SERGEEV	{"email": "sergeev.talgat.14101974@postgrespro.ru", "phone": "+70361597495"}
0005433925765	8A4555	1323 686593	OLGA KOMAROVA	{"phone": "+70916792265"}
0005433925766	67107F	1233 290500	OLGA MEDVEDEVA	{"email": "olga_medvedeva.011966@postgrespro.ru", "phone": "+70583982736"}
0005433925767	67107F	1817 773835	RENAT BORISOV	{"phone": "+70680750331"}
0005433925768	97BCF7	6606 700549	LIDIYA NIKOLAEVA	{"email": "nikolaeva.lidiya_061980@postgrespro.ru", "phone": "+70416630741"}
0005433925769	3B9EF7	2282 264720	ZINAIDA DENISOVA	{"email": "z.denisova.17051968@postgrespro.ru", "phone": "+70188315658"}
0005433925770	D461BD	0656 009474	SVETLANA EFREMOVA	{"email": "efremova.s_23031971@postgrespro.ru", "phone": "+70189642902"}
0005433925771	5FA1B8	1755 230884	KSENIYA PETROVA	{"phone": "+70214065386"}
0005433925772	5FA1B8	3212 649714	VERONIKA IVANOVA	{"email": "ivanovaveronika-26081977@postgrespro.ru", "phone": "+70161339189"}
0005433925773	3B7F8C	2038 970426	ILMIRA DAVYDOVA	{"phone": "+70586470672"}
0005433925774	3B7F8C	7053 833328	GALINA FEDOROVA	{"email": "galina_fedorova111963@postgrespro.ru", "phone": "+70857396842"}
0005433925775	3B7F8C	1804 486079	VLADIMIR MIKHAYLOV	{"phone": "+70832821944"}
0005433925776	6E4F9F	1837 519030	OLEG ALEKSEEV	{"phone": "+70897577172"}
0005433925777	6E4F9F	7565 086305	OLGA ARKHIPOVA	{"email": "arkhipovaolga_1977@postgrespro.ru", "phone": "+70603818689"}
0005433925778	74324C	7323 130796	NATALYA GORBUNOVA	{"phone": "+70539326771"}
0005433925779	A45C3E	7650 094354	NINA DENISOVA	{"email": "denisovan-071968@postgrespro.ru", "phone": "+70643828423"}
0005433925780	359020	8833 552841	VALERIY KUZNECOV	{"phone": "+70509706052"}
0005433925781	6C8221	2354 985864	LEV KISELEV	{"email": "l_kiselev-1976@postgrespro.ru", "phone": "+70953121586"}
0005433925782	4D0984	8076 954780	TATYANA KUZNECOVA	{"email": "kuznecova.t-021977@postgrespro.ru", "phone": "+70203213212"}
0005433925783	C76890	2924 548522	YANA IVANOVA	{"phone": "+70310553012"}
0005433925784	C76890	5409 190696	ANATOLIY ROMANOV	{"email": "anatoliy-romanov_1973@postgrespro.ru", "phone": "+70238210019"}
0005433925785	8461C8	6102 424532	ALEKSEY KULIKOV	{"email": "a_kulikov041978@postgrespro.ru", "phone": "+70877813913"}
0005433925786	8461C8	8791 039879	ALEKSEY MARTYNOV	{"email": "a.martynov_1982@postgrespro.ru", "phone": "+70047421725"}
0005433925787	587046	7806 453973	ILYA IVANOV	{"phone": "+70840756999"}
0005433925788	BDF009	4967 715434	YANA KONDRATEVA	{"email": "kondratevayana.051984@postgrespro.ru", "phone": "+70869901157"}
0005433925789	0A626E	7434 305226	OLEG MELNIKOV	{"phone": "+70779813167"}
0005433925790	0A626E	7311 006390	ANNA SOKOLOVA	{"email": "sokolova_anna1966@postgrespro.ru", "phone": "+70751264644"}
0005433925791	06DEDD	9796 731453	LYUBOV TIMOFEEVA	{"email": "timofeevalyubov.13081978@postgrespro.ru", "phone": "+70145347428"}
0005433925792	06DEDD	5858 298986	VYACHESLAV BELOV	{"phone": "+70560552709"}
0005433925793	6A77D6	1967 734131	VYACHESLAV KISELEV	{"phone": "+70008405769"}
0005433925794	6A77D6	0260 920457	SERGEY SCHERBAKOV	{"email": "scherbakov.s_28031962@postgrespro.ru", "phone": "+70627762591"}
0005433925795	807E10	3054 351462	NIKOLAY VOROBEV	{"phone": "+70485989412"}
0005433925796	807E10	3332 045731	ALEKSEY BARANOV	{"email": "aleksey_baranov.08031963@postgrespro.ru", "phone": "+70463659133"}
0005433925797	88E177	8512 571447	ALBERT POPOV	{"phone": "+70606712505"}
0005433925798	E4F51E	7660 576755	ANATOLIY ANTONOV	{"phone": "+70839226570"}
0005433925799	E4F51E	7555 196155	EVGENIYA BELYAEVA	{"email": "belyaeva_e.061971@postgrespro.ru", "phone": "+70215820020"}
0005433925800	58077D	2704 553252	NINA VASILEVA	{"phone": "+70143792076"}
0005433925801	25C360	3613 917073	SERGEY MATVEEV	{"email": "smatveev1977@postgrespro.ru", "phone": "+70828427000"}
0005433925802	F51E33	6979 532682	MIKHAIL GAVRILOV	{"email": "mikhailgavrilov_1973@postgrespro.ru", "phone": "+70665146320"}
0005433925803	F51E33	8215 730323	ALEKSEY POPOV	{"email": "a_popov17031970@postgrespro.ru", "phone": "+70670636055"}
0005433925804	DA092A	3836 713615	VLADIMIR MAKAROV	{"phone": "+70014648578"}
0005433925805	DA092A	4795 058135	NATALYA VOLKOVA	{"email": "n-volkova-03061959@postgrespro.ru", "phone": "+70156278836"}
0005433925806	AC83E0	1644 683181	EVGENIYA ILINA	{"email": "evgeniya-ilina_04081972@postgrespro.ru", "phone": "+70685725302"}
0005433925807	49B682	1252 242162	RUSLAN GAVRILOV	{"phone": "+70216609261"}
0005433925808	49B682	3571 353113	VALERIY KUZNECOV	{"phone": "+70137035853"}
0005433925809	5C34B4	2057 938005	TATYANA FROLOVA	{"email": "frolova_tatyana-1975@postgrespro.ru", "phone": "+70079276958"}
0005433925810	5C34B4	1043 279912	ANNA ZAKHAROVA	{"phone": "+70560187021"}
0005433925811	E1999D	8041 463472	YULIYA ANDREEVA	{"phone": "+70991915978"}
0005433925812	5B15DC	0547 202046	VALENTINA DAVYDOVA	{"email": "davydova.valentina.1976@postgrespro.ru", "phone": "+70052181587"}
0005433925813	5B15DC	3617 643186	ELIZAVETA KUZNECOVA	{"email": "e.kuznecova25031973@postgrespro.ru", "phone": "+70531959545"}
0005433925814	0EB49D	4072 179107	SHAMIL FOMIN	{"email": "s_fomin.051974@postgrespro.ru", "phone": "+70120801837"}
0005433925815	669254	0565 954895	KRISTINA KUZNECOVA	{"email": "k.kuznecova.11071973@postgrespro.ru", "phone": "+70010709155"}
0005433925816	669254	9650 217566	POLINA KUZNECOVA	{"phone": "+70223831394"}
0005433925817	E09D99	3230 077365	LIDIYA KOMAROVA	{"phone": "+70823295273"}
0005433925818	7F8775	0338 785632	OLEG SCHERBAKOV	{"email": "olegscherbakov031971@postgrespro.ru", "phone": "+70060331789"}
0005433925819	503FB0	1133 076787	LARISA MEDVEDEVA	{"email": "larisa.medvedeva.12081973@postgrespro.ru", "phone": "+70742409643"}
0005433925820	AECD93	4694 850237	RAISA KONOVALOVA	{"email": "konovalova-raisa-121974@postgrespro.ru", "phone": "+70940623433"}
0005433925821	3B34CF	7448 485928	VLADIMIR BORISOV	{"phone": "+70928662501"}
0005433925822	72E9F6	6964 058143	YULIYA MIRONOVA	{"email": "y-mironova.1970@postgrespro.ru", "phone": "+70685313475"}
0005433925823	4CB609	8245 144195	LYUDMILA PETROVA	{"phone": "+70460386385"}
0005433925824	901BEF	8764 059552	ARTEM NOVIKOV	{"email": "novikovartem111976@postgrespro.ru", "phone": "+70715284105"}
0005433925825	DB3FFD	9253 777016	LARISA TARASOVA	{"email": "larisa_tarasova-1982@postgrespro.ru", "phone": "+70764566045"}
0005433925826	A6E0D7	2492 033282	ELENA VASILEVA	{"email": "vasileva_e_30041964@postgrespro.ru", "phone": "+70288176092"}
0005433925827	633C23	7983 208172	TATYANA KUZNECOVA	{"email": "kuznecova_t_08091978@postgrespro.ru", "phone": "+70063342929"}
0005433925828	35A7D4	7008 738589	ELENA VASILEVA	{"phone": "+70572317778"}
0005433925829	A1E396	8550 014789	NATALYA IVANOVA	{"phone": "+70605082100"}
0005433925830	7CD03B	8768 364588	ANDREY GORBUNOV	{"phone": "+70579079107"}
0005433925831	BEAC5E	1784 848910	SVETLANA KUZNECOVA	{"email": "s_kuznecova.1969@postgrespro.ru", "phone": "+70142792029"}
0005433925832	9B9A87	2773 272372	TATYANA BARANOVA	{"email": "baranova.tatyana_1958@postgrespro.ru", "phone": "+70487792778"}
0005433925833	1B6BFA	8023 370329	GULFIYA NAZAROVA	{"email": "gulfiya.nazarova_031974@postgrespro.ru", "phone": "+70191634791"}
0005433925834	3DFA08	0158 232709	ELENA MOROZOVA	{"email": "elena.morozova1974@postgrespro.ru", "phone": "+70851654067"}
0005433925835	3DFA08	8868 438485	ANNA YAKOVLEVA	{"phone": "+70423121873"}
0005433925836	8D7A63	6708 276937	LIDIYA TIKHONOVA	{"phone": "+70199982078"}
0005433925837	8D7A63	8829 945828	NADEZHDA KISELEVA	{"email": "kiseleva-nadezhda.30081969@postgrespro.ru", "phone": "+70772956944"}
0005433925838	8D7A63	4234 987830	DANIIL KONOVALOV	{"phone": "+70889124242"}
0005433925839	488B44	5979 159401	EKATERINA DMITRIEVA	{"email": "dmitrievae.031971@postgrespro.ru", "phone": "+70109160313"}
0005433925840	F2FD14	1911 013930	ALEKSEY DAVYDOV	{"email": "davydova.07041968@postgrespro.ru", "phone": "+70259335908"}
0005433925841	F2FD14	1204 134094	YULIYA BARANOVA	{"phone": "+70535015407"}
0005433925842	BEC1D6	9291 301130	VALENTIN KUZNECOV	{"email": "kuznecov_valentin03051977@postgrespro.ru", "phone": "+70481259984"}
0005433925843	770F1A	5159 437826	VALENTINA NIKOLAEVA	{"email": "v.nikolaeva-19071965@postgrespro.ru", "phone": "+70369353857"}
0005433925844	F7F98A	5424 087389	SOFYA KAZAKOVA	{"phone": "+70155754435"}
0005433925845	F7F98A	8227 486779	ZINAIDA MAKAROVA	{"email": "makarova-zinaida.27091980@postgrespro.ru", "phone": "+70019759368"}
0005433925846	356955	0208 579095	OLGA KUZMINA	{"email": "okuzmina20061958@postgrespro.ru", "phone": "+70373259759"}
0005433925847	915005	5035 917797	LIDIYA NAZAROVA	{"email": "nazarova_l081976@postgrespro.ru", "phone": "+70093179417"}
0005433925848	915005	0803 312140	NIKITA NIKOLAEV	{"email": "nikita_nikolaev_19081963@postgrespro.ru", "phone": "+70295769710"}
0005433925849	271547	9841 125734	ELENA STEPANOVA	{"phone": "+70620266694"}
0005433925850	515C45	5944 959356	VIKTORIYA VOROBEVA	{"phone": "+70207818713"}
0005433925851	C3E3CA	9389 387595	KIRILL AFANASEV	{"email": "kafanasev1967@postgrespro.ru", "phone": "+70028639191"}
0005433925852	C3E3CA	5642 325646	ALEKSANDRA KOROLEVA	{"phone": "+70546590531"}
0005433925853	2D0898	9187 973437	LYUDMILA KOZLOVA	{"email": "lkozlova_121968@postgrespro.ru", "phone": "+70751007716"}
0005433925854	96534B	1025 861816	DMITRIY FEDOTOV	{"email": "fedotov_dmitriy_011984@postgrespro.ru", "phone": "+70524345688"}
0005433925855	26810B	2139 832743	ALIYA POTAPOVA	{"email": "a-potapova-08091979@postgrespro.ru", "phone": "+70917956574"}
0005433925856	65BB77	4711 808724	KONSTANTIN SOLOVEV	{"phone": "+70706665643"}
0005433925857	E10E21	8464 795212	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy-031963@postgrespro.ru", "phone": "+70661592973"}
0005433925858	E10E21	8982 724336	VLADIMIR SAVELEV	{"phone": "+70058399824"}
0005433925859	802342	8519 188206	TATYANA MARTYNOVA	{"phone": "+70022742108"}
0005433925860	802342	1558 769811	LYUBOV GUSEVA	{"phone": "+70258983127"}
0005433925861	802342	7879 659759	VIKTOR KUZNECOV	{"phone": "+70765754085"}
0005433925862	A8E579	6184 591055	ANDREY TIKHONOV	{"phone": "+70736157025"}
0005433925863	A8E579	4928 739090	OLGA SOROKINA	{"phone": "+70580731699"}
0005433925864	631D96	4366 723505	EGOR MAKAROV	{"email": "egor-makarov-28081973@postgrespro.ru", "phone": "+70938795619"}
0005433925865	DE656B	8572 023513	OLGA NOVIKOVA	{"email": "o-novikova-021957@postgrespro.ru", "phone": "+70826077743"}
0005433925866	DE656B	4906 987351	OLEG NIKITIN	{"email": "oleg.nikitin.1975@postgrespro.ru", "phone": "+70552663750"}
0005433925867	05E259	0993 089860	IRINA OVCHINNIKOVA	{"phone": "+70665169518"}
0005433925868	922204	2921 530716	ANATOLIY NIKOLAEV	{"email": "anatoliy-nikolaev-031972@postgrespro.ru", "phone": "+70260174908"}
0005433925869	B7F74E	7161 877666	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov.091967@postgrespro.ru", "phone": "+70807153590"}
0005433925870	B7F74E	5390 768686	ALEKSANDR SIDOROV	{"email": "a.sidorov.1970@postgrespro.ru", "phone": "+70472559462"}
0005433925871	BC5D6B	8746 813340	EGOR IVANOV	{"email": "ivanov-egor-061965@postgrespro.ru", "phone": "+70438398191"}
0005433925872	2840F3	4975 563489	ANDREY NAZAROV	{"email": "nazarov_andrey_1973@postgrespro.ru", "phone": "+70513735859"}
0005433925873	2840F3	1109 718436	VIKTOR MAKSIMOV	{"email": "v-maksimov.17061962@postgrespro.ru", "phone": "+70643879747"}
0005433925874	D9B330	0230 242522	NATALYA MIKHAYLOVA	{"phone": "+70743066738"}
0005433925875	CEE9C3	3301 972709	RUMIYA DMITRIEVA	{"email": "r-dmitrieva_031968@postgrespro.ru", "phone": "+70165413998"}
0005433925876	715359	9248 007500	NINA PAVLOVA	{"email": "npavlova-061960@postgrespro.ru", "phone": "+70715016469"}
0005433925877	9D66FC	8677 118292	TATYANA AFANASEVA	{"phone": "+70781218546"}
0005433925878	9D66FC	5045 477747	ALISA YUDINA	{"phone": "+70613792583"}
0005433925879	9D66FC	3686 875674	SERGEY POPOV	{"phone": "+70578471419"}
0005433925880	2B44E1	9922 819987	MIKHAIL KARPOV	{"phone": "+70075398557"}
0005433925881	2B44E1	3977 773514	ANASTASIYA POPOVA	{"email": "anastasiya-popova_06061974@postgrespro.ru", "phone": "+70689094672"}
0005433925882	E42AC1	2509 499162	VALENTINA SEMENOVA	{"email": "valentinasemenova021976@postgrespro.ru", "phone": "+70426958005"}
0005433925883	8EEE39	8002 078794	NATALYA ERMAKOVA	{"phone": "+70162120613"}
0005433925884	8EEE39	7115 695102	KRISTINA IVANOVA	{"email": "ivanova_kristina1980@postgrespro.ru", "phone": "+70883689127"}
0005433925885	285809	4756 152522	DMITRIY BORISOV	{"email": "borisov_d1969@postgrespro.ru", "phone": "+70128912897"}
0005433925886	285809	3646 096178	SVETLANA KAZAKOVA	{"email": "s_kazakova_1969@postgrespro.ru", "phone": "+70791156472"}
0005433925887	0A675A	1129 601610	RAISA GRISHINA	{"phone": "+70468845859"}
0005433925888	EA47C4	5859 706481	VALENTINA PAVLOVA	{"email": "valentina_pavlova091971@postgrespro.ru", "phone": "+70707611345"}
0005433925889	B73BC4	3601 422986	TATYANA KOROLEVA	{"email": "t-koroleva-12071979@postgrespro.ru", "phone": "+70006588239"}
0005433925890	B73BC4	8978 969860	ANATOLIY VLASOV	{"email": "vlasov-a1979@postgrespro.ru", "phone": "+70381058221"}
0005433925891	441CCB	4267 526915	ANATOLIY SEMENOV	{"phone": "+70164142402"}
0005433925892	0043FB	0526 742989	RAIL SMIRNOV	{"phone": "+70223476551"}
0005433925893	CBCFF2	0711 982940	DANILA ORLOV	{"email": "danila-orlov.1960@postgrespro.ru", "phone": "+70664545663"}
0005433925894	92E779	9698 287010	IVAN KUZNECOV	{"email": "ikuznecov-051980@postgrespro.ru", "phone": "+70557142759"}
0005433925895	2417CD	2352 078067	LYUDMILA ABRAMOVA	{"phone": "+70849611043"}
0005433925896	2417CD	2293 478593	VASILIY SIDOROV	{"phone": "+70508218254"}
0005433925897	604997	5678 703032	SERGEY PETROV	{"phone": "+70722474480"}
0005433925898	604997	0559 420256	DARYA IVANOVA	{"phone": "+70234872305"}
0005433925899	03035D	8409 900563	ALEKSANDR AFANASEV	{"email": "afanasev-a-02111971@postgrespro.ru", "phone": "+70841222707"}
0005433925900	41A147	1791 008846	ANNA KUZNECOVA	{"phone": "+70524953215"}
0005433925901	C818CC	4458 228018	DMITRIY FILIPPOV	{"phone": "+70341205754"}
0005433925902	7C8728	7616 867581	ANNA IVANOVA	{"phone": "+70192202107"}
0005433925903	0FDEDE	9129 812075	SERGEY POPOV	{"email": "popovsergey-1972@postgrespro.ru", "phone": "+70269858412"}
0005433925904	924D4B	9078 131069	NADEZHDA KULIKOVA	{"phone": "+70156619595"}
0005433925905	F53DD1	9699 292178	TATYANA KOLESNIKOVA	{"email": "tatyana_kolesnikova-1968@postgrespro.ru", "phone": "+70387332278"}
0005433925906	3E1349	3833 131045	ZINAIDA ZHURAVLEVA	{"email": "zinaida_zhuravleva021952@postgrespro.ru", "phone": "+70465646366"}
0005433925907	11A619	0929 397853	ARTUR EGOROV	{"phone": "+70400395095"}
0005433925908	D3C966	0603 898687	VASILIY PETROV	{"phone": "+70663118462"}
0005433925909	AACC4F	2035 597982	BORIS EGOROV	{"phone": "+70896980632"}
0005433925910	2C6B5B	0702 708708	IVAN SMIRNOV	{"phone": "+70715098955"}
0005433925911	B48CC1	8252 215985	NATALYA YAKOVLEVA	{"email": "nyakovleva-111960@postgrespro.ru", "phone": "+70154548524"}
0005433925912	AE3610	2798 914690	DMITRIY NAUMOV	{"email": "dmitriy-naumov1972@postgrespro.ru", "phone": "+70242517864"}
0005433925913	195354	5382 920584	DENIS BARANOV	{"email": "baranov.d-071973@postgrespro.ru", "phone": "+70094047048"}
0005433925914	239FF9	8467 749461	PRASKOVYA SOROKINA	{"email": "sorokina_p.14071962@postgrespro.ru", "phone": "+70462772528"}
0005433925915	E785AF	3344 642551	VALENTINA POPOVA	{"phone": "+70108340413"}
0005433925916	AACF53	8532 616057	MARINA NIKOLAEVA	{"phone": "+70027846886"}
0005433925917	AACF53	6723 429631	LIDIYA IVANOVA	{"phone": "+70701425040"}
0005433925918	A3A3CB	1973 626753	TAMARA SIDOROVA	{"email": "sidorova.t03031975@postgrespro.ru", "phone": "+70876174151"}
0005433925919	953FE8	8933 277282	IRINA KRASNOVA	{"email": "i_krasnova.02061979@postgrespro.ru", "phone": "+70277899729"}
0005433925920	218541	3466 999430	NATALYA ALEKSEEVA	{"phone": "+70093701297"}
0005433925921	F5DD8F	5267 615131	TATYANA SCHERBAKOVA	{"email": "tscherbakova_1967@postgrespro.ru", "phone": "+70823852143"}
0005433925922	65324E	4796 593682	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey-09101972@postgrespro.ru", "phone": "+70127716130"}
0005433925923	796625	9210 698401	YURIY ALEKSEEV	{"phone": "+70172896595"}
0005433925924	082A9C	6357 550457	GALINA LOGINOVA	{"phone": "+70481516600"}
0005433925925	7A0863	5658 243832	ALEKSANDR ZHURAVLEV	{"phone": "+70559157548"}
0005433925983	E55193	0648 220921	TAGIR PETROV	{"phone": "+70432829556"}
0005433925926	1EAED1	0322 873503	NIKOLAY FILIPPOV	{"email": "n.filippov.1981@postgrespro.ru", "phone": "+70966040644"}
0005433925927	412C3C	8929 427739	OLGA PAVLOVA	{"phone": "+70552409079"}
0005433925928	5E3585	9954 017705	ANATOLIY FEDOTOV	{"email": "anatoliyfedotov.1974@postgrespro.ru", "phone": "+70417270470"}
0005433925929	A98A0D	3211 247484	NADEZHDA ANDREEVA	{"phone": "+70002931607"}
0005433925930	35EA0D	9456 517906	VALENTINA SOKOLOVA	{"email": "sokolovav1971@postgrespro.ru", "phone": "+70789671158"}
0005433925931	DDE408	7071 918794	KONSTANTIN KISELEV	{"email": "kiselev.k.04101984@postgrespro.ru", "phone": "+70742585188"}
0005433925932	BCD69C	2483 181409	VALERIY GUSEV	{"phone": "+70231591032"}
0005433925933	49389A	9585 328510	ALEKSEY BONDARENKO	{"phone": "+70555427492"}
0005433925934	50AE8E	9184 612688	SERGEY IVANOV	{"email": "ivanovs-1978@postgrespro.ru", "phone": "+70633525327"}
0005433925935	D054F6	4836 754420	IVAN MEDVEDEV	{"email": "i-medvedev101983@postgrespro.ru", "phone": "+70073803023"}
0005433925936	D054F6	2899 873110	ALEKSANDR SERGEEV	{"phone": "+70726232057"}
0005433925937	F4BBB7	7708 182447	ANATOLIY MATVEEV	{"phone": "+70657009214"}
0005433925938	B0334E	5186 031229	ROZA IVANOVA	{"email": "ivanova-r.20121974@postgrespro.ru", "phone": "+70704814126"}
0005433925939	7B1227	6938 071214	EKATERINA POPOVA	{"phone": "+70881954946"}
0005433925940	4CEDFC	0368 356027	YAKOV FILIPPOV	{"email": "filippovyakov.121971@postgrespro.ru", "phone": "+70879970844"}
0005433925941	4CEDFC	0442 270725	ALEKSANDR MAKSIMOV	{"phone": "+70039855798"}
0005433925942	279672	5554 814938	NIKOLAY GRIGOREV	{"email": "grigorev.n1969@postgrespro.ru", "phone": "+70992809491"}
0005433925943	DF3D54	7625 095882	IGOR TIMOFEEV	{"phone": "+70473800787"}
0005433925944	DF3D54	5621 413361	ZOYA KULIKOVA	{"phone": "+70730690248"}
0005433925945	5D378F	9116 629047	LYUBOV DANILOVA	{"email": "danilova.lyubov.09091970@postgrespro.ru", "phone": "+70322364234"}
0005433925946	5D378F	1084 723792	NADEZHDA EFREMOVA	{"phone": "+70326890700"}
0005433925947	0969AD	4272 469425	ALEKSANDR ALEKSANDROV	{"phone": "+70249186180"}
0005433925948	4DE611	9590 100930	SERGEY FILIPPOV	{"phone": "+70329795238"}
0005433925949	49E286	2862 807822	EGOR SERGEEV	{"email": "esergeev.1959@postgrespro.ru", "phone": "+70382303197"}
0005433925950	6AD714	5670 084127	NINA MOROZOVA	{"phone": "+70743432443"}
0005433925951	58B56D	3368 718083	ALEKSEY ORLOV	{"email": "aleksey-orlov.18021975@postgrespro.ru", "phone": "+70028279994"}
0005433925952	58B56D	7966 644835	DMITRIY GRIGOREV	{"email": "grigorevdmitriy-071979@postgrespro.ru", "phone": "+70569545448"}
0005433925953	58B56D	0140 205374	KLAVDIYA EGOROVA	{"email": "egorova-k.08011965@postgrespro.ru", "phone": "+70012282490"}
0005433925954	DAC1A9	2084 886043	ALEKSANDR GAVRILOV	{"phone": "+70085159197"}
0005433925955	2A7F9B	1691 752602	GENNADIY GORBUNOV	{"email": "gorbunov-gennadiy31101965@postgrespro.ru", "phone": "+70636236875"}
0005433925956	FBBED5	2295 148771	ELENA KONDRATEVA	{"phone": "+70264177994"}
0005433925957	7EFEB7	8324 812177	ALEKSANDRA STEPANOVA	{"email": "a_stepanova_101974@postgrespro.ru", "phone": "+70058935546"}
0005433925958	F6B42F	3635 989902	EVGENIY MIKHAYLOV	{"phone": "+70814967203"}
0005433925959	4234A8	7794 822277	DMITRIY OSIPOV	{"email": "dmitriy_osipov-18041976@postgrespro.ru", "phone": "+70396713311"}
0005433925960	6167D3	4351 343916	MARGARITA KUZNECOVA	{"phone": "+70848522455"}
0005433925961	1AC87A	4030 114018	ANATOLIY MEDVEDEV	{"email": "anatoliy-medvedev-111968@postgrespro.ru", "phone": "+70297796545"}
0005433925962	1AC87A	5308 584286	NATALYA KISELEVA	{"email": "kiselevanatalya-1964@postgrespro.ru", "phone": "+70688424082"}
0005433925963	1AC87A	4992 049248	YURIY MELNIKOV	{"email": "melnikov.yuriy.091967@postgrespro.ru", "phone": "+70834822640"}
0005433925964	099BE2	2425 069534	LYUBOV KULIKOVA	{"email": "kulikovalyubov_011987@postgrespro.ru", "phone": "+70530444336"}
0005433925965	8F0691	8662 695714	ILGIZ TARASOV	{"email": "itarasov-17091971@postgrespro.ru", "phone": "+70198475907"}
0005433925966	3CD5C5	7719 943580	SVETLANA BORISOVA	{"phone": "+70319423197"}
0005433925967	112D57	9721 211580	MAKSIM IVANOV	{"phone": "+70820815774"}
0005433925968	E8E7C4	1025 180785	ALEKSEY ABRAMOV	{"email": "abramov.aleksey-10011972@postgrespro.ru", "phone": "+70475698469"}
0005433925969	E8E7C4	9968 464290	RAISA DENISOVA	{"email": "raisa_denisova_051968@postgrespro.ru", "phone": "+70547258158"}
0005433925970	57C29B	0682 601157	OLGA MAKAROVA	{"phone": "+70039512425"}
0005433925971	F0C2D0	9642 390877	VALENTINA ANDREEVA	{"phone": "+70848510483"}
0005433925972	F0C2D0	2750 655399	VLADIMIR TIKHONOV	{"phone": "+70159387937"}
0005433925973	826A1E	0366 754614	YURIY BARANOV	{"phone": "+70685269254"}
0005433925974	ECBCDA	4900 278703	ANTONINA ANISIMOVA	{"phone": "+70881833772"}
0005433925975	02372A	5227 182858	MARIYA ANTONOVA	{"phone": "+70949678386"}
0005433925976	64791E	1266 557535	VIKTORIYA STEPANOVA	{"email": "v.stepanova_081975@postgrespro.ru", "phone": "+70305109499"}
0005433925977	741284	6355 745509	OLGA YUDINA	{"phone": "+70241339592"}
0005433925978	741284	8225 836244	YULIYA MEDVEDEVA	{"phone": "+70538232865"}
0005433925979	96F46B	3570 510478	DMITRIY MOROZOV	{"phone": "+70089636728"}
0005433925980	0D8EA1	1920 580730	EVGENIY SCHERBAKOV	{"phone": "+70947755445"}
0005433925981	9914B3	3775 893780	EVGENIY NOVIKOV	{"phone": "+70070664009"}
0005433929548	1B690C	1794 550756	SVETLANA VOROBEVA	{"phone": "+70817496264"}
0005433925982	1C364F	9664 103078	TATYANA TROFIMOVA	{"email": "tatyana.trofimova24031986@postgrespro.ru", "phone": "+70740353646"}
0005433925984	87EE40	5709 832675	ALEKSANDR FOMIN	{"phone": "+70784052432"}
0005433925985	87EE40	2885 697740	ANNA NIKITINA	{"phone": "+70939995216"}
0005433925986	8D8CDE	8102 600054	OLEG ZAYCEV	{"phone": "+70537656726"}
0005433925987	BCAA0B	1326 976905	NINA GERASIMOVA	{"phone": "+70620356839"}
0005433925988	A0D41E	0028 503468	YULIYA GERASIMOVA	{"phone": "+70146816268"}
0005433925989	E4570E	2931 191543	ANZHELIKA ROMANOVA	{"phone": "+70208569911"}
0005433925990	E4570E	9707 430853	ALEKSEY KUZNECOV	{"phone": "+70293492216"}
0005433925991	56E5EA	2168 002183	ALEKSEY ALEKSEEV	{"phone": "+70998788531"}
0005433925992	8C3A59	4252 526363	VLADIMIR SERGEEV	{"email": "sergeev.v.09021969@postgrespro.ru", "phone": "+70239662611"}
0005433925993	08C223	8439 315267	MIKHAIL ZHUKOV	{"email": "zhukovmikhail_1967@postgrespro.ru", "phone": "+70781363522"}
0005433925994	3FD76D	4049 739526	VITALIY PETROV	{"email": "vitaliypetrov_011985@postgrespro.ru", "phone": "+70586529494"}
0005433925995	3FD76D	9048 423039	LIDIYA ANDREEVA	{"phone": "+70570973456"}
0005433925996	F4009C	8962 414337	VLADISLAV GAVRILOV	{"phone": "+70798378470"}
0005433925997	F4009C	4338 160110	DANIIL NIKOLAEV	{"email": "dnikolaev_1971@postgrespro.ru", "phone": "+70830341470"}
0005433925998	F4009C	0047 890331	NIKOLAY GERASIMOV	{"email": "nikolay_gerasimov_101980@postgrespro.ru", "phone": "+70058979771"}
0005433925999	32BD0A	2881 144736	VALERIY GAVRILOV	{"email": "valeriy.gavrilov.1967@postgrespro.ru", "phone": "+70712059233"}
0005433926000	32BD0A	9009 274838	GENNADIY KUZNECOV	{"phone": "+70706352124"}
0005433926001	32BD0A	6018 743144	ANNA GUSEVA	{"email": "anna-guseva.1971@postgrespro.ru", "phone": "+70452425614"}
0005433926002	3C1264	4476 687200	VENIAMIN DMITRIEV	{"phone": "+70772445845"}
0005433926003	48435C	6914 347342	VERA STEPANOVA	{"email": "stepanova_v.071970@postgrespro.ru", "phone": "+70148688970"}
0005433926004	48435C	3101 233614	LIDIYA POPOVA	{"phone": "+70473412842"}
0005433926005	48435C	0894 175709	PETR KUZMIN	{"phone": "+70075434394"}
0005433926006	B8D5BF	4717 749699	MIKHAIL SMIRNOV	{"phone": "+70105361037"}
0005433926007	4219FA	7981 809555	NATALYA MELNIKOVA	{"email": "melnikova_n_09031975@postgrespro.ru", "phone": "+70431119788"}
0005433926008	4219FA	7993 675407	MAKSIM KAZAKOV	{"phone": "+70000522802"}
0005433926009	B77798	2573 782485	ANDREY ISAEV	{"phone": "+70684430464"}
0005433926010	B77798	4557 137735	GALINA ERMAKOVA	{"email": "ermakova_g.27031986@postgrespro.ru", "phone": "+70174274659"}
0005433926011	6848E3	5711 641118	VIKTORIYA KOMAROVA	{"phone": "+70471129680"}
0005433926012	AD050A	7877 767904	VLADIMIR FEDOROV	{"email": "fedorov.v1970@postgrespro.ru", "phone": "+70348288439"}
0005433926013	AD050A	8158 784737	LYUDMILA ALEKSEEVA	{"phone": "+70778808179"}
0005433926014	ECF9C3	6290 617628	ALEKSEY MIRONOV	{"email": "mironov_aleksey.11081968@postgrespro.ru", "phone": "+70893145985"}
0005433926015	3ADEFD	0962 748922	EKATERINA BELOVA	{"email": "e-belova.14071974@postgrespro.ru", "phone": "+70643753015"}
0005433926016	9185F8	4973 662924	ANTON FOMIN	{"email": "fomina-031982@postgrespro.ru", "phone": "+70030608123"}
0005433926017	DACC09	6422 524867	VLADIMIR ABRAMOV	{"phone": "+70424371297"}
0005433926018	7233DF	2082 681324	VALERIY NIKOLAEV	{"email": "nikolaev-v-04021982@postgrespro.ru", "phone": "+70015408698"}
0005433926019	B47292	8495 124399	DIANA ARKHIPOVA	{"email": "d.arkhipova01111969@postgrespro.ru", "phone": "+70224426991"}
0005433926020	B47292	2444 274681	LYUDMILA BORISOVA	{"email": "lyudmila_borisova.1983@postgrespro.ru", "phone": "+70065804243"}
0005433926021	D864C9	0833 544681	NIKOLAY IVANOV	{"email": "ivanovnikolay071973@postgrespro.ru", "phone": "+70999112287"}
0005433926022	9C4197	0665 939838	ANDREY BONDARENKO	{"email": "a_bondarenko1975@postgrespro.ru", "phone": "+70278376264"}
0005433926023	C9C2B1	2143 347394	NIKOLAY MAKAROV	{"email": "makarovn_20031973@postgrespro.ru", "phone": "+70767177471"}
0005433926024	A8AFB0	9833 003417	SVETLANA LOGINOVA	{"phone": "+70187868946"}
0005433926025	A8AFB0	6620 539976	RENAT IVANOV	{"phone": "+70686953206"}
0005433926026	A8AFB0	4357 336913	LYUDMILA SERGEEVA	{"email": "sergeeva_l05071968@postgrespro.ru", "phone": "+70603831190"}
0005433926027	738C86	9276 520548	TATYANA SMIRNOVA	{"phone": "+70014266804"}
0005433926028	738C86	0517 526940	LYUDMILA MOROZOVA	{"phone": "+70479055574"}
0005433926029	9886CF	4108 910436	KONSTANTIN MELNIKOV	{"email": "konstantin_melnikov-17021977@postgrespro.ru", "phone": "+70983545518"}
0005433926030	9886CF	8355 999297	SVETLANA ALEKSANDROVA	{"phone": "+70258565180"}
0005433926031	533AFC	9021 468437	ILYA SEMENOV	{"email": "semenov.ilya061974@postgrespro.ru", "phone": "+70990276227"}
0005433926032	C0CD0B	7111 309076	MARIYA VASILEVA	{"email": "vasileva.m_081981@postgrespro.ru", "phone": "+70304439461"}
0005433926033	FAD918	6141 451043	MARGARITA ROMANOVA	{"phone": "+70279878066"}
0005433926034	975DB8	1700 460614	NAILYA SIDOROVA	{"email": "n.sidorova_25111971@postgrespro.ru", "phone": "+70409253862"}
0005433926035	D4F20E	5265 579170	YULIYA PAVLOVA	{"email": "y-pavlova.1969@postgrespro.ru", "phone": "+70550195232"}
0005433926036	D4F20E	2157 326407	MIKHAIL GORBUNOV	{"phone": "+70158672226"}
0005433926037	699BD3	3376 617249	SVETLANA KOVALEVA	{"phone": "+70174219497"}
0005433926038	309F71	6114 064758	ALEKSEY NIKOLAEV	{"phone": "+70949329281"}
0005433926039	2DECF6	4461 513431	ANNA ZAYCEVA	{"email": "zayceva.a-11111962@postgrespro.ru", "phone": "+70296757783"}
0005433926040	795AE9	7503 597408	PETR TIMOFEEV	{"phone": "+70849715791"}
0005433926041	D1F477	6474 682864	MIKHAIL ZHURAVLEV	{"phone": "+70104525206"}
0005433926042	D1F477	7751 432856	MARINA PETROVA	{"email": "marinapetrova.1968@postgrespro.ru", "phone": "+70506995897"}
0005433929549	AA4C90	5180 431240	ILYA IVANOV	{"phone": "+70649537884"}
0005433926043	D1F477	1411 810059	SERGEY KUZNECOV	{"email": "sergey.kuznecov_011977@postgrespro.ru", "phone": "+70825087502"}
0005433926044	F2ED2A	3587 467301	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy.05031969@postgrespro.ru", "phone": "+70264039751"}
0005433926045	F2ED2A	6125 873687	TATYANA SEMENOVA	{"phone": "+70911294649"}
0005433926046	00B31B	8570 120257	LILIYA KRASNOVA	{"phone": "+70558493060"}
0005433926047	F5B4E1	3627 832315	KONSTANTIN VASILEV	{"email": "konstantinvasilev.101970@postgrespro.ru", "phone": "+70112825714"}
0005433926048	B6A468	4329 720050	VALENTINA TIMOFEEVA	{"phone": "+70402753006"}
0005433926049	B6A468	7804 608282	VALENTINA GUSEVA	{"email": "guseva_v-02051981@postgrespro.ru", "phone": "+70725095918"}
0005433926050	AD2A84	5823 323002	GALINA GERASIMOVA	{"email": "galina-gerasimova.17031972@postgrespro.ru", "phone": "+70317599328"}
0005433926051	699E6E	2740 898733	IVAN SEMENOV	{"email": "ivan.semenov-041991@postgrespro.ru", "phone": "+70111569297"}
0005433926052	EC72EB	1162 041561	VLADIMIR EGOROV	{"phone": "+70533562461"}
0005433926053	979F24	1332 595953	VERA TITOVA	{"phone": "+70430618723"}
0005433926054	AB2108	8821 269802	LYUDMILA ZAKHAROVA	{"phone": "+70120904719"}
0005433926055	2C3F11	6171 782863	ALENA CHERNOVA	{"phone": "+70692680711"}
0005433926056	562CFB	4017 552249	NINA FOMINA	{"email": "n.fomina_08021971@postgrespro.ru", "phone": "+70418900215"}
0005433926057	D1C037	4320 134568	MARIYA GUSEVA	{"email": "guseva.mariya_101978@postgrespro.ru", "phone": "+70799335990"}
0005433926058	241590	8409 894627	ALEKSANDR GORBUNOV	{"email": "gorbunov-a.1964@postgrespro.ru", "phone": "+70403930060"}
0005433926059	764CCF	7450 028742	GALINA ALEKSEEVA	{"phone": "+70940706743"}
0005433926060	98F80E	7175 289559	ROMAN VASILEV	{"email": "roman-vasilev-051976@postgrespro.ru", "phone": "+70778311788"}
0005433926061	E4852F	3635 266993	VLADIMIR VOLKOV	{"phone": "+70657790291"}
0005433926062	65AEC8	7629 981185	VIKTOR ROMANOV	{"email": "romanov_viktor1972@postgrespro.ru", "phone": "+70132159566"}
0005433926063	65AEC8	4538 670377	ANDREY IVANOV	{"phone": "+70829021043"}
0005433926064	589C0B	6059 923893	LYUDMILA SOROKINA	{"phone": "+70179767115"}
0005433926065	395C89	7371 968658	ALEKSANDR SOLOVEV	{"email": "solovev_a_041975@postgrespro.ru", "phone": "+70695460486"}
0005433926066	395C89	8168 534748	SNEZHANA MIRONOVA	{"email": "snezhana_mironova.28101981@postgrespro.ru", "phone": "+70082052099"}
0005433926067	5CC0AB	7036 464236	ALEKSANDR KOROLEV	{"email": "korolevaleksandr.071977@postgrespro.ru", "phone": "+70726112825"}
0005433926068	A88E44	0648 027755	MIKHAIL MAKAROV	{"email": "mikhailmakarov_071969@postgrespro.ru", "phone": "+70215312980"}
0005433926069	CB6840	2849 860904	SERGEY ZAKHAROV	{"phone": "+70285222699"}
0005433926070	37CEB6	8652 142216	ALLA KAZAKOVA	{"phone": "+70288135281"}
0005433926071	8B9ED0	5564 945908	NINA KONDRATEVA	{"email": "n-kondrateva_17071978@postgrespro.ru", "phone": "+70492361363"}
0005433926072	0543D0	5027 585504	SERGEY BONDARENKO	{"email": "s-bondarenko_18051976@postgrespro.ru", "phone": "+70130320011"}
0005433926073	0543D0	3349 431302	DARYA EFIMOVA	{"email": "efimova.d21051985@postgrespro.ru", "phone": "+70488129455"}
0005433926074	9272B1	8463 248753	VALENTINA STEPANOVA	{"email": "stepanova-valentina_1983@postgrespro.ru", "phone": "+70037109692"}
0005433926075	9272B1	9659 791881	VALENTINA TIMOFEEVA	{"phone": "+70452242115"}
0005433926076	9272B1	0793 397179	VERA BARANOVA	{"email": "v_baranova-111975@postgrespro.ru", "phone": "+70371150368"}
0005433926077	AC6B02	3495 821793	ANNA FILIPPOVA	{"phone": "+70442136448"}
0005433926078	A1F1DB	3160 057023	NINA MALYSHEVA	{"phone": "+70830879576"}
0005433926079	2B6BB0	2588 945658	DMITRIY ZAKHAROV	{"phone": "+70373402267"}
0005433926080	2B6BB0	3166 641840	ALEKSANDR PAVLOV	{"email": "a.pavlov.03041969@postgrespro.ru", "phone": "+70369448481"}
0005433926081	C0F963	1451 483947	MIKHAIL KOZLOV	{"phone": "+70142776969"}
0005433926082	D5E357	8884 113269	MARINA GORBUNOVA	{"phone": "+70571135049"}
0005433926083	046FE8	8306 129556	INGA POLYAKOVA	{"phone": "+70178043239"}
0005433926084	046FE8	8689 862500	ANATOLIY MIKHAYLOV	{"email": "a-mikhaylov111968@postgrespro.ru", "phone": "+70715493123"}
0005433926085	5FF20E	0398 556420	VALENTINA MELNIKOVA	{"email": "melnikovav1971@postgrespro.ru", "phone": "+70504615832"}
0005433926086	457DC7	8028 462399	ELENA SCHERBAKOVA	{"email": "elena_scherbakova_061971@postgrespro.ru", "phone": "+70596233334"}
0005433926087	55DF38	3742 799618	ALINA PETROVA	{"email": "alinapetrova10071969@postgrespro.ru", "phone": "+70756398699"}
0005433926088	2BE206	6318 850820	VLADIMIR NAUMOV	{"email": "naumov-vladimir.15071978@postgrespro.ru", "phone": "+70043787312"}
0005433926089	2BE206	2109 254363	PRASKOVYA TIKHONOVA	{"phone": "+70054101715"}
0005433926090	AF3497	7478 516039	VALERIYA KUZNECOVA	{"email": "valeriya_kuznecova1969@postgrespro.ru", "phone": "+70509096729"}
0005433926091	DBD147	6243 194982	MARGARITA SOROKINA	{"phone": "+70785262843"}
0005433926092	DBD147	6898 980600	VYACHESLAV ROMANOV	{"email": "vromanov29111962@postgrespro.ru", "phone": "+70017047569"}
0005433926093	F7FA2D	3262 631629	KONSTANTIN MAKAROV	{"phone": "+70499639666"}
0005433926094	2AE8CD	8733 590851	ROMAN ROMANOV	{"phone": "+70010214114"}
0005433926095	B38CFF	4374 603601	NATALYA MAKAROVA	{"phone": "+70745187560"}
0005433926096	B38CFF	5576 572672	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay-061963@postgrespro.ru", "phone": "+70509904712"}
0005433926097	B38CFF	2596 351167	ANASTASIYA DMITRIEVA	{"email": "dmitrieva_anastasiya.27081967@postgrespro.ru", "phone": "+70474346421"}
0005433926098	2785D5	7833 151687	KRISTINA MOISEEVA	{"email": "moiseeva_kristina1972@postgrespro.ru", "phone": "+70246967739"}
0005433926099	AE6720	5323 233808	DAMIR ORLOV	{"phone": "+70975130938"}
0005433926100	AE6720	8955 500805	VIKTOR FOMIN	{"email": "viktorfomin-24071982@postgrespro.ru", "phone": "+70247154624"}
0005433926101	A0F82B	3680 932620	MARGARITA AFANASEVA	{"email": "m.afanaseva07041973@postgrespro.ru", "phone": "+70836136516"}
0005433926102	A0F82B	1438 252829	FARIT STEPANOV	{"email": "faritstepanov_10041978@postgrespro.ru", "phone": "+70399149360"}
0005433926103	18BCB5	4170 819530	IRINA SOROKINA	{"phone": "+70071387663"}
0005433926104	18BCB5	0048 653003	ALEKSANDRA PAVLOVA	{"phone": "+70401851690"}
0005433926105	7E1F7F	9815 777626	SVETLANA DAVYDOVA	{"email": "s.davydova051968@postgrespro.ru", "phone": "+70879714566"}
0005433926106	7E1F7F	1109 652595	YULIYA MAKAROVA	{"phone": "+70656361544"}
0005433926107	ACBF18	6270 063768	LYUDMILA MIKHAYLOVA	{"email": "mikhaylovalyudmila.1977@postgrespro.ru", "phone": "+70285304297"}
0005433926108	481922	5105 409855	GALINA KULIKOVA	{"phone": "+70752584251"}
0005433926109	481922	3313 968999	NINA BOGDANOVA	{"email": "bogdanova.nina1961@postgrespro.ru", "phone": "+70553317792"}
0005433926110	E85FF2	4448 376503	IRINA EGOROVA	{"email": "i-egorova-26031974@postgrespro.ru", "phone": "+70977833611"}
0005433926111	941165	6477 051033	ANDREY SMIRNOV	{"phone": "+70169128961"}
0005433926112	753C68	8000 197455	EVGENIY ZHURAVLEV	{"email": "evgeniy-zhuravlev.011974@postgrespro.ru", "phone": "+70370016291"}
0005433926113	753C68	0690 017017	GALINA MIRONOVA	{"email": "g_mironova.021972@postgrespro.ru", "phone": "+70334400091"}
0005433926114	BA58F6	8983 712661	ALEKSANDR PETROV	{"phone": "+70912875522"}
0005433926115	BA58F6	4944 686815	LARISA KAZAKOVA	{"phone": "+70474740171"}
0005433926116	4CF077	9048 274472	KLAVDIYA KALININA	{"phone": "+70707771470"}
0005433926117	80FE89	6891 585963	ANTON IVANOV	{"phone": "+70100653408"}
0005433926118	D6EEB8	8817 898265	IRINA PETROVA	{"email": "petrova_i.021971@postgrespro.ru", "phone": "+70877336980"}
0005433926119	D6EEB8	3080 962097	MATVEY SHEVCHENKO	{"email": "matvey_shevchenko-031973@postgrespro.ru", "phone": "+70988762924"}
0005433926120	D6EEB8	8716 823115	NINA KUDRYASHOVA	{"email": "kudryashova_n1969@postgrespro.ru", "phone": "+70943360247"}
0005433926121	4906E9	6173 041710	VLADIMIR ANDREEV	{"email": "vladimir_andreev101982@postgrespro.ru", "phone": "+70737292702"}
0005433926122	4906E9	2332 230081	TAISA PETROVA	{"email": "tpetrova-081981@postgrespro.ru", "phone": "+70359621585"}
0005433926123	4906E9	9370 913360	SERGEY GERASIMOV	{"email": "gerasimov_s1981@postgrespro.ru", "phone": "+70295893875"}
0005433927495	9982D4	4823 819209	TATYANA MEDVEDEVA	{"phone": "+70482332879"}
0005433927395	8E33C4	3397 306949	BORIS STEPANOV	{"phone": "+70933787943"}
0005433927396	1731E8	7272 906899	YURIY KUZNECOV	{"email": "kuznecov-y_06011962@postgrespro.ru", "phone": "+70921475571"}
0005433927397	1731E8	4843 493701	ALEKSANDR TARASOV	{"email": "atarasov-01081973@postgrespro.ru", "phone": "+70846573090"}
0005433927398	2C1666	6653 783225	TATYANA YAKOVLEVA	{"email": "tatyana-yakovleva_1967@postgrespro.ru", "phone": "+70058910731"}
0005433927399	2C1666	4141 659681	TATYANA POPOVA	{"email": "tatyana.popova.1966@postgrespro.ru", "phone": "+70064532691"}
0005433927400	8D06C5	1221 682100	NIKOLAY FILIPPOV	{"phone": "+70883385117"}
0005433927401	7BACF6	6291 029047	LYUBOV SIDOROVA	{"phone": "+70629418692"}
0005433927402	26BF11	3150 804192	TATYANA SMIRNOVA	{"email": "tatyana_smirnova121963@postgrespro.ru", "phone": "+70682113007"}
0005433927403	6AEC70	3251 507187	RUSLAN POPOV	{"phone": "+70293908905"}
0005433927404	A4377F	2516 963442	VIKTOR KOROLEV	{"phone": "+70590546678"}
0005433927405	A4377F	9902 040575	MARIYA SERGEEVA	{"phone": "+70402536155"}
0005433927406	157341	8132 498152	ZOYA GERASIMOVA	{"phone": "+70754285983"}
0005433927407	157341	7494 882668	BORIS KOZLOV	{"phone": "+70863511314"}
0005433927408	7CC306	9661 325770	SERGEY VOLKOV	{"email": "s_volkov_1967@postgrespro.ru", "phone": "+70332492564"}
0005433927409	7CC306	0090 177746	ANASTASIYA EGOROVA	{"phone": "+70363629304"}
0005433927410	078D95	0370 846809	EVGENIY KUZNECOV	{"phone": "+70179380314"}
0005433927411	C52FAE	0397 620388	SVETLANA TARASOVA	{"phone": "+70319278790"}
0005433927412	C52FAE	0122 656321	VLADIMIR STEPANOV	{"phone": "+70641065049"}
0005433927413	428485	9341 287996	TAMARA IVANOVA	{"phone": "+70254582013"}
0005433927414	428485	6811 035223	VALENTINA SMIRNOVA	{"email": "smirnova-valentina_19061975@postgrespro.ru", "phone": "+70990610889"}
0005433927415	428485	7616 165328	ANDREY KRASNOV	{"phone": "+70830458430"}
0005433927416	118AD1	7418 584635	ALEKSEY MOROZOV	{"email": "aleksey_morozov1963@postgrespro.ru", "phone": "+70094055104"}
0005433927417	3EF0D8	0186 328455	NATALYA KOROLEVA	{"phone": "+70773591976"}
0005433927418	C737BB	7491 102524	LEONID FILIPPOV	{"phone": "+70318483459"}
0005433927419	443A0C	3645 302733	ILYA KOZLOV	{"phone": "+70096903717"}
0005433927420	AD5E36	4073 283077	ANDREY ALEKSANDROV	{"phone": "+70356082551"}
0005433927421	F7DEDA	6721 416310	ELENA CHERNOVA	{"email": "chernova.e021965@postgrespro.ru", "phone": "+70876568776"}
0005433927422	EF2B0F	6769 385060	TATYANA FADEEVA	{"email": "tatyana-fadeeva021965@postgrespro.ru", "phone": "+70309451878"}
0005433927423	589760	5425 042258	ANASTASIYA FILATOVA	{"phone": "+70930819871"}
0005433927424	589760	0703 293539	GALINA POLYAKOVA	{"phone": "+70206319281"}
0005433927425	AF521C	7580 144530	YURIY CHERNOV	{"phone": "+70737280936"}
0005433927426	FCC60A	7906 661629	VALENTINA NESTEROVA	{"email": "nesterovavalentina041960@postgrespro.ru", "phone": "+70300800449"}
0005433927427	16F9C7	4303 074163	ALEKSANDR KULIKOV	{"email": "akulikov.041973@postgrespro.ru", "phone": "+70171495110"}
0005433927428	16F9C7	1736 150893	MARIYA AKIMOVA	{"email": "mariya_akimova.011981@postgrespro.ru", "phone": "+70369080997"}
0005433927429	5A305D	1940 363060	YAROSLAV MOISEEV	{"phone": "+70932468422"}
0005433927430	5A305D	3090 263077	KSENIYA KUZNECOVA	{"email": "kuznecova.kseniya-30051973@postgrespro.ru", "phone": "+70083870011"}
0005433927431	696E29	0894 596063	TATYANA KONDRATEVA	{"email": "kondrateva_t.14101973@postgrespro.ru", "phone": "+70555909534"}
0005433927432	5D775F	1334 169417	VALENTIN MAKAROV	{"phone": "+70174197563"}
0005433927433	6A6B4A	3644 973400	ANNA DENISOVA	{"email": "denisova.anna101978@postgrespro.ru", "phone": "+70578778858"}
0005433927434	6A6B4A	2570 311380	SERGEY MELNIKOV	{"phone": "+70520153094"}
0005433927435	3D30C4	5485 270530	VALERIY MARTYNOV	{"email": "martynov.valeriy1959@postgrespro.ru", "phone": "+70727669803"}
0005433927436	13DA13	5371 780365	TATYANA ROMANOVA	{"phone": "+70318699449"}
0005433927437	BE547F	4254 847578	NIKOLAY ISAEV	{"email": "nisaev_101985@postgrespro.ru", "phone": "+70192242619"}
0005433927438	0CEE2E	4148 000460	GULNAZ ROMANOVA	{"email": "romanova.gulnaz.1963@postgrespro.ru", "phone": "+70508495730"}
0005433927439	0CEE2E	8136 684437	VYACHESLAV IVANOV	{"phone": "+70097188873"}
0005433927440	97B97E	7545 267121	OKSANA MOROZOVA	{"email": "oksanamorozova_1962@postgrespro.ru", "phone": "+70577156097"}
0005433927441	08B081	9369 475374	GALINA GRISHINA	{"email": "g.grishina-1974@postgrespro.ru", "phone": "+70607495758"}
0005433927442	EF948C	9160 274232	IRAIDA MIKHAYLOVA	{"phone": "+70057930312"}
0005433927443	7E5FA1	6432 062529	VALERIY FEDOTOV	{"email": "valeriyfedotov-07121961@postgrespro.ru", "phone": "+70907980778"}
0005433927444	FFEEF2	1987 065355	ALEKSEY BONDARENKO	{"phone": "+70729958998"}
0005433927445	23F15E	9349 539428	ELENA KALININA	{"phone": "+70749108505"}
0005433927446	23F15E	9709 900456	VIKTOR IVANOV	{"email": "ivanov.v031982@postgrespro.ru", "phone": "+70702433378"}
0005433927447	AA3337	1793 023870	GALINA NOVIKOVA	{"phone": "+70021543484"}
0005433927448	E059D7	1465 691217	NADEZHDA NESTEROVA	{"email": "nesterova.nadezhda30061961@postgrespro.ru", "phone": "+70796819333"}
0005433927449	41B034	7656 183552	NADEZHDA ZAYCEVA	{"phone": "+70155940373"}
0005433927450	41B034	5629 995649	ANATOLIY ZHURAVLEV	{"phone": "+70824896650"}
0005433927451	41B034	2784 362191	VITALIY MAKSIMOV	{"phone": "+70416563605"}
0005433927452	37D521	2206 216166	MIKHAIL FROLOV	{"phone": "+70456131242"}
0005433927453	37D521	9333 491522	TATYANA ROMANOVA	{"email": "romanova.t.041968@postgrespro.ru", "phone": "+70342786978"}
0005433927454	2FA37B	0429 450731	VIKTORIYA SOROKINA	{"email": "viktoriyasorokina10021967@postgrespro.ru", "phone": "+70838371358"}
0005433927455	2FA37B	1643 485812	ALENA IVANOVA	{"email": "alena-ivanova21061972@postgrespro.ru", "phone": "+70704030159"}
0005433927456	69CEDC	1653 979446	ANTONINA LAZAREVA	{"email": "lazareva_a.1979@postgrespro.ru", "phone": "+70614697010"}
0005433927457	69CEDC	9254 349167	PETR DENISOV	{"phone": "+70283138607"}
0005433927458	369437	8708 684873	ANASTASIYA MOROZOVA	{"phone": "+70331807819"}
0005433927459	369437	1318 682739	VITALIY GUSEV	{"email": "v-gusev_1970@postgrespro.ru", "phone": "+70599007597"}
0005433927460	3D68F7	6011 420081	DMITRIY ANTONOV	{"email": "dmitriy-antonov_11081971@postgrespro.ru", "phone": "+70549565346"}
0005433927461	CFAF15	9508 973641	PELAGEYA MOISEEVA	{"phone": "+70982167251"}
0005433927462	3B703F	7180 458812	VALERIY ISAEV	{"phone": "+70507944400"}
0005433927463	DEC40B	2541 744608	GALINA NIKIFOROVA	{"email": "nikiforovag.04061975@postgrespro.ru", "phone": "+70273363856"}
0005433927464	DEC40B	0936 007351	ARSENIY ANDREEV	{"email": "aandreev061977@postgrespro.ru", "phone": "+70124038680"}
0005433927465	2ED1FB	0776 361661	LYUBOV MOROZOVA	{"email": "lyubovmorozova.1971@postgrespro.ru", "phone": "+70106445069"}
0005433927466	2ED1FB	6844 364624	RAIL GUSEV	{"email": "rail_gusev_12081963@postgrespro.ru", "phone": "+70271530469"}
0005433927467	2ED1FB	0149 545692	ALEKSEY DAVYDOV	{"email": "davydov_a1963@postgrespro.ru", "phone": "+70468146469"}
0005433927468	D525AD	0313 804853	MIKHAIL PETROV	{"email": "mikhail_petrov-1964@postgrespro.ru", "phone": "+70127148696"}
0005433927469	C73D98	0549 198385	IRINA TARASOVA	{"phone": "+70026901886"}
0005433927470	6DA149	6930 516344	VITALIY GAVRILOV	{"email": "vitaliy_gavrilov-09051963@postgrespro.ru", "phone": "+70630695721"}
0005433927471	AB735D	5499 309090	ANDREY SOROKIN	{"phone": "+70108687939"}
0005433927472	6A97B1	8671 111183	OLESYA NAZAROVA	{"phone": "+70327435039"}
0005433927473	C99690	4897 898714	NATALYA KARPOVA	{"email": "karpova-n.22121967@postgrespro.ru", "phone": "+70705528024"}
0005433927474	42029B	2928 140429	VADIM YAKOVLEV	{"email": "vadim.yakovlev.16031979@postgrespro.ru", "phone": "+70028740419"}
0005433927475	42029B	0389 675361	MAKSIM SHEVCHENKO	{"email": "maksim-shevchenko-08021978@postgrespro.ru", "phone": "+70528400711"}
0005433927476	AB15D0	4246 110640	TATYANA SIDOROVA	{"email": "tatyana_sidorova.1966@postgrespro.ru", "phone": "+70810130722"}
0005433927477	120745	4749 353118	ZINAIDA FEDOROVA	{"email": "zinaida.fedorova1962@postgrespro.ru", "phone": "+70316878268"}
0005433927478	B2BA90	4652 598381	ROMAN NAZAROV	{"email": "nazarov.r-121965@postgrespro.ru", "phone": "+70170004987"}
0005433927479	641D28	7145 426324	LYUDMILA ERMAKOVA	{"phone": "+70958570205"}
0005433927480	641D28	0096 345746	NADEZHDA ZAKHAROVA	{"phone": "+70349008672"}
0005433927481	747B63	4568 506719	YURIY BARANOV	{"email": "baranov.yuriy-1972@postgrespro.ru", "phone": "+70645102585"}
0005433927482	747B63	4287 125108	SVETLANA IVANOVA	{"phone": "+70288603450"}
0005433927483	B34324	2209 095995	ALEKSEY NIKOLAEV	{"email": "a_nikolaev-14111965@postgrespro.ru", "phone": "+70006805211"}
0005433927484	7CB50A	5403 552718	GALINA DENISOVA	{"email": "gdenisova_081986@postgrespro.ru", "phone": "+70479409371"}
0005433927485	99E853	6550 065510	DARYA IVANOVA	{"email": "divanova1979@postgrespro.ru", "phone": "+70842642088"}
0005433927486	05C854	2925 745789	VALENTINA VOLKOVA	{"email": "vvolkova011975@postgrespro.ru", "phone": "+70903782802"}
0005433927487	09A93A	1321 521429	DANIIL MEDVEDEV	{"email": "medvedev_daniil_28101970@postgrespro.ru", "phone": "+70724623711"}
0005433927488	09A93A	0480 863550	YAROSLAV SMIRNOV	{"phone": "+70579708780"}
0005433927489	67FEAF	1206 903324	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova-15031969@postgrespro.ru", "phone": "+70243453050"}
0005433927490	F5053F	4125 391777	KLAVDIYA DAVYDOVA	{"email": "davydova.k_1970@postgrespro.ru", "phone": "+70598421640"}
0005433927491	F5053F	9484 801746	ELENA NIKITINA	{"email": "enikitina_021963@postgrespro.ru", "phone": "+70173558750"}
0005433927492	798E19	6791 924264	VIKTOR MIKHAYLOV	{"email": "v_mikhaylov01111967@postgrespro.ru", "phone": "+70964285797"}
0005433927493	45F837	6927 865750	RAISA FOMINA	{"email": "fomina.raisa.01091969@postgrespro.ru", "phone": "+70913758187"}
0005433927494	4DA646	5609 443216	ALEKSEY FROLOV	{"phone": "+70133790627"}
0005433927496	525596	2700 166313	LARISA KOLESNIKOVA	{"phone": "+70971519167"}
0005433927497	525596	5764 448382	NINA NAZAROVA	{"email": "nina-nazarova21021984@postgrespro.ru", "phone": "+70457986875"}
0005433927498	4B1590	8898 006311	GRIGORIY FEDOROV	{"email": "fedorovgrigoriy071971@postgrespro.ru", "phone": "+70832337936"}
0005433927499	2BE02F	4631 213182	VERA TITOVA	{"email": "veratitova_1975@postgrespro.ru", "phone": "+70138763036"}
0005433927500	26B2B3	9097 630186	VASILIY POPOV	{"email": "popov.v.06121966@postgrespro.ru", "phone": "+70141590026"}
0005433927501	26B2B3	5943 131213	SANIYA ILINA	{"phone": "+70359623535"}
0005433927502	D69CC9	2437 945491	ANATOLIY IVANOV	{"email": "ivanov_anatoliy.1963@postgrespro.ru", "phone": "+70043049211"}
0005433927503	C30D43	7663 470125	NAZIYA VOLKOVA	{"email": "nvolkova1967@postgrespro.ru", "phone": "+70321522467"}
0005433927504	CDC35A	0837 501679	ELENA VOLKOVA	{"email": "volkova-e-31071978@postgrespro.ru", "phone": "+70259380920"}
0005433927505	AE06C6	9105 656027	SVETLANA ANDREEVA	{"email": "svetlana_andreeva-1971@postgrespro.ru", "phone": "+70880262880"}
0005433927506	0E3915	9833 926228	LYUDMILA YUDINA	{"phone": "+70848224693"}
0005433927507	0FB66D	8201 639738	MARIYA ARKHIPOVA	{"email": "arkhipova.mariya.10061983@postgrespro.ru", "phone": "+70529880516"}
0005433927508	BEFA1F	9602 802952	ANNA NIKOLAEVA	{"email": "nikolaevaa.071975@postgrespro.ru", "phone": "+70738148936"}
0005433927509	35C3F7	9243 137165	SOFYA MEDVEDEVA	{"email": "medvedeva.s_11051967@postgrespro.ru", "phone": "+70449112893"}
0005433927510	CAB81F	2389 789570	VALERIY DENISOV	{"email": "valeriy_denisov.1969@postgrespro.ru", "phone": "+70413291728"}
0005433927511	2A876F	4864 481200	GALINA CHERNOVA	{"phone": "+70550899299"}
0005433927512	2A876F	1452 211145	VASILIY ANDREEV	{"email": "andreev-vasiliy.12121972@postgrespro.ru", "phone": "+70887069191"}
0005433927513	719359	8317 754035	ALEKSEY TIKHONOV	{"email": "tikhonov-aleksey_1973@postgrespro.ru", "phone": "+70277786688"}
0005433927514	027E31	0389 914942	OKSANA ZOTOVA	{"email": "oksana.zotova_11061978@postgrespro.ru", "phone": "+70361870896"}
0005433927515	B6D89F	0586 841024	VERA SCHERBAKOVA	{"phone": "+70153055402"}
0005433927516	8FE636	8799 676643	BORIS FROLOV	{"email": "boris_frolov-121972@postgrespro.ru", "phone": "+70572557655"}
0005433927517	9A3F04	8802 613019	NATALIYA FILIPPOVA	{"phone": "+70216774702"}
0005433927518	021018	1089 349146	NIKOLAY NAUMOV	{"phone": "+70712858173"}
0005433927519	021018	3805 931449	ALEKSANDR MAKSIMOV	{"phone": "+70255295351"}
0005433927520	25E94D	8495 664609	LARISA ZHURAVLEVA	{"email": "zhuravleva_larisa-081962@postgrespro.ru", "phone": "+70681098433"}
0005433927521	25E94D	5092 298731	EVGENIY GUSEV	{"phone": "+70769151277"}
0005433927522	52734B	1838 738700	TAMARA KUZNECOVA	{"email": "tkuznecova-1978@postgrespro.ru", "phone": "+70502977380"}
0005433927523	10018C	8862 871709	LYUBOV FILATOVA	{"email": "l.filatova.20071969@postgrespro.ru", "phone": "+70956344134"}
0005433927524	498682	4558 781490	SOFYA KUZMINA	{"phone": "+70792731793"}
0005433927525	C27AC1	2451 472211	DARYA ERMAKOVA	{"phone": "+70066702425"}
0005433927526	A07E18	0769 751692	DENIS MAKSIMOV	{"email": "maksimovd.031966@postgrespro.ru", "phone": "+70804388484"}
0005433927527	40E0EE	7955 917466	LYUDMILA KOROLEVA	{"email": "lyudmila-koroleva_111973@postgrespro.ru", "phone": "+70816052093"}
0005433927528	40E0EE	1293 262012	NIKITA KUZMIN	{"email": "kuzmin-n_091978@postgrespro.ru", "phone": "+70180084704"}
0005433927529	AAE92F	9620 078965	SERGEY KAZAKOV	{"email": "kazakovsergey.071974@postgrespro.ru", "phone": "+70286882997"}
0005433927530	1B5896	0977 228174	ELENA BELYAEVA	{"email": "e.belyaeva-28061969@postgrespro.ru", "phone": "+70091145334"}
0005433927531	35D0C1	6882 335822	KSENIYA IVANOVA	{"phone": "+70374651578"}
0005433927532	6EC0CC	3699 827142	ELENA DAVYDOVA	{"email": "e.davydova-14051979@postgrespro.ru", "phone": "+70419283050"}
0005433927533	B278C3	0476 922763	VASILIY POPOV	{"email": "v.popov111967@postgrespro.ru", "phone": "+70905378769"}
0005433927534	0462EF	4216 699308	VASILIY MIKHAYLOV	{"email": "v.mikhaylov.121966@postgrespro.ru", "phone": "+70846388795"}
0005433927535	0462EF	0153 553293	TATYANA BELYAEVA	{"email": "belyaeva-t28011968@postgrespro.ru", "phone": "+70830376661"}
0005433927536	0AE29D	6342 658970	VLADIMIR IVANOV	{"phone": "+70236056445"}
0005433927537	BB0933	6952 292989	ANATOLIY SOROKIN	{"phone": "+70994578737"}
0005433927538	24650A	4180 391932	NATALYA NIKITINA	{"email": "nnikitina_1967@postgrespro.ru", "phone": "+70571148782"}
0005433927539	4DDC16	5352 939177	ELENA NAUMOVA	{"email": "naumovaelena.121974@postgrespro.ru", "phone": "+70438942708"}
0005433927540	86F2F6	2940 132291	MARINA TIKHONOVA	{"phone": "+70883990987"}
0005433929539	DA27B2	9581 537700	ELENA VASILEVA	{"phone": "+70176111615"}
0005433929540	FB698B	7924 831861	DMITRIY ROMANOV	{"email": "romanov.d-1980@postgrespro.ru", "phone": "+70549243693"}
0005433929541	195FA0	4108 496876	MARIYA KUZNECOVA	{"email": "kuznecova.mariya_26051966@postgrespro.ru", "phone": "+70474635745"}
0005433929542	9905CB	5063 720627	YULIYA ZAYCEVA	{"phone": "+70929250706"}
0005433929543	553C73	6915 787254	DARYA SMIRNOVA	{"phone": "+70587134772"}
0005433929544	553C73	4262 141682	RAMIL NIKOLAEV	{"email": "nikolaev.r.021979@postgrespro.ru", "phone": "+70143352895"}
0005433929545	305B1C	7052 103333	NIKOLAY FROLOV	{"email": "frolov-nikolay.27081967@postgrespro.ru", "phone": "+70737987897"}
0005433929546	A611A5	1766 919603	SERGEY VASILEV	{"email": "sergey_vasilev18111968@postgrespro.ru", "phone": "+70499676136"}
0005433929547	974183	8813 770872	NATALYA FADEEVA	{"phone": "+70065385060"}
0005433929550	E708D6	3256 251396	NATALYA SIDOROVA	{"email": "n-sidorova.1985@postgrespro.ru", "phone": "+70606681388"}
0005433929551	E708D6	3439 956649	DMITRIY SHEVCHENKO	{"email": "d_shevchenko-1978@postgrespro.ru", "phone": "+70991465667"}
0005433929552	E708D6	7190 894711	LYUDMILA RYABOVA	{"phone": "+70561702698"}
0005433929553	40DC10	5253 353769	MARIYA KULIKOVA	{"phone": "+70406403386"}
0005433929554	8B7A09	7780 415074	GULFIYA GERASIMOVA	{"email": "gerasimova-gulfiya.1976@postgrespro.ru", "phone": "+70183135018"}
0005433929555	01FE70	2347 064209	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_011979@postgrespro.ru", "phone": "+70052234109"}
0005433929556	146FD3	1609 251013	OLESYA ZAKHAROVA	{"phone": "+70472996200"}
0005433929557	146FD3	2670 539151	DANILA KAZAKOV	{"email": "kazakov-danila-24121981@postgrespro.ru", "phone": "+70757205990"}
0005433929558	247626	6102 247466	KIRILL SOROKIN	{"phone": "+70403038384"}
0005433929559	247626	6141 453527	GALINA MAKSIMOVA	{"email": "maksimova_g.21041966@postgrespro.ru", "phone": "+70582439989"}
0005433929560	4D56EF	9015 419041	SERGEY SOROKIN	{"email": "sorokinsergey1969@postgrespro.ru", "phone": "+70113333874"}
0005433929561	4D56EF	1004 829209	DENIS MOISEEV	{"email": "d_moiseev-061974@postgrespro.ru", "phone": "+70584707319"}
0005433929562	57A7DD	2312 308648	VLADIMIR ALEKSANDROV	{"email": "v-aleksandrov1974@postgrespro.ru", "phone": "+70117201186"}
0005433929563	92E586	8202 289382	SERGEY IVANOV	{"phone": "+70069252021"}
0005433929564	92E586	8951 722948	TATYANA KUZMINA	{"email": "t_kuzmina02051969@postgrespro.ru", "phone": "+70024337399"}
0005433929565	C11508	6799 079453	EVGENIYA ALEKSEEVA	{"phone": "+70151799651"}
0005433929566	BF6AEC	6145 135376	YULIYA KUZMINA	{"email": "kuzmina.y-20031970@postgrespro.ru", "phone": "+70418055418"}
0005433929567	BF6AEC	7731 419012	TIGRAN ROMANOV	{"phone": "+70803352407"}
0005433929568	BCF300	0731 884725	ALEKSANDR KARPOV	{"phone": "+70503344319"}
0005433929569	ADCAB0	4036 473629	ANATOLIY DENISOV	{"email": "anatoliydenisov.041981@postgrespro.ru", "phone": "+70529989558"}
0005433929570	D9AEEA	6363 323123	TATYANA BELOVA	{"email": "belova_t1976@postgrespro.ru", "phone": "+70759081025"}
0005433929571	48F8F1	9764 842673	ANASTASIYA IVANOVA	{"phone": "+70439413589"}
0005433929572	48F8F1	7915 532814	YULIYA NIKITINA	{"phone": "+70265555512"}
0005433929573	163928	4347 475846	TATYANA ALEKSEEVA	{"phone": "+70286700323"}
0005433929574	163928	7330 972286	ALENA KOZLOVA	{"email": "kozlova.alena-01051970@postgrespro.ru", "phone": "+70995896312"}
0005433929575	E5BF8C	5746 606752	DENIS GORBUNOV	{"email": "gorbunov-d_1973@postgrespro.ru", "phone": "+70185876824"}
0005433929576	17D260	5038 265323	ALEKSEY POPOV	{"phone": "+70536852521"}
0005433929577	17D260	6550 205410	VALENTINA PETROVA	{"phone": "+70521975605"}
0005433929578	B61E2E	8870 819962	ANNA TROFIMOVA	{"phone": "+70597021892"}
0005433929579	B61E2E	8655 503466	TATYANA NESTEROVA	{"email": "t.nesterova.1981@postgrespro.ru", "phone": "+70995224527"}
0005433929580	472DB0	0557 867877	VALENTINA STEPANOVA	{"email": "valentina.stepanova1971@postgrespro.ru", "phone": "+70826990228"}
0005433929581	A9CB52	8287 493147	TATYANA AFANASEVA	{"email": "afanasevatatyana_1966@postgrespro.ru", "phone": "+70708215821"}
0005433929582	0035C0	4975 467368	ANATOLIY FROLOV	{"phone": "+70254482853"}
0005433929583	0035C0	9520 822919	DARYA NOVIKOVA	{"phone": "+70640229494"}
0005433929584	A55FFA	8128 511366	POLINA KONOVALOVA	{"phone": "+70714188322"}
0005433929585	D22BFE	7816 494337	ARTEM KULIKOV	{"email": "kulikov_a08041975@postgrespro.ru", "phone": "+70997457690"}
0005433929586	9827E2	1292 954275	TATYANA KONDRATEVA	{"email": "kondrateva.tatyana-1977@postgrespro.ru", "phone": "+70937578611"}
0005433929587	3539B9	9291 340571	EMILIYA NESTEROVA	{"email": "nesterova-e.061971@postgrespro.ru", "phone": "+70550030076"}
0005433929588	6890C3	2861 200447	NADEZHDA NAZAROVA	{"email": "nazarova.n.19111967@postgrespro.ru", "phone": "+70073579852"}
0005433929589	E84B8C	9982 068567	ANATOLIY IVANOV	{"email": "ivanov-a.03101958@postgrespro.ru", "phone": "+70139673153"}
0005433929590	9DDD90	7383 684092	ANTON DAVYDOV	{"email": "anton-davydov.1971@postgrespro.ru", "phone": "+70392372416"}
0005433929591	2F77CC	5722 360403	VALERIYA SOKOLOVA	{"email": "sokolovav-1969@postgrespro.ru", "phone": "+70362579962"}
0005433929592	BC4D49	2175 864448	NIKITA IVANOV	{"email": "ivanovn_1963@postgrespro.ru", "phone": "+70125986438"}
0005433929593	BC4D49	3364 321581	ELENA EFIMOVA	{"phone": "+70742696350"}
0005433929594	1ACAB3	7121 022454	SVETLANA PETROVA	{"phone": "+70270266057"}
0005433929595	1ACAB3	9280 264791	ALEKSANDR NAUMOV	{"email": "naumov_aleksandr-1969@postgrespro.ru", "phone": "+70105653786"}
0005433929596	919CBA	2930 098653	VLADIMIR ORLOV	{"email": "vladimir_orlov_101969@postgrespro.ru", "phone": "+70614004137"}
0005433929597	C5442B	5493 433564	ANDREY GORBUNOV	{"email": "andrey.gorbunov.011963@postgrespro.ru", "phone": "+70074874416"}
0005433929598	C5442B	7614 390599	ARTEM BORISOV	{"email": "aborisov.071974@postgrespro.ru", "phone": "+70295379052"}
0005433929599	C5442B	1277 872649	VALENTINA MIKHAYLOVA	{"phone": "+70328039842"}
0005433929600	19D8B4	3452 044672	SERGEY MAKSIMOV	{"email": "smaksimov.20021968@postgrespro.ru", "phone": "+70150284669"}
0005433929601	B66993	1322 162083	MARGARITA KULIKOVA	{"phone": "+70521448803"}
0005433929602	74B43B	6558 863298	ELIZAVETA VOLKOVA	{"phone": "+70561672813"}
0005433929603	3E0290	9862 431656	TATYANA LEBEDEVA	{"email": "lebedevatatyana081969@postgrespro.ru", "phone": "+70707689200"}
0005433929604	F51654	3071 734763	RASIM MARTYNOV	{"email": "martynov-r-1965@postgrespro.ru", "phone": "+70399484903"}
0005433929605	F51654	1029 463807	MARIYA STEPANOVA	{"email": "mstepanova_13091970@postgrespro.ru", "phone": "+70155777324"}
0005433929606	2292F1	6128 907741	NIKOLAY PETROV	{"phone": "+70789833862"}
0005433929607	2292F1	0485 445364	ARTEM BELOV	{"email": "belov-artem.1980@postgrespro.ru", "phone": "+70776295506"}
0005433929608	DD2C6F	2354 246747	RAIS SERGEEV	{"email": "raissergeev_111975@postgrespro.ru", "phone": "+70368545809"}
0005433929609	DD2C6F	9788 363214	EVGENIY TIKHONOV	{"email": "evgeniy.tikhonov_1976@postgrespro.ru", "phone": "+70313236295"}
0005433929610	F7A33B	0764 781110	EVGENIY AFANASEV	{"email": "evgeniy-afanasev1966@postgrespro.ru", "phone": "+70548964964"}
0005433929611	1515B4	8826 724240	GALINA MELNIKOVA	{"phone": "+70749504995"}
0005433929612	5B0615	7033 375720	TATYANA ANTONOVA	{"email": "antonovat1966@postgrespro.ru", "phone": "+70386122911"}
0005433929613	B55711	4337 858371	MARIYA SIDOROVA	{"phone": "+70135472974"}
0005433929614	99D3EF	8068 473425	EVGENIY BORISOV	{"email": "evgeniy.borisov-011973@postgrespro.ru", "phone": "+70549292958"}
0005433929615	99D3EF	7637 719247	DARYA KOLESNIKOVA	{"phone": "+70166370549"}
0005433929616	700DE8	2929 820333	VLADISLAV VOROBEV	{"email": "v_vorobev-10091968@postgrespro.ru", "phone": "+70973362607"}
0005433929617	700DE8	7266 006078	VIKTOR CHERNOV	{"email": "chernov.viktor_041978@postgrespro.ru", "phone": "+70836864668"}
0005433929618	C52A7E	5602 478906	TATYANA MOROZOVA	{"phone": "+70582582997"}
0005433929619	483DC1	3957 072760	MARIYA STEPANOVA	{"email": "stepanovam-24011968@postgrespro.ru", "phone": "+70062847620"}
0005433929620	546282	9589 244127	ANASTASIYA KULIKOVA	{"email": "kulikova_anastasiya_081972@postgrespro.ru", "phone": "+70766637137"}
0005433929621	73EA3E	8273 768702	YULIYA SMIRNOVA	{"email": "smirnovay.101973@postgrespro.ru", "phone": "+70627653941"}
0005433929622	73EA3E	7787 872691	NINA BELOVA	{"email": "belova.n_11011964@postgrespro.ru", "phone": "+70994355775"}
0005433929623	73EA3E	6665 468935	EDUARD POPOV	{"phone": "+70647020350"}
0005433929624	E5CF51	5014 201840	DMITRIY ANDREEV	{"email": "andreev.d1963@postgrespro.ru", "phone": "+70876884892"}
0005433929625	E5CF51	7065 399140	VLADLEN FROLOV	{"phone": "+70498904843"}
0005433929626	CE603D	8676 871876	ELENA ALEKSANDROVA	{"email": "e-aleksandrova.18081983@postgrespro.ru", "phone": "+70138318953"}
0005433929627	AB52E3	1517 326077	ZINAIDA RODIONOVA	{"email": "zinaidarodionova-1973@postgrespro.ru", "phone": "+70359710234"}
0005433929628	AB52E3	4097 318259	EVGENIY ALEKSEEV	{"phone": "+70614136619"}
0005433929629	0D9147	7759 465366	MATRENA KAZAKOVA	{"phone": "+70492590556"}
0005433929630	5A4F55	7018 589189	ELENA GERASIMOVA	{"phone": "+70681492727"}
0005433929631	EA15DE	2992 367640	DMITRIY IVANOV	{"phone": "+70390476281"}
0005433929632	24DCF0	3308 215407	OLGA OVCHINNIKOVA	{"phone": "+70433477464"}
0005433929633	24DCF0	3928 259636	TATYANA RODIONOVA	{"phone": "+70556266009"}
0005433929634	2F42BB	0450 865168	SERGEY IVANOV	{"phone": "+70562129984"}
0005433929635	29B5CA	5920 042011	ALEKSANDR VOROBEV	{"email": "a_vorobev.18111979@postgrespro.ru", "phone": "+70713382267"}
0005433929636	1422F3	8351 149074	EKATERINA OSIPOVA	{"email": "osipova_e111969@postgrespro.ru", "phone": "+70563384988"}
0005433929637	D5054D	9903 807503	ANDREY STEPANOV	{"phone": "+70212978298"}
0005433929638	D5054D	0867 193620	ANASTASIYA VASILEVA	{"email": "anastasiyavasileva_041968@postgrespro.ru", "phone": "+70845297595"}
0005433929639	D5054D	8609 173086	ALEKSANDR ZHUKOV	{"phone": "+70208433939"}
0005433929640	77EF68	4087 191252	VIKTOR SAVELEV	{"phone": "+70060474239"}
0005433929641	77EF68	9879 405295	VALERIY GRIGOREV	{"email": "grigorevv_091969@postgrespro.ru", "phone": "+70029286595"}
0005433929642	C1E8E9	2801 832159	EVGENIY PETROV	{"email": "e.petrov.061989@postgrespro.ru", "phone": "+70100377489"}
0005433929643	D88C40	4594 345712	ALIYA BELOVA	{"phone": "+70350729395"}
0005433929644	D88C40	4755 917966	MARINA SMIRNOVA	{"phone": "+70240054381"}
0005433929645	D88C40	7542 697647	NIKOLAY VASILEV	{"email": "n-vasilev10051975@postgrespro.ru", "phone": "+70101236012"}
0005433929646	D2358A	2903 674102	OLEG KUZNECOV	{"email": "olegkuznecov_061980@postgrespro.ru", "phone": "+70917562992"}
0005433929647	89C9AC	4694 367468	NIKITA MAKSIMOV	{"email": "nikita-maksimov051975@postgrespro.ru", "phone": "+70399492728"}
0005433929648	75E473	8711 115870	SVETLANA CHERNOVA	{"email": "chernovasvetlana-121977@postgrespro.ru", "phone": "+70967062614"}
0005433929649	20B61C	7435 851036	ELENA KOZLOVA	{"phone": "+70383025131"}
0005433929650	20B61C	6453 035421	SOFYA KOROLEVA	{"phone": "+70740414459"}
0005433929651	90759A	7502 642748	SOFYA POLYAKOVA	{"phone": "+70077889229"}
0005433929652	90759A	2126 011431	GALINA PETROVA	{"phone": "+70260142900"}
0005433929653	90759A	0297 377060	DENIS IVANOV	{"phone": "+70628951935"}
0005433929654	85DCC0	4465 553864	ALEKSANDR POPOV	{"phone": "+70558764356"}
0005433929655	B6107F	5591 125784	STANISLAV SMIRNOV	{"email": "smirnov-s1974@postgrespro.ru", "phone": "+70629588205"}
0005433929656	B843ED	0142 460361	VALENTIN MAKAROV	{"phone": "+70553168776"}
0005433929657	B843ED	0300 157885	LYUBOV MELNIKOVA	{"email": "lyubovmelnikova-091973@postgrespro.ru", "phone": "+70534390450"}
0005433929658	F8390D	7144 690187	MIKHAIL PETROV	{"phone": "+70964311530"}
0005433929659	F8390D	7140 360619	ANDREY MOROZOV	{"email": "andrey.morozov1976@postgrespro.ru", "phone": "+70175074407"}
0005433929660	49F4DD	3586 385523	OLEG GORBUNOV	{"phone": "+70756698765"}
0005433929661	CC4AFA	2870 936424	ALEKSANDR MOISEEV	{"email": "moiseeva-051966@postgrespro.ru", "phone": "+70075334326"}
0005433929662	12C886	9777 592917	NADEZHDA MIKHAYLOVA	{"email": "n.mikhaylova021970@postgrespro.ru", "phone": "+70312724975"}
0005433929663	FF4EBE	3097 805162	NATALYA KONOVALOVA	{"phone": "+70671049600"}
0005433929664	EEC82D	7511 072805	SERGEY KUZNECOV	{"email": "sergeykuznecov13091982@postgrespro.ru", "phone": "+70772529472"}
0005433929665	445430	0733 262282	ANATOLIY KOZLOV	{"email": "a_kozlov.1973@postgrespro.ru", "phone": "+70111724702"}
0005433929666	63B016	3108 878821	TATYANA MASLOVA	{"email": "tatyanamaslova_121966@postgrespro.ru", "phone": "+70127652464"}
0005433929667	63B016	5048 489326	NINA SOLOVEVA	{"email": "ninasoloveva13061974@postgrespro.ru", "phone": "+70495302768"}
0005433929668	3125AF	3814 362740	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr.1963@postgrespro.ru", "phone": "+70522751955"}
0005433929669	43A6F1	9776 652437	MIKHAIL NAZAROV	{"phone": "+70149601912"}
0005433929670	43A6F1	6617 567386	SVETLANA VLASOVA	{"phone": "+70805943528"}
0005433929671	F79D8F	0385 308191	EVGENIY BELOV	{"phone": "+70092047138"}
0005433929672	CE1D4B	8643 932698	ALEKSEY POPOV	{"email": "aleksey_popov061973@postgrespro.ru", "phone": "+70958719466"}
0005433929673	13655D	8154 562078	LYUDMILA FROLOVA	{"email": "lyudmilafrolova.081965@postgrespro.ru", "phone": "+70727344783"}
0005433929674	E09EA2	7244 181487	ANNA PAVLOVA	{"phone": "+70314652625"}
0005433929675	C3A2B4	9995 029621	OLGA ZAKHAROVA	{"email": "zakharova-o-1965@postgrespro.ru", "phone": "+70867786503"}
0005433929676	D1B7CD	2457 364444	SERGEY BONDARENKO	{"email": "sbondarenko.11011970@postgrespro.ru", "phone": "+70958509518"}
0005433929677	409C34	7204 201419	ANNA KUZNECOVA	{"email": "kuznecova-anna-1970@postgrespro.ru", "phone": "+70203697550"}
0005433929678	A8EA9D	2154 634893	NINA KOROLEVA	{"email": "koroleva_nina-051981@postgrespro.ru", "phone": "+70384101130"}
0005433929679	A08ACF	5065 289443	NIKOLAY VLASOV	{"phone": "+70568794639"}
0005433929680	5DC5AD	1286 408734	SHAMIL ANDREEV	{"phone": "+70993914126"}
0005433929681	5DC5AD	9585 213600	EKATERINA MIKHAYLOVA	{"phone": "+70580524491"}
0005433929682	EAAB24	7628 896776	ANNA PAVLOVA	{"phone": "+70535964280"}
0005433929683	EAAB24	8261 937807	LYUBOV KRASNOVA	{"email": "l.krasnova_04081981@postgrespro.ru", "phone": "+70803646429"}
0005433929684	81A087	7666 178866	LYUDMILA KAZAKOVA	{"email": "kazakova_l-1981@postgrespro.ru", "phone": "+70931906652"}
0005433929685	81A087	4222 673239	PAVEL VOLKOV	{"phone": "+70717154147"}
0005433929686	A10EDB	0145 717459	SERGEY ZAKHAROV	{"phone": "+70958008639"}
0005433929687	A10EDB	9016 518753	IGOR KUZNECOV	{"email": "kuznecov.igor1978@postgrespro.ru", "phone": "+70943321585"}
0005433929688	5DCECA	3189 944940	EGOR NAZAROV	{"email": "nazarov_egor_1973@postgrespro.ru", "phone": "+70126525774"}
0005433929689	B04EA5	4390 532997	ANATOLIY ZHUKOV	{"phone": "+70633297948"}
0005433929690	B04EA5	4515 340771	VERA NOVIKOVA	{"email": "vera-novikova-18041971@postgrespro.ru", "phone": "+70480847791"}
0005433929691	103460	2346 750149	NATALYA MAKSIMOVA	{"phone": "+70044415201"}
0005433929692	AD4B93	1322 319951	NATALYA POPOVA	{"email": "natalya.popova_061966@postgrespro.ru", "phone": "+70000081476"}
0005433929693	270756	6645 384589	MIKHAIL ILIN	{"phone": "+70019085307"}
0005433929694	270756	5627 121672	MARINA NESTEROVA	{"phone": "+70966789533"}
0005433929695	87EFF3	2600 165687	GALINA ILINA	{"email": "galina.ilina.19111981@postgrespro.ru", "phone": "+70773652869"}
0005433929696	87EFF3	8553 935999	IRINA GORBUNOVA	{"email": "gorbunova.irina.1973@postgrespro.ru", "phone": "+70807730242"}
0005433929697	461861	6566 623949	DMITRIY SOKOLOV	{"phone": "+70058606898"}
0005433929698	461861	9794 755769	GALINA MATVEEVA	{"email": "matveeva_g-121973@postgrespro.ru", "phone": "+70337445048"}
0005433929699	010DBE	6179 009716	ANASTASIYA PETROVA	{"phone": "+70325516188"}
0005433929700	010DBE	9067 553033	TATYANA CHERNOVA	{"phone": "+70802979660"}
0005433929701	11ABE5	9743 545301	TAMARA SOROKINA	{"phone": "+70899213913"}
0005433929702	73A807	1736 562914	ELENA ARKHIPOVA	{"phone": "+70500802870"}
0005433929703	73A807	4830 812026	TATYANA POPOVA	{"email": "tatyana_popova_02121975@postgrespro.ru", "phone": "+70538586556"}
0005433929704	ADA143	4564 791490	ELENA NAZAROVA	{"email": "enazarova_091978@postgrespro.ru", "phone": "+70723768195"}
0005433929705	ADA143	8171 438809	ELENA KUZNECOVA	{"phone": "+70954606943"}
0005433929706	ADA143	3553 129852	ALINA BARANOVA	{"email": "baranova_alina1974@postgrespro.ru", "phone": "+70848493848"}
0005433929707	532E66	5134 543401	IVAN SOROKIN	{"email": "sorokinivan081967@postgrespro.ru", "phone": "+70511206544"}
0005433929708	208386	6101 522455	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov-31051977@postgrespro.ru", "phone": "+70167445341"}
0005433929709	208386	9964 643705	ALEKSANDR PETROV	{"email": "aleksandr-petrov.021965@postgrespro.ru", "phone": "+70135102026"}
0005433929710	208386	1440 844707	NATALYA NOVIKOVA	{"email": "novikovanatalya_1982@postgrespro.ru", "phone": "+70974033795"}
0005433929711	B6006A	6939 511493	VIKTOR MOISEEV	{"phone": "+70455195741"}
0005433929712	B6006A	0095 670164	ANTONINA SIDOROVA	{"email": "a-sidorova.011969@postgrespro.ru", "phone": "+70442471325"}
0005433929713	6C5766	5421 963783	YULIYA NOVIKOVA	{"email": "yuliyanovikova_1981@postgrespro.ru", "phone": "+70010413464"}
0005433929714	C86438	5578 562063	VLADIMIR KRASNOV	{"phone": "+70552047147"}
0005433929715	6C4CC5	2938 061556	ARSENIY IVANOV	{"phone": "+70002333211"}
0005433929716	63F046	4631 317200	MIKHAIL SOLOVEV	{"email": "solovev_mikhail_101960@postgrespro.ru", "phone": "+70230505386"}
0005433929717	63F046	7014 319340	VYACHESLAV SOROKIN	{"phone": "+70808997417"}
0005433929718	734BDB	4591 471065	TATYANA VOROBEVA	{"email": "t.vorobeva_081957@postgrespro.ru", "phone": "+70808796149"}
0005433929719	E7AD38	6998 638943	ANTON NIKOLAEV	{"phone": "+70709018836"}
0005433929720	12C3B0	0821 219911	ELENA ANDREEVA	{"phone": "+70045795386"}
0005433929721	42CB2E	1975 148821	ELENA MIRONOVA	{"email": "mironova.elena_05041968@postgrespro.ru", "phone": "+70764232718"}
0005433929722	8B1BA3	9961 240646	NIKITA NOVIKOV	{"phone": "+70134085683"}
0005433929723	8B1BA3	5277 863820	SERGEY SOROKIN	{"phone": "+70443042114"}
0005433929724	96169C	6421 679408	NAIL DENISOV	{"email": "naildenisov031960@postgrespro.ru", "phone": "+70647839915"}
0005433929725	7F2802	7048 782578	GENNADIY MAKAROV	{"phone": "+70271094785"}
0005433929726	C10C7D	5500 811866	OKSANA ABRAMOVA	{"email": "o.abramova1969@postgrespro.ru", "phone": "+70038862568"}
0005433929727	660EC0	5819 266107	EKATERINA KISELEVA	{"email": "kiselevaekaterina091978@postgrespro.ru", "phone": "+70404945912"}
0005433929728	8FD818	5067 025812	RAISA ROMANOVA	{"phone": "+70107460258"}
0005433929729	8FD818	3592 572086	EVGENIY VASILEV	{"phone": "+70208457042"}
0005433929730	9D31D9	0873 464739	DMITRIY VASILEV	{"email": "vasilevd08121976@postgrespro.ru", "phone": "+70481798523"}
0005433929731	CC08F7	6334 871323	EVGENIY BARANOV	{"phone": "+70012674126"}
0005433929732	CC08F7	7098 040797	VALENTINA FADEEVA	{"phone": "+70192403234"}
0005433929733	F1DA50	3099 653910	ELENA VASILEVA	{"phone": "+70871746392"}
0005433929734	F1DA50	2727 598550	ANTON KUDRYASHOV	{"email": "antonkudryashov.03021969@postgrespro.ru", "phone": "+70961808337"}
0005433929857	3A75AD	6141 502679	DARYA IVANOVA	{"email": "ivanova_d10011979@postgrespro.ru", "phone": "+70895673043"}
0005433929858	8A10D0	3826 248611	ALEKSEY SOROKIN	{"email": "a-sorokin.051970@postgrespro.ru", "phone": "+70234595191"}
0005433929859	FA6584	3044 052030	TAMARA MOROZOVA	{"phone": "+70431779966"}
0005433929860	FA6584	5700 704896	ELENA IVANOVA	{"email": "ivanova-e-15111972@postgrespro.ru", "phone": "+70758652326"}
0005433929861	69B122	1690 904642	VLADIMIR IVANOV	{"phone": "+70602011637"}
0005433929862	69B122	7742 207986	ALEKSANDR POPOV	{"phone": "+70637091373"}
0005433929863	0507E3	4084 531076	NADEZHDA MOROZOVA	{"email": "n_morozova26051967@postgrespro.ru", "phone": "+70545854715"}
0005433929864	0881CD	1648 701891	GRIGORIY MEDVEDEV	{"email": "grigoriy.medvedev061960@postgrespro.ru", "phone": "+70059327272"}
0005433929865	4DF40A	4364 449396	ANDREY POPOV	{"phone": "+70239781410"}
0005433929866	4DF40A	3689 814386	ELENA VLASOVA	{"email": "vlasova.elena111978@postgrespro.ru", "phone": "+70666827438"}
0005433929867	4AB4B8	1583 767028	OLEG EGOROV	{"email": "egorov-o-11071972@postgrespro.ru", "phone": "+70121595323"}
0005433929868	4AB4B8	3376 475797	SERGEY BORISOV	{"email": "sborisov-051970@postgrespro.ru", "phone": "+70105439966"}
0005433929869	5A308C	7898 703777	PAVEL FROLOV	{"email": "frolov-pavel_1962@postgrespro.ru", "phone": "+70544118464"}
0005433929870	C16CDE	1244 036415	NADEZHDA ZAYCEVA	{"phone": "+70695545825"}
0005433929871	C16CDE	9343 524609	SERGEY FROLOV	{"phone": "+70772109765"}
0005433929872	078E23	5413 271504	MAKSIM KOZLOV	{"email": "kozlov_maksim081972@postgrespro.ru", "phone": "+70098735245"}
0005433929873	09319D	8053 335338	ALEKSANDR IVANOV	{"phone": "+70707389399"}
0005433929874	C22C49	1887 881283	ANNA EGOROVA	{"phone": "+70104333614"}
0005433929875	C22C49	0844 042702	ANTON GRIGOREV	{"email": "grigorevanton25041962@postgrespro.ru", "phone": "+70699595240"}
0005433929876	98E610	5309 163753	DMITRIY KONOVALOV	{"phone": "+70126460043"}
0005433929877	2F8F7C	5751 923152	EVGENIY MEDVEDEV	{"email": "medvedev_e.01091975@postgrespro.ru", "phone": "+70126162071"}
0005433929878	2F8F7C	6770 093771	ALEKSANDR NIKOLAEV	{"phone": "+70487389661"}
0005433929879	61D71B	6550 777859	NINA VOROBEVA	{"email": "ninavorobeva1968@postgrespro.ru", "phone": "+70178345402"}
0005433929880	61D71B	6076 713978	ANNA EFIMOVA	{"phone": "+70105962556"}
0005433929881	563913	5081 633152	PRASKOVYA VLASOVA	{"email": "p_vlasova_1970@postgrespro.ru", "phone": "+70619741342"}
0005433929882	563913	9266 765097	IRINA MOROZOVA	{"email": "irinamorozova081978@postgrespro.ru", "phone": "+70314543017"}
0005433929883	631FFD	5839 426870	ALBINA KUZNECOVA	{"email": "a-kuznecova-1967@postgrespro.ru", "phone": "+70985777604"}
0005433929884	8BCE24	5651 472191	MARGARITA SEMENOVA	{"phone": "+70490352654"}
0005433929885	8BCE24	4585 640046	AYRAT ZHURAVLEV	{"email": "a.zhuravlev041978@postgrespro.ru", "phone": "+70638071590"}
0005433929886	8EE5CB	8579 169074	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-091965@postgrespro.ru", "phone": "+70123123046"}
0005433929887	3BA5CE	4944 766778	NATALIYA ROMANOVA	{"phone": "+70307866207"}
0005433929888	3BA5CE	5595 855669	OLGA BOGDANOVA	{"email": "o.bogdanova-1972@postgrespro.ru", "phone": "+70107500170"}
0005433929889	8239B9	3377 137198	SERGEY SMIRNOV	{"phone": "+70953789848"}
0005433929890	F243A1	3883 798266	ANNA LEBEDEVA	{"email": "annalebedeva.041983@postgrespro.ru", "phone": "+70748907550"}
0005433929891	F243A1	3017 705103	ANTON VASILEV	{"email": "antonvasilev-02081971@postgrespro.ru", "phone": "+70885850537"}
0005433929892	C1A3EF	7510 843475	SVETLANA PAVLOVA	{"phone": "+70454488536"}
0005433929893	C1A3EF	5727 636884	ELENA YAKOVLEVA	{"phone": "+70900916233"}
0005433929894	DF680A	8902 147361	ALEKSEY GRIGOREV	{"email": "grigorev-aleksey_1974@postgrespro.ru", "phone": "+70307014425"}
0005433929895	DB3D14	3708 149441	ELENA MAKSIMOVA	{"email": "maksimova.e.011975@postgrespro.ru", "phone": "+70630691699"}
0005433929896	29E402	0027 586076	MAKSIM VASILEV	{"email": "m.vasilev-12071976@postgrespro.ru", "phone": "+70562512981"}
0005433929897	5FC87C	4253 938833	EKATERINA KOROLEVA	{"phone": "+70561163592"}
0005433929898	EFEE96	6686 999523	NURLAN BONDARENKO	{"email": "n.bondarenko_13071965@postgrespro.ru", "phone": "+70131322371"}
0005433929899	88CE4C	2457 391887	LYUDMILA NIKOLAEVA	{"email": "lyudmilanikolaeva_031961@postgrespro.ru", "phone": "+70268098562"}
0005433931466	43807C	9018 296028	TATYANA AKIMOVA	{"phone": "+70566408829"}
0005433931467	499019	7378 287684	SERGEY MAKAROV	{"phone": "+70065659508"}
0005433931413	910DCB	8445 213911	MIKHAIL ANDREEV	{"email": "mikhail.andreev1980@postgrespro.ru", "phone": "+70008291529"}
0005433931414	910DCB	5197 352803	MIKHAIL ZAKHAROV	{"phone": "+70734513313"}
0005433931415	030F41	7727 491327	SERGEY FILIPPOV	{"phone": "+70758045577"}
0005433931416	030F41	7392 828103	GALINA OVCHINNIKOVA	{"email": "g.ovchinnikova_22051966@postgrespro.ru", "phone": "+70572035509"}
0005433931417	413027	9054 973729	RASHID MOROZOV	{"email": "morozov.rashid-031976@postgrespro.ru", "phone": "+70090011397"}
0005433931418	FB3209	4339 370000	YURIY GRIGOREV	{"phone": "+70630464020"}
0005433931419	FB3209	0853 568597	MIKHAIL ANDREEV	{"email": "andreev-mikhail13021981@postgrespro.ru", "phone": "+70889638677"}
0005433931420	81DA79	7722 392561	EVGENIY SHEVCHENKO	{"phone": "+70347855211"}
0005433931421	D01D66	8171 416131	DENIS KUZNECOV	{"phone": "+70459882881"}
0005433931422	D01D66	2068 492589	DANIL DMITRIEV	{"phone": "+70556883181"}
0005433931423	827E57	7764 554355	VIKTOR IVANOV	{"email": "viktor-ivanov12061984@postgrespro.ru", "phone": "+70788691779"}
0005433931424	BB2B27	7097 658132	FARID BORISOV	{"email": "farid_borisov-23051963@postgrespro.ru", "phone": "+70268773000"}
0005433931425	89E384	4300 163750	LYUBOV VASILEVA	{"phone": "+70901326050"}
0005433931426	DFF82C	0314 082928	LYUDMILA TITOVA	{"email": "lyudmila.titova.081973@postgrespro.ru", "phone": "+70424179865"}
0005433931427	B6BA37	9962 612911	ALEKSEY STEPANOV	{"phone": "+70737467796"}
0005433931428	DFD0DE	2477 654469	DENIS ISAEV	{"phone": "+70503754651"}
0005433931429	DFD0DE	9534 373627	VERA GRISHINA	{"email": "grishina-v-16111972@postgrespro.ru", "phone": "+70032058563"}
0005433931430	0B2938	1809 499817	NINA KUDRYASHOVA	{"phone": "+70685915151"}
0005433931431	B0D7AC	7371 513217	MARIYA SERGEEVA	{"email": "sergeevam-02111976@postgrespro.ru", "phone": "+70158640200"}
0005433931432	258606	6737 446320	VLADIMIR KISELEV	{"email": "vladimirkiselev.1972@postgrespro.ru", "phone": "+70308292608"}
0005433931433	BE0CE5	0115 601287	NIKOLAY SOROKIN	{"email": "sorokinnikolay.1959@postgrespro.ru", "phone": "+70444178068"}
0005433931434	A8CAFA	5996 516341	ALEKSANDR SEMENOV	{"email": "asemenov_1974@postgrespro.ru", "phone": "+70842540306"}
0005433931435	A8CAFA	8912 734792	VALENTINA POPOVA	{"email": "valentinapopova_07051976@postgrespro.ru", "phone": "+70563033691"}
0005433931436	51E60E	5499 124818	ALINA ANDREEVA	{"phone": "+70792495763"}
0005433931437	D490DA	6334 622527	NIKOLAY KULIKOV	{"phone": "+70374127501"}
0005433931438	D490DA	8223 007624	NADEZHDA POPOVA	{"email": "popova_n_25071979@postgrespro.ru", "phone": "+70242255846"}
0005433931439	ED2931	1143 842375	NIKITA KUZMIN	{"phone": "+70306507348"}
0005433931440	2A5E34	0256 360790	SEMEN ZAKHAROV	{"email": "zakharov-s.121976@postgrespro.ru", "phone": "+70906158958"}
0005433931441	2A5E34	6709 443740	OLGA DMITRIEVA	{"email": "odmitrieva.24121968@postgrespro.ru", "phone": "+70757533112"}
0005433931442	A19B16	6574 723067	TATYANA ORLOVA	{"phone": "+70659756751"}
0005433931443	BB0214	7471 338480	SERGEY KUZNECOV	{"phone": "+70130289925"}
0005433931444	79C139	0999 573213	SERGEY ALEKSEEV	{"phone": "+70672058743"}
0005433931445	800F20	5103 540320	EVGENIY KOZLOV	{"phone": "+70612086534"}
0005433931446	800F20	7165 232882	NINA KONOVALOVA	{"email": "nina_konovalova_1969@postgrespro.ru", "phone": "+70372058921"}
0005433931447	5FAB64	6683 414515	LYUBOV DENISOVA	{"phone": "+70776220723"}
0005433931448	198F1B	8086 199012	TATYANA CHERNOVA	{"email": "chernova_t_30051973@postgrespro.ru", "phone": "+70854883820"}
0005433931449	51F756	7518 071691	ZINAIDA VOROBEVA	{"email": "vorobeva.z-081969@postgrespro.ru", "phone": "+70532543268"}
0005433931450	8AFB57	9811 596957	VENERA VOLKOVA	{"email": "venera-volkova_03041968@postgrespro.ru", "phone": "+70648508699"}
0005433931451	79980C	4333 333388	VALENTINA NESTEROVA	{"email": "v-nesterova-1958@postgrespro.ru", "phone": "+70582644933"}
0005433931452	79980C	2759 946763	NADEZHDA GORBUNOVA	{"email": "gorbunovanadezhda041979@postgrespro.ru", "phone": "+70960830428"}
0005433931453	670411	9111 489442	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr071975@postgrespro.ru", "phone": "+70055308720"}
0005433931454	69E53C	1115 946657	LADA ERMAKOVA	{"phone": "+70679751463"}
0005433931455	69E53C	9227 074451	PAVEL IVANOV	{"email": "ivanov.pavel_12111961@postgrespro.ru", "phone": "+70421647564"}
0005433931456	2E3B5A	7249 180157	EVGENIY VOLKOV	{"phone": "+70157722862"}
0005433931457	34BCB6	3046 164433	GALINA FADEEVA	{"email": "fadeeva_galina_081965@postgrespro.ru", "phone": "+70640457738"}
0005433931458	967771	8620 441595	IVAN IVANOV	{"email": "ivanivanov041984@postgrespro.ru", "phone": "+70880931359"}
0005433931459	967771	6701 453005	LARISA NOVIKOVA	{"email": "novikova.larisa_28121980@postgrespro.ru", "phone": "+70148745847"}
0005433931460	3917E9	2770 363304	ANDREY ZAKHAROV	{"email": "zakharov_andrey091978@postgrespro.ru", "phone": "+70744214288"}
0005433931461	4D17DC	6016 041357	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_aleksey_121969@postgrespro.ru", "phone": "+70317287146"}
0005433931462	4D17DC	0819 540079	NADEZHDA KUZMINA	{"email": "nadezhda.kuzmina1973@postgrespro.ru", "phone": "+70547206289"}
0005433931463	F56891	6611 272286	NATALYA POPOVA	{"email": "popova-n_27091969@postgrespro.ru", "phone": "+70671107899"}
0005433931464	D94606	8871 042446	ANATOLIY TIKHONOV	{"phone": "+70454761971"}
0005433931465	FC666B	0212 916390	SERGEY AFANASEV	{"email": "sergey_afanasev-30101973@postgrespro.ru", "phone": "+70989459202"}
0005433931468	EC7974	7250 642582	VERA MAKSIMOVA	{"email": "vera-maksimova.111970@postgrespro.ru", "phone": "+70041891987"}
0005433931469	EC7974	5178 319144	STANISLAV TARASOV	{"phone": "+70526065581"}
0005433931470	180921	9828 013446	EGOR SMIRNOV	{"phone": "+70548040220"}
0005433931471	180921	6202 166701	ALENA BORISOVA	{"phone": "+70742837856"}
0005433931472	316288	9285 546885	SERGEY ILIN	{"email": "ilin.sergey1980@postgrespro.ru", "phone": "+70024166062"}
0005433931473	316288	9751 251500	VLADIMIR POPOV	{"email": "vladimir.popov.031964@postgrespro.ru", "phone": "+70952025103"}
0005433931474	316288	7052 643078	NATALYA VLASOVA	{"phone": "+70718262749"}
0005433931475	0B736F	2647 205603	LYUDMILA KOROLEVA	{"phone": "+70353589335"}
0005433931476	C483BD	4140 326687	NATALIYA KAZAKOVA	{"phone": "+70698328451"}
0005433931477	C483BD	0999 523330	ALEKSANDR GUSEV	{"email": "a_gusev_1958@postgrespro.ru", "phone": "+70816867284"}
0005433931478	352D43	4967 364184	ALEKSANDR FILIPPOV	{"phone": "+70021404588"}
0005433931479	352D43	8589 788684	MARINA VOROBEVA	{"phone": "+70259055992"}
0005433931480	352D43	4813 621794	ELENA BORISOVA	{"email": "e_borisova.17081976@postgrespro.ru", "phone": "+70092271854"}
0005433931481	15737B	6766 334425	IGOR KAZAKOV	{"phone": "+70954479522"}
0005433931482	59D111	5585 232745	NINA AFANASEVA	{"phone": "+70100246563"}
0005433931483	59D111	4570 944622	VALENTINA KUZNECOVA	{"phone": "+70063547024"}
0005433931484	4E4F54	3457 365191	ALEKSEY SEMENOV	{"phone": "+70174352533"}
0005433931485	8AF768	5427 962169	VIKTOR MIKHAYLOV	{"phone": "+70892598244"}
0005433931486	B67A6C	3133 843232	ALEKSEY PETROV	{"email": "petrov-aleksey.23051966@postgrespro.ru", "phone": "+70498836188"}
0005433931487	D80687	6814 086819	SVETLANA LUKYANOVA	{"email": "lukyanovas.111976@postgrespro.ru", "phone": "+70129636808"}
0005433931488	81214D	1399 205060	OLGA SCHERBAKOVA	{"phone": "+70893686726"}
0005433931489	81214D	2728 569412	OLEG ANDREEV	{"email": "andreevoleg1962@postgrespro.ru", "phone": "+70345184915"}
0005433931490	A10A4C	9890 651778	DENIS NAZAROV	{"email": "nazarov_denis041966@postgrespro.ru", "phone": "+70633909249"}
0005433931491	A10A4C	6213 198943	SVETLANA ANISIMOVA	{"email": "anisimova_svetlana.1974@postgrespro.ru", "phone": "+70920440239"}
0005433931492	EB91A4	4388 911578	OLGA YUDINA	{"phone": "+70925009804"}
0005433931493	5DF151	3165 642999	OLEG ALEKSEEV	{"email": "alekseevoleg_26051978@postgrespro.ru", "phone": "+70441742732"}
0005433931494	A28D60	7083 560123	OLGA POPOVA	{"email": "popova-olga-1976@postgrespro.ru", "phone": "+70089311967"}
0005433931495	A28D60	4018 410144	KONSTANTIN GRIGOREV	{"email": "grigorevkonstantin_23071965@postgrespro.ru", "phone": "+70095889440"}
0005433931496	647E6D	5109 377725	ALEKSANDR ROMANOV	{"phone": "+70660297469"}
0005433931497	647E6D	2250 017860	MARIYA ABRAMOVA	{"phone": "+70460478788"}
0005433931498	C980E7	3511 813862	SERGEY SIDOROV	{"phone": "+70011342452"}
0005433931499	B3DABE	3601 163493	TATYANA ABRAMOVA	{"phone": "+70656460204"}
0005433931500	5AB2E0	5070 308424	EKATERINA MIRONOVA	{"phone": "+70117118232"}
0005433931501	188F5C	9160 489077	KRISTINA ANISIMOVA	{"email": "anisimova.k-13111978@postgrespro.ru", "phone": "+70154913173"}
0005433931502	9A347B	9621 915001	LYUBOV KUZNECOVA	{"phone": "+70845170924"}
0005433931503	9A347B	4292 899135	ALEKSANDR FILIPPOV	{"phone": "+70885769906"}
0005433931504	9A347B	1033 610979	NADEZHDA DENISOVA	{"email": "denisova-n-121964@postgrespro.ru", "phone": "+70927463912"}
0005433931505	811A8E	4885 542644	VASILIY BELOV	{"email": "belov-vasiliy1975@postgrespro.ru", "phone": "+70827185747"}
0005433931506	91B92A	9828 019028	KSENIYA ZHURAVLEVA	{"phone": "+70911009568"}
0005433931507	D959FF	5744 787560	ALEKSEY TIMOFEEV	{"email": "timofeev-a_1971@postgrespro.ru", "phone": "+70960289909"}
0005433931508	D959FF	0965 631557	ALEKSANDR POPOV	{"email": "popova_1968@postgrespro.ru", "phone": "+70392761931"}
0005433931509	BFA549	3200 022260	ANDREY ZAYCEV	{"phone": "+70721545139"}
0005433931510	BFA549	0555 849719	NIKOLAY BORISOV	{"phone": "+70575915666"}
0005433931511	B4D11B	8002 363003	VYACHESLAV GAVRILOV	{"email": "gavrilov.v_27111973@postgrespro.ru", "phone": "+70792746134"}
0005433931512	CA1D68	4813 913346	VALENTINA GORBUNOVA	{"email": "gorbunova-valentina-28091970@postgrespro.ru", "phone": "+70244858565"}
0005433931513	CA1D68	4604 431102	MARINA NESTEROVA	{"email": "nesterova-marina_061967@postgrespro.ru", "phone": "+70631207697"}
0005433931514	4531EC	0929 975434	VALENTINA ALEKSEEVA	{"phone": "+70499865150"}
0005433931515	E25BE0	1988 101557	GYUZEL GAVRILOVA	{"email": "g.gavrilova-11091980@postgrespro.ru", "phone": "+70724456137"}
0005433931516	E25BE0	2574 388512	VLADIMIR OSIPOV	{"phone": "+70323498990"}
0005433931517	E3326B	4334 873287	SOFYA STEPANOVA	{"email": "sstepanova.1975@postgrespro.ru", "phone": "+70481926929"}
0005433931518	E3326B	9012 525256	YULIYA SEMENOVA	{"email": "semenova-yuliya18071953@postgrespro.ru", "phone": "+70667732910"}
0005433931519	D9980B	1408 540210	LYUDMILA ZHUKOVA	{"email": "l_zhukova-1969@postgrespro.ru", "phone": "+70610059592"}
0005433931520	298DD5	4443 506241	VERA POPOVA	{"email": "popovavera.081987@postgrespro.ru", "phone": "+70851973969"}
0005433931521	3BF458	5563 681203	VALENTIN KUZMIN	{"phone": "+70054414078"}
0005433931522	6A8E1D	3007 457667	NIKOLAY NAZAROV	{"email": "n-nazarov-16071972@postgrespro.ru", "phone": "+70265890392"}
0005433931523	27244C	3267 878309	PETR KISELEV	{"email": "petrkiselev111976@postgrespro.ru", "phone": "+70186648068"}
0005433931524	6DFDC5	9246 138513	GENNADIY MELNIKOV	{"phone": "+70105231867"}
0005433931525	27D1F2	7937 119513	MARINA NIKITINA	{"phone": "+70495984759"}
0005433931526	27D1F2	3483 459931	ALINA ZOTOVA	{"email": "zotova.alina.081959@postgrespro.ru", "phone": "+70615315627"}
0005433931527	CB1B82	8519 999458	YULIYA TARASOVA	{"email": "tarasovayuliya-1968@postgrespro.ru", "phone": "+70315367713"}
0005433931528	DEC7BB	2819 595460	GALINA SMIRNOVA	{"phone": "+70242443597"}
0005433931529	9FBEA0	1193 981070	VALENTIN MATVEEV	{"phone": "+70761603568"}
0005433931530	6833BC	0924 257974	EKATERINA GERASIMOVA	{"phone": "+70109306726"}
0005433931531	A21BA8	8803 288592	EKATERINA VLASOVA	{"email": "ekaterina_vlasova_031971@postgrespro.ru", "phone": "+70587818376"}
0005433931532	0C00FF	4315 310464	VLADISLAV KUZNECOV	{"phone": "+70012549878"}
0005433931533	0C00FF	3371 669709	VIKTOR MAKSIMOV	{"phone": "+70322437923"}
0005433931534	760409	5114 371376	VIKTOR ALEKSEEV	{"phone": "+70895334249"}
0005433931535	8C6D46	4439 442784	TATYANA MARTYNOVA	{"email": "martynova-tatyana27081967@postgrespro.ru", "phone": "+70019644147"}
0005433931536	BCC70C	6802 812288	IGOR YAKOVLEV	{"email": "yakovlev.i_16081969@postgrespro.ru", "phone": "+70289364474"}
0005433931537	BCC70C	8937 719600	NATALYA POPOVA	{"email": "popovan-1968@postgrespro.ru", "phone": "+70277805355"}
0005433931538	0456BC	0744 815531	SERGEY VLASOV	{"phone": "+70131576375"}
0005433931539	0456BC	7487 838207	YURIY KOZLOV	{"phone": "+70751950981"}
0005433931540	E88CE6	3594 996581	ANDREY ZAKHAROV	{"phone": "+70967405194"}
0005433931541	4CB52C	3527 623071	DARINA LAZAREVA	{"email": "lazarevad.021977@postgrespro.ru", "phone": "+70541565263"}
0005433931542	4CB52C	8941 491465	VLADIMIR ALEKSEEV	{"email": "vladimir.alekseev.031970@postgrespro.ru", "phone": "+70495223501"}
0005433931543	C3D070	3663 683902	SVETLANA KOROLEVA	{"phone": "+70688281242"}
0005433931544	3654DA	7214 575943	IRINA KONDRATEVA	{"phone": "+70048912074"}
0005433931545	27E713	3780 824695	ALENA MELNIKOVA	{"email": "a_melnikova-10111980@postgrespro.ru", "phone": "+70303565175"}
0005433931546	27E713	5555 131031	SVETLANA FILATOVA	{"phone": "+70868396375"}
0005433931547	27E713	8271 280529	VERA SMIRNOVA	{"email": "v-smirnova_1982@postgrespro.ru", "phone": "+70085535564"}
0005433931548	E62CB0	3474 301302	GALINA PETROVA	{"phone": "+70889359762"}
0005433931549	914B4A	4760 398818	VASILISA ORLOVA	{"email": "vasilisaorlova.011974@postgrespro.ru", "phone": "+70986014437"}
0005433931550	914B4A	3726 062938	ANTONINA LEBEDEVA	{"email": "a-lebedeva.041970@postgrespro.ru", "phone": "+70758609441"}
0005433931551	9FF041	7257 189009	EKATERINA FILATOVA	{"email": "ekaterina-filatova.071977@postgrespro.ru", "phone": "+70714877914"}
0005433931552	A26241	3107 518784	YURIY NAZAROV	{"email": "yuriy-nazarov_1967@postgrespro.ru", "phone": "+70142444946"}
0005433931553	0EC7AA	2170 377874	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr.061971@postgrespro.ru", "phone": "+70656411199"}
0005433931554	21F176	8571 127300	OLEG KARPOV	{"phone": "+70326460440"}
0005433931555	C71456	2246 113916	LYUBOV EFREMOVA	{"phone": "+70739849867"}
0005433931556	AC7639	5085 461264	NATALYA LAZAREVA	{"phone": "+70794119533"}
0005433931557	AC7639	7240 395352	OLEG MIKHAYLOV	{"email": "oleg.mikhaylov_051965@postgrespro.ru", "phone": "+70492014570"}
0005433931558	571CF7	3306 021622	VALENTINA LEBEDEVA	{"email": "valentina-lebedeva1978@postgrespro.ru", "phone": "+70950906087"}
0005433931559	571CF7	8517 872393	NIKOLAY STEPANOV	{"phone": "+70141466767"}
0005433959856	7D432D	4218 610064	SVETLANA YAKOVLEVA	{"phone": "+70475343517"}
0005433959857	7D432D	2239 837630	MARGARITA IVANOVA	{"phone": "+70622157633"}
0005433959858	7D432D	4435 716364	EVGENIY MIKHAYLOV	{"email": "e-mikhaylov1964@postgrespro.ru", "phone": "+70272878622"}
0005433959859	A51091	3162 901970	VITALIY PETROV	{"email": "v-petrov-21071973@postgrespro.ru", "phone": "+70474226795"}
0005433959860	A51091	8508 507021	ZINAIDA MELNIKOVA	{"phone": "+70064388353"}
0005433959861	9704FF	3269 872704	PETR RODIONOV	{"phone": "+70980391693"}
0005433959862	7A5DD4	9786 317663	TAMARA OSIPOVA	{"email": "t-osipova-09061981@postgrespro.ru", "phone": "+70940296716"}
0005433959863	7A5DD4	0308 818291	ALEKSANDRA VASILEVA	{"email": "aleksandra.vasileva.30061969@postgrespro.ru", "phone": "+70719604072"}
0005433959864	72D993	4457 066159	NIKITA BELOV	{"phone": "+70275235827"}
0005433959865	AA2915	9149 359631	EVGENIY PETROV	{"email": "petrov-e-1971@postgrespro.ru", "phone": "+70545094215"}
0005433959866	69E229	8010 306306	VLADIMIR ZAYCEV	{"phone": "+70782006892"}
0005433959867	69E229	2481 875902	VLADIMIR VOROBEV	{"phone": "+70050811765"}
0005433959868	E8F622	2817 857842	ANZHELIKA VOLKOVA	{"phone": "+70590322732"}
0005433959869	484C73	0753 510137	DARYA VASILEVA	{"phone": "+70700406317"}
0005433959870	324F33	2500 150149	VALERIY ISAEV	{"phone": "+70904196565"}
0005433959871	317290	3619 771423	EMIL ILIN	{"phone": "+70486111414"}
0005433959872	89B1F8	7514 547311	KONSTANTIN MOROZOV	{"phone": "+70478541304"}
0005433959873	2C34A0	0568 160576	VLADIMIR FROLOV	{"phone": "+70916604956"}
0005433959874	EFA66C	6718 784750	EVDOKIYA ARKHIPOVA	{"email": "earkhipova-09011969@postgrespro.ru", "phone": "+70425549065"}
0005433959875	1D7C93	0265 855331	ARTEM SEMENOV	{"email": "asemenov_16021967@postgrespro.ru", "phone": "+70113399652"}
0005433959876	AD721E	6931 699841	NIKOLAY VLASOV	{"email": "n-vlasov121978@postgrespro.ru", "phone": "+70020854125"}
0005433959877	9F4D6D	2343 968822	EVGENIY DAVYDOV	{"phone": "+70875730618"}
0005433959878	AE0522	8619 621639	ALEKSANDR ISAEV	{"email": "aleksandrisaev1957@postgrespro.ru", "phone": "+70920453573"}
0005433959879	AE0522	9303 338800	YULIYA ROMANOVA	{"phone": "+70369498427"}
0005433959880	A254E6	2053 294370	IGOR TIKHONOV	{"email": "tikhonovi23021970@postgrespro.ru", "phone": "+70673691524"}
0005433959881	BB3FBE	6057 954788	ILYA VOROBEV	{"phone": "+70008855648"}
0005433959882	275B1A	6987 803477	MARIYA KONOVALOVA	{"phone": "+70463545388"}
0005433959883	275B1A	5044 235239	OLGA VASILEVA	{"phone": "+70045989593"}
0005433959884	275B1A	6832 396319	NINA KUZNECOVA	{"email": "kuznecova-n.101975@postgrespro.ru", "phone": "+70386055984"}
0005433959885	1BF44F	0686 063928	ANTON IVANOV	{"phone": "+70892591629"}
0005433959886	646AB5	4228 402453	LYUDMILA KUZNECOVA	{"phone": "+70469961984"}
0005433959887	1AC027	0139 019106	ALEKSANDR DAVYDOV	{"email": "davydov-a121966@postgrespro.ru", "phone": "+70542708209"}
0005433959888	B8071C	1357 966283	ALEKSANDR KUZMIN	{"phone": "+70626909765"}
0005433959889	A74392	9201 401865	ANNA EGOROVA	{"email": "egorovaanna.24091969@postgrespro.ru", "phone": "+70625456901"}
0005433959890	CAE594	4036 486653	VLADIMIR BORISOV	{"phone": "+70975989729"}
0005433959891	CAE594	5063 749477	LARISA OVCHINNIKOVA	{"phone": "+70503202437"}
0005433959892	C696B6	7263 584527	ALEKSANDRA VOLKOVA	{"email": "aleksandra-volkova_26121976@postgrespro.ru", "phone": "+70845535667"}
0005433959893	2A9729	7931 925043	ELENA ROMANOVA	{"phone": "+70660052088"}
0005433959894	2A9729	5548 771965	VALERIY MATVEEV	{"phone": "+70387144888"}
0005433959895	2A9729	9766 447977	YULIYA SMIRNOVA	{"email": "smirnova.y_051975@postgrespro.ru", "phone": "+70952385184"}
0005433959896	DE1019	8943 746758	ELENA YAKOVLEVA	{"phone": "+70564526602"}
0005433959897	A8CAC8	6887 438756	ANDREY FROLOV	{"phone": "+70231131805"}
0005433959898	5EE1F2	3816 155993	IVAN VASILEV	{"email": "i_vasilev_1964@postgrespro.ru", "phone": "+70495934825"}
0005433959899	CD8D54	3382 635238	ANNA NIKIFOROVA	{"email": "anna.nikiforova_1972@postgrespro.ru", "phone": "+70021306691"}
0005433959900	BF5B08	7180 566279	EVGENIY SERGEEV	{"email": "evgeniy-sergeev_1975@postgrespro.ru", "phone": "+70119171626"}
0005433959901	489A76	1096 667861	ANDREY MELNIKOV	{"phone": "+70958965285"}
0005433959902	489A76	5196 459622	DMITRIY IVANOV	{"phone": "+70891456055"}
0005433959903	7C474F	9942 798129	ALEKSANDR VOLKOV	{"email": "a_volkov.1983@postgrespro.ru", "phone": "+70491763319"}
0005433959904	E18E70	2960 563521	EVELINA EFREMOVA	{"phone": "+70735452475"}
0005433959905	8F8C78	0983 400133	NATALYA POPOVA	{"email": "n_popova.101968@postgrespro.ru", "phone": "+70572366687"}
0005433959906	8F8C78	2134 130904	LIDIYA NESTEROVA	{"email": "nesterova-l.1971@postgrespro.ru", "phone": "+70884647960"}
0005433959907	C48E45	8357 911778	VIKTOR NIKITIN	{"email": "viktor_nikitin.101971@postgrespro.ru", "phone": "+70810940864"}
0005433959908	A1ADDF	2064 204583	ANATOLIY NIKOLAEV	{"phone": "+70992939177"}
0005433959909	A1ADDF	7458 617188	SVETLANA KUZNECOVA	{"phone": "+70729218268"}
0005433959910	F35535	0746 420675	ROMAN TIKHONOV	{"email": "romantikhonov_1979@postgrespro.ru", "phone": "+70021973922"}
0005433959911	9600E5	0532 924465	TATYANA NOVIKOVA	{"email": "tatyana-novikova-1977@postgrespro.ru", "phone": "+70636403557"}
0005433959912	606EFD	1651 128289	ALBERT ANDREEV	{"phone": "+70210415456"}
0005433959913	A46E6A	8910 735335	GENNADIY IVANOV	{"phone": "+70372650740"}
0005433959914	A46E6A	9986 372170	NATALYA MOROZOVA	{"email": "nmorozova-021974@postgrespro.ru", "phone": "+70105029261"}
0005433959915	CC0012	6705 441031	ANDREY FILIPPOV	{"email": "a_filippov061962@postgrespro.ru", "phone": "+70701424145"}
0005433959916	E70BE1	3773 308634	ALEKSANDR MAKAROV	{"email": "makarov_a.1970@postgrespro.ru", "phone": "+70309959007"}
0005433959917	E70BE1	6646 798403	ILGIZ ZAYCEV	{"email": "i_zaycev.02061971@postgrespro.ru", "phone": "+70127187735"}
0005433959918	5D1CC6	7135 781325	ELENA TIKHONOVA	{"email": "tikhonova.e_22031965@postgrespro.ru", "phone": "+70412835797"}
0005433959919	5D1CC6	6109 969976	ALEKSANDRA NIKOLAEVA	{"phone": "+70819309803"}
0005433959920	5D1CC6	9483 971317	OLESYA LOGINOVA	{"email": "loginova.o28011978@postgrespro.ru", "phone": "+70565280796"}
0005433959921	1B4632	6938 154223	ANDREY PETROV	{"phone": "+70223815872"}
0005433959922	1B4632	0397 618128	NATALYA BELYAEVA	{"phone": "+70643311352"}
0005433959923	1B4632	1793 500103	ALEKSEY MAKSIMOV	{"phone": "+70709193415"}
0005433959924	D14EF2	7414 357870	KLAVDIYA EFIMOVA	{"phone": "+70251225035"}
0005433959925	E8FB99	1843 341949	NADEZHDA PAVLOVA	{"email": "nadezhda-pavlova-20031984@postgrespro.ru", "phone": "+70300777647"}
0005433959926	32540F	0436 215193	NINA SERGEEVA	{"phone": "+70112216543"}
0005433959927	6BBACC	8769 846550	OLGA EGOROVA	{"phone": "+70632132143"}
0005433959928	A0E3EB	1043 416764	ALEKSANDR SOKOLOV	{"email": "sokolov.a_29011980@postgrespro.ru", "phone": "+70413715023"}
0005433959929	2315AB	4636 231375	SVETLANA IVANOVA	{"email": "ivanova_svetlana_21051978@postgrespro.ru", "phone": "+70758082428"}
0005433959930	FA460F	1838 457455	DENIS PAVLOV	{"email": "d_pavlov-091973@postgrespro.ru", "phone": "+70356681013"}
0005433959931	FA460F	3740 800011	LIDIYA LUKYANOVA	{"email": "lukyanova.l.1971@postgrespro.ru", "phone": "+70127835024"}
0005433959932	0A94B0	6276 215771	TATYANA BOGDANOVA	{"phone": "+70131351284"}
0005433959933	AD5AA7	3764 087725	ZHANNA IVANOVA	{"phone": "+70763804102"}
0005433959934	AD5AA7	7009 799052	ELENA TITOVA	{"phone": "+70551343335"}
0005433959935	875826	2136 734365	ARTEMIY MOROZOV	{"email": "a.morozov.1965@postgrespro.ru", "phone": "+70721669343"}
0005433959936	CA0E2A	3910 648577	VALERIY ZAKHAROV	{"phone": "+70513881925"}
0005433959937	CA0E2A	6091 208984	SVETLANA MAKAROVA	{"email": "svetlana_makarova_08011980@postgrespro.ru", "phone": "+70044242560"}
0005433959938	162AEE	3061 490102	ALEKSANDR EGOROV	{"email": "aleksandr-egorov121976@postgrespro.ru", "phone": "+70107389173"}
0005433959939	F64967	7168 118417	OLGA TARASOVA	{"phone": "+70484562653"}
0005433959940	65E29F	4867 831464	VLADIMIR ROMANOV	{"phone": "+70035322031"}
0005433959941	BE1CC4	7845 285419	LYUBOV BELYAEVA	{"phone": "+70706757343"}
0005433959942	A6BDC1	7759 349491	YANA SERGEEVA	{"phone": "+70548145442"}
0005433959943	FE9507	0946 226886	YULIYA VASILEVA	{"phone": "+70080083831"}
0005433959944	FE9507	2244 367831	VADIM RODIONOV	{"email": "rodionov.vadim22041979@postgrespro.ru", "phone": "+70122500113"}
0005433959945	3D2934	0180 836536	NATALYA FEDOROVA	{"phone": "+70576345050"}
0005433959946	3D2934	8000 475171	ANDREY ROMANOV	{"email": "andreyromanov-071975@postgrespro.ru", "phone": "+70108079674"}
0005433959947	700755	7489 723042	KLAVDIYA FROLOVA	{"email": "kfrolova02031980@postgrespro.ru", "phone": "+70887643405"}
0005433959948	00E0BE	4154 649155	ELENA ALEKSEEVA	{"email": "alekseeva.e-111971@postgrespro.ru", "phone": "+70840332099"}
0005433959949	00E0BE	8801 685545	SVETLANA POLYAKOVA	{"phone": "+70935865076"}
0005433959950	1C1980	9886 033579	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov101960@postgrespro.ru", "phone": "+70763836171"}
0005433959951	5B2C06	7096 699019	VERA FROLOVA	{"email": "v-frolova-18021969@postgrespro.ru", "phone": "+70496880739"}
0005433959952	9D4C96	1862 570490	ARTEM EGOROV	{"phone": "+70580026415"}
0005433959953	F97113	2533 833207	SERGEY MATVEEV	{"email": "sergey_matveev_1963@postgrespro.ru", "phone": "+70456894702"}
0005433959954	F97113	5627 379442	TATYANA GAVRILOVA	{"email": "gavrilova.t02071962@postgrespro.ru", "phone": "+70576250091"}
0005433959955	F97113	8045 574566	EGOR IVANOV	{"phone": "+70583758018"}
0005433959956	DB7389	3455 769476	NATALIYA MATVEEVA	{"phone": "+70558175559"}
0005433959957	DB7389	2914 409002	LARISA FROLOVA	{"phone": "+70637940658"}
0005433959958	52FC10	8512 692304	DENIS CHERNOV	{"email": "chernovdenis041969@postgrespro.ru", "phone": "+70888417152"}
0005433959959	FE35B5	9109 022072	IGOR SERGEEV	{"email": "i.sergeev-1963@postgrespro.ru", "phone": "+70599852103"}
0005433959960	FE35B5	3751 742407	LIDIYA BELOVA	{"email": "lidiya.belova_16111972@postgrespro.ru", "phone": "+70892076607"}
0005433959961	2276DA	1196 947907	VIKTOR NIKOLAEV	{"email": "v.nikolaev21121969@postgrespro.ru", "phone": "+70734606511"}
0005433959962	2276DA	4620 021960	VLADIMIR KUDRYASHOV	{"phone": "+70835103000"}
0005433959963	DEDAA7	0174 930988	NIKOLAY NOVIKOV	{"email": "nikolay_novikov_1969@postgrespro.ru", "phone": "+70813744527"}
0005433959964	35EB3E	5014 821304	IGOR GORBUNOV	{"email": "gorbunov_i_071973@postgrespro.ru", "phone": "+70932040433"}
0005433959965	35EB3E	8761 256495	IVAN SOROKIN	{"phone": "+70232397960"}
0005433959966	8AA22D	9582 208376	YURIY SIDOROV	{"phone": "+70411143271"}
0005433959967	8AA22D	6187 127781	VLADIMIR IVANOV	{"email": "ivanov-vladimir_041965@postgrespro.ru", "phone": "+70622539886"}
0005433959968	F7D071	2527 312970	ANDREY VLASOV	{"email": "vlasov-andrey-1965@postgrespro.ru", "phone": "+70359725421"}
0005433959969	D90E23	9161 866910	ALEKSANDR KARPOV	{"phone": "+70782031841"}
0005433959970	12A05A	5786 710034	SVETLANA POPOVA	{"phone": "+70863793838"}
0005433959971	12A05A	9354 414615	ALEKSANDR DAVYDOV	{"email": "davydov_a041973@postgrespro.ru", "phone": "+70086538452"}
0005433959972	699720	7937 816678	TATYANA AKIMOVA	{"phone": "+70893918774"}
0005433959973	BD971B	0821 411269	VALENTIN ZHUKOV	{"phone": "+70030179385"}
0005433959974	BD971B	3832 841444	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov_071972@postgrespro.ru", "phone": "+70226283977"}
0005433959975	39DCD3	5198 275176	ANASTASIYA FILATOVA	{"phone": "+70305927989"}
0005433959976	EBDB1B	0666 349672	ALEKSEY VOLKOV	{"email": "volkov-aleksey-15031965@postgrespro.ru", "phone": "+70824504417"}
0005433959977	E99E1F	7142 780693	TATYANA TIKHONOVA	{"phone": "+70735651053"}
0005433959978	B8F5FD	7051 390968	TAMARA IVANOVA	{"email": "tamara.ivanova1973@postgrespro.ru", "phone": "+70679996360"}
0005433959979	B8F5FD	4519 551198	ELIZAVETA YAKOVLEVA	{"phone": "+70142492248"}
0005433959980	ED1E49	8589 453434	OLGA ZAYCEVA	{"email": "zaycevao_1966@postgrespro.ru", "phone": "+70462123177"}
0005433959981	614F81	1336 037621	ALEKSEY IVANOV	{"phone": "+70782457767"}
0005433959982	EA753F	6328 295984	ALEKSANDR KOZLOV	{"phone": "+70710543914"}
0005433959983	5AB566	6994 443313	ALEKSEY NAUMOV	{"phone": "+70120027084"}
0005433959984	B45771	0516 699496	VLADISLAV PAVLOV	{"email": "v.pavlov-041971@postgrespro.ru", "phone": "+70569668265"}
0005433959985	0F0A17	0134 645412	ELENA VLASOVA	{"email": "e-vlasova.24051958@postgrespro.ru", "phone": "+70638765435"}
0005433959986	5E821D	1288 977482	RUSTAM DAVYDOV	{"phone": "+70590566077"}
0005433959987	5E821D	6070 612831	VLADIMIR MOROZOV	{"email": "morozov_vladimir081978@postgrespro.ru", "phone": "+70322506998"}
0005433959988	84FC74	7878 614601	NATALYA FILIPPOVA	{"phone": "+70728649782"}
0005433959989	84FC74	2704 913737	VIKTOR KUZNECOV	{"email": "viktor_kuznecov-1972@postgrespro.ru", "phone": "+70661983472"}
0005433959990	32878C	9692 000129	IGOR SEMENOV	{"email": "semenov-igor.26121973@postgrespro.ru", "phone": "+70729799533"}
0005433959991	F2AD39	7353 355997	NIKITA NOVIKOV	{"email": "n-novikov_1967@postgrespro.ru", "phone": "+70081874654"}
0005433959992	41D3AE	0368 449768	VALERIY SOLOVEV	{"phone": "+70553388064"}
0005433959993	6C36BF	9481 552156	DANIYA PAVLOVA	{"email": "pavlova-d1964@postgrespro.ru", "phone": "+70365780432"}
0005433959994	7FDA5B	8338 232468	DANIIL MELNIKOV	{"phone": "+70196798879"}
0005433959995	1BD6DD	5027 979176	PAVEL FOMIN	{"phone": "+70824634647"}
0005433959996	5782EF	4771 387346	LIDIYA PETROVA	{"phone": "+70376131175"}
0005433959997	275E0C	0155 317790	VALENTINA ABRAMOVA	{"phone": "+70489303886"}
0005433959998	275E0C	2401 124485	TATYANA VOLKOVA	{"email": "tvolkova1978@postgrespro.ru", "phone": "+70627626789"}
0005433959999	F965A1	7773 580938	NINA DENISOVA	{"phone": "+70563047795"}
0005433960000	231003	1865 079995	OLGA MELNIKOVA	{"email": "melnikovao-041976@postgrespro.ru", "phone": "+70316497870"}
0005433960001	231003	5596 652994	EVGENIY IVANOV	{"phone": "+70341002610"}
0005433960002	D44B90	8165 111023	VLADIMIR SOROKIN	{"phone": "+70463596194"}
0005433960003	D44B90	0105 244286	ALEKSEY FEDOROV	{"phone": "+70656259326"}
0005433960004	EF2C0E	9429 208853	NIKOLAY EGOROV	{"email": "n_egorov.071972@postgrespro.ru", "phone": "+70515432741"}
0005433960005	B667E1	3097 428701	TATYANA MATVEEVA	{"phone": "+70578652080"}
0005433960006	144600	5690 588219	ELENA AFANASEVA	{"phone": "+70724996168"}
0005433960007	8BCF2F	1845 895425	IGOR KULIKOV	{"phone": "+70244627875"}
0005433960008	4EA6DF	8815 015710	ELENA TITOVA	{"email": "etitova-21101978@postgrespro.ru", "phone": "+70704474921"}
0005433960009	6A68B0	0922 247000	OLGA IVANOVA	{"email": "o-ivanova.1978@postgrespro.ru", "phone": "+70532253612"}
0005433960010	947A3B	7641 330309	MARIYA GAVRILOVA	{"email": "gavrilova-m.1962@postgrespro.ru", "phone": "+70443049275"}
0005433960011	5C965F	9629 949125	VIKTOR ANDREEV	{"phone": "+70850450193"}
0005433960012	5C965F	3859 598785	VIKTOR KUZNECOV	{"phone": "+70167069755"}
0005433960013	5C965F	1732 191473	YURIY DAVYDOV	{"phone": "+70931071519"}
0005433960014	486A4E	8765 289938	VIKTOR ZAKHAROV	{"email": "v-zakharov_24051968@postgrespro.ru", "phone": "+70323694793"}
0005433960015	BA98F5	7626 921508	ALMIRA KUZMINA	{"email": "kuzmina.almira1970@postgrespro.ru", "phone": "+70317073991"}
0005433960016	8FC71E	8391 077518	MARIYA DMITRIEVA	{"phone": "+70209037430"}
0005433960017	8FC71E	3124 288614	SERGEY SAVELEV	{"email": "savelev.s-061971@postgrespro.ru", "phone": "+70284500458"}
0005433960018	8FC71E	0854 510720	NATALYA NESTEROVA	{"email": "nesterova-natalya_1969@postgrespro.ru", "phone": "+70679886881"}
0005433960019	766374	4371 566842	SERGEY VASILEV	{"email": "vasilev_sergey081972@postgrespro.ru", "phone": "+70408484122"}
0005433960020	766374	5263 393143	FARIDA BELOVA	{"email": "fbelova-22021963@postgrespro.ru", "phone": "+70306875297"}
0005433960021	07682F	0825 762103	LIDIYA ZHURAVLEVA	{"email": "lidiya.zhuravleva_1965@postgrespro.ru", "phone": "+70327211170"}
0005433960022	07682F	8084 865827	SERGEY BONDARENKO	{"email": "s-bondarenko.1971@postgrespro.ru", "phone": "+70331458583"}
0005433960023	5905C9	2776 093326	DMITRIY NOVIKOV	{"email": "d.novikov-121982@postgrespro.ru", "phone": "+70019608473"}
0005433960024	7B4E7C	4530 139603	VERA MATVEEVA	{"phone": "+70336358851"}
0005433960025	DF72A9	2598 100086	NIKITA MARTYNOV	{"phone": "+70323522376"}
0005433960026	C6847E	3342 906119	ANASTASIYA FILATOVA	{"email": "filatova.a_091964@postgrespro.ru", "phone": "+70608854450"}
0005433960027	C6847E	2309 427411	OLGA IVANOVA	{"phone": "+70321931703"}
0005433960028	04F4AC	2174 885209	VLADIMIR EGOROV	{"phone": "+70769172444"}
0005433960029	FCC212	6898 018755	VERA MAKAROVA	{"phone": "+70979411566"}
0005433960030	3F9418	7773 794226	GALINA SAVELEVA	{"email": "saveleva_galina1976@postgrespro.ru", "phone": "+70618431566"}
0005433960031	3F9418	9239 604057	DANIL MOROZOV	{"email": "danil_morozov041970@postgrespro.ru", "phone": "+70171533555"}
0005433960032	3F9418	5950 747753	ANATOLIY NIKOLAEV	{"phone": "+70970014620"}
0005433960033	A80592	9406 091236	VIKTOR BONDARENKO	{"phone": "+70443503467"}
0005433960034	A80592	4454 393066	ANDREY MAKAROV	{"email": "makarov-a-011977@postgrespro.ru", "phone": "+70003777850"}
0005433960035	51A0D4	7150 716214	MIKHAIL ABRAMOV	{"phone": "+70365666898"}
0005433960036	D24900	6741 099346	ALEVTINA STEPANOVA	{"email": "alevtinastepanova.081970@postgrespro.ru", "phone": "+70729348259"}
0005433960037	AE7E41	4791 970938	ALEKSEY KUZNECOV	{"phone": "+70121032509"}
0005433960038	1D008F	1700 775082	NINA RYABOVA	{"email": "ryabova_n_1968@postgrespro.ru", "phone": "+70622682754"}
0005433960039	7EDB99	1910 322947	GEORGIY NAUMOV	{"email": "naumov-g071971@postgrespro.ru", "phone": "+70561625848"}
0005433960040	B64F33	0485 415816	SERGEY GUSEV	{"email": "gusev-sergey1980@postgrespro.ru", "phone": "+70079762077"}
0005433960041	6C2B9A	5991 461160	ELENA ISAEVA	{"phone": "+70571174741"}
0005433960042	6C2B9A	0203 908445	ILYA KISELEV	{"email": "kiselev.ilya_101975@postgrespro.ru", "phone": "+70630012378"}
0005433960043	AC48C1	5146 105247	LYUBOV KUZNECOVA	{"phone": "+70986324959"}
0005433960044	C6482B	0431 378758	VALENTINA TIKHONOVA	{"email": "tikhonova-v.30061971@postgrespro.ru", "phone": "+70379514965"}
0005433960045	B8F76E	9779 042981	IRINA IVANOVA	{"phone": "+70415988325"}
0005433960046	B8F76E	9930 239772	VIKTOR FEDOROV	{"phone": "+70289215930"}
0005433960047	21FEC2	9625 235873	SERGEY MATVEEV	{"email": "sergeymatveev_27101960@postgrespro.ru", "phone": "+70827859860"}
0005433960048	21FEC2	9009 986877	RODION TARASOV	{"email": "tarasov-r-1973@postgrespro.ru", "phone": "+70375691962"}
0005433960049	21FEC2	7646 893262	EKATERINA NAZAROVA	{"email": "e_nazarova.1970@postgrespro.ru", "phone": "+70964516295"}
0005433960050	7812FF	0863 251012	SHAMIL SIDOROV	{"phone": "+70353983507"}
0005433960051	A16C31	5645 899632	GULNARA PAVLOVA	{"email": "pavlovag.01071976@postgrespro.ru", "phone": "+70713499391"}
0005433960052	284087	9695 684059	ALEKSANDR KUZNECOV	{"email": "a_kuznecov_061963@postgrespro.ru", "phone": "+70168675174"}
0005433960053	CCCBBB	7349 944134	ANATOLIY ZAKHAROV	{"phone": "+70109676078"}
0005433960054	F3A9B7	7267 499740	MAKSIM MAKAROV	{"email": "m-makarov_081972@postgrespro.ru", "phone": "+70836055911"}
0005433960055	F3A9B7	8782 590464	RIMMA ANDREEVA	{"phone": "+70836064521"}
0005433960056	5E1C9A	7886 022024	ELENA KUZNECOVA	{"email": "kuznecova-e_011970@postgrespro.ru", "phone": "+70417429359"}
0005433960057	C586AE	1362 548297	KSENIYA GORBUNOVA	{"phone": "+70851866880"}
0005433960058	E7E045	8054 947483	GALINA ARKHIPOVA	{"phone": "+70150528581"}
0005433960059	CDA0DE	4968 024732	IVAN SAVELEV	{"phone": "+70511919354"}
0005433960060	CDA0DE	5870 123173	ALEKSANDR SOLOVEV	{"phone": "+70950800145"}
0005433960061	3B1442	4312 428921	OLGA DAVYDOVA	{"phone": "+70356430760"}
0005433960062	FA101E	5794 500790	OLGA SIDOROVA	{"phone": "+70523550512"}
0005433960063	98D1D6	0455 090802	TATYANA IVANOVA	{"phone": "+70509070691"}
0005433960064	AAB510	7944 264813	SERGEY MIRONOV	{"phone": "+70342702534"}
0005433960065	AAB510	1399 644015	ALENA KUZNECOVA	{"email": "alena.kuznecova-071982@postgrespro.ru", "phone": "+70624295409"}
0005433960066	83CC54	4050 489415	YULIYA MASLOVA	{"phone": "+70217425037"}
0005433960067	64F449	3731 718511	ALEKSANDRA DANILOVA	{"email": "danilova.aleksandra13111977@postgrespro.ru", "phone": "+70753884194"}
0005433960068	5E493D	6617 997764	ALEKSANDR GORBUNOV	{"email": "a.gorbunov_111980@postgrespro.ru", "phone": "+70933459566"}
0005433960069	2C47F5	5767 585706	VLADIMIR PETROV	{"email": "vladimir-petrov081979@postgrespro.ru", "phone": "+70633933499"}
0005433960070	580EB2	5963 457943	VIKTOR SAVELEV	{"email": "savelev_viktor.1977@postgrespro.ru", "phone": "+70409277366"}
0005433960071	8A0818	8687 176317	SVYATOSLAV CHERNOV	{"email": "chernov.svyatoslav-20111960@postgrespro.ru", "phone": "+70596613083"}
0005433960072	8A0818	4161 090500	ZOYA MIRONOVA	{"email": "z_mironova_15031973@postgrespro.ru", "phone": "+70495075892"}
0005433960073	8A0818	0439 633922	ALEKSANDR MAKAROV	{"phone": "+70388491452"}
0005433960074	66210F	7775 932173	TATYANA NIKITINA	{"phone": "+70442978047"}
0005433960075	A053C8	0967 410125	DENIS FROLOV	{"email": "frolovd04011976@postgrespro.ru", "phone": "+70641555248"}
0005433960076	A053C8	9544 598788	SERGEY NOVIKOV	{"phone": "+70127755081"}
0005433960077	9EFFA3	3230 744923	ANASTASIYA IVANOVA	{"phone": "+70866905705"}
0005433960078	C2B2D4	3800 607417	VLADIMIR VASILEV	{"phone": "+70717718194"}
0005433960079	C2B2D4	0707 042374	OLGA OSIPOVA	{"phone": "+70267946405"}
0005433960080	208A84	7202 459756	LEONID IVANOV	{"email": "ivanov-l-121969@postgrespro.ru", "phone": "+70514110160"}
0005433960081	8B4AD1	5755 233806	IRINA KARPOVA	{"phone": "+70739478200"}
0005433960082	1DF062	3195 634074	ELISEY GRIGOREV	{"phone": "+70658330551"}
0005433960083	907626	3656 724657	BORIS BELOV	{"phone": "+70365189166"}
0005433960084	3D5B2A	8285 330210	ANATOLIY KOZLOV	{"phone": "+70821840566"}
0005433960085	2D3D15	2284 523214	DMITRIY SOKOLOV	{"email": "sokolov-d1979@postgrespro.ru", "phone": "+70169563951"}
0005433960086	2D3D15	4834 318691	SVETLANA FADEEVA	{"phone": "+70533064316"}
0005433960087	C6E4D5	2724 874242	NADEZHDA AKIMOVA	{"phone": "+70332059063"}
0005433960088	DD795F	5510 670416	ALEKSANDR SERGEEV	{"phone": "+70533253661"}
0005433960089	1CD7D1	0899 683744	ELENA VOLKOVA	{"phone": "+70553806153"}
0005433960090	1CD7D1	3740 403915	SVETLANA SOKOLOVA	{"email": "sokolova_s-28061962@postgrespro.ru", "phone": "+70364988619"}
0005433960091	DD3809	5761 427500	FATIMA NIKITINA	{"phone": "+70652460556"}
0005433960092	AB7FD7	1752 689590	DMITRIY SOKOLOV	{"phone": "+70081140527"}
0005433960093	AB7FD7	1348 370301	ALEKSANDR DENISOV	{"email": "aleksandr-denisov011976@postgrespro.ru", "phone": "+70847409178"}
0005433960094	EBF2E3	3646 707823	YULIYA MOROZOVA	{"email": "morozova_y28031961@postgrespro.ru", "phone": "+70221487896"}
0005433960095	7C8C8A	0516 450297	NADEZHDA NIKITINA	{"email": "nadezhda.nikitina_1973@postgrespro.ru", "phone": "+70235593200"}
0005433960096	7C8C8A	7135 483106	SVETLANA MELNIKOVA	{"email": "melnikovas.101972@postgrespro.ru", "phone": "+70119417833"}
0005433960097	8336F1	8441 480685	ANDREY GORBUNOV	{"phone": "+70428251029"}
0005433960098	8336F1	7897 445573	NIKOLAY FEDOROV	{"email": "nikolay.fedorov-08061977@postgrespro.ru", "phone": "+70061587691"}
0005433960099	F00983	7489 672033	RAILYA MAKAROVA	{"phone": "+70920936449"}
0005433960100	B6C247	9070 720907	SERGEY ROMANOV	{"email": "romanov.sergey1976@postgrespro.ru", "phone": "+70782854945"}
0005433960101	AC013A	7544 850863	VLADIMIR ANDREEV	{"email": "vladimir-andreev.111962@postgrespro.ru", "phone": "+70842704764"}
0005433960102	AC013A	5895 037127	EVGENIY KRASNOV	{"email": "krasnove.23031967@postgrespro.ru", "phone": "+70133354748"}
0005433960103	9E2876	6738 042407	SERGEY OSIPOV	{"email": "sergey.osipov051972@postgrespro.ru", "phone": "+70287090531"}
0005433960104	D48625	2545 397123	OLEG POPOV	{"email": "oleg_popov1971@postgrespro.ru", "phone": "+70804607004"}
0005433960105	4BBFAF	8010 233342	EKATERINA BELYAEVA	{"phone": "+70557779113"}
0005433960106	4BBFAF	8623 087014	ALEKSEY SOKOLOV	{"email": "aleksey-sokolov1975@postgrespro.ru", "phone": "+70584784279"}
0005433960107	D1ADE0	7244 925770	OLGA ANTONOVA	{"phone": "+70767691469"}
0005433960108	D1ADE0	9001 363199	GALINA KUZMINA	{"email": "galina.kuzmina1982@postgrespro.ru", "phone": "+70859785130"}
0005433960109	6A19C5	4247 437460	VITALIY ALEKSANDROV	{"email": "aleksandrov-v_1963@postgrespro.ru", "phone": "+70229994540"}
0005433960110	6A19C5	1141 735855	MARINA SMIRNOVA	{"email": "marinasmirnova01121972@postgrespro.ru", "phone": "+70062368958"}
0005433960111	8F3FFA	6801 910511	ANFISA SOLOVEVA	{"email": "soloveva-anfisa-1969@postgrespro.ru", "phone": "+70084389996"}
0005433960112	6E20A1	2117 122907	LYUDMILA IVANOVA	{"phone": "+70006212561"}
0005433960113	6E20A1	3007 179848	VALENTINA MEDVEDEVA	{"phone": "+70096777742"}
0005433960114	BA169C	6805 506397	ANTONINA BOGDANOVA	{"email": "bogdanovaantonina-1959@postgrespro.ru", "phone": "+70491107237"}
0005433960115	BA169C	8650 220825	DMITRIY SEMENOV	{"phone": "+70548961831"}
0005433960116	3F901D	1602 044590	TATYANA DAVYDOVA	{"phone": "+70530745833"}
0005433960117	969708	7368 673095	VIKTOR ROMANOV	{"phone": "+70718194654"}
0005433960118	AF5C93	2387 965161	SHAMIL MARTYNOV	{"phone": "+70768920239"}
0005433960119	D9704E	7782 949205	ALEKSEY ANDREEV	{"phone": "+70748839358"}
0005433960120	FF7FE9	3742 788987	IVAN BONDARENKO	{"email": "ivan.bondarenko-1978@postgrespro.ru", "phone": "+70316703659"}
0005433960121	B739F2	1978 126418	TATYANA OSIPOVA	{"email": "t.osipova.1970@postgrespro.ru", "phone": "+70396506610"}
0005433960122	B739F2	8180 707714	ANDREY NAUMOV	{"email": "andreynaumov011969@postgrespro.ru", "phone": "+70399804643"}
0005433960123	B734EF	4849 353917	VLADISLAV ROMANOV	{"email": "vladislav_romanov-1969@postgrespro.ru", "phone": "+70012576611"}
0005433960124	EC9D0F	0503 580508	VITALIY KARPOV	{"phone": "+70766321162"}
0005433960125	13729E	9591 903851	OLGA TARASOVA	{"email": "olga-tarasova_1974@postgrespro.ru", "phone": "+70288060760"}
0005433960126	816F37	9968 169209	SERGEY SOROKIN	{"email": "sergey_sorokin-1971@postgrespro.ru", "phone": "+70412449224"}
0005433960127	816F37	0754 420946	VLADIMIR ABRAMOV	{"email": "vabramov.051977@postgrespro.ru", "phone": "+70460636567"}
0005433960128	EA4911	9576 678306	VASILISA MAKAROVA	{"email": "vmakarova1974@postgrespro.ru", "phone": "+70604874114"}
0005433960129	1B2FB5	4780 076017	SERGEY SEMENOV	{"email": "sergey_semenov.1969@postgrespro.ru", "phone": "+70459019040"}
0005433960130	1B2FB5	7598 123737	KIRILL ALEKSANDROV	{"email": "aleksandrovk18031969@postgrespro.ru", "phone": "+70210931832"}
0005433960131	E7973F	2555 152307	VLADIMIR KAZAKOV	{"phone": "+70672257863"}
0005433960132	8E88E8	0291 365203	SERGEY NOVIKOV	{"email": "s_novikov-1970@postgrespro.ru", "phone": "+70630765477"}
0005433960133	8E88E8	4206 447104	PETR PETROV	{"phone": "+70549294474"}
0005433960134	47892D	6790 167176	YAKOV GUSEV	{"email": "yakov.gusev071974@postgrespro.ru", "phone": "+70237416810"}
0005433960135	B09DEC	6062 151297	VLADISLAV VOROBEV	{"email": "vorobev.v-091986@postgrespro.ru", "phone": "+70454941872"}
0005433960136	B09DEC	4671 215165	VIKTORIYA FROLOVA	{"phone": "+70534395651"}
0005433960137	198826	0727 330967	SVETLANA BORISOVA	{"email": "sborisova1979@postgrespro.ru", "phone": "+70585622208"}
0005433960138	7A4ACF	0369 034274	MIKHAIL TIKHONOV	{"phone": "+70777186856"}
0005433960139	8B2334	9703 933571	ALEKSANDR GUSEV	{"phone": "+70233834439"}
0005433960140	7F0738	2381 017447	ALEKSANDRA GAVRILOVA	{"email": "a-gavrilova_11081963@postgrespro.ru", "phone": "+70084923423"}
0005433960141	7F0738	0280 810318	NADEZHDA SEMENOVA	{"phone": "+70028141087"}
0005433960142	9AC1A8	9804 429237	ALEKSANDRA IVANOVA	{"email": "a_ivanova011969@postgrespro.ru", "phone": "+70138043227"}
0005433960143	9AC1A8	2306 049830	VALENTINA LAZAREVA	{"phone": "+70592505282"}
0005433960144	1F101F	6303 899581	VYACHESLAV KAZAKOV	{"email": "v.kazakov_1985@postgrespro.ru", "phone": "+70924694390"}
0005433960145	1F101F	7184 107348	ARTUR IVANOV	{"email": "ivanov.a-091969@postgrespro.ru", "phone": "+70912455272"}
0005433960146	38F056	6753 553751	NATALYA VOLKOVA	{"email": "n.volkova-071979@postgrespro.ru", "phone": "+70954132681"}
0005433960147	38F056	4722 285706	ANASTASIYA KOROLEVA	{"phone": "+70441276096"}
0005433960148	7FF7C4	3844 768146	TATYANA SOKOLOVA	{"phone": "+70994266036"}
0005433960149	0153FD	7337 646213	NIKOLAY IVANOV	{"email": "n-ivanov17071969@postgrespro.ru", "phone": "+70519980795"}
0005433960150	062800	0105 894333	DANIL ZAKHAROV	{"email": "zakharov_d_1980@postgrespro.ru", "phone": "+70758147520"}
0005433960151	062800	4381 831006	EKATERINA MAKSIMOVA	{"phone": "+70090117082"}
0005433960152	062800	5907 368837	NIKOLAY SERGEEV	{"phone": "+70796346848"}
0005433960153	FBB9DF	9021 447303	NADEZHDA TITOVA	{"phone": "+70260465807"}
0005433960154	A8B7B1	5176 715850	NIKOLAY SOROKIN	{"email": "n-sorokin.111973@postgrespro.ru", "phone": "+70277525980"}
0005433960155	E9D6B6	9619 071080	VLADIMIR VASILEV	{"phone": "+70571828960"}
0005433960156	E54DF5	7898 544696	SERGEY KOZLOV	{"email": "kozlov_s-07031968@postgrespro.ru", "phone": "+70704365368"}
0005433960157	E54DF5	1397 247563	ELINA STEPANOVA	{"email": "estepanova.22061973@postgrespro.ru", "phone": "+70361969184"}
0005433960158	C0CB61	6718 327740	ALEKSANDR ZHURAVLEV	{"phone": "+70237897395"}
0005433960159	D60FF5	6290 555589	RADIK NIKITIN	{"email": "nikitin_r_07111971@postgrespro.ru", "phone": "+70881415459"}
0005433960160	D60FF5	0968 337290	MIKHAIL SMIRNOV	{"email": "msmirnov_061976@postgrespro.ru", "phone": "+70536805524"}
0005433960161	91A552	5641 302536	NINA GORBUNOVA	{"email": "gorbunova-nina10021965@postgrespro.ru", "phone": "+70673424535"}
0005433960162	91A552	7626 206107	VIKTOR YAKOVLEV	{"email": "viktor.yakovlev.26051978@postgrespro.ru", "phone": "+70526046159"}
0005433960163	7DC1DD	2857 927071	EVGENIY IVANOV	{"phone": "+70021015557"}
0005433960164	A30BAD	6769 216077	IGOR EGOROV	{"email": "iegorov.1973@postgrespro.ru", "phone": "+70371556218"}
0005433960165	3CB98D	7471 542692	SERGEY DENISOV	{"email": "sergey-denisov_061970@postgrespro.ru", "phone": "+70859359563"}
0005433960166	98C494	9106 485685	VALENTINA SMIRNOVA	{"email": "smirnova-v.1959@postgrespro.ru", "phone": "+70800991707"}
0005433960167	98C494	6959 838317	DMITRIY SEMENOV	{"email": "dmitriy-semenov.101980@postgrespro.ru", "phone": "+70094850996"}
0005433960168	552265	4119 629917	NATALYA POPOVA	{"email": "popova.natalya-18091973@postgrespro.ru", "phone": "+70316810645"}
0005433960169	552265	6611 604887	NATALYA MIRONOVA	{"phone": "+70038336300"}
0005433960170	51BFBA	9754 575221	ALEKSANDR GERASIMOV	{"email": "agerasimov_1965@postgrespro.ru", "phone": "+70641080992"}
0005433960171	358F09	8408 744611	NADEZHDA LOGINOVA	{"email": "n-loginova031976@postgrespro.ru", "phone": "+70547520906"}
0005433960172	428DAB	3999 755963	MAKSIM GORBUNOV	{"phone": "+70780051099"}
0005433960173	2EE641	3330 994676	SERGEY ILIN	{"email": "ilin-sergey-27071968@postgrespro.ru", "phone": "+70556150028"}
0005433960174	284ED7	9447 027947	VALENTINA DENISOVA	{"email": "v.denisova-121984@postgrespro.ru", "phone": "+70455726359"}
0005433960175	284ED7	0120 172457	ALEKSANDR FROLOV	{"email": "aleksandr-frolov.15061976@postgrespro.ru", "phone": "+70639960769"}
0005433960176	82A589	8483 605307	SERGEY FILIPPOV	{"email": "sfilippov-061970@postgrespro.ru", "phone": "+70143786632"}
0005433960177	82A589	8284 831245	VYACHESLAV MIRONOV	{"email": "vyacheslav.mironov091962@postgrespro.ru", "phone": "+70685335714"}
0005433960178	699424	5302 784330	IVAN MEDVEDEV	{"email": "medvedevivan-1974@postgrespro.ru", "phone": "+70935721453"}
0005433960179	699424	4046 985465	OLGA CHERNOVA	{"phone": "+70666768167"}
0005433960180	B43237	8740 544497	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey1964@postgrespro.ru", "phone": "+70978512305"}
0005433960181	CB8B9C	9804 313121	NIKOLAY VLASOV	{"email": "nvlasov.051967@postgrespro.ru", "phone": "+70737788943"}
0005433960182	AC57A6	6009 000848	GALINA SMIRNOVA	{"phone": "+70125818202"}
0005433960183	2DB0FB	7026 817794	SVETLANA MASLOVA	{"email": "s-maslova-121959@postgrespro.ru", "phone": "+70685343594"}
0005433960184	A7484C	0364 943229	NATALIYA GORBUNOVA	{"email": "gorbunova_n.041968@postgrespro.ru", "phone": "+70193462364"}
0005433960185	52D014	8149 538814	ANTON GUSEV	{"phone": "+70838507804"}
0005433960186	E40671	3141 065855	IRINA KUZNECOVA	{"phone": "+70929811986"}
0005433960187	E40671	7467 431892	NATALYA BARANOVA	{"email": "baranova_natalya.28031967@postgrespro.ru", "phone": "+70953959276"}
0005433960188	8F370B	4451 716302	SERGEY YAKOVLEV	{"email": "s_yakovlev_101981@postgrespro.ru", "phone": "+70249180355"}
0005433960189	71F086	6242 913356	ILYA GRIGOREV	{"phone": "+70161570077"}
0005433960190	3E1CBD	1224 464891	EKATERINA ZHURAVLEVA	{"email": "e-zhuravleva1958@postgrespro.ru", "phone": "+70885123171"}
0005433960191	397C3C	5480 737884	NADEZHDA AKIMOVA	{"email": "nadezhdaakimova.051967@postgrespro.ru", "phone": "+70771432147"}
0005433960192	397C3C	1760 363510	OKSANA STEPANOVA	{"email": "stepanovao_1988@postgrespro.ru", "phone": "+70241260719"}
0005433960193	45C7D4	2026 936222	NATALYA MASLOVA	{"email": "natalya.maslova.1958@postgrespro.ru", "phone": "+70385792487"}
0005433960194	D9E381	5004 118653	NAILYA KONOVALOVA	{"email": "nailya-konovalova-061973@postgrespro.ru", "phone": "+70942850507"}
0005433960195	5F5E21	5172 305329	VALENTINA KUZNECOVA	{"phone": "+70101411116"}
0005433960196	873F82	1394 401181	ALEKSANDR ORLOV	{"email": "orlovaleksandr1965@postgrespro.ru", "phone": "+70021821068"}
0005433960197	7E74EE	8474 460594	VERA AKIMOVA	{"email": "akimovavera_30071971@postgrespro.ru", "phone": "+70523353884"}
0005433960198	5C0539	9412 103188	YURIY SEMENOV	{"phone": "+70965148445"}
0005433960199	811E56	4808 327462	SERGEY FOMIN	{"phone": "+70232006229"}
0005433960200	8DCA31	2294 973952	DARYA KOLESNIKOVA	{"email": "kolesnikovad_1972@postgrespro.ru", "phone": "+70169976913"}
0005433960201	8DCA31	1610 037585	VIKTOR VASILEV	{"phone": "+70433279379"}
0005433960202	099E6E	7729 246294	OLGA SOKOLOVA	{"phone": "+70066469117"}
0005433960203	099E6E	0956 030206	EKATERINA SCHERBAKOVA	{"email": "ekaterinascherbakova-091974@postgrespro.ru", "phone": "+70225696259"}
0005433960204	BCA37C	5426 721520	SVETLANA DAVYDOVA	{"phone": "+70072824852"}
0005433960205	D4DE81	5046 833145	BULAT OSIPOV	{"email": "bulat.osipov-041981@postgrespro.ru", "phone": "+70805815444"}
0005433960263	7693BE	4434 322061	SERGEY MARTYNOV	{"phone": "+70231709016"}
0005433960206	D4DE81	3320 529746	ANDREY KONOVALOV	{"email": "a_konovalov_071972@postgrespro.ru", "phone": "+70240424215"}
0005433960207	D4DE81	7914 648432	PETR KISELEV	{"phone": "+70149525317"}
0005433960208	0AE58F	1672 269945	ALEKSANDR MEDVEDEV	{"email": "medvedev.a_11031976@postgrespro.ru", "phone": "+70703779559"}
0005433960209	106EF0	6847 944064	ALEKSANDR SOKOLOV	{"phone": "+70205125276"}
0005433960210	106EF0	7708 958583	ALEKSEY ANDREEV	{"phone": "+70402231286"}
0005433960211	64D938	2733 499836	VIKTOR SIDOROV	{"email": "viktor.sidorov.1977@postgrespro.ru", "phone": "+70454804564"}
0005433960212	9379A8	8802 138112	SERGEY ZHUKOV	{"email": "s_zhukov-20091967@postgrespro.ru", "phone": "+70170594467"}
0005433960213	9379A8	7703 824213	NATALYA ROMANOVA	{"phone": "+70698228737"}
0005433960214	A3CC84	8237 258943	MARIYA ILINA	{"phone": "+70477462794"}
0005433960215	2907F3	3804 677480	SERGEY ROMANOV	{"email": "sergey_romanov_21011972@postgrespro.ru", "phone": "+70886182198"}
0005433960216	2907F3	9942 697220	ANATOLIY ZAKHAROV	{"phone": "+70387257339"}
0005433960217	6EDF27	8743 292853	ALEKSANDRA KRASNOVA	{"phone": "+70652018307"}
0005433960218	DE2D16	8230 076330	SERGEY VASILEV	{"email": "vasilev.sergey.1961@postgrespro.ru", "phone": "+70149513484"}
0005433960219	120DE2	3948 191636	LEONID AFANASEV	{"email": "l.afanasev.1974@postgrespro.ru", "phone": "+70125361837"}
0005433960220	120DE2	9388 983579	IRINA IVANOVA	{"email": "ivanova_irina_101973@postgrespro.ru", "phone": "+70168036944"}
0005433960221	C4F881	1955 825219	NADEZHDA SERGEEVA	{"phone": "+70435715879"}
0005433960222	C4F881	6842 504899	VALENTINA ERMAKOVA	{"phone": "+70510501418"}
0005433960223	766DE7	1172 438954	LYUBOV MIKHAYLOVA	{"email": "mikhaylova.lyubov_1977@postgrespro.ru", "phone": "+70749388959"}
0005433960224	63539E	5474 924124	VALERIY ALEKSEEV	{"email": "alekseevvaleriy25111982@postgrespro.ru", "phone": "+70569742112"}
0005433960225	E17068	0554 153860	ELIZAVETA POLYAKOVA	{"email": "e.polyakova.1962@postgrespro.ru", "phone": "+70039174969"}
0005433960226	34347E	6228 811908	ALEKSANDR STEPANOV	{"phone": "+70265593149"}
0005433960227	6B80EB	3974 261463	DANIIL STEPANOV	{"phone": "+70870793218"}
0005433960228	8D9D02	2910 531314	LYUDMILA ILINA	{"email": "lyudmila_ilina1978@postgrespro.ru", "phone": "+70522105436"}
0005433960229	8D9D02	6634 584867	NADEZHDA ISAEVA	{"email": "n_isaeva.09091976@postgrespro.ru", "phone": "+70657748334"}
0005433960230	04B965	0038 758597	YULIYA KOZLOVA	{"phone": "+70468976109"}
0005433960231	04B965	8955 843434	ROZA KRASNOVA	{"email": "r.krasnova1968@postgrespro.ru", "phone": "+70668685646"}
0005433960232	04B965	0800 277689	ALEKSANDR VASILEV	{"email": "vasilev_a091971@postgrespro.ru", "phone": "+70261229212"}
0005433960233	3D3F4B	6895 065060	SERGEY ZAKHAROV	{"phone": "+70165402132"}
0005433960234	F29223	9494 072414	TATYANA KALININA	{"email": "kalinina-t06031972@postgrespro.ru", "phone": "+70215196978"}
0005433960235	F29223	1800 280379	IRINA MIRONOVA	{"email": "irina_mironova-111973@postgrespro.ru", "phone": "+70212010818"}
0005433960236	3ADC51	3055 027004	ALEKSANDR GRIGOREV	{"phone": "+70877484802"}
0005433960237	890177	6252 966815	SERGEY KUZNECOV	{"phone": "+70926264982"}
0005433960238	2AB8B2	9786 544941	VERA DMITRIEVA	{"email": "veradmitrieva.1983@postgrespro.ru", "phone": "+70074707613"}
0005433960239	2AB8B2	3210 127679	EVGENIY ABRAMOV	{"phone": "+70514182081"}
0005433960240	173E71	1976 659440	ALEKSANDR MARTYNOV	{"email": "a-martynov_08041963@postgrespro.ru", "phone": "+70170179602"}
0005433960241	5F63E0	8113 935505	ANNA CHERNOVA	{"phone": "+70227478480"}
0005433960242	5F63E0	6270 850116	ANATOLIY ROMANOV	{"phone": "+70966776638"}
0005433960243	FF3F6E	4131 696074	SERGEY SMIRNOV	{"phone": "+70915004308"}
0005433960244	A661DB	4593 724060	TATYANA KUZMINA	{"email": "tatyana.kuzmina.041968@postgrespro.ru", "phone": "+70911885703"}
0005433960245	5A97EB	2976 059835	VLADIMIR GUSEV	{"email": "gusev.v.1964@postgrespro.ru", "phone": "+70464226080"}
0005433960246	2C7594	7904 685606	LARISA LOGINOVA	{"email": "loginoval1972@postgrespro.ru", "phone": "+70883550119"}
0005433960247	0DDC17	2291 265462	TAMARA SCHERBAKOVA	{"email": "scherbakovat-1961@postgrespro.ru", "phone": "+70295482204"}
0005433960248	0DDC17	3309 212843	GALINA IVANOVA	{"phone": "+70424988659"}
0005433960249	F47337	0933 080985	LYUBOV LUKYANOVA	{"phone": "+70842060998"}
0005433960250	8BE004	5734 565218	LYUDMILA MIKHAYLOVA	{"phone": "+70351940005"}
0005433960251	4C541B	1402 948336	VLADIMIR STEPANOV	{"phone": "+70611801794"}
0005433960252	C4641B	7583 089681	ANATOLIY NOVIKOV	{"phone": "+70992460156"}
0005433960253	C4641B	2015 915997	PAVEL NAUMOV	{"phone": "+70346407418"}
0005433960254	C4641B	2293 011927	VALENTINA YUDINA	{"phone": "+70873570881"}
0005433960255	54F9E8	9818 825062	YURIY ANDREEV	{"phone": "+70064749471"}
0005433960256	54F9E8	0052 207692	TAGIR MIRONOV	{"phone": "+70003534856"}
0005433960257	2DFB3C	4025 839385	MIKHAIL MOISEEV	{"phone": "+70613132151"}
0005433960258	7AF06A	4153 379537	GENNADIY KUZNECOV	{"email": "kuznecovg.05091975@postgrespro.ru", "phone": "+70392890169"}
0005433960259	9A8010	2113 543759	LIDIYA ANDREEVA	{"email": "andreeva_l1965@postgrespro.ru", "phone": "+70498831864"}
0005433960260	9A8010	2886 279715	ALEKSEY POPOV	{"email": "popovaleksey1971@postgrespro.ru", "phone": "+70161501284"}
0005433960261	54C8BC	9364 928695	NADEZHDA FADEEVA	{"email": "fadeevanadezhda-1985@postgrespro.ru", "phone": "+70277606817"}
0005433960262	7693BE	2994 741576	LYUDMILA NOVIKOVA	{"phone": "+70716788085"}
0005433960264	9E2DFC	0636 150284	VALENTINA BORISOVA	{"phone": "+70170489517"}
0005433960265	746134	8619 510134	MARINA POLYAKOVA	{"email": "m-polyakova01051975@postgrespro.ru", "phone": "+70736317848"}
0005433960266	A6A1C9	6734 401584	ILYA ANTONOV	{"email": "ilya_antonov_1964@postgrespro.ru", "phone": "+70024038119"}
0005433960267	1F9C7E	1171 114396	VALENTINA DAVYDOVA	{"phone": "+70254975267"}
0005433960268	661B06	4747 664234	TATYANA ISAEVA	{"phone": "+70245697978"}
0005433960269	661B06	1613 311067	ARSENIY VOLKOV	{"email": "volkov_a.21061973@postgrespro.ru", "phone": "+70572534428"}
0005433960270	629ECE	2134 265212	GENNADIY KUZMIN	{"email": "kuzmin.g101981@postgrespro.ru", "phone": "+70107954019"}
0005433960271	629ECE	1368 395502	ALEKSANDR PETROV	{"email": "petrov.a-051978@postgrespro.ru", "phone": "+70235289325"}
0005433960272	EF71F8	1631 814177	LILIYA PETROVA	{"phone": "+70033347004"}
0005433960273	400B60	0661 511790	SERGEY BONDARENKO	{"email": "bondarenko_sergey_1982@postgrespro.ru", "phone": "+70623727275"}
0005433960274	400B60	4862 797340	GENNADIY MOROZOV	{"email": "g.morozov18091980@postgrespro.ru", "phone": "+70566485056"}
0005433960275	BC68F4	5029 063132	TATYANA PAVLOVA	{"email": "pavlova-tatyana_18051977@postgrespro.ru", "phone": "+70065879001"}
0005433960276	221C24	8560 617787	ANASTASIYA MATVEEVA	{"phone": "+70975200875"}
0005433960277	58C2FF	3470 358691	ZINAIDA KOROLEVA	{"email": "koroleva.z_15011973@postgrespro.ru", "phone": "+70506158157"}
0005433960278	B3879D	0622 387659	VIKTOR VLASOV	{"phone": "+70241582291"}
0005433960279	B3879D	4079 703583	LARISA IVANOVA	{"phone": "+70543079032"}
0005433960280	7B4D85	4283 501928	MARGARITA MELNIKOVA	{"phone": "+70760440994"}
0005433960281	8B23F0	6876 900851	IVAN ZAYCEV	{"phone": "+70836658879"}
0005433960282	CB3871	6006 276677	ANASTASIYA PETROVA	{"phone": "+70808047167"}
0005433960283	4BE70C	6265 722110	VALERIY ZHURAVLEV	{"phone": "+70728036575"}
0005433960284	AD513D	1627 480522	VLADISLAV KONOVALOV	{"email": "konovalov-v-011965@postgrespro.ru", "phone": "+70428606328"}
0005433960285	745DF1	3792 341143	TATYANA TITOVA	{"phone": "+70667839442"}
0005433960286	23A54C	2065 060388	VADIM KOZLOV	{"email": "vkozlov07031976@postgrespro.ru", "phone": "+70297740221"}
0005433960287	1E3A27	7393 256467	ANATOLIY IVANOV	{"email": "ivanov-anatoliy_021977@postgrespro.ru", "phone": "+70157818950"}
0005433960288	5613D8	5440 313967	IRINA ANDREEVA	{"email": "irina-andreeva-111968@postgrespro.ru", "phone": "+70109626412"}
0005433960289	CC65F8	4175 217775	MARINA FEDOROVA	{"email": "m.fedorova10051975@postgrespro.ru", "phone": "+70475011602"}
0005433960290	779857	0422 063275	VASILIY ALEKSANDROV	{"email": "valeksandrov011973@postgrespro.ru", "phone": "+70513733140"}
0005433960291	DF17EC	8981 134673	LYUBOV KULIKOVA	{"phone": "+70718408470"}
0005433960292	357562	4416 891694	MARINA ERMAKOVA	{"email": "ermakova-m_22011990@postgrespro.ru", "phone": "+70142768797"}
0005433960293	BFFD03	2586 962869	ARINA MOISEEVA	{"email": "amoiseeva.1963@postgrespro.ru", "phone": "+70889563266"}
0005433960294	1FAD83	8212 591078	DARYA DENISOVA	{"phone": "+70143934205"}
0005433960295	1FAD83	3048 198815	PAVEL SMIRNOV	{"phone": "+70178835567"}
0005433960296	2E7B1C	7231 391413	VLADIMIR SOLOVEV	{"email": "solovevv_1974@postgrespro.ru", "phone": "+70234236422"}
0005433960297	5557AC	5147 235258	LYUDMILA KULIKOVA	{"phone": "+70539162124"}
0005433960298	5557AC	6846 949549	EKATERINA SOKOLOVA	{"phone": "+70030050282"}
0005433960299	521B8A	1824 360729	NINA CHERNOVA	{"phone": "+70179887136"}
0005433960300	521B8A	5601 378795	VERA MIKHAYLOVA	{"email": "mikhaylova.v.051971@postgrespro.ru", "phone": "+70868363415"}
0005433960301	1E7701	0038 039920	VALENTINA EGOROVA	{"phone": "+70844940226"}
0005433960302	1E7701	6664 046010	VLADIMIR ROMANOV	{"email": "romanov-v.10081967@postgrespro.ru", "phone": "+70588020659"}
0005433960303	22D893	3363 993403	YURIY BELOV	{"email": "belovyuriy13091968@postgrespro.ru", "phone": "+70925658158"}
0005433960304	4B981B	3003 331592	SVETLANA ANTONOVA	{"email": "svetlana_antonova_1960@postgrespro.ru", "phone": "+70662889462"}
0005433960305	6E0E88	3924 939117	YULIYA EGOROVA	{"phone": "+70603157015"}
0005433960306	181C55	0000 112600	LYUDMILA ALEKSANDROVA	{"email": "l.aleksandrova_1968@postgrespro.ru", "phone": "+70023214361"}
0005433960307	181C55	8757 403109	ALEKSANDR ZAYCEV	{"phone": "+70264290775"}
0005433960308	77F11C	0429 591880	ALLA KUZNECOVA	{"email": "kuznecova_alla_21051965@postgrespro.ru", "phone": "+70448191304"}
0005433960309	77F11C	7990 365041	RADIK NIKITIN	{"email": "nikitin.radik1977@postgrespro.ru", "phone": "+70616822843"}
0005433960310	04E869	8243 025728	TATYANA EFREMOVA	{"email": "efremova_tatyana-061961@postgrespro.ru", "phone": "+70984112081"}
0005433960311	04E869	8269 893917	LEV BELOV	{"email": "belov_lev-061963@postgrespro.ru", "phone": "+70318349764"}
0005433960312	0C4F41	5337 107564	PAVEL SOROKIN	{"email": "sorokin.pavel1969@postgrespro.ru", "phone": "+70101155008"}
0005433960313	0C4F41	8024 205330	IVAN IVANOV	{"email": "ivanov.ivan-041972@postgrespro.ru", "phone": "+70377469858"}
0005433960314	8643E7	0381 715612	ALEKSANDR KUZNECOV	{"email": "a.kuznecov03111964@postgrespro.ru", "phone": "+70180673160"}
0005433960315	8643E7	5154 776681	ELENA ANDREEVA	{"email": "eandreeva_14011971@postgrespro.ru", "phone": "+70972629367"}
0005433960316	51B90B	4279 071811	ALEKSEY VASILEV	{"phone": "+70170318991"}
0005433960317	60CC9B	1872 195562	VIKTOR KUZNECOV	{"phone": "+70684839470"}
0005433960318	63CBF0	0167 822759	NATALYA YUDINA	{"email": "n.yudina.1971@postgrespro.ru", "phone": "+70090625961"}
0005433960319	63CBF0	4375 152361	VALENTINA POPOVA	{"phone": "+70226705298"}
0005433960320	E7F928	7798 947678	ROMAN IVANOV	{"email": "rivanov_1968@postgrespro.ru", "phone": "+70891893558"}
0005433960321	E7F928	4261 160205	ALEKSEY KUDRYASHOV	{"email": "kudryashov_a_111980@postgrespro.ru", "phone": "+70979188200"}
0005433960322	E441CD	0845 655242	ARTEM PETROV	{"phone": "+70871432010"}
0005433960323	E441CD	3589 822094	EKATERINA KOROLEVA	{"email": "ekoroleva-29071979@postgrespro.ru", "phone": "+70960648042"}
0005433960324	E441CD	6448 763349	VALENTINA POPOVA	{"email": "popova-v20071984@postgrespro.ru", "phone": "+70884420191"}
0005433960325	1FC52F	5470 505095	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov_101979@postgrespro.ru", "phone": "+70149431204"}
0005433960326	9B9293	6427 368860	SERGEY GERASIMOV	{"email": "sergey_gerasimov-1971@postgrespro.ru", "phone": "+70727391072"}
0005433960327	E6A53B	0010 560558	VITALIY SCHERBAKOV	{"email": "scherbakovvitaliy-31101974@postgrespro.ru", "phone": "+70013729001"}
0005433960328	8D2110	4340 269929	EVGENIYA ROMANOVA	{"email": "romanovaevgeniya_1970@postgrespro.ru", "phone": "+70629112737"}
0005433960329	8D2110	1123 900289	DENIS ANDREEV	{"email": "d.andreev15071977@postgrespro.ru", "phone": "+70892673800"}
0005433960330	90954C	0260 507646	ANNA SMIRNOVA	{"email": "anna-smirnova-25031977@postgrespro.ru", "phone": "+70229599182"}
0005433960331	D2034C	0269 768485	VITALIY ZHURAVLEV	{"phone": "+70943387018"}
0005433960332	D2034C	3341 508044	SVETLANA MOISEEVA	{"email": "smoiseeva.26081968@postgrespro.ru", "phone": "+70195163365"}
0005433960333	133877	9729 924443	LYUBOV KALININA	{"phone": "+70584822421"}
0005433960334	3F15FB	5082 404329	OKSANA GAVRILOVA	{"email": "gavrilovao-101970@postgrespro.ru", "phone": "+70884489799"}
0005433960335	3F15FB	2160 326513	GENNADIY MAKAROV	{"phone": "+70295792678"}
0005433960336	D92848	2847 659389	VIKTORIYA LOGINOVA	{"phone": "+70344100646"}
0005433960337	E8F67E	9356 597587	VIKTOR FOMIN	{"email": "v.fomin1970@postgrespro.ru", "phone": "+70143902734"}
0005433960338	E8F67E	7856 998362	ROMAN CHERNOV	{"phone": "+70908871776"}
0005433960339	04AA5F	3617 352184	NATALYA ZAKHAROVA	{"phone": "+70165051634"}
0005433960340	EF8149	0840 361104	ALINA DANILOVA	{"phone": "+70192444694"}
0005433960341	EF8149	0122 387948	VALENTINA KOMAROVA	{"email": "komarova_valentina-101962@postgrespro.ru", "phone": "+70295157314"}
0005433960342	96180E	1627 106369	IRINA VASILEVA	{"phone": "+70854121467"}
0005433960343	0C2EC6	7689 412131	YURIY BORISOV	{"email": "y.borisov-17091969@postgrespro.ru", "phone": "+70007091494"}
0005433960344	968926	0258 882092	VLADIMIR SOROKIN	{"email": "vladimirsorokin1973@postgrespro.ru", "phone": "+70680490829"}
0005433960345	968926	5779 013309	ANDREY MAKAROV	{"phone": "+70053617599"}
0005433960346	3B0CB2	1102 834627	IRINA ARKHIPOVA	{"email": "arkhipovai24031968@postgrespro.ru", "phone": "+70803388920"}
0005433960347	3B0CB2	5213 772676	TATYANA ARKHIPOVA	{"email": "arkhipovat08121960@postgrespro.ru", "phone": "+70157568741"}
0005433960348	80A931	6395 326312	NATALIYA GERASIMOVA	{"phone": "+70219688830"}
0005433960349	7AF4EF	6931 581157	SERGEY BARANOV	{"email": "sergey_baranov.061974@postgrespro.ru", "phone": "+70336192774"}
0005433960350	7AF4EF	3397 224919	MARINA KISELEVA	{"phone": "+70585536595"}
0005433960351	35AF8C	5596 335647	ANNA SEMENOVA	{"email": "a-semenova_091969@postgrespro.ru", "phone": "+70600893280"}
0005433960352	35AF8C	4924 326271	DARYA SAVELEVA	{"phone": "+70241353831"}
0005433960353	31C1B0	8425 638873	RAISA SMIRNOVA	{"phone": "+70077953883"}
0005433960354	DAE7E0	1245 519551	IGOR IVANOV	{"phone": "+70157538726"}
0005433960355	980224	6120 243234	LYUDMILA OSIPOVA	{"phone": "+70758116749"}
0005433960356	12B73C	4076 963868	ANZHELIKA ALEKSEEVA	{"phone": "+70121260102"}
0005433960357	87E592	2989 342049	ANNA DENISOVA	{"email": "denisova-anna061965@postgrespro.ru", "phone": "+70216680936"}
0005433960358	DF8D83	5048 785676	EKATERINA FADEEVA	{"email": "efadeeva.061969@postgrespro.ru", "phone": "+70412710114"}
0005433960359	DF8D83	2440 933711	NADEZHDA CHERNOVA	{"email": "chernova_n-03111970@postgrespro.ru", "phone": "+70636651967"}
0005433960360	2A0508	4950 153465	NIKOLAY AFANASEV	{"phone": "+70640696135"}
0005433960361	2A0508	8584 722800	DENIS EGOROV	{"phone": "+70634655368"}
0005433960472	52FA73	1532 561177	ANASTASIYA BORISOVA	{"phone": "+70745598337"}
0005433960362	F01FEA	9162 489980	NIKOLAY GORBUNOV	{"email": "gorbunov_nikolay08121974@postgrespro.ru", "phone": "+70581102101"}
0005433960363	EC25D0	2684 201482	ANATOLIY IVANOV	{"email": "a_ivanov29051971@postgrespro.ru", "phone": "+70432093295"}
0005433960364	53EA2B	1451 122492	IVAN TIMOFEEV	{"email": "timofeevi101971@postgrespro.ru", "phone": "+70200089009"}
0005433960365	26CB96	2802 063515	MIKHAIL KARPOV	{"phone": "+70798986456"}
0005433960366	B3FDE2	4056 407078	NIKOLAY MOISEEV	{"email": "moiseev_n-24011976@postgrespro.ru", "phone": "+70495229280"}
0005433960367	D91253	1297 242064	NATALYA FILIPPOVA	{"phone": "+70446906682"}
0005433960368	D91253	2277 083595	EKATERINA ANISIMOVA	{"email": "eanisimova-011975@postgrespro.ru", "phone": "+70142273677"}
0005433960369	C79487	3911 824394	OLEG MOROZOV	{"phone": "+70337836059"}
0005433960370	1A5752	5485 488280	TATYANA TARASOVA	{"email": "t_tarasova15081980@postgrespro.ru", "phone": "+70431767593"}
0005433960371	C284D7	9598 875364	ANTONINA ZAKHAROVA	{"phone": "+70275934353"}
0005433960372	C284D7	3010 594883	SEMEN TIMOFEEV	{"phone": "+70309064977"}
0005433960373	786437	1598 602143	LYUBOV NAZAROVA	{"phone": "+70710103152"}
0005433960374	786437	3316 128064	SERGEY BELOV	{"email": "sergey_belov13051975@postgrespro.ru", "phone": "+70208375976"}
0005433960375	73DEDA	7344 942970	VERA KOVALEVA	{"email": "kovalevav051969@postgrespro.ru", "phone": "+70054520459"}
0005433960376	8B1B29	9064 772965	VYACHESLAV KARPOV	{"phone": "+70208366824"}
0005433960377	8B1B29	0174 008701	NATALYA SOKOLOVA	{"phone": "+70965512069"}
0005433960378	8B1B29	9915 137805	ELENA EFREMOVA	{"phone": "+70620112631"}
0005433960379	4094DC	2382 671725	EVGENIY OSIPOV	{"email": "osipov_e-02121974@postgrespro.ru", "phone": "+70767589216"}
0005433960380	95F4FF	9610 190133	ANASTASIYA PETROVA	{"email": "petrovaa.051971@postgrespro.ru", "phone": "+70895476342"}
0005433960381	05FC94	1250 699670	ELENA KISELEVA	{"phone": "+70466518157"}
0005433960382	5A8BEB	1577 593277	NADEZHDA ZHUKOVA	{"phone": "+70548155260"}
0005433960383	5A8BEB	9436 452358	ILYA IVANOV	{"email": "ilyaivanov-30031976@postgrespro.ru", "phone": "+70496359190"}
0005433960384	29218A	3400 288381	ALEKSEY POPOV	{"phone": "+70017327084"}
0005433960385	29218A	5157 034039	VALERIY SOROKIN	{"phone": "+70351299958"}
0005433960386	9F9F03	4949 503112	MIKHAIL IVANOV	{"email": "mikhail_ivanov-071958@postgrespro.ru", "phone": "+70782000464"}
0005433960387	A231EC	8949 436553	NATALYA ILINA	{"email": "nilina111960@postgrespro.ru", "phone": "+70569714950"}
0005433960388	81D662	0538 834577	VALENTINA PAVLOVA	{"phone": "+70335397224"}
0005433960389	9F5317	6056 768260	ALEKSANDR NAZAROV	{"email": "a-nazarov_31071967@postgrespro.ru", "phone": "+70474239005"}
0005433960390	09BAFB	5675 520498	YULIYA NIKOLAEVA	{"phone": "+70667493216"}
0005433960391	0FA2FC	5377 323025	VITALIY SCHERBAKOV	{"email": "vscherbakov-1964@postgrespro.ru", "phone": "+70896718469"}
0005433960392	630B3D	3745 163821	GALINA IVANOVA	{"email": "galinaivanova_1972@postgrespro.ru", "phone": "+70348824954"}
0005433960393	630B3D	0348 589892	ANDREY MIRONOV	{"email": "mironov_a.021978@postgrespro.ru", "phone": "+70054943518"}
0005433960394	D3C5D9	4347 311528	YURIY NOVIKOV	{"phone": "+70938288880"}
0005433960395	D3C5D9	2929 147499	ANDREY MOROZOV	{"phone": "+70785516374"}
0005433960396	F6FE2E	1390 628270	MARIYA MIRONOVA	{"email": "mariya.mironova031980@postgrespro.ru", "phone": "+70089849766"}
0005433960397	FB8A5B	7286 787465	ALEKSANDRA KOLESNIKOVA	{"phone": "+70089152454"}
0005433960398	1A2483	4724 524318	SERGEY MAKAROV	{"email": "s_makarov-07061963@postgrespro.ru", "phone": "+70020777573"}
0005433960399	0B9263	1077 433587	ELENA STEPANOVA	{"phone": "+70397306756"}
0005433960400	7DCCFE	1664 258978	GALINA MEDVEDEVA	{"email": "galina.medvedeva_1971@postgrespro.ru", "phone": "+70394599429"}
0005433960401	EF12C6	4848 668946	ANATOLIY MIKHAYLOV	{"email": "anatoliy.mikhaylov.061968@postgrespro.ru", "phone": "+70007511812"}
0005433960402	EBFB8E	1989 501150	ANASTASIYA MOROZOVA	{"email": "a.morozova18111968@postgrespro.ru", "phone": "+70338076346"}
0005433960403	3BF7FC	5364 434782	NATALYA KOZLOVA	{"email": "natalyakozlova-1968@postgrespro.ru", "phone": "+70947757442"}
0005433960404	12006E	5972 927978	IGOR EGOROV	{"email": "igor-egorov.03061965@postgrespro.ru", "phone": "+70726586174"}
0005433960405	5B0AAB	9974 020123	IVAN AFANASEV	{"email": "afanasevi-081980@postgrespro.ru", "phone": "+70483758844"}
0005433960406	62E8C4	9176 732858	LIDIYA ALEKSANDROVA	{"email": "aleksandrova.l-16031960@postgrespro.ru", "phone": "+70130435965"}
0005433960407	489689	1092 656992	ANNA BELYAEVA	{"email": "belyaeva.a121965@postgrespro.ru", "phone": "+70845267287"}
0005433960408	7629E0	8214 398576	NATALYA MOROZOVA	{"phone": "+70007724065"}
0005433960409	A7B88A	0940 961968	OLGA MELNIKOVA	{"phone": "+70873188704"}
0005433960410	77409D	6731 382815	ANDREY PETROV	{"phone": "+70942220373"}
0005433960411	978855	7132 181616	GEORGIY KUZNECOV	{"email": "georgiykuznecov-26061971@postgrespro.ru", "phone": "+70360774203"}
0005433960412	8E5DE8	2472 140265	YULIYA NESTEROVA	{"phone": "+70310126950"}
0005433960413	8487A7	6033 229931	SERGEY BELOV	{"email": "sergeybelov.04061984@postgrespro.ru", "phone": "+70616127099"}
0005433960414	D3EADA	8864 744159	ALEKSANDR SMIRNOV	{"phone": "+70592728546"}
0005433960415	D3EADA	2829 104184	VYACHESLAV GERASIMOV	{"email": "gerasimovvyacheslav_20021966@postgrespro.ru", "phone": "+70274425996"}
0005433960416	BFE8CD	4824 067036	IGOR MEDVEDEV	{"email": "igor-medvedev-11071972@postgrespro.ru", "phone": "+70305571074"}
0005433960417	BFE8CD	8558 950163	POLINA KAZAKOVA	{"email": "kazakova.p.1972@postgrespro.ru", "phone": "+70664270169"}
0005433960418	9763B7	3883 573225	ALEKSEY ZAKHAROV	{"email": "zakharov.aleksey31101976@postgrespro.ru", "phone": "+70090451481"}
0005433960419	9763B7	2550 300320	TAMARA GERASIMOVA	{"email": "gerasimovat-13061973@postgrespro.ru", "phone": "+70761422240"}
0005433960420	5F91B9	8688 329029	ANNA KUZNECOVA	{"phone": "+70606396117"}
0005433960421	7E9E3C	2577 525677	VLADIMIR IVANOV	{"email": "ivanov_vladimir_14061977@postgrespro.ru", "phone": "+70221311103"}
0005433960422	D99855	1463 966095	SVETLANA TARASOVA	{"email": "svetlana-tarasova_09081985@postgrespro.ru", "phone": "+70092951244"}
0005433960423	F3DDE3	6667 581087	TATYANA MAKAROVA	{"phone": "+70383517040"}
0005433960424	F3DDE3	4890 314386	MIKHAIL EGOROV	{"email": "mikhail.egorov.051976@postgrespro.ru", "phone": "+70805958292"}
0005433960425	A28F5A	7765 403175	LYUDMILA EGOROVA	{"phone": "+70510488623"}
0005433960426	0D82AE	5973 170023	KLAVDIYA DMITRIEVA	{"email": "dmitrieva-k_1963@postgrespro.ru", "phone": "+70349852389"}
0005433960427	97ABD8	2047 926843	VALERIY KARPOV	{"email": "karpovv11111969@postgrespro.ru", "phone": "+70775997241"}
0005433960428	97ABD8	1687 478895	YULIYA IVANOVA	{"email": "yuliya.ivanova1969@postgrespro.ru", "phone": "+70049833484"}
0005433960429	CD9CC7	8881 376597	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov1964@postgrespro.ru", "phone": "+70202011149"}
0005433960430	223A30	4657 064840	VENIAMIN CHERNOV	{"phone": "+70890794389"}
0005433960431	223A30	8409 902183	YANA MIKHAYLOVA	{"email": "yana.mikhaylova.081969@postgrespro.ru", "phone": "+70290207526"}
0005433960432	5BBFF8	4902 780716	LIDIYA FILIPPOVA	{"phone": "+70292184223"}
0005433960433	620BBB	1861 040329	KLAVDIYA BELYAEVA	{"email": "klavdiya_belyaeva-051971@postgrespro.ru", "phone": "+70391934031"}
0005433960434	620BBB	3771 598461	TATYANA MAKAROVA	{"email": "makarova_tatyana_041969@postgrespro.ru", "phone": "+70390676155"}
0005433960435	620BBB	2159 197985	ALEKSANDR FEDOTOV	{"phone": "+70012915580"}
0005433960497	57A7D1	1718 606937	ANNA EGOROVA	{"phone": "+70668912176"}
0005433960436	2C720A	0711 270858	SOFYA FEDOROVA	{"email": "sofya-fedorova.051972@postgrespro.ru", "phone": "+70895917927"}
0005433960437	2C720A	3932 764092	GALINA ANTONOVA	{"email": "gantonova051961@postgrespro.ru", "phone": "+70843637110"}
0005433960438	0FB3D2	0185 078822	ZOYA GORBUNOVA	{"phone": "+70009981549"}
0005433960439	BD7EE7	5544 365045	ARTEM TARASOV	{"phone": "+70202782308"}
0005433960440	5E1228	4937 719089	EVGENIY MAKAROV	{"phone": "+70741049214"}
0005433960441	204E5D	2980 114200	EVGENIYA KOROLEVA	{"email": "e-koroleva.1988@postgrespro.ru", "phone": "+70872255268"}
0005433960442	47E202	7850 250359	NIKOLAY SOLOVEV	{"phone": "+70145219381"}
0005433960443	4D1E0F	4303 373134	DMITRIY FILIPPOV	{"phone": "+70097076519"}
0005433960444	B8C227	7506 884036	SOFYA KOROLEVA	{"phone": "+70725902404"}
0005433960445	B8C227	2793 351241	NIKOLAY SEMENOV	{"email": "nikolay-semenov_1969@postgrespro.ru", "phone": "+70568055766"}
0005433960446	2D7DA0	8557 174781	ALEVTINA ALEKSEEVA	{"email": "alekseeva.a13011978@postgrespro.ru", "phone": "+70058592603"}
0005433960447	2D7DA0	4387 549706	DMITRIY BARANOV	{"email": "baranov-d_061965@postgrespro.ru", "phone": "+70499167848"}
0005433960448	C9BC70	1486 361944	NIKITA IVANOV	{"email": "ivanov_nikita-04011974@postgrespro.ru", "phone": "+70410573215"}
0005433960449	C9BC70	9957 475566	EKATERINA ILINA	{"email": "ilina-ekaterina22091968@postgrespro.ru", "phone": "+70269438411"}
0005433960450	665850	6592 946654	SERGEY MAKSIMOV	{"phone": "+70670287397"}
0005433960451	4AF686	3989 961655	MIKHAIL NAZAROV	{"phone": "+70618745371"}
0005433960452	8EC609	5276 551006	OLGA BORISOVA	{"email": "borisova.olga-021971@postgrespro.ru", "phone": "+70566854762"}
0005433960453	8EC609	8749 813417	NADEZHDA KAZAKOVA	{"email": "kazakova_nadezhda-13011964@postgrespro.ru", "phone": "+70363471179"}
0005433960454	1937EB	3597 699071	IGOR FEDOTOV	{"email": "fedotovigor_1967@postgrespro.ru", "phone": "+70508835573"}
0005433960455	A9558F	4001 728327	YURIY CHERNOV	{"phone": "+70596975133"}
0005433960456	A9558F	7602 836396	ANATOLIY SAVELEV	{"phone": "+70237761757"}
0005433960457	F1D41E	5928 407181	KONSTANTIN SOLOVEV	{"phone": "+70108681162"}
0005433960458	7617E8	2615 427215	IVAN SERGEEV	{"phone": "+70020163355"}
0005433960459	7617E8	6637 079435	PETR PETROV	{"phone": "+70742488199"}
0005433960460	7617E8	2761 818283	IRINA BORISOVA	{"phone": "+70737099075"}
0005433960461	B660EF	6603 690903	SVETLANA MIKHAYLOVA	{"phone": "+70714543494"}
0005433960462	35B236	4658 045570	VITALIY KISELEV	{"email": "kiselev_vitaliy1969@postgrespro.ru", "phone": "+70389776513"}
0005433960463	B0D4BB	9681 783561	NATALIYA ZAYCEVA	{"email": "zayceva.nataliya-1979@postgrespro.ru", "phone": "+70498509761"}
0005433960464	F8CA4D	8150 937993	ELENA ZAKHAROVA	{"email": "zakharova_elena_1969@postgrespro.ru", "phone": "+70472776899"}
0005433960465	F8CA4D	9350 983384	TATYANA FADEEVA	{"email": "fadeevat06101961@postgrespro.ru", "phone": "+70014324582"}
0005433960466	D630FF	0792 121998	NATALIYA SEMENOVA	{"email": "n.semenova1980@postgrespro.ru", "phone": "+70306305912"}
0005433960467	B27533	6468 984514	VYACHESLAV KISELEV	{"phone": "+70043092949"}
0005433960468	B27533	8965 225276	ANDREY IVANOV	{"email": "ivanovandrey_041978@postgrespro.ru", "phone": "+70754805882"}
0005433960469	B27533	5085 896471	IRINA BARANOVA	{"email": "i-baranova.1975@postgrespro.ru", "phone": "+70247024105"}
0005433960470	FA1780	2024 725832	TIMUR SMIRNOV	{"email": "t_smirnov-05061972@postgrespro.ru", "phone": "+70457526460"}
0005433960471	E903A6	5478 217837	VIKTOR VASILEV	{"phone": "+70707517246"}
0005433960473	DF23C9	3072 606753	SNEZHANA MOROZOVA	{"phone": "+70898827354"}
0005433960474	DF23C9	3275 973555	IVAN ROMANOV	{"phone": "+70421314034"}
0005433960475	9015D4	1699 229923	YULIYA ALEKSEEVA	{"phone": "+70071273422"}
0005433960476	4A7BE0	9622 756310	PETR ALEKSANDROV	{"email": "p.aleksandrov-25071980@postgrespro.ru", "phone": "+70440483917"}
0005433960477	4A7BE0	5379 939432	GALINA ABRAMOVA	{"email": "galina_abramova-1966@postgrespro.ru", "phone": "+70576078526"}
0005433960478	C0437D	6911 386595	VYACHESLAV TIKHONOV	{"email": "v_tikhonov_29101981@postgrespro.ru", "phone": "+70719574030"}
0005433960479	C0437D	9932 225597	LARISA ZAKHAROVA	{"phone": "+70202219523"}
0005433960480	19326E	1499 622166	ANASTASIYA VOLKOVA	{"phone": "+70666676567"}
0005433960481	19326E	2040 604381	ROMAN ANDREEV	{"phone": "+70618036946"}
0005433960482	9B6170	6801 926830	ELIZAVETA FILIPPOVA	{"phone": "+70933826724"}
0005433960483	70421B	3196 000825	ZINAIDA SERGEEVA	{"email": "sergeeva_zinaida_25121968@postgrespro.ru", "phone": "+70858282185"}
0005433960484	AFDF7E	6621 347511	SVETLANA KRASNOVA	{"phone": "+70256248510"}
0005433960485	AFDF7E	4460 868786	NATALYA MOISEEVA	{"email": "natalya_moiseeva.24081975@postgrespro.ru", "phone": "+70788210003"}
0005433960486	AFDF7E	2979 189127	SERGEY ROMANOV	{"email": "romanovs-10021973@postgrespro.ru", "phone": "+70753642706"}
0005433960487	1820A1	5591 581950	MIKHAIL KUZMIN	{"email": "mikhail.kuzmin_28061959@postgrespro.ru", "phone": "+70599059729"}
0005433960488	8D256F	9962 085740	VERA SEMENOVA	{"phone": "+70465990210"}
0005433960489	94C70B	7683 834259	OLGA MATVEEVA	{"phone": "+70145910787"}
0005433960490	C29380	6714 831843	NIKOLAY SMIRNOV	{"email": "nsmirnov.1969@postgrespro.ru", "phone": "+70161000321"}
0005433960491	0C8ED9	5860 221306	INNA NAZAROVA	{"phone": "+70979326567"}
0005433960492	0C8ED9	5928 292913	IRINA BARANOVA	{"email": "baranovairina1971@postgrespro.ru", "phone": "+70523372884"}
0005433960493	51C4A7	8001 774034	ALEKSEY VOLKOV	{"phone": "+70241617829"}
0005433960494	51C4A7	9174 926598	EKATERINA SCHERBAKOVA	{"email": "ekaterinascherbakova.091966@postgrespro.ru", "phone": "+70728273453"}
0005433960495	474E5A	3568 341556	ANATOLIY ANDREEV	{"email": "andreev_anatoliy_021973@postgrespro.ru", "phone": "+70542419010"}
0005433960496	54A232	2646 270877	TATYANA FOMINA	{"email": "t.fomina071968@postgrespro.ru", "phone": "+70918922886"}
0005433960498	57A7D1	8132 913333	MIKHAIL VASILEV	{"phone": "+70575291593"}
0005433960499	132658	5306 657947	SERGEY IVANOV	{"email": "sergeyivanov-20011967@postgrespro.ru", "phone": "+70632700652"}
0005433960500	132658	7373 536875	RINAT MAKSIMOV	{"phone": "+70690233256"}
0005433960501	85FABA	9081 651946	ALEKSEY SCHERBAKOV	{"phone": "+70684289688"}
0005433960502	90C3E3	3592 475632	NATALYA PAVLOVA	{"phone": "+70655345096"}
0005433960503	7B5BE9	2912 558904	EGOR NIKOLAEV	{"phone": "+70968564344"}
0005433960504	7B5BE9	4127 327865	ALEKSEY SEMENOV	{"phone": "+70266050549"}
0005433960505	5F1409	3819 254374	MARIYA ZAKHAROVA	{"phone": "+70892514308"}
0005433960506	5F1409	0515 828700	ILYA SAVELEV	{"email": "ilya.savelev_11061975@postgrespro.ru", "phone": "+70531571414"}
0005433960507	2EC851	6512 590446	ALEKSANDR NIKITIN	{"phone": "+70555558158"}
0005433960508	2E1E34	8159 915436	ELENA MOROZOVA	{"phone": "+70131405319"}
0005433960509	FEA707	2467 918611	VIKTORIYA SOLOVEVA	{"email": "soloveva.viktoriya.031990@postgrespro.ru", "phone": "+70759975349"}
0005433960510	C6CD8F	1528 061917	GENNADIY ABRAMOV	{"email": "gabramov.06071978@postgrespro.ru", "phone": "+70326208961"}
0005433960511	C6CD8F	3334 435269	ANATOLIY FILIPPOV	{"phone": "+70181547851"}
0005433960512	2ECA98	1683 282519	OLGA ZAKHAROVA	{"phone": "+70661240877"}
0005433960513	2ECA98	8262 326376	VALENTIN MOROZOV	{"phone": "+70209970860"}
0005433960514	62E0BE	2216 259040	ANDREY BELOV	{"email": "andrey-belov_061975@postgrespro.ru", "phone": "+70875282656"}
0005433960515	62E0BE	5849 389748	SERGEY CHERNOV	{"phone": "+70684296262"}
0005433960516	42C1E5	8295 615142	EVGENIY NAZAROV	{"phone": "+70616677442"}
0005433960517	545403	4538 833256	VIKTOR NIKOLAEV	{"phone": "+70377404831"}
0005433960518	24F8E7	7046 126813	NINA ISAEVA	{"email": "isaeva.nina.29051975@postgrespro.ru", "phone": "+70541550211"}
0005433960519	CBB357	0165 915763	BOGDAN ZAYCEV	{"phone": "+70143228996"}
0005433960520	C22EF4	5396 455820	GENNADIY ZHURAVLEV	{"email": "zhuravlev.g.011972@postgrespro.ru", "phone": "+70390397399"}
0005433960521	C22EF4	0588 980097	ALEKSANDR MEDVEDEV	{"phone": "+70071763232"}
0005433960522	BD16F1	3338 938871	DMITRIY SOLOVEV	{"email": "solovevd.021987@postgrespro.ru", "phone": "+70363676157"}
0005433960523	01B3D6	1861 740951	VLADIMIR FILIPPOV	{"phone": "+70900101888"}
0005433960524	886162	5802 964603	VALERIY IVANOV	{"email": "v.ivanov27041967@postgrespro.ru", "phone": "+70929036932"}
0005433960525	886162	0150 108149	LYUDMILA ZOTOVA	{"phone": "+70098973550"}
0005433960526	2A9CF4	6139 786828	LYUDMILA RODIONOVA	{"phone": "+70803637219"}
0005433960527	27B8CC	8494 304524	NATALYA GAVRILOVA	{"phone": "+70549972358"}
0005433960528	27B8CC	5215 982978	VYACHESLAV FEDOROV	{"email": "fedorov-vyacheslav121973@postgrespro.ru", "phone": "+70964057260"}
0005433960529	0ACDD9	9846 207329	MIKHAIL FEDOROV	{"email": "mikhail.fedorov-21071978@postgrespro.ru", "phone": "+70959791775"}
0005433960530	4CA845	8731 264061	NATALIYA DMITRIEVA	{"email": "dmitrievan.19111965@postgrespro.ru", "phone": "+70741288874"}
0005433960531	4CA845	2777 324077	SERGEY MAKSIMOV	{"email": "maksimov.s22031976@postgrespro.ru", "phone": "+70337898576"}
0005433960532	ACA345	9377 511568	ANASTASIYA NIKITINA	{"phone": "+70392729435"}
0005433960533	0F580D	3543 784910	ALEKSEY ZAYCEV	{"phone": "+70484195851"}
0005433960534	9A53B3	9168 479460	KRISTINA ZOTOVA	{"phone": "+70708940985"}
0005433960535	9A53B3	2087 744554	IGOR MOROZOV	{"phone": "+70082493214"}
0005433960536	901EB4	6652 932522	STANISLAV PETROV	{"phone": "+70174476495"}
0005433960537	901EB4	2017 334194	SERGEY VOLKOV	{"email": "volkov-sergey1980@postgrespro.ru", "phone": "+70627521970"}
0005433960538	03A7D5	6483 343215	ALEKSANDR KONOVALOV	{"email": "konovalov-aleksandr_1986@postgrespro.ru", "phone": "+70585535207"}
0005433960539	89F4EE	5092 388935	ANASTASIYA SMIRNOVA	{"phone": "+70180468863"}
0005433960540	89F4EE	9376 170166	LYUBOV GORBUNOVA	{"email": "l.gorbunova-24031970@postgrespro.ru", "phone": "+70631380202"}
0005433960541	A2FA45	4845 533538	IVAN SERGEEV	{"email": "i.sergeev081972@postgrespro.ru", "phone": "+70061015049"}
0005433960542	A2FA45	5413 477683	VERA KULIKOVA	{"email": "kulikova_vera26091966@postgrespro.ru", "phone": "+70549393362"}
0005433960543	88C832	1729 926669	ANDREY KARPOV	{"phone": "+70446596496"}
0005433960544	88C832	9578 135730	DENIS POPOV	{"email": "popov.d_031973@postgrespro.ru", "phone": "+70022109692"}
0005433960545	88C832	5559 212645	IVAN POPOV	{"email": "popov-i_051980@postgrespro.ru", "phone": "+70334025987"}
0005433960546	E5CEDD	9195 480475	NIKOLAY KOZLOV	{"email": "kozlov-n-24101972@postgrespro.ru", "phone": "+70966265124"}
0005433960547	D20B3B	1179 322355	MAKSIM POPOV	{"email": "maksimpopov031973@postgrespro.ru", "phone": "+70329100461"}
0005433960548	12B2DF	3990 285708	ANDREY SEMENOV	{"email": "semenov_andrey-04011969@postgrespro.ru", "phone": "+70365555447"}
0005433960549	5AC617	9953 224979	YULIYA FADEEVA	{"email": "fadeeva-y1967@postgrespro.ru", "phone": "+70107192168"}
0005433960550	5AC617	8465 627340	ANASTASIYA VLASOVA	{"email": "anastasiyavlasova_1976@postgrespro.ru", "phone": "+70227875631"}
0005433960551	5AC617	6356 115446	IVAN RODIONOV	{"phone": "+70114670793"}
0005433960552	93BFE2	1514 532356	VIKTORIYA POPOVA	{"email": "viktoriya.popova1967@postgrespro.ru", "phone": "+70744997963"}
0005433960553	C34D7D	9951 951942	OLGA NAZAROVA	{"phone": "+70319401623"}
0005433960554	C342E2	1667 597559	VLADIMIR BORISOV	{"phone": "+70445475505"}
0005433960555	59134A	2529 389422	VLADIMIR ISAEV	{"phone": "+70248223317"}
0005433960556	59134A	0817 844440	LYUDMILA LUKYANOVA	{"phone": "+70848886639"}
0005433960557	61A4BB	6741 132528	IRINA FILATOVA	{"email": "filatova-irina.1977@postgrespro.ru", "phone": "+70961064206"}
0005433960558	D3AE46	3935 749657	EKATERINA OVCHINNIKOVA	{"phone": "+70428614005"}
0005433960559	D3AE46	7672 461794	GALINA MAKSIMOVA	{"phone": "+70167542042"}
0005433960560	470E8B	2056 305237	ANDREY SERGEEV	{"email": "a.sergeev_051981@postgrespro.ru", "phone": "+70223219815"}
0005433960561	470E8B	5800 674831	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr1974@postgrespro.ru", "phone": "+70354497897"}
0005433960562	A97B2A	2182 101831	ALEKSANDR KRASNOV	{"email": "krasnov_a_15041965@postgrespro.ru", "phone": "+70128170606"}
0005433960563	799328	5472 432939	TATYANA KOZLOVA	{"phone": "+70187090287"}
0005433960564	C9B7CE	1258 464559	NATALYA SAVELEVA	{"email": "n_saveleva_061982@postgrespro.ru", "phone": "+70576561303"}
0005433960565	2F1702	6060 570442	YULIYA RYABOVA	{"email": "y.ryabova22021968@postgrespro.ru", "phone": "+70070675312"}
0005433960566	4ED975	9437 660345	OKSANA VLASOVA	{"phone": "+70538193144"}
0005433960567	370B7C	0532 925158	SERGEY ANDREEV	{"email": "s_andreev04081972@postgrespro.ru", "phone": "+70554110239"}
0005433960568	994B51	5236 696116	IRINA RYABOVA	{"phone": "+70504263520"}
0005433960569	614EFF	9807 642576	VALENTINA MAKAROVA	{"phone": "+70772533263"}
0005433960570	614EFF	1234 194613	VLADIMIR ZHURAVLEV	{"phone": "+70338751837"}
0005433960571	CE7998	2059 266158	ANVAR KOZLOV	{"phone": "+70745192542"}
0005433960572	B693EE	0857 317754	LYUBOV EGOROVA	{"phone": "+70331392654"}
0005433960573	B693EE	6826 227937	VLADIMIR PAVLOV	{"email": "pavlovv.091965@postgrespro.ru", "phone": "+70100739938"}
0005433960574	3A551F	0452 116372	LYUBOV IVANOVA	{"email": "livanova_12071973@postgrespro.ru", "phone": "+70672381860"}
0005433960575	2A10C2	9897 297308	VIKTOR POPOV	{"email": "popov_v_11061976@postgrespro.ru", "phone": "+70616101733"}
0005433960576	59BF75	9369 995111	ALENA TIMOFEEVA	{"email": "timofeeva-alena-1965@postgrespro.ru", "phone": "+70392390002"}
0005433960577	182ADF	8804 217410	VLADISLAV ROMANOV	{"email": "v-romanov_18081957@postgrespro.ru", "phone": "+70371582071"}
0005433960578	423265	1199 824882	ANDREY TARASOV	{"phone": "+70749701235"}
0005433960579	82A5CD	4041 563724	ALENA RODIONOVA	{"phone": "+70685318506"}
0005433960580	82A5CD	1738 220538	SERGEY IVANOV	{"email": "ivanov-sergey-1983@postgrespro.ru", "phone": "+70397146745"}
0005433960581	371EEC	8379 644980	MARIYA ANDREEVA	{"phone": "+70549815868"}
0005433960582	7725C4	1810 879619	IVAN KRASNOV	{"phone": "+70901413929"}
0005433960583	7725C4	8071 066814	DMITRIY FEDOROV	{"phone": "+70627023884"}
0005433960584	BA6D3F	6700 894456	VIKTOR FEDOTOV	{"email": "viktorfedotov.07081972@postgrespro.ru", "phone": "+70763410684"}
0005433960585	1578E2	9046 340691	NIKOLAY MAKSIMOV	{"phone": "+70724168876"}
0005433960586	1578E2	3936 612520	NATALYA MAKAROVA	{"phone": "+70585663353"}
0005433960587	C7CA0B	1710 757250	NATALIYA MEDVEDEVA	{"email": "medvedeva-n081976@postgrespro.ru", "phone": "+70780727868"}
0005433960588	78DD11	2958 736712	ALEKSANDR SOROKIN	{"phone": "+70840956987"}
0005433960589	8BDD84	0247 859090	EVGENIYA VASILEVA	{"phone": "+70574099794"}
0005433960590	8BDD84	4961 527997	VYACHESLAV IVANOV	{"phone": "+70682905434"}
0005433960591	8BDD84	2601 943310	IRINA GUSEVA	{"email": "gusevairina-031965@postgrespro.ru", "phone": "+70368431454"}
0005433960592	E10670	9514 434401	GENNADIY MAKAROV	{"email": "g_makarov1965@postgrespro.ru", "phone": "+70455707512"}
0005433960593	5B2D3B	8489 729839	ALEKSEY SERGEEV	{"email": "sergeev-aleksey.21121968@postgrespro.ru", "phone": "+70929781065"}
0005433960594	5B2D3B	7616 389077	DMITRIY ZAKHAROV	{"phone": "+70274764099"}
0005433960595	639B25	2461 792685	NADEZHDA KUZNECOVA	{"email": "nadezhda.kuznecova04021985@postgrespro.ru", "phone": "+70803065600"}
0005433960596	639B25	5112 361344	NATALYA SOLOVEVA	{"phone": "+70885900994"}
0005433960597	E246F4	9992 280206	ALEKSANDR SAVELEV	{"phone": "+70978758053"}
0005433960598	0D1C06	7538 482330	VIKTOR ILIN	{"phone": "+70599620051"}
0005433960599	75898C	5301 088813	GALINA BOGDANOVA	{"email": "bogdanova_g20111968@postgrespro.ru", "phone": "+70731238745"}
0005433960600	DFAF03	0251 524731	ALEKSANDR SIDOROV	{"phone": "+70208878882"}
0005433960601	81ACE7	5648 487969	ALEKSANDR GUSEV	{"phone": "+70343358339"}
0005433960602	81ACE7	8878 238172	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov.091970@postgrespro.ru", "phone": "+70515629550"}
0005433960603	2AA5CB	5136 061011	MIKHAIL MATVEEV	{"phone": "+70727421299"}
0005433960604	81F3A5	6162 055047	VLADISLAV RODIONOV	{"email": "rodionov-v-1971@postgrespro.ru", "phone": "+70492326906"}
0005433960605	EFAD69	5925 931950	NATALYA EFIMOVA	{"email": "n.efimova.12101978@postgrespro.ru", "phone": "+70875533611"}
0005433960606	0B9BEC	9085 554942	VERA PAVLOVA	{"email": "pavlova.v041981@postgrespro.ru", "phone": "+70439205380"}
0005433960607	9F3934	3003 792083	ELENA SMIRNOVA	{"phone": "+70197794376"}
0005433960608	95AC85	5687 877806	SEMEN GERASIMOV	{"phone": "+70672665493"}
0005433960609	AF924E	3860 646935	MARINA VASILEVA	{"phone": "+70267490012"}
0005433960610	64653B	0976 317635	SVETLANA GAVRILOVA	{"email": "svetlana_gavrilova-1975@postgrespro.ru", "phone": "+70019205451"}
0005433960611	5A9E0D	3279 868561	SERGEY MARTYNOV	{"phone": "+70372971574"}
0005433960612	5A9E0D	1915 981997	MARIYA VOLKOVA	{"email": "m-volkova_23121977@postgrespro.ru", "phone": "+70711816132"}
0005433960613	2C8AD0	0160 141207	DMITRIY PETROV	{"phone": "+70339410095"}
0005433960614	2C8AD0	1359 303647	VALENTINA SIDOROVA	{"email": "valentina.sidorova25121977@postgrespro.ru", "phone": "+70521180516"}
0005433960615	5DC575	2140 906464	VADIM ROMANOV	{"email": "vromanov081968@postgrespro.ru", "phone": "+70029231632"}
0005433960616	189149	9432 004850	VERA EGOROVA	{"phone": "+70868263927"}
0005433960617	189149	5861 242107	ANDREY ALEKSEEV	{"phone": "+70633955771"}
0005433960618	69A8F2	0994 104095	YULIYA NESTEROVA	{"phone": "+70705345776"}
0005433960619	69A8F2	1527 358088	VALERIY ILIN	{"phone": "+70412367548"}
0005433960620	579627	1111 692813	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr.1980@postgrespro.ru", "phone": "+70105379681"}
0005433960621	579627	9120 867574	IGOR PETROV	{"phone": "+70273807320"}
0005433960622	C237C9	7715 790990	ANATOLIY STEPANOV	{"email": "a_stepanov1989@postgrespro.ru", "phone": "+70226738367"}
0005433960623	E8C5EF	1004 458701	TATYANA GAVRILOVA	{"email": "t_gavrilova_20101971@postgrespro.ru", "phone": "+70681778787"}
0005433960624	B65F50	2059 298641	DMITRIY ZAYCEV	{"email": "zaycev-d.081975@postgrespro.ru", "phone": "+70528464674"}
0005433960625	67361A	9356 031600	ANDREY SEMENOV	{"phone": "+70932607913"}
0005433960626	940B4C	0660 946815	MARINA POPOVA	{"email": "popovam.081981@postgrespro.ru", "phone": "+70069601455"}
0005433960627	298CDB	3066 559164	DMITRIY SOROKIN	{"email": "dmitriy_sorokin-081970@postgrespro.ru", "phone": "+70947243768"}
0005433960628	E92F82	7265 535233	ALEKSEY SEMENOV	{"phone": "+70467953243"}
0005433960629	651E00	5292 546970	VALENTINA KUZNECOVA	{"email": "valentina.kuznecova-1971@postgrespro.ru", "phone": "+70987959293"}
0005433960630	3F018A	8401 604893	ALEKSANDR DMITRIEV	{"phone": "+70062563479"}
0005433960631	D34F17	7336 167623	VLADIMIR NIKOLAEV	{"email": "nikolaev_v_1965@postgrespro.ru", "phone": "+70376801594"}
0005433960632	D34F17	4177 332757	TATYANA KOROLEVA	{"phone": "+70073726657"}
0005433960633	23D220	4487 384888	ALENA BORISOVA	{"phone": "+70637917838"}
0005433960634	23D220	1497 987326	ELENA CHERNOVA	{"phone": "+70165746947"}
0005433960635	2F7D02	7846 407161	VIKTOR SEMENOV	{"email": "v.semenov-11041972@postgrespro.ru", "phone": "+70087081380"}
0005433960636	9CBAC5	5033 060626	DMITRIY ISAEV	{"phone": "+70669662637"}
0005433960637	9CBAC5	8475 323427	MARGARITA KOROLEVA	{"phone": "+70568583240"}
0005433960638	9CBAC5	5769 024619	INNA IVANOVA	{"email": "i.ivanova09091962@postgrespro.ru", "phone": "+70867630319"}
0005433960639	D0183D	5907 736289	SVETLANA KOROLEVA	{"email": "svetlana-koroleva_111969@postgrespro.ru", "phone": "+70511301270"}
0005433960640	31D935	2774 427037	SVETLANA SCHERBAKOVA	{"phone": "+70192955627"}
0005433960641	6463C7	8829 958969	TATYANA KOROLEVA	{"phone": "+70823295508"}
0005433960642	A1C091	3316 999924	ALEKSANDR MAKSIMOV	{"phone": "+70655379946"}
0005433960643	33A791	0485 190015	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov.1967@postgrespro.ru", "phone": "+70282483300"}
0005433960644	512E94	4883 089040	TATYANA KUZNECOVA	{"email": "t.kuznecova.1975@postgrespro.ru", "phone": "+70756119408"}
0005433960645	840576	8426 109050	TAMARA BELOVA	{"phone": "+70938180783"}
0005433960646	423857	7740 704215	LYUDMILA GRISHINA	{"phone": "+70213299215"}
0005433960647	D480CE	2237 029945	NADEZHDA BARANOVA	{"phone": "+70000896187"}
0005433960648	5AA0C1	2545 235307	EVGENIY DENISOV	{"email": "denisove31011990@postgrespro.ru", "phone": "+70394603968"}
0005433960649	5AA0C1	1321 891649	SVETLANA STEPANOVA	{"email": "stepanovas-081973@postgrespro.ru", "phone": "+70660954854"}
0005433960650	D4277B	9795 765811	ALEKSANDRA YAKOVLEVA	{"phone": "+70516630999"}
0005433960651	D4277B	9729 406209	LIDIYA TROFIMOVA	{"phone": "+70152579142"}
0005433960652	F6AEBB	8589 197557	NATALYA KUZNECOVA	{"email": "kuznecova.natalya-021976@postgrespro.ru", "phone": "+70581106271"}
0005433960653	F6AEBB	2888 366657	SVETLANA KALININA	{"phone": "+70398445323"}
0005433960654	1E34C3	9002 145179	LIDIYA KOZLOVA	{"email": "lidiyakozlova_12091965@postgrespro.ru", "phone": "+70289046957"}
0005433960655	1E34C3	2762 684495	KRISTINA CHERNOVA	{"phone": "+70295799408"}
0005433960656	1E34C3	4568 682909	MARIYA MAKSIMOVA	{"email": "maksimova.mariya.1967@postgrespro.ru", "phone": "+70368522040"}
0005433960657	E69BFE	3509 991911	ELENA KUZNECOVA	{"phone": "+70834847185"}
0005433960658	30BEF1	0502 576739	RAISA IVANOVA	{"email": "r_ivanova.24071965@postgrespro.ru", "phone": "+70465020494"}
0005433960659	252FF6	0593 747129	ILYA TIKHONOV	{"phone": "+70703761674"}
0005433960660	252FF6	4666 831247	VALERIY ABRAMOV	{"phone": "+70855765160"}
0005433960661	ED5A6E	1384 526704	LYUDMILA TITOVA	{"email": "titoval.071979@postgrespro.ru", "phone": "+70321773913"}
0005433960662	C161CE	1059 557634	VLADIMIR ANDREEV	{"phone": "+70283682223"}
0005433960663	762F0F	0595 316589	VALENTINA IVANOVA	{"phone": "+70943466730"}
0005433960664	C6EB62	2633 974358	OLGA SIDOROVA	{"email": "o.sidorova_1973@postgrespro.ru", "phone": "+70043176562"}
0005433960665	82573D	4892 768090	ALEKSANDR SEMENOV	{"email": "asemenov.30031976@postgrespro.ru", "phone": "+70779853827"}
0005433960666	82573D	0764 521704	NIKOLAY RODIONOV	{"phone": "+70989329165"}
0005433960667	82573D	7032 464154	VITALIY KUZNECOV	{"phone": "+70479940965"}
0005433960668	82B2C9	5187 880928	VERA FEDOROVA	{"phone": "+70052028792"}
0005433960669	9087D8	0594 099957	NIKOLAY ALEKSEEV	{"phone": "+70927559661"}
0005433960670	AAD1AE	4755 548128	YURIY CHERNOV	{"phone": "+70849430027"}
0005433960671	AAD1AE	5212 947368	PAVEL KULIKOV	{"email": "kulikov.p-09111968@postgrespro.ru", "phone": "+70423375123"}
0005433960672	3FB7EA	1085 616955	VALERIY MAKAROV	{"email": "valeriy.makarov.04121981@postgrespro.ru", "phone": "+70702781927"}
0005433960673	E2CC88	6402 869142	ELENA GERASIMOVA	{"email": "gerasimova_e02121968@postgrespro.ru", "phone": "+70343179692"}
0005433960674	E02FE7	5784 270699	TATYANA GERASIMOVA	{"email": "tatyanagerasimova_18011964@postgrespro.ru", "phone": "+70166551340"}
0005433960675	B72DF6	3062 893829	VLADIMIR IVANOV	{"email": "vladimir-ivanov.12011973@postgrespro.ru", "phone": "+70251211771"}
0005433960676	B72DF6	9665 193044	LYUDMILA MATVEEVA	{"email": "matveeva_l_021972@postgrespro.ru", "phone": "+70617146350"}
0005433960677	A17B9D	8706 601294	MARIYA IVANOVA	{"phone": "+70619136073"}
0005433960678	2CF970	1043 514813	KHASAN NOVIKOV	{"email": "k_novikov_06061971@postgrespro.ru", "phone": "+70203176154"}
0005433960679	2CF970	3858 122758	ANASTASIYA VOLKOVA	{"email": "volkova_a-1972@postgrespro.ru", "phone": "+70148988571"}
0005433960680	2CF970	3498 869624	ALEKSANDR ZAKHAROV	{"phone": "+70930710373"}
0005433960681	2AC4B1	9134 551696	NATALYA ANDREEVA	{"email": "natalya_andreeva_13041969@postgrespro.ru", "phone": "+70655718958"}
0005433960682	CD6E60	0678 209528	SERGEY KARPOV	{"email": "sergey-karpov.121964@postgrespro.ru", "phone": "+70516893354"}
0005433960683	9C412D	2821 301206	SVETLANA ERMAKOVA	{"email": "ermakova.s.061975@postgrespro.ru", "phone": "+70277503722"}
0005433960684	7632DE	0531 557538	SVETLANA KOROLEVA	{"phone": "+70482046888"}
0005433960685	7632DE	8220 525692	VLADIMIR NIKOLAEV	{"email": "vladimir.nikolaev-121973@postgrespro.ru", "phone": "+70299150822"}
0005433960686	035255	9559 675841	NATALYA ILINA	{"phone": "+70258522081"}
0005433960687	21633E	9825 129194	VALERIY VOLKOV	{"phone": "+70166664383"}
0005433960688	E7653C	7425 317679	LYUDMILA KUZNECOVA	{"email": "l-kuznecova-20081972@postgrespro.ru", "phone": "+70964065112"}
0005433960689	0940FD	9873 523167	ANASTASIYA NIKOLAEVA	{"email": "anikolaeva.28061968@postgrespro.ru", "phone": "+70777147585"}
0005433960690	0940FD	3962 920363	LYUDMILA IVANOVA	{"email": "l-ivanova121981@postgrespro.ru", "phone": "+70175212185"}
0005433960691	0940FD	3514 557187	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy-1979@postgrespro.ru", "phone": "+70466033526"}
0005433960692	0940FD	8614 675412	ROMAN YAKOVLEV	{"phone": "+70759405096"}
0005433960693	B07EE8	2597 602236	VALENTINA KOZLOVA	{"phone": "+70995580078"}
0005433960694	B07EE8	6089 312071	ALEKSEY KOZLOV	{"phone": "+70132936953"}
0005433960695	982F8E	2241 990417	RAVIL VASILEV	{"email": "vasilev-r1974@postgrespro.ru", "phone": "+70260742934"}
0005433960696	982F8E	0234 070052	ALBINA STEPANOVA	{"phone": "+70197067059"}
0005433960697	982F8E	7676 009342	IVAN SIDOROV	{"phone": "+70427821452"}
0005433960698	7979AB	8089 883964	SERGEY KONOVALOV	{"email": "konovalovs-081975@postgrespro.ru", "phone": "+70750560832"}
0005433960699	7979AB	1385 717927	IGOR KUZNECOV	{"phone": "+70011194345"}
0005433960700	F72DE3	4240 036793	ANASTASIYA TIMOFEEVA	{"email": "timofeeva_anastasiya27021977@postgrespro.ru", "phone": "+70140300982"}
0005433960701	F72DE3	2953 000244	IVAN YAKOVLEV	{"email": "iyakovlev-1966@postgrespro.ru", "phone": "+70397096651"}
0005433960702	C62E87	1377 971732	NINA FILIPPOVA	{"email": "filippova.nina-1962@postgrespro.ru", "phone": "+70173375116"}
0005433960703	C62E87	3477 570458	ILYA BONDARENKO	{"phone": "+70552097332"}
0005433960704	9ED2BF	2055 160866	VALENTINA NESTEROVA	{"phone": "+70021845428"}
0005433960705	369358	9600 310488	VLADIMIR KRASNOV	{"email": "vkrasnov051972@postgrespro.ru", "phone": "+70254277797"}
0005433960706	DF226B	1047 565268	MARGARITA SEMENOVA	{"email": "margarita_semenova-13011975@postgrespro.ru", "phone": "+70538223545"}
0005433960707	D0DBEF	3698 352337	ANASTASIYA KUZNECOVA	{"email": "anastasiya-kuznecova_17071970@postgrespro.ru", "phone": "+70396556608"}
0005433960708	D0DBEF	0553 370762	VERONIKA CHERNOVA	{"phone": "+70628244907"}
0005433960709	9DA7F8	2000 254881	KONSTANTIN VASILEV	{"phone": "+70285127163"}
0005433960710	E76FF5	6796 811096	SERGEY NIKOLAEV	{"phone": "+70111952533"}
0005433960711	071C9C	2275 289641	ROMAN OSIPOV	{"phone": "+70238046391"}
0005433960712	5F389F	1461 678626	LEONID FROLOV	{"phone": "+70473799636"}
0005433960713	6C0B5D	3604 076836	VALERIY ISAEV	{"phone": "+70394982741"}
0005433960714	6C0B5D	2125 265833	ANATOLIY OSIPOV	{"email": "anatoliyosipov.041976@postgrespro.ru", "phone": "+70036383151"}
0005433960715	6C0B5D	5249 476909	RAISA NESTEROVA	{"email": "nesterovaraisa.07031967@postgrespro.ru", "phone": "+70830458772"}
0005433960716	434808	1722 759470	OLGA LAZAREVA	{"email": "lazarevao-1968@postgrespro.ru", "phone": "+70837967984"}
0005433960717	434808	0920 087753	YURIY OSIPOV	{"phone": "+70218989775"}
0005433960718	434808	7992 830272	ELENA LEBEDEVA	{"phone": "+70921251076"}
0005433960719	A351C2	6102 123779	VLADIMIR POPOV	{"email": "vladimir.popov121984@postgrespro.ru", "phone": "+70899843956"}
0005433960720	A351C2	5937 802367	STEPAN NOVIKOV	{"email": "s_novikov.1969@postgrespro.ru", "phone": "+70741989531"}
0005433960721	B11CB9	9693 068067	ALEKSANDR IVANOV	{"email": "aleksandrivanov_101974@postgrespro.ru", "phone": "+70458226969"}
0005433960722	39A896	4360 454571	NADEZHDA SOLOVEVA	{"email": "soloveva.nadezhda.28051965@postgrespro.ru", "phone": "+70861938241"}
0005433960723	39A896	3637 733349	SEMEN MAKSIMOV	{"phone": "+70780296266"}
0005433960724	B41C5F	2015 319109	VLADIMIR NIKOLAEV	{"email": "vladimir-nikolaev_031975@postgrespro.ru", "phone": "+70080932575"}
0005433960725	9765AF	2307 144685	LYUDMILA GUSEVA	{"email": "guseva_l-25011985@postgrespro.ru", "phone": "+70186187711"}
0005433960726	9539BC	7196 852107	VYACHESLAV FROLOV	{"phone": "+70653760244"}
0005433960727	9539BC	7528 917443	DIANA FEDOROVA	{"phone": "+70777544275"}
0005433960728	BE0AE4	1741 304369	VALERIY VOROBEV	{"email": "vvorobev-081974@postgrespro.ru", "phone": "+70599028300"}
0005433960729	BE0AE4	4854 512840	TATYANA SOLOVEVA	{"phone": "+70066518144"}
0005433960730	D10D4B	3006 702991	ELENA BARANOVA	{"phone": "+70780229780"}
0005433960731	D10D4B	3003 727278	SVETLANA SOKOLOVA	{"email": "sokolovas05121964@postgrespro.ru", "phone": "+70095566095"}
0005433960732	1A8E8B	5197 838481	ANATOLIY GRIGOREV	{"email": "anatoliy-grigorev.041967@postgrespro.ru", "phone": "+70345258485"}
0005433960733	1A8E8B	9359 810365	EVGENIY KUZNECOV	{"email": "kuznecov.e-1971@postgrespro.ru", "phone": "+70138216098"}
0005433960734	1A8E8B	3284 482841	ALEKSANDR MOROZOV	{"phone": "+70056789889"}
0005433960735	6BA63F	6590 392979	TAMARA KRASNOVA	{"email": "t-krasnova-01081968@postgrespro.ru", "phone": "+70555125254"}
0005433960736	6BA63F	8252 843414	LYUDMILA KUZNECOVA	{"email": "lkuznecova.23061976@postgrespro.ru", "phone": "+70189838863"}
0005433960737	F30929	0609 215669	NATALYA BELOVA	{"email": "belova.natalya-111975@postgrespro.ru", "phone": "+70353956242"}
0005433960738	C62479	3922 651225	ELIZAVETA MIRONOVA	{"email": "mironova_elizaveta1973@postgrespro.ru", "phone": "+70036998672"}
0005433960739	241B55	7759 301673	VLADISLAV DAVYDOV	{"email": "vladislav.davydov-1978@postgrespro.ru", "phone": "+70245284030"}
0005433960740	241B55	3191 690401	VIKTOR FEDOROV	{"phone": "+70295351819"}
0005433960741	C3143A	5261 427219	TATYANA POPOVA	{"email": "popova-tatyana_22071985@postgrespro.ru", "phone": "+70728147792"}
0005433960742	C3143A	4838 569012	SERGEY IVANOV	{"phone": "+70946313587"}
0005433960743	C7C500	0865 526496	DANILA MIRONOV	{"email": "danila.mironov.061991@postgrespro.ru", "phone": "+70710177306"}
0005433960744	C7C500	6447 851035	ANNA NIKOLAEVA	{"phone": "+70870331823"}
0005433960745	4E2D8D	9110 924028	NADEZHDA EGOROVA	{"phone": "+70552045900"}
0005433960746	49BB43	0555 857469	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr081960@postgrespro.ru", "phone": "+70709988510"}
0005433960747	FCBA3A	1947 716224	DMITRIY ABRAMOV	{"phone": "+70795401172"}
0005433960748	30D584	1187 920067	ALEKSEY BONDARENKO	{"phone": "+70864357822"}
0005433960749	DF5214	7310 889702	ANDREY ZHURAVLEV	{"email": "a-zhuravlev1979@postgrespro.ru", "phone": "+70296134677"}
0005433960750	76563D	0826 276678	OLEG KAZAKOV	{"phone": "+70152728659"}
0005433960751	76563D	4060 692496	NATALYA NIKOLAEVA	{"email": "nikolaeva_n1971@postgrespro.ru", "phone": "+70567818350"}
0005433960752	A47864	1724 125878	EDUARD VASILEV	{"phone": "+70770707920"}
0005433960753	3D0E67	5386 714694	ANDREY ANDREEV	{"phone": "+70896401400"}
0005433960754	33D573	1305 630809	ANATOLIY SHEVCHENKO	{"phone": "+70323575375"}
0005433960755	58543F	3271 793696	OLGA BARANOVA	{"phone": "+70560065319"}
0005433960756	58543F	9123 879561	ALEKSANDRA LAZAREVA	{"phone": "+70678012188"}
0005433960757	58543F	1068 151015	ELENA GERASIMOVA	{"email": "e.gerasimova_31081978@postgrespro.ru", "phone": "+70728874747"}
0005433960758	73FC0E	8619 501740	ELIZAVETA SOKOLOVA	{"email": "e-sokolova_21011977@postgrespro.ru", "phone": "+70302073938"}
0005433960759	5208AE	0614 031210	DMITRIY MATVEEV	{"email": "d-matveev-1971@postgrespro.ru", "phone": "+70923652124"}
0005433960760	A102A0	7576 827766	YULIYA SIDOROVA	{"phone": "+70966852331"}
0005433960761	A102A0	5762 668643	ANATOLIY GUSEV	{"email": "gusev_a-30111974@postgrespro.ru", "phone": "+70049399044"}
0005433960762	288E9F	7872 860108	GALINA TIKHONOVA	{"email": "tikhonova_galina.1964@postgrespro.ru", "phone": "+70499953907"}
0005433960763	643D7B	0761 996580	OLGA KUDRYASHOVA	{"email": "o_kudryashova1977@postgrespro.ru", "phone": "+70428979739"}
0005433960764	643D7B	6677 509070	TATYANA STEPANOVA	{"email": "tatyanastepanova1971@postgrespro.ru", "phone": "+70724679044"}
0005433960765	5333A7	1025 889059	ALEKSANDR GERASIMOV	{"email": "gerasimov.a_1964@postgrespro.ru", "phone": "+70813726559"}
0005433960766	02ACFD	0547 527817	TATYANA ZAYCEVA	{"email": "t-zayceva.1963@postgrespro.ru", "phone": "+70867083096"}
0005433960767	13507C	9260 154759	OLEG TARASOV	{"phone": "+70030091091"}
0005433960768	13507C	6373 741455	NAIL ZHUKOV	{"email": "zhukovn-1970@postgrespro.ru", "phone": "+70520918683"}
0005433960769	3A9038	4978 373381	IRINA GRISHINA	{"phone": "+70983221143"}
0005433960770	347906	6105 160626	OLEG MIRONOV	{"email": "mironov-oleg-27011977@postgrespro.ru", "phone": "+70347951002"}
0005433960771	C46CE5	3747 536376	ANASTASIYA FILIPPOVA	{"phone": "+70047658960"}
0005433960772	F1DB75	1981 617060	GERMAN POPOV	{"email": "popov.german_14061978@postgrespro.ru", "phone": "+70105375346"}
0005433960773	A8A585	8140 464989	MIKHAIL GAVRILOV	{"phone": "+70238324860"}
0005433960774	A8A585	5694 167643	GALINA LOGINOVA	{"phone": "+70421759013"}
0005433960775	B3E90A	8481 303770	NIKOLAY PETROV	{"email": "n.petrov_1971@postgrespro.ru", "phone": "+70622255530"}
0005433960776	B3E90A	9840 330710	LYUBOV OSIPOVA	{"email": "l.osipova.14011982@postgrespro.ru", "phone": "+70326149573"}
0005433960777	B3E90A	3146 353067	GRIGORIY NAUMOV	{"phone": "+70959287447"}
0005433960778	666E77	7772 132289	SVETLANA FILIPPOVA	{"email": "filippovas-18021969@postgrespro.ru", "phone": "+70511648909"}
0005433960779	07185D	5304 994831	SERGEY ROMANOV	{"email": "s_romanov-011976@postgrespro.ru", "phone": "+70068604270"}
0005433960780	DD1465	0184 732693	NADEZHDA PETROVA	{"email": "petrova.n-121973@postgrespro.ru", "phone": "+70345739428"}
0005433960781	D66881	7214 907314	ALEKSANDR ANDREEV	{"phone": "+70734696361"}
0005433960782	7FD5D5	0221 777568	ROMAN PETROV	{"email": "petrovroman-01011965@postgrespro.ru", "phone": "+70564473266"}
0005433960783	80C1E1	0287 897668	IVAN BARANOV	{"email": "baranov.i.20021968@postgrespro.ru", "phone": "+70173038112"}
0005433960784	EE569D	0717 741700	VENERA ORLOVA	{"email": "venera-orlova071968@postgrespro.ru", "phone": "+70860648146"}
0005433960785	21367C	7250 982496	EVGENIYA KARPOVA	{"phone": "+70362255992"}
0005433960786	21367C	5087 430259	VERA MIKHAYLOVA	{"email": "mikhaylova-vera05021977@postgrespro.ru", "phone": "+70365972820"}
0005433960787	9C8A2A	1301 921153	LYUBOV POPOVA	{"phone": "+70452440009"}
0005433960788	9C8A2A	4843 150917	GRIGORIY ABRAMOV	{"email": "grigoriyabramov-11121976@postgrespro.ru", "phone": "+70826585566"}
0005433960789	6D5617	3513 077163	VALENTINA IVANOVA	{"phone": "+70149118664"}
0005433960790	82B06B	6461 840004	KIRA MELNIKOVA	{"phone": "+70576879819"}
0005433960791	8EB8FA	0804 129996	VASILIY NAZAROV	{"phone": "+70188253746"}
0005433960792	73B672	5067 534696	ALINA KRASNOVA	{"email": "krasnova-alina1968@postgrespro.ru", "phone": "+70164862063"}
0005433960793	977D1F	4956 008560	LIDIYA KARPOVA	{"phone": "+70569814776"}
0005433960794	66565B	3370 054788	YULIYA RYABOVA	{"phone": "+70795161601"}
0005433960795	E39F79	5800 329168	ALEKSANDRA SMIRNOVA	{"phone": "+70219875858"}
0005433960796	9942B6	7814 588333	ANASTASIYA VOLKOVA	{"email": "a_volkova.051969@postgrespro.ru", "phone": "+70429151949"}
0005433960797	94F407	3000 716268	VLADIMIR FEDOTOV	{"phone": "+70959149379"}
0005433960798	94F407	4848 032427	LYUDMILA ISAEVA	{"phone": "+70597439361"}
0005433960799	42C264	9274 925386	REGINA LOGINOVA	{"phone": "+70319097515"}
0005433960800	42C264	7446 419179	LYUBOV EGOROVA	{"phone": "+70113065647"}
0005433960801	EAD2F7	9641 167811	MARIYA POPOVA	{"phone": "+70000765280"}
0005433960802	6D9937	4868 115963	NINA MELNIKOVA	{"phone": "+70283916982"}
0005433960803	6D9937	7468 678139	LYUBOV AFANASEVA	{"email": "afanaseva_l-1973@postgrespro.ru", "phone": "+70651132540"}
0005433960804	D60D5E	1326 373327	VITALIY PETROV	{"email": "petrovvitaliy_041967@postgrespro.ru", "phone": "+70996487604"}
0005433960805	B97D43	2015 055639	SERGEY BARANOV	{"email": "baranov.s1968@postgrespro.ru", "phone": "+70305103726"}
0005433960806	AB843C	6682 960260	MIKHAIL MARTYNOV	{"email": "martynovmikhail.111975@postgrespro.ru", "phone": "+70824398934"}
0005433960807	E293E0	1577 844817	VITALIY STEPANOV	{"phone": "+70645324141"}
0005433960808	E19E3A	3548 262171	ANNA MELNIKOVA	{"phone": "+70323067400"}
0005433960809	777985	7043 469858	VENERA YUDINA	{"email": "yudinavenera_01041965@postgrespro.ru", "phone": "+70998238081"}
0005433960810	777985	6205 153763	SVETLANA ZAYCEVA	{"email": "zayceva_s_22011974@postgrespro.ru", "phone": "+70050534814"}
0005433960811	39CEBC	7803 580821	SERGEY KUZNECOV	{"phone": "+70878258999"}
0005433960812	012A18	9526 412423	NATALYA LEBEDEVA	{"phone": "+70943417017"}
0005433960813	7E41D6	0969 580195	NATALIYA NOVIKOVA	{"email": "novikova_n1967@postgrespro.ru", "phone": "+70683405569"}
0005433960814	3F7349	2133 452468	ZINAIDA GORBUNOVA	{"phone": "+70231750035"}
0005433960815	3F7349	0961 622938	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov.03041958@postgrespro.ru", "phone": "+70007063975"}
0005433960816	FF106E	3927 866902	OKSANA PAVLOVA	{"phone": "+70741102553"}
0005433960817	FF106E	9620 102702	SANIYA SIDOROVA	{"phone": "+70575823089"}
0005433960818	FF106E	2127 694520	VALENTINA IVANOVA	{"email": "valentina_ivanova-011973@postgrespro.ru", "phone": "+70458631450"}
0005433960819	FF106E	0370 907050	MAKSIM KRASNOV	{"phone": "+70623537768"}
0005433960820	DB1BEA	3185 129114	YURIY FEDOROV	{"phone": "+70406950775"}
0005433960821	F6F14C	1369 911680	VIKTORIYA NESTEROVA	{"phone": "+70427393492"}
0005433960822	B57DD3	0735 400781	ANASTASIYA KUZMINA	{"email": "kuzmina.anastasiya05081963@postgrespro.ru", "phone": "+70360252770"}
0005433960823	B57DD3	6265 111387	KSENIYA MOISEEVA	{"email": "moiseeva.k_1971@postgrespro.ru", "phone": "+70373619462"}
0005433960824	AC19E6	5587 657003	MARIYA ROMANOVA	{"phone": "+70775396363"}
0005433960993	9D7CE5	9565 959007	LUIZA PAVLOVA	{"phone": "+70748062748"}
0005433960825	AD7313	8027 575780	NATALYA FADEEVA	{"email": "natalyafadeeva.1972@postgrespro.ru", "phone": "+70407073637"}
0005433960826	3E265B	1698 657672	ALEKSEY DMITRIEV	{"email": "admitriev.021970@postgrespro.ru", "phone": "+70113946778"}
0005433960827	C3099B	5376 380206	NIKOLAY GORBUNOV	{"email": "gorbunov_nikolay_26021978@postgrespro.ru", "phone": "+70745963367"}
0005433960828	5FFA48	5047 676000	SOFYA ZAKHAROVA	{"email": "zakharova_s_1972@postgrespro.ru", "phone": "+70722611966"}
0005433960829	5FFA48	7340 439829	TATYANA KOROLEVA	{"phone": "+70784936087"}
0005433960830	40B51F	8968 577487	ELENA SEMENOVA	{"phone": "+70732447628"}
0005433960831	40B51F	0557 891263	VITALIY FOMIN	{"phone": "+70355130492"}
0005433960832	66CCF5	3033 417153	ELLA PAVLOVA	{"phone": "+70637522305"}
0005433960833	396AA4	7265 168636	GENNADIY MEDVEDEV	{"email": "g.medvedev_091967@postgrespro.ru", "phone": "+70201162668"}
0005433960834	EF8707	0161 884986	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir.1970@postgrespro.ru", "phone": "+70744244823"}
0005433960835	D6B9E6	9326 230331	EVGENIYA NIKOLAEVA	{"phone": "+70503923574"}
0005433960836	0A0305	7786 980384	VALENTINA FROLOVA	{"email": "frolova_v.121965@postgrespro.ru", "phone": "+70424316421"}
0005433960837	0A0305	3915 419782	DARYA KOZLOVA	{"email": "darya.kozlova_1976@postgrespro.ru", "phone": "+70064884176"}
0005433960838	6B4AC1	5066 704598	RAMZIYA OVCHINNIKOVA	{"phone": "+70924260329"}
0005433960839	5B14DE	7636 870378	LIDIYA TIMOFEEVA	{"email": "l-timofeeva1985@postgrespro.ru", "phone": "+70743734880"}
0005433960840	3FD534	6460 625653	OLGA ORLOVA	{"email": "orlova-olga-06021972@postgrespro.ru", "phone": "+70434999725"}
0005433960841	DF2C94	6140 592123	YURIY VOROBEV	{"phone": "+70822111408"}
0005433960842	BF578D	2576 650972	LYUBOV ANISIMOVA	{"phone": "+70371523691"}
0005433960843	BF578D	2608 957158	NIKITA MOROZOV	{"phone": "+70029230381"}
0005433960844	ECDF3E	9763 931358	RAISA ANDREEVA	{"phone": "+70310220079"}
0005433960845	ECDF3E	6822 122114	GEORGIY ZAYCEV	{"email": "georgiyzaycev1967@postgrespro.ru", "phone": "+70864469679"}
0005433960846	9CF558	4990 030591	PETR GERASIMOV	{"phone": "+70956688668"}
0005433960847	C731E4	4519 262926	ARTEM GUSEV	{"phone": "+70492983601"}
0005433960848	9A44D9	9276 099646	NIKOLAY GAVRILOV	{"email": "gavrilov.n.16031974@postgrespro.ru", "phone": "+70913658377"}
0005433960849	A83481	9434 557951	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e-1968@postgrespro.ru", "phone": "+70678004287"}
0005433960850	448C7B	5502 273441	SVETLANA ILINA	{"phone": "+70686238250"}
0005433960851	9DE9CF	6802 203163	SVETLANA LUKYANOVA	{"phone": "+70604943918"}
0005433960852	9DE9CF	0438 101760	VIKTOR MIRONOV	{"email": "mironov.viktor_1976@postgrespro.ru", "phone": "+70788609648"}
0005433960853	1172BA	0876 342841	DANIIL IVANOV	{"email": "d.ivanov27121966@postgrespro.ru", "phone": "+70306477597"}
0005433960854	1172BA	7752 713227	SVETLANA POPOVA	{"email": "svetlana-popova-1979@postgrespro.ru", "phone": "+70665016002"}
0005433960855	7E46E6	7660 210139	ALEKSANDRA POLYAKOVA	{"email": "aleksandrapolyakova_071970@postgrespro.ru", "phone": "+70125652499"}
0005433960856	7481D7	6950 739782	NIKOLAY IVANOV	{"email": "ivanov-n-1973@postgrespro.ru", "phone": "+70134359958"}
0005433960857	9F096F	0172 026628	VALERIY PAVLOV	{"email": "pavlov_v-061961@postgrespro.ru", "phone": "+70111350133"}
0005433960858	9F096F	2227 314034	IRINA BELOVA	{"phone": "+70769309506"}
0005433960859	456105	3192 241758	IRINA TARASOVA	{"phone": "+70348212100"}
0005433960860	CE79C8	1959 524767	MIKHAIL NIKOLAEV	{"phone": "+70520178222"}
0005433960861	2A3BD1	3154 997723	NATALYA VLASOVA	{"email": "vlasova.n-1976@postgrespro.ru", "phone": "+70561071088"}
0005433960862	62438B	9718 116866	KRISTINA KUZNECOVA	{"email": "kkuznecova_1962@postgrespro.ru", "phone": "+70926673045"}
0005433960863	4F37EB	7330 658415	SERGEY GUSEV	{"email": "s_gusev-1966@postgrespro.ru", "phone": "+70442185780"}
0005433960864	B016F3	8770 052776	EKATERINA MOISEEVA	{"email": "moiseeva.ekaterina-041972@postgrespro.ru", "phone": "+70084291287"}
0005433960865	3E1B58	9390 515985	ARTEM VOLKOV	{"phone": "+70786961675"}
0005433960866	D2BC90	6999 780053	VERA NOVIKOVA	{"email": "novikovavera-27111978@postgrespro.ru", "phone": "+70656446316"}
0005433960867	D2BC90	2531 764782	IRINA EFREMOVA	{"phone": "+70041637235"}
0005433960868	55390E	0002 677164	VIKTOR TIKHONOV	{"email": "tikhonov-v_03061975@postgrespro.ru", "phone": "+70031408554"}
0005433960869	234FF5	6408 213594	ANATOLIY IVANOV	{"email": "a-ivanov.111974@postgrespro.ru", "phone": "+70205726541"}
0005433960870	E6B2B2	8676 067400	SERGEY ANDREEV	{"email": "andreev-sergey041973@postgrespro.ru", "phone": "+70068484914"}
0005433960871	2E8EA0	9614 668664	LIDIYA GUSEVA	{"email": "l.guseva_1982@postgrespro.ru", "phone": "+70025149513"}
0005433960872	7A5C36	7101 032502	MARINA PAVLOVA	{"email": "m.pavlova1970@postgrespro.ru", "phone": "+70163987065"}
0005433960873	2776F0	1820 545893	OLGA STEPANOVA	{"phone": "+70588745600"}
0005433960874	F42094	1301 678977	MARGARITA FADEEVA	{"email": "mfadeeva_19091979@postgrespro.ru", "phone": "+70247173550"}
0005433960875	F57283	8768 555704	SERGEY TIMOFEEV	{"email": "sergey_timofeev-1975@postgrespro.ru", "phone": "+70880126230"}
0005433960876	2E73B5	2309 520442	MAKSIM NOVIKOV	{"email": "novikovm.1971@postgrespro.ru", "phone": "+70474818469"}
0005433960877	54A3BA	3980 016231	GALINA VOROBEVA	{"phone": "+70135314786"}
0005433960878	54A3BA	7570 925455	NINA TIKHONOVA	{"phone": "+70372274501"}
0005433960879	B0F0B9	1823 069191	SVETLANA ZHURAVLEVA	{"phone": "+70188882330"}
0005433960880	B0F0B9	5294 101608	ELIZAVETA BELOVA	{"phone": "+70332632546"}
0005433960881	29C0BD	4629 487879	EDUARD ALEKSEEV	{"email": "ealekseev_03071967@postgrespro.ru", "phone": "+70788299173"}
0005433960882	13FCB5	9200 460062	NIKOLAY KOZLOV	{"email": "kozlovn22031968@postgrespro.ru", "phone": "+70143159076"}
0005433960883	13FCB5	5542 059981	ANASTASIYA FROLOVA	{"email": "anastasiya_frolova-101981@postgrespro.ru", "phone": "+70591936755"}
0005433960884	13FCB5	0611 266538	ARTEM NIKOLAEV	{"email": "artem_nikolaev_071979@postgrespro.ru", "phone": "+70343901242"}
0005433960885	2B7E52	7502 634748	MARIYA SIDOROVA	{"phone": "+70081963765"}
0005433960886	2B7E52	7360 028233	SERGEY BORISOV	{"phone": "+70461044573"}
0005433960887	8FAA85	3621 236687	EVGENIY STEPANOV	{"email": "stepanov-evgeniy.101970@postgrespro.ru", "phone": "+70590956199"}
0005433960888	E2F4DC	3962 764172	SERGEY SHEVCHENKO	{"email": "s-shevchenko_1967@postgrespro.ru", "phone": "+70822944772"}
0005433960889	AC4526	1434 317841	VASILIY POPOV	{"email": "popovvasiliy_1973@postgrespro.ru", "phone": "+70916360959"}
0005433960890	552733	4604 258321	VLADIMIR KUZMIN	{"phone": "+70141647043"}
0005433960891	ED651F	3640 111469	TATYANA YUDINA	{"phone": "+70295806545"}
0005433960892	ED651F	2167 320016	ANASTASIYA SAVELEVA	{"email": "anastasiya_saveleva.041975@postgrespro.ru", "phone": "+70193340310"}
0005433960893	189B39	9308 123755	NIKOLAY NAZAROV	{"phone": "+70103443110"}
0005433960894	189B39	0296 896943	ALEKSEY FEDOROV	{"phone": "+70552181933"}
0005433960895	66359A	3678 400454	ALEKSANDR KULIKOV	{"phone": "+70684908122"}
0005433960896	2633DC	5136 975368	GULFIYA GUSEVA	{"email": "guseva.g071976@postgrespro.ru", "phone": "+70689460686"}
0005433960897	2633DC	2737 340061	NIKITA GUSEV	{"email": "gusev-nikita-1975@postgrespro.ru", "phone": "+70029379676"}
0005433960898	A740B3	4462 158414	SVETLANA OSIPOVA	{"phone": "+70232076088"}
0005433960899	67AD81	2335 520174	SERGEY KULIKOV	{"email": "kulikovs-22011979@postgrespro.ru", "phone": "+70616646010"}
0005433960900	67AD81	7892 147712	MIKHAIL KUDRYASHOV	{"phone": "+70867529438"}
0005433960901	67AD81	9676 390168	ALEKSEY ALEKSEEV	{"phone": "+70790009792"}
0005433960902	86B08F	0644 215301	VIKTOR SIDOROV	{"email": "viktor-sidorov1981@postgrespro.ru", "phone": "+70400320857"}
0005433960903	09CCC7	1293 466985	PAVEL YAKOVLEV	{"email": "yakovlev_pavel.1974@postgrespro.ru", "phone": "+70929470632"}
0005433960904	9298D3	1598 089273	IRINA KUZNECOVA	{"email": "kuznecovai_1975@postgrespro.ru", "phone": "+70267155543"}
0005433960905	A360A9	9817 549959	PETR TIMOFEEV	{"email": "timofeev_p_23061974@postgrespro.ru", "phone": "+70420848665"}
0005433960906	3B8F47	3487 324318	TATYANA FEDOROVA	{"phone": "+70162126192"}
0005433960907	085ECE	9778 801228	MARIYA EGOROVA	{"email": "egorova_mariya-051981@postgrespro.ru", "phone": "+70765959163"}
0005433960908	09157D	3131 462622	MARINA NAUMOVA	{"email": "naumova_m_1962@postgrespro.ru", "phone": "+70259713607"}
0005433960909	46F484	3576 738475	YULIYA SIDOROVA	{"phone": "+70723489253"}
0005433960910	C91327	4805 934097	IRINA SIDOROVA	{"phone": "+70620012935"}
0005433960911	C91327	4112 963574	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana_1970@postgrespro.ru", "phone": "+70635798221"}
0005433960912	1DEADF	8304 670328	ALISA NAZAROVA	{"phone": "+70641899646"}
0005433960913	D3C4F6	4157 486716	SERGEY GRIGOREV	{"phone": "+70174920102"}
0005433960914	D3C4F6	5937 494670	NINA EFIMOVA	{"phone": "+70354127651"}
0005433960915	D3C4F6	4255 620547	SVETLANA ZHURAVLEVA	{"phone": "+70793540301"}
0005433960916	AA6BBB	8061 505611	VLADIMIR EGOROV	{"email": "egorovvladimir_031977@postgrespro.ru", "phone": "+70038774448"}
0005433960917	AA6BBB	1180 768512	NINA AKIMOVA	{"email": "akimova.n-27081966@postgrespro.ru", "phone": "+70500715759"}
0005433960918	AA6BBB	5004 734684	LEONID IVANOV	{"phone": "+70778953030"}
0005433960919	66FACE	0564 649914	SERGEY KULIKOV	{"phone": "+70564758534"}
0005433960920	E1BC54	3098 664513	VLADIMIR NAUMOV	{"email": "vladimir.naumov-071979@postgrespro.ru", "phone": "+70709306716"}
0005433960921	E1BC54	6441 869347	DMITRIY ALEKSANDROV	{"email": "dmitriy-aleksandrov29041974@postgrespro.ru", "phone": "+70399438594"}
0005433960922	277197	4926 929783	ELENA EGOROVA	{"email": "egorovaelena.05091973@postgrespro.ru", "phone": "+70101899113"}
0005433960923	277197	1530 446188	IGOR GORBUNOV	{"email": "igor_gorbunov.1976@postgrespro.ru", "phone": "+70449592656"}
0005433960924	0829CB	2832 270370	TATYANA KOROLEVA	{"phone": "+70684623513"}
0005433960925	358310	7075 099923	ALEKSEY DMITRIEV	{"phone": "+70811953357"}
0005433960926	1ABEC7	9462 699070	ELENA BARANOVA	{"email": "baranovaelena-17071983@postgrespro.ru", "phone": "+70686252393"}
0005433960927	59CEB7	1546 813040	MARIYA TROFIMOVA	{"email": "trofimova_mariya1965@postgrespro.ru", "phone": "+70884163498"}
0005433960928	0ED48C	4667 130697	ARKADIY VASILEV	{"email": "arkadiy_vasilev.1969@postgrespro.ru", "phone": "+70187176170"}
0005433960929	885051	4654 623645	MARINA YUDINA	{"phone": "+70462275732"}
0005433960930	87F2E8	3466 381196	SERGEY YAKOVLEV	{"email": "yakovlev_s011974@postgrespro.ru", "phone": "+70398263520"}
0005433960931	87F2E8	4174 590358	DARYA IVANOVA	{"phone": "+70123194141"}
0005433960932	08394C	8537 597985	ALEKSANDR KUZMIN	{"email": "kuzmin-a_18091966@postgrespro.ru", "phone": "+70925071820"}
0005433960933	0DAE3D	2165 682625	NURIYA PETROVA	{"phone": "+70261471886"}
0005433960934	840264	5884 333600	VLADIMIR ALEKSANDROV	{"phone": "+70476921454"}
0005433960935	840264	9142 521090	IRINA ALEKSANDROVA	{"email": "aleksandrova_irina24031961@postgrespro.ru", "phone": "+70056092275"}
0005433960936	C23178	7694 296376	TATYANA KRASNOVA	{"email": "krasnova.t.09121978@postgrespro.ru", "phone": "+70005865924"}
0005433960937	FC1E94	0136 381874	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev21111979@postgrespro.ru", "phone": "+70104888758"}
0005433960938	FC1E94	7862 930607	MAKSIM SOKOLOV	{"email": "m_sokolov1972@postgrespro.ru", "phone": "+70361237142"}
0005433960939	344F61	9661 060908	ALEKSANDR ROMANOV	{"email": "romanova15061969@postgrespro.ru", "phone": "+70110062898"}
0005433960940	344F61	1284 609441	ANNA TROFIMOVA	{"email": "trofimova_a.101978@postgrespro.ru", "phone": "+70829051579"}
0005433960941	1394AD	5581 625101	OLGA SIDOROVA	{"email": "sidorova-o1966@postgrespro.ru", "phone": "+70659564475"}
0005433960942	F0C739	3135 667938	VLADIMIR MOROZOV	{"phone": "+70839103586"}
0005433960943	7C501B	2426 416178	ELENA KULIKOVA	{"email": "kulikova_elena_1975@postgrespro.ru", "phone": "+70869651568"}
0005433960944	4067B6	3425 589737	NATALYA DMITRIEVA	{"phone": "+70665477698"}
0005433960945	AF2361	2758 089646	LYUBOV BELYAEVA	{"email": "l-belyaeva.121974@postgrespro.ru", "phone": "+70786529201"}
0005433960946	02B1EB	2494 254685	YULIYA ABRAMOVA	{"email": "yuliya_abramova_111977@postgrespro.ru", "phone": "+70980257274"}
0005433960947	873787	1132 294792	ALEKSANDR BELOV	{"email": "aleksandrbelov.20051979@postgrespro.ru", "phone": "+70016984428"}
0005433960948	E2E9A1	7057 595399	NINA NIKITINA	{"phone": "+70344387237"}
0005433960949	99ABDD	4602 047016	SERGEY KAZAKOV	{"phone": "+70115198767"}
0005433960950	6424DB	3326 662249	DINA KOROLEVA	{"email": "koroleva.dina1975@postgrespro.ru", "phone": "+70926906807"}
0005433960951	EC1E49	4827 973970	EVGENIY MATVEEV	{"phone": "+70360419784"}
0005433960952	8F3BFE	2576 565581	OLGA KARPOVA	{"email": "karpovaolga-1977@postgrespro.ru", "phone": "+70209737838"}
0005433960953	34381C	5945 374740	ALEKSANDR GRIGOREV	{"phone": "+70331148201"}
0005433960954	444D56	5124 967231	IRINA STEPANOVA	{"phone": "+70747994229"}
0005433960955	1532FA	9774 590705	VALERIY MATVEEV	{"email": "vmatveev.11021971@postgrespro.ru", "phone": "+70469364916"}
0005433960956	1532FA	6992 039675	IRINA KRASNOVA	{"email": "ikrasnova_26071977@postgrespro.ru", "phone": "+70592233532"}
0005433960957	9E33C1	6854 125875	DENIS NIKOLAEV	{"phone": "+70147255177"}
0005433960958	3B6C3C	8525 152906	NATALYA KOZLOVA	{"email": "nkozlova_30071971@postgrespro.ru", "phone": "+70158416546"}
0005433960959	AEAD5E	6094 300730	PAVEL VOROBEV	{"phone": "+70329744396"}
0005433960960	AEAD5E	6369 538105	GLEB ROMANOV	{"email": "romanovgleb.051981@postgrespro.ru", "phone": "+70279964588"}
0005433960961	AEAD5E	9157 961256	SERGEY NOVIKOV	{"phone": "+70384394595"}
0005433960962	F452E5	0365 890023	VLADIMIR MIKHAYLOV	{"phone": "+70931242627"}
0005433960963	F452E5	3911 561988	DARYA BORISOVA	{"email": "borisova.darya021985@postgrespro.ru", "phone": "+70946763317"}
0005433960964	711E9B	9214 049531	IRINA TIMOFEEVA	{"phone": "+70463804108"}
0005433960965	60D234	9461 068429	ANTONINA BORISOVA	{"phone": "+70363784525"}
0005433960966	60D234	5208 074680	ANDREY KUZMIN	{"phone": "+70561051770"}
0005433960967	A3728D	0879 264989	ELENA BORISOVA	{"phone": "+70343724512"}
0005433960968	7DBE4A	9030 151871	DMITRIY ZAYCEV	{"phone": "+70209708161"}
0005433960969	2F7905	7424 647377	EVGENIYA STEPANOVA	{"email": "stepanova.evgeniya_101969@postgrespro.ru", "phone": "+70457126688"}
0005433960970	51DAC9	5710 279092	ALENA IVANOVA	{"phone": "+70756605315"}
0005433960971	55001D	5130 146010	MARIYA TIKHONOVA	{"email": "tikhonova-m-20121967@postgrespro.ru", "phone": "+70790798913"}
0005433960972	55001D	7373 709835	NATALYA BOGDANOVA	{"email": "bogdanova_natalya.081978@postgrespro.ru", "phone": "+70265205102"}
0005433960973	337465	4781 844707	GENNADIY DMITRIEV	{"phone": "+70330103509"}
0005433960974	96D694	6422 100522	ALEKSEY KUZNECOV	{"phone": "+70011662216"}
0005433960975	B30EA4	5307 284177	ALENA SCHERBAKOVA	{"phone": "+70544832334"}
0005433960976	09EF24	3861 067567	VLADIMIR ALEKSEEV	{"email": "vladimiralekseev06041974@postgrespro.ru", "phone": "+70912243869"}
0005433960977	09EF24	3674 385421	SERGEY PAVLOV	{"email": "pavlov.sergey_20091966@postgrespro.ru", "phone": "+70303076911"}
0005433960978	1527D5	4722 347707	ANNA RODIONOVA	{"email": "anna.rodionova.1972@postgrespro.ru", "phone": "+70964357052"}
0005433960979	1527D5	1681 305860	VALERIYA PAVLOVA	{"email": "v.pavlova08081979@postgrespro.ru", "phone": "+70934250609"}
0005433960980	D5C213	1501 304021	VALERIY VOLKOV	{"email": "vvolkov_071980@postgrespro.ru", "phone": "+70833287065"}
0005433961103	A185B8	6950 767677	TIKHON KRASNOV	{"phone": "+70449495202"}
0005433960981	D561CA	7001 963572	NIKOLAY GUSEV	{"email": "nikolay.gusev08041977@postgrespro.ru", "phone": "+70796159705"}
0005433960982	5903CA	8902 209827	ANNA MELNIKOVA	{"email": "melnikovaanna-081984@postgrespro.ru", "phone": "+70053486999"}
0005433960983	5903CA	8512 982882	OKSANA ZHURAVLEVA	{"email": "o_zhuravleva26071970@postgrespro.ru", "phone": "+70280388918"}
0005433960984	109E48	3619 074906	EKATERINA TIMOFEEVA	{"phone": "+70423871056"}
0005433960985	109E48	3638 069045	VIKTOR ALEKSANDROV	{"phone": "+70037492646"}
0005433960986	282B8E	4102 553902	OLGA STEPANOVA	{"email": "o.stepanova-1996@postgrespro.ru", "phone": "+70995812361"}
0005433960987	282B8E	3154 389248	LYUBOV SOLOVEVA	{"email": "l-soloveva.081979@postgrespro.ru", "phone": "+70603104582"}
0005433960988	01DA80	5287 633308	EVGENIY KUZNECOV	{"phone": "+70225451860"}
0005433960989	5E7783	8135 049010	VLADIMIR BELOV	{"phone": "+70809005320"}
0005433960990	006EEC	5215 800214	ALEKSANDR SEMENOV	{"email": "a_semenov1981@postgrespro.ru", "phone": "+70315220817"}
0005433960991	12AAC4	2091 143081	ELENA TIMOFEEVA	{"email": "timofeevaelena1964@postgrespro.ru", "phone": "+70356149288"}
0005433960992	12AAC4	0764 646317	SVETLANA SIDOROVA	{"phone": "+70129987563"}
0005433960994	D057B9	4048 992147	LIDIYA FILIPPOVA	{"email": "filippova-l_1966@postgrespro.ru", "phone": "+70709845887"}
0005433960995	D057B9	8141 430636	SVETLANA BELOVA	{"phone": "+70274760170"}
0005433960996	DF649A	4435 303585	GALINA KOVALEVA	{"email": "galina-kovaleva.071971@postgrespro.ru", "phone": "+70997290180"}
0005433960997	3F897B	7211 431561	ALEKSANDR POPOV	{"email": "popov_aleksandr.1978@postgrespro.ru", "phone": "+70003749615"}
0005433960998	9E1424	8127 381383	NINA VOLKOVA	{"phone": "+70074688316"}
0005433960999	7B8996	9317 234686	ELENA MELNIKOVA	{"email": "elenamelnikova-04091963@postgrespro.ru", "phone": "+70500735298"}
0005433961000	7B8996	0080 476334	ILNAR ALEKSEEV	{"phone": "+70691887172"}
0005433961001	EADAF5	4760 300878	ALEKSANDR MIKHAYLOV	{"phone": "+70731904333"}
0005433961002	8D4024	6313 833157	VIKTOR KARPOV	{"phone": "+70168694431"}
0005433961003	E1EC4D	3021 018692	ANNA POTAPOVA	{"email": "potapova-anna_18051983@postgrespro.ru", "phone": "+70012269783"}
0005433961004	E1EC4D	4882 254164	YAROSLAV KONOVALOV	{"phone": "+70326160643"}
0005433961005	E1EC4D	3582 559475	EVGENIYA SCHERBAKOVA	{"phone": "+70097692052"}
0005433961006	6D4861	0843 225523	VLADIMIR MIKHAYLOV	{"email": "vladimirmikhaylov091989@postgrespro.ru", "phone": "+70233430515"}
0005433961007	33A9A5	1482 644234	ALEKSANDRA FROLOVA	{"email": "a-frolova.19051971@postgrespro.ru", "phone": "+70638191719"}
0005433961008	9779CE	3483 539296	DMITRIY KUDRYASHOV	{"email": "d-kudryashov-1969@postgrespro.ru", "phone": "+70458452574"}
0005433961009	9779CE	9633 285538	VASILIY SERGEEV	{"email": "sergeev-v1970@postgrespro.ru", "phone": "+70542847462"}
0005433961010	4EA29E	2175 503196	DMITRIY KRASNOV	{"email": "d-krasnov_1977@postgrespro.ru", "phone": "+70446746945"}
0005433961011	153756	8525 338952	VIKTOR SERGEEV	{"phone": "+70370528152"}
0005433961012	153756	9769 270073	MATVEY MARTYNOV	{"email": "m.martynov_1967@postgrespro.ru", "phone": "+70368219981"}
0005433961013	0D99F4	2766 143706	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov19031972@postgrespro.ru", "phone": "+70325920893"}
0005433961014	34AD42	0445 925122	ALEKSANDR KOZLOV	{"phone": "+70499142524"}
0005433961015	8D1D86	6809 831038	ALEKSANDR KUZMIN	{"phone": "+70849013948"}
0005433961016	8D1D86	6491 752557	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova_041983@postgrespro.ru", "phone": "+70895176163"}
0005433961017	B96FDA	9586 078181	VALENTINA IVANOVA	{"email": "valentina.ivanova.1968@postgrespro.ru", "phone": "+70394267498"}
0005433961018	F9A41B	1133 923357	ZINAIDA KOROLEVA	{"phone": "+70918145245"}
0005433961019	F9A41B	2122 071966	VLADIMIR ZAKHAROV	{"phone": "+70647387243"}
0005433961020	82F89B	6653 115319	DANIL NAZAROV	{"email": "nazarov_d-051971@postgrespro.ru", "phone": "+70640816596"}
0005433961021	3A9050	1978 693556	IRINA MOROZOVA	{"phone": "+70771807837"}
0005433961022	3A9050	5718 209342	LYUBOV NAZAROVA	{"email": "nazarova_lyubov.30101977@postgrespro.ru", "phone": "+70759259399"}
0005433961023	3D3D8B	5221 813916	VALENTINA PAVLOVA	{"phone": "+70071316901"}
0005433961024	3D3D8B	2635 347242	DMITRIY TIMOFEEV	{"phone": "+70933065667"}
0005433961025	1B801A	1885 865883	MAKSIM KULIKOV	{"email": "kulikov.m.1967@postgrespro.ru", "phone": "+70170112737"}
0005433961026	802F6F	3580 714749	KONSTANTIN YAKOVLEV	{"phone": "+70401750199"}
0005433961027	0C0609	1666 593495	NATALYA IVANOVA	{"phone": "+70581235784"}
0005433961028	0C0609	7722 043643	NINA PAVLOVA	{"email": "pavlova.n-07071977@postgrespro.ru", "phone": "+70977680622"}
0005433961029	6EE24D	0569 326158	IGOR BELOV	{"email": "igorbelov-051972@postgrespro.ru", "phone": "+70014867742"}
0005433961030	0EC252	0580 693344	NIKITA VOROBEV	{"email": "vorobev_nikita-1977@postgrespro.ru", "phone": "+70658048561"}
0005433961031	BC4E37	3580 969776	ELIZAVETA VASILEVA	{"email": "vasilevaelizaveta.1971@postgrespro.ru", "phone": "+70911831842"}
0005433961032	52FE7B	9118 489466	NATALYA ZOTOVA	{"email": "nzotova_1968@postgrespro.ru", "phone": "+70434245714"}
0005433961033	7B3F8A	5629 774642	TIMOFEY DAVYDOV	{"phone": "+70419599713"}
0005433961034	1EE11E	9119 118520	SVETLANA KUDRYASHOVA	{"phone": "+70018791218"}
0005433961035	75F726	6965 566226	MIKHAIL SEMENOV	{"phone": "+70574838700"}
0005433961036	817DC5	7158 035784	VYACHESLAV MARTYNOV	{"phone": "+70929547948"}
0005433961037	817DC5	4218 228697	TAMARA FADEEVA	{"email": "tamara_fadeeva_01011970@postgrespro.ru", "phone": "+70195948062"}
0005433961038	7DE9C5	6589 733510	NIKOLAY SERGEEV	{"email": "sergeev_nikolay-121969@postgrespro.ru", "phone": "+70881728082"}
0005433961039	23EDA2	6773 371909	ANDREY BARANOV	{"email": "baranov-andrey.101968@postgrespro.ru", "phone": "+70957768562"}
0005433961040	933442	9567 558051	YULIYA MEDVEDEVA	{"phone": "+70908653813"}
0005433961041	933442	0642 149707	PETR ZHUKOV	{"phone": "+70372307714"}
0005433961042	836FC8	8424 591775	ALEKSEY MEDVEDEV	{"email": "aleksey.medvedev.23051969@postgrespro.ru", "phone": "+70012926970"}
0005433961043	836FC8	0065 154096	RAISA SMIRNOVA	{"email": "smirnova_raisa20031974@postgrespro.ru", "phone": "+70355492292"}
0005433961044	2EF51A	5981 828338	SERGEY KRASNOV	{"email": "s-krasnov-1971@postgrespro.ru", "phone": "+70988361342"}
0005433961045	BCA338	8951 215448	EKATERINA SAVELEVA	{"phone": "+70208590406"}
0005433961046	BCA338	1422 048656	VIKTOR SIDOROV	{"phone": "+70213571919"}
0005433961047	DAA9EF	8189 674610	PELAGEYA PAVLOVA	{"phone": "+70439865978"}
0005433961048	DAA9EF	8710 283803	YURIY GUSEV	{"email": "gusevy-1969@postgrespro.ru", "phone": "+70944814139"}
0005433961049	485C8D	3708 427075	LIDIYA POPOVA	{"phone": "+70441843777"}
0005433961050	485C8D	2329 016694	MARIYA ANDREEVA	{"email": "andreeva-m-021965@postgrespro.ru", "phone": "+70733303367"}
0005433961051	8EC39A	5824 884646	LIDIYA ALEKSANDROVA	{"phone": "+70957085841"}
0005433961052	355597	4563 248887	VLADIMIR MAKSIMOV	{"email": "vladimir.maksimov.14101969@postgrespro.ru", "phone": "+70898449664"}
0005433961053	01C77F	8781 199984	DMITRIY POPOV	{"phone": "+70179798888"}
0005433961054	9823FC	2918 727503	SVETLANA NIKIFOROVA	{"email": "svetlananikiforova_1961@postgrespro.ru", "phone": "+70154883256"}
0005433961055	6A8C00	8923 752858	IGOR VOLKOV	{"phone": "+70863714103"}
0005433961056	3D5D9C	4118 023535	VASILIY KONOVALOV	{"phone": "+70533120909"}
0005433961057	3D5D9C	9318 516145	VALENTINA VOROBEVA	{"phone": "+70246310159"}
0005433961058	86EF95	9291 026651	GALINA KOVALEVA	{"phone": "+70106078815"}
0005433961059	230EAC	7385 502985	IVAN YAKOVLEV	{"email": "yakovlevi.121976@postgrespro.ru", "phone": "+70099526175"}
0005433961060	0BD29A	4505 674292	ANNA EGOROVA	{"phone": "+70548722621"}
0005433961061	DF0C79	3173 055439	GALINA ZAYCEVA	{"email": "zayceva.galina-06031976@postgrespro.ru", "phone": "+70555771596"}
0005433961062	50E890	8272 529924	MAYYA VLASOVA	{"phone": "+70658575120"}
0005433961063	B260ED	6583 458537	ZOYA TARASOVA	{"email": "tarasova.zoya1969@postgrespro.ru", "phone": "+70993121089"}
0005433961064	41782A	3637 683275	OLGA ABRAMOVA	{"email": "abramova.o_1976@postgrespro.ru", "phone": "+70390002740"}
0005433961065	6E00C7	3514 365833	RAISA MAKAROVA	{"email": "raisamakarova101966@postgrespro.ru", "phone": "+70428571811"}
0005433961066	771C99	0585 522540	VASILIY SCHERBAKOV	{"email": "scherbakov-v02111965@postgrespro.ru", "phone": "+70156739248"}
0005433961067	771C99	6529 413104	TATYANA KOZLOVA	{"email": "tatyana.kozlova_16011977@postgrespro.ru", "phone": "+70064260971"}
0005433961068	141AC0	2090 514301	NADEZHDA BELOVA	{"phone": "+70456024581"}
0005433961069	141AC0	7320 310674	MIKHAIL VLASOV	{"phone": "+70143138405"}
0005433961070	8C2081	5609 200357	ROMAN KOZLOV	{"email": "kozlov-roman.111966@postgrespro.ru", "phone": "+70529279223"}
0005433961071	5628D8	3636 858621	IGOR VLASOV	{"phone": "+70988931056"}
0005433961072	5628D8	6835 688553	VITALIY KRASNOV	{"phone": "+70957587014"}
0005433961073	CD26A2	2363 773830	YAKOV ANTONOV	{"email": "yakov.antonov_091975@postgrespro.ru", "phone": "+70197953224"}
0005433961074	79F186	2125 079627	ARINA LEBEDEVA	{"phone": "+70435720376"}
0005433961075	82EB1A	9372 368402	NIKITA VOLKOV	{"email": "n-volkov-101980@postgrespro.ru", "phone": "+70506762320"}
0005433961076	29FB41	8070 555073	PRASKOVYA FILIPPOVA	{"phone": "+70447459517"}
0005433961077	29FB41	7618 625230	ALEKSANDR ZAKHAROV	{"phone": "+70256387619"}
0005433961078	78589B	7432 342529	ALEKSEY SIDOROV	{"phone": "+70307980839"}
0005433961079	78589B	2988 309389	VALENTINA PETROVA	{"phone": "+70077355503"}
0005433961080	78589B	6659 500049	DENIS FEDOTOV	{"email": "fedotov.d.1978@postgrespro.ru", "phone": "+70735056488"}
0005433961081	C8465A	5056 502256	VALERIY SEMENOV	{"email": "semenov-valeriy31031972@postgrespro.ru", "phone": "+70594333558"}
0005433961082	C8465A	2020 179545	ALEKSANDR MOROZOV	{"email": "aleksandr-morozov_021974@postgrespro.ru", "phone": "+70045784084"}
0005433961083	7D2B1D	0744 175670	RUSLAN STEPANOV	{"phone": "+70677110337"}
0005433961084	C22965	4307 851656	ANASTASIYA DMITRIEVA	{"email": "anastasiya.dmitrieva-08101969@postgrespro.ru", "phone": "+70302913982"}
0005433961085	527420	5636 810421	SERGEY MAKSIMOV	{"email": "maksimov_sergey-1973@postgrespro.ru", "phone": "+70904286913"}
0005433961086	B3AE68	5623 970645	EKATERINA ISAEVA	{"phone": "+70537925440"}
0005433961087	AB8CA5	5916 199487	EVGENIY DENISOV	{"phone": "+70629200433"}
0005433961088	650D6E	3945 968394	NINA POPOVA	{"phone": "+70716572028"}
0005433961089	650D6E	6342 358505	EDUARD BORISOV	{"email": "borisov_eduard08081967@postgrespro.ru", "phone": "+70716345528"}
0005433961090	650D6E	1086 744714	DMITRIY BORISOV	{"phone": "+70837747423"}
0005433961091	492483	3137 814978	SVETLANA MARTYNOVA	{"email": "smartynova_1972@postgrespro.ru", "phone": "+70895034171"}
0005433961092	F8B3FD	2923 045151	ANDREY ZAYCEV	{"phone": "+70314293931"}
0005433961093	419E04	5251 949777	VYACHESLAV ZAKHAROV	{"phone": "+70757541180"}
0005433961094	419E04	8524 879385	MARIYA SOLOVEVA	{"email": "msoloveva-10071969@postgrespro.ru", "phone": "+70998143017"}
0005433961095	94F51A	0247 529818	NINA IVANOVA	{"phone": "+70902635806"}
0005433961096	A8C9D9	5028 426104	YULIYA SOLOVEVA	{"email": "yuliyasoloveva1969@postgrespro.ru", "phone": "+70964013453"}
0005433961097	A8C9D9	0968 511480	ALEKSANDR STEPANOV	{"email": "a.stepanov.12121976@postgrespro.ru", "phone": "+70549893339"}
0005433961098	A8C9D9	8002 343945	ANTON GERASIMOV	{"phone": "+70049832937"}
0005433961099	B57AFE	2563 200651	LILIYA ZHUKOVA	{"email": "l-zhukova.04081969@postgrespro.ru", "phone": "+70106668063"}
0005433961100	78A581	7193 555399	SERGEY KONOVALOV	{"email": "konovalov-sergey-09011974@postgrespro.ru", "phone": "+70920130073"}
0005433961101	78A581	1511 289750	ANNA KUZNECOVA	{"phone": "+70117807184"}
0005433961102	F4C8E7	9576 079802	ILYA RODIONOV	{"phone": "+70829194184"}
0005433961104	A185B8	6135 447799	VIKTOR ILIN	{"email": "ilinv-071961@postgrespro.ru", "phone": "+70516435110"}
0005433961105	1C1EC4	7957 389140	IGOR STEPANOV	{"email": "i_stepanov11101973@postgrespro.ru", "phone": "+70667181845"}
0005433961106	110078	4753 752458	DMITRIY ZAKHAROV	{"phone": "+70131214421"}
0005433961107	DAC715	7686 191615	VALERIY ORLOV	{"email": "valeriy.orlov_18091963@postgrespro.ru", "phone": "+70328546488"}
0005433961108	FC6909	4528 500452	TAMARA POTAPOVA	{"email": "potapova-t-14021978@postgrespro.ru", "phone": "+70681604634"}
0005433961109	695AC3	8289 621384	ALEKSANDR IVANOV	{"phone": "+70853207720"}
0005433961110	D46D1A	5674 700728	ELENA SCHERBAKOVA	{"email": "elenascherbakova_03111978@postgrespro.ru", "phone": "+70615021760"}
0005433961111	D46D1A	7695 679780	DMITRIY MATVEEV	{"email": "d_matveev.1976@postgrespro.ru", "phone": "+70910666949"}
0005433961112	4619C7	5861 751205	NADEZHDA MAKAROVA	{"email": "nadezhda-makarova.051975@postgrespro.ru", "phone": "+70960117111"}
0005433961113	4619C7	9366 514664	INNA LAZAREVA	{"email": "lazarevainna_101992@postgrespro.ru", "phone": "+70981475940"}
0005433961114	ADC5B1	2652 009656	MARIYA YAKOVLEVA	{"phone": "+70311673780"}
0005433961115	ADC5B1	6676 622100	EKATERINA ROMANOVA	{"phone": "+70476964331"}
0005433961116	ADC5B1	2780 773289	OLGA ZAYCEVA	{"phone": "+70227119835"}
0005433961117	512A67	1646 887194	OLEG ISAEV	{"phone": "+70511800767"}
0005433961118	512A67	3741 093904	VITALIY NIKOLAEV	{"phone": "+70469008917"}
0005433961119	8AF72B	2355 663434	VALENTIN BELOV	{"email": "belov-valentin-1960@postgrespro.ru", "phone": "+70643883775"}
0005433961120	8AF72B	7546 547264	DMITRIY CHERNOV	{"phone": "+70781527653"}
0005433961121	489BB2	3384 304172	ELENA ANISIMOVA	{"email": "anisimova_elena.21051972@postgrespro.ru", "phone": "+70374088781"}
0005433961122	0CA32A	2245 475823	IVAN FROLOV	{"phone": "+70958696839"}
0005433961123	0CA32A	8140 300369	MIKHAIL PAVLOV	{"phone": "+70019629219"}
0005433961124	6C7649	0915 538526	VLADIMIR SCHERBAKOV	{"phone": "+70926794828"}
0005433961125	1E1AC2	5796 608374	TAMARA ANISIMOVA	{"phone": "+70135098738"}
0005433961126	83DECC	5496 474427	NIKOLAY GAVRILOV	{"email": "nikolay-gavrilov_121967@postgrespro.ru", "phone": "+70634582547"}
0005433961127	83DECC	8082 277067	NATALYA SERGEEVA	{"phone": "+70014262958"}
0005433961128	9923A5	2549 100751	EKATERINA TITOVA	{"email": "ekaterina.titova111974@postgrespro.ru", "phone": "+70433299506"}
0005433961129	6B2BA1	5885 610220	MIKHAIL MELNIKOV	{"email": "melnikovmikhail.1974@postgrespro.ru", "phone": "+70431197939"}
0005433961130	6B2BA1	7886 585189	DARYA FILIPPOVA	{"phone": "+70336878373"}
0005433961131	14E04C	4174 658802	ILYA SHEVCHENKO	{"phone": "+70720019971"}
0005433961132	DAEC5C	3241 774648	YURIY MOROZOV	{"email": "morozov.y.24061976@postgrespro.ru", "phone": "+70457214802"}
0005433961133	B3BF81	5404 059317	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr-30111973@postgrespro.ru", "phone": "+70537538262"}
0005433961134	B3BF81	1838 559622	ALEKSANDR BELOV	{"phone": "+70233990067"}
0005433961135	D09D81	3345 650891	ROMAN EGOROV	{"email": "egorov_roman03121963@postgrespro.ru", "phone": "+70896365668"}
0005433961136	8B897A	3931 284901	ALEKSANDR KOROLEV	{"email": "a-korolev-071972@postgrespro.ru", "phone": "+70884119805"}
0005433961137	8B897A	8787 614550	ZINAIDA SOLOVEVA	{"phone": "+70280630236"}
0005433961138	6CFF37	8105 804730	ELENA MARTYNOVA	{"phone": "+70868787733"}
0005433961139	6CFF37	0511 874312	SERGEY KULIKOV	{"phone": "+70433922541"}
0005433961140	6CFF37	2536 595020	MAKSIM FROLOV	{"email": "maksimfrolov.1965@postgrespro.ru", "phone": "+70882287883"}
0005433961141	F5C46D	5897 244756	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr101981@postgrespro.ru", "phone": "+70261488466"}
0005433961142	E1B989	3236 926429	LYUDMILA FROLOVA	{"phone": "+70648049778"}
0005433961143	3D65DE	8542 264949	NATALYA ZAYCEVA	{"phone": "+70110049076"}
0005433961144	9D99DC	6567 516881	NATALYA NOVIKOVA	{"email": "novikova_natalya_27111960@postgrespro.ru", "phone": "+70453309973"}
0005433961145	2ACD52	7953 833550	IRINA KOZLOVA	{"email": "irina.kozlova_13091974@postgrespro.ru", "phone": "+70621831192"}
0005433961146	511D23	4425 748588	VARVARA POTAPOVA	{"phone": "+70095117871"}
0005433961147	4C50A6	6545 929532	VENERA ERMAKOVA	{"email": "ermakovavenera.1987@postgrespro.ru", "phone": "+70748310231"}
0005433961148	4C50A6	2087 982896	MARIYA POLYAKOVA	{"phone": "+70476866482"}
0005433961149	6CAD89	1837 050977	VALENTINA NAZAROVA	{"email": "nazarovavalentina-1964@postgrespro.ru", "phone": "+70125688482"}
0005433961150	6CAD89	0874 661299	SABINA VASILEVA	{"phone": "+70677053565"}
0005433961151	B80A8E	6886 672823	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-021969@postgrespro.ru", "phone": "+70143196154"}
0005433961152	B4CA95	1171 278289	VITALIY RODIONOV	{"email": "vitaliy-rodionov_081967@postgrespro.ru", "phone": "+70394336852"}
0005433961153	B14AC5	9057 011638	GALINA ZHURAVLEVA	{"email": "zhuravlevagalina_1974@postgrespro.ru", "phone": "+70573051597"}
0005433961154	8ED979	6062 708110	NATALYA AFANASEVA	{"phone": "+70598857788"}
0005433961155	8E4B25	6648 249948	NIKOLAY MOISEEV	{"phone": "+70019225753"}
0005433961156	8E4B25	2085 944411	EVGENIY POPOV	{"phone": "+70005481080"}
0005433961157	8E4B25	4108 581054	YURIY MOROZOV	{"email": "yuriymorozov_121975@postgrespro.ru", "phone": "+70870710927"}
0005433961158	0E59D4	6417 160747	DINA ZOTOVA	{"phone": "+70245384217"}
0005433961159	8B8FD8	9710 300819	ANASTASIYA TARASOVA	{"phone": "+70593952827"}
0005433961160	8B8FD8	9851 261373	VLADIMIR SIDOROV	{"phone": "+70424133284"}
0005433961161	3999E7	5640 473284	VLADIMIR KARPOV	{"email": "vladimir.karpov_061974@postgrespro.ru", "phone": "+70061213084"}
0005433961162	3999E7	2029 194546	ALEKSEY KOZLOV	{"phone": "+70782368765"}
0005433961163	124353	6616 454775	NATALYA KUDRYASHOVA	{"email": "natalyakudryashova1967@postgrespro.ru", "phone": "+70574040471"}
0005433961164	99DB72	0980 984093	VIKTOR KUZNECOV	{"phone": "+70991439861"}
0005433961165	F1A048	3566 243996	OLEG ALEKSEEV	{"email": "o_alekseev.04071966@postgrespro.ru", "phone": "+70106750942"}
0005433961166	760D44	6024 322419	GENNADIY RODIONOV	{"phone": "+70390840528"}
0005433961167	9881D0	3768 791620	GALINA ORLOVA	{"phone": "+70837229707"}
0005433961168	9881D0	9550 689491	TATYANA NIKIFOROVA	{"phone": "+70046911077"}
0005433961169	9881D0	5971 769822	LARISA PAVLOVA	{"phone": "+70343092360"}
0005433961170	12406B	3646 898896	TATYANA MAKSIMOVA	{"phone": "+70999881368"}
0005433961171	5F253D	7816 308106	NIKOLAY ORLOV	{"email": "orlov_nikolay-24111980@postgrespro.ru", "phone": "+70386354004"}
0005433961172	1FD2AD	6187 431378	ANDREY FROLOV	{"phone": "+70065692486"}
0005433961173	3CF369	3893 384740	GERMAN NIKOLAEV	{"email": "german.nikolaev1975@postgrespro.ru", "phone": "+70604179682"}
0005433961174	3CF369	2655 195358	OLGA CHERNOVA	{"phone": "+70572046079"}
0005433961175	7B7DCB	7669 323053	ANNA ROMANOVA	{"email": "a-romanova.1978@postgrespro.ru", "phone": "+70818485536"}
0005433961176	71E68F	3815 353003	RAISA VLASOVA	{"email": "raisa.vlasova_1969@postgrespro.ru", "phone": "+70330547144"}
0005433961177	7E7F09	3642 281374	EKATERINA ZAKHAROVA	{"email": "zakharova_ekaterina14081977@postgrespro.ru", "phone": "+70353566987"}
0005433961178	7E7F09	9841 312197	ELENA KALININA	{"phone": "+70388275861"}
0005433961179	5420E7	4240 735906	RASHID KUZNECOV	{"phone": "+70890569974"}
0005433961180	9A252B	7333 983311	MIKHAIL DAVYDOV	{"email": "m_davydov_061961@postgrespro.ru", "phone": "+70281106968"}
0005433961181	6DF953	8575 560900	ELENA KUZNECOVA	{"email": "e_kuznecova_1961@postgrespro.ru", "phone": "+70508640936"}
0005433961182	C39F07	1847 952885	DMITRIY EGOROV	{"phone": "+70936009694"}
0005433961183	BB761F	2210 417979	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-tatyana_041972@postgrespro.ru", "phone": "+70935984212"}
0005433961184	BA548A	3989 075390	VALENTINA ABRAMOVA	{"phone": "+70122408372"}
0005433961185	8000BA	3206 239261	YULIYA KUZNECOVA	{"phone": "+70979843297"}
0005433961186	3C15B9	5179 476898	DMITRIY MIKHAYLOV	{"phone": "+70097998427"}
0005433961187	D741D4	6548 978666	SERGEY ROMANOV	{"phone": "+70122099007"}
0005433961188	D741D4	6484 761891	DMITRIY OSIPOV	{"phone": "+70789510952"}
0005433961189	D741D4	9155 600960	IVAN DENISOV	{"email": "denisov.i.15101966@postgrespro.ru", "phone": "+70759406901"}
0005433961190	6D5168	9291 890211	ANNA ORLOVA	{"phone": "+70483084263"}
0005433961191	6D5168	9393 728665	EVGENIYA NESTEROVA	{"email": "nesterova.e_051986@postgrespro.ru", "phone": "+70786311966"}
0005433961192	ADD4D3	1289 977085	GALINA ALEKSEEVA	{"email": "galekseeva_1964@postgrespro.ru", "phone": "+70676662600"}
0005433961193	B7D627	1999 131728	TATYANA CHERNOVA	{"email": "chernova-tatyana.1969@postgrespro.ru", "phone": "+70197294071"}
0005433961194	B7D627	1923 553102	ARTEM ZAYCEV	{"email": "zaycev_artem_13081976@postgrespro.ru", "phone": "+70429208624"}
0005433961195	B7D627	6241 661467	DMITRIY PETROV	{"phone": "+70467933865"}
0005433961196	B7D627	6493 195308	ALEKSANDR OSIPOV	{"phone": "+70666988147"}
0005433961197	B7D627	1044 182960	YURIY ANDREEV	{"email": "yuriy_andreev.061966@postgrespro.ru", "phone": "+70662723025"}
0005433961198	D17C32	6705 276019	DMITRIY KOZLOV	{"email": "dmitriy-kozlov_1969@postgrespro.ru", "phone": "+70863696089"}
0005433961199	23A267	0178 098886	MAKSIM ZAKHAROV	{"email": "zakharovm.121971@postgrespro.ru", "phone": "+70234535665"}
0005433961200	AA855B	8056 452663	SVETLANA KRASNOVA	{"email": "krasnova-svetlana-26041973@postgrespro.ru", "phone": "+70785681122"}
0005433961201	CCDC43	5030 335560	LARISA YUDINA	{"phone": "+70314648492"}
0005433961202	E7311F	8889 949070	EKATERINA MASLOVA	{"email": "maslova.ekaterina_18071964@postgrespro.ru", "phone": "+70945183155"}
0005433961203	5058D1	7540 803036	ANASTASIYA RYABOVA	{"phone": "+70326641255"}
0005433961204	E33308	8853 048043	LIDIYA FILIPPOVA	{"email": "lidiyafilippova1972@postgrespro.ru", "phone": "+70923209131"}
0005433961205	5F12D7	0725 987848	MAKSIM KULIKOV	{"phone": "+70180127368"}
0005433961206	77E828	3025 395294	ROMAN SOROKIN	{"phone": "+70452330247"}
0005433961207	77E828	6780 704893	ALENA VOROBEVA	{"email": "alenavorobeva17011971@postgrespro.ru", "phone": "+70844744094"}
0005433961208	77E828	3926 415508	ALEKSEY KISELEV	{"phone": "+70859544522"}
0005433961209	128D09	9729 878716	MARIYA NIKOLAEVA	{"email": "nikolaeva-m1985@postgrespro.ru", "phone": "+70497714935"}
0005433961210	2FB674	1201 304960	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay_061971@postgrespro.ru", "phone": "+70093883880"}
0005433961211	6A18F3	9581 583953	VLADIMIR FOMIN	{"phone": "+70612716335"}
0005433961212	C209ED	5464 967856	ALEKSANDR POPOV	{"phone": "+70207905441"}
0005433961213	C209ED	0653 718834	STANISLAV MIRONOV	{"phone": "+70061705348"}
0005433961214	BE69F5	2920 115982	MIKHAIL MARTYNOV	{"email": "mikhail_martynov_09021985@postgrespro.ru", "phone": "+70150627028"}
0005433961215	F0729A	3870 642966	KLAVDIYA AFANASEVA	{"email": "k-afanaseva111966@postgrespro.ru", "phone": "+70811027006"}
0005433961216	98D6DD	9937 977619	ALEKSEY KUZNECOV	{"phone": "+70688827254"}
0005433961217	D36C25	0258 250032	PAVEL POPOV	{"email": "popov-pavel1971@postgrespro.ru", "phone": "+70926618264"}
0005433961218	CA2F59	1749 622402	DARYA ILINA	{"email": "ilina-darya.091972@postgrespro.ru", "phone": "+70699210378"}
0005433961219	ED54E5	6896 499590	ANDREY FEDOTOV	{"email": "andreyfedotov041975@postgrespro.ru", "phone": "+70474996175"}
0005433961220	E22AFE	2984 276570	ALEKSANDR DAVYDOV	{"phone": "+70106819352"}
0005433961221	8F7D8D	1375 751829	YURIY DMITRIEV	{"email": "dmitriev.yuriy-01011962@postgrespro.ru", "phone": "+70174935528"}
0005433961222	F94EA1	4723 815014	LIDIYA DAVYDOVA	{"phone": "+70439602629"}
0005433961223	3B7D95	5561 001378	IRINA KONOVALOVA	{"phone": "+70500632765"}
0005433961224	3B7D95	9522 245458	ANNA FEDOROVA	{"email": "fedorovaanna28051979@postgrespro.ru", "phone": "+70222586031"}
0005433961225	24D44F	2226 946117	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov.1975@postgrespro.ru", "phone": "+70922811980"}
0005433961226	EB611D	2578 111887	ANDREY IVANOV	{"email": "a_ivanov_06111980@postgrespro.ru", "phone": "+70158052694"}
0005433961227	D941C9	2992 848966	PAVEL KAZAKOV	{"email": "kazakov.pavel_1969@postgrespro.ru", "phone": "+70895011061"}
0005433961228	39870F	0040 524186	ALEKSEY PETROV	{"phone": "+70479837679"}
0005433961229	5B8F55	1733 928933	NIKOLAY NIKOLAEV	{"email": "nikolaev_n.29091955@postgrespro.ru", "phone": "+70311906179"}
0005433961230	5B8F55	5198 291396	OLEG KOZLOV	{"email": "oleg-kozlov_25111980@postgrespro.ru", "phone": "+70620604144"}
0005433961231	726B82	0544 346617	ALEKSANDRA VASILEVA	{"email": "vasileva_aleksandra.111981@postgrespro.ru", "phone": "+70175825955"}
0005433961232	BCC85A	9609 584895	LYUDMILA PETROVA	{"email": "l-petrova_1970@postgrespro.ru", "phone": "+70061708203"}
0005433961233	14E4A0	9910 518993	ALEKSANDR OSIPOV	{"phone": "+70461148752"}
0005433961234	62D9B9	1028 310948	OLGA BELOVA	{"email": "olga_belova21061958@postgrespro.ru", "phone": "+70038466176"}
0005433961235	AA3574	7120 778259	YULIYA ANDREEVA	{"email": "andreeva-yuliya27021970@postgrespro.ru", "phone": "+70369716989"}
0005433961236	AA3574	9672 350860	ANNA SERGEEVA	{"email": "annasergeeva-011980@postgrespro.ru", "phone": "+70956367263"}
0005433961237	DFAA10	6045 680014	LYUDMILA FEDOROVA	{"email": "fedoroval_021972@postgrespro.ru", "phone": "+70969147004"}
0005433961238	7A1288	1643 041853	OLGA NAZAROVA	{"phone": "+70078008090"}
0005433961239	7A1288	9509 208279	ANASTASIYA ROMANOVA	{"phone": "+70017249406"}
0005433961240	7A1288	3631 339773	EVGENIYA PAVLOVA	{"phone": "+70872290053"}
0005433961241	47EABD	7189 910777	MARIYA POPOVA	{"email": "m.popova.23051974@postgrespro.ru", "phone": "+70746514661"}
0005433961242	2B0D44	7193 552936	VERA MIRONOVA	{"email": "mironova-vera_121971@postgrespro.ru", "phone": "+70181809881"}
0005433961243	A3E260	5356 711483	VITALIY PAVLOV	{"email": "pavlov.v.11091969@postgrespro.ru", "phone": "+70631023570"}
0005433961244	8A3077	1123 709151	EKATERINA POPOVA	{"email": "popovaekaterina.29051963@postgrespro.ru", "phone": "+70986699118"}
0005433961245	7BBFF2	0747 082280	ANTON IVANOV	{"email": "anton-ivanov.28111971@postgrespro.ru", "phone": "+70547955732"}
0005433961246	2A7E06	4015 922431	NIKOLAY ANDREEV	{"email": "andreevn1962@postgrespro.ru", "phone": "+70816725069"}
0005433961247	66E898	7393 570968	ANDREY KUZNECOV	{"email": "andreykuznecov.10091966@postgrespro.ru", "phone": "+70491248787"}
0005433961248	66E898	7709 175528	VERONIKA AKIMOVA	{"email": "veronika-akimova.021974@postgrespro.ru", "phone": "+70778890804"}
0005433961249	36F566	7428 823129	IRINA NOVIKOVA	{"email": "irina.novikova_1966@postgrespro.ru", "phone": "+70081704445"}
0005433961250	98F71A	2105 878913	NATALYA NIKIFOROVA	{"phone": "+70065870739"}
0005433961251	8E9C9D	5927 240874	TATYANA TARASOVA	{"email": "tarasova-tatyana.1960@postgrespro.ru", "phone": "+70075851125"}
0005433961252	B0DA27	3212 924517	VASILIY SOROKIN	{"phone": "+70884547444"}
0005433961253	B0DA27	5144 043227	IRINA NAUMOVA	{"phone": "+70645754448"}
0005433961254	D57112	3368 733542	GALINA KOROLEVA	{"email": "galina.koroleva.071972@postgrespro.ru", "phone": "+70450320073"}
0005433961255	18EF90	2628 984310	LYUDMILA ROMANOVA	{"phone": "+70462119729"}
0005433961256	9B1F2B	6559 060212	ELENA NOVIKOVA	{"email": "elena.novikova.1971@postgrespro.ru", "phone": "+70723888684"}
0005433961257	9B1F2B	4585 960659	OLGA KAZAKOVA	{"phone": "+70630257461"}
0005433961258	D61550	4225 426760	IVAN ANTONOV	{"email": "antonovivan_121963@postgrespro.ru", "phone": "+70052142684"}
0005433961259	D61550	2435 390121	SEMEN GORBUNOV	{"phone": "+70795197379"}
0005433961260	167958	6774 436260	TAISIYA SCHERBAKOVA	{"email": "taisiya_scherbakova.1973@postgrespro.ru", "phone": "+70285113541"}
0005433961261	74F6B4	9014 008603	EKATERINA SCHERBAKOVA	{"email": "ekaterina.scherbakova-20061968@postgrespro.ru", "phone": "+70231319506"}
0005433961262	74F6B4	7020 319144	NINA MARTYNOVA	{"phone": "+70647418524"}
0005433961263	DBE12D	2401 105209	ANNA NESTEROVA	{"phone": "+70786561435"}
0005433961264	5997E1	1567 184006	ANASTASIYA SAVELEVA	{"email": "anastasiya-saveleva1972@postgrespro.ru", "phone": "+70475807224"}
0005433961265	DF91AE	7830 038187	ALEKSANDR KONOVALOV	{"phone": "+70850863081"}
0005433961266	DF91AE	1696 662526	ANDREY KOZLOV	{"email": "kozlov.a.071966@postgrespro.ru", "phone": "+70318633358"}
0005433961267	DF91AE	1735 014104	STANISLAV ISAEV	{"email": "isaevstanislav_09031981@postgrespro.ru", "phone": "+70308541690"}
0005433961268	5C0F5F	1072 126949	SVETLANA RODIONOVA	{"email": "s_rodionova_111983@postgrespro.ru", "phone": "+70950318057"}
0005433961269	AC252C	9921 849675	DMITRIY VLASOV	{"email": "vlasov-d.061967@postgrespro.ru", "phone": "+70679152698"}
0005433961270	AC252C	9707 846614	ANASTASIYA ZAKHAROVA	{"email": "azakharova_1970@postgrespro.ru", "phone": "+70155152485"}
0005433961271	F855FD	8705 802129	ANDREY BARANOV	{"phone": "+70515004728"}
0005433961272	F855FD	8798 730364	ALEKSANDR MELNIKOV	{"email": "aleksandr_melnikov-1963@postgrespro.ru", "phone": "+70880513974"}
0005433961273	36C275	3242 690324	NINA KARPOVA	{"phone": "+70021143969"}
0005433961274	389342	3161 483273	TAMARA EFREMOVA	{"phone": "+70488118132"}
0005433961275	389342	8013 048105	NIKOLAY RODIONOV	{"phone": "+70990629639"}
0005433961276	2CA1C4	0316 236251	VALERIY POPOV	{"email": "vpopov-1968@postgrespro.ru", "phone": "+70914083754"}
0005433961277	2CA1C4	2394 281059	DMITRIY MAKAROV	{"phone": "+70484176821"}
0005433961278	3903EA	7856 247845	KRISTINA AFANASEVA	{"phone": "+70564915611"}
0005433961279	74D3DC	0452 688091	VALENTINA GUSEVA	{"phone": "+70384515243"}
0005433961280	8EAEF9	0490 850116	ALEKSEY FROLOV	{"phone": "+70612087086"}
0005433961281	F20769	8222 881230	PAVEL ILIN	{"email": "p-ilin_1967@postgrespro.ru", "phone": "+70098465736"}
0005433961282	637DEE	0553 865577	ALEKSEY SCHERBAKOV	{"phone": "+70126732571"}
0005433961283	169108	5160 862154	ALEKSEY ILIN	{"email": "ailin.22061970@postgrespro.ru", "phone": "+70098701589"}
0005433961284	169108	7153 511529	LYUBOV SAVELEVA	{"email": "saveleva_l101976@postgrespro.ru", "phone": "+70749989661"}
0005433961285	F10F4E	1167 820363	VALERIY GAVRILOV	{"email": "valeriy-gavrilov.1965@postgrespro.ru", "phone": "+70304601929"}
0005433961286	6308FF	7113 768476	EVGENIY VOLKOV	{"email": "volkov-e071980@postgrespro.ru", "phone": "+70052836958"}
0005433961287	6308FF	3636 236072	ALEKSANDR POPOV	{"email": "popov.aleksandr.27021972@postgrespro.ru", "phone": "+70112152532"}
0005433961288	1C19B9	5638 706345	SERGEY EGOROV	{"phone": "+70915632826"}
0005433961289	FC3CFD	4553 196969	TAMARA FOMINA	{"phone": "+70981834274"}
0005433961290	FC3CFD	9742 284525	RAISA KUZNECOVA	{"email": "rkuznecova_07101967@postgrespro.ru", "phone": "+70199730607"}
0005433961291	FE119A	6403 737847	VIKTOR MATVEEV	{"email": "viktormatveev-27111971@postgrespro.ru", "phone": "+70662402428"}
0005433961292	361934	2934 058691	EKATERINA GAVRILOVA	{"email": "gavrilova-ekaterina_14081974@postgrespro.ru", "phone": "+70086831144"}
0005433961293	361934	6357 180243	LARISA GUSEVA	{"phone": "+70538991804"}
0005433961294	5171D2	7110 422244	OLGA SOROKINA	{"email": "sorokina_olga.1972@postgrespro.ru", "phone": "+70271102886"}
0005433961295	F057EE	9998 990471	LILIYA ANISIMOVA	{"email": "liliya_anisimova_17091967@postgrespro.ru", "phone": "+70628271354"}
0005433961296	2C6708	1569 166328	ALEKSANDR MOISEEV	{"phone": "+70452251321"}
0005433961297	AFFC0C	2533 060054	ELINA NAZAROVA	{"email": "nazarova_elina-1963@postgrespro.ru", "phone": "+70712732132"}
0005433961298	56B930	9681 786403	OKSANA VOLKOVA	{"email": "ovolkova04111963@postgrespro.ru", "phone": "+70918378397"}
0005433961299	937E17	7363 283669	VITALIY TARASOV	{"phone": "+70596220496"}
0005433961300	93F517	0010 604951	LEONID KISELEV	{"email": "leonid-kiselev_13121981@postgrespro.ru", "phone": "+70598760709"}
0005433961301	852266	3777 910336	ELENA MIKHAYLOVA	{"email": "mikhaylova.elena101957@postgrespro.ru", "phone": "+70624970726"}
0005433961302	916C76	1267 126094	ELVIRA NAZAROVA	{"email": "elvira-nazarova.17091976@postgrespro.ru", "phone": "+70000603861"}
0005433961303	9E39AC	8172 969665	SVETLANA PETROVA	{"email": "petrova-s17111973@postgrespro.ru", "phone": "+70620621486"}
0005433961304	EE0166	9987 488854	VERA VASILEVA	{"phone": "+70414206942"}
0005433961305	D7825C	7733 309355	MIKHAIL SOKOLOV	{"email": "mikhailsokolov1965@postgrespro.ru", "phone": "+70184769557"}
0005433961306	73857F	7833 994060	MARIYA POPOVA	{"email": "mpopova-1980@postgrespro.ru", "phone": "+70643670636"}
0005433961307	73857F	2162 405482	MARINA MOROZOVA	{"phone": "+70635136454"}
0005433961308	73857F	7702 012074	DMITRIY ROMANOV	{"email": "dmitriy_romanov1973@postgrespro.ru", "phone": "+70663554698"}
0005433961309	769346	0885 089002	ELVIRA VOLKOVA	{"email": "elvira.volkova.1974@postgrespro.ru", "phone": "+70954660049"}
0005433961310	769346	3782 565848	ELENA KONDRATEVA	{"phone": "+70795564719"}
0005433961311	769346	8560 925353	IRINA FROLOVA	{"email": "frolovai1981@postgrespro.ru", "phone": "+70876244876"}
0005433961312	BBB758	0215 024442	DENIS NIKITIN	{"phone": "+70813977625"}
0005433961313	BBB758	3971 368526	ANASTASIYA SMIRNOVA	{"phone": "+70646390398"}
0005433961314	BBB758	5917 274861	SVETLANA VASILEVA	{"email": "vasilevas-1974@postgrespro.ru", "phone": "+70318569330"}
0005433961315	D25FB4	2355 002878	VLADIMIR PAVLOV	{"email": "pavlovvladimir1979@postgrespro.ru", "phone": "+70616057814"}
0005433961316	3C073C	5873 924260	NATALYA ZAKHAROVA	{"email": "natalya-zakharova_1962@postgrespro.ru", "phone": "+70158439065"}
0005433961317	E7D5D4	7753 997206	SVETLANA GUSEVA	{"phone": "+70983575242"}
0005433961318	E7D5D4	0274 242723	VERA ABRAMOVA	{"phone": "+70052612226"}
0005433961319	469EB1	9801 378051	EVGENIYA NIKOLAEVA	{"email": "nikolaeva_e011976@postgrespro.ru", "phone": "+70032589638"}
0005433961320	469EB1	0251 270178	VIKTOR ANDREEV	{"phone": "+70936499873"}
0005433961321	C88924	6199 657314	IGOR ISAEV	{"email": "isaev.igor_091958@postgrespro.ru", "phone": "+70332031238"}
0005433961322	C88924	1243 199283	GENNADIY ROMANOV	{"phone": "+70492018543"}
0005433961323	487A2B	7023 012389	ELENA TIKHONOVA	{"phone": "+70061684116"}
0005433961324	23B66E	7054 740947	YURIY NAUMOV	{"phone": "+70089183934"}
0005433961325	23B66E	7436 822338	MARIYA DENISOVA	{"email": "denisova_m031960@postgrespro.ru", "phone": "+70690733483"}
0005433961326	23B66E	2597 915232	VIKTOR POPOV	{"phone": "+70223816831"}
0005433961327	2C13D7	0710 242544	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr_041961@postgrespro.ru", "phone": "+70117542134"}
0005433961328	3BC4D8	5418 733152	DIANA MIKHAYLOVA	{"email": "mikhaylovad_31011957@postgrespro.ru", "phone": "+70008942952"}
0005433961329	78EC7F	7059 688093	MIKHAIL KUZNECOV	{"phone": "+70615638958"}
0005433961330	17A5B7	1958 120331	VIKTOR ZHUKOV	{"email": "zhukov-v1979@postgrespro.ru", "phone": "+70479520810"}
0005433961331	C85BAD	0017 958826	VLADIMIR TARASOV	{"email": "tarasov_v011969@postgrespro.ru", "phone": "+70397533485"}
0005433961332	E043A6	2435 929815	PELAGEYA FILATOVA	{"email": "filatova-pelageya.12121969@postgrespro.ru", "phone": "+70972418653"}
0005433961333	E043A6	3967 159714	YAROSLAV STEPANOV	{"email": "yaroslavstepanov_1970@postgrespro.ru", "phone": "+70154623185"}
0005433961334	AA3A4C	5713 855491	SVETLANA ABRAMOVA	{"email": "abramovas_1973@postgrespro.ru", "phone": "+70616951818"}
0005433961335	63DD10	3829 661898	PAVEL KUZNECOV	{"email": "kuznecovp-061974@postgrespro.ru", "phone": "+70264359960"}
0005433961336	63DD10	1052 053017	NATALYA TIKHONOVA	{"email": "n_tikhonova1965@postgrespro.ru", "phone": "+70483861547"}
0005433961337	8A3E2B	1925 847061	ANATOLIY NIKOLAEV	{"email": "nikolaev_anatoliy_05071967@postgrespro.ru", "phone": "+70466695559"}
0005433961338	E6EEA6	6794 846198	OLGA ORLOVA	{"email": "orlova_o.081970@postgrespro.ru", "phone": "+70743520876"}
0005433961339	92C5D7	7807 977734	MARIYA POTAPOVA	{"email": "potapova_mariya_10121981@postgrespro.ru", "phone": "+70780593214"}
0005433961340	92C5D7	1171 307439	SERGEY ABRAMOV	{"email": "sergey_abramov.091966@postgrespro.ru", "phone": "+70904911644"}
0005433961341	C896C0	0355 281507	ALENA MASLOVA	{"email": "maslovaalena.1979@postgrespro.ru", "phone": "+70379348032"}
0005433961342	114199	3706 893809	MIKHAIL TIMOFEEV	{"phone": "+70641173331"}
0005433961343	114199	2597 810369	LYUDMILA KARPOVA	{"email": "l_karpova.041972@postgrespro.ru", "phone": "+70525025362"}
0005433961344	39053B	9346 051429	EKATERINA MATVEEVA	{"phone": "+70096261762"}
0005433961345	39053B	3212 985760	YAKOV NIKOLAEV	{"phone": "+70761836215"}
0005433961346	F38149	1687 859895	VALERIY KRASNOV	{"phone": "+70179313663"}
0005433961347	F38149	2622 363842	NIKOLAY KISELEV	{"email": "n_kiselev_07041972@postgrespro.ru", "phone": "+70285973370"}
0005433961348	F38149	5516 004635	ALEKSANDR KRASNOV	{"phone": "+70488049015"}
0005433961349	CB70D4	1525 950468	SANIYA NIKIFOROVA	{"phone": "+70283772734"}
0005433961350	0D6AB5	1593 110135	DMITRIY NIKITIN	{"email": "nikitind061967@postgrespro.ru", "phone": "+70205893831"}
0005433961351	2946F7	1776 843773	IGOR KUDRYASHOV	{"phone": "+70731850201"}
0005433961352	4566AC	3213 266563	VALERIY ALEKSANDROV	{"phone": "+70627304034"}
0005433961353	4566AC	3504 562489	DANILA ROMANOV	{"phone": "+70098292257"}
0005433961354	9904C4	8491 517969	IRINA STEPANOVA	{"email": "stepanova-irina1980@postgrespro.ru", "phone": "+70343918960"}
0005433961355	54051E	7789 597315	ROMAN KUZMIN	{"email": "r.kuzmin.15101962@postgrespro.ru", "phone": "+70011313689"}
0005433961356	58B6B9	1496 334647	VLADIMIR FROLOV	{"email": "frolov.v_021974@postgrespro.ru", "phone": "+70096382933"}
0005433961357	FB3377	1284 393683	VLADISLAV IVANOV	{"phone": "+70611935854"}
0005433961358	FCF635	2450 495186	KONSTANTIN KUZNECOV	{"phone": "+70782662630"}
0005433961359	A332A1	8899 780361	ANATOLIY POPOV	{"email": "popov-a_091965@postgrespro.ru", "phone": "+70637434844"}
0005433961360	92FFEB	3214 664208	EVGENIY MATVEEV	{"email": "ematveev.051967@postgrespro.ru", "phone": "+70712735746"}
0005433961361	92FFEB	4736 610840	FEDOR ANDREEV	{"phone": "+70727101629"}
0005433961362	92FFEB	8369 214437	ANASTASIYA KOMAROVA	{"phone": "+70501417011"}
0005433961363	2A9394	7197 906460	VIKTOR SERGEEV	{"email": "sergeev.viktor1974@postgrespro.ru", "phone": "+70562844048"}
0005433961364	FE42B7	5876 911282	LYUBOV SMIRNOVA	{"email": "smirnova-l.1963@postgrespro.ru", "phone": "+70694970221"}
0005433961365	654A09	3459 305125	ALEKSEY DENISOV	{"phone": "+70204240375"}
0005433961366	CC6019	4057 042665	ALEKSEY MOISEEV	{"email": "aleksey.moiseev-051973@postgrespro.ru", "phone": "+70299246693"}
0005433961367	CC1CCD	0400 488171	NATALYA FOMINA	{"email": "nfomina-1977@postgrespro.ru", "phone": "+70047184735"}
0005433961368	45CAC7	0793 365843	ALEKSANDR MEDVEDEV	{"phone": "+70961980298"}
0005433961369	45CAC7	5452 284985	VITALIY TIKHONOV	{"phone": "+70106027399"}
0005433961370	DF58B5	6559 274486	ELENA NIKOLAEVA	{"email": "elena_nikolaeva_071966@postgrespro.ru", "phone": "+70043852556"}
0005433961371	3B60BE	9768 845121	ALEKSEY MOROZOV	{"email": "morozov.a_1979@postgrespro.ru", "phone": "+70974289862"}
0005433961372	19D9BD	0545 047802	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir.10111972@postgrespro.ru", "phone": "+70398210240"}
0005433961373	50536F	8127 090150	ALEKSANDR IVANOV	{"phone": "+70429300505"}
0005433961374	50536F	7966 536581	NINEL TITOVA	{"email": "n_titova_1974@postgrespro.ru", "phone": "+70865704315"}
0005433961375	FC695B	6915 609251	NADEZHDA BORISOVA	{"phone": "+70616783769"}
0005433961376	8D90C3	4824 932686	YURIY ZHURAVLEV	{"email": "zhuravlev-yuriy14021961@postgrespro.ru", "phone": "+70812359252"}
0005433961377	2366AA	0662 986738	VLADIMIR FROLOV	{"email": "vladimir.frolov.121976@postgrespro.ru", "phone": "+70643096835"}
0005433961378	2366AA	8228 852824	GALINA SOROKINA	{"phone": "+70374282382"}
0005433961379	9DE8F6	5659 425103	OLGA SERGEEVA	{"phone": "+70496350346"}
0005433961380	00DE87	6557 888202	DENIS SCHERBAKOV	{"email": "denis_scherbakov.051971@postgrespro.ru", "phone": "+70460248711"}
0005433961381	40C23F	6826 505861	TIGRAN ILIN	{"phone": "+70340648778"}
0005433961382	40C23F	4998 703900	ALEKSANDR YAKOVLEV	{"phone": "+70980936851"}
0005433961383	8AC432	0001 455746	ANTONINA MASLOVA	{"email": "maslova_a021963@postgrespro.ru", "phone": "+70850762793"}
0005433961384	8AC432	3941 205865	NIKOLAY DMITRIEV	{"phone": "+70630037662"}
0005433961385	501099	5900 170610	SEMEN ANDREEV	{"email": "semen-andreev1964@postgrespro.ru", "phone": "+70091194941"}
0005433961386	0F753E	8854 883515	IRINA MIRONOVA	{"phone": "+70676730022"}
0005433961387	CF54C9	0198 654365	GERMAN IVANOV	{"phone": "+70929108183"}
0005433961388	315815	1500 303124	ANNA KUZNECOVA	{"phone": "+70975398980"}
0005433961389	315815	9019 457308	VALENTINA TITOVA	{"phone": "+70886272998"}
0005433961390	52136C	6089 281534	ELENA KUZNECOVA	{"phone": "+70279504878"}
0005433961391	1C44B4	4212 064628	PAVEL BONDARENKO	{"phone": "+70524331947"}
0005433961392	1C44B4	6111 388100	NATALYA TIMOFEEVA	{"email": "n.timofeeva_121980@postgrespro.ru", "phone": "+70056824835"}
0005433961393	20E367	2020 754748	GALINA MASLOVA	{"phone": "+70769735736"}
0005433961394	20E367	6178 799219	VLADIMIR TIKHONOV	{"email": "vladimir.tikhonov_09101966@postgrespro.ru", "phone": "+70375034752"}
0005433961395	BC3396	8256 335481	NIKITA FEDOROV	{"phone": "+70027399807"}
0005433961396	BC3396	1396 285128	TAISIYA PAVLOVA	{"email": "pavlova-taisiya111963@postgrespro.ru", "phone": "+70594063285"}
0005433961397	736392	2815 544105	ELENA ALEKSANDROVA	{"email": "aleksandrovae081973@postgrespro.ru", "phone": "+70555220447"}
0005433961398	736392	1042 006581	ELIZAVETA BORISOVA	{"email": "elizavetaborisova-041971@postgrespro.ru", "phone": "+70867653624"}
0005433961399	C2A827	5717 989166	ALEKSEY FEDOTOV	{"phone": "+70260070484"}
0005433961400	7EB597	9180 223461	DARYA RYABOVA	{"phone": "+70459465644"}
0005433961401	7EB597	4782 627920	NIKITA NAUMOV	{"email": "nikita.naumov.1975@postgrespro.ru", "phone": "+70150445994"}
0005433961402	BCAEE9	0053 461401	EKATERINA SMIRNOVA	{"phone": "+70417801337"}
0005433961403	BCAEE9	5117 729987	VALENTINA GERASIMOVA	{"phone": "+70727188834"}
0005433961404	1A0F2E	6228 380232	MARINA TIKHONOVA	{"email": "tikhonova.marina_08071968@postgrespro.ru", "phone": "+70153880799"}
0005433961405	1A0F2E	4596 302533	ALEKSANDR BELOV	{"phone": "+70993964749"}
0005433961406	332D87	9608 217761	PAVEL NIKOLAEV	{"phone": "+70728335211"}
0005433961407	CA4F6D	4982 903342	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev.22091963@postgrespro.ru", "phone": "+70987385695"}
0005433961408	CA4F6D	7021 350997	NIKOLAY ROMANOV	{"email": "n_romanov.05051986@postgrespro.ru", "phone": "+70599142725"}
0005433961409	40D565	1633 657158	ALEKSANDR KONOVALOV	{"phone": "+70414722417"}
0005433961410	D90721	2599 252194	VERA SOKOLOVA	{"email": "sokolova.vera1964@postgrespro.ru", "phone": "+70672290557"}
0005433961411	39B528	9062 878580	ALEKSEY FROLOV	{"phone": "+70199168741"}
0005433961412	CF2284	3907 955292	YURIY ORLOV	{"phone": "+70358941934"}
0005433961413	55D9E6	2873 874980	ALEKSANDR POPOV	{"email": "a_popov-021964@postgrespro.ru", "phone": "+70671187132"}
0005433961414	0A86C8	3159 338288	VLADIMIR ZAKHAROV	{"phone": "+70247174923"}
0005433961415	83FC6C	4307 151624	DENIS SHEVCHENKO	{"phone": "+70273796495"}
0005433961416	67FD7F	5918 025563	YURIY ZHURAVLEV	{"email": "yuriy.zhuravlev_041965@postgrespro.ru", "phone": "+70562339322"}
0005433961417	392856	4154 760139	NINA BOGDANOVA	{"phone": "+70158113936"}
0005433961418	392856	7284 785041	TATYANA MARTYNOVA	{"phone": "+70796303410"}
0005433961419	F9C0DE	8735 391015	EKATERINA SEMENOVA	{"email": "e.semenova_22121971@postgrespro.ru", "phone": "+70228936427"}
0005433961420	F9C0DE	0021 898971	ELENA DANILOVA	{"phone": "+70786378901"}
0005433961421	3F2048	6395 614938	ALEKSEY NIKOLAEV	{"email": "alekseynikolaev.1966@postgrespro.ru", "phone": "+70749507371"}
0005433961422	18B9C7	6566 747858	SVETLANA ZHURAVLEVA	{"email": "s-zhuravleva-15061969@postgrespro.ru", "phone": "+70594383291"}
0005433961423	18B9C7	9037 064219	IVAN KUZNECOV	{"phone": "+70421599810"}
0005433961424	18B9C7	9452 660718	LYUBOV ROMANOVA	{"email": "romanova_l_1960@postgrespro.ru", "phone": "+70233875640"}
0005433961425	E91F90	7738 762811	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-06051974@postgrespro.ru", "phone": "+70806444909"}
0005433961426	A8B7FC	2734 263378	IRINA AKIMOVA	{"phone": "+70007589184"}
0005433961427	12F441	7662 424932	NATALYA SEMENOVA	{"phone": "+70063960643"}
0005433961428	418C03	8412 547234	YURIY VLASOV	{"phone": "+70636132237"}
0005433961429	43029F	5781 528791	MARINA GAVRILOVA	{"email": "mgavrilova121974@postgrespro.ru", "phone": "+70225999977"}
0005433961430	06E45F	3013 547798	LILIYA NIKOLAEVA	{"phone": "+70410905589"}
0005433961431	C392A2	6529 554478	TATYANA SAVELEVA	{"email": "t-saveleva1972@postgrespro.ru", "phone": "+70082215230"}
0005433961432	47A8D1	4450 039885	YULIYA KALININA	{"phone": "+70822904231"}
0005433961433	E4036D	3919 501656	ANDREY KUDRYASHOV	{"email": "andrey.kudryashov.26071970@postgrespro.ru", "phone": "+70224822860"}
0005433961434	B8F5E5	2954 265753	ANATOLIY POPOV	{"phone": "+70232465429"}
0005433961435	07D10F	5841 826542	VLADIMIR ZHURAVLEV	{"phone": "+70320412429"}
0005433961436	345F24	1452 261568	TATYANA SIDOROVA	{"email": "tatyanasidorova-091967@postgrespro.ru", "phone": "+70567180736"}
0005433961437	345F24	8009 676461	IRINA KUZMINA	{"phone": "+70760005577"}
0005433961438	418610	0825 798369	ELENA YAKOVLEVA	{"email": "yakovleva-e.21031978@postgrespro.ru", "phone": "+70084387091"}
0005433961439	418610	6561 424765	EVGENIY PETROV	{"phone": "+70422419469"}
0005433961440	2334EC	4423 588137	OLEG MARTYNOV	{"phone": "+70481594896"}
0005433961441	15E9FC	2354 753319	RIMMA VOROBEVA	{"email": "vorobeva_r-18061974@postgrespro.ru", "phone": "+70379360256"}
0005433961442	15E9FC	2948 354704	ANDREY PAVLOV	{"email": "andrey.pavlov16041971@postgrespro.ru", "phone": "+70195725562"}
0005433961443	6F34B5	6196 653519	ELENA FEDOROVA	{"phone": "+70148963311"}
0005433961444	6F34B5	4960 881928	INESSA KUZNECOVA	{"phone": "+70078855767"}
0005433961445	435990	0732 629514	OLGA MASLOVA	{"phone": "+70617077272"}
0005433961446	2F5474	8232 867039	VALENTIN ISAEV	{"phone": "+70427316315"}
0005433961447	C477C2	0618 214455	LYUBOV NESTEROVA	{"email": "nesterova-lyubov.04071973@postgrespro.ru", "phone": "+70138439767"}
0005433961448	C477C2	5621 361223	KLAVDIYA BELOVA	{"email": "belova_k_111977@postgrespro.ru", "phone": "+70836017640"}
0005433961449	33D49F	1548 996304	ALEKSANDR KRASNOV	{"phone": "+70930520874"}
0005433961450	8FC434	4430 587266	MATVEY ZAYCEV	{"email": "m-zaycev_09021970@postgrespro.ru", "phone": "+70391169897"}
0005433961451	2B3F0A	5935 105339	GENNADIY SMIRNOV	{"phone": "+70799705328"}
0005433961452	2B3F0A	3909 669628	ALEKSANDR ILIN	{"phone": "+70138286349"}
0005433961453	FF0B0A	6395 023957	VLADIMIR ORLOV	{"email": "v_orlov06111973@postgrespro.ru", "phone": "+70235974124"}
0005433961454	C83688	9878 235094	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.nikolay_081975@postgrespro.ru", "phone": "+70905840386"}
0005433961455	C83688	1193 640035	DMITRIY ORLOV	{"email": "d_orlov-30071966@postgrespro.ru", "phone": "+70482371951"}
0005433961456	9E3D86	5622 131879	SOFYA IVANOVA	{"email": "sivanova23061965@postgrespro.ru", "phone": "+70149977057"}
0005433961457	F8F942	0099 063331	SERGEY KOZLOV	{"phone": "+70943620251"}
0005433961458	F8F942	5966 565296	NADEZHDA TARASOVA	{"phone": "+70585100943"}
0005433961459	E9334F	0824 725891	SERGEY OSIPOV	{"email": "sergey_osipov051977@postgrespro.ru", "phone": "+70736860662"}
0005433961460	E9334F	2669 647365	ALEKSANDR GERASIMOV	{"phone": "+70357254535"}
0005433961461	4BB4D6	9272 117449	VALERIY EGOROV	{"email": "egorov_valeriy.031979@postgrespro.ru", "phone": "+70339645812"}
0005433961462	4BB4D6	7476 252450	SVETLANA BORISOVA	{"email": "borisova-svetlana-1972@postgrespro.ru", "phone": "+70676343349"}
0005433961463	4BB4D6	3260 217079	KLAVDIYA KOROLEVA	{"email": "korolevak.011973@postgrespro.ru", "phone": "+70284576719"}
0005433961464	93272F	1014 106512	PETR MELNIKOV	{"phone": "+70358274913"}
0005433961465	E04260	2664 433622	ALEKSANDR GUSEV	{"email": "agusev_03071973@postgrespro.ru", "phone": "+70943880555"}
0005433961466	E04260	4199 120449	TATYANA STEPANOVA	{"email": "stepanova_tatyana_081971@postgrespro.ru", "phone": "+70469786475"}
0005433961467	E04260	1082 487534	ALEKSANDR SMIRNOV	{"email": "a.smirnov25071974@postgrespro.ru", "phone": "+70971847335"}
0005433961468	36203A	8565 094673	VIKTOR ANDREEV	{"phone": "+70959258960"}
0005433961469	36203A	8315 032640	ALEKSANDR RODIONOV	{"phone": "+70445649055"}
0005433961470	F1CCF8	9529 247198	DMITRIY SOKOLOV	{"email": "dmitriysokolov_011966@postgrespro.ru", "phone": "+70484461294"}
0005433961471	745C4C	3354 152077	OLEG ANTONOV	{"email": "oleg-antonov_121972@postgrespro.ru", "phone": "+70051317777"}
0005433961472	825B19	7793 768747	OLESYA BELOVA	{"email": "belovao-05031954@postgrespro.ru", "phone": "+70550641100"}
0005433961473	87CFD7	2028 043858	MIKHAIL KRASNOV	{"email": "m_krasnov-1983@postgrespro.ru", "phone": "+70060152390"}
0005433961474	C359AD	8144 211342	ANASTASIYA KUZNECOVA	{"email": "kuznecova.anastasiya.1967@postgrespro.ru", "phone": "+70954437129"}
0005433961475	A4D3EC	0002 712531	GALIYA IVANOVA	{"phone": "+70500949662"}
0005433961476	71FD11	1071 499168	SERGEY KUZNECOV	{"email": "kuznecov-s_111972@postgrespro.ru", "phone": "+70312282436"}
0005433961477	71FD11	0257 920968	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov_041975@postgrespro.ru", "phone": "+70923114228"}
0005433961478	71FD11	2947 771220	VYACHESLAV YAKOVLEV	{"phone": "+70103892769"}
0005433961479	B75A26	5222 484942	SERGEY VOLKOV	{"email": "s_volkov.021975@postgrespro.ru", "phone": "+70557589301"}
0005433961480	33D2E4	8076 307264	ANDREY DENISOV	{"phone": "+70662182475"}
0005433961481	639C45	3076 451424	EVGENIY FOMIN	{"email": "fomin-evgeniy.091970@postgrespro.ru", "phone": "+70799626961"}
0005433961482	72A185	5434 862570	IRINA IVANOVA	{"email": "irinaivanova_1975@postgrespro.ru", "phone": "+70421890652"}
0005433961483	72A185	4266 176242	VALENTINA IVANOVA	{"email": "ivanovav.041966@postgrespro.ru", "phone": "+70390569150"}
0005433961484	6F76ED	7895 288318	DENIS NIKITIN	{"phone": "+70746829241"}
0005433961485	210238	5091 544755	NATALYA AFANASEVA	{"email": "n.afanaseva-1965@postgrespro.ru", "phone": "+70113628425"}
0005433961486	187A07	1897 548863	ALEKSANDR ABRAMOV	{"phone": "+70779086993"}
0005433961487	5F9A07	6320 613645	ANDREY ROMANOV	{"email": "romanovandrey.1981@postgrespro.ru", "phone": "+70392186518"}
0005433961488	35F476	8014 472742	IGOR POPOV	{"email": "popov-i021974@postgrespro.ru", "phone": "+70201542873"}
0005433961489	479FB5	7438 265321	LYUBOV KOVALEVA	{"email": "kovaleva.l-021976@postgrespro.ru", "phone": "+70259889850"}
0005433961490	479FB5	4369 503039	VITALIY GORBUNOV	{"phone": "+70704400211"}
0005433961491	F54FA6	8251 060497	SERGEY ORLOV	{"email": "sergey-orlov1983@postgrespro.ru", "phone": "+70026255026"}
0005433961492	75F04A	8417 378975	SERGEY SHEVCHENKO	{"phone": "+70931674580"}
0005433961493	E9402E	8950 449888	ANDREY MAKAROV	{"phone": "+70826509615"}
0005433961494	63644E	3234 304150	ALEKSANDRA KULIKOVA	{"phone": "+70138441149"}
0005433961495	D244B4	2803 396175	LYUBOV POTAPOVA	{"email": "potapova-l27011974@postgrespro.ru", "phone": "+70553045640"}
0005433961496	EE7710	5651 857439	VLADIMIR VLASOV	{"email": "vlasov-v-02121964@postgrespro.ru", "phone": "+70426928147"}
0005433961497	CBEA82	7980 973217	DMITRIY POPOV	{"phone": "+70233057565"}
0005433961498	CBEA82	6483 553439	MARINA DANILOVA	{"email": "danilova-marina-1968@postgrespro.ru", "phone": "+70864723023"}
0005433961499	60EBBE	9387 302671	DARYA GERASIMOVA	{"email": "d_gerasimova071969@postgrespro.ru", "phone": "+70465682190"}
0005433961500	53B1E0	1183 651049	ALEKSANDR STEPANOV	{"phone": "+70007611746"}
0005433961501	2BCAA1	4362 330502	ANTON STEPANOV	{"email": "stepanov.a-1977@postgrespro.ru", "phone": "+70144606005"}
0005433961502	1392EA	4895 923154	ALEKSANDR FOMIN	{"email": "aleksandr_fomin_031974@postgrespro.ru", "phone": "+70147432421"}
0005433961503	1392EA	0324 820611	EVGENIY ROMANOV	{"phone": "+70386931134"}
0005433961504	0CBE60	4588 959540	ELENA MIRONOVA	{"email": "e_mironova_011976@postgrespro.ru", "phone": "+70775552743"}
0005433961505	8D3541	5180 820435	EGOR IVANOV	{"email": "egor_ivanov_1967@postgrespro.ru", "phone": "+70248576434"}
0005433961506	B97555	5314 571350	SERGEY IVANOV	{"email": "ivanov_sergey04051975@postgrespro.ru", "phone": "+70116455011"}
0005433961507	FB2D57	3995 683790	LYUBOV DENISOVA	{"email": "l_denisova1968@postgrespro.ru", "phone": "+70625699416"}
0005433961508	1F260C	4479 692392	NADEZHDA SOKOLOVA	{"phone": "+70074827177"}
0005433961509	A7BCD0	3677 332067	MARINA SMIRNOVA	{"phone": "+70768720029"}
0005433961510	A7BCD0	3622 201313	SERGEY ALEKSEEV	{"email": "sergey.alekseev041966@postgrespro.ru", "phone": "+70836115565"}
0005433961511	A7BCD0	5738 736708	IGOR GERASIMOV	{"email": "gerasimovi_12061967@postgrespro.ru", "phone": "+70401917284"}
0005433961512	B7B005	6778 703993	VITALIY PETROV	{"phone": "+70901369218"}
0005433961513	C214A9	0838 852206	EKATERINA NIKITINA	{"phone": "+70667084738"}
0005433961514	014D49	6606 418704	ALEKSEY MOISEEV	{"phone": "+70895646672"}
0005433961515	B55FE2	9348 828695	INESSA IVANOVA	{"email": "i-ivanova_09031973@postgrespro.ru", "phone": "+70871444124"}
0005433961516	E66596	4501 272509	VALENTINA KUDRYASHOVA	{"phone": "+70365623357"}
0005433961517	8A6F8C	8908 263970	PETR MIKHAYLOV	{"email": "petr.mikhaylov11101968@postgrespro.ru", "phone": "+70080436158"}
0005433961518	55B25B	5316 129653	GENNADIY EGOROV	{"email": "gennadiy.egorov.06081973@postgrespro.ru", "phone": "+70992985398"}
0005433961519	55B25B	5253 344120	SVETLANA ALEKSANDROVA	{"email": "s_aleksandrova-1968@postgrespro.ru", "phone": "+70275781371"}
0005433961520	6F2246	9952 162552	MARAT KUZMIN	{"phone": "+70630595878"}
0005433961521	6F2246	7785 078926	ANDREY NIKITIN	{"phone": "+70846964494"}
0005433961522	DFEF4E	2557 676084	ANDREY MOROZOV	{"email": "andrey-morozov.1970@postgrespro.ru", "phone": "+70412326971"}
0005433961523	CCB6E2	2962 462535	OLEG MOROZOV	{"phone": "+70851107628"}
0005433961524	CCB6E2	4570 301393	OLGA BELYAEVA	{"phone": "+70943116247"}
0005433961525	D4582B	0950 007917	ALEKSEY DMITRIEV	{"phone": "+70150440994"}
0005433961526	D4BFB1	9925 537295	YULIYA KUZMINA	{"email": "kuzminayuliya-31031974@postgrespro.ru", "phone": "+70147605167"}
0005433961527	C9D46D	9898 911847	ANASTASIYA VLASOVA	{"email": "vlasova-a-1963@postgrespro.ru", "phone": "+70519579282"}
0005433961528	C9D46D	4932 049590	TATYANA MIKHAYLOVA	{"email": "mikhaylova.t-21101974@postgrespro.ru", "phone": "+70136118658"}
0005433961529	4F000D	8222 524083	ARTEM EGOROV	{"email": "egorov_artem-1971@postgrespro.ru", "phone": "+70513475396"}
0005433961530	D09B9F	3518 382418	IRINA MOROZOVA	{"email": "i.morozova-09051967@postgrespro.ru", "phone": "+70887793626"}
0005433961531	D09B9F	4794 144058	DARYA KUZNECOVA	{"phone": "+70670764964"}
0005433961532	D3FD6D	2009 895173	MARGARITA SIDOROVA	{"email": "m_sidorova.1962@postgrespro.ru", "phone": "+70153538755"}
0005433961533	7CB5F5	1688 782068	ALLA POPOVA	{"phone": "+70824249611"}
0005433961534	7CB5F5	7697 999206	MARINA STEPANOVA	{"phone": "+70447312984"}
0005433961535	7CB5F5	7735 545492	ELINA IVANOVA	{"email": "elinaivanova_1967@postgrespro.ru", "phone": "+70982151520"}
0005433961536	D906FA	8842 467591	SERGEY NOVIKOV	{"phone": "+70800855735"}
0005433961537	D906FA	7275 911380	VIKTOR MIRONOV	{"email": "mironov-viktor_051965@postgrespro.ru", "phone": "+70732836345"}
0005433961538	950955	1585 684206	ROZA PAVLOVA	{"email": "rpavlova.06081977@postgrespro.ru", "phone": "+70147885377"}
0005433961539	F7BC61	9953 281831	NATALYA KUZMINA	{"phone": "+70555052903"}
0005433961540	099E32	2101 145372	OLGA MIRONOVA	{"phone": "+70765784552"}
0005433961541	9616A2	4595 759694	ANTONINA IVANOVA	{"phone": "+70049312244"}
0005433961542	480867	2832 442059	DMITRIY KOZLOV	{"email": "kozlov_dmitriy061968@postgrespro.ru", "phone": "+70441633099"}
0005433961543	480867	2146 215634	ALENA POPOVA	{"phone": "+70792139506"}
0005433961544	480867	0261 626920	IRINA KONDRATEVA	{"phone": "+70890608009"}
0005433961545	D7F7CA	2654 724790	DANILA SIDOROV	{"email": "sidorovdanila_021974@postgrespro.ru", "phone": "+70277873596"}
0005433961546	3AECB4	2872 832808	VALENTINA KONDRATEVA	{"email": "valentina-kondrateva-091975@postgrespro.ru", "phone": "+70469159651"}
0005433961547	1E0AC3	0148 206393	LILIYA KARPOVA	{"phone": "+70944031310"}
0005433961548	AF7D43	8787 641933	ANATOLIY KARPOV	{"phone": "+70619234248"}
0005433961549	AF7D43	6657 752798	ILYA KUZNECOV	{"phone": "+70135001848"}
0005433961550	8442ED	0388 646566	LYUDMILA DANILOVA	{"email": "lyudmila_danilova_1969@postgrespro.ru", "phone": "+70587004999"}
0005433961551	3D4CB2	7242 189101	OLGA SOROKINA	{"phone": "+70687964316"}
0005433961552	3D4CB2	2054 305611	ANNA TROFIMOVA	{"email": "trofimova_anna-01031961@postgrespro.ru", "phone": "+70926911032"}
0005433961553	D78272	3035 352864	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva_1975@postgrespro.ru", "phone": "+70853108152"}
0005433961554	AFF42F	8873 027494	IGOR BELOV	{"email": "belovigor_04061975@postgrespro.ru", "phone": "+70135748361"}
0005433961555	AFF42F	7402 077351	SERGEY VASILEV	{"phone": "+70030381950"}
0005433961556	AFF42F	3911 285290	OLEG ALEKSANDROV	{"phone": "+70821561989"}
0005433961557	523488	0637 322541	SERGEY SOROKIN	{"phone": "+70787136717"}
0005433961558	D697DD	2677 817535	TATYANA PETROVA	{"phone": "+70509747599"}
0005433961559	A3C63D	4893 174571	SERGEY GERASIMOV	{"phone": "+70881989348"}
0005433961560	A3C63D	0891 236320	ROMAN DAVYDOV	{"phone": "+70179676535"}
0005433961561	1DE534	1207 629812	ELENA NAUMOVA	{"phone": "+70364267542"}
0005433961562	1DE534	3641 319639	DENIS ISAEV	{"email": "denis.isaev.29101958@postgrespro.ru", "phone": "+70831377994"}
0005433961563	0DD2B9	7801 880267	ALEKSANDRA ALEKSEEVA	{"phone": "+70427526537"}
0005433961564	26E063	2296 967370	ANZHELIKA VASILEVA	{"email": "a.vasileva-03101979@postgrespro.ru", "phone": "+70345680343"}
0005433961565	320633	8591 399349	ARINA MIRONOVA	{"email": "arina_mironova1981@postgrespro.ru", "phone": "+70262501725"}
0005433961566	4FA57D	7884 048145	LEV AFANASEV	{"phone": "+70813780944"}
0005433961567	4FA57D	4904 359292	LYUDMILA BARANOVA	{"email": "baranova-l1974@postgrespro.ru", "phone": "+70268346178"}
0005433961568	C2B264	9212 945614	EVGENIY PETROV	{"email": "petrov-e101964@postgrespro.ru", "phone": "+70724976673"}
0005433961569	C2B264	4076 648339	FANIS MOISEEV	{"email": "moiseev-fanis_1971@postgrespro.ru", "phone": "+70745000163"}
0005433961570	C2B264	9527 229357	ELIZAVETA FILIPPOVA	{"email": "e.filippova081976@postgrespro.ru", "phone": "+70308961973"}
0005433961571	817E32	9500 417490	SERGEY NAZAROV	{"phone": "+70005663205"}
0005433961572	2521BD	4095 923241	VALENTINA TARASOVA	{"phone": "+70493622757"}
0005433961573	80E02B	9894 847156	NATALYA FILIPPOVA	{"email": "natalya_filippova_1975@postgrespro.ru", "phone": "+70270863532"}
0005433961574	80E02B	0014 390602	LYUDMILA SIDOROVA	{"email": "sidoroval_1983@postgrespro.ru", "phone": "+70379880870"}
0005433961575	2AC43C	6854 494745	ZHANNA SOKOLOVA	{"email": "zsokolova_24101963@postgrespro.ru", "phone": "+70503273564"}
0005433961576	22BCB4	7231 469642	ALEKSEY ANDREEV	{"email": "aandreev.081957@postgrespro.ru", "phone": "+70460558156"}
0005433961577	22BCB4	5576 960087	ILYA GRIGOREV	{"phone": "+70276997912"}
0005433961578	4BE822	1049 550751	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov_1990@postgrespro.ru", "phone": "+70632007183"}
0005433961579	7D0069	3097 768639	VLADIMIR TIMOFEEV	{"email": "timofeevv1973@postgrespro.ru", "phone": "+70069694985"}
0005433961580	7D0069	5098 019425	ALINA STEPANOVA	{"phone": "+70000173903"}
0005433961581	7D0069	3949 368105	EDUARD BORISOV	{"email": "borisov.e_06041976@postgrespro.ru", "phone": "+70339461607"}
0005433961582	B657A9	0125 230454	POLINA KOMAROVA	{"phone": "+70218170385"}
0005433961583	F6A046	6084 146208	ANNA BELOVA	{"email": "a.belova14081979@postgrespro.ru", "phone": "+70495134548"}
0005433961584	A01EA8	3868 686848	ZAKHAR SERGEEV	{"email": "sergeev-zakhar.031970@postgrespro.ru", "phone": "+70672423595"}
0005433961585	A01EA8	2915 833250	SERGEY NIKOLAEV	{"email": "sergeynikolaev061978@postgrespro.ru", "phone": "+70613621359"}
0005433961586	A9A32F	4086 686279	ANDREY VOLKOV	{"phone": "+70219448090"}
0005433961587	F8D177	3551 126773	ANATOLIY NOVIKOV	{"email": "novikov_a-121977@postgrespro.ru", "phone": "+70371583371"}
0005433961588	1931E6	3668 522307	ALEKSANDR KULIKOV	{"email": "kulikov-aleksandr.011971@postgrespro.ru", "phone": "+70558898558"}
0005433961589	1931E6	1693 673508	SERGEY NAUMOV	{"phone": "+70311996669"}
0005433961590	10B091	9740 969467	ANDREY SOLOVEV	{"email": "solovev.a.17011978@postgrespro.ru", "phone": "+70368925002"}
0005433961591	B024AB	8710 971474	EVGENIY GAVRILOV	{"phone": "+70205756625"}
0005433961592	33A409	3541 669818	RUSTAM IVANOV	{"phone": "+70929977835"}
0005433961593	6DF7C8	5200 924990	LYUBOV IVANOVA	{"phone": "+70246614087"}
0005433961594	6DF7C8	1569 187607	MARINA ZAYCEVA	{"phone": "+70315425625"}
0005433961595	4E741F	1188 121302	PETR BONDARENKO	{"email": "petrbondarenko05071979@postgrespro.ru", "phone": "+70760796862"}
0005433961596	4E741F	3429 936765	VYACHESLAV GORBUNOV	{"phone": "+70868618019"}
0005433961597	BC4C82	7918 631716	ALEKSANDRA FEDOROVA	{"email": "a-fedorova-19051972@postgrespro.ru", "phone": "+70510640094"}
0005433961598	17D9E2	4780 191255	MAKSIM MATVEEV	{"email": "m-matveev18091979@postgrespro.ru", "phone": "+70908960337"}
0005433961599	207B9C	6136 968905	ANATOLIY NOVIKOV	{"email": "novikov-anatoliy_1982@postgrespro.ru", "phone": "+70179040790"}
0005433961600	07E50B	1123 519170	DENIS KISELEV	{"email": "kiselev-d-01071969@postgrespro.ru", "phone": "+70041593762"}
0005433961601	F994C1	8240 855153	SERGEY POPOV	{"phone": "+70240601807"}
0005433961602	EA6854	5624 193000	NIKOLAY MOROZOV	{"phone": "+70333564840"}
0005433961603	EA6854	6123 005584	ALEKSANDR NIKOLAEV	{"email": "nikolaeva-1969@postgrespro.ru", "phone": "+70127659843"}
0005433961604	7C2DE1	6165 800438	IGOR IVANOV	{"phone": "+70101908745"}
0005433961605	308AD8	0328 702425	ANDREY SHEVCHENKO	{"phone": "+70943538294"}
0005433961606	999AFE	0358 061154	KRISTINA ABRAMOVA	{"email": "abramovakristina19061960@postgrespro.ru", "phone": "+70820052666"}
0005433961607	999AFE	5456 195137	ANATOLIY IVANOV	{"phone": "+70051024520"}
0005433961608	999AFE	6832 170931	ALEVTINA PAVLOVA	{"email": "pavlova-alevtina.111968@postgrespro.ru", "phone": "+70163981024"}
0005433961609	AE1D5B	0256 687939	STANISLAV FROLOV	{"phone": "+70727855767"}
0005433961610	AE1D5B	4546 400463	VIKTOR GORBUNOV	{"email": "gorbunov-v23091968@postgrespro.ru", "phone": "+70003611941"}
0005433961611	BE1D85	4161 337769	IRINA ROMANOVA	{"phone": "+70552973926"}
0005433961612	C40185	4731 564588	MARINA LEBEDEVA	{"phone": "+70634706484"}
0005433961613	157539	4307 054187	VALERIY VASILEV	{"email": "valeriy.vasilev.19111967@postgrespro.ru", "phone": "+70801721762"}
0005433961614	051560	9316 789112	MARINA SOROKINA	{"phone": "+70577898026"}
0005433961615	051560	2412 519685	VALERIY FEDOTOV	{"phone": "+70557188463"}
0005433961616	DC1FAE	9719 950685	MARINA PETROVA	{"phone": "+70880512648"}
0005433961617	AD2D98	7192 615832	ZHANNA POPOVA	{"email": "zhanna.popova-16061971@postgrespro.ru", "phone": "+70199875864"}
0005433961618	DF9BC8	8455 370410	ANDREY FILIPPOV	{"phone": "+70998652225"}
0005433961619	A464B4	5602 721704	SVETLANA MOISEEVA	{"email": "svetlana_moiseeva_1961@postgrespro.ru", "phone": "+70311776062"}
0005433961620	CE0966	4444 960333	YULIYA LAZAREVA	{"email": "y-lazareva_1970@postgrespro.ru", "phone": "+70288696109"}
0005433961621	CE0966	2580 351391	VLADIMIR ALEKSANDROV	{"email": "v.aleksandrov-05121980@postgrespro.ru", "phone": "+70790902143"}
0005433961622	1EF522	5741 884274	ANASTASIYA BORISOVA	{"email": "borisova-anastasiya061972@postgrespro.ru", "phone": "+70436823610"}
0005433961623	1EF522	7485 983888	VIKTOR BORISOV	{"email": "borisov.viktor_121984@postgrespro.ru", "phone": "+70722972053"}
0005433961624	CFAD7E	6280 790570	VLADIMIR KUZNECOV	{"email": "kuznecov.v.11031968@postgrespro.ru", "phone": "+70212243844"}
0005433961625	D8FEDE	5947 477065	SVETLANA ORLOVA	{"phone": "+70724204452"}
0005433961626	D8FEDE	8772 579697	ALEKSEY ILIN	{"email": "aleksey_ilin-101977@postgrespro.ru", "phone": "+70062756448"}
0005433961627	D8FEDE	9053 679295	DMITRIY KISELEV	{"phone": "+70386677415"}
0005433961628	B6613A	2512 237576	ALEKSEY SIDOROV	{"phone": "+70916098819"}
0005433961629	B6613A	3887 640200	MARIYA KUZNECOVA	{"phone": "+70058716693"}
0005433961630	134195	3174 542588	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova_1978@postgrespro.ru", "phone": "+70630823408"}
0005433961631	6BEFF8	8502 143595	NATALYA MOROZOVA	{"phone": "+70883314270"}
0005433961632	ABADF6	9879 539113	STEPAN GORBUNOV	{"email": "sgorbunov.101977@postgrespro.ru", "phone": "+70884816081"}
0005433961633	ABADF6	2227 556779	IRINA FOMINA	{"phone": "+70223904319"}
0005433961634	5FAC95	3206 492790	LYUDMILA ZHUKOVA	{"phone": "+70204008501"}
0005433961635	70FBAD	3828 256109	ALEKSANDR NOVIKOV	{"phone": "+70685825435"}
0005433961636	ADEE79	4587 800048	IRINA MALYSHEVA	{"phone": "+70578966857"}
0005433961637	ADEE79	1307 514894	ALEKSEY ANDREEV	{"phone": "+70199336410"}
0005433961638	5B10DA	8207 840961	DENIS VOROBEV	{"phone": "+70459364042"}
0005433961639	3BF92C	5510 112929	NIKOLAY NIKOLAEV	{"phone": "+70651327952"}
0005433961640	3BF92C	7508 920401	MIKHAIL VOROBEV	{"phone": "+70495781564"}
0005433961641	D8992E	0600 218049	EVGENIYA FILATOVA	{"email": "filatovaevgeniya.061981@postgrespro.ru", "phone": "+70123786063"}
0005433961642	D8992E	2781 849807	IRINA MEDVEDEVA	{"phone": "+70785981712"}
0005433961643	91B4E2	3429 056008	ALEKSEY GORBUNOV	{"phone": "+70830925616"}
0005433961644	91B4E2	4303 150168	ANDREY SMIRNOV	{"phone": "+70520974734"}
0005433961645	144739	6099 608816	DARYA KOMAROVA	{"phone": "+70330380116"}
0005433961646	2ACEB0	2464 677778	ALEKSANDR SMIRNOV	{"phone": "+70640201546"}
0005433961647	59A08F	0105 766421	ELENA KOZLOVA	{"email": "elena-kozlova.101965@postgrespro.ru", "phone": "+70432563555"}
0005433961648	F14050	5631 755597	YULIYA ZHURAVLEVA	{"phone": "+70172348106"}
0005433961649	27D15B	4292 236031	EKATERINA OVCHINNIKOVA	{"email": "ekaterina-ovchinnikova091967@postgrespro.ru", "phone": "+70952872865"}
0005433961650	5C6C3F	9890 024823	ANASTASIYA SEMENOVA	{"email": "semenova.anastasiya-13061966@postgrespro.ru", "phone": "+70606433313"}
0005433961651	69F077	8282 980790	IVAN MIKHAYLOV	{"phone": "+70788511678"}
0005433961652	56A3D4	5829 578965	ELENA MARTYNOVA	{"email": "martynovaelena17091976@postgrespro.ru", "phone": "+70781447239"}
0005433961653	B6C73D	5948 104351	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov-081975@postgrespro.ru", "phone": "+70602648766"}
0005433961654	C0EC30	0690 199480	DANIIL NOVIKOV	{"email": "dnovikov29111976@postgrespro.ru", "phone": "+70610712138"}
0005433961655	2A4CA5	9761 778713	NIKOLAY ALEKSANDROV	{"phone": "+70339760683"}
0005433961656	34768C	8066 391568	ALEKSANDR MOROZOV	{"phone": "+70837323941"}
0005433961657	3783D6	1064 259738	SERGEY CHERNOV	{"email": "chernov.s_15021967@postgrespro.ru", "phone": "+70351196493"}
0005433961658	1AFA16	1573 919148	VLADISLAV GAVRILOV	{"email": "gavrilov_vladislav-27081972@postgrespro.ru", "phone": "+70217140952"}
0005433961659	C5D721	4006 649377	ELENA LUKYANOVA	{"phone": "+70589974265"}
0005433961660	C5D721	4029 570011	ILYA PAVLOV	{"email": "pavlov_i-18091967@postgrespro.ru", "phone": "+70719014146"}
0005433961661	774CE6	7268 506028	TAMARA KUZNECOVA	{"phone": "+70036920492"}
0005433961662	F56339	9323 139792	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy27101973@postgrespro.ru", "phone": "+70497286997"}
0005433961663	205ED0	3017 356274	SVETLANA SOKOLOVA	{"phone": "+70920324839"}
0005433961664	ED1232	9940 175198	TATYANA PETROVA	{"email": "tpetrova20081968@postgrespro.ru", "phone": "+70598345239"}
0005433961665	49D6D9	3470 312723	ANDREY NOVIKOV	{"phone": "+70094752412"}
0005433961666	D6F506	4584 883573	VIKTOR SOKOLOV	{"email": "viktor_sokolov1967@postgrespro.ru", "phone": "+70985286248"}
0005433961667	4AC24B	5568 251553	NATALYA IVANOVA	{"email": "natalya_ivanova.11011972@postgrespro.ru", "phone": "+70694385119"}
0005433961668	AC9FD8	4395 750420	NIKOLAY POPOV	{"phone": "+70296613407"}
0005433961669	F822AC	6668 326919	OLGA MAKSIMOVA	{"phone": "+70038270780"}
0005433961670	F822AC	8755 418993	VIKTORIYA ISAEVA	{"phone": "+70572366286"}
0005433961671	967B7F	8399 178111	VITALIY MATVEEV	{"email": "vitaliy.matveev.021962@postgrespro.ru", "phone": "+70735164998"}
0005433961672	967B7F	5052 351374	ALEVTINA ZHUKOVA	{"email": "zhukova_a_1981@postgrespro.ru", "phone": "+70476390426"}
0005433961673	722BD3	7711 026617	VLADIMIR IVANOV	{"email": "v-ivanov.121978@postgrespro.ru", "phone": "+70420937374"}
0005433961674	033CCF	8028 592386	DENIS SOLOVEV	{"phone": "+70598098749"}
0005433961675	033CCF	9861 862796	TATYANA MAKAROVA	{"email": "tatyana-makarova-19041970@postgrespro.ru", "phone": "+70094145437"}
0005433961676	FE8582	1033 543093	TATYANA EFREMOVA	{"phone": "+70721266237"}
0005433961677	B12D91	8367 862695	TATYANA FROLOVA	{"email": "frolovat.091965@postgrespro.ru", "phone": "+70732503466"}
0005433961678	CF6F20	0468 829528	TATYANA FEDOROVA	{"email": "tatyana.fedorova111970@postgrespro.ru", "phone": "+70563769470"}
0005433961679	CF6F20	4887 798927	ELVINA SOLOVEVA	{"email": "elvina.soloveva-021976@postgrespro.ru", "phone": "+70967356230"}
0005433961680	75C1DE	8527 468675	NIKOLAY CHERNOV	{"email": "chernov-n27061974@postgrespro.ru", "phone": "+70422359934"}
0005433961681	157EB6	7156 753266	VIKTORIYA POPOVA	{"phone": "+70156998078"}
0005433961682	CFF7E4	3430 772012	YURIY SMIRNOV	{"email": "ysmirnov_1983@postgrespro.ru", "phone": "+70292749938"}
0005433961683	3743FC	9407 231159	LYUBOV IVANOVA	{"phone": "+70813361489"}
0005433961684	30AB8D	4453 491020	LYUDMILA LUKYANOVA	{"email": "lyudmila_lukyanova-051969@postgrespro.ru", "phone": "+70678169023"}
0005433961685	30AB8D	9537 366913	NADEZHDA ROMANOVA	{"phone": "+70971277664"}
0005433961686	C07603	7960 621631	SERGEY OSIPOV	{"phone": "+70377380537"}
0005433961687	FFA5A0	5763 010990	YULIYA KOZLOVA	{"email": "y_kozlova_1965@postgrespro.ru", "phone": "+70435017725"}
0005433961688	FFA5A0	5490 209075	SERGEY MATVEEV	{"email": "matveev-sergey.111971@postgrespro.ru", "phone": "+70472488484"}
0005433961689	762969	8377 289552	LEONID ZAKHAROV	{"email": "zakharov.leonid-09051965@postgrespro.ru", "phone": "+70963781715"}
0005433961690	5F95F5	4558 375678	EKATERINA RODIONOVA	{"email": "rodionova_e_05021964@postgrespro.ru", "phone": "+70330320332"}
0005433961691	F0BE45	0229 280676	ANATOLIY ANDREEV	{"phone": "+70172459929"}
0005433961692	BAA0F8	0340 988341	SERGEY NOVIKOV	{"phone": "+70749307446"}
0005433961693	E5DB47	0447 710047	VASILIY ANTONOV	{"phone": "+70999401784"}
0005433961694	E5DB47	9438 389189	EVGENIY MOROZOV	{"email": "emorozov-121974@postgrespro.ru", "phone": "+70367207990"}
0005433961695	90DAA8	6664 104067	SERGEY SMIRNOV	{"email": "s_smirnov_1961@postgrespro.ru", "phone": "+70162847816"}
0005433961696	346FB0	0324 356795	OLEG KRASNOV	{"phone": "+70363477323"}
0005433961697	346FB0	0110 110624	ALENA IVANOVA	{"phone": "+70215753099"}
0005433961698	A4FAB6	3520 133440	MAKSIM DAVYDOV	{"email": "m.davydov.15011971@postgrespro.ru", "phone": "+70057271689"}
0005433961699	A4FAB6	8502 431006	YANA MIKHAYLOVA	{"email": "mikhaylova_y.28051985@postgrespro.ru", "phone": "+70048205143"}
0005433961700	55D284	9028 991696	IVAN SEMENOV	{"email": "isemenov021980@postgrespro.ru", "phone": "+70597623161"}
0005433961701	3383B2	6952 707816	ANDREY ABRAMOV	{"phone": "+70734449911"}
0005433961702	317385	9643 498313	YANA RODIONOVA	{"phone": "+70621305876"}
0005433961703	AEEE7E	8374 675852	GALINA BELYAEVA	{"email": "g.belyaeva_1968@postgrespro.ru", "phone": "+70022983047"}
0005433961704	F7AE7B	2622 037255	ARTEM KUDRYASHOV	{"email": "artem.kudryashov-09011985@postgrespro.ru", "phone": "+70935862395"}
0005433961705	5AF396	1444 185194	IRINA ZAKHAROVA	{"email": "irina-zakharova.10121967@postgrespro.ru", "phone": "+70346836611"}
0005433961706	72B7C3	8744 962226	SERGEY GORBUNOV	{"email": "gorbunovsergey_031980@postgrespro.ru", "phone": "+70697868886"}
0005433961707	5A49D3	0753 149529	ELENA GUSEVA	{"phone": "+70002582698"}
0005433961708	FA9E6C	8974 376897	ANASTASIYA PAVLOVA	{"phone": "+70686108715"}
0005433961709	DACDC7	5127 566561	ELVIRA NIKIFOROVA	{"phone": "+70076197590"}
0005433961710	DACDC7	3864 194145	DMITRIY ZHURAVLEV	{"email": "zhuravlev.dmitriy1975@postgrespro.ru", "phone": "+70116262408"}
0005433961711	603E70	2446 376008	SERGEY ISAEV	{"phone": "+70120717471"}
0005433961712	58D985	2383 473878	VLADIMIR MARTYNOV	{"email": "martynovv-081977@postgrespro.ru", "phone": "+70742585975"}
0005433961713	AB8FCA	4840 115006	ANASTASIYA ROMANOVA	{"phone": "+70454052707"}
0005433961714	C0D84E	0671 246610	ELENA ALEKSEEVA	{"phone": "+70491801185"}
0005433961715	C0D84E	9026 028593	SEMEN FEDOROV	{"email": "s.fedorov01031964@postgrespro.ru", "phone": "+70448467556"}
0005433961716	F3CE2E	8739 934045	GEORGIY DAVYDOV	{"email": "davydov.georgiy.03011974@postgrespro.ru", "phone": "+70756877377"}
0005433961717	C765B5	4879 784122	OLGA MIKHAYLOVA	{"phone": "+70883072927"}
0005433961718	C765B5	8438 120863	NINA EGOROVA	{"email": "ninaegorova1968@postgrespro.ru", "phone": "+70263106281"}
0005433961719	BA9ABD	9124 125826	NIKOLAY FILIPPOV	{"phone": "+70868395808"}
0005433961720	6CD5FD	8948 401979	GULNARA KOZLOVA	{"email": "kozlovag051965@postgrespro.ru", "phone": "+70347920135"}
0005433961721	6CD5FD	1034 189249	ARKADIY PETROV	{"phone": "+70468619233"}
0005433961722	43252D	1875 081845	LYUBOV NESTEROVA	{"email": "nesterova_l-29051968@postgrespro.ru", "phone": "+70079008109"}
0005433961723	8986FB	5700 838944	TAMARA BELOVA	{"email": "t-belova_101958@postgrespro.ru", "phone": "+70959406893"}
0005433961724	5E3251	4919 567505	SERGEY OSIPOV	{"email": "osipov.sergey1969@postgrespro.ru", "phone": "+70620220447"}
0005433961725	5E3251	4267 870817	IVAN MIKHAYLOV	{"phone": "+70469825598"}
0005433961726	9B3F48	9592 126091	VALENTINA FILATOVA	{"email": "vfilatova-031979@postgrespro.ru", "phone": "+70714706968"}
0005433961727	3B1791	5553 551882	ANNA LUKYANOVA	{"email": "a-lukyanova031973@postgrespro.ru", "phone": "+70960422127"}
0005433961728	65B9DA	1736 660693	TATYANA YUDINA	{"phone": "+70569278827"}
0005433961729	2858DE	1333 698672	VALENTINA ALEKSEEVA	{"email": "alekseeva.v_24101961@postgrespro.ru", "phone": "+70550778907"}
0005433961730	546E4F	5792 791867	GEORGIY MARTYNOV	{"email": "martynov_g-1966@postgrespro.ru", "phone": "+70861236789"}
0005433961731	680593	3367 361777	EVA TIKHONOVA	{"phone": "+70104611965"}
0005433961732	442F35	8255 097900	EVGENIY IVANOV	{"phone": "+70975622139"}
0005433961733	7F794C	9016 798633	LIDIYA DAVYDOVA	{"phone": "+70949108764"}
0005433961734	7F794C	6772 187677	LEONID KULIKOV	{"email": "kulikov-l-051970@postgrespro.ru", "phone": "+70134275355"}
0005433961735	608B51	1964 448040	VYACHESLAV EGOROV	{"phone": "+70069129970"}
0005433961736	608B51	3997 065888	MARIYA MARTYNOVA	{"phone": "+70395120500"}
0005433961737	608B51	2014 981284	YULIYA VOROBEVA	{"email": "vorobeva_yuliya-091975@postgrespro.ru", "phone": "+70472233878"}
0005433961738	608B51	3977 033641	NIKOLAY KUDRYASHOV	{"email": "kudryashov-n.121976@postgrespro.ru", "phone": "+70893344327"}
0005433961739	D6EF1A	3205 280090	MATVEY ORLOV	{"email": "m-orlov_15081972@postgrespro.ru", "phone": "+70075348866"}
0005433961740	C1C1A1	3738 292714	VALERIY SOLOVEV	{"email": "solovevv.21121964@postgrespro.ru", "phone": "+70892659457"}
0005433961741	0E9731	3486 994484	ALEKSANDR PAVLOV	{"phone": "+70679928777"}
0005433961742	0E9731	5822 342218	OLGA LAZAREVA	{"phone": "+70455469603"}
0005433961743	1D86E6	4123 214749	TATYANA NAZAROVA	{"email": "nazarova_t-031969@postgrespro.ru", "phone": "+70482862597"}
0005433961744	4D98F5	6173 993520	DMITRIY KOZLOV	{"email": "dmitriy.kozlov021969@postgrespro.ru", "phone": "+70797339573"}
0005433961745	7CD082	9750 485183	VERA ANDREEVA	{"phone": "+70477072534"}
0005433961746	7CD082	7343 917686	VLADIMIR PAVLOV	{"email": "vladimir_pavlov_091983@postgrespro.ru", "phone": "+70381056570"}
0005433961747	5D8BD4	6600 674406	ELIZAVETA VOROBEVA	{"phone": "+70489345764"}
0005433961748	5D8BD4	8815 781287	ANATOLIY FROLOV	{"phone": "+70928070199"}
0005433961749	C1BEDE	8018 853043	IVAN BARANOV	{"phone": "+70399494979"}
0005433961750	F864D0	5989 433884	NATALYA STEPANOVA	{"email": "stepanova_natalya-25031977@postgrespro.ru", "phone": "+70772758805"}
0005433961751	F864D0	6977 699641	GALINA GERASIMOVA	{"email": "gerasimova.galina1982@postgrespro.ru", "phone": "+70757310981"}
0005433961752	745F80	1371 234856	RUSLAN KRASNOV	{"email": "krasnov.r.071971@postgrespro.ru", "phone": "+70380637147"}
0005433961753	33376E	3039 978540	YURIY NIKITIN	{"phone": "+70441659234"}
0005433961754	33376E	9727 780980	VASILIY MAKAROV	{"email": "vasiliymakarov-22051972@postgrespro.ru", "phone": "+70472092928"}
0005433961755	D9B5E0	5024 200916	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga-071971@postgrespro.ru", "phone": "+70480181380"}
0005433961756	D41B23	9723 478759	VADIM SEMENOV	{"phone": "+70506034091"}
0005433961757	D41B23	8332 538934	YULIYA KUZMINA	{"phone": "+70126963429"}
0005433961758	A8307E	8727 703782	ALEKSANDR AFANASEV	{"phone": "+70050908121"}
0005433961759	3028EF	8073 737567	POLINA BARANOVA	{"phone": "+70766506288"}
0005433961760	3028EF	3831 196959	VIKTOR KUZMIN	{"email": "viktor_kuzmin061975@postgrespro.ru", "phone": "+70366172002"}
0005433961761	438945	9229 527554	DARYA VOLKOVA	{"phone": "+70322569643"}
0005433961762	F288C2	0209 746360	ALEKSEY ZAYCEV	{"phone": "+70053475610"}
0005433961763	612696	5553 249248	VLADIMIR SCHERBAKOV	{"phone": "+70589758424"}
0005433961764	A82FEA	5144 365580	MAKSIM KONOVALOV	{"email": "maksim_konovalov.041962@postgrespro.ru", "phone": "+70446768213"}
0005433961765	76B6FC	2316 609267	DANILA RODIONOV	{"phone": "+70707252055"}
0005433961766	CFB180	4478 543240	OLGA ILINA	{"email": "ilina-olga.07111964@postgrespro.ru", "phone": "+70879491888"}
0005433961767	CFB180	4083 922512	VALENTINA RYABOVA	{"email": "v.ryabova.111978@postgrespro.ru", "phone": "+70937889344"}
0005433961768	5D5689	8296 321891	GALINA MAKAROVA	{"phone": "+70874950905"}
0005433961769	5D5689	5990 806828	NADIYA STEPANOVA	{"email": "nadiya-stepanova_11101953@postgrespro.ru", "phone": "+70010556788"}
0005433961770	5D5689	6807 515758	VALENTINA SEMENOVA	{"email": "valentina_semenova_091971@postgrespro.ru", "phone": "+70026308750"}
0005433961771	5D5689	3354 219110	ALEKSANDR GUSEV	{"email": "agusev041975@postgrespro.ru", "phone": "+70620168522"}
0005433961772	D4B171	8719 750903	RAISA SOLOVEVA	{"email": "solovevar1979@postgrespro.ru", "phone": "+70072156313"}
0005433961773	E5E8B8	6449 675281	NATALYA FEDOROVA	{"email": "fedorova.n-091985@postgrespro.ru", "phone": "+70334377372"}
0005433961774	A4089C	1760 852669	EVGENIY IVANOV	{"phone": "+70986168544"}
0005433961775	E4C5AF	7396 964555	EVGENIYA POTAPOVA	{"phone": "+70900567068"}
0005433961776	E4C5AF	4544 366398	EMILIYA IVANOVA	{"email": "emiliya.ivanova.1969@postgrespro.ru", "phone": "+70964814295"}
0005433961777	F794AD	4613 302110	MAKSIM GUSEV	{"phone": "+70182660714"}
0005433961778	BF1CC9	4755 702149	IGOR ISAEV	{"email": "isaev.i_1984@postgrespro.ru", "phone": "+70396791012"}
0005433961779	120224	4790 696320	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey.101967@postgrespro.ru", "phone": "+70880343976"}
0005433961780	2E3C1B	7787 032794	GALINA ANISIMOVA	{"email": "g-anisimova-061983@postgrespro.ru", "phone": "+70550239003"}
0005433961781	7346BB	1600 545231	LILIYA FILATOVA	{"phone": "+70060048588"}
0005433961782	15C186	3052 143559	GENNADIY SIDOROV	{"email": "sidorov_gennadiy_27101974@postgrespro.ru", "phone": "+70753301543"}
0005433961783	477F6C	5718 629708	OLESYA ORLOVA	{"email": "o.orlova-09101978@postgrespro.ru", "phone": "+70615456496"}
0005433961784	1CF463	9527 363797	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr_01121981@postgrespro.ru", "phone": "+70057092412"}
0005433961785	18E971	7576 942482	ALEKSANDR ZHURAVLEV	{"email": "azhuravlev-1963@postgrespro.ru", "phone": "+70274767505"}
0005433961786	042D5F	6583 501590	MARAT MAKSIMOV	{"phone": "+70640175326"}
0005433961787	2FC507	8509 186893	VALERIY TIKHONOV	{"email": "tikhonov.v.081967@postgrespro.ru", "phone": "+70459862159"}
0005433961788	17A36A	0808 415080	TALGAT MARTYNOV	{"phone": "+70129466572"}
0005433961789	17A36A	8800 494469	MILANA ANTONOVA	{"phone": "+70158714671"}
0005433961790	C57A68	0607 382390	VLADIMIR ILIN	{"phone": "+70971251909"}
0005433961791	6A7533	3553 338056	ALINA TIKHONOVA	{"phone": "+70252556554"}
0005433961792	6A7533	3405 124789	RAMIL MELNIKOV	{"email": "ramil_melnikov-1979@postgrespro.ru", "phone": "+70242000337"}
0005433961793	6A7533	9468 781977	IVAN ALEKSEEV	{"phone": "+70546756921"}
0005433961794	331AF6	8136 481410	SVETLANA KONOVALOVA	{"email": "skonovalova_10051978@postgrespro.ru", "phone": "+70736617125"}
0005433961795	FC2C4F	6407 464032	NIKOLAY CHERNOV	{"phone": "+70590082685"}
0005433961796	FC2C4F	8260 986291	ALINA KOZLOVA	{"email": "alina.kozlova_21111967@postgrespro.ru", "phone": "+70914884308"}
0005433961797	B919AF	2159 623988	YURIY KUZNECOV	{"phone": "+70780842840"}
0005433961798	4E934F	6833 278821	OLEG SMIRNOV	{"phone": "+70165205787"}
0005433961799	FDCB7A	9084 202279	VERA NESTEROVA	{"email": "nesterova-vera_26011972@postgrespro.ru", "phone": "+70344995295"}
0005433961800	CA027F	6648 802261	TATYANA ILINA	{"phone": "+70066490534"}
0005433961801	001F27	7931 634472	NATALIYA ANTONOVA	{"email": "antonova_n_01011978@postgrespro.ru", "phone": "+70442995321"}
0005433961802	291F5B	3198 977520	SERGEY MIRONOV	{"email": "sergey-mironov.03031973@postgrespro.ru", "phone": "+70522063683"}
0005433961803	291F5B	3813 554660	VIKTOR NIKOLAEV	{"phone": "+70913022136"}
0005433961804	157ADF	8826 393945	MARIYA KOMAROVA	{"phone": "+70022812498"}
0005433961805	BBB0A3	4817 091983	IVAN DENISOV	{"email": "denisov_i.02041969@postgrespro.ru", "phone": "+70634138094"}
0005433961806	C12D3C	4123 586237	OLGA EGOROVA	{"phone": "+70572362040"}
0005433961807	C12D3C	9189 056013	VIKTOR NOVIKOV	{"email": "novikov.viktor.091980@postgrespro.ru", "phone": "+70372878049"}
0005433961808	952283	7966 292753	TAMARA MELNIKOVA	{"email": "t-melnikova-08031971@postgrespro.ru", "phone": "+70888573933"}
0005433961809	FCE512	8421 621901	ANATOLIY MEDVEDEV	{"phone": "+70497435175"}
0005433961810	2561BE	3968 384627	VALERIYA STEPANOVA	{"phone": "+70332249111"}
0005433961811	63CFB4	5441 723210	VALENTINA SIDOROVA	{"phone": "+70818160215"}
0005433961812	63CFB4	3263 625613	SERGEY ROMANOV	{"phone": "+70783005038"}
0005433961813	FA9FDA	8211 100699	NATALYA KRASNOVA	{"email": "n.krasnova.1971@postgrespro.ru", "phone": "+70591657077"}
0005433961814	FA9FDA	6464 329529	RAISA PAVLOVA	{"phone": "+70027781096"}
0005433961815	4E1604	1209 547522	ANNA KOROLEVA	{"phone": "+70118892519"}
0005433961816	4E1604	0990 327243	IVAN BELOV	{"email": "belov_ivan-071967@postgrespro.ru", "phone": "+70042864907"}
0005433961817	8F1408	5147 470403	ANATOLIY IVANOV	{"email": "ivanov-a.13071976@postgrespro.ru", "phone": "+70114171546"}
0005433961818	8F1408	5558 196627	ALEKSEY ZAKHAROV	{"phone": "+70339967154"}
0005433961819	4C2663	3766 424435	MATVEY KOZLOV	{"email": "mkozlov-15081966@postgrespro.ru", "phone": "+70344660830"}
0005433961820	4C2663	4329 845388	VLADISLAV SMIRNOV	{"email": "v-smirnov-031979@postgrespro.ru", "phone": "+70053408062"}
0005433961821	4C2663	1038 898095	ALEKSANDR VASILEV	{"email": "a-vasilev_011968@postgrespro.ru", "phone": "+70022509703"}
0005433961822	01B5C3	1339 505634	ELENA VASILEVA	{"phone": "+70329426175"}
0005433961823	01B5C3	6666 886872	NIKOLAY SEMENOV	{"email": "n_semenov1970@postgrespro.ru", "phone": "+70032708777"}
0005433961824	DCFDD9	8541 695100	VERA KUZNECOVA	{"email": "vkuznecova-031970@postgrespro.ru", "phone": "+70837816983"}
0005433961825	DCFDD9	1181 552244	ELVIRA ZAKHAROVA	{"email": "e-zakharova_25061973@postgrespro.ru", "phone": "+70880979894"}
0005433961826	DC946F	5598 635104	TAGIR KOZLOV	{"email": "kozlov.tagir.081974@postgrespro.ru", "phone": "+70788413552"}
0005433961827	15416A	9424 349839	ALEKSANDRA ZAKHAROVA	{"email": "aleksandra_zakharova_28011973@postgrespro.ru", "phone": "+70231586157"}
0005433961828	52B1DE	3169 269211	VIKTORIYA MAKAROVA	{"phone": "+70908753500"}
0005433961829	A9CE92	8544 735208	ALEKSANDR KUZMIN	{"email": "a_kuzmin_1967@postgrespro.ru", "phone": "+70791363150"}
0005433961830	A9CE92	0997 973520	EKATERINA PAVLOVA	{"phone": "+70601488117"}
0005433961831	82CA52	7263 265005	YULIYA NIKOLAEVA	{"email": "nikolaeva.yuliya.071964@postgrespro.ru", "phone": "+70563405316"}
0005433961832	B31386	7611 756470	VALENTINA SERGEEVA	{"email": "sergeevavalentina021966@postgrespro.ru", "phone": "+70788958705"}
0005433961833	52711D	4583 733803	VIKTORIYA SOROKINA	{"phone": "+70613424878"}
0005433961834	45EFA1	6608 015081	IVAN VASILEV	{"email": "vasilev_ivan_1965@postgrespro.ru", "phone": "+70836525750"}
0005433961835	1EF30C	7461 317759	ALESYA VASILEVA	{"email": "vasileva_a_011967@postgrespro.ru", "phone": "+70968890886"}
0005433961836	E8391B	6703 594543	YULIYA TITOVA	{"email": "titova.yuliya_1971@postgrespro.ru", "phone": "+70932321722"}
0005433961837	8FB7BD	8190 452509	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-1960@postgrespro.ru", "phone": "+70707563920"}
0005433961838	CD5391	9600 201732	DMITRIY PETROV	{"phone": "+70288830091"}
0005433961839	F09820	7378 072479	VITALIY TIMOFEEV	{"email": "v_timofeev_1961@postgrespro.ru", "phone": "+70311649336"}
0005433961840	F09820	8509 758858	LIDIYA MAKAROVA	{"email": "makarovalidiya051971@postgrespro.ru", "phone": "+70551914029"}
0005433961841	050113	4615 905318	LEV SERGEEV	{"phone": "+70921829774"}
0005433961842	87FB19	2665 015079	TATYANA ZHUKOVA	{"phone": "+70746625217"}
0005433961843	87FB19	5962 284220	TAMARA NESTEROVA	{"phone": "+70299297956"}
0005433961844	47525B	6099 905281	OLGA ILINA	{"email": "ilina_olga.24121978@postgrespro.ru", "phone": "+70913249016"}
0005433961845	47525B	5630 912849	RAIL ABRAMOV	{"email": "abramov_r_08041974@postgrespro.ru", "phone": "+70982076920"}
0005433961846	B096A0	9619 908324	ALEKSANDR FROLOV	{"phone": "+70298195825"}
0005433961847	23CFD0	5691 532424	ANASTASIYA FEDOROVA	{"email": "anastasiya-fedorova-071970@postgrespro.ru", "phone": "+70834242540"}
0005433961848	23CFD0	9090 820868	NADEZHDA POTAPOVA	{"phone": "+70971450200"}
0005433961849	C2B0E9	2887 886319	VIKTOR FEDOTOV	{"email": "viktor-fedotov-21051971@postgrespro.ru", "phone": "+70590606777"}
0005433961850	C2B0E9	9809 428774	ALEKSANDR ANDREEV	{"phone": "+70194554177"}
0005433961851	14A2FD	0564 367849	INNA DENISOVA	{"email": "i_denisova.081972@postgrespro.ru", "phone": "+70349538345"}
0005433961852	8BADEC	8205 118655	ANASTASIYA EGOROVA	{"phone": "+70381672502"}
0005433961853	5CBF5A	1951 411098	ANTON SAVELEV	{"email": "savelev.a1965@postgrespro.ru", "phone": "+70192026497"}
0005433961854	C02EC1	9867 411215	GENNADIY SOROKIN	{"email": "soroking-03081975@postgrespro.ru", "phone": "+70353743332"}
0005433961855	D867CE	2766 405786	ALLA OVCHINNIKOVA	{"phone": "+70212844673"}
0005433961856	7B222B	8663 341919	NATALYA KUZNECOVA	{"email": "nkuznecova12051979@postgrespro.ru", "phone": "+70565949254"}
0005433961857	7B222B	5945 057463	SERGEY KRASNOV	{"email": "s-krasnov_031969@postgrespro.ru", "phone": "+70780491777"}
0005433961858	4C3A0F	3370 032501	ANASTASIYA MIKHAYLOVA	{"phone": "+70847906722"}
0005433961859	4C3A0F	1275 822879	MARINA PETROVA	{"phone": "+70111637507"}
0005433961860	D9C1CC	0592 710715	VIKTOR ILIN	{"email": "viktor_ilin1981@postgrespro.ru", "phone": "+70281106796"}
0005433961861	2BE0A1	1278 518706	RAIL KOZLOV	{"email": "rail.kozlov1969@postgrespro.ru", "phone": "+70603395022"}
0005433961862	CED3B4	9624 497425	LYUDMILA PAVLOVA	{"email": "pavloval1976@postgrespro.ru", "phone": "+70438262682"}
0005433961863	BE7A56	9476 124671	NINA ALEKSEEVA	{"email": "alekseeva_n-1981@postgrespro.ru", "phone": "+70990573600"}
0005433961864	BE7A56	9334 869763	NADEZHDA ZOTOVA	{"phone": "+70908602632"}
0005433961865	CF08A3	7921 296814	VALENTINA MOISEEVA	{"phone": "+70085850203"}
0005433961866	CF08A3	8345 891240	LYUBOV KAZAKOVA	{"phone": "+70667511259"}
0005433961867	41068E	4797 037479	DMITRIY FEDOROV	{"email": "dmitriy.fedorov.28021969@postgrespro.ru", "phone": "+70105075560"}
0005433961868	73C8A5	7302 962189	SERGEY DENISOV	{"email": "denisov_s021974@postgrespro.ru", "phone": "+70862731114"}
0005433961869	73C8A5	6357 818923	VLADIMIR ZHURAVLEV	{"email": "zhuravlevv21031985@postgrespro.ru", "phone": "+70339057750"}
0005433961870	47A1E9	3652 734360	PAVEL OSIPOV	{"email": "osipovp_1972@postgrespro.ru", "phone": "+70110179990"}
0005433961871	47A1E9	0134 341255	ANASTASIYA MELNIKOVA	{"phone": "+70450529909"}
0005433961872	D89033	2622 921091	ARTEM MEDVEDEV	{"email": "medvedeva_1969@postgrespro.ru", "phone": "+70906503615"}
0005433961873	E6800E	6168 796777	LYUBOV KOLESNIKOVA	{"phone": "+70749091857"}
0005433961874	C7B8D2	6779 000592	ELENA KAZAKOVA	{"phone": "+70075337609"}
0005433961875	F3024C	2406 861756	VLADIMIR ILIN	{"phone": "+70097923124"}
0005433961876	F3024C	7494 698934	EGOR KUZNECOV	{"phone": "+70777405980"}
0005433961877	908ABA	7522 058991	YURIY AFANASEV	{"email": "afanasev_y101975@postgrespro.ru", "phone": "+70385664038"}
0005433961878	908ABA	0261 690841	ANTONINA NIKOLAEVA	{"email": "nikolaeva.a_1971@postgrespro.ru", "phone": "+70821830875"}
0005433961879	908ABA	1515 659071	ALEKSEY ORLOV	{"phone": "+70094718276"}
0005433961880	F93AA1	5168 409391	ANATOLIY MAKSIMOV	{"phone": "+70597000159"}
0005433961881	479FB0	1426 847762	AIDA KAZAKOVA	{"phone": "+70680542693"}
0005433961882	479FB0	5402 756125	ALEKSEY KARPOV	{"email": "karpov.a.02121968@postgrespro.ru", "phone": "+70607991493"}
0005433961883	10EC9B	3874 476128	ANDREY KUZNECOV	{"phone": "+70262845508"}
0005433961884	10EC9B	3544 657969	TATYANA EFREMOVA	{"phone": "+70141258635"}
0005433961885	10EC9B	6599 862855	ALEKSANDR MARTYNOV	{"email": "martynov_aleksandr_30121964@postgrespro.ru", "phone": "+70092770350"}
0005433961886	546ACF	3308 436787	VALENTIN MATVEEV	{"email": "v.matveev09101977@postgrespro.ru", "phone": "+70099111849"}
0005433961887	546ACF	3542 181839	MIKHAIL ALEKSANDROV	{"email": "mikhail-aleksandrov1959@postgrespro.ru", "phone": "+70525368416"}
0005433961888	546ACF	0940 515519	IRINA NESTEROVA	{"email": "nesterova_i_101975@postgrespro.ru", "phone": "+70187365973"}
0005433961889	6D1C21	2040 128732	VALENTINA KONDRATEVA	{"email": "valentina-kondrateva.1973@postgrespro.ru", "phone": "+70720882446"}
0005433961890	6D1C21	1101 860092	PAVEL MIKHAYLOV	{"email": "p_mikhaylov1971@postgrespro.ru", "phone": "+70683719599"}
0005433961891	24B142	9842 339749	EVGENIYA PETROVA	{"phone": "+70139197656"}
0005433961892	24B142	2315 762362	NIKOLAY ZAKHAROV	{"email": "zakharovn_071962@postgrespro.ru", "phone": "+70817706807"}
0005433961893	24B142	1277 152613	NINA KOZLOVA	{"email": "kozlova-nina_25081965@postgrespro.ru", "phone": "+70104459287"}
0005433961894	C597EA	3667 993031	MARIYA KRASNOVA	{"email": "m-krasnova_13091977@postgrespro.ru", "phone": "+70680155244"}
0005433961895	E72A89	1423 025124	ELENA ROMANOVA	{"email": "romanovaelena-23011967@postgrespro.ru", "phone": "+70890348982"}
0005433961896	B8D5C0	1750 349793	EVGENIY KOROLEV	{"email": "korolev-e_1974@postgrespro.ru", "phone": "+70982388008"}
0005433961897	FA4FD8	6394 585253	ANTONINA ALEKSEEVA	{"email": "alekseevaantonina.121974@postgrespro.ru", "phone": "+70393578926"}
0005433961898	FA4FD8	0497 778646	MARINA BORISOVA	{"email": "m_borisova_1967@postgrespro.ru", "phone": "+70545177494"}
0005433961899	EB6516	0415 507280	ELENA NIKITINA	{"email": "elenanikitina.051976@postgrespro.ru", "phone": "+70863288382"}
0005433961900	EBF2F5	3039 353552	ANATOLIY KOZLOV	{"phone": "+70309549496"}
0005433961901	203FB0	4357 452458	ALEKSANDR IVANOV	{"phone": "+70194589725"}
0005433961902	8F008B	5503 980040	ANTON ZAKHAROV	{"phone": "+70638028708"}
0005433961903	EAECDB	4432 597044	ARSENIY SOKOLOV	{"phone": "+70293451937"}
0005433961904	D47069	7012 120461	SERGEY VOROBEV	{"phone": "+70680384320"}
0005433961905	7E816F	2036 189054	SERGEY OSIPOV	{"email": "s_osipov041968@postgrespro.ru", "phone": "+70634432404"}
0005433961906	21CDBC	0155 428944	NADEZHDA STEPANOVA	{"phone": "+70716118361"}
0005433961907	55BD58	4739 791700	TATYANA ZHURAVLEVA	{"phone": "+70980504562"}
0005433961908	2FDF2A	1193 913735	ALEKSEY TIKHONOV	{"email": "tikhonov_a-011968@postgrespro.ru", "phone": "+70242306626"}
0005433961909	409DE3	0828 415292	SVETLANA FILATOVA	{"email": "sfilatova-13011970@postgrespro.ru", "phone": "+70182101413"}
0005433961910	409DE3	2558 307479	RADIK FEDOTOV	{"phone": "+70182781044"}
0005433961911	6986E6	1253 333671	ALINA SAVELEVA	{"phone": "+70208246061"}
0005433961912	6986E6	9213 841730	IGOR SOROKIN	{"phone": "+70540744475"}
0005433961913	6986E6	2505 299214	MARIYA PETROVA	{"phone": "+70547365279"}
0005433961914	72EBDE	5506 128320	NATALYA KOVALEVA	{"email": "kovaleva_n.1974@postgrespro.ru", "phone": "+70602106662"}
0005433961915	E6CB6D	3702 166886	ROSTISLAV KUZNECOV	{"email": "kuznecov.r_021978@postgrespro.ru", "phone": "+70741355752"}
0005433961916	874E1D	9925 812213	ELENA VOLKOVA	{"email": "elena_volkova1975@postgrespro.ru", "phone": "+70264832461"}
0005433961917	76691A	3517 789011	LIDIYA LEBEDEVA	{"phone": "+70410618418"}
0005433961918	76691A	5807 077885	ANDREY MIKHAYLOV	{"phone": "+70941756617"}
0005433961919	783282	8248 400014	MAKSIM MEDVEDEV	{"phone": "+70151082499"}
0005433961920	77CD15	5869 936825	ELENA NAZAROVA	{"email": "nazarova-e01101981@postgrespro.ru", "phone": "+70583132723"}
0005433961921	77CD15	5103 167876	RUSLAN KAZAKOV	{"phone": "+70052683133"}
0005433961922	0F007B	2291 224187	IVAN STEPANOV	{"email": "i.stepanov-091974@postgrespro.ru", "phone": "+70287344735"}
0005433961923	6F8B24	2854 039494	ANATOLIY KOZLOV	{"phone": "+70876596080"}
0005433961924	0C16BB	3625 435113	LIDIYA OVCHINNIKOVA	{"phone": "+70709549791"}
0005433961925	0C16BB	0424 524651	OLGA ISAEVA	{"email": "isaeva.o-13091968@postgrespro.ru", "phone": "+70026716648"}
0005433961926	911483	2460 882443	VLADIMIR MAKAROV	{"email": "v.makarov-1964@postgrespro.ru", "phone": "+70609420809"}
0005433961927	B8D2EA	7783 609185	GALINA ZOTOVA	{"phone": "+70566500712"}
0005433961928	B8D2EA	6178 882549	LYUDMILA TITOVA	{"phone": "+70944280509"}
0005433961929	0D78D7	7413 950019	GRIGORIY TIKHONOV	{"phone": "+70671015940"}
0005433961930	0D78D7	8828 326797	ANVAR ZAKHAROV	{"phone": "+70561890416"}
0005433961931	2B358F	0310 960455	NATALYA SOKOLOVA	{"email": "n_sokolova.03121977@postgrespro.ru", "phone": "+70347508632"}
0005433961932	2B358F	3866 995808	SERGEY ILIN	{"email": "ilinsergey_011967@postgrespro.ru", "phone": "+70032237822"}
0005433961933	326AB9	2821 572204	ALEKSANDR ZAYCEV	{"email": "zaycevaleksandr-07021964@postgrespro.ru", "phone": "+70542605332"}
0005433961934	ED7801	9049 126042	ALEKSEY POPOV	{"phone": "+70880744072"}
0005433961935	DFA4B3	0613 653061	LYUBOV LUKYANOVA	{"email": "llukyanova_111977@postgrespro.ru", "phone": "+70122966963"}
0005433961936	DFA4B3	3222 005952	NIKOLAY NAZAROV	{"email": "nazarov.nikolay.10111976@postgrespro.ru", "phone": "+70340231536"}
0005433961937	60624F	2596 777880	YURIY IVANOV	{"phone": "+70716042221"}
0005433961938	60624F	8672 580405	EKATERINA MIKHAYLOVA	{"email": "mikhaylovae_11041977@postgrespro.ru", "phone": "+70041950898"}
0005433961939	DF3EFD	6121 415103	VALERIY NAUMOV	{"phone": "+70844612939"}
0005433961940	DF3EFD	0092 997720	SERGEY POPOV	{"phone": "+70809323241"}
0005433961941	B0D28D	5435 379088	VIKTOR FEDOROV	{"email": "viktor-fedorov-031958@postgrespro.ru", "phone": "+70498370136"}
0005433961942	EA7EA7	6824 306300	ALEKSANDR NOVIKOV	{"phone": "+70755432220"}
0005433961943	59176C	1502 385357	MARIYA ZOTOVA	{"email": "zotova-mariya.081976@postgrespro.ru", "phone": "+70752531912"}
0005433961944	1C637C	2163 401454	NADEZHDA EFIMOVA	{"phone": "+70587909109"}
0005433961945	B45385	5776 990558	NINA DMITRIEVA	{"email": "dmitrieva.n_23101978@postgrespro.ru", "phone": "+70680416550"}
0005433961946	B45385	7106 500522	TAMARA POPOVA	{"phone": "+70263643557"}
0005433961947	D519C6	6486 651466	ISLAM SOKOLOV	{"phone": "+70347747943"}
0005433961948	68DFFD	0631 805155	SVETLANA AFANASEVA	{"phone": "+70903792557"}
0005433961949	E3D616	1159 459514	ILYA NIKOLAEV	{"email": "ilya.nikolaev_12011972@postgrespro.ru", "phone": "+70744634039"}
0005433961950	E3D616	4327 375049	OLGA NAZAROVA	{"email": "o-nazarova_091966@postgrespro.ru", "phone": "+70991599619"}
0005433961951	94F273	4942 875603	ARINA ZAYCEVA	{"email": "a-zayceva-1965@postgrespro.ru", "phone": "+70620361310"}
0005433961952	A132E2	4905 580729	TATYANA POTAPOVA	{"email": "potapova_tatyana1973@postgrespro.ru", "phone": "+70353813420"}
0005433961953	A132E2	1641 797690	VALERIY GORBUNOV	{"email": "gorbunov.valeriy.12091976@postgrespro.ru", "phone": "+70718673370"}
0005433961954	02D4D8	2199 967044	TAMARA ZAKHAROVA	{"phone": "+70476362162"}
0005433961955	70F735	2110 486168	ELIZAVETA DENISOVA	{"phone": "+70819641867"}
0005433961956	70F735	4193 792392	IRINA IVANOVA	{"email": "irina.ivanova.1966@postgrespro.ru", "phone": "+70079617339"}
0005433961957	38C4F9	5144 215096	VALERIY MELNIKOV	{"phone": "+70002148775"}
0005433961958	8BA2D4	7097 891146	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaaleksandra021968@postgrespro.ru", "phone": "+70687722601"}
0005433961959	8BA2D4	3042 568236	KONSTANTIN PAVLOV	{"email": "konstantinpavlov-31071976@postgrespro.ru", "phone": "+70782973617"}
0005433961960	7B642C	3907 038489	DMITRIY FEDOROV	{"email": "dmitriyfedorov1968@postgrespro.ru", "phone": "+70323085936"}
0005433961961	7B642C	4879 759581	EVGENIY SAVELEV	{"phone": "+70453259227"}
0005433961962	11907D	9438 777645	DENIS ILIN	{"phone": "+70150712211"}
0005433961963	11907D	2194 046385	NINA IVANOVA	{"email": "ivanova.nina-1973@postgrespro.ru", "phone": "+70186145542"}
0005433961964	680485	1568 253419	VYACHESLAV ZHUKOV	{"phone": "+70447652279"}
0005433961965	2091B2	1270 353747	NADEZHDA MARTYNOVA	{"email": "nadezhdamartynova1968@postgrespro.ru", "phone": "+70359306491"}
0005433961966	6EC8F8	0527 355618	RUFINA SMIRNOVA	{"email": "smirnovar.061968@postgrespro.ru", "phone": "+70249159054"}
0005433961967	28C74C	3540 215369	VIKTORIYA GORBUNOVA	{"email": "v.gorbunova-021977@postgrespro.ru", "phone": "+70085707506"}
0005433961968	28C74C	3980 389521	NIKOLAY CHERNOV	{"phone": "+70338875084"}
0005433961969	ECC81C	9776 160168	MAKSIM MOISEEV	{"phone": "+70743854784"}
0005433961970	12F804	4208 590553	VALENTINA DMITRIEVA	{"email": "dmitrieva_valentina1978@postgrespro.ru", "phone": "+70092205719"}
0005433961971	08CF15	1669 455956	RAISA KUZNECOVA	{"phone": "+70709553939"}
0005433961972	B1E83C	6113 470367	ILYA MIRONOV	{"email": "ilya.mironov-051970@postgrespro.ru", "phone": "+70305921811"}
0005433961973	B1E83C	9503 110568	VALENTINA KONOVALOVA	{"email": "valentina-konovalova.04051973@postgrespro.ru", "phone": "+70655360268"}
0005433961974	64E19A	0733 443619	SVETLANA DAVYDOVA	{"email": "s.davydova.1969@postgrespro.ru", "phone": "+70830180345"}
0005433961975	EFFDD4	6690 493076	VERA KUDRYASHOVA	{"phone": "+70549423694"}
0005433961976	C69E8B	7695 600254	BORIS CHERNOV	{"email": "chernovboris-22061976@postgrespro.ru", "phone": "+70131107676"}
0005433961977	765B86	1335 572086	YULIYA MOROZOVA	{"phone": "+70405902806"}
0005433961978	92C5F8	0107 738482	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr-081952@postgrespro.ru", "phone": "+70873421122"}
0005433961979	8F3578	5796 173217	VITALIY ZAKHAROV	{"email": "zakharov.vitaliy-041974@postgrespro.ru", "phone": "+70775568741"}
0005433961980	589DFC	9910 888555	LARISA MIKHAYLOVA	{"email": "l_mikhaylova.05071979@postgrespro.ru", "phone": "+70871076331"}
0005433961981	290951	1436 563626	TAISIYA ZAYCEVA	{"email": "t.zayceva.1977@postgrespro.ru", "phone": "+70988650828"}
0005433961982	32AB3C	8129 215459	SVETLANA POPOVA	{"email": "popova.s-1971@postgrespro.ru", "phone": "+70366763557"}
0005433961983	32AB3C	5270 105877	VENERA KUZNECOVA	{"email": "kuznecova_v01071961@postgrespro.ru", "phone": "+70061863247"}
0005433961984	32AB3C	1249 287590	ROMAN NAZAROV	{"email": "nazarov-roman22101976@postgrespro.ru", "phone": "+70475487795"}
0005433961985	386BE6	0115 779323	MATRENA EGOROVA	{"phone": "+70250807404"}
0005433961986	3C2E66	6730 967992	VLADISLAV POPOV	{"phone": "+70410899257"}
0005433961987	C1514F	2095 277421	ARTEM ANDREEV	{"phone": "+70584800787"}
0005433961988	6D8D8B	1819 425674	SERGEY RODIONOV	{"email": "rodionovsergey1978@postgrespro.ru", "phone": "+70410602761"}
0005433961989	425F65	1108 058473	DMITRIY BORISOV	{"phone": "+70247269841"}
0005433961990	AAF636	3776 107619	DENIS SERGEEV	{"phone": "+70008491217"}
0005433961991	7516C4	9407 278857	PAVEL BORISOV	{"phone": "+70393000505"}
0005433961992	00E9DC	5486 538276	VYACHESLAV SOKOLOV	{"email": "vyacheslav-sokolov1967@postgrespro.ru", "phone": "+70564198640"}
0005433961993	EE9238	5113 053378	DARYA DANILOVA	{"phone": "+70366967214"}
0005433961994	A93FBF	0602 470038	VIKTOR NIKOLAEV	{"phone": "+70973444449"}
0005433961995	88D463	3159 691347	VALENTINA MOISEEVA	{"email": "v.moiseeva1976@postgrespro.ru", "phone": "+70430525920"}
0005433961996	88D463	4430 391495	OLGA ABRAMOVA	{"phone": "+70661378335"}
0005433961997	B964D5	8600 345639	DENIS VASILEV	{"email": "vasilev-denis-061971@postgrespro.ru", "phone": "+70897345283"}
0005433961998	499D81	6291 635932	IRINA DMITRIEVA	{"phone": "+70425439433"}
0005433962222	3FD8A0	9984 639665	ALIYA KUZNECOVA	{"phone": "+70682615234"}
0005433961999	88B0DC	0602 178785	ANATOLIY KUZMIN	{"email": "kuzminanatoliy.101966@postgrespro.ru", "phone": "+70185991845"}
0005433962000	B2A663	7084 494374	SVETLANA RYABOVA	{"phone": "+70029527149"}
0005433962001	B2A663	4904 000578	IRINA FADEEVA	{"phone": "+70312052158"}
0005433962002	3C6D7E	7242 073360	ALEKSANDR IVANOV	{"phone": "+70655313859"}
0005433962003	3C6D7E	9175 949215	NATALYA KUZNECOVA	{"phone": "+70247967241"}
0005433962004	3C6D7E	0666 990510	LIDIYA PAVLOVA	{"phone": "+70506219822"}
0005433962005	582D89	5547 370095	BOGDAN FEDOTOV	{"email": "fedotov_bogdan.1974@postgrespro.ru", "phone": "+70646863466"}
0005433962006	582D89	7283 195131	ELENA NAZAROVA	{"email": "e_nazarova1977@postgrespro.ru", "phone": "+70782189855"}
0005433962007	52B57C	8401 343904	MIKHAIL MEDVEDEV	{"phone": "+70781030623"}
0005433962008	52B57C	4081 579519	GALINA EGOROVA	{"phone": "+70096459466"}
0005433962009	734D15	2503 468475	NIKOLAY NOVIKOV	{"phone": "+70312531676"}
0005433962010	734D15	6215 328770	NATALYA KONDRATEVA	{"phone": "+70832756937"}
0005433962011	F085AD	5023 702813	ALEKSANDR SERGEEV	{"phone": "+70344769937"}
0005433962012	CDE875	4444 292948	IVAN SOROKIN	{"email": "isorokin_031969@postgrespro.ru", "phone": "+70053285394"}
0005433962013	CDE875	9606 507095	KSENIYA SEMENOVA	{"email": "kseniya_semenova.17061957@postgrespro.ru", "phone": "+70744434895"}
0005433962014	9EDF53	9435 763414	NIKOLAY FEDOROV	{"email": "fedorovnikolay_121979@postgrespro.ru", "phone": "+70317263152"}
0005433962015	262F1A	3098 978102	RAIL KOZLOV	{"phone": "+70123742781"}
0005433962016	EFF708	6604 698192	ANNA FOMINA	{"email": "fomina_anna.011966@postgrespro.ru", "phone": "+70971514953"}
0005433962017	8DA6A0	7220 034188	DMITRIY POPOV	{"phone": "+70412102249"}
0005433962018	8DA6A0	6713 106282	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko-1976@postgrespro.ru", "phone": "+70811540864"}
0005433962019	57EDD0	1718 406388	IGOR SEMENOV	{"email": "igor_semenov.1985@postgrespro.ru", "phone": "+70192126872"}
0005433962020	F7DC12	9390 866259	ZINAIDA AKIMOVA	{"phone": "+70192411653"}
0005433962021	F73A86	9697 918759	VALENTINA VOLKOVA	{"email": "valentina-volkova.22101981@postgrespro.ru", "phone": "+70704930165"}
0005433962022	6A0690	4819 048031	VLADIMIR KULIKOV	{"email": "vkulikov29081967@postgrespro.ru", "phone": "+70959283400"}
0005433962023	6A0690	4792 814962	LYUBOV IVANOVA	{"phone": "+70840513242"}
0005433962024	49CB6E	0022 787694	VALERIYA SCHERBAKOVA	{"phone": "+70466602372"}
0005433962025	49CB6E	7332 509690	RUSTAM IVANOV	{"email": "rustam-ivanov.091977@postgrespro.ru", "phone": "+70640395596"}
0005433962026	AD979D	2965 863740	IVAN MATVEEV	{"phone": "+70606392234"}
0005433962027	0E7ABB	8912 383342	OLGA GRISHINA	{"email": "ogrishina1978@postgrespro.ru", "phone": "+70878881885"}
0005433962028	CAD709	8126 393050	EKATERINA BORISOVA	{"email": "e.borisova1965@postgrespro.ru", "phone": "+70433665417"}
0005433962029	37039D	7994 410005	VALENTINA POPOVA	{"email": "popova-v-121977@postgrespro.ru", "phone": "+70446448092"}
0005433962030	2A0AFA	7084 016774	LYUDMILA FOMINA	{"email": "fomina_l_101970@postgrespro.ru", "phone": "+70209960743"}
0005433962031	E74E62	2589 352844	DMITRIY FEDOROV	{"phone": "+70550457943"}
0005433962032	D186E0	7851 190611	MARIYA KUZNECOVA	{"phone": "+70699994730"}
0005433962033	D186E0	1366 294641	SERGEY ANTONOV	{"email": "antonov-sergey.091977@postgrespro.ru", "phone": "+70947763978"}
0005433962034	D25DAB	2723 192281	NINA ISAEVA	{"email": "nina.isaeva_1968@postgrespro.ru", "phone": "+70935861658"}
0005433962035	CEB8C1	7422 016904	TAMARA IVANOVA	{"email": "tamara.ivanova021992@postgrespro.ru", "phone": "+70882241401"}
0005433962036	31DE9C	3464 582023	ALEKSANDRA ANDREEVA	{"email": "aandreeva-1955@postgrespro.ru", "phone": "+70302001746"}
0005433962037	8A10EA	9053 642542	SERGEY SMIRNOV	{"phone": "+70906989111"}
0005433962038	15F627	5075 623934	NATALYA LEBEDEVA	{"email": "n_lebedeva-1976@postgrespro.ru", "phone": "+70585615763"}
0005433962150	E4CD06	9107 611950	OLGA YAKOVLEVA	{"phone": "+70340593419"}
0005433962039	15F627	2051 054301	SVETLANA SEMENOVA	{"email": "semenova.svetlana_081975@postgrespro.ru", "phone": "+70110449229"}
0005433962040	B6FF07	9567 379927	ALEKSANDR FILIPPOV	{"phone": "+70554512233"}
0005433962041	36BF41	5208 263689	ANASTASIYA EGOROVA	{"email": "egorova-anastasiya26081979@postgrespro.ru", "phone": "+70467221037"}
0005433962042	DFAB41	0165 354486	NADEZHDA ZHUKOVA	{"email": "nadezhda-zhukova-031966@postgrespro.ru", "phone": "+70361765507"}
0005433962043	60D3ED	3247 041085	DMITRIY NIKITIN	{"email": "nikitin.dmitriy.10091968@postgrespro.ru", "phone": "+70520841072"}
0005433962044	DC13E8	5385 314648	LIDIYA KOROLEVA	{"email": "korolevalidiya.13011970@postgrespro.ru", "phone": "+70296814264"}
0005433962045	1E628C	2289 094187	ELENA NAUMOVA	{"phone": "+70764462813"}
0005433962046	1E628C	2381 158379	YULIYA AFANASEVA	{"email": "afanasevayuliya_121977@postgrespro.ru", "phone": "+70135652176"}
0005433962047	F9BD91	5483 572198	LYUDMILA ERMAKOVA	{"phone": "+70407766933"}
0005433962048	40E40E	6967 730590	ELENA KRASNOVA	{"phone": "+70634987044"}
0005433962049	D23E32	9977 246952	MARINA PAVLOVA	{"email": "m.pavlova1972@postgrespro.ru", "phone": "+70479066448"}
0005433962050	16C984	9862 437183	EVGENIY SCHERBAKOV	{"phone": "+70006814870"}
0005433962051	16C984	4138 928796	YULIYA TIMOFEEVA	{"phone": "+70908342852"}
0005433962052	2701FC	3337 643188	ALEKSANDRA SERGEEVA	{"email": "aleksandra.sergeeva-1978@postgrespro.ru", "phone": "+70590659607"}
0005433962053	1CA465	6534 053220	IGOR SIDOROV	{"email": "igorsidorov.1968@postgrespro.ru", "phone": "+70007953669"}
0005433962054	13D60B	8318 281362	ALEKSANDRA ANDREEVA	{"email": "aandreeva28081971@postgrespro.ru", "phone": "+70948545032"}
0005433962055	2ED476	4104 038665	NIKOLAY FEDOROV	{"email": "fedorov.n_05081982@postgrespro.ru", "phone": "+70386677167"}
0005433962056	2ED476	8905 161902	SERGEY TIMOFEEV	{"email": "sergeytimofeev_01041966@postgrespro.ru", "phone": "+70338187865"}
0005433962057	F62680	6655 193222	NINA IVANOVA	{"email": "ivanova-nina20011978@postgrespro.ru", "phone": "+70788372195"}
0005433962058	841FEF	3350 063858	LYUBOV YAKOVLEVA	{"email": "yakovlevalyubov_23061979@postgrespro.ru", "phone": "+70176863024"}
0005433962059	841FEF	1133 809412	VALENTINA ISAEVA	{"email": "v_isaeva1962@postgrespro.ru", "phone": "+70145441698"}
0005433962060	841FEF	2533 394828	IVAN FOMIN	{"phone": "+70547626294"}
0005433962061	6240AC	4806 536166	ANNA KUZMINA	{"email": "a-kuzmina-031982@postgrespro.ru", "phone": "+70256624247"}
0005433962062	E79B49	4164 360392	OLGA IVANOVA	{"email": "ivanova-olga011968@postgrespro.ru", "phone": "+70177153864"}
0005433962063	E79B49	6089 304423	VIKTOR KARPOV	{"email": "viktor.karpov16041972@postgrespro.ru", "phone": "+70499822621"}
0005433962064	E79B49	7308 080753	NATALYA KISELEVA	{"email": "n_kiseleva_08051964@postgrespro.ru", "phone": "+70812147489"}
0005433962065	B00FA5	3022 010916	IRINA IVANOVA	{"email": "ivanovai_081972@postgrespro.ru", "phone": "+70002653229"}
0005433962066	B00FA5	7763 126022	NATALYA MELNIKOVA	{"email": "melnikova.n021975@postgrespro.ru", "phone": "+70395915513"}
0005433962067	EB6BC3	4463 934258	ALEKSANDR MATVEEV	{"phone": "+70639552707"}
0005433962068	85D1F1	8335 435584	LYUDMILA ARKHIPOVA	{"phone": "+70875962575"}
0005433962069	B67517	3232 722625	YANA VOROBEVA	{"phone": "+70585073339"}
0005433962070	C0C9E1	9230 310080	KIRA IVANOVA	{"phone": "+70344752485"}
0005433962071	33D485	2242 731096	ILYA FROLOV	{"phone": "+70890641897"}
0005433962072	CF2365	7610 417187	OLEG GAVRILOV	{"phone": "+70099212546"}
0005433962073	A09A39	7692 912535	MARIYA ORLOVA	{"email": "orlova.mariya1967@postgrespro.ru", "phone": "+70989307081"}
0005433962074	A09A39	8362 458125	ALENA NIKITINA	{"email": "anikitina-071973@postgrespro.ru", "phone": "+70743652227"}
0005433962075	D5179E	5666 297548	ALEKSANDRA FEDOROVA	{"email": "aleksandra_fedorova-1968@postgrespro.ru", "phone": "+70522536669"}
0005433962076	429825	5446 028715	ANDREY MATVEEV	{"phone": "+70193337995"}
0005433962077	EAB9B2	0186 547580	OLGA IVANOVA	{"phone": "+70311261996"}
0005433962078	E378E9	8856 968641	GENNADIY DAVYDOV	{"phone": "+70810285249"}
0005433962079	E378E9	2306 887243	TATYANA PETROVA	{"phone": "+70341541993"}
0005433962080	F7497F	2274 509573	VASILIY SMIRNOV	{"phone": "+70112896411"}
0005433962081	BF44BA	9325 326984	IRINA KUZNECOVA	{"phone": "+70195623913"}
0005433962082	8F199C	3920 850209	VADIM MIRONOV	{"email": "mironovvadim.16101975@postgrespro.ru", "phone": "+70713104445"}
0005433962083	D3C259	6459 589471	VALERIYA IVANOVA	{"email": "valeriyaivanova-24121970@postgrespro.ru", "phone": "+70622820725"}
0005433962084	D3C259	6312 664403	VADIM KULIKOV	{"email": "vadimkulikov_021977@postgrespro.ru", "phone": "+70278455326"}
0005433962085	04CF0C	6977 142618	ALEKSANDR ANTONOV	{"phone": "+70495988502"}
0005433962086	55B3DB	7642 377124	ALEKSANDR SERGEEV	{"email": "sergeev-a1970@postgrespro.ru", "phone": "+70472694502"}
0005433962087	DF4427	3846 125932	YURIY BARANOV	{"email": "y_baranov.28011986@postgrespro.ru", "phone": "+70599765972"}
0005433962088	EA142F	2987 312837	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey.1972@postgrespro.ru", "phone": "+70914513232"}
0005433962089	0976EE	7233 891531	VYACHESLAV MIKHAYLOV	{"phone": "+70946827197"}
0005433962090	013354	6246 301430	VALENTIN MATVEEV	{"phone": "+70652273884"}
0005433962091	AF25E8	0854 154855	OLGA BELOVA	{"phone": "+70907933377"}
0005433962092	AF4DC3	3478 375271	ANNA STEPANOVA	{"email": "astepanova28121968@postgrespro.ru", "phone": "+70654819984"}
0005433962093	C6D9BE	9859 340173	GALINA ANDREEVA	{"phone": "+70971620168"}
0005433962094	C6D9BE	7642 910283	DMITRIY DMITRIEV	{"email": "dmitrievd_1982@postgrespro.ru", "phone": "+70851787479"}
0005433962095	133F87	8857 551036	ANATOLIY ANTONOV	{"email": "antonov.anatoliy.20051972@postgrespro.ru", "phone": "+70493794427"}
0005433962096	133F87	7309 657815	VIKTOR ZAKHAROV	{"email": "zakharov-viktor.081978@postgrespro.ru", "phone": "+70932694231"}
0005433962097	CBC04E	9313 196475	VIKTOR TARASOV	{"phone": "+70203902866"}
0005433962098	BF5D1F	4826 597782	IGOR SIDOROV	{"email": "igor.sidorov1974@postgrespro.ru", "phone": "+70834302785"}
0005433962099	B7DA7A	4469 308614	YULIYA SIDOROVA	{"email": "yuliya.sidorova.31101972@postgrespro.ru", "phone": "+70484638367"}
0005433962100	5C8819	5183 903507	ANDREY KUZNECOV	{"phone": "+70960606486"}
0005433962101	FB59F9	3916 283117	DARYA KOMAROVA	{"email": "d_komarova_1974@postgrespro.ru", "phone": "+70723024261"}
0005433962102	6EBC0F	6668 069274	LIDIYA ZAYCEVA	{"phone": "+70533741889"}
0005433962103	6E355A	0492 774880	MARGARITA KUZNECOVA	{"email": "margaritakuznecova_22111970@postgrespro.ru", "phone": "+70371605828"}
0005433962104	6006DE	3148 386735	DMITRIY VLASOV	{"email": "dvlasov11021972@postgrespro.ru", "phone": "+70072068468"}
0005433962105	6006DE	4193 014933	OLGA ALEKSANDROVA	{"email": "aleksandrova.olga051966@postgrespro.ru", "phone": "+70962369104"}
0005433962106	173AF0	2663 369637	ALEKSANDR PETROV	{"phone": "+70842844325"}
0005433962107	173AF0	9722 160702	VLADISLAV ZHUKOV	{"email": "zhukov-vladislav-1968@postgrespro.ru", "phone": "+70901968107"}
0005433962108	BAF596	8373 634942	VLADIMIR FEDOTOV	{"email": "vfedotov.17031976@postgrespro.ru", "phone": "+70996199875"}
0005433962109	D73CFF	5364 202484	NATALYA FOMINA	{"email": "n_fomina091976@postgrespro.ru", "phone": "+70237082149"}
0005433962110	D73CFF	5326 231518	NATALYA PETROVA	{"email": "npetrova23081970@postgrespro.ru", "phone": "+70398016637"}
0005433962111	298DF4	5681 975477	ELENA PAVLOVA	{"email": "pavlova_e-03051959@postgrespro.ru", "phone": "+70431216736"}
0005433962112	298DF4	3542 126392	ALEKSEY NOVIKOV	{"phone": "+70591284949"}
0005433962113	C79799	2986 339330	SVETLANA RODIONOVA	{"email": "srodionova031969@postgrespro.ru", "phone": "+70244845205"}
0005433962114	0ECD96	7937 660285	LYUDMILA YUDINA	{"phone": "+70979262349"}
0005433962115	57EF03	6290 457446	ALEKSEY TARASOV	{"email": "aleksey.tarasov.07011970@postgrespro.ru", "phone": "+70144915000"}
0005433962116	6D59F2	2216 997200	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov_28101972@postgrespro.ru", "phone": "+70563826272"}
0005433962117	6D59F2	6036 900212	IGOR ZHUKOV	{"email": "i_zhukov-10071980@postgrespro.ru", "phone": "+70274651150"}
0005433962118	09E685	0380 440167	MARINA LOGINOVA	{"email": "marina_loginova.03091969@postgrespro.ru", "phone": "+70495579617"}
0005433962119	A9CD33	8280 487632	DMITRIY FEDOTOV	{"phone": "+70715375571"}
0005433962120	A8BAA6	0492 327228	SERGEY VOLKOV	{"phone": "+70289950725"}
0005433962121	3ADF82	0310 075602	MIKHAIL DAVYDOV	{"phone": "+70243310545"}
0005433962122	3ADF82	3780 905227	YULIYA ZAKHAROVA	{"phone": "+70070995211"}
0005433962123	907F16	0995 783988	LYUBOV ZOTOVA	{"phone": "+70736364079"}
0005433962124	5CF6B7	1587 739789	ANNA EGOROVA	{"phone": "+70707713873"}
0005433962125	5CF6B7	7985 290986	OLGA BORISOVA	{"email": "olga.borisova.1979@postgrespro.ru", "phone": "+70919282996"}
0005433962126	2E4800	3174 105623	VASILIY KUZNECOV	{"email": "vasiliy_kuznecov.1969@postgrespro.ru", "phone": "+70778587248"}
0005433962127	B957E2	8792 364534	FEDOR KUZNECOV	{"email": "kuznecov.f-1965@postgrespro.ru", "phone": "+70569921039"}
0005433962128	D23495	0605 543626	YANA BARANOVA	{"email": "baranovay-20021974@postgrespro.ru", "phone": "+70228761036"}
0005433962129	D23495	6865 922699	ANTONINA ROMANOVA	{"phone": "+70047832159"}
0005433962130	886082	4650 547911	ZHANNA KISELEVA	{"email": "zhanna.kiseleva1977@postgrespro.ru", "phone": "+70343556549"}
0005433962131	886082	6864 975614	SERGEY MELNIKOV	{"email": "melnikov_s_14051976@postgrespro.ru", "phone": "+70288994461"}
0005433962132	758039	9267 541741	ALEKSANDR SERGEEV	{"email": "a.sergeev-031981@postgrespro.ru", "phone": "+70072555621"}
0005433962133	BBAD7B	1547 480407	ALINA SCHERBAKOVA	{"email": "alina-scherbakova_1970@postgrespro.ru", "phone": "+70794165016"}
0005433962134	6A672E	8983 844782	ANDREY MARTYNOV	{"phone": "+70430891465"}
0005433962135	ABA765	8659 581512	NADEZHDA ILINA	{"email": "ilina_nadezhda.081977@postgrespro.ru", "phone": "+70422228765"}
0005433962136	70D5E1	8689 109720	VERA GUSEVA	{"email": "guseva-v-061972@postgrespro.ru", "phone": "+70489574532"}
0005433962137	594835	5385 016791	VIKTOR KULIKOV	{"phone": "+70159486961"}
0005433962138	40F3A5	5853 958251	ELENA SOROKINA	{"phone": "+70851159770"}
0005433962139	40F3A5	0908 542222	OLGA DENISOVA	{"email": "olga-denisova_071985@postgrespro.ru", "phone": "+70917339085"}
0005433962140	40F3A5	6221 102739	DARYA SAVELEVA	{"email": "savelevad081968@postgrespro.ru", "phone": "+70894995465"}
0005433962141	85E317	3586 990508	LIDIYA NOVIKOVA	{"email": "novikova_lidiya.011974@postgrespro.ru", "phone": "+70892223529"}
0005433962142	95FAC3	7550 948339	MIKHAIL KONOVALOV	{"phone": "+70323282912"}
0005433962143	579A56	7274 649342	IRINA KUZNECOVA	{"email": "kuznecovai_1976@postgrespro.ru", "phone": "+70295907784"}
0005433962144	579A56	3770 873209	DMITRIY MOISEEV	{"phone": "+70119616362"}
0005433962145	263BD5	0994 689877	TAMARA SMIRNOVA	{"phone": "+70141723321"}
0005433962146	1DF554	8940 333843	ANASTASIYA SOLOVEVA	{"phone": "+70712615512"}
0005433962147	973BED	5677 138636	EKATERINA ANDREEVA	{"email": "ekaterina.andreeva.071970@postgrespro.ru", "phone": "+70114011431"}
0005433962148	40D622	3129 739237	MARINA FADEEVA	{"email": "fadeevamarina18121983@postgrespro.ru", "phone": "+70561456130"}
0005433962149	40D622	8664 503012	ELIZAVETA DMITRIEVA	{"phone": "+70932861671"}
0005433962151	EB82AE	3022 164906	GRIGORIY MAKAROV	{"phone": "+70378862061"}
0005433962152	179719	7788 695746	VLADIMIR GUSEV	{"email": "v.gusev-011975@postgrespro.ru", "phone": "+70276080073"}
0005433962153	A36309	3557 729393	VLADIMIR IVANOV	{"email": "ivanovv-02111976@postgrespro.ru", "phone": "+70846300624"}
0005433962154	A36309	0942 990004	MIKHAIL ABRAMOV	{"email": "abramov.mikhail_19051978@postgrespro.ru", "phone": "+70517237029"}
0005433962155	615E2B	1918 998555	VENIAMIN STEPANOV	{"email": "v_stepanov-081967@postgrespro.ru", "phone": "+70785532233"}
0005433962156	12CACA	1762 370844	NADEZHDA ILINA	{"email": "n.ilina_29041982@postgrespro.ru", "phone": "+70279457167"}
0005433962157	F02656	2643 167696	MARINA ZHUKOVA	{"email": "zhukova.m03041967@postgrespro.ru", "phone": "+70755201202"}
0005433962158	C05FB1	3763 494736	VITALIY KUDRYASHOV	{"email": "v_kudryashov051976@postgrespro.ru", "phone": "+70554037057"}
0005433962159	9BF5BE	9806 592140	ARTEM PAVLOV	{"phone": "+70355101512"}
0005433962160	C04321	3545 177975	ELENA KOVALEVA	{"email": "kovaleva_elena-101984@postgrespro.ru", "phone": "+70174999609"}
0005433962161	CBB9B7	1689 384444	ALEKSANDR KUZNECOV	{"phone": "+70577744830"}
0005433962162	053CF1	9516 197639	ANATOLIY SCHERBAKOV	{"email": "scherbakov_anatoliy1969@postgrespro.ru", "phone": "+70078461816"}
0005433962163	C4A353	5240 539127	NADEZHDA SMIRNOVA	{"phone": "+70370053325"}
0005433962164	C4A353	4669 771611	VALERIY FEDOROV	{"phone": "+70814392345"}
0005433962165	C4DA79	7982 769471	IRINA MOROZOVA	{"email": "i.morozova-021978@postgrespro.ru", "phone": "+70494332429"}
0005433962166	C4DA79	8763 275455	ELENA SERGEEVA	{"phone": "+70525311918"}
0005433962167	F70B4A	0902 164980	TATYANA VASILEVA	{"email": "vasileva-t-051970@postgrespro.ru", "phone": "+70974496508"}
0005433962168	545BB9	7920 381648	TATYANA STEPANOVA	{"email": "stepanova.tatyana_16031962@postgrespro.ru", "phone": "+70253296299"}
0005433962169	545BB9	2373 230281	TATYANA KOZLOVA	{"phone": "+70149566212"}
0005433962170	9D34B8	6010 345165	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr061965@postgrespro.ru", "phone": "+70213001337"}
0005433962171	100EFE	6667 330598	EVGENIY VASILEV	{"phone": "+70051963838"}
0005433962172	99F725	7553 041206	SVETLANA BORISOVA	{"phone": "+70250611296"}
0005433962173	353F7A	3736 179832	ANDREY KRASNOV	{"email": "krasnov-a-1967@postgrespro.ru", "phone": "+70201713197"}
0005433962174	0DC84D	3015 607312	ALEKSANDR MOISEEV	{"email": "amoiseev09111963@postgrespro.ru", "phone": "+70546194135"}
0005433962175	EB9D28	5918 623167	POLINA TIKHONOVA	{"phone": "+70635211424"}
0005433962176	07A0AB	8107 398714	NATALYA PETROVA	{"phone": "+70542167592"}
0005433962177	73FA7A	7764 315134	PETR KUZNECOV	{"email": "kuznecov-petr1972@postgrespro.ru", "phone": "+70100538381"}
0005433962178	73FA7A	5451 956330	ALEKSANDR KUDRYASHOV	{"phone": "+70738436323"}
0005433962179	849621	9756 171555	ALEKSANDR VASILEV	{"phone": "+70674409366"}
0005433962180	C21FEE	3191 331165	ALEKSEY MIKHAYLOV	{"phone": "+70176123471"}
0005433962181	AF054A	9035 459606	DMITRIY SCHERBAKOV	{"phone": "+70913484500"}
0005433962182	00A251	7331 218336	ALBINA ORLOVA	{"phone": "+70247394101"}
0005433962183	C79FD3	4311 098796	TATYANA NIKOLAEVA	{"email": "tatyana-nikolaeva_091951@postgrespro.ru", "phone": "+70771502773"}
0005433962184	E4B293	1797 395471	ANDREY KOZLOV	{"email": "kozlovandrey03101962@postgrespro.ru", "phone": "+70991171021"}
0005433962185	E32AEC	6636 236713	ARTEMIY SIDOROV	{"email": "sidorov-a-1980@postgrespro.ru", "phone": "+70808042369"}
0005433962186	E32AEC	0747 259232	GENNADIY SMIRNOV	{"phone": "+70074004004"}
0005433962187	2EF49F	0464 124992	LYUDMILA KONDRATEVA	{"email": "lkondrateva-031969@postgrespro.ru", "phone": "+70615561402"}
0005433962188	2EF49F	0598 026708	MIKHAIL DAVYDOV	{"phone": "+70078954421"}
0005433962189	946400	5438 466219	SERGEY KAZAKOV	{"phone": "+70385267829"}
0005433962190	AD78C0	9914 612423	DMITRIY GERASIMOV	{"email": "d_gerasimov-121975@postgrespro.ru", "phone": "+70014627622"}
0005433962191	035218	6025 155626	ANATOLIY EGOROV	{"email": "egorov-anatoliy02031969@postgrespro.ru", "phone": "+70799152395"}
0005433962192	C93AE9	5041 556441	DANIL PETROV	{"phone": "+70330424764"}
0005433962193	93C049	2059 935289	SERGEY KOROLEV	{"email": "korolevs_101971@postgrespro.ru", "phone": "+70231103098"}
0005433962194	189C64	8298 729581	VIKTOR KUZNECOV	{"phone": "+70853467893"}
0005433962195	BD489F	7926 975166	LARISA NOVIKOVA	{"phone": "+70406660801"}
0005433962196	8CC172	8805 537398	PETR MEDVEDEV	{"phone": "+70111496262"}
0005433962197	40D99F	1112 255507	LYUBOV ANDREEVA	{"email": "l.andreeva_1976@postgrespro.ru", "phone": "+70422079340"}
0005433962198	1327A1	5454 966635	IVAN FILIPPOV	{"phone": "+70363747187"}
0005433962199	1327A1	8828 899690	ANDREY FEDOROV	{"phone": "+70423427144"}
0005433962200	7A9163	5579 850826	VLADIMIR ROMANOV	{"phone": "+70842675508"}
0005433962201	7A9163	2843 451782	DMITRIY POPOV	{"email": "popov_dmitriy02061971@postgrespro.ru", "phone": "+70909925930"}
0005433962202	705C38	5109 212297	POLINA STEPANOVA	{"phone": "+70947253684"}
0005433962203	0A83E9	9094 666741	OLGA TROFIMOVA	{"email": "o_trofimova-03041969@postgrespro.ru", "phone": "+70677553358"}
0005433962204	0A83E9	0505 046025	ALEKSANDRA VLASOVA	{"email": "vlasova.aleksandra.04071965@postgrespro.ru", "phone": "+70850858591"}
0005433962205	ACBD98	1914 544822	PAVEL DENISOV	{"email": "pavel-denisov1975@postgrespro.ru", "phone": "+70639574797"}
0005433962206	99AC69	7844 979840	ARTEM MOROZOV	{"email": "morozov.artem_20061974@postgrespro.ru", "phone": "+70920958192"}
0005433962207	FA36C9	1480 074787	TATYANA SOKOLOVA	{"phone": "+70451442568"}
0005433962208	326314	4760 590918	NINA SOLOVEVA	{"phone": "+70891069024"}
0005433962209	326314	3609 639848	SVETLANA GUSEVA	{"phone": "+70718463529"}
0005433962210	609885	2535 901201	RIMMA ZOTOVA	{"email": "zotova-rimma.10121979@postgrespro.ru", "phone": "+70755143310"}
0005433962211	31CB9B	9478 581652	DMITRIY ROMANOV	{"phone": "+70562021289"}
0005433962212	31CB9B	0916 094185	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov-17101967@postgrespro.ru", "phone": "+70942697724"}
0005433962213	2B00B6	1543 655661	MAKSIM MATVEEV	{"phone": "+70125052507"}
0005433962214	A12869	0981 015700	IRINA SEMENOVA	{"email": "semenova_i_1963@postgrespro.ru", "phone": "+70250128861"}
0005433962215	87E3AE	1908 135879	TATYANA NIKIFOROVA	{"phone": "+70484564810"}
0005433962216	132C51	2581 198769	ANDREY KOROLEV	{"phone": "+70186052205"}
0005433962217	132C51	1143 777400	ANASTASIYA LEBEDEVA	{"phone": "+70617422935"}
0005433962218	9E9B00	7852 613691	VALERIYA ABRAMOVA	{"email": "valeriya.abramova-1981@postgrespro.ru", "phone": "+70425984883"}
0005433962219	7AD226	8473 345018	VIKTOR KUZMIN	{"phone": "+70048011677"}
0005433962220	7AD226	2918 655732	RUSLAN MAKAROV	{"phone": "+70054429826"}
0005433962221	040805	7330 402161	MIKHAIL CHERNOV	{"phone": "+70915604551"}
0005433962223	3FD8A0	9335 864658	VALENTIN SOKOLOV	{"email": "sokolov.v_1974@postgrespro.ru", "phone": "+70571692639"}
0005433962224	DD923D	1724 392131	IVAN ALEKSANDROV	{"phone": "+70056725196"}
0005433962225	9003BF	0885 903317	VALENTIN VOLKOV	{"phone": "+70192821621"}
0005433962226	9CC78E	1109 603537	VIKTOR TIKHONOV	{"phone": "+70386743322"}
0005433962227	9CC78E	4025 375193	INNA FROLOVA	{"email": "inna_frolova-051972@postgrespro.ru", "phone": "+70201421236"}
0005433962228	A9B244	6757 834770	ANATOLIY GERASIMOV	{"phone": "+70279865801"}
0005433962229	47489F	1269 736097	KLAVDIYA EGOROVA	{"email": "klavdiya-egorova.12061972@postgrespro.ru", "phone": "+70614455513"}
0005433962230	FCC690	7716 271994	SERGEY CHERNOV	{"email": "chernov-s.011972@postgrespro.ru", "phone": "+70391330905"}
0005433962231	1CBF5C	2367 555023	ILYA EGOROV	{"phone": "+70428148785"}
0005433962232	B77CCC	0498 603669	NADEZHDA STEPANOVA	{"email": "nadezhda-stepanova.081954@postgrespro.ru", "phone": "+70806480628"}
0005433962233	7C5F26	5786 793226	NIKOLAY POPOV	{"phone": "+70196893989"}
0005433962234	6C1C5E	1882 744878	DMITRIY KOZLOV	{"email": "d.kozlov081973@postgrespro.ru", "phone": "+70253742968"}
0005433962235	DDAE6C	9993 235219	ANNA FROLOVA	{"phone": "+70426563906"}
0005433962236	A9D505	4416 602189	EKATERINA DANILOVA	{"email": "ekaterina_danilova_13091970@postgrespro.ru", "phone": "+70898627993"}
0005433962237	45C069	6101 454046	LILIYA NESTEROVA	{"email": "liliya.nesterova_1977@postgrespro.ru", "phone": "+70300471335"}
0005433962238	D31B1D	6110 199814	EVGENIY NIKOLAEV	{"email": "nikolaev_e.03091970@postgrespro.ru", "phone": "+70754504137"}
0005433962239	D0D1DC	4200 319540	VASILIY IVANOV	{"email": "ivanov.vasiliy041965@postgrespro.ru", "phone": "+70758755329"}
0005433962240	D0D1DC	9019 142443	ANDREY MOROZOV	{"phone": "+70081725793"}
0005433962241	7EBFDE	2272 464806	POLINA MELNIKOVA	{"phone": "+70762336648"}
0005433962242	2BB595	0798 149656	GALINA BELOVA	{"email": "belova_g1968@postgrespro.ru", "phone": "+70599089158"}
0005433962243	957C26	0909 127232	SERGEY SOLOVEV	{"email": "s-solovev.021963@postgrespro.ru", "phone": "+70951828747"}
0005433962244	F9B123	5981 184830	MIKHAIL KUZMIN	{"phone": "+70100256100"}
0005433962245	F9B123	9966 092859	IRINA KUDRYASHOVA	{"phone": "+70053596658"}
0005433962246	421D9C	7216 676349	EKATERINA ZAKHAROVA	{"phone": "+70320663906"}
0005433962247	627963	5349 760539	YURIY TIKHONOV	{"phone": "+70580848348"}
0005433962248	BB523A	4800 375691	ELENA GERASIMOVA	{"email": "e.gerasimova-11041975@postgrespro.ru", "phone": "+70192307588"}
0005433962249	884C65	9824 473889	NATALYA FADEEVA	{"email": "fadeeva.natalya.07031983@postgrespro.ru", "phone": "+70306852883"}
0005433962250	884C65	3553 597034	ANATOLIY MIRONOV	{"email": "amironov23011972@postgrespro.ru", "phone": "+70546114858"}
0005433962251	B9EA06	3631 243734	ALEKSANDR MIKHAYLOV	{"phone": "+70414466035"}
0005433962252	CA15FE	2729 325859	ALEKSANDR BORISOV	{"phone": "+70975441693"}
0005433962253	DEF52A	4872 266277	DANIIL GORBUNOV	{"phone": "+70426051956"}
0005433962254	DEF52A	5358 473148	VLADISLAV BARANOV	{"email": "vladislavbaranov1980@postgrespro.ru", "phone": "+70115857429"}
0005433962255	DEF52A	7004 516129	ELINA KOROLEVA	{"email": "ekoroleva-1976@postgrespro.ru", "phone": "+70598493653"}
0005433962256	982FBE	0782 547215	EKATERINA SOKOLOVA	{"email": "e-sokolova_091971@postgrespro.ru", "phone": "+70710238675"}
0005433962257	15DE15	4811 227006	ELENA KUZNECOVA	{"email": "ekuznecova.1984@postgrespro.ru", "phone": "+70276021611"}
0005433962258	15DE15	5498 933061	NATALIYA NAZAROVA	{"email": "nnazarova-1971@postgrespro.ru", "phone": "+70858741210"}
0005433962259	B3700D	6015 644400	ELENA IVANOVA	{"phone": "+70161603213"}
0005433962260	6A3439	7487 176032	DARYA KUZMINA	{"phone": "+70922786611"}
0005433962261	6A3439	8897 793260	OLGA KUZNECOVA	{"phone": "+70738456087"}
0005433962262	E52A83	2987 091149	ELENA KUDRYASHOVA	{"phone": "+70480840890"}
0005433962263	AE9B09	8148 259374	SERGEY ALEKSEEV	{"email": "alekseev-s.111971@postgrespro.ru", "phone": "+70517839797"}
0005433962264	43E88A	4879 474337	MARIYA MELNIKOVA	{"email": "mariya-melnikova21111983@postgrespro.ru", "phone": "+70330867962"}
0005433962265	896784	8705 060891	EKATERINA ALEKSEEVA	{"phone": "+70103004751"}
0005433962266	2FAAB5	8511 481818	VALENTINA EFREMOVA	{"email": "v-efremova.011982@postgrespro.ru", "phone": "+70399673642"}
0005433962267	2FAAB5	8793 841255	ELENA VOLKOVA	{"email": "volkova.elena.121957@postgrespro.ru", "phone": "+70528441178"}
0005433962268	B72AE4	4962 912467	VERA NAZAROVA	{"phone": "+70066890153"}
0005433962269	A2930F	8700 677020	ALEKSEY TIKHONOV	{"phone": "+70834940901"}
0005433962270	6E2A26	8175 990702	NIKOLAY FROLOV	{"email": "frolov.n_04121973@postgrespro.ru", "phone": "+70226565093"}
0005433962271	77531B	2365 725256	FARIDA KUZNECOVA	{"email": "farida.kuznecova091974@postgrespro.ru", "phone": "+70782527970"}
0005433962272	77531B	4737 696478	SVETLANA NIKOLAEVA	{"email": "nikolaeva_svetlana_101980@postgrespro.ru", "phone": "+70879245605"}
0005433962273	9A6503	0388 879495	EVGENIY KULIKOV	{"phone": "+70917606262"}
0005433962274	9A6503	8767 776297	SERGEY MATVEEV	{"email": "sergey.matveev-051963@postgrespro.ru", "phone": "+70950741635"}
0005433962275	90092A	1464 442177	BOGDAN FEDOROV	{"email": "bogdan.fedorov031973@postgrespro.ru", "phone": "+70126942329"}
0005433962276	DC2C22	7806 937575	TAKHIR KUDRYASHOV	{"email": "tkudryashov.1981@postgrespro.ru", "phone": "+70988807360"}
0005433962277	678D71	7226 194048	ALEKSEY GUSEV	{"email": "aleksey_gusev.1975@postgrespro.ru", "phone": "+70588638277"}
0005433962334	93BB3D	5039 113821	NADEZHDA GUSEVA	{"phone": "+70667212621"}
0005433962278	786BD0	1142 072805	ARTUR MATVEEV	{"email": "matveev.a.041976@postgrespro.ru", "phone": "+70398512306"}
0005433962279	786BD0	4183 176334	YANA SIDOROVA	{"phone": "+70456887710"}
0005433962280	B42B01	8539 578127	NIKITA BORISOV	{"email": "borisov.nikita.1971@postgrespro.ru", "phone": "+70062762852"}
0005433962281	396461	4253 707671	IVAN MIKHAYLOV	{"phone": "+70536340183"}
0005433962282	18350E	7975 379581	LIDIYA SOROKINA	{"phone": "+70718680639"}
0005433962283	18350E	6988 255189	EKATERINA NOVIKOVA	{"email": "ekaterina-novikova.1979@postgrespro.ru", "phone": "+70405248925"}
0005433962284	E65283	4969 092264	NIKOLAY KOZLOV	{"email": "kozlov.nikolay041965@postgrespro.ru", "phone": "+70222344933"}
0005433962285	BA5818	1611 731356	RAVIL MIKHAYLOV	{"phone": "+70978818961"}
0005433962286	60DB13	3687 281010	ELENA NAUMOVA	{"phone": "+70046618819"}
0005433962287	DEE897	9457 519566	EKATERINA KAZAKOVA	{"email": "ekaterinakazakova.051961@postgrespro.ru", "phone": "+70140320897"}
0005433962288	551FE3	6825 008439	VALERIY EGOROV	{"phone": "+70867734003"}
0005433962289	B2DF2F	6838 359650	EKATERINA ZAKHAROVA	{"email": "zakharova.e03121975@postgrespro.ru", "phone": "+70328330597"}
0005433962290	68DA0D	4445 382305	SVETLANA MALYSHEVA	{"phone": "+70583491349"}
0005433962291	77A982	9126 436812	ANZHELA TIKHONOVA	{"email": "anzhela.tikhonova.051985@postgrespro.ru", "phone": "+70591387986"}
0005433962292	D692F9	6923 791749	ARKADIY VASILEV	{"phone": "+70568399256"}
0005433962293	11EEBA	8213 335161	NIKITA NIKOLAEV	{"email": "nikolaev-nikita.051970@postgrespro.ru", "phone": "+70114254744"}
0005433962294	11EEBA	0682 800657	ANNA FROLOVA	{"phone": "+70257054811"}
0005433962295	A074DC	5345 032097	DMITRIY KOROLEV	{"phone": "+70133683047"}
0005433962296	0F6D14	4147 066789	OLESYA DAVYDOVA	{"phone": "+70463431588"}
0005433962297	FC808A	4680 879145	ELENA ANDREEVA	{"email": "eandreeva061979@postgrespro.ru", "phone": "+70811794013"}
0005433962298	FC808A	4469 578380	OLEG FILIPPOV	{"email": "olegfilippov.02101975@postgrespro.ru", "phone": "+70093429452"}
0005433962299	05CF75	0479 858338	SERGEY ISAEV	{"phone": "+70873267867"}
0005433962300	05CF75	7596 194280	OKSANA KUZMINA	{"phone": "+70240034861"}
0005433962301	05CF75	8632 370048	EVGENIY MAKAROV	{"email": "evgeniy-makarov.27121979@postgrespro.ru", "phone": "+70493313422"}
0005433962302	374D04	2842 509617	ROMAN ALEKSANDROV	{"email": "raleksandrov.13091977@postgrespro.ru", "phone": "+70180229271"}
0005433962303	C18803	1630 334751	MARGARITA KOZLOVA	{"phone": "+70729715778"}
0005433962304	7EA773	6183 250068	ALEKSANDR DENISOV	{"email": "a_denisov.1979@postgrespro.ru", "phone": "+70176057651"}
0005433962305	22625C	0724 544042	ELVINA VOLKOVA	{"phone": "+70142389315"}
0005433962306	F1E7EA	9062 886102	ELINA SOKOLOVA	{"phone": "+70936575571"}
0005433962307	CF5E32	8433 311744	TATYANA MATVEEVA	{"phone": "+70006013185"}
0005433962308	521C66	6055 516612	NIKOLAY MIRONOV	{"phone": "+70448211850"}
0005433962309	521C66	0679 147658	VASILIY OSIPOV	{"phone": "+70242038669"}
0005433962310	0BC89F	0508 301230	ELENA ILINA	{"email": "ilina-elena011962@postgrespro.ru", "phone": "+70459067196"}
0005433962311	84E484	5658 174033	LYUDMILA NESTEROVA	{"phone": "+70535094831"}
0005433962312	84E484	6206 502037	GEORGIY VOLKOV	{"email": "g.volkov_17121984@postgrespro.ru", "phone": "+70052239239"}
0005433962313	7CF412	8378 180915	VLADA MEDVEDEVA	{"email": "vlada_medvedeva-22051980@postgrespro.ru", "phone": "+70991867428"}
0005433962314	7CF412	4125 111277	SERGEY FOMIN	{"email": "fomin-sergey.23101970@postgrespro.ru", "phone": "+70499300128"}
0005433962315	8823E3	9403 833727	IVAN NIKOLAEV	{"phone": "+70994186080"}
0005433962316	6732C3	4232 836217	LYUDMILA MATVEEVA	{"phone": "+70068783118"}
0005433962317	75EAD7	0767 102731	ARTEMIY DENISOV	{"phone": "+70111187984"}
0005433962318	2E90C4	0345 629808	VLADISLAV FEDOROV	{"email": "fedorov.vladislav_13111967@postgrespro.ru", "phone": "+70681715868"}
0005433962319	47CE5A	5556 650834	VIKTOR ZAYCEV	{"email": "zaycev.v_101963@postgrespro.ru", "phone": "+70211788013"}
0005433962320	C13C6C	1258 541410	VIKTORIYA ANTONOVA	{"email": "viktoriya.antonova25051978@postgrespro.ru", "phone": "+70532443412"}
0005433962321	A595FE	6887 229998	NATALYA TARASOVA	{"phone": "+70670068029"}
0005433962322	3D2400	1883 077679	ANDREY IVANOV	{"phone": "+70589385154"}
0005433962323	B50E29	9040 967730	LIDIYA NOVIKOVA	{"email": "novikova_lidiya.1969@postgrespro.ru", "phone": "+70741699510"}
0005433962324	BC4534	2763 434653	YURIY KUZMIN	{"email": "ykuzmin-1980@postgrespro.ru", "phone": "+70494686760"}
0005433962325	685597	0071 747794	ANDREY BARANOV	{"email": "baranov_a011978@postgrespro.ru", "phone": "+70636491608"}
0005433962326	4AE342	6220 439329	OLGA TIMOFEEVA	{"email": "timofeeva-olga_24091977@postgrespro.ru", "phone": "+70163560241"}
0005433962327	30A99D	9897 626223	VYACHESLAV FILIPPOV	{"phone": "+70619312303"}
0005433962328	6D06F5	2857 228722	ELENA NOVIKOVA	{"email": "elenanovikova1983@postgrespro.ru", "phone": "+70768499976"}
0005433962329	736451	4789 508433	ANDREY MOROZOV	{"phone": "+70971817610"}
0005433962330	736451	8181 298520	NATALYA SMIRNOVA	{"phone": "+70083207586"}
0005433962331	54CFB6	6794 858792	VALENTINA VLASOVA	{"email": "valentina-vlasova-061961@postgrespro.ru", "phone": "+70791655926"}
0005433962332	54CFB6	7462 337151	VALENTINA NOVIKOVA	{"phone": "+70925750531"}
0005433962333	7B86B3	7811 021192	IGOR VOLKOV	{"email": "i_volkov081971@postgrespro.ru", "phone": "+70937587452"}
0005433962335	DED5F0	8043 141381	OLGA KONOVALOVA	{"phone": "+70433688542"}
0005433962336	DED5F0	9148 581623	LIDIYA ANISIMOVA	{"phone": "+70933764549"}
0005433962337	5894C8	6252 281447	TATYANA PETROVA	{"phone": "+70776361139"}
0005433962338	3DDCC6	6418 978620	PETR GUSEV	{"email": "gusevp29091979@postgrespro.ru", "phone": "+70175899572"}
0005433962339	523A25	7462 697558	OLGA VLASOVA	{"phone": "+70314142382"}
0005433962340	523A25	1606 569799	TAMARA SMIRNOVA	{"email": "tamara_smirnova1979@postgrespro.ru", "phone": "+70773776164"}
0005433962341	96E94D	8843 229122	IRINA NESTEROVA	{"email": "nesterova.i.09061969@postgrespro.ru", "phone": "+70045752708"}
0005433962342	B17CEF	2212 632588	VITALIY VASILEV	{"phone": "+70470087927"}
0005433962343	B17CEF	5460 273164	ELENA LUKYANOVA	{"phone": "+70047266808"}
0005433962344	081352	0854 183371	DMITRIY ALEKSEEV	{"email": "alekseev_dmitriy.1979@postgrespro.ru", "phone": "+70367808274"}
0005433962345	5D2BF6	2122 532242	OLEG SHEVCHENKO	{"email": "shevchenkoo.14041974@postgrespro.ru", "phone": "+70200842319"}
0005433962346	5D2BF6	0152 792101	ELMIRA ZHURAVLEVA	{"phone": "+70704080675"}
0005433962347	5D2BF6	6728 234132	ALEKSANDR KOROLEV	{"phone": "+70600906825"}
0005433962348	C216D0	5536 149632	RAFAEL IVANOV	{"phone": "+70463849455"}
0005433962349	CC45C2	6736 159587	ANDREY ABRAMOV	{"email": "abramovandrey-1970@postgrespro.ru", "phone": "+70142753594"}
0005433962350	C4AD14	5270 873186	RAIS BARANOV	{"phone": "+70368365114"}
0005433962351	C4AD14	7123 447392	ZHANNA MIRONOVA	{"email": "mironovazhanna_27121976@postgrespro.ru", "phone": "+70534610530"}
0005433962352	3ABCFF	9205 095393	EKATERINA PETROVA	{"email": "petrova.e.101976@postgrespro.ru", "phone": "+70014229473"}
0005433962353	3ABCFF	8619 672850	EKATERINA KAZAKOVA	{"email": "kazakova-ekaterina_13021963@postgrespro.ru", "phone": "+70642006340"}
0005433962354	F2C471	7311 731945	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov051969@postgrespro.ru", "phone": "+70819212961"}
0005433962355	F2C471	8733 267215	ALEKSANDR SMIRNOV	{"email": "a_smirnov18021977@postgrespro.ru", "phone": "+70405898561"}
0005433962356	F2C471	0428 475884	MATVEY KRASNOV	{"phone": "+70457950571"}
0005433962357	FE3FF1	8264 356654	IRINA MAKAROVA	{"phone": "+70686363711"}
0005433962358	FE3FF1	1637 955687	IRINA MEDVEDEVA	{"email": "medvedevairina-1972@postgrespro.ru", "phone": "+70029196348"}
0005433962359	5681D7	3803 385718	MAKSIM ABRAMOV	{"phone": "+70888961136"}
0005433962360	5681D7	6563 528636	TAISIYA GORBUNOVA	{"phone": "+70215028092"}
0005433962361	770A1D	2245 000658	DMITRIY PETROV	{"phone": "+70226225193"}
0005433962362	A1008E	9197 912501	VIKTORIYA SERGEEVA	{"email": "v_sergeeva22011969@postgrespro.ru", "phone": "+70847458090"}
0005433962363	B4B4EC	9702 027002	BOGDAN NIKOLAEV	{"email": "bogdan.nikolaev29121973@postgrespro.ru", "phone": "+70409295022"}
0005433962364	B4B4EC	2962 541856	VALENTINA TIMOFEEVA	{"email": "valentinatimofeeva-071971@postgrespro.ru", "phone": "+70030930925"}
0005433962365	5D3AB9	8623 267675	SVETLANA SMIRNOVA	{"phone": "+70421889550"}
0005433962366	5D3AB9	2032 834972	ALEKSANDR BONDARENKO	{"phone": "+70864635452"}
0005433962367	1B3E9B	8924 607251	PAVEL IVANOV	{"phone": "+70152679272"}
0005433962368	1B3E9B	9295 334272	NIKITA ANDREEV	{"phone": "+70476305539"}
0005433962369	791E81	6083 238444	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko_111977@postgrespro.ru", "phone": "+70037838944"}
0005433962370	791E81	8184 137556	ANNA KOZLOVA	{"email": "kozlovaanna.1973@postgrespro.ru", "phone": "+70423013926"}
0005433962371	791E81	5372 920171	TATYANA SMIRNOVA	{"phone": "+70319901374"}
0005433962372	6B8012	4273 449587	SERGEY GAVRILOV	{"phone": "+70434404543"}
0005433962373	6B8012	0775 561510	NATALYA SOROKINA	{"email": "n.sorokina1973@postgrespro.ru", "phone": "+70619082003"}
0005433962374	6B8012	2453 609819	EVGENIYA SEMENOVA	{"email": "semenova.e_121976@postgrespro.ru", "phone": "+70164359499"}
0005433962375	53D91F	3511 521666	YURIY KUZMIN	{"phone": "+70483604300"}
0005433962376	53D91F	1032 419062	ELENA STEPANOVA	{"phone": "+70170848264"}
0005433962377	69B5E8	8390 444707	VALENTIN SHEVCHENKO	{"phone": "+70257195690"}
0005433962378	DB97E5	2007 310455	VYACHESLAV SMIRNOV	{"email": "vyacheslavsmirnov.1965@postgrespro.ru", "phone": "+70066454636"}
0005433962379	DA7CB1	4612 061940	ELENA KAZAKOVA	{"phone": "+70381643456"}
0005433962380	DA7CB1	9575 932744	MIKHAIL SEMENOV	{"email": "semenov-m.07061962@postgrespro.ru", "phone": "+70230558436"}
0005433962381	183ACC	3238 098733	IGOR MAKAROV	{"phone": "+70835135284"}
0005433962382	6434F1	8583 838424	NIKITA ALEKSEEV	{"phone": "+70848120617"}
0005433962383	C09C25	9970 659534	MARIYA TROFIMOVA	{"email": "mariya.trofimova-031970@postgrespro.ru", "phone": "+70662124535"}
0005433962384	C09C25	6931 664619	VLADIMIR KISELEV	{"email": "kiselev-vladimir-011977@postgrespro.ru", "phone": "+70095085477"}
0005433962385	36D2F5	2769 121192	IVAN ANTONOV	{"email": "ivan-antonov-1971@postgrespro.ru", "phone": "+70557206419"}
0005433962386	36D2F5	3936 074580	SVYATOSLAV PETROV	{"email": "petrovsvyatoslav-1966@postgrespro.ru", "phone": "+70542583120"}
0005433962387	6C89CE	7222 415486	SERGEY KUDRYASHOV	{"email": "skudryashov-1973@postgrespro.ru", "phone": "+70134061275"}
0005433962388	7581C6	4520 482711	DARYA LAZAREVA	{"phone": "+70087998885"}
0005433962389	407DEF	9706 406179	SERGEY TARASOV	{"email": "sergey-tarasov14051991@postgrespro.ru", "phone": "+70682247953"}
0005433962390	E13D6A	7696 628600	NATALYA YAKOVLEVA	{"phone": "+70430150970"}
0005433962391	8687F6	7560 199950	MIKHAIL PETROV	{"phone": "+70811768087"}
0005433962392	AA92C3	5604 257860	NATALYA DENISOVA	{"email": "denisovanatalya-071978@postgrespro.ru", "phone": "+70837766537"}
0005433962393	DCA875	9650 550726	EVGENIY SIDOROV	{"phone": "+70661126372"}
0005433962394	14618E	0954 895613	VERA MEDVEDEVA	{"phone": "+70344385590"}
0005433962395	940790	3010 010949	YURIY BONDARENKO	{"email": "bondarenko-y22021966@postgrespro.ru", "phone": "+70058763400"}
0005433962396	940790	8876 406025	SERGEY PETROV	{"email": "sergey_petrov20041968@postgrespro.ru", "phone": "+70119866133"}
0005433962397	FB9F10	4804 526630	ANNA SOKOLOVA	{"email": "sokolova_a-1974@postgrespro.ru", "phone": "+70225856050"}
0005433962398	F941D7	3868 059192	ALEKSANDRA KULIKOVA	{"phone": "+70173826989"}
0005433962399	F941D7	6224 299895	ANATOLIY SOKOLOV	{"email": "a.sokolov.041972@postgrespro.ru", "phone": "+70193868006"}
0005433962400	F941D7	6263 675052	PAVEL BARANOV	{"email": "baranov.pavel.23121978@postgrespro.ru", "phone": "+70387446188"}
0005433962401	50885E	2172 776777	GALINA POPOVA	{"phone": "+70852422197"}
0005433962402	1DA421	6712 748765	NATALYA KONOVALOVA	{"phone": "+70666260610"}
0005433962403	1DA421	8150 437313	IVAN OSIPOV	{"phone": "+70538165249"}
0005433962404	2C7505	0061 899736	GALINA KARPOVA	{"phone": "+70438553219"}
0005433962405	2C7505	4853 028869	IRINA MOROZOVA	{"email": "irina.morozova1974@postgrespro.ru", "phone": "+70013367179"}
0005433962406	EF799E	3448 440492	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_18041959@postgrespro.ru", "phone": "+70257115621"}
0005433962407	F3AC77	9575 798617	YAROSLAV VOROBEV	{"email": "yvorobev.1968@postgrespro.ru", "phone": "+70629289988"}
0005433962408	22AE30	4493 049508	MARIYA ZAYCEVA	{"email": "zayceva.mariya.071976@postgrespro.ru", "phone": "+70841620030"}
0005433962409	22AE30	6480 464324	ROZALIYA KUZMINA	{"email": "rozaliya_kuzmina.1970@postgrespro.ru", "phone": "+70506308553"}
0005433962410	4C86E0	1000 717694	VIKTOR KUZNECOV	{"email": "kuznecov.viktor-1969@postgrespro.ru", "phone": "+70263448056"}
0005433962411	38410B	2327 023252	ANDREY NIKITIN	{"email": "nikitina_1974@postgrespro.ru", "phone": "+70370651388"}
0005433962412	38410B	7346 358212	NADEZHDA GUSEVA	{"phone": "+70257084013"}
0005433962413	2CD2EC	2444 026061	YULIYA SERGEEVA	{"phone": "+70366709598"}
0005433962414	933361	2868 020637	VERONIKA GORBUNOVA	{"email": "gorbunova.v071976@postgrespro.ru", "phone": "+70827414262"}
0005433962415	E6F375	3938 709339	NIKOLAY SAVELEV	{"phone": "+70347686675"}
0005433962416	E6F375	1630 957416	EKATERINA FOMINA	{"email": "e.fomina.031968@postgrespro.ru", "phone": "+70219310914"}
0005433962417	E6F375	4282 411787	ELENA FADEEVA	{"email": "elena-fadeeva031971@postgrespro.ru", "phone": "+70640794455"}
0005433962418	E00F1E	7599 918485	TATYANA EGOROVA	{"phone": "+70751624984"}
0005433962419	E00F1E	3903 303934	NATALYA TARASOVA	{"email": "ntarasova-03011955@postgrespro.ru", "phone": "+70228047287"}
0005433962420	A66712	2185 237839	NATALYA ISAEVA	{"email": "nisaeva27091974@postgrespro.ru", "phone": "+70402038145"}
0005433962421	F538D5	8100 322831	PRASKOVYA EFREMOVA	{"email": "efremova_praskovya.1974@postgrespro.ru", "phone": "+70932567047"}
0005433962422	F538D5	5246 688720	DARYA GAVRILOVA	{"phone": "+70476582262"}
0005433962423	F7A5B9	7747 298066	MAKSIM SERGEEV	{"phone": "+70863416080"}
0005433962424	21C1BE	3460 487851	ANDREY NOVIKOV	{"phone": "+70198478929"}
0005433962425	21C1BE	4387 454011	SERGEY NIKOLAEV	{"phone": "+70553442951"}
0005433962426	1B7F1F	5156 909229	VERONIKA DANILOVA	{"email": "danilova_veronika.1976@postgrespro.ru", "phone": "+70538539963"}
0005433962427	74237F	0071 776668	ALSU FROLOVA	{"phone": "+70875360795"}
0005433962428	1379BE	1365 718171	ILYA EGOROV	{"phone": "+70527044795"}
0005433962429	FDAA5B	7025 495784	SERGEY KOROLEV	{"email": "korolev_s-041977@postgrespro.ru", "phone": "+70276158334"}
0005433962430	13DF62	6559 196796	VERA AFANASEVA	{"email": "afanaseva-v_10031961@postgrespro.ru", "phone": "+70490524067"}
0005433962431	13DF62	4206 554431	VALERIY PAVLOV	{"email": "v_pavlov-12111965@postgrespro.ru", "phone": "+70856461102"}
0005433962432	4B0957	5325 185302	NINA DAVYDOVA	{"email": "n.davydova-20051968@postgrespro.ru", "phone": "+70529525112"}
0005433962433	11AE33	4907 371677	LIYA ZAKHAROVA	{"email": "zakharova_liya.021964@postgrespro.ru", "phone": "+70958623295"}
0005433962434	9C8060	0651 802198	PAVEL ZHUKOV	{"phone": "+70268131494"}
0005433962435	9C8060	4167 631874	OLGA TIKHONOVA	{"phone": "+70789854273"}
0005433962436	9C8060	0976 620327	SVETLANA SMIRNOVA	{"phone": "+70011082778"}
0005433962437	F4BE28	4816 279441	OLGA NIKITINA	{"phone": "+70289322875"}
0005433962438	9EA001	8006 668907	NIKOLAY ISAEV	{"email": "isaevn.1970@postgrespro.ru", "phone": "+70730585892"}
0005433962439	9EA001	3980 702347	IGOR ZAYCEV	{"phone": "+70027937325"}
0005433962440	A8AB40	6303 008996	NINA RODIONOVA	{"email": "rodionova-n011968@postgrespro.ru", "phone": "+70267125500"}
0005433962441	BD450D	9781 993301	NATALYA BARANOVA	{"phone": "+70389260624"}
0005433962442	4132E0	9025 474572	ELENA KUZMINA	{"email": "kuzmina_e111974@postgrespro.ru", "phone": "+70122374092"}
0005433962443	D149BE	7035 284783	RAISA NESTEROVA	{"email": "r_nesterova071973@postgrespro.ru", "phone": "+70899449721"}
0005433962444	67130C	5370 295595	ALEKSANDR MAKSIMOV	{"email": "a.maksimov.1973@postgrespro.ru", "phone": "+70390733036"}
0005433962445	67130C	5991 693202	VIKTOR BORISOV	{"email": "borisov-v.111979@postgrespro.ru", "phone": "+70984142585"}
0005433962446	9827FB	9170 711324	ALEKSEY VASILEV	{"email": "vasilev_a.22071956@postgrespro.ru", "phone": "+70170898205"}
0005433962447	9B8C45	7103 354636	OLGA ORLOVA	{"email": "orlova_o_1980@postgrespro.ru", "phone": "+70758594869"}
0005433962448	E67CD5	5822 318231	VIKTOR SOKOLOV	{"email": "sokolov_v031971@postgrespro.ru", "phone": "+70406823485"}
0005433962449	A616F6	5899 317937	YANA FROLOVA	{"email": "frolova_yana_17051969@postgrespro.ru", "phone": "+70608545187"}
0005433962450	543BCE	1177 370884	VALERIYA KRASNOVA	{"phone": "+70785174815"}
0005433962451	543BCE	9990 462871	SERGEY VLASOV	{"phone": "+70158657696"}
0005433962452	6F8EDC	4794 683566	VALERIYA POPOVA	{"phone": "+70756163558"}
0005433962453	6F8EDC	7481 410690	RUSLAN VOROBEV	{"email": "ruslan_vorobev.26061979@postgrespro.ru", "phone": "+70079489657"}
0005433962454	207303	2945 059603	DARYA ZHUKOVA	{"email": "d-zhukova-051976@postgrespro.ru", "phone": "+70596409195"}
0005433962455	207303	3527 603263	ALEKSANDR OSIPOV	{"phone": "+70850590714"}
0005433962456	9FBCB8	1479 844866	GALINA BORISOVA	{"phone": "+70568216201"}
0005433962457	A52932	3176 844657	ALEKSEY SOROKIN	{"phone": "+70479238541"}
0005433962458	CFD304	1762 665658	MIKHAIL BONDARENKO	{"email": "m.bondarenko1976@postgrespro.ru", "phone": "+70312904737"}
0005433962459	C8DFB1	5190 836602	TATYANA EFIMOVA	{"email": "tatyana_efimova_1968@postgrespro.ru", "phone": "+70123762766"}
0005433962460	EF9999	2226 101255	SERGEY ROMANOV	{"phone": "+70517751354"}
0005433962461	5E2047	7154 332816	IRINA LAZAREVA	{"email": "irinalazareva1967@postgrespro.ru", "phone": "+70490411101"}
0005433962462	5E2047	7027 054194	VERA NIKOLAEVA	{"phone": "+70471478684"}
0005433962463	4FB100	2839 465916	VALERIY ISAEV	{"email": "isaev-valeriy05051983@postgrespro.ru", "phone": "+70090686831"}
0005433962464	4FB100	2374 807210	BOGDAN KUDRYASHOV	{"email": "kudryashov.b_051966@postgrespro.ru", "phone": "+70737973270"}
0005433962465	6F369C	2279 407726	VLADIMIR SEMENOV	{"phone": "+70670641053"}
0005433962466	BF5A3A	1182 679292	YURIY BARANOV	{"email": "baranovyuriy.021966@postgrespro.ru", "phone": "+70674210630"}
0005433962467	AA01C3	8224 663885	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov-1972@postgrespro.ru", "phone": "+70250421480"}
0005433962468	26825C	2236 865911	OLGA GUSEVA	{"email": "gusevao.091975@postgrespro.ru", "phone": "+70280509653"}
0005433962469	74BFDF	5718 256832	ARTUR NIKITIN	{"email": "a.nikitin-061963@postgrespro.ru", "phone": "+70661389486"}
0005433962470	74BFDF	2087 406846	MARINA GUSEVA	{"phone": "+70283711047"}
0005433962471	FE1348	3863 067898	EKATERINA EGOROVA	{"email": "ekaterina.egorova08081974@postgrespro.ru", "phone": "+70086530097"}
0005433962472	FE1348	0993 447006	ALEKSANDR SEMENOV	{"email": "a_semenov-1985@postgrespro.ru", "phone": "+70053676505"}
0005433962473	0EAA1B	1650 382780	VERONIKA AKIMOVA	{"phone": "+70664634574"}
0005433962474	12C921	7382 028493	ELENA ISAEVA	{"phone": "+70136951647"}
0005433962475	12C921	1876 723300	MARIYA BELOVA	{"phone": "+70660654911"}
0005433962476	8930F4	1479 987555	ANNA SCHERBAKOVA	{"email": "anna-scherbakova-24121968@postgrespro.ru", "phone": "+70749745898"}
0005433962477	4C0102	9723 767281	TAISIYA KOZLOVA	{"email": "kozlovataisiya.1966@postgrespro.ru", "phone": "+70041540626"}
0005433962478	8EADD4	4572 285980	NINA DMITRIEVA	{"email": "n_dmitrieva_091977@postgrespro.ru", "phone": "+70286126072"}
0005433962479	8EADD4	4511 603690	RUSLAN MAKSIMOV	{"phone": "+70631585225"}
0005433962480	7D197F	3603 774567	ALEKSEY FROLOV	{"phone": "+70469182387"}
0005433962481	40A7AE	7717 003578	PAVEL TIKHONOV	{"email": "tikhonovpavel.14011981@postgrespro.ru", "phone": "+70630043185"}
0005433962482	F26BFE	7158 605496	IRINA ILINA	{"phone": "+70932595895"}
0005433962483	161869	9037 263007	ALEKSEY VASILEV	{"email": "alekseyvasilev_08061976@postgrespro.ru", "phone": "+70265403648"}
0005433962484	EC066C	4424 506035	YURIY NIKITIN	{"phone": "+70497040494"}
0005433962485	6063EF	1176 490738	DMITRIY MOISEEV	{"email": "d.moiseev.1972@postgrespro.ru", "phone": "+70609553134"}
0005433962486	929250	5237 467618	SERGEY VLASOV	{"email": "vlasov-s111974@postgrespro.ru", "phone": "+70824170282"}
0005433962487	808ABF	7169 680994	TATYANA KARPOVA	{"email": "tatyanakarpova.10011968@postgrespro.ru", "phone": "+70010777250"}
0005433962488	7F5A0D	7111 099583	PETR VOROBEV	{"email": "petr_vorobev091978@postgrespro.ru", "phone": "+70206793339"}
0005433962489	7F5A0D	0914 243385	ELENA KOMAROVA	{"email": "elena.komarova-041973@postgrespro.ru", "phone": "+70528975444"}
0005433962490	CD115A	8883 587872	VLADISLAV KISELEV	{"phone": "+70873760447"}
0005433962491	AEECD0	4571 155768	VARVARA KULIKOVA	{"email": "kulikovav.051982@postgrespro.ru", "phone": "+70858800164"}
0005433962492	2A0E4B	7805 492301	ALEKSEY ANDREEV	{"email": "aleksey_andreev.19101962@postgrespro.ru", "phone": "+70850900024"}
0005433962493	58FF94	3010 268606	DMITRIY SHEVCHENKO	{"email": "shevchenko.d1972@postgrespro.ru", "phone": "+70500790894"}
0005433962494	9D6D68	9044 223030	EVGENIY ANTONOV	{"email": "evgeniyantonov_1965@postgrespro.ru", "phone": "+70963127282"}
0005433962495	9D6D68	1496 711923	YULIYA MALYSHEVA	{"email": "malysheva_y.1966@postgrespro.ru", "phone": "+70418816428"}
0005433962496	77EE36	4618 473579	VALERIYA NAUMOVA	{"email": "naumovav.1966@postgrespro.ru", "phone": "+70560760411"}
0005433962497	412437	9501 646193	ANASTASIYA MALYSHEVA	{"phone": "+70498133197"}
0005433962498	412437	7746 981230	KSENIYA GRISHINA	{"email": "kseniya.grishina041972@postgrespro.ru", "phone": "+70824242220"}
0005433962499	50DAB6	7874 174279	GEORGIY ORLOV	{"email": "orlov-g121973@postgrespro.ru", "phone": "+70742124523"}
0005433962500	50DAB6	5097 595189	VLADISLAV BARANOV	{"email": "v_baranov.11061983@postgrespro.ru", "phone": "+70829981202"}
0005433962501	982D29	2470 483514	PETR KARPOV	{"phone": "+70869356568"}
0005433962502	2CFC75	7183 037035	VIKTOR POPOV	{"phone": "+70035898896"}
0005433962503	41D2A2	0996 395334	OLGA DENISOVA	{"phone": "+70817368437"}
0005433962504	41D2A2	4037 666427	VIKTOR POPOV	{"phone": "+70877440915"}
0005433962505	7247AD	3583 513068	ROMAN SEMENOV	{"email": "r_semenov1960@postgrespro.ru", "phone": "+70792194281"}
0005433962506	7247AD	8691 125930	ELENA NIKOLAEVA	{"phone": "+70183427377"}
0005433962507	CFE09B	9313 142799	ILYA BORISOV	{"email": "borisov-ilya.10111978@postgrespro.ru", "phone": "+70245084225"}
0005433962508	CFE09B	5459 332056	NADEZHDA FILATOVA	{"phone": "+70932565917"}
0005433962509	02C88C	6455 941446	VITALIY STEPANOV	{"phone": "+70350220051"}
0005433962510	C45B8D	2676 320749	ARTEM ILIN	{"email": "ailin.06061957@postgrespro.ru", "phone": "+70419438760"}
0005433962511	C45B8D	7844 427291	LYUBOV SIDOROVA	{"phone": "+70788728912"}
0005433962512	AAD52D	6294 689331	ZLATA VOROBEVA	{"email": "z_vorobeva011964@postgrespro.ru", "phone": "+70357449120"}
0005433962513	AFEE68	9243 865918	SERGEY ANDREEV	{"email": "sergey.andreev_1954@postgrespro.ru", "phone": "+70600667267"}
0005433962514	6250AB	8332 163476	SVETLANA BELYAEVA	{"email": "svetlana-belyaeva-1978@postgrespro.ru", "phone": "+70530563387"}
0005433962515	6250AB	5165 807586	KRISTINA SERGEEVA	{"phone": "+70380667143"}
0005433962516	399AE0	3244 958510	ARTEM FROLOV	{"email": "frolovartem1976@postgrespro.ru", "phone": "+70873892746"}
0005433962517	2CD7B3	2552 002382	ALINA MOISEEVA	{"phone": "+70685421770"}
0005433962518	7797CC	2980 097293	IVAN SAVELEV	{"phone": "+70295875336"}
0005433962519	2E03C3	0511 586070	ALEKSEY GRIGOREV	{"email": "a.grigorev-091975@postgrespro.ru", "phone": "+70755001086"}
0005433962520	C311A3	4591 964237	SERGEY ISAEV	{"email": "s.isaev-1959@postgrespro.ru", "phone": "+70370208105"}
0005433962521	419FA2	6676 429607	LILIYA KOLESNIKOVA	{"email": "l-kolesnikova-1965@postgrespro.ru", "phone": "+70378815879"}
0005433962522	DA2C64	1356 383990	VASILIY BONDARENKO	{"email": "v-bondarenko-081986@postgrespro.ru", "phone": "+70926397288"}
0005433962523	86BA42	1989 749483	ANDREY KULIKOV	{"phone": "+70089359101"}
0005433962524	86BA42	3113 087777	ALEKSANDR MARTYNOV	{"phone": "+70322360310"}
0005433962525	19E584	3370 139235	LYUDMILA KULIKOVA	{"email": "kulikova.l.10011976@postgrespro.ru", "phone": "+70740164362"}
0005433962526	819A3E	7151 386848	NADEZHDA DENISOVA	{"phone": "+70400908004"}
0005433962527	819A3E	0360 211880	VLADIMIR MELNIKOV	{"email": "melnikov-v-12101972@postgrespro.ru", "phone": "+70818918624"}
0005433962528	BF91FA	3251 410187	NADEZHDA PETROVA	{"phone": "+70864620313"}
0005433962529	BF91FA	9098 771164	NADEZHDA PAVLOVA	{"email": "nadezhdapavlova1964@postgrespro.ru", "phone": "+70966879283"}
0005433962530	BF91FA	9158 763503	VALENTINA SOLOVEVA	{"email": "soloveva.valentina29041971@postgrespro.ru", "phone": "+70690609702"}
0005433962531	968D52	6796 934180	EVDOKIYA IVANOVA	{"phone": "+70020345987"}
0005433962532	DB996B	2108 537822	NINA MOROZOVA	{"phone": "+70194210056"}
0005433962533	DB996B	6257 653039	LYUBOV IVANOVA	{"phone": "+70701838289"}
0005433962534	B66EC4	5663 554910	SERGEY ZAYCEV	{"email": "zaycev.s1980@postgrespro.ru", "phone": "+70878493743"}
0005433962535	2B14AF	7281 935737	DANIL SOKOLOV	{"email": "danil-sokolov-1976@postgrespro.ru", "phone": "+70715021486"}
0005433962536	5AD2A8	6899 859659	DENIS VASILEV	{"phone": "+70291375537"}
0005433962537	5AD2A8	9510 047212	MARIYA IVANOVA	{"email": "ivanova_mariya12011962@postgrespro.ru", "phone": "+70494153476"}
0005433962538	39B7DC	2671 395765	ELENA SCHERBAKOVA	{"email": "e_scherbakova-22041972@postgrespro.ru", "phone": "+70632694483"}
0005433962539	39B7DC	2617 727627	ALEKSEY VASILEV	{"phone": "+70772269058"}
0005433962540	39B7DC	2420 067417	SVETLANA SAVELEVA	{"email": "saveleva.s.08071953@postgrespro.ru", "phone": "+70725342026"}
0005433962541	89D599	9372 115704	ALEKSANDR BORISOV	{"phone": "+70332571415"}
0005433962542	EDDEEA	4699 134515	YURIY KOZLOV	{"phone": "+70795217147"}
0005433962543	FEA7FB	3494 499726	EMIL ZHURAVLEV	{"phone": "+70631172932"}
0005433962544	549B4C	8867 246984	EKATERINA ANISIMOVA	{"email": "e_anisimova_1973@postgrespro.ru", "phone": "+70354888975"}
0005433962545	9CBF68	6084 039706	ALEKSANDR MATVEEV	{"email": "aleksandr.matveev-091965@postgrespro.ru", "phone": "+70162815315"}
0005433962546	8E5477	3169 326364	LYUDMILA EGOROVA	{"phone": "+70439161035"}
0005433962547	8E5477	9271 690090	ELENA GAVRILOVA	{"phone": "+70651675534"}
0005433962548	FABCE2	8681 771638	VLADIMIR ZAYCEV	{"email": "vladimirzaycev_11021976@postgrespro.ru", "phone": "+70210662668"}
0005433962549	45A532	4176 241432	DANIL GAVRILOV	{"email": "gavrilov_d-01021970@postgrespro.ru", "phone": "+70317005176"}
0005433962550	C51765	4439 812396	PETR NIKOLAEV	{"phone": "+70604590803"}
0005433962551	6172A8	8487 837783	VLADISLAV CHERNOV	{"phone": "+70847447132"}
0005433962552	464057	2938 637571	ANNA GUSEVA	{"email": "guseva-a.1973@postgrespro.ru", "phone": "+70884030614"}
0005433962553	32AEA9	4522 577086	BORIS NIKITIN	{"phone": "+70835827673"}
0005433962554	F3ED4B	7532 449756	MIKHAIL MAKAROV	{"email": "mikhailmakarov_1965@postgrespro.ru", "phone": "+70048356660"}
0005433962555	592EFA	5393 726012	ALEKSANDR POPOV	{"email": "popovaleksandr_1975@postgrespro.ru", "phone": "+70060024612"}
0005433962556	E8675F	1415 299170	YULIYA ROMANOVA	{"phone": "+70161279752"}
0005433962557	E8675F	0160 129171	ANDREY KARPOV	{"phone": "+70212650068"}
0005433962614	8428AB	4163 227914	VALENTINA PETROVA	{"phone": "+70038191608"}
0005433962558	40E0C1	9173 311570	DMITRIY EGOROV	{"email": "dmitriyegorov121960@postgrespro.ru", "phone": "+70417541144"}
0005433962559	959D6A	7222 545909	TAMARA KOLESNIKOVA	{"email": "kolesnikova-tamara_101986@postgrespro.ru", "phone": "+70471134683"}
0005433962560	0C3BB3	6747 016050	EKATERINA KOROLEVA	{"phone": "+70754195724"}
0005433962561	0C3BB3	7271 812961	GALINA RODIONOVA	{"phone": "+70697964602"}
0005433962562	C9BC6F	7228 209290	SERGEY MIKHAYLOV	{"phone": "+70824156421"}
0005433962563	C9BC6F	9802 019170	YAKOV IVANOV	{"phone": "+70037041263"}
0005433962564	70AC5D	6838 136585	ALISA MAKAROVA	{"phone": "+70407485316"}
0005433962565	70AC5D	6603 022479	ALEKSEY VOROBEV	{"email": "aleksey_vorobev30081976@postgrespro.ru", "phone": "+70295360941"}
0005433962566	70AC5D	7050 606373	ELENA ILINA	{"phone": "+70445321778"}
0005433962567	70AC5D	5620 593373	TAMARA TIMOFEEVA	{"email": "tamaratimofeeva-27041968@postgrespro.ru", "phone": "+70894788742"}
0005433962568	1E89FF	0666 744594	IVAN FROLOV	{"phone": "+70323433496"}
0005433962569	1E89FF	8133 686106	GENNADIY EGOROV	{"email": "g-egorov.1984@postgrespro.ru", "phone": "+70358138386"}
0005433962570	C0F1D3	3729 680781	ALEKSANDR KUZNECOV	{"email": "kuznecov-a031975@postgrespro.ru", "phone": "+70045833812"}
0005433962571	0476ED	7768 389160	GALINA BELYAEVA	{"email": "belyaeva_g-18121964@postgrespro.ru", "phone": "+70294525292"}
0005433962572	96BB8C	1512 516532	DIANA CHERNOVA	{"email": "d_chernova1961@postgrespro.ru", "phone": "+70141270475"}
0005433962573	96BB8C	9924 058755	ANTONIDA SOKOLOVA	{"phone": "+70647941833"}
0005433962574	B2CB46	9810 519999	VALERIY ZAKHAROV	{"email": "zakharov-v26071974@postgrespro.ru", "phone": "+70004951269"}
0005433962575	44BB38	5773 181153	ELENA ZAYCEVA	{"phone": "+70126829690"}
0005433962576	CC86EF	8397 596619	ILYA MELNIKOV	{"email": "i_melnikov-111968@postgrespro.ru", "phone": "+70760531042"}
0005433962577	9CFF6B	1549 136991	TAMARA BOGDANOVA	{"phone": "+70651458480"}
0005433962578	9CFF6B	0383 098264	LYUDMILA ZAKHAROVA	{"phone": "+70620537234"}
0005433962579	17174B	0540 406804	TATYANA FROLOVA	{"email": "t_frolova-12081979@postgrespro.ru", "phone": "+70916105236"}
0005433962580	5BA39B	0900 829193	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva27071975@postgrespro.ru", "phone": "+70776374499"}
0005433962581	392D35	7167 643617	GALINA MATVEEVA	{"phone": "+70676940321"}
0005433962582	392D35	2995 520085	YAROSLAVA TARASOVA	{"email": "tarasova-yaroslava19031974@postgrespro.ru", "phone": "+70052320580"}
0005433962583	405447	2868 629510	MARINA ALEKSEEVA	{"email": "marina.alekseeva_061970@postgrespro.ru", "phone": "+70936340017"}
0005433962584	B596BA	8110 393788	EVGENIYA VLASOVA	{"phone": "+70384866657"}
0005433962585	4124AF	2700 712037	ANTONINA KUZMINA	{"email": "antonina-kuzmina-1971@postgrespro.ru", "phone": "+70411444657"}
0005433962586	4124AF	5371 231803	BORIS KRASNOV	{"email": "krasnov.b.1986@postgrespro.ru", "phone": "+70077809160"}
0005433962587	D84F1B	0433 893018	TATYANA ABRAMOVA	{"email": "abramova-t-1967@postgrespro.ru", "phone": "+70422293624"}
0005433962588	77D57F	2063 298790	ALEKSEY IVANOV	{"email": "a.ivanov_101978@postgrespro.ru", "phone": "+70332282076"}
0005433962589	8909F0	3535 381438	ELENA FILIPPOVA	{"email": "e.filippova-081979@postgrespro.ru", "phone": "+70269214317"}
0005433962590	0E34C2	9771 031108	MIKHAIL SMIRNOV	{"email": "smirnov-mikhail-1970@postgrespro.ru", "phone": "+70976579976"}
0005433962591	E11B3E	7087 332668	MIKHAIL KOZLOV	{"email": "m-kozlov10121967@postgrespro.ru", "phone": "+70977022683"}
0005433962592	E11B3E	4882 482861	EVGENIY ZAKHAROV	{"phone": "+70505278909"}
0005433962593	38B334	4854 286927	VERA CHERNOVA	{"phone": "+70766863775"}
0005433962594	0603D8	2804 658482	ALEKSANDR NIKITIN	{"phone": "+70903025778"}
0005433962595	0603D8	5461 900927	ANDREY MARTYNOV	{"email": "andrey.martynov-15121972@postgrespro.ru", "phone": "+70410929709"}
0005433962596	9236BA	7120 792207	SERGEY NAZAROV	{"email": "s-nazarov_051967@postgrespro.ru", "phone": "+70961237607"}
0005433962597	9236BA	0316 387554	ILYA KUZNECOV	{"email": "kuznecovilya_121972@postgrespro.ru", "phone": "+70846069492"}
0005433962718	24A5E5	5730 524868	NATALYA MOISEEVA	{"phone": "+70212821598"}
0005433962598	2F0604	7371 200728	YULIYA ALEKSEEVA	{"email": "alekseeva.yuliya.04071970@postgrespro.ru", "phone": "+70483557268"}
0005433962599	C10EE1	6632 424458	KIRA MASLOVA	{"phone": "+70398702328"}
0005433962600	A100D7	1911 676558	EVGENIY YAKOVLEV	{"phone": "+70630906428"}
0005433962601	A100D7	8774 829055	EVGENIY MIRONOV	{"phone": "+70983842750"}
0005433962602	A856E0	9337 216162	NADEZHDA ARKHIPOVA	{"phone": "+70558273754"}
0005433962603	4D0D07	0284 903693	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova081960@postgrespro.ru", "phone": "+70715759503"}
0005433962604	65B369	1851 765590	NIKOLAY MEDVEDEV	{"phone": "+70266414259"}
0005433962605	65B369	9219 438910	ROMAN ALEKSEEV	{"phone": "+70153738809"}
0005433962606	2FD356	7634 562023	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov_1970@postgrespro.ru", "phone": "+70143945367"}
0005433962607	2FD356	8224 535724	ALEKSEY STEPANOV	{"email": "a-stepanov-1975@postgrespro.ru", "phone": "+70006274443"}
0005433962608	6AD9B5	1103 334637	NADEZHDA DENISOVA	{"phone": "+70601914768"}
0005433962609	042614	9882 452556	YURIY MIKHAYLOV	{"email": "mikhaylovyuriy.121978@postgrespro.ru", "phone": "+70771108741"}
0005433962610	B151F9	5632 970138	NINA GRISHINA	{"email": "grishinanina_081969@postgrespro.ru", "phone": "+70768395044"}
0005433962611	C59559	2515 880418	ANNA LUKYANOVA	{"email": "lukyanovaa.1973@postgrespro.ru", "phone": "+70892871149"}
0005433962612	C27A49	1000 328943	DMITRIY KONOVALOV	{"phone": "+70763941116"}
0005433962613	C27A49	3404 135041	SERGEY BORISOV	{"phone": "+70834907264"}
0005433962615	0639D4	4342 522741	TATYANA LOGINOVA	{"email": "loginova_tatyana.23051978@postgrespro.ru", "phone": "+70427479454"}
0005433962616	413A59	7340 642715	GENNADIY KUDRYASHOV	{"phone": "+70735105313"}
0005433962617	413A59	4171 223801	ALEKSANDR DENISOV	{"email": "denisov-aleksandr1971@postgrespro.ru", "phone": "+70180834373"}
0005433962618	02584E	4596 470311	GALINA KUZNECOVA	{"phone": "+70768439612"}
0005433962619	5D33DE	9071 888299	ILYA VASILEV	{"phone": "+70117482706"}
0005433962620	AB44FF	9538 287998	VLADIMIR MAKSIMOV	{"phone": "+70259242329"}
0005433962621	9E6163	6874 324460	DMITRIY VASILEV	{"email": "dmitriyvasilev1976@postgrespro.ru", "phone": "+70863628035"}
0005433962622	1C91A8	3924 151435	VLADIMIR KULIKOV	{"phone": "+70391357107"}
0005433962623	39B674	9057 910877	NIKOLAY MOROZOV	{"email": "nikolay.morozov1976@postgrespro.ru", "phone": "+70980524465"}
0005433962624	4EFF31	9328 595016	SERGEY SOROKIN	{"email": "s.sorokin_27081974@postgrespro.ru", "phone": "+70867736238"}
0005433962625	4EFF31	0283 159807	IVAN IVANOV	{"email": "ivanov-i.1964@postgrespro.ru", "phone": "+70254022860"}
0005433962626	C010A0	2059 962627	GEORGIY DENISOV	{"phone": "+70029409738"}
0005433962627	9138D2	1957 229699	YURIY MAKAROV	{"email": "makarov_yuriy.20071971@postgrespro.ru", "phone": "+70670741662"}
0005433962628	3883F8	1229 427475	VYACHESLAV ROMANOV	{"email": "romanov-v.121984@postgrespro.ru", "phone": "+70894845966"}
0005433962629	8D9FD8	0849 693366	ANDREY NAUMOV	{"email": "naumov.andrey_27021965@postgrespro.ru", "phone": "+70492400004"}
0005433962630	F47855	4562 646843	PETR IVANOV	{"phone": "+70520477338"}
0005433962631	255D5E	4979 988314	VIKTOR IVANOV	{"phone": "+70355523115"}
0005433962632	D233F1	0443 781163	MARIYA NESTEROVA	{"phone": "+70821699399"}
0005433962633	369D44	5753 743691	ZHANNA NAZAROVA	{"email": "nazarova-zhanna1981@postgrespro.ru", "phone": "+70285793998"}
0005433962634	369D44	9923 989082	TATYANA KULIKOVA	{"phone": "+70803037320"}
0005433962635	8979A3	1983 818345	VLADIMIR SHEVCHENKO	{"phone": "+70291175765"}
0005433962636	8979A3	4272 183337	RAILYA MAKSIMOVA	{"phone": "+70904323720"}
0005433962637	A77F41	2603 105002	DANILA KUZNECOV	{"phone": "+70118962693"}
0005433962638	A77F41	1867 259917	VYACHESLAV KARPOV	{"phone": "+70065952589"}
0005433962639	A77F41	4739 678776	VLADIMIR SOLOVEV	{"email": "vladimir_solovev04071977@postgrespro.ru", "phone": "+70256484430"}
0005433962640	21ACDA	4971 228435	ELVIRA KARPOVA	{"phone": "+70304516751"}
0005433962641	0CF3E9	5875 572336	VALENTINA SIDOROVA	{"email": "valentina_sidorova_04011967@postgrespro.ru", "phone": "+70763448823"}
0005433962642	0CF3E9	5383 896471	ANATOLIY ANTONOV	{"phone": "+70472077051"}
0005433962643	0CF3E9	7245 826822	VASILIY DENISOV	{"email": "v.denisov.16101975@postgrespro.ru", "phone": "+70478316904"}
0005433962644	0CF3E9	9959 434811	VLADIMIR MIKHAYLOV	{"email": "mikhaylovv.08051982@postgrespro.ru", "phone": "+70493143025"}
0005433962645	B76423	8131 168725	ELENA IVANOVA	{"phone": "+70443923671"}
0005433962646	A66C57	7966 963333	IGOR KRASNOV	{"phone": "+70973426739"}
0005433962647	A66C57	7958 058635	YULIYA MAKAROVA	{"phone": "+70127966346"}
0005433962648	9E8529	5658 255289	MARIYA BOGDANOVA	{"email": "bogdanovam051967@postgrespro.ru", "phone": "+70440529743"}
0005433962649	7A1B62	9886 820778	NATALYA BELOVA	{"email": "n.belova.081972@postgrespro.ru", "phone": "+70411581673"}
0005433962650	181162	9343 003436	LYUDMILA MAKAROVA	{"email": "makarova-l29081968@postgrespro.ru", "phone": "+70439892745"}
0005433962651	54C59E	7164 479181	NIKITA NOVIKOV	{"phone": "+70496173788"}
0005433962652	54C59E	3025 659217	MARIYA KALININA	{"phone": "+70396901263"}
0005433962653	0703DA	8887 368927	VALERIYA ANISIMOVA	{"phone": "+70472743828"}
0005433962654	1B9EEE	0673 161452	VITALIY NAZAROV	{"phone": "+70447195359"}
0005433962655	B20C32	7169 887950	ALEKSANDR FEDOTOV	{"phone": "+70582878468"}
0005433962656	4BD8F1	3061 268485	YURIY TIMOFEEV	{"email": "yuriytimofeev.30101955@postgrespro.ru", "phone": "+70025599922"}
0005433962657	D1CFA1	5942 472117	NINA EFREMOVA	{"phone": "+70185031915"}
0005433962658	D1CFA1	6072 007071	LYUDMILA DMITRIEVA	{"phone": "+70357442786"}
0005433962659	D1CFA1	0148 107270	ALEKSANDR MAKSIMOV	{"phone": "+70214815096"}
0005433962660	8FB79A	1399 792666	SOFYA FEDOROVA	{"phone": "+70192764841"}
0005433962661	C25CC6	5731 238179	ANNA EGOROVA	{"email": "egorovaa.22071973@postgrespro.ru", "phone": "+70638897161"}
0005433962662	0BBD06	0341 232089	OKSANA VASILEVA	{"phone": "+70040366797"}
0005433962663	0BD7EF	4980 321763	NATALYA DANILOVA	{"email": "danilova.n-101979@postgrespro.ru", "phone": "+70151710380"}
0005433962664	0BD7EF	9995 200214	ANASTASIYA ZHURAVLEVA	{"email": "anastasiya_zhuravleva071970@postgrespro.ru", "phone": "+70896377860"}
0005433962665	15BF1F	9203 266004	KLAVDIYA SOKOLOVA	{"email": "ksokolova.1968@postgrespro.ru", "phone": "+70566265506"}
0005433962666	15BF1F	1919 549346	VITALIY GUSEV	{"email": "vitaliy_gusev.1985@postgrespro.ru", "phone": "+70644699334"}
0005433962667	D8726C	5583 947955	YAROSLAV GERASIMOV	{"email": "y-gerasimov_1963@postgrespro.ru", "phone": "+70411318082"}
0005433962668	D424E1	4411 804297	TATYANA MOISEEVA	{"phone": "+70679338214"}
0005433962669	D424E1	7428 925958	ANATOLIY DMITRIEV	{"phone": "+70365864420"}
0005433962670	0AA295	0029 343018	VIKTOR GORBUNOV	{"email": "vgorbunov021990@postgrespro.ru", "phone": "+70058345688"}
0005433962671	7E6410	4176 331314	ARTEM ORLOV	{"email": "orlov_a081975@postgrespro.ru", "phone": "+70563567979"}
0005433962672	7E6410	8482 251805	VLADIMIR NAUMOV	{"email": "naumov-vladimir1963@postgrespro.ru", "phone": "+70248264467"}
0005433962673	2DA590	4031 160932	NIKOLAY MOISEEV	{"email": "nikolay_moiseev1973@postgrespro.ru", "phone": "+70742371318"}
0005433962674	17EB9A	0772 906853	OLGA SCHERBAKOVA	{"phone": "+70051035279"}
0005433962675	0F9A1E	1404 097928	TAMARA ABRAMOVA	{"email": "abramova.t_1974@postgrespro.ru", "phone": "+70451613686"}
0005433962676	34758C	7031 562340	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev.01091972@postgrespro.ru", "phone": "+70517941069"}
0005433962677	34758C	7175 328106	NIKITA NOVIKOV	{"email": "n.novikov_071982@postgrespro.ru", "phone": "+70186537156"}
0005433962678	34758C	9452 777206	ANDREY MEDVEDEV	{"email": "andreymedvedev1983@postgrespro.ru", "phone": "+70070923167"}
0005433962679	663879	3105 313876	IRINA SERGEEVA	{"email": "sergeeva-i_021977@postgrespro.ru", "phone": "+70598448931"}
0005433962680	E82EE3	4904 572012	SERGEY VOLKOV	{"email": "s_volkov.21111968@postgrespro.ru", "phone": "+70918199165"}
0005433962681	547692	9341 326210	OLGA NOVIKOVA	{"phone": "+70151814055"}
0005433962682	D0E972	4460 973804	VASILIY PAVLOV	{"email": "pavlovvasiliy-041976@postgrespro.ru", "phone": "+70149933679"}
0005433962683	7AFF6D	9468 499249	ALEKSANDR ALEKSANDROV	{"phone": "+70872702120"}
0005433962684	7AFF6D	4982 570687	VALERIY GRIGOREV	{"phone": "+70762705572"}
0005433962685	40B7EB	8257 747458	LYUBOV NESTEROVA	{"phone": "+70280476333"}
0005433962686	0848D1	2903 034412	LYUDMILA KONDRATEVA	{"phone": "+70084311624"}
0005433962687	0848D1	8051 090436	NINA BELOVA	{"email": "belovan02041976@postgrespro.ru", "phone": "+70592271905"}
0005433962688	166DAB	7075 150343	SERGEY STEPANOV	{"phone": "+70135135427"}
0005433962689	550178	4349 791031	ELLA ISAEVA	{"email": "ellaisaeva.041959@postgrespro.ru", "phone": "+70427319337"}
0005433962690	8C2202	8422 167945	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr_1965@postgrespro.ru", "phone": "+70519867312"}
0005433962691	8C2202	1366 548742	VLADIMIR TIKHONOV	{"email": "v.tikhonov03081962@postgrespro.ru", "phone": "+70352210657"}
0005433962692	8C2202	0333 094862	MARIYA YUDINA	{"phone": "+70250998393"}
0005433962693	61D3C1	7905 368082	NADEZHDA VASILEVA	{"email": "vasileva-nadezhda.10071974@postgrespro.ru", "phone": "+70749486466"}
0005433962694	61D3C1	8354 660039	OLESYA KOZLOVA	{"email": "o.kozlova.30121973@postgrespro.ru", "phone": "+70430762321"}
0005433962695	8BF22F	4580 120878	ZINAIDA TARASOVA	{"phone": "+70339150507"}
0005433962696	702D20	3224 516294	POLINA NAZAROVA	{"email": "nazarova_p.051970@postgrespro.ru", "phone": "+70272949661"}
0005433962697	6E85F4	8164 987858	ALEKSANDR NIKOLAEV	{"phone": "+70529227827"}
0005433962698	40C99B	6961 293971	NATALYA MAKSIMOVA	{"email": "maksimova.n111968@postgrespro.ru", "phone": "+70289766273"}
0005433962699	22100C	4277 166348	LIDIYA SOKOLOVA	{"email": "l_sokolova-1968@postgrespro.ru", "phone": "+70644502045"}
0005433962700	04CD47	0725 137298	LYUBOV AKIMOVA	{"email": "akimova-l_02111956@postgrespro.ru", "phone": "+70446575085"}
0005433962701	04CD47	4503 552592	VLADISLAV GORBUNOV	{"email": "gorbunov.v.27071974@postgrespro.ru", "phone": "+70205979372"}
0005433962702	62CF1F	4109 162282	ANTON GUSEV	{"email": "a-gusev-1969@postgrespro.ru", "phone": "+70212342375"}
0005433962703	62CF1F	0227 662156	DENIS YAKOVLEV	{"email": "yakovlev_denis-091974@postgrespro.ru", "phone": "+70214536070"}
0005433962704	62CF1F	9410 437884	VLADIMIR KOZLOV	{"email": "kozlovv011976@postgrespro.ru", "phone": "+70001558710"}
0005433962705	8C663A	7130 690805	VERA RYABOVA	{"phone": "+70683178987"}
0005433962706	039893	1028 034142	ANTON ALEKSEEV	{"phone": "+70266318646"}
0005433962707	7A3140	9656 078514	SERGEY CHERNOV	{"email": "chernov.sergey.1970@postgrespro.ru", "phone": "+70464461818"}
0005433962708	BB2D89	0743 322686	ALEKSANDR NOVIKOV	{"email": "novikov_a_1982@postgrespro.ru", "phone": "+70674821860"}
0005433962709	06CE8F	8626 102958	ROMAN ANTONOV	{"phone": "+70136467936"}
0005433962710	06CE8F	0926 480342	IVAN GRIGOREV	{"phone": "+70916643948"}
0005433962711	06CE8F	0583 024439	SVETLANA OSIPOVA	{"email": "svetlanaosipova.011970@postgrespro.ru", "phone": "+70743305038"}
0005433962712	C34BCA	6279 906256	ALEKSANDR ROMANOV	{"email": "romanov-a111972@postgrespro.ru", "phone": "+70231357338"}
0005433962713	C34BCA	3992 327650	ALEKSANDR VOLKOV	{"email": "volkovaleksandr-1956@postgrespro.ru", "phone": "+70696648814"}
0005433962714	88092F	4887 033694	ALEKSANDR ALEKSEEV	{"phone": "+70722014395"}
0005433962715	AD2427	7431 070174	SVETLANA RYABOVA	{"email": "sryabova.14061958@postgrespro.ru", "phone": "+70404148538"}
0005433962716	8A8472	3108 503666	ANTON ZAKHAROV	{"email": "zakharov-a.101961@postgrespro.ru", "phone": "+70463652559"}
0005433962717	24A5E5	6657 958490	VIKTOR MIKHAYLOV	{"email": "v.mikhaylov.1970@postgrespro.ru", "phone": "+70883215271"}
0005433962719	0CC181	8923 304362	LYUDMILA EFREMOVA	{"email": "lyudmilaefremova01061973@postgrespro.ru", "phone": "+70981682420"}
0005433962720	0CC181	0720 098394	OLGA PAVLOVA	{"email": "o_pavlova.021983@postgrespro.ru", "phone": "+70810675633"}
0005433962721	DFC00F	9810 750962	YURIY PAVLOV	{"email": "pavlovy-071975@postgrespro.ru", "phone": "+70854633680"}
0005433962722	DFC00F	5093 355896	ANASTASIYA MAKSIMOVA	{"email": "maksimova-a1968@postgrespro.ru", "phone": "+70282202344"}
0005433962723	99A927	7212 504471	ALEKSEY KONOVALOV	{"phone": "+70525770215"}
0005433962724	99A927	6677 314991	ALEKSANDR BARANOV	{"email": "baranova-25081973@postgrespro.ru", "phone": "+70883558518"}
0005433962725	77984E	3184 089360	VIKTOR ALEKSEEV	{"email": "alekseev.viktor051966@postgrespro.ru", "phone": "+70373673637"}
0005433962726	77984E	0984 190285	ELENA MOROZOVA	{"email": "morozova.e_08061965@postgrespro.ru", "phone": "+70528099075"}
0005433962727	096DF3	0539 091824	VITALIY IVANOV	{"email": "v_ivanov.061966@postgrespro.ru", "phone": "+70005469915"}
0005433962728	03FEC7	9337 600878	ALEKSANDR NIKOLAEV	{"phone": "+70470487689"}
0005433962729	03FEC7	5889 521200	PETR KUDRYASHOV	{"email": "p_kudryashov_111966@postgrespro.ru", "phone": "+70888396607"}
0005433962730	03FEC7	2793 785219	NATALIYA MASLOVA	{"email": "nataliya.maslova.02101962@postgrespro.ru", "phone": "+70113673340"}
0005433962731	E18027	4226 250110	EVGENIYA PETROVA	{"email": "petrova_e.05111970@postgrespro.ru", "phone": "+70187785664"}
0005433962732	F58581	8470 448447	VASILIY SCHERBAKOV	{"email": "v.scherbakov_121972@postgrespro.ru", "phone": "+70135517736"}
0005433962733	F58581	1251 431454	RIMMA SAVELEVA	{"phone": "+70002453157"}
0005433962734	547B2D	8929 728030	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya.1979@postgrespro.ru", "phone": "+70966109238"}
0005433962735	547B2D	3253 383782	NIKITA KONOVALOV	{"phone": "+70033178152"}
0005433962736	98C901	3631 089707	MARAT IVANOV	{"email": "mivanov1971@postgrespro.ru", "phone": "+70134267870"}
0005433962737	C02E19	8430 529374	PAVEL KRASNOV	{"email": "pavelkrasnov-16061973@postgrespro.ru", "phone": "+70644076218"}
0005433962738	C02E19	4937 788612	ALESYA MALYSHEVA	{"email": "malysheva_alesya.1969@postgrespro.ru", "phone": "+70421599956"}
0005433962739	C279F3	6758 057845	ALEKSANDR ABRAMOV	{"phone": "+70215580304"}
0005433962740	C279F3	5939 063626	VITALIY MIKHAYLOV	{"email": "vitaliy-mikhaylov04121972@postgrespro.ru", "phone": "+70604924407"}
0005433962741	CDA4EC	0269 573061	ALENA LOGINOVA	{"email": "aloginova14021965@postgrespro.ru", "phone": "+70663248489"}
0005433962742	CDA4EC	9872 195482	ANNA MIRONOVA	{"email": "anna.mironova23031962@postgrespro.ru", "phone": "+70601375141"}
0005433962743	7D0363	5759 121949	KAMILA SCHERBAKOVA	{"phone": "+70096688289"}
0005433962744	D84264	6530 884053	MARIYA VOROBEVA	{"phone": "+70874807410"}
0005433962745	169568	8087 548459	MAKSIM FROLOV	{"phone": "+70530428282"}
0005433962746	169568	5416 233246	ALEKSEY ANDREEV	{"email": "aandreev.02061974@postgrespro.ru", "phone": "+70819299039"}
0005433962747	4AE504	9060 571095	EVGENIYA TROFIMOVA	{"email": "trofimova-e-1970@postgrespro.ru", "phone": "+70971955063"}
0005433962748	1FD0F6	3468 740586	TATYANA NOVIKOVA	{"email": "novikova_tatyana-1985@postgrespro.ru", "phone": "+70102103294"}
0005433962749	1FD0F6	4040 266638	VALERIY ZAKHAROV	{"phone": "+70052897960"}
0005433962750	58969E	7942 960069	VALENTINA TROFIMOVA	{"email": "valentina.trofimova1975@postgrespro.ru", "phone": "+70480654677"}
0005433962751	58969E	9133 089864	GALINA PAVLOVA	{"email": "galina_pavlova-111973@postgrespro.ru", "phone": "+70804520032"}
0005433962752	C11B39	5673 091542	MARINA NAUMOVA	{"email": "m.naumova-021976@postgrespro.ru", "phone": "+70023431834"}
0005433962753	CD092A	4851 008039	OLGA KALININA	{"phone": "+70096497159"}
0005433962754	CD092A	8887 837318	OLGA BELOVA	{"email": "belovao-01091971@postgrespro.ru", "phone": "+70761429304"}
0005433962755	8BF0A6	0079 313908	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir_031967@postgrespro.ru", "phone": "+70082153471"}
0005433962756	8BF0A6	2414 361752	KONSTANTIN OSIPOV	{"phone": "+70870309044"}
0005433962757	C2238D	9984 569812	DMITRIY POPOV	{"email": "d-popov1965@postgrespro.ru", "phone": "+70351985206"}
0005433962758	50BB6C	8842 843530	NIKOLAY NIKOLAEV	{"phone": "+70433755621"}
0005433962759	50BB6C	2577 376397	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev_021968@postgrespro.ru", "phone": "+70806474342"}
0005433962760	A526D2	3446 088808	ALEKSANDR GERASIMOV	{"email": "gerasimov-a25011970@postgrespro.ru", "phone": "+70286786392"}
0005433962761	F0D42A	5140 907084	LYUDMILA VASILEVA	{"phone": "+70643666810"}
0005433962762	C768D4	7427 710099	ANTONINA SCHERBAKOVA	{"phone": "+70778738685"}
0005433962763	94118C	3521 983754	NATALYA VOROBEVA	{"phone": "+70614728681"}
0005433962764	94118C	9968 093560	DANIIL BARANOV	{"email": "daniil-baranov-061970@postgrespro.ru", "phone": "+70356190184"}
0005433962765	CF9BFB	3229 131224	DARYA ERMAKOVA	{"email": "darya_ermakova-06021971@postgrespro.ru", "phone": "+70047116406"}
0005433962766	CF9BFB	0186 254169	LYUBOV KULIKOVA	{"phone": "+70257171973"}
0005433962767	58A6D8	7481 772596	RAMZIYA STEPANOVA	{"email": "stepanovaramziya081976@postgrespro.ru", "phone": "+70724815043"}
0005433962768	83CA76	1546 588988	ALEKSANDR MAKAROV	{"email": "makarov.a.031985@postgrespro.ru", "phone": "+70422811542"}
0005433962769	C42E24	4640 851718	LYUDMILA IVANOVA	{"email": "ivanova_l_27121973@postgrespro.ru", "phone": "+70102744632"}
0005433962770	C42E24	5230 411163	YULIYA KUZNECOVA	{"email": "kuznecovayuliya_06071966@postgrespro.ru", "phone": "+70765460685"}
0005433962771	C42E24	8591 827662	DMITRIY NAUMOV	{"email": "naumov_dmitriy_09031959@postgrespro.ru", "phone": "+70780966437"}
0005433962772	C42E24	6842 482301	RUZALIYA KUDRYASHOVA	{"email": "ruzaliya-kudryashova17101967@postgrespro.ru", "phone": "+70957733417"}
0005433962773	4EBCFC	8373 091660	ANASTASIYA MOROZOVA	{"phone": "+70231995325"}
0005433985122	1FBFF7	0972 841377	YURIY SCHERBAKOV	{"phone": "+70970334660"}
0005433985123	1FBFF7	4414 015132	ALEKSANDRA ALEKSEEVA	{"phone": "+70591602768"}
0005433985124	C9C069	3770 283475	SERGEY ILIN	{"phone": "+70140684108"}
0005433985125	C9C069	0147 382535	VALENTINA BOGDANOVA	{"email": "v-bogdanova.12061977@postgrespro.ru", "phone": "+70198544024"}
0005433985126	F0C88F	2749 580557	TAMARA SCHERBAKOVA	{"email": "scherbakova.t1963@postgrespro.ru", "phone": "+70963184234"}
0005433985127	35FAF4	2880 398359	SOFYA KRASNOVA	{"email": "krasnova.s121980@postgrespro.ru", "phone": "+70382830564"}
0005433985128	C4D391	5047 827178	ANGELINA POPOVA	{"phone": "+70653506672"}
0005433985129	C4D391	0393 304551	OLGA KONOVALOVA	{"phone": "+70322370655"}
0005433985130	C4D391	6295 308486	ALFIYA ORLOVA	{"email": "alfiya_orlova_121973@postgrespro.ru", "phone": "+70230069705"}
0005433985131	EA0ACC	2712 186464	ALEKSANDR MATVEEV	{"phone": "+70143686230"}
0005433985132	EA0ACC	0595 745232	SVETLANA NIKOLAEVA	{"email": "s-nikolaeva_14101965@postgrespro.ru", "phone": "+70330822434"}
0005433985133	832F0A	4558 005846	STANISLAV BARANOV	{"email": "stanislav-baranov12061966@postgrespro.ru", "phone": "+70732436253"}
0005433985134	9C7BD7	1665 686361	OLGA MARTYNOVA	{"email": "martynova-olga071963@postgrespro.ru", "phone": "+70541791323"}
0005433985135	332BFD	2956 977161	LYUBOV RYABOVA	{"email": "l_ryabova.20051968@postgrespro.ru", "phone": "+70520946186"}
0005433985136	B66E06	4351 546653	EKATERINA SCHERBAKOVA	{"email": "scherbakova-ekaterina091981@postgrespro.ru", "phone": "+70380525698"}
0005433985137	F934D4	2925 701052	EVGENIYA LAZAREVA	{"email": "evgeniya.lazareva.1982@postgrespro.ru", "phone": "+70407098617"}
0005433985138	4891A9	7877 221231	VASILIY ANDREEV	{"email": "andreevvasiliy_1962@postgrespro.ru", "phone": "+70786468989"}
0005433985139	F57F29	6740 181646	ALEKSANDR IVANOV	{"email": "ivanov_a_081968@postgrespro.ru", "phone": "+70883504054"}
0005433985140	F57F29	6776 472959	DANIIL TIMOFEEV	{"email": "timofeevd-061979@postgrespro.ru", "phone": "+70688912873"}
0005433985141	F57F29	4811 483899	LYUDMILA TROFIMOVA	{"phone": "+70791236022"}
0005433985142	F57F29	1652 827375	EKATERINA RYABOVA	{"email": "ekaterina_ryabova_051978@postgrespro.ru", "phone": "+70959510308"}
0005433985143	1F8A7B	5842 241346	PAVEL RODIONOV	{"phone": "+70754041836"}
0005433985144	1F8A7B	7238 468806	NATALYA ANDREEVA	{"phone": "+70518545664"}
0005433985145	217329	1579 369534	NADEZHDA GUSEVA	{"phone": "+70009909053"}
0005433985146	EC3651	7859 927475	IRINA VOROBEVA	{"email": "vorobeva-irina1972@postgrespro.ru", "phone": "+70344051003"}
0005433985147	DC5943	4785 363067	GALINA MASLOVA	{"phone": "+70241783946"}
0005433985148	DC5943	8389 992168	SHAMIL ANDREEV	{"phone": "+70757128090"}
0005433985149	B8C5B8	8308 547602	RUDOLF KONOVALOV	{"phone": "+70410395586"}
0005433985150	E00923	2564 240197	IVAN ALEKSANDROV	{"phone": "+70766692236"}
0005433985151	98F645	2345 209859	KRISTINA SOLOVEVA	{"email": "soloveva-k.1962@postgrespro.ru", "phone": "+70849771136"}
0005433985152	98F645	2892 463949	MAKSIM MAKAROV	{"email": "maksim-makarov.071972@postgrespro.ru", "phone": "+70380586804"}
0005433985153	CF4763	3657 704368	OLEG KOROLEV	{"email": "korolev.o_09121965@postgrespro.ru", "phone": "+70505654208"}
0005433985154	A2E896	5134 388175	VIKTOR MOISEEV	{"email": "moiseev_v.02121976@postgrespro.ru", "phone": "+70567850976"}
0005433985155	A2E896	8169 446694	NIKOLAY GAVRILOV	{"email": "n_gavrilov.051976@postgrespro.ru", "phone": "+70081615245"}
0005433985156	CD249A	3930 576529	LARISA EFREMOVA	{"phone": "+70837431446"}
0005433985157	37BA88	4662 252943	VALENTINA VOROBEVA	{"email": "v.vorobeva29051968@postgrespro.ru", "phone": "+70099813233"}
0005433985158	3904DF	1037 370185	DARYA ZHUKOVA	{"phone": "+70622632372"}
0005433985159	7E34DD	8861 343570	TATYANA GRISHINA	{"email": "t_grishina29021972@postgrespro.ru", "phone": "+70954275624"}
0005433985160	E52595	3101 038356	NATALYA FADEEVA	{"email": "n.fadeeva1978@postgrespro.ru", "phone": "+70646057938"}
0005433985161	330443	7836 425312	TAMARA KOROLEVA	{"phone": "+70532398886"}
0005433985162	4E4D5D	3748 539797	ANGELINA KUZNECOVA	{"phone": "+70119652815"}
0005433985163	4E4D5D	8845 347051	NATALYA DANILOVA	{"phone": "+70213530838"}
0005433985164	4E4D5D	2673 235730	VALENTINA ZAKHAROVA	{"email": "zakharova_v14081979@postgrespro.ru", "phone": "+70655423181"}
0005433985165	4E4D5D	1277 684848	GALINA KOROLEVA	{"email": "koroleva-g_011962@postgrespro.ru", "phone": "+70469898509"}
0005433985166	AAB96A	2222 901712	BORIS SMIRNOV	{"email": "smirnovboris16111966@postgrespro.ru", "phone": "+70637519277"}
0005433985167	AAB96A	7974 705053	VITALIY ZHUKOV	{"phone": "+70493574553"}
0005433985168	5882A6	0485 958078	OLGA KUZNECOVA	{"phone": "+70276485828"}
0005433985169	5882A6	2341 627067	NATALYA RODIONOVA	{"email": "n_rodionova_061973@postgrespro.ru", "phone": "+70644048119"}
0005433985170	34ABE5	0733 283504	MARINA NIKOLAEVA	{"email": "nikolaeva_marina-1972@postgrespro.ru", "phone": "+70926903348"}
0005433985171	160C58	0641 181693	NIKOLAY BORISOV	{"phone": "+70943092977"}
0005433985172	010457	0940 816798	VLADISLAV SEMENOV	{"email": "semenovvladislav.101967@postgrespro.ru", "phone": "+70002566596"}
0005433985173	010457	6670 513738	EVGENIY KUDRYASHOV	{"email": "kudryashov-e_091979@postgrespro.ru", "phone": "+70852481893"}
0005433985174	C8DCF4	3847 958476	IVAN SERGEEV	{"phone": "+70775176078"}
0005433985175	C8DCF4	0017 163250	ROMAN BELOV	{"email": "belovroman_27031980@postgrespro.ru", "phone": "+70151704740"}
0005433985176	5B64F6	6018 618607	ALBINA NESTEROVA	{"phone": "+70055879560"}
0005433985177	5235E1	4655 200548	ANASTASIYA MEDVEDEVA	{"phone": "+70740543914"}
0005433985178	625C22	8980 013476	IRINA ILINA	{"email": "irinailina.13061965@postgrespro.ru", "phone": "+70201994709"}
0005433985179	726402	8816 074864	GALINA VASILEVA	{"email": "g.vasileva-1969@postgrespro.ru", "phone": "+70757409009"}
0005433985180	C81174	1216 575018	NATALYA POPOVA	{"phone": "+70670137756"}
0005433985181	1CBB16	7650 952104	PAVEL SOROKIN	{"email": "sorokinp021976@postgrespro.ru", "phone": "+70562983707"}
0005433985182	066635	5716 848889	ALBERT KRASNOV	{"phone": "+70624699961"}
0005433985183	6CA177	3971 077823	GALINA ANISIMOVA	{"email": "g_anisimova_111969@postgrespro.ru", "phone": "+70310532848"}
0005433985184	8DB750	5208 679438	VIKTORIYA ZAKHAROVA	{"phone": "+70070340082"}
0005433985185	01D8B3	5124 779291	OLGA PETROVA	{"phone": "+70671112908"}
0005433985186	01D8B3	7463 738836	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov.aleksandr031960@postgrespro.ru", "phone": "+70145284043"}
0005433985187	01D8B3	0575 707048	VALENTINA DENISOVA	{"email": "vdenisova26111961@postgrespro.ru", "phone": "+70928732569"}
0005433985188	EAF5D1	4179 659314	ALEKSEY ZHURAVLEV	{"phone": "+70767312531"}
0005433985189	EAF5D1	9671 984046	KONSTANTIN KULIKOV	{"email": "k_kulikov.20121979@postgrespro.ru", "phone": "+70730804201"}
0005433985190	E7D92B	7640 173458	SERGEY VOLKOV	{"email": "sergey_volkov.1971@postgrespro.ru", "phone": "+70467837608"}
0005433985191	E5C2BF	2715 958305	ALEKSEY SAVELEV	{"phone": "+70994276833"}
0005433985192	78C0C3	2336 444717	OLGA LOGINOVA	{"email": "loginova.o091972@postgrespro.ru", "phone": "+70948476193"}
0005433985193	78C0C3	9668 293521	POLINA POPOVA	{"phone": "+70622028809"}
0005433985194	F8EBD8	3729 754052	VALENTINA DENISOVA	{"email": "valentina-denisova_05081973@postgrespro.ru", "phone": "+70710587978"}
0005433985195	F8EBD8	0817 643041	DARYA FILIPPOVA	{"email": "filippovad_1965@postgrespro.ru", "phone": "+70441675083"}
0005433985196	F8EBD8	3706 657671	VASILIY FEDOROV	{"phone": "+70656382735"}
0005433985197	D73D5E	8970 401399	VYACHESLAV BELOV	{"email": "belov-vyacheslav-031964@postgrespro.ru", "phone": "+70109422636"}
0005433985198	D73D5E	3777 483608	NATALYA OSIPOVA	{"phone": "+70885110374"}
0005433985199	60D460	0174 360228	VASILIY VOLKOV	{"phone": "+70900280296"}
0005433985200	60D460	0137 869168	VALERIY SIDOROV	{"phone": "+70058646970"}
0005433985201	91AAB2	7159 397814	IGOR VOLKOV	{"phone": "+70250902481"}
0005433985202	91AAB2	4571 943507	VLADIMIR ORLOV	{"email": "vladimirorlov-07011978@postgrespro.ru", "phone": "+70808214711"}
0005433985203	27E375	5969 389135	YURIY GAVRILOV	{"email": "yuriy.gavrilov.07021977@postgrespro.ru", "phone": "+70612692755"}
0005433985204	27E375	7408 794326	TATYANA POPOVA	{"email": "popovatatyana.1984@postgrespro.ru", "phone": "+70337630054"}
0005433985205	828E01	6461 071911	NATALYA KONOVALOVA	{"phone": "+70473925567"}
0005433985206	828E01	5402 713463	ELENA GORBUNOVA	{"phone": "+70470810071"}
0005433985207	7CBA4B	3537 695715	NIKITA VASILEV	{"email": "vasilev_nikita-1968@postgrespro.ru", "phone": "+70507224554"}
0005433985208	D1B11D	3513 126734	RUSLAN IVANOV	{"email": "ivanov-ruslan-1966@postgrespro.ru", "phone": "+70693428192"}
0005433985209	2B29B8	6991 562757	ZINAIDA IVANOVA	{"email": "z.ivanova_1969@postgrespro.ru", "phone": "+70206719891"}
0005433985210	D23E56	8937 369825	LYUDMILA SIDOROVA	{"phone": "+70012527416"}
0005433985211	D23E56	2390 656879	YURIY BELOV	{"email": "yuriybelov.061977@postgrespro.ru", "phone": "+70298300231"}
0005433985212	6DA08F	3412 752678	MAKSIM KOZLOV	{"email": "kozlovm24011962@postgrespro.ru", "phone": "+70204096159"}
0005433985213	B777C2	9026 076464	ANASTASIYA RODIONOVA	{"email": "anastasiyarodionova_29031975@postgrespro.ru", "phone": "+70086458945"}
0005433985214	045A14	1421 054497	OLEG ANDREEV	{"email": "oleg_andreev_21051960@postgrespro.ru", "phone": "+70715370123"}
0005433985215	738233	3649 723264	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr_23081968@postgrespro.ru", "phone": "+70820550869"}
0005433985216	738233	4465 944075	MARIYA PETROVA	{"email": "mpetrova_16041966@postgrespro.ru", "phone": "+70802924533"}
0005433985217	5D281F	4228 278687	EVGENIYA KISELEVA	{"email": "evgeniya_kiseleva1982@postgrespro.ru", "phone": "+70910129961"}
0005433985218	C2677B	9535 438851	TATYANA SERGEEVA	{"phone": "+70997883594"}
0005433985219	C2677B	2416 323827	VERA ZAKHAROVA	{"phone": "+70129134594"}
0005433985220	59E552	0215 083104	VIOLETTA YAKOVLEVA	{"phone": "+70855865306"}
0005433985221	59E552	7748 712407	GALINA IVANOVA	{"phone": "+70756052814"}
0005433985222	AC166D	2224 308286	VALENTINA MATVEEVA	{"email": "valentinamatveeva081964@postgrespro.ru", "phone": "+70068831821"}
0005433985223	FB0368	3852 649775	ALEKSANDR TARASOV	{"phone": "+70555125036"}
0005433985224	9E6193	1339 994075	KONSTANTIN BONDARENKO	{"phone": "+70776538984"}
0005433985225	1800EC	2866 942663	IRINA KISELEVA	{"email": "ikiseleva.26061969@postgrespro.ru", "phone": "+70499935784"}
0005433985226	DB056B	3833 254530	ANNA IVANOVA	{"phone": "+70528850316"}
0005433985227	DB056B	0841 384550	DMITRIY FEDOTOV	{"email": "fedotovd.26081982@postgrespro.ru", "phone": "+70090811905"}
0005433985228	DB056B	0741 012941	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr-051972@postgrespro.ru", "phone": "+70610514357"}
0005433985229	B1F966	6560 928326	ANTON ROMANOV	{"email": "anton.romanov-021983@postgrespro.ru", "phone": "+70842603833"}
0005433985230	B1F966	2982 920906	DIANA RODIONOVA	{"email": "rodionova-diana.1974@postgrespro.ru", "phone": "+70846962927"}
0005433985231	2E9D59	2213 569375	OLGA KUZNECOVA	{"email": "kuznecova.olga.1974@postgrespro.ru", "phone": "+70917020438"}
0005433985232	2E9D59	5247 983103	LARISA EGOROVA	{"phone": "+70680775447"}
0005433985233	5E58C7	6221 077154	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov-1969@postgrespro.ru", "phone": "+70379138812"}
0005433985234	61C7CD	4007 160872	KONSTANTIN VOLKOV	{"phone": "+70089707987"}
0005433985235	A761C1	4978 726800	VITALIY ZHURAVLEV	{"phone": "+70203887645"}
0005433985236	F73656	8865 392383	OLGA NESTEROVA	{"email": "nesterovaolga.091963@postgrespro.ru", "phone": "+70390203189"}
0005433985237	F05A36	8620 126172	ANDREY MOROZOV	{"phone": "+70399624256"}
0005433985238	575D73	5228 343536	ELENA ROMANOVA	{"phone": "+70161783224"}
0005433985239	1591B9	2946 679569	ALEKSEY ZAKHAROV	{"email": "azakharov27121968@postgrespro.ru", "phone": "+70741887123"}
0005433985240	1591B9	8783 501619	YANA GUSEVA	{"email": "guseva.yana-05081984@postgrespro.ru", "phone": "+70436810042"}
0005433985241	4CBA23	5539 370497	LIDIYA KOROLEVA	{"phone": "+70070621181"}
0005433985242	4CBA23	1475 402677	OLGA SMIRNOVA	{"email": "smirnova-olga.111978@postgrespro.ru", "phone": "+70297729184"}
0005433985243	1E3884	7226 258827	TATYANA FADEEVA	{"phone": "+70012909399"}
0005433985244	1D3021	9121 729729	NIKOLAY MOROZOV	{"phone": "+70405623159"}
0005433985245	069DCF	2735 627233	NATALYA KRASNOVA	{"email": "krasnova_n14111980@postgrespro.ru", "phone": "+70073443139"}
0005433985246	555C57	2389 284919	LYUDMILA PETROVA	{"email": "petrova-l-29011971@postgrespro.ru", "phone": "+70616450555"}
0005433985247	EF66C0	6648 156539	NINA GAVRILOVA	{"email": "nina-gavrilova_31051963@postgrespro.ru", "phone": "+70885511964"}
0005433985248	43089B	2128 188276	SVETLANA CHERNOVA	{"phone": "+70943223066"}
0005433985249	96FBCA	5033 173000	LYUBOV IVANOVA	{"email": "ivanoval1968@postgrespro.ru", "phone": "+70726260258"}
0005433985250	96FBCA	1875 669290	YULIYA DAVYDOVA	{"email": "yuliya-davydova_121955@postgrespro.ru", "phone": "+70104308566"}
0005433985251	BC8AA3	3114 460653	ALEKSEY SHEVCHENKO	{"email": "shevchenko_aleksey_13121964@postgrespro.ru", "phone": "+70351928504"}
0005433985252	BC8AA3	2820 762820	VITALIY FEDOROV	{"email": "fedorov-vitaliy_1970@postgrespro.ru", "phone": "+70384175059"}
0005433985253	DB9BED	2785 210064	ALEKSANDR POPOV	{"phone": "+70099313221"}
0005433985254	FB9969	1346 981230	IVAN POPOV	{"phone": "+70363763675"}
0005433985255	FB9969	9734 885291	YURIY YAKOVLEV	{"email": "yakovlevyuriy-091983@postgrespro.ru", "phone": "+70855239123"}
0005433985256	48E0B9	0574 252425	ELENA FEDOROVA	{"phone": "+70347470152"}
0005433985257	8D18F8	4186 787437	EVGENIYA KUZNECOVA	{"email": "kuznecova.e.061972@postgrespro.ru", "phone": "+70357146023"}
0005433985258	6540D5	7822 062856	ANDREY NAUMOV	{"email": "naumov_andrey02101976@postgrespro.ru", "phone": "+70870344346"}
0005433985259	B6B5DF	8138 407939	ELENA ANISIMOVA	{"phone": "+70982434336"}
0005433985260	B6B5DF	7903 698580	SERGEY GUSEV	{"email": "gusev_s-011971@postgrespro.ru", "phone": "+70808945217"}
0005433985261	21B547	3746 759348	MARGARITA DMITRIEVA	{"email": "dmitrieva.margarita.1981@postgrespro.ru", "phone": "+70708926667"}
0005433985262	008279	3982 575604	SERGEY SOROKIN	{"phone": "+70786452821"}
0005433985263	169D7F	9502 598363	ANATOLIY KUZNECOV	{"phone": "+70558195391"}
0005433985264	169D7F	8155 613796	VLADIMIR KARPOV	{"email": "vladimir_karpov_1972@postgrespro.ru", "phone": "+70592668858"}
0005433985265	DEFFFE	2140 412128	KLAVDIYA ZAKHAROVA	{"email": "zakharova_klavdiya.1969@postgrespro.ru", "phone": "+70499999642"}
0005433985266	1EC98F	5971 752816	ALEKSANDR ILIN	{"email": "aleksandr.ilin-03061970@postgrespro.ru", "phone": "+70935422238"}
0005433985267	1EC98F	2284 522691	EKATERINA KARPOVA	{"email": "karpovae091961@postgrespro.ru", "phone": "+70309738529"}
0005433985268	435D99	4375 274598	NATALYA MAKAROVA	{"phone": "+70677204271"}
0005433985269	56D761	9045 871044	ANASTASIYA SEMENOVA	{"phone": "+70407404240"}
0005433985270	28DCB6	3936 928840	LYUBOV BORISOVA	{"email": "l_borisova_16101975@postgrespro.ru", "phone": "+70579746797"}
0005433985271	42A315	9292 016848	ARINA ANTONOVA	{"phone": "+70816660442"}
0005433985272	42A315	4700 231584	DMITRIY GORBUNOV	{"email": "d-gorbunov.091970@postgrespro.ru", "phone": "+70037684142"}
0005433985273	7E2D22	0098 981307	EVGENIY TIKHONOV	{"email": "tikhonov-e.11051970@postgrespro.ru", "phone": "+70053697532"}
0005433985274	254F20	9906 350462	LYUDMILA NESTEROVA	{"phone": "+70247386307"}
0005433985275	1014C9	1548 944346	LIDIYA MAKAROVA	{"email": "makaroval091966@postgrespro.ru", "phone": "+70395161256"}
0005433985276	22B6F5	4569 153652	DMITRIY SOROKIN	{"phone": "+70037256140"}
0005433985277	22B6F5	9972 409722	GALINA SMIRNOVA	{"email": "smirnova.g_31011974@postgrespro.ru", "phone": "+70333577380"}
0005433985278	371779	8671 606000	IVAN SHEVCHENKO	{"phone": "+70144509787"}
0005433985279	D5F521	2292 751518	EVGENIYA VASILEVA	{"phone": "+70755245752"}
0005433985280	B9C076	0216 245505	YURIY FILIPPOV	{"email": "filippov.y091975@postgrespro.ru", "phone": "+70202343433"}
0005433985281	990E52	8908 756566	IVAN MOROZOV	{"email": "ivanmorozov_13051963@postgrespro.ru", "phone": "+70884309982"}
0005433985282	DF9E95	8119 319840	ARTEM ROMANOV	{"email": "romanov_artem_091976@postgrespro.ru", "phone": "+70294399351"}
0005433985283	DF9E95	8209 663887	DARYA GUSEVA	{"email": "d_guseva_021976@postgrespro.ru", "phone": "+70771341403"}
0005433985284	2DE0C3	6775 196398	EVGENIYA PETROVA	{"email": "evgeniyapetrova.051970@postgrespro.ru", "phone": "+70348747895"}
0005433985285	705DC4	9646 453694	IGOR GERASIMOV	{"phone": "+70947422443"}
0005433985286	E3C2A7	2672 941604	SVETLANA GUSEVA	{"email": "s_guseva23031965@postgrespro.ru", "phone": "+70260550951"}
0005433985287	A6202E	8375 704673	OLEG SOROKIN	{"phone": "+70705774387"}
0005433985288	A6202E	4087 695545	ELENA ROMANOVA	{"email": "romanova_e.031979@postgrespro.ru", "phone": "+70302494257"}
0005433985289	262DEB	8096 026063	VALENTINA DMITRIEVA	{"email": "dmitrievavalentina_19011964@postgrespro.ru", "phone": "+70514705173"}
0005433985290	262DEB	0530 018009	DMITRIY EGOROV	{"email": "dmitriy.egorov-121984@postgrespro.ru", "phone": "+70609305287"}
0005433985291	262DEB	4643 164903	ALEKSEY IVANOV	{"email": "aivanov.1963@postgrespro.ru", "phone": "+70352275504"}
0005433985292	726B94	6074 596767	ALEKSANDR SMIRNOV	{"phone": "+70545453155"}
0005433985293	726B94	4216 131607	OLGA NESTEROVA	{"email": "nesterova_o-1980@postgrespro.ru", "phone": "+70240880577"}
0005433985294	647320	0921 773378	ANASTASIYA LOGINOVA	{"phone": "+70034203010"}
0005433985295	144BBD	0771 510118	VALERIY POPOV	{"email": "vpopov-091968@postgrespro.ru", "phone": "+70466100961"}
0005433985296	7FBA2D	4995 226447	LYUBOV IVANOVA	{"phone": "+70026256905"}
0005433985297	7FBA2D	3502 701138	GALINA KALININA	{"phone": "+70794035138"}
0005433985298	9B8DAD	4286 343220	MARINA NIKITINA	{"email": "nikitina.m-041964@postgrespro.ru", "phone": "+70826031604"}
0005433985299	9B8DAD	1924 100019	SERGEY KUZNECOV	{"email": "kuznecovsergey111977@postgrespro.ru", "phone": "+70654064588"}
0005433985300	378581	7805 071059	NADEZHDA MAKSIMOVA	{"phone": "+70788716143"}
0005433985301	378581	6858 506702	MIKHAIL ZAKHAROV	{"email": "zakharovmikhail_07051973@postgrespro.ru", "phone": "+70570853892"}
0005433985302	A90CE2	4166 521792	OLEG EGOROV	{"phone": "+70341091872"}
0005433985303	F6FAD5	8340 475833	GALINA KONOVALOVA	{"phone": "+70600775282"}
0005433985304	F6FAD5	2557 198822	OLEG NOVIKOV	{"email": "o-novikov1973@postgrespro.ru", "phone": "+70354336924"}
0005433985305	1811AB	8497 368173	LYUBOV DENISOVA	{"email": "denisova-lyubov-18051975@postgrespro.ru", "phone": "+70942168198"}
0005433985306	7A82DA	4917 314199	EDUARD SCHERBAKOV	{"email": "eduard.scherbakov111972@postgrespro.ru", "phone": "+70054285816"}
0005433985307	98732C	7289 591436	OKSANA TARASOVA	{"email": "tarasovao071981@postgrespro.ru", "phone": "+70741876295"}
0005433985308	55C356	4672 145692	YURIY SOLOVEV	{"email": "solovev_y_021964@postgrespro.ru", "phone": "+70655444324"}
0005433985309	8E9F79	0604 500363	YAROSLAV MELNIKOV	{"phone": "+70947973283"}
0005433985310	893528	5024 891762	VLADIMIR MARTYNOV	{"email": "martynov-vladimir.011969@postgrespro.ru", "phone": "+70853541296"}
0005433985311	F106A0	3898 984579	DMITRIY ILIN	{"phone": "+70513869467"}
0005433985312	97694B	6819 880695	ANDREY KUZNECOV	{"phone": "+70864511157"}
0005433985313	9111AF	5560 594295	LYUDMILA LAZAREVA	{"phone": "+70330086549"}
0005433985314	F68CD6	8827 473452	NIKOLAY POPOV	{"email": "popov_nikolay.1967@postgrespro.ru", "phone": "+70140324572"}
0005433985315	F68CD6	2905 811767	MIKHAIL ANDREEV	{"phone": "+70618633314"}
0005433985316	6AC6C6	3315 073792	IVAN KUZMIN	{"email": "ikuzmin.18041962@postgrespro.ru", "phone": "+70171792172"}
0005433985317	6AC6C6	1430 838870	VASILIY NIKITIN	{"email": "vasiliy-nikitin011974@postgrespro.ru", "phone": "+70263197809"}
0005433985318	FF7228	0718 652770	DMITRIY PETROV	{"phone": "+70327839322"}
0005433985319	D41B8F	9684 434362	ROMAN NIKITIN	{"email": "nikitin_r_29071982@postgrespro.ru", "phone": "+70692875776"}
0005433985320	FA69D2	2310 891780	ARTEM SEMENOV	{"phone": "+70250617713"}
0005433985321	C65BFC	8825 126003	RAISA VASILEVA	{"email": "raisa-vasileva_1982@postgrespro.ru", "phone": "+70315886376"}
0005433985322	C65BFC	3317 500280	VIKTOR ANDREEV	{"email": "viktor_andreev.031970@postgrespro.ru", "phone": "+70501278432"}
0005433985323	C65BFC	2334 612879	ANDREY STEPANOV	{"phone": "+70738719663"}
0005433985324	86D749	5491 320226	ANDREY MOISEEV	{"email": "a.moiseev.25091972@postgrespro.ru", "phone": "+70193090472"}
0005433985325	86D749	0558 669132	ANNA AFANASEVA	{"email": "a-afanaseva-101964@postgrespro.ru", "phone": "+70791547523"}
0005433985326	02FD54	1919 164207	ANTON PETROV	{"phone": "+70613585877"}
0005433985327	513459	4837 741063	LYUDMILA KONDRATEVA	{"email": "kondrateva.l_1969@postgrespro.ru", "phone": "+70506285079"}
0005433985328	513459	6104 935153	FEDOR MAKSIMOV	{"email": "maksimov_f1983@postgrespro.ru", "phone": "+70365510490"}
0005433985329	A3530E	7143 434711	VADIM BARANOV	{"phone": "+70956321848"}
0005433985330	A2C555	6428 993301	KONSTANTIN ZHUKOV	{"phone": "+70118272894"}
0005433985331	A2C555	7304 557223	ELIZAVETA YUDINA	{"phone": "+70842508465"}
0005433985332	85F9D9	9012 114911	VALENTINA YUDINA	{"email": "yudinavalentina26061968@postgrespro.ru", "phone": "+70871389939"}
0005433985333	E27CEC	6553 664739	LYUBOV NIKOLAEVA	{"email": "lnikolaeva_121968@postgrespro.ru", "phone": "+70414051399"}
0005433985334	E27CEC	1198 759013	VLADIMIR KUDRYASHOV	{"email": "vladimir.kudryashov-051980@postgrespro.ru", "phone": "+70706679668"}
0005433985335	C889C3	7840 078812	DMITRIY DAVYDOV	{"phone": "+70420234570"}
0005433985336	3D5E01	1232 731790	VERA IVANOVA	{"email": "ivanova.vera.101973@postgrespro.ru", "phone": "+70160217844"}
0005433985337	CBE488	8216 829539	VALENTINA SEMENOVA	{"phone": "+70211317900"}
0005433985338	8AFFA7	6232 811446	ALEKSANDR FILIPPOV	{"email": "filippov_a.1963@postgrespro.ru", "phone": "+70459042681"}
0005433985339	8AFFA7	7039 472826	NINA POTAPOVA	{"email": "potapova_nina-071954@postgrespro.ru", "phone": "+70346461845"}
0005433985340	2DA841	4178 729031	ILDAR SIDOROV	{"phone": "+70104982614"}
0005433985341	2DA841	9409 134683	OLGA EFIMOVA	{"email": "oefimova-04101970@postgrespro.ru", "phone": "+70988735518"}
0005433985342	2DA841	1209 939062	ALEKSANDR MIKHAYLOV	{"phone": "+70162211773"}
0005433985343	540C68	1153 357795	RUSTAM KOZLOV	{"phone": "+70076781676"}
0005433985344	D52028	9611 749634	ALINA DAVYDOVA	{"email": "davydova_a-1968@postgrespro.ru", "phone": "+70751862643"}
0005433985345	DF7551	6065 480908	ANDREY NOVIKOV	{"email": "anovikov.21081967@postgrespro.ru", "phone": "+70703443174"}
0005433985346	DF7551	7303 051441	DMITRIY IVANOV	{"phone": "+70105657283"}
0005433985347	55D8CD	9764 422668	TATYANA MASLOVA	{"phone": "+70762868473"}
0005433985348	70A24F	2068 406020	KRISTINA ALEKSEEVA	{"email": "kristina.alekseeva_1985@postgrespro.ru", "phone": "+70624219267"}
0005433985349	C74F0D	0320 392291	KSENIYA MASLOVA	{"phone": "+70332166056"}
0005433985350	4B24C8	0256 458464	EVGENIY DMITRIEV	{"email": "e.dmitriev-011959@postgrespro.ru", "phone": "+70031400647"}
0005433985351	637D3B	9731 845899	PAVEL EGOROV	{"email": "egorov.pavel-1975@postgrespro.ru", "phone": "+70783630803"}
0005433985352	6041D4	2363 803976	LYUBOV AKIMOVA	{"phone": "+70773954596"}
0005433985353	8F3E3B	2911 327772	ALEKSANDR SAVELEV	{"phone": "+70711855621"}
0005433985354	B68D71	8391 623786	RINAT IVANOV	{"phone": "+70532480969"}
0005433985355	01FE9E	8377 314424	IVAN DENISOV	{"phone": "+70071964456"}
0005433985356	78FF96	2890 480193	IVAN IVANOV	{"phone": "+70007237408"}
0005433985357	78FF96	4713 530436	VALERIY VASILEV	{"phone": "+70112046692"}
0005433985358	0060D3	9047 855605	ALEKSANDR MIKHAYLOV	{"phone": "+70858347443"}
0005433985359	4706D7	2480 021051	DMITRIY ZAYCEV	{"email": "zaycev.dmitriy13081959@postgrespro.ru", "phone": "+70736345180"}
0005433985480	14E733	4507 514509	TATYANA NIKITINA	{"phone": "+70430524781"}
0005433985360	4706D7	3000 672696	ARTEM KRASNOV	{"email": "a-krasnov_051974@postgrespro.ru", "phone": "+70088949725"}
0005433985361	DD5C78	1849 754732	ANTONINA KOLESNIKOVA	{"phone": "+70644697371"}
0005433985362	698FFC	2092 060877	ANASTASIYA FILIPPOVA	{"phone": "+70493968900"}
0005433985363	02637B	3933 884015	SERGEY PAVLOV	{"email": "spavlov.1975@postgrespro.ru", "phone": "+70279471226"}
0005433985364	3BEA60	3575 250644	YULIYA BOGDANOVA	{"email": "bogdanovayuliya-04041969@postgrespro.ru", "phone": "+70799992814"}
0005433985365	3BEA60	2996 154858	ALEKSANDR KAZAKOV	{"email": "kazakov.a.05081974@postgrespro.ru", "phone": "+70762369172"}
0005433985366	7A8DD1	8287 940929	VYACHESLAV ROMANOV	{"email": "vyacheslav.romanov.081965@postgrespro.ru", "phone": "+70546565579"}
0005433985367	D05DB2	2342 485452	ANASTASIYA EFIMOVA	{"phone": "+70366951300"}
0005433985368	D05DB2	4718 244359	SERGEY KUZMIN	{"email": "s_kuzmin-25031971@postgrespro.ru", "phone": "+70709946258"}
0005433985369	A813C2	1391 760578	ELENA NIKOLAEVA	{"phone": "+70639712508"}
0005433985370	A813C2	7983 216074	NINA ALEKSEEVA	{"email": "n.alekseeva031950@postgrespro.ru", "phone": "+70666149659"}
0005433985371	FC5F60	3412 138136	ALEKSEY PETROV	{"phone": "+70671478080"}
0005433985372	1E3856	1408 587710	NIKOLAY CHERNOV	{"phone": "+70972673411"}
0005433985373	7B3699	3227 534870	VASILIY NOVIKOV	{"phone": "+70524400033"}
0005433985374	7B3699	9310 971784	EVGENIYA ANDREEVA	{"phone": "+70202690949"}
0005433985375	25A21F	4276 347241	VLADIMIR KOROLEV	{"email": "korolevvladimir071958@postgrespro.ru", "phone": "+70207254124"}
0005433985376	C701AB	5342 871491	DARYA ZOTOVA	{"phone": "+70803033584"}
0005433985377	9E9CCA	5474 812291	VITALIY MOISEEV	{"phone": "+70084663402"}
0005433985378	32FB0D	0700 642429	KIRILL MIRONOV	{"email": "kirillmironov-1972@postgrespro.ru", "phone": "+70256286388"}
0005433985379	32FB0D	2237 401174	ELENA TIMOFEEVA	{"phone": "+70631954963"}
0005433985380	32FB0D	3139 059003	SERGEY MAKSIMOV	{"phone": "+70115227990"}
0005433985381	B988CC	5367 217838	VALENTINA KUZNECOVA	{"email": "v-kuznecova_061962@postgrespro.ru", "phone": "+70968005748"}
0005433985382	B988CC	0316 989448	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov-1965@postgrespro.ru", "phone": "+70091947799"}
0005433985383	BEFD8A	6616 143128	NADEZHDA MAKSIMOVA	{"email": "n-maksimova.18011967@postgrespro.ru", "phone": "+70879752903"}
0005433985384	19746E	4550 530033	LYUDMILA DMITRIEVA	{"phone": "+70525872489"}
0005433985385	19746E	7310 946997	ALEKSEY GAVRILOV	{"email": "agavrilov111974@postgrespro.ru", "phone": "+70872017339"}
0005433985609	750303	0818 344187	GENNADIY KARPOV	{"phone": "+70054749600"}
0005433985386	19746E	1532 380100	SERGEY KOZLOV	{"email": "kozlov-sergey21011962@postgrespro.ru", "phone": "+70058300923"}
0005433985387	97B683	5569 477533	NADEZHDA KOROLEVA	{"email": "koroleva-n.1967@postgrespro.ru", "phone": "+70743186049"}
0005433985388	97B683	4294 497894	ALEKSEY NIKITIN	{"phone": "+70347567809"}
0005433985389	46BD42	8239 960407	NATALYA MARTYNOVA	{"email": "martynova.n_051971@postgrespro.ru", "phone": "+70466753137"}
0005433985390	2F9361	5226 888606	VLADIMIR NIKOLAEV	{"phone": "+70328315876"}
0005433985391	2F9361	8479 464422	LYUDMILA FROLOVA	{"email": "frolova_lyudmila_25031981@postgrespro.ru", "phone": "+70423666712"}
0005433985392	058A94	2374 102443	TATYANA BORISOVA	{"email": "t.borisova_30091966@postgrespro.ru", "phone": "+70988344766"}
0005433985393	058A94	2436 953373	SVETLANA KOROLEVA	{"phone": "+70005481168"}
0005433985394	B15973	2960 537115	GALINA GORBUNOVA	{"phone": "+70072467803"}
0005433985395	B15973	7204 294537	STANISLAV SEMENOV	{"email": "semenov-stanislav1972@postgrespro.ru", "phone": "+70278936550"}
0005433985396	BEDD5F	2043 190298	LYUBOV ZAYCEVA	{"email": "zayceva-l091980@postgrespro.ru", "phone": "+70767318385"}
0005433985397	BEDD5F	6593 209415	YURIY SEMENOV	{"phone": "+70487597292"}
0005433985398	BEDD5F	5635 153934	ALEKSANDR GERASIMOV	{"phone": "+70574284609"}
0005433985399	386E06	4531 357922	MARGARITA NIKOLAEVA	{"phone": "+70874549242"}
0005433985400	7C6576	7800 620561	ALEKSANDR SERGEEV	{"phone": "+70565491264"}
0005433985401	7C6576	5728 937843	TATYANA NAUMOVA	{"phone": "+70375463853"}
0005433985402	C35135	7948 321109	ALENA FOMINA	{"phone": "+70860245722"}
0005433985403	E300BE	8840 814779	ELENA ABRAMOVA	{"email": "eabramova-1966@postgrespro.ru", "phone": "+70034884457"}
0005433985404	9E7E36	3528 219922	TATYANA POLYAKOVA	{"phone": "+70167388426"}
0005433985405	9E7E36	8541 763016	YURIY OSIPOV	{"email": "osipov_yuriy.1972@postgrespro.ru", "phone": "+70296031910"}
0005433985406	E546B1	6952 932445	VALERIY SIDOROV	{"phone": "+70477747610"}
0005433985407	107E9C	4015 292878	ZINAIDA GAVRILOVA	{"email": "gavrilova-z-23031968@postgrespro.ru", "phone": "+70378604714"}
0005433985408	79C8B4	6328 321888	EKATERINA POPOVA	{"email": "popova_e02081976@postgrespro.ru", "phone": "+70766131933"}
0005433985409	79C8B4	6643 032597	KIRILL DAVYDOV	{"email": "davydov-k1966@postgrespro.ru", "phone": "+70685348442"}
0005433985410	029434	8504 553830	VLADIMIR ZAYCEV	{"phone": "+70564235790"}
0005433985411	029434	8237 891810	YULIYA EGOROVA	{"email": "y_egorova.27101967@postgrespro.ru", "phone": "+70061890829"}
0005433985412	06C731	4901 004141	GENNADIY ANDREEV	{"email": "g_andreev-1975@postgrespro.ru", "phone": "+70050767306"}
0005433985413	7D040B	2319 393938	VASILIY FILIPPOV	{"phone": "+70070928323"}
0005433985414	7D040B	6665 990200	ANASTASIYA FILIPPOVA	{"email": "filippova-a_1971@postgrespro.ru", "phone": "+70260099863"}
0005433985415	7D040B	0351 763872	VALENTINA ANDREEVA	{"email": "v.andreeva101967@postgrespro.ru", "phone": "+70881980383"}
0005433985416	B1D7DD	8426 600781	TATYANA EGOROVA	{"phone": "+70932592344"}
0005433985417	68ADB2	8566 597346	ALEKSANDR KUZNECOV	{"phone": "+70226088977"}
0005433985418	BC6F79	0780 591693	NIKOLAY VOROBEV	{"email": "vorobev-n1978@postgrespro.ru", "phone": "+70030297975"}
0005433985419	BC6F79	6670 673987	ALEKSEY ILIN	{"email": "aleksey_ilin_1981@postgrespro.ru", "phone": "+70946336429"}
0005433985420	3065F9	7821 299627	KONSTANTIN NIKOLAEV	{"email": "konstantin-nikolaev_1981@postgrespro.ru", "phone": "+70221786758"}
0005433985421	3065F9	7181 107445	MARINA FADEEVA	{"email": "m.fadeeva-27061973@postgrespro.ru", "phone": "+70442844792"}
0005433985422	2BD234	4488 840148	MARINA ZHUKOVA	{"phone": "+70055623444"}
0005433985423	2BD234	0876 981484	NADEZHDA FROLOVA	{"phone": "+70860749754"}
0005433985424	2BD234	2586 519678	ALEKSANDR ZAYCEV	{"email": "zaycev.a.07071982@postgrespro.ru", "phone": "+70652153476"}
0005433985425	B356D3	9293 115570	DMITRIY SMIRNOV	{"email": "smirnovd_1963@postgrespro.ru", "phone": "+70648178992"}
0005433985426	9739E4	0258 170969	NADEZHDA NIKOLAEVA	{"email": "nikolaeva-n_051975@postgrespro.ru", "phone": "+70910955667"}
0005433985427	1953BF	2278 838645	EKATERINA TIKHONOVA	{"phone": "+70901499120"}
0005433985428	1953BF	1671 589457	NATALYA RODIONOVA	{"phone": "+70205348982"}
0005433985429	1953BF	4470 719382	NIKOLAY KOZLOV	{"email": "kozlovn_101974@postgrespro.ru", "phone": "+70311797082"}
0005433985430	90A2D1	1685 452440	SERGEY DAVYDOV	{"email": "davydov_s-25101964@postgrespro.ru", "phone": "+70200625698"}
0005433985431	0EAB13	6061 833177	VENIAMIN YAKOVLEV	{"phone": "+70383431579"}
0005433985432	0EAB13	6558 595413	ELENA ANDREEVA	{"phone": "+70884586122"}
0005433985433	BDB378	5745 470133	MARIYA PETROVA	{"phone": "+70874659448"}
0005433985434	C812CC	2901 264935	VLADIMIR BELOV	{"phone": "+70203506211"}
0005433985435	C4E896	7704 496684	KONSTANTIN MATVEEV	{"email": "matveev-k1980@postgrespro.ru", "phone": "+70227971975"}
0005433985436	321E19	2384 594135	VIKTOR ISAEV	{"email": "v.isaev31031975@postgrespro.ru", "phone": "+70738111803"}
0005433985437	BC411A	3056 292899	ANNA TARASOVA	{"email": "anna_tarasova_1969@postgrespro.ru", "phone": "+70527444060"}
0005433985438	B1EF30	3725 792216	NADEZHDA MELNIKOVA	{"email": "melnikova-n_011972@postgrespro.ru", "phone": "+70551626935"}
0005433985439	B1EF30	8641 654090	ALEKSANDR BONDARENKO	{"email": "bondarenkoaleksandr-031973@postgrespro.ru", "phone": "+70344848338"}
0005433985440	9EA77D	2911 935410	SVETLANA KOVALEVA	{"email": "kovaleva.svetlana-13021979@postgrespro.ru", "phone": "+70562706493"}
0005433985441	9EA77D	8660 441039	ANASTASIYA LEBEDEVA	{"phone": "+70662778238"}
0005433985442	9EA77D	1303 393666	ANDREY ANTONOV	{"email": "andrey_antonov1964@postgrespro.ru", "phone": "+70265848887"}
0005433985443	D0B97C	9011 728675	GALINA NIKIFOROVA	{"phone": "+70559386765"}
0005433985444	D93946	9159 577831	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr06071964@postgrespro.ru", "phone": "+70016289906"}
0005433985445	AABDA9	3391 988343	DAVID ILIN	{"email": "david-ilin051981@postgrespro.ru", "phone": "+70659749364"}
0005433985446	AABDA9	9992 408183	EVGENIY MIRONOV	{"email": "mironov.evgeniy.25011969@postgrespro.ru", "phone": "+70495541230"}
0005433985447	D44CF0	9568 722646	ALINA IVANOVA	{"phone": "+70387875540"}
0005433985448	F5E959	7688 240870	ALINA KONOVALOVA	{"email": "alina.konovalova-1973@postgrespro.ru", "phone": "+70580455375"}
0005433985449	2F3042	3124 135180	ARTEM KAZAKOV	{"email": "kazakov.artem.081976@postgrespro.ru", "phone": "+70074592698"}
0005433985450	BE0CDE	0082 487358	NINA KUZNECOVA	{"email": "nkuznecova.1961@postgrespro.ru", "phone": "+70710521075"}
0005433985451	1DDADA	7144 785956	ANZHELIKA SCHERBAKOVA	{"phone": "+70471229439"}
0005433985452	1DDADA	1595 358876	ALEKSEY FILIPPOV	{"phone": "+70018431354"}
0005433985453	2019E6	1912 684739	KLAVDIYA MELNIKOVA	{"email": "melnikovaklavdiya_061971@postgrespro.ru", "phone": "+70657251418"}
0005433985454	2019E6	4106 056260	NADEZHDA ABRAMOVA	{"phone": "+70277447913"}
0005433985455	8B12F6	5105 954325	ELENA KRASNOVA	{"phone": "+70580241475"}
0005433985456	8B12F6	2933 048263	MARINA DANILOVA	{"phone": "+70148081623"}
0005433985457	8B12F6	4054 145901	ANTON TIKHONOV	{"phone": "+70715785670"}
0005433985458	547762	9639 401586	ELENA EFREMOVA	{"phone": "+70244234297"}
0005433985459	7ADA9C	4296 281211	SERGEY FEDOROV	{"email": "sfedorov031974@postgrespro.ru", "phone": "+70980244738"}
0005433985460	415290	6560 712954	VIKTORIYA TIKHONOVA	{"phone": "+70282206971"}
0005433985461	A80C14	3901 245985	DMITRIY IVANOV	{"phone": "+70966606742"}
0005433985462	2C6A5D	5170 264276	PAVEL STEPANOV	{"email": "stepanovpavel.16101978@postgrespro.ru", "phone": "+70369256704"}
0005433985463	2C6A5D	1651 832045	OLEG ZAKHAROV	{"email": "zakharov.o.041974@postgrespro.ru", "phone": "+70850937631"}
0005433985464	EA9B2D	0741 576464	TATYANA NAUMOVA	{"phone": "+70053671718"}
0005433985465	EA9B2D	1608 846240	SVETLANA GUSEVA	{"phone": "+70208643856"}
0005433985466	5446FF	7937 373009	AMIR GUSEV	{"email": "guseva101974@postgrespro.ru", "phone": "+70334109620"}
0005433985467	377122	3900 088716	ANNA NIKITINA	{"phone": "+70698058528"}
0005433985468	ADEE59	7617 666855	LYUDMILA MOROZOVA	{"phone": "+70380896509"}
0005433985469	ADEE59	9305 413629	ALEKSEY BONDARENKO	{"email": "bondarenko_aleksey-25061969@postgrespro.ru", "phone": "+70572425466"}
0005433985470	3171BA	5826 101517	VIKTOR VLASOV	{"email": "viktor.vlasov-18021976@postgrespro.ru", "phone": "+70863475114"}
0005433985471	3171BA	2086 669804	NIKITA IVANOV	{"phone": "+70737797068"}
0005433985472	A0C533	8480 165315	ZULFIYA IVANOVA	{"email": "zulfiyaivanova_1970@postgrespro.ru", "phone": "+70555152136"}
0005433985473	43B844	8719 196728	VLADIMIR BORISOV	{"phone": "+70233973054"}
0005433985474	C265A8	7900 260877	SERGEY SEMENOV	{"phone": "+70298684926"}
0005433985475	EB96D5	6508 745724	IGOR BARANOV	{"phone": "+70616683250"}
0005433985476	EB96D5	5445 717676	ANNA NAUMOVA	{"phone": "+70847398966"}
0005433985477	A7286D	0828 890738	EKATERINA LEBEDEVA	{"phone": "+70107775244"}
0005433985478	912C57	1772 886668	INNA TARASOVA	{"phone": "+70236992496"}
0005433985479	BCC371	6730 504660	PAVEL KUZNECOV	{"phone": "+70961303627"}
0005433985481	14E733	8003 825434	GALINA ANISIMOVA	{"email": "galina.anisimova.1977@postgrespro.ru", "phone": "+70648723146"}
0005433985482	EEDDC3	7086 410548	NATALYA NAZAROVA	{"email": "n-nazarova-071961@postgrespro.ru", "phone": "+70193987769"}
0005433985483	EEDDC3	8306 274036	EKATERINA KUZNECOVA	{"email": "kuznecova_e.02031975@postgrespro.ru", "phone": "+70471335243"}
0005433985484	C3D500	0763 827251	MIKHAIL SMIRNOV	{"phone": "+70116421917"}
0005433985485	C3D500	3637 624350	SERGEY SOLOVEV	{"phone": "+70251761128"}
0005433985486	2B4487	8914 643079	PETR DAVYDOV	{"email": "petr.davydov.041981@postgrespro.ru", "phone": "+70757425036"}
0005433985487	2B4487	2196 785882	PETR NAUMOV	{"phone": "+70895844303"}
0005433985488	C6755F	7600 046961	DMITRIY BORISOV	{"phone": "+70259474255"}
0005433985489	C6755F	5570 386945	LYUBOV MIRONOVA	{"phone": "+70197613153"}
0005433985490	8B8699	9018 998748	VLADIMIR BONDARENKO	{"email": "bondarenko-v27071973@postgrespro.ru", "phone": "+70589703421"}
0005433985491	6EED8F	1053 009591	SVETLANA SMIRNOVA	{"email": "smirnova-s28021969@postgrespro.ru", "phone": "+70511330554"}
0005433985492	1C5C50	2922 259833	ULYANA ORLOVA	{"email": "u_orlova27111964@postgrespro.ru", "phone": "+70029539815"}
0005433985493	1C5C50	8767 756817	LYUDMILA VASILEVA	{"email": "vasileva-l1983@postgrespro.ru", "phone": "+70436792599"}
0005433985494	B48AD4	0958 303438	DARYA ZAKHAROVA	{"email": "zakharova_darya1969@postgrespro.ru", "phone": "+70405499900"}
0005433985495	B48AD4	2137 748826	RIMMA BELOVA	{"phone": "+70874972798"}
0005433985496	B48AD4	7506 581744	FILIPP KUZNECOV	{"email": "kuznecov-f.23011962@postgrespro.ru", "phone": "+70129789520"}
0005433985497	9FEA34	9901 753248	YULIYA ERMAKOVA	{"email": "y-ermakova12041962@postgrespro.ru", "phone": "+70741369447"}
0005433985945	3325DF	3172 432617	VALENTINA KONDRATEVA	{"phone": "+70667844663"}
0005433985498	90897F	4918 259606	NIKOLAY SIDOROV	{"email": "sidorov_n_101966@postgrespro.ru", "phone": "+70508004816"}
0005433985499	E1BA5C	2424 443378	VALENTINA ZOTOVA	{"email": "valentina_zotova-01101960@postgrespro.ru", "phone": "+70455109589"}
0005433985500	85C1B9	5706 209471	OLGA ANDREEVA	{"email": "andreeva-olga071972@postgrespro.ru", "phone": "+70713390286"}
0005433985501	3B0706	2693 534493	ANASTASIYA ANDREEVA	{"email": "andreeva.anastasiya1959@postgrespro.ru", "phone": "+70298504904"}
0005433985502	3B0706	8557 557129	ELIZAVETA YAKOVLEVA	{"phone": "+70988905650"}
0005433985503	66C15A	8325 677848	ELENA ZAKHAROVA	{"email": "e_zakharova-1961@postgrespro.ru", "phone": "+70498726863"}
0005433985504	93F178	5036 820137	IRINA NIKOLAEVA	{"email": "nikolaeva-i101977@postgrespro.ru", "phone": "+70606445200"}
0005433985505	1438EE	0153 372490	SVETLANA FOMINA	{"email": "svetlanafomina_06101971@postgrespro.ru", "phone": "+70105430050"}
0005433985506	B2FCE7	7292 202915	VITALIY MOROZOV	{"email": "v-morozov-041981@postgrespro.ru", "phone": "+70390453467"}
0005433985507	65DE7F	6410 827872	VALENTINA ZHUKOVA	{"email": "zhukova.valentina.1974@postgrespro.ru", "phone": "+70697605061"}
0005433985508	19222B	8975 853296	NATALYA PAVLOVA	{"phone": "+70121800947"}
0005433985509	25224C	5607 541089	GENNADIY DMITRIEV	{"phone": "+70396202500"}
0005433985510	C1E4F8	8850 107004	NINA ARKHIPOVA	{"phone": "+70876042851"}
0005433985511	4FA1B3	2786 019596	ANNA AKIMOVA	{"email": "aakimova-25091970@postgrespro.ru", "phone": "+70126346786"}
0005433985512	69B76F	7776 994767	ALEKSANDR ALEKSEEV	{"email": "alekseeva-04011969@postgrespro.ru", "phone": "+70867315792"}
0005433985513	69B76F	9660 665366	SVETLANA ABRAMOVA	{"phone": "+70388433738"}
0005433985514	635614	9399 920113	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov_061986@postgrespro.ru", "phone": "+70417422480"}
0005433985515	7695F3	6471 911740	VALERIY ZAKHAROV	{"phone": "+70628358374"}
0005433985516	7695F3	2908 797119	TATYANA KUZNECOVA	{"phone": "+70263986477"}
0005433985517	405B73	9228 562248	VLADISLAV VLASOV	{"phone": "+70186517826"}
0005433985518	7C02F4	3603 486224	LYUBOV NAZAROVA	{"phone": "+70839803277"}
0005433985519	7C02F4	3787 607391	ALENA ZAYCEVA	{"phone": "+70804451989"}
0005433985520	0B0302	8974 407452	ALEKSEY FILIPPOV	{"phone": "+70496494803"}
0005433985521	0B0302	7455 585224	ANDREY KONOVALOV	{"email": "akonovalov_1975@postgrespro.ru", "phone": "+70699225976"}
0005433985522	A890BA	1840 893409	VALERIYA NIKIFOROVA	{"phone": "+70047114007"}
0005433985523	706FC0	2165 156379	ANASTASIYA SEMENOVA	{"email": "anastasiya-semenova18051969@postgrespro.ru", "phone": "+70444544242"}
0005433985524	706FC0	4789 515899	TATYANA RYABOVA	{"email": "t-ryabova051981@postgrespro.ru", "phone": "+70146776748"}
0005433985525	281BD1	0884 860746	VENIAMIN FROLOV	{"phone": "+70644768483"}
0005433985526	281BD1	9897 128031	NAILYA SIDOROVA	{"phone": "+70918238238"}
0005433985527	404094	7321 809246	ARTEM TIMOFEEV	{"email": "timofeev-a.05081972@postgrespro.ru", "phone": "+70357434864"}
0005433985528	270270	8216 056739	OLGA VOLKOVA	{"phone": "+70493154517"}
0005433985529	44A1D4	6076 414179	ANASTASIYA FADEEVA	{"email": "anastasiya_fadeeva_02051967@postgrespro.ru", "phone": "+70628461816"}
0005433985530	4B1AD2	5790 694256	OKSANA PETROVA	{"phone": "+70534367025"}
0005433985531	4E0818	2961 178824	VLADISLAV GAVRILOV	{"email": "gavrilov.v.1962@postgrespro.ru", "phone": "+70818233436"}
0005433985532	07019F	3303 791395	ALEKSANDR KUDRYASHOV	{"phone": "+70564982717"}
0005433985533	1A0F33	2107 026449	NATALYA TITOVA	{"email": "n.titova-1957@postgrespro.ru", "phone": "+70441726596"}
0005433985534	CAB080	7647 041220	YURIY VLASOV	{"email": "yuriy-vlasov1975@postgrespro.ru", "phone": "+70056390512"}
0005433985535	CAB080	3283 945340	ZAKHAR KOROLEV	{"phone": "+70734703017"}
0005433985536	C0E100	3029 195671	OLGA KOLESNIKOVA	{"phone": "+70362570582"}
0005433985649	1BB640	6837 209686	RAISA POPOVA	{"phone": "+70205154060"}
0005433985537	22AF8A	8929 120491	RAISA VLASOVA	{"email": "vlasova.raisa_031969@postgrespro.ru", "phone": "+70999711315"}
0005433985538	22AF8A	0887 313737	ELENA NIKITINA	{"email": "nikitinae-15101968@postgrespro.ru", "phone": "+70975755085"}
0005433985539	DF07F5	1593 307443	NATALYA MARTYNOVA	{"email": "n_martynova01071972@postgrespro.ru", "phone": "+70417995424"}
0005433985540	DF07F5	6852 105713	YULIYA ZOTOVA	{"phone": "+70013513540"}
0005433985541	3BEBE3	8998 339859	NATALYA PETROVA	{"phone": "+70212222074"}
0005433985542	3BEBE3	1249 252027	VALENTINA DAVYDOVA	{"email": "valentina_davydova-31031975@postgrespro.ru", "phone": "+70656388040"}
0005433985543	C254FD	0458 976874	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov_31071971@postgrespro.ru", "phone": "+70062794951"}
0005433985544	D4EFC4	4926 817176	IRINA PAVLOVA	{"phone": "+70693074010"}
0005433985545	575497	7364 457624	TATYANA SOKOLOVA	{"phone": "+70742256716"}
0005433985546	ABDFF1	5873 341861	ALEKSANDR MAKSIMOV	{"email": "a.maksimov-1965@postgrespro.ru", "phone": "+70377734921"}
0005433985547	5127BB	0341 822079	ELENA EFIMOVA	{"email": "efimova_elena1977@postgrespro.ru", "phone": "+70210280493"}
0005433985548	5A9A66	5748 455132	DENIS EGOROV	{"email": "egorov-d05101963@postgrespro.ru", "phone": "+70866352035"}
0005433985549	2B4319	8820 964541	OLGA MASLOVA	{"phone": "+70188674668"}
0005433985550	C7C728	2149 214391	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.02021970@postgrespro.ru", "phone": "+70415529420"}
0005433985551	C7C728	9770 118971	VLADIMIR VLASOV	{"phone": "+70954914756"}
0005433985552	DCBC27	4702 868804	ELENA ISAEVA	{"phone": "+70313595427"}
0005433985553	87F35B	2854 191320	NIKOLAY SOKOLOV	{"email": "sokolov_n-21071964@postgrespro.ru", "phone": "+70314922110"}
0005433985554	7306BA	7470 351587	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov-1969@postgrespro.ru", "phone": "+70089683114"}
0005433985555	11C24A	8497 702544	ALEKSANDR BORISOV	{"phone": "+70382201040"}
0005433985556	11C24A	2583 813360	MARIYA DAVYDOVA	{"email": "davydova_m_09071969@postgrespro.ru", "phone": "+70983570583"}
0005433985557	7469E8	0442 116832	OLGA ZOTOVA	{"email": "olga.zotova.16081967@postgrespro.ru", "phone": "+70457505028"}
0005433985558	7469E8	3671 809986	ANASTASIYA KOMAROVA	{"phone": "+70553962954"}
0005433985559	21AE3B	2224 552399	ANDREY NOVIKOV	{"phone": "+70432042623"}
0005433985560	4D2FF1	0942 784111	VALERIY ZHURAVLEV	{"email": "vzhuravlev_26121962@postgrespro.ru", "phone": "+70946407348"}
0005433985561	417CD3	2247 544568	DMITRIY KOZLOV	{"email": "kozlov-d.20111967@postgrespro.ru", "phone": "+70341510476"}
0005433985562	1654D0	1420 155649	VALENTINA EFREMOVA	{"email": "efremova-valentina1965@postgrespro.ru", "phone": "+70158611366"}
0005433985563	1654D0	4108 405195	SVETLANA ALEKSANDROVA	{"phone": "+70180309787"}
0005433985564	1654D0	8856 977711	EKATERINA IVANOVA	{"phone": "+70605716556"}
0005433985565	A4AC6E	8556 583194	ANZHELA VLASOVA	{"email": "vlasova.a-1970@postgrespro.ru", "phone": "+70583809658"}
0005433985566	1E134F	3916 008247	NATALYA MOISEEVA	{"email": "natalya_moiseeva041967@postgrespro.ru", "phone": "+70825926475"}
0005433985567	1E134F	5612 869415	DANIIL MATVEEV	{"phone": "+70016854036"}
0005433985568	C9FB65	3825 737351	FARID ROMANOV	{"email": "romanov-f_15021967@postgrespro.ru", "phone": "+70522620361"}
0005433985569	5A0524	6227 911186	VALENTINA ARKHIPOVA	{"phone": "+70044492218"}
0005433985570	537331	2633 788838	SERGEY ANDREEV	{"phone": "+70524126343"}
0005433985571	537331	3588 981736	SERGEY FEDOROV	{"phone": "+70675397225"}
0005433985572	111CF1	9626 130674	VYACHESLAV SCHERBAKOV	{"email": "scherbakov.v031972@postgrespro.ru", "phone": "+70419244243"}
0005433985573	165F08	1032 804513	DMITRIY IVANOV	{"phone": "+70834027862"}
0005433985574	7E268F	4752 933935	GRIGORIY MELNIKOV	{"email": "grigoriy-melnikov.011987@postgrespro.ru", "phone": "+70973227417"}
0005433985575	7E268F	1456 252296	LYUDMILA BOGDANOVA	{"phone": "+70293969153"}
0005433985576	59E39A	0287 840996	NIKOLAY KUZNECOV	{"phone": "+70374333961"}
0005433985577	F44639	3322 161889	TATYANA ZAKHAROVA	{"phone": "+70685246637"}
0005433985578	BB2B7C	8283 645580	TATYANA CHERNOVA	{"phone": "+70611141944"}
0005433985579	BB2B7C	1740 430513	NATALYA MOROZOVA	{"email": "morozovan.041969@postgrespro.ru", "phone": "+70401826536"}
0005433985580	525C19	0451 161460	ANNA ANDREEVA	{"email": "anna-andreeva_021962@postgrespro.ru", "phone": "+70943107060"}
0005433985581	21616A	3547 415642	GRIGORIY ISAEV	{"email": "isaevg-29081976@postgrespro.ru", "phone": "+70244842910"}
0005433985582	21616A	7268 315348	VLADIMIR ANTONOV	{"phone": "+70276792254"}
0005433985583	3F82B9	1087 923095	GULNARA ERMAKOVA	{"phone": "+70755426263"}
0005433985584	30E46C	3746 101981	EKATERINA SERGEEVA	{"email": "esergeeva.091977@postgrespro.ru", "phone": "+70192046604"}
0005433985585	84018C	8241 518544	ELENA GORBUNOVA	{"phone": "+70135346116"}
0005433985586	504F96	4704 103006	TATYANA LAZAREVA	{"phone": "+70905523634"}
0005433985587	504F96	4689 889421	ELENA VOLKOVA	{"phone": "+70003204922"}
0005433985588	D38E2A	7365 423148	LIDIYA DANILOVA	{"phone": "+70841365085"}
0005433985589	77E166	7959 844410	EKATERINA STEPANOVA	{"phone": "+70545588950"}
0005433985590	714948	1408 464506	GEORGIY GAVRILOV	{"email": "georgiy_gavrilov29041969@postgrespro.ru", "phone": "+70065435698"}
0005433985591	19D8ED	3855 034008	OLGA MARTYNOVA	{"email": "o-martynova_31101970@postgrespro.ru", "phone": "+70588133011"}
0005433985592	F764D6	7661 061427	MIKHAIL AFANASEV	{"email": "mikhailafanasev01041966@postgrespro.ru", "phone": "+70925110748"}
0005433985593	265DF8	0457 813119	BORIS NAUMOV	{"email": "naumov-boris_041976@postgrespro.ru", "phone": "+70504851723"}
0005433985594	908815	7057 307879	VLADIMIR STEPANOV	{"email": "vladimir_stepanov081968@postgrespro.ru", "phone": "+70335270760"}
0005433985595	908815	4882 762866	SERGEY SMIRNOV	{"phone": "+70229167831"}
0005433985596	0D2EFE	4526 967305	EVGENIY KUZMIN	{"phone": "+70323720407"}
0005433985597	96D3BC	3680 029361	YULIYA TARASOVA	{"email": "tarasova.yuliya03121976@postgrespro.ru", "phone": "+70850302000"}
0005433985598	70B655	6227 287808	ELENA GERASIMOVA	{"email": "gerasimova.elena_1967@postgrespro.ru", "phone": "+70915989242"}
0005433985599	5FDF5C	3518 953658	ZOYA AFANASEVA	{"phone": "+70589600236"}
0005433985600	5FDF5C	7722 348795	ELENA VASILEVA	{"email": "elena_vasileva-071964@postgrespro.ru", "phone": "+70042515657"}
0005433985601	2F723B	2938 075945	MIKHAIL FOMIN	{"phone": "+70755284913"}
0005433985602	2F723B	6587 608967	OKSANA DENISOVA	{"email": "denisova.oksana.1980@postgrespro.ru", "phone": "+70269371745"}
0005433985603	746F04	5439 364522	ALEKSEY BARANOV	{"phone": "+70531451217"}
0005433985604	746F04	6225 307173	SANIYA LAZAREVA	{"email": "s.lazareva-051972@postgrespro.ru", "phone": "+70232810686"}
0005433985605	077892	3160 819719	MAKSIM STEPANOV	{"phone": "+70846033781"}
0005433985606	7CDC47	8429 168375	TATYANA FROLOVA	{"email": "tatyanafrolova_26011978@postgrespro.ru", "phone": "+70046833521"}
0005433985607	EC2000	1352 226883	ZARINA ORLOVA	{"phone": "+70626610351"}
0005433985608	EC2000	8815 185909	OLEG SOLOVEV	{"email": "o-solovev.01031973@postgrespro.ru", "phone": "+70010166319"}
0005433985610	B1A93A	7488 827868	SVETLANA KRASNOVA	{"email": "krasnova.s.091969@postgrespro.ru", "phone": "+70851031556"}
0005433985611	B1A93A	5778 524800	ALEKSANDR ISAEV	{"email": "aisaev23111962@postgrespro.ru", "phone": "+70931335800"}
0005433985612	FED95F	2952 581901	OKSANA MARTYNOVA	{"phone": "+70830979400"}
0005433985613	FED95F	6265 427512	ROMAN SOLOVEV	{"phone": "+70803649831"}
0005433985614	54EC75	4611 563891	YULIYA MAKAROVA	{"email": "makarova_y-1981@postgrespro.ru", "phone": "+70740197305"}
0005433985615	DDD347	5635 522498	ALEKSEY SAVELEV	{"phone": "+70754402802"}
0005433985616	0921A0	1136 651429	VITALIY NIKOLAEV	{"phone": "+70250228386"}
0005433985617	0921A0	6204 169107	ANTON VASILEV	{"email": "vasilev_anton061976@postgrespro.ru", "phone": "+70443850362"}
0005433985618	AA02F6	8208 345926	LYUDMILA SOROKINA	{"email": "sorokina-lyudmila021974@postgrespro.ru", "phone": "+70595622817"}
0005433985619	619D78	2025 381382	SERGEY PAVLOV	{"email": "sergey-pavlov.1984@postgrespro.ru", "phone": "+70762623936"}
0005433985620	044E40	3796 405714	GALINA KALININA	{"email": "galina_kalinina.061968@postgrespro.ru", "phone": "+70584449039"}
0005433985621	91FC74	3605 250383	ALEKSANDR IVANOV	{"phone": "+70812011229"}
0005433985622	B9E7AA	6713 322467	ANTON MOISEEV	{"email": "moiseev_anton.1973@postgrespro.ru", "phone": "+70281919454"}
0005433985623	647E92	1120 037055	VLADIMIR ZHUKOV	{"phone": "+70053526728"}
0005433985624	4C8673	3880 946834	ANNA KISELEVA	{"phone": "+70092249042"}
0005433985625	6B1FA4	2601 550169	DANIIL NOVIKOV	{"email": "novikov-d_031975@postgrespro.ru", "phone": "+70362230856"}
0005433985626	6B1FA4	1337 353039	VLADIMIR ANDREEV	{"email": "v-andreev.14121987@postgrespro.ru", "phone": "+70930989147"}
0005433985627	6B1FA4	6592 452084	SERGEY DENISOV	{"phone": "+70191732033"}
0005433985628	978B33	5938 500475	OLGA MAKAROVA	{"phone": "+70745214251"}
0005433985629	978B33	2360 859113	NINA KOZLOVA	{"phone": "+70029697505"}
0005433985630	067718	0710 288725	ALEKSANDRA PETROVA	{"phone": "+70624601367"}
0005433985631	0D8E64	3699 252308	ELVIRA VASILEVA	{"email": "elviravasileva_20011985@postgrespro.ru", "phone": "+70946544289"}
0005433985632	1F6C6F	1043 184883	GALINA OSIPOVA	{"phone": "+70725233043"}
0005433985633	7F9ECC	3234 386834	TATYANA ALEKSANDROVA	{"email": "aleksandrova-tatyana.081981@postgrespro.ru", "phone": "+70513927655"}
0005433985634	7F9ECC	0903 585006	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr-1964@postgrespro.ru", "phone": "+70114231035"}
0005433985635	7F9ECC	5011 782132	SVETLANA POTAPOVA	{"email": "svetlanapotapova_121970@postgrespro.ru", "phone": "+70440162199"}
0005433985636	742D38	8904 498054	ARSEN KRASNOV	{"email": "krasnov-a_07101982@postgrespro.ru", "phone": "+70351033784"}
0005433985637	3E586E	9400 963714	DMITRIY KOROLEV	{"email": "d-korolev.1965@postgrespro.ru", "phone": "+70961373260"}
0005433985638	3E586E	5978 678323	YANA MIRONOVA	{"phone": "+70784491680"}
0005433985639	B163EE	6340 992004	ARTEM POPOV	{"email": "apopov091968@postgrespro.ru", "phone": "+70037618858"}
0005433985640	B163EE	4592 615042	KONSTANTIN IVANOV	{"phone": "+70133138263"}
0005433985641	00C367	3393 587191	EVGENIY ALEKSANDROV	{"email": "aleksandrov_e-19071968@postgrespro.ru", "phone": "+70808664540"}
0005433985642	D236A1	4621 350208	VLADIMIR ANTONOV	{"email": "antonov.v_1978@postgrespro.ru", "phone": "+70507324435"}
0005433985643	1AA57D	2709 921381	YURIY OSIPOV	{"phone": "+70582721621"}
0005433985644	66AB8F	7603 682437	OKSANA OVCHINNIKOVA	{"phone": "+70105119774"}
0005433985645	66AB8F	0201 108876	GALINA BELOVA	{"email": "belova.galina-1975@postgrespro.ru", "phone": "+70920801693"}
0005433985646	3AA6FE	1305 377953	VERA MAKAROVA	{"phone": "+70307895772"}
0005433985647	3AA6FE	9565 299574	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov.18091969@postgrespro.ru", "phone": "+70760025685"}
0005433985648	CFAE9C	6828 453885	MARIYA KONOVALOVA	{"phone": "+70664776847"}
0005433985650	1BB640	9069 373127	VYACHESLAV ISAEV	{"email": "isaev.vyacheslav-1975@postgrespro.ru", "phone": "+70527407982"}
0005433985651	CB061B	6464 387628	RUSLAN MAKSIMOV	{"email": "ruslanmaksimov-23081958@postgrespro.ru", "phone": "+70131778476"}
0005433985652	CB061B	2787 009291	SERGEY ALEKSEEV	{"phone": "+70103977655"}
0005433985653	B15381	6822 158903	TAMARA MELNIKOVA	{"phone": "+70858085951"}
0005433985654	5D0910	4935 859793	ELENA KOVALEVA	{"email": "kovaleva_e19051981@postgrespro.ru", "phone": "+70627322439"}
0005433985655	5D0910	0442 448470	DMITRIY SEMENOV	{"phone": "+70886252062"}
0005433985656	94A952	2276 821652	VLADIMIR IVANOV	{"phone": "+70441313665"}
0005433985657	F14D34	7040 232887	SERGEY KRASNOV	{"phone": "+70462170021"}
0005433985658	F14D34	2515 325007	KIRILL FROLOV	{"phone": "+70280164254"}
0005433985659	B69922	1075 813958	VALERIY IVANOV	{"phone": "+70588272091"}
0005433985660	CFEFA7	2383 105801	TATYANA KONDRATEVA	{"email": "t_kondrateva-011976@postgrespro.ru", "phone": "+70404191345"}
0005433985661	AFD594	5197 696270	EVGENIY TIKHONOV	{"phone": "+70102798194"}
0005433985662	B9F6B3	2674 230109	MARIYA AKIMOVA	{"email": "akimova_m1978@postgrespro.ru", "phone": "+70137701805"}
0005433985663	B9F6B3	4998 479159	NINA DAVYDOVA	{"email": "davydova-nina.071968@postgrespro.ru", "phone": "+70847580422"}
0005433985664	89257B	2310 922612	ALEKSEY BELOV	{"phone": "+70658611146"}
0005433985665	E0591E	3718 968349	MIKHAIL POPOV	{"email": "mikhail-popov_1972@postgrespro.ru", "phone": "+70486846919"}
0005433985666	E0591E	9809 989691	SERGEY KONOVALOV	{"phone": "+70524218868"}
0005433985667	CB81A3	5651 403389	RUSLAN SAVELEV	{"email": "ruslan.savelev091964@postgrespro.ru", "phone": "+70438017514"}
0005433985668	CB81A3	3764 371415	VLADIMIR DMITRIEV	{"email": "dmitrievvladimir-1967@postgrespro.ru", "phone": "+70382091465"}
0005433985669	382B40	7269 817616	NADEZHDA POPOVA	{"email": "nadezhda_popova-1971@postgrespro.ru", "phone": "+70258817351"}
0005433985670	C481DF	3141 552697	ILYA RODIONOV	{"email": "irodionov-101975@postgrespro.ru", "phone": "+70175728409"}
0005433985671	D8FA05	7118 383081	VALERIY ZAKHAROV	{"phone": "+70656204347"}
0005433985672	937ECA	6829 256239	ANDREY SOKOLOV	{"email": "sokolov.andrey1973@postgrespro.ru", "phone": "+70153711380"}
0005433985673	42F97B	4131 270584	NATALYA YUDINA	{"email": "yudina-natalya.14121973@postgrespro.ru", "phone": "+70445252418"}
0005433985674	0D6B2B	2452 931260	GALINA IVANOVA	{"phone": "+70383077745"}
0005433985675	0D6B2B	6968 545313	ALEKSANDR POPOV	{"email": "popovaleksandr_14031971@postgrespro.ru", "phone": "+70500435532"}
0005433985676	3EC5C8	8100 898680	SVETLANA IVANOVA	{"phone": "+70888493241"}
0005433985677	F46CF3	2451 109132	GLEB KISELEV	{"email": "g.kiselev-25101972@postgrespro.ru", "phone": "+70348598345"}
0005433985678	A98D09	4381 568643	KLAVDIYA OSIPOVA	{"email": "klavdiya-osipova061982@postgrespro.ru", "phone": "+70108655630"}
0005433985679	A98D09	9234 094799	ALEKSEY SCHERBAKOV	{"phone": "+70840327803"}
0005433985680	A98D09	1538 018759	NIKOLAY BARANOV	{"phone": "+70900334211"}
0005433985681	A6ADED	1470 040683	SOFIYA ROMANOVA	{"email": "romanova_sofiya13101984@postgrespro.ru", "phone": "+70604725479"}
0005433985682	220DAD	3231 559224	ALEKSEY ALEKSANDROV	{"phone": "+70804693367"}
0005433985683	220DAD	6075 351756	LYUDMILA DAVYDOVA	{"email": "davydova.lyudmila-01111964@postgrespro.ru", "phone": "+70321881017"}
0005433985684	09327F	0690 247439	VADIM BARANOV	{"phone": "+70589042993"}
0005433985685	09327F	0796 364422	NINA ALEKSEEVA	{"email": "nina.alekseeva051960@postgrespro.ru", "phone": "+70208830081"}
0005433985686	DC9360	8650 951433	MARIYA POPOVA	{"phone": "+70000240081"}
0005433985687	F3475A	6397 450380	NIKOLAY ISAEV	{"email": "isaev.n1976@postgrespro.ru", "phone": "+70837336278"}
0005433985688	F3475A	0988 653069	KIRA MIRONOVA	{"phone": "+70730308870"}
0005433985689	E547C7	9919 650927	ANNA ABRAMOVA	{"phone": "+70482987186"}
0005433985690	CE633B	7833 208311	NIKOLAY PAVLOV	{"email": "pavlov.n.28041975@postgrespro.ru", "phone": "+70119614875"}
0005433985691	095D4D	3757 845610	ILDAR RODIONOV	{"phone": "+70370306719"}
0005433985692	095D4D	2711 567083	ALEKSEY IVANOV	{"email": "ivanov-a-28071972@postgrespro.ru", "phone": "+70984248542"}
0005433985693	095D4D	0329 214135	LYUDMILA IVANOVA	{"email": "ivanova-l1978@postgrespro.ru", "phone": "+70114319786"}
0005433985694	F8E72E	3223 692063	ANASTASIYA SOLOVEVA	{"email": "solovevaanastasiya_051973@postgrespro.ru", "phone": "+70015075218"}
0005433985695	F8E72E	9098 759267	VIKTOR KUZMIN	{"email": "kuzmin-v_1987@postgrespro.ru", "phone": "+70945517402"}
0005433985696	DA04FE	7223 929067	ALINA LEBEDEVA	{"phone": "+70601421048"}
0005433985697	17C084	1484 877845	OLGA MELNIKOVA	{"email": "olga-melnikova.021980@postgrespro.ru", "phone": "+70363614327"}
0005433985698	C90E5B	0963 058900	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova-1967@postgrespro.ru", "phone": "+70847724197"}
0005433985699	C90E5B	7285 131062	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev21091973@postgrespro.ru", "phone": "+70251421865"}
0005433985700	AAFDE6	3169 946515	GLEB ALEKSEEV	{"phone": "+70858888222"}
0005433985701	AAFDE6	7465 677010	SHAVKAT KONOVALOV	{"email": "konovalov.shavkat_031962@postgrespro.ru", "phone": "+70784318693"}
0005433985702	A8E8CD	1612 118170	VYACHESLAV MARTYNOV	{"email": "martynovvyacheslav.1965@postgrespro.ru", "phone": "+70232884828"}
0005433985703	9FA9E0	1551 103887	ELENA FROLOVA	{"email": "frolova.elena-1959@postgrespro.ru", "phone": "+70356863005"}
0005433985704	9FA9E0	2855 088929	ALEKSANDR IVANOV	{"email": "aivanov.1961@postgrespro.ru", "phone": "+70922042760"}
0005433985705	DBD5E1	5954 414947	VYACHESLAV POPOV	{"phone": "+70256628652"}
0005433985706	B62B98	5718 843929	EKATERINA SOKOLOVA	{"phone": "+70844023748"}
0005433985707	9623A6	5890 031365	YANA SMIRNOVA	{"email": "ysmirnova_27031982@postgrespro.ru", "phone": "+70213894388"}
0005433985708	9623A6	3129 382589	MARINA ARKHIPOVA	{"phone": "+70237982196"}
0005433985709	33FF06	2028 444512	YURIY KARPOV	{"email": "y_karpov-03111970@postgrespro.ru", "phone": "+70022609577"}
0005433985710	7AFF8D	7527 328071	OKSANA MIKHAYLOVA	{"email": "oksanamikhaylova.30091969@postgrespro.ru", "phone": "+70088083908"}
0005433985711	7AFF8D	7873 454701	ELENA NAZAROVA	{"phone": "+70259511696"}
0005433985712	F92B30	0857 001106	ELENA KUZNECOVA	{"phone": "+70742400915"}
0005433985713	F92B30	9809 368926	EKATERINA KAZAKOVA	{"email": "ekaterina_kazakova011971@postgrespro.ru", "phone": "+70433027390"}
0005433985714	F92B30	2209 925390	NATALYA NIKOLAEVA	{"email": "nikolaeva_natalya_1974@postgrespro.ru", "phone": "+70879336660"}
0005433985715	349304	7766 152003	SERGEY MELNIKOV	{"phone": "+70172799654"}
0005433985716	35C318	5509 248274	IRINA MARTYNOVA	{"phone": "+70776805705"}
0005433985717	A706E0	7140 300268	MARIYA YUDINA	{"phone": "+70237539079"}
0005433985896	EEA328	6386 477310	ANASTASIYA RODIONOVA	{"phone": "+70880654923"}
0005433985718	A706E0	4522 545662	TATYANA RODIONOVA	{"email": "t-rodionova_1980@postgrespro.ru", "phone": "+70466316950"}
0005433985719	11E2F7	7792 213183	ARTEM SCHERBAKOV	{"phone": "+70919941825"}
0005433985720	169929	1582 624833	VLADIMIR MOROZOV	{"phone": "+70073854092"}
0005433985721	96E103	3016 837524	DANIIL STEPANOV	{"email": "stepanov_d.26091966@postgrespro.ru", "phone": "+70813871090"}
0005433985722	C0F951	9930 764916	VASILIY ZAYCEV	{"email": "vasiliy-zaycev-28041978@postgrespro.ru", "phone": "+70140345229"}
0005433985723	D46357	9134 693759	VLADIMIR NAUMOV	{"email": "naumov.vladimir101978@postgrespro.ru", "phone": "+70713218666"}
0005433985724	EE8CEE	1991 149318	ELENA KOROLEVA	{"email": "korolevaelena101969@postgrespro.ru", "phone": "+70976180966"}
0005433985725	EE8CEE	0782 040916	ANNA SMIRNOVA	{"phone": "+70122327437"}
0005433985726	B254DC	1761 022408	TATYANA SCHERBAKOVA	{"phone": "+70661561494"}
0005433985727	B254DC	3877 812773	ALEKSANDRA MAKAROVA	{"email": "aleksandra.makarova_1980@postgrespro.ru", "phone": "+70868941774"}
0005433985728	2AAC2E	4662 811523	NINA KUDRYASHOVA	{"phone": "+70732699455"}
0005433985729	2A835C	7228 807770	ELENA ANTONOVA	{"email": "elena-antonova_11081974@postgrespro.ru", "phone": "+70526936105"}
0005433985730	2A835C	6840 574361	ELENA DAVYDOVA	{"phone": "+70474535300"}
0005433985731	370BE8	9081 100355	ANASTASIYA EFREMOVA	{"email": "a-efremova1960@postgrespro.ru", "phone": "+70598110881"}
0005433985732	370BE8	9793 285676	LIDIYA RYABOVA	{"email": "ryabovalidiya.02071962@postgrespro.ru", "phone": "+70807312405"}
0005433985733	3EB261	7455 991359	VIKTORIYA KUZNECOVA	{"phone": "+70088100167"}
0005433985734	274DF4	3630 633997	ELIZAVETA RYABOVA	{"email": "elizaveta.ryabova_29061970@postgrespro.ru", "phone": "+70586052565"}
0005433985735	57D15A	3854 839325	NINA NESTEROVA	{"email": "nesterova_nina.091974@postgrespro.ru", "phone": "+70905247327"}
0005433985736	57D15A	6139 310993	MAKSIM NAUMOV	{"phone": "+70949310796"}
0005433985737	7ADFA0	7910 611343	SVETLANA BORISOVA	{"phone": "+70223723462"}
0005433985738	F3A631	6523 608497	TATYANA DENISOVA	{"email": "t-denisova.1982@postgrespro.ru", "phone": "+70945546017"}
0005433985739	9D0455	8451 876771	ANDREY VLASOV	{"phone": "+70167721147"}
0005433985740	2133F8	3427 531071	VADIM TARASOV	{"phone": "+70984798609"}
0005433985741	2133F8	1756 987309	GALINA NIKITINA	{"email": "galinanikitina.041978@postgrespro.ru", "phone": "+70537418805"}
0005433985742	A811E1	5268 099178	KIRILL SOKOLOV	{"phone": "+70467411166"}
0005433985743	342C58	7985 473431	VLADIMIR MEDVEDEV	{"email": "medvedevvladimir.1958@postgrespro.ru", "phone": "+70797943145"}
0005433985744	342C58	9445 118964	TATYANA NIKOLAEVA	{"email": "nikolaeva_t-051964@postgrespro.ru", "phone": "+70637861451"}
0005433985745	342C58	4562 769818	DANIL BORISOV	{"phone": "+70978477705"}
0005433985746	021354	2964 272367	BORIS FEDOROV	{"email": "boris.fedorov061966@postgrespro.ru", "phone": "+70901675936"}
0005433985747	55616F	3039 787405	KIRA ZAKHAROVA	{"phone": "+70018769725"}
0005433985748	DDA707	2547 454468	GULFIYA SAVELEVA	{"email": "g.saveleva.17051966@postgrespro.ru", "phone": "+70511234156"}
0005433985749	D29EA9	2410 079109	YULIYA DANILOVA	{"phone": "+70202370175"}
0005433985750	E15DF3	5234 174977	VADIM NAZAROV	{"email": "nazarovvadim-1964@postgrespro.ru", "phone": "+70818450846"}
0005433985751	E12C4B	9958 437684	IRINA SMIRNOVA	{"email": "smirnova.irina1971@postgrespro.ru", "phone": "+70359040816"}
0005433985752	BF6462	8398 686025	YAROSLAV VASILEV	{"phone": "+70557553805"}
0005433985753	BF6462	0187 733143	IRINA KOROLEVA	{"email": "irina-koroleva03041981@postgrespro.ru", "phone": "+70978274196"}
0005433985754	C566EA	7412 158749	ELENA NESTEROVA	{"phone": "+70407550256"}
0005433985755	6E09EE	4144 020342	VIKTOR NIKOLAEV	{"phone": "+70669668320"}
0005433985756	41CAFA	3902 772122	ANATOLIY SCHERBAKOV	{"email": "scherbakov-a.30061966@postgrespro.ru", "phone": "+70321605052"}
0005433985757	9D3EAC	8835 596856	VLADIMIR MELNIKOV	{"email": "melnikov_v031974@postgrespro.ru", "phone": "+70577281689"}
0005433985758	F502F6	8846 807189	ALEKSANDR IVANOV	{"email": "ivanov.a_16061963@postgrespro.ru", "phone": "+70699835300"}
0005433985759	45B441	0591 176168	ROMAN BELOV	{"email": "roman-belov-19061965@postgrespro.ru", "phone": "+70500660282"}
0005433985871	E5D3BB	4942 309115	LYUDMILA NIKOLAEVA	{"phone": "+70587009876"}
0005433985760	0A1889	7273 136377	LYUBOV POPOVA	{"email": "lyubovpopova.1977@postgrespro.ru", "phone": "+70182294306"}
0005433985761	181DF5	2404 280986	ELENA KUZNECOVA	{"email": "kuznecovae.1957@postgrespro.ru", "phone": "+70931746496"}
0005433985762	181DF5	3531 973519	TAISIYA CHERNOVA	{"phone": "+70001212807"}
0005433985763	593252	2139 349935	VLADIMIR FILIPPOV	{"email": "v.filippov1976@postgrespro.ru", "phone": "+70399781070"}
0005433985764	593252	2298 020078	NIKOLAY SHEVCHENKO	{"email": "nikolay-shevchenko-08081980@postgrespro.ru", "phone": "+70447136772"}
0005433985765	78C1CB	7853 083260	VALERIY PAVLOV	{"phone": "+70867753169"}
0005433985766	8A996F	3545 426146	SERGEY KONOVALOV	{"email": "skonovalov1956@postgrespro.ru", "phone": "+70757012807"}
0005433985767	412C18	3118 194268	EKATERINA ORLOVA	{"phone": "+70658985995"}
0005433985768	665801	6187 893979	ELENA NAUMOVA	{"email": "naumova.elena_1971@postgrespro.ru", "phone": "+70175992704"}
0005433985769	665801	5286 103086	NIKOLAY NAZAROV	{"phone": "+70834459313"}
0005433985770	B2C977	1603 164980	VALENTIN KONOVALOV	{"email": "valentin_konovalov1966@postgrespro.ru", "phone": "+70011650191"}
0005433985771	C663CF	6327 063129	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_11121972@postgrespro.ru", "phone": "+70619020246"}
0005433985772	117B6F	1255 969678	ANDREY IVANOV	{"email": "ivanova.011983@postgrespro.ru", "phone": "+70805753778"}
0005433985773	E8B7CA	4490 023963	ALEVTINA DENISOVA	{"phone": "+70396805059"}
0005433985774	4329F1	9654 305436	NELLI POLYAKOVA	{"phone": "+70756339709"}
0005433985775	AB4ED5	2265 787154	EKATERINA YAKOVLEVA	{"phone": "+70810310238"}
0005433985776	441D8A	6054 705791	LYUBOV ZAYCEVA	{"email": "lyubovzayceva_23051975@postgrespro.ru", "phone": "+70968128370"}
0005433985777	D05616	1115 162456	VLADIMIR MAKSIMOV	{"phone": "+70132883924"}
0005433985778	D05616	6192 508149	SOFYA SERGEEVA	{"phone": "+70696705004"}
0005433985779	F6254D	2087 599732	VALERIY ALEKSEEV	{"phone": "+70801594485"}
0005433985780	F6254D	3727 880800	SVETLANA FADEEVA	{"phone": "+70768224566"}
0005433985781	3DAFF9	4226 814942	RAIS POPOV	{"email": "popov_rais.101978@postgrespro.ru", "phone": "+70536366708"}
0005433985782	3F64AE	9862 263194	EVGENIY KISELEV	{"email": "evgeniy_kiselev_041969@postgrespro.ru", "phone": "+70446085466"}
0005433985783	ABC8B4	3573 667948	ALEKSANDRA GORBUNOVA	{"phone": "+70862242582"}
0005433985784	E93041	0083 002016	ANNA DAVYDOVA	{"email": "adavydova.22101981@postgrespro.ru", "phone": "+70782645523"}
0005433985785	12FC0F	5575 070821	SERGEY NOVIKOV	{"phone": "+70014509317"}
0005433985786	087F13	3145 951043	ELENA NAZAROVA	{"email": "elena_nazarova_22011965@postgrespro.ru", "phone": "+70683679961"}
0005433985787	087F13	6788 117388	RINAT BORISOV	{"email": "r.borisov1967@postgrespro.ru", "phone": "+70666135612"}
0005433985788	97B181	9591 918623	DANIIL KRASNOV	{"email": "daniil_krasnov_01071982@postgrespro.ru", "phone": "+70924190552"}
0005433985789	15C41E	0401 507010	LARISA MOISEEVA	{"phone": "+70359745921"}
0005433985790	15C41E	0178 690952	YAROSLAV BORISOV	{"email": "borisov_yaroslav.051973@postgrespro.ru", "phone": "+70148553401"}
0005433985791	FE68E7	3811 795856	TATYANA VLASOVA	{"phone": "+70615307818"}
0005433985792	FE68E7	6568 355370	DMITRIY BORISOV	{"email": "borisov.dmitriy-041972@postgrespro.ru", "phone": "+70394393835"}
0005433985793	F725A9	8051 384499	ALEKSEY KUZNECOV	{"email": "alekseykuznecov.1972@postgrespro.ru", "phone": "+70337976206"}
0005433985794	DB4308	1361 256153	VLADIMIR KUZMIN	{"email": "vladimirkuzmin.1976@postgrespro.ru", "phone": "+70591933854"}
0005433985795	DB4308	8192 327417	RAVIL FEDOTOV	{"email": "fedotovr_09031981@postgrespro.ru", "phone": "+70523786029"}
0005433985796	644BB9	9761 796498	VIKTOR KOZLOV	{"phone": "+70660977229"}
0005433985797	7367D7	7689 433597	ANDREY NAZAROV	{"email": "a-nazarov1975@postgrespro.ru", "phone": "+70858055583"}
0005433985798	77C342	1098 566334	VLADIMIR ZHURAVLEV	{"phone": "+70603028816"}
0005433985799	8D10FC	4625 185771	SERGEY FEDOTOV	{"email": "fedotovsergey.021985@postgrespro.ru", "phone": "+70253937104"}
0005433985800	336811	0189 875143	PAVEL ANTONOV	{"email": "antonov_p-061976@postgrespro.ru", "phone": "+70574136756"}
0005433985801	8DB3E3	2044 052443	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov1970@postgrespro.ru", "phone": "+70016434952"}
0005433985802	30A676	1234 098501	ALEKSEY MOROZOV	{"email": "aleksey-morozov-15081965@postgrespro.ru", "phone": "+70072639813"}
0005433985803	30A676	6705 833233	ANTONINA ERMAKOVA	{"email": "ermakova.antonina15031970@postgrespro.ru", "phone": "+70622334703"}
0005433985804	B52E49	9359 315400	NADEZHDA STEPANOVA	{"email": "n.stepanova1972@postgrespro.ru", "phone": "+70195052793"}
0005433985805	6819DA	7344 071528	OLESYA ANTONOVA	{"phone": "+70407431664"}
0005433985806	C540DC	2492 831556	OLGA ZHUKOVA	{"email": "olgazhukova-111968@postgrespro.ru", "phone": "+70345931109"}
0005433985807	0BB771	3132 605390	IGOR SAVELEV	{"email": "savelevigor.061968@postgrespro.ru", "phone": "+70107010563"}
0005433985808	A1EE2E	7688 127066	NATALYA ZAKHAROVA	{"phone": "+70108028188"}
0005433985809	0A6C0F	0942 069190	LYUDMILA ANDREEVA	{"phone": "+70873809415"}
0005433985810	0A6C0F	0716 790792	ELENA MAKSIMOVA	{"email": "maksimova_e-081966@postgrespro.ru", "phone": "+70430710358"}
0005433985811	0A6C0F	2205 180651	TATYANA SAVELEVA	{"email": "tsaveleva_061977@postgrespro.ru", "phone": "+70797301537"}
0005433985812	DEB61C	1770 959769	MARIYA NESTEROVA	{"email": "m-nesterova-25071973@postgrespro.ru", "phone": "+70979887632"}
0005433985813	C7105D	0032 760045	SVETLANA ISAEVA	{"phone": "+70534912174"}
0005433985814	4A1CD1	8330 281932	NADEZHDA FROLOVA	{"phone": "+70099647258"}
0005433985815	AAB164	9452 363888	ILYA AFANASEV	{"email": "afanasev_ilya.06101969@postgrespro.ru", "phone": "+70526361426"}
0005433985816	D4F334	7776 006310	LEV ANDREEV	{"phone": "+70668636084"}
0005433985817	D4F334	6429 370573	MARINA VOROBEVA	{"email": "m-vorobeva_1972@postgrespro.ru", "phone": "+70823485456"}
0005433985818	91148D	4430 579720	YULIYA OSIPOVA	{"phone": "+70584190922"}
0005433985819	7FCBDE	3553 905549	TATYANA SCHERBAKOVA	{"email": "tatyana.scherbakova_1977@postgrespro.ru", "phone": "+70624480629"}
0005433985820	CAF2A9	0987 346743	OLGA RYABOVA	{"email": "olga_ryabova_1978@postgrespro.ru", "phone": "+70264751093"}
0005433985821	428411	5843 367639	TIMUR VLASOV	{"phone": "+70016839632"}
0005433985822	CE3E3A	7308 433830	EKATERINA MIRONOVA	{"email": "mironova-ekaterina1984@postgrespro.ru", "phone": "+70421651954"}
0005433985823	6598FD	4206 796825	EKATERINA KISELEVA	{"phone": "+70662468048"}
0005433985824	2508C6	2408 219609	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey_26081963@postgrespro.ru", "phone": "+70730179638"}
0005433985825	F33374	8888 542805	DMITRIY KONOVALOV	{"phone": "+70076123436"}
0005433985826	F33374	3813 233922	IRINA TROFIMOVA	{"email": "trofimova.irina041971@postgrespro.ru", "phone": "+70607803543"}
0005433985827	F33374	1022 484496	OLGA LAZAREVA	{"email": "lazareva.olga_071969@postgrespro.ru", "phone": "+70864032165"}
0005433985828	E890F0	9604 682280	YANA NESTEROVA	{"email": "nesterova.y.29041976@postgrespro.ru", "phone": "+70307052690"}
0005433985829	4A3C0E	0895 249721	VITALIY KUZMIN	{"email": "kuzminv.1973@postgrespro.ru", "phone": "+70140982374"}
0005433985830	4A3C0E	3273 504101	ANNA NOVIKOVA	{"email": "annanovikova_1972@postgrespro.ru", "phone": "+70548366867"}
0005433985831	FCFB7D	5906 508629	MIKHAIL SOKOLOV	{"email": "sokolov-mikhail-071973@postgrespro.ru", "phone": "+70416084310"}
0005433985832	0B77D4	9182 881840	ALEKSEY ALEKSANDROV	{"phone": "+70552345367"}
0005433985833	653D59	5845 276753	VLADIMIR KULIKOV	{"email": "kulikov.v.121972@postgrespro.ru", "phone": "+70542737722"}
0005433985834	0518CD	6976 179701	NIKOLAY MEDVEDEV	{"email": "n_medvedev_17061976@postgrespro.ru", "phone": "+70249968623"}
0005433985835	745A1B	1745 669543	OLEG POPOV	{"phone": "+70088825378"}
0005433985836	1CFF36	1231 407149	ELVIRA FILIPPOVA	{"email": "filippova_elvira_15021967@postgrespro.ru", "phone": "+70258984274"}
0005433985837	0DEE73	5250 612119	SVETLANA MAKSIMOVA	{"email": "s_maksimova27071975@postgrespro.ru", "phone": "+70726168070"}
0005433985838	F2C0DA	0177 730294	ANATOLIY NIKITIN	{"phone": "+70585297157"}
0005433985839	BC4D1F	7908 578502	NELLYA POTAPOVA	{"phone": "+70185880000"}
0005433985840	DD5F54	6916 412774	VLADIMIR POPOV	{"phone": "+70719505579"}
0005433985841	6B2313	3020 875273	MARTA VOLKOVA	{"email": "volkova.marta-121970@postgrespro.ru", "phone": "+70855890091"}
0005433985842	BCBA9C	4832 817262	PAVEL MATVEEV	{"phone": "+70895120436"}
0005433985843	BE2F8C	3079 357241	ALLA KUZNECOVA	{"phone": "+70114132721"}
0005433985844	915813	0878 700926	YULIYA BELYAEVA	{"phone": "+70323340258"}
0005433985845	915813	9842 998369	SVETLANA OSIPOVA	{"phone": "+70515810428"}
0005433985846	5F2A69	9102 177943	YURIY SOKOLOV	{"phone": "+70865811364"}
0005433985847	CAE5D0	9745 331127	MARINA MIKHAYLOVA	{"phone": "+70246604935"}
0005433985848	4AE09C	6890 009055	RINAT ZHUKOV	{"phone": "+70025727299"}
0005433985849	4AE09C	3133 380115	RISHAT ANDREEV	{"email": "andreev_r_1979@postgrespro.ru", "phone": "+70468851125"}
0005433985850	22093F	7116 510690	MARAT BORISOV	{"phone": "+70406169817"}
0005433985851	22093F	3022 644405	SERGEY GORBUNOV	{"email": "gorbunov.sergey-09111967@postgrespro.ru", "phone": "+70918284547"}
0005433985852	D5C750	4697 241909	IVAN ZAYCEV	{"email": "i.zaycev-31031970@postgrespro.ru", "phone": "+70261319769"}
0005433985853	175764	8038 944357	MARGARITA IVANOVA	{"phone": "+70640181418"}
0005433985854	4CD609	9537 444292	VLADIMIR TARASOV	{"email": "vtarasov13091988@postgrespro.ru", "phone": "+70821670762"}
0005433985855	0E2D04	0359 103710	VLADIMIR POPOV	{"email": "popovv06041979@postgrespro.ru", "phone": "+70741929652"}
0005433985856	5507BD	8740 461012	NIKITA YAKOVLEV	{"phone": "+70861577360"}
0005433985857	5507BD	8512 598598	EVGENIY ZHUKOV	{"phone": "+70681232176"}
0005433985858	C51298	6398 378238	ALEKSEY BORISOV	{"phone": "+70464116539"}
0005433985859	50A46F	4021 240184	IRINA KUZNECOVA	{"email": "kuznecova_i031965@postgrespro.ru", "phone": "+70595437036"}
0005433985860	6E4347	9432 403504	IRINA SOKOLOVA	{"email": "irina.sokolova09101960@postgrespro.ru", "phone": "+70756252443"}
0005433985861	6E4347	6965 662053	NADEZHDA TIMOFEEVA	{"phone": "+70250247072"}
0005433985862	C674C4	5136 754480	NINA KUZNECOVA	{"phone": "+70632534968"}
0005433985863	C40FC0	9040 022821	SERGEY BORISOV	{"phone": "+70786334250"}
0005433985864	172D93	2636 344363	ANNA SOKOLOVA	{"phone": "+70072367119"}
0005433985865	683293	8371 690366	YURIY BARANOV	{"phone": "+70789883390"}
0005433985866	8C2A71	7272 723896	ALEKSANDRA AKIMOVA	{"phone": "+70810449943"}
0005433985867	F3AF54	8880 274752	ANASTASIYA SERGEEVA	{"email": "anastasiya-sergeeva-1977@postgrespro.ru", "phone": "+70014867981"}
0005433985868	5EA3EB	8163 269916	MAKSIM NOVIKOV	{"email": "m-novikov.1969@postgrespro.ru", "phone": "+70175159659"}
0005433985869	5EA3EB	6244 074999	SERGEY TIKHONOV	{"email": "tikhonov-sergey-25091983@postgrespro.ru", "phone": "+70247102804"}
0005433985870	2A6D56	8036 205212	PAVEL PAVLOV	{"email": "p.pavlov1959@postgrespro.ru", "phone": "+70141538359"}
0005433985872	8A6424	0024 807490	VALENTINA KUZMINA	{"email": "kuzminavalentina-24111974@postgrespro.ru", "phone": "+70005346642"}
0005433985873	E5DA50	8280 058191	MIKHAIL DENISOV	{"email": "denisovmikhail_081975@postgrespro.ru", "phone": "+70823684549"}
0005433985874	C8F0DE	8251 900155	RAISA VLASOVA	{"phone": "+70892039397"}
0005433985875	17033C	9566 061744	ANATOLIY MAKSIMOV	{"email": "maksimovanatoliy-111965@postgrespro.ru", "phone": "+70386522302"}
0005433985876	17033C	5568 735408	RAMIL IVANOV	{"email": "ivanov.ramil_021975@postgrespro.ru", "phone": "+70547866830"}
0005433985877	8F7829	2761 333004	SERGEY KISELEV	{"email": "kiselev.sergey-061968@postgrespro.ru", "phone": "+70228420866"}
0005433985878	56CF77	9926 051954	VERA ALEKSANDROVA	{"phone": "+70068531960"}
0005433985879	56CF77	2779 119892	NATALIYA ILINA	{"email": "ilina_n_011987@postgrespro.ru", "phone": "+70557487504"}
0005433985880	21B323	7609 990457	NATALIYA RYABOVA	{"phone": "+70714602770"}
0005433985881	21B323	7956 800707	LIDIYA FEDOROVA	{"phone": "+70356836091"}
0005433985882	2C32A2	3396 369357	KSENIYA CHERNOVA	{"email": "kseniya_chernova031966@postgrespro.ru", "phone": "+70696549221"}
0005433985883	D5AE80	1165 719547	ALEKSEY RODIONOV	{"phone": "+70613441393"}
0005433985884	D5AE80	9491 927618	LYUDMILA VASILEVA	{"email": "lvasileva-20011960@postgrespro.ru", "phone": "+70570933279"}
0005433985885	C40ED0	5488 982661	SERGEY BELOV	{"email": "belov-s_04071973@postgrespro.ru", "phone": "+70427842913"}
0005433985886	8C6BF8	1664 206468	OLGA OVCHINNIKOVA	{"email": "ovchinnikova_olga02081958@postgrespro.ru", "phone": "+70254283984"}
0005433985887	75AF0A	2452 731687	SERGEY BELOV	{"phone": "+70182415644"}
0005433986002	E1740D	3341 144877	ANNA MIKHAYLOVA	{"phone": "+70439297032"}
0005433985888	56BE55	6814 525435	DMITRIY KOROLEV	{"email": "korolev-d_03041981@postgrespro.ru", "phone": "+70131439222"}
0005433985889	56BE55	5554 839842	VYACHESLAV ANDREEV	{"phone": "+70370237760"}
0005433985890	C6717C	4754 481688	AZAT VASILEV	{"phone": "+70328429059"}
0005433985891	236866	8385 278939	DMITRIY POPOV	{"email": "d-popov-011975@postgrespro.ru", "phone": "+70280465812"}
0005433985892	B066A4	2261 465863	ELENA LUKYANOVA	{"email": "e-lukyanova_031973@postgrespro.ru", "phone": "+70526803999"}
0005433985893	B066A4	8353 191234	MILANA KOZLOVA	{"email": "kozlova-milana071978@postgrespro.ru", "phone": "+70353228171"}
0005433985894	B066A4	1507 980012	GENNADIY MELNIKOV	{"phone": "+70757422599"}
0005433985895	D7ACCF	7756 705642	ANATOLIY NIKITIN	{"phone": "+70279230763"}
0005433985897	EEA328	3280 532722	ANDREY MIKHAYLOV	{"phone": "+70383165570"}
0005433985898	9BF6E3	7051 732907	ANNA VOLKOVA	{"phone": "+70958051167"}
0005433985899	9BF6E3	7625 457378	ALEKSANDR KUZMIN	{"phone": "+70818210837"}
0005433985900	A78CF5	2867 583220	ALEKSANDR IVANOV	{"phone": "+70253806155"}
0005433985901	E783B6	4590 785808	TATYANA SERGEEVA	{"phone": "+70088922080"}
0005433985902	E783B6	2086 382026	EVGENIY TARASOV	{"email": "evgeniy-tarasov.1980@postgrespro.ru", "phone": "+70613577151"}
0005433985903	0957BA	1342 060252	YURIY MARTYNOV	{"email": "martynov-yuriy1971@postgrespro.ru", "phone": "+70760626223"}
0005433985904	0957BA	4769 907925	OLESYA IVANOVA	{"phone": "+70439289143"}
0005433985905	C81758	9859 886050	INNA KARPOVA	{"phone": "+70820999377"}
0005433985906	C81758	2428 248919	TAMARA MIRONOVA	{"phone": "+70487254885"}
0005433985907	FCAF32	3492 504698	TAMARA ROMANOVA	{"email": "romanova_t-051981@postgrespro.ru", "phone": "+70124370510"}
0005433985908	6A6877	0604 061738	VALERIY EGOROV	{"phone": "+70941475349"}
0005433985909	6A6877	0170 164513	NATALYA SEMENOVA	{"phone": "+70941468472"}
0005433985910	DDCB14	5270 255206	MATVEY EGOROV	{"phone": "+70654965085"}
0005433985911	28DB76	0125 703280	MARIYA KUZNECOVA	{"email": "mariyakuznecova.18091962@postgrespro.ru", "phone": "+70266504321"}
0005433985912	28DB76	1523 064147	ANDREY BARANOV	{"email": "andrey.baranov02041967@postgrespro.ru", "phone": "+70264366551"}
0005433985913	543A1C	0436 904663	VLADIMIR MATVEEV	{"phone": "+70913610953"}
0005433985914	543A1C	0431 340808	OLGA SOKOLOVA	{"email": "olga-sokolova081969@postgrespro.ru", "phone": "+70180901193"}
0005433985915	46FB1A	8527 361278	OKSANA KUZNECOVA	{"phone": "+70004246059"}
0005433985916	214298	3693 234179	NATALYA NESTEROVA	{"phone": "+70144032201"}
0005433985917	7124FB	7123 610901	ALEKSEY VLASOV	{"phone": "+70043689804"}
0005433985918	5DF5E7	0505 522463	IGOR FROLOV	{"phone": "+70663278011"}
0005433985919	915095	4799 321661	SERGEY ALEKSANDROV	{"email": "s_aleksandrov.25021969@postgrespro.ru", "phone": "+70959827824"}
0005433985920	0C92D1	9059 169937	GALINA ZAYCEVA	{"email": "zayceva_g_05111961@postgrespro.ru", "phone": "+70543512245"}
0005433985921	0C92D1	3061 000166	ANDREY DAVYDOV	{"email": "davydovandrey_1968@postgrespro.ru", "phone": "+70967777521"}
0005433985922	187767	2391 821816	ALENA MALYSHEVA	{"phone": "+70800584380"}
0005433985923	187767	0884 556135	RAISA MARTYNOVA	{"phone": "+70907769425"}
0005433985924	9BB042	2563 621113	NATALYA NAZAROVA	{"phone": "+70495835316"}
0005433985925	9BB042	1610 698370	ANNA FOMINA	{"email": "fominaa.021961@postgrespro.ru", "phone": "+70407788792"}
0005433985926	52DE2C	0458 428165	LYUDMILA ISAEVA	{"email": "lisaeva07081964@postgrespro.ru", "phone": "+70906676234"}
0005433985927	EF22BD	3636 811684	MARINA ZAYCEVA	{"phone": "+70657365497"}
0005433985928	B7C87C	8556 550083	REGINA RYABOVA	{"email": "ryabovaregina_051973@postgrespro.ru", "phone": "+70172540742"}
0005433985929	781AFB	4219 650867	IVAN DAVYDOV	{"phone": "+70334101250"}
0005433985930	50846B	0123 503642	ELENA IVANOVA	{"phone": "+70452602951"}
0005433985931	B7B727	6591 316793	EDUARD CHERNOV	{"email": "e.chernov.101962@postgrespro.ru", "phone": "+70435464300"}
0005433985932	DBF048	6374 288091	VLADIMIR ABRAMOV	{"email": "abramov.v081964@postgrespro.ru", "phone": "+70172416968"}
0005433985933	DBF048	5078 747602	SERGEY IVANOV	{"phone": "+70082619799"}
0005433985934	47B7E8	3076 557703	LIDIYA YUDINA	{"email": "yudina.lidiya-121965@postgrespro.ru", "phone": "+70683325108"}
0005433985935	4925AE	3333 604800	ALEKSANDR NAZAROV	{"email": "a-nazarov-10021976@postgrespro.ru", "phone": "+70007518779"}
0005433985936	4925AE	1377 004830	SERGEY PAVLOV	{"email": "spavlov28081968@postgrespro.ru", "phone": "+70695657240"}
0005433985937	798EFA	7246 391731	DMITRIY IVANOV	{"email": "ivanov-dmitriy-15101964@postgrespro.ru", "phone": "+70056392608"}
0005433985938	798EFA	0108 928965	RENAT NAZAROV	{"phone": "+70797251630"}
0005433985939	7AF67B	8039 714799	TATYANA MOROZOVA	{"email": "morozova.t-1971@postgrespro.ru", "phone": "+70108670113"}
0005433985940	9F3691	5128 326343	IGOR KUZNECOV	{"email": "igor.kuznecov.1965@postgrespro.ru", "phone": "+70347022660"}
0005433985941	9F3691	3106 464095	TATYANA SOROKINA	{"email": "tatyanasorokina1972@postgrespro.ru", "phone": "+70967520627"}
0005433985942	522795	7668 750488	NATALYA MAKSIMOVA	{"phone": "+70022971861"}
0005433985943	9C666F	8860 420813	ELENA GUSEVA	{"phone": "+70321412852"}
0005433985944	9C666F	4523 400547	VLADIMIR VASILEV	{"phone": "+70378764648"}
0005433985946	652E0A	3891 018150	VLADIMIR GAVRILOV	{"email": "gavrilov-vladimir15011990@postgrespro.ru", "phone": "+70131238497"}
0005433985947	BA6F72	3265 519666	ANTONINA BELYAEVA	{"phone": "+70296699771"}
0005433985948	8FAA9A	9350 494418	IRINA NOVIKOVA	{"email": "novikova.i.051974@postgrespro.ru", "phone": "+70752361865"}
0005433985949	8FAA9A	6224 151602	NADEZHDA KULIKOVA	{"email": "kulikovan_071975@postgrespro.ru", "phone": "+70066066938"}
0005433985950	B62447	1932 757307	LARISA BORISOVA	{"email": "borisova_larisa09051968@postgrespro.ru", "phone": "+70721593076"}
0005433985951	B62447	6532 263486	MARINA YUDINA	{"email": "yudina-m1984@postgrespro.ru", "phone": "+70643964525"}
0005433985952	ABC2B9	9648 119837	MARINA SEMENOVA	{"email": "marina-semenova-03121977@postgrespro.ru", "phone": "+70920637616"}
0005433985953	ABC2B9	9185 712972	MARIYA NAZAROVA	{"phone": "+70052334982"}
0005433985954	6D5DC4	8238 563162	EKATERINA SOLOVEVA	{"email": "soloveva_e_12071981@postgrespro.ru", "phone": "+70333435969"}
0005433985955	694575	3094 966178	VYACHESLAV ZHURAVLEV	{"phone": "+70956526602"}
0005433985956	42CB41	0061 028501	VALENTINA MOROZOVA	{"phone": "+70972168111"}
0005433985957	C75240	4168 482535	ARINA POPOVA	{"phone": "+70737018986"}
0005433985958	C75240	4615 520708	ILMIR FROLOV	{"phone": "+70492505015"}
0005433985959	E0BFB4	5143 097139	IVAN ABRAMOV	{"phone": "+70731381463"}
0005433985960	E933D3	4674 460033	PAVEL DENISOV	{"email": "denisov.pavel_1973@postgrespro.ru", "phone": "+70405849728"}
0005433985961	E933D3	2357 973050	OLGA ANTONOVA	{"phone": "+70831125021"}
0005433985962	6B68AE	5016 087541	LYUBOV BELYAEVA	{"email": "belyaeva_l_31101976@postgrespro.ru", "phone": "+70507980997"}
0005433985963	644FFD	3808 961432	ALEKSANDR ALEKSEEV	{"phone": "+70453073545"}
0005433985964	644FFD	8870 371471	LILIYA NAZAROVA	{"email": "lnazarova10101977@postgrespro.ru", "phone": "+70273340071"}
0005433985965	74F9AF	0862 862966	VLADIMIR SHEVCHENKO	{"phone": "+70204738181"}
0005433985966	54F84D	4804 939723	NURLAN GORBUNOV	{"email": "nurlan_gorbunov_081977@postgrespro.ru", "phone": "+70824944910"}
0005433985967	1018DE	1097 744960	VLADIMIR POPOV	{"phone": "+70279321473"}
0005433985968	3EE44F	0585 566057	NIKOLAY ROMANOV	{"email": "romanov-n-22031972@postgrespro.ru", "phone": "+70621344097"}
0005433985969	492B0A	8752 047256	ILYA BARANOV	{"email": "baranov-i-1966@postgrespro.ru", "phone": "+70136962273"}
0005433985970	C8BEF9	8264 988083	GULSHAT ALEKSANDROVA	{"email": "aleksandrova.g_1965@postgrespro.ru", "phone": "+70230610248"}
0005433985971	62F876	0152 025248	VALENTINA IVANOVA	{"email": "v_ivanova-1969@postgrespro.ru", "phone": "+70056037308"}
0005433985972	EBE5ED	7191 016697	PAVEL TIMOFEEV	{"phone": "+70929023399"}
0005433985973	E738F3	3330 405841	SVETLANA MATVEEVA	{"email": "matveevas.121974@postgrespro.ru", "phone": "+70997025864"}
0005433985974	C20C8D	3428 500801	RAISA GORBUNOVA	{"phone": "+70592291824"}
0005433985975	C20C8D	7981 394370	SVYATOSLAV ZHUKOV	{"email": "zhukovsvyatoslav-19061954@postgrespro.ru", "phone": "+70084129994"}
0005433985976	DD8BDD	0887 590369	NATALYA FILIPPOVA	{"phone": "+70289516914"}
0005433985977	DD8BDD	0810 161816	OLGA ROMANOVA	{"phone": "+70322138807"}
0005433985978	6EAFF4	3701 870123	ALEKSANDR STEPANOV	{"phone": "+70054908863"}
0005433985979	6EAFF4	0791 964000	MARIYA KOVALEVA	{"email": "kovaleva-m-01011971@postgrespro.ru", "phone": "+70878889309"}
0005433985980	E7056D	3389 428547	MIKHAIL ORLOV	{"email": "orlov-mikhail1972@postgrespro.ru", "phone": "+70776307616"}
0005433985981	715E32	0156 888389	ANATOLIY ZHURAVLEV	{"phone": "+70802726723"}
0005433985982	5139E7	6474 585606	ANTON VOLKOV	{"phone": "+70045208050"}
0005433985983	5139E7	4104 634204	NIKITA SCHERBAKOV	{"phone": "+70273230379"}
0005433985984	242BFE	0136 208084	RINAT ZHURAVLEV	{"email": "rzhuravlev-19011973@postgrespro.ru", "phone": "+70970728719"}
0005433985985	242BFE	3098 706746	NIKITA GRIGOREV	{"email": "n-grigorev05061980@postgrespro.ru", "phone": "+70918016910"}
0005433985986	9F2952	2035 435794	OLGA OVCHINNIKOVA	{"phone": "+70514074944"}
0005433985987	E94872	0888 565442	DMITRIY KOZLOV	{"phone": "+70854029166"}
0005433985988	ADCE25	1068 725309	ARTEM ISAEV	{"phone": "+70389459114"}
0005433985989	2688B5	9841 098276	ARTEM NOVIKOV	{"email": "artem.novikov1971@postgrespro.ru", "phone": "+70954463033"}
0005433985990	2688B5	3030 660155	ELENA SMIRNOVA	{"phone": "+70903684850"}
0005433985991	95E03F	8074 815945	ANDREY KOZLOV	{"phone": "+70267489138"}
0005433985992	571817	0499 451853	ALEKSANDR VOLKOV	{"email": "avolkov.07071976@postgrespro.ru", "phone": "+70369786873"}
0005433985993	571817	3465 336720	ALEKSEY SEMENOV	{"phone": "+70562361804"}
0005433985994	E73C4A	8401 965693	TAISIYA ANTONOVA	{"phone": "+70095250806"}
0005433985995	D0A75B	8371 576643	GALINA VOLKOVA	{"email": "g.volkova081968@postgrespro.ru", "phone": "+70248487013"}
0005433985996	9503C3	8612 948490	ALINA ANDREEVA	{"phone": "+70426323093"}
0005433985997	E46697	0880 495566	ALENA ZAKHAROVA	{"phone": "+70649350300"}
0005433985998	5277FE	3557 976407	ARINA FILIPPOVA	{"email": "a.filippova1981@postgrespro.ru", "phone": "+70327915233"}
0005433985999	3F8B95	7136 236027	SERGEY KRASNOV	{"email": "krasnov-s-15071980@postgrespro.ru", "phone": "+70206582377"}
0005433986000	E1740D	5548 528363	NIKOLAY SEMENOV	{"phone": "+70179685049"}
0005433986001	E1740D	4141 734938	VIKTOR SCHERBAKOV	{"email": "scherbakov.viktor18041965@postgrespro.ru", "phone": "+70004709988"}
0005433986003	458ACF	9708 395841	NIKOLAY VASILEV	{"phone": "+70489530515"}
0005433986004	5C4B37	0730 187828	MIKHAIL VLASOV	{"email": "vlasov-mikhail.051975@postgrespro.ru", "phone": "+70221617245"}
0005433986005	5C4B37	1967 528189	LYUDMILA VASILEVA	{"phone": "+70986642029"}
0005433986006	5C4B37	8123 648632	RAMILYA TIKHONOVA	{"email": "ramilya.tikhonova.081971@postgrespro.ru", "phone": "+70720420400"}
0005433986007	45EFA8	3025 922730	OLGA CHERNOVA	{"email": "olga-chernova_1974@postgrespro.ru", "phone": "+70500621835"}
0005433986008	45EFA8	4764 675118	ELENA KRASNOVA	{"email": "elenakrasnova111973@postgrespro.ru", "phone": "+70866026228"}
0005433986009	45EFA8	6484 369463	YURIY VOLKOV	{"email": "y-volkov011975@postgrespro.ru", "phone": "+70747848833"}
0005433986010	EAE2CA	9853 005189	RAISA MATVEEVA	{"phone": "+70756771752"}
0005433986011	EAE2CA	5398 773476	DARYA AFANASEVA	{"email": "dafanaseva-041977@postgrespro.ru", "phone": "+70091700713"}
0005433986012	704CF6	9144 969620	VLADIMIR MELNIKOV	{"email": "melnikov_vladimir.091976@postgrespro.ru", "phone": "+70815153445"}
0005433986013	704CF6	2456 724470	PAVEL ALEKSANDROV	{"email": "aleksandrov.pavel-04121969@postgrespro.ru", "phone": "+70183732681"}
0005433986014	704CF6	9818 601687	SULTAN SEMENOV	{"phone": "+70877197109"}
0005433986015	1A91BA	3761 795989	ADELINA MARTYNOVA	{"email": "martynova_adelina_1969@postgrespro.ru", "phone": "+70420870261"}
0005433986016	272125	2132 146291	VERA KISELEVA	{"email": "kiseleva.v101968@postgrespro.ru", "phone": "+70237936047"}
0005433986017	6C5FCA	9932 575242	POLINA LAZAREVA	{"email": "lazareva-p_05121972@postgrespro.ru", "phone": "+70245243015"}
0005433986018	6C1BB2	0710 268183	GRIGORIY KUZNECOV	{"email": "kuznecov-g-1970@postgrespro.ru", "phone": "+70472940338"}
0005433986019	DF207D	3505 380140	ANNA EGOROVA	{"email": "a-egorova_26121968@postgrespro.ru", "phone": "+70387588334"}
0005433986020	024A2F	9284 040790	NINA SERGEEVA	{"phone": "+70775384119"}
0005433986021	82E038	1345 859961	KLAVDIYA NOVIKOVA	{"phone": "+70033183616"}
0005433986022	00C811	8772 257069	LARISA NESTEROVA	{"email": "nesterova-l_1975@postgrespro.ru", "phone": "+70403674976"}
0005433986023	BEC6CA	8356 794807	NIKOLAY ROMANOV	{"email": "n_romanov_25101971@postgrespro.ru", "phone": "+70433713434"}
0005433986024	2DE8FF	0767 962308	DMITRIY MOROZOV	{"email": "morozov.dmitriy_1966@postgrespro.ru", "phone": "+70080105997"}
0005433986025	EC4F56	1020 995801	VALERIY GORBUNOV	{"email": "valeriy.gorbunov02061977@postgrespro.ru", "phone": "+70402022067"}
0005433986026	EC4F56	5804 245226	OLGA YAKOVLEVA	{"email": "olga_yakovleva.091967@postgrespro.ru", "phone": "+70210780757"}
0005433986027	201FC4	2070 571677	VIKTORIYA ZAYCEVA	{"email": "v.zayceva_23031978@postgrespro.ru", "phone": "+70090998037"}
0005433986028	201FC4	6956 487066	IRINA VOLKOVA	{"email": "irina.volkova1967@postgrespro.ru", "phone": "+70487594607"}
0005433986029	128050	6990 362242	ALEKSANDR NIKITIN	{"email": "a_nikitin-22121981@postgrespro.ru", "phone": "+70159999037"}
0005433986030	128050	4677 888461	ELIZAVETA CHERNOVA	{"email": "elizaveta_chernova-15111959@postgrespro.ru", "phone": "+70779186586"}
0005433986031	8E771F	4578 503482	ALEKSANDR STEPANOV	{"email": "astepanov-1985@postgrespro.ru", "phone": "+70175787613"}
0005433986032	5D4817	1306 267364	NIKITA SERGEEV	{"email": "n-sergeev-041966@postgrespro.ru", "phone": "+70575038484"}
0005433986033	D3A8BD	6192 003616	STEPAN SMIRNOV	{"email": "smirnovstepan-091975@postgrespro.ru", "phone": "+70149874176"}
0005433986034	2A9881	3647 784893	TATYANA PAVLOVA	{"phone": "+70655564595"}
0005433986035	90CACD	8221 808477	TIMOFEY NIKITIN	{"email": "timofeynikitin-081989@postgrespro.ru", "phone": "+70165247040"}
0005433986036	7F0226	4065 485099	OLGA SMIRNOVA	{"phone": "+70391342987"}
0005433986037	0C0560	9760 192782	DMITRIY KUZNECOV	{"phone": "+70491927054"}
0005433986038	ADF8D4	1216 913676	ANATOLIY ISAEV	{"phone": "+70349004011"}
0005433986039	8CB51A	3795 440269	ALINA MAKAROVA	{"phone": "+70325380693"}
0005433986040	AEC586	8086 870585	NADEZHDA ALEKSEEVA	{"phone": "+70634191443"}
0005433986041	AC563A	5342 249248	IGOR NAZAROV	{"email": "igor-nazarov.18041970@postgrespro.ru", "phone": "+70893258411"}
0005433986042	2ED778	2528 684800	IGOR FEDOROV	{"email": "fedorov.i.16031974@postgrespro.ru", "phone": "+70269289324"}
0005433986043	2ED778	8840 453567	SVETLANA FEDOROVA	{"phone": "+70742208352"}
0005433986044	03D142	8589 300674	ANGELINA NIKITINA	{"email": "nikitina-a-121988@postgrespro.ru", "phone": "+70472733188"}
0005433986045	9AA60A	3567 463184	PETR FEDOROV	{"email": "fedorov.p051965@postgrespro.ru", "phone": "+70043900347"}
0005433986046	9AA60A	5011 131483	GALINA BARANOVA	{"phone": "+70544884834"}
0005433986047	29BB8A	3050 445749	ANDREY KONOVALOV	{"email": "konovalova-021973@postgrespro.ru", "phone": "+70051788332"}
0005433986048	0C1A97	2208 290558	MARIYA SOROKINA	{"email": "msorokina.041967@postgrespro.ru", "phone": "+70098699070"}
0005433986049	4BBA31	1244 742807	ALLA KUZNECOVA	{"email": "kuznecova-alla1978@postgrespro.ru", "phone": "+70431486955"}
0005433986050	F45C8D	0580 934472	VERA MARTYNOVA	{"email": "vera-martynova-111984@postgrespro.ru", "phone": "+70713944517"}
0005433986051	340F4E	4545 776675	VIKTOR KRASNOV	{"phone": "+70659514972"}
0005433986052	665D3B	2139 814007	ZINAIDA NOVIKOVA	{"phone": "+70691024263"}
0005433986053	48BDA4	1059 962993	MIKHAIL BELOV	{"phone": "+70489331215"}
0005433986054	D84F1A	7641 925781	ALINA NIKOLAEVA	{"email": "a.nikolaeva_1987@postgrespro.ru", "phone": "+70477878973"}
0005433986055	D84F1A	6972 450978	OLGA BOGDANOVA	{"email": "bogdanovaolga_011975@postgrespro.ru", "phone": "+70642413260"}
0005433986056	E6F100	6177 776043	VALENTINA EGOROVA	{"phone": "+70012239492"}
0005433986057	E6F100	2539 507868	KSENIYA PETROVA	{"phone": "+70268089308"}
0005433986058	0D9B9E	5458 225461	EGOR NIKITIN	{"email": "nikitin_e.1983@postgrespro.ru", "phone": "+70592801119"}
0005433986059	00044E	6676 063457	ALEKSEY DENISOV	{"phone": "+70938695075"}
0005433986060	00044E	9938 399775	SERGEY ZAKHAROV	{"email": "zakharov.sergey.091960@postgrespro.ru", "phone": "+70512436540"}
0005433986061	4EDB66	8965 383402	NADEZHDA SOLOVEVA	{"phone": "+70594988251"}
0005433986062	4EDB66	7142 970741	TATYANA VOROBEVA	{"phone": "+70105634149"}
0005433986063	DA4DCE	8714 636174	EVGENIY PETROV	{"email": "petrov-evgeniy.30011970@postgrespro.ru", "phone": "+70991468522"}
0005433986064	DD6561	4163 995815	ILYAS ORLOV	{"phone": "+70943552333"}
0005433986065	A435B6	6114 437004	VIKTOR ALEKSANDROV	{"phone": "+70559265952"}
0005433986066	919C37	5125 635930	TIMUR DMITRIEV	{"phone": "+70389428523"}
0005433986067	2AC540	5358 430854	NINA MOROZOVA	{"email": "n-morozova011972@postgrespro.ru", "phone": "+70328051346"}
0005433986068	5F92DC	4361 557325	NIKITA EGOROV	{"phone": "+70487164941"}
0005433986069	B8B18A	9141 633449	TATYANA DAVYDOVA	{"email": "davydova_tatyana-23031983@postgrespro.ru", "phone": "+70915262255"}
0005433986070	1B5CC6	9935 686651	ELENA KOZLOVA	{"phone": "+70884608424"}
0005433986071	1B5CC6	1061 265511	NIKOLAY KUZNECOV	{"phone": "+70159065166"}
0005433986072	FA3E75	4653 699715	EKATERINA NIKOLAEVA	{"phone": "+70009238811"}
0005433986073	3E5F35	5076 171367	ANNA YUDINA	{"email": "a_yudina.1965@postgrespro.ru", "phone": "+70174197723"}
0005433986074	9A975D	5593 757634	TAMARA VOROBEVA	{"email": "vorobeva-t_1962@postgrespro.ru", "phone": "+70338739126"}
0005433986075	AAFDC3	8556 142075	STANISLAV DENISOV	{"email": "stanislav_denisov1971@postgrespro.ru", "phone": "+70632739438"}
0005433986076	BD3100	5280 610785	VYACHESLAV BORISOV	{"email": "borisovvyacheslav_1970@postgrespro.ru", "phone": "+70056297959"}
0005433986077	E1AD7B	2849 011651	ILYA NAUMOV	{"phone": "+70158280090"}
0005433986078	D57F88	2099 188951	VALERIYA POPOVA	{"email": "valeriya_popova-081973@postgrespro.ru", "phone": "+70537897862"}
0005433986079	D57F88	1733 755521	DENIS IVANOV	{"email": "d_ivanov1965@postgrespro.ru", "phone": "+70749708516"}
0005433986080	528101	7405 019093	NURLAN GORBUNOV	{"phone": "+70797181004"}
0005433986081	12A0FC	5462 670488	NADEZHDA KISELEVA	{"email": "n-kiseleva041980@postgrespro.ru", "phone": "+70913956089"}
0005433986082	5EF00C	1616 003520	KARINA KUZMINA	{"email": "karinakuzmina021979@postgrespro.ru", "phone": "+70058625600"}
0005433986083	80CA6A	1850 126715	ALLA KOZLOVA	{"email": "alla.kozlova071978@postgrespro.ru", "phone": "+70580078565"}
0005433986084	80CA6A	0543 126064	KSENIYA MARTYNOVA	{"email": "kseniyamartynova1971@postgrespro.ru", "phone": "+70962313463"}
0005433986085	BF90C1	5229 105995	ULYANA YAKOVLEVA	{"email": "u.yakovleva_011976@postgrespro.ru", "phone": "+70926328795"}
0005433986086	822E55	8727 569304	ELENA MIKHAYLOVA	{"phone": "+70518419438"}
0005433986087	822E55	0351 924440	IGOR IVANOV	{"phone": "+70404428084"}
0005433986088	49DC8A	2393 464910	NADEZHDA MIKHAYLOVA	{"email": "nadezhda-mikhaylova.011971@postgrespro.ru", "phone": "+70288615963"}
0005433986089	49DC8A	4605 346636	VLADISLAV ILIN	{"email": "vladislav_ilin071968@postgrespro.ru", "phone": "+70357206944"}
0005433986090	E12008	4358 015898	LIDIYA CHERNOVA	{"phone": "+70775915189"}
0005433986091	EEB8BD	6761 596490	POLINA ANTONOVA	{"phone": "+70270195823"}
0005433986092	8830D9	9789 162121	IVAN SOROKIN	{"phone": "+70489034747"}
0005433986093	BFCAF1	0823 698249	SVETLANA MALYSHEVA	{"email": "malysheva.s_11101975@postgrespro.ru", "phone": "+70641355869"}
0005433986094	613B05	3531 285762	LEONID KUZNECOV	{"phone": "+70788145281"}
0005433986095	22D950	0899 814808	TATYANA GUSEVA	{"email": "guseva_tatyana081976@postgrespro.ru", "phone": "+70740489329"}
0005433986096	22D950	0165 414347	DMITRIY SOKOLOV	{"phone": "+70683313478"}
0005433986097	A1355C	7501 989262	VERA DAVYDOVA	{"email": "vera_davydova-101972@postgrespro.ru", "phone": "+70535507779"}
0005433986098	A1355C	3793 700086	IRINA MOROZOVA	{"phone": "+70146097850"}
0005433986099	6D528B	0001 217596	SERGEY EGOROV	{"email": "sergey_egorov.25101964@postgrespro.ru", "phone": "+70988258454"}
0005433986100	8C7B65	0622 477289	NATALYA SOKOLOVA	{"email": "natalya-sokolova_091975@postgrespro.ru", "phone": "+70021076083"}
0005433986101	0AAB98	7622 510030	ILYA KUZNECOV	{"email": "ilya_kuznecov.011970@postgrespro.ru", "phone": "+70501728254"}
0005433986102	FD8CD2	4801 880530	VASILIY MAKAROV	{"email": "v_makarov-1967@postgrespro.ru", "phone": "+70480803129"}
0005433986103	57A029	5282 399546	ILSHAT ZAYCEV	{"phone": "+70268961878"}
0005433986104	A45089	0078 513494	LYUBOV FEDOROVA	{"phone": "+70815815968"}
0005433986105	A45089	7686 683517	YULIYA YAKOVLEVA	{"email": "yakovleva.y_27051967@postgrespro.ru", "phone": "+70660839918"}
0005433986106	A45089	5265 678029	OLGA YAKOVLEVA	{"email": "yakovleva_o-1961@postgrespro.ru", "phone": "+70164532472"}
0005433986107	9F7762	2290 980425	ALEKSANDR ALEKSEEV	{"phone": "+70027369351"}
0005433986108	08F5D7	7002 676461	EVGENIYA NIKOLAEVA	{"email": "e_nikolaeva-1974@postgrespro.ru", "phone": "+70326936926"}
0005433986109	08F5D7	7578 693432	MARIYA VASILEVA	{"email": "mariyavasileva19101977@postgrespro.ru", "phone": "+70750305955"}
0005433986110	C56F65	4560 426136	SVETLANA VOLKOVA	{"email": "svolkova_101977@postgrespro.ru", "phone": "+70864053158"}
0005433986111	BD6902	4562 383311	YULIYA ANDREEVA	{"phone": "+70381382839"}
0005433986112	D2CBEC	8279 118827	SERGEY DAVYDOV	{"email": "sergey-davydov_06041968@postgrespro.ru", "phone": "+70957713337"}
0005433986113	D2CBEC	1881 978802	SERGEY MATVEEV	{"phone": "+70623830993"}
0005433986114	64760A	4591 240145	OLEG ROMANOV	{"phone": "+70863176114"}
0005433986115	64760A	7390 773544	SVETLANA NIKITINA	{"phone": "+70365885564"}
0005433986116	45A5A0	4153 591031	LYUBOV DMITRIEVA	{"phone": "+70221172415"}
0005433986117	45A5A0	0954 511436	IRINA VASILEVA	{"phone": "+70449494321"}
0005433986118	5B8E3E	0256 102959	ANATOLIY KUZNECOV	{"phone": "+70474855083"}
0005433986119	5B8E3E	1708 946170	VLADIMIR ROMANOV	{"phone": "+70921815078"}
0005433986120	00E566	9381 370373	SVETLANA IVANOVA	{"phone": "+70271549604"}
0005433986121	00E566	0491 805197	ALEKSANDR SERGEEV	{"phone": "+70774600920"}
0005433986122	01A591	0547 665754	IGOR MAKAROV	{"phone": "+70492423717"}
0005433986123	45E956	1140 707124	YURIY NIKOLAEV	{"email": "nikolaev-y.17061978@postgrespro.ru", "phone": "+70044241213"}
0005433986124	5A1FFF	7200 125488	SVETLANA TIKHONOVA	{"phone": "+70256192535"}
0005433986125	5A1FFF	1340 451476	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana.071978@postgrespro.ru", "phone": "+70708398190"}
0005433986126	5A1FFF	7845 007005	YURIY ALEKSANDROV	{"email": "y_aleksandrov.1977@postgrespro.ru", "phone": "+70606334743"}
0005433986127	054AF4	0916 622655	IVAN GAVRILOV	{"phone": "+70481383152"}
0005433986128	1008C8	3781 710226	LYUDMILA MAKSIMOVA	{"phone": "+70007081082"}
0005433986129	1008C8	0464 726811	ARTEM KULIKOV	{"email": "a-kulikov_121966@postgrespro.ru", "phone": "+70716467901"}
0005433986130	3212B5	8684 232168	NATALYA ROMANOVA	{"phone": "+70077783182"}
0005433986131	3212B5	2623 072502	SVETLANA KUZNECOVA	{"email": "s_kuznecova.1959@postgrespro.ru", "phone": "+70241440339"}
0005433986132	557F4C	0053 268978	IRINA KUZNECOVA	{"phone": "+70783754697"}
0005433986133	6D1DC5	8177 344426	ANDREY ROMANOV	{"email": "romanov_andrey.04111973@postgrespro.ru", "phone": "+70298687658"}
0005433986134	5F75DF	6042 395718	VALERIYA SOLOVEVA	{"phone": "+70963177725"}
0005433986135	675D45	7924 495741	LYUDMILA ILINA	{"email": "ilina.lyudmila.29081979@postgrespro.ru", "phone": "+70532431174"}
0005433986136	A219B3	5978 832661	ALEKSANDR IVANOV	{"email": "ivanov-a031981@postgrespro.ru", "phone": "+70380113210"}
0005433986137	A219B3	1662 745192	ANDREY IVANOV	{"email": "ivanovandrey-071971@postgrespro.ru", "phone": "+70602581120"}
0005433986138	6AB69B	9864 674384	EVGENIY ALEKSEEV	{"phone": "+70480017976"}
0005433986139	F79ECD	4657 340891	ANNA PAVLOVA	{"email": "pavlova_a_1978@postgrespro.ru", "phone": "+70522912144"}
0005433986140	17FBC7	5467 707310	ZULFIYA ZAKHAROVA	{"email": "zakharovaz.031971@postgrespro.ru", "phone": "+70014544028"}
0005433986141	DFAC3D	8632 285955	ANNA FROLOVA	{"phone": "+70674656001"}
0005433986142	DFAC3D	4056 048608	ANNA PAVLOVA	{"phone": "+70349690091"}
0005433986143	5CD248	0125 074293	ANDREY RODIONOV	{"phone": "+70426248659"}
0005433986144	84EE62	2345 631948	ILMIRA ANDREEVA	{"phone": "+70766865959"}
0005433986145	300B42	5986 255410	ALEKSEY FROLOV	{"email": "frolov-a-081965@postgrespro.ru", "phone": "+70840566583"}
0005433986146	FF7C45	3128 177012	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail29081970@postgrespro.ru", "phone": "+70132404553"}
0005433986147	FF7C45	4815 921109	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev.24081971@postgrespro.ru", "phone": "+70327510007"}
0005433986148	FF7C45	8187 872757	MARINA ANTONOVA	{"email": "mantonova1962@postgrespro.ru", "phone": "+70292716919"}
0005433986149	60DFCE	9529 364540	SERGEY FEDOTOV	{"email": "sergey_fedotov18011980@postgrespro.ru", "phone": "+70305990833"}
0005433986150	60DFCE	8638 260418	ARTEM MIKHAYLOV	{"email": "mikhaylov_artem20011971@postgrespro.ru", "phone": "+70445352295"}
0005433986151	1CEEB3	4032 151006	IRINA SEMENOVA	{"email": "semenova_i-11021970@postgrespro.ru", "phone": "+70199760964"}
0005433986152	406EF8	4710 374297	NIKITA KUZNECOV	{"email": "kuznecov_nikita_031967@postgrespro.ru", "phone": "+70516507650"}
0005433986153	B93173	9674 701011	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva-111980@postgrespro.ru", "phone": "+70367203880"}
0005433986154	851E8D	9150 493364	ARTEM ALEKSEEV	{"phone": "+70587145388"}
0005433986155	851E8D	2533 544242	ELENA FEDOROVA	{"email": "elena_fedorova.121972@postgrespro.ru", "phone": "+70153975327"}
0005433986156	B562C2	6314 711710	OLGA SOKOLOVA	{"phone": "+70781616938"}
0005433986157	16FDD0	9805 159375	TAISIYA KOZLOVA	{"phone": "+70714225598"}
0005433986158	16FDD0	7681 854383	SERGEY MAKAROV	{"phone": "+70419387511"}
0005433986159	537EB2	1121 697736	NADEZHDA KUZNECOVA	{"email": "kuznecova_n_031977@postgrespro.ru", "phone": "+70062121247"}
0005433986160	537EB2	4087 460835	ANATOLIY MELNIKOV	{"email": "melnikov-a_14031982@postgrespro.ru", "phone": "+70698111279"}
0005433986161	71276B	4839 620179	OLGA ALEKSEEVA	{"email": "alekseeva_o1974@postgrespro.ru", "phone": "+70403417997"}
0005433986162	6E9F9C	7108 090386	IRINA PETROVA	{"email": "petrova-irina051979@postgrespro.ru", "phone": "+70683605737"}
0005433986163	FFFF43	0169 339108	ANASTASIYA NIKITINA	{"email": "anastasiyanikitina1960@postgrespro.ru", "phone": "+70858036373"}
0005433986164	FFFF43	0961 118506	ILYA VOLKOV	{"email": "volkov_ilya081976@postgrespro.ru", "phone": "+70640137554"}
0005433986165	9741AE	7728 659364	VLADIMIR KOZLOV	{"phone": "+70872210311"}
0005433986166	48114E	3786 353973	DENIS MIRONOV	{"email": "denis.mironov1969@postgrespro.ru", "phone": "+70800934405"}
0005433986167	48114E	2740 784205	ANDREY SIDOROV	{"email": "sidorov-a101970@postgrespro.ru", "phone": "+70245553396"}
0005433986168	DDDA7D	2770 331622	VLADIMIR FOMIN	{"email": "fomin_v.16101976@postgrespro.ru", "phone": "+70955742157"}
0005433986169	DDDA7D	9488 841361	MARIYA GUSEVA	{"email": "guseva_m_1978@postgrespro.ru", "phone": "+70568450234"}
0005433986170	EA7DD2	0660 099203	ILYA SOKOLOV	{"email": "sokolov_i_26091971@postgrespro.ru", "phone": "+70821514655"}
0005433986171	10D095	4070 698443	MARIYA MELNIKOVA	{"email": "m.melnikova.07051969@postgrespro.ru", "phone": "+70741581818"}
0005433986172	B8CBC5	1454 830744	VERA TIMOFEEVA	{"phone": "+70167770401"}
0005433986173	B8CBC5	4608 976783	SNEZHANA KUZMINA	{"email": "kuzmina_s-1971@postgrespro.ru", "phone": "+70815883321"}
0005433986174	BDC11B	0090 793536	VLADIMIR MAKAROV	{"phone": "+70965178644"}
0005433986175	BDC11B	6842 480059	DENIS KUZMIN	{"email": "denis_kuzmin_1965@postgrespro.ru", "phone": "+70322310620"}
0005433986176	11A59E	5683 876599	TAMARA EGOROVA	{"phone": "+70010716487"}
0005433986177	B15B53	2259 949685	IVAN MEDVEDEV	{"phone": "+70274984184"}
0005433986178	F0676E	1396 435115	NADEZHDA ALEKSANDROVA	{"email": "nadezhda.aleksandrova.1962@postgrespro.ru", "phone": "+70400024352"}
0005433986179	77AD13	7346 378947	VITALIY KULIKOV	{"email": "kulikov.vitaliy-1968@postgrespro.ru", "phone": "+70228709757"}
0005433986180	82729C	4493 736668	DMITRIY NAUMOV	{"phone": "+70647499907"}
0005433986181	E852AB	3289 601912	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr-1962@postgrespro.ru", "phone": "+70800284219"}
0005433986182	8073DF	5066 672105	VALERIY PETROV	{"phone": "+70027250997"}
0005433986183	626320	1762 621383	TATYANA MASLOVA	{"email": "t.maslova061983@postgrespro.ru", "phone": "+70866825923"}
0005433986184	918339	3628 886056	RINAT NIKOLAEV	{"email": "r_nikolaev071977@postgrespro.ru", "phone": "+70073387103"}
0005433986185	7AF77B	9363 137914	SERGEY GAVRILOV	{"phone": "+70967232623"}
0005433986186	7AF77B	6623 663263	VITALIY GORBUNOV	{"email": "v_gorbunov-061962@postgrespro.ru", "phone": "+70801594454"}
0005433986187	A51F46	0816 022405	ALEKSEY EGOROV	{"email": "egorov.aleksey-1963@postgrespro.ru", "phone": "+70114914087"}
0005433986188	442637	2367 614505	ILYA ALEKSANDROV	{"phone": "+70959966499"}
0005433986189	DF882B	8456 547525	ILMIRA NIKOLAEVA	{"email": "nikolaeva.i_06101985@postgrespro.ru", "phone": "+70012834729"}
0005433986190	1E4820	5364 253071	NATALYA FOMINA	{"phone": "+70174618074"}
0005433986191	792B54	9548 869782	EVGENIYA KUZNECOVA	{"email": "kuznecova-evgeniya1975@postgrespro.ru", "phone": "+70055872473"}
0005433986192	FD78AC	4888 478260	EKATERINA CHERNOVA	{"email": "chernovae-10051984@postgrespro.ru", "phone": "+70141735694"}
0005433986193	3FC7E3	8005 282662	MARINA POPOVA	{"email": "popova.m-06031991@postgrespro.ru", "phone": "+70682958794"}
0005433986194	69EE3E	5835 889165	MARAT RODIONOV	{"phone": "+70925530937"}
0005433986195	14E6E5	0321 745646	KONSTANTIN KOROLEV	{"email": "k-korolev.12111969@postgrespro.ru", "phone": "+70655415970"}
0005433986313	CD2AE1	5086 016786	ANNA SIDOROVA	{"phone": "+70184294317"}
0005433986196	14E6E5	0429 219746	YULIYA IVANOVA	{"email": "ivanova.y-24081967@postgrespro.ru", "phone": "+70111362170"}
0005433986197	D5D81B	1293 609742	NADEZHDA VOROBEVA	{"email": "nadezhda_vorobeva-1957@postgrespro.ru", "phone": "+70724585770"}
0005433986198	D5D81B	9300 005642	DMITRIY EGOROV	{"email": "egorov.d-071975@postgrespro.ru", "phone": "+70967338841"}
0005433986199	98776D	3199 507855	ALEKSEY MOROZOV	{"email": "morozov.a.011970@postgrespro.ru", "phone": "+70088264684"}
0005433986200	98776D	5616 464491	SERGEY NOVIKOV	{"phone": "+70517771268"}
0005433986201	3B3497	0022 530335	VLADIMIR MARTYNOV	{"email": "vladimir.martynov041978@postgrespro.ru", "phone": "+70900584906"}
0005433986202	553BAB	3433 752013	DMITRIY NIKOLAEV	{"phone": "+70976649347"}
0005433986203	553BAB	9487 755910	NINA FROLOVA	{"email": "frolova.n.031971@postgrespro.ru", "phone": "+70056242181"}
0005433986204	553BAB	8558 747431	VLADIMIR VOLKOV	{"email": "volkov-v_1960@postgrespro.ru", "phone": "+70927298338"}
0005433986205	1E279E	9336 413461	SERGEY KRASNOV	{"phone": "+70468622495"}
0005433986206	6C898C	0338 271026	VALENTINA KOROLEVA	{"phone": "+70469141162"}
0005433986207	FC61BE	6709 757214	MARIYA KUZNECOVA	{"phone": "+70752105961"}
0005433986208	C0062E	9454 251356	ELENA FADEEVA	{"email": "e-fadeeva-1981@postgrespro.ru", "phone": "+70313474715"}
0005433986209	C0062E	7779 288139	ANNA CHERNOVA	{"phone": "+70872762775"}
0005433986210	9F5109	0718 259681	ANASTASIYA SEMENOVA	{"email": "semenovaanastasiya_13021970@postgrespro.ru", "phone": "+70255426647"}
0005433986211	D99C2B	8104 867191	IRINA TARASOVA	{"email": "tarasova.irina23011982@postgrespro.ru", "phone": "+70661695351"}
0005433986212	EDF74F	8315 941087	TATYANA VLASOVA	{"phone": "+70861971774"}
0005433986213	EDF74F	8610 246055	SERAFIMA LAZAREVA	{"email": "lazarevaserafima.021963@postgrespro.ru", "phone": "+70865636695"}
0005433986214	9A9818	6202 634307	FEDOR ANDREEV	{"email": "andreevf_101971@postgrespro.ru", "phone": "+70569335118"}
0005433986215	C73430	6766 830869	VALENTINA KRASNOVA	{"phone": "+70595985992"}
0005433986216	C73430	4255 432293	YULIYA SAVELEVA	{"phone": "+70708993004"}
0005433986217	C73430	7024 043069	OKSANA KUZNECOVA	{"email": "o-kuznecova031977@postgrespro.ru", "phone": "+70593148388"}
0005433986218	897F46	3897 024512	VIKTOR MEDVEDEV	{"email": "medvedev.viktor021971@postgrespro.ru", "phone": "+70881137992"}
0005433986219	5B0089	0737 877121	TATYANA ANDREEVA	{"email": "tatyana-andreeva-1972@postgrespro.ru", "phone": "+70175390560"}
0005433986220	FF9FDA	8209 162868	ANATOLIY MOROZOV	{"email": "morozov-anatoliy-071964@postgrespro.ru", "phone": "+70772918270"}
0005433986221	D5F2A0	0469 765534	ANASTASIYA DMITRIEVA	{"phone": "+70593355165"}
0005433986222	E26472	9524 385302	ALEKSANDR BORISOV	{"email": "borisov-aleksandr31071974@postgrespro.ru", "phone": "+70567484014"}
0005433986223	E26472	5287 417499	MIKHAIL KUZNECOV	{"phone": "+70407911012"}
0005433986224	FD23D9	3724 696157	GENNADIY DMITRIEV	{"email": "dmitrievgennadiy_1973@postgrespro.ru", "phone": "+70030707179"}
0005433986225	A6F21A	1639 684837	YANA KUZMINA	{"phone": "+70740183168"}
0005433986226	18533E	2576 635497	ANTON KISELEV	{"email": "anton-kiselev_09031976@postgrespro.ru", "phone": "+70856999289"}
0005433986227	D9FC80	0227 163656	GALINA NESTEROVA	{"email": "nesterova_g051969@postgrespro.ru", "phone": "+70933521131"}
0005433986228	D9FC80	7140 280652	ALEKSEY NAUMOV	{"email": "anaumov.19071963@postgrespro.ru", "phone": "+70025742648"}
0005433986229	64C575	2224 314528	ALEKSANDRA VASILEVA	{"phone": "+70291969762"}
0005433986230	F4B022	8037 681049	KRISTINA KUZNECOVA	{"email": "kkuznecova_1975@postgrespro.ru", "phone": "+70870234601"}
0005433986231	490E22	0015 994536	IVAN SEMENOV	{"phone": "+70886577202"}
0005433986232	490E22	9034 600090	YURIY SEMENOV	{"phone": "+70657522074"}
0005433986233	A1997B	7536 992195	IRINA DANILOVA	{"email": "danilovai_21011972@postgrespro.ru", "phone": "+70009906981"}
0005433986234	45B252	6517 677392	VIKTOR NOVIKOV	{"phone": "+70076270323"}
0005433986235	C6FE34	3320 784352	IGOR KUZNECOV	{"email": "igorkuznecov-17031977@postgrespro.ru", "phone": "+70482473381"}
0005433986236	C6FE34	5900 282411	MAKSIM POPOV	{"phone": "+70499452331"}
0005433986237	878FB0	3645 045399	NATALYA NIKIFOROVA	{"email": "n-nikiforova_12121973@postgrespro.ru", "phone": "+70182162934"}
0005433986238	878FB0	7066 583052	GALINA DAVYDOVA	{"phone": "+70880419725"}
0005433986239	0889E8	7166 879993	RAISA KOROLEVA	{"phone": "+70793487307"}
0005433986240	392B2A	6386 685120	VALERIYA POTAPOVA	{"phone": "+70904102721"}
0005433986241	F15735	5213 443289	SVETLANA KUZNECOVA	{"email": "s-kuznecova_021970@postgrespro.ru", "phone": "+70044065861"}
0005433986242	824182	6660 986687	NIKOLAY IVANOV	{"phone": "+70952860379"}
0005433986243	8281B1	5414 324769	VITALIY ORLOV	{"email": "v.orlov1963@postgrespro.ru", "phone": "+70307466194"}
0005433986244	2A86E6	5690 887892	ANATOLIY KUZNECOV	{"phone": "+70909332967"}
0005433986245	2F445E	6026 761625	EDUARD DAVYDOV	{"phone": "+70669724662"}
0005433986246	E6244F	5519 259421	ALEKSEY FROLOV	{"email": "aleksey-frolov19041967@postgrespro.ru", "phone": "+70149898798"}
0005433986247	0BF047	1118 751876	NADEZHDA NIKIFOROVA	{"phone": "+70370434759"}
0005433986248	0BF047	3962 405100	LYUBOV BORISOVA	{"email": "borisovalyubov-101965@postgrespro.ru", "phone": "+70779680592"}
0005433986249	8CAB1E	1461 468823	MIKHAIL IVANOV	{"email": "mikhail_ivanov_16071975@postgrespro.ru", "phone": "+70183368101"}
0005433986250	8CAB1E	7139 049811	ALEKSANDR NIKOLAEV	{"phone": "+70657626421"}
0005433986251	A6FBDF	4746 775782	VIKTORIYA VOLKOVA	{"email": "volkova-v.111964@postgrespro.ru", "phone": "+70026674911"}
0005433986252	A6FBDF	4647 817562	ANZHELIKA FADEEVA	{"email": "fadeeva_a-1973@postgrespro.ru", "phone": "+70865699117"}
0005433986253	A6FBDF	6276 211775	DMITRIY IVANOV	{"email": "dmitriy-ivanov041968@postgrespro.ru", "phone": "+70736362810"}
0005433986254	A8CFAA	0595 595158	ANGELINA MIRONOVA	{"email": "a_mironova1980@postgrespro.ru", "phone": "+70139421828"}
0005433986255	2BE84F	6876 072984	SVETLANA RYABOVA	{"email": "svetlana.ryabova_1973@postgrespro.ru", "phone": "+70444457638"}
0005433986256	2BE84F	2905 025400	GALINA SAVELEVA	{"email": "galina_saveleva1970@postgrespro.ru", "phone": "+70967632696"}
0005433986257	D4844C	1873 764279	YULIYA MOROZOVA	{"phone": "+70078250823"}
0005433986258	E719DC	3845 958579	VALENTINA SMIRNOVA	{"phone": "+70612318271"}
0005433986259	6ABD19	5805 458848	EKATERINA GERASIMOVA	{"email": "gerasimova_ekaterina20061979@postgrespro.ru", "phone": "+70866704994"}
0005433986260	6ABD19	5540 525219	IRINA VOROBEVA	{"phone": "+70183897696"}
0005433986261	6ABD19	3431 797967	SVETLANA AKIMOVA	{"email": "akimova.svetlana_1962@postgrespro.ru", "phone": "+70578381583"}
0005433986262	40111C	7339 495528	EVGENIY SAVELEV	{"email": "savelevevgeniy-1980@postgrespro.ru", "phone": "+70172950761"}
0005433986263	DEFE07	2484 853897	MIKHAIL NAZAROV	{"email": "nazarov-mikhail-101970@postgrespro.ru", "phone": "+70507823425"}
0005433986264	9B435A	3170 232210	NIKOLAY ZAKHAROV	{"email": "zakharov.nikolay.1971@postgrespro.ru", "phone": "+70264101089"}
0005433986265	9B435A	7780 658054	SERGEY IVANOV	{"email": "s_ivanov_1967@postgrespro.ru", "phone": "+70403683593"}
0005433986266	743E74	4216 404080	ANNA KOMAROVA	{"phone": "+70087829883"}
0005433986267	743E74	2060 169083	NIKOLAY TIKHONOV	{"email": "tikhonov.n-06091967@postgrespro.ru", "phone": "+70176429656"}
0005433986268	80FBEF	9416 347888	ELENA GORBUNOVA	{"email": "e_gorbunova.071965@postgrespro.ru", "phone": "+70331641102"}
0005433986269	80FBEF	6670 435370	NIKOLAY FEDOTOV	{"phone": "+70228512123"}
0005433986270	80FBEF	4546 776975	ALEKSEY BONDARENKO	{"email": "bondarenko-aleksey_26061976@postgrespro.ru", "phone": "+70611219205"}
0005433986271	2EDCCC	6577 378326	TAMARA PAVLOVA	{"phone": "+70267094085"}
0005433986272	4768F8	7537 841647	NINA KUZNECOVA	{"phone": "+70815374328"}
0005433986273	4768F8	6912 614770	DMITRIY ABRAMOV	{"email": "abramov_dmitriy101960@postgrespro.ru", "phone": "+70727972870"}
0005433986274	865ACE	4366 917068	ANATOLIY FEDOROV	{"phone": "+70373451058"}
0005433986275	865ACE	8189 842468	NATALYA AKIMOVA	{"phone": "+70040725142"}
0005433986276	992E6A	9869 505086	DMITRIY ORLOV	{"phone": "+70980615387"}
0005433986277	992E6A	1412 870824	MIKHAIL EGOROV	{"phone": "+70438263487"}
0005433986278	4A1954	0249 901831	NIKOLAY KUZNECOV	{"phone": "+70087100292"}
0005433986279	1F8FD5	0051 676171	VIKTOR KUZNECOV	{"phone": "+70685030734"}
0005433986280	1F8FD5	3455 233552	NIKITA MELNIKOV	{"phone": "+70493479340"}
0005433986281	A535C1	2044 515456	NADEZHDA GERASIMOVA	{"phone": "+70964721191"}
0005433986282	A535C1	4791 288938	YURIY EGOROV	{"email": "egorovyuriy.05011979@postgrespro.ru", "phone": "+70284887611"}
0005433986283	81FA48	3034 095014	MARIYA FADEEVA	{"phone": "+70840740445"}
0005433986284	81FA48	6872 031848	SERGEY ROMANOV	{"phone": "+70253506204"}
0005433986285	D677A3	0257 207051	TATYANA SOKOLOVA	{"email": "t-sokolova-1966@postgrespro.ru", "phone": "+70308002933"}
0005433986286	D677A3	4560 030556	MIKHAIL GERASIMOV	{"email": "m.gerasimov.1983@postgrespro.ru", "phone": "+70670295595"}
0005433986287	A2EF74	9101 063454	OLGA BORISOVA	{"email": "o-borisova12111980@postgrespro.ru", "phone": "+70028681214"}
0005433986288	AF5BB0	5581 230712	SERGEY ZAYCEV	{"email": "zaycev_sergey_031974@postgrespro.ru", "phone": "+70775162910"}
0005433986289	116907	3691 534473	SERGEY SOROKIN	{"email": "sorokins_041977@postgrespro.ru", "phone": "+70628580392"}
0005433986290	FC849C	5405 683578	ROMAN KRASNOV	{"email": "krasnov_roman_29081965@postgrespro.ru", "phone": "+70137392738"}
0005433986291	F6B9CE	1385 764039	YULIYA ERMAKOVA	{"email": "ermakova-yuliya.28031969@postgrespro.ru", "phone": "+70853028049"}
0005433986292	842BD5	5081 275686	ELENA RODIONOVA	{"email": "e-rodionova.121967@postgrespro.ru", "phone": "+70189311656"}
0005433986293	842BD5	9323 078829	VASILIY ISAEV	{"email": "vasiliy-isaev-1966@postgrespro.ru", "phone": "+70174026630"}
0005433986294	29696F	2985 806738	TATYANA KISELEVA	{"phone": "+70291354960"}
0005433986295	092D6C	3892 750119	LIDIYA EFIMOVA	{"email": "efimova.lidiya_1980@postgrespro.ru", "phone": "+70875476199"}
0005433986296	092D6C	4898 339574	NIKOLAY SOLOVEV	{"phone": "+70291288298"}
0005433986297	6607F2	1908 617388	GALINA MAKAROVA	{"phone": "+70530120853"}
0005433986298	055816	0541 571948	EVGENIY SERGEEV	{"email": "esergeev.1968@postgrespro.ru", "phone": "+70567645681"}
0005433986299	055816	3628 233606	ANTONINA MOISEEVA	{"email": "antonina-moiseeva1971@postgrespro.ru", "phone": "+70784399777"}
0005433986300	055816	4888 014149	MARIYA FROLOVA	{"email": "frolova_m.1975@postgrespro.ru", "phone": "+70951724965"}
0005433986301	52E290	6314 614064	LARISA MARTYNOVA	{"email": "martynova-l-1964@postgrespro.ru", "phone": "+70250158338"}
0005433986302	B42678	5341 681965	NATALYA KOROLEVA	{"email": "koroleva-n-111977@postgrespro.ru", "phone": "+70197659314"}
0005433986303	182208	8634 135813	LYUBOV ZAKHAROVA	{"email": "zakharova_lyubov-1970@postgrespro.ru", "phone": "+70506048616"}
0005433986304	604027	1161 272468	OLGA SAVELEVA	{"email": "saveleva.o_1973@postgrespro.ru", "phone": "+70730342635"}
0005433986305	89BA75	7788 426574	SERGEY MATVEEV	{"email": "sergey_matveev101971@postgrespro.ru", "phone": "+70563838786"}
0005433986306	3C0917	3235 684037	LYUBOV VLASOVA	{"email": "vlasova.lyubov.07011971@postgrespro.ru", "phone": "+70560947093"}
0005433986307	8F6CCF	0939 864530	ALEKSEY MOROZOV	{"email": "morozova1981@postgrespro.ru", "phone": "+70082920387"}
0005433986308	8F6CCF	4018 998846	ALENA MATVEEVA	{"phone": "+70677170583"}
0005433986309	1A8A0C	1332 984295	ALEKSEY KRASNOV	{"phone": "+70077005969"}
0005433986310	63973A	7968 698178	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr111972@postgrespro.ru", "phone": "+70445509410"}
0005433986311	63973A	8335 878342	KSENIYA KOZLOVA	{"email": "kseniyakozlova021974@postgrespro.ru", "phone": "+70899508746"}
0005433986312	CD2AE1	6011 736533	EKATERINA RYABOVA	{"email": "e_ryabova.1973@postgrespro.ru", "phone": "+70939298869"}
0005433986314	3A8AF8	5356 199261	EKATERINA GORBUNOVA	{"phone": "+70192537956"}
0005433986315	E8FA37	3468 559233	ROMAN PETROV	{"phone": "+70303102558"}
0005433986316	A2B38F	5271 865447	OLGA TARASOVA	{"phone": "+70553486022"}
0005433986429	46226D	4524 636477	LYUDMILA ABRAMOVA	{"phone": "+70302776340"}
0005433986317	A2B38F	5174 978309	DANIIL KULIKOV	{"email": "kulikovd_121963@postgrespro.ru", "phone": "+70236385036"}
0005433986318	A2B38F	1449 236520	DMITRIY PAVLOV	{"email": "pavlov_dmitriy_1980@postgrespro.ru", "phone": "+70109101083"}
0005433986319	757991	6041 619564	ANDREY IVANOV	{"phone": "+70108097976"}
0005433986320	6EDDC6	6868 905591	OKSANA SEMENOVA	{"phone": "+70399615608"}
0005433986321	6EDDC6	0445 348324	IRINA SCHERBAKOVA	{"email": "scherbakova_irina-121970@postgrespro.ru", "phone": "+70243048132"}
0005433986322	EBA4D2	4857 555197	ELENA MOISEEVA	{"email": "elena.moiseeva-1991@postgrespro.ru", "phone": "+70117482135"}
0005433986323	0BDD11	2768 355046	GALINA POPOVA	{"email": "g.popova_021966@postgrespro.ru", "phone": "+70865791068"}
0005433986324	E0B5E3	1981 915045	STANISLAV GAVRILOV	{"phone": "+70930426241"}
0005433986325	3DB215	9744 045191	VLADIMIR ALEKSEEV	{"email": "alekseev-vladimir-1973@postgrespro.ru", "phone": "+70880644094"}
0005433986326	AB196D	5430 007954	NATALYA MEDVEDEVA	{"email": "medvedevan-091969@postgrespro.ru", "phone": "+70363396692"}
0005433986327	FE5D4D	5674 767133	KRISTINA ANTONOVA	{"email": "antonovak.09051970@postgrespro.ru", "phone": "+70790198672"}
0005433986328	FE5D4D	0657 442928	MIKHAIL VOLKOV	{"phone": "+70898241440"}
0005433986329	042B22	9512 889585	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev_031966@postgrespro.ru", "phone": "+70633495278"}
0005433986330	914B3C	7647 581470	LYUDMILA ZAKHAROVA	{"phone": "+70967935361"}
0005433986331	BB2E37	1587 681098	LYUDMILA POPOVA	{"phone": "+70900564654"}
0005433986332	7D715E	8848 376152	MARINA BARANOVA	{"email": "marina-baranova1978@postgrespro.ru", "phone": "+70867886002"}
0005433986333	7D715E	4791 615558	SVETLANA IVANOVA	{"email": "ivanova.s17071981@postgrespro.ru", "phone": "+70541956367"}
0005433986334	C665AD	0679 603694	VITALIY GUSEV	{"email": "gusev-v031971@postgrespro.ru", "phone": "+70710933702"}
0005433986335	C665AD	8194 283121	NIKITA FEDOROV	{"email": "nikita.fedorov.05011959@postgrespro.ru", "phone": "+70807463784"}
0005433986336	CA35D2	5396 540882	MARIYA ILINA	{"phone": "+70473225452"}
0005433986337	9B635B	5467 941284	DARYA FOMINA	{"email": "fomina-d1976@postgrespro.ru", "phone": "+70310601704"}
0005433986338	97DC95	2302 381658	GRIGORIY FROLOV	{"email": "grigoriyfrolov_1982@postgrespro.ru", "phone": "+70932759192"}
0005433986339	040675	6572 245282	MARGARITA SOKOLOVA	{"phone": "+70694247480"}
0005433986340	258172	7325 172521	IRINA LAZAREVA	{"phone": "+70455025027"}
0005433986341	258172	4108 899344	ANDREY SOKOLOV	{"email": "a_sokolov_13071979@postgrespro.ru", "phone": "+70601421115"}
0005433986342	9F86AF	1807 633199	ANTONINA MIKHAYLOVA	{"phone": "+70507400188"}
0005433986343	D7AAC9	3729 356799	DANIIL ABRAMOV	{"email": "daniilabramov-011969@postgrespro.ru", "phone": "+70494658666"}
0005433986344	D7AAC9	8364 302588	SVETLANA ABRAMOVA	{"email": "abramova_s.24011987@postgrespro.ru", "phone": "+70563526286"}
0005433986345	D12500	0628 441873	EKATERINA BARANOVA	{"phone": "+70475353105"}
0005433986346	2E4555	9713 677740	ALEKSANDR KOZLOV	{"phone": "+70332643098"}
0005433986347	2E4555	1696 876855	SERGEY NIKITIN	{"email": "s_nikitin_1962@postgrespro.ru", "phone": "+70257680772"}
0005433986348	3572E0	9735 092917	LYUDMILA TROFIMOVA	{"phone": "+70418117934"}
0005433986349	212E7D	1303 742300	ANASTASIYA VASILEVA	{"phone": "+70970201781"}
0005433986350	CB08D6	3866 115064	VALERIY MELNIKOV	{"phone": "+70586442164"}
0005433986351	7DB5D1	7045 386321	DMITRIY NIKITIN	{"email": "dmitriy.nikitin.101971@postgrespro.ru", "phone": "+70595828445"}
0005433986352	7DB5D1	0513 528088	VALENTINA STEPANOVA	{"email": "stepanova_v-1967@postgrespro.ru", "phone": "+70055280977"}
0005433986353	7DB5D1	7106 571843	PRASKOVYA AFANASEVA	{"email": "afanaseva.p_09021976@postgrespro.ru", "phone": "+70717406248"}
0005433986354	1CC307	1704 332063	VLADIMIR STEPANOV	{"phone": "+70288425477"}
0005433986355	1CC307	6882 938591	ANNA KUZNECOVA	{"email": "annakuznecova.1978@postgrespro.ru", "phone": "+70809354946"}
0005433986356	5D1F81	7079 162101	ILYA POPOV	{"phone": "+70518131151"}
0005433986357	5E6436	1269 417435	ELENA ALEKSEEVA	{"email": "elenaalekseeva03121975@postgrespro.ru", "phone": "+70452064910"}
0005433986358	208974	0472 075631	ALLA FOMINA	{"phone": "+70919093455"}
0005433986359	4FBC48	7391 213265	ELENA FROLOVA	{"phone": "+70152999493"}
0005433986360	86C7C0	2299 140696	VYACHESLAV IVANOV	{"email": "vyacheslav.ivanov_051972@postgrespro.ru", "phone": "+70361262966"}
0005433986361	AE31E8	3430 878094	ALEKSANDR BELOV	{"email": "belov-aleksandr_1966@postgrespro.ru", "phone": "+70159557414"}
0005433986362	82011D	0787 754462	ANDREY KUZNECOV	{"email": "kuznecovandrey-071964@postgrespro.ru", "phone": "+70737903557"}
0005433986363	838EA5	4723 736850	BORIS SIDOROV	{"phone": "+70392520362"}
0005433986364	838EA5	0010 661460	ALEKSANDR YAKOVLEV	{"phone": "+70054658902"}
0005433986365	7CED69	6922 922928	DARYA FEDOROVA	{"email": "d-fedorova_1966@postgrespro.ru", "phone": "+70026856419"}
0005433986366	7CED69	7437 795214	DMITRIY VASILEV	{"email": "dmitriy_vasilev-1969@postgrespro.ru", "phone": "+70363796727"}
0005433986367	13BFF2	9947 076354	DMITRIY KRASNOV	{"phone": "+70386590287"}
0005433986368	513E9E	4130 675331	ANASTASIYA NAUMOVA	{"phone": "+70688980622"}
0005433986369	1C62B0	6335 443037	DANIS ZAKHAROV	{"email": "zakharov_danis031966@postgrespro.ru", "phone": "+70342113500"}
0005433986370	C77FDF	9358 250559	NATALYA ZAYCEVA	{"email": "zayceva_natalya1970@postgrespro.ru", "phone": "+70819494112"}
0005433986371	C77FDF	9669 127256	NIKOLAY NIKOLAEV	{"phone": "+70490296122"}
0005433986372	7B29EB	1242 207745	ELENA NOVIKOVA	{"phone": "+70977228620"}
0005433986373	F0003B	2095 064595	GALINA ZHUKOVA	{"email": "zhukova_galina_01051968@postgrespro.ru", "phone": "+70827255958"}
0005433986374	D92242	5972 430418	ALEKSEY RODIONOV	{"phone": "+70021120071"}
0005433986375	2BC5F0	6891 906241	VASILIY MOISEEV	{"phone": "+70637513632"}
0005433986376	2BC5F0	4197 997656	DMITRIY KUZNECOV	{"phone": "+70476116464"}
0005433986377	3B24AC	0041 178372	EKATERINA CHERNOVA	{"email": "chernova.ekaterina_071960@postgrespro.ru", "phone": "+70150919456"}
0005433986378	365077	6851 163764	VALERIY SERGEEV	{"email": "valeriy_sergeev-1964@postgrespro.ru", "phone": "+70527974401"}
0005433986379	8D1154	0247 764293	NADEZHDA POPOVA	{"phone": "+70765807811"}
0005433986380	72D9F9	8669 842827	ALEKSANDR GERASIMOV	{"phone": "+70886725953"}
0005433986381	A0D034	1724 331790	EGOR ZAYCEV	{"email": "zaycev.e.1975@postgrespro.ru", "phone": "+70287462100"}
0005433986382	A0D034	6964 174358	ROMAN SIDOROV	{"phone": "+70485184143"}
0005433986383	812E6E	2754 078080	NATALYA PETROVA	{"phone": "+70222034444"}
0005433986384	58C92A	4160 090623	TATYANA ROMANOVA	{"phone": "+70867904569"}
0005433986385	3A840E	9569 758668	VYACHESLAV DENISOV	{"email": "denisov-v1975@postgrespro.ru", "phone": "+70067810048"}
0005433986386	AA94FD	2925 025501	NIKITA KUZNECOV	{"phone": "+70950087741"}
0005433986387	42558E	2619 668726	ANDREY IVANOV	{"email": "a_ivanov.11011973@postgrespro.ru", "phone": "+70231085704"}
0005433986388	42558E	7641 511100	PETR KOZLOV	{"phone": "+70621404299"}
0005433986389	4F477E	4429 013640	ANDREY DMITRIEV	{"phone": "+70387665807"}
0005433986390	4F477E	3533 942715	NINA SEMENOVA	{"email": "n.semenova21101972@postgrespro.ru", "phone": "+70293998604"}
0005433986391	4F477E	6824 884130	VLADIMIR ALEKSEEV	{"phone": "+70162406421"}
0005433986392	DCF93D	4248 178118	VERA IVANOVA	{"phone": "+70375834764"}
0005433986393	DCF93D	8913 354359	LYUBOV MASLOVA	{"email": "maslova_l-011964@postgrespro.ru", "phone": "+70975307778"}
0005433986394	6FA3D5	6239 155766	EVGENIY ILIN	{"email": "ilin-evgeniy111967@postgrespro.ru", "phone": "+70188134732"}
0005433986395	00098F	8115 721627	VASILIY GUSEV	{"phone": "+70832488955"}
0005433986396	BDAA06	9738 747291	ANATOLIY GAVRILOV	{"email": "a.gavrilov.13121965@postgrespro.ru", "phone": "+70086454164"}
0005433986397	1F5746	1344 849607	EVGENIY AFANASEV	{"email": "evgeniy-afanasev_27061982@postgrespro.ru", "phone": "+70074533323"}
0005433986398	1F5746	2800 993650	FEDOR FROLOV	{"phone": "+70011611328"}
0005433986399	E84D2F	3449 609887	MIKHAIL KISELEV	{"email": "m_kiselev-071963@postgrespro.ru", "phone": "+70936195225"}
0005433986400	F2E7FD	5859 386775	LIDIYA FOMINA	{"email": "fominalidiya_011970@postgrespro.ru", "phone": "+70618948010"}
0005433986401	F2E7FD	4338 183533	ELENA EGOROVA	{"email": "egorova-e-101972@postgrespro.ru", "phone": "+70012524959"}
0005433986402	8394B8	2789 689182	OLEG KOZLOV	{"phone": "+70284742866"}
0005433986403	8394B8	5418 661026	GALINA VLASOVA	{"email": "vlasova-g121978@postgrespro.ru", "phone": "+70226397068"}
0005433986404	6C76A6	0354 696551	DARYA OSIPOVA	{"phone": "+70816263070"}
0005433986405	5EB494	9519 345756	ALEKSANDR ILIN	{"email": "aleksandr.ilin.1982@postgrespro.ru", "phone": "+70053607660"}
0005433986406	FCA45E	0879 105643	NINA EGOROVA	{"phone": "+70627926168"}
0005433986407	FCA45E	0475 963539	IRINA KUZNECOVA	{"phone": "+70281225576"}
0005433986408	FCA45E	2533 277787	MARINA KISELEVA	{"phone": "+70029166035"}
0005433986409	C72E9C	5760 294616	GALINA KOZLOVA	{"phone": "+70202496982"}
0005433986410	85CD8B	8126 498852	EKATERINA ROMANOVA	{"email": "ekaterina.romanova.15101973@postgrespro.ru", "phone": "+70457752345"}
0005433986411	23352A	9499 821708	YULIYA MIKHAYLOVA	{"phone": "+70448776587"}
0005433986412	23352A	3318 600935	VYACHESLAV ILIN	{"email": "ilin-vyacheslav.04011980@postgrespro.ru", "phone": "+70104922194"}
0005433986413	70B472	1781 631201	NADEZHDA MOROZOVA	{"phone": "+70750641703"}
0005433986414	B15A83	6830 585238	STEPAN KAZAKOV	{"email": "s.kazakov1973@postgrespro.ru", "phone": "+70985489231"}
0005433986415	FCC3BF	7522 964502	ILYAS ILIN	{"phone": "+70234009154"}
0005433986416	FCC3BF	1706 796124	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey_1986@postgrespro.ru", "phone": "+70915778808"}
0005433986417	6F6A7F	7170 803226	TATYANA ILINA	{"phone": "+70197660959"}
0005433986418	6F6A7F	4547 844713	NADEZHDA MEDVEDEVA	{"phone": "+70040224926"}
0005433986419	52856B	5415 185658	EVGENIY ORLOV	{"email": "evgeniy.orlov-1966@postgrespro.ru", "phone": "+70995438318"}
0005433986420	D9A699	1603 448196	GALINA KUZMINA	{"email": "kuzminag-101974@postgrespro.ru", "phone": "+70167722077"}
0005433986421	B0FC68	7759 694532	TAMARA ZHURAVLEVA	{"email": "tamara-zhuravleva-041971@postgrespro.ru", "phone": "+70152754146"}
0005433986422	3A2901	8925 234806	EKATERINA POLYAKOVA	{"phone": "+70076598962"}
0005433986423	725582	9381 952035	YULIYA ALEKSANDROVA	{"email": "y.aleksandrova06081969@postgrespro.ru", "phone": "+70896694611"}
0005433986424	725582	1065 819774	ROZALIYA ALEKSEEVA	{"email": "alekseeva-r.07081969@postgrespro.ru", "phone": "+70693682913"}
0005433986425	ED527B	7283 424765	MAKSIM KOZLOV	{"email": "m-kozlov-101970@postgrespro.ru", "phone": "+70472910053"}
0005433986426	1F75F0	7635 193172	IRINA GUSEVA	{"email": "gusevai-19021968@postgrespro.ru", "phone": "+70083581985"}
0005433986427	6E2D08	6228 224446	EGOR FILIPPOV	{"email": "egorfilippov.20111968@postgrespro.ru", "phone": "+70495940441"}
0005433986428	2B6180	7641 126139	YURIY SERGEEV	{"phone": "+70942354459"}
0005433986430	007C00	8234 227927	SERGEY NIKOLAEV	{"email": "nikolaev_s-1965@postgrespro.ru", "phone": "+70747664178"}
0005433986431	9652BE	6027 122228	NADEZHDA ORLOVA	{"email": "orlovanadezhda-1966@postgrespro.ru", "phone": "+70847792913"}
0005433986432	9652BE	4436 520574	FEDOR SMIRNOV	{"phone": "+70698222193"}
0005433986433	2E22E3	9823 617394	ANASTASIYA BELOVA	{"phone": "+70316987197"}
0005433986434	54DE73	9579 455597	ALEKSANDR BELOV	{"phone": "+70562715214"}
0005433986435	54DE73	6233 565923	YURIY RODIONOV	{"email": "yrodionov-18021983@postgrespro.ru", "phone": "+70519208681"}
0005433986436	A6E580	9428 734523	OLEG VOLKOV	{"phone": "+70061048061"}
0005433986437	770CD2	1573 678194	LYUBOV SMIRNOVA	{"phone": "+70981600718"}
0005433986438	770CD2	1748 104561	SERGEY SEMENOV	{"email": "semenov_s04081970@postgrespro.ru", "phone": "+70273228985"}
0005433986439	DEC328	6420 378574	ADELINA MEDVEDEVA	{"email": "medvedevaadelina.1968@postgrespro.ru", "phone": "+70623811568"}
0005433986440	DEC328	3812 111519	ALEKSANDR GUSEV	{"phone": "+70001726909"}
0005433986441	6B4519	1425 629308	NIKOLAY KONOVALOV	{"phone": "+70295683620"}
0005433986442	7E9C97	1707 370769	YAROSLAV FROLOV	{"email": "frolov_y081977@postgrespro.ru", "phone": "+70328687719"}
0005433986443	D6170F	4653 349168	ALEKSANDR PAVLOV	{"email": "a_pavlov08011970@postgrespro.ru", "phone": "+70086556722"}
0005433986444	D6170F	6121 880768	SERGEY STEPANOV	{"email": "sstepanov1970@postgrespro.ru", "phone": "+70271598502"}
0005433986445	D98C5F	9345 512007	OLGA AFANASEVA	{"phone": "+70594134078"}
0005433986446	64A583	5063 984818	IVAN TIKHONOV	{"phone": "+70376823352"}
0005433986447	64A583	8197 537454	MARYAM TIMOFEEVA	{"email": "m.timofeeva-1979@postgrespro.ru", "phone": "+70310319475"}
0005433986448	C8D0B5	2812 637473	ANATOLIY KOZLOV	{"phone": "+70909059594"}
0005433986449	C8D0B5	2384 612149	KIRILL IVANOV	{"email": "ivanov-kirill.1965@postgrespro.ru", "phone": "+70561061913"}
0005433986450	7DA089	7371 780741	PETR BELOV	{"email": "p-belov.03091969@postgrespro.ru", "phone": "+70126160464"}
0005433986451	3C58C8	6730 571878	LARISA MELNIKOVA	{"email": "melnikova.l021969@postgrespro.ru", "phone": "+70337954790"}
0005433986452	3C58C8	7396 155231	NIKOLAY ZHURAVLEV	{"email": "zhuravlev-n_1975@postgrespro.ru", "phone": "+70418074930"}
0005433986453	B3CEB3	9360 156477	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko12011978@postgrespro.ru", "phone": "+70482789735"}
0005433986454	B3CEB3	9753 746901	ALEKSANDR ISAEV	{"email": "aleksandr.isaev_16051975@postgrespro.ru", "phone": "+70003569591"}
0005433986455	C93448	6629 984248	MARINA NESTEROVA	{"email": "m_nesterova.041968@postgrespro.ru", "phone": "+70103212746"}
0005433986456	300B53	6618 487056	LIDIYA LEBEDEVA	{"email": "llebedeva081972@postgrespro.ru", "phone": "+70409951831"}
0005433986457	300B53	9154 200275	VERONIKA SOROKINA	{"phone": "+70531800253"}
0005433986458	DB35CF	2067 132047	NATALYA ZAKHAROVA	{"phone": "+70899221715"}
0005433986459	B0C488	7337 485364	DIANA ERMAKOVA	{"phone": "+70821380432"}
0005433986460	9EAC4D	6370 635781	TATYANA FILIPPOVA	{"email": "filippova_t_03121975@postgrespro.ru", "phone": "+70724898309"}
0005433986461	21F047	5243 006746	VLADIMIR IVANOV	{"email": "ivanov-vladimir-091960@postgrespro.ru", "phone": "+70761840194"}
0005433986462	59A1CB	3227 788101	ANATOLIY ZAKHAROV	{"email": "zakharov-anatoliy-121984@postgrespro.ru", "phone": "+70151188095"}
0005433986463	59A1CB	4725 506206	YULIYA DMITRIEVA	{"email": "y.dmitrieva_13021969@postgrespro.ru", "phone": "+70249053524"}
0005433986464	8648F0	2529 453451	MIKHAIL MELNIKOV	{"phone": "+70697803242"}
0005433986465	8648F0	8866 876686	ANATOLIY FOMIN	{"phone": "+70817866457"}
0005433986466	8F8999	5333 275236	OLGA NOVIKOVA	{"email": "novikova-olga_1978@postgrespro.ru", "phone": "+70531284952"}
0005433986467	B60083	4667 458155	NATALYA ILINA	{"email": "nilina-1967@postgrespro.ru", "phone": "+70936223818"}
0005433986468	CDD800	8446 597463	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev-071967@postgrespro.ru", "phone": "+70844298129"}
0005433986469	8F0615	6292 600297	SERGEY ISAEV	{"phone": "+70583474490"}
0005433986470	3C1802	2297 971770	NADEZHDA ABRAMOVA	{"email": "nadezhda.abramova_091979@postgrespro.ru", "phone": "+70401635576"}
0005433986471	0A6282	0119 905463	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev_121981@postgrespro.ru", "phone": "+70550744601"}
0005433986472	A714C8	7484 075931	RAMAZAN KOZLOV	{"email": "kozlovramazan05011978@postgrespro.ru", "phone": "+70062345339"}
0005433986473	A714C8	7670 847273	GALINA ROMANOVA	{"phone": "+70831775083"}
0005433986474	C2B805	8444 348915	GRIGORIY MELNIKOV	{"email": "melnikov-grigoriy30101980@postgrespro.ru", "phone": "+70447528687"}
0005433986475	C2B805	8497 542298	MARIYA MASLOVA	{"phone": "+70135267582"}
0005433986476	0DCCA4	6844 399206	LIDIYA KARPOVA	{"email": "karpova.l-101971@postgrespro.ru", "phone": "+70407801425"}
0005433986477	0DCCA4	9244 271764	MAKSIM IVANOV	{"email": "ivanov-m-03101963@postgrespro.ru", "phone": "+70092505044"}
0005433986478	0DCCA4	6377 328081	EVGENIY VOROBEV	{"email": "e-vorobev.101955@postgrespro.ru", "phone": "+70462309294"}
0005433986479	C4E81A	6624 764217	ALEKSANDR DMITRIEV	{"phone": "+70929189737"}
0005433986480	793E99	8765 704610	RUSLAN ILIN	{"phone": "+70468023233"}
0005433986481	37C772	5122 853841	VIKTOR ZAKHAROV	{"email": "zakharov-viktor29041973@postgrespro.ru", "phone": "+70538774139"}
0005433986482	37C772	9311 986036	SVETLANA POPOVA	{"email": "svetlana.popova_041974@postgrespro.ru", "phone": "+70354382840"}
0005433986483	7FAA71	6155 839974	ANTONINA MOROZOVA	{"email": "antoninamorozova_1987@postgrespro.ru", "phone": "+70327618689"}
0005433986484	358C02	3077 553891	SERGEY MAKAROV	{"email": "makarovsergey051970@postgrespro.ru", "phone": "+70621874628"}
0005433986485	AB598F	8279 551759	TAMARA MALYSHEVA	{"phone": "+70936090238"}
0005433986486	550B89	5935 635665	MARIYA GORBUNOVA	{"phone": "+70932016513"}
0005433986487	550B89	6273 023756	NATALYA NIKOLAEVA	{"email": "nikolaeva.n25031979@postgrespro.ru", "phone": "+70396326230"}
0005433986488	4D7C0B	3156 239635	ANDREY ABRAMOV	{"phone": "+70140324236"}
0005433986489	4D7C0B	0694 087892	OLEG PAVLOV	{"email": "o_pavlov.1972@postgrespro.ru", "phone": "+70867959365"}
0005433986490	CF62A9	5819 099412	VALENTINA VASILEVA	{"phone": "+70405055859"}
0005433986491	A215A6	2359 470753	VALENTINA PETROVA	{"email": "petrova-v.051971@postgrespro.ru", "phone": "+70655769868"}
0005433986492	A1B47E	5930 887788	EVGENIY VASILEV	{"phone": "+70028398433"}
0005433986493	A1B47E	4816 071428	EVGENIYA GAVRILOVA	{"email": "gavrilova.e.051967@postgrespro.ru", "phone": "+70583196485"}
0005433986494	A1B47E	0489 094968	DMITRIY GAVRILOV	{"phone": "+70166300808"}
0005433986495	AD77DA	1663 101353	YURIY ROMANOV	{"phone": "+70787906327"}
0005433986496	AD77DA	9075 929973	ALEKSANDR PAVLOV	{"phone": "+70271708106"}
0005433986497	AD77DA	1271 287084	ALENA KARPOVA	{"phone": "+70173076438"}
0005433986498	AD77DA	5535 284060	NIKITA SEMENOV	{"email": "semenovnikita_101972@postgrespro.ru", "phone": "+70119878531"}
0005433986499	D9CD27	6655 101183	ANDREY SIDOROV	{"phone": "+70876513140"}
0005433986500	67E027	9309 039729	ANATOLIY PAVLOV	{"phone": "+70051632300"}
0005433986501	67E027	4711 785271	VLADIMIR TARASOV	{"email": "tarasov-v.051978@postgrespro.ru", "phone": "+70022275558"}
0005433986502	AA6B6A	8850 521817	TATYANA ALEKSEEVA	{"email": "alekseeva_t-081968@postgrespro.ru", "phone": "+70670482540"}
0005433986503	844C5D	8085 603659	SERGEY ROMANOV	{"phone": "+70138961953"}
0005433986504	1DD6F3	6719 951115	NATALIYA NIKIFOROVA	{"email": "nikiforova.nataliya_1965@postgrespro.ru", "phone": "+70502760184"}
0005433986505	1DD6F3	3387 078500	IGOR SOKOLOV	{"phone": "+70336513086"}
0005433986506	3EBD0C	8779 256886	VALENTINA NIKOLAEVA	{"email": "nikolaeva_v.30111972@postgrespro.ru", "phone": "+70104258755"}
0005433986507	3EBD0C	8996 210342	MARINA KALININA	{"phone": "+70480502657"}
0005433986508	E1DFE3	8360 965246	VALENTINA NOVIKOVA	{"phone": "+70546527414"}
0005433986509	CB9F25	0824 256966	EVGENIY ILIN	{"phone": "+70394415317"}
0005433986510	CB9F25	8304 096693	ALEKSANDR FEDOROV	{"phone": "+70728273091"}
0005433986511	C47310	6329 988346	RUSTYAM BORISOV	{"email": "rustyam.borisov-1971@postgrespro.ru", "phone": "+70608378999"}
0005433986512	C47310	0290 453567	EKATERINA PETROVA	{"phone": "+70783785412"}
0005433986513	C50229	3949 309677	EKATERINA ISAEVA	{"email": "ekaterina-isaeva_23031975@postgrespro.ru", "phone": "+70358564662"}
0005433986514	8D2B34	1461 413610	ELENA SERGEEVA	{"phone": "+70513357890"}
0005433986515	90F16B	5714 020714	SERGEY ORLOV	{"phone": "+70749643616"}
0005433986516	3636C1	1738 451517	PAVEL CHERNOV	{"phone": "+70549825024"}
0005433986517	3636C1	3776 176751	TATYANA LOGINOVA	{"email": "loginova_tatyana-081977@postgrespro.ru", "phone": "+70034987122"}
0005433986518	3636C1	2461 445264	ELLA EGOROVA	{"email": "e-egorova11021978@postgrespro.ru", "phone": "+70814462695"}
0005433986519	465696	9464 014452	DENIS NAZAROV	{"email": "nazarov_denis_1970@postgrespro.ru", "phone": "+70632824902"}
0005433986520	9FD68D	1253 457479	EVGENIYA NIKITINA	{"phone": "+70210060251"}
0005433986521	9FD68D	5462 480633	LYUDMILA EFIMOVA	{"email": "efimova.lyudmila-031970@postgrespro.ru", "phone": "+70884552787"}
0005433986522	2D7996	4780 260523	VIKTOR KAZAKOV	{"email": "v_kazakov-051974@postgrespro.ru", "phone": "+70804986740"}
0005433986523	7746F7	0609 003471	VALENTINA MALYSHEVA	{"email": "valentinamalysheva011970@postgrespro.ru", "phone": "+70068763718"}
0005433986524	5F447A	4137 320153	NINA POPOVA	{"email": "n_popova-19051973@postgrespro.ru", "phone": "+70842539406"}
0005433986525	EF0404	6698 061256	EVGENIY EGOROV	{"email": "evgeniy_egorov.061978@postgrespro.ru", "phone": "+70006118085"}
0005433986526	D43730	8903 442022	VALENTINA FEDOROVA	{"email": "fedorova_valentina.011978@postgrespro.ru", "phone": "+70025650241"}
0005433986527	FF61BB	0021 060048	BOGDAN TARASOV	{"email": "bogdan.tarasov-12061966@postgrespro.ru", "phone": "+70390353486"}
0005433986528	720CE0	5568 777030	NINA IVANOVA	{"phone": "+70885001462"}
0005433986529	720CE0	3852 906630	ALEKSANDR ALEKSEEV	{"phone": "+70300894501"}
0005433986530	720CE0	0950 924300	NATALYA KOROLEVA	{"phone": "+70253950087"}
0005433986531	720CE0	2549 248027	IVAN NIKOLAEV	{"email": "i-nikolaev10061977@postgrespro.ru", "phone": "+70692965236"}
0005433986532	8840AC	7374 815233	ELENA KUZNECOVA	{"email": "e.kuznecova_1969@postgrespro.ru", "phone": "+70450472985"}
0005433986533	87AF24	2012 849986	ALEKSANDRA KUZNECOVA	{"phone": "+70775207360"}
0005433986534	87AF24	0889 079331	ANDREY POPOV	{"email": "popova-071973@postgrespro.ru", "phone": "+70913276537"}
0005433986535	71B735	5710 696984	MARINA GERASIMOVA	{"email": "mgerasimova_121972@postgrespro.ru", "phone": "+70748131865"}
0005433986536	4B0C82	4695 897129	NINA GUSEVA	{"phone": "+70685385154"}
0005433986537	4B0C82	9567 825164	PAVEL FEDOROV	{"phone": "+70517740046"}
0005433986538	027795	2976 902613	LYUBOV MIRONOVA	{"phone": "+70117991554"}
0005433986539	DE70ED	8362 919606	ANTON KUZNECOV	{"email": "kuznecov_anton.1982@postgrespro.ru", "phone": "+70336299525"}
0005433986540	DE70ED	2050 506280	NINA BELYAEVA	{"email": "nina_belyaeva.1969@postgrespro.ru", "phone": "+70709507118"}
0005433986541	A0FD6B	1357 189360	SERGEY SHEVCHENKO	{"email": "sergey.shevchenko_1970@postgrespro.ru", "phone": "+70894461440"}
0005433986542	B9BDB7	5781 308908	TATYANA NOVIKOVA	{"phone": "+70106968123"}
0005433986543	E2C851	0850 674376	OLGA VOLKOVA	{"email": "o-volkova_091975@postgrespro.ru", "phone": "+70690240760"}
0005433986544	FE9084	1158 686364	IRINA KAZAKOVA	{"email": "irina-kazakova-081967@postgrespro.ru", "phone": "+70107850423"}
0005433986545	FE9084	3151 494216	YULIYA MOROZOVA	{"email": "morozova-yuliya-1968@postgrespro.ru", "phone": "+70216017313"}
0005433986546	C1249D	7717 839435	SERGEY BARANOV	{"phone": "+70749682188"}
0005433986547	9471BC	0184 474499	NIKOLAY STEPANOV	{"email": "stepanovn04101962@postgrespro.ru", "phone": "+70720247299"}
0005433986548	0F2C41	2362 714439	TATYANA ALEKSANDROVA	{"phone": "+70753885047"}
0005433986549	8F371F	6493 155825	ALLA GERASIMOVA	{"phone": "+70493780964"}
0005433986550	8F371F	9702 274916	PETR MARTYNOV	{"email": "martynovpetr1971@postgrespro.ru", "phone": "+70510146562"}
0005433986551	61E054	2601 563477	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya091959@postgrespro.ru", "phone": "+70187170988"}
0005433986552	4FFC4E	8263 904568	ALEKSANDR PAVLOV	{"email": "pavlov.a1979@postgrespro.ru", "phone": "+70934084361"}
0005433986553	023429	6517 722578	FEDOR KUZNECOV	{"email": "kuznecov_fedor.091964@postgrespro.ru", "phone": "+70462649821"}
0005433986554	C3CF0F	7962 630411	ALEKSANDR PETROV	{"email": "apetrov.031968@postgrespro.ru", "phone": "+70947400867"}
0005433986555	C3CF0F	6534 008481	YAROSLAV KUZNECOV	{"email": "yaroslav-kuznecov.041976@postgrespro.ru", "phone": "+70187182641"}
0005433986556	72CDD7	9881 109001	MARIYA RODIONOVA	{"email": "rodionovam15011986@postgrespro.ru", "phone": "+70315399514"}
0005433986557	4058DF	3499 378303	ANDREY NOVIKOV	{"email": "a-novikov-18071982@postgrespro.ru", "phone": "+70953118809"}
0005433986558	0FE5CB	1965 419790	ALEKSANDR MEDVEDEV	{"email": "a_medvedev.081973@postgrespro.ru", "phone": "+70680813201"}
0005433986559	0FE5CB	2931 847644	ANATOLIY MOROZOV	{"phone": "+70001144745"}
0005433986560	8D77A5	3707 255871	YULIYA ROMANOVA	{"phone": "+70175268180"}
0005433986561	8D77A5	0300 728189	ALEKSEY KRASNOV	{"email": "aleksey.krasnov-14021967@postgrespro.ru", "phone": "+70226139718"}
0005433986562	8D77A5	2917 468229	NATALYA NESTEROVA	{"email": "natalyanesterova_23061971@postgrespro.ru", "phone": "+70209917333"}
0005433986563	4E7F8A	4685 592452	RAISA PAVLOVA	{"email": "raisa.pavlova091971@postgrespro.ru", "phone": "+70564198044"}
0005433986564	4E7F8A	1374 292120	KIRILL SMIRNOV	{"phone": "+70924273489"}
0005433986565	4E7F8A	9958 747472	NIKOLAY EGOROV	{"phone": "+70899328440"}
0005433986566	53CE72	7649 001231	LYUDMILA ANISIMOVA	{"email": "anisimova.l051973@postgrespro.ru", "phone": "+70385186106"}
0005433986567	1EB4A1	3341 051843	IRINA KULIKOVA	{"phone": "+70055704924"}
0005433986568	1EB4A1	5498 400367	ALEKSANDR TIMOFEEV	{"phone": "+70632976244"}
0005433986569	520371	9475 863980	LYUBOV BOGDANOVA	{"phone": "+70341614748"}
0005433986570	520371	3805 353695	LARISA ABRAMOVA	{"email": "l_abramova_1969@postgrespro.ru", "phone": "+70035617915"}
0005433986571	520371	0065 410669	ALEKSANDR STEPANOV	{"phone": "+70241591843"}
0005433986572	3C7F04	6486 621606	ALEKSANDRA KONOVALOVA	{"phone": "+70150980895"}
0005433986573	3C7F04	0851 421716	TAMARA MOISEEVA	{"phone": "+70895869933"}
0005433986574	03EBA6	9969 761588	ZINAIDA ZAYCEVA	{"phone": "+70251707825"}
0005433986575	03EBA6	9082 034464	ALEKSEY GORBUNOV	{"email": "a.gorbunov04101958@postgrespro.ru", "phone": "+70703797651"}
0005433986576	03EBA6	2421 078255	FAIL POPOV	{"phone": "+70985201969"}
0005433986577	07262E	2270 804702	SERGEY ORLOV	{"email": "orlov_sergey_1977@postgrespro.ru", "phone": "+70191805017"}
0005433986578	07262E	0393 458157	LYUBOV MELNIKOVA	{"phone": "+70672842730"}
0005433986579	C339DA	8521 350019	VLADISLAV SIDOROV	{"phone": "+70490068778"}
0005433986580	C339DA	1113 410158	ELENA ROMANOVA	{"email": "romanova_e.081974@postgrespro.ru", "phone": "+70862157049"}
0005433986581	55842B	1074 823986	MIKHAIL FEDOROV	{"email": "mikhail_fedorov16081980@postgrespro.ru", "phone": "+70819644060"}
0005433986582	68B7C6	6226 673120	DMITRIY KISELEV	{"email": "dmitriy-kiselev.011980@postgrespro.ru", "phone": "+70807420532"}
0005433986583	65E2D3	4738 934816	OLGA TARASOVA	{"phone": "+70826618140"}
0005433986584	E7B5E1	7440 404141	ZHANNA GUSEVA	{"phone": "+70819969045"}
0005433986585	E7B5E1	7869 714336	MARIYA MAKAROVA	{"email": "mariyamakarova_1969@postgrespro.ru", "phone": "+70210818751"}
0005433986586	519B32	5687 054732	KSENIYA NESTEROVA	{"email": "nesterova-k.121971@postgrespro.ru", "phone": "+70914707256"}
0005433986587	519B32	3242 155992	ANNA SOLOVEVA	{"phone": "+70367310959"}
0005433986588	7EFA7A	0114 557901	IRINA ANDREEVA	{"email": "andreeva_i_1973@postgrespro.ru", "phone": "+70133630537"}
0005433986589	7EFA7A	0890 143650	RIMMA GORBUNOVA	{"email": "r_gorbunova101979@postgrespro.ru", "phone": "+70662148455"}
0005433986590	74459E	1346 805462	TAMARA VOLKOVA	{"email": "t_volkova031972@postgrespro.ru", "phone": "+70794087518"}
0005433986591	C94D9B	5115 984029	LYUBOV ORLOVA	{"phone": "+70890144522"}
0005433986592	C90AD0	0861 363757	ALEKSEY IVANOV	{"email": "ivanov_aleksey22121965@postgrespro.ru", "phone": "+70336254256"}
0005433986593	C90AD0	0322 892181	SVETLANA NIKITINA	{"phone": "+70591757435"}
0005433986594	1DF56A	2151 989645	VALERIY PETROV	{"email": "petrov.v-1960@postgrespro.ru", "phone": "+70363413304"}
0005433986595	1DF56A	3630 877900	TATYANA SERGEEVA	{"email": "sergeevat.05101977@postgrespro.ru", "phone": "+70193107293"}
0005433986652	DC3CC5	1738 919880	ALEKSANDR MARTYNOV	{"phone": "+70897244830"}
0005433986596	C34C17	3759 252313	OLGA KALININA	{"email": "olga_kalinina-1967@postgrespro.ru", "phone": "+70032170708"}
0005433986597	A4EAA9	6251 287394	NATALYA GAVRILOVA	{"email": "gavrilova-natalya_09031979@postgrespro.ru", "phone": "+70929871642"}
0005433986598	2316C8	6017 510634	ELENA VOROBEVA	{"phone": "+70139307696"}
0005433986599	BC9856	7690 849940	ELENA KULIKOVA	{"email": "e_kulikova_1972@postgrespro.ru", "phone": "+70582123867"}
0005433986600	C6BC95	5585 183981	ZOYA GORBUNOVA	{"phone": "+70254859104"}
0005433986601	7DAFF7	5549 813437	NATALYA KOZLOVA	{"email": "kozlova-n.121962@postgrespro.ru", "phone": "+70960164212"}
0005433986602	FF5470	8432 280907	DENIS GORBUNOV	{"phone": "+70097434192"}
0005433986603	AEF074	6366 806254	ANNA EFIMOVA	{"phone": "+70995475308"}
0005433986604	AEF074	5804 908710	DMITRIY SOLOVEV	{"email": "solovevd-041958@postgrespro.ru", "phone": "+70422087011"}
0005433986605	D6C5A2	7774 807551	RAISA DAVYDOVA	{"email": "davydova_raisa_1970@postgrespro.ru", "phone": "+70779239738"}
0005433986606	A6BB8E	6014 624273	ALINA GUSEVA	{"phone": "+70045595798"}
0005433986607	41F7D2	3608 200324	MARIYA KOZLOVA	{"email": "mkozlova.051970@postgrespro.ru", "phone": "+70079546579"}
0005433986608	658FA1	7945 739656	ILYA GRIGOREV	{"email": "grigorev-ilya_09011976@postgrespro.ru", "phone": "+70132374863"}
0005433986609	973F73	7324 476547	DIANA SMIRNOVA	{"phone": "+70409223364"}
0005433986610	973F73	6403 741649	MARGARITA DENISOVA	{"email": "denisova_m_18081971@postgrespro.ru", "phone": "+70992981786"}
0005433986611	AB8D26	9698 869815	ANNA KAZAKOVA	{"phone": "+70622373616"}
0005433986612	AB8D26	7545 803143	NINA SMIRNOVA	{"email": "smirnova_n091968@postgrespro.ru", "phone": "+70789749160"}
0005433986613	9CD4DD	4133 365904	MARIYA DAVYDOVA	{"email": "davydovam-02051975@postgrespro.ru", "phone": "+70041904298"}
0005433986614	1CBAB0	9545 628832	EKATERINA IVANOVA	{"phone": "+70872846197"}
0005433986615	EAEBC6	8891 072479	IRINA ZAKHAROVA	{"email": "irina_zakharova.071974@postgrespro.ru", "phone": "+70881503659"}
0005433986616	EAEBC6	0985 778378	ALEKSEY AFANASEV	{"email": "afanaseva.03071977@postgrespro.ru", "phone": "+70496956459"}
0005433986617	090F16	3303 918992	YULIYA NESTEROVA	{"phone": "+70022621447"}
0005433986618	090F16	5126 834451	TAMARA KAZAKOVA	{"phone": "+70844800690"}
0005433986619	0712F7	9727 226617	SERGEY ZHUKOV	{"phone": "+70545628127"}
0005433986620	ADE819	9662 234604	ALEKSANDR MOROZOV	{"phone": "+70909369114"}
0005433986621	ADE819	8960 957821	ANASTASIYA KAZAKOVA	{"email": "kazakova_a.051983@postgrespro.ru", "phone": "+70442603609"}
0005433986622	A71B8E	1352 780568	VYACHESLAV GRIGOREV	{"email": "grigorevvyacheslav-1975@postgrespro.ru", "phone": "+70070311085"}
0005433986623	FD35A0	7028 055718	VALENTINA ALEKSEEVA	{"email": "alekseeva_valentina-11071964@postgrespro.ru", "phone": "+70368196895"}
0005433986624	64DCF6	8221 952161	VIKTOR SOLOVEV	{"phone": "+70016381674"}
0005433986625	EE7715	1352 999617	DMITRIY ANTONOV	{"phone": "+70590811291"}
0005433986626	3E0256	0022 640726	MIKHAIL ANTONOV	{"email": "antonov-m-1964@postgrespro.ru", "phone": "+70861355846"}
0005433986627	3E0256	7578 405230	KSENIYA FEDOROVA	{"phone": "+70767458688"}
0005433986628	3E0256	3619 875313	LIDIYA TROFIMOVA	{"email": "l-trofimova021972@postgrespro.ru", "phone": "+70240597973"}
0005433986629	A77DA6	8118 774562	LIDIYA KOVALEVA	{"email": "lidiyakovaleva111979@postgrespro.ru", "phone": "+70716604990"}
0005433986630	BD604A	7575 311436	ANATOLIY MOROZOV	{"phone": "+70946390162"}
0005433986631	DCF7CC	3316 942328	ELENA VASILEVA	{"email": "vasileva-elena_05031962@postgrespro.ru", "phone": "+70649027562"}
0005433986632	501223	3085 871207	PAVEL KUZNECOV	{"email": "p.kuznecov.1976@postgrespro.ru", "phone": "+70922354646"}
0005433986633	C765A7	6210 051543	LEONID SMIRNOV	{"email": "smirnov_l1975@postgrespro.ru", "phone": "+70844236343"}
0005433986634	BDC4E5	4870 776846	VLADIMIR FEDOROV	{"phone": "+70151075166"}
0005433986635	14BF00	8551 847992	MIKHAIL PAVLOV	{"email": "mikhail_pavlov.1982@postgrespro.ru", "phone": "+70906618276"}
0005433986636	0C4B52	8459 206483	GENNADIY MEDVEDEV	{"phone": "+70280904806"}
0005433986637	BE5EEA	1760 988420	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov-31121976@postgrespro.ru", "phone": "+70112566856"}
0005433986638	C8608B	5668 128815	VLADISLAV KAZAKOV	{"email": "kazakov-v_011966@postgrespro.ru", "phone": "+70978409250"}
0005433986639	CA504F	6429 338867	OLGA SERGEEVA	{"email": "sergeevaolga.23041971@postgrespro.ru", "phone": "+70640071916"}
0005433986640	CFE29C	7369 017044	NATALYA PETROVA	{"phone": "+70457513454"}
0005433986641	C87BB9	7322 419508	VERA PETROVA	{"phone": "+70766771313"}
0005433986642	B9B96F	8846 165225	VLADIMIR NIKITIN	{"phone": "+70355939171"}
0005433986643	43116F	7319 237507	VIKTOR VOLKOV	{"phone": "+70352358488"}
0005433986644	BE354F	0612 942219	GALINA VOROBEVA	{"email": "galina-vorobeva-08091979@postgrespro.ru", "phone": "+70203924159"}
0005433986645	B9D3AA	8242 453507	LYUBOV MELNIKOVA	{"email": "melnikova.lyubov30121957@postgrespro.ru", "phone": "+70849633830"}
0005433986646	878075	6971 586108	OLESYA GERASIMOVA	{"email": "gerasimova.olesya-14041960@postgrespro.ru", "phone": "+70523207518"}
0005433986647	E14737	1833 783538	YULIYA DANILOVA	{"phone": "+70952324455"}
0005433986648	E14737	2709 686002	LYUBOV SOROKINA	{"phone": "+70541455711"}
0005433986649	854782	7636 784648	VASILIY EGOROV	{"phone": "+70847819752"}
0005433986650	854782	7698 428290	ELIZAVETA BELOVA	{"phone": "+70241281653"}
0005433986651	DC3CC5	5632 098911	TATYANA KAZAKOVA	{"email": "tatyanakazakova.091968@postgrespro.ru", "phone": "+70824977765"}
0005433986653	DEB361	6670 167545	EKATERINA SOROKINA	{"email": "sorokinae071973@postgrespro.ru", "phone": "+70939368505"}
0005433986654	F21EDF	3409 837269	ZOYA ILINA	{"email": "zoyailina-1965@postgrespro.ru", "phone": "+70111221996"}
0005433986655	2694C9	7704 848388	IVAN KUZMIN	{"email": "kuzmin_i.1983@postgrespro.ru", "phone": "+70853145665"}
0005433986656	7FD592	9731 215293	ANASTASIYA PAVLOVA	{"phone": "+70875087065"}
0005433986657	BBA005	9204 514020	TAMARA PETROVA	{"phone": "+70827645697"}
0005433986658	BBA005	1580 478859	VALERIY KISELEV	{"email": "valeriy.kiselev-051974@postgrespro.ru", "phone": "+70207949076"}
0005433986659	949484	8641 044561	DENIS TARASOV	{"email": "d-tarasov061976@postgrespro.ru", "phone": "+70965239350"}
0005433986660	F8451D	4638 127539	DENIS SMIRNOV	{"email": "smirnov-denis.29121975@postgrespro.ru", "phone": "+70964647861"}
0005433986661	F8451D	4864 282115	GALINA KUZMINA	{"email": "galina.kuzmina-121976@postgrespro.ru", "phone": "+70404361697"}
0005433986662	E1F52D	0836 317799	VIKTOR YAKOVLEV	{"phone": "+70745180439"}
0005433986663	E1F52D	9228 859677	DARYA VLASOVA	{"phone": "+70136185972"}
0005433986664	8AB338	9839 402525	LYUBOV YAKOVLEVA	{"email": "lyubov-yakovleva1980@postgrespro.ru", "phone": "+70971155044"}
0005433986665	8AB338	2273 237755	NIKOLAY IVANOV	{"phone": "+70959304542"}
0005433986666	7A30F7	7781 564456	ELENA KOZLOVA	{"email": "kozlova.e_12061966@postgrespro.ru", "phone": "+70169951898"}
0005433986667	B2B91A	0804 034176	ANTON VASILEV	{"phone": "+70790886487"}
0005433986668	F7538B	9348 709189	ANDREY KOROLEV	{"phone": "+70145893367"}
0005433986669	C4FBBD	2554 093022	NADEZHDA MOROZOVA	{"email": "morozova.n.1959@postgrespro.ru", "phone": "+70215123125"}
0005433986670	C11878	1101 735720	VALERIY NIKOLAEV	{"email": "nikolaev-valeriy-101977@postgrespro.ru", "phone": "+70750977820"}
0005433986671	C66C34	6955 499742	NIKOLAY NIKOLAEV	{"email": "n.nikolaev1975@postgrespro.ru", "phone": "+70340731138"}
0005433986672	C66C34	0443 142560	ALLA KOLESNIKOVA	{"phone": "+70863604963"}
0005433986673	CEA235	2378 057489	PAVEL ROMANOV	{"email": "pavel-romanov_26111958@postgrespro.ru", "phone": "+70076968810"}
0005433986674	CEA235	3176 672256	IRINA KARPOVA	{"email": "karpova-irina22081979@postgrespro.ru", "phone": "+70508318399"}
0005433986675	CEA235	9627 696675	EVGENIY POPOV	{"phone": "+70347931102"}
0005433986676	0E9FC8	3716 948173	ALEKSANDRA KOVALEVA	{"email": "kovaleva.a.071975@postgrespro.ru", "phone": "+70868591302"}
0005433986677	0E9FC8	6670 839424	SERGEY ZAKHAROV	{"phone": "+70198560453"}
0005433986678	39C636	0025 447816	ANNA VASILEVA	{"phone": "+70989005949"}
0005433986679	39C636	7205 903013	EKATERINA ZHUKOVA	{"email": "ekaterinazhukova_09061975@postgrespro.ru", "phone": "+70541009770"}
0005433986680	9707F7	2118 786255	BORIS SMIRNOV	{"email": "borissmirnov.13071969@postgrespro.ru", "phone": "+70903036466"}
0005433986681	9707F7	7618 542971	LIDIYA PAVLOVA	{"phone": "+70520365143"}
0005433986682	B00847	6909 201346	EVGENIY MIKHAYLOV	{"phone": "+70472312065"}
0005433986683	B00847	6862 658681	ANDREY POPOV	{"email": "popov.andrey.1973@postgrespro.ru", "phone": "+70926921056"}
0005433986684	F98E30	2567 529549	ELENA ZOTOVA	{"phone": "+70946147296"}
0005433986685	B91CF3	3133 353738	ANNA BARANOVA	{"phone": "+70719017554"}
0005433986686	F4EAFC	6455 429551	ELENA KUZNECOVA	{"email": "kuznecova-e.1975@postgrespro.ru", "phone": "+70145057422"}
0005433986687	6D6C0E	2148 636305	NINA LEBEDEVA	{"phone": "+70243149669"}
0005433986688	6D6C0E	9859 405604	ALEKSEY MOROZOV	{"email": "morozov.a_04041976@postgrespro.ru", "phone": "+70239410664"}
0005433986689	A83881	6802 872829	RENAT KISELEV	{"phone": "+70651164521"}
0005433986690	49BCB0	0514 232517	VITALIY SCHERBAKOV	{"email": "vitaliyscherbakov-17101979@postgrespro.ru", "phone": "+70821760267"}
0005433986691	6339ED	1256 283078	MAKSIM NAZAROV	{"email": "maksim_nazarov.18111968@postgrespro.ru", "phone": "+70414640251"}
0005433986692	50B121	2723 404273	TAMARA GERASIMOVA	{"phone": "+70613005633"}
0005433986693	CAEE32	8391 585095	ANDREY SOKOLOV	{"email": "sokolovandrey-1978@postgrespro.ru", "phone": "+70133397683"}
0005433986694	1E6362	3899 743164	PAVEL SHEVCHENKO	{"phone": "+70353896914"}
0005433986695	1E6362	9380 537781	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr-10121958@postgrespro.ru", "phone": "+70637733097"}
0005433986696	891893	6605 601546	YURIY MOROZOV	{"email": "morozov_yuriy.071968@postgrespro.ru", "phone": "+70808883113"}
0005433986697	891893	6174 768289	VIKTORIYA ZAKHAROVA	{"phone": "+70838453280"}
0005433986698	B4D4FF	6161 740896	IRINA DMITRIEVA	{"phone": "+70032963894"}
0005433986699	B4D4FF	3950 361990	NIKOLAY GERASIMOV	{"phone": "+70662293978"}
0005433986700	BC93C2	0240 901336	EGOR KONOVALOV	{"email": "konovalov-e_081976@postgrespro.ru", "phone": "+70517384949"}
0005433986701	66A224	8692 385542	KONSTANTIN MELNIKOV	{"phone": "+70686503081"}
0005433986702	B9151E	8339 687513	YURIY OSIPOV	{"phone": "+70017445039"}
0005433986703	B9151E	0242 353945	LIDIYA FOMINA	{"email": "lidiya_fomina.041966@postgrespro.ru", "phone": "+70067194674"}
0005433986704	70A100	6284 458302	LYUBOV GRISHINA	{"phone": "+70049194444"}
0005433986705	C95C04	4957 934389	ARTEM TARASOV	{"phone": "+70828425202"}
0005433986706	C95C04	2926 527578	SERGEY KAZAKOV	{"email": "kazakovsergey28091972@postgrespro.ru", "phone": "+70136069271"}
0005433986707	1ED4B0	3149 096551	NATALYA OVCHINNIKOVA	{"email": "natalya-ovchinnikova.1968@postgrespro.ru", "phone": "+70714155285"}
0005433986708	6BF25C	8652 712366	ANNA FOMINA	{"email": "anna_fomina_071982@postgrespro.ru", "phone": "+70888305004"}
0005433986709	F5B587	4479 796225	GULNARA KALININA	{"email": "g-kalinina041977@postgrespro.ru", "phone": "+70487563229"}
0005433986710	CC9332	4169 683169	POLINA ZAYCEVA	{"phone": "+70810349580"}
0005433986711	A4941B	7382 480234	NATALYA ANTONOVA	{"email": "antonovanatalya.1970@postgrespro.ru", "phone": "+70074326789"}
0005433986712	7880DC	8259 466778	EVGENIY KOZLOV	{"phone": "+70983977093"}
0005433986713	7880DC	0890 702317	SERGEY IVANOV	{"email": "sergey-ivanov_1980@postgrespro.ru", "phone": "+70329874206"}
0005433986714	6EC5CC	2256 688642	TATYANA GAVRILOVA	{"email": "t.gavrilova-27101971@postgrespro.ru", "phone": "+70970221461"}
0005433986715	B9C48A	0580 483615	ANGELINA MALYSHEVA	{"phone": "+70394044544"}
0005433986716	B9C48A	3389 760762	VIKTOR MIRONOV	{"email": "viktor-mironov.1971@postgrespro.ru", "phone": "+70738137715"}
0005433986717	2ED935	1191 730681	EVGENIYA NOVIKOVA	{"phone": "+70369922731"}
0005433986718	33A5C1	7999 063602	TATYANA AKIMOVA	{"email": "akimova_t.05041977@postgrespro.ru", "phone": "+70800148224"}
0005433986719	A05AA6	9538 454291	IVAN ANDREEV	{"email": "andreev_i-01121982@postgrespro.ru", "phone": "+70225230641"}
0005433986720	A05AA6	6149 520619	ALEKSANDR NIKITIN	{"phone": "+70727334096"}
0005433986721	233624	6636 150772	VIKTOR ALEKSANDROV	{"phone": "+70266816937"}
0005433986722	531B10	6559 050660	MAKSIM ZAKHAROV	{"email": "zakharov-m1975@postgrespro.ru", "phone": "+70349247684"}
0005433986723	2AFFE7	2400 565320	NINA OVCHINNIKOVA	{"email": "novchinnikova.1969@postgrespro.ru", "phone": "+70949635332"}
0005433986724	2AFFE7	6544 848510	ELENA FROLOVA	{"phone": "+70192207637"}
0005433986725	26CF2A	4459 332307	VIKTOR PETROV	{"phone": "+70173687863"}
0005433986726	416A0A	6780 403131	VLADIMIR VASILEV	{"email": "vladimir_vasilev.031968@postgrespro.ru", "phone": "+70250822623"}
0005433986727	0792C0	1190 783306	SERGEY SCHERBAKOV	{"email": "s_scherbakov_18031969@postgrespro.ru", "phone": "+70021061989"}
0005433986728	0792C0	7621 936446	SERGEY RODIONOV	{"phone": "+70288878218"}
0005433986729	0792C0	2411 451847	ALEKSANDR AFANASEV	{"email": "a_afanasev-091977@postgrespro.ru", "phone": "+70340544547"}
0005433986730	98FDFA	1491 625825	KSENIYA VOROBEVA	{"phone": "+70680648027"}
0005433986731	170D6F	5524 711578	ALEKSANDR KRASNOV	{"email": "krasnova031964@postgrespro.ru", "phone": "+70259791333"}
0005433986732	170D6F	9919 701276	ANDREY MOROZOV	{"phone": "+70299531032"}
0005433986733	0002DB	1093 509566	ANNA TITOVA	{"email": "titova-a_051959@postgrespro.ru", "phone": "+70594590451"}
0005433986734	0002DB	9617 908381	OLGA POTAPOVA	{"phone": "+70138304349"}
0005433986735	62DA16	2957 705011	IRINA PETROVA	{"phone": "+70510400376"}
0005433986736	DF435F	5793 773839	ANASTASIYA NIKOLAEVA	{"phone": "+70418421628"}
0005433986737	DF435F	3789 399104	EKATERINA OSIPOVA	{"email": "osipova-ekaterina23071965@postgrespro.ru", "phone": "+70974415256"}
0005433986738	63445C	5172 104841	VALERIY ORLOV	{"email": "orlov_valeriy021979@postgrespro.ru", "phone": "+70294072325"}
0005433986739	136713	4611 926014	ASIYA KONDRATEVA	{"phone": "+70549952703"}
0005433986740	136713	7800 457068	LYUBOV IVANOVA	{"email": "ivanovalyubov11061972@postgrespro.ru", "phone": "+70461553153"}
0005433986741	136713	4668 361838	MAKSIM KUZNECOV	{"email": "kuznecovm_1960@postgrespro.ru", "phone": "+70282341623"}
0005433986742	CD2C0B	0183 120178	OLGA PAVLOVA	{"email": "olga-pavlova-091982@postgrespro.ru", "phone": "+70342832176"}
0005433986743	5A5C1B	8438 534794	ELENA ALEKSEEVA	{"phone": "+70061750394"}
0005433986744	0A23F1	4883 624376	LYUBOV IVANOVA	{"email": "ivanova.lyubov1978@postgrespro.ru", "phone": "+70280005356"}
0005433986745	EC138A	6762 610424	MARINA KAZAKOVA	{"email": "marina.kazakova-15091975@postgrespro.ru", "phone": "+70466854208"}
0005433986746	45C80B	5850 691633	VALENTINA ZAYCEVA	{"phone": "+70200135514"}
0005433986747	45C80B	3358 767801	VIKTOR ANTONOV	{"phone": "+70683546195"}
0005433986748	405C6C	5259 701942	NADEZHDA ZAKHAROVA	{"email": "n_zakharova_1976@postgrespro.ru", "phone": "+70957174586"}
0005433986749	5D5818	9115 975787	ARTEM MAKAROV	{"email": "a-makarov.081965@postgrespro.ru", "phone": "+70376534893"}
0005433986750	13E0A7	5642 041543	ANDREY VASILEV	{"email": "andreyvasilev1962@postgrespro.ru", "phone": "+70515378942"}
0005433986751	9B8FEF	0530 711495	ALEKSEY DMITRIEV	{"phone": "+70790593452"}
0005433986752	9B8FEF	3124 068479	VALENTIN EGOROV	{"phone": "+70539578299"}
0005433986753	789686	4878 575249	KIRILL ALEKSEEV	{"email": "kirill.alekseev-071974@postgrespro.ru", "phone": "+70428891098"}
0005433986754	8B6BC9	0953 924098	LYUBOV IVANOVA	{"phone": "+70970632496"}
0005433986755	8B6BC9	6934 368624	NIKOLAY NOVIKOV	{"email": "nikolay.novikov_081970@postgrespro.ru", "phone": "+70835878211"}
0005433986756	93B3C6	7228 498213	MARIYA KOROLEVA	{"email": "m-koroleva.09101975@postgrespro.ru", "phone": "+70538336720"}
0005433986757	93B3C6	3344 942672	ALEKSEY NIKOLAEV	{"email": "anikolaev13021976@postgrespro.ru", "phone": "+70245467330"}
0005433986758	A37930	9154 029657	MARAT ALEKSANDROV	{"email": "aleksandrovmarat.23081968@postgrespro.ru", "phone": "+70305972654"}
0005433986759	5FB10E	9202 949472	SERGEY DAVYDOV	{"email": "s-davydov_1960@postgrespro.ru", "phone": "+70611147452"}
0005433986760	5FB10E	7988 167671	NATALYA ANDREEVA	{"email": "natalya.andreeva_22011965@postgrespro.ru", "phone": "+70077165371"}
0005433986761	E063F7	8236 069317	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov-031974@postgrespro.ru", "phone": "+70018634506"}
0005433986762	E063F7	2873 938745	ILYA YAKOVLEV	{"phone": "+70028076924"}
0005433986763	044697	3151 155174	ANTONINA ILINA	{"phone": "+70332281076"}
0005433986764	5FB144	1314 490199	SVETLANA MOROZOVA	{"email": "svetlana.morozova.1966@postgrespro.ru", "phone": "+70225485717"}
0005433986765	5FB144	1195 971600	DMITRIY KOZLOV	{"phone": "+70740567235"}
0005433986766	31B567	3304 743033	LYUDMILA DANILOVA	{"phone": "+70701671430"}
0005433986767	4AC46E	6558 589534	ANNA NAZAROVA	{"email": "nazarovaanna13091965@postgrespro.ru", "phone": "+70386872548"}
0005433986768	4AC46E	9100 884268	ZOYA BARANOVA	{"email": "z.baranova12051980@postgrespro.ru", "phone": "+70713193218"}
0005433986769	94365B	0546 133860	MIKHAIL MELNIKOV	{"phone": "+70350960408"}
0005433986770	94365B	9646 989384	VLADIMIR MAKAROV	{"email": "makarov_v-081977@postgrespro.ru", "phone": "+70789196765"}
0005433986771	A8D16C	0078 724872	YULIYA CHERNOVA	{"email": "yuliyachernova.051970@postgrespro.ru", "phone": "+70250516914"}
0005433986772	1DBB45	7139 811142	MARK EGOROV	{"phone": "+70848126533"}
0005433986773	1DBB45	6800 429991	SERGEY TIMOFEEV	{"email": "sergey-timofeev061972@postgrespro.ru", "phone": "+70251274540"}
0005433986774	6DD14C	5892 127950	EKATERINA DENISOVA	{"email": "ekaterinadenisova.101980@postgrespro.ru", "phone": "+70145636675"}
0005433986775	99C94D	4476 589608	ALEKSANDR KULIKOV	{"email": "a.kulikov051972@postgrespro.ru", "phone": "+70901606693"}
0005433986776	AAE32F	1367 564433	ANDREY KOROLEV	{"email": "a_korolev21031982@postgrespro.ru", "phone": "+70169712436"}
0005433986777	9DA5FA	7812 232511	NADEZHDA RODIONOVA	{"email": "rodionova.nadezhda.1967@postgrespro.ru", "phone": "+70137078826"}
0005433986778	2DBFF8	3506 032888	IGOR NOVIKOV	{"email": "novikov-igor.05011973@postgrespro.ru", "phone": "+70358282673"}
0005433986779	EABD31	4224 700028	TATYANA MOROZOVA	{"phone": "+70402641912"}
0005433986780	EABD31	1403 026002	YULIYA YAKOVLEVA	{"phone": "+70436192153"}
0005433986781	A5973C	2853 374891	RAVIL ANTONOV	{"email": "antonov_r_03051965@postgrespro.ru", "phone": "+70421019415"}
0005433986782	3789C8	7219 790546	KIRILL KUZMIN	{"phone": "+70372380738"}
0005433986783	1D525F	6380 923119	YULIYA SCHERBAKOVA	{"phone": "+70160654475"}
0005433986784	046A41	5091 852543	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay_121956@postgrespro.ru", "phone": "+70296457526"}
0005433986785	046A41	5367 322145	OLEG KOROLEV	{"email": "korolev.o.091981@postgrespro.ru", "phone": "+70065750004"}
0005433986786	77AE12	2316 783800	VALENTINA ZAYCEVA	{"phone": "+70270291186"}
0005433986787	48C799	4112 438370	GEORGIY SOKOLOV	{"phone": "+70608007641"}
0005433986788	5A5FE3	7875 118737	VALENTIN ZAKHAROV	{"phone": "+70457096936"}
0005433986789	5A5FE3	8900 146207	ALENA PAVLOVA	{"email": "pavlovaalena021967@postgrespro.ru", "phone": "+70914291506"}
0005433986790	F533A3	8702 467259	ANATOLIY MIRONOV	{"email": "anatoliy.mironov.02071968@postgrespro.ru", "phone": "+70759723596"}
0005433986791	5FDE4B	8703 921860	ANNA MAKSIMOVA	{"email": "maksimova.a.1972@postgrespro.ru", "phone": "+70034486891"}
0005433986792	25348D	9492 181490	VLADIMIR IVANOV	{"email": "ivanovvladimir.1979@postgrespro.ru", "phone": "+70314965061"}
0005433986793	8F6F17	0669 205474	VALENTINA POPOVA	{"phone": "+70637666636"}
0005433986794	8A8C55	1607 084565	LIDIYA KOVALEVA	{"phone": "+70202730071"}
0005433986795	A41272	5688 153695	EVGENIYA MELNIKOVA	{"phone": "+70193211522"}
0005433986796	A41272	0349 601538	ZOYA EGOROVA	{"phone": "+70881679291"}
0005433986797	94CF0D	4889 364367	ANDREY SOROKIN	{"email": "sorokin_andrey-1980@postgrespro.ru", "phone": "+70917230366"}
0005433986798	69571F	8948 837699	ALEKSEY EGOROV	{"email": "egorova101972@postgrespro.ru", "phone": "+70008197640"}
0005433986799	D88A9C	5105 433329	MIKHAIL MOISEEV	{"email": "mikhailmoiseev-031981@postgrespro.ru", "phone": "+70439299672"}
0005433986800	D88A9C	4019 783467	ALEKSANDR KAZAKOV	{"phone": "+70692922003"}
0005433986801	3C80C6	6085 723509	DMITRIY ISAEV	{"phone": "+70672507189"}
0005433986802	DC68A1	3748 325736	ANNA KULIKOVA	{"email": "kulikova_anna.08121974@postgrespro.ru", "phone": "+70871299267"}
0005433986803	7A6C8B	8782 096033	ANDREY BORISOV	{"email": "a.borisov_011976@postgrespro.ru", "phone": "+70103224823"}
0005433986804	C0318D	2002 379940	VADIM MAKAROV	{"phone": "+70845052954"}
0005433986805	1661A6	9792 570356	YULIYA GUSEVA	{"phone": "+70912548955"}
0005433986806	D569D1	1556 721681	DARYA ANTONOVA	{"phone": "+70224603136"}
0005433986807	D569D1	0878 424782	ALBINA ZAYCEVA	{"phone": "+70229200922"}
0005433986808	D569D1	8604 877923	ALEKSANDR NIKITIN	{"phone": "+70899078637"}
0005433986809	DC67E5	8955 580283	NIKOLAY DENISOV	{"email": "denisov.n_1975@postgrespro.ru", "phone": "+70428947098"}
0005433986810	5BA56C	4666 730227	VLADIMIR VOROBEV	{"email": "v_vorobev.031973@postgrespro.ru", "phone": "+70226900075"}
0005433986811	5E9085	7137 017339	ALEKSANDR PAVLOV	{"phone": "+70124208608"}
0005433986812	5E9085	7885 912718	ALEKSANDR MOISEEV	{"phone": "+70678602908"}
0005433986813	AE5E54	3842 949813	ANTON NAZAROV	{"email": "antonnazarov.02071980@postgrespro.ru", "phone": "+70447530628"}
0005433986814	BE3C4D	7952 888758	ARTEM DMITRIEV	{"email": "dmitriev.artem021972@postgrespro.ru", "phone": "+70031741502"}
0005433986815	FBB89F	2618 849414	VERA MATVEEVA	{"email": "vmatveeva_071970@postgrespro.ru", "phone": "+70026871012"}
0005433986816	C3DEE4	3559 433524	ALSU DMITRIEVA	{"phone": "+70328323464"}
0005433986817	85FCA7	3289 696654	YULIYA FILIPPOVA	{"email": "filippova_y-1975@postgrespro.ru", "phone": "+70422386064"}
0005433986818	85FCA7	8887 297222	INESSA FILIPPOVA	{"email": "filippova.i.111980@postgrespro.ru", "phone": "+70146636970"}
0005433986819	85FCA7	2530 246843	ANNA KOMAROVA	{"email": "annakomarova071975@postgrespro.ru", "phone": "+70919439582"}
0005433986820	AAEC50	1596 937412	VLADISLAV SOKOLOV	{"phone": "+70043271429"}
0005433986821	AAEC50	6323 755533	YULIYA EFREMOVA	{"email": "efremovay_1966@postgrespro.ru", "phone": "+70296038660"}
0005433986822	39CC15	1900 190257	EDUARD VOLKOV	{"phone": "+70590110103"}
0005433986823	39CC15	4697 384989	SERGEY MATVEEV	{"email": "matveev-sergey19071965@postgrespro.ru", "phone": "+70147059504"}
0005433986824	0F7F87	3482 839827	ELENA SERGEEVA	{"phone": "+70036069358"}
0005433986825	C0170A	8677 397570	DENIS FROLOV	{"email": "dfrolov_20091992@postgrespro.ru", "phone": "+70889415447"}
0005433986826	462BF1	0214 504034	ALIYA FILATOVA	{"email": "aliyafilatova-1964@postgrespro.ru", "phone": "+70851552394"}
0005433986827	A3D25E	2795 902121	ALLA MAKAROVA	{"email": "makarova-a-05071955@postgrespro.ru", "phone": "+70119618538"}
0005433986828	A812C0	9587 733211	ANASTASIYA FILIPPOVA	{"email": "anastasiyafilippova-1980@postgrespro.ru", "phone": "+70544289865"}
0005433986829	B6666F	3467 314580	TAMARA NAZAROVA	{"phone": "+70912872576"}
0005433986830	889C2F	3725 422253	ALEKSANDR ZAKHAROV	{"email": "azakharov1969@postgrespro.ru", "phone": "+70993747197"}
0005433986831	889C2F	6918 991504	NATALYA TIKHONOVA	{"phone": "+70467927090"}
0005433986832	4F3A65	9079 396419	OLGA POPOVA	{"email": "popovao.1968@postgrespro.ru", "phone": "+70026879990"}
0005433986833	1DE44C	3319 315533	EGOR MAKAROV	{"phone": "+70525337486"}
0005433986834	4D9916	3832 092484	IRINA RYABOVA	{"phone": "+70990880788"}
0005433986835	C03E2C	2404 864639	NIKITA SIDOROV	{"email": "n.sidorov1969@postgrespro.ru", "phone": "+70695359834"}
0005433986836	EA9644	7280 983987	NIKITA MOROZOV	{"email": "nikita.morozov.1967@postgrespro.ru", "phone": "+70775261896"}
0005433986837	51530B	2053 932541	OLGA STEPANOVA	{"phone": "+70695618186"}
0005433986838	6F222B	2941 896800	LYUDMILA PETROVA	{"email": "petrova_lyudmila_101974@postgrespro.ru", "phone": "+70344234905"}
0005433986839	6F222B	7055 803301	ALEKSEY VASILEV	{"phone": "+70138836934"}
0005433986840	3E298E	1123 464765	ALEKSEY SERGEEV	{"email": "alekseysergeev1957@postgrespro.ru", "phone": "+70550169931"}
0005433986841	FA75F3	2711 651256	MARIYA SERGEEVA	{"email": "sergeeva.mariya_061975@postgrespro.ru", "phone": "+70982279521"}
0005433986842	10766C	9182 156921	PETR BELOV	{"email": "belov-petr-04081978@postgrespro.ru", "phone": "+70792691196"}
0005433986843	10766C	5384 097997	ALEKSANDR PETROV	{"email": "petrov_aleksandr_1963@postgrespro.ru", "phone": "+70162074253"}
0005433986844	10766C	3726 707179	ANDREY IVANOV	{"email": "ivanova-021978@postgrespro.ru", "phone": "+70742483319"}
0005433986845	86D0F0	8370 592200	ILMIRA POPOVA	{"email": "popovailmira-30011969@postgrespro.ru", "phone": "+70453344762"}
0005433986846	4E07C4	8104 955805	MAKSIM SERGEEV	{"email": "sergeev-maksim_22021981@postgrespro.ru", "phone": "+70580976437"}
0005433986847	F3D982	8921 924054	OLGA SIDOROVA	{"email": "o-sidorova-101969@postgrespro.ru", "phone": "+70083038079"}
0005433986848	8F36A6	6993 576963	ALEKSANDR NIKOLAEV	{"phone": "+70777640011"}
0005433986849	4C9F11	9397 432323	SVETLANA BELYAEVA	{"phone": "+70878710454"}
0005433986850	04081F	3889 675253	TATYANA PAVLOVA	{"email": "pavlova.tatyana-25111982@postgrespro.ru", "phone": "+70353452250"}
0005433986851	3CE892	0760 158200	ALEKSEY MIRONOV	{"email": "amironov-011967@postgrespro.ru", "phone": "+70060352605"}
0005433986852	78E9AE	1634 813866	OLEG SOKOLOV	{"phone": "+70077230769"}
0005433986853	329768	6658 924386	DMITRIY KUZNECOV	{"phone": "+70553339908"}
0005433986854	E811F5	8527 000934	DMITRIY KUZNECOV	{"email": "dmitriykuznecov.09061980@postgrespro.ru", "phone": "+70659532022"}
0005433986855	B6A23B	7671 376904	ANATOLIY KONOVALOV	{"email": "anatoliykonovalov-28041974@postgrespro.ru", "phone": "+70819149451"}
0005433986856	B6A23B	6565 659571	SERGEY MOROZOV	{"phone": "+70805082940"}
0005433986857	B5000F	1207 346452	MARK SMIRNOV	{"phone": "+70802646176"}
0005433986858	B5000F	4693 015416	PETR ALEKSEEV	{"phone": "+70138763777"}
0005433986859	48D322	6599 719946	EVGENIYA TIMOFEEVA	{"email": "timofeeva.evgeniya_08121974@postgrespro.ru", "phone": "+70069943710"}
0005433986860	39F50E	4721 535025	VALENTINA GAVRILOVA	{"email": "gavrilovavalentina23101974@postgrespro.ru", "phone": "+70951296015"}
0005433986861	39F50E	5679 640587	KIRILL VASILEV	{"email": "vasilev.k.1975@postgrespro.ru", "phone": "+70987961387"}
0005433986862	39F50E	3634 375138	ANATOLIY ZAKHAROV	{"email": "anatoliy_zakharov_18031975@postgrespro.ru", "phone": "+70098796863"}
0005433986863	F1E27F	7875 593787	ANDREY MEDVEDEV	{"email": "medvedeva.1981@postgrespro.ru", "phone": "+70621571102"}
0005433986864	5F628B	0356 986846	ADELINA SERGEEVA	{"phone": "+70103750887"}
0005433986865	4A4169	6785 644944	ANNA YAKOVLEVA	{"phone": "+70812654761"}
0005433986866	4A4169	5866 041858	GALINA VASILEVA	{"phone": "+70739947934"}
0005433986867	84B40D	6118 857742	GALINA SOLOVEVA	{"phone": "+70827199378"}
0005433986868	A793DA	5907 069849	ANDREY KUZNECOV	{"email": "a-kuznecov23041968@postgrespro.ru", "phone": "+70212537356"}
0005433986869	2EBE32	2665 057466	GRIGORIY NAZAROV	{"phone": "+70333186125"}
0005433986870	A96306	6170 784453	ANASTASIYA ERMAKOVA	{"email": "ermakova_anastasiya.061983@postgrespro.ru", "phone": "+70716501054"}
0005433986871	6FA0E6	5858 938022	ANATOLIY GAVRILOV	{"email": "anatoliygavrilov1966@postgrespro.ru", "phone": "+70618362488"}
0005433986872	F10B94	2752 539576	VASILIY FEDOROV	{"phone": "+70929907152"}
0005433986873	58B705	9272 012541	LIDIYA BELOVA	{"email": "l.belova-121970@postgrespro.ru", "phone": "+70768597238"}
0005433986874	68EFF7	9202 136791	BORIS MAKAROV	{"email": "makarov_boris.10101981@postgrespro.ru", "phone": "+70879976936"}
0005433986875	F86366	4907 214185	VLADIMIR CHERNOV	{"email": "chernovvladimir-1970@postgrespro.ru", "phone": "+70736724612"}
0005433986876	9B929B	3620 936380	ALEKSANDRA PAVLOVA	{"phone": "+70014115015"}
0005433986877	676495	5908 888776	ELENA VASILEVA	{"email": "e_vasileva-21111985@postgrespro.ru", "phone": "+70011338875"}
0005433986878	A84219	9506 819092	ANATOLIY KUZMIN	{"phone": "+70964048278"}
0005433986879	957C5E	2459 630338	ELENA AFANASEVA	{"phone": "+70753706500"}
0005433986880	957C5E	8500 734716	ALEKSANDRA VLASOVA	{"phone": "+70898105010"}
0005433986881	957C5E	9952 723515	EKATERINA SOROKINA	{"phone": "+70774396345"}
0005433986882	43DF09	3666 007640	NATALYA IVANOVA	{"phone": "+70765271556"}
0005433986883	9E4150	4568 519021	ALEFTINA MIKHAYLOVA	{"phone": "+70669203404"}
0005433986884	9E4150	9369 444830	OLEG SOKOLOV	{"email": "o_sokolov22101974@postgrespro.ru", "phone": "+70441155639"}
0005433986885	9E4150	7923 698014	TAMARA TIKHONOVA	{"phone": "+70310381386"}
0005433986886	EE0DCA	9041 496300	ALEKSANDR PETROV	{"email": "petrov-aleksandr-081970@postgrespro.ru", "phone": "+70631505482"}
0005433986887	DCADB6	5669 048303	YULIYA BOGDANOVA	{"phone": "+70882932502"}
0005433986888	596E0E	4325 662657	VLADIMIR SCHERBAKOV	{"phone": "+70682029142"}
0005433986889	E2BB2D	7419 351059	ANTONINA SEMENOVA	{"email": "a-semenova-1981@postgrespro.ru", "phone": "+70746241359"}
0005433986890	E2BB2D	9692 752523	PELAGEYA MOISEEVA	{"phone": "+70686640802"}
0005433986891	3932F3	7263 103241	ALEKSANDRA ANTONOVA	{"email": "antonovaaleksandra-031963@postgrespro.ru", "phone": "+70305197775"}
0005433986892	7E3A03	7092 952542	MARIYA OSIPOVA	{"email": "mariya.osipova_061976@postgrespro.ru", "phone": "+70630481626"}
0005433986950	8474D5	9378 002816	ANNA POLYAKOVA	{"phone": "+70880707451"}
0005433986893	7E3A03	5198 108193	DIANA KAZAKOVA	{"email": "kazakova.diana-121964@postgrespro.ru", "phone": "+70848071195"}
0005433986894	A33E81	2912 858475	VLADIMIR FILIPPOV	{"email": "filippov_vladimir-1970@postgrespro.ru", "phone": "+70764657328"}
0005433986895	A33E81	7874 764050	NIKOLAY IVANOV	{"phone": "+70244917110"}
0005433986896	0B8274	1774 171427	ANASTASIYA OSIPOVA	{"email": "osipovaa-22081952@postgrespro.ru", "phone": "+70456962262"}
0005433986897	0B8274	9601 956818	LYUDMILA MASLOVA	{"phone": "+70128813107"}
0005433986898	C912E7	0942 939749	VALENTINA KUZNECOVA	{"phone": "+70616731562"}
0005433986899	C912E7	5021 156292	VLADIMIR SERGEEV	{"phone": "+70232598300"}
0005433986900	329711	8981 825858	ALEKSEY MARTYNOV	{"email": "aleksey-martynov27111980@postgrespro.ru", "phone": "+70868371734"}
0005433986901	329711	3962 041755	ROZA TROFIMOVA	{"phone": "+70256206445"}
0005433986902	E7A48B	8906 496502	YURIY DENISOV	{"phone": "+70697613162"}
0005433986903	ABF91E	9544 095560	NATALYA MARTYNOVA	{"phone": "+70102306789"}
0005433986904	ABF91E	7307 134676	DMITRIY ZHUKOV	{"email": "zhukov_dmitriy031983@postgrespro.ru", "phone": "+70738730415"}
0005433986905	9EF321	1986 464877	ALEKSANDRA AKIMOVA	{"phone": "+70234573816"}
0005433986906	8981C4	6141 350242	MAKSIM PETROV	{"phone": "+70474599843"}
0005433986907	EE7A7B	0898 415726	OLGA FILIPPOVA	{"phone": "+70004064317"}
0005433986908	E0A600	0495 816983	RAVIL MIKHAYLOV	{"phone": "+70612736237"}
0005433986909	E0A600	9210 367530	IGOR BELOV	{"phone": "+70757993352"}
0005433986910	24C3D1	8183 096938	SERGEY OSIPOV	{"email": "osipov.s041973@postgrespro.ru", "phone": "+70369639147"}
0005433986911	1A16F3	5665 624766	GALINA RODIONOVA	{"phone": "+70165040423"}
0005433986912	237138	0551 703140	VIKTOR BORISOV	{"phone": "+70749301024"}
0005433986913	F7ACB4	7855 957102	VASILIY ISAEV	{"phone": "+70344174004"}
0005433986914	515B25	1107 407962	TATYANA MOROZOVA	{"phone": "+70862327676"}
0005433986915	515B25	5784 373604	ANDREY BONDARENKO	{"phone": "+70303605593"}
0005433986916	B8EC3B	3566 422286	NADEZHDA GORBUNOVA	{"email": "nadezhda_gorbunova06111982@postgrespro.ru", "phone": "+70342735948"}
0005433986917	CDA8CA	5732 115964	SERGEY MARTYNOV	{"email": "martynov_sergey_1972@postgrespro.ru", "phone": "+70994097628"}
0005433986918	03B9DB	2363 600433	ALEKSANDR IVANOV	{"email": "ivanov-a_10031965@postgrespro.ru", "phone": "+70243036155"}
0005433986919	946A4B	2548 889276	EVGENIYA GERASIMOVA	{"phone": "+70920127762"}
0005433986920	4B2095	8081 407673	PAVEL ZHUKOV	{"phone": "+70996699357"}
0005433986921	4B2095	4326 195628	ELENA NIKIFOROVA	{"email": "elena.nikiforova-1967@postgrespro.ru", "phone": "+70248022499"}
0005433986922	9E125C	0965 156622	GALINA IVANOVA	{"phone": "+70291744248"}
0005433986923	5ECA8C	7702 120647	ADELINA SIDOROVA	{"phone": "+70704738897"}
0005433986924	924E23	4019 653912	OKSANA MELNIKOVA	{"phone": "+70590019718"}
0005433986925	AF1E18	8054 306128	NINA FEDOROVA	{"email": "nina_fedorova_1973@postgrespro.ru", "phone": "+70207750906"}
0005433986926	FF9697	5874 599714	ANATOLIY AFANASEV	{"phone": "+70392144513"}
0005433986927	FF9697	8612 851556	LYUDMILA ZAKHAROVA	{"phone": "+70619850217"}
0005433986928	07A63C	8767 247967	VERA KISELEVA	{"email": "kiseleva-vera-1975@postgrespro.ru", "phone": "+70165619828"}
0005433986929	8BCEF2	5804 417127	SERGEY TARASOV	{"phone": "+70960118494"}
0005433986930	31C282	9427 245594	PAVEL PETROV	{"phone": "+70017802685"}
0005433986931	622FDB	5461 648869	ROMAN BORISOV	{"phone": "+70595843100"}
0005433986932	AC37E4	7251 359930	PETR KRASNOV	{"email": "krasnovp.061967@postgrespro.ru", "phone": "+70797336070"}
0005433986933	877575	0761 238849	LIDIYA MAKAROVA	{"email": "makarova_l-15041975@postgrespro.ru", "phone": "+70579465472"}
0005433986934	877575	9611 897447	MARTA RYABOVA	{"phone": "+70447593617"}
0005433986935	43D777	3790 941115	ILDAR DENISOV	{"phone": "+70866239472"}
0005433986936	209E2B	1199 196171	ALEKSANDRA KARPOVA	{"email": "karpovaa-061972@postgrespro.ru", "phone": "+70642430361"}
0005433986937	024E66	7509 390201	NIKOLAY MOROZOV	{"email": "morozov_nikolay.071974@postgrespro.ru", "phone": "+70956571748"}
0005433986938	919486	4006 144353	VYACHESLAV KOROLEV	{"email": "v_korolev_23101974@postgrespro.ru", "phone": "+70029444138"}
0005433986939	F4A8A5	7395 595527	LYUBOV SAVELEVA	{"phone": "+70070995911"}
0005433986940	7891B6	4271 755353	ILYA ZHURAVLEV	{"phone": "+70599992835"}
0005433986941	7891B6	5276 943213	ANNA EFIMOVA	{"email": "efimovaa-1977@postgrespro.ru", "phone": "+70121378003"}
0005433986942	91F5E5	4061 221717	KSENIYA SAVELEVA	{"email": "k_saveleva04071978@postgrespro.ru", "phone": "+70506872555"}
0005433986943	178616	9783 337123	FEDOR VASILEV	{"email": "f-vasilev_19011966@postgrespro.ru", "phone": "+70802007814"}
0005433986944	178616	0700 783107	SVETLANA VOROBEVA	{"phone": "+70372106659"}
0005433986945	4167A5	5980 557491	OLGA ZHUKOVA	{"phone": "+70827498573"}
0005433986946	4167A5	3034 902197	ANASTASIYA BORISOVA	{"email": "borisova-a-1978@postgrespro.ru", "phone": "+70170929506"}
0005433986947	3CD3A2	0836 164443	ANNA VOLKOVA	{"email": "a_volkova1962@postgrespro.ru", "phone": "+70914714955"}
0005433986948	6263EC	8997 923134	ALEKSANDR PAVLOV	{"email": "pavlov.a-19031973@postgrespro.ru", "phone": "+70610879127"}
0005433986949	EB469D	2620 924993	LYUDMILA MATVEEVA	{"email": "lyudmila-matveeva_061973@postgrespro.ru", "phone": "+70376286919"}
0005433986951	67E8C8	9366 813070	TATYANA IVANOVA	{"phone": "+70422404719"}
0005433986952	D79961	9550 387434	ANNA POTAPOVA	{"email": "potapova-a.01111983@postgrespro.ru", "phone": "+70951613606"}
0005433986953	7AB7F6	7949 598355	DINA ROMANOVA	{"phone": "+70392379821"}
0005433986954	7AB7F6	0286 707396	SVETLANA ZAKHAROVA	{"email": "zakharova.svetlana.021971@postgrespro.ru", "phone": "+70279582337"}
0005433986955	7AB7F6	9988 872057	VITALIY KULIKOV	{"phone": "+70373234882"}
0005433986956	EA3CC1	8879 284865	YURIY MAKAROV	{"email": "yuriymakarov1972@postgrespro.ru", "phone": "+70812574284"}
0005433986957	E5C389	5001 822994	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr-1968@postgrespro.ru", "phone": "+70519304464"}
0005433986958	E208DB	8800 218923	VYACHESLAV MIKHAYLOV	{"phone": "+70251950991"}
0005433986959	E208DB	5628 574318	ALEKSEY ALEKSEEV	{"phone": "+70576259317"}
0005433986960	E208DB	7298 021086	OLEG POPOV	{"phone": "+70831589540"}
0005433986961	362674	9687 590466	LARISA VOLKOVA	{"phone": "+70714835466"}
0005433986962	362674	3544 950492	ANDREY ANDREEV	{"email": "a-andreev-1975@postgrespro.ru", "phone": "+70381462928"}
0005433986963	7CF233	9162 582720	GALINA NIKITINA	{"email": "nikitina-galina.1963@postgrespro.ru", "phone": "+70807345624"}
0005433986964	7CF233	2884 878508	NATALYA FOMINA	{"phone": "+70151457191"}
0005433986965	2CF44C	0941 524499	ELENA OSIPOVA	{"phone": "+70842454824"}
0005433986966	2CF44C	3718 893071	ROMAN KRASNOV	{"phone": "+70946311967"}
0005433986967	4C7859	5933 363337	VYACHESLAV SIDOROV	{"phone": "+70674077532"}
0005433986968	0F6379	1858 567567	KIRILL KAZAKOV	{"email": "k-kazakov_1980@postgrespro.ru", "phone": "+70121920035"}
0005433986969	C6DEAB	6123 994383	VERA GERASIMOVA	{"phone": "+70470927330"}
0005433986970	C6DEAB	0385 996235	ELENA PETROVA	{"phone": "+70634986879"}
0005433986971	C29A88	4102 952139	ELVIRA MIKHAYLOVA	{"phone": "+70600779305"}
0005433986972	E65C70	6655 883872	OLGA STEPANOVA	{"phone": "+70114666130"}
0005433986973	E65C70	4142 435710	GALINA POPOVA	{"phone": "+70392684253"}
0005433986974	4790ED	7861 531295	LEONID ZAKHAROV	{"email": "zakharov-leonid_071972@postgrespro.ru", "phone": "+70804987261"}
0005433986975	F2A54E	7500 470075	ANDREY KAZAKOV	{"email": "andrey_kazakov-1972@postgrespro.ru", "phone": "+70204809733"}
0005433986976	F2A54E	7700 464228	NATALYA KOZLOVA	{"phone": "+70918181301"}
0005433986977	093CD2	2384 302046	VALENTINA STEPANOVA	{"phone": "+70943147337"}
0005433986978	AFDEA3	0900 902719	DMITRIY VOROBEV	{"phone": "+70725494642"}
0005433986979	297415	7595 276595	DANIL KUZNECOV	{"email": "kuznecov-d.121953@postgrespro.ru", "phone": "+70509645086"}
0005433986980	297415	8766 260087	YURIY ZAKHAROV	{"email": "zakharovyuriy.011973@postgrespro.ru", "phone": "+70271861503"}
0005433986981	985E60	8882 757654	NATALYA POPOVA	{"phone": "+70992926770"}
0005433986982	8DCB12	3348 469093	OLGA NIKOLAEVA	{"email": "olga.nikolaeva_06051973@postgrespro.ru", "phone": "+70711007255"}
0005433986983	38029C	2281 924800	ALEKSANDR KAZAKOV	{"email": "aleksandr_kazakov_1974@postgrespro.ru", "phone": "+70869718677"}
0005433986984	BA2E10	3301 066774	ALEKSANDR GRIGOREV	{"email": "grigorev.a-1968@postgrespro.ru", "phone": "+70736011238"}
0005433986985	8903D0	5927 840079	NATALYA STEPANOVA	{"email": "natalya_stepanova_1963@postgrespro.ru", "phone": "+70089960760"}
0005433986986	42F1A0	9144 071294	NATALYA ZAKHAROVA	{"email": "zakharovan-28021977@postgrespro.ru", "phone": "+70001048149"}
0005433986987	DBB7C8	8918 727438	ANTON SCHERBAKOV	{"email": "scherbakov-anton_011967@postgrespro.ru", "phone": "+70577605033"}
0005433986988	DBB7C8	7656 342612	NADEZHDA ROMANOVA	{"email": "romanovanadezhda_25111970@postgrespro.ru", "phone": "+70343503327"}
0005433986989	9B3AC8	7779 769362	PAVEL MARTYNOV	{"email": "pmartynov081972@postgrespro.ru", "phone": "+70878720696"}
0005433986990	ADCAF9	9008 998576	NIKITA NOVIKOV	{"email": "novikovnikita_25071977@postgrespro.ru", "phone": "+70235511165"}
0005433986991	6A6DB5	1593 643404	ANDREY GORBUNOV	{"email": "andrey.gorbunov_14091966@postgrespro.ru", "phone": "+70864492042"}
0005433986992	6A6DB5	0116 789968	ALENA FILIPPOVA	{"phone": "+70883874063"}
0005433986993	0E4A80	4618 880745	NATALYA DMITRIEVA	{"email": "dmitrieva-n071968@postgrespro.ru", "phone": "+70035416190"}
0005433986994	0E4A80	1905 649762	LYUDMILA KUZNECOVA	{"phone": "+70311675799"}
0005433986995	09DB0F	5106 129875	NIKOLAY ILIN	{"phone": "+70095681386"}
0005433986996	2612D4	7895 581207	MIKHAIL SOLOVEV	{"phone": "+70011887903"}
0005433986997	B93589	2271 403661	ALEKSEY ROMANOV	{"phone": "+70088960729"}
0005433986998	8A93CF	3384 141765	ALLA MOISEEVA	{"phone": "+70776055447"}
0005433986999	1135A6	6469 309047	LYUDMILA ARKHIPOVA	{"phone": "+70213339917"}
0005433987000	BDCE6B	6750 583993	ALEKSANDR KOZLOV	{"phone": "+70350048834"}
0005433987001	6AE9D8	0505 068660	IVAN NAZAROV	{"email": "nazarov.i-041962@postgrespro.ru", "phone": "+70732102688"}
0005433987002	8749C5	2513 740730	OLESYA NESTEROVA	{"email": "olesyanesterova-10071979@postgrespro.ru", "phone": "+70961209493"}
0005433987003	6632B5	1610 347920	ANDREY ZAYCEV	{"phone": "+70779220105"}
0005433987004	6632B5	8715 018549	ALEKSEY POPOV	{"phone": "+70898646684"}
0005433987005	A89A1B	5695 779127	SVETLANA POTAPOVA	{"phone": "+70853913529"}
0005433987006	F65F5A	6308 587745	DENIS MOROZOV	{"phone": "+70420365892"}
0005433987007	17BEDD	9572 628283	VLADIMIR ORLOV	{"phone": "+70756354195"}
0005433987008	51F018	3416 398154	GENNADIY KUZNECOV	{"email": "g.kuznecov_14081975@postgrespro.ru", "phone": "+70820711016"}
0005433987009	51F018	0843 473066	MARINA NIKITINA	{"phone": "+70622806199"}
0005433987010	E013CD	4269 048959	VYACHESLAV GERASIMOV	{"email": "vyacheslav.gerasimov.1979@postgrespro.ru", "phone": "+70090245707"}
0005433987011	8688D7	3638 589007	ANATOLIY TIMOFEEV	{"email": "atimofeev11121962@postgrespro.ru", "phone": "+70916457213"}
0005433987012	E64F50	6491 618844	SERGEY FEDOROV	{"phone": "+70199319094"}
0005433987013	E64F50	8023 346195	VALENTINA DMITRIEVA	{"phone": "+70529520847"}
0005433987014	73AAE7	5189 019035	RAISA ZAKHAROVA	{"email": "zakharovaraisa-29101972@postgrespro.ru", "phone": "+70278459450"}
0005433987015	73AAE7	2814 111693	BORIS ISAEV	{"email": "bisaev_1966@postgrespro.ru", "phone": "+70746018704"}
0005433987016	E6FD20	4339 605710	IRINA SOROKINA	{"email": "i_sorokina-1979@postgrespro.ru", "phone": "+70089388213"}
0005433987017	06B72A	0674 029109	ELENA GAVRILOVA	{"phone": "+70392757557"}
0005433987018	7D2A48	3416 850844	IDA SCHERBAKOVA	{"email": "ischerbakova.1972@postgrespro.ru", "phone": "+70915909492"}
0005433987019	D6AF1F	7485 469215	ZINAIDA KOROLEVA	{"phone": "+70194861395"}
0005433987020	6F7C17	2116 763827	NATALYA GERASIMOVA	{"email": "gerasimovan-091970@postgrespro.ru", "phone": "+70170463755"}
0005433987021	786DBC	2510 721024	ANNA BOGDANOVA	{"email": "anna-bogdanova1980@postgrespro.ru", "phone": "+70446351408"}
0005433987022	786DBC	9730 947625	RUZALIYA POPOVA	{"phone": "+70731829590"}
0005433987023	9E8063	5132 984660	ALEKSEY PETROV	{"phone": "+70499543992"}
0005433987024	B046D7	0678 185747	TATYANA TIMOFEEVA	{"phone": "+70895452684"}
0005433987025	B046D7	2189 937858	ELENA NIKIFOROVA	{"phone": "+70966239300"}
0005433987026	D7C96A	9499 976188	ALEKSANDR IVANOV	{"email": "a_ivanov04111959@postgrespro.ru", "phone": "+70463932061"}
0005433987027	79BCB5	6229 083958	ZULFIYA SOKOLOVA	{"phone": "+70044831179"}
0005433987028	79BCB5	2855 148220	SERGEY IVANOV	{"email": "ivanov_sergey_111972@postgrespro.ru", "phone": "+70560435960"}
0005433987029	07C355	5680 989736	ANNA GRISHINA	{"phone": "+70844897906"}
0005433987030	3B955F	1683 370502	NATALYA POLYAKOVA	{"email": "polyakova.natalya-091968@postgrespro.ru", "phone": "+70374470469"}
0005433987031	32BDA4	5972 532713	NIKOLAY KUZNECOV	{"phone": "+70283672900"}
0005433987032	32BDA4	4047 908987	LIDIYA KISELEVA	{"phone": "+70904871728"}
0005433987033	86EB7F	5920 415765	ALEKSEY BORISOV	{"email": "borisov-aleksey1963@postgrespro.ru", "phone": "+70048475511"}
0005433987034	E6063E	5697 024455	ANDREY SAVELEV	{"email": "savelevandrey-1972@postgrespro.ru", "phone": "+70643135671"}
0005433987035	E6063E	4080 369530	LILIYA MELNIKOVA	{"phone": "+70771676252"}
0005433987036	094552	0782 440800	SVETLANA GORBUNOVA	{"phone": "+70696681605"}
0005433987037	094552	0354 299700	SERGEY ZHUKOV	{"email": "sergey_zhukov_05081973@postgrespro.ru", "phone": "+70177772343"}
0005433987038	9DFFDA	6887 015464	MAKSIM NIKITIN	{"email": "m_nikitin.1971@postgrespro.ru", "phone": "+70570275011"}
0005433987039	9DFFDA	7890 231879	RUSLAN IVANOV	{"phone": "+70681089110"}
0005433987040	8D6369	2021 825647	LYUBOV ZAKHAROVA	{"email": "lyubov-zakharova08051976@postgrespro.ru", "phone": "+70212256448"}
0005433987041	EDB2D0	5281 534532	VALERIYA SCHERBAKOVA	{"phone": "+70843567117"}
0005433987042	1FBAAE	6382 486260	PAVEL NAZAROV	{"email": "nazarov_p-121954@postgrespro.ru", "phone": "+70460630247"}
0005433987043	DCBC0B	6791 780968	DARYA KULIKOVA	{"email": "kulikova.darya.101970@postgrespro.ru", "phone": "+70511620084"}
0005433987044	BEF7ED	3126 460582	SVETLANA RODIONOVA	{"email": "rodionova_svetlana1977@postgrespro.ru", "phone": "+70821451184"}
0005433987045	FEC408	1959 614592	ALEKSANDR TIMOFEEV	{"phone": "+70934147041"}
0005433987046	63A95B	9724 346791	VALENTIN NAUMOV	{"phone": "+70972168370"}
0005433987047	229D55	5713 010332	ANNA FEDOROVA	{"email": "fedorovaa-091974@postgrespro.ru", "phone": "+70672542203"}
0005433987048	DAB798	8325 199276	GALINA MEDVEDEVA	{"phone": "+70380969687"}
0005433987049	DAB798	6886 372196	NATALYA YAKOVLEVA	{"phone": "+70320380429"}
0005433987050	7212E5	9302 825104	ALEKSANDR SCHERBAKOV	{"phone": "+70430858567"}
0005433987051	213BC1	9695 605455	ELENA VASILEVA	{"phone": "+70772701080"}
0005433987052	67F51A	3031 850365	DMITRIY ABRAMOV	{"phone": "+70169287712"}
0005433987053	67F51A	1442 341015	SVETLANA MASLOVA	{"phone": "+70411360402"}
0005433987054	892DBB	2317 280347	RAISA RYABOVA	{"email": "rryabova-061968@postgrespro.ru", "phone": "+70836705084"}
0005433987055	892DBB	8256 563165	VIKTOR ANTONOV	{"email": "viktor_antonov.031975@postgrespro.ru", "phone": "+70425518236"}
0005433987056	D797AF	0121 106610	OLEG TIKHONOV	{"email": "o_tikhonov19021968@postgrespro.ru", "phone": "+70871700646"}
0005433987057	A242EE	1692 009094	ANDREY FEDOROV	{"phone": "+70189960918"}
0005433987058	A242EE	5258 640664	ANNA VOROBEVA	{"email": "vorobeva.a_021972@postgrespro.ru", "phone": "+70816382755"}
0005433987059	7A57B7	0069 745074	ALEKSANDRA MAKSIMOVA	{"email": "maksimova_aleksandra-14111972@postgrespro.ru", "phone": "+70120360871"}
0005433987060	517FC9	1830 621873	TATYANA GAVRILOVA	{"phone": "+70109201838"}
0005433987061	6A2FD9	3987 110860	DENIS ABRAMOV	{"phone": "+70076962498"}
0005433987062	6A2FD9	9634 914275	RINAT SERGEEV	{"phone": "+70268376608"}
0005433987063	6A2FD9	1081 073114	ALEVTINA DAVYDOVA	{"email": "alevtinadavydova101962@postgrespro.ru", "phone": "+70002516755"}
0005433987064	118281	6754 101874	DENIS TIKHONOV	{"phone": "+70393954251"}
0005433987065	118281	6645 519311	RAISA MEDVEDEVA	{"phone": "+70439509517"}
0005433987066	8C5FDA	7706 332483	ANDREY NIKITIN	{"email": "nikitin.a-1959@postgrespro.ru", "phone": "+70331674358"}
0005433987067	FF2419	8420 365023	NINA NESTEROVA	{"email": "nesterova-nina-31081971@postgrespro.ru", "phone": "+70844086138"}
0005433987068	FF2419	6386 182051	MIKHAIL FROLOV	{"phone": "+70154728090"}
0005433987069	F6DC2E	7313 195759	ANNA ISAEVA	{"phone": "+70019447338"}
0005433987070	FB1074	2826 533949	LYUDMILA KALININA	{"phone": "+70042676137"}
0005433987071	FB1074	6975 222743	NATALYA YAKOVLEVA	{"email": "natalya.yakovleva_091966@postgrespro.ru", "phone": "+70474184220"}
0005433987072	37931B	6775 058030	NADEZHDA MIKHAYLOVA	{"phone": "+70905660285"}
0005433987073	479ED7	9960 959840	TATYANA FEDOROVA	{"email": "fedorova_tatyana_061977@postgrespro.ru", "phone": "+70951368379"}
0005433987074	E5FAE0	3792 574832	ZINAIDA KUZNECOVA	{"email": "z-kuznecova_041971@postgrespro.ru", "phone": "+70468575784"}
0005433987075	71AF65	3000 449128	TAMARA FOMINA	{"email": "fomina_tamara_15051977@postgrespro.ru", "phone": "+70532727145"}
0005433987076	E1E005	7315 830235	MIKHAIL KOROLEV	{"email": "m_korolev031975@postgrespro.ru", "phone": "+70548175947"}
0005433987077	2D4BB5	9327 689694	MARINA SERGEEVA	{"phone": "+70388660995"}
0005433987078	9F6FC2	5203 314510	SVETLANA EGOROVA	{"email": "egorova_svetlana-051979@postgrespro.ru", "phone": "+70622137513"}
0005433987079	F9CCD8	7454 084366	OLGA KOROLEVA	{"phone": "+70037771358"}
0005433987080	27EA54	5913 391350	OLEG KOROLEV	{"phone": "+70290554412"}
0005433987081	86D852	1924 101669	ALEKSANDR FILIPPOV	{"phone": "+70636152804"}
0005433987082	AC6EB2	3744 135060	DZHAMILYA VLASOVA	{"phone": "+70027491258"}
0005433987083	40E0E9	7951 314527	LEYLA KULIKOVA	{"phone": "+70546034690"}
0005433987084	A9F9F7	6831 243915	GENNADIY DENISOV	{"email": "denisov.g1978@postgrespro.ru", "phone": "+70244746917"}
0005433987085	A7772C	1534 503654	ALEKSANDR KAZAKOV	{"email": "aleksandr_kazakov.061972@postgrespro.ru", "phone": "+70186030990"}
0005433987086	A7772C	1389 871489	VLADIMIR BORISOV	{"email": "vladimir-borisov-1970@postgrespro.ru", "phone": "+70189972687"}
0005433987087	9A60CD	6330 887944	MILENA KALININA	{"email": "kalininam.081977@postgrespro.ru", "phone": "+70732117567"}
0005433987088	01E401	7537 210040	TATYANA SMIRNOVA	{"phone": "+70071784797"}
0005433987089	80199E	6337 216823	KARINA ALEKSEEVA	{"email": "k.alekseeva1970@postgrespro.ru", "phone": "+70184268599"}
0005433987090	380B0C	3023 704399	SERGEY KULIKOV	{"phone": "+70942718499"}
0005433987091	380B0C	6822 823209	EVGENIY NAZAROV	{"phone": "+70661598011"}
0005433987092	076FAF	0767 847940	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev_031968@postgrespro.ru", "phone": "+70797726315"}
0005433987093	7698AB	2429 783428	VSEVOLOD KOZLOV	{"phone": "+70235031654"}
0005433987094	BE4AFE	5989 510283	ANASTASIYA STEPANOVA	{"email": "astepanova-24101978@postgrespro.ru", "phone": "+70280416263"}
0005433987095	00E303	8553 768838	TIMUR ZAKHAROV	{"phone": "+70989419519"}
0005433987096	6673BE	0862 679282	ANATOLIY MOROZOV	{"email": "morozov_anatoliy-29031957@postgrespro.ru", "phone": "+70405861977"}
0005433987097	6673BE	7188 995978	EVGENIY ANDREEV	{"phone": "+70053794716"}
0005433987098	D3951D	5300 571993	VIKTOR ZHURAVLEV	{"email": "zhuravlev_viktor-1967@postgrespro.ru", "phone": "+70982073735"}
0005433987099	0AC44C	5362 027082	KRISTINA BORISOVA	{"phone": "+70025705269"}
0005433987100	0AC44C	2454 324641	TATYANA EFIMOVA	{"phone": "+70734775982"}
0005433987212	E887FF	7521 604075	ANDREY KOZLOV	{"phone": "+70958518946"}
0005433987101	0AC44C	4448 529720	ELENA MAKAROVA	{"email": "makarova.e_111971@postgrespro.ru", "phone": "+70471090654"}
0005433987102	1E1216	9905 905999	GALINA ALEKSANDROVA	{"email": "aleksandrova.g.111971@postgrespro.ru", "phone": "+70427191444"}
0005433987103	6FBECB	9923 013637	OLEG KUZNECOV	{"phone": "+70076240632"}
0005433987104	BB9EAB	4975 787375	VIOLETTA MOROZOVA	{"phone": "+70345934987"}
0005433987105	B43798	0048 253466	VLADIMIR BONDARENKO	{"email": "bondarenkov.1973@postgrespro.ru", "phone": "+70910626258"}
0005433987106	6B945E	7959 185988	KRISTINA BORISOVA	{"email": "borisova-kristina_1985@postgrespro.ru", "phone": "+70006404375"}
0005433987107	6DB663	5950 664664	MIKHAIL ZAYCEV	{"email": "zaycev-mikhail1977@postgrespro.ru", "phone": "+70653760273"}
0005433987108	6DB663	4112 551672	ANASTASIYA VOLKOVA	{"phone": "+70754060040"}
0005433987109	981D0C	8956 987122	LYUBOV POTAPOVA	{"email": "lyubov-potapova-20121959@postgrespro.ru", "phone": "+70448528113"}
0005433987110	0DEB9D	4152 452450	NADEZHDA KOZLOVA	{"phone": "+70403790168"}
0005433987111	0DEB9D	8421 905320	MARIYA ANDREEVA	{"email": "andreeva-mariya091969@postgrespro.ru", "phone": "+70776816543"}
0005433987112	0DEB9D	6273 391985	VERA LAZAREVA	{"email": "veralazareva_19081975@postgrespro.ru", "phone": "+70603487260"}
0005433987113	2822AB	9679 011507	VASILIY MARTYNOV	{"phone": "+70653047574"}
0005433987114	BBE91C	6415 460592	ALLA FOMINA	{"email": "allafomina1966@postgrespro.ru", "phone": "+70263921166"}
0005433987115	CF496D	0534 549140	OLGA VOLKOVA	{"phone": "+70536062154"}
0005433987116	966891	4259 969379	LYUDMILA ABRAMOVA	{"email": "l_abramova_061968@postgrespro.ru", "phone": "+70629330266"}
0005433987117	966891	5936 653031	OLGA KULIKOVA	{"phone": "+70297221793"}
0005433987118	A414D8	2532 720952	NADEZHDA MOROZOVA	{"phone": "+70447865999"}
0005433987119	082E8A	9291 124816	AMINA GAVRILOVA	{"email": "a_gavrilova-09021986@postgrespro.ru", "phone": "+70468305910"}
0005433987120	4DA6C5	0065 194217	OLGA NIKOLAEVA	{"email": "nikolaeva-o011977@postgrespro.ru", "phone": "+70012243952"}
0005433987121	413476	4255 957464	DAMIR MIKHAYLOV	{"email": "d-mikhaylov.021973@postgrespro.ru", "phone": "+70025081096"}
0005433987122	1D856A	2546 354889	NIKOLAY TIMOFEEV	{"phone": "+70346631234"}
0005433987123	C399A5	1630 270974	OLGA POLYAKOVA	{"email": "polyakovaolga.021978@postgrespro.ru", "phone": "+70675691506"}
0005433987124	C957E2	6772 904671	ANATOLIY FEDOTOV	{"phone": "+70879339543"}
0005433987125	C957E2	4135 828343	ILYA SCHERBAKOV	{"email": "ischerbakov_1987@postgrespro.ru", "phone": "+70736954498"}
0005433987126	0A129C	4812 934214	TAMARA STEPANOVA	{"email": "stepanova_tamara091983@postgrespro.ru", "phone": "+70243188194"}
0005433987127	991312	4176 353007	ANDREY VOLKOV	{"phone": "+70933121801"}
0005433987128	0F7E3B	0928 626551	IVAN PAVLOV	{"phone": "+70958920656"}
0005433987129	0F7E3B	7986 588716	ALINA ALEKSEEVA	{"email": "alina-alekseeva_1979@postgrespro.ru", "phone": "+70877935607"}
0005433987130	846908	5309 226433	VLADIMIR DENISOV	{"phone": "+70644087251"}
0005433987131	846908	9145 920536	MIKHAIL PAVLOV	{"email": "pavlov-mikhail_09101973@postgrespro.ru", "phone": "+70858524119"}
0005433987132	846908	1594 000598	SERGEY KUZMIN	{"email": "sergeykuzmin-101962@postgrespro.ru", "phone": "+70244498554"}
0005433987133	A1EE47	7665 769975	ELIZAVETA POPOVA	{"email": "popova.elizaveta-011966@postgrespro.ru", "phone": "+70850260176"}
0005433987134	1F8A3A	2207 541697	ALEKSANDR AFANASEV	{"phone": "+70321339547"}
0005433987135	43D626	7878 241692	ALEKSEY FEDOROV	{"phone": "+70327796025"}
0005433987136	43D626	2990 331196	VALENTINA ANDREEVA	{"email": "andreeva_valentina031980@postgrespro.ru", "phone": "+70705029642"}
0005433987137	5CFD17	2625 300530	GLEB RODIONOV	{"email": "grodionov.111973@postgrespro.ru", "phone": "+70449070717"}
0005433987138	7BFDE3	7431 939825	MIKHAIL VOROBEV	{"phone": "+70641617546"}
0005433987139	BEDA09	0759 403782	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva-02011974@postgrespro.ru", "phone": "+70688005924"}
0005433987140	9EB628	4607 526606	SERGEY IVANOV	{"phone": "+70648605150"}
0005433987141	F2583F	3976 075082	NADEZHDA ZOTOVA	{"email": "nadezhda.zotova.1981@postgrespro.ru", "phone": "+70978174131"}
0005433987142	214B8E	3900 900248	ANTON ROMANOV	{"phone": "+70919444538"}
0005433987143	8E2B24	5059 394314	LYUDMILA ARKHIPOVA	{"phone": "+70280485560"}
0005433987144	9EC7E6	1524 869008	SERGEY VOLKOV	{"phone": "+70700224948"}
0005433987145	A748AE	2927 740692	ELENA GUSEVA	{"email": "e.guseva.1977@postgrespro.ru", "phone": "+70143166801"}
0005433987146	B7D0C4	6625 042626	NIKITA ALEKSEEV	{"email": "alekseev_n.1964@postgrespro.ru", "phone": "+70333023099"}
0005433987147	44D49C	1154 771987	NADEZHDA SEMENOVA	{"phone": "+70475707701"}
0005433987148	058534	3629 860934	NATALYA LUKYANOVA	{"email": "lukyanovan1962@postgrespro.ru", "phone": "+70310029382"}
0005433987149	0FE446	4964 143765	MARIYA OVCHINNIKOVA	{"phone": "+70346816880"}
0005433987150	002DC9	8696 763245	MAKSIM NOVIKOV	{"email": "m-novikov-24021976@postgrespro.ru", "phone": "+70765000060"}
0005433987151	81BEB1	7392 080769	TAMARA LUKYANOVA	{"email": "tamaralukyanova_1965@postgrespro.ru", "phone": "+70007593932"}
0005433987152	610BE3	9447 006993	NADEZHDA IVANOVA	{"phone": "+70231737766"}
0005433987153	EC10C1	3938 145094	MARIYA FEDOROVA	{"email": "m.fedorova1985@postgrespro.ru", "phone": "+70405893761"}
0005433987154	EC10C1	9124 909232	ALEKSANDR MOROZOV	{"phone": "+70534882702"}
0005433987155	E21C98	8716 429076	EKATERINA DMITRIEVA	{"phone": "+70831349865"}
0005433987156	4A0113	2382 027446	MARIYA SAVELEVA	{"email": "saveleva_m26071969@postgrespro.ru", "phone": "+70777307243"}
0005433987157	FE4505	8822 615918	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov-21031980@postgrespro.ru", "phone": "+70351364346"}
0005433987158	FE4505	5501 568768	OLEG PAVLOV	{"email": "o_pavlov081974@postgrespro.ru", "phone": "+70331015203"}
0005433987159	316662	0046 468470	DMITRIY TARASOV	{"phone": "+70834961571"}
0005433987160	9F9F5E	8691 120068	LYUBOV DENISOVA	{"email": "denisova_lyubov1972@postgrespro.ru", "phone": "+70303288401"}
0005433987161	B9BDEA	4919 892551	LIDIYA FILIPPOVA	{"email": "lidiya-filippova-1980@postgrespro.ru", "phone": "+70192489856"}
0005433987162	034FBF	6881 678569	ALEKSANDR SERGEEV	{"email": "asergeev14031979@postgrespro.ru", "phone": "+70018432656"}
0005433987163	604574	5483 281518	MARINA SERGEEVA	{"email": "sergeevamarina011978@postgrespro.ru", "phone": "+70418259253"}
0005433987164	604574	7153 367440	GALINA VASILEVA	{"email": "galina_vasileva.1958@postgrespro.ru", "phone": "+70676469874"}
0005433987165	067B50	4751 360227	DARYA MIKHAYLOVA	{"email": "mikhaylova_darya1983@postgrespro.ru", "phone": "+70816770581"}
0005433987166	067B50	6010 311187	OLGA ZHURAVLEVA	{"email": "olga_zhuravleva111966@postgrespro.ru", "phone": "+70985828677"}
0005433987167	F99E78	3527 526261	VIKTOR IVANOV	{"email": "viktorivanov1966@postgrespro.ru", "phone": "+70569944402"}
0005433987168	F99E78	2843 839507	EVGENIY KUZNECOV	{"phone": "+70296410275"}
0005433987169	62CD97	9300 579655	EKATERINA KOROLEVA	{"email": "e_koroleva21011980@postgrespro.ru", "phone": "+70584821614"}
0005433987170	E6D866	6292 350404	TATYANA ISAEVA	{"email": "t-isaeva-1964@postgrespro.ru", "phone": "+70369279800"}
0005433987171	16F961	1518 250057	MAKSIM SMIRNOV	{"email": "smirnov-m1971@postgrespro.ru", "phone": "+70329449228"}
0005433987172	4AB7B3	6203 340305	LYUBOV ROMANOVA	{"phone": "+70717176529"}
0005433987173	ECDE19	8287 647883	NIKITA MELNIKOV	{"email": "melnikovnikita-20121970@postgrespro.ru", "phone": "+70971582984"}
0005433987174	ECDE19	9167 996489	ALEKSEY SERGEEV	{"email": "a_sergeev.1977@postgrespro.ru", "phone": "+70301608821"}
0005433987175	0C4EEE	7759 167263	ALEKSANDR FEDOROV	{"email": "a.fedorov.071974@postgrespro.ru", "phone": "+70339157067"}
0005433987176	3DF807	3010 299266	VLADIMIR SHEVCHENKO	{"phone": "+70380473903"}
0005433987177	47B2F9	4619 670904	MAKSIM ZAYCEV	{"email": "m_zaycev_14091978@postgrespro.ru", "phone": "+70052244122"}
0005433987178	47B2F9	1975 241398	ALEKSANDR BELOV	{"email": "belov_aleksandr-101968@postgrespro.ru", "phone": "+70107281873"}
0005433987179	54621D	5289 086909	TATYANA GERASIMOVA	{"email": "gerasimova-t.01081973@postgrespro.ru", "phone": "+70620331013"}
0005433987180	F083BF	4208 652300	LYUBOV VASILEVA	{"email": "vasileva_l101972@postgrespro.ru", "phone": "+70246070075"}
0005433987181	B4C1B6	8885 621258	ANNA SCHERBAKOVA	{"phone": "+70486937513"}
0005433987182	B4C1B6	5609 487646	ANDREY ILIN	{"email": "ilin.andrey.1981@postgrespro.ru", "phone": "+70514040811"}
0005433987183	DCC424	1329 040389	MARIYA SOKOLOVA	{"email": "sokolova_m_26021969@postgrespro.ru", "phone": "+70786827257"}
0005433987184	5EF867	5080 768813	VLADISLAV RODIONOV	{"phone": "+70206849598"}
0005433987185	7CFD57	8955 951422	SERGEY MAKSIMOV	{"phone": "+70349517062"}
0005433987186	7CFD57	7936 405817	VLADIMIR POPOV	{"phone": "+70705441514"}
0005433987187	1AC525	2662 231981	NADEZHDA ANTONOVA	{"email": "nadezhdaantonova_1969@postgrespro.ru", "phone": "+70059510040"}
0005433987188	1AC525	4043 252923	VIKTOR KULIKOV	{"email": "viktor-kulikov_111977@postgrespro.ru", "phone": "+70470810764"}
0005433987189	BD9BD7	8419 421961	ALEKSANDR PETROV	{"email": "a-petrov_1968@postgrespro.ru", "phone": "+70150109451"}
0005433987190	BD9BD7	3427 561835	TATYANA KONOVALOVA	{"phone": "+70183089735"}
0005433987191	554552	1015 598911	VALERIY ORLOV	{"email": "valeriy_orlov_18091974@postgrespro.ru", "phone": "+70755253535"}
0005433987192	16B3E5	1943 015349	TATYANA MALYSHEVA	{"phone": "+70665860819"}
0005433987193	3053F0	9021 172646	ALEKSANDR SEMENOV	{"phone": "+70306285068"}
0005433987194	53B966	9271 599813	YURIY DENISOV	{"email": "denisov.y.071964@postgrespro.ru", "phone": "+70982979459"}
0005433987195	9325E1	5306 556121	SOFYA FEDOROVA	{"email": "s.fedorova_1983@postgrespro.ru", "phone": "+70387207662"}
0005433987196	488C81	3228 584192	RUSTEM IVANOV	{"phone": "+70590369324"}
0005433987197	3EB86E	7621 933357	OLEG PETROV	{"phone": "+70855055390"}
0005433987198	3EB86E	3586 279969	ELENA VASILEVA	{"email": "vasileva.elena.1967@postgrespro.ru", "phone": "+70034447639"}
0005433987199	7788AC	7833 769201	NADEZHDA SIDOROVA	{"email": "sidorova_nadezhda_28081970@postgrespro.ru", "phone": "+70101545199"}
0005433987200	441033	1990 107535	ALEKSANDR NIKOLAEV	{"phone": "+70749442735"}
0005433987201	441033	8165 263514	YULIYA PAVLOVA	{"phone": "+70224824966"}
0005433987202	441033	7594 537379	ALENA KUDRYASHOVA	{"phone": "+70548306069"}
0005433987203	36E360	9766 059087	RAISA KALININA	{"phone": "+70869431856"}
0005433987204	9F8AE4	9039 090856	VALERIY STEPANOV	{"phone": "+70181980343"}
0005433987205	807750	2373 819089	ANATOLIY MOROZOV	{"email": "anatoliymorozov_10081969@postgrespro.ru", "phone": "+70541615769"}
0005433987206	98C37D	9911 865366	NIKOLAY ROMANOV	{"phone": "+70161995033"}
0005433987207	98C37D	2924 059733	EVGENIY SHEVCHENKO	{"phone": "+70348040094"}
0005433987208	E18D0B	9878 134886	OLGA SOROKINA	{"email": "sorokina.o.26061965@postgrespro.ru", "phone": "+70345221725"}
0005433987209	E18D0B	0907 197025	MARIYA SIDOROVA	{"email": "mariya-sidorova-14111973@postgrespro.ru", "phone": "+70053674827"}
0005433987210	F45E73	8386 292066	VLADIMIR KULIKOV	{"email": "vladimirkulikov_041977@postgrespro.ru", "phone": "+70301522392"}
0005433987211	F45E73	6730 461573	RIMMA OSIPOVA	{"email": "osipova-r-111968@postgrespro.ru", "phone": "+70741539899"}
0005433987213	3216A6	7595 422055	OLEG KUZMIN	{"phone": "+70947150682"}
0005433987214	F4EC88	9020 769735	ALEKSANDR KONOVALOV	{"phone": "+70151121016"}
0005433987215	635826	5989 191474	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev-051970@postgrespro.ru", "phone": "+70438704736"}
0005433987216	8D480C	7076 169370	EGOR FEDOROV	{"email": "fedorov.e-1969@postgrespro.ru", "phone": "+70240324495"}
0005433987217	8D480C	1338 388554	EVA KUZNECOVA	{"phone": "+70916268574"}
0005433987218	8D480C	5296 391176	ALEKSANDR ANTONOV	{"phone": "+70777044100"}
0005433987219	050E3F	9313 544072	LYUDMILA ARKHIPOVA	{"email": "lyudmilaarkhipova1971@postgrespro.ru", "phone": "+70446638384"}
0005433987220	80AB90	4542 411674	DIANA KULIKOVA	{"phone": "+70829447055"}
0005433987221	1E244D	5138 744365	VIKTOR KUZNECOV	{"email": "viktor_kuznecov26071981@postgrespro.ru", "phone": "+70686395122"}
0005433987222	55B765	6101 655712	SERGEY KOZLOV	{"phone": "+70712495551"}
0005433987223	94A7A6	4739 265323	TATYANA KOZLOVA	{"phone": "+70629205716"}
0005433987224	94A7A6	4333 974586	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-18111969@postgrespro.ru", "phone": "+70296264081"}
0005433987225	14091E	7122 638502	MARIYA KOZLOVA	{"email": "mkozlova15081971@postgrespro.ru", "phone": "+70162273241"}
0005433987226	B6802C	6294 142021	DARYA KONDRATEVA	{"email": "dkondrateva011972@postgrespro.ru", "phone": "+70839957462"}
0005433987227	B6802C	2443 288556	ILYA MARTYNOV	{"email": "martynov-i.1970@postgrespro.ru", "phone": "+70573538534"}
0005433987228	572C46	9554 176072	VASILIY PAVLOV	{"email": "v_pavlov.15041978@postgrespro.ru", "phone": "+70658980449"}
0005433987229	ED30BD	2587 189501	ILYA IVANOV	{"phone": "+70194371868"}
0005433987230	ED30BD	6158 814092	ALEKSANDR FROLOV	{"phone": "+70151321971"}
0005433987231	176826	4792 902421	YULIYA MIKHAYLOVA	{"phone": "+70140376629"}
0005433987232	83B072	7081 269991	TATYANA ISAEVA	{"email": "isaevat.091969@postgrespro.ru", "phone": "+70011737325"}
0005433987233	D03EEA	0745 684050	NIKOLAY NIKITIN	{"email": "nikolay_nikitin.031970@postgrespro.ru", "phone": "+70380857711"}
0005433987234	FE0116	4811 786018	ILYA KRASNOV	{"email": "ilya-krasnov-041971@postgrespro.ru", "phone": "+70072074760"}
0005433987235	838610	0290 779429	TAMARA KUZNECOVA	{"phone": "+70706632293"}
0005433987236	A0B975	0259 709061	RAVILYA ROMANOVA	{"email": "romanova_r.121963@postgrespro.ru", "phone": "+70901631464"}
0005433987237	A0B975	1919 644140	EKATERINA PETROVA	{"phone": "+70547795364"}
0005433987238	FFC86C	6716 321251	ALEVTINA STEPANOVA	{"phone": "+70622416212"}
0005433987239	D76607	4951 212718	ILYA SMIRNOV	{"email": "ilya.smirnov.1974@postgrespro.ru", "phone": "+70637611440"}
0005433987240	D76607	5505 121888	VADIM TARASOV	{"email": "vadim_tarasov-1975@postgrespro.ru", "phone": "+70998492877"}
0005433987241	BF45DF	0082 481802	BORIS EGOROV	{"email": "borisegorov.11101982@postgrespro.ru", "phone": "+70675922046"}
0005433987242	E75211	2224 739209	MIKHAIL RODIONOV	{"phone": "+70829933243"}
0005433987243	24EC1A	1604 887922	EVGENIY MEDVEDEV	{"email": "evgeniy_medvedev07061977@postgrespro.ru", "phone": "+70401453490"}
0005433987244	8657F0	5154 038745	RAISA ORLOVA	{"email": "orlova.r-031955@postgrespro.ru", "phone": "+70291895113"}
0005433987245	202432	6799 807496	FAINA BELOVA	{"phone": "+70644415663"}
0005433987246	1734BD	7081 973434	VASILIY SIDOROV	{"phone": "+70490218778"}
0005433987247	1734BD	5277 386651	NATALYA TROFIMOVA	{"email": "trofimova_natalya.071988@postgrespro.ru", "phone": "+70242957487"}
0005433987248	4AA948	5638 281803	ANASTASIYA ORLOVA	{"email": "aorlova.24101977@postgrespro.ru", "phone": "+70763984558"}
0005433987249	4AA948	3119 037557	MIKHAIL MARTYNOV	{"email": "martynov_mikhail-021972@postgrespro.ru", "phone": "+70507009750"}
0005433987250	EEDD46	8812 329044	GALINA SOKOLOVA	{"phone": "+70431737953"}
0005433987251	243237	7895 790960	SERGEY FILIPPOV	{"phone": "+70773696506"}
0005433987252	02FA47	5663 054473	ANDREY MARTYNOV	{"phone": "+70465471842"}
0005433987253	02FA47	9951 912247	YURIY BORISOV	{"phone": "+70153585429"}
0005433987254	74E768	0413 340955	ANNA SCHERBAKOVA	{"phone": "+70463186547"}
0005433987255	953345	7762 979138	NATALIYA FROLOVA	{"phone": "+70937267899"}
0005433987256	FCF7E4	1890 922541	OLGA ISAEVA	{"email": "isaevao081969@postgrespro.ru", "phone": "+70698141664"}
0005433987257	32F4C9	9848 987995	ANGELINA RYABOVA	{"email": "a.ryabova19041972@postgrespro.ru", "phone": "+70267966027"}
0005433987258	1F57A2	7707 701706	EGOR VASILEV	{"phone": "+70693082435"}
0005433987259	DCFEC4	1525 803742	OLGA EFIMOVA	{"email": "olga.efimova_07081975@postgrespro.ru", "phone": "+70759453343"}
0005433987260	2D1F85	7439 509853	VALENTINA YUDINA	{"phone": "+70205770593"}
0005433987261	3072DB	2155 471526	SVETLANA KISELEVA	{"email": "kiseleva_svetlana.1972@postgrespro.ru", "phone": "+70397729806"}
0005433987262	3072DB	8327 417906	OLGA STEPANOVA	{"email": "o_stepanova_04031976@postgrespro.ru", "phone": "+70334449453"}
0005433987263	2ADFB2	7268 294118	ULYANA KOROLEVA	{"phone": "+70723827647"}
0005433987264	4CDAFF	1427 991672	TATYANA FROLOVA	{"email": "frolovat-1976@postgrespro.ru", "phone": "+70817876215"}
0005433987265	4CDAFF	6855 794820	VALERIYA MIRONOVA	{"email": "vmironova_1972@postgrespro.ru", "phone": "+70696438223"}
0005433987266	EAA20B	8029 066775	TATYANA TITOVA	{"email": "t_titova-051982@postgrespro.ru", "phone": "+70927714255"}
0005433987267	3EACC8	8913 396934	ANASTASIYA RODIONOVA	{"email": "a.rodionova.021977@postgrespro.ru", "phone": "+70711176763"}
0005433987268	329BA7	9726 092646	NADEZHDA BARANOVA	{"email": "baranova.nadezhda_071968@postgrespro.ru", "phone": "+70283612706"}
0005433987269	ED6867	7524 466386	MARIYA MATVEEVA	{"phone": "+70031861446"}
0005433987270	F157F7	6227 930955	VERA NAZAROVA	{"email": "nazarovav-1966@postgrespro.ru", "phone": "+70502746259"}
0005433987271	9DB507	0120 468015	PAVEL IVANOV	{"phone": "+70285920843"}
0005433987272	9DB507	7237 081304	KSENIYA GORBUNOVA	{"phone": "+70553245054"}
0005433987273	53CC14	1007 384365	ALEKSANDR KONOVALOV	{"phone": "+70401121609"}
0005433987274	53CC14	8177 698293	ALEKSANDR TIKHONOV	{"phone": "+70359349568"}
0005433987275	FD6865	6415 748202	ANDREY SERGEEV	{"phone": "+70922843887"}
0005433987276	FD6865	5651 652980	OKSANA ILINA	{"email": "oksana.ilina-031973@postgrespro.ru", "phone": "+70556447084"}
0005433987277	00D77C	9637 428193	SERGEY OSIPOV	{"phone": "+70864695165"}
0005433987278	00D77C	6520 098055	ANNA KAZAKOVA	{"email": "anna_kazakova_1965@postgrespro.ru", "phone": "+70648225129"}
0005433987279	F043EB	1336 535046	PETR MAKAROV	{"phone": "+70676143307"}
0005433987280	2AA356	9009 485893	VIKTOR ZAKHAROV	{"phone": "+70347487516"}
0005433987281	AA6ED4	8922 504578	TATYANA KARPOVA	{"phone": "+70472649218"}
0005433987282	AB9863	9030 016384	VALERIYA VLASOVA	{"phone": "+70887921098"}
0005433987283	655853	8025 462364	MAKSIM SCHERBAKOV	{"phone": "+70566951059"}
0005433987284	0E4DE4	1659 602407	EVGENIY BORISOV	{"email": "e-borisov_021974@postgrespro.ru", "phone": "+70014332257"}
0005433987285	2AEB75	5608 925440	YAROSLAV IVANOV	{"phone": "+70231219075"}
0005433987286	774F2B	0184 162648	ALEKSANDR VASILEV	{"email": "a-vasilev_121966@postgrespro.ru", "phone": "+70563926441"}
0005433987287	125632	5123 981965	VLADIMIR GUSEV	{"email": "gusevv.101958@postgrespro.ru", "phone": "+70867871370"}
0005433987288	E693AB	3147 975079	SVETLANA POPOVA	{"phone": "+70952817288"}
0005433987289	151A52	6005 291783	LIDIYA BARANOVA	{"phone": "+70498362882"}
0005433987290	AE0E63	0402 130307	YULIYA KUDRYASHOVA	{"phone": "+70758328030"}
0005433987291	2375E0	3064 576597	VARVARA ERMAKOVA	{"email": "varvara-ermakova-041965@postgrespro.ru", "phone": "+70260141875"}
0005433987292	2375E0	3621 050966	STANISLAV IVANOV	{"phone": "+70915071092"}
0005433987293	7697C5	1019 724540	LYUDMILA LOGINOVA	{"phone": "+70699117327"}
0005433987294	03E023	1756 956896	VALENTINA BORISOVA	{"email": "valentina.borisova-1978@postgrespro.ru", "phone": "+70872290775"}
0005433987295	B9F15F	1383 316356	KRISTINA KUZNECOVA	{"email": "kuznecova_kristina_07081966@postgrespro.ru", "phone": "+70208658260"}
0005433987296	B9F15F	5692 886203	DMITRIY BORISOV	{"email": "borisov-d-1979@postgrespro.ru", "phone": "+70105634310"}
0005433987297	F57EB3	2002 276569	MAKSIM PETROV	{"email": "maksim-petrov1962@postgrespro.ru", "phone": "+70374867243"}
0005433987298	F57EB3	3175 279767	OLGA SMIRNOVA	{"email": "smirnova-olga.08051974@postgrespro.ru", "phone": "+70719355603"}
0005433987299	5CCC6B	7164 164794	GALINA KARPOVA	{"email": "galina.karpova_1969@postgrespro.ru", "phone": "+70960191682"}
0005433987300	791E24	1792 405243	SVETLANA RODIONOVA	{"email": "rodionovas1990@postgrespro.ru", "phone": "+70084037917"}
0005433987301	2F0D5E	1022 833768	ROMAN KUZNECOV	{"phone": "+70538974210"}
0005433987302	6D53DE	5294 822332	SERGEY DENISOV	{"email": "denisov-s_011972@postgrespro.ru", "phone": "+70410718935"}
0005433987303	C17841	7948 860895	DMITRIY POPOV	{"phone": "+70775958102"}
0005433987304	C17841	8086 332915	ELENA VASILEVA	{"phone": "+70821596393"}
0005433987305	954F48	0931 707609	ELENA KARPOVA	{"email": "elena_karpova-031977@postgrespro.ru", "phone": "+70304209279"}
0005433987306	954F48	0862 718568	SERGEY MATVEEV	{"email": "smatveev-1977@postgrespro.ru", "phone": "+70848778370"}
0005433987307	954F48	0863 286644	DMITRIY DAVYDOV	{"phone": "+70156918954"}
0005433987308	954F48	6975 488103	ZINAIDA KOROLEVA	{"phone": "+70984494620"}
0005433987309	7FEF6D	5784 943083	TATYANA RYABOVA	{"phone": "+70902075024"}
0005433987310	7FEF6D	6054 405888	PETR POPOV	{"phone": "+70313132381"}
0005433987311	2704E2	7541 677364	ANDREY KRASNOV	{"phone": "+70975729103"}
0005433987312	2704E2	1256 586943	MIKHAIL FOMIN	{"phone": "+70720234465"}
0005433987313	C55331	2530 514727	MAKSIM VASILEV	{"phone": "+70919594148"}
0005433987314	C55331	7954 372149	ALEKSEY BONDARENKO	{"email": "bondarenko.a30081974@postgrespro.ru", "phone": "+70314541899"}
0005433987315	124F8C	6986 280660	VALERIYA BOGDANOVA	{"phone": "+70675567916"}
0005433987316	60E7B8	8484 761774	VLADIMIR MOROZOV	{"email": "morozov.v.111967@postgrespro.ru", "phone": "+70021941165"}
0005433987317	1A4407	7946 727379	IVAN SMIRNOV	{"phone": "+70556560100"}
0005433987318	55D9DD	7706 521460	DENIS IVANOV	{"email": "d.ivanov.051970@postgrespro.ru", "phone": "+70811323723"}
0005433987319	55D9DD	0683 452300	VIKTORIYA MIKHAYLOVA	{"phone": "+70771805829"}
0005433987320	180422	8606 862209	ELVIRA SOKOLOVA	{"email": "elvira_sokolova-1971@postgrespro.ru", "phone": "+70896751184"}
0005433987321	540004	4928 750318	SVETLANA MASLOVA	{"phone": "+70668123979"}
0005433987322	540004	9914 822010	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr13071963@postgrespro.ru", "phone": "+70224025452"}
0005433987323	31B47F	2563 085656	TATYANA TARASOVA	{"phone": "+70064411774"}
0005433987324	31B47F	6276 712001	VLADIMIR AFANASEV	{"phone": "+70729809685"}
0005433987325	128855	2493 230832	ANTON MAKAROV	{"email": "makarovanton_051971@postgrespro.ru", "phone": "+70699857061"}
0005433987326	128855	3558 373117	ALEKSANDR FROLOV	{"phone": "+70391460966"}
0005433987327	352DAA	6703 808604	VLADIMIR IVANOV	{"phone": "+70826338053"}
0005433987328	C7BD30	0614 488031	VLADIMIR YAKOVLEV	{"email": "v-yakovlev_091960@postgrespro.ru", "phone": "+70566237487"}
0005433987329	C7BD30	4873 506151	KLAVDIYA STEPANOVA	{"phone": "+70871072025"}
0005433987330	B214E4	9367 996434	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr.27091962@postgrespro.ru", "phone": "+70064919134"}
0005433987331	948985	7077 195823	VLADIMIR MOROZOV	{"phone": "+70094491885"}
0005433987332	14B579	9636 141941	SERGEY ROMANOV	{"phone": "+70461555678"}
0005433987333	89A0E3	7652 790090	VASILIY GERASIMOV	{"email": "gerasimov-vasiliy121971@postgrespro.ru", "phone": "+70896280066"}
0005433987334	062F7D	8843 731287	SERGEY ANTONOV	{"email": "sergey-antonov15041971@postgrespro.ru", "phone": "+70574343564"}
0005433987335	74099D	0155 126445	GALINA BARANOVA	{"email": "baranovagalina_1988@postgrespro.ru", "phone": "+70186713366"}
0005433987336	D6BE1F	2003 033124	VYACHESLAV SEMENOV	{"phone": "+70148742893"}
0005433987337	6248D0	7245 365620	MARINA VLASOVA	{"email": "marina-vlasova_05101978@postgrespro.ru", "phone": "+70973148570"}
0005433987338	7D47E7	3267 243103	VIKTOR FEDOTOV	{"phone": "+70472307904"}
0005433987339	16025A	3661 763225	NATALYA LOGINOVA	{"phone": "+70472804618"}
0005433987340	16025A	3501 844275	DMITRIY ANTONOV	{"phone": "+70162191916"}
0005433987341	A92BF6	0897 227141	VALERIY MAKAROV	{"phone": "+70908553421"}
0005433987342	A92BF6	5153 949958	SERGEY GRIGOREV	{"email": "grigorev.sergey.111968@postgrespro.ru", "phone": "+70583540590"}
0005433987343	A92BF6	7510 763167	LYUBOV GUSEVA	{"email": "lguseva_071978@postgrespro.ru", "phone": "+70891735133"}
0005433987344	592B10	4051 069061	ANZHELIKA RYABOVA	{"email": "anzhelika.ryabova-1988@postgrespro.ru", "phone": "+70556312450"}
0005433987345	592B10	6836 917036	ALEKSANDR SIDOROV	{"email": "a.sidorov.1974@postgrespro.ru", "phone": "+70168132767"}
0005433987346	592B10	8267 852117	NINA LAZAREVA	{"phone": "+70440032665"}
0005433987347	47362A	6457 898116	DMITRIY SOROKIN	{"email": "sorokin_d071970@postgrespro.ru", "phone": "+70120778132"}
0005433987348	47362A	8879 430165	VIKTORIYA ARKHIPOVA	{"email": "arkhipova-v-1964@postgrespro.ru", "phone": "+70572132019"}
0005433987349	05B980	8073 947898	GENNADIY IVANOV	{"phone": "+70102833567"}
0005433987350	05B980	6060 638759	SERGEY ANDREEV	{"phone": "+70505872867"}
0005433987351	C90A84	7670 758311	LYUDMILA MIKHAYLOVA	{"email": "mikhayloval-1976@postgrespro.ru", "phone": "+70454895729"}
0005433987352	C90A84	5861 530261	ANDREY SEMENOV	{"phone": "+70783505017"}
0005433987353	A9CDEA	3584 360766	TATYANA SEMENOVA	{"email": "semenova_t_05041967@postgrespro.ru", "phone": "+70719811207"}
0005433987354	ED5862	0544 867484	MARIYA MIRONOVA	{"email": "mironova.mariya_29091971@postgrespro.ru", "phone": "+70109207860"}
0005433987355	E65421	5251 485695	VIKTORIYA DENISOVA	{"email": "v_denisova_1967@postgrespro.ru", "phone": "+70129181363"}
0005433987356	32576A	6745 955417	TATYANA SMIRNOVA	{"phone": "+70900440181"}
0005433987357	32576A	9339 286496	VALENTINA FROLOVA	{"email": "valentina_frolova-02041969@postgrespro.ru", "phone": "+70740803005"}
0005433987358	EF15B1	8278 082907	ELVIRA MAKAROVA	{"email": "emakarova.1969@postgrespro.ru", "phone": "+70324686162"}
0005433987359	B2DEC5	1889 616395	VASILIY ZHUKOV	{"phone": "+70680056387"}
0005433987360	802385	8218 900680	SOFYA SOKOLOVA	{"phone": "+70714780938"}
0005433987361	802385	0701 701193	ANNA MATVEEVA	{"email": "matveeva_a.1981@postgrespro.ru", "phone": "+70374059172"}
0005433987362	C5E8D6	3253 320361	LYUBOV ZHURAVLEVA	{"phone": "+70724601939"}
0005433987363	A859D0	3824 621324	MARINA ZAKHAROVA	{"email": "zakharova_m.051976@postgrespro.ru", "phone": "+70303479163"}
0005433987364	55B8FF	0084 534096	PAVEL ISAEV	{"phone": "+70283434517"}
0005433987365	12C6CC	7175 416669	LYUDMILA CHERNOVA	{"email": "chernova-l1983@postgrespro.ru", "phone": "+70333729361"}
0005433987366	12C6CC	2333 376070	VIKTORIYA KUZMINA	{"email": "kuzmina.viktoriya1982@postgrespro.ru", "phone": "+70734322010"}
0005433987367	F04032	5975 739675	ELENA KARPOVA	{"phone": "+70022527017"}
0005433987368	F0E89D	9904 779171	YULIYA SCHERBAKOVA	{"phone": "+70741604456"}
0005433987369	4EEFA0	5433 570514	ALEKSANDR PETROV	{"phone": "+70513408351"}
0005433987370	4EEFA0	4926 229304	KSENIYA SOLOVEVA	{"email": "k-soloveva.24071973@postgrespro.ru", "phone": "+70632042800"}
0005433987371	31DECC	1367 471855	NADEZHDA BARANOVA	{"phone": "+70582520033"}
0005433987372	D5CB88	9325 903272	LARISA SMIRNOVA	{"phone": "+70666366311"}
0005433987373	D7DA82	1144 954198	DIANA SIDOROVA	{"phone": "+70033303004"}
0005433987374	3FA3BC	7297 662783	EKATERINA OSIPOVA	{"phone": "+70520752896"}
0005433987375	BA384E	0064 245347	SERGEY MIRONOV	{"phone": "+70314989235"}
0005433987376	6E839F	7932 470369	VLADIMIR BELOV	{"email": "v-belov-13071980@postgrespro.ru", "phone": "+70358114017"}
0005433987377	6E839F	2836 556229	NADIYA LUKYANOVA	{"email": "lukyanova.n.29011963@postgrespro.ru", "phone": "+70995004843"}
0005433987378	261037	5186 752797	FAINA BORISOVA	{"phone": "+70953911827"}
0005433987379	06C89F	8146 562225	FEDOR FILIPPOV	{"email": "filippov.fedor.23121970@postgrespro.ru", "phone": "+70113531800"}
0005433987380	554857	4896 592281	RENAT NOVIKOV	{"email": "novikov-r_19081967@postgrespro.ru", "phone": "+70092649216"}
0005433987381	554857	4329 833153	VYACHESLAV ALEKSANDROV	{"email": "aleksandrovv1981@postgrespro.ru", "phone": "+70014124162"}
0005433989681	1501F0	1291 789309	VLADIMIR MIKHAYLOV	{"phone": "+70734067159"}
0005433989682	1501F0	0670 072123	ANDREY ANTONOV	{"phone": "+70593652277"}
0005433989683	490A04	2590 594207	ARTEM EGOROV	{"email": "artem.egorov101983@postgrespro.ru", "phone": "+70251525032"}
0005433989684	490A04	6264 814676	LYUDMILA GRISHINA	{"phone": "+70234129973"}
0005433989685	9DB48A	7413 422590	TAMARA TARASOVA	{"email": "tarasova.t_1972@postgrespro.ru", "phone": "+70622819992"}
0005433989686	9DB48A	3138 405378	OLGA MOROZOVA	{"phone": "+70248987322"}
0005433989687	9DB48A	1884 834782	VLADIMIR ALEKSANDROV	{"phone": "+70351110492"}
0005433989688	37BEC4	5675 355100	MIKHAIL PETROV	{"email": "mpetrov_13021978@postgrespro.ru", "phone": "+70223289764"}
0005433989689	F7EC4E	4519 846203	SERGEY ANTONOV	{"phone": "+70895459802"}
0005433989690	4B6037	5011 472912	SVETLANA NIKIFOROVA	{"email": "nikiforova.s.1978@postgrespro.ru", "phone": "+70794109307"}
0005433989691	4B6037	4027 656033	NATALYA VOROBEVA	{"phone": "+70892861198"}
0005433989692	0BC4DA	5206 638291	ELENA SEMENOVA	{"email": "elenasemenova-101964@postgrespro.ru", "phone": "+70603269117"}
0005433989693	C2DA4D	2692 036127	BORIS DAVYDOV	{"phone": "+70754872242"}
0005433989694	C2DA4D	4742 053007	ALEKSANDR MAKAROV	{"phone": "+70727914149"}
0005433989695	416915	0497 974088	DARYA ANDREEVA	{"email": "d_andreeva041962@postgrespro.ru", "phone": "+70027784952"}
0005433989696	416915	4272 663256	ALEKSEY KUZNECOV	{"phone": "+70874489947"}
0005433989697	985C9C	6144 784019	NATALYA MAKSIMOVA	{"email": "maksimovanatalya.05031965@postgrespro.ru", "phone": "+70548877924"}
0005433989698	A40661	5942 145226	EVGENIY SERGEEV	{"phone": "+70413828581"}
0005433989699	0E8495	0685 233046	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr.12071967@postgrespro.ru", "phone": "+70002733534"}
0005433989700	441ADC	7444 864915	TATYANA POPOVA	{"phone": "+70141722991"}
0005433989701	3A9498	4419 778775	ELENA GORBUNOVA	{"email": "gorbunova.elena_19061970@postgrespro.ru", "phone": "+70214525024"}
0005433989702	835F8D	3296 710187	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov_16081977@postgrespro.ru", "phone": "+70347593996"}
0005433989703	835F8D	6792 866124	ALEKSEY GRIGOREV	{"email": "grigorev.a_101973@postgrespro.ru", "phone": "+70429379279"}
0005433989704	B11A28	9916 032976	VYACHESLAV GRIGOREV	{"phone": "+70706542688"}
0005433989705	E07DDE	6200 932387	IRINA GERASIMOVA	{"email": "i_gerasimova.1971@postgrespro.ru", "phone": "+70933068289"}
0005433989706	E07DDE	0125 213662	YULIYA BORISOVA	{"phone": "+70982643165"}
0005433989707	E07DDE	6224 595921	NELLI KUZNECOVA	{"email": "kuznecovanelli_1970@postgrespro.ru", "phone": "+70292481605"}
0005433989708	84621B	2908 518061	GENNADIY POPOV	{"email": "popov.g.09071985@postgrespro.ru", "phone": "+70816513644"}
0005433989709	AA142E	4145 659252	GULSHAT NIKOLAEVA	{"email": "g.nikolaeva-071977@postgrespro.ru", "phone": "+70476249668"}
0005433989710	650D02	1523 134225	GEORGIY SOROKIN	{"email": "sorokin.g.24101968@postgrespro.ru", "phone": "+70848883618"}
0005433989711	31568F	3108 968786	MAKSIM KUZMIN	{"email": "kuzmin-maksim_1971@postgrespro.ru", "phone": "+70558400003"}
0005433989712	31568F	7992 227986	MIKHAIL POPOV	{"phone": "+70073015011"}
0005433989713	C77F89	3281 072838	POLINA MIKHAYLOVA	{"email": "p.mikhaylova.021987@postgrespro.ru", "phone": "+70332771665"}
0005433989714	CDA272	2296 318375	YURIY SEMENOV	{"phone": "+70400622545"}
0005433989715	986717	4660 023785	TATYANA AFANASEVA	{"phone": "+70370919636"}
0005433989716	B37DC4	6909 724970	VALERIY MIRONOV	{"email": "mironov.valeriy.05041964@postgrespro.ru", "phone": "+70128638251"}
0005433989717	B37DC4	3527 687402	VYACHESLAV IVANOV	{"phone": "+70596204008"}
0005433989718	B37DC4	7478 076969	ALEKSEY FEDOROV	{"email": "fedorov.aleksey.091981@postgrespro.ru", "phone": "+70210944843"}
0005433989719	C2791E	8785 610396	ALEKSANDR ABRAMOV	{"phone": "+70981606002"}
0005433989720	74B482	0098 994148	VIKTORIYA MAKAROVA	{"phone": "+70165815923"}
0005433989721	8436F7	2046 856489	YULIYA MEDVEDEVA	{"email": "yuliyamedvedeva-1967@postgrespro.ru", "phone": "+70198491268"}
0005433989722	8436F7	9036 654091	EVGENIYA BORISOVA	{"email": "eborisova.20061967@postgrespro.ru", "phone": "+70570443044"}
0005433989723	5CACA0	6608 508937	LYUDMILA NIKOLAEVA	{"email": "lnikolaeva_011973@postgrespro.ru", "phone": "+70307355699"}
0005433989724	429E83	4951 524813	NIKOLAY NAZAROV	{"phone": "+70622206923"}
0005433989725	304849	5638 526200	ANDREY ZHURAVLEV	{"email": "zhuravlev-andrey_22061962@postgrespro.ru", "phone": "+70507165269"}
0005433989726	76C4E8	1435 828692	NATALIYA MAKAROVA	{"phone": "+70906847153"}
0005433989727	76C4E8	2963 118268	LEONID IVANOV	{"email": "l.ivanov-1959@postgrespro.ru", "phone": "+70428341404"}
0005433989728	F5FD8C	3398 390208	ANATOLIY OSIPOV	{"phone": "+70329756573"}
0005433989729	F5FD8C	5741 698221	VALERIY ZHURAVLEV	{"phone": "+70149626002"}
0005433989730	834EC0	8657 422156	SERGEY VOROBEV	{"email": "sergey-vorobev.1979@postgrespro.ru", "phone": "+70292700405"}
0005433989731	6C517E	9564 128298	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov-v.24051970@postgrespro.ru", "phone": "+70001247556"}
0005433989732	6C517E	5757 625200	MARINA TIMOFEEVA	{"phone": "+70362013520"}
0005433989733	C2B276	6358 241747	MARIYA ISAEVA	{"phone": "+70537545255"}
0005433989734	C2B276	0709 327665	NINA ANISIMOVA	{"phone": "+70074292976"}
0005433989735	2F594E	4156 278176	GRIGORIY EGOROV	{"email": "egorov.g-071969@postgrespro.ru", "phone": "+70066578302"}
0005433989736	B90C77	9767 888362	NADEZHDA SEMENOVA	{"phone": "+70516268903"}
0005433989737	21372C	1578 506902	ANZHELA OVCHINNIKOVA	{"email": "ovchinnikova-a_051972@postgrespro.ru", "phone": "+70718969486"}
0005433989738	5E3C5E	5388 935736	STANISLAV FEDOTOV	{"phone": "+70308906537"}
0005433989739	5E3C5E	5730 166901	ANATOLIY ALEKSEEV	{"phone": "+70096845406"}
0005433989740	ACDA43	0002 416895	IVAN SHEVCHENKO	{"email": "shevchenko.ivan.1955@postgrespro.ru", "phone": "+70836629409"}
0005433989741	A94AB7	6191 735800	ALEKSEY MIKHAYLOV	{"email": "mikhaylovaleksey_1972@postgrespro.ru", "phone": "+70791385018"}
0005433989742	A94AB7	9621 669452	SERGEY MAKSIMOV	{"email": "sergey.maksimov-25051983@postgrespro.ru", "phone": "+70749999744"}
0005433989743	A94AB7	2588 336546	MARIYA ARKHIPOVA	{"email": "arkhipova-mariya1974@postgrespro.ru", "phone": "+70012115361"}
0005433989744	73C860	6787 462694	LYUDMILA NIKITINA	{"phone": "+70503172661"}
0005433989745	DF4A87	5368 669607	OKSANA BARANOVA	{"email": "baranova.o.101962@postgrespro.ru", "phone": "+70646200578"}
0005433989746	CF6380	7635 275730	DENIS POPOV	{"email": "popov.denis1984@postgrespro.ru", "phone": "+70071143175"}
0005433989747	14EC1A	3709 001873	NADEZHDA SMIRNOVA	{"email": "nadezhda-smirnova-091981@postgrespro.ru", "phone": "+70460843683"}
0005433989748	8CD564	5431 874038	TAMARA KRASNOVA	{"phone": "+70113602477"}
0005433989749	8CD564	9487 913284	LARISA MAKSIMOVA	{"phone": "+70652246164"}
0005433989750	ED2709	9803 943416	ARTUR DAVYDOV	{"email": "davydov_a-17051984@postgrespro.ru", "phone": "+70506570925"}
0005433989751	C90D99	9367 102922	NATALYA NOVIKOVA	{"email": "natalya_novikova.031962@postgrespro.ru", "phone": "+70690483453"}
0005433989752	E1F535	7503 406131	ELENA AKIMOVA	{"email": "akimova-elena-26051959@postgrespro.ru", "phone": "+70424201623"}
0005433989753	CF485E	4096 782799	ANNA KOROLEVA	{"phone": "+70842125601"}
0005433989754	CF485E	5026 782546	RAISA DAVYDOVA	{"phone": "+70733691230"}
0005433989755	8A2BF5	4582 843785	MAKSIM FEDOROV	{"phone": "+70077672410"}
0005433989756	196AAB	7924 360802	ALEKSANDR NAUMOV	{"phone": "+70043485757"}
0005433989757	196AAB	5281 158157	MARIYA POPOVA	{"email": "popova.m_24071973@postgrespro.ru", "phone": "+70948957506"}
0005433989758	4CEFC2	1929 341906	OLGA SCHERBAKOVA	{"phone": "+70336619169"}
0005433989759	84EC09	5134 665646	MARIYA FADEEVA	{"email": "fadeevam1957@postgrespro.ru", "phone": "+70498212311"}
0005433989760	84EC09	1666 945802	DMITRIY SOKOLOV	{"phone": "+70771213606"}
0005433989761	8C9F82	7543 387709	DMITRIY FEDOROV	{"email": "fedorov_dmitriy021975@postgrespro.ru", "phone": "+70311551910"}
0005433989762	824AC3	6196 487051	LIDIYA VOLKOVA	{"email": "lidiya_volkova-30031967@postgrespro.ru", "phone": "+70942419801"}
0005433989763	0BCB42	7005 122887	YURIY MAKAROV	{"email": "yuriy_makarov27021977@postgrespro.ru", "phone": "+70232032108"}
0005433989764	0B12EB	1165 626711	ALEKSANDRA NAUMOVA	{"email": "aleksandra-naumova.111966@postgrespro.ru", "phone": "+70355338707"}
0005433989765	0B12EB	9549 446263	VYACHESLAV POPOV	{"phone": "+70770655559"}
0005433989766	A1E77E	3404 333206	IVAN KARPOV	{"email": "karpovi.121966@postgrespro.ru", "phone": "+70186657351"}
0005433989767	B8DDEE	0058 294797	NINA BORISOVA	{"email": "borisovan-1964@postgrespro.ru", "phone": "+70391067651"}
0005433989768	D97651	8981 730907	KONSTANTIN FEDOTOV	{"phone": "+70281611919"}
0005433989769	AE237D	7181 073711	VALERIY KONOVALOV	{"email": "konovalov.valeriy.1970@postgrespro.ru", "phone": "+70375562354"}
0005433989770	777AD8	1716 348102	VLADIMIR FEDOTOV	{"phone": "+70327505094"}
0005433989771	777AD8	1288 236867	KIRILL SEMENOV	{"email": "semenovk-031964@postgrespro.ru", "phone": "+70979072360"}
0005433989772	BCC9E4	9163 152096	MARIYA KISELEVA	{"email": "mariyakiseleva.1971@postgrespro.ru", "phone": "+70516210094"}
0005433989773	BCC9E4	4914 962089	TATYANA ZAYCEVA	{"email": "zayceva-tatyana1967@postgrespro.ru", "phone": "+70839450630"}
0005433989774	BCC9E4	7597 442967	ANASTASIYA LUKYANOVA	{"phone": "+70529116694"}
0005433989775	55DB35	5313 532001	MAKSIM SERGEEV	{"phone": "+70944351894"}
0005433989776	C0C762	9169 158319	IRINA KOZLOVA	{"phone": "+70877953495"}
0005433989777	3173B6	2850 088090	GALINA ZAKHAROVA	{"email": "galinazakharova-04111975@postgrespro.ru", "phone": "+70023706689"}
0005433989778	A370BA	6745 926792	YAROSLAVA SERGEEVA	{"email": "sergeevayaroslava_17031964@postgrespro.ru", "phone": "+70694820067"}
0005433989779	0E5A54	8391 405411	VALENTINA DMITRIEVA	{"phone": "+70127850357"}
0005433989780	BE1CF4	3666 921875	VYACHESLAV GAVRILOV	{"email": "vyacheslav.gavrilov-081976@postgrespro.ru", "phone": "+70497784185"}
0005433989781	A199E1	7508 871821	IGOR IVANOV	{"email": "ivanov.igor.1983@postgrespro.ru", "phone": "+70405905579"}
0005433989782	28218D	3261 970648	NADEZHDA TIKHONOVA	{"phone": "+70188068556"}
0005433989783	52DACC	1510 975253	NIKOLAY VASILEV	{"email": "vasilev-nikolay.081976@postgrespro.ru", "phone": "+70982232869"}
0005433989784	7B0D1F	2016 985681	IGOR SEMENOV	{"email": "semenov-igor_1969@postgrespro.ru", "phone": "+70587216785"}
0005433989785	AC4DD2	7189 877383	MARIYA MOROZOVA	{"phone": "+70257353558"}
0005433989786	50A85D	8986 259791	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov-13091974@postgrespro.ru", "phone": "+70493781520"}
0005433989787	C654E8	2819 680657	ANNA NAZAROVA	{"email": "nazarova.anna.13071976@postgrespro.ru", "phone": "+70652588853"}
0005433989788	497415	7430 234604	VLADIMIR CHERNOV	{"phone": "+70276685735"}
0005433989789	D2592F	9501 748670	NIKOLAY DENISOV	{"phone": "+70229777388"}
0005433989790	D2592F	8010 051794	ULYANA MASLOVA	{"email": "maslova.ulyana_1964@postgrespro.ru", "phone": "+70246308716"}
0005433989791	F3F44B	7767 014185	TATYANA ANISIMOVA	{"email": "anisimovatatyana08021969@postgrespro.ru", "phone": "+70577814737"}
0005433989792	B83909	2143 522224	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev18021963@postgrespro.ru", "phone": "+70632282007"}
0005433989793	B83909	8999 638531	NIKOLAY SHEVCHENKO	{"email": "shevchenko.n.1967@postgrespro.ru", "phone": "+70676615065"}
0005433989794	5E831F	1422 651657	ALEKSEY POPOV	{"phone": "+70433235273"}
0005433989795	539E30	6558 273519	PAVEL GORBUNOV	{"email": "gorbunov_p051975@postgrespro.ru", "phone": "+70611593766"}
0005433989796	C201A7	8911 330237	ALLA IVANOVA	{"email": "a-ivanova1974@postgrespro.ru", "phone": "+70431412833"}
0005433989797	045C06	7698 382828	ANNA ALEKSEEVA	{"phone": "+70721441209"}
0005433989798	B135AA	8720 349715	ELVIRA MAKAROVA	{"email": "elvira_makarova1975@postgrespro.ru", "phone": "+70959520201"}
0005433989799	BE139D	7035 419552	VERA BOGDANOVA	{"phone": "+70807424471"}
0005433989800	BE139D	8327 921823	VASILIY KOZLOV	{"email": "v_kozlov_15061974@postgrespro.ru", "phone": "+70036306690"}
0005433989801	5059C5	2141 388983	OLGA LOGINOVA	{"phone": "+70907168149"}
0005433989802	3388CC	8070 083529	LEONID FEDOROV	{"phone": "+70239384770"}
0005433989803	4FF03B	8355 348605	IVAN SOLOVEV	{"phone": "+70411977054"}
0005433989804	6787C0	6163 306558	OLGA PETROVA	{"email": "petrovaolga1965@postgrespro.ru", "phone": "+70097413097"}
0005433989805	6787C0	8324 761301	VLADIMIR VOLKOV	{"phone": "+70923333183"}
0005433989806	70015F	5927 025715	ALEKSEY ZAYCEV	{"phone": "+70971801236"}
0005433989807	70015F	1184 217269	VALENTIN YAKOVLEV	{"email": "valentin_yakovlev.28101967@postgrespro.ru", "phone": "+70887444189"}
0005433989808	2E2313	9001 018581	TATYANA MARTYNOVA	{"phone": "+70499399650"}
0005433989809	72BE21	7450 956623	VARVARA PAVLOVA	{"phone": "+70214826118"}
0005433989810	72BE21	3535 682485	VADIM MAKAROV	{"email": "vadimmakarov.081963@postgrespro.ru", "phone": "+70120419504"}
0005433989811	F9407A	6220 539245	GENNADIY SHEVCHENKO	{"email": "shevchenko_g-041968@postgrespro.ru", "phone": "+70794341467"}
0005433989812	D754F0	5357 248296	ALEKSEY ALEKSEEV	{"email": "a_alekseev-27091971@postgrespro.ru", "phone": "+70963827173"}
0005433989813	9F71AF	4104 243765	SVETLANA NIKITINA	{"email": "snikitina_1973@postgrespro.ru", "phone": "+70611859457"}
0005433989814	9F71AF	8975 215217	ELENA KISELEVA	{"email": "kiselevaelena.021983@postgrespro.ru", "phone": "+70598869054"}
0005433989815	831492	6066 306938	RAISA GORBUNOVA	{"phone": "+70898195771"}
0005433989816	831492	9353 089204	OLGA RYABOVA	{"email": "o_ryabova_04081973@postgrespro.ru", "phone": "+70729716619"}
0005433989817	58F626	3556 097658	MIKHAIL MEDVEDEV	{"email": "mikhailmedvedev-12051973@postgrespro.ru", "phone": "+70676644016"}
0005433989818	58F626	0361 253592	OLGA ARKHIPOVA	{"phone": "+70315454415"}
0005433989819	16A496	6932 107996	ANATOLIY FROLOV	{"email": "anatoliyfrolov1972@postgrespro.ru", "phone": "+70150889505"}
0005433989820	16A496	8299 710083	DMITRIY FEDOROV	{"email": "fedorov_dmitriy-1968@postgrespro.ru", "phone": "+70440754519"}
0005433989821	DA9E46	9629 555682	ALEKSANDR VASILEV	{"email": "a_vasilev.02121972@postgrespro.ru", "phone": "+70016795935"}
0005433989822	DA9E46	3707 133031	SVETLANA SERGEEVA	{"email": "s_sergeeva111963@postgrespro.ru", "phone": "+70235490402"}
0005433989823	2E0CB2	7046 172252	OLGA ERMAKOVA	{"email": "o_ermakova_1968@postgrespro.ru", "phone": "+70208522051"}
0005433989824	2E0CB2	3292 799471	SERGEY KOZLOV	{"phone": "+70420888325"}
0005433989825	2E0CB2	9184 807388	KONSTANTIN PETROV	{"phone": "+70450574262"}
0005433989826	34820E	0170 896849	VALENTIN ILIN	{"email": "v.ilin_07061970@postgrespro.ru", "phone": "+70836596877"}
0005433989827	388D6A	4331 983358	SERGEY IVANOV	{"email": "sergey_ivanov.081976@postgrespro.ru", "phone": "+70927340627"}
0005433989828	388D6A	2148 118223	EGOR NOVIKOV	{"email": "egornovikov_031978@postgrespro.ru", "phone": "+70109583801"}
0005433989829	77B669	7433 543570	LIDIYA EFREMOVA	{"email": "l.efremova_1962@postgrespro.ru", "phone": "+70112433613"}
0005433989830	32A191	3169 257244	EKATERINA KOROLEVA	{"email": "e-koroleva_24051975@postgrespro.ru", "phone": "+70046081859"}
0005433989831	015AED	8037 306020	VLADIMIR SERGEEV	{"email": "sergeev_vladimir-1971@postgrespro.ru", "phone": "+70569053294"}
0005433989832	015AED	9784 605147	VLADIMIR MIRONOV	{"email": "vladimir-mironov-17081969@postgrespro.ru", "phone": "+70288038900"}
0005433989833	015AED	7850 088844	ALEKSANDR PETROV	{"phone": "+70284757809"}
0005433989834	965B52	1173 106715	NINA SCHERBAKOVA	{"phone": "+70177410581"}
0005433989835	4F416B	7773 328451	NINA TROFIMOVA	{"email": "n_trofimova_21081975@postgrespro.ru", "phone": "+70361710327"}
0005433989836	12A3C9	4772 342285	MARINA KOROLEVA	{"email": "koroleva-marina.061972@postgrespro.ru", "phone": "+70855748905"}
0005433989837	12A3C9	2877 565009	AZAT IVANOV	{"phone": "+70977984506"}
0005433989838	CC4757	1459 854765	KIRILL SMIRNOV	{"phone": "+70517131174"}
0005433989839	CC4757	0214 414832	ALEKSEY KUDRYASHOV	{"email": "kudryashovaleksey_021969@postgrespro.ru", "phone": "+70820623781"}
0005433989840	CC4757	5802 919792	GENNADIY DENISOV	{"phone": "+70258684418"}
0005433989841	453A71	6690 610306	ALFIYA KUZNECOVA	{"email": "a_kuznecova.16091967@postgrespro.ru", "phone": "+70605859426"}
0005433989842	A1FF06	4830 354115	SERGEY VASILEV	{"email": "vasilev_s021973@postgrespro.ru", "phone": "+70414976461"}
0005433989843	A1FF06	4327 202860	ILYA VASILEV	{"email": "vasilev_i_1969@postgrespro.ru", "phone": "+70538072554"}
0005433989844	8359AE	2211 286709	ARTEM VOLKOV	{"phone": "+70806525844"}
0005433989845	9CECBB	6731 362361	KIRILL CHERNOV	{"email": "chernov_k-051960@postgrespro.ru", "phone": "+70517275827"}
0005433989846	9CECBB	9096 889590	ELENA STEPANOVA	{"phone": "+70168946278"}
0005433989847	33A986	5583 913717	ANDREY MOISEEV	{"email": "moiseev.andrey_12031971@postgrespro.ru", "phone": "+70191807803"}
0005433989848	33A986	0985 703976	ANTONINA BOGDANOVA	{"email": "bogdanova_a_1983@postgrespro.ru", "phone": "+70035261230"}
0005433989849	33A986	3292 216286	ALEKSANDR MAKSIMOV	{"phone": "+70782431062"}
0005433989850	7AD55E	6336 047397	NATALYA BELOVA	{"email": "belovanatalya-031969@postgrespro.ru", "phone": "+70343444137"}
0005433989851	7AD55E	6552 750065	RAMIL MAKAROV	{"phone": "+70503427859"}
0005433989852	25B31B	9990 243560	SERGEY FROLOV	{"email": "frolov_sergey_071959@postgrespro.ru", "phone": "+70934740963"}
0005433989853	569E0A	1079 713636	VERA POTAPOVA	{"phone": "+70136028005"}
0005433989854	569E0A	0090 374121	DMITRIY IVANOV	{"phone": "+70665028971"}
0005433989855	DB659F	1379 785619	NIKOLAY NOVIKOV	{"phone": "+70141754994"}
0005433989856	9CEA08	3536 358866	ALEVTINA SMIRNOVA	{"email": "alevtina_smirnova-20031969@postgrespro.ru", "phone": "+70251998238"}
0005433989857	E02E78	3974 895246	OLGA SMIRNOVA	{"phone": "+70347080323"}
0005433989858	DFE43C	8731 852394	ALEKSANDR PAVLOV	{"phone": "+70100542035"}
0005433989859	FAF305	2076 965385	ALEKSANDR KISELEV	{"phone": "+70991204753"}
0005433989860	EBF3B9	9942 492514	ELENA VLASOVA	{"phone": "+70092517470"}
0005433989861	6D9D74	0359 858758	EKATERINA IVANOVA	{"email": "ekaterinaivanova051967@postgrespro.ru", "phone": "+70985951179"}
0005433989862	6D9D74	4041 602758	ARINA IVANOVA	{"email": "ivanova.a.1977@postgrespro.ru", "phone": "+70269420486"}
0005433989863	3052C0	6245 273473	NADEZHDA ERMAKOVA	{"email": "nadezhda_ermakova_091970@postgrespro.ru", "phone": "+70234140119"}
0005433989864	0762A9	7256 553811	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov29041970@postgrespro.ru", "phone": "+70456879074"}
0005433989865	7762B4	2973 121697	ANDREY KUZMIN	{"phone": "+70916345024"}
0005433989866	7762B4	8305 213792	EVGENIY OSIPOV	{"email": "evgeniy-osipov.1975@postgrespro.ru", "phone": "+70611341230"}
0005433989867	5D572A	6008 763675	DENIS SOLOVEV	{"phone": "+70088970848"}
0005433989868	45F4C5	5187 585868	ANDREY IVANOV	{"phone": "+70185452042"}
0005433989869	47B863	8588 256248	NATALYA ISAEVA	{"phone": "+70036040280"}
0005433989870	47B863	4281 536045	GERMAN ZAYCEV	{"email": "german-zaycev27021975@postgrespro.ru", "phone": "+70931113881"}
0005433989871	BDF5A9	3611 437778	IVAN KUZNECOV	{"email": "kuznecov_ivan-111977@postgrespro.ru", "phone": "+70060856791"}
0005433989872	BDF5A9	9954 967878	ZINAIDA MAKAROVA	{"phone": "+70531022605"}
0005433989873	E176B4	7476 688873	NATALYA GUSEVA	{"email": "guseva.natalya.1966@postgrespro.ru", "phone": "+70777206043"}
0005433989874	F1BE15	0379 407238	ANDREY FOMIN	{"phone": "+70398538387"}
0005433989875	F1BE15	2616 636804	MARIYA YAKOVLEVA	{"phone": "+70943152079"}
0005433989876	138F76	2570 400395	ALIK MIKHAYLOV	{"phone": "+70816969072"}
0005433989877	B79FE3	3983 758595	MATVEY GUSEV	{"phone": "+70840099009"}
0005433989878	11993E	9158 925024	LYUDMILA MEDVEDEVA	{"email": "l-medvedeva-01091978@postgrespro.ru", "phone": "+70458255811"}
0005433989879	11993E	8738 379418	VALERIY PAVLOV	{"email": "pavlovvaleriy-03081973@postgrespro.ru", "phone": "+70102842671"}
0005433989880	9293C3	9532 027401	LYUDMILA ERMAKOVA	{"email": "ermakova-lyudmila09041981@postgrespro.ru", "phone": "+70244635614"}
0005433989881	9293C3	3692 073225	DMITRIY IVANOV	{"email": "dmitriy-ivanov.1969@postgrespro.ru", "phone": "+70945111073"}
0005433989882	80855D	3646 941099	YURIY POPOV	{"email": "popov_y061974@postgrespro.ru", "phone": "+70987317180"}
0005433989883	6C0A47	7837 807333	ANNA ISAEVA	{"email": "anna.isaeva041973@postgrespro.ru", "phone": "+70434834131"}
0005433989884	D20AD3	6592 658260	OLGA POPOVA	{"email": "popova-olga_1980@postgrespro.ru", "phone": "+70298490862"}
0005433989885	D20AD3	5278 953429	VYACHESLAV ROMANOV	{"email": "vromanov-031979@postgrespro.ru", "phone": "+70434755736"}
0005433989886	05C629	1623 552975	NIKOLAY MAKSIMOV	{"phone": "+70315526980"}
0005433989887	2F51D6	8386 748324	MIKHAIL MIRONOV	{"phone": "+70228844048"}
0005433989888	CCB69A	5275 974617	ALEKSANDR GUSEV	{"phone": "+70402261652"}
0005433989889	CCB69A	5557 881290	POLINA TROFIMOVA	{"phone": "+70714584133"}
0005433989890	7379DB	7723 279364	INNA MAKAROVA	{"email": "makarovainna_021968@postgrespro.ru", "phone": "+70443039326"}
0005433989891	7379DB	0171 733947	ELIZAVETA ROMANOVA	{"email": "elizaveta.romanova031970@postgrespro.ru", "phone": "+70316083226"}
0005433989892	E7A037	0217 452114	IRINA MOROZOVA	{"email": "morozova.irina_121978@postgrespro.ru", "phone": "+70394377171"}
0005433989893	EC93AA	7877 669728	OKSANA ANDREEVA	{"phone": "+70219939567"}
0005433989894	EC93AA	4466 474809	YULIYA VOLKOVA	{"email": "volkova-yuliya-071971@postgrespro.ru", "phone": "+70734720010"}
0005433989895	735AD6	4762 864577	GALINA ZHURAVLEVA	{"email": "g.zhuravleva.1958@postgrespro.ru", "phone": "+70091165527"}
0005433989896	735AD6	3149 735849	NATALYA ZAKHAROVA	{"phone": "+70862349111"}
0005433989897	962860	8087 681526	VERA BARANOVA	{"email": "baranova_v011971@postgrespro.ru", "phone": "+70337694772"}
0005433989898	5EC403	7764 703357	OLGA STEPANOVA	{"email": "stepanova-o.19021982@postgrespro.ru", "phone": "+70318632194"}
0005433989899	99CE58	8178 375135	VARVARA YUDINA	{"email": "yudina_varvara08021970@postgrespro.ru", "phone": "+70563919801"}
0005433989900	99CE58	8054 964686	MARIYA ANISIMOVA	{"email": "m_anisimova_1974@postgrespro.ru", "phone": "+70313789706"}
0005433989901	99CE58	2315 497877	ALEKSANDR DAVYDOV	{"phone": "+70754010365"}
0005433989902	E1BA07	8547 258471	ANNA DENISOVA	{"phone": "+70876196123"}
0005433989903	E1BA07	8511 512848	NIKOLAY MATVEEV	{"phone": "+70475273353"}
0005433989904	0B3540	4999 358214	DANIIL RODIONOV	{"phone": "+70128630298"}
0005433989905	B10501	2221 848851	VALERIYA SOKOLOVA	{"email": "sokolova-valeriya_031963@postgrespro.ru", "phone": "+70999994260"}
0005433989906	B10501	5500 054677	EVGENIY YAKOVLEV	{"phone": "+70301137139"}
0005434022533	38D72C	6896 263283	ILYA ORLOV	{"phone": "+70350756585"}
0005434022501	9713CB	6136 870342	ANNA MIKHAYLOVA	{"phone": "+70456173820"}
0005434022502	9713CB	2170 522345	GENNADIY KUZNECOV	{"phone": "+70509051174"}
0005434022503	A16C98	6036 916371	PAVEL ISAEV	{"email": "isaev.pavel.111976@postgrespro.ru", "phone": "+70628849771"}
0005434022504	A16C98	8270 094018	SERGEY SERGEEV	{"email": "s.sergeev051976@postgrespro.ru", "phone": "+70374103810"}
0005434022505	E5264C	4590 046476	NATALYA CHERNOVA	{"email": "chernova.n.19011969@postgrespro.ru", "phone": "+70443921860"}
0005434022506	E5264C	1212 131421	VLADIMIR MOROZOV	{"email": "vladimirmorozov05031966@postgrespro.ru", "phone": "+70301603630"}
0005434022507	BA62EF	2270 166108	ALEKSANDRA EGOROVA	{"phone": "+70707039703"}
0005434022508	BA62EF	8878 335885	MIKHAIL IVANOV	{"email": "mivanov_081961@postgrespro.ru", "phone": "+70594882568"}
0005434022509	8AD8BE	8151 632836	EVGENIY NIKOLAEV	{"phone": "+70495254738"}
0005434022510	8AD8BE	8076 796857	ELENA TARASOVA	{"phone": "+70244127929"}
0005434022511	D2FD3F	3708 049837	SVETLANA FROLOVA	{"email": "svetlana-frolova1983@postgrespro.ru", "phone": "+70612876887"}
0005434022512	33D1EC	5676 773661	ANDREY KUZMIN	{"email": "a.kuzmin.021973@postgrespro.ru", "phone": "+70260787118"}
0005434022513	39CDFB	7553 597097	MAKSIM FEDOROV	{"email": "fedorov_m.1979@postgrespro.ru", "phone": "+70863666562"}
0005434022514	8C298C	8144 661297	NATALYA LOGINOVA	{"email": "loginova-n-1960@postgrespro.ru", "phone": "+70343669113"}
0005434022515	3A9551	5750 899177	ILYA KISELEV	{"email": "kiselev-ilya.101983@postgrespro.ru", "phone": "+70140595133"}
0005434022516	3A9551	7607 923285	NINA GUSEVA	{"phone": "+70108089258"}
0005434022517	2E552A	9465 068378	VERA AKIMOVA	{"email": "akimova.v_1973@postgrespro.ru", "phone": "+70536815868"}
0005434022518	D18143	0327 604758	LARISA POPOVA	{"phone": "+70796222152"}
0005434022519	D18143	8603 471021	TAMARA AFANASEVA	{"phone": "+70783722353"}
0005434022520	05AF28	8808 351336	KRISTINA VLASOVA	{"email": "k_vlasova_1967@postgrespro.ru", "phone": "+70202524095"}
0005434022521	84E404	4991 229403	SERGEY MOROZOV	{"phone": "+70851320221"}
0005434022522	840D62	4869 576772	SOFIYA SOKOLOVA	{"email": "sokolovas-17071964@postgrespro.ru", "phone": "+70223145622"}
0005434022523	840D62	4972 539205	SALAVAT KUZMIN	{"phone": "+70825985842"}
0005434022524	840D62	3279 255164	DMITRIY NAUMOV	{"email": "naumov.dmitriy.01111972@postgrespro.ru", "phone": "+70235428063"}
0005434022525	A3EDF2	6921 005253	SERGEY ANDREEV	{"email": "andreev-s-08071962@postgrespro.ru", "phone": "+70392352371"}
0005434022526	A3EDF2	6713 748866	TATYANA KOVALEVA	{"email": "tatyana.kovaleva.15091970@postgrespro.ru", "phone": "+70422245675"}
0005434022527	A3EDF2	3233 446304	GALINA BELYAEVA	{"email": "belyaeva_galina.24061968@postgrespro.ru", "phone": "+70750313157"}
0005434022528	ADFAA8	9472 011261	IRINA FROLOVA	{"phone": "+70330783935"}
0005434022529	ADFAA8	7267 630116	ANATOLIY CHERNOV	{"phone": "+70614050544"}
0005434022530	8E3234	1385 361735	VALENTIN VOLKOV	{"email": "volkovv03071969@postgrespro.ru", "phone": "+70659811035"}
0005434022531	B26C53	3544 695247	VLADIMIR IVANOV	{"phone": "+70212994730"}
0005434022532	B26C53	3750 758207	VLADIMIR VOROBEV	{"phone": "+70928747097"}
0005434022534	87233C	3107 516573	KLAVDIYA SIDOROVA	{"email": "sidorova.k-021973@postgrespro.ru", "phone": "+70090398971"}
0005434022535	460F06	1289 540296	SVETLANA KUZNECOVA	{"phone": "+70444618913"}
0005434022536	460F06	6564 662311	OKSANA FILIPPOVA	{"email": "filippova-o1967@postgrespro.ru", "phone": "+70260696069"}
0005434022537	C830D9	5887 371949	MARINA NOVIKOVA	{"email": "novikova-m_18091959@postgrespro.ru", "phone": "+70155994020"}
0005434022538	C830D9	1714 701703	DMITRIY RODIONOV	{"email": "d-rodionov_1977@postgrespro.ru", "phone": "+70048966465"}
0005434022539	0088C7	3530 264372	GALINA SMIRNOVA	{"email": "smirnova-galina-01051965@postgrespro.ru", "phone": "+70677714477"}
0005434022540	52BB9B	4713 577793	ELENA CHERNOVA	{"email": "chernova_elena041972@postgrespro.ru", "phone": "+70409453488"}
0005434022541	D72B53	3230 079365	DAMIR NOVIKOV	{"email": "novikov.damir.20031974@postgrespro.ru", "phone": "+70727179758"}
0005434022542	D72B53	5851 086622	ANNA MIKHAYLOVA	{"phone": "+70619283203"}
0005434022543	60B3AF	3985 973802	NATALYA DMITRIEVA	{"phone": "+70007727077"}
0005434022544	1DC568	1648 595302	VIKTOR ANDREEV	{"email": "andreev-viktor-111971@postgrespro.ru", "phone": "+70492879543"}
0005434022545	B46B4B	8884 737899	ELENA POPOVA	{"phone": "+70923163580"}
0005434022546	81C435	0743 444241	VALERIY KOZLOV	{"phone": "+70278640559"}
0005434022547	B8BA72	0224 683786	MARIYA MAKAROVA	{"phone": "+70345631698"}
0005434022548	FA9094	3725 741824	EVGENIY SCHERBAKOV	{"phone": "+70854568980"}
0005434022549	FA9094	5626 326437	KSENIYA BORISOVA	{"phone": "+70254581945"}
0005434022550	346B2D	1470 101887	KONSTANTIN BELOV	{"phone": "+70071666756"}
0005434022551	FB4702	6357 736421	MARINA MAKAROVA	{"phone": "+70547141249"}
0005434022552	FB4702	7807 892611	NIKOLAY BELOV	{"phone": "+70992274052"}
0005434022553	FB4702	4547 976843	RAISA VLASOVA	{"phone": "+70822773700"}
0005434022554	22A60B	3681 671212	IGOR FROLOV	{"phone": "+70319495859"}
0005434022555	0AF178	0859 057377	RASHID SAVELEV	{"phone": "+70808053587"}
0005434022556	0AF178	2305 349581	VIKTOR GAVRILOV	{"email": "viktor.gavrilov_1974@postgrespro.ru", "phone": "+70979725880"}
0005434022557	EF91D5	2891 529212	ALEVTINA FADEEVA	{"email": "fadeeva-a101985@postgrespro.ru", "phone": "+70946382869"}
0005434022558	F78E5D	2887 302646	NIKOLAY KULIKOV	{"phone": "+70076239051"}
0005434022559	B81040	1025 392901	SERGEY TIMOFEEV	{"email": "timofeev.sergey_121976@postgrespro.ru", "phone": "+70308589757"}
0005434022560	B81040	4862 847566	YAROSLAV ZAKHAROV	{"phone": "+70538870699"}
0005434022561	B81040	6526 772410	VARVARA EGOROVA	{"email": "egorova_varvara-071960@postgrespro.ru", "phone": "+70739494866"}
0005434022562	6B47BB	3987 724230	EKATERINA ABRAMOVA	{"phone": "+70892290823"}
0005434022563	6F9748	4042 147394	ARTEM KULIKOV	{"email": "a_kulikov021974@postgrespro.ru", "phone": "+70745068346"}
0005434022564	B0599D	3704 167945	IVAN VOLKOV	{"phone": "+70147507546"}
0005434022565	B0599D	9942 844363	YANA KOZLOVA	{"email": "kozlova_y_1978@postgrespro.ru", "phone": "+70233850699"}
0005434022566	B0599D	2283 811543	GENNADIY ZAKHAROV	{"email": "g.zakharov1970@postgrespro.ru", "phone": "+70279847119"}
0005434022567	2047C0	5467 265157	TATYANA KUZNECOVA	{"phone": "+70122801971"}
0005434022568	4A4BF3	7244 266739	TATYANA CHERNOVA	{"phone": "+70959546876"}
0005434022569	529E6D	0751 020232	OKSANA POLYAKOVA	{"phone": "+70892065081"}
0005434022570	810A4E	4324 217284	ELENA SCHERBAKOVA	{"email": "scherbakova.elena.07011969@postgrespro.ru", "phone": "+70438091349"}
0005434022571	E8A164	0144 741961	ZLATA FILATOVA	{"phone": "+70531387278"}
0005434022572	2A876B	0041 366877	VLADIMIR SERGEEV	{"email": "sergeevv-011978@postgrespro.ru", "phone": "+70145498924"}
0005434022573	BAFAC6	7016 075775	EKATERINA NIKITINA	{"phone": "+70957898095"}
0005434022574	F8E1BC	4450 010500	ROZA FILATOVA	{"phone": "+70298901220"}
0005434022575	BBB847	3926 898115	ALEKSEY FEDOROV	{"phone": "+70122523520"}
0005434022576	BBB847	1516 334040	VALENTINA OVCHINNIKOVA	{"phone": "+70004361549"}
0005434022577	5780B4	7076 851741	LYUBOV BORISOVA	{"phone": "+70228119276"}
0005434022578	C41D95	0078 865207	ANATOLIY NIKOLAEV	{"email": "nikolaev_a_111967@postgrespro.ru", "phone": "+70475165411"}
0005434022579	460999	6944 697676	VALENTINA ORLOVA	{"email": "orlovavalentina.1961@postgrespro.ru", "phone": "+70360065950"}
0005434022580	460999	8782 566194	SERGEY MIRONOV	{"phone": "+70553361279"}
0005434022581	7BA034	2069 865809	OLGA RODIONOVA	{"phone": "+70774432272"}
0005434022582	7BA034	8489 773358	RAISA POPOVA	{"email": "popova_raisa.121981@postgrespro.ru", "phone": "+70585861038"}
0005434022583	B9CEAC	8441 309573	ALEKSANDR NOVIKOV	{"phone": "+70181850879"}
0005434022584	6B77AC	9936 113919	NIKOLAY EGOROV	{"email": "egorovn1965@postgrespro.ru", "phone": "+70188809296"}
0005434022585	6B77AC	1659 023841	EVGENIY MAKAROV	{"email": "evgeniy.makarov_03051970@postgrespro.ru", "phone": "+70003751530"}
0005434022586	DD9427	4619 740797	LYUDMILA ANTONOVA	{"email": "lyudmila-antonova-1971@postgrespro.ru", "phone": "+70491385798"}
0005434022587	A0B613	9389 141414	ANGELINA MELNIKOVA	{"phone": "+70970844828"}
0005434022588	A0B613	9790 768905	VLADISLAV MIKHAYLOV	{"phone": "+70737373600"}
0005434022589	99269B	7787 159419	TATYANA EFREMOVA	{"phone": "+70839841339"}
0005434022590	99269B	4658 680416	GALINA AFANASEVA	{"phone": "+70575677598"}
0005434022591	E4B24D	9093 046661	ELENA KRASNOVA	{"phone": "+70771795368"}
0005434022592	BDF15A	0635 023904	OLGA EGOROVA	{"email": "o.egorova.061976@postgrespro.ru", "phone": "+70618659234"}
0005434022593	1E79F5	5132 045378	BORIS SCHERBAKOV	{"email": "b_scherbakov03121977@postgrespro.ru", "phone": "+70032473807"}
0005434022594	829473	0133 333808	VLADIMIR IVANOV	{"email": "v.ivanov.22031961@postgrespro.ru", "phone": "+70408233013"}
0005434022595	829473	4529 500718	OKSANA TIKHONOVA	{"email": "oksana_tikhonova-021978@postgrespro.ru", "phone": "+70367502359"}
0005434022596	15A653	6580 115686	NATALYA EGOROVA	{"email": "n.egorova-031972@postgrespro.ru", "phone": "+70101916601"}
0005434022597	355CDC	0298 482062	ANDREY GUSEV	{"email": "gusevandrey1968@postgrespro.ru", "phone": "+70029329330"}
0005434022598	8E5F3A	5056 476224	STANISLAV KULIKOV	{"phone": "+70811953437"}
0005434022599	E50276	4534 559107	RAISA MAKAROVA	{"email": "r-makarova.101978@postgrespro.ru", "phone": "+70278222156"}
0005434022600	8DD1D2	1378 425698	NARIMAN MOISEEV	{"email": "moiseevn_1978@postgrespro.ru", "phone": "+70119848685"}
0005434022601	F754A1	6186 756509	ELENA SEMENOVA	{"phone": "+70301658585"}
0005434022602	4AEE75	0275 213972	NATALYA KUZNECOVA	{"phone": "+70628964391"}
0005434022603	4AEE75	1876 645121	ALEKSEY ALEKSEEV	{"phone": "+70689650615"}
0005434022604	38058D	1172 391601	ANDREY MIRONOV	{"email": "andrey-mironov-051977@postgrespro.ru", "phone": "+70661985689"}
0005434022605	7ECA17	5331 623926	VASILIY ILIN	{"phone": "+70871491008"}
0005434022606	4D64DA	6274 370245	IVAN MOISEEV	{"email": "moiseev_ivan_29101973@postgrespro.ru", "phone": "+70009151939"}
0005434022607	4D64DA	6014 544295	ILGIZ FILIPPOV	{"phone": "+70225585193"}
0005434022608	954B8A	4181 313386	MARIYA TIMOFEEVA	{"phone": "+70363853818"}
0005434022609	954B8A	1806 270253	STANISLAV KUZMIN	{"email": "skuzmin_101970@postgrespro.ru", "phone": "+70299191668"}
0005434022610	95D1C9	7421 005395	IGOR BORISOV	{"phone": "+70950674290"}
0005434022611	86D6F9	0032 553024	LIDIYA NIKITINA	{"email": "nikitina.l.25081976@postgrespro.ru", "phone": "+70837799826"}
0005434022612	8058C5	8247 549570	MARIYA BORISOVA	{"email": "mariya_borisova-02091987@postgrespro.ru", "phone": "+70033019563"}
0005434022613	8058C5	2220 556056	VALERIY DENISOV	{"phone": "+70552154063"}
0005434022614	901A26	9347 807642	SERGEY ZHURAVLEV	{"email": "zhuravlev-sergey_20021981@postgrespro.ru", "phone": "+70730935508"}
0005434022615	97F916	3127 265203	PAVEL FOMIN	{"email": "fomin.p_101975@postgrespro.ru", "phone": "+70396262748"}
0005434022616	985D98	1517 733119	VLADIMIR TIKHONOV	{"phone": "+70056906029"}
0005434022617	38150C	6571 229353	VALENTINA ZHUKOVA	{"phone": "+70609319412"}
0005434022618	C741C8	4395 048519	VLADIMIR NAZAROV	{"phone": "+70971144041"}
0005434022619	DBFDC1	5308 509375	EVGENIYA DENISOVA	{"email": "denisova-evgeniya1969@postgrespro.ru", "phone": "+70795170699"}
0005434022620	DBFDC1	4919 342815	VITALIY NIKOLAEV	{"email": "nikolaevvitaliy-1963@postgrespro.ru", "phone": "+70892338173"}
0005434022621	B7743D	5484 289167	MARINA KALININA	{"phone": "+70751222791"}
0005434022622	7D7B23	1982 543127	ELENA KISELEVA	{"phone": "+70889061705"}
0005434022623	7D7B23	3952 386729	ANDREY MOISEEV	{"email": "moiseev-andrey_121968@postgrespro.ru", "phone": "+70558433016"}
0005434022624	B581CC	5946 217352	ILYA SMIRNOV	{"email": "i-smirnov_1993@postgrespro.ru", "phone": "+70846490675"}
0005434022625	4C89A0	4432 250564	PAVEL NIKITIN	{"phone": "+70858472124"}
0005434022626	5A319F	5792 851357	ALEKSANDR SEMENOV	{"email": "asemenov071977@postgrespro.ru", "phone": "+70195520465"}
0005434022627	B7AE95	0094 505376	LYAYSAN IVANOVA	{"phone": "+70695166708"}
0005434022628	B7AE95	1010 723767	RUSTAM NIKITIN	{"email": "nikitinrustam1973@postgrespro.ru", "phone": "+70886062326"}
0005434022629	D0711D	9026 724445	TAMARA SIDOROVA	{"phone": "+70392148821"}
0005434022630	D0711D	2886 193629	ALEKSANDR KUZNECOV	{"phone": "+70545156962"}
0005434022631	E37C2E	7271 922440	RAVZA SEMENOVA	{"email": "r.semenova_1958@postgrespro.ru", "phone": "+70778622888"}
0005434022632	E37C2E	5158 275453	NINA AKIMOVA	{"email": "akimova.n-20121960@postgrespro.ru", "phone": "+70533502584"}
0005434022633	88A254	4955 620791	ANNA FEDOROVA	{"phone": "+70892879086"}
0005434022634	88A254	4688 449100	NATALYA ANISIMOVA	{"email": "anisimova-natalya-1980@postgrespro.ru", "phone": "+70133502729"}
0005434022635	2D47C5	8865 181246	KSENIYA SCHERBAKOVA	{"phone": "+70095233477"}
0005434022636	70568C	8187 563777	GULFIYA ROMANOVA	{"email": "romanova.gulfiya03021973@postgrespro.ru", "phone": "+70538138585"}
0005434022637	FDD4F2	5496 474699	ELENA ERMAKOVA	{"email": "e_ermakova.1972@postgrespro.ru", "phone": "+70393319975"}
0005434022638	EB833E	0394 336244	ANATOLIY AFANASEV	{"phone": "+70519403261"}
0005434022639	959C21	5925 472972	GALINA MIKHAYLOVA	{"email": "mikhaylova-galina.101961@postgrespro.ru", "phone": "+70343836782"}
0005434022640	959C21	8745 476467	ILYA BORISOV	{"email": "borisov-ilya.091973@postgrespro.ru", "phone": "+70652666373"}
0005434022641	F86BF9	7923 820535	IGOR OSIPOV	{"email": "igorosipov_091971@postgrespro.ru", "phone": "+70226546248"}
0005434022642	F86BF9	3759 012931	DARYA PETROVA	{"email": "d_petrova.041963@postgrespro.ru", "phone": "+70341234570"}
0005434022643	52CFD1	3339 832745	LYUDMILA YAKOVLEVA	{"email": "yakovleva.lyudmila.1970@postgrespro.ru", "phone": "+70703564385"}
0005434022644	C035CB	3428 685036	ALENA DANILOVA	{"phone": "+70304940898"}
0005434022645	7E7232	0404 918497	ELENA SMIRNOVA	{"email": "smirnova-e-1985@postgrespro.ru", "phone": "+70860850258"}
0005434022646	3DA335	0187 858544	IRINA YUDINA	{"phone": "+70447228037"}
0005434022647	3DA335	9076 005357	MARIYA PAVLOVA	{"email": "mpavlova1967@postgrespro.ru", "phone": "+70871473173"}
0005434022648	9498B6	8075 155990	NATALYA NAUMOVA	{"email": "naumova.n_081979@postgrespro.ru", "phone": "+70872760925"}
0005434022649	9498B6	7692 917876	YURIY SEMENOV	{"phone": "+70843914029"}
0005434022650	730141	7074 159389	MIKHAIL PETROV	{"email": "petrovmikhail_29101965@postgrespro.ru", "phone": "+70018499222"}
0005434022651	27B32E	4972 262904	SEMEN ANDREEV	{"phone": "+70344524273"}
0005434022652	C60EAB	9408 437755	LYUDMILA ZHURAVLEVA	{"email": "l-zhuravleva1971@postgrespro.ru", "phone": "+70274242022"}
0005434022653	C1DD95	0908 153369	VALENTINA KALININA	{"email": "valentinakalinina.24011987@postgrespro.ru", "phone": "+70422394336"}
0005434022654	2729EB	0299 934897	NADEZHDA SOROKINA	{"email": "sorokina-n_1960@postgrespro.ru", "phone": "+70783643569"}
0005434022655	2729EB	5621 038540	ALEKSANDR ILIN	{"email": "a_ilin1972@postgrespro.ru", "phone": "+70943937725"}
0005434022656	B93C7D	9718 567596	MAKSIM NIKITIN	{"phone": "+70531417588"}
0005434022657	4EAF96	2517 418234	YULIYA STEPANOVA	{"phone": "+70508881665"}
0005434022658	248E97	9862 995148	ALINA TIKHONOVA	{"email": "a-tikhonova.011962@postgrespro.ru", "phone": "+70792833396"}
0005434022659	0C14FC	6710 589898	ELMIRA STEPANOVA	{"phone": "+70553014253"}
0005434022660	BA1236	8744 677628	ANDREY SOROKIN	{"phone": "+70421617565"}
0005434022661	BA1236	4534 320533	VASILIY MELNIKOV	{"phone": "+70858832091"}
0005434022662	774841	7316 887959	VASILIY YAKOVLEV	{"phone": "+70218221379"}
0005434022663	774841	9724 885483	ALEKSANDR PAVLOV	{"phone": "+70014125728"}
0005434022664	6A35B1	3127 488940	SERGEY YAKOVLEV	{"phone": "+70037118424"}
0005434022665	6A35B1	4124 780334	SERGEY ZAYCEV	{"phone": "+70365837834"}
0005434022666	C85CE8	0513 542668	KSENIYA DAVYDOVA	{"phone": "+70683436042"}
0005434022667	16A9A2	7087 153032	MARIYA VLASOVA	{"email": "mariya.vlasova_24011958@postgrespro.ru", "phone": "+70848543746"}
0005434022668	761B35	5220 591438	SERGEY ZHURAVLEV	{"phone": "+70171256519"}
0005434022669	AAC7A0	7222 365470	IVAN SHEVCHENKO	{"phone": "+70075075595"}
0005434022670	14018E	7796 273462	ALEKSANDR FROLOV	{"email": "frolov.aleksandr-1970@postgrespro.ru", "phone": "+70187459855"}
0005434022671	547D4A	6383 868560	ANDREY ROMANOV	{"email": "a-romanov-1975@postgrespro.ru", "phone": "+70042060771"}
0005434022672	54AAE4	8068 801407	TATYANA ARKHIPOVA	{"email": "tatyanaarkhipova_011971@postgrespro.ru", "phone": "+70021778907"}
0005434022673	54AAE4	2454 559958	YULIYA NIKIFOROVA	{"phone": "+70924298309"}
0005434022674	E9BE7A	9356 944954	KAMILA PAVLOVA	{"email": "pavlovak.06101971@postgrespro.ru", "phone": "+70554967412"}
0005434022675	A60256	6161 606953	LYUDMILA KUDRYASHOVA	{"email": "kudryashova.l-1977@postgrespro.ru", "phone": "+70261932041"}
0005434022676	74664E	2793 220827	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila.061971@postgrespro.ru", "phone": "+70281104564"}
0005434022677	5F09BA	2176 007420	IRINA PETROVA	{"email": "petrova.i_021967@postgrespro.ru", "phone": "+70237703800"}
0005434022678	182623	7483 839114	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-02011976@postgrespro.ru", "phone": "+70279476826"}
0005434022679	182623	0946 973685	KSENIYA AFANASEVA	{"email": "kafanaseva.28031968@postgrespro.ru", "phone": "+70183863543"}
0005434022680	422D3C	2674 224635	NARIMAN FILIPPOV	{"email": "filippov-n_051969@postgrespro.ru", "phone": "+70649713090"}
0005434022681	F997E3	1547 811604	ALEKSANDR MATVEEV	{"phone": "+70939876505"}
0005434022682	0AA188	2447 701401	VLADIMIR VOROBEV	{"phone": "+70363592014"}
0005434022683	93553C	1038 403765	NIKOLAY NOVIKOV	{"phone": "+70516657053"}
0005434022684	93553C	5234 524916	LARISA MEDVEDEVA	{"phone": "+70159696227"}
0005434022685	0F3A13	0422 753603	TATYANA LAZAREVA	{"phone": "+70564652382"}
0005434022686	0F3A13	4515 713509	VALERIY ANTONOV	{"phone": "+70322230063"}
0005434022687	569168	2646 227435	LYUDMILA ORLOVA	{"email": "lorlova_041962@postgrespro.ru", "phone": "+70707085965"}
0005434022688	569168	5572 770903	SVETLANA RODIONOVA	{"phone": "+70854078211"}
0005434022689	29F820	3593 983872	SERGEY BORISOV	{"phone": "+70271691007"}
0005434022690	F18647	3322 452592	MARIYA NIKITINA	{"email": "nikitina.m.1974@postgrespro.ru", "phone": "+70955621272"}
0005434022691	C0B312	4041 115424	IRINA NAZAROVA	{"email": "irina.nazarova051984@postgrespro.ru", "phone": "+70463719240"}
0005434022692	C0B312	4431 213251	EVGENIY IVANOV	{"phone": "+70208578951"}
0005434022693	4B6727	2820 957154	EVGENIY FROLOV	{"phone": "+70427745668"}
0005434022694	7E6271	9415 886477	VERA KUZNECOVA	{"email": "vera-kuznecova15101973@postgrespro.ru", "phone": "+70829322249"}
0005434022695	7E6271	9224 594157	RAIL DAVYDOV	{"email": "r_davydov-1966@postgrespro.ru", "phone": "+70967263322"}
0005434022696	FEE175	9929 544199	ANATOLIY ZHUKOV	{"email": "anatoliy.zhukov_1958@postgrespro.ru", "phone": "+70763479918"}
0005434022697	D9889C	9592 365196	DARYA ZHURAVLEVA	{"phone": "+70442155320"}
0005434022698	19D0A1	2754 047308	GENNADIY IVANOV	{"email": "ivanov-gennadiy041966@postgrespro.ru", "phone": "+70216950360"}
0005434022699	19D0A1	3685 286821	RIMMA GRISHINA	{"email": "grishina.r.1970@postgrespro.ru", "phone": "+70227632281"}
0005434022700	19D0A1	5914 426199	VALENTINA PETROVA	{"phone": "+70159453344"}
0005434022701	B72069	9790 239830	NATALIYA POPOVA	{"email": "popova.n_14051975@postgrespro.ru", "phone": "+70083640740"}
0005434022702	666AB6	7669 339882	ALEKSEY SOLOVEV	{"email": "aleksey_solovev081976@postgrespro.ru", "phone": "+70448526424"}
0005434022703	0D0F3F	7419 615447	NIKOLAY SOROKIN	{"phone": "+70036610450"}
0005434022704	460FF1	7832 195617	LYUDMILA FADEEVA	{"email": "l_fadeeva.1980@postgrespro.ru", "phone": "+70153303105"}
0005434022705	460FF1	7273 555195	IRINA MATVEEVA	{"email": "i.matveeva.01011969@postgrespro.ru", "phone": "+70884356088"}
0005434022706	A5A69B	2119 559219	OLEG PETROV	{"phone": "+70775036798"}
0005434022707	A5A69B	8136 210024	OLEG SHEVCHENKO	{"email": "oleg.shevchenko_1975@postgrespro.ru", "phone": "+70907166521"}
0005434022708	06A4A3	6732 341497	TATYANA AFANASEVA	{"email": "afanaseva_t.27071969@postgrespro.ru", "phone": "+70456363051"}
0005434022709	6F88BB	5915 596730	NURLAN MAKAROV	{"email": "nurlan.makarov.1970@postgrespro.ru", "phone": "+70789044159"}
0005434022710	C544CE	6871 359110	LYUBOV RYABOVA	{"phone": "+70688168468"}
0005434022711	C544CE	2385 825253	DARYA SOLOVEVA	{"phone": "+70958896169"}
0005434022712	C544CE	9699 328226	DARYA ALEKSEEVA	{"email": "alekseeva-darya_16021972@postgrespro.ru", "phone": "+70113092804"}
0005434022713	07F989	9812 679837	SERGEY POPOV	{"email": "popov-sergey-27091975@postgrespro.ru", "phone": "+70265719358"}
0005434022714	419F2C	1670 455447	NIKOLAY MAKAROV	{"email": "n_makarov.01101967@postgrespro.ru", "phone": "+70487701409"}
0005434022715	419F2C	7139 354398	ELENA LUKYANOVA	{"email": "lukyanova.elena011980@postgrespro.ru", "phone": "+70371565608"}
0005434022716	B74F09	0594 655625	VLADIMIR GORBUNOV	{"phone": "+70482798189"}
0005434022717	B74F09	2125 378370	TATYANA POPOVA	{"phone": "+70911001730"}
0005434022718	ECE24A	8546 709588	TATYANA SOKOLOVA	{"phone": "+70674486856"}
0005434022719	ECE24A	4846 180075	NATALYA EGOROVA	{"email": "natalyaegorova_031971@postgrespro.ru", "phone": "+70448379682"}
0005434022720	6A7738	1556 006713	EKATERINA BOGDANOVA	{"email": "e-bogdanova-05091961@postgrespro.ru", "phone": "+70405949738"}
0005434022721	6A7738	7649 962793	ALENA ZAYCEVA	{"email": "azayceva.1970@postgrespro.ru", "phone": "+70966376938"}
0005434022722	9807B5	3892 297214	EVGENIY EGOROV	{"email": "egorove.01111973@postgrespro.ru", "phone": "+70149519024"}
0005434022723	9807B5	7617 366534	VERA FILATOVA	{"email": "filatova.vera.1966@postgrespro.ru", "phone": "+70602664961"}
0005434022724	9807B5	1935 631487	IRAIDA SOLOVEVA	{"phone": "+70241802355"}
0005434022725	C6ACD1	9127 272389	TATYANA KUZNECOVA	{"email": "t.kuznecova08051971@postgrespro.ru", "phone": "+70251425560"}
0005434022726	C6ACD1	1982 406426	YAROSLAV SOROKIN	{"email": "sorokin-y041963@postgrespro.ru", "phone": "+70951392120"}
0005434022727	8AD417	9002 429416	GENNADIY SEMENOV	{"email": "semenov-gennadiy011980@postgrespro.ru", "phone": "+70514702948"}
0005434022728	BC3B47	1964 003575	IRINA MASLOVA	{"phone": "+70806311962"}
0005434022729	BC3B47	8625 541444	ALEKSEY ALEKSANDROV	{"phone": "+70965680489"}
0005434022730	57A2D7	9537 612306	ANNA MIRONOVA	{"email": "a-mironova1971@postgrespro.ru", "phone": "+70998629344"}
0005434022731	57A2D7	2628 846152	NATALYA BELOVA	{"email": "belova-n.1970@postgrespro.ru", "phone": "+70764973912"}
0005434022732	536FC2	4745 626415	EVGENIY MAKAROV	{"email": "makarov-evgeniy_1972@postgrespro.ru", "phone": "+70715047611"}
0005434022733	D1A0E3	1681 438074	ALEKSANDR SMIRNOV	{"phone": "+70176571849"}
0005434022734	4F96B0	7491 390822	GALINA MAKAROVA	{"phone": "+70547008297"}
0005434022735	4F96B0	2587 720144	DANILA ANDREEV	{"phone": "+70470298839"}
0005434022736	0FBD9E	8276 814807	ANATOLIY ISAEV	{"email": "isaev.anatoliy1969@postgrespro.ru", "phone": "+70645673914"}
0005434022737	87E323	6035 308300	ALSU YAKOVLEVA	{"email": "yakovleva-a-30071962@postgrespro.ru", "phone": "+70577934685"}
0005434022738	87E323	6050 633670	MIKHAIL DAVYDOV	{"email": "davydov_mikhail_17121972@postgrespro.ru", "phone": "+70182795685"}
0005434022739	5E37BF	5941 606779	KIRILL GORBUNOV	{"email": "kirillgorbunov1969@postgrespro.ru", "phone": "+70337384666"}
0005434022740	9C4A4F	7360 201991	ANTONINA FILIPPOVA	{"phone": "+70594055484"}
0005434022741	7499C1	7535 575638	DENIS FEDOROV	{"phone": "+70288000269"}
0005434022742	B40799	8066 216867	SERGEY FILIPPOV	{"phone": "+70349852622"}
0005434022743	C4CDFD	4718 688720	NINA NESTEROVA	{"phone": "+70334955186"}
0005434022744	C4CDFD	1366 446206	LEONID SERGEEV	{"phone": "+70318452935"}
0005434022745	6D858E	7437 018478	GALINA NAZAROVA	{"phone": "+70184440350"}
0005434022746	8B82EF	0210 532406	IVAN ZAYCEV	{"phone": "+70067586539"}
0005434022747	1241E3	9425 416160	VLADIMIR ORLOV	{"email": "orlov-vladimir-13031974@postgrespro.ru", "phone": "+70270993188"}
0005434022748	A0FA0F	7552 115868	EDGAR KUZMIN	{"phone": "+70232859652"}
0005434022749	CD90A4	7143 630590	VERA KUZMINA	{"email": "v-kuzmina.061968@postgrespro.ru", "phone": "+70915755517"}
0005434022750	CD90A4	1826 212670	VALENTINA YAKOVLEVA	{"email": "vyakovleva_011969@postgrespro.ru", "phone": "+70409975704"}
0005434022751	77855D	9993 144254	NINA KISELEVA	{"phone": "+70781651537"}
0005434022752	C4F542	6933 348880	VLADIMIR GORBUNOV	{"phone": "+70352800960"}
0005434022753	C4F542	6271 860341	LYUBOV FEDOROVA	{"phone": "+70959213986"}
0005434022754	CD7BF1	9934 256140	NINA ZAKHAROVA	{"email": "zakharovanina071960@postgrespro.ru", "phone": "+70274520412"}
0005434022755	5429BA	2607 826437	MARIYA PETROVA	{"email": "petrova_mariya_111976@postgrespro.ru", "phone": "+70494813432"}
0005434022756	EF8205	0716 873030	LYUDMILA NIKOLAEVA	{"email": "nikolaeval081968@postgrespro.ru", "phone": "+70515519612"}
0005434022757	D56B1F	9938 946200	ANASTASIYA AKIMOVA	{"email": "anastasiya-akimova071970@postgrespro.ru", "phone": "+70162461112"}
0005434022758	9D95A4	5675 559332	VLADIMIR KUZMIN	{"phone": "+70408499720"}
0005434022759	9D95A4	7268 782895	ANDREY KULIKOV	{"email": "andrey_kulikov28081982@postgrespro.ru", "phone": "+70689001585"}
0005434022760	E3D4C9	9038 900123	NATALIYA IVANOVA	{"phone": "+70867208901"}
0005434022761	9CE6ED	3351 958064	EVGENIYA ALEKSEEVA	{"email": "alekseeva.evgeniya1966@postgrespro.ru", "phone": "+70170859010"}
0005434022762	761335	2019 340418	IRINA MASLOVA	{"phone": "+70044101625"}
0005434022763	ABA459	3931 425816	ZOYA ANISIMOVA	{"phone": "+70937244187"}
0005434022764	96E15D	0671 620157	VYACHESLAV KRASNOV	{"email": "krasnovvyacheslav.26111977@postgrespro.ru", "phone": "+70933223006"}
0005434022765	44A4F1	9340 901575	LYUBOV IVANOVA	{"email": "ivanoval.16041978@postgrespro.ru", "phone": "+70174594166"}
0005434022766	4D4899	1360 328562	SERGEY PAVLOV	{"phone": "+70267651940"}
0005434022767	02970C	8928 017372	SVETLANA MARTYNOVA	{"phone": "+70948715804"}
0005434022768	D0B1A9	9078 394081	SERGEY ORLOV	{"email": "orlov-s-111966@postgrespro.ru", "phone": "+70541853985"}
0005434022769	B59F80	3123 632223	GALINA ALEKSANDROVA	{"email": "galina_aleksandrova-1961@postgrespro.ru", "phone": "+70565199967"}
0005434022770	B59F80	2945 789328	RASHID ZHUKOV	{"email": "zhukov.rashid061975@postgrespro.ru", "phone": "+70885652173"}
0005434022771	B59F80	7229 677994	POLINA BARANOVA	{"phone": "+70367175836"}
0005434022772	D95B55	8531 299532	ARTUR SERGEEV	{"phone": "+70514070437"}
0005434022773	CC9484	4753 500330	DENIS IVANOV	{"email": "d_ivanov_031979@postgrespro.ru", "phone": "+70956977368"}
0005434022774	ABC771	9768 601791	LIDIYA SEMENOVA	{"phone": "+70672781623"}
0005434022775	ABC771	5964 184237	ANATOLIY ANTONOV	{"phone": "+70183617645"}
0005434022776	934253	1045 512801	VENERA MIKHAYLOVA	{"phone": "+70126922270"}
0005434022777	811E87	7032 346262	GLEB YAKOVLEV	{"email": "yakovlev-g111970@postgrespro.ru", "phone": "+70367228985"}
0005434022778	A84D88	3179 588878	MIKHAIL MATVEEV	{"phone": "+70270194361"}
0005434022779	CA1712	8238 755344	RAISA VOLKOVA	{"phone": "+70337718214"}
0005434022780	332D79	3156 672123	OLGA TARASOVA	{"phone": "+70383120363"}
0005434022781	332D79	1872 701761	YURIY NIKITIN	{"email": "yuriy_nikitin_26051973@postgrespro.ru", "phone": "+70648036217"}
0005434022782	332D79	6643 058112	NADEZHDA MOISEEVA	{"email": "moiseeva.nadezhda-1973@postgrespro.ru", "phone": "+70579764145"}
0005434022783	B967FE	0873 221965	TATYANA MEDVEDEVA	{"phone": "+70035888928"}
0005434022784	B967FE	6897 833272	NIKOLAY VOROBEV	{"phone": "+70402824733"}
0005434022785	650A33	9002 696265	ANDREY BELOV	{"phone": "+70537337758"}
0005434022786	650A33	2427 822665	LYUDMILA GUSEVA	{"phone": "+70708525337"}
0005434022787	5152BD	6473 239798	RAISA SMIRNOVA	{"email": "smirnova.r.101974@postgrespro.ru", "phone": "+70839140367"}
0005434022788	E1F0C3	2469 126459	ANNA GUSEVA	{"email": "guseva_anna21121975@postgrespro.ru", "phone": "+70882441237"}
0005434022789	37ED52	7386 840185	DMITRIY POPOV	{"phone": "+70672278775"}
0005434022790	37ED52	4005 684574	IVAN SIDOROV	{"email": "sidorovi26071966@postgrespro.ru", "phone": "+70448252136"}
0005434022791	3159FD	7467 023884	MIKHAIL IVANOV	{"phone": "+70283744882"}
0005434022792	8CA762	4179 082856	YAROSLAV IVANOV	{"phone": "+70569683543"}
0005434022793	8CA762	5833 724947	LIDIYA KOMAROVA	{"phone": "+70842331760"}
0005434022794	35AFFB	7832 498338	SERGEY VLASOV	{"phone": "+70798246957"}
0005434022795	35AFFB	5920 135557	ALEKSEY SOROKIN	{"phone": "+70821705754"}
0005434022796	5E3DF7	8180 554845	ANTON MIRONOV	{"email": "mironov-anton_1965@postgrespro.ru", "phone": "+70166475819"}
0005434022797	5E3DF7	7314 379825	VLADIMIR STEPANOV	{"email": "vladimir-stepanov_061967@postgrespro.ru", "phone": "+70803616928"}
0005434022798	07F6C6	8882 490601	ARINA ABRAMOVA	{"email": "abramova-arina_11111978@postgrespro.ru", "phone": "+70068905464"}
0005434022799	AB8B6B	8733 598341	NATALIYA MIRONOVA	{"phone": "+70548929043"}
0005434022800	7A6098	6934 076612	YULIYA NOVIKOVA	{"email": "y_novikova-1974@postgrespro.ru", "phone": "+70187165155"}
0005434022801	7A6098	3597 479223	KSENIYA VLASOVA	{"email": "k.vlasova.091966@postgrespro.ru", "phone": "+70663068914"}
0005434022802	DF8916	7546 582780	VLADIMIR SHEVCHENKO	{"email": "shevchenko_vladimir_1978@postgrespro.ru", "phone": "+70409589797"}
0005434022803	3650AF	2753 789454	VALENTINA IVANOVA	{"email": "v-ivanova_021978@postgrespro.ru", "phone": "+70424184160"}
0005434022804	9643C9	7992 409016	YURIY VASILEV	{"email": "vasilev-y1967@postgrespro.ru", "phone": "+70658745315"}
0005434022805	4DE5DA	7029 295159	KRISTINA MEDVEDEVA	{"email": "medvedevakristina-14081960@postgrespro.ru", "phone": "+70015721987"}
0005434022806	C5AA50	2184 511287	SERGEY TIKHONOV	{"phone": "+70715244334"}
0005434022807	C5AA50	5262 024784	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.051969@postgrespro.ru", "phone": "+70979434081"}
0005434022808	C5AA50	1705 525040	TATYANA GERASIMOVA	{"email": "t-gerasimova.1975@postgrespro.ru", "phone": "+70188406843"}
0005434022809	8C3EAB	3332 392999	LARISA MATVEEVA	{"phone": "+70307538011"}
0005434022810	730B61	0106 502170	SVETLANA MALYSHEVA	{"email": "svetlana.malysheva.02061977@postgrespro.ru", "phone": "+70198800521"}
0005434022811	A93946	1403 734851	VYACHESLAV PAVLOV	{"phone": "+70375353037"}
0005434022812	484BAC	4860 159367	VLADIMIR DENISOV	{"phone": "+70081600657"}
0005434022813	7CC5F8	5371 296316	ANDREY VASILEV	{"email": "avasilev-101966@postgrespro.ru", "phone": "+70608787089"}
0005434022814	7CC5F8	8452 659923	EKATERINA SEMENOVA	{"email": "esemenova11041978@postgrespro.ru", "phone": "+70149317983"}
0005434022815	F9596F	7693 643242	ANNA MAKAROVA	{"phone": "+70101162478"}
0005434022816	F9596F	1543 176650	NIKOLAY BARANOV	{"phone": "+70790096521"}
0005434022817	00FAD5	7209 012370	NATALYA IVANOVA	{"email": "ivanova-n.1978@postgrespro.ru", "phone": "+70130829377"}
0005434022818	C547B4	0116 753720	OLGA NOVIKOVA	{"email": "olga_novikova.061973@postgrespro.ru", "phone": "+70809620881"}
0005434022819	B8EC07	0952 747310	LYUDMILA KOMAROVA	{"phone": "+70026941254"}
0005434022820	B8EC07	2221 134221	VALERIYA SOLOVEVA	{"email": "soloveva.valeriya.12031977@postgrespro.ru", "phone": "+70741794775"}
0005434022821	67C174	0400 623189	ANASTASIYA KOMAROVA	{"phone": "+70924280531"}
0005434022822	67C174	5446 763649	NATALIYA SEMENOVA	{"email": "n_semenova-081978@postgrespro.ru", "phone": "+70583984900"}
0005434022823	A22B4E	5135 967349	TAMARA DENISOVA	{"email": "t_denisova1978@postgrespro.ru", "phone": "+70594834197"}
0005434022824	6A806A	9090 194213	IGOR SIDOROV	{"email": "i-sidorov.061985@postgrespro.ru", "phone": "+70649022796"}
0005434022825	745C32	0787 854479	EVGENIY MIKHAYLOV	{"email": "mikhaylov-evgeniy-1971@postgrespro.ru", "phone": "+70341368012"}
0005434022826	685193	2527 086313	YULIYA FROLOVA	{"email": "y-frolova.21011971@postgrespro.ru", "phone": "+70210421020"}
0005434022827	8956B9	2188 946555	MAKSIM VOROBEV	{"email": "m.vorobev-16021954@postgrespro.ru", "phone": "+70564576057"}
0005434022828	7AF955	5720 988488	LYUBOV NAZAROVA	{"phone": "+70735801031"}
0005434022829	D9B5A7	9655 321216	VALENTINA SEMENOVA	{"email": "semenovavalentina.25051967@postgrespro.ru", "phone": "+70619460370"}
0005434022830	4036F6	7828 939471	ILYA FROLOV	{"email": "frolov_i.101975@postgrespro.ru", "phone": "+70925413875"}
0005434022831	1E4CC2	6157 669544	ANATOLIY SMIRNOV	{"email": "smirnov.a1970@postgrespro.ru", "phone": "+70700068488"}
0005434022832	61A07E	3163 019154	NIKOLAY STEPANOV	{"email": "nikolay_stepanov_051968@postgrespro.ru", "phone": "+70539751322"}
0005434022833	61A07E	6733 431068	ELENA TROFIMOVA	{"email": "e_trofimova_18081963@postgrespro.ru", "phone": "+70131190725"}
0005434022834	61A07E	8147 058200	TAMARA KOZLOVA	{"email": "t-kozlova.121971@postgrespro.ru", "phone": "+70196002546"}
0005434022835	7B47B5	1594 088859	VERA LOGINOVA	{"email": "loginova-vera.061977@postgrespro.ru", "phone": "+70414296822"}
0005434022836	60831F	7930 167352	IGOR SAVELEV	{"phone": "+70355241145"}
0005434022837	60831F	8501 183860	OLGA KUZMINA	{"phone": "+70768797454"}
0005434022838	C97820	6416 630136	YURIY DAVYDOV	{"phone": "+70330119325"}
0005434022839	863878	7069 547147	VALENTINA DENISOVA	{"email": "denisovav-101974@postgrespro.ru", "phone": "+70965363768"}
0005434022840	863878	5668 893955	LYUBOV KARPOVA	{"phone": "+70887437858"}
0005434022841	3F29D9	4143 215689	VALERIY NAZAROV	{"phone": "+70679236479"}
0005434022842	B5EB1B	4931 499224	TATYANA VASILEVA	{"email": "vasileva.t-1978@postgrespro.ru", "phone": "+70077069124"}
0005434022843	ECC1DC	4931 251289	ALEKSANDR CHERNOV	{"email": "aleksandr.chernov.061972@postgrespro.ru", "phone": "+70311815639"}
0005434022844	1366D7	9747 634204	GALINA ZHUKOVA	{"email": "g_zhukova.1964@postgrespro.ru", "phone": "+70146847766"}
0005434022845	699652	3956 206824	VALERIYA LEBEDEVA	{"phone": "+70714330035"}
0005434022846	8910EF	8247 032892	MIKHAIL SOROKIN	{"phone": "+70765703877"}
0005434022847	2E93C5	5021 377465	RUSTAM KUZMIN	{"email": "r-kuzmin101965@postgrespro.ru", "phone": "+70730543066"}
0005434022848	E143EF	7531 183055	YURIY KRASNOV	{"phone": "+70670919764"}
0005434022849	1FEA3C	1676 868236	VIKTOR RODIONOV	{"email": "viktorrodionov_041970@postgrespro.ru", "phone": "+70063760328"}
0005434022850	8C9D4A	3787 438751	DANILA SOLOVEV	{"phone": "+70918776397"}
0005434022851	1AB5F4	3062 185912	NADEZHDA ORLOVA	{"phone": "+70297581669"}
0005434022852	1AB5F4	7210 553232	ANDREY ZHUKOV	{"phone": "+70074322241"}
0005434022853	869B0A	2407 300145	VYACHESLAV MIRONOV	{"email": "vyacheslav-mironov.22031983@postgrespro.ru", "phone": "+70922079465"}
0005434022854	90AA83	7739 081537	LYUBOV NAZAROVA	{"phone": "+70437735716"}
0005434022855	90AA83	9833 456302	DMITRIY MOROZOV	{"phone": "+70573145493"}
0005434022856	B84592	6593 227782	ANDREY SMIRNOV	{"phone": "+70461827695"}
0005434022857	7EF2B9	7713 776793	STANISLAV KUZMIN	{"email": "kuzmin.s_061972@postgrespro.ru", "phone": "+70428689537"}
0005434022858	B2A331	5453 641006	PAVEL KUZNECOV	{"phone": "+70961107428"}
0005434022859	306694	6258 747944	ALEKSANDR DAVYDOV	{"phone": "+70095200879"}
0005434022860	7C3C3C	5105 607395	TAISIYA KUZNECOVA	{"phone": "+70240103260"}
0005434022861	A54E80	6907 753459	LARISA ZAYCEVA	{"email": "larisa-zayceva_1976@postgrespro.ru", "phone": "+70201885402"}
0005434022862	A54E80	0886 053834	KIRILL POPOV	{"phone": "+70564475227"}
0005434022863	4F119D	1905 433656	EVGENIY POPOV	{"email": "popov-evgeniy-111968@postgrespro.ru", "phone": "+70181927031"}
0005434022864	0EE650	9636 266046	ANDREY EGOROV	{"email": "aegorov.011970@postgrespro.ru", "phone": "+70310719612"}
0005434022865	0EE650	7521 277572	VALENTINA MELNIKOVA	{"phone": "+70089144371"}
0005434022866	CE7766	2378 261986	VLADIMIR SOROKIN	{"phone": "+70382128578"}
0005434022867	E73782	8408 564890	TIMUR PETROV	{"email": "petrov.t.09121980@postgrespro.ru", "phone": "+70677058942"}
0005434022868	E73782	2603 318559	ZINAIDA VASILEVA	{"phone": "+70106716923"}
0005434022869	E39A4E	0029 825122	STANISLAV KUZNECOV	{"email": "s_kuznecov1977@postgrespro.ru", "phone": "+70949351067"}
0005434022870	C4758D	6458 407745	VLADIMIR SEMENOV	{"email": "vsemenov_01021968@postgrespro.ru", "phone": "+70078753702"}
0005434022871	CF9F3A	3344 880844	ANDREY DMITRIEV	{"email": "andrey.dmitriev_1970@postgrespro.ru", "phone": "+70875145432"}
0005434022872	CF9F3A	6813 820231	NADEZHDA SEMENOVA	{"phone": "+70175175652"}
0005434022873	9DA057	4261 200254	NADEZHDA FILATOVA	{"phone": "+70270471899"}
0005434022874	9DA057	5486 473094	NATALIYA KUZNECOVA	{"email": "nataliya-kuznecova.1966@postgrespro.ru", "phone": "+70461046305"}
0005434022875	9DA057	4888 312359	VLADIMIR MEDVEDEV	{"email": "medvedevvladimir_06031977@postgrespro.ru", "phone": "+70874758074"}
0005434022876	16B026	1273 369121	ALEKSEY FEDOTOV	{"phone": "+70821599123"}
0005434022877	03CA3E	5885 003956	DMITRIY KONOVALOV	{"email": "konovalov.dmitriy02081969@postgrespro.ru", "phone": "+70056967902"}
0005434022878	B3CB41	7366 417907	VLADIMIR MAKAROV	{"email": "v.makarov_071967@postgrespro.ru", "phone": "+70553494013"}
0005434022879	49884E	5193 010523	ALEKSANDR SIDOROV	{"email": "asidorov-031961@postgrespro.ru", "phone": "+70555654840"}
0005434022880	A599F7	3341 949470	ARTEM POPOV	{"phone": "+70909733627"}
0005434022881	EA01FC	4456 718385	ROMAN IVANOV	{"phone": "+70858956705"}
0005434022882	ECFB2D	4639 999201	VALENTINA VASILEVA	{"email": "v-vasileva02101974@postgrespro.ru", "phone": "+70222664077"}
0005434022883	000769	8265 551713	LYUDMILA MIKHAYLOVA	{"phone": "+70561917157"}
0005434022884	000769	5552 039028	NADEZHDA ABRAMOVA	{"email": "abramova_nadezhda-081981@postgrespro.ru", "phone": "+70773156852"}
0005434022885	A7A6CE	5573 137978	ANASTASIYA IVANOVA	{"phone": "+70940640174"}
0005434022886	A7A6CE	5032 329451	NIKITA SCHERBAKOV	{"email": "n-scherbakov_1985@postgrespro.ru", "phone": "+70992405642"}
0005434022887	EE9F7C	6770 713457	ALEKSANDR BONDARENKO	{"email": "bondarenkoa20121977@postgrespro.ru", "phone": "+70570265597"}
0005434022888	851974	0436 878067	EVGENIYA IVANOVA	{"phone": "+70270718039"}
0005434022889	C7FACD	5876 309955	DANIYA NOVIKOVA	{"email": "dnovikova10121962@postgrespro.ru", "phone": "+70196486779"}
0005434022890	C7FACD	7772 083706	ALEKSEY EGOROV	{"phone": "+70625543290"}
0005434022891	A37CA9	3212 386307	SERGEY VOROBEV	{"email": "svorobev-1972@postgrespro.ru", "phone": "+70325766377"}
0005434022892	A37CA9	7407 312606	ANATOLIY SMIRNOV	{"email": "anatoliy.smirnov.051976@postgrespro.ru", "phone": "+70642455616"}
0005434022893	1AABC5	4747 945201	KARINA PETROVA	{"phone": "+70623754275"}
0005434022894	FD752F	1910 252854	LARISA KOZLOVA	{"email": "larisa.kozlova05061982@postgrespro.ru", "phone": "+70570983063"}
0005434022895	AB092C	9647 301876	OLGA TITOVA	{"email": "titovaolga-04071969@postgrespro.ru", "phone": "+70543089160"}
0005434022896	F823DD	1015 765990	NIKOLAY ZHUKOV	{"email": "nikolayzhukov-041970@postgrespro.ru", "phone": "+70701076266"}
0005434022897	F823DD	5644 152123	GALINA SCHERBAKOVA	{"phone": "+70181803799"}
0005434022898	AC94A8	1450 950531	GALINA VLASOVA	{"email": "vlasova-galina-25011977@postgrespro.ru", "phone": "+70981193990"}
0005434022899	6461CF	8958 124399	VALENTINA OSIPOVA	{"email": "osipova_v-041971@postgrespro.ru", "phone": "+70952220905"}
0005434022900	E2F565	5852 209263	VALENTINA FEDOROVA	{"phone": "+70419072847"}
0005434022901	11A687	2383 978714	NIKOLAY SOKOLOV	{"email": "nikolay.sokolov.07111980@postgrespro.ru", "phone": "+70508531158"}
0005434022902	FDED40	5378 701286	ALEKSEY PETROV	{"phone": "+70401820186"}
0005434022903	FDED40	0307 523768	NADEZHDA NAZAROVA	{"email": "nnazarova_1961@postgrespro.ru", "phone": "+70679285053"}
0005434022904	09B830	7439 754952	GENNADIY GERASIMOV	{"email": "gerasimov.g.1970@postgrespro.ru", "phone": "+70054051093"}
0005434022905	32F859	8703 736646	VLADIMIR TIKHONOV	{"phone": "+70567700062"}
0005434022906	798BB0	6297 225396	YURIY KULIKOV	{"phone": "+70579846142"}
0005434022907	798BB0	9091 163073	ANDREY TIMOFEEV	{"email": "andrey-timofeev1969@postgrespro.ru", "phone": "+70964961309"}
0005434022908	C5972C	7382 739467	IRINA ZHUKOVA	{"phone": "+70423279936"}
0005434022909	D3D5C2	7846 439994	ELENA MOISEEVA	{"phone": "+70405433994"}
0005434022910	4A90FD	2178 159493	MIKHAIL BELOV	{"phone": "+70042973345"}
0005434022911	1DA0F4	0370 558607	DMITRIY MOROZOV	{"phone": "+70820293161"}
0005434022912	1DA0F4	9114 261047	MARINA OSIPOVA	{"email": "osipovam.22111967@postgrespro.ru", "phone": "+70751276186"}
0005434022913	5E2D08	0877 887261	IRINA DAVYDOVA	{"email": "i.davydova20101976@postgrespro.ru", "phone": "+70172003827"}
0005434022914	32231B	0894 902827	ANASTASIYA EGOROVA	{"email": "aegorova.1972@postgrespro.ru", "phone": "+70493114216"}
0005434022915	4B218E	1922 787354	ALEKSEY KRASNOV	{"email": "aleksey_krasnov_1968@postgrespro.ru", "phone": "+70768083826"}
0005434022916	4B218E	2305 280774	ILYA VOROBEV	{"email": "vorobev_i-091980@postgrespro.ru", "phone": "+70364868962"}
0005434022917	00C812	9508 995196	KSENIYA IVANOVA	{"phone": "+70769894879"}
0005434022918	5E8CFE	6425 322215	ZINAIDA GORBUNOVA	{"phone": "+70727861074"}
0005434022919	5E8CFE	1300 425217	ROMAN MELNIKOV	{"phone": "+70816323498"}
0005434022920	072AE2	9039 932438	ANDREY PETROV	{"email": "petrov_a26121961@postgrespro.ru", "phone": "+70768847053"}
0005434022921	6048B7	4090 980858	TATYANA SOKOLOVA	{"email": "tsokolova-101972@postgrespro.ru", "phone": "+70344093499"}
0005434022922	C5FBF0	7282 762946	ANATOLIY VASILEV	{"email": "vasilevanatoliy101968@postgrespro.ru", "phone": "+70851526230"}
0005434022923	B7C139	9894 710705	ANDREY NAUMOV	{"phone": "+70179786930"}
0005434022924	B3B0C5	1018 571489	NATALYA KUZMINA	{"phone": "+70727660142"}
0005434022925	B3B0C5	3259 117005	MARINA FOMINA	{"phone": "+70771431415"}
0005434022926	313AB8	6374 300941	ELENA SERGEEVA	{"phone": "+70310795020"}
0005434022927	313AB8	7066 841766	ELENA KUZNECOVA	{"phone": "+70736518529"}
0005434022928	3C827F	5789 186081	ALEKSEY DENISOV	{"phone": "+70864974449"}
0005434022929	6B0BF3	3199 999693	EVGENIY VOROBEV	{"phone": "+70368360772"}
0005434022930	B307B3	7168 249203	LARISA VASILEVA	{"email": "vasileva_larisa-27101967@postgrespro.ru", "phone": "+70029405469"}
0005434022931	B307B3	5741 391295	DANIIL MOISEEV	{"email": "moiseevd_1963@postgrespro.ru", "phone": "+70158072020"}
0005434022932	B307B3	0149 548715	ALEKSANDR KARPOV	{"phone": "+70830191416"}
0005434022933	4BB44C	4385 491561	TAMARA ALEKSEEVA	{"email": "tamara.alekseeva10011979@postgrespro.ru", "phone": "+70677680880"}
0005434022934	1CF9F9	8601 523128	RAIS MARTYNOV	{"phone": "+70566368635"}
0005434022935	CB393B	2655 958263	ALEKSANDR POPOV	{"email": "popova28011972@postgrespro.ru", "phone": "+70912366904"}
0005434022936	FBD29F	3372 217433	LYUDMILA BORISOVA	{"phone": "+70351103015"}
0005434022937	FBD29F	3382 157557	DMITRIY RODIONOV	{"phone": "+70895342711"}
0005434022938	FBD29F	1516 011987	KRISTINA SAVELEVA	{"phone": "+70242929116"}
0005434022939	3E6839	9291 098502	ANNA KUZMINA	{"phone": "+70468475638"}
0005434022940	1DCF2F	3747 170309	ALEKSANDR SIDOROV	{"email": "sidorov_a07061989@postgrespro.ru", "phone": "+70134583642"}
0005434022941	1DCF2F	2528 753554	NIKOLAY NIKOLAEV	{"email": "nnikolaev_051971@postgrespro.ru", "phone": "+70040066169"}
0005434022942	1DCF2F	7710 842318	DMITRIY KULIKOV	{"phone": "+70467724823"}
0005434022943	A07CE4	0923 819798	KSENIYA GRISHINA	{"email": "kseniya_grishina.19011975@postgrespro.ru", "phone": "+70130231796"}
0005434022944	2448C4	4501 008297	VALENTINA ANISIMOVA	{"email": "anisimova-v.1970@postgrespro.ru", "phone": "+70063805965"}
0005434022945	2448C4	8473 622673	NATALYA ANDREEVA	{"email": "andreeva-n-03061972@postgrespro.ru", "phone": "+70004493149"}
0005434022946	2448C4	4379 842340	VLADIMIR VOROBEV	{"email": "vorobev_v1966@postgrespro.ru", "phone": "+70774573222"}
0005434022947	EC02D2	4605 080791	OLGA DENISOVA	{"email": "denisova_olga051972@postgrespro.ru", "phone": "+70758571424"}
0005434022948	EC02D2	1417 705621	OLGA NIKITINA	{"phone": "+70265947961"}
0005434022949	11F28C	2966 226756	IRINA KONOVALOVA	{"email": "konovalova.irina-1970@postgrespro.ru", "phone": "+70076210189"}
0005434022950	116BCD	0731 384006	SERGEY MATVEEV	{"email": "s-matveev_1976@postgrespro.ru", "phone": "+70368166221"}
0005434022951	116BCD	5985 502927	DAMIR IVANOV	{"phone": "+70201173827"}
0005434022952	CF901C	3765 237409	MARINA FEDOROVA	{"email": "mfedorova051978@postgrespro.ru", "phone": "+70386371231"}
0005434022953	CF901C	6109 817929	NIKITA GUSEV	{"phone": "+70998764514"}
0005434022954	22EC26	8666 706089	EVGENIYA NAZAROVA	{"phone": "+70382283699"}
0005434022955	22EC26	9292 058410	ELENA ABRAMOVA	{"email": "e_abramova.1968@postgrespro.ru", "phone": "+70724295995"}
0005434022956	F3D9FF	0997 905349	VIOLETTA PETROVA	{"email": "v-petrova.1967@postgrespro.ru", "phone": "+70370689560"}
0005434022957	F3D9FF	8874 637233	MARIYA EGOROVA	{"phone": "+70585098133"}
0005434022958	AD37CF	1079 856229	PETR KOZLOV	{"phone": "+70502689340"}
0005434022959	0DEA1F	3463 187036	OLGA ILINA	{"phone": "+70919755602"}
0005434022960	0DEA1F	5638 736454	PAVEL KUZNECOV	{"email": "kuznecov.pavel_1967@postgrespro.ru", "phone": "+70311673801"}
0005434022961	0DF7B8	6672 435296	NATALYA DENISOVA	{"phone": "+70291820924"}
0005434022962	109B5A	3234 360353	SERGEY NAUMOV	{"phone": "+70198028077"}
0005434022963	898709	1976 945287	VALENTINA ROMANOVA	{"phone": "+70419673064"}
0005434022964	4C1AF6	1710 736990	VALENTINA LAZAREVA	{"email": "lazarevavalentina-071981@postgrespro.ru", "phone": "+70271062554"}
0005434022965	F43931	5274 336963	SVETLANA ANDREEVA	{"email": "andreeva_s_1965@postgrespro.ru", "phone": "+70646870987"}
0005434022966	62FB33	7124 100107	ALEKSEY NIKITIN	{"email": "alekseynikitin-081980@postgrespro.ru", "phone": "+70929779137"}
0005434022967	69F689	9322 719712	SERGEY DMITRIEV	{"phone": "+70663478661"}
0005434022968	69F689	9442 036680	GENNADIY IVANOV	{"phone": "+70321408320"}
0005434022969	880EA3	4475 130763	YAN KONOVALOV	{"email": "konovalov-y.09031979@postgrespro.ru", "phone": "+70572318566"}
0005434022970	266D25	5354 246376	VENIAMIN ABRAMOV	{"email": "veniamin_abramov.19101983@postgrespro.ru", "phone": "+70525098818"}
0005434022971	28A46F	3609 703273	SERGEY ZHURAVLEV	{"phone": "+70253883280"}
0005434022972	7D7D06	4621 942228	ALEKSEY POPOV	{"email": "popov_aleksey.071976@postgrespro.ru", "phone": "+70288089027"}
0005434022973	7D7D06	3224 891637	TATYANA DANILOVA	{"phone": "+70890400660"}
0005434022974	9AFB9A	8762 741113	NATALYA PAVLOVA	{"phone": "+70768163359"}
0005434022975	043BE6	4388 527673	DARYA IVANOVA	{"email": "darya_ivanova.1968@postgrespro.ru", "phone": "+70179824953"}
0005434022976	ECD035	3770 683179	ANDREY GRIGOREV	{"email": "grigorev.andrey.111975@postgrespro.ru", "phone": "+70430148243"}
0005434022977	ECD035	1206 623042	EKATERINA KUDRYASHOVA	{"email": "kudryashova.ekaterina-06091963@postgrespro.ru", "phone": "+70186756776"}
0005434022978	B3D93D	2155 167131	ALEKSANDR GERASIMOV	{"email": "gerasimova-031955@postgrespro.ru", "phone": "+70793584034"}
0005434022979	FCF97A	7036 233230	ANNA EFIMOVA	{"phone": "+70026475205"}
0005434022980	F4D7F9	3034 254961	SVETLANA VOROBEVA	{"phone": "+70052647623"}
0005434022981	584BB7	1996 115449	SVETLANA YAKOVLEVA	{"phone": "+70611938967"}
0005434022982	FC40CE	6708 698841	OLGA MAKSIMOVA	{"phone": "+70675547501"}
0005434022983	4DB342	0562 895382	LYUCIYA GUSEVA	{"phone": "+70420612218"}
0005434022984	96AF98	6618 519447	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr.30101972@postgrespro.ru", "phone": "+70018278619"}
0005434022985	A181AF	8508 428452	GENNADIY EGOROV	{"phone": "+70376381080"}
0005434022986	8A9832	9696 212380	ARKADIY SHEVCHENKO	{"phone": "+70550492044"}
0005434022987	BC0290	9670 275572	ELEONORA KOZLOVA	{"email": "e.kozlova.091968@postgrespro.ru", "phone": "+70340220325"}
0005434022988	2B9969	6549 962571	ALEKSEY FEDOROV	{"email": "aleksey_fedorov_081965@postgrespro.ru", "phone": "+70826459675"}
0005434022989	F15BEB	0152 603523	YURIY ANDREEV	{"phone": "+70534468761"}
0005434022990	67F998	5736 969764	OLGA FADEEVA	{"email": "fadeevao_121975@postgrespro.ru", "phone": "+70330366782"}
0005434022991	67F998	2183 703568	ALEKSANDR ZAKHAROV	{"email": "a-zakharov-01061962@postgrespro.ru", "phone": "+70186826204"}
0005434022992	977266	3501 950998	YULIYA KONOVALOVA	{"email": "y_konovalova_071981@postgrespro.ru", "phone": "+70219574293"}
0005434022993	F8D062	5589 276961	ANDREY VOLKOV	{"phone": "+70365314809"}
0005434022994	397503	0506 174347	OKSANA BORISOVA	{"email": "borisova-oksana031968@postgrespro.ru", "phone": "+70221975353"}
0005434022995	6ED54E	8974 696358	VERA KRASNOVA	{"phone": "+70938888539"}
0005434022996	6ED54E	6601 830310	VLADISLAV FILIPPOV	{"phone": "+70810246522"}
0005434022997	1915E8	7397 163264	ANASTASIYA KARPOVA	{"phone": "+70816026916"}
0005434022998	A0DFFC	2475 678779	ANNA KOROLEVA	{"phone": "+70784552870"}
0005434022999	81BED1	4811 214776	IRINA FILIPPOVA	{"email": "irinafilippova_041966@postgrespro.ru", "phone": "+70554906143"}
0005434023000	E44B7F	2534 629572	OLEG FOMIN	{"phone": "+70275142858"}
0005434023001	3F938E	3778 852074	OLGA BELYAEVA	{"phone": "+70635541632"}
0005434023002	B69DB6	1969 413403	IGOR FEDOROV	{"phone": "+70030614413"}
0005434023003	881EAA	8726 726668	NATALYA KOROLEVA	{"phone": "+70470506822"}
0005434023004	726193	7525 558617	YULIYA LAZAREVA	{"email": "y_lazareva10091966@postgrespro.ru", "phone": "+70180263529"}
0005434023005	E35963	0606 524268	REGINA VLASOVA	{"phone": "+70163293950"}
0005434023006	0A8DF7	6890 066396	VLADIMIR MAKSIMOV	{"email": "maksimovv.101969@postgrespro.ru", "phone": "+70868826813"}
0005434023007	0A8DF7	8890 382764	VALENTINA KOZLOVA	{"email": "valentina.kozlova_01091972@postgrespro.ru", "phone": "+70234934313"}
0005434023008	241BD4	0224 458934	RAISA LUKYANOVA	{"email": "r.lukyanova-13111976@postgrespro.ru", "phone": "+70760623945"}
0005434023009	5BF246	4977 407036	TATYANA AFANASEVA	{"phone": "+70854730345"}
0005434023010	DC5591	7197 257205	INNA KUZNECOVA	{"phone": "+70192226969"}
0005434023011	33389D	0800 762154	LYUBOV ABRAMOVA	{"phone": "+70031210551"}
0005434023012	64D263	6218 019762	NATALYA NAUMOVA	{"email": "natalya.naumova.16061982@postgrespro.ru", "phone": "+70526568000"}
0005434023013	64D263	7450 129426	VERA GUSEVA	{"phone": "+70796363154"}
0005434023014	449C81	3307 795081	GALINA BELOVA	{"phone": "+70648346359"}
0005434023015	0E1498	0888 484403	ALINA SOROKINA	{"email": "sorokina-a18081976@postgrespro.ru", "phone": "+70339682703"}
0005434023016	AD66C3	7292 774230	KIRA FADEEVA	{"phone": "+70935611142"}
0005434023017	2F1836	6380 525950	ALEKSANDR SOROKIN	{"email": "sorokina.1982@postgrespro.ru", "phone": "+70933153312"}
0005434023018	2F1836	5836 356020	ALEKSEY KUZNECOV	{"phone": "+70055349290"}
0005434023019	63820D	2006 896090	ANASTASIYA MALYSHEVA	{"email": "malysheva-anastasiya1976@postgrespro.ru", "phone": "+70019200616"}
0005434023020	63820D	5552 495766	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a-1984@postgrespro.ru", "phone": "+70889811285"}
0005434023021	8DF836	6599 097501	NINA EGOROVA	{"email": "egorovan.111971@postgrespro.ru", "phone": "+70921763703"}
0005434023022	6F16CD	9069 786224	DMITRIY MIRONOV	{"email": "dmitriy_mironov.20051968@postgrespro.ru", "phone": "+70551103711"}
0005434023023	A17FE9	9199 931797	KLAVDIYA MOROZOVA	{"email": "morozovak1964@postgrespro.ru", "phone": "+70270517091"}
0005434023024	9E800F	7053 057116	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir.20021976@postgrespro.ru", "phone": "+70153594809"}
0005434023025	9E800F	8717 227300	ELENA KUZNECOVA	{"phone": "+70078122060"}
0005434023026	FBBA51	0498 744401	VALENTINA RODIONOVA	{"email": "v-rodionova_11021983@postgrespro.ru", "phone": "+70145306958"}
0005434023027	468A54	1797 089239	EKATERINA TARASOVA	{"phone": "+70066267562"}
0005434023028	468A54	6924 756849	TATYANA GUSEVA	{"email": "tatyanaguseva-1972@postgrespro.ru", "phone": "+70588077631"}
0005434023029	6CE6BD	2076 925429	GALINA ZAYCEVA	{"phone": "+70746733140"}
0005434023030	95F291	8443 016928	RINAT SOLOVEV	{"email": "rinatsolovev1961@postgrespro.ru", "phone": "+70326435765"}
0005434023031	AACC66	8344 523823	VARVARA FROLOVA	{"phone": "+70285009648"}
0005434023032	0CD7B2	2400 477169	DMITRIY SAVELEV	{"email": "savelevdmitriy-1967@postgrespro.ru", "phone": "+70543496887"}
0005434023033	4CEFE0	2202 052521	VLADIMIR IVANOV	{"email": "vladimir.ivanov.19111965@postgrespro.ru", "phone": "+70717156348"}
0005434023034	E902CE	1949 582037	OLEG VOLKOV	{"email": "oleg_volkov1972@postgrespro.ru", "phone": "+70175706809"}
0005434023035	611362	6419 697385	LYUDMILA ROMANOVA	{"email": "l_romanova.02091984@postgrespro.ru", "phone": "+70353321440"}
0005434023036	483BFB	2112 447782	ELENA FEDOROVA	{"email": "fedorovaelena-05061970@postgrespro.ru", "phone": "+70600756277"}
0005434023037	695AC7	8307 269799	ELVIRA KUDRYASHOVA	{"phone": "+70667007977"}
0005434023038	4BE520	3055 843182	STANISLAV YAKOVLEV	{"phone": "+70211231374"}
0005434023039	4BE520	8282 486548	NINA PETROVA	{"email": "petrovan_111979@postgrespro.ru", "phone": "+70583410638"}
0005434023040	4BE520	1269 503259	ANDREY MAKAROV	{"email": "makarov_andrey_101967@postgrespro.ru", "phone": "+70749535990"}
0005434023041	6D7CCF	9944 445158	MARINA LUKYANOVA	{"phone": "+70859426571"}
0005434023042	D59D42	7710 733598	OLEG ABRAMOV	{"email": "abramovoleg.12081969@postgrespro.ru", "phone": "+70684613325"}
0005434023043	F58275	5192 654151	VLADIMIR MATVEEV	{"email": "matveev_vladimir-1984@postgrespro.ru", "phone": "+70518348749"}
0005434023044	F58275	6015 119737	ALSU LUKYANOVA	{"email": "lukyanova_alsu.031966@postgrespro.ru", "phone": "+70347233231"}
0005434023045	56A424	2314 016598	ALESYA KULIKOVA	{"phone": "+70495356062"}
0005434023046	755F0B	3869 760992	ANATOLIY TIKHONOV	{"email": "atikhonov-26091970@postgrespro.ru", "phone": "+70624766023"}
0005434023047	755F0B	0270 642170	VARVARA NAZAROVA	{"email": "v_nazarova_051972@postgrespro.ru", "phone": "+70104543869"}
0005434023048	33ADD0	7187 367877	TATYANA KUZNECOVA	{"phone": "+70543857975"}
0005434023049	997024	0755 077126	ELVIRA VASILEVA	{"phone": "+70995215915"}
0005434023050	997024	6577 321812	GALINA EGOROVA	{"email": "egorovagalina-101964@postgrespro.ru", "phone": "+70716759169"}
0005434023051	F2FA8F	6174 914432	VIKTORIYA GERASIMOVA	{"email": "vgerasimova-21031957@postgrespro.ru", "phone": "+70852930602"}
0005434023052	1D23F5	4724 650040	EKATERINA SEMENOVA	{"email": "semenova-ekaterina-011974@postgrespro.ru", "phone": "+70992062122"}
0005434023053	1D23F5	2032 230720	OLGA PETROVA	{"email": "petrova-olga-121985@postgrespro.ru", "phone": "+70616740256"}
0005434023054	99E8DA	5740 706255	GALINA KISELEVA	{"phone": "+70236353670"}
0005434023055	5C194E	2809 944533	MARIYA ZAYCEVA	{"email": "zaycevamariya.051972@postgrespro.ru", "phone": "+70630682723"}
0005434023056	5C194E	2591 212983	NIKOLAY DAVYDOV	{"email": "nikolay.davydov_061980@postgrespro.ru", "phone": "+70771243749"}
0005434023057	5A2A4B	9717 393110	ALEKSANDR POPOV	{"email": "popovaleksandr1972@postgrespro.ru", "phone": "+70115875374"}
0005434023058	0BF5B0	3536 565306	VALERIY GRIGOREV	{"phone": "+70301568002"}
0005434023059	0BF5B0	6961 499443	EVGENIY DMITRIEV	{"email": "e.dmitriev-01031964@postgrespro.ru", "phone": "+70962123000"}
0005434023060	7CFB56	4439 495933	VALERIY MAKAROV	{"email": "valeriy-makarov.03031979@postgrespro.ru", "phone": "+70562520705"}
0005434023061	39BF5A	8844 649007	ALEKSANDR SMIRNOV	{"phone": "+70959459609"}
0005434023062	39BF5A	2543 650809	NATALYA NIKOLAEVA	{"phone": "+70060839644"}
0005434023063	FEB3B5	5165 132794	ANDREY VOLKOV	{"phone": "+70342339599"}
0005434023064	FEB3B5	2148 965794	NADEZHDA ZHUKOVA	{"phone": "+70083964323"}
0005434023065	C8B434	8986 368491	SVETLANA NIKOLAEVA	{"phone": "+70117790929"}
0005434023066	E19353	2797 879434	MARAT MOISEEV	{"email": "m.moiseev.23091985@postgrespro.ru", "phone": "+70364086686"}
0005434023067	E19353	0113 942943	IGOR IVANOV	{"phone": "+70649779870"}
0005434023068	4496F6	9107 552703	VALENTINA GORBUNOVA	{"phone": "+70900807650"}
0005434023069	D3072B	7268 765379	STANISLAV KOZLOV	{"email": "stanislavkozlov1963@postgrespro.ru", "phone": "+70559307551"}
0005434023070	31E6DC	4033 397574	RAIS SOROKIN	{"email": "rais.sorokin.1970@postgrespro.ru", "phone": "+70314432591"}
0005434023071	7EA689	5638 376829	ANTON PAVLOV	{"phone": "+70355120003"}
0005434023072	714DAC	7983 768377	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr-1974@postgrespro.ru", "phone": "+70362391818"}
0005434023073	14447D	2761 757479	EKATERINA ANDREEVA	{"phone": "+70198372434"}
0005434023074	14447D	2491 704903	ALEKSANDR NAUMOV	{"phone": "+70903486595"}
0005434023075	D936ED	8238 663814	NADEZHDA SAVELEVA	{"phone": "+70327000315"}
0005434023076	407F24	9996 717038	ILYA VOROBEV	{"phone": "+70504678065"}
0005434023077	F1E093	8799 034651	BORIS MATVEEV	{"email": "boris-matveev_1966@postgrespro.ru", "phone": "+70913463844"}
0005434023078	DF5F29	0997 866922	NINA RYABOVA	{"phone": "+70208977757"}
0005434023079	EA0DEE	3554 711527	OLEG BARANOV	{"email": "oleg_baranov.25061985@postgrespro.ru", "phone": "+70144287005"}
0005434023080	674B3B	5925 866892	ANATOLIY GERASIMOV	{"phone": "+70850502368"}
0005434023081	674B3B	3049 064952	VALENTINA KUZNECOVA	{"phone": "+70500853718"}
0005434023082	E5F6BB	5481 253761	VLADIMIR POPOV	{"phone": "+70382778070"}
0005434023083	E5F6BB	8123 633797	VLADIMIR SEMENOV	{"phone": "+70046052220"}
0005434023084	CF38D0	1064 780126	VLADIMIR MARTYNOV	{"phone": "+70472590450"}
0005434023085	ECF613	1970 998767	ANATOLIY POPOV	{"email": "popovanatoliy_24041963@postgrespro.ru", "phone": "+70457703077"}
0005434023086	41344B	0412 695135	REGINA VLASOVA	{"email": "r-vlasova.03111969@postgrespro.ru", "phone": "+70675801541"}
0005434023087	042BEC	6051 518111	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr.1975@postgrespro.ru", "phone": "+70491237314"}
0005434023088	042BEC	2588 021837	VERA MELNIKOVA	{"email": "veramelnikova-1972@postgrespro.ru", "phone": "+70963333669"}
0005434023089	72AB24	1312 924320	AMIR FEDOROV	{"email": "amir.fedorov_1971@postgrespro.ru", "phone": "+70916253645"}
0005434023090	EEC7A6	7045 860439	TATYANA KISELEVA	{"email": "t-kiseleva_02121974@postgrespro.ru", "phone": "+70609189403"}
0005434023091	2C26AD	6555 179807	NINA KALININA	{"phone": "+70043696371"}
0005434023092	4D703E	3676 134689	IGOR GORBUNOV	{"email": "gorbunov_igor_25071976@postgrespro.ru", "phone": "+70098828643"}
0005434023093	4D703E	3880 269291	VIKTOR DAVYDOV	{"phone": "+70831561025"}
0005434023094	40FED0	7092 222927	EDUARD SOKOLOV	{"phone": "+70271707227"}
0005434023095	72DB7C	1907 959906	LYUBOV FILIPPOVA	{"email": "lyubov.filippova_1973@postgrespro.ru", "phone": "+70201044551"}
0005434023096	726041	7260 894922	ALLA TIKHONOVA	{"phone": "+70915139723"}
0005434023097	726041	7117 616232	ALEKSANDR DMITRIEV	{"email": "aleksandrdmitriev051968@postgrespro.ru", "phone": "+70249308112"}
0005434023098	D50EFC	5884 889137	TAMARA ILINA	{"email": "ilinatamara23041980@postgrespro.ru", "phone": "+70589861753"}
0005434023099	85F2B2	8044 106518	DENIS FOMIN	{"phone": "+70819716107"}
0005434023100	85F2B2	7345 088981	ANASTASIYA FILIPPOVA	{"email": "a_filippova.1968@postgrespro.ru", "phone": "+70638447589"}
0005434023101	635420	5244 222494	OLGA ZAYCEVA	{"phone": "+70346893784"}
0005434023102	364044	6465 553706	VIKTOR SHEVCHENKO	{"phone": "+70051432774"}
0005434023103	B5E809	9595 144485	OLGA MEDVEDEVA	{"phone": "+70825578962"}
0005434023104	4537A7	7780 865650	GERMAN BARANOV	{"email": "baranov.g021976@postgrespro.ru", "phone": "+70343735157"}
0005434023105	7FC8D6	4536 185907	ANASTASIYA ALEKSANDROVA	{"phone": "+70785169445"}
0005434023106	292AF1	4232 031569	ALEKSEY KOROLEV	{"phone": "+70273290343"}
0005434023107	292AF1	8166 957604	PAVEL VOROBEV	{"email": "vorobev.pavel_061973@postgrespro.ru", "phone": "+70320172926"}
0005434023108	1B41D9	1378 922846	DANILA ZHURAVLEV	{"phone": "+70018222196"}
0005434023109	1B41D9	5997 938998	ALEKSEY GRIGOREV	{"phone": "+70202291894"}
0005434023110	1B41D9	9509 574056	NIKOLAY AFANASEV	{"phone": "+70205668573"}
0005434023111	F1B7FB	1153 921803	VLADIMIR MAKSIMOV	{"phone": "+70787583884"}
0005434023112	008DC5	1621 703307	YURIY KUZNECOV	{"email": "yuriy.kuznecov.14081978@postgrespro.ru", "phone": "+70106857112"}
0005434023113	00D1D2	2005 138309	ARTUR IVANOV	{"email": "aivanov-101977@postgrespro.ru", "phone": "+70481599634"}
0005434023114	A142BA	4073 154995	ANTONINA FROLOVA	{"email": "frolova.a-1979@postgrespro.ru", "phone": "+70993272993"}
0005434023115	A9CDBE	1506 179558	NINA KOMAROVA	{"email": "komarovanina-1975@postgrespro.ru", "phone": "+70276685141"}
0005434023116	A9CDBE	1744 961025	VLADIMIR SHEVCHENKO	{"phone": "+70127742222"}
0005434023117	5F465D	9573 659008	KRISTINA MIRONOVA	{"email": "mironovak_16121974@postgrespro.ru", "phone": "+70642542442"}
0005434023118	154B17	3077 746117	VLADIMIR ROMANOV	{"email": "romanovv.14101977@postgrespro.ru", "phone": "+70771602020"}
0005434023119	154B17	1202 293846	KONSTANTIN MAKAROV	{"email": "makarov_konstantin.1966@postgrespro.ru", "phone": "+70337858416"}
0005434023120	3CA8D5	8077 147559	TATYANA MIKHAYLOVA	{"email": "tatyana.mikhaylova.1969@postgrespro.ru", "phone": "+70837133517"}
0005434023121	BC60E7	3390 932275	ILDUS NOVIKOV	{"email": "ildusnovikov-101975@postgrespro.ru", "phone": "+70813456058"}
0005434023122	BC60E7	8259 290210	EVGENIY ZHUKOV	{"phone": "+70483739238"}
0005434023123	9541FE	8054 287479	GALINA GUSEVA	{"phone": "+70347775897"}
0005434023124	EF3431	6106 330891	SVETLANA KALININA	{"email": "kalinina.svetlana14091980@postgrespro.ru", "phone": "+70774816618"}
0005434023125	EF3431	1510 146441	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy.1984@postgrespro.ru", "phone": "+70029196660"}
0005434023126	1B6D40	8860 517270	VITALIY OSIPOV	{"phone": "+70900035692"}
0005434023127	1B6D40	2947 569981	DANIIL DENISOV	{"email": "d_denisov051983@postgrespro.ru", "phone": "+70069103901"}
0005434023128	34E123	1922 881739	LIDIYA DAVYDOVA	{"email": "davydova-lidiya031983@postgrespro.ru", "phone": "+70004119947"}
0005434023129	AAE07A	9013 095180	ELENA IVANOVA	{"email": "ivanova.e1984@postgrespro.ru", "phone": "+70809782964"}
0005434023130	78475D	6343 949972	LILIYA DANILOVA	{"email": "liliyadanilova1973@postgrespro.ru", "phone": "+70751277210"}
0005434023131	78475D	3638 348152	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov.1970@postgrespro.ru", "phone": "+70798104802"}
0005434023132	D31010	0171 641002	VYACHESLAV KARPOV	{"phone": "+70639334993"}
0005434023133	D31010	0106 866332	MARIYA DENISOVA	{"email": "denisova.m-1967@postgrespro.ru", "phone": "+70045114417"}
0005434023134	16B223	8932 394870	NIKOLAY ROMANOV	{"phone": "+70897310706"}
0005434023135	16B223	6593 223781	ALINA MIKHAYLOVA	{"email": "a.mikhaylova-15011976@postgrespro.ru", "phone": "+70356460903"}
0005434023247	3963FF	7586 121438	TATYANA NOVIKOVA	{"phone": "+70866327918"}
0005434023136	D0003A	2009 565763	VYACHESLAV ISAEV	{"email": "isaev.vyacheslav-031975@postgrespro.ru", "phone": "+70606983350"}
0005434023137	8EA5E6	2339 932339	POLINA KOMAROVA	{"phone": "+70868064971"}
0005434023138	8EA5E6	4552 167361	ELINA TITOVA	{"email": "titova-e.121980@postgrespro.ru", "phone": "+70454407217"}
0005434023139	76DD01	9844 186255	ANDREY FILIPPOV	{"phone": "+70960578748"}
0005434023140	36E86B	6851 706580	YULIYA KARPOVA	{"email": "yuliyakarpova.1975@postgrespro.ru", "phone": "+70538215981"}
0005434023141	166124	4459 852424	ALEKSEY BELOV	{"email": "alekseybelov-1973@postgrespro.ru", "phone": "+70667928793"}
0005434023142	166124	3290 574987	LARISA TITOVA	{"email": "l.titova_30031981@postgrespro.ru", "phone": "+70097900408"}
0005434023143	028AC4	9451 514971	VIKTOR SOROKIN	{"phone": "+70614996926"}
0005434023144	86542F	8392 514352	GALINA TARASOVA	{"email": "tarasova.galina1968@postgrespro.ru", "phone": "+70120387949"}
0005434023145	1C85B6	3090 428029	SERGEY GAVRILOV	{"email": "sergey-gavrilov011968@postgrespro.ru", "phone": "+70665342837"}
0005434023146	1C85B6	9595 311070	NINA ILINA	{"phone": "+70043027757"}
0005434023147	572C11	0409 250018	VALENTINA LEBEDEVA	{"email": "valentina.lebedeva.011983@postgrespro.ru", "phone": "+70993325328"}
0005434023148	747D6A	4434 957284	EKATERINA IVANOVA	{"email": "e-ivanova.14061974@postgrespro.ru", "phone": "+70515137095"}
0005434023149	2DE46C	5017 576245	NINA SCHERBAKOVA	{"email": "nina.scherbakova.041954@postgrespro.ru", "phone": "+70574935252"}
0005434023150	A948A0	6678 405403	ANDREY KUZNECOV	{"email": "andrey_kuznecov-24091969@postgrespro.ru", "phone": "+70481448353"}
0005434023151	A640C7	7767 639051	PAVEL KUZNECOV	{"email": "kuznecov-pavel_27051967@postgrespro.ru", "phone": "+70077657809"}
0005434023152	795152	1131 708622	MARINA DANILOVA	{"email": "m_danilova-16041977@postgrespro.ru", "phone": "+70459059516"}
0005434023153	3AA0A3	2932 612260	GERMAN ZAYCEV	{"email": "zaycev_german_071982@postgrespro.ru", "phone": "+70831047376"}
0005434023154	2C45CC	2016 885487	ROMAN MAKSIMOV	{"phone": "+70776342082"}
0005434023155	23DBA0	3231 261011	VLADIMIR BARANOV	{"phone": "+70371340247"}
0005434023156	23DBA0	1169 465386	POLINA BORISOVA	{"phone": "+70017012431"}
0005434023157	620BA7	3959 193473	ALEFTINA DMITRIEVA	{"phone": "+70063664009"}
0005434023158	C533F9	7080 596850	VLADIMIR DENISOV	{"phone": "+70458576072"}
0005434023159	F024AF	2638 939431	ROMAN MAKSIMOV	{"phone": "+70533957671"}
0005434023160	F024AF	3703 300115	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr.12121973@postgrespro.ru", "phone": "+70173824518"}
0005434023161	F024AF	5999 668650	TATYANA GERASIMOVA	{"phone": "+70986645081"}
0005434023162	D1E3B9	6736 436201	VIOLETTA ROMANOVA	{"email": "romanova-violetta_051978@postgrespro.ru", "phone": "+70258406921"}
0005434023163	259BC3	0816 218269	IVAN ORLOV	{"phone": "+70557151619"}
0005434023164	11AB8B	3482 064321	TATYANA GAVRILOVA	{"email": "gavrilovatatyana_15051968@postgrespro.ru", "phone": "+70370986473"}
0005434023165	11AB8B	3141 358439	VARVARA FEDOROVA	{"email": "varvara.fedorova.15081963@postgrespro.ru", "phone": "+70747651992"}
0005434023166	19F1B4	2959 864285	NADEZHDA LAZAREVA	{"phone": "+70518000611"}
0005434023167	9725D0	7785 769329	MIKHAIL KONOVALOV	{"phone": "+70390488161"}
0005434023168	CDCBD7	7879 943086	ALEKSEY PETROV	{"phone": "+70041400123"}
0005434023169	C5B114	3748 368187	EGOR ROMANOV	{"phone": "+70076343250"}
0005434023170	5652D9	5190 588232	SERGEY MELNIKOV	{"email": "sergey_melnikov10101970@postgrespro.ru", "phone": "+70802382131"}
0005434023171	5652D9	2252 214986	EKATERINA ZOTOVA	{"email": "zotovaekaterina15101970@postgrespro.ru", "phone": "+70643800438"}
0005434023172	DEB6A7	3079 916583	IGOR VOLKOV	{"phone": "+70908318141"}
0005434023173	F13756	0306 985866	GLEB VASILEV	{"email": "glebvasilev-04041970@postgrespro.ru", "phone": "+70499173117"}
0005434023174	02922B	4906 930872	ANGELINA ZAYCEVA	{"email": "zaycevaa_1967@postgrespro.ru", "phone": "+70269177685"}
0005434023175	63A539	7914 070616	NINA VASILEVA	{"phone": "+70039689237"}
0005434023176	63A539	3465 374212	IVAN ABRAMOV	{"email": "abramov.ivan1968@postgrespro.ru", "phone": "+70798527060"}
0005434023177	63A539	5474 297379	NIKOLAY ALEKSANDROV	{"phone": "+70428379713"}
0005434023178	58DE8A	3192 727924	YURIY KRASNOV	{"email": "ykrasnov-1967@postgrespro.ru", "phone": "+70150520228"}
0005434023179	3F6A44	2533 429309	YURIY KUZMIN	{"email": "kuzmin-y.1972@postgrespro.ru", "phone": "+70833664600"}
0005434023180	3F6A44	5557 390467	EVGENIY ZAKHAROV	{"email": "zakharov.e_031971@postgrespro.ru", "phone": "+70918607371"}
0005434023181	7D70F7	9985 012188	PAVEL SERGEEV	{"phone": "+70005390858"}
0005434023182	4577CB	7813 077915	KIRILL VOROBEV	{"email": "kirill_vorobev.1976@postgrespro.ru", "phone": "+70250035211"}
0005434023183	027BA0	3570 986627	ROMAN KARPOV	{"email": "r-karpov_011975@postgrespro.ru", "phone": "+70418231761"}
0005434023184	9AAA37	5009 238468	NIKOLAY MAKAROV	{"email": "nikolay_makarov.25011978@postgrespro.ru", "phone": "+70605728543"}
0005434023185	35396E	4006 022405	ELENA TARASOVA	{"email": "e_tarasova_1973@postgrespro.ru", "phone": "+70037470862"}
0005434023186	B0AE7E	5504 133468	LEONID IVANOV	{"email": "leonidivanov_31071976@postgrespro.ru", "phone": "+70636943488"}
0005434023187	B98674	1053 856302	ANDREY KAZAKOV	{"phone": "+70456031482"}
0005434023188	6D2C78	0221 954406	TATYANA BORISOVA	{"email": "tatyanaborisova-25071977@postgrespro.ru", "phone": "+70185419739"}
0005434023189	59EE7D	2222 127225	DARYA SERGEEVA	{"phone": "+70762032283"}
0005434023190	C86CAC	9053 234225	MIKHAIL KUZNECOV	{"phone": "+70539352939"}
0005434023191	C86CAC	8063 377732	VERONIKA SCHERBAKOVA	{"email": "scherbakova.veronika-12121975@postgrespro.ru", "phone": "+70654046719"}
0005434023192	59E029	2480 455274	SVETLANA TITOVA	{"email": "s_titova_1969@postgrespro.ru", "phone": "+70945081360"}
0005434023193	F1D544	4777 454891	RUSLAN SMIRNOV	{"email": "smirnov.ruslan_121964@postgrespro.ru", "phone": "+70339417050"}
0005434023194	F1D544	9147 992912	NATALYA ROMANOVA	{"phone": "+70988602644"}
0005434023195	2498DD	9274 676045	KIRILL PAVLOV	{"email": "k.pavlov_1963@postgrespro.ru", "phone": "+70006817831"}
0005434023196	EB8299	5618 815343	OLGA VOLKOVA	{"email": "volkova.o30031977@postgrespro.ru", "phone": "+70129303300"}
0005434023197	0441FE	4800 963374	NATALYA SEMENOVA	{"email": "n-semenova_071979@postgrespro.ru", "phone": "+70947185140"}
0005434023198	0441FE	2113 768189	YANA MEDVEDEVA	{"phone": "+70202237595"}
0005434023199	0441FE	8005 604974	ALEKSANDR NAUMOV	{"phone": "+70801611623"}
0005434023200	4B08D6	4447 757261	MARGARITA KUZMINA	{"phone": "+70505831931"}
0005434023201	B6A8FA	1570 609021	ZINAIDA GUSEVA	{"phone": "+70563760320"}
0005434023202	E96F2B	4363 340437	MAKSIM GUSEV	{"email": "mgusev_06071982@postgrespro.ru", "phone": "+70531477507"}
0005434023203	E96F2B	0600 144987	MIROSLAV PETROV	{"email": "petrov-m081967@postgrespro.ru", "phone": "+70798851883"}
0005434023204	D64300	4478 413707	MIKHAIL MAKSIMOV	{"email": "maksimov_mikhail.1967@postgrespro.ru", "phone": "+70979963654"}
0005434023205	554967	4817 629114	ALEKSEY MIKHAYLOV	{"phone": "+70565109741"}
0005434023206	000842	6372 396970	TATYANA NIKITINA	{"phone": "+70698837467"}
0005434023207	000842	7452 869794	YULIYA KOZLOVA	{"phone": "+70675857345"}
0005434023208	FC4AAF	2555 297510	KAPITALINA MOROZOVA	{"phone": "+70815771796"}
0005434023209	BF9D37	3741 010734	ALEKSANDR IVANOV	{"phone": "+70676054145"}
0005434023210	BF9D37	8906 137707	EVGENIY MARTYNOV	{"phone": "+70512817971"}
0005434023211	2E275D	4701 389957	NIKOLAY ISAEV	{"email": "isaev_nikolay.1977@postgrespro.ru", "phone": "+70189232182"}
0005434023212	4CAB0F	1145 718474	NINA ANDREEVA	{"phone": "+70792169793"}
0005434023213	327C1A	7266 240155	SNEZHANA KISELEVA	{"phone": "+70639490518"}
0005434023214	7453CD	4880 491809	VALERIY PAVLOV	{"email": "valeriy.pavlov-041974@postgrespro.ru", "phone": "+70376687107"}
0005434023215	7453CD	1195 060423	YULIYA MAKAROVA	{"email": "yuliyamakarova.031991@postgrespro.ru", "phone": "+70025283391"}
0005434023216	1EAC6C	1534 659875	IRINA DAVYDOVA	{"email": "davydova.irina.1972@postgrespro.ru", "phone": "+70170346765"}
0005434023217	EBFA1C	6189 344724	NADEZHDA BELYAEVA	{"email": "belyaeva.n.1972@postgrespro.ru", "phone": "+70224639819"}
0005434023218	D416D4	4914 803469	ANNA FILIPPOVA	{"phone": "+70656826620"}
0005434023219	137D3F	7367 919261	VERA ORLOVA	{"email": "orlova_v.1974@postgrespro.ru", "phone": "+70826393933"}
0005434023220	74C221	6071 641877	ALLA AKIMOVA	{"phone": "+70182587532"}
0005434023221	74C221	2819 554793	DMITRIY MEDVEDEV	{"phone": "+70427652780"}
0005434023222	74C221	8409 780216	IGOR KRASNOV	{"email": "ikrasnov-1961@postgrespro.ru", "phone": "+70575171855"}
0005434023223	CBA044	9010 796816	ELENA ANDREEVA	{"phone": "+70081792424"}
0005434023224	95426E	2305 461558	NIKOLAY POPOV	{"phone": "+70153501618"}
0005434023225	712BEC	7957 441854	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr_041971@postgrespro.ru", "phone": "+70521759466"}
0005434023226	775366	9093 121740	VIKTOR SERGEEV	{"email": "viktor.sergeev.24081978@postgrespro.ru", "phone": "+70896540228"}
0005434023227	775366	6795 818153	EKATERINA IVANOVA	{"phone": "+70118413005"}
0005434023228	0C207B	5318 181107	ALEKSANDR SOLOVEV	{"phone": "+70628897087"}
0005434023229	20727E	4525 631682	VYACHESLAV KUZNECOV	{"email": "vyacheslav.kuznecov.1973@postgrespro.ru", "phone": "+70777195476"}
0005434023230	9D4F2B	2588 076934	VALENTINA KUZNECOVA	{"email": "vkuznecova_02031975@postgrespro.ru", "phone": "+70370010560"}
0005434023231	9D4F2B	0343 343809	YURIY KULIKOV	{"phone": "+70892590015"}
0005434023232	FB7AAD	8709 925671	ALEKSEY SHEVCHENKO	{"email": "shevchenko_a-011969@postgrespro.ru", "phone": "+70987209707"}
0005434023233	FB7AAD	6087 919329	LIDIYA KUZMINA	{"email": "kuzmina-l22081972@postgrespro.ru", "phone": "+70666356760"}
0005434023234	6683DC	5756 898947	ELENA MIKHAYLOVA	{"phone": "+70807961283"}
0005434023235	DD3D6B	6814 216547	OKSANA KUZNECOVA	{"email": "kuznecovaoksana.061978@postgrespro.ru", "phone": "+70045475763"}
0005434023236	0E8B8E	4317 060778	SERGEY SEMENOV	{"email": "ssemenov.101972@postgrespro.ru", "phone": "+70976564644"}
0005434023237	0E8B8E	2050 450265	VIKTOR BORISOV	{"email": "borisovv-011972@postgrespro.ru", "phone": "+70765429491"}
0005434023238	46075F	2793 014714	RAVIL FEDOROV	{"email": "fedorov_ravil1966@postgrespro.ru", "phone": "+70580129076"}
0005434023239	44A94B	1069 612330	MARINA KALININA	{"email": "marina-kalinina.1979@postgrespro.ru", "phone": "+70760868282"}
0005434023240	B6F0FB	1992 980457	NIKITA FILIPPOV	{"email": "filippovn-29121961@postgrespro.ru", "phone": "+70882811692"}
0005434023241	B6F0FB	9209 874074	VLADIMIR ZAKHAROV	{"email": "zakharovv111964@postgrespro.ru", "phone": "+70765527853"}
0005434023242	FF42C3	4831 591150	NATALYA BARANOVA	{"phone": "+70396741314"}
0005434023243	641E2E	2581 027487	GALINA SMIRNOVA	{"phone": "+70291158875"}
0005434023244	BB5632	4571 221897	DMITRIY BORISOV	{"phone": "+70222577555"}
0005434023245	BB5632	2586 297253	NIKOLAY BORISOV	{"email": "nikolayborisov_011977@postgrespro.ru", "phone": "+70641366924"}
0005434023246	3963FF	4024 470634	EKATERINA GUSEVA	{"email": "gusevae.14081972@postgrespro.ru", "phone": "+70809619439"}
0005434023248	236D9C	7451 603170	DANILA NAZAROV	{"phone": "+70596821128"}
0005434023249	236D9C	5736 576187	ANNA VASILEVA	{"email": "vasileva_a_1965@postgrespro.ru", "phone": "+70735966219"}
0005434023250	79BEB0	0819 766761	NINA STEPANOVA	{"phone": "+70150643671"}
0005434023251	914DAF	3708 163921	VASILIY IVANOV	{"email": "ivanov-v.011978@postgrespro.ru", "phone": "+70014097058"}
0005434023252	463937	9050 226693	IRINA MAKSIMOVA	{"phone": "+70558795622"}
0005434023253	D584A3	9645 523641	ANTON KUZNECOV	{"email": "anton.kuznecov_17091971@postgrespro.ru", "phone": "+70111254616"}
0005434023254	D584A3	2284 851330	SERGEY SERGEEV	{"email": "sergeev_sergey091970@postgrespro.ru", "phone": "+70408791559"}
0005434023255	4DD895	2204 756432	SERGEY ORLOV	{"email": "sergeyorlov28101968@postgrespro.ru", "phone": "+70799209596"}
0005434023256	548746	7790 206829	MARIYA PETROVA	{"phone": "+70970075363"}
0005434023257	1B43DA	3884 184711	SERGEY NAZAROV	{"email": "s_nazarov.051986@postgrespro.ru", "phone": "+70348399433"}
0005434023258	F4E1BD	9036 937105	ALEKSANDR PETROV	{"email": "petrov.a-051970@postgrespro.ru", "phone": "+70528558415"}
0005434023259	4D0FFB	5062 278639	TATYANA STEPANOVA	{"email": "stepanova-t.111970@postgrespro.ru", "phone": "+70892772768"}
0005434023260	4D0FFB	5169 671046	VLADIMIR BORISOV	{"phone": "+70763178220"}
0005434023261	0BD5E5	6906 518331	VERA SMIRNOVA	{"phone": "+70857299774"}
0005434023262	EC8DFD	8990 126930	IVAN MATVEEV	{"phone": "+70668685414"}
0005434023263	EC8DFD	4521 402562	VYACHESLAV KOZLOV	{"email": "kozlovv_15031974@postgrespro.ru", "phone": "+70148107591"}
0005434023264	D4EB62	0587 556868	ANTONINA FEDOROVA	{"email": "fedorovaa-1971@postgrespro.ru", "phone": "+70371148666"}
0005434023265	CF2BDE	0764 920562	ILYA MEDVEDEV	{"email": "i-medvedev_101974@postgrespro.ru", "phone": "+70349753875"}
0005434023266	EEB99B	4372 642782	ALEKSEY SOROKIN	{"email": "aleksey-sorokin-1960@postgrespro.ru", "phone": "+70184889078"}
0005434023267	BB564D	1887 583831	NINA ORLOVA	{"phone": "+70206348675"}
0005434023268	9C6749	3841 855526	ARTUR PETROV	{"phone": "+70412566676"}
0005434023269	8558B1	6095 051484	DANILA BELOV	{"phone": "+70740893589"}
0005434023270	6C8B73	4421 957037	ANNA SEMENOVA	{"phone": "+70767209579"}
0005434023271	4589A8	7231 766188	NATALYA DMITRIEVA	{"email": "dmitrieva_natalya011967@postgrespro.ru", "phone": "+70382259118"}
0005434023272	D5F6F7	3833 435842	IVAN MOISEEV	{"email": "moiseev_ivan_1966@postgrespro.ru", "phone": "+70955178467"}
0005434023273	D5F6F7	6980 646934	NURIYA POPOVA	{"email": "n_popova_1967@postgrespro.ru", "phone": "+70567476911"}
0005434023274	4F5CEF	8778 341669	VLADIMIR GAVRILOV	{"email": "vgavrilov.1982@postgrespro.ru", "phone": "+70185197441"}
0005434023275	41BFCD	9504 665957	VLADIMIR IVANOV	{"phone": "+70040025210"}
0005434023276	41BFCD	0137 965839	TATYANA KUZNECOVA	{"phone": "+70986742645"}
0005434023277	4116D5	3876 670802	KIRILL SOKOLOV	{"email": "k-sokolov_041964@postgrespro.ru", "phone": "+70535466336"}
0005434023278	AD4AF1	9794 817572	VIKTOR KUZMIN	{"email": "viktor.kuzmin05061972@postgrespro.ru", "phone": "+70362665514"}
0005434023279	AD4AF1	4912 190863	ANASTASIYA NIKOLAEVA	{"email": "a-nikolaeva.1969@postgrespro.ru", "phone": "+70897948438"}
0005434023280	DA39EB	4104 380670	SERGEY MIKHAYLOV	{"phone": "+70167870335"}
0005434023281	DA39EB	8800 237627	ALEKSANDR MIKHAYLOV	{"phone": "+70889097930"}
0005434023282	F26F33	1250 308609	EVGENIYA AFANASEVA	{"phone": "+70214181561"}
0005434023283	F26F33	0190 370142	ANASTASIYA ZHURAVLEVA	{"phone": "+70955615038"}
0005434023284	F26F33	5498 805092	SERGEY KULIKOV	{"email": "sergey.kulikov.061965@postgrespro.ru", "phone": "+70486915051"}
0005434023285	FE90EC	0275 100567	POLINA FEDOROVA	{"phone": "+70865109160"}
0005434023286	FE90EC	2871 006726	EVGENIY MAKAROV	{"email": "evgeniymakarov-1979@postgrespro.ru", "phone": "+70427447815"}
0005434023287	FE90EC	8803 625625	VLADIMIR MIRONOV	{"phone": "+70596648041"}
0005434023288	D24EC4	4907 036552	ILYA NIKOLAEV	{"email": "nikolaevilya-1972@postgrespro.ru", "phone": "+70746200936"}
0005434023289	5D6DD6	3830 421249	DMITRIY KOROLEV	{"phone": "+70459906158"}
0005434023290	5D6DD6	8596 102105	GALINA MIKHAYLOVA	{"email": "galinamikhaylova-14121963@postgrespro.ru", "phone": "+70219838295"}
0005434023291	B03097	3723 925408	EVGENIY DENISOV	{"email": "denisove-081987@postgrespro.ru", "phone": "+70309655056"}
0005434023292	B03097	2825 324020	SERGEY MAKSIMOV	{"email": "maksimov.sergey1963@postgrespro.ru", "phone": "+70460501680"}
0005434023293	5303AD	1854 979330	ANASTASIYA DANILOVA	{"email": "danilova-anastasiya1975@postgrespro.ru", "phone": "+70607247572"}
0005434023294	2DFAE1	6484 669758	IRINA SOKOLOVA	{"phone": "+70381130530"}
0005434023295	2DFAE1	0572 561604	NATALYA VOROBEVA	{"phone": "+70396963282"}
0005434023296	9B05EB	6574 516103	YURIY MEDVEDEV	{"phone": "+70482520019"}
0005434023297	9B05EB	1070 647640	ELIZAVETA IVANOVA	{"phone": "+70995559436"}
0005434023298	303900	9491 792053	ELENA SCHERBAKOVA	{"phone": "+70733032713"}
0005434023299	303900	9190 246601	NATALYA ZAKHAROVA	{"email": "zakharovanatalya021968@postgrespro.ru", "phone": "+70904197586"}
0005434023300	663611	1178 749663	NATALYA BOGDANOVA	{"phone": "+70951057164"}
0005434023301	47A3DD	9433 610375	ALINA KONDRATEVA	{"email": "kondrateva.a_1971@postgrespro.ru", "phone": "+70365546324"}
0005434023302	47A3DD	7245 998393	MARIYA ANDREEVA	{"email": "andreevamariya.1979@postgrespro.ru", "phone": "+70897475121"}
0005434023303	B0E116	3335 126251	MARIYA VOLKOVA	{"phone": "+70189480907"}
0005434023304	E48007	3762 698185	ELENA EGOROVA	{"email": "egorova-e_031973@postgrespro.ru", "phone": "+70605670840"}
0005434023305	B1F8A2	5094 058122	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov.17111978@postgrespro.ru", "phone": "+70276898579"}
0005434023306	B1F8A2	7315 717801	TATYANA KALININA	{"email": "t-kalinina_051972@postgrespro.ru", "phone": "+70573646183"}
0005434023307	C670B3	6910 607859	LYUBOV TROFIMOVA	{"phone": "+70096316867"}
0005434023308	C670B3	5068 187003	LYUDMILA EFIMOVA	{"email": "efimova-lyudmila_1983@postgrespro.ru", "phone": "+70187191879"}
0005434023309	087660	9758 631119	TATYANA TARASOVA	{"email": "tatyana.tarasova-031980@postgrespro.ru", "phone": "+70456728823"}
0005434023310	087660	7975 221680	YURIY NIKITIN	{"phone": "+70519910774"}
0005434023311	DDA024	8293 903317	VENIAMIN MAKAROV	{"email": "vmakarov1989@postgrespro.ru", "phone": "+70391211621"}
0005434023312	F1AF75	9600 551397	PAVEL ZAYCEV	{"phone": "+70756798322"}
0005434023313	290324	5810 489583	LYUBOV VLASOVA	{"email": "vlasova-l_10081975@postgrespro.ru", "phone": "+70689246232"}
0005434023314	2CC7B4	7647 990586	ALISA FADEEVA	{"email": "fadeevaalisa_061970@postgrespro.ru", "phone": "+70038067344"}
0005434023315	2CC7B4	1469 890798	PAVEL KONOVALOV	{"email": "konovalov.pavel.021973@postgrespro.ru", "phone": "+70817467737"}
0005434023316	2CC7B4	6519 347507	LIDIYA SERGEEVA	{"phone": "+70980745780"}
0005434023317	A177D9	8081 520460	OLGA IVANOVA	{"email": "ivanova-olga1964@postgrespro.ru", "phone": "+70771176165"}
0005434023318	1A0EF3	1995 793381	ALEKSANDR PETROV	{"phone": "+70131234629"}
0005434023319	0C7080	8009 713326	TAMARA SERGEEVA	{"phone": "+70233648231"}
0005434023320	0C7080	5590 806376	MARIYA EFREMOVA	{"email": "efremova_mariya.1972@postgrespro.ru", "phone": "+70603043428"}
0005434023321	2D318F	8001 252250	VYACHESLAV KAZAKOV	{"email": "vyacheslav.kazakov-1979@postgrespro.ru", "phone": "+70795804192"}
0005434023322	92395A	9667 250558	VLADIMIR BORISOV	{"phone": "+70693899995"}
0005434023323	3F2629	1695 045828	ALEKSEY NIKITIN	{"email": "nikitin.aleksey_30111963@postgrespro.ru", "phone": "+70368424308"}
0005434023324	5DB687	0996 454772	SERGEY SOLOVEV	{"email": "s.solovev_041964@postgrespro.ru", "phone": "+70772550917"}
0005434023325	D29240	8505 974454	ROMAN PAVLOV	{"email": "r-pavlov1976@postgrespro.ru", "phone": "+70823535046"}
0005434023326	62C630	5774 396003	ELINA FILATOVA	{"email": "filatova-elina071975@postgrespro.ru", "phone": "+70351279342"}
0005434023327	27919F	2337 546592	SERGEY PETROV	{"phone": "+70696754356"}
0005434023328	4BF1F0	3651 744540	LIDIYA KOMAROVA	{"phone": "+70642993911"}
0005434023329	A4FC03	3225 964315	EVDOKIYA ANTONOVA	{"email": "e_antonova-121972@postgrespro.ru", "phone": "+70347891515"}
0005434023330	A4FC03	1446 359110	SVETLANA PETROVA	{"phone": "+70008316271"}
0005434023331	76E979	8478 228125	ANNA SMIRNOVA	{"email": "a_smirnova17101967@postgrespro.ru", "phone": "+70770108830"}
0005434023332	52B6C9	4725 404749	YULIYA ZOTOVA	{"email": "zotovay_081980@postgrespro.ru", "phone": "+70048676102"}
0005434023333	52B6C9	2185 368265	RAFAIL GERASIMOV	{"phone": "+70527823259"}
0005434023334	D1D35A	3166 930371	LILIYA KUZNECOVA	{"phone": "+70824907859"}
0005434023335	D1D35A	3120 124440	VLADIMIR KOZLOV	{"phone": "+70351912433"}
0005434023336	2BC4FA	7176 498041	LYUDMILA GORBUNOVA	{"email": "l.gorbunova_04091975@postgrespro.ru", "phone": "+70785586106"}
0005434023337	D09ADC	5948 277514	NELLI SOLOVEVA	{"phone": "+70088160819"}
0005434023338	E92A26	3475 752010	GALINA SEMENOVA	{"phone": "+70320340557"}
0005434023339	58A931	0694 290937	RAISA GAVRILOVA	{"email": "r_gavrilova-011974@postgrespro.ru", "phone": "+70168923103"}
0005434023340	58A931	5355 802039	VIKTOR POPOV	{"phone": "+70006202188"}
0005434023341	146310	1047 518673	ANATOLIY SCHERBAKOV	{"email": "scherbakovanatoliy-04081977@postgrespro.ru", "phone": "+70177074303"}
0005434023342	EBE803	6574 236346	SERGEY BELOV	{"phone": "+70262333656"}
0005434023343	EBE803	1906 999714	OLESYA LOGINOVA	{"phone": "+70296816115"}
0005434023344	DD8953	3690 474992	MAKSIM KUZMIN	{"email": "m_kuzmin_1963@postgrespro.ru", "phone": "+70687697132"}
0005434023345	620132	6580 966944	VITALIY ANTONOV	{"phone": "+70618024435"}
0005434023346	F9DCDB	4357 445708	ALEKSANDR ABRAMOV	{"phone": "+70661360638"}
0005434023347	F9DCDB	3910 625316	EKATERINA SOKOLOVA	{"phone": "+70518338746"}
0005434023348	F9DCDB	7079 786031	GENNADIY NAUMOV	{"phone": "+70521365671"}
0005434023349	4B8D28	4778 106381	VALENTINA MIRONOVA	{"email": "mironova_v.28111971@postgrespro.ru", "phone": "+70619718772"}
0005434023350	B27E2A	4532 981425	ALEKSANDR GRIGOREV	{"email": "grigorev-aleksandr29081969@postgrespro.ru", "phone": "+70975006004"}
0005434023351	90938D	5398 719556	LYUBOV CHERNOVA	{"email": "lyubov-chernova.1968@postgrespro.ru", "phone": "+70249573595"}
0005434023352	17D13C	4159 958248	ANNA EGOROVA	{"phone": "+70265569368"}
0005434023353	17D13C	5077 525320	NINA ZHUKOVA	{"email": "n_zhukova02041974@postgrespro.ru", "phone": "+70560288364"}
0005434023354	E6EEC3	7836 888924	OLGA TIKHONOVA	{"phone": "+70608821285"}
0005434023355	453902	3613 561666	AYRAT BONDARENKO	{"phone": "+70337641942"}
0005434023356	12FAE2	2440 504276	ALINA SERGEEVA	{"phone": "+70823624104"}
0005434023357	54FE51	9924 765800	EGOR ZHUKOV	{"email": "zhukov-egor04061983@postgrespro.ru", "phone": "+70987251552"}
0005434023358	3E8224	4151 644456	DARYA VLASOVA	{"phone": "+70398764911"}
0005434023359	BF463D	2747 344819	NIKOLAY MEDVEDEV	{"phone": "+70232470061"}
0005434023360	BF463D	9372 522798	ALINA VOLKOVA	{"phone": "+70278561431"}
0005434023361	7451CF	7849 940946	ALEKSANDR ANTONOV	{"phone": "+70624393066"}
0005434023362	2879A3	3668 327207	ALEKSEY MIRONOV	{"phone": "+70989368400"}
0005434023363	2879A3	1631 204743	ARINA MIKHAYLOVA	{"email": "mikhaylova-a1958@postgrespro.ru", "phone": "+70060112708"}
0005434023364	C00EBF	9267 788315	NATALIYA DANILOVA	{"phone": "+70428064125"}
0005434023365	A6DBAB	5026 405172	NATALYA KUDRYASHOVA	{"phone": "+70190975251"}
0005434023366	A6DBAB	4345 833243	LIDIYA STEPANOVA	{"email": "stepanova_lidiya031974@postgrespro.ru", "phone": "+70528686662"}
0005434023367	A6DBAB	5171 471532	VLADIMIR MIRONOV	{"email": "vladimir.mironov_091964@postgrespro.ru", "phone": "+70346094639"}
0005434023368	3CE594	4737 650743	SERGEY NIKITIN	{"phone": "+70213785112"}
0005434023369	3CE594	1995 092436	ALEKSANDR FROLOV	{"phone": "+70547352144"}
0005434023370	2A70B3	5816 997635	VERONIKA PETROVA	{"email": "veronika_petrova1977@postgrespro.ru", "phone": "+70497318046"}
0005434023371	2A70B3	5404 913995	VASILIY SCHERBAKOV	{"phone": "+70115809745"}
0005434023372	87EFF1	9876 803920	LYUBOV DENISOVA	{"phone": "+70719274454"}
0005434023373	9AE109	3376 496434	GALINA KUDRYASHOVA	{"phone": "+70968119940"}
0005434023374	9AE109	4353 946684	SERGEY SIDOROV	{"phone": "+70443608555"}
0005434023375	D74646	6961 826632	MIKHAIL PETROV	{"phone": "+70824251287"}
0005434023376	D74646	7570 605612	TATYANA ALEKSANDROVA	{"email": "aleksandrova.tatyana24031971@postgrespro.ru", "phone": "+70002815795"}
0005434023377	CD845A	4572 869585	ALISA FEDOROVA	{"phone": "+70449418063"}
0005434023378	B0E94B	9442 186231	SERGEY KUDRYASHOV	{"phone": "+70920386124"}
0005434023379	F4DAA1	3333 901697	LILIYA POLYAKOVA	{"email": "liliya_polyakova-1980@postgrespro.ru", "phone": "+70780447653"}
0005434023380	18F82C	3615 289960	VERA KAZAKOVA	{"phone": "+70103422356"}
0005434023381	05D19A	1215 194742	OLGA FOMINA	{"email": "olga-fomina1966@postgrespro.ru", "phone": "+70149652351"}
0005434023382	FC8E87	0195 342299	EVGENIY VOLKOV	{"email": "volkov-e-1979@postgrespro.ru", "phone": "+70927053896"}
0005434023383	FC8E87	1187 403547	IRINA POPOVA	{"email": "irinapopova.22021976@postgrespro.ru", "phone": "+70107906561"}
0005434023384	915FA3	5194 865083	ANNA NIKOLAEVA	{"phone": "+70844638704"}
0005434023385	915FA3	7456 941040	IVAN IVANOV	{"phone": "+70807599784"}
0005434023386	D06F28	2287 779575	NATALYA ILINA	{"email": "natalya-ilina-111969@postgrespro.ru", "phone": "+70030173281"}
0005434023387	7C4564	1647 129682	ALEKSANDR KUZNECOV	{"email": "kuznecova071974@postgrespro.ru", "phone": "+70612705291"}
0005434023388	C23576	3571 596360	DANIIL FILIPPOV	{"email": "filippovdaniil.23061975@postgrespro.ru", "phone": "+70361405134"}
0005434023389	D24484	9225 096669	ALEKSANDR STEPANOV	{"phone": "+70935134026"}
0005434023390	D24484	6664 364175	FEDOR BONDARENKO	{"phone": "+70449659936"}
0005434023391	8D5D53	3298 943338	ALINA LOGINOVA	{"phone": "+70028641963"}
0005434023392	BBB266	5688 313967	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_061963@postgrespro.ru", "phone": "+70231989731"}
0005434023393	6F117A	2111 698359	VLADIMIR TIKHONOV	{"phone": "+70344540839"}
0005434023394	C6A075	6703 656199	GALINA ROMANOVA	{"email": "galina.romanova_02081963@postgrespro.ru", "phone": "+70278976004"}
0005434023395	C6A075	8840 413688	GRIGORIY BONDARENKO	{"email": "bondarenkogrigoriy-031975@postgrespro.ru", "phone": "+70075885221"}
0005434023396	3A7AED	2255 538527	MARIYA AFANASEVA	{"phone": "+70868657102"}
0005434023397	3A7AED	6021 162563	VERA BARANOVA	{"phone": "+70498089059"}
0005434023398	80D6A2	2729 046311	MARIYA MIKHAYLOVA	{"phone": "+70419461679"}
0005434023399	80D6A2	8274 616704	DARYA KUZNECOVA	{"phone": "+70391212651"}
0005434023400	BE7B8A	1942 660024	DMITRIY TARASOV	{"phone": "+70051335869"}
0005434023401	BE7B8A	9382 451543	ANDREY IVANOV	{"phone": "+70179736170"}
0005434023402	E174C4	3620 560653	MAKSIM NIKOLAEV	{"email": "m-nikolaev-1983@postgrespro.ru", "phone": "+70901820178"}
0005434023403	56D563	6784 509944	MARIYA POLYAKOVA	{"phone": "+70511299580"}
0005434023404	9409D3	0934 066202	NIKOLAY ANDREEV	{"email": "andreev_nikolay.121969@postgrespro.ru", "phone": "+70280648913"}
0005434023405	693A1C	5299 551405	VYACHESLAV SOKOLOV	{"phone": "+70416058122"}
0005434023406	693A1C	0274 403867	MARINA ZAYCEVA	{"email": "zaycevam.11051976@postgrespro.ru", "phone": "+70649779280"}
0005434023407	693A1C	5551 195130	ALEKSEY POPOV	{"email": "popova_051975@postgrespro.ru", "phone": "+70258686732"}
0005434023408	666782	4666 812228	KSENIYA SOKOLOVA	{"phone": "+70058966301"}
0005434023409	3DBF92	6709 595211	DMITRIY FEDOROV	{"email": "dmitriyfedorov031975@postgrespro.ru", "phone": "+70988066285"}
0005434023410	3DBF92	7475 251887	SERGEY SERGEEV	{"email": "ssergeev_1963@postgrespro.ru", "phone": "+70642096611"}
0005434023411	7D3EEB	8839 240291	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy_28061974@postgrespro.ru", "phone": "+70563833852"}
0005434023412	33D71D	9711 318855	ANNA ANDREEVA	{"email": "andreeva_anna.1969@postgrespro.ru", "phone": "+70571810146"}
0005434023413	F7828F	7113 041355	TATYANA AFANASEVA	{"email": "tatyana_afanaseva-1978@postgrespro.ru", "phone": "+70155538816"}
0005434023414	87DF96	8751 191881	ALEKSANDRA ROMANOVA	{"phone": "+70228345957"}
0005434023415	3F95F2	6691 834875	NINA MOROZOVA	{"email": "n.morozova1971@postgrespro.ru", "phone": "+70754949952"}
0005434023526	953A04	0141 288741	YAROSLAV GUSEV	{"phone": "+70785318612"}
0005434023416	BE6D6F	9848 544358	RUSLAN ZAKHAROV	{"email": "zakharovr_121978@postgrespro.ru", "phone": "+70083715521"}
0005434023417	E07DB8	8166 796357	VALENTINA AFANASEVA	{"email": "valentina_afanaseva-1964@postgrespro.ru", "phone": "+70124942235"}
0005434023418	E07DB8	6426 711936	ALEKSANDR ABRAMOV	{"phone": "+70729826908"}
0005434023419	D89193	8071 634399	VALENTINA KUZNECOVA	{"email": "v.kuznecova-031981@postgrespro.ru", "phone": "+70243699052"}
0005434023420	6C50F6	5067 999888	SERGEY NIKITIN	{"phone": "+70727542655"}
0005434023421	6C50F6	6669 529230	KLARA POPOVA	{"phone": "+70583087061"}
0005434023422	97555F	4108 511838	POLINA DMITRIEVA	{"email": "dmitrieva_polina_03081980@postgrespro.ru", "phone": "+70957498228"}
0005434023423	FD1ECE	5954 145875	ULYANA KUZNECOVA	{"email": "ulyana-kuznecova-04071990@postgrespro.ru", "phone": "+70955420199"}
0005434023424	87B2E0	1152 471904	DMITRIY MIRONOV	{"email": "dmitriy.mironov-1980@postgrespro.ru", "phone": "+70065713203"}
0005434023425	EC60BA	3655 963100	ELENA PAVLOVA	{"phone": "+70234332391"}
0005434023426	EC60BA	8792 914397	VLADIMIR PAVLOV	{"email": "pavlovvladimir1963@postgrespro.ru", "phone": "+70341325293"}
0005434023427	29D662	3810 829146	SEMEN ZHURAVLEV	{"phone": "+70743927456"}
0005434023428	41052E	2476 726811	ANDREY FEDOTOV	{"email": "fedotova.101964@postgrespro.ru", "phone": "+70001445702"}
0005434023429	2A9E1D	1035 104471	VLADISLAV VOLKOV	{"phone": "+70275703150"}
0005434023430	85A011	4395 266403	ALEKSANDR SAVELEV	{"phone": "+70530759887"}
0005434023431	85A011	3024 661370	NINA GAVRILOVA	{"email": "ngavrilova1972@postgrespro.ru", "phone": "+70327465863"}
0005434023432	E88850	3080 902920	ALEKSANDR SHEVCHENKO	{"phone": "+70362756143"}
0005434023433	E6F050	0452 302516	TATYANA KUZMINA	{"email": "kuzmina-t.021977@postgrespro.ru", "phone": "+70274448902"}
0005434023434	E6F050	6950 549756	TAMARA SERGEEVA	{"phone": "+70021123550"}
0005434023435	0575BF	5839 968602	EVGENIY STEPANOV	{"email": "evgeniy_stepanov.121970@postgrespro.ru", "phone": "+70258189052"}
0005434023436	5F76E3	3957 113802	ALEKSANDR DAVYDOV	{"phone": "+70006024132"}
0005434023437	5F76E3	0317 922845	OLGA ANTONOVA	{"email": "o-antonova-111971@postgrespro.ru", "phone": "+70276769162"}
0005434023438	ED73E2	2907 029662	VASILISA SAVELEVA	{"phone": "+70657521295"}
0005434023439	ED73E2	2306 530306	ILYA DAVYDOV	{"email": "davydov-i.021973@postgrespro.ru", "phone": "+70033245139"}
0005434023440	7EF796	9669 036153	LYUDMILA STEPANOVA	{"email": "l_stepanova_23071969@postgrespro.ru", "phone": "+70680277859"}
0005434023441	98E57A	0123 749665	NADEZHDA ROMANOVA	{"phone": "+70514610283"}
0005434023442	696DCC	7416 919080	ALEKSANDR MATVEEV	{"email": "a-matveev.031975@postgrespro.ru", "phone": "+70253191844"}
0005434023443	696DCC	0009 873402	DMITRIY IVANOV	{"email": "ivanov.d_071967@postgrespro.ru", "phone": "+70120755295"}
0005434023444	318FCF	4420 087824	ELENA STEPANOVA	{"email": "stepanova.elena-1964@postgrespro.ru", "phone": "+70209101830"}
0005434023445	449EAE	7430 838465	VALERIY MAKAROV	{"phone": "+70773811802"}
0005434023446	702005	7900 861008	SVETLANA SOROKINA	{"email": "svetlana-sorokina1973@postgrespro.ru", "phone": "+70953580573"}
0005434023447	DC6A75	0279 253407	ALBERT STEPANOV	{"email": "albert-stepanov041973@postgrespro.ru", "phone": "+70387364238"}
0005434023448	39CE93	2047 954255	SERGEY VASILEV	{"phone": "+70168012520"}
0005434023449	D346CB	0690 901107	ALEKSANDR FEDOTOV	{"phone": "+70256085407"}
0005434023450	46D5BE	4651 905749	OKSANA SERGEEVA	{"email": "sergeevaoksana.1967@postgrespro.ru", "phone": "+70745123295"}
0005434023451	46D5BE	2240 060466	RAVIL GAVRILOV	{"phone": "+70030361255"}
0005434023452	20F63A	2484 457808	OLGA KUZNECOVA	{"phone": "+70110705343"}
0005434023453	F74876	8605 165482	VALERIY ZHUKOV	{"phone": "+70916891999"}
0005434023454	07B710	4469 062533	VLADIMIR ANTONOV	{"email": "v_antonov1975@postgrespro.ru", "phone": "+70838113809"}
0005434023455	1D3495	7070 928213	ROMAN SOROKIN	{"email": "r.sorokin1970@postgrespro.ru", "phone": "+70100930693"}
0005434023456	1D3495	0844 236610	LYUDMILA ISAEVA	{"email": "isaeval.051971@postgrespro.ru", "phone": "+70783856419"}
0005434023457	7411D3	1716 158694	SERGEY ALEKSANDROV	{"email": "aleksandrov_s_25051977@postgrespro.ru", "phone": "+70459568892"}
0005434023458	7411D3	6888 500630	OLESYA GERASIMOVA	{"email": "gerasimova_olesya-011971@postgrespro.ru", "phone": "+70419019870"}
0005434023459	3F0281	5692 239218	YULIYA TIKHONOVA	{"email": "yuliya_tikhonova_17071962@postgrespro.ru", "phone": "+70355586666"}
0005434023460	3F0281	2528 851951	DANIL NIKOLAEV	{"email": "danilnikolaev041976@postgrespro.ru", "phone": "+70717392301"}
0005434023461	45B788	3783 914209	VYACHESLAV PAVLOV	{"email": "v_pavlov_14011978@postgrespro.ru", "phone": "+70346514120"}
0005434023462	E96137	1032 991190	VALERIY MIRONOV	{"phone": "+70730801464"}
0005434023463	E96137	5333 077527	SERGEY VOROBEV	{"phone": "+70258056319"}
0005434023464	B5F723	5976 172366	ANGELINA KALININA	{"phone": "+70529317805"}
0005434023465	B5F723	8881 866242	VASILIY POPOV	{"email": "popov_vasiliy25121959@postgrespro.ru", "phone": "+70933784850"}
0005434023466	9B4A3D	2054 654216	NINA SMIRNOVA	{"phone": "+70586482965"}
0005434023467	F032F5	5073 996717	SERGEY TIKHONOV	{"email": "tikhonovsergey101969@postgrespro.ru", "phone": "+70147455320"}
0005434023468	03C482	9676 631081	MIKHAIL MAKSIMOV	{"phone": "+70193813329"}
0005434023469	1D3D66	0510 872367	ELENA VASILEVA	{"email": "e_vasileva1978@postgrespro.ru", "phone": "+70211593152"}
0005434023470	1D3D66	7483 122177	LYUBOV VOLKOVA	{"email": "volkova.lyubov-1987@postgrespro.ru", "phone": "+70497489897"}
0005434023471	1E2E62	2802 575464	KSENIYA DENISOVA	{"email": "denisova.k-1962@postgrespro.ru", "phone": "+70661912414"}
0005434023472	1C653F	9703 140265	VITALIY SOROKIN	{"phone": "+70798262507"}
0005434023473	1C653F	2944 584367	ELENA NOVIKOVA	{"email": "enovikova27051974@postgrespro.ru", "phone": "+70394472378"}
0005434023474	83467B	9794 678338	GRIGORIY AFANASEV	{"email": "afanasev_grigoriy_041981@postgrespro.ru", "phone": "+70005663051"}
0005434023475	386088	1663 894428	VLADIMIR VOLKOV	{"email": "volkov_v-101973@postgrespro.ru", "phone": "+70591482750"}
0005434023476	3BCF14	2778 970874	VASILIY MOROZOV	{"email": "vasiliy.morozov_08041962@postgrespro.ru", "phone": "+70992747094"}
0005434023477	BDEB4C	5134 875801	MIKHAIL FEDOROV	{"phone": "+70146081412"}
0005434023478	BDEB4C	1208 503803	NATALYA ZAKHAROVA	{"email": "zakharovanatalya081979@postgrespro.ru", "phone": "+70795673029"}
0005434023479	AA9BC8	8417 794364	ALEKSANDR ZAKHAROV	{"email": "azakharov.04031967@postgrespro.ru", "phone": "+70796168494"}
0005434023480	AA9BC8	6181 179041	MARINA RYABOVA	{"email": "ryabovam-101974@postgrespro.ru", "phone": "+70051246989"}
0005434023481	1E156D	2023 365219	SERGEY MIKHAYLOV	{"email": "smikhaylov.051968@postgrespro.ru", "phone": "+70526275425"}
0005434023482	507580	5535 721185	YULIYA KRASNOVA	{"email": "krasnova_y.1974@postgrespro.ru", "phone": "+70104401536"}
0005434023483	3CACB0	3161 083616	NATALYA ROMANOVA	{"phone": "+70883410943"}
0005434023484	3CACB0	3686 384670	BORIS ABRAMOV	{"email": "abramov.boris_1975@postgrespro.ru", "phone": "+70332701959"}
0005434023485	3CACB0	9857 007460	ELENA FILATOVA	{"email": "filatovae1977@postgrespro.ru", "phone": "+70710221730"}
0005434023486	2C9274	0961 957741	ANASTASIYA EGOROVA	{"email": "egorova.a111967@postgrespro.ru", "phone": "+70587520221"}
0005434023487	2649AA	4794 750468	ALEKSANDR BELOV	{"email": "a-belov_041979@postgrespro.ru", "phone": "+70766518657"}
0005434023488	2649AA	5589 065788	OLGA SEMENOVA	{"email": "semenova.o_1965@postgrespro.ru", "phone": "+70964265008"}
0005434023489	F29F1A	8251 952819	KONSTANTIN DMITRIEV	{"phone": "+70404624960"}
0005434023490	F29F1A	4196 121438	NATALIYA KOROLEVA	{"phone": "+70737158315"}
0005434023491	5F15D2	3918 978254	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin.1973@postgrespro.ru", "phone": "+70880947771"}
0005434023492	5F15D2	8339 245411	EVGENIY SMIRNOV	{"email": "smirnove12051986@postgrespro.ru", "phone": "+70898651919"}
0005434023493	482631	5556 640269	YURIY ROMANOV	{"email": "yuriyromanov_031974@postgrespro.ru", "phone": "+70888832219"}
0005434023494	482631	9085 744411	KRISTINA LOGINOVA	{"phone": "+70910328042"}
0005434023495	61E67E	9480 628820	VITALIY KONOVALOV	{"email": "vitaliy.konovalov_011984@postgrespro.ru", "phone": "+70842194895"}
0005434023496	61E67E	2567 832827	SERGEY SEMENOV	{"email": "semenov-sergey09081978@postgrespro.ru", "phone": "+70595195435"}
0005434023497	EA8A5B	1738 985278	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.02011970@postgrespro.ru", "phone": "+70037569626"}
0005434023498	D2D066	4030 976640	VLADIMIR PETROV	{"email": "vladimir.petrov-041970@postgrespro.ru", "phone": "+70713392704"}
0005434023499	D2D066	6966 309889	NATALYA DANILOVA	{"phone": "+70716832766"}
0005434023500	2C9F3A	9583 981589	MARIYA IVANOVA	{"email": "mivanova-1972@postgrespro.ru", "phone": "+70809811401"}
0005434023501	321587	3641 635772	SVETLANA ZAYCEVA	{"phone": "+70419150077"}
0005434023502	321587	6049 186649	VLADIMIR FEDOTOV	{"phone": "+70202479584"}
0005434023503	EB0CE9	1005 236168	GALINA KONOVALOVA	{"phone": "+70934335691"}
0005434023504	2DAFC2	1645 977007	SVETLANA NAZAROVA	{"email": "s.nazarova.22061964@postgrespro.ru", "phone": "+70340824652"}
0005434023505	2DAFC2	3462 836801	VIKTORIYA KUZMINA	{"email": "kuzminav.081967@postgrespro.ru", "phone": "+70452520801"}
0005434023506	77F9A6	6869 767750	LYUDMILA SOKOLOVA	{"email": "lsokolova18111967@postgrespro.ru", "phone": "+70609181529"}
0005434023507	77F9A6	5456 533308	GALINA KUZMINA	{"email": "kuzmina.galina-071982@postgrespro.ru", "phone": "+70349789996"}
0005434023508	F2C92D	8917 490898	ALEKSANDR ZHURAVLEV	{"phone": "+70596813880"}
0005434023509	8EAA59	4986 195889	TATYANA RODIONOVA	{"email": "t.rodionova.081971@postgrespro.ru", "phone": "+70108630206"}
0005434023510	1F10B6	2034 812773	VALENTINA NIKITINA	{"phone": "+70131273236"}
0005434023511	752B72	2056 524093	GENNADIY POPOV	{"email": "gpopov_1958@postgrespro.ru", "phone": "+70303757467"}
0005434023512	AFFE81	1475 470212	ALENA PETROVA	{"email": "alena-petrova-1971@postgrespro.ru", "phone": "+70433882907"}
0005434023513	CF6985	9560 931696	VLADISLAV ROMANOV	{"phone": "+70724792792"}
0005434023514	5120A1	2957 404489	NINA LUKYANOVA	{"email": "n-lukyanova-30041964@postgrespro.ru", "phone": "+70498168515"}
0005434023515	5120A1	6153 357477	VALENTINA MAKSIMOVA	{"phone": "+70775755555"}
0005434023516	95AC4F	0519 951907	YANA SOROKINA	{"phone": "+70617282758"}
0005434023517	95AC4F	4015 978511	YURIY VASILEV	{"phone": "+70251729135"}
0005434023518	95AC4F	3344 935282	EKATERINA IVANOVA	{"phone": "+70630982573"}
0005434023519	019372	7377 200504	OKSANA KOZLOVA	{"phone": "+70012906340"}
0005434023520	019372	4303 128059	RADIK NAZAROV	{"phone": "+70144336297"}
0005434023521	019372	7545 728631	NATALYA SERGEEVA	{"phone": "+70394312816"}
0005434023522	2E2283	9059 058783	ARTEM FEDOROV	{"phone": "+70322576714"}
0005434023523	2E2283	7072 539044	MAKSIM GUSEV	{"phone": "+70105074997"}
0005434023524	4A0FEB	5075 219951	OLEG ALEKSANDROV	{"phone": "+70467361478"}
0005434023525	68B6A4	6635 362701	IVAN OSIPOV	{"email": "osipov-ivan-071973@postgrespro.ru", "phone": "+70457303480"}
0005434023527	953A04	3025 988771	IGOR ROMANOV	{"email": "igor.romanov031971@postgrespro.ru", "phone": "+70327770762"}
0005434023528	84275F	6660 977503	ALEKSANDR STEPANOV	{"phone": "+70684843181"}
0005434023529	281022	0150 469362	NINA KUZMINA	{"email": "kuzmina-nina-1970@postgrespro.ru", "phone": "+70482424407"}
0005434023530	7236CA	4671 355590	ELENA AKIMOVA	{"phone": "+70447952674"}
0005434023531	FF1E0B	1622 623577	NATALYA KONDRATEVA	{"phone": "+70469302079"}
0005434023532	E966EC	1534 294552	ALEKSANDR ROMANOV	{"email": "a-romanov07021963@postgrespro.ru", "phone": "+70029965126"}
0005434023533	E966EC	7157 259756	NADEZHDA STEPANOVA	{"email": "stepanova-n_1966@postgrespro.ru", "phone": "+70025603895"}
0005434023534	E7FD58	6608 182628	LIDIYA STEPANOVA	{"email": "stepanova_l_1973@postgrespro.ru", "phone": "+70023295989"}
0005434023535	E7FD58	7430 375789	ALEKSANDR FOMIN	{"phone": "+70669919842"}
0005434023536	D887C4	7877 786852	MAKSIM NAUMOV	{"email": "naumovmaksim-09041958@postgrespro.ru", "phone": "+70330357575"}
0005434023537	D266D3	5080 465225	VIKTOR SEMENOV	{"phone": "+70471827130"}
0005434023538	84AAA1	6144 370378	NADEZHDA ANTONOVA	{"email": "antonova-nadezhda-06071977@postgrespro.ru", "phone": "+70395223713"}
0005434023539	491877	9801 106888	TATYANA IVANOVA	{"email": "ivanova.tatyana.16061977@postgrespro.ru", "phone": "+70302412563"}
0005434023540	4A7E36	9016 289470	VIKTORIYA KONOVALOVA	{"email": "viktoriyakonovalova.1975@postgrespro.ru", "phone": "+70675990607"}
0005434023541	A32FEE	8739 901968	ROMAN SEMENOV	{"email": "semenovr.1977@postgrespro.ru", "phone": "+70161610576"}
0005434023542	4F740D	6445 670609	EKATERINA KOROLEVA	{"phone": "+70703892680"}
0005434023543	28BDFC	9648 788372	ALEKSANDR SOROKIN	{"email": "asorokin-081965@postgrespro.ru", "phone": "+70860944806"}
0005434023544	BAEB55	2492 672858	VIKTOR SERGEEV	{"phone": "+70576153385"}
0005434023545	B69641	3862 558623	DARYA LOGINOVA	{"phone": "+70668105344"}
0005434023546	144F5F	1649 511136	SERGEY KISELEV	{"email": "s-kiselev121975@postgrespro.ru", "phone": "+70075840330"}
0005434023547	816079	9248 356883	GRIGORIY SMIRNOV	{"email": "grigoriy_smirnov.17111965@postgrespro.ru", "phone": "+70315729871"}
0005434023548	271B5E	8252 256388	NADEZHDA GAVRILOVA	{"email": "nadezhda-gavrilova_1978@postgrespro.ru", "phone": "+70066068426"}
0005434023549	271B5E	6748 004021	ANNA ANISIMOVA	{"email": "aanisimova-1972@postgrespro.ru", "phone": "+70078348913"}
0005434023550	46F1E9	3707 619927	VALENTINA POTAPOVA	{"email": "potapova_valentina-1969@postgrespro.ru", "phone": "+70995581728"}
0005434023551	A58F06	6983 072738	ANASTASIYA ROMANOVA	{"email": "romanova.a1984@postgrespro.ru", "phone": "+70880798252"}
0005434023552	796477	9859 606648	MARINA ZOTOVA	{"phone": "+70665661024"}
0005434023553	796477	0571 636086	NATALYA NESTEROVA	{"email": "nesterova-natalya-101969@postgrespro.ru", "phone": "+70555072832"}
0005434023554	ABE500	0661 114122	VERA ABRAMOVA	{"email": "vera-abramova08041969@postgrespro.ru", "phone": "+70060658241"}
0005434023555	212056	6759 751755	ALEKSANDR ISAEV	{"email": "aleksandrisaev_1974@postgrespro.ru", "phone": "+70695148777"}
0005434023556	687A41	3298 541242	SOFIYA LEBEDEVA	{"email": "sofiya-lebedeva071969@postgrespro.ru", "phone": "+70141268235"}
0005434023557	41B1B7	4648 932212	TATYANA KUZMINA	{"email": "t.kuzmina.1975@postgrespro.ru", "phone": "+70786569120"}
0005434023558	7CB68F	1212 038065	LYUDMILA NOVIKOVA	{"email": "lnovikova1963@postgrespro.ru", "phone": "+70586583279"}
0005434023559	1141BD	1256 090300	LYUBOV TIKHONOVA	{"email": "l_tikhonova.101967@postgrespro.ru", "phone": "+70027013529"}
0005434023560	29D970	7360 816583	GENNADIY SERGEEV	{"phone": "+70120702552"}
0005434023561	45D773	8276 507270	TATYANA BORISOVA	{"email": "borisova-t.23111975@postgrespro.ru", "phone": "+70416822131"}
0005434023562	2C3AFE	1233 530950	OLGA FROLOVA	{"email": "olga-frolova.1964@postgrespro.ru", "phone": "+70830111123"}
0005434023563	955215	7077 291529	ANDREY FEDOTOV	{"phone": "+70460099698"}
0005434023564	787242	8607 548788	VALERIY PETROV	{"phone": "+70285971400"}
0005434023565	C24F17	5706 969705	SVETLANA POPOVA	{"email": "popova-s02011970@postgrespro.ru", "phone": "+70663892730"}
0005434023566	63AD6D	4109 534398	PAVEL SOLOVEV	{"phone": "+70652566556"}
0005434023567	2E9DAF	6851 392498	NADEZHDA IVANOVA	{"email": "ivanova.n_041972@postgrespro.ru", "phone": "+70478722019"}
0005434023568	329978	1989 625882	MIKHAIL FEDOROV	{"phone": "+70062242044"}
0005434023569	329978	2089 398131	NIKOLAY PAVLOV	{"email": "nikolay.pavlov15101975@postgrespro.ru", "phone": "+70316606498"}
0005434023570	BE5D56	1032 374501	ANDREY TIMOFEEV	{"email": "timofeev_andrey-081966@postgrespro.ru", "phone": "+70151771849"}
0005434023571	78785E	2188 247030	ALEKSANDR TIMOFEEV	{"phone": "+70370262821"}
0005434023572	52C199	4316 004039	VIKTOR MAKAROV	{"phone": "+70962221339"}
0005434023573	24A93C	8449 303620	ALEKSANDR ZAKHAROV	{"phone": "+70636027425"}
0005434023574	24A93C	9021 824207	ALEKSEY BORISOV	{"phone": "+70839175277"}
0005434023575	9770FF	0686 346308	ALENA ZAKHAROVA	{"email": "zakharovaalena.1964@postgrespro.ru", "phone": "+70911233546"}
0005434023576	9770FF	4104 220192	ALEKSANDR ZHURAVLEV	{"phone": "+70415833774"}
0005434023577	994BC9	2009 255668	TATYANA VASILEVA	{"phone": "+70203815600"}
0005434023578	994BC9	4717 020451	RUSLAN SIDOROV	{"phone": "+70785573159"}
0005434023579	7A96BF	5909 112369	ALEKSANDR NAUMOV	{"phone": "+70703706247"}
0005434023580	DFBC98	5271 717398	EDUARD SHEVCHENKO	{"email": "shevchenkoe.08031972@postgrespro.ru", "phone": "+70512811618"}
0005434023581	24EC8F	6182 755652	SVETLANA NAZAROVA	{"phone": "+70181074383"}
0005434023582	C44CB5	7478 665053	ANTONINA CHERNOVA	{"phone": "+70020898636"}
0005434023583	C44CB5	2032 544922	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr_021975@postgrespro.ru", "phone": "+70666876816"}
0005434023584	C44CB5	6972 950412	VLADIMIR CHERNOV	{"email": "v_chernov.23041967@postgrespro.ru", "phone": "+70382093380"}
0005434023585	13C2F1	0615 698207	TATYANA KONOVALOVA	{"email": "konovalova_t-1969@postgrespro.ru", "phone": "+70496420734"}
0005434023586	34399D	4129 881201	VIKTOR BELOV	{"email": "viktor-belov.071971@postgrespro.ru", "phone": "+70284113755"}
0005434023587	803309	7947 138412	VERA LEBEDEVA	{"phone": "+70494684858"}
0005434023588	06E1A6	9546 755594	ALEKSEY DENISOV	{"phone": "+70292983344"}
0005434023589	06E1A6	1550 750955	OLGA IVANOVA	{"email": "o-ivanova.08071963@postgrespro.ru", "phone": "+70363258378"}
0005434023590	C86964	6560 723409	LADA ANTONOVA	{"phone": "+70100759546"}
0005434023591	C86964	9398 138260	ULYANA VOLKOVA	{"email": "ulyana-volkova.041970@postgrespro.ru", "phone": "+70664179003"}
0005434023592	C8256B	4839 891794	NATALYA EFIMOVA	{"email": "efimovan17051977@postgrespro.ru", "phone": "+70429761579"}
0005434023593	C8256B	3640 234492	NIKITA NAZAROV	{"phone": "+70734772426"}
0005434023594	05F523	9968 863987	ELENA CHERNOVA	{"email": "chernovae.021971@postgrespro.ru", "phone": "+70889780872"}
0005434023595	05F523	8583 277954	SERGEY TIKHONOV	{"phone": "+70685943297"}
0005434023596	DBDA15	7323 467145	IRINA RODIONOVA	{"phone": "+70351055328"}
0005434023597	B7F6A7	9642 691937	ALEVTINA MAKAROVA	{"phone": "+70089801435"}
0005434023598	818A7D	2067 708511	LYUBOV PETROVA	{"email": "petrova_l-10091970@postgrespro.ru", "phone": "+70691651150"}
0005434023599	818A7D	4195 493324	DMITRIY IVANOV	{"email": "dmitriy-ivanov_18111975@postgrespro.ru", "phone": "+70298322267"}
0005434023600	4C9316	5783 413164	PRASKOVYA KAZAKOVA	{"phone": "+70207331430"}
0005434023601	EDCB06	2652 078439	NATALYA ISAEVA	{"phone": "+70080670186"}
0005434023602	EDCB06	4463 294508	NIKOLAY MAKAROV	{"email": "nikolaymakarov_1965@postgrespro.ru", "phone": "+70419653764"}
0005434023603	49F657	9315 519438	VASILIY STEPANOV	{"email": "stepanov_vasiliy1970@postgrespro.ru", "phone": "+70122906292"}
0005434023604	14130F	3352 377477	LYUBOV KISELEVA	{"phone": "+70937726067"}
0005434023605	5C29F9	3377 608806	SERGEY ZHUKOV	{"email": "sergey.zhukov1973@postgrespro.ru", "phone": "+70925478868"}
0005434023606	A62981	5831 670058	EVGENIY AFANASEV	{"phone": "+70305950900"}
0005434023607	4822FE	4301 105044	IVAN ROMANOV	{"email": "romanovi-031971@postgrespro.ru", "phone": "+70994019296"}
0005434023608	4822FE	3110 722714	NADEZHDA VOLKOVA	{"phone": "+70490351185"}
0005434023609	47420C	0844 587656	NADEZHDA STEPANOVA	{"phone": "+70013361230"}
0005434023610	B9376A	7948 298590	NATALYA IVANOVA	{"email": "n.ivanova.071967@postgrespro.ru", "phone": "+70877537617"}
0005434023611	052E62	3541 450488	NADEZHDA YUDINA	{"phone": "+70443378414"}
0005434023612	052E62	4021 062523	NADEZHDA ZAYCEVA	{"email": "zayceva_n_1974@postgrespro.ru", "phone": "+70068720294"}
0005434023613	12585B	4771 763664	VALENTINA YUDINA	{"phone": "+70718615496"}
0005434023614	BD372B	2338 267112	ANDREY VLASOV	{"phone": "+70216915899"}
0005434023615	D98021	2536 799160	ANTONINA GUSEVA	{"phone": "+70753784817"}
0005434023616	6AED14	6851 396264	ELENA POPOVA	{"phone": "+70084056191"}
0005434023617	6AED14	6388 625693	ALEKSANDR DAVYDOV	{"phone": "+70491704122"}
0005434023618	279DB4	4389 651863	MARIYA NOVIKOVA	{"email": "mnovikova101965@postgrespro.ru", "phone": "+70175499614"}
0005434023619	CC6259	9913 890910	TATYANA RYABOVA	{"email": "tatyana_ryabova_05061968@postgrespro.ru", "phone": "+70517935145"}
0005434023620	0BADFD	5075 932643	ALEKSANDR KUZNECOV	{"phone": "+70490946176"}
0005434023621	093DE0	0566 450930	MARIYA MALYSHEVA	{"phone": "+70399617566"}
0005434023622	093DE0	7565 403892	KRISTINA SOKOLOVA	{"phone": "+70900577872"}
0005434023623	5707F2	7013 360549	FEDOR SEMENOV	{"email": "semenov_fedor16041973@postgrespro.ru", "phone": "+70615875080"}
0005434023624	70F937	7129 397508	ALEKSANDR ABRAMOV	{"phone": "+70028058798"}
0005434023625	221D4B	9780 124677	ARINA BORISOVA	{"email": "borisova.arina-28011966@postgrespro.ru", "phone": "+70601959989"}
0005434023626	38FB4C	9703 213828	ANTONINA TIMOFEEVA	{"phone": "+70661204522"}
0005434023627	38FB4C	9360 833853	ALEKSANDR FROLOV	{"phone": "+70822709697"}
0005434023628	3D190A	3025 680020	DMITRIY SERGEEV	{"phone": "+70813638275"}
0005434023629	1B02FF	4134 660106	YURIY MAKSIMOV	{"email": "yuriymaksimov.051956@postgrespro.ru", "phone": "+70681572142"}
0005434023630	5D61C9	4735 011212	KSENIYA KALININA	{"email": "kalinina_kseniya_01051971@postgrespro.ru", "phone": "+70478226328"}
0005434023631	5D61C9	3868 285713	PETR GRIGOREV	{"email": "grigorev.petr-121971@postgrespro.ru", "phone": "+70878441710"}
0005434023632	5D61C9	6220 855464	YULIYA SEMENOVA	{"email": "semenova-yuliya1976@postgrespro.ru", "phone": "+70388572648"}
0005434023633	4A60A2	9412 983740	NIKITA BORISOV	{"phone": "+70475906851"}
0005434023634	4A60A2	0363 132328	SERGEY STEPANOV	{"email": "sstepanov-031973@postgrespro.ru", "phone": "+70332108661"}
0005434023635	A7FF68	4455 797726	ANDREY BORISOV	{"phone": "+70165477510"}
0005434023636	A7FF68	6500 407856	VENERA ALEKSANDROVA	{"email": "veneraaleksandrova-29101977@postgrespro.ru", "phone": "+70697589626"}
0005434023637	196A11	4500 125293	SERGEY IVANOV	{"phone": "+70442152938"}
0005434023638	196A11	3626 430453	LYUDMILA FADEEVA	{"phone": "+70086590027"}
0005434023639	36E865	2699 915976	TAMARA NAZAROVA	{"email": "nazarova.tamara-1969@postgrespro.ru", "phone": "+70085734525"}
0005434023640	473A1F	2511 712622	ANTONINA ROMANOVA	{"phone": "+70625570770"}
0005434023641	473A1F	9725 726192	GALINA BORISOVA	{"email": "borisova.galina-1963@postgrespro.ru", "phone": "+70190719509"}
0005434023642	4C13A1	3067 463133	DMITRIY VOLKOV	{"phone": "+70120605168"}
0005434023643	4C13A1	7560 844859	ELENA MELNIKOVA	{"email": "melnikova.elena_1990@postgrespro.ru", "phone": "+70775770257"}
0005434023644	ED5037	6506 172355	POLINA NAZAROVA	{"phone": "+70118714452"}
0005434023645	ED5037	8852 333728	NADEZHDA EFREMOVA	{"phone": "+70775906476"}
0005434023646	F6563A	0504 278189	GULNAZ CHERNOVA	{"email": "chernovagulnaz_27101979@postgrespro.ru", "phone": "+70201072776"}
0005434023647	8047D0	1635 789957	OLGA KUZNECOVA	{"email": "kuznecovaolga-1970@postgrespro.ru", "phone": "+70490317443"}
0005434023648	8047D0	6372 610716	DMITRIY ZAYCEV	{"phone": "+70568316474"}
0005434023649	A948BC	3191 789113	BORIS MELNIKOV	{"phone": "+70747749313"}
0005434023650	68837E	6423 173037	MIKHAIL ALEKSANDROV	{"email": "m.aleksandrov_1985@postgrespro.ru", "phone": "+70126128367"}
0005434023651	56F35C	9784 024385	LYUBOV BORISOVA	{"email": "l_borisova.071982@postgrespro.ru", "phone": "+70156495646"}
0005434023652	56F35C	1048 565016	SERGEY SOKOLOV	{"phone": "+70929341069"}
0005434023653	56F35C	7236 951057	ALEKSANDR FROLOV	{"phone": "+70906772697"}
0005434023654	8CFE74	8971 953945	ANATOLIY ZHURAVLEV	{"phone": "+70428539231"}
0005434023655	8CFE74	8533 271741	VYACHESLAV POPOV	{"email": "popov_v_1979@postgrespro.ru", "phone": "+70162222303"}
0005434023656	C79438	6449 779146	ANGELINA SMIRNOVA	{"email": "smirnovaangelina-1972@postgrespro.ru", "phone": "+70829303978"}
0005434023657	C79438	3013 274599	NIKOLAY OSIPOV	{"email": "osipov-nikolay.051975@postgrespro.ru", "phone": "+70617143527"}
0005434023658	ABE072	7613 364162	VIKTOR ZAKHAROV	{"phone": "+70713378780"}
0005434023659	FEF90B	4838 465648	LYUDMILA PAVLOVA	{"phone": "+70809446125"}
0005434023660	DBC783	1968 451199	RAISA KOROLEVA	{"email": "r.koroleva_22071965@postgrespro.ru", "phone": "+70040224961"}
0005434023661	DBC783	0675 538841	NINA SOKOLOVA	{"phone": "+70537662433"}
0005434023662	DBC783	8962 199841	ANASTASIYA NIKOLAEVA	{"phone": "+70873061942"}
0005434023663	BB4129	2677 481755	MIKHAIL MOROZOV	{"phone": "+70620013192"}
0005434023664	5E33E9	3853 433105	VLADIMIR FEDOROV	{"phone": "+70363044904"}
0005434023665	5E33E9	0833 897872	TATYANA VOLKOVA	{"phone": "+70008288321"}
0005434023666	2A1912	6064 243548	MARGARITA SOKOLOVA	{"email": "m-sokolova.101969@postgrespro.ru", "phone": "+70977303297"}
0005434023667	2A1912	0519 698380	ANATOLIY KUZMIN	{"email": "a-kuzmin051974@postgrespro.ru", "phone": "+70500850332"}
0005434023668	2A1912	3954 543627	MAKSIM MEDVEDEV	{"phone": "+70339624795"}
0005434023669	526B4C	9769 221567	LIDIYA POPOVA	{"email": "popovalidiya_1970@postgrespro.ru", "phone": "+70523975100"}
0005434023670	16ABA4	9217 615972	MARIYA KUZNECOVA	{"email": "kuznecovamariya08081977@postgrespro.ru", "phone": "+70696796450"}
0005434023671	16ABA4	9514 002238	NATALYA KALININA	{"phone": "+70696048505"}
0005434023672	323C13	1364 499791	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov-26021964@postgrespro.ru", "phone": "+70353675431"}
0005434023673	34F744	8139 385984	NIKITA MARTYNOV	{"phone": "+70354555805"}
0005434023674	DB03AC	5495 960208	VALENTINA SEMENOVA	{"phone": "+70362796854"}
0005434023675	DB03AC	1584 128993	ELENA KOLESNIKOVA	{"email": "e_kolesnikova.09071980@postgrespro.ru", "phone": "+70325094876"}
0005434023676	7D5755	0480 433494	OLGA KUZMINA	{"email": "o-kuzmina01061977@postgrespro.ru", "phone": "+70282472667"}
0005434023677	DFB803	4857 512001	INGA KOROLEVA	{"email": "koroleva_i061972@postgrespro.ru", "phone": "+70701773048"}
0005434023678	DFB803	4980 590837	MARIYA ARKHIPOVA	{"email": "arkhipovamariya.01031972@postgrespro.ru", "phone": "+70606499210"}
0005434023679	DFB803	0973 638180	IVAN POPOV	{"email": "ivan.popov_1978@postgrespro.ru", "phone": "+70151379815"}
0005434023680	1AFF73	4053 588904	GULNARA SMIRNOVA	{"email": "gsmirnova1970@postgrespro.ru", "phone": "+70096424478"}
0005434023681	1AFF73	6292 849654	NIKOLAY SOKOLOV	{"email": "nikolay.sokolov_01101968@postgrespro.ru", "phone": "+70758030979"}
0005434023682	72CBB2	8768 137505	EGOR IVANOV	{"email": "e_ivanov-19031974@postgrespro.ru", "phone": "+70040333999"}
0005434023683	8310DA	7874 930212	ALSU SOLOVEVA	{"phone": "+70883166017"}
0005434023684	CE80BB	9390 864041	ANDREY ZAYCEV	{"email": "zaycev.a-091970@postgrespro.ru", "phone": "+70052722010"}
0005434023685	B302DA	6514 127483	RAISA ALEKSANDROVA	{"phone": "+70686094988"}
0005434023686	509765	1637 605115	NIKOLAY KUZNECOV	{"email": "kuznecov_n-1977@postgrespro.ru", "phone": "+70722760893"}
0005434023687	1698E0	9987 514544	ELENA KONOVALOVA	{"phone": "+70472100674"}
0005434023688	272105	3382 631283	ELENA AFANASEVA	{"phone": "+70668026614"}
0005434023689	24F117	6151 695994	MIKHAIL KUZNECOV	{"phone": "+70591444173"}
0005434023690	D8E875	3294 729567	LYUDMILA POLYAKOVA	{"email": "lpolyakova.05061974@postgrespro.ru", "phone": "+70730442247"}
0005434023691	36A981	4129 942491	IVAN SCHERBAKOV	{"email": "i.scherbakov.1965@postgrespro.ru", "phone": "+70186996481"}
0005434023692	6C52A1	7345 873261	NADEZHDA ROMANOVA	{"email": "nadezhda-romanova26021976@postgrespro.ru", "phone": "+70541533327"}
0005434023693	6C52A1	2417 280185	YURIY ALEKSEEV	{"email": "alekseev_y-1981@postgrespro.ru", "phone": "+70866471401"}
0005434023694	45E862	3277 182505	VLADIMIR MATVEEV	{"phone": "+70443225618"}
0005434023695	E9804B	6497 992398	GRIGORIY ZAYCEV	{"email": "zaycev.grigoriy_25101967@postgrespro.ru", "phone": "+70188465435"}
0005434023696	E9804B	2541 182647	NIKOLAY SOROKIN	{"email": "sorokinn-1980@postgrespro.ru", "phone": "+70420262952"}
0005434023697	E9804B	8939 462450	ALINA YUDINA	{"email": "yudina.alina-1967@postgrespro.ru", "phone": "+70813198216"}
0005434023698	9973A8	4095 666544	BORIS TARASOV	{"phone": "+70415266045"}
0005434023699	BE4C4A	8180 441859	MARINA PAVLOVA	{"phone": "+70156656749"}
0005434023700	77671B	3713 603070	VALENTINA KUZMINA	{"email": "kuzmina.valentina.28081964@postgrespro.ru", "phone": "+70439644774"}
0005434023701	77671B	5435 591957	DMITRIY NAZAROV	{"email": "dmitriy.nazarov_08081963@postgrespro.ru", "phone": "+70258465980"}
0005434023702	1C26C6	8021 529735	NATALYA ZAKHAROVA	{"email": "zakharova-natalya_06021980@postgrespro.ru", "phone": "+70152039283"}
0005434023703	63F0B0	5273 869810	YURIY VLASOV	{"phone": "+70126590274"}
0005434023704	00A165	6562 143846	NATALYA ANTONOVA	{"email": "antonova_natalya.081970@postgrespro.ru", "phone": "+70936560053"}
0005434023705	9B0B5D	2631 224354	ALENA NIKITINA	{"phone": "+70697724569"}
0005434023706	9B0B5D	2756 582433	ALEKSANDR AFANASEV	{"email": "aafanasev-021971@postgrespro.ru", "phone": "+70416631754"}
0005434023707	9B0B5D	0623 261701	SVETLANA VLASOVA	{"email": "vlasova_svetlana.31101977@postgrespro.ru", "phone": "+70993915283"}
0005434023708	9380A0	7266 862738	NINA BARANOVA	{"email": "nina-baranova.1982@postgrespro.ru", "phone": "+70722334406"}
0005434023709	E24315	3911 935296	ANATOLIY IVANOV	{"email": "a.ivanov.081964@postgrespro.ru", "phone": "+70873929820"}
0005434023710	E0A936	7240 513064	VASILIY MAKAROV	{"email": "vmakarov_011969@postgrespro.ru", "phone": "+70849996978"}
0005434023711	1669B5	0160 304187	SVETLANA EFIMOVA	{"email": "efimova_s.1968@postgrespro.ru", "phone": "+70640927111"}
0005434023712	F77442	0447 230339	SERGEY MOISEEV	{"phone": "+70506946048"}
0005434023713	806D48	2452 118447	SERGEY SOLOVEV	{"email": "solovev.sergey-021964@postgrespro.ru", "phone": "+70865416162"}
0005434023714	806D48	0735 842178	VIKTOR MAKSIMOV	{"phone": "+70197360259"}
0005434023715	2D561B	9916 482917	ZINAIDA ZAYCEVA	{"phone": "+70486005696"}
0005434023716	2D561B	2312 560928	VASILIY BELOV	{"email": "v_belov121973@postgrespro.ru", "phone": "+70226001984"}
0005434023717	3DEC4F	3796 096434	ELENA KALININA	{"email": "elenakalinina-1974@postgrespro.ru", "phone": "+70820342157"}
0005434023718	3DEC4F	0062 795746	OLGA ILINA	{"phone": "+70851018267"}
0005434023719	DDC789	5681 128280	MARIYA SMIRNOVA	{"phone": "+70096172221"}
0005434023720	DDC789	7138 582467	ELENA MATVEEVA	{"phone": "+70368844784"}
0005434023721	808569	0367 123384	ALEKSEY TIMOFEEV	{"phone": "+70780914524"}
0005434023722	7E9C12	5241 688580	VERA GUSEVA	{"email": "v_guseva.24041972@postgrespro.ru", "phone": "+70698589292"}
0005434023723	05BE84	9462 562915	NATALYA POPOVA	{"phone": "+70573723741"}
0005434023724	9F3637	8514 171050	GALINA MELNIKOVA	{"email": "galina_melnikova_1966@postgrespro.ru", "phone": "+70777130095"}
0005434023725	9F3637	8635 773534	PAVEL ALEKSANDROV	{"email": "pavel_aleksandrov.02081966@postgrespro.ru", "phone": "+70857202738"}
0005434023726	9F3637	7961 129199	NIKOLAY BARANOV	{"email": "nikolay-baranov.1975@postgrespro.ru", "phone": "+70274533315"}
0005434023727	7217DF	7320 184770	VLADA KOMAROVA	{"email": "vlada.komarova.24081981@postgrespro.ru", "phone": "+70322500785"}
0005434023728	A73F8F	3956 464979	SERGEY NOVIKOV	{"phone": "+70140694369"}
0005434023729	A73F8F	9520 750991	LYUDMILA KUZMINA	{"email": "kuzmina-l-1977@postgrespro.ru", "phone": "+70716947450"}
0005434023730	939F1A	3894 503255	ALEKSEY VOROBEV	{"email": "vorobev-aleksey_1974@postgrespro.ru", "phone": "+70432605225"}
0005434023731	939F1A	8138 806664	MAKSIM VASILEV	{"phone": "+70720731590"}
0005434023732	C2280D	4507 593834	DMITRIY ANDREEV	{"phone": "+70029162981"}
0005434023733	D8CF22	3977 662838	DANILA ZAYCEV	{"phone": "+70539384954"}
0005434023734	D8CF22	7697 683481	GALINA ROMANOVA	{"phone": "+70863599579"}
0005434023735	FEFF3B	7487 417482	MARINA EGOROVA	{"phone": "+70963662239"}
0005434023736	7FAD71	1348 916387	DENIS SAVELEV	{"email": "denis.savelev-28071969@postgrespro.ru", "phone": "+70517882334"}
0005434023737	7FAD71	0242 975903	DENIS ZAKHAROV	{"email": "zakharov-d_25081969@postgrespro.ru", "phone": "+70730517691"}
0005434023738	E7BC4D	0138 803467	SVETLANA KARPOVA	{"phone": "+70662220263"}
0005434023739	2144DE	4853 494912	ARTEM FILIPPOV	{"phone": "+70927284210"}
0005434023740	FB14BB	8907 776984	ALENA NESTEROVA	{"phone": "+70805105066"}
0005434023741	045101	4813 515842	SERGEY MARTYNOV	{"email": "sergey-martynov.091977@postgrespro.ru", "phone": "+70459546369"}
0005434023742	BD901B	8859 192112	IGOR MELNIKOV	{"email": "melnikovi.1972@postgrespro.ru", "phone": "+70995280730"}
0005434023743	C1D707	3168 271664	SERGEY MIRONOV	{"email": "s_mironov17051987@postgrespro.ru", "phone": "+70792783034"}
0005434023744	71846A	3094 824726	VIKTOR GAVRILOV	{"email": "v-gavrilov-021967@postgrespro.ru", "phone": "+70831951628"}
0005434023745	FCE8B0	4722 433125	IRINA DAVYDOVA	{"email": "irina-davydova.09051976@postgrespro.ru", "phone": "+70434516396"}
0005434023746	090065	9702 620178	ANASTASIYA KUZMINA	{"email": "a.kuzmina-28081967@postgrespro.ru", "phone": "+70028048504"}
0005434023747	090065	9575 907547	SERGEY POPOV	{"email": "popovsergey.18091970@postgrespro.ru", "phone": "+70019489636"}
0005434023748	3AB8ED	8378 926213	MARINA KALININA	{"phone": "+70953599798"}
0005434023749	3AB8ED	7167 133900	INNA BORISOVA	{"phone": "+70189897601"}
0005434023750	182CF2	0739 623933	IGOR KUZNECOV	{"email": "kuznecov-i-121960@postgrespro.ru", "phone": "+70011678939"}
0005434023751	182CF2	8400 967650	GEVORG VOLKOV	{"phone": "+70636514884"}
0005434023752	3B8D7C	4569 297786	DENIS GORBUNOV	{"phone": "+70678829257"}
0005434023753	1D83E0	5903 157001	NINA KUZNECOVA	{"email": "n-kuznecova.051973@postgrespro.ru", "phone": "+70788784171"}
0005434023754	2EA4E8	5303 567231	TATYANA KONOVALOVA	{"phone": "+70845000172"}
0005434023755	CCA564	8472 216345	VASILIY ALEKSEEV	{"phone": "+70846685647"}
0005434023756	B901C6	6135 061784	YULIYA GRISHINA	{"phone": "+70664560814"}
0005434023757	B901C6	5837 396514	MILENA TITOVA	{"phone": "+70635527657"}
0005434023758	C475E1	0994 449303	MAKSIM PETROV	{"phone": "+70312086066"}
0005434023759	174063	9434 370306	NATALYA VASILEVA	{"email": "vasileva.natalya-27021974@postgrespro.ru", "phone": "+70190507913"}
0005434023760	174063	9035 463744	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev_1973@postgrespro.ru", "phone": "+70582836577"}
0005434023761	B4D2F3	3287 745392	DMITRIY GUSEV	{"email": "d.gusev_27081976@postgrespro.ru", "phone": "+70808293126"}
0005434023762	1ED098	4404 532020	DENIS IVANOV	{"email": "d_ivanov_1979@postgrespro.ru", "phone": "+70931623253"}
0005434023763	F86BA9	4684 006649	LYUDMILA MAKSIMOVA	{"phone": "+70147547024"}
0005434023764	F86BA9	9802 689051	ANTONINA FROLOVA	{"phone": "+70718755184"}
0005434023765	111741	8022 007896	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova-a.28101982@postgrespro.ru", "phone": "+70927929521"}
0005434023766	111741	9504 822033	IRINA KUZNECOVA	{"email": "kuznecova.i03071967@postgrespro.ru", "phone": "+70508690578"}
0005434023767	7C5F7C	0049 288508	LILIYA LEBEDEVA	{"email": "lebedeva-liliya.04071968@postgrespro.ru", "phone": "+70480440066"}
0005434023768	CD9DF1	0993 317450	VALERIYA ZHURAVLEVA	{"email": "zhuravleva_valeriya.16031970@postgrespro.ru", "phone": "+70366236687"}
0005434023769	31D717	1050 653431	LYUDMILA ARKHIPOVA	{"phone": "+70640425664"}
0005434023770	017309	2417 921521	TATYANA STEPANOVA	{"phone": "+70500168796"}
0005434023771	017309	5953 184057	ANDREY NIKITIN	{"phone": "+70207625948"}
0005434023772	9C4971	9863 025396	NIKOLAY KUZNECOV	{"phone": "+70923221076"}
0005434023773	CFDC36	7568 276476	TATYANA EGOROVA	{"phone": "+70141762770"}
0005434023774	CFDC36	4228 903523	IRINA SOLOVEVA	{"email": "soloveva_i-1971@postgrespro.ru", "phone": "+70982466668"}
0005434023775	BC4CD1	3931 015793	MIKHAIL SCHERBAKOV	{"phone": "+70897193120"}
0005434023776	BC4CD1	4688 698060	ALEKSANDR DENISOV	{"email": "denisov_aleksandr-19071978@postgrespro.ru", "phone": "+70470305823"}
0005434023777	C52BD2	4356 738115	LYUDMILA ROMANOVA	{"email": "l_romanova1986@postgrespro.ru", "phone": "+70020489787"}
0005434023778	857335	1312 705359	ALEKSEY RODIONOV	{"phone": "+70231856027"}
0005434023779	BE92C1	4846 494382	VLADIMIR ALEKSEEV	{"email": "v-alekseev-29071975@postgrespro.ru", "phone": "+70141538683"}
0005434023780	BE92C1	1114 338246	VIKTOR IVANOV	{"phone": "+70533766724"}
0005434023781	A1F9F6	8979 236811	ALENA GRISHINA	{"email": "a_grishina_24101980@postgrespro.ru", "phone": "+70697171001"}
0005434023782	A1F9F6	5724 700258	DMITRIY SOLOVEV	{"email": "solovev.dmitriy-09051973@postgrespro.ru", "phone": "+70326217511"}
0005434023783	F46F9D	6954 788718	NADEZHDA FILIPPOVA	{"phone": "+70923427135"}
0005434023784	092620	1767 541414	LIDIYA KALININA	{"email": "kalinina_l1970@postgrespro.ru", "phone": "+70718345920"}
0005434023785	149EA2	9474 609692	VALENTINA NESTEROVA	{"email": "nesterova-valentina.13081970@postgrespro.ru", "phone": "+70400488461"}
0005434023786	149EA2	6709 678327	ANASTASIYA ZAKHAROVA	{"email": "anastasiya_zakharova.041974@postgrespro.ru", "phone": "+70501180442"}
0005434023787	181437	8378 503358	NADEZHDA KOZLOVA	{"email": "nadezhda.kozlova-12011968@postgrespro.ru", "phone": "+70558420744"}
0005434023788	19B610	9172 036678	VLADIMIR EGOROV	{"phone": "+70362792889"}
0005434023789	2FD21A	4098 900821	BORIS TARASOV	{"email": "boristarasov031975@postgrespro.ru", "phone": "+70521909106"}
0005434023790	2FD21A	9343 409742	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev08101977@postgrespro.ru", "phone": "+70882166453"}
0005434023791	B1C919	5082 149741	LYUBOV ALEKSEEVA	{"phone": "+70517712564"}
0005434023792	B1C919	8449 084835	MIKHAIL POPOV	{"email": "mikhail_popov.02111983@postgrespro.ru", "phone": "+70676714628"}
0005434023793	F070CD	3056 785107	DENIS KOZLOV	{"email": "kozlovdenis-1957@postgrespro.ru", "phone": "+70018588236"}
0005434023794	1DC7DA	7491 892136	KARINA EFIMOVA	{"email": "efimova_karina-11041980@postgrespro.ru", "phone": "+70047268820"}
0005434023795	3DC3D6	6356 248811	TATYANA VOLKOVA	{"email": "tatyana_volkova-23101983@postgrespro.ru", "phone": "+70940106748"}
0005434023796	529D50	3888 182237	YURIY SOKOLOV	{"email": "sokolov.y_1974@postgrespro.ru", "phone": "+70372311749"}
0005434023797	FAEF83	9089 001868	VERA SERGEEVA	{"email": "sergeevavera1975@postgrespro.ru", "phone": "+70209385215"}
0005434023798	13F73A	5120 200744	ANNA MEDVEDEVA	{"phone": "+70818818918"}
0005434023799	ED4C90	5184 926520	OLEG KULIKOV	{"email": "kulikov.oleg101977@postgrespro.ru", "phone": "+70989971286"}
0005434023800	ED4C90	0659 404587	SVETLANA SCHERBAKOVA	{"email": "scherbakova-svetlana011972@postgrespro.ru", "phone": "+70529934966"}
0005434023801	6C7B82	2810 334797	VIKTOR GORBUNOV	{"email": "gorbunovv-1969@postgrespro.ru", "phone": "+70814958041"}
0005434023802	E8CABF	3263 187098	MIKHAIL FILIPPOV	{"phone": "+70129676390"}
0005434023803	E8CABF	7277 732022	VIKTOR KOZLOV	{"phone": "+70223183563"}
0005434023804	B6FF65	1864 666532	VLADIMIR CHERNOV	{"email": "vladimir_chernov26101970@postgrespro.ru", "phone": "+70730343192"}
0005434023805	B6FF65	7934 076449	DENIS MAKSIMOV	{"email": "dmaksimov_1969@postgrespro.ru", "phone": "+70290936915"}
0005434023806	6790DE	0385 775311	EKATERINA TROFIMOVA	{"email": "ekaterina_trofimova.061978@postgrespro.ru", "phone": "+70582235780"}
0005434023807	88C72D	6463 278871	ELENA SIDOROVA	{"phone": "+70482160172"}
0005434023808	88C72D	1091 592963	ELENA NOVIKOVA	{"email": "novikova.elena101978@postgrespro.ru", "phone": "+70580214895"}
0005434023809	C73903	6454 410064	ALEKSEY VOLKOV	{"phone": "+70858767729"}
0005434023810	4C9036	0462 360471	PETR FEDOTOV	{"email": "p_fedotov1965@postgrespro.ru", "phone": "+70032506533"}
0005434023811	9F8B86	9816 869220	KSENIYA ABRAMOVA	{"email": "kseniya.abramova.09041977@postgrespro.ru", "phone": "+70311484595"}
0005434023812	9F8B86	6183 263890	SVETLANA KISELEVA	{"email": "skiseleva.01091969@postgrespro.ru", "phone": "+70217493994"}
0005434023813	9F8B86	6824 643097	KRISTINA KUZNECOVA	{"email": "kristina-kuznecova061968@postgrespro.ru", "phone": "+70928492017"}
0005434023814	3C209B	4278 355691	ANASTASIYA MIRONOVA	{"email": "anastasiya_mironova-1966@postgrespro.ru", "phone": "+70291830273"}
0005434023815	9FC2E5	5177 860200	VALENTINA VLASOVA	{"phone": "+70675189377"}
0005434023816	586A0A	0177 675209	YURIY ISAEV	{"phone": "+70542011350"}
0005434023817	49E515	6402 331694	ANDREY BONDARENKO	{"phone": "+70812613133"}
0005434023818	F65DC4	3630 260313	IRINA VOLKOVA	{"email": "volkova_irina-031971@postgrespro.ru", "phone": "+70799166086"}
0005434023819	EDBD0C	8359 102242	EVGENIY GAVRILOV	{"phone": "+70980507433"}
0005434023820	2B11AB	2880 883318	ANNA ANTONOVA	{"email": "anna.antonova.061984@postgrespro.ru", "phone": "+70963220446"}
0005434023821	22559C	2900 267198	SVETLANA ANDREEVA	{"phone": "+70013084273"}
0005434023822	B325DA	4191 437029	VIKTORIYA BARANOVA	{"phone": "+70134017820"}
0005434023823	B325DA	7623 313343	TATYANA SMIRNOVA	{"email": "tatyana-smirnova_061977@postgrespro.ru", "phone": "+70255442907"}
0005434023824	17B968	8545 026169	LEV STEPANOV	{"email": "lev-stepanov-07071974@postgrespro.ru", "phone": "+70824281316"}
0005434023825	17B968	9538 080697	ALEKSEY OSIPOV	{"phone": "+70319410760"}
0005434023826	A504E1	6604 868916	EGOR KAZAKOV	{"email": "egor_kazakov1975@postgrespro.ru", "phone": "+70148655193"}
0005434023827	B4478E	0791 093434	ELENA NOVIKOVA	{"phone": "+70522946197"}
0005434023828	B4478E	8262 870909	MIKHAIL SOKOLOV	{"phone": "+70181222440"}
0005434023829	05F301	5807 338341	OLGA MAKAROVA	{"phone": "+70001482568"}
0005434023830	9DF150	4169 429971	YURIY ZHURAVLEV	{"email": "zhuravlev-yuriy061966@postgrespro.ru", "phone": "+70359955333"}
0005434023831	70CAC4	3955 830217	OLGA KONOVALOVA	{"email": "o.konovalova-11011977@postgrespro.ru", "phone": "+70729977289"}
0005434023832	8C4EC7	6274 946761	SERAFIMA FEDOROVA	{"phone": "+70523806777"}
0005434023833	2DDB92	1833 573768	GENNADIY SMIRNOV	{"phone": "+70092103977"}
0005434023834	1E1DA0	9664 848707	TATYANA KOVALEVA	{"email": "tatyana.kovaleva_041967@postgrespro.ru", "phone": "+70862390101"}
0005434023835	599A92	7538 186176	ALEKSEY EGOROV	{"phone": "+70057264276"}
0005434023836	F44169	2573 926921	MARIYA KOROLEVA	{"email": "mariya-koroleva21031967@postgrespro.ru", "phone": "+70847604769"}
0005434023837	F44169	8503 412310	TATYANA TIMOFEEVA	{"phone": "+70617267740"}
0005434023838	A4C504	2532 419517	ANTON KOROLEV	{"phone": "+70126063328"}
0005434023839	A4C504	1470 952084	SERGEY SAVELEV	{"email": "s_savelev-1985@postgrespro.ru", "phone": "+70266527247"}
0005434023840	DCF4B6	0522 181144	NATALIYA MAKAROVA	{"phone": "+70217374812"}
0005434023841	4419E0	9903 653944	YURIY VOLKOV	{"phone": "+70700775593"}
0005434023842	4419E0	6650 304713	PAVEL PAVLOV	{"email": "pavelpavlov_14071974@postgrespro.ru", "phone": "+70604361015"}
0005434023843	9004B0	7529 150240	LYUDMILA VLASOVA	{"phone": "+70420603653"}
0005434023844	9004B0	6541 213403	NATALYA AFANASEVA	{"email": "natalya.afanaseva1985@postgrespro.ru", "phone": "+70333791218"}
0005434023845	A2777B	3673 915173	VLADIMIR GORBUNOV	{"phone": "+70793907696"}
0005434023846	A2777B	6318 179642	ANASTASIYA MIRONOVA	{"email": "anastasiya.mironova_23091974@postgrespro.ru", "phone": "+70762391082"}
0005434023847	9A6CBA	7303 752635	IRINA IVANOVA	{"phone": "+70465305870"}
0005434023848	9A6CBA	1843 072242	SOFIYA VOLKOVA	{"email": "volkova_sofiya_1980@postgrespro.ru", "phone": "+70580617473"}
0005434023849	9A6CBA	0359 538170	DARYA MAKAROVA	{"phone": "+70348068091"}
0005434023850	6C570E	8732 578359	VALENTINA SMIRNOVA	{"phone": "+70338717352"}
0005434023851	4F12A5	9356 824065	SERGEY GRIGOREV	{"email": "s_grigorev-091982@postgrespro.ru", "phone": "+70812566843"}
0005434023852	4F12A5	7448 905719	NINA MOROZOVA	{"phone": "+70894820810"}
0005434023853	4F12A5	9818 032151	YULIYA EGOROVA	{"email": "egorova_yuliya1974@postgrespro.ru", "phone": "+70030204188"}
0005434023854	65ABB6	8157 034073	MARINA ALEKSEEVA	{"email": "alekseevamarina29091961@postgrespro.ru", "phone": "+70627691448"}
0005434023855	DB7288	1948 880330	ALISA NESTEROVA	{"email": "nesterova_a-25071967@postgrespro.ru", "phone": "+70890875822"}
0005434023856	D2792C	9728 255487	VERONIKA KAZAKOVA	{"phone": "+70323102941"}
0005434023857	AF6B0F	8453 624045	PRASKOVYA LAZAREVA	{"email": "p.lazareva-17031960@postgrespro.ru", "phone": "+70652787112"}
0005434023858	9276CF	4829 316282	DARYA GUSEVA	{"phone": "+70345267680"}
0005434023859	F60FCE	6690 810342	ALEKSEY DENISOV	{"email": "a.denisov.10061974@postgrespro.ru", "phone": "+70316502948"}
0005434023860	F60FCE	1788 363106	ALLA NIKIFOROVA	{"email": "nikiforova.alla1984@postgrespro.ru", "phone": "+70033706415"}
0005434023861	E6B4B2	0621 473542	GALINA TIKHONOVA	{"phone": "+70809282150"}
0005434023862	E6B4B2	2808 323366	SVETLANA RYABOVA	{"phone": "+70299442982"}
0005434023863	DE785B	4360 175650	EKATERINA FROLOVA	{"email": "frolova_e.23071964@postgrespro.ru", "phone": "+70020728751"}
0005434023864	DE785B	4434 418524	LIDIYA ANISIMOVA	{"email": "l.anisimova31031982@postgrespro.ru", "phone": "+70210565405"}
0005434023865	263537	6681 563954	ZINAIDA SOROKINA	{"phone": "+70121911417"}
0005434023866	56D48A	4805 315927	GALINA PAVLOVA	{"phone": "+70848785032"}
0005434023867	8EF40A	6630 727136	DINARA KUZNECOVA	{"phone": "+70015231901"}
0005434023868	8EF40A	8330 660664	ZOYA MIKHAYLOVA	{"email": "zoya.mikhaylova_23081975@postgrespro.ru", "phone": "+70992326067"}
0005434023869	0B0B83	1825 400012	PETR BORISOV	{"phone": "+70157383588"}
0005434023870	7B670B	6200 986115	NATALYA LUKYANOVA	{"email": "natalya_lukyanova_21121975@postgrespro.ru", "phone": "+70584950647"}
0005434023871	B6113B	1294 160201	NINA KOZLOVA	{"phone": "+70191264739"}
0005434023872	D81144	1300 073303	TATYANA KUZMINA	{"email": "t.kuzmina-061975@postgrespro.ru", "phone": "+70780956511"}
0005434023873	A2AF00	0228 463150	MAKSIM PETROV	{"phone": "+70335547210"}
0005434023874	A7AE57	3086 879001	MARINA LEBEDEVA	{"phone": "+70741090598"}
0005434023875	2F8094	1918 119590	ANDREY SOLOVEV	{"phone": "+70495630070"}
0005434023876	0272A2	3051 741827	ALEKSANDR NIKOLAEV	{"phone": "+70713154623"}
0005434023877	0272A2	7437 829215	YURIY NOVIKOV	{"email": "y.novikov.02041972@postgrespro.ru", "phone": "+70676616237"}
0005434023878	FB62E2	8067 797151	EKATERINA BELYAEVA	{"email": "belyaeva_e_121985@postgrespro.ru", "phone": "+70482546607"}
0005434023879	FB62E2	1057 130150	IVAN NAZAROV	{"email": "nazarov-i12091975@postgrespro.ru", "phone": "+70381129600"}
0005434023880	ABAE04	4879 500265	VALERIY GRIGOREV	{"phone": "+70698531338"}
0005434023881	E21841	6084 666690	GALINA MIKHAYLOVA	{"phone": "+70822597247"}
0005434023882	E21841	6371 558757	ANTON FOMIN	{"phone": "+70747703513"}
0005434023883	368FF5	6548 831325	MARIYA SEMENOVA	{"email": "m_semenova-01081978@postgrespro.ru", "phone": "+70342769737"}
0005434023884	CCEA1C	0782 264922	FEDOR FEDOTOV	{"phone": "+70451308464"}
0005434023885	DBA982	0018 550815	ELENA CHERNOVA	{"email": "chernova_elena_24071970@postgrespro.ru", "phone": "+70448764018"}
0005434023886	DBA982	6531 878038	OLEG MAKSIMOV	{"phone": "+70118099003"}
0005434023887	B7817C	6149 367891	VALENTINA SOKOLOVA	{"phone": "+70300179292"}
0005434023888	4EBB18	4502 979140	DARYA IVANOVA	{"email": "d_ivanova_01121971@postgrespro.ru", "phone": "+70259897155"}
0005434023889	4EBB18	5963 512816	EVGENIY VASILEV	{"phone": "+70915609384"}
0005434023890	255C1B	5025 405057	ANNA GAVRILOVA	{"email": "a_gavrilova.121989@postgrespro.ru", "phone": "+70043237893"}
0005434023891	297234	8285 490128	ELENA STEPANOVA	{"phone": "+70915681261"}
0005434023892	297234	0413 777311	VASILIY POPOV	{"email": "v.popov-15061964@postgrespro.ru", "phone": "+70548790244"}
0005434023893	94287B	4556 746085	SERGEY MAKSIMOV	{"email": "s_maksimov_1984@postgrespro.ru", "phone": "+70529468145"}
0005434023894	8842FA	5279 173220	YURIY NIKOLAEV	{"email": "y.nikolaev.24101977@postgrespro.ru", "phone": "+70765086450"}
0005434023895	5675A2	7361 901604	YULIYA IVANOVA	{"phone": "+70048280669"}
0005434023896	BFE59B	0803 405718	EVGENIY MAKAROV	{"phone": "+70521059218"}
0005434023897	63D3C7	2491 668642	LYUBOV FOMINA	{"email": "fomina.l_30081959@postgrespro.ru", "phone": "+70947097500"}
0005434023898	B3C018	8330 796665	YURIY SOROKIN	{"phone": "+70898796013"}
0005434023899	B3C018	8928 192780	VLADIMIR VOLKOV	{"phone": "+70116143799"}
0005434023900	07591D	5107 667507	ALEKSANDR KUZNECOV	{"email": "a_kuznecov11041971@postgrespro.ru", "phone": "+70557258912"}
0005434023901	07591D	9331 345068	ALEKSANDRA NAUMOVA	{"phone": "+70627997466"}
0005434023902	89EC41	9573 049937	ANNA OSIPOVA	{"phone": "+70242037668"}
0005434023903	E0B9F3	1437 387146	YULIYA NAZAROVA	{"email": "nazarova-y.051964@postgrespro.ru", "phone": "+70883222513"}
0005434023904	E0B9F3	7415 367798	VADIM AFANASEV	{"phone": "+70892284770"}
0005434023905	7D80D0	6519 390846	EGOR GRIGOREV	{"phone": "+70120220426"}
0005434023906	BCD9F3	3489 283045	IGOR BORISOV	{"email": "igor_borisov_1980@postgrespro.ru", "phone": "+70869162785"}
0005434023907	4EDC53	9052 842579	PAVEL ROMANOV	{"email": "romanov-p051969@postgrespro.ru", "phone": "+70322373431"}
0005434023908	FFFA64	2145 634331	YURIY MAKSIMOV	{"phone": "+70283579120"}
0005434023909	4E33A9	8247 611843	RAISA ALEKSEEVA	{"email": "raisaalekseeva_1968@postgrespro.ru", "phone": "+70767512287"}
0005434023910	4E33A9	2114 723203	RASHIT VOROBEV	{"phone": "+70097924852"}
0005434023911	9EE30F	9379 419265	ALEKSEY STEPANOV	{"phone": "+70285953711"}
0005434023912	9EE30F	7256 871205	VALERIY EGOROV	{"phone": "+70597801244"}
0005434023913	19D722	3211 989089	ARTEM ZAYCEV	{"phone": "+70773390678"}
0005434023914	F3849C	8185 651714	OKSANA DANILOVA	{"phone": "+70715239448"}
0005434023915	3727D6	3576 640985	ZINAIDA ZAYCEVA	{"phone": "+70917525924"}
0005434023916	5E26B4	7246 983529	TATYANA VOROBEVA	{"email": "vorobevat-1976@postgrespro.ru", "phone": "+70667642139"}
0005434023917	A3A4AF	4254 420284	VERA DANILOVA	{"phone": "+70299085066"}
0005434023918	A3A4AF	7949 505032	MIKHAIL PAVLOV	{"phone": "+70115805724"}
0005434023919	C4B2FA	8743 642931	LIDIYA TITOVA	{"email": "l-titova.021968@postgrespro.ru", "phone": "+70815645909"}
0005434023920	C4B2FA	4580 026109	IGOR ORLOV	{"phone": "+70041358490"}
0005434023921	96D6FC	8802 632712	SOFIYA SERGEEVA	{"email": "sergeeva.s.1951@postgrespro.ru", "phone": "+70406205734"}
0005434023922	5291E3	4262 078255	VALERIY ZHUKOV	{"email": "valeriyzhukov-1964@postgrespro.ru", "phone": "+70980928826"}
0005434023923	5291E3	3471 417855	ALEKSANDR VOLKOV	{"email": "volkov-a_031976@postgrespro.ru", "phone": "+70488449336"}
0005434023924	24B4B8	4391 864086	GALINA SAVELEVA	{"email": "g_saveleva.1983@postgrespro.ru", "phone": "+70435969257"}
0005434023925	F6EFA4	8736 940869	SERGEY TIMOFEEV	{"email": "timofeev_sergey.22061980@postgrespro.ru", "phone": "+70593634409"}
0005434023926	F6EFA4	0715 368479	YURIY MELNIKOV	{"email": "melnikov_y1977@postgrespro.ru", "phone": "+70929118307"}
0005434023927	D90014	2147 666623	NIKOLAY VASILEV	{"email": "nvasilev-051970@postgrespro.ru", "phone": "+70792462526"}
0005434023928	D90014	4174 004322	VALENTINA YUDINA	{"phone": "+70228152334"}
0005434023929	D90014	6322 344200	YAROSLAV IVANOV	{"email": "ivanov_yaroslav_1973@postgrespro.ru", "phone": "+70498317870"}
0005434023930	6429F5	6430 406798	TATYANA NAZAROVA	{"phone": "+70092529794"}
0005434023931	12C35F	5447 825695	VALERIY CHERNOV	{"phone": "+70848941452"}
0005434023932	12C35F	4020 845095	NURLAN FILIPPOV	{"phone": "+70292925709"}
0005434023933	FAEA67	5898 099602	ALEKSANDR FOMIN	{"email": "fominaleksandr-30111966@postgrespro.ru", "phone": "+70105550785"}
0005434023934	C3B737	5258 764875	VALENTINA KRASNOVA	{"phone": "+70911212658"}
0005434023935	23FD99	3882 164247	SERGEY ZAYCEV	{"email": "zaycev_sergey.19051960@postgrespro.ru", "phone": "+70871922544"}
0005434023936	23FD99	8798 813562	VLADIMIR IVANOV	{"email": "v-ivanov031980@postgrespro.ru", "phone": "+70692292599"}
0005434023937	23FD99	5231 489063	TAMARA KOROLEVA	{"email": "koroleva.t.021974@postgrespro.ru", "phone": "+70466747028"}
0005434023938	2DE874	0106 814276	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr111971@postgrespro.ru", "phone": "+70936895305"}
0005434023939	2DE874	9538 333513	ZHANNA MEDVEDEVA	{"email": "medvedeva_z-07011967@postgrespro.ru", "phone": "+70815187859"}
0005434023940	40DBE2	7432 555280	SVETLANA SMIRNOVA	{"phone": "+70104981502"}
0005434023941	40DBE2	8995 982195	TATYANA BORISOVA	{"phone": "+70087034155"}
0005434023942	AD6FF3	4059 859641	ALEKSEY SOLOVEV	{"email": "a-solovev.041972@postgrespro.ru", "phone": "+70333942763"}
0005434023943	AD6FF3	3244 055334	LYUDMILA RODIONOVA	{"email": "lyudmilarodionova1966@postgrespro.ru", "phone": "+70352504871"}
0005434023944	BF03C7	2210 538423	NINA EGOROVA	{"email": "egorova-nina_1976@postgrespro.ru", "phone": "+70137900027"}
0005434023945	A60A80	3654 013952	TATYANA POTAPOVA	{"phone": "+70683410000"}
0005434023946	A176B7	6703 287227	LYUDMILA MELNIKOVA	{"email": "lmelnikova-051979@postgrespro.ru", "phone": "+70194095844"}
0005434023947	A176B7	4073 335666	ANDREY VASILEV	{"phone": "+70891734592"}
0005434023948	6DE9EF	3597 190658	SERGEY SOLOVEV	{"email": "solovev.sergey.10081963@postgrespro.ru", "phone": "+70894032316"}
0005434023949	3E3329	7271 119111	TIMUR ISAEV	{"email": "isaev.timur02091972@postgrespro.ru", "phone": "+70276688415"}
0005434023950	5EC5D4	6572 285501	ALEKSANDR MELNIKOV	{"email": "melnikova_27081974@postgrespro.ru", "phone": "+70333185221"}
0005434023951	0E1379	1334 097163	ALEKSANDR MARTYNOV	{"email": "martynova.051973@postgrespro.ru", "phone": "+70536178217"}
0005434023952	0E1379	2701 431540	DMITRIY IVANOV	{"phone": "+70182720320"}
0005434023953	5D8ED0	9369 723985	NATALYA LAZAREVA	{"phone": "+70854917581"}
0005434023954	5D8ED0	3511 100253	INNA KOROLEVA	{"phone": "+70517446071"}
0005434023955	57A1E0	1353 353021	ALINA PAVLOVA	{"phone": "+70083215399"}
0005434023956	85CF55	5239 157028	EKATERINA KALININA	{"email": "e-kalinina1966@postgrespro.ru", "phone": "+70223458372"}
0005434023957	85CF55	4380 637403	ANATOLIY KRASNOV	{"email": "krasnov.a.31071974@postgrespro.ru", "phone": "+70774890084"}
0005434023958	4C86AE	9117 132552	GENNADIY NIKOLAEV	{"phone": "+70067451277"}
0005434023959	4C86AE	5416 504007	TATYANA TIMOFEEVA	{"email": "timofeevatatyana_021977@postgrespro.ru", "phone": "+70195090419"}
0005434023960	A737CC	4153 831065	ALEKSANDR SOROKIN	{"phone": "+70696826656"}
0005434023961	A737CC	6506 384831	NIKOLAY NAZAROV	{"email": "nazarov_nikolay111968@postgrespro.ru", "phone": "+70877993757"}
0005434023962	8BD8A1	7612 836444	EKATERINA KOMAROVA	{"email": "e-komarova.06021967@postgrespro.ru", "phone": "+70202178199"}
0005434023963	ECC89C	5636 764202	MARAT SEMENOV	{"email": "marat.semenov_27111969@postgrespro.ru", "phone": "+70119403098"}
0005434023964	BDEADF	9696 587409	SERGEY NIKOLAEV	{"email": "s.nikolaev_051979@postgrespro.ru", "phone": "+70820640069"}
0005434023965	CF2C6D	3409 465204	ANASTASIYA CHERNOVA	{"email": "anastasiya.chernova-1975@postgrespro.ru", "phone": "+70149761476"}
0005434023966	B288A3	5025 867686	ANTON POPOV	{"phone": "+70961289242"}
0005434023967	BAAAAC	5676 551957	ELENA ZOTOVA	{"email": "zotova_e_1973@postgrespro.ru", "phone": "+70355355498"}
0005434023968	BAAAAC	5287 024542	IRINA KISELEVA	{"email": "ikiseleva_021974@postgrespro.ru", "phone": "+70105586362"}
0005434023969	BAAAAC	0327 252856	VLADIMIR CHERNOV	{"phone": "+70303688768"}
0005434023970	BAAAAC	9440 764165	SERGEY IVANOV	{"email": "ivanovs.19011966@postgrespro.ru", "phone": "+70744975252"}
0005434023971	04E8E1	5402 076394	GALINA TIKHONOVA	{"phone": "+70303276529"}
0005434023972	04E8E1	6605 793139	RUSTEM KOZLOV	{"email": "rustem.kozlov-121974@postgrespro.ru", "phone": "+70810096556"}
0005434023973	137C44	8910 804771	PAVEL KONOVALOV	{"phone": "+70397144640"}
0005434023974	333857	8562 198333	EKATERINA ZAKHAROVA	{"email": "zakharova.ekaterina-1976@postgrespro.ru", "phone": "+70411132638"}
0005434023975	5A1AC5	7917 531773	MAKSIM DMITRIEV	{"email": "m_dmitriev.21011972@postgrespro.ru", "phone": "+70816105298"}
0005434023976	856A01	9256 168185	ELENA FROLOVA	{"email": "e-frolova-1975@postgrespro.ru", "phone": "+70247691538"}
0005434023977	4962BC	0905 036383	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov-14061961@postgrespro.ru", "phone": "+70247365980"}
0005434023978	87CFC4	0620 535096	DMITRIY MAKSIMOV	{"email": "dmitriy-maksimov-1969@postgrespro.ru", "phone": "+70608474443"}
0005434023979	A8818F	3687 266917	VALENTINA ABRAMOVA	{"email": "valentina-abramova.101968@postgrespro.ru", "phone": "+70998211066"}
0005434023980	BFB265	1573 922343	EMILIYA FILIPPOVA	{"phone": "+70600284476"}
0005434023981	605AAA	9602 978836	RASHID MIKHAYLOV	{"phone": "+70718458537"}
0005434023982	605AAA	9482 666478	VLADIMIR SOKOLOV	{"phone": "+70068074227"}
0005434023983	4AA302	3791 951228	ALEKSANDR BORISOV	{"phone": "+70921964344"}
0005434023984	4AA302	7666 130254	SVETLANA KUDRYASHOVA	{"email": "svetlana_kudryashova1961@postgrespro.ru", "phone": "+70042482258"}
0005434023985	1E2C70	9073 552323	ANDREY IVANOV	{"phone": "+70881958738"}
0005434023986	9D5012	9966 097498	MAKSIM GRIGOREV	{"email": "m-grigorev.1979@postgrespro.ru", "phone": "+70965985124"}
0005434023987	9D5012	0086 393258	ALEKSEY RODIONOV	{"phone": "+70848853141"}
0005434023988	F2CC05	9946 669826	TATYANA MIKHAYLOVA	{"email": "mikhaylova.tatyana_18031979@postgrespro.ru", "phone": "+70438786703"}
0005434023989	E8BB52	4026 383205	TATYANA KUZMINA	{"email": "tatyana_kuzmina-1978@postgrespro.ru", "phone": "+70288958564"}
0005434023990	E8BB52	2075 147735	VLADIMIR ILIN	{"email": "ilin_v1982@postgrespro.ru", "phone": "+70152420402"}
0005434023991	E2C6A1	6185 230086	YURIY GRIGOREV	{"phone": "+70498803329"}
0005434023992	E2C6A1	1764 859148	SERGEY FEDOTOV	{"email": "sergey-fedotov-101964@postgrespro.ru", "phone": "+70611697375"}
0005434023993	A253FB	4842 340623	INNA EFREMOVA	{"email": "efremovai071964@postgrespro.ru", "phone": "+70106809278"}
0005434023994	6B3EF8	0075 684190	MARIYA ZAKHAROVA	{"phone": "+70501965023"}
0005434023995	39C2EE	3157 327867	SERGEY KARPOV	{"phone": "+70172429590"}
0005434023996	12E694	7329 585908	NATALYA VOLKOVA	{"phone": "+70181712362"}
0005434023997	323003	1262 546493	ROMAN KUZNECOV	{"email": "roman_kuznecov-111968@postgrespro.ru", "phone": "+70536945452"}
0005434023998	323003	9455 323552	VLADIMIR SIDOROV	{"email": "vladimir.sidorov1975@postgrespro.ru", "phone": "+70310987205"}
0005434023999	325D5E	0361 497418	EKATERINA FOMINA	{"email": "e_fomina.121981@postgrespro.ru", "phone": "+70370207794"}
0005434024000	C00B5F	1377 330434	VITALIY SOLOVEV	{"phone": "+70385512463"}
0005434024001	701BC9	3823 998580	YURIY POPOV	{"phone": "+70659124259"}
0005434024002	701BC9	2517 148222	ALEKSANDR NAZAROV	{"phone": "+70464689438"}
0005434024003	F60F09	7359 375401	EVGENIY OSIPOV	{"email": "osipov.evgeniy05061976@postgrespro.ru", "phone": "+70506912478"}
0005434024004	9386FC	9781 203388	KRISTINA KUZNECOVA	{"email": "kkuznecova_27051974@postgrespro.ru", "phone": "+70425399605"}
0005434024005	9386FC	4387 974067	NIKOLAY NIKOLAEV	{"email": "nikolaev.nikolay_1972@postgrespro.ru", "phone": "+70231435204"}
0005434024006	9386FC	4585 914101	DMITRIY POPOV	{"email": "popov_d.1970@postgrespro.ru", "phone": "+70930618013"}
0005434024007	23561E	7856 947055	TATYANA NIKOLAEVA	{"phone": "+70424016786"}
0005434024008	23561E	3613 302195	ANDREY VOLKOV	{"email": "volkov_a091976@postgrespro.ru", "phone": "+70385857003"}
0005434024009	E2AFCB	9315 604032	VLADIMIR KAZAKOV	{"email": "kazakov.v.23051969@postgrespro.ru", "phone": "+70310147283"}
0005434024010	1C1F05	2418 774788	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov20011963@postgrespro.ru", "phone": "+70252839022"}
0005434024011	1C1F05	0456 365533	VLADIMIR KRASNOV	{"phone": "+70337798517"}
0005434024012	A3888A	4678 609105	IRINA DENISOVA	{"email": "denisovairina_081974@postgrespro.ru", "phone": "+70663162195"}
0005434024013	A3888A	2379 725026	EVGENIY MAKAROV	{"phone": "+70993303162"}
0005434024014	68BD9B	7686 184919	ANDREY YAKOVLEV	{"email": "yakovlev-a_1978@postgrespro.ru", "phone": "+70071605811"}
0005434024015	828356	8466 753794	IRAIDA IVANOVA	{"email": "i-ivanova_011967@postgrespro.ru", "phone": "+70165937879"}
0005434024016	828356	2387 725513	VIKTOR ALEKSANDROV	{"phone": "+70955833336"}
0005434024017	079212	9076 347199	DANILA MAKAROV	{"phone": "+70354004811"}
0005434024018	079212	8591 546292	GALINA PETROVA	{"phone": "+70071051438"}
0005434024019	1443E1	7615 567979	NADEZHDA NIKIFOROVA	{"phone": "+70796680136"}
0005434024020	089362	6771 665960	DMITRIY GUSEV	{"phone": "+70759772088"}
0005434024021	089362	9107 284861	ANDREY PAVLOV	{"email": "pavlov.a-1963@postgrespro.ru", "phone": "+70426396803"}
0005434024022	089362	3899 339115	MATVEY GERASIMOV	{"phone": "+70448637927"}
0005434024023	AE5321	9307 306011	LYUBOV ANDREEVA	{"email": "l.andreeva02021967@postgrespro.ru", "phone": "+70785893351"}
0005434024024	373228	7255 451269	ARTEM ORLOV	{"email": "orlov.artem011973@postgrespro.ru", "phone": "+70715492625"}
0005434024025	373228	9146 031336	NADEZHDA AFANASEVA	{"email": "afanaseva-n-1972@postgrespro.ru", "phone": "+70102130852"}
0005434024026	12AC89	6490 496793	ALEKSANDR RODIONOV	{"phone": "+70776380558"}
0005434024144	8E8586	9132 661741	LIDIYA MAKSIMOVA	{"phone": "+70139446413"}
0005434024027	12AC89	7182 566977	VLADIMIR ANDREEV	{"email": "v.andreev-12021980@postgrespro.ru", "phone": "+70226987728"}
0005434024028	12AC89	2947 850363	SERGEY DAVYDOV	{"email": "sergeydavydov.21061970@postgrespro.ru", "phone": "+70755584592"}
0005434024472	FC7937	0805 877155	EVGENIY KONOVALOV	{"phone": "+70141084038"}
0005434024029	4C4BE7	8088 320068	TATYANA SOLOVEVA	{"email": "soloveva_tatyana_21111982@postgrespro.ru", "phone": "+70197032703"}
0005434024030	4C4BE7	0815 289943	DMITRIY ZAYCEV	{"phone": "+70993848184"}
0005434024031	F1A21C	2568 992150	ARTEM VOROBEV	{"phone": "+70494860430"}
0005434024032	C874ED	1654 626297	LIDIYA TARASOVA	{"phone": "+70927839965"}
0005434024033	09BF8F	3805 205734	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav.30071980@postgrespro.ru", "phone": "+70122948270"}
0005434024034	C1590F	0255 986148	LIDIYA ZAKHAROVA	{"email": "l_zakharova10011965@postgrespro.ru", "phone": "+70818079233"}
0005434024035	BA2677	9725 271529	MIKHAIL SMIRNOV	{"email": "mikhail.smirnov-041981@postgrespro.ru", "phone": "+70895839840"}
0005434024036	47BAE9	5341 945840	MARIYA FROLOVA	{"phone": "+70924142474"}
0005434024037	C8D0B3	5569 736499	LYUDMILA NESTEROVA	{"email": "nesterovalyudmila.021975@postgrespro.ru", "phone": "+70844080223"}
0005434024038	A8A817	5464 106768	NIKOLAY ZHURAVLEV	{"phone": "+70029098243"}
0005434024039	1D59DA	4524 634563	SERGEY IVANOV	{"phone": "+70324565701"}
0005434024040	1D59DA	6300 738800	TAMARA GORBUNOVA	{"email": "t_gorbunova_121973@postgrespro.ru", "phone": "+70837335126"}
0005434024041	806655	1499 655697	ILDAR TIKHONOV	{"phone": "+70689718373"}
0005434024042	12089D	9276 621522	DMITRIY ANDREEV	{"phone": "+70400261438"}
0005434024043	75F6A7	7252 639746	TATYANA BARANOVA	{"phone": "+70013750887"}
0005434024044	AD70E7	1901 462381	ALEKSANDR AFANASEV	{"phone": "+70316126982"}
0005434024045	C6DA96	7073 043673	NADEZHDA NIKITINA	{"phone": "+70118312182"}
0005434024046	14FA87	7497 839463	STEPAN DAVYDOV	{"phone": "+70110728910"}
0005434024047	14FA87	6562 293989	DMITRIY SOLOVEV	{"email": "dmitriy.solovev.081970@postgrespro.ru", "phone": "+70109306141"}
0005434024048	09A464	8550 402944	OLGA FILIPPOVA	{"email": "filippova_o-101971@postgrespro.ru", "phone": "+70488655264"}
0005434024049	09A464	9909 569975	ANNA BORISOVA	{"phone": "+70171700903"}
0005434024050	9A8A42	0252 274165	TATYANA NESTEROVA	{"phone": "+70810147668"}
0005434024051	038E38	3384 780401	SERGEY KAZAKOV	{"phone": "+70428077225"}
0005434024052	3E6F06	9346 796269	VIKTORIYA ANDREEVA	{"phone": "+70803899756"}
0005434024053	3E6F06	5127 067070	ANTON VOROBEV	{"email": "anton-vorobev_21041967@postgrespro.ru", "phone": "+70561919646"}
0005434024054	F47FD8	5189 193019	ANTONINA GERASIMOVA	{"email": "antoninagerasimova_1971@postgrespro.ru", "phone": "+70423269379"}
0005434024055	E42595	1976 976465	IRINA GERASIMOVA	{"phone": "+70976513985"}
0005434024056	E42595	5787 049670	NIKOLAY NAZAROV	{"email": "nikolaynazarov_1974@postgrespro.ru", "phone": "+70148480755"}
0005434024057	CB6E45	3415 328078	EVGENIY BORISOV	{"phone": "+70028695262"}
0005434024058	CB6E45	9233 992788	KRISTINA ZHUKOVA	{"email": "zhukova.k25101973@postgrespro.ru", "phone": "+70547591113"}
0005434024059	159EE5	1308 801547	IRINA SOROKINA	{"phone": "+70134539462"}
0005434024060	159EE5	1777 760504	SERGEY VLASOV	{"phone": "+70336670183"}
0005434024061	8A63FA	8711 412828	VALERIY MAKSIMOV	{"phone": "+70461408723"}
0005434024062	8A63FA	9739 862085	MAKSIM ISAEV	{"email": "maksim.isaev.091971@postgrespro.ru", "phone": "+70384937439"}
0005434024063	8A63FA	2463 370738	SERGEY PETROV	{"phone": "+70073744798"}
0005434024064	F551C4	2264 459746	TAMARA MARTYNOVA	{"email": "tamara_martynova-29061961@postgrespro.ru", "phone": "+70530431858"}
0005434024065	66EC11	1737 142262	VALENTINA MOROZOVA	{"phone": "+70377402232"}
0005434024066	66EC11	8260 014129	VYACHESLAV ROMANOV	{"phone": "+70766843276"}
0005434024067	50501F	0160 551314	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya-mikhaylova.061984@postgrespro.ru", "phone": "+70843086237"}
0005434024068	50501F	7704 243134	VALENTINA OSIPOVA	{"phone": "+70656533092"}
0005434024069	50501F	3313 981999	ANASTASIYA FADEEVA	{"email": "a-fadeeva-121972@postgrespro.ru", "phone": "+70974171327"}
0005434024070	5F5046	1772 641170	DMITRIY NAZAROV	{"phone": "+70160549162"}
0005434024071	5F5046	2807 113199	ARTEM MAKAROV	{"email": "makarov-a-081978@postgrespro.ru", "phone": "+70026783294"}
0005434024072	C146CF	7688 651215	OLGA ANTONOVA	{"email": "olga-antonova_07061976@postgrespro.ru", "phone": "+70901528937"}
0005434024073	C146CF	1520 018877	YURIY MELNIKOV	{"email": "melnikov.yuriy-1975@postgrespro.ru", "phone": "+70735142798"}
0005434024074	A3EB31	9099 163293	ALEKSANDR SEMENOV	{"phone": "+70398066467"}
0005434024075	E844A1	0038 608946	EKATERINA VOLKOVA	{"phone": "+70730203404"}
0005434024076	3D69E9	0827 722196	GALINA KISELEVA	{"phone": "+70654366371"}
0005434024077	8B6719	9205 457605	GENNADIY ZHUKOV	{"phone": "+70546165907"}
0005434024078	80EA4A	6393 943139	IRINA NOVIKOVA	{"phone": "+70933924605"}
0005434024079	23D88D	5428 367591	SVETLANA NIKOLAEVA	{"phone": "+70487972327"}
0005434024080	D4AE92	1635 739077	OLGA BORISOVA	{"email": "borisovao.26021966@postgrespro.ru", "phone": "+70957906287"}
0005434024081	EC7871	8700 254309	GENNADIY MOROZOV	{"email": "morozov.gennadiy.1964@postgrespro.ru", "phone": "+70205667734"}
0005434024082	7E3DE7	6505 136780	LYUDMILA PAVLOVA	{"phone": "+70975007851"}
0005434024083	188C38	8942 763767	GALINA FOMINA	{"email": "galina.fomina101966@postgrespro.ru", "phone": "+70988607820"}
0005434024084	6C8E5E	3780 339510	ILMIR TARASOV	{"phone": "+70072046150"}
0005434024085	40EA42	8795 627476	ELENA ILINA	{"email": "ilina-elena-1967@postgrespro.ru", "phone": "+70487079620"}
0005434024086	40EA42	3283 524833	TATYANA BOGDANOVA	{"email": "tatyanabogdanova1976@postgrespro.ru", "phone": "+70568646168"}
0005434024204	A0AFC0	4326 357743	MIKHAIL ZHUKOV	{"phone": "+70569649119"}
0005434024087	3150A3	9288 578425	ALEVTINA DANILOVA	{"email": "danilovaalevtina.15031966@postgrespro.ru", "phone": "+70695549116"}
0005434024088	625754	5872 128918	VIKTOR VOLKOV	{"email": "vvolkov.1987@postgrespro.ru", "phone": "+70800633900"}
0005434024089	D0A39D	9763 422201	YULIYA GORBUNOVA	{"email": "y.gorbunova-091974@postgrespro.ru", "phone": "+70490701328"}
0005434024090	FADDF1	6769 291389	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr_12121973@postgrespro.ru", "phone": "+70707931300"}
0005434024091	501589	8956 662435	ALEKSANDR KUZNECOV	{"phone": "+70010325681"}
0005434024092	F63309	4698 865776	NATALYA OSIPOVA	{"email": "osipovanatalya_04111970@postgrespro.ru", "phone": "+70257764026"}
0005434024093	790DC8	6401 774475	NATALYA SERGEEVA	{"email": "sergeeva-natalya_081971@postgrespro.ru", "phone": "+70834367609"}
0005434024094	790DC8	1792 509405	SERGEY OSIPOV	{"email": "osipovsergey15021982@postgrespro.ru", "phone": "+70031097369"}
0005434024095	873E4F	1895 684224	ANDREY ANTONOV	{"phone": "+70192102821"}
0005434024096	873E4F	0304 893796	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_1982@postgrespro.ru", "phone": "+70783438851"}
0005434024097	8E9F12	7497 712888	ANDREY MATVEEV	{"email": "matveevandrey-1971@postgrespro.ru", "phone": "+70293214472"}
0005434024098	8E9F12	9021 330356	MARINA MELNIKOVA	{"email": "m.melnikova-28051970@postgrespro.ru", "phone": "+70291173293"}
0005434024099	F2705D	1108 381627	TATYANA KOZLOVA	{"email": "t.kozlova.101969@postgrespro.ru", "phone": "+70632793207"}
0005434024100	78E013	7140 688982	VLADIMIR TARASOV	{"email": "vtarasov03011965@postgrespro.ru", "phone": "+70677031802"}
0005434024101	6B7294	2325 090371	VLADIMIR VASILEV	{"email": "vladimirvasilev_1967@postgrespro.ru", "phone": "+70098592312"}
0005434024102	6B7294	9468 941506	LEONID VOROBEV	{"email": "vorobev-l1971@postgrespro.ru", "phone": "+70227690432"}
0005434024103	FCFBA4	3782 595228	NIKOLAY SIDOROV	{"phone": "+70367818136"}
0005434024104	9CB102	7863 055557	GALINA ROMANOVA	{"phone": "+70814607918"}
0005434024105	5CD438	8893 448222	FARID ALEKSANDROV	{"email": "aleksandrov-farid-051976@postgrespro.ru", "phone": "+70150408365"}
0005434024106	5CD438	5827 456575	ARTEM ANTONOV	{"phone": "+70081004702"}
0005434024107	6CDDE6	3264 496294	RIMMA AFANASEVA	{"email": "afanaseva.rimma_12031983@postgrespro.ru", "phone": "+70866196089"}
0005434024108	D948D2	6895 300468	ELIZAVETA KOVALEVA	{"phone": "+70385398892"}
0005434024109	D4C5C0	1128 779514	ALEKSEY VASILEV	{"email": "vasilev-a30071968@postgrespro.ru", "phone": "+70609685751"}
0005434024110	111C49	2474 236013	TATYANA BORISOVA	{"phone": "+70543369517"}
0005434024111	111C49	0031 982321	ELENA KALININA	{"email": "kalininaelena-1970@postgrespro.ru", "phone": "+70865154456"}
0005434024112	BF7C34	7262 179335	SERGEY SEMENOV	{"email": "sergey_semenov-091971@postgrespro.ru", "phone": "+70472246010"}
0005434024113	C7FD05	4245 996783	SERGEY TARASOV	{"phone": "+70571820187"}
0005434024114	C7FD05	4915 564114	DANILA MARTYNOV	{"phone": "+70338559731"}
0005434024115	66B478	6931 071775	BORIS TIKHONOV	{"email": "btikhonov.1975@postgrespro.ru", "phone": "+70345550182"}
0005434024116	66B478	4092 111196	ANASTASIYA AFANASEVA	{"email": "a-afanaseva.28091965@postgrespro.ru", "phone": "+70099497005"}
0005434024117	F84DA1	9106 852989	ANNA ZAKHAROVA	{"email": "a_zakharova_21041960@postgrespro.ru", "phone": "+70922238523"}
0005434024118	0B3598	4342 515617	NIKOLAY CHERNOV	{"email": "chernov_n_031976@postgrespro.ru", "phone": "+70107577202"}
0005434024119	5E3EF3	5197 870557	VALERIYA ORLOVA	{"email": "valeriya-orlova-1960@postgrespro.ru", "phone": "+70950430608"}
0005434024120	803BED	6282 546544	SERGEY ZHUKOV	{"phone": "+70672531414"}
0005434024121	1FE372	8802 614530	NAIL SEMENOV	{"email": "semenovn.03081964@postgrespro.ru", "phone": "+70311585248"}
0005434024122	1FE372	3543 946373	SERGEY VOLKOV	{"email": "volkov_s121969@postgrespro.ru", "phone": "+70391143161"}
0005434024123	C3560C	0669 351256	ANDREY ALEKSANDROV	{"email": "andrey-aleksandrov.1985@postgrespro.ru", "phone": "+70537116719"}
0005434024124	6B5405	2297 034696	VLADIMIR BONDARENKO	{"email": "bondarenko_v1967@postgrespro.ru", "phone": "+70681412987"}
0005434024125	6B5405	2167 703207	ANATOLIY SOROKIN	{"phone": "+70639208122"}
0005434024126	46A97D	6736 300285	ZOYA KAZAKOVA	{"email": "zoya.kazakova.1974@postgrespro.ru", "phone": "+70341212526"}
0005434024127	46A97D	2321 970927	KONSTANTIN KRASNOV	{"email": "krasnov-k_1965@postgrespro.ru", "phone": "+70419244387"}
0005434024128	4F75E7	0621 610914	VIKTOR KUZNECOV	{"email": "kuznecov.viktor111969@postgrespro.ru", "phone": "+70938578567"}
0005434024129	ECC06E	3509 402405	RIMMA KONOVALOVA	{"email": "konovalovar_14111968@postgrespro.ru", "phone": "+70082951293"}
0005434024130	C964B0	8093 682015	OLEG SMIRNOV	{"email": "o-smirnov01071973@postgrespro.ru", "phone": "+70757346104"}
0005434024131	C964B0	2887 888668	MAKSIM KRASNOV	{"email": "krasnov_maksim_011976@postgrespro.ru", "phone": "+70629952050"}
0005434024132	5C3165	7487 845959	NINA KOZLOVA	{"email": "kozlova_n031974@postgrespro.ru", "phone": "+70146214640"}
0005434024133	A243DE	1612 161214	DIANA ISAEVA	{"email": "isaeva-diana.051971@postgrespro.ru", "phone": "+70023701290"}
0005434024134	586C72	0577 769153	ANNA KRASNOVA	{"email": "krasnova-anna1975@postgrespro.ru", "phone": "+70026769440"}
0005434024135	586C72	3302 525926	ELENA KUZNECOVA	{"phone": "+70369563683"}
0005434024136	7E9E2E	5657 565906	KSENIYA SOKOLOVA	{"phone": "+70332506245"}
0005434024137	7E9E2E	7510 243789	TATYANA SERGEEVA	{"phone": "+70802201099"}
0005434024138	EC407B	2263 132679	MARIYA BORISOVA	{"phone": "+70019201787"}
0005434024139	EC407B	1009 947699	ROMAN ALEKSEEV	{"email": "alekseev-roman-22011979@postgrespro.ru", "phone": "+70167518454"}
0005434024140	099C2E	4266 797240	GENNADIY ORLOV	{"email": "orlovgennadiy.081970@postgrespro.ru", "phone": "+70738455613"}
0005434024141	099C2E	8800 785173	IDA KOVALEVA	{"phone": "+70681664822"}
0005434024142	52EBB8	3621 529024	MIKHAIL SIDOROV	{"phone": "+70919124026"}
0005434024143	8E8586	8771 764876	SERGEY SCHERBAKOV	{"email": "scherbakovs-1968@postgrespro.ru", "phone": "+70400067682"}
0005434024145	03C6C0	3742 406606	NATALYA ZOTOVA	{"email": "natalya_zotova-1964@postgrespro.ru", "phone": "+70432435966"}
0005434024146	47A217	7653 318275	NATALYA ZOTOVA	{"email": "zotova.natalya111972@postgrespro.ru", "phone": "+70292232871"}
0005434024147	F192E5	5819 177463	VLADISLAV FILIPPOV	{"email": "filippov-vladislav.02061974@postgrespro.ru", "phone": "+70806084389"}
0005434024148	F192E5	4593 875415	KSENIYA LUKYANOVA	{"phone": "+70349459947"}
0005434024149	ECC736	5346 008928	OLGA FROLOVA	{"phone": "+70401575219"}
0005434024150	0DAAAC	2664 605290	MARINA PAVLOVA	{"email": "pavlova.marina-081969@postgrespro.ru", "phone": "+70272613222"}
0005434024151	3EA8B0	6654 519252	DMITRIY FROLOV	{"email": "frolovd_04051982@postgrespro.ru", "phone": "+70298825944"}
0005434024152	D10DB9	2336 073912	DAMIR IVANOV	{"phone": "+70803231551"}
0005434024153	E12A91	1565 657104	FEDOR DENISOV	{"email": "denisov-fedor_1968@postgrespro.ru", "phone": "+70715379364"}
0005434024154	86A003	4246 271753	MARIYA VOLKOVA	{"phone": "+70311915447"}
0005434024155	23FF24	3407 138392	DMITRIY MEDVEDEV	{"email": "medvedev_d25011967@postgrespro.ru", "phone": "+70481965630"}
0005434024156	23FF24	0287 324861	TATYANA NESTEROVA	{"email": "nesterovatatyana_121967@postgrespro.ru", "phone": "+70937275955"}
0005434024157	B3E52E	4585 488926	VYACHESLAV KONOVALOV	{"phone": "+70147913745"}
0005434024158	54C12A	9387 760972	EVGENIY KISELEV	{"email": "kiselev.evgeniy_1971@postgrespro.ru", "phone": "+70295100255"}
0005434024159	54C12A	8223 574922	MARAT SAVELEV	{"email": "savelev-m-1973@postgrespro.ru", "phone": "+70578108977"}
0005434024160	534296	6800 838764	ALEKSEY POPOV	{"phone": "+70336348648"}
0005434024161	534296	6867 047272	ANATOLIY FEDOROV	{"email": "fedorova1986@postgrespro.ru", "phone": "+70850599676"}
0005434024162	534296	9793 598585	ALENA KOROLEVA	{"email": "korolevaa_20101969@postgrespro.ru", "phone": "+70776340091"}
0005434024163	4EA49F	4097 151885	DMITRIY TIKHONOV	{"email": "dmitriy-tikhonov-121971@postgrespro.ru", "phone": "+70464739818"}
0005434024164	4CEBE9	9862 120337	SERGEY KAZAKOV	{"phone": "+70146158863"}
0005434024165	9C0CF9	5513 762078	TAMARA SOKOLOVA	{"phone": "+70919992479"}
0005434024166	A28D41	0286 003046	LIDIYA KONOVALOVA	{"phone": "+70613604920"}
0005434024167	226783	8057 165899	GEORGIY FOMIN	{"phone": "+70172160682"}
0005434024168	E32EE9	8495 379774	ALEKSANDR BARANOV	{"email": "aleksandr.baranov.07091970@postgrespro.ru", "phone": "+70765038984"}
0005434024169	6BFA1E	8511 623652	SVETLANA VOLKOVA	{"phone": "+70435287062"}
0005434024170	6BFA1E	6173 120112	ANATOLIY NAZAROV	{"email": "nazarov-a_1978@postgrespro.ru", "phone": "+70357588160"}
0005434024171	6BFA1E	5714 902129	OLEG BARANOV	{"phone": "+70814124839"}
0005434024172	178093	3889 225098	ILYA IVANOV	{"email": "ilya_ivanov.121974@postgrespro.ru", "phone": "+70352658361"}
0005434024173	76A933	3461 580843	MAKSIM VOLKOV	{"phone": "+70849751469"}
0005434024174	C1BCE4	6351 480108	IOSIF MAKSIMOV	{"email": "maksimov.i-27071979@postgrespro.ru", "phone": "+70833520165"}
0005434024175	C1BCE4	4389 924077	ALEKSANDR GUSEV	{"email": "gusev-a_101969@postgrespro.ru", "phone": "+70330538191"}
0005434024176	C1BCE4	2897 683842	IVAN KUZNECOV	{"phone": "+70042564646"}
0005434024177	C08C0E	0846 261289	NIKOLAY KONOVALOV	{"email": "konovalov_n_1968@postgrespro.ru", "phone": "+70621428463"}
0005434024178	AF3244	3891 398049	ELENA FILIPPOVA	{"email": "filippova-elena-1969@postgrespro.ru", "phone": "+70645985211"}
0005434024179	AF3244	4628 313941	IRINA BARANOVA	{"email": "ibaranova09111970@postgrespro.ru", "phone": "+70257562626"}
0005434024180	E755FB	0485 377967	MIKHAIL VOLKOV	{"email": "mikhailvolkov-15111979@postgrespro.ru", "phone": "+70934636875"}
0005434024181	E755FB	8072 464677	EVGENIY SOKOLOV	{"phone": "+70349904716"}
0005434024182	3CC1FA	4704 316354	ANNA KONDRATEVA	{"email": "kondrateva-a.1962@postgrespro.ru", "phone": "+70590601781"}
0005434024183	EF1ACC	7304 263770	ANATOLIY TARASOV	{"phone": "+70278823269"}
0005434024184	EF1ACC	4871 122348	ANDREY IVANOV	{"phone": "+70098429163"}
0005434024185	1497F4	1987 149044	EVGENIY ZAYCEV	{"phone": "+70119081750"}
0005434024186	FE1F12	5729 697135	MAKSIM KUZMIN	{"email": "maksim-kuzmin.1974@postgrespro.ru", "phone": "+70966375078"}
0005434024187	FE1F12	9975 507536	IRINA TIKHONOVA	{"email": "itikhonova-091982@postgrespro.ru", "phone": "+70752137849"}
0005434024188	84A64A	3435 340544	ELINA BORISOVA	{"email": "borisovaelina.021977@postgrespro.ru", "phone": "+70769952141"}
0005434024189	84A64A	5234 471843	YULIYA MATVEEVA	{"email": "y_matveeva.1977@postgrespro.ru", "phone": "+70471271521"}
0005434024190	A340A3	4073 111084	OLESYA TIKHONOVA	{"phone": "+70768812749"}
0005434024191	82BAC0	4629 681756	ALEKSEY PAVLOV	{"phone": "+70617419633"}
0005434024192	82BAC0	6243 138510	VERA NOVIKOVA	{"phone": "+70875719773"}
0005434024193	E6AFCC	1700 711621	ANATOLIY GORBUNOV	{"email": "gorbunov-anatoliy-081961@postgrespro.ru", "phone": "+70301731218"}
0005434024194	A8C91E	6666 595813	ELENA TARASOVA	{"email": "tarasova-elena061964@postgrespro.ru", "phone": "+70356954557"}
0005434024195	84898B	9802 125808	GEORGIY ABRAMOV	{"email": "abramov.georgiy_19071975@postgrespro.ru", "phone": "+70842455373"}
0005434024196	2DB999	4736 835570	RAISA VASILEVA	{"email": "raisa-vasileva-091970@postgrespro.ru", "phone": "+70848601637"}
0005434024197	2DB999	9724 303780	SVETLANA ZAKHAROVA	{"phone": "+70666843931"}
0005434024198	1BB86C	0342 165553	ALEKSANDR VASILEV	{"phone": "+70281127713"}
0005434024199	1BB86C	4592 489855	ILYA ZHURAVLEV	{"email": "ilya_zhuravlev-21081965@postgrespro.ru", "phone": "+70146625938"}
0005434024200	DE49F6	9857 879519	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr_121973@postgrespro.ru", "phone": "+70037256075"}
0005434024201	4BDFFD	6021 214522	IRAIDA SEMENOVA	{"email": "semenova_iraida-021972@postgrespro.ru", "phone": "+70909491527"}
0005434024202	87EBCB	9691 659242	IGOR EGOROV	{"phone": "+70602393214"}
0005434024203	87EBCB	7782 048366	SERGEY ANDREEV	{"email": "andreev_sergey101965@postgrespro.ru", "phone": "+70243241445"}
0005434024205	31ADBA	3055 281536	SVETLANA POTAPOVA	{"email": "potapova_s.12111971@postgrespro.ru", "phone": "+70736242040"}
0005434024206	31ADBA	4659 758713	EKATERINA SEMENOVA	{"phone": "+70964433496"}
0005434024207	1CCCC1	0108 664604	ILMIR KUZMIN	{"phone": "+70436775556"}
0005434024208	186DC4	2111 363379	NADEZHDA NIKITINA	{"phone": "+70534759991"}
0005434024209	186DC4	3708 121615	RODION KUZNECOV	{"email": "kuznecov_rodion1978@postgrespro.ru", "phone": "+70659863696"}
0005434024210	8263C3	6426 795926	VALENTINA SOLOVEVA	{"phone": "+70778911540"}
0005434024211	3E6BFA	1138 948258	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy.1971@postgrespro.ru", "phone": "+70093244766"}
0005434024212	3E6BFA	4062 498111	POLINA EGOROVA	{"phone": "+70129006612"}
0005434024213	3E6BFA	3949 677399	PAVEL KARPOV	{"phone": "+70876158251"}
0005434024214	B02645	6518 052641	SERGEY VOROBEV	{"phone": "+70321471675"}
0005434024215	192AC8	0912 934193	ZINAIDA SOROKINA	{"phone": "+70265719988"}
0005434024216	41D17A	0491 279840	IVAN DAVYDOV	{"email": "ivandavydov_091973@postgrespro.ru", "phone": "+70128278163"}
0005434024217	A6E2D1	5056 992757	ALEKSANDR FILIPPOV	{"phone": "+70393085749"}
0005434024218	6AA688	8810 374046	VYACHESLAV NAZAROV	{"phone": "+70008119972"}
0005434024219	6AA688	7942 549271	GALINA RODIONOVA	{"phone": "+70977316459"}
0005434024220	AB587A	5200 929233	MARIYA LEBEDEVA	{"email": "mariya-lebedeva071977@postgrespro.ru", "phone": "+70429947269"}
0005434024221	AB587A	2554 462453	ANASTASIYA MEDVEDEVA	{"email": "anastasiya_medvedeva_1970@postgrespro.ru", "phone": "+70736530208"}
0005434024222	97C3AC	9021 987630	SVETLANA SEMENOVA	{"phone": "+70986929729"}
0005434024223	97C3AC	4697 794640	VALERIYA TIKHONOVA	{"email": "tikhonovavaleriya_1972@postgrespro.ru", "phone": "+70680997795"}
0005434024224	65F19C	1699 211574	ALEKSEY PETROV	{"email": "a_petrov_111968@postgrespro.ru", "phone": "+70164322955"}
0005434024225	CEEF33	1082 872418	MARGARITA ANISIMOVA	{"email": "margaritaanisimova121960@postgrespro.ru", "phone": "+70882678076"}
0005434024226	42168E	5913 212503	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov011987@postgrespro.ru", "phone": "+70821484554"}
0005434024227	DC158C	1512 570411	TATYANA MEDVEDEVA	{"phone": "+70690722318"}
0005434024228	DE646F	3585 711243	EGOR SAVELEV	{"email": "egor-savelev111977@postgrespro.ru", "phone": "+70768965205"}
0005434024229	B3AC7F	0381 276374	GENNADIY IVANOV	{"email": "ivanovg081971@postgrespro.ru", "phone": "+70129111626"}
0005434024230	B3AC7F	8318 727506	ILYA MAKSIMOV	{"phone": "+70715536664"}
0005434024231	10F5EB	5061 214821	TIMOFEY SOROKIN	{"phone": "+70368328852"}
0005434024232	CE5151	4484 087337	VIKTOR FEDOROV	{"email": "fedorov.viktor.11071960@postgrespro.ru", "phone": "+70445383022"}
0005434024233	86B2CC	0543 096611	YAROSLAV KUZMIN	{"email": "kuzmin_yaroslav_101983@postgrespro.ru", "phone": "+70186495984"}
0005434024234	86B2CC	5852 084705	ANNA YUDINA	{"email": "yudina.anna_24091971@postgrespro.ru", "phone": "+70639757524"}
0005434024235	B6BBB0	0749 536133	YULIYA IVANOVA	{"phone": "+70834455931"}
0005434024236	4DD9F7	1787 652543	ANTONINA MIKHAYLOVA	{"phone": "+70602398664"}
0005434024237	E0A6EF	8819 124328	EVDOKIYA NESTEROVA	{"phone": "+70321878408"}
0005434024238	97FE1A	7176 818771	SVETLANA NESTEROVA	{"phone": "+70757229297"}
0005434024239	43BEE4	0143 012520	DANIL SCHERBAKOV	{"phone": "+70792877175"}
0005434024240	43BEE4	6714 100634	NIKOLAY NOVIKOV	{"phone": "+70725249716"}
0005434024241	43BEE4	8889 031668	ALEKSANDR KARPOV	{"email": "karpov-a22071979@postgrespro.ru", "phone": "+70236693665"}
0005434024242	16F34F	0197 770987	SERGEY EGOROV	{"email": "sergey_egorov-071975@postgrespro.ru", "phone": "+70233134006"}
0005434024243	F69B63	6334 871353	VLADIMIR IVANOV	{"phone": "+70980364370"}
0005434024244	F69B63	7156 798640	TATYANA PAVLOVA	{"email": "pavlova-tatyana_081976@postgrespro.ru", "phone": "+70997429137"}
0005434024245	6D1243	7329 579508	DMITRIY NIKOLAEV	{"email": "d.nikolaev-071962@postgrespro.ru", "phone": "+70546000898"}
0005434024246	6D1243	8384 842477	LYUBOV NIKIFOROVA	{"email": "nikiforovalyubov_1966@postgrespro.ru", "phone": "+70860777401"}
0005434024247	D59C63	9018 157870	VYACHESLAV KRASNOV	{"email": "v_krasnov.1970@postgrespro.ru", "phone": "+70428487651"}
0005434024248	007E54	5483 506986	OLEG MELNIKOV	{"phone": "+70662055295"}
0005434024249	007E54	8718 150103	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov061974@postgrespro.ru", "phone": "+70473065030"}
0005434024250	D91F0A	9288 712494	TATYANA NIKOLAEVA	{"phone": "+70081857959"}
0005434024251	D91F0A	0518 421041	ALEKSANDR PETROV	{"email": "aleksandr.petrov-071966@postgrespro.ru", "phone": "+70786027860"}
0005434024252	305CF5	5898 849904	ALEKSEY DAVYDOV	{"email": "davydov_aleksey-30071982@postgrespro.ru", "phone": "+70356190108"}
0005434024253	305CF5	2890 967092	MAYYA ROMANOVA	{"phone": "+70918113169"}
0005434024254	9CC610	6582 798195	VERA KOROLEVA	{"email": "vera_koroleva_1971@postgrespro.ru", "phone": "+70175645820"}
0005434024255	80BBDD	0902 492307	ANDREY EGOROV	{"email": "egorov.andrey24031977@postgrespro.ru", "phone": "+70524064573"}
0005434024256	CAEE99	7975 394591	VLADIMIR PETROV	{"email": "vpetrov-15091975@postgrespro.ru", "phone": "+70768955027"}
0005434024257	2E4FC1	1288 814954	RENAT VOLKOV	{"email": "volkov-r.071973@postgrespro.ru", "phone": "+70725530744"}
0005434024258	2E4FC1	7273 016412	ALIYA ABRAMOVA	{"email": "abramova-a01041971@postgrespro.ru", "phone": "+70118410966"}
0005434024259	2E4FC1	4306 895646	LYUDMILA ALEKSEEVA	{"email": "alekseeva-l-17061971@postgrespro.ru", "phone": "+70856770878"}
0005434024260	F07714	5888 118569	SVETLANA SMIRNOVA	{"phone": "+70398009259"}
0005434024261	F07714	1366 235331	IVAN GAVRILOV	{"phone": "+70932493403"}
0005434024262	DEAA08	6396 899901	KSENIYA IVANOVA	{"phone": "+70911581595"}
0005434024263	DEAA08	8442 743521	EVGENIYA LOGINOVA	{"email": "evgeniyaloginova.25031980@postgrespro.ru", "phone": "+70155824919"}
0005434024264	6CA964	5894 413527	LYUBOV ANTONOVA	{"phone": "+70931134387"}
0005434024265	328C2D	5932 564547	VIKTORIYA ZHURAVLEVA	{"email": "viktoriya-zhuravleva1975@postgrespro.ru", "phone": "+70153431583"}
0005434024266	951D7C	7413 964480	VLADIMIR MELNIKOV	{"email": "v-melnikov071967@postgrespro.ru", "phone": "+70820213615"}
0005434024267	951D7C	9589 475902	ARTEM FEDOROV	{"phone": "+70884045693"}
0005434024268	235FB4	7357 082405	DMITRIY MIKHAYLOV	{"email": "dmikhaylov_1967@postgrespro.ru", "phone": "+70154283335"}
0005434024269	86AE53	4355 740113	VADIM TIMOFEEV	{"phone": "+70099172896"}
0005434024270	FCA310	1140 804463	ANNA ANTONOVA	{"phone": "+70212263915"}
0005434024271	EDF1AE	6987 235632	NATALYA SMIRNOVA	{"phone": "+70360142641"}
0005434024272	204A1A	8394 849830	ALEKSANDR RODIONOV	{"phone": "+70683596043"}
0005434024273	3AB3C8	1831 039113	LYUDMILA KUZNECOVA	{"email": "lyudmila-kuznecova1985@postgrespro.ru", "phone": "+70927720871"}
0005434024274	3D8D44	6308 774982	LYUDMILA NOVIKOVA	{"phone": "+70004583519"}
0005434024275	3D8D44	7290 574267	ANDREY KRASNOV	{"email": "a_krasnov051977@postgrespro.ru", "phone": "+70150319386"}
0005434024276	AC9ABB	8364 832599	VARVARA ILINA	{"email": "ilina_varvara-26011966@postgrespro.ru", "phone": "+70469237988"}
0005434024277	C70BCE	4210 114201	ALBINA GUSEVA	{"phone": "+70382239106"}
0005434024278	5EAA99	3786 548705	SERGEY KULIKOV	{"phone": "+70099558193"}
0005434024279	BB3B39	9326 711266	NATALYA ZAKHAROVA	{"phone": "+70097370196"}
0005434024280	8F5278	5761 085440	LYUBOV MELNIKOVA	{"email": "melnikovalyubov.1971@postgrespro.ru", "phone": "+70281589239"}
0005434024281	318931	7471 630097	IRINA KUZNECOVA	{"email": "kuznecova-i_18081968@postgrespro.ru", "phone": "+70789306071"}
0005434024282	C99B9C	2065 594453	SVETLANA YUDINA	{"email": "syudina_21041968@postgrespro.ru", "phone": "+70019816185"}
0005434024283	8F8C26	8069 182791	ANGELINA VASILEVA	{"email": "a.vasileva-1971@postgrespro.ru", "phone": "+70438623031"}
0005434024284	8EECA1	7759 158049	SERGEY EGOROV	{"email": "segorov16051970@postgrespro.ru", "phone": "+70958442118"}
0005434024285	8EECA1	2765 662877	PAVEL ANTONOV	{"email": "p.antonov041973@postgrespro.ru", "phone": "+70857279733"}
0005434024286	8734CF	8641 739182	SVETLANA KONDRATEVA	{"email": "svetlana.kondrateva-011978@postgrespro.ru", "phone": "+70966500356"}
0005434024287	24465E	1245 275936	ANATOLIY DMITRIEV	{"email": "dmitriev-anatoliy.25041968@postgrespro.ru", "phone": "+70992407491"}
0005434024288	3F85B8	3429 564299	INNA SOKOLOVA	{"phone": "+70759470930"}
0005434024289	3F85B8	9835 041731	VLADISLAV NIKITIN	{"phone": "+70647569500"}
0005434024290	5A1575	8144 946095	KLAVDIYA BARANOVA	{"phone": "+70075289172"}
0005434024291	2F7E06	5130 842182	IRAIDA SOROKINA	{"email": "iraida-sorokina_121977@postgrespro.ru", "phone": "+70642889899"}
0005434024292	BDA0C9	3075 305522	NIKOLAY GRIGOREV	{"phone": "+70778846312"}
0005434024293	761A7F	1921 333981	VASILIY KUZNECOV	{"email": "kuznecovvasiliy_25051968@postgrespro.ru", "phone": "+70243546336"}
0005434024294	761A7F	6175 338936	TATYANA KAZAKOVA	{"phone": "+70695047015"}
0005434024295	413925	7271 692758	NATALIYA GORBUNOVA	{"email": "gorbunova-n-1979@postgrespro.ru", "phone": "+70774091096"}
0005434024296	88E4E5	9174 349797	ZOYA KUZNECOVA	{"phone": "+70086154227"}
0005434024297	99029F	4945 368223	TATYANA KONOVALOVA	{"email": "tatyana-konovalova11051965@postgrespro.ru", "phone": "+70298024624"}
0005434024298	528AA2	5881 770096	KARINA DAVYDOVA	{"email": "davydova.k23091968@postgrespro.ru", "phone": "+70833100082"}
0005434024299	865BFF	5787 739375	ANTON KISELEV	{"phone": "+70786573079"}
0005434024300	E70A57	2105 716697	LYUDMILA NAUMOVA	{"email": "lyudmila-naumova.22071965@postgrespro.ru", "phone": "+70533258100"}
0005434024301	E70A57	2090 008196	OLGA ORLOVA	{"email": "orlova_o.061981@postgrespro.ru", "phone": "+70026083765"}
0005434024302	E70A57	5935 991217	GENNADIY ABRAMOV	{"email": "abramovg-1971@postgrespro.ru", "phone": "+70787498955"}
0005434024303	F662B4	1709 962123	MARINA MELNIKOVA	{"phone": "+70753649939"}
0005434024304	C7C048	0967 327247	YULIYA KONOVALOVA	{"phone": "+70693719694"}
0005434024305	7512C7	7862 819226	TATYANA ANISIMOVA	{"phone": "+70809284717"}
0005434024306	7512C7	8509 057282	ANTONINA DAVYDOVA	{"email": "adavydova-1962@postgrespro.ru", "phone": "+70889690832"}
0005434024307	BDBCE7	4753 040559	ANNA STEPANOVA	{"email": "stepanovaanna-1966@postgrespro.ru", "phone": "+70116131573"}
0005434024308	CCF6F9	0059 892998	OLEG KOZLOV	{"phone": "+70892731064"}
0005434024309	992F61	3359 222399	NINA EFREMOVA	{"phone": "+70068777634"}
0005434024310	992F61	9339 151374	RASUL SERGEEV	{"email": "rsergeev_08091977@postgrespro.ru", "phone": "+70229512924"}
0005434024311	92A5B9	4821 681457	OLGA KAZAKOVA	{"phone": "+70808422018"}
0005434024312	F84BDD	4824 441056	IRAIDA EFIMOVA	{"email": "iefimova.021971@postgrespro.ru", "phone": "+70664140760"}
0005434024313	2229EC	9371 017201	SERGEY EGOROV	{"email": "egorov_s-1963@postgrespro.ru", "phone": "+70684096221"}
0005434024314	398EA1	9907 136156	MIKHAIL ROMANOV	{"phone": "+70651165263"}
0005434024315	0F7A09	4105 778410	NATALYA GRISHINA	{"email": "grishina-natalya-1976@postgrespro.ru", "phone": "+70039270328"}
0005434024316	2001E0	8714 379652	EKATERINA ABRAMOVA	{"phone": "+70807751457"}
0005434024317	2001E0	3492 119748	NADEZHDA BOGDANOVA	{"phone": "+70908448869"}
0005434024318	552035	3940 479264	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.05041969@postgrespro.ru", "phone": "+70301296661"}
0005434024319	F03B3F	3936 750604	TATYANA KOROLEVA	{"email": "tkoroleva-25091978@postgrespro.ru", "phone": "+70404337888"}
0005434024320	26D798	4654 247326	SERGEY FILIPPOV	{"phone": "+70851869716"}
0005434024321	EF51C2	2795 151798	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy1980@postgrespro.ru", "phone": "+70976396017"}
0005434024322	5FE9B4	9280 654936	NIKOLAY SOROKIN	{"email": "nsorokin_1975@postgrespro.ru", "phone": "+70739842730"}
0005434024323	5FE9B4	6392 456075	PAVEL IVANOV	{"phone": "+70172522418"}
0005434024743	A6275E	8816 929925	TATYANA OSIPOVA	{"phone": "+70468531149"}
0005434024324	B1F0DD	7262 234779	IGOR ZHURAVLEV	{"email": "igor_zhuravlev01111973@postgrespro.ru", "phone": "+70272553190"}
0005434024325	92CE3C	6308 763295	NATALYA GRISHINA	{"email": "grishina-natalya-1979@postgrespro.ru", "phone": "+70885211645"}
0005434024326	92CE3C	1133 347580	NADEZHDA PAVLOVA	{"email": "pavlova_n.08011973@postgrespro.ru", "phone": "+70626962468"}
0005434024327	38806B	2984 787247	MARINA BELOVA	{"email": "m-belova-02031975@postgrespro.ru", "phone": "+70989611560"}
0005434024328	252C26	0950 351450	DENIS NIKOLAEV	{"phone": "+70423670959"}
0005434024329	252C26	4186 413934	NADEZHDA ANDREEVA	{"phone": "+70955982701"}
0005434024330	648158	1249 329433	EKATERINA MIRONOVA	{"phone": "+70023428567"}
0005434024331	648158	8254 744409	ALEKSANDR MELNIKOV	{"phone": "+70350936735"}
0005434024332	42C4BF	9843 094255	GENNADIY EGOROV	{"phone": "+70614685125"}
0005434024333	3E3B60	8693 527749	MARINA GUSEVA	{"phone": "+70163337908"}
0005434024334	F71C39	2944 190053	NATALYA MATVEEVA	{"email": "natalya_matveeva_1976@postgrespro.ru", "phone": "+70396133896"}
0005434024335	46DC01	8319 233168	VIKTOR SOKOLOV	{"phone": "+70056037788"}
0005434024336	54E2D6	5609 509241	ALEKSEY EGOROV	{"email": "aleksey-egorov-021968@postgrespro.ru", "phone": "+70208994478"}
0005434024337	54E2D6	2223 960597	ALEKSANDR MOROZOV	{"email": "a.morozov.27031974@postgrespro.ru", "phone": "+70475445048"}
0005434024338	AA4271	6375 468593	ZINAIDA MOROZOVA	{"email": "zinaidamorozova04021979@postgrespro.ru", "phone": "+70903668678"}
0005434024339	715F45	6017 886277	EVGENIY STEPANOV	{"email": "stepanovevgeniy-051981@postgrespro.ru", "phone": "+70287601727"}
0005434024340	7E2601	9065 366363	KLAVDIYA MAKSIMOVA	{"phone": "+70497647709"}
0005434024341	7E2601	3954 670224	OKSANA KARPOVA	{"email": "okarpova061972@postgrespro.ru", "phone": "+70930777605"}
0005434024342	938A26	9768 643416	IGOR NAZAROV	{"phone": "+70527025781"}
0005434024343	3463DE	5462 406546	IGOR SOROKIN	{"phone": "+70298708042"}
0005434024344	EDE996	9617 182517	ZINAIDA EFREMOVA	{"phone": "+70802029060"}
0005434024345	EDE996	1605 297293	MAKSIM BELOV	{"email": "belov.m.111971@postgrespro.ru", "phone": "+70328848527"}
0005434024346	EDE996	6202 208715	ALEKSEY GORBUNOV	{"phone": "+70014790666"}
0005434024347	547E24	3425 563331	ANDREY SAVELEV	{"email": "savelev.a.121975@postgrespro.ru", "phone": "+70683917232"}
0005434024348	547E24	4132 830841	SERGEY ALEKSEEV	{"email": "alekseev.sergey1979@postgrespro.ru", "phone": "+70929935789"}
0005434024349	D0F032	9251 613102	IRINA BELOVA	{"phone": "+70273640402"}
0005434024350	FBFBE8	3261 885279	IGOR DAVYDOV	{"email": "davydov_igor.1969@postgrespro.ru", "phone": "+70994927509"}
0005434024351	5D9D04	2335 620920	RAISA VLASOVA	{"email": "r_vlasova1976@postgrespro.ru", "phone": "+70540267741"}
0005434024352	5E2845	1896 619003	VLADIMIR KUZMIN	{"email": "kuzminv.021985@postgrespro.ru", "phone": "+70297959538"}
0005434024353	5E2845	0789 252676	DMITRIY SCHERBAKOV	{"phone": "+70011752838"}
0005434024354	3ABFD1	0856 110482	SERGEY VOLKOV	{"phone": "+70198383282"}
0005434024355	2A6D6C	5039 612432	TATYANA KONDRATEVA	{"email": "tatyana-kondrateva-011966@postgrespro.ru", "phone": "+70114862889"}
0005434024356	24F4AC	7653 080007	GALIYA POPOVA	{"email": "popovag20041960@postgrespro.ru", "phone": "+70992266688"}
0005434024357	275757	3256 809327	ALEKSANDRA ZAYCEVA	{"phone": "+70635280796"}
0005434024358	1F91F8	4140 074560	DENIS FILIPPOV	{"phone": "+70795980303"}
0005434024359	1F91F8	0115 936753	DANIIL MEDVEDEV	{"email": "medvedevdaniil1969@postgrespro.ru", "phone": "+70195139855"}
0005434024360	3EFA59	6477 542906	LARISA ALEKSEEVA	{"phone": "+70019283888"}
0005434024361	85846B	8419 627330	ANASTASIYA MOROZOVA	{"email": "a-morozova.051968@postgrespro.ru", "phone": "+70472692590"}
0005434024362	D74FF7	1695 075872	YAROSLAV KUZNECOV	{"email": "yaroslav_kuznecov-1972@postgrespro.ru", "phone": "+70455628400"}
0005434024363	D74FF7	7348 675664	OLGA DMITRIEVA	{"email": "dmitrieva_olga20031969@postgrespro.ru", "phone": "+70833423276"}
0005434024364	4B84CC	2818 912119	ALEKSEY GERASIMOV	{"phone": "+70338986718"}
0005434024365	732552	5300 317098	MAKSIM EGOROV	{"phone": "+70646921046"}
0005434024366	732552	8828 110331	MARINA AKIMOVA	{"phone": "+70360374407"}
0005434024367	FFBDBE	6037 089496	ANNA SOKOLOVA	{"email": "sokolovaanna1978@postgrespro.ru", "phone": "+70055072920"}
0005434024368	FFBDBE	4280 549270	MIKHAIL ALEKSANDROV	{"email": "mikhail.aleksandrov-081971@postgrespro.ru", "phone": "+70271668841"}
0005434024369	BD23CC	0366 541868	EKATERINA NAZAROVA	{"email": "nazarovae.1975@postgrespro.ru", "phone": "+70935513806"}
0005434024370	BD23CC	4392 245476	VLADIMIR ABRAMOV	{"email": "abramov.vladimir_081972@postgrespro.ru", "phone": "+70810376774"}
0005434024371	040AB6	8686 760628	OLGA GAVRILOVA	{"phone": "+70728017245"}
0005434024372	34D963	3440 912513	VALENTINA TARASOVA	{"email": "tarasovavalentina-111981@postgrespro.ru", "phone": "+70178672181"}
0005434024373	34D963	2950 115206	VLADIMIR MELNIKOV	{"email": "melnikov_vladimir-01021965@postgrespro.ru", "phone": "+70922743524"}
0005434024374	AB0F57	5836 030987	EKATERINA KUZMINA	{"email": "e_kuzmina-1973@postgrespro.ru", "phone": "+70686562770"}
0005434024375	58C60B	1485 464019	ROBERT MAKAROV	{"phone": "+70169394862"}
0005434024376	7504C8	5479 672306	VITALIY NOVIKOV	{"email": "novikov.vitaliy.011963@postgrespro.ru", "phone": "+70495094317"}
0005434024377	129370	8081 928381	VLADIMIR EGOROV	{"phone": "+70054385592"}
0005434024378	78F8A5	5896 705321	NATALYA KOROLEVA	{"phone": "+70146962146"}
0005434024379	78F8A5	9542 423285	GENNADIY ANDREEV	{"email": "gennadiy-andreev011986@postgrespro.ru", "phone": "+70366115692"}
0005434024380	8FDCAF	6168 776845	NADEZHDA NIKOLAEVA	{"phone": "+70415075495"}
0005434024381	160AA1	5559 131827	EKATERINA DMITRIEVA	{"email": "dmitrievaekaterina1976@postgrespro.ru", "phone": "+70613651254"}
0005434024382	160AA1	0429 019212	OKSANA IVANOVA	{"phone": "+70680656063"}
0005434024383	71703B	5759 025416	NINA MOISEEVA	{"email": "ninamoiseeva-06021980@postgrespro.ru", "phone": "+70667873647"}
0005434024384	191DEE	5244 832993	EVGENIYA VLASOVA	{"email": "evgeniya_vlasova_1964@postgrespro.ru", "phone": "+70854645369"}
0005434024385	E31CCF	7908 285429	NATALYA ANDREEVA	{"email": "natalya.andreeva1959@postgrespro.ru", "phone": "+70993844943"}
0005434024386	333FA4	1249 434522	TIMUR BORISOV	{"phone": "+70919108364"}
0005434024387	2F9D31	2169 561022	MIKHAIL BONDARENKO	{"email": "bondarenko.m21111973@postgrespro.ru", "phone": "+70350379553"}
0005434024388	2F9D31	6490 536317	TATYANA SOROKINA	{"email": "sorokinatatyana05031971@postgrespro.ru", "phone": "+70875880363"}
0005434024389	2F9D31	8377 256868	ARINA ISAEVA	{"phone": "+70412903982"}
0005434024390	261660	8252 654820	OKSANA NAUMOVA	{"email": "naumova.oksana.091973@postgrespro.ru", "phone": "+70240179411"}
0005434024391	261660	8563 034263	KLIM KUZNECOV	{"email": "kuznecov-k.27101967@postgrespro.ru", "phone": "+70669591890"}
0005434024392	1B6A1C	5461 601416	OLEG PETROV	{"phone": "+70611595273"}
0005434024393	680369	2439 211185	KONSTANTIN VOROBEV	{"phone": "+70278722213"}
0005434024394	680369	1715 714444	ARTEM GERASIMOV	{"email": "gerasimov.artem_15101963@postgrespro.ru", "phone": "+70015587195"}
0005434024395	680369	5289 626564	LARISA KOROLEVA	{"email": "larisa.koroleva1970@postgrespro.ru", "phone": "+70973106934"}
0005434024396	3E8EBA	0123 555770	NADEZHDA FILIPPOVA	{"phone": "+70384422481"}
0005434024397	3E8EBA	9835 696145	TATYANA KARPOVA	{"email": "karpova-t_1977@postgrespro.ru", "phone": "+70296507947"}
0005434024398	4878C0	8723 504702	TATYANA SERGEEVA	{"email": "sergeeva-tatyana04121963@postgrespro.ru", "phone": "+70328376554"}
0005434024399	ED5414	1191 749112	ALEKSANDR MELNIKOV	{"phone": "+70762249362"}
0005434024400	216502	8256 251846	ALEKSANDR VASILEV	{"phone": "+70590997825"}
0005434024401	506211	7884 259257	ALEKSANDR NAZAROV	{"email": "nazarov_a_021972@postgrespro.ru", "phone": "+70816394347"}
0005434024402	6D183E	0837 357466	MARIYA MAKAROVA	{"email": "makarova_mariya-021976@postgrespro.ru", "phone": "+70391723490"}
0005434024403	0FFC47	8631 383208	TATYANA CHERNOVA	{"email": "t-chernova.021976@postgrespro.ru", "phone": "+70584966915"}
0005434024404	89E183	4074 967563	OLEG MELNIKOV	{"phone": "+70014021774"}
0005434024405	89E183	2862 998073	MARIYA TARASOVA	{"email": "tarasova-mariya16031984@postgrespro.ru", "phone": "+70679394927"}
0005434024406	78D539	4387 715931	VLADISLAV RODIONOV	{"phone": "+70248239630"}
0005434024407	78D539	8768 483700	IVAN GORBUNOV	{"email": "i_gorbunov1968@postgrespro.ru", "phone": "+70975668243"}
0005434024408	639B63	4716 539013	NATALYA BELOVA	{"email": "belova-natalya_06091978@postgrespro.ru", "phone": "+70687019450"}
0005434024409	C25642	8317 785587	OLEG ABRAMOV	{"phone": "+70903140111"}
0005434024410	C6D926	9128 054459	RAISA FILATOVA	{"phone": "+70525381493"}
0005434024411	C6D926	1153 042267	YURIY RODIONOV	{"phone": "+70541801311"}
0005434024412	C6D926	1356 958055	MAKSIM SCHERBAKOV	{"phone": "+70351586657"}
0005434024413	C9E48B	8853 684854	ANDREY ZAKHAROV	{"phone": "+70454763945"}
0005434024414	CBB2BF	0392 468222	VIKTOR IVANOV	{"email": "ivanovviktor14011977@postgrespro.ru", "phone": "+70756281887"}
0005434024415	F79688	8929 680905	PRASKOVYA ZAYCEVA	{"email": "p.zayceva-14031964@postgrespro.ru", "phone": "+70764755722"}
0005434024416	5B8AD2	4083 760068	VASILIY KUZNECOV	{"email": "vkuznecov_051976@postgrespro.ru", "phone": "+70163106216"}
0005434024417	573953	1135 415309	FAIL TARASOV	{"phone": "+70270450933"}
0005434024418	48A1EB	7848 290825	VALENTINA YAKOVLEVA	{"email": "valentina_yakovleva1970@postgrespro.ru", "phone": "+70352766800"}
0005434024419	9F28A2	7981 852414	TAMARA GERASIMOVA	{"phone": "+70258167098"}
0005434024420	C315D9	7831 595698	VYACHESLAV ALEKSEEV	{"email": "vyacheslav.alekseev-1978@postgrespro.ru", "phone": "+70420240348"}
0005434024421	C315D9	6745 981529	NIKOLAY GORBUNOV	{"email": "nikolaygorbunov.1961@postgrespro.ru", "phone": "+70554726621"}
0005434024422	C315D9	2902 054566	VALENTINA ROMANOVA	{"phone": "+70285470793"}
0005434024423	C21E09	2614 386671	YURIY ROMANOV	{"phone": "+70104101835"}
0005434024424	EB520B	4996 733248	NATALYA MEDVEDEVA	{"email": "natalya_medvedeva29101966@postgrespro.ru", "phone": "+70467730974"}
0005434024425	26B3C7	3189 068835	IVAN SCHERBAKOV	{"email": "i_scherbakov1968@postgrespro.ru", "phone": "+70688385499"}
0005434024426	ECA09D	9911 242974	VALENTINA FROLOVA	{"email": "valentinafrolova061970@postgrespro.ru", "phone": "+70817879366"}
0005434024427	840FE2	7869 990323	ALEFTINA KUZMINA	{"email": "aleftina_kuzmina_12071970@postgrespro.ru", "phone": "+70183427958"}
0005434024428	D03406	6024 643694	DMITRIY PAVLOV	{"email": "dmitriypavlov_061978@postgrespro.ru", "phone": "+70654539286"}
0005434024429	D03406	5365 442749	ALEKSANDR SAVELEV	{"email": "a-savelev_121968@postgrespro.ru", "phone": "+70650997700"}
0005434024430	AB6CF3	7572 220629	LIDIYA POTAPOVA	{"email": "lidiya-potapova.05061975@postgrespro.ru", "phone": "+70529239471"}
0005434024431	AB6CF3	1406 559077	VIKTORIYA BORISOVA	{"email": "vborisova061985@postgrespro.ru", "phone": "+70467416867"}
0005434024432	7CC59A	6971 266028	ALISA VOLKOVA	{"email": "alisa_volkova.31011979@postgrespro.ru", "phone": "+70505729779"}
0005434024433	7CC59A	1346 453946	VIKTOR DMITRIEV	{"email": "viktordmitriev01061972@postgrespro.ru", "phone": "+70319622016"}
0005434024434	2DC828	9587 821031	DARYA VOROBEVA	{"phone": "+70127579149"}
0005434024435	2DC828	0417 913296	EVDOKIYA DENISOVA	{"email": "evdokiya-denisova.19091967@postgrespro.ru", "phone": "+70526812317"}
0005434024436	F31F03	7765 305484	LYUDMILA SERGEEVA	{"phone": "+70549361213"}
0005434024437	F31F03	8880 620284	VLADIMIR ZAKHAROV	{"email": "v_zakharov_111984@postgrespro.ru", "phone": "+70070861500"}
0005434024438	66A722	7170 934263	NADEZHDA KAZAKOVA	{"phone": "+70636381525"}
0005434024439	AA2F08	1167 666789	POLINA KOZLOVA	{"email": "p-kozlova.101971@postgrespro.ru", "phone": "+70017438625"}
0005434024440	74CF59	9720 877879	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova_121981@postgrespro.ru", "phone": "+70682776531"}
0005434024441	74CF59	3639 833830	NIKOLAY FEDOROV	{"email": "nikolay-fedorov01031969@postgrespro.ru", "phone": "+70716727487"}
0005434024442	DBD3C9	5361 665082	ALEKSANDR FEDOTOV	{"phone": "+70323148272"}
0005434024443	70709D	5197 876858	ALEKSANDR VASILEV	{"email": "vasileva.15011971@postgrespro.ru", "phone": "+70516309392"}
0005434024444	70709D	0308 535469	VLADIMIR VOLKOV	{"email": "volkov-vladimir23091981@postgrespro.ru", "phone": "+70991116252"}
0005434024445	1B06BC	4707 766591	MARINA FROLOVA	{"email": "frolova-marina-111965@postgrespro.ru", "phone": "+70521964916"}
0005434024446	D04649	5351 971757	LIDIYA GORBUNOVA	{"email": "lidiyagorbunova051977@postgrespro.ru", "phone": "+70943166297"}
0005434024447	D04649	6334 823144	SERGEY DENISOV	{"phone": "+70353985488"}
0005434024448	620565	5870 430010	VASILIY KUZNECOV	{"email": "vasiliykuznecov021967@postgrespro.ru", "phone": "+70206161492"}
0005434024449	2F0B7D	1483 676816	ANNA MEDVEDEVA	{"phone": "+70231485012"}
0005434024450	25A7BC	3533 751650	SVETLANA EFIMOVA	{"email": "efimova.svetlana071969@postgrespro.ru", "phone": "+70804808276"}
0005434024451	25A7BC	1224 008028	VALENTINA SOROKINA	{"phone": "+70728929099"}
0005434024452	11A27C	4153 197535	VLADIMIR MOROZOV	{"email": "v_morozov-061976@postgrespro.ru", "phone": "+70110957975"}
0005434024453	5DD88C	9850 608534	MARIYA ZHURAVLEVA	{"email": "zhuravleva.mariya_111972@postgrespro.ru", "phone": "+70018316277"}
0005434024454	4C5148	1375 766602	IVAN KUZNECOV	{"email": "kuznecov-ivan.1979@postgrespro.ru", "phone": "+70868437405"}
0005434024455	8EE4F5	0401 957045	NIKITA KISELEV	{"email": "kiselevnikita_071979@postgrespro.ru", "phone": "+70972201716"}
0005434024456	E0BC8A	1669 743405	OLEG ILIN	{"phone": "+70602045610"}
0005434024457	9D8E63	4546 481356	VLADIMIR GAVRILOV	{"email": "v.gavrilov-111971@postgrespro.ru", "phone": "+70275294992"}
0005434024458	F38CAF	9598 510019	KRISTINA NOVIKOVA	{"email": "novikova_kristina_1969@postgrespro.ru", "phone": "+70188049319"}
0005434024459	677551	8412 516578	VITALIY KULIKOV	{"email": "kulikov.v11071962@postgrespro.ru", "phone": "+70064995349"}
0005434024460	F6CC69	6136 449731	YULIYA ANISIMOVA	{"email": "anisimova.y.031972@postgrespro.ru", "phone": "+70033426912"}
0005434024461	B5D698	2656 897054	NINA SMIRNOVA	{"email": "smirnova.nina_041985@postgrespro.ru", "phone": "+70913177091"}
0005434024462	D02E0B	6357 658430	VLADIMIR MAKSIMOV	{"email": "maksimovv.08111968@postgrespro.ru", "phone": "+70048297219"}
0005434024463	A6ED2D	7444 525264	YURIY YAKOVLEV	{"email": "y.yakovlev_14111960@postgrespro.ru", "phone": "+70254060638"}
0005434024464	9445FF	0438 973224	IRINA LEBEDEVA	{"phone": "+70337126776"}
0005434024465	87A75A	8516 654298	VIKTORIYA PETROVA	{"email": "viktoriya-petrova-1977@postgrespro.ru", "phone": "+70142799641"}
0005434024466	0DDA7A	7177 600276	KSENIYA ORLOVA	{"email": "korlova_1972@postgrespro.ru", "phone": "+70559084536"}
0005434024467	0DDA7A	7858 780168	TATYANA TARASOVA	{"phone": "+70921240186"}
0005434024468	3DEC40	5090 552998	ALEKSEY ALEKSANDROV	{"phone": "+70132106771"}
0005434024469	3DEC40	6468 166188	ANNA KUZMINA	{"email": "kuzminaa.29041958@postgrespro.ru", "phone": "+70874531095"}
0005434024470	BFD41F	3520 401302	EMIL MAKSIMOV	{"phone": "+70705755391"}
0005434024471	AC523A	1945 210899	ALEKSANDR BARANOV	{"phone": "+70917458091"}
0005434024473	2FDC3D	7065 852325	NATALYA KOVALEVA	{"phone": "+70505270186"}
0005434024474	9E13F7	6525 240968	LYUDMILA MAKSIMOVA	{"email": "l.maksimova-1977@postgrespro.ru", "phone": "+70977414952"}
0005434024475	9E13F7	7806 229379	ALEKSANDR IVANOV	{"email": "ivanovaleksandr021979@postgrespro.ru", "phone": "+70092040936"}
0005434024476	59B301	9855 575456	ALBINA RODIONOVA	{"phone": "+70920445960"}
0005434024477	FEE78F	3863 343909	OLGA MATVEEVA	{"phone": "+70351305408"}
0005434024478	48116F	6075 593020	KLAVDIYA STEPANOVA	{"email": "stepanova_klavdiya_061984@postgrespro.ru", "phone": "+70034374110"}
0005434024479	48116F	8527 082789	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy.28011970@postgrespro.ru", "phone": "+70832307984"}
0005434024480	E3A973	2771 139641	ELENA NIKITINA	{"email": "nikitina.elena.1969@postgrespro.ru", "phone": "+70465049350"}
0005434024481	427BF6	6881 012890	DMITRIY NIKITIN	{"phone": "+70954512008"}
0005434024482	427BF6	1641 092837	ELENA YAKOVLEVA	{"phone": "+70061367149"}
0005434024483	45073D	0566 333663	DMITRIY VASILEV	{"phone": "+70207016456"}
0005434024484	45073D	0271 427917	NADEZHDA KOMAROVA	{"email": "komarova_n-1966@postgrespro.ru", "phone": "+70811194135"}
0005434024485	41B299	8819 007480	OLEG NIKOLAEV	{"phone": "+70308678881"}
0005434024486	41B299	6085 295873	NATALYA SIDOROVA	{"phone": "+70936023916"}
0005434024487	F9AD3C	1296 558215	IRINA BELOVA	{"email": "belova.i-051975@postgrespro.ru", "phone": "+70408776451"}
0005434024488	60FEA6	0689 689516	ZINAIDA PAVLOVA	{"email": "pavlovazinaida-1982@postgrespro.ru", "phone": "+70518884000"}
0005434024489	6A84E2	3778 694817	NINA ANTONOVA	{"email": "ninaantonova1970@postgrespro.ru", "phone": "+70568541082"}
0005434024490	F18504	7054 537962	ALEKSEY MARTYNOV	{"email": "aleksey.martynov-061965@postgrespro.ru", "phone": "+70877843306"}
0005434024491	F18504	5368 826724	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev_31031968@postgrespro.ru", "phone": "+70413592936"}
0005434024492	F18504	0870 905593	ANATOLIY SEMENOV	{"phone": "+70108017212"}
0005434024493	26DF66	9865 254488	DMITRIY ROMANOV	{"phone": "+70894543295"}
0005434024494	26DF66	5579 533759	VIKTORIYA KUZNECOVA	{"phone": "+70488960022"}
0005434024495	7E7D17	7142 476069	VLADIMIR DAVYDOV	{"phone": "+70461907102"}
0005434024496	085A29	8481 867582	VLADIMIR TIMOFEEV	{"phone": "+70257720387"}
0005434024497	CC2A05	4722 328490	ILYA ROMANOV	{"phone": "+70776795680"}
0005434024498	A9A0E9	4294 338224	ELENA KUZNECOVA	{"phone": "+70235979973"}
0005434024499	3A3859	4596 258884	VIKTOR MIKHAYLOV	{"phone": "+70473605969"}
0005434024500	154AC1	8082 469345	ALEKSANDR PETROV	{"email": "petrov_aleksandr.101978@postgrespro.ru", "phone": "+70182052780"}
0005434024501	154AC1	6703 014313	VALERIYA GRISHINA	{"phone": "+70428221453"}
0005434024502	71FEC9	4493 586359	GALINA FILIPPOVA	{"email": "filippova_galina_1980@postgrespro.ru", "phone": "+70704999730"}
0005434024503	D93B07	2678 780986	IVAN MEDVEDEV	{"phone": "+70624965921"}
0005434024504	D93B07	5922 084820	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova_091970@postgrespro.ru", "phone": "+70627102960"}
0005434024505	5DB4D4	4390 424182	IRINA SERGEEVA	{"phone": "+70509319430"}
0005434024506	F47C6A	0848 893681	MAKSIM KUDRYASHOV	{"email": "m-kudryashov22081968@postgrespro.ru", "phone": "+70479519458"}
0005434024507	F47C6A	5389 083884	LYUBOV VASILEVA	{"email": "vasileva-lyubov_1979@postgrespro.ru", "phone": "+70423563516"}
0005434024508	0950AC	2160 870822	ANATOLIY ABRAMOV	{"email": "abramov-anatoliy29051977@postgrespro.ru", "phone": "+70788823983"}
0005434024509	4C017D	5359 073463	VALERIY MATVEEV	{"email": "v.matveev031978@postgrespro.ru", "phone": "+70537908045"}
0005434024510	4C017D	6167 421536	DMITRIY ANDREEV	{"email": "dmitriyandreev.26021962@postgrespro.ru", "phone": "+70203826904"}
0005434024511	F40E74	1976 309971	ALEKSEY OSIPOV	{"email": "aleksey-osipov24051970@postgrespro.ru", "phone": "+70772355409"}
0005434024512	F40E74	2601 068898	SERGEY PETROV	{"phone": "+70450374438"}
0005434024513	B30DAE	5715 497713	DARYA NAZAROVA	{"phone": "+70902983552"}
0005434024514	B30DAE	7181 680399	EVGENIY GAVRILOV	{"email": "gavrilov.evgeniy05021970@postgrespro.ru", "phone": "+70283972536"}
0005434024515	E9EBE7	6599 205571	VALERIY NIKOLAEV	{"phone": "+70909105907"}
0005434024516	DB82D4	9837 884738	NADEZHDA MAKSIMOVA	{"email": "maksimova_n-06101961@postgrespro.ru", "phone": "+70630111694"}
0005434024517	B7E0DA	5615 264830	LARISA KUZNECOVA	{"phone": "+70611485984"}
0005434024518	7B7207	5825 382723	TATYANA KONOVALOVA	{"phone": "+70921358178"}
0005434024519	7B7207	5068 857804	MURAT POPOV	{"email": "m.popov_091968@postgrespro.ru", "phone": "+70873871493"}
0005434024520	D5F8D1	6476 016032	POLINA STEPANOVA	{"email": "stepanova_polina09011972@postgrespro.ru", "phone": "+70635845514"}
0005434024521	DCC7CC	6598 070149	SERGEY EGOROV	{"email": "egorov_sergey.1970@postgrespro.ru", "phone": "+70013194370"}
0005434024522	EE91F8	7067 372387	SVETLANA FILATOVA	{"phone": "+70723212739"}
0005434024523	8EEAD4	4296 183997	DANIIL SOROKIN	{"phone": "+70550118128"}
0005434024524	B5F8BF	1828 586913	ELENA ZHUKOVA	{"email": "zhukova_elena071973@postgrespro.ru", "phone": "+70577881153"}
0005434024525	93CCE8	2745 699701	POLINA BOGDANOVA	{"phone": "+70190807378"}
0005434024526	93CCE8	2523 288301	VALENTIN MIRONOV	{"phone": "+70012546546"}
0005434024527	982091	5715 967153	ANTONINA GAVRILOVA	{"phone": "+70307031963"}
0005434024528	982091	9013 373929	ALEKSEY GERASIMOV	{"phone": "+70739754347"}
0005434024529	84E21C	6845 974831	GALINA MIKHAYLOVA	{"phone": "+70504538851"}
0005434024530	84E21C	2974 606690	VLADIMIR SEMENOV	{"email": "vladimir.semenov_21031978@postgrespro.ru", "phone": "+70602982726"}
0005434024531	29F9A7	9787 689344	KIRILL MELNIKOV	{"email": "melnikov_kirill_061971@postgrespro.ru", "phone": "+70237760801"}
0005434024532	29F9A7	1263 680758	VERA YAKOVLEVA	{"phone": "+70725986682"}
0005434024533	E6D4E0	6946 414480	NIKOLAY DENISOV	{"email": "nikolay-denisov1972@postgrespro.ru", "phone": "+70803848889"}
0005434024534	E6D4E0	3080 965763	LEONID TARASOV	{"email": "tarasovleonid_081984@postgrespro.ru", "phone": "+70536234708"}
0005434024535	2B3BDF	9118 435203	ROMAN SOKOLOV	{"email": "sokolov-r-1967@postgrespro.ru", "phone": "+70918740731"}
0005434024536	9D8FDF	2999 120311	NIKOLAY FILIPPOV	{"phone": "+70199911032"}
0005434024537	9D8FDF	2898 952439	NIKOLAY ZHUKOV	{"phone": "+70451952855"}
0005434024538	A1D4D4	6945 124235	TAMARA KULIKOVA	{"phone": "+70327588329"}
0005434024539	E7FDB7	7511 290584	VALERIY SEMENOV	{"phone": "+70641875118"}
0005434024540	E7FDB7	6814 326392	SERGEY SIDOROV	{"email": "sidorov.sergey_11061971@postgrespro.ru", "phone": "+70469312812"}
0005434024541	87FA95	7299 420768	OLGA KOROLEVA	{"email": "koroleva_olga_1965@postgrespro.ru", "phone": "+70663734212"}
0005434024542	2FCA9C	6636 729451	GALIYA FOMINA	{"email": "fomina.galiya19091983@postgrespro.ru", "phone": "+70247157573"}
0005434024543	9D138E	7826 242861	ARTEM MIRONOV	{"phone": "+70229690185"}
0005434024544	819474	7947 131774	VASILIY SEMENOV	{"email": "vasiliy.semenov.041980@postgrespro.ru", "phone": "+70795829312"}
0005434024545	819474	1265 768762	DANIL PETROV	{"email": "petrov_d_011977@postgrespro.ru", "phone": "+70408996526"}
0005434024546	9CFF5A	7643 426482	ANNA FEDOROVA	{"email": "a.fedorova30061980@postgrespro.ru", "phone": "+70593048466"}
0005434024547	23D174	6544 108933	OLGA MAKAROVA	{"email": "makarova-o-05081971@postgrespro.ru", "phone": "+70989545001"}
0005434024548	23D174	9591 835172	LEONID FOMIN	{"email": "fominleonid_24031975@postgrespro.ru", "phone": "+70790225059"}
0005434024549	FE4086	8956 884733	NATALYA NESTEROVA	{"phone": "+70498276115"}
0005434024550	147F35	6070 590029	MARINA IVANOVA	{"phone": "+70776046490"}
0005434024551	147F35	1460 472664	VLADIMIR AFANASEV	{"phone": "+70681918518"}
0005434024552	3F6209	8411 573095	ARINA KOMAROVA	{"email": "komarova-a_011959@postgrespro.ru", "phone": "+70675650356"}
0005434024553	28B4AA	6015 278239	PETR KISELEV	{"email": "p-kiselev-28051975@postgrespro.ru", "phone": "+70559463698"}
0005434024554	28B4AA	6647 505450	ALEKSANDR RODIONOV	{"phone": "+70665785797"}
0005434024555	89B623	7628 322456	ANASTASIYA BARANOVA	{"phone": "+70376316769"}
0005434024556	37413C	8022 821032	INNA KARPOVA	{"phone": "+70157488120"}
0005434024557	37413C	0533 342232	OLGA GORBUNOVA	{"phone": "+70572159867"}
0005434024558	EDDAC0	8182 798547	OLEG TARASOV	{"phone": "+70473752323"}
0005434024559	4A773F	7782 344728	NIKOLAY ZAKHAROV	{"email": "zakharov.n_1971@postgrespro.ru", "phone": "+70409058501"}
0005434024560	4A773F	5979 697507	VALERIYA DANILOVA	{"email": "v-danilova.031971@postgrespro.ru", "phone": "+70875917300"}
0005434024561	132A55	3320 386385	MADINA KISELEVA	{"email": "kiseleva-madina25111963@postgrespro.ru", "phone": "+70278290365"}
0005434024562	02211E	2427 571425	ANASTASIYA LEBEDEVA	{"email": "alebedeva-061969@postgrespro.ru", "phone": "+70978003207"}
0005434024563	02211E	7240 561886	VERA SOROKINA	{"email": "vera_sorokina051988@postgrespro.ru", "phone": "+70633126578"}
0005434024564	AEC95F	4004 034236	DMITRIY ALEKSEEV	{"phone": "+70218162601"}
0005434024565	8C1EB3	9048 337012	EVGENIY ABRAMOV	{"email": "e-abramov-17031979@postgrespro.ru", "phone": "+70021400855"}
0005434024566	4472BC	3934 140782	ALEKSEY ORLOV	{"phone": "+70505073456"}
0005434024567	4472BC	1702 668067	EVGENIYA NOVIKOVA	{"email": "novikova.evgeniya_1973@postgrespro.ru", "phone": "+70409235615"}
0005434024568	88C7EA	9258 691919	ANTON AFANASEV	{"phone": "+70599937712"}
0005434024569	88C7EA	3521 373502	EVGENIY MARTYNOV	{"phone": "+70984711510"}
0005434024570	7CC205	6290 055334	ANNA FILIPPOVA	{"email": "filippova.a_22021986@postgrespro.ru", "phone": "+70018205243"}
0005434024571	10F1CD	6645 029640	ILYA BONDARENKO	{"phone": "+70018287551"}
0005434024572	0C1D1A	5003 407299	NATALYA KOROLEVA	{"email": "koroleva.natalya.061968@postgrespro.ru", "phone": "+70963875322"}
0005434024573	89ED6B	8818 693032	MAKSIM KUZMIN	{"phone": "+70572763760"}
0005434024574	89ED6B	2932 054874	ANNA MIRONOVA	{"email": "a_mironova_1979@postgrespro.ru", "phone": "+70697167127"}
0005434024575	89ED6B	6254 103262	TATYANA FEDOROVA	{"email": "fedorova-tatyana.02111968@postgrespro.ru", "phone": "+70211065677"}
0005434024576	B054E8	1504 512988	OLEG DENISOV	{"email": "oleg-denisov.26041964@postgrespro.ru", "phone": "+70210371205"}
0005434024577	B054E8	5729 985316	NATALYA DMITRIEVA	{"email": "n_dmitrieva11051977@postgrespro.ru", "phone": "+70524049945"}
0005434024578	B054E8	0767 207192	DARYA MELNIKOVA	{"email": "darya.melnikova_1965@postgrespro.ru", "phone": "+70114066530"}
0005434024579	EE16F2	3977 306106	GULNAZ IVANOVA	{"email": "ivanova.gulnaz1972@postgrespro.ru", "phone": "+70735400680"}
0005434024580	EE16F2	5179 156813	MATVEY ZHUKOV	{"phone": "+70081773938"}
0005434024581	D06DD5	7085 514156	ELENA ANTONOVA	{"phone": "+70255051958"}
0005434024582	EF405C	1082 826788	YANA SIDOROVA	{"email": "sidorovay.1965@postgrespro.ru", "phone": "+70582160849"}
0005434024583	EF405C	4611 674053	VALENTINA KALININA	{"email": "v-kalinina-23011971@postgrespro.ru", "phone": "+70434894765"}
0005434024584	9C3DC8	6813 347873	YURIY MELNIKOV	{"phone": "+70230663841"}
0005434024585	9C3DC8	9823 336439	MARIYA RODIONOVA	{"email": "rodionovam_13121966@postgrespro.ru", "phone": "+70306276846"}
0005434024586	B7749E	6962 250641	ZOYA LEBEDEVA	{"email": "zoya-lebedeva09121975@postgrespro.ru", "phone": "+70787867921"}
0005434024587	B7749E	0672 627537	KONSTANTIN ANDREEV	{"phone": "+70561277385"}
0005434024588	E7073B	1265 474030	GALINA ERMAKOVA	{"phone": "+70260380688"}
0005434024589	6264B2	4759 450498	VLADIMIR NIKOLAEV	{"phone": "+70889096727"}
0005434024590	0072B1	4683 374436	ANATOLIY DENISOV	{"email": "a.denisov05051967@postgrespro.ru", "phone": "+70110271016"}
0005434024591	5E3C7A	0788 489091	ALEKSANDR SEMENOV	{"phone": "+70548369730"}
0005434024592	A2E76E	9033 185392	VYACHESLAV ZAKHAROV	{"phone": "+70548431963"}
0005434024593	C1D388	5211 232219	NATALYA STEPANOVA	{"phone": "+70344090154"}
0005434024594	17A2AC	0006 206037	EKATERINA KOLESNIKOVA	{"phone": "+70120320278"}
0005434024595	2ED9AC	1731 624617	RUSLAN ILIN	{"email": "rilin1979@postgrespro.ru", "phone": "+70726613185"}
0005434024596	6F6912	4736 475932	MARINA MEDVEDEVA	{"email": "mmedvedeva101962@postgrespro.ru", "phone": "+70118786354"}
0005434024597	6ED620	0142 342266	SERGEY KAZAKOV	{"email": "sergey.kazakov081970@postgrespro.ru", "phone": "+70165405706"}
0005434024598	57B4FE	3033 813377	ALEKSANDRA BORISOVA	{"email": "a_borisova.13071972@postgrespro.ru", "phone": "+70419059113"}
0005434024599	1366FA	2298 397369	ALENA DMITRIEVA	{"phone": "+70260121597"}
0005434024600	1366FA	2790 355471	RAILYA KOMAROVA	{"email": "komarovar.1970@postgrespro.ru", "phone": "+70650447955"}
0005434024601	1366FA	8009 306916	ANDREY STEPANOV	{"email": "a_stepanov-1974@postgrespro.ru", "phone": "+70846587219"}
0005434024602	A4B859	0770 177453	YURIY VOLKOV	{"email": "y-volkov.081973@postgrespro.ru", "phone": "+70727414572"}
0005434024603	5CC886	3809 594155	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova_natalya1970@postgrespro.ru", "phone": "+70676191017"}
0005434024604	DC2EB4	8095 412206	DMITRIY KARPOV	{"phone": "+70333345959"}
0005434024605	2CF30F	8853 426505	ANATOLIY BORISOV	{"phone": "+70415597062"}
0005434024606	2CF30F	6063 692660	OLEG KUZMIN	{"email": "o.kuzmin.1969@postgrespro.ru", "phone": "+70422580343"}
0005434024607	261F04	6628 047512	ALEKSANDR SIDOROV	{"phone": "+70086313547"}
0005434024608	E14E91	5031 680035	ALEKSANDR KOROLEV	{"phone": "+70989572037"}
0005434024609	E14E91	2074 950093	ELIZAVETA MAKSIMOVA	{"phone": "+70701907895"}
0005434024610	2719E9	6629 826016	OLGA ALEKSEEVA	{"phone": "+70804876864"}
0005434024611	337082	3259 675104	RAVILYA KISELEVA	{"email": "r_kiseleva-26041978@postgrespro.ru", "phone": "+70179934667"}
0005434024612	4805BD	9762 248685	DMITRIY NAZAROV	{"phone": "+70079175355"}
0005434024613	6ECCF7	2864 044906	DARYA VASILEVA	{"phone": "+70033767892"}
0005434024614	6ECCF7	3282 011353	TATYANA MAKAROVA	{"phone": "+70056935456"}
0005434024615	6444E5	9363 410129	VLADIMIR MARTYNOV	{"phone": "+70438147157"}
0005434024616	8C3527	6333 279728	ELENA SCHERBAKOVA	{"phone": "+70999446072"}
0005434024617	F07580	3642 869979	GALINA GORBUNOVA	{"email": "gorbunovag_15061978@postgrespro.ru", "phone": "+70450946146"}
0005434024618	CE022D	8147 368647	ANASTASIYA NESTEROVA	{"phone": "+70083572717"}
0005434024619	6E5356	8294 077993	VITALIY AFANASEV	{"phone": "+70656756668"}
0005434024620	2E808F	4387 441605	ALEKSANDR SIDOROV	{"phone": "+70467181874"}
0005434024621	01CEED	9948 338758	EVGENIY FROLOV	{"email": "e_frolov.081965@postgrespro.ru", "phone": "+70993596811"}
0005434024622	673BBE	2745 607995	VITALIY ABRAMOV	{"phone": "+70062348849"}
0005434024623	71587A	0481 702880	VITALIY SIDOROV	{"email": "sidorov.v_031966@postgrespro.ru", "phone": "+70065927326"}
0005434024624	5A91A1	8331 090180	VALENTIN CHERNOV	{"phone": "+70462065200"}
0005434024625	5A91A1	8310 646098	VALERIY SEMENOV	{"email": "valeriy-semenov.31081964@postgrespro.ru", "phone": "+70791695642"}
0005434024626	594EBE	7010 071135	GALINA MOROZOVA	{"email": "galina_morozova.101969@postgrespro.ru", "phone": "+70143161379"}
0005434024627	594EBE	6732 376730	VLADIMIR SOROKIN	{"phone": "+70545419636"}
0005434024628	A27C15	8190 906787	LIDIYA LAZAREVA	{"email": "llazareva.041973@postgrespro.ru", "phone": "+70174315135"}
0005434024629	B5E317	0064 442437	SERGEY ABRAMOV	{"phone": "+70936023449"}
0005434024630	2BD6C8	2510 352276	VLADIMIR FOMIN	{"email": "vladimir-fomin071975@postgrespro.ru", "phone": "+70246388248"}
0005434024631	2BD6C8	1537 648884	GALINA KUZNECOVA	{"email": "kuznecova.galina-1984@postgrespro.ru", "phone": "+70838035102"}
0005434024632	83BE4C	3483 584435	ELENA KUZMINA	{"phone": "+70331404949"}
0005434024633	246DE8	6882 490756	SVETLANA VLASOVA	{"phone": "+70456635012"}
0005434024634	44813C	5618 928476	NATALYA IVANOVA	{"phone": "+70702194656"}
0005434024635	87A165	3383 675037	VLADIMIR SAVELEV	{"email": "v_savelev13121974@postgrespro.ru", "phone": "+70320711273"}
0005434024636	87A165	1161 702762	IRINA KOZLOVA	{"email": "kozlova.i_071965@postgrespro.ru", "phone": "+70623099504"}
0005434024637	9ADF32	5936 708639	SERGEY POPOV	{"phone": "+70051723371"}
0005434024638	342CA7	2158 338598	ALENA SOROKINA	{"phone": "+70029435607"}
0005434024639	971B26	2972 347308	VLADIMIR BORISOV	{"phone": "+70750465772"}
0005434024640	2D157C	1598 688625	VLADIMIR KRASNOV	{"phone": "+70431824245"}
0005434024641	7532D9	4185 365784	DENIS SOROKIN	{"phone": "+70913158894"}
0005434024642	754AE9	2490 343414	ANASTASIYA PETROVA	{"email": "petrova.anastasiya-1980@postgrespro.ru", "phone": "+70317024221"}
0005434024643	C598C0	7821 523725	MARIYA ANTONOVA	{"phone": "+70949168176"}
0005434024644	C598C0	9517 223181	SVETLANA SEMENOVA	{"email": "semenovasvetlana-061972@postgrespro.ru", "phone": "+70954447175"}
0005434024645	17A8ED	8015 919455	ANNA IVANOVA	{"email": "anna-ivanova_121975@postgrespro.ru", "phone": "+70529676623"}
0005434024646	25459A	5092 586470	PETR SCHERBAKOV	{"phone": "+70631054539"}
0005434024647	25459A	1598 054692	ALEKSANDR ALEKSEEV	{"email": "a-alekseev-23111973@postgrespro.ru", "phone": "+70742974300"}
0005434024648	42E247	6988 580546	OLGA ABRAMOVA	{"phone": "+70755105868"}
0005434024649	42E247	2416 961963	VASILIY EGOROV	{"email": "vegorov_09041973@postgrespro.ru", "phone": "+70096316882"}
0005434024650	92D248	3023 198973	NINA YUDINA	{"email": "nina_yudina1981@postgrespro.ru", "phone": "+70838099535"}
0005434024651	92D248	0038 789420	DMITRIY DAVYDOV	{"email": "dmitriy_davydov.051985@postgrespro.ru", "phone": "+70546925045"}
0005434024652	07688A	3083 965045	YURIY SOROKIN	{"email": "sorokinyuriy111971@postgrespro.ru", "phone": "+70663079899"}
0005434024653	5F569D	2570 413993	VALENTINA MELNIKOVA	{"phone": "+70412819195"}
0005434024654	BBCA2D	8764 895544	ZINAIDA TIKHONOVA	{"phone": "+70397758052"}
0005434024655	5E0059	3079 944420	SVETLANA BOGDANOVA	{"email": "s-bogdanova.15041967@postgrespro.ru", "phone": "+70001486145"}
0005434024656	81C578	2846 115940	VITALIY NAUMOV	{"email": "naumovvitaliy_031972@postgrespro.ru", "phone": "+70768689913"}
0005434024657	DC5CE5	5995 727749	NATALYA SERGEEVA	{"email": "sergeevan-1959@postgrespro.ru", "phone": "+70590916385"}
0005434024658	57A6FD	6648 875896	IGOR NOVIKOV	{"email": "inovikov_17011968@postgrespro.ru", "phone": "+70845966920"}
0005434024659	6C2C7C	0744 832615	TIMOFEY IVANOV	{"phone": "+70236381683"}
0005434024660	5C2C69	1706 691434	NIKOLAY TARASOV	{"email": "tarasov-nikolay.28041965@postgrespro.ru", "phone": "+70719516020"}
0005434024661	CAE992	3479 601692	KAROLINA NAUMOVA	{"email": "naumova_karolina_1979@postgrespro.ru", "phone": "+70026056383"}
0005434024662	299BB2	4460 642032	GALINA MIRONOVA	{"phone": "+70473372988"}
0005434024663	9802B5	7183 457543	ALEKSANDR VOLKOV	{"email": "a.volkov_22061967@postgrespro.ru", "phone": "+70300714380"}
0005434024664	9802B5	5458 882311	ILYA KUZNECOV	{"phone": "+70382810467"}
0005434024665	AA6BB6	6081 502250	ELENA NIKIFOROVA	{"email": "elena-nikiforova_041968@postgrespro.ru", "phone": "+70754765867"}
0005434024666	620321	6121 751630	LIDIYA SAVELEVA	{"phone": "+70218481288"}
0005434024667	F1E573	3501 475017	DIANA KONDRATEVA	{"phone": "+70089657165"}
0005434024668	F1E573	5442 331846	TATYANA MOROZOVA	{"email": "t-morozova.08071968@postgrespro.ru", "phone": "+70803218339"}
0005434024669	C167A4	9878 491502	SVETLANA ZAKHAROVA	{"phone": "+70162267346"}
0005434024670	CD993C	7443 011566	ALENA SMIRNOVA	{"email": "alena-smirnova_071970@postgrespro.ru", "phone": "+70275068344"}
0005434024671	6B3D1A	9333 199934	OLGA SOLOVEVA	{"phone": "+70359817119"}
0005434024672	6B3D1A	5572 255725	YURIY SAVELEV	{"email": "yuriy_savelev_121975@postgrespro.ru", "phone": "+70207443066"}
0005434024673	3DC317	7131 724519	LYUBOV DENISOVA	{"email": "denisova_lyubov_1975@postgrespro.ru", "phone": "+70469614172"}
0005434024674	E9774F	5239 588502	VASILIY AFANASEV	{"phone": "+70051603080"}
0005434024675	C36562	7049 607290	SVETLANA ZHURAVLEVA	{"email": "zhuravleva.s09101975@postgrespro.ru", "phone": "+70642375020"}
0005434024676	CDC694	9067 585699	OLGA RODIONOVA	{"email": "o.rodionova-15111973@postgrespro.ru", "phone": "+70783656124"}
0005434024677	E22805	1500 302977	GALINA PETROVA	{"phone": "+70592812171"}
0005434024678	2AF440	6510 264997	LYUDMILA SEMENOVA	{"phone": "+70017623389"}
0005434024679	2AF440	9462 003929	IRINA ORLOVA	{"phone": "+70774349889"}
0005434024680	68EDC1	2677 593428	DIANA KUZNECOVA	{"phone": "+70702316618"}
0005434024681	68EDC1	5226 793434	POLINA ALEKSANDROVA	{"email": "aleksandrova_p011978@postgrespro.ru", "phone": "+70247957414"}
0005434024682	68EDC1	1883 038888	NIKOLAY ZHUKOV	{"phone": "+70071051682"}
0005434024683	6290EF	5449 801608	VALENTINA MATVEEVA	{"phone": "+70310925017"}
0005434024684	6290EF	7676 303454	MARINA ZAKHAROVA	{"phone": "+70840196898"}
0005434024685	281F92	9831 243800	VLADISLAV PETROV	{"email": "petrov-vladislav051967@postgrespro.ru", "phone": "+70052526617"}
0005434024686	F0DADE	3639 778773	MIKHAIL KULIKOV	{"email": "mkulikov_021974@postgrespro.ru", "phone": "+70742524519"}
0005434024687	B32B67	8731 985337	LYUDMILA NOVIKOVA	{"email": "novikoval031973@postgrespro.ru", "phone": "+70006126891"}
0005434024688	B32B67	3701 174006	NADEZHDA POLYAKOVA	{"phone": "+70811910685"}
0005434024689	1BB46A	7110 410541	ANNA TIMOFEEVA	{"phone": "+70796456443"}
0005434024690	C39CE8	2112 387163	ROMAN NAZAROV	{"email": "r_nazarov-1973@postgrespro.ru", "phone": "+70417005594"}
0005434024691	C39CE8	8600 588483	ARTEM KULIKOV	{"email": "kulikov-artem.1976@postgrespro.ru", "phone": "+70248371323"}
0005434024692	B8826E	6115 963217	ALEKSANDR ANDREEV	{"email": "a_andreev.21071982@postgrespro.ru", "phone": "+70085666299"}
0005434024693	B8826E	1640 722901	MAGOMED MEDVEDEV	{"email": "m_medvedev-1969@postgrespro.ru", "phone": "+70343611977"}
0005434024694	CF1A6B	6629 449868	TATYANA AKIMOVA	{"phone": "+70830838915"}
0005434024695	CF1A6B	3234 970839	VITALIY TIMOFEEV	{"phone": "+70213995312"}
0005434024696	2A0107	5500 146351	DMITRIY SOLOVEV	{"phone": "+70125265977"}
0005434024697	C52B9B	5328 390514	ARTEM NAZAROV	{"email": "artemnazarov_101977@postgrespro.ru", "phone": "+70720790834"}
0005434024698	7DCC4C	7803 501398	TATYANA DMITRIEVA	{"email": "dmitrieva_tatyana.16011984@postgrespro.ru", "phone": "+70734174847"}
0005434024699	7DCC4C	7952 352182	NIKOLAY OSIPOV	{"email": "osipov_nikolay_1981@postgrespro.ru", "phone": "+70822073932"}
0005434024700	46DCDD	0097 976333	MARK SOROKIN	{"email": "sorokin_mark-28071980@postgrespro.ru", "phone": "+70928065783"}
0005434024701	46DCDD	5240 481208	OKSANA GAVRILOVA	{"email": "gavrilova-oksana091966@postgrespro.ru", "phone": "+70680644218"}
0005434024702	FF1B4A	7718 701307	ANASTASIYA IVANOVA	{"phone": "+70693408362"}
0005434024703	90B23C	3997 760394	ANATOLIY SEMENOV	{"phone": "+70478876175"}
0005434024704	0CD6DC	9064 965751	OKSANA POPOVA	{"email": "o-popova10011975@postgrespro.ru", "phone": "+70605518661"}
0005434024705	38F382	2367 834227	DMITRIY PETROV	{"phone": "+70950031284"}
0005434024706	C61F9A	3510 447705	ANASTASIYA POTAPOVA	{"phone": "+70526033587"}
0005434024707	C61F9A	1762 361526	OLGA NIKITINA	{"phone": "+70067018557"}
0005434024708	8507B1	7967 539201	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.aleksandra.26091971@postgrespro.ru", "phone": "+70145027959"}
0005434024709	025DF7	5058 226148	MAKSIM MEDVEDEV	{"phone": "+70042557733"}
0005434024710	DFCF7A	9922 614068	IGOR VOLKOV	{"email": "volkov_i1987@postgrespro.ru", "phone": "+70654690033"}
0005434024711	E0B61E	2382 560696	NIKITA PETROV	{"phone": "+70400388861"}
0005434024712	04EC69	6017 246978	MARIYA RODIONOVA	{"email": "rodionova_mariya1979@postgrespro.ru", "phone": "+70593730946"}
0005434024713	5C6B0E	6908 149199	ALEKSANDR PAVLOV	{"email": "a.pavlov.1965@postgrespro.ru", "phone": "+70449111642"}
0005434024714	5C6B0E	2642 033211	LYUDMILA MAKAROVA	{"phone": "+70431520997"}
0005434024715	19D5B5	4963 733643	ALINA NIKITINA	{"phone": "+70819159562"}
0005434024716	201718	8853 035026	ALEKSANDR ILIN	{"phone": "+70885707422"}
0005434024717	617160	6542 380476	ANDREY FEDOROV	{"email": "fedorov.a.101972@postgrespro.ru", "phone": "+70988491973"}
0005434024718	9FE5E8	3589 061922	ANASTASIYA DAVYDOVA	{"email": "a.davydova041982@postgrespro.ru", "phone": "+70497271470"}
0005434024719	B79981	8611 388233	IVAN CHERNOV	{"phone": "+70570813582"}
0005434024720	B79981	9107 482935	RENAT SAVELEV	{"email": "r.savelev061982@postgrespro.ru", "phone": "+70982495593"}
0005434024721	B79981	3117 349952	MARIYA NIKOLAEVA	{"email": "m-nikolaeva.19021975@postgrespro.ru", "phone": "+70624118390"}
0005434024722	45F026	4700 754171	SERGEY AFANASEV	{"phone": "+70847966278"}
0005434024723	B32052	0347 772912	EKATERINA MAKAROVA	{"phone": "+70284853201"}
0005434024724	B32052	6050 985198	OLEG KUZNECOV	{"email": "oleg-kuznecov1967@postgrespro.ru", "phone": "+70672621814"}
0005434024725	BAD410	1040 266205	ZINAIDA ALEKSEEVA	{"phone": "+70374194458"}
0005434024726	6EB1A1	3071 626068	IRINA NAUMOVA	{"phone": "+70871833019"}
0005434024727	EAFD16	9158 156128	SERGEY GORBUNOV	{"phone": "+70066615093"}
0005434024728	314CD2	6275 880176	GALINA MOISEEVA	{"phone": "+70779958252"}
0005434024729	970C78	3333 018376	SERGEY MEDVEDEV	{"phone": "+70716978810"}
0005434024730	B6D106	8021 821029	NIKOLAY SHEVCHENKO	{"phone": "+70907123464"}
0005434024731	EBF62D	8305 746445	NIKOLAY ZAKHAROV	{"phone": "+70114262537"}
0005434024732	EBF62D	5998 259337	NIKOLAY POPOV	{"phone": "+70923667776"}
0005434024733	B1C29A	4759 604823	EVGENIY SEMENOV	{"phone": "+70804509739"}
0005434024734	232F85	1631 150070	DARYA MOROZOVA	{"phone": "+70313741231"}
0005434024735	A0CF3A	2650 705478	OKSANA PETROVA	{"email": "oksana.petrova-121965@postgrespro.ru", "phone": "+70101716548"}
0005434024736	0E3549	8066 382785	VLADIMIR VOLKOV	{"email": "vvolkov14121956@postgrespro.ru", "phone": "+70891327417"}
0005434024737	818C22	5936 258253	TAISIYA GORBUNOVA	{"email": "tgorbunova-1977@postgrespro.ru", "phone": "+70991920345"}
0005434024738	818C22	6084 194849	STEPAN AFANASEV	{"email": "stepanafanasev-1966@postgrespro.ru", "phone": "+70808621298"}
0005434024739	69CD19	5097 015511	ALEKSEY GAVRILOV	{"phone": "+70113044026"}
0005434024740	327A91	5717 462435	DMITRIY VOROBEV	{"phone": "+70789745259"}
0005434024741	1BB75C	8799 260696	VERA KUZMINA	{"phone": "+70424102634"}
0005434024742	AEF5FD	3201 043231	YULIYA GERASIMOVA	{"email": "gerasimova_yuliya16011969@postgrespro.ru", "phone": "+70718993931"}
0005434024744	A6275E	7983 670052	YURIY NIKITIN	{"phone": "+70266166404"}
0005434024745	100F9C	3921 107172	ANTONINA VLASOVA	{"email": "a-vlasova_09061970@postgrespro.ru", "phone": "+70371795870"}
0005434024746	100F9C	8969 121336	ALISA FEDOROVA	{"phone": "+70506620453"}
0005434024747	7A5948	2565 272369	ALEKSANDR TIMOFEEV	{"email": "timofeev_a.25031982@postgrespro.ru", "phone": "+70983787557"}
0005434024748	0BEEBB	6180 734994	ELENA DENISOVA	{"phone": "+70706313467"}
0005434024749	D02252	4886 367629	ALENA KOROLEVA	{"email": "a_koroleva1985@postgrespro.ru", "phone": "+70807187905"}
0005434024750	0BFC64	3794 307055	IRINA ANDREEVA	{"phone": "+70028225777"}
0005434024751	8F9E36	9904 411358	ANNA SMIRNOVA	{"phone": "+70067947888"}
0005434024752	F841BA	9374 384230	SERGEY ROMANOV	{"phone": "+70333622021"}
0005434024753	AB298C	6674 496340	OLGA ZAKHAROVA	{"phone": "+70118814744"}
0005434024754	AB298C	7531 945613	NATALYA KUZNECOVA	{"phone": "+70958757218"}
0005434024755	762403	4995 023183	VALERIY VLASOV	{"email": "v-vlasov.1967@postgrespro.ru", "phone": "+70087004035"}
0005434024756	89570E	0274 717079	NATALYA ALEKSEEVA	{"email": "alekseeva-natalya121973@postgrespro.ru", "phone": "+70512040050"}
0005434024757	89570E	7863 588594	RUSTAM SEMENOV	{"email": "rsemenov-1963@postgrespro.ru", "phone": "+70505517804"}
0005434024758	7DB435	3705 970712	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr_1977@postgrespro.ru", "phone": "+70959372526"}
0005434024759	7DB435	9965 371609	YURIY OSIPOV	{"email": "osipovy_041974@postgrespro.ru", "phone": "+70172603808"}
0005434024760	95AE5B	5114 630354	ARTEM ALEKSEEV	{"phone": "+70706151579"}
0005434024761	95AE5B	2967 521613	ANASTASIYA GUSEVA	{"email": "guseva.a-10071976@postgrespro.ru", "phone": "+70891142293"}
0005434024762	95AE5B	9657 262636	ALEKSANDR TARASOV	{"email": "aleksandr_tarasov.041982@postgrespro.ru", "phone": "+70495245160"}
0005434024763	1776B3	9056 582062	MAKSIM EGOROV	{"phone": "+70282544638"}
0005434024764	1776B3	5442 182247	MARINA IVANOVA	{"email": "mivanova.1971@postgrespro.ru", "phone": "+70548252234"}
0005434024765	DECB18	8060 400326	MIKHAIL ANTONOV	{"email": "antonov-m1979@postgrespro.ru", "phone": "+70504787200"}
0005434024766	DECB18	1646 086792	MAKSIM FILIPPOV	{"phone": "+70548970185"}
0005434024767	D8987E	5323 506980	ALEKSEY VOLKOV	{"email": "a_volkov.061971@postgrespro.ru", "phone": "+70101736101"}
0005434024768	5D2287	2998 057002	ANDREY AFANASEV	{"phone": "+70136442044"}
0005434024769	E15629	2164 601488	VLADIMIR SIDOROV	{"phone": "+70873443837"}
0005434024770	9D8563	8965 610963	ANATOLIY ABRAMOV	{"email": "abramov.anatoliy.30051961@postgrespro.ru", "phone": "+70155096572"}
0005434024771	23181C	9496 053166	OLEG KUZMIN	{"email": "o_kuzmin071964@postgrespro.ru", "phone": "+70483843101"}
0005434024772	8052BF	9902 823958	SERGEY CHERNOV	{"email": "sergeychernov-1986@postgrespro.ru", "phone": "+70920338550"}
0005434024773	62F8D7	0313 111456	TAMARA MIKHAYLOVA	{"email": "mikhaylova-t-13031974@postgrespro.ru", "phone": "+70167674057"}
0005434024774	897CD7	4775 818698	TATYANA MAKSIMOVA	{"phone": "+70828698609"}
0005434024775	897CD7	8981 365455	YULIYA ZAYCEVA	{"phone": "+70898468140"}
0005434024776	897CD7	2213 464918	ANDREY FROLOV	{"email": "frolov_a-24031956@postgrespro.ru", "phone": "+70717377694"}
0005434024777	64E3FF	7817 293992	SERGEY SOKOLOV	{"phone": "+70249773574"}
0005434024778	5806CF	0768 240619	ALEKSANDRA SIDOROVA	{"email": "a-sidorova-1966@postgrespro.ru", "phone": "+70348065560"}
0005434024779	09C92F	9358 407398	NADEZHDA ZHUKOVA	{"email": "zhukovanadezhda.121983@postgrespro.ru", "phone": "+70858049928"}
0005434024780	BE721C	6351 761640	LARISA EGOROVA	{"phone": "+70685700546"}
0005434024781	273751	0609 110552	EVGENIYA FEDOROVA	{"phone": "+70843540327"}
0005434024782	498B2F	6728 221278	EVGENIY MELNIKOV	{"phone": "+70271631813"}
0005434024783	22A77A	8030 776432	ALEVTINA LOGINOVA	{"email": "loginova_a-11041978@postgrespro.ru", "phone": "+70967040162"}
0005434024784	ABEBE1	6938 904784	LYUDMILA MIKHAYLOVA	{"phone": "+70294218705"}
0005434024785	ABEBE1	6432 848608	VALENTINA NIKITINA	{"email": "nikitina-v_02111983@postgrespro.ru", "phone": "+70147940996"}
0005434024786	6B13E6	0744 905392	VALENTIN KOZLOV	{"email": "kozlovvalentin-071971@postgrespro.ru", "phone": "+70487562526"}
0005434024787	2D384B	0969 566613	ANNA GERASIMOVA	{"email": "agerasimova_1972@postgrespro.ru", "phone": "+70926687248"}
0005434024788	64DD10	0082 502600	MIKHAIL GAVRILOV	{"email": "gavrilov_mikhail_30121979@postgrespro.ru", "phone": "+70429320604"}
0005434024789	64DD10	7124 586027	ELENA LOGINOVA	{"phone": "+70488239243"}
0005434024790	E2E5C8	9949 972159	LIDIYA PAVLOVA	{"phone": "+70328390330"}
0005434024791	136181	3847 747686	DARYA PETROVA	{"phone": "+70057136672"}
0005434024792	136181	2819 517396	LYUBOV ROMANOVA	{"email": "lyubov.romanova-021960@postgrespro.ru", "phone": "+70120606579"}
0005434024793	034A6C	9110 496091	VALENTINA SERGEEVA	{"phone": "+70599547718"}
0005434024794	979FAC	0622 804246	ANTON VOLKOV	{"phone": "+70104648493"}
0005434024795	979FAC	0619 224094	ANASTASIYA MIKHAYLOVA	{"phone": "+70000218807"}
0005434024796	6158FD	5063 171216	KLAVDIYA KOMAROVA	{"email": "klavdiya.komarova1982@postgrespro.ru", "phone": "+70150374887"}
0005434024797	29F4C2	2874 258334	SERGEY GERASIMOV	{"phone": "+70149709036"}
0005434024798	29F4C2	9027 080166	TATYANA DAVYDOVA	{"phone": "+70874684001"}
0005434024799	885B4A	3415 366247	IVAN ANTONOV	{"phone": "+70298064577"}
0005434024800	B3CAAD	9709 980913	TATYANA IVANOVA	{"email": "ivanovat.011964@postgrespro.ru", "phone": "+70691409339"}
0005434024801	B3CAAD	9565 609900	ALISA KUZMINA	{"email": "a-kuzmina-1962@postgrespro.ru", "phone": "+70979624773"}
0005434024802	E15FC2	2756 393582	NATALYA KUDRYASHOVA	{"email": "natalya_kudryashova-021968@postgrespro.ru", "phone": "+70424690286"}
0005434024803	B3E06E	4944 820463	IRINA BELOVA	{"phone": "+70866409130"}
0005434024804	7F5B4B	0395 848611	EVDOKIYA PETROVA	{"phone": "+70423478908"}
0005434024805	D398DB	4136 408939	MIKHAIL BORISOV	{"email": "borisov-mikhail-15041971@postgrespro.ru", "phone": "+70041247243"}
0005434024806	CD351A	9426 400058	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr01091976@postgrespro.ru", "phone": "+70248458180"}
0005434024807	CD351A	4255 088083	DMITRIY MARTYNOV	{"email": "dmitriy_martynov_021950@postgrespro.ru", "phone": "+70620243748"}
0005434024808	39697B	4901 368399	VALENTIN GRIGOREV	{"phone": "+70489331366"}
0005434024809	7434FF	5517 188766	SERGEY KUZNECOV	{"phone": "+70168625282"}
0005434024810	EB5CEC	1082 333798	IRINA TIMOFEEVA	{"phone": "+70871771846"}
0005434024811	95B853	0811 696623	YURIY MEDVEDEV	{"email": "yuriy-medvedev_27051964@postgrespro.ru", "phone": "+70209561058"}
0005434024812	E91DA6	7324 968195	ANTONINA SOROKINA	{"email": "sorokina.a-04051972@postgrespro.ru", "phone": "+70568615935"}
0005434024813	AFED76	2345 443611	MARINA MEDVEDEVA	{"phone": "+70365437322"}
0005434024814	AFED76	7819 500119	VYACHESLAV DAVYDOV	{"phone": "+70229749623"}
0005434024815	B303B1	8729 300634	OLESYA KALININA	{"phone": "+70599978830"}
0005434024816	5B2E46	0669 784674	INNA NOVIKOVA	{"email": "inovikova.1973@postgrespro.ru", "phone": "+70543187067"}
0005434024817	DAC9D1	8443 415138	LYUBOV MOROZOVA	{"email": "morozova_l_071964@postgrespro.ru", "phone": "+70384126797"}
0005434024818	7AB58A	2971 922457	GENNADIY SIDOROV	{"phone": "+70042858262"}
0005434024819	C6EA78	6170 150543	SVETLANA ALEKSANDROVA	{"email": "svetlanaaleksandrova.01041971@postgrespro.ru", "phone": "+70410240316"}
0005434024820	C6EA78	2731 041005	MIKHAIL KRASNOV	{"phone": "+70310393261"}
0005434024821	157DE2	1132 089157	GRIGORIY NAUMOV	{"email": "g_naumov.04101981@postgrespro.ru", "phone": "+70029733123"}
0005434024822	1A3999	3933 161179	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a101970@postgrespro.ru", "phone": "+70480406807"}
0005434024823	1A3999	8131 724370	IGOR VASILEV	{"phone": "+70613553526"}
0005434024824	FE503A	1159 256995	ILYA ORLOV	{"email": "iorlov1968@postgrespro.ru", "phone": "+70603088245"}
0005434024825	FE503A	9922 502435	VERA ZHURAVLEVA	{"phone": "+70890712965"}
0005434024826	FE503A	9382 147202	NIKOLAY VASILEV	{"email": "nikolay.vasilev051971@postgrespro.ru", "phone": "+70191390678"}
0005434024827	A5077D	1480 043861	ANTON PETROV	{"email": "anton-petrov_1963@postgrespro.ru", "phone": "+70669330967"}
0005434024828	16197B	9920 335480	MIKHAIL VASILEV	{"phone": "+70396408741"}
0005434024829	B9528B	8336 306895	ALEKSANDR SIDOROV	{"email": "sidorov-a.121966@postgrespro.ru", "phone": "+70558622171"}
0005434024830	CC9D56	6772 693578	DMITRIY KUZMIN	{"email": "dmitriykuzmin-061967@postgrespro.ru", "phone": "+70352545729"}
0005434024831	976D5E	4231 022596	VADIM ANTONOV	{"phone": "+70839926494"}
0005434024832	976D5E	2853 384210	VLADIMIR SMIRNOV	{"phone": "+70697410992"}
0005434024833	976D5E	0505 428258	ANDREY KARPOV	{"email": "karpova.07091969@postgrespro.ru", "phone": "+70851665181"}
0005434024834	FB5AF0	1309 064530	ANDREY FROLOV	{"email": "frolov.andrey_121975@postgrespro.ru", "phone": "+70199574230"}
0005434024835	9DD024	3767 327912	YULIYA MOISEEVA	{"phone": "+70272240864"}
0005434024836	A553A9	5992 408543	NADEZHDA IVANOVA	{"email": "nadezhda_ivanova1967@postgrespro.ru", "phone": "+70455790215"}
0005434024837	B836BA	8777 791317	MARINA RODIONOVA	{"phone": "+70589095340"}
0005434024838	8C4A08	6196 645865	YURIY DMITRIEV	{"phone": "+70151437576"}
0005434024839	94E543	1133 419042	VIKTORIYA TARASOVA	{"phone": "+70304400307"}
0005434024840	94E543	5128 089642	GENNADIY NIKITIN	{"phone": "+70218010004"}
0005434024841	782838	7863 677223	VYACHESLAV STEPANOV	{"phone": "+70054542923"}
0005434024842	9CFEFC	9407 818864	EKATERINA ANTONOVA	{"email": "antonovae.031966@postgrespro.ru", "phone": "+70708038508"}
0005434024843	357975	1814 876436	DMITRIY KUDRYASHOV	{"email": "kudryashov_d-1975@postgrespro.ru", "phone": "+70214041525"}
0005434024844	45D611	2675 342096	MIKHAIL BELOV	{"phone": "+70401601840"}
0005434024845	45D611	6987 027529	ALEKSANDR KOZLOV	{"phone": "+70400832624"}
0005434024846	D68C6B	0534 956112	ELENA POLYAKOVA	{"phone": "+70807078121"}
0005434024847	D68C6B	8271 013279	LYUDMILA STEPANOVA	{"email": "stepanova-lyudmila.101967@postgrespro.ru", "phone": "+70749666519"}
0005434024848	ECD70F	0634 364832	SERGEY ZAKHAROV	{"phone": "+70265771481"}
0005434024849	4CE8C6	3333 768829	OKSANA POLYAKOVA	{"email": "o_polyakova.101975@postgrespro.ru", "phone": "+70489009869"}
0005434024850	4CE8C6	1835 635707	ANNA MATVEEVA	{"email": "annamatveeva16031967@postgrespro.ru", "phone": "+70810927556"}
0005434024851	4E9F82	6462 485555	ROZALIYA VASILEVA	{"email": "vasileva_r1968@postgrespro.ru", "phone": "+70013433475"}
0005434024852	813FB9	3334 285616	SERGEY VOROBEV	{"phone": "+70106424265"}
0005434024853	6C2C82	6586 977535	IVAN ABRAMOV	{"email": "ivan-abramov.111958@postgrespro.ru", "phone": "+70853056436"}
0005434024854	6C2C82	7518 854222	ELIZAVETA KALININA	{"phone": "+70069787940"}
0005434024855	5AACC7	4351 556289	VALENTINA TITOVA	{"phone": "+70287038365"}
0005434024856	5AACC7	9332 019772	STEPAN NIKOLAEV	{"email": "stepan-nikolaev01031978@postgrespro.ru", "phone": "+70537155146"}
0005434024857	7C48C8	3783 534051	IRINA RYABOVA	{"email": "ryabova-i.111978@postgrespro.ru", "phone": "+70291252770"}
0005434024858	747353	3448 277726	NIKOLAY FROLOV	{"email": "nikolayfrolov08031977@postgrespro.ru", "phone": "+70341968429"}
0005434024859	747353	2810 479992	ALEKSANDR NIKOLAEV	{"phone": "+70623528675"}
0005434024860	E5203E	8138 784001	YURIY MEDVEDEV	{"phone": "+70150753624"}
0005434024861	A539DB	1471 113889	VITALIY SAVELEV	{"phone": "+70258645465"}
0005434024862	A539DB	5842 113176	EVGENIYA ZOTOVA	{"email": "zotovae.1979@postgrespro.ru", "phone": "+70364664034"}
0005434024863	1CA35A	8261 954429	EVGENIY NIKITIN	{"phone": "+70762443130"}
0005434024864	774FE9	5508 656506	NIKOLAY ALEKSANDROV	{"phone": "+70641125127"}
0005434024865	7EF36B	8280 385631	ARTEM VLASOV	{"email": "artem.vlasov1978@postgrespro.ru", "phone": "+70338592020"}
0005434024922	7EE268	8939 837631	SOFYA PETROVA	{"phone": "+70100949293"}
0005434024866	8093FA	1295 409566	IRINA ERMAKOVA	{"email": "ermakova.i_051978@postgrespro.ru", "phone": "+70793374470"}
0005434024867	BF60DE	3707 418512	VIKTOR KUZMIN	{"phone": "+70901423536"}
0005434024868	BF60DE	5813 168787	VALENTINA VOLKOVA	{"phone": "+70837835102"}
0005434024869	4D3F8A	4903 912837	OLGA ANDREEVA	{"email": "olga-andreeva_081975@postgrespro.ru", "phone": "+70722830203"}
0005434024870	EF07B5	8568 017094	ALEKSANDR RODIONOV	{"email": "a_rodionov-011974@postgrespro.ru", "phone": "+70231324899"}
0005434024871	EF07B5	6901 200808	SERGEY KONOVALOV	{"email": "konovalov.s20021978@postgrespro.ru", "phone": "+70752400650"}
0005434024872	A85C99	8601 227000	OLGA MATVEEVA	{"email": "matveeva-olga.28011960@postgrespro.ru", "phone": "+70639614565"}
0005434024873	4B44DC	8616 670488	EKATERINA SERGEEVA	{"phone": "+70381835292"}
0005434024874	4B44DC	8544 060271	VALERIY FOMIN	{"email": "fomin.v-1959@postgrespro.ru", "phone": "+70022438133"}
0005434024875	DABF00	0513 238799	ELENA MARTYNOVA	{"email": "elenamartynova-1964@postgrespro.ru", "phone": "+70561140126"}
0005434024876	DABF00	0299 735645	ANATOLIY DMITRIEV	{"email": "dmitriev_a-1969@postgrespro.ru", "phone": "+70428425611"}
0005434024877	F0032D	5665 279072	VLADIMIR SOKOLOV	{"email": "sokolovvladimir09061970@postgrespro.ru", "phone": "+70470704539"}
0005434024878	F0032D	3788 020373	ALEKSANDR DENISOV	{"email": "aleksandr-denisov-30071976@postgrespro.ru", "phone": "+70997775693"}
0005434024879	26EF58	2892 161807	ZINAIDA DANILOVA	{"phone": "+70596360307"}
0005434024880	86CB75	0351 217220	EVGENIY ILIN	{"phone": "+70614614817"}
0005434024881	7B6401	8072 528054	OLGA ZHURAVLEVA	{"email": "zhuravlevaolga-1974@postgrespro.ru", "phone": "+70836086568"}
0005434024882	7B6401	0308 402223	NIKOLAY IVANOV	{"phone": "+70543540296"}
0005434024883	454B8E	4489 967399	YULIYA ZHURAVLEVA	{"email": "zhuravleva-yuliya.051979@postgrespro.ru", "phone": "+70768719297"}
0005434024884	4F6513	6573 798754	KRISTINA ZAKHAROVA	{"phone": "+70164989556"}
0005434024885	5F764C	7656 732899	NIKOLAY NIKOLAEV	{"phone": "+70380296517"}
0005434024886	5EA2DC	6247 609601	GUZEL KUDRYASHOVA	{"email": "kudryashovaguzel.051967@postgrespro.ru", "phone": "+70273612065"}
0005434024887	0DC35E	0405 838883	PETR MIRONOV	{"email": "mironovpetr.051975@postgrespro.ru", "phone": "+70086494663"}
0005434024888	D21EFB	6230 538678	ROMAN NAUMOV	{"phone": "+70178103170"}
0005434024889	0D6E46	1949 220639	LYUBOV YUDINA	{"phone": "+70850888600"}
0005434024890	0D6E46	8255 226230	ELENA ABRAMOVA	{"phone": "+70626479336"}
0005434024891	1ACF73	2747 292264	IVAN MELNIKOV	{"email": "ivan.melnikov.1966@postgrespro.ru", "phone": "+70666057142"}
0005434024892	802A13	7737 324776	NADEZHDA TARASOVA	{"email": "tarasovan.071983@postgrespro.ru", "phone": "+70302722990"}
0005434024893	00A59D	9137 954087	MARINA FROLOVA	{"email": "frolovam_24081967@postgrespro.ru", "phone": "+70510285013"}
0005434024894	EAA507	9486 516203	DMITRIY KOZLOV	{"email": "kozlovdmitriy_1965@postgrespro.ru", "phone": "+70795682447"}
0005434024895	1846AB	9749 363192	ANASTASIYA KONDRATEVA	{"email": "kondrateva.a1970@postgrespro.ru", "phone": "+70293135568"}
0005434024896	9E5607	7179 616187	SERGEY MEDVEDEV	{"phone": "+70666788731"}
0005434024897	237BA9	8420 282952	ELENA ABRAMOVA	{"email": "abramova.e_26071976@postgrespro.ru", "phone": "+70015969158"}
0005434024898	37C5F3	5665 700348	LYUDMILA ROMANOVA	{"phone": "+70554566445"}
0005434024899	A9A417	1745 091022	MIKHAIL GAVRILOV	{"email": "mgavrilov-03051973@postgrespro.ru", "phone": "+70755249706"}
0005434024900	153F6B	6540 731143	OLEG VASILEV	{"phone": "+70698445590"}
0005434024901	153F6B	4004 730358	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-111978@postgrespro.ru", "phone": "+70981523364"}
0005434024902	0BE218	0738 946921	TATYANA KARPOVA	{"phone": "+70296340103"}
0005434024903	D9EB31	3466 029511	MAKSIM SAVELEV	{"phone": "+70623386909"}
0005434024904	F7BB54	1997 469231	KIRILL VOLKOV	{"email": "kirillvolkov071967@postgrespro.ru", "phone": "+70106468098"}
0005434024905	E091A0	9812 200477	GENNADIY FROLOV	{"email": "frolov-g-1973@postgrespro.ru", "phone": "+70175590577"}
0005434024906	C0F9F4	9794 874088	TATYANA MAKAROVA	{"phone": "+70969210914"}
0005434024907	14D76C	6733 783500	SVETLANA ZHURAVLEVA	{"email": "svetlana.zhuravleva091978@postgrespro.ru", "phone": "+70245545632"}
0005434024908	CDEAF9	8820 915820	POLINA MARTYNOVA	{"email": "pmartynova.061969@postgrespro.ru", "phone": "+70424666822"}
0005434024909	2B5D5C	2871 737432	VIKTOR ANDREEV	{"phone": "+70067596158"}
0005434024910	2B5D5C	5445 688751	ANASTASIYA ABRAMOVA	{"phone": "+70653581828"}
0005434024911	107449	9054 759503	DMITRIY TIMOFEEV	{"email": "timofeev-dmitriy1965@postgrespro.ru", "phone": "+70403902917"}
0005434024912	70B545	3341 249160	ANTONINA VLASOVA	{"email": "vlasova_antonina_1979@postgrespro.ru", "phone": "+70752772743"}
0005434024913	A213A9	9503 637428	VIKTOR SERGEEV	{"phone": "+70739132354"}
0005434024914	540632	3323 260887	PAVEL KOZLOV	{"phone": "+70052194189"}
0005434024915	ECA30C	1633 416775	ALEKSANDR KONOVALOV	{"email": "aleksandr-konovalov-29021976@postgrespro.ru", "phone": "+70386240471"}
0005434024916	8BB3B1	1201 651056	VERA EGOROVA	{"email": "egorovavera-27091973@postgrespro.ru", "phone": "+70043894265"}
0005434024917	82CE1C	4338 401774	TIMOFEY PAVLOV	{"phone": "+70234319507"}
0005434024918	82CE1C	8016 638267	TIMUR FEDOROV	{"email": "fedorov-t1981@postgrespro.ru", "phone": "+70263974347"}
0005434024919	C40DA1	7374 981489	IRINA MAKAROVA	{"phone": "+70009962254"}
0005434024920	61C102	7772 125653	TATYANA NOVIKOVA	{"phone": "+70322523724"}
0005434024921	AFD213	7131 475250	ILYA FEDOTOV	{"phone": "+70398195063"}
0005434024923	BA3FD8	8610 925124	ELENA MOROZOVA	{"email": "morozova.elena.1969@postgrespro.ru", "phone": "+70616953500"}
0005434024924	87C81F	1311 633591	IRINA LOGINOVA	{"phone": "+70738810867"}
0005434024925	10F4FE	5169 611680	VIKTORIYA SOKOLOVA	{"phone": "+70875698230"}
0005434024926	10F4FE	0007 766879	VERA FROLOVA	{"phone": "+70745741379"}
0005434024927	A4F41F	3898 163374	ANTONINA KOLESNIKOVA	{"phone": "+70631964519"}
0005434024928	1124C2	0206 588524	VLADIMIR PAVLOV	{"phone": "+70119771498"}
0005434024929	40F672	3039 866405	ALEKSANDR KULIKOV	{"email": "kulikov_a-1976@postgrespro.ru", "phone": "+70605625301"}
0005434024930	40F672	8736 799753	IGOR ROMANOV	{"email": "i_romanov-1964@postgrespro.ru", "phone": "+70295427424"}
0005434024931	0D0366	4754 431806	VITALIY POPOV	{"email": "popov-vitaliy.061981@postgrespro.ru", "phone": "+70128324961"}
0005434024932	AF0A49	6588 614634	VALENTINA POLYAKOVA	{"phone": "+70740355156"}
0005434024933	D4D97E	9310 932763	DENIS MOROZOV	{"phone": "+70010704228"}
0005434024934	9161FD	2644 666890	YURIY KOZLOV	{"phone": "+70390299785"}
0005434024935	17ED28	8221 477602	SERGEY ZAKHAROV	{"email": "zakharov-s10021971@postgrespro.ru", "phone": "+70187126169"}
0005434024936	17ED28	9770 617952	TATYANA YAKOVLEVA	{"phone": "+70836170631"}
0005434024937	9536EF	8281 943961	VIKTOR KUZNECOV	{"email": "kuznecovviktor.12101960@postgrespro.ru", "phone": "+70110741770"}
0005434024938	9263FC	4980 973304	ALEKSEY SIDOROV	{"phone": "+70451353586"}
0005434024939	D8483C	3207 017196	YURIY PAVLOV	{"email": "y-pavlov.071975@postgrespro.ru", "phone": "+70064125575"}
0005434024940	0B0AA5	2984 623923	LILIYA SOROKINA	{"phone": "+70118301473"}
0005434024941	EA502D	3676 169857	ANASTASIYA SOLOVEVA	{"phone": "+70219976140"}
0005434024942	F6E645	0987 876959	VIKTOR GAVRILOV	{"phone": "+70408962042"}
0005434024943	F6E645	0645 820123	SERGEY GRIGOREV	{"phone": "+70529881749"}
0005434024944	A3D118	6583 338871	DMITRIY BORISOV	{"phone": "+70978280177"}
0005434024945	A3D118	2978 463300	EKATERINA GORBUNOVA	{"phone": "+70915863046"}
0005434024946	12064C	7342 546901	NIKOLAY POPOV	{"email": "nikolay_popov-121963@postgrespro.ru", "phone": "+70937085982"}
0005434024947	10318D	5116 882561	OLGA YUDINA	{"email": "yudinao1972@postgrespro.ru", "phone": "+70811679954"}
0005434024948	875600	1896 844049	TATYANA DENISOVA	{"phone": "+70596698413"}
0005434024949	359A13	6769 641168	ALEKSANDR ALEKSEEV	{"phone": "+70413827818"}
0005434024950	359A13	1642 220423	OKSANA ABRAMOVA	{"phone": "+70991410280"}
0005434024951	499280	6750 988361	ULYANA EGOROVA	{"email": "u.egorova.11111973@postgrespro.ru", "phone": "+70812421737"}
0005434024952	49A85F	2948 511905	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_vyacheslav.14111982@postgrespro.ru", "phone": "+70177293301"}
0005434024953	BAE66B	2015 349402	ARTEM IVANOV	{"email": "ivanov_a_21061969@postgrespro.ru", "phone": "+70670553964"}
0005434024954	A3C45A	6317 487754	NADEZHDA ZHURAVLEVA	{"phone": "+70883830657"}
0005434024955	A3C45A	3549 823794	VIKTOR KUDRYASHOV	{"email": "v-kudryashov1975@postgrespro.ru", "phone": "+70786996817"}
0005434024956	3A5617	6842 750023	ALEKSANDR PETROV	{"email": "petrov.a-1984@postgrespro.ru", "phone": "+70546070399"}
0005434024957	1D67CD	2355 929469	MIKHAIL ANTONOV	{"phone": "+70288128661"}
0005434024958	56D911	0066 818173	BORIS ZHUKOV	{"email": "b-zhukov1970@postgrespro.ru", "phone": "+70939461595"}
0005434024959	56D911	6189 656398	ALEKSANDR IVANOV	{"phone": "+70064459454"}
0005434024960	D19ADE	1352 164586	OLEG SOLOVEV	{"email": "solovevoleg-15121964@postgrespro.ru", "phone": "+70059010967"}
0005434024961	D19ADE	6224 120974	VIKTOR NOVIKOV	{"phone": "+70675076060"}
0005434024962	773438	0856 459712	LARISA MOROZOVA	{"email": "larisa-morozova.03101977@postgrespro.ru", "phone": "+70420991325"}
0005434024963	E340CF	2386 767703	STEPAN VOLKOV	{"phone": "+70217371816"}
0005434024964	C13648	8931 299607	SERGEY SMIRNOV	{"phone": "+70550299552"}
0005434024965	C13648	1944 184327	PETR DAVYDOV	{"phone": "+70504717256"}
0005434024966	DA8235	2238 199863	VERA DAVYDOVA	{"email": "davydovavera-17071962@postgrespro.ru", "phone": "+70965160485"}
0005434024967	ACCF08	4120 215193	ARTEM FEDOTOV	{"email": "fedotova20021968@postgrespro.ru", "phone": "+70302282610"}
0005434024968	58DCA1	4692 048876	VARVARA KUZNECOVA	{"email": "kuznecovavarvara1966@postgrespro.ru", "phone": "+70820188243"}
0005434024969	9464F1	2338 020307	SERGEY KUDRYASHOV	{"email": "sergeykudryashov1961@postgrespro.ru", "phone": "+70601346675"}
0005434024970	8E0DFF	3526 854879	LIDIYA ABRAMOVA	{"email": "abramova.l_20121962@postgrespro.ru", "phone": "+70381440283"}
0005434024971	8E0DFF	6869 043913	IGOR NOVIKOV	{"phone": "+70819214961"}
0005434024972	8E0DFF	4093 727354	ANNA BELYAEVA	{"phone": "+70399615801"}
0005434024973	80A3F9	3874 844712	VALENTINA SERGEEVA	{"email": "v-sergeeva_05111969@postgrespro.ru", "phone": "+70806241146"}
0005434024974	23A562	4931 276186	EVGENIY TARASOV	{"email": "tarasov-e.26051980@postgrespro.ru", "phone": "+70152788159"}
0005434024975	6A129D	9167 515775	LIDIYA ORLOVA	{"email": "orlova_lidiya_1981@postgrespro.ru", "phone": "+70121288193"}
0005434024976	6A129D	0198 152311	LEYLA MOROZOVA	{"email": "morozova.leyla_1967@postgrespro.ru", "phone": "+70345052742"}
0005434024977	8F7ADF	2079 459799	ELENA ROMANOVA	{"email": "e-romanova051975@postgrespro.ru", "phone": "+70488373446"}
0005434024978	7E0741	4301 288952	KONSTANTIN TIKHONOV	{"email": "ktikhonov071979@postgrespro.ru", "phone": "+70200691703"}
0005434024979	2938C8	6579 563551	ANDREY SOKOLOV	{"phone": "+70976970214"}
0005434024980	2938C8	3565 801693	ELENA MOISEEVA	{"phone": "+70454124656"}
0005434024981	E1737C	2687 301276	EVGENIY GORBUNOV	{"phone": "+70759986985"}
0005434024982	378073	5531 774029	SERGEY IVANOV	{"email": "s-ivanov.25061972@postgrespro.ru", "phone": "+70335131741"}
0005434024983	8B2DC8	2922 744425	OLGA ANDREEVA	{"phone": "+70457509031"}
0005434024984	721D4A	1092 500425	ARTEM ORLOV	{"email": "a_orlov19021971@postgrespro.ru", "phone": "+70866026330"}
0005434024985	C33801	7289 220345	ALEKSEY DMITRIEV	{"email": "a-dmitriev.071981@postgrespro.ru", "phone": "+70999438178"}
0005434024986	666068	9147 639782	OLGA MATVEEVA	{"email": "olga-matveeva_1963@postgrespro.ru", "phone": "+70537204908"}
0005434024987	666068	8900 934707	ARTEM KUZNECOV	{"phone": "+70202400288"}
0005434024988	3EFA9A	2734 986737	ANTONINA BARANOVA	{"phone": "+70552722703"}
0005434024989	3EFA9A	8956 127645	VIKTOR KOROLEV	{"email": "viktor.korolev-071965@postgrespro.ru", "phone": "+70078730848"}
0005434024990	594E9C	6590 870830	TAMARA ZHURAVLEVA	{"phone": "+70739688587"}
0005434024991	97FA45	9291 444842	ALINA TIKHONOVA	{"email": "a_tikhonova-1971@postgrespro.ru", "phone": "+70597206989"}
0005434024992	7FDD01	6662 747626	VALENTINA KOROLEVA	{"email": "v-koroleva_011971@postgrespro.ru", "phone": "+70471603839"}
0005434024993	26681C	2792 120373	EDUARD NOVIKOV	{"phone": "+70196673062"}
0005434024994	26681C	4565 709530	ANDREY FOMIN	{"phone": "+70279055637"}
0005434024995	26681C	4127 693763	YURIY KUZNECOV	{"phone": "+70273898815"}
0005434024996	B579C8	8578 155195	ELENA MOROZOVA	{"email": "morozova.elena.1972@postgrespro.ru", "phone": "+70042129962"}
0005434024997	32EA64	0173 877044	SERGEY ZAYCEV	{"phone": "+70947102017"}
0005434024998	F86B21	6029 359103	MAKSIM SCHERBAKOV	{"email": "maksim_scherbakov_03041980@postgrespro.ru", "phone": "+70987342506"}
0005434024999	EED90A	2249 162983	ELENA YAKOVLEVA	{"email": "e.yakovleva-19081967@postgrespro.ru", "phone": "+70391158754"}
0005434025000	BFEE53	7178 940996	OLEG KAZAKOV	{"email": "o-kazakov_051969@postgrespro.ru", "phone": "+70279371911"}
0005434025001	C34D56	5785 432182	DARYA KAZAKOVA	{"phone": "+70434790760"}
0005434025002	C34D56	2099 725250	IRINA EGOROVA	{"email": "irinaegorova_1960@postgrespro.ru", "phone": "+70189541865"}
0005434025003	0E3F46	1021 496406	ALEKSANDR BARANOV	{"email": "baranov-aleksandr_121974@postgrespro.ru", "phone": "+70177177460"}
0005434025004	4FEDB9	4163 547704	ALEKSEY BELOV	{"phone": "+70338785795"}
0005434025005	98C9E2	8092 302497	ALEKSANDR OSIPOV	{"email": "a_osipov-09061970@postgrespro.ru", "phone": "+70544335564"}
0005434025006	C04AB6	8091 273246	NATALYA POPOVA	{"email": "popovanatalya.21071983@postgrespro.ru", "phone": "+70851117277"}
0005434025007	14AD3A	3389 885054	TATYANA PAVLOVA	{"email": "tatyana_pavlova101976@postgrespro.ru", "phone": "+70758809924"}
0005434025008	3489FA	3795 518886	ANATOLIY ABRAMOV	{"email": "abramova-121971@postgrespro.ru", "phone": "+70702497163"}
0005434025009	3489FA	8624 700872	VLADIMIR IVANOV	{"phone": "+70365058775"}
0005434025010	BBF99D	7333 698142	KLAVDIYA SOLOVEVA	{"phone": "+70911258166"}
0005434025011	BBF99D	8586 792343	VALERIY KUZNECOV	{"phone": "+70294197652"}
0005434025012	3BF001	4588 071862	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova_041969@postgrespro.ru", "phone": "+70206706294"}
0005434025013	983142	2530 350909	LYUBOV ZAKHAROVA	{"email": "zakharova-lyubov-1975@postgrespro.ru", "phone": "+70583617303"}
0005434025014	DEFFF0	8232 048084	DMITRIY MEDVEDEV	{"email": "medvedev.d-1975@postgrespro.ru", "phone": "+70588343386"}
0005434025015	DEFFF0	6518 674692	EGOR MAKSIMOV	{"email": "e.maksimov-101974@postgrespro.ru", "phone": "+70933712007"}
0005434025016	0CFA76	0024 599178	ANDREY KUZNECOV	{"phone": "+70694094539"}
0005434025017	0CFA76	6888 967300	SNEZHANA IVANOVA	{"email": "ivanova_s-09081971@postgrespro.ru", "phone": "+70392991302"}
0005434025018	CCDABB	0297 503543	ELENA STEPANOVA	{"email": "estepanova.22021964@postgrespro.ru", "phone": "+70643624996"}
0005434025019	37DA0D	5133 629303	GRIGORIY ALEKSEEV	{"email": "galekseev-071981@postgrespro.ru", "phone": "+70217708233"}
0005434025020	37DA0D	5466 997440	GAGIK SOLOVEV	{"email": "gagiksolovev_071974@postgrespro.ru", "phone": "+70040327501"}
0005434025021	7D5645	9395 062041	EKATERINA NAZAROVA	{"email": "ekaterina_nazarova.1973@postgrespro.ru", "phone": "+70642638614"}
0005434025022	7D5645	6579 907374	ALBERT POPOV	{"email": "apopov.051977@postgrespro.ru", "phone": "+70550572149"}
0005434025023	F24B54	0985 294057	LYUBOV BOGDANOVA	{"email": "lyubov-bogdanova08101969@postgrespro.ru", "phone": "+70470129742"}
0005434025024	CB7740	8873 987969	RAVIL VLASOV	{"phone": "+70407309929"}
0005434025025	8C9949	4304 939524	YAROSLAV ANTONOV	{"phone": "+70845432445"}
0005434025026	8C9949	8606 896861	YURIY MEDVEDEV	{"email": "y_medvedev21041976@postgrespro.ru", "phone": "+70995389691"}
0005434025027	E5397F	2529 585419	OLGA NESTEROVA	{"email": "nesterova-olga1977@postgrespro.ru", "phone": "+70915223183"}
0005434025028	131397	5611 743930	DMITRIY FEDOTOV	{"email": "dmitriyfedotov1971@postgrespro.ru", "phone": "+70885993262"}
0005434025029	55FD42	4361 383728	MIKHAIL POPOV	{"phone": "+70133508642"}
0005434025030	462E40	7407 725874	VALENTINA KOVALEVA	{"phone": "+70704574928"}
0005434025031	D01B86	5781 807993	OLGA TARASOVA	{"email": "tarasovao-10011982@postgrespro.ru", "phone": "+70050425497"}
0005434025032	D01B86	8104 295956	MARINA EFIMOVA	{"phone": "+70164802217"}
0005434025033	D01B86	2130 706770	DMITRIY DAVYDOV	{"phone": "+70196934498"}
0005434025034	BC27BC	4497 199099	DENIS POPOV	{"phone": "+70316850420"}
0005434025035	361A10	2759 079291	NADEZHDA KOZLOVA	{"phone": "+70265912309"}
0005434025036	F896E2	6493 513713	VALERIY KUZNECOV	{"email": "v.kuznecov-091961@postgrespro.ru", "phone": "+70305664881"}
0005434025037	66F1C6	9322 362329	ALEKSANDR BELOV	{"email": "aleksandr_belov.101977@postgrespro.ru", "phone": "+70173435075"}
0005434025038	A00621	3997 663038	ELIZAVETA EGOROVA	{"phone": "+70014741849"}
0005434025039	BF178C	6673 024592	GALINA MOROZOVA	{"email": "morozova-galina-1981@postgrespro.ru", "phone": "+70669616020"}
0005434025040	BF178C	0957 100632	ANNA ROMANOVA	{"phone": "+70439925612"}
0005434025041	80C43A	3179 178890	ANNA BORISOVA	{"email": "anna.borisova-19121977@postgrespro.ru", "phone": "+70440041959"}
0005434025042	349445	9708 199127	ALEKSEY NAZAROV	{"phone": "+70501370321"}
0005434025043	349445	0637 005696	ALEKSANDR SCHERBAKOV	{"phone": "+70836815292"}
0005434025044	BEB7C1	4745 560464	DIANA FEDOROVA	{"email": "fedorova_diana031966@postgrespro.ru", "phone": "+70863611538"}
0005434025045	299B1B	3537 007291	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov_041980@postgrespro.ru", "phone": "+70338678328"}
0005434025046	299B1B	6876 400570	ELENA AFANASEVA	{"phone": "+70927643540"}
0005434025047	6D0EEA	3328 609888	LYUDMILA OSIPOVA	{"email": "losipova.1961@postgrespro.ru", "phone": "+70854758484"}
0005434025048	6D0EEA	8889 937593	EVGENIY STEPANOV	{"email": "stepanov-e.20091968@postgrespro.ru", "phone": "+70632450182"}
0005434025049	6D0EEA	9823 186809	NINA TARASOVA	{"email": "tarasova-n04021976@postgrespro.ru", "phone": "+70853137256"}
0005434025050	6D72D6	4685 019896	MARIYA KARPOVA	{"phone": "+70132464098"}
0005434025051	AD4E84	1026 692528	ANNA KUDRYASHOVA	{"email": "kudryashova_a-041963@postgrespro.ru", "phone": "+70317419772"}
0005434025052	AD4E84	2353 122528	LIDIYA MELNIKOVA	{"phone": "+70631208423"}
0005434025053	B28F66	5086 205320	ALEKSANDR GUSEV	{"email": "a.gusev20111968@postgrespro.ru", "phone": "+70155359660"}
0005434025054	B28F66	9043 801140	VIKTOR KUZNECOV	{"phone": "+70489515125"}
0005434025055	B28F66	8128 079491	SVETLANA MELNIKOVA	{"email": "s.melnikova121962@postgrespro.ru", "phone": "+70101633299"}
0005434025056	25B206	9712 300961	VLADISLAV BELOV	{"phone": "+70359252829"}
0005434025057	4FB1FE	3790 212028	KSENIYA NIKITINA	{"phone": "+70655588615"}
0005434025058	EA2E14	7059 423880	DMITRIY ZHUKOV	{"email": "zhukov-d-091960@postgrespro.ru", "phone": "+70982598248"}
0005434025059	013044	9365 471101	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr10071982@postgrespro.ru", "phone": "+70791083990"}
0005434025060	FAF46E	3093 220726	MARGARITA MAKAROVA	{"email": "makarova-margarita23101978@postgrespro.ru", "phone": "+70288148693"}
0005434025061	FAF46E	7245 010454	MARIYA ALEKSEEVA	{"email": "mariya_alekseeva.04091979@postgrespro.ru", "phone": "+70073804071"}
0005434025062	F9437D	3804 764897	EGOR SERGEEV	{"email": "sergeev_e_1974@postgrespro.ru", "phone": "+70454049512"}
0005434025063	F9437D	8024 767640	ALISA GORBUNOVA	{"phone": "+70041242510"}
0005434025064	A3E130	1685 876494	MAKSIM VOLKOV	{"phone": "+70304496207"}
0005434025065	E708E0	5546 847940	RUSLAN ORLOV	{"email": "orlov_r-13091968@postgrespro.ru", "phone": "+70592577536"}
0005434025066	BA9AD1	7488 530356	ANTON SOKOLOV	{"email": "a_sokolov.021963@postgrespro.ru", "phone": "+70888199639"}
0005434025067	B34C6A	7357 696929	ZINAIDA OSIPOVA	{"email": "z_osipova1974@postgrespro.ru", "phone": "+70147683646"}
0005434025068	FD0DE4	1301 612234	MARIYA MATVEEVA	{"email": "matveeva_mariya-1974@postgrespro.ru", "phone": "+70864725129"}
0005434025069	EFA116	1186 392428	MATVEY GUSEV	{"phone": "+70436783899"}
0005434025070	1A47E7	7609 789442	ALEKSANDRA ANDREEVA	{"email": "andreevaaleksandra_071975@postgrespro.ru", "phone": "+70488756638"}
0005434025071	1A47E7	9299 879668	ALEKSANDRA MIRONOVA	{"email": "mironova-aleksandra_061979@postgrespro.ru", "phone": "+70205401823"}
0005434025072	715586	8937 262224	ALEKSANDR MARTYNOV	{"email": "aleksandr.martynov30091968@postgrespro.ru", "phone": "+70504388604"}
0005434025073	0E72E8	0111 190769	ALEKSANDR MELNIKOV	{"phone": "+70261345226"}
0005434025074	E2C73A	7846 640628	VITALIY ZAKHAROV	{"email": "vitaliy-zakharov_23091970@postgrespro.ru", "phone": "+70629699692"}
0005434025075	3D1E8C	1276 551714	DMITRIY SAVELEV	{"email": "dmitriy.savelev-11011977@postgrespro.ru", "phone": "+70083810929"}
0005434025076	3D1E8C	2421 075033	VIKTORIYA ISAEVA	{"phone": "+70298361420"}
0005434025077	F3927B	1506 258480	NADEZHDA SMIRNOVA	{"phone": "+70380432099"}
0005434025078	FC4597	4538 511629	NINA MAKAROVA	{"email": "makarova-n-031959@postgrespro.ru", "phone": "+70677349582"}
0005434025079	421EDE	7124 041757	VALENTINA MELNIKOVA	{"phone": "+70787745608"}
0005434025080	DE1B20	7257 658170	ANNA ISAEVA	{"phone": "+70142653158"}
0005434025081	DE1B20	4939 233418	LYUDMILA ZAYCEVA	{"email": "lyudmila.zayceva1971@postgrespro.ru", "phone": "+70669978389"}
0005434025082	FF2295	4791 921901	MARIYA AKIMOVA	{"phone": "+70456541690"}
0005434025083	FF2295	2422 059916	NINA FROLOVA	{"email": "ninafrolova061970@postgrespro.ru", "phone": "+70728892234"}
0005434025084	61F644	5305 746599	TAMARA OSIPOVA	{"phone": "+70721641673"}
0005434025085	3C508A	1912 049286	MARGARITA FILATOVA	{"email": "filatovamargarita_1970@postgrespro.ru", "phone": "+70598590738"}
0005434025086	05C319	5129 987226	EGOR KULIKOV	{"email": "kulikov.egor_011984@postgrespro.ru", "phone": "+70510790132"}
0005434025087	05C319	3476 449297	NATALYA ORLOVA	{"email": "natalya_orlova-091972@postgrespro.ru", "phone": "+70119716337"}
0005434025088	EF9284	8506 728011	LYUDMILA PAVLOVA	{"phone": "+70019080474"}
0005434025089	FA3AF4	6225 712574	VIKTOR VASILEV	{"phone": "+70417689339"}
0005434025090	FA3AF4	1427 354761	EKATERINA NESTEROVA	{"email": "nesterova-e21051977@postgrespro.ru", "phone": "+70005333283"}
0005434025091	A42641	6212 428319	GALINA KRASNOVA	{"email": "krasnova_galina.1981@postgrespro.ru", "phone": "+70710054066"}
0005434025092	1D78DC	6972 941766	VIKTOR KOROLEV	{"email": "korolev-viktor.17021976@postgrespro.ru", "phone": "+70795089410"}
0005434025093	78F645	6210 058786	LYUBOV ALEKSEEVA	{"email": "alekseeva_lyubov1971@postgrespro.ru", "phone": "+70430568380"}
0005434025094	D09802	6131 149721	EKATERINA ANISIMOVA	{"phone": "+70452971146"}
0005434025095	BB1D52	5895 133700	ANTON NIKITIN	{"email": "nikitin_a.121973@postgrespro.ru", "phone": "+70132273446"}
0005434025096	075699	9985 049052	NADEZHDA KULIKOVA	{"email": "nadezhda.kulikova.101971@postgrespro.ru", "phone": "+70763236462"}
0005434025097	075699	4648 156486	IRINA ABRAMOVA	{"email": "abramovai-1971@postgrespro.ru", "phone": "+70582708968"}
0005434025098	0E6848	6278 483910	IRINA ZAYCEVA	{"email": "zaycevai_021974@postgrespro.ru", "phone": "+70666653081"}
0005434025099	53824C	8030 954790	GALIYA BELOVA	{"email": "belova_g-111977@postgrespro.ru", "phone": "+70486199869"}
0005434025100	E1C6AF	1829 681841	NATALYA YAKOVLEVA	{"email": "yakovleva.n-101980@postgrespro.ru", "phone": "+70054592195"}
0005434025101	E1C6AF	1101 542780	TATYANA TIMOFEEVA	{"email": "tatyana.timofeeva-071966@postgrespro.ru", "phone": "+70767779910"}
0005434025102	E429AD	1411 779984	NATALYA MARTYNOVA	{"phone": "+70967617717"}
0005434025278	28B5D4	3217 033073	SERGEY KUZNECOV	{"phone": "+70296996504"}
0005434025103	619C3F	7894 634954	ALEKSEY PAVLOV	{"email": "apavlov.1984@postgrespro.ru", "phone": "+70478340807"}
0005434025104	4B100B	7597 123766	SERGEY NIKOLAEV	{"phone": "+70831686653"}
0005434025105	E367D1	3548 058863	STEPAN BORISOV	{"email": "borisov-s_08041968@postgrespro.ru", "phone": "+70248709925"}
0005434025106	253B9D	9886 056039	MARIYA NESTEROVA	{"phone": "+70301806200"}
0005434025107	253B9D	9504 523667	VITALIY PETROV	{"email": "vitaliy.petrov-061968@postgrespro.ru", "phone": "+70851062698"}
0005434025108	53021A	4649 968541	NIKOLAY PETROV	{"email": "nikolay_petrov.20121973@postgrespro.ru", "phone": "+70787137542"}
0005434025109	98D5C3	9245 913400	KONSTANTIN RODIONOV	{"email": "rodionov_k_1968@postgrespro.ru", "phone": "+70034948951"}
0005434025110	98D5C3	6668 528747	DENIS NOVIKOV	{"phone": "+70639158968"}
0005434025111	4B1044	7295 397364	FEDOR KUZMIN	{"phone": "+70901816809"}
0005434025112	FD9BAC	2994 599441	GALINA DMITRIEVA	{"phone": "+70454612435"}
0005434025113	0F210A	5838 095688	OKSANA RYABOVA	{"email": "oksanaryabova.01011976@postgrespro.ru", "phone": "+70379023367"}
0005434025114	BFEF0E	4580 919278	RAISA EGOROVA	{"phone": "+70453975447"}
0005434025115	BDE9E0	9258 537889	IRINA ROMANOVA	{"phone": "+70481204359"}
0005434025116	81ED80	3507 201857	NIKOLAY PETROV	{"email": "petrovnikolay.05081985@postgrespro.ru", "phone": "+70445630657"}
0005434025117	81ED80	7607 016503	BORIS NIKOLAEV	{"phone": "+70945523155"}
0005434025118	2FE712	1589 421174	YULIYA NIKIFOROVA	{"email": "nikiforovayuliya-1978@postgrespro.ru", "phone": "+70822050458"}
0005434025119	DB72A9	2640 904756	OKSANA KOLESNIKOVA	{"phone": "+70159653674"}
0005434025120	23511D	1925 698458	NADEZHDA KOROLEVA	{"email": "korolevanadezhda.26011982@postgrespro.ru", "phone": "+70494674167"}
0005434025121	23511D	2081 148017	MATRENA IVANOVA	{"phone": "+70983300901"}
0005434025122	1C7D34	2577 168064	TAISIYA KARPOVA	{"email": "t-karpova_11101965@postgrespro.ru", "phone": "+70050187304"}
0005434025123	65B888	4562 964340	GENNADIY POPOV	{"email": "popov.g.021960@postgrespro.ru", "phone": "+70902894806"}
0005434025124	4B9CE8	9175 992772	VIKTOR POPOV	{"email": "popov-viktor_011981@postgrespro.ru", "phone": "+70735516363"}
0005434025125	4B9CE8	3318 217331	NIKOLAY SOLOVEV	{"email": "nikolay-solovev_011975@postgrespro.ru", "phone": "+70765650078"}
0005434025126	4B9CE8	4331 911454	VERONIKA MAKAROVA	{"phone": "+70998122963"}
0005434025127	34B83C	3862 699137	ANNA MELNIKOVA	{"email": "a_melnikova.051976@postgrespro.ru", "phone": "+70842751035"}
0005434025128	0C13D9	0435 703320	EKATERINA STEPANOVA	{"email": "e.stepanova.011961@postgrespro.ru", "phone": "+70600769702"}
0005434025129	F291E8	2622 194966	LIDIYA EGOROVA	{"phone": "+70732560832"}
0005434025130	F291E8	1234 508273	VERA EFIMOVA	{"phone": "+70803707772"}
0005434025131	F291E8	7007 453457	ANASTASIYA NIKOLAEVA	{"email": "a.nikolaeva-1971@postgrespro.ru", "phone": "+70269176709"}
0005434025132	301BE4	3771 764275	VERA FADEEVA	{"email": "fadeevavera.19021966@postgrespro.ru", "phone": "+70684879967"}
0005434025133	293FDC	4812 223242	OLGA ERMAKOVA	{"phone": "+70265216090"}
0005434025134	293FDC	9043 424024	ELENA ALEKSEEVA	{"email": "e_alekseeva-121978@postgrespro.ru", "phone": "+70341624212"}
0005434025135	5AA556	3140 614546	MIKHAIL SOKOLOV	{"email": "sokolov.m.1968@postgrespro.ru", "phone": "+70587780113"}
0005434025136	DCCC16	8552 927597	MATVEY ISAEV	{"email": "m-isaev-011965@postgrespro.ru", "phone": "+70376729578"}
0005434025137	C80CE0	4899 113013	IVAN IVANOV	{"phone": "+70046853577"}
0005434025138	D3836C	0244 996242	SVETLANA RODIONOVA	{"phone": "+70419145296"}
0005434025139	D3836C	2263 388478	OLGA GUSEVA	{"phone": "+70054280094"}
0005434025140	23446A	4993 374933	LYUBOV VOROBEVA	{"email": "lyubov.vorobeva.1971@postgrespro.ru", "phone": "+70928498818"}
0005434025141	23C085	3881 732898	TAISIYA FOMINA	{"email": "taisiya.fomina19101973@postgrespro.ru", "phone": "+70437365786"}
0005434025142	71487B	5909 398506	BOGDAN ANDREEV	{"phone": "+70899567829"}
0005434025143	613C3A	5346 087969	PAVEL DMITRIEV	{"email": "pavel-dmitriev1971@postgrespro.ru", "phone": "+70033950021"}
0005434025144	89EC0C	4278 722675	VALENTINA YUDINA	{"email": "yudina.v011974@postgrespro.ru", "phone": "+70205608726"}
0005434025145	B7517D	5267 216952	OLGA KOVALEVA	{"phone": "+70688888540"}
0005434025146	B0C374	7666 438536	VALENTINA TROFIMOVA	{"email": "valentina-trofimova1976@postgrespro.ru", "phone": "+70397832628"}
0005434025147	377725	3318 106131	GALINA MIKHAYLOVA	{"phone": "+70217745365"}
0005434025148	76E17C	3252 542596	GALINA ZAYCEVA	{"phone": "+70539900090"}
0005434025149	76E17C	5601 722057	BORIS FROLOV	{"email": "boris_frolov1990@postgrespro.ru", "phone": "+70688172756"}
0005434025150	ED5B96	6818 381473	ARTEM SOLOVEV	{"email": "solovevartem101967@postgrespro.ru", "phone": "+70805461244"}
0005434025151	28B4D8	2831 888865	ANDREY SERGEEV	{"phone": "+70731331127"}
0005434025152	28F0F7	0583 900341	ALEKSANDR SERGEEV	{"email": "a-sergeev1979@postgrespro.ru", "phone": "+70188946714"}
0005434025153	B01902	8969 944189	DMITRIY ILIN	{"phone": "+70385235248"}
0005434025154	B01902	9457 882478	LYUDMILA ANDREEVA	{"phone": "+70981121762"}
0005434025155	C3F58C	4504 510175	LYUDMILA ROMANOVA	{"phone": "+70056344851"}
0005434025156	C3F58C	3463 813965	ZINAIDA KULIKOVA	{"email": "kulikova_z.1966@postgrespro.ru", "phone": "+70550591578"}
0005434025157	E066C0	4844 062985	ALEKSANDR MELNIKOV	{"phone": "+70798460225"}
0005434025158	AAE2D5	6473 489093	GALINA FEDOROVA	{"phone": "+70454626226"}
0005434025159	AAE2D5	8198 061836	ANATOLIY MAKAROV	{"phone": "+70779695237"}
0005434025160	9124D4	9619 115922	TATYANA POLYAKOVA	{"phone": "+70637400202"}
0005434025161	A4EB8C	3769 196638	ANATOLIY POPOV	{"email": "anatoliy-popov_091962@postgrespro.ru", "phone": "+70548437905"}
0005434025162	F33410	3349 752831	ROMAN TARASOV	{"email": "romantarasov-1973@postgrespro.ru", "phone": "+70633421633"}
0005434025163	757078	6724 791188	VERA STEPANOVA	{"email": "stepanova-vera.1968@postgrespro.ru", "phone": "+70546366818"}
0005434025164	23B756	1069 442561	ANDREY TIMOFEEV	{"email": "timofeev.andrey-05111971@postgrespro.ru", "phone": "+70725426919"}
0005434025165	52750E	0067 901863	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.111968@postgrespro.ru", "phone": "+70469305423"}
0005434025166	609654	3071 917434	GENNADIY MAKAROV	{"email": "g.makarov.1968@postgrespro.ru", "phone": "+70283301416"}
0005434025167	0B435D	9218 865708	ELENA IVANOVA	{"email": "ivanovae-1969@postgrespro.ru", "phone": "+70853777681"}
0005434025168	8E5246	3445 160249	KONSTANTIN MARTYNOV	{"email": "martynovk_1963@postgrespro.ru", "phone": "+70854273216"}
0005434025169	6197A1	2770 768332	ALEKSEY POPOV	{"email": "a-popov1959@postgrespro.ru", "phone": "+70845778188"}
0005434025170	F6A768	7517 623521	TATYANA AFANASEVA	{"email": "afanaseva_tatyana_25121970@postgrespro.ru", "phone": "+70278263051"}
0005434025171	F6A768	7648 092212	ELIZAVETA MOISEEVA	{"email": "emoiseeva_24061982@postgrespro.ru", "phone": "+70216188493"}
0005434025172	D6DF8A	9028 016017	ANNA SEMENOVA	{"phone": "+70735228491"}
0005434025173	D6DF8A	0208 293926	ALENA BELYAEVA	{"email": "alena_belyaeva.061977@postgrespro.ru", "phone": "+70847493747"}
0005434025174	5D5C37	2786 132378	ELVINA MOROZOVA	{"phone": "+70321101586"}
0005434025175	AAA6CE	4602 006572	VYACHESLAV KRASNOV	{"phone": "+70915333568"}
0005434025176	4DC182	2505 788103	KIRILL KONOVALOV	{"phone": "+70186778622"}
0005434025177	4DC182	7715 121317	ANNA PETROVA	{"email": "apetrova03011977@postgrespro.ru", "phone": "+70825574842"}
0005434025178	E5696B	3270 085583	IRINA AFANASEVA	{"email": "afanasevairina_111972@postgrespro.ru", "phone": "+70026328904"}
0005434025179	337B0A	7058 747243	OLEG MOISEEV	{"phone": "+70420339741"}
0005434025180	D647B8	3008 660127	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda.04051981@postgrespro.ru", "phone": "+70433267818"}
0005434025181	57A847	8072 107056	OKSANA DMITRIEVA	{"email": "o_dmitrieva.29101968@postgrespro.ru", "phone": "+70057960793"}
0005434025182	CC0BF6	1122 318944	NIKITA NAZAROV	{"email": "nazarov.n.1969@postgrespro.ru", "phone": "+70315013272"}
0005434025183	6C3544	8415 335842	ANTONINA YUDINA	{"phone": "+70522791418"}
0005434025184	6C3544	7688 740533	INESSA SMIRNOVA	{"phone": "+70742706580"}
0005434025185	6C3544	3302 168753	OLEG DAVYDOV	{"phone": "+70091274572"}
0005434025186	D1F902	7682 380799	MARIYA MIRONOVA	{"phone": "+70531050829"}
0005434025187	D1F902	7334 133991	MAKSIM BELOV	{"phone": "+70361031224"}
0005434025188	E0360E	8157 609408	VLADISLAV KUZMIN	{"phone": "+70272729046"}
0005434025189	E35FCE	8004 964966	ALEKSANDR KUZMIN	{"phone": "+70195379001"}
0005434025190	E35FCE	5761 554500	OLGA OSIPOVA	{"email": "osipovaolga-02071959@postgrespro.ru", "phone": "+70822244847"}
0005434025191	E35FCE	3291 358108	ANTONINA MOISEEVA	{"email": "moiseeva.antonina_041974@postgrespro.ru", "phone": "+70657222537"}
0005434025192	D4E30E	9113 508646	RUSLAN KAZAKOV	{"phone": "+70156883115"}
0005434025193	D4E30E	8412 240893	MARIYA NOVIKOVA	{"email": "novikova_mariya-25121962@postgrespro.ru", "phone": "+70038152218"}
0005434025194	49D0FC	2564 411629	ELENA KUZMINA	{"email": "e.kuzmina-041982@postgrespro.ru", "phone": "+70485376567"}
0005434025195	49D0FC	6164 757579	ELENA SEMENOVA	{"email": "semenova-elena.051965@postgrespro.ru", "phone": "+70919066591"}
0005434025196	F7906B	6293 370717	OLGA DANILOVA	{"email": "danilova.olga-1975@postgrespro.ru", "phone": "+70721256560"}
0005434025197	854E0A	2281 085369	ALEKSANDRA OSIPOVA	{"email": "aleksandra.osipova.28071975@postgrespro.ru", "phone": "+70938759069"}
0005434025198	854E0A	2980 694132	OLEG ISAEV	{"email": "isaev.oleg-1971@postgrespro.ru", "phone": "+70060530024"}
0005434025199	56BA66	8940 399741	IGOR MARTYNOV	{"email": "martynov.i-1969@postgrespro.ru", "phone": "+70172567097"}
0005434025200	1C76AA	2503 877154	MARGARITA LAZAREVA	{"email": "m.lazareva16041977@postgrespro.ru", "phone": "+70571720344"}
0005434025201	BD77A0	6700 885228	DMITRIY ANTONOV	{"phone": "+70997711465"}
0005434025202	BD77A0	5247 516277	ANTONINA KAZAKOVA	{"email": "a-kazakova.1965@postgrespro.ru", "phone": "+70316299499"}
0005434025203	C463A5	8123 755243	ANTONINA LEBEDEVA	{"phone": "+70341878425"}
0005434025204	C463A5	5945 255287	VALENTINA MAKSIMOVA	{"email": "maksimova.valentina.01051975@postgrespro.ru", "phone": "+70808741635"}
0005434025205	0D551C	6425 604550	MARINA MAKAROVA	{"email": "m-makarova-111972@postgrespro.ru", "phone": "+70421360685"}
0005434025206	5AD96F	6486 390394	MIKHAIL ZHUKOV	{"email": "mikhailzhukov.031969@postgrespro.ru", "phone": "+70291729312"}
0005434025207	7A2C81	4225 968961	TATYANA NIKOLAEVA	{"email": "tnikolaeva-1973@postgrespro.ru", "phone": "+70246205390"}
0005434025208	32EA24	9779 518792	ANASTASIYA SOROKINA	{"email": "sorokinaanastasiya.24031982@postgrespro.ru", "phone": "+70400538336"}
0005434025209	B42693	7360 148545	SAVELIY SEMENOV	{"phone": "+70464388507"}
0005434025210	B42693	0406 967356	TATYANA FEDOROVA	{"email": "fedorova.tatyana1973@postgrespro.ru", "phone": "+70372064091"}
0005434025211	DE9159	5672 642983	ANDREY MOISEEV	{"phone": "+70807892669"}
0005434025212	DE9159	5938 866809	ALBINA SCHERBAKOVA	{"phone": "+70772493517"}
0005434025213	8719CE	1592 176142	ALEKSANDRA LEBEDEVA	{"email": "aleksandra_lebedeva.1965@postgrespro.ru", "phone": "+70043643162"}
0005434025214	8719CE	8212 391764	IRINA KUZMINA	{"email": "kuzminairina_1965@postgrespro.ru", "phone": "+70149911811"}
0005434025215	F51D7C	2548 687680	ELENA IVANOVA	{"phone": "+70139650422"}
0005434025216	A3CFE2	5687 764229	RAMIL MATVEEV	{"email": "matveev.r_021967@postgrespro.ru", "phone": "+70708691416"}
0005434025217	A3CFE2	1260 178133	ANDREY GERASIMOV	{"phone": "+70197321589"}
0005434025218	C41BF7	5598 679938	ANDREY MAKAROV	{"email": "andrey.makarov1963@postgrespro.ru", "phone": "+70817614172"}
0005434025219	758BD1	1244 607750	SERGEY SERGEEV	{"email": "ssergeev.11011974@postgrespro.ru", "phone": "+70404237373"}
0005434025279	28B5D4	4402 863747	ALEKSANDR MIKHAYLOV	{"phone": "+70349503756"}
0005434025220	2C1400	6246 387734	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr-1971@postgrespro.ru", "phone": "+70828035411"}
0005434025221	2C1400	1592 806028	ARINA MOROZOVA	{"email": "morozova-a_01021971@postgrespro.ru", "phone": "+70684790140"}
0005434025222	52CBAB	6009 153326	DMITRIY EGOROV	{"phone": "+70524441194"}
0005434025223	52CBAB	5987 717364	IRINA NAZAROVA	{"email": "nazarova_irina1971@postgrespro.ru", "phone": "+70987703736"}
0005434025224	570333	2468 831507	LIDIYA FEDOROVA	{"phone": "+70039725666"}
0005434025225	CED24E	7069 890896	VIKTOR SIDOROV	{"email": "sidorov_v121976@postgrespro.ru", "phone": "+70760665320"}
0005434025226	E36DE6	0596 350598	RAISA OVCHINNIKOVA	{"phone": "+70121220706"}
0005434025227	42DCB1	6486 557572	TATYANA LEBEDEVA	{"phone": "+70906282135"}
0005434025228	B60C7E	0839 430471	OLGA LEBEDEVA	{"phone": "+70931059891"}
0005434025229	365700	6975 982213	KONSTANTIN ROMANOV	{"email": "k_romanov.14091973@postgrespro.ru", "phone": "+70922620812"}
0005434025230	365700	3094 606620	OLGA IVANOVA	{"email": "oivanova1978@postgrespro.ru", "phone": "+70380277871"}
0005434025231	365700	6815 622894	NATALYA KAZAKOVA	{"email": "kazakova-natalya091978@postgrespro.ru", "phone": "+70927152110"}
0005434025232	D51FFA	3950 008603	GENNADIY MIRONOV	{"email": "gennadiy.mironov_13051965@postgrespro.ru", "phone": "+70696065524"}
0005434025233	99CAB3	6328 451556	INNA NIKIFOROVA	{"email": "inikiforova_1979@postgrespro.ru", "phone": "+70755135385"}
0005434025234	EA6A9C	0784 838398	TATYANA MALYSHEVA	{"email": "t-malysheva.26071982@postgrespro.ru", "phone": "+70623668176"}
0005434025235	EA6A9C	4993 058933	DARYA IVANOVA	{"phone": "+70420033757"}
0005434025236	DEF033	4728 096217	ANASTASIYA ANISIMOVA	{"email": "a_anisimova.021974@postgrespro.ru", "phone": "+70070110733"}
0005434025237	5F5446	1240 904736	TATYANA IVANOVA	{"phone": "+70481862412"}
0005434025238	AC8626	8312 170213	GALINA GUSEVA	{"phone": "+70899163499"}
0005434025239	E42130	0654 666491	ANASTASIYA SAVELEVA	{"email": "a_saveleva18011979@postgrespro.ru", "phone": "+70319489341"}
0005434025240	E7F4C2	5062 714895	ALEKSANDR MATVEEV	{"email": "matveeva051973@postgrespro.ru", "phone": "+70270027960"}
0005434025241	E7F4C2	0158 436053	EVGENIYA MALYSHEVA	{"phone": "+70375020725"}
0005434025242	95E33A	1141 341815	ANATOLIY VASILEV	{"email": "anatoliy-vasilev_05081971@postgrespro.ru", "phone": "+70501536019"}
0005434025243	95E33A	7282 162652	VALENTINA KARPOVA	{"email": "v.karpova-081972@postgrespro.ru", "phone": "+70141176299"}
0005434025244	41B6C8	2046 382723	LYUDMILA SOROKINA	{"phone": "+70338622259"}
0005434025245	A42FE1	2746 849174	EKATERINA ZHURAVLEVA	{"email": "ekaterina.zhuravleva_1976@postgrespro.ru", "phone": "+70761992152"}
0005434025246	A42FE1	1147 327178	VITALIY MAKAROV	{"email": "v.makarov1964@postgrespro.ru", "phone": "+70046909867"}
0005434025247	30C30B	1217 595767	ALINA POPOVA	{"phone": "+70329032931"}
0005434025248	30C30B	9818 321336	ELENA SMIRNOVA	{"email": "e.smirnova1977@postgrespro.ru", "phone": "+70458142452"}
0005434025249	B8E3F5	9802 410163	ELENA ZAKHAROVA	{"email": "e_zakharova09061969@postgrespro.ru", "phone": "+70489729458"}
0005434025250	9A915F	1058 463091	IGOR GORBUNOV	{"phone": "+70487638096"}
0005434025251	9A915F	8701 981102	IRINA IVANOVA	{"email": "irinaivanova.041969@postgrespro.ru", "phone": "+70137026916"}
0005434025252	5E98E9	3255 157133	VALENTINA KOMAROVA	{"phone": "+70864641911"}
0005434025253	DB3310	3545 350222	LYUDMILA ROMANOVA	{"phone": "+70366169246"}
0005434025254	ECE53D	9803 227686	SVETLANA ZAKHAROVA	{"phone": "+70205392325"}
0005434025255	724B36	5307 830492	DAMIR BONDARENKO	{"email": "dbondarenko.25021972@postgrespro.ru", "phone": "+70653059281"}
0005434025256	724B36	8709 033338	YURIY MATVEEV	{"phone": "+70185291572"}
0005434025257	FE8428	9032 765268	IVAN VOLKOV	{"phone": "+70193162920"}
0005434025258	4412C6	7779 089489	ANDREY GAVRILOV	{"phone": "+70196314326"}
0005434025259	D3426F	3294 815052	ANDREY EGOROV	{"phone": "+70947820173"}
0005434025260	2D3019	9807 331234	EVGENIY KISELEV	{"email": "e.kiselev_1969@postgrespro.ru", "phone": "+70974585837"}
0005434025261	0A72DC	6870 415401	TATYANA BELYAEVA	{"email": "tatyanabelyaeva_021984@postgrespro.ru", "phone": "+70617627108"}
0005434025262	0A72DC	1273 017369	ANATOLIY SMIRNOV	{"email": "a.smirnov27121981@postgrespro.ru", "phone": "+70033747522"}
0005434025263	C5B6A0	0814 282381	VLADISLAV KULIKOV	{"email": "vladislav.kulikov12081967@postgrespro.ru", "phone": "+70597889026"}
0005434025264	C5B6A0	8348 945284	LYUDMILA FILIPPOVA	{"email": "lyudmila.filippova.1986@postgrespro.ru", "phone": "+70816109454"}
0005434025265	D9E6FC	0992 932135	DMITRIY KRASNOV	{"email": "dmitriy.krasnov-1972@postgrespro.ru", "phone": "+70852212815"}
0005434025266	2BA887	1913 382752	NADEZHDA ZAYCEVA	{"email": "zayceva.n06061968@postgrespro.ru", "phone": "+70542579981"}
0005434025267	DC64A6	8355 712912	EKATERINA ALEKSEEVA	{"phone": "+70613509587"}
0005434025268	ADBA94	2751 122029	MARIYA ZHUKOVA	{"email": "zhukova.mariya121968@postgrespro.ru", "phone": "+70038851284"}
0005434025269	0416F9	7223 446336	EVGENIY ANDREEV	{"phone": "+70145148519"}
0005434025270	49D90A	1055 058551	NIKOLAY SIDOROV	{"phone": "+70786527349"}
0005434025271	7000B8	6854 102851	EKATERINA PETROVA	{"email": "petrova_e.021972@postgrespro.ru", "phone": "+70235316030"}
0005434025272	99AC3B	7772 579062	PETR ZHURAVLEV	{"email": "zhuravlev_petr.15121982@postgrespro.ru", "phone": "+70069301431"}
0005434025273	99AC3B	9362 575680	VYACHESLAV OSIPOV	{"email": "vyacheslav_osipov.041985@postgrespro.ru", "phone": "+70895374321"}
0005434025274	99AC3B	2796 221692	ELENA SAVELEVA	{"email": "savelevae_29031977@postgrespro.ru", "phone": "+70449997095"}
0005434025275	52003D	3956 367943	YANA NIKOLAEVA	{"email": "ynikolaeva021971@postgrespro.ru", "phone": "+70720352693"}
0005434025276	A7BB35	7402 391700	RUSLAN SIDOROV	{"email": "sidorov_ruslan.1961@postgrespro.ru", "phone": "+70813958631"}
0005434025277	74D7DF	9890 739229	DENIS KUZNECOV	{"email": "kuznecov_denis.1957@postgrespro.ru", "phone": "+70349792223"}
0005434025280	F4374A	8890 720542	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya_05101977@postgrespro.ru", "phone": "+70528516910"}
0005434025281	F15684	1145 218203	TATYANA ROMANOVA	{"email": "romanova-tatyana_031975@postgrespro.ru", "phone": "+70476686652"}
0005434025282	FDD61B	7692 465034	ALEKSANDR POPOV	{"phone": "+70574195073"}
0005434025283	F5F70F	0745 995284	VALERIY ANTONOV	{"email": "antonov_valeriy.29071967@postgrespro.ru", "phone": "+70619983431"}
0005434025284	3DF0AD	2858 170887	NIKOLAY DMITRIEV	{"email": "dmitriev_n-071976@postgrespro.ru", "phone": "+70252952192"}
0005434025285	41B005	3896 920796	SERGEY DMITRIEV	{"email": "dmitriev_s.051974@postgrespro.ru", "phone": "+70978830779"}
0005434025286	65162F	7466 081608	OLGA ILINA	{"email": "o_ilina1962@postgrespro.ru", "phone": "+70790767680"}
0005434025287	65162F	0362 196103	VALENTINA TIMOFEEVA	{"phone": "+70807345949"}
0005434025288	EABB93	3805 312415	VIKTORIYA SOROKINA	{"phone": "+70913137858"}
0005434025289	FC9A74	9767 649450	MARIYA MARTYNOVA	{"phone": "+70461964442"}
0005434025290	C2AEC3	9399 684661	DARINA MOISEEVA	{"phone": "+70648276110"}
0005434025291	C2AEC3	8911 051941	NATALYA ZAYCEVA	{"phone": "+70677018103"}
0005434025292	DDF2A0	8980 794813	NIKOLAY GORBUNOV	{"phone": "+70358094478"}
0005434025293	545BA4	5353 005762	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov_101977@postgrespro.ru", "phone": "+70637705781"}
0005434025294	545BA4	4762 449315	MIKHAIL ISAEV	{"email": "isaev_m_081974@postgrespro.ru", "phone": "+70749168925"}
0005434025295	9DB6D3	0998 073197	NIKOLAY ILIN	{"phone": "+70532804958"}
0005434025296	C29C1A	4683 846613	YURIY YAKOVLEV	{"email": "yakovlev.yuriy091970@postgrespro.ru", "phone": "+70340360774"}
0005434025297	871297	1193 039470	VALERIY ALEKSEEV	{"email": "v_alekseev-19111983@postgrespro.ru", "phone": "+70440583518"}
0005434025298	7058A5	9970 944287	KRISTINA KUZNECOVA	{"phone": "+70474812062"}
0005434025299	D2C5AE	5592 804842	ALEKSANDR KUZMIN	{"phone": "+70968781466"}
0005434025300	6D0E38	8633 987884	ANTONINA VLASOVA	{"phone": "+70006641926"}
0005434025301	0C6D21	8744 666214	ANDREY DMITRIEV	{"phone": "+70660392516"}
0005434025302	13231B	8876 173500	OKSANA FADEEVA	{"phone": "+70928049988"}
0005434025303	2F2A13	7972 728383	NATALYA MEDVEDEVA	{"phone": "+70479936351"}
0005434025304	A23388	1983 190868	ANASTASIYA IVANOVA	{"phone": "+70033832880"}
0005434025305	82FB1F	3399 895524	ANASTASIYA KOLESNIKOVA	{"phone": "+70992906651"}
0005434025306	82FB1F	7869 925544	VYACHESLAV EGOROV	{"phone": "+70127756460"}
0005434025307	0F2800	0690 820085	SERGEY KUZMIN	{"phone": "+70628966154"}
0005434025308	A096DF	0917 258885	VIKTOR SAVELEV	{"phone": "+70838335614"}
0005434025309	518FAA	1576 234805	ALEKSANDR GRIGOREV	{"email": "aleksandr-grigorev1963@postgrespro.ru", "phone": "+70736843197"}
0005434025310	518FAA	4131 986084	KLARA LEBEDEVA	{"email": "lebedeva.k-19031979@postgrespro.ru", "phone": "+70443437101"}
0005434025311	9671B2	3870 572622	TAMARA BORISOVA	{"phone": "+70410087731"}
0005434025312	F6485E	3443 888523	MARIYA NAUMOVA	{"phone": "+70585217230"}
0005434025313	8E7418	1374 390185	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr1967@postgrespro.ru", "phone": "+70715782469"}
0005434025314	8E7418	4032 347442	VLADISLAV TARASOV	{"email": "vtarasov-23101958@postgrespro.ru", "phone": "+70247347590"}
0005434025315	13FAB6	9961 608093	ALEKSANDRA KAZAKOVA	{"email": "aleksandra.kazakova.1966@postgrespro.ru", "phone": "+70479888071"}
0005434025316	3251FA	0575 828506	INNA AFANASEVA	{"email": "afanaseva-inna-031982@postgrespro.ru", "phone": "+70423263175"}
0005434025317	E406BC	8796 134077	ANDREY PETROV	{"email": "andreypetrov_031977@postgrespro.ru", "phone": "+70130536854"}
0005434025318	E7D5F8	8430 298555	VLADIMIR SIDOROV	{"email": "sidorovvladimir_121970@postgrespro.ru", "phone": "+70241738639"}
0005434025319	E7D5F8	1905 309229	VALERIY VLASOV	{"email": "valeriyvlasov1974@postgrespro.ru", "phone": "+70425090999"}
0005434025320	E7D5F8	9715 712007	VALENTINA SEMENOVA	{"email": "v-semenova-1962@postgrespro.ru", "phone": "+70869822581"}
0005434025321	C22E8E	0866 727085	SERGEY GRIGOREV	{"email": "sergeygrigorev.111983@postgrespro.ru", "phone": "+70155283065"}
0005434025322	2F7050	2176 807721	VADIM VOROBEV	{"phone": "+70574084888"}
0005434025323	FC55EC	1112 524782	MARIYA MALYSHEVA	{"email": "malysheva-mariya051978@postgrespro.ru", "phone": "+70679525104"}
0005434025324	FC55EC	6042 921593	LYUBOV ABRAMOVA	{"email": "abramova-lyubov-1974@postgrespro.ru", "phone": "+70054967039"}
0005434025325	6B24BA	1662 647782	IRINA LEBEDEVA	{"phone": "+70533347870"}
0005434025326	6B24BA	6682 615372	TATYANA GAVRILOVA	{"phone": "+70280113803"}
0005434025327	96BADD	9845 801904	VITALIY SEMENOV	{"phone": "+70268878405"}
0005434025328	DD3E75	8686 580436	ALENA MAKSIMOVA	{"email": "maksimova_a_041973@postgrespro.ru", "phone": "+70625246481"}
0005434025329	DD3E75	1881 930077	YURIY SCHERBAKOV	{"phone": "+70132865070"}
0005434025330	DD3E75	4470 707015	TATYANA IVANOVA	{"phone": "+70620942193"}
0005434025331	635894	5050 125199	VLADIMIR POPOV	{"email": "popov-v_011975@postgrespro.ru", "phone": "+70619106925"}
0005434025332	635894	0675 467431	ALEKSANDR MAKAROV	{"phone": "+70068665777"}
0005434025333	47637E	5420 071602	ALINA POPOVA	{"email": "popova-alina_20091975@postgrespro.ru", "phone": "+70160452773"}
0005434025334	47637E	3479 908423	NINA MEDVEDEVA	{"email": "medvedeva_n041969@postgrespro.ru", "phone": "+70043356940"}
0005434025335	AAD8E7	8841 244637	VALERIY VASILEV	{"email": "vasilev-valeriy021985@postgrespro.ru", "phone": "+70705432658"}
0005434025336	334DB6	4685 741649	ELENA KUDRYASHOVA	{"phone": "+70399549411"}
0005434025337	4BEF7B	7026 010324	VIKTORIYA GAVRILOVA	{"email": "v-gavrilova08021977@postgrespro.ru", "phone": "+70179800868"}
0005434025338	4BEF7B	9172 278896	ANTONINA TROFIMOVA	{"email": "a_trofimova.051974@postgrespro.ru", "phone": "+70143295915"}
0005434025339	E69CE0	5017 982302	YURIY SIDOROV	{"phone": "+70276579597"}
0005434025340	CE1567	3142 368511	VALENTIN BARANOV	{"phone": "+70899508959"}
0005434025341	F4A817	5408 687319	OKSANA KOZLOVA	{"email": "oksana.kozlova_1973@postgrespro.ru", "phone": "+70221079036"}
0005434025342	619912	6097 084863	ROMAN TARASOV	{"email": "roman-tarasov_071970@postgrespro.ru", "phone": "+70523687141"}
0005434025343	BE628F	6749 194000	BORIS SERGEEV	{"phone": "+70653220418"}
0005434025344	3B7179	8730 768271	NIKOLAY MELNIKOV	{"phone": "+70913617972"}
0005434025345	3B7179	3518 826526	SERGEY DAVYDOV	{"email": "s_davydov-29031976@postgrespro.ru", "phone": "+70395632053"}
0005434025346	9BF4CE	7580 577001	PETR OSIPOV	{"phone": "+70856678910"}
0005434025347	9BF4CE	5500 169865	DANIIL KONOVALOV	{"phone": "+70253596480"}
0005434025348	9BF4CE	5309 345796	LYUBOV IVANOVA	{"phone": "+70812709761"}
0005434025349	9BF4CE	6301 910030	KONSTANTIN SCHERBAKOV	{"phone": "+70569026791"}
0005434025350	9BF4CE	8567 608992	DMITRIY KUZNECOV	{"phone": "+70048232859"}
0005434025351	17D394	1652 990541	VALENTIN PAVLOV	{"email": "valentin-pavlov-021963@postgrespro.ru", "phone": "+70246391274"}
0005434025352	17D394	5462 851451	LYUDMILA KOLESNIKOVA	{"email": "lyudmila_kolesnikova1955@postgrespro.ru", "phone": "+70978013176"}
0005434025353	B6D356	2158 489665	SERGEY ROMANOV	{"email": "romanov-sergey-26041968@postgrespro.ru", "phone": "+70320534607"}
0005434025354	B6D356	9105 017402	VALENTINA ZOTOVA	{"email": "vzotova121975@postgrespro.ru", "phone": "+70477137471"}
0005434025355	B6D356	2311 090762	NINA NESTEROVA	{"email": "nesterovanina-1965@postgrespro.ru", "phone": "+70877942783"}
0005434025356	B6D356	0326 374080	SVETLANA GAVRILOVA	{"email": "svetlana.gavrilova_01061963@postgrespro.ru", "phone": "+70461737997"}
0005434025357	B30293	2874 998138	SERGEY SOKOLOV	{"phone": "+70766892954"}
0005434025358	FA42DC	0605 627567	SVETLANA OSIPOVA	{"phone": "+70271015917"}
0005434025359	659BF2	1503 855667	IVAN MELNIKOV	{"phone": "+70160100373"}
0005434025360	8C6C81	8754 872501	TATYANA NESTEROVA	{"email": "tatyana.nesterova-19041980@postgrespro.ru", "phone": "+70587266446"}
0005434025361	8C6C81	1140 032971	ANNA KONDRATEVA	{"phone": "+70059160907"}
0005434025362	8BC5A8	4297 498570	VALENTINA MASLOVA	{"phone": "+70400998315"}
0005434025363	C4269E	4000 508991	YURIY KUZNECOV	{"email": "kuznecov_y_071960@postgrespro.ru", "phone": "+70511467440"}
0005434025364	C4269E	0897 104274	NATALYA MAKAROVA	{"email": "natalya.makarova.1972@postgrespro.ru", "phone": "+70763802239"}
0005434025365	5F635E	0750 099992	RAMIL SERGEEV	{"email": "sergeev.r-011976@postgrespro.ru", "phone": "+70834493001"}
0005434025366	720478	7773 400754	DMITRIY FROLOV	{"phone": "+70887421931"}
0005434025367	9908E2	5528 841953	LYUDMILA ANTONOVA	{"email": "lantonova-061978@postgrespro.ru", "phone": "+70272323629"}
0005434025368	56CBA3	9575 752435	DENIS KUDRYASHOV	{"phone": "+70396542179"}
0005434025369	56CBA3	2131 759833	EGOR MAKSIMOV	{"email": "e.maksimov-22021970@postgrespro.ru", "phone": "+70591230944"}
0005434025370	36544F	9446 967142	MAKSIM KUZMIN	{"email": "m.kuzmin-1960@postgrespro.ru", "phone": "+70969839788"}
0005434025371	44ACEC	4756 066599	ALEKSANDR KAZAKOV	{"phone": "+70855634548"}
0005434025372	2F7F24	3334 774863	ANNA EFREMOVA	{"email": "efremova_a_22021977@postgrespro.ru", "phone": "+70078938951"}
0005434025373	E71722	1589 815494	VALENTINA MARTYNOVA	{"phone": "+70462883251"}
0005434025374	E71722	4113 471220	PELAGEYA MAKAROVA	{"email": "makarovap_12091966@postgrespro.ru", "phone": "+70460565513"}
0005434025375	414EF2	1845 597844	MAKSIM YAKOVLEV	{"phone": "+70369761084"}
0005434025376	BD3751	1674 345597	EVGENIY PETROV	{"email": "petrov-evgeniy-101970@postgrespro.ru", "phone": "+70132578259"}
0005434025377	387EB5	1410 714243	ANASTASIYA FOMINA	{"phone": "+70910473944"}
0005434025378	B94EC6	7393 074267	VALENTINA NIKITINA	{"phone": "+70071293609"}
0005434025379	4DD5C7	3679 586235	VLADIMIR NOVIKOV	{"phone": "+70228407346"}
0005434025380	4DD5C7	5301 562061	VALENTINA DAVYDOVA	{"phone": "+70426525234"}
0005434025381	A78F66	0127 865223	VERA MAKAROVA	{"phone": "+70123759870"}
0005434025382	A78F66	1046 586820	DMITRIY ABRAMOV	{"phone": "+70218262007"}
0005434025383	7BBB93	6259 505444	EKATERINA IVANOVA	{"phone": "+70979194097"}
0005434025384	5D07AF	1042 508061	MIKHAIL ANDREEV	{"phone": "+70495660680"}
0005434025385	5698DE	6118 280767	GENNADIY KOZLOV	{"email": "kozlov-gennadiy.1977@postgrespro.ru", "phone": "+70174351734"}
0005434025386	5698DE	2911 156963	ANDREY VASILEV	{"phone": "+70422064125"}
0005434025387	4BAE0D	0320 180980	VERA NIKOLAEVA	{"email": "nikolaevavera-091956@postgrespro.ru", "phone": "+70392006858"}
0005434025388	4BAE0D	8385 823758	LYUDMILA IVANOVA	{"phone": "+70826594063"}
0005434025389	3C66C9	6706 371819	TATYANA TIKHONOVA	{"email": "tikhonovat_1964@postgrespro.ru", "phone": "+70168379117"}
0005434025390	3C66C9	2228 892014	MAKSIM MELNIKOV	{"email": "melnikov_maksim.06061967@postgrespro.ru", "phone": "+70557141984"}
0005434025391	9BB98E	5497 874395	DMITRIY VOLKOV	{"phone": "+70207962585"}
0005434025392	9BB98E	8648 624341	TIKHON PETROV	{"phone": "+70887072044"}
0005434025393	463B4A	7925 963401	ANDREY KARPOV	{"phone": "+70047656694"}
0005434025394	463B4A	5677 800025	VADIM SEMENOV	{"phone": "+70253325822"}
0005434025395	9D58E7	1867 311813	NIKOLAY CHERNOV	{"email": "nikolay.chernov-111966@postgrespro.ru", "phone": "+70445544608"}
0005434025396	C60203	1823 325486	VITALIY MOISEEV	{"email": "v-moiseev.1972@postgrespro.ru", "phone": "+70785626525"}
0005434025397	68FEC0	4829 518205	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-1976@postgrespro.ru", "phone": "+70332457615"}
0005434025398	A40FD5	2494 120849	ANATOLIY KUZMIN	{"phone": "+70931898957"}
0005434025399	04167A	8537 318948	TATYANA SOROKINA	{"phone": "+70461960246"}
0005434025400	C2660F	9501 754024	NATALYA POPOVA	{"email": "natalya_popova.23121961@postgrespro.ru", "phone": "+70940072394"}
0005434025401	C3245A	2509 377846	EVGENIY GORBUNOV	{"phone": "+70786296751"}
0005434025402	C3245A	2792 234677	NADEZHDA KOMAROVA	{"phone": "+70066823426"}
0005434025403	1C9F85	5784 751360	NATALIYA POPOVA	{"email": "popova.n.29111974@postgrespro.ru", "phone": "+70915652131"}
0005434025404	1C9F85	1136 555384	NINA KRASNOVA	{"email": "krasnovanina11071981@postgrespro.ru", "phone": "+70275209182"}
0005434025405	475471	5258 149934	NADEZHDA SMIRNOVA	{"phone": "+70146062165"}
0005434025406	BBA8F1	9737 422984	NATALYA IVANOVA	{"email": "n-ivanova_17051961@postgrespro.ru", "phone": "+70168208971"}
0005434025407	48C27F	1947 417887	EKATERINA LAZAREVA	{"email": "e-lazareva.08121979@postgrespro.ru", "phone": "+70933482321"}
0005434025408	EABEE9	5876 189092	KRISTINA KOLESNIKOVA	{"email": "kolesnikova_k.1972@postgrespro.ru", "phone": "+70911115874"}
0005434025409	EABEE9	9098 161209	MARINA MIRONOVA	{"phone": "+70375376500"}
0005434025410	4C5307	4350 358912	ROMAN YAKOVLEV	{"phone": "+70263375768"}
0005434025411	4C5307	4471 138988	ROMAN BELOV	{"phone": "+70104741866"}
0005434025412	6C1D96	5404 651492	MARAT DAVYDOV	{"email": "davydovm121970@postgrespro.ru", "phone": "+70169749010"}
0005434025413	6C1D96	7514 966116	NADEZHDA MELNIKOVA	{"phone": "+70500307987"}
0005434025414	B599E2	4065 190715	OKSANA KULIKOVA	{"phone": "+70568141167"}
0005434025415	B599E2	6171 931704	IGOR NAUMOV	{"email": "i-naumov-10121975@postgrespro.ru", "phone": "+70304243083"}
0005434025416	DA91B2	6075 782567	LARISA LAZAREVA	{"phone": "+70504588632"}
0005434025417	DA91B2	5247 902326	ANATOLIY SAVELEV	{"email": "savelev.a-031972@postgrespro.ru", "phone": "+70892472447"}
0005434025418	47FE3D	5353 156304	ALEKSEY KRASNOV	{"email": "a.krasnov.25121980@postgrespro.ru", "phone": "+70960985314"}
0005434025419	47FE3D	0620 396851	VALERIY KOROLEV	{"email": "v-korolev_06021979@postgrespro.ru", "phone": "+70849056834"}
0005434025420	47FE3D	4437 686657	SERGEY GORBUNOV	{"phone": "+70074150945"}
0005434025421	896BCC	0776 913212	TATYANA NIKOLAEVA	{"email": "nikolaeva.tatyana-051973@postgrespro.ru", "phone": "+70311599893"}
0005434025422	896BCC	7979 272549	VARVARA OSIPOVA	{"phone": "+70296363044"}
0005434025423	2626AB	1150 443930	EVGENIY SOLOVEV	{"email": "evgeniy_solovev-07021973@postgrespro.ru", "phone": "+70347367445"}
0005434025424	2626AB	4203 625064	OLGA DENISOVA	{"email": "denisova.o-14041970@postgrespro.ru", "phone": "+70581630842"}
0005434025425	C5D23B	0421 694528	VYACHESLAV KRASNOV	{"email": "v_krasnov_26091969@postgrespro.ru", "phone": "+70576457084"}
0005434025426	C5D23B	0706 823235	ALEKSANDR POPOV	{"email": "popov-aleksandr-1966@postgrespro.ru", "phone": "+70405345945"}
0005434025427	FD2104	4755 530869	NATALYA EGOROVA	{"phone": "+70483872070"}
0005434025428	FD2104	9637 187866	IVAN POPOV	{"email": "popov.i.051982@postgrespro.ru", "phone": "+70329246374"}
0005434025429	5177ED	7149 739030	ANNA PETROVA	{"phone": "+70907203681"}
0005434025430	FEAD2F	1901 945167	ROMAN KOZLOV	{"email": "rkozlov041970@postgrespro.ru", "phone": "+70028856040"}
0005434025431	5FBA86	5932 341062	ANATOLIY KUZNECOV	{"phone": "+70955328704"}
0005434025432	D2E4A9	2038 739337	GENNADIY IVANOV	{"email": "gennadiy_ivanov_101971@postgrespro.ru", "phone": "+70993176668"}
0005434025433	4DC03C	6614 122917	ALEKSANDR ABRAMOV	{"phone": "+70409843150"}
0005434025434	D0D348	6706 780248	NIKITA ANTONOV	{"email": "antonov_n_1975@postgrespro.ru", "phone": "+70987076607"}
0005434025435	3393AE	3094 617917	KLAVDIYA KONDRATEVA	{"phone": "+70997270338"}
0005434025436	0D57B7	2209 013912	ARTEM SHEVCHENKO	{"phone": "+70098576861"}
0005434025437	0D57B7	5637 936455	IGOR KOZLOV	{"phone": "+70699719008"}
0005434025438	981109	9834 258032	ALEKSEY MIRONOV	{"phone": "+70530135968"}
0005434025439	8F173A	8606 230368	FAIL ALEKSANDROV	{"phone": "+70533180169"}
0005434025440	8F173A	6541 512910	EKATERINA ZAKHAROVA	{"email": "ekaterina.zakharova.1967@postgrespro.ru", "phone": "+70808753625"}
0005434025441	006F53	5441 421380	VALERIY MELNIKOV	{"email": "melnikov.valeriy-1981@postgrespro.ru", "phone": "+70657352096"}
0005434025442	F58BF4	2882 853086	NINA KAZAKOVA	{"phone": "+70192836550"}
0005434025443	7C59D8	9029 407404	VALENTINA MIRONOVA	{"phone": "+70449800247"}
0005434025444	D0170D	4440 886255	ELENA MIRONOVA	{"phone": "+70825391496"}
0005434025445	D0170D	9940 627394	ALEKSANDR MOROZOV	{"email": "a.morozov121984@postgrespro.ru", "phone": "+70331827619"}
0005434025446	E05F18	9652 039295	VALENTINA YAKOVLEVA	{"phone": "+70153037929"}
0005434025447	198B33	9791 217158	MARIYA IVANOVA	{"phone": "+70587623687"}
0005434025448	198B33	1737 917622	SERGEY GORBUNOV	{"email": "gorbunov_s051960@postgrespro.ru", "phone": "+70444425840"}
0005434025449	B377C4	2073 407179	ALEKSANDR KUZNECOV	{"email": "kuznecov_a16011968@postgrespro.ru", "phone": "+70155244720"}
0005434025450	DF9900	4593 668633	VASILIY MOISEEV	{"phone": "+70906767039"}
0005434025451	AB0832	1859 535539	ALLA ERMAKOVA	{"email": "ermakova_a_041962@postgrespro.ru", "phone": "+70010255848"}
0005434025452	F446C2	2634 699367	ANNA GUSEVA	{"email": "guseva.a-051978@postgrespro.ru", "phone": "+70713638598"}
0005434025453	76519E	6957 744714	SVETLANA MASLOVA	{"phone": "+70312783236"}
0005434025454	76519E	2447 327904	VALERIY PETROV	{"email": "petrov-valeriy_091973@postgrespro.ru", "phone": "+70060847165"}
0005434025455	3D161C	6415 518910	ALINA POLYAKOVA	{"email": "polyakova_alina-081964@postgrespro.ru", "phone": "+70436302527"}
0005434025456	2C57A5	0524 050391	KIRILL IVANOV	{"email": "ivanov.kirill_1972@postgrespro.ru", "phone": "+70801991940"}
0005434025457	30DB81	6471 484904	ALEKSANDR MARTYNOV	{"email": "aleksandr.martynov.061966@postgrespro.ru", "phone": "+70843729583"}
0005434025458	42E3A4	0936 879537	KRISTINA LOGINOVA	{"phone": "+70351914649"}
0005434025459	46A70A	8027 181711	EVGENIY KOROLEV	{"phone": "+70699244486"}
0005434025460	5986F7	1115 096561	IGOR KUZNECOV	{"phone": "+70853402296"}
0005434025461	603C73	2535 768602	MIKHAIL GRIGOREV	{"email": "grigorevmikhail.10081981@postgrespro.ru", "phone": "+70724700045"}
0005434025462	402922	4809 218383	SERGEY BONDARENKO	{"phone": "+70675852571"}
0005434025463	B3C52D	3137 586568	ANNA BOGDANOVA	{"phone": "+70747832811"}
0005434025464	064643	4604 279705	VLADIMIR ALEKSANDROV	{"phone": "+70411853844"}
0005434025465	EEAD17	7020 956041	DARYA POLYAKOVA	{"phone": "+70479197480"}
0005434025466	3B8E3F	6933 703217	OLGA PETROVA	{"email": "o.petrova.1960@postgrespro.ru", "phone": "+70385968807"}
0005434025467	541576	6760 725422	IRINA GORBUNOVA	{"phone": "+70600184159"}
0005434025468	115372	8927 736889	VALENTINA NIKIFOROVA	{"phone": "+70829494442"}
0005434025469	115372	9626 343558	IRINA SAVELEVA	{"phone": "+70291685951"}
0005434025470	9F452D	6403 751904	VIKTORIYA POPOVA	{"phone": "+70258857135"}
0005434025471	545732	7651 503789	ZOYA ERMAKOVA	{"email": "ermakovaz-1971@postgrespro.ru", "phone": "+70169972060"}
0005434025472	545732	8078 001963	ARINA ANTONOVA	{"phone": "+70768545543"}
0005434025473	6396E4	2137 646864	MAKSIM NAUMOV	{"email": "maksim-naumov.031973@postgrespro.ru", "phone": "+70434309136"}
0005434025474	696A24	2537 881853	ROMAN NIKOLAEV	{"email": "r_nikolaev_121974@postgrespro.ru", "phone": "+70695080206"}
0005434025475	610E73	0798 132133	MIKHAIL STEPANOV	{"phone": "+70918814766"}
0005434025476	357C4D	5839 517042	POLINA VOROBEVA	{"phone": "+70651671128"}
0005434025477	70D6E3	7426 871727	ANDREY RODIONOV	{"phone": "+70433398156"}
0005434025478	70D6E3	7033 917562	VERA NIKOLAEVA	{"email": "v_nikolaeva.05031967@postgrespro.ru", "phone": "+70832129899"}
0005434025479	192F86	9612 048629	ALEKSEY NIKOLAEV	{"email": "a-nikolaev23091972@postgrespro.ru", "phone": "+70190154317"}
0005434025480	3EA856	6986 253225	RAFAEL CHERNOV	{"email": "chernovr-1970@postgrespro.ru", "phone": "+70548692335"}
0005434025481	3EA856	0902 163713	DAVID SOLOVEV	{"phone": "+70569896507"}
0005434025482	1EAC9F	9777 529135	ALEKSANDR KUZNECOV	{"phone": "+70046589639"}
0005434025483	1DC4BF	0346 003622	GALINA ISAEVA	{"phone": "+70949533125"}
0005434025484	3C816E	1740 355320	OLGA KOMAROVA	{"phone": "+70309325689"}
0005434025485	3C816E	7803 306017	ANTONINA SCHERBAKOVA	{"phone": "+70092015483"}
0005434025486	C9FA3A	2125 006306	DMITRIY KULIKOV	{"phone": "+70715889064"}
0005434025487	D71115	9831 671882	IRINA NOVIKOVA	{"phone": "+70168435448"}
0005434025488	F9DE96	5132 594977	NADEZHDA MOISEEVA	{"phone": "+70542223904"}
0005434025489	0B68F7	5018 037012	ALEKSANDR POPOV	{"email": "aleksandr-popov_1973@postgrespro.ru", "phone": "+70827151438"}
0005434025490	AAAF25	0701 675227	IRINA KUZNECOVA	{"phone": "+70338456791"}
0005434025491	AAAF25	0939 250793	VLADIMIR PAVLOV	{"email": "v_pavlov_121971@postgrespro.ru", "phone": "+70740719827"}
0005434025492	E9266F	7136 720775	NATALYA VOROBEVA	{"phone": "+70877720356"}
0005434025493	E9266F	2593 982153	GALINA YAKOVLEVA	{"phone": "+70914272362"}
0005434025494	F1AD58	3391 437009	ANDREY ZAKHAROV	{"email": "zakharovandrey.20111971@postgrespro.ru", "phone": "+70036975769"}
0005434025495	723D5B	7126 506540	VLADIMIR MOROZOV	{"email": "vladimir-morozov_1976@postgrespro.ru", "phone": "+70381661056"}
0005434025496	B9A608	2836 622735	DARYA ZAYCEVA	{"email": "zayceva_darya-01051976@postgrespro.ru", "phone": "+70282899406"}
0005434025497	B9A608	4765 018793	ILMIR KRASNOV	{"phone": "+70303923743"}
0005434025498	B8DFE5	7413 163931	NINA MOROZOVA	{"phone": "+70711822733"}
0005434025499	B8DFE5	5808 140095	DMITRIY KARPOV	{"email": "d_karpov_011974@postgrespro.ru", "phone": "+70454006781"}
0005434025500	B8DFE5	3768 212941	ILYA ZHURAVLEV	{"email": "i_zhuravlev_1972@postgrespro.ru", "phone": "+70894438578"}
0005434025501	6C1589	4721 191478	OLGA MALYSHEVA	{"email": "malysheva.o_05011959@postgrespro.ru", "phone": "+70384371937"}
0005434025502	EB41B4	9659 709547	NATALYA VOLKOVA	{"phone": "+70173238162"}
0005434025503	E41B49	8983 538123	TATYANA TARASOVA	{"email": "tarasova_tatyana.24101971@postgrespro.ru", "phone": "+70100298991"}
0005434025504	E41B49	5393 793078	SERGEY FEDOROV	{"email": "sergey_fedorov-09041966@postgrespro.ru", "phone": "+70716078450"}
0005434025505	562E82	0394 398961	ANDREY NAUMOV	{"phone": "+70506699901"}
0005434025506	BB10BF	6936 974313	VITALIY PETROV	{"email": "v-petrov.25061965@postgrespro.ru", "phone": "+70412951531"}
0005434025507	56DF1B	5034 110183	TATYANA FILIPPOVA	{"email": "t.filippova_111980@postgrespro.ru", "phone": "+70112434001"}
0005434025508	DD6A70	6188 070206	EKATERINA AFANASEVA	{"phone": "+70378924388"}
0005434025509	451505	4045 480915	ANDREY GRIGOREV	{"email": "grigorev_andrey19081974@postgrespro.ru", "phone": "+70037911359"}
0005434025510	3F4FA3	5224 828441	ALEKSANDRA KRASNOVA	{"phone": "+70329587354"}
0005434025511	3F4FA3	6577 752784	NINA ISAEVA	{"phone": "+70192651776"}
0005434025512	03FD9C	5193 578141	YULIYA TIMOFEEVA	{"email": "y.timofeeva-011965@postgrespro.ru", "phone": "+70863485884"}
0005434025513	03FD9C	6578 536899	NATALYA LAZAREVA	{"phone": "+70261311661"}
0005434025514	03FD9C	3827 140383	NATALYA FADEEVA	{"phone": "+70874228111"}
0005434025515	58F7E2	4856 683516	VARVARA SOROKINA	{"phone": "+70284538195"}
0005434025516	9DC3D0	9758 475127	VLADIMIR VASILEV	{"phone": "+70810320270"}
0005434025517	D9E7AB	5982 232664	ANATOLIY MATVEEV	{"email": "matveeva051961@postgrespro.ru", "phone": "+70842575634"}
0005434025518	81AFAC	5524 186079	EKATERINA TARASOVA	{"phone": "+70561939086"}
0005434025519	ADC45A	8766 328791	VALERIY CHERNOV	{"email": "v.chernov.041965@postgrespro.ru", "phone": "+70566779960"}
0005434025520	C126CC	6021 921893	ROSTISLAV BONDARENKO	{"email": "bondarenkor.1974@postgrespro.ru", "phone": "+70412962511"}
0005434025521	EE7666	6507 987365	ANNA AFANASEVA	{"phone": "+70924023910"}
0005434025522	1A5DC2	1577 741733	OKSANA KALININA	{"phone": "+70154238090"}
0005434025523	1A5DC2	5521 634393	SERGEY ALEKSANDROV	{"email": "aleksandrov.s_1961@postgrespro.ru", "phone": "+70596780788"}
0005434025524	21E611	8877 169201	ANTON ROMANOV	{"phone": "+70069973160"}
0005434025525	3E367D	2185 831234	GEORGIY SCHERBAKOV	{"phone": "+70093555036"}
0005434025526	3C5136	7377 549191	SERGEY SCHERBAKOV	{"email": "sergeyscherbakov.25101966@postgrespro.ru", "phone": "+70352721758"}
0005434025527	3C5136	0613 583324	VLADISLAV GRIGOREV	{"email": "vgrigorev111984@postgrespro.ru", "phone": "+70343906762"}
0005434025528	52F014	7772 702542	VALENTINA DANILOVA	{"email": "valentina-danilova-021961@postgrespro.ru", "phone": "+70462790049"}
0005434025529	52F014	8571 826866	PAVEL MELNIKOV	{"phone": "+70766353319"}
0005434025530	359860	1264 972571	FEDOR VASILEV	{"email": "vasilev.fedor-23031980@postgrespro.ru", "phone": "+70578876381"}
0005434025531	597F85	0017 016474	SVETLANA BORISOVA	{"email": "borisova_svetlana.16011960@postgrespro.ru", "phone": "+70489863192"}
0005434025532	597F85	8369 894605	SERGEY KUZNECOV	{"phone": "+70764178088"}
0005434025533	E54566	8917 052394	ANATOLIY MIRONOV	{"phone": "+70976901144"}
0005434025534	5C74C1	3319 550551	MARIYA SIDOROVA	{"email": "sidorova_m.1970@postgrespro.ru", "phone": "+70630692385"}
0005434025535	A8942A	7657 167247	DANIL ZAYCEV	{"phone": "+70335232128"}
0005434025536	8D3343	2270 278109	TATYANA NOVIKOVA	{"email": "novikovatatyana-041987@postgrespro.ru", "phone": "+70723416835"}
0005434025594	0A7D71	2844 733304	VALENTINA ROMANOVA	{"phone": "+70906539162"}
0005434025537	8D3343	0210 742134	IRAIDA ROMANOVA	{"email": "romanova-iraida-011968@postgrespro.ru", "phone": "+70215606991"}
0005434025538	931066	5311 554514	OLESYA SCHERBAKOVA	{"phone": "+70573413774"}
0005434025539	9754D4	0378 451964	SVETLANA ORLOVA	{"email": "orlova-s.22021967@postgrespro.ru", "phone": "+70281026451"}
0005434025540	128042	7879 551246	EKATERINA ALEKSANDROVA	{"email": "ekaterina_aleksandrova12121964@postgrespro.ru", "phone": "+70319778215"}
0005434025541	128042	1352 649148	RIMMA NIKITINA	{"phone": "+70501013386"}
0005434025542	31B6B1	8684 763939	GENNADIY DAVYDOV	{"email": "g_davydov-1973@postgrespro.ru", "phone": "+70502849691"}
0005434025543	931D17	8428 283985	TATYANA MAKSIMOVA	{"email": "t-maksimova_03081981@postgrespro.ru", "phone": "+70877249196"}
0005434025544	931D17	9714 039397	PAVEL KUZMIN	{"email": "pkuzmin_1981@postgrespro.ru", "phone": "+70177836620"}
0005434025545	B202AE	6965 481789	OLGA IVANOVA	{"phone": "+70637357504"}
0005434025546	B202AE	1364 045391	VALERIY SMIRNOV	{"phone": "+70250888324"}
0005434025547	0EFC64	1414 802224	NATALYA SCHERBAKOVA	{"phone": "+70703703111"}
0005434025548	9C80A4	2820 107349	INNA SEMENOVA	{"email": "i.semenova_011965@postgrespro.ru", "phone": "+70087821271"}
0005434025549	2ACA67	7128 690097	ZOYA POPOVA	{"phone": "+70432572489"}
0005434025550	D2C2CB	3846 758435	DENIS MAKSIMOV	{"phone": "+70956086344"}
0005434025551	3BCF04	2893 895407	MIKHAIL ILIN	{"phone": "+70720756348"}
0005434025552	793C6A	2377 125581	VYACHESLAV NOVIKOV	{"email": "novikovv1975@postgrespro.ru", "phone": "+70160161296"}
0005434025553	793C6A	5687 953617	MIKHAIL VLASOV	{"phone": "+70622530650"}
0005434025554	793C6A	9311 532329	MIKHAIL FROLOV	{"email": "mikhailfrolov_011972@postgrespro.ru", "phone": "+70983589661"}
0005434025555	28BC8D	8824 112568	NIKOLAY POPOV	{"email": "popov.nikolay27071974@postgrespro.ru", "phone": "+70524357396"}
0005434025556	919D60	5025 564695	ANDREY IVANOV	{"phone": "+70044914667"}
0005434025557	919D60	4352 730619	OLESYA SMIRNOVA	{"email": "smirnova_o.051969@postgrespro.ru", "phone": "+70818174448"}
0005434025558	F8FFA4	9942 128331	ELENA EFREMOVA	{"phone": "+70448174871"}
0005434025559	7C9C44	9480 793350	YURIY ANDREEV	{"email": "yuriy-andreev.04021977@postgrespro.ru", "phone": "+70307396921"}
0005434025560	6D1AEE	6577 800360	YURIY SEMENOV	{"phone": "+70586718016"}
0005434025561	D31A02	5443 621381	IRINA KONOVALOVA	{"email": "konovalova_irina_10081968@postgrespro.ru", "phone": "+70756252040"}
0005434025562	D31A02	0693 625906	LYUBOV ARKHIPOVA	{"phone": "+70673690689"}
0005434025563	145E44	2575 448250	YURIY NAUMOV	{"phone": "+70071568170"}
0005434025564	145E44	7511 366939	KSENIYA NIKOLAEVA	{"phone": "+70534551949"}
0005434025565	145E44	7723 738577	SERGEY OSIPOV	{"email": "sergey.osipov-1966@postgrespro.ru", "phone": "+70664788629"}
0005434025566	58AEA2	8571 478618	MARIYA SERGEEVA	{"phone": "+70032153886"}
0005434025567	C69143	4310 135931	IVAN TARASOV	{"email": "tarasov-i.1975@postgrespro.ru", "phone": "+70529039847"}
0005434025568	6794BA	7302 081318	ANATOLIY SIDOROV	{"email": "sidorov_anatoliy.1972@postgrespro.ru", "phone": "+70224306907"}
0005434025569	16ECFC	1756 985408	VLADIMIR SERGEEV	{"phone": "+70449936653"}
0005434025570	16ECFC	6716 343525	VLADIMIR GUSEV	{"phone": "+70823261703"}
0005434025571	A0A617	1686 582194	ILGIZ SAVELEV	{"email": "savelev-ilgiz_03021964@postgrespro.ru", "phone": "+70399345273"}
0005434025572	A0A617	8330 658136	SVETLANA FROLOVA	{"email": "sfrolova12051971@postgrespro.ru", "phone": "+70761170122"}
0005434025573	FD4046	3580 067878	BORIS KOZLOV	{"email": "boris_kozlov08021975@postgrespro.ru", "phone": "+70822697559"}
0005434025574	0A046B	4938 448884	IVAN GORBUNOV	{"phone": "+70668974670"}
0005434025575	0A046B	0578 002828	DMITRIY GRIGOREV	{"email": "grigorev.dmitriy-21011974@postgrespro.ru", "phone": "+70734058985"}
0005434025576	CB503C	4632 460306	VERA YUDINA	{"phone": "+70900567426"}
0005434025577	CB503C	9092 724599	DARYA CHERNOVA	{"phone": "+70094950718"}
0005434025578	5F17A0	4870 588548	VERA GAVRILOVA	{"email": "gavrilova_vera09061968@postgrespro.ru", "phone": "+70400934136"}
0005434025579	E59001	7497 834090	OKSANA ANTONOVA	{"email": "antonovaoksana021977@postgrespro.ru", "phone": "+70256006216"}
0005434025580	999092	2893 883578	MARINA LAZAREVA	{"phone": "+70397383087"}
0005434025581	401292	1467 892688	ANASTASIYA KULIKOVA	{"phone": "+70761768528"}
0005434025582	9BC48D	7275 124435	ANASTASIYA IVANOVA	{"email": "a-ivanova.20061971@postgrespro.ru", "phone": "+70706421776"}
0005434025583	29C5E3	0827 494785	ANASTASIYA KUZNECOVA	{"phone": "+70400952607"}
0005434025584	AB719C	3005 106448	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy-1978@postgrespro.ru", "phone": "+70092782130"}
0005434025585	7927CF	3848 347856	ARTEM KRASNOV	{"email": "krasnov.artem-19021980@postgrespro.ru", "phone": "+70273521195"}
0005434025586	7927CF	8243 952664	GERMAN ALEKSEEV	{"phone": "+70651233199"}
0005434025587	7927CF	8705 917616	NATALYA RODIONOVA	{"phone": "+70981475128"}
0005434025588	7927CF	2880 339097	ANDREY ALEKSEEV	{"email": "alekseev_andrey1957@postgrespro.ru", "phone": "+70499088101"}
0005434025589	1D71D0	8757 114636	DMITRIY FROLOV	{"phone": "+70071263411"}
0005434025590	02610A	0305 057014	VALENTINA MOROZOVA	{"email": "v-morozova.1974@postgrespro.ru", "phone": "+70716399775"}
0005434025591	BEA061	7956 493079	IRINA POPOVA	{"email": "i_popova-02011973@postgrespro.ru", "phone": "+70377912384"}
0005434025592	0A7D71	4599 576956	EVGENIY PAVLOV	{"phone": "+70542513174"}
0005434025593	0A7D71	0170 825039	IRINA MOROZOVA	{"phone": "+70517152473"}
0005434025595	B0C9A0	8120 135082	ALEKSEY ROMANOV	{"phone": "+70829403427"}
0005434025596	B0C9A0	5326 152933	SVETLANA BORISOVA	{"phone": "+70777039481"}
0005434025597	A971E2	9642 598842	NADEZHDA ZHURAVLEVA	{"email": "n-zhuravleva_16011965@postgrespro.ru", "phone": "+70027171136"}
0005434025598	A971E2	9762 440170	SEMEN GORBUNOV	{"email": "gorbunov_semen-1976@postgrespro.ru", "phone": "+70731181857"}
0005434025599	2AC831	3206 460543	MARIYA FROLOVA	{"email": "frolova-mariya_1982@postgrespro.ru", "phone": "+70855633608"}
0005434025600	2AC831	1781 880372	DANIIL SCHERBAKOV	{"email": "daniilscherbakov1970@postgrespro.ru", "phone": "+70908358630"}
0005434025601	2AC831	6437 618575	BORIS ALEKSANDROV	{"phone": "+70299577695"}
0005434025602	48E554	5170 061245	LYUBOV YAKOVLEVA	{"email": "yakovleval.12011969@postgrespro.ru", "phone": "+70449243699"}
0005434025603	4106E7	4184 864041	YULIYA KUZNECOVA	{"phone": "+70283459825"}
0005434025604	4106E7	9789 990725	KRISTINA VOLKOVA	{"email": "volkova-kristina_111983@postgrespro.ru", "phone": "+70823558612"}
0005434025605	EC2C69	1702 715843	ANNA SAVELEVA	{"email": "saveleva-anna.1972@postgrespro.ru", "phone": "+70306754963"}
0005434025606	EC2C69	2860 506979	ANNA KOZLOVA	{"phone": "+70062436071"}
0005434025607	EC2C69	7787 772435	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov.071954@postgrespro.ru", "phone": "+70092368530"}
0005434025608	EC2EA4	2062 437928	EVDOKIYA GUSEVA	{"phone": "+70352324883"}
0005434025609	460C0F	4723 489310	ELENA ZAYCEVA	{"phone": "+70024486425"}
0005434025610	460C0F	2609 400333	VALERIYA ANDREEVA	{"email": "valeriyaandreeva28081981@postgrespro.ru", "phone": "+70156308947"}
0005434025611	460C0F	5065 820555	VALENTINA KARPOVA	{"email": "v-karpova_1973@postgrespro.ru", "phone": "+70807239419"}
0005434025612	F7B5A8	0167 621607	ALEKSANDR TARASOV	{"phone": "+70360781367"}
0005434025613	E91D5B	5012 138115	IVAN ABRAMOV	{"email": "ivanabramov-23101967@postgrespro.ru", "phone": "+70833939650"}
0005434025614	D051B7	1507 533185	VIKTOR PETROV	{"email": "v_petrov_1967@postgrespro.ru", "phone": "+70931203739"}
0005434025615	F9986A	0603 537300	ANDREY BORISOV	{"phone": "+70034206468"}
0005434025616	F9986A	8169 872431	KAMIL SOKOLOV	{"email": "kamil-sokolov.071972@postgrespro.ru", "phone": "+70264759570"}
0005434025617	BC1287	4589 846758	VLADIMIR PETROV	{"email": "petrov.vladimir-1972@postgrespro.ru", "phone": "+70185142199"}
0005434025618	BB28A2	0807 574295	OLGA MOISEEVA	{"email": "olgamoiseeva_1969@postgrespro.ru", "phone": "+70586642149"}
0005434025619	AD0438	7280 454998	ANNA LEBEDEVA	{"phone": "+70997158002"}
0005434025620	4C949D	7140 663680	LYUBOV VOLKOVA	{"phone": "+70557169109"}
0005434025621	4C949D	5069 801873	NADIYA NIKOLAEVA	{"phone": "+70598915787"}
0005434025622	3D8792	6497 526300	YURIY KUZNECOV	{"email": "kuznecov.yuriy1976@postgrespro.ru", "phone": "+70794609448"}
0005434025623	3D8792	6632 970720	MIKHAIL BORISOV	{"phone": "+70146798938"}
0005434025624	388C97	2897 404865	IRINA EGOROVA	{"email": "egorovairina1967@postgrespro.ru", "phone": "+70472600613"}
0005434025625	046647	8985 338407	ROMAN NAZAROV	{"phone": "+70670879883"}
0005434025626	046647	2320 510154	OLGA SIDOROVA	{"email": "o_sidorova28041955@postgrespro.ru", "phone": "+70689215091"}
0005434025627	1B1F1D	0840 075209	VALERIYA NAZAROVA	{"email": "valeriya.nazarova_091960@postgrespro.ru", "phone": "+70130675271"}
0005434025628	1B1F1D	7785 882195	NATALYA PAVLOVA	{"email": "pavlovanatalya.07011968@postgrespro.ru", "phone": "+70654719302"}
0005434025629	417BFE	7595 260621	ANDREY KUZMIN	{"email": "kuzmin.a_041962@postgrespro.ru", "phone": "+70006682961"}
0005434025630	DF6821	2310 422303	VIKTOR TIKHONOV	{"phone": "+70442726184"}
0005434025631	1903F1	0868 171330	ANNA BELOVA	{"phone": "+70235901010"}
0005434025632	CB6915	0411 670961	EVGENIY DENISOV	{"phone": "+70040438686"}
0005434025633	CB6915	0746 927686	EVGENIYA SEMENOVA	{"email": "e.semenova1967@postgrespro.ru", "phone": "+70696313561"}
0005434025634	4B5225	5118 670404	SERGEY FILIPPOV	{"email": "s.filippov_101976@postgrespro.ru", "phone": "+70826528599"}
0005434025635	15AC98	8484 090494	EKATERINA POPOVA	{"phone": "+70035679023"}
0005434025636	C392C7	0250 512973	NADEZHDA LUKYANOVA	{"phone": "+70170981888"}
0005434025637	C392C7	9665 692135	SERGEY IVANOV	{"email": "ivanov_sergey-12101968@postgrespro.ru", "phone": "+70300889511"}
0005434025638	EA946E	7851 205538	EVGENIY FILIPPOV	{"phone": "+70065472733"}
0005434025639	EA946E	7699 239169	NATALYA PETROVA	{"phone": "+70264056197"}
0005434025640	EA946E	9730 666722	OLGA VOROBEVA	{"phone": "+70780138632"}
0005434025641	9FC7E7	1894 208527	LIDIYA MIKHAYLOVA	{"phone": "+70423722751"}
0005434025642	9FC7E7	3067 486813	PETR POPOV	{"phone": "+70714191702"}
0005434025643	FC242C	8843 308089	DARYA DANILOVA	{"email": "ddanilova.11111969@postgrespro.ru", "phone": "+70182238838"}
0005434025644	D3C6EA	6056 317486	RUSLAN PETROV	{"email": "petrovruslan121969@postgrespro.ru", "phone": "+70890160378"}
0005434025645	5AF0C4	1001 134819	TATYANA KOZLOVA	{"phone": "+70318736599"}
0005434026674	A81AE4	7309 140881	TATYANA ZHUKOVA	{"phone": "+70964358390"}
0005434025646	16BD2E	8480 077993	VYACHESLAV SEMENOV	{"email": "vyacheslav-semenov031969@postgrespro.ru", "phone": "+70333287063"}
0005434025647	16BD2E	4813 200257	KLAVDIYA VASILEVA	{"email": "vasileva_klavdiya_25071975@postgrespro.ru", "phone": "+70108980949"}
0005434025648	574E93	4992 530591	KIRILL ISAEV	{"phone": "+70684725761"}
0005434025649	192DE9	0449 090295	ANATOLIY NIKITIN	{"phone": "+70821848884"}
0005434025650	C7EB79	9149 857865	ANASTASIYA KULIKOVA	{"phone": "+70096727706"}
0005434025651	C77047	0987 580990	YURIY FROLOV	{"email": "frolovyuriy_16091980@postgrespro.ru", "phone": "+70081619156"}
0005434025652	121494	2869 631899	GALINA FADEEVA	{"email": "g_fadeeva_101974@postgrespro.ru", "phone": "+70425329303"}
0005434025653	E7B1C8	8079 799730	LYUDMILA MIKHAYLOVA	{"phone": "+70706443105"}
0005434025654	7C141E	6219 786571	MIKHAIL FEDOROV	{"phone": "+70670303994"}
0005434025655	7C141E	5696 715582	TATYANA ZAKHAROVA	{"phone": "+70116831369"}
0005434025656	2E3BAC	5738 905821	LARISA POPOVA	{"phone": "+70099321658"}
0005434025657	2E3BAC	8971 428043	LYUDMILA VASILEVA	{"phone": "+70802237249"}
0005434025658	0773D0	8163 629973	SVETLANA KUDRYASHOVA	{"email": "kudryashova.s05071972@postgrespro.ru", "phone": "+70068311434"}
0005434025659	E9A737	9632 862317	IVAN NOVIKOV	{"email": "i.novikov11031975@postgrespro.ru", "phone": "+70682163740"}
0005434025660	3584EE	8213 183154	ANTONINA IVANOVA	{"phone": "+70362783756"}
0005434025661	3584EE	4891 661437	PAVEL VASILEV	{"phone": "+70711251348"}
0005434025662	658036	8735 511804	ASKHAT GERASIMOV	{"email": "gerasimov_askhat17031972@postgrespro.ru", "phone": "+70528394048"}
0005434025663	6F39A2	0381 609874	IRINA SMIRNOVA	{"phone": "+70910159567"}
0005434025664	6F39A2	3260 723942	LYUBOV IVANOVA	{"phone": "+70964113496"}
0005434025665	95AC8F	2696 662919	ANASTASIYA ANDREEVA	{"phone": "+70823747690"}
0005434025666	6514AE	5303 450958	ELENA POPOVA	{"email": "elena_popova111973@postgrespro.ru", "phone": "+70159402745"}
0005434025667	E84A2D	7634 050620	LYUDMILA ANISIMOVA	{"phone": "+70478391935"}
0005434025668	4BF37F	0416 293519	ANATOLIY RODIONOV	{"phone": "+70765432317"}
0005434025669	3EAED0	9328 650245	IRINA EGOROVA	{"email": "egorova-irina.13101969@postgrespro.ru", "phone": "+70089202804"}
0005434025670	52DC4C	7981 226154	NADEZHDA SMIRNOVA	{"phone": "+70939705006"}
0005434025671	EA1066	4955 810279	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov.13071960@postgrespro.ru", "phone": "+70533285644"}
0005434025672	EA1066	4596 135437	VLADIMIR ZAYCEV	{"phone": "+70165362798"}
0005434025673	6D269D	4728 014969	RINAT KUZNECOV	{"email": "kuznecovrinat_1975@postgrespro.ru", "phone": "+70684106248"}
0005434025674	146940	1035 239490	VLADISLAV NIKOLAEV	{"phone": "+70502944870"}
0005434025675	3E0CC9	6399 935523	LEONID ALEKSEEV	{"email": "leonid_alekseev.1979@postgrespro.ru", "phone": "+70947761092"}
0005434025676	FD4C05	2184 313445	ANATOLIY SOROKIN	{"phone": "+70518883948"}
0005434025677	FD4C05	7889 999053	NADEZHDA BORISOVA	{"email": "borisova.nadezhda_08121973@postgrespro.ru", "phone": "+70450375236"}
0005434025678	91507D	1814 089751	KSENIYA KOZLOVA	{"phone": "+70588037106"}
0005434025679	47D72A	3408 499274	VADIM ABRAMOV	{"email": "vabramov-19051976@postgrespro.ru", "phone": "+70444806017"}
0005434025680	736D04	4111 742643	LYUDMILA KARPOVA	{"phone": "+70653661048"}
0005434025681	736D04	6643 254941	MARIYA AFANASEVA	{"email": "afanaseva_m_15081972@postgrespro.ru", "phone": "+70750895639"}
0005434025682	8AEA47	2951 029328	ALENA MIKHAYLOVA	{"phone": "+70663839117"}
0005434025683	8AEA47	0766 032994	ELENA TIKHONOVA	{"phone": "+70779745157"}
0005434025684	C3A56F	9574 760796	NATALYA SOLOVEVA	{"phone": "+70184987475"}
0005434025685	C3A56F	7358 003363	EKATERINA BORISOVA	{"phone": "+70292906651"}
0005434025686	87942A	8367 397731	OKSANA SEMENOVA	{"phone": "+70423133079"}
0005434025687	87942A	4461 193270	IRINA ROMANOVA	{"email": "i_romanova_1974@postgrespro.ru", "phone": "+70596031695"}
0005434025688	DD3BD6	3443 581117	YAROSLAV ZHUKOV	{"phone": "+70775194788"}
0005434025689	DD3BD6	0016 749764	VALENTINA ANTONOVA	{"phone": "+70651582524"}
0005434025690	DD3BD6	9927 332590	ALINA BELOVA	{"email": "alinabelova26021973@postgrespro.ru", "phone": "+70129821899"}
0005434025691	D40C60	2689 710092	ALEKSANDRA PAVLOVA	{"phone": "+70369223033"}
0005434025692	4DA5D6	4581 043148	VLADIMIR BONDARENKO	{"email": "bondarenko_vladimir-101963@postgrespro.ru", "phone": "+70634585944"}
0005434025693	4DA5D6	1007 342102	LARISA ZAKHAROVA	{"email": "larisa_zakharova.061976@postgrespro.ru", "phone": "+70496544233"}
0005434025694	6C2355	6638 373298	GALINA STEPANOVA	{"email": "stepanova.galina18091979@postgrespro.ru", "phone": "+70202029383"}
0005434025695	C3A2B5	4346 111530	GALINA BELYAEVA	{"email": "g_belyaeva.16101979@postgrespro.ru", "phone": "+70097329382"}
0005434025696	DA8477	7282 170358	NATALYA KOROLEVA	{"phone": "+70394827111"}
0005434025697	400A0E	4785 208305	VLADIMIR VASILEV	{"email": "v_vasilev-061967@postgrespro.ru", "phone": "+70112379195"}
0005434025698	485470	5491 885188	ANTONINA KULIKOVA	{"email": "a.kulikova-101963@postgrespro.ru", "phone": "+70693714551"}
0005434025699	949625	6457 599940	LYUBOV MAKSIMOVA	{"email": "maksimoval-22091970@postgrespro.ru", "phone": "+70278245296"}
0005434025700	03FD91	4000 585971	TAMARA KUZNECOVA	{"phone": "+70779121536"}
0005434025701	03FD91	0890 109665	TATYANA YUDINA	{"phone": "+70102794991"}
0005434026669	5211D4	4789 054023	LEONID TARASOV	{"email": "tarasovleonid_111976@postgrespro.ru", "phone": "+70663594594"}
0005434026670	5211D4	1259 882469	DMITRIY ANTONOV	{"phone": "+70686817330"}
0005434026671	5211D4	5869 893628	LYUDMILA FILATOVA	{"email": "lyudmilafilatova_091972@postgrespro.ru", "phone": "+70356473851"}
0005434026672	D58939	6035 281032	NADEZHDA IVANOVA	{"phone": "+70864231199"}
0005434026673	B45D1E	7723 122410	VADIM GERASIMOV	{"email": "vadim_gerasimov-07111978@postgrespro.ru", "phone": "+70995110019"}
0005434026675	A81AE4	6987 384136	LIDIYA ORLOVA	{"phone": "+70396043349"}
0005434026676	A81AE4	2133 865635	IRINA TARASOVA	{"phone": "+70100970103"}
0005434026677	CD9BB3	5555 506682	SAVELIY BONDARENKO	{"phone": "+70779809290"}
0005434026678	CD9BB3	1454 123127	SVETLANA DENISOVA	{"phone": "+70420998954"}
0005434026679	D43F69	8024 583073	VADIM MOROZOV	{"email": "morozov-vadim-051970@postgrespro.ru", "phone": "+70362332717"}
0005434026680	D43F69	0836 612731	ANDREY DAVYDOV	{"email": "davydov_a-1969@postgrespro.ru", "phone": "+70077255158"}
0005434026681	3DD840	4860 094693	LEONTIY POPOV	{"phone": "+70998088973"}
0005434026682	3DD840	5144 118307	VLADIMIR KUZNECOV	{"phone": "+70746253456"}
0005434026683	FFD7EE	0530 705680	YULIYA VOROBEVA	{"email": "vorobeva-yuliya07121974@postgrespro.ru", "phone": "+70066628281"}
0005434026684	56E308	3857 718517	NIKOLAY KUZNECOV	{"email": "n_kuznecov.031977@postgrespro.ru", "phone": "+70930784376"}
0005434026685	929328	1144 217728	YURIY NAZAROV	{"email": "nazarov-yuriy.23081970@postgrespro.ru", "phone": "+70165541382"}
0005434026686	929328	5518 589749	VALENTINA OSIPOVA	{"email": "v_osipova-07121960@postgrespro.ru", "phone": "+70206876230"}
0005434026687	FA164A	1027 346550	GENNADIY NOVIKOV	{"email": "gennadiy-novikov_011980@postgrespro.ru", "phone": "+70233861137"}
0005434026688	FA164A	7209 326826	TATYANA KALININA	{"email": "t_kalinina-021974@postgrespro.ru", "phone": "+70771736623"}
0005434026689	FA164A	0419 332581	ANTON BORISOV	{"email": "borisovanton_1980@postgrespro.ru", "phone": "+70223919543"}
0005434026690	61FAA6	8981 822636	TATYANA FROLOVA	{"email": "frolovatatyana-01101969@postgrespro.ru", "phone": "+70107136601"}
0005434026691	CA6DBD	2530 073962	ARINA PAVLOVA	{"phone": "+70033031164"}
0005434026692	CA6DBD	7306 252737	RUSLAN EGOROV	{"phone": "+70521851371"}
0005434026693	776314	1345 000987	EKATERINA NIKOLAEVA	{"phone": "+70052581979"}
0005434026694	04AC33	4831 662526	ALEKSEY OSIPOV	{"phone": "+70029500506"}
0005434026695	A86852	6916 548209	VLADIMIR ROMANOV	{"email": "v-romanov_16051977@postgrespro.ru", "phone": "+70069081894"}
0005434026696	025AAA	0212 869862	YULIYA BELOVA	{"email": "belovayuliya-111966@postgrespro.ru", "phone": "+70203380898"}
0005434026697	D3FAE6	3705 542381	ELENA DMITRIEVA	{"phone": "+70859475373"}
0005434026698	7A3455	1739 939454	TATYANA LOGINOVA	{"email": "tloginova1965@postgrespro.ru", "phone": "+70756374959"}
0005434026699	7A3455	1686 325467	OLGA MEDVEDEVA	{"email": "medvedevao_14081984@postgrespro.ru", "phone": "+70861219754"}
0005434026700	38592D	7392 759298	VALERIY FEDOTOV	{"email": "fedotov_valeriy-061982@postgrespro.ru", "phone": "+70613966523"}
0005434026701	793E48	7769 603923	ALEKSEY NAZAROV	{"phone": "+70638765578"}
0005434026702	1C1FA8	3648 807853	DENIS KUZNECOV	{"email": "kuznecov.d-071976@postgrespro.ru", "phone": "+70781918733"}
0005434026703	204A0B	0566 489874	TATYANA SAVELEVA	{"email": "saveleva_t22111965@postgrespro.ru", "phone": "+70035047183"}
0005434026704	BA48D5	3747 045720	TATYANA MELNIKOVA	{"email": "melnikova-t13011980@postgrespro.ru", "phone": "+70243584442"}
0005434026705	BA48D5	9056 186857	NINA IVANOVA	{"email": "ninaivanova1968@postgrespro.ru", "phone": "+70925851624"}
0005434026706	1C99BB	6987 398426	EVGENIY STEPANOV	{"phone": "+70279116558"}
0005434026707	E5F03C	5231 597154	DENIS NIKITIN	{"email": "denis_nikitin_1986@postgrespro.ru", "phone": "+70162017282"}
0005434026708	E5F03C	0068 477123	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir1963@postgrespro.ru", "phone": "+70557150757"}
0005434026709	945708	1256 324687	NATALYA POPOVA	{"email": "popova.natalya1973@postgrespro.ru", "phone": "+70809393897"}
0005434026710	945708	0340 056522	YULIYA GAVRILOVA	{"email": "yuliya.gavrilova-1967@postgrespro.ru", "phone": "+70049455543"}
0005434026711	1A85CF	1587 791338	EVGENIY AFANASEV	{"email": "afanasev_e_081978@postgrespro.ru", "phone": "+70663279872"}
0005434026712	1A85CF	8408 507727	ALENA MAKAROVA	{"email": "makarova.alena.02111965@postgrespro.ru", "phone": "+70471989780"}
0005434026713	CC189B	6285 068407	VLADIMIR MAKSIMOV	{"email": "v_maksimov-27051965@postgrespro.ru", "phone": "+70904542567"}
0005434026714	8B403B	7972 755552	LYUDMILA SOKOLOVA	{"phone": "+70910228664"}
0005434026715	0E1274	2348 258224	NURIYA FILIPPOVA	{"phone": "+70560714335"}
0005434026716	40AEB2	9999 373463	ZINAIDA ZHURAVLEVA	{"email": "z-zhuravleva.041962@postgrespro.ru", "phone": "+70554452177"}
0005434026717	6AD294	2214 194845	ALIYA BARANOVA	{"email": "a.baranova.1966@postgrespro.ru", "phone": "+70870965584"}
0005434026718	4A4822	0618 425163	LYUBOV ALEKSEEVA	{"email": "l-alekseeva-1965@postgrespro.ru", "phone": "+70429267381"}
0005434026719	4A4822	2967 340607	ALEKSEY GERASIMOV	{"phone": "+70115954723"}
0005434026720	A290A3	3926 762747	DMITRIY KUZNECOV	{"phone": "+70576630876"}
0005434026721	844686	7100 398551	LYUDMILA AFANASEVA	{"email": "afanasevalyudmila-1976@postgrespro.ru", "phone": "+70240208166"}
0005434026722	8DA8AA	9477 587065	ANASTASIYA KONOVALOVA	{"email": "konovalova_a29051978@postgrespro.ru", "phone": "+70923602823"}
0005434026723	8DA8AA	0832 865625	ANTON SCHERBAKOV	{"phone": "+70154080369"}
0005434026724	95089B	8951 525849	VERA OSIPOVA	{"email": "osipova.vera_1973@postgrespro.ru", "phone": "+70156144065"}
0005434026725	356C75	7698 656387	LIDIYA SOKOLOVA	{"email": "lsokolova-1968@postgrespro.ru", "phone": "+70591467915"}
0005434026726	583BFB	3051 207898	VLADIMIR KUZMIN	{"email": "kuzmin-v.04041971@postgrespro.ru", "phone": "+70319518512"}
0005434026727	6A46AA	1744 616152	ANTONINA ERMAKOVA	{"email": "aermakova1954@postgrespro.ru", "phone": "+70848118927"}
0005434026728	8B3A5C	8651 164424	NATALYA PETROVA	{"phone": "+70851189475"}
0005434026729	1D366B	6885 504038	VYACHESLAV IVANOV	{"phone": "+70264295570"}
0005434026730	11BFBC	7605 135495	ELENA IVANOVA	{"phone": "+70923675449"}
0005434026731	C22B71	0288 904345	SVETLANA PETROVA	{"phone": "+70035667604"}
0005434026732	BEDDA0	9709 404773	KONSTANTIN ALEKSEEV	{"phone": "+70714076185"}
0005434026733	BEDDA0	3792 988969	VERONIKA KOMAROVA	{"email": "komarova.v.1964@postgrespro.ru", "phone": "+70220053597"}
0005434026734	8451EE	7082 272740	ROMAN BELOV	{"email": "belov-roman.1977@postgrespro.ru", "phone": "+70535390642"}
0005434026735	84F9D0	9220 905705	VASILIY POPOV	{"phone": "+70524945852"}
0005434026736	84F9D0	3714 049589	LIDIYA NIKOLAEVA	{"email": "nikolaeva.l.21101974@postgrespro.ru", "phone": "+70244620036"}
0005434026737	71E1CB	7267 688481	VLADIMIR GRIGOREV	{"email": "vladimir.grigorev-111967@postgrespro.ru", "phone": "+70762797935"}
0005434026738	71E1CB	1018 350670	NIKOLAY SIDOROV	{"email": "sidorov.n.1968@postgrespro.ru", "phone": "+70165015630"}
0005434026739	5AB2F4	1480 259848	VALERIY BELOV	{"email": "v.belov.101969@postgrespro.ru", "phone": "+70071068325"}
0005434026740	EAA871	9960 253221	EVGENIY STEPANOV	{"phone": "+70216289146"}
0005434026741	8849CE	6222 225080	ANASTASIYA POPOVA	{"phone": "+70435458210"}
0005434026742	8849CE	8972 566725	VERA MAKAROVA	{"phone": "+70083422713"}
0005434026743	A79898	4242 601635	ULYANA MOISEEVA	{"email": "moiseeva-u.1984@postgrespro.ru", "phone": "+70516398501"}
0005434026744	39F6AA	8454 565475	NINA DENISOVA	{"email": "denisovanina-1975@postgrespro.ru", "phone": "+70675938812"}
0005434026745	C2E282	6195 609124	NIKOLAY MARTYNOV	{"phone": "+70570927655"}
0005434026746	61B093	0026 281241	ANDREY ALEKSEEV	{"phone": "+70739035429"}
0005434026747	61B093	5537 495183	TAMARA GAVRILOVA	{"phone": "+70605261499"}
0005434026748	0577A8	8436 693196	VALENTINA ROMANOVA	{"email": "valentina_romanova-1953@postgrespro.ru", "phone": "+70626626756"}
0005434026749	A40A40	7599 088299	MARIYA TIMOFEEVA	{"phone": "+70569068236"}
0005434026750	58B284	4773 283495	ALEKSEY ANDREEV	{"phone": "+70597056733"}
0005434026751	233B26	9590 654565	TAISIYA ISAEVA	{"phone": "+70476083160"}
0005434026752	FB3B3E	6196 952235	ELENA KUZMINA	{"phone": "+70194930275"}
0005434026753	DA40FD	6034 863155	ANDREY POPOV	{"phone": "+70381867613"}
0005434026754	DA40FD	6972 830568	ALEKSANDR BARANOV	{"phone": "+70874267764"}
0005434026755	4B61E8	9011 534106	NATALYA TIKHONOVA	{"email": "tikhonova.natalya.1977@postgrespro.ru", "phone": "+70919646299"}
0005434026756	4B61E8	3907 465341	GALINA VOROBEVA	{"email": "vorobeva.galina.17101985@postgrespro.ru", "phone": "+70865588966"}
0005434026757	D61910	6456 954016	VITALIY SMIRNOV	{"email": "smirnov_v-1984@postgrespro.ru", "phone": "+70051399376"}
0005434026758	D61910	8929 877670	ELENA ABRAMOVA	{"phone": "+70487648834"}
0005434026759	D61910	4430 379150	MAKSIM ALEKSEEV	{"phone": "+70733748213"}
0005434026760	039AE9	8225 702612	VLADIMIR TARASOV	{"phone": "+70413321498"}
0005434026761	C22C0C	8637 954632	VIKTOR RODIONOV	{"email": "v-rodionov.14101967@postgrespro.ru", "phone": "+70069840297"}
0005434026762	B28FC4	0900 592610	ALEKSEY KULIKOV	{"email": "alekseykulikov_061979@postgrespro.ru", "phone": "+70204296298"}
0005434026763	CF9111	1848 155581	OLGA ZHURAVLEVA	{"email": "olga.zhuravleva121980@postgrespro.ru", "phone": "+70297109333"}
0005434028327	E2B164	8176 119584	TATYANA SIDOROVA	{"phone": "+70523815932"}
0005434028328	48B325	3377 588352	OLGA KALININA	{"phone": "+70501728471"}
0005434028385	D8ADEA	6883 379156	ANATOLIY SCHERBAKOV	{"phone": "+70656743651"}
0005434028386	3DC957	9166 832807	NIKOLAY KUZMIN	{"phone": "+70624761646"}
0005434028246	E5A99A	8712 356241	ROMAN GAVRILOV	{"phone": "+70908269291"}
0005434028247	BB862D	4054 162985	MARIYA MOROZOVA	{"phone": "+70808910106"}
0005434028248	FF9CBE	3336 081815	RAMILYA GRISHINA	{"email": "grishinar-1981@postgrespro.ru", "phone": "+70368225938"}
0005434028249	4A5C28	4428 039298	KIRILL GRIGOREV	{"email": "grigorev.k-1968@postgrespro.ru", "phone": "+70016543952"}
0005434028250	5A7AFE	7893 886344	ANNA IVANOVA	{"phone": "+70558806194"}
0005434028251	5A7AFE	0904 117680	MIKHAIL AFANASEV	{"phone": "+70457142688"}
0005434028252	485BBC	0162 868514	VLADIMIR ISAEV	{"phone": "+70749385767"}
0005434028253	485BBC	6106 231738	ANASTASIYA FROLOVA	{"email": "frolova.anastasiya-1979@postgrespro.ru", "phone": "+70449699886"}
0005434028254	8993B0	8881 183224	IVAN NIKOLAEV	{"email": "ivannikolaev101971@postgrespro.ru", "phone": "+70677382255"}
0005434028255	F5078A	4870 345646	NADEZHDA YAKOVLEVA	{"email": "yakovleva.nadezhda26081966@postgrespro.ru", "phone": "+70738775409"}
0005434028256	0DA5AA	9432 387389	ALEKSEY GERASIMOV	{"email": "gerasimov_a-011985@postgrespro.ru", "phone": "+70493848770"}
0005434028257	EDACE5	1509 626986	PAVEL GUSEV	{"email": "gusev-pavel-1966@postgrespro.ru", "phone": "+70130268437"}
0005434028258	EDACE5	0080 356703	KRISTINA NOVIKOVA	{"email": "kristina_novikova021969@postgrespro.ru", "phone": "+70416386963"}
0005434028259	157153	6749 939919	DMITRIY STEPANOV	{"phone": "+70787589636"}
0005434028260	9FDF12	1477 989182	MARINA ZHURAVLEVA	{"phone": "+70787348963"}
0005434028261	B1560D	5578 012364	VLADIMIR SEMENOV	{"phone": "+70533553017"}
0005434028262	D3CBB8	3866 104103	VLADIMIR FROLOV	{"phone": "+70425396664"}
0005434028263	7A90B8	2251 060020	VADIM SOKOLOV	{"email": "sokolov.vadim081977@postgrespro.ru", "phone": "+70919095789"}
0005434028264	987808	6044 800387	YULIYA PAVLOVA	{"phone": "+70171711644"}
0005434028265	987808	0884 346200	DMITRIY IVANOV	{"email": "ivanov.dmitriy-15041975@postgrespro.ru", "phone": "+70853034445"}
0005434028266	6B53C7	0724 731528	NADEZHDA NIKITINA	{"phone": "+70875993508"}
0005434028267	4B94FC	1038 719053	SERGEY CHERNOV	{"email": "chernovs-10101960@postgrespro.ru", "phone": "+70755483077"}
0005434028268	5C62A4	7222 159823	ALEKSANDR KUDRYASHOV	{"phone": "+70902761085"}
0005434028269	5C62A4	1051 655231	NINA ANDREEVA	{"email": "n.andreeva_1981@postgrespro.ru", "phone": "+70087205890"}
0005434028270	235799	6179 449371	VASILIY VOLKOV	{"phone": "+70745893531"}
0005434028387	3DC957	6300 957821	ANATOLIY IVANOV	{"phone": "+70014454497"}
0005434028271	0F9025	5474 880124	OLEG SOROKIN	{"email": "oleg_sorokin_15081964@postgrespro.ru", "phone": "+70567501741"}
0005434028272	954D15	7923 107897	GALINA ROMANOVA	{"email": "romanova-galina_16071954@postgrespro.ru", "phone": "+70161421173"}
0005434028273	20261F	8488 711698	MIKHAIL RODIONOV	{"phone": "+70160085929"}
0005434028274	20261F	6691 303135	MIKHAIL SOROKIN	{"email": "msorokin-17091983@postgrespro.ru", "phone": "+70161529233"}
0005434028275	E18744	2870 466232	ALEKSEY DENISOV	{"email": "denisovaleksey101980@postgrespro.ru", "phone": "+70757405856"}
0005434028276	61E932	3869 499657	NINA FADEEVA	{"email": "nina.fadeeva091975@postgrespro.ru", "phone": "+70551223100"}
0005434028277	EE7CC0	2783 206285	IGOR PAVLOV	{"email": "igor.pavlov.011981@postgrespro.ru", "phone": "+70576080813"}
0005434028278	E435BF	8512 129512	GENNADIY NIKOLAEV	{"email": "nikolaev_g.1979@postgrespro.ru", "phone": "+70171126451"}
0005434028279	E435BF	3868 455640	ALEKSANDR MATVEEV	{"email": "matveeva-1976@postgrespro.ru", "phone": "+70482591168"}
0005434028280	CEAF3A	8440 772657	VIKTORIYA KUZMINA	{"email": "kuzmina.viktoriya.081983@postgrespro.ru", "phone": "+70120616539"}
0005434028281	CEAF3A	8886 324291	TAMARA KRASNOVA	{"phone": "+70296626978"}
0005434028282	FE9A53	4835 267670	NATALYA KUZNECOVA	{"phone": "+70252554902"}
0005434028283	864F5A	0528 743662	DAMIR ISAEV	{"email": "damir.isaev.081973@postgrespro.ru", "phone": "+70255587249"}
0005434028284	242799	8287 962830	ALEKSANDR NIKOLAEV	{"phone": "+70516030627"}
0005434028285	0ABD25	8784 648591	DENIS CHERNOV	{"email": "denis_chernov_1971@postgrespro.ru", "phone": "+70124523531"}
0005434028286	551961	7750 375362	ALEKSANDRA SAVELEVA	{"email": "aleksandrasaveleva.29011963@postgrespro.ru", "phone": "+70592754634"}
0005434028287	EC1866	8363 427213	OLGA VOROBEVA	{"email": "olga_vorobeva.061978@postgrespro.ru", "phone": "+70549551688"}
0005434028288	B0CD36	6064 900540	DMITRIY FILIPPOV	{"email": "filippovd-011975@postgrespro.ru", "phone": "+70122297245"}
0005434028289	EDA3F9	5304 139484	IVAN ROMANOV	{"phone": "+70309624847"}
0005434028290	EDA3F9	9218 221093	DMITRIY VASILEV	{"phone": "+70437872234"}
0005434028291	158861	6777 748485	SERGEY GAVRILOV	{"phone": "+70256420786"}
0005434028292	2067D8	4717 051181	ANATOLIY SOROKIN	{"phone": "+70526897446"}
0005434028293	2067D8	6112 075316	VALENTINA EGOROVA	{"phone": "+70151659204"}
0005434028294	BE4814	8295 658471	NIKOLAY FOMIN	{"email": "fomin-nikolay.121968@postgrespro.ru", "phone": "+70989328543"}
0005434028295	BC1E34	3453 560486	RAFAEL FEDOROV	{"phone": "+70733307957"}
0005434028296	BC1E34	8810 075197	ALEKSANDR GERASIMOV	{"email": "aleksandrgerasimov-1974@postgrespro.ru", "phone": "+70886319002"}
0005434028297	C3BE89	3161 968593	ALEKSANDR NOVIKOV	{"phone": "+70411114086"}
0005434028298	6022B5	6904 639263	TATYANA KOZLOVA	{"email": "t-kozlova-101965@postgrespro.ru", "phone": "+70435174404"}
0005434028299	ED3AF9	5122 659577	IGOR NIKITIN	{"email": "inikitin-101981@postgrespro.ru", "phone": "+70102412684"}
0005434028300	8CE7E3	7152 674720	MARIYA LAZAREVA	{"email": "lazarevam_1974@postgrespro.ru", "phone": "+70980352969"}
0005434028301	8CE7E3	5508 253283	LYUBOV MATVEEVA	{"email": "l_matveeva.1969@postgrespro.ru", "phone": "+70744596411"}
0005434028302	E43BE9	8027 796277	ILYA SEMENOV	{"email": "i_semenov23061979@postgrespro.ru", "phone": "+70081823568"}
0005434028303	E43BE9	0190 363776	ALEKSANDR SERGEEV	{"phone": "+70816655247"}
0005434028304	E43BE9	4373 347351	NADEZHDA SOLOVEVA	{"phone": "+70573222196"}
0005434028305	32AF84	2996 633757	NINA NOVIKOVA	{"phone": "+70113309979"}
0005434028306	32AF84	3139 626071	ELVIRA KUZNECOVA	{"phone": "+70700791973"}
0005434028307	849AC2	1829 127207	VERA PAVLOVA	{"email": "pavlova.v.051962@postgrespro.ru", "phone": "+70688775828"}
0005434028308	68FDF4	6729 713769	VYACHESLAV ALEKSEEV	{"email": "alekseev.v.13041978@postgrespro.ru", "phone": "+70678030087"}
0005434028309	5A305E	9997 512615	GALINA FILATOVA	{"phone": "+70323002539"}
0005434028310	5A305E	7866 952875	MARIYA MAKAROVA	{"email": "makarova-m_28011976@postgrespro.ru", "phone": "+70396023107"}
0005434028311	A84C4C	3800 275689	VIKTOR NOVIKOV	{"email": "novikov.v.081959@postgrespro.ru", "phone": "+70806729192"}
0005434028312	D3716C	9286 888036	EVGENIYA AFANASEVA	{"phone": "+70105835858"}
0005434028313	1C5CA9	8242 259751	ANNA MOISEEVA	{"phone": "+70501114717"}
0005434028314	13BFE9	9475 164418	VALENTINA FOMINA	{"phone": "+70582621238"}
0005434028315	2DA0B7	2717 480966	NATALYA VOROBEVA	{"email": "vorobeva.n.1989@postgrespro.ru", "phone": "+70947456927"}
0005434028316	703F6D	6520 810941	OLGA MAKAROVA	{"email": "omakarova.30031973@postgrespro.ru", "phone": "+70461531785"}
0005434028317	EAF9EE	7316 761826	NADEZHDA IVANOVA	{"phone": "+70493793191"}
0005434028318	030AE8	4442 047122	IVAN KUZNECOV	{"email": "kuznecov-i-27031973@postgrespro.ru", "phone": "+70646613157"}
0005434028319	A3F3B4	7499 015663	VERA ZAYCEVA	{"email": "zayceva-vera.1977@postgrespro.ru", "phone": "+70903765068"}
0005434028320	A3F3B4	8696 887810	EVGENIY KISELEV	{"phone": "+70441985391"}
0005434028321	15706B	1154 173503	STEPAN KISELEV	{"phone": "+70084609986"}
0005434028322	79A47A	6042 142078	NADEZHDA AKIMOVA	{"phone": "+70951822718"}
0005434028323	934578	9450 505870	YULIYA SMIRNOVA	{"email": "ysmirnova.31101975@postgrespro.ru", "phone": "+70638269013"}
0005434028324	2FB1EB	2967 314037	ALEKSANDRA LEBEDEVA	{"phone": "+70179635534"}
0005434028325	8B9D39	6005 669963	ALEKSANDR OSIPOV	{"phone": "+70248712355"}
0005434028326	AA0911	7045 735127	VERA NIKOLAEVA	{"email": "vera.nikolaeva_051966@postgrespro.ru", "phone": "+70794829406"}
0005434028329	7A7FF0	0064 858759	SERGEY BONDARENKO	{"email": "bondarenko_sergey-18061973@postgrespro.ru", "phone": "+70385083358"}
0005434028330	B431B0	2864 549614	ROMAN KUZNECOV	{"phone": "+70294056206"}
0005434028331	E24A86	0293 817228	IRINA MIKHAYLOVA	{"phone": "+70868056354"}
0005434028332	E24A86	6074 551602	NATALIYA MASLOVA	{"email": "nataliya.maslova-081973@postgrespro.ru", "phone": "+70743158883"}
0005434028333	41CEF4	9618 136038	DMITRIY POPOV	{"phone": "+70739281201"}
0005434028334	FE1987	0228 218023	GALINA EGOROVA	{"email": "egorova.galina16111984@postgrespro.ru", "phone": "+70047850965"}
0005434028335	6E75F3	7521 111131	ARTEM MARTYNOV	{"email": "artem_martynov.1978@postgrespro.ru", "phone": "+70181510680"}
0005434028336	6E75F3	3378 510356	MAKSIM ALEKSANDROV	{"phone": "+70823111521"}
0005434028337	6E75F3	4777 786847	NADEZHDA ZHURAVLEVA	{"email": "n-zhuravleva1963@postgrespro.ru", "phone": "+70760100515"}
0005434028338	0B4B97	9574 775416	INNA NIKOLAEVA	{"email": "nikolaeva.inna_23041972@postgrespro.ru", "phone": "+70032179162"}
0005434028339	0B4B97	0118 158316	TATYANA TROFIMOVA	{"email": "trofimova_t-1971@postgrespro.ru", "phone": "+70687162426"}
0005434028340	F47CCA	8100 764306	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir-1981@postgrespro.ru", "phone": "+70808263575"}
0005434028341	899785	6302 758030	VLADIMIR POPOV	{"email": "popov-vladimir071973@postgrespro.ru", "phone": "+70744339360"}
0005434028342	ADBA2B	2607 382538	ALEKSANDR DENISOV	{"email": "aleksandr.denisov-1971@postgrespro.ru", "phone": "+70577049276"}
0005434028343	120D81	5526 532634	ILYA BONDARENKO	{"email": "ibondarenko.091974@postgrespro.ru", "phone": "+70909425839"}
0005434028344	120D81	0353 181258	VALERIYA ABRAMOVA	{"phone": "+70926885886"}
0005434028345	CFA46F	4697 846126	VLADIMIR RODIONOV	{"email": "vladimir-rodionov.051961@postgrespro.ru", "phone": "+70852290318"}
0005434028346	7FEC4A	2424 274585	ALEKSEY PAVLOV	{"phone": "+70788678682"}
0005434028347	7FEC4A	4201 577430	DMITRIY DAVYDOV	{"email": "davydov-d_1978@postgrespro.ru", "phone": "+70741129752"}
0005434028348	11ECCA	0098 258082	ELENA FROLOVA	{"phone": "+70319811056"}
0005434028349	DE6E29	5162 237653	MATVEY ILIN	{"email": "ilin_matvey.121969@postgrespro.ru", "phone": "+70566354271"}
0005434028350	DE6E29	4144 305132	VALERIY ZAKHAROV	{"email": "zakharovvaleriy_09051973@postgrespro.ru", "phone": "+70279100987"}
0005434028351	4299D9	6660 758270	BORIS TIMOFEEV	{"phone": "+70246633068"}
0005434028352	4299D9	8789 632534	MIKHAIL SIDOROV	{"phone": "+70804349582"}
0005434028353	61DC0B	3335 505659	GALINA NESTEROVA	{"phone": "+70634152807"}
0005434028354	EC7346	4267 594713	MARINA STEPANOVA	{"phone": "+70699984413"}
0005434028355	EC7346	4745 063197	ALEKSEY VASILEV	{"phone": "+70355671233"}
0005434028356	9F8636	2157 315349	ALEKSEY MOROZOV	{"phone": "+70380405423"}
0005434028357	E8E61A	6342 581384	IGOR SOLOVEV	{"phone": "+70677373778"}
0005434028358	47374C	4453 367727	SVETLANA VOROBEVA	{"email": "svetlana_vorobeva-081984@postgrespro.ru", "phone": "+70011727341"}
0005434028359	913B5A	4025 419303	NATALYA BELYAEVA	{"email": "belyaevanatalya.1970@postgrespro.ru", "phone": "+70374587753"}
0005434028360	470190	2932 376264	ANDREY KUZNECOV	{"email": "andrey.kuznecov.03111976@postgrespro.ru", "phone": "+70680215641"}
0005434028361	095411	1803 594146	LIDIYA ANDREEVA	{"phone": "+70467237937"}
0005434028362	5A427F	6908 138931	ANATOLIY KOZLOV	{"email": "kozlov.a_1964@postgrespro.ru", "phone": "+70625927743"}
0005434028363	3483A2	2669 197561	VIKTOR PETROV	{"phone": "+70197448691"}
0005434028364	3483A2	8410 338317	IRINA MAKSIMOVA	{"phone": "+70564723004"}
0005434028365	02F4CE	5551 258968	MARIYA MIKHAYLOVA	{"phone": "+70067933801"}
0005434028366	02F4CE	6252 855972	TATYANA GORBUNOVA	{"email": "t-gorbunova021965@postgrespro.ru", "phone": "+70782460765"}
0005434028367	02F4CE	4679 114751	VLADIMIR DENISOV	{"phone": "+70871998526"}
0005434028368	D1FAC5	6692 170528	NIKOLAY DENISOV	{"email": "ndenisov-29061973@postgrespro.ru", "phone": "+70127620997"}
0005434028369	AA4CF0	6469 533499	VALENTINA DENISOVA	{"phone": "+70766688211"}
0005434028370	4BD760	6986 033427	EVGENIY ZAYCEV	{"phone": "+70436672515"}
0005434028371	4BD760	2898 826491	NATALYA ABRAMOVA	{"phone": "+70839003274"}
0005434028372	762C2E	5006 823276	ANDREY ZAKHAROV	{"email": "zakharov_andrey.1974@postgrespro.ru", "phone": "+70173302336"}
0005434028373	686A41	2295 952166	ANNA KULIKOVA	{"email": "kulikovaanna031975@postgrespro.ru", "phone": "+70328191676"}
0005434028374	686A41	1555 953410	ALEKSEY MIKHAYLOV	{"phone": "+70499589521"}
0005434028375	E42400	1131 298922	VIKTORIYA SIDOROVA	{"email": "v_sidorova_27101976@postgrespro.ru", "phone": "+70864036666"}
0005434028376	E42400	8625 502898	ELIZAVETA LEBEDEVA	{"email": "lebedevae-051984@postgrespro.ru", "phone": "+70929957021"}
0005434028377	375BD0	3739 692768	GALINA IVANOVA	{"phone": "+70575079971"}
0005434028378	F02C3B	0181 178918	ELVIRA KUZNECOVA	{"phone": "+70017366042"}
0005434028379	48B97D	5966 230018	STANISLAV NIKITIN	{"email": "s-nikitin17021964@postgrespro.ru", "phone": "+70585414241"}
0005434028380	AFF8EB	0554 013351	DENIS VASILEV	{"phone": "+70575625852"}
0005434028381	9D1C45	3527 911546	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrova.aleksandra_26071973@postgrespro.ru", "phone": "+70301701728"}
0005434028382	A524FF	0878 625817	SERGEY ZAKHAROV	{"email": "zakharov_sergey-1963@postgrespro.ru", "phone": "+70776462287"}
0005434028383	094DC6	0667 332013	YURIY PETROV	{"phone": "+70977839304"}
0005434028384	7D3747	2157 881204	NATALYA ZHUKOVA	{"email": "zhukova-natalya.21031971@postgrespro.ru", "phone": "+70254242992"}
0005434028388	C3FC13	2094 113671	ELENA BELOVA	{"email": "ebelova.31011976@postgrespro.ru", "phone": "+70425433445"}
0005434028389	AF2320	9129 442622	SERGEY MELNIKOV	{"email": "s.melnikov-23051981@postgrespro.ru", "phone": "+70818393246"}
0005434028390	AF2320	0988 990062	NIKOLAY DMITRIEV	{"email": "nikolaydmitriev1959@postgrespro.ru", "phone": "+70700287024"}
0005434028391	AF2320	0572 299705	SERGEY AFANASEV	{"email": "s.afanasev041981@postgrespro.ru", "phone": "+70386543559"}
0005434028392	37DDF9	1851 259040	OLEG SAVELEV	{"email": "savelevo-111971@postgrespro.ru", "phone": "+70934406288"}
0005434028393	37DDF9	6859 395663	TATYANA EGOROVA	{"phone": "+70600945501"}
0005434028394	644E5F	3339 931129	SVETLANA IVANOVA	{"phone": "+70736131235"}
0005434028395	E2A1B2	2590 813777	NIKOLAY KONOVALOV	{"phone": "+70318302508"}
0005434028396	9086CE	2491 678427	NINA TIMOFEEVA	{"phone": "+70990785804"}
0005434028397	FEB15A	4611 851029	DANIL VASILEV	{"email": "danil.vasilev.1974@postgrespro.ru", "phone": "+70517857829"}
0005434028398	4D9408	0063 258937	VIKTOR ZAYCEV	{"email": "v-zaycev-061973@postgrespro.ru", "phone": "+70106679491"}
0005434028399	D48277	4521 860281	MARINA SOKOLOVA	{"email": "sokolova-m.25081981@postgrespro.ru", "phone": "+70147916660"}
0005434028400	6AB8BF	0688 323563	NIKOLAY PAVLOV	{"email": "n.pavlov-1981@postgrespro.ru", "phone": "+70666808072"}
0005434029634	736F99	6736 114139	VLADIMIR ZHURAVLEV	{"phone": "+70907153938"}
0005434029690	B3C987	0424 866337	ALENA GRISHINA	{"phone": "+70606510604"}
0005434029613	C75F0A	4693 006005	IRINA SEMENOVA	{"phone": "+70991253110"}
0005434029614	7337AD	6687 104726	OLEG BORISOV	{"phone": "+70600560071"}
0005434029615	7337AD	9202 653470	ALEKSANDR SOLOVEV	{"email": "asolovev.1968@postgrespro.ru", "phone": "+70478082975"}
0005434029616	F36AFE	7531 809430	DANIIL OSIPOV	{"phone": "+70300768146"}
0005434029617	F36AFE	8990 827233	INNA NAZAROVA	{"email": "inna_nazarova02091970@postgrespro.ru", "phone": "+70272330455"}
0005434029618	F36AFE	5715 838970	VALENTINA DMITRIEVA	{"email": "dmitrieva.valentina.19071975@postgrespro.ru", "phone": "+70436260183"}
0005434029619	F71DF0	6174 452599	SVETLANA KOZLOVA	{"phone": "+70325828684"}
0005434029620	F71DF0	0227 391645	ELENA BORISOVA	{"email": "borisova_elena.1951@postgrespro.ru", "phone": "+70067294099"}
0005434029621	725D07	2777 352072	VALENTINA ANDREEVA	{"email": "andreeva.v_1972@postgrespro.ru", "phone": "+70269261756"}
0005434029622	725D07	2144 239057	LEONID CHERNOV	{"email": "chernovl.051975@postgrespro.ru", "phone": "+70211582011"}
0005434029623	725D07	4855 538180	VERA MELNIKOVA	{"phone": "+70265536783"}
0005434029624	1A8501	0938 383118	SVETLANA TROFIMOVA	{"email": "s-trofimova-08051969@postgrespro.ru", "phone": "+70892272052"}
0005434029625	1A8501	5042 400337	RAISA LEBEDEVA	{"email": "raisa_lebedeva-25071978@postgrespro.ru", "phone": "+70846973495"}
0005434029626	20E3A5	6747 924617	ALEKSANDRA VLASOVA	{"email": "vlasova.a_101976@postgrespro.ru", "phone": "+70483655526"}
0005434029627	38ADAB	8377 872729	NATALYA MAKSIMOVA	{"phone": "+70913118727"}
0005434029628	EEC750	8643 132250	SVETLANA OSIPOVA	{"email": "s_osipova.081968@postgrespro.ru", "phone": "+70879749536"}
0005434029629	EEC750	2486 380767	IRINA SERGEEVA	{"phone": "+70162443489"}
0005434029630	1AD98A	5371 067218	ANNA BOGDANOVA	{"email": "bogdanovaanna-1976@postgrespro.ru", "phone": "+70732475907"}
0005434029631	E2254D	9619 548765	EVGENIY POPOV	{"phone": "+70869182055"}
0005434029632	D3F8CC	2729 927406	ELVIRA GAVRILOVA	{"phone": "+70911265626"}
0005434029633	736F99	1778 648305	SERGEY KOROLEV	{"phone": "+70680703137"}
0005434029635	1ABCF9	5401 143042	LARISA FOMINA	{"email": "larisa_fomina-1971@postgrespro.ru", "phone": "+70342991732"}
0005434029636	B01BE8	8515 692842	NATALYA AKIMOVA	{"email": "akimova.n-28101983@postgrespro.ru", "phone": "+70567873267"}
0005434029637	D5512D	2346 059201	SVETLANA KUZNECOVA	{"email": "s.kuznecova1965@postgrespro.ru", "phone": "+70510575824"}
0005434029638	0062E8	9276 254962	ALINA LUKYANOVA	{"email": "lukyanova-alina07021962@postgrespro.ru", "phone": "+70407025659"}
0005434029639	57A6C0	4867 308357	ROZA KRASNOVA	{"email": "krasnovar_071978@postgrespro.ru", "phone": "+70075731677"}
0005434029640	57A6C0	5249 369269	TATYANA EGOROVA	{"email": "egorova-t021973@postgrespro.ru", "phone": "+70443664754"}
0005434029641	03614E	1842 032300	ADELINA ALEKSEEVA	{"email": "adelina_alekseeva-021969@postgrespro.ru", "phone": "+70540852393"}
0005434029642	BBC402	4104 613634	IRINA LOGINOVA	{"email": "irina.loginova071971@postgrespro.ru", "phone": "+70080952328"}
0005434029643	C3C6BF	4450 568452	ALEKSANDR KAZAKOV	{"phone": "+70385119970"}
0005434029644	6993F2	8892 108973	LARISA SEMENOVA	{"phone": "+70845766213"}
0005434029645	AE849F	8505 561475	VLADIMIR DAVYDOV	{"email": "v.davydov-18091970@postgrespro.ru", "phone": "+70342388522"}
0005434029646	32AC28	2184 643532	NIKOLAY DAVYDOV	{"email": "n.davydov_1964@postgrespro.ru", "phone": "+70064806941"}
0005434029647	AA1443	2432 316972	VSEVOLOD SMIRNOV	{"phone": "+70228728070"}
0005434029648	AA1443	0518 476782	VYACHESLAV KUZNECOV	{"phone": "+70635838584"}
0005434029649	12D7B8	0609 410005	NIKOLAY FOMIN	{"phone": "+70109736147"}
0005434029650	A6140F	9517 760125	DENIS ALEKSANDROV	{"email": "denis-aleksandrov.081968@postgrespro.ru", "phone": "+70514771025"}
0005434029651	5801A8	2323 496021	YURIY MIKHAYLOV	{"email": "mikhaylovy11071967@postgrespro.ru", "phone": "+70302114542"}
0005434029652	5801A8	8169 337426	OLGA MASLOVA	{"email": "o_maslova061973@postgrespro.ru", "phone": "+70548158470"}
0005434029653	5801A8	6938 587710	EVGENIY CHERNOV	{"email": "evgeniychernov-031983@postgrespro.ru", "phone": "+70358556020"}
0005434029654	F9F527	0670 176705	VIKTORIYA PETROVA	{"email": "v_petrova1972@postgrespro.ru", "phone": "+70670448037"}
0005434029655	383AEB	0527 293205	ALEKSEY SOLOVEV	{"phone": "+70490739294"}
0005434029656	383AEB	9137 837399	VIKTOR MOROZOV	{"email": "morozovviktor-07111971@postgrespro.ru", "phone": "+70928353867"}
0005434029657	861040	4056 012594	DAVID KUZMIN	{"phone": "+70979403682"}
0005434029658	861040	1772 354741	YURIY MAKAROV	{"phone": "+70521702832"}
0005434029659	285247	0218 698658	VLADIMIR BONDARENKO	{"phone": "+70017577959"}
0005434029660	F17BF0	1397 160095	ANASTASIYA BARANOVA	{"email": "baranova.anastasiya-061959@postgrespro.ru", "phone": "+70753801002"}
0005434029661	4C362A	4721 448210	EKATERINA MARTYNOVA	{"phone": "+70943793061"}
0005434029662	D2E8D5	3315 262026	DMITRIY KOROLEV	{"phone": "+70193941053"}
0005434029663	58459A	8162 033011	IRINA NESTEROVA	{"phone": "+70572502264"}
0005434029664	58459A	2226 064519	EVGENIYA ZAKHAROVA	{"email": "zakharova-evgeniya.1981@postgrespro.ru", "phone": "+70591324339"}
0005434029665	C71A45	8069 643886	EVGENIY EGOROV	{"email": "eegorov02121976@postgrespro.ru", "phone": "+70460658776"}
0005434029666	C71A45	0686 260839	ALBERT BORISOV	{"email": "borisov.a-13031983@postgrespro.ru", "phone": "+70606208739"}
0005434029667	77E081	5156 509888	YURIY ZAYCEV	{"email": "zaycev-yuriy_22031965@postgrespro.ru", "phone": "+70292044309"}
0005434029668	5DC12B	6021 543982	VITALIY IVANOV	{"email": "ivanovvitaliy081968@postgrespro.ru", "phone": "+70478398819"}
0005434029669	F30EF0	2071 657548	MIKHAIL KUDRYASHOV	{"email": "kudryashov.mikhail-1961@postgrespro.ru", "phone": "+70147505340"}
0005434029670	61FB03	9027 530521	ILYA SCHERBAKOV	{"email": "scherbakov-ilya-04091974@postgrespro.ru", "phone": "+70926687712"}
0005434029671	A0D2F1	4570 913184	YURIY EGOROV	{"email": "yuriy-egorov.1966@postgrespro.ru", "phone": "+70656737297"}
0005434029672	A0D2F1	8422 395707	DANIIL KULIKOV	{"email": "kulikov.daniil-051977@postgrespro.ru", "phone": "+70180066081"}
0005434029673	FC77DC	5512 243661	RIMMA FEDOROVA	{"email": "r-fedorova011976@postgrespro.ru", "phone": "+70175202957"}
0005434029674	19DA93	9002 616412	GRIGORIY SOROKIN	{"phone": "+70609238213"}
0005434029675	1564A2	3252 659002	EVDOKIYA FOMINA	{"email": "e.fomina09021971@postgrespro.ru", "phone": "+70163289941"}
0005434029676	B1A7A2	1302 624713	DENIS PAVLOV	{"phone": "+70020190775"}
0005434029677	70C063	1042 716594	ANNA ZAKHAROVA	{"email": "zakharova_a031967@postgrespro.ru", "phone": "+70589940062"}
0005434029678	754790	2484 970700	SVETLANA RODIONOVA	{"email": "rodionovas-01121963@postgrespro.ru", "phone": "+70445558772"}
0005434029679	4700A8	2473 130402	MAKSIM EGOROV	{"email": "egorovmaksim-1983@postgrespro.ru", "phone": "+70254104490"}
0005434029680	3F9660	4573 489341	NADEZHDA FEDOROVA	{"phone": "+70304424338"}
0005434029681	3F9660	0200 416376	OLEG SMIRNOV	{"email": "smirnov_oleg1965@postgrespro.ru", "phone": "+70618676511"}
0005434029682	01DCD5	9082 671319	TATYANA EFIMOVA	{"email": "t-efimova-1978@postgrespro.ru", "phone": "+70424283824"}
0005434029683	DECF02	5802 462945	VYACHESLAV VOLKOV	{"email": "volkov.v_27101964@postgrespro.ru", "phone": "+70449078610"}
0005434029684	DECF02	2499 919189	BORIS ZAKHAROV	{"phone": "+70015244931"}
0005434029685	C73C73	8404 406028	NADEZHDA FILIPPOVA	{"email": "filippova-nadezhda-1965@postgrespro.ru", "phone": "+70638230108"}
0005434029686	6BD1A7	6544 258488	MARINA KOZLOVA	{"phone": "+70320061065"}
0005434029687	DD2018	6492 993723	ALEKSEY FOMIN	{"email": "fomin.a.1969@postgrespro.ru", "phone": "+70828509560"}
0005434029688	B3C987	4694 397774	DENIS FROLOV	{"phone": "+70196095819"}
0005434029689	B3C987	0913 504715	VALENTIN DENISOV	{"phone": "+70519621232"}
0005434029691	F31B38	3766 919948	DMITRIY YAKOVLEV	{"phone": "+70013582769"}
0005434029692	F31B38	3784 129332	EGOR ANTONOV	{"phone": "+70036317538"}
0005434029693	F81E12	1292 471101	LYUCIYA OSIPOVA	{"email": "lyuciya-osipova-30071967@postgrespro.ru", "phone": "+70426129912"}
0005434029694	C37675	4076 635200	VLADIMIR RODIONOV	{"email": "rodionovvladimir.06031968@postgrespro.ru", "phone": "+70031894698"}
0005434029695	F87CDE	4561 739263	LYUBOV ZAKHAROVA	{"phone": "+70607738645"}
0005434029696	5B7F18	0259 213783	ANNA IVANOVA	{"phone": "+70026117389"}
0005434029697	5B7F18	2686 889669	PELAGEYA KUDRYASHOVA	{"email": "kudryashovap.1974@postgrespro.ru", "phone": "+70548825234"}
0005434029698	41D539	6091 135801	IBRAGIM RODIONOV	{"phone": "+70142770924"}
0005434029699	41D539	1573 505205	ARTEM ZAKHAROV	{"phone": "+70030836286"}
0005434029700	41D539	6028 919427	LYUDMILA KUZNECOVA	{"phone": "+70734416340"}
0005434029701	B856AB	3216 541607	VALERIY MOISEEV	{"email": "valeriy.moiseev_31101981@postgrespro.ru", "phone": "+70935199978"}
0005434029702	B856AB	7323 227881	NATALYA NIKITINA	{"email": "nikitinanatalya.1979@postgrespro.ru", "phone": "+70210921356"}
0005434029703	4294BB	6767 287829	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr.1968@postgrespro.ru", "phone": "+70969213545"}
0005434029704	7089D2	6806 641576	LIDIYA SOROKINA	{"phone": "+70905305076"}
0005434029705	6D55BB	3736 530503	IVAN MIKHAYLOV	{"email": "mikhaylovivan051988@postgrespro.ru", "phone": "+70605887715"}
0005434029706	34339D	4803 971134	ROMAN KUZMIN	{"email": "r_kuzmin.1972@postgrespro.ru", "phone": "+70744156920"}
0005434029707	34339D	1065 796577	VLADIMIR SIDOROV	{"phone": "+70423520368"}
0005434029708	01B4DC	0736 859125	KSENIYA BELOVA	{"email": "kseniya_belova-17111966@postgrespro.ru", "phone": "+70161452951"}
0005434029709	A84DF4	1476 812349	VALENTINA ARKHIPOVA	{"phone": "+70977588172"}
0005434029710	A84DF4	3588 115758	VLADIMIR TIMOFEEV	{"phone": "+70734563407"}
0005434029711	A166E0	7422 866137	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko1965@postgrespro.ru", "phone": "+70117298980"}
0005434029712	E4FBF5	9338 828936	OLEG KOROLEV	{"phone": "+70791992832"}
0005434029713	557A35	0471 469678	SERAFIMA EFIMOVA	{"email": "serafima.efimova-101967@postgrespro.ru", "phone": "+70338147814"}
0005434029714	557A35	4166 043822	KARINA OVCHINNIKOVA	{"email": "ovchinnikova-k-1962@postgrespro.ru", "phone": "+70886124932"}
0005434029715	E44F8B	4040 144979	EKATERINA KUZNECOVA	{"email": "ekaterina.kuznecova.1961@postgrespro.ru", "phone": "+70215539567"}
0005434029716	E44F8B	1095 803091	EKATERINA ANTONOVA	{"phone": "+70383864429"}
0005434029717	27FD6D	5740 173553	VALENTINA IVANOVA	{"email": "ivanova_v_1984@postgrespro.ru", "phone": "+70771838580"}
0005434029718	F22A37	1198 876862	IRINA NIKITINA	{"phone": "+70567759663"}
0005434029719	F22A37	4854 505032	ALEKSEY SCHERBAKOV	{"phone": "+70092456229"}
0005434029720	51C393	8404 122460	MAYYA FILIPPOVA	{"email": "m-filippova_25051966@postgrespro.ru", "phone": "+70875386143"}
0005434029721	1FBE18	5480 078521	NATALYA VLASOVA	{"phone": "+70413899523"}
0005434029722	1FBE18	9615 552409	YANA NIKITINA	{"email": "nikitina_yana_1983@postgrespro.ru", "phone": "+70365560656"}
0005434029723	1864D4	8819 737437	LYUDMILA OSIPOVA	{"email": "osipova-lyudmila-1965@postgrespro.ru", "phone": "+70602086762"}
0005434029724	013315	7678 571487	INNA LEBEDEVA	{"email": "i-lebedeva-03081970@postgrespro.ru", "phone": "+70980454072"}
0005434029725	589484	3450 018236	SERGEY NIKITIN	{"email": "snikitin021979@postgrespro.ru", "phone": "+70037016050"}
0005434029726	F70681	2544 711522	OLEG KISELEV	{"email": "kiselev_oleg061975@postgrespro.ru", "phone": "+70943266759"}
0005434029727	53C686	3003 614658	ALEKSEY NIKITIN	{"phone": "+70267312814"}
0005434029728	53C686	9559 745483	VALENTINA EGOROVA	{"email": "egorova.valentina-011980@postgrespro.ru", "phone": "+70016639967"}
0005434029729	5A6299	3863 946609	ALEKSANDR KUZMIN	{"email": "a.kuzmin.101960@postgrespro.ru", "phone": "+70346325999"}
0005434029730	5A6299	5773 458507	OLGA KAZAKOVA	{"phone": "+70768368354"}
0005434031944	A71E74	9505 642346	NATALYA KOROLEVA	{"phone": "+70744112202"}
0005434031945	EF18FF	2204 682173	SERGEY PETROV	{"phone": "+70841423321"}
0005434031946	727181	5444 422507	MAKSIM MATVEEV	{"email": "matveev_m-091976@postgrespro.ru", "phone": "+70457344181"}
0005434031947	27195A	4550 053594	NADEZHDA ALEKSEEVA	{"phone": "+70913365558"}
0005434031948	BCAC0C	4022 419216	RAVIL MAKSIMOV	{"email": "ravil-maksimov20021963@postgrespro.ru", "phone": "+70718375943"}
0005434031949	BCAC0C	8245 897613	NINA BARANOVA	{"email": "nbaranova.011963@postgrespro.ru", "phone": "+70817397689"}
0005434031950	566C20	9056 761459	GALINA MALYSHEVA	{"phone": "+70353455005"}
0005434031951	37C9DC	9323 025211	AYRAT MELNIKOV	{"email": "a_melnikov.1969@postgrespro.ru", "phone": "+70948441109"}
0005434031952	29C68E	3180 471664	VLADIMIR GORBUNOV	{"email": "vladimir_gorbunov_29121966@postgrespro.ru", "phone": "+70408364179"}
0005434031953	3BBCED	2598 341601	GENNADIY ANTONOV	{"phone": "+70401592737"}
0005434031954	D4AE5E	8360 311301	MARIYA MAKSIMOVA	{"email": "maksimova.mariya051973@postgrespro.ru", "phone": "+70768337775"}
0005434031955	D4AE5E	5111 553044	SVETLANA POLYAKOVA	{"email": "polyakova-svetlana081971@postgrespro.ru", "phone": "+70612729446"}
0005434031956	2BABDB	1862 056457	SERGEY KAZAKOV	{"phone": "+70226227172"}
0005434031957	AD71F8	7872 574994	SERGEY BARANOV	{"phone": "+70458717322"}
0005434031958	9DC750	1997 306976	LYUDMILA KOMAROVA	{"phone": "+70001987583"}
0005434031959	C232B5	1029 461599	LYUBOV ILINA	{"email": "lyubov-ilina-061977@postgrespro.ru", "phone": "+70265471784"}
0005434031960	B1C674	4998 661380	TATYANA GERASIMOVA	{"email": "t.gerasimova_1963@postgrespro.ru", "phone": "+70351461627"}
0005434031961	4C360C	9601 143902	NELLI ANTONOVA	{"email": "nantonova.19011966@postgrespro.ru", "phone": "+70971336730"}
0005434031962	552434	3389 057948	LYUDMILA LAZAREVA	{"email": "l-lazareva-011989@postgrespro.ru", "phone": "+70559234043"}
0005434031963	552434	3341 951041	NATALYA BARANOVA	{"email": "baranova-natalya_15051976@postgrespro.ru", "phone": "+70997907930"}
0005434031964	54DD74	0360 086410	ALEKSANDR ZHUKOV	{"email": "a.zhukov-1977@postgrespro.ru", "phone": "+70744914354"}
0005434031965	E5A6AC	9594 894581	NATALYA BOGDANOVA	{"phone": "+70567944837"}
0005434031966	E5A6AC	1829 070855	MARIYA MIKHAYLOVA	{"email": "mikhaylovamariya.09061965@postgrespro.ru", "phone": "+70512741550"}
0005434031967	472E6D	2580 058810	VYACHESLAV POPOV	{"email": "vyacheslav_popov1959@postgrespro.ru", "phone": "+70696154164"}
0005434031968	4F755B	1532 649324	ANTON PETROV	{"email": "anton-petrov-061980@postgrespro.ru", "phone": "+70466822256"}
0005434031969	E069B4	2275 395427	TATYANA ALEKSEEVA	{"email": "alekseeva.t051980@postgrespro.ru", "phone": "+70136833042"}
0005434031970	51CB14	6674 521023	SVETLANA IVANOVA	{"email": "sivanova.06031980@postgrespro.ru", "phone": "+70361688080"}
0005434031971	898220	1358 089263	ALEKSANDRA ILINA	{"email": "aleksandra_ilina041973@postgrespro.ru", "phone": "+70864060748"}
0005434031972	211301	9857 067767	LIDIYA NIKOLAEVA	{"phone": "+70406885330"}
0005434031973	211301	9481 282449	LYUDMILA DAVYDOVA	{"phone": "+70036065826"}
0005434031974	9BC2E1	9692 706549	ANNA ZHURAVLEVA	{"email": "azhuravleva_17081984@postgrespro.ru", "phone": "+70084143612"}
0005434031975	FA213D	9368 848756	ANDREY NAZAROV	{"email": "nazarov.andrey-011976@postgrespro.ru", "phone": "+70753749045"}
0005434031976	50D78A	7165 510950	SVETLANA GERASIMOVA	{"phone": "+70547880092"}
0005434031977	92EA7F	4373 440318	KRISTINA MASLOVA	{"phone": "+70897236516"}
0005434031978	FE286F	9281 159858	SERGEY MOISEEV	{"email": "moiseev-sergey_021973@postgrespro.ru", "phone": "+70612396858"}
0005434031979	DF6339	5292 604443	YULIYA ILINA	{"email": "ilinayuliya091977@postgrespro.ru", "phone": "+70577593677"}
0005434031980	DF6339	9716 109547	MARIYA FROLOVA	{"phone": "+70181970632"}
0005434031981	3E7643	5441 306012	ALEKSANDR NIKITIN	{"email": "a.nikitin101974@postgrespro.ru", "phone": "+70226195151"}
0005434031982	0A9011	7890 776631	ELENA BARANOVA	{"phone": "+70040508483"}
0005434031983	0A9011	5128 890987	LYUDMILA MEDVEDEVA	{"email": "l_medvedeva.04071975@postgrespro.ru", "phone": "+70271456673"}
0005434031984	D4D414	0725 824327	MARINA GRISHINA	{"email": "grishina_marina.1971@postgrespro.ru", "phone": "+70624612540"}
0005434031985	7FF00E	3867 739027	MAKSIM VOROBEV	{"email": "vorobev-m.011972@postgrespro.ru", "phone": "+70226269147"}
0005434031986	9D2D39	7640 661126	ANASTASIYA GERASIMOVA	{"email": "gerasimova.a.021976@postgrespro.ru", "phone": "+70580398018"}
0005434031987	324AA0	5657 465344	EMIL KUZNECOV	{"email": "e_kuznecov-1985@postgrespro.ru", "phone": "+70072458267"}
0005434031988	E6D220	4785 909377	MARIYA NIKOLAEVA	{"phone": "+70043492612"}
0005434031989	E6D220	4836 694078	ANASTASIYA DMITRIEVA	{"phone": "+70752407877"}
0005434031990	F95D04	8447 632135	ALEKSEY TIKHONOV	{"email": "aleksey-tikhonov.1967@postgrespro.ru", "phone": "+70322570488"}
0005434031991	B51DCA	7782 640203	ANDREY DMITRIEV	{"phone": "+70468418345"}
0005434031992	B51DCA	3493 590006	VALENTINA BELYAEVA	{"email": "belyaeva_v-101965@postgrespro.ru", "phone": "+70804553304"}
0005434031993	B51DCA	8877 812484	VALENTINA TIKHONOVA	{"phone": "+70968634362"}
0005434031994	3B829F	3165 014866	VARVARA POPOVA	{"email": "v-popova_051969@postgrespro.ru", "phone": "+70522996783"}
0005434031995	81873C	9548 339025	VERONIKA IVANOVA	{"phone": "+70875577567"}
0005434031996	0765FC	3957 910694	DARYA POTAPOVA	{"email": "d-potapova10021977@postgrespro.ru", "phone": "+70625273979"}
0005434031997	0765FC	2429 011610	YULIYA KOZLOVA	{"email": "kozlova.yuliya26121968@postgrespro.ru", "phone": "+70680414702"}
0005434031998	5D4F25	3198 039133	ROMAN EGOROV	{"phone": "+70648085623"}
0005434031999	420583	0285 888353	NATALYA IVANOVA	{"phone": "+70616992187"}
0005434032000	420583	4785 698208	DENIS MAKSIMOV	{"email": "maksimov.d23031970@postgrespro.ru", "phone": "+70479267422"}
0005434032001	50352B	4065 528154	ALEKSANDRA KOZLOVA	{"email": "kozlovaaleksandra1964@postgrespro.ru", "phone": "+70822544895"}
0005434032002	C30FB3	7839 720080	SERGEY IVANOV	{"email": "ivanovsergey.02041987@postgrespro.ru", "phone": "+70849572960"}
0005434032003	54A28C	8683 684140	NADEZHDA TROFIMOVA	{"email": "trofimova_nadezhda.1979@postgrespro.ru", "phone": "+70935384472"}
0005434032004	0E0DA5	4392 291860	ALLA KUZMINA	{"email": "kuzmina.a1976@postgrespro.ru", "phone": "+70418766927"}
0005434032005	1FD608	4763 793954	VLADIMIR EGOROV	{"phone": "+70086705438"}
0005434032006	1FD608	2655 946578	EVGENIYA EGOROVA	{"email": "evgeniyaegorova.071977@postgrespro.ru", "phone": "+70650656974"}
0005434032007	C2925D	0377 115459	SAVELIY KUZNECOV	{"phone": "+70448083860"}
0005434032008	2C00D2	4524 452590	NATALYA SAVELEVA	{"phone": "+70219000170"}
0005434032009	2C00D2	7981 631997	LYUDMILA RYABOVA	{"email": "ryabovalyudmila_071964@postgrespro.ru", "phone": "+70018784561"}
0005434032010	1FC034	9494 344941	ANDREY VASILEV	{"email": "a.vasilev.1965@postgrespro.ru", "phone": "+70894097791"}
0005434032011	1FC034	4486 974703	LYUBOV CHERNOVA	{"phone": "+70173734460"}
0005434032012	D10339	3289 464418	DMITRIY NIKOLAEV	{"phone": "+70622163132"}
0005434032013	D10339	4556 038651	TATYANA BORISOVA	{"phone": "+70020658559"}
0005434032014	A6CE40	3124 004681	RUSTAM FILIPPOV	{"email": "rustam-filippov_121978@postgrespro.ru", "phone": "+70995003734"}
0005434032015	F70F18	1060 030823	ALEKSEY MEDVEDEV	{"phone": "+70321945364"}
0005434032016	A5E01E	0197 755571	NADEZHDA IVANOVA	{"phone": "+70410661149"}
0005434032017	CB47A3	8160 272146	IRINA IVANOVA	{"email": "irina_ivanova_091970@postgrespro.ru", "phone": "+70879803412"}
0005434032018	54F17E	0080 293234	VLADIMIR SIDOROV	{"email": "sidorov-v-071971@postgrespro.ru", "phone": "+70039130813"}
0005434032019	D67DB5	1412 344969	EVGENIY KOROLEV	{"email": "ekorolev.031976@postgrespro.ru", "phone": "+70524251377"}
0005434032020	0E186F	9787 794026	NELLI ARKHIPOVA	{"email": "narkhipova_1964@postgrespro.ru", "phone": "+70780674793"}
0005434032021	09F2F7	2165 584056	ARINA KOZLOVA	{"email": "kozlova_arina041981@postgrespro.ru", "phone": "+70446019347"}
0005434032022	8E0F10	1697 172451	SERGEY DAVYDOV	{"phone": "+70818498706"}
0005434032023	D8B7B8	1782 014463	SERGEY IVANOV	{"email": "s-ivanov-03071970@postgrespro.ru", "phone": "+70434574959"}
0005434032024	D8B7B8	8631 813718	OLGA RYABOVA	{"email": "olgaryabova.031971@postgrespro.ru", "phone": "+70962473306"}
0005434032025	2D34F0	3754 239630	ALISA POPOVA	{"phone": "+70064807996"}
0005434032026	BDB651	2326 681510	VALENTINA POPOVA	{"email": "valentina-popova_1975@postgrespro.ru", "phone": "+70580179658"}
0005434032027	BDB651	5249 483922	ELENA DMITRIEVA	{"email": "dmitrievae.011969@postgrespro.ru", "phone": "+70389737072"}
0005434032028	EBDBBE	3522 274762	VERA ABRAMOVA	{"email": "abramova_vera_1974@postgrespro.ru", "phone": "+70048904653"}
0005434032029	803444	8173 876445	VADIM VASILEV	{"phone": "+70355154827"}
0005434032030	803444	6482 070206	MARINA SAVELEVA	{"phone": "+70734462777"}
0005434032031	6851AC	0431 027997	VALENTIN BORISOV	{"email": "valentin_borisov-011977@postgrespro.ru", "phone": "+70323280060"}
0005434032032	04D0B8	3376 971090	OLGA SOKOLOVA	{"email": "o.sokolova-121979@postgrespro.ru", "phone": "+70521713460"}
0005434032033	4610B9	5136 489500	VLADIMIR ALEKSEEV	{"email": "valekseev.121974@postgrespro.ru", "phone": "+70578013672"}
0005434032034	C8A118	4446 306041	NADEZHDA ISAEVA	{"email": "n_isaeva_061973@postgrespro.ru", "phone": "+70969587158"}
0005434032035	C8A118	6897 090581	NATALIYA MAKAROVA	{"phone": "+70577293701"}
0005434032036	95B647	8424 245710	GENNADIY DMITRIEV	{"email": "gdmitriev.121968@postgrespro.ru", "phone": "+70874536412"}
0005434032037	95B647	9340 427226	NATALYA VOLKOVA	{"phone": "+70538173807"}
0005434032038	681C0B	9587 302594	ELENA MOROZOVA	{"phone": "+70908589682"}
0005434032039	681C0B	8214 718015	VYACHESLAV KONOVALOV	{"email": "konovalov_vyacheslav1976@postgrespro.ru", "phone": "+70191462372"}
0005434032040	6183AE	1765 426897	VLADIMIR SCHERBAKOV	{"phone": "+70944626179"}
0005434032041	BD641D	7832 925827	ELENA FEDOROVA	{"phone": "+70942916375"}
0005434032042	C77587	7937 747842	SERGEY VASILEV	{"email": "sergey-vasilev-1987@postgrespro.ru", "phone": "+70665117884"}
0005434032043	C77587	7764 423557	YURIY DENISOV	{"phone": "+70213942123"}
0005434032044	FB928C	4151 894521	ILYA GORBUNOV	{"email": "gorbunov-ilya.081968@postgrespro.ru", "phone": "+70152419770"}
0005434032045	2957A0	6608 202231	YURIY STEPANOV	{"phone": "+70327595344"}
0005434032046	BC8487	2110 466017	SERGEY VASILEV	{"phone": "+70902928374"}
0005434032047	749F7B	0718 459539	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr-09031963@postgrespro.ru", "phone": "+70841743816"}
0005434032048	03ABED	2414 766930	VALENTIN PAVLOV	{"phone": "+70132092940"}
0005434032049	03ABED	7178 273805	OLGA SEMENOVA	{"phone": "+70756036840"}
0005434032050	34CEDB	0099 734143	RUSLAN VOLKOV	{"email": "volkovruslan_021962@postgrespro.ru", "phone": "+70589171425"}
0005434032051	35BBA6	0732 348314	VLADIMIR KOZLOV	{"email": "kozlov-vladimir_041966@postgrespro.ru", "phone": "+70211485463"}
0005434032052	B00E1C	2923 881886	MIKHAIL NOVIKOV	{"email": "novikov-mikhail1957@postgrespro.ru", "phone": "+70514544394"}
0005434032053	7A577E	9391 926263	TATYANA ARKHIPOVA	{"email": "arkhipova.tatyana_121987@postgrespro.ru", "phone": "+70829702422"}
0005434032054	519645	0150 010077	EVGENIYA KUDRYASHOVA	{"email": "evgeniyakudryashova-1963@postgrespro.ru", "phone": "+70924817649"}
0005434032055	23D57A	1252 752945	SERGEY MEDVEDEV	{"phone": "+70816794457"}
0005434032056	F06DC9	9128 413962	VALERIY MAKSIMOV	{"phone": "+70940106502"}
0005434032057	938E52	8316 646912	ALLA KRASNOVA	{"phone": "+70892225657"}
0005434032058	2A392A	9618 750871	EVGENIYA MOISEEVA	{"email": "moiseeva-evgeniya.081983@postgrespro.ru", "phone": "+70143162804"}
0005434032059	4CFD3D	4031 992393	MAKSIM KRASNOV	{"email": "krasnovmaksim_1980@postgrespro.ru", "phone": "+70567102534"}
0005434032060	4CFD3D	5951 402361	OLGA ZAKHAROVA	{"email": "zakharovaolga1979@postgrespro.ru", "phone": "+70368140518"}
0005434032061	2B919D	1157 543415	ELIZAVETA FILATOVA	{"email": "filatovaelizaveta-021981@postgrespro.ru", "phone": "+70945773829"}
0005434032062	D419C5	8316 437277	ZOYA CHERNOVA	{"email": "chernova_z-19111978@postgrespro.ru", "phone": "+70621607281"}
0005434032063	1F1459	2811 501118	VIKTOR ANDREEV	{"email": "andreev.v.071972@postgrespro.ru", "phone": "+70296208636"}
0005434032064	1F1459	0572 459607	NADEZHDA PETROVA	{"phone": "+70620496228"}
0005434032065	71AABE	5090 433152	GALINA KUZMINA	{"email": "galina.kuzmina.1973@postgrespro.ru", "phone": "+70710238050"}
0005434032066	905473	7606 857432	VYACHESLAV MOROZOV	{"email": "vyacheslav-morozov.071967@postgrespro.ru", "phone": "+70809240913"}
0005434032067	905473	2905 022391	VALENTINA MELNIKOVA	{"email": "melnikovav.1988@postgrespro.ru", "phone": "+70870024649"}
0005434032068	2A6480	1559 557109	POLINA ZHURAVLEVA	{"email": "polina.zhuravleva021981@postgrespro.ru", "phone": "+70799435101"}
0005434032069	2A6480	0777 194554	KRISTINA OVCHINNIKOVA	{"email": "ovchinnikova-k_11111968@postgrespro.ru", "phone": "+70900147294"}
0005434032070	257961	0655 733612	IRINA FILATOVA	{"phone": "+70574553620"}
0005434032071	3871C7	2859 740991	FAINA LUKYANOVA	{"email": "faina-lukyanova.081964@postgrespro.ru", "phone": "+70663801266"}
0005434032072	3871C7	3401 266596	MARIYA NIKITINA	{"phone": "+70149518715"}
0005434032073	25C754	5437 882582	NATALYA BARANOVA	{"email": "n-baranova-1979@postgrespro.ru", "phone": "+70536251350"}
0005434032074	25C754	7198 700708	NATALYA ALEKSEEVA	{"email": "alekseeva.n.081982@postgrespro.ru", "phone": "+70539996613"}
0005434032075	BE246C	9699 186366	LYUBOV SAVELEVA	{"email": "saveleval_1980@postgrespro.ru", "phone": "+70648866887"}
0005434032076	BE246C	7995 453782	SVETLANA SEMENOVA	{"email": "s_semenova14071975@postgrespro.ru", "phone": "+70732497266"}
0005434032077	D3DD69	2869 447651	LYUBOV KULIKOVA	{"email": "kulikova.l_14031967@postgrespro.ru", "phone": "+70479942137"}
0005434032078	869D1F	7504 066513	ALEKSANDR TIKHONOV	{"email": "atikhonov061978@postgrespro.ru", "phone": "+70218958188"}
0005434032079	869D1F	5069 799217	TATYANA ILINA	{"email": "ilina-t.1971@postgrespro.ru", "phone": "+70721256311"}
0005434032080	BDEA35	3983 935874	SERGEY SOROKIN	{"email": "sorokin_s_061975@postgrespro.ru", "phone": "+70180756554"}
0005434032081	BDEA35	3940 890831	SHAMIL MIKHAYLOV	{"email": "shamil.mikhaylov1970@postgrespro.ru", "phone": "+70715338216"}
0005434032082	C84B60	1989 161151	OLEG KONOVALOV	{"email": "konovalov_oleg.101973@postgrespro.ru", "phone": "+70017342461"}
0005434032083	B5765A	3976 429098	VALENTINA VASILEVA	{"phone": "+70034489572"}
0005434032084	8EB761	6868 335515	TAISIYA ALEKSEEVA	{"email": "taisiya-alekseeva-19111963@postgrespro.ru", "phone": "+70399216551"}
0005434032085	8EB761	5234 669814	ALLA MIRONOVA	{"phone": "+70229583263"}
0005434032086	F1D16E	7146 178200	MARINA AFANASEVA	{"phone": "+70259336808"}
0005434032087	C274F2	2434 716184	ANATOLIY YAKOVLEV	{"email": "anatoliy.yakovlev011959@postgrespro.ru", "phone": "+70719203486"}
0005434032088	FB1BE1	9555 550776	NINA KUZNECOVA	{"email": "nkuznecova-01031978@postgrespro.ru", "phone": "+70384143681"}
0005434032089	292726	3679 092160	OLGA ILINA	{"email": "olga_ilina-1966@postgrespro.ru", "phone": "+70845827415"}
0005434032090	865403	0346 897676	VALERIY FEDOROV	{"phone": "+70947502225"}
0005434032091	5E1C29	2113 515081	NADEZHDA BOGDANOVA	{"phone": "+70097389419"}
0005434032092	5E1C29	1208 756796	DINARA FILIPPOVA	{"email": "filippovadinara_18011980@postgrespro.ru", "phone": "+70487968539"}
0005434032093	5E1C29	7188 788660	SERGEY FEDOROV	{"phone": "+70040211048"}
0005434032094	7BF879	0603 715129	DMITRIY ROMANOV	{"email": "dromanov1968@postgrespro.ru", "phone": "+70910536818"}
0005434032095	61EA09	1127 137141	DMITRIY MIKHAYLOV	{"phone": "+70533089213"}
0005434032096	729E0A	3665 306522	NINA IVANOVA	{"phone": "+70416904215"}
0005434032097	B17B4E	6719 531780	NADIYA KUZNECOVA	{"email": "kuznecova.nadiya_1982@postgrespro.ru", "phone": "+70518202813"}
0005434032098	48A882	1396 669581	OLGA KUZNECOVA	{"phone": "+70485620092"}
0005434032099	521A7D	4277 555977	TATYANA GORBUNOVA	{"phone": "+70613388990"}
0005434032100	521A7D	0895 787735	TATYANA SEMENOVA	{"email": "tatyanasemenova-031966@postgrespro.ru", "phone": "+70770988489"}
0005434032101	B20916	9213 019243	LYUBOV POPOVA	{"phone": "+70597454162"}
0005434032102	E5B764	6783 952582	RUSLAN KUZMIN	{"phone": "+70145024802"}
0005434032103	36BC76	8053 774458	MARIYA KUZNECOVA	{"phone": "+70172224561"}
0005434032104	85D73B	1434 480184	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr_26101993@postgrespro.ru", "phone": "+70555104325"}
0005434032105	0B13E9	5624 693890	LYUBOV YAKOVLEVA	{"email": "lyubov_yakovleva-02011984@postgrespro.ru", "phone": "+70631273372"}
0005434032106	0B13E9	5442 228367	ALEKSANDR TIMOFEEV	{"phone": "+70085501266"}
0005434032107	F57D9C	0725 243756	GALINA FROLOVA	{"email": "frolova-g.1974@postgrespro.ru", "phone": "+70729850268"}
0005434032108	F57D9C	2003 782848	SERGEY KISELEV	{"phone": "+70745094860"}
0005434032109	38A737	4516 711740	VLADIMIR OSIPOV	{"phone": "+70555515391"}
0005434032110	34CAC9	4851 091691	OKSANA NIKITINA	{"phone": "+70784465338"}
0005434032111	EEDFC6	6035 623215	NADEZHDA AKIMOVA	{"phone": "+70421810952"}
0005434032112	E56912	2884 884222	SVETLANA CHERNOVA	{"phone": "+70701437743"}
0005434032113	E56912	9196 372475	ANATOLIY ZAKHAROV	{"email": "zakharov.anatoliy-1975@postgrespro.ru", "phone": "+70018876578"}
0005434066601	42C626	7795 516349	SERGEY SCHERBAKOV	{"phone": "+70051733346"}
0005434032114	50D928	1070 160533	VASILIY BARANOV	{"email": "baranovv_051964@postgrespro.ru", "phone": "+70005568954"}
0005434032115	DB58BA	9859 545794	VASILIY RODIONOV	{"email": "v.rodionov-1979@postgrespro.ru", "phone": "+70622861958"}
0005434032116	DB58BA	9201 103800	SERGEY MIRONOV	{"email": "mironov-sergey_1974@postgrespro.ru", "phone": "+70998924135"}
0005434032117	5C1EE4	2145 377300	OLGA DENISOVA	{"email": "olgadenisova-051967@postgrespro.ru", "phone": "+70644925556"}
0005434032118	5C1EE4	9572 413109	ANDREY SAVELEV	{"email": "saveleva03021960@postgrespro.ru", "phone": "+70741218714"}
0005434032119	F77994	7309 393277	VASILIY VOLKOV	{"phone": "+70990060269"}
0005434032120	A878B8	2598 616536	IRINA BORISOVA	{"email": "borisovai_041963@postgrespro.ru", "phone": "+70414690827"}
0005434032121	E47180	7627 180570	YURIY SOKOLOV	{"email": "sokolov_y.121969@postgrespro.ru", "phone": "+70450998504"}
0005434032122	05466E	7567 018646	RAISA VLASOVA	{"email": "vlasova.r1969@postgrespro.ru", "phone": "+70756179586"}
0005434032123	05466E	3883 777058	ANATOLIY GERASIMOV	{"phone": "+70681516596"}
0005434032124	4A3628	6533 616203	DANIL BELOV	{"phone": "+70321086940"}
0005434032125	F9E0C2	9350 462986	VIKTOR TIKHONOV	{"email": "viktor-tikhonov03041969@postgrespro.ru", "phone": "+70283141195"}
0005434032126	F9E0C2	8030 797286	NATALYA SMIRNOVA	{"email": "n_smirnova.17081958@postgrespro.ru", "phone": "+70345054678"}
0005434032127	8DFB46	1349 772530	EVGENIY RODIONOV	{"email": "evgeniy-rodionov.021972@postgrespro.ru", "phone": "+70416509162"}
0005434032128	437C0B	2737 575619	NATALYA OSIPOVA	{"phone": "+70745827214"}
0005434032129	8BC43B	0136 890819	NADEZHDA ZAKHAROVA	{"phone": "+70936740765"}
0005434032130	2E92C6	5973 948086	ARTEM ALEKSANDROV	{"email": "aleksandrovartem_07051966@postgrespro.ru", "phone": "+70370018037"}
0005434032131	E772F4	0440 785267	ANDREY RODIONOV	{"phone": "+70114429215"}
0005434032132	08C1F7	2430 820167	ARTEM MAKAROV	{"phone": "+70813186701"}
0005434032133	700AB6	1934 450515	VLADIMIR BARANOV	{"phone": "+70333358378"}
0005434032134	5D404C	1050 623728	ELIZAVETA SOLOVEVA	{"email": "soloveva-e_051980@postgrespro.ru", "phone": "+70804127421"}
0005434032135	5D404C	8819 796476	VALENTINA NOVIKOVA	{"email": "v.novikova_121963@postgrespro.ru", "phone": "+70129336073"}
0005434032136	5D404C	5123 898509	ALEKSANDR ISAEV	{"phone": "+70457175851"}
0005434032137	BB599A	7293 636392	VLADIMIR NIKITIN	{"phone": "+70703815196"}
0005434032138	0936A3	1135 798667	IRINA AFANASEVA	{"email": "afanaseva-irina.081969@postgrespro.ru", "phone": "+70392479908"}
0005434032139	F1A580	6138 149748	NADEZHDA PAVLOVA	{"phone": "+70543839624"}
0005434032140	27A66D	8900 314685	FAINA MIRONOVA	{"phone": "+70063584372"}
0005434032141	F695C7	8073 005400	SEMEN SIDOROV	{"phone": "+70584190710"}
0005434032142	81F79A	0205 406483	YURIY MAKAROV	{"phone": "+70310840614"}
0005434032143	81F79A	6861 995090	OLGA KISELEVA	{"email": "o.kiseleva101970@postgrespro.ru", "phone": "+70527207558"}
0005434032144	81F79A	4753 391572	YULIYA EFREMOVA	{"email": "efremova-y.1985@postgrespro.ru", "phone": "+70523200302"}
0005434032145	81F79A	5285 674063	OLEG PAVLOV	{"email": "pavlov-o_1982@postgrespro.ru", "phone": "+70988637342"}
0005434032146	A94578	7564 641613	ALEKSEY MIRONOV	{"email": "alekseymironov-031975@postgrespro.ru", "phone": "+70002024854"}
0005434032147	7F0E34	7590 926877	EVGENIYA FADEEVA	{"email": "fadeeva.e-1986@postgrespro.ru", "phone": "+70067141055"}
0005434032148	7F0E34	4852 009101	ALBERT GORBUNOV	{"phone": "+70250415318"}
0005434032149	24D849	7551 439062	IRINA SERGEEVA	{"email": "i-sergeeva_13111968@postgrespro.ru", "phone": "+70230258157"}
0005434032150	CD9B79	4924 757028	DMITRIY KUZNECOV	{"phone": "+70869957661"}
0005434032151	AB10A2	6097 804942	NATALIYA PAVLOVA	{"phone": "+70361813980"}
0005434032152	398259	5718 533809	ALFIYA SMIRNOVA	{"email": "alfiya_smirnova-021966@postgrespro.ru", "phone": "+70891519416"}
0005434032153	9153E4	4230 533273	DMITRIY GRIGOREV	{"email": "d_grigorev051965@postgrespro.ru", "phone": "+70401243350"}
0005434032154	14D069	5380 334015	ELIZAVETA VOROBEVA	{"email": "vorobevaelizaveta_1980@postgrespro.ru", "phone": "+70760683531"}
0005434032155	882ADA	3052 830655	MARINA NESTEROVA	{"phone": "+70407409119"}
0005434032156	882ADA	3327 893591	ANZHELIKA IVANOVA	{"email": "ivanovaanzhelika_1969@postgrespro.ru", "phone": "+70879005902"}
0005434032157	BD4113	6556 919346	SERGEY ORLOV	{"phone": "+70735720518"}
0005434032158	55AD2F	7733 261545	ELENA FROLOVA	{"email": "frolovae_1973@postgrespro.ru", "phone": "+70260992635"}
0005434032159	89AE4C	0191 079289	MIKHAIL GUSEV	{"phone": "+70505451923"}
0005434032160	89AE4C	6794 950568	LYUDMILA PETROVA	{"email": "petrovalyudmila.081980@postgrespro.ru", "phone": "+70686670415"}
0005434032161	64A7C9	1280 427157	LYUDMILA NOVIKOVA	{"email": "novikova_lyudmila.20091974@postgrespro.ru", "phone": "+70888369005"}
0005434032162	912E87	0741 430014	YURIY OSIPOV	{"email": "yuriyosipov_03071967@postgrespro.ru", "phone": "+70751720677"}
0005434066295	F7FF78	9687 641809	VALENTINA FROLOVA	{"phone": "+70774100653"}
0005434066296	F7FF78	0606 971011	ARTEM ZAKHAROV	{"email": "artem-zakharov-17041977@postgrespro.ru", "phone": "+70828977266"}
0005434066297	1D644B	1466 311440	ALEKSANDR TARASOV	{"phone": "+70583464302"}
0005434066298	1D644B	4976 498306	GENNADIY KRASNOV	{"phone": "+70997631999"}
0005434066299	8B2D89	8608 601630	VALENTINA ROMANOVA	{"email": "romanova.v.19111975@postgrespro.ru", "phone": "+70214956759"}
0005434066300	E16A09	5378 918957	ALEKSANDRA GAVRILOVA	{"phone": "+70610378433"}
0005434066301	5CA999	9506 831910	SERGEY GERASIMOV	{"email": "sergeygerasimov-14121957@postgrespro.ru", "phone": "+70131548315"}
0005434066302	5CA999	4845 612064	IVAN KISELEV	{"phone": "+70297670749"}
0005434066303	F098E4	7540 465829	LYUDMILA ILINA	{"email": "lyudmila-ilina.041973@postgrespro.ru", "phone": "+70710888373"}
0005434066304	365612	2756 915100	RAMIL VASILEV	{"phone": "+70705833956"}
0005434066305	365612	4486 567337	NIKOLAY ANDREEV	{"email": "nandreev.031972@postgrespro.ru", "phone": "+70470914256"}
0005434066306	A5E52D	3922 711415	ANNA ROMANOVA	{"email": "romanova.a.23081978@postgrespro.ru", "phone": "+70123704372"}
0005434066307	4609D9	6748 657825	SERGEY ZHUKOV	{"phone": "+70812931787"}
0005434066308	9E5D12	2332 756350	VLADIMIR ISAEV	{"email": "isaev_vladimir-24101970@postgrespro.ru", "phone": "+70678910339"}
0005434066309	B8043C	9608 987142	LILIYA ABRAMOVA	{"email": "labramova111979@postgrespro.ru", "phone": "+70262369212"}
0005434066310	1AF662	7404 044958	DANILA IVANOV	{"email": "danila-ivanov.101962@postgrespro.ru", "phone": "+70623205584"}
0005434066311	674B9B	6596 704785	ANNA STEPANOVA	{"phone": "+70624809567"}
0005434066312	0B2986	9689 962353	ELENA STEPANOVA	{"email": "elena-stepanova-031975@postgrespro.ru", "phone": "+70228339934"}
0005434066313	056AB1	7594 617892	ALEKSEY VOROBEV	{"phone": "+70941188285"}
0005434066314	736A61	6532 188060	NATALYA MOROZOVA	{"phone": "+70520822862"}
0005434066315	736A61	8035 496220	ANASTASIYA POTAPOVA	{"email": "potapova.a.091978@postgrespro.ru", "phone": "+70866503777"}
0005434066316	873209	5306 300531	EKATERINA TROFIMOVA	{"email": "trofimovae081975@postgrespro.ru", "phone": "+70212385575"}
0005434066317	59DA9D	9112 197658	MIKHAIL EGOROV	{"email": "mikhail_egorov-1981@postgrespro.ru", "phone": "+70235761540"}
0005434066318	59DA9D	1431 801228	NATALYA PETROVA	{"email": "natalya-petrova05051971@postgrespro.ru", "phone": "+70270286561"}
0005434066319	6823F4	2160 081668	LYUDMILA MIKHAYLOVA	{"phone": "+70177853619"}
0005434066320	6823F4	3676 139739	ANDREY NOVIKOV	{"phone": "+70238524429"}
0005434066321	902DD7	7320 839730	ALEKSEY KULIKOV	{"phone": "+70446623408"}
0005434066322	1F19C8	4730 796349	LYUDMILA GUSEVA	{"email": "l-guseva_03011974@postgrespro.ru", "phone": "+70817898641"}
0005434066323	1F19C8	6171 159193	OLGA ABRAMOVA	{"email": "olga_abramova_021979@postgrespro.ru", "phone": "+70232677191"}
0005434066324	652ED6	7695 735755	ZHANNA IVANOVA	{"email": "ivanova.z121984@postgrespro.ru", "phone": "+70965285688"}
0005434066325	022097	2082 318469	POLINA YUDINA	{"email": "yudina.polina091975@postgrespro.ru", "phone": "+70327606485"}
0005434066326	D0A75D	5028 008572	KRISTINA IVANOVA	{"email": "ivanova.k_081973@postgrespro.ru", "phone": "+70231025213"}
0005434066327	A48415	4866 225083	VLADIMIR VOLKOV	{"phone": "+70010895568"}
0005434066328	A48415	2101 753758	LYUDMILA VLASOVA	{"email": "vlasova.l_27021975@postgrespro.ru", "phone": "+70485083199"}
0005434066329	9736B5	2011 574401	MARGARITA NOVIKOVA	{"email": "novikovamargarita.08091972@postgrespro.ru", "phone": "+70608144949"}
0005434066330	EF1393	6494 354563	MIKHAIL SHEVCHENKO	{"email": "shevchenko.mikhail_02101978@postgrespro.ru", "phone": "+70149463509"}
0005434066331	F73729	5540 891631	POLINA MOROZOVA	{"email": "morozova.p_12031969@postgrespro.ru", "phone": "+70697535757"}
0005434066332	45282A	2822 619436	ANDREY FILIPPOV	{"email": "filippov-a_29071976@postgrespro.ru", "phone": "+70977330550"}
0005434066333	45282A	5065 598096	OLEG FEDOROV	{"email": "o-fedorov1972@postgrespro.ru", "phone": "+70278853232"}
0005434066334	26C8F0	2975 891788	MARIYA GAVRILOVA	{"phone": "+70976622699"}
0005434066335	03CCC5	1876 727117	VLADIMIR SMIRNOV	{"phone": "+70126598915"}
0005434066336	E80B4F	3390 227197	ALBINA ANTONOVA	{"email": "antonovaa03031973@postgrespro.ru", "phone": "+70194583228"}
0005434066337	E80B4F	7533 753573	ALENA IVANOVA	{"email": "ivanova-alena.04081964@postgrespro.ru", "phone": "+70070140087"}
0005434066338	1B499B	0103 799228	DMITRIY KOZLOV	{"email": "dmitriy-kozlov-011979@postgrespro.ru", "phone": "+70989510513"}
0005434066339	C9FE74	3744 542790	IGOR MIRONOV	{"email": "mironov.igor_1964@postgrespro.ru", "phone": "+70783843803"}
0005434066340	C11E18	0652 429555	RINAT ZHUKOV	{"phone": "+70410425685"}
0005434066341	30AB74	9879 940478	SVETLANA NIKITINA	{"phone": "+70585188082"}
0005434066342	24C3B8	2199 854461	VIKTOR ZAKHAROV	{"phone": "+70805894618"}
0005434066343	C1AF5D	3394 066009	OLGA PETROVA	{"email": "o.petrova1978@postgrespro.ru", "phone": "+70229017093"}
0005434066344	FE343F	5318 885333	SERGEY KISELEV	{"email": "s_kiselev-081980@postgrespro.ru", "phone": "+70032388782"}
0005434066345	DFD027	0444 286775	GALINA LUKYANOVA	{"phone": "+70948673493"}
0005434066346	DFD027	8235 798188	GALINA KUZNECOVA	{"phone": "+70583658255"}
0005434066347	D5B654	2783 524748	NATALYA ROMANOVA	{"email": "romanova_n.1983@postgrespro.ru", "phone": "+70971503282"}
0005434066348	512A64	7264 709557	STEPAN STEPANOV	{"phone": "+70404881115"}
0005434066349	DCC287	4190 179289	EKATERINA BELYAEVA	{"phone": "+70895696266"}
0005434066350	C28019	2441 398403	ANATOLIY SMIRNOV	{"email": "smirnov_a.041977@postgrespro.ru", "phone": "+70149762161"}
0005434066351	C28019	9552 685999	OLGA STEPANOVA	{"email": "stepanova_o15091980@postgrespro.ru", "phone": "+70195332854"}
0005434066352	6C2F75	0648 647820	DMITRIY BORISOV	{"phone": "+70948423406"}
0005434066353	23973D	0961 765394	ZINAIDA RODIONOVA	{"email": "zrodionova_1964@postgrespro.ru", "phone": "+70102264098"}
0005434066354	2285F1	7942 772545	NADEZHDA ISAEVA	{"email": "n-isaeva-17081975@postgrespro.ru", "phone": "+70803599252"}
0005434066355	D472F4	4994 830352	LYUDMILA ISAEVA	{"phone": "+70736436711"}
0005434066356	D472F4	4096 122533	ASIYA KOVALEVA	{"email": "kovaleva_asiya-121965@postgrespro.ru", "phone": "+70897074667"}
0005434066357	D2CB8C	5725 268781	ALEKSANDRA FILIPPOVA	{"phone": "+70786661466"}
0005434066358	D2CB8C	2931 391230	OLEG ZAKHAROV	{"phone": "+70262632012"}
0005434066359	686773	3352 655747	SERGEY OSIPOV	{"phone": "+70145132966"}
0005434066360	686773	8040 504034	SOFIYA KUZNECOVA	{"phone": "+70502695008"}
0005434066361	62E4BE	6919 885677	VLADIMIR MOROZOV	{"phone": "+70050605036"}
0005434066362	9FC93D	3118 290197	VIKTOR TARASOV	{"email": "viktor-tarasov_1972@postgrespro.ru", "phone": "+70836172995"}
0005434066363	1DA3F2	6223 719777	SERGEY VASILEV	{"phone": "+70024954192"}
0005434066364	A186C8	7407 220814	ALENA RODIONOVA	{"email": "alena.rodionova_1979@postgrespro.ru", "phone": "+70839556515"}
0005434066365	4C8E9B	2483 955828	DMITRIY KOZLOV	{"email": "kozlov-dmitriy.19081974@postgrespro.ru", "phone": "+70341583273"}
0005434066366	D8491A	5559 302987	MAKSIM FILIPPOV	{"phone": "+70500978499"}
0005434066367	64C0D6	6257 052548	IGOR IVANOV	{"phone": "+70262054707"}
0005434066368	A96142	1151 182224	SERGEY DMITRIEV	{"phone": "+70483260381"}
0005434066369	A96142	7459 786205	ARTUR STEPANOV	{"email": "artur.stepanov-1973@postgrespro.ru", "phone": "+70235775080"}
0005434066370	43CF77	6492 459298	ELENA SAVELEVA	{"email": "saveleva.elena.10081971@postgrespro.ru", "phone": "+70956731754"}
0005434066371	43CF77	3242 811679	ALLA SMIRNOVA	{"phone": "+70063254425"}
0005434066372	43CF77	3368 579439	YURIY SOLOVEV	{"email": "yuriysolovev1978@postgrespro.ru", "phone": "+70187363254"}
0005434066373	88691D	2195 478994	ANDREY ALEKSEEV	{"phone": "+70067856772"}
0005434066374	DFEBBA	9684 411018	LIDIYA ANTONOVA	{"email": "antonova-lidiya_1970@postgrespro.ru", "phone": "+70363043738"}
0005434066375	DFEBBA	9935 689743	ANDREY OSIPOV	{"email": "osipova_1974@postgrespro.ru", "phone": "+70145194836"}
0005434066376	DFEBBA	4886 630016	TATYANA NESTEROVA	{"phone": "+70663308987"}
0005434066377	7423C8	2169 701463	ALEKSANDR FROLOV	{"email": "aleksandr-frolov-071976@postgrespro.ru", "phone": "+70296901483"}
0005434066378	5734FB	9424 184703	LIDIYA IVANOVA	{"email": "ivanova_lidiya.29031967@postgrespro.ru", "phone": "+70004788365"}
0005434066379	5734FB	1179 532631	VLADIMIR YAKOVLEV	{"phone": "+70310637860"}
0005434066380	648A33	2335 944691	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_051969@postgrespro.ru", "phone": "+70960685332"}
0005434066381	17A01E	6665 960809	MARINA NESTEROVA	{"email": "nesterovam10061982@postgrespro.ru", "phone": "+70377878101"}
0005434066382	B6B5A2	0092 092230	RUSLAN TARASOV	{"email": "tarasovruslan-22051976@postgrespro.ru", "phone": "+70910404388"}
0005434066383	795113	9140 957935	LYUDMILA FILATOVA	{"email": "lyudmila-filatova_07061977@postgrespro.ru", "phone": "+70299242661"}
0005434066384	159F8E	4404 295061	MIKHAIL DMITRIEV	{"phone": "+70283500091"}
0005434066385	A8045B	0676 205849	ELENA ZHUKOVA	{"phone": "+70093697036"}
0005434066386	A8045B	1709 366876	VALENTINA MOROZOVA	{"phone": "+70005377884"}
0005434066387	BF42F5	8473 441408	SERGEY NOVIKOV	{"email": "sergeynovikov_1969@postgrespro.ru", "phone": "+70992981042"}
0005434066388	BF42F5	5186 912234	ANDREY ANTONOV	{"email": "antonov-andrey06071967@postgrespro.ru", "phone": "+70454108497"}
0005434066389	BD22BE	0470 945867	EVGENIY NIKOLAEV	{"email": "enikolaev-051973@postgrespro.ru", "phone": "+70095412288"}
0005434066390	435D1F	3035 121406	LYUBOV MAKAROVA	{"email": "lyubovmakarova031983@postgrespro.ru", "phone": "+70608104079"}
0005434066391	AF8FBF	0966 504968	MIKHAIL NOVIKOV	{"email": "m_novikov-1971@postgrespro.ru", "phone": "+70455597278"}
0005434066392	72B278	2759 103957	VIKTOR MELNIKOV	{"email": "viktor_melnikov_29031978@postgrespro.ru", "phone": "+70801016773"}
0005434066393	72B278	0969 075552	OKSANA SOROKINA	{"email": "sorokina-oksana.30011970@postgrespro.ru", "phone": "+70563330786"}
0005434066394	E648B0	1448 617186	LIDIYA IVANOVA	{"phone": "+70989427577"}
0005434066395	9ED911	7463 860765	SVETLANA NESTEROVA	{"phone": "+70522957756"}
0005434066396	BEC825	6475 469134	LARISA KULIKOVA	{"email": "larisa.kulikova.021965@postgrespro.ru", "phone": "+70979430672"}
0005434066397	D45880	1076 000890	ALENA KUZNECOVA	{"email": "kuznecova-alena.24121967@postgrespro.ru", "phone": "+70707226990"}
0005434066398	C6992E	0245 714350	VIKTOR ALEKSANDROV	{"email": "aleksandrov_v_061969@postgrespro.ru", "phone": "+70064869878"}
0005434066399	349FF5	6832 961155	NIKOLAY SMIRNOV	{"email": "n-smirnov-05101973@postgrespro.ru", "phone": "+70537851910"}
0005434066400	340A5A	2385 115528	NATALYA MASLOVA	{"email": "n-maslova-031971@postgrespro.ru", "phone": "+70047507061"}
0005434066401	427C8C	8562 795335	ALEKSANDR PETROV	{"email": "petrovaleksandr041978@postgrespro.ru", "phone": "+70726795905"}
0005434066402	34E456	1909 177201	DANILA DENISOV	{"phone": "+70931315967"}
0005434066403	34E456	9755 978647	ALEKSANDR FEDOROV	{"email": "a_fedorov08031969@postgrespro.ru", "phone": "+70033137789"}
0005434066404	3354E1	2503 122868	YULIYA SOKOLOVA	{"phone": "+70241300692"}
0005434066405	261E32	3054 369990	ELENA SOLOVEVA	{"phone": "+70595403142"}
0005434066406	6608F4	0911 153720	ALEKSANDR TARASOV	{"phone": "+70167667116"}
0005434066407	6608F4	5386 615237	ALEKSANDR OSIPOV	{"phone": "+70362284961"}
0005434066408	9345A6	7278 957105	ZOYA MARTYNOVA	{"email": "zoyamartynova011970@postgrespro.ru", "phone": "+70656995400"}
0005434066409	E846ED	4745 794192	ALEKSANDR DENISOV	{"phone": "+70035460008"}
0005434066410	22C0BA	0801 525070	IVAN KOZLOV	{"phone": "+70111773335"}
0005434066411	5E75F3	0114 527663	ALEKSANDR VLASOV	{"phone": "+70052636008"}
0005434066412	5E75F3	8921 585737	IGOR TIKHONOV	{"phone": "+70113596031"}
0005434066413	1CAF55	0680 167328	EVGENIYA MAKAROVA	{"email": "evgeniya-makarova.27101978@postgrespro.ru", "phone": "+70082973736"}
0005434066414	961EFD	2995 751302	KONSTANTIN POPOV	{"email": "popov-k031963@postgrespro.ru", "phone": "+70079297805"}
0005434066415	961EFD	4449 875830	GRIGORIY MEDVEDEV	{"phone": "+70801687629"}
0005434066416	AE7E4E	9358 896055	VASILIY NOVIKOV	{"email": "novikov_vasiliy_101972@postgrespro.ru", "phone": "+70203997460"}
0005434066417	981E6D	2896 955009	OLEG ILIN	{"email": "o_ilin_101962@postgrespro.ru", "phone": "+70031132398"}
0005434066418	CB9A76	8161 354988	YURIY ANTONOV	{"phone": "+70416726706"}
0005434066419	CB9A76	1320 861376	SERGEY TIKHONOV	{"email": "stikhonov.1977@postgrespro.ru", "phone": "+70275640940"}
0005434066420	53877B	2184 119544	ANDREY KARPOV	{"email": "karpovandrey081980@postgrespro.ru", "phone": "+70252800045"}
0005434066421	84A4C3	2101 567451	ANNA MIKHAYLOVA	{"phone": "+70438085667"}
0005434066422	62818C	9622 040585	KONSTANTIN KOZLOV	{"phone": "+70423571829"}
0005434066423	481FDF	3350 848200	TATYANA MAKAROVA	{"email": "t-makarova_11071969@postgrespro.ru", "phone": "+70953918907"}
0005434066424	E4F604	2620 746421	ANATOLIY BONDARENKO	{"email": "bondarenko_a_041962@postgrespro.ru", "phone": "+70979687246"}
0005434066425	63AF62	1343 208017	KONSTANTIN NIKOLAEV	{"phone": "+70870995416"}
0005434066426	71F54E	1499 208721	MIKHAIL MEDVEDEV	{"phone": "+70261691095"}
0005434066427	ECA513	6343 362362	EVGENIY KUZNECOV	{"phone": "+70921526493"}
0005434066428	864717	3360 360323	LYUBOV ZHURAVLEVA	{"email": "lyubov-zhuravleva06101968@postgrespro.ru", "phone": "+70222355937"}
0005434066429	F171E1	8253 593480	ALLA MIKHAYLOVA	{"email": "mikhaylovaalla1974@postgrespro.ru", "phone": "+70053667594"}
0005434066430	CFC0CE	3575 549416	ARTEM BONDARENKO	{"email": "bondarenko.a.17011975@postgrespro.ru", "phone": "+70214715774"}
0005434066431	52CFE8	0067 914518	ANNA MIKHAYLOVA	{"email": "mikhaylova_a1979@postgrespro.ru", "phone": "+70085728113"}
0005434066432	65E292	3144 271165	ALEKSANDR SEMENOV	{"phone": "+70432899415"}
0005434066433	0205B2	2668 789050	ALEKSEY RODIONOV	{"email": "aleksey.rodionov-031979@postgrespro.ru", "phone": "+70885998877"}
0005434066434	0205B2	4404 309658	SERGEY TIKHONOV	{"phone": "+70161490996"}
0005434066435	A07B9C	1234 344406	IRINA SOLOVEVA	{"email": "irina_soloveva_1973@postgrespro.ru", "phone": "+70747704738"}
0005434066436	A07B9C	9025 926374	NADEZHDA DMITRIEVA	{"phone": "+70615980617"}
0005434066437	F912C6	7643 537351	ANNA MIKHAYLOVA	{"phone": "+70193115764"}
0005434066438	4081D3	1273 474066	MARINA OVCHINNIKOVA	{"email": "ovchinnikova_marina-121976@postgrespro.ru", "phone": "+70864705851"}
0005434066439	4081D3	2300 679069	SERGEY KUZMIN	{"phone": "+70033095417"}
0005434066440	09CF01	4585 260907	ELENA POLYAKOVA	{"email": "e-polyakova-011959@postgrespro.ru", "phone": "+70182330213"}
0005434066441	09CF01	3812 056609	ALEKSANDR SIDOROV	{"phone": "+70365741311"}
0005434066442	09CF01	7188 855050	RAISA EGOROVA	{"phone": "+70732331096"}
0005434066443	75E24C	2134 697729	RUSTAM VOROBEV	{"phone": "+70066259047"}
0005434066444	75E24C	5382 078381	LARISA KUZNECOVA	{"email": "larisakuznecova09071974@postgrespro.ru", "phone": "+70695923534"}
0005434066445	142976	3451 296899	EKATERINA KALININA	{"phone": "+70614345172"}
0005434066446	FFC513	0924 417991	NATALYA ARKHIPOVA	{"phone": "+70244760096"}
0005434066447	D9500F	9626 877620	MARIYA LAZAREVA	{"phone": "+70947453365"}
0005434066448	55432D	0333 045056	ANASTASIYA MOROZOVA	{"phone": "+70557403092"}
0005434066449	3C1020	8162 306123	NINA KULIKOVA	{"email": "nina_kulikova1972@postgrespro.ru", "phone": "+70605559782"}
0005434066450	3C1020	1333 184484	KRISTINA KOMAROVA	{"email": "k-komarova03081980@postgrespro.ru", "phone": "+70065034571"}
0005434066451	2FA738	0080 934783	OLEG MOROZOV	{"phone": "+70321601336"}
0005434066452	3F238E	2347 316787	POLINA AKIMOVA	{"email": "p-akimova_18091976@postgrespro.ru", "phone": "+70305672013"}
0005434066453	3F238E	3393 292059	LYUBOV SOLOVEVA	{"email": "soloveva_lyubov30071972@postgrespro.ru", "phone": "+70522889727"}
0005434066454	90CBF2	3722 020983	BORIS PAVLOV	{"email": "pavlov-boris_041975@postgrespro.ru", "phone": "+70784050473"}
0005434066455	90CBF2	5329 632087	ALEKSANDR VOROBEV	{"phone": "+70992541705"}
0005434066456	368AC5	4105 806538	SVETLANA MATVEEVA	{"phone": "+70003875605"}
0005434066457	368AC5	9901 350057	ANNA NESTEROVA	{"phone": "+70957094014"}
0005434066458	65B41A	1908 690259	YAROSLAV KUZNECOV	{"email": "kuznecov_y-1984@postgrespro.ru", "phone": "+70150666322"}
0005434066459	DCDC8A	8181 289848	SERGEY FROLOV	{"email": "sergey-frolov_051970@postgrespro.ru", "phone": "+70096594015"}
0005434066460	DCDC8A	8715 176587	LYUDMILA NESTEROVA	{"phone": "+70477434494"}
0005434066461	C75BDE	5774 533289	OKSANA MOROZOVA	{"phone": "+70891642093"}
0005434066462	0303DD	3347 386853	MIKHAIL TIKHONOV	{"phone": "+70793399081"}
0005434066463	E5920B	2986 524420	SOFYA SIDOROVA	{"phone": "+70655677613"}
0005434066464	997E68	6405 355855	MARIYA OSIPOVA	{"email": "m.osipova-1979@postgrespro.ru", "phone": "+70774836132"}
0005434066465	6CA818	8196 186791	SERGEY ANDREEV	{"email": "sergey.andreev_111975@postgrespro.ru", "phone": "+70632853397"}
0005434066466	69C4DB	3106 104180	VLADISLAV KUZNECOV	{"email": "v.kuznecov-1973@postgrespro.ru", "phone": "+70088130259"}
0005434066467	A0A1AC	3954 789254	MILANA POTAPOVA	{"phone": "+70966644450"}
0005434066468	718742	4848 954367	NATALYA MATVEEVA	{"phone": "+70354922623"}
0005434066469	467EA0	6183 352620	VALENTINA NAUMOVA	{"email": "valentinanaumova19021974@postgrespro.ru", "phone": "+70196537615"}
0005434066470	9AE419	9824 641888	YULIYA SEMENOVA	{"email": "ysemenova_1972@postgrespro.ru", "phone": "+70307189432"}
0005434066471	0840B5	6195 752736	PETR IVANOV	{"email": "petr_ivanov.011976@postgrespro.ru", "phone": "+70133404904"}
0005434066472	C7D2EC	1772 411618	ALEKSEY BELOV	{"email": "a-belov_071978@postgrespro.ru", "phone": "+70429983570"}
0005434066473	C928CF	8621 278955	ANDREY SIDOROV	{"phone": "+70657028328"}
0005434066474	797110	6381 245485	RUFINA MELNIKOVA	{"phone": "+70622442551"}
0005434066475	05505B	6658 266999	MARIYA IVANOVA	{"email": "ivanova-mariya031974@postgrespro.ru", "phone": "+70782088701"}
0005434066476	08351F	1530 226163	VALERIY ZAYCEV	{"phone": "+70989463066"}
0005434066477	E23232	6754 920623	EDUARD RODIONOV	{"email": "rodionov.eduard.071974@postgrespro.ru", "phone": "+70951593804"}
0005434066478	7D4C3C	0761 136254	MARIYA ROMANOVA	{"phone": "+70605820529"}
0005434066479	23CFCC	7609 053101	DMITRIY KUZMIN	{"email": "d_kuzmin_1970@postgrespro.ru", "phone": "+70952876815"}
0005434066480	5EBEFA	0552 405693	YULIYA ALEKSANDROVA	{"phone": "+70315570787"}
0005434066481	5EBEFA	4366 098388	SERGEY MEDVEDEV	{"phone": "+70308487546"}
0005434066482	7DBE14	8337 148341	SERGEY RODIONOV	{"email": "s-rodionov.01081984@postgrespro.ru", "phone": "+70988055851"}
0005434066483	7DBE14	4648 734782	EDUARD BELOV	{"phone": "+70998223494"}
0005434066484	BB4863	1935 696301	ALFIYA LUKYANOVA	{"email": "lukyanovaalfiya_06091969@postgrespro.ru", "phone": "+70951731743"}
0005434066485	4895E9	3593 827187	VYACHESLAV KRASNOV	{"email": "krasnov_vyacheslav1968@postgrespro.ru", "phone": "+70993125168"}
0005434066486	C3A9DD	1120 930477	MAKSIM KUZNECOV	{"phone": "+70733061414"}
0005434066487	C3A9DD	8682 252003	ANNA CHERNOVA	{"email": "chernova-a1968@postgrespro.ru", "phone": "+70942421832"}
0005434066488	C61722	9812 531264	MIKHAIL FROLOV	{"email": "frolovmikhail08031978@postgrespro.ru", "phone": "+70590339427"}
0005434066489	185DFA	7306 289248	PAVEL SOKOLOV	{"email": "sokolov.pavel_1971@postgrespro.ru", "phone": "+70422330156"}
0005434066490	C265F7	3984 417243	GENNADIY MIRONOV	{"email": "mironovg18081968@postgrespro.ru", "phone": "+70438154886"}
0005434066491	CC05C5	3266 187626	NIKOLAY ORLOV	{"phone": "+70450732558"}
0005434066492	B2BC1F	1255 675814	ALEKSANDR GERASIMOV	{"phone": "+70864287492"}
0005434066493	B2BC1F	2336 804135	ELENA NAZAROVA	{"phone": "+70810579718"}
0005434066494	2AE83C	8412 696014	OLGA SERGEEVA	{"phone": "+70331501728"}
0005434066495	2AE83C	8159 184099	VERA AFANASEVA	{"email": "afanasevav.1967@postgrespro.ru", "phone": "+70079503662"}
0005434066496	7C2C7A	2447 025340	GALINA GORBUNOVA	{"email": "galinagorbunova-10061962@postgrespro.ru", "phone": "+70379041681"}
0005434066497	5525F4	4753 209257	OLGA NAZAROVA	{"email": "nazarovaolga1966@postgrespro.ru", "phone": "+70399309762"}
0005434066498	5525F4	4283 213720	SVETLANA KALININA	{"phone": "+70349465201"}
0005434066499	532100	5419 132098	ADELINA NAUMOVA	{"email": "adelina-naumova1970@postgrespro.ru", "phone": "+70205365666"}
0005434066500	585235	7041 530936	VLADIMIR IVANOV	{"email": "ivanov_v25111968@postgrespro.ru", "phone": "+70491223011"}
0005434066501	1ADC2E	2065 304408	ALEKSANDR KARPOV	{"phone": "+70294546514"}
0005434066502	1ADC2E	4299 920891	EVGENIY VOROBEV	{"phone": "+70213796097"}
0005434066503	9062A2	9086 454960	KLAVDIYA KUZNECOVA	{"phone": "+70777801000"}
0005434066504	9062A2	5865 465293	ANASTASIYA KOVALEVA	{"email": "akovaleva05121984@postgrespro.ru", "phone": "+70257013034"}
0005434066505	037817	0822 219214	ANTONINA MATVEEVA	{"email": "matveeva_a.05081966@postgrespro.ru", "phone": "+70431638172"}
0005434066506	639F0B	2670 357566	SERGEY MELNIKOV	{"email": "melnikov_sergey_021981@postgrespro.ru", "phone": "+70438412483"}
0005434066507	758E06	3633 052158	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa.1972@postgrespro.ru", "phone": "+70970339663"}
0005434066508	718717	3774 644960	ALEKSEY MARTYNOV	{"email": "aleksey-martynov-021966@postgrespro.ru", "phone": "+70589573275"}
0005434066509	718717	1420 014762	ANASTASIYA BELYAEVA	{"phone": "+70447634628"}
0005434066510	8F3C03	2481 866090	OLGA SIDOROVA	{"phone": "+70845786461"}
0005434066511	04353C	2431 519097	STANISLAV YAKOVLEV	{"email": "yakovlev.stanislav-1968@postgrespro.ru", "phone": "+70967857597"}
0005434066512	6DC992	9112 860745	IVAN SERGEEV	{"email": "sergeev_i10031963@postgrespro.ru", "phone": "+70593414988"}
0005434066513	6DC992	8015 486320	ALEKSEY MARTYNOV	{"phone": "+70246988494"}
0005434066514	A76BB4	8523 107258	EDUARD MAKSIMOV	{"email": "maksimov_eduard-1981@postgrespro.ru", "phone": "+70163515841"}
0005434066515	4C25AB	4419 660448	REGINA YAKOVLEVA	{"email": "regina-yakovleva_061984@postgrespro.ru", "phone": "+70849580204"}
0005434066516	4C25AB	5641 727689	DMITRIY KISELEV	{"phone": "+70877672540"}
0005434066517	F8D842	2835 412078	MIKHAIL CHERNOV	{"phone": "+70147405897"}
0005434066518	2E3D33	8200 814548	ARTEM POPOV	{"email": "popov_artem1970@postgrespro.ru", "phone": "+70427024654"}
0005434066519	2E3D33	6699 021119	IRINA DANILOVA	{"phone": "+70532383213"}
0005434066520	4F4091	3519 964040	ILYA ZHUKOV	{"email": "ilyazhukov_1970@postgrespro.ru", "phone": "+70049284416"}
0005434066521	20CE33	3140 834265	DMITRIY DENISOV	{"phone": "+70443953216"}
0005434066522	20CE33	6994 465761	RAISA GUSEVA	{"email": "raisa-guseva.25051975@postgrespro.ru", "phone": "+70676118291"}
0005434066523	20CE33	3485 036838	DARYA KARPOVA	{"email": "karpova-darya21031970@postgrespro.ru", "phone": "+70258458762"}
0005434066524	2FB390	4414 782913	NIKITA ZAKHAROV	{"email": "n_zakharov-13101966@postgrespro.ru", "phone": "+70088748360"}
0005434066525	C072D6	1622 539531	ANDREY KULIKOV	{"phone": "+70198485047"}
0005434066526	C072D6	0479 369872	NINA KAZAKOVA	{"email": "kazakova.nina021973@postgrespro.ru", "phone": "+70683737727"}
0005434066527	790D18	5976 535843	NIKOLAY ALEKSEEV	{"email": "alekseev-nikolay-091972@postgrespro.ru", "phone": "+70579754549"}
0005434066528	E8C165	5345 056396	NIKOLAY KOROLEV	{"email": "n-korolev-1973@postgrespro.ru", "phone": "+70003495631"}
0005434066529	E8C165	9679 950050	VITALIY IVANOV	{"email": "ivanovv111957@postgrespro.ru", "phone": "+70358092998"}
0005434066530	7FF582	9260 165785	MARINA IVANOVA	{"email": "marina-ivanova_11101977@postgrespro.ru", "phone": "+70994382119"}
0005434066531	7FF582	7954 100870	TATYANA ZAKHAROVA	{"email": "t_zakharova.1970@postgrespro.ru", "phone": "+70160362596"}
0005434066532	03F18A	4073 293035	VITALIY VOROBEV	{"email": "vorobev-v-11051979@postgrespro.ru", "phone": "+70291557374"}
0005434066533	03F18A	2331 786374	LILIYA KOVALEVA	{"phone": "+70419194588"}
0005434066534	F3D773	8432 944093	LYUDMILA KRASNOVA	{"email": "lyudmila.krasnova101979@postgrespro.ru", "phone": "+70657112740"}
0005434066535	F64DF7	3865 602468	TATYANA TIMOFEEVA	{"email": "t.timofeeva21021978@postgrespro.ru", "phone": "+70818837584"}
0005434066536	F64DF7	8008 329067	IVAN MAKAROV	{"email": "makarovi_15051966@postgrespro.ru", "phone": "+70282731532"}
0005434066537	007A53	6300 313875	PETR NIKOLAEV	{"email": "petr_nikolaev-1990@postgrespro.ru", "phone": "+70929654018"}
0005434066538	007A53	9814 382234	SERGEY MOROZOV	{"email": "morozov_s1971@postgrespro.ru", "phone": "+70581303927"}
0005434066539	B0046C	6559 865554	SVETLANA ROMANOVA	{"phone": "+70236169992"}
0005434066540	4706FC	6045 620767	RUSLAN SEMENOV	{"email": "ruslan_semenov_03051968@postgrespro.ru", "phone": "+70918426394"}
0005434066541	29A04F	9626 710259	TAMARA ISAEVA	{"email": "isaeva.tamara.071969@postgrespro.ru", "phone": "+70017680617"}
0005434066542	5929F9	3864 494094	OLGA ANDREEVA	{"email": "andreeva.o.28051962@postgrespro.ru", "phone": "+70074343333"}
0005434066543	5929F9	5359 245529	ELENA KUZNECOVA	{"email": "kuznecova.elena.051978@postgrespro.ru", "phone": "+70879226102"}
0005434066544	1D2113	1199 425779	RENATA RODIONOVA	{"email": "renata-rodionova30121976@postgrespro.ru", "phone": "+70706755125"}
0005434066545	892766	9150 114288	EGOR POPOV	{"email": "egorpopov121974@postgrespro.ru", "phone": "+70959543332"}
0005434066546	01BD88	1046 266175	RUSLAN YAKOVLEV	{"email": "yakovlev_r.091971@postgrespro.ru", "phone": "+70148184036"}
0005434066547	01BD88	8698 659126	ALEKSANDR POPOV	{"phone": "+70749100019"}
0005434066548	1C6120	2177 700315	YURIY RODIONOV	{"email": "rodionov_yuriy-02121971@postgrespro.ru", "phone": "+70273712547"}
0005434066549	108F1D	9353 370309	RAMIL IVANOV	{"phone": "+70458876566"}
0005434066550	108F1D	3044 575535	OLGA IVANOVA	{"email": "ivanova_o1978@postgrespro.ru", "phone": "+70723915753"}
0005434066551	0B0C24	8871 744602	ANNA KUZNECOVA	{"email": "kuznecova_anna101967@postgrespro.ru", "phone": "+70088576192"}
0005434066552	0B0C24	0202 777368	VLADIMIR NAZAROV	{"phone": "+70910866250"}
0005434066553	8989C4	3030 727609	ANASTASIYA ANDREEVA	{"email": "andreeva-anastasiya031973@postgrespro.ru", "phone": "+70787658966"}
0005434066554	F75772	0000 464969	LYUBOV MEDVEDEVA	{"phone": "+70941760045"}
0005434066555	35D820	1683 662078	NINA TIMOFEEVA	{"phone": "+70543319433"}
0005434066556	9191FC	7889 961251	ARTEM MATVEEV	{"email": "matveev.a_1969@postgrespro.ru", "phone": "+70363982515"}
0005434066557	9191FC	3530 302797	MARIYA IVANOVA	{"email": "ivanova_m_10071993@postgrespro.ru", "phone": "+70250529908"}
0005434066558	7A8DC9	2470 914979	VALENTIN VASILEV	{"phone": "+70124717456"}
0005434066559	19D0EE	2662 614369	FAINA SMIRNOVA	{"email": "f.smirnova1966@postgrespro.ru", "phone": "+70316434189"}
0005434066560	66BD47	3904 474907	IRINA VOLKOVA	{"email": "irina_volkova-17071967@postgrespro.ru", "phone": "+70522684057"}
0005434066561	66BD47	8764 727855	YURIY GRIGOREV	{"email": "yuriy_grigorev-1970@postgrespro.ru", "phone": "+70467859188"}
0005434066562	3A3D89	1962 836018	YURIY KUZNECOV	{"phone": "+70449891783"}
0005434066563	10FF3B	7591 286314	ANASTASIYA MELNIKOVA	{"phone": "+70587006397"}
0005434066564	C76779	0787 684519	MIKHAIL FROLOV	{"email": "frolovm1984@postgrespro.ru", "phone": "+70420085564"}
0005434066565	C76779	6438 501502	ZULFIYA ARKHIPOVA	{"email": "z_arkhipova.061970@postgrespro.ru", "phone": "+70805931036"}
0005434066566	FDBDF0	6073 699358	NIKITA NIKITIN	{"phone": "+70626388521"}
0005434066567	FDBDF0	7759 125373	ANATOLIY KOZLOV	{"email": "anatoliy-kozlov-25051969@postgrespro.ru", "phone": "+70743588643"}
0005434066568	225F1E	2446 722473	IRINA BELYAEVA	{"phone": "+70738933384"}
0005434066569	993529	1354 064508	EVDOKIYA FROLOVA	{"email": "frolova_e07011983@postgrespro.ru", "phone": "+70280009452"}
0005434066570	E62382	8845 665867	LARISA BARANOVA	{"email": "larisa_baranova.15071972@postgrespro.ru", "phone": "+70573260185"}
0005434066571	F9E291	5178 434178	ALEKSANDR NAZAROV	{"phone": "+70680732326"}
0005434066572	1833B5	3267 524954	ANZHELA ANISIMOVA	{"email": "a.anisimova-091979@postgrespro.ru", "phone": "+70321998195"}
0005434066573	A6BA04	7838 378783	MARGARITA ALEKSEEVA	{"phone": "+70693100947"}
0005434066574	A6BA04	8066 340988	VALENTINA ANTONOVA	{"phone": "+70881133186"}
0005434066575	C33AD6	5995 783601	KLAVDIYA MAKAROVA	{"phone": "+70595662969"}
0005434066576	65B078	9018 485464	ELENA ZAYCEVA	{"email": "zayceva_elena.1971@postgrespro.ru", "phone": "+70739891839"}
0005434066577	65B078	5760 792555	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda_1975@postgrespro.ru", "phone": "+70223296919"}
0005434066578	AFCF22	6651 548357	LARISA NIKITINA	{"phone": "+70649546535"}
0005434066579	93E8C3	1015 243481	NINA OSIPOVA	{"email": "nina.osipova_06041965@postgrespro.ru", "phone": "+70268893238"}
0005434066580	D1EF3C	3372 821025	LYUBOV POTAPOVA	{"email": "potapova_l081969@postgrespro.ru", "phone": "+70144167984"}
0005434066581	D1EF3C	4489 857568	ANASTASIYA MELNIKOVA	{"phone": "+70756845514"}
0005434066582	D1EF3C	0315 317385	YURIY STEPANOV	{"phone": "+70920909036"}
0005434066583	4DD58F	7696 533695	YURIY GORBUNOV	{"email": "ygorbunov1972@postgrespro.ru", "phone": "+70927737953"}
0005434066584	CDD656	4103 265290	PAVEL BONDARENKO	{"phone": "+70518499577"}
0005434066585	4CE34C	9718 714296	SOFYA TARASOVA	{"email": "sofya.tarasova071977@postgrespro.ru", "phone": "+70852358344"}
0005434066586	2CEF3F	2086 149132	VASILIY KUZNECOV	{"email": "vasiliykuznecov-1965@postgrespro.ru", "phone": "+70551105685"}
0005434066587	2CEF3F	7184 475790	AMINA ALEKSEEVA	{"email": "alekseeva_amina-011974@postgrespro.ru", "phone": "+70265720438"}
0005434066588	D18797	7487 365220	NADEZHDA PETROVA	{"phone": "+70230779143"}
0005434066589	D18797	8804 751774	YURIY NOVIKOV	{"phone": "+70428473573"}
0005434066590	A068A7	3006 541244	VIKTORIYA MIRONOVA	{"email": "viktoriya-mironova_111974@postgrespro.ru", "phone": "+70153212876"}
0005434066591	A068A7	0068 610894	ALEKSANDRA SEMENOVA	{"phone": "+70065712303"}
0005434066592	902CE7	8109 199591	MIKHAIL EGOROV	{"phone": "+70769222581"}
0005434066593	A98D2E	7554 742713	MARIYA MAKAROVA	{"phone": "+70134532648"}
0005434066594	829DC7	1062 881846	NADEZHDA BELOVA	{"phone": "+70875120764"}
0005434066595	829DC7	0412 920615	ALEKSANDR VASILEV	{"phone": "+70797663351"}
0005434066596	829DC7	2457 778348	PAVEL SOROKIN	{"email": "pavel_sorokin.041965@postgrespro.ru", "phone": "+70130435414"}
0005434066597	BCD733	3919 918054	ROMAN KULIKOV	{"email": "kulikov_roman.1966@postgrespro.ru", "phone": "+70043482484"}
0005434066598	BCD733	0004 749978	OLGA KUZNECOVA	{"phone": "+70509518132"}
0005434066599	C786BF	4569 931781	NIKOLAY KRASNOV	{"email": "krasnov_n.071973@postgrespro.ru", "phone": "+70317172750"}
0005434066600	4151B6	5380 301655	OKSANA ZAYCEVA	{"phone": "+70307438188"}
0005434066602	3615F1	8584 592495	ELENA FILIPPOVA	{"email": "e.filippova-14031965@postgrespro.ru", "phone": "+70984863920"}
0005434066603	3615F1	8878 062116	NAIL CHERNOV	{"email": "nail-chernov031967@postgrespro.ru", "phone": "+70302688906"}
0005434066604	275B7B	0647 940621	YULIYA OSIPOVA	{"email": "osipova-y021973@postgrespro.ru", "phone": "+70832456051"}
0005434066605	63A137	1507 673118	LIDIYA BELYAEVA	{"email": "belyaeva-l-01121966@postgrespro.ru", "phone": "+70542055424"}
0005434066606	36BDE6	4720 397723	NIKOLAY GRIGOREV	{"phone": "+70334709320"}
0005434066607	A13627	0400 788614	ELENA ALEKSANDROVA	{"phone": "+70507457057"}
0005434066608	AF31C6	4618 353948	NADEZHDA SIDOROVA	{"phone": "+70983100285"}
0005434066609	9E767A	9452 130185	ANNA DENISOVA	{"phone": "+70719995866"}
0005434066610	A89BB3	6556 969049	EKATERINA VASILEVA	{"email": "vasileva_ekaterina-10101971@postgrespro.ru", "phone": "+70905383432"}
0005434066611	B698EF	0471 676055	VLADIMIR RODIONOV	{"phone": "+70547883510"}
0005434066612	B698EF	3120 935845	LYUDMILA OVCHINNIKOVA	{"phone": "+70985510015"}
0005434066613	543E5A	6551 435341	ALEKSANDR DMITRIEV	{"phone": "+70885267351"}
0005434066614	E97C5B	8700 610725	VITALIY ROMANOV	{"email": "romanov.v_021969@postgrespro.ru", "phone": "+70572716775"}
0005434066615	E97C5B	3357 717839	ALEKSANDR POPOV	{"email": "popov.aleksandr081975@postgrespro.ru", "phone": "+70179369523"}
0005434066616	1D9A8E	3327 025784	NIKOLAY SCHERBAKOV	{"email": "nikolay_scherbakov-071974@postgrespro.ru", "phone": "+70152406006"}
0005434066617	EC33B3	9295 859736	STEPAN IVANOV	{"phone": "+70522316268"}
0005434066618	1DEE33	6541 864249	ANDREY IVANOV	{"phone": "+70801539035"}
0005434066619	BA0334	3808 671675	VALENTINA TROFIMOVA	{"phone": "+70011099499"}
0005434066620	BA0334	6777 780088	ANATOLIY PAVLOV	{"phone": "+70833332008"}
0005434066621	4A4FBC	0648 014964	OKSANA PETROVA	{"email": "petrova_o.1976@postgrespro.ru", "phone": "+70360446169"}
0005434066622	4A4FBC	6907 908604	YURIY DMITRIEV	{"email": "yuriy_dmitriev121958@postgrespro.ru", "phone": "+70308987478"}
0005434066623	DE8511	7396 823462	PETR KUZMIN	{"phone": "+70755147799"}
0005434066624	DE8511	6328 860827	VALENTINA PETROVA	{"phone": "+70098612402"}
0005434066625	6F7F03	8182 185680	SVETLANA EFIMOVA	{"email": "efimova.svetlana_14081965@postgrespro.ru", "phone": "+70552290511"}
0005434066626	37E8F3	9652 606062	VYACHESLAV SEMENOV	{"email": "semenov_v051974@postgrespro.ru", "phone": "+70169523731"}
0005434066627	95391C	4847 629785	ANTON KONOVALOV	{"email": "konovalov_anton_091974@postgrespro.ru", "phone": "+70817146467"}
0005434066628	95391C	7023 101423	ANDREY ZAKHAROV	{"email": "zakharov-a02071974@postgrespro.ru", "phone": "+70402965180"}
0005434066629	326B2F	3843 804614	IRINA DAVYDOVA	{"email": "irina.davydova.031970@postgrespro.ru", "phone": "+70835611040"}
0005434066630	3A624B	0107 449579	SERGEY VOLKOV	{"email": "volkov-s-1969@postgrespro.ru", "phone": "+70742420947"}
0005434066631	3DD4D0	8248 269081	GALINA ALEKSANDROVA	{"phone": "+70884476362"}
0005434066632	C02311	0346 181366	IRINA PETROVA	{"email": "petrova-i.03071974@postgrespro.ru", "phone": "+70267224792"}
0005434066633	05A218	8948 837799	NATALIYA ORLOVA	{"email": "norlova091969@postgrespro.ru", "phone": "+70435598892"}
0005434066634	05A218	6352 359067	VERONIKA PETROVA	{"phone": "+70323431399"}
0005434066635	9AC252	5025 867244	RUSHANIYA VASILEVA	{"phone": "+70831560920"}
0005434066636	9AC252	8647 661136	ALEKSEY SHEVCHENKO	{"email": "shevchenko_aleksey1973@postgrespro.ru", "phone": "+70048478844"}
0005434066637	5A1940	0621 931773	DMITRIY KUZNECOV	{"phone": "+70478172661"}
0005434066638	836EA3	2086 763671	TATYANA KOLESNIKOVA	{"phone": "+70910770446"}
0005434066639	836EA3	9662 264568	ARTUR NAUMOV	{"phone": "+70646640260"}
0005434066640	836EA3	8846 042371	VALERIY POPOV	{"phone": "+70611397918"}
0005434066641	DF8B23	9483 723760	OLEG FOMIN	{"phone": "+70785513720"}
0005434066642	DF8B23	2547 800733	NIKITA MIKHAYLOV	{"email": "mikhaylov.nikita071967@postgrespro.ru", "phone": "+70838551000"}
0005434066643	74BB1E	5112 659667	ANNA BOGDANOVA	{"email": "bogdanova-anna-1976@postgrespro.ru", "phone": "+70472372003"}
0005434066644	74BB1E	9833 187046	ANTONINA POTAPOVA	{"email": "potapova_a_111985@postgrespro.ru", "phone": "+70943344885"}
0005434066645	C3E3AF	0410 360193	NATALYA VOROBEVA	{"phone": "+70343140213"}
0005434066646	4BC9AC	2234 307407	VLADIMIR MIRONOV	{"phone": "+70161603887"}
0005434066647	CD3AD1	2452 888396	IGOR DENISOV	{"email": "i-denisov041973@postgrespro.ru", "phone": "+70248538286"}
0005434066648	CD3AD1	7249 876499	SERGEY FEDOROV	{"phone": "+70015321453"}
0005434066649	F3DE0A	5994 578109	LIDIYA KOROLEVA	{"phone": "+70866500893"}
0005434066650	E73C81	0179 559933	VALERIY ORLOV	{"phone": "+70238358706"}
0005434066651	E73C81	0916 425906	ALEKSANDR KISELEV	{"email": "aleksandrkiselev_1974@postgrespro.ru", "phone": "+70096263780"}
0005434066652	BBF773	4008 901621	IRINA POLYAKOVA	{"phone": "+70184738041"}
0005434066653	727EEC	8954 923725	VIKTOR KUZMIN	{"phone": "+70367957106"}
0005434066654	0F3510	3618 078385	RAISA MAKSIMOVA	{"email": "maksimova-r.05101973@postgrespro.ru", "phone": "+70043370832"}
0005434066655	EC23DC	7423 424623	IVAN NIKITIN	{"email": "ivan_nikitin1959@postgrespro.ru", "phone": "+70739269282"}
0005434066656	871724	9839 532502	DENIS STEPANOV	{"email": "stepanov.d_1968@postgrespro.ru", "phone": "+70173021799"}
0005434066657	FF7DC8	0977 249635	MIKHAIL ISAEV	{"email": "isaev.m.081986@postgrespro.ru", "phone": "+70501920414"}
0005434066658	0F2346	2770 097664	OLGA IVANOVA	{"email": "o_ivanova-1975@postgrespro.ru", "phone": "+70110138083"}
0005434066659	53B1E7	0081 629017	MARINA NIKOLAEVA	{"phone": "+70538335363"}
0005434066660	53B1E7	6648 260645	ZAKHAR KUZNECOV	{"email": "kuznecovzakhar-061977@postgrespro.ru", "phone": "+70791441053"}
0005434066661	E041AA	8863 360327	VALENTINA KOROLEVA	{"email": "koroleva.v.1990@postgrespro.ru", "phone": "+70525566130"}
0005434066662	CB03F6	9391 643681	LYUBOV GERASIMOVA	{"phone": "+70263498972"}
0005434066663	CB03F6	4866 874379	IVAN SOKOLOV	{"phone": "+70678068951"}
0005434066664	555B9F	2049 858412	VALENTINA ANDREEVA	{"phone": "+70662433088"}
0005434066665	555B9F	7895 801507	IVAN DENISOV	{"email": "denisov.ivan021969@postgrespro.ru", "phone": "+70866978367"}
0005434066666	99EECE	9881 545892	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-mikhail.1966@postgrespro.ru", "phone": "+70442775742"}
0005434066667	99EECE	4042 842488	ANDREY NIKITIN	{"phone": "+70503791631"}
0005434066668	31D2D2	6849 858010	PETR GAVRILOV	{"email": "p_gavrilov.1971@postgrespro.ru", "phone": "+70270437954"}
0005434066669	BBE23D	1345 728218	IGOR DMITRIEV	{"phone": "+70924693871"}
0005434066670	B0D811	3523 620451	TATYANA BARANOVA	{"phone": "+70375162230"}
0005434066671	B0D811	2359 087267	SERGEY ABRAMOV	{"email": "abramov_s091963@postgrespro.ru", "phone": "+70499134855"}
0005434066672	587D6A	8604 591942	DILYARA KUZMINA	{"email": "kuzmina_dilyara_26101970@postgrespro.ru", "phone": "+70524457290"}
0005434066673	587D6A	6075 392987	MAKSIM KUZMIN	{"phone": "+70158436860"}
0005434066674	20C9E4	2024 393529	KIRILL SAVELEV	{"phone": "+70674226631"}
0005434066675	20C9E4	7335 082066	RUSTAM KULIKOV	{"email": "kulikov.rustam1984@postgrespro.ru", "phone": "+70499714687"}
0005434066676	20C9E4	8610 060064	VLADIMIR FEDOROV	{"email": "fedorov.vladimir04111971@postgrespro.ru", "phone": "+70363741119"}
0005434066677	C7D669	9296 433346	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a.13071972@postgrespro.ru", "phone": "+70699044056"}
0005434066678	8A17AC	6927 541985	MARIYA GAVRILOVA	{"phone": "+70689745217"}
0005434066679	ED3200	4042 720888	ALEKSANDR IVANOV	{"phone": "+70762795710"}
0005434066680	14DD37	3389 410786	YULIYA SCHERBAKOVA	{"email": "scherbakova-y101972@postgrespro.ru", "phone": "+70896106989"}
0005434066681	5100B0	6220 745725	VIKTOR VOLKOV	{"email": "volkov-viktor031970@postgrespro.ru", "phone": "+70743540664"}
0005434066682	5100B0	0551 973135	ERIK STEPANOV	{"phone": "+70293457941"}
0005434066683	64EC99	7287 893165	VIKTORIYA ZHURAVLEVA	{"email": "viktoriya-zhuravleva-1972@postgrespro.ru", "phone": "+70168275738"}
0005434066684	64EC99	2723 277054	ELENA NAZAROVA	{"email": "nazarova_e-1973@postgrespro.ru", "phone": "+70596835495"}
0005434066685	02CE64	7907 837081	EVGENIY IVANOV	{"email": "e.ivanov_1980@postgrespro.ru", "phone": "+70107098045"}
0005434066686	031D75	7709 954615	OLGA FADEEVA	{"email": "fadeevaolga1984@postgrespro.ru", "phone": "+70684246508"}
0005434066687	07A3B2	0768 353347	ALEKSEY MIRONOV	{"email": "a-mironov_021979@postgrespro.ru", "phone": "+70568069991"}
0005434066688	4531E3	5909 422078	SERGEY ISAEV	{"email": "s-isaev.061970@postgrespro.ru", "phone": "+70655225683"}
0005434066689	9C1551	8944 650529	NATALYA FADEEVA	{"phone": "+70573534885"}
0005434066690	ADF955	4616 395987	ZOYA KOVALEVA	{"phone": "+70837860418"}
0005434066691	ADF955	3525 974530	ANTONINA DMITRIEVA	{"phone": "+70625115610"}
0005434066692	ADF955	3104 449958	TATYANA KUZNECOVA	{"email": "t-kuznecova1973@postgrespro.ru", "phone": "+70555136046"}
0005434066693	F8152C	9315 187924	VIKTOR VOLKOV	{"phone": "+70716523516"}
0005434066694	B2F715	2138 375924	ANNA ISAEVA	{"email": "a_isaeva30011974@postgrespro.ru", "phone": "+70419902329"}
0005434066695	10C47B	0938 094066	ANGELINA EFREMOVA	{"email": "a.efremova-1970@postgrespro.ru", "phone": "+70429524276"}
0005434066696	F90A62	6937 028997	NIKOLAY MOROZOV	{"email": "nikolay_morozov1969@postgrespro.ru", "phone": "+70810586125"}
0005434066697	DE6770	2469 137183	TATYANA ORLOVA	{"email": "t_orlova-1971@postgrespro.ru", "phone": "+70043939952"}
0005434066698	DE6770	8960 260225	SERGEY ZAKHAROV	{"email": "sergey_zakharov.121979@postgrespro.ru", "phone": "+70566578280"}
0005434066699	DE6770	6413 495552	VADIM GAVRILOV	{"phone": "+70241690056"}
0005434066700	56A6A0	2073 794593	NADEZHDA EFREMOVA	{"phone": "+70937317902"}
0005434066701	68A137	1209 362458	TATYANA NOVIKOVA	{"email": "t_novikova.28091974@postgrespro.ru", "phone": "+70912713084"}
0005434066702	68A137	7522 304558	SERGEY NOVIKOV	{"phone": "+70050169498"}
0005434066703	754A6A	3918 985849	TATYANA KALININA	{"phone": "+70750138590"}
0005434066704	BCAB6B	7995 300825	TATYANA IVANOVA	{"phone": "+70729473556"}
0005434066705	BCAB6B	4085 545116	ANASTASIYA ANISIMOVA	{"email": "a-anisimova23111975@postgrespro.ru", "phone": "+70091638620"}
0005434066706	19E4E6	2146 635976	OLGA EFIMOVA	{"email": "olgaefimova-1970@postgrespro.ru", "phone": "+70360891749"}
0005434066707	C5A659	2576 540364	ELENA KOROLEVA	{"phone": "+70866267195"}
0005434066708	C5A659	1565 107338	ALEKSANDR BONDARENKO	{"phone": "+70905723859"}
0005434066709	2AE5A8	9374 683628	VYACHESLAV ROMANOV	{"phone": "+70241067616"}
0005434066710	3699B0	4704 339781	NINA GERASIMOVA	{"phone": "+70735711516"}
0005434066711	F5CE1E	0382 577527	GALINA POPOVA	{"phone": "+70647753560"}
0005434066712	D0FF1A	0526 894213	NATALYA KISELEVA	{"phone": "+70567550435"}
0005434066713	3E4CAA	1577 772060	ANASTASIYA NIKOLAEVA	{"email": "anastasiya-nikolaeva06091968@postgrespro.ru", "phone": "+70638738134"}
0005434066714	3E4CAA	4271 698835	SVETLANA GERASIMOVA	{"phone": "+70239226871"}
0005434066715	3E4CAA	2463 152260	OLGA GRISHINA	{"email": "olga_grishina_1970@postgrespro.ru", "phone": "+70099480074"}
0005434066716	AD3F23	6794 973096	MARIYA NAZAROVA	{"email": "mariya.nazarova.1970@postgrespro.ru", "phone": "+70903596194"}
0005434066717	AD3F23	6473 230924	ELZA ZAYCEVA	{"email": "zayceva.elza1973@postgrespro.ru", "phone": "+70443554838"}
0005434066718	402604	4648 277740	ALINA DAVYDOVA	{"phone": "+70061756455"}
0005434066719	83C673	1435 284151	ROZA LUKYANOVA	{"email": "rozalukyanova1981@postgrespro.ru", "phone": "+70703471430"}
0005434066720	CACB81	1615 360398	RUFINA KALININA	{"email": "rufina_kalinina_041965@postgrespro.ru", "phone": "+70870984090"}
0005434066721	568E4D	7318 067478	ALEKSANDR TARASOV	{"email": "a_tarasov_07061974@postgrespro.ru", "phone": "+70926957782"}
0005434066722	568E4D	4638 097611	VLADIMIR MIRONOV	{"phone": "+70936697003"}
0005434066723	74D66F	2459 341161	EDUARD POPOV	{"phone": "+70557017293"}
0005434066724	74D66F	8990 283607	LYUBOV ABRAMOVA	{"email": "lyubovabramova.17121956@postgrespro.ru", "phone": "+70378872958"}
0005434066725	246A8B	9192 341312	GALINA DAVYDOVA	{"email": "davydova.galina_1968@postgrespro.ru", "phone": "+70482540880"}
0005434066726	A75CE2	9608 735860	RUSLAN KARPOV	{"phone": "+70834879417"}
0005434066727	A75CE2	1187 009427	ILYA ANDREEV	{"email": "iandreev_1973@postgrespro.ru", "phone": "+70553541434"}
0005434066728	73AB4E	1478 477933	ANDREY DENISOV	{"phone": "+70973095952"}
0005434066729	73AB4E	3316 452314	ROMAN MOISEEV	{"email": "moiseev-roman011970@postgrespro.ru", "phone": "+70685788472"}
0005434066730	DCC2A4	2494 533661	EKATERINA ANISIMOVA	{"email": "eanisimova1961@postgrespro.ru", "phone": "+70057933961"}
0005434066731	5DD6A2	1290 476516	ALEKSANDRA TROFIMOVA	{"phone": "+70292751610"}
0005434066732	85ADE4	2346 230564	ANDREY SERGEEV	{"phone": "+70144707351"}
0005434066733	C72C8B	6683 098778	ANDREY PAVLOV	{"email": "a.pavlov10041983@postgrespro.ru", "phone": "+70960565360"}
0005434066734	12C3BD	8306 551822	ANGELINA CHERNOVA	{"email": "chernovaa-011978@postgrespro.ru", "phone": "+70753084434"}
0005434066735	20777E	6138 705528	ROZA SIDOROVA	{"phone": "+70030213364"}
0005434066736	85F89C	1628 680949	ALEKSANDRA MALYSHEVA	{"phone": "+70222103365"}
0005434066737	85F89C	6837 826605	ANDREY IVANOV	{"phone": "+70479627934"}
0005434066738	133EF1	2092 740859	SERGEY FOMIN	{"phone": "+70128691924"}
0005434066739	B89A41	5398 081038	VALERIY ILIN	{"email": "ilin-valeriy_06021968@postgrespro.ru", "phone": "+70915860458"}
0005434066740	EAC02F	8518 505295	LYUBOV KUZMINA	{"phone": "+70939805159"}
0005434066741	BBD828	9436 767111	DARYA ZAYCEVA	{"phone": "+70431039393"}
0005434066742	BBD828	5489 290274	NATALYA KOVALEVA	{"email": "natalya_kovaleva_041963@postgrespro.ru", "phone": "+70914952841"}
0005434066743	E4F5E6	2998 074023	MARINA RYABOVA	{"email": "m-ryabova-051969@postgrespro.ru", "phone": "+70700177564"}
0005434066744	E4F5E6	6436 266045	VIKTOR MEDVEDEV	{"email": "medvedevviktor071975@postgrespro.ru", "phone": "+70714191601"}
0005434066745	E4F5E6	2413 227901	ALEKSANDR AFANASEV	{"phone": "+70926696160"}
0005434066746	AA0FB8	2798 119610	ELENA POPOVA	{"email": "popova.elena1980@postgrespro.ru", "phone": "+70532939060"}
0005434066747	720E17	1443 552945	VASILIY KONOVALOV	{"phone": "+70671633674"}
0005434066748	91D8ED	8150 800631	DMITRIY MOROZOV	{"phone": "+70541247870"}
0005434066749	C84AAB	5232 393712	MARGARITA ILINA	{"phone": "+70293262503"}
0005434066750	DD1096	4320 810825	NIKOLAY PETROV	{"email": "petrov-n1975@postgrespro.ru", "phone": "+70678173707"}
0005434066751	DD1096	3598 654727	VERA RODIONOVA	{"phone": "+70207473439"}
0005434066752	663E41	2672 514408	TATYANA SOROKINA	{"email": "sorokina_tatyana1968@postgrespro.ru", "phone": "+70634535993"}
0005434066753	663E41	3019 712866	ALEKSANDR RODIONOV	{"email": "rodionov.aleksandr.1972@postgrespro.ru", "phone": "+70961717439"}
0005434066754	415383	0806 279262	DMITRIY IVANOV	{"phone": "+70337417909"}
0005434066755	13E284	5384 626614	ANASTASIYA NOVIKOVA	{"email": "novikova-a.051962@postgrespro.ru", "phone": "+70953988537"}
0005434066756	FCFAFC	7591 057628	OKSANA KALININA	{"email": "kalinina.oksana03081967@postgrespro.ru", "phone": "+70233973377"}
0005434066757	FCFAFC	2550 320803	IVAN FROLOV	{"email": "ivanfrolov-121973@postgrespro.ru", "phone": "+70009669434"}
0005434066758	FCFAFC	5051 482439	NINA ILINA	{"email": "ilina-nina-021968@postgrespro.ru", "phone": "+70472279624"}
0005434066759	63FFB7	9281 373118	ALEKSANDR NIKITIN	{"email": "nikitin-a-1970@postgrespro.ru", "phone": "+70762221403"}
0005434066760	9C76B2	6142 034468	SERGEY VLASOV	{"email": "vlasovs.01081968@postgrespro.ru", "phone": "+70053823277"}
0005434066761	B85C43	1613 107309	INGA NIKOLAEVA	{"phone": "+70030017967"}
0005434066762	3CCDDA	6356 109183	NADEZHDA ANDREEVA	{"phone": "+70972551835"}
0005434066763	B5FB47	3559 927634	ILYA SHEVCHENKO	{"email": "ilyashevchenko_031974@postgrespro.ru", "phone": "+70070537030"}
0005434066764	B5FB47	8340 976048	OLEG OSIPOV	{"email": "osipov_oleg-18051973@postgrespro.ru", "phone": "+70216594236"}
0005434066765	7839A7	9847 420549	RAVIL KUZNECOV	{"email": "kuznecovravil_14091967@postgrespro.ru", "phone": "+70061171649"}
0005434066766	6F1D16	6914 519733	NINA KALININA	{"email": "kalinina.nina1979@postgrespro.ru", "phone": "+70686763111"}
0005434066767	2C6F5B	6989 656835	SERGEY ROMANOV	{"phone": "+70678839428"}
0005434066768	E54D64	9534 342588	ANNA ALEKSANDROVA	{"phone": "+70051019558"}
0005434066769	CD82C1	1569 153406	IRINA DENISOVA	{"email": "denisova_irina15071968@postgrespro.ru", "phone": "+70880050751"}
0005434066770	B7D818	1793 652849	ROZA MIKHAYLOVA	{"email": "r_mikhaylova_091965@postgrespro.ru", "phone": "+70391549979"}
0005434066771	B198AA	1217 352873	ALINA IVANOVA	{"email": "ivanova.alina071970@postgrespro.ru", "phone": "+70272898920"}
0005434066772	F952B7	9957 910317	NATALIYA ZAKHAROVA	{"phone": "+70735533273"}
0005434066773	F952B7	1126 672775	VLADIMIR TIMOFEEV	{"email": "vladimir-timofeev.28071971@postgrespro.ru", "phone": "+70403511481"}
0005434066774	69B437	1928 538702	MARIYA TIKHONOVA	{"phone": "+70455081175"}
0005434066775	69B437	3716 240338	KIRA NESTEROVA	{"email": "nesterova_k-1980@postgrespro.ru", "phone": "+70422390008"}
0005434066776	69B437	4192 580319	ANDREY VASILEV	{"email": "vasileva.18061970@postgrespro.ru", "phone": "+70178379938"}
0005434066777	4AD030	4856 080283	PAVEL GAVRILOV	{"phone": "+70076529550"}
0005434066778	4AD030	2742 731470	ELIZAVETA KUZMINA	{"phone": "+70899767722"}
0005434066779	747478	3384 491180	EKATERINA SOLOVEVA	{"email": "ekaterina.soloveva-1964@postgrespro.ru", "phone": "+70673102598"}
0005434066780	7A5C96	0822 510943	VALENTINA PETROVA	{"phone": "+70790154640"}
0005434066781	3B552D	4430 539797	VLADIMIR KUZNECOV	{"email": "v-kuznecov.10071973@postgrespro.ru", "phone": "+70308673008"}
0005434066782	453B54	6538 083253	MARIANNA LUKYANOVA	{"email": "lukyanova_marianna-021964@postgrespro.ru", "phone": "+70170911416"}
0005434066783	453B54	0573 951687	VALENTINA NESTEROVA	{"email": "valentina_nesterova081957@postgrespro.ru", "phone": "+70914950909"}
0005434066784	730F15	5278 851325	YANA MAKSIMOVA	{"phone": "+70192747411"}
0005434066785	730F15	2662 969328	ALSU NOVIKOVA	{"email": "anovikova061966@postgrespro.ru", "phone": "+70593360674"}
0005434066786	7AEAAC	8119 326666	YURIY TARASOV	{"email": "y-tarasov.22081972@postgrespro.ru", "phone": "+70274210272"}
0005434066787	123C6A	8279 559021	VITALIY SOKOLOV	{"phone": "+70298231102"}
0005434066788	123C6A	3547 350487	LYUDMILA FADEEVA	{"email": "fadeeva_lyudmila1979@postgrespro.ru", "phone": "+70929489847"}
0005434066789	7AFC77	5395 872127	ARTEM GAVRILOV	{"email": "gavrilov-artem091972@postgrespro.ru", "phone": "+70047324337"}
0005434066790	7AFC77	1237 304811	ANATOLIY MATVEEV	{"email": "matveev.a.011974@postgrespro.ru", "phone": "+70953206801"}
0005434066791	F892D1	6532 559089	VSEVOLOD KUZNECOV	{"email": "kuznecov_v-19071982@postgrespro.ru", "phone": "+70010716028"}
0005434066792	F892D1	0764 007695	LYUDMILA VOLKOVA	{"email": "lyudmilavolkova.051972@postgrespro.ru", "phone": "+70336691092"}
0005434066793	F892D1	6057 792645	RAMIL MOISEEV	{"phone": "+70847023527"}
0005434066794	7791BD	1765 236202	YAN KAZAKOV	{"phone": "+70223945692"}
0005434066795	7791BD	3416 884125	ANTON BARANOV	{"email": "anton_baranov-17111980@postgrespro.ru", "phone": "+70126107962"}
0005434066796	7791BD	3086 058962	ANASTASIYA MEDVEDEVA	{"phone": "+70700021900"}
0005434066797	E373C5	2083 611901	GALINA NESTEROVA	{"email": "g_nesterova1967@postgrespro.ru", "phone": "+70032521452"}
0005434066798	E373C5	4428 100217	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila_041969@postgrespro.ru", "phone": "+70790434150"}
0005434066799	A47E21	6347 490757	ALINA VOROBEVA	{"phone": "+70281648354"}
0005434066800	A47E21	3931 851535	POLINA ZAKHAROVA	{"phone": "+70424303307"}
0005434066801	4024D1	0580 995044	ELENA KONDRATEVA	{"phone": "+70133384627"}
0005434066802	989A1A	6060 939847	SERGEY BARANOV	{"email": "sergey.baranov-031970@postgrespro.ru", "phone": "+70866532586"}
0005434066803	989A1A	8670 834498	NIKOLAY ANDREEV	{"email": "nandreev_071974@postgrespro.ru", "phone": "+70496746747"}
0005434066804	223024	8520 999332	ANNA BARANOVA	{"email": "baranovaanna-1970@postgrespro.ru", "phone": "+70393895273"}
0005434066805	7D8A37	1218 938322	ELENA ILINA	{"email": "elenailina.1969@postgrespro.ru", "phone": "+70073882019"}
0005434066806	E3FB8D	0096 139128	YULIYA NOVIKOVA	{"phone": "+70287628488"}
0005434066807	4C2027	2984 775792	MIKHAIL SOROKIN	{"email": "sorokinm.1976@postgrespro.ru", "phone": "+70437309338"}
0005434066808	56E991	2017 430331	VYACHESLAV ZHUKOV	{"email": "vzhukov-071975@postgrespro.ru", "phone": "+70343685596"}
0005434066809	56E991	3498 727265	VLADIMIR FEDOROV	{"email": "v.fedorov.021971@postgrespro.ru", "phone": "+70422138916"}
0005434066810	2BF636	9802 629177	VLADISLAV NOVIKOV	{"phone": "+70893705975"}
0005434066811	4A0CBA	1674 813241	LYUDMILA GUSEVA	{"phone": "+70194788954"}
0005434066812	12BE57	1201 448079	VALERIY VLASOV	{"email": "vlasov_v_1978@postgrespro.ru", "phone": "+70102077687"}
0005434066813	12BE57	5112 266055	LYUDMILA VOROBEVA	{"phone": "+70242656562"}
0005434066814	985212	8244 572683	VIKTORIYA FILIPPOVA	{"email": "filippovav1982@postgrespro.ru", "phone": "+70438414317"}
0005434066815	6F7428	8786 321107	GALINA FEDOROVA	{"phone": "+70050252743"}
0005434066816	6F7428	6461 966642	MARIYA MAKSIMOVA	{"email": "maksimovamariya_10071958@postgrespro.ru", "phone": "+70518787890"}
0005434066817	52DD3E	3285 072762	DMITRIY NIKOLAEV	{"email": "dnikolaev_091970@postgrespro.ru", "phone": "+70585045116"}
0005434066818	52DD3E	6314 787842	YAKOV BORISOV	{"email": "borisov-yakov-111963@postgrespro.ru", "phone": "+70476761568"}
0005434066819	41C790	5895 522576	VLADISLAV SIDOROV	{"email": "sidorov-vladislav-1970@postgrespro.ru", "phone": "+70375051693"}
0005434066820	5008C8	1560 627245	ALEKSANDR KOZLOV	{"phone": "+70468549217"}
0005434066821	15D60F	8392 971764	LEONID BORISOV	{"email": "l-borisov_22021963@postgrespro.ru", "phone": "+70459586001"}
0005434066822	15D60F	3268 990766	TATYANA KRASNOVA	{"email": "krasnova.t121978@postgrespro.ru", "phone": "+70205171988"}
0005434066823	568BA9	7310 811308	ANASTASIYA VOLKOVA	{"email": "a-volkova.19081964@postgrespro.ru", "phone": "+70978516215"}
0005434066824	568BA9	3039 686680	ANNA MATVEEVA	{"phone": "+70948567621"}
0005434066825	6ECBE1	5519 858583	OLGA TIMOFEEVA	{"email": "timofeeva_olga.18051965@postgrespro.ru", "phone": "+70081491127"}
0005434066826	189123	3851 470868	RINAT GUSEV	{"email": "gusev.rinat.111978@postgrespro.ru", "phone": "+70041576451"}
0005434066827	189123	7494 093132	EKATERINA SOKOLOVA	{"email": "sokolova_e_1970@postgrespro.ru", "phone": "+70545852760"}
0005434066828	189123	1075 995803	DARYA KUZNECOVA	{"email": "darya_kuznecova-1976@postgrespro.ru", "phone": "+70613004091"}
0005434066829	2A0FC7	5200 806914	IRINA KUZNECOVA	{"email": "kuznecova_i-081975@postgrespro.ru", "phone": "+70052187727"}
0005434066830	2FA803	4741 013993	IGOR CHERNOV	{"phone": "+70244292508"}
0005434066831	2FA803	1715 934220	SERGEY SOKOLOV	{"phone": "+70993218779"}
0005434066832	11F274	4154 344327	SVETLANA KAZAKOVA	{"phone": "+70865108449"}
0005434066833	DFA03C	2983 691490	YULIYA MEDVEDEVA	{"phone": "+70468631726"}
0005434066834	03DBCB	1890 597416	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov1977@postgrespro.ru", "phone": "+70211660584"}
0005434066835	03DBCB	6178 745767	SERGEY ROMANOV	{"phone": "+70707233705"}
0005434066836	A82E85	5024 676791	DMITRIY VOLKOV	{"phone": "+70412468274"}
0005434066837	A82E85	9822 979134	KONSTANTIN KONOVALOV	{"email": "konstantin.konovalov_31011973@postgrespro.ru", "phone": "+70368494941"}
0005434066838	CF62B1	1019 340904	SERGEY IVANOV	{"phone": "+70472867492"}
0005434066839	243F68	6145 140956	NADEZHDA OSIPOVA	{"phone": "+70882303858"}
0005434066840	1E7DC1	2880 534278	SEMEN AFANASEV	{"phone": "+70458674226"}
0005434066841	1E7DC1	1376 629223	LYUBOV SEMENOVA	{"email": "lyubov.semenova.101969@postgrespro.ru", "phone": "+70734478597"}
0005434066842	915176	4788 604485	IRINA KOROLEVA	{"phone": "+70031430834"}
0005434066843	C13ACB	9085 101892	TATYANA SOROKINA	{"email": "sorokina-t-1978@postgrespro.ru", "phone": "+70643500848"}
0005434066844	C13ACB	2868 890176	ELZA OVCHINNIKOVA	{"email": "ovchinnikova_elza.02061980@postgrespro.ru", "phone": "+70440685802"}
0005434066845	06257B	1528 084565	ANTON EGOROV	{"email": "anton-egorov-111976@postgrespro.ru", "phone": "+70178126010"}
0005434066846	06257B	7999 225428	NADEZHDA PETROVA	{"phone": "+70477313482"}
0005434066847	C0B710	3721 116053	DARYA MOISEEVA	{"phone": "+70318373249"}
0005434066848	1486AD	0798 515630	ELENA PAVLOVA	{"email": "elena-pavlova.031978@postgrespro.ru", "phone": "+70115204369"}
0005434066849	979539	2275 953453	MIKHAIL IVANOV	{"phone": "+70749377403"}
0005434066850	979539	0638 464057	DMITRIY MATVEEV	{"email": "matveev.dmitriy-101978@postgrespro.ru", "phone": "+70607537077"}
0005434066851	6E661D	3251 763610	ALEKSEY PETROV	{"email": "a_petrov-1969@postgrespro.ru", "phone": "+70783352924"}
0005434066852	B3829B	4863 514763	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya.1960@postgrespro.ru", "phone": "+70139584894"}
0005434066853	CDAA54	6518 974384	MIKHAIL BORISOV	{"phone": "+70947204912"}
0005434066854	CDAA54	6801 903425	OLGA BARANOVA	{"phone": "+70631526039"}
0005434066855	CDAA54	3725 170478	MARGARITA SIDOROVA	{"phone": "+70926807644"}
0005434066856	64B74E	4809 999242	VLADIMIR SEMENOV	{"email": "semenov-v.31031978@postgrespro.ru", "phone": "+70347025710"}
0005434066857	52B93A	3039 331122	SVETLANA NOVIKOVA	{"email": "s.novikova_02021970@postgrespro.ru", "phone": "+70956349456"}
0005434066858	921D4F	8961 383353	YULIYA ARKHIPOVA	{"phone": "+70833808488"}
0005434066859	D1FD2E	0283 621717	VALENTINA GAVRILOVA	{"email": "gavrilova.valentina_051967@postgrespro.ru", "phone": "+70991322174"}
0005434066860	D1FD2E	7955 053623	NIKOLAY NAZAROV	{"email": "n-nazarov_1974@postgrespro.ru", "phone": "+70923377111"}
0005434066861	D1FD2E	9755 698833	ZINAIDA ZAKHAROVA	{"phone": "+70671647446"}
0005434066862	018C1E	7841 853660	ALEKSEY SHEVCHENKO	{"email": "shevchenko_a-011971@postgrespro.ru", "phone": "+70405306881"}
0005434066863	AE576C	7683 226524	IRINA SOKOLOVA	{"phone": "+70380259564"}
0005434066864	FECAE1	7566 588243	SVETLANA ZHUKOVA	{"phone": "+70754317118"}
0005434066865	FECAE1	0612 553946	VIKTOR BORISOV	{"phone": "+70630088032"}
0005434066866	6B1581	8575 087244	VLADIMIR KUZNECOV	{"phone": "+70884532845"}
0005434066867	C835F3	0095 190317	ALISHER ZHUKOV	{"phone": "+70191718757"}
0005434066868	27F1D3	5478 740589	EKATERINA BELOVA	{"email": "ekaterina.belova09051975@postgrespro.ru", "phone": "+70671279275"}
0005434066869	C59C55	8100 136125	DMITRIY BELOV	{"email": "dmitriy_belov_091961@postgrespro.ru", "phone": "+70531970557"}
0005434066870	E71838	6802 926623	YANA KUZNECOVA	{"email": "yana_kuznecova-13021971@postgrespro.ru", "phone": "+70246476129"}
0005434066871	EBF081	7279 549851	NATALYA SOROKINA	{"email": "n.sorokina.111971@postgrespro.ru", "phone": "+70345843133"}
0005434066872	EBF081	8870 051145	KSENIYA SOLOVEVA	{"phone": "+70374228134"}
0005434066873	4068F0	6445 787901	LIDIYA ZAYCEVA	{"phone": "+70646307152"}
0005434066874	60C1E9	6093 934517	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr15011975@postgrespro.ru", "phone": "+70490224328"}
0005434066875	60C1E9	8364 060089	SERGEY FROLOV	{"email": "sergey-frolov_1978@postgrespro.ru", "phone": "+70942253048"}
0005434066876	93FD75	2867 911903	ANDREY ABRAMOV	{"phone": "+70300571250"}
0005434066877	93FD75	7039 702106	YURIY SEMENOV	{"phone": "+70471198819"}
0005434066878	27F7BC	5749 537895	NADEZHDA KUZNECOVA	{"email": "kuznecova-nadezhda_081976@postgrespro.ru", "phone": "+70977397308"}
0005434066879	DD87FE	8942 991549	VALENTINA KAZAKOVA	{"email": "v-kazakova-28031963@postgrespro.ru", "phone": "+70874931552"}
0005434066880	DD87FE	7541 507014	VALERIY KISELEV	{"email": "kiselevv.071978@postgrespro.ru", "phone": "+70509552410"}
0005434066881	DD87FE	7383 096411	YURIY GAVRILOV	{"email": "y_gavrilov_1970@postgrespro.ru", "phone": "+70203608467"}
0005434066882	BE3BFF	6583 737032	ANATOLIY MOROZOV	{"phone": "+70988900974"}
0005434066883	BE3BFF	5318 956540	OLESYA KONDRATEVA	{"phone": "+70172169745"}
0005434066884	A08B24	9478 719703	ANNA SCHERBAKOVA	{"phone": "+70414507279"}
0005434066885	D6D7AE	6208 031392	ARTEM ANDREEV	{"phone": "+70372247120"}
0005434066886	40210F	3412 558775	ARTUR TARASOV	{"email": "tarasov.a-04121955@postgrespro.ru", "phone": "+70856017358"}
0005434066887	60AF92	4199 839308	ALEKSEY MATVEEV	{"email": "matveev-a-12071980@postgrespro.ru", "phone": "+70103620625"}
0005434066888	C5FF86	3259 417154	ALEKSANDR VOLKOV	{"email": "volkov_a.02021965@postgrespro.ru", "phone": "+70077772534"}
0005434066889	C5FF86	9976 973427	NATALYA FEDOROVA	{"email": "fedorova.natalya_1977@postgrespro.ru", "phone": "+70558803705"}
0005434066890	C5FF86	4901 928947	MAKSIM VOLKOV	{"email": "volkov.m-23011974@postgrespro.ru", "phone": "+70604251353"}
0005434066891	0660CA	4472 809111	NATALYA MELNIKOVA	{"email": "natalya.melnikova.21071968@postgrespro.ru", "phone": "+70813605796"}
0005434066892	C43A38	7792 032655	STEPAN KAZAKOV	{"email": "kazakov_stepan-1980@postgrespro.ru", "phone": "+70546583717"}
0005434066893	C43A38	9804 455995	GALINA NOVIKOVA	{"email": "galinanovikova02061964@postgrespro.ru", "phone": "+70004406973"}
0005434066894	C43A38	1568 107907	NIKOLAY SOROKIN	{"email": "n.sorokin_1966@postgrespro.ru", "phone": "+70322049082"}
0005434066895	0EF58C	4883 523398	ROMAN MOISEEV	{"email": "r.moiseev.1977@postgrespro.ru", "phone": "+70541940172"}
0005434066896	B193E3	2301 202660	GENNADIY FEDOTOV	{"email": "gfedotov-101985@postgrespro.ru", "phone": "+70045458260"}
0005434066897	B193E3	6867 866248	ANASTASIYA MIRONOVA	{"email": "mironova.a-1970@postgrespro.ru", "phone": "+70379597424"}
0005434066898	6737F1	6152 752303	TATYANA MALYSHEVA	{"phone": "+70520185228"}
0005434066899	7E5261	0915 410153	IRINA KOZLOVA	{"email": "kozlova_irina.091981@postgrespro.ru", "phone": "+70071457608"}
0005434066900	9A993C	0696 889917	MARINA DANILOVA	{"phone": "+70397516341"}
0005434066901	DF3049	3843 132000	VLADIMIR ISAEV	{"phone": "+70960233391"}
0005434066902	335E6F	4100 906036	DENIS FEDOROV	{"phone": "+70388443185"}
0005434066903	84B0A0	6059 713737	TATYANA KUZMINA	{"phone": "+70980101193"}
0005434066904	693EA9	7353 764456	ELENA MELNIKOVA	{"email": "melnikovae13101968@postgrespro.ru", "phone": "+70556024061"}
0005434066905	693EA9	8521 628691	ROMAN MAKAROV	{"email": "roman_makarov_071973@postgrespro.ru", "phone": "+70619001629"}
0005434066906	F2AD77	7600 634448	VASILIY IVANOV	{"email": "v.ivanov14061970@postgrespro.ru", "phone": "+70210089823"}
0005434066907	F2AD77	0834 183974	ANATOLIY SCHERBAKOV	{"email": "a.scherbakov28121986@postgrespro.ru", "phone": "+70509187366"}
0005434066908	452743	3719 234856	ALEKSANDR YAKOVLEV	{"phone": "+70077566043"}
0005434066909	124CA3	1533 853663	ZINAIDA SERGEEVA	{"phone": "+70120526185"}
0005434066910	3CA5C4	3324 890381	VERA DENISOVA	{"email": "v_denisova.081963@postgrespro.ru", "phone": "+70998243399"}
0005434066911	3CA5C4	3026 056453	NADEZHDA VLASOVA	{"phone": "+70026054554"}
0005434066912	DC00FD	6263 935493	ALEKSANDRA ABRAMOVA	{"phone": "+70396353198"}
0005434066913	DC00FD	5767 026316	VLADIMIR NIKITIN	{"email": "v_nikitin_27101969@postgrespro.ru", "phone": "+70314259119"}
0005434066914	FA4BA0	2947 798241	PAVEL MATVEEV	{"phone": "+70751103160"}
0005434066915	FB2936	3970 158754	DARYA KOVALEVA	{"email": "d_kovaleva-12101971@postgrespro.ru", "phone": "+70647003508"}
0005434066916	457E91	3435 084939	IGOR ZHURAVLEV	{"email": "i_zhuravlev_1964@postgrespro.ru", "phone": "+70518380299"}
0005434066917	457E91	3920 361984	DMITRIY KUZMIN	{"phone": "+70962729264"}
0005434066918	625877	1470 400706	SERGEY KUZNECOV	{"email": "skuznecov_101973@postgrespro.ru", "phone": "+70402199615"}
0005434066919	29399C	3995 319112	VLADIMIR KUZNECOV	{"phone": "+70483562066"}
0005434066920	6B891A	1860 948783	ALEKSEY DAVYDOV	{"email": "aleksey-davydov031966@postgrespro.ru", "phone": "+70005978917"}
0005434066921	07AF15	6384 923454	EGOR MEDVEDEV	{"email": "medvedev.egor.081971@postgrespro.ru", "phone": "+70560773697"}
0005434066922	977E19	8450 465381	IVAN PETROV	{"phone": "+70466104827"}
0005434066923	977E19	6799 486256	EKATERINA POTAPOVA	{"email": "potapova_e-1961@postgrespro.ru", "phone": "+70406568057"}
0005434066924	F0DCB7	0097 617742	VALERIY NOVIKOV	{"email": "v.novikov23091964@postgrespro.ru", "phone": "+70002783635"}
0005434066925	97B3FE	5192 239553	NIKOLAY NOVIKOV	{"email": "nikolay_novikov-1983@postgrespro.ru", "phone": "+70982780841"}
0005434066926	97B3FE	8569 489012	ANNA TARASOVA	{"phone": "+70895822135"}
0005434066927	97B3FE	0403 241122	IVAN MIRONOV	{"email": "mironovivan.041967@postgrespro.ru", "phone": "+70681160188"}
0005434066928	04D22C	6514 343425	EVGENIYA ALEKSEEVA	{"phone": "+70085868270"}
0005434066929	ED8F6A	8343 461690	NIKOLAY OSIPOV	{"phone": "+70092563067"}
0005434066930	BDCF66	4716 519786	ALEKSANDR DMITRIEV	{"phone": "+70937538033"}
0005434066931	433D1F	9491 862669	DARYA KOZLOVA	{"phone": "+70623555808"}
0005434066932	020967	1635 647458	ALEKSANDR KISELEV	{"email": "kiselev.a091971@postgrespro.ru", "phone": "+70148812750"}
0005434066933	2B6E3B	8683 354178	TIMUR VOROBEV	{"phone": "+70998400827"}
0005434066934	439E24	0202 350213	IGOR ALEKSANDROV	{"email": "aleksandrovigor-25031972@postgrespro.ru", "phone": "+70130025081"}
0005434066935	439E24	6348 932445	IVAN ROMANOV	{"email": "ivan_romanov031963@postgrespro.ru", "phone": "+70691738275"}
0005434066936	5ADE18	5098 001024	RADMIR KOROLEV	{"email": "korolev.r_1972@postgrespro.ru", "phone": "+70850238956"}
0005434066937	4F4E21	2179 868703	VYACHESLAV GORBUNOV	{"phone": "+70699380834"}
0005434066938	8FAE39	3222 859420	EVGENIY KULIKOV	{"phone": "+70694010697"}
0005434066939	1A4909	1467 111331	ALEKSANDRA GUSEVA	{"email": "a-guseva.1979@postgrespro.ru", "phone": "+70051622822"}
0005434066940	11212C	6921 044408	EKATERINA LUKYANOVA	{"phone": "+70721650156"}
0005434066941	11212C	6541 146567	STANISLAV NIKITIN	{"phone": "+70984862688"}
0005434066942	CC468A	6960 103390	DMITRIY EGOROV	{"email": "dmitriy_egorov_1974@postgrespro.ru", "phone": "+70647354328"}
0005434066943	CC468A	6316 350174	TAMARA NAUMOVA	{"phone": "+70692677536"}
0005434066944	CC468A	4499 072759	KONSTANTIN VOLKOV	{"email": "kvolkov-1975@postgrespro.ru", "phone": "+70377823298"}
0005434066945	EB62BD	4002 344872	NIKOLAY TIKHONOV	{"phone": "+70252541900"}
0005434066946	5243D6	5067 805460	VLADISLAV DMITRIEV	{"phone": "+70214420471"}
0005434066947	5243D6	1466 570458	IRINA SCHERBAKOVA	{"phone": "+70259312111"}
0005434066948	1BBFC4	9874 258290	VIKTOR ANDREEV	{"email": "andreevviktor_1965@postgrespro.ru", "phone": "+70857558019"}
0005434066949	1BBFC4	5378 371292	REGINA KOROLEVA	{"email": "korolevaregina.1973@postgrespro.ru", "phone": "+70002606133"}
0005434066950	2AF14B	9780 299530	TATYANA KUZMINA	{"phone": "+70199630447"}
0005434066951	2AF14B	0131 724554	VLADIMIR IVANOV	{"phone": "+70361867739"}
0005434066952	C8A1AF	9947 378961	NIKITA SCHERBAKOV	{"email": "scherbakov_nikita.1970@postgrespro.ru", "phone": "+70180685405"}
0005434066953	8E9D7E	3159 866763	ALEKSANDR MAKAROV	{"phone": "+70047622914"}
0005434066954	8E9D7E	2226 469641	VYACHESLAV IVANOV	{"email": "vyacheslav.ivanov-21101977@postgrespro.ru", "phone": "+70905765586"}
0005434066955	DEEE1B	1576 813273	EVGENIY ROMANOV	{"email": "romanov_evgeniy1972@postgrespro.ru", "phone": "+70255557334"}
0005434066956	066EB9	5174 146581	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov_051975@postgrespro.ru", "phone": "+70924418026"}
0005434066957	066EB9	5307 642975	DENIS IVANOV	{"email": "ivanov_d_061970@postgrespro.ru", "phone": "+70485120165"}
0005434066958	BD24D5	3736 646005	LILIYA KUZNECOVA	{"phone": "+70074198019"}
0005434067079	D611F0	2741 567744	VITALIY IVANOV	{"phone": "+70560636409"}
0005434066959	487BFB	0191 497113	ALEKSANDR SOROKIN	{"email": "asorokin13111966@postgrespro.ru", "phone": "+70964588776"}
0005434066960	87DB92	1273 010077	NINA AFANASEVA	{"phone": "+70840658971"}
0005434066961	2A38FC	4944 490249	VLADISLAV SIDOROV	{"phone": "+70981673330"}
0005434066962	2A38FC	6335 831170	ILYA ZAKHAROV	{"phone": "+70381234133"}
0005434066963	EC47FA	3598 182762	ZINAIDA MEDVEDEVA	{"phone": "+70093487364"}
0005434066964	EC47FA	0625 833698	ANATOLIY YAKOVLEV	{"email": "yakovlev-anatoliy1977@postgrespro.ru", "phone": "+70779001578"}
0005434066965	E5A196	7998 907739	KLAVDIYA BORISOVA	{"email": "borisovak-22111978@postgrespro.ru", "phone": "+70554095070"}
0005434066966	87752C	3477 845436	VALENTINA YAKOVLEVA	{"phone": "+70097852474"}
0005434066967	7C9778	2690 490802	GLEB MOROZOV	{"phone": "+70087503747"}
0005434066968	7C9778	7497 233339	RAVIL VASILEV	{"phone": "+70430323209"}
0005434066969	57FF03	3613 873745	TATYANA YAKOVLEVA	{"phone": "+70833470603"}
0005434066970	37635E	0917 653774	VYACHESLAV TIKHONOV	{"email": "tikhonovvyacheslav1977@postgrespro.ru", "phone": "+70383822787"}
0005434066971	6F34BF	2655 271608	ALEKSEY VASILEV	{"phone": "+70222076206"}
0005434066972	F85B26	2734 589565	KONSTANTIN IVANOV	{"email": "k_ivanov.1980@postgrespro.ru", "phone": "+70914887121"}
0005434066973	F85B26	1311 230633	KSENIYA NAZAROVA	{"phone": "+70321509519"}
0005434066974	EECB47	1619 807394	PAVEL MARTYNOV	{"phone": "+70838418562"}
0005434066975	64D6EA	4022 948664	NADEZHDA ROMANOVA	{"email": "nadezhda_romanova28111976@postgrespro.ru", "phone": "+70326123552"}
0005434066976	2CC650	6153 150315	SERGEY DAVYDOV	{"email": "sergeydavydov_30041963@postgrespro.ru", "phone": "+70429409515"}
0005434066977	781E08	8504 992996	TATYANA MAKSIMOVA	{"email": "maksimovat021972@postgrespro.ru", "phone": "+70157178717"}
0005434067090	ABDC5B	6323 729368	ALBINA SMIRNOVA	{"phone": "+70604059204"}
0005434067091	7630AA	4437 169937	ANASTASIYA PETROVA	{"phone": "+70771892324"}
0005434066978	676AE0	1064 080080	ANATOLIY ZHURAVLEV	{"email": "zhuravlev-anatoliy_1974@postgrespro.ru", "phone": "+70000247988"}
0005434066979	676AE0	8062 006043	INGA NIKOLAEVA	{"phone": "+70018695010"}
0005434066980	2533DB	5687 108915	GALINA NESTEROVA	{"phone": "+70984060328"}
0005434066981	92B362	8744 484502	ANASTASIYA POTAPOVA	{"phone": "+70406832914"}
0005434066982	F4EC69	9489 114774	EKATERINA EFIMOVA	{"email": "ekaterina_efimova.16031975@postgrespro.ru", "phone": "+70305134858"}
0005434066983	B4207F	7207 843091	NIKOLAY SOROKIN	{"phone": "+70342637293"}
0005434066984	73370A	7910 696415	SVETLANA FROLOVA	{"phone": "+70209089346"}
0005434066985	25CD86	0203 364487	SERGEY BONDARENKO	{"email": "bondarenko.sergey_1985@postgrespro.ru", "phone": "+70442242129"}
0005434066986	E0D8F8	9155 440274	ALEKSANDRA STEPANOVA	{"email": "aleksandra-stepanova.23061979@postgrespro.ru", "phone": "+70070907818"}
0005434066987	DBAEAF	3515 482849	FAINA KOVALEVA	{"phone": "+70464770989"}
0005434066988	926575	9219 911873	OLEG VASILEV	{"email": "oleg-vasilev.041976@postgrespro.ru", "phone": "+70820036114"}
0005434066989	646B01	1468 039747	IGOR KUZMIN	{"email": "i.kuzmin28121979@postgrespro.ru", "phone": "+70564377227"}
0005434066990	646B01	5049 398113	MAKSIM SOROKIN	{"email": "sorokinm.12011966@postgrespro.ru", "phone": "+70471828815"}
0005434066991	646B01	7399 936803	VALENTINA GERASIMOVA	{"phone": "+70783059343"}
0005434066992	E7B70B	3925 048443	LIDIYA KARPOVA	{"email": "karpovalidiya_041971@postgrespro.ru", "phone": "+70411077378"}
0005434066993	E7B70B	8039 552781	EVGENIY PAVLOV	{"phone": "+70447663256"}
0005434066994	BCB2AB	8460 388242	SERGEY GUSEV	{"email": "sergeygusev-04031973@postgrespro.ru", "phone": "+70163755098"}
0005434066995	1C4D74	5794 982868	ELENA SMIRNOVA	{"phone": "+70296596606"}
0005434066996	40E425	3255 301211	ILYA IVANOV	{"phone": "+70483017614"}
0005434066997	A90D84	6548 996891	MIKHAIL VASILEV	{"phone": "+70205226954"}
0005434066998	A90D84	8291 680729	ELENA BOGDANOVA	{"phone": "+70101843293"}
0005434066999	B33126	8017 717515	MARIYA ANTONOVA	{"phone": "+70569055555"}
0005434067000	6A2BDC	2771 701227	RUSLAN NAZAROV	{"email": "nazarov_ruslan_22041974@postgrespro.ru", "phone": "+70444712886"}
0005434067001	6A2BDC	6903 254196	NIKOLAY ZHUKOV	{"phone": "+70759380029"}
0005434067002	168A1A	4351 913418	MARGARITA GAVRILOVA	{"phone": "+70460684158"}
0005434067003	6283CA	9295 757460	EKATERINA MASLOVA	{"phone": "+70846435887"}
0005434067004	F1D02A	3759 471234	GALINA FILATOVA	{"email": "g.filatova.1977@postgrespro.ru", "phone": "+70963034237"}
0005434067005	19D4F0	8741 492310	GALINA GUSEVA	{"phone": "+70436515128"}
0005434067006	19D4F0	4194 630336	EKATERINA RYABOVA	{"email": "e.ryabova16061986@postgrespro.ru", "phone": "+70600099346"}
0005434067007	D62E69	2885 999628	SERGEY RODIONOV	{"email": "srodionov_1974@postgrespro.ru", "phone": "+70929060492"}
0005434067008	044A24	5896 818083	ELENA ZAYCEVA	{"phone": "+70395303281"}
0005434067009	FD553D	6255 581561	KONSTANTIN GUSEV	{"email": "gusev_konstantin.02071977@postgrespro.ru", "phone": "+70829648376"}
0005434067010	430D17	3233 210727	IVAN GAVRILOV	{"email": "i_gavrilov011986@postgrespro.ru", "phone": "+70860973196"}
0005434067011	44771B	8703 605888	MATVEY GORBUNOV	{"phone": "+70806888008"}
0005434067012	A9FF14	9651 378027	ELENA DENISOVA	{"email": "denisova_elena_19121972@postgrespro.ru", "phone": "+70128189310"}
0005434067013	A9FF14	8216 647257	ELENA KOROLEVA	{"email": "e.koroleva051973@postgrespro.ru", "phone": "+70807165978"}
0005434067014	A02F81	0561 880533	LIDIYA SOLOVEVA	{"email": "l.soloveva.111976@postgrespro.ru", "phone": "+70914424529"}
0005434067015	F88D79	7806 841897	VITALIY SCHERBAKOV	{"email": "scherbakovvitaliy.1984@postgrespro.ru", "phone": "+70020264531"}
0005434067016	409249	6710 582717	LYUDMILA KARPOVA	{"phone": "+70524791609"}
0005434067017	13FDA9	0870 998639	RAMILYA KUZNECOVA	{"phone": "+70331398286"}
0005434067018	4E9405	8130 194025	ELENA PAVLOVA	{"phone": "+70064921134"}
0005434067019	01FA1D	4298 334061	FAINA KUZNECOVA	{"email": "fainakuznecova-091968@postgrespro.ru", "phone": "+70665618888"}
0005434067020	259AC2	4410 732371	VIKTOR YAKOVLEV	{"email": "yakovlevviktor_1976@postgrespro.ru", "phone": "+70346570141"}
0005434067021	26E49E	4581 757390	PRASKOVYA PETROVA	{"email": "praskovya_petrova_01011969@postgrespro.ru", "phone": "+70326993945"}
0005434067022	85F4FC	6503 925654	IRINA IVANOVA	{"phone": "+70480192701"}
0005434067023	EE96BC	2032 914767	IGOR TIKHONOV	{"email": "tikhonov.i_18091963@postgrespro.ru", "phone": "+70539218756"}
0005434067024	F1C81A	9251 709769	EVGENIYA RODIONOVA	{"email": "e.rodionova081963@postgrespro.ru", "phone": "+70712482755"}
0005434067025	F1C81A	5312 938672	SERGEY YAKOVLEV	{"email": "sergey-yakovlev_1971@postgrespro.ru", "phone": "+70697992688"}
0005434067026	58E85E	9044 651970	ALEKSANDR SAVELEV	{"phone": "+70918714933"}
0005434067027	1C94AD	4250 537160	SERGEY SAVELEV	{"phone": "+70757829266"}
0005434067028	D8D3FA	1105 028155	YULIYA BOGDANOVA	{"email": "yuliya_bogdanova-1982@postgrespro.ru", "phone": "+70884769323"}
0005434067029	D8D3FA	1479 871967	VYACHESLAV ZAKHAROV	{"email": "zakharov.v1966@postgrespro.ru", "phone": "+70365681002"}
0005434067030	51A804	4913 680933	ALEKSANDRA KOMAROVA	{"phone": "+70571420909"}
0005434067031	8CF631	7283 113536	IVAN ALEKSEEV	{"phone": "+70568210992"}
0005434067032	4BCBA5	9731 339441	ALEKSEY TIKHONOV	{"phone": "+70120583376"}
0005434067033	E51674	5822 960075	ANNA MAKSIMOVA	{"phone": "+70461064869"}
0005434067034	E51674	4207 335319	IRINA SOKOLOVA	{"email": "irina_sokolova.27071958@postgrespro.ru", "phone": "+70602183961"}
0005434067035	E51674	8803 955510	VADIM MOROZOV	{"email": "morozov-v_26081978@postgrespro.ru", "phone": "+70502622248"}
0005434067036	9959A4	5227 582268	VLADIMIR KRASNOV	{"phone": "+70163631509"}
0005434067037	5E70FB	7284 887770	NIKOLAY MIRONOV	{"phone": "+70218113694"}
0005434067038	5E70FB	7687 901092	LIDIYA SAVELEVA	{"email": "saveleva-l-1972@postgrespro.ru", "phone": "+70996313901"}
0005434067039	54E7DA	5864 010803	SALAVAT BELOV	{"phone": "+70418711236"}
0005434067040	E1BF61	5020 476313	IRINA POTAPOVA	{"phone": "+70271110528"}
0005434067041	E1BF61	9670 776870	GALINA KONOVALOVA	{"phone": "+70587682746"}
0005434067042	652A01	1581 404977	KIRA VLASOVA	{"phone": "+70814405119"}
0005434067043	4E1CCB	1486 291789	RADIK SOLOVEV	{"phone": "+70783106432"}
0005434067044	EF48FC	5218 600206	GALINA SMIRNOVA	{"phone": "+70632113902"}
0005434067045	9275FC	5883 837937	EVGENIY FOMIN	{"email": "e-fomin_111970@postgrespro.ru", "phone": "+70387041079"}
0005434067046	9275FC	3262 487979	VIKTOR MOROZOV	{"phone": "+70737830084"}
0005434067047	17D4A9	3797 879314	ANNA TITOVA	{"phone": "+70937847302"}
0005434067048	4D1C41	6184 854277	ALENA ANISIMOVA	{"email": "a-anisimova1974@postgrespro.ru", "phone": "+70420970468"}
0005434067049	4D1C41	3038 765971	IGOR KOZLOV	{"phone": "+70753299000"}
0005434067050	54EFD0	8604 512227	ANASTASIYA KUZMINA	{"phone": "+70404539763"}
0005434067051	54EFD0	1635 825576	MARINA RODIONOVA	{"phone": "+70574417311"}
0005434067052	54EFD0	0838 245513	ROMAN KULIKOV	{"phone": "+70984857473"}
0005434067053	9C3C8D	3085 329875	ALEKSANDR EGOROV	{"phone": "+70447989497"}
0005434067054	05B18D	8357 207133	VIKTOR DMITRIEV	{"email": "dmitrievv-08091986@postgrespro.ru", "phone": "+70040649284"}
0005434067055	05B18D	0272 239381	OLGA BELYAEVA	{"email": "obelyaeva_021968@postgrespro.ru", "phone": "+70448465828"}
0005434067056	F658BB	6273 435152	INNA KAZAKOVA	{"email": "inna_kazakova_26081969@postgrespro.ru", "phone": "+70549201741"}
0005434067057	29428C	0098 642832	VLADIMIR KOROLEV	{"phone": "+70612300430"}
0005434067058	29428C	4283 484128	ELENA RYABOVA	{"phone": "+70006183816"}
0005434067059	29428C	3564 640063	YURIY BELOV	{"email": "yuriy.belov-1970@postgrespro.ru", "phone": "+70717144218"}
0005434067060	87BC65	4610 330126	SERGEY ZAYCEV	{"email": "zaycev-sergey.061980@postgrespro.ru", "phone": "+70278755882"}
0005434067061	5EAE69	2374 135143	NATALYA LEBEDEVA	{"phone": "+70765433210"}
0005434067062	5EAE69	5410 581176	ALEKSANDR KUZMIN	{"phone": "+70047645917"}
0005434067063	0007ED	9039 738730	VERA FILATOVA	{"email": "vera_filatova.02091969@postgrespro.ru", "phone": "+70136607673"}
0005434067064	0007ED	6248 580709	LYUBOV ABRAMOVA	{"email": "l.abramova26061967@postgrespro.ru", "phone": "+70761496340"}
0005434067065	6D2093	2227 277768	TAMARA MELNIKOVA	{"email": "tamara.melnikova_24101966@postgrespro.ru", "phone": "+70374173017"}
0005434067066	B10808	8215 171123	VALENTINA STEPANOVA	{"email": "v_stepanova_1970@postgrespro.ru", "phone": "+70545213756"}
0005434067067	4732EE	8444 566957	PETR SERGEEV	{"email": "sergeev.petr.22061984@postgrespro.ru", "phone": "+70413776489"}
0005434067068	C5BB4B	3836 524604	SERGEY KISELEV	{"phone": "+70426450939"}
0005434067069	B6683D	3889 068541	EVGENIYA LAZAREVA	{"email": "lazareva.e_1970@postgrespro.ru", "phone": "+70077828372"}
0005434067070	D46746	7858 561324	ALEKSEY IVANOV	{"email": "alekseyivanov061967@postgrespro.ru", "phone": "+70346339894"}
0005434067071	D46746	5126 717974	VENIAMIN NAZAROV	{"email": "nazarovveniamin-1963@postgrespro.ru", "phone": "+70784216127"}
0005434067072	2CA8CA	6341 994427	RASUL SCHERBAKOV	{"email": "scherbakovr_18081982@postgrespro.ru", "phone": "+70999463199"}
0005434067073	2DE856	4794 350872	DARYA GERASIMOVA	{"email": "d-gerasimova1969@postgrespro.ru", "phone": "+70312827740"}
0005434067074	89E4B1	3670 026683	NADEZHDA GORBUNOVA	{"email": "n.gorbunova_06061970@postgrespro.ru", "phone": "+70394278084"}
0005434067075	C25674	9356 707087	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov051974@postgrespro.ru", "phone": "+70222261264"}
0005434067076	D18170	0578 781698	ARTEM FROLOV	{"email": "frolovartem.1985@postgrespro.ru", "phone": "+70416326952"}
0005434067077	AD4C6B	9992 766505	INNA VOLKOVA	{"email": "inna-volkova.101969@postgrespro.ru", "phone": "+70833105771"}
0005434067078	AD4C6B	9072 190047	ROMAN GUSEV	{"email": "gusevr.1958@postgrespro.ru", "phone": "+70135961855"}
0005434067080	D611F0	3121 627898	ALEKSANDR GUSEV	{"email": "aleksandrgusev.11031961@postgrespro.ru", "phone": "+70120921957"}
0005434067081	3EDAD3	6644 351628	EVGENIY KOZLOV	{"email": "e-kozlov_06061979@postgrespro.ru", "phone": "+70555830047"}
0005434067082	32F0C0	1907 221817	EVGENIY RODIONOV	{"email": "rodionov-evgeniy1959@postgrespro.ru", "phone": "+70906531708"}
0005434067083	4EFC33	6932 811055	GALINA POTAPOVA	{"email": "galina-potapova031993@postgrespro.ru", "phone": "+70141679086"}
0005434067084	B0B9CD	2787 824160	ANDREY FROLOV	{"phone": "+70634690233"}
0005434067085	DF3AA8	2049 164587	MARIYA NOVIKOVA	{"phone": "+70805923435"}
0005434067086	B0AEDB	5612 331082	KAMILA FILATOVA	{"email": "filatovakamila1970@postgrespro.ru", "phone": "+70895174063"}
0005434067087	017E83	2788 661345	KSENIYA OSIPOVA	{"email": "osipova.k-1970@postgrespro.ru", "phone": "+70068063421"}
0005434067088	017E83	3406 718325	OLGA MAKSIMOVA	{"email": "maksimovao-071976@postgrespro.ru", "phone": "+70457581211"}
0005434067089	5B78F8	7333 557194	VLADIMIR KUZNECOV	{"phone": "+70278368299"}
0005434067092	68AF2D	9036 572580	SVETLANA SAVELEVA	{"email": "saveleva-s-041972@postgrespro.ru", "phone": "+70074417757"}
0005434067093	68AF2D	7162 963269	NINA KUZNECOVA	{"phone": "+70773626941"}
0005434067094	AA9732	4910 487984	LYUBOV VOLKOVA	{"phone": "+70145934759"}
0005434067095	9D4546	9556 713350	VALERIYA ORLOVA	{"email": "orlova_v-031985@postgrespro.ru", "phone": "+70173767012"}
0005434067096	16508A	8188 451307	MAKSIM SMIRNOV	{"phone": "+70851314570"}
0005434067097	16508A	5361 051161	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov_1978@postgrespro.ru", "phone": "+70679943810"}
0005434067098	7C529E	5614 379392	ELENA MOROZOVA	{"email": "e_morozova_021974@postgrespro.ru", "phone": "+70920205697"}
0005434067099	7C529E	0207 709413	SERGEY KARPOV	{"email": "karpov-sergey051974@postgrespro.ru", "phone": "+70515369060"}
0005434067100	E5FFFC	8734 363832	NINA TROFIMOVA	{"email": "trofimova_n.021976@postgrespro.ru", "phone": "+70803236040"}
0005434067101	718D80	4905 059766	NATALYA PETROVA	{"phone": "+70817702103"}
0005434067102	1C2DC0	1602 243237	VLADIMIR KAZAKOV	{"phone": "+70007040462"}
0005434067103	1C2DC0	2847 573057	GALIYA TIKHONOVA	{"email": "tikhonova_g-021974@postgrespro.ru", "phone": "+70218317005"}
0005434067104	E44C74	0376 823805	ELENA ZAKHAROVA	{"email": "zakharova.e_021980@postgrespro.ru", "phone": "+70180668816"}
0005434067105	E4101C	5827 814759	ELIZAVETA SMIRNOVA	{"email": "smirnova.elizaveta-111976@postgrespro.ru", "phone": "+70533816784"}
0005434067106	531D36	7009 966503	ALEKSANDRA VASILEVA	{"email": "vasileva.a1984@postgrespro.ru", "phone": "+70163086220"}
0005434067107	9FD6B7	0716 659325	VALENTINA SCHERBAKOVA	{"phone": "+70703102684"}
0005434067108	9FD6B7	4582 563155	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya.101966@postgrespro.ru", "phone": "+70468393149"}
0005434067109	9FD6B7	9018 641908	YULIYA NESTEROVA	{"phone": "+70313594737"}
0005434067110	80AFE2	3926 193042	TATYANA IVANOVA	{"email": "ivanovatatyana1976@postgrespro.ru", "phone": "+70422237480"}
0005434067111	A507E7	2671 766323	IRINA MAKAROVA	{"email": "imakarova.07101964@postgrespro.ru", "phone": "+70598388333"}
0005434067112	3A228A	2692 435081	ALENA YUDINA	{"phone": "+70045800459"}
0005434067113	1C31F8	8674 654893	ANASTASIYA LAZAREVA	{"email": "anastasiya-lazareva021979@postgrespro.ru", "phone": "+70774338862"}
0005434067114	1C31F8	6882 821106	TATYANA KAZAKOVA	{"phone": "+70385422420"}
0005434067115	F873CE	2682 584522	SERGEY SOKOLOV	{"email": "sergey-sokolov071980@postgrespro.ru", "phone": "+70150596441"}
0005434067116	9D3785	9338 448910	KONSTANTIN IVANOV	{"phone": "+70024911842"}
0005434067117	9D3785	6504 684121	VLADIMIR KOZLOV	{"email": "vladimirkozlov.19061978@postgrespro.ru", "phone": "+70185311112"}
0005434067118	48A1AF	7771 835406	VLADIMIR GORBUNOV	{"phone": "+70908010093"}
0005434067119	DDD55C	6340 823771	LYUBOV ANISIMOVA	{"email": "l.anisimova.1964@postgrespro.ru", "phone": "+70175391774"}
0005434067120	DDD55C	8738 140063	NATALYA MOROZOVA	{"phone": "+70218864661"}
0005434067121	0D3F30	1885 095615	TATYANA VASILEVA	{"phone": "+70705913223"}
0005434067122	C15C69	6265 882106	ELENA BELYAEVA	{"email": "elena_belyaeva.1975@postgrespro.ru", "phone": "+70702413323"}
0005434067123	22A2A0	6313 707644	ALEKSANDR MIKHAYLOV	{"phone": "+70240507487"}
0005434067124	A3A6D2	7806 006191	ALEKSEY SIDOROV	{"email": "a-sidorov_121974@postgrespro.ru", "phone": "+70529883972"}
0005434067125	A3A6D2	1680 576685	VITALIY GUSEV	{"phone": "+70988245140"}
0005434067126	7B7EA5	3086 401804	ILYA KOZLOV	{"phone": "+70417091246"}
0005434067127	3B76A5	4496 160781	SANIYA OSIPOVA	{"email": "s_osipova.081966@postgrespro.ru", "phone": "+70866222543"}
0005434067128	F5EC66	5805 186106	TAMARA KONOVALOVA	{"email": "konovalova.t-12101962@postgrespro.ru", "phone": "+70460625742"}
0005434067129	F5EC66	6394 237684	OLGA TITOVA	{"email": "olgatitova.011975@postgrespro.ru", "phone": "+70786851929"}
0005434067130	07104C	7246 044205	EKATERINA STEPANOVA	{"email": "e_stepanova.1968@postgrespro.ru", "phone": "+70469599761"}
0005434067131	605DFA	0288 736820	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr111971@postgrespro.ru", "phone": "+70070614318"}
0005434067132	605DFA	6913 046660	EVDOKIYA NOVIKOVA	{"email": "novikova_e-04071961@postgrespro.ru", "phone": "+70811397721"}
0005434067133	40B35B	7033 609046	KSENIYA MIKHAYLOVA	{"email": "kmikhaylova_08071986@postgrespro.ru", "phone": "+70582533724"}
0005434067134	1F4DA1	1559 213939	ARTEM ZHUKOV	{"phone": "+70989318683"}
0005434067135	AD1DCC	8403 420384	OLGA STEPANOVA	{"phone": "+70778963131"}
0005434067136	AD1DCC	1500 416124	INNA KOROLEVA	{"phone": "+70685355617"}
0005434067137	FD4CCC	2016 995743	VLADIMIR ABRAMOV	{"phone": "+70837519105"}
0005434067138	FD4CCC	8689 645271	NATALYA IVANOVA	{"phone": "+70805635133"}
0005434067139	FD4CCC	5306 791689	MIKHAIL BONDARENKO	{"email": "m-bondarenko.1981@postgrespro.ru", "phone": "+70356099716"}
0005434067140	66D1BD	4934 448414	RUMIYA BORISOVA	{"phone": "+70471681475"}
0005434067141	447272	6084 208667	MAKSIM MEDVEDEV	{"email": "m-medvedev1973@postgrespro.ru", "phone": "+70091802834"}
0005434067142	447272	1473 868964	ANTONINA FILATOVA	{"phone": "+70165720125"}
0005434067143	ADD956	4602 476519	VERA KAZAKOVA	{"email": "verakazakova121961@postgrespro.ru", "phone": "+70819068714"}
0005434067144	ADD956	2547 947128	IGOR SAVELEV	{"phone": "+70811663462"}
0005434067145	CF66A9	3391 496694	EVGENIY IVANOV	{"phone": "+70008399060"}
0005434067146	FF8553	3573 744024	ANTONINA KOZLOVA	{"email": "kozlova-a.1983@postgrespro.ru", "phone": "+70298274727"}
0005434067147	5986D4	8281 504889	MARIYA GERASIMOVA	{"email": "gerasimova_m-1975@postgrespro.ru", "phone": "+70525409738"}
0005434067148	CD29C1	8753 693375	KIRILL VLASOV	{"phone": "+70644926462"}
0005434067149	D1C9B3	7723 178420	GALINA ZAKHAROVA	{"email": "zakharova.g_15011971@postgrespro.ru", "phone": "+70758511815"}
0005434067150	62B0CC	2005 479182	LYUDMILA KISELEVA	{"phone": "+70659085167"}
0005434067151	6BB623	9949 450390	NIKITA ZAKHAROV	{"phone": "+70168100041"}
0005434067152	56DBB6	0933 724665	GALINA VOROBEVA	{"phone": "+70746891493"}
0005434067153	56DBB6	7150 734988	LYUBOV SEMENOVA	{"phone": "+70530183669"}
0005434067154	6C77C0	0842 441615	VYACHESLAV GUSEV	{"phone": "+70444609999"}
0005434067155	717BEB	5844 599925	OLGA MAKAROVA	{"email": "makarova-olga-021968@postgrespro.ru", "phone": "+70505872785"}
0005434067156	514577	6798 406512	DIANA ALEKSEEVA	{"phone": "+70788389678"}
0005434067157	95146F	4193 472408	EKATERINA CHERNOVA	{"email": "echernova.12101966@postgrespro.ru", "phone": "+70576263743"}
0005434067158	523D52	7489 374020	LIDIYA MALYSHEVA	{"phone": "+70961611011"}
0005434067159	C3374B	0989 023557	VLADIMIR ZAYCEV	{"phone": "+70393177544"}
0005434067160	44CB64	5269 939148	DMITRIY PETROV	{"phone": "+70068630871"}
0005434067161	44CB64	6643 715779	DMITRIY SOROKIN	{"email": "sorokin.d-1969@postgrespro.ru", "phone": "+70965836970"}
0005434067162	BEFD8D	0054 316804	ANTONINA KONOVALOVA	{"phone": "+70429587197"}
0005434067163	D4E78F	3088 890171	ELENA MIKHAYLOVA	{"phone": "+70174734323"}
0005434067164	FC3C91	9473 128646	EGOR MELNIKOV	{"email": "egor_melnikov-1974@postgrespro.ru", "phone": "+70323663920"}
0005434067165	FC3C91	2432 897502	LARISA ANISIMOVA	{"phone": "+70684990323"}
0005434067166	FC3C91	2710 909385	ILYA IVANOV	{"phone": "+70294652474"}
0005434067167	92FB4E	8667 652905	ALEKSEY MIRONOV	{"phone": "+70588501379"}
0005434067168	92FB4E	7591 458560	VALENTINA ALEKSANDROVA	{"phone": "+70214478663"}
0005434067169	3CFEA2	0081 650425	RUZALIYA DENISOVA	{"phone": "+70373034720"}
0005434067170	B16B88	9286 672691	LYUDMILA EFIMOVA	{"phone": "+70801308631"}
0005434067171	512E5F	2565 837679	FARID PAVLOV	{"email": "faridpavlov_1982@postgrespro.ru", "phone": "+70072285616"}
0005434067172	512E5F	4397 957143	MARIYA YUDINA	{"email": "mariya-yudina_19101983@postgrespro.ru", "phone": "+70511768188"}
0005434067173	2AA7A4	5887 551856	NINA KOROLEVA	{"phone": "+70295312637"}
0005434067174	C5524E	5715 649462	LIDIYA BOGDANOVA	{"phone": "+70358856612"}
0005434067175	238BF5	8817 217238	SEMEN BONDARENKO	{"email": "s.bondarenko1978@postgrespro.ru", "phone": "+70365786805"}
0005434067176	179C65	9069 978097	NIKITA MIKHAYLOV	{"phone": "+70805590618"}
0005434067177	179C65	2764 809221	SVETLANA PETROVA	{"email": "petrova.svetlana1983@postgrespro.ru", "phone": "+70238389673"}
0005434067178	C94073	6896 860002	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr111967@postgrespro.ru", "phone": "+70265931268"}
0005434067179	6DF54B	2761 008689	STANISLAV DENISOV	{"phone": "+70733267135"}
0005434067180	5B006B	8195 982361	VLADISLAV PETROV	{"email": "vpetrov.1959@postgrespro.ru", "phone": "+70491191256"}
0005434067181	BBBCD7	2092 232806	LYUDMILA POTAPOVA	{"phone": "+70793905709"}
0005434067182	BBBCD7	5409 481519	IRINA TARASOVA	{"email": "tarasovairina-24011980@postgrespro.ru", "phone": "+70636427939"}
0005434067183	10A67F	6487 632675	ANDREY BELOV	{"phone": "+70555718487"}
0005434067184	C3CA50	1700 784836	ALEKSANDR BORISOV	{"phone": "+70655070985"}
0005434067185	BAE9F1	8789 583578	GENNADIY POPOV	{"email": "popov.g.111977@postgrespro.ru", "phone": "+70646354628"}
0005434067186	664B9A	3676 749195	ROMAN DMITRIEV	{"email": "dmitriev_roman_1969@postgrespro.ru", "phone": "+70087112217"}
0005434067187	CB309C	1023 321010	YURIY SIDOROV	{"email": "y_sidorov-31011978@postgrespro.ru", "phone": "+70443473139"}
0005434067188	CB309C	1846 773899	SERGEY DENISOV	{"phone": "+70402303872"}
0005434067189	F56918	6557 279353	ALEKSANDR NOVIKOV	{"phone": "+70953070713"}
0005434067190	C7E06C	4222 190009	KRISTINA KUZNECOVA	{"email": "kuznecovak_06101965@postgrespro.ru", "phone": "+70846576596"}
0005434067191	C7E06C	8140 123855	YURIY KOZLOV	{"phone": "+70619537206"}
0005434067192	8B9A57	4862 870019	INESSA KOROLEVA	{"email": "ikoroleva031980@postgrespro.ru", "phone": "+70716867011"}
0005434067193	3F0096	2853 252101	DMITRIY BORISOV	{"email": "dborisov-101972@postgrespro.ru", "phone": "+70331444886"}
0005434067194	7A2660	9562 918922	SVETLANA ZHUKOVA	{"phone": "+70434095464"}
0005434067195	36787D	3755 423020	VASILIY AFANASEV	{"phone": "+70891081808"}
0005434067196	D70CEF	2695 867189	NINA GUSEVA	{"email": "guseva-n_1970@postgrespro.ru", "phone": "+70870254640"}
0005434067197	D70CEF	7928 877127	ELENA NAZAROVA	{"phone": "+70658753511"}
0005434067198	430DE4	6188 967756	GALINA ORLOVA	{"phone": "+70954728832"}
0005434067199	430DE4	2603 322507	NIKOLAY BORISOV	{"email": "borisov_nikolay24111968@postgrespro.ru", "phone": "+70580224194"}
0005434067200	430DE4	9367 629178	STANISLAV IVANOV	{"email": "stanislav-ivanov011972@postgrespro.ru", "phone": "+70153862668"}
0005434067201	B8BA61	9919 450049	IRINA STEPANOVA	{"email": "stepanova.i-1970@postgrespro.ru", "phone": "+70139101259"}
0005434067202	B8BA61	6850 374044	VALENTINA VOLKOVA	{"email": "vvolkova.1982@postgrespro.ru", "phone": "+70807385394"}
0005434067203	F2067E	6027 510895	VLADIMIR MEDVEDEV	{"phone": "+70457970028"}
0005434067204	7259D5	3507 068809	KRISTINA ALEKSEEVA	{"email": "kristinaalekseeva.1982@postgrespro.ru", "phone": "+70283159476"}
0005434067205	7061EB	3033 627026	ZOYA ZAKHAROVA	{"phone": "+70832566407"}
0005434067206	9445F4	5181 763092	ANATOLIY DAVYDOV	{"phone": "+70148420728"}
0005434067207	5B557F	0454 142540	TATYANA BARANOVA	{"email": "tatyanabaranova_101968@postgrespro.ru", "phone": "+70954541250"}
0005434067208	7BA5F0	5152 060402	NINA POLYAKOVA	{"email": "polyakova-nina-1969@postgrespro.ru", "phone": "+70683271438"}
0005434067209	7BA5F0	7825 679396	LYUDMILA MIKHAYLOVA	{"email": "mikhaylovalyudmila-121971@postgrespro.ru", "phone": "+70825983655"}
0005434067210	A954FB	7203 770588	SVETLANA GUSEVA	{"phone": "+70253797322"}
0005434067211	2D0C80	3025 801149	NADEZHDA ALEKSEEVA	{"email": "alekseeva-n-04091970@postgrespro.ru", "phone": "+70437791002"}
0005434067212	858AE1	0303 109561	TATYANA BELYAEVA	{"phone": "+70972389919"}
0005434067213	347976	2633 776963	POLINA KUDRYASHOVA	{"phone": "+70753370793"}
0005434067214	FE0E16	6345 807789	ROMAN NAUMOV	{"phone": "+70871241975"}
0005434067215	8272E9	1587 405040	IRINA YUDINA	{"email": "yudina-i_1964@postgrespro.ru", "phone": "+70467074406"}
0005434067216	51E752	9831 476226	YULIYA SEMENOVA	{"phone": "+70469236647"}
0005434067217	51E752	1268 107829	ALEKSANDR MOISEEV	{"email": "moiseevaleksandr.01051968@postgrespro.ru", "phone": "+70885450428"}
0005434067218	7D777E	4397 442509	OLEG SIDOROV	{"email": "oleg-sidorov.1966@postgrespro.ru", "phone": "+70189471835"}
0005434067219	78E5D5	8334 672820	IRINA VLASOVA	{"email": "i.vlasova.1972@postgrespro.ru", "phone": "+70545392334"}
0005434067220	78E5D5	3282 998868	ELENA VOROBEVA	{"phone": "+70550878467"}
0005434067221	F2A686	7964 321307	ELENA DMITRIEVA	{"email": "dmitrieva_e1973@postgrespro.ru", "phone": "+70829528709"}
0005434067222	F2A686	0048 614141	EVELINA KUZNECOVA	{"phone": "+70572208108"}
0005434067223	107EEC	4122 182347	SVETLANA BOGDANOVA	{"phone": "+70743678489"}
0005434067224	2171E6	1960 986514	IRINA ABRAMOVA	{"email": "abramovairina_071977@postgrespro.ru", "phone": "+70837581695"}
0005434067225	4008F5	4847 362243	GALINA MATVEEVA	{"phone": "+70140004208"}
0005434067226	4008F5	2947 576455	ALBINA VLASOVA	{"email": "vlasova-a.051981@postgrespro.ru", "phone": "+70359460248"}
0005434067227	4008F5	3780 012872	SVETLANA NIKITINA	{"phone": "+70983140153"}
0005434067228	F3D6C7	6299 726000	VLADISLAV ZAYCEV	{"phone": "+70648313154"}
0005434067229	F3D6C7	8973 210669	YAROSLAV VASILEV	{"email": "vasilev-y_111982@postgrespro.ru", "phone": "+70654656198"}
0005434067230	23C3D2	4166 964817	SERGEY KOZLOV	{"phone": "+70133368136"}
0005434067231	018CB6	5867 410123	VLADISLAV KUZNECOV	{"email": "vladislavkuznecov-04021967@postgrespro.ru", "phone": "+70940208960"}
0005434067232	55357A	4699 015508	PETR SCHERBAKOV	{"email": "scherbakov_p-051966@postgrespro.ru", "phone": "+70054928285"}
0005434067233	692190	0661 709221	VALERIY BORISOV	{"phone": "+70799581822"}
0005434067234	692190	9450 319591	OLGA STEPANOVA	{"phone": "+70401641874"}
0005434067235	D00571	9150 859101	ALEKSANDRA EFIMOVA	{"email": "aleksandra-efimova-021968@postgrespro.ru", "phone": "+70266163067"}
0005434067236	ECE944	2937 023621	KRISTINA OSIPOVA	{"email": "osipovak_1973@postgrespro.ru", "phone": "+70355856009"}
0005434067237	D21C26	4801 430833	RIMMA VASILEVA	{"phone": "+70513302386"}
0005434067238	B3BD33	6888 368153	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr.1971@postgrespro.ru", "phone": "+70233495688"}
0005434067239	4782C0	2836 120983	VALERIY KUZMIN	{"email": "v.kuzmin.1985@postgrespro.ru", "phone": "+70680499672"}
0005434067240	95A2A5	0586 968071	NINA ROMANOVA	{"phone": "+70471538988"}
0005434067241	12264F	4811 379561	EVGENIY ZHUKOV	{"email": "ezhukov_1976@postgrespro.ru", "phone": "+70682548953"}
0005434067242	1389B9	1735 729616	VALENTINA FROLOVA	{"phone": "+70608911912"}
0005434067243	1389B9	2194 599455	ALEKSANDR MATVEEV	{"phone": "+70827081600"}
0005434067244	1389B9	3293 501567	NATALYA STEPANOVA	{"email": "nstepanova1972@postgrespro.ru", "phone": "+70433407704"}
0005434067245	6EA8B0	5505 464572	RUSLAN VOLKOV	{"email": "ruslan.volkov_11011972@postgrespro.ru", "phone": "+70752914498"}
0005434067246	6BF91F	5720 348918	ALEKSANDR DENISOV	{"phone": "+70149753229"}
0005434067247	D62705	3567 110480	NATALYA SOLOVEVA	{"email": "solovevanatalya_10061964@postgrespro.ru", "phone": "+70386487516"}
0005434067248	8483C2	6372 782443	NATALYA MIKHAYLOVA	{"phone": "+70354329624"}
0005434067249	8483C2	8349 418662	NIKOLAY SOROKIN	{"email": "nikolaysorokin-23041970@postgrespro.ru", "phone": "+70245075287"}
0005434067250	6B727F	2374 635480	ARTEM VOROBEV	{"email": "avorobev_1973@postgrespro.ru", "phone": "+70388245575"}
0005434067251	5C6160	3043 462369	LYUDMILA SEMENOVA	{"phone": "+70628015509"}
0005434067252	C62D89	0493 517853	MARIYA IVANOVA	{"email": "m_ivanova_1965@postgrespro.ru", "phone": "+70949748063"}
0005434067253	419E42	0677 418108	ALEKSEY KUZNECOV	{"phone": "+70293242365"}
0005434067254	419E42	3941 014659	ALEKSANDR EGOROV	{"phone": "+70049270818"}
0005434067255	78E7CA	8781 832862	MARIYA KOROLEVA	{"phone": "+70296355812"}
0005434067256	9B1E26	0733 194874	GENNADIY BORISOV	{"email": "borisov_gennadiy_15121976@postgrespro.ru", "phone": "+70312895936"}
0005434067257	776DFC	4717 103007	ANDREY PETROV	{"email": "andrey_petrov111969@postgrespro.ru", "phone": "+70759593056"}
0005434067258	8DC0B8	9178 553771	ALEKSANDR GORBUNOV	{"phone": "+70772586736"}
0005434067259	111A75	7913 243948	PAVEL ZAKHAROV	{"phone": "+70770273285"}
0005434067260	931218	6690 844388	VALERIY SERGEEV	{"email": "valeriy_sergeev091974@postgrespro.ru", "phone": "+70138735628"}
0005434067261	931218	9169 164344	LARISA MIKHAYLOVA	{"phone": "+70331173279"}
0005434067262	8178F9	3635 219105	LYUDMILA ROMANOVA	{"email": "lyudmila-romanova_03091971@postgrespro.ru", "phone": "+70374412772"}
0005434067263	4A2E6E	9451 052645	VLADIMIR FEDOTOV	{"phone": "+70888809856"}
0005434067264	4A2E6E	1309 623624	ALEKSANDR KUDRYASHOV	{"email": "aleksandr.kudryashov-1975@postgrespro.ru", "phone": "+70381501535"}
0005434067265	4A2E6E	1193 219080	TATYANA FROLOVA	{"phone": "+70664794654"}
0005434067266	E69A08	1684 798542	ALLA GRISHINA	{"email": "agrishina-1967@postgrespro.ru", "phone": "+70899820599"}
0005434067267	B20F2D	8701 651037	SVETLANA MOISEEVA	{"email": "svetlana.moiseeva05091972@postgrespro.ru", "phone": "+70174460207"}
0005434067268	B20F2D	6999 898651	VLADIMIR ZAYCEV	{"phone": "+70717336898"}
0005434067269	A7B28D	1723 752453	DMITRIY BELOV	{"email": "belov_dmitriy_20091970@postgrespro.ru", "phone": "+70548461132"}
0005434067270	D404B7	4897 789918	ANDREY MOROZOV	{"phone": "+70264940211"}
0005434067271	D404B7	6330 332326	ROZA ANTONOVA	{"email": "antonova_roza.1969@postgrespro.ru", "phone": "+70816974677"}
0005434067272	96F0F8	9621 872785	OLGA ARKHIPOVA	{"phone": "+70964101782"}
0005434067273	854960	4310 913251	ALEKSEY DAVYDOV	{"email": "davydov_aleksey03091973@postgrespro.ru", "phone": "+70417948687"}
0005434067274	BEBDE1	6300 847812	MIKHAIL KOZLOV	{"email": "kozlov-mikhail_061972@postgrespro.ru", "phone": "+70787013882"}
0005434067275	90DA30	0025 437098	DMITRIY GERASIMOV	{"email": "d.gerasimov.011976@postgrespro.ru", "phone": "+70000214429"}
0005434067276	ACF4E9	5203 025838	ROBERT PAVLOV	{"phone": "+70398012604"}
0005434067277	ACF4E9	0051 822180	VALENTINA AKIMOVA	{"email": "v-akimova_1972@postgrespro.ru", "phone": "+70615617653"}
0005434067278	ACF4E9	5796 176882	ANDREY SERGEEV	{"email": "andreysergeev_071980@postgrespro.ru", "phone": "+70351924790"}
0005434067279	3913C8	9840 014762	VLADIMIR YAKOVLEV	{"phone": "+70003922703"}
0005434067280	3913C8	4450 462506	LYUDMILA TROFIMOVA	{"email": "l_trofimova1971@postgrespro.ru", "phone": "+70471273458"}
0005434067281	604899	8915 210761	LYUDMILA PETROVA	{"phone": "+70199518603"}
0005434067282	CBFE69	6998 142935	ANISA SCHERBAKOVA	{"email": "anisascherbakova.14051977@postgrespro.ru", "phone": "+70681275743"}
0005434067283	CBFE69	7384 419605	IGOR GAVRILOV	{"email": "gavrilovi101980@postgrespro.ru", "phone": "+70231045702"}
0005434067284	15DDE6	1085 033205	TATYANA IVANOVA	{"email": "ivanova-tatyana-091976@postgrespro.ru", "phone": "+70336682539"}
0005434067285	15DDE6	9301 854735	NADEZHDA PETROVA	{"email": "petrova_nadezhda-10101969@postgrespro.ru", "phone": "+70045322429"}
0005434067286	15DDE6	1889 190453	IVAN ROMANOV	{"email": "romanov.i.1982@postgrespro.ru", "phone": "+70720800193"}
0005434067287	B3A7D0	4792 215844	ALEKSANDR VASILEV	{"phone": "+70066246352"}
0005434067288	93D602	1295 638577	MARIYA BELOVA	{"phone": "+70839765346"}
0005434067289	734DDC	1907 171636	ELENA SIDOROVA	{"phone": "+70044786732"}
0005434067290	2BA513	7775 754766	OLGA TIMOFEEVA	{"email": "o.timofeeva.1981@postgrespro.ru", "phone": "+70279005470"}
0005434067291	B11790	6616 807442	ANDREY SEMENOV	{"email": "semenov_andrey-20081974@postgrespro.ru", "phone": "+70240489644"}
0005434067292	B11790	4805 901790	DINARA ANISIMOVA	{"phone": "+70496250006"}
0005434067293	B99CE4	2781 615042	MIKHAIL FEDOTOV	{"email": "mikhail.fedotov021977@postgrespro.ru", "phone": "+70562024587"}
0005434067294	019599	9735 830352	OLGA MIRONOVA	{"email": "o.mironova1962@postgrespro.ru", "phone": "+70924949704"}
0005434067295	019599	8846 451957	EKATERINA MAKAROVA	{"email": "makarova.ekaterina_041963@postgrespro.ru", "phone": "+70361997583"}
0005434067296	AA1D9D	2397 053208	GRIGORIY NIKOLAEV	{"email": "nikolaev.g28091979@postgrespro.ru", "phone": "+70070116045"}
0005434067297	178F79	4383 018190	MARGARITA SOLOVEVA	{"email": "soloveva_margarita09061976@postgrespro.ru", "phone": "+70134734151"}
0005434067298	2C3DF0	9515 368776	EKATERINA KUZNECOVA	{"email": "kuznecova_e031975@postgrespro.ru", "phone": "+70125659030"}
0005434067299	40D5A4	1632 644922	ANTONINA ROMANOVA	{"email": "antonina.romanova30081970@postgrespro.ru", "phone": "+70938247948"}
0005434067300	3AC0E6	4800 258433	VLADIMIR NOVIKOV	{"email": "novikov.v.041966@postgrespro.ru", "phone": "+70215770806"}
0005434067301	106C6A	6311 587436	VLADISLAV PAVLOV	{"phone": "+70421134006"}
0005434067302	106C6A	5034 929770	LYUDMILA GAVRILOVA	{"email": "gavriloval091967@postgrespro.ru", "phone": "+70333901828"}
0005434067303	525EFB	8999 020886	ANVAR VOLKOV	{"email": "anvar.volkov1976@postgrespro.ru", "phone": "+70217534149"}
0005434067304	525EFB	9042 482828	ALEKSANDRA ZAKHAROVA	{"email": "zakharovaaleksandra_1962@postgrespro.ru", "phone": "+70334403794"}
0005434067305	785EC2	1142 774405	IVAN ORLOV	{"email": "orlov_ivan.1966@postgrespro.ru", "phone": "+70593179152"}
0005434067306	093FC1	6680 657456	ANDREY GRIGOREV	{"phone": "+70759225538"}
0005434067307	369F1E	2335 964404	TATYANA KOROLEVA	{"email": "tatyana-koroleva031967@postgrespro.ru", "phone": "+70126830799"}
0005434067308	369F1E	2529 346942	SERGEY GORBUNOV	{"phone": "+70430306197"}
0005434067309	313048	8577 235656	PETR SEMENOV	{"phone": "+70940078681"}
0005434067310	C403E2	2140 217908	NATALYA VOLKOVA	{"phone": "+70882008307"}
0005434067311	5779E5	8796 450608	ALEKSEY ZAYCEV	{"email": "zayceva_071971@postgrespro.ru", "phone": "+70839663449"}
0005434067312	5779E5	2534 845902	MARIYA SEMENOVA	{"phone": "+70522821481"}
0005434067313	52833B	3752 571762	GENNADIY BORISOV	{"email": "g-borisov-1977@postgrespro.ru", "phone": "+70030202104"}
0005434067314	52833B	5888 571056	LARISA IVANOVA	{"email": "larisa.ivanova.05021976@postgrespro.ru", "phone": "+70763952872"}
0005434067315	BE39F5	0511 291169	VALENTINA DAVYDOVA	{"phone": "+70431283334"}
0005434067316	BE39F5	1185 630077	ELENA MAKAROVA	{"phone": "+70641021773"}
0005434067317	07C049	0249 112257	NADEZHDA BELYAEVA	{"phone": "+70262000254"}
0005434067318	07C049	0850 665057	GALINA KUZNECOVA	{"phone": "+70610767990"}
0005434067319	9248F1	2034 974914	SERGEY RODIONOV	{"email": "sergeyrodionov.16011971@postgrespro.ru", "phone": "+70854558011"}
0005434067320	1DE29D	2853 039825	SERGEY STEPANOV	{"phone": "+70089516000"}
0005434067321	CE9488	4930 499472	VALENTINA NIKITINA	{"email": "valentinanikitina.041972@postgrespro.ru", "phone": "+70396949408"}
0005434067322	211B82	1539 924969	TATYANA MOROZOVA	{"phone": "+70040605653"}
0005434067323	E0634B	1727 625317	DANILA MOISEEV	{"phone": "+70394460059"}
0005434067324	E0634B	2259 948487	OLEG ZAYCEV	{"phone": "+70422945026"}
0005434067325	04AE53	2465 839394	ANATOLIY ILIN	{"email": "anatoliy.ilin091966@postgrespro.ru", "phone": "+70965570953"}
0005434067326	CB65E8	6735 235128	MATVEY ILIN	{"phone": "+70719326840"}
0005434067327	E0C6CE	7352 168148	VERA FILIPPOVA	{"phone": "+70269660961"}
0005434067328	E65ED6	6379 721516	VYACHESLAV IVANOV	{"email": "vyacheslav_ivanov_111976@postgrespro.ru", "phone": "+70285580113"}
0005434067329	49AD58	7982 259871	OLEG FILIPPOV	{"email": "o_filippov121975@postgrespro.ru", "phone": "+70953053424"}
0005434067330	49AD58	9108 432138	SERGEY KAZAKOV	{"phone": "+70791461853"}
0005434067331	925158	6254 744909	MARGARITA NAZAROVA	{"email": "nazarova.margarita-29111982@postgrespro.ru", "phone": "+70147711323"}
0005434067332	925158	3872 413282	KSENIYA NAZAROVA	{"phone": "+70060078206"}
0005434067333	AE99F4	2028 890952	ANASTASIYA AKIMOVA	{"phone": "+70368759391"}
0005434067334	43E1CD	5126 258489	NINA ANTONOVA	{"email": "antonova.nina_1969@postgrespro.ru", "phone": "+70244268328"}
0005434067335	3404F4	5093 818699	YAROSLAV SHEVCHENKO	{"email": "y_shevchenko-081960@postgrespro.ru", "phone": "+70941628788"}
0005434067336	A6E9A7	8944 409793	ELENA FEDOROVA	{"email": "elena_fedorova.1972@postgrespro.ru", "phone": "+70494311287"}
0005434067337	495035	4673 171843	ALEKSEY KRASNOV	{"email": "a_krasnov_20101970@postgrespro.ru", "phone": "+70666422858"}
0005434067338	495035	3820 623344	IVAN MAKAROV	{"email": "i.makarov.081978@postgrespro.ru", "phone": "+70475792110"}
0005434067339	ED6FE0	0879 411287	MARIYA POPOVA	{"phone": "+70928831946"}
0005434067340	15F415	2320 093832	ILYA PAVLOV	{"email": "i-pavlov.1974@postgrespro.ru", "phone": "+70211410476"}
0005434067341	CAAEDF	8912 515706	VIKTOR PAVLOV	{"phone": "+70166230980"}
0005434067342	47CAF4	1454 629738	ELENA ZAKHAROVA	{"phone": "+70875771715"}
0005434067343	6C0652	8769 286424	ALEKSANDR PETROV	{"email": "apetrov.1972@postgrespro.ru", "phone": "+70780844530"}
0005434067344	875762	8362 953270	GRIGORIY SCHERBAKOV	{"phone": "+70997119602"}
0005434067345	875762	0429 812550	PAVEL MEDVEDEV	{"phone": "+70920473801"}
0005434067346	20674A	3973 286121	YAKOV PAVLOV	{"phone": "+70281464252"}
0005434067347	8E4B3C	0760 708660	TATYANA FILATOVA	{"phone": "+70147818452"}
0005434067348	D3D043	9477 694143	VALERIY VLASOV	{"email": "vlasovvaleriy-071976@postgrespro.ru", "phone": "+70864195481"}
0005434067349	D3D043	0768 779693	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov081974@postgrespro.ru", "phone": "+70346542566"}
0005434067350	40D20F	2953 931487	ALEKSEY PETROV	{"email": "petrov.a1968@postgrespro.ru", "phone": "+70985877673"}
0005434067351	FE3A87	5930 466479	ILYA ORLOV	{"email": "orlov-i_031980@postgrespro.ru", "phone": "+70611059082"}
0005434067352	B33D1D	8011 484972	VLADIMIR MARTYNOV	{"phone": "+70887396301"}
0005434067353	24926B	4639 981875	ANDREY STEPANOV	{"email": "stepanov.andrey_09021985@postgrespro.ru", "phone": "+70993766968"}
0005434067354	0B9651	9905 848633	ALEKSANDR TARASOV	{"email": "a.tarasov1971@postgrespro.ru", "phone": "+70896314842"}
0005434067355	0B9651	1088 358209	NATALYA FROLOVA	{"email": "frolova.natalya-031979@postgrespro.ru", "phone": "+70897862348"}
0005434067356	2BC038	4185 061493	ALEKSANDR KOZLOV	{"phone": "+70078489300"}
0005434067357	ED7802	0425 904865	EVELINA VASILEVA	{"email": "vasileva.e.021976@postgrespro.ru", "phone": "+70658605303"}
0005434067358	93E4F8	7704 827332	LYUDMILA PETROVA	{"email": "petroval_19091975@postgrespro.ru", "phone": "+70140032773"}
0005434067359	CB2AD9	7053 948425	TATYANA ZAKHAROVA	{"email": "zakharova_t-1971@postgrespro.ru", "phone": "+70905910695"}
0005434067360	51EE31	5587 849923	ANNA SIDOROVA	{"phone": "+70076663185"}
0005434067361	B0A6AB	2084 380275	LIDIYA VOROBEVA	{"email": "l.vorobeva1963@postgrespro.ru", "phone": "+70358161096"}
0005434067362	F98FEF	1113 437825	ANDREY MIKHAYLOV	{"email": "mikhaylov_andrey.011976@postgrespro.ru", "phone": "+70887322709"}
0005434067363	162EA3	3952 391965	MIKHAIL MARTYNOV	{"email": "martynov_m_071979@postgrespro.ru", "phone": "+70646608176"}
0005434067364	C27C31	1705 401961	YURIY DENISOV	{"email": "yuriy_denisov.031968@postgrespro.ru", "phone": "+70293619940"}
0005434067365	AB9412	1634 540386	KLAVDIYA VOLKOVA	{"phone": "+70825244462"}
0005434067366	B7B215	0763 433651	NINA SOROKINA	{"email": "nina_sorokina.13081962@postgrespro.ru", "phone": "+70991745376"}
0005434067367	A65D70	4705 109180	EKATERINA FOMINA	{"email": "ekaterina-fomina-1977@postgrespro.ru", "phone": "+70946119868"}
0005434067368	A65D70	9468 162061	MARIYA VOLKOVA	{"email": "mariyavolkova.071969@postgrespro.ru", "phone": "+70085885020"}
0005434067369	139EF6	4355 683763	MIKHAIL ZAKHAROV	{"email": "zakharov-mikhail091971@postgrespro.ru", "phone": "+70213872793"}
0005434067370	DF0C0B	0955 353431	ANATOLIY SOROKIN	{"email": "sorokin.a.1973@postgrespro.ru", "phone": "+70404824611"}
0005434067428	CCB50D	6192 884261	SOFYA NAZAROVA	{"phone": "+70282505539"}
0005434067371	53F40F	7878 629602	TATYANA KULIKOVA	{"email": "kulikova.t.20091976@postgrespro.ru", "phone": "+70191696930"}
0005434067372	596025	5031 765206	VALENTINA KONDRATEVA	{"email": "valentina_kondrateva-1971@postgrespro.ru", "phone": "+70661512460"}
0005434067373	A3861A	6022 772240	ALEKSEY DENISOV	{"phone": "+70988791694"}
0005434067374	A3861A	3966 726626	OKSANA VOLKOVA	{"phone": "+70563454975"}
0005434067375	E31887	0443 016267	ELENA GRISHINA	{"phone": "+70740680722"}
0005434067376	E31887	8952 971465	DENIS MARTYNOV	{"phone": "+70362396472"}
0005434067377	E31887	0076 237713	SVETLANA STEPANOVA	{"phone": "+70842831692"}
0005434067378	E39D44	1016 104137	ANDREY BARANOV	{"phone": "+70646120294"}
0005434067379	E39D44	3814 790100	MIKHAIL OSIPOV	{"email": "mikhail_osipov101975@postgrespro.ru", "phone": "+70773440822"}
0005434067380	8419F7	9155 167734	VLADIMIR ROMANOV	{"phone": "+70591664360"}
0005434067381	EE34C6	9841 366209	DMITRIY ALEKSEEV	{"email": "alekseev_dmitriy_30051974@postgrespro.ru", "phone": "+70951680099"}
0005434067382	A08A64	0545 081824	VERA ORLOVA	{"email": "vorlova11101975@postgrespro.ru", "phone": "+70502317194"}
0005434067383	A08A64	0986 620394	SVETLANA POPOVA	{"email": "popovas101961@postgrespro.ru", "phone": "+70636745423"}
0005434067384	8D6A15	7179 093436	ALEKSANDR VOLKOV	{"phone": "+70139567426"}
0005434067385	8D6A15	4237 312721	OKSANA AFANASEVA	{"phone": "+70699138027"}
0005434067386	2786A7	8548 459817	DENIS GORBUNOV	{"phone": "+70086257468"}
0005434067387	2786A7	2534 642285	GALINA ORLOVA	{"phone": "+70927734428"}
0005434067388	684E4B	3162 010442	ALEKSANDRA KULIKOVA	{"phone": "+70589569276"}
0005434067389	684E4B	3545 672005	ILSHAT ANDREEV	{"phone": "+70811016459"}
0005434067390	F704A0	7981 449081	SERGEY FEDOTOV	{"email": "fedotovs091965@postgrespro.ru", "phone": "+70197733459"}
0005434067391	E2DC74	0026 679772	VYACHESLAV ZAYCEV	{"email": "zaycev.vyacheslav.16071975@postgrespro.ru", "phone": "+70145682978"}
0005434067392	A2D87E	3591 381545	KONSTANTIN MIKHAYLOV	{"phone": "+70583396401"}
0005434067393	523304	4863 247776	LYUBOV IVANOVA	{"phone": "+70363348190"}
0005434067394	523304	8302 742265	NATALYA MOROZOVA	{"phone": "+70574664779"}
0005434067395	9B0EAC	2658 984110	PETR PETROV	{"phone": "+70195119386"}
0005434067396	610942	0468 607392	PAVEL EGOROV	{"email": "p_egorov_03071981@postgrespro.ru", "phone": "+70977718517"}
0005434067397	18EE35	1362 624653	LYUBOV EGOROVA	{"phone": "+70769358075"}
0005434067398	22EE34	8842 033706	SERGEY NIKITIN	{"phone": "+70235275097"}
0005434067399	EACA9F	0438 508716	NADEZHDA NAZAROVA	{"email": "n-nazarova.1974@postgrespro.ru", "phone": "+70912323380"}
0005434067400	A08624	4155 583678	ANTON ZHURAVLEV	{"email": "zhuravlev_a09101974@postgrespro.ru", "phone": "+70777646349"}
0005434067401	A08624	2186 995923	MIKHAIL MOROZOV	{"phone": "+70225004277"}
0005434067402	B6DFDC	3750 847654	EGOR KISELEV	{"email": "egorkiselev.1960@postgrespro.ru", "phone": "+70710789036"}
0005434067403	B21849	5015 154889	ALEKSEY MOISEEV	{"email": "aleksey.moiseev-1970@postgrespro.ru", "phone": "+70447236614"}
0005434067404	B21849	8059 078508	MAKSIM BORISOV	{"email": "m_borisov.26011983@postgrespro.ru", "phone": "+70812148905"}
0005434067405	81E763	8214 935552	ANGELINA STEPANOVA	{"email": "stepanovaangelina-1974@postgrespro.ru", "phone": "+70985764354"}
0005434067406	81E763	2020 723866	NADEZHDA IVANOVA	{"phone": "+70912499876"}
0005434067407	9FBE0B	1116 479963	VLADIMIR PETROV	{"email": "petrov-v.051974@postgrespro.ru", "phone": "+70218062751"}
0005434067408	9FBE0B	7783 494517	DARYA NAUMOVA	{"phone": "+70247209543"}
0005434067409	491B2C	4577 418692	TATYANA KUDRYASHOVA	{"email": "tatyana.kudryashova-041979@postgrespro.ru", "phone": "+70738265369"}
0005434067410	491B2C	6318 267149	VLADIMIR ZAKHAROV	{"email": "v-zakharov-1972@postgrespro.ru", "phone": "+70987839267"}
0005434067411	3FCA6C	4728 720440	LYUDMILA RYABOVA	{"phone": "+70110109625"}
0005434067412	3FCA6C	1679 893094	VITALIY ANTONOV	{"email": "antonov_v1972@postgrespro.ru", "phone": "+70058060578"}
0005434067413	F2650F	5427 037163	ROMAN IVANOV	{"email": "ivanov_r-1986@postgrespro.ru", "phone": "+70984767489"}
0005434067414	B99F4B	6795 438965	SERGEY KOZLOV	{"email": "s-kozlov.101971@postgrespro.ru", "phone": "+70640323654"}
0005434067415	43EB70	6354 533953	GALINA FROLOVA	{"phone": "+70919428337"}
0005434067416	068304	4634 268203	ALENA KONDRATEVA	{"phone": "+70288321079"}
0005434067417	111D3D	2886 718241	ALEKSANDR BORISOV	{"phone": "+70344741983"}
0005434067418	111D3D	5731 466341	KSENIYA NIKIFOROVA	{"email": "kseniya-nikiforova-1980@postgrespro.ru", "phone": "+70078164790"}
0005434067419	92C2FC	6664 084566	ANNA SMIRNOVA	{"phone": "+70424768465"}
0005434067420	EFBD1E	0123 707955	NIKOLAY ZAKHAROV	{"phone": "+70667850868"}
0005434067421	EFBD1E	2043 050370	KAMILLA ZHURAVLEVA	{"phone": "+70043464400"}
0005434067422	EFBD1E	3095 133276	RAVIL ZAKHAROV	{"phone": "+70464618194"}
0005434067423	B93375	7077 763238	NIKOLAY KUZNECOV	{"email": "kuznecov_n_061967@postgrespro.ru", "phone": "+70753500790"}
0005434067424	B93375	3218 180918	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir-01101970@postgrespro.ru", "phone": "+70464157683"}
0005434067425	E3C1E8	6318 685313	YULIYA MEDVEDEVA	{"phone": "+70971338516"}
0005434067426	E3C1E8	1109 042334	KIRA GRISHINA	{"email": "grishina_kira.27111969@postgrespro.ru", "phone": "+70095986615"}
0005434067427	661CEC	6532 170511	NATALIYA RYABOVA	{"phone": "+70116237533"}
0005434067429	CCB50D	2889 496911	ZINAIDA YUDINA	{"email": "zinaida.yudina-1962@postgrespro.ru", "phone": "+70908541136"}
0005434067430	541B8A	2580 961366	GALINA DANILOVA	{"phone": "+70704562020"}
0005434067431	65E2CF	3881 632794	ANATOLIY VLASOV	{"phone": "+70150656754"}
0005434067432	A84E04	5875 579987	VALENTINA NIKIFOROVA	{"phone": "+70271720913"}
0005434067433	A854A4	1336 803698	ELENA NIKITINA	{"email": "nikitinaelena24081977@postgrespro.ru", "phone": "+70546333835"}
0005434067434	A854A4	8106 378522	LYUBOV ZHUKOVA	{"email": "lyubov.zhukova07031972@postgrespro.ru", "phone": "+70297947692"}
0005434067435	2FE793	7887 100147	ALEKSANDRA TIMOFEEVA	{"email": "aleksandra-timofeeva.1981@postgrespro.ru", "phone": "+70968056376"}
0005434067436	2EDB02	3540 976164	ARTEM SERGEEV	{"email": "a.sergeev_30011980@postgrespro.ru", "phone": "+70165400385"}
0005434067437	704FBB	0400 202299	ELIZAVETA NIKOLAEVA	{"phone": "+70943685300"}
0005434067438	4B43E7	2396 266268	VLADIMIR ABRAMOV	{"phone": "+70341514833"}
0005434067439	4B43E7	4552 805220	FEDOR PAVLOV	{"email": "pavlovf021970@postgrespro.ru", "phone": "+70748352354"}
0005434067440	CD4D2A	7774 475432	EKATERINA IVANOVA	{"email": "ivanovae21021973@postgrespro.ru", "phone": "+70213024300"}
0005434067441	CD4D2A	4503 372280	ANASTASIYA ALEKSEEVA	{"phone": "+70911444707"}
0005434067442	7BB587	8447 682309	SERGEY TIKHONOV	{"phone": "+70709431813"}
0005434067443	62C717	3403 125104	VLADIMIR TARASOV	{"phone": "+70347137456"}
0005434067444	4B83DF	5189 965386	YURIY SHEVCHENKO	{"email": "y_shevchenko_1976@postgrespro.ru", "phone": "+70019415043"}
0005434067445	107C82	5829 441209	ANATOLIY ZHURAVLEV	{"email": "anatoliyzhuravlev_1971@postgrespro.ru", "phone": "+70815446603"}
0005434067446	894EF7	6205 807183	ANASTASIYA NIKITINA	{"email": "a-nikitina1960@postgrespro.ru", "phone": "+70284119731"}
0005434067447	1B835E	1065 470842	DMITRIY SERGEEV	{"email": "dsergeev_28071978@postgrespro.ru", "phone": "+70884391801"}
0005434067448	8D5FA4	8375 241978	ALEKSEY YAKOVLEV	{"email": "aleksey-yakovlev_101975@postgrespro.ru", "phone": "+70620090351"}
0005434067449	1112AE	5159 095530	EKATERINA EFIMOVA	{"email": "efimova.ekaterina.1978@postgrespro.ru", "phone": "+70983775391"}
0005434067450	1112AE	3726 340812	TATYANA KOROLEVA	{"email": "t.koroleva041974@postgrespro.ru", "phone": "+70506088362"}
0005434067451	4AA362	1824 072209	EVGENIYA SEMENOVA	{"phone": "+70551807373"}
0005434067452	C07FDD	3541 538562	SERGEY MIRONOV	{"email": "s.mironov-26051971@postgrespro.ru", "phone": "+70179462817"}
0005434067453	365590	2719 810292	VALERIY ALEKSANDROV	{"email": "aleksandrov.v111956@postgrespro.ru", "phone": "+70008566781"}
0005434067454	8FD90D	3642 065943	EKATERINA KAZAKOVA	{"phone": "+70716608407"}
0005434067455	45F089	1584 900837	MARIYA ZAKHAROVA	{"email": "zakharova_m_1966@postgrespro.ru", "phone": "+70219501451"}
0005434067456	A456CF	2415 077812	GRIGORIY KUZMIN	{"email": "kuzmingrigoriy-1973@postgrespro.ru", "phone": "+70730357938"}
0005434067457	BE18BB	3916 885637	VIKTOR DENISOV	{"phone": "+70727031219"}
0005434067458	BE18BB	5981 936031	ALEKSANDR FROLOV	{"email": "a_frolov.021976@postgrespro.ru", "phone": "+70225000369"}
0005434067459	CFE688	0526 276196	IGOR KISELEV	{"phone": "+70397039987"}
0005434067460	7BD96B	0133 013799	SERGEY PETROV	{"phone": "+70506047757"}
0005434067461	D80E08	8453 207941	OKSANA NESTEROVA	{"phone": "+70595368664"}
0005434067462	D80E08	3736 528208	KLAVDIYA STEPANOVA	{"phone": "+70475198750"}
0005434067463	A75EAD	5128 701912	YURIY POPOV	{"phone": "+70689733167"}
0005434067464	00CEB5	8265 202297	ANATOLIY FEDOROV	{"email": "afedorov-02021974@postgrespro.ru", "phone": "+70132496815"}
0005434067465	F1A8EA	2571 396893	TAMARA KOZLOVA	{"email": "tamarakozlova081976@postgrespro.ru", "phone": "+70480852582"}
0005434067466	A7A576	0992 404211	IVAN VASILEV	{"email": "vasilev-ivan_061974@postgrespro.ru", "phone": "+70575558421"}
0005434067467	B7EA0F	5112 545278	IVAN BONDARENKO	{"phone": "+70776839417"}
0005434067468	A79ED0	2693 426968	LYUBOV ZAKHAROVA	{"email": "lzakharova-051973@postgrespro.ru", "phone": "+70573105396"}
0005434067469	E47F28	3587 703109	VLADIMIR KUZNECOV	{"email": "kuznecov.v041967@postgrespro.ru", "phone": "+70584645788"}
0005434067470	E47F28	7437 619795	VYACHESLAV POPOV	{"phone": "+70091855863"}
0005434067471	CF85A5	2433 573410	ALINA DMITRIEVA	{"email": "dmitrievaa_071978@postgrespro.ru", "phone": "+70640943293"}
0005434067472	EAAB71	1767 687820	ARTEM ZAYCEV	{"email": "a-zaycev.01021972@postgrespro.ru", "phone": "+70022227553"}
0005434067473	EAAB71	3914 196413	ANNA ORLOVA	{"email": "annaorlova_18081972@postgrespro.ru", "phone": "+70951738327"}
0005434067474	496E25	5199 277857	ANDREY MAKSIMOV	{"email": "amaksimov_061970@postgrespro.ru", "phone": "+70106076016"}
0005434067475	47ADB7	6022 868159	YULIYA LUKYANOVA	{"email": "y_lukyanova1980@postgrespro.ru", "phone": "+70010625106"}
0005434067476	8A003A	2668 405994	NIKITA SIDOROV	{"email": "n-sidorov_17111975@postgrespro.ru", "phone": "+70192829830"}
0005434067477	85F42B	7398 270440	VLADIMIR SMIRNOV	{"email": "smirnovv_1985@postgrespro.ru", "phone": "+70667816936"}
0005434067478	5A08A4	1598 163590	NINA VASILEVA	{"email": "vasileva-nina-1968@postgrespro.ru", "phone": "+70896485742"}
0005434067479	5A08A4	7637 487294	TATYANA MIRONOVA	{"email": "mironova.t_13081965@postgrespro.ru", "phone": "+70837299567"}
0005434067480	CBC0E4	0288 370979	VIKTOR MAKAROV	{"phone": "+70316538585"}
0005434067481	9A701E	3335 572095	ANASTASIYA TARASOVA	{"phone": "+70517200018"}
0005434067482	262B31	4756 573221	MARIYA PETROVA	{"phone": "+70622883805"}
0005434067483	BC14A9	3382 743676	MAKSIM KUZMIN	{"phone": "+70716729113"}
0005434067484	EA5CF6	2237 969890	VLADIMIR STEPANOV	{"phone": "+70250955518"}
0005434067485	9FBDBA	6098 682427	EVGENIY SOLOVEV	{"email": "solovev.evgeniy_1975@postgrespro.ru", "phone": "+70800057315"}
0005434067486	C28035	8711 662871	VLADIMIR ANDREEV	{"email": "vandreev05101981@postgrespro.ru", "phone": "+70120214019"}
0005434067487	B27627	9155 948972	LIDIYA PETROVA	{"email": "l.petrova_1980@postgrespro.ru", "phone": "+70331156323"}
0005434067488	62AEB7	1737 663836	LYUDMILA TIMOFEEVA	{"phone": "+70796905664"}
0005434067489	FDCCC1	3128 471186	OLGA POPOVA	{"email": "popova.o-01021968@postgrespro.ru", "phone": "+70166376074"}
0005434067490	09121B	5919 030717	VLADIMIR EGOROV	{"phone": "+70349462454"}
0005434067491	1AF212	8289 551120	NADEZHDA SERGEEVA	{"email": "sergeeva_nadezhda.09111978@postgrespro.ru", "phone": "+70913754786"}
0005434067492	1AF212	1206 404547	NATALYA KONOVALOVA	{"phone": "+70632068028"}
0005434067493	EEA3C9	0577 585454	ANTON SHEVCHENKO	{"phone": "+70208198445"}
0005434067494	0CC11F	2341 929148	VALENTIN FOMIN	{"phone": "+70056824784"}
0005434067495	0CC11F	1861 859737	NATALIYA SOLOVEVA	{"email": "nataliyasoloveva_31031977@postgrespro.ru", "phone": "+70348998204"}
0005434067496	DE8221	1758 881396	VERA ARKHIPOVA	{"phone": "+70692524055"}
0005434067497	23C3BD	3860 976392	TATYANA NAUMOVA	{"phone": "+70547275533"}
0005434067498	45C1F6	8113 292541	SERGEY FOMIN	{"email": "fomin-sergey14031968@postgrespro.ru", "phone": "+70450646752"}
0005434067499	A42D1F	7649 055829	PETR STEPANOV	{"phone": "+70810151675"}
0005434067500	4C1805	7353 088933	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov.1974@postgrespro.ru", "phone": "+70903848707"}
0005434067501	4C1805	3170 037878	OLEG KOROLEV	{"email": "oleg_korolev-24091979@postgrespro.ru", "phone": "+70388360477"}
0005434067502	FFF776	0313 672922	ELENA MIKHAYLOVA	{"phone": "+70937963948"}
0005434067503	30C7BC	4244 074375	OLEG ORLOV	{"phone": "+70919551088"}
0005434067504	94EEB4	0480 899625	ELENA FROLOVA	{"email": "frolova_e_25101974@postgrespro.ru", "phone": "+70186181238"}
0005434067505	94EEB4	6459 577687	IRINA FROLOVA	{"email": "frolova-irina-061966@postgrespro.ru", "phone": "+70627444252"}
0005434067506	973DC8	9757 300070	TATYANA MAKAROVA	{"phone": "+70388878574"}
0005434067507	181C67	6717 115594	EKATERINA NIKITINA	{"email": "nikitina-ekaterina_111980@postgrespro.ru", "phone": "+70821283190"}
0005434067508	00982B	7172 026908	LILIYA MAKAROVA	{"phone": "+70534645649"}
0005434067509	00982B	8646 345023	MARIYA KUZMINA	{"phone": "+70012910769"}
0005434067510	FE4C32	0264 210864	NIKITA GORBUNOV	{"email": "n.gorbunov-041980@postgrespro.ru", "phone": "+70686149109"}
0005434067511	4872B4	5597 228493	DINA NAUMOVA	{"phone": "+70916343046"}
0005434067512	4872B4	7658 181311	KIRILL MIKHAYLOV	{"phone": "+70276777517"}
0005434067513	4872B4	0023 012079	ZINAIDA GORBUNOVA	{"phone": "+70986028846"}
0005434067514	B47A98	1010 899883	MARIYA EGOROVA	{"phone": "+70657977382"}
0005434067515	6CB83E	3130 625029	ALEKSANDR KONOVALOV	{"email": "konovalov_a.031961@postgrespro.ru", "phone": "+70758060710"}
0005434067516	8923B2	2083 626378	KUZMA KUZNECOV	{"phone": "+70209529587"}
0005434067517	8923B2	6710 214539	KRISTINA NESTEROVA	{"email": "nesterova_kristina-1970@postgrespro.ru", "phone": "+70633762498"}
0005434067518	94227C	2719 682706	ELENA ILINA	{"phone": "+70989693703"}
0005434067519	94227C	4372 970032	NATALYA SEMENOVA	{"phone": "+70599683408"}
0005434067520	94227C	7719 448925	DMITRIY MIRONOV	{"email": "mironov.d.111973@postgrespro.ru", "phone": "+70812231255"}
0005434067521	8E2028	9844 264082	VERONIKA NAZAROVA	{"email": "nazarovaveronika031968@postgrespro.ru", "phone": "+70805899332"}
0005434067522	7C6CEF	7216 225640	LYUDMILA ANTONOVA	{"email": "antonova_l23061976@postgrespro.ru", "phone": "+70453696692"}
0005434067523	7C6CEF	6139 620162	TAMARA KONDRATEVA	{"phone": "+70630885207"}
0005434067524	8430F6	8882 998496	RAVIL ILIN	{"email": "ilinravil_30041975@postgrespro.ru", "phone": "+70491295219"}
0005434067525	7436C6	9729 690262	NIKITA KUZMIN	{"phone": "+70663229198"}
0005434067526	065E9D	6629 972239	TATYANA NOVIKOVA	{"email": "tatyana.novikova1970@postgrespro.ru", "phone": "+70646098310"}
0005434067527	065E9D	0880 683730	NATALYA VASILEVA	{"email": "vasileva_natalya.29071963@postgrespro.ru", "phone": "+70995137439"}
0005434067528	065E9D	5416 419892	NINA POPOVA	{"phone": "+70751143425"}
0005434067529	DAB9DB	7726 260182	VLADIMIR MIKHAYLOV	{"phone": "+70065882180"}
0005434067530	40E93B	5925 945998	VLADIMIR KUZNECOV	{"phone": "+70071506571"}
0005434067531	718B54	7077 942206	NADEZHDA SOROKINA	{"email": "sorokina-n-03031975@postgrespro.ru", "phone": "+70402001003"}
0005434067532	42F6E7	3190 219592	ILYA KARPOV	{"phone": "+70328447057"}
0005434067533	42F6E7	3618 723992	SERGEY VOROBEV	{"phone": "+70251582818"}
0005434067534	34F877	6604 253895	NIKOLAY SCHERBAKOV	{"email": "scherbakov-nikolay_061969@postgrespro.ru", "phone": "+70424574091"}
0005434067535	F2EF4D	3974 010850	EKATERINA NIKIFOROVA	{"phone": "+70286522474"}
0005434067536	812310	8625 730661	FARIDA BARANOVA	{"phone": "+70474732120"}
0005434067537	812310	9845 141683	SERGEY ABRAMOV	{"email": "abramov-sergey-111976@postgrespro.ru", "phone": "+70751112013"}
0005434067538	D7636B	7456 243305	SERGEY NIKITIN	{"email": "sergey_nikitin071979@postgrespro.ru", "phone": "+70181902260"}
0005434067539	F156D1	9206 239857	VADIM KOZLOV	{"email": "kozlov.v-09071966@postgrespro.ru", "phone": "+70621126867"}
0005434067540	B27142	3567 317932	ALEKSANDR ZHUKOV	{"email": "a-zhukov.011973@postgrespro.ru", "phone": "+70116617978"}
0005434067541	E4ACCC	6240 076844	GALINA TARASOVA	{"email": "gtarasova.1971@postgrespro.ru", "phone": "+70152548654"}
0005434067542	E4ACCC	6078 172007	KONSTANTIN KUZNECOV	{"phone": "+70812567191"}
0005434067543	053D2A	1595 297528	DMITRIY KOZLOV	{"phone": "+70927438440"}
0005434067544	053D2A	3162 257462	VYACHESLAV ZAYCEV	{"email": "zaycev_vyacheslav071971@postgrespro.ru", "phone": "+70113127749"}
0005434067545	053D2A	4755 807108	MIKHAIL VASILEV	{"email": "m.vasilev-1979@postgrespro.ru", "phone": "+70030286124"}
0005434067546	F05B7B	3490 434511	ANDREY GUSEV	{"phone": "+70630687546"}
0005434067547	DB1035	8573 061705	ALEKSANDR ZAKHAROV	{"phone": "+70038210968"}
0005434067548	C31C3A	9571 316599	DMITRIY KONOVALOV	{"email": "d.konovalov_041968@postgrespro.ru", "phone": "+70102686764"}
0005434067549	C31C3A	8536 574676	VERONIKA NIKOLAEVA	{"email": "v_nikolaeva_1966@postgrespro.ru", "phone": "+70994397924"}
0005434067550	FCA82C	1019 894134	STEPAN ZAKHAROV	{"phone": "+70931609165"}
0005434067551	C94F00	1914 664450	VALENTINA NIKOLAEVA	{"email": "nikolaeva_v.081975@postgrespro.ru", "phone": "+70364782706"}
0005434067552	C94F00	1318 419981	TAMARA LAZAREVA	{"phone": "+70251074108"}
0005434067553	DFF67C	1161 047006	ALEKSANDRA POPOVA	{"email": "popova_aleksandra-07061969@postgrespro.ru", "phone": "+70387403353"}
0005434067554	929554	2544 168149	VIKTOR ZAKHAROV	{"email": "zakharovviktor_27081974@postgrespro.ru", "phone": "+70956339338"}
0005434067555	B0F049	3136 271584	SERGEY NIKITIN	{"email": "sergey-nikitin121974@postgrespro.ru", "phone": "+70979252980"}
0005434067556	78B041	4969 019476	SERGEY MAKAROV	{"email": "s_makarov081964@postgrespro.ru", "phone": "+70767887581"}
0005434067557	78B041	5142 247252	EKATERINA SOLOVEVA	{"email": "soloveva_e-1966@postgrespro.ru", "phone": "+70358200685"}
0005434067558	78B041	5665 202769	LYUBOV DENISOVA	{"email": "denisoval-18061966@postgrespro.ru", "phone": "+70248555704"}
0005434067559	D72F76	9370 227080	LIDIYA MAKSIMOVA	{"email": "l-maksimova-1972@postgrespro.ru", "phone": "+70573937836"}
0005434067560	E22CD7	4221 600259	ARTEM KUZMIN	{"phone": "+70752505763"}
0005434067561	4A8242	6308 053277	YURIY MOROZOV	{"email": "morozovyuriy.19061970@postgrespro.ru", "phone": "+70729847124"}
0005434067562	F79904	4853 581606	ARTEM MIRONOV	{"phone": "+70026262167"}
0005434067563	35B077	9625 044522	MARIYA KUZNECOVA	{"email": "mariyakuznecova121977@postgrespro.ru", "phone": "+70300973743"}
0005434067564	0BEAA1	1750 023549	LYUDMILA KONOVALOVA	{"phone": "+70317824458"}
0005434067565	0BEAA1	9711 631614	DAVID FROLOV	{"email": "d_frolov1961@postgrespro.ru", "phone": "+70511975370"}
0005434067566	D02400	7633 350740	EKATERINA SOROKINA	{"phone": "+70322668836"}
0005434067567	F057C2	9994 093538	OLEG FEDOTOV	{"phone": "+70465317035"}
0005434067568	E61B36	7517 733263	NATALYA EFREMOVA	{"email": "efremova.natalya071965@postgrespro.ru", "phone": "+70683306328"}
0005434067569	29E793	4102 644442	VALENTINA KOMAROVA	{"phone": "+70690391674"}
0005434067570	29E793	2276 433139	MIKHAIL GERASIMOV	{"phone": "+70223503394"}
0005434067571	752215	5045 021797	TATYANA PAVLOVA	{"email": "pavlova_tatyana-1980@postgrespro.ru", "phone": "+70643028490"}
0005434067572	3443BD	5000 042180	ALEKSEY DMITRIEV	{"phone": "+70131576811"}
0005434067573	FC8D68	8175 553183	ALEKSANDR MOROZOV	{"phone": "+70081617890"}
0005434067574	FC8D68	2067 384367	ELIZAVETA LEBEDEVA	{"email": "lebedevaelizaveta_011982@postgrespro.ru", "phone": "+70088154814"}
0005434067575	C7424C	1361 843771	ANTON KISELEV	{"email": "kiselev-anton23071965@postgrespro.ru", "phone": "+70141116734"}
0005434067576	7B5160	3677 181073	PETR IVANOV	{"email": "petrivanov10101970@postgrespro.ru", "phone": "+70313645975"}
0005434067577	94FED5	3207 657712	SVETLANA MOISEEVA	{"email": "svetlana-moiseeva_121984@postgrespro.ru", "phone": "+70528408588"}
0005434067578	72F194	7307 648741	ELIZAVETA KISELEVA	{"phone": "+70284898787"}
0005434067579	677360	5400 435467	ALEKSANDRA ZAKHAROVA	{"email": "aleksandra-zakharova_02031966@postgrespro.ru", "phone": "+70225842119"}
0005434067580	677360	2601 113238	EGOR BARANOV	{"email": "baranovegor.051977@postgrespro.ru", "phone": "+70744182087"}
0005434067581	AEE981	7432 270699	ARTEM KOROLEV	{"email": "a-korolev.18021980@postgrespro.ru", "phone": "+70734670807"}
0005434067582	AEE981	3306 569536	ANTONINA DANILOVA	{"email": "danilovaantonina_051968@postgrespro.ru", "phone": "+70874744054"}
0005434067583	AEE981	9357 585495	SVETLANA STEPANOVA	{"phone": "+70684353680"}
0005434067584	9F38D3	6462 680413	VYACHESLAV MATVEEV	{"email": "vyacheslav.matveev-1974@postgrespro.ru", "phone": "+70224329850"}
0005434067585	F7CD31	3489 228810	TATYANA KAZAKOVA	{"email": "kazakova_t_041976@postgrespro.ru", "phone": "+70015245432"}
0005434067586	F7CD31	7418 921784	ALEKSANDR SCHERBAKOV	{"phone": "+70275637047"}
0005434067587	63333D	3809 405427	IVAN TARASOV	{"email": "tarasovivan_30031971@postgrespro.ru", "phone": "+70994506110"}
0005434067588	63333D	5437 096675	BORIS MOROZOV	{"email": "morozov-boris1981@postgrespro.ru", "phone": "+70258428830"}
0005434067589	80A3EE	5031 106949	YULIYA RYABOVA	{"email": "y-ryabova.091969@postgrespro.ru", "phone": "+70723641182"}
0005434067590	EB0FD3	1156 026305	TATYANA ANDREEVA	{"email": "andreeva-t.1959@postgrespro.ru", "phone": "+70732918038"}
0005434067591	B33953	3662 200235	VIKTORIYA OVCHINNIKOVA	{"email": "vovchinnikova.15081962@postgrespro.ru", "phone": "+70933427854"}
0005434067592	B33953	7639 075149	VLADIMIR ANDREEV	{"email": "vladimir-andreev041974@postgrespro.ru", "phone": "+70039187687"}
0005434067593	55B617	9619 262709	EDUARD FEDOROV	{"email": "eduard-fedorov_07071967@postgrespro.ru", "phone": "+70890082474"}
0005434067759	5BCC41	5810 875598	NATALYA ZHURAVLEVA	{"phone": "+70318896012"}
0005434067594	19BE0F	8412 787216	TAMARA POPOVA	{"email": "popova.t.21061955@postgrespro.ru", "phone": "+70023176591"}
0005434067595	3A8178	8703 121398	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_041967@postgrespro.ru", "phone": "+70158754413"}
0005434067596	971192	1551 394044	MIKHAIL MIRONOV	{"phone": "+70003029747"}
0005434067597	14A247	8979 289610	MARIYA MOROZOVA	{"phone": "+70414690152"}
0005434067598	14A247	3135 608799	ALEKSANDRA VOLKOVA	{"email": "volkova.aleksandra_061967@postgrespro.ru", "phone": "+70266683061"}
0005434067599	35C193	3195 137676	VASILISA KUZMINA	{"phone": "+70394607882"}
0005434067600	EE1788	4094 797578	KLAVDIYA RYABOVA	{"phone": "+70595462156"}
0005434067601	2B54D8	6472 190000	EKATERINA STEPANOVA	{"email": "estepanova1967@postgrespro.ru", "phone": "+70832725972"}
0005434067602	2B54D8	5525 463126	TAMARA YAKOVLEVA	{"phone": "+70290682425"}
0005434067603	AA7D23	9147 044080	RAFAIL VASILEV	{"email": "rafail.vasilev-02011983@postgrespro.ru", "phone": "+70552006744"}
0005434067604	B22A4A	3710 394536	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova.13071972@postgrespro.ru", "phone": "+70975292062"}
0005434067605	B22A4A	2657 979497	NATALYA ARKHIPOVA	{"email": "narkhipova-1971@postgrespro.ru", "phone": "+70063748161"}
0005434067606	1541E7	3538 172166	VALERIY ZAKHAROV	{"phone": "+70803498815"}
0005434067607	1541E7	5487 805408	REGINA ANTONOVA	{"email": "antonovar_1976@postgrespro.ru", "phone": "+70591132952"}
0005434067608	432B81	0330 021134	MILENA VOLKOVA	{"email": "milenavolkova1974@postgrespro.ru", "phone": "+70213934165"}
0005434067609	A57C32	5275 103915	VERA KAZAKOVA	{"email": "v_kazakova-121983@postgrespro.ru", "phone": "+70558979038"}
0005434067610	A57C32	8992 250611	OLGA TARASOVA	{"phone": "+70210494034"}
0005434067611	A57C32	6941 941688	VLADIMIR KULIKOV	{"email": "v.kulikov-091971@postgrespro.ru", "phone": "+70886604697"}
0005434067612	76C69B	3998 842040	ALEKSANDR SERGEEV	{"email": "a-sergeev04031986@postgrespro.ru", "phone": "+70333558631"}
0005434067613	2E1986	2413 831733	DARYA GERASIMOVA	{"phone": "+70869463216"}
0005434067614	2E1986	5731 961774	NATALYA SERGEEVA	{"email": "sergeeva-n-01071968@postgrespro.ru", "phone": "+70396364253"}
0005434067615	B8C54F	0424 457411	VALENTINA NESTEROVA	{"email": "nesterova.v-1969@postgrespro.ru", "phone": "+70510429242"}
0005434067616	75A256	1898 595380	FARIT GRIGOREV	{"email": "grigorevfarit-1979@postgrespro.ru", "phone": "+70625923404"}
0005434067617	75A256	4791 152728	DMITRIY DENISOV	{"phone": "+70111203681"}
0005434067618	0C000C	4240 279131	NATALYA SOROKINA	{"email": "n-sorokina-07011965@postgrespro.ru", "phone": "+70291477245"}
0005434067619	0C000C	4488 808216	VYACHESLAV NIKOLAEV	{"email": "vyacheslav.nikolaev071969@postgrespro.ru", "phone": "+70876547886"}
0005434067620	0C000C	0614 117684	ULYANA POPOVA	{"email": "u_popova.101975@postgrespro.ru", "phone": "+70693450076"}
0005434067621	EE8CD5	2274 209978	ELENA CHERNOVA	{"phone": "+70768038820"}
0005434067622	E3DE40	5868 699869	SERGEY BELOV	{"email": "belov_s1978@postgrespro.ru", "phone": "+70608381636"}
0005434067623	97E7AC	0462 898195	YULIYA VOLKOVA	{"email": "yvolkova1961@postgrespro.ru", "phone": "+70894086297"}
0005434067624	AFB702	0519 010409	PAVEL KISELEV	{"email": "pavel.kiselev-11081972@postgrespro.ru", "phone": "+70428874032"}
0005434067625	3D92BE	8311 687522	VLADIMIR YAKOVLEV	{"phone": "+70646657241"}
0005434067626	4677B4	4905 056954	LIDIYA TIMOFEEVA	{"phone": "+70090683924"}
0005434067627	C97787	0018 809467	VALENTINA MIRONOVA	{"email": "valentina_mironova_1970@postgrespro.ru", "phone": "+70826985540"}
0005434067628	C97787	6503 726125	VERA FOMINA	{"phone": "+70575271255"}
0005434067629	AB2D2B	6773 648111	EDUARD KUZNECOV	{"email": "eduard_kuznecov-15021965@postgrespro.ru", "phone": "+70153142785"}
0005434067630	65A631	6677 509537	OLEG SOROKIN	{"email": "sorokin.oleg-051975@postgrespro.ru", "phone": "+70240679689"}
0005434067631	65A631	9999 650666	VALENTINA NOVIKOVA	{"phone": "+70009040412"}
0005434067632	15C43F	2810 506351	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaa.061974@postgrespro.ru", "phone": "+70439180616"}
0005434067633	15C43F	6551 843711	GALINA BORISOVA	{"email": "borisova-galina_23021977@postgrespro.ru", "phone": "+70490664704"}
0005434067634	7E914B	8663 190237	ALEKSEY KUZNECOV	{"email": "alekseykuznecov-081985@postgrespro.ru", "phone": "+70901367930"}
0005434067635	7E914B	9747 900666	ANDREY POPOV	{"email": "andrey.popov081967@postgrespro.ru", "phone": "+70240854009"}
0005434067636	211E21	2384 600170	ALEKSANDR MOISEEV	{"phone": "+70958048241"}
0005434067637	775FA1	0141 496486	ARINA KAZAKOVA	{"phone": "+70586109048"}
0005434067638	775FA1	0707 929016	TATYANA SEMENOVA	{"email": "tatyana_semenova.1968@postgrespro.ru", "phone": "+70803960680"}
0005434067639	A481E4	7896 847864	YULIYA KUZMINA	{"email": "yuliyakuzmina.12071961@postgrespro.ru", "phone": "+70426862434"}
0005434067640	207E6F	3471 863180	VIKTOR KUZNECOV	{"phone": "+70793228012"}
0005434067641	207E6F	8275 013783	VARVARA ABRAMOVA	{"email": "abramova-varvara_1987@postgrespro.ru", "phone": "+70701877350"}
0005434067642	562482	0047 103529	LIDIYA IVANOVA	{"phone": "+70115481314"}
0005434067643	13CF1D	0943 163204	DMITRIY SOLOVEV	{"email": "d_solovev091965@postgrespro.ru", "phone": "+70836394234"}
0005434067644	07BD4B	9578 591621	LEONID STEPANOV	{"phone": "+70602434660"}
0005434067645	07BD4B	8549 115412	LYUDMILA SIDOROVA	{"email": "l.sidorova_1973@postgrespro.ru", "phone": "+70359562873"}
0005434067646	EEF4B7	2410 503014	TATYANA FILATOVA	{"email": "filatovatatyana031977@postgrespro.ru", "phone": "+70637436438"}
0005434067647	5FED8A	5901 315103	ELENA BORISOVA	{"email": "borisova_e.1983@postgrespro.ru", "phone": "+70364774874"}
0005434067648	5FED8A	1013 770156	TATYANA MOISEEVA	{"phone": "+70668129005"}
0005434067649	F78D59	1183 300670	GENNADIY GRIGOREV	{"email": "grigorev-gennadiy_1979@postgrespro.ru", "phone": "+70604754978"}
0005434067650	409EC7	8109 485842	OLESYA EGOROVA	{"email": "egorova_o.03081975@postgrespro.ru", "phone": "+70272746170"}
0005434067651	39B15B	5421 202350	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov.20021979@postgrespro.ru", "phone": "+70085361004"}
0005434067652	39B15B	5133 350072	VIKTOR VOROBEV	{"email": "viktor-vorobev-29061960@postgrespro.ru", "phone": "+70537813860"}
0005434067653	A8D129	8123 941803	OKSANA ISAEVA	{"phone": "+70393262430"}
0005434067654	A8D129	9975 137974	YULIYA VASILEVA	{"email": "vasileva.yuliya.1974@postgrespro.ru", "phone": "+70435707883"}
0005434067655	6B5490	6140 987067	EKATERINA KISELEVA	{"email": "ekaterinakiseleva091974@postgrespro.ru", "phone": "+70718238135"}
0005434067656	60BF46	5964 043204	ANASTASIYA KOROLEVA	{"phone": "+70364707715"}
0005434067657	488E80	5622 799992	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova-l-021982@postgrespro.ru", "phone": "+70429189988"}
0005434067658	488E80	6295 847041	SERGEY ABRAMOV	{"email": "abramovsergey-031962@postgrespro.ru", "phone": "+70616899852"}
0005434067659	2BEE18	9559 330618	RAFAEL TIKHONOV	{"phone": "+70976478969"}
0005434067660	2BEE18	6196 704944	ALEKSANDR KOZLOV	{"phone": "+70616272944"}
0005434067661	F97E51	4794 617270	SOFYA NAUMOVA	{"phone": "+70134160119"}
0005434067662	8E429D	6973 076933	VLADIMIR MOISEEV	{"email": "vmoiseev.1968@postgrespro.ru", "phone": "+70127803309"}
0005434067663	CC7FA3	2761 252593	IRINA KOMAROVA	{"email": "i.komarova17051983@postgrespro.ru", "phone": "+70044899571"}
0005434067664	A47A5B	7269 770135	MARIYA KUZNECOVA	{"email": "mariya.kuznecova-101974@postgrespro.ru", "phone": "+70077049344"}
0005434067665	333C8F	2870 822236	SERGEY EGOROV	{"email": "egorov_s-1960@postgrespro.ru", "phone": "+70548773271"}
0005434067666	E87AC3	3889 741719	LARISA NOVIKOVA	{"phone": "+70959607992"}
0005434067667	E87AC3	2205 431237	ARSENIY SMIRNOV	{"phone": "+70558384639"}
0005434067668	97A380	7183 147400	OLGA KRASNOVA	{"email": "krasnova_olga.1977@postgrespro.ru", "phone": "+70605243261"}
0005434067669	94E05C	0922 492869	GENNADIY ALEKSEEV	{"email": "gennadiy_alekseev-1965@postgrespro.ru", "phone": "+70658930391"}
0005434067670	0FFCA1	9121 767132	ELENA ANDREEVA	{"email": "andreevae.011975@postgrespro.ru", "phone": "+70985923975"}
0005434067671	0FFCA1	0210 429602	VLADIMIR ZHURAVLEV	{"phone": "+70334367139"}
0005434067672	A4E952	6080 965789	NATALIYA MOROZOVA	{"email": "n_morozova111974@postgrespro.ru", "phone": "+70206217319"}
0005434067673	641042	1541 427365	OLGA KISELEVA	{"phone": "+70296691316"}
0005434067674	71BCC2	2266 608065	ANATOLIY KARPOV	{"phone": "+70874268129"}
0005434067675	71BCC2	1615 027947	MIKHAIL ANTONOV	{"email": "antonov_m-011981@postgrespro.ru", "phone": "+70478347116"}
0005434067676	ECB4F5	0014 176088	ALEKSANDRA DAVYDOVA	{"phone": "+70596995142"}
0005434067677	ECB4F5	6028 290850	KONSTANTIN SHEVCHENKO	{"phone": "+70877369544"}
0005434067678	478478	5524 371672	NATALIYA NIKOLAEVA	{"email": "nnikolaeva-1972@postgrespro.ru", "phone": "+70657429463"}
0005434067679	0BCE15	7102 436461	OLEG SERGEEV	{"phone": "+70299938786"}
0005434067680	286429	6320 427929	IRINA OSIPOVA	{"email": "osipova-irina-17021977@postgrespro.ru", "phone": "+70618921887"}
0005434067681	286429	6520 266817	LYUDMILA SOKOLOVA	{"email": "sokolova.lyudmila_1968@postgrespro.ru", "phone": "+70278293862"}
0005434067682	5B07F2	2059 389021	KONSTANTIN AFANASEV	{"email": "k-afanasev.041977@postgrespro.ru", "phone": "+70475180615"}
0005434067683	635604	0725 520828	NATALYA YAKOVLEVA	{"phone": "+70360024303"}
0005434067684	F13276	7556 757289	OLEG FEDOROV	{"email": "fedorov_oleg1978@postgrespro.ru", "phone": "+70532640234"}
0005434067685	E71AAC	6124 329225	IGOR ZAKHAROV	{"email": "zakharov-i021978@postgrespro.ru", "phone": "+70815118430"}
0005434067686	45DF9C	4580 939027	NIKOLAY SAVELEV	{"phone": "+70182084058"}
0005434067687	45DF9C	9039 090870	ANGELINA BELYAEVA	{"email": "a-belyaeva_1972@postgrespro.ru", "phone": "+70579055591"}
0005434067688	900AD1	8583 186865	ANNA NIKITINA	{"phone": "+70977274775"}
0005434067689	28351F	6025 959244	RUZALIYA EFIMOVA	{"email": "efimova_r071969@postgrespro.ru", "phone": "+70693893771"}
0005434067690	92E1B7	5675 254828	VSEVOLOD BELOV	{"phone": "+70957015452"}
0005434067691	92E1B7	5727 526454	BORIS ANTONOV	{"phone": "+70148981767"}
0005434067692	07739E	7191 135314	DARYA NESTEROVA	{"phone": "+70769481968"}
0005434067693	07739E	7488 402904	TATYANA YUDINA	{"email": "t.yudina_05021982@postgrespro.ru", "phone": "+70838950797"}
0005434067694	07739E	2870 023090	EVGENIY TIMOFEEV	{"email": "e.timofeev10091975@postgrespro.ru", "phone": "+70848502781"}
0005434067695	87C0CA	3890 077499	OLGA IVANOVA	{"email": "o-ivanova_031972@postgrespro.ru", "phone": "+70925702419"}
0005434067696	BB255F	8278 957408	GENNADIY IVANOV	{"phone": "+70670572574"}
0005434067697	7EEDF0	1221 945533	ILYA IVANOV	{"email": "ivanovilya021973@postgrespro.ru", "phone": "+70919653302"}
0005434067698	7EEDF0	7373 315470	ANASTASIYA MATVEEVA	{"email": "matveevaa-1965@postgrespro.ru", "phone": "+70670055634"}
0005434067699	F49A4B	1411 229467	KSENIYA NESTEROVA	{"phone": "+70100937597"}
0005434067700	45E001	6070 679196	SERGEY SAVELEV	{"phone": "+70362743628"}
0005434067701	45E001	6742 194283	OLGA KOVALEVA	{"phone": "+70251110730"}
0005434067702	0E3D21	6669 783045	SERGEY DENISOV	{"email": "denisov.sergey091975@postgrespro.ru", "phone": "+70749757379"}
0005434067703	2C2695	4374 433781	VLADIMIR NIKITIN	{"phone": "+70300477944"}
0005434067816	EAFBCF	0955 295181	IGOR BORISOV	{"phone": "+70589413932"}
0005434067704	8DC04A	6014 260770	ELEONORA ANDREEVA	{"email": "andreevaeleonora1959@postgrespro.ru", "phone": "+70826677461"}
0005434067705	8DC04A	0452 864752	MIKHAIL SCHERBAKOV	{"phone": "+70972813854"}
0005434067706	2B117E	7088 903721	TAISIYA SOKOLOVA	{"email": "sokolovataisiya_1986@postgrespro.ru", "phone": "+70416353873"}
0005434067707	78B656	8044 620168	ALEKSANDR VLASOV	{"email": "vlasov-a_111968@postgrespro.ru", "phone": "+70848169378"}
0005434067708	B43E8E	2752 940713	ALEKSEY STEPANOV	{"phone": "+70231332054"}
0005434067709	B43E8E	9085 283049	VALENTINA IVANOVA	{"phone": "+70146672208"}
0005434067710	490A3D	8492 198202	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova.28071964@postgrespro.ru", "phone": "+70735378115"}
0005434067711	490A3D	4949 911670	GULNARA RODIONOVA	{"phone": "+70418053017"}
0005434067712	33ECF8	4301 874711	YULIYA FOMINA	{"email": "fominayuliya051966@postgrespro.ru", "phone": "+70731106924"}
0005434067713	2DEFFE	9866 699085	NIKOLAY SMIRNOV	{"phone": "+70696637764"}
0005434067714	2DEFFE	0884 291707	ALEKSEY TIMOFEEV	{"phone": "+70062038861"}
0005434067715	81350C	5149 440893	SERGEY POPOV	{"phone": "+70802370970"}
0005434067716	81350C	5521 745634	TATYANA MAKAROVA	{"email": "makarova_t_081966@postgrespro.ru", "phone": "+70756560434"}
0005434067717	81350C	1579 197981	ANDREY ZHURAVLEV	{"email": "zhuravlev_a19041985@postgrespro.ru", "phone": "+70490206675"}
0005434067718	DB1B3B	3670 153339	ANNA ZOTOVA	{"email": "azotova-06041969@postgrespro.ru", "phone": "+70178707114"}
0005434067719	DB1B3B	3185 463405	NINA SCHERBAKOVA	{"email": "nina.scherbakova.1971@postgrespro.ru", "phone": "+70463363487"}
0005434067720	BDD0D7	3243 231164	MARIYA DMITRIEVA	{"email": "dmitrieva.mariya.25071973@postgrespro.ru", "phone": "+70387421254"}
0005434067721	A10B57	1892 947634	YULIYA VLASOVA	{"email": "yvlasova20121970@postgrespro.ru", "phone": "+70912792093"}
0005434067722	83306A	4827 894258	TATYANA MOROZOVA	{"email": "tatyana-morozova-1973@postgrespro.ru", "phone": "+70563390883"}
0005434067723	D12018	7282 641417	NATALYA ILINA	{"phone": "+70457215721"}
0005434067724	F8F4DD	4297 220303	ANNA ORLOVA	{"email": "orlova_a-08061969@postgrespro.ru", "phone": "+70114487208"}
0005434067725	F8F4DD	9186 182001	EVGENIY VASILEV	{"email": "vasilev-evgeniy.031981@postgrespro.ru", "phone": "+70019000742"}
0005434067726	E6774D	8907 405546	IVAN DENISOV	{"email": "ivan.denisov.051978@postgrespro.ru", "phone": "+70975414767"}
0005434067727	094D49	7872 847488	ELENA MAKAROVA	{"phone": "+70929227863"}
0005434067728	EC904F	2126 693810	ALEKSANDR KRASNOV	{"email": "krasnov.a14121967@postgrespro.ru", "phone": "+70010311834"}
0005434067729	EC904F	2104 957594	IGOR MAKAROV	{"email": "i_makarov-021971@postgrespro.ru", "phone": "+70885484502"}
0005434067791	7CC469	6616 847183	VYACHESLAV IVANOV	{"phone": "+70496960830"}
0005434067730	B5F601	3436 472923	GENNADIY KULIKOV	{"email": "g_kulikov_23031965@postgrespro.ru", "phone": "+70262369695"}
0005434067731	A1ABC4	6872 050976	VALERIY GERASIMOV	{"email": "v_gerasimov09051961@postgrespro.ru", "phone": "+70168745105"}
0005434067732	A1ABC4	4112 594858	ILYA NIKITIN	{"phone": "+70461267630"}
0005434067733	54A9DA	1574 936152	NATALYA VOLKOVA	{"phone": "+70726381129"}
0005434067734	C1BC94	8800 228266	TATYANA POPOVA	{"email": "popova-tatyana_1973@postgrespro.ru", "phone": "+70966705876"}
0005434067735	DE5394	0617 866072	TATYANA ABRAMOVA	{"phone": "+70227733691"}
0005434067736	3CB2EE	1868 959563	RUSLAN GAVRILOV	{"email": "ruslan_gavrilov.22071977@postgrespro.ru", "phone": "+70031185134"}
0005434067737	780758	0854 149549	ALFIYA PAVLOVA	{"phone": "+70373808898"}
0005434067738	18E479	8705 789342	ELENA ANDREEVA	{"phone": "+70537284091"}
0005434067739	B2D317	3913 648564	ANNA KOMAROVA	{"phone": "+70609208255"}
0005434067740	97DE16	9126 689485	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov_051982@postgrespro.ru", "phone": "+70819974811"}
0005434067741	245D0D	4065 959203	NIKOLAY MOISEEV	{"email": "moiseev.n-021983@postgrespro.ru", "phone": "+70470603351"}
0005434067742	245D0D	4901 622112	POLINA MIRONOVA	{"phone": "+70709617125"}
0005434067743	42898F	5320 165254	OLGA GAVRILOVA	{"email": "o_gavrilova1963@postgrespro.ru", "phone": "+70254875827"}
0005434067744	42898F	7896 606704	LIDIYA LEBEDEVA	{"phone": "+70366030207"}
0005434067745	4B9DE7	0121 431564	VLADIMIR KUZNECOV	{"email": "kuznecov-v.081976@postgrespro.ru", "phone": "+70360183189"}
0005434067746	4B9DE7	5202 841154	DENIS POPOV	{"phone": "+70056259304"}
0005434067747	20043B	9141 499316	ALEKSANDR PETROV	{"email": "petrov_aleksandr-091975@postgrespro.ru", "phone": "+70483435847"}
0005434067748	B73768	1111 395932	NATALYA YAKOVLEVA	{"email": "yakovlevanatalya-1969@postgrespro.ru", "phone": "+70559001680"}
0005434067749	B73768	5507 918324	VYACHESLAV MOISEEV	{"phone": "+70142220438"}
0005434067750	B9E5A1	4951 456172	SOFIYA ROMANOVA	{"email": "s_romanova_1981@postgrespro.ru", "phone": "+70941897239"}
0005434067751	B9E5A1	9145 762339	ELENA SAVELEVA	{"email": "savelevae24051972@postgrespro.ru", "phone": "+70962922303"}
0005434067752	B9E5A1	1458 388320	VARVARA KUZNECOVA	{"email": "kuznecova-varvara_1971@postgrespro.ru", "phone": "+70890007196"}
0005434067753	EC9A20	8024 935545	VLADIMIR SIDOROV	{"email": "vladimir-sidorov.111969@postgrespro.ru", "phone": "+70027268206"}
0005434067754	7C6568	1329 413846	ANASTASIYA KOVALEVA	{"phone": "+70263144685"}
0005434067755	C93EEE	9764 492992	GALINA SAVELEVA	{"email": "saveleva-galina.15081972@postgrespro.ru", "phone": "+70822337681"}
0005434067756	854846	9900 081006	MARIYA POPOVA	{"phone": "+70768270108"}
0005434067757	854846	0708 752036	DENIS SEMENOV	{"email": "semenov.denis_30011964@postgrespro.ru", "phone": "+70268449075"}
0005434067758	8D9791	8610 381898	IVAN ISAEV	{"phone": "+70036289643"}
0005434067760	61232D	4675 141134	IVAN PETROV	{"email": "ivan.petrov-1961@postgrespro.ru", "phone": "+70448319550"}
0005434067761	61232D	6799 177656	KIRILL ZAYCEV	{"email": "zaycev-kirill_071973@postgrespro.ru", "phone": "+70119136497"}
0005434067762	844C08	0836 867987	ALEKSEY GAVRILOV	{"phone": "+70401534678"}
0005434067763	844C08	6659 248706	ANASTASIYA YAKOVLEVA	{"phone": "+70376903299"}
0005434067764	844C08	0300 991940	SERGEY ALEKSEEV	{"email": "s-alekseev-1961@postgrespro.ru", "phone": "+70427868031"}
0005434067765	1E802D	5745 986571	MIKHAIL ISAEV	{"email": "misaev061969@postgrespro.ru", "phone": "+70867615310"}
0005434067766	1E802D	8470 895703	VIKTOR VASILEV	{"phone": "+70615397089"}
0005434067767	1E802D	8334 314598	ALEKSANDR TARASOV	{"email": "tarasova_081960@postgrespro.ru", "phone": "+70145323373"}
0005434067768	F7A5ED	7659 525313	MAKSIM FILIPPOV	{"phone": "+70693172253"}
0005434067769	A399E2	0494 141484	NINA NIKIFOROVA	{"phone": "+70300222928"}
0005434067770	F434F8	4880 293167	VASILIY NIKITIN	{"phone": "+70918590406"}
0005434067771	CFCE0D	6962 367354	VIKTORIYA KONOVALOVA	{"email": "v-konovalova_021954@postgrespro.ru", "phone": "+70609091265"}
0005434067772	BD94FC	6180 988720	IRINA ABRAMOVA	{"email": "abramova-irina_1967@postgrespro.ru", "phone": "+70460923881"}
0005434067773	C0DE93	0725 307764	VERA FADEEVA	{"email": "vera_fadeeva.24101983@postgrespro.ru", "phone": "+70738263196"}
0005434067774	49CA8D	3663 246252	SERGEY BELOV	{"phone": "+70030772040"}
0005434067775	49CA8D	9246 644504	VLADIMIR GERASIMOV	{"phone": "+70343967622"}
0005434067776	4114C3	3929 092837	ARTEM NIKITIN	{"email": "artemnikitin.23101975@postgrespro.ru", "phone": "+70611865665"}
0005434067777	E205A0	4174 671770	LARISA MALYSHEVA	{"phone": "+70274381575"}
0005434067778	E205A0	1401 063497	NADEZHDA PETROVA	{"email": "petrovan03081978@postgrespro.ru", "phone": "+70451231490"}
0005434067779	F365BA	3799 738734	IRINA ZHUKOVA	{"phone": "+70258048285"}
0005434067780	ED7233	0571 207886	OLGA ROMANOVA	{"email": "olga_romanova.121970@postgrespro.ru", "phone": "+70839301412"}
0005434067781	ED7233	0070 510779	ALINA MALYSHEVA	{"email": "a_malysheva-061975@postgrespro.ru", "phone": "+70189093133"}
0005434067782	F90605	9034 259583	ALEKSANDR IVANOV	{"phone": "+70207256704"}
0005434067783	4987F2	6959 725061	VLADIMIR KRASNOV	{"email": "v-krasnov_1968@postgrespro.ru", "phone": "+70319839831"}
0005434067784	6DC412	8070 200408	TATYANA BORISOVA	{"phone": "+70684008448"}
0005434067785	665369	8769 544207	SVETLANA STEPANOVA	{"email": "stepanova_s28091975@postgrespro.ru", "phone": "+70949561595"}
0005434067786	672F62	4692 089772	OLGA GORBUNOVA	{"email": "gorbunovao.21031970@postgrespro.ru", "phone": "+70904534136"}
0005434067787	F2577F	3987 915930	POLINA MAKSIMOVA	{"phone": "+70030948817"}
0005434067788	F2577F	6341 584475	SERGEY IVANOV	{"email": "ivanov_s-28091971@postgrespro.ru", "phone": "+70096460248"}
0005434067789	2B7A3F	4334 707152	LARISA NIKITINA	{"email": "larisa_nikitina.101971@postgrespro.ru", "phone": "+70333554752"}
0005434067790	2B7A3F	8636 384244	VLADIMIR AFANASEV	{"phone": "+70758281308"}
0005434067792	7E2DC4	6310 374190	NATALYA MAKAROVA	{"email": "makarova-natalya_1974@postgrespro.ru", "phone": "+70776459470"}
0005434067793	7FA80B	6322 493405	ANASTASIYA MARTYNOVA	{"email": "martynovaanastasiya_27051967@postgrespro.ru", "phone": "+70587556948"}
0005434067794	FE182E	0114 524668	TATYANA KOROLEVA	{"phone": "+70897391568"}
0005434067795	BBC71A	1758 875614	YAROSLAV KOZLOV	{"email": "yaroslavkozlov-1972@postgrespro.ru", "phone": "+70682426891"}
0005434067796	BC24BD	0396 139183	TATYANA NAUMOVA	{"phone": "+70403258812"}
0005434067797	BC24BD	0432 296435	YULIYA IVANOVA	{"email": "yuliya-ivanova-18061973@postgrespro.ru", "phone": "+70512575929"}
0005434067798	A2273F	8824 595846	NADEZHDA MOROZOVA	{"phone": "+70157947680"}
0005434067799	6D5DF2	4056 501161	FILIPP MIRONOV	{"email": "f-mironov-1965@postgrespro.ru", "phone": "+70202721398"}
0005434067800	3EF515	8729 529464	VLADIMIR IVANOV	{"email": "ivanov_v111969@postgrespro.ru", "phone": "+70935792074"}
0005434067801	56BC6E	8888 815990	ANNA ALEKSEEVA	{"email": "anna-alekseeva_1970@postgrespro.ru", "phone": "+70417264259"}
0005434067802	B32CD8	8498 423491	MAKSIM ABRAMOV	{"phone": "+70552891517"}
0005434067803	B32CD8	8967 052326	MARIYA ORLOVA	{"email": "orlova-mariya11111975@postgrespro.ru", "phone": "+70004333482"}
0005434067804	DDDA22	1223 660742	VALENTIN FROLOV	{"phone": "+70106884606"}
0005434067805	AAEF1C	9597 495715	OKSANA FEDOROVA	{"phone": "+70154271085"}
0005434067806	AAEF1C	0667 293779	IVAN BORISOV	{"phone": "+70010965930"}
0005434067807	0BCCA0	8414 848217	VIKTORIYA NESTEROVA	{"phone": "+70803293719"}
0005434067808	12AD70	8288 419062	ALEKSEY FILIPPOV	{"email": "filippov-a_1976@postgrespro.ru", "phone": "+70396472062"}
0005434067809	16C67C	2701 512259	NATALYA MARTYNOVA	{"email": "natalya.martynova_18121985@postgrespro.ru", "phone": "+70393548954"}
0005434067810	57325B	6797 508032	MARIYA KALININA	{"email": "m_kalinina_1959@postgrespro.ru", "phone": "+70679712615"}
0005434067811	57325B	4899 074929	ALEKSANDR VLASOV	{"email": "vlasov_aleksandr.29061972@postgrespro.ru", "phone": "+70803510460"}
0005434067812	C65DE7	8777 497424	RAISA KISELEVA	{"email": "raisa-kiseleva-1969@postgrespro.ru", "phone": "+70108756947"}
0005434067813	164E14	9272 499484	MARIYA PAVLOVA	{"email": "mariya.pavlova_1964@postgrespro.ru", "phone": "+70630671682"}
0005434067814	164E14	5061 961814	VLADIMIR FROLOV	{"email": "vladimir.frolov-1971@postgrespro.ru", "phone": "+70088621591"}
0005434067815	FF8579	1408 936591	VALENTINA OVCHINNIKOVA	{"phone": "+70003783609"}
0005434067873	13AEAB	8871 111270	ELENA SEMENOVA	{"phone": "+70859661467"}
0005434067817	EAFBCF	0175 044657	VITALIY TIKHONOV	{"email": "vitaliy.tikhonov09051969@postgrespro.ru", "phone": "+70911953588"}
0005434067818	51817F	6196 057212	ALEKSANDR GRIGOREV	{"email": "aleksandrgrigorev.011974@postgrespro.ru", "phone": "+70502203240"}
0005434067819	326B0E	5295 671095	VALENTINA ABRAMOVA	{"email": "abramova-valentina_071976@postgrespro.ru", "phone": "+70656571484"}
0005434067820	0DD816	2650 551994	VITALIY FROLOV	{"email": "v-frolov-04071973@postgrespro.ru", "phone": "+70065056612"}
0005434067821	5DD2A9	6335 033759	OLGA EGOROVA	{"phone": "+70836267750"}
0005434067822	5DD2A9	1205 327674	SOFYA SIDOROVA	{"phone": "+70806966819"}
0005434067823	B74980	6801 292988	AMINA KUZNECOVA	{"email": "amina-kuznecova_27111974@postgrespro.ru", "phone": "+70302108708"}
0005434067824	B74980	6250 734139	LYUBOV LUKYANOVA	{"email": "lyubovlukyanova28041969@postgrespro.ru", "phone": "+70230707162"}
0005434067825	8A251E	2673 887544	VIKTORIYA MASLOVA	{"email": "maslova_v-1968@postgrespro.ru", "phone": "+70205170071"}
0005434067826	EC7251	9365 184137	ANDREY GERASIMOV	{"phone": "+70021977323"}
0005434067827	EC7251	0309 770256	OLEG ZAKHAROV	{"phone": "+70715962624"}
0005434067828	3EE306	9015 048975	MAKSIM FEDOTOV	{"email": "maksim.fedotov011986@postgrespro.ru", "phone": "+70737789767"}
0005434067829	B462C4	6986 291785	VALENTINA SERGEEVA	{"phone": "+70622352079"}
0005434067830	81A3CD	8134 663009	LYUDMILA VOLKOVA	{"phone": "+70971007137"}
0005434067831	49EAB5	9200 519879	VALENTINA MAKSIMOVA	{"phone": "+70892396301"}
0005434067832	B70149	1325 915373	NATALYA ZAKHAROVA	{"email": "n_zakharova_1966@postgrespro.ru", "phone": "+70345154775"}
0005434067833	4BD71A	2833 548624	VALENTIN TARASOV	{"phone": "+70305535910"}
0005434067834	4BD71A	2155 503896	ALENA KULIKOVA	{"email": "akulikova_031976@postgrespro.ru", "phone": "+70662574139"}
0005434067835	C3B89F	1984 983463	NIKOLAY MOISEEV	{"phone": "+70413732307"}
0005434067836	56D1FF	0788 956073	OLGA ZAKHAROVA	{"email": "o.zakharova_1980@postgrespro.ru", "phone": "+70516719790"}
0005434067837	41B1BA	5508 222762	ILYA SAVELEV	{"email": "i_savelev-18071964@postgrespro.ru", "phone": "+70537955793"}
0005434067838	41B1BA	9245 834693	MAKSIM GAVRILOV	{"phone": "+70758585643"}
0005434067839	41B1BA	4297 316483	OLGA EFREMOVA	{"email": "efremova.olga091981@postgrespro.ru", "phone": "+70555034968"}
0005434067840	F06B3E	9553 249193	VLADIMIR SERGEEV	{"phone": "+70330777347"}
0005434067841	955E93	1520 531482	ALINA ZAKHAROVA	{"phone": "+70098781285"}
0005434067842	6C8F80	2555 399830	MARIYA TIKHONOVA	{"phone": "+70902097049"}
0005434067843	313076	1922 682953	GULNARA POTAPOVA	{"email": "potapova.g-111981@postgrespro.ru", "phone": "+70723756072"}
0005434067844	A69297	6172 809408	DMITRIY ZAYCEV	{"email": "zaycev.dmitriy061971@postgrespro.ru", "phone": "+70607790644"}
0005434067845	D99AE9	0233 766308	VALERIYA MIKHAYLOVA	{"phone": "+70578428200"}
0005434067846	BF53E1	2801 341562	TAMARA MEDVEDEVA	{"email": "tamaramedvedeva_1968@postgrespro.ru", "phone": "+70447474941"}
0005434067847	370D23	3327 042764	SOFYA FROLOVA	{"email": "frolova.s-14111974@postgrespro.ru", "phone": "+70580496548"}
0005434067848	5C28C5	1947 564271	VALENTINA YUDINA	{"phone": "+70136769748"}
0005434067849	D20229	0716 526768	VLADIMIR ANDREEV	{"email": "vladimir_andreev_23031967@postgrespro.ru", "phone": "+70488494739"}
0005434067850	9BF1A3	8087 304320	IGOR SMIRNOV	{"email": "igor_smirnov.1978@postgrespro.ru", "phone": "+70623629212"}
0005434067851	8EBE2D	2484 791043	ELENA LAZAREVA	{"phone": "+70649305148"}
0005434067852	45EEE9	9522 909079	ARSEN NIKITIN	{"email": "nikitinarsen1974@postgrespro.ru", "phone": "+70016516696"}
0005434067853	45EEE9	3149 334146	PETR SAVELEV	{"email": "psavelev.1964@postgrespro.ru", "phone": "+70212221328"}
0005434067854	32950F	7290 653093	ANNA EFIMOVA	{"phone": "+70705426930"}
0005434067855	84BF26	5122 405670	RENAT MOROZOV	{"email": "morozovrenat-1968@postgrespro.ru", "phone": "+70829163067"}
0005434067856	D8D4AC	3525 797927	VIKTOR GORBUNOV	{"email": "gorbunov.viktor.091967@postgrespro.ru", "phone": "+70705223651"}
0005434067857	D8D4AC	8000 647861	GALIYA MAKAROVA	{"phone": "+70138632347"}
0005434067858	7EEFFF	8966 776140	ANTON MIRONOV	{"email": "amironov1969@postgrespro.ru", "phone": "+70845978031"}
0005434067859	A6E05D	3475 866131	ELENA MATVEEVA	{"email": "elena_matveeva-1971@postgrespro.ru", "phone": "+70983602668"}
0005434067860	A6E05D	9850 400215	SERGEY KISELEV	{"phone": "+70307589214"}
0005434067861	F772ED	9613 575270	VALENTINA ROMANOVA	{"email": "romanova-v-17111969@postgrespro.ru", "phone": "+70445308104"}
0005434067862	F772ED	6801 331517	NINA MATVEEVA	{"email": "n-matveeva.1984@postgrespro.ru", "phone": "+70629571562"}
0005434067863	B9E564	0276 087310	VALENTINA ILINA	{"email": "valentina.ilina-061973@postgrespro.ru", "phone": "+70627101153"}
0005434067864	B9E564	0585 469494	VLADIMIR ANDREEV	{"phone": "+70654324093"}
0005434067865	C3BADF	5735 632060	VALENTINA CHERNOVA	{"phone": "+70537790999"}
0005434067866	E95717	2542 829493	ROZA SAVELEVA	{"phone": "+70226390018"}
0005434067867	588930	4537 532782	VLADISLAV MARTYNOV	{"phone": "+70478273279"}
0005434067868	589D6C	7279 488156	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana_081967@postgrespro.ru", "phone": "+70915098023"}
0005434067869	A91871	8150 602135	TATYANA DENISOVA	{"phone": "+70854801201"}
0005434067870	A91871	8333 126102	VERA ALEKSEEVA	{"email": "valekseeva.011968@postgrespro.ru", "phone": "+70780655968"}
0005434067871	A91871	8238 521868	GALINA EGOROVA	{"phone": "+70978175795"}
0005434067872	C7C000	4636 960168	TATYANA BOGDANOVA	{"email": "t_bogdanova-071961@postgrespro.ru", "phone": "+70354460120"}
0005434067874	66B0E9	9460 341643	ANNA ALEKSEEVA	{"email": "a_alekseeva.021973@postgrespro.ru", "phone": "+70068431439"}
0005434067875	2B1A48	1152 478687	VALENTIN MEDVEDEV	{"phone": "+70599596720"}
0005434067876	39F12A	5761 713355	TAISIYA MOROZOVA	{"email": "taisiyamorozova.021971@postgrespro.ru", "phone": "+70761536543"}
0005434067877	39F12A	3769 430959	TATYANA KAZAKOVA	{"phone": "+70315887752"}
0005434067878	A8A61A	3633 570613	MARIYA MOISEEVA	{"phone": "+70993733695"}
0005434067879	540A3E	0702 483862	ALEKSEY MAKAROV	{"email": "a_makarov12101977@postgrespro.ru", "phone": "+70176324717"}
0005434067880	D9BCB1	7921 100803	ALEKSANDR MOROZOV	{"phone": "+70245502281"}
0005434067881	65E8EE	2094 408160	ANZHELIKA NIKIFOROVA	{"email": "nikiforova-a_29091977@postgrespro.ru", "phone": "+70779107947"}
0005434067882	F0B6CE	6579 943844	ELENA KAZAKOVA	{"phone": "+70396358110"}
0005434067883	801B32	3050 097414	ELENA NAZAROVA	{"phone": "+70189410482"}
0005434067884	ABC571	8321 310720	ALEKSANDR ZHURAVLEV	{"email": "azhuravlev.051968@postgrespro.ru", "phone": "+70432428026"}
0005434067885	2ABA9D	4577 042852	SVETLANA KOMAROVA	{"phone": "+70904805092"}
0005434067886	EE7CB4	9260 532532	EKATERINA EFREMOVA	{"phone": "+70403220270"}
0005434067887	EE7CB4	3006 819714	TAMARA NOVIKOVA	{"phone": "+70989277854"}
0005434067888	5DF8A4	8265 470747	RAISA ZAKHAROVA	{"phone": "+70245806111"}
0005434067889	572624	2191 100232	SVETLANA RYABOVA	{"email": "svetlana.ryabova-121992@postgrespro.ru", "phone": "+70734688609"}
0005434067890	77EC29	3256 616659	GALINA KOVALEVA	{"email": "kovaleva.galina_041957@postgrespro.ru", "phone": "+70778332152"}
0005434067891	77EC29	3816 918461	VLADIMIR GUSEV	{"phone": "+70379556934"}
0005434067892	A88693	4129 431193	KIRILL KOZLOV	{"email": "kozlov_kirill-17051966@postgrespro.ru", "phone": "+70295296879"}
0005434067893	185D79	7546 588547	ELENA MOISEEVA	{"email": "moiseevaelena1971@postgrespro.ru", "phone": "+70676151567"}
0005434067894	39700A	1889 515067	GALINA SERGEEVA	{"email": "sergeeva.galina1956@postgrespro.ru", "phone": "+70109426945"}
0005434067895	6D5529	3304 910953	VASILIY VOLKOV	{"email": "volkov-v-071974@postgrespro.ru", "phone": "+70159501574"}
0005434067896	C71B34	3374 738266	ALEKSEY DMITRIEV	{"phone": "+70548177368"}
0005434067897	0E49FE	4401 123407	OLGA SERGEEVA	{"phone": "+70176357985"}
0005434067898	225764	1575 502427	ANASTASIYA KOLESNIKOVA	{"phone": "+70139019104"}
0005434067899	F6BE28	6799 159530	VERA KUZNECOVA	{"phone": "+70826413105"}
0005434067900	DA76C3	5527 737681	LYUDMILA KRASNOVA	{"email": "lyudmilakrasnova071969@postgrespro.ru", "phone": "+70830080591"}
0005434067901	DA76C3	0557 195364	ALEKSANDR BORISOV	{"phone": "+70188837745"}
0005434067902	BCB3FD	2068 167530	MIKHAIL DAVYDOV	{"phone": "+70158644341"}
0005434067903	27B98D	7973 433627	ANNA IVANOVA	{"phone": "+70275305536"}
0005434067904	7D517B	1500 827341	NIKOLAY MEDVEDEV	{"phone": "+70808434860"}
0005434067905	65FE2F	3085 437135	IVAN NAZAROV	{"phone": "+70235784607"}
0005434067906	B33FDB	4516 854581	TATYANA POPOVA	{"email": "tatyana-popova05041974@postgrespro.ru", "phone": "+70052480206"}
0005434067907	B33FDB	1266 652453	DIANA POLYAKOVA	{"email": "polyakova-d_15071959@postgrespro.ru", "phone": "+70799087107"}
0005434067908	A18A4D	6408 509888	ALEKSEY ROMANOV	{"phone": "+70820743753"}
0005434067909	A7F7F3	4745 209661	VALENTINA NIKITINA	{"phone": "+70308426864"}
0005434067910	7427BB	0312 824795	ANASTASIYA ABRAMOVA	{"email": "abramova-a031979@postgrespro.ru", "phone": "+70090243126"}
0005434067911	7427BB	8375 745755	VITALIY ZHUKOV	{"phone": "+70064508039"}
0005434067912	D61EB2	3570 942300	NIKOLAY TIKHONOV	{"phone": "+70491896242"}
0005434067913	3651A7	4738 670600	ALEKSEY MAKAROV	{"email": "alekseymakarov25051968@postgrespro.ru", "phone": "+70233718952"}
0005434067914	CD10F7	2811 008364	VALENTINA ARKHIPOVA	{"email": "arkhipova-v1968@postgrespro.ru", "phone": "+70044083168"}
0005434067915	CD10F7	7621 824062	EKATERINA GUSEVA	{"email": "gusevae1969@postgrespro.ru", "phone": "+70357275935"}
0005434067916	CD10F7	6673 452354	ALENA ALEKSANDROVA	{"phone": "+70171979854"}
0005434067917	6D1A40	7385 650356	ALEKSANDR SCHERBAKOV	{"phone": "+70168291821"}
0005434067918	6D1A40	3745 456193	ELENA EGOROVA	{"phone": "+70447533606"}
0005434067919	6D1A40	6610 851065	PAVEL BELOV	{"email": "belov_pavel-011972@postgrespro.ru", "phone": "+70184515265"}
0005434067920	5B6A0A	8094 219354	SVETLANA POPOVA	{"email": "popovas121962@postgrespro.ru", "phone": "+70397436673"}
0005434067921	D1DAD9	9159 399479	ANASTASIYA ARKHIPOVA	{"phone": "+70490807773"}
0005434067922	5EB0B6	2246 667141	ARSENIY DENISOV	{"email": "arseniy_denisov_15071967@postgrespro.ru", "phone": "+70274194299"}
0005434067923	5EB0B6	3338 578056	ARTUR ANTONOV	{"email": "antonov-a_051974@postgrespro.ru", "phone": "+70171503531"}
0005434067924	E14556	9108 312218	VALENTINA FEDOROVA	{"phone": "+70267175427"}
0005434067925	E14556	7248 475492	IVAN BORISOV	{"email": "borisov_i04041969@postgrespro.ru", "phone": "+70051078720"}
0005434067926	E14556	0697 193068	VITALIY SOROKIN	{"email": "vsorokin_1977@postgrespro.ru", "phone": "+70788460110"}
0005434067927	7953A6	9289 154506	VASILIY ZAKHAROV	{"phone": "+70423236226"}
0005434067928	E495C5	6049 746860	FEDOR KUDRYASHOV	{"phone": "+70249065937"}
0005434067929	9C8B32	4861 955167	ANDREY PETROV	{"email": "petrov.a.20051971@postgrespro.ru", "phone": "+70189163018"}
0005434067930	9B5E7D	9275 346879	OLGA ZAKHAROVA	{"email": "zakharova.o.031975@postgrespro.ru", "phone": "+70344749697"}
0005434067931	6D1BC7	4454 597537	VALENTINA NAZAROVA	{"email": "v_nazarova1968@postgrespro.ru", "phone": "+70119182814"}
0005434067932	6D1BC7	7659 794685	NIKOLAY ANTONOV	{"phone": "+70075908731"}
0005434067933	41B917	9948 860423	NATALYA ALEKSANDROVA	{"email": "natalya-aleksandrova1965@postgrespro.ru", "phone": "+70330118738"}
0005434067934	41B917	8627 646304	GALINA BARANOVA	{"phone": "+70222309624"}
0005434067935	41B917	9064 624741	ELENA KOVALEVA	{"email": "kovaleva_elena121972@postgrespro.ru", "phone": "+70362685661"}
0005434067936	7E164B	3469 860424	TATYANA KUZNECOVA	{"phone": "+70708910630"}
0005434067937	7E164B	1462 160306	IVAN ANDREEV	{"email": "ivan.andreev_1978@postgrespro.ru", "phone": "+70058628435"}
0005434067938	BFF882	9048 618577	ARTUR SHEVCHENKO	{"phone": "+70298363979"}
0005434067939	5A7259	2755 996085	GENNADIY FOMIN	{"email": "foming_051968@postgrespro.ru", "phone": "+70247612091"}
0005434067940	5A7259	9502 301546	SVETLANA SERGEEVA	{"phone": "+70468580059"}
0005434067941	DC4B28	0995 606748	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_011970@postgrespro.ru", "phone": "+70840840529"}
0005434067942	862275	9878 764992	ALEKSANDR RODIONOV	{"phone": "+70375713111"}
0005434067943	97F8FA	6647 538427	MARIYA BELOVA	{"phone": "+70901578485"}
0005434067944	D4F0FB	7678 866796	GALINA IVANOVA	{"email": "ivanova-galina-1978@postgrespro.ru", "phone": "+70497157020"}
0005434067945	92ABB9	5286 351327	IGOR MAKSIMOV	{"phone": "+70209625539"}
0005434067946	92ABB9	1814 901629	ALEKSEY EGOROV	{"phone": "+70762456371"}
0005434067947	6E15C7	6577 680083	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr-1975@postgrespro.ru", "phone": "+70445182448"}
0005434067948	2622C7	3267 073656	VALENTINA MELNIKOVA	{"email": "melnikova_v19101976@postgrespro.ru", "phone": "+70825401602"}
0005434067949	2622C7	5577 664450	MAKSIM NOVIKOV	{"phone": "+70640336084"}
0005434067950	AC8790	1599 908010	DMITRIY KRASNOV	{"email": "dmitriykrasnov.101976@postgrespro.ru", "phone": "+70800996965"}
0005434067951	8835EB	7997 238238	ALEKSANDR POPOV	{"email": "a_popov-1964@postgrespro.ru", "phone": "+70268314935"}
0005434067952	E9C7DB	1083 021428	VITALIY NAUMOV	{"phone": "+70860336809"}
0005434067953	A8ADBC	4353 978788	YURIY DENISOV	{"email": "denisov.yuriy_03021972@postgrespro.ru", "phone": "+70072364378"}
0005434067954	A8ADBC	3616 440429	KSENIYA KUDRYASHOVA	{"email": "kseniya-kudryashova-011982@postgrespro.ru", "phone": "+70437377846"}
0005434067955	2E1984	7386 705837	ANTON SOROKIN	{"email": "sorokin-a.08091966@postgrespro.ru", "phone": "+70272326132"}
0005434067956	2AA481	5407 584976	NATALIYA SEMENOVA	{"email": "semenova.n_1973@postgrespro.ru", "phone": "+70225907520"}
0005434067957	2AA481	8069 284483	ALEKSEY PAVLOV	{"phone": "+70867198218"}
0005434067958	2AA481	1829 620702	VITALIY MIKHAYLOV	{"phone": "+70587711389"}
0005434067959	C6ED5E	6470 375877	NATALYA NIKOLAEVA	{"phone": "+70190836992"}
0005434067960	337F82	4108 891553	ANZHELA FILATOVA	{"email": "filatova-anzhela-021967@postgrespro.ru", "phone": "+70058445809"}
0005434067961	371910	2102 581504	EVGENIYA FROLOVA	{"email": "frolovaevgeniya-1977@postgrespro.ru", "phone": "+70308565540"}
0005434067962	371910	6155 044250	EVGENIY VOLKOV	{"email": "evolkov_1983@postgrespro.ru", "phone": "+70779521120"}
0005434067963	8EE246	9690 515832	ANASTASIYA VOROBEVA	{"phone": "+70866273819"}
0005434067964	036642	2664 138222	ELENA SOROKINA	{"email": "sorokina-elena071972@postgrespro.ru", "phone": "+70213085383"}
0005434067965	8AEE96	2838 957562	YULIYA DENISOVA	{"email": "yuliyadenisova_091968@postgrespro.ru", "phone": "+70700428865"}
0005434067966	100871	6772 526714	DMITRIY VLASOV	{"email": "dvlasov_101967@postgrespro.ru", "phone": "+70415773823"}
0005434067967	4A67D6	8862 204165	ELENA ZAKHAROVA	{"phone": "+70926179950"}
0005434067968	4A67D6	2033 754336	OLGA VASILEVA	{"phone": "+70945358006"}
0005434067969	185223	3202 214851	RODION KUZMIN	{"email": "rodion-kuzmin-24061976@postgrespro.ru", "phone": "+70813561861"}
0005434067970	185223	2958 881976	DANIL MELNIKOV	{"phone": "+70011767888"}
0005434067971	185223	0618 755350	MIKHAIL NIKOLAEV	{"email": "m_nikolaev_071974@postgrespro.ru", "phone": "+70548008858"}
0005434067972	21BAD4	7748 252827	ELENA ANDREEVA	{"email": "e-andreeva-041980@postgrespro.ru", "phone": "+70073668581"}
0005434067973	D2365D	4140 101358	VIKTORIYA ALEKSEEVA	{"phone": "+70037507770"}
0005434067974	6AF012	1182 782286	MARIYA IVANOVA	{"email": "ivanova-mariya-1979@postgrespro.ru", "phone": "+70752649393"}
0005434067975	C5BC8E	3780 834162	VALENTINA KOLESNIKOVA	{"email": "valentinakolesnikova.021968@postgrespro.ru", "phone": "+70220361247"}
0005434067976	C5BC8E	4562 234230	MAKSIM ROMANOV	{"phone": "+70375225900"}
0005434067977	9EC586	6934 606208	ALEKSANDR MELNIKOV	{"email": "amelnikov.111955@postgrespro.ru", "phone": "+70570893875"}
0005434067978	42CED5	7421 364573	ALBINA KONOVALOVA	{"phone": "+70786628156"}
0005434067979	ACFFB8	4735 823157	DMITRIY NOVIKOV	{"email": "novikov.dmitriy-051969@postgrespro.ru", "phone": "+70354500921"}
0005434067980	3E94A2	9271 480554	ANTON MAKAROV	{"phone": "+70104944667"}
0005434067981	73EF8F	8013 397366	DMITRIY SOKOLOV	{"email": "d_sokolov08101973@postgrespro.ru", "phone": "+70469016815"}
0005434067982	73EF8F	0470 952351	GALINA KAZAKOVA	{"email": "kazakova-g091967@postgrespro.ru", "phone": "+70139248591"}
0005434067983	311777	3778 472700	OKSANA IVANOVA	{"phone": "+70950458336"}
0005434067984	56A2E7	0497 036326	SVETLANA KRASNOVA	{"email": "s.krasnova.111975@postgrespro.ru", "phone": "+70617847890"}
0005434067985	BD8156	3923 719403	NINA KOMAROVA	{"phone": "+70245046016"}
0005434068265	745F47	1434 592091	VYACHESLAV SERGEEV	{"phone": "+70872112481"}
0005434067986	476AD8	6450 782138	ANTONINA SOROKINA	{"email": "asorokina_11081976@postgrespro.ru", "phone": "+70749999776"}
0005434067987	476AD8	8932 211800	ANTON MAKAROV	{"phone": "+70913806480"}
0005434067988	70D49F	0335 935428	DARYA NIKOLAEVA	{"email": "nikolaeva_d1972@postgrespro.ru", "phone": "+70343776043"}
0005434067989	C9B7DE	2176 992754	LARISA GERASIMOVA	{"email": "l.gerasimova.01041974@postgrespro.ru", "phone": "+70610843638"}
0005434067990	C9B7DE	3414 924982	RAILYA TIKHONOVA	{"email": "tikhonova.railya.1965@postgrespro.ru", "phone": "+70800374765"}
0005434067991	C9B7DE	1737 640752	IGOR NIKOLAEV	{"phone": "+70802956027"}
0005434067992	2AF3C1	8750 967453	YULIYA BELOVA	{"email": "belova-y-021971@postgrespro.ru", "phone": "+70044079755"}
0005434067993	DC96D1	4791 897310	YURIY KOROLEV	{"phone": "+70152779543"}
0005434067994	3FCAFF	2604 785132	ALEKSANDR VLASOV	{"email": "avlasov_1976@postgrespro.ru", "phone": "+70543223394"}
0005434067995	3FCAFF	3126 619046	GRIGORIY TARASOV	{"email": "tarasov_g.1981@postgrespro.ru", "phone": "+70993386093"}
0005434067996	4C657F	0058 133675	ALEKSANDR KUZMIN	{"email": "a_kuzmin1965@postgrespro.ru", "phone": "+70874367443"}
0005434067997	AC8AAD	7981 760599	NADEZHDA FILIPPOVA	{"phone": "+70444302547"}
0005434067998	FACF2F	9152 231169	NIKOLAY FOMIN	{"phone": "+70498427793"}
0005434067999	B2CF5A	1658 443396	MARIYA SOLOVEVA	{"phone": "+70393033091"}
0005434068000	377D88	1557 739775	OLGA FROLOVA	{"phone": "+70942732943"}
0005434068001	C0D69C	7483 594261	NINA YAKOVLEVA	{"phone": "+70853710107"}
0005434068002	A7BE9D	0192 891545	ELENA SCHERBAKOVA	{"email": "elenascherbakova.111970@postgrespro.ru", "phone": "+70609804917"}
0005434068003	A7BE9D	8759 521497	YURIY ANTONOV	{"phone": "+70004988825"}
0005434068004	102AF9	2134 878626	GENNADIY ZHURAVLEV	{"email": "gennadiy-zhuravlev.051985@postgrespro.ru", "phone": "+70717910418"}
0005434068005	2981F6	6035 741591	VIKTOR NAZAROV	{"email": "nazarov.v_1980@postgrespro.ru", "phone": "+70766601743"}
0005434068006	2981F6	5487 822990	IRINA STEPANOVA	{"email": "irina_stepanova.04051971@postgrespro.ru", "phone": "+70158732500"}
0005434068007	2981F6	9008 903176	GALINA GRISHINA	{"email": "g_grishina-1963@postgrespro.ru", "phone": "+70762218553"}
0005434068008	6A6152	9845 715112	IRINA POTAPOVA	{"email": "irina.potapova_1979@postgrespro.ru", "phone": "+70168092516"}
0005434068009	6A6152	1671 606701	VLADIMIR KUZNECOV	{"phone": "+70705488887"}
0005434068010	48F2EC	6193 037766	ANDREY ISAEV	{"phone": "+70548496272"}
0005434068011	48F2EC	6653 050519	SVETLANA POPOVA	{"email": "svetlana_popova-051968@postgrespro.ru", "phone": "+70940431581"}
0005434068012	62FC39	9287 525498	GALINA NIKITINA	{"phone": "+70520559662"}
0005434068013	839204	3089 281936	SVETLANA ZOTOVA	{"phone": "+70964464954"}
0005434068014	C7B3DA	0175 939311	ELENA MEDVEDEVA	{"phone": "+70407097183"}
0005434068015	C7B3DA	1145 744914	GALINA MASLOVA	{"email": "galina_maslova23101977@postgrespro.ru", "phone": "+70811500040"}
0005434068016	29ACD3	6699 370432	NATALIYA MAKSIMOVA	{"phone": "+70163843917"}
0005434068017	66FE3E	3068 762073	ALINA MARTYNOVA	{"phone": "+70012826026"}
0005434068018	4BD63E	8291 330160	LYUDMILA VOROBEVA	{"email": "lyudmila-vorobeva-111965@postgrespro.ru", "phone": "+70167041757"}
0005434068019	4BD63E	0574 523929	ANASTASIYA POPOVA	{"email": "popovaanastasiya091979@postgrespro.ru", "phone": "+70336151089"}
0005434068020	5589C5	2508 309735	NATALIYA DENISOVA	{"email": "n-denisova011980@postgrespro.ru", "phone": "+70483233227"}
0005434068021	1916E8	0892 652610	RAFAEL MELNIKOV	{"email": "rafael-melnikov_09091975@postgrespro.ru", "phone": "+70593632635"}
0005434068022	1916E8	5957 087160	IRINA ISAEVA	{"phone": "+70831579048"}
0005434068023	1916E8	1925 203502	MARIYA KOVALEVA	{"email": "m-kovaleva_20031969@postgrespro.ru", "phone": "+70534369605"}
0005434068024	FB856E	7068 024280	NADEZHDA SOROKINA	{"phone": "+70730210886"}
0005434068025	4C7EA0	1337 864393	VALERIY NIKITIN	{"phone": "+70425068674"}
0005434068026	4C7EA0	8838 599229	ALINA KOLESNIKOVA	{"phone": "+70125871788"}
0005434068027	E27283	8968 453466	VLADIMIR SOLOVEV	{"phone": "+70876506717"}
0005434068028	FC70C3	5694 178978	SERGEY MOROZOV	{"email": "morozov_sergey.111969@postgrespro.ru", "phone": "+70479550552"}
0005434068029	71ED59	6140 357779	ANZHELIKA ISAEVA	{"phone": "+70458122853"}
0005434068030	CEAC73	9673 824176	LYUDMILA ROMANOVA	{"phone": "+70857721081"}
0005434068031	0188C9	0277 268926	ARTEM CHERNOV	{"phone": "+70841443262"}
0005434068032	905325	1429 048859	TATYANA ABRAMOVA	{"email": "abramova-t_1977@postgrespro.ru", "phone": "+70434193071"}
0005434068033	905325	9778 168744	IRINA NIKITINA	{"phone": "+70623429311"}
0005434068034	8C41B6	5627 103493	YURIY GUSEV	{"phone": "+70941830020"}
0005434068035	8C41B6	7802 545185	OLEG KOZLOV	{"email": "oleg.kozlov.10031968@postgrespro.ru", "phone": "+70293535470"}
0005434068036	5A4111	2311 648904	IRINA MOROZOVA	{"phone": "+70373840609"}
0005434068037	5A4111	1414 553759	LYUDMILA ZOTOVA	{"email": "l-zotova17041971@postgrespro.ru", "phone": "+70961209930"}
0005434068038	53DB2A	9200 514553	DMITRIY FROLOV	{"email": "d_frolov.25051963@postgrespro.ru", "phone": "+70156686384"}
0005434068039	30C91B	9869 991942	MIKHAIL MAKAROV	{"email": "mikhail_makarov.08031974@postgrespro.ru", "phone": "+70854273179"}
0005434068040	30C91B	4014 510248	VLADISLAV ANDREEV	{"phone": "+70593298666"}
0005434068041	77436A	3751 008866	IVAN KARPOV	{"email": "karpovivan-061972@postgrespro.ru", "phone": "+70264650327"}
0005434068042	FDBA89	0734 337284	ANTON KUZNECOV	{"email": "kuznecov-anton_13041973@postgrespro.ru", "phone": "+70383743290"}
0005434068043	D06B7E	8303 053065	MIKHAIL MIRONOV	{"phone": "+70677176385"}
0005434068044	D06B7E	1987 203732	VALENTIN ZAYCEV	{"email": "valentinzaycev_21091973@postgrespro.ru", "phone": "+70434433594"}
0005434068045	7E0CA6	1582 901998	ANATOLIY AFANASEV	{"email": "anatoliy_afanasev.1988@postgrespro.ru", "phone": "+70291330827"}
0005434068046	7E0CA6	6627 648394	DMITRIY AFANASEV	{"email": "afanasevdmitriy07101965@postgrespro.ru", "phone": "+70440546800"}
0005434068047	6C6AAE	3118 399423	GALINA NESTEROVA	{"phone": "+70249180125"}
0005434068048	6C6AAE	8532 606609	MILANA ZHURAVLEVA	{"phone": "+70389600348"}
0005434068049	73061D	7777 842301	ZINAIDA BELOVA	{"email": "z.belova-061981@postgrespro.ru", "phone": "+70840135091"}
0005434068050	734AEB	1424 698641	ALENA KUZNECOVA	{"phone": "+70425515229"}
0005434068051	734AEB	9618 012109	VITALIY KUZMIN	{"email": "kuzmin_vitaliy.1958@postgrespro.ru", "phone": "+70951393290"}
0005434068052	734AEB	5888 154407	VIKTOR NOVIKOV	{"email": "v-novikov.121970@postgrespro.ru", "phone": "+70658511649"}
0005434068053	029F43	4185 014809	SVETLANA MEDVEDEVA	{"email": "svetlanamedvedeva.081977@postgrespro.ru", "phone": "+70056371315"}
0005434068054	C2D8BA	5199 747663	VLADIMIR SMIRNOV	{"phone": "+70154173154"}
0005434068055	9C8A4E	9919 782818	VERONIKA KUZNECOVA	{"email": "vkuznecova.021975@postgrespro.ru", "phone": "+70422157162"}
0005434068056	9C8A4E	6062 757194	SVETLANA FILIPPOVA	{"email": "s_filippova_1977@postgrespro.ru", "phone": "+70148955929"}
0005434068057	4EF438	6103 874537	VLADIMIR DMITRIEV	{"phone": "+70882160850"}
0005434068058	4EF438	2490 047499	ILDAR ZAKHAROV	{"phone": "+70682302722"}
0005434068059	4EF438	8689 548178	IGOR KUZNECOV	{"phone": "+70475873364"}
0005434068060	2154B9	2040 704966	YURIY IVANOV	{"phone": "+70093536238"}
0005434068061	76D12D	4895 458163	ANZHELA ALEKSANDROVA	{"phone": "+70207229992"}
0005434068062	CC16C4	0639 788245	VITALIY CHERNOV	{"phone": "+70917014159"}
0005434068063	CC16C4	1455 635919	POLINA KOZLOVA	{"email": "kozlovap-1975@postgrespro.ru", "phone": "+70432406545"}
0005434068064	CC16C4	5790 336378	ALEKSANDR ANTONOV	{"phone": "+70373193148"}
0005434068065	E58546	3647 941732	VALERIYA LOGINOVA	{"phone": "+70495657562"}
0005434068066	6D8701	8483 057882	VYACHESLAV NAUMOV	{"phone": "+70896759897"}
0005434068067	6D8701	7047 374063	MARINA VOROBEVA	{"email": "vorobevamarina.011968@postgrespro.ru", "phone": "+70796946862"}
0005434068068	B899D1	1543 322663	SERGEY VASILEV	{"phone": "+70317793741"}
0005434068069	9B6245	2206 597748	DENIS PETROV	{"phone": "+70216340658"}
0005434068070	9B6245	0541 782132	ALEKSANDR NOVIKOV	{"email": "aleksandr_novikov.051972@postgrespro.ru", "phone": "+70232330946"}
0005434068071	20A195	9838 915265	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov_1982@postgrespro.ru", "phone": "+70691285688"}
0005434068072	3DD756	1281 832821	GALINA ZHURAVLEVA	{"email": "zhuravleva.galina_21091974@postgrespro.ru", "phone": "+70576893137"}
0005434068073	40525D	5814 638951	ANASTASIYA ILINA	{"email": "ilina_a_05011966@postgrespro.ru", "phone": "+70651065806"}
0005434068074	576345	9280 990050	OKSANA OVCHINNIKOVA	{"phone": "+70049272245"}
0005434068075	576345	1600 044986	SERGEY SOROKIN	{"phone": "+70932732095"}
0005434068076	C84054	8353 188178	OLGA POPOVA	{"email": "olgapopova-071968@postgrespro.ru", "phone": "+70544186993"}
0005434068077	C84054	5270 164312	GALINA SOROKINA	{"phone": "+70891420144"}
0005434068078	1B815F	6804 070563	GALINA NESTEROVA	{"phone": "+70955580949"}
0005434068079	83B66E	4456 334988	ALEKSEY MAKSIMOV	{"email": "maksimov-aleksey-1989@postgrespro.ru", "phone": "+70541438952"}
0005434068080	83B66E	8342 661523	IRINA LAZAREVA	{"phone": "+70487636700"}
0005434068081	C82055	5157 381095	VIKTOR DENISOV	{"email": "denisov-viktor.071971@postgrespro.ru", "phone": "+70697940540"}
0005434068082	F91C90	4855 427843	MIKHAIL MAKAROV	{"email": "m-makarov-02101968@postgrespro.ru", "phone": "+70967949052"}
0005434068083	0C8733	7250 325430	OLGA KOZLOVA	{"email": "o_kozlova31031974@postgrespro.ru", "phone": "+70696806072"}
0005434068084	1ACFF9	2482 530949	LARISA MOROZOVA	{"phone": "+70964491887"}
0005434068085	CBFA70	6631 319744	LYUDMILA KOZLOVA	{"phone": "+70527630215"}
0005434068086	89DB54	6929 296325	PAVEL TIMOFEEV	{"phone": "+70329867277"}
0005434068087	997643	7439 586796	VALERIY MAKSIMOV	{"phone": "+70333334187"}
0005434068088	997643	0821 522088	ZOYA ANDREEVA	{"phone": "+70067647868"}
0005434068089	E7DBBD	1723 985512	VALERIY VASILEV	{"phone": "+70919308965"}
0005434068090	E7DBBD	1541 204199	SERGEY FEDOTOV	{"email": "sergey_fedotov1968@postgrespro.ru", "phone": "+70467421565"}
0005434068091	A67F5D	5254 023246	ALEFTINA KOROLEVA	{"email": "akoroleva-12021980@postgrespro.ru", "phone": "+70404147712"}
0005434068092	C810B1	7160 386222	ALINA IVANOVA	{"email": "aivanova_1976@postgrespro.ru", "phone": "+70235960360"}
0005434068093	CBC4A2	3518 785175	SOFIYA TIKHONOVA	{"phone": "+70064411487"}
0005434068094	763047	5437 884434	VLADIMIR KOZLOV	{"email": "vladimirkozlov28061978@postgrespro.ru", "phone": "+70105754554"}
0005434068095	763047	4762 030105	KONSTANTIN ANTONOV	{"phone": "+70585535296"}
0005434068096	BD3C43	1747 390786	LIDIYA POTAPOVA	{"email": "lpotapova.091971@postgrespro.ru", "phone": "+70674854104"}
0005434068097	C1AA22	3930 806025	EVGENIYA RODIONOVA	{"phone": "+70397172748"}
0005434068321	490295	5737 822263	NIKOLAY NAZAROV	{"phone": "+70695718749"}
0005434068098	3D4907	8499 471211	OLGA DENISOVA	{"email": "o_denisova_1980@postgrespro.ru", "phone": "+70350365757"}
0005434068099	3D4907	6453 300199	TATYANA TIMOFEEVA	{"email": "tatyana-timofeeva-1969@postgrespro.ru", "phone": "+70051751070"}
0005434068100	D52EB1	1229 173932	ALEKSEY BARANOV	{"email": "baranov.a1973@postgrespro.ru", "phone": "+70320844021"}
0005434068101	BD3A2A	6762 335889	ALEKSANDR SOROKIN	{"phone": "+70699512898"}
0005434068102	733A33	5452 322310	VLADIMIR AFANASEV	{"phone": "+70238393698"}
0005434068103	733A33	8714 778346	VALENTINA ABRAMOVA	{"email": "vabramova-041982@postgrespro.ru", "phone": "+70882493727"}
0005434068104	593E55	3999 587001	ANDREY STEPANOV	{"phone": "+70361051813"}
0005434068105	3D88E5	0800 622792	NIKITA VASILEV	{"email": "vasilev-nikita_19071982@postgrespro.ru", "phone": "+70549952883"}
0005434068106	16E4B6	8737 916852	POLINA MOROZOVA	{"phone": "+70996142358"}
0005434068107	69908A	0017 320278	ELENA VASILEVA	{"email": "e-vasileva.031969@postgrespro.ru", "phone": "+70651599941"}
0005434068108	3FF4D7	4803 282596	GLEB FROLOV	{"phone": "+70277638498"}
0005434068109	5CD714	4743 042395	BORIS SAVELEV	{"email": "boris.savelev.16051975@postgrespro.ru", "phone": "+70736202028"}
0005434068110	AC90A7	4798 357236	IVAN VLASOV	{"email": "vlasovi.1972@postgrespro.ru", "phone": "+70364956567"}
0005434068111	AC90A7	5383 852341	VALENTINA POPOVA	{"phone": "+70374686139"}
0005434068112	571A6F	7407 106989	NATALYA DENISOVA	{"phone": "+70228426834"}
0005434068113	571A6F	4603 602477	MAKSIM ZAKHAROV	{"email": "zakharov_m26011968@postgrespro.ru", "phone": "+70294656646"}
0005434068114	2E75F5	9841 742397	MARINA KOZLOVA	{"email": "marina.kozlova-1962@postgrespro.ru", "phone": "+70534131208"}
0005434068115	62CD9A	9584 841871	STEPAN SOKOLOV	{"email": "stepan_sokolov_14021967@postgrespro.ru", "phone": "+70383541949"}
0005434068116	6DBF8A	6272 630433	EKATERINA MAKAROVA	{"email": "makarova.ekaterina.14091977@postgrespro.ru", "phone": "+70434787840"}
0005434068117	6DBF8A	8797 657248	VALERIY MAKAROV	{"phone": "+70443313129"}
0005434068118	6DBF8A	6295 667735	NINA KUDRYASHOVA	{"phone": "+70784886539"}
0005434068119	9F0995	7958 781693	GENNADIY TARASOV	{"phone": "+70561871242"}
0005434068120	9F0995	4848 017992	ANDREY ZAKHAROV	{"phone": "+70914424147"}
0005434068121	5DCE5B	7858 195714	ELIZAVETA NIKITINA	{"phone": "+70900959126"}
0005434068122	7397A8	4291 269517	PAVEL STEPANOV	{"email": "pstepanov071975@postgrespro.ru", "phone": "+70060792808"}
0005434068123	6225C3	0863 466332	NURLAN SOLOVEV	{"phone": "+70236825813"}
0005434068124	6225C3	6489 475576	EVGENIY SERGEEV	{"email": "sergeeve_27091978@postgrespro.ru", "phone": "+70604485400"}
0005434068125	BA78E3	3040 207264	ALEKSANDR MATVEEV	{"email": "aleksandrmatveev-041980@postgrespro.ru", "phone": "+70427167683"}
0005434068126	581871	1908 485729	RAISA MOROZOVA	{"email": "r_morozova_15061970@postgrespro.ru", "phone": "+70838024883"}
0005434068127	620D3D	9737 528769	TAMARA SCHERBAKOVA	{"email": "tamara-scherbakova-061975@postgrespro.ru", "phone": "+70227054172"}
0005434068128	C79401	3495 425609	ANNA DENISOVA	{"phone": "+70233710054"}
0005434068129	CD932C	4068 192477	MIKHAIL ALEKSANDROV	{"phone": "+70140658271"}
0005434068130	BBB6F9	8171 318622	GALINA KUZNECOVA	{"email": "kuznecova.g-14061970@postgrespro.ru", "phone": "+70963291816"}
0005434068131	324546	6183 979720	IRINA ZHUKOVA	{"phone": "+70342908731"}
0005434068132	0107DE	7359 199764	VALENTIN KULIKOV	{"phone": "+70147713872"}
0005434068133	0107DE	0625 926102	VIKTOR CHERNOV	{"phone": "+70156161036"}
0005434068134	88A321	1939 958315	IRINA PETROVA	{"email": "irinapetrova_21101973@postgrespro.ru", "phone": "+70330006890"}
0005434068135	39F316	3421 723610	TATYANA ZAKHAROVA	{"phone": "+70236849948"}
0005434068136	0BFCB9	5939 622414	RAFAIL GAVRILOV	{"email": "gavrilov_rafail1965@postgrespro.ru", "phone": "+70629134403"}
0005434068137	0BFCB9	4627 139171	GALINA YAKOVLEVA	{"email": "galinayakovleva_051970@postgrespro.ru", "phone": "+70297132073"}
0005434068138	CBF869	6689 793896	SERGEY MOISEEV	{"email": "moiseev.sergey.011976@postgrespro.ru", "phone": "+70684715950"}
0005434068139	DC5136	3393 032570	TATYANA MARTYNOVA	{"email": "martynova.tatyana-1977@postgrespro.ru", "phone": "+70558973742"}
0005434068140	DC5136	3476 468980	VIKTOR NOVIKOV	{"email": "vnovikov_061970@postgrespro.ru", "phone": "+70441772932"}
0005434068141	016829	8423 177067	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.1979@postgrespro.ru", "phone": "+70835095273"}
0005434068142	CAB732	6009 371507	INNA GORBUNOVA	{"email": "i.gorbunova-1974@postgrespro.ru", "phone": "+70025288240"}
0005434068143	79E2C0	2800 036501	VASILIY RODIONOV	{"phone": "+70491061928"}
0005434068144	A9007F	2447 314958	ANATOLIY KOROLEV	{"email": "akorolev1974@postgrespro.ru", "phone": "+70898614824"}
0005434068145	A9007F	3578 457507	LILIYA BELYAEVA	{"email": "belyaeval-24121983@postgrespro.ru", "phone": "+70474423343"}
0005434068146	A9007F	7823 445091	LIDIYA POPOVA	{"phone": "+70202024437"}
0005434068147	0948D6	4634 845167	ELENA IVANOVA	{"phone": "+70397298394"}
0005434068148	C6B9FC	7272 814188	ELENA VOLKOVA	{"phone": "+70003745984"}
0005434068149	C70376	6627 348153	VLADIMIR BELOV	{"phone": "+70569551920"}
0005434068150	C4E090	6701 072565	DMITRIY KUZNECOV	{"email": "d_kuznecov.15061979@postgrespro.ru", "phone": "+70600124819"}
0005434068151	C4E090	1036 907378	NIKOLAY MEDVEDEV	{"phone": "+70242431123"}
0005434068152	573E97	7133 217661	EGOR MOROZOV	{"email": "morozov_e091980@postgrespro.ru", "phone": "+70547320266"}
0005434068153	616186	7688 800828	ELENA KONOVALOVA	{"phone": "+70019249764"}
0005434068154	AE6B5A	0403 043788	AZAT KUZNECOV	{"email": "azatkuznecov.011977@postgrespro.ru", "phone": "+70435249224"}
0005434068155	AE6B5A	4694 491714	DMITRIY SEMENOV	{"email": "semenov-d.061971@postgrespro.ru", "phone": "+70115932102"}
0005434068156	74F35B	0766 347709	OLGA SIDOROVA	{"phone": "+70302951366"}
0005434068157	C06E6E	5693 289180	DANIIL ALEKSEEV	{"phone": "+70732888540"}
0005434068158	D46B8F	3994 396213	NATALYA MAKAROVA	{"phone": "+70986555951"}
0005434068159	D46B8F	5628 428110	MATVEY ABRAMOV	{"phone": "+70353703343"}
0005434068160	2A4CBD	5458 920016	SERGEY KONOVALOV	{"phone": "+70355710457"}
0005434068161	325BF8	7281 550614	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.tatyana_1966@postgrespro.ru", "phone": "+70159375178"}
0005434068162	325BF8	3072 986090	IVAN CHERNOV	{"email": "chernovi_121972@postgrespro.ru", "phone": "+70722175136"}
0005434068163	5AACBE	7000 207538	SERGEY MEDVEDEV	{"email": "medvedevsergey-031972@postgrespro.ru", "phone": "+70875503600"}
0005434068164	5AACBE	6017 317330	ARTUR TARASOV	{"phone": "+70017984764"}
0005434068165	541361	9325 237019	IRINA KUZNECOVA	{"phone": "+70304078989"}
0005434068166	45F7E7	2688 672450	VLADIMIR KULIKOV	{"phone": "+70327412976"}
0005434068167	0BE6B6	1523 287898	VENIAMIN IVANOV	{"phone": "+70098176913"}
0005434068168	0BE6B6	2365 782749	ANTONINA TIMOFEEVA	{"email": "antoninatimofeeva_081965@postgrespro.ru", "phone": "+70674485368"}
0005434068169	2672B1	6625 141982	VALERIY FROLOV	{"phone": "+70151398962"}
0005434068170	D8E008	3231 896721	DMITRIY RODIONOV	{"phone": "+70740493578"}
0005434068171	D07712	9119 975147	GEVORG MEDVEDEV	{"email": "medvedevgevorg1978@postgrespro.ru", "phone": "+70605578415"}
0005434068172	0101DE	0694 832327	NINA VOLKOVA	{"email": "nina-volkova-071973@postgrespro.ru", "phone": "+70319545097"}
0005434068173	E7857C	8277 668473	SERGEY ABRAMOV	{"phone": "+70754487795"}
0005434068174	E7857C	4697 019518	VLADIMIR ZAKHAROV	{"phone": "+70936089344"}
0005434068175	3ABE99	7385 224959	LIDIYA KOLESNIKOVA	{"email": "l_kolesnikova081974@postgrespro.ru", "phone": "+70604885784"}
0005434068176	3ABE99	7651 438862	TAMARA IVANOVA	{"email": "tamara.ivanova_1963@postgrespro.ru", "phone": "+70602800833"}
0005434068177	3ABE99	3265 942417	VALENTINA ANISIMOVA	{"phone": "+70954734873"}
0005434068178	2DAC5D	0753 307403	VERA FROLOVA	{"email": "v-frolova07041971@postgrespro.ru", "phone": "+70061562846"}
0005434068179	E53472	1347 878483	ELIZAVETA MIKHAYLOVA	{"email": "emikhaylova_14011971@postgrespro.ru", "phone": "+70417465541"}
0005434068180	E53472	9096 772819	KIRILL NIKOLAEV	{"email": "kirill_nikolaev111972@postgrespro.ru", "phone": "+70692038635"}
0005434068181	945A48	9231 581645	MARK MATVEEV	{"email": "matveev-mark1960@postgrespro.ru", "phone": "+70444372293"}
0005434068182	1639B3	3372 497938	ALEKSANDR VLASOV	{"email": "aleksandrvlasov1969@postgrespro.ru", "phone": "+70586002568"}
0005434068183	59F828	5027 009431	DMITRIY SCHERBAKOV	{"phone": "+70080675647"}
0005434068184	137453	7714 683125	TATYANA VOLKOVA	{"phone": "+70848970091"}
0005434068185	F94458	3601 522967	VLADIMIR ORLOV	{"email": "orlov_vladimir-111980@postgrespro.ru", "phone": "+70619622913"}
0005434068186	83E616	7549 716043	RUSLAN KOZLOV	{"phone": "+70945806356"}
0005434068187	83E616	6344 152731	NINA GUSEVA	{"email": "nina-guseva-011977@postgrespro.ru", "phone": "+70388518115"}
0005434068188	A933E7	9164 769756	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov-08011965@postgrespro.ru", "phone": "+70242240270"}
0005434068189	A933E7	4126 942347	MIKHAIL SERGEEV	{"email": "sergeevmikhail.25091976@postgrespro.ru", "phone": "+70308421431"}
0005434068190	107DE4	7851 309359	ROMAN MARTYNOV	{"phone": "+70971025826"}
0005434068191	E9A52B	0330 932026	ELENA CHERNOVA	{"email": "chernova_e.011970@postgrespro.ru", "phone": "+70378412277"}
0005434068192	E9A52B	9349 472876	ALEKSANDR NIKOLAEV	{"phone": "+70457431786"}
0005434068193	397DC6	8592 407646	IRINA EGOROVA	{"email": "i.egorova_29071977@postgrespro.ru", "phone": "+70475222264"}
0005434068194	FBC2BA	3773 880369	DINA POPOVA	{"email": "popova_dina_14111974@postgrespro.ru", "phone": "+70137823913"}
0005434068195	2C0436	0669 557292	ALEKSEY ALEKSEEV	{"phone": "+70691774614"}
0005434068196	D6DD55	1328 614051	EKATERINA PETROVA	{"email": "e-petrova.011975@postgrespro.ru", "phone": "+70470230686"}
0005434068197	DEBB0F	6105 796856	OLGA PETROVA	{"email": "petrova_olga-20021969@postgrespro.ru", "phone": "+70257188229"}
0005434068198	7FD3DB	7968 182961	ZINAIDA NESTEROVA	{"phone": "+70122952509"}
0005434068199	7FD3DB	8897 446814	ROMAN ROMANOV	{"email": "roman-romanov-28061967@postgrespro.ru", "phone": "+70054067453"}
0005434068200	501CC4	2809 064930	LYUBOV CHERNOVA	{"phone": "+70966294667"}
0005434068201	E5AC2A	3962 213155	ALEKSANDRA KONOVALOVA	{"email": "konovalova_a-30091961@postgrespro.ru", "phone": "+70438085383"}
0005434068202	CA0F89	3742 839384	ELENA KOMAROVA	{"email": "komarovaelena031967@postgrespro.ru", "phone": "+70262727382"}
0005434068203	49FF61	2356 802301	IRINA ALEKSANDROVA	{"email": "irinaaleksandrova01041973@postgrespro.ru", "phone": "+70536411939"}
0005434068204	92FE25	6946 063552	LILIYA ROMANOVA	{"email": "romanova-liliya.1986@postgrespro.ru", "phone": "+70943581385"}
0005434068205	A81387	0235 822298	TAMARA DANILOVA	{"email": "tamaradanilova.081986@postgrespro.ru", "phone": "+70785095366"}
0005434068206	A81387	8149 515770	LIDIYA FILIPPOVA	{"phone": "+70822542584"}
0005434068207	A81387	0692 602263	DMITRIY DAVYDOV	{"phone": "+70456333547"}
0005434068208	47CC37	7178 398665	LIDIYA MOISEEVA	{"email": "lmoiseeva.03121957@postgrespro.ru", "phone": "+70028583155"}
0005434068322	AB8102	7839 664684	TAISIYA VOLKOVA	{"phone": "+70670993232"}
0005434068209	504B66	0039 454197	TATYANA IVANOVA	{"email": "ivanova_tatyana_17121968@postgrespro.ru", "phone": "+70484174732"}
0005434068210	129B0C	9149 830760	ALEKSANDR SCHERBAKOV	{"phone": "+70110216879"}
0005434068509	D207E7	2711 450191	ALEKSANDR POPOV	{"phone": "+70831644681"}
0005434068211	129B0C	5053 114000	ELENA KONDRATEVA	{"email": "kondrateva.e-081970@postgrespro.ru", "phone": "+70940589334"}
0005434068212	0890FA	0846 384508	VADIM TIKHONOV	{"email": "vadim-tikhonov.02091974@postgrespro.ru", "phone": "+70487092788"}
0005434068213	83AFAD	2993 218427	VLADISLAV VOROBEV	{"email": "v.vorobev10121964@postgrespro.ru", "phone": "+70711157826"}
0005434068214	83AFAD	0242 545979	OLGA GAVRILOVA	{"email": "gavrilova_olga_1977@postgrespro.ru", "phone": "+70463406009"}
0005434068215	2D1384	8905 595039	OKSANA VOLKOVA	{"phone": "+70299538523"}
0005434068216	2D1384	7036 041599	SERGEY VOROBEV	{"email": "vorobevs-28081967@postgrespro.ru", "phone": "+70701225750"}
0005434068217	8456C5	0315 734509	ALEKSANDR ANDREEV	{"email": "aandreev_03071980@postgrespro.ru", "phone": "+70787078268"}
0005434068218	8456C5	0784 870036	VIKTOR KUZNECOV	{"phone": "+70162155017"}
0005434068219	7A14D2	7372 552954	ZOYA MASLOVA	{"phone": "+70014321415"}
0005434068220	7A14D2	9749 390173	EKATERINA MALYSHEVA	{"phone": "+70671312421"}
0005434068221	9CEB28	7919 838745	ALEKSEY ROMANOV	{"email": "romanovaleksey.23021979@postgrespro.ru", "phone": "+70768660767"}
0005434068222	9CEB28	4150 791246	SVETLANA ANDREEVA	{"phone": "+70010969790"}
0005434068223	0EACAE	0931 576411	ALEKSANDR KAZAKOV	{"email": "kazakov_a-13091972@postgrespro.ru", "phone": "+70528185900"}
0005434068224	98D3C8	3495 020389	MAKSIM STEPANOV	{"phone": "+70263871164"}
0005434068225	9716E1	6347 041893	MARIYA SERGEEVA	{"phone": "+70683408368"}
0005434068226	F4B773	9455 829069	MARINA FADEEVA	{"phone": "+70093836385"}
0005434068227	F4B773	9367 628154	LEONID NOVIKOV	{"phone": "+70273524779"}
0005434068228	F4B773	0209 097906	EVGENIY SMIRNOV	{"email": "evgeniysmirnov-091969@postgrespro.ru", "phone": "+70462180852"}
0005434068229	0822B3	4598 935280	NADEZHDA SCHERBAKOVA	{"email": "scherbakova-n09081964@postgrespro.ru", "phone": "+70298813622"}
0005434068230	4C0E76	0668 296892	DMITRIY IVANOV	{"email": "ivanov.d-19091972@postgrespro.ru", "phone": "+70036177843"}
0005434068231	8299B4	0108 449199	EVGENIY ALEKSANDROV	{"phone": "+70479847632"}
0005434068232	8299B4	0817 198107	ALEKSANDR MOISEEV	{"phone": "+70589462653"}
0005434068233	BB1501	8371 338917	KIRILL VOROBEV	{"phone": "+70819127444"}
0005434068234	E1D084	2740 986011	DENIS GORBUNOV	{"email": "gorbunovdenis061972@postgrespro.ru", "phone": "+70004843080"}
0005434068235	A78ECE	1171 626073	SEMEN KRASNOV	{"email": "s_krasnov.041964@postgrespro.ru", "phone": "+70713016598"}
0005434068236	A78ECE	8402 401795	VLADIMIR KAZAKOV	{"phone": "+70127624280"}
0005434068237	01F755	0661 202874	ALEKSANDR KRASNOV	{"email": "krasnova.12101969@postgrespro.ru", "phone": "+70629697748"}
0005434068238	0BE0E0	3929 085118	SAVELIY VLASOV	{"email": "svlasov-061965@postgrespro.ru", "phone": "+70403854215"}
0005434068239	1BE2C9	5659 529242	ALEKSEY FEDOROV	{"phone": "+70371672014"}
0005434068240	B2D8A2	6415 779947	MARGARITA PETROVA	{"phone": "+70122838341"}
0005434068241	3C5B6F	9807 386435	VLADISLAV ABRAMOV	{"email": "v-abramov-29081973@postgrespro.ru", "phone": "+70058728746"}
0005434068242	3C5B6F	9263 936845	ALEKSANDR FROLOV	{"phone": "+70702551288"}
0005434068243	3C5B6F	0251 632171	YURIY VASILEV	{"email": "yuriy.vasilev1967@postgrespro.ru", "phone": "+70942527828"}
0005434068244	BD6CC6	9932 885682	ALEKSEY PETROV	{"email": "alekseypetrov-121966@postgrespro.ru", "phone": "+70261161183"}
0005434068245	24BCF6	6105 827930	NINA POPOVA	{"email": "ninapopova_111975@postgrespro.ru", "phone": "+70537502574"}
0005434068246	4582F7	2516 778063	NIKOLAY MOROZOV	{"email": "morozovnikolay-1981@postgrespro.ru", "phone": "+70240179529"}
0005434068247	4582F7	9513 029856	VERA FILATOVA	{"phone": "+70009009050"}
0005434068248	54054E	4014 510989	RAISA GAVRILOVA	{"email": "gavrilova_raisa.051971@postgrespro.ru", "phone": "+70857939920"}
0005434068249	54054E	0673 958365	PAVEL MELNIKOV	{"phone": "+70706416327"}
0005434068250	B67B40	9365 861376	ZHANNA BELOVA	{"email": "zhanna.belova.05021971@postgrespro.ru", "phone": "+70358500833"}
0005434068251	B67B40	9327 728439	VERA VASILEVA	{"phone": "+70779468736"}
0005434068252	B67B40	1803 436771	VADIM ZHURAVLEV	{"phone": "+70906221284"}
0005434068253	4F04D3	1963 207716	NINA BOGDANOVA	{"phone": "+70816151086"}
0005434068254	327E19	1294 870409	NADEZHDA EFREMOVA	{"email": "efremova-n1968@postgrespro.ru", "phone": "+70173273224"}
0005434068255	B06B6A	0844 681960	VLADIMIR ANDREEV	{"phone": "+70265932497"}
0005434068256	163E70	4006 786005	OLEG KUZNECOV	{"email": "kuznecovo_06111978@postgrespro.ru", "phone": "+70787954867"}
0005434068257	49404D	3439 695016	YURIY KONOVALOV	{"phone": "+70010712276"}
0005434068258	49404D	6811 923714	RAMIL POPOV	{"email": "popov_ramil1955@postgrespro.ru", "phone": "+70120010336"}
0005434068259	17F4B3	0521 745165	OLGA NAZAROVA	{"email": "nazarova-olga_041973@postgrespro.ru", "phone": "+70995472135"}
0005434068260	A4B8E5	0518 705309	LYUDMILA KOVALEVA	{"email": "kovaleva_l1972@postgrespro.ru", "phone": "+70302297558"}
0005434068261	A4B8E5	5801 132863	VYACHESLAV ZAKHAROV	{"phone": "+70103475323"}
0005434068262	78340C	4455 870964	NATALYA ILINA	{"phone": "+70564391018"}
0005434068263	7DBE7C	7149 993966	GALINA MAKAROVA	{"email": "galina.makarova1960@postgrespro.ru", "phone": "+70915759986"}
0005434068264	7DBE7C	4770 383397	ANNA RODIONOVA	{"email": "rodionovaanna.1973@postgrespro.ru", "phone": "+70068610187"}
0005434068266	8C5908	1610 443452	VIKTOR MOISEEV	{"email": "moiseevv-27021973@postgrespro.ru", "phone": "+70034634099"}
0005434068267	66B350	1184 667484	ANDREY MATVEEV	{"email": "andrey.matveev.1972@postgrespro.ru", "phone": "+70676709236"}
0005434068268	7F97FB	8334 213374	GENNADIY TARASOV	{"phone": "+70223827354"}
0005434068269	D11C62	1515 662449	ARTEM SERGEEV	{"email": "sergeev-a061975@postgrespro.ru", "phone": "+70480885412"}
0005434068270	A4D918	7097 303059	MARGARITA KOROLEVA	{"email": "m_koroleva_11111971@postgrespro.ru", "phone": "+70532832314"}
0005434068271	91DAA6	6084 515897	MAKSIM SIDOROV	{"phone": "+70368423791"}
0005434068272	67B790	0980 048748	NATALYA KOVALEVA	{"email": "natalyakovaleva_1978@postgrespro.ru", "phone": "+70757641535"}
0005434068273	067C72	4729 969334	LYUDMILA LAZAREVA	{"phone": "+70162268518"}
0005434068274	067C72	1879 216375	MARIYA PAVLOVA	{"email": "pavlova.mariya-021979@postgrespro.ru", "phone": "+70939683267"}
0005434068275	18D34B	2888 917825	EVGENIY FEDOTOV	{"phone": "+70492124863"}
0005434068276	A311C4	3859 996181	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr-091973@postgrespro.ru", "phone": "+70579487791"}
0005434068277	A311C4	0212 735425	NATALYA TIMOFEEVA	{"email": "natalya_timofeeva07121968@postgrespro.ru", "phone": "+70122032714"}
0005434068278	E9F405	9064 208778	VALENTINA STEPANOVA	{"phone": "+70282757681"}
0005434068279	E9F405	5939 083024	ALBINA DMITRIEVA	{"email": "dmitrievaa_1964@postgrespro.ru", "phone": "+70872247726"}
0005434068280	C2F511	2287 536751	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov-1976@postgrespro.ru", "phone": "+70252310159"}
0005434068281	092C9C	0634 676641	OLGA IVANOVA	{"email": "o-ivanova-1973@postgrespro.ru", "phone": "+70434375115"}
0005434068282	766643	9173 878903	OKSANA POTAPOVA	{"phone": "+70854791048"}
0005434068283	766643	5394 650299	DENIS RODIONOV	{"email": "rodionov-d031965@postgrespro.ru", "phone": "+70586897587"}
0005434068284	5C6F97	8683 035522	MIROSLAV BORISOV	{"email": "borisovm_1971@postgrespro.ru", "phone": "+70002912938"}
0005434068285	547A35	8991 665554	KLAVDIYA MOISEEVA	{"email": "moiseeva_k.07081966@postgrespro.ru", "phone": "+70127159648"}
0005434068286	547A35	8393 805055	SVETLANA DENISOVA	{"email": "denisova_svetlana-041981@postgrespro.ru", "phone": "+70936906388"}
0005434068287	B416AF	7618 740504	ANATOLIY MOISEEV	{"phone": "+70845292004"}
0005434068288	AB9A8B	1562 053125	ANZHELIKA ALEKSEEVA	{"email": "alekseevaa-021975@postgrespro.ru", "phone": "+70772278337"}
0005434068289	71944B	2317 893190	ALEKSANDR KULIKOV	{"email": "aleksandr-kulikov-1978@postgrespro.ru", "phone": "+70263243905"}
0005434068290	5BB1D8	4425 247110	GALINA LEBEDEVA	{"email": "g-lebedeva.061966@postgrespro.ru", "phone": "+70093910922"}
0005434068291	5BB1D8	5667 962643	NATALYA SOLOVEVA	{"email": "soloveva.natalya-1964@postgrespro.ru", "phone": "+70730698872"}
0005434068292	5BB1D8	9917 455699	NIKOLAY NIKOLAEV	{"email": "nikolaev.nikolay_051971@postgrespro.ru", "phone": "+70011049784"}
0005434068293	4B691D	5476 960412	ALEKSANDR ROMANOV	{"email": "romanovaleksandr-061975@postgrespro.ru", "phone": "+70995335460"}
0005434068294	045073	2829 220714	NAZIYA NESTEROVA	{"phone": "+70220128416"}
0005434068295	5130AD	4561 404603	ELIZAVETA SOKOLOVA	{"email": "sokolova-elizaveta.051961@postgrespro.ru", "phone": "+70478981852"}
0005434068296	5130AD	9872 138234	OLGA IVANOVA	{"phone": "+70963354306"}
0005434068297	FEB73E	3041 239212	TATYANA EGOROVA	{"email": "t.egorova-021965@postgrespro.ru", "phone": "+70345510437"}
0005434068298	59F32E	3071 557176	LYUBOV GAVRILOVA	{"email": "gavrilova.l1964@postgrespro.ru", "phone": "+70416798808"}
0005434068299	603A53	6158 830111	ANNA PETROVA	{"phone": "+70725367148"}
0005434068300	F0693B	3958 694969	RAISA ARKHIPOVA	{"phone": "+70236930620"}
0005434068301	98ECC7	1063 795117	ALEKSANDR ILIN	{"email": "ilin.aleksandr1959@postgrespro.ru", "phone": "+70649911686"}
0005434068302	98ECC7	0795 851601	VLADISLAV VASILEV	{"email": "vasilev.v_101975@postgrespro.ru", "phone": "+70152325856"}
0005434068303	D41C1C	1296 293592	ANNA YAKOVLEVA	{"phone": "+70280281241"}
0005434068304	C05362	5346 607659	IGOR KRASNOV	{"phone": "+70524793676"}
0005434068305	B0425B	8300 394803	EKATERINA ZHUKOVA	{"email": "ekaterina-zhukova041972@postgrespro.ru", "phone": "+70828747578"}
0005434068306	352F97	7539 260168	ROBERT FEDOROV	{"email": "fedorov-r_1972@postgrespro.ru", "phone": "+70573810523"}
0005434068307	352F97	1361 878745	ALEKSEY KONOVALOV	{"email": "konovalovaleksey-24031972@postgrespro.ru", "phone": "+70045588899"}
0005434068308	976581	3744 666301	ELENA IVANOVA	{"email": "ivanova-elena111972@postgrespro.ru", "phone": "+70914776595"}
0005434068309	DE486B	0610 464593	SVETLANA ANTONOVA	{"email": "antonova-s.1963@postgrespro.ru", "phone": "+70327488931"}
0005434068310	6F6CC0	3746 431554	LARISA BORISOVA	{"email": "larisaborisova_11091973@postgrespro.ru", "phone": "+70696002108"}
0005434068311	82CA3C	2702 956519	NIKITA PAVLOV	{"phone": "+70322672477"}
0005434068312	F07D3F	8041 734333	SVETLANA EFREMOVA	{"phone": "+70519335710"}
0005434068313	3B5263	8172 370303	SERGEY MAKAROV	{"phone": "+70439841991"}
0005434068314	3B5263	5478 947475	PAVEL GUSEV	{"phone": "+70676059447"}
0005434068315	ADDE84	0257 876683	GALIYA BELYAEVA	{"phone": "+70075526604"}
0005434068316	FC315D	2605 391967	ALEKSANDR GUSEV	{"phone": "+70573805809"}
0005434068317	8A6B1E	9720 653663	EVGENIY MIRONOV	{"phone": "+70102037162"}
0005434068318	A34D1D	0705 659906	DMITRIY SIDOROV	{"email": "sidorovdmitriy.14061976@postgrespro.ru", "phone": "+70636714152"}
0005434068319	CFB18D	1282 746127	NINA NIKIFOROVA	{"email": "nina_nikiforova.28021986@postgrespro.ru", "phone": "+70921291689"}
0005434068320	CFB18D	2712 577480	EVGENIY NIKITIN	{"email": "nikitin.e-01031974@postgrespro.ru", "phone": "+70501867883"}
0005434068323	AB8102	6841 377015	NIKOLAY NIKOLAEV	{"email": "nikolay_nikolaev_1964@postgrespro.ru", "phone": "+70684743451"}
0005434068324	186A4C	1793 568871	ANTONINA PAVLOVA	{"phone": "+70394489212"}
0005434068325	A91D46	0807 127640	VLADIMIR POPOV	{"email": "v.popov-1975@postgrespro.ru", "phone": "+70281301564"}
0005434068326	8CC35B	5927 638031	SVETLANA SIDOROVA	{"phone": "+70553376006"}
0005434068327	9B575D	8502 180740	GALINA SOKOLOVA	{"phone": "+70545973045"}
0005434068328	5FECA2	4103 518521	OLGA SOKOLOVA	{"phone": "+70256701143"}
0005434068329	5FECA2	0383 534781	IRINA BORISOVA	{"email": "i_borisova-30031979@postgrespro.ru", "phone": "+70942056426"}
0005434068330	FF6B8A	7957 039981	MARINA AFANASEVA	{"phone": "+70560961160"}
0005434068331	FF6B8A	8265 180433	VLADIMIR PAVLOV	{"phone": "+70794038296"}
0005434068510	A6E62C	1417 231096	LYUDMILA BELOVA	{"phone": "+70789819974"}
0005434068332	9BF19D	6475 982277	LYUDMILA SERGEEVA	{"email": "lyudmilasergeeva.11111977@postgrespro.ru", "phone": "+70101612248"}
0005434068333	F062AD	4002 444273	YAKOV RODIONOV	{"phone": "+70834230341"}
0005434068334	8309C3	5377 940607	GLEB ANTONOV	{"phone": "+70685716128"}
0005434068335	8309C3	4932 969512	OLGA KONDRATEVA	{"phone": "+70061153146"}
0005434068336	1745D1	6567 173311	NIKITA GRIGOREV	{"phone": "+70770380021"}
0005434068337	307F02	0070 670194	VIKTOR DENISOV	{"email": "denisov_viktor14061973@postgrespro.ru", "phone": "+70131960986"}
0005434068338	A9AE17	1955 911196	NADEZHDA IVANOVA	{"email": "ivanova_n.23101974@postgrespro.ru", "phone": "+70671054247"}
0005434068339	A9AE17	4724 808730	VERA ERMAKOVA	{"email": "ermakova.vera.1981@postgrespro.ru", "phone": "+70104764349"}
0005434068340	AAF119	5172 058139	ALISA SEMENOVA	{"phone": "+70601012494"}
0005434068341	AAF119	4810 337241	ANNA NESTEROVA	{"email": "anna.nesterova.16111978@postgrespro.ru", "phone": "+70307512054"}
0005434068342	E3D167	5787 755383	LYUBOV NAZAROVA	{"phone": "+70954034600"}
0005434068343	E3D167	9541 489605	SOFYA MIKHAYLOVA	{"phone": "+70732749029"}
0005434068344	C46FCD	2951 364872	BORIS KUDRYASHOV	{"email": "kudryashov_boris021966@postgrespro.ru", "phone": "+70358873872"}
0005434068345	C46FCD	6656 955978	ELENA MAKSIMOVA	{"email": "maksimova.elena.011969@postgrespro.ru", "phone": "+70739709467"}
0005434068346	C46FCD	5462 823293	SERGEY BORISOV	{"email": "sergey_borisov1973@postgrespro.ru", "phone": "+70521571958"}
0005434068347	B7986E	9240 528186	NADEZHDA KUZNECOVA	{"phone": "+70861722183"}
0005434068348	9C98D3	2230 323221	NELLYA KAZAKOVA	{"email": "n_kazakova-12111967@postgrespro.ru", "phone": "+70665322147"}
0005434068349	9C98D3	5930 702156	EMIL MEDVEDEV	{"email": "medvedev_e_03091966@postgrespro.ru", "phone": "+70744409124"}
0005434068350	9C98D3	2548 575765	VLADIMIR VOLKOV	{"email": "volkovvladimir.121978@postgrespro.ru", "phone": "+70354430590"}
0005434068351	BB2427	0199 781134	ELENA ZAYCEVA	{"email": "zayceva-elena_10121963@postgrespro.ru", "phone": "+70186228559"}
0005434068352	85DDA6	0487 133445	EKATERINA SOKOLOVA	{"phone": "+70878523661"}
0005434068353	85DDA6	2065 276637	NINA MIKHAYLOVA	{"email": "n.mikhaylova-1971@postgrespro.ru", "phone": "+70246261255"}
0005434068354	B07EAA	1112 388152	ANATOLIY GORBUNOV	{"phone": "+70239626239"}
0005434068355	61C85C	8488 127013	VALENTINA KULIKOVA	{"phone": "+70745807560"}
0005434068356	62522A	1109 280281	ALEKSEY STEPANOV	{"email": "aleksey.stepanov_091962@postgrespro.ru", "phone": "+70154884980"}
0005434068357	B88F5D	0361 866628	NATALYA ANDREEVA	{"email": "andreeva_natalya03121959@postgrespro.ru", "phone": "+70555355528"}
0005434068358	2CBBDD	9727 863324	LYUDMILA DAVYDOVA	{"email": "davydova-l021966@postgrespro.ru", "phone": "+70757286951"}
0005434068359	450871	3721 052939	ANNA TARASOVA	{"email": "tarasovaanna-01081973@postgrespro.ru", "phone": "+70755559197"}
0005434068360	450871	7826 660007	PETR SIDOROV	{"phone": "+70431573138"}
0005434068361	710BAC	2993 217536	SERGEY KOZLOV	{"email": "s_kozlov22011973@postgrespro.ru", "phone": "+70710863847"}
0005434068362	46C7B8	7268 690246	IRINA NESTEROVA	{"phone": "+70110940790"}
0005434068363	B1889C	8193 052410	RUMIYA KOZLOVA	{"email": "kozlovar-071960@postgrespro.ru", "phone": "+70294979645"}
0005434068364	020D1F	7260 432505	ROMAN NIKITIN	{"email": "nikitin.r.26071973@postgrespro.ru", "phone": "+70140096363"}
0005434068365	9A9814	4024 976033	ANASTASIYA PETROVA	{"email": "petrova-anastasiya_091976@postgrespro.ru", "phone": "+70157143630"}
0005434068366	99751A	7112 553972	INNA BORISOVA	{"email": "inna.borisova-1982@postgrespro.ru", "phone": "+70822277486"}
0005434068367	99751A	3287 286671	SERGEY FEDOROV	{"email": "s.fedorov1967@postgrespro.ru", "phone": "+70889661631"}
0005434068368	BA6368	5990 112440	EKATERINA LOGINOVA	{"phone": "+70452133911"}
0005434068369	296293	5712 590575	ANTON SEMENOV	{"email": "semenov.anton-1968@postgrespro.ru", "phone": "+70971430952"}
0005434068370	EA8CD2	2042 005543	NIKOLAY IVANOV	{"email": "ivanovn091970@postgrespro.ru", "phone": "+70784544509"}
0005434068371	EA8CD2	1276 244844	IRINA BELOVA	{"phone": "+70212220434"}
0005434068372	4CA7E3	4842 038544	ARTEM MOROZOV	{"email": "morozov.a_10071953@postgrespro.ru", "phone": "+70582227991"}
0005434068373	4CA7E3	0575 041826	MIKHAIL OSIPOV	{"phone": "+70505100128"}
0005434068374	E4AB8E	2782 461387	RAVIL KISELEV	{"phone": "+70532780354"}
0005434068375	24CCC2	0791 839828	YURIY BARANOV	{"phone": "+70169553799"}
0005434068376	B12769	3099 884860	EVGENIYA SEMENOVA	{"phone": "+70826928109"}
0005434068377	2A5007	7318 845851	SARIYA IVANOVA	{"email": "ivanova.sariya.14111975@postgrespro.ru", "phone": "+70380479281"}
0005434068378	2296B2	0709 246921	ALEKSANDR FILIPPOV	{"phone": "+70208368556"}
0005434068379	D6094C	8749 848198	ALEKSEY SOKOLOV	{"email": "a.sokolov.1967@postgrespro.ru", "phone": "+70806816172"}
0005434068380	05C28B	3028 626500	KONSTANTIN KAZAKOV	{"email": "konstantin_kazakov011969@postgrespro.ru", "phone": "+70290432179"}
0005434068381	05C28B	7137 137925	EVGENIY TIMOFEEV	{"email": "evgeniy-timofeev-1969@postgrespro.ru", "phone": "+70263544476"}
0005434068382	722C0A	6671 260434	ILNUR FEDOROV	{"phone": "+70953109241"}
0005434068383	0E9295	7299 918982	VYACHESLAV MATVEEV	{"email": "vyacheslavmatveev-021970@postgrespro.ru", "phone": "+70880757994"}
0005434068384	EE53D8	8646 300114	SVETLANA ZAKHAROVA	{"email": "zakharovasvetlana021968@postgrespro.ru", "phone": "+70673229351"}
0005434068385	883A8D	1311 212102	EKATERINA RYABOVA	{"phone": "+70483690365"}
0005434068386	AE5FBE	0533 876650	ALEKSANDR ROMANOV	{"email": "aromanov14071975@postgrespro.ru", "phone": "+70682820791"}
0005434068387	65B8EE	5659 853501	SVETLANA FADEEVA	{"email": "svetlana-fadeeva.26091971@postgrespro.ru", "phone": "+70790136921"}
0005434068388	DE62DB	7010 681456	MARIYA EGOROVA	{"phone": "+70686412412"}
0005434068389	DE62DB	7469 287940	MARGARITA SOKOLOVA	{"phone": "+70239270884"}
0005434068390	783902	9242 851885	ANATOLIY KUZNECOV	{"email": "a-kuznecov_03021978@postgrespro.ru", "phone": "+70143317272"}
0005434068391	783902	1472 924181	ANTONINA NAUMOVA	{"phone": "+70624778753"}
0005434068392	70DB16	5358 794223	VIKTOR NAZAROV	{"email": "nazarovviktor_1983@postgrespro.ru", "phone": "+70143292956"}
0005434068393	069D8B	0216 176136	IGOR NOVIKOV	{"phone": "+70098338986"}
0005434068394	05B67C	5636 335770	EGOR SCHERBAKOV	{"email": "scherbakov-e_041973@postgrespro.ru", "phone": "+70886323318"}
0005434068395	467F22	6002 083830	VYACHESLAV GORBUNOV	{"phone": "+70529472440"}
0005434068396	61388D	5853 738340	EKATERINA ISAEVA	{"email": "ekaterinaisaeva_12061965@postgrespro.ru", "phone": "+70010277105"}
0005434068397	F50F6C	4027 925776	KIRILL VOLKOV	{"email": "volkov_kirill13011974@postgrespro.ru", "phone": "+70176426661"}
0005434068398	9A69BA	2460 497685	KONSTANTIN AFANASEV	{"phone": "+70911567554"}
0005434068399	B7779C	4694 311424	VLADISLAV MIRONOV	{"email": "v-mironov-011974@postgrespro.ru", "phone": "+70477337941"}
0005434068400	767447	3088 042717	OLEG ROMANOV	{"email": "o-romanov-021955@postgrespro.ru", "phone": "+70402712828"}
0005434068401	767447	0759 432715	ALEKSANDR TIKHONOV	{"email": "tikhonova_1976@postgrespro.ru", "phone": "+70964649275"}
0005434068402	6D9BFA	9950 929417	YANA KUZNECOVA	{"phone": "+70514082787"}
0005434068403	26BBF8	9668 416156	SERGEY KUDRYASHOV	{"phone": "+70952181074"}
0005434068404	03E19F	1420 586844	EVA FILIPPOVA	{"email": "filippova-e-24091978@postgrespro.ru", "phone": "+70682544009"}
0005434068405	7D5DDE	9921 741970	ANTONINA SOROKINA	{"phone": "+70779230221"}
0005434068406	7D5DDE	9030 818787	ANATOLIY SEMENOV	{"email": "semenovanatoliy_1961@postgrespro.ru", "phone": "+70236445329"}
0005434068407	EE54C1	4605 790199	NATALYA DMITRIEVA	{"email": "dmitrieva_natalya091972@postgrespro.ru", "phone": "+70047029231"}
0005434068408	EE54C1	8160 558743	VALERIY ISAEV	{"phone": "+70656087926"}
0005434068409	E82875	2723 345882	ANNA GUSEVA	{"phone": "+70070838153"}
0005434068410	E82875	6677 587617	NIKITA FOMIN	{"phone": "+70066575862"}
0005434068411	7A5054	4034 845453	PETR EGOROV	{"phone": "+70028107600"}
0005434068412	D3AADC	6794 189073	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov16081958@postgrespro.ru", "phone": "+70919821032"}
0005434068413	BEA5BB	1837 723177	ANDREY SEMENOV	{"phone": "+70868345777"}
0005434068414	6C2A14	1213 270951	VLADISLAV KISELEV	{"email": "vladislav-kiselev_09051973@postgrespro.ru", "phone": "+70676932992"}
0005434068415	69ACFB	6340 547575	SERGEY SCHERBAKOV	{"email": "s-scherbakov-1980@postgrespro.ru", "phone": "+70786484310"}
0005434068416	F4F840	4841 531086	NADEZHDA BELOVA	{"email": "belova-nadezhda1969@postgrespro.ru", "phone": "+70735292110"}
0005434068417	DFD303	7348 351239	PAVEL GUSEV	{"phone": "+70645187131"}
0005434068418	DFD303	1731 892341	NADEZHDA SMIRNOVA	{"phone": "+70355439736"}
0005434068419	FC8100	9351 186826	NIKOLAY KAZAKOV	{"email": "kazakov.nikolay.30011973@postgrespro.ru", "phone": "+70067770668"}
0005434068420	6B220A	6434 359524	VLADIMIR GERASIMOV	{"email": "v_gerasimov.28091963@postgrespro.ru", "phone": "+70267639842"}
0005434068421	B8D386	7063 276295	SERGEY KUZNECOV	{"email": "sergey.kuznecov031968@postgrespro.ru", "phone": "+70348799643"}
0005434068422	B8D386	3560 902736	YURIY FROLOV	{"email": "y_frolov_22041971@postgrespro.ru", "phone": "+70178662014"}
0005434068423	59F113	1448 690328	OLEG SERGEEV	{"email": "osergeev.25091970@postgrespro.ru", "phone": "+70669897077"}
0005434068424	64BB21	7315 236334	ALEVTINA VASILEVA	{"phone": "+70882403085"}
0005434068425	64BB21	4506 375086	OLGA TIMOFEEVA	{"phone": "+70774841079"}
0005434068426	4838DD	1516 040904	SVETLANA MALYSHEVA	{"email": "malysheva_svetlana.21121973@postgrespro.ru", "phone": "+70656469024"}
0005434068427	4838DD	4278 141808	NIKITA BORISOV	{"email": "borisovn.21041975@postgrespro.ru", "phone": "+70653647192"}
0005434068428	4838DD	9102 198839	STANISLAV KONOVALOV	{"email": "konovalovs-05101975@postgrespro.ru", "phone": "+70047467880"}
0005434068429	3475EF	1480 562499	ALINA KOZLOVA	{"email": "kozlovaa1969@postgrespro.ru", "phone": "+70137888243"}
0005434068430	F23A93	8756 433322	STEPAN SMIRNOV	{"phone": "+70649657224"}
0005434068431	F23A93	5900 692268	ELIZAVETA FILIPPOVA	{"email": "elizavetafilippova_031980@postgrespro.ru", "phone": "+70906517281"}
0005434068432	CC8FE4	4809 305739	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev_21101974@postgrespro.ru", "phone": "+70407182426"}
0005434068433	CC8FE4	1502 560872	SERGEY SOROKIN	{"email": "sorokin.sergey.1971@postgrespro.ru", "phone": "+70977476387"}
0005434068434	21E6C7	6442 779807	SVETLANA POPOVA	{"email": "popovasvetlana_101959@postgrespro.ru", "phone": "+70290948075"}
0005434068435	65F87D	2483 946614	DARYA ANTONOVA	{"email": "d.antonova18091978@postgrespro.ru", "phone": "+70792193794"}
0005434068436	98C3B3	8352 738850	ANASTASIYA MOROZOVA	{"phone": "+70097155835"}
0005434068437	98C3B3	9761 701706	MARIYA GAVRILOVA	{"email": "m-gavrilova_08031989@postgrespro.ru", "phone": "+70403243352"}
0005434068438	A153AC	4345 665370	VERA VOROBEVA	{"email": "vera-vorobeva041975@postgrespro.ru", "phone": "+70492616896"}
0005434068439	CFE71E	1581 945907	IGOR ZAKHAROV	{"phone": "+70967260782"}
0005434068440	CFE71E	5613 698589	VIKTOR MEDVEDEV	{"phone": "+70370957497"}
0005434068441	714D7B	6206 722324	VALERIY MAKAROV	{"email": "makarovv_22111972@postgrespro.ru", "phone": "+70325528386"}
0005434068442	F918D1	1135 013764	VLADIMIR KUZMIN	{"email": "vkuzmin-1969@postgrespro.ru", "phone": "+70085320159"}
0005434068443	F918D1	2398 260042	KRISTINA YAKOVLEVA	{"email": "kristina-yakovleva_19011968@postgrespro.ru", "phone": "+70697597060"}
0005434068444	F918D1	4653 931646	ILDAR GERASIMOV	{"phone": "+70541003853"}
0005434068445	05CE87	4319 497325	TIMUR MAKSIMOV	{"phone": "+70971986026"}
0005434068446	A77018	1246 819869	VITALIY VOLKOV	{"phone": "+70379368671"}
0005434068447	A77018	8322 846882	ANASTASIYA PETROVA	{"email": "petrova_anastasiya-1969@postgrespro.ru", "phone": "+70598838897"}
0005434068448	F823AA	8343 440526	LIDIYA ANDREEVA	{"email": "andreeva_l.091983@postgrespro.ru", "phone": "+70854763617"}
0005434068449	F823AA	2015 720886	ANDREY KULIKOV	{"email": "a_kulikov-011970@postgrespro.ru", "phone": "+70881785807"}
0005434068450	8F498B	8225 877150	YULIYA SAVELEVA	{"email": "yuliya.saveleva.101984@postgrespro.ru", "phone": "+70042468236"}
0005434068451	8F498B	0113 539254	LILIYA EGOROVA	{"email": "liliyaegorova_051975@postgrespro.ru", "phone": "+70330133778"}
0005434068452	6022BD	2090 309288	ELENA ABRAMOVA	{"email": "abramovae_071963@postgrespro.ru", "phone": "+70627071901"}
0005434068453	6022BD	6638 820564	NINA FILATOVA	{"phone": "+70084862868"}
0005434068454	6022BD	4212 578111	SOFYA KOVALEVA	{"phone": "+70206283687"}
0005434068455	3DEF90	3207 843612	TATYANA TARASOVA	{"phone": "+70456079298"}
0005434068456	D6E487	4470 950036	MARINA KUZNECOVA	{"phone": "+70284281358"}
0005434068457	6F562B	9741 758037	VIKTOR DMITRIEV	{"email": "v-dmitriev.041975@postgrespro.ru", "phone": "+70249248581"}
0005434068458	6F562B	6150 719524	GALINA ISAEVA	{"email": "isaeva.galina.121968@postgrespro.ru", "phone": "+70757844113"}
0005434068459	DF347D	8739 145343	SOFYA BORISOVA	{"phone": "+70167695751"}
0005434068460	DF347D	6064 065049	ANDREY VASILEV	{"phone": "+70288349030"}
0005434068461	3878F0	7037 448021	EKATERINA GRISHINA	{"phone": "+70786292169"}
0005434068462	6B51C1	5891 885610	VALERIY NAZAROV	{"email": "nazarovvaleriy.051974@postgrespro.ru", "phone": "+70472584173"}
0005434068463	09F65B	4364 181059	NIKOLAY KUZNECOV	{"phone": "+70021554868"}
0005434068464	424ADC	0936 473130	GAGIK MOROZOV	{"phone": "+70027094170"}
0005434068465	83297C	2377 438411	ZINAIDA KARPOVA	{"phone": "+70615456217"}
0005434068466	15E09C	5333 516463	NATALYA KOROLEVA	{"email": "natalyakoroleva.1960@postgrespro.ru", "phone": "+70572361790"}
0005434068467	677BCA	7353 873577	VADIM SMIRNOV	{"email": "vadimsmirnov1972@postgrespro.ru", "phone": "+70804814297"}
0005434068468	1A66FF	0910 139529	YULIYA PAVLOVA	{"email": "pavlova_y-111966@postgrespro.ru", "phone": "+70609499132"}
0005434068469	A7C6B3	3658 336577	ALEKSANDR PETROV	{"phone": "+70606992395"}
0005434068470	8BE2D0	5526 240922	VIKTORIYA ANTONOVA	{"email": "antonovaviktoriya021978@postgrespro.ru", "phone": "+70981634539"}
0005434068471	1A714D	3656 200731	IGOR NIKITIN	{"email": "nikitin.i1971@postgrespro.ru", "phone": "+70276039663"}
0005434068472	1A714D	0048 486807	OLGA ZAKHAROVA	{"email": "zakharova-olga26011967@postgrespro.ru", "phone": "+70938203848"}
0005434068473	838F3F	9115 260338	NADEZHDA MATVEEVA	{"email": "n.matveeva26021977@postgrespro.ru", "phone": "+70897118315"}
0005434068474	838F3F	0381 603565	PAVEL AFANASEV	{"phone": "+70592239063"}
0005434068475	A591AD	1577 281665	IBRAGIM MATVEEV	{"phone": "+70999028785"}
0005434068476	A591AD	9470 681067	YULIYA KRASNOVA	{"email": "ykrasnova.07091970@postgrespro.ru", "phone": "+70967889743"}
0005434068477	3C9104	1787 363408	GULNARA KALININA	{"phone": "+70751407135"}
0005434068478	7A64B0	8190 447611	ANNA MIKHAYLOVA	{"phone": "+70399766486"}
0005434068479	F9D6FD	6293 328641	RAISA AKIMOVA	{"phone": "+70542761346"}
0005434068480	3027B0	5136 748132	VIKTOR DAVYDOV	{"phone": "+70562593420"}
0005434068481	BAB8C0	5897 445604	ALEKSEY FEDOROV	{"email": "fedorovaleksey.01051972@postgrespro.ru", "phone": "+70621073329"}
0005434068482	BAB8C0	2894 823484	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana_01121979@postgrespro.ru", "phone": "+70281468559"}
0005434068483	5A6093	6593 445585	ANNA SIDOROVA	{"phone": "+70851402132"}
0005434068484	A6C4A6	1036 371477	KSENIYA OSIPOVA	{"phone": "+70192478006"}
0005434068485	F1DB44	1893 016037	VALENTINA KOMAROVA	{"email": "v.komarova_1964@postgrespro.ru", "phone": "+70876431948"}
0005434068598	080AF9	3674 845820	YULIYA MARTYNOVA	{"phone": "+70500111582"}
0005434068486	F1DB44	8911 884794	TATYANA BORISOVA	{"email": "tborisova021973@postgrespro.ru", "phone": "+70634237023"}
0005434068487	11207D	2942 466966	ALEKSANDR GUSEV	{"phone": "+70291424003"}
0005434068488	11207D	3933 442697	NIKOLAY IVANOV	{"email": "ivanov.nikolay02111966@postgrespro.ru", "phone": "+70982280829"}
0005434068489	0FB298	6098 849596	SVETLANA SERGEEVA	{"phone": "+70573561349"}
0005434068490	0FB298	3648 251287	ELENA BORISOVA	{"email": "e_borisova.1983@postgrespro.ru", "phone": "+70276723048"}
0005434068491	7181A4	2163 137100	PETR SOROKIN	{"email": "petr_sorokin_1974@postgrespro.ru", "phone": "+70969391070"}
0005434068492	61A5BE	8298 763739	VLADIMIR KOROLEV	{"phone": "+70390384333"}
0005434068493	F42DDA	4977 394253	ANDREY ZHURAVLEV	{"phone": "+70677793118"}
0005434068494	280C1E	5695 766857	VIKTOR BARANOV	{"phone": "+70205119102"}
0005434068495	F0DBF0	6314 258505	ALEKSANDR MAKAROV	{"phone": "+70967920905"}
0005434068496	F0DBF0	6094 622498	NIKOLAY FEDOROV	{"phone": "+70255858185"}
0005434068497	1895C0	0985 638364	ALEKSANDR FILIPPOV	{"phone": "+70474788905"}
0005434068498	C3A716	7960 321326	NADEZHDA BELOVA	{"email": "n.belova-06101968@postgrespro.ru", "phone": "+70030664960"}
0005434068499	AAE078	1236 190095	ALEKSANDR KISELEV	{"phone": "+70858605857"}
0005434068500	F280FF	2910 080913	SERGEY VASILEV	{"email": "vasilevsergey_101964@postgrespro.ru", "phone": "+70541319369"}
0005434068501	F280FF	7547 568163	EVGENIY MIRONOV	{"phone": "+70839939118"}
0005434068502	413EA3	5812 761270	LEONID KUZMIN	{"phone": "+70900622767"}
0005434068503	DB45A3	8218 429281	SERGEY OSIPOV	{"phone": "+70563742145"}
0005434068504	DB45A3	5496 499901	VLADIMIR IVANOV	{"phone": "+70605214750"}
0005434068505	A0D40C	4010 859434	ANDREY FILIPPOV	{"email": "filippov-a051976@postgrespro.ru", "phone": "+70274981931"}
0005434068506	A0D40C	7134 816436	ALEKSANDR KUZNECOV	{"phone": "+70835107486"}
0005434068507	16215A	9351 209765	ALEKSEY TIKHONOV	{"email": "a_tikhonov.101984@postgrespro.ru", "phone": "+70873084639"}
0005434068508	D207E7	2694 253674	NINA FROLOVA	{"phone": "+70563041425"}
0005434068511	A6E62C	0282 674963	ARTUR VOLKOV	{"email": "volkova06031974@postgrespro.ru", "phone": "+70406375608"}
0005434068512	A6E62C	5398 073314	PETR AFANASEV	{"email": "afanasev.petr1970@postgrespro.ru", "phone": "+70877695245"}
0005434068513	B80DF1	6793 091570	IRINA LOGINOVA	{"phone": "+70060598919"}
0005434068514	106423	5915 244585	EVGENIY KONOVALOV	{"email": "konovalove.061962@postgrespro.ru", "phone": "+70024318763"}
0005434068515	106423	6087 081590	MARINA KUZNECOVA	{"email": "marina-kuznecova.31101979@postgrespro.ru", "phone": "+70036670820"}
0005434068516	B39B16	9080 909048	ANATOLIY CHERNOV	{"phone": "+70314248425"}
0005434068517	22C49E	9286 377079	MARIYA KUZNECOVA	{"email": "m.kuznecova-091969@postgrespro.ru", "phone": "+70308336040"}
0005434068518	22C49E	9211 069224	ANDREY ZAYCEV	{"email": "andrey.zaycev27051979@postgrespro.ru", "phone": "+70594731250"}
0005434068519	4D140E	1555 782334	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov-1982@postgrespro.ru", "phone": "+70628476723"}
0005434068520	6286B3	3943 994267	ALEKSANDR KUZNECOV	{"phone": "+70075391631"}
0005434068521	6286B3	8250 564990	SERGEY KAZAKOV	{"phone": "+70778545456"}
0005434068522	DFDDDB	5790 574075	VLADIMIR IVANOV	{"email": "vladimirivanov_07121967@postgrespro.ru", "phone": "+70353314585"}
0005434068523	DFDDDB	7074 635729	ALFIYA KISELEVA	{"email": "a-kiseleva.21041971@postgrespro.ru", "phone": "+70052331881"}
0005434068524	14E542	2933 984480	ALINA KUZMINA	{"email": "kuzmina-alina.25011970@postgrespro.ru", "phone": "+70587115470"}
0005434068525	14E542	2799 770037	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-e_1964@postgrespro.ru", "phone": "+70652076848"}
0005434068526	D4ECD2	6802 868594	ALEKSANDR IVANOV	{"phone": "+70574836019"}
0005434068527	D4ECD2	8648 974753	ELENA ZHUKOVA	{"email": "e-zhukova.21091992@postgrespro.ru", "phone": "+70550341226"}
0005434068528	5F8E0E	9905 484034	ELIZAVETA TIMOFEEVA	{"email": "elizavetatimofeeva_13021973@postgrespro.ru", "phone": "+70628225480"}
0005434068529	FF3353	6910 018161	SVETLANA NESTEROVA	{"phone": "+70392496155"}
0005434068530	BF20A5	1824 999025	TATYANA SIDOROVA	{"email": "sidorovat_1966@postgrespro.ru", "phone": "+70171168823"}
0005434068531	C30275	0171 883430	YURIY MOROZOV	{"phone": "+70461672116"}
0005434068532	C30275	7079 128335	ELENA ORLOVA	{"phone": "+70123702911"}
0005434068533	CC7945	0268 623729	NADEZHDA GERASIMOVA	{"phone": "+70551114526"}
0005434068534	1BFF67	9138 865485	ILYA TIMOFEEV	{"email": "ilya.timofeev_1969@postgrespro.ru", "phone": "+70982081488"}
0005434068535	37AE2C	8967 858265	NELLI ILINA	{"email": "ilina-n-06071977@postgrespro.ru", "phone": "+70554502957"}
0005434068536	842958	6252 142916	MIKHAIL SEMENOV	{"email": "semenov.m.1976@postgrespro.ru", "phone": "+70733501396"}
0005434068537	842958	4063 566387	IRINA DENISOVA	{"phone": "+70555581351"}
0005434068538	025824	9351 275815	ALINA GRISHINA	{"email": "grishinaa_16091968@postgrespro.ru", "phone": "+70745398278"}
0005434068539	025824	3704 314213	IRINA NIKOLAEVA	{"email": "irina-nikolaeva.16121972@postgrespro.ru", "phone": "+70752288878"}
0005434068540	EC0CDD	9229 327964	MARIYA KARPOVA	{"email": "karpova.mariya_05031974@postgrespro.ru", "phone": "+70315766097"}
0005434068541	BE3B5B	7828 961926	VLADIMIR NOVIKOV	{"email": "vladimir.novikov24021980@postgrespro.ru", "phone": "+70595037891"}
0005434068542	BE3B5B	5825 476916	ZULFIYA EFREMOVA	{"email": "efremovazulfiya.1985@postgrespro.ru", "phone": "+70553480845"}
0005434068543	D0829B	1578 116152	RAMIS BORISOV	{"email": "borisovr_021972@postgrespro.ru", "phone": "+70336069269"}
0005434068544	F1115C	0450 873141	OLGA BORISOVA	{"phone": "+70293808265"}
0005434068545	2896D7	5183 263272	SERGEY FEDOROV	{"email": "sergey_fedorov-03091970@postgrespro.ru", "phone": "+70481149957"}
0005434068546	2896D7	6458 410764	NATALYA IVANOVA	{"email": "natalya_ivanova-111966@postgrespro.ru", "phone": "+70122746982"}
0005434068547	76567A	1033 063352	ALEKSANDR IVANOV	{"phone": "+70544018048"}
0005434068548	2972FC	8721 221383	TATYANA MELNIKOVA	{"phone": "+70972774909"}
0005434068549	CEE36E	2292 034112	IVAN VASILEV	{"email": "ivan_vasilev_1963@postgrespro.ru", "phone": "+70459099515"}
0005434068550	80479F	6350 377331	VITALIY BORISOV	{"phone": "+70814964600"}
0005434068551	80479F	6006 798027	ALEKSANDR RODIONOV	{"phone": "+70032899475"}
0005434068552	80479F	2589 045470	NIKOLAY GORBUNOV	{"email": "nikolaygorbunov-15021967@postgrespro.ru", "phone": "+70870093432"}
0005434068553	9097D0	7849 509533	EVDOKIYA BELOVA	{"email": "belovae_081973@postgrespro.ru", "phone": "+70819770691"}
0005434068554	9097D0	4989 946110	ALEKSANDR BELOV	{"email": "belov-aleksandr.1978@postgrespro.ru", "phone": "+70611556977"}
0005434068555	FBCB34	6392 186746	KSENIYA SMIRNOVA	{"email": "smirnova.kseniya1969@postgrespro.ru", "phone": "+70631240136"}
0005434068556	5436F7	2138 118344	MARINA ZHUKOVA	{"phone": "+70198317181"}
0005434068557	5436F7	4562 543470	GENNADIY GUSEV	{"phone": "+70793485938"}
0005434068558	86C7AF	3663 845870	TATYANA MATVEEVA	{"phone": "+70702385383"}
0005434068559	728182	4312 583447	TAMARA TARASOVA	{"phone": "+70192281771"}
0005434068560	586BDC	7420 693522	NATALYA BARANOVA	{"phone": "+70702279269"}
0005434068561	586BDC	6246 300671	ALEKSANDR NIKITIN	{"phone": "+70410997603"}
0005434068562	3D9B13	1485 199039	IVAN SERGEEV	{"phone": "+70068529350"}
0005434068563	DCD8BA	4213 825219	VALENTINA ZHUKOVA	{"phone": "+70951591857"}
0005434068564	9E9C02	1181 534632	DENIS PAVLOV	{"email": "denis-pavlov.1981@postgrespro.ru", "phone": "+70988811887"}
0005434068565	9E9C02	5159 450429	IVAN SEMENOV	{"phone": "+70185464498"}
0005434068566	E45494	3462 450419	TATYANA BELYAEVA	{"email": "tatyana.belyaeva_111975@postgrespro.ru", "phone": "+70638437211"}
0005434068567	8C1B10	7392 084367	NATALIYA GAVRILOVA	{"phone": "+70327852018"}
0005434068568	8C1B10	1989 136262	SERGEY VOROBEV	{"email": "s_vorobev_1972@postgrespro.ru", "phone": "+70040645506"}
0005434068569	1EC30C	1213 294498	VLADIMIR IVANOV	{"phone": "+70978943058"}
0005434068570	1EC30C	5027 514695	ELENA GAVRILOVA	{"email": "gavrilova_e1967@postgrespro.ru", "phone": "+70902974735"}
0005434068571	6FC13E	0882 624705	ANZHELA PAVLOVA	{"email": "anzhelapavlova_011972@postgrespro.ru", "phone": "+70887539343"}
0005434068572	86AA70	2535 753837	ALEKSANDR KUZNECOV	{"phone": "+70258458871"}
0005434068573	7C9BE5	4219 799544	ANDREY DENISOV	{"email": "andrey-denisov1971@postgrespro.ru", "phone": "+70614626084"}
0005434068574	7C9BE5	6685 746957	NIKITA MIKHAYLOV	{"email": "nmikhaylov.121979@postgrespro.ru", "phone": "+70818523660"}
0005434068575	C63A67	2949 107977	ELENA EGOROVA	{"phone": "+70685441882"}
0005434068576	C63A67	1663 265040	ALISA SMIRNOVA	{"email": "alisasmirnova-111969@postgrespro.ru", "phone": "+70348338081"}
0005434068577	C63A67	1084 004427	SERGEY KULIKOV	{"email": "skulikov051969@postgrespro.ru", "phone": "+70611501956"}
0005434068578	42E16A	6236 149112	SERGEY KUZNECOV	{"phone": "+70107037414"}
0005434068579	8CA182	2809 443850	VERA ALEKSANDROVA	{"phone": "+70935582534"}
0005434068580	8E499D	8221 229318	ALEKSEY KARPOV	{"phone": "+70698602239"}
0005434068581	177CAF	6054 441291	IVAN POPOV	{"phone": "+70815191265"}
0005434068582	48630A	2539 287652	ARTEM KUZMIN	{"email": "kuzmin_artem_05081981@postgrespro.ru", "phone": "+70001733815"}
0005434068583	06078B	0865 182960	LYUDMILA ARKHIPOVA	{"email": "arkhipova_l14091985@postgrespro.ru", "phone": "+70293134852"}
0005434068584	06078B	4098 840462	KONSTANTIN EGOROV	{"phone": "+70957601344"}
0005434068585	C1AD91	1668 073762	YULIYA VASILEVA	{"email": "vasileva.yuliya.011974@postgrespro.ru", "phone": "+70764366309"}
0005434068586	C1AD91	1711 312019	SERGEY FROLOV	{"phone": "+70648030173"}
0005434068587	12DF2D	2910 406611	POLINA POPOVA	{"email": "popovapolina1968@postgrespro.ru", "phone": "+70533363980"}
0005434068588	F8FEBB	7009 699994	DINA VASILEVA	{"email": "dinavasileva.18041986@postgrespro.ru", "phone": "+70060112318"}
0005434068589	F8FEBB	6392 412399	LYUBOV GERASIMOVA	{"phone": "+70128820792"}
0005434068590	61035A	1532 059382	ALEKSANDR DMITRIEV	{"email": "a_dmitriev.13061975@postgrespro.ru", "phone": "+70788829097"}
0005434068591	4ED62B	5097 409674	PLATON KOZLOV	{"email": "platonkozlov.04021964@postgrespro.ru", "phone": "+70262967100"}
0005434068592	4ED62B	7247 921969	VADIM SHEVCHENKO	{"email": "vadim-shevchenko1977@postgrespro.ru", "phone": "+70699548528"}
0005434068593	4ED62B	4806 847183	VLADIMIR FOMIN	{"phone": "+70330442899"}
0005434068594	480296	7783 182936	MARIYA MELNIKOVA	{"email": "melnikovam-28021973@postgrespro.ru", "phone": "+70205879598"}
0005434068595	71F39F	1431 391656	EKATERINA IVANOVA	{"email": "e.ivanova-30101964@postgrespro.ru", "phone": "+70824227334"}
0005434068596	71F39F	2207 009025	ROMAN TIKHONOV	{"phone": "+70331026962"}
0005434068597	85784B	6402 458102	DMITRIY GAVRILOV	{"email": "gavrilov-d-14051966@postgrespro.ru", "phone": "+70267775461"}
0005434068599	935899	5091 527681	ANTONINA BELYAEVA	{"email": "belyaeva.antonina-1972@postgrespro.ru", "phone": "+70688872668"}
0005434068600	622AC3	4984 687422	IGOR VOLKOV	{"phone": "+70346765385"}
0005434068601	622AC3	1040 784370	ULYANA NIKIFOROVA	{"email": "u.nikiforova.111975@postgrespro.ru", "phone": "+70425233630"}
0005434068602	622AC3	6249 982908	MIKHAIL MAKAROV	{"phone": "+70038554479"}
0005434068603	8E6577	2037 995958	SERGEY NAUMOV	{"phone": "+70915222840"}
0005434068604	7D8C72	6817 473077	LYUBOV MOISEEVA	{"email": "moiseeva.lyubov_21061964@postgrespro.ru", "phone": "+70845379269"}
0005434068605	30D9BB	8178 952853	ROMAN SOKOLOV	{"email": "romansokolov-23091968@postgrespro.ru", "phone": "+70105195707"}
0005434068606	B794E4	1583 178160	LYUDMILA NOVIKOVA	{"email": "novikova-lyudmila_061978@postgrespro.ru", "phone": "+70493950586"}
0005434068607	B794E4	3545 156765	VIKTOR ZAKHAROV	{"email": "v.zakharov-021975@postgrespro.ru", "phone": "+70336074652"}
0005434068608	557C46	9907 074194	MARIYA SOROKINA	{"phone": "+70910803889"}
0005434068609	EE626E	2225 301291	LYUBOV CHERNOVA	{"email": "lyubovchernova_1971@postgrespro.ru", "phone": "+70459231275"}
0005434068610	2B9899	7547 099539	YAN VOLKOV	{"phone": "+70803190374"}
0005434068611	8492A6	5617 362201	OLEG BARANOV	{"email": "oleg.baranov101972@postgrespro.ru", "phone": "+70242001610"}
0005434068612	8492A6	9455 339912	ALEKSANDR ZAKHAROV	{"phone": "+70555296632"}
0005434068613	8492A6	2589 758925	IVAN VOROBEV	{"phone": "+70777624437"}
0005434068614	8492A6	1809 332326	ELENA KOROLEVA	{"phone": "+70850410555"}
0005434068615	1878BF	6996 573656	SEMEN ISAEV	{"phone": "+70626155485"}
0005434068616	3C1093	6600 509029	OLEG POPOV	{"email": "oleg_popov03061974@postgrespro.ru", "phone": "+70406019455"}
0005434068617	82BDD7	5642 406070	VERA TARASOVA	{"phone": "+70231014848"}
0005434068618	3FD604	4844 177098	ALINA KOROLEVA	{"email": "koroleva.alina.1980@postgrespro.ru", "phone": "+70532347111"}
0005434068619	3926AE	9355 575470	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr_1962@postgrespro.ru", "phone": "+70578926537"}
0005434068620	764451	6169 311895	ANTON TIMOFEEV	{"email": "a-timofeev.1976@postgrespro.ru", "phone": "+70135523319"}
0005434068621	764451	5735 804760	TATYANA ANDREEVA	{"email": "andreeva.tatyana031969@postgrespro.ru", "phone": "+70514114307"}
0005434068622	36AE99	5157 656967	NINA KUZNECOVA	{"phone": "+70036073168"}
0005434068623	36AE99	4246 926827	VLADIMIR BELOV	{"email": "belov-vladimir-081974@postgrespro.ru", "phone": "+70161197123"}
0005434068624	36AE99	2486 166195	ANASTASIYA VOLKOVA	{"email": "avolkova-1970@postgrespro.ru", "phone": "+70204170330"}
0005434068625	D44D43	0503 092476	NINA POPOVA	{"email": "nina.popova-1975@postgrespro.ru", "phone": "+70666224503"}
0005434068626	3E475C	2155 056007	VALENTINA SEMENOVA	{"email": "v_semenova_26091966@postgrespro.ru", "phone": "+70809500192"}
0005434068627	E55342	3460 804495	SERGEY VOLKOV	{"email": "s_volkov_111972@postgrespro.ru", "phone": "+70754759081"}
0005434068628	E55342	9834 013312	ALEKSEY TIMOFEEV	{"email": "a-timofeev.111972@postgrespro.ru", "phone": "+70795188003"}
0005434068629	E55342	7757 808145	ALEKSANDR MAKSIMOV	{"email": "maksimov_a_1976@postgrespro.ru", "phone": "+70467517589"}
0005434068630	B3BB6F	7489 951712	NIKOLAY GRIGOREV	{"phone": "+70964543560"}
0005434068631	EF867F	4410 364480	NATALYA KUZNECOVA	{"email": "natalyakuznecova-111976@postgrespro.ru", "phone": "+70629845072"}
0005434068632	F7EB7A	6493 450633	ALEKSANDR IVANOV	{"email": "ivanov_a-011969@postgrespro.ru", "phone": "+70229214509"}
0005434068633	53D30B	0240 541981	LIDIYA MEDVEDEVA	{"phone": "+70713004650"}
0005434068634	91DC38	5015 652345	ANASTASIYA YAKOVLEVA	{"phone": "+70651032917"}
0005434068635	91DC38	9766 497330	IGOR OSIPOV	{"email": "osipov.igor.07091970@postgrespro.ru", "phone": "+70971540788"}
0005434068636	4CCA0E	4866 808751	RAISA MATVEEVA	{"email": "rmatveeva-1970@postgrespro.ru", "phone": "+70487370161"}
0005434068637	3C8B2D	8113 439772	OLGA GAVRILOVA	{"phone": "+70398044270"}
0005434068638	BCB9CE	6972 636496	VLADIMIR SOROKIN	{"phone": "+70322422217"}
0005434068639	BCB9CE	6277 124490	ANDREY ZHURAVLEV	{"phone": "+70008145587"}
0005434068640	05F1E3	1790 845462	VLADIMIR DAVYDOV	{"email": "davydov-vladimir-26061978@postgrespro.ru", "phone": "+70031855284"}
0005434068641	4FF6C0	3298 784306	PETR GERASIMOV	{"email": "gerasimovpetr-14091963@postgrespro.ru", "phone": "+70245864292"}
0005434068642	36D938	6141 013162	ARINA KRASNOVA	{"phone": "+70831081711"}
0005434068643	0C9682	8007 718811	ALEKSEY STEPANOV	{"phone": "+70512441551"}
0005434068644	8F266D	5852 978016	LYUDMILA ANTONOVA	{"email": "l-antonova.07081974@postgrespro.ru", "phone": "+70065200603"}
0005434068645	8F266D	6970 924883	ROZALIYA ANTONOVA	{"phone": "+70984514142"}
0005434068646	6C8260	2044 187895	POLINA TIMOFEEVA	{"phone": "+70915334294"}
0005434068647	323D99	6688 421732	PAVEL GRIGOREV	{"phone": "+70475140646"}
0005434068648	323D99	1329 112269	ELENA MOISEEVA	{"email": "moiseeva-e_1974@postgrespro.ru", "phone": "+70936285709"}
0005434068649	67CA5E	9305 112749	ALEKSEY FROLOV	{"email": "a_frolov_1980@postgrespro.ru", "phone": "+70883334081"}
0005434068650	9A86FD	5966 288101	ILYA IVANOV	{"email": "i_ivanov.10071961@postgrespro.ru", "phone": "+70151335057"}
0005434068651	96079B	4120 082319	SERGEY ALEKSANDROV	{"email": "sergey.aleksandrov-061975@postgrespro.ru", "phone": "+70157248470"}
0005434068652	EE8AAE	4828 736915	TAMARA SAVELEVA	{"phone": "+70144434125"}
0005434068653	6AA1B9	3440 687390	VIKTOR IVANOV	{"email": "vivanov.1982@postgrespro.ru", "phone": "+70177195176"}
0005434068822	75C820	6545 364380	TAMARA DMITRIEVA	{"phone": "+70174607393"}
0005434068654	6AA1B9	6570 756033	VALENTINA ANTONOVA	{"email": "antonova.v_1970@postgrespro.ru", "phone": "+70580858112"}
0005434068655	6AA1B9	7065 838483	NADEZHDA MEDVEDEVA	{"email": "n.medvedeva.091959@postgrespro.ru", "phone": "+70990043769"}
0005434068656	319788	7607 444592	ARTEM NIKOLAEV	{"phone": "+70546221916"}
0005434068657	319788	9585 439174	YURIY MARTYNOV	{"email": "y-martynov041976@postgrespro.ru", "phone": "+70121896856"}
0005434068658	F309EC	1830 037617	LYUBOV FADEEVA	{"email": "fadeeval.1980@postgrespro.ru", "phone": "+70245076444"}
0005434068659	E1E9AF	3727 236844	KLAVDIYA KUZNECOVA	{"email": "klavdiyakuznecova1968@postgrespro.ru", "phone": "+70600855307"}
0005434068660	803DF0	4080 408689	OLGA KISELEVA	{"phone": "+70650360470"}
0005434068661	B8506C	2598 344126	DMITRIY VLASOV	{"email": "vlasov_d06031980@postgrespro.ru", "phone": "+70410361751"}
0005434068662	2F12A1	5706 111883	EVGENIY VOLKOV	{"phone": "+70746963090"}
0005434068663	3CAA69	5385 148844	ANDREY SIDOROV	{"email": "asidorov_07031977@postgrespro.ru", "phone": "+70542520873"}
0005434068664	2D1395	9004 764734	IVAN KUZNECOV	{"email": "kuznecov_ivan051981@postgrespro.ru", "phone": "+70141801864"}
0005434068665	801FC6	6280 190581	ANNA KONOVALOVA	{"email": "konovalovaanna_20051961@postgrespro.ru", "phone": "+70650792488"}
0005434068666	801FC6	5681 920761	LIDIYA VOROBEVA	{"email": "vorobeva_l-10021965@postgrespro.ru", "phone": "+70024599395"}
0005434068667	81E063	1175 527496	YURIY SOLOVEV	{"phone": "+70891388713"}
0005434068668	CCF01F	3950 055031	ALINA KRASNOVA	{"phone": "+70988242315"}
0005434068669	1F5D0A	5350 551148	MAKSIM IVANOV	{"email": "ivanov-m06121966@postgrespro.ru", "phone": "+70826504069"}
0005434068670	7E1EBF	2410 046708	LEV KISELEV	{"phone": "+70853823396"}
0005434068671	7E1EBF	1619 071080	ARINA FADEEVA	{"email": "fadeeva-a.26121968@postgrespro.ru", "phone": "+70478553106"}
0005434068672	B75896	4282 255196	VALERIYA MOROZOVA	{"phone": "+70720340910"}
0005434068673	A13618	1887 308358	ELENA GRISHINA	{"email": "grishinaelena_031977@postgrespro.ru", "phone": "+70965601093"}
0005434068674	9E0485	2442 531383	EVGENIY GORBUNOV	{"phone": "+70187850063"}
0005434068675	FA9236	9393 783538	RAMAZAN SCHERBAKOV	{"email": "scherbakov.ramazan_30041953@postgrespro.ru", "phone": "+70624579562"}
0005434068676	FA9236	8647 568413	VALERIY KULIKOV	{"email": "vkulikov.14111962@postgrespro.ru", "phone": "+70281198826"}
0005434068677	4730A9	9465 209961	GALINA MIRONOVA	{"email": "mironovagalina.08121969@postgrespro.ru", "phone": "+70272433658"}
0005434068678	7AD9A4	1203 639683	ELENA TROFIMOVA	{"phone": "+70772117594"}
0005434068679	170095	3229 606018	VASILIY VASILEV	{"email": "vasiliy.vasilev1974@postgrespro.ru", "phone": "+70393700068"}
0005434068680	AECCB5	4347 866521	GALINA ANTONOVA	{"email": "galina-antonova081977@postgrespro.ru", "phone": "+70860984097"}
0005434068681	AECCB5	0174 041872	NIKOLAY ANTONOV	{"phone": "+70059646713"}
0005434068682	8E42CC	7857 904855	ALEKSANDR ZAYCEV	{"email": "a_zaycev-051967@postgrespro.ru", "phone": "+70667766800"}
0005434068683	C3784D	8162 725051	ALEKSANDR EGOROV	{"email": "a.egorov_1967@postgrespro.ru", "phone": "+70047012040"}
0005434068684	C3784D	9595 823124	IVAN FOMIN	{"phone": "+70316980946"}
0005434068685	D2DC10	8088 404993	GENNADIY ZHUKOV	{"email": "zhukov_g.23011976@postgrespro.ru", "phone": "+70582614240"}
0005434068686	C203B0	7149 633452	KRISTINA GERASIMOVA	{"email": "gerasimova.k-1959@postgrespro.ru", "phone": "+70440337548"}
0005434068687	E4A728	6203 659142	EKATERINA LEBEDEVA	{"phone": "+70672928603"}
0005434068688	E4A728	6962 608136	VADIM NAUMOV	{"email": "naumov.v-06061969@postgrespro.ru", "phone": "+70441482094"}
0005434068689	4D80C3	6915 806909	YURIY GERASIMOV	{"phone": "+70598806472"}
0005434068690	1D6E81	8114 651950	NADEZHDA NIKITINA	{"phone": "+70633328182"}
0005434068691	7E304F	2275 197218	NADEZHDA MELNIKOVA	{"phone": "+70061274164"}
0005434068692	7E304F	5605 310237	VASILIY NIKOLAEV	{"email": "v-nikolaev1974@postgrespro.ru", "phone": "+70759576679"}
0005434068693	CFD62F	3123 248188	NATALIYA VASILEVA	{"email": "vasileva_n27031985@postgrespro.ru", "phone": "+70685110728"}
0005434068694	AF930C	7901 700264	ALEKSEY CHERNOV	{"phone": "+70752516283"}
0005434068695	AF930C	2587 826344	YURIY KOZLOV	{"email": "kozlovyuriy_06101970@postgrespro.ru", "phone": "+70382862542"}
0005434068696	AF930C	4520 569365	LIDIYA FROLOVA	{"email": "lidiya.frolova.1967@postgrespro.ru", "phone": "+70762494459"}
0005434068697	1F2C7E	5527 241849	SERGEY VOLKOV	{"phone": "+70791330117"}
0005434068698	1F2C7E	0484 317386	SERGEY ANDREEV	{"email": "sergey_andreev_081977@postgrespro.ru", "phone": "+70580562941"}
0005434068699	4ABF77	2014 966873	VALENTINA PAVLOVA	{"email": "pavlova.valentina.10121972@postgrespro.ru", "phone": "+70458490173"}
0005434068700	F45576	4218 988429	OLGA KOROLEVA	{"phone": "+70944136408"}
0005434068701	F45576	9553 625429	NIKOLAY ZAYCEV	{"email": "zaycevnikolay_091972@postgrespro.ru", "phone": "+70203635566"}
0005434068702	B05951	7586 947670	EKATERINA FOMINA	{"email": "fomina.ekaterina_10051969@postgrespro.ru", "phone": "+70959005950"}
0005434068703	A6DFD2	0940 772369	ANNA LOGINOVA	{"phone": "+70085508358"}
0005434068704	B9CC6F	4629 233153	ALEKSEY IVANOV	{"email": "aivanov021981@postgrespro.ru", "phone": "+70897412983"}
0005434068705	185A69	4207 779453	NIKOLAY BELOV	{"email": "n_belov061978@postgrespro.ru", "phone": "+70653549932"}
0005434068706	DA5800	9277 391835	SERGEY FOMIN	{"email": "s_fomin1966@postgrespro.ru", "phone": "+70927569253"}
0005434068707	CB7C68	2240 924746	ALENA ANDREEVA	{"email": "alena_andreeva-011971@postgrespro.ru", "phone": "+70050413336"}
0005434068708	979D2A	9891 592151	ZULFIYA KOROLEVA	{"email": "zkoroleva-1969@postgrespro.ru", "phone": "+70830217641"}
0005434068709	932226	3259 432719	IVAN ALEKSEEV	{"email": "ivan-alekseev_111959@postgrespro.ru", "phone": "+70868988766"}
0005434068710	932226	6213 165327	GALINA KOROLEVA	{"phone": "+70826449507"}
0005434068711	F496DB	2654 065700	ALEKSANDRA KUZNECOVA	{"phone": "+70126485013"}
0005434068712	F496DB	4878 079928	IGOR MAKAROV	{"email": "i-makarov.1969@postgrespro.ru", "phone": "+70717104146"}
0005434068713	34A83C	5258 823454	VALERIY KONOVALOV	{"email": "valeriy.konovalov-1967@postgrespro.ru", "phone": "+70750211694"}
0005434068714	811EC0	9715 094643	VIKTORIYA MAKAROVA	{"email": "makarovaviktoriya111979@postgrespro.ru", "phone": "+70156936347"}
0005434068715	811EC0	9607 887897	GALINA KUZNECOVA	{"phone": "+70363935641"}
0005434068716	402A79	6994 344297	OLGA DENISOVA	{"phone": "+70657631978"}
0005434068717	0FBC54	7630 172968	IRINA ANDREEVA	{"phone": "+70604391522"}
0005434068718	21E0A3	1237 013730	VLADIMIR KARPOV	{"email": "v-karpov-061973@postgrespro.ru", "phone": "+70790093932"}
0005434068719	2B4AC1	7790 602218	GEORGIY ZHURAVLEV	{"phone": "+70832185448"}
0005434068720	2B4AC1	5564 183485	VLADIMIR SEMENOV	{"phone": "+70116617626"}
0005434068721	F3DFAE	2146 752048	LYUDMILA BELOVA	{"phone": "+70176383475"}
0005434068722	F3DFAE	3891 509994	GENNADIY ISAEV	{"email": "gennadiy-isaev1975@postgrespro.ru", "phone": "+70730506828"}
0005434068723	9579C3	8121 067563	MARINA TARASOVA	{"phone": "+70609043497"}
0005434068724	9579C3	0869 969271	LYUDMILA IVANOVA	{"email": "ivanova.l.021966@postgrespro.ru", "phone": "+70361067253"}
0005434068725	87EE6D	3931 574462	ARSENIY KARPOV	{"email": "arseniy_karpov_1977@postgrespro.ru", "phone": "+70428230764"}
0005434068726	87EE6D	8216 649427	ALEKSEY SERGEEV	{"email": "alekseysergeev-041955@postgrespro.ru", "phone": "+70940520757"}
0005434068727	0C6217	6916 973909	LIDIYA KOZLOVA	{"phone": "+70794704213"}
0005434068728	0C6217	1788 652375	NINA BORISOVA	{"email": "n-borisova-19091976@postgrespro.ru", "phone": "+70670886996"}
0005434068729	1C3D48	7623 132326	VALENTINA KOROLEVA	{"email": "korolevavalentina_1981@postgrespro.ru", "phone": "+70902261138"}
0005434068730	1C3D48	2006 002038	MARIYA POTAPOVA	{"email": "potapova.m-1982@postgrespro.ru", "phone": "+70822718032"}
0005434068731	D1E3D1	9284 692808	ALEKSEY EGOROV	{"email": "aleksey.egorov_08121977@postgrespro.ru", "phone": "+70154668000"}
0005434068732	D1E3D1	3377 341498	NINA MELNIKOVA	{"phone": "+70157646709"}
0005434068733	5BBE70	1240 301341	AZAT YAKOVLEV	{"email": "yakovlev-azat-111974@postgrespro.ru", "phone": "+70279496842"}
0005434068734	8D7CF9	0474 009426	ANTON NAUMOV	{"phone": "+70758744939"}
0005434068735	9E7DF8	7743 013288	TATYANA ANTONOVA	{"phone": "+70201712217"}
0005434068736	654051	1648 522370	MARINA SOROKINA	{"email": "sorokina.marina.1964@postgrespro.ru", "phone": "+70951516492"}
0005434068737	0768BA	1032 441526	ELIZAVETA KUZNECOVA	{"email": "kuznecova_elizaveta.30101981@postgrespro.ru", "phone": "+70347829468"}
0005434068738	06AC3F	0652 706288	VITALIY POPOV	{"phone": "+70541855531"}
0005434068739	BC1F1D	4759 847874	ANATOLIY ALEKSEEV	{"phone": "+70835208922"}
0005434068740	2F3C2F	2797 107715	ANNA FEDOROVA	{"phone": "+70201271793"}
0005434068741	2F3C2F	6208 068751	ELENA KRASNOVA	{"phone": "+70004256865"}
0005434068742	7D22C3	2623 512192	GULFIYA MOROZOVA	{"email": "morozova-gulfiya_08031972@postgrespro.ru", "phone": "+70038456419"}
0005434068743	4EED5C	9517 177600	VLADIMIR NIKOLAEV	{"phone": "+70087413105"}
0005434068744	91B0A7	5975 677768	RIMA RODIONOVA	{"email": "rodionova.r1963@postgrespro.ru", "phone": "+70183367824"}
0005434068745	91B0A7	6388 194787	NATALYA IVANOVA	{"phone": "+70613056747"}
0005434068746	91B0A7	6412 529083	OLEG BELOV	{"email": "belov-oleg-1973@postgrespro.ru", "phone": "+70477290834"}
0005434068747	AD5D26	9878 488317	GALINA KRASNOVA	{"email": "krasnova.g_1966@postgrespro.ru", "phone": "+70335156994"}
0005434068748	6D4677	5715 820323	IRAIDA LOGINOVA	{"email": "iraida.loginova-20061975@postgrespro.ru", "phone": "+70086797698"}
0005434068749	6D4677	9086 993789	VLADIMIR GORBUNOV	{"phone": "+70693577866"}
0005434068750	B61D5A	1786 861385	NIKOLAY KAZAKOV	{"email": "nikolaykazakov1972@postgrespro.ru", "phone": "+70292490330"}
0005434068751	B61D5A	5541 713473	ALLA SEMENOVA	{"email": "semenova_a051970@postgrespro.ru", "phone": "+70426902200"}
0005434068752	B61D5A	5436 354912	ANDREY MAKSIMOV	{"phone": "+70178554790"}
0005434068753	B46F69	1585 568502	PAVEL ZAKHAROV	{"email": "p_zakharov-1970@postgrespro.ru", "phone": "+70442687156"}
0005434068754	1FAC20	0220 691916	OLGA TIKHONOVA	{"email": "tikhonova.o1964@postgrespro.ru", "phone": "+70877764934"}
0005434068755	6F1CEE	4892 630216	EVGENIY AFANASEV	{"email": "e.afanasev-031973@postgrespro.ru", "phone": "+70479965847"}
0005434068756	EEDE94	9433 946833	DMITRIY ISAEV	{"phone": "+70924740072"}
0005434068757	EEDE94	0607 908092	EKATERINA FILATOVA	{"phone": "+70253953674"}
0005434068758	B50184	5967 068797	VLADIMIR NAUMOV	{"phone": "+70506221108"}
0005434068759	B50184	4120 980703	GENNADIY KUZNECOV	{"phone": "+70031389443"}
0005434068760	7C5CE8	1424 533839	GALINA SMIRNOVA	{"email": "g_smirnova_1972@postgrespro.ru", "phone": "+70478694289"}
0005434068761	2C6DAC	8111 297835	DMITRIY SMIRNOV	{"email": "smirnov-dmitriy_22061973@postgrespro.ru", "phone": "+70886418182"}
0005434068762	A76783	0682 292242	NATALYA SCHERBAKOVA	{"email": "scherbakova.n.091976@postgrespro.ru", "phone": "+70138666388"}
0005434068763	9D0D14	8421 164845	ALEKSANDR GERASIMOV	{"phone": "+70358830380"}
0005434068764	248770	0271 902185	LYUBOV MATVEEVA	{"phone": "+70549876774"}
0005434068765	5C7543	7888 970884	MAKSIM ILIN	{"email": "ilin.m1969@postgrespro.ru", "phone": "+70530025471"}
0005434068766	C1D677	3201 582112	DIANA IVANOVA	{"email": "ivanovadiana_021979@postgrespro.ru", "phone": "+70271384706"}
0005434068936	C44B79	4995 823590	NATALYA GORBUNOVA	{"phone": "+70195857741"}
0005434068767	89E14A	2065 105072	TATYANA ZHURAVLEVA	{"email": "tatyana.zhuravleva-091976@postgrespro.ru", "phone": "+70247408288"}
0005434068768	89E14A	3659 016545	ALEKSEY GRIGOREV	{"phone": "+70699812496"}
0005434068769	1DE2C0	1020 300234	GALINA KULIKOVA	{"email": "kulikova_g_14051964@postgrespro.ru", "phone": "+70062571489"}
0005434068770	F6AFCE	1620 166340	ALENA TITOVA	{"email": "titovaa1961@postgrespro.ru", "phone": "+70436447695"}
0005434068771	87D161	6964 703044	ALBINA MAKSIMOVA	{"phone": "+70601312747"}
0005434068772	4A3EF9	3564 829566	SERGEY ROMANOV	{"phone": "+70615585955"}
0005434068773	609C33	2960 038417	ANNA KRASNOVA	{"email": "krasnova.anna041975@postgrespro.ru", "phone": "+70709242560"}
0005434068774	609C33	7238 539076	GALINA NIKITINA	{"phone": "+70565259707"}
0005434068775	879F84	2538 002305	NIKOLAY IVANOV	{"email": "n_ivanov.051976@postgrespro.ru", "phone": "+70640379512"}
0005434068776	879F84	5177 820101	NIKOLAY ALEKSEEV	{"phone": "+70685851441"}
0005434068777	AB9780	0832 053044	ALEKSANDR KUZNECOV	{"phone": "+70112334583"}
0005434068778	4DD8BB	9944 157853	VIKTOR NAUMOV	{"email": "v_naumov-17071969@postgrespro.ru", "phone": "+70410062572"}
0005434068779	4DD8BB	3338 656504	GALINA TIKHONOVA	{"email": "galinatikhonova.041966@postgrespro.ru", "phone": "+70733663940"}
0005434068780	1799A6	9183 139518	TATYANA PETROVA	{"phone": "+70143502086"}
0005434068781	1799A6	1920 214239	TATYANA IVANOVA	{"email": "t_ivanova-051975@postgrespro.ru", "phone": "+70873749094"}
0005434068782	D08D40	5606 283386	PETR FEDOROV	{"phone": "+70372847871"}
0005434068783	D08D40	2486 845481	IVAN KRASNOV	{"phone": "+70867657629"}
0005434068784	350F9F	5739 396655	DMITRIY FROLOV	{"phone": "+70790095308"}
0005434068785	25B002	6995 603283	SERGEY ANTONOV	{"phone": "+70174359686"}
0005434068786	25B002	8801 167769	NIKITA TIMOFEEV	{"email": "timofeev_nikita.1973@postgrespro.ru", "phone": "+70534530323"}
0005434068787	0C0011	0100 148884	DENIS ZAKHAROV	{"phone": "+70716678223"}
0005434068788	3D290E	7929 926184	NATALYA ALEKSANDROVA	{"phone": "+70478206348"}
0005434068789	3D290E	8542 763395	ZUKHRA TITOVA	{"email": "ztitova-15031981@postgrespro.ru", "phone": "+70519508035"}
0005434068790	F345FB	2661 466705	RAISA OSIPOVA	{"email": "osipova.raisa_101976@postgrespro.ru", "phone": "+70540175082"}
0005434068791	DF9052	9522 484984	SERGEY KUDRYASHOV	{"phone": "+70633282151"}
0005434068792	5FE0AA	9798 388822	EVGENIY SEMENOV	{"email": "semenov-e1964@postgrespro.ru", "phone": "+70329480231"}
0005434068793	5BEDA7	1506 661784	GENNADIY MEDVEDEV	{"phone": "+70047286685"}
0005434068794	5BEDA7	8296 487765	DANIIL KOZLOV	{"email": "d.kozlov-1960@postgrespro.ru", "phone": "+70968438918"}
0005434068795	6AB4B4	6959 388940	GALINA SMIRNOVA	{"email": "g.smirnova.111974@postgrespro.ru", "phone": "+70525170306"}
0005434068796	1F5126	0988 998099	ELENA SCHERBAKOVA	{"phone": "+70168463664"}
0005434068797	AF20D4	2040 468783	NATALYA BOGDANOVA	{"email": "bogdanova-natalya121972@postgrespro.ru", "phone": "+70342829470"}
0005434068798	93BBB8	5231 902212	ELENA MIKHAYLOVA	{"phone": "+70643069364"}
0005434068799	1AC16D	2900 242783	SVETLANA DAVYDOVA	{"phone": "+70068470387"}
0005434068800	AAE44E	0504 030599	YURIY OSIPOV	{"email": "osipovyuriy-29081965@postgrespro.ru", "phone": "+70649286117"}
0005434068801	8024A6	5952 020148	ELENA SOROKINA	{"phone": "+70542674301"}
0005434068802	8024A6	3132 360118	VLADIMIR BORISOV	{"phone": "+70431797657"}
0005434068803	C6F709	5670 515077	ILYA SAVELEV	{"phone": "+70829565002"}
0005434068804	790A95	7807 684087	ALEKSEY MOROZOV	{"phone": "+70597034384"}
0005434068805	790A95	9752 505238	DANILA EGOROV	{"email": "egorov.d_121973@postgrespro.ru", "phone": "+70195177464"}
0005434068806	B7B7C2	4313 599971	STANISLAV ILIN	{"phone": "+70025614945"}
0005434068807	97BAAF	8950 047031	ALEKSANDR PETROV	{"phone": "+70510634939"}
0005434068808	F4978F	5933 882605	NIKOLAY NIKOLAEV	{"email": "nikolaev_n041978@postgrespro.ru", "phone": "+70548711337"}
0005434068809	F4978F	4523 361360	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrovaanastasiya_031969@postgrespro.ru", "phone": "+70365511660"}
0005434068810	AF32C1	4533 503870	LYUBOV ZAYCEVA	{"phone": "+70918937093"}
0005434068811	211CBA	4286 767589	TATYANA VOLKOVA	{"phone": "+70699544735"}
0005434068812	5E0810	3732 919848	KIRILL SOKOLOV	{"email": "kirillsokolov.111978@postgrespro.ru", "phone": "+70384698649"}
0005434068813	5E0810	0196 807627	NIKOLAY PETROV	{"phone": "+70619564586"}
0005434068814	5E0810	0442 897266	DARYA PETROVA	{"email": "petrova_darya.061990@postgrespro.ru", "phone": "+70401722247"}
0005434068815	725BC8	6653 296263	MAYYA TITOVA	{"phone": "+70418734063"}
0005434068816	8088F3	3252 077599	LYUDMILA ZOTOVA	{"email": "zotova-lyudmila-02091976@postgrespro.ru", "phone": "+70804299333"}
0005434068817	3DFB4E	8217 258451	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-12021974@postgrespro.ru", "phone": "+70229765373"}
0005434068818	B462AE	5559 785793	ANATOLIY CHERNOV	{"email": "anatoliy.chernov1975@postgrespro.ru", "phone": "+70107172731"}
0005434068819	B462AE	6722 219056	ELENA EGOROVA	{"phone": "+70549321117"}
0005434068820	43A3EF	8665 337261	VERA OSIPOVA	{"email": "osipovav_24071966@postgrespro.ru", "phone": "+70859774675"}
0005434068821	7536B9	7786 701146	LYUDMILA ANDREEVA	{"phone": "+70415089124"}
0005434068823	5D16A0	4537 691011	ALEKSANDR SERGEEV	{"phone": "+70825795142"}
0005434068824	5D16A0	2674 412009	ALEKSEY SEMENOV	{"phone": "+70631464346"}
0005434068825	5D16A0	7687 214519	ALEVTINA MATVEEVA	{"email": "alevtina-matveeva-16041987@postgrespro.ru", "phone": "+70552460120"}
0005434068826	20E967	9853 896498	SERGEY KOZLOV	{"phone": "+70032327379"}
0005434068827	E521EF	7800 273786	ALEKSANDR VOLKOV	{"phone": "+70960533271"}
0005434068828	B6797A	8478 510818	DMITRIY ROMANOV	{"email": "romanov_d-011968@postgrespro.ru", "phone": "+70174701952"}
0005434068829	98FF86	9810 184596	ELENA KONDRATEVA	{"email": "e.kondrateva_03031965@postgrespro.ru", "phone": "+70478282311"}
0005434068830	57635A	0473 619855	YURIY MIKHAYLOV	{"email": "yuriy_mikhaylov081976@postgrespro.ru", "phone": "+70672084344"}
0005434068831	73FA88	9801 215194	DAMIR POPOV	{"email": "popov-d-091981@postgrespro.ru", "phone": "+70560067878"}
0005434068832	B3D97A	9784 919104	GRIGORIY KAZAKOV	{"email": "kazakov.grigoriy07111992@postgrespro.ru", "phone": "+70991298169"}
0005434068833	942692	3768 208715	OLGA GRISHINA	{"email": "grishinaolga.071977@postgrespro.ru", "phone": "+70218343188"}
0005434068834	719650	7074 645976	DMITRIY EGOROV	{"phone": "+70115766448"}
0005434068835	7D2CD6	5900 100041	VALENTINA KONOVALOVA	{"phone": "+70269020755"}
0005434068836	3D716D	7338 651521	GALINA FROLOVA	{"email": "galina_frolova_1954@postgrespro.ru", "phone": "+70751877872"}
0005434068837	CDC87D	2104 273624	SVETLANA NIKIFOROVA	{"email": "nikiforova_svetlana011982@postgrespro.ru", "phone": "+70868338819"}
0005434068838	43CB2F	7981 123046	BORIS NIKITIN	{"email": "nikitinboris1971@postgrespro.ru", "phone": "+70388532004"}
0005434068839	0FFF34	3750 238037	PAVEL ALEKSEEV	{"email": "pavel.alekseev_12011971@postgrespro.ru", "phone": "+70021400436"}
0005434068840	01B927	1358 393339	DENIS GORBUNOV	{"email": "gorbunovd-021980@postgrespro.ru", "phone": "+70596458250"}
0005434068841	D199CB	0828 639683	VALERIY KUZNECOV	{"email": "valeriy.kuznecov-081986@postgrespro.ru", "phone": "+70264066993"}
0005434068842	439768	9442 613940	NINA ORLOVA	{"phone": "+70470589867"}
0005434068843	17577B	6987 664859	ALINA KALININA	{"email": "a_kalinina1976@postgrespro.ru", "phone": "+70945208730"}
0005434068844	4D666F	7121 368105	NADEZHDA STEPANOVA	{"email": "stepanova_n_061979@postgrespro.ru", "phone": "+70179024589"}
0005434068845	4D666F	5549 222246	VLADIMIR PETROV	{"email": "vladimir-petrov.25111965@postgrespro.ru", "phone": "+70324474033"}
0005434068846	9B0504	7526 172707	ALEKSEY TARASOV	{"email": "tarasov-aleksey.061962@postgrespro.ru", "phone": "+70804166134"}
0005434068847	9B0504	9696 869163	OLGA NAZAROVA	{"phone": "+70311739350"}
0005434068848	BF87A8	6191 309622	SERGEY OSIPOV	{"email": "sosipov-051978@postgrespro.ru", "phone": "+70409059859"}
0005434068849	BC8B1F	1006 912566	ROMAN KOZLOV	{"phone": "+70737098779"}
0005434068850	5D4353	3498 949126	GALINA FROLOVA	{"phone": "+70635159047"}
0005434068851	0E596E	2407 444175	MARGARITA KOROLEVA	{"phone": "+70604649469"}
0005434068852	FFF1FD	9822 456056	YULIYA MALYSHEVA	{"phone": "+70774900227"}
0005434068853	E9FA1E	3199 863847	EVGENIY EGOROV	{"phone": "+70511644452"}
0005434068854	CA7B38	7921 773628	MARIYA AFANASEVA	{"phone": "+70532072179"}
0005434068855	21FDD0	2559 034490	VLADIMIR SEMENOV	{"email": "v.semenov.13071968@postgrespro.ru", "phone": "+70055144099"}
0005434068856	70D7B0	3343 421494	VADIM ANDREEV	{"phone": "+70093072889"}
0005434068857	70D7B0	6226 756328	ILYA PETROV	{"phone": "+70991754635"}
0005434068858	E82EDB	2272 438151	MARGARITA FROLOVA	{"phone": "+70582720745"}
0005434068859	A24D86	8888 598374	RUSLAN ROMANOV	{"phone": "+70262115957"}
0005434068860	71C027	5084 354116	OLEG FILIPPOV	{"email": "filippov_o1969@postgrespro.ru", "phone": "+70733331085"}
0005434068861	303488	4771 640618	RINAT FEDOTOV	{"email": "fedotov_r-121970@postgrespro.ru", "phone": "+70112974815"}
0005434068862	0A8A3B	3523 484304	DANIIL MARTYNOV	{"phone": "+70978376662"}
0005434068863	B32F2D	8045 152293	EVGENIY AFANASEV	{"phone": "+70283734273"}
0005434068864	B32F2D	8089 769180	VYACHESLAV POPOV	{"phone": "+70143643959"}
0005434068865	AE07E8	9724 359984	ALEKSANDR VLASOV	{"email": "a-vlasov101969@postgrespro.ru", "phone": "+70009307919"}
0005434068866	ADFDA9	5447 877341	NIKOLAY GUSEV	{"phone": "+70144871883"}
0005434068867	ADFDA9	8179 457617	DARYA KOZLOVA	{"email": "dkozlova011972@postgrespro.ru", "phone": "+70465699237"}
0005434068868	ADFDA9	0654 691034	VIKTOR KUZNECOV	{"email": "viktor-kuznecov_17011980@postgrespro.ru", "phone": "+70973602567"}
0005434068869	D7479F	3830 693025	EVGENIY KUZNECOV	{"phone": "+70163451393"}
0005434068870	D7479F	5255 249358	IRINA TITOVA	{"phone": "+70313005917"}
0005434068871	2A041C	5525 521930	ALEKSANDR BORISOV	{"phone": "+70804106748"}
0005434068872	86717B	1320 474431	EKATERINA KOZLOVA	{"phone": "+70096593311"}
0005434068873	A198ED	2969 045841	NIKOLAY IVANOV	{"email": "nivanov.051962@postgrespro.ru", "phone": "+70529658207"}
0005434068874	9832A5	1197 122423	VALENTINA PAVLOVA	{"phone": "+70956366607"}
0005434068875	B5EF65	1218 007332	KONSTANTIN MELNIKOV	{"phone": "+70016404599"}
0005434068876	AFF189	0241 745951	KIRILL ZAKHAROV	{"email": "zakharov_kirill-1966@postgrespro.ru", "phone": "+70409744843"}
0005434068877	15CDA8	4589 139731	VIKTOR KULIKOV	{"phone": "+70672023427"}
0005434068878	15CDA8	6521 399058	ALEKSANDRA SAVELEVA	{"email": "a_saveleva031988@postgrespro.ru", "phone": "+70524668464"}
0005434068879	5D28CC	2139 516808	TATYANA NIKITINA	{"phone": "+70882792883"}
0005434068880	5D28CC	5891 429740	ALEKSANDR ILIN	{"email": "a-ilin-06081970@postgrespro.ru", "phone": "+70200918928"}
0005434068993	A47721	1412 127793	LUIZA KALININA	{"phone": "+70761011955"}
0005434068881	8A5870	8615 872458	DZHAMILYA ZAYCEVA	{"email": "d-zayceva1981@postgrespro.ru", "phone": "+70718045927"}
0005434068882	8A5870	3749 378326	OLGA MEDVEDEVA	{"phone": "+70780610895"}
0005434068883	CC7697	9826 959927	LYUDMILA PETROVA	{"email": "petrova_lyudmila_21071974@postgrespro.ru", "phone": "+70799700632"}
0005434068884	CC7697	0195 038326	GALINA FROLOVA	{"email": "g.frolova101964@postgrespro.ru", "phone": "+70574808158"}
0005434068885	8B3235	9206 412492	OLEG KUZNECOV	{"phone": "+70421294657"}
0005434068886	6AD06D	1886 339808	YULIYA ALEKSEEVA	{"email": "yuliya.alekseeva.091968@postgrespro.ru", "phone": "+70851091189"}
0005434068887	2DFCD7	2126 410966	VIKTOR KOZLOV	{"phone": "+70284639050"}
0005434068888	9CCFA5	5722 185939	MARIYA ALEKSANDROVA	{"phone": "+70950132035"}
0005434068889	9CCFA5	0573 062357	VALERIY TARASOV	{"phone": "+70635996862"}
0005434068890	BEEA89	1482 909867	GEORGIY KUZMIN	{"email": "kuzmin.g_1982@postgrespro.ru", "phone": "+70693566620"}
0005434068891	FEFC8F	9941 048942	ZOYA KUZNECOVA	{"email": "kuznecova_zoya1981@postgrespro.ru", "phone": "+70542876415"}
0005434068892	FEFC8F	9920 746207	SERGEY FROLOV	{"phone": "+70595258360"}
0005434068893	54AEFB	8541 263516	RENAT ORLOV	{"email": "rorlov_17081975@postgrespro.ru", "phone": "+70115589040"}
0005434068894	800D29	1729 194965	SERGEY FEDOROV	{"email": "fedorov_s_1974@postgrespro.ru", "phone": "+70287847176"}
0005434068895	1A4F6E	1464 763136	EVGENIY MIKHAYLOV	{"email": "e-mikhaylov_121974@postgrespro.ru", "phone": "+70906560624"}
0005434068896	1A4F6E	6037 637934	ALENA TIKHONOVA	{"email": "tikhonova-a-21011965@postgrespro.ru", "phone": "+70023262885"}
0005434068897	1A4F6E	0376 992551	GRIGORIY BORISOV	{"phone": "+70552288115"}
0005434068898	B0960F	0505 327214	ANTON POPOV	{"email": "a-popov1964@postgrespro.ru", "phone": "+70914058960"}
0005434068899	D474B8	0234 680145	RAISA KUZNECOVA	{"phone": "+70010949945"}
0005434068900	D474B8	4553 115430	VERA ANISIMOVA	{"phone": "+70320865753"}
0005434068901	C969DD	2920 157425	ANATOLIY MIRONOV	{"phone": "+70087799607"}
0005434068902	C969DD	2954 702235	SERGEY GERASIMOV	{"email": "sergey.gerasimov17071972@postgrespro.ru", "phone": "+70679002777"}
0005434068903	C969DD	5393 242083	OKSANA TARASOVA	{"phone": "+70585932567"}
0005434068904	A6E6EE	6951 691900	ALEVTINA NIKOLAEVA	{"email": "nikolaevaalevtina.1968@postgrespro.ru", "phone": "+70498053942"}
0005434068905	A6E6EE	8884 892704	ANATOLIY STEPANOV	{"phone": "+70387164136"}
0005434068906	D332F6	5250 361665	YURIY FILIPPOV	{"email": "filippov_yuriy_1963@postgrespro.ru", "phone": "+70872544484"}
0005434068907	D332F6	6661 460787	VLADIMIR EGOROV	{"email": "egorov_vladimir-1964@postgrespro.ru", "phone": "+70469390537"}
0005434068908	8EA592	4166 030295	ELENA KOLESNIKOVA	{"phone": "+70507561536"}
0005434068909	8EA592	0275 048316	SERGEY DMITRIEV	{"email": "dmitrievsergey_1968@postgrespro.ru", "phone": "+70514781316"}
0005434068910	823516	6977 734192	ANDREY NAUMOV	{"phone": "+70569214680"}
0005434068911	866918	6372 649355	PAVEL ABRAMOV	{"phone": "+70670154844"}
0005434068912	03620F	3931 698471	GALINA PETROVA	{"email": "petrova.galina28081968@postgrespro.ru", "phone": "+70728516120"}
0005434068913	03620F	0524 324125	ALEKSEY KOZLOV	{"email": "kozlov-a.28011975@postgrespro.ru", "phone": "+70052584820"}
0005434068914	03620F	3893 189126	ALEKSANDR KUZMIN	{"phone": "+70793519766"}
0005434068915	63BEC8	7524 466195	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_041972@postgrespro.ru", "phone": "+70698041461"}
0005434068916	838DC5	1641 941655	OLGA MOISEEVA	{"email": "moiseeva.olga12111988@postgrespro.ru", "phone": "+70257924930"}
0005434068917	CFE754	0035 891455	TATYANA BELOVA	{"phone": "+70037474067"}
0005434068918	7D4C3F	3604 525751	VALENTIN AFANASEV	{"email": "v_afanasev1969@postgrespro.ru", "phone": "+70246453908"}
0005434068919	151C61	1655 517538	IRINA GAVRILOVA	{"email": "i-gavrilova.081976@postgrespro.ru", "phone": "+70285943339"}
0005434068920	151C61	9830 094522	VLADIMIR FILIPPOV	{"email": "filippov-v.031989@postgrespro.ru", "phone": "+70730412600"}
0005434068921	A46066	8817 120126	VALENTIN GORBUNOV	{"email": "gorbunov_v051977@postgrespro.ru", "phone": "+70953997076"}
0005434068922	A46066	7452 079115	IVAN MOROZOV	{"email": "morozov-i-11061964@postgrespro.ru", "phone": "+70091598111"}
0005434068923	8E7F50	2282 115619	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov-101973@postgrespro.ru", "phone": "+70238954643"}
0005434068924	8E7F50	3016 362786	NURLAN AFANASEV	{"phone": "+70107464763"}
0005434068925	994F97	3490 418465	IVAN BONDARENKO	{"phone": "+70522606401"}
0005434068926	994F97	6408 770591	RUSTAM ABRAMOV	{"email": "rabramov-20111976@postgrespro.ru", "phone": "+70244457740"}
0005434068927	D55281	3159 050005	LYUDMILA NAUMOVA	{"email": "lnaumova-24071983@postgrespro.ru", "phone": "+70462640200"}
0005434068928	D55281	7417 339116	DIANA ORLOVA	{"phone": "+70693277247"}
0005434068929	DE7AB6	3882 835711	VITALIY ORLOV	{"phone": "+70647200026"}
0005434068930	DE7AB6	9265 186388	SERGEY KAZAKOV	{"phone": "+70222826565"}
0005434068931	88EB02	3809 138140	DMITRIY SOLOVEV	{"email": "solovev_d1980@postgrespro.ru", "phone": "+70033451900"}
0005434068932	88EB02	3595 093800	ALFIYA TARASOVA	{"phone": "+70745822924"}
0005434068933	D64F3E	2820 342463	ALEKSEY KUZNECOV	{"phone": "+70630124023"}
0005434068934	3CB0F1	4761 850278	ALEKSEY SIDOROV	{"email": "sidorov-aleksey-18061976@postgrespro.ru", "phone": "+70791922544"}
0005434069047	62784A	7766 937289	VALENTINA KOZLOVA	{"phone": "+70243543314"}
0005434068935	4540F7	9635 306547	ARINA ALEKSANDROVA	{"email": "aleksandrova_arina_19061972@postgrespro.ru", "phone": "+70360708161"}
0005434068937	F2F886	9829 905707	NIKITA FEDOROV	{"email": "fedorov_n121967@postgrespro.ru", "phone": "+70834659555"}
0005434068938	61147D	2171 445301	LYUDMILA TIKHONOVA	{"phone": "+70028936943"}
0005434068939	61147D	8229 916217	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana-1972@postgrespro.ru", "phone": "+70014018859"}
0005434068940	61147D	6210 089837	NIKITA BORISOV	{"email": "borisov.nikita_011978@postgrespro.ru", "phone": "+70673460976"}
0005434068941	ECF348	1390 498221	GALINA MAKAROVA	{"phone": "+70713930171"}
0005434068942	ECF348	6175 542279	VADIM KUZNECOV	{"email": "v_kuznecov1967@postgrespro.ru", "phone": "+70197932142"}
0005434068943	20156E	1563 764186	NINA MAKSIMOVA	{"email": "maksimovanina_1972@postgrespro.ru", "phone": "+70280776482"}
0005434068944	D5D5A8	5195 711076	IRINA FROLOVA	{"phone": "+70098480364"}
0005434068945	D9C6E6	6401 674494	RAISA GUSEVA	{"email": "raisa_guseva-14121972@postgrespro.ru", "phone": "+70631413100"}
0005434068946	927140	0631 330339	NADEZHDA DMITRIEVA	{"email": "nadezhda.dmitrieva.031976@postgrespro.ru", "phone": "+70171118392"}
0005434068947	F23C66	5787 584957	ILDUS DENISOV	{"email": "idenisov1968@postgrespro.ru", "phone": "+70946438902"}
0005434068948	F1124B	7751 716576	RAISA STEPANOVA	{"email": "raisastepanova-1983@postgrespro.ru", "phone": "+70653775915"}
0005434068949	460D02	8057 074311	OLGA GRISHINA	{"phone": "+70497648574"}
0005434068950	C143D9	3173 106078	ANASTASIYA ANISIMOVA	{"email": "a-anisimova_25021972@postgrespro.ru", "phone": "+70913994717"}
0005434068951	C143D9	5975 855500	SERGEY NAZAROV	{"phone": "+70790832474"}
0005434068952	C143D9	6757 033994	ANDREY YAKOVLEV	{"email": "andrey.yakovlev.091970@postgrespro.ru", "phone": "+70016892173"}
0005434068953	E2CF91	1253 277433	MARAT ZAKHAROV	{"phone": "+70297502342"}
0005434068954	E2CF91	2813 221580	ANTON KUZNECOV	{"phone": "+70559273434"}
0005434068955	95EDB1	2272 760831	YULIYA ISAEVA	{"email": "yuliyaisaeva.1965@postgrespro.ru", "phone": "+70271598326"}
0005434068956	F6B724	7536 881928	PAVEL SMIRNOV	{"email": "smirnov_pavel031971@postgrespro.ru", "phone": "+70238562425"}
0005434068957	0D05C7	6580 468885	ELIZAVETA PETROVA	{"email": "elizavetapetrova.28011985@postgrespro.ru", "phone": "+70213973158"}
0005434068958	B0FF6B	2011 125350	OLGA GAVRILOVA	{"phone": "+70106245423"}
0005434068959	7A7E21	1465 000503	VERA YAKOVLEVA	{"phone": "+70941898770"}
0005434068960	F7241E	4823 232046	ALEKSEY KUZMIN	{"email": "kuzmin-a.13051985@postgrespro.ru", "phone": "+70442091638"}
0005434068961	F7241E	9897 501739	ARTEM POPOV	{"phone": "+70228757722"}
0005434068962	727A62	6630 476256	IRINA ILINA	{"email": "i.ilina.071964@postgrespro.ru", "phone": "+70717008361"}
0005434068963	0F96D8	7444 788134	ALEKSANDR KUZNECOV	{"phone": "+70860000891"}
0005434068964	786F3E	9654 643339	IRINA YAKOVLEVA	{"phone": "+70281576223"}
0005434068965	435141	7564 529881	GEORGIY VASILEV	{"email": "georgiy_vasilev-031970@postgrespro.ru", "phone": "+70914235554"}
0005434068966	AECB4F	1530 089654	VITALIY VLASOV	{"phone": "+70978822667"}
0005434068967	E3520B	3796 017243	DMITRIY MARTYNOV	{"email": "martynov-d011969@postgrespro.ru", "phone": "+70500498077"}
0005434068968	E3520B	7098 708568	MARINA KOROLEVA	{"email": "marina_koroleva.25061973@postgrespro.ru", "phone": "+70978067825"}
0005434068969	2E722D	6491 483222	ZINAIDA FEDOROVA	{"phone": "+70355436092"}
0005434068970	0D8EE8	1623 978303	DANIL ZAKHAROV	{"email": "danil.zakharov_051973@postgrespro.ru", "phone": "+70612881380"}
0005434068971	317EEC	7694 352585	VLADIMIR BONDARENKO	{"phone": "+70862802430"}
0005434068972	7E5B4B	3842 374090	ANATOLIY AFANASEV	{"phone": "+70396919119"}
0005434068973	7F67C9	1321 002728	MAKSIM MIKHAYLOV	{"email": "mikhaylov-m.1979@postgrespro.ru", "phone": "+70572691632"}
0005434068974	468AE4	4581 412797	ILMIR KARPOV	{"email": "ilmir.karpov-021979@postgrespro.ru", "phone": "+70633594824"}
0005434068975	8518F4	0411 974394	MARINA VOLKOVA	{"phone": "+70849089789"}
0005434068976	8518F4	8823 391340	NATALYA KOLESNIKOVA	{"phone": "+70790203059"}
0005434068977	DAA423	1572 429709	POLINA BELYAEVA	{"email": "polina_belyaeva-041970@postgrespro.ru", "phone": "+70246037222"}
0005434068978	C90761	8407 966077	ZINAIDA MASLOVA	{"email": "zmaslova13101970@postgrespro.ru", "phone": "+70806523165"}
0005434068979	E2B8FC	0244 466407	LIDIYA GORBUNOVA	{"phone": "+70305538818"}
0005434068980	2863BC	8001 832924	ELIZAVETA FEDOROVA	{"email": "fedorova_e-031961@postgrespro.ru", "phone": "+70776663171"}
0005434068981	A04B6C	9218 114710	TAISIYA ALEKSEEVA	{"phone": "+70693037120"}
0005434068982	A04B6C	5574 508927	NINA NESTEROVA	{"phone": "+70121175675"}
0005434068983	F80D05	7919 864581	ALEKSANDR BONDARENKO	{"phone": "+70424449544"}
0005434068984	1FE28B	5401 632325	VALENTINA ZHURAVLEVA	{"phone": "+70714424366"}
0005434068985	B3E608	6849 429806	VITALIY SERGEEV	{"email": "vitaliy-sergeev.021974@postgrespro.ru", "phone": "+70873528981"}
0005434068986	25F010	1325 615256	ANASTASIYA VOROBEVA	{"phone": "+70375038593"}
0005434068987	15AD3B	5407 522125	KIRILL KRASNOV	{"phone": "+70958284768"}
0005434068988	BE6838	1213 367445	VALENTINA NESTEROVA	{"phone": "+70759025671"}
0005434068989	F09EFB	3393 741811	SVETLANA EGOROVA	{"phone": "+70600953077"}
0005434068990	590645	2774 715153	ANATOLIY NAZAROV	{"phone": "+70173549906"}
0005434068991	3E3E99	2291 434696	ALEKSANDRA PAVLOVA	{"email": "pavlova-aleksandra_051977@postgrespro.ru", "phone": "+70263902370"}
0005434068992	A47721	7848 776703	ANASTASIYA VOROBEVA	{"phone": "+70322652232"}
0005434068994	13095A	3801 758346	DMITRIY PETROV	{"email": "d-petrov1979@postgrespro.ru", "phone": "+70482305803"}
0005434068995	21D6AA	9417 638593	ALEKSANDR MATVEEV	{"phone": "+70539602860"}
0005434068996	62F35C	6053 540910	ANASTASIYA KARPOVA	{"phone": "+70786368944"}
0005434068997	17BC68	2811 481690	IVAN OSIPOV	{"email": "ivan_osipov-30051967@postgrespro.ru", "phone": "+70457927152"}
0005434068998	0C2623	7124 428681	VIKTOR DAVYDOV	{"phone": "+70132669443"}
0005434068999	D3CEDC	0623 740919	LYUDMILA SMIRNOVA	{"phone": "+70863595813"}
0005434069000	D3CEDC	3408 728122	VLADIMIR SMIRNOV	{"email": "v_smirnov18101962@postgrespro.ru", "phone": "+70879599942"}
0005434069001	2D337B	9691 140968	IRINA GORBUNOVA	{"phone": "+70389654539"}
0005434069002	2D337B	4240 452853	BORIS SMIRNOV	{"email": "smirnov_b-1977@postgrespro.ru", "phone": "+70776648893"}
0005434069003	404BF1	1778 276127	RAISA ROMANOVA	{"email": "romanovar_20031979@postgrespro.ru", "phone": "+70091849920"}
0005434069004	2ABA55	6670 106414	VIKTORIYA TROFIMOVA	{"email": "trofimova.viktoriya1969@postgrespro.ru", "phone": "+70689820819"}
0005434069005	6618D5	3558 784980	IGOR ISAEV	{"phone": "+70604129045"}
0005434069006	6618D5	8635 169153	FATIMA KUZNECOVA	{"email": "fatima_kuznecova-26071973@postgrespro.ru", "phone": "+70156394224"}
0005434069007	6618D5	7742 361106	NINA FILIPPOVA	{"email": "nina.filippova23011977@postgrespro.ru", "phone": "+70193697276"}
0005434069008	5EFCE8	8417 410696	LYUDMILA IVANOVA	{"phone": "+70554041073"}
0005434069009	5EFCE8	2692 457447	RUSLAN PAVLOV	{"phone": "+70993389092"}
0005434069010	5EFCE8	2949 520391	DMITRIY ANTONOV	{"email": "dantonov_101987@postgrespro.ru", "phone": "+70603776167"}
0005434069011	4DBC3E	2535 132275	NINA MAKAROVA	{"phone": "+70628331821"}
0005434069012	30DD66	5946 237741	SERGEY IVANOV	{"email": "sergey.ivanov1972@postgrespro.ru", "phone": "+70817080829"}
0005434069013	A19D3C	2851 050238	MIKHAIL BORISOV	{"phone": "+70213318601"}
0005434069014	51B030	1066 974702	EVGENIY GORBUNOV	{"phone": "+70991346346"}
0005434069015	D1AACC	2369 183580	ALEKSEY IVANOV	{"email": "aleksey.ivanov_1982@postgrespro.ru", "phone": "+70047817222"}
0005434069016	25D8BD	4034 498065	VALERIYA PAVLOVA	{"email": "pavlova-valeriya-14011982@postgrespro.ru", "phone": "+70207747247"}
0005434069017	E8C663	1887 752117	SERGEY OSIPOV	{"phone": "+70518984451"}
0005434069018	833E8A	6014 571401	SERGEY DMITRIEV	{"email": "dmitriev.sergey-1962@postgrespro.ru", "phone": "+70796983339"}
0005434069019	833E8A	4101 940421	DENIS AFANASEV	{"phone": "+70181566265"}
0005434069020	216D11	4365 837650	EKATERINA SOROKINA	{"phone": "+70441759825"}
0005434069021	F071A9	0078 366341	SERGEY PETROV	{"phone": "+70249733237"}
0005434069022	2CC27E	1681 028702	GLEB GRIGOREV	{"phone": "+70794539303"}
0005434069023	2CC27E	5744 453967	TATYANA MOROZOVA	{"email": "morozovat_22111971@postgrespro.ru", "phone": "+70483896174"}
0005434069024	AE84DE	2005 866063	NIKOLAY KOROLEV	{"email": "korolev_n14091974@postgrespro.ru", "phone": "+70234676959"}
0005434069025	C70B9C	2979 287402	FEDOR POPOV	{"email": "popovf1973@postgrespro.ru", "phone": "+70715593266"}
0005434069026	112462	4377 507612	OLEG NAUMOV	{"email": "onaumov1963@postgrespro.ru", "phone": "+70858455955"}
0005434069027	54ADA7	2456 601854	ELIZAVETA ZHURAVLEVA	{"email": "zhuravleva_e31121968@postgrespro.ru", "phone": "+70014698119"}
0005434069028	D4644C	2383 680073	NATALYA FROLOVA	{"phone": "+70862265794"}
0005434069029	1B2E2B	1464 343924	MARIYA POPOVA	{"email": "popovam-1981@postgrespro.ru", "phone": "+70144808280"}
0005434069030	96A8B1	5405 499842	IVAN BORISOV	{"email": "borisovivan-1968@postgrespro.ru", "phone": "+70471923042"}
0005434069031	CF8777	2107 670373	ARTEM MAKAROV	{"email": "a.makarov.091981@postgrespro.ru", "phone": "+70023846708"}
0005434069032	158727	3002 818555	SERGEY EGOROV	{"phone": "+70833611645"}
0005434069033	3440F1	2135 622476	SVETLANA MIRONOVA	{"email": "mironova-svetlana-061970@postgrespro.ru", "phone": "+70080309509"}
0005434069034	3440F1	7253 980717	NATALYA KULIKOVA	{"email": "n_kulikova1981@postgrespro.ru", "phone": "+70339704916"}
0005434069035	3440F1	2443 371325	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr_1987@postgrespro.ru", "phone": "+70150095446"}
0005434069036	0E3C10	3682 733693	ALEKSEY DMITRIEV	{"phone": "+70000277040"}
0005434069037	0E3C10	0232 794026	NINA AKIMOVA	{"email": "akimovanina_091969@postgrespro.ru", "phone": "+70581261695"}
0005434069038	0E3C10	4653 248462	VYACHESLAV BELOV	{"phone": "+70227035344"}
0005434069039	DC9973	1246 672797	LYUDMILA DENISOVA	{"email": "denisova_l-12051973@postgrespro.ru", "phone": "+70546391469"}
0005434069040	515DC5	5338 025941	VYACHESLAV GRIGOREV	{"phone": "+70568287830"}
0005434069041	0DCD8C	0830 692924	EVGENIY ALEKSEEV	{"email": "evgeniy_alekseev25031966@postgrespro.ru", "phone": "+70146383074"}
0005434069042	4FA606	7400 430062	IVAN DENISOV	{"email": "denisov.i.11021983@postgrespro.ru", "phone": "+70201454467"}
0005434069043	4FA606	1095 133699	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr-061978@postgrespro.ru", "phone": "+70050710235"}
0005434069044	031C38	5386 500431	ILMIRA GUSEVA	{"phone": "+70762128147"}
0005434069045	1912E8	6040 318380	ALEKSANDR KUZMIN	{"phone": "+70802249315"}
0005434069046	68F9DA	6317 599138	ALEKSANDR CHERNOV	{"email": "chernov_a.03021978@postgrespro.ru", "phone": "+70355634467"}
0005434069048	422EF5	3485 281262	SERGEY MIRONOV	{"email": "smironov.061973@postgrespro.ru", "phone": "+70803524826"}
0005434069049	422EF5	2768 053873	SERGEY FILIPPOV	{"email": "sergey-filippov.22031974@postgrespro.ru", "phone": "+70895935244"}
0005434069105	7470FB	9789 527452	EKATERINA POPOVA	{"phone": "+70099248746"}
0005434069050	B2556F	4310 758174	MIKHAIL SIDOROV	{"email": "m.sidorov-121970@postgrespro.ru", "phone": "+70443707188"}
0005434069051	B2556F	4221 655582	ELENA SOKOLOVA	{"phone": "+70124849425"}
0005434069052	CAA78B	2246 168203	ALLA VOLKOVA	{"email": "avolkova.22061970@postgrespro.ru", "phone": "+70796119095"}
0005434069053	CAA78B	2091 838385	YANA KOZLOVA	{"email": "kozlova.y27031965@postgrespro.ru", "phone": "+70185820083"}
0005434069054	57139C	7016 446836	NATALYA EGOROVA	{"phone": "+70622320394"}
0005434069055	57139C	6861 029160	VALENTINA ANTONOVA	{"email": "valentinaantonova15031983@postgrespro.ru", "phone": "+70445275964"}
0005434069056	57139C	8001 497883	ALEKSEY KUZNECOV	{"phone": "+70055503993"}
0005434069057	049FDF	0139 076041	OLEG ROMANOV	{"email": "romanov_oleg1986@postgrespro.ru", "phone": "+70728927522"}
0005434069058	0B3CC2	1886 317008	SVETLANA KOVALEVA	{"phone": "+70386639579"}
0005434069059	0B3CC2	9913 883780	ALEKSANDR MAKAROV	{"email": "a_makarov-29121977@postgrespro.ru", "phone": "+70305597635"}
0005434069060	A9F3C5	0265 153412	MARIYA ORLOVA	{"email": "mariyaorlova.19061969@postgrespro.ru", "phone": "+70764797334"}
0005434069061	767142	9582 076607	RAISA KULIKOVA	{"email": "r.kulikova_07061969@postgrespro.ru", "phone": "+70084941217"}
0005434069062	767142	1235 638454	ELENA MIKHAYLOVA	{"email": "elena.mikhaylova.1978@postgrespro.ru", "phone": "+70616437131"}
0005434069063	02AE4D	0797 970548	ANATOLIY MIKHAYLOV	{"email": "anatoliy-mikhaylov-1987@postgrespro.ru", "phone": "+70014879169"}
0005434069064	8C7286	6447 293741	VLADIMIR KUDRYASHOV	{"email": "kudryashov_v14081973@postgrespro.ru", "phone": "+70173485600"}
0005434069065	7EAB27	8474 803793	ANNA KOROLEVA	{"phone": "+70725505913"}
0005434069066	CCA3A2	8253 335612	GALINA BORISOVA	{"email": "borisova_g.031975@postgrespro.ru", "phone": "+70800401788"}
0005434069067	CCA3A2	9084 850500	PAVEL KAZAKOV	{"phone": "+70000061175"}
0005434069068	45C168	9195 603373	NATALYA MAKAROVA	{"email": "makarovan.021975@postgrespro.ru", "phone": "+70775837280"}
0005434069069	1197BF	6488 144342	DMITRIY ZAKHAROV	{"phone": "+70507655070"}
0005434069070	7CE48E	0593 316299	EGOR SHEVCHENKO	{"email": "shevchenko_e-1976@postgrespro.ru", "phone": "+70717029005"}
0005434069071	7CE48E	9897 106381	ELENA FOMINA	{"email": "fomina-e_1966@postgrespro.ru", "phone": "+70966594080"}
0005434069072	7CE48E	5883 700647	IRINA ISAEVA	{"email": "i.isaeva_1969@postgrespro.ru", "phone": "+70077112056"}
0005434069073	A4BDCD	5112 280243	ALEKSANDR OSIPOV	{"phone": "+70578867323"}
0005434069074	A4BDCD	2242 426584	SALAVAT BORISOV	{"phone": "+70055287186"}
0005434069075	7C9537	9536 403207	DANILA GERASIMOV	{"email": "dgerasimov.16041971@postgrespro.ru", "phone": "+70354190956"}
0005434069076	A93FA1	7818 420965	VLADIMIR ANDREEV	{"email": "vandreev-1983@postgrespro.ru", "phone": "+70625244764"}
0005434069077	806A18	6712 562895	KRISTINA SCHERBAKOVA	{"email": "k.scherbakova071972@postgrespro.ru", "phone": "+70605008964"}
0005434069078	EBB2E8	5100 988719	DMITRIY BARANOV	{"email": "baranov-d-1967@postgrespro.ru", "phone": "+70444076455"}
0005434069079	3257CE	6885 992950	ALEKSANDR FEDOROV	{"email": "fedorov-a011982@postgrespro.ru", "phone": "+70458561701"}
0005434069080	3257CE	1268 189723	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr_041971@postgrespro.ru", "phone": "+70335012019"}
0005434069081	49C6E3	7538 659578	LYUDMILA PETROVA	{"phone": "+70979982023"}
0005434069082	12E3CD	7215 637232	ELENA KALININA	{"email": "e.kalinina1973@postgrespro.ru", "phone": "+70708150008"}
0005434069083	A4041B	6122 640828	PETR BORISOV	{"email": "borisov-petr-061957@postgrespro.ru", "phone": "+70288027771"}
0005434069084	480368	4651 287466	VLADIMIR STEPANOV	{"phone": "+70564517622"}
0005434069085	D8C637	3060 100985	MARIYA KUDRYASHOVA	{"phone": "+70223694528"}
0005434069086	D8C637	6401 014070	MARIYA ERMAKOVA	{"phone": "+70670949252"}
0005434069087	D8C637	5417 211555	NADEZHDA BELYAEVA	{"phone": "+70740123471"}
0005434069088	213111	4312 886974	SVETLANA ARKHIPOVA	{"phone": "+70589153972"}
0005434069089	213111	9674 898297	NADEZHDA KUZNECOVA	{"phone": "+70530723156"}
0005434069090	213111	5777 435330	MIKHAIL KUZNECOV	{"phone": "+70957425147"}
0005434069091	8BA8A8	8835 517106	ROMAN KUZNECOV	{"email": "roman_kuznecov.1974@postgrespro.ru", "phone": "+70652015353"}
0005434069092	8BA8A8	8070 134749	ALLA KULIKOVA	{"phone": "+70395241187"}
0005434069093	34B595	7867 947841	ALEKSANDR NIKITIN	{"email": "a_nikitin.05101973@postgrespro.ru", "phone": "+70016693911"}
0005434069094	819926	1002 359012	NIKITA MOROZOV	{"phone": "+70836039505"}
0005434069095	819926	9340 098602	LIDIYA NIKIFOROVA	{"email": "nikiforoval_18071978@postgrespro.ru", "phone": "+70498445454"}
0005434069096	501ABE	8867 839722	GALINA ZAYCEVA	{"email": "zayceva.g021975@postgrespro.ru", "phone": "+70097560806"}
0005434069097	501ABE	0948 328690	KRISTINA SCHERBAKOVA	{"email": "scherbakova-kristina_10011976@postgrespro.ru", "phone": "+70396354095"}
0005434069098	501ABE	8986 768760	ANTONINA MASLOVA	{"phone": "+70811034177"}
0005434069099	47ECE8	4426 568200	MARIYA GERASIMOVA	{"email": "m_gerasimova_08051970@postgrespro.ru", "phone": "+70319663882"}
0005434069100	47ECE8	8848 861401	EKATERINA POPOVA	{"email": "e-popova.091970@postgrespro.ru", "phone": "+70801210506"}
0005434069101	F4C57A	9891 518570	EVGENIY FEDOTOV	{"email": "fedotov-evgeniy_1964@postgrespro.ru", "phone": "+70078451839"}
0005434069102	2C001E	2670 649569	LEONID SHEVCHENKO	{"email": "leonid-shevchenko031981@postgrespro.ru", "phone": "+70768982537"}
0005434069103	CABFAC	5559 863533	NIKOLAY MOROZOV	{"phone": "+70877197012"}
0005434069104	CABFAC	8354 061190	OKSANA MOROZOVA	{"phone": "+70910838937"}
0005434069106	277A91	1170 398823	ELENA SCHERBAKOVA	{"phone": "+70164291638"}
0005434069224	82DEFA	9522 810086	ALEKSEY KUDRYASHOV	{"phone": "+70897821613"}
0005434069107	CEE6B9	5613 023909	MARIYA OSIPOVA	{"email": "osipova-m23121980@postgrespro.ru", "phone": "+70184994588"}
0005434069108	CEE6B9	9062 413709	NATALYA NAZAROVA	{"email": "nazarovanatalya_1973@postgrespro.ru", "phone": "+70979632329"}
0005434069109	234888	6913 245581	MARGARITA MARTYNOVA	{"email": "martynova_margarita-1966@postgrespro.ru", "phone": "+70682968778"}
0005434069110	234888	7268 996628	VIKTOR SEMENOV	{"phone": "+70094779948"}
0005434069111	304345	0410 645887	OLGA KRASNOVA	{"phone": "+70434930130"}
0005434069112	59EF76	2312 297463	ALEKSANDR ROMANOV	{"email": "a-romanov_071967@postgrespro.ru", "phone": "+70211764042"}
0005434069113	5271D0	6559 075927	ALEKSANDR KOROLEV	{"phone": "+70034066409"}
0005434069114	53D941	6721 726991	TATYANA KONOVALOVA	{"email": "t.konovalova_1971@postgrespro.ru", "phone": "+70401896445"}
0005434069115	DE9F0C	9744 948524	VIKTOR KULIKOV	{"phone": "+70879166382"}
0005434069116	CCFC7A	4342 627311	LIDIYA ANDREEVA	{"email": "lidiya_andreeva_03011971@postgrespro.ru", "phone": "+70904998987"}
0005434069117	E1A690	2572 981272	SERGEY NIKOLAEV	{"email": "sergey.nikolaev061973@postgrespro.ru", "phone": "+70666918643"}
0005434069118	E1A690	3050 771237	DENIS PAVLOV	{"email": "d_pavlov.011976@postgrespro.ru", "phone": "+70331613889"}
0005434069119	F475C1	7804 877868	DMITRIY BARANOV	{"phone": "+70622784197"}
0005434069120	B20B5D	6897 977819	OLGA LAZAREVA	{"phone": "+70406283004"}
0005434069121	4BEB34	5904 262628	NATALYA FADEEVA	{"phone": "+70835894028"}
0005434069122	4BEB34	2653 309261	ALINA IVANOVA	{"email": "a_ivanova01111986@postgrespro.ru", "phone": "+70527529383"}
0005434069123	C219F6	4360 080498	LYUDMILA POLYAKOVA	{"email": "lyudmila.polyakova_041979@postgrespro.ru", "phone": "+70020620336"}
0005434069124	C219F6	2567 806080	BORIS SOROKIN	{"phone": "+70546262409"}
0005434069125	65FBEB	0146 336132	ZOYA ILINA	{"email": "z-ilina-071970@postgrespro.ru", "phone": "+70212421189"}
0005434069126	4A14D0	1447 282030	NINA YUDINA	{"email": "n-yudina_081973@postgrespro.ru", "phone": "+70770087173"}
0005434069127	4A14D0	6400 458736	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir-1970@postgrespro.ru", "phone": "+70449731575"}
0005434069128	7E9CA3	0001 056300	VLADIMIR IVANOV	{"email": "ivanov_v101979@postgrespro.ru", "phone": "+70915605054"}
0005434069129	7E9CA3	3231 867835	VLADIMIR TIKHONOV	{"email": "v.tikhonov_1981@postgrespro.ru", "phone": "+70222482771"}
0005434069130	57F587	4323 572132	ANDREY MAKAROV	{"phone": "+70574924392"}
0005434069131	A03928	6187 739687	IRINA ERMAKOVA	{"phone": "+70904638875"}
0005434069132	A03928	6383 659009	GENNADIY KUZNECOV	{"phone": "+70614658599"}
0005434069133	219C7C	3836 804531	DMITRIY PAVLOV	{"phone": "+70250319827"}
0005434069134	EF95E7	8300 695011	EVGENIY BARANOV	{"phone": "+70421510384"}
0005434069135	EF95E7	9006 974576	GALINA KRASNOVA	{"email": "g.krasnova-1974@postgrespro.ru", "phone": "+70332479058"}
0005434069136	E4ACBE	3791 177676	NIKOLAY VASILEV	{"phone": "+70086039369"}
0005434069137	E4ACBE	4380 372040	NIKOLAY PAVLOV	{"phone": "+70930618284"}
0005434069138	A62875	2023 377167	MARIYA KOROLEVA	{"email": "mariya-koroleva1979@postgrespro.ru", "phone": "+70077393079"}
0005434069139	1FC1E4	4840 712805	VASILIY CHERNOV	{"email": "v.chernov091968@postgrespro.ru", "phone": "+70987950894"}
0005434069140	1FC1E4	7454 852915	TAMARA EFREMOVA	{"phone": "+70653527169"}
0005434069141	5833A0	6676 749420	EKATERINA KISELEVA	{"email": "kiseleva-e031974@postgrespro.ru", "phone": "+70793671177"}
0005434069142	7D8CDC	0580 416116	YULIYA MIKHAYLOVA	{"phone": "+70122841886"}
0005434069143	7D8CDC	0771 085580	SERGEY POPOV	{"email": "sergey_popov_1982@postgrespro.ru", "phone": "+70642524780"}
0005434069144	386518	8031 913092	NATALIYA MAKAROVA	{"phone": "+70810322879"}
0005434069145	386518	5172 172041	VIKTOR NAZAROV	{"email": "nazarovv-041958@postgrespro.ru", "phone": "+70255703258"}
0005434069146	C4FA0A	3313 773948	YURIY KARPOV	{"email": "yuriy_karpov101967@postgrespro.ru", "phone": "+70402006028"}
0005434069147	C50BC8	5446 503120	VIKTOR IVANOV	{"email": "viktor-ivanov-07031986@postgrespro.ru", "phone": "+70987575624"}
0005434069148	F9BD2C	0362 200128	ANDREY PAVLOV	{"email": "andrey.pavlov_1970@postgrespro.ru", "phone": "+70619526681"}
0005434069149	BC0C49	7315 449516	NIKOLAY BARANOV	{"email": "baranovn_081972@postgrespro.ru", "phone": "+70521194246"}
0005434069150	68A64B	9570 971079	SERGEY BELOV	{"email": "sergey-belov-021978@postgrespro.ru", "phone": "+70745314266"}
0005434069151	6F16B5	2511 218158	FILIPP GAVRILOV	{"email": "f.gavrilov.091975@postgrespro.ru", "phone": "+70780360915"}
0005434069152	0FEA3F	1022 602920	VLADIMIR RODIONOV	{"email": "rodionov_vladimir-091972@postgrespro.ru", "phone": "+70906867161"}
0005434069153	0FEA3F	7804 117873	EKATERINA POPOVA	{"phone": "+70513732685"}
0005434069154	0FEA3F	4164 059053	NIKOLAY SMIRNOV	{"phone": "+70955764504"}
0005434069155	D68B84	7990 496431	EVDOKIYA ZHURAVLEVA	{"email": "e-zhuravleva-041978@postgrespro.ru", "phone": "+70053894521"}
0005434069156	F731D9	6906 766599	VLADISLAV VOROBEV	{"email": "vorobevv-30111962@postgrespro.ru", "phone": "+70956234151"}
0005434069157	F731D9	3349 976360	IVAN KUZNECOV	{"email": "ivankuznecov.25021970@postgrespro.ru", "phone": "+70174602989"}
0005434069158	546373	9146 055021	DARYA NAUMOVA	{"email": "darya.naumova1962@postgrespro.ru", "phone": "+70799405971"}
0005434069159	546373	5200 046508	ALEKSANDR ALEKSEEV	{"email": "alekseev-a16071968@postgrespro.ru", "phone": "+70082357622"}
0005434069160	C7B205	9008 584866	PETR IVANOV	{"phone": "+70679403757"}
0005434069161	F3ACD3	1331 555715	VALENTIN GRIGOREV	{"phone": "+70017405251"}
0005434069162	BA2522	5803 164834	VLADIMIR PETROV	{"email": "vladimir-petrov09081978@postgrespro.ru", "phone": "+70837280846"}
0005434069163	C54F70	6299 811347	VLADIMIR KAZAKOV	{"email": "v-kazakov-111973@postgrespro.ru", "phone": "+70166875478"}
0005434069164	17517A	8362 917228	OKSANA ZOTOVA	{"phone": "+70330833154"}
0005434069225	82DEFA	7963 917410	RAISA KUDRYASHOVA	{"phone": "+70368754305"}
0005434069165	35D32F	6106 234697	ANATOLIY BELOV	{"email": "anatoliy-belov.1966@postgrespro.ru", "phone": "+70292082967"}
0005434069166	66BEBC	6454 924021	ANASTASIYA KULIKOVA	{"email": "kulikova-a-1966@postgrespro.ru", "phone": "+70818691022"}
0005434069167	D4A963	4393 927551	VLADIMIR GERASIMOV	{"email": "vladimir.gerasimov-07011969@postgrespro.ru", "phone": "+70924005929"}
0005434069168	0D8E63	3702 184829	OLGA ANTONOVA	{"email": "oantonova_041984@postgrespro.ru", "phone": "+70536804321"}
0005434069169	0D8E63	2211 446697	ANATOLIY ZAKHAROV	{"phone": "+70003097297"}
0005434069170	3493C8	4251 107399	EVGENIY FILIPPOV	{"phone": "+70969559541"}
0005434069171	EEBBDE	5721 635737	DANIIL MAKAROV	{"phone": "+70744701917"}
0005434069172	EEBBDE	8924 075941	IVAN NAZAROV	{"email": "nazarovi_10031968@postgrespro.ru", "phone": "+70836443989"}
0005434069173	651985	1650 485893	LYUDMILA VASILEVA	{"email": "l.vasileva-22011963@postgrespro.ru", "phone": "+70650497671"}
0005434069174	651985	2111 509934	VLADIMIR VLASOV	{"phone": "+70286434454"}
0005434069175	2CD254	5592 150628	NAILYA KOMAROVA	{"phone": "+70280516666"}
0005434069176	A6891C	9633 289787	VALENTINA KOROLEVA	{"email": "v-koroleva_061969@postgrespro.ru", "phone": "+70423895806"}
0005434069177	6770DE	8844 151600	VLADIMIR NIKITIN	{"phone": "+70819440683"}
0005434069178	6770DE	8272 253410	VLADIMIR SCHERBAKOV	{"phone": "+70899376916"}
0005434069179	6770DE	2048 591499	VALERIY DMITRIEV	{"email": "dmitriev-v.1967@postgrespro.ru", "phone": "+70248277648"}
0005434069180	7554F3	1330 562392	PETR SMIRNOV	{"phone": "+70971888937"}
0005434069181	0853F9	6142 325402	VITALIY VOROBEV	{"email": "vvorobev-27091964@postgrespro.ru", "phone": "+70938834974"}
0005434069182	0853F9	3853 189861	ALEKSEY VOROBEV	{"phone": "+70512388361"}
0005434069183	F429B7	5423 957460	VIKTOR SIDOROV	{"email": "sidorov.viktor_041975@postgrespro.ru", "phone": "+70243813614"}
0005434069184	F952F8	7731 300109	MAKSIM MOROZOV	{"email": "mmorozov051980@postgrespro.ru", "phone": "+70576487929"}
0005434069185	9E4D28	5647 882884	YURIY ISAEV	{"email": "isaev.yuriy_08081982@postgrespro.ru", "phone": "+70669716539"}
0005434069186	9E4D28	2788 313803	ALEKSANDR PETROV	{"email": "petrov-a_01061966@postgrespro.ru", "phone": "+70315197864"}
0005434069187	A13F79	0304 598259	VIKTOR SCHERBAKOV	{"phone": "+70031619425"}
0005434069188	1CD6CE	9779 376896	ANDREY RODIONOV	{"phone": "+70871696099"}
0005434069189	1CD6CE	1145 121630	TATYANA GUSEVA	{"email": "guseva.t.1975@postgrespro.ru", "phone": "+70648429507"}
0005434069190	2AD9A0	9929 724425	DENIS ANTONOV	{"email": "antonov_denis1974@postgrespro.ru", "phone": "+70629345901"}
0005434069191	EC6380	6860 208773	SERGEY VASILEV	{"email": "vasilev_sergey_071976@postgrespro.ru", "phone": "+70095211147"}
0005434069192	CC6E47	7126 866928	ALEKSANDRA VOLKOVA	{"phone": "+70878908583"}
0005434069193	CDBA71	1966 587615	SVETLANA GERASIMOVA	{"email": "gerasimovas_01071971@postgrespro.ru", "phone": "+70885852514"}
0005434069194	F0C4F1	7892 921959	DENIS ABRAMOV	{"email": "abramov_denis_1963@postgrespro.ru", "phone": "+70469098602"}
0005434069195	293ABE	0965 188495	RADMIR SIDOROV	{"phone": "+70998857492"}
0005434069196	EDD849	9261 844793	LYUDMILA KUZNECOVA	{"phone": "+70041770047"}
0005434069197	417220	0286 596177	TATYANA ZHURAVLEVA	{"phone": "+70525552208"}
0005434069198	3A8E34	1713 245370	VALERIY GORBUNOV	{"email": "gorbunov-v_31071977@postgrespro.ru", "phone": "+70143757474"}
0005434069199	3A8E34	0011 314018	NIKOLAY KUZMIN	{"email": "kuzmin-nikolay.051975@postgrespro.ru", "phone": "+70968714414"}
0005434069200	3A8E34	7138 174717	SERGEY FILIPPOV	{"email": "filippov_sergey-1965@postgrespro.ru", "phone": "+70000362160"}
0005434069201	C505CF	3617 156470	TATYANA MIRONOVA	{"phone": "+70159437970"}
0005434069202	C505CF	6072 251108	GALINA SERGEEVA	{"email": "galinasergeeva.101967@postgrespro.ru", "phone": "+70538853069"}
0005434069203	C505CF	5984 315770	OLGA NOVIKOVA	{"email": "novikovao.021966@postgrespro.ru", "phone": "+70823327427"}
0005434069204	D663D6	6819 192030	ALEKSEY YAKOVLEV	{"email": "yakovlevaleksey-031970@postgrespro.ru", "phone": "+70412952531"}
0005434069205	D5A452	0340 664219	SERGEY SOKOLOV	{"email": "sokolov.s_1972@postgrespro.ru", "phone": "+70983029286"}
0005434069206	485E31	1061 146535	ALEKSEY GERASIMOV	{"email": "aleksey-gerasimov-101976@postgrespro.ru", "phone": "+70787090998"}
0005434069207	3A31B3	2905 055816	OLESYA MATVEEVA	{"email": "matveeva.o1965@postgrespro.ru", "phone": "+70326736589"}
0005434069208	03E79A	5753 971372	TATYANA TARASOVA	{"phone": "+70187509686"}
0005434069209	76BEDE	9889 720990	TATYANA VASILEVA	{"phone": "+70414855995"}
0005434069210	CF0A0C	8988 146606	IVAN IVANOV	{"phone": "+70087196976"}
0005434069211	E8A744	4239 725287	ALEKSANDR NAZAROV	{"email": "nazarov-a-25101975@postgrespro.ru", "phone": "+70734981095"}
0005434069212	DBAD6C	7937 424655	NATALYA MAKAROVA	{"phone": "+70275378082"}
0005434069213	688715	1265 091561	STANISLAV DMITRIEV	{"email": "sdmitriev_1970@postgrespro.ru", "phone": "+70595481214"}
0005434069214	69190E	4863 547168	RAFAIL BORISOV	{"phone": "+70652042043"}
0005434069215	69190E	2616 716988	VASILIY ISAEV	{"email": "isaev_v121972@postgrespro.ru", "phone": "+70329471773"}
0005434069216	D18CF8	4534 873039	ELENA BOGDANOVA	{"email": "bogdanova.e-31081973@postgrespro.ru", "phone": "+70146053911"}
0005434069217	D18CF8	8559 841173	VIKTORIYA PETROVA	{"email": "petrova-viktoriya1962@postgrespro.ru", "phone": "+70575305572"}
0005434069218	AADF6D	3196 665822	OLESYA KUZMINA	{"email": "o.kuzmina.071979@postgrespro.ru", "phone": "+70212539781"}
0005434069219	0E52F9	5588 043403	TATYANA KUZMINA	{"phone": "+70797926856"}
0005434069220	0E52F9	0316 722493	GALINA POPOVA	{"phone": "+70006847979"}
0005434069221	11D9C6	7317 746188	IVAN IVANOV	{"email": "ivanov_ivan_09011976@postgrespro.ru", "phone": "+70350649337"}
0005434069222	11D9C6	0273 910874	NIKITA PETROV	{"email": "n-petrov_111973@postgrespro.ru", "phone": "+70694143726"}
0005434069223	C523E5	2986 532665	NIKOLAY NOVIKOV	{"email": "novikov-nikolay-1970@postgrespro.ru", "phone": "+70743926242"}
0005434069226	976392	0726 717849	YULIYA VLASOVA	{"phone": "+70616043532"}
0005434069227	976392	5359 621322	OLEG NIKOLAEV	{"phone": "+70662308198"}
0005434069228	16A9C3	5051 244587	DMITRIY MIKHAYLOV	{"phone": "+70624244765"}
0005434069229	16A9C3	7250 275944	RAFAIL NAUMOV	{"email": "r_naumov.28051969@postgrespro.ru", "phone": "+70580827946"}
0005434069230	D7C644	3261 535522	ROZA ANISIMOVA	{"phone": "+70785468895"}
0005434069231	7E86D9	1505 809187	VIKTORIYA LUKYANOVA	{"email": "v-lukyanova.1976@postgrespro.ru", "phone": "+70801962674"}
0005434069232	695CAE	5261 942178	DMITRIY MELNIKOV	{"phone": "+70838422666"}
0005434069233	695CAE	0604 741788	DARYA NESTEROVA	{"email": "darya.nesterova041973@postgrespro.ru", "phone": "+70328475127"}
0005434069234	68F7F0	7123 732147	ANTON RODIONOV	{"phone": "+70269594490"}
0005434069235	68F7F0	5792 191124	ROMAN FILIPPOV	{"email": "filippov_roman011984@postgrespro.ru", "phone": "+70003440922"}
0005434069236	947ECE	8851 354186	ALEKSANDRA KOZLOVA	{"email": "kozlova-aleksandra_091976@postgrespro.ru", "phone": "+70551492442"}
0005434069237	AE0C83	0114 447516	TATYANA NIKOLAEVA	{"phone": "+70775154143"}
0005434069238	CD8C9A	3174 200448	VLADISLAV SEMENOV	{"email": "semenovvladislav_29111977@postgrespro.ru", "phone": "+70059580670"}
0005434069239	CD8C9A	1736 489194	VLADIMIR VOROBEV	{"email": "vorobev.vladimir.1972@postgrespro.ru", "phone": "+70662173560"}
0005434069240	CD8C9A	6829 620176	FAINA KULIKOVA	{"phone": "+70838653926"}
0005434069241	BE5EC1	6355 390345	LYUDMILA NAUMOVA	{"email": "lyudmila.naumova.1970@postgrespro.ru", "phone": "+70397268697"}
0005434069242	E01249	2170 633155	MARINA MIRONOVA	{"email": "mironova.marina101979@postgrespro.ru", "phone": "+70315344771"}
0005434069243	FDBFBF	8925 346681	FAIL ISAEV	{"email": "failisaev_061978@postgrespro.ru", "phone": "+70713998743"}
0005434069244	69FD8A	3405 716359	TATYANA SEMENOVA	{"phone": "+70492558625"}
0005434069245	357BE8	1815 405372	MIKHAIL MATVEEV	{"phone": "+70230078052"}
0005434069246	357BE8	9622 472316	YULIYA SOKOLOVA	{"email": "sokolovayuliya16031982@postgrespro.ru", "phone": "+70549962456"}
0005434069247	453987	8292 653077	SERGEY CHERNOV	{"phone": "+70021894203"}
0005434069248	F067E3	1393 202541	LYUBOV ANDREEVA	{"email": "andreeva_l081963@postgrespro.ru", "phone": "+70594248094"}
0005434069249	F067E3	6264 537184	ANATOLIY NIKITIN	{"phone": "+70348792543"}
0005434069250	6F7EEA	1693 667271	VLADISLAV PAVLOV	{"email": "vpavlov-1967@postgrespro.ru", "phone": "+70894703574"}
0005434069251	A29B74	8434 907846	RASHID KUZNECOV	{"phone": "+70398479580"}
0005434069252	A29B74	9625 544896	ALBINA KOZLOVA	{"phone": "+70833498621"}
0005434069253	2C1643	9183 327838	ALEKSANDR ZHUKOV	{"email": "zhukov.aleksandr_30101973@postgrespro.ru", "phone": "+70055360335"}
0005434069254	2A57E4	4129 034016	SERGEY TIKHONOV	{"email": "sergeytikhonov011976@postgrespro.ru", "phone": "+70240014305"}
0005434069255	2A57E4	6641 350549	ALEKSANDR FILIPPOV	{"email": "filippov_aleksandr-011983@postgrespro.ru", "phone": "+70248524878"}
0005434069256	F3A8F8	7262 176485	NINA FROLOVA	{"email": "frolova.n_01101982@postgrespro.ru", "phone": "+70767019485"}
0005434069257	C97DDA	5463 502090	GENNADIY KUZMIN	{"email": "g.kuzmin1976@postgrespro.ru", "phone": "+70834597701"}
0005434069258	2279F3	2945 437537	GENNADIY MIKHAYLOV	{"email": "mikhaylov-gennadiy_18121965@postgrespro.ru", "phone": "+70719840156"}
0005434069259	A4C589	0248 850256	ANTON NIKOLAEV	{"email": "anton_nikolaev1968@postgrespro.ru", "phone": "+70190937257"}
0005434069260	A4C589	2893 663028	VALERIY FOMIN	{"email": "valeriy-fomin-27071961@postgrespro.ru", "phone": "+70893659475"}
0005434069261	26AF55	3627 114641	LIDIYA ZHUKOVA	{"email": "zhukoval051960@postgrespro.ru", "phone": "+70085090886"}
0005434069262	49E43E	4833 492193	NATALYA POLYAKOVA	{"phone": "+70206857115"}
0005434069263	E90743	6481 023874	NATALYA DENISOVA	{"phone": "+70681589580"}
0005434069264	E90743	1674 684539	PAVEL GRIGOREV	{"email": "pavel-grigorev_111974@postgrespro.ru", "phone": "+70348764138"}
0005434069265	28880E	9655 697541	VENERA PAVLOVA	{"email": "venera-pavlova.02061988@postgrespro.ru", "phone": "+70428255505"}
0005434069266	28880E	2323 912362	GENNADIY KAZAKOV	{"phone": "+70745631394"}
0005434069267	350021	5965 307504	VALERIY GRIGOREV	{"email": "grigorev-valeriy-02021975@postgrespro.ru", "phone": "+70239257395"}
0005434069268	5B9F74	1675 724907	ANTON ORLOV	{"email": "orlov-a-1987@postgrespro.ru", "phone": "+70203946118"}
0005434069269	13599D	9740 271609	TAMARA YUDINA	{"email": "yudina.t.1983@postgrespro.ru", "phone": "+70675092761"}
0005434069270	EC3776	7098 299199	ELIZAVETA IVANOVA	{"email": "eivanova-061973@postgrespro.ru", "phone": "+70683416493"}
0005434069271	268D2A	9547 502775	LYUBOV NIKITINA	{"phone": "+70683247847"}
0005434069272	268D2A	7963 423640	OLGA KONDRATEVA	{"phone": "+70139155213"}
0005434069273	CD59DC	8843 917441	EKATERINA TIKHONOVA	{"phone": "+70296709388"}
0005434069274	FADCA1	8953 878933	TATYANA CHERNOVA	{"email": "tatyana-chernova.1970@postgrespro.ru", "phone": "+70926497096"}
0005434069275	FADCA1	8296 831099	KLARA FROLOVA	{"phone": "+70397978727"}
0005434069276	FADCA1	2648 433861	EGOR MOISEEV	{"email": "moiseeve1957@postgrespro.ru", "phone": "+70199083726"}
0005434069277	FC96D1	1116 076412	RAISA AKIMOVA	{"phone": "+70355033950"}
0005434069278	22930D	3515 172847	OLGA GRISHINA	{"phone": "+70269068069"}
0005434069279	19B6C3	2410 630420	POLINA MELNIKOVA	{"phone": "+70733803637"}
0005434069280	19B6C3	2322 024669	ELENA AFANASEVA	{"phone": "+70117789096"}
0005434069281	2599B7	6050 453434	MARIYA KRASNOVA	{"email": "mariya.krasnova-16061980@postgrespro.ru", "phone": "+70289411085"}
0005434069282	7D091F	7847 557989	IVAN ROMANOV	{"email": "romanov_ivan111973@postgrespro.ru", "phone": "+70518016903"}
0005434069283	7D091F	3012 906328	OLEG KAZAKOV	{"email": "kazakov.o.14011987@postgrespro.ru", "phone": "+70306263357"}
0005434069284	7D091F	6406 056497	VLADIMIR BARANOV	{"email": "baranov-vladimir1979@postgrespro.ru", "phone": "+70375892903"}
0005434069285	8BB5AA	0949 532979	ANTON FOMIN	{"phone": "+70454685240"}
0005434069286	ABF305	3782 119476	NADEZHDA NIKOLAEVA	{"phone": "+70546553098"}
0005434069287	4E423A	0678 782339	ZOYA SIDOROVA	{"phone": "+70744186459"}
0005434069288	4E423A	2251 608044	YULIYA SMIRNOVA	{"phone": "+70518303108"}
0005434069289	7930D0	3391 626140	VALERIYA NIKITINA	{"phone": "+70246576376"}
0005434069290	A1696E	6071 898591	OLGA MARTYNOVA	{"phone": "+70835940420"}
0005434069291	002C5A	6562 947566	VALERIY ZAKHAROV	{"email": "zakharovvaleriy-23091971@postgrespro.ru", "phone": "+70728816909"}
0005434069292	BE1BE6	4170 495010	NATALYA ABRAMOVA	{"phone": "+70215709637"}
0005434069293	AEE356	6731 355309	VIKTORIYA KARPOVA	{"phone": "+70382567844"}
0005434069294	053A7F	6943 745918	PETR FEDOTOV	{"phone": "+70991748126"}
0005434069295	053A7F	5217 081725	ELENA KUZNECOVA	{"email": "ekuznecova.22111972@postgrespro.ru", "phone": "+70661405061"}
0005434069296	053A7F	7765 289108	OLGA BORISOVA	{"phone": "+70783577441"}
0005434069297	020557	2106 653316	VIKTOR TIMOFEEV	{"email": "timofeev_v.061971@postgrespro.ru", "phone": "+70319751223"}
0005434069298	020557	6777 620475	ALEKSANDR PAVLOV	{"email": "pavlov_a.081968@postgrespro.ru", "phone": "+70921434365"}
0005434069299	B7AD42	2755 211707	EVGENIY NIKITIN	{"phone": "+70589261275"}
0005434069300	C195B5	2833 990116	MARINA MALYSHEVA	{"phone": "+70447289289"}
0005434069301	0B026B	9636 516323	VYACHESLAV SCHERBAKOV	{"phone": "+70988596620"}
0005434069302	FEAB9D	4554 375938	VLADIMIR BELOV	{"email": "belov.v-091961@postgrespro.ru", "phone": "+70645527802"}
0005434069303	8139F7	0510 221734	DARYA MOROZOVA	{"email": "morozova.darya-081969@postgrespro.ru", "phone": "+70448757668"}
0005434069304	541838	6802 035696	ALEKSANDR ALEKSANDROV	{"phone": "+70252051340"}
0005434069305	8F60E7	9130 254797	VERA OSIPOVA	{"phone": "+70370336309"}
0005434069306	B736E0	2448 173945	ALEKSANDRA OVCHINNIKOVA	{"phone": "+70948939575"}
0005434069307	271A88	3411 229408	TATYANA GERASIMOVA	{"phone": "+70426325536"}
0005434069308	271A88	9894 397493	ARINA MOROZOVA	{"email": "morozovaa_041965@postgrespro.ru", "phone": "+70319862449"}
0005434069309	C92802	0349 260337	VLADIMIR IVANOV	{"email": "vivanov.1979@postgrespro.ru", "phone": "+70036575536"}
0005434069310	C92802	3415 997628	EKATERINA KOROLEVA	{"phone": "+70008148378"}
0005434069311	A1AA43	0855 421050	ALEKSANDR GUSEV	{"phone": "+70664717333"}
0005434069312	89865C	4071 768259	DANIIL VOLKOV	{"email": "volkov-d071966@postgrespro.ru", "phone": "+70524442819"}
0005434069313	D6FDB9	0153 324977	ZOYA SOKOLOVA	{"email": "zoya-sokolova.12081971@postgrespro.ru", "phone": "+70525672235"}
0005434069314	D6FDB9	9940 996102	KONSTANTIN NOVIKOV	{"phone": "+70586691112"}
0005434069315	9FE381	5268 229439	ANNA POPOVA	{"email": "anna.popova-29111969@postgrespro.ru", "phone": "+70922911141"}
0005434069316	D46806	2613 347745	NADEZHDA NIKOLAEVA	{"email": "nikolaevan041975@postgrespro.ru", "phone": "+70476563471"}
0005434069317	D46806	7440 700818	MARINA ILINA	{"email": "ilinamarina-1971@postgrespro.ru", "phone": "+70172560615"}
0005434069318	C112EA	6485 493842	YULIYA IVANOVA	{"phone": "+70238528998"}
0005434069319	C112EA	0349 324054	ELENA POTAPOVA	{"phone": "+70078229565"}
0005434069320	C112EA	0310 134247	LARISA BARANOVA	{"phone": "+70893717109"}
0005434069321	C112EA	6724 678422	NADEZHDA NIKOLAEVA	{"phone": "+70026596561"}
0005434069322	D657F9	4044 023864	LYUDMILA EFIMOVA	{"phone": "+70866032607"}
0005434069323	D657F9	1422 914832	SVETLANA KOVALEVA	{"email": "svetlana-kovaleva1962@postgrespro.ru", "phone": "+70471692990"}
0005434069324	7F6CBF	4092 370564	VENERA ZAKHAROVA	{"phone": "+70290853322"}
0005434069325	AABBCB	2202 290554	NATALYA SMIRNOVA	{"email": "n-smirnova_22061971@postgrespro.ru", "phone": "+70129111413"}
0005434069326	AABBCB	4846 216666	ALEKSEY ALEKSANDROV	{"email": "a_aleksandrov.24071983@postgrespro.ru", "phone": "+70847771561"}
0005434069327	180064	4392 412550	OLGA NAUMOVA	{"phone": "+70350870818"}
0005434069328	4FAB98	7696 790226	LILIYA POPOVA	{"email": "liliyapopova-1972@postgrespro.ru", "phone": "+70011971843"}
0005434069329	83249D	6084 003292	OLGA YAKOVLEVA	{"email": "yakovleva_olga.011970@postgrespro.ru", "phone": "+70339022270"}
0005434069330	DECE18	7492 280871	NIKOLAY IVANOV	{"phone": "+70638704240"}
0005434069331	E1E17B	6971 231014	ANNA EGOROVA	{"email": "annaegorova_1962@postgrespro.ru", "phone": "+70719076098"}
0005434069332	137ACC	1990 040264	ALEKSANDR OSIPOV	{"email": "aosipov021975@postgrespro.ru", "phone": "+70380328357"}
0005434069333	599CE3	8943 858332	KSENIYA IVANOVA	{"phone": "+70168946783"}
0005434069334	0597B1	8491 555537	VLADIMIR KUZNECOV	{"email": "kuznecov.v29081972@postgrespro.ru", "phone": "+70144960740"}
0005434069335	0597B1	0417 948731	IGOR PETROV	{"phone": "+70053016197"}
0005434069336	5D6CFC	3512 316492	SVETLANA BARANOVA	{"phone": "+70826506083"}
0005434069337	1CA5C2	7129 055232	IRINA POLYAKOVA	{"email": "irinapolyakova.06061968@postgrespro.ru", "phone": "+70945843668"}
0005434069338	5AAA9F	4428 045453	ARTEM BARANOV	{"email": "baranov.a-05011963@postgrespro.ru", "phone": "+70005673208"}
0005434069339	5AAA9F	1509 210648	NATALYA MELNIKOVA	{"email": "natalya_melnikova_09081980@postgrespro.ru", "phone": "+70497491624"}
0005434069340	CE60D1	1624 329401	NIKOLAY MIKHAYLOV	{"email": "mikhaylovnikolay_081983@postgrespro.ru", "phone": "+70886529479"}
0005434069341	0AD84E	3398 597888	VADIM MIKHAYLOV	{"phone": "+70446238232"}
0005434069342	7451F7	8475 725973	ELENA MIRONOVA	{"email": "emironova_13061961@postgrespro.ru", "phone": "+70925929819"}
0005434069343	7451F7	1872 773967	PETR OSIPOV	{"phone": "+70899023558"}
0005434069344	A5AEE5	1393 482651	YURIY KONOVALOV	{"phone": "+70997946419"}
0005434069345	636A6D	3782 999560	TATYANA VOLKOVA	{"email": "tvolkova_071963@postgrespro.ru", "phone": "+70058654599"}
0005434069346	3C6C14	9051 625421	EVGENIY KOZLOV	{"email": "evgeniy.kozlov.021975@postgrespro.ru", "phone": "+70801958596"}
0005434069347	3C6C14	8767 582320	GALINA KOMAROVA	{"phone": "+70206989930"}
0005434069348	AAA5E7	8338 014255	ALEKSANDR ZAKHAROV	{"email": "a_zakharov.041975@postgrespro.ru", "phone": "+70424612932"}
0005434069349	AAA5E7	1984 050509	ZINAIDA SIDOROVA	{"email": "z-sidorova-041972@postgrespro.ru", "phone": "+70035962291"}
0005434069350	A05807	6554 673403	VIKTORIYA MIKHAYLOVA	{"email": "mikhaylovav1985@postgrespro.ru", "phone": "+70660430432"}
0005434069351	A05807	7485 873573	ELENA TIMOFEEVA	{"email": "e-timofeeva.01091974@postgrespro.ru", "phone": "+70679238333"}
0005434069352	2544D9	5684 876327	VALERIY ZAYCEV	{"phone": "+70220385517"}
0005434069353	3F16A5	2624 461504	IVAN GUSEV	{"phone": "+70343077946"}
0005434069354	B03744	7812 992268	ZINAIDA KOMAROVA	{"phone": "+70097121391"}
0005434069355	5833DF	5634 053483	ALEKSEY ZAYCEV	{"phone": "+70489488221"}
0005434069356	5833DF	0173 715604	OLGA KUZMINA	{"phone": "+70452048066"}
0005434069357	FF2444	0058 594363	IGOR MAKSIMOV	{"email": "i-maksimov.091964@postgrespro.ru", "phone": "+70814167338"}
0005434069358	ACBE5F	4338 422320	IRINA NAUMOVA	{"email": "irina_naumova_28031974@postgrespro.ru", "phone": "+70249275278"}
0005434069359	69ECA3	1134 020996	YURIY KUZMIN	{"email": "yuriy-kuzmin.011979@postgrespro.ru", "phone": "+70012761106"}
0005434069360	69ECA3	7548 955111	EKATERINA EGOROVA	{"phone": "+70527474495"}
0005434069361	69ECA3	6299 357788	ANNA ALEKSANDROVA	{"phone": "+70631974645"}
0005434069362	A117AC	0643 420084	MIKHAIL DMITRIEV	{"email": "m.dmitriev.1969@postgrespro.ru", "phone": "+70809625308"}
0005434069363	2D14A8	2923 969098	SERGEY SAVELEV	{"email": "ssavelev_051978@postgrespro.ru", "phone": "+70923498438"}
0005434069364	52C5A9	4125 183684	VLADIMIR POPOV	{"phone": "+70951382018"}
0005434069365	224D38	3909 580446	ELIZAVETA LOGINOVA	{"phone": "+70280970675"}
0005434069366	224D38	8217 970973	MAKSIM KULIKOV	{"email": "kulikov-m.1976@postgrespro.ru", "phone": "+70631081578"}
0005434069367	0FC32C	0591 583627	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov_051976@postgrespro.ru", "phone": "+70480190713"}
0005434069368	3655C1	6329 030462	ELENA STEPANOVA	{"phone": "+70247196791"}
0005434069369	3655C1	0964 635197	OLGA ANTONOVA	{"phone": "+70814631850"}
0005434069370	3655C1	9526 055283	ANATOLIY MIKHAYLOV	{"phone": "+70288600689"}
0005434069371	CA42C9	4587 551624	GALINA GORBUNOVA	{"email": "galina_gorbunova061975@postgrespro.ru", "phone": "+70062746242"}
0005434069372	1CFCEC	7841 657361	OLGA OSIPOVA	{"email": "olgaosipova.011980@postgrespro.ru", "phone": "+70863899042"}
0005434069373	1CFCEC	2300 073244	NADEZHDA KUZNECOVA	{"phone": "+70615063227"}
0005434069374	1CFCEC	0318 942499	LIDIYA NESTEROVA	{"email": "nesterova.lidiya1959@postgrespro.ru", "phone": "+70464816749"}
0005434069375	04C26B	4239 711001	TATYANA IVANOVA	{"email": "ivanovat_17061972@postgrespro.ru", "phone": "+70751296481"}
0005434069376	66D7D0	5633 266419	VALENTINA EFIMOVA	{"email": "valentinaefimova15101973@postgrespro.ru", "phone": "+70232300725"}
0005434069377	66D7D0	9153 671708	VLADIMIR GERASIMOV	{"email": "gerasimov_v1971@postgrespro.ru", "phone": "+70921885134"}
0005434069378	66D7D0	4280 881961	KONSTANTIN SIDOROV	{"email": "sidorov_konstantin_1964@postgrespro.ru", "phone": "+70193140624"}
0005434069379	425355	5891 646486	ELENA POPOVA	{"email": "elena_popova1973@postgrespro.ru", "phone": "+70527888971"}
0005434069380	26BCD8	5927 534193	ALEKSANDR GUSEV	{"phone": "+70100956258"}
0005434069381	552430	5689 971087	MARINA ROMANOVA	{"email": "marina_romanova_25111963@postgrespro.ru", "phone": "+70056810003"}
0005434069382	C3210A	1610 280362	ARTEM KONOVALOV	{"email": "artem_konovalov-011973@postgrespro.ru", "phone": "+70008234384"}
0005434069383	C3210A	0242 969877	ANATOLIY TIKHONOV	{"phone": "+70404528107"}
0005434069384	601C47	6157 487123	LEONID FILIPPOV	{"phone": "+70626968472"}
0005434069385	000EA2	5269 321462	ALEKSEY MAKSIMOV	{"phone": "+70641512674"}
0005434069386	28F068	3977 762696	SERGEY YAKOVLEV	{"email": "yakovlev-sergey1967@postgrespro.ru", "phone": "+70338960517"}
0005434069387	0FA805	5832 114601	SERGEY NOVIKOV	{"email": "snovikov_1969@postgrespro.ru", "phone": "+70346063047"}
0005434069388	8F6845	6661 045468	ALEKSANDR POPOV	{"email": "popov.a-15101974@postgrespro.ru", "phone": "+70826564731"}
0005434069389	7C6CC9	7944 187815	SVETLANA GUSEVA	{"phone": "+70101530691"}
0005434069390	7C6CC9	7572 978587	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy.1967@postgrespro.ru", "phone": "+70052282733"}
0005434069391	7C6CC9	9594 163665	SERGEY NAZAROV	{"phone": "+70812837546"}
0005434069392	F5BECF	4001 580393	LARISA VASILEVA	{"phone": "+70751324308"}
0005434069393	F5BECF	8781 495606	SVETLANA SMIRNOVA	{"phone": "+70817870400"}
0005434069394	47950A	0433 993598	SERGEY PETROV	{"phone": "+70007933221"}
0005434069395	FF6A96	5006 560932	NATALYA KISELEVA	{"phone": "+70165315709"}
0005434069396	FF6A96	6614 079232	OLGA VASILEVA	{"phone": "+70206777237"}
0005434069397	F60245	0962 165106	LARISA GERASIMOVA	{"phone": "+70122298989"}
0005434069398	98997D	7907 230783	ANNA ALEKSANDROVA	{"email": "aleksandrovaanna-021970@postgrespro.ru", "phone": "+70736908062"}
0005434069399	36E76E	1017 878838	TATYANA FEDOROVA	{"phone": "+70634870686"}
0005434069400	36E76E	6473 530508	VIKTOR ISAEV	{"phone": "+70167414711"}
0005434069401	67483D	4145 655231	ALEKSEY SOKOLOV	{"email": "aleksey-sokolov-18011975@postgrespro.ru", "phone": "+70215998144"}
0005434069402	2FDC72	1456 345784	ALENA MIKHAYLOVA	{"email": "alenamikhaylova.13081969@postgrespro.ru", "phone": "+70180951191"}
0005434069403	234FA0	9903 148621	EVGENIY FILIPPOV	{"email": "evgeniy-filippov.21011975@postgrespro.ru", "phone": "+70199608661"}
0005434069404	629941	8313 852750	IRINA DAVYDOVA	{"email": "i_davydova16061975@postgrespro.ru", "phone": "+70588228088"}
0005434069405	D4A786	6657 370165	MARINA YAKOVLEVA	{"phone": "+70203151389"}
0005434069406	D76203	6265 023137	OLESYA AFANASEVA	{"email": "olesyaafanaseva.121979@postgrespro.ru", "phone": "+70521447749"}
0005434069407	429340	5377 329462	NATALYA LEBEDEVA	{"email": "natalya-lebedeva101968@postgrespro.ru", "phone": "+70810617379"}
0005434069408	EA88E3	8667 394100	NATALIYA ZAKHAROVA	{"phone": "+70577838106"}
0005434069409	B36F74	6168 098936	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev.30091972@postgrespro.ru", "phone": "+70600558703"}
0005434069410	2B937D	6640 978429	OLGA SAVELEVA	{"email": "savelevaolga_031980@postgrespro.ru", "phone": "+70556789019"}
0005434069411	AF8803	8533 993838	MAKSIM EGOROV	{"email": "egorov.m.13041970@postgrespro.ru", "phone": "+70379623694"}
0005434069412	AF8803	3778 425264	NINA BORISOVA	{"email": "nina-borisova.1976@postgrespro.ru", "phone": "+70760003560"}
0005434069413	D162DE	8285 728715	ALEKSANDR ZAKHAROV	{"email": "azakharov.1974@postgrespro.ru", "phone": "+70668119324"}
0005434069414	CDADC7	4412 343205	VALENTINA TITOVA	{"email": "titova-v_1961@postgrespro.ru", "phone": "+70361219689"}
0005434069415	CDADC7	6133 467611	VITALIY EGOROV	{"phone": "+70638922100"}
0005434069416	F79D5B	2178 601049	MARINA KUZNECOVA	{"email": "m-kuznecova_1968@postgrespro.ru", "phone": "+70233824723"}
0005434069417	F79D5B	5742 332389	VALENTINA FROLOVA	{"email": "v-frolova.081971@postgrespro.ru", "phone": "+70522742177"}
0005434069418	5ACD41	8569 739763	OLEG MELNIKOV	{"phone": "+70525713981"}
0005434069419	F508FC	1558 845380	ALEKSEY FROLOV	{"phone": "+70574297222"}
0005434069420	2E5373	7477 505838	NINA MOROZOVA	{"email": "morozovan_22031971@postgrespro.ru", "phone": "+70368988159"}
0005434069421	2E5373	4105 869803	ALEKSEY IVANOV	{"phone": "+70053418604"}
0005434069422	620144	1423 366371	NINA NIKITINA	{"email": "nikitina-n1967@postgrespro.ru", "phone": "+70638534836"}
0005434069423	620144	4196 232411	IRINA KISELEVA	{"phone": "+70896399224"}
0005434069424	620144	2165 965743	VALENTINA MOROZOVA	{"phone": "+70280167614"}
0005434069425	EA5EF6	6479 324372	VERA NAUMOVA	{"phone": "+70120200349"}
0005434069426	EA5EF6	4901 060100	MARINA PAVLOVA	{"phone": "+70642143559"}
0005434069427	44E926	0967 678635	DMITRIY ALEKSANDROV	{"email": "aleksandrov.d.26051975@postgrespro.ru", "phone": "+70469127256"}
0005434069428	7D0005	3848 063045	NATALYA MOISEEVA	{"email": "nmoiseeva091966@postgrespro.ru", "phone": "+70789098289"}
0005434069429	7D0005	8082 289835	GALINA MAKAROVA	{"phone": "+70190762741"}
0005434069430	77ED07	6783 605194	NIKOLAY EGOROV	{"phone": "+70548088813"}
0005434069431	51C176	1608 183939	VASILIY BELOV	{"phone": "+70735087323"}
0005434069432	51C176	5205 524072	ANATOLIY GRIGOREV	{"phone": "+70762036847"}
0005434069433	A4FB25	1772 964949	MAKSIM ROMANOV	{"email": "maksim.romanov_1977@postgrespro.ru", "phone": "+70370251335"}
0005434069434	86B0D3	1519 158740	ELENA POTAPOVA	{"email": "e-potapova1979@postgrespro.ru", "phone": "+70464303203"}
0005434069435	86B0D3	8298 228875	EKATERINA SEMENOVA	{"email": "semenovae-1976@postgrespro.ru", "phone": "+70058558864"}
0005434069436	24A29C	9883 285298	ELENA SIDOROVA	{"email": "sidorova_e111971@postgrespro.ru", "phone": "+70133443234"}
0005434069437	8A5DE6	1028 663582	LYUBOV RODIONOVA	{"phone": "+70834142327"}
0005434069438	825159	9664 291988	VIKTORIYA FOMINA	{"email": "v_fomina-03101988@postgrespro.ru", "phone": "+70277030591"}
0005434069439	4D3809	9342 978865	OLGA BOGDANOVA	{"phone": "+70947428332"}
0005434069440	DDB9A5	4193 222336	ZINAIDA MOISEEVA	{"email": "z_moiseeva.23111968@postgrespro.ru", "phone": "+70886062796"}
0005434069441	DDB9A5	6356 661477	LYUDMILA ROMANOVA	{"email": "romanova-lyudmila.01041982@postgrespro.ru", "phone": "+70917242837"}
0005434069442	54186B	0092 934704	MARINA KOZLOVA	{"phone": "+70057508278"}
0005434069443	54186B	0095 265857	ALEKSANDR MOROZOV	{"phone": "+70201377956"}
0005434069444	D729F0	6128 913915	MARINA ZAKHAROVA	{"phone": "+70079455202"}
0005434069445	77CE62	1199 072095	LYUBOV KISELEVA	{"email": "lyubovkiseleva-1960@postgrespro.ru", "phone": "+70064042395"}
0005434069446	99F38C	1830 073943	ILMIRA PAVLOVA	{"email": "pavlova_i-101971@postgrespro.ru", "phone": "+70224262539"}
0005434069447	99F38C	9121 678067	SERGEY VASILEV	{"phone": "+70339411069"}
0005434069448	AFC542	6939 278715	TAMARA NIKITINA	{"email": "t_nikitina-091972@postgrespro.ru", "phone": "+70423259246"}
0005434069449	E0F467	3081 708885	ELENA MIRONOVA	{"email": "mironovaelena06021967@postgrespro.ru", "phone": "+70868357325"}
0005434069450	C92230	2968 544570	OKSANA IVANOVA	{"email": "oksanaivanova-1983@postgrespro.ru", "phone": "+70856724080"}
0005434069451	C92230	6726 704603	SERGEY IVANOV	{"email": "sergey_ivanov.081965@postgrespro.ru", "phone": "+70521154702"}
0005434069452	EE8B55	6594 402580	NIKITA BONDARENKO	{"email": "bondarenkon_06041964@postgrespro.ru", "phone": "+70455043381"}
0005434069453	0EAE12	8529 550063	IGOR ANDREEV	{"email": "andreev.igor-1973@postgrespro.ru", "phone": "+70878504822"}
0005434069454	450210	0944 903000	ALEKSANDR GUSEV	{"email": "a_gusev_25061972@postgrespro.ru", "phone": "+70063036445"}
0005434069455	450210	4174 038981	DARYA SERGEEVA	{"phone": "+70093686375"}
0005434069456	7A2A94	5433 594934	GALINA MELNIKOVA	{"email": "melnikova_g1969@postgrespro.ru", "phone": "+70313445016"}
0005434069457	7A2A94	6187 388623	SVETLANA NESTEROVA	{"email": "s_nesterova.1977@postgrespro.ru", "phone": "+70133980633"}
0005434069458	9F7178	0823 877185	YURIY ANDREEV	{"email": "andreev-y_1955@postgrespro.ru", "phone": "+70337927225"}
0005434069459	E79CBB	7551 891959	MARGARITA KOROLEVA	{"phone": "+70272436302"}
0005434069460	E79CBB	9578 414794	NADEZHDA PAVLOVA	{"email": "n_pavlova.03101973@postgrespro.ru", "phone": "+70644692275"}
0005434069461	CE71D2	7477 922915	VIKTORIYA BELYAEVA	{"email": "belyaeva-v-1967@postgrespro.ru", "phone": "+70838832807"}
0005434069462	CE1A06	0474 116351	BORIS FROLOV	{"email": "frolovboris021976@postgrespro.ru", "phone": "+70170583384"}
0005434069463	7D2E58	5293 061030	ELENA SOKOLOVA	{"phone": "+70066421958"}
0005434069464	7147B6	1538 577174	SERGEY ISAEV	{"email": "isaevs1968@postgrespro.ru", "phone": "+70870639412"}
0005434069465	2F30F4	8240 885408	VIKTOR SCHERBAKOV	{"email": "scherbakov.v_17061962@postgrespro.ru", "phone": "+70703158119"}
0005434069466	EC9B88	5628 632104	VIKTORIYA ANTONOVA	{"email": "antonova-v-081977@postgrespro.ru", "phone": "+70470824550"}
0005434069467	836A4E	7517 759017	ALEKSANDR DENISOV	{"phone": "+70936903922"}
0005434069468	836A4E	8346 856275	SERGEY MEDVEDEV	{"phone": "+70544139906"}
0005434069469	97E33E	3852 769602	ALEKSANDR IVANOV	{"phone": "+70366237153"}
0005434069470	97E33E	7209 688164	VIKTOR TIMOFEEV	{"email": "v-timofeev_041965@postgrespro.ru", "phone": "+70934558904"}
0005434069471	6C5128	5611 201902	ANATOLIY GRIGOREV	{"email": "grigorev-a1987@postgrespro.ru", "phone": "+70497220597"}
0005434069472	09218A	5278 126078	LIDIYA OVCHINNIKOVA	{"phone": "+70402529118"}
0005434069473	D44E25	0893 846017	ZHANNA BORISOVA	{"phone": "+70619346511"}
0005434069474	D44E25	8479 533957	IVAN KUZNECOV	{"email": "kuznecov-ivan.26101969@postgrespro.ru", "phone": "+70196721716"}
0005434069475	8954CA	8886 111600	TATYANA MOROZOVA	{"email": "t_morozova.071983@postgrespro.ru", "phone": "+70865898341"}
0005434069476	617D78	5923 767009	NIKOLAY POPOV	{"phone": "+70918497779"}
0005434069477	617D78	6356 045664	ELENA FEDOROVA	{"email": "fedorova.elena.081975@postgrespro.ru", "phone": "+70609425827"}
0005434069478	8DD305	0244 311989	VLADIMIR ALEKSEEV	{"phone": "+70327713973"}
0005434069479	7A71D6	1640 946966	ANNA IVANOVA	{"email": "ivanova_anna-111971@postgrespro.ru", "phone": "+70656175489"}
0005434069480	0B5356	9348 277438	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov.081979@postgrespro.ru", "phone": "+70520941472"}
0005434069481	196EA5	5926 310440	LIDIYA IVANOVA	{"email": "ivanovalidiya-021965@postgrespro.ru", "phone": "+70149696263"}
0005434069482	F672DD	3788 789768	MIKHAIL RODIONOV	{"email": "rodionov.m061965@postgrespro.ru", "phone": "+70933761096"}
0005434069483	82BA4F	4395 617951	VALENTINA SAVELEVA	{"email": "savelevav081968@postgrespro.ru", "phone": "+70506576506"}
0005434069484	82BA4F	2344 891901	OLEG GAVRILOV	{"phone": "+70471902551"}
0005434069485	32AEF3	8608 401159	EVGENIYA POLYAKOVA	{"email": "polyakovae_061978@postgrespro.ru", "phone": "+70053817286"}
0005434069486	0C838D	4823 168552	ILYA NIKITIN	{"email": "i_nikitin.29061972@postgrespro.ru", "phone": "+70471690519"}
0005434069487	39254B	6704 868952	EVGENIY GORBUNOV	{"phone": "+70005953422"}
0005434069488	39254B	8740 385800	MARAT TIMOFEEV	{"email": "timofeev.m_1976@postgrespro.ru", "phone": "+70657371131"}
0005434069489	85FC86	7701 109255	IGOR BORISOV	{"email": "borisov-i-02021967@postgrespro.ru", "phone": "+70225580892"}
0005434069490	417B19	5694 026987	ANASTASIYA NESTEROVA	{"phone": "+70082809882"}
0005434069491	417B19	0783 100067	YURIY NIKOLAEV	{"email": "ynikolaev_091962@postgrespro.ru", "phone": "+70431487737"}
0005434069492	B4040D	6389 298817	ANDREY ZHUKOV	{"phone": "+70949564065"}
0005434069493	C7AF0C	5488 143366	ANATOLIY ANTONOV	{"email": "anatoliy_antonov081964@postgrespro.ru", "phone": "+70418263113"}
0005434069494	02AD8E	1751 133734	PAVEL NIKOLAEV	{"phone": "+70478878892"}
0005434069495	6C065F	7673 434631	ELENA KONOVALOVA	{"email": "ekonovalova-02091969@postgrespro.ru", "phone": "+70797500069"}
0005434069496	6C065F	4320 787700	ALEKSEY ANTONOV	{"phone": "+70245173333"}
0005434069497	BFAB9E	4767 594203	MAKSIM DMITRIEV	{"phone": "+70166458747"}
0005434069498	9B57B0	6639 433761	GALINA NIKOLAEVA	{"email": "galina-nikolaeva031975@postgrespro.ru", "phone": "+70468056767"}
0005434069499	413F4A	5089 423819	IVAN GAVRILOV	{"email": "gavrilov.ivan_1981@postgrespro.ru", "phone": "+70726009789"}
0005434069500	21C1F4	3999 203947	ANATOLIY IVANOV	{"email": "anatoliyivanov-03091973@postgrespro.ru", "phone": "+70660529049"}
0005434069501	21C1F4	5660 740305	GALINA LUKYANOVA	{"phone": "+70781344647"}
0005434069502	553A05	3010 989149	NIKOLAY POPOV	{"phone": "+70025219502"}
0005434069503	553A05	9819 930211	ELVIRA DAVYDOVA	{"phone": "+70169811214"}
0005434069504	A9623B	6333 161453	EVGENIY PETROV	{"email": "petrov_e1981@postgrespro.ru", "phone": "+70121052950"}
0005434069505	E235D3	2311 386337	ALEKSANDR ISAEV	{"phone": "+70903484220"}
0005434069506	612AAB	3046 450767	LYUDMILA ANDREEVA	{"phone": "+70555599517"}
0005434069507	9E1D8A	5620 672790	NIKOLAY SCHERBAKOV	{"email": "n-scherbakov_061964@postgrespro.ru", "phone": "+70422771190"}
0005434069508	9E1D8A	8011 018511	DENIS GRIGOREV	{"phone": "+70257080182"}
0005434069509	C19CBF	4053 862652	DAMIR ANDREEV	{"phone": "+70808845312"}
0005434069510	33DA79	1071 821450	YURIY SOROKIN	{"email": "sorokinyuriy.01041978@postgrespro.ru", "phone": "+70420887525"}
0005434069511	ACAB0D	0853 518177	ALEKSANDR SEMENOV	{"phone": "+70802783322"}
0005434069512	51B792	6061 500843	ANTONINA NESTEROVA	{"email": "nesterova_antonina-121969@postgrespro.ru", "phone": "+70519062342"}
0005434069513	45D708	0630 677396	LARISA GAVRILOVA	{"phone": "+70143491421"}
0005434069514	8C4809	3160 070079	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.24121975@postgrespro.ru", "phone": "+70867290016"}
0005434069515	846E1F	2716 073875	SVETLANA MAKSIMOVA	{"phone": "+70760579296"}
0005434069516	B3E196	3718 451211	NIKOLAY PETROV	{"phone": "+70904793525"}
0005434069517	B3E196	9730 930708	SVETLANA VOROBEVA	{"phone": "+70071825739"}
0005434069518	312540	9438 220536	EDUARD PETROV	{"email": "petrov-e.1973@postgrespro.ru", "phone": "+70948337963"}
0005434069519	CEC491	5488 453939	ANATOLIY GRIGOREV	{"email": "grigorev-a021971@postgrespro.ru", "phone": "+70337566864"}
0005434069520	CEC491	8760 458582	IVAN SOLOVEV	{"email": "solovev_i071974@postgrespro.ru", "phone": "+70513654352"}
0005434069521	212547	0668 130546	NATALYA MATVEEVA	{"phone": "+70581431822"}
0005434069522	212547	9427 208029	ALINA IVANOVA	{"email": "ivanova.a-08081971@postgrespro.ru", "phone": "+70570435802"}
0005434069523	6EA485	4738 792058	SERGEY NOVIKOV	{"phone": "+70446723123"}
0005434069524	6EA485	5701 343605	SERGEY SOROKIN	{"email": "sergey.sorokin051968@postgrespro.ru", "phone": "+70223595606"}
0005434069525	D73769	9773 909644	SERGEY FILIPPOV	{"phone": "+70032334486"}
0005434069526	F43CBD	5182 819098	MAGOMED SHEVCHENKO	{"phone": "+70197866702"}
0005434069527	F43CBD	3062 025814	ANDREY TARASOV	{"phone": "+70481369212"}
0005434069528	C7322A	0774 405756	VERA ZAKHAROVA	{"email": "vzakharova_091969@postgrespro.ru", "phone": "+70423256105"}
0005434069529	494E70	8892 358508	DENIS VASILEV	{"email": "dvasilev_1976@postgrespro.ru", "phone": "+70362729834"}
0005434069530	6F9858	6324 817512	ALEKSEY KRASNOV	{"email": "alekseykrasnov-111972@postgrespro.ru", "phone": "+70741504712"}
0005434069531	B88576	7107 541233	PETR DENISOV	{"email": "p-denisov_24081978@postgrespro.ru", "phone": "+70655128900"}
0005434069532	E83AD0	0781 348501	EKATERINA POPOVA	{"phone": "+70712298267"}
0005434069533	688087	8589 559799	VADIM SMIRNOV	{"phone": "+70755529155"}
0005434069534	1078E6	5670 808346	DILYARA SMIRNOVA	{"phone": "+70085840640"}
0005434069535	1078E6	4340 168872	VYACHESLAV BARANOV	{"email": "baranov-vyacheslav-1970@postgrespro.ru", "phone": "+70123748001"}
0005434069536	118618	0024 506160	YURIY DENISOV	{"phone": "+70690689755"}
0005434069537	118618	8516 090241	ALEKSANDR ANTONOV	{"phone": "+70922724947"}
0005434069538	F9B2D2	6255 495068	OLGA TIMOFEEVA	{"phone": "+70100041263"}
0005434069539	C2EA1A	3081 267600	VLADIMIR EGOROV	{"email": "egorovvladimir-1976@postgrespro.ru", "phone": "+70037459373"}
0005434069540	C2EA1A	2716 736675	LIDIYA ERMAKOVA	{"email": "lidiya-ermakova.061984@postgrespro.ru", "phone": "+70328116582"}
0005434069541	73D775	8494 549292	TAISIYA ANISIMOVA	{"email": "tanisimova.1957@postgrespro.ru", "phone": "+70241225778"}
0005434069542	73D775	1783 018392	MARAT MIRONOV	{"phone": "+70743847402"}
0005434069543	E0DAC7	8569 735749	MIKHAIL SOKOLOV	{"email": "m_sokolov.22061972@postgrespro.ru", "phone": "+70295736253"}
0005434069544	A12EDA	0234 792434	NADEZHDA IVANOVA	{"email": "n_ivanova.18121974@postgrespro.ru", "phone": "+70074577016"}
0005434069545	B20060	4086 356349	TATYANA EGOROVA	{"email": "egorova-tatyana11121971@postgrespro.ru", "phone": "+70492859544"}
0005434069546	02ACEF	3449 443519	SVETLANA MAKSIMOVA	{"email": "maksimova_svetlana-05041980@postgrespro.ru", "phone": "+70872216040"}
0005434069547	02ACEF	6687 991634	GALINA STEPANOVA	{"phone": "+70139541954"}
0005434069548	9ECDA4	5825 831903	ALSU PETROVA	{"phone": "+70395215040"}
0005434069549	9ECDA4	9122 326316	ANDREY NOVIKOV	{"email": "novikov_andrey.1984@postgrespro.ru", "phone": "+70663650089"}
0005434069550	9ECDA4	1031 021049	IGOR ORLOV	{"phone": "+70548941069"}
0005434069551	2ED641	9734 973218	OLGA GUSEVA	{"email": "o-guseva.23081963@postgrespro.ru", "phone": "+70426887626"}
0005434069552	2ED641	8240 669410	DMITRIY SOROKIN	{"email": "dsorokin.11031978@postgrespro.ru", "phone": "+70571368499"}
0005434069553	81E01B	6391 725502	LYUBOV KUZNECOVA	{"email": "kuznecovalyubov-1968@postgrespro.ru", "phone": "+70757863520"}
0005434069554	2D04C1	0140 179141	OLGA SAVELEVA	{"email": "saveleva_olga.121967@postgrespro.ru", "phone": "+70496460822"}
0005434069555	908A69	3719 514520	ELENA BORISOVA	{"email": "borisova_elena121973@postgrespro.ru", "phone": "+70465517560"}
0005434069556	908A69	0423 676696	NATALYA GRISHINA	{"email": "n.grishina-101969@postgrespro.ru", "phone": "+70665564595"}
0005434069557	92F377	7534 933539	LINAR FROLOV	{"phone": "+70106493509"}
0005434069558	515453	4227 225622	ANDREY TARASOV	{"phone": "+70541427259"}
0005434069559	515453	4350 147364	OLGA VASILEVA	{"email": "olgavasileva_20111976@postgrespro.ru", "phone": "+70024115160"}
0005434069560	4FCEB1	5349 243617	ANDREY KULIKOV	{"phone": "+70353987645"}
0005434069561	4FCEB1	6645 909340	YULIYA SEMENOVA	{"phone": "+70036948203"}
0005434069562	BEF0D3	3363 441704	ALEKSANDR SOLOVEV	{"phone": "+70364408750"}
0005434069563	3D2D86	4302 545820	NATALYA GERASIMOVA	{"phone": "+70206065623"}
0005434069564	DF3DBF	0875 913859	VIKTOR NAUMOV	{"email": "naumovv-1972@postgrespro.ru", "phone": "+70562347347"}
0005434069565	35978E	5604 974121	ALEKSEY MARTYNOV	{"email": "aleksey_martynov1986@postgrespro.ru", "phone": "+70341495219"}
0005434069566	35978E	6574 959274	SEMEN SHEVCHENKO	{"email": "semen.shevchenko-1987@postgrespro.ru", "phone": "+70031601551"}
0005434069567	880073	8654 863466	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a101973@postgrespro.ru", "phone": "+70658989175"}
0005434069568	880073	0086 236460	GALINA ZAKHAROVA	{"email": "g.zakharova-1983@postgrespro.ru", "phone": "+70576669195"}
0005434069569	32EED9	6415 031808	ANASTASIYA MOROZOVA	{"email": "morozovaa11041973@postgrespro.ru", "phone": "+70160652404"}
0005434069570	32EED9	9652 455646	ANATOLIY MAKSIMOV	{"phone": "+70449756052"}
0005434069571	AD0BF6	2505 312529	ALEKSANDR KUZNECOV	{"email": "kuznecova-121970@postgrespro.ru", "phone": "+70092994921"}
0005434069572	3DD523	9655 551240	VITALIY SERGEEV	{"email": "vitaliy.sergeev30041971@postgrespro.ru", "phone": "+70258235852"}
0005434069573	7B2F81	4717 031940	SVETLANA GRISHINA	{"email": "svetlanagrishina.101980@postgrespro.ru", "phone": "+70329410533"}
0005434069574	7B2F81	8578 194645	IRINA MATVEEVA	{"email": "matveeva_irina11121979@postgrespro.ru", "phone": "+70926439940"}
0005434069575	7B2F81	8686 254126	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova_23101964@postgrespro.ru", "phone": "+70314355981"}
0005434069576	D93737	6035 503793	OLGA KUZNECOVA	{"email": "kuznecovao_01121975@postgrespro.ru", "phone": "+70647474343"}
0005434069577	68E5B7	2462 327264	ALINA CHERNOVA	{"email": "chernovaa1959@postgrespro.ru", "phone": "+70505175282"}
0005434069578	B97F68	4511 979918	NIKOLAY KONOVALOV	{"phone": "+70106009164"}
0005434069579	CCB8F5	9170 195624	OLESYA MOISEEVA	{"email": "o.moiseeva081976@postgrespro.ru", "phone": "+70948059171"}
0005434069580	7034BA	5147 190076	ALEKSANDR VASILEV	{"phone": "+70598192149"}
0005434069581	571CB7	6120 558125	LARISA ISAEVA	{"email": "l_isaeva-071975@postgrespro.ru", "phone": "+70546066410"}
0005434069582	F92E6C	1274 066273	ELENA IVANOVA	{"email": "e-ivanova.29061985@postgrespro.ru", "phone": "+70427345579"}
0005434069583	F92E6C	1195 827081	IVAN SERGEEV	{"phone": "+70110240973"}
0005434069584	435A0A	7245 788155	IGOR PAVLOV	{"email": "pavlovigor1964@postgrespro.ru", "phone": "+70817215666"}
0005434069585	435A0A	5213 176072	SVETLANA ANTONOVA	{"phone": "+70678612045"}
0005434069586	4044A9	4632 729426	RAISA POTAPOVA	{"email": "r-potapova.25011967@postgrespro.ru", "phone": "+70148256160"}
0005434069587	302B79	1214 546858	LARISA MELNIKOVA	{"phone": "+70141040755"}
0005434069588	F98B98	6817 256863	KONSTANTIN DMITRIEV	{"phone": "+70952282860"}
0005434069589	100D93	6769 273990	DARYA KOVALEVA	{"phone": "+70405314154"}
0005434069590	100D93	6271 665563	VASILIY ZAYCEV	{"phone": "+70544124544"}
0005434069591	31101C	6634 255774	KRISTINA KRASNOVA	{"phone": "+70570977840"}
0005434069592	31101C	8406 562285	MAKSIM KRASNOV	{"email": "krasnovmaksim1969@postgrespro.ru", "phone": "+70887548344"}
0005434069593	31101C	8549 387547	NINA MELNIKOVA	{"email": "n.melnikova_1969@postgrespro.ru", "phone": "+70209226121"}
0005434069594	41D6CC	1530 418137	ALEKSANDRA KULIKOVA	{"email": "a.kulikova.1975@postgrespro.ru", "phone": "+70571539156"}
0005434069595	B78C57	7386 463455	YULIYA NIKOLAEVA	{"email": "nikolaeva.y101963@postgrespro.ru", "phone": "+70605861818"}
0005434069596	B78C57	9009 990498	ANASTASIYA ALEKSEEVA	{"phone": "+70482044519"}
0005434069597	FF56BA	8907 462946	ANASTASIYA TIMOFEEVA	{"email": "anastasiya.timofeeva_03101970@postgrespro.ru", "phone": "+70999920917"}
0005434069598	2D1092	8899 365019	SERGEY MELNIKOV	{"phone": "+70751385583"}
0005434069599	1C6064	7004 105506	MIKHAIL MAKSIMOV	{"email": "maksimov_m_1977@postgrespro.ru", "phone": "+70958332622"}
0005434069600	3C2356	0882 315961	NADEZHDA ALEKSEEVA	{"phone": "+70451149821"}
0005434069601	12D482	7015 329922	NINA KRASNOVA	{"email": "krasnova-n-011968@postgrespro.ru", "phone": "+70715458103"}
0005434069602	8C1AB9	8981 220587	ARINA DMITRIEVA	{"email": "dmitrieva.arina-13021968@postgrespro.ru", "phone": "+70604069138"}
0005434069603	8C1AB9	3823 371806	SERGEY TARASOV	{"email": "tarasov.sergey-1973@postgrespro.ru", "phone": "+70088556959"}
0005434069604	E9BFBB	3436 486733	VALENTINA FILATOVA	{"email": "filatovav_061980@postgrespro.ru", "phone": "+70626409644"}
0005434069605	96466B	5680 367164	IVAN VOLKOV	{"email": "volkovi021975@postgrespro.ru", "phone": "+70985073640"}
0005434069606	93F013	2406 896834	IDA SOKOLOVA	{"email": "i.sokolova1973@postgrespro.ru", "phone": "+70556273477"}
0005434069607	93F013	6438 974864	DMITRIY GUSEV	{"email": "dmitriy-gusev1970@postgrespro.ru", "phone": "+70091971437"}
0005434069608	93F013	8846 144655	NINA IVANOVA	{"email": "n_ivanova-1985@postgrespro.ru", "phone": "+70037155367"}
0005434069609	FD065D	2490 829270	SERGEY SCHERBAKOV	{"email": "scherbakovs101973@postgrespro.ru", "phone": "+70189728721"}
0005434069610	03A9A0	7749 230553	LYUBOV MASLOVA	{"email": "maslova.l.021977@postgrespro.ru", "phone": "+70343964468"}
0005434069611	46E2FE	6435 894199	ALEKSANDR SMIRNOV	{"phone": "+70641762055"}
0005434069612	46E2FE	4822 938945	OLGA POLYAKOVA	{"email": "polyakova.olga-22091972@postgrespro.ru", "phone": "+70872064227"}
0005434069613	6132B6	9573 068205	DMITRIY IVANOV	{"phone": "+70392110678"}
0005434069614	4E7C80	9120 573284	MARINA ARKHIPOVA	{"phone": "+70456307214"}
0005434069615	5834B9	3540 262324	IRINA KUZNECOVA	{"email": "irina-kuznecova_021974@postgrespro.ru", "phone": "+70164537423"}
0005434069616	2B4761	4355 346883	MARIYA ORLOVA	{"email": "orlova-mariya1985@postgrespro.ru", "phone": "+70043366271"}
0005434069617	2B4761	6544 720961	ALEKSANDRA BARANOVA	{"email": "baranova.aleksandra021984@postgrespro.ru", "phone": "+70364256423"}
0005434069618	1250C3	7272 060013	ALENA GUSEVA	{"email": "gusevaa_121977@postgrespro.ru", "phone": "+70621936338"}
0005434069619	1250C3	2044 355557	PETR KOZLOV	{"email": "petrkozlov-1969@postgrespro.ru", "phone": "+70705208390"}
0005434069620	9C31C7	6081 907812	ALEKSEY ANTONOV	{"phone": "+70183193999"}
0005434069621	E65F77	5267 409815	VIKTOR NAUMOV	{"phone": "+70902143149"}
0005434069622	5384F4	3775 332491	VIKTOR MELNIKOV	{"email": "viktor-melnikov_1978@postgrespro.ru", "phone": "+70134025371"}
0005434069623	CA2C8B	5489 031708	KIRILL VOROBEV	{"email": "kirill-vorobev-27071981@postgrespro.ru", "phone": "+70092851990"}
0005434069624	D4975C	3043 305932	DARYA PETROVA	{"email": "petrovadarya121974@postgrespro.ru", "phone": "+70923807857"}
0005434069625	D4975C	2174 945948	ANNA POPOVA	{"email": "a-popova111972@postgrespro.ru", "phone": "+70396133595"}
0005434069626	0E493C	6330 692793	SERGEY ILIN	{"phone": "+70971891768"}
0005434069627	991A1F	4324 338067	EGOR POPOV	{"email": "e_popov.071972@postgrespro.ru", "phone": "+70402798042"}
0005434069628	991A1F	6128 486851	ALEKSEY KISELEV	{"email": "kiselev.a.21081972@postgrespro.ru", "phone": "+70887026045"}
0005434069629	0796AE	2792 609169	VALENTINA IVANOVA	{"email": "ivanova-v_1971@postgrespro.ru", "phone": "+70171352217"}
0005434069630	6E2C6F	1290 449887	EGOR YAKOVLEV	{"phone": "+70830073575"}
0005434069631	50A843	8382 384269	VIKTOR IVANOV	{"email": "viktor.ivanov091968@postgrespro.ru", "phone": "+70116124894"}
0005434069632	74A433	3586 794083	ALEKSANDR STEPANOV	{"email": "stepanov.a.27031976@postgrespro.ru", "phone": "+70175592117"}
0005434069633	6C707D	7361 272175	KRISTINA FILATOVA	{"phone": "+70432603280"}
0005434069634	9164B6	2996 200786	LYUDMILA KARPOVA	{"phone": "+70375056108"}
0005434069635	9164B6	7970 408312	LIDIYA KOLESNIKOVA	{"phone": "+70720950069"}
0005434069636	4BBDDD	0550 633844	VLADIMIR KOZLOV	{"email": "vladimir_kozlov081973@postgrespro.ru", "phone": "+70984994067"}
0005434069637	3279F6	2980 056614	ALEKSANDR PETROV	{"email": "petrov-a10091973@postgrespro.ru", "phone": "+70047507241"}
0005434069638	3279F6	0777 668986	SERGEY VOROBEV	{"phone": "+70539807123"}
0005434069639	1C7179	5975 658720	SVETLANA KRASNOVA	{"email": "krasnovas1952@postgrespro.ru", "phone": "+70704962664"}
0005434069640	F97A5E	8913 877389	NATALYA VLASOVA	{"phone": "+70915679375"}
0005434069641	F97A5E	3899 800359	VIKTORIYA FADEEVA	{"email": "fadeeva.viktoriya.19051968@postgrespro.ru", "phone": "+70735001424"}
0005434069642	8D74E2	3620 093520	MAKSIM KUZMIN	{"email": "m_kuzmin-24011970@postgrespro.ru", "phone": "+70631849831"}
0005434069643	83910A	8454 586086	ANATOLIY MOISEEV	{"phone": "+70377758203"}
0005434069644	71D004	8015 609667	ANNA ILINA	{"phone": "+70913887593"}
0005434069645	49A10E	3213 791071	ANTON MARTYNOV	{"email": "anton_martynov_1978@postgrespro.ru", "phone": "+70488305349"}
0005434069646	49A10E	0125 939615	TATYANA AKIMOVA	{"email": "t.akimova.1963@postgrespro.ru", "phone": "+70554082573"}
0005434069647	49A10E	2056 547858	SVETLANA KONOVALOVA	{"email": "konovalova_s12021968@postgrespro.ru", "phone": "+70221965756"}
0005434069648	49A10E	0295 250064	ALEKSANDR BARANOV	{"phone": "+70049232005"}
0005434069649	20C5AB	3351 728798	ARINA NOVIKOVA	{"email": "anovikova-1976@postgrespro.ru", "phone": "+70352801375"}
0005434081470	D4B7C8	9489 982581	ALEKSANDR FROLOV	{"phone": "+70528747278"}
0005434081471	A1C51C	3475 559786	ALEKSEY MOISEEV	{"email": "a-moiseev.01121985@postgrespro.ru", "phone": "+70904322918"}
0005434081472	7DCF40	6536 791942	YURIY NIKOLAEV	{"email": "nikolaevy.091985@postgrespro.ru", "phone": "+70161373465"}
0005434081473	7DCF40	8977 261876	DAMIR MELNIKOV	{"email": "damir-melnikov-1974@postgrespro.ru", "phone": "+70919501567"}
0005434081474	CD7067	0675 944571	NIKITA KUZNECOV	{"phone": "+70293705175"}
0005434081475	159507	7608 549351	VALERIY FEDOTOV	{"email": "fedotov_valeriy011972@postgrespro.ru", "phone": "+70684647697"}
0005434081476	CFDC89	4756 295611	ANGELINA KOMAROVA	{"email": "angelina_komarova.1983@postgrespro.ru", "phone": "+70754512728"}
0005434081477	71D67F	0310 792430	YANA MELNIKOVA	{"phone": "+70037810534"}
0005434081478	DF3622	8266 999853	ALEKSANDR SHEVCHENKO	{"phone": "+70519617322"}
0005434081479	DF3622	1959 172455	ALENA FROLOVA	{"phone": "+70641799427"}
0005434081480	9D28B3	0005 581339	TATYANA MOISEEVA	{"phone": "+70259927409"}
0005434081481	9D28B3	8948 524689	ANTON PETROV	{"phone": "+70489888792"}
0005434081482	984B59	3425 065106	SVETLANA KOLESNIKOVA	{"email": "svetlana-kolesnikova19011973@postgrespro.ru", "phone": "+70863501548"}
0005434081483	E163DC	3933 470940	ELENA TITOVA	{"email": "titova-elena1968@postgrespro.ru", "phone": "+70949269886"}
0005434081484	018214	8960 001381	ROZA DENISOVA	{"email": "rozadenisova011973@postgrespro.ru", "phone": "+70659237463"}
0005434081485	17AE42	8596 750594	TAMARA POPOVA	{"phone": "+70352318311"}
0005434081486	A5490D	0590 639981	SHAMIL AFANASEV	{"email": "safanasev.1970@postgrespro.ru", "phone": "+70149350274"}
0005434081487	D40281	5093 995216	ELENA DANILOVA	{"email": "elenadanilova-051976@postgrespro.ru", "phone": "+70062595209"}
0005434081488	9F9FFD	8885 755468	DMITRIY GAVRILOV	{"email": "gavrilov_dmitriy_01111967@postgrespro.ru", "phone": "+70766873028"}
0005434081489	50DEE9	6846 655048	VLADIMIR YAKOVLEV	{"email": "vyakovlev-011978@postgrespro.ru", "phone": "+70148131356"}
0005434081490	50DEE9	3906 082151	VYACHESLAV MOROZOV	{"phone": "+70190636652"}
0005434081491	50DEE9	2621 981751	NINA SMIRNOVA	{"phone": "+70051893566"}
0005434081492	FB288F	1787 224695	VALERIY KOZLOV	{"email": "kozlov.valeriy.20031983@postgrespro.ru", "phone": "+70566733210"}
0005434081493	FB288F	6705 266423	OLGA LAZAREVA	{"email": "lazareva.o_031970@postgrespro.ru", "phone": "+70503603613"}
0005434081494	FB288F	3391 603112	IGOR BONDARENKO	{"phone": "+70264898526"}
0005434081495	0A7106	6523 870156	ALESYA LUKYANOVA	{"phone": "+70630736466"}
0005434081496	8F652D	1769 390144	ALEKSEY DAVYDOV	{"email": "a.davydov-06071977@postgrespro.ru", "phone": "+70171270300"}
0005434081497	6C247B	2346 003280	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr-11111968@postgrespro.ru", "phone": "+70864382161"}
0005434081498	6C247B	4135 573410	TATYANA VLASOVA	{"phone": "+70391384824"}
0005434081499	C991F1	3309 586911	LEV MEDVEDEV	{"phone": "+70744926541"}
0005434081500	4E1900	1080 903680	VLADIMIR NAZAROV	{"phone": "+70960881428"}
0005434081501	4E1900	3244 603198	DMITRIY FOMIN	{"email": "dmitriy_fomin.18101973@postgrespro.ru", "phone": "+70180262572"}
0005434081502	6C79A2	1406 555465	YULIYA ROMANOVA	{"email": "y-romanova.04081982@postgrespro.ru", "phone": "+70659267143"}
0005434081503	0D80E5	9674 156402	ALBERT KUZNECOV	{"phone": "+70832299504"}
0005434081504	A4FD2A	4735 415057	YURIY MIRONOV	{"phone": "+70215206175"}
0005434081505	828FE5	4672 911250	PETR ILIN	{"email": "ilinp.1961@postgrespro.ru", "phone": "+70595741244"}
0005434081506	828FE5	2902 377741	ANTONINA OVCHINNIKOVA	{"phone": "+70855868912"}
0005434081507	828FE5	6441 429872	NATALYA ZOTOVA	{"phone": "+70534091771"}
0005434081508	3C5589	7933 405463	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda-1982@postgrespro.ru", "phone": "+70359490692"}
0005434081509	3C5589	5150 704626	GALINA ZHURAVLEVA	{"phone": "+70473289819"}
0005434081510	22A30F	6953 210259	VASILIY BORISOV	{"email": "vasiliyborisov-031981@postgrespro.ru", "phone": "+70072421152"}
0005434081511	7CF480	9007 833538	ANDREY SOLOVEV	{"phone": "+70419100298"}
0005434081512	91A65C	2530 488846	NIKOLAY MARTYNOV	{"email": "nmartynov-05051972@postgrespro.ru", "phone": "+70972748568"}
0005434081513	DAD12A	7230 891924	ZOYA NIKITINA	{"email": "zoyanikitina-1969@postgrespro.ru", "phone": "+70304204327"}
0005434081514	DAD12A	7635 271829	NINA ISAEVA	{"phone": "+70727233747"}
0005434081515	7728C1	6263 186658	MARGARITA NAZAROVA	{"phone": "+70504449405"}
0005434081516	B31BA2	3914 146347	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr_091974@postgrespro.ru", "phone": "+70340928219"}
0005434081517	EDC2D3	3310 366306	KSENIYA NAUMOVA	{"phone": "+70618096723"}
0005434081518	10DC4C	0573 242354	ALEKSANDR IVANOV	{"email": "ivanov_a_081961@postgrespro.ru", "phone": "+70852600162"}
0005434081519	D154D5	5892 853640	OLGA VOLKOVA	{"phone": "+70524822980"}
0005434081520	D154D5	2712 882576	OLEG NAUMOV	{"phone": "+70821967485"}
0005434081521	1FFBB6	4637 923170	SVETLANA ZOTOVA	{"email": "zotova.svetlana081985@postgrespro.ru", "phone": "+70280211290"}
0005434081522	954D6B	7158 064106	SERGEY MIRONOV	{"phone": "+70056867749"}
0005434081523	954D6B	6974 985348	LYUBOV KOMAROVA	{"email": "l.komarova.031971@postgrespro.ru", "phone": "+70887280877"}
0005434081524	92BB6B	8587 862601	OLEG TIMOFEEV	{"phone": "+70492988181"}
0005434081525	92BB6B	8427 764105	VARVARA MIRONOVA	{"phone": "+70754520937"}
0005434081526	8BC7DF	8580 420128	MARIYA NESTEROVA	{"email": "mariya.nesterova-27031974@postgrespro.ru", "phone": "+70765166732"}
0005434081527	8BC7DF	6262 084339	IRINA CHERNOVA	{"email": "irina_chernova.091976@postgrespro.ru", "phone": "+70590623077"}
0005434081528	BA28A8	1687 571193	MARIYA EFIMOVA	{"email": "efimovam12101974@postgrespro.ru", "phone": "+70916733970"}
0005434081529	EFBC9C	6730 384253	ANDREY MIKHAYLOV	{"email": "andrey.mikhaylov-18091961@postgrespro.ru", "phone": "+70571877281"}
0005434081530	915A9E	4484 466537	ELENA VOLKOVA	{"phone": "+70298164104"}
0005434081531	54C4E8	2708 325251	GENNADIY GUSEV	{"email": "g-gusev.23041974@postgrespro.ru", "phone": "+70812157701"}
0005434081532	E39673	4090 463471	ELENA ZHURAVLEVA	{"email": "zhuravleva.e-1968@postgrespro.ru", "phone": "+70243133738"}
0005434081533	3FC668	3248 069065	VALERIY ZHUKOV	{"email": "valeriy-zhukov_011972@postgrespro.ru", "phone": "+70791897950"}
0005434081534	3FC668	5194 233829	ALEKSANDR GERASIMOV	{"email": "gerasimov_aleksandr.13021977@postgrespro.ru", "phone": "+70821766090"}
0005434081535	314B81	9477 671492	VALERIY MARTYNOV	{"phone": "+70264725857"}
0005434081536	314B81	4729 563186	FANIL MAKSIMOV	{"phone": "+70048277391"}
0005434081537	12B2C7	2954 799209	ANNA LUKYANOVA	{"email": "annalukyanova-17041972@postgrespro.ru", "phone": "+70244663293"}
0005434081538	981701	6242 135731	ELENA NOVIKOVA	{"email": "novikova_e_101981@postgrespro.ru", "phone": "+70837323435"}
0005434081539	639A9A	9892 675262	SVETLANA NAZAROVA	{"email": "nazarova.svetlana.1983@postgrespro.ru", "phone": "+70379409015"}
0005434081540	4D1CC1	3654 643239	LYUDMILA FEDOROVA	{"phone": "+70014054462"}
0005434081541	0DA0E6	6018 107952	EKATERINA ALEKSEEVA	{"email": "alekseeva.ekaterina-11011973@postgrespro.ru", "phone": "+70871170280"}
0005434081542	512AB4	7372 666771	NATALYA IVANOVA	{"email": "ivanova-n-11031965@postgrespro.ru", "phone": "+70268696130"}
0005434081543	62D5A0	4753 634903	ANNA KOROLEVA	{"email": "korolevaanna.25061972@postgrespro.ru", "phone": "+70034039652"}
0005434081544	B40C88	1896 224855	OKSANA GAVRILOVA	{"email": "gavrilova-oksana.17021964@postgrespro.ru", "phone": "+70485156140"}
0005434081545	213377	7851 042172	GALINA VOROBEVA	{"phone": "+70566543930"}
0005434081546	E18131	9167 411567	VERA KONOVALOVA	{"email": "vera.konovalova-1976@postgrespro.ru", "phone": "+70924594592"}
0005434081547	E18131	3673 258829	VASILIY SIDOROV	{"email": "sidorovv.03061969@postgrespro.ru", "phone": "+70054692155"}
0005434081548	3BE03D	5868 492970	INNA KOVALEVA	{"email": "inna.kovaleva_1967@postgrespro.ru", "phone": "+70570059132"}
0005434081549	3BE03D	2947 495234	STANISLAV MELNIKOV	{"email": "melnikov_stanislav-1969@postgrespro.ru", "phone": "+70758425408"}
0005434081550	CCE95F	1612 352772	ALEKSANDR YAKOVLEV	{"email": "ayakovlev051979@postgrespro.ru", "phone": "+70032140994"}
0005434081551	1C44E7	1887 927582	EKATERINA SAVELEVA	{"phone": "+70632474278"}
0005434081552	04B80C	3908 503504	NATALYA ILINA	{"email": "ilina-n_29051973@postgrespro.ru", "phone": "+70881062502"}
0005434081553	CA07DD	9516 425099	DMITRIY BELOV	{"email": "d.belov-111969@postgrespro.ru", "phone": "+70078029803"}
0005434081554	79CCCF	6022 084547	ALEKSANDR RODIONOV	{"phone": "+70052967917"}
0005434081555	C1BE98	3594 367831	ANASTASIYA KUZMINA	{"phone": "+70912301079"}
0005434081556	795876	4603 526846	DMITRIY SIDOROV	{"phone": "+70349615695"}
0005434081557	ED683F	6192 736930	NATALYA BELOVA	{"email": "natalya.belova-121971@postgrespro.ru", "phone": "+70613752362"}
0005434081558	ED683F	8423 516121	GALINA NAZAROVA	{"email": "g-nazarova061963@postgrespro.ru", "phone": "+70787933365"}
0005434081559	A166C8	6435 022544	LEONID ABRAMOV	{"email": "abramov.l_1970@postgrespro.ru", "phone": "+70407071339"}
0005434081560	A166C8	4079 729722	TATYANA ALEKSEEVA	{"phone": "+70887817807"}
0005434081561	32441D	4071 421454	ALENA PETROVA	{"phone": "+70559207628"}
0005434081562	B8AC70	1918 024830	ANTON CHERNOV	{"email": "anton.chernov.26031971@postgrespro.ru", "phone": "+70814448015"}
0005434081563	B8AC70	0915 011815	ARTUR ANTONOV	{"email": "a_antonov-28071980@postgrespro.ru", "phone": "+70180808533"}
0005434081564	488BBC	0479 365424	VALERIY KONOVALOV	{"phone": "+70083465400"}
0005434081565	488BBC	4780 128541	OKSANA DMITRIEVA	{"phone": "+70363935924"}
0005434081566	7ABB8B	1865 302557	ALEKSANDR ILIN	{"email": "ilin.a_121968@postgrespro.ru", "phone": "+70343963917"}
0005434081567	EDD51B	3860 678207	IRINA KOMAROVA	{"phone": "+70529210619"}
0005434081568	EDD51B	4852 567858	OLEG ISAEV	{"email": "isaev.o021968@postgrespro.ru", "phone": "+70022274041"}
0005434081569	7534AB	0687 431037	VASILIY ANTONOV	{"email": "vasiliy_antonov_081972@postgrespro.ru", "phone": "+70008925535"}
0005434081570	7534AB	8845 333355	NIKITA BORISOV	{"email": "borisov_n.1966@postgrespro.ru", "phone": "+70842340424"}
0005434081571	7721D6	2805 329245	IVAN VASILEV	{"email": "vasilev-i-1974@postgrespro.ru", "phone": "+70764942981"}
0005434081572	7721D6	7366 718506	SHAMIL OSIPOV	{"phone": "+70919113926"}
0005434081573	24CF61	4591 054879	LIDIYA KALININA	{"email": "kalinina_lidiya-081965@postgrespro.ru", "phone": "+70201890292"}
0005434081574	9629C8	1681 884180	TALGAT GAVRILOV	{"phone": "+70974105093"}
0005434081575	9629C8	5508 936741	ALEKSANDR ORLOV	{"phone": "+70881185263"}
0005434081576	2F93F8	2990 015952	GALIYA ZAKHAROVA	{"phone": "+70446109974"}
0005434081577	728DF3	3222 307184	ALEKSEY DENISOV	{"email": "alekseydenisov.01021977@postgrespro.ru", "phone": "+70418639406"}
0005434081578	728DF3	4076 383197	ANDREY VLASOV	{"email": "vlasova-09111967@postgrespro.ru", "phone": "+70030987723"}
0005434081579	5EC58C	4407 871404	OLGA CHERNOVA	{"email": "olgachernova-121975@postgrespro.ru", "phone": "+70542451036"}
0005434081580	FA9B5E	0236 570457	TAMARA POPOVA	{"email": "t-popova-011975@postgrespro.ru", "phone": "+70163141437"}
0005434081581	FA9B5E	2794 256698	EKATERINA KALININA	{"phone": "+70810365080"}
0005434081582	305915	8962 133374	ARTEM FEDOROV	{"phone": "+70202757198"}
0005434081583	393D84	2159 213351	ELENA GAVRILOVA	{"email": "gavrilova-elena-1980@postgrespro.ru", "phone": "+70834352664"}
0005434081584	393D84	8654 994597	ARTEM SERGEEV	{"phone": "+70116603888"}
0005434081585	29C2EB	4934 632028	YULIYA FOMINA	{"email": "yuliya_fomina_29081971@postgrespro.ru", "phone": "+70625881682"}
0005434081586	9B6DDB	6291 925782	PRASKOVYA PETROVA	{"phone": "+70403691641"}
0005434081587	9B6DDB	2399 363435	ELVIRA NIKIFOROVA	{"email": "nikiforova_elvira.011977@postgrespro.ru", "phone": "+70175407410"}
0005434081588	D8EAEA	3441 896555	ELENA PETROVA	{"phone": "+70766738670"}
0005434081589	D8EAEA	2652 959514	OLGA DANILOVA	{"phone": "+70680633325"}
0005434081590	72DC06	4883 088489	EVGENIY SOROKIN	{"email": "e.sorokin-041979@postgrespro.ru", "phone": "+70581185634"}
0005434081591	83634F	6074 940167	KSENIYA DAVYDOVA	{"phone": "+70631371511"}
0005434081592	9CCCCB	7893 372809	SERGEY NIKITIN	{"email": "s.nikitin-061972@postgrespro.ru", "phone": "+70269409917"}
0005434081593	2CA020	8305 593006	VIKTOR STEPANOV	{"phone": "+70108955194"}
0005434081594	2CA020	3236 556880	OKSANA OSIPOVA	{"phone": "+70950208972"}
0005434081595	88A827	0246 744555	VYACHESLAV GERASIMOV	{"email": "gerasimovv_111967@postgrespro.ru", "phone": "+70223535967"}
0005434081596	565809	9681 218368	ARTUR VOLKOV	{"email": "volkovartur-1971@postgrespro.ru", "phone": "+70745431033"}
0005434081597	565809	9041 566133	MARIYA GRISHINA	{"email": "m.grishina_27091978@postgrespro.ru", "phone": "+70456285115"}
0005434081598	917EF5	0994 309758	DARYA MAKAROVA	{"phone": "+70812164877"}
0005434081599	B92B43	3718 576543	NADEZHDA ANDREEVA	{"email": "nadezhda-andreeva.031967@postgrespro.ru", "phone": "+70415515095"}
0005434081600	BC7B74	9527 023431	LYUBOV BORISOVA	{"phone": "+70146303866"}
0005434081601	31CCD5	2125 884485	VALERIY SEMENOV	{"phone": "+70118561744"}
0005434081602	4E6BC2	0446 832868	VLADIMIR KONOVALOV	{"email": "konovalov-vladimir_08051982@postgrespro.ru", "phone": "+70333471369"}
0005434081603	4E6BC2	7631 182641	DMITRIY STEPANOV	{"phone": "+70437689403"}
0005434081604	13364B	4400 122632	VLADIMIR FOMIN	{"phone": "+70275041626"}
0005434081605	5DEC32	2834 327855	VLADIMIR GORBUNOV	{"email": "v_gorbunov1980@postgrespro.ru", "phone": "+70382073955"}
0005434081606	5DEC32	5482 486965	SVETLANA RODIONOVA	{"phone": "+70482294329"}
0005434081607	5DEC32	6100 621446	VLADIMIR MAKAROV	{"email": "makarov_vladimir.1975@postgrespro.ru", "phone": "+70333742241"}
0005434081608	6BA3C1	4385 498884	GALINA MOROZOVA	{"phone": "+70249799416"}
0005434081609	6BA3C1	9510 596523	DMITRIY KOZLOV	{"email": "dmitriy_kozlov1973@postgrespro.ru", "phone": "+70711112047"}
0005434081610	DE64EF	5442 190477	INNA SMIRNOVA	{"email": "ismirnova.21111977@postgrespro.ru", "phone": "+70001451615"}
0005434081611	A55DBE	1361 716498	ROMAN FEDOTOV	{"email": "romanfedotov101971@postgrespro.ru", "phone": "+70768966131"}
0005434081612	2BAAAE	4571 503710	NADEZHDA MATVEEVA	{"email": "nadezhda_matveeva.1976@postgrespro.ru", "phone": "+70954443820"}
0005434081613	2BAAAE	3086 052756	NAIL ANTONOV	{"phone": "+70917660152"}
0005434081614	D7C942	5132 197716	LARISA MEDVEDEVA	{"phone": "+70982058409"}
0005434081615	80629A	4455 797441	TAMARA SERGEEVA	{"email": "sergeevat.29121971@postgrespro.ru", "phone": "+70725212853"}
0005434081616	80629A	8610 079545	YURIY PAVLOV	{"phone": "+70062737808"}
0005434081617	47A31C	4190 437197	NIKOLAY KONOVALOV	{"phone": "+70344835727"}
0005434081618	47A31C	7686 560430	ANNA KUZNECOVA	{"email": "anna.kuznecova1960@postgrespro.ru", "phone": "+70804750752"}
0005434081619	F47269	3638 677011	VALENTINA GERASIMOVA	{"phone": "+70978906215"}
0005434081620	F74B82	6234 085711	NAILYA DMITRIEVA	{"email": "dmitrieva-nailya-1983@postgrespro.ru", "phone": "+70791248256"}
0005434081621	F74B82	3094 844326	ANNA BELYAEVA	{"email": "belyaeva-a_1964@postgrespro.ru", "phone": "+70373999987"}
0005434081622	BD289E	7684 605848	DMITRIY STEPANOV	{"phone": "+70984161317"}
0005434081623	BD289E	4654 031026	LYUDMILA BELOVA	{"phone": "+70859857055"}
0005434081624	5C2BFC	0648 082794	SERGEY GAVRILOV	{"email": "sergey-gavrilov_1959@postgrespro.ru", "phone": "+70044733443"}
0005434081625	5C2BFC	8494 600166	MIKHAIL BORISOV	{"phone": "+70208757303"}
0005434081626	C95F6D	8889 808074	OLGA DAVYDOVA	{"email": "davydovaolga.16121968@postgrespro.ru", "phone": "+70904050157"}
0005434081627	A51770	8927 592575	VITALIY ZAKHAROV	{"email": "zakharov-vitaliy_1957@postgrespro.ru", "phone": "+70899225544"}
0005434081628	A51770	0454 220527	GRIGORIY STEPANOV	{"phone": "+70339874522"}
0005434081629	120F8F	3241 193369	RINAT SERGEEV	{"phone": "+70582462178"}
0005434081630	120F8F	4729 037591	ULYANA NIKITINA	{"email": "ulyana.nikitina16121975@postgrespro.ru", "phone": "+70786082742"}
0005434081631	9DFBE4	8618 192877	MARIYA SEMENOVA	{"email": "semenovamariya_03111971@postgrespro.ru", "phone": "+70622266717"}
0005434081632	9DFBE4	1112 523570	OLEG VOROBEV	{"phone": "+70813508311"}
0005434081633	B70526	6741 893525	SERGEY ORLOV	{"email": "orlovs-05011973@postgrespro.ru", "phone": "+70081473622"}
0005434081634	B70526	5847 216038	ZINAIDA NIKOLAEVA	{"phone": "+70448919076"}
0005434081635	2629EE	8674 333724	ALEKSANDR NOVIKOV	{"phone": "+70737668825"}
0005434081636	2938C5	0716 538116	DMITRIY KULIKOV	{"phone": "+70565400471"}
0005434081637	DE611D	0795 379104	ANATOLIY FOMIN	{"phone": "+70798297226"}
0005434081638	C79A90	9109 490520	ELENA LUKYANOVA	{"email": "lukyanova.elena_081975@postgrespro.ru", "phone": "+70626231035"}
0005434081639	879F7C	4790 869150	VLADIMIR BELOV	{"email": "v.belov29061967@postgrespro.ru", "phone": "+70897024677"}
0005434081640	879F7C	5663 303648	ANZHELA KUZNECOVA	{"email": "kuznecova.a_101963@postgrespro.ru", "phone": "+70396606707"}
0005434081641	58082F	0681 056867	MARINA KISELEVA	{"phone": "+70572272367"}
0005434081642	80280E	0792 467824	NATALYA LOGINOVA	{"phone": "+70520510379"}
0005434081643	907305	4601 813674	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr_081976@postgrespro.ru", "phone": "+70604979364"}
0005434081644	5575EB	7573 917299	NATALYA VLASOVA	{"email": "vlasova-natalya061974@postgrespro.ru", "phone": "+70478476677"}
0005434081645	AFF25E	2919 536863	KSENIYA VASILEVA	{"phone": "+70027128860"}
0005434081646	69CCE0	1688 379563	NADEZHDA KULIKOVA	{"email": "nadezhdakulikova-11111976@postgrespro.ru", "phone": "+70951612699"}
0005434081647	40C431	1654 791418	OLGA KOROLEVA	{"phone": "+70708200828"}
0005434081648	74A092	5438 862708	EVGENIYA ZOTOVA	{"phone": "+70455228973"}
0005434081649	8FFCC2	7057 483084	DMITRIY SOKOLOV	{"email": "dmitriy_sokolov-021978@postgrespro.ru", "phone": "+70714122943"}
0005434081650	942141	5930 579782	NADEZHDA ZHUKOVA	{"phone": "+70221465176"}
0005434081651	942141	9329 194765	ARTEM POPOV	{"email": "popov-artem21101983@postgrespro.ru", "phone": "+70339515548"}
0005434081652	DFA0FA	1459 349340	ANASTASIYA PETROVA	{"email": "petrova.anastasiya021961@postgrespro.ru", "phone": "+70938376267"}
0005434081653	73728B	9075 031546	GALINA KUZNECOVA	{"phone": "+70099445781"}
0005434081654	73728B	4245 745884	EKATERINA ZAYCEVA	{"email": "zayceva.ekaterina011980@postgrespro.ru", "phone": "+70432687201"}
0005434081655	3F29E1	6122 963208	ILYA POPOV	{"phone": "+70769532647"}
0005434081656	EB1BEA	5477 693202	YURIY ORLOV	{"phone": "+70649698600"}
0005434081657	B82C23	5554 899911	EVGENIY PETROV	{"email": "petrovevgeniy.1959@postgrespro.ru", "phone": "+70398910057"}
0005434081658	B82C23	9823 900205	VLADIMIR KUZNECOV	{"email": "kuznecov-v1973@postgrespro.ru", "phone": "+70393514892"}
0005434081659	F68AF6	7955 455192	SERGEY NAUMOV	{"email": "naumovs.051971@postgrespro.ru", "phone": "+70536735459"}
0005434081660	12B618	3702 410475	ELENA FILATOVA	{"email": "e_filatova01061969@postgrespro.ru", "phone": "+70022006561"}
0005434081661	1A73AD	1256 247246	SERGEY SMIRNOV	{"phone": "+70186239168"}
0005434081662	1A73AD	4809 548376	GEORGIY ANDREEV	{"email": "gandreev_1966@postgrespro.ru", "phone": "+70512132311"}
0005434081663	1A73AD	8413 850850	NIKOLAY MOROZOV	{"phone": "+70344967132"}
0005434081664	8338B8	4927 465318	DMITRIY GUSEV	{"email": "d_gusev_121966@postgrespro.ru", "phone": "+70712007227"}
0005434081665	DFECCC	4280 762685	ELENA MEDVEDEVA	{"phone": "+70086058129"}
0005434081666	EB4504	9887 057304	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-18101967@postgrespro.ru", "phone": "+70104868150"}
0005434081667	EB4504	8092 262554	SVETLANA BORISOVA	{"phone": "+70478304787"}
0005434081668	B8B905	2054 741653	VALENTINA GORBUNOVA	{"phone": "+70410228189"}
0005434081669	79C303	1238 433777	NIKOLAY DENISOV	{"email": "n-denisov1965@postgrespro.ru", "phone": "+70444284028"}
0005434081670	79C303	0163 327666	VALENTINA MIKHAYLOVA	{"email": "v-mikhaylova.1960@postgrespro.ru", "phone": "+70035041040"}
0005434081671	81D001	1992 390246	SERGEY SEMENOV	{"phone": "+70262749410"}
0005434081672	EF274D	3875 040739	SVETLANA TROFIMOVA	{"phone": "+70816386696"}
0005434081673	40B885	1437 633989	RAMIL OSIPOV	{"email": "ramil_osipov_1971@postgrespro.ru", "phone": "+70144220071"}
0005434081674	BFCD0D	4068 226156	VERA ROMANOVA	{"email": "vera_romanova_121971@postgrespro.ru", "phone": "+70227114882"}
0005434081675	BFCD0D	8638 333659	DAMIR DENISOV	{"email": "damir_denisov-20101978@postgrespro.ru", "phone": "+70181910335"}
0005434081676	9D412C	2007 356150	ELENA SOROKINA	{"email": "sorokina.e.28031969@postgrespro.ru", "phone": "+70799486695"}
0005434081677	9D412C	6424 343153	TATYANA MALYSHEVA	{"phone": "+70053295516"}
0005434081678	96593F	4295 449450	SERGEY ZAYCEV	{"email": "s-zaycev.1977@postgrespro.ru", "phone": "+70860867164"}
0005434081679	96593F	5139 841722	ALEKSANDRA BELOVA	{"email": "a_belova-04011973@postgrespro.ru", "phone": "+70774988834"}
0005434081680	96593F	9998 700744	VLADIMIR POPOV	{"phone": "+70276224532"}
0005434081681	1B0BE0	6166 784518	GENNADIY TIKHONOV	{"email": "gennadiy_tikhonov1969@postgrespro.ru", "phone": "+70242610138"}
0005434081682	1B0BE0	0921 206077	GRIGORIY ZAKHAROV	{"email": "g_zakharov.1969@postgrespro.ru", "phone": "+70589932589"}
0005434081683	17D3C8	0677 031336	YURIY KUZNECOV	{"phone": "+70735165546"}
0005434081684	9D004B	2361 652595	VYACHESLAV KOROLEV	{"email": "vyacheslav_korolev.20101976@postgrespro.ru", "phone": "+70831251684"}
0005434081685	9D004B	4197 057192	EVGENIYA FADEEVA	{"email": "evgeniyafadeeva041977@postgrespro.ru", "phone": "+70104128285"}
0005434081686	9F42F6	6030 386971	ANDREY CHERNOV	{"email": "andreychernov-09051970@postgrespro.ru", "phone": "+70153913891"}
0005434081687	CEAFCC	0253 438286	ALEKSEY FEDOROV	{"phone": "+70018444401"}
0005434081688	CEAFCC	6932 904338	ANNA KUDRYASHOVA	{"email": "kudryashovaanna_1973@postgrespro.ru", "phone": "+70425077917"}
0005434081689	1A4EB7	9791 078099	EKATERINA RODIONOVA	{"phone": "+70464354130"}
0005434081690	E1318F	3518 952681	ALEKSEY FEDOTOV	{"phone": "+70704169380"}
0005434081691	F16627	7908 141961	KSENIYA MEDVEDEVA	{"email": "k-medvedeva_1961@postgrespro.ru", "phone": "+70092634578"}
0005434081692	E5139F	3032 086491	EVGENIY GERASIMOV	{"email": "e_gerasimov-121967@postgrespro.ru", "phone": "+70193558420"}
0005434081693	E5139F	6053 195178	OLGA FOMINA	{"phone": "+70409622715"}
0005434081694	D71D72	1475 748121	ANDREY KUZNECOV	{"email": "kuznecov-andrey.051970@postgrespro.ru", "phone": "+70397829196"}
0005434081695	47762C	2900 583426	DENIS PETROV	{"email": "petrov_denis_1962@postgrespro.ru", "phone": "+70625947210"}
0005434081696	0D8EA4	1179 909790	MAKSIM FILIPPOV	{"phone": "+70767569499"}
0005434081697	D0B2F0	9318 416803	GALINA KOLESNIKOVA	{"phone": "+70667057333"}
0005434081698	30D212	8832 904865	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov_15021967@postgrespro.ru", "phone": "+70309509802"}
0005434081699	30D212	9085 696590	DIANA ORLOVA	{"email": "d-orlova_011967@postgrespro.ru", "phone": "+70524165731"}
0005434081700	738CA2	8303 029688	PETR PETROV	{"email": "petrov_petr_1965@postgrespro.ru", "phone": "+70144632845"}
0005434081701	738CA2	1823 924471	ALEKSANDR SEMENOV	{"email": "a.semenov.02121966@postgrespro.ru", "phone": "+70014731141"}
0005434081702	AD85C9	9056 947322	NATALYA MAKSIMOVA	{"phone": "+70119441572"}
0005434081703	899142	8570 788751	TAMARA POPOVA	{"email": "tamara_popova11101971@postgrespro.ru", "phone": "+70029975022"}
0005434081704	BC3505	8967 252611	ALEKSANDR KONOVALOV	{"phone": "+70891233100"}
0005434081705	BC3505	3533 245669	ZINAIDA KONDRATEVA	{"phone": "+70271816583"}
0005434081706	1E0F0E	0333 456321	EVGENIYA ROMANOVA	{"phone": "+70730101445"}
0005434081707	FC4A9A	2288 429011	ANDREY IVANOV	{"email": "ivanov.andrey18091982@postgrespro.ru", "phone": "+70964720991"}
0005434081708	BE2859	7759 376253	OLESYA NOVIKOVA	{"phone": "+70917084831"}
0005434081709	0373BE	6509 698727	VIKTOR SERGEEV	{"email": "v.sergeev_12111962@postgrespro.ru", "phone": "+70858200778"}
0005434081710	28B705	4408 633313	LIDIYA STEPANOVA	{"email": "lstepanova.1970@postgrespro.ru", "phone": "+70193140947"}
0005434081711	28B705	6335 259470	ELENA NIKOLAEVA	{"email": "e_nikolaeva.1971@postgrespro.ru", "phone": "+70607866225"}
0005434081712	409997	0424 103943	DENIS ANDREEV	{"phone": "+70664511167"}
0005434081713	409997	3217 588912	DMITRIY NAUMOV	{"phone": "+70556313219"}
0005434081714	562412	3436 984294	NATALYA FILIPPOVA	{"phone": "+70837976960"}
0005434081715	562412	9324 871841	DIANA DAVYDOVA	{"phone": "+70827432789"}
0005434081716	5B0B46	4846 985193	MARIYA SAVELEVA	{"phone": "+70781375953"}
0005434081717	685F7B	8720 533086	KARINA KOZLOVA	{"email": "kozlovak_081972@postgrespro.ru", "phone": "+70307452917"}
0005434081718	A40C26	5972 545619	ANDREY PAVLOV	{"phone": "+70409365815"}
0005434081719	18403C	6568 470951	RASHID KAZAKOV	{"phone": "+70728103814"}
0005434081720	C47115	5409 872962	NIKITA IVANOV	{"phone": "+70331513603"}
0005434081721	8E2CDC	9561 132861	DENIS MARTYNOV	{"email": "martynov_denis_1963@postgrespro.ru", "phone": "+70536697762"}
0005434081722	77CF57	5659 867529	DENIS GAVRILOV	{"phone": "+70234464264"}
0005434081723	77CF57	5031 643404	BORIS KARPOV	{"phone": "+70915293746"}
0005434081724	64829F	0271 923606	EKATERINA MATVEEVA	{"email": "matveevaekaterina14071973@postgrespro.ru", "phone": "+70678561838"}
0005434081725	64829F	6156 679112	EKATERINA KAZAKOVA	{"email": "kazakova.ekaterina-24111965@postgrespro.ru", "phone": "+70870594630"}
0005434081726	22D5A6	0471 757922	TATYANA MARTYNOVA	{"email": "martynovat1972@postgrespro.ru", "phone": "+70736172927"}
0005434081727	22D5A6	1351 426503	ALBINA OVCHINNIKOVA	{"phone": "+70819466307"}
0005434081728	EBA1EA	0144 881119	TATYANA GERASIMOVA	{"email": "tatyana-gerasimova_1968@postgrespro.ru", "phone": "+70464637956"}
0005434081729	6047DE	4244 130466	DMITRIY VASILEV	{"email": "vasilev-d.111992@postgrespro.ru", "phone": "+70734707362"}
0005434081730	6047DE	3775 797515	MARINA POPOVA	{"phone": "+70787973298"}
0005434081731	DC607A	4635 554961	NATALYA SCHERBAKOVA	{"email": "natalya.scherbakova-071959@postgrespro.ru", "phone": "+70663673722"}
0005434081732	826ADD	9406 716202	ALEKSEY NIKITIN	{"email": "a.nikitin-22041970@postgrespro.ru", "phone": "+70802127736"}
0005434081733	7441DF	5073 565214	ALEKSANDR SOLOVEV	{"email": "solovev_aleksandr_1986@postgrespro.ru", "phone": "+70822142771"}
0005434081734	1BDC51	2899 287262	TATYANA SIDOROVA	{"phone": "+70199420982"}
0005434081735	A83959	8914 099189	IVAN VASILEV	{"email": "vasilev-ivan_18121972@postgrespro.ru", "phone": "+70587800926"}
0005434081736	E21177	5710 447161	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova1969@postgrespro.ru", "phone": "+70962883660"}
0005434081737	E21177	3128 826466	NADEZHDA BELOVA	{"phone": "+70930275437"}
0005434081738	B35EC8	6862 258579	RAVIL BONDARENKO	{"email": "ravilbondarenko_25071973@postgrespro.ru", "phone": "+70813275359"}
0005434081739	5C6823	1874 679939	STANISLAV MAKAROV	{"phone": "+70851225836"}
0005434081740	71E981	7967 691630	ALINA MIKHAYLOVA	{"email": "amikhaylova_19061973@postgrespro.ru", "phone": "+70856174465"}
0005434081741	E5C75F	9715 406666	PAVEL FROLOV	{"phone": "+70489364831"}
0005434081742	8B4575	3688 021575	ANATOLIY VOROBEV	{"email": "anatoliy_vorobev-011972@postgrespro.ru", "phone": "+70387068178"}
0005434081743	4C60FE	2167 269113	NADEZHDA NESTEROVA	{"email": "nesterova_n.18121973@postgrespro.ru", "phone": "+70325809173"}
0005434081744	633DA4	0778 547582	EKATERINA ILINA	{"phone": "+70212480207"}
0005434081745	472AF2	9855 666372	ALEKSEY STEPANOV	{"email": "stepanov-aleksey.1972@postgrespro.ru", "phone": "+70591054569"}
0005434081746	176E55	4674 073897	VLADIMIR BORISOV	{"phone": "+70580366932"}
0005434081747	176E55	1240 477631	ALEKSANDR VASILEV	{"email": "a_vasilev-06071977@postgrespro.ru", "phone": "+70542474415"}
0005434081748	7AE8C6	4999 631423	PETR POPOV	{"phone": "+70598102090"}
0005434081749	1A7B0D	4881 439317	OLGA KUZNECOVA	{"phone": "+70197079056"}
0005434081750	AC630B	5193 763852	LYUBOV VOLKOVA	{"email": "volkova.lyubov_17021988@postgrespro.ru", "phone": "+70052897587"}
0005434081751	AC630B	3768 906472	SERGEY SOROKIN	{"phone": "+70960365086"}
0005434081752	DF12AE	4014 524627	ALEKSANDR MIRONOV	{"email": "a-mironov1972@postgrespro.ru", "phone": "+70065212872"}
0005434081753	8A491D	5957 874391	EVGENIY BORISOV	{"phone": "+70070920843"}
0005434081754	8A491D	9300 005124	KIRILL MAKAROV	{"email": "kirill.makarov1978@postgrespro.ru", "phone": "+70484966863"}
0005434081755	8A491D	3704 460221	IREK MAKSIMOV	{"phone": "+70366687877"}
0005434081756	4AECCF	5600 419508	DIANA KOROLEVA	{"email": "korolevadiana-051975@postgrespro.ru", "phone": "+70858214345"}
0005434081757	CC3A2B	2230 699864	MIKHAIL VASILEV	{"phone": "+70862194997"}
0005434081758	06DDB5	9212 531795	SERGEY ZAYCEV	{"phone": "+70161305417"}
0005434081759	90A9D7	7070 443825	OLGA SEMENOVA	{"email": "olga.semenova-121981@postgrespro.ru", "phone": "+70982689566"}
0005434081760	90A9D7	0417 575874	EKATERINA IVANOVA	{"email": "ivanova-ekaterina.1977@postgrespro.ru", "phone": "+70670174088"}
0005434081761	90A9D7	8872 164334	VASILIY FEDOROV	{"email": "v.fedorov_031984@postgrespro.ru", "phone": "+70452654857"}
0005434081762	25EE16	7448 482405	EVGENIYA FROLOVA	{"phone": "+70448649692"}
0005434081763	25EE16	3183 101562	IRINA DENISOVA	{"email": "denisova-irina_29031988@postgrespro.ru", "phone": "+70449256183"}
0005434081764	02AB71	6045 234373	SVETLANA KAZAKOVA	{"email": "s_kazakova.1987@postgrespro.ru", "phone": "+70501629366"}
0005434081765	C4DEC1	6383 435822	IRINA BELOVA	{"email": "irina-belova1974@postgrespro.ru", "phone": "+70230003560"}
0005434081766	C4DEC1	1198 885997	KSENIYA MAKAROVA	{"email": "k.makarova-1970@postgrespro.ru", "phone": "+70287839233"}
0005434081767	6AB677	7047 729769	VLADIMIR ABRAMOV	{"email": "v_abramov051982@postgrespro.ru", "phone": "+70794276587"}
0005434081768	7A0E52	4115 971455	LEONID FROLOV	{"phone": "+70853705713"}
0005434081769	8190C3	8313 131269	OLGA SEMENOVA	{"email": "o-semenova.101974@postgrespro.ru", "phone": "+70330812648"}
0005434081770	C14506	5252 175629	VALENTINA MAKSIMOVA	{"email": "valentina-maksimova_071972@postgrespro.ru", "phone": "+70546982748"}
0005434081771	7B98BD	8510 032692	YULIYA KUZMINA	{"phone": "+70162198129"}
0005434081772	21AF01	7224 637870	NADEZHDA SCHERBAKOVA	{"phone": "+70535733926"}
0005434081773	21AF01	9486 075029	SVETLANA KOROLEVA	{"email": "svetlana.koroleva1976@postgrespro.ru", "phone": "+70555804393"}
0005434081774	299692	8073 720529	SVETLANA OSIPOVA	{"email": "osipovas.24081960@postgrespro.ru", "phone": "+70594596792"}
0005434081775	29C1C2	4000 941199	MIKHAIL ILIN	{"phone": "+70203925458"}
0005434081776	29C1C2	5730 795182	EGOR PETROV	{"email": "petrov-e-101976@postgrespro.ru", "phone": "+70313972937"}
0005434081777	16D4E0	3943 246781	YULIYA KUZNECOVA	{"email": "yuliya_kuznecova.1967@postgrespro.ru", "phone": "+70920191426"}
0005434081778	3F6E43	3692 225705	VALENTIN ROMANOV	{"email": "valentin.romanov09061975@postgrespro.ru", "phone": "+70236850594"}
0005434081779	AD3095	3410 721522	VALENTINA AKIMOVA	{"email": "v_akimova.1975@postgrespro.ru", "phone": "+70491235850"}
0005434081780	AD3095	4612 935054	ALEKSANDR SOKOLOV	{"email": "sokolov.a-121969@postgrespro.ru", "phone": "+70996287844"}
0005434081781	40D0DF	5869 875207	ANATOLIY PETROV	{"phone": "+70766783258"}
0005434081782	416E2C	6409 295319	ELENA KOMAROVA	{"phone": "+70838912054"}
0005434081783	E8536F	2171 378034	VYACHESLAV BORISOV	{"phone": "+70226493816"}
0005434081784	E8536F	7114 986701	EVGENIYA SOROKINA	{"email": "evgeniya_sorokina021981@postgrespro.ru", "phone": "+70884166390"}
0005434081785	070EDA	2916 407665	PAVEL IVANOV	{"phone": "+70748561011"}
0005434081786	070EDA	7734 326572	ALEKSEY ROMANOV	{"phone": "+70737220423"}
0005434081787	633BEE	1419 233092	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr_18061955@postgrespro.ru", "phone": "+70595467151"}
0005434081788	6348F9	7614 300634	NIKOLAY KUZMIN	{"phone": "+70561239250"}
0005434081789	6348F9	4047 759524	RUSLAN MIRONOV	{"phone": "+70163061661"}
0005434081790	B95A6C	1183 896281	ARTEM BORISOV	{"email": "borisov_artem_11071972@postgrespro.ru", "phone": "+70369621010"}
0005434081791	E1FE8B	6419 349633	BORIS PETROV	{"phone": "+70095061562"}
0005434081792	87E159	3575 521698	ANDREY DMITRIEV	{"phone": "+70409479768"}
0005434081793	87E159	5794 955769	ARTUR ANTONOV	{"email": "antonovartur.101971@postgrespro.ru", "phone": "+70287654340"}
0005434081794	B906B4	3961 732831	IRINA NIKOLAEVA	{"phone": "+70334093782"}
0005434081795	EAE681	0828 686389	EVGENIYA IVANOVA	{"email": "evgeniyaivanova.13091976@postgrespro.ru", "phone": "+70728653654"}
0005434081796	954813	3790 687192	VLADIMIR NOVIKOV	{"phone": "+70509110852"}
0005434081797	23CDC5	8477 130529	ANDREY SEMENOV	{"email": "a_semenov_041977@postgrespro.ru", "phone": "+70799350270"}
0005434081798	C99BB4	6184 542998	SERGEY BONDARENKO	{"phone": "+70634392599"}
0005434081799	817D5A	8966 538931	MARINA ANISIMOVA	{"email": "m-anisimova_061976@postgrespro.ru", "phone": "+70600875279"}
0005434081800	C96367	4907 506252	NIKITA NIKITIN	{"phone": "+70390314431"}
0005434081801	C96367	7604 423966	VALENTINA KRASNOVA	{"phone": "+70327613169"}
0005434081802	8928A3	2331 217651	VLADIMIR TIKHONOV	{"email": "vtikhonov111963@postgrespro.ru", "phone": "+70565530448"}
0005434081803	8928A3	6320 897890	NADEZHDA TARASOVA	{"email": "nadezhda_tarasova021970@postgrespro.ru", "phone": "+70693774709"}
0005434081804	826576	9406 247136	LIDIYA FROLOVA	{"email": "frolova_l04031966@postgrespro.ru", "phone": "+70005469548"}
0005434081805	826576	3488 501760	OLEG NAZAROV	{"phone": "+70379601088"}
0005434081806	FF1C1B	7976 969932	GENNADIY STEPANOV	{"email": "gennadiy.stepanov-1966@postgrespro.ru", "phone": "+70511813449"}
0005434081807	5B3B24	6862 368049	EDUARD KUZNECOV	{"email": "eduard.kuznecov.1969@postgrespro.ru", "phone": "+70368922315"}
0005434081808	5B3B24	4528 073435	RAMIL ABRAMOV	{"email": "r.abramov_021972@postgrespro.ru", "phone": "+70275639753"}
0005434081809	5B3B24	2058 864078	LYUDMILA GAVRILOVA	{"phone": "+70179230070"}
0005434081810	7D76F1	5433 915542	MARIYA MIRONOVA	{"phone": "+70288094012"}
0005434081811	BD88E6	8588 466216	ALEKSANDRA ZHUKOVA	{"phone": "+70952156488"}
0005434081812	BD88E6	2069 968757	VLADIMIR TIKHONOV	{"phone": "+70679673371"}
0005434081813	D7A8B9	2002 666915	SVETLANA VLASOVA	{"phone": "+70802386992"}
0005434081814	D7A8B9	5098 742547	IRINA LOGINOVA	{"phone": "+70535152536"}
0005434081815	27F893	9191 144137	YURIY KUZNECOV	{"phone": "+70931434945"}
0005434081816	8B3115	2863 601141	LIDIYA YUDINA	{"email": "l_yudina14041979@postgrespro.ru", "phone": "+70401221924"}
0005434081817	8B3115	1308 188166	NADEZHDA KUZNECOVA	{"phone": "+70591420867"}
0005434081818	C5E91C	6218 979732	DANIS ABRAMOV	{"phone": "+70863144394"}
0005434081819	515D18	9745 415905	ALEKSANDR IVANOV	{"phone": "+70532958352"}
0005434081820	1B24A0	9100 226159	NATALYA ANDREEVA	{"email": "natalya-andreeva21091989@postgrespro.ru", "phone": "+70093819974"}
0005434081821	C9830E	4932 001540	ANDREY ZHUKOV	{"phone": "+70252563990"}
0005434081822	E48791	2929 619943	MIKHAIL KUZNECOV	{"email": "kuznecov-m-15031977@postgrespro.ru", "phone": "+70460732446"}
0005434081823	9D29FF	0610 003983	ANDREY MELNIKOV	{"phone": "+70891858449"}
0005434081824	CABCEB	4217 935481	ANNA IVANOVA	{"phone": "+70970379428"}
0005434081825	CABCEB	2603 779683	LYUBOV VLASOVA	{"phone": "+70835999164"}
0005434081826	F19F06	7765 457912	VIKTOR MIKHAYLOV	{"email": "mikhaylov-v23091968@postgrespro.ru", "phone": "+70393988974"}
0005434081827	D5E076	7976 969111	VERA CHERNOVA	{"phone": "+70847892722"}
0005434081828	02E929	6042 207697	ANTON ORLOV	{"email": "anton.orlov_28091971@postgrespro.ru", "phone": "+70610818383"}
0005434081829	37A25D	4727 056079	ELDAR MATVEEV	{"email": "eldarmatveev1966@postgrespro.ru", "phone": "+70483602488"}
0005434081830	37A25D	3945 988775	LYUDMILA MATVEEVA	{"email": "matveeva-l_121969@postgrespro.ru", "phone": "+70381868613"}
0005434081831	4C7DD7	8991 355352	IVAN ALEKSEEV	{"phone": "+70889176470"}
0005434081832	0EF62E	8337 491394	NATALYA ALEKSANDROVA	{"email": "aleksandrovanatalya-061971@postgrespro.ru", "phone": "+70170561144"}
0005434081833	0EF62E	8025 629555	SERGEY DAVYDOV	{"email": "davydov_s-15041967@postgrespro.ru", "phone": "+70095231974"}
0005434081834	824487	3456 012978	ANATOLIY GORBUNOV	{"email": "gorbunov-anatoliy-011962@postgrespro.ru", "phone": "+70175824832"}
0005434081835	3BAA7C	1375 536690	TATYANA KAZAKOVA	{"phone": "+70003853049"}
0005434081836	5D5AD1	2654 511187	MAKSIM BARANOV	{"phone": "+70926424726"}
0005434081837	F5F1BC	0037 551508	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov-1966@postgrespro.ru", "phone": "+70266274553"}
0005434082173	14365A	4525 637812	VALENTINA DENISOVA	{"phone": "+70484537213"}
0005434081838	C02C0D	3577 731766	MARIYA TROFIMOVA	{"email": "m-trofimova05011968@postgrespro.ru", "phone": "+70641200146"}
0005434081839	09B5F4	5277 006464	EKATERINA DMITRIEVA	{"phone": "+70974349995"}
0005434081840	85E910	5422 224837	ANDREY FOMIN	{"phone": "+70496914850"}
0005434081841	79AF93	0851 134903	ANNA ANTONOVA	{"phone": "+70442936215"}
0005434081842	F93CB0	0285 419473	NATALYA SOROKINA	{"email": "sorokinanatalya.05041981@postgrespro.ru", "phone": "+70897564856"}
0005434081843	F93CB0	1888 699142	NIKOLAY IVANOV	{"phone": "+70392120173"}
0005434081844	F9EF78	3675 510528	NATALYA MEDVEDEVA	{"email": "n-medvedeva.23111967@postgrespro.ru", "phone": "+70082051301"}
0005434081845	7BD969	2498 348950	ROMAN ROMANOV	{"phone": "+70388437765"}
0005434081846	2E98FE	9958 365301	NIKITA AFANASEV	{"email": "afanasev_nikita.13091967@postgrespro.ru", "phone": "+70082411593"}
0005434081847	2E98FE	9027 714743	RINAT NAZAROV	{"phone": "+70072764740"}
0005434081848	73A067	9836 489958	VALENTINA ILINA	{"email": "valentinailina101968@postgrespro.ru", "phone": "+70541948516"}
0005434081849	8E6F68	5358 051952	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov24081965@postgrespro.ru", "phone": "+70360370936"}
0005434081850	8E6F68	1770 698603	YULIYA ROMANOVA	{"phone": "+70293675901"}
0005434081851	8E6F68	1043 780395	ALEKSEY KRASNOV	{"phone": "+70183689130"}
0005434081852	9E9916	1899 757242	ARTEM KRASNOV	{"email": "krasnov.a-091959@postgrespro.ru", "phone": "+70916098715"}
0005434081853	9E9916	0022 801671	NADEZHDA STEPANOVA	{"email": "stepanovan-1976@postgrespro.ru", "phone": "+70022000327"}
0005434081854	C66EEC	1585 426385	LYUDMILA DMITRIEVA	{"email": "dmitrieva.l-25071976@postgrespro.ru", "phone": "+70841348995"}
0005434081855	0897B4	4946 501307	NADEZHDA TARASOVA	{"email": "tarasova-nadezhda-17051967@postgrespro.ru", "phone": "+70237364944"}
0005434081856	0897B4	4352 619378	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov22091967@postgrespro.ru", "phone": "+70467336008"}
0005434081857	12651D	5938 253683	MARINA PAVLOVA	{"email": "pavlovamarina081969@postgrespro.ru", "phone": "+70755802599"}
0005434081858	12651D	5552 319208	SERGEY ZAKHAROV	{"email": "zakharov_sergey051973@postgrespro.ru", "phone": "+70883343873"}
0005434081859	8BD8DF	6159 575139	SERGEY MIRONOV	{"phone": "+70494333493"}
0005434081860	AB4B15	9079 369608	ALEKSANDR TIMOFEEV	{"email": "aleksandr_timofeev-05121969@postgrespro.ru", "phone": "+70545708269"}
0005434081861	AB4B15	9639 695755	ELENA KOROLEVA	{"phone": "+70788655925"}
0005434081862	AB48F7	9232 929491	TATYANA ANDREEVA	{"email": "andreeva.tatyana28021969@postgrespro.ru", "phone": "+70310723395"}
0005434081863	E971FD	0711 672073	ANASTASIYA MARTYNOVA	{"email": "martynovaa-1970@postgrespro.ru", "phone": "+70316236747"}
0005434081864	B6F8C2	0231 036196	STEPAN ORLOV	{"email": "stepanorlov08091976@postgrespro.ru", "phone": "+70979789193"}
0005434081865	AD720C	1552 869957	GENNADIY ZAYCEV	{"email": "zaycev-g12091962@postgrespro.ru", "phone": "+70795259821"}
0005434081866	AD720C	9890 345822	SVETLANA KOMAROVA	{"email": "komarova.s.021973@postgrespro.ru", "phone": "+70326771389"}
0005434081867	57AEBE	3789 000233	VALENTINA PAVLOVA	{"phone": "+70845413768"}
0005434081868	85F271	1792 895830	ANASTASIYA KARPOVA	{"phone": "+70662072239"}
0005434081869	47A8E4	8319 604677	VYACHESLAV RODIONOV	{"email": "rodionovvyacheslav.111980@postgrespro.ru", "phone": "+70416781308"}
0005434081870	3DC086	6900 549750	VIKTOR GUSEV	{"email": "viktor_gusev.1970@postgrespro.ru", "phone": "+70327232297"}
0005434081871	3DC086	0022 728502	VIOLETTA FADEEVA	{"email": "fadeeva-v021976@postgrespro.ru", "phone": "+70175028254"}
0005434081872	E5306A	1324 726489	EKATERINA KULIKOVA	{"phone": "+70443946260"}
0005434081873	E5306A	3804 863075	TAMARA SAVELEVA	{"email": "t_saveleva-021972@postgrespro.ru", "phone": "+70776439416"}
0005434081874	27DE47	5420 416539	SVETLANA LOGINOVA	{"phone": "+70017489819"}
0005434081875	27DE47	0035 094881	KONSTANTIN VOLKOV	{"phone": "+70744465238"}
0005434082238	09D9D6	4706 621606	YULIYA ERMAKOVA	{"phone": "+70471848498"}
0005434081876	CD6D39	0678 584557	NINA KOROLEVA	{"email": "korolevanina1965@postgrespro.ru", "phone": "+70950160420"}
0005434081877	CD6D39	9650 322221	ALEFTINA EGOROVA	{"phone": "+70729399448"}
0005434081878	CEA2CE	6393 847513	ALEKSEY ISAEV	{"phone": "+70753420130"}
0005434081879	CEA2CE	7212 886999	VIKTORIYA KISELEVA	{"phone": "+70122976131"}
0005434081880	860638	1054 182424	NADEZHDA VOLKOVA	{"phone": "+70094070817"}
0005434081881	1025CB	9760 123727	ALINA IVANOVA	{"phone": "+70329440410"}
0005434081882	442543	7477 587215	PAVEL VLASOV	{"phone": "+70524114478"}
0005434081883	0A2635	6504 560798	DMITRIY CHERNOV	{"phone": "+70846948916"}
0005434081884	5AC13B	4816 335541	ALEKSANDR KAZAKOV	{"email": "a.kazakov.111960@postgrespro.ru", "phone": "+70569432158"}
0005434081885	5AC13B	0671 590977	ANDREY MELNIKOV	{"phone": "+70112382602"}
0005434081886	9645D1	1976 037557	DENIS GRIGOREV	{"email": "grigorev_denis.29061970@postgrespro.ru", "phone": "+70678713223"}
0005434081887	95A268	3374 043891	SVETLANA MASLOVA	{"phone": "+70296964817"}
0005434081888	95A268	9914 237667	SERGEY NIKOLAEV	{"email": "nikolaevsergey.05031974@postgrespro.ru", "phone": "+70596369764"}
0005434081889	DF9ADF	2106 126225	TATYANA ROMANOVA	{"email": "t-romanova_101977@postgrespro.ru", "phone": "+70980581638"}
0005434081890	DF9ADF	9246 369765	VITALIY GORBUNOV	{"email": "vitaliy-gorbunov05041972@postgrespro.ru", "phone": "+70378188022"}
0005434081891	D69BE9	3410 408098	EVGENIY ANDREEV	{"phone": "+70939779534"}
0005434081892	0C7842	7845 792948	ARSENIY ANTONOV	{"email": "antonov_arseniy.051980@postgrespro.ru", "phone": "+70739660881"}
0005434081893	0C7842	6851 998689	OLGA LEBEDEVA	{"email": "lebedeva-o1963@postgrespro.ru", "phone": "+70486309722"}
0005434081894	0C7842	5236 581295	VALENTINA SIDOROVA	{"email": "sidorova-v_1964@postgrespro.ru", "phone": "+70794912347"}
0005434081895	835440	2286 205543	OLGA SOKOLOVA	{"email": "o-sokolova_1960@postgrespro.ru", "phone": "+70523291655"}
0005434081896	3DA699	6228 986434	ALEKSANDR VLASOV	{"phone": "+70467898982"}
0005434081897	BC90F1	6904 977084	TATYANA KUZNECOVA	{"email": "kuznecova_t.21061974@postgrespro.ru", "phone": "+70677040133"}
0005434081898	9B9DE3	8287 624026	NINA ILINA	{"phone": "+70710814965"}
0005434081899	D434C8	2377 152114	LYUBOV MELNIKOVA	{"email": "melnikova-l011978@postgrespro.ru", "phone": "+70442944478"}
0005434081900	75B43B	9826 087930	DENIS MEDVEDEV	{"phone": "+70463342609"}
0005434081901	9FD795	6084 073415	ANNA RODIONOVA	{"phone": "+70500163586"}
0005434081902	00DC56	2383 893996	SERGEY ZAYCEV	{"email": "zaycevsergey071974@postgrespro.ru", "phone": "+70311608031"}
0005434081903	D0F8AB	1253 945584	NATALYA KUZNECOVA	{"phone": "+70677322068"}
0005434081904	97D282	8392 355752	TATYANA NAZAROVA	{"email": "t_nazarova19031980@postgrespro.ru", "phone": "+70738845771"}
0005434081905	322ECD	5188 435206	ANNA SERGEEVA	{"phone": "+70173431629"}
0005434081906	322ECD	5076 397682	ANDREY SCHERBAKOV	{"email": "scherbakov.a.091970@postgrespro.ru", "phone": "+70129681000"}
0005434081907	491004	9602 757754	ALEKSEY YAKOVLEV	{"phone": "+70109742823"}
0005434081908	7240D7	3409 741774	MIKHAIL NIKOLAEV	{"phone": "+70683004197"}
0005434081909	7240D7	1601 450540	DENIS GORBUNOV	{"email": "denis-gorbunov_1982@postgrespro.ru", "phone": "+70950932369"}
0005434081910	5E1E4F	3805 048886	GALINA ANISIMOVA	{"email": "anisimova-galina.081969@postgrespro.ru", "phone": "+70469271676"}
0005434081911	5E1E4F	1287 174162	ALEKSANDR TIMOFEEV	{"email": "timofeevaleksandr-27041968@postgrespro.ru", "phone": "+70018657811"}
0005434081912	89916D	2829 649771	MARIYA KOROLEVA	{"email": "mariya.koroleva-27031966@postgrespro.ru", "phone": "+70260679797"}
0005434081913	4F9E06	1697 184908	RIMMA GERASIMOVA	{"phone": "+70050768247"}
0005434081914	40BFDF	8141 810259	IVAN ALEKSANDROV	{"phone": "+70646970199"}
0005434081915	0621A3	5057 336828	NINA FROLOVA	{"email": "frolova_n.15021968@postgrespro.ru", "phone": "+70480987083"}
0005434081916	350208	0250 887048	PAVEL NAUMOV	{"email": "naumov.pavel-051972@postgrespro.ru", "phone": "+70067638442"}
0005434081917	24ADD3	3608 050686	PETR FEDOTOV	{"email": "fedotovp.1971@postgrespro.ru", "phone": "+70646566957"}
0005434081918	347BD3	5241 186321	MADINA FEDOROVA	{"phone": "+70000399483"}
0005434081919	39951C	3462 627643	VLADIMIR MOROZOV	{"phone": "+70978072582"}
0005434081920	11B1F3	2142 540703	DARYA LEBEDEVA	{"phone": "+70962145591"}
0005434081921	BB9F7E	7579 711197	ALEKSANDRA BORISOVA	{"email": "borisova_a-061971@postgrespro.ru", "phone": "+70644162294"}
0005434081922	54801D	6088 911060	ALEKSEY ROMANOV	{"email": "aleksey-romanov.051968@postgrespro.ru", "phone": "+70710908813"}
0005434081923	9596A5	9484 054391	YURIY ZAYCEV	{"phone": "+70291180994"}
0005434081924	06078C	1338 060963	FEDOR FOMIN	{"email": "fedor_fomin_1967@postgrespro.ru", "phone": "+70514251105"}
0005434081925	A11411	4341 570769	VALENTIN ISAEV	{"email": "visaev_15051972@postgrespro.ru", "phone": "+70971220432"}
0005434081926	5C2864	8503 452717	MARINA GORBUNOVA	{"phone": "+70318412985"}
0005434081927	3FBFDB	8416 786646	LYUBOV FROLOVA	{"phone": "+70619171730"}
0005434081928	3FBFDB	8115 449862	MARINA ZHUKOVA	{"email": "zhukova_m.18091969@postgrespro.ru", "phone": "+70102529820"}
0005434081929	F92694	9108 606350	IGOR NOVIKOV	{"phone": "+70877966633"}
0005434081930	F92694	9695 606863	SVETLANA TIKHONOVA	{"email": "svetlana.tikhonova.23061972@postgrespro.ru", "phone": "+70411855235"}
0005434081931	75C32C	0410 454189	OLGA KOLESNIKOVA	{"phone": "+70750159326"}
0005434081932	AE4344	3829 741904	EKATERINA KUZNECOVA	{"email": "kuznecova.e-31071967@postgrespro.ru", "phone": "+70543329711"}
0005434081933	611F66	5408 403710	GALINA NIKITINA	{"phone": "+70246697669"}
0005434081934	29FE13	5438 146673	ALEKSANDR SOLOVEV	{"email": "a-solovev-1972@postgrespro.ru", "phone": "+70210213972"}
0005434081935	9262C4	4544 147511	OKSANA POPOVA	{"phone": "+70097136939"}
0005434081936	74E57E	2372 331685	IRINA KOZLOVA	{"email": "kozlova_i_1967@postgrespro.ru", "phone": "+70442336843"}
0005434081937	03C99D	7989 632592	FARIDA NOVIKOVA	{"email": "faridanovikova011978@postgrespro.ru", "phone": "+70544843284"}
0005434081938	01025C	2278 290967	NATALYA IVANOVA	{"email": "natalya-ivanova1978@postgrespro.ru", "phone": "+70052519939"}
0005434081939	94642A	7090 510447	ALSU KARPOVA	{"phone": "+70715810277"}
0005434081940	3A92BA	7355 072528	SERGEY ANTONOV	{"phone": "+70816482905"}
0005434081941	80E6E7	9843 414623	ALEKSANDR ANTONOV	{"phone": "+70283099885"}
0005434081942	2B7A65	8499 950279	NINA ZHUKOVA	{"phone": "+70241664925"}
0005434081943	EA26AA	8925 067958	RAUF VOROBEV	{"email": "raufvorobev-1977@postgrespro.ru", "phone": "+70338134280"}
0005434081944	73770B	9821 889968	ANASTASIYA SMIRNOVA	{"phone": "+70877850559"}
0005434081945	A90BC7	4615 997527	ZOYA EFIMOVA	{"phone": "+70081645279"}
0005434081946	A90BC7	1956 878350	DMITRIY DMITRIEV	{"phone": "+70869427667"}
0005434081947	240282	7799 746682	FEDOR PETROV	{"phone": "+70500591648"}
0005434081948	42AABB	2341 742499	TATYANA ZHURAVLEVA	{"email": "t_zhuravleva_04111963@postgrespro.ru", "phone": "+70574540400"}
0005434082286	5A9FE5	0814 249043	TATYANA MALYSHEVA	{"phone": "+70826772525"}
0005434081949	64D086	1249 496580	SVETLANA ZOTOVA	{"email": "szotova_09121976@postgrespro.ru", "phone": "+70770186088"}
0005434081950	8991AB	9379 917158	ALENA KONOVALOVA	{"phone": "+70193123134"}
0005434081951	8991AB	2909 244584	YURIY ISAEV	{"phone": "+70744820857"}
0005434081952	76D192	9009 073620	BORIS IVANOV	{"email": "boris_ivanov101971@postgrespro.ru", "phone": "+70198066533"}
0005434081953	76D192	3097 116257	ALBERT GAVRILOV	{"email": "a.gavrilov-22121959@postgrespro.ru", "phone": "+70148119228"}
0005434081954	B041C9	9800 255394	ALEVTINA BOGDANOVA	{"phone": "+70352649378"}
0005434081955	B041C9	0630 221587	KONSTANTIN MOROZOV	{"phone": "+70581125341"}
0005434081956	010925	3453 997742	DMITRIY CHERNOV	{"phone": "+70241008765"}
0005434081957	FE51B4	6653 093660	SERGEY DMITRIEV	{"email": "sergey-dmitriev14101975@postgrespro.ru", "phone": "+70111653392"}
0005434081958	39D6EA	4308 519860	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov_1962@postgrespro.ru", "phone": "+70039517713"}
0005434081959	E685AB	5468 716271	ELENA FILIPPOVA	{"phone": "+70295884719"}
0005434081960	538601	3507 586946	OLGA PAVLOVA	{"email": "o.pavlova101974@postgrespro.ru", "phone": "+70916810841"}
0005434081961	1C8080	8580 460331	FATIMA YAKOVLEVA	{"email": "yakovleva-f_1968@postgrespro.ru", "phone": "+70335242281"}
0005434081962	4008CD	5120 116342	LEONID ZAKHAROV	{"phone": "+70760016620"}
0005434081963	99C6E6	9793 370763	NATALYA PAVLOVA	{"email": "pavlova.natalya_1988@postgrespro.ru", "phone": "+70356115755"}
0005434081964	99C6E6	5091 294426	DMITRIY ZAYCEV	{"phone": "+70382486967"}
0005434081965	4D60A5	4491 142050	OLGA NESTEROVA	{"email": "nesterovaolga.101977@postgrespro.ru", "phone": "+70920320657"}
0005434081966	E9C4C7	8095 652007	ILYA SHEVCHENKO	{"phone": "+70737786323"}
0005434081967	E9C4C7	3956 324323	SERGEY FILIPPOV	{"phone": "+70981840136"}
0005434081968	F3AEFE	8960 343399	DARINA GUSEVA	{"phone": "+70893306325"}
0005434081969	F3AEFE	3725 357871	MARINA SOROKINA	{"email": "marina_sorokina.20101976@postgrespro.ru", "phone": "+70540774701"}
0005434081970	656D27	9810 824901	VIKTOR ANDREEV	{"email": "viktor.andreev.081966@postgrespro.ru", "phone": "+70750740915"}
0005434081971	46BF01	4601 434671	NINA VOROBEVA	{"phone": "+70069995783"}
0005434081972	AFCF3D	0305 307537	TATYANA NOVIKOVA	{"phone": "+70580667117"}
0005434081973	BA3662	6140 164123	VLADIMIR PETROV	{"phone": "+70731157600"}
0005434081974	1A973E	6602 269830	ALENA SERGEEVA	{"phone": "+70802127548"}
0005434081975	188009	9622 055237	EKATERINA SERGEEVA	{"phone": "+70485100945"}
0005434081976	AF1ACA	9401 362841	DMITRIY SIDOROV	{"email": "dmitriy.sidorov.1970@postgrespro.ru", "phone": "+70218098616"}
0005434081977	46E530	3852 066436	ANTONINA PETROVA	{"phone": "+70558711725"}
0005434081978	369C8A	4724 305645	KIRILL TIKHONOV	{"email": "tikhonov_kirill-13111971@postgrespro.ru", "phone": "+70775749112"}
0005434081979	BD85FF	9515 072968	NIKOLAY ANDREEV	{"phone": "+70177561138"}
0005434081980	BD85FF	0373 061416	IRINA PETROVA	{"phone": "+70715161959"}
0005434081981	D3469E	4450 996215	VLADIMIR SIDOROV	{"phone": "+70117727972"}
0005434081982	6A332D	8879 501820	SERGEY VLASOV	{"phone": "+70559897185"}
0005434081983	3CFCDD	3557 788927	IVAN MAKSIMOV	{"phone": "+70494570507"}
0005434081984	76BB0A	9745 950795	DMITRIY VASILEV	{"phone": "+70498582824"}
0005434081985	59CFBD	1710 050035	NATALYA IVANOVA	{"phone": "+70728425676"}
0005434081986	59CFBD	3166 309558	GLEB ZAYCEV	{"phone": "+70244004644"}
0005434081987	59CFBD	6545 527880	NIKITA EGOROV	{"phone": "+70557035328"}
0005434081988	0F59A7	9404 878687	EVGENIY ORLOV	{"email": "evgeniy_orlov091964@postgrespro.ru", "phone": "+70702770445"}
0005434081989	748C99	8034 063545	RAISA FEDOROVA	{"email": "fedorova.raisa-30091965@postgrespro.ru", "phone": "+70369054689"}
0005434081990	748C99	4107 501169	VIKTORIYA KUDRYASHOVA	{"email": "kudryashovaviktoriya.041977@postgrespro.ru", "phone": "+70569132007"}
0005434081991	E38FCF	0890 660098	ELIZAVETA NESTEROVA	{"phone": "+70855334069"}
0005434081992	CC5B1B	0961 821246	VLADA YAKOVLEVA	{"phone": "+70354826222"}
0005434081993	6398B7	4741 580569	NIKOLAY PETROV	{"email": "nikolaypetrov_1977@postgrespro.ru", "phone": "+70688142596"}
0005434081994	B4234D	6019 112656	LEONID KOZLOV	{"email": "kozlov.l-1971@postgrespro.ru", "phone": "+70421869591"}
0005434081995	B4234D	9360 908702	ALEKSANDR VLASOV	{"email": "vlasov-a.14101972@postgrespro.ru", "phone": "+70833654960"}
0005434081996	B3AA5C	1393 181417	ALEKSANDR FEDOTOV	{"phone": "+70765334405"}
0005434081997	784A05	5847 075270	TATYANA NIKITINA	{"phone": "+70938823243"}
0005434081998	F11153	5143 870433	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin_061972@postgrespro.ru", "phone": "+70146873296"}
0005434081999	F11153	3272 812222	VLADIMIR TARASOV	{"email": "vladimir.tarasov22081969@postgrespro.ru", "phone": "+70924383905"}
0005434082000	0C51D7	5336 180358	GALINA BELOVA	{"phone": "+70159632134"}
0005434082001	328BF7	9045 182697	DMITRIY IVANOV	{"phone": "+70740104842"}
0005434082002	8BD6F3	1074 172220	ARTEM MATVEEV	{"email": "matveev.a.01011978@postgrespro.ru", "phone": "+70153887834"}
0005434082003	8BD6F3	4943 787245	ALENA MIRONOVA	{"phone": "+70807693024"}
0005434082004	21C03E	9201 480470	YULIYA KUZMINA	{"email": "kuzminayuliya-07111969@postgrespro.ru", "phone": "+70740902444"}
0005434082005	84329A	2153 100569	VITALIY FEDOROV	{"email": "fedorov_vitaliy_1966@postgrespro.ru", "phone": "+70742519965"}
0005434082006	84329A	1313 860321	TATYANA LOGINOVA	{"email": "loginova.tatyana_20101962@postgrespro.ru", "phone": "+70947061442"}
0005434082007	81179D	0699 927823	KRISTINA NIKOLAEVA	{"email": "knikolaeva_15081973@postgrespro.ru", "phone": "+70718891722"}
0005434082008	FDF145	8787 670821	NATALYA BOGDANOVA	{"phone": "+70537575069"}
0005434082009	EA9F6A	9017 840491	SERGEY KULIKOV	{"email": "s-kulikov_101977@postgrespro.ru", "phone": "+70745144552"}
0005434082010	3CCCC8	1117 441964	NADEZHDA PETROVA	{"email": "nadezhda_petrova.011977@postgrespro.ru", "phone": "+70940209763"}
0005434082011	2B5CB6	6295 007217	VLADIMIR BONDARENKO	{"email": "v_bondarenko-04041966@postgrespro.ru", "phone": "+70105352220"}
0005434082012	B2D5D3	8097 795133	VIKTOR EGOROV	{"phone": "+70684659444"}
0005434082013	160C42	4712 328186	ARTEM VOROBEV	{"phone": "+70544574077"}
0005434082014	160C42	1677 088147	GENNADIY DENISOV	{"phone": "+70154993433"}
0005434082015	E26EA1	4858 283425	YURIY MARTYNOV	{"email": "martynov.yuriy-1975@postgrespro.ru", "phone": "+70471461317"}
0005434082016	E26EA1	5865 664975	ALEKSEY MEDVEDEV	{"email": "medvedevaleksey-1972@postgrespro.ru", "phone": "+70883211621"}
0005434082017	F6B5A9	4885 915988	ANZHELIKA FOMINA	{"phone": "+70435207263"}
0005434082018	ED2F25	4175 543538	MIKHAIL MIKHAYLOV	{"phone": "+70917140687"}
0005434082019	ED2F25	9141 343576	PETR BARANOV	{"email": "baranovpetr_1969@postgrespro.ru", "phone": "+70301843443"}
0005434082020	ED2F25	8928 813319	SOFYA ZAYCEVA	{"email": "s-zayceva.24011975@postgrespro.ru", "phone": "+70075197588"}
0005434082021	97F9E4	8150 696379	ALEKSANDR FROLOV	{"email": "aleksandrfrolov.1973@postgrespro.ru", "phone": "+70782103689"}
0005434082022	72C361	6649 903168	TAMARA NAUMOVA	{"phone": "+70013638195"}
0005434082023	72C361	7659 861529	IGOR MAKSIMOV	{"email": "igor-maksimov.101960@postgrespro.ru", "phone": "+70164529072"}
0005434082024	FFB8EE	9153 050639	VALERIY MAKAROV	{"phone": "+70623927305"}
0005434082025	FFB8EE	3530 121124	VALENTINA KUZNECOVA	{"phone": "+70213607259"}
0005434082026	58C97E	7954 055981	ANASTASIYA TIMOFEEVA	{"email": "anastasiya_timofeeva061963@postgrespro.ru", "phone": "+70488078983"}
0005434082027	58C97E	9874 697945	DMITRIY KONOVALOV	{"phone": "+70736708605"}
0005434082028	50A405	1073 453666	ELINA ROMANOVA	{"phone": "+70301618496"}
0005434082029	50A405	3834 440371	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov_1969@postgrespro.ru", "phone": "+70883610504"}
0005434082030	033B0C	4748 857483	MARIYA ILINA	{"email": "ilinamariya_031977@postgrespro.ru", "phone": "+70165912377"}
0005434082031	033B0C	3193 823407	ALEKSANDR PETROV	{"email": "apetrov-1965@postgrespro.ru", "phone": "+70173640900"}
0005434082032	ED6B2B	5865 802006	ANDREY IVANOV	{"email": "a_ivanov-091988@postgrespro.ru", "phone": "+70327323201"}
0005434082033	ED6B2B	7672 920279	DENIS OSIPOV	{"email": "osipov-denis_05021969@postgrespro.ru", "phone": "+70604261368"}
0005434082034	3ECD83	9494 354109	ANDREY KISELEV	{"email": "kiselev_andrey1983@postgrespro.ru", "phone": "+70769125707"}
0005434082035	3ECD83	2048 253476	MARIYA VOLKOVA	{"phone": "+70482027149"}
0005434082036	3ECD83	2220 881083	VALERIY ROMANOV	{"email": "romanov.valeriy-071984@postgrespro.ru", "phone": "+70100805286"}
0005434082037	3ECD83	5506 580062	MIKHAIL FEDOTOV	{"phone": "+70493262071"}
0005434082038	6EC443	7102 006102	ANNA GAVRILOVA	{"phone": "+70259886062"}
0005434082039	4E4888	6446 689592	EKATERINA IVANOVA	{"email": "ivanova-ekaterina-1962@postgrespro.ru", "phone": "+70119474438"}
0005434082040	4E4888	6274 813910	SERGEY SERGEEV	{"phone": "+70681658185"}
0005434082041	5DC7D9	1886 498497	NIKOLAY KARPOV	{"email": "n-karpov_061970@postgrespro.ru", "phone": "+70059436296"}
0005434082042	217F9D	9418 465981	TATYANA KUZNECOVA	{"phone": "+70712852885"}
0005434082043	8591E4	0307 676230	KLAVDIYA KUZNECOVA	{"email": "klavdiya.kuznecova.29091973@postgrespro.ru", "phone": "+70980775209"}
0005434082044	8591E4	7837 418687	EVGENIY KRASNOV	{"phone": "+70132652088"}
0005434082045	04E906	7446 959276	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a.011965@postgrespro.ru", "phone": "+70671893033"}
0005434082046	04E906	6137 418299	NATALYA KUDRYASHOVA	{"email": "nkudryashova.28051971@postgrespro.ru", "phone": "+70589411663"}
0005434082047	04E906	3246 443450	LYUDMILA KUDRYASHOVA	{"phone": "+70692224193"}
0005434082048	04E906	7324 104328	GULNARA MAKAROVA	{"email": "gulnara-makarova_1973@postgrespro.ru", "phone": "+70751736647"}
0005434082049	2A1856	6841 691734	GALINA KUDRYASHOVA	{"phone": "+70557355733"}
0005434082050	64FA49	7022 918597	LEONID BORISOV	{"email": "borisovl.031973@postgrespro.ru", "phone": "+70022168734"}
0005434082051	64FA49	1518 448405	ANASTASIYA YAKOVLEVA	{"phone": "+70315119277"}
0005434082052	6B7144	2286 344358	NATALYA BARANOVA	{"email": "natalya_baranova-1980@postgrespro.ru", "phone": "+70124371305"}
0005434082053	6B7144	6763 606948	ALEKSEY ZAYCEV	{"email": "azaycev1959@postgrespro.ru", "phone": "+70152359210"}
0005434082054	D0E4A3	4610 563488	PAVEL KULIKOV	{"email": "kulikov.p1968@postgrespro.ru", "phone": "+70254172202"}
0005434082055	3BD92E	8565 298685	NATALYA NOVIKOVA	{"email": "natalya_novikova.1973@postgrespro.ru", "phone": "+70629713805"}
0005434082056	D54552	7609 608192	FANIL TIKHONOV	{"email": "f-tikhonov07031975@postgrespro.ru", "phone": "+70142533669"}
0005434082057	D3C677	2548 818679	TATYANA MEDVEDEVA	{"email": "medvedeva-tatyana-1968@postgrespro.ru", "phone": "+70965793617"}
0005434082058	16CBFB	5685 944659	EKATERINA KONOVALOVA	{"email": "ekonovalova_07111970@postgrespro.ru", "phone": "+70073206296"}
0005434082059	FB5D47	1008 063002	ANNA KOROLEVA	{"phone": "+70914911866"}
0005434082060	FB5D47	0647 955722	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev031966@postgrespro.ru", "phone": "+70583800445"}
0005434082061	FB5D47	8033 037675	ANNA AFANASEVA	{"email": "afanaseva.anna1975@postgrespro.ru", "phone": "+70952151317"}
0005434082062	FB923B	1451 949083	ELENA ANDREEVA	{"phone": "+70884606623"}
0005434082063	CBED2E	2248 669819	FELIKS PAVLOV	{"email": "pavlov_feliks-011959@postgrespro.ru", "phone": "+70537953099"}
0005434082064	CBED2E	6316 951934	YURIY KOZLOV	{"email": "ykozlov.12091961@postgrespro.ru", "phone": "+70623912075"}
0005434082065	CBED2E	9436 151375	SOFYA NAUMOVA	{"email": "s.naumova_16111965@postgrespro.ru", "phone": "+70926240637"}
0005434082066	96AE09	9216 968994	NIKITA ZAYCEV	{"phone": "+70338335494"}
0005434082067	96AE09	0520 526831	ALEKSANDR POPOV	{"phone": "+70400733813"}
0005434082068	EC9776	3020 002959	KONSTANTIN NIKITIN	{"email": "knikitin1964@postgrespro.ru", "phone": "+70084052487"}
0005434082069	330C7B	5804 037476	ALEKSEY KISELEV	{"email": "kiseleva.08081980@postgrespro.ru", "phone": "+70418971589"}
0005434082070	0D099F	2901 331458	OLGA MAKAROVA	{"email": "makarova_o-011977@postgrespro.ru", "phone": "+70029249475"}
0005434082071	743408	1248 629375	ALEKSANDR GRIGOREV	{"phone": "+70043625407"}
0005434082072	B83C79	3987 240521	SERGEY BORISOV	{"phone": "+70819005875"}
0005434082073	67E397	2815 117731	ANDREY NIKITIN	{"phone": "+70590627927"}
0005434082074	E08141	7435 680044	SVETLANA VOROBEVA	{"email": "vorobeva-s.071969@postgrespro.ru", "phone": "+70557530788"}
0005434082075	92843D	3143 785446	LYUDMILA LOGINOVA	{"phone": "+70118403319"}
0005434082076	92843D	9353 608171	RAISA ANTONOVA	{"phone": "+70280672843"}
0005434082077	3E649A	4704 407093	SEMEN VASILEV	{"phone": "+70902034516"}
0005434082078	337C73	2112 376255	REGINA GORBUNOVA	{"email": "regina.gorbunova_061961@postgrespro.ru", "phone": "+70963541937"}
0005434082079	337C73	4074 748717	VYACHESLAV TIKHONOV	{"phone": "+70908305463"}
0005434082080	DFD5DB	4696 831645	NATALYA GRISHINA	{"phone": "+70707978027"}
0005434082081	DFD5DB	7970 157033	NINA BORISOVA	{"email": "borisovanina_01111970@postgrespro.ru", "phone": "+70029290151"}
0005434082082	E6B05E	9964 931579	OLEG SAVELEV	{"phone": "+70774822727"}
0005434082083	91D150	4033 987646	GALINA ORLOVA	{"phone": "+70818236976"}
0005434082084	EEC306	0669 447552	ELENA KOLESNIKOVA	{"phone": "+70677299219"}
0005434082085	BD6624	1282 059570	SVETLANA LAZAREVA	{"phone": "+70866792897"}
0005434082086	BD6624	8884 214566	OLGA PETROVA	{"phone": "+70922295848"}
0005434082087	41A8B6	5546 871523	ALEVTINA ZOTOVA	{"email": "zotovaa_1958@postgrespro.ru", "phone": "+70961341118"}
0005434082088	38662A	1103 898677	ILYA GORBUNOV	{"email": "gorbunov_i121963@postgrespro.ru", "phone": "+70993014066"}
0005434082089	38662A	7474 893140	ALEKSANDR PETROV	{"phone": "+70885358498"}
0005434082090	CE3504	0695 988090	ALEKSANDR MAKAROV	{"phone": "+70708952705"}
0005434082091	CE3504	1125 265386	DMITRIY DENISOV	{"email": "denisov.d_031966@postgrespro.ru", "phone": "+70570465140"}
0005434082092	DF28BF	8480 764193	IRINA VOLKOVA	{"email": "irinavolkova-091970@postgrespro.ru", "phone": "+70775773712"}
0005434082093	DF28BF	8323 702941	OLEG TIMOFEEV	{"phone": "+70129807552"}
0005434082094	DF28BF	5675 134362	ANASTASIYA SEMENOVA	{"phone": "+70662661048"}
0005434082095	C0FE96	3446 960109	VALENTINA SOLOVEVA	{"email": "vsoloveva16051988@postgrespro.ru", "phone": "+70171446887"}
0005434082096	C0FE96	3175 970482	GALINA VLASOVA	{"email": "gvlasova-15031974@postgrespro.ru", "phone": "+70882704928"}
0005434082097	CC8A43	9946 748002	VALENTINA PAVLOVA	{"phone": "+70409178299"}
0005434082098	CC8A43	0561 783801	YURIY VOLKOV	{"email": "volkovy-041978@postgrespro.ru", "phone": "+70303871568"}
0005434082099	A20FEA	1168 442152	GULNARA KISELEVA	{"phone": "+70592067018"}
0005434082100	83A609	5031 297485	ELENA KOMAROVA	{"phone": "+70574401300"}
0005434082101	5278B2	3641 834198	ALEKSANDR MOROZOV	{"phone": "+70191968795"}
0005434082102	5278B2	3548 594197	GALINA NAUMOVA	{"email": "naumova_galina.1972@postgrespro.ru", "phone": "+70472147511"}
0005434082103	8F2711	5505 254077	DMITRIY SAVELEV	{"phone": "+70724992881"}
0005434082104	2AAB44	3910 884266	DMITRIY GORBUNOV	{"phone": "+70777638514"}
0005434082105	7EECB3	5846 351727	ALEKSANDR KUZNECOV	{"phone": "+70258588722"}
0005434082106	C5B57B	5659 828560	MARGARITA MALYSHEVA	{"email": "m-malysheva-03051966@postgrespro.ru", "phone": "+70278338647"}
0005434082107	34F6F8	6462 558181	OLGA SMIRNOVA	{"phone": "+70604453797"}
0005434082108	34F6F8	3769 579398	SVETLANA ZHUKOVA	{"email": "s_zhukova_21051969@postgrespro.ru", "phone": "+70517681418"}
0005434082109	BAFA45	8966 395428	OLGA ORLOVA	{"phone": "+70956242367"}
0005434082110	BAFA45	6667 230676	DMITRIY MEDVEDEV	{"phone": "+70468667528"}
0005434082111	CBD13B	1055 590117	YULIYA TIMOFEEVA	{"phone": "+70755103399"}
0005434082112	3AD7BC	7451 451472	OLGA POLYAKOVA	{"email": "olga-polyakova-081975@postgrespro.ru", "phone": "+70558093660"}
0005434082113	3AD7BC	7620 912895	GALINA KISELEVA	{"phone": "+70760690050"}
0005434082114	D7EED7	6312 782412	EKATERINA VOLKOVA	{"phone": "+70667402999"}
0005434082115	D7EED7	3344 156814	NIKOLAY ALEKSEEV	{"phone": "+70659490789"}
0005434082116	8A41AF	2108 663822	EDUARD SHEVCHENKO	{"phone": "+70908339816"}
0005434082117	687B04	6091 417279	NATALIYA BOGDANOVA	{"email": "bogdanova-nataliya.09081966@postgrespro.ru", "phone": "+70884513575"}
0005434082344	6985CB	4558 895531	LYUDMILA MELNIKOVA	{"phone": "+70771651649"}
0005434082422	EEA14C	4704 324490	ALEKSEY FROLOV	{"phone": "+70099845361"}
0005434082118	BDCF44	0433 789879	EVGENIY SHEVCHENKO	{"email": "e-shevchenko-29121975@postgrespro.ru", "phone": "+70956770854"}
0005434082119	BDCF44	6668 617088	YURIY KISELEV	{"email": "kiselev.y.09021974@postgrespro.ru", "phone": "+70003640637"}
0005434082120	1116C6	9356 870719	ALEKSANDR KONOVALOV	{"email": "a.konovalov_1975@postgrespro.ru", "phone": "+70828759486"}
0005434082121	5C02C8	9504 162811	LYUBOV ZAYCEVA	{"email": "zayceva_lyubov-071970@postgrespro.ru", "phone": "+70493519216"}
0005434082122	5C02C8	4847 877919	LIDIYA SERGEEVA	{"phone": "+70309723415"}
0005434082123	B8BDAE	8756 375527	OLEG DAVYDOV	{"phone": "+70029281837"}
0005434082124	42ACC1	2762 703305	INNA NIKOLAEVA	{"email": "inna.nikolaeva-031966@postgrespro.ru", "phone": "+70105946792"}
0005434082125	488AD2	1822 647113	ANASTASIYA GRISHINA	{"email": "a.grishina02091984@postgrespro.ru", "phone": "+70717894731"}
0005434082126	9BA51B	8922 840353	MARIYA MARTYNOVA	{"phone": "+70818554367"}
0005434082127	8DA626	1779 113847	IRINA ANDREEVA	{"email": "i-andreeva24101960@postgrespro.ru", "phone": "+70950443309"}
0005434082128	3361A6	1079 540607	OLGA ORLOVA	{"phone": "+70680325371"}
0005434082129	5707FF	5518 628877	ANATOLIY MIKHAYLOV	{"phone": "+70581753291"}
0005434082130	5707FF	7386 289530	TATYANA SEMENOVA	{"phone": "+70958155931"}
0005434082131	404CDB	6212 372608	ZOYA EFIMOVA	{"email": "z_efimova10061965@postgrespro.ru", "phone": "+70442118843"}
0005434082132	AB9658	0565 344374	DARYA AKIMOVA	{"phone": "+70545787121"}
0005434082133	BA9F80	9980 297714	MIKHAIL PETROV	{"email": "petrovmikhail.07051967@postgrespro.ru", "phone": "+70218592086"}
0005434082134	EA320C	9570 544777	ALEKSEY ZAYCEV	{"phone": "+70396359290"}
0005434082135	E2BAAA	4245 408175	RENATA IVANOVA	{"email": "renata-ivanova011965@postgrespro.ru", "phone": "+70518262080"}
0005434082136	E2BAAA	4671 639597	GALINA OVCHINNIKOVA	{"phone": "+70001650145"}
0005434082137	D6B430	0436 836985	TAMARA NAZAROVA	{"email": "t.nazarova_05051984@postgrespro.ru", "phone": "+70012632150"}
0005434082138	AFA4A2	0975 751122	OLGA FILIPPOVA	{"phone": "+70671054115"}
0005434082139	571D54	3287 288311	ANATOLIY GRIGOREV	{"phone": "+70285586302"}
0005434082140	571D54	0163 763743	ELENA KUDRYASHOVA	{"phone": "+70793536624"}
0005434082141	7A3CB2	2645 243823	ALEKSEY KOROLEV	{"phone": "+70143977653"}
0005434082142	7CB7A1	4495 926004	LILIYA MAKAROVA	{"email": "liliya_makarova.24071978@postgrespro.ru", "phone": "+70594045262"}
0005434082143	FA90B2	2771 937337	POLINA KUZNECOVA	{"phone": "+70253818643"}
0005434082144	BA2173	8338 014376	SVETLANA AFANASEVA	{"email": "svetlana_afanaseva-021966@postgrespro.ru", "phone": "+70640746155"}
0005434082145	09FBF5	0474 047899	TAMARA PAVLOVA	{"phone": "+70004142541"}
0005434082146	3A085A	4129 647863	GULNARA KUZMINA	{"phone": "+70325393744"}
0005434082147	E800AC	3808 350344	SVETLANA MOISEEVA	{"email": "moiseeva_s-18071973@postgrespro.ru", "phone": "+70812860260"}
0005434082148	701DD3	0277 264388	SERGEY NIKOLAEV	{"email": "nikolaev.sergey_101976@postgrespro.ru", "phone": "+70027798750"}
0005434082149	AB0F34	6108 301629	VLADIMIR ILIN	{"phone": "+70925605367"}
0005434082150	0B01E1	1781 359441	VASILIY FILIPPOV	{"email": "v.filippov-1966@postgrespro.ru", "phone": "+70609918488"}
0005434082151	44212B	7364 994459	ALEKSANDR PAVLOV	{"phone": "+70432448315"}
0005434082152	0827E9	6215 006152	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova1981@postgrespro.ru", "phone": "+70647439273"}
0005434082153	0827E9	6175 964755	ELDAR FOMIN	{"email": "efomin111979@postgrespro.ru", "phone": "+70718329555"}
0005434082154	7FF65A	5018 037162	SERGEY SEMENOV	{"email": "sergeysemenov-21011971@postgrespro.ru", "phone": "+70414790983"}
0005434082155	4071C0	0789 273931	RAISA RODIONOVA	{"email": "raisa-rodionova_11041977@postgrespro.ru", "phone": "+70659187288"}
0005434082156	1BDA3D	3602 669053	LYUDMILA MAKAROVA	{"email": "l.makarova-1976@postgrespro.ru", "phone": "+70169591255"}
0005434082157	1BDA3D	9911 124008	SVETLANA KUZMINA	{"email": "kuzmina-svetlana08111970@postgrespro.ru", "phone": "+70248008179"}
0005434082158	938693	5258 898240	DMITRIY MAKAROV	{"email": "d.makarov_111979@postgrespro.ru", "phone": "+70909952584"}
0005434082159	9ABE14	7057 868566	ROZALIYA PETROVA	{"email": "petrova.r_1969@postgrespro.ru", "phone": "+70872502425"}
0005434082160	9ABE14	2438 098373	EVGENIY GAVRILOV	{"email": "e-gavrilov01031970@postgrespro.ru", "phone": "+70574462990"}
0005434082161	9ABE14	5974 059639	VALERIYA SAVELEVA	{"phone": "+70359927525"}
0005434082162	973A99	3198 936656	GALINA VOLKOVA	{"phone": "+70683488117"}
0005434082163	BB5210	9147 844233	OLESYA ZHUKOVA	{"phone": "+70579664154"}
0005434082164	3DF099	7067 890948	MARIYA MIKHAYLOVA	{"email": "mariya.mikhaylova081971@postgrespro.ru", "phone": "+70021970086"}
0005434082165	75F7AD	8434 202646	EVDOKIYA IVANOVA	{"phone": "+70289809391"}
0005434082166	75F7AD	1601 198508	VLADIMIR ABRAMOV	{"email": "v_abramov.031965@postgrespro.ru", "phone": "+70024906037"}
0005434082167	11CB29	0909 615994	SVETLANA STEPANOVA	{"email": "s.stepanova111972@postgrespro.ru", "phone": "+70305129744"}
0005434082168	11CB29	3446 768521	GALINA PAVLOVA	{"email": "galina.pavlova.091975@postgrespro.ru", "phone": "+70606558404"}
0005434082169	91C97E	4807 245519	ALENA IVANOVA	{"email": "alena-ivanova-1971@postgrespro.ru", "phone": "+70154534301"}
0005434082170	286AE7	7824 549557	RAISA KOMAROVA	{"email": "komarovaraisa_041967@postgrespro.ru", "phone": "+70695381273"}
0005434082171	55946C	3092 674928	SVETLANA ARKHIPOVA	{"email": "s_arkhipova-08091963@postgrespro.ru", "phone": "+70601633706"}
0005434082172	55946C	9851 909678	VERA ILINA	{"phone": "+70129911371"}
0005434082174	14365A	5596 366237	OLGA POPOVA	{"email": "popovaolga.121966@postgrespro.ru", "phone": "+70524704895"}
0005434082175	0F81C9	5362 936345	ARTUR ANTONOV	{"phone": "+70453503754"}
0005434082176	13AD75	8740 221458	IRINA YUDINA	{"email": "i.yudina-20121971@postgrespro.ru", "phone": "+70309790277"}
0005434082177	A47494	5231 354641	ANASTASIYA ILINA	{"email": "ilinaa.03011974@postgrespro.ru", "phone": "+70933196292"}
0005434082178	A2002C	1641 425200	ROMAN FOMIN	{"email": "r-fomin_011980@postgrespro.ru", "phone": "+70554917284"}
0005434082179	A2002C	7548 841983	ALEKSANDR DENISOV	{"email": "aleksandr_denisov.1960@postgrespro.ru", "phone": "+70319092389"}
0005434082180	1D0795	0403 533262	GALINA DENISOVA	{"phone": "+70361791781"}
0005434082181	1D0795	7629 194373	DARYA MOROZOVA	{"email": "d-morozova_05121968@postgrespro.ru", "phone": "+70757392132"}
0005434082182	CAFDE3	8441 614524	VYACHESLAV KISELEV	{"email": "v.kiselev_121981@postgrespro.ru", "phone": "+70064777876"}
0005434082183	CAFDE3	2669 672131	MIKHAIL KARPOV	{"email": "m.karpov20021974@postgrespro.ru", "phone": "+70612102279"}
0005434082184	CAFDE3	0763 806215	KLAVDIYA DMITRIEVA	{"phone": "+70959697859"}
0005434082185	CAFDE3	2434 151872	DMITRIY EGOROV	{"phone": "+70074975889"}
0005434082186	CF3F8A	3251 543707	OLEG FROLOV	{"phone": "+70351546746"}
0005434082187	4C00C4	7907 152619	KSENIYA IVANOVA	{"email": "kivanova011974@postgrespro.ru", "phone": "+70152594162"}
0005434082188	53956E	9600 027991	ILMIR FEDOROV	{"phone": "+70397892700"}
0005434082189	AB5F7D	5279 516814	SVETLANA KISELEVA	{"email": "kiseleva_svetlana.121970@postgrespro.ru", "phone": "+70256986940"}
0005434082190	71D59B	7497 358856	RADIK NIKOLAEV	{"phone": "+70730063833"}
0005434082191	610160	6123 855005	SVETLANA KRASNOVA	{"email": "krasnova.svetlana.091969@postgrespro.ru", "phone": "+70783732024"}
0005434082192	85CAE2	9838 238044	VLADIMIR KUZNECOV	{"phone": "+70493395481"}
0005434082193	85CAE2	5977 584283	VLADIMIR PAVLOV	{"email": "v-pavlov-16021981@postgrespro.ru", "phone": "+70211858591"}
0005434082194	98A2C2	1059 427023	YURIY FILIPPOV	{"email": "filippov-y15111985@postgrespro.ru", "phone": "+70471206960"}
0005434082195	98A2C2	8914 205689	VALERIY MOROZOV	{"email": "morozov.valeriy-28111965@postgrespro.ru", "phone": "+70605782393"}
0005434082196	98A2C2	3547 855228	RUMIYA ZHURAVLEVA	{"email": "zhuravleva_r02051963@postgrespro.ru", "phone": "+70745003917"}
0005434082197	8763ED	3436 770033	EKATERINA KUDRYASHOVA	{"phone": "+70603712328"}
0005434082198	8763ED	3932 421597	PAVEL STEPANOV	{"phone": "+70925206689"}
0005434082199	AB3A8F	4266 328537	EVGENIY KUZMIN	{"phone": "+70663699193"}
0005434082200	72E444	4404 339561	ALEKSANDR DENISOV	{"phone": "+70730559810"}
0005434082201	18EE57	5784 268526	IGOR KOROLEV	{"email": "i.korolev.12011965@postgrespro.ru", "phone": "+70397034873"}
0005434082202	1D73A9	6338 531019	YURIY FROLOV	{"email": "yuriy_frolov_101965@postgrespro.ru", "phone": "+70094312639"}
0005434082203	AEE944	8097 603482	ALEKSANDR ALEKSEEV	{"phone": "+70654771684"}
0005434082204	2A5E8D	9907 058812	SVETLANA IVANOVA	{"phone": "+70068106507"}
0005434082205	1B0D09	6540 380653	VASILIY SMIRNOV	{"phone": "+70879532650"}
0005434082206	B14ABC	4983 727976	OKSANA KONDRATEVA	{"email": "kondrateva-o_091971@postgrespro.ru", "phone": "+70918914014"}
0005434082207	B14ABC	1935 148512	LYUDMILA LOGINOVA	{"phone": "+70441954777"}
0005434082208	B14ABC	5261 018116	ANNA KULIKOVA	{"email": "kulikova_anna-30011967@postgrespro.ru", "phone": "+70648218720"}
0005434082209	6063D4	8542 832684	ANZHELIKA VASILEVA	{"phone": "+70666226731"}
0005434082210	6063D4	4958 848479	OLGA IVANOVA	{"phone": "+70442551334"}
0005434082211	90ED84	9676 515023	VALERIY KUZNECOV	{"email": "kuznecov_valeriy-041974@postgrespro.ru", "phone": "+70853326248"}
0005434082212	705209	8664 593642	DMITRIY FEDOTOV	{"phone": "+70620267401"}
0005434082213	C55E27	7867 616613	ELEONORA TIKHONOVA	{"email": "tikhonova_e.1973@postgrespro.ru", "phone": "+70699321128"}
0005434082214	65875C	8184 467860	GALINA NESTEROVA	{"phone": "+70929585002"}
0005434082215	8CB13E	7788 381765	ALEKSEY KUZMIN	{"phone": "+70068298233"}
0005434082216	FEFFAD	2773 860346	ALEKSANDR KUZMIN	{"email": "a_kuzmin-25071967@postgrespro.ru", "phone": "+70560922693"}
0005434082217	4D4669	7891 097957	ANDREY ANDREEV	{"phone": "+70262486553"}
0005434082218	D6DA83	2710 995551	PAVEL GUSEV	{"phone": "+70211481100"}
0005434082219	D6DA83	3289 979525	ELIZAVETA EFIMOVA	{"phone": "+70194370528"}
0005434082220	71C238	3380 493572	LYUDMILA KULIKOVA	{"email": "kulikoval-1968@postgrespro.ru", "phone": "+70207565725"}
0005434082221	71C238	1910 318923	ROMAN SMIRNOV	{"email": "rsmirnov_061973@postgrespro.ru", "phone": "+70857981787"}
0005434082222	15E3BE	1191 318673	LEV FROLOV	{"email": "frolov.lev.01041987@postgrespro.ru", "phone": "+70283750004"}
0005434082223	15E3BE	2270 753278	ALEKSANDR KUZNECOV	{"phone": "+70248774852"}
0005434082224	6D66C1	9183 266042	NATALYA MAKAROVA	{"phone": "+70643107599"}
0005434082225	6D66C1	6849 460958	VITALIY SHEVCHENKO	{"email": "shevchenko-v_101976@postgrespro.ru", "phone": "+70537060038"}
0005434082226	51376F	9184 863472	VALENTINA NIKITINA	{"email": "vnikitina-26021968@postgrespro.ru", "phone": "+70645756281"}
0005434082227	3DEB20	9416 986023	KSENIYA ZHURAVLEVA	{"email": "zhuravleva-kseniya.15111966@postgrespro.ru", "phone": "+70307150954"}
0005434082228	B6BB11	1529 936758	MARIYA ZAYCEVA	{"email": "mariya-zayceva-071965@postgrespro.ru", "phone": "+70012364912"}
0005434082229	B6BB11	3398 643708	ANNA NOVIKOVA	{"email": "anna_novikova101980@postgrespro.ru", "phone": "+70708302541"}
0005434082230	A11E74	3281 253239	IGOR ORLOV	{"email": "igororlov-1960@postgrespro.ru", "phone": "+70103358931"}
0005434082231	DC6CF8	7654 360888	ELENA KUZNECOVA	{"email": "elena.kuznecova-011961@postgrespro.ru", "phone": "+70026324685"}
0005434082232	E56053	7669 059591	SERGEY YAKOVLEV	{"phone": "+70739793074"}
0005434082233	C16F3A	4433 861125	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov_27051970@postgrespro.ru", "phone": "+70923435962"}
0005434082234	C16F3A	2494 891129	VALENTINA KISELEVA	{"email": "valentina-kiseleva-08021969@postgrespro.ru", "phone": "+70463839027"}
0005434082235	B271EC	5960 840720	ALEKSEY IVANOV	{"phone": "+70117787443"}
0005434082236	D73081	5711 764734	ALENA MARTYNOVA	{"email": "martynova-a1971@postgrespro.ru", "phone": "+70516109606"}
0005434082237	600D45	8148 071761	DMITRIY MOROZOV	{"phone": "+70328642237"}
0005434082239	4D8FA3	8951 609048	VITALIY POPOV	{"email": "popov.vitaliy.1979@postgrespro.ru", "phone": "+70449154405"}
0005434082240	681EDF	8441 848948	SERGEY BORISOV	{"phone": "+70506063000"}
0005434082241	C58816	2293 985801	VIKTOR KUDRYASHOV	{"email": "v.kudryashov-1978@postgrespro.ru", "phone": "+70084540642"}
0005434082242	86A3B3	4896 657848	DIANA IVANOVA	{"email": "ivanovad111977@postgrespro.ru", "phone": "+70057375172"}
0005434082243	86A3B3	6812 680354	NATALYA ROMANOVA	{"phone": "+70770255578"}
0005434082244	9A749C	2219 543812	NATALYA BOGDANOVA	{"email": "n-bogdanova_1968@postgrespro.ru", "phone": "+70312878065"}
0005434082245	A951ED	3121 037208	KONSTANTIN MOROZOV	{"email": "k-morozov_061976@postgrespro.ru", "phone": "+70719365394"}
0005434082246	A348D3	8786 699837	OLGA ABRAMOVA	{"email": "abramova-o.21071959@postgrespro.ru", "phone": "+70330805352"}
0005434082247	8C0FF3	3760 302742	ALEKSEY FILIPPOV	{"email": "a-filippov.13111970@postgrespro.ru", "phone": "+70570366709"}
0005434082248	AF9CB4	0594 601173	LYUBOV KOROLEVA	{"email": "koroleva_lyubov.071974@postgrespro.ru", "phone": "+70312238143"}
0005434082249	AF9CB4	8639 417531	YULIYA MELNIKOVA	{"email": "yuliyamelnikova.1965@postgrespro.ru", "phone": "+70377648867"}
0005434082250	B3F263	1592 191773	ANNA SIDOROVA	{"email": "sidorova_anna19061969@postgrespro.ru", "phone": "+70495816926"}
0005434082251	B3F263	4870 776262	LYUBOV MALYSHEVA	{"phone": "+70822207824"}
0005434082252	43AE8A	6776 255548	NATALYA KRASNOVA	{"email": "natalyakrasnova-1970@postgrespro.ru", "phone": "+70989348015"}
0005434082253	43AE8A	1981 280864	PAVEL SOROKIN	{"phone": "+70220853908"}
0005434082254	AB6E15	2953 869243	VLADIMIR PETROV	{"email": "petrov.vladimir_1966@postgrespro.ru", "phone": "+70803922288"}
0005434082255	5077F5	1777 359065	ANDREY TIMOFEEV	{"email": "atimofeev091964@postgrespro.ru", "phone": "+70800803526"}
0005434082256	5077F5	2923 139720	ANDREY POPOV	{"email": "a-popov.1961@postgrespro.ru", "phone": "+70843695161"}
0005434082257	5077F5	7876 125288	MATVEY MOROZOV	{"email": "morozov_m_15101968@postgrespro.ru", "phone": "+70948643254"}
0005434082258	AE26EE	4413 020787	DMITRIY KARPOV	{"email": "karpov.d081978@postgrespro.ru", "phone": "+70724834060"}
0005434082259	AE26EE	9048 640946	IRINA LOGINOVA	{"email": "loginova-i.041974@postgrespro.ru", "phone": "+70856212759"}
0005434082260	B38A28	7306 436198	MATVEY GAVRILOV	{"phone": "+70997912443"}
0005434082261	B38A28	8669 469216	OLGA MAKAROVA	{"phone": "+70326054197"}
0005434082262	DA1235	7621 198595	SERGEY IVANOV	{"phone": "+70649406221"}
0005434082263	058588	2870 462618	YANA ANTONOVA	{"email": "antonova_yana_031972@postgrespro.ru", "phone": "+70730922366"}
0005434082264	058588	5036 445284	ANASTASIYA NESTEROVA	{"phone": "+70543088959"}
0005434082265	D2E8F2	7239 422911	LARISA VLASOVA	{"phone": "+70934035549"}
0005434082266	3860B4	4338 766267	VIKTOR FEDOROV	{"phone": "+70126059606"}
0005434082267	3860B4	3498 132293	ALEKSANDR POPOV	{"phone": "+70013915370"}
0005434082268	3860B4	5553 992438	VALENTINA KOVALEVA	{"email": "kovaleva_valentina1978@postgrespro.ru", "phone": "+70494570349"}
0005434082269	F01A4F	2154 476285	NATALYA PAVLOVA	{"email": "pavlova_natalya_09111969@postgrespro.ru", "phone": "+70774909624"}
0005434082270	F01A4F	1022 501576	ALEKSEY STEPANOV	{"phone": "+70942085421"}
0005434082271	C71751	3009 967106	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev-1972@postgrespro.ru", "phone": "+70497523514"}
0005434082272	6658AC	8741 138259	VLADISLAV IVANOV	{"phone": "+70328057951"}
0005434082273	8BA8F8	7978 718873	DMITRIY MIKHAYLOV	{"phone": "+70934007486"}
0005434082274	42A6F5	9209 680105	GALINA NESTEROVA	{"phone": "+70657948209"}
0005434082275	42A6F5	0691 495235	SERGEY KONOVALOV	{"phone": "+70621677935"}
0005434082276	03F89B	0370 774430	MARINA FEDOROVA	{"phone": "+70972555649"}
0005434082277	A6AB8D	5446 287611	ANNA SMIRNOVA	{"email": "smirnova-anna.01121976@postgrespro.ru", "phone": "+70361688735"}
0005434082278	A6AB8D	5015 133780	ALEKSANDRA MIRONOVA	{"phone": "+70748598410"}
0005434082279	406CB5	9964 600097	ELIZAVETA MAKAROVA	{"email": "elizaveta-makarova.1969@postgrespro.ru", "phone": "+70415754691"}
0005434082280	C52092	3648 387049	ILDAR DAVYDOV	{"phone": "+70942440496"}
0005434082281	628211	3744 993563	LYUBOV ZHUKOVA	{"email": "lyubov.zhukova-1977@postgrespro.ru", "phone": "+70554910539"}
0005434082282	628211	2958 908392	ANDREY MAKSIMOV	{"email": "maksimov.andrey_21081979@postgrespro.ru", "phone": "+70227037299"}
0005434082283	E5EA5A	7298 014119	ELENA SOLOVEVA	{"phone": "+70634317253"}
0005434082284	0FF7BC	5312 812222	DMITRIY ZAYCEV	{"phone": "+70839705236"}
0005434082285	5A9FE5	8067 010229	LILIYA KUZNECOVA	{"phone": "+70017892437"}
0005434082287	5720DF	7318 245346	SERGEY POPOV	{"email": "popov_s.111966@postgrespro.ru", "phone": "+70684152621"}
0005434082288	5720DF	0071 448325	ALEKSANDR ROMANOV	{"phone": "+70056809126"}
0005434082289	F464CD	6021 088915	NATALIYA YAKOVLEVA	{"email": "nataliya.yakovleva.07081955@postgrespro.ru", "phone": "+70375108762"}
0005434082290	F464CD	2737 600613	IVAN NIKOLAEV	{"email": "nikolaev.ivan061972@postgrespro.ru", "phone": "+70055589069"}
0005434082291	466EED	3832 806801	VIKTOR FEDOROV	{"email": "fedorov-v.1961@postgrespro.ru", "phone": "+70990223346"}
0005434082292	001751	2440 568529	IGOR MIKHAYLOV	{"phone": "+70351749522"}
0005434082293	9F8774	0796 662865	ALEKSEY NOVIKOV	{"email": "aleksey-novikov-1966@postgrespro.ru", "phone": "+70066250751"}
0005434082294	9F8774	3883 414625	VALENTINA KULIKOVA	{"phone": "+70587737979"}
0005434082295	9F8774	2955 303508	LIDIYA CHERNOVA	{"phone": "+70742760218"}
0005434082296	9F8774	1527 125823	TIMOFEY ALEKSANDROV	{"email": "timofey.aleksandrov.021981@postgrespro.ru", "phone": "+70651942541"}
0005434082297	C44BAB	6128 563426	VIKTORIYA GUSEVA	{"phone": "+70224838478"}
0005434082298	E28274	9985 402789	NINA ALEKSEEVA	{"phone": "+70403981246"}
0005434082299	6CFE39	6368 600866	VITALIY FOMIN	{"email": "vitaliyfomin_1976@postgrespro.ru", "phone": "+70258551023"}
0005434082300	6CFE39	2269 271173	LIDIYA POPOVA	{"email": "lpopova.1981@postgrespro.ru", "phone": "+70204901417"}
0005434082301	B88D6B	3065 883061	MARINA BORISOVA	{"phone": "+70999640673"}
0005434082302	C1F82C	1888 033395	ALEKSANDR PETROV	{"phone": "+70113729648"}
0005434082303	F69373	9439 600372	NIKOLAY RODIONOV	{"email": "nikolayrodionov_1973@postgrespro.ru", "phone": "+70520123180"}
0005434082304	E1CEE5	6389 139700	NADEZHDA ZHUKOVA	{"email": "zhukova-nadezhda29081974@postgrespro.ru", "phone": "+70955549789"}
0005434082305	A2CD4E	9303 571349	ELENA MARTYNOVA	{"phone": "+70307553316"}
0005434082306	9C967D	1340 406671	NIKOLAY MOROZOV	{"phone": "+70147160516"}
0005434082307	9C967D	3299 090593	PAVEL KONOVALOV	{"phone": "+70621261066"}
0005434082308	C6503A	0388 987979	ALEKSEY SOLOVEV	{"phone": "+70434872204"}
0005434082309	C38E97	6758 708553	MARIYA KAZAKOVA	{"phone": "+70088642801"}
0005434082310	BBC6A7	2569 118408	OKSANA ANDREEVA	{"phone": "+70076752867"}
0005434082311	383303	8467 811072	ANASTASIYA KUZNECOVA	{"phone": "+70440084379"}
0005434082312	383303	9055 876068	VERA PETROVA	{"phone": "+70072883648"}
0005434082313	383303	1543 424477	OLGA DAVYDOVA	{"phone": "+70169491566"}
0005434082314	873E43	5556 621615	RAISA MOROZOVA	{"email": "morozova.r.15021971@postgrespro.ru", "phone": "+70330480973"}
0005434082315	024D9E	2863 665475	IVAN ANTONOV	{"phone": "+70188222885"}
0005434082316	024D9E	7569 682851	OLEG NOVIKOV	{"phone": "+70936717284"}
0005434082317	2FC726	1347 282486	GALINA MALYSHEVA	{"email": "galinamalysheva-09051985@postgrespro.ru", "phone": "+70696867384"}
0005434082318	FB2851	1292 079935	VERA KOZLOVA	{"email": "v_kozlova091973@postgrespro.ru", "phone": "+70529388929"}
0005434082319	158A0A	7456 129948	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey-121979@postgrespro.ru", "phone": "+70995141567"}
0005434082320	B80E19	9133 357051	SVETLANA IVANOVA	{"phone": "+70222272005"}
0005434082321	E67BE7	4063 714493	LYUBOV IVANOVA	{"email": "ivanovalyubov-041975@postgrespro.ru", "phone": "+70781490646"}
0005434082322	E67BE7	4508 041942	VLADIMIR KOZLOV	{"phone": "+70592540627"}
0005434082323	18CED0	7848 635236	MARINA NOVIKOVA	{"phone": "+70491291893"}
0005434082324	4E0E2D	8452 074358	ANTON VLASOV	{"phone": "+70596236975"}
0005434082325	4E0E2D	3773 649432	ANTONINA FILATOVA	{"phone": "+70198136506"}
0005434082326	4E0E2D	5425 536933	ANNA KAZAKOVA	{"phone": "+70750096544"}
0005434082327	42E66A	0711 046826	IRINA ILINA	{"email": "ilinairina01121969@postgrespro.ru", "phone": "+70202455952"}
0005434082328	290B94	2494 740263	VLADISLAV MATVEEV	{"phone": "+70615057531"}
0005434082329	290B94	8787 765792	IRINA KARPOVA	{"email": "karpova_irina1969@postgrespro.ru", "phone": "+70317446626"}
0005434082330	EC31DF	0188 785064	DIANA ANDREEVA	{"phone": "+70045864534"}
0005434082331	30A697	6250 067773	SERGEY KRASNOV	{"email": "krasnov-sergey_06031972@postgrespro.ru", "phone": "+70321146352"}
0005434082332	30A697	4227 662052	NIKOLAY OSIPOV	{"email": "osipov.n1976@postgrespro.ru", "phone": "+70872535331"}
0005434082333	FB6FA7	9203 779149	ALEKSANDRA PETROVA	{"phone": "+70214899812"}
0005434082334	FB6FA7	7097 538957	TIMUR SOLOVEV	{"email": "solovev-timur.1975@postgrespro.ru", "phone": "+70138867148"}
0005434082335	AE8C29	7449 980487	ZINAIDA DAVYDOVA	{"email": "z_davydova_1970@postgrespro.ru", "phone": "+70062628163"}
0005434082336	3594CE	8698 258028	VLADIMIR FILIPPOV	{"email": "filippov.v_1970@postgrespro.ru", "phone": "+70494678204"}
0005434082337	88535E	3813 888216	VLADIMIR BONDARENKO	{"phone": "+70148292631"}
0005434082338	88535E	0144 871325	EGOR PAVLOV	{"phone": "+70268357438"}
0005434082339	DF12CE	3074 751285	ANTONINA NOVIKOVA	{"phone": "+70490467211"}
0005434082340	467B46	9372 399378	RAFAIL ZHUKOV	{"phone": "+70011602643"}
0005434082341	684CFC	5926 810577	TATYANA FROLOVA	{"email": "frolova-t_121970@postgrespro.ru", "phone": "+70210046509"}
0005434082342	684CFC	2629 570039	LYUDMILA RODIONOVA	{"phone": "+70464557179"}
0005434082343	F0D080	7119 514810	YURIY KONOVALOV	{"email": "konovalov_yuriy111984@postgrespro.ru", "phone": "+70136433192"}
0005434082345	A16F4E	4349 523976	TATYANA POPOVA	{"email": "popova.tatyana.021977@postgrespro.ru", "phone": "+70653879580"}
0005434082346	78BC15	8448 860681	VLADIMIR MAKAROV	{"email": "makarov_v.061960@postgrespro.ru", "phone": "+70447628148"}
0005434082347	BE27B0	9214 255618	VALERIY ZAYCEV	{"email": "valeriy-zaycev-1973@postgrespro.ru", "phone": "+70820306688"}
0005434082348	87BDC8	9580 885783	VERA LAZAREVA	{"phone": "+70047354397"}
0005434082349	87BDC8	7326 664717	VALENTINA KOLESNIKOVA	{"phone": "+70779581276"}
0005434082350	BEFF52	6858 135651	EVGENIYA MOROZOVA	{"phone": "+70929686812"}
0005434082351	BEFF52	1391 141306	SERGEY GAVRILOV	{"phone": "+70548266356"}
0005434082352	7BA91D	8137 152310	DMITRIY MEDVEDEV	{"email": "medvedev-dmitriy20011977@postgrespro.ru", "phone": "+70813326288"}
0005434082353	0DD6DC	9704 910182	IBRAGIM SEMENOV	{"email": "semenov_ibragim-071973@postgrespro.ru", "phone": "+70106811204"}
0005434082354	959100	7316 936887	OLEG DMITRIEV	{"phone": "+70121477621"}
0005434082355	4567DD	0023 844966	RUSLAN GUSEV	{"email": "gusevr.121974@postgrespro.ru", "phone": "+70268717585"}
0005434082356	CE4D26	1165 881717	EKATERINA GAVRILOVA	{"phone": "+70909638359"}
0005434082357	2055C0	1778 566044	DARYA KUZNECOVA	{"email": "darya_kuznecova-031984@postgrespro.ru", "phone": "+70745775979"}
0005434082358	2055C0	9022 788107	LINAR KUZNECOV	{"email": "kuznecov_linar021975@postgrespro.ru", "phone": "+70471166577"}
0005434082359	04FE8C	6766 701838	VYACHESLAV RODIONOV	{"phone": "+70520544558"}
0005434082360	04FE8C	8293 749425	TATYANA ALEKSEEVA	{"phone": "+70123827612"}
0005434082361	04FE8C	7104 676260	NIKOLAY MARTYNOV	{"email": "nmartynov.1965@postgrespro.ru", "phone": "+70108991068"}
0005434082362	834F00	2519 976725	SERGEY ORLOV	{"phone": "+70522341614"}
0005434082363	32FC1C	0805 448821	ALEKSEY VASILEV	{"email": "aleksey.vasilev1972@postgrespro.ru", "phone": "+70944707774"}
0005434082364	BD9084	4215 454016	DMITRIY NOVIKOV	{"email": "d-novikov_1968@postgrespro.ru", "phone": "+70355294279"}
0005434082365	BD9084	9713 565028	SERGEY ISAEV	{"phone": "+70339342296"}
0005434082366	945160	8406 548639	PETR TARASOV	{"email": "petr_tarasov-1961@postgrespro.ru", "phone": "+70495708474"}
0005434082367	974F10	0012 941367	VLADIMIR BONDARENKO	{"phone": "+70775317783"}
0005434082368	974F10	8944 392910	VLADIMIR NIKOLAEV	{"phone": "+70007322919"}
0005434082369	FE395F	8972 070525	ALEKSEY KOZLOV	{"email": "aleksey_kozlov-18041966@postgrespro.ru", "phone": "+70357454717"}
0005434082370	6802FE	4857 383307	MARINA ABRAMOVA	{"phone": "+70407610136"}
0005434082371	ABF99F	0160 262432	KLAVDIYA VOLKOVA	{"email": "volkova_k.1967@postgrespro.ru", "phone": "+70485907340"}
0005434082372	E9CFE4	7627 508388	POLINA KISELEVA	{"email": "kiselevapolina_1974@postgrespro.ru", "phone": "+70016177828"}
0005434082373	ED845A	2512 809582	YURIY IVANOV	{"email": "y.ivanov11021969@postgrespro.ru", "phone": "+70524855296"}
0005434082374	3913E1	5441 761890	LIDIYA NIKIFOROVA	{"phone": "+70810769191"}
0005434082375	3913E1	2162 497974	VLADIMIR VOLKOV	{"phone": "+70564425522"}
0005434082376	969817	8815 718083	NIKOLAY ILIN	{"email": "n_ilin15031973@postgrespro.ru", "phone": "+70676546807"}
0005434082377	54CE83	6954 672460	ZINAIDA KUZNECOVA	{"email": "zinaida.kuznecova21041971@postgrespro.ru", "phone": "+70959151887"}
0005434082378	AAF957	7815 756547	SERGEY ZHURAVLEV	{"email": "sergey_zhuravlev1962@postgrespro.ru", "phone": "+70875065523"}
0005434082379	AAF957	3725 712821	MARINA FILIPPOVA	{"email": "marina.filippova-031957@postgrespro.ru", "phone": "+70012990705"}
0005434082380	5D53A3	3898 383075	GALINA KOZLOVA	{"email": "galina.kozlova.09051961@postgrespro.ru", "phone": "+70529404077"}
0005434082381	0341A5	9492 809147	ALEKSANDR MOISEEV	{"phone": "+70857373167"}
0005434082382	401B36	8278 775141	NATALYA ROMANOVA	{"phone": "+70380296605"}
0005434082383	EB18FD	4081 534943	ILGIZ KUZMIN	{"email": "ilgiz_kuzmin.1975@postgrespro.ru", "phone": "+70844791767"}
0005434082384	EB18FD	4040 030341	NATALIYA BELYAEVA	{"phone": "+70814570665"}
0005434082385	467157	4914 540258	ELENA MARTYNOVA	{"phone": "+70925459628"}
0005434082386	559E3A	5176 162624	MARIYA POPOVA	{"phone": "+70000148828"}
0005434082387	559E3A	9893 218134	PAVEL ZAYCEV	{"phone": "+70810876641"}
0005434082388	559E3A	7845 215997	YURIY VOROBEV	{"phone": "+70724085417"}
0005434082389	299599	9894 770034	YULIYA IVANOVA	{"email": "ivanova.yuliya-15031981@postgrespro.ru", "phone": "+70253799684"}
0005434082390	F50212	5006 815809	NADEZHDA NESTEROVA	{"email": "nesterovan-091967@postgrespro.ru", "phone": "+70286563319"}
0005434082391	CBB3B4	6250 111458	OLGA RODIONOVA	{"email": "rodionova_olga_081973@postgrespro.ru", "phone": "+70120780329"}
0005434082392	6F6E1B	6241 351282	SERGEY IVANOV	{"phone": "+70851696896"}
0005434082393	33A3D3	6211 725262	PAVEL EGOROV	{"phone": "+70484296828"}
0005434082394	1251CD	6008 901804	EVGENIY SIDOROV	{"phone": "+70201942497"}
0005434082395	25ECD4	4828 858622	TATYANA FROLOVA	{"email": "tfrolova.22041971@postgrespro.ru", "phone": "+70769604698"}
0005434082396	25ECD4	4488 546504	VLADIMIR POPOV	{"phone": "+70024130620"}
0005434082397	5C1E60	3783 503400	ANDREY GUSEV	{"phone": "+70083661037"}
0005434082398	5C1E60	6030 556290	MARIYA KOVALEVA	{"email": "mariya_kovaleva.1975@postgrespro.ru", "phone": "+70783705600"}
0005434082399	7FAFC8	9570 056262	VIKTOR PAVLOV	{"phone": "+70531479345"}
0005434082400	256DEC	9177 717479	GALINA MIKHAYLOVA	{"email": "g.mikhaylova_11031971@postgrespro.ru", "phone": "+70417163526"}
0005434082512	23932B	7050 058578	DINARA MALYSHEVA	{"phone": "+70551320321"}
0005434082401	B4847F	7046 237675	VLADIMIR DENISOV	{"email": "denisovvladimir.091957@postgrespro.ru", "phone": "+70328338275"}
0005434082402	B4847F	0381 536644	VASILIY ILIN	{"email": "ilin.vasiliy29121964@postgrespro.ru", "phone": "+70616861367"}
0005434082403	677CAE	2461 588721	NATALYA KAZAKOVA	{"phone": "+70881069059"}
0005434082404	677CAE	2818 920673	ALBINA CHERNOVA	{"email": "chernova.a_1977@postgrespro.ru", "phone": "+70942667316"}
0005434082405	46B0EB	6264 338682	EVGENIY IVANOV	{"phone": "+70895061729"}
0005434082406	817B18	9411 488907	VLADIMIR MAKAROV	{"email": "makarov-v-29081975@postgrespro.ru", "phone": "+70918624042"}
0005434082407	8F43AA	1301 989180	LYUBOV SOROKINA	{"email": "l_sorokina-1976@postgrespro.ru", "phone": "+70990076180"}
0005434082408	1CD675	9354 750222	PAVEL KARPOV	{"email": "karpov_pavel041977@postgrespro.ru", "phone": "+70801911407"}
0005434082409	346F2C	1020 395492	SERGEY ORLOV	{"phone": "+70268384291"}
0005434082410	1E752F	9902 362734	BORIS VOLKOV	{"phone": "+70280369886"}
0005434082411	C40FF5	5208 257275	SERGEY MOISEEV	{"email": "sergey.moiseev07061967@postgrespro.ru", "phone": "+70553121662"}
0005434082412	F1EBBA	7191 581637	NIKOLAY MELNIKOV	{"email": "melnikov.nikolay.1963@postgrespro.ru", "phone": "+70620877808"}
0005434082413	A6C980	7778 097105	NIKOLAY MELNIKOV	{"phone": "+70572191759"}
0005434082414	6F3B60	1933 186668	ELENA FROLOVA	{"email": "frolova-elena_101963@postgrespro.ru", "phone": "+70597105377"}
0005434082415	FF7570	8431 026694	OLGA SOLOVEVA	{"email": "olga_soloveva-15101976@postgrespro.ru", "phone": "+70499191924"}
0005434082416	CF8125	6058 987323	SVETLANA MAKAROVA	{"email": "svetlana.makarova_1971@postgrespro.ru", "phone": "+70792819221"}
0005434082417	CF8125	8019 932566	ALEKSANDR PETROV	{"phone": "+70084197348"}
0005434082418	CA650F	3296 814939	EVGENIYA AFANASEVA	{"email": "afanaseva_e021968@postgrespro.ru", "phone": "+70744687158"}
0005434082419	CA650F	2275 132980	KSENIYA LAZAREVA	{"phone": "+70288442002"}
0005434082420	899D50	3963 684998	ELENA TIMOFEEVA	{"phone": "+70632982798"}
0005434082421	899D50	8582 543641	TIMUR GAVRILOV	{"phone": "+70102788786"}
0005434082423	C44071	6454 891305	NADEZHDA SAVELEVA	{"email": "nadezhda_saveleva-1974@postgrespro.ru", "phone": "+70490647889"}
0005434082424	C44071	1884 959467	PAVEL NIKOLAEV	{"phone": "+70057461832"}
0005434082425	4FB2DD	8157 890362	TAMARA VOROBEVA	{"email": "vorobevat1971@postgrespro.ru", "phone": "+70555250373"}
0005434082426	105245	6780 969524	LYUDMILA VOROBEVA	{"phone": "+70225101333"}
0005434082427	105245	2578 964911	SERGEY IVANOV	{"email": "ivanovs.01011975@postgrespro.ru", "phone": "+70583054981"}
0005434082428	950105	4776 723246	ANATOLIY ZAYCEV	{"email": "azaycev.10011975@postgrespro.ru", "phone": "+70693004437"}
0005434082429	66E834	0171 000348	RUSTAM SCHERBAKOV	{"email": "r-scherbakov-25041975@postgrespro.ru", "phone": "+70143092742"}
0005434082430	10E0BD	4515 860786	MARIYA SOROKINA	{"email": "mariyasorokina12101976@postgrespro.ru", "phone": "+70904490574"}
0005434082431	896369	0972 690284	GENNADIY MAKSIMOV	{"email": "maksimovgennadiy04081970@postgrespro.ru", "phone": "+70943132196"}
0005434082432	896369	2883 712231	NADEZHDA GORBUNOVA	{"email": "gorbunovan11021971@postgrespro.ru", "phone": "+70898763430"}
0005434082433	D74689	2060 518745	TAMARA YAKOVLEVA	{"phone": "+70373832302"}
0005434082434	B36C6D	5083 499011	DMITRIY BARANOV	{"email": "dmitriybaranov.20081974@postgrespro.ru", "phone": "+70070712439"}
0005434082435	BAFAF1	2853 692670	SERGEY VOLKOV	{"phone": "+70628391847"}
0005434082436	BAFAF1	8340 283672	TALGAT MIKHAYLOV	{"phone": "+70737816338"}
0005434082437	3F8434	6414 118759	NADEZHDA PAVLOVA	{"phone": "+70448107084"}
0005434082438	3F8434	9590 148570	TAMARA POLYAKOVA	{"email": "tpolyakova-02021973@postgrespro.ru", "phone": "+70869156270"}
0005434082439	BEC14E	9616 631814	BORIS NIKITIN	{"phone": "+70140167720"}
0005434082440	9AC862	4622 468757	NINA LAZAREVA	{"phone": "+70319560193"}
0005434082441	71105A	4302 443424	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova.011963@postgrespro.ru", "phone": "+70766253964"}
0005434082442	B6F5D6	9829 520745	VALENTIN POPOV	{"email": "v-popov_121968@postgrespro.ru", "phone": "+70269248397"}
0005434082443	8F3DE0	3888 551053	VLADIMIR SEMENOV	{"email": "vladimir.semenov-071975@postgrespro.ru", "phone": "+70125041728"}
0005434082444	52CDEB	3288 228035	VERA KULIKOVA	{"phone": "+70245557799"}
0005434082445	52CDEB	2684 864751	RAMIL MOISEEV	{"email": "ramil_moiseev08031971@postgrespro.ru", "phone": "+70226295897"}
0005434082446	62EB0E	4702 876512	NINA NESTEROVA	{"phone": "+70539395930"}
0005434082447	279681	7556 776495	NIKITA TIKHONOV	{"email": "n_tikhonov071973@postgrespro.ru", "phone": "+70869142840"}
0005434082448	279681	2954 069971	ANATOLIY KARPOV	{"phone": "+70192773046"}
0005434082449	64E3B0	1510 305909	ALEKSANDR FOMIN	{"phone": "+70507162238"}
0005434082450	F9F0D7	0007 822089	ALEKSEY CHERNOV	{"email": "aleksey.chernov-1962@postgrespro.ru", "phone": "+70435376588"}
0005434082451	8A191B	8151 510245	IRINA DENISOVA	{"phone": "+70767598195"}
0005434082452	8A191B	6027 174506	ALINA PETROVA	{"email": "alina_petrova.091965@postgrespro.ru", "phone": "+70697157911"}
0005434082453	CF63EE	8317 377071	SVETLANA TITOVA	{"phone": "+70864731437"}
0005434082454	3BF164	4081 437190	ALEKSANDR VOLKOV	{"email": "a_volkov051969@postgrespro.ru", "phone": "+70728857788"}
0005434082455	3BF164	9613 063289	MARIYA MIRONOVA	{"email": "mironova-m08101971@postgrespro.ru", "phone": "+70956398585"}
0005434082456	D9ECD6	5177 818535	ANDREY FROLOV	{"email": "a_frolov_1965@postgrespro.ru", "phone": "+70413088811"}
0005434082457	AC1009	1297 194500	KLAVDIYA MALYSHEVA	{"email": "malysheva.k-1971@postgrespro.ru", "phone": "+70840915081"}
0005434082458	B44EF2	9954 314546	VYACHESLAV BORISOV	{"email": "borisov.v1977@postgrespro.ru", "phone": "+70676957980"}
0005434082459	872CAA	6684 619185	POLINA KOZLOVA	{"email": "polina.kozlova_15051968@postgrespro.ru", "phone": "+70251670979"}
0005434082460	E6AD04	0135 006283	YULIYA BORISOVA	{"email": "borisova.yuliya-1970@postgrespro.ru", "phone": "+70153682402"}
0005434082461	AA6C43	2981 310570	VIKTOR VLASOV	{"phone": "+70647591491"}
0005434082462	AA6C43	8686 679712	TAMARA ZAKHAROVA	{"email": "zakharovat13101958@postgrespro.ru", "phone": "+70229898302"}
0005434082463	DBB000	5215 327553	OKSANA BELOVA	{"email": "o-belova.22051968@postgrespro.ru", "phone": "+70475537928"}
0005434082464	F723A4	7049 500074	DENIS VOLKOV	{"email": "volkov.denis.14051979@postgrespro.ru", "phone": "+70634856367"}
0005434082465	FC946F	8637 947656	ANDREY KISELEV	{"phone": "+70976389858"}
0005434082466	FC946F	6416 404338	DENIS NAUMOV	{"email": "naumov_denis_15071974@postgrespro.ru", "phone": "+70919654935"}
0005434082467	FC946F	7010 225986	LIDIYA KOMAROVA	{"email": "komarova_lidiya-1962@postgrespro.ru", "phone": "+70573461973"}
0005434082468	0D6456	0025 476814	ANATOLIY MIKHAYLOV	{"phone": "+70800315051"}
0005434082469	E2935D	0731 252736	KRISTINA SMIRNOVA	{"email": "smirnovakristina_061965@postgrespro.ru", "phone": "+70245382351"}
0005434082470	34853A	6089 073273	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey_081970@postgrespro.ru", "phone": "+70230749163"}
0005434082471	F78AA7	4585 395841	RUSTAM POPOV	{"email": "r.popov-041981@postgrespro.ru", "phone": "+70322936434"}
0005434082472	F78AA7	2261 604460	RIMA TIMOFEEVA	{"email": "timofeeva.rima_1964@postgrespro.ru", "phone": "+70992404507"}
0005434082473	9D8EEF	2025 182217	EGOR POPOV	{"email": "popov_egor031976@postgrespro.ru", "phone": "+70724437149"}
0005434082474	B7BE66	8636 499924	ELENA NOVIKOVA	{"phone": "+70278753281"}
0005434082475	B7BE66	2346 116101	YULIYA KONOVALOVA	{"phone": "+70319204419"}
0005434082476	CE8BE1	3442 443196	MARINA AKIMOVA	{"email": "m-akimova-30061976@postgrespro.ru", "phone": "+70779795237"}
0005434082477	FD4887	6323 914807	EVGENIY KULIKOV	{"email": "kulikov-e_1967@postgrespro.ru", "phone": "+70999082089"}
0005434082478	FD4887	8299 539030	ALEKSEY TARASOV	{"phone": "+70740720449"}
0005434082479	12572C	7886 684105	VITALIY SEMENOV	{"phone": "+70065745304"}
0005434082480	937BD3	0748 687566	LYUDMILA MAKSIMOVA	{"phone": "+70079910704"}
0005434082481	937BD3	2998 254232	SERGEY POPOV	{"phone": "+70049061861"}
0005434082482	937BD3	9116 943344	VALENTIN EGOROV	{"phone": "+70262143180"}
0005434082483	B66893	0772 900217	KRISTINA FADEEVA	{"email": "kristina.fadeeva_081959@postgrespro.ru", "phone": "+70822188119"}
0005434082484	0878CC	8497 043734	NIKOLAY ROMANOV	{"phone": "+70824521882"}
0005434082485	97CFD8	4794 376460	MARINA SERGEEVA	{"phone": "+70154158730"}
0005434082486	07F2A5	1484 045259	DIANA ALEKSANDROVA	{"email": "aleksandrova-diana_1965@postgrespro.ru", "phone": "+70666601085"}
0005434082487	28E7C9	1973 160358	ANDREY KUZNECOV	{"phone": "+70143755167"}
0005434082488	B2BCBF	9773 941938	MARINA ROMANOVA	{"email": "romanova_marina_091976@postgrespro.ru", "phone": "+70617106115"}
0005434082489	10E722	6582 440355	VALENTINA VOLKOVA	{"email": "volkova_v.061967@postgrespro.ru", "phone": "+70664777955"}
0005434082490	10E722	6748 734657	ALEKSANDRA KUZNECOVA	{"email": "kuznecova-a.081980@postgrespro.ru", "phone": "+70758762414"}
0005434082491	A59C75	7412 521381	ANASTASIYA ALEKSANDROVA	{"phone": "+70860701816"}
0005434082492	D8EEC3	5212 902819	OKSANA MAKAROVA	{"email": "makarova-oksana-091986@postgrespro.ru", "phone": "+70833782999"}
0005434082493	F89D88	0682 822453	VALENTINA SIDOROVA	{"email": "sidorova.valentina1963@postgrespro.ru", "phone": "+70738384793"}
0005434082494	790780	4902 722051	ELENA POTAPOVA	{"phone": "+70207643143"}
0005434082495	1EDE14	9965 092451	IRINA KISELEVA	{"email": "kiseleva_i101982@postgrespro.ru", "phone": "+70729819461"}
0005434082496	E93574	8941 855364	POLINA TITOVA	{"email": "titova_polina22111968@postgrespro.ru", "phone": "+70549774394"}
0005434082497	E93574	4751 998445	LYUBOV VOROBEVA	{"email": "l-vorobeva-121975@postgrespro.ru", "phone": "+70253503592"}
0005434082498	82701B	6860 435883	YURIY ZAKHAROV	{"phone": "+70533715614"}
0005434082499	82701B	0958 775482	VIKTOR DENISOV	{"phone": "+70505062511"}
0005434082500	D808F8	6092 618540	TATYANA KALININA	{"email": "tatyana.kalinina051966@postgrespro.ru", "phone": "+70102564315"}
0005434082501	51A1E5	2768 081680	VYACHESLAV NIKOLAEV	{"phone": "+70641772070"}
0005434082502	773669	6098 515721	GALINA SERGEEVA	{"phone": "+70488536522"}
0005434082503	773669	9008 825749	IRINA CHERNOVA	{"email": "ichernova.1958@postgrespro.ru", "phone": "+70712094667"}
0005434082504	8F3DD9	2329 228379	VASILIY NIKOLAEV	{"phone": "+70379318440"}
0005434082505	8F3DD9	4242 056115	ELENA ANDREEVA	{"email": "eandreeva111980@postgrespro.ru", "phone": "+70480165360"}
0005434082506	D1BDC2	1147 223515	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr1969@postgrespro.ru", "phone": "+70490443978"}
0005434082507	9F1586	7340 208643	RAISA KUZMINA	{"email": "kuzmina_raisa_30121982@postgrespro.ru", "phone": "+70786849096"}
0005434082508	1A351D	9476 753306	RUSLAN POPOV	{"email": "r_popov-111976@postgrespro.ru", "phone": "+70636057441"}
0005434082509	1A351D	1999 005964	VASILIY SIDOROV	{"email": "sidorov.v-051971@postgrespro.ru", "phone": "+70270543079"}
0005434082510	1A351D	9252 757867	LYUBOV BOGDANOVA	{"phone": "+70923091608"}
0005434082511	0A24C9	7094 925158	DARYA MAKSIMOVA	{"phone": "+70418056915"}
0005434082513	23932B	9234 764463	EVGENIY ISAEV	{"email": "evgeniy-isaev.1976@postgrespro.ru", "phone": "+70184789967"}
0005434082514	2581CD	7952 180229	LIDIYA SOLOVEVA	{"phone": "+70043875925"}
0005434082515	2581CD	3327 201023	TATYANA TIKHONOVA	{"phone": "+70434429196"}
0005434082516	DBC4D3	5300 964792	ALEKSANDR FILIPPOV	{"phone": "+70812476852"}
0005434082517	33805B	8518 526113	OKSANA IVANOVA	{"email": "ivanovaoksana041967@postgrespro.ru", "phone": "+70493317943"}
0005434082518	33805B	1713 539544	MARINA ZOTOVA	{"email": "zotova-marina-1982@postgrespro.ru", "phone": "+70807658974"}
0005434082519	B21B4C	4575 367267	ANDREY ZHURAVLEV	{"email": "andrey.zhuravlev-011975@postgrespro.ru", "phone": "+70510876961"}
0005434082520	B21B4C	4599 249949	VLADIMIR KUZMIN	{"email": "vladimirkuzmin091968@postgrespro.ru", "phone": "+70075994029"}
0005434082521	D5F6AD	1697 259545	IGOR ALEKSANDROV	{"phone": "+70808366692"}
0005434082522	B61AB4	8036 824507	OLEG DENISOV	{"email": "o.denisov-1989@postgrespro.ru", "phone": "+70857841403"}
0005434082523	D30BC2	8848 373966	VLADIMIR DMITRIEV	{"phone": "+70696087436"}
0005434082524	1E43C4	2541 924965	TATYANA POPOVA	{"email": "popova.t-071972@postgrespro.ru", "phone": "+70497642848"}
0005434082525	F6CF5E	9141 750471	EKATERINA ZOTOVA	{"email": "ekaterina_zotova_041965@postgrespro.ru", "phone": "+70354079038"}
0005434082526	CBB66B	9543 913595	LEONID FOMIN	{"email": "leonid_fomin-1973@postgrespro.ru", "phone": "+70655821855"}
0005434082527	820F16	2723 384205	IRINA VASILEVA	{"email": "vasileva-i111980@postgrespro.ru", "phone": "+70470037795"}
0005434082528	D89F0B	1862 723855	ALEKSEY NIKITIN	{"phone": "+70763905021"}
0005434082529	8E44F9	6795 184692	ELENA GAVRILOVA	{"email": "e.gavrilova1968@postgrespro.ru", "phone": "+70823912863"}
0005434082530	82A661	5648 885457	ROMAN SCHERBAKOV	{"phone": "+70301770165"}
0005434082531	82A661	9778 991426	MARIYA YUDINA	{"email": "mariya.yudina_21061981@postgrespro.ru", "phone": "+70678585978"}
0005434082532	534A84	4284 277655	LYUDMILA SOLOVEVA	{"email": "soloveva.l-02121979@postgrespro.ru", "phone": "+70225068252"}
0005434082533	6B18DC	2732 393365	VALENTINA KAZAKOVA	{"email": "v.kazakova-1971@postgrespro.ru", "phone": "+70414084419"}
0005434082534	AF02E9	4121 288771	IGOR POPOV	{"email": "i-popov_121975@postgrespro.ru", "phone": "+70865430345"}
0005434082535	674A40	4170 907700	GULNARA EFREMOVA	{"email": "g_efremova021974@postgrespro.ru", "phone": "+70634570642"}
0005434082536	1FD714	0338 348107	ANASTASIYA MIRONOVA	{"email": "a-mironova101972@postgrespro.ru", "phone": "+70932594467"}
0005434082537	1FD714	6912 198565	ARTUR GRIGOREV	{"phone": "+70787043100"}
0005434082538	E4B344	0768 192093	ALENA PETROVA	{"phone": "+70169367188"}
0005434082539	A9524B	0492 585924	DMITRIY CHERNOV	{"email": "dmitriy_chernov-1974@postgrespro.ru", "phone": "+70144561528"}
0005434082601	6B8E48	4790 344315	ALEKSANDR ZAYCEV	{"phone": "+70473519039"}
0005434082540	937248	3140 297644	SOFYA ORLOVA	{"email": "orlova_sofya.07031976@postgrespro.ru", "phone": "+70826336056"}
0005434082541	937248	9196 304656	NIKOLAY BELOV	{"email": "nikolay.belov-14021970@postgrespro.ru", "phone": "+70257995217"}
0005434082542	A2491A	1864 881460	ANNA SIDOROVA	{"email": "sidorova_anna-26031982@postgrespro.ru", "phone": "+70563600092"}
0005434082543	CCA4AC	5315 957531	GENNADIY FROLOV	{"phone": "+70106013297"}
0005434082544	5B1E71	9624 648055	RUSTAM DMITRIEV	{"phone": "+70286052841"}
0005434082545	42427B	1904 226209	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev091975@postgrespro.ru", "phone": "+70463357134"}
0005434082546	42427B	7276 088922	DMITRIY ZHURAVLEV	{"email": "zhuravlevdmitriy-29081989@postgrespro.ru", "phone": "+70129209870"}
0005434082547	C3F199	6203 110768	EKATERINA IVANOVA	{"phone": "+70802252430"}
0005434082548	C3F199	6057 749263	TATYANA BELOVA	{"email": "belovatatyana061969@postgrespro.ru", "phone": "+70018212283"}
0005434082549	3DE452	0125 984449	SERGEY KONOVALOV	{"email": "s.konovalov06011975@postgrespro.ru", "phone": "+70771161673"}
0005434082550	7D037E	7746 303523	EKATERINA ERMAKOVA	{"email": "ermakova_e-1978@postgrespro.ru", "phone": "+70840963179"}
0005434082551	7D037E	2700 161795	ANNA VLASOVA	{"email": "vlasova_a.1971@postgrespro.ru", "phone": "+70555292222"}
0005434082552	E4F39C	4949 392801	ARTEM DMITRIEV	{"phone": "+70610972880"}
0005434082553	6F0499	1705 144199	MARIYA SERGEEVA	{"email": "sergeevam-14051957@postgrespro.ru", "phone": "+70708556038"}
0005434082554	6F0499	6440 032939	EVGENIY ANDREEV	{"email": "andreeve.1973@postgrespro.ru", "phone": "+70447711501"}
0005434082555	C28050	4432 685049	VALENTINA GERASIMOVA	{"email": "v-gerasimova-051969@postgrespro.ru", "phone": "+70319156596"}
0005434082556	9361E5	8407 032356	LYUBOV GERASIMOVA	{"phone": "+70984655481"}
0005434082557	D64B50	1530 151929	SERGEY MELNIKOV	{"phone": "+70783216958"}
0005434082558	D64B50	7463 645245	VALENTINA KOVALEVA	{"phone": "+70343061467"}
0005434082559	6C365C	9873 891553	OLGA FILATOVA	{"phone": "+70010037326"}
0005434082560	F86C08	1569 111622	ALEKSANDR SMIRNOV	{"phone": "+70361692193"}
0005434082561	11BD19	0394 361882	POLINA RYABOVA	{"phone": "+70051256257"}
0005434082562	7FB4E1	3645 210261	ELENA KOROLEVA	{"email": "ekoroleva-1974@postgrespro.ru", "phone": "+70229371847"}
0005434082563	ECB408	6457 448366	ANASTASIYA YAKOVLEVA	{"email": "ayakovleva_081976@postgrespro.ru", "phone": "+70404635805"}
0005434082564	6ABD71	2535 670748	MATVEY GUSEV	{"phone": "+70628994940"}
0005434082565	E0770C	6495 478259	ANTONINA ISAEVA	{"email": "isaeva_antonina-051978@postgrespro.ru", "phone": "+70125828822"}
0005434082566	E0770C	3828 741591	KRISTINA GAVRILOVA	{"email": "gavrilova.k_1975@postgrespro.ru", "phone": "+70469371808"}
0005434082567	4103D0	4307 940086	ELENA KUZNECOVA	{"email": "kuznecova_e.061979@postgrespro.ru", "phone": "+70945517977"}
0005434082568	4103D0	0021 004817	EKATERINA ARKHIPOVA	{"phone": "+70629609072"}
0005434082569	4103D0	7593 206390	VLADIMIR KUZNECOV	{"phone": "+70844346074"}
0005434082570	44BB15	4902 146964	KONSTANTIN ORLOV	{"phone": "+70614604600"}
0005434082571	44BB15	6770 387605	SVETLANA ZOTOVA	{"phone": "+70104001040"}
0005434082572	00D4A6	7888 299759	ALEKSANDR ALEKSANDROV	{"phone": "+70142533160"}
0005434082573	3E8842	5476 527388	ALEKSANDR SOROKIN	{"email": "a_sorokin051977@postgrespro.ru", "phone": "+70051407008"}
0005434082574	9FF9C0	8386 505893	ARINA POPOVA	{"phone": "+70420139388"}
0005434082575	85BAA8	8851 123930	OLGA IVANOVA	{"email": "ivanova-o.1979@postgrespro.ru", "phone": "+70617356219"}
0005434082576	90D19B	2029 540098	ANNA VOLKOVA	{"email": "anna.volkova_121964@postgrespro.ru", "phone": "+70524519562"}
0005434082577	EB156F	9718 541046	MARIYA ZAKHAROVA	{"email": "mzakharova031973@postgrespro.ru", "phone": "+70754878660"}
0005434082578	EB156F	0403 437744	LYUBOV SOROKINA	{"phone": "+70238746886"}
0005434082579	C0AA73	3800 295187	SVETLANA NAUMOVA	{"phone": "+70273303276"}
0005434082580	193566	8125 243229	ALEKSANDR VASILEV	{"email": "vasilevaleksandr-051969@postgrespro.ru", "phone": "+70443515678"}
0005434082581	193566	5447 673210	ELENA EGOROVA	{"phone": "+70520010960"}
0005434082582	F0C6F9	4810 210211	SERGEY GUSEV	{"email": "sergeygusev071965@postgrespro.ru", "phone": "+70622290725"}
0005434082583	159C5C	9678 918143	MAKSIM MELNIKOV	{"email": "maksim.melnikov29011976@postgrespro.ru", "phone": "+70548272612"}
0005434082584	9A1AAC	2560 929804	LYUDMILA ERMAKOVA	{"phone": "+70441909972"}
0005434082585	09B1E2	3989 559331	TATYANA GUSEVA	{"email": "t_guseva-1979@postgrespro.ru", "phone": "+70956970141"}
0005434082586	E14F13	4790 120917	SERGEY AFANASEV	{"phone": "+70190597304"}
0005434082587	B2CB1A	1646 033702	SERGEY SEMENOV	{"phone": "+70475307682"}
0005434082588	B2CB1A	6142 366928	OLGA TIMOFEEVA	{"email": "o_timofeeva05021971@postgrespro.ru", "phone": "+70064994376"}
0005434082589	2130A4	6182 574424	VALERIY VOROBEV	{"phone": "+70052734704"}
0005434082590	EC9B87	2172 689716	EVGENIY ALEKSANDROV	{"email": "e.aleksandrov-17121965@postgrespro.ru", "phone": "+70225800421"}
0005434082591	E15188	2281 914909	STANISLAV RODIONOV	{"email": "stanislav_rodionov_121956@postgrespro.ru", "phone": "+70319904550"}
0005434082592	E15188	6025 894228	VALERIY FEDOTOV	{"phone": "+70676069269"}
0005434082593	D7B141	4253 947290	TATYANA SCHERBAKOVA	{"phone": "+70164159500"}
0005434082594	8CA387	1529 504980	VLADIMIR FOMIN	{"phone": "+70862308517"}
0005434082595	F2A57A	2416 419371	VYACHESLAV FROLOV	{"email": "frolov-v-1979@postgrespro.ru", "phone": "+70819700969"}
0005434082596	7B5853	9624 889561	SERGEY KUZMIN	{"phone": "+70383372115"}
0005434082597	7B5853	2888 146428	IRINA IVANOVA	{"phone": "+70514424340"}
0005434082598	7B5853	5111 608241	EGOR KUZNECOV	{"email": "kuznecove101976@postgrespro.ru", "phone": "+70142530099"}
0005434082599	88C69A	3587 780651	SERGEY SCHERBAKOV	{"phone": "+70512008969"}
0005434082600	6B8E48	8268 229333	GALINA MAKSIMOVA	{"phone": "+70559022360"}
0005434082602	FF1C8C	4086 052154	NINA NOVIKOVA	{"phone": "+70208170609"}
0005434082603	BFB05A	1235 742564	KONSTANTIN PETROV	{"phone": "+70719666520"}
0005434082604	5282EF	2851 987205	YURIY KUZNECOV	{"phone": "+70509534595"}
0005434082605	5282EF	6592 442516	ANASTASIYA ZAKHAROVA	{"phone": "+70036195541"}
0005434082606	F741CA	2499 032903	IRINA MEDVEDEVA	{"email": "irina-medvedeva1972@postgrespro.ru", "phone": "+70903626360"}
0005434082607	9D39C6	1749 675336	ALEKSANDRA ANDREEVA	{"phone": "+70836729057"}
0005434082608	D62BAA	8108 576119	NINA KOLESNIKOVA	{"email": "ninakolesnikova031969@postgrespro.ru", "phone": "+70294814651"}
0005434082609	31DC5B	8091 661381	ALEKSANDR MELNIKOV	{"phone": "+70219409105"}
0005434082610	0B6D34	5044 736914	VLADIMIR ISAEV	{"phone": "+70585372869"}
0005434082611	0B6D34	9326 227768	SERGEY BORISOV	{"email": "borisov.s.1963@postgrespro.ru", "phone": "+70432996210"}
0005434082612	DD240F	9217 515519	VALERIY MATVEEV	{"phone": "+70342569175"}
0005434082613	60DBB4	1702 217026	YURIY KUZMIN	{"email": "ykuzmin-1974@postgrespro.ru", "phone": "+70619475278"}
0005434082614	775B06	5078 895017	DMITRIY PETROV	{"phone": "+70047743351"}
0005434082615	49FFF5	7761 833318	MARIYA SMIRNOVA	{"email": "m_smirnova-051985@postgrespro.ru", "phone": "+70250675142"}
0005434082616	F324C9	3118 041525	NADEZHDA DANILOVA	{"phone": "+70188026169"}
0005434082617	E6F65E	2211 740886	SVETLANA IVANOVA	{"email": "ivanova.svetlana051975@postgrespro.ru", "phone": "+70334030814"}
0005434082618	83CA40	0530 556769	GALINA ZAKHAROVA	{"email": "galinazakharova-021967@postgrespro.ru", "phone": "+70470229246"}
0005434082619	83CA40	8722 708389	VASILIY KONOVALOV	{"email": "vasiliykonovalov_1970@postgrespro.ru", "phone": "+70480991834"}
0005434082620	8F9CB8	7955 309675	TATYANA VOLKOVA	{"email": "tatyanavolkova-1966@postgrespro.ru", "phone": "+70254453950"}
0005434082621	823CC9	2312 563167	SVETLANA NAZAROVA	{"email": "s-nazarova.02101972@postgrespro.ru", "phone": "+70195708867"}
0005434082622	823CC9	6523 831148	NATALYA FOMINA	{"phone": "+70826031215"}
0005434082623	8F871D	7022 060791	TATYANA STEPANOVA	{"phone": "+70964183464"}
0005434082624	2F5AE3	6823 094335	MIKHAIL PAVLOV	{"phone": "+70212512581"}
0005434082625	35D246	7380 506171	ANNA EFREMOVA	{"phone": "+70131445688"}
0005434082626	AD0BCC	1020 571568	KRISTINA VASILEVA	{"phone": "+70312561834"}
0005434082627	D1DA2D	1631 385380	NATALYA MALYSHEVA	{"phone": "+70257350396"}
0005434082628	FE36BB	0067 845314	TATYANA PAVLOVA	{"email": "pavlova_t_04061976@postgrespro.ru", "phone": "+70100785279"}
0005434082629	DCA665	8312 067394	VLADIMIR DENISOV	{"phone": "+70902968567"}
0005434082630	2CB800	6472 893339	ANDREY MOROZOV	{"email": "andrey.morozov.071977@postgrespro.ru", "phone": "+70036887915"}
0005434082631	EFB431	4447 063464	ALEKSANDR MOROZOV	{"email": "morozov-a_27041977@postgrespro.ru", "phone": "+70628746645"}
0005434082632	EFB431	7046 404068	GENNADIY PAVLOV	{"email": "g_pavlov.1970@postgrespro.ru", "phone": "+70769404058"}
0005434082633	D7C190	2312 027389	NINA FOMINA	{"email": "fomina-nina1966@postgrespro.ru", "phone": "+70172134312"}
0005434082634	641197	1623 864862	VLADIMIR SEMENOV	{"phone": "+70614989222"}
0005434082635	641197	6846 661979	VERA LEBEDEVA	{"email": "v-lebedeva_02121967@postgrespro.ru", "phone": "+70326981128"}
0005434082636	38DEE8	9183 728801	IVAN MAKAROV	{"email": "makarov-i-051976@postgrespro.ru", "phone": "+70436103878"}
0005434082637	2D83B5	5341 496067	LYUBOV KUZMINA	{"email": "l_kuzmina.031975@postgrespro.ru", "phone": "+70310763657"}
0005434082638	B087E0	3473 884288	SVETLANA MOROZOVA	{"phone": "+70961316352"}
0005434082639	4246A2	8328 801978	IRINA KALININA	{"phone": "+70590841929"}
0005434082640	BC92AD	2799 894059	LEONID NIKITIN	{"email": "nikitin_leonid_16051973@postgrespro.ru", "phone": "+70348942546"}
0005434082641	22063E	9930 920530	DAMIR MAKAROV	{"email": "makarov-damir-1971@postgrespro.ru", "phone": "+70632135964"}
0005434082642	22063E	1882 042021	ARSENIY MAKSIMOV	{"phone": "+70393219194"}
0005434082643	5C05ED	7397 097082	NATALYA ROMANOVA	{"email": "natalya-romanova-05061974@postgrespro.ru", "phone": "+70235416287"}
0005434082644	5C05ED	6814 328790	ANATOLIY SOKOLOV	{"email": "sokolov.anatoliy1967@postgrespro.ru", "phone": "+70287166211"}
0005434082645	CD7DC5	7409 997782	SVETLANA NOVIKOVA	{"email": "novikova-svetlana071966@postgrespro.ru", "phone": "+70385646924"}
0005434082646	CD7DC5	6150 337577	IGOR GORBUNOV	{"email": "gorbunov_i_07101977@postgrespro.ru", "phone": "+70380068030"}
0005434082647	9A85F8	1958 407283	ALINA LAZAREVA	{"phone": "+70028772953"}
0005434082648	7C5B49	1981 988975	ANATOLIY MAKAROV	{"email": "anatoliy_makarov-06121969@postgrespro.ru", "phone": "+70700569715"}
0005434082649	7C5B49	7369 713389	VYACHESLAV KUZNECOV	{"phone": "+70258122325"}
0005434082650	DC8A52	6363 055111	ANASTASIYA RODIONOVA	{"phone": "+70181242400"}
0005434082651	DC8A52	4790 968675	KIRILL BELOV	{"email": "belov_k-021970@postgrespro.ru", "phone": "+70419135631"}
0005434082652	77535E	6256 335184	VERA MIRONOVA	{"email": "v_mironova-071972@postgrespro.ru", "phone": "+70191210213"}
0005434084903	3DC677	7116 916090	ELENA LUKYANOVA	{"phone": "+70974612811"}
0005434084848	1103F4	9214 147895	TAMARA ZHURAVLEVA	{"phone": "+70269875520"}
0005434084849	36633C	1802 639565	VLADIMIR MAKSIMOV	{"email": "maksimov.v_041973@postgrespro.ru", "phone": "+70519544413"}
0005434084850	36633C	8511 366071	PETR PETROV	{"email": "petrovpetr_1970@postgrespro.ru", "phone": "+70340472488"}
0005434084851	2C8672	2850 664580	LYUDMILA ABRAMOVA	{"email": "abramovalyudmila26101974@postgrespro.ru", "phone": "+70480643603"}
0005434084852	3E1988	0977 219210	IRINA RYABOVA	{"phone": "+70369866705"}
0005434084853	581BA2	8625 950343	VLADIMIR KRASNOV	{"email": "v-krasnov1971@postgrespro.ru", "phone": "+70764090931"}
0005434084854	581BA2	8494 553048	ALEKSEY GERASIMOV	{"email": "aleksey.gerasimov.16031973@postgrespro.ru", "phone": "+70501908377"}
0005434084855	F1A6D0	8921 193957	ANATOLIY KUZNECOV	{"phone": "+70232481956"}
0005434084856	F1A6D0	3699 851411	IVAN KUZNECOV	{"phone": "+70243468693"}
0005434084857	F1A6D0	5578 590040	NADEZHDA PETROVA	{"email": "petrova.nadezhda_081966@postgrespro.ru", "phone": "+70812597356"}
0005434084858	FCFF8B	1090 664860	NINA MAKAROVA	{"email": "makarovan.06051977@postgrespro.ru", "phone": "+70747841894"}
0005434084859	FCFF8B	2741 129891	SANIYA NIKITINA	{"email": "saniya-nikitina1979@postgrespro.ru", "phone": "+70685848810"}
0005434084860	EEA0A5	4371 628255	LYUDMILA VOROBEVA	{"phone": "+70717702264"}
0005434084861	7AF63A	5415 502982	SERGEY SIDOROV	{"phone": "+70812803774"}
0005434084862	DABCAB	4156 024510	SERGEY TIMOFEEV	{"phone": "+70721632756"}
0005434084863	4BDE89	4149 596633	ARINA KOZLOVA	{"email": "kozlova-arina_1968@postgrespro.ru", "phone": "+70265103990"}
0005434084864	79E5D8	3401 363507	YURIY IVANOV	{"phone": "+70645637069"}
0005434084865	ABCA1F	1822 009987	VLADIMIR ZHUKOV	{"phone": "+70514788869"}
0005434084866	BA5C9B	4191 663846	YULIYA VASILEVA	{"phone": "+70431932055"}
0005434084867	36FA7C	2100 714453	IRINA MIKHAYLOVA	{"phone": "+70372883911"}
0005434084868	58BD38	7113 907772	ILYA PETROV	{"email": "i-petrov.011974@postgrespro.ru", "phone": "+70847013573"}
0005434084869	65FF65	8473 001476	OKSANA OSIPOVA	{"email": "osipova-o09101965@postgrespro.ru", "phone": "+70718886277"}
0005434084870	A614AF	7897 259526	GALINA MAKAROVA	{"email": "galina.makarova-1966@postgrespro.ru", "phone": "+70263205038"}
0005434084871	6C570F	3630 624795	ANNA OSIPOVA	{"phone": "+70772434144"}
0005434084872	86ECF3	3625 523335	ROMAN ZAKHAROV	{"email": "zakharov.roman-1977@postgrespro.ru", "phone": "+70280868985"}
0005434084873	C0463E	1905 203674	VIKTOR IVANOV	{"email": "viktor_ivanov18091971@postgrespro.ru", "phone": "+70899688654"}
0005434084874	4C716D	7557 991306	SERGEY SMIRNOV	{"phone": "+70621738341"}
0005434084875	83998B	0642 215028	NINA ZHUKOVA	{"phone": "+70527960957"}
0005434084876	83998B	9063 905050	NATALYA VASILEVA	{"email": "vasileva-natalya_091971@postgrespro.ru", "phone": "+70295121932"}
0005434084877	83998B	7409 823440	DARYA ISAEVA	{"email": "disaeva_041960@postgrespro.ru", "phone": "+70557399123"}
0005434084878	747591	3907 908262	ELENA VASILEVA	{"phone": "+70002158581"}
0005434084879	6434D2	0916 462538	POLINA EGOROVA	{"phone": "+70184624091"}
0005434084880	6434D2	1835 687982	ALEKSEY ROMANOV	{"email": "alekseyromanov_06051973@postgrespro.ru", "phone": "+70576373848"}
0005434084881	6434D2	4002 958666	ALEKSANDR KONOVALOV	{"phone": "+70123449155"}
0005434084882	06DCAC	9825 941411	SERGEY PETROV	{"phone": "+70207177459"}
0005434084883	06DCAC	7749 606217	VALENTINA MOISEEVA	{"phone": "+70848511453"}
0005434084884	C8B123	5980 259833	ANDREY GAVRILOV	{"phone": "+70857033033"}
0005434084885	0920A8	7186 576628	VADIM KUDRYASHOV	{"phone": "+70593313446"}
0005434084886	0920A8	7461 776590	ARTEM PETROV	{"email": "a.petrov.27061973@postgrespro.ru", "phone": "+70000887122"}
0005434084887	E30052	7594 166091	SERGEY FROLOV	{"email": "frolov-sergey_011970@postgrespro.ru", "phone": "+70459566292"}
0005434084888	E30052	9767 122054	EKATERINA MAKAROVA	{"phone": "+70374860144"}
0005434084889	3A2A4E	9300 651777	NIKOLAY NOVIKOV	{"phone": "+70858696912"}
0005434084890	F087BB	0318 155429	IGOR ABRAMOV	{"email": "i-abramov.1978@postgrespro.ru", "phone": "+70730868594"}
0005434084891	B93453	3829 850933	EDUARD TIKHONOV	{"email": "e-tikhonov1970@postgrespro.ru", "phone": "+70077448132"}
0005434084892	60A8A4	8463 771815	MARIYA ANDREEVA	{"phone": "+70733389541"}
0005434084893	60A8A4	2155 488890	GALINA IVANOVA	{"email": "ivanova-g031981@postgrespro.ru", "phone": "+70677171091"}
0005434084894	60A8A4	1808 961113	KSENIYA SMIRNOVA	{"email": "k-smirnova_1971@postgrespro.ru", "phone": "+70491345471"}
0005434084895	60A8A4	5366 818993	ALEKSANDR PAVLOV	{"phone": "+70605827028"}
0005434084896	C29A23	2099 189702	SERGEY ILIN	{"phone": "+70057860289"}
0005434084897	EB21D2	8655 817607	SERGEY ALEKSANDROV	{"phone": "+70349150706"}
0005434084898	F113FA	8534 049956	ELENA KALININA	{"email": "kalinina_e-121976@postgrespro.ru", "phone": "+70974207072"}
0005434084899	F113FA	8698 265444	MAKSIM ANDREEV	{"email": "andreev-m_1970@postgrespro.ru", "phone": "+70624675294"}
0005434084900	897100	1833 746627	DANIIL SEMENOV	{"email": "daniil_semenov-23081984@postgrespro.ru", "phone": "+70890811477"}
0005434084901	359F16	8688 007138	NATALYA POPOVA	{"phone": "+70390755440"}
0005434084902	359F16	1869 188847	LYUDMILA ORLOVA	{"phone": "+70103244104"}
0005434084904	3DC677	0608 619659	MAKSIM IVANOV	{"phone": "+70757498720"}
0005434084905	5BFAF2	1888 672557	LYUBOV VASILEVA	{"email": "lyubov_vasileva.18091978@postgrespro.ru", "phone": "+70484712477"}
0005434084906	FB7F90	2481 594097	SERGEY TIMOFEEV	{"phone": "+70760541855"}
0005434084907	FB7F90	2673 105931	VERA KUZNECOVA	{"email": "vera.kuznecova1988@postgrespro.ru", "phone": "+70916529217"}
0005434084908	14D77E	0817 299127	YULIYA RODIONOVA	{"email": "yuliya_rodionova.27011974@postgrespro.ru", "phone": "+70263749867"}
0005434084909	14D77E	4410 311517	ALEKSEY KRASNOV	{"email": "krasnov-a_081966@postgrespro.ru", "phone": "+70717443922"}
0005434084910	3FE112	4988 351225	VLADIMIR GERASIMOV	{"email": "gerasimovvladimir.1966@postgrespro.ru", "phone": "+70218385067"}
0005434084911	3FE112	8629 606212	VIKTOR NOVIKOV	{"email": "novikov-v-041983@postgrespro.ru", "phone": "+70379534817"}
0005434084912	2C6B97	2864 063623	GALINA KUZNECOVA	{"email": "kuznecovag03071964@postgrespro.ru", "phone": "+70081243786"}
0005434084913	2C6B97	2002 044514	EVGENIY GAVRILOV	{"email": "gavrilov-evgeniy111971@postgrespro.ru", "phone": "+70189028411"}
0005434084914	2C6B97	5854 311602	OKSANA FILIPPOVA	{"email": "filippova.o29101967@postgrespro.ru", "phone": "+70023289645"}
0005434084915	09F178	0837 394383	ANATOLIY MATVEEV	{"phone": "+70195839582"}
0005434084916	32024B	5548 569219	TAISIYA KUZMINA	{"email": "taisiya-kuzmina_25031979@postgrespro.ru", "phone": "+70470770602"}
0005434084917	5BBD62	1867 943235	NATALYA KOZLOVA	{"email": "kozlova-n071962@postgrespro.ru", "phone": "+70767480589"}
0005434084918	138A52	7473 537704	ANDREY RODIONOV	{"email": "andrey_rodionov1976@postgrespro.ru", "phone": "+70931536741"}
0005434084919	7F73CD	4749 938993	ALEKSEY VLASOV	{"phone": "+70537376160"}
0005434084920	4DE7D0	9991 951285	EKATERINA MAKSIMOVA	{"email": "maksimova-ekaterina06121968@postgrespro.ru", "phone": "+70844076333"}
0005434084921	4DE7D0	5042 633554	NATALYA MATVEEVA	{"phone": "+70865491130"}
0005434084922	A6CF61	5621 419718	RUSLAN ZHUKOV	{"phone": "+70352388438"}
0005434084923	A6CF61	3664 403811	NINA TIMOFEEVA	{"email": "n_timofeeva-11071968@postgrespro.ru", "phone": "+70913593776"}
0005434084924	A53CCD	7987 469830	VALENTINA NIKITINA	{"email": "nikitinav.1968@postgrespro.ru", "phone": "+70357239600"}
0005434084925	FF90BA	3117 870021	EVGENIYA PETROVA	{"email": "evgeniya_petrova1978@postgrespro.ru", "phone": "+70735555565"}
0005434084926	222669	8726 591965	SVETLANA EGOROVA	{"email": "egorova_s.1962@postgrespro.ru", "phone": "+70557836733"}
0005434084927	222669	5118 187646	ALEKSANDR STEPANOV	{"phone": "+70402581837"}
0005434084928	A46866	8951 627342	EVGENIY MAKAROV	{"phone": "+70535350752"}
0005434084929	BFAB9C	4052 355732	MARIYA VOLKOVA	{"email": "volkova-mariya_061965@postgrespro.ru", "phone": "+70302389180"}
0005434084930	CC6539	6873 872791	SERGEY VLASOV	{"email": "sergey-vlasov.09061967@postgrespro.ru", "phone": "+70016593821"}
0005434084931	17FD84	1477 111957	NATALYA KOZLOVA	{"email": "n.kozlova_1960@postgrespro.ru", "phone": "+70331957893"}
0005434084932	17FD84	9956 768058	TAGIR FILIPPOV	{"phone": "+70080244438"}
0005434084933	628569	6041 013719	TATYANA ZHUKOVA	{"phone": "+70817311958"}
0005434084934	89F2E4	9551 784993	EKATERINA FILIPPOVA	{"phone": "+70306217275"}
0005434084935	89F2E4	3092 408404	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko25081975@postgrespro.ru", "phone": "+70418874737"}
0005434084936	D08615	4602 831610	ANDREY FOMIN	{"email": "fomina.24081964@postgrespro.ru", "phone": "+70413006127"}
0005434084937	725A0E	4757 266017	ANTON KARPOV	{"email": "karpovanton-1979@postgrespro.ru", "phone": "+70714676814"}
0005434084938	7F51F4	9116 656142	VIKTOR ALEKSANDROV	{"email": "v.aleksandrov_1969@postgrespro.ru", "phone": "+70849612135"}
0005434084939	233361	3865 427561	NATALYA POLYAKOVA	{"email": "polyakovanatalya-17101980@postgrespro.ru", "phone": "+70632783935"}
0005434084940	6B1A60	3815 227989	EKATERINA FROLOVA	{"email": "e_frolova-021956@postgrespro.ru", "phone": "+70354139614"}
0005434084941	251CA5	3705 469191	DMITRIY ORLOV	{"email": "orlov.dmitriy.1975@postgrespro.ru", "phone": "+70082373136"}
0005434084942	251CA5	0992 538432	VLADIMIR MAKAROV	{"email": "makarov_v.1973@postgrespro.ru", "phone": "+70071536235"}
0005434084943	25EE4E	6527 148485	ELENA POPOVA	{"phone": "+70971453639"}
0005434084944	25EE4E	1208 763231	YURIY IVANOV	{"email": "ivanovyuriy_1969@postgrespro.ru", "phone": "+70665556029"}
0005434084945	83245A	7617 434918	SERGEY FEDOROV	{"email": "sergey-fedorov-28091967@postgrespro.ru", "phone": "+70788485769"}
0005434084946	AECAE8	9410 555510	YULIYA KONDRATEVA	{"email": "yuliya-kondrateva.041976@postgrespro.ru", "phone": "+70094367043"}
0005434084947	AECAE8	3505 051085	SVETLANA POPOVA	{"phone": "+70054534067"}
0005434084948	3DADF6	6829 064102	MARINA KULIKOVA	{"email": "kulikovamarina-12021964@postgrespro.ru", "phone": "+70806091377"}
0005434084949	9C9B5D	4542 285332	IRINA ANDREEVA	{"phone": "+70368627509"}
0005434084950	ED3568	5220 171215	VIKTORIYA KUZMINA	{"phone": "+70566138730"}
0005434084951	7DE97D	9007 620563	VALENTINA ZAYCEVA	{"email": "zayceva.valentina-031981@postgrespro.ru", "phone": "+70644526940"}
0005434084952	7DE97D	1088 383205	NIKITA VOLKOV	{"email": "volkov.nikita-1969@postgrespro.ru", "phone": "+70141781001"}
0005434084953	00AC52	1245 753560	VERA STEPANOVA	{"phone": "+70859519929"}
0005434084954	8AB08F	4970 167650	MARINA ROMANOVA	{"phone": "+70656221217"}
0005434084955	BD2835	6438 402843	LIDIYA BORISOVA	{"email": "borisova.lidiya.021971@postgrespro.ru", "phone": "+70391404286"}
0005434084956	4E2688	9817 959324	NIKITA STEPANOV	{"email": "nikitastepanov1967@postgrespro.ru", "phone": "+70521089799"}
0005434084957	4E2688	8393 440561	ELENA BORISOVA	{"phone": "+70793022980"}
0005434084958	AC31FB	1213 370821	VALENTINA ZHURAVLEVA	{"email": "valentina_zhuravleva_071974@postgrespro.ru", "phone": "+70418250003"}
0005434084959	94E529	1529 739411	ALEKSANDR KAZAKOV	{"email": "akazakov_24011973@postgrespro.ru", "phone": "+70436676615"}
0005434084960	7FB35D	9119 537544	YULIYA TIMOFEEVA	{"email": "timofeevayuliya1977@postgrespro.ru", "phone": "+70634303212"}
0005434084961	7CADD4	2972 640255	MARINA FEDOROVA	{"phone": "+70487720547"}
0005434084962	9B24C8	0573 074462	DMITRIY FEDOTOV	{"email": "fedotovd_091974@postgrespro.ru", "phone": "+70802042783"}
0005434084963	9B24C8	6696 435148	NIKOLAY POPOV	{"phone": "+70131376992"}
0005434084964	9B24C8	0786 097296	KRISTINA VASILEVA	{"email": "vasileva-k.091965@postgrespro.ru", "phone": "+70039456518"}
0005434084965	8B3D5F	7962 532714	ANZHELIKA NAUMOVA	{"phone": "+70635558030"}
0005434084966	8B3D5F	5205 242580	SVETLANA VOROBEVA	{"phone": "+70367236626"}
0005434084967	7FB391	7044 590856	YURIY IVANOV	{"phone": "+70162176296"}
0005434084968	CB6653	2551 087716	ALEKSANDR VOLKOV	{"phone": "+70397663144"}
0005434084969	CB6653	8273 899487	OLGA ZAYCEVA	{"email": "zaycevaolga_1973@postgrespro.ru", "phone": "+70133614543"}
0005434084970	566AEF	9535 146191	ALEKSEY MAKAROV	{"email": "makarov.aleksey-30071973@postgrespro.ru", "phone": "+70305534752"}
0005434084971	7C93D9	1980 732536	DENIS DENISOV	{"phone": "+70414053129"}
0005434084972	9E58CC	5468 223592	GALINA IVANOVA	{"phone": "+70279497495"}
0005434084973	094D86	7526 448655	VASILIY TIKHONOV	{"phone": "+70211085118"}
0005434084974	20CB79	1906 752158	ALEKSEY BELOV	{"phone": "+70199266503"}
0005434084975	20CB79	6496 738574	MIKHAIL YAKOVLEV	{"phone": "+70649951280"}
0005434084976	20CB79	7472 528842	YULIYA FEDOROVA	{"email": "fedorova_yuliya.1966@postgrespro.ru", "phone": "+70775989813"}
0005434084977	0FF4CC	8615 634243	EVGENIYA DANILOVA	{"email": "danilova.e.10101961@postgrespro.ru", "phone": "+70636135655"}
0005434084978	CFD173	6458 250292	VLADIMIR MIRONOV	{"email": "vladimir-mironov.011974@postgrespro.ru", "phone": "+70438387747"}
0005434084979	CFD173	8375 880179	ANATOLIY AFANASEV	{"email": "a-afanasev-101973@postgrespro.ru", "phone": "+70010374171"}
0005434084980	8EE3B3	7351 075522	ANASTASIYA PETROVA	{"email": "anastasiyapetrova.03101967@postgrespro.ru", "phone": "+70428293025"}
0005434084981	F4394E	7756 903680	ALEKSANDR ANDREEV	{"phone": "+70069699087"}
0005434084982	F4394E	0226 854487	NATALYA POPOVA	{"phone": "+70783157434"}
0005434084983	DB2A4F	1606 501560	NIKOLAY KAZAKOV	{"email": "kazakov_n_30051971@postgrespro.ru", "phone": "+70623152676"}
0005434084984	7686C5	7829 755041	VYACHESLAV KOZLOV	{"email": "kozlov-v_24091975@postgrespro.ru", "phone": "+70427487723"}
0005434084985	7686C5	6114 199612	KONSTANTIN MAKSIMOV	{"phone": "+70037648876"}
0005434084986	8AAD87	8495 098834	SERGEY IVANOV	{"email": "sergey-ivanov081981@postgrespro.ru", "phone": "+70523727116"}
0005434084987	1A4B06	4764 893713	SERGEY ZAKHAROV	{"email": "sergey.zakharov_061975@postgrespro.ru", "phone": "+70214714429"}
0005434084988	1A4B06	6627 122687	LYUDMILA VLASOVA	{"email": "vlasova.l20101964@postgrespro.ru", "phone": "+70270883330"}
0005434084989	769453	0955 584004	NATALYA NOVIKOVA	{"phone": "+70100226491"}
0005434084990	10E110	1838 279746	DANILA ANDREEV	{"phone": "+70987306690"}
0005434084991	95B9F7	4263 280781	KRISTINA NIKITINA	{"phone": "+70574736991"}
0005434084992	9A5717	1007 703821	SERGEY ALEKSANDROV	{"phone": "+70609689509"}
0005434084993	7406F8	2294 834033	SERGEY SOROKIN	{"phone": "+70658475769"}
0005434084994	D3D938	9183 782052	ALEKSANDR NAZAROV	{"phone": "+70354772817"}
0005434084995	D3D938	2005 206825	ALINA ZHURAVLEVA	{"phone": "+70107443472"}
0005434084996	51CB82	9377 588689	NIKOLAY BARANOV	{"email": "baranov.n-1965@postgrespro.ru", "phone": "+70353132154"}
0005434084997	87368D	1064 484800	DENIS IVANOV	{"email": "denis-ivanov071969@postgrespro.ru", "phone": "+70252831524"}
0005434084998	87368D	1074 562317	ELENA YAKOVLEVA	{"phone": "+70418478965"}
0005434084999	87368D	7356 642156	ARTEM POPOV	{"email": "popov.a.11051975@postgrespro.ru", "phone": "+70757372472"}
0005434085000	8FB3A7	5835 751861	NIKOLAY MARTYNOV	{"phone": "+70837476455"}
0005434085001	0BE353	8113 937649	ANNA BOGDANOVA	{"phone": "+70942541772"}
0005434085002	9C4502	6567 219814	MIKHAIL MEDVEDEV	{"phone": "+70133976806"}
0005434085003	4E6741	8015 874896	TAMARA YUDINA	{"phone": "+70908677469"}
0005434085004	9E117F	9656 201660	VALERIY FEDOTOV	{"phone": "+70241922219"}
0005434085005	9E117F	0580 626629	NATALYA KOZLOVA	{"email": "kozlova-natalya-071970@postgrespro.ru", "phone": "+70413266669"}
0005434085006	256DFA	9076 262643	MAKSIM BORISOV	{"phone": "+70073788422"}
0005434085007	ECB33C	2858 776439	DANILA MEDVEDEV	{"phone": "+70584932867"}
0005434085008	E57498	4952 506641	KIRILL PAVLOV	{"email": "pavlov_kirill_1980@postgrespro.ru", "phone": "+70114811271"}
0005434085009	E66CC9	1364 304902	SERGEY SCHERBAKOV	{"email": "scherbakov_s02121974@postgrespro.ru", "phone": "+70153722518"}
0005434085010	E66CC9	1780 982766	VLADIMIR SMIRNOV	{"phone": "+70292354926"}
0005434085011	2C8FEE	4314 385197	MARIYA ZAYCEVA	{"email": "m.zayceva_1975@postgrespro.ru", "phone": "+70336003063"}
0005434085012	1FAB6A	1471 311188	MARINA TIKHONOVA	{"phone": "+70631355404"}
0005434085013	1FAB6A	5202 151241	MARIYA MAKSIMOVA	{"email": "mariya-maksimova-02061970@postgrespro.ru", "phone": "+70764626938"}
0005434085014	875EE8	4661 986896	LYUDMILA LUKYANOVA	{"phone": "+70576234688"}
0005434085015	57985D	1080 505697	ZAKHAR SIDOROV	{"phone": "+70064389181"}
0005434085016	A49D19	6632 704973	GALINA KOVALEVA	{"phone": "+70833054943"}
0005434085017	96A226	6625 523622	MAKSIM SMIRNOV	{"phone": "+70268258710"}
0005434085018	64BF9E	6673 096940	LIDIYA GRISHINA	{"email": "grishina-l1966@postgrespro.ru", "phone": "+70894214860"}
0005434085019	E78755	2447 258128	TAISIYA MAKAROVA	{"email": "makarovat.25041977@postgrespro.ru", "phone": "+70587232076"}
0005434085020	ECF8E8	1277 396689	MIKHAIL DENISOV	{"email": "m_denisov_27021967@postgrespro.ru", "phone": "+70944445359"}
0005434085021	C5A9AE	9740 375362	VLADIMIR MELNIKOV	{"phone": "+70876834546"}
0005434085022	033733	1269 328458	LYUBOV NESTEROVA	{"email": "nesterova-lyubov-28091977@postgrespro.ru", "phone": "+70887805994"}
0005434085023	E42542	1231 459176	ANTONINA MIKHAYLOVA	{"phone": "+70657205560"}
0005434085024	ED644E	0417 999223	LYUDMILA KUZMINA	{"email": "kuzmina.lyudmila.1971@postgrespro.ru", "phone": "+70561431759"}
0005434085025	7A0320	9587 119163	LEV ALEKSANDROV	{"email": "l.aleksandrov1978@postgrespro.ru", "phone": "+70023304574"}
0005434085026	A6559C	0188 320778	ALEKSANDR PETROV	{"phone": "+70274845874"}
0005434085027	23F7F2	7636 193389	NATALYA MAKAROVA	{"email": "n-makarova.071964@postgrespro.ru", "phone": "+70579566451"}
0005434085028	97A4B4	8044 309287	LYUBOV MAKAROVA	{"phone": "+70439109622"}
0005434085029	97A4B4	6147 944561	VLADIMIR ZAKHAROV	{"email": "zakharov_v.14121982@postgrespro.ru", "phone": "+70051397627"}
0005434085030	178821	8958 873436	NINA ANDREEVA	{"email": "andreevanina071968@postgrespro.ru", "phone": "+70755875180"}
0005434085031	178821	9670 249005	VLADIMIR MIKHAYLOV	{"email": "vladimir.mikhaylov.051955@postgrespro.ru", "phone": "+70545075350"}
0005434085032	178821	8580 083414	DMITRIY ALEKSANDROV	{"email": "aleksandrov_dmitriy081957@postgrespro.ru", "phone": "+70775463268"}
0005434085033	FB5F19	2684 787834	LYUDMILA ANDREEVA	{"phone": "+70821006408"}
0005434085034	02DDC5	9187 203494	OKSANA MOROZOVA	{"email": "o-morozova1974@postgrespro.ru", "phone": "+70302682370"}
0005434085035	0ED2ED	7622 352235	ANATOLIY GERASIMOV	{"email": "anatoliy-gerasimov041974@postgrespro.ru", "phone": "+70598323503"}
0005434085036	BF5F47	8658 700698	VIKTOR BORISOV	{"phone": "+70814192024"}
0005434085037	195EB5	1873 181092	ELENA KUZNECOVA	{"email": "elena.kuznecova_21121966@postgrespro.ru", "phone": "+70566720082"}
0005434085038	A5068E	5892 602900	TIGRAN GRIGOREV	{"phone": "+70057662592"}
0005434085039	169549	2513 362971	RUSLAN BONDARENKO	{"email": "bondarenko.ruslan_121973@postgrespro.ru", "phone": "+70099630634"}
0005434085040	169549	9441 747936	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy071973@postgrespro.ru", "phone": "+70000995974"}
0005434085041	5A9CCF	2857 964949	TATYANA POPOVA	{"email": "tatyana.popova_02091968@postgrespro.ru", "phone": "+70091971297"}
0005434085042	5734D5	9444 872059	YURIY SAVELEV	{"email": "savelevyuriy-121975@postgrespro.ru", "phone": "+70764347177"}
0005434085043	670A8D	1185 914385	VIKTOR KUZNECOV	{"phone": "+70626024351"}
0005434085044	24AC6A	6343 875856	VERA MAKSIMOVA	{"email": "maksimova_v-11091968@postgrespro.ru", "phone": "+70208613468"}
0005434085045	870828	6478 846059	VALENTINA STEPANOVA	{"email": "v-stepanova1984@postgrespro.ru", "phone": "+70141399229"}
0005434085046	216E88	3648 588629	ALEKSANDR SOROKIN	{"phone": "+70951043504"}
0005434085047	2C0E1A	6566 388322	KRISTINA PETROVA	{"phone": "+70713958070"}
0005434085048	B0FB8C	2934 245846	NADEZHDA SOKOLOVA	{"email": "nadezhda_sokolova_101995@postgrespro.ru", "phone": "+70856978927"}
0005434085049	B0FB8C	5853 916690	EKATERINA EFIMOVA	{"email": "efimova.ekaterina.061960@postgrespro.ru", "phone": "+70721202219"}
0005434085050	FA404A	0788 956211	LYUDMILA VOROBEVA	{"email": "vorobeva-lyudmila.121982@postgrespro.ru", "phone": "+70664281944"}
0005434085051	758156	1436 486055	MIKHAIL FEDOTOV	{"email": "mikhail.fedotov_26061966@postgrespro.ru", "phone": "+70901719349"}
0005434085052	758156	2440 500801	NATALYA NIKOLAEVA	{"phone": "+70424627225"}
0005434085053	01CB44	6315 144378	MAKSIM RODIONOV	{"phone": "+70324991976"}
0005434085054	DDB1BE	4989 931182	NATALYA BELOVA	{"email": "n-belova-011962@postgrespro.ru", "phone": "+70201999150"}
0005434085055	C8E67D	6657 227429	ANDREY SERGEEV	{"email": "andrey_sergeev-1975@postgrespro.ru", "phone": "+70354770863"}
0005434085056	898CF0	0563 772596	ANATOLIY MAKAROV	{"phone": "+70276080048"}
0005434085057	898CF0	0920 623073	NATALYA KONDRATEVA	{"email": "natalya.kondrateva1980@postgrespro.ru", "phone": "+70681253424"}
0005434085058	573C8C	5589 198857	IGOR SOROKIN	{"phone": "+70455953922"}
0005434085059	2A2A7F	5933 646704	KRISTINA VOLKOVA	{"email": "volkova_k_111979@postgrespro.ru", "phone": "+70623538212"}
0005434085060	D226FD	0630 468382	SERGEY NIKITIN	{"email": "nikitin.s1975@postgrespro.ru", "phone": "+70873259104"}
0005434085061	DDAC65	2490 598870	LYUDMILA SOKOLOVA	{"phone": "+70551485712"}
0005434085062	CBFF93	9391 358958	SERGEY BONDARENKO	{"phone": "+70753896298"}
0005434085063	24100E	4184 256761	PETR KUZMIN	{"phone": "+70194503147"}
0005434085064	C8FBDD	6185 793558	MURAD MARTYNOV	{"phone": "+70922494037"}
0005434085065	C8FBDD	2884 678430	VLADIMIR POPOV	{"email": "vladimir.popov.1978@postgrespro.ru", "phone": "+70735376382"}
0005434087427	BF67BD	5175 947759	ELENA ZHURAVLEVA	{"phone": "+70153397210"}
0005434087428	BF67BD	8187 109012	IRINA EGOROVA	{"email": "egorova.i24031973@postgrespro.ru", "phone": "+70971493791"}
0005434087429	48292F	3176 985289	MARIYA SOLOVEVA	{"phone": "+70528046115"}
0005434087430	6EA19D	6637 535734	ALBINA BELYAEVA	{"phone": "+70406028648"}
0005434087431	22C6D2	1367 848218	LIDIYA NOVIKOVA	{"email": "l-novikova_041981@postgrespro.ru", "phone": "+70927673070"}
0005434087432	20FD6D	3650 917683	TATYANA DANILOVA	{"email": "danilovatatyana-1986@postgrespro.ru", "phone": "+70875257846"}
0005434087433	D0FF84	6867 132834	ELENA POPOVA	{"email": "e.popova121983@postgrespro.ru", "phone": "+70998052557"}
0005434087434	49439A	9879 043262	TATYANA DMITRIEVA	{"email": "t_dmitrieva1981@postgrespro.ru", "phone": "+70678347726"}
0005434087435	49439A	9418 836273	LIDIYA KUDRYASHOVA	{"phone": "+70143083567"}
0005434087436	D8369E	5817 630810	FARIT ORLOV	{"phone": "+70178095999"}
0005434087437	A7F485	4006 471478	LYUBOV ALEKSEEVA	{"email": "alekseeval31071963@postgrespro.ru", "phone": "+70854348746"}
0005434087438	3FA1FE	3457 036376	MIKHAIL ILIN	{"email": "ilin_m_1973@postgrespro.ru", "phone": "+70943887271"}
0005434087439	3FA1FE	3226 710944	SERGEY PETROV	{"phone": "+70317068501"}
0005434087440	429DF1	8829 418061	VALERIY MEDVEDEV	{"phone": "+70733749181"}
0005434087441	5E61C3	0168 955171	LYUDMILA KULIKOVA	{"email": "kulikova-lyudmila.1978@postgrespro.ru", "phone": "+70767102472"}
0005434087442	D7E87E	7572 077902	YULIYA GUSEVA	{"email": "y.guseva_14021971@postgrespro.ru", "phone": "+70190723554"}
0005434087443	74624E	2667 004892	SERGEY NOVIKOV	{"email": "sergey.novikov-1972@postgrespro.ru", "phone": "+70985983400"}
0005434087444	E6285E	5713 890796	OLEG SOROKIN	{"email": "o_sorokin_031972@postgrespro.ru", "phone": "+70135421416"}
0005434087445	4FE30E	9269 417356	ARTEM ILIN	{"phone": "+70152327175"}
0005434087446	4FE30E	5108 717434	YURIY TARASOV	{"email": "tarasov_yuriy_28011977@postgrespro.ru", "phone": "+70978161285"}
0005434087447	DEB737	6513 279879	ALINA TIKHONOVA	{"phone": "+70957287302"}
0005434087448	3818C6	0209 995142	DMITRIY SOLOVEV	{"phone": "+70170049190"}
0005434087449	3818C6	1800 713265	ANDREY MAKAROV	{"email": "makarov_andrey02061969@postgrespro.ru", "phone": "+70103311719"}
0005434087450	56CB5E	4770 533993	ALEKSANDR MAKSIMOV	{"phone": "+70520380263"}
0005434087451	56CB5E	6825 717919	DMITRIY ROMANOV	{"email": "romanov_d091982@postgrespro.ru", "phone": "+70384852167"}
0005434087452	C6C60E	7078 863667	ELENA AKIMOVA	{"email": "akimovae15041969@postgrespro.ru", "phone": "+70957966692"}
0005434087453	C6C60E	7906 733258	EVGENIY KARPOV	{"phone": "+70062345579"}
0005434087454	45F492	1873 988932	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova.04061974@postgrespro.ru", "phone": "+70893158504"}
0005434087455	45F492	9786 252619	KRISTINA GORBUNOVA	{"phone": "+70177237574"}
0005434087456	45F492	4055 118607	SERGEY YAKOVLEV	{"phone": "+70850426215"}
0005434087457	45F492	0655 323019	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov_1979@postgrespro.ru", "phone": "+70621190402"}
0005434087458	1941A2	6404 690265	EKATERINA SOKOLOVA	{"email": "ekaterina_sokolova_051972@postgrespro.ru", "phone": "+70167110811"}
0005434087459	C4ACE5	2999 324943	MIKHAIL MATVEEV	{"email": "matveev.mikhail_09111970@postgrespro.ru", "phone": "+70250756325"}
0005434087460	C4ACE5	7629 742579	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov1978@postgrespro.ru", "phone": "+70100958701"}
0005434087461	9DE787	9777 952408	TATYANA PETROVA	{"email": "petrovatatyana_051977@postgrespro.ru", "phone": "+70652235840"}
0005434087462	9DE787	8674 298612	VIKTORIYA VOLKOVA	{"email": "volkova_v.21091968@postgrespro.ru", "phone": "+70533117477"}
0005434087463	6C225C	1671 857890	DMITRIY KUZNECOV	{"phone": "+70882655550"}
0005434087464	6C225C	3590 526068	ALEKSANDRA YAKOVLEVA	{"phone": "+70049645614"}
0005434087465	B3DF05	9765 402634	TATYANA KOROLEVA	{"email": "tatyana.koroleva_121986@postgrespro.ru", "phone": "+70546517165"}
0005434087466	B3DF05	4581 753433	VALENTINA KARPOVA	{"phone": "+70644420423"}
0005434087467	9C8F88	4641 743852	OLGA DMITRIEVA	{"email": "dmitrieva-o_1977@postgrespro.ru", "phone": "+70383266117"}
0005434087468	9C8F88	0342 095743	FEDOR DMITRIEV	{"email": "dmitriev-f.10041976@postgrespro.ru", "phone": "+70653036945"}
0005434087469	9C8F88	0327 498348	ANNA VLASOVA	{"email": "vlasova_a.18061968@postgrespro.ru", "phone": "+70630034649"}
0005434087470	CFCE05	0789 980123	ANTON KOZLOV	{"email": "anton_kozlov-031978@postgrespro.ru", "phone": "+70948205456"}
0005434087471	CFCE05	6128 314272	LYUDMILA POTAPOVA	{"phone": "+70195784170"}
0005434087472	712901	5922 783687	TATYANA GORBUNOVA	{"email": "gorbunova.t1964@postgrespro.ru", "phone": "+70005144613"}
0005434087473	D96E65	9403 431558	VADIM MIRONOV	{"email": "mironovv.12031977@postgrespro.ru", "phone": "+70813208858"}
0005434087474	D96E65	2397 189642	OLGA KONOVALOVA	{"phone": "+70742512927"}
0005434087475	F04C5E	7738 548714	VITALIY KUZNECOV	{"phone": "+70841598569"}
0005434087476	F04C5E	6112 062787	GEORGIY EGOROV	{"phone": "+70243481360"}
0005434087477	375EC4	3989 143432	NIKOLAY MEDVEDEV	{"phone": "+70904237913"}
0005434087478	375EC4	4719 742676	MARIYA MATVEEVA	{"phone": "+70964471529"}
0005434087479	E9AC2D	6689 235883	ANTON NIKITIN	{"phone": "+70307735040"}
0005434087480	E9AC2D	5040 896177	DENIS ZAYCEV	{"email": "d_zaycev-20031969@postgrespro.ru", "phone": "+70808709906"}
0005434087481	4F66B4	7296 848711	VLADIMIR YAKOVLEV	{"phone": "+70074084828"}
0005434087482	5CF899	2100 099808	YANA BORISOVA	{"phone": "+70209702085"}
0005434087483	EA3974	4262 769894	SERGEY IVANOV	{"phone": "+70294201112"}
0005434087484	6798D0	8920 264870	GALINA POPOVA	{"phone": "+70257144439"}
0005434087485	C476C6	1759 867359	ANVAR GERASIMOV	{"email": "a.gerasimov-1964@postgrespro.ru", "phone": "+70652177012"}
0005434087486	C476C6	9055 922970	SERGEY ABRAMOV	{"email": "sergey-abramov21041968@postgrespro.ru", "phone": "+70992159067"}
0005434087487	7E7934	8660 984233	ALISA IVANOVA	{"phone": "+70662259933"}
0005434087488	7E7934	3867 532335	KLARA ZAYCEVA	{"email": "zayceva.klara_20121979@postgrespro.ru", "phone": "+70268162135"}
0005434087489	5B1322	7076 787878	TATYANA SERGEEVA	{"phone": "+70784346342"}
0005434087490	C5480E	1913 387522	ALEKSEY MATVEEV	{"email": "aleksey_matveev-011978@postgrespro.ru", "phone": "+70809190902"}
0005434087491	5EB98C	4481 526847	ALEKSANDRA SERGEEVA	{"email": "sergeeva_a021976@postgrespro.ru", "phone": "+70099232826"}
0005434087492	5EB98C	7897 511140	ELENA KULIKOVA	{"phone": "+70321186766"}
0005434087493	3E38FA	5904 608995	ALEKSANDR DAVYDOV	{"email": "davydov.a.121976@postgrespro.ru", "phone": "+70503933787"}
0005434087494	06F217	4171 979258	VLADIMIR ZAKHAROV	{"phone": "+70575303000"}
0005434087495	06F217	0450 648998	DMITRIY PAVLOV	{"phone": "+70701732552"}
0005434087496	0226F6	4615 749050	ARMEN SEMENOV	{"email": "a_semenov_28041972@postgrespro.ru", "phone": "+70162641378"}
0005434087497	254689	4027 304349	ALINA AKIMOVA	{"phone": "+70729550835"}
0005434087498	916D71	8072 359333	VASILIY BORISOV	{"email": "borisov-vasiliy12051983@postgrespro.ru", "phone": "+70856909098"}
0005434087499	6FB6AB	3808 247769	OLGA ZHUKOVA	{"email": "o-zhukova.011985@postgrespro.ru", "phone": "+70975449580"}
0005434087500	B1E193	0576 750197	TATYANA KISELEVA	{"phone": "+70947892984"}
0005434087501	6CAF22	0660 187065	ALEKSEY TIKHONOV	{"phone": "+70946647526"}
0005434087502	192728	3880 352502	SVETLANA TIKHONOVA	{"email": "tikhonova-s_1968@postgrespro.ru", "phone": "+70711877399"}
0005434087503	192728	9661 102593	MARIYA MIKHAYLOVA	{"phone": "+70423547018"}
0005434087504	192728	4038 280252	VALERIY VOROBEV	{"email": "vorobev-valeriy_091969@postgrespro.ru", "phone": "+70247102699"}
0005434087505	737B38	7255 671410	SERGEY ZAKHAROV	{"phone": "+70393767125"}
0005434087506	A8BA29	2542 163435	MARINA BARANOVA	{"phone": "+70416533517"}
0005434087507	FB5B36	6847 774683	ALEKSANDR KUZMIN	{"email": "kuzmin_a.01031970@postgrespro.ru", "phone": "+70167135335"}
0005434087508	BD3AFC	5355 743001	VERA KISELEVA	{"email": "kiseleva-v-081971@postgrespro.ru", "phone": "+70715555041"}
0005434087509	840B8B	9851 614868	ELENA KISELEVA	{"email": "elena_kiseleva-121977@postgrespro.ru", "phone": "+70281706545"}
0005434087510	840B8B	5552 619963	NATALYA NIKOLAEVA	{"email": "natalyanikolaeva.05081972@postgrespro.ru", "phone": "+70573494241"}
0005434087511	D0E0E5	5302 818814	NELLYA DAVYDOVA	{"email": "davydova-nellya.27121975@postgrespro.ru", "phone": "+70104866911"}
0005434087512	DD37BC	7330 818093	YULIYA LOGINOVA	{"email": "yloginova.1972@postgrespro.ru", "phone": "+70593073203"}
0005434087513	45AEAC	5035 967184	VIKTOR MARTYNOV	{"email": "viktor.martynov_1959@postgrespro.ru", "phone": "+70436044899"}
0005434087514	45AEAC	9571 817507	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_s_04081965@postgrespro.ru", "phone": "+70082789867"}
0005434087515	4CB6CD	7521 044510	YURIY MEDVEDEV	{"email": "yuriy_medvedev_011973@postgrespro.ru", "phone": "+70549024634"}
0005434087516	4CB6CD	0618 523138	ANDREY KOZLOV	{"phone": "+70566409350"}
0005434087517	E79F07	3122 164609	ELENA STEPANOVA	{"email": "elenastepanova_13051979@postgrespro.ru", "phone": "+70643924418"}
0005434087518	E79F07	9158 793263	YANA NIKOLAEVA	{"phone": "+70876121373"}
0005434087519	047344	9087 394846	VLADIMIR PETROV	{"phone": "+70269195682"}
0005434087520	A210B9	9055 808981	ELENA BARANOVA	{"email": "baranova_e15081976@postgrespro.ru", "phone": "+70043453151"}
0005434087521	A210B9	9116 128637	IRINA SIDOROVA	{"phone": "+70313797651"}
0005434087522	0FE264	8268 048464	SVETLANA KOZLOVA	{"email": "svetlana_kozlova-07081965@postgrespro.ru", "phone": "+70852760677"}
0005434087523	EC61EC	4552 781671	ELENA VOLKOVA	{"email": "e-volkova101968@postgrespro.ru", "phone": "+70220337995"}
0005434087524	EC61EC	9417 627940	IRINA MAKAROVA	{"phone": "+70464965214"}
0005434087525	24DC6A	2078 513962	TATYANA BARANOVA	{"email": "t-baranova.031976@postgrespro.ru", "phone": "+70042897585"}
0005434087526	B9651B	5890 176507	SVETLANA POPOVA	{"phone": "+70288961452"}
0005434087527	BFAEE8	1017 324171	DMITRIY KOROLEV	{"email": "korolev_d-121965@postgrespro.ru", "phone": "+70120648066"}
0005434087528	D99C03	3726 471814	ALEKSANDR FILIPPOV	{"email": "filippova.07091977@postgrespro.ru", "phone": "+70221090045"}
0005434087529	9AEAAA	6406 308602	RIMMA CHERNOVA	{"email": "chernova-rimma_1972@postgrespro.ru", "phone": "+70201893359"}
0005434087530	9AEAAA	7374 740249	ANNA FEDOROVA	{"phone": "+70367352337"}
0005434087531	DA46ED	8803 943354	VASILIY POPOV	{"phone": "+70893365825"}
0005434087532	DA46ED	1589 149038	STANISLAV BELOV	{"email": "belov.stanislav_11051962@postgrespro.ru", "phone": "+70108459802"}
0005434087533	B477F5	6001 124342	IGOR SERGEEV	{"phone": "+70168734876"}
0005434087534	B477F5	1114 463752	YULIYA KUZNECOVA	{"email": "y_kuznecova.13121975@postgrespro.ru", "phone": "+70878500890"}
0005434087591	179FF9	1385 208702	SVETLANA POPOVA	{"phone": "+70677684147"}
0005434087535	0FD91B	4403 600288	TATYANA ALEKSEEVA	{"email": "t.alekseeva23051977@postgrespro.ru", "phone": "+70645500244"}
0005434087536	6BE994	6920 312858	SERGEY GRIGOREV	{"phone": "+70369775287"}
0005434087537	C08495	0824 042606	TATYANA POLYAKOVA	{"phone": "+70424005974"}
0005434087538	11263E	0994 295440	VIKTOR SOKOLOV	{"phone": "+70402486012"}
0005434087539	11263E	0438 404913	VALENTINA MALYSHEVA	{"email": "v_malysheva_031961@postgrespro.ru", "phone": "+70711034159"}
0005434087540	B82EC9	8240 731949	SVETLANA FOMINA	{"phone": "+70083530608"}
0005434087541	40C6BA	6361 719954	ANASTASIYA KRASNOVA	{"phone": "+70236360403"}
0005434087542	40C6BA	5019 415046	VALENTINA ZAKHAROVA	{"phone": "+70893380315"}
0005434087543	685CE7	1269 670184	ROMAN KOZLOV	{"email": "roman.kozlov.1966@postgrespro.ru", "phone": "+70842681224"}
0005434087544	22721A	7793 999512	YURIY PETROV	{"phone": "+70663151203"}
0005434087545	ADA606	5574 408986	ARTEM MOROZOV	{"phone": "+70140215641"}
0005434087546	ADA606	1260 546193	VIKTORIYA SIDOROVA	{"email": "sidorova.viktoriya1979@postgrespro.ru", "phone": "+70226129202"}
0005434087547	ACC194	1209 159141	VALENTINA POPOVA	{"phone": "+70209183047"}
0005434087548	D29236	1180 468371	YULIYA KUZMINA	{"email": "y.kuzmina.041978@postgrespro.ru", "phone": "+70336172794"}
0005434087549	D29236	3012 278443	PETR TARASOV	{"email": "petr_tarasov26091975@postgrespro.ru", "phone": "+70890949468"}
0005434087550	D29236	1759 765008	LEONID SERGEEV	{"phone": "+70644267229"}
0005434087551	574387	6918 744641	OLGA DENISOVA	{"phone": "+70356480196"}
0005434087552	93CB53	5987 938362	DMITRIY KONOVALOV	{"email": "konovalov_dmitriy091966@postgrespro.ru", "phone": "+70303428483"}
0005434087553	93CB53	9581 947263	IRINA TARASOVA	{"phone": "+70722434679"}
0005434087554	BC06C2	0964 077314	ILYA MOISEEV	{"phone": "+70259783853"}
0005434087555	463F48	1924 509544	ALEKSANDR KULIKOV	{"phone": "+70177248041"}
0005434087556	463F48	1748 020722	TAKHIR KUZNECOV	{"email": "t_kuznecov.27101976@postgrespro.ru", "phone": "+70067249412"}
0005434087557	F6CA08	6627 201314	VADIM GORBUNOV	{"phone": "+70274832596"}
0005434087558	F6CA08	1566 770199	ELIZAVETA MAKAROVA	{"phone": "+70218869646"}
0005434087559	C848F1	4543 085793	PAVEL SOROKIN	{"email": "sorokin.p051963@postgrespro.ru", "phone": "+70372661838"}
0005434087560	C848F1	7600 509789	MARINA SOROKINA	{"email": "msorokina-071980@postgrespro.ru", "phone": "+70625083588"}
0005434087561	E2BF17	7081 974012	KSENIYA MAKSIMOVA	{"email": "maksimova-kseniya.121983@postgrespro.ru", "phone": "+70515550497"}
0005434087562	E2BF17	8550 902157	VLADIMIR TIKHONOV	{"phone": "+70175420351"}
0005434087563	8A3773	9059 322931	VASILIY VOLKOV	{"phone": "+70882934344"}
0005434087564	8A3773	4567 006469	BORIS TIMOFEEV	{"phone": "+70425188279"}
0005434087565	559457	5311 712715	DANIL FROLOV	{"phone": "+70529059131"}
0005434087566	F3ECC2	6436 810061	NIKOLAY KULIKOV	{"email": "kulikov.n.1973@postgrespro.ru", "phone": "+70995590697"}
0005434087567	3ADE1C	3834 028806	VITALIY FILIPPOV	{"email": "v-filippov071978@postgrespro.ru", "phone": "+70392081587"}
0005434087568	3B87DC	2273 720546	VIKTORIYA KAZAKOVA	{"email": "kazakova.viktoriya-1972@postgrespro.ru", "phone": "+70708486371"}
0005434087569	3AD4C3	3345 482888	OLGA VOLKOVA	{"phone": "+70031158672"}
0005434087570	F6A0E8	4208 897618	TATYANA CHERNOVA	{"email": "chernova_tatyana_1970@postgrespro.ru", "phone": "+70676646326"}
0005434087571	F6A0E8	6658 843897	OLGA POPOVA	{"email": "popova-o.1966@postgrespro.ru", "phone": "+70532644911"}
0005434087572	CC7E59	2265 725329	PAVEL SERGEEV	{"email": "sergeevp.071978@postgrespro.ru", "phone": "+70309628607"}
0005434087573	A22A92	6363 006083	MARIYA KISELEVA	{"email": "kiselevamariya1970@postgrespro.ru", "phone": "+70341260207"}
0005434087574	A22A92	9794 089702	YULIYA SCHERBAKOVA	{"email": "scherbakovayuliya_1963@postgrespro.ru", "phone": "+70226075246"}
0005434087575	0200ED	2613 506665	TATYANA SCHERBAKOVA	{"phone": "+70536174245"}
0005434087576	A7F24B	5258 519207	ELENA CHERNOVA	{"email": "echernova25111968@postgrespro.ru", "phone": "+70257482790"}
0005434087577	C78DBE	8185 743236	FILIPP POPOV	{"phone": "+70336238136"}
0005434087578	11935E	1454 846129	MARINA KOZLOVA	{"phone": "+70560430282"}
0005434087579	57E701	7870 204743	SERGEY FEDOTOV	{"email": "fedotov.sergey.011973@postgrespro.ru", "phone": "+70365865610"}
0005434087580	B1A646	3265 857582	VLADIMIR IVANOV	{"phone": "+70070082058"}
0005434087581	3CF408	9722 138565	MARINA FROLOVA	{"email": "frolovamarina-15041999@postgrespro.ru", "phone": "+70520623457"}
0005434087582	3CF408	5656 990295	NINA VOLKOVA	{"phone": "+70992637857"}
0005434087583	B4CF0D	0283 920123	ALENA ROMANOVA	{"phone": "+70195704988"}
0005434087584	7ADC45	5427 661198	ALEKSEY SOROKIN	{"email": "sorokin-a_19011980@postgrespro.ru", "phone": "+70674445460"}
0005434087585	064F3E	3286 779961	ALFIYA KUDRYASHOVA	{"email": "alfiya.kudryashova20031977@postgrespro.ru", "phone": "+70207351178"}
0005434087586	A01B75	3733 149135	MAKSIM VOLKOV	{"email": "volkov_maksim.1971@postgrespro.ru", "phone": "+70279011741"}
0005434087587	A01B75	4998 136301	VLADISLAV VOLKOV	{"email": "vladislavvolkov03101980@postgrespro.ru", "phone": "+70375009429"}
0005434087588	EAE173	7344 149471	GALINA ZAYCEVA	{"phone": "+70100098379"}
0005434087589	41E975	0733 209972	IGOR SERGEEV	{"email": "sergeev_igor1972@postgrespro.ru", "phone": "+70573629914"}
0005434087590	41E975	4404 762769	NIKOLAY VLASOV	{"email": "nikolayvlasov.1975@postgrespro.ru", "phone": "+70556011273"}
0005434087592	EC8D64	7077 652863	MIKHAIL TIMOFEEV	{"phone": "+70511500350"}
0005434087593	6C99B7	8794 358748	LYUDMILA POLYAKOVA	{"email": "polyakova.lyudmila-111970@postgrespro.ru", "phone": "+70337938220"}
0005434087594	6C99B7	3034 370590	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov_11091979@postgrespro.ru", "phone": "+70513117723"}
0005434087595	E0370A	6910 633708	FEDOR POPOV	{"email": "popov_fedor-1974@postgrespro.ru", "phone": "+70754185446"}
0005434087596	E0370A	7354 887712	IVAN YAKOVLEV	{"phone": "+70589245756"}
0005434087597	907E14	6147 360765	YULIYA ALEKSANDROVA	{"phone": "+70729992229"}
0005434087598	907E14	2483 542279	RAISA SMIRNOVA	{"email": "raisa-smirnova_1971@postgrespro.ru", "phone": "+70270610360"}
0005434087599	269F20	1440 808784	NADEZHDA POPOVA	{"phone": "+70629223996"}
0005434087600	13D94E	0102 886621	MILENA MAKAROVA	{"phone": "+70385346291"}
0005434087601	A8F3F4	6994 516689	RIFAT MOROZOV	{"phone": "+70249315427"}
0005434087602	A8F3F4	5731 482042	NADEZHDA SERGEEVA	{"phone": "+70330588712"}
0005434087603	4923CC	4734 184922	VYACHESLAV MIKHAYLOV	{"email": "vyacheslav.mikhaylov.1967@postgrespro.ru", "phone": "+70443076708"}
0005434087604	4923CC	5752 608015	ANATOLIY SHEVCHENKO	{"phone": "+70958029925"}
0005434087605	947929	2636 425713	VIKTOR SCHERBAKOV	{"email": "scherbakov.viktor_041969@postgrespro.ru", "phone": "+70519038848"}
0005434087606	947929	3319 007477	IRINA ORLOVA	{"email": "orlova_irina18111967@postgrespro.ru", "phone": "+70266549554"}
0005434087607	2A100C	0880 084128	DMITRIY FOMIN	{"email": "d-fomin-061974@postgrespro.ru", "phone": "+70821220948"}
0005434087608	553A27	6783 844106	ANNA KONDRATEVA	{"phone": "+70517864284"}
0005434087609	553A27	0478 085415	ANDREY MIRONOV	{"email": "mironovandrey1967@postgrespro.ru", "phone": "+70335513248"}
0005434087610	B1AFE4	7814 400021	DENIS OSIPOV	{"email": "denisosipov1967@postgrespro.ru", "phone": "+70187298597"}
0005434087611	53E3E5	3201 486868	MARIYA ANDREEVA	{"email": "andreeva.m11051970@postgrespro.ru", "phone": "+70439206546"}
0005434087612	E862DB	5742 837295	SERGEY VASILEV	{"email": "vasilev.s.1969@postgrespro.ru", "phone": "+70050099692"}
0005434087613	E862DB	2012 417843	ALENA MEDVEDEVA	{"phone": "+70095907995"}
0005434087614	2BDA7F	8480 099084	SERGEY MARTYNOV	{"email": "martynov-sergey.081972@postgrespro.ru", "phone": "+70254836991"}
0005434087615	0BEC6D	8203 330687	POLINA STEPANOVA	{"email": "polina_stepanova21111981@postgrespro.ru", "phone": "+70054731270"}
0005434087616	27819D	6045 727939	EVGENIY BONDARENKO	{"email": "evgeniy_bondarenko-08121983@postgrespro.ru", "phone": "+70878031223"}
0005434087617	27819D	8127 728079	RUSLAN CHERNOV	{"email": "chernov_ruslan.26031963@postgrespro.ru", "phone": "+70159330079"}
0005434087618	3FF17B	5502 857524	OKSANA EGOROVA	{"email": "egorova-oksana011953@postgrespro.ru", "phone": "+70958437462"}
0005434087619	7A96DA	6180 824162	IVAN PETROV	{"email": "ipetrov_061977@postgrespro.ru", "phone": "+70472330900"}
0005434087620	485CC1	9035 846278	NADEZHDA YUDINA	{"phone": "+70859766973"}
0005434087621	875561	1362 084471	OLGA KULIKOVA	{"email": "kulikovaolga.121983@postgrespro.ru", "phone": "+70537812996"}
0005434087622	875561	7046 054484	SERGEY GUSEV	{"email": "gusev-s071979@postgrespro.ru", "phone": "+70008360114"}
0005434087623	102233	5194 120697	VERA KRASNOVA	{"email": "krasnova_vera.1971@postgrespro.ru", "phone": "+70914355565"}
0005434087624	5D0AA7	1756 225052	ZUKHRA FOMINA	{"phone": "+70520112996"}
0005434087625	52C7D8	3754 041423	MARIYA FILIPPOVA	{"email": "filippova_mariya.091991@postgrespro.ru", "phone": "+70600331726"}
0005434087626	4480AB	3819 708756	DMITRIY MAKAROV	{"email": "dmakarov-1964@postgrespro.ru", "phone": "+70699668789"}
0005434087627	A541D2	8455 948776	VALENTINA NIKOLAEVA	{"phone": "+70573358390"}
0005434087628	059457	1158 184409	ARKADIY SOKOLOV	{"phone": "+70481436333"}
0005434087629	4F9B55	4797 163565	SERGEY IVANOV	{"phone": "+70368928456"}
0005434087630	825247	8027 759317	EKATERINA PAVLOVA	{"email": "pavlova.e06041977@postgrespro.ru", "phone": "+70383519777"}
0005434087631	825247	1967 786544	SVETLANA ZAKHAROVA	{"phone": "+70194371531"}
0005434087632	825247	5958 572739	GALINA GAVRILOVA	{"email": "gavrilova_galina1979@postgrespro.ru", "phone": "+70523368641"}
0005434087633	3C2B45	1040 797622	VALENTINA RODIONOVA	{"email": "valentinarodionova.30081970@postgrespro.ru", "phone": "+70486586225"}
0005434087634	3C2B45	2811 842915	IGOR KUZNECOV	{"phone": "+70248493705"}
0005434087635	BFBE0D	0453 444933	LIDIYA DENISOVA	{"phone": "+70092649746"}
0005434087636	BFBE0D	4732 499756	ILGIZ FILIPPOV	{"email": "filippovilgiz_26011969@postgrespro.ru", "phone": "+70718068921"}
0005434087637	0BF3C5	9817 708909	NATALYA MAKAROVA	{"email": "natalya-makarova.08031959@postgrespro.ru", "phone": "+70443594672"}
0005434087638	0BF3C5	3006 095964	NADEZHDA SEMENOVA	{"phone": "+70178961636"}
0005434087639	DA713B	9437 513958	ANASTASIYA KRASNOVA	{"email": "a_krasnova_1975@postgrespro.ru", "phone": "+70389323857"}
0005434087640	DA713B	6791 098341	VIKTORIYA SOKOLOVA	{"phone": "+70722930917"}
0005434087641	33F9BC	7090 672571	VLADIMIR DAVYDOV	{"email": "v_davydov_19061966@postgrespro.ru", "phone": "+70285129991"}
0005434087642	21718A	3004 718176	TATYANA CHERNOVA	{"phone": "+70425739547"}
0005434087643	21718A	3292 026956	NIKOLAY MOISEEV	{"phone": "+70510444474"}
0005434087644	AD937C	3387 601853	VLADISLAV BONDARENKO	{"phone": "+70623750540"}
0005434087645	4DC172	9625 676068	IRINA POPOVA	{"email": "irina_popova.1965@postgrespro.ru", "phone": "+70163196313"}
0005434087646	4DC172	1720 989662	TATYANA IVANOVA	{"phone": "+70878779823"}
0005434087647	592F55	5742 710356	EKATERINA BELYAEVA	{"email": "belyaeva_ekaterina.10081955@postgrespro.ru", "phone": "+70287410716"}
0005434087648	57409A	3959 366275	EVGENIYA NIKIFOROVA	{"phone": "+70901985587"}
0005434087649	36C5E0	5551 671435	LYUDMILA KARPOVA	{"email": "karpova_lyudmila_081979@postgrespro.ru", "phone": "+70561129162"}
0005434087650	36C5E0	9096 335795	MIKHAIL ISAEV	{"phone": "+70085123967"}
0005434087651	CADCF3	8445 145418	OLEG NIKITIN	{"email": "o-nikitin.061970@postgrespro.ru", "phone": "+70087376923"}
0005434087652	BEDE19	2073 534458	YULIYA ANTONOVA	{"email": "antonova_y1977@postgrespro.ru", "phone": "+70991059742"}
0005434087653	70D59E	6001 031352	IRINA MAKAROVA	{"phone": "+70617189412"}
0005434087654	3CE4D0	8515 079186	OLESYA GAVRILOVA	{"phone": "+70533217805"}
0005434087655	3CE4D0	5600 779422	IVAN POPOV	{"phone": "+70206204235"}
0005434087918	630CA4	9205 058601	GENNADIY TIKHONOV	{"email": "tikhonov-gennadiy_041990@postgrespro.ru", "phone": "+70175217427"}
0005434087919	B1924C	7904 667593	VIKTOR NIKOLAEV	{"phone": "+70199895145"}
0005434087920	B1924C	4082 007109	ZINAIDA KUZNECOVA	{"phone": "+70425552850"}
0005434087921	B1924C	9300 237481	IRINA SOLOVEVA	{"email": "soloveva-irina1982@postgrespro.ru", "phone": "+70821956174"}
0005434087922	F8F92F	4085 734583	VALENTINA LAZAREVA	{"phone": "+70514196357"}
0005434087923	7CF128	3520 208800	NATALYA BOGDANOVA	{"phone": "+70915246310"}
0005434087924	7CF128	2449 167293	ANNA ZHUKOVA	{"phone": "+70969426465"}
0005434087925	7CF128	2712 408277	VLADISLAV VASILEV	{"email": "vasilev_v021970@postgrespro.ru", "phone": "+70996845901"}
0005434087926	A8D63D	1480 659911	ZOYA POLYAKOVA	{"email": "zpolyakova-1962@postgrespro.ru", "phone": "+70266967332"}
0005434087927	A8D63D	2353 031920	ARTEM NOVIKOV	{"email": "novikovartem051980@postgrespro.ru", "phone": "+70762467972"}
0005434087928	A8D63D	7886 054800	RISHAT ORLOV	{"phone": "+70902769586"}
0005434087929	A8C3B6	8591 060857	LYUBOV ALEKSEEVA	{"email": "alekseeva.l.13101970@postgrespro.ru", "phone": "+70512680651"}
0005434087930	BCA27A	5266 432058	ELIZAVETA NOVIKOVA	{"phone": "+70152670645"}
0005434087931	BCA27A	2923 846770	ULYANA POPOVA	{"email": "popovau.13101983@postgrespro.ru", "phone": "+70231866763"}
0005434087932	BCA27A	4275 895859	IOSIF MIKHAYLOV	{"phone": "+70751914860"}
0005434087933	06A6BF	8519 753473	ANDREY CHERNOV	{"email": "chernovandrey.061967@postgrespro.ru", "phone": "+70681554569"}
0005434087934	A87474	8767 925597	SERGEY GRIGOREV	{"email": "grigorev_s-1977@postgrespro.ru", "phone": "+70359035980"}
0005434087935	A87474	6789 963507	BORIS ZAYCEV	{"email": "boriszaycev-071972@postgrespro.ru", "phone": "+70117892676"}
0005434087936	A87474	1281 568013	ELENA KARPOVA	{"email": "karpova.elena1964@postgrespro.ru", "phone": "+70692594223"}
0005434087937	636D8B	1871 837326	VASILIY VOLKOV	{"phone": "+70936412843"}
0005434087938	A5429B	7681 326938	POLINA KOLESNIKOVA	{"email": "kolesnikovap17061985@postgrespro.ru", "phone": "+70435928428"}
0005434087939	3B83AB	4904 731792	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr.16091978@postgrespro.ru", "phone": "+70096176478"}
0005434087940	3B83AB	4476 556436	DMITRIY VASILEV	{"phone": "+70780513727"}
0005434087941	3B83AB	9826 786947	TATYANA IVANOVA	{"email": "tatyana_ivanova-051979@postgrespro.ru", "phone": "+70969615576"}
0005434087942	3B83AB	4912 420771	TATYANA KOZLOVA	{"phone": "+70790912414"}
0005434087943	BC04A1	7919 261656	VLADIMIR SEMENOV	{"phone": "+70139069228"}
0005434087944	D86AB1	8889 162196	VLADIMIR NAUMOV	{"phone": "+70683045424"}
0005434087945	2C992C	4939 974101	ALEKSEY OSIPOV	{"email": "osipov.a.1969@postgrespro.ru", "phone": "+70485037909"}
0005434087946	2C992C	2326 601066	ELENA OSIPOVA	{"phone": "+70587229701"}
0005434087947	5209A9	6933 416994	SERGEY IVANOV	{"phone": "+70015724358"}
0005434087948	9B533A	5469 374864	ALENA NESTEROVA	{"phone": "+70488453619"}
0005434087949	9B533A	0824 960430	VLADIMIR SOROKIN	{"email": "v_sorokin.22111970@postgrespro.ru", "phone": "+70082276126"}
0005434087950	145B20	6175 430259	VITALIY ALEKSEEV	{"email": "vitaliy-alekseev051975@postgrespro.ru", "phone": "+70964831962"}
0005434087951	FFE0BE	4481 978320	LYUBOV DANILOVA	{"phone": "+70894332841"}
0005434087952	FFE0BE	0135 132293	ANDREY MIKHAYLOV	{"phone": "+70516793799"}
0005434087953	9D951B	4437 510954	ELIZAVETA NAZAROVA	{"phone": "+70029695974"}
0005434087954	9D951B	0904 467739	EGOR BORISOV	{"phone": "+70010153230"}
0005434087955	BB6DFD	3842 671181	ANASTASIYA BORISOVA	{"phone": "+70659255278"}
0005434087956	3C3468	3634 130474	IRINA GUSEVA	{"email": "irinaguseva.081964@postgrespro.ru", "phone": "+70687100912"}
0005434087957	15B87F	0975 060326	PAVEL IVANOV	{"email": "pavel-ivanov.1968@postgrespro.ru", "phone": "+70997627250"}
0005434087958	38A480	8703 370240	IGOR KOROLEV	{"email": "korolevigor.18011987@postgrespro.ru", "phone": "+70000007965"}
0005434087959	38A480	8920 744822	SERGEY BARANOV	{"email": "baranov_s25031967@postgrespro.ru", "phone": "+70020249879"}
0005434087960	38A480	7214 301054	EGOR ANDREEV	{"phone": "+70671735744"}
0005434087961	F68901	0515 809867	NIKOLAY GERASIMOV	{"email": "nikolaygerasimov_041973@postgrespro.ru", "phone": "+70726399619"}
0005434087962	9EA5A9	6720 642084	VERA OVCHINNIKOVA	{"phone": "+70050460247"}
0005434087963	9EA5A9	7332 773373	LILIYA NOVIKOVA	{"email": "l-novikova1971@postgrespro.ru", "phone": "+70048188681"}
0005434087964	9021E5	7432 123454	VIKTORIYA ALEKSANDROVA	{"phone": "+70787563579"}
0005434087965	9021E5	6533 829983	KONSTANTIN NIKITIN	{"phone": "+70017630805"}
0005434087966	265DD8	2535 475815	ELENA FILIPPOVA	{"email": "elena-filippova.1961@postgrespro.ru", "phone": "+70412237941"}
0005434087967	25EDDF	6289 682870	LIDIYA KOROLEVA	{"email": "l_koroleva_1966@postgrespro.ru", "phone": "+70791368233"}
0005434087968	0E5B8D	4612 554298	ALEKSANDR VOROBEV	{"phone": "+70303815109"}
0005434087969	9B57D7	5087 376467	ALEKSEY VOROBEV	{"phone": "+70078441646"}
0005434087970	9B57D7	6295 069481	ANDREY ANDREEV	{"email": "andreev-a-101967@postgrespro.ru", "phone": "+70546165647"}
0005434087971	27C524	5374 407162	ARSENIY FEDOTOV	{"email": "fedotov-a021968@postgrespro.ru", "phone": "+70038855239"}
0005434087972	27C524	2278 958049	EVGENIY GUSEV	{"phone": "+70046900636"}
0005434087973	27C524	7345 627980	VARVARA KUZNECOVA	{"email": "kuznecova.varvara-1969@postgrespro.ru", "phone": "+70673930967"}
0005434087974	ACA4EB	2753 041860	ALEKSEY FEDOROV	{"phone": "+70066299334"}
0005434087975	3425E2	2167 980587	VLADIMIR SOLOVEV	{"email": "solovev-v.061968@postgrespro.ru", "phone": "+70661962249"}
0005434087976	7A38CB	6714 647951	ANATOLIY IVANOV	{"email": "ivanovanatoliy05061970@postgrespro.ru", "phone": "+70007673990"}
0005434087977	A0D425	4314 007595	ZOYA VOLKOVA	{"phone": "+70362639443"}
0005434087978	AD4F6A	2571 452004	NIKOLAY SOKOLOV	{"email": "n-sokolov1965@postgrespro.ru", "phone": "+70786599802"}
0005434087979	DDB5B2	0432 463192	GALINA RODIONOVA	{"email": "rodionovagalina.18071974@postgrespro.ru", "phone": "+70355119838"}
0005434087980	DDB5B2	2792 667313	SERGEY FEDOROV	{"phone": "+70416390665"}
0005434087981	F3A0A7	3611 600372	DMITRIY VOROBEV	{"email": "d-vorobev.111969@postgrespro.ru", "phone": "+70153957873"}
0005434087982	B1A3D4	6895 995673	SNEZHANA FROLOVA	{"phone": "+70070647785"}
0005434087983	29CE6C	4753 491687	ANDREY KARPOV	{"email": "karpov.andrey.1977@postgrespro.ru", "phone": "+70651753194"}
0005434087984	D6D173	8108 866818	VALENTINA FOMINA	{"email": "fominavalentina16061977@postgrespro.ru", "phone": "+70628886569"}
0005434087985	218FB8	2966 892099	NINA FILATOVA	{"email": "nina_filatova_1973@postgrespro.ru", "phone": "+70411190136"}
0005434087986	ACDDC7	1017 532095	SVETLANA LEBEDEVA	{"phone": "+70723334787"}
0005434087987	ACDDC7	0950 326323	SERGEY CHERNOV	{"email": "chernov.s-1962@postgrespro.ru", "phone": "+70247324974"}
0005434087988	ACDDC7	1033 398138	KRISTINA PETROVA	{"phone": "+70386736324"}
0005434087989	653E6F	6599 801747	MARINA ORLOVA	{"phone": "+70857494344"}
0005434087990	8C0281	9639 705256	OKSANA KISELEVA	{"phone": "+70665927220"}
0005434087991	2E2FDA	9406 028086	LIDIYA ZHUKOVA	{"phone": "+70926912584"}
0005434087992	539774	3489 438753	SVETLANA SOKOLOVA	{"email": "sokolovasvetlana081970@postgrespro.ru", "phone": "+70775689381"}
0005434087993	C48F5A	7589 889087	VALENTINA FEDOROVA	{"email": "v_fedorova.26111975@postgrespro.ru", "phone": "+70867793887"}
0005434087994	C48F5A	5717 300366	SVETLANA KUDRYASHOVA	{"email": "kudryashova-svetlana.101977@postgrespro.ru", "phone": "+70920642410"}
0005434087995	C48F5A	6108 962860	ELINA ZAYCEVA	{"email": "zaycevaelina.01101977@postgrespro.ru", "phone": "+70141179291"}
0005434087996	0DE345	8162 703039	DENIS SIDOROV	{"email": "denis.sidorov-31031974@postgrespro.ru", "phone": "+70698273225"}
0005434087997	0DE345	4272 181289	DMITRIY KRASNOV	{"email": "dmitriykrasnov-091979@postgrespro.ru", "phone": "+70577609596"}
0005434087998	052704	2998 902626	DANILA MELNIKOV	{"phone": "+70087848029"}
0005434087999	63075B	7462 600313	OKSANA DMITRIEVA	{"email": "oksana.dmitrieva06021970@postgrespro.ru", "phone": "+70615934584"}
0005434088000	92475B	7520 537490	EGOR BORISOV	{"phone": "+70755925186"}
0005434088001	BC7245	0951 009342	TAISIYA DAVYDOVA	{"phone": "+70415541942"}
0005434088002	B76DA4	8712 647680	OLGA NESTEROVA	{"email": "nesterova_o.011970@postgrespro.ru", "phone": "+70832182370"}
0005434088003	B76DA4	0734 329980	OLGA YUDINA	{"email": "oyudina-1986@postgrespro.ru", "phone": "+70154968482"}
0005434088004	8CFBA4	4289 022294	VLADIMIR KISELEV	{"phone": "+70156352313"}
0005434088005	AAE339	3808 767366	ROMAN MAKAROV	{"email": "r-makarov.041965@postgrespro.ru", "phone": "+70502724416"}
0005434088006	E80916	0496 723919	OLEG MOROZOV	{"email": "omorozov-1975@postgrespro.ru", "phone": "+70757768693"}
0005434088007	D83964	9023 260639	MARINA FEDOROVA	{"email": "fedorova.m021972@postgrespro.ru", "phone": "+70878290764"}
0005434088008	B4D0DB	9388 002865	NATALYA GRISHINA	{"phone": "+70955250159"}
0005434088009	A28885	4002 030714	SVETLANA KUZNECOVA	{"email": "kuznecova.s011972@postgrespro.ru", "phone": "+70022116007"}
0005434088010	793C15	4030 300573	YURIY ROMANOV	{"phone": "+70052536152"}
0005434088011	C2E1C4	5199 922493	VIKTOR KONOVALOV	{"email": "konovalovv-12031983@postgrespro.ru", "phone": "+70790158860"}
0005434088012	278EB7	7849 916751	SERGEY ZAKHAROV	{"email": "s-zakharov_061962@postgrespro.ru", "phone": "+70058117907"}
0005434088013	C97450	8506 300167	EGOR ZAKHAROV	{"email": "e_zakharov27051979@postgrespro.ru", "phone": "+70789196825"}
0005434088014	C97450	6805 169004	NIKOLAY MAKAROV	{"email": "n-makarov041972@postgrespro.ru", "phone": "+70387010543"}
0005434088015	2F2483	1326 313702	VALERIY KISELEV	{"email": "kiselev-v1971@postgrespro.ru", "phone": "+70461609170"}
0005434088016	43CC1A	8667 003493	NADEZHDA KOLESNIKOVA	{"email": "kolesnikova-nadezhda051974@postgrespro.ru", "phone": "+70328121835"}
0005434088017	D83229	4703 934990	MIKHAIL KRASNOV	{"email": "mikhail.krasnov-1965@postgrespro.ru", "phone": "+70809017647"}
0005434088018	8EFDF1	7082 309045	TAMARA KARPOVA	{"email": "t-karpova.051976@postgrespro.ru", "phone": "+70332662434"}
0005434088019	4BB28B	4198 043277	ELENA MIRONOVA	{"email": "emironova07061961@postgrespro.ru", "phone": "+70131454392"}
0005434088020	EA2127	6540 193343	POLINA VOROBEVA	{"email": "polina_vorobeva031981@postgrespro.ru", "phone": "+70484783753"}
0005434088021	EA2127	1263 608279	ROMAN IVANOV	{"phone": "+70183222459"}
0005434088022	AEE6C6	9259 245381	RAISA EGOROVA	{"email": "regorova-101965@postgrespro.ru", "phone": "+70980186253"}
0005434088023	B74450	4745 279153	RASHID YAKOVLEV	{"phone": "+70570152389"}
0005434088024	B74450	2692 970899	ANDREY ALEKSANDROV	{"email": "aleksandrovandrey-26111963@postgrespro.ru", "phone": "+70899695263"}
0005434088025	60C0EF	5993 609907	MIKHAIL ZHURAVLEV	{"phone": "+70334684776"}
0005434088026	60C0EF	4226 061321	GALINA TIMOFEEVA	{"phone": "+70096061348"}
0005434088027	DD5988	1468 315834	EVGENIY KISELEV	{"email": "kiselev.e_1974@postgrespro.ru", "phone": "+70318659938"}
0005434088028	12FA16	2828 924634	OLEG STEPANOV	{"phone": "+70775368989"}
0005434088029	B72751	3962 920939	NIKOLAY MAKAROV	{"phone": "+70706299540"}
0005434088030	672352	2876 906022	KAMILA ORLOVA	{"email": "korlova-101974@postgrespro.ru", "phone": "+70822056820"}
0005434088031	672352	7672 992391	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov-1975@postgrespro.ru", "phone": "+70365054143"}
0005434088032	0A3897	5797 524120	PAVEL SCHERBAKOV	{"email": "pavel-scherbakov_051962@postgrespro.ru", "phone": "+70155004304"}
0005434088033	0A3897	3809 033500	MIKHAIL DENISOV	{"email": "m_denisov-14101977@postgrespro.ru", "phone": "+70861388886"}
0005434088034	E7A991	0102 322889	ALEKSANDR SOROKIN	{"email": "sorokina101975@postgrespro.ru", "phone": "+70740741844"}
0005434088035	83434E	1511 064649	OLGA KOMAROVA	{"email": "komarova.o_101981@postgrespro.ru", "phone": "+70687182315"}
0005434088036	4613DF	6457 727227	KSENIYA AFANASEVA	{"phone": "+70121898115"}
0005434088037	3682A8	8744 899185	ALENA ERMAKOVA	{"phone": "+70883962648"}
0005434088038	3682A8	8626 246044	LYUBOV AKIMOVA	{"phone": "+70797217882"}
0005434088039	19763C	0574 669917	ELENA FROLOVA	{"email": "elenafrolova14111972@postgrespro.ru", "phone": "+70510525098"}
0005434088040	577B72	2480 416448	SERGEY FILIPPOV	{"email": "s.filippov1976@postgrespro.ru", "phone": "+70228494110"}
0005434088041	577B72	3623 345784	ALBERT ANTONOV	{"phone": "+70271187174"}
0005434088042	846429	9430 201297	VIKTOR BARANOV	{"phone": "+70861180547"}
0005434088043	39480B	4209 782559	ALEKSEY EGOROV	{"phone": "+70697736225"}
0005434088044	6C3A73	0176 992062	ILYA SMIRNOV	{"email": "ilya.smirnov21041982@postgrespro.ru", "phone": "+70925618015"}
0005434088045	B94603	8119 334344	ELENA KOROLEVA	{"phone": "+70576929029"}
0005434088046	363AFE	1993 722953	VASILISA SEMENOVA	{"email": "vasilisa-semenova.081984@postgrespro.ru", "phone": "+70928070801"}
0005434088050	80D9A4	4204 799925	VALERIY ZAKHAROV	{"email": "zakharov_valeriy.081963@postgrespro.ru", "phone": "+70732357683"}
0005434088051	80D9A4	4903 157278	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir.10111973@postgrespro.ru", "phone": "+70212292584"}
0005434088052	391F01	5028 681720	SVETLANA ZHUKOVA	{"phone": "+70264305344"}
0005434088053	5AE30D	3043 940910	EKATERINA BELOVA	{"email": "belova-ekaterina_26091984@postgrespro.ru", "phone": "+70984714988"}
0005434088054	5AE30D	7772 668159	EVGENIY BARANOV	{"phone": "+70409880732"}
0005434088055	951480	5548 566414	MIKHAIL ZHURAVLEV	{"email": "zhuravlev-mikhail1973@postgrespro.ru", "phone": "+70202226185"}
0005434088056	ED60A2	1373 768577	ALEKSEY ISAEV	{"phone": "+70252871219"}
0005434088057	ED60A2	0088 009484	NAZAR VASILEV	{"phone": "+70072078925"}
0005434088058	ED60A2	3295 741902	ALEKSEY KOZLOV	{"email": "kozlov-a-1968@postgrespro.ru", "phone": "+70567818270"}
0005434088059	3E0358	9345 256989	IVAN SEMENOV	{"phone": "+70426374049"}
0005434088060	3E0358	5566 360296	VLADIMIR TIKHONOV	{"email": "v_tikhonov_081978@postgrespro.ru", "phone": "+70499143851"}
0005434095228	F965F7	0909 692430	GENNADIY STEPANOV	{"phone": "+70074615897"}
0005434095015	50C54E	5991 526393	OLGA NIKIFOROVA	{"email": "olga-nikiforova_1965@postgrespro.ru", "phone": "+70997554492"}
0005434095016	525B10	1766 956873	ANDREY MELNIKOV	{"email": "a.melnikov.21101972@postgrespro.ru", "phone": "+70199738432"}
0005434095017	6B86DD	6913 808309	TAMARA KOLESNIKOVA	{"phone": "+70808753422"}
0005434095018	6B86DD	5955 486176	ROMAN MARTYNOV	{"email": "romanmartynov.1962@postgrespro.ru", "phone": "+70010028550"}
0005434095019	E01598	8308 876391	IGOR NOVIKOV	{"email": "novikov_i-04031966@postgrespro.ru", "phone": "+70713627113"}
0005434095020	D0B20E	6897 669931	VIKTORIYA ROMANOVA	{"phone": "+70072258189"}
0005434095021	2600A8	9101 675425	FAINA SOROKINA	{"phone": "+70131398102"}
0005434095022	2600A8	8309 959310	VYACHESLAV KONOVALOV	{"phone": "+70980019760"}
0005434095023	0993AF	7506 595687	GALINA NAZAROVA	{"phone": "+70906925483"}
0005434095024	A3AF39	6551 106605	SERGEY SIDOROV	{"email": "sidorovs-1973@postgrespro.ru", "phone": "+70199755280"}
0005434095025	407715	1820 806311	KIRILL MAKAROV	{"email": "makarov-kirill-1964@postgrespro.ru", "phone": "+70586945506"}
0005434095026	8B5093	7333 958361	ALEKSANDR SEMENOV	{"phone": "+70301660227"}
0005434095027	8B5093	8980 580471	IVAN IVANOV	{"phone": "+70717231091"}
0005434095028	950ACB	6862 867660	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-06121975@postgrespro.ru", "phone": "+70866537737"}
0005434095029	F150A5	7637 947132	ULYANA IVANOVA	{"email": "ulyana_ivanova.1969@postgrespro.ru", "phone": "+70779073836"}
0005434095030	529DBD	2969 468977	IVAN SOROKIN	{"email": "ivan.sorokin_021973@postgrespro.ru", "phone": "+70386274746"}
0005434095031	AE9B2C	0552 472626	VALENTINA ZOTOVA	{"email": "zotova.valentina-23021981@postgrespro.ru", "phone": "+70014863666"}
0005434095032	AE9B2C	6612 550742	ZAKHAR VASILEV	{"phone": "+70030276976"}
0005434095033	F6BCFE	6198 236132	MIKHAIL POPOV	{"phone": "+70125521389"}
0005434095034	F6BCFE	8514 811674	VERA ZHUKOVA	{"email": "zhukova_vera-1962@postgrespro.ru", "phone": "+70838645370"}
0005434095035	1D1B95	7810 265795	TATYANA FOMINA	{"email": "fominat-1977@postgrespro.ru", "phone": "+70367395428"}
0005434095036	1D1B95	5852 061229	IRINA VOLKOVA	{"email": "irinavolkova1973@postgrespro.ru", "phone": "+70155142748"}
0005434095037	018311	9915 862334	ALEKSANDR GAVRILOV	{"phone": "+70083651864"}
0005434095038	018311	0375 803508	ALEKSANDR ORLOV	{"phone": "+70503579783"}
0005434095039	665567	2366 327006	TAISIYA LAZAREVA	{"phone": "+70532435861"}
0005434095040	1E1A46	0148 037980	NATALYA TIMOFEEVA	{"email": "natalya.timofeeva101975@postgrespro.ru", "phone": "+70407921694"}
0005434095041	1E1A46	5518 853974	ALEKSANDR MEDVEDEV	{"phone": "+70825280296"}
0005434095042	1E1A46	7840 944871	ALEKSANDR VOLKOV	{"phone": "+70905321761"}
0005434095043	3E03E7	9444 390532	TATYANA GUSEVA	{"phone": "+70771618223"}
0005434095044	A8E250	8837 520180	SERGEY KAZAKOV	{"email": "sergey-kazakov_06051991@postgrespro.ru", "phone": "+70967037764"}
0005434095045	FF31B3	5557 240696	MIKHAIL GERASIMOV	{"phone": "+70113768268"}
0005434095046	FE9F61	7702 771541	ELENA TIKHONOVA	{"email": "tikhonova-elena.121973@postgrespro.ru", "phone": "+70958975708"}
0005434095047	B9B09B	1228 561095	ALEKSANDR MAKAROV	{"email": "makarova031968@postgrespro.ru", "phone": "+70776329825"}
0005434095048	26E27D	6156 112314	VASILIY VOLKOV	{"email": "volkovv1965@postgrespro.ru", "phone": "+70342270893"}
0005434095049	5CF089	8649 578962	DMITRIY KRASNOV	{"phone": "+70507427568"}
0005434095050	61BDE4	0758 498045	MIKHAIL PAVLOV	{"phone": "+70773939203"}
0005434095051	61BDE4	3638 334804	VYACHESLAV SOROKIN	{"phone": "+70080400297"}
0005434095052	61266E	2172 523022	SERGEY FROLOV	{"phone": "+70457331531"}
0005434095053	61266E	7529 864239	TIMUR KONOVALOV	{"email": "konovalovtimur22061970@postgrespro.ru", "phone": "+70121294914"}
0005434095054	61266E	1239 935627	NATALYA IVANOVA	{"phone": "+70223768744"}
0005434095055	C634FE	3871 987557	ALEKSANDR POPOV	{"phone": "+70252257433"}
0005434095056	C634FE	6925 575240	YULIYA IVANOVA	{"email": "ivanova.y-031987@postgrespro.ru", "phone": "+70842616464"}
0005434095057	27DAE0	1753 761912	YURIY KOZLOV	{"phone": "+70782383888"}
0005434095058	A3FF37	1185 131917	NINA TROFIMOVA	{"email": "n_trofimova-19121971@postgrespro.ru", "phone": "+70721167223"}
0005434095059	5E59C8	7590 598013	VLADIMIR POPOV	{"email": "popov.v.01111986@postgrespro.ru", "phone": "+70051157919"}
0005434095060	EAECA5	3994 279898	EKATERINA MEDVEDEVA	{"phone": "+70162147966"}
0005434095061	48546F	8508 361130	SVETLANA BOGDANOVA	{"email": "bogdanova-s-031965@postgrespro.ru", "phone": "+70457660747"}
0005434095062	48546F	2689 143719	RAISA ZOTOVA	{"email": "rzotova-21091978@postgrespro.ru", "phone": "+70924768638"}
0005434095063	48546F	9106 270332	ANDREY NOVIKOV	{"email": "a-novikov-12031971@postgrespro.ru", "phone": "+70444102054"}
0005434095064	3C8A92	7532 824249	VALENTINA ISAEVA	{"phone": "+70556904019"}
0005434095065	D6C115	3972 813707	ANASTASIYA GERASIMOVA	{"phone": "+70138892923"}
0005434095066	5F8290	2227 171109	SERGEY ZAYCEV	{"email": "zaycev-sergey18111975@postgrespro.ru", "phone": "+70238882222"}
0005434095067	5F8290	9221 106012	ALEKSEY NOVIKOV	{"phone": "+70783262090"}
0005434095068	121F96	3132 940228	DMITRIY SCHERBAKOV	{"phone": "+70085666024"}
0005434095069	121F96	8424 563580	EVDOKIYA SAVELEVA	{"phone": "+70897865527"}
0005434095070	97E5CB	9342 273030	LARISA EGOROVA	{"email": "egorovalarisa_24111968@postgrespro.ru", "phone": "+70521522851"}
0005434095071	6E1C11	4499 450261	ALEKSANDR TARASOV	{"phone": "+70102974546"}
0005434095072	45B803	4389 468057	ILYA DMITRIEV	{"email": "ilya-dmitriev_1968@postgrespro.ru", "phone": "+70268735794"}
0005434095073	45B803	1494 090800	GALINA SOKOLOVA	{"phone": "+70161867097"}
0005434095074	844D42	9370 421366	TATYANA MIKHAYLOVA	{"email": "t.mikhaylova-1965@postgrespro.ru", "phone": "+70662210261"}
0005434095075	44DC2F	6132 598913	IRINA ZHURAVLEVA	{"email": "zhuravlevairina-1973@postgrespro.ru", "phone": "+70422776398"}
0005434095076	44DC2F	1091 628568	VALENTINA MAKAROVA	{"email": "v_makarova_101980@postgrespro.ru", "phone": "+70693947646"}
0005434095077	2D420C	1253 611233	SERGEY VASILEV	{"phone": "+70992303951"}
0005434095078	2D420C	1111 991696	NADEZHDA KONOVALOVA	{"phone": "+70104921920"}
0005434095079	3DC646	4336 496023	IGOR FEDOROV	{"phone": "+70778242128"}
0005434095247	3D4E51	2503 806544	DMITRIY MOISEEV	{"phone": "+70325953274"}
0005434095080	461678	8664 348013	EKATERINA SCHERBAKOVA	{"email": "e-scherbakova.08041978@postgrespro.ru", "phone": "+70516076801"}
0005434095081	461678	0934 872892	ARTEM IVANOV	{"email": "ivanov.artem-15041969@postgrespro.ru", "phone": "+70067516015"}
0005434095082	461678	8752 518021	IRINA ZHUKOVA	{"phone": "+70651853056"}
0005434095083	E77CE8	1135 734629	ALEKSANDRA POTAPOVA	{"email": "potapova_aleksandra-091973@postgrespro.ru", "phone": "+70854002869"}
0005434095084	E77CE8	8526 846364	YULIYA MALYSHEVA	{"email": "malysheva.y.041970@postgrespro.ru", "phone": "+70457474158"}
0005434095085	FA9879	1730 457609	MARIYA VOLKOVA	{"email": "volkovamariya_26061968@postgrespro.ru", "phone": "+70344634494"}
0005434095086	0AD0C8	8042 600176	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a11011967@postgrespro.ru", "phone": "+70744226131"}
0005434095087	A360ED	0194 168732	VLADA SIDOROVA	{"email": "sidorova.vlada.101975@postgrespro.ru", "phone": "+70993581216"}
0005434095088	A360ED	2673 753137	SERGEY VASILEV	{"email": "sergeyvasilev_16041963@postgrespro.ru", "phone": "+70945704363"}
0005434095089	31AB0E	4582 314705	SERGEY RODIONOV	{"email": "sergeyrodionov_12121971@postgrespro.ru", "phone": "+70298256161"}
0005434095090	31AB0E	7802 360386	MIKHAIL FEDOTOV	{"phone": "+70187273868"}
0005434095091	2C6A42	6884 753125	EVGENIY MAKAROV	{"phone": "+70652801108"}
0005434095092	2C6A42	1388 165310	VIKTOR CHERNOV	{"email": "chernov.v13011973@postgrespro.ru", "phone": "+70424904520"}
0005434095093	13C4C4	3561 798664	ANDREY RODIONOV	{"email": "a.rodionov_1974@postgrespro.ru", "phone": "+70233142050"}
0005434095094	6083CB	4159 040360	MARIYA POPOVA	{"phone": "+70900229176"}
0005434095095	78C923	4089 506639	VASILIY MATVEEV	{"phone": "+70193792033"}
0005434095096	78C923	2072 270188	NIKOLAY SOKOLOV	{"phone": "+70858640940"}
0005434095097	2A7783	7043 197720	OLGA ALEKSEEVA	{"email": "olga.alekseeva-1973@postgrespro.ru", "phone": "+70220189885"}
0005434095098	3CCA1B	2427 066942	NATALYA MAKAROVA	{"email": "makarova.n021977@postgrespro.ru", "phone": "+70119910145"}
0005434095099	5ECAF5	6042 701819	TATYANA ZAYCEVA	{"phone": "+70991985804"}
0005434095100	5ECAF5	8103 508068	NATALYA KRASNOVA	{"email": "krasnova_n_31101973@postgrespro.ru", "phone": "+70121635497"}
0005434095101	EF9B74	3748 188072	DANIIL FEDOROV	{"email": "fedorov_daniil1972@postgrespro.ru", "phone": "+70808973412"}
0005434095102	EF9B74	0789 852411	VALENTIN TARASOV	{"email": "tarasov-v1979@postgrespro.ru", "phone": "+70220560736"}
0005434095103	1EC98C	5284 206479	KONSTANTIN BELOV	{"email": "konstantin-belov-091962@postgrespro.ru", "phone": "+70643321398"}
0005434095104	DC5246	7349 411644	ELENA YUDINA	{"phone": "+70100897724"}
0005434095105	560C68	9421 746500	NATALYA MOROZOVA	{"phone": "+70523017460"}
0005434095106	D73A25	3708 734774	DMITRIY MOISEEV	{"phone": "+70190312857"}
0005434095107	792D23	1471 757802	ILYA SCHERBAKOV	{"phone": "+70022977186"}
0005434095108	8B47B0	1501 480780	ANATOLIY VASILEV	{"email": "vasilev-anatoliy10121984@postgrespro.ru", "phone": "+70539171738"}
0005434095109	8EA729	3944 908592	EVGENIYA ZHUKOVA	{"email": "zhukova_e.101963@postgrespro.ru", "phone": "+70939626811"}
0005434095110	A23DF5	1017 762752	ALEKSANDR FOMIN	{"email": "fomin-aleksandr.021967@postgrespro.ru", "phone": "+70615045365"}
0005434095111	68F60B	4457 658510	MAKSIM ALEKSEEV	{"phone": "+70507503032"}
0005434095112	900BB3	2409 779986	YAROSLAV GUSEV	{"email": "gusev_y-1969@postgrespro.ru", "phone": "+70598307086"}
0005434095113	900BB3	2740 076219	TATYANA STEPANOVA	{"email": "stepanova.tatyana-1969@postgrespro.ru", "phone": "+70530525091"}
0005434095114	11F099	5313 865466	ZINAIDA BORISOVA	{"email": "borisova-zinaida.011972@postgrespro.ru", "phone": "+70627572909"}
0005434095115	3FA198	6183 790382	DENIS SERGEEV	{"phone": "+70517858971"}
0005434095116	075A86	7079 193335	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev.101985@postgrespro.ru", "phone": "+70490278228"}
0005434095117	483F69	7372 044499	YURIY SOKOLOV	{"email": "sokolov_yuriy.041980@postgrespro.ru", "phone": "+70473142591"}
0005434095118	483F69	5324 128936	GRIGORIY SOROKIN	{"email": "sorokin_g.071975@postgrespro.ru", "phone": "+70425738741"}
0005434095119	A8F910	6161 243188	ALBINA GERASIMOVA	{"email": "albina.gerasimova1986@postgrespro.ru", "phone": "+70505499142"}
0005434095120	D44A24	9453 015036	SERGEY DAVYDOV	{"phone": "+70482426309"}
0005434095121	2A5A98	7337 580746	NIKITA POPOV	{"phone": "+70563956060"}
0005434095122	2E2D6B	0962 868447	IRINA ABRAMOVA	{"email": "abramova_irina041967@postgrespro.ru", "phone": "+70610985328"}
0005434095123	306066	9232 216861	VLADIMIR VOLKOV	{"email": "volkov-v_1975@postgrespro.ru", "phone": "+70254860837"}
0005434095124	8DC62B	3454 872791	LYUDMILA RODIONOVA	{"phone": "+70771809429"}
0005434095125	789295	0549 381067	ALEKSANDR TIKHONOV	{"email": "tikhonova_1974@postgrespro.ru", "phone": "+70507965111"}
0005434095126	789295	6819 435223	SERGEY BARANOV	{"phone": "+70983857285"}
0005434095127	6DC0B0	7543 551762	EVGENIYA KOZLOVA	{"email": "evgeniya-kozlova_03011985@postgrespro.ru", "phone": "+70200504502"}
0005434095128	A733ED	7563 700712	ANASTASIYA POPOVA	{"phone": "+70610426303"}
0005434095129	A733ED	4197 371640	IRINA ZHURAVLEVA	{"phone": "+70587627393"}
0005434095130	A1514B	7977 511436	VSEVOLOD SMIRNOV	{"email": "smirnov.v30111971@postgrespro.ru", "phone": "+70129552845"}
0005434095131	2DAB35	8942 606743	ARMAN EGOROV	{"email": "a-egorov.1982@postgrespro.ru", "phone": "+70294748246"}
0005434095132	2DAB35	1392 639404	ALEKSANDR ISAEV	{"email": "aisaev-051971@postgrespro.ru", "phone": "+70045162819"}
0005434095133	D4C2DB	5112 858556	ELENA VOROBEVA	{"phone": "+70660647038"}
0005434095134	DADD9A	1138 644110	ALEKSANDRA POLYAKOVA	{"email": "polyakovaaleksandra-101978@postgrespro.ru", "phone": "+70477975127"}
0005434095135	DADD9A	8582 385020	STANISLAV KUZNECOV	{"email": "stanislavkuznecov.05051976@postgrespro.ru", "phone": "+70001531380"}
0005434095136	4846D4	3367 671437	ALENA ROMANOVA	{"email": "romanova-a-061976@postgrespro.ru", "phone": "+70832650925"}
0005434095137	EA5B9B	2233 116954	OLGA DENISOVA	{"email": "odenisova16091979@postgrespro.ru", "phone": "+70217374054"}
0005434095138	EA5B9B	6863 573198	KONSTANTIN SERGEEV	{"phone": "+70420377833"}
0005434095139	D0B5FD	3786 897404	ALEKSANDR ALEKSEEV	{"phone": "+70352232155"}
0005434095140	D0B5FD	9814 357678	SERGEY NAZAROV	{"phone": "+70435353434"}
0005434095141	547B38	1064 607328	VLADIMIR ZAYCEV	{"phone": "+70594635817"}
0005434095142	D2D5F9	2537 013992	DINA BORISOVA	{"email": "dinaborisova051977@postgrespro.ru", "phone": "+70201546868"}
0005434095143	5DBB05	7990 718054	ANDREY KUZMIN	{"email": "andreykuzmin.30071977@postgrespro.ru", "phone": "+70110324867"}
0005434095144	426A89	3137 667068	SERGEY MAKSIMOV	{"phone": "+70060824446"}
0005434095145	22212C	6083 676143	SERGEY SOLOVEV	{"phone": "+70983427606"}
0005434095146	920DBA	1759 862478	VALENTINA KRASNOVA	{"email": "krasnova_v_26061971@postgrespro.ru", "phone": "+70990602805"}
0005434095147	701FC4	5987 160407	YURIY IVANOV	{"email": "yuriy.ivanov-061966@postgrespro.ru", "phone": "+70488056669"}
0005434095148	358754	2917 268192	VERA KOVALEVA	{"phone": "+70292813147"}
0005434095149	8C3E43	9583 180705	ANNA EFREMOVA	{"email": "efremovaa_091972@postgrespro.ru", "phone": "+70671650019"}
0005434095150	EE9E00	8552 774636	LILIYA KOZLOVA	{"phone": "+70525511418"}
0005434095151	78203E	9069 722445	IRINA KARPOVA	{"phone": "+70556544772"}
0005434095152	594FB9	4766 896239	VLADIMIR KOZLOV	{"email": "kozlov_vladimir-081968@postgrespro.ru", "phone": "+70105780413"}
0005434095153	DBF6B8	3389 835804	IVAN BONDARENKO	{"phone": "+70807608263"}
0005434095154	E7D34D	4660 236809	NINA POLYAKOVA	{"phone": "+70675606727"}
0005434095155	E7D34D	9294 499287	ALEKSEY VOROBEV	{"email": "vorobev-aleksey_061958@postgrespro.ru", "phone": "+70933267179"}
0005434095156	E7D34D	0347 491903	ELENA MIKHAYLOVA	{"email": "mikhaylovae_051963@postgrespro.ru", "phone": "+70424906648"}
0005434095157	4A3AC7	1587 397814	ALEKSANDR BORISOV	{"phone": "+70919214608"}
0005434095158	921A9C	7136 869376	RAISA MEDVEDEVA	{"email": "medvedeva-raisa_1974@postgrespro.ru", "phone": "+70378407270"}
0005434095159	693F0D	5184 583461	ANNA NAZAROVA	{"email": "a_nazarova-031969@postgrespro.ru", "phone": "+70921022338"}
0005434095160	CCAF41	2666 003921	VALENTINA GORBUNOVA	{"phone": "+70291209896"}
0005434095161	CCAF41	3197 885200	ROMAN PAVLOV	{"phone": "+70353757154"}
0005434095162	42C770	6768 369105	MIKHAIL VASILEV	{"phone": "+70628640473"}
0005434095163	1A750D	7381 878901	RAMIS MIKHAYLOV	{"email": "mikhaylov.ramis_24081971@postgrespro.ru", "phone": "+70660059215"}
0005434095164	9EA841	1940 766974	MARGARITA CHERNOVA	{"email": "chernovam021985@postgrespro.ru", "phone": "+70909522944"}
0005434095165	0C1C60	1521 664613	MIKHAIL GUSEV	{"email": "mikhail.gusev10031966@postgrespro.ru", "phone": "+70831962689"}
0005434095166	0C1C60	1991 508633	IGOR GAVRILOV	{"email": "gavrilovi-081976@postgrespro.ru", "phone": "+70312180714"}
0005434095167	1A85D3	7996 085958	ANZHELIKA IVANOVA	{"phone": "+70657220847"}
0005434095168	13DB93	6702 351551	ALEKSANDR MELNIKOV	{"phone": "+70841891942"}
0005434095169	D9F5B4	0476 344204	OLGA KRASNOVA	{"email": "o_krasnova-22091980@postgrespro.ru", "phone": "+70790827125"}
0005434095170	5DD26A	6503 237477	PAVEL ALEKSANDROV	{"phone": "+70044086041"}
0005434095171	40DDFE	9064 631154	NADEZHDA PAVLOVA	{"phone": "+70285197127"}
0005434095172	2CCF4E	6292 967871	SERGEY VLASOV	{"email": "vlasov_sergey-071973@postgrespro.ru", "phone": "+70544436348"}
0005434095173	2CCF4E	5197 116185	NATALYA ZHURAVLEVA	{"phone": "+70596518081"}
0005434095174	B79412	8716 659640	ANNA AFANASEVA	{"email": "afanasevaa1968@postgrespro.ru", "phone": "+70216417192"}
0005434095175	AABE47	0512 156070	ALEKSANDRA MATVEEVA	{"email": "matveevaa_1967@postgrespro.ru", "phone": "+70996285208"}
0005434095176	AABE47	1053 465267	ZULFIYA DMITRIEVA	{"phone": "+70592474658"}
0005434095177	D0E7C2	1673 049653	ANDREY FOMIN	{"phone": "+70634502649"}
0005434095178	D0E7C2	9548 834385	ANNA BARANOVA	{"email": "baranova-anna.071974@postgrespro.ru", "phone": "+70768112058"}
0005434095179	2AFF25	4558 375847	KIRILL MEDVEDEV	{"phone": "+70655148395"}
0005434095180	2AFF25	1068 571083	SERGEY SCHERBAKOV	{"phone": "+70232885985"}
0005434095181	99A74E	6325 811448	VASILIY ISAEV	{"email": "isaevv.02071970@postgrespro.ru", "phone": "+70240876542"}
0005434095182	D2EDBC	9137 088870	NINA PETROVA	{"phone": "+70561177384"}
0005434095183	340EEC	6545 390166	BOGDAN DMITRIEV	{"phone": "+70226617681"}
0005434095184	65B6B2	0276 542917	ALEKSANDR MEDVEDEV	{"phone": "+70557876145"}
0005434095185	687CED	6980 324768	NINA ALEKSEEVA	{"email": "n.alekseeva.111980@postgrespro.ru", "phone": "+70393712370"}
0005434095186	52B11C	1361 699238	KONSTANTIN KISELEV	{"email": "k-kiselev.27101970@postgrespro.ru", "phone": "+70548590684"}
0005434095187	745DEA	7239 455811	DMITRIY DMITRIEV	{"email": "d_dmitriev-1965@postgrespro.ru", "phone": "+70113099361"}
0005434095188	E2F189	0892 522368	ELENA ZHURAVLEVA	{"phone": "+70384425676"}
0005434095189	E2F189	1788 889082	YURIY MATVEEV	{"email": "matveev-yuriy_061966@postgrespro.ru", "phone": "+70154724749"}
0005434095190	601104	5018 210035	TATYANA KAZAKOVA	{"email": "t.kazakova23111965@postgrespro.ru", "phone": "+70033333738"}
0005434095191	31BA70	2715 917732	NIKOLAY EGOROV	{"email": "negorov.12091980@postgrespro.ru", "phone": "+70738326033"}
0005434095192	4F26DA	7674 284564	ANNA KRASNOVA	{"email": "krasnova.anna.121974@postgrespro.ru", "phone": "+70785517327"}
0005434095193	2782F9	5934 193750	ALEKSANDR VOROBEV	{"email": "a-vorobev.101966@postgrespro.ru", "phone": "+70697193067"}
0005434095194	2782F9	0147 442419	IRINA TITOVA	{"phone": "+70424435126"}
0005434095195	21E5F4	4130 099866	ZINAIDA ILINA	{"email": "ilinazinaida-1962@postgrespro.ru", "phone": "+70313311536"}
0005434095196	F1022A	6544 482940	DANIIL OSIPOV	{"email": "d-osipov.101975@postgrespro.ru", "phone": "+70342345563"}
0005434095197	F1022A	8680 491560	MIKHAIL ALEKSEEV	{"phone": "+70077591023"}
0005434095198	0F6406	9738 631534	ARTEM TARASOV	{"email": "tarasov-artem1978@postgrespro.ru", "phone": "+70647331845"}
0005434095199	6337A8	7625 347554	LYUBOV GUSEVA	{"phone": "+70715097475"}
0005434095200	5605E4	0597 224201	ANTON POPOV	{"email": "popov_anton.121985@postgrespro.ru", "phone": "+70563641834"}
0005434095201	1E60C3	5344 298391	DARYA EGOROVA	{"phone": "+70932408347"}
0005434095202	1E60C3	7881 756630	SVETLANA KOROLEVA	{"phone": "+70049882237"}
0005434095203	D8DA6C	4208 471088	VLADIMIR NOVIKOV	{"email": "vladimirnovikov-021973@postgrespro.ru", "phone": "+70122114894"}
0005434095204	D8DA6C	6489 832351	NATALYA FEDOROVA	{"email": "fedorova_n_081971@postgrespro.ru", "phone": "+70737195173"}
0005434095205	8DD6C9	4818 930263	EDUARD ABRAMOV	{"email": "abramov-e.1973@postgrespro.ru", "phone": "+70502008600"}
0005434095206	8DD6C9	3134 877102	VALERIY MIKHAYLOV	{"email": "mikhaylov_valeriy-11071973@postgrespro.ru", "phone": "+70221038049"}
0005434095207	585DB2	9434 944488	ANASTASIYA MOROZOVA	{"phone": "+70469245988"}
0005434095208	585DB2	4004 561927	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin_111971@postgrespro.ru", "phone": "+70961647244"}
0005434095209	1EC84E	8187 434878	ANATOLIY MEDVEDEV	{"email": "amedvedev.1960@postgrespro.ru", "phone": "+70248458847"}
0005434095210	21DAB3	2233 899761	VLADIMIR SCHERBAKOV	{"email": "scherbakov.vladimir_1966@postgrespro.ru", "phone": "+70497188908"}
0005434095211	21DAB3	2104 198622	VERA KOROLEVA	{"email": "koroleva-v_24121974@postgrespro.ru", "phone": "+70375361645"}
0005434095212	35182F	1674 667109	GALINA ILINA	{"phone": "+70441094433"}
0005434095213	35182F	7958 337180	VIKTOR ZAKHAROV	{"email": "zakharovviktor.1972@postgrespro.ru", "phone": "+70102573367"}
0005434095214	9CC539	1972 325500	ALEKSANDR SOROKIN	{"email": "a-sorokin-041963@postgrespro.ru", "phone": "+70946370659"}
0005434095215	57A92D	0380 481002	VASILIY KOZLOV	{"email": "kozlov.v-081982@postgrespro.ru", "phone": "+70683746260"}
0005434095216	57A92D	2975 551105	AMIR BORISOV	{"phone": "+70359606867"}
0005434095217	A269E1	2716 353716	ELENA KOMAROVA	{"phone": "+70492671891"}
0005434095218	A269E1	1612 051705	LEONID SIDOROV	{"phone": "+70626791498"}
0005434095219	A269E1	3771 046878	EVA KAZAKOVA	{"email": "eva_kazakova-05041975@postgrespro.ru", "phone": "+70743816394"}
0005434095220	45A91D	2330 284256	NIKITA NOVIKOV	{"email": "n-novikov_1978@postgrespro.ru", "phone": "+70128303864"}
0005434095221	45A91D	0648 929419	EDUARD MELNIKOV	{"phone": "+70797354237"}
0005434095222	696645	9441 832036	IGOR CHERNOV	{"email": "i.chernov_081980@postgrespro.ru", "phone": "+70226144270"}
0005434095223	696645	4226 049365	SERGEY IVANOV	{"email": "ivanovs1972@postgrespro.ru", "phone": "+70185076869"}
0005434095224	C70F93	4507 272454	MIKHAIL ZAKHAROV	{"email": "m_zakharov_071971@postgrespro.ru", "phone": "+70326629897"}
0005434095225	C70F93	7800 240026	ANATOLIY ABRAMOV	{"phone": "+70815686236"}
0005434095226	D595CA	6149 093446	IRINA AKIMOVA	{"email": "i_akimova.081978@postgrespro.ru", "phone": "+70244443229"}
0005434095227	D595CA	5593 787645	EKATERINA ANISIMOVA	{"email": "anisimovae_1973@postgrespro.ru", "phone": "+70961758398"}
0005434095229	CB6327	2204 135686	VIKTOR MOISEEV	{"phone": "+70675470790"}
0005434095230	C8E7A9	4949 902287	ELENA MAKAROVA	{"email": "elenamakarova1963@postgrespro.ru", "phone": "+70777113898"}
0005434095231	C8E7A9	2345 860304	VIOLETTA BELYAEVA	{"email": "belyaeva_v.1972@postgrespro.ru", "phone": "+70880016294"}
0005434095232	B1E5E1	4119 153948	VYACHESLAV MOROZOV	{"phone": "+70650738534"}
0005434095233	012205	0037 304096	VIKTOR IVANOV	{"email": "ivanov_viktor-11121980@postgrespro.ru", "phone": "+70218226077"}
0005434095234	9A81C9	1928 046182	KONSTANTIN ZAYCEV	{"phone": "+70978410112"}
0005434095235	9A81C9	1435 989530	SERGEY STEPANOV	{"email": "sergey.stepanov011977@postgrespro.ru", "phone": "+70016555460"}
0005434095236	0DAA3B	8277 781923	ALEKSANDR FROLOV	{"phone": "+70738313910"}
0005434095237	0DAA3B	0733 712414	DMITRIY ALEKSANDROV	{"phone": "+70535635445"}
0005434095238	FC2C86	4452 794649	SERGEY SMIRNOV	{"email": "smirnov_s_011973@postgrespro.ru", "phone": "+70809123632"}
0005434095239	FC2C86	8182 953543	ANDREY AFANASEV	{"phone": "+70872353071"}
0005434095240	B3F4D2	6873 865522	GALINA ANISIMOVA	{"email": "anisimova-g-01121976@postgrespro.ru", "phone": "+70910923749"}
0005434095241	BE7D99	7253 583727	VALENTINA KUZNECOVA	{"email": "v.kuznecova-031971@postgrespro.ru", "phone": "+70802876752"}
0005434095242	25677C	1263 759809	EVGENIY KONOVALOV	{"email": "evgeniykonovalov-071974@postgrespro.ru", "phone": "+70852239883"}
0005434095243	25677C	7356 817198	MAKSIM MEDVEDEV	{"email": "maksim_medvedev_1975@postgrespro.ru", "phone": "+70960864384"}
0005434095244	09B11A	3001 898857	VLADIMIR SOROKIN	{"email": "v_sorokin_1980@postgrespro.ru", "phone": "+70323949229"}
0005434095245	F12DD1	9921 202017	IRINA SEMENOVA	{"email": "i.semenova.091968@postgrespro.ru", "phone": "+70296855319"}
0005434095246	4EF35A	4112 267784	SVETLANA TITOVA	{"email": "titovasvetlana11041976@postgrespro.ru", "phone": "+70960192509"}
0005434095248	768591	0614 058716	VYACHESLAV MIRONOV	{"email": "mironov_v1973@postgrespro.ru", "phone": "+70047693155"}
0005434095249	A3444B	7770 726751	LYUDMILA ERMAKOVA	{"phone": "+70083773311"}
0005434095250	F9DE71	6009 454905	VLADIMIR MAKSIMOV	{"email": "vladimir_maksimov.02051981@postgrespro.ru", "phone": "+70085946189"}
0005434095251	A7BEC5	5187 376568	SERGEY KUZNECOV	{"email": "kuznecov-s.06121967@postgrespro.ru", "phone": "+70359522193"}
0005434095252	7B485E	2197 450909	LYUBOV ANDREEVA	{"phone": "+70819511175"}
0005434095253	7B485E	1617 486087	MARINA MATVEEVA	{"phone": "+70549290791"}
0005434095254	6B7438	7775 788905	PETR POPOV	{"email": "petr.popov.101976@postgrespro.ru", "phone": "+70809218007"}
0005434095255	6B7438	8607 895055	ANASTASIYA KUZMINA	{"phone": "+70461358502"}
0005434095256	7BDCCE	9267 334204	MARINA POPOVA	{"phone": "+70674487175"}
0005434095257	E6682E	7766 679876	DMITRIY KUZNECOV	{"phone": "+70268352577"}
0005434095258	2D2425	4767 864423	ALEKSANDRA ZAYCEVA	{"phone": "+70391227139"}
0005434095259	2D2425	2746 682486	SERGEY KUZNECOV	{"phone": "+70077613133"}
0005434095260	62D012	1521 314088	LYUBOV OSIPOVA	{"phone": "+70021284845"}
0005434095261	C79450	5313 542344	NATALYA STEPANOVA	{"phone": "+70242728540"}
0005434095262	FB03E1	9346 370341	VALENTINA SCHERBAKOVA	{"email": "scherbakova_v21041970@postgrespro.ru", "phone": "+70780089522"}
0005434095263	6029FB	0501 893952	RAFIS KOZLOV	{"phone": "+70772213145"}
0005434095264	88B8E0	7765 107943	YURIY SOLOVEV	{"phone": "+70854957307"}
0005434095265	DCAF51	7992 806111	GENNADIY FOMIN	{"email": "gennadiy-fomin.11101977@postgrespro.ru", "phone": "+70219927559"}
0005434095266	124AC5	3602 201750	POLINA POTAPOVA	{"phone": "+70514366611"}
0005434095267	124AC5	2080 332566	KSENIYA KOLESNIKOVA	{"email": "kolesnikova-kseniya.1963@postgrespro.ru", "phone": "+70689646369"}
0005434095268	BCF91F	4973 927771	TATYANA ANISIMOVA	{"phone": "+70541081235"}
0005434095269	5FD3C3	7059 011685	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov_101972@postgrespro.ru", "phone": "+70603720228"}
0005434095270	54D178	4223 989649	SERGEY BORISOV	{"email": "borisov-sergey-1977@postgrespro.ru", "phone": "+70929356801"}
0005434095271	CDB3B1	9730 267817	ALEKSANDR NIKITIN	{"phone": "+70565722203"}
0005434095272	B163B1	6909 884160	REGINA DANILOVA	{"email": "rdanilova-061979@postgrespro.ru", "phone": "+70317336288"}
0005434095273	C369C5	9565 717832	NINA AFANASEVA	{"phone": "+70807487240"}
0005434095274	4477BF	6867 154251	ANNA DENISOVA	{"email": "denisovaanna.111970@postgrespro.ru", "phone": "+70870549117"}
0005434095275	CFB2DE	8796 357030	ALEKSANDR OSIPOV	{"phone": "+70032933994"}
0005434095276	2DD61E	4019 642847	OLEG MAKAROV	{"phone": "+70096353759"}
0005434095277	2DD61E	8313 476140	EVGENIY GRIGOREV	{"email": "grigorev_e.12121975@postgrespro.ru", "phone": "+70123802354"}
0005434095278	5E33E4	2150 796152	TIMUR POPOV	{"email": "popovtimur101976@postgrespro.ru", "phone": "+70986832489"}
0005434095279	5E33E4	4400 683621	YANA KUZNECOVA	{"email": "kuznecova_y1973@postgrespro.ru", "phone": "+70879302338"}
0005434095280	0090FE	3226 392573	NIKOLAY ZAYCEV	{"email": "zaycev_nikolay.1967@postgrespro.ru", "phone": "+70368865227"}
0005434095281	7E7A1C	4632 354653	GERMAN KOZLOV	{"email": "g-kozlov1972@postgrespro.ru", "phone": "+70644707256"}
0005434095282	8EC6C9	9754 881101	TAMARA ZAYCEVA	{"phone": "+70906024275"}
0005434095283	8EC6C9	3599 430233	VLADISLAV ILIN	{"email": "ilinvladislav-18071972@postgrespro.ru", "phone": "+70658883454"}
0005434095284	183B66	6156 148150	NATALYA FOMINA	{"phone": "+70568368076"}
0005434095285	183B66	4186 716264	ARKADIY KOROLEV	{"phone": "+70965994751"}
0005434095286	DDDFA4	6905 079151	VALENTIN EGOROV	{"phone": "+70199386352"}
0005434095287	DDDFA4	1956 847707	SERGEY KAZAKOV	{"phone": "+70234089261"}
0005434095288	29D139	6998 255213	ANDREY RODIONOV	{"phone": "+70835352983"}
0005434095289	ABC6EE	0497 106183	KONSTANTIN ZHUKOV	{"email": "konstantin-zhukov-21041964@postgrespro.ru", "phone": "+70413362309"}
0005434095290	ABC6EE	4052 094025	VIKTOR FILIPPOV	{"email": "filippov.viktor121968@postgrespro.ru", "phone": "+70414544898"}
0005434095291	44051E	1596 349873	NADEZHDA EGOROVA	{"email": "egorovan101975@postgrespro.ru", "phone": "+70308424289"}
0005434095292	2794AB	8204 209362	OLGA KISELEVA	{"email": "olgakiseleva-1969@postgrespro.ru", "phone": "+70802694745"}
0005434095293	106F7A	4764 585360	NIKOLAY FROLOV	{"phone": "+70429690794"}
0005434095294	106F7A	5469 469990	TATYANA ROMANOVA	{"email": "romanova_tatyana.101969@postgrespro.ru", "phone": "+70009772185"}
0005434095295	A26F93	9092 815456	EGOR VOROBEV	{"phone": "+70187211371"}
0005434095296	9178E4	2348 671619	ALEKSANDR GRIGOREV	{"phone": "+70695872278"}
0005434095297	6111E3	0739 355981	TATYANA ALEKSEEVA	{"phone": "+70784625124"}
0005434095298	0A4152	3271 647783	GEORGIY SIDOROV	{"phone": "+70509840184"}
0005434095299	0A4152	8598 524227	MARINA ISAEVA	{"phone": "+70280303965"}
0005434095300	ED8BBA	1775 331590	NATALYA NIKOLAEVA	{"phone": "+70678886239"}
0005434095301	26F0B5	2600 644135	FARIT FEDOROV	{"email": "fedorovf-1973@postgrespro.ru", "phone": "+70783466591"}
0005434095302	26F0B5	8075 954653	ARKADIY SEMENOV	{"email": "asemenov_21031968@postgrespro.ru", "phone": "+70742410463"}
0005434095303	6653E4	6808 940655	NINA ABRAMOVA	{"email": "n-abramova_011977@postgrespro.ru", "phone": "+70682467731"}
0005434095304	B58C47	5554 840036	MARGARITA GAVRILOVA	{"email": "m-gavrilova-121979@postgrespro.ru", "phone": "+70038519433"}
0005434095305	B58C47	9345 605630	MIKHAIL KUZMIN	{"phone": "+70921375741"}
0005434095306	832581	1136 795043	ALENA EFREMOVA	{"phone": "+70484183660"}
0005434095307	832581	5170 036123	NATALYA KUZNECOVA	{"email": "natalya_kuznecova.1975@postgrespro.ru", "phone": "+70762040558"}
0005434095308	B77CB8	6079 609723	ALEKSANDRA MARTYNOVA	{"phone": "+70409246008"}
0005434095309	B77CB8	2358 237058	VALENTINA MAKAROVA	{"email": "v.makarova-12101970@postgrespro.ru", "phone": "+70946953816"}
0005434095310	AA296B	2442 368902	IGOR PETROV	{"email": "petrov-igor28091981@postgrespro.ru", "phone": "+70215016384"}
0005434095311	3CD630	0812 599677	ALEKSANDRA VOROBEVA	{"email": "aleksandra_vorobeva-031958@postgrespro.ru", "phone": "+70362104573"}
0005434095312	462107	3007 092627	KIRILL EGOROV	{"email": "egorov_k111972@postgrespro.ru", "phone": "+70843496689"}
0005434095313	462107	0034 687766	LYUBOV KOZLOVA	{"phone": "+70607270019"}
0005434095314	462107	9418 601947	ELENA FILIPPOVA	{"phone": "+70633735862"}
0005434095315	B936B6	0675 076679	ARSENIY ALEKSEEV	{"email": "a-alekseev.121977@postgrespro.ru", "phone": "+70571097575"}
0005434095316	095DE3	3835 502324	RAISA NAUMOVA	{"phone": "+70376458298"}
0005434095317	095DE3	1902 287907	VLADIMIR ANDREEV	{"email": "vandreev_02111974@postgrespro.ru", "phone": "+70425234405"}
0005434095318	197298	7445 282469	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_31081969@postgrespro.ru", "phone": "+70231343431"}
0005434095319	84906F	4213 231465	NADEZHDA PETROVA	{"email": "nadezhdapetrova.1976@postgrespro.ru", "phone": "+70048582110"}
0005434095320	84906F	1193 038309	TAMARA KARPOVA	{"phone": "+70376125776"}
0005434095321	FA77D7	5440 393872	ANNA ANTONOVA	{"email": "antonova_a-10101975@postgrespro.ru", "phone": "+70534077548"}
0005434095322	4F03B4	1868 471268	NIKOLAY MOROZOV	{"email": "morozovn-02061965@postgrespro.ru", "phone": "+70378323180"}
0005434095323	4F03B4	8460 135325	ANASTASIYA MAKSIMOVA	{"email": "maksimova_anastasiya-26021964@postgrespro.ru", "phone": "+70599556416"}
0005434095324	268AD2	4836 046621	TATYANA SERGEEVA	{"email": "sergeevatatyana_041980@postgrespro.ru", "phone": "+70853318042"}
0005434095325	DD17E7	0191 208507	DMITRIY SCHERBAKOV	{"email": "scherbakov-dmitriy1962@postgrespro.ru", "phone": "+70362185539"}
0005434095326	A2E148	9888 477752	ARINA SERGEEVA	{"phone": "+70999316720"}
0005434095327	A2E148	6095 111879	NADEZHDA IVANOVA	{"phone": "+70043593884"}
0005434095328	090086	7579 188649	ROMAN SOROKIN	{"phone": "+70814466932"}
0005434095564	DBC22D	2579 131628	RUSLAN FOMIN	{"phone": "+70977739138"}
0005434095329	090086	0031 344153	VALERIYA NAZAROVA	{"email": "nazarova_valeriya_1979@postgrespro.ru", "phone": "+70361052665"}
0005434095330	090086	9428 276127	VYACHESLAV SEMENOV	{"phone": "+70772306748"}
0005434095331	D9101B	6099 290132	VALENTINA MIRONOVA	{"phone": "+70761859913"}
0005434095332	D9101B	8587 899023	DMITRIY DAVYDOV	{"phone": "+70679531404"}
0005434095333	A08FF4	0085 912578	ANZHELA VOLKOVA	{"phone": "+70968139494"}
0005434095334	A08FF4	3415 791746	GALINA RYABOVA	{"email": "ryabova-galina_041975@postgrespro.ru", "phone": "+70232275818"}
0005434095335	E6A680	2969 522134	NATALYA ALEKSANDROVA	{"phone": "+70749935006"}
0005434095336	56D9C7	9427 922098	VLADISLAV ILIN	{"phone": "+70872318309"}
0005434095337	588EDB	9068 318840	OLESYA PETROVA	{"email": "olesya-petrova27081967@postgrespro.ru", "phone": "+70956682748"}
0005434095338	588EDB	6422 966605	ALEKSANDR DENISOV	{"email": "denisov.a.23011975@postgrespro.ru", "phone": "+70387937428"}
0005434095339	D00DF8	2087 038245	ELENA MAKAROVA	{"email": "makarovaelena101974@postgrespro.ru", "phone": "+70868283408"}
0005434095340	389250	3249 637403	ANATOLIY KAZAKOV	{"phone": "+70660496402"}
0005434095341	F6BFF0	0622 694506	MIKHAIL GERASIMOV	{"phone": "+70863447521"}
0005434095342	246996	8989 447452	YANA POPOVA	{"email": "yana.popova.111974@postgrespro.ru", "phone": "+70470539615"}
0005434095343	246996	3070 159311	ALBINA GERASIMOVA	{"phone": "+70215861259"}
0005434095344	5B783B	0168 286980	LYUDMILA KUZMINA	{"email": "lyudmila_kuzmina051975@postgrespro.ru", "phone": "+70936703217"}
0005434095345	12E576	8094 267970	ROMAN STEPANOV	{"email": "roman_stepanov071984@postgrespro.ru", "phone": "+70224905833"}
0005434095346	CBE9AF	5828 524750	DMITRIY ZAKHAROV	{"phone": "+70368446780"}
0005434095347	CBE9AF	8943 631435	ZOYA FADEEVA	{"phone": "+70365934132"}
0005434095348	C51E73	7578 406595	TAMARA VASILEVA	{"phone": "+70398560209"}
0005434095349	581856	7468 307656	ARTEM ZAKHAROV	{"phone": "+70270977063"}
0005434095350	E66FDC	9231 510794	VALERIY ILIN	{"phone": "+70617423589"}
0005434095351	4248F1	3803 294826	NIKOLAY ZAYCEV	{"email": "zaycevn_27111970@postgrespro.ru", "phone": "+70530724712"}
0005434095352	4248F1	3117 658585	TAMARA FADEEVA	{"phone": "+70125299291"}
0005434095353	4248F1	0259 683885	ANDREY KOZLOV	{"phone": "+70020795150"}
0005434095354	E5B888	2069 023909	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov.06101969@postgrespro.ru", "phone": "+70306882448"}
0005434095355	E5B888	2300 941943	LYUBOV KUZNECOVA	{"email": "kuznecova_lyubov-011972@postgrespro.ru", "phone": "+70290086457"}
0005434095356	E5B888	2107 594174	VITALIY ZAYCEV	{"email": "vitaliyzaycev1980@postgrespro.ru", "phone": "+70385387856"}
0005434095357	A6246A	8056 384489	LYUBOV SEMENOVA	{"email": "lyubov-semenova.091980@postgrespro.ru", "phone": "+70156519279"}
0005434095358	6BDBAF	2108 767554	INNA STEPANOVA	{"email": "stepanovai051968@postgrespro.ru", "phone": "+70554704688"}
0005434095359	6BDBAF	4393 486962	NATALYA RYABOVA	{"phone": "+70895789398"}
0005434095360	302451	3116 640600	MARINA ANISIMOVA	{"email": "marinaanisimova-061978@postgrespro.ru", "phone": "+70878130295"}
0005434095361	18B9B0	7717 487190	MARGARITA ABRAMOVA	{"email": "mabramova.051982@postgrespro.ru", "phone": "+70006869102"}
0005434095362	18B9B0	7234 827554	ZINAIDA FADEEVA	{"email": "zfadeeva-111987@postgrespro.ru", "phone": "+70944760320"}
0005434095363	3AA37B	0238 261710	ANNA FOMINA	{"phone": "+70495205574"}
0005434095364	3AA37B	5315 059354	OLEG MIRONOV	{"email": "o-mironov1971@postgrespro.ru", "phone": "+70974738356"}
0005434095365	2A203F	0495 778523	GALINA NAZAROVA	{"email": "g-nazarova-071960@postgrespro.ru", "phone": "+70447926252"}
0005434095366	3D2161	9313 673304	ROMAN BELOV	{"email": "r.belov-1963@postgrespro.ru", "phone": "+70141608070"}
0005434095367	A73203	7885 944413	ANNA IVANOVA	{"email": "a.ivanova.021972@postgrespro.ru", "phone": "+70899757356"}
0005434095368	56172D	3781 601745	NATALYA DANILOVA	{"email": "danilova_n_1982@postgrespro.ru", "phone": "+70679440644"}
0005434095369	56172D	4325 708602	ALEKSANDR BELOV	{"email": "belov-a-1975@postgrespro.ru", "phone": "+70928084433"}
0005434095370	56172D	5174 023845	LYUDMILA CHERNOVA	{"email": "lyudmilachernova.1975@postgrespro.ru", "phone": "+70642429793"}
0005434095371	A334A3	9174 455756	DMITRIY KISELEV	{"email": "kiselev.dmitriy_19011965@postgrespro.ru", "phone": "+70700354639"}
0005434095372	A334A3	1904 743116	IGOR ISAEV	{"phone": "+70898274520"}
0005434095373	4705F4	7850 407076	VALERIY FOMIN	{"phone": "+70192705732"}
0005434095374	FBF68C	7451 635290	ALENA EFREMOVA	{"email": "aefremova10111975@postgrespro.ru", "phone": "+70112351746"}
0005434095375	FBF68C	1842 886801	OLGA IVANOVA	{"email": "ivanova-o_041980@postgrespro.ru", "phone": "+70610230637"}
0005434095376	BA5DAF	6874 567614	IRINA RYABOVA	{"phone": "+70674250393"}
0005434095377	2D02D7	9654 447916	EKATERINA MAKAROVA	{"email": "makarova_ekaterina_1980@postgrespro.ru", "phone": "+70202865540"}
0005434095378	1F3025	8439 809817	GENNADIY MIRONOV	{"phone": "+70327872211"}
0005434095379	CB3BA0	7054 949469	ANASTASIYA ZAYCEVA	{"email": "anastasiyazayceva_011975@postgrespro.ru", "phone": "+70998625460"}
0005434095380	9FBD1E	9899 338994	MARIYA STEPANOVA	{"email": "stepanova_mariya-1975@postgrespro.ru", "phone": "+70559630325"}
0005434095381	9FBD1E	2307 547998	PAVEL DAVYDOV	{"phone": "+70462176315"}
0005434095382	6C1383	7076 521930	ANDREY ZHUKOV	{"email": "andrey-zhukov-03071968@postgrespro.ru", "phone": "+70859058850"}
0005434095383	986754	2107 446903	NATALYA POPOVA	{"email": "n_popova_1981@postgrespro.ru", "phone": "+70073080129"}
0005434095384	2DFD97	7873 986705	EKATERINA MAKAROVA	{"email": "ekaterina.makarova_051975@postgrespro.ru", "phone": "+70273476644"}
0005434095385	2DFD97	4239 757003	STANISLAV BONDARENKO	{"phone": "+70541681949"}
0005434095386	2DFD97	0167 186749	ANNA KUZMINA	{"email": "kuzminaanna.1973@postgrespro.ru", "phone": "+70011925675"}
0005434095387	86DCC7	2438 833402	OLGA OVCHINNIKOVA	{"phone": "+70404176676"}
0005434095388	86DCC7	7340 085863	ALENA DENISOVA	{"email": "alena_denisova-07061959@postgrespro.ru", "phone": "+70061678018"}
0005434095389	0C05DE	6284 866460	VALERIY STEPANOV	{"phone": "+70576276680"}
0005434095390	46F6DB	1373 451460	ALEKSANDR ZHUKOV	{"email": "zhukov_aleksandr-1973@postgrespro.ru", "phone": "+70098070276"}
0005434095391	46F6DB	6541 860884	VYACHESLAV GORBUNOV	{"phone": "+70265743325"}
0005434095392	D897A9	5761 000538	ALEKSANDR MAKSIMOV	{"phone": "+70086354595"}
0005434095393	AF8F46	0639 475964	OLGA DENISOVA	{"email": "denisova-olga.09111975@postgrespro.ru", "phone": "+70345017491"}
0005434095394	B91A46	8159 374754	ALEKSEY TARASOV	{"email": "tarasov-aleksey_121961@postgrespro.ru", "phone": "+70799981292"}
0005434095395	B91A46	3642 617148	ALLA MAKAROVA	{"phone": "+70701583920"}
0005434095452	3FA40F	7131 203977	ELENA MASLOVA	{"phone": "+70375579955"}
0005434095396	879318	1027 992964	MARIYA TIKHONOVA	{"email": "tikhonovamariya.031971@postgrespro.ru", "phone": "+70614129968"}
0005434095397	879318	2825 196121	VIKTOR NIKOLAEV	{"email": "nikolaev_v.1970@postgrespro.ru", "phone": "+70990464619"}
0005434095398	E0AF4C	8494 392455	GENNADIY DENISOV	{"email": "g_denisov.121970@postgrespro.ru", "phone": "+70288284734"}
0005434095399	C99887	3642 349391	OLGA BOGDANOVA	{"email": "bogdanovao_11121965@postgrespro.ru", "phone": "+70201451007"}
0005434095400	67C83D	3431 644271	KONSTANTIN KUZNECOV	{"phone": "+70829933247"}
0005434095401	67C83D	3415 170980	OLEG CHERNOV	{"email": "chernovo_1984@postgrespro.ru", "phone": "+70005046704"}
0005434095402	4B2B63	5048 188625	YURIY MIRONOV	{"phone": "+70234823252"}
0005434095403	233F16	7283 054016	EVGENIY MIRONOV	{"phone": "+70222200642"}
0005434095404	F7E0EC	7630 843077	LYUDMILA KARPOVA	{"email": "lyudmila.karpova101979@postgrespro.ru", "phone": "+70780355218"}
0005434095405	F9F201	0965 779194	MAKSIM SERGEEV	{"phone": "+70828557440"}
0005434095406	A67EAB	1140 249919	ILYA SCHERBAKOV	{"phone": "+70184005227"}
0005434095407	4A9E1C	4278 314684	DANIIL MAKAROV	{"phone": "+70826662628"}
0005434095408	4A9E1C	3806 842110	TATYANA NAZAROVA	{"phone": "+70748245033"}
0005434095409	A91864	9006 778233	ANATOLIY SOROKIN	{"phone": "+70665827203"}
0005434095410	3ECA6C	8913 164483	SERGEY AFANASEV	{"email": "s_afanasev-031974@postgrespro.ru", "phone": "+70736579878"}
0005434095411	8B9E7E	2260 271260	VARVARA EGOROVA	{"phone": "+70776644737"}
0005434095412	8B9E7E	8568 452105	GALINA KONDRATEVA	{"phone": "+70225045529"}
0005434095413	FADC24	9159 669636	EKATERINA NIKIFOROVA	{"phone": "+70046275575"}
0005434095414	BE27D9	8455 389989	DANA NESTEROVA	{"phone": "+70167734664"}
0005434095415	BE27D9	9601 585999	ARTEM SOROKIN	{"email": "artem.sorokin_1977@postgrespro.ru", "phone": "+70340954091"}
0005434095416	881407	7993 006128	MARSEL EGOROV	{"email": "egorov.m.29071976@postgrespro.ru", "phone": "+70823558235"}
0005434095417	0B5636	1680 774950	TATYANA OVCHINNIKOVA	{"phone": "+70812935885"}
0005434095418	0B5636	6804 604793	SERGEY YAKOVLEV	{"email": "yakovlev-sergey-10051987@postgrespro.ru", "phone": "+70906015187"}
0005434095419	80F6C9	3010 620275	ANASTASIYA DMITRIEVA	{"phone": "+70315131156"}
0005434095420	DF917E	2886 506321	EVGENIY KISELEV	{"phone": "+70633200915"}
0005434095421	BC793F	4441 392284	ANATOLIY MARTYNOV	{"phone": "+70418679483"}
0005434095422	62E185	1359 536688	NATALYA ANDREEVA	{"email": "andreeva.natalya_1980@postgrespro.ru", "phone": "+70102667883"}
0005434095423	A815E4	0316 801199	KIRILL MIKHAYLOV	{"phone": "+70400039364"}
0005434095424	83AAA5	6626 051849	DMITRIY SERGEEV	{"phone": "+70783661448"}
0005434095425	83AAA5	8951 371720	TATYANA FROLOVA	{"email": "tatyanafrolova10061983@postgrespro.ru", "phone": "+70179814152"}
0005434095426	DEBDFB	0791 242185	RAMIS IVANOV	{"phone": "+70261581672"}
0005434095427	2A6A2D	1532 810167	VERA EFIMOVA	{"email": "v-efimova.111970@postgrespro.ru", "phone": "+70635021253"}
0005434095428	7C7EEA	3913 069169	FARIT KRASNOV	{"phone": "+70498861377"}
0005434095429	4761BD	6006 950004	NINA CHERNOVA	{"email": "chernova-n-19031966@postgrespro.ru", "phone": "+70821100170"}
0005434095430	8CD92E	7454 460965	NATALYA ANTONOVA	{"email": "antonovanatalya-07061971@postgrespro.ru", "phone": "+70739492245"}
0005434095431	E682D3	2105 168071	IVAN ZAYCEV	{"email": "zaycev-i_08091972@postgrespro.ru", "phone": "+70588239679"}
0005434095432	E682D3	6672 493666	ALINA NIKOLAEVA	{"phone": "+70050922425"}
0005434095433	E682D3	0372 935840	OKSANA NOVIKOVA	{"phone": "+70408772237"}
0005434095434	31A73C	9510 128508	DMITRIY FOMIN	{"email": "dmitriyfomin-091974@postgrespro.ru", "phone": "+70197021669"}
0005434095435	633CD6	0850 623947	ELENA ANDREEVA	{"phone": "+70143444206"}
0005434095436	2A1BC4	1111 559130	VALENTINA KUZNECOVA	{"email": "valentinakuznecova_08041965@postgrespro.ru", "phone": "+70926095089"}
0005434095437	2A1BC4	9412 652874	ALEKSANDR SMIRNOV	{"email": "a-smirnov.021967@postgrespro.ru", "phone": "+70622033414"}
0005434095438	9E919D	8552 530909	ANNA RODIONOVA	{"email": "a-rodionova_1976@postgrespro.ru", "phone": "+70414397841"}
0005434095439	9E919D	5858 762714	ANTONINA POPOVA	{"phone": "+70631617853"}
0005434095440	5F707F	7976 392547	SERGEY GORBUNOV	{"phone": "+70142689215"}
0005434095441	5F707F	2892 135683	OKSANA MATVEEVA	{"email": "matveevaoksana26061975@postgrespro.ru", "phone": "+70059859510"}
0005434095442	22BBC4	8423 576186	NADEZHDA ALEKSEEVA	{"email": "n.alekseeva_25011974@postgrespro.ru", "phone": "+70928331506"}
0005434095443	F5BA8C	3835 965252	OLGA KULIKOVA	{"email": "kulikovao06011979@postgrespro.ru", "phone": "+70678758058"}
0005434095444	F5BA8C	1613 709426	ANASTASIYA ZAYCEVA	{"email": "a.zayceva-1969@postgrespro.ru", "phone": "+70062514673"}
0005434095445	2BBA19	0045 941699	OLGA NIKIFOROVA	{"email": "o.nikiforova1966@postgrespro.ru", "phone": "+70932440828"}
0005434095446	719325	1528 634349	ROMAN POPOV	{"email": "r_popov121975@postgrespro.ru", "phone": "+70472425470"}
0005434095447	DF3189	3998 925812	SERGEY KOROLEV	{"email": "korolev-s_081980@postgrespro.ru", "phone": "+70927922227"}
0005434095448	4867D9	1833 910857	YURIY KUZNECOV	{"email": "y-kuznecov_071973@postgrespro.ru", "phone": "+70759584656"}
0005434095449	4867D9	0296 276963	LILIYA KOROLEVA	{"email": "liliya-koroleva-101980@postgrespro.ru", "phone": "+70907667066"}
0005434095450	CC4AC0	3611 023107	NINA POPOVA	{"email": "popova.nina.18041962@postgrespro.ru", "phone": "+70915959714"}
0005434095451	3FA40F	8194 988353	ANATOLIY SCHERBAKOV	{"email": "anatoliy-scherbakov_081980@postgrespro.ru", "phone": "+70952944308"}
0005434095453	8E4389	0957 562178	YURIY EGOROV	{"email": "egorov.yuriy.29041966@postgrespro.ru", "phone": "+70744368200"}
0005434095454	786353	1262 854307	OKSANA CHERNOVA	{"email": "o.chernova.1971@postgrespro.ru", "phone": "+70146110162"}
0005434095455	B9DB0C	8406 880931	VADIM PETROV	{"phone": "+70077944755"}
0005434095456	B9DB0C	0502 953527	VITALIY OSIPOV	{"phone": "+70873999509"}
0005434095457	B37E3C	6821 292372	VALENTINA KUZNECOVA	{"phone": "+70066328396"}
0005434095458	B37E3C	2458 255233	EVGENIY NAZAROV	{"email": "nazarov.e.07091971@postgrespro.ru", "phone": "+70416148181"}
0005434095459	EC7169	9012 298990	ALEKSANDRA SEMENOVA	{"phone": "+70058915336"}
0005434095460	EC7169	9773 011684	ANNA SERGEEVA	{"email": "sergeeva_a.111974@postgrespro.ru", "phone": "+70484258543"}
0005434095461	88B1EB	6621 899253	ELENA NIKOLAEVA	{"email": "elena-nikolaeva1956@postgrespro.ru", "phone": "+70481183616"}
0005434095462	3C0C54	1786 242005	ROMAN NIKOLAEV	{"email": "nikolaev-r1974@postgrespro.ru", "phone": "+70266685378"}
0005434095463	3C0C54	8201 644862	DARYA BORISOVA	{"phone": "+70987385710"}
0005434095464	877EA4	7040 450453	VIKTOR CHERNOV	{"email": "chernovv1986@postgrespro.ru", "phone": "+70834136475"}
0005434095465	E51F72	3157 146775	RINAT SOROKIN	{"email": "r.sorokin_1975@postgrespro.ru", "phone": "+70978452757"}
0005434095466	E73AD2	5324 070714	ALEKSANDR ALEKSANDROV	{"phone": "+70355593971"}
0005434095467	E73AD2	6288 683545	ALEKSANDR BORISOV	{"email": "borisov_a_28061976@postgrespro.ru", "phone": "+70834589134"}
0005434095468	E0FFDB	9389 071278	IRINA MELNIKOVA	{"email": "i_melnikova_071968@postgrespro.ru", "phone": "+70162229054"}
0005434095469	CD3EEE	8723 897991	ROMAN FOMIN	{"email": "roman-fomin.041978@postgrespro.ru", "phone": "+70128098833"}
0005434095470	CD3EEE	6171 402678	VLADIMIR ALEKSEEV	{"phone": "+70226762749"}
0005434095471	3C4A3B	0624 617603	LYUDMILA KUZMINA	{"email": "kuzmina_lyudmila_1966@postgrespro.ru", "phone": "+70950671211"}
0005434095472	B8C9DD	4395 649067	ALINA MASLOVA	{"email": "maslova_alina-1976@postgrespro.ru", "phone": "+70643040454"}
0005434095473	4668FD	2175 503525	KLAVDIYA SOKOLOVA	{"email": "sokolova.k-041971@postgrespro.ru", "phone": "+70251908570"}
0005434095474	76E94A	2250 684595	ANASTASIYA CHERNOVA	{"phone": "+70648452759"}
0005434095475	76E94A	9157 057440	FEDOR KOZLOV	{"phone": "+70452679255"}
0005434095476	B9C73C	8307 793507	LYUDMILA ZHURAVLEVA	{"phone": "+70581145698"}
0005434095477	894E63	4606 542196	OLEG KOZLOV	{"email": "kozlov.o1974@postgrespro.ru", "phone": "+70715582726"}
0005434095478	894E63	4986 527701	OLGA VOROBEVA	{"email": "vorobeva_olga.091961@postgrespro.ru", "phone": "+70694614338"}
0005434095479	335C55	1606 109597	OLGA MIRONOVA	{"email": "mironova-olga.061978@postgrespro.ru", "phone": "+70058570534"}
0005434095480	335C55	1682 868218	GALINA MIKHAYLOVA	{"phone": "+70611170610"}
0005434095481	DA8DC6	0438 518015	EDUARD ANTONOV	{"email": "antonov_e_22041966@postgrespro.ru", "phone": "+70432479258"}
0005434095482	DA8DC6	4071 545372	LYAYSAN DMITRIEVA	{"phone": "+70392395633"}
0005434095483	945743	7462 909845	VLADIMIR MOROZOV	{"email": "morozov.v_1969@postgrespro.ru", "phone": "+70399886211"}
0005434095484	945743	8226 218243	GALINA KAZAKOVA	{"phone": "+70678555106"}
0005434095485	945743	6865 692760	DANILA OSIPOV	{"phone": "+70737555980"}
0005434095486	4DDE43	4768 557021	ALINA IVANOVA	{"phone": "+70554122427"}
0005434095487	4DDE43	6391 571277	ELENA KOZLOVA	{"email": "kozlova_elena_1979@postgrespro.ru", "phone": "+70745936857"}
0005434095488	42F851	5580 264801	TAMARA OSIPOVA	{"email": "osipova-tamara_1980@postgrespro.ru", "phone": "+70776679650"}
0005434095489	4AA40C	1853 965021	ALEKSANDR MIKHAYLOV	{"phone": "+70326780024"}
0005434095490	4AA40C	0577 612833	ANTONINA VOLKOVA	{"phone": "+70135025109"}
0005434095491	345AD1	7528 739437	EVGENIY VOLKOV	{"phone": "+70367440783"}
0005434095492	A9FDE2	5726 197041	GULFIYA ALEKSEEVA	{"email": "gulfiya.alekseeva.111970@postgrespro.ru", "phone": "+70942007194"}
0005434095493	6E0885	1719 438988	GENNADIY KUDRYASHOV	{"email": "g_kudryashov_1971@postgrespro.ru", "phone": "+70899463593"}
0005434095494	6E0885	2879 005246	SERGEY BARANOV	{"email": "s.baranov02111974@postgrespro.ru", "phone": "+70437771311"}
0005434095495	AFEF31	1998 705457	ANDREY GAVRILOV	{"email": "a.gavrilov-18121975@postgrespro.ru", "phone": "+70534701913"}
0005434095496	259281	0603 696157	DIANA MEDVEDEVA	{"phone": "+70405137700"}
0005434095497	98BD16	0851 091343	ELENA RYABOVA	{"email": "e-ryabova06041967@postgrespro.ru", "phone": "+70558656878"}
0005434095498	98BD16	5616 501129	EVGENIY ZHUKOV	{"email": "ezhukov121976@postgrespro.ru", "phone": "+70187926499"}
0005434095499	98BD16	9712 146253	SERGEY PETROV	{"phone": "+70709249853"}
0005434095500	7CF33B	4204 123460	ALEKSANDR PETROV	{"phone": "+70018576427"}
0005434095501	4B9EFF	3811 375066	MIKHAIL MELNIKOV	{"phone": "+70430537554"}
0005434095502	4B9EFF	0599 869827	ANDREY POPOV	{"phone": "+70605534749"}
0005434095503	4B9EFF	6380 496218	ALEKSANDR YAKOVLEV	{"phone": "+70819716015"}
0005434095504	249149	8365 853975	ILYA BELOV	{"email": "belov.ilya.1972@postgrespro.ru", "phone": "+70015805507"}
0005434095505	AC6D92	5779 571668	SVETLANA MIKHAYLOVA	{"phone": "+70143708217"}
0005434095506	468EDA	1340 165862	SEMEN KUZNECOV	{"phone": "+70700189832"}
0005434136725	360A91	8350 620402	VLADISLAV MAKSIMOV	{"phone": "+70641070951"}
0005434095507	468EDA	1763 256529	PAVEL TIMOFEEV	{"email": "ptimofeev_1971@postgrespro.ru", "phone": "+70578488617"}
0005434095508	D172A5	1730 357651	IRINA NIKIFOROVA	{"phone": "+70196996852"}
0005434095509	E5D03A	4229 599739	SERGEY OSIPOV	{"phone": "+70037473852"}
0005434095510	26F4EE	0569 441103	DMITRIY YAKOVLEV	{"email": "dmitriy.yakovlev081966@postgrespro.ru", "phone": "+70379564391"}
0005434095511	26F4EE	8277 687843	ALEKSANDRA KOZLOVA	{"email": "a_kozlova.121965@postgrespro.ru", "phone": "+70946737773"}
0005434095512	2FC5EC	9534 465913	KONSTANTIN BARANOV	{"phone": "+70409947041"}
0005434095513	21CA11	8236 168158	SERGEY STEPANOV	{"phone": "+70117556714"}
0005434095514	5D7831	5124 343049	MIKHAIL EGOROV	{"email": "mikhail_egorov_041971@postgrespro.ru", "phone": "+70788692020"}
0005434095515	0103F0	1470 563666	EVGENIY KUZNECOV	{"email": "ekuznecov-011976@postgrespro.ru", "phone": "+70618478248"}
0005434095516	901D1C	5459 262116	ANTON SMIRNOV	{"email": "a.smirnov111968@postgrespro.ru", "phone": "+70749568729"}
0005434095517	3F17B6	3543 191969	SERGEY EGOROV	{"email": "segorov-1983@postgrespro.ru", "phone": "+70499950747"}
0005434095518	3F17B6	8870 207909	ARTEM MAKAROV	{"email": "a_makarov.11071960@postgrespro.ru", "phone": "+70845472832"}
0005434095519	AAABF4	8331 188952	OLGA MIKHAYLOVA	{"email": "mikhaylova-o1961@postgrespro.ru", "phone": "+70391980736"}
0005434095520	AAABF4	6892 335069	VIKTOR SHEVCHENKO	{"email": "v.shevchenko1972@postgrespro.ru", "phone": "+70443511178"}
0005434095521	A0D007	0424 867701	NATALIYA ZAKHAROVA	{"phone": "+70035543799"}
0005434095522	A0D007	8476 174005	YULIYA KUZNECOVA	{"email": "kuznecova_y_10071974@postgrespro.ru", "phone": "+70593081206"}
0005434095523	A0D007	8468 538109	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_1960@postgrespro.ru", "phone": "+70693320921"}
0005434095524	2540E7	2618 354322	ANNA BELYAEVA	{"email": "belyaeva-a1969@postgrespro.ru", "phone": "+70533839170"}
0005434095525	4D26FA	8068 721660	EKATERINA OSIPOVA	{"phone": "+70871848622"}
0005434095526	F8736A	7580 382547	ANASTASIYA ZHUKOVA	{"email": "zhukova-anastasiya-31051972@postgrespro.ru", "phone": "+70159910117"}
0005434095527	91360F	3685 235993	OLEG ZAKHAROV	{"phone": "+70051352123"}
0005434095528	91360F	9553 837660	NIKOLAY ZAKHAROV	{"email": "zakharov-n_1967@postgrespro.ru", "phone": "+70538235485"}
0005434095529	DC02EC	9261 362286	IRINA KUZNECOVA	{"phone": "+70569455536"}
0005434095530	7A7946	7591 855491	KLAVDIYA MIKHAYLOVA	{"email": "mikhaylova.k_051983@postgrespro.ru", "phone": "+70049706313"}
0005434095531	A89286	5776 889219	ELENA SMIRNOVA	{"phone": "+70596475704"}
0005434095532	954420	2295 954697	NADEZHDA NIKOLAEVA	{"email": "nnikolaeva1969@postgrespro.ru", "phone": "+70531971415"}
0005434095533	95243E	5456 691725	LYUBOV VOLKOVA	{"phone": "+70470357422"}
0005434095534	1FF987	6316 143570	SERGEY MATVEEV	{"email": "matveev_s-1980@postgrespro.ru", "phone": "+70883863033"}
0005434095535	98CC0E	4224 732626	NIKOLAY SAVELEV	{"email": "nikolay-savelev1973@postgrespro.ru", "phone": "+70485572596"}
0005434095536	A46441	4404 181587	VERA IVANOVA	{"email": "ivanovavera101980@postgrespro.ru", "phone": "+70501255212"}
0005434095537	18467A	5628 233491	IRINA ALEKSEEVA	{"phone": "+70488757289"}
0005434095538	F3024B	4893 306588	ALEKSANDR FOMIN	{"email": "afomin02081980@postgrespro.ru", "phone": "+70312754997"}
0005434095539	80DE93	0831 701097	VITALIY DMITRIEV	{"phone": "+70401645317"}
0005434095540	80DE93	6980 438297	DENIS YAKOVLEV	{"email": "yakovlev.denis_19081973@postgrespro.ru", "phone": "+70487053771"}
0005434095541	9B8FEC	0086 213726	DMITRIY NIKOLAEV	{"email": "dmitriy-nikolaev_07121982@postgrespro.ru", "phone": "+70674088062"}
0005434095542	212BB7	1366 637461	MAKSIM YAKOVLEV	{"email": "myakovlev.1966@postgrespro.ru", "phone": "+70938303854"}
0005434095543	21B8A0	3765 651926	ALEKSANDR IVANOV	{"email": "a-ivanov_011968@postgrespro.ru", "phone": "+70645612139"}
0005434095544	2A924D	8153 890727	KONSTANTIN MATVEEV	{"email": "konstantinmatveev.18121969@postgrespro.ru", "phone": "+70622776472"}
0005434095545	B76586	4247 219004	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr_1956@postgrespro.ru", "phone": "+70443740336"}
0005434095546	417A1F	1386 572436	IVAN MAKAROV	{"email": "ivan-makarov-1965@postgrespro.ru", "phone": "+70750529944"}
0005434095547	AABC40	3548 492058	ALEKSANDR NAUMOV	{"email": "anaumov_011973@postgrespro.ru", "phone": "+70859647392"}
0005434095548	AABC40	3261 626732	SERGEY MATVEEV	{"email": "s_matveev071982@postgrespro.ru", "phone": "+70777326622"}
0005434095549	3F2A30	0572 303301	YURIY ORLOV	{"phone": "+70943180129"}
0005434095550	27D488	1918 628808	PAVEL KUZNECOV	{"email": "p.kuznecov.121978@postgrespro.ru", "phone": "+70709724149"}
0005434095551	27D488	0980 864079	VALENTINA KUZNECOVA	{"phone": "+70925409466"}
0005434095552	1034E0	2778 281510	ALINA IVANOVA	{"email": "ivanovaalina_1974@postgrespro.ru", "phone": "+70358673560"}
0005434095553	1034E0	5831 793603	NIKOLAY VASILEV	{"email": "n-vasilev.18101985@postgrespro.ru", "phone": "+70830335926"}
0005434095554	1034E0	2378 931749	ANATOLIY TIMOFEEV	{"email": "timofeev-anatoliy.1974@postgrespro.ru", "phone": "+70848638395"}
0005434095555	D57104	3138 267616	OLGA DAVYDOVA	{"email": "odavydova.1975@postgrespro.ru", "phone": "+70137570096"}
0005434095556	D42226	3749 878933	VLADIMIR PETROV	{"email": "vladimir_petrov_21031971@postgrespro.ru", "phone": "+70440152742"}
0005434095557	34AB0D	0970 295880	MAKSIM ILIN	{"phone": "+70201807076"}
0005434095558	DE01F5	5490 255230	ELENA ANISIMOVA	{"phone": "+70238193259"}
0005434095559	DE01F5	0038 175993	LIDIYA ORLOVA	{"email": "lidiya.orlova041985@postgrespro.ru", "phone": "+70473496214"}
0005434095560	DD1417	0067 223807	ALLA VOLKOVA	{"email": "a.volkova.16021970@postgrespro.ru", "phone": "+70769897750"}
0005434095561	DD1417	6832 400375	LYUBOV TARASOVA	{"phone": "+70753595537"}
0005434095562	ED3016	1554 435970	SVETLANA ARKHIPOVA	{"email": "arkhipova_svetlana_1973@postgrespro.ru", "phone": "+70660736344"}
0005434095563	CB9CB8	7795 693442	OKSANA SMIRNOVA	{"email": "osmirnova1978@postgrespro.ru", "phone": "+70283024900"}
0005434095565	3F02C0	9147 907719	RAISA NIKITINA	{"email": "nikitinar061976@postgrespro.ru", "phone": "+70154076951"}
0005434095566	3F02C0	9355 610598	ALEKSEY ZAKHAROV	{"email": "zakharova29101975@postgrespro.ru", "phone": "+70425988889"}
0005434095567	3F02C0	1817 700548	MARINA VOLKOVA	{"email": "marinavolkova_16011970@postgrespro.ru", "phone": "+70784876120"}
0005434095568	FDE647	9065 672766	NADEZHDA NIKIFOROVA	{"email": "nikiforovanadezhda-09101980@postgrespro.ru", "phone": "+70961544173"}
0005434095569	D7F0AD	7498 177471	OLGA DAVYDOVA	{"email": "davydova-o.1981@postgrespro.ru", "phone": "+70389513799"}
0005434095570	867CC1	6921 229309	IRINA YUDINA	{"email": "i-yudina_28071969@postgrespro.ru", "phone": "+70243353274"}
0005434095571	6B8234	8003 887328	DMITRIY KUZNECOV	{"phone": "+70026228720"}
0005434095572	E5A863	0518 925292	EKATERINA EFIMOVA	{"email": "efimovae-011963@postgrespro.ru", "phone": "+70544958401"}
0005434095573	61B3BB	9038 752870	SERGEY GORBUNOV	{"email": "sergey.gorbunov051983@postgrespro.ru", "phone": "+70807066716"}
0005434095574	27B2A4	6971 163001	TATYANA VOLKOVA	{"phone": "+70980089574"}
0005434095575	0821BD	5351 419550	VLADIMIR SMIRNOV	{"phone": "+70134156872"}
0005434095576	217665	0091 533896	ALEKSANDR VASILEV	{"phone": "+70535893308"}
0005434095577	217665	1773 540819	MARIANNA KOMAROVA	{"phone": "+70437060046"}
0005434095578	110D01	6542 062585	MAKSIM VOROBEV	{"email": "maksim-vorobev1966@postgrespro.ru", "phone": "+70524854045"}
0005434095579	F303FA	3336 962867	OLEG ILIN	{"email": "oleg-ilin-16051967@postgrespro.ru", "phone": "+70947576966"}
0005434095580	853CBD	9427 364670	SERGEY SCHERBAKOV	{"phone": "+70067361605"}
0005434095581	BA81CA	0591 597449	VADIM ZHUKOV	{"phone": "+70834554670"}
0005434095582	BA81CA	4988 100554	MIKHAIL MEDVEDEV	{"phone": "+70699162097"}
0005434095583	ED3EB9	9066 979809	MARAT ZHUKOV	{"phone": "+70330307536"}
0005434095584	59FAEA	2869 712363	IRINA ZHUKOVA	{"phone": "+70924491251"}
0005434095585	59FAEA	0250 553915	DMITRIY KUZNECOV	{"email": "dmitriykuznecov_111969@postgrespro.ru", "phone": "+70641011764"}
0005434095586	0BC354	5032 659357	DMITRIY MAKSIMOV	{"email": "maksimov-dmitriy.29061970@postgrespro.ru", "phone": "+70338065958"}
0005434095587	0BC354	2079 478099	ALEKSANDR ZHUKOV	{"email": "zhukov-aleksandr-1966@postgrespro.ru", "phone": "+70455574594"}
0005434095588	A3AEF5	9285 455872	TATYANA SAVELEVA	{"email": "t_saveleva-1976@postgrespro.ru", "phone": "+70547344180"}
0005434095589	FB2599	3506 875171	MARIYA NIKITINA	{"phone": "+70232480926"}
0005434095590	FB2599	4205 390022	EKATERINA MOROZOVA	{"email": "morozova-e-071973@postgrespro.ru", "phone": "+70319419585"}
0005434095591	70D4D5	8763 726764	VALENTINA STEPANOVA	{"email": "vstepanova-26091982@postgrespro.ru", "phone": "+70601272019"}
0005434095592	70D4D5	6451 374197	ANASTASIYA BORISOVA	{"phone": "+70957350796"}
0005434095593	A8A7A6	7533 476759	RAISA EGOROVA	{"phone": "+70446281365"}
0005434095594	4CBCFA	7684 201896	VERA SEMENOVA	{"email": "semenovav_28111980@postgrespro.ru", "phone": "+70218604039"}
0005434095595	4CBCFA	2933 904810	OLEG MEDVEDEV	{"email": "medvedev-oleg16101965@postgrespro.ru", "phone": "+70848969164"}
0005434095596	E5C184	9766 237615	ALEKSEY KOZLOV	{"phone": "+70464763482"}
0005434095597	0B14EF	2747 839639	EVGENIY KUZNECOV	{"phone": "+70682613522"}
0005434095598	0B14EF	0866 617978	KONSTANTIN FOMIN	{"phone": "+70064483674"}
0005434095599	D3AAEB	2610 453846	VALENTINA KOROLEVA	{"email": "korolevavalentina31121975@postgrespro.ru", "phone": "+70919916469"}
0005434095600	D5047C	6801 772433	VIKTORIYA NOVIKOVA	{"email": "v-novikova_1970@postgrespro.ru", "phone": "+70323882781"}
0005434095601	D5047C	4311 021619	ELENA IVANOVA	{"email": "ivanovae.031970@postgrespro.ru", "phone": "+70091547722"}
0005434095602	A7EA94	0878 881101	OLGA GAVRILOVA	{"phone": "+70405214704"}
0005434095603	2F6320	4691 739406	ANDREY MIRONOV	{"email": "mironov_a_071974@postgrespro.ru", "phone": "+70585480445"}
0005434095604	5318D4	2173 702825	OLGA FOMINA	{"phone": "+70889359984"}
0005434095605	5318D4	3320 953471	ELVIRA KOZLOVA	{"phone": "+70486435150"}
0005434095606	EF5645	4524 497657	NADEZHDA TIMOFEEVA	{"phone": "+70955346545"}
0005434095607	62F6C9	8145 930630	MARINA VASILEVA	{"phone": "+70712178952"}
0005434095608	0E8A3B	0009 250142	NATALYA KOROLEVA	{"email": "korolevan021963@postgrespro.ru", "phone": "+70912638461"}
0005434095609	A3C267	0929 356578	VASILIY SCHERBAKOV	{"phone": "+70972409566"}
0005434095610	A3C267	2990 848221	VLADIMIR KUDRYASHOV	{"email": "v.kudryashov_111963@postgrespro.ru", "phone": "+70714515708"}
0005434095611	353CBA	2149 108749	VALERIY STEPANOV	{"phone": "+70571893985"}
0005434095612	C5E259	5147 067545	VALERIY NAZAROV	{"email": "v_nazarov071964@postgrespro.ru", "phone": "+70273419298"}
0005434095613	FB39B6	1696 990485	LIDIYA KOVALEVA	{"email": "lidiya_kovaleva.021969@postgrespro.ru", "phone": "+70410178152"}
0005434095614	FAB4B5	0243 723319	VLADIMIR SMIRNOV	{"email": "smirnov-v11021969@postgrespro.ru", "phone": "+70200109307"}
0005434095615	FAB4B5	6757 531275	DARYA MIKHAYLOVA	{"email": "mikhaylova_d.081961@postgrespro.ru", "phone": "+70858386395"}
0005434095616	20AF85	0538 121709	YURIY SERGEEV	{"email": "sergeev.yuriy-061968@postgrespro.ru", "phone": "+70575180580"}
0005434095617	E4D153	7147 048388	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov19021966@postgrespro.ru", "phone": "+70424897908"}
0005434095618	21659B	0782 631955	NIKOLAY NOVIKOV	{"phone": "+70531747634"}
0005434095619	E0D977	7973 471994	YULIYA KONOVALOVA	{"email": "konovalova_y_1968@postgrespro.ru", "phone": "+70985913988"}
0005434095620	D8E448	5917 732167	MARIYA MEDVEDEVA	{"phone": "+70035455433"}
0005434095621	D8E448	4666 873605	ANTONINA PETROVA	{"email": "a-petrova1977@postgrespro.ru", "phone": "+70716826378"}
0005434095622	58534E	4413 276337	IRINA PAVLOVA	{"phone": "+70999699116"}
0005434095623	08691E	2834 910740	GULSHAT CHERNOVA	{"email": "gulshat_chernova1969@postgrespro.ru", "phone": "+70229048190"}
0005434095624	55D105	9966 657756	OLEG ILIN	{"phone": "+70794149508"}
0005434095625	55D105	2782 562528	ALEKSANDR BARANOV	{"email": "aleksandr_baranov111974@postgrespro.ru", "phone": "+70556987810"}
0005434095626	3B1D2D	6446 889944	ILYA KRASNOV	{"email": "krasnov-i.15031971@postgrespro.ru", "phone": "+70300396803"}
0005434095627	96C3E1	5980 806608	ELENA PETROVA	{"email": "elenapetrova.21111975@postgrespro.ru", "phone": "+70524364675"}
0005434095628	A6D0D2	3579 485860	YULIYA DMITRIEVA	{"email": "dmitrievayuliya-12031956@postgrespro.ru", "phone": "+70110312789"}
0005434095629	19FFB4	5796 601726	ZINAIDA KOZLOVA	{"email": "kozlova_zinaida.13121972@postgrespro.ru", "phone": "+70698213387"}
0005434095630	E068ED	1059 430158	RUSLAN SCHERBAKOV	{"email": "scherbakov-ruslan10031966@postgrespro.ru", "phone": "+70151140627"}
0005434095631	727602	6644 417119	KSENIYA ZAKHAROVA	{"email": "k_zakharova_27051970@postgrespro.ru", "phone": "+70838723296"}
0005434095632	093032	2821 597037	EVGENIYA KOLESNIKOVA	{"phone": "+70493425736"}
0005434095633	093032	0904 978360	OLEG ANTONOV	{"email": "antonov.o_1970@postgrespro.ru", "phone": "+70931226943"}
0005434095634	EF8560	9027 873625	DMITRIY VASILEV	{"phone": "+70441205896"}
0005434095635	EF8560	0514 097060	MAKSIM IVANOV	{"phone": "+70427159724"}
0005434095636	7D1B49	8221 652041	LYUDMILA EFREMOVA	{"email": "lyudmila_efremova.1973@postgrespro.ru", "phone": "+70484868637"}
0005434095637	DB5287	4013 850618	MIKHAIL IVANOV	{"email": "ivanov.m-23021949@postgrespro.ru", "phone": "+70134209418"}
0005434095638	E7910A	4100 522367	ALEKSANDR KAZAKOV	{"phone": "+70220602636"}
0005434095639	2D5B51	9602 753478	ANNA ANTONOVA	{"phone": "+70773212928"}
0005434095640	2D5B51	1797 308798	OLGA SERGEEVA	{"email": "olga.sergeeva-1965@postgrespro.ru", "phone": "+70217887812"}
0005434095641	88D1B2	0701 498607	OLEG BORISOV	{"phone": "+70051620316"}
0005434095642	88D1B2	1815 785401	ANNA ERMAKOVA	{"phone": "+70479126320"}
0005434095643	A7287F	1927 084884	FILIPP KRASNOV	{"email": "krasnov_f1978@postgrespro.ru", "phone": "+70837270776"}
0005434095644	B47AC0	7541 617692	TIGRAN CHERNOV	{"phone": "+70595769673"}
0005434095645	A086E4	8839 342242	TATYANA MAKAROVA	{"phone": "+70787972016"}
0005434095646	A086E4	6571 605512	ANATOLIY KONOVALOV	{"email": "konovalov_anatoliy.011982@postgrespro.ru", "phone": "+70336872586"}
0005434095647	3309C9	5904 253286	OLGA MIRONOVA	{"phone": "+70236145129"}
0005434095648	3309C9	5572 724685	LYUBOV VOROBEVA	{"phone": "+70185511525"}
0005434095649	B15A80	1436 751523	ARTEM MAKAROV	{"email": "makarov.artem-1975@postgrespro.ru", "phone": "+70208410775"}
0005434095650	D98013	5056 484295	ANATOLIY KULIKOV	{"phone": "+70937841718"}
0005434095651	D98013	2911 494089	VERA YUDINA	{"phone": "+70639520583"}
0005434095652	554499	1762 275723	VLADIMIR PAVLOV	{"email": "pavlovvladimir-061969@postgrespro.ru", "phone": "+70178911425"}
0005434095653	554499	4663 741680	NATALYA NESTEROVA	{"phone": "+70699371192"}
0005434095654	554499	2180 358434	MARIYA KOLESNIKOVA	{"phone": "+70704834801"}
0005434095655	B9B88B	7655 443659	IVAN ILIN	{"email": "i-ilin.1971@postgrespro.ru", "phone": "+70650635526"}
0005434095656	395CDC	3510 346085	NATALYA VOLKOVA	{"email": "natalya_volkova-07011973@postgrespro.ru", "phone": "+70188494363"}
0005434095657	6824B5	7336 880363	ARTEM SMIRNOV	{"email": "smirnov-a-1967@postgrespro.ru", "phone": "+70119021638"}
0005434095658	6A46D3	3676 968858	DMITRIY SIDOROV	{"email": "dmitriy-sidorov.10121977@postgrespro.ru", "phone": "+70617949085"}
0005434095659	9A2E85	0810 757375	SERGEY GERASIMOV	{"email": "gerasimov_s_07091978@postgrespro.ru", "phone": "+70415685657"}
0005434095660	E1E490	6804 295998	SERGEY VASILEV	{"phone": "+70395375889"}
0005434095661	5147C7	6240 667690	VALERIYA VASILEVA	{"email": "vasileva.v.1978@postgrespro.ru", "phone": "+70861998617"}
0005434095662	5147C7	1438 393455	NIKOLAY KULIKOV	{"phone": "+70532404259"}
0005434095663	43A5AF	4748 684150	VIKTOR MARTYNOV	{"email": "v.martynov_15011976@postgrespro.ru", "phone": "+70384318718"}
0005434095664	851ABE	7498 841474	IRINA KOVALEVA	{"phone": "+70236925060"}
0005434095665	258070	8485 144569	NIKITA KOZLOV	{"email": "kozlov.nikita-21121969@postgrespro.ru", "phone": "+70218866390"}
0005434095666	B77E5C	0564 183847	KIRILL STEPANOV	{"phone": "+70987583967"}
0005434095667	B77E5C	6441 040414	TATYANA ALEKSANDROVA	{"phone": "+70459973196"}
0005434095668	EFC697	9350 321765	ALEKSANDRA KULIKOVA	{"email": "kulikovaa1971@postgrespro.ru", "phone": "+70481354408"}
0005434095669	EFC697	5048 122421	SERGEY BARANOV	{"phone": "+70010556793"}
0005434095670	EFC697	0978 277220	ILYA ZAKHAROV	{"phone": "+70872806471"}
0005434095671	32935C	2819 634819	SVETLANA KOROLEVA	{"phone": "+70798746643"}
0005434095672	2D5BC3	3670 604518	VASILIY VOROBEV	{"email": "vvorobev28021972@postgrespro.ru", "phone": "+70617695317"}
0005434095673	7A0A88	9260 927826	ELENA KUZMINA	{"email": "kuzmina-e-02071977@postgrespro.ru", "phone": "+70831108332"}
0005434095674	7A0A88	7878 202431	ALEKSANDR MARTYNOV	{"phone": "+70835547483"}
0005434095675	BC5286	1445 603719	VASILIY MOROZOV	{"email": "morozov.v.041971@postgrespro.ru", "phone": "+70530540906"}
0005434095676	A55A08	8890 418660	MIKHAIL KUZNECOV	{"phone": "+70400418610"}
0005434095677	A55A08	8059 934170	MARIYA BELOVA	{"email": "mbelova_08041966@postgrespro.ru", "phone": "+70223559552"}
0005434095678	0A13A1	8478 208624	VLADIMIR DMITRIEV	{"email": "dmitrievvladimir.101968@postgrespro.ru", "phone": "+70264427168"}
0005434095679	0A13A1	6658 085559	EKATERINA SEMENOVA	{"phone": "+70003945412"}
0005434095680	F81D99	5398 530786	PAVEL NIKOLAEV	{"email": "p.nikolaev.1956@postgrespro.ru", "phone": "+70139909694"}
0005434095681	7BC8B1	7456 361238	SERGEY GAVRILOV	{"phone": "+70559543223"}
0005434095682	7BC8B1	3530 526772	VLADIMIR PAVLOV	{"phone": "+70997672560"}
0005434095683	607488	8041 090420	REGINA RODIONOVA	{"phone": "+70201400098"}
0005434095684	4D579D	0526 303338	SVETLANA EFREMOVA	{"phone": "+70277479445"}
0005434095685	4D579D	6879 795780	TATYANA GRISHINA	{"phone": "+70772881673"}
0005434095686	B5C071	4562 837755	VLADIMIR KULIKOV	{"email": "vladimir.kulikov_22101970@postgrespro.ru", "phone": "+70039756881"}
0005434095687	1A6CC6	2264 872641	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr011985@postgrespro.ru", "phone": "+70719075552"}
0005434095688	7F06F4	7946 962575	EDUARD KUZNECOV	{"email": "kuznecove-121967@postgrespro.ru", "phone": "+70895284716"}
0005434095689	1F9B31	5302 429666	YAROSLAV DMITRIEV	{"phone": "+70275459015"}
0005434095690	1F9B31	2094 272365	ANASTASIYA RODIONOVA	{"email": "rodionova.anastasiya_1965@postgrespro.ru", "phone": "+70902051278"}
0005434095691	F24625	3608 887922	NATALIYA DAVYDOVA	{"phone": "+70175423530"}
0005434095692	16F11C	9438 830778	TAMARA SOROKINA	{"email": "sorokina.tamara_041969@postgrespro.ru", "phone": "+70457366922"}
0005434095693	A3866F	9889 148953	NIKOLAY KOROLEV	{"phone": "+70813411052"}
0005434095694	4A3614	3732 806540	OLGA MOISEEVA	{"email": "o.moiseeva1961@postgrespro.ru", "phone": "+70655861044"}
0005434095695	D9A2CC	3118 340942	SERGEY BORISOV	{"phone": "+70184529909"}
0005434095696	D9A2CC	6356 952008	ALENA SEMENOVA	{"phone": "+70741964298"}
0005434095697	A40FF1	2025 011920	LEONID GORBUNOV	{"email": "gorbunov_l.081968@postgrespro.ru", "phone": "+70916967958"}
0005434095698	A40FF1	6608 818025	ANNA ABRAMOVA	{"phone": "+70391749085"}
0005434095699	997DF1	8377 027806	BORIS SIDOROV	{"email": "sidorovboris_1970@postgrespro.ru", "phone": "+70373204940"}
0005434095700	2A5122	4313 594627	RUSLAN DENISOV	{"email": "denisovruslan-1975@postgrespro.ru", "phone": "+70463233836"}
0005434095701	76D610	3055 720607	ELENA IVANOVA	{"email": "e-ivanova-17031965@postgrespro.ru", "phone": "+70882465866"}
0005434095702	76D610	0305 685444	ALEKSEY SOLOVEV	{"email": "aleksey.solovev1971@postgrespro.ru", "phone": "+70664537728"}
0005434095703	13C622	8265 978926	NIKOLAY STEPANOV	{"email": "nikolay-stepanov_17091975@postgrespro.ru", "phone": "+70598471338"}
0005434095704	E4B821	1548 680058	ARTUR KULIKOV	{"email": "artur_kulikov_021981@postgrespro.ru", "phone": "+70649480202"}
0005434095705	281859	7848 645857	TAMARA KUZNECOVA	{"email": "kuznecova_tamara_041979@postgrespro.ru", "phone": "+70818793555"}
0005434095706	281859	0130 445990	ANDREY SCHERBAKOV	{"email": "scherbakov-andrey.081974@postgrespro.ru", "phone": "+70292354532"}
0005434095707	281859	8596 266537	IVAN IVANOV	{"email": "ivanov.ivan.1975@postgrespro.ru", "phone": "+70482349340"}
0005434095708	3374BF	5055 165894	TATYANA ZHUKOVA	{"email": "t.zhukova051982@postgrespro.ru", "phone": "+70152881866"}
0005434096707	9A5722	8116 258464	OLEG SIDOROV	{"email": "sidorov_oleg1971@postgrespro.ru", "phone": "+70446701419"}
0005434096708	9A5722	4836 424533	VYACHESLAV SOKOLOV	{"email": "sokolov.vyacheslav_28111980@postgrespro.ru", "phone": "+70249164438"}
0005434096709	3A819E	5993 653278	POLINA FOMINA	{"email": "fomina_polina-041963@postgrespro.ru", "phone": "+70159598170"}
0005434096710	3A819E	6221 683863	ALEKSANDR SAVELEV	{"phone": "+70794115534"}
0005434096711	E9DC94	0192 563957	KONSTANTIN BONDARENKO	{"email": "k-bondarenko.03011976@postgrespro.ru", "phone": "+70077767007"}
0005434096712	CE691E	4875 631030	MARIYA BELOVA	{"phone": "+70740446444"}
0005434096713	CE691E	7405 273796	VALENTINA SOROKINA	{"phone": "+70156803204"}
0005434096714	8F5B7B	6125 418707	NADEZHDA SERGEEVA	{"phone": "+70043267332"}
0005434096715	4D4644	3980 013805	TATYANA KOMAROVA	{"email": "komarova-t111971@postgrespro.ru", "phone": "+70703895863"}
0005434096716	5F869F	9468 637044	GENNADIY POPOV	{"phone": "+70318756711"}
0005434096717	5F869F	0670 042937	TATYANA ERMAKOVA	{"email": "ermakovatatyana.021971@postgrespro.ru", "phone": "+70022747781"}
0005434096718	095ACC	0438 592827	NATALYA FILIPPOVA	{"phone": "+70727127436"}
0005434096719	E57E15	8088 480960	LYUDMILA KOZLOVA	{"email": "l-kozlova.07081974@postgrespro.ru", "phone": "+70205949241"}
0005434096720	E57E15	4625 963903	OLGA MOROZOVA	{"email": "morozova.olga1970@postgrespro.ru", "phone": "+70253092710"}
0005434096721	92D3AA	8602 067885	DMITRIY SHEVCHENKO	{"email": "shevchenkodmitriy-1960@postgrespro.ru", "phone": "+70324571956"}
0005434096722	92D3AA	6373 493291	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir-07011969@postgrespro.ru", "phone": "+70781043416"}
0005434096723	23E5CE	2596 420240	ANDREY SAVELEV	{"email": "savelevandrey-121985@postgrespro.ru", "phone": "+70364256521"}
0005434096724	576263	8781 106072	TATYANA KONOVALOVA	{"email": "tatyana.konovalova-1968@postgrespro.ru", "phone": "+70340792196"}
0005434096725	5ABE05	7071 440053	DMITRIY MAKAROV	{"email": "makarovdmitriy07021977@postgrespro.ru", "phone": "+70141510687"}
0005434096726	F77842	6661 889923	ALEKSANDR MIKHAYLOV	{"phone": "+70013197445"}
0005434096727	F77842	5932 564139	BORIS MEDVEDEV	{"email": "medvedev.boris.1967@postgrespro.ru", "phone": "+70044413285"}
0005434096728	727D91	8570 194948	SALAVAT KISELEV	{"phone": "+70559406502"}
0005434096729	FC64DD	1639 610885	OLESYA AKIMOVA	{"email": "o.akimova_121965@postgrespro.ru", "phone": "+70650593971"}
0005434096730	3675D5	4037 883007	SERGEY ZAYCEV	{"email": "zaycev_sergey_12081977@postgrespro.ru", "phone": "+70078720645"}
0005434096731	BA9D65	0874 103937	ALEKSANDR FEDOTOV	{"phone": "+70936311333"}
0005434096732	9AE31D	6876 049259	SERGEY ILIN	{"phone": "+70114895351"}
0005434096733	EEC388	4525 916101	GALINA KOMAROVA	{"email": "komarova_g_061973@postgrespro.ru", "phone": "+70082369197"}
0005434096734	E407EE	3934 402626	VALENTINA IVANOVA	{"email": "ivanova_valentina_1977@postgrespro.ru", "phone": "+70509908917"}
0005434096735	E407EE	4777 163004	SERGEY VOROBEV	{"phone": "+70719389222"}
0005434096736	7A1E4C	0566 405175	SERGEY FOMIN	{"phone": "+70144749243"}
0005434096737	87746F	0281 169528	OLGA KONOVALOVA	{"email": "o_konovalova.31051969@postgrespro.ru", "phone": "+70544052512"}
0005434096738	D6C775	4712 734913	ELENA KAZAKOVA	{"email": "ekazakova02041989@postgrespro.ru", "phone": "+70323697074"}
0005434096739	029F94	7922 299535	GENNADIY FEDOROV	{"phone": "+70192502219"}
0005434096740	2DE827	3228 809749	LEONID ORLOV	{"phone": "+70621677455"}
0005434096741	2DE827	5184 821017	VIKTORIYA VASILEVA	{"email": "viktoriyavasileva-05051986@postgrespro.ru", "phone": "+70027128827"}
0005434096742	8F3A96	8728 220249	ALINA ANDREEVA	{"email": "alina_andreeva_041971@postgrespro.ru", "phone": "+70273351510"}
0005434096743	6DA9EB	9475 185583	LEONID GRIGOREV	{"email": "grigorevleonid-061976@postgrespro.ru", "phone": "+70661098820"}
0005434096744	6DA9EB	1165 013360	GALINA VOLKOVA	{"email": "volkova-galina_13111964@postgrespro.ru", "phone": "+70149014563"}
0005434096745	A0F089	9906 475425	ANASTASIYA MAKAROVA	{"phone": "+70520784063"}
0005434096746	A0F089	0237 229626	VIKTOR DAVYDOV	{"phone": "+70840106515"}
0005434096747	E0C3DD	3624 629508	ALEKSANDR TARASOV	{"phone": "+70664641626"}
0005434096748	E0C3DD	7376 264198	ELENA SERGEEVA	{"phone": "+70274510424"}
0005434096749	5C2CB2	1966 372515	ALEKSEY DMITRIEV	{"email": "aleksey.dmitriev_1982@postgrespro.ru", "phone": "+70003584523"}
0005434096750	652BB6	8397 113214	NIKOLAY RODIONOV	{"email": "rodionov.n26031956@postgrespro.ru", "phone": "+70841224201"}
0005434096751	17C576	7888 742641	RUSLAN SMIRNOV	{"phone": "+70546984818"}
0005434096752	17C576	1272 419054	VIKTORIYA VLASOVA	{"email": "vlasovav_031971@postgrespro.ru", "phone": "+70303309407"}
0005434096753	155F58	4440 190673	VIKTOR NIKOLAEV	{"email": "vnikolaev-19091978@postgrespro.ru", "phone": "+70400585525"}
0005434096754	8B706A	2251 068654	ANASTASIYA TARASOVA	{"phone": "+70643701341"}
0005434096755	3D4BDC	4346 906844	ILYA KUZNECOV	{"phone": "+70169287990"}
0005434096756	3D4BDC	4584 185413	VYACHESLAV SMIRNOV	{"email": "vyacheslav.smirnov-16121985@postgrespro.ru", "phone": "+70242810551"}
0005434096757	2508C0	6233 599768	NADEZHDA KARPOVA	{"email": "n_karpova-29011970@postgrespro.ru", "phone": "+70068130031"}
0005434096758	B359D7	0505 153555	NATALYA ANDREEVA	{"email": "andreevan22091962@postgrespro.ru", "phone": "+70690401847"}
0005434096759	B359D7	1348 883540	TATYANA AFANASEVA	{"phone": "+70260146583"}
0005434096760	6A250A	8878 062111	INNA KAZAKOVA	{"email": "ikazakova-1965@postgrespro.ru", "phone": "+70043544690"}
0005434096761	6A250A	7658 397005	LEONID PETROV	{"phone": "+70368677369"}
0005434096762	D885AE	4526 384283	MIKHAIL MIRONOV	{"phone": "+70978188165"}
0005434096763	D885AE	6375 592173	ALEKSANDR KUZNECOV	{"phone": "+70681384125"}
0005434096764	0D3584	9645 321435	SERGEY SERGEEV	{"phone": "+70505935358"}
0005434096765	CE7C27	4125 724471	ANTON MIKHAYLOV	{"email": "mikhaylov-anton_27091972@postgrespro.ru", "phone": "+70271339561"}
0005434096766	CE7C27	6755 811803	MAKSIM MELNIKOV	{"phone": "+70173087889"}
0005434096767	7E5C0C	7907 315175	NIKITA STEPANOV	{"email": "n.stepanov1973@postgrespro.ru", "phone": "+70418292802"}
0005434096768	431EA0	5116 623635	MARINA TIMOFEEVA	{"phone": "+70159498624"}
0005434096769	BA391D	7498 893408	ALEKSANDR ALEKSEEV	{"email": "alekseev.a.121965@postgrespro.ru", "phone": "+70256870117"}
0005434096770	CBF0A1	7746 208161	IGOR FILIPPOV	{"phone": "+70931550916"}
0005434096771	A789D9	2820 488498	NADEZHDA IVANOVA	{"email": "n_ivanova.19051968@postgrespro.ru", "phone": "+70552610573"}
0005434096772	A789D9	4205 253502	ANASTASIYA FROLOVA	{"phone": "+70384173520"}
0005434096773	B64E5C	7583 799030	EVGENIY DMITRIEV	{"phone": "+70364644053"}
0005434096774	B64E5C	5834 289122	INESSA ZAKHAROVA	{"phone": "+70388476124"}
0005434096775	A77FA4	1266 719586	EVGENIY MOROZOV	{"email": "e.morozov121969@postgrespro.ru", "phone": "+70299252780"}
0005434096776	A77FA4	2598 551415	ANNA PETROVA	{"email": "petrova.a_1969@postgrespro.ru", "phone": "+70382685027"}
0005434096777	42E6CD	3665 353051	KIRILL DENISOV	{"phone": "+70224352362"}
0005434096778	42E6CD	0569 131688	ALEKSANDR KUZNECOV	{"phone": "+70656839384"}
0005434096779	88DCD3	0103 228583	NATALYA AFANASEVA	{"email": "afanasevanatalya.051971@postgrespro.ru", "phone": "+70009109250"}
0005434096780	385B0E	1822 483825	RAISA ZHUKOVA	{"email": "zhukova_raisa.061971@postgrespro.ru", "phone": "+70538336205"}
0005434096781	8EDCC5	2394 062712	NIKITA ILIN	{"email": "nikita-ilin.1968@postgrespro.ru", "phone": "+70052061201"}
0005434096782	F41D8F	3952 503374	NINA MELNIKOVA	{"phone": "+70320117551"}
0005434096783	1B816D	0039 267806	EKATERINA ILINA	{"phone": "+70546304632"}
0005434096784	1B816D	3596 653806	LYUDMILA VOROBEVA	{"email": "l-vorobeva_17071977@postgrespro.ru", "phone": "+70472834973"}
0005434096785	DFEE16	9399 827489	ELENA CHERNOVA	{"phone": "+70798038519"}
0005434096786	052A32	9559 802456	ANATOLIY FROLOV	{"phone": "+70767231282"}
0005434096787	052A32	7359 148571	ALEKSEY KUZNECOV	{"phone": "+70183903291"}
0005434096788	07C975	9338 705078	VLADIMIR ZHUKOV	{"email": "zhukov-v.101967@postgrespro.ru", "phone": "+70407134626"}
0005434096789	07C975	9309 407963	ANNA ZHURAVLEVA	{"phone": "+70470876409"}
0005434096790	07C975	4788 695604	NINA KOLESNIKOVA	{"phone": "+70096605815"}
0005434096791	3497E7	4413 738736	ANNA SEMENOVA	{"email": "semenova-anna121974@postgrespro.ru", "phone": "+70248210311"}
0005434096792	85B972	0737 237128	SERGEY KUZNECOV	{"phone": "+70811368131"}
0005434096793	85B972	1277 836543	SVETLANA ERMAKOVA	{"phone": "+70683015370"}
0005434096794	65F93E	2590 237736	ANATOLIY KISELEV	{"email": "akiselev121976@postgrespro.ru", "phone": "+70770526889"}
0005434096795	65F93E	3311 264258	ELIZAVETA MOROZOVA	{"phone": "+70420395768"}
0005434096796	DB2D87	9476 955127	DMITRIY ISAEV	{"email": "isaev_d_28041971@postgrespro.ru", "phone": "+70908536468"}
0005434096797	2DA6B6	5977 757959	ANATOLIY YAKOVLEV	{"phone": "+70014105009"}
0005434096798	B83668	7985 550422	ALINA ILINA	{"email": "ilina.alina-121970@postgrespro.ru", "phone": "+70043962091"}
0005434096799	B83668	8872 077026	TATYANA ANTONOVA	{"email": "antonova-tatyana-1971@postgrespro.ru", "phone": "+70654811328"}
0005434096800	F175BF	2332 038756	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_021979@postgrespro.ru", "phone": "+70006924531"}
0005434096801	095E7D	8216 207749	VLADIMIR FILIPPOV	{"email": "vladimirfilippov-021971@postgrespro.ru", "phone": "+70324147427"}
0005434096802	7F3AB2	2205 854043	VIKTOR MAKSIMOV	{"email": "v-maksimov.24091968@postgrespro.ru", "phone": "+70271885778"}
0005434096803	7F3AB2	0037 371151	SERGEY SOKOLOV	{"email": "sokolov-s-14101973@postgrespro.ru", "phone": "+70201614921"}
0005434096804	34680E	1816 960047	VIKTOR TIMOFEEV	{"phone": "+70427848343"}
0005434096805	BD852E	1754 480984	NADEZHDA IVANOVA	{"phone": "+70319403044"}
0005434097477	8A13B5	0594 058479	ILYA GORBUNOV	{"phone": "+70926386067"}
0005434097449	121562	3535 607775	ILGIZ KUZNECOV	{"phone": "+70441400576"}
0005434097450	783516	1426 171980	LARISA OSIPOVA	{"email": "osipova_l1970@postgrespro.ru", "phone": "+70370705090"}
0005434097451	783516	6778 645998	MARINA FADEEVA	{"phone": "+70680099336"}
0005434097452	A3EA7D	8944 534639	TATYANA BORISOVA	{"email": "t.borisova-17111978@postgrespro.ru", "phone": "+70426014767"}
0005434097453	A3EA7D	3890 544358	NIKOLAY VASILEV	{"phone": "+70334130209"}
0005434097454	399304	9721 945338	PETR PETROV	{"phone": "+70787527174"}
0005434097455	399304	8190 047076	LYUDMILA PETROVA	{"phone": "+70149346411"}
0005434097456	F19A50	4785 964252	ALEKSEY SCHERBAKOV	{"email": "scherbakov_a_03121974@postgrespro.ru", "phone": "+70570444876"}
0005434097457	3846D8	0938 358445	IRINA FROLOVA	{"email": "irina_frolova101971@postgrespro.ru", "phone": "+70043445809"}
0005434097458	0526F3	5565 069307	IRAIDA SOROKINA	{"email": "isorokina-021975@postgrespro.ru", "phone": "+70485172400"}
0005434097459	DAAB9A	3317 832535	DMITRIY ILIN	{"phone": "+70335158563"}
0005434097460	1D7B5F	3928 264628	SERGEY KAZAKOV	{"email": "s-kazakov-09061973@postgrespro.ru", "phone": "+70673107429"}
0005434097461	FEC1B5	1978 480865	IGOR MIKHAYLOV	{"email": "mikhaylovigor061977@postgrespro.ru", "phone": "+70152938487"}
0005434097462	FEC1B5	6699 941227	ILYA OSIPOV	{"email": "osipov_ilya_1960@postgrespro.ru", "phone": "+70155855699"}
0005434097463	FEC1B5	3188 683232	YURIY FEDOTOV	{"phone": "+70486147642"}
0005434097464	726C18	4325 613066	OLGA SOLOVEVA	{"email": "o_soloveva.02081967@postgrespro.ru", "phone": "+70207120380"}
0005434097465	D507AC	5321 297721	NATALYA YUDINA	{"phone": "+70688093656"}
0005434097466	C576C1	1743 713360	GALINA GERASIMOVA	{"phone": "+70470870632"}
0005434097467	85B303	6779 965062	VLADIMIR ISAEV	{"phone": "+70195517447"}
0005434097468	18D216	6392 892682	LYUDMILA EGOROVA	{"phone": "+70362466397"}
0005434097469	FCBBD9	8074 413667	SERGEY VOLKOV	{"phone": "+70233130494"}
0005434097470	148510	1660 757034	MARINA BARANOVA	{"phone": "+70600144721"}
0005434097471	148510	3240 714413	ARSENIY YAKOVLEV	{"email": "yakovlevarseniy_1961@postgrespro.ru", "phone": "+70176806629"}
0005434097472	17762B	0723 653685	GALINA ARKHIPOVA	{"phone": "+70607995427"}
0005434097473	17762B	0817 433658	NADEZHDA KOMAROVA	{"email": "n-komarova101984@postgrespro.ru", "phone": "+70516509909"}
0005434097474	DB45BC	3815 166800	VALENTIN YAKOVLEV	{"email": "yakovlev-v-1958@postgrespro.ru", "phone": "+70867097072"}
0005434097475	DB45BC	8797 772351	IVAN GRIGOREV	{"phone": "+70699332274"}
0005434097476	A42150	3916 258975	ALEKSANDR ZHURAVLEV	{"phone": "+70287665254"}
0005434097478	E9EC4C	6871 052535	ANTON NIKOLAEV	{"email": "anton_nikolaev.14101972@postgrespro.ru", "phone": "+70178552751"}
0005434097479	D33217	6930 797192	NADEZHDA CHERNOVA	{"email": "chernovanadezhda.1971@postgrespro.ru", "phone": "+70212405975"}
0005434097480	1404D7	5449 549753	ELIZAVETA ROMANOVA	{"email": "elizaveta_romanova_1969@postgrespro.ru", "phone": "+70863455318"}
0005434097481	1404D7	7891 207124	ALEKSANDR NOVIKOV	{"phone": "+70511413681"}
0005434097482	DF1D91	7001 442185	NADEZHDA NAZAROVA	{"email": "nadezhda.nazarova_18011971@postgrespro.ru", "phone": "+70755442151"}
0005434097483	DF1D91	9887 915185	EVGENIYA MASLOVA	{"email": "maslovaevgeniya.10021974@postgrespro.ru", "phone": "+70361305812"}
0005434097484	B84F5C	7061 455125	ALEKSANDRA GRISHINA	{"email": "grishinaaleksandra_021971@postgrespro.ru", "phone": "+70750194192"}
0005434097485	B84F5C	9493 459124	OLGA NIKOLAEVA	{"email": "olga_nikolaeva25111964@postgrespro.ru", "phone": "+70472205378"}
0005434097486	2429C1	7716 252440	TATYANA SMIRNOVA	{"phone": "+70547515331"}
0005434097487	4CC791	0649 063079	NIKOLAY DENISOV	{"email": "n-denisov_30051975@postgrespro.ru", "phone": "+70652904666"}
0005434097488	3B7578	1061 110369	ARTEM ZHUKOV	{"email": "zhukov.artem041970@postgrespro.ru", "phone": "+70356239049"}
0005434097489	F6B4D3	4869 231999	GENNADIY YAKOVLEV	{"phone": "+70082880509"}
0005434097490	F6B4D3	6539 773290	OLGA DENISOVA	{"email": "odenisova1987@postgrespro.ru", "phone": "+70664584076"}
0005434097491	6181AC	2586 887298	MATVEY SEMENOV	{"email": "semenov_matvey121972@postgrespro.ru", "phone": "+70653503103"}
0005434097492	BE3326	1798 221639	ALEKSANDRA FROLOVA	{"email": "frolova-a.101975@postgrespro.ru", "phone": "+70569263814"}
0005434097493	B40442	1112 687525	ALEKSEY SEMENOV	{"email": "aleksey-semenov-04031963@postgrespro.ru", "phone": "+70423483797"}
0005434097494	7D3664	3087 046740	LIDIYA VOROBEVA	{"phone": "+70868891172"}
0005434097495	8AA88B	1819 174321	PETR SOKOLOV	{"phone": "+70418106618"}
0005434097496	5BF6F0	0791 152239	VLADIMIR POPOV	{"phone": "+70894858302"}
0005434097497	222FBE	2114 108723	MARIYA KOLESNIKOVA	{"email": "mkolesnikova-1973@postgrespro.ru", "phone": "+70998892827"}
0005434097498	A62430	9772 713926	IRINA FADEEVA	{"email": "fadeeva_irina-03031974@postgrespro.ru", "phone": "+70225733931"}
0005434097499	E3BC07	8698 669666	IGOR EGOROV	{"email": "egorovi23101969@postgrespro.ru", "phone": "+70712181982"}
0005434097500	F05F8D	0666 945405	ELENA MELNIKOVA	{"phone": "+70090395755"}
0005434097501	62D4D0	9152 731762	TAMARA BORISOVA	{"email": "borisova.t.081982@postgrespro.ru", "phone": "+70860018076"}
0005434097502	B6341E	2596 753473	TATYANA TIKHONOVA	{"email": "tikhonovat-10051974@postgrespro.ru", "phone": "+70319222971"}
0005434097503	C3E84A	8550 782506	ANASTASIYA PAVLOVA	{"phone": "+70862594009"}
0005434097504	700A7F	5859 044660	TATYANA SEMENOVA	{"phone": "+70601140672"}
0005434097505	700A7F	9702 751254	OLGA EFIMOVA	{"email": "olgaefimova_091966@postgrespro.ru", "phone": "+70957301674"}
0005434097506	BC008A	7472 549241	ALEKSEY KOZLOV	{"phone": "+70740908358"}
0005434097507	476868	3831 203031	ALEKSANDR ZHURAVLEV	{"phone": "+70099906111"}
0005434097508	865400	8333 114285	IVAN POPOV	{"email": "popov_ivan-101961@postgrespro.ru", "phone": "+70649705521"}
0005434097509	66E849	6260 078399	VADIM SOKOLOV	{"email": "v-sokolov.041965@postgrespro.ru", "phone": "+70349909987"}
0005434097510	A5D1BF	9031 976459	IDA MEDVEDEVA	{"phone": "+70133652523"}
0005434097511	5BD415	1548 600490	EKATERINA NAZAROVA	{"email": "nazarova.ekaterina.111970@postgrespro.ru", "phone": "+70524775166"}
0005434097512	5BD415	6844 411824	EVGENIY SMIRNOV	{"phone": "+70135712863"}
0005434097513	558C2F	4493 398905	YAN ANTONOV	{"phone": "+70213808653"}
0005434097514	558C2F	0919 441450	VLADIMIR SOLOVEV	{"phone": "+70291579699"}
0005434136685	9790E7	8205 538189	TATYANA OVCHINNIKOVA	{"phone": "+70653111603"}
0005434136675	BB5685	8037 992016	NATALYA BELOVA	{"email": "n_belova_25031979@postgrespro.ru", "phone": "+70126460680"}
0005434136676	BB5685	0689 839221	ALEKSANDR TARASOV	{"phone": "+70780229285"}
0005434136677	081B2F	1465 187610	LARISA TIMOFEEVA	{"phone": "+70885592198"}
0005434136678	081B2F	9387 373188	EKATERINA GERASIMOVA	{"phone": "+70707914031"}
0005434136679	103ECB	9876 104114	PAVEL IVANOV	{"email": "pavel.ivanov.1974@postgrespro.ru", "phone": "+70030651272"}
0005434136680	BA5E56	8087 071135	MAKSIM SOKOLOV	{"email": "sokolov.maksim1971@postgrespro.ru", "phone": "+70060273991"}
0005434136681	D3FC2E	0669 168689	LYUDMILA TROFIMOVA	{"phone": "+70185923441"}
0005434136682	71E630	5733 670500	VLADIMIR AFANASEV	{"email": "vladimir_afanasev-041977@postgrespro.ru", "phone": "+70174698875"}
0005434136683	9667C7	8791 361182	EVGENIY ILIN	{"email": "ilin-evgeniy_1976@postgrespro.ru", "phone": "+70357472122"}
0005434136684	9667C7	0182 216888	ANASTASIYA DENISOVA	{"email": "denisovaanastasiya-19051961@postgrespro.ru", "phone": "+70645702072"}
0005434136686	C6A532	9623 919884	OLGA NESTEROVA	{"email": "onesterova_121981@postgrespro.ru", "phone": "+70493815686"}
0005434136687	C6A532	7856 862140	IGOR VOROBEV	{"email": "i.vorobev_05041973@postgrespro.ru", "phone": "+70526209922"}
0005434136688	C6A532	6559 209163	IRINA ISAEVA	{"email": "i.isaeva-081966@postgrespro.ru", "phone": "+70241567598"}
0005434136689	6DF041	3062 360251	ELLA ROMANOVA	{"phone": "+70575435009"}
0005434136690	FCB999	3274 055160	VLADIMIR POPOV	{"phone": "+70983193097"}
0005434136691	93C46A	2309 849604	DARYA TARASOVA	{"phone": "+70206930852"}
0005434136692	93C46A	8318 844333	SERGEY GORBUNOV	{"email": "sergey-gorbunov04011977@postgrespro.ru", "phone": "+70533858775"}
0005434136693	93C46A	5075 914654	ILYA GERASIMOV	{"phone": "+70787936844"}
0005434136694	0C8D3A	5406 532183	GENNADIY ANDREEV	{"phone": "+70240753505"}
0005434136695	0C8D3A	7659 667517	IRINA SOKOLOVA	{"email": "sokolova-irina-26101971@postgrespro.ru", "phone": "+70186381089"}
0005434136696	AEC186	8976 267568	ANNA MIKHAYLOVA	{"email": "anna.mikhaylova.081972@postgrespro.ru", "phone": "+70292840703"}
0005434136697	AEC186	4050 775123	IRINA ANDREEVA	{"email": "iandreeva.23101971@postgrespro.ru", "phone": "+70008343067"}
0005434136698	5A78AF	9133 988372	ANASTASIYA FEDOROVA	{"email": "anastasiyafedorova_031975@postgrespro.ru", "phone": "+70096933840"}
0005434136699	4F2424	6845 049219	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev.091975@postgrespro.ru", "phone": "+70649327070"}
0005434136700	F2C1D5	4843 190917	NIKOLAY EGOROV	{"email": "n_egorov.111982@postgrespro.ru", "phone": "+70277461088"}
0005434136701	F2C1D5	2896 344441	RAFAIL KAZAKOV	{"phone": "+70656543906"}
0005434136702	C8B357	2647 874511	GENNADIY NIKITIN	{"email": "nikitin.g_05111963@postgrespro.ru", "phone": "+70088671414"}
0005434136703	C8B357	0284 892676	NATALIYA KISELEVA	{"email": "kiseleva-n.09101979@postgrespro.ru", "phone": "+70235121773"}
0005434136704	5D76AB	5540 487309	NATALYA NIKITINA	{"email": "n-nikitina-08071974@postgrespro.ru", "phone": "+70340702467"}
0005434136705	A1756A	2806 907986	ALEKSEY TARASOV	{"email": "atarasov1981@postgrespro.ru", "phone": "+70107254348"}
0005434136706	A1756A	0312 608327	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir_111976@postgrespro.ru", "phone": "+70684615213"}
0005434136707	1A09FF	8824 437141	EKATERINA MAKAROVA	{"phone": "+70302156899"}
0005434136708	1A09FF	4366 467659	VLADIMIR IVANOV	{"phone": "+70605897477"}
0005434136709	E30B37	5207 190279	ALEKSEY SEMENOV	{"email": "aleksey-semenov27101965@postgrespro.ru", "phone": "+70690892657"}
0005434136710	99551A	8802 461969	ALEKSEY ZAKHAROV	{"phone": "+70631708896"}
0005434136711	0E00F6	7428 454080	SERGEY NAUMOV	{"email": "naumov_s-081968@postgrespro.ru", "phone": "+70696487909"}
0005434136712	0E00F6	4039 966012	DMITRIY VOLKOV	{"email": "d_volkov-1981@postgrespro.ru", "phone": "+70131394561"}
0005434136713	43B083	5243 794972	OLGA VASILEVA	{"phone": "+70055329255"}
0005434136714	43B083	3548 224114	DMITRIY ANDREEV	{"phone": "+70513382976"}
0005434136715	6D4E4F	7066 006756	ALEKSANDRA BARANOVA	{"phone": "+70285028719"}
0005434136716	6D4E4F	8927 168949	DMITRIY ORLOV	{"phone": "+70181291164"}
0005434136717	E205D4	0724 487562	LILIYA MOROZOVA	{"email": "l.morozova_041979@postgrespro.ru", "phone": "+70136354717"}
0005434136718	E205D4	3137 208818	ANATOLIY ABRAMOV	{"email": "abramov_anatoliy22031982@postgrespro.ru", "phone": "+70551262913"}
0005434136719	0AC49D	5845 497059	DENIS KUZNECOV	{"phone": "+70423938236"}
0005434136720	08378D	2798 865071	ALEKSANDR MARTYNOV	{"phone": "+70116221989"}
0005434136721	DBC8F9	0244 736806	OLGA FEDOROVA	{"email": "o.fedorova.1982@postgrespro.ru", "phone": "+70872732696"}
0005434136722	D035C5	9334 534424	TATYANA MATVEEVA	{"phone": "+70251075902"}
0005434136723	180B9C	7117 794934	RAFAEL IVANOV	{"phone": "+70210556789"}
0005434136724	360A91	4828 810083	ANTON NOVIKOV	{"phone": "+70614136785"}
0005434136726	DB8C0A	7290 100958	IRINA GAVRILOVA	{"email": "i.gavrilova-1969@postgrespro.ru", "phone": "+70612729291"}
0005434136727	4E4B87	1006 462097	ALEKSANDRA FADEEVA	{"phone": "+70301823335"}
0005434136728	A48006	6584 907468	TATYANA IVANOVA	{"email": "tatyanaivanova_06021973@postgrespro.ru", "phone": "+70590671634"}
0005434136729	BF0A42	8381 270372	SERGEY ROMANOV	{"phone": "+70181306489"}
0005434136730	BF0A42	7753 932019	MARAT SIDOROV	{"email": "marat-sidorov1967@postgrespro.ru", "phone": "+70491871817"}
0005434136731	8F6B84	5224 704469	VALENTINA KONOVALOVA	{"email": "konovalova.v011970@postgrespro.ru", "phone": "+70974719205"}
0005434136732	754AD4	2060 829610	SERGEY MARTYNOV	{"email": "martynov.s.02061962@postgrespro.ru", "phone": "+70053122926"}
0005434136733	62D829	7712 303192	ALEKSANDRA GERASIMOVA	{"email": "gerasimova_aleksandra-1969@postgrespro.ru", "phone": "+70782470722"}
0005434136734	A96F11	4236 919563	LIDIYA SOROKINA	{"phone": "+70675120975"}
0005434136735	A96F11	2478 403021	EGOR MELNIKOV	{"phone": "+70154190440"}
0005434136736	C15ADD	2045 481519	TATYANA LAZAREVA	{"email": "lazareva_tatyana-21101974@postgrespro.ru", "phone": "+70932828582"}
0005434136737	C15ADD	8552 015152	VERA KOZLOVA	{"phone": "+70128329304"}
0005434136738	AEE841	9286 882062	LYUDMILA CHERNOVA	{"phone": "+70561213615"}
0005434136739	AEE841	4142 666736	ELENA OVCHINNIKOVA	{"phone": "+70148005888"}
0005434136740	0B0044	2484 264686	TATYANA ZHURAVLEVA	{"email": "zhuravleva.t28061964@postgrespro.ru", "phone": "+70318215756"}
0005434136741	0B0044	3808 203927	ELENA YUDINA	{"phone": "+70902612099"}
0005434136742	957FA2	1237 654218	SERGEY MARTYNOV	{"email": "s_martynov.1975@postgrespro.ru", "phone": "+70170472912"}
0005434136743	957FA2	0474 697175	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa_11021967@postgrespro.ru", "phone": "+70439902486"}
0005434136744	4FBB08	1006 664498	VALENTINA MOROZOVA	{"email": "morozovav-091976@postgrespro.ru", "phone": "+70697596313"}
0005434136745	A11262	6807 021913	VLADIMIR KUZMIN	{"email": "kuzmin_v-19101967@postgrespro.ru", "phone": "+70972323045"}
0005434136746	A11262	0878 678841	OKSANA GORBUNOVA	{"email": "o_gorbunova-121966@postgrespro.ru", "phone": "+70083398450"}
0005434136747	A11262	9497 844228	EVGENIY POPOV	{"email": "popov.evgeniy_22031968@postgrespro.ru", "phone": "+70574782764"}
0005434136748	03AF98	4949 840272	LILIYA NIKOLAEVA	{"email": "nikolaeva.liliya_05101966@postgrespro.ru", "phone": "+70792079468"}
0005434136749	C11BF1	6114 208275	SOFIYA KUDRYASHOVA	{"phone": "+70256319335"}
0005434136750	6252D7	1774 865804	ELENA ILINA	{"email": "elena.ilina.091973@postgrespro.ru", "phone": "+70415704315"}
0005434136751	6252D7	6000 221914	DENIS ALEKSEEV	{"email": "alekseev_d.1974@postgrespro.ru", "phone": "+70086220438"}
0005434136752	F8AA39	1811 870043	ANDREY KULIKOV	{"email": "andreykulikov-1975@postgrespro.ru", "phone": "+70177492884"}
0005434136753	1E520E	3427 024505	ALEKSANDR VOLKOV	{"phone": "+70420607254"}
0005434136754	A90A76	8686 460532	LIDIYA KUZNECOVA	{"phone": "+70854387831"}
0005434136755	451E47	5483 136896	VIKTOR GERASIMOV	{"phone": "+70277342094"}
0005434136756	7850C1	6334 606947	NINA YAKOVLEVA	{"phone": "+70297277578"}
0005434136757	DBFAED	8162 110357	ALEKSANDR SCHERBAKOV	{"phone": "+70745854483"}
0005434136758	9A0A59	8731 533338	ULYANA VASILEVA	{"email": "vasileva-u.101962@postgrespro.ru", "phone": "+70512552376"}
0005434136759	3E9550	6202 432579	NATALYA CHERNOVA	{"phone": "+70872996411"}
0005434136760	9404FF	6050 300163	VIKTOR GORBUNOV	{"email": "gorbunov-viktor_1979@postgrespro.ru", "phone": "+70928119524"}
0005434136761	9404FF	5855 955202	VIKTORIYA NOVIKOVA	{"email": "v-novikova111968@postgrespro.ru", "phone": "+70773950042"}
0005434136762	F65A54	7618 330062	MARIYA KUZNECOVA	{"email": "m.kuznecova071979@postgrespro.ru", "phone": "+70725109965"}
0005434136763	352E5E	9058 292368	VERA TARASOVA	{"email": "tarasova-vera_1970@postgrespro.ru", "phone": "+70700675832"}
0005434136764	5079F7	6009 286612	NIKOLAY ABRAMOV	{"email": "abramovn.06041969@postgrespro.ru", "phone": "+70474014744"}
0005434136765	5079F7	6331 257761	MARIYA FOMINA	{"phone": "+70234899351"}
0005434136766	183FE1	7618 574535	LIDIYA LEBEDEVA	{"phone": "+70610082034"}
0005434136767	3FBA84	2455 853859	GALINA FOMINA	{"email": "fomina_galina_1973@postgrespro.ru", "phone": "+70070350314"}
0005434136768	958030	8888 837224	EVGENIYA VOLKOVA	{"email": "volkova.e.031973@postgrespro.ru", "phone": "+70602736971"}
0005434136769	C8DE49	5683 653997	VERA BELOVA	{"email": "belova.vera_1968@postgrespro.ru", "phone": "+70403753529"}
0005434136770	C8DE49	3792 258408	NIKOLAY RODIONOV	{"phone": "+70362751227"}
0005434136771	5CB6BE	1174 662972	MARIYA NIKOLAEVA	{"phone": "+70126533202"}
0005434136772	6287E3	7423 555405	ALEKSEY DAVYDOV	{"phone": "+70498782703"}
0005434136773	5519FA	7714 601645	VALENTINA YAKOVLEVA	{"phone": "+70481447777"}
0005434136774	2A3236	1575 457859	VIKTOR SOKOLOV	{"phone": "+70396252796"}
0005434136775	2A3236	2201 264006	VLADIMIR BORISOV	{"phone": "+70715109242"}
0005434136776	BFB221	5691 197255	SERGEY IVANOV	{"email": "ivanov-sergey_1977@postgrespro.ru", "phone": "+70086480647"}
0005434136777	3D450A	5007 976432	NATALYA AFANASEVA	{"email": "afanaseva_n-16061984@postgrespro.ru", "phone": "+70131885288"}
0005434136778	77DA41	8534 056863	ANATOLIY BORISOV	{"phone": "+70279735471"}
0005434136779	271EF7	6464 373694	ALINA ZAKHAROVA	{"email": "a.zakharova1968@postgrespro.ru", "phone": "+70041499791"}
0005434136780	271EF7	4740 801135	ELENA PETROVA	{"phone": "+70173532438"}
0005434136781	B38709	3365 612368	ALEKSANDR VLASOV	{"email": "vlasov.a-1974@postgrespro.ru", "phone": "+70437222167"}
0005434136782	FCD67E	7169 372890	EVGENIY BELOV	{"email": "evgeniy-belov_09091963@postgrespro.ru", "phone": "+70945105524"}
0005434136783	EF280C	9259 892999	ALEKSANDRA BARANOVA	{"phone": "+70557041594"}
0005434136784	B1DA0C	5708 915038	VLADIMIR POPOV	{"email": "v.popov_1972@postgrespro.ru", "phone": "+70000738375"}
0005434136785	9CA12E	6704 556595	OLEG NAZAROV	{"phone": "+70138821175"}
0005434136786	9CA12E	5592 070208	LYUBOV IVANOVA	{"email": "ivanova.lyubov1967@postgrespro.ru", "phone": "+70154373138"}
0005434136787	6BEC02	8130 639278	VALENTIN SHEVCHENKO	{"email": "valentinshevchenko.19041966@postgrespro.ru", "phone": "+70089922782"}
0005434136788	E68BF1	8679 388343	IGOR YAKOVLEV	{"email": "yakovlev-igor_041972@postgrespro.ru", "phone": "+70824727667"}
0005434136789	6F4D9A	0019 954751	ANDREY NAUMOV	{"email": "andrey.naumov1968@postgrespro.ru", "phone": "+70146758372"}
0005434136790	6F4D9A	1046 495015	IRINA FEDOROVA	{"email": "fedorova_irina.13041977@postgrespro.ru", "phone": "+70624954008"}
0005434136791	4257C0	0346 471776	ZINAIDA KOROLEVA	{"email": "zinaidakoroleva.31031963@postgrespro.ru", "phone": "+70463068821"}
0005434136792	4257C0	4046 811843	LARISA PETROVA	{"phone": "+70708564039"}
0005434136793	C64423	3481 799561	KONSTANTIN ROMANOV	{"phone": "+70333135216"}
0005434136794	5BE163	3582 950833	VLADIMIR ANDREEV	{"email": "andreev.vladimir_10121971@postgrespro.ru", "phone": "+70040914416"}
0005434136795	28E49E	1729 199425	EVDOKIYA KUZMINA	{"email": "kuzmina-evdokiya-02111971@postgrespro.ru", "phone": "+70423538205"}
0005434136796	367B06	6436 707208	FEDOR NOVIKOV	{"email": "novikov_f081960@postgrespro.ru", "phone": "+70341263270"}
0005434136797	9F1DBE	2999 668102	ALEKSANDR CHERNOV	{"email": "chernov.a051979@postgrespro.ru", "phone": "+70565024734"}
0005434136798	55CCAD	9369 730746	VIKTOR PETROV	{"phone": "+70823310956"}
0005434136799	0EC544	9093 719685	LYUDMILA POPOVA	{"phone": "+70913186614"}
0005434136800	78E058	4309 074157	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey_05071975@postgrespro.ru", "phone": "+70622879847"}
0005434136801	78E058	9894 333959	ANDREY KUZMIN	{"phone": "+70057835422"}
0005434136802	78E058	2484 723817	SERGEY IVANOV	{"email": "ivanov.sergey-121967@postgrespro.ru", "phone": "+70932187662"}
0005434136803	C4A1DE	1295 887593	IRINA SIDOROVA	{"email": "sidorovairina.12121970@postgrespro.ru", "phone": "+70193789052"}
0005434136804	84C7CA	5703 748317	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr.1970@postgrespro.ru", "phone": "+70832295959"}
0005434136805	84C7CA	6890 719277	YULIYA MATVEEVA	{"email": "matveevay.021971@postgrespro.ru", "phone": "+70585792922"}
0005434136806	FCE42C	1272 207868	VLADIMIR POPOV	{"phone": "+70635873826"}
0005434136807	23E045	1097 429357	GALINA OSIPOVA	{"phone": "+70397753785"}
0005434136808	73AD30	3707 551354	VALENTIN ANDREEV	{"email": "andreev-valentin1967@postgrespro.ru", "phone": "+70202364276"}
0005434136809	73AD30	0182 648016	VERONIKA MAKAROVA	{"phone": "+70366349393"}
0005434136810	73AD30	4930 931664	MARIYA OSIPOVA	{"phone": "+70190190272"}
0005434136811	8547E7	3777 553115	MARIYA ROMANOVA	{"email": "mariya.romanova.061972@postgrespro.ru", "phone": "+70508562764"}
0005434136812	9B86D3	5811 373936	YURIY IVANOV	{"email": "y.ivanov081982@postgrespro.ru", "phone": "+70895001703"}
0005434136813	0061B4	1464 458214	MIKHAIL MIKHAYLOV	{"phone": "+70558302046"}
0005434136814	0061B4	0097 554715	LARISA YAKOVLEVA	{"email": "yakovleva.larisa_08081963@postgrespro.ru", "phone": "+70694459989"}
0005434136815	F1D689	9452 587699	VLADIMIR SOKOLOV	{"email": "vsokolov_051983@postgrespro.ru", "phone": "+70994944983"}
0005434136816	F1D689	0702 624011	SEMEN ALEKSANDROV	{"phone": "+70169765215"}
0005434136817	82DCEB	9421 724074	SERGEY MEDVEDEV	{"email": "medvedev-sergey.1983@postgrespro.ru", "phone": "+70237180802"}
0005434136818	90140D	6179 397628	IVAN NOVIKOV	{"email": "i.novikov-1967@postgrespro.ru", "phone": "+70780325513"}
0005434136819	7D95BC	9445 733932	ALEKSANDR GRIGOREV	{"phone": "+70791941843"}
0005434136820	408516	6559 900010	ALEKSANDR BORISOV	{"email": "borisov.a_011969@postgrespro.ru", "phone": "+70039913507"}
0005434136821	978603	6961 482213	DMITRIY GORBUNOV	{"email": "gorbunov_dmitriy.1966@postgrespro.ru", "phone": "+70830666930"}
0005434136822	978603	6618 881985	OLGA ANDREEVA	{"phone": "+70474930443"}
0005434136823	FAE153	4635 327394	IVAN MAKAROV	{"phone": "+70040730428"}
0005434136824	793048	8131 675785	LYUDMILA KUZNECOVA	{"email": "l_kuznecova-071975@postgrespro.ru", "phone": "+70667835350"}
0005434136825	6F538B	4967 404237	VERONIKA BOGDANOVA	{"email": "vbogdanova23041978@postgrespro.ru", "phone": "+70884235327"}
0005434136826	6F538B	6929 555593	VITALIY POPOV	{"email": "popov_vitaliy.071979@postgrespro.ru", "phone": "+70748953956"}
0005434136827	C01ED5	1927 671088	VERA ANDREEVA	{"phone": "+70171838950"}
0005434136828	C01ED5	1959 602638	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana03041970@postgrespro.ru", "phone": "+70807973666"}
0005434136829	C01ED5	3349 149935	VIKTOR TIMOFEEV	{"email": "viktor-timofeev-021985@postgrespro.ru", "phone": "+70385061357"}
0005434136830	BF13F5	5494 170339	LARISA KUZNECOVA	{"phone": "+70144207885"}
0005434136831	1FD927	4990 431274	NATALYA ZAYCEVA	{"email": "nzayceva-101965@postgrespro.ru", "phone": "+70745886169"}
0005434136832	1FD927	6341 037055	GALINA MIRONOVA	{"phone": "+70680097392"}
0005434136833	7FA39B	4434 505813	VADIM KAZAKOV	{"phone": "+70180250528"}
0005434136834	6FD4F6	9252 452059	VIKTOR SCHERBAKOV	{"email": "v-scherbakov.1965@postgrespro.ru", "phone": "+70491011302"}
0005434136835	6FD4F6	1513 018040	DARYA KONDRATEVA	{"email": "kondrateva-d.101965@postgrespro.ru", "phone": "+70669117390"}
0005434136836	31FA00	4661 389381	ARTUR NAUMOV	{"phone": "+70009945110"}
0005434136837	78444A	6795 572766	IRINA GORBUNOVA	{"email": "igorbunova-21011980@postgrespro.ru", "phone": "+70551511924"}
0005434136838	78444A	6533 210189	VLADIMIR ZHURAVLEV	{"phone": "+70307947787"}
0005434136839	518D00	0095 277076	KIRILL NIKITIN	{"email": "nikitin-kirill1969@postgrespro.ru", "phone": "+70163564393"}
0005434136840	4873A0	6715 923666	OLGA VOROBEVA	{"phone": "+70021228981"}
0005434136841	02BAD6	2554 263516	LYUDMILA FILATOVA	{"phone": "+70654232300"}
0005434136842	ABC147	8180 096036	DMITRIY MOROZOV	{"phone": "+70698129280"}
0005434136843	ABC147	1720 661224	ALEKSANDR GAVRILOV	{"phone": "+70755813146"}
0005434136844	D6A4CE	3498 213985	SERGEY KUZNECOV	{"email": "s_kuznecov1981@postgrespro.ru", "phone": "+70954904151"}
0005434136845	51EB1C	6345 491905	LYUDMILA ZHURAVLEVA	{"email": "zhuravleval26091981@postgrespro.ru", "phone": "+70129459327"}
0005434136846	2F602D	4737 007609	VLADIMIR ANDREEV	{"email": "vladimir-andreev-111971@postgrespro.ru", "phone": "+70502437124"}
0005434136847	A678B5	5891 351514	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova_15041963@postgrespro.ru", "phone": "+70719125623"}
0005434136848	1C9E3D	0927 709581	VERA ZAKHAROVA	{"email": "zakharovavera091979@postgrespro.ru", "phone": "+70238079795"}
0005434136849	1C9E3D	2214 143344	IGOR KRASNOV	{"phone": "+70550318182"}
0005434136850	08C87E	6959 480369	NADEZHDA NOVIKOVA	{"email": "n-novikova1958@postgrespro.ru", "phone": "+70980404806"}
0005434136851	D11F5C	9886 902596	YULIYA DMITRIEVA	{"email": "y_dmitrieva061973@postgrespro.ru", "phone": "+70992128419"}
0005434137133	5BA0EF	7810 539347	ALEKSANDR KUZNECOV	{"phone": "+70900338356"}
0005434136852	D11F5C	6344 439162	POLINA SOROKINA	{"email": "sorokina-p-19041972@postgrespro.ru", "phone": "+70741326358"}
0005434136853	D11F5C	2660 760539	IGOR PAVLOV	{"email": "pavlov_i21051978@postgrespro.ru", "phone": "+70206201150"}
0005434136854	82BCDE	6051 769833	MARIYA DAVYDOVA	{"email": "davydovamariya_041979@postgrespro.ru", "phone": "+70149254032"}
0005434136855	82BCDE	7823 057298	LIDIYA KONDRATEVA	{"phone": "+70915772991"}
0005434136856	B4E2E3	7322 313405	MARINA DANILOVA	{"email": "m_danilova1970@postgrespro.ru", "phone": "+70143194208"}
0005434136857	F300FF	9302 499770	SERGEY FEDOROV	{"phone": "+70471461855"}
0005434136858	183A65	1040 682729	TATYANA ANDREEVA	{"email": "tatyana_andreeva-29061977@postgrespro.ru", "phone": "+70463760008"}
0005434136859	3F6722	8184 623170	ANNA BORISOVA	{"phone": "+70964042684"}
0005434136860	3F6722	8830 584563	LYUBOV SOKOLOVA	{"phone": "+70468752356"}
0005434136861	B31FB7	1454 566887	VALENTINA FROLOVA	{"email": "valentina-frolova-03061972@postgrespro.ru", "phone": "+70721784294"}
0005434136862	B31FB7	9247 454131	GENNADIY ZAKHAROV	{"email": "gennadiy_zakharov_16121968@postgrespro.ru", "phone": "+70056550399"}
0005434136863	9D0385	9928 425078	ALEKSANDR PAVLOV	{"phone": "+70276544229"}
0005434136864	02C8D0	6384 290467	VIKTORIYA MAKSIMOVA	{"phone": "+70486072309"}
0005434136865	AE4880	7171 400562	YULIYA SEMENOVA	{"phone": "+70509124698"}
0005434136866	BE10C3	7057 187999	NATALYA RYABOVA	{"email": "ryabovanatalya.13061971@postgrespro.ru", "phone": "+70190477821"}
0005434136867	BE10C3	1394 818435	VLADIMIR EGOROV	{"phone": "+70332147918"}
0005434136868	DD2D99	8464 215884	NIKOLAY VOLKOV	{"phone": "+70838756008"}
0005434136869	DD2D99	2974 840686	DMITRIY NIKITIN	{"email": "nikitind_02041973@postgrespro.ru", "phone": "+70165306057"}
0005434136870	DD2D99	4542 763635	ANZHELA ZAYCEVA	{"email": "anzhelazayceva1985@postgrespro.ru", "phone": "+70918734214"}
0005434136871	323B74	3181 457142	OLEG NIKITIN	{"phone": "+70743910472"}
0005434136872	D9BDDC	9419 716482	DARYA PETROVA	{"phone": "+70134445119"}
0005434136873	5CF482	0580 051684	ELENA ZHUKOVA	{"email": "zhukova.e_20101971@postgrespro.ru", "phone": "+70784049852"}
0005434136874	4E27FD	3924 029893	SERGEY NAUMOV	{"phone": "+70811941329"}
0005434136875	C811A4	0549 374642	ARTEM PETROV	{"phone": "+70240535511"}
0005434136876	C811A4	0603 768516	YULIYA LEBEDEVA	{"phone": "+70863933703"}
0005434136877	C98B9C	2840 160601	SERGEY BARANOV	{"email": "baranov_s_29101977@postgrespro.ru", "phone": "+70766431709"}
0005434136878	049CE9	3999 070001	VLADIMIR VOROBEV	{"email": "vorobev_v.03091969@postgrespro.ru", "phone": "+70701035832"}
0005434136879	845415	3951 350166	SERGEY NIKOLAEV	{"email": "nikolaev_s-081975@postgrespro.ru", "phone": "+70066015863"}
0005434136880	845415	8074 376864	ANNA LAZAREVA	{"phone": "+70430029038"}
0005434136881	DB14F7	1251 394624	ANATOLIY SCHERBAKOV	{"phone": "+70791554005"}
0005434136882	F2EAE6	2898 161928	EVGENIY DAVYDOV	{"phone": "+70522444876"}
0005434136883	26A4A5	1379 978170	NATALYA ANDREEVA	{"phone": "+70095964948"}
0005434136884	D2DB30	8803 282230	DMITRIY OSIPOV	{"email": "dmitriy.osipov.12091980@postgrespro.ru", "phone": "+70121866449"}
0005434136885	1A3122	2399 535315	ALEKSANDR KONOVALOV	{"phone": "+70451212028"}
0005434136886	20E7BA	8387 907455	ALEKSANDR STEPANOV	{"phone": "+70020339221"}
0005434136887	20E7BA	4956 822425	ALEKSANDR MARTYNOV	{"phone": "+70924724845"}
0005434136888	20E7BA	1489 210490	IVAN FEDOTOV	{"phone": "+70978876675"}
0005434136889	67D993	3306 929870	OLESYA ORLOVA	{"email": "orlova_o-121968@postgrespro.ru", "phone": "+70091400998"}
0005434136890	BFC5AB	4100 276321	ELENA KOROLEVA	{"phone": "+70564694851"}
0005434136891	EBE3FA	8455 648758	ANDREY BELOV	{"email": "andrey_belov-1969@postgrespro.ru", "phone": "+70200776931"}
0005434136892	6557A7	2837 819028	VALENTINA MOROZOVA	{"phone": "+70791721366"}
0005434136893	3B734B	9097 228917	SEMEN BORISOV	{"phone": "+70444970772"}
0005434136894	88BE35	8273 682981	VIKTORIYA FADEEVA	{"phone": "+70353549236"}
0005434136895	3E5CFE	9998 971870	VLADIMIR ZAKHAROV	{"email": "v_zakharov-26051970@postgrespro.ru", "phone": "+70685359740"}
0005434136896	3E5CFE	7261 422761	LIDIYA VLASOVA	{"email": "lidiya.vlasova_021977@postgrespro.ru", "phone": "+70266814254"}
0005434136897	EC9F3E	6842 769712	MAKSIM VOLKOV	{"email": "mvolkov.1967@postgrespro.ru", "phone": "+70413467574"}
0005434136898	CFA6DE	8475 805663	YULIYA GORBUNOVA	{"phone": "+70911086336"}
0005434136899	CFA6DE	1557 579728	GRIGORIY VLASOV	{"email": "grigoriy_vlasov28101973@postgrespro.ru", "phone": "+70705996130"}
0005434136900	CFA6DE	3330 336133	RIFAT YAKOVLEV	{"phone": "+70224320027"}
0005434136901	D1F0D3	5223 581919	ILYA ZAKHAROV	{"email": "zakharovilya061971@postgrespro.ru", "phone": "+70983248733"}
0005434136902	ECC430	3274 130160	VLADIMIR VLASOV	{"phone": "+70286030885"}
0005434136903	ECC430	9521 223813	DIANA ROMANOVA	{"phone": "+70322206438"}
0005434136904	F4EFB1	3165 568432	VYACHESLAV KOZLOV	{"email": "kozlov.v-091971@postgrespro.ru", "phone": "+70213980601"}
0005434136905	F4EFB1	4465 484848	SERGEY BARANOV	{"email": "baranov.sergey-05051974@postgrespro.ru", "phone": "+70445679704"}
0005434136906	F4EFB1	5599 341195	INESSA GRISHINA	{"phone": "+70022430227"}
0005434136907	CDCD83	7204 200532	ANNA PETROVA	{"email": "petrovaa.1978@postgrespro.ru", "phone": "+70113424859"}
0005434136908	056565	1170 907590	VALENTIN ORLOV	{"phone": "+70743437071"}
0005434136909	056565	9320 342091	VLADISLAV ZAYCEV	{"email": "vladislavzaycev-101968@postgrespro.ru", "phone": "+70184527410"}
0005434136910	056565	5439 683295	LEONID DENISOV	{"email": "denisov.leonid.011974@postgrespro.ru", "phone": "+70589684247"}
0005434136911	61C2E0	4968 747638	GALINA TIMOFEEVA	{"phone": "+70785434041"}
0005434136912	61C2E0	5041 554061	DMITRIY SHEVCHENKO	{"email": "shevchenko-d_051971@postgrespro.ru", "phone": "+70779062882"}
0005434136913	EBFDFE	9041 543268	MARIYA POLYAKOVA	{"email": "polyakovam1963@postgrespro.ru", "phone": "+70997492304"}
0005434136914	EBFDFE	2938 322154	ALEKSEY KAZAKOV	{"phone": "+70177028877"}
0005434136915	337A3C	5644 031524	ALENA VOLKOVA	{"phone": "+70647804288"}
0005434136916	337A3C	4948 566906	MARIYA CHERNOVA	{"phone": "+70372400041"}
0005434136917	5BE18D	7793 440429	ALEKSANDR ALEKSANDROV	{"phone": "+70141484501"}
0005434136918	400C46	1513 960992	VLADIMIR DAVYDOV	{"email": "v.davydov.011955@postgrespro.ru", "phone": "+70394324543"}
0005434136919	49452E	9560 211952	LYUDMILA SOROKINA	{"email": "lyudmila-sorokina.14041971@postgrespro.ru", "phone": "+70419106730"}
0005434136920	7C097E	4772 943387	YULIYA YAKOVLEVA	{"phone": "+70475405864"}
0005434136921	3E71A3	2469 984298	VLADIMIR ZAKHAROV	{"email": "zakharovv.1959@postgrespro.ru", "phone": "+70073254660"}
0005434136922	3E71A3	0238 030114	YULIYA FEDOROVA	{"email": "y_fedorova-19061977@postgrespro.ru", "phone": "+70514304811"}
0005434136923	BCD8B6	4119 060834	VLADIMIR BARANOV	{"email": "vladimir-baranov_30011977@postgrespro.ru", "phone": "+70818744403"}
0005434136924	F8C930	9476 612029	RASIM SIDOROV	{"phone": "+70585261407"}
0005434136925	F8C930	1563 678399	SVETLANA SEMENOVA	{"email": "s_semenova_22081976@postgrespro.ru", "phone": "+70690028371"}
0005434136926	A9FCA9	4896 363575	ALEKSANDRA KOROLEVA	{"email": "akoroleva_081975@postgrespro.ru", "phone": "+70418787839"}
0005434136927	A9FCA9	4087 329289	EVGENIY ANDREEV	{"email": "andreev-e011958@postgrespro.ru", "phone": "+70527043862"}
0005434136928	EE1D30	9919 757592	VYACHESLAV ROMANOV	{"phone": "+70802523405"}
0005434136929	1AE869	1415 947316	ZOYA FROLOVA	{"email": "frolova.zoya-081974@postgrespro.ru", "phone": "+70618087802"}
0005434136930	1AE869	2148 513596	ALEKSANDR ANTONOV	{"phone": "+70265621410"}
0005434136931	A392FC	9904 254731	EVGENIY PETROV	{"phone": "+70526343734"}
0005434136932	D2F343	9355 653328	LYUDMILA MAKSIMOVA	{"email": "l.maksimova-011968@postgrespro.ru", "phone": "+70159135351"}
0005434136933	8A5D1F	9010 356844	ALEKSANDR POPOV	{"email": "popov-a.1976@postgrespro.ru", "phone": "+70106129383"}
0005434136934	8A5D1F	2811 942730	NELLYA VOLKOVA	{"phone": "+70471876466"}
0005434136935	B232F6	9708 718335	ALEKSANDR KAZAKOV	{"phone": "+70810241490"}
0005434136936	B232F6	8433 453576	ELENA NIKITINA	{"email": "nikitinae_111972@postgrespro.ru", "phone": "+70321206820"}
0005434136937	0D0474	1428 622483	DMITRIY AFANASEV	{"email": "afanasev-d-1968@postgrespro.ru", "phone": "+70265235790"}
0005434136938	612EC1	4617 444826	ALENA EFREMOVA	{"email": "efremova-a_18071964@postgrespro.ru", "phone": "+70459954910"}
0005434136939	5F0197	4093 764481	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_1974@postgrespro.ru", "phone": "+70421085786"}
0005434136940	59D8F5	0107 809485	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_011987@postgrespro.ru", "phone": "+70527931532"}
0005434136941	4BA874	1638 022843	ALEKSANDR ANDREEV	{"phone": "+70727115235"}
0005434136942	9A21F6	7266 979047	ALEKSEY EGOROV	{"email": "egorov_aleksey_1961@postgrespro.ru", "phone": "+70606838383"}
0005434136943	812CB1	0623 303668	SERGEY MATVEEV	{"email": "matveev-s011971@postgrespro.ru", "phone": "+70577597217"}
0005434136944	812CB1	4902 322094	ALEKSANDR YAKOVLEV	{"email": "yakovlev.aleksandr.021989@postgrespro.ru", "phone": "+70110608760"}
0005434136945	D67D8C	7212 173649	VALERIY ANTONOV	{"email": "v_antonov1968@postgrespro.ru", "phone": "+70694369978"}
0005434136946	E73680	5126 565300	MAKSIM NAZAROV	{"phone": "+70074636948"}
0005434136947	E73680	8940 131179	VALENTINA YUDINA	{"email": "valentinayudina16041964@postgrespro.ru", "phone": "+70199323177"}
0005434136948	4F6717	9219 896664	PETR PAVLOV	{"email": "pavlov_p_17091964@postgrespro.ru", "phone": "+70330801553"}
0005434136949	4F6717	6439 524800	SERGEY MOROZOV	{"email": "morozov_sergey061974@postgrespro.ru", "phone": "+70630070691"}
0005434136950	CD0D16	1910 835725	SERGEY PAVLOV	{"phone": "+70863184174"}
0005434136951	FFB18D	4127 110720	ALEKSEY SEMENOV	{"email": "semenovaleksey09061978@postgrespro.ru", "phone": "+70587112145"}
0005434136952	394DF3	4014 619869	ANATOLIY SIDOROV	{"email": "sidorova-1965@postgrespro.ru", "phone": "+70803729850"}
0005434136953	394DF3	2444 126980	ANATOLIY ZAYCEV	{"email": "zaycev_a-091971@postgrespro.ru", "phone": "+70719865364"}
0005434136954	0E1800	1905 692215	NATALYA CHERNOVA	{"email": "chernova-n_041975@postgrespro.ru", "phone": "+70451740132"}
0005434136955	BE8BCF	5999 110518	ANTON ANDREEV	{"phone": "+70437164423"}
0005434136956	6BE864	3401 814659	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr_07101964@postgrespro.ru", "phone": "+70921292151"}
0005434136957	5B77A5	8859 965162	ANTONINA ILINA	{"email": "ilina_antonina24101971@postgrespro.ru", "phone": "+70249580710"}
0005434136958	F48ECF	2824 063949	ALEKSANDR MATVEEV	{"phone": "+70421246451"}
0005434136959	9DD680	7755 487358	ANNA PAVLOVA	{"email": "pavlova-a-101966@postgrespro.ru", "phone": "+70400486238"}
0005434136960	9DD680	6931 596142	ELENA CHERNOVA	{"phone": "+70313554396"}
0005434136961	8891D6	7673 410024	SERGEY VOLKOV	{"phone": "+70632446356"}
0005434136962	8891D6	7537 160142	VLADISLAV MOISEEV	{"phone": "+70868099173"}
0005434136963	8891D6	2062 845307	ELENA ALEKSEEVA	{"email": "alekseeva-elena_1962@postgrespro.ru", "phone": "+70425899805"}
0005434136964	8891D6	1816 060854	ARTEM KUZNECOV	{"email": "a.kuznecov30061974@postgrespro.ru", "phone": "+70307117540"}
0005434136965	541601	7945 194731	ELENA BARANOVA	{"email": "elena_baranova.12111967@postgrespro.ru", "phone": "+70983240784"}
0005434136966	541601	9568 703479	ALEKSEY GAVRILOV	{"phone": "+70520410746"}
0005434136967	0A1E40	4728 578842	ANTONINA DAVYDOVA	{"email": "davydova_antonina051964@postgrespro.ru", "phone": "+70254208483"}
0005434136968	A97D7D	0992 376889	ALEKSANDR ROMANOV	{"phone": "+70331743516"}
0005434136969	AE2216	6084 854688	ALEKSEY SOROKIN	{"email": "sorokin.aleksey-01011968@postgrespro.ru", "phone": "+70496404894"}
0005434136970	AE2216	7880 050006	TATYANA PAVLOVA	{"phone": "+70475863147"}
0005434136971	8D2BD4	5609 324353	VLADIMIR SCHERBAKOV	{"phone": "+70682804697"}
0005434136972	8D2BD4	9518 780404	EVGENIY BELOV	{"phone": "+70542133560"}
0005434136973	43D5D1	7987 140150	VLADIMIR NIKOLAEV	{"phone": "+70215298641"}
0005434136974	C3CB4A	4974 209735	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr_1977@postgrespro.ru", "phone": "+70645838591"}
0005434136975	C3CB4A	9719 645346	EKATERINA ROMANOVA	{"email": "e.romanova.071967@postgrespro.ru", "phone": "+70013829476"}
0005434136976	5578AA	9513 157169	VALENTINA KISELEVA	{"email": "vkiseleva-1973@postgrespro.ru", "phone": "+70653816925"}
0005434136977	5578AA	3801 494940	ALEKSEY IVANOV	{"phone": "+70527445734"}
0005434136978	D1D2B9	2027 699492	NATALIYA MOROZOVA	{"phone": "+70253063538"}
0005434136979	D1D2B9	0599 229121	ANNA YAKOVLEVA	{"email": "a-yakovleva.1974@postgrespro.ru", "phone": "+70013812381"}
0005434136980	C25782	8691 767579	MIKHAIL MOROZOV	{"phone": "+70037150098"}
0005434136981	892DD8	6067 877096	MATVEY NOVIKOV	{"email": "novikovmatvey-051981@postgrespro.ru", "phone": "+70644434438"}
0005434136982	A24C58	5480 049157	DMITRIY SIDOROV	{"phone": "+70333400908"}
0005434136983	9C8B4C	7227 235016	TAMARA ROMANOVA	{"email": "tromanova.1975@postgrespro.ru", "phone": "+70598265430"}
0005434136984	9C8B4C	5311 906527	SVETLANA EGOROVA	{"email": "egorovasvetlana-1970@postgrespro.ru", "phone": "+70031325512"}
0005434136985	66EC89	5313 911903	NADIYA ORLOVA	{"phone": "+70027258608"}
0005434136986	66EC89	4420 189392	MARINA TIKHONOVA	{"email": "tikhonova.m-19081980@postgrespro.ru", "phone": "+70051589501"}
0005434136987	66EC89	1929 361072	OKSANA MARTYNOVA	{"email": "martynova-o_041971@postgrespro.ru", "phone": "+70064392037"}
0005434136988	E616E4	2719 331268	TATYANA POTAPOVA	{"email": "potapova.tatyana.1975@postgrespro.ru", "phone": "+70880251448"}
0005434136989	3CC770	0158 175200	MARINA SERGEEVA	{"email": "sergeeva.marina.011971@postgrespro.ru", "phone": "+70715310149"}
0005434136990	51D53E	9169 375806	ALEKSANDRA ZAYCEVA	{"email": "a-zayceva.051971@postgrespro.ru", "phone": "+70165353946"}
0005434136991	51D53E	9387 697087	AYRAT TARASOV	{"phone": "+70339341947"}
0005434136992	E68736	7797 143777	NADEZHDA KULIKOVA	{"phone": "+70643483832"}
0005434136993	E780A3	0692 177100	LEONID SERGEEV	{"phone": "+70824427677"}
0005434136994	3498A8	0901 562161	IRINA GUSEVA	{"phone": "+70416114049"}
0005434136995	3498A8	1877 144466	RAMIL VASILEV	{"email": "vasilev_r_1972@postgrespro.ru", "phone": "+70366948543"}
0005434136996	EE2223	0062 928699	SERGEY KUZNECOV	{"phone": "+70450995391"}
0005434136997	EE2223	3116 062274	EKATERINA PETROVA	{"phone": "+70104272459"}
0005434136998	D68A71	0383 188284	MARINA CHERNOVA	{"email": "mchernova.1961@postgrespro.ru", "phone": "+70004717481"}
0005434136999	278360	3105 006751	KIRILL IVANOV	{"email": "k_ivanov_1965@postgrespro.ru", "phone": "+70625364123"}
0005434137000	278360	2972 903157	ELIZAVETA ZOTOVA	{"phone": "+70482073700"}
0005434137001	278360	3556 400034	TATYANA DANILOVA	{"email": "tdanilova_021971@postgrespro.ru", "phone": "+70438349734"}
0005434137002	8C5A33	4000 143347	VALENTINA GERASIMOVA	{"email": "v_gerasimova_24101990@postgrespro.ru", "phone": "+70123413736"}
0005434137003	A3120D	8578 196058	ALEKSANDR FEDOTOV	{"phone": "+70843396207"}
0005434137004	A3120D	3774 825865	NATALYA EFREMOVA	{"email": "efremova.natalya051967@postgrespro.ru", "phone": "+70373540765"}
0005434137005	1AB4FD	4320 883424	NIKOLAY DMITRIEV	{"email": "dmitrievnikolay.101965@postgrespro.ru", "phone": "+70261853831"}
0005434137006	F9D0A3	7635 391604	GALINA TIKHONOVA	{"phone": "+70019987026"}
0005434137007	F9D0A3	7339 602580	VYACHESLAV MEDVEDEV	{"phone": "+70872503807"}
0005434137008	7E0F0D	8041 955328	NINA FEDOROVA	{"phone": "+70323913593"}
0005434137009	460CA1	9899 874504	NADEZHDA KOVALEVA	{"email": "n-kovaleva_071973@postgrespro.ru", "phone": "+70802509456"}
0005434137010	21EDBD	7824 981168	VALENTINA FILIPPOVA	{"phone": "+70583898383"}
0005434137011	21EDBD	5992 298936	DANIIL EGOROV	{"phone": "+70042310506"}
0005434137012	EC287C	7384 511601	VIKTOR GRIGOREV	{"phone": "+70052509634"}
0005434137013	256C31	7984 416337	RAFAEL PAVLOV	{"phone": "+70228135972"}
0005434137014	58ABE5	3848 105990	ALEKSANDR BARANOV	{"email": "baranov_a.04081986@postgrespro.ru", "phone": "+70885723180"}
0005434137015	1365CD	5326 837051	DENIS SOROKIN	{"email": "sorokind07011963@postgrespro.ru", "phone": "+70010881639"}
0005434137016	A4B558	5425 405970	SERGEY DENISOV	{"email": "s-denisov-1976@postgrespro.ru", "phone": "+70352356735"}
0005434137017	D619D9	0461 860978	LYUBOV BORISOVA	{"email": "borisova-lyubov.1970@postgrespro.ru", "phone": "+70226671156"}
0005434137018	18F81A	6345 176376	ARTEM MELNIKOV	{"email": "melnikov_artem.011966@postgrespro.ru", "phone": "+70221938422"}
0005434137019	6B6D4E	7700 495431	IVAN RODIONOV	{"phone": "+70446459906"}
0005434137020	6B6D4E	8663 468550	MARINA KUZNECOVA	{"email": "mkuznecova28091977@postgrespro.ru", "phone": "+70643326195"}
0005434137021	97238E	6648 121390	VIKTOR POPOV	{"email": "viktor_popov_1979@postgrespro.ru", "phone": "+70375544367"}
0005434137022	5920C2	4244 935483	NADEZHDA KUZNECOVA	{"email": "kuznecova_n.121973@postgrespro.ru", "phone": "+70353060731"}
0005434137023	34C133	2794 617880	TATYANA GRISHINA	{"phone": "+70646455442"}
0005434137024	9EF200	6771 678053	ALEKSANDR MIRONOV	{"phone": "+70654214323"}
0005434137025	E0E0A8	6783 435867	VARVARA IVANOVA	{"phone": "+70811795405"}
0005434137026	D4AA1B	1244 398937	OLEG CHERNOV	{"phone": "+70119759049"}
0005434137027	113023	5866 876501	YURIY ISAEV	{"email": "y_isaev07061980@postgrespro.ru", "phone": "+70191420884"}
0005434137028	113023	3630 883507	VIKTOR MAKAROV	{"email": "makarov-v081974@postgrespro.ru", "phone": "+70927496411"}
0005434137029	B2E301	8505 070366	KIRILL OSIPOV	{"email": "osipov-k.111980@postgrespro.ru", "phone": "+70569553191"}
0005434137030	44FE36	9647 192688	ELENA FILATOVA	{"email": "filatova-elena.1977@postgrespro.ru", "phone": "+70189752415"}
0005434137031	2AC9AF	4864 329919	YURIY ANTONOV	{"email": "antonov.y-15101973@postgrespro.ru", "phone": "+70513150908"}
0005434137032	1EB83E	1966 012357	LYUDMILA TROFIMOVA	{"email": "lyudmilatrofimova-08041970@postgrespro.ru", "phone": "+70975227361"}
0005434137033	B9B6CE	8781 627427	SERGEY SERGEEV	{"email": "sergeev-sergey21021980@postgrespro.ru", "phone": "+70143999819"}
0005434137034	88F00A	8503 274307	NATALYA AFANASEVA	{"phone": "+70077903117"}
0005434137035	88F00A	2009 095384	ILYA RODIONOV	{"phone": "+70375109679"}
0005434137036	70175B	6151 219613	NIKOLAY MAKAROV	{"phone": "+70523011006"}
0005434137037	F3E0B6	6300 583175	TATYANA ZAKHAROVA	{"email": "t.zakharova-011960@postgrespro.ru", "phone": "+70730259700"}
0005434137038	AA539A	6361 775936	NIKOLAY DMITRIEV	{"phone": "+70984332389"}
0005434137039	F4335D	5455 417244	VALERIYA YAKOVLEVA	{"phone": "+70019895720"}
0005434137040	F4335D	6206 629967	RISHAT ANDREEV	{"phone": "+70264479681"}
0005434137041	2B87B6	2006 722101	VYACHESLAV SEMENOV	{"phone": "+70082771731"}
0005434137042	2B87B6	3265 414015	IRINA FOMINA	{"email": "irinafomina1969@postgrespro.ru", "phone": "+70866646610"}
0005434137043	2B87B6	2205 330463	MARIYA FILATOVA	{"phone": "+70642873343"}
0005434137044	42F8F4	3605 261914	ROMAN SHEVCHENKO	{"phone": "+70914647122"}
0005434137045	84006F	3436 095843	YAN ALEKSEEV	{"phone": "+70862883337"}
0005434137046	84006F	9342 351768	ANASTASIYA MIKHAYLOVA	{"phone": "+70130649301"}
0005434137047	987DE6	9930 310920	VALERIY ZAYCEV	{"phone": "+70952835569"}
0005434137048	063B2B	3206 564023	ALEKSANDR TIMOFEEV	{"email": "timofeev.a_24041973@postgrespro.ru", "phone": "+70227562400"}
0005434137049	063B2B	6688 415054	EKATERINA ABRAMOVA	{"phone": "+70600090660"}
0005434137050	602DD3	6847 886638	ILYA SMIRNOV	{"phone": "+70213006718"}
0005434137051	F05AD8	3932 714475	NAIL SMIRNOV	{"phone": "+70808749293"}
0005434137052	B53AAB	7777 696402	VLADIMIR SEMENOV	{"email": "v.semenov1974@postgrespro.ru", "phone": "+70023471114"}
0005434137053	984C16	0291 526881	EKATERINA POPOVA	{"phone": "+70572058305"}
0005434137054	A013AF	3171 537948	ALLA LOGINOVA	{"email": "a-loginova-21041970@postgrespro.ru", "phone": "+70836294176"}
0005434137055	DC869E	8833 624000	GALINA ZAKHAROVA	{"email": "galina_zakharova.03101970@postgrespro.ru", "phone": "+70234142478"}
0005434137056	1652B0	8483 630766	BORIS KRASNOV	{"phone": "+70254166288"}
0005434137057	0DC97D	4440 237183	IRINA EGOROVA	{"email": "egorovai20011967@postgrespro.ru", "phone": "+70388312522"}
0005434137058	18D6E2	7809 003797	VERA NIKITINA	{"email": "v-nikitina.25041968@postgrespro.ru", "phone": "+70699233697"}
0005434137059	F0E3A0	6927 843650	ALEKSANDR BELOV	{"email": "a-belov1967@postgrespro.ru", "phone": "+70774406242"}
0005434137060	47C8D1	7187 521840	ALENA KOZLOVA	{"email": "kozlovaa-101978@postgrespro.ru", "phone": "+70748462800"}
0005434137061	47C8D1	5265 609997	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr_1971@postgrespro.ru", "phone": "+70316340912"}
0005434137062	3556E4	8216 449796	YURIY MAKSIMOV	{"phone": "+70592007784"}
0005434137063	3556E4	0301 555731	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko-1966@postgrespro.ru", "phone": "+70684463104"}
0005434137064	7FE14B	3628 501018	IRINA SEMENOVA	{"phone": "+70743426129"}
0005434137065	852DB4	7025 937152	EKATERINA SIDOROVA	{"email": "sidorova_e.1984@postgrespro.ru", "phone": "+70120253199"}
0005434137066	852DB4	9665 914153	VIKTOR KRASNOV	{"phone": "+70116688105"}
0005434137067	60635E	4239 568678	KIRILL KUZNECOV	{"phone": "+70011593346"}
0005434137068	60635E	9469 022822	NADEZHDA AKIMOVA	{"phone": "+70848673464"}
0005434137069	13BA7C	2583 805997	IGOR MIKHAYLOV	{"phone": "+70834287466"}
0005434137070	13BA7C	4083 983648	ANDREY GAVRILOV	{"phone": "+70556103359"}
0005434137071	64E7BA	7354 491206	ELENA VASILEVA	{"phone": "+70547604008"}
0005434137072	4D2871	7515 698994	ALEKSANDR ILIN	{"phone": "+70447908039"}
0005434137073	2C7D00	5763 369434	ALEKSEY IVANOV	{"phone": "+70962740084"}
0005434137074	972AE5	7390 294251	NIKITA IVANOV	{"email": "ivanov_nikita_1961@postgrespro.ru", "phone": "+70557498178"}
0005434137075	972AE5	8866 767878	LIDIYA YAKOVLEVA	{"email": "l.yakovleva.1982@postgrespro.ru", "phone": "+70054138850"}
0005434137076	B503DB	2035 380664	KRISTINA PETROVA	{"email": "k.petrova_13081970@postgrespro.ru", "phone": "+70138789795"}
0005434137077	B503DB	8715 055412	BORIS RODIONOV	{"email": "rodionov.b-1979@postgrespro.ru", "phone": "+70929880001"}
0005434137078	4B75A9	8790 580935	OLGA TROFIMOVA	{"phone": "+70379832979"}
0005434137079	BA4D69	1379 696920	TIMUR BARANOV	{"email": "baranov_timur_15021977@postgrespro.ru", "phone": "+70186433045"}
0005434137080	BA4D69	2728 722833	OLGA KAZAKOVA	{"phone": "+70252966860"}
0005434137081	BA4D69	1825 477422	ALENA NIKITINA	{"email": "nikitina-alena1971@postgrespro.ru", "phone": "+70484322550"}
0005434137082	AECE37	4793 798740	DMITRIY SEMENOV	{"phone": "+70661809698"}
0005434137083	B0D8C9	5896 557695	MIKHAIL DENISOV	{"email": "denisov_mikhail-1982@postgrespro.ru", "phone": "+70875844922"}
0005434137084	B0D8C9	2121 303176	GEORGIY NOVIKOV	{"phone": "+70128413924"}
0005434137085	B0D8C9	7172 692845	VALERIY VASILEV	{"email": "valeriy-vasilev051967@postgrespro.ru", "phone": "+70108153107"}
0005434137086	189262	5274 644211	ANDREY NAZAROV	{"email": "nazarova071963@postgrespro.ru", "phone": "+70090898877"}
0005434137087	189262	0952 489738	YURIY GUSEV	{"email": "gusevy-1959@postgrespro.ru", "phone": "+70775981245"}
0005434137088	9047C9	5283 787120	ALEKSANDR DENISOV	{"phone": "+70259890003"}
0005434137089	658C18	7479 288716	DARYA ZAKHAROVA	{"phone": "+70350979640"}
0005434137090	658C18	3156 532741	LILIYA SIDOROVA	{"email": "lsidorova071972@postgrespro.ru", "phone": "+70476234694"}
0005434137091	658C18	1062 910356	VALERIY KUZNECOV	{"phone": "+70421208737"}
0005434137092	F5FA0E	6172 248128	SVETLANA SIDOROVA	{"email": "sidorova-svetlana.071973@postgrespro.ru", "phone": "+70067277873"}
0005434137093	FD7061	6459 746868	NADEZHDA DAVYDOVA	{"phone": "+70952908817"}
0005434137094	4E58E0	3452 643307	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov22121969@postgrespro.ru", "phone": "+70166544294"}
0005434137095	4E58E0	1622 878645	BORIS MAKAROV	{"email": "makarov.b.31081974@postgrespro.ru", "phone": "+70230565209"}
0005434137096	638B32	1434 268254	ANATOLIY DENISOV	{"email": "a_denisov.031962@postgrespro.ru", "phone": "+70182955537"}
0005434137097	638B32	5324 669290	ALEKSANDR STEPANOV	{"phone": "+70860751677"}
0005434137098	5B3EA5	2029 379037	OLEG MARTYNOV	{"phone": "+70087670622"}
0005434137099	BC4CB6	3652 495744	IRINA ROMANOVA	{"phone": "+70782813895"}
0005434137100	1FB11A	8403 219722	NADEZHDA BOGDANOVA	{"email": "nadezhda.bogdanova.1974@postgrespro.ru", "phone": "+70319725991"}
0005434137101	978112	8255 768776	ANATOLIY FROLOV	{"email": "frolov.a.28091989@postgrespro.ru", "phone": "+70768556878"}
0005434137102	608A13	0838 364529	LYUBOV POTAPOVA	{"phone": "+70526792158"}
0005434137103	36430F	7946 900676	VALENTINA TIKHONOVA	{"email": "tikhonova.valentina_1963@postgrespro.ru", "phone": "+70265872603"}
0005434137104	36430F	4889 912742	SVETLANA POLYAKOVA	{"email": "polyakova.svetlana05011974@postgrespro.ru", "phone": "+70800706781"}
0005434137105	B4C41B	0442 493919	OLGA FILIPPOVA	{"email": "o.filippova-1966@postgrespro.ru", "phone": "+70690878397"}
0005434137106	B4C41B	8048 562216	IVAN PETROV	{"email": "ivan-petrov-16041972@postgrespro.ru", "phone": "+70969205404"}
0005434137107	4CDDE5	8971 458881	YURIY KUZNECOV	{"email": "kuznecov_yuriy1958@postgrespro.ru", "phone": "+70278113266"}
0005434137108	5443A9	5949 499343	ANASTASIYA KUZMINA	{"phone": "+70347328967"}
0005434137109	D50160	3550 993717	OLEG ALEKSANDROV	{"phone": "+70182710336"}
0005434137110	D50160	1444 720677	ELIZAVETA STEPANOVA	{"phone": "+70034923622"}
0005434137111	A3F15A	0546 395652	IVAN NOVIKOV	{"email": "ivannovikov-1975@postgrespro.ru", "phone": "+70510214016"}
0005434137112	C73407	3903 437198	SVETLANA ISAEVA	{"email": "isaeva.svetlana_1972@postgrespro.ru", "phone": "+70284992427"}
0005434137113	6D47F9	3601 010653	LIDIYA FOMINA	{"phone": "+70958397167"}
0005434137114	99E250	7936 698411	ANDREY SIDOROV	{"email": "sidorov-andrey_1972@postgrespro.ru", "phone": "+70588945473"}
0005434137115	484F25	6356 484413	ALEKSANDR VOLKOV	{"phone": "+70084474640"}
0005434137116	749B87	2085 379151	OLGA MIKHAYLOVA	{"email": "omikhaylova_1970@postgrespro.ru", "phone": "+70865884330"}
0005434137117	EE828C	2423 866160	GENNADIY KOROLEV	{"email": "korolev.gennadiy061975@postgrespro.ru", "phone": "+70419409568"}
0005434137118	EE828C	8634 853559	ANNA DAVYDOVA	{"phone": "+70677382868"}
0005434137119	450223	1938 004816	PAVEL IVANOV	{"phone": "+70847960771"}
0005434137120	450223	1409 963413	SVETLANA IVANOVA	{"phone": "+70712623201"}
0005434137121	CC1425	5882 257265	ARTEM ANDREEV	{"email": "andreev.a-041966@postgrespro.ru", "phone": "+70411069344"}
0005434137122	C94174	9895 159674	ANDREY NIKOLAEV	{"email": "nikolaevandrey25041971@postgrespro.ru", "phone": "+70077251112"}
0005434137123	5854E8	2140 218014	EVGENIY ZHUKOV	{"phone": "+70629400963"}
0005434137124	03DED7	1609 910809	VLADIMIR YAKOVLEV	{"email": "yakovlev.v031973@postgrespro.ru", "phone": "+70041739728"}
0005434137125	EA0763	8242 761617	GALINA KUZNECOVA	{"phone": "+70864713194"}
0005434137126	EA0763	2800 564687	KIRILL SOROKIN	{"email": "sorokin_kirill.1963@postgrespro.ru", "phone": "+70141119627"}
0005434137127	ED7EBC	2582 338776	NIKITA FROLOV	{"phone": "+70372345293"}
0005434137128	ED7EBC	2396 863467	ALEKSEY ORLOV	{"phone": "+70256607795"}
0005434137129	934E52	2951 134171	VSEVOLOD SERGEEV	{"phone": "+70064763512"}
0005434137130	934E52	6362 294271	NADEZHDA KULIKOVA	{"phone": "+70038241473"}
0005434137131	596B3D	4097 659861	MARIYA SMIRNOVA	{"phone": "+70428539061"}
0005434137132	5BA0EF	9007 586836	VALENTIN YAKOVLEV	{"phone": "+70291738626"}
0005434137134	A758BF	7303 510707	ALEKSANDRA VASILEVA	{"email": "aleksandravasileva.23041958@postgrespro.ru", "phone": "+70106901592"}
0005434137135	A758BF	5594 806832	FEDOR MOISEEV	{"email": "fedor.moiseev.06071985@postgrespro.ru", "phone": "+70306725994"}
0005434137136	8E9AE4	2016 132721	VALERIY SIDOROV	{"email": "valeriysidorov_20061972@postgrespro.ru", "phone": "+70404852707"}
0005434137137	8E9AE4	2299 819996	ANNA SIDOROVA	{"phone": "+70268366947"}
0005434137138	A18F0F	8753 128600	MARIYA FEDOROVA	{"email": "m_fedorova_021970@postgrespro.ru", "phone": "+70606370392"}
0005434137139	A18F0F	9240 206628	VIKTORIYA MAKSIMOVA	{"phone": "+70997466572"}
0005434137140	9E2578	6235 111564	SVETLANA VLASOVA	{"email": "vlasovasvetlana21041966@postgrespro.ru", "phone": "+70756118156"}
0005434137141	D03AE8	2482 281643	YULIYA ZOTOVA	{"phone": "+70038841454"}
0005434137142	D87533	9500 236129	DMITRIY CHERNOV	{"email": "d.chernov_061976@postgrespro.ru", "phone": "+70120975229"}
0005434137143	D87533	7707 036825	YURIY GAVRILOV	{"phone": "+70663656500"}
0005434137144	5E892B	6321 571980	VADIM KAZAKOV	{"email": "vadimkazakov-091970@postgrespro.ru", "phone": "+70728192423"}
0005434137145	768C11	2811 849801	VLADIMIR KOROLEV	{"email": "vladimir_korolev.1978@postgrespro.ru", "phone": "+70023997712"}
0005434137146	AD63A0	1283 612092	DMITRIY KRASNOV	{"email": "dmitriykrasnov_071976@postgrespro.ru", "phone": "+70973630092"}
0005434137147	DFA1AE	6006 538505	EKATERINA BARANOVA	{"phone": "+70255117737"}
0005434137148	6C8BA3	5556 047927	VLADIMIR DAVYDOV	{"phone": "+70427507213"}
0005434137149	6C8BA3	3670 311921	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr-1974@postgrespro.ru", "phone": "+70685567621"}
0005434137150	979CE3	1200 099878	ALEKSANDR MOISEEV	{"phone": "+70223843783"}
0005434137151	CC8DDA	5996 016283	DANIL ROMANOV	{"email": "romanov.d.111973@postgrespro.ru", "phone": "+70269142821"}
0005434137152	BFC6EE	5300 097808	NIKITA MARTYNOV	{"phone": "+70235016288"}
0005434137153	39CB55	9470 793404	ALEKSEY YAKOVLEV	{"phone": "+70911932065"}
0005434137154	4DA8B5	7772 528509	VALERIYA EFIMOVA	{"email": "vefimova-02051977@postgrespro.ru", "phone": "+70063580536"}
0005434137155	201DEA	5583 748763	VALENTINA PAVLOVA	{"email": "v.pavlova-1969@postgrespro.ru", "phone": "+70325306947"}
0005434137156	59F98E	7441 655870	YULIYA LEBEDEVA	{"phone": "+70691511157"}
0005434137157	340D30	4156 517203	ARTEM VLASOV	{"email": "vlasov_a-22011966@postgrespro.ru", "phone": "+70516018641"}
0005434137158	340D30	7302 835186	LYUDMILA ZAYCEVA	{"email": "zayceva.lyudmila_1975@postgrespro.ru", "phone": "+70508570450"}
0005434137159	340D30	9647 280678	SVETLANA ILINA	{"phone": "+70921201128"}
0005434137160	B77F7B	0511 391254	ANASTASIYA MIRONOVA	{"email": "mironovaa-25011990@postgrespro.ru", "phone": "+70816863506"}
0005434137161	639B56	1878 371224	LYAYSAN DANILOVA	{"email": "lyaysan.danilova_31101971@postgrespro.ru", "phone": "+70091253934"}
0005434137162	639B56	2926 124838	TATYANA ZHUKOVA	{"email": "zhukova-t_31121970@postgrespro.ru", "phone": "+70980729514"}
0005434137163	AAAD97	0063 675874	ELENA MAKAROVA	{"email": "makarova.elena02021957@postgrespro.ru", "phone": "+70489893973"}
0005434137164	89353D	8589 707985	NINEL KOZLOVA	{"email": "kozlova_ninel.1973@postgrespro.ru", "phone": "+70419862078"}
0005434137165	C76681	6748 881640	SERGEY IVANOV	{"email": "ivanov_sergey_08031965@postgrespro.ru", "phone": "+70528882693"}
0005434137166	9F8759	6812 798908	VYACHESLAV IVANOV	{"email": "vyacheslavivanov_1967@postgrespro.ru", "phone": "+70681684727"}
0005434137167	A96402	1285 986854	LARISA SOLOVEVA	{"email": "soloveva_larisa.021986@postgrespro.ru", "phone": "+70317503226"}
0005434137168	BF0AA8	2337 956892	NATALYA ARKHIPOVA	{"phone": "+70275008701"}
0005434137169	BF0AA8	9042 970868	YURIY ALEKSEEV	{"phone": "+70651641405"}
0005434137170	E385D5	6026 185911	ALEKSANDRA ZHUKOVA	{"phone": "+70778163357"}
0005434137171	BAB0C0	6111 103461	NIKOLAY ZHUKOV	{"email": "zhukov-n.04111971@postgrespro.ru", "phone": "+70869252990"}
0005434137172	A143B5	9387 947943	ANNA STEPANOVA	{"email": "stepanovaa081969@postgrespro.ru", "phone": "+70676728180"}
0005434137173	A143B5	5811 354914	ARSENIY CHERNOV	{"phone": "+70476531419"}
0005434137174	E0D48C	5637 150453	VARVARA LOGINOVA	{"email": "loginovavarvara101976@postgrespro.ru", "phone": "+70751932717"}
0005434137175	E0D48C	3350 772415	EKATERINA FROLOVA	{"phone": "+70224098753"}
0005434137176	9CDF15	0258 999778	YULIYA SOKOLOVA	{"email": "sokolovay-22031972@postgrespro.ru", "phone": "+70664801455"}
0005434137177	97FF5A	9532 837822	SERGEY TIMOFEEV	{"phone": "+70516922356"}
0005434137178	97FF5A	0803 137150	RISHAT ZAKHAROV	{"email": "zakharovr.12081964@postgrespro.ru", "phone": "+70038280537"}
0005434137179	C0005C	2689 200333	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr.23091964@postgrespro.ru", "phone": "+70464244441"}
0005434137180	B4B78A	7758 527193	ALEKSEY KUZNECOV	{"email": "alekseykuznecov_09021965@postgrespro.ru", "phone": "+70447480069"}
0005434137181	A9D15B	7249 608428	STANISLAV ZAYCEV	{"email": "zaycev_s19061984@postgrespro.ru", "phone": "+70333648133"}
0005434137182	A9D15B	5703 058302	NATALYA LOGINOVA	{"email": "n.loginova.1974@postgrespro.ru", "phone": "+70175721245"}
0005434137183	7DDC74	8412 555010	LILIYA OSIPOVA	{"email": "liliyaosipova-101966@postgrespro.ru", "phone": "+70834563601"}
0005434137184	372003	6378 185386	VLADIMIR SCHERBAKOV	{"phone": "+70619459901"}
0005434137185	8CC706	1365 265002	BOGDAN KRASNOV	{"phone": "+70805121392"}
0005434137186	EC8E24	3159 548785	NIKOLAY IVANOV	{"email": "nikolay-ivanov.06111970@postgrespro.ru", "phone": "+70276581157"}
0005434137187	10F986	7941 625668	TATYANA KOZLOVA	{"phone": "+70936489816"}
0005434137188	72B38D	0291 408588	OKSANA BORISOVA	{"phone": "+70559286772"}
0005434137189	1B37D4	4368 103559	EKATERINA KULIKOVA	{"phone": "+70853444488"}
0005434137190	A4EE38	1273 702460	ALEKSANDRA ANTONOVA	{"email": "aleksandra-antonova-091963@postgrespro.ru", "phone": "+70010630841"}
0005434137191	8D683A	6006 782738	ALEKSANDR GORBUNOV	{"phone": "+70542099249"}
0005434137192	8D683A	1844 802899	IVAN POPOV	{"email": "popov-ivan-081976@postgrespro.ru", "phone": "+70307974469"}
0005434137193	AE76A9	0822 330308	SERGEY SHEVCHENKO	{"email": "sergeyshevchenko_1964@postgrespro.ru", "phone": "+70047245587"}
0005434137194	285D64	2812 473284	NADEZHDA DAVYDOVA	{"email": "n.davydova031972@postgrespro.ru", "phone": "+70287260262"}
0005434137195	D72B27	6220 167913	ALEKSEY POPOV	{"email": "a_popov_081971@postgrespro.ru", "phone": "+70087467876"}
0005434137196	D72B27	0772 313009	ANISA SOKOLOVA	{"email": "sokolova_a.07061968@postgrespro.ru", "phone": "+70782815034"}
0005434137197	D72B27	1278 250976	ELENA KUZNECOVA	{"phone": "+70175426946"}
0005434137198	D72B27	5160 072675	ALISA BARANOVA	{"email": "baranova.alisa.12121972@postgrespro.ru", "phone": "+70015659488"}
0005434137199	4958C4	7997 092243	GENNADIY KUZNECOV	{"phone": "+70662407692"}
0005434137200	E5984E	7761 520785	SERGEY SIDOROV	{"email": "sidorov_sergey_1971@postgrespro.ru", "phone": "+70134755577"}
0005434137201	5EFF34	8056 576545	EKATERINA NIKOLAEVA	{"email": "ekaterina-nikolaeva_111967@postgrespro.ru", "phone": "+70637305896"}
0005434137202	48EB6C	7147 178749	VALERIYA LAZAREVA	{"phone": "+70658933299"}
0005434137203	FF9A9C	4317 786837	OLGA POPOVA	{"phone": "+70973230345"}
0005434137204	06B0AF	6500 145130	NATALYA GERASIMOVA	{"phone": "+70851098225"}
0005434137205	06B0AF	1559 590760	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.01121978@postgrespro.ru", "phone": "+70726132197"}
0005434137206	D7E3BF	0570 633672	RAUF KUZNECOV	{"phone": "+70315363986"}
0005434137207	FE9B28	9566 959045	AIDA FEDOROVA	{"email": "fedorova-aida.1972@postgrespro.ru", "phone": "+70137113077"}
0005434137208	226476	6517 872695	NATALYA VASILEVA	{"phone": "+70158524781"}
0005434137209	1FF8FB	3046 125474	IRINA NIKOLAEVA	{"email": "nikolaevairina1965@postgrespro.ru", "phone": "+70700118765"}
0005434137210	1FF8FB	4570 301171	ANTON STEPANOV	{"email": "stepanov_anton_101974@postgrespro.ru", "phone": "+70433905275"}
0005434137211	535F2A	3841 236865	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova-a-121980@postgrespro.ru", "phone": "+70217221283"}
0005434137212	3156FF	3107 975446	VYACHESLAV POPOV	{"phone": "+70517347307"}
0005434137213	3156FF	9646 015475	IOSIF NIKOLAEV	{"email": "iosif.nikolaev.1975@postgrespro.ru", "phone": "+70292631306"}
0005434137214	3156FF	8625 649201	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr-14071971@postgrespro.ru", "phone": "+70918212311"}
0005434137215	BAE4F3	8396 925033	KRISTINA CHERNOVA	{"phone": "+70964321991"}
0005434137216	BAE4F3	7696 966576	NATALYA ORLOVA	{"email": "orlovan.051977@postgrespro.ru", "phone": "+70359228155"}
0005434137217	3A06BF	1672 085757	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov.16061967@postgrespro.ru", "phone": "+70501032993"}
0005434137218	730C53	4902 934883	ANASTASIYA NAZAROVA	{"email": "nazarova.anastasiya.1962@postgrespro.ru", "phone": "+70111797858"}
0005434137219	14BE16	5415 161880	LIDIYA ALEKSEEVA	{"phone": "+70179173964"}
0005434137220	20005C	1880 160598	NIKOLAY GAVRILOV	{"phone": "+70861486672"}
0005434137221	20005C	5356 544506	LILIYA YAKOVLEVA	{"email": "lyakovleva_02101970@postgrespro.ru", "phone": "+70532474119"}
0005434137222	46EC1B	3197 953441	DMITRIY MATVEEV	{"email": "matveevd.121958@postgrespro.ru", "phone": "+70267328101"}
0005434137223	3FEEB2	9015 461568	EKATERINA SERGEEVA	{"email": "sergeeva.ekaterina.1975@postgrespro.ru", "phone": "+70920196377"}
0005434137224	3FEEB2	9801 930812	GALIYA RODIONOVA	{"phone": "+70613005011"}
0005434137225	52B67F	7938 467025	ELENA ZHUKOVA	{"phone": "+70059711688"}
0005434137226	23A945	3821 254399	LYUBOV PAVLOVA	{"phone": "+70036492035"}
0005434137227	F922E2	6345 541773	RUMIYA ABRAMOVA	{"email": "rabramova-1972@postgrespro.ru", "phone": "+70566361823"}
0005434137228	AAF9E9	8784 720244	VADIM CHERNOV	{"email": "chernov.vadim.091973@postgrespro.ru", "phone": "+70245774648"}
0005434137229	AAF9E9	3682 279115	LYUDMILA FROLOVA	{"phone": "+70641171433"}
0005434137230	A5051C	1488 192194	FAIL VLASOV	{"phone": "+70393415691"}
0005434137231	A5051C	9170 551685	ANNA GRISHINA	{"email": "grishina-anna1970@postgrespro.ru", "phone": "+70972456713"}
0005434137232	97FA79	3298 696523	ZINAIDA KOLESNIKOVA	{"phone": "+70121030283"}
0005434137233	9B0FB3	7255 970117	GALINA VLASOVA	{"email": "vlasova-g-1973@postgrespro.ru", "phone": "+70922434872"}
0005434137234	622EC8	8529 104086	NADEZHDA IVANOVA	{"phone": "+70632298267"}
0005434137235	622EC8	0181 060265	OLEG KUZNECOV	{"email": "kuznecovoleg-111966@postgrespro.ru", "phone": "+70608054744"}
0005434137236	184373	4495 685078	IVAN VOLKOV	{"phone": "+70397788268"}
0005434137237	6FB78C	6562 337195	ALEKSANDRA GORBUNOVA	{"email": "gorbunova.a011984@postgrespro.ru", "phone": "+70832876323"}
0005434137238	96E491	8469 838637	VIKTOR KUZNECOV	{"phone": "+70949254199"}
0005434137239	96E491	2422 768356	MADINA POPOVA	{"email": "popovamadina_02121979@postgrespro.ru", "phone": "+70324343187"}
0005434137240	96E491	4098 885132	MARAT SOROKIN	{"email": "sorokin_marat_031966@postgrespro.ru", "phone": "+70899182609"}
0005434137241	E392F2	2032 059216	SERGEY SEMENOV	{"email": "sergey_semenov1983@postgrespro.ru", "phone": "+70811463527"}
0005434137242	E392F2	1318 944268	YURIY GAVRILOV	{"email": "gavrilov_yuriy07101960@postgrespro.ru", "phone": "+70518797987"}
0005434137243	782509	0462 126504	TATYANA KUDRYASHOVA	{"phone": "+70398733269"}
0005434137244	782509	6148 451843	YURIY SHEVCHENKO	{"email": "y_shevchenko121988@postgrespro.ru", "phone": "+70200785535"}
0005434137245	782509	2234 023678	OLGA VLASOVA	{"email": "olga_vlasova111979@postgrespro.ru", "phone": "+70686444522"}
0005434137246	6D1501	9171 489222	ALEKSEY VASILEV	{"email": "vasilev_aleksey_29111955@postgrespro.ru", "phone": "+70879290007"}
0005434137247	6D1501	3617 340198	NIKOLAY VOLKOV	{"email": "nikolay.volkov-10021971@postgrespro.ru", "phone": "+70113562283"}
0005434137248	632E3B	9633 218493	VERONIKA KALININA	{"email": "kalininaveronika.111966@postgrespro.ru", "phone": "+70309521495"}
0005434137249	632E3B	8418 741662	ALEKSANDR CHERNOV	{"email": "aleksandr.chernov.1968@postgrespro.ru", "phone": "+70370683589"}
0005434137250	3BE862	4009 456069	IRINA ILINA	{"email": "irina.ilina_17021969@postgrespro.ru", "phone": "+70499789780"}
0005434137251	0E00C5	4129 251405	VALERIY TIKHONOV	{"email": "vtikhonov-16061971@postgrespro.ru", "phone": "+70407464665"}
0005434137252	0E00C5	5497 925420	ALEKSEY NIKOLAEV	{"email": "nikolaeva_1978@postgrespro.ru", "phone": "+70995588034"}
0005434137253	1D4A31	7169 425225	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev_23051976@postgrespro.ru", "phone": "+70237982764"}
0005434137254	1D4A31	6701 160681	VIKTOR ZHUKOV	{"email": "v-zhukov.1953@postgrespro.ru", "phone": "+70614958270"}
0005434137255	6E1BE0	0548 355311	NATALYA SCHERBAKOVA	{"email": "n_scherbakova1969@postgrespro.ru", "phone": "+70630197265"}
0005434137256	6E1BE0	3447 823783	GALINA ZAKHAROVA	{"phone": "+70152533507"}
0005434137257	872A30	3160 030349	NATALYA NIKIFOROVA	{"email": "n.nikiforova.25041984@postgrespro.ru", "phone": "+70638633243"}
0005434137258	8D6D3D	4189 281562	OLEG KARPOV	{"email": "o-karpov-1977@postgrespro.ru", "phone": "+70231104840"}
0005434137259	7AB47B	0586 931629	NIKOLAY SAVELEV	{"phone": "+70612894608"}
0005434137260	27E83D	5424 604646	VALERIY VLASOV	{"email": "valeriy.vlasov_28051979@postgrespro.ru", "phone": "+70015003853"}
0005434137261	DD5E7B	2876 398973	ALEKSEY POPOV	{"phone": "+70811198686"}
0005434137262	FC4415	4504 371434	LYUDMILA KUZNECOVA	{"email": "kuznecovalyudmila1983@postgrespro.ru", "phone": "+70382526085"}
0005434137263	1599BC	0589 518958	ALEKSANDR SEMENOV	{"phone": "+70956002828"}
0005434137264	9DA1E0	2801 698331	ILYA ANDREEV	{"phone": "+70752564377"}
0005434137265	BD44E2	8555 383516	ELIZAVETA FROLOVA	{"phone": "+70393048115"}
0005434137266	BD44E2	6934 078184	LYUBOV NESTEROVA	{"email": "nesterova_l-031971@postgrespro.ru", "phone": "+70774111776"}
0005434137267	4D0E16	3688 597828	NIKOLAY AFANASEV	{"email": "afanasev-n121969@postgrespro.ru", "phone": "+70581861423"}
0005434137268	B2F833	3084 460242	VALENTIN POPOV	{"phone": "+70768869173"}
0005434137269	B2F833	3491 003791	ALENA ROMANOVA	{"email": "romanova-a-1984@postgrespro.ru", "phone": "+70781021788"}
0005434137270	A7C526	5888 870305	IRINA DAVYDOVA	{"phone": "+70972482467"}
0005434137271	09EA18	1888 229499	NADEZHDA VASILEVA	{"phone": "+70969039133"}
0005434137272	09EA18	2900 072462	IRINA PAVLOVA	{"phone": "+70412085941"}
0005434137273	31A5FF	8110 194210	ALINA FOMINA	{"phone": "+70753121810"}
0005434137274	17704E	3169 485705	KAPITALINA GRISHINA	{"phone": "+70250213684"}
0005434137275	A75DA3	7925 811168	PAVEL VOLKOV	{"phone": "+70125802387"}
0005434137276	D28879	8349 047041	PRASKOVYA DMITRIEVA	{"phone": "+70031344769"}
0005434137277	D28879	5347 078089	ANDREY ZHUKOV	{"email": "andrey_zhukov_09061975@postgrespro.ru", "phone": "+70778273501"}
0005434137278	D28879	5140 413350	VLADIMIR AFANASEV	{"email": "afanasevvladimir_011970@postgrespro.ru", "phone": "+70156056189"}
0005434137279	C28FEF	5278 044515	IRINA ILINA	{"email": "ilina_i_111970@postgrespro.ru", "phone": "+70302091558"}
0005434137280	F59DB5	1875 593803	ELENA VOLKOVA	{"phone": "+70954269068"}
0005434137281	F4C2E5	1128 604430	KRISTINA MAKSIMOVA	{"email": "kristinamaksimova_041958@postgrespro.ru", "phone": "+70127066161"}
0005434137282	F4C2E5	9543 789308	MATVEY FILIPPOV	{"email": "filippov-m-1977@postgrespro.ru", "phone": "+70447510676"}
0005434137283	F4C2E5	4012 255648	ALEKSEY KUZMIN	{"email": "kuzminaleksey-041970@postgrespro.ru", "phone": "+70148526897"}
0005434137284	D8DFD3	8112 612946	KSENIYA MASLOVA	{"phone": "+70656206999"}
0005434137285	09C829	8131 191288	LYUDMILA ALEKSANDROVA	{"phone": "+70480652146"}
0005434137286	09C829	4079 464231	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov.1968@postgrespro.ru", "phone": "+70096914799"}
0005434137287	23D6B2	2548 140936	ALEKSANDR POPOV	{"email": "popovaleksandr1974@postgrespro.ru", "phone": "+70984072459"}
0005434137288	E60D28	4340 150166	NINA MOROZOVA	{"phone": "+70745693797"}
0005434137289	213907	4092 353942	ANDREY ZHUKOV	{"phone": "+70776796412"}
0005434137290	3CE906	1116 030566	MARIYA DAVYDOVA	{"email": "davydova-mariya1970@postgrespro.ru", "phone": "+70990898769"}
0005434137291	5C5292	4416 746599	IVAN IVANOV	{"phone": "+70939234273"}
0005434137292	88122F	2184 792590	TATYANA VASILEVA	{"email": "vasilevat-07111976@postgrespro.ru", "phone": "+70772822380"}
0005434137293	88122F	6518 900211	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy-16081969@postgrespro.ru", "phone": "+70006052338"}
0005434137294	550FEA	8604 192234	MARIYA ZAYCEVA	{"email": "m_zayceva25071966@postgrespro.ru", "phone": "+70973716441"}
0005434137295	550FEA	2540 934032	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova_nadezhda1965@postgrespro.ru", "phone": "+70284404364"}
0005434137296	38E5A8	6446 686117	OLGA ISAEVA	{"email": "o_isaeva.1970@postgrespro.ru", "phone": "+70828235855"}
0005434137297	38E5A8	2924 741444	VLADIMIR KAZAKOV	{"email": "kazakov_vladimir.101968@postgrespro.ru", "phone": "+70400138272"}
0005434137298	11AC0B	2412 353710	YURIY NOVIKOV	{"phone": "+70331297802"}
0005434137299	11AC0B	9623 179152	ALEKSEY PETROV	{"email": "a-petrov091977@postgrespro.ru", "phone": "+70218348237"}
0005434137300	F5EB7E	6778 414032	NADEZHDA KUZNECOVA	{"email": "nadezhda.kuznecova.1968@postgrespro.ru", "phone": "+70896562297"}
0005434137301	C54293	6805 219056	ELENA ZAKHAROVA	{"email": "zakharova.e.28061965@postgrespro.ru", "phone": "+70251251578"}
0005434137302	BC0D2A	8909 245778	MIKHAIL GRIGOREV	{"phone": "+70563405894"}
0005434137303	BC0D2A	4195 920715	DMITRIY SIDOROV	{"email": "sidorovd041961@postgrespro.ru", "phone": "+70079826783"}
0005434137304	2A9FEA	3798 785266	PETR KUZNECOV	{"email": "kuznecov_petr.081965@postgrespro.ru", "phone": "+70557709714"}
0005434137305	4E3CAF	5764 944665	KLARA SOROKINA	{"phone": "+70520916327"}
0005434137306	4E3CAF	4238 010719	EKATERINA ISAEVA	{"phone": "+70072499389"}
0005434137307	4E3CAF	5859 970428	EVGENIY ZHUKOV	{"email": "zhukov_evgeniy-1963@postgrespro.ru", "phone": "+70261183994"}
0005434137308	F67004	8276 279906	VERA SIDOROVA	{"phone": "+70949160175"}
0005434137309	6F2F17	7529 042193	EVGENIY MIRONOV	{"phone": "+70457188383"}
0005434137310	018AC9	2568 751315	NINA ISAEVA	{"phone": "+70550174276"}
0005434137311	453390	2598 297708	GENNADIY TIKHONOV	{"phone": "+70471577761"}
0005434137312	2DE003	6406 904663	IGOR KUZNECOV	{"phone": "+70157781465"}
0005434137313	C8135B	5683 414582	ANASTASIYA NIKOLAEVA	{"phone": "+70236559807"}
0005434137314	6255B8	0988 232034	ALEKSANDR EGOROV	{"phone": "+70792135530"}
0005434137315	6255B8	0777 799620	ANASTASIYA BOGDANOVA	{"phone": "+70970591545"}
0005434137316	2681EE	2118 046234	TATYANA SOKOLOVA	{"phone": "+70713994486"}
0005434137317	2681EE	4595 861264	MATVEY KONOVALOV	{"email": "matveykonovalov.011961@postgrespro.ru", "phone": "+70440837937"}
0005434137318	21E71F	4650 725123	OKSANA DAVYDOVA	{"email": "davydova.o.1969@postgrespro.ru", "phone": "+70125463388"}
0005434137319	21E71F	8770 199485	ZOYA KOZLOVA	{"email": "kozlovazoya.1970@postgrespro.ru", "phone": "+70735439863"}
0005434137320	381BAA	4417 990216	TAMARA MAKAROVA	{"email": "tamaramakarova.1966@postgrespro.ru", "phone": "+70524110020"}
0005434137321	29B35F	8112 156317	IRINA ZHUKOVA	{"phone": "+70273968999"}
0005434137322	29B35F	4086 150934	LYUDMILA ANDREEVA	{"email": "andreeva-l_041984@postgrespro.ru", "phone": "+70117406841"}
0005434137323	18A9E2	4812 893607	TAMARA EGOROVA	{"email": "tamara_egorova-22121975@postgrespro.ru", "phone": "+70627621790"}
0005434137324	18A9E2	9597 647911	NIKITA BORISOV	{"phone": "+70972328859"}
0005434137325	1ED24E	1114 721313	ALENA EGOROVA	{"phone": "+70896151193"}
0005434137326	052BB4	5553 761335	ELENA EFIMOVA	{"phone": "+70831128632"}
0005434137327	052BB4	6621 463329	DANILA YAKOVLEV	{"phone": "+70500572732"}
0005434137328	66B106	9390 966251	MARIYA AFANASEVA	{"email": "mariyaafanaseva-061968@postgrespro.ru", "phone": "+70854798161"}
0005434137329	66B106	1417 316703	ALBERT POPOV	{"email": "popov-albert.101958@postgrespro.ru", "phone": "+70463045867"}
0005434137330	1EF406	6302 715518	ELIZAVETA TIMOFEEVA	{"email": "elizaveta-timofeeva01051967@postgrespro.ru", "phone": "+70770267770"}
0005434137331	D946DC	9962 061618	MARAT YAKOVLEV	{"phone": "+70244542617"}
0005434137332	D946DC	5743 252970	NATALYA SEMENOVA	{"phone": "+70229474323"}
0005434137333	235C87	6669 363907	EVGENIYA EFIMOVA	{"phone": "+70643972836"}
0005434137334	D80113	6419 469489	ANZHELIKA MARTYNOVA	{"email": "martynova-a-20121957@postgrespro.ru", "phone": "+70472887710"}
0005434137335	D80113	3228 430039	ALEVTINA EFIMOVA	{"phone": "+70023575868"}
0005434137336	B576E6	5616 752703	ARTUR DENISOV	{"phone": "+70701915208"}
0005434137337	3D4065	3942 573705	ANATOLIY KUZMIN	{"phone": "+70879347889"}
0005434137338	3D4065	4924 756222	MARINA KUDRYASHOVA	{"email": "kudryashova_marina-1970@postgrespro.ru", "phone": "+70433541925"}
0005434137339	71C09F	9989 355410	IRINA ALEKSEEVA	{"email": "alekseevai071980@postgrespro.ru", "phone": "+70661849818"}
0005434137340	71C09F	3671 170290	MARINA ABRAMOVA	{"phone": "+70011113277"}
0005434137341	71C09F	4727 732580	RUMIYA NIKOLAEVA	{"email": "r_nikolaeva.051966@postgrespro.ru", "phone": "+70124591878"}
0005434137342	2FD3AB	9002 210158	OLGA ARKHIPOVA	{"phone": "+70958367951"}
0005434137343	2FD3AB	7897 511582	MARIYA GUSEVA	{"email": "guseva-mariya_061974@postgrespro.ru", "phone": "+70249423105"}
0005434137344	C77F9F	8139 897273	ALESYA FILIPPOVA	{"email": "a_filippova-10111961@postgrespro.ru", "phone": "+70762446364"}
0005434137345	34523A	1465 487899	EDUARD KOZLOV	{"email": "kozloveduard.121974@postgrespro.ru", "phone": "+70941495744"}
0005434137346	1952C8	8232 915994	RAFAEL SEMENOV	{"email": "r-semenov.06061960@postgrespro.ru", "phone": "+70808066052"}
0005434137347	4F9F90	9133 356709	OLGA GORBUNOVA	{"email": "olgagorbunova.1961@postgrespro.ru", "phone": "+70479951276"}
0005434137348	9B4E65	7588 505127	ALEKSANDR VASILEV	{"email": "a.vasilev-25121975@postgrespro.ru", "phone": "+70697503945"}
0005434137349	7B3850	0419 146129	VLADIMIR KUZMIN	{"phone": "+70907148967"}
0005434137350	7B3850	4940 190138	MARIYA MELNIKOVA	{"email": "melnikova.mariya_22041967@postgrespro.ru", "phone": "+70344787228"}
0005434137351	FD9109	8489 966352	VIKTOR FROLOV	{"email": "v.frolov_031985@postgrespro.ru", "phone": "+70058685808"}
0005434137352	7B8C90	3891 478612	OLGA PETROVA	{"email": "petrovaolga-1958@postgrespro.ru", "phone": "+70981800526"}
0005434137353	D318A2	1954 052829	IGOR ILIN	{"email": "ilin.igor.1969@postgrespro.ru", "phone": "+70203825487"}
0005434137354	D318A2	7849 779196	IRINA SOKOLOVA	{"phone": "+70396377052"}
0005434137355	953947	1266 733900	NIKOLAY EGOROV	{"email": "negorov.111952@postgrespro.ru", "phone": "+70402329892"}
0005434137356	953947	9657 422361	OKSANA MATVEEVA	{"phone": "+70817195937"}
0005434137357	FE39A6	8366 799937	ALEKSEY MIRONOV	{"phone": "+70225590874"}
0005434137358	370063	8702 382987	VALENTINA KUZNECOVA	{"phone": "+70892741721"}
0005434137359	2E1516	4192 487728	SVETLANA BORISOVA	{"phone": "+70525280627"}
0005434137360	1501FB	3699 356694	ANASTASIYA NIKOLAEVA	{"email": "nikolaevaanastasiya_061963@postgrespro.ru", "phone": "+70526449711"}
0005434137361	EBBEAD	7859 375902	NINA AFANASEVA	{"email": "n-afanaseva-011980@postgrespro.ru", "phone": "+70161280685"}
0005434137362	B33569	4965 657638	NINA PAVLOVA	{"phone": "+70289948556"}
0005434137363	B33569	2443 140882	MARIYA GERASIMOVA	{"phone": "+70101860228"}
0005434137364	520DE2	5811 982339	MAKSIM KUZMIN	{"phone": "+70618423053"}
0005434137365	520DE2	3889 120656	VENIAMIN ANDREEV	{"phone": "+70765291077"}
0005434137366	520DE2	7148 898835	TATYANA CHERNOVA	{"email": "chernova-t-1973@postgrespro.ru", "phone": "+70241855071"}
0005434137367	A64E14	9159 428348	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila_021965@postgrespro.ru", "phone": "+70693475624"}
0005434137368	524667	7209 095538	MARINA TITOVA	{"phone": "+70804529555"}
0005434137369	524667	3863 406943	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr_011968@postgrespro.ru", "phone": "+70299097273"}
0005434137370	524667	5068 844543	DMITRIY ANTONOV	{"email": "dantonov_081969@postgrespro.ru", "phone": "+70433570965"}
0005434137371	AFFBC2	1604 483627	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr_21031980@postgrespro.ru", "phone": "+70211735978"}
0005434137372	0DDA14	7506 737916	VIKTOR DMITRIEV	{"email": "v-dmitriev_03011973@postgrespro.ru", "phone": "+70239573058"}
0005434137373	6C3412	4679 218855	ANDREY MAKSIMOV	{"email": "maksimovandrey.06091964@postgrespro.ru", "phone": "+70057773400"}
0005434137374	0BBB72	2120 766296	SHAMIL KONOVALOV	{"email": "konovalov-shamil121977@postgrespro.ru", "phone": "+70012578611"}
0005434137375	0BBB72	8625 078658	OKSANA MIKHAYLOVA	{"phone": "+70817091216"}
0005434137376	92C077	3067 196733	NINA MEDVEDEVA	{"phone": "+70940776192"}
0005434137377	92C077	1933 363495	ANDREY YAKOVLEV	{"phone": "+70741703259"}
0005434137378	7FFE6F	2605 304833	ALEKSEY NOVIKOV	{"email": "aleksey-novikov15061976@postgrespro.ru", "phone": "+70445276190"}
0005434137379	7FFE6F	0278 381497	ALEKSANDRA NOVIKOVA	{"phone": "+70528307482"}
0005434137380	D07A49	7963 573375	NIKOLAY CHERNOV	{"email": "chernovnikolay.1969@postgrespro.ru", "phone": "+70773133688"}
0005434137381	7494B6	0619 402475	LYUDMILA KOZLOVA	{"phone": "+70789956393"}
0005434137382	15A936	5246 507797	PAVEL PETROV	{"phone": "+70028453804"}
0005434137383	15A936	2604 529695	OLGA SERGEEVA	{"email": "o-sergeeva.031973@postgrespro.ru", "phone": "+70204122135"}
0005434137551	9271EC	7895 088017	MAKSIM GUSEV	{"phone": "+70840501341"}
0005434137384	ABD435	1181 724962	ALEKSANDRA ROMANOVA	{"email": "a-romanova_1978@postgrespro.ru", "phone": "+70821565337"}
0005434137385	ABD435	8384 204519	VIKTORIYA MATVEEVA	{"email": "vmatveeva-1983@postgrespro.ru", "phone": "+70634710697"}
0005434137386	ABD435	7561 673025	TAISIYA KALININA	{"email": "tkalinina.17021962@postgrespro.ru", "phone": "+70232052303"}
0005434137387	2690A2	9975 111556	IGOR ZAYCEV	{"email": "i_zaycev_25081964@postgrespro.ru", "phone": "+70279474130"}
0005434137388	2690A2	4152 585074	NIKOLAY KISELEV	{"phone": "+70828833145"}
0005434137389	CF2DF1	1608 344362	MAKSIM VASILEV	{"email": "m_vasilev08021979@postgrespro.ru", "phone": "+70374366926"}
0005434137390	EB337A	1410 815136	GALINA TITOVA	{"email": "g.titova-16071978@postgrespro.ru", "phone": "+70011853826"}
0005434137391	DCB145	1699 322841	NATALYA MOROZOVA	{"phone": "+70161709304"}
0005434137392	DCB145	9894 286541	GALINA ROMANOVA	{"phone": "+70864636481"}
0005434137393	45B8E6	2662 992272	ALLA ANTONOVA	{"phone": "+70768152742"}
0005434137394	45B8E6	7941 568184	ANATOLIY MELNIKOV	{"email": "anatoliy_melnikov_1970@postgrespro.ru", "phone": "+70055553256"}
0005434137395	45B8E6	6451 272156	DMITRIY SOKOLOV	{"email": "sokolovdmitriy-1971@postgrespro.ru", "phone": "+70158873211"}
0005434137396	27D33C	4064 093476	FELIKS NIKITIN	{"email": "nikitin_feliks_1972@postgrespro.ru", "phone": "+70394783820"}
0005434137397	27D33C	6810 966097	DMITRIY ALEKSEEV	{"email": "alekseev-dmitriy.1970@postgrespro.ru", "phone": "+70936191704"}
0005434137398	89F6E0	0870 147197	ELENA ALEKSEEVA	{"phone": "+70742954151"}
0005434137399	0C3C4A	3385 209335	NATALYA ILINA	{"email": "ilina_natalya.1968@postgrespro.ru", "phone": "+70555247139"}
0005434137400	2A5EBD	4860 016662	IVAN ROMANOV	{"phone": "+70405688348"}
0005434137401	2A5EBD	5346 957271	ELIZAVETA ANDREEVA	{"phone": "+70502154862"}
0005434137402	E5A437	3218 702066	ALEKSEY AFANASEV	{"phone": "+70193739474"}
0005434137403	E5A437	5527 705860	IGOR SEMENOV	{"phone": "+70606305350"}
0005434137404	27321F	0585 850076	ALEKSANDR IVANOV	{"phone": "+70557047472"}
0005434137405	27321F	1204 339615	PAVEL NIKOLAEV	{"phone": "+70014760219"}
0005434137406	FB7D89	0432 787368	ELENA KAZAKOVA	{"email": "e-kazakova_021970@postgrespro.ru", "phone": "+70234856861"}
0005434137407	A44483	1524 629938	SVETLANA KOVALEVA	{"email": "svetlanakovaleva13111969@postgrespro.ru", "phone": "+70839923060"}
0005434137408	A44483	6866 535150	YULIYA BARANOVA	{"email": "y-baranova-28031970@postgrespro.ru", "phone": "+70496229082"}
0005434137409	C9439F	8954 959488	EVGENIY POPOV	{"email": "popove.18031978@postgrespro.ru", "phone": "+70803578007"}
0005434137410	C9439F	7289 259635	ANASTASIYA LAZAREVA	{"phone": "+70840830001"}
0005434137411	E9F7F4	0740 587919	NATALYA SIDOROVA	{"phone": "+70684630916"}
0005434137412	D99891	5627 966035	ANASTASIYA MIKHAYLOVA	{"phone": "+70080550199"}
0005434137413	057489	6407 302472	GALINA SIDOROVA	{"email": "sidorova-galina-01101981@postgrespro.ru", "phone": "+70574767217"}
0005434137414	057489	8534 447978	EVGENIY MIRONOV	{"phone": "+70219728729"}
0005434137415	2582B5	6635 505030	EVDOKIYA ANTONOVA	{"phone": "+70124667339"}
0005434137416	DD0B75	0781 223939	SERGEY TARASOV	{"email": "tarasov.s_011984@postgrespro.ru", "phone": "+70304640530"}
0005434137417	0240C2	7137 044789	LYUDMILA NESTEROVA	{"phone": "+70590703018"}
0005434137418	46A258	7536 267773	SERGEY SMIRNOV	{"phone": "+70691007811"}
0005434137419	46A258	2875 721921	ALEKSANDR KOZLOV	{"phone": "+70483320214"}
0005434137420	DE4205	1246 739039	NIKOLAY POPOV	{"phone": "+70568194838"}
0005434137421	DE4205	4947 515374	YULIYA MALYSHEVA	{"phone": "+70309620152"}
0005434137422	120505	5962 899541	NATALYA ZAYCEVA	{"phone": "+70978609153"}
0005434137423	DA8CCA	7317 399161	SVETLANA IVANOVA	{"email": "ivanovasvetlana.16061973@postgrespro.ru", "phone": "+70978246632"}
0005434137424	7923C4	4230 879219	VIKTOR VLASOV	{"email": "viktor-vlasov.09011978@postgrespro.ru", "phone": "+70629793452"}
0005434137425	7923C4	6626 742965	ZINAIDA ALEKSANDROVA	{"phone": "+70918996260"}
0005434137426	90C266	5826 153869	ALEKSANDR KUZNECOV	{"email": "kuznecov.a.05051984@postgrespro.ru", "phone": "+70171069048"}
0005434137427	E6D4AA	2663 353414	TAMARA NAZAROVA	{"email": "nazarovatamara25051976@postgrespro.ru", "phone": "+70309458573"}
0005434137428	E6D4AA	5259 501754	IGOR KISELEV	{"phone": "+70898567715"}
0005434137429	C3C7A5	5376 639531	SERGEY KONOVALOV	{"email": "konovalovs_07111990@postgrespro.ru", "phone": "+70112398610"}
0005434137430	5F9F10	7422 216033	VERA IVANOVA	{"phone": "+70260965661"}
0005434137431	E51864	8506 772007	EKATERINA ALEKSEEVA	{"email": "ekaterina_alekseeva_1986@postgrespro.ru", "phone": "+70260716068"}
0005434137432	E51864	0192 604070	LYUDMILA SMIRNOVA	{"phone": "+70505527820"}
0005434137433	BF16C4	5687 801559	LYUBOV GERASIMOVA	{"email": "gerasimovalyubov_12101978@postgrespro.ru", "phone": "+70729652619"}
0005434137434	20D8E4	4726 336385	ALEKSEY FOMIN	{"phone": "+70134268882"}
0005434137435	20D8E4	8295 776936	OLGA DAVYDOVA	{"phone": "+70470851361"}
0005434137436	20D8E4	9152 169167	DMITRIY KUZMIN	{"email": "dkuzmin.17051967@postgrespro.ru", "phone": "+70325317467"}
0005434137437	619D40	8049 466600	RAISA MELNIKOVA	{"email": "melnikova_raisa-091975@postgrespro.ru", "phone": "+70017408748"}
0005434137438	46088A	0520 664221	ALLA YAKOVLEVA	{"phone": "+70744147527"}
0005434137439	46088A	5322 304799	ELENA LAZAREVA	{"phone": "+70131457044"}
0005434137440	E43F00	7300 325002	ELENA KOZLOVA	{"email": "ekozlova_1959@postgrespro.ru", "phone": "+70661823845"}
0005434137441	E43F00	2586 185441	NATALYA POPOVA	{"phone": "+70899265635"}
0005434137442	11462F	9437 438348	TATYANA NOVIKOVA	{"phone": "+70350809206"}
0005434137443	3DEDF3	3912 678781	VITALIY BORISOV	{"email": "borisovvitaliy_1970@postgrespro.ru", "phone": "+70421235301"}
0005434137444	0D2441	3135 386205	OLGA KUZNECOVA	{"phone": "+70304483487"}
0005434137445	0D2441	9825 500385	OLGA NAZAROVA	{"email": "olga_nazarova.081972@postgrespro.ru", "phone": "+70582802976"}
0005434137446	2D9D46	2617 377793	YULIYA GERASIMOVA	{"email": "y.gerasimova_1976@postgrespro.ru", "phone": "+70069053362"}
0005434137447	947E57	4230 941139	SVETLANA LUKYANOVA	{"email": "lukyanova_svetlana051976@postgrespro.ru", "phone": "+70952893140"}
0005434137448	60E340	9496 661180	KRISTINA CHERNOVA	{"email": "k-chernova-1980@postgrespro.ru", "phone": "+70924014995"}
0005434137449	CD6FFE	0354 195431	MARIYA AKIMOVA	{"email": "mariya.akimova.031975@postgrespro.ru", "phone": "+70400175175"}
0005434137450	A452CF	6253 247925	ANTON AFANASEV	{"email": "afanasev_anton.041977@postgrespro.ru", "phone": "+70290932432"}
0005434137451	A452CF	4770 848173	VADIM BELOV	{"email": "v_belov071982@postgrespro.ru", "phone": "+70815362443"}
0005434137452	D3CDCB	3413 654522	ANDREY GAVRILOV	{"email": "gavrilov-andrey08071979@postgrespro.ru", "phone": "+70028776147"}
0005434137453	D3CDCB	5463 439994	YULIYA POLYAKOVA	{"phone": "+70961056547"}
0005434137454	290D7D	9956 053165	ANDREY IVANOV	{"phone": "+70178167297"}
0005434137455	63192D	7739 654210	LYUDMILA NESTEROVA	{"phone": "+70948738195"}
0005434137456	63192D	6099 714698	SERGEY ISAEV	{"phone": "+70973665773"}
0005434137457	63192D	5395 395975	VALENTINA DAVYDOVA	{"email": "davydova_v10071966@postgrespro.ru", "phone": "+70237333727"}
0005434137458	63192D	9601 608907	OLGA ANDREEVA	{"email": "andreeva-o_09111969@postgrespro.ru", "phone": "+70745703125"}
0005434137459	E7B2D1	9823 632053	GERMAN GAVRILOV	{"phone": "+70092687434"}
0005434137460	E7B2D1	9307 162420	VERA SCHERBAKOVA	{"email": "scherbakovav.091977@postgrespro.ru", "phone": "+70911176953"}
0005434137461	E7B2D1	3463 280058	ANATOLIY KULIKOV	{"phone": "+70039960385"}
0005434137462	E7B2D1	9332 324478	PAVEL FROLOV	{"phone": "+70075943433"}
0005434137463	32A1E5	5939 087860	RAVIL KUZNECOV	{"phone": "+70575968123"}
0005434137464	32A1E5	5686 913028	ELENA CHERNOVA	{"phone": "+70569244121"}
0005434137465	32A1E5	4022 028568	YULIYA SEMENOVA	{"phone": "+70094486610"}
0005434137466	C77144	7151 566858	MARIYA POLYAKOVA	{"email": "mpolyakova011966@postgrespro.ru", "phone": "+70971496479"}
0005434137467	F60342	5196 429592	ANDREY IVANOV	{"email": "ivanov.a011978@postgrespro.ru", "phone": "+70962186887"}
0005434137468	502D56	3267 021100	NINA VOROBEVA	{"phone": "+70607269645"}
0005434137469	D5B7F1	7940 828403	ELENA CHERNOVA	{"phone": "+70308815241"}
0005434137470	6ED18A	5233 022417	MIKHAIL PETROV	{"email": "petrov.mikhail-03091968@postgrespro.ru", "phone": "+70382538935"}
0005434137471	C4FC7D	7364 523092	DMITRIY VOLKOV	{"email": "dmitriy_volkov041979@postgrespro.ru", "phone": "+70207937146"}
0005434137472	C4FC7D	1860 225128	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.24081966@postgrespro.ru", "phone": "+70701305952"}
0005434137473	C4FC7D	9396 223167	KIRILL SHEVCHENKO	{"email": "kirill_shevchenko-18101977@postgrespro.ru", "phone": "+70483397490"}
0005434137474	8E241B	0232 255707	ELIZAVETA MAKAROVA	{"phone": "+70068729975"}
0005434137475	1AD924	4037 407537	EGOR ABRAMOV	{"phone": "+70268872329"}
0005434137476	610EBE	2456 773140	DMITRIY IVANOV	{"email": "dmitriyivanov_25101982@postgrespro.ru", "phone": "+70133010087"}
0005434137477	F1F94B	5921 527033	NATALYA MIRONOVA	{"phone": "+70778586475"}
0005434137478	F1F94B	6153 542745	OKSANA EFREMOVA	{"email": "efremova-o-1977@postgrespro.ru", "phone": "+70548399999"}
0005434137479	E0E1F4	6505 756698	NATALYA VASILEVA	{"email": "n_vasileva06031973@postgrespro.ru", "phone": "+70892773566"}
0005434137480	678C4E	2484 662390	FAIL MOROZOV	{"phone": "+70696214751"}
0005434137481	5C3091	6998 609537	ANTONINA ARKHIPOVA	{"email": "antonina-arkhipova_15031968@postgrespro.ru", "phone": "+70506975759"}
0005434137482	5C3091	5286 460302	LYUBOV KISELEVA	{"phone": "+70613610438"}
0005434137483	5C3091	2206 636708	YURIY PAVLOV	{"phone": "+70525196104"}
0005434137484	D95628	2636 688396	TATYANA SMIRNOVA	{"phone": "+70925561206"}
0005434137485	77E513	0460 073708	ANNA ROMANOVA	{"phone": "+70541406684"}
0005434137486	77E513	3104 785075	ANATOLIY EGOROV	{"phone": "+70569283068"}
0005434137487	BEF5E6	6094 731181	YURIY SCHERBAKOV	{"phone": "+70464171810"}
0005434137488	BEF5E6	9303 157627	LYUDMILA KOZLOVA	{"email": "kozlovalyudmila-101962@postgrespro.ru", "phone": "+70111120501"}
0005434137489	7C9DF3	7016 177496	ANDREY FROLOV	{"email": "frolov-andrey_121967@postgrespro.ru", "phone": "+70466473553"}
0005434137490	B8E1D1	4316 355410	LEONID KULIKOV	{"email": "leonid.kulikov09071961@postgrespro.ru", "phone": "+70422001601"}
0005434137491	B8E1D1	6381 351054	NATALYA IVANOVA	{"phone": "+70642682204"}
0005434137492	8C15FA	2232 102325	MARINA OSIPOVA	{"email": "osipovam_1966@postgrespro.ru", "phone": "+70469958328"}
0005434137493	B45818	0989 956107	ANDREY MOROZOV	{"email": "morozova021970@postgrespro.ru", "phone": "+70934722554"}
0005434137494	E5620B	8349 756424	VERONIKA ZAKHAROVA	{"phone": "+70535461988"}
0005434137495	0B2A81	8657 828182	VIKTORIYA ISAEVA	{"email": "isaeva_v.02021959@postgrespro.ru", "phone": "+70058462587"}
0005434137496	58EEF9	9905 348042	SVETLANA DAVYDOVA	{"email": "davydova_s1975@postgrespro.ru", "phone": "+70286951397"}
0005434137497	58EEF9	6340 076405	KONSTANTIN KOZLOV	{"email": "kozlov.k.1975@postgrespro.ru", "phone": "+70212036029"}
0005434137498	A7E559	4849 280961	ANDREY VLASOV	{"email": "vlasov_andrey_1962@postgrespro.ru", "phone": "+70505464371"}
0005434137499	298747	2278 950899	IVAN MEDVEDEV	{"phone": "+70910464240"}
0005434137500	298747	4613 358915	LILIYA KUZNECOVA	{"email": "kuznecovaliliya.1977@postgrespro.ru", "phone": "+70812609714"}
0005434137501	45BCA1	5490 859077	ZHANNA FEDOROVA	{"email": "fedorovazhanna-1952@postgrespro.ru", "phone": "+70812081967"}
0005434137502	860C8B	9075 554704	VALENTINA MIKHAYLOVA	{"phone": "+70095644510"}
0005434137503	5D9565	5552 834372	VLADIMIR STEPANOV	{"email": "stepanov.v-061974@postgrespro.ru", "phone": "+70438815526"}
0005434137504	5D9565	1390 653259	NINA VOROBEVA	{"email": "vorobeva_nina28091978@postgrespro.ru", "phone": "+70005967542"}
0005434137505	963A5F	6574 706856	VLADIMIR KUZNECOV	{"phone": "+70209462288"}
0005434137506	963A5F	2246 946665	YULIYA NOVIKOVA	{"phone": "+70803823965"}
0005434137507	2F809D	8840 281665	NATALYA BORISOVA	{"email": "n.borisova-111981@postgrespro.ru", "phone": "+70567907458"}
0005434137508	2F809D	4701 540691	ALEKSANDR ORLOV	{"email": "a_orlov1970@postgrespro.ru", "phone": "+70913475154"}
0005434137509	950EFD	0862 425191	ZAKHAR MAKSIMOV	{"phone": "+70545913222"}
0005434137510	DD8E88	7953 487530	ILYA MIKHAYLOV	{"phone": "+70745886560"}
0005434137511	DD8E88	7063 120076	MAKSIM KUZNECOV	{"email": "kuznecovmaksim041966@postgrespro.ru", "phone": "+70012124138"}
0005434137512	15FD49	2398 073742	TATYANA LAZAREVA	{"email": "lazareva_tatyana_1980@postgrespro.ru", "phone": "+70367054279"}
0005434137513	163BAF	0016 190464	NIKOLAY PETROV	{"email": "n_petrov_05041974@postgrespro.ru", "phone": "+70083534238"}
0005434137514	BC2630	7062 224733	ALEKSANDR FROLOV	{"email": "frolov_a.061972@postgrespro.ru", "phone": "+70321658038"}
0005434137515	7C1E83	5369 456089	AZAT FOMIN	{"phone": "+70451109203"}
0005434137516	6CE456	3717 357007	OKSANA ZOTOVA	{"email": "zotova.oksana_03021973@postgrespro.ru", "phone": "+70739765062"}
0005434137517	6CE456	8571 785366	MARINA ZAKHAROVA	{"phone": "+70609020637"}
0005434137518	4E3FED	8421 246989	VASILIY NIKITIN	{"email": "vasiliynikitin-041985@postgrespro.ru", "phone": "+70143466014"}
0005434137519	A88A45	9828 384694	ANDREY STEPANOV	{"phone": "+70546342091"}
0005434137520	99D1B4	4794 942865	OKSANA MOISEEVA	{"email": "o_moiseeva.091968@postgrespro.ru", "phone": "+70340538749"}
0005434137521	255789	5001 970313	SVETLANA DMITRIEVA	{"email": "svetlanadmitrieva-1973@postgrespro.ru", "phone": "+70110187298"}
0005434137800	A68F4F	7165 430582	ALEKSANDR POPOV	{"phone": "+70983182930"}
0005434137522	255789	3165 834927	EKATERINA ALEKSANDROVA	{"email": "e_aleksandrova.051982@postgrespro.ru", "phone": "+70358229684"}
0005434137523	8F2521	7218 877365	YURIY MOROZOV	{"phone": "+70375936873"}
0005434137524	8F2521	1888 131876	ANNA KOLESNIKOVA	{"phone": "+70989888349"}
0005434137525	2D21E1	9832 607727	NATALYA AFANASEVA	{"email": "afanaseva.natalya1961@postgrespro.ru", "phone": "+70052809417"}
0005434137526	2D21E1	7468 482190	NIKOLAY VOLKOV	{"email": "volkov_nikolay011972@postgrespro.ru", "phone": "+70399893966"}
0005434137527	DF0BA5	6039 393320	ALEKSANDRA AFANASEVA	{"phone": "+70413252675"}
0005434137528	CD9221	7341 959456	TATYANA RYABOVA	{"email": "ryabova_tatyana.071966@postgrespro.ru", "phone": "+70247722106"}
0005434137529	CD9221	9990 601795	ALEKSEY ANDREEV	{"phone": "+70278106568"}
0005434137530	AA24A1	1425 963026	DENIS MOISEEV	{"phone": "+70559525494"}
0005434137531	482437	8724 486906	ALEKSANDR ISAEV	{"email": "aleksandr-isaev-021978@postgrespro.ru", "phone": "+70836543533"}
0005434137532	482437	3034 977503	YULIYA AKIMOVA	{"email": "akimova-yuliya15111973@postgrespro.ru", "phone": "+70367056104"}
0005434137533	482437	2744 743586	YURIY FEDOROV	{"phone": "+70872997247"}
0005434137534	482437	9499 870726	OLGA FILIPPOVA	{"phone": "+70722066781"}
0005434137535	B0F8F4	7470 171958	LYUBOV LEBEDEVA	{"email": "lebedeva-l_21111966@postgrespro.ru", "phone": "+70257012678"}
0005434137536	49C24E	8020 925632	VLADIMIR SERGEEV	{"email": "vladimir_sergeev_24041977@postgrespro.ru", "phone": "+70529503465"}
0005434137537	49C24E	3060 717325	SERGEY NIKITIN	{"email": "nikitinsergey_1959@postgrespro.ru", "phone": "+70971195165"}
0005434137538	E28FC4	6141 102616	MIKHAIL BORISOV	{"phone": "+70309845916"}
0005434137539	74D3A1	8181 846698	VALERIY SERGEEV	{"email": "v_sergeev.20081980@postgrespro.ru", "phone": "+70089397565"}
0005434137540	C7C4EE	4981 145748	EKATERINA ALEKSEEVA	{"email": "e_alekseeva_091974@postgrespro.ru", "phone": "+70411938105"}
0005434137541	8C22F0	4751 290126	VALENTIN ALEKSEEV	{"phone": "+70471954700"}
0005434137542	8C22F0	8960 282754	YULIYA KAZAKOVA	{"email": "ykazakova011970@postgrespro.ru", "phone": "+70678904471"}
0005434137543	364D2A	0225 419595	MIKHAIL POPOV	{"email": "mikhail.popov1975@postgrespro.ru", "phone": "+70883494337"}
0005434137544	FB8821	4030 683063	ALEKSANDRA TARASOVA	{"email": "aleksandra_tarasova1965@postgrespro.ru", "phone": "+70789373804"}
0005434137545	0C785F	8352 821133	NIKOLAY CHERNOV	{"phone": "+70795472213"}
0005434137546	8B6BD7	4186 407307	VLADIMIR MAKSIMOV	{"phone": "+70035928451"}
0005434137547	B656B8	1893 161820	RAFAIL SOLOVEV	{"email": "rafail_solovev_06091968@postgrespro.ru", "phone": "+70650179713"}
0005434137548	FBF9E6	0349 571923	SVETLANA TROFIMOVA	{"phone": "+70970033668"}
0005434137549	CBBAF7	2450 726188	GALINA KARPOVA	{"email": "karpova.galina-1966@postgrespro.ru", "phone": "+70685139029"}
0005434137550	CBBAF7	1611 632576	GENNADIY FEDOTOV	{"email": "fedotov.gennadiy.091973@postgrespro.ru", "phone": "+70428796886"}
0005434137552	9271EC	8657 448012	SERGEY STEPANOV	{"email": "stepanovsergey-18121967@postgrespro.ru", "phone": "+70427080479"}
0005434137553	C5E3B9	2877 882489	ANDREY KUZNECOV	{"phone": "+70601725059"}
0005434137554	C5E3B9	6464 556438	MIKHAIL PAVLOV	{"phone": "+70900304635"}
0005434137555	41B08D	4968 284553	YURIY ISAEV	{"phone": "+70512466544"}
0005434137556	9B295E	7417 366301	MARINA PAVLOVA	{"email": "pavlovamarina1974@postgrespro.ru", "phone": "+70356260634"}
0005434137557	B4D067	9236 315484	EVGENIY SOROKIN	{"email": "e.sorokin.031970@postgrespro.ru", "phone": "+70418849787"}
0005434137558	536DDD	9656 966874	ANASTASIYA FOMINA	{"phone": "+70227656782"}
0005434137559	913138	4221 866506	ANNA MAKAROVA	{"email": "amakarova.1976@postgrespro.ru", "phone": "+70364809779"}
0005434137560	913138	9438 810531	ALENA NAZAROVA	{"email": "a_nazarova.07071978@postgrespro.ru", "phone": "+70475161354"}
0005434137561	774B1E	4504 027307	VIKTOR IVANOV	{"phone": "+70608739335"}
0005434137562	80601E	3032 881782	EVGENIY NAUMOV	{"phone": "+70415867907"}
0005434137563	B659AE	9394 702592	NATALYA KOLESNIKOVA	{"email": "kolesnikova-natalya_07091962@postgrespro.ru", "phone": "+70994855456"}
0005434137564	B659AE	3255 445196	EVGENIYA IVANOVA	{"email": "e_ivanova-03091967@postgrespro.ru", "phone": "+70915327645"}
0005434137565	604FA1	7334 194476	IRINA RODIONOVA	{"email": "rodionova.i-1970@postgrespro.ru", "phone": "+70256542639"}
0005434137566	604FA1	2935 478593	GALINA ANDREEVA	{"email": "galina-andreeva_10081972@postgrespro.ru", "phone": "+70155372057"}
0005434137567	183906	7670 908046	NIKOLAY ZHUKOV	{"phone": "+70179255916"}
0005434137568	183906	4731 880400	VALERIY KULIKOV	{"email": "v_kulikov18021971@postgrespro.ru", "phone": "+70341308677"}
0005434137569	41640A	3226 877411	VERA NAUMOVA	{"email": "naumovavera_1967@postgrespro.ru", "phone": "+70954129838"}
0005434137570	4CAB0C	4996 908542	VERA KISELEVA	{"email": "kiseleva_v.011972@postgrespro.ru", "phone": "+70436398789"}
0005434137571	6D78AB	2854 319414	VALERIY MAKAROV	{"phone": "+70993186606"}
0005434137572	2E3A0E	7481 266071	NATALYA SMIRNOVA	{"email": "natalya-smirnova.111973@postgrespro.ru", "phone": "+70153455764"}
0005434137573	7C3749	9565 995957	ALEKSANDR FROLOV	{"phone": "+70719426981"}
0005434137574	66C14C	5765 309886	OLEG GRIGOREV	{"email": "o.grigorev.061976@postgrespro.ru", "phone": "+70564969874"}
0005434137575	7817AD	7599 687576	EVGENIY SOKOLOV	{"email": "sokolov-evgeniy091981@postgrespro.ru", "phone": "+70846421752"}
0005434137576	85D4DB	3502 662988	DMITRIY VASILEV	{"email": "vasilev-d19051971@postgrespro.ru", "phone": "+70081669463"}
0005434137577	85D4DB	8393 934871	EVGENIY SAVELEV	{"phone": "+70173804674"}
0005434137578	85D4DB	1942 715601	TATYANA ROMANOVA	{"email": "romanova-tatyana.111970@postgrespro.ru", "phone": "+70867512751"}
0005434137579	E6375A	7413 415630	ELENA BELYAEVA	{"email": "e_belyaeva15091970@postgrespro.ru", "phone": "+70728508595"}
0005434137580	02D800	9148 739575	VYACHESLAV KOROLEV	{"email": "korolev.v.17121975@postgrespro.ru", "phone": "+70541564498"}
0005434137581	02D800	5498 526449	YURIY MOROZOV	{"email": "morozov.y_1973@postgrespro.ru", "phone": "+70782155272"}
0005434137582	93AE62	9768 526465	MARIYA NIKOLAEVA	{"email": "nikolaeva_m-091978@postgrespro.ru", "phone": "+70611506517"}
0005434137583	D8795D	8699 994786	TAISIYA SAVELEVA	{"phone": "+70366365915"}
0005434137584	D8795D	5689 606380	MARIYA KUZNECOVA	{"email": "kuznecova.m_05071977@postgrespro.ru", "phone": "+70780256296"}
0005434137585	A605FC	6652 921278	VLADIMIR FEDOTOV	{"phone": "+70051289118"}
0005434137586	A605FC	8593 872882	EKATERINA EGOROVA	{"email": "egorova.e071978@postgrespro.ru", "phone": "+70302813821"}
0005434137587	2060ED	1179 347014	OLGA NESTEROVA	{"phone": "+70634752833"}
0005434137588	2060ED	5757 833386	NATALYA GAVRILOVA	{"phone": "+70490451552"}
0005434137589	FFBB78	6026 180641	VASILIY NAUMOV	{"phone": "+70707655461"}
0005434137590	6EC2F8	4170 341627	VERA KUZNECOVA	{"phone": "+70229338663"}
0005434137591	B4E4BC	3450 574683	SHAMIL MAKSIMOV	{"email": "s-maksimov_091969@postgrespro.ru", "phone": "+70995202922"}
0005434137592	1DD510	6815 492273	ZOYA SOKOLOVA	{"email": "sokolova.zoya-1963@postgrespro.ru", "phone": "+70449088810"}
0005434137593	B0C06E	2454 190771	BORIS VOLKOV	{"phone": "+70840965005"}
0005434137594	9C5441	2010 927266	LEONID KOZLOV	{"phone": "+70905911415"}
0005434137595	9C5441	5800 944896	YURIY MAKAROV	{"phone": "+70801037286"}
0005434137596	805F80	5573 812647	ROMAN BELOV	{"phone": "+70560292052"}
0005434137597	805F80	0929 281317	ELENA ANTONOVA	{"phone": "+70087925208"}
0005434137598	BAD146	6643 535821	YULIYA MELNIKOVA	{"phone": "+70951990765"}
0005434137599	BAD146	3862 525449	NIKOLAY KAZAKOV	{"email": "kazakov_n041969@postgrespro.ru", "phone": "+70962178223"}
0005434137600	9FFF0D	3443 241876	ALSU ZHUKOVA	{"phone": "+70158247707"}
0005434137601	9FFF0D	9069 066705	LYUDMILA MOROZOVA	{"phone": "+70553778778"}
0005434137602	84F5D3	6629 141887	LIDIYA KUZMINA	{"phone": "+70159521862"}
0005434137603	15797C	6553 972390	EVGENIY NIKOLAEV	{"email": "nikolaev_e25011968@postgrespro.ru", "phone": "+70777410849"}
0005434137604	EF63FC	1541 783537	SERGEY PETROV	{"email": "s.petrov.051974@postgrespro.ru", "phone": "+70523778087"}
0005434137605	6FBDDE	5017 896300	LYUDMILA ANDREEVA	{"phone": "+70243345948"}
0005434137606	2EC930	3549 502356	YULIYA FROLOVA	{"phone": "+70621571879"}
0005434137607	2EC930	7958 840041	GLEB KONOVALOV	{"email": "konovalov-g-091965@postgrespro.ru", "phone": "+70756888401"}
0005434137608	CA24DC	5554 484212	ANDREY KUZNECOV	{"email": "kuznecovandrey-24111972@postgrespro.ru", "phone": "+70323126256"}
0005434137609	CA24DC	4957 260707	EVGENIY BORISOV	{"email": "borisov.evgeniy-1968@postgrespro.ru", "phone": "+70543419297"}
0005434137610	F500EB	7670 548871	ANASTASIYA FILIPPOVA	{"email": "filippova_anastasiya-04011962@postgrespro.ru", "phone": "+70997401773"}
0005434137611	47B595	5088 745623	MAKSIM ISAEV	{"phone": "+70248960055"}
0005434137612	B678BE	9226 289697	SERGEY SOROKIN	{"phone": "+70839028009"}
0005434137613	28F21B	8257 745720	ELENA MIRONOVA	{"phone": "+70055705538"}
0005434137614	B3D1ED	3353 469186	GALINA SOROKINA	{"email": "galinasorokina.031975@postgrespro.ru", "phone": "+70311224429"}
0005434137615	59B4AC	3757 043006	PRASKOVYA SIDOROVA	{"phone": "+70296066986"}
0005434137616	C521A6	3078 870267	NADEZHDA IVANOVA	{"phone": "+70405583783"}
0005434137617	D5E1A1	9381 667162	STANISLAV TIMOFEEV	{"email": "stimofeev-24011977@postgrespro.ru", "phone": "+70188044949"}
0005434137618	D5E1A1	7072 219701	NATALYA AFANASEVA	{"email": "n-afanaseva.081969@postgrespro.ru", "phone": "+70136134411"}
0005434137619	D5E1A1	0995 495454	VLADIMIR MAKSIMOV	{"phone": "+70559697662"}
0005434137620	4356C3	4995 764249	NATALYA DANILOVA	{"email": "danilova-natalya-1977@postgrespro.ru", "phone": "+70301865618"}
0005434137621	4356C3	8031 814867	SVETLANA MATVEEVA	{"phone": "+70177961040"}
0005434137622	E512EA	5787 232796	NIKOLAY NIKOLAEV	{"phone": "+70336376156"}
0005434137623	E512EA	3105 536743	IGOR BARANOV	{"email": "igor.baranov_01031981@postgrespro.ru", "phone": "+70115194920"}
0005434137624	72D706	2492 218892	YAROSLAVA SOROKINA	{"phone": "+70465788320"}
0005434137625	72D706	1019 747815	VIKTOR IVANOV	{"email": "viktor-ivanov-15031977@postgrespro.ru", "phone": "+70225805917"}
0005434137626	C45D37	0498 405142	YURIY MOISEEV	{"email": "moiseev_y.081964@postgrespro.ru", "phone": "+70817009975"}
0005434137627	E652A9	7715 743427	LEONID SAVELEV	{"phone": "+70643173961"}
0005434137628	7C79D9	0722 720495	DMITRIY SEMENOV	{"email": "semenovdmitriy-1970@postgrespro.ru", "phone": "+70029352582"}
0005434137629	7C79D9	0340 793951	NIKOLAY FILIPPOV	{"email": "nikolay_filippov_1968@postgrespro.ru", "phone": "+70138591005"}
0005434137630	4D6AC5	8057 636633	MARINA FADEEVA	{"email": "fadeeva.marina-07031973@postgrespro.ru", "phone": "+70203990375"}
0005434137631	4D6AC5	8106 543414	SERGEY MARTYNOV	{"email": "martynov.sergey_1970@postgrespro.ru", "phone": "+70598508288"}
0005434137632	68A575	7116 095560	GYUZEL MATVEEVA	{"email": "g_matveeva_051975@postgrespro.ru", "phone": "+70282146197"}
0005434137633	59C050	0535 428294	IVAN GERASIMOV	{"email": "gerasimov.ivan-091972@postgrespro.ru", "phone": "+70610063493"}
0005434137634	59C050	1532 109482	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana_1957@postgrespro.ru", "phone": "+70399929165"}
0005434137635	512236	8943 263063	SERGEY MELNIKOV	{"email": "melnikov.s.1969@postgrespro.ru", "phone": "+70718880137"}
0005434137636	D927A3	2603 904811	LEONID MEDVEDEV	{"phone": "+70812442280"}
0005434137637	D2FFEC	5268 872424	SERGEY SMIRNOV	{"email": "sergey-smirnov-01041974@postgrespro.ru", "phone": "+70164745188"}
0005434137638	D70ACC	6766 027799	MARIYA ZAYCEVA	{"phone": "+70874143412"}
0005434137639	D70ACC	7281 244923	ELIZAVETA MAKAROVA	{"email": "makarovae_1967@postgrespro.ru", "phone": "+70560392953"}
0005434137640	CBF104	3563 231397	VIKTOR KUZNECOV	{"phone": "+70109823053"}
0005434137641	381A6E	4242 353732	DMITRIY VLASOV	{"email": "dmitriy.vlasov21031979@postgrespro.ru", "phone": "+70215396441"}
0005434137642	81C5B3	4604 353308	GERMAN NIKOLAEV	{"phone": "+70706934843"}
0005434137643	294A47	8006 748294	VALENTINA ROMANOVA	{"email": "romanova-valentina_01091970@postgrespro.ru", "phone": "+70766817477"}
0005434137644	294A47	9485 342470	VERA BORISOVA	{"phone": "+70402514142"}
0005434137645	DA75F1	8582 368150	ANTON DMITRIEV	{"phone": "+70185441758"}
0005434137646	D8FC03	8437 106226	MAKSIM PETROV	{"email": "petrovmaksim.1974@postgrespro.ru", "phone": "+70262878516"}
0005434137647	D8FC03	1964 462567	TATYANA TIMOFEEVA	{"email": "tatyana.timofeeva_061979@postgrespro.ru", "phone": "+70486764388"}
0005434137648	02BF56	6415 861129	GALINA KOROLEVA	{"email": "galinakoroleva_101984@postgrespro.ru", "phone": "+70018970070"}
0005434137649	7899CF	1823 410624	VERA SOROKINA	{"phone": "+70761270541"}
0005434137650	ED626E	5796 701722	GALINA MELNIKOVA	{"email": "melnikova-galina_26041985@postgrespro.ru", "phone": "+70809906814"}
0005434137651	56EE3C	5271 099030	VLADISLAV VLASOV	{"phone": "+70797830485"}
0005434137652	56EE3C	5694 261300	SVETLANA POPOVA	{"email": "svetlana-popova.011984@postgrespro.ru", "phone": "+70698821906"}
0005434137653	BE4B7D	8171 778199	MIKHAIL STEPANOV	{"phone": "+70644339080"}
0005434137654	BE4B7D	7192 470624	IRINA GORBUNOVA	{"phone": "+70198729330"}
0005434137655	7207AB	2719 539045	ANTONINA KRASNOVA	{"email": "krasnova.antonina_1974@postgrespro.ru", "phone": "+70157813112"}
0005434137656	3720B5	0280 079222	EVGENIY VOLKOV	{"phone": "+70751536022"}
0005434137657	3720B5	9130 744411	VLADISLAV NIKOLAEV	{"email": "v-nikolaev19071969@postgrespro.ru", "phone": "+70288200585"}
0005434137658	B66FE1	4156 680560	ELENA OSIPOVA	{"phone": "+70156212438"}
0005434137659	B66FE1	7846 854464	ZINAIDA TARASOVA	{"phone": "+70156155359"}
0005434137660	D6B0F0	7746 467711	MIKHAIL PETROV	{"phone": "+70647852438"}
0005434137661	836286	7702 457693	VASILIY MEDVEDEV	{"phone": "+70044315614"}
0005434137662	836286	2824 161823	STEPAN YAKOVLEV	{"email": "stepan-yakovlev_22071959@postgrespro.ru", "phone": "+70378412980"}
0005434137663	836286	5556 291592	ALEKSANDR GUSEV	{"phone": "+70145680364"}
0005434137664	CAC1C2	2797 426226	YANA EFREMOVA	{"email": "yefremova081978@postgrespro.ru", "phone": "+70666440987"}
0005434137665	CAC1C2	7777 021356	ALEKSEY MOROZOV	{"phone": "+70143177408"}
0005434137666	F3C53F	5173 560761	DMITRIY BELOV	{"phone": "+70496012674"}
0005434137667	D9D2C4	4549 587467	NATALYA SERGEEVA	{"email": "natalya.sergeeva_04031972@postgrespro.ru", "phone": "+70045115392"}
0005434137668	D4D690	4807 736188	ANATOLIY KULIKOV	{"phone": "+70854514149"}
0005434137669	2052EF	7815 665306	VALERIY IVANOV	{"phone": "+70017120356"}
0005434137670	C14144	6939 064642	NATALYA DENISOVA	{"phone": "+70847044882"}
0005434137671	D7A9BA	7232 421898	ZINAIDA KOZLOVA	{"phone": "+70192296356"}
0005434137672	D7A9BA	2292 011877	TATYANA KUZNECOVA	{"email": "t.kuznecova14061972@postgrespro.ru", "phone": "+70897332204"}
0005434137673	531E36	2296 872857	ALENA RYABOVA	{"phone": "+70660512118"}
0005434137674	D34395	0026 102057	LIDIYA IVANOVA	{"phone": "+70025497352"}
0005434137675	D34395	6004 111668	NATALYA KOMAROVA	{"phone": "+70350392960"}
0005434137676	FBFAB7	2429 193835	SERGEY SAVELEV	{"phone": "+70965470829"}
0005434137677	E83037	4483 512434	SERGEY POPOV	{"phone": "+70508724216"}
0005434137678	548C6F	2564 823631	ALEKSANDR NIKITIN	{"phone": "+70784922168"}
0005434137679	6D2DC7	8160 139814	SVETLANA ALEKSANDROVA	{"phone": "+70561095188"}
0005434137680	4E3D81	5088 719031	ANNA MIRONOVA	{"email": "a_mironova.011972@postgrespro.ru", "phone": "+70655115129"}
0005434137681	2809E3	1341 764063	ANATOLIY BONDARENKO	{"phone": "+70395277425"}
0005434137739	A25E40	4779 037054	ELLA KUDRYASHOVA	{"phone": "+70586677197"}
0005434137682	E85046	5039 093866	VIKTORIYA DMITRIEVA	{"email": "viktoriya-dmitrieva-02091971@postgrespro.ru", "phone": "+70958731075"}
0005434137683	E85046	1365 546658	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana.11031970@postgrespro.ru", "phone": "+70550796116"}
0005434137684	CBAF67	8635 002230	ANNA IVANOVA	{"email": "a_ivanova_25101975@postgrespro.ru", "phone": "+70494922053"}
0005434137685	CBAF67	8919 114884	VLADIMIR KUZNECOV	{"phone": "+70120586449"}
0005434137686	AD62DA	3537 083954	GALINA PAVLOVA	{"phone": "+70221298469"}
0005434137687	AD62DA	9135 757695	DMITRIY SCHERBAKOV	{"phone": "+70174429958"}
0005434137688	BE0122	6522 419862	VASILIY ALEKSEEV	{"email": "alekseev.v06051982@postgrespro.ru", "phone": "+70971570840"}
0005434137689	BE0122	3920 468127	LIDIYA VOLKOVA	{"email": "volkovalidiya04081968@postgrespro.ru", "phone": "+70408648199"}
0005434137690	121801	3843 899422	EGOR OSIPOV	{"email": "osipov_egor-30111966@postgrespro.ru", "phone": "+70248758369"}
0005434137691	FC77D6	4187 945530	VIKTORIYA KUZNECOVA	{"email": "viktoriyakuznecova.091969@postgrespro.ru", "phone": "+70905970056"}
0005434137692	FC77D6	4565 511896	MARAT ROMANOV	{"email": "romanov.m_03101965@postgrespro.ru", "phone": "+70123140508"}
0005434137693	4F3092	7331 067409	VLADIMIR VLASOV	{"email": "vlasov-v-111973@postgrespro.ru", "phone": "+70646441877"}
0005434137694	4F3092	1556 863977	RAFIK VASILEV	{"email": "rafik.vasilev_061981@postgrespro.ru", "phone": "+70401510467"}
0005434137695	B9E80A	4472 885121	OKSANA SEMENOVA	{"phone": "+70158947567"}
0005434137696	B9E80A	4301 852222	VALERIY FEDOTOV	{"phone": "+70702110958"}
0005434137697	992A8B	4610 147905	SERGEY POPOV	{"phone": "+70089627949"}
0005434137698	2EBC27	6586 590068	MIKHAIL SCHERBAKOV	{"email": "scherbakov.mikhail.1971@postgrespro.ru", "phone": "+70398098301"}
0005434137699	316011	4300 177906	LYUDMILA FOMINA	{"phone": "+70214690917"}
0005434137700	4B3380	3032 803491	EVGENIY GORBUNOV	{"phone": "+70239271294"}
0005434137701	4B3380	4004 848432	EVA KOZLOVA	{"email": "kozlova-e.23111959@postgrespro.ru", "phone": "+70650562040"}
0005434137702	0A049B	3300 482157	NIKOLAY MATVEEV	{"email": "n_matveev.16061980@postgrespro.ru", "phone": "+70842512089"}
0005434137703	99D5FB	3742 910802	ARTEM KULIKOV	{"phone": "+70519014532"}
0005434137704	2FCD1C	1301 999322	ANDREY VLASOV	{"email": "a-vlasov_25121970@postgrespro.ru", "phone": "+70088144758"}
0005434137705	2FCD1C	4618 295410	LARISA BOGDANOVA	{"email": "bogdanova_larisa.021973@postgrespro.ru", "phone": "+70572958860"}
0005434137706	2FCD1C	2096 335550	OLGA GUSEVA	{"email": "guseva-olga.19051975@postgrespro.ru", "phone": "+70209129739"}
0005434137707	CBFF70	4776 157730	VADIM FOMIN	{"email": "v_fomin-021971@postgrespro.ru", "phone": "+70697031570"}
0005434137708	20154B	2181 771714	ANATOLIY SIDOROV	{"phone": "+70132968471"}
0005434137709	2B95DA	2645 969397	GALINA CHERNOVA	{"email": "galinachernova_1961@postgrespro.ru", "phone": "+70267918240"}
0005434137710	2B95DA	6788 681725	YULIYA KISELEVA	{"email": "yuliya_kiseleva_081967@postgrespro.ru", "phone": "+70888541105"}
0005434137711	83654D	4741 463838	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov06111976@postgrespro.ru", "phone": "+70199908320"}
0005434137712	83654D	7784 361804	ANDREY VOROBEV	{"email": "andrey.vorobev061974@postgrespro.ru", "phone": "+70943743473"}
0005434137713	87DCEF	9710 362584	DENIS SOLOVEV	{"phone": "+70331401487"}
0005434137714	8A2A4D	2846 894455	IRINA MEDVEDEVA	{"email": "medvedeva.irina-051965@postgrespro.ru", "phone": "+70145434813"}
0005434137715	54D3BD	8475 341333	ZAKHAR SEMENOV	{"email": "semenov_z.1976@postgrespro.ru", "phone": "+70758193186"}
0005434137716	54D3BD	7283 845001	NADEZHDA EGOROVA	{"phone": "+70747332465"}
0005434137717	54D3BD	7903 004816	VLADIMIR SEMENOV	{"email": "semenov_v.081964@postgrespro.ru", "phone": "+70234016364"}
0005434137718	E1559A	1801 334755	NIKITA SOKOLOV	{"email": "n-sokolov.25071966@postgrespro.ru", "phone": "+70133756105"}
0005434137719	4D20CE	6297 630437	LYAYSAN NOVIKOVA	{"phone": "+70477955780"}
0005434137720	4D20CE	5008 480777	LARISA ORLOVA	{"email": "larisa-orlova-12081978@postgrespro.ru", "phone": "+70988287016"}
0005434137721	4D20CE	5470 086426	VALENTINA DENISOVA	{"email": "denisova.v.14041963@postgrespro.ru", "phone": "+70468026311"}
0005434137722	6C9C7B	3013 217210	MARINA NIKOLAEVA	{"email": "nikolaeva.m.12121974@postgrespro.ru", "phone": "+70258295988"}
0005434137723	6C9C7B	2892 863752	ALEKSEY GERASIMOV	{"phone": "+70582803180"}
0005434137724	6C9C7B	8783 968451	NIKITA FROLOV	{"email": "frolov.n1969@postgrespro.ru", "phone": "+70130272177"}
0005434137725	7E40B2	4318 690214	ALEKSANDR MOROZOV	{"email": "morozovaleksandr1965@postgrespro.ru", "phone": "+70487625888"}
0005434137726	C1339F	9396 693618	NATALYA PETROVA	{"email": "n-petrova_121974@postgrespro.ru", "phone": "+70819332201"}
0005434137727	89CB90	2315 039727	ANATOLIY MELNIKOV	{"email": "melnikov.a_081983@postgrespro.ru", "phone": "+70608908791"}
0005434137728	6846EB	4986 644960	ALEKSEY SERGEEV	{"email": "sergeev-a-1962@postgrespro.ru", "phone": "+70705491766"}
0005434137729	41467A	9281 659589	OLEG SOLOVEV	{"phone": "+70429514378"}
0005434137730	41467A	7946 622915	ARTUR FEDOTOV	{"phone": "+70836151879"}
0005434137731	41467A	8863 173107	SERGEY IVANOV	{"email": "ivanovsergey21051963@postgrespro.ru", "phone": "+70142589587"}
0005434137732	421692	6421 636665	SERGEY OSIPOV	{"phone": "+70893439644"}
0005434137733	421692	4178 276383	NINA BELYAEVA	{"email": "belyaeva_nina.24051982@postgrespro.ru", "phone": "+70378204317"}
0005434137734	A7C6ED	6992 051390	VENERA KUZNECOVA	{"email": "kuznecovav.1973@postgrespro.ru", "phone": "+70149492408"}
0005434137735	A7C6ED	6425 310385	ANDREY AFANASEV	{"phone": "+70379469878"}
0005434137736	A7C6ED	4758 513161	IVAN ZAYCEV	{"email": "zaycev-ivan.091976@postgrespro.ru", "phone": "+70815801163"}
0005434137737	12B7A9	4486 342811	NIKITA SOROKIN	{"email": "sorokin.nikita.13041976@postgrespro.ru", "phone": "+70643446060"}
0005434137738	12B7A9	5606 511755	ALEKSANDR IVANOV	{"email": "ivanov.a.16091967@postgrespro.ru", "phone": "+70037461303"}
0005434137740	F7EE8B	2301 557038	VALENTINA ORLOVA	{"phone": "+70572605814"}
0005434137741	06E8A1	3539 005396	MARIYA POTAPOVA	{"phone": "+70077389475"}
0005434137742	644795	9951 163670	REGINA ALEKSEEVA	{"phone": "+70450503591"}
0005434137743	C5E1CB	3242 084341	VIKTOR SEMENOV	{"email": "semenov-v.22011983@postgrespro.ru", "phone": "+70787493419"}
0005434137744	99564F	9745 454641	NADEZHDA ZAKHAROVA	{"email": "zakharova.n_31051979@postgrespro.ru", "phone": "+70037999746"}
0005434137745	99564F	0760 353320	RAISA AFANASEVA	{"email": "raisa_afanaseva-01031982@postgrespro.ru", "phone": "+70029812342"}
0005434137746	33F002	7792 042957	MARAT FOMIN	{"phone": "+70139045351"}
0005434137747	ADD210	4052 635546	ELIZAVETA KONOVALOVA	{"email": "e_konovalova.091974@postgrespro.ru", "phone": "+70654998553"}
0005434137748	ADD210	6919 412690	TATYANA DAVYDOVA	{"email": "t_davydova.1969@postgrespro.ru", "phone": "+70732422393"}
0005434137749	368E05	6978 486541	YURIY SAVELEV	{"phone": "+70081214059"}
0005434137750	D22A52	8997 207339	IRINA SEMENOVA	{"email": "semenova-irina-1980@postgrespro.ru", "phone": "+70117919159"}
0005434137751	0537DE	6342 196343	EVGENIY NIKITIN	{"email": "enikitin.09041969@postgrespro.ru", "phone": "+70495363198"}
0005434137752	A4D611	6645 016398	NATALYA FILIPPOVA	{"phone": "+70247079161"}
0005434137753	A6363C	8767 715972	TATYANA SAVELEVA	{"phone": "+70108558427"}
0005434137754	50434D	7124 585196	IVAN FOMIN	{"phone": "+70825413126"}
0005434137755	50434D	1105 884761	ALEKSANDR OSIPOV	{"phone": "+70222182515"}
0005434137756	75C315	3002 486090	LYUBOV MAKSIMOVA	{"email": "lyubov-maksimova_091964@postgrespro.ru", "phone": "+70604597212"}
0005434137757	057EB6	1911 042991	IVAN MIKHAYLOV	{"phone": "+70289368197"}
0005434137758	F038D8	6365 623657	SVETLANA NAUMOVA	{"phone": "+70369010564"}
0005434137759	EBD952	6182 415484	VALERIY VOLKOV	{"email": "v.volkov-101968@postgrespro.ru", "phone": "+70880283626"}
0005434137760	EBD952	3162 525037	YULIYA ALEKSEEVA	{"phone": "+70375156007"}
0005434137761	4C327C	6236 452295	YURIY VOROBEV	{"phone": "+70731853908"}
0005434137762	4C327C	7953 158608	OLGA TROFIMOVA	{"email": "trofimova-o_1972@postgrespro.ru", "phone": "+70611012051"}
0005434137763	0C80D3	5631 286449	IVAN ORLOV	{"email": "i_orlov.1976@postgrespro.ru", "phone": "+70049215007"}
0005434137764	0C80D3	0868 462436	KSENIYA POPOVA	{"email": "kpopova.07091976@postgrespro.ru", "phone": "+70539773512"}
0005434137765	A987FF	6432 496305	MATVEY VOLKOV	{"phone": "+70931075249"}
0005434137766	D238F0	3825 299305	ANASTASIYA MALYSHEVA	{"email": "anastasiya-malysheva_21111978@postgrespro.ru", "phone": "+70865825699"}
0005434137767	D238F0	1807 513095	IVAN PETROV	{"email": "petrovi.14081973@postgrespro.ru", "phone": "+70675906432"}
0005434137768	D238F0	8314 638416	NINA RODIONOVA	{"email": "rodionova-nina021983@postgrespro.ru", "phone": "+70253260774"}
0005434137769	BC1204	9235 532409	NINA ABRAMOVA	{"email": "ninaabramova.1984@postgrespro.ru", "phone": "+70351313776"}
0005434137770	DD80B6	2811 904828	GENNADIY KUZNECOV	{"phone": "+70074764740"}
0005434137771	D01884	5800 095142	IVAN BONDARENKO	{"phone": "+70768825048"}
0005434137772	F1C296	9360 182282	MAKSIM MIKHAYLOV	{"phone": "+70204466256"}
0005434137773	77C147	9851 291783	ANATOLIY ALEKSANDROV	{"email": "anatoliyaleksandrov.14101989@postgrespro.ru", "phone": "+70176675375"}
0005434137941	5C33B4	8580 976289	ANATOLIY SAVELEV	{"phone": "+70799879490"}
0005434137774	3F1FB5	2007 650246	NIKOLAY FOMIN	{"email": "n.fomin_1976@postgrespro.ru", "phone": "+70883515400"}
0005434137775	3F1FB5	2185 106336	MARINA SIDOROVA	{"email": "sidorovam1975@postgrespro.ru", "phone": "+70125112416"}
0005434137776	E4934A	7837 386582	MARIYA KRASNOVA	{"phone": "+70184591676"}
0005434137777	1EDF44	0816 036132	NIKOLAY POPOV	{"phone": "+70992792459"}
0005434137778	6FF2D9	8559 086804	OLGA ALEKSANDROVA	{"phone": "+70926437341"}
0005434137779	2225C2	0474 383882	NATALYA SOROKINA	{"email": "natalya_sorokina-111968@postgrespro.ru", "phone": "+70609625626"}
0005434137780	2225C2	3067 538080	EVGENIY MEDVEDEV	{"phone": "+70411644128"}
0005434137781	57A8D3	5655 203155	IVAN NOVIKOV	{"phone": "+70031992367"}
0005434137782	57A8D3	2706 589261	SOFIYA NIKOLAEVA	{"email": "nikolaeva.s-09081968@postgrespro.ru", "phone": "+70475826906"}
0005434137783	57A8D3	6769 241288	VLADIMIR STEPANOV	{"phone": "+70043523509"}
0005434137784	B589A3	1068 515570	MIKHAIL FROLOV	{"email": "mikhail_frolov-011974@postgrespro.ru", "phone": "+70932640476"}
0005434137785	DA6CEF	1378 179109	TAMARA AKIMOVA	{"phone": "+70829282631"}
0005434137786	DA6CEF	4414 039231	MARIYA BOGDANOVA	{"phone": "+70167521415"}
0005434137787	1CFDC1	3100 079081	TATYANA VASILEVA	{"phone": "+70383315637"}
0005434137788	ECF499	1121 455606	SERGEY KUZNECOV	{"email": "kuznecov.sergey01111968@postgrespro.ru", "phone": "+70850238109"}
0005434137789	ECF499	0705 608521	TATYANA MAKAROVA	{"email": "tatyana.makarova-30111970@postgrespro.ru", "phone": "+70124066461"}
0005434137790	D96767	9558 224524	VERA POPOVA	{"email": "verapopova_071979@postgrespro.ru", "phone": "+70111408032"}
0005434137791	CCD8E6	4632 592325	VLADIMIR SCHERBAKOV	{"email": "scherbakovv_041972@postgrespro.ru", "phone": "+70529163325"}
0005434137792	A0E211	3962 728037	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir_011966@postgrespro.ru", "phone": "+70778840089"}
0005434137793	DA4D9D	0979 413367	DMITRIY SOROKIN	{"email": "dmitriy_sorokin_061975@postgrespro.ru", "phone": "+70880745036"}
0005434137794	A525D4	7705 288619	VALENTINA LOGINOVA	{"phone": "+70181524150"}
0005434137795	CB222B	4681 673576	OLGA PAVLOVA	{"email": "olga-pavlova.1983@postgrespro.ru", "phone": "+70168238660"}
0005434137796	D1B112	2739 150645	ANDREY SIDOROV	{"email": "asidorov.051967@postgrespro.ru", "phone": "+70108786468"}
0005434137797	D1B112	9220 406092	LYUBOV AKIMOVA	{"email": "akimova-l-29101963@postgrespro.ru", "phone": "+70935302643"}
0005434137798	7B7720	2794 239142	ANTONINA KULIKOVA	{"email": "kulikova.a.011970@postgrespro.ru", "phone": "+70963287950"}
0005434137799	A68F4F	7561 503732	ALEKSANDRA KARPOVA	{"phone": "+70581982285"}
0005434137801	40D799	3004 747877	ANATOLIY FROLOV	{"email": "frolov.anatoliy_1955@postgrespro.ru", "phone": "+70347350061"}
0005434137802	FCF379	2445 543076	ALEKSANDRA ZOTOVA	{"email": "zotovaa.081970@postgrespro.ru", "phone": "+70992263622"}
0005434137803	B89506	1086 287951	ELENA KONOVALOVA	{"email": "ekonovalova.10041974@postgrespro.ru", "phone": "+70982339974"}
0005434137804	B89506	8161 800130	EKATERINA SOROKINA	{"email": "sorokina-ekaterina24041976@postgrespro.ru", "phone": "+70554721899"}
0005434137805	B89506	1266 579607	ALENA ZAKHAROVA	{"email": "zakharova.a.121969@postgrespro.ru", "phone": "+70592614736"}
0005434137806	279690	3114 546348	EVGENIY FILIPPOV	{"phone": "+70605547873"}
0005434137807	EA5036	2809 284882	ARTEM ZHURAVLEV	{"phone": "+70446100639"}
0005434137808	EA5036	1621 861199	OLEG MIRONOV	{"email": "mironov-oleg_091978@postgrespro.ru", "phone": "+70279370230"}
0005434137809	EA5036	7115 714190	DINARA KOROLEVA	{"phone": "+70117961659"}
0005434137810	BE577E	9958 220456	OLGA STEPANOVA	{"email": "o.stepanova.02041968@postgrespro.ru", "phone": "+70856477586"}
0005434137811	BE577E	3236 717591	SERGEY GERASIMOV	{"phone": "+70921846511"}
0005434137812	9D8E61	5002 920758	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga.081972@postgrespro.ru", "phone": "+70275190925"}
0005434137813	F4CE64	7232 729150	NADEZHDA PETROVA	{"phone": "+70523191994"}
0005434137814	545CA4	2888 130948	VLADIMIR ORLOV	{"phone": "+70715398829"}
0005434137815	545CA4	1692 878043	IVAN ILIN	{"phone": "+70431532350"}
0005434137816	545CA4	8670 777066	KRISTINA DENISOVA	{"email": "denisova-kristina_031970@postgrespro.ru", "phone": "+70056666976"}
0005434137817	7D1AA9	3191 340354	OLGA POPOVA	{"email": "popova_o_041964@postgrespro.ru", "phone": "+70427605990"}
0005434137818	FB7A36	4206 186905	VLADIMIR NIKOLAEV	{"phone": "+70318091221"}
0005434137819	3278F2	1448 789374	ALEKSANDRA KOROLEVA	{"phone": "+70768045463"}
0005434137820	3278F2	3254 932956	YULIYA SIDOROVA	{"email": "sidorova.yuliya.1982@postgrespro.ru", "phone": "+70580229837"}
0005434137821	3278F2	7043 907800	SVETLANA MAKSIMOVA	{"phone": "+70549577813"}
0005434137822	A5873A	4917 276894	KONSTANTIN ZHUKOV	{"email": "zhukov.k-1964@postgrespro.ru", "phone": "+70725351627"}
0005434137823	FF99AD	6266 767283	NIKOLAY SMIRNOV	{"phone": "+70061877148"}
0005434137824	FF99AD	9531 752482	OLGA KAZAKOVA	{"phone": "+70265742644"}
0005434137825	5A7EA5	6020 417947	YAKOV VOLKOV	{"phone": "+70413519171"}
0005434137826	91D13F	8717 663504	DARYA ZOTOVA	{"email": "zotova.d_1969@postgrespro.ru", "phone": "+70568797039"}
0005434137827	1E2B34	7235 710113	VIKTOR MIKHAYLOV	{"phone": "+70099555689"}
0005434137828	EE5090	5866 457294	PELAGEYA DENISOVA	{"phone": "+70076299880"}
0005434137829	D84763	5004 063914	ANDREY KUZMIN	{"email": "andrey.kuzmin-05101960@postgrespro.ru", "phone": "+70987110016"}
0005434137830	D84763	3268 495082	OLESYA BARANOVA	{"email": "olesya.baranova.1973@postgrespro.ru", "phone": "+70155574108"}
0005434137831	989334	4237 243885	ELENA KUZMINA	{"email": "kuzmina.elena071974@postgrespro.ru", "phone": "+70748662187"}
0005434137832	AE6DDC	5581 230676	ARKADIY KUDRYASHOV	{"phone": "+70901923692"}
0005434137833	AE6DDC	7109 343634	YULIYA MELNIKOVA	{"phone": "+70285106057"}
0005434137834	79400A	1476 830945	OLGA ABRAMOVA	{"email": "abramova_olga01121968@postgrespro.ru", "phone": "+70185482108"}
0005434137835	79400A	3029 866808	YURIY GERASIMOV	{"email": "ygerasimov_111963@postgrespro.ru", "phone": "+70606523002"}
0005434137836	03533A	2196 439642	ALEKSANDR TARASOV	{"phone": "+70390651426"}
0005434137837	03533A	7956 663136	GALINA GERASIMOVA	{"email": "galinagerasimova.1963@postgrespro.ru", "phone": "+70465597645"}
0005434137838	829A46	2015 250688	SVETLANA IVANOVA	{"email": "ivanova.s_1963@postgrespro.ru", "phone": "+70402754831"}
0005434137839	30EF80	9221 556964	KSENIYA KOROLEVA	{"phone": "+70766409736"}
0005434137840	30EF80	5515 506061	LILIYA ANTONOVA	{"email": "antonova-liliya1974@postgrespro.ru", "phone": "+70103125664"}
0005434137841	75EAC9	5915 236975	ELENA KAZAKOVA	{"phone": "+70873478602"}
0005434137842	75EAC9	3712 170657	EVGENIY GAVRILOV	{"email": "gavrilov-e-111975@postgrespro.ru", "phone": "+70678068838"}
0005434137843	FD550C	1605 519294	EKATERINA KRASNOVA	{"phone": "+70362913843"}
0005434137844	0DA379	7899 305736	ANTON FROLOV	{"email": "a.frolov111969@postgrespro.ru", "phone": "+70633979155"}
0005434137845	6069C7	9077 447442	ANTON FILIPPOV	{"phone": "+70053453796"}
0005434137846	AA6C8F	1470 316034	SERGEY OSIPOV	{"email": "s.osipov1969@postgrespro.ru", "phone": "+70907979757"}
0005434137847	A9039F	7124 624280	ZOYA SERGEEVA	{"email": "zoya.sergeeva101968@postgrespro.ru", "phone": "+70274363147"}
0005434137848	56E04A	3290 580149	VYACHESLAV NAUMOV	{"phone": "+70634409429"}
0005434137849	565FED	4774 456086	ELENA KOROLEVA	{"email": "koroleva.e-1981@postgrespro.ru", "phone": "+70338553456"}
0005434137850	565FED	9265 015341	LYUBOV SAVELEVA	{"phone": "+70776955001"}
0005434137851	7A6BBB	9066 173367	IRINA ILINA	{"email": "ilina-irina.1962@postgrespro.ru", "phone": "+70211520101"}
0005434137852	72CF94	4469 842006	YULIYA MOROZOVA	{"email": "y_morozova.02011970@postgrespro.ru", "phone": "+70507458647"}
0005434137853	72CF94	8683 103609	DMITRIY VOLKOV	{"phone": "+70198175998"}
0005434137854	72CF94	8319 341691	SERGEY DENISOV	{"email": "s_denisov-19111979@postgrespro.ru", "phone": "+70603248098"}
0005434137855	C79DA4	3415 060055	ELENA MOROZOVA	{"phone": "+70346739619"}
0005434137856	18B52B	6503 414075	LYUDMILA NIKOLAEVA	{"phone": "+70078972321"}
0005434137857	2B8994	0866 617194	ELENA KOZLOVA	{"phone": "+70684162096"}
0005434137858	0A1727	1366 806568	EKATERINA GRISHINA	{"email": "ekaterina.grishina_13111971@postgrespro.ru", "phone": "+70654187999"}
0005434137859	A1C1EB	0114 109111	MAKSIM PAVLOV	{"email": "m-pavlov.20091971@postgrespro.ru", "phone": "+70715797019"}
0005434137860	A244E8	2222 005769	ANDREY EGOROV	{"email": "egorov-a_1979@postgrespro.ru", "phone": "+70862237955"}
0005434137861	AFF084	4379 739417	ANATOLIY ILIN	{"email": "a_ilin-1967@postgrespro.ru", "phone": "+70243994353"}
0005434137862	F47F2F	2346 545157	RAISA KARPOVA	{"phone": "+70514173475"}
0005434137863	F47F2F	2484 670005	MATVEY MAKAROV	{"phone": "+70347244778"}
0005434137864	3C5AE2	9973 082603	SERGEY TIKHONOV	{"phone": "+70359219123"}
0005434137865	744932	4335 069427	ANDREY PETROV	{"email": "petrovandrey.1977@postgrespro.ru", "phone": "+70928207495"}
0005434137866	3D7EA4	3667 280448	VYACHESLAV KONOVALOV	{"email": "v_konovalov.06111977@postgrespro.ru", "phone": "+70579556801"}
0005434137867	FA3939	4728 417542	LYUDMILA SERGEEVA	{"email": "sergeeva.l.021977@postgrespro.ru", "phone": "+70984689153"}
0005434137868	FA3939	9122 403579	SERGEY KUZNECOV	{"phone": "+70034296203"}
0005434137869	DBF230	8899 167043	NADEZHDA EGOROVA	{"phone": "+70074669931"}
0005434137870	EF3497	5102 377672	MADINA CHERNOVA	{"email": "chernova_m051980@postgrespro.ru", "phone": "+70014053838"}
0005434137871	FEC0FA	6559 857055	DMITRIY AFANASEV	{"phone": "+70039664562"}
0005434137872	576430	6292 709476	LYUBOV ALEKSEEVA	{"email": "l-alekseeva_1971@postgrespro.ru", "phone": "+70309245552"}
0005434137873	2192AB	6310 683272	VADIM NAUMOV	{"phone": "+70450444689"}
0005434137874	5E371B	5952 970818	DMITRIY BELOV	{"phone": "+70688403629"}
0005434137875	5E371B	6885 690079	OLGA IVANOVA	{"phone": "+70558435027"}
0005434137876	5E371B	4729 225546	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev101964@postgrespro.ru", "phone": "+70594435320"}
0005434137877	ED1502	4125 616075	ANNA KUDRYASHOVA	{"phone": "+70497307871"}
0005434137878	941AD8	1639 464584	INNA PAVLOVA	{"phone": "+70881217562"}
0005434137879	941AD8	1076 141944	MARAT GORBUNOV	{"phone": "+70676160049"}
0005434137880	1EF1FD	3245 818266	OLGA SOROKINA	{"phone": "+70403601597"}
0005434137881	6082AE	6514 528079	ROZALIYA MARTYNOVA	{"phone": "+70421738213"}
0005434137882	6082AE	8949 548917	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a031972@postgrespro.ru", "phone": "+70441028299"}
0005434137883	6082AE	0781 556906	OLGA VOLKOVA	{"email": "ovolkova_061977@postgrespro.ru", "phone": "+70250183779"}
0005434137884	60786A	1979 613692	VALENTINA ZHURAVLEVA	{"email": "vzhuravleva_04041972@postgrespro.ru", "phone": "+70793939602"}
0005434137885	BEFC6A	7591 669703	SVETLANA MIRONOVA	{"phone": "+70697390454"}
0005434138112	DCE995	2872 124568	ANNA RYABOVA	{"phone": "+70229368982"}
0005434137886	CCA63B	0996 957416	VYACHESLAV SEMENOV	{"email": "vsemenov.1979@postgrespro.ru", "phone": "+70709248005"}
0005434137887	2985C7	9359 596967	ANTONINA LAZAREVA	{"phone": "+70839050299"}
0005434137888	2985C7	5000 613482	VLADIMIR ROMANOV	{"email": "vladimir-romanov_1970@postgrespro.ru", "phone": "+70514961522"}
0005434137889	886661	4450 034626	VLADIMIR IVANOV	{"email": "v-ivanov_24071967@postgrespro.ru", "phone": "+70698611872"}
0005434137890	E0BB89	7377 817345	VYACHESLAV VOROBEV	{"email": "vorobev.vyacheslav121969@postgrespro.ru", "phone": "+70318215326"}
0005434137891	3018D9	6156 730094	GALINA SMIRNOVA	{"phone": "+70283111491"}
0005434137892	3018D9	4050 429594	IRINA KUZNECOVA	{"email": "kuznecova_irina041975@postgrespro.ru", "phone": "+70682282628"}
0005434137893	7216E5	9494 018231	VLADISLAV IVANOV	{"phone": "+70690302224"}
0005434137894	7216E5	4054 525525	IGOR TIMOFEEV	{"phone": "+70300110131"}
0005434137895	2158A6	3895 805227	VLADIMIR STEPANOV	{"email": "vladimir.stepanov09021980@postgrespro.ru", "phone": "+70444071962"}
0005434137896	41A85C	3148 532195	NINA IVANOVA	{"email": "ivanova-nina-1979@postgrespro.ru", "phone": "+70494132035"}
0005434137897	2A89DE	1742 252419	ZOYA KISELEVA	{"email": "zkiseleva.06101969@postgrespro.ru", "phone": "+70464914552"}
0005434137898	79EE3E	2090 563655	VERA KOZLOVA	{"email": "kozlovavera_1970@postgrespro.ru", "phone": "+70248023355"}
0005434137899	3BD016	2281 363372	DMITRIY ANDREEV	{"phone": "+70180796564"}
0005434137900	BF13C0	0224 167138	DMITRIY SMIRNOV	{"phone": "+70917116983"}
0005434137901	102ADB	1326 768042	PETR KUZNECOV	{"email": "p_kuznecov.15041981@postgrespro.ru", "phone": "+70864241874"}
0005434137902	102ADB	8855 721280	TAMARA IVANOVA	{"email": "ivanova-t_031976@postgrespro.ru", "phone": "+70009542945"}
0005434137903	102ADB	6796 673607	KLAVDIYA PETROVA	{"email": "k_petrova-091975@postgrespro.ru", "phone": "+70081196010"}
0005434137904	102ADB	0526 798777	ANATOLIY FILIPPOV	{"email": "anatoliy-filippov-16091967@postgrespro.ru", "phone": "+70822931703"}
0005434137905	6446EB	2988 787618	MARIYA NESTEROVA	{"email": "nesterovamariya-16091971@postgrespro.ru", "phone": "+70106655117"}
0005434137906	6446EB	5791 593439	DARYA VLASOVA	{"email": "d.vlasova05091956@postgrespro.ru", "phone": "+70540714897"}
0005434137907	71CB98	9720 586945	ALEKSANDR FOMIN	{"phone": "+70242529390"}
0005434137908	71CB98	0082 886497	SERGEY SEMENOV	{"email": "s-semenov_1972@postgrespro.ru", "phone": "+70600402500"}
0005434137909	71CB98	3710 714585	TAMARA ORLOVA	{"email": "t_orlova_1970@postgrespro.ru", "phone": "+70130574896"}
0005434137910	219FAB	3421 693442	VASILIY KRASNOV	{"email": "krasnov_vasiliy_1972@postgrespro.ru", "phone": "+70688669435"}
0005434137911	477F2F	9947 803200	VALENTINA KUZNECOVA	{"phone": "+70438719827"}
0005434137912	477F2F	0813 659072	BORIS PAVLOV	{"phone": "+70350247184"}
0005434137913	832807	0218 899765	SVETLANA POPOVA	{"phone": "+70179208183"}
0005434137914	832807	2724 728730	GALINA DMITRIEVA	{"phone": "+70146084873"}
0005434137915	3B02F3	4007 781968	VIKTOR DAVYDOV	{"email": "davydov-v-051972@postgrespro.ru", "phone": "+70708746172"}
0005434137916	3B02F3	6274 153515	EKATERINA SOROKINA	{"phone": "+70881575267"}
0005434137917	1941AD	3021 880149	YULIYA KONDRATEVA	{"email": "yuliya-kondrateva021973@postgrespro.ru", "phone": "+70990003846"}
0005434137918	F1A422	3940 877913	NINA BORISOVA	{"email": "borisovan-071971@postgrespro.ru", "phone": "+70529202123"}
0005434137919	F1A422	0781 536969	SVETLANA EFIMOVA	{"phone": "+70237043434"}
0005434137920	0CA19C	4836 620941	TATYANA ORLOVA	{"phone": "+70529145059"}
0005434137921	0CA19C	7851 255837	MARIYA KONDRATEVA	{"email": "m-kondrateva31101965@postgrespro.ru", "phone": "+70695657080"}
0005434137922	0CA19C	8973 749782	VENERA NIKITINA	{"phone": "+70586380442"}
0005434137923	ED4AC2	0446 212172	NIKOLAY POPOV	{"email": "nikolay-popov.20021971@postgrespro.ru", "phone": "+70918622495"}
0005434137924	CBC8F3	7169 188681	TIMOFEY ALEKSANDROV	{"phone": "+70296312470"}
0005434137925	CBC8F3	9173 602077	SERGEY SCHERBAKOV	{"phone": "+70558008204"}
0005434137926	7D7EAB	6299 541946	DANILA NOVIKOV	{"phone": "+70078381411"}
0005434137927	798C81	6311 943761	VLADIMIR DENISOV	{"phone": "+70564627791"}
0005434137928	9D4E32	3445 432651	EKATERINA IVANOVA	{"email": "ivanova.ekaterina-121967@postgrespro.ru", "phone": "+70765043871"}
0005434137929	95BE48	3143 170545	ARTEM SERGEEV	{"email": "asergeev-27081976@postgrespro.ru", "phone": "+70721681886"}
0005434137930	5D5239	2697 207543	MIKHAIL SEMENOV	{"email": "semenov.mikhail_031978@postgrespro.ru", "phone": "+70861991552"}
0005434137931	A34CDE	9668 978780	RAISA SEMENOVA	{"email": "semenova-raisa_12101967@postgrespro.ru", "phone": "+70669286990"}
0005434137932	A34CDE	2859 648298	ANDREY BARANOV	{"phone": "+70374562383"}
0005434137933	241850	1166 875949	VIKTOR NOVIKOV	{"email": "novikov_v-1970@postgrespro.ru", "phone": "+70781303319"}
0005434137934	241850	6021 227620	ALEKSANDRA KUZNECOVA	{"email": "aleksandra-kuznecova.011976@postgrespro.ru", "phone": "+70619738677"}
0005434137935	9A3DDC	4696 120307	VASILIY KUZNECOV	{"phone": "+70861857004"}
0005434137936	3F2288	1058 280154	DMITRIY PETROV	{"phone": "+70712025330"}
0005434137937	27949A	2639 158456	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.12061979@postgrespro.ru", "phone": "+70755656399"}
0005434137938	27949A	9689 887403	ARTEM MOROZOV	{"email": "morozova_03081971@postgrespro.ru", "phone": "+70148912562"}
0005434137939	505835	1972 438689	NINA FEDOROVA	{"email": "n.fedorova_1970@postgrespro.ru", "phone": "+70172112778"}
0005434137940	505835	2164 392812	VASILIY ILIN	{"phone": "+70424237736"}
0005434137942	1A8800	3457 078893	ALEKSEY MIKHAYLOV	{"email": "alekseymikhaylov091972@postgrespro.ru", "phone": "+70026036670"}
0005434137943	9CFA30	1237 607489	ALINA MAKAROVA	{"phone": "+70698417489"}
0005434137944	B75840	5270 323382	ELIZAVETA KONOVALOVA	{"phone": "+70676646181"}
0005434137945	4FE744	1087 057314	YURIY YAKOVLEV	{"email": "yuriy.yakovlev1973@postgrespro.ru", "phone": "+70468108184"}
0005434137946	4FE744	8682 533419	ILYA KUZMIN	{"phone": "+70154258675"}
0005434137947	EB2DA0	6397 189104	ELENA NESTEROVA	{"phone": "+70768397925"}
0005434137948	EB2DA0	8219 445071	MARINA KISELEVA	{"email": "kiselevamarina.031965@postgrespro.ru", "phone": "+70336974800"}
0005434137949	4911CC	3057 658633	OLESYA GORBUNOVA	{"phone": "+70485338941"}
0005434137950	C69CED	0775 154185	NINA SMIRNOVA	{"email": "nsmirnova031968@postgrespro.ru", "phone": "+70788132297"}
0005434137951	785F9C	9606 986913	ANDREY KARPOV	{"email": "karpov.a_1981@postgrespro.ru", "phone": "+70565937162"}
0005434137952	2CAD7A	0973 251894	ELINA MEDVEDEVA	{"email": "medvedeva_e-03021976@postgrespro.ru", "phone": "+70178152262"}
0005434137953	68AC44	2191 593676	YAROSLAVA ZAKHAROVA	{"email": "y.zakharova-1983@postgrespro.ru", "phone": "+70127120177"}
0005434137954	43902D	2509 211934	LYUDMILA GERASIMOVA	{"phone": "+70365991062"}
0005434137955	6781C2	4625 869250	SVETLANA FILIPPOVA	{"phone": "+70038558603"}
0005434137956	280159	1396 759878	VYACHESLAV FEDOROV	{"email": "v-fedorov061982@postgrespro.ru", "phone": "+70734414663"}
0005434137957	2AAE15	8940 964409	TAMARA NESTEROVA	{"phone": "+70504399063"}
0005434137958	769753	7284 424918	VALENTINA SOKOLOVA	{"phone": "+70423061044"}
0005434137959	769753	8018 138800	EKATERINA POPOVA	{"email": "epopova1973@postgrespro.ru", "phone": "+70809624646"}
0005434137960	F6238A	0389 633127	IVAN NIKITIN	{"phone": "+70320157238"}
0005434137961	C51E2C	0827 540836	GALINA MEDVEDEVA	{"phone": "+70575446464"}
0005434137962	545624	0111 937067	VERA MASLOVA	{"email": "maslova-vera-21081970@postgrespro.ru", "phone": "+70916495551"}
0005434137963	64FBAD	6477 189667	LYUBOV KAZAKOVA	{"email": "lyubov-kazakova-05031971@postgrespro.ru", "phone": "+70098258348"}
0005434137964	6D92E6	1726 663441	VLADIMIR ZAYCEV	{"email": "zaycevvladimir091980@postgrespro.ru", "phone": "+70656547289"}
0005434137965	4DB199	8429 813836	NIKITA MARTYNOV	{"email": "martynov_nikita_1971@postgrespro.ru", "phone": "+70163067206"}
0005434137966	30D6FF	0243 673315	ANTON MIRONOV	{"phone": "+70508186949"}
0005434137967	282004	2789 728959	ALINA NOVIKOVA	{"email": "alina_novikova081965@postgrespro.ru", "phone": "+70979865830"}
0005434137968	282004	3493 173505	ALEKSANDRA KUZMINA	{"email": "aleksandra-kuzmina_051975@postgrespro.ru", "phone": "+70198359202"}
0005434137969	AF23A3	0104 673305	ALEKSANDRA MEDVEDEVA	{"phone": "+70475418166"}
0005434137970	E84148	4784 432276	NADEZHDA KOVALEVA	{"phone": "+70252718301"}
0005434137971	04DDC7	0929 703857	TATYANA FILIPPOVA	{"email": "filippovat1979@postgrespro.ru", "phone": "+70393001866"}
0005434137972	96C7D3	1216 578579	EGOR VOLKOV	{"email": "volkov-e-01061977@postgrespro.ru", "phone": "+70512917585"}
0005434137973	76CC1A	1676 922845	LYUBOV VASILEVA	{"phone": "+70827668547"}
0005434137974	F8C11D	9119 353332	LARISA NESTEROVA	{"email": "nesterova-l-011962@postgrespro.ru", "phone": "+70451728726"}
0005434137975	F8C11D	6528 930747	LIDIYA FROLOVA	{"email": "frolova_l.19121975@postgrespro.ru", "phone": "+70555838655"}
0005434137976	77E36B	0497 050457	NIKOLAY PETROV	{"email": "n-petrov1967@postgrespro.ru", "phone": "+70130981374"}
0005434137977	77E36B	1290 796609	ROZA DENISOVA	{"phone": "+70146081698"}
0005434137978	05F9D1	6520 945192	NATALYA TROFIMOVA	{"phone": "+70989910987"}
0005434137979	8656D5	8090 507530	ANDREY VLASOV	{"phone": "+70189197290"}
0005434137980	F72032	9375 753053	IRINA ABRAMOVA	{"email": "abramova_i29071988@postgrespro.ru", "phone": "+70627914549"}
0005434137981	0F510E	7879 999464	ANDREY MOROZOV	{"phone": "+70260906962"}
0005434137982	3C851E	9697 511792	ALEKSEY KUZMIN	{"phone": "+70439611225"}
0005434137983	036317	7234 893224	OKSANA MAKAROVA	{"email": "o-makarova1970@postgrespro.ru", "phone": "+70987131025"}
0005434137984	036317	4357 713802	VALENTINA RODIONOVA	{"phone": "+70126623292"}
0005434137985	2CABEE	7943 363633	YANA SERGEEVA	{"phone": "+70963985635"}
0005434137986	C3EF21	0480 085511	ANASTASIYA RODIONOVA	{"phone": "+70837658361"}
0005434137987	C11887	4403 686691	OLGA VOLKOVA	{"email": "olgavolkova_25031975@postgrespro.ru", "phone": "+70259927679"}
0005434137988	C11887	8674 297859	LIDIYA YAKOVLEVA	{"phone": "+70949895049"}
0005434137989	077918	2585 915349	NATALIYA DANILOVA	{"phone": "+70915733521"}
0005434137990	077918	6693 994097	NINA PAVLOVA	{"email": "pavlovan.081971@postgrespro.ru", "phone": "+70143108114"}
0005434137991	BF12DC	2820 360077	ARKADIY SHEVCHENKO	{"phone": "+70191466947"}
0005434137992	DF8DB6	3554 756277	VLADIMIR FOMIN	{"email": "vfomin.041967@postgrespro.ru", "phone": "+70327980169"}
0005434137993	599D57	2111 011280	VALENTINA KOROLEVA	{"phone": "+70209028946"}
0005434137994	599D57	8432 271723	GALINA CHERNOVA	{"phone": "+70391427126"}
0005434137995	48CD71	4741 138248	TATYANA SOROKINA	{"email": "sorokina_tatyana-121972@postgrespro.ru", "phone": "+70245629033"}
0005434137996	48CD71	5082 534834	VITALIY MAKAROV	{"email": "v-makarov_17081980@postgrespro.ru", "phone": "+70963077896"}
0005434137997	C67F68	7971 868905	ALEKSANDR GRIGOREV	{"email": "a.grigorev_25091959@postgrespro.ru", "phone": "+70391615991"}
0005434138113	C368DF	5557 450973	YULIYA PETROVA	{"phone": "+70329089803"}
0005434137998	E91795	6483 992238	OLEG FILIPPOV	{"email": "filippov.oleg_1978@postgrespro.ru", "phone": "+70483016718"}
0005434137999	F77F11	9581 486844	NADEZHDA SEMENOVA	{"email": "semenovanadezhda_061977@postgrespro.ru", "phone": "+70688180434"}
0005434138000	F77F11	6902 147759	GENNADIY NAUMOV	{"phone": "+70318668084"}
0005434138001	4DD17E	4106 210405	EVGENIY IVANOV	{"phone": "+70419869304"}
0005434138002	D7CAD7	5198 856827	ELENA GORBUNOVA	{"phone": "+70094085749"}
0005434138003	08C26B	6618 033938	ALEKSANDR SIDOROV	{"phone": "+70816089007"}
0005434138004	ECE4EF	6508 358481	MIKHAIL YAKOVLEV	{"email": "yakovlev-m-011960@postgrespro.ru", "phone": "+70181373427"}
0005434138005	ECE4EF	1212 215007	TATYANA BARANOVA	{"email": "tbaranova-19101977@postgrespro.ru", "phone": "+70709408684"}
0005434138006	A0E395	7443 985302	OLEG NIKITIN	{"email": "o_nikitin_081975@postgrespro.ru", "phone": "+70335298153"}
0005434138007	B4CF44	3924 383772	ALEKSEY MATVEEV	{"phone": "+70628323709"}
0005434138008	42537D	8788 988126	ELIZAVETA BELOVA	{"email": "belovaelizaveta031961@postgrespro.ru", "phone": "+70380826020"}
0005434138009	42537D	4251 595325	EKATERINA KUZNECOVA	{"phone": "+70919895264"}
0005434138010	F3569C	7805 330450	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr051967@postgrespro.ru", "phone": "+70092642787"}
0005434138011	F3569C	8743 428604	MARINA PETROVA	{"phone": "+70202907487"}
0005434138012	060D44	1554 994902	ARTEM KUZNECOV	{"phone": "+70468507134"}
0005434138013	E75E3C	1324 061583	ANNA GORBUNOVA	{"email": "a-gorbunova101963@postgrespro.ru", "phone": "+70548576061"}
0005434138014	0194BE	6178 363196	OKSANA TIMOFEEVA	{"phone": "+70511817061"}
0005434138015	0194BE	8634 490355	SVETLANA GAVRILOVA	{"email": "s.gavrilova-1970@postgrespro.ru", "phone": "+70631241129"}
0005434138016	ED7A01	2710 482040	SERGEY PETROV	{"email": "petrov-sergey-1974@postgrespro.ru", "phone": "+70217299826"}
0005434138017	ED7A01	4850 749020	ANDREY MIRONOV	{"email": "a_mironov-1977@postgrespro.ru", "phone": "+70882207994"}
0005434138018	ED7A01	7408 995322	ARTEM NAUMOV	{"phone": "+70724608733"}
0005434138019	7A69C1	1250 861805	SERGEY MELNIKOV	{"email": "melnikov-s1975@postgrespro.ru", "phone": "+70293650296"}
0005434138020	3476E0	7268 613265	KRISTINA DENISOVA	{"phone": "+70766093490"}
0005434138021	5CCED5	7552 193751	EKATERINA ABRAMOVA	{"phone": "+70251939975"}
0005434138022	82C391	8047 594518	YULIYA EGOROVA	{"email": "egorova_yuliya.031953@postgrespro.ru", "phone": "+70095576272"}
0005434138023	70CE36	0037 813878	ANZHELIKA NAZAROVA	{"email": "nazarovaanzhelika-11121974@postgrespro.ru", "phone": "+70483604582"}
0005434138024	656955	6354 777755	IRINA EFIMOVA	{"phone": "+70977482525"}
0005434138025	2F86C2	1433 781507	IRINA KOROLEVA	{"phone": "+70638578166"}
0005434138026	03B9E1	6455 692628	IRINA OVCHINNIKOVA	{"email": "ovchinnikova_i21081964@postgrespro.ru", "phone": "+70888700316"}
0005434138027	4CDFF3	6225 840973	ANNA AFANASEVA	{"phone": "+70736188506"}
0005434138028	4CDFF3	4625 599438	NAILYA KOZLOVA	{"phone": "+70523101603"}
0005434138029	554BC9	2587 519162	YURIY SMIRNOV	{"email": "smirnov_yuriy-12031968@postgrespro.ru", "phone": "+70872935495"}
0005434138030	61DF12	8585 223264	GALINA MOROZOVA	{"email": "galina-morozova-1978@postgrespro.ru", "phone": "+70967805433"}
0005434138031	166938	2037 531708	GENNADIY POPOV	{"phone": "+70270896461"}
0005434138032	AEF8ED	2341 645112	KONSTANTIN CHERNOV	{"email": "chernov-k_04011973@postgrespro.ru", "phone": "+70165006656"}
0005434138033	CC0489	4231 944340	ALEKSANDR KISELEV	{"phone": "+70035138673"}
0005434138034	DE0870	6929 134442	LILIYA SIDOROVA	{"phone": "+70656400748"}
0005434138035	6CED6C	1691 885544	MARINA FOMINA	{"phone": "+70052566285"}
0005434138036	11E0FD	2161 686810	YANA ISAEVA	{"phone": "+70905201866"}
0005434138037	11E0FD	7983 596099	ELENA STEPANOVA	{"phone": "+70796078068"}
0005434138038	B09BC1	9824 396635	EKATERINA AKIMOVA	{"phone": "+70396756979"}
0005434138039	2C97A5	9003 048858	SERGEY DAVYDOV	{"phone": "+70837316844"}
0005434138040	F11E2A	9357 886010	TAISIYA AFANASEVA	{"phone": "+70088827459"}
0005434138041	9BDAAF	2352 600858	SERGEY SERGEEV	{"phone": "+70612661927"}
0005434138042	9F2513	6096 226416	EGOR PETROV	{"phone": "+70329522515"}
0005434138043	DD9299	4256 609356	VALENTINA DENISOVA	{"phone": "+70136779063"}
0005434138044	DD9299	3499 217432	ANZHELA SMIRNOVA	{"phone": "+70552733330"}
0005434138045	2D1F0C	7159 904741	VASILIY SOKOLOV	{"phone": "+70908840233"}
0005434138046	2D1F0C	8632 154012	ELENA SCHERBAKOVA	{"email": "scherbakova.elena.25061970@postgrespro.ru", "phone": "+70733294804"}
0005434138047	C09B83	8064 647913	YULIYA PETROVA	{"email": "yuliyapetrova_021976@postgrespro.ru", "phone": "+70768673496"}
0005434138048	A7F4A5	9841 965689	SERGEY ZAKHAROV	{"email": "zakharovsergey_061983@postgrespro.ru", "phone": "+70156995980"}
0005434138049	A7F4A5	8832 592193	EMIL MARTYNOV	{"phone": "+70787835275"}
0005434138050	A7F4A5	4246 743946	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr_08071966@postgrespro.ru", "phone": "+70915077888"}
0005434138051	256980	5074 626192	VIKTOR VOLKOV	{"email": "vvolkov.23121971@postgrespro.ru", "phone": "+70742793013"}
0005434138052	220AF1	0381 825285	IVAN KAZAKOV	{"email": "ivan-kazakov_17081964@postgrespro.ru", "phone": "+70650920913"}
0005434138053	220AF1	4680 630474	PAVEL MAKSIMOV	{"email": "p.maksimov03051971@postgrespro.ru", "phone": "+70693699872"}
0005434138054	A37023	6159 956087	ALEKSEY ZAYCEV	{"email": "a_zaycev17041968@postgrespro.ru", "phone": "+70913487804"}
0005434138055	BB6A3A	0035 930120	SVETLANA FEDOROVA	{"email": "svetlanafedorova_031968@postgrespro.ru", "phone": "+70464182920"}
0005434138056	BB6A3A	1362 052963	PETR KOZLOV	{"phone": "+70430694440"}
0005434138057	58E3C0	6895 545110	VALERIY IVANOV	{"phone": "+70915466052"}
0005434138058	58E3C0	2748 335874	SERGEY SMIRNOV	{"phone": "+70246612922"}
0005434138059	CCB04E	5699 914437	EKATERINA ALEKSANDROVA	{"phone": "+70065213464"}
0005434138060	A9B71F	9262 084747	EVGENIY TARASOV	{"phone": "+70072448414"}
0005434138061	E99B94	5301 466362	IVAN MAKAROV	{"phone": "+70196614677"}
0005434138062	9EE577	5343 564608	ELENA KUZNECOVA	{"email": "kuznecovaelena26121972@postgrespro.ru", "phone": "+70090616662"}
0005434138063	6A9A8B	3880 423870	NATALYA LAZAREVA	{"phone": "+70766443778"}
0005434138064	572D21	9222 575801	VALENTINA DENISOVA	{"phone": "+70391356732"}
0005434138065	3E303C	8311 053215	SVETLANA ANTONOVA	{"phone": "+70183655370"}
0005434138066	C230DA	5865 711892	ALEKSEY KOROLEV	{"email": "koroleva-011978@postgrespro.ru", "phone": "+70531028421"}
0005434138067	C230DA	0494 056726	VLADIMIR MAKAROV	{"phone": "+70692482627"}
0005434138068	1F59F6	2521 316365	LIDIYA STEPANOVA	{"phone": "+70604153459"}
0005434138069	45A73D	6560 802575	NATALYA ROMANOVA	{"email": "natalya-romanova_071977@postgrespro.ru", "phone": "+70912814985"}
0005434138070	B04CFC	8122 784663	ALEKSEY KRASNOV	{"email": "krasnov_a-1987@postgrespro.ru", "phone": "+70713030668"}
0005434138071	AA6D52	0807 362786	EKATERINA SEMENOVA	{"email": "semenovaekaterina-12081965@postgrespro.ru", "phone": "+70703974129"}
0005434138072	AA6D52	7190 137128	RUMIYA KAZAKOVA	{"email": "kazakova-rumiya_25011974@postgrespro.ru", "phone": "+70327428434"}
0005434138073	D04ED0	6468 214692	GALINA RODIONOVA	{"email": "g.rodionova.121974@postgrespro.ru", "phone": "+70133418881"}
0005434138074	8ADFE3	0924 851900	ROMAN TIKHONOV	{"phone": "+70135058339"}
0005434138075	1A8C10	3211 937318	ANNA SIDOROVA	{"phone": "+70601587490"}
0005434138076	1A8C10	2075 196807	ANTONINA VLASOVA	{"phone": "+70840643906"}
0005434138077	244364	0488 673010	ELENA DENISOVA	{"phone": "+70580634197"}
0005434138078	5127A6	9883 975057	TATYANA EGOROVA	{"email": "egorovat061971@postgrespro.ru", "phone": "+70655524697"}
0005434138079	5127A6	3172 965192	TIMUR KUZNECOV	{"email": "kuznecov.t.1969@postgrespro.ru", "phone": "+70732681471"}
0005434138080	63E1D1	1033 329615	PAVEL NOVIKOV	{"phone": "+70349332521"}
0005434138081	35AD29	7880 044712	ALENA KALININA	{"phone": "+70210010202"}
0005434138082	35AD29	8300 508660	VIKTOR KUZNECOV	{"phone": "+70287844548"}
0005434138083	BFCB0F	6913 082803	TATYANA KOROLEVA	{"email": "korolevat17101975@postgrespro.ru", "phone": "+70170852895"}
0005434138084	C0BC78	4244 321732	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr-031980@postgrespro.ru", "phone": "+70572125455"}
0005434138085	4DC46E	6735 193676	VALENTINA SOROKINA	{"phone": "+70508969658"}
0005434138086	4DC46E	9069 814347	VASILIY MARTYNOV	{"phone": "+70450691208"}
0005434138087	B56F02	7591 700363	SERGEY ROMANOV	{"email": "romanov-s-041978@postgrespro.ru", "phone": "+70583736896"}
0005434138088	B56F02	1638 363414	MIKHAIL IVANOV	{"email": "mikhail_ivanov1968@postgrespro.ru", "phone": "+70539706777"}
0005434138089	F87E1C	4364 209992	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov-1965@postgrespro.ru", "phone": "+70455055076"}
0005434138090	F87E1C	7678 299718	ELENA SEMENOVA	{"phone": "+70134612798"}
0005434138091	F87E1C	2017 841422	VASILIY GUSEV	{"phone": "+70771335024"}
0005434138092	AC7AD2	4378 899036	ALEKSANDR SERGEEV	{"phone": "+70369600387"}
0005434138093	AC7AD2	4912 563764	MARIYA MARTYNOVA	{"phone": "+70733460641"}
0005434138094	5559CA	6023 152486	EVGENIY MELNIKOV	{"email": "emelnikov.121968@postgrespro.ru", "phone": "+70953218562"}
0005434138095	5559CA	3054 361060	MIKHAIL GAVRILOV	{"phone": "+70082291306"}
0005434138096	5559CA	8661 182910	TATYANA STEPANOVA	{"phone": "+70509610471"}
0005434138097	22D97F	1458 430448	ALEKSANDR GORBUNOV	{"email": "a_gorbunov.30121956@postgrespro.ru", "phone": "+70981240467"}
0005434138098	575408	4965 860000	ELENA TARASOVA	{"email": "tarasova.e17021987@postgrespro.ru", "phone": "+70190786979"}
0005434138099	575408	2076 227605	ILYA KOZLOV	{"email": "kozlov-i_13041963@postgrespro.ru", "phone": "+70123357553"}
0005434138100	B7A911	6592 405447	VALENTINA ZAYCEVA	{"email": "zaycevavalentina_111976@postgrespro.ru", "phone": "+70909331327"}
0005434138101	B7A911	4459 597545	ANDREY ZHUKOV	{"phone": "+70387014028"}
0005434138102	FA66CD	4384 402443	DMITRIY KOZLOV	{"email": "dkozlov_02031970@postgrespro.ru", "phone": "+70002476253"}
0005434138103	4B3974	3894 971866	ANATOLIY PAVLOV	{"phone": "+70860173857"}
0005434138104	4B3974	7248 033915	EVELINA POLYAKOVA	{"email": "polyakova_evelina.1972@postgrespro.ru", "phone": "+70256324099"}
0005434138105	7D0DEE	0667 016038	LEV MOISEEV	{"phone": "+70628976212"}
0005434138106	7D0DEE	7591 130337	EKATERINA FILATOVA	{"phone": "+70407295832"}
0005434138107	D2779D	9347 896998	NADEZHDA MASLOVA	{"email": "maslova.nadezhda_121979@postgrespro.ru", "phone": "+70727781894"}
0005434138108	6456A2	0860 081891	DMITRIY IVANOV	{"email": "d_ivanov.1973@postgrespro.ru", "phone": "+70790777211"}
0005434138109	6456A2	5738 715121	PAVEL EGOROV	{"phone": "+70780127540"}
0005434138110	6456A2	5352 853912	ALEKSANDR ROMANOV	{"email": "romanov_a_1967@postgrespro.ru", "phone": "+70924414801"}
0005434138111	4657D8	1506 556109	TATYANA KOZLOVA	{"phone": "+70830152577"}
0005434138114	94CB4D	1113 258362	EKATERINA AKIMOVA	{"phone": "+70103396037"}
0005434138115	8475DA	6616 571093	VALENTINA FROLOVA	{"phone": "+70289488485"}
0005434138116	6C5093	7341 589858	NATALYA EGOROVA	{"email": "egorova-n22051974@postgrespro.ru", "phone": "+70031139114"}
0005434138117	5EF45E	1366 847607	ALEKSANDR KUZNECOV	{"phone": "+70613148058"}
0005434138118	E0BE79	2235 925784	ALINA MARTYNOVA	{"email": "a.martynova_25081975@postgrespro.ru", "phone": "+70819581865"}
0005434138119	010CF4	4045 194939	VLADISLAV EGOROV	{"phone": "+70881075498"}
0005434138120	BD4DC7	2872 654706	YULIYA KARPOVA	{"phone": "+70620861602"}
0005434138121	A026F2	8830 805488	SVETLANA GUSEVA	{"phone": "+70865135513"}
0005434138122	81FAB9	1215 834553	SOFIYA POPOVA	{"email": "popova_s.1980@postgrespro.ru", "phone": "+70594662523"}
0005434138123	0A847A	0455 082552	ANASTASIYA SAVELEVA	{"email": "a.saveleva_1960@postgrespro.ru", "phone": "+70695848190"}
0005434138124	332F5E	5624 129159	ALISA AKIMOVA	{"email": "akimova.alisa051970@postgrespro.ru", "phone": "+70006403362"}
0005434138125	CC3EC3	5634 326942	NIKITA IVANOV	{"email": "ivanov.n31121962@postgrespro.ru", "phone": "+70288978106"}
0005434138126	1DA7C4	6221 684447	ANNA FOMINA	{"email": "fomina_a12091981@postgrespro.ru", "phone": "+70190105146"}
0005434138127	D8B0A1	4413 414309	VERA ANTONOVA	{"phone": "+70131823472"}
0005434138128	906CD5	6904 632987	YURIY MEDVEDEV	{"phone": "+70295528633"}
0005434138129	16B25E	8364 875595	KLAVDIYA ALEKSANDROVA	{"email": "aleksandrova.k.04081964@postgrespro.ru", "phone": "+70185362472"}
0005434138130	0E30C1	3199 667065	MARIYA MASLOVA	{"email": "maslova_mariya1980@postgrespro.ru", "phone": "+70150273140"}
0005434138131	0E30C1	5291 943534	DENIS IVANOV	{"phone": "+70104384412"}
0005434138132	0E30C1	4906 624011	LYUBOV ZAKHAROVA	{"email": "l-zakharova_1964@postgrespro.ru", "phone": "+70305151662"}
0005434138133	BDA75C	3771 842720	VALENTINA TARASOVA	{"email": "v_tarasova_011980@postgrespro.ru", "phone": "+70995375689"}
0005434138134	E1BBA7	3310 251460	SVETLANA IVANOVA	{"phone": "+70843752282"}
0005434138135	D62E23	4883 933138	NADEZHDA SOROKINA	{"email": "sorokinanadezhda031978@postgrespro.ru", "phone": "+70036505082"}
0005434138136	E861A2	2092 070567	VLADIMIR ZHUKOV	{"phone": "+70220169833"}
0005434138137	E861A2	3673 327164	ALEKSANDRA VASILEVA	{"phone": "+70399187472"}
0005434138138	A55E84	5204 408569	NADEZHDA FROLOVA	{"phone": "+70898917181"}
0005434138139	904318	1091 968580	OLEG ORLOV	{"email": "o.orlov18051981@postgrespro.ru", "phone": "+70755586244"}
0005434138140	154138	9373 111604	ZINAIDA ILINA	{"phone": "+70116027265"}
0005434138141	154138	7396 494328	ROMAN ANTONOV	{"email": "roman-antonov.1960@postgrespro.ru", "phone": "+70846130095"}
0005434138142	B4AA23	0129 612286	VALERIYA ZAKHAROVA	{"email": "zakharova.v-111962@postgrespro.ru", "phone": "+70161168661"}
0005434138143	DB1FD0	9348 946212	VALENTINA MAKSIMOVA	{"phone": "+70004958236"}
0005434138144	DB1FD0	6285 624642	ANASTASIYA ZAYCEVA	{"email": "anastasiya-zayceva13061989@postgrespro.ru", "phone": "+70584460767"}
0005434138145	510077	3448 798407	ARTEM SEMENOV	{"email": "artemsemenov011973@postgrespro.ru", "phone": "+70355498493"}
0005434138146	5AADCA	6441 341286	ANNA TITOVA	{"phone": "+70771544844"}
0005434138147	06D91D	1732 989045	OLGA POPOVA	{"phone": "+70227827899"}
0005434138148	7C1D03	1157 800278	PELAGEYA KUZNECOVA	{"phone": "+70875445580"}
0005434138149	7C1D03	2524 802844	LYUDMILA PETROVA	{"email": "lyudmila.petrova-071977@postgrespro.ru", "phone": "+70172162057"}
0005434138150	806AEF	2431 629419	VIKTORIYA KUDRYASHOVA	{"email": "kudryashova-viktoriya1975@postgrespro.ru", "phone": "+70486989231"}
0005434138151	806AEF	6469 604508	NATALYA KRASNOVA	{"email": "n.krasnova18051978@postgrespro.ru", "phone": "+70359700946"}
0005434138152	806AEF	9463 832938	TATYANA RODIONOVA	{"phone": "+70584650071"}
0005434138153	0BF829	1884 351697	ALEKSANDR ILIN	{"email": "ilin-aleksandr-071978@postgrespro.ru", "phone": "+70917599324"}
0005434138154	0BF829	3792 718736	TATYANA FOMINA	{"phone": "+70268407968"}
0005434138155	0BF829	1649 983640	LYUDMILA LUKYANOVA	{"email": "l.lukyanova_1960@postgrespro.ru", "phone": "+70382635989"}
0005434138156	0BF829	1301 444356	LEONID SERGEEV	{"email": "l-sergeev.1956@postgrespro.ru", "phone": "+70253900531"}
0005434138157	BFF0D8	3110 043400	OLEG MOISEEV	{"email": "o.moiseev101983@postgrespro.ru", "phone": "+70877174809"}
0005434138158	BFF0D8	5971 222437	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov_1971@postgrespro.ru", "phone": "+70090495936"}
0005434138159	CEE1E0	3150 371917	LYUBOV SOKOLOVA	{"phone": "+70062472353"}
0005434138160	CEE1E0	6660 294314	MARIYA CHERNOVA	{"email": "mchernova_041970@postgrespro.ru", "phone": "+70248082227"}
0005434138161	6B3231	1925 239796	SERGEY VLASOV	{"email": "vlasov-sergey-30071981@postgrespro.ru", "phone": "+70994601862"}
0005434138162	23BCAD	3829 649052	OLGA CHERNOVA	{"email": "chernova.olga.1968@postgrespro.ru", "phone": "+70981012212"}
0005434138163	23BCAD	1017 559584	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova_121964@postgrespro.ru", "phone": "+70367919281"}
0005434138164	43E9D3	9626 424995	ANTON KULIKOV	{"email": "kulikova-101957@postgrespro.ru", "phone": "+70025458742"}
0005434138165	43E9D3	7791 407444	ALEKSANDR AFANASEV	{"email": "afanasev.a.04091974@postgrespro.ru", "phone": "+70370342332"}
0005434138166	43E9D3	0342 148849	ANNA ALEKSEEVA	{"email": "alekseeva.anna17031982@postgrespro.ru", "phone": "+70814978978"}
0005434138167	2C6F9A	3698 763991	ELENA DMITRIEVA	{"email": "edmitrieva_1970@postgrespro.ru", "phone": "+70798297114"}
0005434138168	3CCBDE	2257 907707	DARYA EFIMOVA	{"email": "efimova_darya_01021974@postgrespro.ru", "phone": "+70902842095"}
0005434138169	0FDAD8	3112 880141	KONSTANTIN NOVIKOV	{"email": "k_novikov_031971@postgrespro.ru", "phone": "+70475147668"}
0005434138170	8E71E3	0716 043356	ALEKSEY KOROLEV	{"email": "akorolev-25021979@postgrespro.ru", "phone": "+70119606838"}
0005434138171	8E71E3	9235 375159	RAMIL OSIPOV	{"phone": "+70065195446"}
0005434138172	AF2870	4383 754699	SVETLANA NESTEROVA	{"email": "snesterova1965@postgrespro.ru", "phone": "+70923797830"}
0005434138173	3A6691	1180 592828	MARIYA PAVLOVA	{"email": "pavlova.mariya111966@postgrespro.ru", "phone": "+70070160739"}
0005434138174	FA0B08	8778 995560	MARINA ANTONOVA	{"phone": "+70552478179"}
0005434138175	FA0B08	5987 394762	NATALYA IVANOVA	{"phone": "+70540997497"}
0005434138176	0A438F	4901 457391	NIKOLAY SOLOVEV	{"email": "solovev-n101965@postgrespro.ru", "phone": "+70422642830"}
0005434138177	1008F1	7028 253149	OLGA FEDOROVA	{"email": "fedorova.olga101970@postgrespro.ru", "phone": "+70986972178"}
0005434138178	1008F1	8510 231155	EVGENIY MIKHAYLOV	{"email": "e-mikhaylov_1970@postgrespro.ru", "phone": "+70749545009"}
0005434138179	9F47B3	0155 242316	ILSHAT KULIKOV	{"email": "kulikov.ilshat.1960@postgrespro.ru", "phone": "+70539951117"}
0005434138180	E1725D	3287 572931	ELENA KONOVALOVA	{"email": "konovalova-e_081974@postgrespro.ru", "phone": "+70726726969"}
0005434138181	E1725D	6224 173822	ANDREY FROLOV	{"email": "a.frolov061969@postgrespro.ru", "phone": "+70151075440"}
0005434138182	C3B203	6160 052759	VYACHESLAV KUZNECOV	{"email": "kuznecovvyacheslav-1980@postgrespro.ru", "phone": "+70650475409"}
0005434138183	C3B203	6773 566794	VALENTINA ANDREEVA	{"phone": "+70800275962"}
0005434138184	E9BCFC	4560 504406	ELENA NAUMOVA	{"phone": "+70566425635"}
0005434138185	E9BCFC	8838 347493	ANNA EFIMOVA	{"email": "efimova-a.081970@postgrespro.ru", "phone": "+70061784341"}
0005434138186	637DE2	5231 240522	VLADIMIR KAZAKOV	{"email": "kazakov.v_111971@postgrespro.ru", "phone": "+70056063981"}
0005434138187	23BE39	9345 138437	YULIYA LAZAREVA	{"phone": "+70792360207"}
0005434138188	FF651E	6394 874578	ALEKSANDR TIMOFEEV	{"email": "timofeev_a_041969@postgrespro.ru", "phone": "+70359754629"}
0005434138189	FF651E	9975 098661	YURIY NIKOLAEV	{"email": "yuriynikolaev1970@postgrespro.ru", "phone": "+70099007422"}
0005434138190	FF651E	1069 326841	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila1962@postgrespro.ru", "phone": "+70818534970"}
0005434138191	8B19D8	0985 443386	VIKTOR IVANOV	{"phone": "+70615041523"}
0005434138192	09DBA7	2965 112210	ELENA ALEKSANDROVA	{"email": "e-aleksandrova-1963@postgrespro.ru", "phone": "+70017448063"}
0005434138193	8ED986	0404 889195	DMITRIY SHEVCHENKO	{"phone": "+70173715771"}
0005434138194	503428	5608 456756	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.31071966@postgrespro.ru", "phone": "+70191219980"}
0005434138195	478240	6539 898719	VERONIKA YAKOVLEVA	{"phone": "+70944608424"}
0005434138196	1FE793	3035 888154	ELENA SIDOROVA	{"phone": "+70632080460"}
0005434138197	248263	8900 589086	SERGEY SOROKIN	{"email": "sorokins_1985@postgrespro.ru", "phone": "+70761736617"}
0005434138198	7FD7EA	8253 206694	DARYA FROLOVA	{"email": "d_frolova_21031971@postgrespro.ru", "phone": "+70705931588"}
0005434138199	3D905A	4433 202477	STEPAN ABRAMOV	{"email": "abramov_stepan.1970@postgrespro.ru", "phone": "+70318159948"}
0005434138200	3D905A	5763 919763	YULIYA IVANOVA	{"phone": "+70090980086"}
0005434138201	6ED981	3647 684764	NATALYA IVANOVA	{"email": "natalya.ivanova_1962@postgrespro.ru", "phone": "+70882841809"}
0005434138202	6ED981	9945 737119	VLADIMIR KONOVALOV	{"email": "konovalov_v.17091977@postgrespro.ru", "phone": "+70378179183"}
0005434138203	7691DE	3281 025687	DARINA MIKHAYLOVA	{"phone": "+70683859837"}
0005434138204	40179E	4848 481380	EKATERINA MIRONOVA	{"phone": "+70743158470"}
0005434138205	B7BEF4	1109 205348	RAFAIL SCHERBAKOV	{"email": "rafail_scherbakov061976@postgrespro.ru", "phone": "+70446429878"}
0005434138206	95F23B	6226 018973	LYUBOV LUKYANOVA	{"email": "l-lukyanova1970@postgrespro.ru", "phone": "+70498392769"}
0005434138207	95F23B	7613 526247	LINAR VOROBEV	{"phone": "+70347368594"}
0005434138208	59812D	4526 288968	TATYANA MASLOVA	{"email": "tatyanamaslova-28041964@postgrespro.ru", "phone": "+70118010509"}
0005434138209	59812D	2631 449031	DMITRIY MEDVEDEV	{"email": "medvedev-dmitriy1989@postgrespro.ru", "phone": "+70945772260"}
0005434138210	80C4F3	3056 861473	OKSANA TARASOVA	{"email": "tarasova_oksana.121985@postgrespro.ru", "phone": "+70403550629"}
0005434138211	80C4F3	9452 239756	SERGEY MIRONOV	{"email": "mironov.s-1959@postgrespro.ru", "phone": "+70978302950"}
0005434138212	238713	2620 391506	VLADIMIR POPOV	{"phone": "+70081642796"}
0005434138213	CDB198	4438 429020	ALENA MELNIKOVA	{"email": "melnikova_a10071968@postgrespro.ru", "phone": "+70069777773"}
0005434138214	CDB198	6211 953351	ANASTASIYA BELOVA	{"email": "a-belova011972@postgrespro.ru", "phone": "+70783223262"}
0005434138215	B8F96C	6637 545866	ANATOLIY GRIGOREV	{"email": "anatoliy_grigorev_06021980@postgrespro.ru", "phone": "+70598293309"}
0005434138216	E80296	0640 015590	ELIZAVETA POTAPOVA	{"email": "e.potapova_1972@postgrespro.ru", "phone": "+70437904201"}
0005434138217	97012A	7782 994508	EVGENIY ANDREEV	{"email": "andreev-evgeniy041965@postgrespro.ru", "phone": "+70256480274"}
0005434138218	690A56	9685 071610	RUMIYA KUZNECOVA	{"email": "kuznecova_r061964@postgrespro.ru", "phone": "+70260893407"}
0005434138219	B77B02	7122 177019	MIKHAIL SCHERBAKOV	{"email": "m_scherbakov1977@postgrespro.ru", "phone": "+70397162037"}
0005434138220	B77B02	5126 771868	VLADIMIR DENISOV	{"phone": "+70637525698"}
0005434138221	2C275E	6226 615537	OLGA GRISHINA	{"phone": "+70554926936"}
0005434138222	899797	9551 274157	ALISA SAVELEVA	{"phone": "+70964350689"}
0005434138279	4A89ED	5276 927196	YURIY MOISEEV	{"phone": "+70275328295"}
0005434138223	E8122A	6418 255488	SERAFIMA MAKAROVA	{"email": "s-makarova.26081970@postgrespro.ru", "phone": "+70746692788"}
0005434138224	E8122A	3953 794834	DMITRIY KARPOV	{"email": "karpov.d.1982@postgrespro.ru", "phone": "+70729715537"}
0005434138225	B04D56	8857 315686	ELINA FEDOROVA	{"phone": "+70876702144"}
0005434138226	90F464	8072 959613	VALENTINA NESTEROVA	{"phone": "+70895709963"}
0005434138227	F7D8F6	7908 885724	NATALYA AKIMOVA	{"email": "akimova-natalya_1970@postgrespro.ru", "phone": "+70852562393"}
0005434138228	AF2B59	5082 554374	VALERIY MOROZOV	{"email": "valeriy.morozov.041965@postgrespro.ru", "phone": "+70599460744"}
0005434138229	AF2B59	9144 933098	EDUARD FOMIN	{"email": "e-fomin.22121966@postgrespro.ru", "phone": "+70760981082"}
0005434138230	33EF81	4794 076259	SERGEY ZAYCEV	{"phone": "+70564347960"}
0005434138231	33EF81	3195 978888	ELENA RODIONOVA	{"email": "e.rodionova-041964@postgrespro.ru", "phone": "+70796987065"}
0005434138232	33EF81	4209 378280	ALEKSEY ROMANOV	{"email": "a_romanov_021975@postgrespro.ru", "phone": "+70845803258"}
0005434138233	3F4B35	8109 805682	SERGEY ZAKHAROV	{"phone": "+70342050482"}
0005434138234	3F4B35	2849 215977	OLGA CHERNOVA	{"email": "olga-chernova_21121969@postgrespro.ru", "phone": "+70635581220"}
0005434138235	1D8C4D	8645 727445	ANTONINA EGOROVA	{"phone": "+70088590577"}
0005434138236	DDD4D7	0775 763878	VIKTOR PETROV	{"phone": "+70572118523"}
0005434138237	DDD4D7	2518 825823	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov1976@postgrespro.ru", "phone": "+70047995409"}
0005434138238	09581C	9629 237883	VLADIMIR PETROV	{"email": "petrov_vladimir041974@postgrespro.ru", "phone": "+70284387192"}
0005434138239	09581C	7534 115200	ANDREY KUZNECOV	{"phone": "+70308398732"}
0005434138240	0C9284	7863 719065	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev15091976@postgrespro.ru", "phone": "+70824465823"}
0005434138241	531DB2	4541 513004	LYUBOV CHERNOVA	{"email": "lyubovchernova-03081976@postgrespro.ru", "phone": "+70013300369"}
0005434138242	0E77DA	7030 927365	KAMILA SCHERBAKOVA	{"phone": "+70148373150"}
0005434138243	0E77DA	6532 203993	ANASTASIYA AFANASEVA	{"phone": "+70761935233"}
0005434138244	055EDF	5425 556536	NIKOLAY ANDREEV	{"email": "andreevn061962@postgrespro.ru", "phone": "+70790601356"}
0005434138245	055EDF	7904 539250	VIKTOR FROLOV	{"phone": "+70309464366"}
0005434138246	82C6B1	7194 981615	VLADIMIR SOROKIN	{"email": "v-sorokin15091984@postgrespro.ru", "phone": "+70109916012"}
0005434138247	C80241	7426 887218	NINA KALININA	{"phone": "+70142798713"}
0005434138248	477D09	0283 642470	VLADISLAV ANDREEV	{"email": "andreev_vladislav_1967@postgrespro.ru", "phone": "+70092852474"}
0005434138249	087091	1515 077658	MIKHAIL KUZMIN	{"phone": "+70843697558"}
0005434138250	6914C9	2956 647287	ELENA ZOTOVA	{"email": "zotova-elena26081971@postgrespro.ru", "phone": "+70913067141"}
0005434138251	0E3BC7	5370 355746	OLGA ZAKHAROVA	{"phone": "+70855740590"}
0005434138252	EA57C3	4873 603501	LARISA MELNIKOVA	{"email": "larisamelnikova_07051967@postgrespro.ru", "phone": "+70493563265"}
0005434138253	EA57C3	7104 395559	LEV VASILEV	{"phone": "+70551620924"}
0005434138254	C5637D	9232 098040	LYUDMILA ROMANOVA	{"email": "l-romanova25081965@postgrespro.ru", "phone": "+70538416210"}
0005434138255	A786AC	1565 536935	VLADIMIR BONDARENKO	{"phone": "+70687360679"}
0005434138256	A786AC	8347 781352	OLEG ZAYCEV	{"phone": "+70626992914"}
0005434138257	A786AC	0015 385560	NADEZHDA KAZAKOVA	{"phone": "+70447285338"}
0005434138258	786C4E	7243 017455	RADIK IVANOV	{"email": "ivanov-radik-18091957@postgrespro.ru", "phone": "+70867188461"}
0005434138259	1C5C6A	8446 846470	GALINA GUSEVA	{"email": "guseva.g041963@postgrespro.ru", "phone": "+70437388352"}
0005434138260	22681E	4696 236223	NATALYA ILINA	{"email": "ilinanatalya_1972@postgrespro.ru", "phone": "+70985072952"}
0005434138261	C4D25F	2100 884623	NIKOLAY MELNIKOV	{"email": "melnikov-n.10031975@postgrespro.ru", "phone": "+70041078805"}
0005434138262	6A6100	0473 820891	VYACHESLAV ALEKSEEV	{"email": "v.alekseev.1974@postgrespro.ru", "phone": "+70352735073"}
0005434138263	1AC5F2	1582 620184	NIKOLAY MOISEEV	{"phone": "+70417080573"}
0005434138264	BDA409	7329 257248	ELENA IVANOVA	{"email": "ivanova-elena.091965@postgrespro.ru", "phone": "+70359464571"}
0005434138265	72BDAA	0739 094467	ALEKSANDRA BORISOVA	{"phone": "+70152955395"}
0005434138266	09856A	3102 114317	ALEKSANDRA GUSEVA	{"email": "aleksandra.guseva_29041977@postgrespro.ru", "phone": "+70133147528"}
0005434138267	98E636	3038 035261	TATYANA KALININA	{"phone": "+70330240875"}
0005434138268	98E636	5161 903490	LYUDMILA ZHURAVLEVA	{"phone": "+70772346337"}
0005434138269	98E636	0034 416864	GENNADIY KOROLEV	{"phone": "+70484783091"}
0005434138270	A92E97	9190 043042	ALEKSANDR KULIKOV	{"phone": "+70931273628"}
0005434138271	9AC79D	7042 125538	SVETLANA KOZLOVA	{"phone": "+70082156132"}
0005434138272	1589D5	3624 973418	ELENA KONOVALOVA	{"email": "konovalovae21081979@postgrespro.ru", "phone": "+70408883952"}
0005434138273	1589D5	8154 918254	PAVEL RODIONOV	{"email": "rodionov_pavel20021972@postgrespro.ru", "phone": "+70124687633"}
0005434138274	6C1225	3975 693568	ARTEM SOROKIN	{"phone": "+70336539252"}
0005434138275	6C1225	3861 153946	TATYANA ANDREEVA	{"phone": "+70308564995"}
0005434138276	D92BF7	8201 844247	VYACHESLAV SAVELEV	{"email": "savelev.vyacheslav-01011963@postgrespro.ru", "phone": "+70163315259"}
0005434138277	38D681	4173 829445	SERGEY TIKHONOV	{"phone": "+70330846841"}
0005434138278	4162AF	8357 689959	LYUDMILA STEPANOVA	{"phone": "+70357655520"}
0005434138280	C0B30B	8770 529739	YURIY KUZMIN	{"email": "kuzmin-y.101958@postgrespro.ru", "phone": "+70395414289"}
0005434138281	9E4192	6383 691506	EMILIYA SIDOROVA	{"email": "sidorovaemiliya31071965@postgrespro.ru", "phone": "+70736929590"}
0005434138282	9E4192	6475 733975	ANNA ZOTOVA	{"phone": "+70859062943"}
0005434138283	9F786A	5585 792115	MARIYA ROMANOVA	{"email": "m.romanova_021973@postgrespro.ru", "phone": "+70647843269"}
0005434138284	9F786A	2765 248035	YULIYA SERGEEVA	{"phone": "+70083222808"}
0005434138285	41D5FA	0229 429997	GERMAN VASILEV	{"phone": "+70171297226"}
0005434138286	41D5FA	3920 808701	VASILIY MAKAROV	{"phone": "+70313885026"}
0005434138287	D5AB25	1750 517770	VLADIMIR VASILEV	{"email": "vladimirvasilev.06011974@postgrespro.ru", "phone": "+70248819769"}
0005434138288	D5AB25	0854 286786	NATALYA NIKOLAEVA	{"email": "n-nikolaeva071986@postgrespro.ru", "phone": "+70423184547"}
0005434138289	92C37C	9581 104424	NATALYA MAKSIMOVA	{"email": "maksimovan_031965@postgrespro.ru", "phone": "+70979492851"}
0005434138290	BA2A53	6945 602109	IGOR OSIPOV	{"phone": "+70964074076"}
0005434138291	569EB8	7434 136521	IRINA IVANOVA	{"phone": "+70697576148"}
0005434138292	569EB8	7424 589124	NIKOLAY KUZNECOV	{"phone": "+70173563211"}
0005434138293	FCE87B	8286 071781	ARTEM ANTONOV	{"email": "antonov.artem13101977@postgrespro.ru", "phone": "+70372037839"}
0005434138294	708820	1343 436404	ANDREY SOLOVEV	{"email": "andrey-solovev-1976@postgrespro.ru", "phone": "+70592591571"}
0005434138295	767052	6704 670167	ALEKSEY NIKITIN	{"email": "aleksey-nikitin-071969@postgrespro.ru", "phone": "+70865505385"}
0005434138296	C71800	1301 081888	IVAN KUZMIN	{"phone": "+70175445603"}
0005434138297	66D406	8212 544455	TATYANA SOKOLOVA	{"phone": "+70882444337"}
0005434138298	66D406	6027 244868	LEONID ALEKSANDROV	{"email": "l.aleksandrov.031971@postgrespro.ru", "phone": "+70772060140"}
0005434138299	2C2AB4	4644 664498	MAKSIM BONDARENKO	{"email": "bondarenko-maksim_1974@postgrespro.ru", "phone": "+70200921740"}
0005434138300	0D731E	7858 033854	MARIYA DENISOVA	{"email": "denisovamariya.19011965@postgrespro.ru", "phone": "+70601832564"}
0005434138301	0D731E	8642 257050	POLINA BARANOVA	{"email": "pbaranova051983@postgrespro.ru", "phone": "+70226110021"}
0005434138302	A57A78	7710 874539	DENIS MIKHAYLOV	{"email": "denismikhaylov_08031960@postgrespro.ru", "phone": "+70088642001"}
0005434138303	80B49E	8438 361606	ELENA ZAYCEVA	{"email": "zaycevaelena_22021964@postgrespro.ru", "phone": "+70687641115"}
0005434138304	91A86F	6765 813335	TAMARA SEMENOVA	{"email": "semenova-t091968@postgrespro.ru", "phone": "+70910485033"}
0005434138305	3C16A2	9031 196201	NINA DENISOVA	{"email": "denisova_n_29041975@postgrespro.ru", "phone": "+70013041714"}
0005434138306	2AED9A	3940 846425	VALERIY ROMANOV	{"phone": "+70890427620"}
0005434138307	2AED9A	5067 874168	RAMZIYA YUDINA	{"email": "ramziya_yudina-101967@postgrespro.ru", "phone": "+70332610537"}
0005434138308	48E719	2778 463506	ELENA PETROVA	{"email": "petrova_elena.051979@postgrespro.ru", "phone": "+70887692006"}
0005434138309	4ADDC7	2329 248875	ALEKSEY IVANOV	{"phone": "+70740174551"}
0005434138310	4ADDC7	9037 489071	ALEKSANDR NOVIKOV	{"phone": "+70273453332"}
0005434138311	510C8B	6929 211262	ALLA EGOROVA	{"email": "egorova.a_20061976@postgrespro.ru", "phone": "+70704139165"}
0005434138312	A81E6E	9620 681429	ELENA PETROVA	{"email": "elena-petrova.20011955@postgrespro.ru", "phone": "+70014140987"}
0005434138313	90DB0F	7445 342373	STEPAN ILIN	{"email": "ilin-stepan-021975@postgrespro.ru", "phone": "+70647578238"}
0005434138314	57BB5E	1526 986742	GALINA MOROZOVA	{"phone": "+70026245406"}
0005434138315	57BB5E	1644 515614	LIDIYA POPOVA	{"phone": "+70703246588"}
0005434138316	9EFCEA	0654 495666	OKSANA TARASOVA	{"email": "tarasova_o-18071978@postgrespro.ru", "phone": "+70107139964"}
0005434138317	9EFCEA	1736 788547	GALINA STEPANOVA	{"email": "stepanova.galina.30051971@postgrespro.ru", "phone": "+70521699400"}
0005434138318	9EFCEA	7141 743581	LIDIYA TROFIMOVA	{"phone": "+70674287785"}
0005434138319	53CE35	6173 733477	IGOR KUZNECOV	{"phone": "+70517807052"}
0005434138320	53CE35	5414 840943	MIKHAIL MOISEEV	{"phone": "+70045604305"}
0005434138321	CDEB79	7725 300406	ALEKSEY TIKHONOV	{"email": "a.tikhonov-081966@postgrespro.ru", "phone": "+70583959498"}
0005434138322	CDEB79	1146 957184	ALEKSANDR VASILEV	{"email": "avasilev.30031975@postgrespro.ru", "phone": "+70392564293"}
0005434138323	B36677	4736 925519	TATYANA CHERNOVA	{"phone": "+70506742346"}
0005434138324	B36677	5056 367121	SVETLANA RODIONOVA	{"email": "rodionova_s-1972@postgrespro.ru", "phone": "+70250855048"}
0005434138325	433840	9211 138339	NINA KUZNECOVA	{"email": "n-kuznecova_1960@postgrespro.ru", "phone": "+70568354806"}
0005434138326	3873F7	8982 124824	VLADIMIR ZAYCEV	{"phone": "+70083022463"}
0005434138327	E4FF1F	7819 911237	IRINA LOGINOVA	{"email": "i_loginova031977@postgrespro.ru", "phone": "+70621668304"}
0005434138328	F2B1EC	3988 526076	DIANA POLYAKOVA	{"email": "d_polyakova-11121970@postgrespro.ru", "phone": "+70526290130"}
0005434138329	BCB304	0982 722469	VASILIY KUZNECOV	{"email": "vasiliy.kuznecov1977@postgrespro.ru", "phone": "+70948964495"}
0005434138330	1EEF66	7253 856924	LILIYA AKIMOVA	{"email": "l_akimova_17101969@postgrespro.ru", "phone": "+70456495205"}
0005434138331	F4013B	3010 904517	IVAN OSIPOV	{"email": "osipov-i01081986@postgrespro.ru", "phone": "+70803551687"}
0005434138332	F4013B	2738 231364	TATYANA KAZAKOVA	{"email": "t.kazakova-011985@postgrespro.ru", "phone": "+70056751520"}
0005434138333	B0DF16	9053 041076	DENIS DAVYDOV	{"phone": "+70658984714"}
0005434138334	A3713A	7892 215826	YURIY ANDREEV	{"email": "andreevy041977@postgrespro.ru", "phone": "+70549025002"}
0005434138335	A3713A	1010 055243	INNA LAZAREVA	{"email": "inna.lazareva1981@postgrespro.ru", "phone": "+70019812392"}
0005434138336	F7D1F1	4292 961672	MARAT SAVELEV	{"email": "savelev.m-111977@postgrespro.ru", "phone": "+70921077882"}
0005434138337	F7D1F1	6918 156928	DMITRIY MOROZOV	{"email": "morozovd.1982@postgrespro.ru", "phone": "+70056382615"}
0005434138338	56B62E	7433 534730	BORIS FROLOV	{"email": "boris_frolov_021973@postgrespro.ru", "phone": "+70100231037"}
0005434138339	56B62E	5576 714264	ANASTASIYA POPOVA	{"phone": "+70024742778"}
0005434138340	1027C2	4141 226868	MARINA ZAKHAROVA	{"phone": "+70315191288"}
0005434138341	74FB18	7443 138507	VLADIMIR MAKAROV	{"email": "makarov.v_13101959@postgrespro.ru", "phone": "+70623911983"}
0005434138342	379184	6014 636366	ILYA CHERNOV	{"email": "chernov.i1981@postgrespro.ru", "phone": "+70224499591"}
0005434138343	21C36F	0939 120395	EVGENIY MOROZOV	{"phone": "+70371762953"}
0005434138344	6ABF6F	0512 716029	OKSANA VLASOVA	{"email": "vlasova_oksana-031966@postgrespro.ru", "phone": "+70128833689"}
0005434138345	EB2CCD	3447 208600	DMITRIY DENISOV	{"phone": "+70695180710"}
0005434138346	CE0CC6	9040 542528	ANDREY BORISOV	{"email": "a.borisov-041976@postgrespro.ru", "phone": "+70255727447"}
0005434138347	CE0CC6	3164 261721	ELENA KUZMINA	{"email": "e_kuzmina021970@postgrespro.ru", "phone": "+70824478874"}
0005434138348	848DA3	2850 361264	NIKOLAY VOLKOV	{"phone": "+70458995371"}
0005434138349	848DA3	4200 409101	ANASTASIYA TITOVA	{"phone": "+70157518743"}
0005434138350	FB015B	1038 628319	NADEZHDA ANTONOVA	{"email": "n.antonova.011967@postgrespro.ru", "phone": "+70272819605"}
0005434138351	FB015B	5203 592318	MARINA KISELEVA	{"email": "m.kiseleva.081983@postgrespro.ru", "phone": "+70553194504"}
0005434138352	09C710	8190 996155	ALEKSANDRA BELOVA	{"phone": "+70895451275"}
0005434138353	B2D770	7283 689323	TATYANA GUSEVA	{"phone": "+70310716992"}
0005434138354	B2D770	7070 129704	NATALYA SMIRNOVA	{"email": "natalya-smirnova.071968@postgrespro.ru", "phone": "+70972382417"}
0005434138355	098531	5017 474194	YULIYA GRISHINA	{"email": "grishina_y_051974@postgrespro.ru", "phone": "+70161202476"}
0005434138356	098531	0980 062877	NADEZHDA IVANOVA	{"email": "n_ivanova-1975@postgrespro.ru", "phone": "+70671462075"}
0005434138357	92EFEC	6081 366665	EKATERINA IVANOVA	{"phone": "+70886512181"}
0005434138358	92EFEC	6429 492985	SVETLANA ANTONOVA	{"phone": "+70393942517"}
0005434138359	9C7E68	6076 409673	OLGA TIMOFEEVA	{"email": "olga-timofeeva03081974@postgrespro.ru", "phone": "+70102917624"}
0005434138360	9C7E68	6305 842327	ANDREY ROMANOV	{"phone": "+70418413319"}
0005434138361	85DBE9	8458 589585	VLADIMIR ANDREEV	{"email": "vladimirandreev1984@postgrespro.ru", "phone": "+70413559559"}
0005434138362	3E2AC6	8746 936110	TAMARA MATVEEVA	{"email": "tamara_matveeva031978@postgrespro.ru", "phone": "+70362620468"}
0005434138363	993CFB	2282 038388	EKATERINA FEDOROVA	{"email": "fedorovaekaterina15041970@postgrespro.ru", "phone": "+70823334787"}
0005434138364	61EF7B	5039 484351	TATYANA SOLOVEVA	{"phone": "+70602987918"}
0005434138365	FAF3D2	7036 959577	ALEKSEY CHERNOV	{"email": "achernov_1974@postgrespro.ru", "phone": "+70494594702"}
0005434138366	BE9D6D	4892 601678	LYUDMILA NAZAROVA	{"phone": "+70303372580"}
0005434138367	8A3862	8960 608234	VITALIY KUZMIN	{"phone": "+70804169539"}
0005434138368	4DC19F	8429 806140	GEORGIY SCHERBAKOV	{"phone": "+70524173421"}
0005434138369	E5AE55	9337 589682	FELIKS FILIPPOV	{"phone": "+70314932997"}
0005434138370	C8F915	5763 995528	OLGA IVANOVA	{"email": "o.ivanova-13021967@postgrespro.ru", "phone": "+70877369659"}
0005434138371	C8F915	5678 540599	LIDIYA OVCHINNIKOVA	{"email": "lidiya_ovchinnikova-081967@postgrespro.ru", "phone": "+70606230645"}
0005434138372	9A0CB2	6979 555438	ELENA FILATOVA	{"phone": "+70375987484"}
0005434138373	9A0CB2	8154 450321	ALEKSEY NIKOLAEV	{"phone": "+70170301640"}
0005434138374	9A0CB2	2834 546531	MIKHAIL MIKHAYLOV	{"email": "mikhailmikhaylov111971@postgrespro.ru", "phone": "+70172502526"}
0005434138375	14DD1B	1574 676798	NINA TROFIMOVA	{"phone": "+70742501438"}
0005434138376	14DD1B	4520 315900	MAKSIM GUSEV	{"phone": "+70069576037"}
0005434138377	F14F3A	5721 849582	NIKITA SERGEEV	{"email": "n-sergeev02111974@postgrespro.ru", "phone": "+70106559263"}
0005434138378	F14F3A	0230 999066	ANTON KUZNECOV	{"phone": "+70044427795"}
0005434138379	F14F3A	4164 475627	PETR GORBUNOV	{"email": "petr-gorbunov121987@postgrespro.ru", "phone": "+70786057529"}
0005434138380	E27870	2366 228099	OLEG KARPOV	{"phone": "+70270131816"}
0005434138381	E27870	7471 585298	LYUDMILA SOROKINA	{"phone": "+70294675656"}
0005434138382	E27870	5486 727125	ANTON IVANOV	{"email": "ivanov.anton.1976@postgrespro.ru", "phone": "+70306270026"}
0005434138383	468766	7925 098850	VERONIKA DANILOVA	{"email": "v.danilova.1968@postgrespro.ru", "phone": "+70501330455"}
0005434138384	F2DADB	2601 986000	NADIYA BELOVA	{"phone": "+70985518141"}
0005434138385	906169	0556 435400	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva_1971@postgrespro.ru", "phone": "+70179762779"}
0005434138386	906169	0674 448830	DMITRIY ZAKHAROV	{"email": "zakharov-d_1982@postgrespro.ru", "phone": "+70086417984"}
0005434138387	6E7304	7286 209887	ALEKSEY NIKOLAEV	{"phone": "+70159125279"}
0005434138388	6E7304	8772 224031	TATYANA SIDOROVA	{"phone": "+70335884738"}
0005434138389	584413	1975 699790	VLADIMIR SEMENOV	{"phone": "+70503803509"}
0005434138390	ABFF52	9333 522761	DARYA KONDRATEVA	{"phone": "+70794118474"}
0005434138391	ABFF52	8683 533372	LYUDMILA MEDVEDEVA	{"email": "lyudmila-medvedeva-1961@postgrespro.ru", "phone": "+70659083864"}
0005434138392	E25CB9	2805 452482	IRINA KONDRATEVA	{"phone": "+70436887618"}
0005434138393	110A89	2404 592554	LIDIYA STEPANOVA	{"phone": "+70314198135"}
0005434138394	B49A38	9307 933996	SERGEY VOLKOV	{"phone": "+70488806630"}
0005434138395	CF8920	9636 105233	MAKSIM SIDOROV	{"phone": "+70626369666"}
0005434138396	BA7C4B	0161 139344	SALAVAT YAKOVLEV	{"email": "yakovlev_salavat-13031955@postgrespro.ru", "phone": "+70062570931"}
0005434138397	4B7729	5243 704585	LYUBOV MAKSIMOVA	{"email": "maksimova-l_091963@postgrespro.ru", "phone": "+70776770925"}
0005434138398	4B7729	8461 028340	TATYANA BORISOVA	{"email": "borisova.tatyana031965@postgrespro.ru", "phone": "+70629827089"}
0005434138399	0DA2BA	1585 182664	NADEZHDA FILIPPOVA	{"email": "nfilippova-03081972@postgrespro.ru", "phone": "+70149624220"}
0005434138400	049D7E	4100 049305	SVETLANA GORBUNOVA	{"email": "svetlanagorbunova.1969@postgrespro.ru", "phone": "+70203334970"}
0005434138401	2291E2	7457 138239	NIKOLAY KOZLOV	{"email": "n.kozlov.121973@postgrespro.ru", "phone": "+70978271570"}
0005434138402	41617E	4646 493113	IVAN ANTONOV	{"email": "iantonov-1973@postgrespro.ru", "phone": "+70138393767"}
0005434138403	F09273	5950 291326	EVGENIYA FILIPPOVA	{"phone": "+70289355399"}
0005434138404	430E80	0823 304539	VALENTINA VASILEVA	{"phone": "+70507622687"}
0005434138405	CB97B0	4994 801339	TATYANA POPOVA	{"email": "popova.t-011962@postgrespro.ru", "phone": "+70740711976"}
0005434138406	CB97B0	5307 327381	ZARINA VOLKOVA	{"phone": "+70454324831"}
0005434138407	2491D5	8698 608525	EKATERINA PETROVA	{"phone": "+70675157048"}
0005434138408	1658BC	9957 972055	OLESYA STEPANOVA	{"email": "olesya-stepanova.20081971@postgrespro.ru", "phone": "+70421256976"}
0005434138409	00EA00	3032 566854	DMITRIY FEDOROV	{"email": "dmitriyfedorov-071970@postgrespro.ru", "phone": "+70055304999"}
0005434138410	00EA00	6432 803226	NATALYA YAKOVLEVA	{"email": "n-yakovleva11021969@postgrespro.ru", "phone": "+70801888792"}
0005434138411	92B33E	0665 490258	MAKSIM VOLKOV	{"email": "maksim-volkov.1967@postgrespro.ru", "phone": "+70471841600"}
0005434138412	92B33E	3935 084626	OLGA MIRONOVA	{"phone": "+70126309892"}
0005434138413	4E4160	3753 329056	IGOR MOISEEV	{"email": "moiseev-igor_041971@postgrespro.ru", "phone": "+70771086208"}
0005434138414	854991	0078 649715	ELENA NIKITINA	{"email": "enikitina-061982@postgrespro.ru", "phone": "+70599436051"}
0005434138415	DC345C	8846 542652	NATALYA VOLKOVA	{"email": "volkovanatalya01021977@postgrespro.ru", "phone": "+70165623318"}
0005434138416	BE1DAE	5980 035647	ZINAIDA SERGEEVA	{"phone": "+70027594790"}
0005434138417	53C1BC	8869 163523	VALENTINA GORBUNOVA	{"phone": "+70040326971"}
0005434138418	A7A0CA	5167 969386	LYUDMILA VASILEVA	{"email": "vasileva.l-121975@postgrespro.ru", "phone": "+70279023227"}
0005434138419	005EC4	2728 468834	ALEKSANDR ANDREEV	{"email": "a.andreev.29111971@postgrespro.ru", "phone": "+70282523046"}
0005434138420	C472C8	5000 608946	SERGEY ZAYCEV	{"phone": "+70694000259"}
0005434138421	C472C8	4314 845904	LYUDMILA DENISOVA	{"phone": "+70104389175"}
0005434138422	F3BAD5	4013 385338	SVETLANA NIKOLAEVA	{"email": "svetlana-nikolaeva-09031979@postgrespro.ru", "phone": "+70707320767"}
0005434138423	39D270	9984 808394	SERGEY NIKOLAEV	{"email": "nikolaevs.021978@postgrespro.ru", "phone": "+70403305768"}
0005434138424	EC9D5E	0777 097487	ARTEM TIKHONOV	{"email": "tikhonov.a.05011964@postgrespro.ru", "phone": "+70699539658"}
0005434138425	F09071	1157 082460	SVETLANA KOZLOVA	{"phone": "+70080968261"}
0005434138426	96F62A	6496 591575	ANDREY OSIPOV	{"email": "osipov_andrey03061964@postgrespro.ru", "phone": "+70244607192"}
0005434138427	96F62A	6912 383592	LYUDMILA ALEKSEEVA	{"phone": "+70476749416"}
0005434138428	D480CC	2456 083377	ELENA KOZLOVA	{"email": "kozlova_e101981@postgrespro.ru", "phone": "+70431502560"}
0005434138429	D480CC	3744 378906	GALINA PAVLOVA	{"email": "galinapavlova-1978@postgrespro.ru", "phone": "+70993986237"}
0005434138430	045DEC	8676 783673	VITALIY KOZLOV	{"phone": "+70044751539"}
0005434138431	045DEC	5751 041984	ROMAN KUZNECOV	{"phone": "+70194916658"}
0005434138432	1221E9	0742 966083	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr.071968@postgrespro.ru", "phone": "+70725642825"}
0005434138433	1221E9	6248 923942	ALEKSANDR DENISOV	{"email": "a-denisov.09021974@postgrespro.ru", "phone": "+70975276467"}
0005434138434	E5F1BD	1648 851887	MARIYA BARANOVA	{"phone": "+70966524646"}
0005434138435	4F41FD	9893 440574	GENNADIY RODIONOV	{"phone": "+70663313231"}
0005434138436	D8C2F7	8370 334037	TIMUR FILIPPOV	{"email": "filippov.t-1978@postgrespro.ru", "phone": "+70571712107"}
0005434138437	A47D18	6206 124108	DMITRIY ALEKSEEV	{"email": "d.alekseev.21051967@postgrespro.ru", "phone": "+70451894313"}
0005434138438	77CFA1	3692 815755	ALEKSANDR SAVELEV	{"phone": "+70974851992"}
0005434138439	77CFA1	5233 165428	ANASTASIYA ZAKHAROVA	{"email": "a_zakharova.051971@postgrespro.ru", "phone": "+70428454357"}
0005434138440	134E59	2603 400029	VLADIMIR BONDARENKO	{"email": "bondarenko.v.1982@postgrespro.ru", "phone": "+70758517083"}
0005434138441	80E8BE	2156 683676	ANASTASIYA KISELEVA	{"phone": "+70168233104"}
0005434138442	E31C17	1683 941399	LYUBOV KONOVALOVA	{"email": "lyubov_konovalova.1979@postgrespro.ru", "phone": "+70828905040"}
0005434138443	9C8D15	0475 787240	VIKTOR ZAKHAROV	{"email": "viktorzakharov-01071965@postgrespro.ru", "phone": "+70103284933"}
0005434138444	F9E574	6121 918005	VLADISLAV MIKHAYLOV	{"email": "mikhaylov.vladislav1978@postgrespro.ru", "phone": "+70718266292"}
0005434138445	41BEF5	3698 407482	SERGEY SOLOVEV	{"phone": "+70359748824"}
0005434138446	BAF609	5999 016636	GALINA NESTEROVA	{"email": "g.nesterova.071973@postgrespro.ru", "phone": "+70249018644"}
0005434138447	F963B7	8862 210947	VYACHESLAV MARTYNOV	{"email": "martynov-v_011970@postgrespro.ru", "phone": "+70168232922"}
0005434138448	45C0DE	1731 864052	ALEKSANDR KOROLEV	{"email": "korolev_a_081973@postgrespro.ru", "phone": "+70784966656"}
0005434138449	AC8F35	9045 539197	IGOR ALEKSANDROV	{"phone": "+70654972066"}
0005434138450	B436CE	9383 440479	IRINA KONDRATEVA	{"phone": "+70553991470"}
0005434138451	B436CE	8592 974273	VASILIY BARANOV	{"email": "baranovvasiliy_031982@postgrespro.ru", "phone": "+70481740205"}
0005434138452	665C65	6408 490590	EKATERINA SOLOVEVA	{"phone": "+70205905281"}
0005434138453	F05C6B	7138 756633	DMITRIY SOKOLOV	{"email": "d.sokolov1969@postgrespro.ru", "phone": "+70966976431"}
0005434138454	6F1192	4883 063582	ELENA IVANOVA	{"email": "elena-ivanova.1972@postgrespro.ru", "phone": "+70823704786"}
0005434138455	9FC785	7367 634955	DMITRIY IVANOV	{"phone": "+70663121130"}
0005434138456	CFFD3B	9446 018193	SERGEY KARPOV	{"email": "karpov_s_15071978@postgrespro.ru", "phone": "+70039743313"}
0005434138457	FCBAA5	6583 929301	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a30031972@postgrespro.ru", "phone": "+70949059579"}
0005434138458	B6385B	1873 350695	SERGEY SMIRNOV	{"phone": "+70481549585"}
0005434138459	A0F5D1	6809 250427	VLADIMIR MOROZOV	{"email": "v_morozov.051973@postgrespro.ru", "phone": "+70583316422"}
0005434138460	A0F5D1	5325 608526	SERGEY SOLOVEV	{"email": "solovev_s.021974@postgrespro.ru", "phone": "+70455002445"}
0005434138461	D68C5D	7378 086421	SERGEY OSIPOV	{"email": "osipov-s-101977@postgrespro.ru", "phone": "+70404056951"}
0005434138462	7B85F0	2827 412483	SERGEY KOZLOV	{"phone": "+70873331435"}
0005434138463	7B85F0	4181 151025	OKSANA SOKOLOVA	{"email": "oksana.sokolova-051968@postgrespro.ru", "phone": "+70749301451"}
0005434138464	F056ED	1725 720488	VLADIMIR MAKSIMOV	{"phone": "+70935993214"}
0005434138465	F056ED	4042 282543	MIKHAIL IVANOV	{"email": "mikhailivanov_1969@postgrespro.ru", "phone": "+70180397304"}
0005434138466	4C4EBA	1486 600064	VALENTINA MOISEEVA	{"phone": "+70000429749"}
0005434138467	54E1BF	1585 208271	SERGEY IVANOV	{"phone": "+70168459336"}
0005434138468	C5DF49	2288 913309	NINA ROMANOVA	{"email": "nina-romanova.07111975@postgrespro.ru", "phone": "+70676469214"}
0005434138469	C5DF49	1102 365876	LIDIYA KALININA	{"phone": "+70641782960"}
0005434138470	A66962	1494 914083	KONSTANTIN SMIRNOV	{"email": "k.smirnov_091972@postgrespro.ru", "phone": "+70223979419"}
0005434138471	E05480	3367 443727	ELENA KARPOVA	{"email": "e_karpova.1964@postgrespro.ru", "phone": "+70071085802"}
0005434138472	5BE69D	2847 003758	DMITRIY SOKOLOV	{"phone": "+70866687705"}
0005434138473	5BE69D	2986 705334	DARYA ANISIMOVA	{"email": "d.anisimova.07011981@postgrespro.ru", "phone": "+70278768994"}
0005434138474	B125AA	2767 872593	KLAVDIYA KUZNECOVA	{"phone": "+70923333061"}
0005434138475	DD5A37	1009 178525	DENIS VASILEV	{"email": "vasilev_denis1948@postgrespro.ru", "phone": "+70075211023"}
0005434138476	DD5A37	6396 239815	KONSTANTIN VOLKOV	{"phone": "+70900816817"}
0005434138477	D1192A	0290 018325	OKSANA VOLKOVA	{"phone": "+70179827641"}
0005434138478	D1192A	8820 716102	LYUBOV AKIMOVA	{"email": "lyubov_akimova-021965@postgrespro.ru", "phone": "+70718420438"}
0005434138479	F2FF63	6784 287502	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin01101982@postgrespro.ru", "phone": "+70164982157"}
0005434138480	F2FF63	2192 577321	KAMIL DAVYDOV	{"phone": "+70697355192"}
0005434138481	717F21	7835 561414	TATYANA YAKOVLEVA	{"email": "t.yakovleva_31011965@postgrespro.ru", "phone": "+70753219379"}
0005434138482	15B296	9387 551063	TAMARA PETROVA	{"phone": "+70950614241"}
0005434138483	05045F	9837 301927	EVGENIY ZAKHAROV	{"phone": "+70278782774"}
0005434138484	5B24B7	3445 289867	TAMARA NOVIKOVA	{"email": "novikova.t07111975@postgrespro.ru", "phone": "+70485742759"}
0005434138485	18C24D	5814 079436	NATALYA ABRAMOVA	{"email": "abramova_natalya-031983@postgrespro.ru", "phone": "+70261219334"}
0005434138486	50C79B	7514 672848	ANDREY MATVEEV	{"phone": "+70320489055"}
0005434138487	9CCC85	6456 472824	DARYA PAVLOVA	{"email": "pavlova.darya-09071973@postgrespro.ru", "phone": "+70291221872"}
0005434138488	63ADA2	8518 246006	ARTEM ZAYCEV	{"email": "azaycev_011963@postgrespro.ru", "phone": "+70194247667"}
0005434138489	DCD18C	0430 264902	OLGA ARKHIPOVA	{"phone": "+70537739977"}
0005434138490	DCD18C	0551 405963	ANDREY VOROBEV	{"email": "vorobevandrey071963@postgrespro.ru", "phone": "+70779289846"}
0005434138491	63FD6F	9268 255615	OKSANA TARASOVA	{"phone": "+70199699030"}
0005434138492	71AE62	2102 370550	ANASTASIYA FEDOROVA	{"phone": "+70129452064"}
0005434138493	15C123	4347 577325	LIDIYA TROFIMOVA	{"phone": "+70729171346"}
0005434138494	15C123	4640 726591	ALEKSANDR KISELEV	{"phone": "+70918268332"}
0005434138495	1BA661	6753 696081	VYACHESLAV ANDREEV	{"email": "v.andreev.1980@postgrespro.ru", "phone": "+70484323326"}
0005434138496	8BCC2B	8364 703914	IRINA EGOROVA	{"email": "iegorova_041975@postgrespro.ru", "phone": "+70760573643"}
0005434138497	8DBAA2	6304 297572	YULIYA KUZNECOVA	{"phone": "+70490631386"}
0005434138498	61178C	4264 050745	DMITRIY SEMENOV	{"email": "dmitriysemenov1952@postgrespro.ru", "phone": "+70226850446"}
0005434138499	30999F	2740 263223	MARGARITA EGOROVA	{"email": "m.egorova_1968@postgrespro.ru", "phone": "+70207657739"}
0005434138500	F88EE3	6063 766963	NIKOLAY KUZNECOV	{"phone": "+70348772719"}
0005434138501	459838	0809 742877	VLADIMIR IVANOV	{"phone": "+70911884959"}
0005434138502	43C043	0640 465985	MURAD AFANASEV	{"phone": "+70412170711"}
0005434138503	43C043	1550 348620	PAVEL TARASOV	{"phone": "+70428962367"}
0005434138504	5F4038	0997 210670	YANA PETROVA	{"phone": "+70120150971"}
0005434138505	99CAC1	2748 064282	KONSTANTIN SCHERBAKOV	{"email": "scherbakov.konstantin_19011971@postgrespro.ru", "phone": "+70005522399"}
0005434138506	87AF36	1125 554067	LYUDMILA TITOVA	{"email": "lyudmila_titova-1973@postgrespro.ru", "phone": "+70647263201"}
0005434138507	B5DFE5	6230 157881	SERGEY BELOV	{"email": "belov-sergey091975@postgrespro.ru", "phone": "+70728552126"}
0005434138508	7257A8	1387 651476	TATYANA ZAYCEVA	{"email": "tzayceva1967@postgrespro.ru", "phone": "+70791112037"}
0005434138509	06BEDA	9125 103972	NADEZHDA MASLOVA	{"phone": "+70481707948"}
0005434138510	3A48EA	8416 778071	VIKTORIYA PETROVA	{"email": "v.petrova_1963@postgrespro.ru", "phone": "+70701923652"}
0005434138511	3A48EA	5137 809565	NIKOLAY MAKSIMOV	{"phone": "+70784506134"}
0005434138512	123736	8311 605163	EKATERINA GUSEVA	{"phone": "+70393173260"}
0005434138513	C5C5B7	6656 211410	ANDREY ORLOV	{"email": "orlov-a.28101972@postgrespro.ru", "phone": "+70909989891"}
0005434138514	320D06	7193 832244	ALEKSEY YAKOVLEV	{"phone": "+70763002781"}
0005434138515	320D06	1473 345365	TATYANA EGOROVA	{"phone": "+70626758335"}
0005434138516	5D1860	2184 733493	ELENA DMITRIEVA	{"email": "e_dmitrieva_1980@postgrespro.ru", "phone": "+70817959181"}
0005434138517	F3A387	3306 863576	ANATOLIY RODIONOV	{"email": "rodionovanatoliy-1970@postgrespro.ru", "phone": "+70765111108"}
0005434138518	F3A387	2518 775116	GALINA FILIPPOVA	{"phone": "+70554392917"}
0005434138519	8743C1	2061 289588	VLADIMIR PAVLOV	{"email": "vladimirpavlov121973@postgrespro.ru", "phone": "+70187777973"}
0005434138520	5E0060	3131 101914	VALENTINA ROMANOVA	{"phone": "+70648211435"}
0005434138521	20299B	3661 481383	ELENA ZHURAVLEVA	{"email": "elenazhuravleva.121973@postgrespro.ru", "phone": "+70560468449"}
0005434138522	20299B	5767 457607	ANDREY ABRAMOV	{"phone": "+70364622185"}
0005434138523	743EDE	5592 544541	MARIYA MOISEEVA	{"phone": "+70393277615"}
0005434138524	743EDE	2589 770457	NATALIYA SOROKINA	{"email": "n_sorokina.30061976@postgrespro.ru", "phone": "+70143357567"}
0005434138525	FA4F30	7188 171298	NIKOLAY FEDOROV	{"email": "nikolay.fedorov.18101971@postgrespro.ru", "phone": "+70159256401"}
0005434138526	D02A99	7748 065984	YULIYA MAKSIMOVA	{"phone": "+70805277966"}
0005434138527	D02A99	2358 700306	LIDIYA EFIMOVA	{"email": "efimova-l031972@postgrespro.ru", "phone": "+70733935617"}
0005434138528	21144F	7230 303408	DARYA POPOVA	{"email": "daryapopova-07101970@postgrespro.ru", "phone": "+70776950737"}
0005434138529	21144F	2371 128227	NIKOLAY TARASOV	{"phone": "+70277189678"}
0005434138530	6E942B	4487 891703	VERA SMIRNOVA	{"email": "smirnovavera_1975@postgrespro.ru", "phone": "+70492789071"}
0005434138531	B12D2C	0992 977151	NIKOLAY KUZNECOV	{"phone": "+70409298037"}
0005434138532	BD5D32	5331 197633	VALENTINA KONOVALOVA	{"email": "v_konovalova_1977@postgrespro.ru", "phone": "+70015295272"}
0005434138533	BD5D32	0607 797398	ELENA NESTEROVA	{"phone": "+70225743747"}
0005434138534	93502F	3168 804990	VALENTINA SOROKINA	{"email": "sorokinav-091965@postgrespro.ru", "phone": "+70420680466"}
0005434138535	93502F	0395 880001	NADEZHDA NIKOLAEVA	{"phone": "+70306316133"}
0005434138536	5F8CF3	0387 405320	ARSENIY GUSEV	{"email": "arseniy_gusev101973@postgrespro.ru", "phone": "+70812229405"}
0005434138537	10861F	9988 463358	ANASTASIYA MAKSIMOVA	{"email": "maksimova_a_17021968@postgrespro.ru", "phone": "+70037675322"}
0005434138538	10861F	9542 085015	ARTEM ANDREEV	{"phone": "+70040523592"}
0005434138539	F05089	8443 993962	RIMMA KONOVALOVA	{"phone": "+70748586783"}
0005434138540	F05089	9480 907513	TAMARA MIRONOVA	{"email": "tamara_mironova30121980@postgrespro.ru", "phone": "+70251041772"}
0005434138541	F05089	9934 374471	ANATOLIY KUZNECOV	{"phone": "+70995746841"}
0005434138542	F05089	7833 832748	KLAVDIYA ANTONOVA	{"phone": "+70341685555"}
0005434138543	27F7C1	6711 058259	SERGEY IVANOV	{"email": "ivanov_sergey-17041979@postgrespro.ru", "phone": "+70174644486"}
0005434138544	27F7C1	2280 066856	DMITRIY SCHERBAKOV	{"email": "dmitriyscherbakov31071979@postgrespro.ru", "phone": "+70289482395"}
0005434138545	F8AD04	4110 227326	LYUDMILA KAZAKOVA	{"phone": "+70069318150"}
0005434138546	C19E4A	3284 658658	VALENTINA GUSEVA	{"email": "v.guseva-051982@postgrespro.ru", "phone": "+70870542525"}
0005434138547	C19E4A	8111 962174	DENIS BELOV	{"phone": "+70721318287"}
0005434138548	574F68	5741 044510	DMITRIY KONOVALOV	{"phone": "+70734391448"}
0005434138549	89365F	3020 531173	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr-1977@postgrespro.ru", "phone": "+70525264511"}
0005434138550	89365F	7016 465220	TATYANA ARKHIPOVA	{"phone": "+70205873571"}
0005434138551	2764E3	3070 863934	LYUBOV EFREMOVA	{"phone": "+70286058335"}
0005434138552	8D72C3	4027 141914	VERA POPOVA	{"email": "popova-v04071977@postgrespro.ru", "phone": "+70968672132"}
0005434138553	4DF28F	4982 699300	EKATERINA FILIPPOVA	{"email": "filippovae.041974@postgrespro.ru", "phone": "+70336363107"}
0005434138554	4DF28F	9698 553244	ZINAIDA ANISIMOVA	{"phone": "+70151304828"}
0005434138555	9F7835	9489 171314	ANDREY KUZNECOV	{"email": "a.kuznecov_021978@postgrespro.ru", "phone": "+70153868189"}
0005434138556	9F7835	0350 271019	SOFYA KARPOVA	{"phone": "+70032025723"}
0005434138557	63A38B	1422 491641	MARGARITA IVANOVA	{"email": "margaritaivanova21091972@postgrespro.ru", "phone": "+70769705581"}
0005434138558	63A38B	7737 721490	LYUBOV KOROLEVA	{"phone": "+70538524522"}
0005434138559	FE86A4	2818 426577	ANNA NESTEROVA	{"email": "nesterova_a1977@postgrespro.ru", "phone": "+70450087440"}
0005434138560	F653B1	9502 527781	ALEKSEY NIKITIN	{"phone": "+70160543620"}
0005434138561	76AAB8	3394 096298	VALENTINA GERASIMOVA	{"phone": "+70068891487"}
0005434138562	76AAB8	5434 457924	NATALYA IVANOVA	{"phone": "+70180479287"}
0005434138563	76AAB8	1575 179378	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov.07051976@postgrespro.ru", "phone": "+70220901116"}
0005434138564	D405D2	7602 425697	ANDREY KISELEV	{"email": "andrey.kiselev04111975@postgrespro.ru", "phone": "+70010754548"}
0005434138565	CE13AE	5011 704815	ANASTASIYA TIKHONOVA	{"phone": "+70546420331"}
0005434138566	1E6002	6133 146147	RAVIL SOKOLOV	{"phone": "+70532608604"}
0005434138567	1E6002	2017 687979	ANDREY MIKHAYLOV	{"email": "amikhaylov-031976@postgrespro.ru", "phone": "+70763205474"}
0005434138568	22E820	4176 527817	ALENA GRISHINA	{"phone": "+70916808721"}
0005434138569	9035DB	2595 779605	KIRILL KUZNECOV	{"phone": "+70579075184"}
0005434138570	5CE2A5	0343 475600	TATYANA ANDREEVA	{"email": "tatyanaandreeva_091971@postgrespro.ru", "phone": "+70944436808"}
0005434138571	5CE2A5	2161 470811	KIRILL MAKAROV	{"phone": "+70483759809"}
0005434138572	333301	8810 083668	ANASTASIYA EGOROVA	{"phone": "+70012730012"}
0005434138573	8BA14A	3318 666441	ALEKSEY SOROKIN	{"phone": "+70106888921"}
0005434138574	8BA14A	8961 523488	TATYANA YAKOVLEVA	{"email": "yakovleva.t07031977@postgrespro.ru", "phone": "+70304406304"}
0005434138575	8BA14A	9671 246928	IRINA KUZNECOVA	{"phone": "+70583203796"}
0005434138576	CA3090	4030 248521	SERGEY MARTYNOV	{"email": "sergey.martynov1990@postgrespro.ru", "phone": "+70801134160"}
0005434138577	CA3090	8428 845833	OLGA BOGDANOVA	{"email": "bogdanova_olga.1974@postgrespro.ru", "phone": "+70912172989"}
0005434138578	CA3090	5651 551254	PAVEL NIKOLAEV	{"phone": "+70477972091"}
0005434138579	174123	3776 623346	SERGEY KOROLEV	{"email": "korolevsergey_081974@postgrespro.ru", "phone": "+70787696016"}
0005434138580	174123	8718 402436	SERGEY MOISEEV	{"email": "moiseev-sergey-1961@postgrespro.ru", "phone": "+70480261549"}
0005434138581	174123	6046 272715	ALEKSANDR ZAKHAROV	{"phone": "+70897168672"}
0005434138582	26EDB9	3105 901113	IRINA NIKITINA	{"phone": "+70083662515"}
0005434138583	9A0663	6642 624659	LARISA KOZLOVA	{"email": "lkozlova_101976@postgrespro.ru", "phone": "+70518491646"}
0005434138584	F7A5C8	4362 057387	LIDIYA FILATOVA	{"email": "filatova.lidiya_1974@postgrespro.ru", "phone": "+70156842894"}
0005434138585	F60D47	9182 813717	GENNADIY POPOV	{"phone": "+70981694931"}
0005434138586	586647	1998 096519	DMITRIY PETROV	{"email": "petrovdmitriy-1972@postgrespro.ru", "phone": "+70976881942"}
0005434138587	31D890	4698 799415	LARISA DAVYDOVA	{"email": "l_davydova.15021970@postgrespro.ru", "phone": "+70621415993"}
0005434138588	1DADC2	4103 672736	ELENA GAVRILOVA	{"phone": "+70821168959"}
0005434138589	1DADC2	8611 983824	ANDREY FROLOV	{"phone": "+70509887088"}
0005434138590	D58A9D	9205 897380	PAVEL PETROV	{"email": "pavelpetrov_021967@postgrespro.ru", "phone": "+70558031340"}
0005434138591	D58A9D	4431 269673	SERGEY KUZNECOV	{"email": "kuznecov-s-1959@postgrespro.ru", "phone": "+70284647033"}
0005434138592	CA38DD	0697 329877	PAVEL ISAEV	{"email": "isaev_p-111977@postgrespro.ru", "phone": "+70381972387"}
0005434138593	CA38DD	3747 090297	VLADIMIR KUZNECOV	{"phone": "+70200941842"}
0005434138594	CA38DD	3668 288030	SERGEY IVANOV	{"phone": "+70090457212"}
0005434138595	5E0A3D	2568 765844	NATALYA MATVEEVA	{"email": "matveeva.natalya01021967@postgrespro.ru", "phone": "+70293436527"}
0005434138596	7715B1	8638 509660	LYUBOV IVANOVA	{"email": "lyubov_ivanova041970@postgrespro.ru", "phone": "+70521688838"}
0005434138597	07F981	4859 623006	KSENIYA KUZMINA	{"phone": "+70714394780"}
0005434138598	07F981	1308 363594	YULIYA GUSEVA	{"email": "guseva-y.08031974@postgrespro.ru", "phone": "+70233250516"}
0005434138599	2666F7	3409 223811	IRINA POPOVA	{"email": "popova-i091972@postgrespro.ru", "phone": "+70855266251"}
0005434138600	2666F7	1720 349035	EGOR GUSEV	{"phone": "+70502454535"}
0005434138601	495416	6401 385914	OLGA POTAPOVA	{"email": "potapovaolga-08081975@postgrespro.ru", "phone": "+70047065492"}
0005434138602	9BEAEF	5945 412204	ELINA NIKITINA	{"phone": "+70590215651"}
0005434138603	55CE19	4745 832497	GALINA NOVIKOVA	{"email": "novikovagalina_1975@postgrespro.ru", "phone": "+70717470322"}
0005434138604	55CE19	4398 993760	GALINA TIKHONOVA	{"email": "tikhonova-g_05031959@postgrespro.ru", "phone": "+70317150328"}
0005434138605	00B4B4	3670 602593	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr_25061970@postgrespro.ru", "phone": "+70126120250"}
0005434138606	EFD810	2955 727143	SEMEN ROMANOV	{"phone": "+70283738754"}
0005434138607	DFBEFF	7939 925446	IGOR EGOROV	{"phone": "+70419527440"}
0005434138608	DFBEFF	4397 819488	NATALYA SERGEEVA	{"email": "natalya_sergeeva1963@postgrespro.ru", "phone": "+70909401132"}
0005434138609	DFBEFF	4136 315401	RUSLAN AFANASEV	{"email": "ruslan-afanasev.1979@postgrespro.ru", "phone": "+70357173019"}
0005434138610	28ACD5	6543 353658	RAFAIL ANTONOV	{"email": "r.antonov_1962@postgrespro.ru", "phone": "+70145753844"}
0005434138611	28ACD5	3359 702987	OLGA SAVELEVA	{"phone": "+70695932269"}
0005434138612	28ACD5	4572 140578	YURIY KULIKOV	{"phone": "+70336651864"}
0005434138613	278217	4888 635720	ANNA FEDOROVA	{"phone": "+70450009811"}
0005434138614	40216C	6334 576341	STEPAN SOLOVEV	{"email": "s.solovev011971@postgrespro.ru", "phone": "+70247554867"}
0005434138615	40216C	6062 821728	MAKSIM ILIN	{"phone": "+70562275923"}
0005434138616	9BD542	0883 241288	ALEKSEY POPOV	{"email": "aleksey-popov.19061969@postgrespro.ru", "phone": "+70342978042"}
0005434138617	6029F3	6262 607868	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev-111961@postgrespro.ru", "phone": "+70004716898"}
0005434138618	BC4CC1	2053 344175	ANDREY VOLKOV	{"email": "andrey.volkov_1969@postgrespro.ru", "phone": "+70236906899"}
0005434138619	9D1BEE	4744 127026	TAMARA TROFIMOVA	{"email": "trofimova_tamara-12071974@postgrespro.ru", "phone": "+70502777079"}
0005434138620	DDCA96	0603 056337	RAISA KISELEVA	{"phone": "+70854370289"}
0005434138621	6A5394	4860 853178	DMITRIY DMITRIEV	{"phone": "+70752101133"}
0005434138622	74BCA4	9890 386362	ALEKSANDR CHERNOV	{"email": "chernova.19111967@postgrespro.ru", "phone": "+70647312503"}
0005434138623	C8019F	9883 820069	VERA STEPANOVA	{"email": "v-stepanova.021964@postgrespro.ru", "phone": "+70128153130"}
0005434138624	C8019F	0484 248301	ALEKSANDR KULIKOV	{"email": "kulikov.a-081977@postgrespro.ru", "phone": "+70255380045"}
0005434138625	B7DC41	8331 773744	ALEKSANDR NAUMOV	{"phone": "+70349130911"}
0005434138626	D02D08	4254 827951	OLGA BELOVA	{"email": "belova.olga101972@postgrespro.ru", "phone": "+70516070421"}
0005434138627	B4E92B	7915 852284	SERGEY KUZNECOV	{"phone": "+70077343804"}
0005434138628	B4E92B	4980 190373	ALEKSEY FROLOV	{"phone": "+70225220944"}
0005434138629	C2F482	6565 566693	GALINA SOKOLOVA	{"phone": "+70362501155"}
0005434138630	C2F482	2306 728765	ANDREY DAVYDOV	{"email": "davydov_andrey.011992@postgrespro.ru", "phone": "+70703517531"}
0005434138631	C9DCBC	7921 914964	SVETLANA KUZMINA	{"phone": "+70523148337"}
0005434138632	4838BA	1450 289195	PELAGEYA ZAKHAROVA	{"email": "p_zakharova.011962@postgrespro.ru", "phone": "+70326477950"}
0005434138633	4838BA	0696 367078	NIKOLAY ALEKSEEV	{"email": "alekseevn02081974@postgrespro.ru", "phone": "+70238840287"}
0005434138634	3DEE92	6590 077691	TATYANA KOMAROVA	{"email": "komarova-tatyana-101973@postgrespro.ru", "phone": "+70933211170"}
0005434138635	95ED1B	0980 220608	ALEKSANDR KISELEV	{"phone": "+70151934153"}
0005434138636	95ED1B	5452 350625	MARIYA ZAYCEVA	{"phone": "+70264108001"}
0005434138637	3F7891	9621 944041	GENNADIY MIRONOV	{"phone": "+70340825175"}
0005434138638	958A5F	4143 355489	ELENA DANILOVA	{"email": "elena-danilova.17061964@postgrespro.ru", "phone": "+70250732869"}
0005434138639	B25D58	5206 277882	IGOR MATVEEV	{"email": "matveevi15111985@postgrespro.ru", "phone": "+70196872720"}
0005434138640	B25D58	3411 483249	TATYANA KISELEVA	{"phone": "+70442564372"}
0005434138641	44B55D	5909 835917	NINA LUKYANOVA	{"phone": "+70855060965"}
0005434138642	44B55D	0962 136013	PAVEL KRASNOV	{"phone": "+70167548511"}
0005434138643	859964	2442 145277	FANIYA IVANOVA	{"phone": "+70804582870"}
0005434138644	224CB4	5547 954766	ELENA KOZLOVA	{"phone": "+70927172494"}
0005434138645	D946A6	2870 567365	MARIYA KOROLEVA	{"email": "korolevam-1973@postgrespro.ru", "phone": "+70540855814"}
0005434138646	D946A6	9458 917297	ANATOLIY NIKOLAEV	{"email": "anatoliynikolaev_051977@postgrespro.ru", "phone": "+70827671350"}
0005434138647	48F04B	8161 706771	ZARINA FROLOVA	{"phone": "+70415543388"}
0005434138648	F67EC7	4705 074528	NIKOLAY SEMENOV	{"email": "semenovnikolay1972@postgrespro.ru", "phone": "+70471396140"}
0005434138649	31A366	3159 517367	IGOR FOMIN	{"email": "i.fomin_081976@postgrespro.ru", "phone": "+70459224525"}
0005434138650	F49DB9	8384 536696	IVAN SEMENOV	{"email": "isemenov.1968@postgrespro.ru", "phone": "+70008918483"}
0005434138651	F49DB9	2018 952439	LYUBOV NIKITINA	{"email": "l.nikitina081974@postgrespro.ru", "phone": "+70016822688"}
0005434138652	E764E6	7484 942181	IRINA PAVLOVA	{"email": "irina.pavlova1969@postgrespro.ru", "phone": "+70106711757"}
0005434138653	251D91	3743 362080	ELENA ROMANOVA	{"email": "romanova-elena_1971@postgrespro.ru", "phone": "+70169317916"}
0005434138654	251D91	7636 029591	MARIYA NIKOLAEVA	{"phone": "+70823240966"}
0005434138655	282FC4	8021 348961	SVETLANA MAKAROVA	{"email": "makarovas.11011966@postgrespro.ru", "phone": "+70651734265"}
0005434138656	7345ED	0395 159583	YURIY ILIN	{"email": "y.ilin-1974@postgrespro.ru", "phone": "+70001995834"}
0005434138657	B9EBAF	9442 770475	GALINA VOLKOVA	{"email": "g.volkova.021977@postgrespro.ru", "phone": "+70962737727"}
0005434138658	472D8F	8505 427733	SVETLANA SERGEEVA	{"phone": "+70387026674"}
0005434138659	472D8F	9865 934684	ALEKSEY POPOV	{"email": "popov_a_12031976@postgrespro.ru", "phone": "+70850109871"}
0005434138660	443D48	1237 366915	OLGA KUZNECOVA	{"email": "o.kuznecova-091976@postgrespro.ru", "phone": "+70300431291"}
0005434138661	1E66F4	9871 371506	POLINA IVANOVA	{"phone": "+70389996736"}
0005434138662	871D46	8103 688775	VIKTOR ZAKHAROV	{"email": "zakharov-v_18061973@postgrespro.ru", "phone": "+70510412004"}
0005434138663	7A87BA	5384 765755	ALINA VLASOVA	{"phone": "+70294327113"}
0005434138664	7278A1	6511 349348	VIKTOR ZAYCEV	{"email": "viktor_zaycev_24111986@postgrespro.ru", "phone": "+70511168326"}
0005434138665	E4BF69	6053 005711	EVGENIY KUZNECOV	{"phone": "+70892330013"}
0005434138666	B4BBD1	2163 952301	IVAN SCHERBAKOV	{"phone": "+70379459471"}
0005434138667	B4BBD1	6738 872944	ANATOLIY PAVLOV	{"phone": "+70198714896"}
0005434138668	B4BBD1	2338 767942	VALENTINA TROFIMOVA	{"email": "trofimova.valentina.10011983@postgrespro.ru", "phone": "+70166554937"}
0005434138669	47EBAD	1859 050293	OKSANA FROLOVA	{"email": "frolovaoksana_1966@postgrespro.ru", "phone": "+70489816182"}
0005434138670	7947F4	5562 973988	ANDREY EGOROV	{"email": "andreyegorov_17121968@postgrespro.ru", "phone": "+70318155787"}
0005434138671	8A445D	8831 557786	VERA EGOROVA	{"email": "egorova.vera.1971@postgrespro.ru", "phone": "+70184850185"}
0005434138672	A4B7D5	2311 177316	ALEKSEY ANTONOV	{"phone": "+70620242028"}
0005434138673	675C53	3293 883462	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev_11111967@postgrespro.ru", "phone": "+70050999001"}
0005434138674	F65788	2223 400683	OLGA TARASOVA	{"email": "olga-tarasova051966@postgrespro.ru", "phone": "+70986844920"}
0005434138675	F65788	1729 088794	ANDREY KARPOV	{"email": "karpov.andrey.1978@postgrespro.ru", "phone": "+70756312371"}
0005434138676	BC52EB	4844 392208	OLEG EGOROV	{"email": "olegegorov_041976@postgrespro.ru", "phone": "+70163159468"}
0005434138677	656E56	3620 307658	LYUBOV FROLOVA	{"email": "lyubov.frolova-1970@postgrespro.ru", "phone": "+70131136295"}
0005434138678	502B73	9844 303253	TATYANA STEPANOVA	{"phone": "+70811363363"}
0005434138679	86E25C	5163 112475	ALISA KISELEVA	{"email": "alisa-kiseleva-121968@postgrespro.ru", "phone": "+70056744578"}
0005434138680	86E25C	7243 649978	ANATOLIY SEMENOV	{"email": "semenov-anatoliy_031969@postgrespro.ru", "phone": "+70984111007"}
0005434138681	86E25C	7199 088054	TATYANA ALEKSEEVA	{"phone": "+70055089444"}
0005434138682	A5D230	2360 783127	SERGEY VASILEV	{"email": "s-vasilev1969@postgrespro.ru", "phone": "+70024948521"}
0005434138683	A5D230	0291 921568	STANISLAV SOLOVEV	{"email": "solovev_stanislav031986@postgrespro.ru", "phone": "+70314811536"}
0005434138684	ADA669	0051 210338	NADEZHDA TARASOVA	{"email": "n_tarasova.25121960@postgrespro.ru", "phone": "+70974591874"}
0005434138685	659EB1	9459 210426	ELENA DMITRIEVA	{"email": "dmitrieva.elena-10021965@postgrespro.ru", "phone": "+70181896346"}
0005434138686	659EB1	8672 217521	YURIY OSIPOV	{"email": "osipov-y-121973@postgrespro.ru", "phone": "+70214661741"}
0005434138687	060403	0425 086197	IVAN VASILEV	{"email": "i_vasilev_041974@postgrespro.ru", "phone": "+70145944761"}
0005434138688	F4A24A	2259 937191	VYACHESLAV SEMENOV	{"phone": "+70065105918"}
0005434138689	F4A24A	8834 409538	NADEZHDA PETROVA	{"email": "petrova_n_26011968@postgrespro.ru", "phone": "+70737050344"}
0005434138690	3534B7	1072 558507	ALBINA ZAKHAROVA	{"phone": "+70896672802"}
0005434138691	C95E30	4319 518480	NIKITA IVANOV	{"phone": "+70616313699"}
0005434138692	58FD41	9174 960765	DENIS VLASOV	{"phone": "+70329679953"}
0005434138693	265462	6245 189532	ALEKSEY SCHERBAKOV	{"email": "ascherbakov10021977@postgrespro.ru", "phone": "+70227969570"}
0005434138694	265462	3515 641601	ROMAN KUZNECOV	{"email": "romankuznecov.111989@postgrespro.ru", "phone": "+70863214043"}
0005434138695	855800	7444 787193	MARIYA KUZNECOVA	{"phone": "+70168110546"}
0005434138696	855800	1023 239603	EVGENIY POPOV	{"email": "popov.evgeniy_071977@postgrespro.ru", "phone": "+70290372979"}
0005434138697	E97B8F	1623 693896	NADEZHDA CHERNOVA	{"email": "n_chernova.20021953@postgrespro.ru", "phone": "+70745356429"}
0005434138698	6761B9	9142 117544	ELENA NIKITINA	{"phone": "+70210324682"}
0005434138699	9CB60E	6140 576950	MARIYA NESTEROVA	{"email": "m_nesterova101973@postgrespro.ru", "phone": "+70000751660"}
0005434138700	18B10B	2437 503279	VLADIMIR MAKAROV	{"email": "vmakarov.29121972@postgrespro.ru", "phone": "+70328128490"}
0005434138701	0CE6A2	9998 286533	SVETLANA POPOVA	{"phone": "+70676898576"}
0005434138702	0CE6A2	6176 405604	MARINA MEDVEDEVA	{"email": "medvedeva.m_01111965@postgrespro.ru", "phone": "+70712906607"}
0005434138703	785D11	8097 284683	IVAN MELNIKOV	{"email": "melnikov.i-1966@postgrespro.ru", "phone": "+70786542352"}
0005434138704	785D11	1830 581697	VYACHESLAV PETROV	{"phone": "+70960241246"}
0005434138705	C3EFD8	4179 350906	KSENIYA VOLKOVA	{"phone": "+70398255644"}
0005434138706	C293EA	3799 277182	ALEKSEY YAKOVLEV	{"email": "alekseyyakovlev_16061964@postgrespro.ru", "phone": "+70244336221"}
0005434138707	877D93	9078 497746	VLADIMIR VASILEV	{"email": "vasilev.vladimir-1964@postgrespro.ru", "phone": "+70330731357"}
0005434138708	F9772F	1271 187600	LARISA ROMANOVA	{"email": "romanova.larisa.1978@postgrespro.ru", "phone": "+70804725195"}
0005434138709	8BCCAB	5059 139777	OLESYA KRASNOVA	{"email": "olesya.krasnova10121973@postgrespro.ru", "phone": "+70234487617"}
0005434138710	C308AB	4693 609909	GALINA MEDVEDEVA	{"email": "medvedeva.galina.27091969@postgrespro.ru", "phone": "+70867463031"}
0005434138711	C308AB	4945 224759	PETR STEPANOV	{"phone": "+70399763867"}
0005434138712	045F8F	6326 198747	RINAT SEMENOV	{"phone": "+70453397036"}
0005434138713	B6B1C9	9931 263341	KSENIYA GERASIMOVA	{"phone": "+70483220593"}
0005434138714	4FA452	3995 431244	VALENTINA GORBUNOVA	{"phone": "+70931421419"}
0005434138715	A4897F	4126 156818	KONSTANTIN KARPOV	{"phone": "+70525930028"}
0005434138716	43A962	8999 324513	LIDIYA ZAYCEVA	{"phone": "+70337967507"}
0005434138717	880B63	3384 156165	VALENTINA LAZAREVA	{"phone": "+70757001430"}
0005434138718	139430	1969 632042	NINA SOKOLOVA	{"phone": "+70219811440"}
0005434138719	A8ADF8	6763 022121	VALERIYA KOROLEVA	{"phone": "+70960152553"}
0005434138720	DD0A37	2683 089140	LIDIYA POTAPOVA	{"phone": "+70956551867"}
0005434138721	9DC940	0869 936609	OLEG BELOV	{"email": "oleg_belov011972@postgrespro.ru", "phone": "+70795327377"}
0005434138722	E4D289	4457 356274	ANDREY BARANOV	{"phone": "+70096906044"}
0005434138723	E4D289	6387 840569	SERGEY OSIPOV	{"phone": "+70025581090"}
0005434138724	86FDBB	2274 639051	ALEKSANDR BONDARENKO	{"phone": "+70044900303"}
0005434138725	26628C	6984 651893	ANATOLIY TIKHONOV	{"phone": "+70648315695"}
0005434138726	7A175A	1780 667849	ANASTASIYA FOMINA	{"phone": "+70770544280"}
0005434138727	279169	5325 677710	YULIYA LOGINOVA	{"email": "loginova-yuliya.101977@postgrespro.ru", "phone": "+70454429305"}
0005434138728	279169	5700 848918	EKATERINA SEMENOVA	{"phone": "+70798186661"}
0005434138729	FB9168	7321 823794	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova25011971@postgrespro.ru", "phone": "+70904537163"}
0005434138730	FB9168	2649 675361	LYUDMILA OSIPOVA	{"phone": "+70853530020"}
0005434138731	122F57	2127 343509	EKATERINA KRASNOVA	{"phone": "+70698681898"}
0005434138732	565D46	8586 502351	STANISLAV VLASOV	{"email": "vlasov_s-01051978@postgrespro.ru", "phone": "+70298795266"}
0005434138733	2E5265	3435 347331	GRIGORIY VASILEV	{"email": "vasilev.g_031967@postgrespro.ru", "phone": "+70915682658"}
0005434138734	BF4D2A	3825 055701	NATALYA MAKAROVA	{"email": "n.makarova_1976@postgrespro.ru", "phone": "+70196727357"}
0005434138735	44961C	0554 118097	EVGENIY SOKOLOV	{"phone": "+70774401337"}
0005434138736	44961C	9039 893888	ELENA GAVRILOVA	{"phone": "+70576029871"}
0005434138737	BB8E8C	6179 756847	ZINAIDA NAUMOVA	{"email": "naumova.z-25021970@postgrespro.ru", "phone": "+70714272427"}
0005434138738	BB8E8C	9998 591256	YULIYA STEPANOVA	{"phone": "+70246870080"}
0005434138739	BB8E8C	1524 719008	ANTONINA MASLOVA	{"phone": "+70620050726"}
0005434138740	EA6801	6753 848802	ALEKSANDR FOMIN	{"phone": "+70027724265"}
0005434138741	D45179	2203 771703	POLINA BELOVA	{"phone": "+70773915579"}
0005434138742	D45179	6610 821873	IGOR KAZAKOV	{"phone": "+70384865366"}
0005434138743	864D91	3775 119146	LYUBOV ROMANOVA	{"email": "romanoval_11081970@postgrespro.ru", "phone": "+70959027338"}
0005434138744	39FD66	2549 414994	DMITRIY MOISEEV	{"email": "moiseev_dmitriy17031962@postgrespro.ru", "phone": "+70749464186"}
0005434138745	EF53A5	1117 700969	ALEKSANDR KISELEV	{"email": "a-kiselev.1964@postgrespro.ru", "phone": "+70328960661"}
0005434138746	50DB56	4017 285015	SOFYA IVANOVA	{"phone": "+70023455526"}
0005434138747	F82400	4127 495427	NATALYA GERASIMOVA	{"email": "gerasimovanatalya101983@postgrespro.ru", "phone": "+70797022960"}
0005434138748	430193	9636 343964	VLADISLAV KUZNECOV	{"phone": "+70991549962"}
0005434138749	FC4DD2	6316 067943	PAVEL ALEKSEEV	{"phone": "+70591473407"}
0005434138750	14C4AC	2959 944457	YULIYA VASILEVA	{"email": "yuliyavasileva.18121974@postgrespro.ru", "phone": "+70077585432"}
0005434138751	F4B7F1	5918 038485	LYUDMILA MATVEEVA	{"email": "l_matveeva26081973@postgrespro.ru", "phone": "+70493275045"}
0005434138752	F4B7F1	4805 118412	GENNADIY VOLKOV	{"phone": "+70822921719"}
0005434138753	5F9AE5	4366 134141	LUIZA KONOVALOVA	{"email": "luiza_konovalova23051975@postgrespro.ru", "phone": "+70930244850"}
0005434138754	5F9AE5	1195 892337	OLGA VOLKOVA	{"phone": "+70946877154"}
0005434138755	4D94EA	5038 484767	IVAN SOKOLOV	{"email": "ivan_sokolov.011955@postgrespro.ru", "phone": "+70105180062"}
0005434138756	4D94EA	7065 856635	ELENA VASILEVA	{"email": "elenavasileva1963@postgrespro.ru", "phone": "+70082372739"}
0005434138757	456B94	4342 130649	GALINA POPOVA	{"email": "popovagalina1970@postgrespro.ru", "phone": "+70627317082"}
0005434138758	CC6B31	8410 389244	SERGEY NIKITIN	{"phone": "+70688996363"}
0005434138759	3BE839	5067 481425	LYUDMILA MAKAROVA	{"email": "makarovalyudmila.081966@postgrespro.ru", "phone": "+70566902182"}
0005434138760	7E6B2C	2132 602544	ELENA KULIKOVA	{"phone": "+70996917465"}
0005434138761	A25EB3	5624 625288	SERGEY MELNIKOV	{"phone": "+70546016342"}
0005434138762	EE7892	5875 606722	ALEKSANDR SMIRNOV	{"email": "smirnov_a_1982@postgrespro.ru", "phone": "+70151927651"}
0005434138763	5FCC6C	7307 425920	OLGA VLASOVA	{"email": "o_vlasova_121974@postgrespro.ru", "phone": "+70669660323"}
0005434138764	5FCC6C	3538 048362	IVAN KOROLEV	{"phone": "+70465899721"}
0005434138765	EDE615	7352 101177	EKATERINA MAKAROVA	{"email": "makarova.e09021969@postgrespro.ru", "phone": "+70817938854"}
0005434138766	C80897	9928 156030	MIKHAIL SERGEEV	{"email": "sergeev_m.23121982@postgrespro.ru", "phone": "+70992424387"}
0005434138767	8678A9	9896 370966	IGOR SAVELEV	{"phone": "+70631381542"}
0005434138768	5CF9AB	5820 888309	MARINA ALEKSEEVA	{"email": "alekseeva.marina_07041974@postgrespro.ru", "phone": "+70101829122"}
0005434138769	A31BBB	1889 814202	OLEG SOROKIN	{"email": "sorokinoleg.10091978@postgrespro.ru", "phone": "+70065286899"}
0005434138770	A31BBB	3306 083866	VYACHESLAV MEDVEDEV	{"email": "medvedev-vyacheslav.051968@postgrespro.ru", "phone": "+70504018232"}
0005434138771	6D935B	6366 143512	ANDREY ZAKHAROV	{"email": "andreyzakharov_051964@postgrespro.ru", "phone": "+70297728577"}
0005434138772	10C3B3	7974 614229	ALEVTINA EGOROVA	{"email": "egorova.alevtina_29121974@postgrespro.ru", "phone": "+70383585999"}
0005434138773	C36A1F	2677 577919	OLEG ZHURAVLEV	{"phone": "+70429657979"}
0005434138774	FA27AE	9611 062955	VLADIMIR BELOV	{"phone": "+70764338987"}
0005434138775	9F3CE0	0425 137718	ANDREY SCHERBAKOV	{"email": "scherbakova28081969@postgrespro.ru", "phone": "+70392323851"}
0005434138776	637A1C	1330 284486	ALEKSANDR MOROZOV	{"phone": "+70327120174"}
0005434138777	637A1C	8972 330344	EKATERINA STEPANOVA	{"phone": "+70288893832"}
0005434138778	DA1F02	1304 116349	IRINA SOKOLOVA	{"email": "sokolova-i.071972@postgrespro.ru", "phone": "+70365841748"}
0005434138779	DA1F02	0264 326681	ANVAR ZAYCEV	{"phone": "+70662386176"}
0005434138780	BEC5F2	7641 483508	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr-28101962@postgrespro.ru", "phone": "+70296144185"}
0005434138781	AFABCC	2140 829628	ALEKSANDR KULIKOV	{"phone": "+70241860824"}
0005434138782	942A8A	0420 822204	NATALYA NIKOLAEVA	{"phone": "+70966865165"}
0005434138783	9234A8	4468 346742	LARISA SOKOLOVA	{"email": "sokolova_larisa041966@postgrespro.ru", "phone": "+70505964001"}
0005434138784	5555C1	9181 538355	ROMAN YAKOVLEV	{"email": "r-yakovlev.091977@postgrespro.ru", "phone": "+70099274813"}
0005434138785	5555C1	0733 487307	DARYA OSIPOVA	{"email": "d-osipova10091976@postgrespro.ru", "phone": "+70047612700"}
0005434138786	490241	9297 627214	ALEKSANDR SAVELEV	{"phone": "+70125931949"}
0005434138787	490241	1192 669412	NADEZHDA KOMAROVA	{"email": "n.komarova.1971@postgrespro.ru", "phone": "+70509225127"}
0005434138788	D3C75B	3197 401674	KIRILL TARASOV	{"email": "tarasov-k.01011965@postgrespro.ru", "phone": "+70777245684"}
0005434138789	D3C75B	0683 070355	VALENTIN ALEKSANDROV	{"email": "aleksandrov-valentin_041970@postgrespro.ru", "phone": "+70589281862"}
0005434138790	D3C75B	8558 896746	NADEZHDA EGOROVA	{"email": "nadezhdaegorova_23011974@postgrespro.ru", "phone": "+70541337534"}
0005434138791	D3C75B	8225 867409	VLADIMIR NIKOLAEV	{"email": "vnikolaev.041972@postgrespro.ru", "phone": "+70868715856"}
0005434138792	7141CD	8257 609629	YANA NESTEROVA	{"phone": "+70839372099"}
0005434138793	7141CD	0126 928219	MARIYA LUKYANOVA	{"phone": "+70104622268"}
0005434138794	7141CD	2708 442209	NATALYA EGOROVA	{"phone": "+70023683427"}
0005434138795	4E4B45	6016 910008	ANDREY IVANOV	{"phone": "+70723967396"}
0005434138796	6021FF	6261 387155	OLESYA AKIMOVA	{"phone": "+70294410124"}
0005434138797	AAA5F4	6309 714518	VLADIMIR CHERNOV	{"phone": "+70028713271"}
0005434138798	3CC9C2	1332 284441	VLADIMIR AFANASEV	{"email": "v.afanasev-121960@postgrespro.ru", "phone": "+70233795048"}
0005434138799	BFAAA1	6641 632138	VALERIYA ILINA	{"email": "ilina-v-1968@postgrespro.ru", "phone": "+70045128567"}
0005434138800	F57233	7232 231796	ARTEM TIKHONOV	{"email": "atikhonov-041978@postgrespro.ru", "phone": "+70094742433"}
0005434138801	F57233	9012 841608	ELENA ZHUKOVA	{"email": "zhukova-e.021983@postgrespro.ru", "phone": "+70565712536"}
0005434138802	926BF1	1427 873852	IVAN POPOV	{"email": "popov-ivan_081967@postgrespro.ru", "phone": "+70111333306"}
0005434138803	266AD6	1005 696884	DMITRIY ZAYCEV	{"phone": "+70791723340"}
0005434138804	2BC9D4	1555 931058	KAPITALINA LOGINOVA	{"email": "loginova_kapitalina-18031976@postgrespro.ru", "phone": "+70799190921"}
0005434138805	2BC9D4	0683 071338	ANTONINA RYABOVA	{"phone": "+70259180120"}
0005434138806	FE53C6	6656 509131	VALERIY SIDOROV	{"email": "valeriy-sidorov.1965@postgrespro.ru", "phone": "+70572996618"}
0005434138807	1F7B7F	8359 552719	SERGEY FEDOROV	{"email": "s_fedorov_1966@postgrespro.ru", "phone": "+70499633177"}
0005434138808	1F7B7F	9834 336951	NINA NIKITINA	{"phone": "+70670361712"}
0005434138809	96CCE8	5118 117200	ANNA AFANASEVA	{"email": "afanaseva.a_081972@postgrespro.ru", "phone": "+70507324381"}
0005434138810	CF4D07	9504 641932	PLATON STEPANOV	{"phone": "+70486857640"}
0005434138811	DBAE91	6821 886430	GALINA MIKHAYLOVA	{"phone": "+70729625751"}
0005434138812	DBAE91	1201 289662	ANNA TARASOVA	{"phone": "+70786431182"}
0005434138813	DBAE91	7063 920148	VERONIKA KONDRATEVA	{"email": "kondrateva.veronika.041969@postgrespro.ru", "phone": "+70965583677"}
0005434138814	B01519	0294 871242	OLGA MIKHAYLOVA	{"email": "mikhaylovao_1957@postgrespro.ru", "phone": "+70638505246"}
0005434138815	BFBB68	5785 680961	ALEKSANDR MARTYNOV	{"email": "aleksandr_martynov_091975@postgrespro.ru", "phone": "+70979078477"}
0005434138816	230FDE	1526 988631	SVETLANA GERASIMOVA	{"phone": "+70953256842"}
0005434138817	0F7B12	1195 743922	EVGENIY MATVEEV	{"email": "e.matveev021982@postgrespro.ru", "phone": "+70781455290"}
0005434138818	05E229	7684 771000	ARTEM PAVLOV	{"email": "artempavlov_1977@postgrespro.ru", "phone": "+70445479974"}
0005434138819	218538	7161 068928	ALEKSANDR ROMANOV	{"email": "romanov-a04101974@postgrespro.ru", "phone": "+70359791429"}
0005434138820	218538	5154 468886	VLADIMIR IVANOV	{"email": "ivanov-v.1952@postgrespro.ru", "phone": "+70701938501"}
0005434138821	88C5FD	6896 243571	SEMEN KONOVALOV	{"email": "semen_konovalov_29051979@postgrespro.ru", "phone": "+70770314858"}
0005434138822	346F2B	0422 929141	VALENTINA EGOROVA	{"email": "egorova-v011986@postgrespro.ru", "phone": "+70707211906"}
0005434138823	B45A46	8386 881048	YURIY PAVLOV	{"email": "yuriypavlov_1970@postgrespro.ru", "phone": "+70192405439"}
0005434138824	22AA11	5143 024658	ELENA KOZLOVA	{"email": "e.kozlova-24061972@postgrespro.ru", "phone": "+70985981458"}
0005434138825	51E361	0366 560049	VYACHESLAV EGOROV	{"phone": "+70724871758"}
0005434138826	F0BFA4	7316 872885	NIKOLAY KUZMIN	{"email": "nikolaykuzmin-25031962@postgrespro.ru", "phone": "+70713080982"}
0005434138827	F0BFA4	1098 465355	VERA VOLKOVA	{"email": "volkova-v01021963@postgrespro.ru", "phone": "+70556501375"}
0005434138828	A12B85	2615 621903	IRINA GUSEVA	{"email": "guseva-irina.06031971@postgrespro.ru", "phone": "+70413936301"}
0005434138829	A12B85	9597 583301	ALEKSEY SCHERBAKOV	{"phone": "+70396382301"}
0005434138830	00F1EF	8952 353040	LYUDMILA OSIPOVA	{"phone": "+70959335547"}
0005434138831	00F1EF	3939 689073	TATYANA KARPOVA	{"email": "tatyana-karpova011980@postgrespro.ru", "phone": "+70306917451"}
0005434138832	5847F5	4868 991094	VITALIY NOVIKOV	{"email": "v-novikov.17081974@postgrespro.ru", "phone": "+70091869924"}
0005434138833	28C5CC	6123 300251	NADEZHDA IVANOVA	{"phone": "+70877724443"}
0005434138834	DE5F62	5088 389478	VITALIY SOROKIN	{"email": "v-sorokin.091970@postgrespro.ru", "phone": "+70761594157"}
0005434138835	DE5F62	5281 573268	ALEKSANDR AFANASEV	{"phone": "+70439659478"}
0005434138836	DE5F62	1122 853153	ALINA SMIRNOVA	{"phone": "+70337618014"}
0005434138837	646BAC	7327 974380	ANNA NESTEROVA	{"phone": "+70491114208"}
0005434138838	06DF1A	6900 370059	ALEKSANDR SIDOROV	{"email": "sidorov.a.061967@postgrespro.ru", "phone": "+70234127474"}
0005434138839	06DF1A	2985 076123	ALEKSANDR MEDVEDEV	{"email": "medvedev.a_1959@postgrespro.ru", "phone": "+70889474234"}
0005434138840	5FB073	5303 655433	ELENA MIKHAYLOVA	{"phone": "+70531506475"}
0005434138841	4EB7ED	0438 499649	NIKOLAY KOROLEV	{"email": "nikolaykorolev1980@postgrespro.ru", "phone": "+70558092610"}
0005434138842	4EB7ED	2589 532507	VALENTINA FROLOVA	{"email": "v.frolova.17071974@postgrespro.ru", "phone": "+70878906158"}
0005434138843	4EB7ED	4583 779468	MAKSIM IVANOV	{"phone": "+70674030621"}
0005434138844	03BA01	8373 724554	NADEZHDA ANDREEVA	{"email": "n.andreeva12011968@postgrespro.ru", "phone": "+70383036615"}
0005434138845	03BA01	3668 658528	SERGEY IVANOV	{"phone": "+70790326237"}
0005434138846	7D46F6	4123 754144	VLADIMIR ZHUKOV	{"phone": "+70310815035"}
0005434138847	D76606	4603 804792	ILNAR MAKAROV	{"email": "makarov-ilnar-101960@postgrespro.ru", "phone": "+70875744495"}
0005434138848	D76606	9747 715009	SERGEY STEPANOV	{"email": "stepanov-s_02091971@postgrespro.ru", "phone": "+70921701465"}
0005434138849	F595E7	8348 726669	DARYA SOLOVEVA	{"phone": "+70066501402"}
0005434138850	0DF7BB	6300 385631	YURIY BORISOV	{"email": "borisov.yuriy.021977@postgrespro.ru", "phone": "+70676597606"}
0005434138851	0DF7BB	8059 147291	MARIYA SIDOROVA	{"email": "m.sidorova071977@postgrespro.ru", "phone": "+70908503530"}
0005434138852	D7B10D	4178 303047	GALINA ANDREEVA	{"phone": "+70672815607"}
0005434138853	81056D	1077 418357	IRINA KARPOVA	{"phone": "+70298894498"}
0005434138854	4E4468	4547 883424	NINA OSIPOVA	{"email": "nina-osipova_18111986@postgrespro.ru", "phone": "+70249249214"}
0005434138855	A93258	4728 389293	ALEKSANDR BELOV	{"email": "a.belov.111978@postgrespro.ru", "phone": "+70300246124"}
0005434138856	C4FBF6	8659 351678	ANASTASIYA KUZNECOVA	{"email": "kuznecova-anastasiya_1979@postgrespro.ru", "phone": "+70896578724"}
0005434138857	58AA61	8237 373119	TAMARA SEMENOVA	{"phone": "+70905797681"}
0005434138858	58AA61	3560 173231	VADIM PETROV	{"phone": "+70742034476"}
0005434138859	7733C6	2351 100321	ZINAIDA GORBUNOVA	{"email": "gorbunova.z-121980@postgrespro.ru", "phone": "+70815774325"}
0005434138860	65B4AB	3207 215083	ARTEM GAVRILOV	{"email": "gavrilov.a_1973@postgrespro.ru", "phone": "+70567671826"}
0005434138861	65B4AB	5983 864379	TATYANA KONDRATEVA	{"phone": "+70628004530"}
0005434138974	ABC722	0257 976345	GLEB PETROV	{"phone": "+70592412756"}
0005434138862	0E9215	2378 253708	SVYATOSLAV MIRONOV	{"email": "s.mironov-051985@postgrespro.ru", "phone": "+70654358786"}
0005434138863	C63945	4280 342571	IVAN SERGEEV	{"email": "ivansergeev28101964@postgrespro.ru", "phone": "+70131393832"}
0005434138864	3DC2AD	9121 831111	NINA OSIPOVA	{"phone": "+70591243480"}
0005434138865	3DC2AD	1293 229191	DINARA POLYAKOVA	{"phone": "+70233591513"}
0005434138866	3DC2AD	6787 976293	VADIM MOROZOV	{"email": "v-morozov_1987@postgrespro.ru", "phone": "+70055765101"}
0005434138867	F1511C	4827 968513	NINA KOLESNIKOVA	{"phone": "+70770524888"}
0005434138868	65DC55	7932 151841	VALENTINA KRASNOVA	{"phone": "+70224314330"}
0005434138869	42B274	9814 837611	KSENIYA NESTEROVA	{"phone": "+70756939286"}
0005434138870	42B274	9114 423954	NIKOLAY MAKAROV	{"phone": "+70944153851"}
0005434138871	0AD2A0	8056 748882	ALI STEPANOV	{"phone": "+70188056886"}
0005434138872	393943	4200 873490	ROMAN ISAEV	{"email": "isaev_roman1970@postgrespro.ru", "phone": "+70486160516"}
0005434138873	0889A5	4592 716563	VLADIMIR NAZAROV	{"email": "v_nazarov-101977@postgrespro.ru", "phone": "+70065399524"}
0005434138874	3B050A	8507 308550	ERIK GRIGOREV	{"phone": "+70884881254"}
0005434138875	3B050A	7152 372055	LYUDMILA PAVLOVA	{"email": "pavlovalyudmila_1966@postgrespro.ru", "phone": "+70733263421"}
0005434138876	3B050A	2263 747746	VIKTORIYA DANILOVA	{"email": "viktoriyadanilova-1977@postgrespro.ru", "phone": "+70519234781"}
0005434138877	3B050A	2799 844548	LYUBOV PETROVA	{"phone": "+70730602324"}
0005434138878	CCB12A	7263 187176	SERGEY MAKAROV	{"phone": "+70725397103"}
0005434138879	15657F	9626 885435	EKATERINA MAKAROVA	{"phone": "+70046001831"}
0005434138880	5F0A74	0353 369431	EKATERINA GAVRILOVA	{"phone": "+70877207972"}
0005434138881	562DDE	9115 181820	NADEZHDA IVANOVA	{"email": "nivanova_10051979@postgrespro.ru", "phone": "+70481853875"}
0005434138882	562DDE	9629 426638	OLGA DMITRIEVA	{"email": "dmitrieva-olga-1979@postgrespro.ru", "phone": "+70108900903"}
0005434138883	E84410	2060 843052	OLEG FEDOTOV	{"phone": "+70982532467"}
0005434138884	A066F2	1349 305410	ANNA ZOTOVA	{"email": "azotova_25041976@postgrespro.ru", "phone": "+70230737677"}
0005434138885	A066F2	0369 468072	VALENTINA MIRONOVA	{"phone": "+70661012452"}
0005434138886	E067A3	4769 340222	VASILIY MAKSIMOV	{"email": "vmaksimov_22091983@postgrespro.ru", "phone": "+70031030025"}
0005434138887	E067A3	1285 435259	NADEZHDA MAKAROVA	{"phone": "+70130301036"}
0005434138888	32D074	0248 995756	NIKOLAY SERGEEV	{"email": "sergeev-n.091979@postgrespro.ru", "phone": "+70297208413"}
0005434138889	C8296E	2670 486709	NADEZHDA KOVALEVA	{"phone": "+70453115904"}
0005434138890	C8296E	3981 443435	NATALYA AKIMOVA	{"phone": "+70723678577"}
0005434138891	0A8917	2285 910034	IVAN ZAYCEV	{"phone": "+70527918785"}
0005434138892	F981B3	7599 974741	DMITRIY NAZAROV	{"email": "nazarov-dmitriy15031974@postgrespro.ru", "phone": "+70700952193"}
0005434138893	F8D11C	8604 957277	IGOR YAKOVLEV	{"phone": "+70237146720"}
0005434138894	3542BA	4080 246357	DMITRIY TARASOV	{"email": "d-tarasov.24121972@postgrespro.ru", "phone": "+70672349826"}
0005434138895	3542BA	1683 332729	EVDOKIYA POPOVA	{"phone": "+70614938045"}
0005434138896	A4C8E1	0699 583545	DMITRIY DMITRIEV	{"phone": "+70349932664"}
0005434138897	AF63FE	9767 690364	ALEKSANDRA GORBUNOVA	{"email": "agorbunova29031979@postgrespro.ru", "phone": "+70871992687"}
0005434138898	2E54C0	0696 419648	TATYANA SOKOLOVA	{"email": "sokolova-t.04101983@postgrespro.ru", "phone": "+70681127213"}
0005434138899	68DEE2	3252 211562	VALERIY ZHURAVLEV	{"phone": "+70232433358"}
0005434138900	3AE0A4	8251 077989	ANNA ZAKHAROVA	{"phone": "+70478662217"}
0005434138901	C147AE	1561 088382	NIKOLAY FEDOROV	{"email": "nikolay.fedorov.09091971@postgrespro.ru", "phone": "+70733654364"}
0005434138902	C147AE	6125 118385	INESSA SOROKINA	{"email": "inessa_sorokina_1960@postgrespro.ru", "phone": "+70907269004"}
0005434138903	D3DBCE	2340 595570	NIKOLAY MAKAROV	{"email": "makarov_n_031970@postgrespro.ru", "phone": "+70433848233"}
0005434138904	CCA2A1	3979 413513	OLGA STEPANOVA	{"email": "o.stepanova.051977@postgrespro.ru", "phone": "+70807530174"}
0005434138905	B34E0B	5065 456134	TATYANA FILATOVA	{"phone": "+70224051258"}
0005434138906	B34E0B	6992 043513	MAKSIM VASILEV	{"phone": "+70375605210"}
0005434138907	5AFA89	8978 778976	IGOR RODIONOV	{"phone": "+70637918942"}
0005434138908	2C2792	8106 306515	VIKTOR KAZAKOV	{"email": "kazakov.viktor1975@postgrespro.ru", "phone": "+70309996771"}
0005434138909	2C2792	6575 664568	EVGENIYA ABRAMOVA	{"email": "evgeniyaabramova_041986@postgrespro.ru", "phone": "+70569642258"}
0005434138910	2C2792	8975 406106	OLGA SOROKINA	{"email": "sorokinaolga-051975@postgrespro.ru", "phone": "+70426799378"}
0005434138911	2C2792	0603 791587	EVGENIY ORLOV	{"phone": "+70131157671"}
0005434138912	DF2D46	9107 703665	PELAGEYA NOVIKOVA	{"phone": "+70275608121"}
0005434138913	DF2D46	2722 128842	ANASTASIYA BELOVA	{"email": "anastasiyabelova.1967@postgrespro.ru", "phone": "+70762112514"}
0005434138914	08193F	6245 693548	LYUBOV ARKHIPOVA	{"phone": "+70786361166"}
0005434138915	96B41D	8058 278801	ZINAIDA SOROKINA	{"phone": "+70009326191"}
0005434138916	A190B9	9411 500666	VALENTINA SOROKINA	{"phone": "+70589835476"}
0005434138917	A4563F	7017 329556	TATYANA MIKHAYLOVA	{"email": "mikhaylova_t.17081973@postgrespro.ru", "phone": "+70133355589"}
0005434138918	A4563F	2344 707189	ANDREY SOKOLOV	{"email": "andrey_sokolov-021975@postgrespro.ru", "phone": "+70110203092"}
0005434138919	9786A8	5920 527112	ALEKSANDR BORISOV	{"email": "aleksandr.borisov031979@postgrespro.ru", "phone": "+70718451331"}
0005434138920	6B24DC	6238 909158	LARISA IVANOVA	{"email": "livanova1976@postgrespro.ru", "phone": "+70804442763"}
0005434138921	96CD3D	9615 474809	VALENTINA POLYAKOVA	{"email": "valentinapolyakova081974@postgrespro.ru", "phone": "+70884378917"}
0005434138922	C6A8A4	7729 812737	TATYANA ABRAMOVA	{"phone": "+70187643232"}
0005434138923	86838E	0423 437528	IRINA PETROVA	{"phone": "+70224895760"}
0005434138924	86838E	5919 198693	EGOR EGOROV	{"email": "egorove-18011980@postgrespro.ru", "phone": "+70617261684"}
0005434138925	86838E	7959 704901	ARSENIY NIKOLAEV	{"email": "nikolaev-a051966@postgrespro.ru", "phone": "+70354761587"}
0005434138926	BEFB13	7483 072439	VIKTOR FEDOTOV	{"email": "fedotov-v.1960@postgrespro.ru", "phone": "+70481200746"}
0005434138927	BEFB13	3086 847696	ELENA EGOROVA	{"email": "egorova-elena.13011976@postgrespro.ru", "phone": "+70052445925"}
0005434138928	44286F	5806 963428	ELENA FILIPPOVA	{"email": "elena.filippova-1971@postgrespro.ru", "phone": "+70214078928"}
0005434138929	44286F	5092 005350	VLADIMIR ABRAMOV	{"email": "abramov_vladimir-1985@postgrespro.ru", "phone": "+70698012496"}
0005434138930	44286F	9130 565020	NIKOLAY SOROKIN	{"email": "sorokin_nikolay-081978@postgrespro.ru", "phone": "+70988965049"}
0005434138931	CD9925	4840 795808	LYUBOV NIKITINA	{"phone": "+70280416310"}
0005434138932	691BCF	5000 673195	GRIGORIY PAVLOV	{"email": "pavlovgrigoriy_1981@postgrespro.ru", "phone": "+70166044894"}
0005434138933	B58BB4	4904 079023	ALEKSANDRA NAUMOVA	{"email": "a_naumova_051988@postgrespro.ru", "phone": "+70392833336"}
0005434138934	B58BB4	7771 344879	VIKTORIYA BOGDANOVA	{"email": "vbogdanova_061968@postgrespro.ru", "phone": "+70843785018"}
0005434138935	9A3C2F	6828 298679	GRIGORIY DMITRIEV	{"email": "g-dmitriev1974@postgrespro.ru", "phone": "+70804768595"}
0005434138936	9A3C2F	8277 451565	SERGEY NAZAROV	{"email": "s.nazarov-011976@postgrespro.ru", "phone": "+70676860776"}
0005434138937	EE3C2F	5397 248471	ELENA SOLOVEVA	{"phone": "+70695580553"}
0005434138938	829458	0236 117512	NATALYA NESTEROVA	{"email": "nesterova_natalya-22101975@postgrespro.ru", "phone": "+70662822769"}
0005434138939	616B50	9140 957158	NINA NIKIFOROVA	{"phone": "+70716930917"}
0005434138940	616B50	6478 183956	PAVEL MAKAROV	{"phone": "+70007123792"}
0005434138941	E5FAA1	6578 268216	ELENA POPOVA	{"email": "popova.elena.01051972@postgrespro.ru", "phone": "+70442951928"}
0005434138942	E5FAA1	5046 139600	VLADIMIR EGOROV	{"phone": "+70498023224"}
0005434138943	EDA0B7	9398 705445	DENIS SEMENOV	{"email": "semenov_d.17091978@postgrespro.ru", "phone": "+70097728788"}
0005434138944	8E3D2D	8075 343891	EVGENIY KULIKOV	{"phone": "+70543190728"}
0005434138945	7E2D04	2254 404100	STANISLAV IVANOV	{"email": "sivanov-16091965@postgrespro.ru", "phone": "+70639190163"}
0005434138946	864B21	3693 699288	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr.1967@postgrespro.ru", "phone": "+70383097002"}
0005434138947	0556E9	6065 257171	ZHANNA BARANOVA	{"email": "zbaranova27111984@postgrespro.ru", "phone": "+70242804977"}
0005434138948	ABC3A2	4864 426041	VERA VOLKOVA	{"email": "veravolkova_061958@postgrespro.ru", "phone": "+70904116240"}
0005434138949	74DAB4	8568 459070	ELENA PETROVA	{"email": "petrova_e.1959@postgrespro.ru", "phone": "+70481719444"}
0005434138950	1DDC96	2268 188338	VYACHESLAV PAVLOV	{"email": "pavlovvyacheslav-1977@postgrespro.ru", "phone": "+70702068064"}
0005434138951	A45442	9382 878207	EKATERINA ANDREEVA	{"phone": "+70029806651"}
0005434138952	A45442	4807 841363	ANNA KUZNECOVA	{"email": "anna-kuznecova-091974@postgrespro.ru", "phone": "+70916208815"}
0005434138953	5F469A	8068 063814	YULIYA EGOROVA	{"phone": "+70124015160"}
0005434138954	5F469A	4500 144015	DMITRIY ZAKHAROV	{"phone": "+70665474788"}
0005434138955	84B959	1884 113399	VIKTOR IVANOV	{"phone": "+70662704202"}
0005434138956	A53790	1601 286534	ARKADIY SEMENOV	{"phone": "+70471596036"}
0005434138957	B2B4C8	7153 810950	KONSTANTIN ISAEV	{"phone": "+70368065494"}
0005434138958	9A7F44	8133 287702	MAKSIM MOROZOV	{"email": "m-morozov-1967@postgrespro.ru", "phone": "+70965416912"}
0005434138959	AB6E1E	6939 408377	DMITRIY NOVIKOV	{"phone": "+70241650539"}
0005434138960	2CF26B	2641 214316	NINA KARPOVA	{"email": "nkarpova-091966@postgrespro.ru", "phone": "+70528415437"}
0005434138961	5A9120	2464 580936	SERGEY FEDOROV	{"phone": "+70035336947"}
0005434138962	5A9120	2263 534172	TATYANA VOLKOVA	{"phone": "+70302743297"}
0005434138963	694714	0573 155132	EVGENIY STEPANOV	{"email": "evgeniy.stepanov.071970@postgrespro.ru", "phone": "+70955087712"}
0005434138964	694714	6804 637948	LIDIYA KONOVALOVA	{"phone": "+70360897910"}
0005434138965	267993	6336 645726	EMILIYA ILINA	{"email": "emiliyailina-20031965@postgrespro.ru", "phone": "+70647752196"}
0005434138966	267993	8354 961913	ALEKSEY STEPANOV	{"email": "stepanov.aleksey-26091968@postgrespro.ru", "phone": "+70537504274"}
0005434138967	95654C	1470 207635	OLGA ANTONOVA	{"phone": "+70894779852"}
0005434138968	D23749	9940 976990	EKATERINA MEDVEDEVA	{"email": "medvedeva.e031974@postgrespro.ru", "phone": "+70330186525"}
0005434138969	C2C352	2896 134221	VLADIMIR DENISOV	{"email": "vladimir_denisov-1968@postgrespro.ru", "phone": "+70012036097"}
0005434138970	799155	7061 753496	LYUDMILA FROLOVA	{"phone": "+70195432306"}
0005434138971	A6B22F	9169 496180	ANNA POTAPOVA	{"email": "potapova_anna_031971@postgrespro.ru", "phone": "+70064525305"}
0005434138972	E44186	3798 378330	SERGEY IVANOV	{"email": "ivanovs_121973@postgrespro.ru", "phone": "+70191309552"}
0005434138973	E44186	9514 399322	GALINA KOLESNIKOVA	{"phone": "+70797498660"}
0005434138975	042D0D	2341 128715	ELENA PETROVA	{"email": "petrova.e.121976@postgrespro.ru", "phone": "+70524403345"}
0005434138976	042D0D	4068 554828	KIRILL MIRONOV	{"email": "kirill-mironov-1962@postgrespro.ru", "phone": "+70667512427"}
0005434138977	042D0D	1214 704578	LIDIYA IVANOVA	{"phone": "+70655440306"}
0005434138978	4EEA5B	1410 948701	NADEZHDA GERASIMOVA	{"email": "gerasimova.n071981@postgrespro.ru", "phone": "+70316531617"}
0005434138979	1ABC29	2917 246334	GENNADIY ZAKHAROV	{"email": "gennadiy_zakharov.111973@postgrespro.ru", "phone": "+70036242142"}
0005434138980	1ABC29	4545 476618	ANTONINA SEMENOVA	{"email": "semenovaa-1971@postgrespro.ru", "phone": "+70335363344"}
0005434138981	6C96EF	5189 570600	FATYMA MAKAROVA	{"email": "f-makarova1960@postgrespro.ru", "phone": "+70270320881"}
0005434138982	960F05	8159 885387	SERGEY GUSEV	{"phone": "+70431528276"}
0005434138983	E00F34	6008 954677	ANATOLIY KUZNECOV	{"phone": "+70506521231"}
0005434138984	E00F34	6591 144930	FILIPP EGOROV	{"email": "egorovf_081970@postgrespro.ru", "phone": "+70964676570"}
0005434138985	A6E255	9976 142820	ANDREY MAKAROV	{"email": "a_makarov_29081970@postgrespro.ru", "phone": "+70538572089"}
0005434138986	A6E255	4972 297193	ARTEM TIMOFEEV	{"phone": "+70632075253"}
0005434138987	A6E255	7478 938011	LYUBOV ANDREEVA	{"email": "andreeva_l041982@postgrespro.ru", "phone": "+70030969249"}
0005434138988	3C1C16	0644 693193	IRINA YUDINA	{"phone": "+70852241628"}
0005434138989	3C1C16	8458 312734	ANDREY FROLOV	{"phone": "+70024874506"}
0005434138990	4E7219	7562 104532	MAKSIM GORBUNOV	{"email": "m_gorbunov.1979@postgrespro.ru", "phone": "+70599746613"}
0005434138991	E0CBF4	5118 900136	VITALIY MATVEEV	{"email": "vitaliy_matveev_1976@postgrespro.ru", "phone": "+70223241362"}
0005434138992	E0CBF4	8868 520719	SERGEY KOZLOV	{"phone": "+70936304827"}
0005434138993	E0CBF4	2695 356713	RUSLAN MOISEEV	{"phone": "+70032961062"}
0005434138994	0F4AEB	9221 533321	BORIS SMIRNOV	{"email": "borissmirnov071971@postgrespro.ru", "phone": "+70933377927"}
0005434138995	03163E	1741 864802	ANDREY SCHERBAKOV	{"phone": "+70823879345"}
0005434138996	DC1FDA	4013 724484	PAVEL KRASNOV	{"email": "pkrasnov.01021967@postgrespro.ru", "phone": "+70042263739"}
0005434138997	DC1FDA	3272 962374	DMITRIY PETROV	{"email": "d_petrov101964@postgrespro.ru", "phone": "+70425635299"}
0005434138998	4F2FD2	5348 487203	ALEKSEY KRASNOV	{"phone": "+70087840324"}
0005434138999	E633A9	3573 561668	YULIYA MAKAROVA	{"email": "makarovay17091966@postgrespro.ru", "phone": "+70915766233"}
0005434139000	24B570	5576 165127	MIKHAIL ZAYCEV	{"phone": "+70383984062"}
0005434139001	9D361D	4860 856207	IVAN ORLOV	{"phone": "+70965807415"}
0005434139002	5D29B0	0488 998425	DARYA DMITRIEVA	{"email": "dmitrieva.d-1980@postgrespro.ru", "phone": "+70040094080"}
0005434139003	5DDEAC	2286 464825	EVGENIY EGOROV	{"email": "evgeniy.egorov-1967@postgrespro.ru", "phone": "+70362718081"}
0005434139004	C5189E	4003 190676	NATALYA KULIKOVA	{"email": "kulikova-natalya-051972@postgrespro.ru", "phone": "+70278225250"}
0005434139005	C5189E	3403 215717	NINA MALYSHEVA	{"phone": "+70988183937"}
0005434139006	759FED	6839 515314	IRINA AFANASEVA	{"email": "afanasevairina-011973@postgrespro.ru", "phone": "+70249753802"}
0005434139007	907B52	4080 010524	VLADIMIR MAKAROV	{"email": "v.makarov071983@postgrespro.ru", "phone": "+70822750756"}
0005434139008	907B52	0382 249634	SOFIYA ARKHIPOVA	{"phone": "+70563084579"}
0005434139009	7F8097	4427 127746	MAKSIM ZAKHAROV	{"email": "mzakharov_16111975@postgrespro.ru", "phone": "+70597691347"}
0005434139010	0C55C8	4111 414107	DANIIL MARTYNOV	{"email": "d.martynov.1973@postgrespro.ru", "phone": "+70179319921"}
0005434139011	FC2473	4277 829587	VLADIMIR BORISOV	{"phone": "+70383407720"}
0005434139012	EA6D9D	0700 349793	OLGA VASILEVA	{"email": "vasilevaolga-091971@postgrespro.ru", "phone": "+70383868666"}
0005434139013	3AA6C9	7846 713778	ALEKSEY CHERNOV	{"phone": "+70148433787"}
0005434139014	53FCA9	0756 816758	SERGEY KUZNECOV	{"phone": "+70398599503"}
0005434139015	8F10CE	0794 988182	GULFIYA SIDOROVA	{"phone": "+70561026828"}
0005434139016	8F10CE	9667 843636	ALEKSANDR ZHURAVLEV	{"phone": "+70050872569"}
0005434139017	39D477	0177 907484	YURIY KOROLEV	{"email": "ykorolev-29091978@postgrespro.ru", "phone": "+70838710367"}
0005434139018	ED568A	7326 145850	EVGENIY ILIN	{"phone": "+70575445428"}
0005434139019	8A9028	3353 272909	SERGEY MOISEEV	{"phone": "+70373741730"}
0005434139020	3648BD	8648 302001	VIKTOR NAUMOV	{"email": "naumov.viktor_071979@postgrespro.ru", "phone": "+70412140046"}
0005434139021	3648BD	5154 292674	IRINA SOLOVEVA	{"phone": "+70440095013"}
0005434139022	C43C49	7268 216835	GALINA GORBUNOVA	{"phone": "+70224971831"}
0005434139023	34EC65	5900 628644	VLADIMIR GERASIMOV	{"phone": "+70205663677"}
0005434139024	34EC65	9379 496620	ALEKSANDR KUZNECOV	{"phone": "+70983435541"}
0005434139025	A4FCEE	2463 802883	MIKHAIL NIKOLAEV	{"phone": "+70076819168"}
0005434139026	0EB849	5924 235613	ANASTASIYA ERMAKOVA	{"phone": "+70646169125"}
0005434139027	7ED5D8	3159 366211	RAISA IVANOVA	{"email": "ivanova-r_13081972@postgrespro.ru", "phone": "+70421796638"}
0005434139028	7ED5D8	7599 285881	VLADIMIR CHERNOV	{"email": "vladimir.chernov.1976@postgrespro.ru", "phone": "+70842646510"}
0005434139029	BC397E	6373 685904	ANNA EGOROVA	{"email": "anna_egorova-1966@postgrespro.ru", "phone": "+70894778431"}
0005434139030	C1E9BF	1670 067539	ALEKSANDR EGOROV	{"phone": "+70902455997"}
0005434139142	A2AEB0	5621 566363	GALINA EFREMOVA	{"phone": "+70509249962"}
0005434139031	C1E9BF	1517 518159	PAVEL KONOVALOV	{"email": "pavel-konovalov-021975@postgrespro.ru", "phone": "+70041126071"}
0005434139032	59C795	3186 393224	VLADISLAV MIRONOV	{"email": "vladislav_mironov-1968@postgrespro.ru", "phone": "+70601421637"}
0005434139033	59C795	5585 018728	ALEKSANDR NAZAROV	{"email": "anazarov-1970@postgrespro.ru", "phone": "+70869700698"}
0005434139034	1E3114	7619 686801	ALISA NOVIKOVA	{"email": "novikova-alisa031962@postgrespro.ru", "phone": "+70366541106"}
0005434139035	1CB553	6671 717980	VIKTORIYA MIKHAYLOVA	{"email": "viktoriya-mikhaylova-1966@postgrespro.ru", "phone": "+70227652736"}
0005434139036	46E4E2	5051 003526	YANA NIKOLAEVA	{"email": "yananikolaeva111976@postgrespro.ru", "phone": "+70958589505"}
0005434139037	46E4E2	0861 881515	ANTON KULIKOV	{"phone": "+70213977194"}
0005434139038	73CEC5	7647 119184	VLADISLAV BORISOV	{"email": "borisov-vladislav.071964@postgrespro.ru", "phone": "+70304759423"}
0005434139039	A36174	9418 168606	SERGEY KOZLOV	{"phone": "+70843972381"}
0005434139040	8650AF	6049 748858	NINA KAZAKOVA	{"phone": "+70893764605"}
0005434139041	8650AF	7932 894058	ANZHELA BOGDANOVA	{"email": "bogdanova_anzhela12051973@postgrespro.ru", "phone": "+70456611358"}
0005434139042	C85277	1722 701009	VLADISLAV GUSEV	{"email": "v.gusev_1960@postgrespro.ru", "phone": "+70325930389"}
0005434139043	2433A1	9316 014039	DMITRIY BONDARENKO	{"email": "bondarenko_dmitriy-081957@postgrespro.ru", "phone": "+70105709147"}
0005434139044	489C30	9440 662486	ANDREY VOROBEV	{"phone": "+70467398770"}
0005434139045	489C30	8107 704594	YURIY STEPANOV	{"email": "y-stepanov_18031980@postgrespro.ru", "phone": "+70772089813"}
0005434139046	489C30	1265 590405	TAMARA MELNIKOVA	{"email": "t_melnikova-1973@postgrespro.ru", "phone": "+70341588281"}
0005434139047	1FE168	6355 250861	ELVIRA POPOVA	{"email": "popova-elvira.011981@postgrespro.ru", "phone": "+70418711513"}
0005434139048	E58D3A	3128 364928	YURIY MEDVEDEV	{"phone": "+70238155269"}
0005434139049	788C1E	9182 873105	GENNADIY SEMENOV	{"phone": "+70676408723"}
0005434139050	54A61A	1966 031719	YURIY ALEKSEEV	{"phone": "+70379315763"}
0005434139051	7F19AF	3547 537133	VERA BELOVA	{"email": "v_belova1974@postgrespro.ru", "phone": "+70225281248"}
0005434139052	7F19AF	5293 609717	NATALYA RODIONOVA	{"phone": "+70036507474"}
0005434139053	B7F310	9784 102480	ZINAIDA NOVIKOVA	{"email": "novikova-zinaida_24051975@postgrespro.ru", "phone": "+70566901281"}
0005434139054	07E543	5853 253864	ANATOLIY SCHERBAKOV	{"phone": "+70640432643"}
0005434139055	07E543	3335 857674	ELENA RODIONOVA	{"email": "rodionova_elena.091964@postgrespro.ru", "phone": "+70517844994"}
0005434139056	950173	9109 982584	YULIYA YAKOVLEVA	{"email": "yuliya.yakovleva.22081972@postgrespro.ru", "phone": "+70929789558"}
0005434139057	950173	7531 861727	LYUBOV MAKAROVA	{"email": "makarova_l-011975@postgrespro.ru", "phone": "+70916952088"}
0005434139058	76291D	1539 074949	VALERIY MATVEEV	{"phone": "+70163047932"}
0005434139059	67DBC3	5409 204472	NIKOLAY KOROLEV	{"phone": "+70077665544"}
0005434139060	67DBC3	4797 064132	ILYA IVANOV	{"email": "ilya.ivanov.31031969@postgrespro.ru", "phone": "+70473655698"}
0005434139061	67DBC3	6299 273779	VERA IVANOVA	{"email": "v-ivanova_081962@postgrespro.ru", "phone": "+70111528989"}
0005434139062	53195B	8881 873237	ANNA EGOROVA	{"email": "egorovaa.1967@postgrespro.ru", "phone": "+70800120199"}
0005434139063	A46D3E	3814 593115	KONSTANTIN GRIGOREV	{"email": "grigorev_konstantin_011976@postgrespro.ru", "phone": "+70962553555"}
0005434139064	C590AC	1343 574426	BOGDAN BONDARENKO	{"email": "bogdan_bondarenko.051980@postgrespro.ru", "phone": "+70688413559"}
0005434139065	42FCA5	8579 251577	VITALIY NIKITIN	{"email": "vnikitin-03051980@postgrespro.ru", "phone": "+70871966467"}
0005434139066	42FCA5	2024 745598	NATALIYA KOROLEVA	{"phone": "+70618422915"}
0005434139067	F37EB6	8546 549294	YULIYA MIRONOVA	{"phone": "+70945585581"}
0005434139068	F37EB6	5253 438875	SERGEY EGOROV	{"email": "sergey-egorov-011962@postgrespro.ru", "phone": "+70536203864"}
0005434139069	2C0E13	8090 011075	ALEKSEY MAKAROV	{"phone": "+70453278959"}
0005434139070	2C0E13	6599 695200	VALENTINA POLYAKOVA	{"phone": "+70075599847"}
0005434139071	98BEB3	8505 920464	PETR SERGEEV	{"email": "sergeevpetr111973@postgrespro.ru", "phone": "+70595634389"}
0005434139072	98BEB3	0204 479249	RUSLAN KONOVALOV	{"phone": "+70353461459"}
0005434139073	F89CB1	2645 404567	IRINA SOLOVEVA	{"email": "solovevai.1975@postgrespro.ru", "phone": "+70726022225"}
0005434139074	BDFC4D	8902 200458	NATALYA IVANOVA	{"phone": "+70287413942"}
0005434139075	BDFC4D	4117 416089	GALINA SMIRNOVA	{"email": "g_smirnova15081971@postgrespro.ru", "phone": "+70177370215"}
0005434139076	836476	1004 091927	NATALYA VLASOVA	{"email": "vlasova.n.031970@postgrespro.ru", "phone": "+70091519545"}
0005434139077	836476	2533 450523	LARISA YAKOVLEVA	{"email": "l.yakovleva.041977@postgrespro.ru", "phone": "+70034101972"}
0005434139078	441DD2	3771 697900	VIKTORIYA KARPOVA	{"email": "karpova.viktoriya_021969@postgrespro.ru", "phone": "+70593083445"}
0005434139079	C09360	2786 900430	NATALYA VASILEVA	{"email": "vasileva.n10091969@postgrespro.ru", "phone": "+70648413945"}
0005434139080	919DDF	1484 246965	VYACHESLAV VASILEV	{"phone": "+70868918313"}
0005434139081	21599F	1368 495470	ELENA ANTONOVA	{"email": "antonovaelena.1961@postgrespro.ru", "phone": "+70364409541"}
0005434139082	B0FBBC	6195 619396	IVAN MELNIKOV	{"phone": "+70373051480"}
0005434139083	B0FBBC	6028 070046	VLADIMIR KULIKOV	{"email": "kulikov_vladimir.051981@postgrespro.ru", "phone": "+70028688873"}
0005434139084	C73BB9	1112 882341	NINA LEBEDEVA	{"email": "n_lebedeva.16051974@postgrespro.ru", "phone": "+70710817004"}
0005434139085	AA56EC	5062 420778	LYUDMILA KRASNOVA	{"email": "krasnova-l1967@postgrespro.ru", "phone": "+70171701386"}
0005434139086	AA56EC	4566 536691	OLGA KONOVALOVA	{"email": "olga.konovalova091970@postgrespro.ru", "phone": "+70425868477"}
0005434139087	AA56EC	1354 548716	PAVEL IVANOV	{"email": "pavel_ivanov17061976@postgrespro.ru", "phone": "+70044543644"}
0005434139088	87E0A2	6897 351127	ROMAN RODIONOV	{"email": "rodionov_r.29081970@postgrespro.ru", "phone": "+70896069897"}
0005434139089	87E0A2	3167 214256	GALINA PAVLOVA	{"email": "pavlovag_18011968@postgrespro.ru", "phone": "+70076615533"}
0005434139090	D1ADE7	6280 986405	LILIYA KONDRATEVA	{"phone": "+70290155376"}
0005434139091	D1ADE7	3383 761413	ANDREY NIKOLAEV	{"email": "nikolaev.a.22091967@postgrespro.ru", "phone": "+70646006816"}
0005434139092	91A98C	4157 723495	DANILA ROMANOV	{"phone": "+70526875805"}
0005434139093	D04784	1519 123329	MARAT KUDRYASHOV	{"email": "marat_kudryashov.1970@postgrespro.ru", "phone": "+70198365845"}
0005434139094	6BFF55	6733 993461	KLAVDIYA KUZNECOVA	{"email": "k.kuznecova03041966@postgrespro.ru", "phone": "+70422178062"}
0005434139095	E88A06	0037 425308	GALINA KOLESNIKOVA	{"phone": "+70278150980"}
0005434139096	A65603	0242 615299	MIKHAIL ROMANOV	{"phone": "+70246977996"}
0005434139097	9D9CF4	1373 678816	ANDREY FILIPPOV	{"email": "a_filippov-16031978@postgrespro.ru", "phone": "+70578059961"}
0005434139098	9D9CF4	7062 082569	VALENTINA NIKITINA	{"phone": "+70464285369"}
0005434139099	86281E	7206 977202	LYUBOV GRISHINA	{"phone": "+70632667921"}
0005434139100	FA3DFC	4529 217810	DMITRIY PETROV	{"phone": "+70369457386"}
0005434139101	5FA1FE	7427 907317	EKATERINA SERGEEVA	{"phone": "+70652095159"}
0005434139102	5FA1FE	2766 933327	EVGENIY NIKOLAEV	{"email": "nikolaev_evgeniy.1976@postgrespro.ru", "phone": "+70813696431"}
0005434139103	6CDDD6	8543 073308	NADEZHDA BARANOVA	{"email": "baranova.n_03031976@postgrespro.ru", "phone": "+70860836797"}
0005434139104	D23F37	5569 024394	YURIY FEDOROV	{"phone": "+70137505038"}
0005434139105	D92F07	7352 348222	GALINA ANDREEVA	{"phone": "+70988593849"}
0005434139106	75591B	2624 887471	NATALYA VLASOVA	{"email": "natalya.vlasova1996@postgrespro.ru", "phone": "+70195507572"}
0005434139107	089CDF	7033 910850	VIKTOR ANTONOV	{"email": "viktor.antonov_061968@postgrespro.ru", "phone": "+70468657756"}
0005434139108	DBFE81	4751 006581	MAYA POPOVA	{"phone": "+70741963980"}
0005434139109	FE8F8C	7497 581478	VLADIMIR GAVRILOV	{"phone": "+70166159841"}
0005434139110	FE8F8C	9507 134515	VALENTIN NIKOLAEV	{"phone": "+70884642415"}
0005434139111	992047	4749 849721	VERA DAVYDOVA	{"phone": "+70343847926"}
0005434139112	3500D9	3987 646181	YURIY KOZLOV	{"email": "y-kozlov_011992@postgrespro.ru", "phone": "+70365545754"}
0005434139113	3500D9	4797 929484	NATALIYA NESTEROVA	{"phone": "+70444967437"}
0005434139114	CCDED1	2207 087839	ALEKSANDR FOMIN	{"phone": "+70308048461"}
0005434139115	452D4D	8849 838847	YULIYA PETROVA	{"phone": "+70498108598"}
0005434139116	CA372B	6452 873625	KIRILL VOLKOV	{"email": "kirillvolkov.081971@postgrespro.ru", "phone": "+70036179489"}
0005434139117	47603C	8646 504503	VIKTOR BELOV	{"email": "belovv091976@postgrespro.ru", "phone": "+70403487537"}
0005434139118	47603C	3767 468257	NINA ANDREEVA	{"email": "andreevanina19041969@postgrespro.ru", "phone": "+70824847796"}
0005434139119	4F1BB9	3801 539552	VALENTINA KALININA	{"phone": "+70671637189"}
0005434139120	48D13B	5980 606680	NIKOLAY IVANOV	{"email": "ivanov_n-14021953@postgrespro.ru", "phone": "+70495631752"}
0005434139121	ABD6E6	3300 429009	VLADISLAV ROMANOV	{"email": "romanovvladislav011967@postgrespro.ru", "phone": "+70393839371"}
0005434139122	ABD6E6	9326 143032	ALEKSANDR ILIN	{"email": "ilin_aleksandr.061978@postgrespro.ru", "phone": "+70124896873"}
0005434139123	08650D	2309 187630	ULYANA ZAKHAROVA	{"email": "zakharovau_08031976@postgrespro.ru", "phone": "+70854501112"}
0005434139124	E9B7E4	1838 928592	VLADISLAV KUZMIN	{"phone": "+70992983128"}
0005434139125	5213C0	2272 867582	GALINA SIDOROVA	{"phone": "+70587837160"}
0005434139126	8C3025	4832 437626	ANTON MIKHAYLOV	{"phone": "+70598536539"}
0005434139127	624EBE	0320 369367	ALEKSANDR RODIONOV	{"phone": "+70921638686"}
0005434139128	80FF26	9067 424775	SERGEY SOLOVEV	{"email": "ssolovev.061964@postgrespro.ru", "phone": "+70581013215"}
0005434139129	394D32	6839 819149	ANDREY ROMANOV	{"email": "a.romanov.17071975@postgrespro.ru", "phone": "+70188450290"}
0005434139130	E89D61	1178 516071	ALEKSANDR MARTYNOV	{"email": "amartynov27091966@postgrespro.ru", "phone": "+70605766516"}
0005434139131	B98304	3276 079561	ANASTASIYA TARASOVA	{"phone": "+70250919125"}
0005434139132	96391B	3709 816321	OLGA ANDREEVA	{"phone": "+70238577068"}
0005434139133	A0E3E4	5589 438303	DAMIR ANDREEV	{"phone": "+70118935283"}
0005434139134	873EF9	6369 540779	GALINA KUZNECOVA	{"phone": "+70347055984"}
0005434139135	D51B4E	5602 830954	MARINA NIKITINA	{"email": "nikitina-marina_111981@postgrespro.ru", "phone": "+70013114006"}
0005434139136	D51B4E	9074 140073	SERGEY VASILEV	{"email": "vasilevsergey_1971@postgrespro.ru", "phone": "+70863777606"}
0005434139137	A3A09D	4840 560371	ROMAN KOROLEV	{"phone": "+70078119059"}
0005434139138	CBEC4E	4847 541870	ANTONINA SAVELEVA	{"phone": "+70521217877"}
0005434139139	5C1B73	3428 702541	IVAN FILIPPOV	{"phone": "+70817071166"}
0005434139140	5C1B73	0616 644332	ARTUR SOROKIN	{"email": "a-sorokin-1977@postgrespro.ru", "phone": "+70315543905"}
0005434139141	168FE6	3486 064848	VITALIY TIKHONOV	{"email": "tikhonov_vitaliy.24011968@postgrespro.ru", "phone": "+70126735416"}
0005434139143	A2AEB0	3625 545692	GALINA IVANOVA	{"email": "ivanova_galina22011968@postgrespro.ru", "phone": "+70688732158"}
0005434139144	A2AEB0	7068 200394	NIKOLAY SEMENOV	{"email": "semenov-nikolay1965@postgrespro.ru", "phone": "+70197520274"}
0005434139145	278A16	2491 733540	ANTONINA KONOVALOVA	{"phone": "+70379022387"}
0005434139146	479466	2365 468491	VALERIYA ANTONOVA	{"email": "v-antonova_23061981@postgrespro.ru", "phone": "+70859710437"}
0005434139147	90124A	0921 839179	SERGEY MAKAROV	{"phone": "+70462209914"}
0005434139148	08AACB	4143 521986	VALENTINA MELNIKOVA	{"phone": "+70552614500"}
0005434139149	0B40D8	2380 644119	EVGENIY SOROKIN	{"phone": "+70214141558"}
0005434139150	EEBF57	2152 739011	RAMIL AFANASEV	{"phone": "+70656405444"}
0005434139151	17359B	2463 491388	GENNADIY VOLKOV	{"email": "g.volkov-1973@postgrespro.ru", "phone": "+70996326491"}
0005434139152	17359B	5147 015935	YURIY TARASOV	{"email": "tarasov-y25021966@postgrespro.ru", "phone": "+70202906061"}
0005434139153	94024A	4593 549797	NIKOLAY ZAKHAROV	{"email": "n-zakharov-1956@postgrespro.ru", "phone": "+70306710908"}
0005434139154	94024A	5890 545729	MIKHAIL NIKITIN	{"phone": "+70591130942"}
0005434139155	2C38B0	4401 950965	VIKTORIYA IVANOVA	{"email": "ivanova_viktoriya_1968@postgrespro.ru", "phone": "+70408836432"}
0005434139156	1E9D54	2199 875948	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir-08031975@postgrespro.ru", "phone": "+70012305263"}
0005434139157	1E9D54	0494 591601	ANASTASIYA KOLESNIKOVA	{"phone": "+70158077297"}
0005434139158	3B54F4	4301 030131	VYACHESLAV BELOV	{"phone": "+70358733894"}
0005434139159	3B54F4	3935 371027	DMITRIY KUZNECOV	{"email": "kuznecov.d16031979@postgrespro.ru", "phone": "+70584292707"}
0005434139160	3B54F4	3304 297429	SAVELIY ILIN	{"email": "ilin_saveliy1969@postgrespro.ru", "phone": "+70651118657"}
0005434139161	82A17F	6298 048632	SERGEY GERASIMOV	{"email": "sergey.gerasimov_101980@postgrespro.ru", "phone": "+70654429216"}
0005434139162	F2E6FF	3734 426513	YURIY KONOVALOV	{"phone": "+70091271780"}
0005434139163	9CAB6A	0384 498292	ALBINA MAKSIMOVA	{"phone": "+70760277631"}
0005434139164	9CAB6A	6607 640447	OLGA BARANOVA	{"phone": "+70143462527"}
0005434139165	10C3C7	8221 505002	YURIY KUZMIN	{"phone": "+70135685194"}
0005434139166	10C3C7	5911 276995	IRINA BELYAEVA	{"email": "belyaevai.23031973@postgrespro.ru", "phone": "+70386883074"}
0005434139167	F71054	7802 312444	NATALYA MATVEEVA	{"phone": "+70616370103"}
0005434139168	E3513E	7083 922873	LYUBOV VOROBEVA	{"phone": "+70565559338"}
0005434139169	E3513E	1967 617390	ANATOLIY MIKHAYLOV	{"phone": "+70821368174"}
0005434139170	B6D31C	2798 932238	ALEKSANDR IVANOV	{"phone": "+70167787010"}
0005434139171	B6D31C	6921 233091	NATALYA ANDREEVA	{"email": "andreevan_07121966@postgrespro.ru", "phone": "+70025041951"}
0005434139172	FD8DC4	6069 056514	IGOR NIKITIN	{"phone": "+70088522865"}
0005434139173	FD8DC4	5466 923253	VIKTOR NIKOLAEV	{"phone": "+70159844470"}
0005434139174	ED0E35	8884 992967	VALERIY SCHERBAKOV	{"email": "valeriyscherbakov.1973@postgrespro.ru", "phone": "+70203206372"}
0005434139175	7E3576	9203 964939	GRIGORIY OSIPOV	{"email": "g.osipov121971@postgrespro.ru", "phone": "+70210286806"}
0005434139176	0DADF5	5387 740647	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr.1977@postgrespro.ru", "phone": "+70858608426"}
0005434139177	7BFA78	1491 309372	ANNA NESTEROVA	{"phone": "+70124311304"}
0005434139178	7BFA78	4755 947211	ANTONINA KUDRYASHOVA	{"email": "kudryashova_antonina07121986@postgrespro.ru", "phone": "+70411416480"}
0005434139179	BCB175	7369 769237	ALEKSANDR NIKITIN	{"phone": "+70330776362"}
0005434139180	BCB175	3664 095171	VLADIMIR GAVRILOV	{"email": "gavrilov-v_1973@postgrespro.ru", "phone": "+70077187309"}
0005434139181	145288	8726 380603	ALEVTINA BELOVA	{"email": "a-belova081964@postgrespro.ru", "phone": "+70306792418"}
0005434139182	13952B	5950 224422	VIKTOR PETROV	{"email": "petrov_viktor021974@postgrespro.ru", "phone": "+70855964487"}
0005434139183	13952B	4816 663596	OKSANA SEMENOVA	{"phone": "+70795457331"}
0005434139184	3BA9C1	8073 033731	ELINA VLASOVA	{"email": "elina_vlasova-14061970@postgrespro.ru", "phone": "+70156344695"}
0005434139185	785A85	5182 456423	SERGEY GUSEV	{"email": "gusev_s.08071976@postgrespro.ru", "phone": "+70650881243"}
0005434139186	D32A23	0919 679851	YURIY SCHERBAKOV	{"email": "yuriy_scherbakov.10031978@postgrespro.ru", "phone": "+70182885374"}
0005434139187	C1AC79	4955 478368	VIKTOR SOLOVEV	{"phone": "+70590239345"}
0005434139188	C1AC79	7699 155309	ALEKSANDRA VASILEVA	{"email": "a.vasileva-011967@postgrespro.ru", "phone": "+70604658719"}
0005434139189	E16A0A	7280 577769	ANDREY BELOV	{"phone": "+70706417223"}
0005434139190	E16A0A	0958 764649	KRISTINA NESTEROVA	{"phone": "+70743764941"}
0005434139191	4AEC31	8925 417621	OLGA MEDVEDEVA	{"phone": "+70963321936"}
0005434139192	721663	2670 423492	YANA OVCHINNIKOVA	{"email": "y_ovchinnikova.111981@postgrespro.ru", "phone": "+70073423934"}
0005434139193	721663	0751 605947	NADEZHDA ZOTOVA	{"email": "zotova-nadezhda-28031988@postgrespro.ru", "phone": "+70277151856"}
0005434139194	6AF5B1	2830 039398	ALEKSANDR KUZNECOV	{"phone": "+70770727608"}
0005434139195	6AF5B1	3206 222661	ANNA ZHURAVLEVA	{"phone": "+70797574380"}
0005434139196	6F2DC6	5699 222448	VIKTOR RODIONOV	{"email": "v_rodionov.1970@postgrespro.ru", "phone": "+70519976002"}
0005434139197	6F2DC6	8824 382961	MIKHAIL DENISOV	{"phone": "+70284744238"}
0005434139198	20A665	3694 995197	ELENA VASILEVA	{"email": "vasileva-e-031962@postgrespro.ru", "phone": "+70898358393"}
0005434139199	20A665	5924 943200	FLYURA LUKYANOVA	{"phone": "+70508020907"}
0005434139200	00DEF1	7214 239384	NIKOLAY EGOROV	{"email": "negorov-16071976@postgrespro.ru", "phone": "+70370426099"}
0005434139201	6A7B14	7808 845802	ALEKSANDR SEMENOV	{"email": "a_semenov-101983@postgrespro.ru", "phone": "+70700974157"}
0005434139202	857212	8336 067496	IGOR EGOROV	{"email": "i.egorov.081986@postgrespro.ru", "phone": "+70346889580"}
0005434139203	857212	7884 883382	NATALYA KUZNECOVA	{"phone": "+70275588360"}
0005434139204	B4B8EB	1207 749965	ALEKSEY PAVLOV	{"email": "a-pavlov-31011975@postgrespro.ru", "phone": "+70952869616"}
0005434139205	B4B8EB	0281 428245	OLGA KOZLOVA	{"email": "kozlova_o-1972@postgrespro.ru", "phone": "+70248643376"}
0005434139206	C17230	0046 948822	NATALIYA KUZMINA	{"email": "kuzmina-nataliya121977@postgrespro.ru", "phone": "+70821160216"}
0005434139207	C17230	3838 588364	SERGEY SIDOROV	{"email": "sidorov_s.1971@postgrespro.ru", "phone": "+70561024212"}
0005434139208	4992C7	3832 159005	MARK FEDOROV	{"email": "fedorov.mark23071973@postgrespro.ru", "phone": "+70706641714"}
0005434139209	4992C7	8226 677620	MIKHAIL MIKHAYLOV	{"email": "mikhaylov.mikhail.081973@postgrespro.ru", "phone": "+70356856531"}
0005434139210	AAA28E	8323 696848	IRINA NIKITINA	{"email": "nikitina_i.031959@postgrespro.ru", "phone": "+70690434723"}
0005434139211	136FF8	6233 174028	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey-1976@postgrespro.ru", "phone": "+70665344633"}
0005434139212	15BFA9	1437 424430	ALEKSANDR NOVIKOV	{"phone": "+70440576190"}
0005434139213	DAFD7E	7943 279259	SVETLANA ALEKSANDROVA	{"phone": "+70233181339"}
0005434139214	DD8DE0	4934 932030	ANDREY IVANOV	{"email": "ivanov.andrey-1968@postgrespro.ru", "phone": "+70908659286"}
0005434139215	79E9B2	3364 944290	STANISLAV FEDOROV	{"email": "s.fedorov.03121979@postgrespro.ru", "phone": "+70683974833"}
0005434139216	79E9B2	9816 623117	VLADISLAV MOISEEV	{"phone": "+70566687275"}
0005434139217	027820	3803 967524	LYUDMILA ZAKHAROVA	{"phone": "+70378978737"}
0005434139218	B2E31D	5766 436190	MARSEL IVANOV	{"phone": "+70339258988"}
0005434139219	D204F9	3154 442146	NATALYA ROMANOVA	{"email": "romanovan1980@postgrespro.ru", "phone": "+70967566621"}
0005434139220	3B4916	9336 337235	GALINA POPOVA	{"email": "g_popova.28121972@postgrespro.ru", "phone": "+70342246510"}
0005434139221	268D78	6959 234738	NATALYA SCHERBAKOVA	{"email": "natalya-scherbakova_041976@postgrespro.ru", "phone": "+70171340034"}
0005434139222	9C5451	1782 784086	VIKTOR KUZNECOV	{"email": "viktor_kuznecov.28041966@postgrespro.ru", "phone": "+70858659354"}
0005434139223	15F97D	4485 239568	SERGEY ROMANOV	{"email": "romanov-s30091972@postgrespro.ru", "phone": "+70711988393"}
0005434139224	15F97D	0690 470853	FATIMA GORBUNOVA	{"phone": "+70357387306"}
0005434139225	04CB6A	7392 816185	GALINA KULIKOVA	{"email": "kulikovag-05111978@postgrespro.ru", "phone": "+70007770842"}
0005434139226	FD4FE9	0524 968299	DENIS ANTONOV	{"phone": "+70810772643"}
0005434139227	0D512D	0201 617170	EVGENIY EGOROV	{"email": "evgeniy-egorov-021979@postgrespro.ru", "phone": "+70282440571"}
0005434139228	0D512D	8569 276277	VALENTIN VOROBEV	{"phone": "+70744941497"}
0005434139229	8216D6	3843 721947	IGOR SCHERBAKOV	{"phone": "+70907983006"}
0005434139230	4B2FA4	2501 074855	ILYA FROLOV	{"phone": "+70446152736"}
0005434139231	4B2FA4	9503 338692	IRINA FILIPPOVA	{"email": "ifilippova08111978@postgrespro.ru", "phone": "+70484034666"}
0005434139232	1A1406	1601 659863	GENNADIY MEDVEDEV	{"phone": "+70073976262"}
0005434139233	1A1406	5243 227818	ANZHELA NESTEROVA	{"email": "nesterova.a-10061971@postgrespro.ru", "phone": "+70987267674"}
0005434139234	906D1E	5808 307696	ARTEM MEDVEDEV	{"phone": "+70580799741"}
0005434139293	E415D4	2204 608258	TATYANA PETROVA	{"phone": "+70683748507"}
0005434139235	906D1E	1415 503240	ALEKSANDR SOLOVEV	{"email": "solovev_a071979@postgrespro.ru", "phone": "+70296784356"}
0005434139236	906D1E	3850 126655	GALINA SMIRNOVA	{"email": "smirnova.galina_041958@postgrespro.ru", "phone": "+70470906908"}
0005434139237	4FE8D9	4187 574677	ANASTASIYA MOROZOVA	{"email": "a_morozova-08081969@postgrespro.ru", "phone": "+70437058936"}
0005434139238	0F2220	1191 704073	SERGEY FEDOTOV	{"phone": "+70313038762"}
0005434139239	0F2220	2104 550845	OLGA KOROLEVA	{"email": "olga_koroleva.031958@postgrespro.ru", "phone": "+70155833398"}
0005434139240	DFD22E	0740 151358	EKATERINA SMIRNOVA	{"email": "ekaterina_smirnova1975@postgrespro.ru", "phone": "+70845189552"}
0005434139241	9FEC2C	5424 412026	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov1970@postgrespro.ru", "phone": "+70425398138"}
0005434139242	CA91A0	5087 444526	VLADIMIR IVANOV	{"phone": "+70376223901"}
0005434139243	CA91A0	6240 954143	OKSANA SOLOVEVA	{"phone": "+70071988915"}
0005434139244	5CE4B5	7649 677495	VALENTINA KOZLOVA	{"email": "v.kozlova1962@postgrespro.ru", "phone": "+70526703109"}
0005434139245	5570AE	4704 084630	DMITRIY GRIGOREV	{"email": "grigorevdmitriy-17121969@postgrespro.ru", "phone": "+70849638371"}
0005434139246	12D720	8957 439929	VLADISLAV AFANASEV	{"phone": "+70359362558"}
0005434139247	12D720	6873 722663	EVGENIY NIKITIN	{"phone": "+70103794576"}
0005434139248	37405D	4708 282110	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov-121968@postgrespro.ru", "phone": "+70359871495"}
0005434139249	37405D	1570 386214	DMITRIY FEDOROV	{"phone": "+70785257903"}
0005434139250	312648	3824 565484	ANNA IVANOVA	{"email": "a.ivanova091962@postgrespro.ru", "phone": "+70914756444"}
0005434139251	00D514	7397 245132	LYUBOV FILIPPOVA	{"phone": "+70488267970"}
0005434139252	318EB6	4887 930758	VIKTOR ANTONOV	{"email": "v-antonov_1989@postgrespro.ru", "phone": "+70570453509"}
0005434139253	DB4ECC	2954 711227	TATYANA DANILOVA	{"phone": "+70547873906"}
0005434139254	895477	4728 342062	VIKTOR NAZAROV	{"email": "nazarovviktor101969@postgrespro.ru", "phone": "+70398477289"}
0005434139255	8C83D3	0278 447327	SALAVAT VOLKOV	{"email": "volkovsalavat-07091971@postgrespro.ru", "phone": "+70115296257"}
0005434139256	4D156F	0520 399532	SERGEY VLASOV	{"email": "vlasov_s081970@postgrespro.ru", "phone": "+70997034799"}
0005434139257	79B726	4756 849449	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova-101968@postgrespro.ru", "phone": "+70146999907"}
0005434139258	BA5D82	6044 689796	MIKHAIL GERASIMOV	{"email": "mikhail-gerasimov_1971@postgrespro.ru", "phone": "+70604965082"}
0005434139259	BA5D82	3950 387716	SERGEY KUZMIN	{"phone": "+70910271623"}
0005434139260	FC5711	9343 621376	TIMOFEY ANDREEV	{"phone": "+70713595308"}
0005434139261	FC5711	5490 703129	VALENTINA POPOVA	{"email": "valentina_popova-1964@postgrespro.ru", "phone": "+70707191826"}
0005434139262	A71450	0212 003331	RAISA IVANOVA	{"email": "raisa.ivanova-1976@postgrespro.ru", "phone": "+70278253836"}
0005434139263	D3963A	8889 622108	IGOR FOMIN	{"email": "fomin.i.031979@postgrespro.ru", "phone": "+70538627661"}
0005434139264	D3963A	9555 490328	LYUBOV KOVALEVA	{"email": "l.kovaleva_101986@postgrespro.ru", "phone": "+70466362801"}
0005434139265	5ACE09	2277 615811	YURIY MIRONOV	{"email": "mironov_yuriy_021973@postgrespro.ru", "phone": "+70720150316"}
0005434139266	B296FD	6860 544795	NATALIYA YUDINA	{"phone": "+70586266873"}
0005434139267	87F913	7506 585005	ALEKSANDR MOROZOV	{"phone": "+70045572695"}
0005434139268	87F913	7173 381483	ALEKSEY ABRAMOV	{"email": "aleksey-abramov1974@postgrespro.ru", "phone": "+70853060998"}
0005434139269	67AB52	3714 714915	SERGEY MELNIKOV	{"email": "melnikov.s061951@postgrespro.ru", "phone": "+70018589025"}
0005434139270	67AB52	9608 968522	ILYA ROMANOV	{"phone": "+70999139707"}
0005434139271	BFFAFA	7201 389152	VITALIY VASILEV	{"email": "vasilev_vitaliy-25041962@postgrespro.ru", "phone": "+70922056393"}
0005434139272	BD5125	4969 351615	ALEKSANDR SEMENOV	{"phone": "+70659073964"}
0005434139273	15C832	0376 275124	IVAN BONDARENKO	{"email": "bondarenko-ivan.091973@postgrespro.ru", "phone": "+70062641551"}
0005434139274	32F339	1854 724390	ARMEN ZAYCEV	{"email": "azaycev-121959@postgrespro.ru", "phone": "+70817845883"}
0005434139275	588F07	8858 339973	LARISA NOVIKOVA	{"email": "larisanovikova_1973@postgrespro.ru", "phone": "+70303027317"}
0005434139276	7A3E53	2784 542851	OLEG SOKOLOV	{"phone": "+70351578617"}
0005434139277	69A62A	1746 742537	ALEKSANDR IVANOV	{"phone": "+70553126425"}
0005434139278	A837C2	1516 500685	NIKOLAY TARASOV	{"email": "n-tarasov_041970@postgrespro.ru", "phone": "+70425523540"}
0005434139279	A837C2	7149 884090	ANATOLIY EGOROV	{"phone": "+70910990378"}
0005434139280	CE773B	5371 828441	LYUDMILA PAVLOVA	{"phone": "+70444220526"}
0005434139281	256E7F	1520 599344	VIKTOR KULIKOV	{"email": "vkulikov.02031972@postgrespro.ru", "phone": "+70217358742"}
0005434139282	C94CB3	4686 568428	RUMIYA POLYAKOVA	{"email": "polyakova_rumiya-10031976@postgrespro.ru", "phone": "+70490052122"}
0005434139283	C94CB3	3995 612782	RAVIL ZHURAVLEV	{"phone": "+70603933204"}
0005434139284	EA7A4C	3754 373566	ANNA MAKAROVA	{"phone": "+70366387383"}
0005434139285	EA7A4C	0031 586323	YURIY BORISOV	{"phone": "+70002038631"}
0005434139286	6146C0	4496 122917	VLADLEN ZAKHAROV	{"email": "vzakharov1973@postgrespro.ru", "phone": "+70974029534"}
0005434139287	FABCF4	1830 249883	ELENA KOVALEVA	{"phone": "+70678494236"}
0005434139288	3D88B8	0773 643478	SERGEY VASILEV	{"email": "sergey_vasilev1973@postgrespro.ru", "phone": "+70067253281"}
0005434139289	9D5775	2901 251446	TATYANA ANISIMOVA	{"email": "t.anisimova071983@postgrespro.ru", "phone": "+70047630603"}
0005434139290	51BA0F	0179 348892	LYUBOV ORLOVA	{"email": "orlova_lyubov031964@postgrespro.ru", "phone": "+70274178638"}
0005434139291	51BA0F	9279 058074	RAIL SMIRNOV	{"email": "rail-smirnov101974@postgrespro.ru", "phone": "+70373129350"}
0005434139292	FB2653	0757 265489	FEDOR ANDREEV	{"email": "andreev-f-02031978@postgrespro.ru", "phone": "+70200947253"}
0005434139294	3A312F	9411 235316	VERA DAVYDOVA	{"phone": "+70440755958"}
0005434139295	E4084D	6517 808449	VALENTINA BORISOVA	{"email": "borisovavalentina.1977@postgrespro.ru", "phone": "+70080824880"}
0005434139296	986D86	2021 698858	LIDIYA ALEKSANDROVA	{"phone": "+70463820803"}
0005434139297	6B202F	4949 678436	DMITRIY VASILEV	{"email": "d.vasilev_03011983@postgrespro.ru", "phone": "+70866963397"}
0005434139298	6B202F	3410 624883	ANDREY SERGEEV	{"phone": "+70615933988"}
0005434139299	6B202F	9256 597834	NATALYA KOZLOVA	{"phone": "+70816743625"}
0005434139300	6BD528	0145 406191	VASILIY SHEVCHENKO	{"email": "v_shevchenko.061970@postgrespro.ru", "phone": "+70727813951"}
0005434139301	6BD528	0091 277486	EKATERINA POPOVA	{"phone": "+70990850372"}
0005434139302	6BD528	1595 836389	ALEKSEY KUZMIN	{"email": "alekseykuzmin111978@postgrespro.ru", "phone": "+70854909332"}
0005434139303	274B3E	3710 493212	MIKHAIL ALEKSANDROV	{"email": "mikhailaleksandrov.1969@postgrespro.ru", "phone": "+70395796759"}
0005434139304	CE6877	3103 711287	DMITRIY PAVLOV	{"phone": "+70554524127"}
0005434139305	4582D7	7271 721016	DMITRIY FILIPPOV	{"phone": "+70824628862"}
0005434139306	4582D7	7659 866759	EVGENIY MELNIKOV	{"email": "melnikov-e1974@postgrespro.ru", "phone": "+70106906238"}
0005434139307	4CBA6B	6594 344363	ARTUR SCHERBAKOV	{"phone": "+70009235187"}
0005434139308	BA3A40	0470 200610	ASIYA VASILEVA	{"phone": "+70585032418"}
0005434139309	EBEBF2	8947 792528	PAVEL ISAEV	{"email": "pavel_isaev28061974@postgrespro.ru", "phone": "+70461413298"}
0005434139310	EBEBF2	5860 785407	EVGENIY SIDOROV	{"email": "e_sidorov.1984@postgrespro.ru", "phone": "+70316571257"}
0005434139311	C5F1A6	4382 938626	ALEKSANDR MAKSIMOV	{"phone": "+70044306759"}
0005434139312	1F701B	4454 004759	FEDOR GUSEV	{"phone": "+70439545975"}
0005434139313	1F701B	4795 009908	LYUDMILA ZOTOVA	{"phone": "+70820058614"}
0005434139314	1F701B	6363 266696	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr_121971@postgrespro.ru", "phone": "+70829742532"}
0005434139315	36E6FC	2516 524743	ULYANA BORISOVA	{"email": "ulyanaborisova.081964@postgrespro.ru", "phone": "+70411987243"}
0005434139316	791CA1	5342 201189	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov.11081973@postgrespro.ru", "phone": "+70906322465"}
0005434139317	051FC5	4085 931778	VLADIMIR DAVYDOV	{"phone": "+70167748067"}
0005434139318	7BEDEB	7606 662169	ANTON MIRONOV	{"email": "antonmironov_22051964@postgrespro.ru", "phone": "+70782802905"}
0005434139319	7BEDEB	8153 267569	MIKHAIL MELNIKOV	{"phone": "+70366879086"}
0005434139320	8729CF	5944 889335	MARIYA KOROLEVA	{"email": "m-koroleva30041971@postgrespro.ru", "phone": "+70062805777"}
0005434139321	8729CF	9441 376344	SERGEY FROLOV	{"email": "sergey.frolov.071976@postgrespro.ru", "phone": "+70664857326"}
0005434139322	33FBF3	2935 391966	LIDIYA KOMAROVA	{"phone": "+70793741355"}
0005434139323	467523	4745 176918	YURIY KARPOV	{"email": "yuriy.karpov_10101969@postgrespro.ru", "phone": "+70274431313"}
0005434139324	22B240	0988 402349	OLEG KUZMIN	{"phone": "+70964166952"}
0005434139325	D80719	9420 300466	ANASTASIYA SOROKINA	{"email": "anastasiya_sorokina_10061972@postgrespro.ru", "phone": "+70361429598"}
0005434139326	D80719	2292 771167	SERGEY PETROV	{"email": "sergeypetrov-1980@postgrespro.ru", "phone": "+70087723797"}
0005434139327	972360	1304 135058	ELENA EGOROVA	{"phone": "+70538741850"}
0005434139328	972360	7044 589019	NINA DENISOVA	{"email": "n-denisova-071978@postgrespro.ru", "phone": "+70950563595"}
0005434139329	972360	3045 686927	ANNA ZAKHAROVA	{"phone": "+70298617862"}
0005434139330	972360	5352 924424	VASILIY KAZAKOV	{"email": "v-kazakov-121970@postgrespro.ru", "phone": "+70559720541"}
0005434139331	50DD7B	6621 914136	SARIYA LAZAREVA	{"phone": "+70593833201"}
0005434139332	50DD7B	1178 228645	VLADIMIR POPOV	{"email": "vladimir_popov_1962@postgrespro.ru", "phone": "+70569375511"}
0005434139333	32B301	2443 207299	STANISLAV MAKAROV	{"email": "makarov_stanislav_19031961@postgrespro.ru", "phone": "+70054559647"}
0005434139334	32B301	3413 950277	VIKTOR OSIPOV	{"phone": "+70830734634"}
0005434139335	91F070	5100 379142	SVETLANA GORBUNOVA	{"phone": "+70793257012"}
0005434139336	5D9F09	4491 178063	DMITRIY STEPANOV	{"email": "stepanov-dmitriy.07071969@postgrespro.ru", "phone": "+70330636628"}
0005434139337	6CCC69	3009 897200	VIKTOR PETROV	{"email": "petrov.viktor.101977@postgrespro.ru", "phone": "+70810556667"}
0005434139338	6CCC69	8389 235233	MARIYA POPOVA	{"phone": "+70467672105"}
0005434139339	4EDCF9	9732 977509	VLADIMIR POPOV	{"email": "popovv091971@postgrespro.ru", "phone": "+70676002575"}
0005434139340	1176C5	2771 258635	STANISLAV SOROKIN	{"email": "sorokin-s.1974@postgrespro.ru", "phone": "+70415653364"}
0005434139341	1176C5	2961 605313	BORIS MIKHAYLOV	{"email": "mikhaylov_b1976@postgrespro.ru", "phone": "+70418444181"}
0005434139342	487218	2480 312299	OLEG KUZMIN	{"phone": "+70037543142"}
0005434139343	D14C30	4759 600384	OLGA KONOVALOVA	{"email": "olga.konovalova_26091964@postgrespro.ru", "phone": "+70007926690"}
0005434139344	733D02	2361 192772	PAVEL POPOV	{"phone": "+70518164719"}
0005434139345	733D02	4215 123112	GALINA SIDOROVA	{"email": "sidorova.g07121980@postgrespro.ru", "phone": "+70740117893"}
0005434139346	1234E3	0835 028223	TIKHON ROMANOV	{"email": "t.romanov.1967@postgrespro.ru", "phone": "+70219049287"}
0005434139347	725011	0740 693917	ALEKSEY KUZNECOV	{"phone": "+70671077603"}
0005434139348	D5960B	4800 913870	ANDREY ZAKHAROV	{"phone": "+70995235593"}
0005434139349	944465	0336 704454	KRISTINA TIMOFEEVA	{"email": "kristina-timofeeva_031978@postgrespro.ru", "phone": "+70574135365"}
0005434139350	066EA0	6276 252542	TATYANA NIKIFOROVA	{"email": "tnikiforova_111974@postgrespro.ru", "phone": "+70427040599"}
0005434139351	066EA0	3874 467593	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin-1977@postgrespro.ru", "phone": "+70339245185"}
0005434139352	85B654	9373 742685	EKATERINA NIKITINA	{"phone": "+70041181180"}
0005434139353	0E825F	9820 740399	MIKHAIL ORLOV	{"phone": "+70053794406"}
0005434139354	0E825F	1069 081864	ELENA KOROLEVA	{"email": "koroleva.e1981@postgrespro.ru", "phone": "+70986498320"}
0005434139355	0E825F	9757 362475	SVETLANA NOVIKOVA	{"phone": "+70413600638"}
0005434139356	6CFB1B	8637 642708	ELENA KUZNECOVA	{"email": "elena.kuznecova_1966@postgrespro.ru", "phone": "+70280958437"}
0005434139357	7F4D6A	8297 576865	VALENTINA LUKYANOVA	{"email": "valentina_lukyanova.101967@postgrespro.ru", "phone": "+70958769811"}
0005434139358	C4D1C6	2093 487534	VITALIY ZHUKOV	{"phone": "+70625228706"}
0005434139359	225B6F	7065 233914	MIKHAIL KULIKOV	{"email": "kulikovmikhail-30051967@postgrespro.ru", "phone": "+70151641286"}
0005434139360	584B71	0280 186828	ALEKSANDR EGOROV	{"phone": "+70076064733"}
0005434139361	584B71	1506 038718	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey.1978@postgrespro.ru", "phone": "+70716317360"}
0005434139362	132646	7657 004960	TATYANA YUDINA	{"phone": "+70132970452"}
0005434139363	697B3A	6612 789656	ANDREY ABRAMOV	{"email": "abramov_a-021978@postgrespro.ru", "phone": "+70071379757"}
0005434139364	A3A9FA	0095 151491	VERA ERMAKOVA	{"phone": "+70885113739"}
0005434139532	F5B091	5094 760993	ULYANA ILINA	{"phone": "+70230633853"}
0005434139365	C6B30F	3679 863620	SERGEY GORBUNOV	{"email": "gorbunov_sergey1973@postgrespro.ru", "phone": "+70023812458"}
0005434139366	C6B30F	9647 073575	NADEZHDA NAUMOVA	{"phone": "+70787225428"}
0005434139367	AD1C6D	8799 683482	MILENA MASLOVA	{"phone": "+70398095135"}
0005434139368	0F7658	9788 355773	VITALIY KUZMIN	{"email": "kuzmin-v-04011962@postgrespro.ru", "phone": "+70633358443"}
0005434139369	0F7658	7304 510824	EKATERINA FROLOVA	{"email": "e-frolova.25051983@postgrespro.ru", "phone": "+70400203915"}
0005434139370	2FCE51	9275 955098	EKATERINA GERASIMOVA	{"phone": "+70367914123"}
0005434139371	444C07	1713 508975	NADEZHDA ANDREEVA	{"email": "n-andreeva-27031976@postgrespro.ru", "phone": "+70481664934"}
0005434139372	444C07	1385 477710	TAMARA NIKOLAEVA	{"email": "tamaranikolaeva-25061976@postgrespro.ru", "phone": "+70464417597"}
0005434139373	D03CED	6729 064977	ALEKSANDRA TARASOVA	{"email": "tarasova-aleksandra.02021961@postgrespro.ru", "phone": "+70897525574"}
0005434139374	D03CED	3330 461943	VYACHESLAV PETROV	{"email": "v-petrov1965@postgrespro.ru", "phone": "+70327746673"}
0005434139375	18CFF4	2770 521010	ELLA NAZAROVA	{"phone": "+70849117717"}
0005434139376	18CFF4	9544 566711	MAKSIM TIKHONOV	{"phone": "+70055702590"}
0005434139377	A77EC7	4458 527868	ELENA ILINA	{"email": "ilina_elena28101975@postgrespro.ru", "phone": "+70259998027"}
0005434139378	A77EC7	3985 675389	NATALYA YUDINA	{"email": "n-yudina.1972@postgrespro.ru", "phone": "+70325244613"}
0005434139379	C81811	4015 548464	ANATOLIY OSIPOV	{"phone": "+70106465832"}
0005434139380	C81811	9935 999687	VIKTORIYA DAVYDOVA	{"phone": "+70760313144"}
0005434139381	FB2ABF	2532 109894	TATYANA TIKHONOVA	{"email": "tikhonovatatyana.031968@postgrespro.ru", "phone": "+70630876422"}
0005434139382	14998F	0569 155766	MARINA ZAKHAROVA	{"email": "marina-zakharova_1971@postgrespro.ru", "phone": "+70673827568"}
0005434139383	68B52F	2213 429534	FAINA POTAPOVA	{"email": "fpotapova_111977@postgrespro.ru", "phone": "+70302884291"}
0005434139384	68B52F	4321 594014	VLADIMIR VOROBEV	{"phone": "+70126606811"}
0005434139385	39313C	2421 943953	IVAN TARASOV	{"phone": "+70836146516"}
0005434139386	586BF1	2058 348573	MIKHAIL GRIGOREV	{"phone": "+70605411196"}
0005434139387	873809	0987 371227	ELENA KUZNECOVA	{"email": "elena.kuznecova041963@postgrespro.ru", "phone": "+70279923072"}
0005434139388	0F40DF	6093 108597	NIKITA KISELEV	{"email": "nikita.kiselev-05081969@postgrespro.ru", "phone": "+70157207541"}
0005434139389	562D14	2839 119714	SVETLANA VLASOVA	{"email": "svetlana.vlasova-1957@postgrespro.ru", "phone": "+70029855976"}
0005434139390	A9D9B3	9386 206977	DIANA DANILOVA	{"phone": "+70592344154"}
0005434139391	5446F5	4586 199357	NATALYA BELYAEVA	{"phone": "+70123098560"}
0005434139392	197D93	7627 538293	RITA OSIPOVA	{"email": "rita_osipova-1971@postgrespro.ru", "phone": "+70531259000"}
0005434139393	197D93	6063 928137	MAKSIM CHERNOV	{"phone": "+70614461472"}
0005434139394	78EF51	3795 787744	ALEKSEY MIRONOV	{"email": "aleksey-mironov.1984@postgrespro.ru", "phone": "+70311826000"}
0005434139563	91BDA5	4206 059257	GALINA VOLKOVA	{"phone": "+70021601592"}
0005434139395	C5D029	7922 376819	SVETLANA KRASNOVA	{"email": "krasnovasvetlana1968@postgrespro.ru", "phone": "+70895051399"}
0005434139396	180DC2	6702 560334	ALEKSANDR SOKOLOV	{"phone": "+70182658831"}
0005434139397	6CB378	2009 472546	DMITRIY ALEKSANDROV	{"phone": "+70996449025"}
0005434139398	F3708F	7278 028318	IVAN NIKOLAEV	{"phone": "+70976658849"}
0005434139399	F3708F	2448 765372	OLEG IVANOV	{"phone": "+70095122259"}
0005434139400	E58886	4309 419549	ELENA KOZLOVA	{"phone": "+70219015449"}
0005434139401	ECD82D	1480 214651	DMITRIY CHERNOV	{"email": "chernov.d_081972@postgrespro.ru", "phone": "+70486092585"}
0005434139402	935CC1	5746 786029	ALEKSANDR YAKOVLEV	{"phone": "+70641873022"}
0005434139403	935CC1	4788 107555	VLADIMIR YAKOVLEV	{"phone": "+70365708686"}
0005434139404	9857C5	6310 603182	MIKHAIL SCHERBAKOV	{"phone": "+70541151796"}
0005434139405	1FD57C	6119 925150	ALEKSEY ZAKHAROV	{"email": "zakharov-aleksey.021982@postgrespro.ru", "phone": "+70832905050"}
0005434139406	236D0F	5898 792979	ANTONINA DAVYDOVA	{"phone": "+70980298182"}
0005434139407	AE6331	1147 002281	PAVEL KUZNECOV	{"email": "pkuznecov.111970@postgrespro.ru", "phone": "+70355780736"}
0005434139408	AE6331	7293 351103	NIKOLAY KISELEV	{"email": "nikolay-kiselev-1970@postgrespro.ru", "phone": "+70966924292"}
0005434139409	AE6331	3712 615566	ANATOLIY MIRONOV	{"phone": "+70325126509"}
0005434139410	75A0C0	1142 384767	TATYANA KRASNOVA	{"phone": "+70176507688"}
0005434139411	75A0C0	1241 426491	ALEKSEY ILIN	{"email": "ilin-aleksey-1966@postgrespro.ru", "phone": "+70296557137"}
0005434139412	D615AC	4611 257622	SERGEY KONOVALOV	{"phone": "+70250389241"}
0005434139413	D615AC	5339 255685	VASILIY PAVLOV	{"phone": "+70932366520"}
0005434139414	21B099	2842 135230	VASILIY IVANOV	{"phone": "+70843546943"}
0005434139415	51D813	5491 875647	SVETLANA SERGEEVA	{"email": "sergeeva_svetlana071958@postgrespro.ru", "phone": "+70446929835"}
0005434139416	625E13	3663 220241	ANATOLIY RODIONOV	{"phone": "+70263607790"}
0005434139417	C829A4	6254 464542	ANNA KRASNOVA	{"email": "akrasnova051976@postgrespro.ru", "phone": "+70271782132"}
0005434139418	825664	6765 980983	ANNA ANDREEVA	{"phone": "+70103996508"}
0005434139419	74ACF2	9656 715331	POLINA FILIPPOVA	{"email": "polina-filippova-031961@postgrespro.ru", "phone": "+70368654684"}
0005434139420	E02BE3	5168 626064	TATYANA KOVALEVA	{"email": "kovaleva_t_19061968@postgrespro.ru", "phone": "+70149007310"}
0005434139421	99DBC9	7462 375783	VLADIMIR PETROV	{"email": "petrov.vladimir.02121973@postgrespro.ru", "phone": "+70411642839"}
0005434139422	6BEFB4	4755 493301	LARISA ZAKHAROVA	{"email": "zakharovalarisa-081974@postgrespro.ru", "phone": "+70057511445"}
0005434139423	93C751	2219 009318	VIKTOR ANTONOV	{"email": "v_antonov_011965@postgrespro.ru", "phone": "+70672253220"}
0005434139424	87734F	3355 146494	ALLA SAVELEVA	{"phone": "+70234248244"}
0005434139425	87734F	9195 871744	IRINA ISAEVA	{"email": "isaeva_i.04021974@postgrespro.ru", "phone": "+70060257130"}
0005434139426	A2E431	7604 858646	SVETLANA ILINA	{"phone": "+70822883563"}
0005434139427	A2E431	2469 344556	MIKHAIL VOROBEV	{"phone": "+70195034889"}
0005434139428	42B1EF	8338 478735	NADEZHDA VLASOVA	{"email": "n-vlasova_1961@postgrespro.ru", "phone": "+70727812790"}
0005434139429	42B1EF	4357 786673	MIKHAIL TIKHONOV	{"email": "tikhonov-m_1974@postgrespro.ru", "phone": "+70975459538"}
0005434139430	9A8499	0707 011489	ZAKHAR MIKHAYLOV	{"phone": "+70668626319"}
0005434139431	3E692E	3647 734211	ALEKSANDR KUZNECOV	{"phone": "+70395893963"}
0005434139432	1A03A6	7713 666919	ELENA ZAKHAROVA	{"phone": "+70333870699"}
0005434139433	974D84	7835 555042	ANNA VOLKOVA	{"email": "a-volkova_23021970@postgrespro.ru", "phone": "+70305795393"}
0005434139434	974D84	1139 510071	VALENTINA VOLKOVA	{"email": "volkova-valentina_021968@postgrespro.ru", "phone": "+70126110599"}
0005434139435	AEA854	4855 836660	YURIY KUZNECOV	{"email": "kuznecov-y-25051969@postgrespro.ru", "phone": "+70562590246"}
0005434139436	37053E	4103 162870	ALENA PETROVA	{"email": "petrova-a121976@postgrespro.ru", "phone": "+70782684529"}
0005434139437	9868DF	2373 943719	RAISA VLASOVA	{"email": "vlasova_raisa-1975@postgrespro.ru", "phone": "+70844860558"}
0005434139438	A1C9F8	3336 329606	SVETLANA KOROLEVA	{"phone": "+70567513903"}
0005434139439	A1C9F8	0692 423028	NIKOLAY GRIGOREV	{"email": "n.grigorev-021968@postgrespro.ru", "phone": "+70939461373"}
0005434139440	7B96B9	2824 079629	IVAN VOLKOV	{"phone": "+70327825801"}
0005434139441	7B96B9	5924 350672	ANATOLIY KUZNECOV	{"phone": "+70121441614"}
0005434139442	73AEF3	3464 068410	ALEKSEY DENISOV	{"email": "alekseydenisov_01011986@postgrespro.ru", "phone": "+70649545961"}
0005434139443	73AEF3	6440 758761	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr.1974@postgrespro.ru", "phone": "+70855622390"}
0005434139444	5ED82D	3837 431901	ALEKSEY YAKOVLEV	{"email": "yakovlev.a05051971@postgrespro.ru", "phone": "+70083486435"}
0005434139445	CF72FC	1577 846580	NIKOLAY MIKHAYLOV	{"phone": "+70205147637"}
0005434139446	84E515	2978 040442	OKSANA SOROKINA	{"phone": "+70384364026"}
0005434139447	38D297	5287 856626	OLESYA SIDOROVA	{"email": "olesya-sidorova-31081966@postgrespro.ru", "phone": "+70901359551"}
0005434139448	5A5FA3	7657 371603	VIKTOR TIKHONOV	{"email": "vtikhonov-1977@postgrespro.ru", "phone": "+70216398210"}
0005434139449	486F48	6281 012432	ALEKSANDR SOKOLOV	{"email": "sokolova071977@postgrespro.ru", "phone": "+70488387111"}
0005434139450	486F48	0075 577247	OLGA KISELEVA	{"email": "kiseleva_olga1970@postgrespro.ru", "phone": "+70810534573"}
0005434139451	E018F4	4356 090191	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a-28011970@postgrespro.ru", "phone": "+70463942063"}
0005434139452	E018F4	2818 350622	ANASTASIYA MAKAROVA	{"email": "makarova.a.19021973@postgrespro.ru", "phone": "+70918664176"}
0005434139453	BE8E96	6859 283872	VYACHESLAV KAZAKOV	{"phone": "+70908654275"}
0005434139454	BE8E96	0616 857465	MIKHAIL BARANOV	{"email": "baranov.mikhail.1971@postgrespro.ru", "phone": "+70538785205"}
0005434139455	CE8EE6	5195 255429	ALEKSANDR KUZMIN	{"phone": "+70680158526"}
0005434139456	2DBD1D	5321 500646	LYUDMILA MAKSIMOVA	{"phone": "+70611545360"}
0005434139457	22EBE8	6699 909286	IRINA PETROVA	{"phone": "+70756274079"}
0005434139458	612003	9255 989642	ANATOLIY POPOV	{"email": "anatoliy-popov071966@postgrespro.ru", "phone": "+70470816556"}
0005434139459	C374A9	6021 646996	YURIY SERGEEV	{"email": "sergeev-yuriy.071982@postgrespro.ru", "phone": "+70160823714"}
0005434139460	C374A9	4421 166638	NURIYA KOROLEVA	{"phone": "+70244946770"}
0005434139461	3EA655	9206 332525	ALEKSANDRA PAVLOVA	{"email": "pavlova.aleksandra_09061985@postgrespro.ru", "phone": "+70762064069"}
0005434139462	2CFCD0	7171 204130	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev.081967@postgrespro.ru", "phone": "+70871495104"}
0005434139463	319F67	5914 450305	ALEKSANDR KONOVALOV	{"phone": "+70778094282"}
0005434139464	9ADB13	6230 716068	OKSANA KUZMINA	{"email": "kuzmina_o-30061976@postgrespro.ru", "phone": "+70967996033"}
0005434139465	6B78A2	2662 901205	ELENA ANDREEVA	{"email": "elena.andreeva081979@postgrespro.ru", "phone": "+70329629918"}
0005434139466	F3D189	2532 677619	MARINA FILIPPOVA	{"email": "filippova.m.121959@postgrespro.ru", "phone": "+70052921135"}
0005434139467	F3D189	2135 871809	NATALYA MATVEEVA	{"email": "natalya-matveeva04121972@postgrespro.ru", "phone": "+70020472090"}
0005434139468	36A127	0889 116991	MAKSIM ANTONOV	{"email": "antonov_m-061984@postgrespro.ru", "phone": "+70106061473"}
0005434139469	AA067A	7767 019113	ANNA FROLOVA	{"email": "frolovaanna-15081964@postgrespro.ru", "phone": "+70805342464"}
0005434139470	5FA523	8963 791482	OKSANA VLASOVA	{"phone": "+70703508161"}
0005434139471	5FA523	2154 030061	VALENTINA ZHUKOVA	{"email": "zhukova.v13091976@postgrespro.ru", "phone": "+70532186245"}
0005434139472	2BBC84	2794 336365	SVETLANA NIKIFOROVA	{"phone": "+70049920324"}
0005434139473	3D5327	4223 083558	YANA SERGEEVA	{"phone": "+70811242306"}
0005434139474	765DD8	9656 381495	VALERIY VOROBEV	{"phone": "+70526407799"}
0005434139475	E65FBF	8411 242827	KONSTANTIN VASILEV	{"email": "vasilevkonstantin-20061984@postgrespro.ru", "phone": "+70961913741"}
0005434139476	CABE77	2208 447360	OLGA POPOVA	{"email": "olga-popova051979@postgrespro.ru", "phone": "+70754845671"}
0005434139477	A5EDE3	8035 193978	VLADIMIR FEDOROV	{"email": "fedorovvladimir17071974@postgrespro.ru", "phone": "+70357023423"}
0005434139478	918973	8411 732428	SERGEY KAZAKOV	{"phone": "+70516410425"}
0005434139479	918973	0945 921778	RAISA NOVIKOVA	{"phone": "+70410115613"}
0005434139480	D874A1	1982 216256	ANNA DMITRIEVA	{"email": "dmitrieva.a_22101970@postgrespro.ru", "phone": "+70398414525"}
0005434139481	D874A1	5421 608031	DMITRIY TIKHONOV	{"email": "tikhonov-dmitriy-1965@postgrespro.ru", "phone": "+70986822552"}
0005434139482	D874A1	3713 694145	VLADIMIR MEDVEDEV	{"phone": "+70769635197"}
0005434139483	5DF9EF	5872 285968	ALEKSANDRA KUZNECOVA	{"phone": "+70507986497"}
0005434139484	276E74	5769 223053	NINA VASILEVA	{"email": "vasileva_nina.1972@postgrespro.ru", "phone": "+70200265796"}
0005434139485	3F9C0F	2584 444384	NATALIYA IVANOVA	{"phone": "+70506137521"}
0005434139486	3F9C0F	7771 461824	NIKOLAY ROMANOV	{"email": "romanovnikolay.20111972@postgrespro.ru", "phone": "+70435432466"}
0005434139487	A8ED97	5408 828880	VALENTINA NIKIFOROVA	{"phone": "+70217286230"}
0005434139488	3B809D	6803 873079	ANASTASIYA MELNIKOVA	{"phone": "+70878763088"}
0005434139489	647138	2515 410123	VLADIMIR SAVELEV	{"phone": "+70674778711"}
0005434139490	647138	1698 060621	VERA FILATOVA	{"phone": "+70042410550"}
0005434139491	184DD5	3306 846675	VLADIMIR BELOV	{"email": "vladimir.belov021973@postgrespro.ru", "phone": "+70166580028"}
0005434139492	1A4A7C	1359 896167	IVAN VASILEV	{"phone": "+70774864213"}
0005434139493	366E18	5405 084991	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a.011976@postgrespro.ru", "phone": "+70635721875"}
0005434139494	A555EE	1495 817282	NIKOLAY KOZLOV	{"phone": "+70185615501"}
0005434139495	A555EE	4689 305274	MARFA ANTONOVA	{"email": "m-antonova1977@postgrespro.ru", "phone": "+70545968746"}
0005434139496	670887	2931 796128	IVAN ZHUKOV	{"email": "i-zhukov-101969@postgrespro.ru", "phone": "+70232035844"}
0005434139497	32CA7F	0370 092050	TATYANA FROLOVA	{"phone": "+70864407432"}
0005434139498	32CA7F	2760 209705	ELENA KOVALEVA	{"phone": "+70627012118"}
0005434139499	AB1A55	0260 028703	IRINA SOLOVEVA	{"email": "i-soloveva-03121970@postgrespro.ru", "phone": "+70687870609"}
0005434139500	AB1A55	9164 653560	MIKHAIL SIDOROV	{"phone": "+70393187460"}
0005434139501	5F87BC	3854 174255	ANGELINA KUZMINA	{"email": "a-kuzmina.031970@postgrespro.ru", "phone": "+70934086362"}
0005434139502	820995	3921 478148	YURIY KUDRYASHOV	{"phone": "+70159748497"}
0005434139503	820995	7489 156059	VASILIY PAVLOV	{"phone": "+70749744081"}
0005434139504	75DD75	9939 514724	EGOR DAVYDOV	{"phone": "+70196114604"}
0005434139505	5812EB	8757 983764	INNA KULIKOVA	{"email": "inna.kulikova_21051975@postgrespro.ru", "phone": "+70094762344"}
0005434139506	5812EB	4250 056440	ANASTASIYA NESTEROVA	{"phone": "+70523348842"}
0005434139507	799B76	9994 842187	NATALYA ANDREEVA	{"email": "andreevanatalya121974@postgrespro.ru", "phone": "+70728762708"}
0005434139508	4CAD0B	1626 196600	SERGEY SHEVCHENKO	{"email": "shevchenkos_1977@postgrespro.ru", "phone": "+70034687459"}
0005434139509	4CAD0B	2294 784203	VALENTINA KOROLEVA	{"phone": "+70784681260"}
0005434139510	C68B62	3269 006066	GALINA FILIPPOVA	{"phone": "+70165848792"}
0005434139511	CF7659	9557 955375	DMITRIY GRIGOREV	{"email": "grigorev-d_1977@postgrespro.ru", "phone": "+70749710914"}
0005434139512	2B50DB	5066 396107	SERGEY ILIN	{"email": "ilin_sergey_1971@postgrespro.ru", "phone": "+70150667126"}
0005434139513	3BBD65	3636 794895	EVGENIY DMITRIEV	{"email": "evgeniy-dmitriev.15081970@postgrespro.ru", "phone": "+70832686810"}
0005434139514	3BBD65	9827 657311	YAROSLAV POPOV	{"email": "popovy_1978@postgrespro.ru", "phone": "+70152177099"}
0005434139515	75518E	4198 421088	OLEG MEDVEDEV	{"email": "medvedevoleg071972@postgrespro.ru", "phone": "+70051822589"}
0005434139516	BE65E2	0071 847614	DMITRIY EGOROV	{"phone": "+70867649441"}
0005434139517	8B18AC	0997 611262	NATALYA OSIPOVA	{"email": "n.osipova.1975@postgrespro.ru", "phone": "+70945333722"}
0005434139518	C9430C	5346 466774	EVGENIY PAVLOV	{"phone": "+70513297658"}
0005434139519	3171BE	7026 171669	OLEG MATVEEV	{"phone": "+70139522533"}
0005434139520	3171BE	3980 215189	TAMARA FROLOVA	{"phone": "+70155303625"}
0005434139521	3171BE	1215 862139	STANISLAV EGOROV	{"email": "segorov-051963@postgrespro.ru", "phone": "+70326137476"}
0005434139522	3185C2	7534 924994	ANTONINA OSIPOVA	{"phone": "+70194963496"}
0005434139523	F473C8	9066 910903	YURIY PAVLOV	{"phone": "+70110006729"}
0005434139524	F473C8	8728 894032	MARIYA AKIMOVA	{"phone": "+70370131515"}
0005434139525	F473C8	0764 126103	SERGEY ROMANOV	{"email": "sergey_romanov25101966@postgrespro.ru", "phone": "+70370519646"}
0005434139526	0C7D02	1388 757905	VITALIY ALEKSEEV	{"email": "alekseev-v.16061974@postgrespro.ru", "phone": "+70654139691"}
0005434139527	0C7D02	1542 294669	GALINA ERMAKOVA	{"email": "galina_ermakova_1959@postgrespro.ru", "phone": "+70317048856"}
0005434139528	7130C7	9918 399785	VALERIY ROMANOV	{"email": "romanov-valeriy021976@postgrespro.ru", "phone": "+70260347934"}
0005434139529	7130C7	8486 146367	BORIS SHEVCHENKO	{"email": "boris.shevchenko.1978@postgrespro.ru", "phone": "+70994163087"}
0005434139530	7130C7	4718 093448	ALEKSEY DENISOV	{"email": "denisov-a-11051967@postgrespro.ru", "phone": "+70109949315"}
0005434139531	BA7D63	0356 850455	GENNADIY FEDOROV	{"phone": "+70002111202"}
0005434139533	5585C4	3707 174705	ROMAN KUZMIN	{"phone": "+70831336228"}
0005434139534	5585C4	8851 176293	VIKTOR TIMOFEEV	{"phone": "+70815465621"}
0005434139535	46DEEA	9216 105168	ANASTASIYA IVANOVA	{"phone": "+70242063442"}
0005434139536	A0063D	1352 134568	PAVEL RODIONOV	{"phone": "+70317956818"}
0005434139537	AC66BE	4797 279360	ALEKSANDR SOROKIN	{"email": "sorokin-a051982@postgrespro.ru", "phone": "+70033899269"}
0005434139538	AC66BE	4419 507084	YANA GRISHINA	{"email": "y_grishina_1968@postgrespro.ru", "phone": "+70408082273"}
0005434139539	2ECB74	5862 685769	VADIM SAVELEV	{"phone": "+70201613070"}
0005434139540	2ECB74	5920 609650	VLADIMIR ZAKHAROV	{"phone": "+70275582853"}
0005434139541	2FA631	1655 849210	EVGENIYA NAZAROVA	{"email": "evgeniya_nazarova_121968@postgrespro.ru", "phone": "+70594288127"}
0005434139542	51F89D	9667 337056	POLINA MARTYNOVA	{"email": "martynova_polina21011961@postgrespro.ru", "phone": "+70509703570"}
0005434139543	51F89D	0900 307061	ANATOLIY VOROBEV	{"phone": "+70295558792"}
0005434139544	2E32A3	9582 071667	RUSTAM KUZNECOV	{"phone": "+70647563493"}
0005434139545	2E32A3	8228 525027	RUSLAN FROLOV	{"email": "frolov_r1980@postgrespro.ru", "phone": "+70849640330"}
0005434139546	23E2FC	3644 482631	NATALIYA MATVEEVA	{"email": "matveeva_nataliya-11031974@postgrespro.ru", "phone": "+70530755619"}
0005434139547	E57572	9712 164690	VYACHESLAV NAUMOV	{"email": "naumov-vyacheslav1975@postgrespro.ru", "phone": "+70341418085"}
0005434139548	D64C20	0380 832351	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina08111976@postgrespro.ru", "phone": "+70462855254"}
0005434139549	176767	6440 103727	OLGA EFREMOVA	{"phone": "+70046504009"}
0005434139550	9281B9	4513 666193	MIKHAIL FEDOROV	{"email": "mikhail_fedorov_09031962@postgrespro.ru", "phone": "+70894757745"}
0005434139551	6993CD	9740 020332	TATYANA FILATOVA	{"email": "filatova_tatyana-071962@postgrespro.ru", "phone": "+70013478668"}
0005434139552	A38A32	6872 881274	ALEKSANDR KISELEV	{"phone": "+70428625540"}
0005434139553	40B104	9147 248683	VALENTINA STEPANOVA	{"phone": "+70074656237"}
0005434139554	3AEA29	9473 669958	FILIPP GORBUNOV	{"phone": "+70176391572"}
0005434139555	3AEA29	8490 610247	IVAN IVANOV	{"email": "ivanov.i.16041981@postgrespro.ru", "phone": "+70928483501"}
0005434139556	FC4BFE	2900 599805	TATYANA SERGEEVA	{"phone": "+70651293760"}
0005434139557	2C7269	4739 656823	ALEKSANDR FROLOV	{"phone": "+70808623428"}
0005434139558	3F0BEE	6744 002673	ANTONINA NIKOLAEVA	{"phone": "+70278996206"}
0005434139559	CF00B2	2527 072307	ALENA FILATOVA	{"phone": "+70788031091"}
0005434139560	66E8B9	1018 709588	SERGEY VOROBEV	{"email": "vorobev.s.061959@postgrespro.ru", "phone": "+70236812147"}
0005434139561	FBE70C	0299 658005	OLGA PAVLOVA	{"email": "olga_pavlova.061974@postgrespro.ru", "phone": "+70526446542"}
0005434139562	FBE70C	0129 153981	DMITRIY FILIPPOV	{"email": "filippov-d_111976@postgrespro.ru", "phone": "+70058471294"}
0005434139564	8F15CC	0770 583600	NATALYA NOVIKOVA	{"email": "novikovanatalya1961@postgrespro.ru", "phone": "+70778158061"}
0005434139565	8F15CC	4088 999901	VYACHESLAV SOKOLOV	{"phone": "+70839028065"}
0005434139566	8F15CC	3010 772971	DMITRIY BARANOV	{"email": "d.baranov031973@postgrespro.ru", "phone": "+70518215339"}
0005434139567	532E33	6000 071127	PETR ZAKHAROV	{"email": "zakharovp_1969@postgrespro.ru", "phone": "+70559845618"}
0005434139568	532E33	1171 320239	IVAN MAKSIMOV	{"phone": "+70019355845"}
0005434139569	532E33	6427 143213	VIKTORIYA SOLOVEVA	{"email": "viktoriyasoloveva_1961@postgrespro.ru", "phone": "+70370839803"}
0005434139570	46A304	3618 501033	ALEKSEY SMIRNOV	{"email": "smirnova-29031978@postgrespro.ru", "phone": "+70574204432"}
0005434139571	46A304	8167 960285	VALENTINA FROLOVA	{"phone": "+70311180038"}
0005434139572	A26D50	4794 338896	ALEKSEY KOZLOV	{"email": "kozlov_a.031984@postgrespro.ru", "phone": "+70663936536"}
0005434139573	A26D50	2237 860055	IRINA PETROVA	{"phone": "+70743933972"}
0005434139574	0CB516	8034 323989	GALINA EFIMOVA	{"email": "efimova_galina1975@postgrespro.ru", "phone": "+70541150260"}
0005434139575	B0ADCB	4370 967219	KSENIYA ALEKSEEVA	{"email": "alekseeva_k_051972@postgrespro.ru", "phone": "+70963129240"}
0005434139576	133BA6	4803 572754	SERGEY MIRONOV	{"email": "sergeymironov.091977@postgrespro.ru", "phone": "+70763816786"}
0005434139577	133BA6	6984 605573	NIKOLAY TARASOV	{"email": "tarasov_nikolay1977@postgrespro.ru", "phone": "+70166205766"}
0005434139578	133BA6	8390 112409	LYUDMILA FILIPPOVA	{"phone": "+70633262880"}
0005434139579	006FBF	9640 157045	TIMUR SEMENOV	{"phone": "+70592664801"}
0005434139580	BA2AFB	8799 429281	RAMIL KUZNECOV	{"phone": "+70137199010"}
0005434139581	72AFB7	1789 671504	IRINA PAVLOVA	{"phone": "+70832943105"}
0005434139582	72AFB7	5366 504304	VLADIMIR ABRAMOV	{"email": "vladimirabramov02111973@postgrespro.ru", "phone": "+70543467972"}
0005434139583	A514DB	8620 755493	NIKOLAY SERGEEV	{"email": "sergeev-n-28051978@postgrespro.ru", "phone": "+70380361648"}
0005434139584	A514DB	0654 282527	KSENIYA KUZMINA	{"email": "kseniya_kuzmina1962@postgrespro.ru", "phone": "+70747214585"}
0005434139585	8A9A74	8359 313632	DMITRIY EGOROV	{"phone": "+70459833899"}
0005434139586	183223	8938 061862	ANNA POPOVA	{"email": "a.popova.02011966@postgrespro.ru", "phone": "+70589266703"}
0005434139587	47C460	8050 466360	KIRILL STEPANOV	{"email": "stepanov.kirill-31121981@postgrespro.ru", "phone": "+70581159157"}
0005434139588	47C460	4290 075850	NATALYA ANTONOVA	{"email": "natalya-antonova-1955@postgrespro.ru", "phone": "+70183540439"}
0005434139645	988FDC	7886 410087	PAVEL ANDREEV	{"phone": "+70234516452"}
0005434139589	62D799	6718 064031	KONSTANTIN NOVIKOV	{"email": "novikov.konstantin-1963@postgrespro.ru", "phone": "+70257284199"}
0005434139590	62D799	6557 016268	MARIYA GERASIMOVA	{"phone": "+70587861555"}
0005434139591	62D799	7563 896558	ALEKSANDR NIKITIN	{"email": "nikitina_19081981@postgrespro.ru", "phone": "+70345296288"}
0005434139592	62D799	7405 887484	GALINA KUDRYASHOVA	{"phone": "+70587159996"}
0005434139593	F49D15	9103 792024	YULIYA ALEKSEEVA	{"phone": "+70879390335"}
0005434139594	35BD50	5976 026343	TAMARA ERMAKOVA	{"phone": "+70177607070"}
0005434139595	EC5DA0	8950 109585	MARIYA NESTEROVA	{"email": "mariya-nesterova1981@postgrespro.ru", "phone": "+70361942062"}
0005434139596	973852	9456 344295	OLGA STEPANOVA	{"email": "olga-stepanova121965@postgrespro.ru", "phone": "+70312046220"}
0005434139597	B9AF23	8578 382914	ALINA SMIRNOVA	{"phone": "+70300265396"}
0005434139598	794FB9	3981 315268	VIKTOR GAVRILOV	{"email": "gavrilovviktor071970@postgrespro.ru", "phone": "+70134833179"}
0005434139599	89C098	2459 522105	PAVEL MAKAROV	{"email": "p-makarov.1979@postgrespro.ru", "phone": "+70412429778"}
0005434139600	89C098	8164 651530	YURIY SOROKIN	{"phone": "+70348600648"}
0005434139601	A3DEF6	3352 528213	IVAN MOISEEV	{"email": "imoiseev.1981@postgrespro.ru", "phone": "+70663379599"}
0005434139602	16A8D3	3479 831748	VYACHESLAV IVANOV	{"email": "ivanov.v30051969@postgrespro.ru", "phone": "+70965188542"}
0005434139603	16A8D3	9001 624771	LEV DAVYDOV	{"email": "levdavydov-02031974@postgrespro.ru", "phone": "+70873710685"}
0005434139604	93B54F	8609 802807	OKSANA ERMAKOVA	{"email": "ermakova-o.1971@postgrespro.ru", "phone": "+70825834799"}
0005434139605	5C6D33	2711 394948	VALENTINA PETROVA	{"phone": "+70496159944"}
0005434139606	5C6D33	5745 442234	LILIYA TARASOVA	{"phone": "+70133784780"}
0005434139607	65476A	7107 728257	NINA MALYSHEVA	{"email": "malysheva_nina.1969@postgrespro.ru", "phone": "+70635061217"}
0005434139608	C99E7F	2051 680488	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova-anastasiya1978@postgrespro.ru", "phone": "+70536354062"}
0005434139609	C99E7F	8660 303799	ALEKSANDR KAZAKOV	{"phone": "+70595780648"}
0005434139610	88BE09	4141 227157	EKATERINA NIKITINA	{"email": "e-nikitina-15091967@postgrespro.ru", "phone": "+70926330708"}
0005434139611	F5A979	6588 054902	MARIYA ANDREEVA	{"email": "mariya.andreeva-03061974@postgrespro.ru", "phone": "+70523283094"}
0005434139612	A4984A	5610 300806	RUSTAM FILIPPOV	{"phone": "+70254662406"}
0005434139613	A4984A	6662 626226	MAYA EFREMOVA	{"phone": "+70573317578"}
0005434139614	8E0384	6048 028798	LYUDMILA KARPOVA	{"phone": "+70627004376"}
0005434139615	06097C	2517 857990	EGOR KUZNECOV	{"phone": "+70871394715"}
0005434139616	7CDFA8	2671 226842	ZINAIDA MIKHAYLOVA	{"email": "z-mikhaylova1978@postgrespro.ru", "phone": "+70618285711"}
0005434139617	AE5E84	1521 627454	ZOYA ERMAKOVA	{"email": "zoyaermakova_091974@postgrespro.ru", "phone": "+70706771863"}
0005434139618	AE5E84	3485 883996	ALEKSANDR SIDOROV	{"phone": "+70615984016"}
0005434139619	D35B0E	5648 167794	ALEKSANDR SAVELEV	{"email": "a-savelev.071979@postgrespro.ru", "phone": "+70827298301"}
0005434139620	580D11	5979 260355	NINA SOLOVEVA	{"email": "n-soloveva.02071975@postgrespro.ru", "phone": "+70281636901"}
0005434139621	580D11	0759 838220	YULIYA PETROVA	{"phone": "+70009441410"}
0005434139622	77A150	8827 562032	NADEZHDA TIKHONOVA	{"phone": "+70328245948"}
0005434139623	77A150	4983 072864	OKSANA POPOVA	{"phone": "+70740077847"}
0005434139624	1DAB02	1895 055785	YURIY KAZAKOV	{"phone": "+70515638357"}
0005434139625	1474E2	2235 891375	ALEKSANDR BORISOV	{"phone": "+70788335018"}
0005434139626	13124A	5151 499617	IRINA TARASOVA	{"phone": "+70004057644"}
0005434139627	B2B8A4	1311 366788	PAVEL SERGEEV	{"email": "psergeev1978@postgrespro.ru", "phone": "+70178008325"}
0005434139628	D6F3AD	5346 639796	GRIGORIY GUSEV	{"email": "gusev-grigoriy.1986@postgrespro.ru", "phone": "+70574651964"}
0005434139629	049A09	3808 207222	VLADIMIR NAUMOV	{"phone": "+70359185213"}
0005434139630	049A09	3433 817568	POLINA ALEKSANDROVA	{"phone": "+70548332927"}
0005434139631	2F591F	9514 824781	TATYANA GUSEVA	{"phone": "+70684676333"}
0005434139632	65FC57	7507 710530	NATALYA EGOROVA	{"email": "natalya.egorova22051964@postgrespro.ru", "phone": "+70321185225"}
0005434139633	65FC57	1863 420230	OLEG ZAKHAROV	{"phone": "+70371430737"}
0005434139634	D9E642	9739 340175	EVGENIY KUZNECOV	{"email": "kuznecov-e051972@postgrespro.ru", "phone": "+70027502064"}
0005434139635	F51F7D	3579 491880	SVETLANA FOMINA	{"phone": "+70516830118"}
0005434139636	3DE49A	8094 241175	ANATOLIY KOZLOV	{"email": "a-kozlov_1968@postgrespro.ru", "phone": "+70493227487"}
0005434139637	432A6D	0954 733188	ANNA ZAYCEVA	{"email": "zaycevaanna041962@postgrespro.ru", "phone": "+70058697615"}
0005434139638	FCCCB1	4619 744453	VALENTINA LUKYANOVA	{"email": "lukyanova_v_1971@postgrespro.ru", "phone": "+70932478697"}
0005434139639	FCCCB1	9194 586127	MAGOMED MOISEEV	{"phone": "+70490528092"}
0005434139640	67B3E1	3754 598294	ANDREY FROLOV	{"email": "frolov-a101964@postgrespro.ru", "phone": "+70443648055"}
0005434139641	EDA713	1180 798542	MARGARITA SOROKINA	{"phone": "+70887512593"}
0005434139642	AA698E	0488 129423	DANILA MAKAROV	{"email": "makarov.danila-1978@postgrespro.ru", "phone": "+70592343572"}
0005434139643	9CD1A9	2803 158735	NIKOLAY ALEKSEEV	{"phone": "+70985158805"}
0005434139644	F53E18	1317 934700	TATYANA ZAKHAROVA	{"phone": "+70121629209"}
0005434139646	9CADF3	2648 535315	ELENA ZOTOVA	{"email": "elena.zotova.1969@postgrespro.ru", "phone": "+70911828907"}
0005434139647	D6B50D	3461 156341	YURIY GORBUNOV	{"phone": "+70499527079"}
0005434139648	D6B50D	9199 825937	SERGEY EGOROV	{"phone": "+70422265987"}
0005434139649	B9AE6D	7512 220563	YULIYA SOKOLOVA	{"phone": "+70184271415"}
0005434139650	71433B	8485 304506	MARINA ROMANOVA	{"email": "romanova-marina011977@postgrespro.ru", "phone": "+70066708282"}
0005434139651	4C1418	2768 261943	TATYANA IVANOVA	{"email": "ivanovat_13021974@postgrespro.ru", "phone": "+70982885083"}
0005434139652	534E62	2114 030030	ANATOLIY KISELEV	{"email": "kiseleva_041981@postgrespro.ru", "phone": "+70406382798"}
0005434139653	D5913D	5803 890577	ELENA KUDRYASHOVA	{"email": "kudryashova-elena.1968@postgrespro.ru", "phone": "+70807774178"}
0005434139654	7C8DD3	6922 810467	SVETLANA RYABOVA	{"phone": "+70591213276"}
0005434139655	7C8DD3	2042 025138	RUFIYA ABRAMOVA	{"email": "r_abramova_1974@postgrespro.ru", "phone": "+70886325884"}
0005434139656	7C8DD3	9253 193903	NATALYA ZHUKOVA	{"email": "n_zhukova18011972@postgrespro.ru", "phone": "+70818378539"}
0005434139657	E0F6A9	6832 584394	OLGA RYABOVA	{"email": "oryabova-051976@postgrespro.ru", "phone": "+70387341130"}
0005434139658	E0F6A9	8649 205677	IRINA ERMAKOVA	{"phone": "+70284598490"}
0005434139659	E69A05	8986 099265	TAISIYA PAVLOVA	{"phone": "+70059087542"}
0005434139660	7F1649	3767 831710	DARYA ZAKHAROVA	{"email": "zakharova.d-15121964@postgrespro.ru", "phone": "+70988408529"}
0005434139661	7F1649	0132 369289	ELENA POPOVA	{"phone": "+70513551731"}
0005434139662	AB1A95	8497 047666	NIKOLAY AFANASEV	{"phone": "+70981763938"}
0005434139663	812901	7088 212492	ANGELINA VASILEVA	{"phone": "+70416959440"}
0005434139664	B423E5	7308 795757	ANTON DAVYDOV	{"email": "a_davydov_031979@postgrespro.ru", "phone": "+70786713270"}
0005434139665	B423E5	1502 574775	MURAT KARPOV	{"phone": "+70702769205"}
0005434139666	B423E5	2730 749967	ILYA BONDARENKO	{"email": "bondarenko-ilya-051969@postgrespro.ru", "phone": "+70370449217"}
0005434139667	C540F1	3231 269477	SERGEY KULIKOV	{"phone": "+70195544673"}
0005434139668	3CA746	4553 234945	VYACHESLAV ABRAMOV	{"email": "abramov-vyacheslav1990@postgrespro.ru", "phone": "+70122016115"}
0005434139669	A737EC	0327 550353	NADEZHDA ORLOVA	{"email": "n.orlova-1977@postgrespro.ru", "phone": "+70736813723"}
0005434139670	A737EC	7691 155725	ANTONINA MELNIKOVA	{"email": "amelnikova_1977@postgrespro.ru", "phone": "+70703375637"}
0005434139671	4B06A1	5825 259357	ALEKSANDR POPOV	{"email": "popov-aleksandr.10111968@postgrespro.ru", "phone": "+70227013736"}
0005434139672	4B06A1	1991 891517	MIKHAIL MAKAROV	{"phone": "+70121466110"}
0005434139673	62F63A	3848 876794	SERGEY POPOV	{"phone": "+70943850849"}
0005434139674	0C3017	9718 305564	OLGA KOROLEVA	{"phone": "+70300148117"}
0005434139675	0C3017	9101 984183	SERGEY SEMENOV	{"email": "semenovsergey-01081975@postgrespro.ru", "phone": "+70789310370"}
0005434139676	7EE5D4	5207 427820	ANASTASIYA TARASOVA	{"email": "anastasiya_tarasova-031980@postgrespro.ru", "phone": "+70457138791"}
0005434139677	57C472	3938 856336	OKSANA DANILOVA	{"email": "danilova.oksana-011960@postgrespro.ru", "phone": "+70243029321"}
0005434139678	722433	4733 336486	VLADIMIR MOISEEV	{"email": "moiseev.vladimir22081975@postgrespro.ru", "phone": "+70312844949"}
0005434139679	C90193	9133 882687	RAZIYA MASLOVA	{"email": "maslovar091973@postgrespro.ru", "phone": "+70614008924"}
0005434139680	9973DE	2172 893684	RAVIL PETROV	{"email": "r.petrov-1973@postgrespro.ru", "phone": "+70805125471"}
0005434139681	7712CC	8561 796449	ALEKSEY BELOV	{"email": "aleksey_belov-30031967@postgrespro.ru", "phone": "+70883031080"}
0005434139682	7712CC	7132 181613	TATYANA BARANOVA	{"phone": "+70967844615"}
0005434139683	AE4391	1844 222852	SVETLANA MOROZOVA	{"phone": "+70390728480"}
0005434139684	76C475	4615 940561	EKATERINA PETROVA	{"phone": "+70252595942"}
0005434139685	8F513E	1502 502830	MARAT MIRONOV	{"email": "mironov_marat.1968@postgrespro.ru", "phone": "+70780292140"}
0005434139686	8F513E	9334 478256	NIKITA ZAKHAROV	{"email": "nikita_zakharov.081968@postgrespro.ru", "phone": "+70418433746"}
0005434139687	4DD303	3728 577150	GALINA SAVELEVA	{"email": "saveleva_g-18051977@postgrespro.ru", "phone": "+70424047483"}
0005434139688	8FD5D9	9329 979240	ELLA BELYAEVA	{"email": "belyaeva.e-101974@postgrespro.ru", "phone": "+70044307572"}
0005434139689	8FD5D9	9170 107796	YULIYA TARASOVA	{"email": "tarasova_y-19111968@postgrespro.ru", "phone": "+70737970364"}
0005434139690	A46921	4330 466619	GALINA TROFIMOVA	{"email": "g_trofimova_121979@postgrespro.ru", "phone": "+70536571442"}
0005434139691	759F70	4571 936365	ALEKSANDR BORISOV	{"email": "a-borisov.101974@postgrespro.ru", "phone": "+70016902226"}
0005434139692	7138DB	2728 796279	EKATERINA ALEKSEEVA	{"phone": "+70360253740"}
0005434139693	7138DB	4091 347477	LYUBOV POLYAKOVA	{"phone": "+70849247059"}
0005434139694	7D7C46	9687 441005	LYUBOV KOROLEVA	{"email": "korolevalyubov1980@postgrespro.ru", "phone": "+70068577426"}
0005434139695	7D7C46	9858 056199	BORIS SHEVCHENKO	{"email": "b_shevchenko.04051979@postgrespro.ru", "phone": "+70132189778"}
0005434139696	7D7C46	5083 637792	ANDREY KARPOV	{"phone": "+70735500741"}
0005434139697	80559A	3719 744213	NINA FILIPPOVA	{"email": "filippovan-29111990@postgrespro.ru", "phone": "+70974368906"}
0005434139698	9B4A16	5394 249156	GRIGORIY ALEKSEEV	{"email": "grigoriy_alekseev101977@postgrespro.ru", "phone": "+70373047298"}
0005434139699	731957	3377 483576	ARTUR POPOV	{"phone": "+70110445253"}
0005434139700	C0885C	3400 464450	DMITRIY SOROKIN	{"email": "sorokin.dmitriy.1979@postgrespro.ru", "phone": "+70590138185"}
0005434139701	C0885C	7521 463898	SVETLANA NIKITINA	{"email": "s_nikitina09051970@postgrespro.ru", "phone": "+70563432586"}
0005434139702	31A9DB	3106 414766	NADEZHDA ZAKHAROVA	{"email": "nadezhda.zakharova.1974@postgrespro.ru", "phone": "+70317830133"}
0005434139703	6B2375	3396 255082	VITALIY IVANOV	{"phone": "+70507985059"}
0005434139704	6B2375	8870 046067	VALENTINA FEDOROVA	{"phone": "+70746723684"}
0005434139705	50D2A5	5950 632853	GLEB KOZLOV	{"email": "gkozlov_18081967@postgrespro.ru", "phone": "+70551935744"}
0005434139706	326785	3267 090920	GEORGIY GUSEV	{"email": "gusevg-1972@postgrespro.ru", "phone": "+70028694290"}
0005434139707	5EB25C	8218 618746	VERA FEDOROVA	{"phone": "+70028463790"}
0005434139708	7131E2	8508 940314	TATYANA EGOROVA	{"email": "tatyana.egorova-11061973@postgrespro.ru", "phone": "+70177270436"}
0005434139709	7131E2	8520 009012	EVGENIY ABRAMOV	{"phone": "+70769390170"}
0005434139710	308C13	9653 763095	VERA SERGEEVA	{"email": "sergeevav.1973@postgrespro.ru", "phone": "+70555553095"}
0005434139711	302147	6424 793665	VLADIMIR AFANASEV	{"email": "v_afanasev_091972@postgrespro.ru", "phone": "+70900212490"}
0005434139712	FB7613	1000 218134	SERGEY ALEKSEEV	{"phone": "+70253640274"}
0005434139713	59EC84	4345 791691	ELENA STEPANOVA	{"email": "elena-stepanova-09121979@postgrespro.ru", "phone": "+70949976097"}
0005434139714	71D2B8	2178 219846	OLGA IVANOVA	{"phone": "+70615819537"}
0005434139715	6A84B5	7051 949871	SERGEY KUZMIN	{"email": "s_kuzmin.021965@postgrespro.ru", "phone": "+70885098603"}
0005434139716	039648	9772 922721	TATYANA ANDREEVA	{"phone": "+70872765228"}
0005434139717	A1BF2D	7955 924471	STANISLAV KUZNECOV	{"email": "skuznecov_25121978@postgrespro.ru", "phone": "+70238531604"}
0005434139718	E1DA8E	2799 023412	VASILIY FILIPPOV	{"phone": "+70256518955"}
0005434139719	EF6D46	1235 749813	IRINA KUZNECOVA	{"email": "ikuznecova.1971@postgrespro.ru", "phone": "+70983820121"}
0005434139720	C237C4	0598 331509	VLADIMIR PETROV	{"email": "v_petrov1982@postgrespro.ru", "phone": "+70533374876"}
0005434139721	C237C4	2962 691500	VITALIY POPOV	{"email": "popov-v1965@postgrespro.ru", "phone": "+70562195879"}
0005434139722	0E1852	1107 854510	VASILIY MOROZOV	{"phone": "+70268741590"}
0005434139723	B8C752	6511 365832	MARK BARANOV	{"phone": "+70149403521"}
0005434139724	772158	1489 292371	SOFYA VLASOVA	{"phone": "+70116906386"}
0005434139725	772158	3647 921485	EKATERINA MIRONOVA	{"email": "mironova_ekaterina.1988@postgrespro.ru", "phone": "+70817436833"}
0005434139726	2849D0	2599 925999	VLADIMIR KUZNECOV	{"phone": "+70911438904"}
0005434139727	2849D0	5586 472621	ALEKSEY FILIPPOV	{"phone": "+70372443798"}
0005434139728	9D64D7	3237 654405	EVDOKIYA PETROVA	{"phone": "+70911327782"}
0005434139729	9D64D7	1734 462416	NATALYA RODIONOVA	{"phone": "+70220671271"}
0005434139730	9D64D7	2334 280674	LYUDMILA ANDREEVA	{"email": "andreeval-071963@postgrespro.ru", "phone": "+70551113629"}
0005434139953	DD3CD4	5831 637958	DMITRIY MOISEEV	{"phone": "+70606597848"}
0005434139731	A5D6DA	6251 314084	SERGEY MAKSIMOV	{"email": "sergey.maksimov.101971@postgrespro.ru", "phone": "+70236919917"}
0005434139732	EFA9A6	9269 386192	EKATERINA NIKOLAEVA	{"email": "e_nikolaeva1970@postgrespro.ru", "phone": "+70150501245"}
0005434139733	4D0A49	6493 180244	OLGA KUZNECOVA	{"phone": "+70550713636"}
0005434139734	4D0A49	3616 323717	ALEKSEY RODIONOV	{"phone": "+70938963577"}
0005434139735	4AE96E	7656 850222	ZOYA PAVLOVA	{"email": "z_pavlova1978@postgrespro.ru", "phone": "+70771917872"}
0005434139736	4E5EBF	4408 969560	DMITRIY TARASOV	{"email": "d.tarasov011960@postgrespro.ru", "phone": "+70047569725"}
0005434139737	4FA5FB	3745 329819	ILYA FOMIN	{"email": "ilya-fomin.011976@postgrespro.ru", "phone": "+70569691720"}
0005434139738	48906D	5548 409550	VLADIMIR EGOROV	{"phone": "+70968477681"}
0005434139739	4DBD3F	3513 111699	ALEKSANDR MEDVEDEV	{"phone": "+70926451654"}
0005434139740	4DBD3F	9449 631834	KONSTANTIN VOLKOV	{"email": "k-volkov_1964@postgrespro.ru", "phone": "+70257034100"}
0005434139741	7C0681	9852 061743	EVGENIY SOLOVEV	{"phone": "+70903902676"}
0005434139742	E13838	8734 631821	OLGA MOROZOVA	{"email": "olga_morozova-1984@postgrespro.ru", "phone": "+70913789644"}
0005434139743	E13838	9156 644331	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_n.041973@postgrespro.ru", "phone": "+70132539710"}
0005434139744	57863A	4831 429814	VALENTINA PAVLOVA	{"email": "v-pavlova1980@postgrespro.ru", "phone": "+70796348881"}
0005434139745	F8D792	1936 742434	BORIS VOROBEV	{"email": "b.vorobev.071959@postgrespro.ru", "phone": "+70188931857"}
0005434139746	675DE1	9092 043152	VLADIMIR VASILEV	{"phone": "+70349931046"}
0005434139747	E98622	1700 919058	ALLA MALYSHEVA	{"phone": "+70686400383"}
0005434139748	E98622	2357 079836	ELENA FROLOVA	{"email": "elena-frolova.1965@postgrespro.ru", "phone": "+70953141140"}
0005434139749	D1383B	1357 675882	OLGA LOGINOVA	{"email": "ologinova08081972@postgrespro.ru", "phone": "+70602310716"}
0005434139750	AEED82	4203 006459	RAISA ZOTOVA	{"email": "raisa.zotova_1969@postgrespro.ru", "phone": "+70771523238"}
0005434139751	423F30	4578 596302	TATYANA KARPOVA	{"phone": "+70465476187"}
0005434139752	3DF428	1544 028449	VIKTORIYA IVANOVA	{"email": "ivanovav_051966@postgrespro.ru", "phone": "+70971500160"}
0005434139753	3DD679	0423 893105	TATYANA NIKITINA	{"phone": "+70475168726"}
0005434139754	3DD679	3220 299869	VALENTINA KUZNECOVA	{"phone": "+70230986514"}
0005434139755	5CD514	1062 294239	NINA MATVEEVA	{"phone": "+70797144208"}
0005434139756	41B909	4944 684128	IGOR IVANOV	{"email": "ivanov-igor.30051972@postgrespro.ru", "phone": "+70647991122"}
0005434139757	41B909	7854 182705	EVGENIY KARPOV	{"phone": "+70073327615"}
0005434139758	A60ABB	2194 122084	KIRILL ANTONOV	{"phone": "+70627798355"}
0005434139759	2E6A9D	2274 876417	TATYANA NIKIFOROVA	{"email": "nikiforova-tatyana04041965@postgrespro.ru", "phone": "+70099534362"}
0005434139760	2E6A9D	8414 103571	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev-02111970@postgrespro.ru", "phone": "+70459260157"}
0005434139761	FFF3AE	3040 192900	ALEKSEY KAZAKOV	{"email": "aleksey-kazakov.041983@postgrespro.ru", "phone": "+70968225938"}
0005434139762	FFF3AE	0948 551541	ALEKSANDR ISAEV	{"email": "aleksandr-isaev.1972@postgrespro.ru", "phone": "+70714311279"}
0005434139763	76A16A	8583 342312	RAMIL TIMOFEEV	{"email": "ramil-timofeev_1962@postgrespro.ru", "phone": "+70030138446"}
0005434139764	286BEC	7748 069008	YURIY TIKHONOV	{"phone": "+70971899973"}
0005434139765	286BEC	5414 537354	ANDREY GRIGOREV	{"email": "grigorevandrey15031982@postgrespro.ru", "phone": "+70846947244"}
0005434139766	9F38E4	5738 022635	GRIGORIY GERASIMOV	{"phone": "+70215984030"}
0005434139767	9F38E4	4144 272224	VERA MELNIKOVA	{"phone": "+70575244609"}
0005434139768	67A250	2793 498365	VALENTINA OVCHINNIKOVA	{"email": "v_ovchinnikova011970@postgrespro.ru", "phone": "+70288174453"}
0005434139769	A920B1	0428 401791	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov.23021979@postgrespro.ru", "phone": "+70873372545"}
0005434139770	E5E0FE	6558 540274	IRINA ZAKHAROVA	{"phone": "+70269574665"}
0005434139771	C149AC	6276 078234	ANDREY ISAEV	{"phone": "+70493284650"}
0005434139772	52BF57	7812 935750	EVGENIYA ILINA	{"email": "e-ilina091969@postgrespro.ru", "phone": "+70828933890"}
0005434139773	665F79	6855 344171	LIDIYA MARTYNOVA	{"phone": "+70014841688"}
0005434139774	665F79	0730 791574	SVETLANA MAKAROVA	{"phone": "+70340766913"}
0005434139775	EDF502	6498 556878	TATYANA MAKAROVA	{"phone": "+70173485701"}
0005434139776	EDF502	3665 190669	TIMUR FEDOTOV	{"phone": "+70077403924"}
0005434139777	2D8E06	5277 201903	SVETLANA MOROZOVA	{"phone": "+70307679487"}
0005434139778	2D8E06	3505 366802	ANDREY KUDRYASHOV	{"phone": "+70717359904"}
0005434139779	88A760	0259 688459	ANTONINA VLASOVA	{"phone": "+70322988260"}
0005434139780	88A760	9628 149016	VLADIMIR SAVELEV	{"phone": "+70620538519"}
0005434139781	8F7FB5	5427 647552	ANNA SEMENOVA	{"phone": "+70292395360"}
0005434139782	C7D66A	7917 148695	KIRILL SOKOLOV	{"email": "sokolov-kirill121966@postgrespro.ru", "phone": "+70124571078"}
0005434139783	FBBAA5	1861 037249	NATALYA KUZNECOVA	{"email": "kuznecova-n-19021966@postgrespro.ru", "phone": "+70745007720"}
0005434139784	FBBAA5	9777 109219	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir26091978@postgrespro.ru", "phone": "+70965394045"}
0005434139785	C74DD2	3548 923054	SVETLANA GAVRILOVA	{"phone": "+70898969678"}
0005434139786	E13397	7615 303457	IRINA RYABOVA	{"phone": "+70799257817"}
0005434139787	E13397	1311 020375	LYUDMILA KONOVALOVA	{"email": "lyudmila_konovalova.10081965@postgrespro.ru", "phone": "+70032249457"}
0005434139788	13E7E4	1342 718006	LYUDMILA KUZNECOVA	{"email": "kuznecova_l.16021972@postgrespro.ru", "phone": "+70292511964"}
0005434139789	038718	7881 649012	NINA ANDREEVA	{"phone": "+70335930132"}
0005434139790	621E89	3077 418685	TAISIYA SMIRNOVA	{"email": "taisiya_smirnova.061981@postgrespro.ru", "phone": "+70474910841"}
0005434139791	4FD40B	5849 345102	SERGEY VASILEV	{"email": "vasilev-sergey-25071963@postgrespro.ru", "phone": "+70239203173"}
0005434139792	28405F	3034 921109	VLADIMIR PAVLOV	{"email": "pavlov-v.1973@postgrespro.ru", "phone": "+70612104134"}
0005434139793	9B988B	8781 717347	VALENTINA LAZAREVA	{"phone": "+70740786752"}
0005434139794	9B988B	9625 059119	GEORGIY NIKOLAEV	{"phone": "+70756881731"}
0005434139795	9B988B	3394 340975	NATALYA MOROZOVA	{"phone": "+70056981192"}
0005434139796	B3993B	2866 245152	KRISTINA MOISEEVA	{"email": "kristina_moiseeva-091988@postgrespro.ru", "phone": "+70368814560"}
0005434139797	B3993B	4104 913960	MARINA ZHUKOVA	{"email": "marina-zhukova_091974@postgrespro.ru", "phone": "+70829173278"}
0005434139798	A2D857	2843 282079	SERGEY OSIPOV	{"email": "osipov.sergey-15071971@postgrespro.ru", "phone": "+70992411130"}
0005434139799	A2D857	1001 118017	IRINA NESTEROVA	{"phone": "+70705057251"}
0005434139800	A2D857	0110 477238	KSENIYA SMIRNOVA	{"email": "smirnovak-1981@postgrespro.ru", "phone": "+70688854660"}
0005434139801	3B3276	9326 224051	IVAN ALEKSANDROV	{"email": "ivan.aleksandrov-1973@postgrespro.ru", "phone": "+70788913100"}
0005434139802	3B3276	0726 071095	ELENA MARTYNOVA	{"email": "martynova-elena1958@postgrespro.ru", "phone": "+70065717803"}
0005434139803	3B3276	8244 209098	SERGEY NIKITIN	{"phone": "+70637727286"}
0005434139804	1AD649	6671 298016	NATALYA KOZLOVA	{"phone": "+70111183493"}
0005434139805	1AD649	0358 917759	TAMARA BARANOVA	{"email": "baranova_tamara_21031967@postgrespro.ru", "phone": "+70738096317"}
0005434139806	D346C5	2340 287335	MARINA KUZNECOVA	{"email": "marinakuznecova.20091971@postgrespro.ru", "phone": "+70180867008"}
0005434139807	D346C5	0909 108824	ALEKSANDRA BOGDANOVA	{"phone": "+70023056393"}
0005434139808	C4164E	8511 446925	VYACHESLAV SIDOROV	{"email": "vyacheslavsidorov-14121972@postgrespro.ru", "phone": "+70505909883"}
0005434139809	C4164E	4926 642119	LIDIYA DANILOVA	{"email": "lidiya_danilova_041973@postgrespro.ru", "phone": "+70465246176"}
0005434139810	DD5BCD	1690 167581	ILYA VOLKOV	{"email": "volkovi06121967@postgrespro.ru", "phone": "+70390423997"}
0005434140035	2DC081	7588 902039	OLEG SIDOROV	{"phone": "+70578765189"}
0005434139811	D6DCD1	7929 320018	ALEVTINA TIMOFEEVA	{"email": "timofeeva_alevtina.18021957@postgrespro.ru", "phone": "+70775607850"}
0005434139812	D6DCD1	3953 860695	VLADIMIR GRIGOREV	{"email": "vladimir-grigorev-1980@postgrespro.ru", "phone": "+70889318269"}
0005434139813	7B3268	7880 948796	ANNA KARPOVA	{"email": "a_karpova.121973@postgrespro.ru", "phone": "+70152892927"}
0005434139814	7B3268	7012 965112	ALBINA ANDREEVA	{"email": "aandreeva121980@postgrespro.ru", "phone": "+70569506928"}
0005434139815	7B3268	8894 078226	NATALYA SOKOLOVA	{"phone": "+70299663645"}
0005434139816	AC82DC	1978 239258	INNA MARTYNOVA	{"email": "imartynova.021971@postgrespro.ru", "phone": "+70893165194"}
0005434139817	6E88B6	0501 330569	GALINA IVANOVA	{"email": "g_ivanova.1963@postgrespro.ru", "phone": "+70264372136"}
0005434139818	6E88B6	4393 313443	VIKTOR ZHURAVLEV	{"phone": "+70114166494"}
0005434139819	C0FC1D	1007 602930	ZINAIDA KUZNECOVA	{"phone": "+70233125099"}
0005434139820	B5A87A	3076 520878	GALINA ANDREEVA	{"phone": "+70828432130"}
0005434139821	EAD970	8742 564403	NINA MELNIKOVA	{"phone": "+70909083131"}
0005434139822	0D1E29	8712 154653	DANIIL ABRAMOV	{"email": "abramov.d.121965@postgrespro.ru", "phone": "+70212048433"}
0005434139823	CFA01E	7310 472585	NINA VLASOVA	{"phone": "+70988112429"}
0005434139824	CFA01E	9747 821056	ZINAIDA KUZNECOVA	{"phone": "+70923210636"}
0005434139825	6494B7	7222 291834	RUSLAN FOMIN	{"email": "fominr121972@postgrespro.ru", "phone": "+70908561696"}
0005434139826	B96721	7298 194372	ANDREY TIKHONOV	{"phone": "+70008727624"}
0005434139827	B96721	9700 415157	IRINA KUZNECOVA	{"email": "ikuznecova.011969@postgrespro.ru", "phone": "+70788932238"}
0005434139828	C49A6C	6578 886251	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-a.04031984@postgrespro.ru", "phone": "+70536984473"}
0005434139829	FB7492	1296 842368	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov_11051966@postgrespro.ru", "phone": "+70839244739"}
0005434140008	3CF091	7294 859527	NADEZHDA LEBEDEVA	{"phone": "+70759051065"}
0005434139830	FB7492	7859 330719	ANATOLIY BARANOV	{"email": "anatoliy-baranov_121980@postgrespro.ru", "phone": "+70679239427"}
0005434139831	EB9405	2838 204315	IRINA KOROLEVA	{"email": "irina_koroleva-1962@postgrespro.ru", "phone": "+70074941710"}
0005434139832	FB244B	3596 695691	ISLAM DENISOV	{"email": "denisov-islam051970@postgrespro.ru", "phone": "+70906805276"}
0005434139833	FB244B	9424 803970	OLEG ANDREEV	{"email": "oleg-andreev-1972@postgrespro.ru", "phone": "+70466228765"}
0005434139834	A1B1EA	7288 957635	NATALYA KALININA	{"email": "natalya.kalinina.08021970@postgrespro.ru", "phone": "+70941560491"}
0005434139835	5C402A	4313 477440	NIKITA PAVLOV	{"phone": "+70536766034"}
0005434139836	656423	4959 851268	VALENTINA KISELEVA	{"email": "valentinakiseleva-1978@postgrespro.ru", "phone": "+70580910947"}
0005434139837	656423	1319 515902	PAVEL BORISOV	{"phone": "+70715273614"}
0005434139838	88C87F	5995 220887	YULIYA NAZAROVA	{"email": "nazarova_yuliya-121971@postgrespro.ru", "phone": "+70897906723"}
0005434139839	AB4EEA	4280 795991	LYUDMILA SCHERBAKOVA	{"phone": "+70219126434"}
0005434139840	D2BCFB	5348 610167	NINA KOLESNIKOVA	{"phone": "+70088811249"}
0005434139841	D2BCFB	6496 459586	SERGEY FOMIN	{"email": "s.fomin-041974@postgrespro.ru", "phone": "+70804586622"}
0005434139842	5A38B5	6430 467133	DMITRIY ANTONOV	{"email": "antonov.dmitriy-06031975@postgrespro.ru", "phone": "+70433497036"}
0005434139843	5A38B5	9715 200253	NINA YAKOVLEVA	{"email": "yakovleva_nina101972@postgrespro.ru", "phone": "+70552713976"}
0005434139844	5FDAB8	8135 142602	SVETLANA DMITRIEVA	{"email": "dmitrieva-svetlana-1980@postgrespro.ru", "phone": "+70491287008"}
0005434139845	5FDAB8	5444 440505	NIKOLAY GUSEV	{"phone": "+70462232398"}
0005434139846	E5829F	6473 098479	ELENA SEMENOVA	{"email": "semenova_e.011970@postgrespro.ru", "phone": "+70016923464"}
0005434139847	8F2DCF	6896 934900	DENIS PETROV	{"phone": "+70975579311"}
0005434139848	9370B7	7038 016532	SERGEY KOZLOV	{"email": "s-kozlov-20021964@postgrespro.ru", "phone": "+70211478829"}
0005434139849	9370B7	2075 446342	KONSTANTIN ABRAMOV	{"email": "abramovkonstantin.1980@postgrespro.ru", "phone": "+70218313313"}
0005434139850	BB38E1	3508 358715	VLADIMIR KUZMIN	{"email": "v.kuzmin.13031966@postgrespro.ru", "phone": "+70091837522"}
0005434139851	25D501	9827 848561	YULIYA BELOVA	{"phone": "+70056009749"}
0005434139852	EEA159	0210 025416	NIKOLAY GRIGOREV	{"phone": "+70335858655"}
0005434139853	CCC41B	3280 087040	ELIZAVETA ANTONOVA	{"phone": "+70254286449"}
0005434139854	CCC41B	2022 931215	GALINA SOKOLOVA	{"email": "galina-sokolova22061978@postgrespro.ru", "phone": "+70946872578"}
0005434139855	CCC41B	8227 776538	TATYANA ILINA	{"phone": "+70731449824"}
0005434139856	AA0761	3314 246771	NIKOLAY ZHURAVLEV	{"phone": "+70830625385"}
0005434139857	9D33C9	9406 603894	ALINA FILATOVA	{"email": "alina-filatova-1983@postgrespro.ru", "phone": "+70915494880"}
0005434139858	9D33C9	0278 665753	IGOR IVANOV	{"email": "igor_ivanov.091968@postgrespro.ru", "phone": "+70926474628"}
0005434139859	F7D4DB	0998 009540	MIKHAIL NOVIKOV	{"email": "novikov-m.02111953@postgrespro.ru", "phone": "+70063591395"}
0005434139860	F7D4DB	1455 555229	DANIIL CHERNOV	{"email": "daniilchernov.09111962@postgrespro.ru", "phone": "+70251342005"}
0005434139861	D3EC80	4139 739508	VALENTINA TIKHONOVA	{"phone": "+70778341076"}
0005434139862	D3EC80	7317 243348	VALENTINA NESTEROVA	{"phone": "+70638541448"}
0005434139863	F99B5F	3959 948109	YULIYA TROFIMOVA	{"phone": "+70971487160"}
0005434139864	C729F6	8814 467009	ALINA LUKYANOVA	{"email": "alina-lukyanova1970@postgrespro.ru", "phone": "+70905499068"}
0005434139865	02506F	5816 249074	ALEKSANDR AFANASEV	{"phone": "+70190370629"}
0005434139866	142E07	5342 965503	ALEKSANDR ISAEV	{"email": "isaev-a091977@postgrespro.ru", "phone": "+70897120243"}
0005434139867	D91733	9591 303646	ELENA KUZNECOVA	{"email": "e_kuznecova-25061974@postgrespro.ru", "phone": "+70608959506"}
0005434139868	6819B3	0427 672088	SERGEY ILIN	{"phone": "+70137575148"}
0005434139869	431353	5702 074580	PAVEL POPOV	{"email": "popovpavel_23091973@postgrespro.ru", "phone": "+70920750279"}
0005434139870	431353	7751 201207	MARIYA GORBUNOVA	{"phone": "+70238914907"}
0005434139871	7593BE	3593 820311	PETR NAUMOV	{"email": "pnaumov-121965@postgrespro.ru", "phone": "+70230393219"}
0005434139872	98753C	4863 966193	TAMARA EGOROVA	{"phone": "+70480005945"}
0005434139873	D04011	7385 749006	SVETLANA KULIKOVA	{"phone": "+70247922863"}
0005434139874	8901A1	1030 561352	LYUDMILA KUZMINA	{"phone": "+70203611706"}
0005434139875	046E2A	7860 506580	YULIYA VASILEVA	{"email": "yuliya_vasileva-03061956@postgrespro.ru", "phone": "+70309802233"}
0005434139876	30363C	4940 877865	NADEZHDA NESTEROVA	{"phone": "+70502412781"}
0005434139877	30363C	0373 347471	LIDIYA MIKHAYLOVA	{"email": "l.mikhaylova.1972@postgrespro.ru", "phone": "+70006884162"}
0005434139878	EBBC9C	1351 827163	SVETLANA ROMANOVA	{"phone": "+70641074678"}
0005434139879	704118	8343 225416	NATALIYA NAZAROVA	{"phone": "+70573069179"}
0005434139880	C58F21	8730 477878	ANDREY MATVEEV	{"email": "andrey.matveev-1978@postgrespro.ru", "phone": "+70316416041"}
0005434139881	C58F21	7616 795186	ALEKSANDR NIKITIN	{"phone": "+70264667388"}
0005434139882	1C4457	3561 386070	ANNA LOGINOVA	{"email": "loginovaanna.091973@postgrespro.ru", "phone": "+70747062699"}
0005434139883	6EE61A	9843 857063	ANTONINA EFREMOVA	{"email": "efremova_antonina1957@postgrespro.ru", "phone": "+70251708286"}
0005434139884	B6A3B7	0006 465070	LUIZA ORLOVA	{"phone": "+70107613649"}
0005434139885	45481A	3191 671201	NIKITA SMIRNOV	{"email": "smirnovnikita.30121973@postgrespro.ru", "phone": "+70633056845"}
0005434139886	45481A	0185 159108	YULIYA SCHERBAKOVA	{"phone": "+70092388464"}
0005434139887	027588	0321 860231	LIDIYA MOROZOVA	{"email": "lidiya.morozova031968@postgrespro.ru", "phone": "+70168935882"}
0005434139888	FA1305	4279 286219	GALINA STEPANOVA	{"phone": "+70887701893"}
0005434139889	FA1305	8041 656213	SVETLANA BELOVA	{"email": "s_belova-1958@postgrespro.ru", "phone": "+70630150449"}
0005434139890	FA1305	6684 448529	SVETLANA MATVEEVA	{"phone": "+70356526426"}
0005434139891	C5A8B5	9945 581520	VALENTINA NOVIKOVA	{"phone": "+70194465656"}
0005434139892	73626A	6975 714563	MARINA VASILEVA	{"phone": "+70498721860"}
0005434139893	73626A	4076 703205	ANDREY NIKOLAEV	{"phone": "+70039092475"}
0005434139894	4F4B00	2479 301092	VLADIMIR EGOROV	{"email": "v.egorov_05081975@postgrespro.ru", "phone": "+70309428913"}
0005434139895	50BA04	8007 203349	LIDIYA ANDREEVA	{"phone": "+70486980568"}
0005434139896	50BA04	9796 212865	TATYANA KUZNECOVA	{"email": "tkuznecova071968@postgrespro.ru", "phone": "+70526544438"}
0005434139897	E17F75	2509 606660	OLGA SIDOROVA	{"phone": "+70803385714"}
0005434140010	3CF091	6874 713895	OLGA ZAYCEVA	{"phone": "+70386403963"}
0005434139898	CE7280	7802 700879	NIKOLAY ZHURAVLEV	{"email": "n_zhuravlev30061969@postgrespro.ru", "phone": "+70721975653"}
0005434139899	12BA55	2328 961142	ANATOLIY IVANOV	{"phone": "+70922217070"}
0005434139900	919AB5	2180 661878	TATYANA DENISOVA	{"phone": "+70537401771"}
0005434139901	919AB5	1429 155128	OLGA NOVIKOVA	{"phone": "+70647558795"}
0005434139902	0626DD	9753 210255	EVGENIY NAUMOV	{"email": "naumov_evgeniy.121973@postgrespro.ru", "phone": "+70137631845"}
0005434139903	E509DB	7560 952642	LYUBOV GAVRILOVA	{"email": "lgavrilova051980@postgrespro.ru", "phone": "+70797634481"}
0005434139904	E509DB	3449 833136	VLADIMIR ROMANOV	{"email": "romanov_vladimir-29041975@postgrespro.ru", "phone": "+70858909873"}
0005434139905	6FA603	3903 309892	NIKOLAY DENISOV	{"email": "denisov_nikolay-121978@postgrespro.ru", "phone": "+70724136621"}
0005434139906	A20362	1839 849292	NATALIYA VLASOVA	{"phone": "+70272595101"}
0005434139907	DAAC07	9497 955594	ALEKSANDR GRIGOREV	{"email": "a.grigorev_27041977@postgrespro.ru", "phone": "+70543928587"}
0005434139908	552619	8472 657081	SOFYA ROMANOVA	{"email": "sofya_romanova.031972@postgrespro.ru", "phone": "+70365331858"}
0005434139909	C842C0	7518 955783	GRIGORIY KAZAKOV	{"phone": "+70006233677"}
0005434139910	C842C0	5520 806400	LIDIYA KOVALEVA	{"phone": "+70388151330"}
0005434139911	3C1D63	6715 904130	TAISIYA EGOROVA	{"phone": "+70241952052"}
0005434139912	3C1D63	8060 806009	ALEKSANDR FOMIN	{"phone": "+70059585529"}
0005434139913	D0A9BD	4617 812141	SVETLANA MIKHAYLOVA	{"phone": "+70260952540"}
0005434139914	B45F91	3368 577068	NATALYA LUKYANOVA	{"email": "natalya_lukyanova.1974@postgrespro.ru", "phone": "+70900579881"}
0005434139915	5815AA	5245 708035	RUSTAM FOMIN	{"email": "rfomin.1969@postgrespro.ru", "phone": "+70574369536"}
0005434139916	5815AA	8703 311972	GENNADIY PAVLOV	{"email": "g-pavlov.041975@postgrespro.ru", "phone": "+70971252654"}
0005434139917	50FCE4	6306 348790	SERGEY SAVELEV	{"email": "sergey.savelev1969@postgrespro.ru", "phone": "+70824028372"}
0005434139918	9763E4	5110 837526	SVETLANA VOROBEVA	{"email": "vorobevasvetlana_051973@postgrespro.ru", "phone": "+70966678447"}
0005434139919	424584	9972 167438	ALEKSANDR STEPANOV	{"phone": "+70055318310"}
0005434139920	424584	7983 883416	IRINA ZOTOVA	{"email": "irina_zotova-061981@postgrespro.ru", "phone": "+70498246998"}
0005434139921	785BF2	3734 759248	OLGA SIDOROVA	{"email": "sidorovaolga-1971@postgrespro.ru", "phone": "+70105725764"}
0005434139922	1AFB6D	0306 133678	IRINA MOISEEVA	{"email": "irinamoiseeva-1984@postgrespro.ru", "phone": "+70331451008"}
0005434139923	357C3C	1718 662825	ALEKSANDR ANTONOV	{"email": "a.antonov_09101981@postgrespro.ru", "phone": "+70183345385"}
0005434139924	357C3C	9706 269462	VLADIMIR MEDVEDEV	{"phone": "+70668052572"}
0005434139925	A04829	6883 978595	ELIZAVETA FROLOVA	{"phone": "+70567904948"}
0005434139926	7D4452	6661 309580	LIDIYA SMIRNOVA	{"email": "smirnoval031977@postgrespro.ru", "phone": "+70102950086"}
0005434139927	73C058	5617 289351	YANA IVANOVA	{"phone": "+70498271162"}
0005434139928	E1F32C	2221 672253	ALEKSEY POPOV	{"phone": "+70918289060"}
0005434139929	E1F32C	0536 608019	NADEZHDA FILATOVA	{"phone": "+70091471828"}
0005434139930	9FD1D7	3195 950248	TAMARA MIRONOVA	{"phone": "+70387796055"}
0005434139931	6099EE	9632 948257	DARYA VLASOVA	{"phone": "+70014713593"}
0005434139932	413614	4331 289262	MARIYA OSIPOVA	{"email": "osipova.mariya1977@postgrespro.ru", "phone": "+70892353113"}
0005434139933	D32517	1495 600615	MIKHAIL POPOV	{"email": "mpopov111981@postgrespro.ru", "phone": "+70306387782"}
0005434139934	B5DBA2	8564 199433	DIANA NOVIKOVA	{"email": "d-novikova.1960@postgrespro.ru", "phone": "+70769785619"}
0005434139935	FE129C	5637 018971	DANILA KUZNECOV	{"email": "kuznecov_danila-1985@postgrespro.ru", "phone": "+70863966062"}
0005434139936	FE129C	6814 931607	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr.09111961@postgrespro.ru", "phone": "+70667685748"}
0005434139937	EBA31D	8590 612677	POLINA ZAKHAROVA	{"phone": "+70617102824"}
0005434139938	EBA31D	3160 022007	VLADIMIR NIKITIN	{"email": "nikitin.v_031978@postgrespro.ru", "phone": "+70330390757"}
0005434139939	917A21	0949 886517	VALENTINA KUZNECOVA	{"email": "v.kuznecova-1973@postgrespro.ru", "phone": "+70049492323"}
0005434139940	83D5E3	8205 982885	ALEKSANDR EGOROV	{"email": "egorov_aleksandr_101966@postgrespro.ru", "phone": "+70032675358"}
0005434139941	4A244C	4018 445436	SVETLANA ILINA	{"phone": "+70357417027"}
0005434139942	F6FF9D	4406 610927	POLINA IVANOVA	{"email": "ivanova_polina28081969@postgrespro.ru", "phone": "+70614950310"}
0005434139943	F6FF9D	4119 405763	MARINA ROMANOVA	{"email": "marina.romanova.021974@postgrespro.ru", "phone": "+70009443317"}
0005434139944	8825DE	8719 871995	YULIYA KONOVALOVA	{"phone": "+70430016137"}
0005434139945	8825DE	7369 208875	VIOLETTA BOGDANOVA	{"phone": "+70888121616"}
0005434139946	E294C6	3745 102256	OLGA NOVIKOVA	{"phone": "+70727033380"}
0005434139947	80943A	4967 451616	ELINA MIRONOVA	{"email": "elinamironova_081969@postgrespro.ru", "phone": "+70574599213"}
0005434139948	EAD533	6664 833064	MAKSIM BELOV	{"email": "m_belov-1977@postgrespro.ru", "phone": "+70757777574"}
0005434139949	6A060D	7240 759888	VIKTOR ABRAMOV	{"email": "viktor.abramov.1972@postgrespro.ru", "phone": "+70260720995"}
0005434139950	85E82F	2418 599311	SVETLANA DMITRIEVA	{"email": "svetlana_dmitrieva_20111968@postgrespro.ru", "phone": "+70934627510"}
0005434139951	E0D24D	0323 766890	VASILIY IVANOV	{"email": "ivanov-v-1959@postgrespro.ru", "phone": "+70045373140"}
0005434139952	7D9F78	1199 141016	ELENA SERGEEVA	{"email": "sergeeva.elena1960@postgrespro.ru", "phone": "+70898115495"}
0005434139954	DD3CD4	9899 006403	ANZHELIKA LOGINOVA	{"email": "a.loginova_1962@postgrespro.ru", "phone": "+70574466493"}
0005434139955	DD3CD4	2200 868928	OLGA ILINA	{"phone": "+70226808449"}
0005434139956	399813	3065 633734	SERGEY ZHUKOV	{"phone": "+70387292689"}
0005434139957	399813	1170 684924	MARINA LEBEDEVA	{"phone": "+70549874292"}
0005434139958	42BBED	7562 605621	NIKITA ALEKSANDROV	{"email": "nikita_aleksandrov09121970@postgrespro.ru", "phone": "+70384330913"}
0005434139959	944009	2346 448208	RAISA ERMAKOVA	{"email": "ermakova_r_12051978@postgrespro.ru", "phone": "+70225459583"}
0005434139960	C680E2	3695 745500	ANDREY KUZNECOV	{"email": "andreykuznecov.121975@postgrespro.ru", "phone": "+70989510436"}
0005434139961	59D3CB	0788 471063	MARIYA BELOVA	{"email": "belova-m.041974@postgrespro.ru", "phone": "+70238237431"}
0005434139962	59D3CB	5978 540089	POLINA PAVLOVA	{"email": "polina.pavlova081963@postgrespro.ru", "phone": "+70985134942"}
0005434139963	9FF250	1227 810514	VIKTOR STEPANOV	{"phone": "+70535822163"}
0005434139964	9FF250	8910 885424	ANNA ERMAKOVA	{"email": "ermakova-anna_081975@postgrespro.ru", "phone": "+70857280737"}
0005434139965	C89289	3624 208633	VIKTORIYA KUZNECOVA	{"phone": "+70491743203"}
0005434139966	483D1D	6976 664306	SERGEY MATVEEV	{"email": "matveev-sergey20121967@postgrespro.ru", "phone": "+70631933223"}
0005434139967	93092A	4576 325789	NIKITA GAVRILOV	{"email": "gavrilov_nikita.1967@postgrespro.ru", "phone": "+70375867073"}
0005434139968	93092A	5701 714122	ANDREY DAVYDOV	{"phone": "+70012304347"}
0005434139969	93092A	1208 388881	LYUDMILA MAKSIMOVA	{"email": "l.maksimova.1978@postgrespro.ru", "phone": "+70743489198"}
0005434139970	E1C43E	3434 323411	VIKTOR KOZLOV	{"phone": "+70485512278"}
0005434139971	98D48C	1938 720558	VERA RYABOVA	{"phone": "+70279069169"}
0005434139972	29E46C	6258 507816	VLADIMIR MAKAROV	{"email": "makarovvladimir1982@postgrespro.ru", "phone": "+70361269816"}
0005434139973	29B9F8	5516 702057	TATYANA ALEKSANDROVA	{"email": "aleksandrova_t1987@postgrespro.ru", "phone": "+70643206582"}
0005434139974	29B9F8	5883 365952	GALINA EFIMOVA	{"email": "efimova-galina_10081981@postgrespro.ru", "phone": "+70402652372"}
0005434139975	F45F1D	1283 226683	NATALYA GORBUNOVA	{"email": "gorbunovanatalya1973@postgrespro.ru", "phone": "+70633409296"}
0005434139976	EB2162	4221 393429	ANTONINA ANISIMOVA	{"phone": "+70602085181"}
0005434139977	0B48E7	3128 038528	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov.121969@postgrespro.ru", "phone": "+70693682580"}
0005434139978	178021	5802 594777	ALEKSANDR KAZAKOV	{"phone": "+70491417591"}
0005434139979	F21AAB	3717 427894	EKATERINA EFREMOVA	{"phone": "+70516463030"}
0005434139980	F21AAB	0020 973991	MAKSIM ISAEV	{"phone": "+70459014154"}
0005434139981	500A87	0920 313186	ANNA KUZNECOVA	{"phone": "+70730308336"}
0005434139982	066395	2308 023529	ALEKSANDR ROMANOV	{"phone": "+70654963408"}
0005434139983	71F06F	7693 249253	MARINA LEBEDEVA	{"phone": "+70203151545"}
0005434139984	803E6A	1292 839921	MARINA VLASOVA	{"phone": "+70739620840"}
0005434139985	EE398E	4744 352467	MARIYA SERGEEVA	{"email": "sergeeva.mariya.02121974@postgrespro.ru", "phone": "+70275266295"}
0005434139986	EE398E	1304 554451	NATALYA POPOVA	{"phone": "+70120809704"}
0005434139987	4916F7	5567 240503	LYUDMILA KOVALEVA	{"email": "kovaleval-16031967@postgrespro.ru", "phone": "+70986572545"}
0005434139988	4916F7	0971 220366	PETR ANTONOV	{"phone": "+70781586961"}
0005434139989	1D7612	8859 036581	KIRILL ILIN	{"email": "kirill_ilin.031973@postgrespro.ru", "phone": "+70797888959"}
0005434139990	FCA352	4429 261823	OLGA TARASOVA	{"phone": "+70230925483"}
0005434139991	916A8D	1323 873277	ELENA TROFIMOVA	{"email": "trofimovae.101971@postgrespro.ru", "phone": "+70547023334"}
0005434139992	9664AC	3523 499653	VIKTOR KUDRYASHOV	{"email": "kudryashovviktor.061971@postgrespro.ru", "phone": "+70366115936"}
0005434139993	2FEED6	3547 548675	LYUBOV SERGEEVA	{"email": "lyubov-sergeeva-051974@postgrespro.ru", "phone": "+70419101812"}
0005434139994	03ACCC	6136 598844	GULNARA TROFIMOVA	{"email": "g_trofimova_24081967@postgrespro.ru", "phone": "+70244048827"}
0005434139995	3CE6F2	0137 752468	KSENIYA DMITRIEVA	{"phone": "+70965334296"}
0005434139996	4CCE1F	7370 256996	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr-1970@postgrespro.ru", "phone": "+70251678938"}
0005434139997	000862	3664 393414	ARTEM KULIKOV	{"email": "kulikov-a-1956@postgrespro.ru", "phone": "+70337637641"}
0005434139998	000862	1491 834684	MARGARITA MAKAROVA	{"email": "m-makarova-1981@postgrespro.ru", "phone": "+70428423059"}
0005434139999	77B598	8351 603328	LARISA KUZMINA	{"phone": "+70740758825"}
0005434140000	6858AF	2818 912084	MAKSIM VLASOV	{"email": "vlasov.maksim1965@postgrespro.ru", "phone": "+70071927318"}
0005434140001	D17EFC	2415 227679	ALEKSANDR PETROV	{"email": "a_petrov.051972@postgrespro.ru", "phone": "+70963548161"}
0005434140002	6C1084	5851 226972	ALEKSEY DMITRIEV	{"email": "dmitrieva_011977@postgrespro.ru", "phone": "+70948006949"}
0005434140003	FF2AF4	2030 862761	ILYA VASILEV	{"email": "vasilev_ilya051968@postgrespro.ru", "phone": "+70621569450"}
0005434140004	961B52	0400 640799	VLADIMIR VOROBEV	{"phone": "+70056825930"}
0005434140005	961B52	2653 993928	LARISA KISELEVA	{"phone": "+70257797924"}
0005434140006	0B5E33	5550 923698	ANNA ZOTOVA	{"email": "anna-zotova-011988@postgrespro.ru", "phone": "+70308687938"}
0005434140007	0B5E33	8180 108739	SVETLANA MELNIKOVA	{"phone": "+70320590220"}
0005434140009	3CF091	7960 360800	YULIYA DAVYDOVA	{"phone": "+70719233519"}
0005434140011	4482F8	7657 992152	ALEKSANDR POPOV	{"phone": "+70787134873"}
0005434140012	4482F8	2023 764351	NIKOLAY VASILEV	{"phone": "+70624618625"}
0005434140013	0746B3	4878 124345	VLADISLAV VASILEV	{"email": "vasilevv-011971@postgrespro.ru", "phone": "+70435666915"}
0005434140014	060072	7198 607623	DANIIL MIKHAYLOV	{"phone": "+70902844754"}
0005434140015	B47546	0241 878670	VALENTINA IVANOVA	{"phone": "+70026103496"}
0005434140016	89E6DF	3345 067094	LYUBOV MAKSIMOVA	{"phone": "+70632995440"}
0005434140017	3247B0	7943 039883	VLADIMIR SOROKIN	{"email": "vladimir-sorokin_031966@postgrespro.ru", "phone": "+70327092181"}
0005434140018	3247B0	3715 117054	ANDREY SCHERBAKOV	{"email": "andreyscherbakov.1975@postgrespro.ru", "phone": "+70764463483"}
0005434140019	3929E9	8737 528693	TATYANA KOLESNIKOVA	{"phone": "+70732680915"}
0005434140020	DF014D	6075 249749	VLADIMIR YAKOVLEV	{"phone": "+70272927720"}
0005434140021	BCD06F	8814 224890	FAINA KOVALEVA	{"email": "f_kovaleva_021967@postgrespro.ru", "phone": "+70118465686"}
0005434140022	02EEAA	3225 891478	TATYANA ZAYCEVA	{"phone": "+70468827852"}
0005434140023	B9C074	1976 549198	EKATERINA KOLESNIKOVA	{"phone": "+70417967731"}
0005434140024	0AFD65	9045 715303	MARIYA VOROBEVA	{"email": "m-vorobeva_041978@postgrespro.ru", "phone": "+70059881324"}
0005434140025	0AFD65	2955 917616	IRINA NIKOLAEVA	{"phone": "+70750739627"}
0005434140026	0AFD65	1962 604460	RUFIYA GRISHINA	{"email": "grishina-rufiya-03021982@postgrespro.ru", "phone": "+70471499749"}
0005434140027	D1E649	8558 899745	ROZALIYA SERGEEVA	{"email": "r_sergeeva1964@postgrespro.ru", "phone": "+70645196270"}
0005434140028	D1E649	2148 043433	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov1986@postgrespro.ru", "phone": "+70842701837"}
0005434140029	5DD7CB	7333 782813	LYUDMILA EGOROVA	{"phone": "+70594152122"}
0005434140030	04B119	5944 168801	TATYANA SEMENOVA	{"phone": "+70106483396"}
0005434140031	04B119	0236 284352	VLADIMIR FILIPPOV	{"phone": "+70162744178"}
0005434140032	2B567F	5457 243569	NIKITA SEMENOV	{"phone": "+70159422817"}
0005434140033	6ACBA4	5638 434985	YULIYA GUSEVA	{"phone": "+70939814055"}
0005434140034	D3EFCF	4008 610649	OLGA MATVEEVA	{"phone": "+70420450918"}
0005434140036	621926	5675 680205	MIKHAIL VLASOV	{"phone": "+70830089775"}
0005434140037	621926	1704 954726	SVETLANA FILATOVA	{"email": "filatovasvetlana_1982@postgrespro.ru", "phone": "+70551079108"}
0005434140038	621926	8868 048274	MAKSIM KUZMIN	{"email": "kuzmin.m1985@postgrespro.ru", "phone": "+70193979500"}
0005434140039	BF4AE4	7147 083053	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr06111972@postgrespro.ru", "phone": "+70566375734"}
0005434140040	5F30F5	5501 041987	NATALYA MOROZOVA	{"email": "morozovanatalya-1963@postgrespro.ru", "phone": "+70913548493"}
0005434140041	24454F	7878 421750	TATYANA PAVLOVA	{"phone": "+70129101067"}
0005434140042	B9DAD9	0063 690158	LIDIYA POLYAKOVA	{"phone": "+70362251902"}
0005434140043	B4FC2D	1081 270770	EVGENIY POPOV	{"email": "e_popov.12031973@postgrespro.ru", "phone": "+70496918639"}
0005434140044	2BCF9A	8948 510606	VYACHESLAV ZAYCEV	{"phone": "+70284104260"}
0005434140045	2A5746	4555 362813	EVGENIYA PETROVA	{"phone": "+70468341574"}
0005434140046	2A5746	0759 085635	BORIS TIKHONOV	{"phone": "+70280274798"}
0005434140047	BF581B	0130 765502	LYUDMILA SOKOLOVA	{"phone": "+70878475372"}
0005434140048	4143DC	3732 242026	ANDREY ALEKSEEV	{"phone": "+70780570858"}
0005434140049	4143DC	5167 314412	VYACHESLAV SOKOLOV	{"email": "sokolov-v_07011982@postgrespro.ru", "phone": "+70235936896"}
0005434140050	4143DC	7082 560471	MARIYA KOROLEVA	{"phone": "+70670337600"}
0005434140051	7F9DC6	9784 996020	DMITRIY MIKHAYLOV	{"phone": "+70103266052"}
0005434140052	A335B2	4554 897572	TATYANA SIDOROVA	{"phone": "+70903665110"}
0005434140053	3B5028	4749 754408	ANZHELA POPOVA	{"phone": "+70127464382"}
0005434140054	D8104B	8569 775379	ALEKSANDR TARASOV	{"phone": "+70545771840"}
0005434140055	9601D5	7037 102458	NIKITA KOZLOV	{"email": "kozlovnikita.051977@postgrespro.ru", "phone": "+70612960948"}
0005434140056	9601D5	6009 887309	LYUDMILA MASLOVA	{"email": "l-maslova081979@postgrespro.ru", "phone": "+70319555044"}
0005434140057	308DC3	1280 322169	NATALIYA NESTEROVA	{"phone": "+70121345137"}
0005434140058	308DC3	0417 294169	NIKOLAY CHERNOV	{"email": "n-chernov1974@postgrespro.ru", "phone": "+70230343265"}
0005434140059	C92913	4890 618111	NINA KOROLEVA	{"email": "nina_koroleva.30081975@postgrespro.ru", "phone": "+70486365648"}
0005434140060	F83498	7016 721461	LYUDMILA TIKHONOVA	{"email": "tikhonoval011982@postgrespro.ru", "phone": "+70375884612"}
0005434140061	FAB47A	9293 067332	EVGENIYA ORLOVA	{"email": "orlova-evgeniya_1964@postgrespro.ru", "phone": "+70576681587"}
0005434140062	01BE43	6517 615660	EDUARD SCHERBAKOV	{"phone": "+70914507933"}
0005434140063	ECBDA8	9210 221346	GALINA EFIMOVA	{"email": "efimovagalina_031976@postgrespro.ru", "phone": "+70004917928"}
0005434140064	ECBDA8	7990 585150	ALEKSEY GORBUNOV	{"email": "gorbunov.a.23071971@postgrespro.ru", "phone": "+70074154386"}
0005434140065	1D91C5	8762 329014	OKSANA VOROBEVA	{"phone": "+70402426493"}
0005434140066	1D91C5	5233 876065	ELENA ROMANOVA	{"email": "e_romanova.121967@postgrespro.ru", "phone": "+70135278885"}
0005434140067	6D4F7D	7332 481079	VARVARA IVANOVA	{"email": "ivanova.v.031970@postgrespro.ru", "phone": "+70151691745"}
0005434140068	6D4F7D	9715 970419	VALERIY NAZAROV	{"email": "nazarov-v111968@postgrespro.ru", "phone": "+70445077274"}
0005434140069	D209A9	1543 563507	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_061983@postgrespro.ru", "phone": "+70830711580"}
0005434140070	D209A9	2093 636734	ANASTASIYA BORISOVA	{"email": "borisova_a061979@postgrespro.ru", "phone": "+70668673033"}
0005434140071	7BE7F0	7984 699676	SERGEY ANDREEV	{"phone": "+70546743122"}
0005434140072	7D0503	7962 815720	VLADIMIR MELNIKOV	{"email": "v.melnikov_16011979@postgrespro.ru", "phone": "+70594512882"}
0005434140073	7D0503	0418 130141	ILYA GRIGOREV	{"email": "grigorevi_081978@postgrespro.ru", "phone": "+70571859559"}
0005434140074	D62226	2709 033056	VALENTIN BELOV	{"email": "belov-v-1967@postgrespro.ru", "phone": "+70169041434"}
0005434140075	7D8F77	5078 755041	NIKOLAY DAVYDOV	{"phone": "+70726831740"}
0005434140076	7D8F77	2625 648367	LYUDMILA KULIKOVA	{"email": "kulikoval_1965@postgrespro.ru", "phone": "+70931945788"}
0005434140077	D36609	4180 502417	ALEKSEY NIKITIN	{"phone": "+70961271876"}
0005434140078	D36609	4418 923882	VERA IVANOVA	{"phone": "+70904870005"}
0005434140079	0A78D5	8125 163204	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy.1958@postgrespro.ru", "phone": "+70327491786"}
0005434140080	F0BDFC	6809 453763	TATYANA KONOVALOVA	{"email": "tatyana_konovalova.1968@postgrespro.ru", "phone": "+70474229391"}
0005434140081	54FEEC	7452 481139	DMITRIY IVANOV	{"email": "divanov-051968@postgrespro.ru", "phone": "+70669435160"}
0005434140082	54FEEC	0056 690547	NATALYA ZAKHAROVA	{"phone": "+70791024170"}
0005434140083	BD4FB0	9429 032844	IRINA ISAEVA	{"phone": "+70086685961"}
0005434140084	9D8626	6504 076696	MIKHAIL FEDOTOV	{"phone": "+70696563340"}
0005434140085	9D8626	3071 435708	SERGEY GERASIMOV	{"email": "sergey-gerasimov.27061963@postgrespro.ru", "phone": "+70436564664"}
0005434140086	47CFB5	3881 926563	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr051978@postgrespro.ru", "phone": "+70404178983"}
0005434140087	FDD387	1013 639753	LYUDMILA MAKSIMOVA	{"phone": "+70339909771"}
0005434140088	FDD387	6423 404636	LARISA GORBUNOVA	{"email": "gorbunova_larisa_04091969@postgrespro.ru", "phone": "+70402757283"}
0005434140089	27D43F	3380 189451	YANA SMIRNOVA	{"email": "y.smirnova.071975@postgrespro.ru", "phone": "+70060649127"}
0005434140090	8CEB36	8332 530893	LILIYA SIDOROVA	{"email": "sidorova-liliya-22081968@postgrespro.ru", "phone": "+70885336325"}
0005434140147	BEC619	6916 527879	NATALYA MALYSHEVA	{"phone": "+70269458566"}
0005434140091	B4BAD5	1074 141219	POLINA POPOVA	{"email": "ppopova-1962@postgrespro.ru", "phone": "+70514855283"}
0005434140092	B4BAD5	6727 398232	DAMIR SHEVCHENKO	{"email": "shevchenko.damir_011968@postgrespro.ru", "phone": "+70458762891"}
0005434140093	B33398	2305 089925	ANASTASIYA BELYAEVA	{"phone": "+70825262651"}
0005434140094	72D5C4	0148 574510	VLADIMIR TIKHONOV	{"email": "v-tikhonov_081973@postgrespro.ru", "phone": "+70176474466"}
0005434140095	D4D1AE	2509 815709	STANISLAV YAKOVLEV	{"email": "syakovlev.051965@postgrespro.ru", "phone": "+70281825413"}
0005434140096	675284	7303 476055	ELENA FADEEVA	{"email": "e-fadeeva111980@postgrespro.ru", "phone": "+70460842202"}
0005434140097	684EDC	5478 264755	DMITRIY MIRONOV	{"phone": "+70019139374"}
0005434140098	684EDC	4621 583894	GALINA SIDOROVA	{"phone": "+70507386868"}
0005434140099	A23685	4239 752120	NIKITA SMIRNOV	{"phone": "+70265892116"}
0005434140100	A23685	6149 611165	SEMEN TIKHONOV	{"phone": "+70886092090"}
0005434140101	C78A43	6706 949124	IVAN KUZNECOV	{"email": "kuznecov_i-05091971@postgrespro.ru", "phone": "+70489108174"}
0005434140102	C78A43	8964 600496	ELENA MELNIKOVA	{"email": "e.melnikova1976@postgrespro.ru", "phone": "+70636001172"}
0005434140103	C78A43	4027 008183	NATALYA MIRONOVA	{"email": "n-mironova-18101970@postgrespro.ru", "phone": "+70332605541"}
0005434140104	9C3520	6906 689495	SVETLANA BELYAEVA	{"email": "sbelyaeva_091975@postgrespro.ru", "phone": "+70793285447"}
0005434140105	A05736	4978 774337	ALEKSANDR VOROBEV	{"email": "vorobev-aleksandr_1965@postgrespro.ru", "phone": "+70372471948"}
0005434140106	BDEC25	8426 345966	VLADIMIR SIDOROV	{"email": "sidorov-vladimir.1966@postgrespro.ru", "phone": "+70655854601"}
0005434140107	BDEC25	8439 519833	ALEKSANDR MIKHAYLOV	{"phone": "+70022599006"}
0005434140108	E0F29A	5850 972714	DANILA EGOROV	{"email": "egorov_danila-041968@postgrespro.ru", "phone": "+70456489228"}
0005434140109	E0F29A	5534 053637	NIKOLAY BORISOV	{"email": "borisovn.02021971@postgrespro.ru", "phone": "+70454539913"}
0005434140110	CFD014	2867 608028	OLGA FEDOROVA	{"email": "fedorova.olga_1960@postgrespro.ru", "phone": "+70023218152"}
0005434140111	AFA800	7126 099131	YURIY KONOVALOV	{"email": "konovalov.yuriy-031967@postgrespro.ru", "phone": "+70549238620"}
0005434140112	142E12	8291 511712	MARIYA SOLOVEVA	{"email": "mariyasoloveva.011979@postgrespro.ru", "phone": "+70738872423"}
0005434140113	B56A38	9375 004215	DENIS SCHERBAKOV	{"email": "denis.scherbakov-24041968@postgrespro.ru", "phone": "+70811736100"}
0005434140114	B56A38	3363 017404	ANTON ABRAMOV	{"phone": "+70281598953"}
0005434140115	33CC54	1641 909901	LYUBOV ZHURAVLEVA	{"email": "lzhuravleva_011981@postgrespro.ru", "phone": "+70103693432"}
0005434140116	57C9C4	6495 927329	ALEKSANDR KULIKOV	{"email": "a-kulikov.29031976@postgrespro.ru", "phone": "+70900620938"}
0005434140117	255EF4	8397 808262	RAISA OSIPOVA	{"phone": "+70642950282"}
0005434140118	42A7D8	8770 513103	INNA EGOROVA	{"email": "i-egorova_30101975@postgrespro.ru", "phone": "+70888244530"}
0005434140119	83656C	1505 681832	DMITRIY MOISEEV	{"phone": "+70266682209"}
0005434140120	EC74D3	3539 389281	NINA KUDRYASHOVA	{"phone": "+70360817732"}
0005434140121	EC74D3	2102 506604	SEMEN KOZLOV	{"phone": "+70712510480"}
0005434140122	E42378	5162 772068	YURIY VASILEV	{"phone": "+70627401901"}
0005434140123	E42378	9356 236118	EVGENIY VASILEV	{"phone": "+70888997091"}
0005434140124	16C248	7317 560552	STANISLAV CHERNOV	{"phone": "+70358114482"}
0005434140125	D07209	3333 893808	ANATOLIY MIKHAYLOV	{"phone": "+70370203391"}
0005434140126	D07209	7094 974965	EKATERINA NIKOLAEVA	{"email": "e-nikolaeva-02051973@postgrespro.ru", "phone": "+70033855564"}
0005434140127	5723B0	2076 495860	MARIYA EGOROVA	{"phone": "+70471867422"}
0005434140128	58B904	5130 164366	YULIYA OSIPOVA	{"email": "osipovay-17041978@postgrespro.ru", "phone": "+70771840802"}
0005434140129	58B904	0191 680657	LYUBOV KUZMINA	{"phone": "+70608379188"}
0005434140130	E0B098	9403 413794	STEPAN STEPANOV	{"phone": "+70131583049"}
0005434140131	E0B098	1430 502286	ALEKSANDR KAZAKOV	{"phone": "+70614151981"}
0005434140132	498F5F	3040 761379	ANTON BELOV	{"phone": "+70605907963"}
0005434140133	498F5F	7677 953777	ANNA KOROLEVA	{"phone": "+70760518048"}
0005434140134	6CD4E8	4244 836929	OLESYA FILIPPOVA	{"phone": "+70880907270"}
0005434140135	6CD4E8	9083 002183	IRINA GAVRILOVA	{"phone": "+70692747073"}
0005434140136	ECCF20	1797 702564	VLADIMIR AFANASEV	{"phone": "+70935710174"}
0005434140137	292757	7992 274466	TATYANA KUZNECOVA	{"phone": "+70463686749"}
0005434140138	292757	3010 581197	VARVARA NESTEROVA	{"email": "v-nesterova061973@postgrespro.ru", "phone": "+70210939398"}
0005434140139	8F2BEA	6063 143764	KSENIYA STEPANOVA	{"phone": "+70185597190"}
0005434140140	8F2BEA	9296 359408	SERGEY MAKAROV	{"email": "makarovsergey-121974@postgrespro.ru", "phone": "+70170347257"}
0005434140141	EEAC58	9765 574792	ANDREY EGOROV	{"phone": "+70012517089"}
0005434140142	C3726C	1398 755810	ALEKSANDR IVANOV	{"phone": "+70727935845"}
0005434140143	42C5DC	1402 227651	ANTON VASILEV	{"email": "anton_vasilev02081967@postgrespro.ru", "phone": "+70315858869"}
0005434140144	BDB989	6294 975045	VALENTINA VASILEVA	{"email": "vasileva.valentina.061963@postgrespro.ru", "phone": "+70258943125"}
0005434140145	AF8608	0866 396713	POLINA FILIPPOVA	{"phone": "+70327365710"}
0005434140146	AF8608	4484 279832	ANASTASIYA ORLOVA	{"email": "orlova_a-12061972@postgrespro.ru", "phone": "+70822112684"}
0005434140148	99762F	3489 588735	ANASTASIYA POPOVA	{"phone": "+70296924658"}
0005434140149	41A9C6	3109 832218	EVGENIY KAZAKOV	{"phone": "+70323860606"}
0005434140150	27FA07	8530 481185	TATYANA AFANASEVA	{"phone": "+70396628558"}
0005434140151	27FA07	4063 322544	TATYANA KUZMINA	{"phone": "+70972434770"}
0005434140152	152F2D	4404 932940	NATALYA DENISOVA	{"phone": "+70874344753"}
0005434140153	152F2D	8147 061070	ANGELINA POTAPOVA	{"phone": "+70758853178"}
0005434140154	26710D	7105 816163	LARISA ZAKHAROVA	{"email": "zakharova_larisa_1971@postgrespro.ru", "phone": "+70101096257"}
0005434140155	E264E7	4057 030529	DMITRIY FILIPPOV	{"email": "dmitriy_filippov-21031978@postgrespro.ru", "phone": "+70919018499"}
0005434140156	E264E7	4625 171136	NIKOLAY KAZAKOV	{"phone": "+70467754544"}
0005434140157	2A0488	5090 837117	VERA SOROKINA	{"email": "sorokinavera.111974@postgrespro.ru", "phone": "+70170417442"}
0005434140158	375469	8848 862406	ALEKSANDR SEMENOV	{"phone": "+70244381913"}
0005434140159	0F5F69	6046 926640	ALEKSEY SOKOLOV	{"email": "a-sokolov101972@postgrespro.ru", "phone": "+70476812726"}
0005434140160	0F5F69	3581 872148	MARINA POTAPOVA	{"email": "marina_potapova_1972@postgrespro.ru", "phone": "+70430850846"}
0005434140161	AD3F28	3191 269214	SERGEY DAVYDOV	{"email": "sergey_davydov-1972@postgrespro.ru", "phone": "+70585397308"}
0005434140162	B5D3D2	4615 736138	IGOR GAVRILOV	{"email": "gavrilov-i041964@postgrespro.ru", "phone": "+70193070612"}
0005434140163	B5D3D2	3744 875734	EVGENIYA ZOTOVA	{"email": "ezotova_1972@postgrespro.ru", "phone": "+70795042117"}
0005434140164	CA4310	0012 946464	MARIYA ROMANOVA	{"phone": "+70487960990"}
0005434140165	B58407	7982 975316	SVETLANA ISAEVA	{"email": "svetlana_isaeva_1973@postgrespro.ru", "phone": "+70725137913"}
0005434140166	AA7C08	4723 570108	VALENTINA ANISIMOVA	{"phone": "+70333721607"}
0005434140167	271C46	3904 308018	STEPAN MIKHAYLOV	{"phone": "+70335693737"}
0005434140168	271C46	1114 934279	LYUDMILA KUZMINA	{"phone": "+70197527440"}
0005434140169	F7ECAA	0540 660631	ALESYA MEDVEDEVA	{"phone": "+70490756190"}
0005434140170	190C29	6329 377364	TATYANA ARKHIPOVA	{"email": "arkhipova.tatyana-14041973@postgrespro.ru", "phone": "+70983010403"}
0005434140171	190C29	8068 176036	VIKTOR SOROKIN	{"phone": "+70849664177"}
0005434140172	46A975	4694 401081	KRISTINA ANTONOVA	{"phone": "+70335343723"}
0005434140173	46A975	3074 812771	VALERIY KUZNECOV	{"email": "valeriy_kuznecov12031971@postgrespro.ru", "phone": "+70560645653"}
0005434140174	D79584	4129 832617	ALEKSANDR ABRAMOV	{"phone": "+70500010518"}
0005434140175	2977A9	5336 540357	ILYA MEDVEDEV	{"email": "ilya_medvedev-121982@postgrespro.ru", "phone": "+70600950689"}
0005434140176	C6D98E	9422 546073	TATYANA TROFIMOVA	{"email": "trofimovatatyana-1971@postgrespro.ru", "phone": "+70277783307"}
0005434140177	C6D98E	0507 944345	OLGA KUZNECOVA	{"phone": "+70414606199"}
0005434140178	23E886	4237 666122	ANDREY CHERNOV	{"email": "andrey_chernov_021988@postgrespro.ru", "phone": "+70666655890"}
0005434140179	753554	9871 197642	ANATOLIY ROMANOV	{"phone": "+70733508921"}
0005434140180	C50EBB	6176 790407	NINA YUDINA	{"phone": "+70310840009"}
0005434140181	C50EBB	8997 572564	LARISA KAZAKOVA	{"phone": "+70027128949"}
0005434140182	C50EBB	9544 043293	YULIYA SOKOLOVA	{"email": "sokolova-yuliya_081962@postgrespro.ru", "phone": "+70051159165"}
0005434140183	1E275B	7890 691581	VLADISLAV ROMANOV	{"email": "romanov-vladislav_011976@postgrespro.ru", "phone": "+70274604227"}
0005434140184	E70689	0971 051506	ANZHELA IVANOVA	{"phone": "+70090938739"}
0005434140185	E70689	6657 093732	ELENA MAKAROVA	{"phone": "+70564824827"}
0005434140186	CE2267	7768 203890	SERAFIMA ARKHIPOVA	{"email": "arkhipovas30071970@postgrespro.ru", "phone": "+70802349423"}
0005434140187	211720	1114 142718	ILNUR MOROZOV	{"email": "morozovilnur.26021975@postgrespro.ru", "phone": "+70034314364"}
0005434140188	087F19	6260 503678	VITALIY YAKOVLEV	{"phone": "+70160115754"}
0005434140189	087F19	3903 984711	ROMAN MIRONOV	{"phone": "+70280813499"}
0005434140190	F2193D	5094 646501	TATYANA KOMAROVA	{"email": "tatyana.komarova.09071973@postgrespro.ru", "phone": "+70747556870"}
0005434140191	0D44BB	1552 831459	ALEKSEY MAKAROV	{"email": "aleksey.makarov-1970@postgrespro.ru", "phone": "+70750582078"}
0005434140192	6A7399	7189 838352	NINA OVCHINNIKOVA	{"email": "nina.ovchinnikova021968@postgrespro.ru", "phone": "+70919688050"}
0005434140193	FCEE22	0223 446130	YULIYA KUZNECOVA	{"email": "ykuznecova.06071975@postgrespro.ru", "phone": "+70291298286"}
0005434140194	6516F9	6159 938499	ALEKSANDRA MIKHAYLOVA	{"phone": "+70211724763"}
0005434140195	6516F9	8884 680775	LYUDMILA SOKOLOVA	{"email": "sokolova_l_31011974@postgrespro.ru", "phone": "+70555053640"}
0005434140196	CD17C4	1094 082642	ALEKSANDR PETROV	{"phone": "+70915747729"}
0005434140197	CD17C4	9775 592841	PAVEL YAKOVLEV	{"phone": "+70088816026"}
0005434140198	E1C195	8591 767998	VERA POLYAKOVA	{"email": "polyakovavera-091971@postgrespro.ru", "phone": "+70028472627"}
0005434140199	E1C195	7090 642171	ANDREY BELOV	{"phone": "+70096869314"}
0005434140200	C50FC8	0717 562245	GALINA VOLKOVA	{"phone": "+70447272951"}
0005434140201	780347	5696 945781	IVAN GERASIMOV	{"email": "igerasimov_08051969@postgrespro.ru", "phone": "+70178240141"}
0005434140202	45C14D	5333 551315	LYUDMILA KAZAKOVA	{"phone": "+70224085015"}
0005434140203	F59CD9	2099 535944	TATYANA KALININA	{"email": "kalinina_t-24111974@postgrespro.ru", "phone": "+70711860523"}
0005434140204	F59CD9	5018 297372	VALENTINA ISAEVA	{"phone": "+70881578536"}
0005434140205	F59CD9	5980 667883	TIMOFEY BARANOV	{"email": "baranovt_15071979@postgrespro.ru", "phone": "+70376041503"}
0005434140206	6EAED9	6860 847049	ANATOLIY POPOV	{"email": "popov.anatoliy-15061972@postgrespro.ru", "phone": "+70518543940"}
0005434140207	14DEB8	1657 046857	NADEZHDA MELNIKOVA	{"email": "n_melnikova07101970@postgrespro.ru", "phone": "+70448093642"}
0005434140208	14DEB8	2955 109460	EVGENIY DENISOV	{"email": "e.denisov.101967@postgrespro.ru", "phone": "+70420528218"}
0005434140209	80017F	5266 802206	DMITRIY CHERNOV	{"email": "d-chernov.1972@postgrespro.ru", "phone": "+70327708902"}
0005434140210	80017F	7631 923540	VIKTOR STEPANOV	{"email": "viktor.stepanov-041975@postgrespro.ru", "phone": "+70028114741"}
0005434140211	90D4D1	7806 265724	ELENA KOMAROVA	{"phone": "+70732558270"}
0005434140212	5C305E	4180 120236	OLEG FOMIN	{"email": "fomin_oleg_1967@postgrespro.ru", "phone": "+70144088842"}
0005434140213	5C305E	1181 442192	OLGA MARTYNOVA	{"phone": "+70431145375"}
0005434140214	AE0516	8564 775914	NADEZHDA NAZAROVA	{"phone": "+70581493139"}
0005434140215	F30702	1007 630294	EVGENIYA ZHUKOVA	{"phone": "+70569263270"}
0005434140216	F30702	2268 439123	NATALYA POTAPOVA	{"email": "potapova.natalya-11051973@postgrespro.ru", "phone": "+70322277362"}
0005434140217	F30702	7578 112070	ALEKSANDRA MELNIKOVA	{"phone": "+70695367734"}
0005434140218	1F52F4	6871 674560	MADINA MAKAROVA	{"email": "mmakarova_13051971@postgrespro.ru", "phone": "+70561485598"}
0005434140219	1F52F4	1640 533455	TATYANA MAKAROVA	{"phone": "+70963612985"}
0005434140220	EBB057	4393 146630	NADEZHDA GAVRILOVA	{"email": "gavrilova-nadezhda_1967@postgrespro.ru", "phone": "+70840808686"}
0005434140221	67B3AC	9957 448313	GALINA YAKOVLEVA	{"phone": "+70263442428"}
0005434140222	594F87	2426 893341	RUSTAM KUZNECOV	{"email": "rkuznecov-1963@postgrespro.ru", "phone": "+70727532096"}
0005434140223	A7B7EC	2799 258636	DMITRIY TIKHONOV	{"email": "d_tikhonov-07031973@postgrespro.ru", "phone": "+70973156258"}
0005434140224	5DC020	8860 668737	OLEG IVANOV	{"email": "o-ivanov-1965@postgrespro.ru", "phone": "+70485855530"}
0005434140225	C685CE	3249 143518	SERGEY SCHERBAKOV	{"email": "sergey.scherbakov-1967@postgrespro.ru", "phone": "+70200948898"}
0005434140226	27F1F4	2603 287008	PAVEL MIKHAYLOV	{"email": "pavelmikhaylov-1975@postgrespro.ru", "phone": "+70141640067"}
0005434140227	6E0651	7175 698296	MIKHAIL ROMANOV	{"phone": "+70807708218"}
0005434140228	4D346B	8580 218660	ZINAIDA SMIRNOVA	{"email": "smirnova_z_13031983@postgrespro.ru", "phone": "+70664479748"}
0005434140229	2CF04B	7483 682513	TATYANA KONOVALOVA	{"email": "tatyana.konovalova.111978@postgrespro.ru", "phone": "+70973413663"}
0005434140230	318C31	7940 183659	DMITRIY TIKHONOV	{"email": "dmitriy-tikhonov_23061975@postgrespro.ru", "phone": "+70322844657"}
0005434140231	318C31	3878 372368	MARIYA YUDINA	{"email": "yudina_m06031968@postgrespro.ru", "phone": "+70625639111"}
0005434140232	E02708	8208 058064	YURIY ALEKSEEV	{"phone": "+70268172083"}
0005434140233	E02708	2965 118994	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr1972@postgrespro.ru", "phone": "+70072219116"}
0005434140234	E02708	2530 863577	IRINA ANDREEVA	{"phone": "+70325656253"}
0005434140235	259FD0	6829 902664	NINA BORISOVA	{"phone": "+70194536476"}
0005434140236	E020DD	1665 833848	VLADIMIR SCHERBAKOV	{"email": "scherbakov.vladimir-111960@postgrespro.ru", "phone": "+70159691266"}
0005434140237	13B7DE	2785 868897	LILIYA NIKOLAEVA	{"email": "nikolaeva-liliya-1965@postgrespro.ru", "phone": "+70161323592"}
0005434140238	A5957F	8894 058872	EKATERINA MASLOVA	{"email": "e_maslova-061974@postgrespro.ru", "phone": "+70176583237"}
0005434140239	1CB606	4102 700651	EVGENIY GUSEV	{"email": "e_gusev_1975@postgrespro.ru", "phone": "+70427130853"}
0005434140240	1CB606	5558 539893	VLADIMIR POPOV	{"email": "popov.vladimir_111981@postgrespro.ru", "phone": "+70659749062"}
0005434140241	AE8BF2	0386 958527	SERGEY FILIPPOV	{"phone": "+70372345447"}
0005434140242	4B9594	4811 251784	ANTON KUZMIN	{"email": "anton.kuzmin_13081956@postgrespro.ru", "phone": "+70357576489"}
0005434140243	64BD48	3349 463479	RASHIT ANTONOV	{"email": "rantonov_011965@postgrespro.ru", "phone": "+70805649376"}
0005434140244	7FB4F6	1036 055127	EVGENIY TIKHONOV	{"phone": "+70579017988"}
0005434140245	7C6C4A	1134 676613	MIKHAIL KUDRYASHOV	{"phone": "+70990859061"}
0005434140246	7C6C4A	7801 682387	SERGEY KUZNECOV	{"phone": "+70055404713"}
0005434140247	F9D844	7305 885092	NINA EGOROVA	{"email": "egorovan19101961@postgrespro.ru", "phone": "+70780435586"}
0005434140248	F63953	1244 929160	TIMOFEY KONOVALOV	{"email": "t-konovalov_051979@postgrespro.ru", "phone": "+70987164587"}
0005434140249	24A15D	0190 899858	ANDREY VLASOV	{"phone": "+70802980121"}
0005434140250	126C6E	8452 375645	ALEKSANDRA POLYAKOVA	{"phone": "+70862150306"}
0005434140251	0D784D	0031 211095	VITALIY MAKSIMOV	{"email": "maksimov_vitaliy-1977@postgrespro.ru", "phone": "+70758917046"}
0005434140252	924979	2595 024875	IGOR NIKOLAEV	{"phone": "+70997300833"}
0005434140253	410099	5547 922297	EKATERINA AFANASEVA	{"email": "ekaterina.afanaseva-031962@postgrespro.ru", "phone": "+70624581859"}
0005434140254	F35A9B	0259 865049	ELENA KUZMINA	{"phone": "+70117053302"}
0005434140255	BB17BD	7305 879508	VLADIMIR SOROKIN	{"email": "v-sorokin.29041971@postgrespro.ru", "phone": "+70619762146"}
0005434140256	BB17BD	7313 837628	LYUDMILA GAVRILOVA	{"email": "lyudmilagavrilova.081980@postgrespro.ru", "phone": "+70579214823"}
0005434140257	FB615C	9598 178104	ALEKSANDR IVANOV	{"phone": "+70445630183"}
0005434140258	5C164F	9095 736430	OLEG VASILEV	{"email": "o-vasilev.1970@postgrespro.ru", "phone": "+70384557037"}
0005434140259	795C70	4211 076627	ALEKSANDR MELNIKOV	{"phone": "+70098597334"}
0005434140260	795C70	7579 237817	SVETLANA KONOVALOVA	{"phone": "+70785718670"}
0005434140261	B45233	9056 060392	VLADIMIR ISAEV	{"email": "isaev_vladimir-011972@postgrespro.ru", "phone": "+70669494009"}
0005434140262	D4C6D9	0952 848876	ELENA SOKOLOVA	{"email": "sokolova_e11111969@postgrespro.ru", "phone": "+70603933875"}
0005434140263	6CBE47	5895 778835	SERGEY KUDRYASHOV	{"email": "kudryashov-s.1978@postgrespro.ru", "phone": "+70432766381"}
0005434140264	CE4486	4583 436448	TATYANA MELNIKOVA	{"phone": "+70357651843"}
0005434140265	F2B2FF	7354 156599	KAMILA POPOVA	{"email": "popovakamila_17121966@postgrespro.ru", "phone": "+70158289262"}
0005434140266	F3BAE8	4678 714172	YULIYA POTAPOVA	{"phone": "+70949445340"}
0005434140267	F3BAE8	6676 560785	RINAT SIDOROV	{"email": "rsidorov22061975@postgrespro.ru", "phone": "+70739819784"}
0005434140268	F3BAE8	2275 438607	ALEKSEY ALEKSEEV	{"email": "alekseev.a.26091979@postgrespro.ru", "phone": "+70433818518"}
0005434140269	E5D7CD	7530 512099	OLGA VOLKOVA	{"phone": "+70845671967"}
0005434140270	269BFB	1816 443485	ILYA POPOV	{"email": "i-popov1977@postgrespro.ru", "phone": "+70830611448"}
0005434140271	75BB79	8184 135672	DMITRIY RODIONOV	{"email": "rodionov-dmitriy-1982@postgrespro.ru", "phone": "+70807417164"}
0005434140272	D7722D	0742 916968	VITALIY NAUMOV	{"email": "naumov_vitaliy_111971@postgrespro.ru", "phone": "+70730599289"}
0005434140273	134374	2980 814661	ANATOLIY NOVIKOV	{"phone": "+70992049690"}
0005434140274	2D4C2C	5599 641556	DANIYA SMIRNOVA	{"phone": "+70812915751"}
0005434140275	6F531E	9367 464160	NIKOLAY MAKSIMOV	{"phone": "+70084961480"}
0005434140276	6F531E	7653 282432	NADEZHDA MELNIKOVA	{"phone": "+70984209878"}
0005434140277	6F531E	4684 946643	IVAN MATVEEV	{"email": "i_matveev_1972@postgrespro.ru", "phone": "+70382397364"}
0005434140278	83B386	4467 837449	ZINAIDA KONDRATEVA	{"email": "kondrateva_zinaida.30031973@postgrespro.ru", "phone": "+70275927452"}
0005434140279	3E47B9	0765 256556	RAISA KOVALEVA	{"email": "r.kovaleva1983@postgrespro.ru", "phone": "+70376624064"}
0005434140280	3E47B9	1835 024254	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova-01041969@postgrespro.ru", "phone": "+70572657757"}
0005434140281	D2C756	4937 945075	EVGENIY ZAKHAROV	{"email": "evgeniy-zakharov02111969@postgrespro.ru", "phone": "+70869255877"}
0005434140282	310DD8	4913 504947	IGOR AFANASEV	{"phone": "+70328966663"}
0005434140283	310DD8	5233 546851	VYACHESLAV PETROV	{"phone": "+70807153671"}
0005434140284	E9C025	9017 070295	OLGA KOROLEVA	{"email": "o.koroleva121967@postgrespro.ru", "phone": "+70379932079"}
0005434140285	E9C025	0287 783553	LIDIYA ANDREEVA	{"phone": "+70979061508"}
0005434140286	705E59	6409 914466	EVGENIYA KOZLOVA	{"email": "kozlova.e_30071980@postgrespro.ru", "phone": "+70553790584"}
0005434140287	705E59	7186 980223	SERGEY OSIPOV	{"phone": "+70218594839"}
0005434140288	4556E1	3614 344169	SERGEY KUZNECOV	{"email": "kuznecov-sergey_31031976@postgrespro.ru", "phone": "+70207536135"}
0005434140289	F6AEFA	3621 415195	IRINA SIDOROVA	{"phone": "+70006103037"}
0005434140290	5D2FD0	5901 740181	RUSTAM SEMENOV	{"phone": "+70816654601"}
0005434140291	5D2FD0	0508 925995	TAMARA SCHERBAKOVA	{"email": "scherbakova.t.031985@postgrespro.ru", "phone": "+70116056319"}
0005434140292	F2CC07	4586 451579	YURIY ILIN	{"phone": "+70647104636"}
0005434140293	A2CC27	1100 513792	NATALYA EFREMOVA	{"email": "efremova_natalya_1965@postgrespro.ru", "phone": "+70291512918"}
0005434140294	A2CC27	7079 130473	VERA SEMENOVA	{"email": "semenova_vera-1980@postgrespro.ru", "phone": "+70314216199"}
0005434140295	3B34AD	6232 104103	VIKTOR ZHUKOV	{"email": "viktorzhukov.28091964@postgrespro.ru", "phone": "+70666125864"}
0005434140296	4E544E	8310 130419	MARIYA SEMENOVA	{"phone": "+70354938891"}
0005434140297	4E544E	3530 418287	ZULFIYA PAVLOVA	{"email": "zulfiya-pavlova.1970@postgrespro.ru", "phone": "+70305477634"}
0005434140298	05CE5C	0778 519631	RAFIS SOKOLOV	{"email": "r_sokolov.17051984@postgrespro.ru", "phone": "+70722326445"}
0005434140299	58BA0B	9115 467888	ALEKSANDR SOKOLOV	{"phone": "+70252789665"}
0005434140300	0422A8	3477 080085	ANNA FOMINA	{"phone": "+70581587682"}
0005434140301	0422A8	4162 423787	ELIZAVETA FROLOVA	{"phone": "+70758882044"}
0005434140302	F23334	8488 413171	STANISLAV TARASOV	{"email": "s.tarasov_1974@postgrespro.ru", "phone": "+70160055217"}
0005434140303	D38182	7130 568094	ELENA SIDOROVA	{"phone": "+70164725304"}
0005434140304	F1DD7C	8708 383140	SERGEY NIKOLAEV	{"email": "nikolaevsergey_021974@postgrespro.ru", "phone": "+70494596533"}
0005434140305	F1DD7C	1015 984299	ALEKSEY FROLOV	{"phone": "+70692660525"}
0005434140306	F1DD7C	0393 802164	VALERIY VOLKOV	{"phone": "+70278125056"}
0005434140307	FA9C25	2305 243875	IRINA NIKITINA	{"email": "irina-nikitina_061977@postgrespro.ru", "phone": "+70689044350"}
0005434140308	FA9C25	4967 315904	ELENA FILATOVA	{"phone": "+70595383004"}
0005434140309	F42170	7894 587276	ALEKSANDR VLASOV	{"email": "a.vlasov1978@postgrespro.ru", "phone": "+70901118006"}
0005434140310	33D930	2804 676252	PAVEL PAVLOV	{"phone": "+70230346728"}
0005434140311	33D930	9425 903998	ELENA SOROKINA	{"email": "elena_sorokina.011978@postgrespro.ru", "phone": "+70292132971"}
0005434140493	0598B1	5143 751951	YULIYA NAZAROVA	{"phone": "+70726514365"}
0005434140312	42F432	2301 513265	LARISA KUZNECOVA	{"email": "kuznecova.larisa.22111965@postgrespro.ru", "phone": "+70700063531"}
0005434140313	DF8A9E	8827 512422	NATALYA IVANOVA	{"email": "natalyaivanova.041978@postgrespro.ru", "phone": "+70317176173"}
0005434140314	830722	5498 238224	EKATERINA DENISOVA	{"email": "denisova_e_041976@postgrespro.ru", "phone": "+70001934094"}
0005434140315	A6CE5A	3866 259201	NATALYA STEPANOVA	{"email": "n.stepanova-011975@postgrespro.ru", "phone": "+70371250188"}
0005434140316	A6CE5A	7617 455253	NADEZHDA CHERNOVA	{"phone": "+70904474583"}
0005434140317	265CB5	8452 296569	TATYANA KUZNECOVA	{"email": "tkuznecova.051952@postgrespro.ru", "phone": "+70896701884"}
0005434140318	577073	0120 298042	ALEKSEY KUZNECOV	{"phone": "+70930710208"}
0005434140319	D5E43D	9038 832311	OLEG BORISOV	{"email": "o.borisov051974@postgrespro.ru", "phone": "+70648104911"}
0005434140320	495D3B	2000 519645	EVGENIY BONDARENKO	{"phone": "+70637672078"}
0005434140321	074337	9572 001393	KONSTANTIN NIKOLAEV	{"email": "k-nikolaev_19061967@postgrespro.ru", "phone": "+70047264455"}
0005434140322	0D30F2	2900 936976	MARGARITA OVCHINNIKOVA	{"email": "ovchinnikova.m1980@postgrespro.ru", "phone": "+70230339275"}
0005434140323	A3B8A9	6121 256311	IGOR PETROV	{"email": "i-petrov-1964@postgrespro.ru", "phone": "+70293677991"}
0005434140324	A51DF0	3596 132581	ALEKSEY ILIN	{"phone": "+70849360725"}
0005434140325	A51DF0	3661 769060	ANNA LOGINOVA	{"phone": "+70880779607"}
0005434140326	2F1B87	6216 897742	DANIIL SCHERBAKOV	{"email": "scherbakov_daniil.1974@postgrespro.ru", "phone": "+70501172956"}
0005434140327	2F1B87	6971 321848	RUSLAN NAZAROV	{"phone": "+70175607230"}
0005434140328	FE0F46	3554 181708	MARGARITA IVANOVA	{"email": "ivanova_margarita_1976@postgrespro.ru", "phone": "+70548391544"}
0005434140329	FA97BC	5688 397277	TATYANA LOGINOVA	{"email": "t-loginova.25111972@postgrespro.ru", "phone": "+70752215480"}
0005434140330	FA97BC	8947 338198	GEORGIY VOLKOV	{"email": "georgiy.volkov01041979@postgrespro.ru", "phone": "+70394321850"}
0005434140331	5E275A	5716 603796	NATALYA NESTEROVA	{"email": "nesterova.natalya-091969@postgrespro.ru", "phone": "+70263797500"}
0005434140332	5E275A	2477 393700	VASILIY VASILEV	{"phone": "+70508515428"}
0005434140333	971739	2251 746527	DMITRIY FEDOROV	{"email": "fedorov-dmitriy_101965@postgrespro.ru", "phone": "+70351818303"}
0005434140334	16AA0A	5320 890715	VLADIMIR KONOVALOV	{"phone": "+70043990108"}
0005434140335	F0F18D	8091 430384	ANASTASIYA ILINA	{"email": "a_ilina031961@postgrespro.ru", "phone": "+70458380492"}
0005434140336	2C39BF	4984 324683	MARINA ALEKSEEVA	{"phone": "+70798520409"}
0005434140337	2C39BF	3946 196520	VYACHESLAV KONOVALOV	{"email": "konovalov.vyacheslav1973@postgrespro.ru", "phone": "+70896767233"}
0005434140338	2C39BF	2863 737507	ANATOLIY KUZNECOV	{"phone": "+70127782617"}
0005434140339	2C39BF	2901 520228	ALEKSEY IVANOV	{"email": "ivanovaleksey-01061972@postgrespro.ru", "phone": "+70267282321"}
0005434140340	70AC07	3235 246545	LYUDMILA AFANASEVA	{"phone": "+70504315694"}
0005434140341	70AC07	3468 078139	ANDREY ZHUKOV	{"phone": "+70177024985"}
0005434140342	053F5B	7772 614767	GALINA PAVLOVA	{"phone": "+70796009905"}
0005434140343	2DB1B5	0890 261620	ALEKSANDR BORISOV	{"email": "borisov.a.1973@postgrespro.ru", "phone": "+70934611738"}
0005434140344	2DB1B5	1219 406832	EVGENIY KOZLOV	{"phone": "+70248827917"}
0005434140345	EB0ABD	9063 374631	VALENTINA NIKOLAEVA	{"phone": "+70763006639"}
0005434140346	8229AF	1137 507495	NIKOLAY ROMANOV	{"email": "nikolay.romanov_05121970@postgrespro.ru", "phone": "+70425692776"}
0005434140347	B2AAAF	8705 755905	SVETLANA STEPANOVA	{"email": "sstepanova11101967@postgrespro.ru", "phone": "+70636789275"}
0005434140348	3FE541	3758 896089	SVETLANA SEMENOVA	{"phone": "+70781437923"}
0005434140349	3FE541	4020 710248	ALEKSANDRA KUDRYASHOVA	{"phone": "+70588327311"}
0005434140350	5FD47B	6248 388004	TATYANA ANISIMOVA	{"phone": "+70646285117"}
0005434140351	D1D2B4	2479 554473	VALENTINA ANISIMOVA	{"phone": "+70175105634"}
0005434140352	D1D2B4	1144 058524	DENIS GUSEV	{"phone": "+70658390787"}
0005434140353	1F27FF	7063 626639	SERGEY ALEKSANDROV	{"phone": "+70004947767"}
0005434140354	8D5D70	0299 792222	VALERIY CHERNOV	{"phone": "+70386215333"}
0005434140355	8D5D70	0271 159104	OLEG IVANOV	{"email": "oivanov_1971@postgrespro.ru", "phone": "+70604477566"}
0005434140356	C6AE42	6714 884730	ALEKSANDR STEPANOV	{"phone": "+70095797118"}
0005434140357	7B6C4F	1927 640022	STEPAN ISAEV	{"email": "isaevs021979@postgrespro.ru", "phone": "+70485041229"}
0005434140358	7B6C4F	5702 979211	TAMARA KULIKOVA	{"phone": "+70278630038"}
0005434140359	0B31D7	1533 372479	ELENA KUZNECOVA	{"email": "kuznecova-e1979@postgrespro.ru", "phone": "+70506061919"}
0005434140360	0B31D7	9906 385700	VERA FILIPPOVA	{"email": "v_filippova.091976@postgrespro.ru", "phone": "+70942548307"}
0005434140361	202470	6661 818718	DMITRIY SCHERBAKOV	{"phone": "+70661196965"}
0005434140362	202470	5140 029142	EKATERINA MIKHAYLOVA	{"email": "e-mikhaylova-07021972@postgrespro.ru", "phone": "+70832557347"}
0005434140363	0F19A6	4970 364264	VALENTINA GAVRILOVA	{"phone": "+70659490264"}
0005434140364	0F19A6	9860 524831	GENNADIY VASILEV	{"phone": "+70175519448"}
0005434140365	0F19A6	3674 652274	ALENA GUSEVA	{"email": "a_guseva051969@postgrespro.ru", "phone": "+70851189013"}
0005434140366	703DBB	7950 922608	DENIS SEMENOV	{"phone": "+70238082609"}
0005434140367	38621A	9905 933879	DMITRIY FROLOV	{"email": "d-frolov_121962@postgrespro.ru", "phone": "+70632648460"}
0005434140368	1680A2	6257 811237	PELAGEYA KARPOVA	{"phone": "+70148004455"}
0005434140369	5B4719	0712 474820	ROMAN IVANOV	{"phone": "+70898297231"}
0005434140370	5B4719	8236 671449	ALEKSEY SOLOVEV	{"phone": "+70130719529"}
0005434140371	EFDEAE	1303 151762	SVETLANA ABRAMOVA	{"email": "abramova_svetlana_31121974@postgrespro.ru", "phone": "+70528271350"}
0005434142702	FD72BD	1635 703200	NIKOLAY MAKAROV	{"phone": "+70051194988"}
0005434140372	C6232B	5137 742136	ALEKSEY OSIPOV	{"email": "osipov_aleksey.1965@postgrespro.ru", "phone": "+70014236883"}
0005434140373	C6232B	1481 295674	VYACHESLAV KULIKOV	{"phone": "+70168346286"}
0005434140374	F13FD2	8518 861163	DENIS ZHURAVLEV	{"phone": "+70458175513"}
0005434140375	548801	3050 010095	ANATOLIY KUZNECOV	{"email": "anatoliy.kuznecov_20071972@postgrespro.ru", "phone": "+70455718312"}
0005434140376	81A779	6692 303931	SVETLANA LAZAREVA	{"email": "lazareva_s.1971@postgrespro.ru", "phone": "+70782377912"}
0005434140377	81A779	8824 226304	ALEKSEY KRASNOV	{"phone": "+70921856549"}
0005434140378	81A779	8424 358946	LYUBOV KRASNOVA	{"email": "krasnovalyubov.081983@postgrespro.ru", "phone": "+70050707565"}
0005434140379	4836DA	7364 889988	GEORGIY PAVLOV	{"phone": "+70703854943"}
0005434140380	9E2937	4048 538342	VERONIKA MELNIKOVA	{"email": "melnikova.veronika-10111976@postgrespro.ru", "phone": "+70171486480"}
0005434140381	9E2937	8860 970268	TAMARA NIKOLAEVA	{"email": "t-nikolaeva19091974@postgrespro.ru", "phone": "+70152624291"}
0005434140382	7E4176	7873 423047	LYUBOV RODIONOVA	{"phone": "+70497677579"}
0005434140383	7E4176	1116 837373	MARIYA EGOROVA	{"email": "mariyaegorova1966@postgrespro.ru", "phone": "+70029305924"}
0005434140384	CFD1BC	2096 149646	IVAN SHEVCHENKO	{"email": "shevchenko.ivan_021987@postgrespro.ru", "phone": "+70802324883"}
0005434140385	E65848	2431 373528	TATYANA MATVEEVA	{"email": "tatyana.matveeva_091978@postgrespro.ru", "phone": "+70269692015"}
0005434140386	F84B40	8118 635693	ELVIRA ZAYCEVA	{"phone": "+70428625182"}
0005434140387	59868A	0550 160679	VLADIMIR FILIPPOV	{"phone": "+70723462039"}
0005434140388	845675	5436 594962	GALINA SEMENOVA	{"phone": "+70069395710"}
0005434140389	178B99	0418 862882	ELENA NESTEROVA	{"email": "nesterovae.081970@postgrespro.ru", "phone": "+70053441465"}
0005434140390	93F24D	5941 711740	NATALYA IVANOVA	{"phone": "+70383590004"}
0005434140391	ADC163	3073 700406	BORIS GRIGOREV	{"phone": "+70983673952"}
0005434140392	63617B	7521 404498	ILYA ANDREEV	{"phone": "+70470282858"}
0005434140393	BBC6FB	7118 758721	ALEKSANDR IVANOV	{"email": "a.ivanov071979@postgrespro.ru", "phone": "+70579175979"}
0005434140394	6FC2A5	5618 851894	IRINA BELOVA	{"phone": "+70091304144"}
0005434140395	6FC2A5	2634 648244	ALEKSANDR TIKHONOV	{"phone": "+70934769401"}
0005434140396	E103D9	3241 777048	ELIZAVETA KOZLOVA	{"email": "e-kozlova071965@postgrespro.ru", "phone": "+70314837563"}
0005434140397	E103D9	2922 906732	LYUDMILA VASILEVA	{"email": "vasileva-l.28101969@postgrespro.ru", "phone": "+70965802874"}
0005434140398	34257D	6460 863187	IVAN KOROLEV	{"phone": "+70537425177"}
0005434140399	519BE2	3598 898333	RAISA FOMINA	{"email": "rfomina1976@postgrespro.ru", "phone": "+70461776783"}
0005434140400	519BE2	0564 852582	VLADIMIR SCHERBAKOV	{"phone": "+70109354667"}
0005434140401	BDB36F	6725 783112	OLGA SCHERBAKOVA	{"email": "scherbakova.olga.051969@postgrespro.ru", "phone": "+70626152432"}
0005434140402	E298D1	5102 468945	PAVEL OSIPOV	{"email": "posipov-031964@postgrespro.ru", "phone": "+70533566737"}
0005434140403	35746C	6932 581145	VALENTIN SMIRNOV	{"email": "vsmirnov_29031981@postgrespro.ru", "phone": "+70339244621"}
0005434140404	402E17	4301 859517	ELENA KUZNECOVA	{"email": "kuznecovaelena_011977@postgrespro.ru", "phone": "+70444397899"}
0005434140405	81F6E3	6507 939193	DARYA MALYSHEVA	{"phone": "+70029415311"}
0005434140406	5E5C29	5756 588055	NINA MIKHAYLOVA	{"phone": "+70625621221"}
0005434140407	5E5C29	4476 189811	NINA SAVELEVA	{"phone": "+70941994451"}
0005434140408	88B283	8122 417272	IVAN VLASOV	{"phone": "+70299753579"}
0005434140409	253876	6543 407655	SERGEY FROLOV	{"email": "frolov.s-1983@postgrespro.ru", "phone": "+70388553107"}
0005434140410	253876	1102 534675	ELENA IVANOVA	{"email": "elena-ivanova14031977@postgrespro.ru", "phone": "+70613501013"}
0005434140411	752CF3	0468 606765	SVETLANA MARTYNOVA	{"phone": "+70951022660"}
0005434140412	E95872	7157 685947	OLGA POPOVA	{"phone": "+70342831983"}
0005434140413	4A9AEB	6683 009513	VLADIMIR ZAKHAROV	{"phone": "+70270526286"}
0005434140414	31160F	7911 245846	NIKOLAY FOMIN	{"phone": "+70736956788"}
0005434140415	78822B	4654 763053	NATALYA VOLKOVA	{"phone": "+70605127038"}
0005434140416	14E463	5564 177525	MARIYA DENISOVA	{"email": "denisova-mariya_081962@postgrespro.ru", "phone": "+70062702228"}
0005434140417	CB2B62	5322 763912	ANATOLIY ORLOV	{"phone": "+70442663461"}
0005434140418	F21BFA	4031 795631	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev_1978@postgrespro.ru", "phone": "+70785433872"}
0005434140419	F21BFA	0258 034827	TATYANA FEDOROVA	{"email": "fedorovatatyana_1966@postgrespro.ru", "phone": "+70949359583"}
0005434140420	0BFED9	5104 344459	NIKOLAY VOLKOV	{"email": "volkov.nikolay-071982@postgrespro.ru", "phone": "+70190429517"}
0005434140421	8485AF	5557 355668	SABINA YAKOVLEVA	{"email": "yakovleva.sabina_10061969@postgrespro.ru", "phone": "+70970444977"}
0005434140422	D6F18A	2010 687468	OLEG MAKAROV	{"phone": "+70698489791"}
0005434140423	0362ED	7325 770802	ALEKSEY VOLKOV	{"phone": "+70247495685"}
0005434140424	ED0F4B	4508 592113	OLESYA ILINA	{"phone": "+70588059296"}
0005434140425	9119EC	6253 837077	ALEKSANDR KUZNECOV	{"phone": "+70611658214"}
0005434140426	71CE46	9267 898240	EKATERINA NESTEROVA	{"email": "enesterova-15031972@postgrespro.ru", "phone": "+70167335386"}
0005434140427	71CE46	1466 792654	ALEKSEY POPOV	{"email": "aleksey-popov-041971@postgrespro.ru", "phone": "+70028391483"}
0005434140540	E90533	5465 518001	YURIY GUSEV	{"phone": "+70171374848"}
0005434140428	55D4C1	0859 412274	ANGELINA KOROLEVA	{"email": "koroleva_a031973@postgrespro.ru", "phone": "+70506714915"}
0005434140429	55D4C1	3436 881896	POLINA KOZLOVA	{"email": "polinakozlova11021985@postgrespro.ru", "phone": "+70878582122"}
0005434140430	3A406D	1521 401607	VERA MOROZOVA	{"email": "morozovavera_1965@postgrespro.ru", "phone": "+70703812814"}
0005434149571	90EE50	2353 334840	VYACHESLAV SAVELEV	{"phone": "+70954983718"}
0005434140431	1510A9	4656 540492	EVGENIY ROMANOV	{"email": "romanove-1965@postgrespro.ru", "phone": "+70798731123"}
0005434140432	1510A9	6995 875948	MARGARITA ORLOVA	{"email": "margarita_orlova.1974@postgrespro.ru", "phone": "+70562610356"}
0005434140433	2BFB8A	6452 978947	GALINA ZOTOVA	{"email": "g.zotova.1967@postgrespro.ru", "phone": "+70040839291"}
0005434140434	D77A38	6279 727900	NIKITA MIRONOV	{"phone": "+70027744755"}
0005434140435	D77A38	0089 382397	ALEKSANDR KUZMIN	{"phone": "+70209613644"}
0005434140436	D91F7F	9892 958368	VLADIMIR OSIPOV	{"email": "osipov.v.011970@postgrespro.ru", "phone": "+70835097440"}
0005434140437	D91F7F	9315 166630	NIKOLAY FEDOROV	{"phone": "+70602516919"}
0005434140438	5BD918	1869 383111	GALINA SMIRNOVA	{"phone": "+70717504784"}
0005434140439	5BD918	1511 074741	MARIYA NESTEROVA	{"phone": "+70417128509"}
0005434140440	C3838B	0017 001760	TAMARA SMIRNOVA	{"phone": "+70078903569"}
0005434140441	C3838B	4226 526365	EVGENIYA NIKIFOROVA	{"email": "nikiforovae-061973@postgrespro.ru", "phone": "+70013742889"}
0005434140442	8DEC7D	5843 886699	OLGA ORLOVA	{"email": "orlova.o111956@postgrespro.ru", "phone": "+70132960123"}
0005434140443	2E9AB2	5243 850898	ALEKSANDRA NAUMOVA	{"email": "aleksandra-naumova-011981@postgrespro.ru", "phone": "+70422810896"}
0005434140444	0C03C4	4563 158948	LYUBOV GRISHINA	{"email": "lyubov.grishina-1968@postgrespro.ru", "phone": "+70574911985"}
0005434140445	0B6DA9	7333 802557	VALENTINA ILINA	{"phone": "+70271520252"}
0005434140446	FF1E72	6697 077863	ELENA SAVELEVA	{"email": "elenasaveleva-1973@postgrespro.ru", "phone": "+70802101231"}
0005434140447	FF1E72	4874 738640	SVETLANA GERASIMOVA	{"email": "svetlana-gerasimova.1975@postgrespro.ru", "phone": "+70610352107"}
0005434140448	D02363	9658 940649	LIDIYA KUDRYASHOVA	{"phone": "+70288822791"}
0005434140449	38FBFC	1478 546219	ARINA SERGEEVA	{"email": "asergeeva-011974@postgrespro.ru", "phone": "+70801073412"}
0005434140450	38FBFC	5980 281542	TATYANA MATVEEVA	{"phone": "+70391014380"}
0005434140451	EF0498	6638 341045	VERA SOROKINA	{"phone": "+70684877959"}
0005434140452	857826	3369 787125	DMITRIY ROMANOV	{"phone": "+70404148157"}
0005434140453	5D0BCA	3536 113396	YULIYA SCHERBAKOVA	{"email": "yscherbakova1966@postgrespro.ru", "phone": "+70517921034"}
0005434140454	D78D72	2510 567574	LYUDMILA ANDREEVA	{"phone": "+70723200350"}
0005434140455	137E6F	8684 298218	YURIY CHERNOV	{"email": "y.chernov1964@postgrespro.ru", "phone": "+70046839433"}
0005434140456	C57E8A	4614 996645	ALEKSANDR POPOV	{"email": "a.popov.1962@postgrespro.ru", "phone": "+70233381972"}
0005434140457	26B1C6	7075 473027	ALEKSEY OSIPOV	{"email": "alekseyosipov.19031963@postgrespro.ru", "phone": "+70275837414"}
0005434140458	C3787B	4767 060463	ALEKSANDR CHERNOV	{"email": "a-chernov.19091966@postgrespro.ru", "phone": "+70993801526"}
0005434140459	CC6F64	3384 776421	DMITRIY NIKOLAEV	{"phone": "+70068756272"}
0005434140460	B9680F	8138 542953	LYUDMILA CHERNOVA	{"email": "l_chernova.06121970@postgrespro.ru", "phone": "+70885673108"}
0005434140461	E6FE8C	3345 247664	ELENA ORLOVA	{"phone": "+70589406219"}
0005434140462	1B15DF	2288 901163	NADEZHDA BELYAEVA	{"email": "belyaeva-n_1973@postgrespro.ru", "phone": "+70760104972"}
0005434140463	3CC731	1708 759842	YURIY SMIRNOV	{"phone": "+70465189756"}
0005434140464	9AC873	9121 348774	NATALYA SOROKINA	{"phone": "+70938896743"}
0005434140465	B22A33	6417 131743	ELENA KALININA	{"email": "elena-kalinina_1985@postgrespro.ru", "phone": "+70800387239"}
0005434140466	B22A33	6593 171319	LILIYA PAVLOVA	{"phone": "+70575095359"}
0005434140467	0FFB81	3225 921246	SERGEY BARANOV	{"email": "baranovs-23121966@postgrespro.ru", "phone": "+70901943063"}
0005434140468	0FFB81	2562 675064	LYUDMILA SMIRNOVA	{"phone": "+70011270290"}
0005434140469	2AE93B	2847 792989	EKATERINA BELYAEVA	{"phone": "+70473898884"}
0005434140470	9F7F1D	6834 746608	ANNA LUKYANOVA	{"phone": "+70893078919"}
0005434140471	531E7E	7485 887577	DMITRIY FEDOROV	{"email": "fedorov.dmitriy_051971@postgrespro.ru", "phone": "+70636198001"}
0005434140472	B3BDE6	8386 805547	ELENA ROMANOVA	{"email": "elena.romanova_081973@postgrespro.ru", "phone": "+70772729780"}
0005434140473	E45952	7550 629730	KIRILL MAKAROV	{"phone": "+70338833865"}
0005434140474	92BA81	6523 950454	ANASTASIYA ANDREEVA	{"email": "andreevaa.021973@postgrespro.ru", "phone": "+70258677437"}
0005434140475	8CFD16	3898 259224	MARIYA TIMOFEEVA	{"email": "mariya.timofeeva.1966@postgrespro.ru", "phone": "+70540964456"}
0005434140476	8CFD16	6277 782918	ANASTASIYA ANDREEVA	{"email": "andreeva-a.061976@postgrespro.ru", "phone": "+70136622907"}
0005434140477	F713B5	5293 763403	MARIYA KRASNOVA	{"phone": "+70371486048"}
0005434140478	4A0A98	3846 598235	ELENA KALININA	{"email": "e_kalinina_08121968@postgrespro.ru", "phone": "+70229201707"}
0005434140479	DC563A	5973 857879	KHALIDA SMIRNOVA	{"phone": "+70631723604"}
0005434140480	DC563A	5609 115549	GULFIYA ABRAMOVA	{"phone": "+70190487179"}
0005434140481	FA6AAB	0254 388339	ALEKSANDR YAKOVLEV	{"phone": "+70353997176"}
0005434140482	04B960	7636 346950	RAISA MOROZOVA	{"phone": "+70119757064"}
0005434140483	94A141	4061 130424	GALINA KOROLEVA	{"phone": "+70568388152"}
0005434140484	5920A3	1559 196937	OLGA ANDREEVA	{"email": "andreeva_olga.1976@postgrespro.ru", "phone": "+70578457948"}
0005434140485	4AC26E	7557 616212	ALEKSANDR ZHUKOV	{"phone": "+70251824174"}
0005434140486	179AC0	2792 349458	EVGENIY MAKAROV	{"phone": "+70179430685"}
0005434140487	8A56F2	5200 148193	EKATERINA MIRONOVA	{"phone": "+70575527670"}
0005434140488	AFE869	9401 482121	IVAN ILIN	{"email": "ivan.ilin081964@postgrespro.ru", "phone": "+70731772209"}
0005434140489	65BC2F	1179 847669	NATALYA FEDOROVA	{"phone": "+70359362210"}
0005434140490	E9DB7A	0982 051699	VASILIY SMIRNOV	{"email": "vasiliysmirnov-1974@postgrespro.ru", "phone": "+70728182241"}
0005434140491	9F0515	6591 032577	ALEKSANDR FROLOV	{"phone": "+70888172890"}
0005434140492	9F0515	6009 743082	IVAN GRIGOREV	{"phone": "+70080843337"}
0005434140494	EAC704	8956 357792	DARYA EFIMOVA	{"email": "darya.efimova061963@postgrespro.ru", "phone": "+70691297255"}
0005434140495	74EA99	3860 679115	YULIYA POPOVA	{"phone": "+70506598865"}
0005434140496	74EA99	1391 377837	YULIYA MAKAROVA	{"phone": "+70294527665"}
0005434140497	74EA99	8906 229568	IVAN EGOROV	{"email": "egorov-i_17071969@postgrespro.ru", "phone": "+70169791236"}
0005434140498	5EEC67	9115 587251	TATYANA NAZAROVA	{"email": "tnazarova.06061964@postgrespro.ru", "phone": "+70691191165"}
0005434140499	5EEC67	4170 166002	OLGA MARTYNOVA	{"phone": "+70407596412"}
0005434140500	4883D3	9489 436990	ALEKSEY ZHUKOV	{"phone": "+70162509902"}
0005434140501	476FF3	4462 551710	YULIYA KUZMINA	{"email": "y-kuzmina-1960@postgrespro.ru", "phone": "+70757501877"}
0005434140502	A339B6	7483 873071	ELENA MAKSIMOVA	{"phone": "+70076932384"}
0005434140503	8BE37A	6069 183481	SERGEY MELNIKOV	{"email": "s-melnikov_091979@postgrespro.ru", "phone": "+70842823799"}
0005434140504	33F4AD	3566 852958	TATYANA FADEEVA	{"email": "tfadeeva-1967@postgrespro.ru", "phone": "+70604533720"}
0005434140505	33F4AD	4941 917659	RAMIL KISELEV	{"email": "ramil_kiselev.1972@postgrespro.ru", "phone": "+70318959395"}
0005434140506	A5AA95	4678 002124	SVETLANA STEPANOVA	{"email": "s_stepanova041981@postgrespro.ru", "phone": "+70070425041"}
0005434140507	205F60	5472 865947	OLGA NAZAROVA	{"email": "onazarova.091965@postgrespro.ru", "phone": "+70281097497"}
0005434140508	205F60	8256 779748	VALENTIN PAVLOV	{"email": "pavlov-valentin-1977@postgrespro.ru", "phone": "+70971924820"}
0005434140509	EDB78D	5092 646857	NINA EGOROVA	{"email": "ninaegorova_21091971@postgrespro.ru", "phone": "+70278258019"}
0005434140510	B3CC29	5617 960557	EKATERINA NAUMOVA	{"email": "ekaterinanaumova111972@postgrespro.ru", "phone": "+70707257756"}
0005434140511	A73389	7878 008310	TAGIR IVANOV	{"phone": "+70492860169"}
0005434140512	C791D3	1694 478712	KIRILL PAVLOV	{"phone": "+70467903514"}
0005434140513	B72DBA	8099 185112	SERGEY MEDVEDEV	{"phone": "+70598023899"}
0005434140514	B72DBA	8741 281939	ANASTASIYA VASILEVA	{"email": "anastasiya-vasileva-031971@postgrespro.ru", "phone": "+70342035216"}
0005434140515	5C6DC6	4562 209515	ALEKSEY ROMANOV	{"phone": "+70066875109"}
0005434140516	5C6DC6	0863 583797	ANTONINA KUZMINA	{"email": "a.kuzmina.1974@postgrespro.ru", "phone": "+70526705908"}
0005434140517	E30A4B	5058 059897	ANNA NIKOLAEVA	{"email": "nikolaevaanna_17101970@postgrespro.ru", "phone": "+70474067075"}
0005434140518	E30A4B	0499 748567	IVAN MELNIKOV	{"phone": "+70665019900"}
0005434140519	6AE04C	2234 612828	RAISA NIKOLAEVA	{"email": "r_nikolaeva_1968@postgrespro.ru", "phone": "+70393396420"}
0005434140520	6AE04C	5366 629079	NADEZHDA POLYAKOVA	{"email": "polyakovan111974@postgrespro.ru", "phone": "+70164351989"}
0005434140521	686B95	9686 877171	RAISA POPOVA	{"phone": "+70780737560"}
0005434140522	EA301B	1420 649467	DARYA BORISOVA	{"phone": "+70524742612"}
0005434140523	BDBF3C	7175 607143	IRINA KARPOVA	{"phone": "+70945207458"}
0005434140524	0391B7	7394 004585	IRINA STEPANOVA	{"email": "stepanovairina.121969@postgrespro.ru", "phone": "+70034468243"}
0005434140525	0391B7	5621 155077	RAISA KONOVALOVA	{"phone": "+70887715126"}
0005434140526	0391B7	1741 480925	VIKTOR MOROZOV	{"email": "morozovv1974@postgrespro.ru", "phone": "+70379952859"}
0005434140527	A09390	8003 536701	ARTUR TIMOFEEV	{"phone": "+70979598525"}
0005434140528	C7316A	8235 096950	VIKTORIYA EGOROVA	{"email": "v_egorova.101966@postgrespro.ru", "phone": "+70925856072"}
0005434140529	C7316A	6308 660441	POLINA SEMENOVA	{"email": "semenova.polina.10121969@postgrespro.ru", "phone": "+70069662796"}
0005434140530	75F7AE	5055 147152	MARINA POPOVA	{"email": "marina.popova1959@postgrespro.ru", "phone": "+70322502351"}
0005434140531	DE412E	3734 655260	TATYANA TIKHONOVA	{"phone": "+70020519202"}
0005434140532	DE412E	8474 401331	ANASTASIYA VOLKOVA	{"email": "volkova-anastasiya.111969@postgrespro.ru", "phone": "+70480143816"}
0005434140533	AFC56F	5188 301981	IGOR ZAYCEV	{"email": "zaycev.igor_1984@postgrespro.ru", "phone": "+70895555362"}
0005434140534	AFC56F	1639 861624	MARINA NAUMOVA	{"email": "m-naumova_1962@postgrespro.ru", "phone": "+70018063491"}
0005434140535	AC6505	9835 180789	LARISA GORBUNOVA	{"email": "l.gorbunova.1958@postgrespro.ru", "phone": "+70661229449"}
0005434140536	051FDD	4801 978693	NIKOLAY SMIRNOV	{"email": "n-smirnov061975@postgrespro.ru", "phone": "+70816948440"}
0005434140537	23C478	7471 979675	RUSTAM FEDOROV	{"phone": "+70997148926"}
0005434140538	23C478	1395 364436	IRINA FILIPPOVA	{"email": "filippova_irina_1969@postgrespro.ru", "phone": "+70693472912"}
0005434140539	23C478	8796 355015	SOFYA EGOROVA	{"phone": "+70736571879"}
0005434140541	CDC256	3704 950067	OLEG IVANOV	{"phone": "+70414696560"}
0005434140542	C4969E	3707 490570	ZOYA TITOVA	{"phone": "+70839833754"}
0005434140543	C4969E	8177 025114	VALENTINA GERASIMOVA	{"email": "gerasimova.valentina101962@postgrespro.ru", "phone": "+70202935669"}
0005434140544	C26B4C	1747 267847	GRIGORIY KARPOV	{"email": "gkarpov1983@postgrespro.ru", "phone": "+70252615238"}
0005434140545	8B5EEF	8568 226829	ALENA EGOROVA	{"email": "alena_egorova.1978@postgrespro.ru", "phone": "+70034511206"}
0005434140546	F8A5CA	9605 179856	ROMAN KUZMIN	{"email": "kuzmin-r.1974@postgrespro.ru", "phone": "+70083585937"}
0005434140547	FE7D93	1724 182013	ALEVTINA FROLOVA	{"email": "alevtina.frolova1970@postgrespro.ru", "phone": "+70321017404"}
0005434140548	FE7D93	0415 205763	DMITRIY KUZMIN	{"email": "kuzmin_d.011978@postgrespro.ru", "phone": "+70247149910"}
0005434140549	8B6607	0367 978689	GALINA KUZNECOVA	{"phone": "+70809660513"}
0005434140550	8D339D	9319 450569	MIKHAIL DENISOV	{"email": "mdenisov-081977@postgrespro.ru", "phone": "+70892558417"}
0005434140551	8D339D	8940 307053	ANTON FEDOTOV	{"email": "a.fedotov04011984@postgrespro.ru", "phone": "+70223096988"}
0005434140552	973845	9888 503495	IVAN KOZLOV	{"email": "ivan_kozlov.1981@postgrespro.ru", "phone": "+70799225507"}
0005434140553	7BAE25	1787 507529	ARTEM ILIN	{"phone": "+70833762866"}
0005434140554	433E2D	8203 599878	LYUDMILA KONDRATEVA	{"email": "lyudmila.kondrateva-121963@postgrespro.ru", "phone": "+70673423512"}
0005434140555	433E2D	4661 018980	TATYANA KARPOVA	{"phone": "+70695962822"}
0005434140556	918E4A	2535 629054	VLADIMIR ZHURAVLEV	{"phone": "+70372400856"}
0005434140557	086EFA	5922 827824	YANA PETROVA	{"phone": "+70484209759"}
0005434140558	724C22	6714 246861	DANIIL ALEKSANDROV	{"phone": "+70787936682"}
0005434140559	EFF3B7	0779 763634	NAILYA POPOVA	{"phone": "+70663513934"}
0005434140560	B58931	2076 626450	ANATOLIY BORISOV	{"phone": "+70524701731"}
0005434140561	B58931	2431 360724	OKSANA ZHURAVLEVA	{"email": "ozhuravleva.1963@postgrespro.ru", "phone": "+70313245232"}
0005434140562	827CF4	3836 280669	MARINA BARANOVA	{"phone": "+70438876579"}
0005434140563	A6BA8E	4700 084067	VERA ZHURAVLEVA	{"phone": "+70855076671"}
0005434140564	8CAD5F	4755 786246	TATYANA BORISOVA	{"email": "tatyana-borisova29091972@postgrespro.ru", "phone": "+70963207759"}
0005434140565	F0977C	7788 906654	MATVEY ZAYCEV	{"email": "zaycev-matvey.19031981@postgrespro.ru", "phone": "+70478069660"}
0005434140566	121F50	3712 168012	ELENA ZAYCEVA	{"phone": "+70593513118"}
0005434140567	7C7935	9145 398563	SVETLANA PAVLOVA	{"phone": "+70863913906"}
0005434140568	52EF08	6749 373495	SERGEY SAVELEV	{"phone": "+70534247068"}
0005434140569	52EF08	9950 032138	RIMMA EGOROVA	{"email": "egorovar_1954@postgrespro.ru", "phone": "+70764339547"}
0005434140570	BC0205	0484 794756	SERGEY SIDOROV	{"email": "s.sidorov111982@postgrespro.ru", "phone": "+70370377117"}
0005434140571	DFFF43	1852 390952	VALENTINA TIMOFEEVA	{"email": "timofeevav_17011981@postgrespro.ru", "phone": "+70627176373"}
0005434140572	DFFF43	4135 061500	ARINA KONOVALOVA	{"email": "konovalova-a.19061969@postgrespro.ru", "phone": "+70014440673"}
0005434140573	D55ACD	1280 169624	GENNADIY OSIPOV	{"email": "gennadiy.osipov_1970@postgrespro.ru", "phone": "+70988395068"}
0005434140574	D55ACD	9134 772355	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev031978@postgrespro.ru", "phone": "+70880645042"}
0005434140575	71072A	1061 182605	GRIGORIY TIKHONOV	{"phone": "+70079900674"}
0005434140576	71072A	7657 557269	SERGEY DMITRIEV	{"phone": "+70913992357"}
0005434140577	71072A	0040 802995	MARGARITA LEBEDEVA	{"email": "margaritalebedeva21121974@postgrespro.ru", "phone": "+70254706760"}
0005434140578	99CD32	8938 553511	NADEZHDA TITOVA	{"phone": "+70151379216"}
0005434140579	B1ADD9	6242 259674	DMITRIY SIDOROV	{"phone": "+70040326782"}
0005434140580	B1ADD9	1296 692493	VALENTINA ISAEVA	{"phone": "+70855991064"}
0005434140581	F82F89	8853 135386	BORIS FILIPPOV	{"email": "bfilippov24051967@postgrespro.ru", "phone": "+70089935536"}
0005434140582	F82F89	1973 591073	OKSANA MAKSIMOVA	{"email": "maksimovao-18011968@postgrespro.ru", "phone": "+70313356298"}
0005434140583	F82F89	7566 174891	MAKSIM SEMENOV	{"phone": "+70284309912"}
0005434140584	775220	4432 158685	TATYANA ANISIMOVA	{"phone": "+70109105787"}
0005434140585	775220	4589 569610	IRINA VASILEVA	{"email": "i_vasileva02081973@postgrespro.ru", "phone": "+70785553498"}
0005434140586	EEB9F4	7208 556468	VALERIY FEDOROV	{"phone": "+70644705335"}
0005434140587	2048AB	2099 426419	ELENA GORBUNOVA	{"phone": "+70877514378"}
0005434140588	0F4CDB	4292 860235	LIDIYA ROMANOVA	{"email": "lidiya.romanova011968@postgrespro.ru", "phone": "+70211235835"}
0005434140589	3BD3C0	3046 652133	SERGEY KUZNECOV	{"email": "s.kuznecov.121973@postgrespro.ru", "phone": "+70456668474"}
0005434140590	7C192E	4609 748541	NINA POPOVA	{"email": "popova_nina_031975@postgrespro.ru", "phone": "+70261886732"}
0005434140591	6519A4	0319 079409	OLGA TARASOVA	{"email": "olga-tarasova-1971@postgrespro.ru", "phone": "+70785880056"}
0005434140592	6519A4	9863 852312	ANASTASIYA SEMENOVA	{"phone": "+70396733434"}
0005434140593	44F09F	7616 947109	ALINA PETROVA	{"email": "alinapetrova_1974@postgrespro.ru", "phone": "+70706874914"}
0005434140594	AF30B4	9420 292268	ELENA SOKOLOVA	{"email": "e_sokolova_1975@postgrespro.ru", "phone": "+70811672197"}
0005434140595	AF30B4	0685 707279	NATALYA VOROBEVA	{"email": "n-vorobeva1965@postgrespro.ru", "phone": "+70945050461"}
0005434140596	AF30B4	4849 105438	ANATOLIY KULIKOV	{"email": "kulikov_anatoliy_1971@postgrespro.ru", "phone": "+70162091748"}
0005434140597	48F8E6	2953 270812	VLADIMIR EGOROV	{"email": "egorov_v_041968@postgrespro.ru", "phone": "+70207072340"}
0005434140598	48F8E6	5313 859334	OKSANA AFANASEVA	{"email": "afanaseva.oksana101971@postgrespro.ru", "phone": "+70373987650"}
0005434140599	E26452	4075 312959	VALENTINA BORISOVA	{"phone": "+70019442883"}
0005434140600	943C8F	9222 801037	ANTONINA IVANOVA	{"phone": "+70748860335"}
0005434140601	943C8F	9575 373822	VLADIMIR TIMOFEEV	{"email": "v.timofeev031971@postgrespro.ru", "phone": "+70028084801"}
0005434140602	943C8F	0433 995066	SERGEY MAKSIMOV	{"phone": "+70108069570"}
0005434140603	246E5B	6611 557741	EMIL FROLOV	{"phone": "+70740544968"}
0005434140604	AE45D8	3468 287206	DMITRIY MIRONOV	{"phone": "+70210716069"}
0005434140605	AE45D8	2861 175525	SERGEY GORBUNOV	{"phone": "+70448850384"}
0005434140606	179B0C	4560 815788	RAVIL POPOV	{"email": "popovr.17071978@postgrespro.ru", "phone": "+70807005860"}
0005434140607	7862C2	6371 047409	ALEKSANDRA MARTYNOVA	{"email": "martynova_a-1974@postgrespro.ru", "phone": "+70165639469"}
0005434140608	7862C2	3562 169234	TATYANA GAVRILOVA	{"email": "tatyanagavrilova.111975@postgrespro.ru", "phone": "+70147284351"}
0005434140609	EDB93D	5330 526554	VERA DAVYDOVA	{"email": "v.davydova_31011979@postgrespro.ru", "phone": "+70679291566"}
0005434140610	EFFB52	4806 586515	ELENA MATVEEVA	{"email": "matveevae28081965@postgrespro.ru", "phone": "+70792360330"}
0005434140611	E808A8	1767 155514	ELENA RODIONOVA	{"email": "e.rodionova-1971@postgrespro.ru", "phone": "+70625588982"}
0005434140612	7919FF	3806 482952	NATALYA KOZLOVA	{"phone": "+70302593554"}
0005434140613	7919FF	0658 621214	GYUZEL NESTEROVA	{"email": "nesterova_g-08081980@postgrespro.ru", "phone": "+70371423041"}
0005434140614	29BAF2	5127 589754	SVETLANA TARASOVA	{"email": "tarasova-s1974@postgrespro.ru", "phone": "+70521543095"}
0005434140615	0BF367	0271 036729	VLADISLAV PETROV	{"email": "v-petrov_02041968@postgrespro.ru", "phone": "+70975478438"}
0005434140616	B0A0F5	9393 971089	SVYATOSLAV KOZLOV	{"email": "kozlov_svyatoslav_25041969@postgrespro.ru", "phone": "+70455463663"}
0005434140617	B0A0F5	1765 384496	DENIS GRIGOREV	{"email": "grigorev.d1965@postgrespro.ru", "phone": "+70363591652"}
0005434140618	9F246C	6947 685086	ALESYA PAVLOVA	{"email": "pavlova.alesya.091979@postgrespro.ru", "phone": "+70498413738"}
0005434140619	9F246C	3509 306536	VLADIMIR IVANOV	{"email": "ivanov_v_031995@postgrespro.ru", "phone": "+70121324395"}
0005434140620	E07142	3966 975837	GALINA SIDOROVA	{"phone": "+70281051007"}
0005434140621	864B9F	3127 577242	DMITRIY ROMANOV	{"email": "d.romanov.011970@postgrespro.ru", "phone": "+70677033545"}
0005434140622	864B9F	2641 934057	ANDREY ANDREEV	{"phone": "+70500853384"}
0005434140623	69A018	5914 225070	GENNADIY SAVELEV	{"email": "savelevgennadiy.121973@postgrespro.ru", "phone": "+70584491207"}
0005434140624	69A018	5372 326480	RAISA IVANOVA	{"email": "raisa-ivanova111981@postgrespro.ru", "phone": "+70591555820"}
0005434140625	88D10E	9314 136688	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov.1975@postgrespro.ru", "phone": "+70075898895"}
0005434140626	88D10E	8558 487310	YURIY MOROZOV	{"phone": "+70950837571"}
0005434140627	AA6625	5435 037214	MARGARITA GORBUNOVA	{"phone": "+70419137014"}
0005434140628	F497E5	1506 515162	ROMAN GAVRILOV	{"email": "roman.gavrilov_08031965@postgrespro.ru", "phone": "+70260151633"}
0005434142654	A94C29	2553 097607	NADEZHDA POPOVA	{"phone": "+70245866682"}
0005434142655	28F2FF	0699 831297	DMITRIY MIKHAYLOV	{"phone": "+70828656691"}
0005434142540	21DA37	1214 837588	VLADISLAV YAKOVLEV	{"email": "vladislav-yakovlev.1972@postgrespro.ru", "phone": "+70780729899"}
0005434142541	DC37A8	1739 630512	SVETLANA OSIPOVA	{"email": "s-osipova-1973@postgrespro.ru", "phone": "+70115469226"}
0005434142542	DC37A8	5639 705201	LYUDMILA BELOVA	{"email": "belova.l15011978@postgrespro.ru", "phone": "+70096174047"}
0005434142656	28F2FF	3879 999509	TATYANA NOVIKOVA	{"phone": "+70162711259"}
0005434142543	ACD8AA	6696 227702	MIKHAIL SOLOVEV	{"email": "msolovev_1968@postgrespro.ru", "phone": "+70296118460"}
0005434142544	130128	6082 355477	OLGA IVANOVA	{"email": "ivanova_olga-1976@postgrespro.ru", "phone": "+70799376233"}
0005434142545	F6706F	6452 710086	ALSU KOZLOVA	{"email": "kozlovaa_1987@postgrespro.ru", "phone": "+70596738329"}
0005434142546	F6706F	0788 281922	ROMAN KUDRYASHOV	{"email": "r_kudryashov-041975@postgrespro.ru", "phone": "+70956974695"}
0005434142547	E0C39F	3152 036121	TATYANA TITOVA	{"phone": "+70984359360"}
0005434142548	D88447	6331 191122	EVGENIY ANDREEV	{"phone": "+70632551972"}
0005434142549	8CD702	0760 609833	SVETLANA GORBUNOVA	{"phone": "+70093075176"}
0005434142550	6E2D94	1413 473389	OLEG RODIONOV	{"phone": "+70286613055"}
0005434142551	55BC19	0392 349931	ALEKSANDR VASILEV	{"phone": "+70905900983"}
0005434142552	55BC19	1980 274330	DMITRIY MIKHAYLOV	{"email": "dmikhaylov_121970@postgrespro.ru", "phone": "+70256864697"}
0005434142553	55BC19	9170 378045	SERGEY MOROZOV	{"email": "morozovs.011961@postgrespro.ru", "phone": "+70720413980"}
0005434142554	4B6582	2935 734531	ALEKSEY MARTYNOV	{"email": "martynovaleksey25061962@postgrespro.ru", "phone": "+70289116282"}
0005434142555	4B6582	4773 249295	ANDREY VASILEV	{"phone": "+70433939557"}
0005434142556	78E3CB	3267 001142	IGOR TIMOFEEV	{"phone": "+70262278027"}
0005434142557	54139A	0961 316677	EVDOKIYA ORLOVA	{"phone": "+70405198892"}
0005434142558	45EF7D	1242 578445	NATALYA FROLOVA	{"phone": "+70102159733"}
0005434142559	45EF7D	7250 839113	EKATERINA ANTONOVA	{"phone": "+70517545072"}
0005434142560	45EF7D	3936 045021	NIKOLAY NAZAROV	{"email": "nazarovnikolay-20051974@postgrespro.ru", "phone": "+70903479601"}
0005434142561	EF5576	8507 648589	NINA FOMINA	{"email": "nina_fomina-18031979@postgrespro.ru", "phone": "+70899641732"}
0005434142562	F59A0E	1474 188944	NIKOLAY DAVYDOV	{"phone": "+70488484332"}
0005434142563	F59A0E	9958 595128	MIKHAIL TIKHONOV	{"phone": "+70902904868"}
0005434142564	2F5A24	5110 138444	SERGEY BARANOV	{"phone": "+70616924579"}
0005434142565	B509D1	8320 857862	SVETLANA FROLOVA	{"phone": "+70401589673"}
0005434142566	09C6F9	6010 854418	LYUDMILA BARANOVA	{"email": "lyudmila-baranova.28011960@postgrespro.ru", "phone": "+70605426686"}
0005434142567	7D7166	2593 859761	ANZHELA VOLKOVA	{"email": "anzhela.volkova-1962@postgrespro.ru", "phone": "+70505329320"}
0005434142568	085EF8	9395 473378	EVGENIY BARANOV	{"phone": "+70191294300"}
0005434142569	8E34AB	4206 662007	OLEG TARASOV	{"email": "tarasovoleg_111960@postgrespro.ru", "phone": "+70896274711"}
0005434142570	8E34AB	5315 156023	LARISA SOROKINA	{"email": "lsorokina_27021975@postgrespro.ru", "phone": "+70683613055"}
0005434142571	03C92D	4956 443022	ALEKSANDRA TARASOVA	{"email": "tarasova.aleksandra_26101968@postgrespro.ru", "phone": "+70271943605"}
0005434142572	978320	4221 643922	PETR SCHERBAKOV	{"phone": "+70118328831"}
0005434142573	978320	9859 690180	ANATOLIY VOLKOV	{"phone": "+70187205227"}
0005434142574	2102B4	7917 889596	IVAN ZHURAVLEV	{"email": "zhuravlevi-03051980@postgrespro.ru", "phone": "+70064390094"}
0005434142575	2102B4	5552 454114	NIKOLAY SERGEEV	{"email": "nikolay_sergeev.10011967@postgrespro.ru", "phone": "+70763900006"}
0005434142576	DD7FEA	8803 475834	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay.051980@postgrespro.ru", "phone": "+70526426213"}
0005434142577	B76AC4	7459 583664	NATALYA KOROLEVA	{"email": "koroleva.natalya-071962@postgrespro.ru", "phone": "+70025470090"}
0005434142578	C3EE54	8533 231984	IVAN DAVYDOV	{"phone": "+70513060781"}
0005434142579	EC26E3	7921 194828	YAROSLAV SEMENOV	{"phone": "+70644225951"}
0005434142580	E024C5	0532 436635	SVETLANA ZAKHAROVA	{"phone": "+70240356753"}
0005434149572	90EE50	2052 383906	NIKOLAY IVANOV	{"phone": "+70259698418"}
0005434142581	E024C5	0614 216111	PAVEL ZAKHAROV	{"email": "p_zakharov1976@postgrespro.ru", "phone": "+70251362013"}
0005434142582	D83500	6265 551388	SVETLANA KRASNOVA	{"email": "s.krasnova-07021982@postgrespro.ru", "phone": "+70250740051"}
0005434142583	536FD5	8412 435562	PAVEL MOROZOV	{"phone": "+70375313950"}
0005434142584	E1DB61	9826 091990	OLGA SMIRNOVA	{"phone": "+70007276588"}
0005434142585	BE861B	6936 073510	REGINA PETROVA	{"phone": "+70265034806"}
0005434142586	BE861B	2807 956628	KONSTANTIN VASILEV	{"phone": "+70209889526"}
0005434142587	BE861B	3989 643235	EVGENIYA MATVEEVA	{"phone": "+70211690329"}
0005434142588	DE0A24	4854 146007	NIKOLAY ANTONOV	{"email": "antonov_n_11081969@postgrespro.ru", "phone": "+70123359147"}
0005434142589	225D05	0305 883057	SERGEY ANDREEV	{"phone": "+70392991338"}
0005434142590	3C541D	8867 859038	VLADIMIR NIKOLAEV	{"email": "nikolaev.v_021967@postgrespro.ru", "phone": "+70234812549"}
0005434142591	6CABDF	0088 180775	MIKHAIL GRIGOREV	{"email": "m-grigorev_1975@postgrespro.ru", "phone": "+70450341606"}
0005434142592	4AF64D	3246 188036	OLEG VASILEV	{"phone": "+70305698225"}
0005434142593	CBE4CC	9418 263523	ELENA ISAEVA	{"phone": "+70546294868"}
0005434142594	FCFA31	6946 931160	ROSTISLAV KUZNECOV	{"email": "kuznecov-rostislav-24051973@postgrespro.ru", "phone": "+70472055823"}
0005434142595	8D2565	4368 039773	VALENTINA BOGDANOVA	{"phone": "+70956777093"}
0005434142596	1257B9	3771 660746	ZHANNA BOGDANOVA	{"phone": "+70965297994"}
0005434142597	C3693B	0770 717828	YURIY ZHUKOV	{"phone": "+70732647433"}
0005434142598	3AF569	5962 719716	OLGA POPOVA	{"email": "olgapopova.14081980@postgrespro.ru", "phone": "+70287751050"}
0005434142599	9B07C5	5813 871991	ANNA POLYAKOVA	{"email": "a-polyakova.061964@postgrespro.ru", "phone": "+70927835641"}
0005434142600	D6F0D7	8559 026949	RUSLAN ALEKSANDROV	{"phone": "+70433989429"}
0005434142601	D6F0D7	4283 387155	NIKOLAY IVANOV	{"phone": "+70927898629"}
0005434142602	D6F0D7	7931 883783	KLAVDIYA NESTEROVA	{"email": "k.nesterova29031973@postgrespro.ru", "phone": "+70358174185"}
0005434142603	5B2956	5707 518501	NATALYA BELYAEVA	{"phone": "+70524516613"}
0005434142604	5B2956	1409 294286	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov.031979@postgrespro.ru", "phone": "+70195165894"}
0005434142605	AAAD46	9389 838020	ELENA VASILEVA	{"phone": "+70438146060"}
0005434142606	AAAD46	3250 029397	MARIYA MAKAROVA	{"phone": "+70141433617"}
0005434142607	E366BB	7353 709367	VASILIY FEDOROV	{"email": "vasiliyfedorov-031966@postgrespro.ru", "phone": "+70177371283"}
0005434142608	E366BB	2731 563256	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev_1974@postgrespro.ru", "phone": "+70416487331"}
0005434142609	37FBEF	7564 071036	LIDIYA VOLKOVA	{"email": "lidiya.volkova-1980@postgrespro.ru", "phone": "+70930997861"}
0005434142610	B2894F	1896 435319	YURIY FROLOV	{"phone": "+70467459918"}
0005434142611	ABE09C	0671 823879	DMITRIY NIKOLAEV	{"email": "d.nikolaev_27101974@postgrespro.ru", "phone": "+70048578133"}
0005434142612	B44793	0153 405626	EVGENIY ALEKSEEV	{"email": "e-alekseev1976@postgrespro.ru", "phone": "+70773610340"}
0005434142613	F0F123	8781 449131	SERGEY MARTYNOV	{"email": "s_martynov-1979@postgrespro.ru", "phone": "+70388579090"}
0005434142614	F0F123	9489 312999	RODION MIKHAYLOV	{"phone": "+70297976311"}
0005434142615	B9D21B	2730 891082	YAKOV PETROV	{"phone": "+70258529409"}
0005434142616	2B3865	3382 471699	VLADISLAV VOLKOV	{"email": "volkovv.011970@postgrespro.ru", "phone": "+70208431988"}
0005434142617	2B3865	3340 735321	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr-061976@postgrespro.ru", "phone": "+70937273830"}
0005434142618	8D5373	7993 219416	NATALYA KUZNECOVA	{"phone": "+70880169486"}
0005434142619	8D5373	7090 075470	MARIYA ANDREEVA	{"phone": "+70346048237"}
0005434142620	3BD6CC	7423 654613	VERA SMIRNOVA	{"email": "v_smirnova30031977@postgrespro.ru", "phone": "+70045209804"}
0005434142621	3BD6CC	9952 933790	IGNAT STEPANOV	{"email": "stepanovignat_061971@postgrespro.ru", "phone": "+70327632510"}
0005434142622	B4A2D8	2010 416294	VASILIY ROMANOV	{"email": "vasiliy_romanov.08071969@postgrespro.ru", "phone": "+70482770076"}
0005434142623	1C3CCF	3730 780592	SERGEY DENISOV	{"email": "denisov-sergey051972@postgrespro.ru", "phone": "+70308121802"}
0005434142624	1C3CCF	4079 214807	VALERIY ROMANOV	{"email": "v-romanov-021970@postgrespro.ru", "phone": "+70555338582"}
0005434142625	61167C	5772 614515	ARTEM MOROZOV	{"email": "morozova-11041970@postgrespro.ru", "phone": "+70391259438"}
0005434142626	D5DB49	5744 306346	OLGA LOGINOVA	{"phone": "+70893860430"}
0005434142627	D5DB49	3274 276057	GALINA IVANOVA	{"email": "ivanova-g_081971@postgrespro.ru", "phone": "+70660695497"}
0005434142628	08043F	2114 990929	IVAN NOVIKOV	{"email": "novikov.i-11121971@postgrespro.ru", "phone": "+70676759439"}
0005434142629	FE68F3	5594 607448	OLGA MIRONOVA	{"email": "mironova-olga_101973@postgrespro.ru", "phone": "+70275140178"}
0005434142630	D4AEBF	9354 858986	MARIYA ALEKSANDROVA	{"phone": "+70642794679"}
0005434142631	AFE4A0	7886 644625	MARINA KUZNECOVA	{"email": "marina.kuznecova-1977@postgrespro.ru", "phone": "+70358191421"}
0005434142632	AFE4A0	0604 056547	EVGENIY KOZLOV	{"email": "kozlovevgeniy.1969@postgrespro.ru", "phone": "+70121841181"}
0005434142633	EF048D	4152 496172	SERGEY SOKOLOV	{"phone": "+70311588727"}
0005434142634	EF048D	0962 858157	ALEKSEY SERGEEV	{"email": "aleksey.sergeev-13041978@postgrespro.ru", "phone": "+70075895440"}
0005434142635	59437D	4493 076614	DANILA SERGEEV	{"email": "d-sergeev.071968@postgrespro.ru", "phone": "+70587303344"}
0005434142636	59A913	6297 219072	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev.28011978@postgrespro.ru", "phone": "+70129883524"}
0005434142637	861ED6	1877 318839	VALENTINA FILIPPOVA	{"email": "filippova_v-21101968@postgrespro.ru", "phone": "+70863403005"}
0005434142638	861ED6	6785 514475	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_08091960@postgrespro.ru", "phone": "+70880340049"}
0005434149752	75C8EE	0539 577207	ILYAS PAVLOV	{"phone": "+70852867518"}
0005434142639	861ED6	3991 978116	ELENA MASLOVA	{"email": "e-maslova-011972@postgrespro.ru", "phone": "+70797452099"}
0005434142640	DD11C2	0235 941807	NATALYA ISAEVA	{"phone": "+70656220497"}
0005434142641	84FBF0	7043 686007	YURIY KRASNOV	{"email": "yuriykrasnov1959@postgrespro.ru", "phone": "+70702198309"}
0005434142642	84FBF0	3200 206991	ANTON KRASNOV	{"email": "akrasnov-10061963@postgrespro.ru", "phone": "+70084189938"}
0005434142643	7898DB	9080 056339	LIDIYA ROMANOVA	{"email": "lidiyaromanova-101975@postgrespro.ru", "phone": "+70350182008"}
0005434142644	941F66	8506 762300	MARGARITA KRASNOVA	{"phone": "+70441855110"}
0005434142645	66339C	1818 098583	OLGA IVANOVA	{"email": "olga-ivanova.16091972@postgrespro.ru", "phone": "+70052377692"}
0005434142646	0A9C91	6037 277290	ALEKSANDR GAVRILOV	{"phone": "+70020214251"}
0005434142647	0A9C91	8782 218537	VALENTINA GORBUNOVA	{"phone": "+70656238862"}
0005434142648	826120	7015 511688	NINA KOROLEVA	{"email": "koroleva_n.31011970@postgrespro.ru", "phone": "+70803744928"}
0005434142649	C3A47D	4155 622385	VLADIMIR BARANOV	{"email": "vladimir.baranov011965@postgrespro.ru", "phone": "+70513342653"}
0005434142650	168520	8071 370083	OLEG MAKSIMOV	{"phone": "+70940423916"}
0005434142651	A847AE	1991 870780	GRIGORIY DENISOV	{"phone": "+70787350474"}
0005434142652	A847AE	8508 643461	DMITRIY ZHURAVLEV	{"email": "dzhuravlev.06051971@postgrespro.ru", "phone": "+70153334692"}
0005434142653	137074	1308 175985	PRASKOVYA PAVLOVA	{"email": "ppavlova_1984@postgrespro.ru", "phone": "+70204891967"}
0005434142657	29A180	4612 085061	GALINA KOROLEVA	{"email": "galinakoroleva.1989@postgrespro.ru", "phone": "+70858656344"}
0005434142658	F5A04F	1494 834889	ALEKSANDR ORLOV	{"phone": "+70623638320"}
0005434142659	A22468	1197 698725	ANTON KUDRYASHOV	{"phone": "+70438468149"}
0005434142660	C21F93	5795 096197	TATYANA FEDOROVA	{"phone": "+70894608714"}
0005434142661	DBF0EF	5033 983790	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoaleksandr-061969@postgrespro.ru", "phone": "+70835640021"}
0005434142662	3AEA5B	1122 539327	EVGENIY NOVIKOV	{"phone": "+70210082178"}
0005434142663	3AEA5B	6106 833110	ALEKSANDR SMIRNOV	{"phone": "+70697165982"}
0005434142664	3AEA5B	5966 201740	ANDREY ISAEV	{"email": "andrey.isaev13021957@postgrespro.ru", "phone": "+70289757580"}
0005434142665	7EA105	2088 674461	SERGEY PETROV	{"phone": "+70142805595"}
0005434142666	FAB678	5376 061223	VIKTOR GERASIMOV	{"phone": "+70526674742"}
0005434142667	FAB678	5132 503274	VERA SIDOROVA	{"email": "sidorova-vera24091978@postgrespro.ru", "phone": "+70597581331"}
0005434142668	98CDF3	5986 798936	ALEKSANDR GRIGOREV	{"phone": "+70828701059"}
0005434142669	B14FF9	7368 488173	MARINA VOROBEVA	{"phone": "+70270423166"}
0005434142670	B14FF9	0062 775955	NATALYA SOROKINA	{"email": "sorokina_n_061975@postgrespro.ru", "phone": "+70874932719"}
0005434142671	95560E	8024 806322	TAMARA OSIPOVA	{"phone": "+70770867472"}
0005434142672	B2AD29	6516 912416	ELENA MELNIKOVA	{"phone": "+70812148090"}
0005434142673	684046	3917 661467	IVAN ALEKSEEV	{"phone": "+70118696051"}
0005434142674	FC4BDD	6566 355808	EVGENIY VASILEV	{"email": "vasilev_evgeniy_081973@postgrespro.ru", "phone": "+70933493648"}
0005434142675	CC98BC	4396 896478	ALEKSEY SAVELEV	{"phone": "+70332063278"}
0005434142676	E10F65	7509 890622	LYUBOV NIKITINA	{"email": "nikitina.lyubov121972@postgrespro.ru", "phone": "+70044384873"}
0005434142677	F95C49	2445 178107	MARINA ORLOVA	{"email": "orlova-m_20041983@postgrespro.ru", "phone": "+70630168062"}
0005434142678	A405D4	6608 850058	RUMIYA DANILOVA	{"email": "danilova_r22011974@postgrespro.ru", "phone": "+70090709323"}
0005434142679	D9CCC9	2086 238729	ALEKSANDR SAVELEV	{"email": "a-savelev-031978@postgrespro.ru", "phone": "+70995953034"}
0005434142680	73E40E	0633 436007	GALINA LEBEDEVA	{"phone": "+70472900165"}
0005434142681	B48FF8	1440 963474	VITALIY FOMIN	{"phone": "+70779255382"}
0005434142682	B48FF8	9346 387447	ANNA AKIMOVA	{"email": "a-akimova121970@postgrespro.ru", "phone": "+70837970543"}
0005434142683	889467	8467 567022	SERGEY FROLOV	{"phone": "+70643942450"}
0005434142684	889467	4742 621874	VLADISLAV KRASNOV	{"phone": "+70469118524"}
0005434142685	889467	6379 313363	EKATERINA ZAKHAROVA	{"phone": "+70718155939"}
0005434142686	59A87E	4034 196657	VLADIMIR NAUMOV	{"email": "v.naumov-041964@postgrespro.ru", "phone": "+70344244462"}
0005434142687	05B27A	1771 950773	ALEKSEY SMIRNOV	{"email": "smirnov_a031972@postgrespro.ru", "phone": "+70109557734"}
0005434142688	05B27A	8031 137460	FARIT ISAEV	{"email": "isaevf-061973@postgrespro.ru", "phone": "+70104171510"}
0005434142689	7A810D	2786 084821	GRIGORIY NIKOLAEV	{"phone": "+70430623140"}
0005434142690	4AD385	1998 354744	LILIYA KOROLEVA	{"email": "liliya_koroleva.081975@postgrespro.ru", "phone": "+70819183133"}
0005434142691	4AD385	4286 130047	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila.101972@postgrespro.ru", "phone": "+70289590430"}
0005434142692	B9829D	7315 967652	ANNA KONOVALOVA	{"email": "anna.konovalova011966@postgrespro.ru", "phone": "+70027182504"}
0005434142693	B9829D	6252 163688	ELENA MAKSIMOVA	{"phone": "+70599475019"}
0005434142694	C554EF	2153 209116	ALEKSANDR FOMIN	{"email": "afomin081967@postgrespro.ru", "phone": "+70492693012"}
0005434142695	C554EF	2441 709651	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.1972@postgrespro.ru", "phone": "+70763643592"}
0005434142696	C554EF	8935 251147	OLEG KUZMIN	{"email": "kuzmin-o.1975@postgrespro.ru", "phone": "+70255508593"}
0005434142697	B5D153	9466 503965	TIGRAN ROMANOV	{"email": "tigran.romanov-1971@postgrespro.ru", "phone": "+70257679738"}
0005434142698	B5D153	0484 904472	LIDIYA ANTONOVA	{"phone": "+70015587883"}
0005434142699	8E2FE5	5097 309799	ZLATA ZAKHAROVA	{"phone": "+70691712590"}
0005434142700	236425	9869 118256	NADEZHDA IVANOVA	{"email": "ivanova_n-071968@postgrespro.ru", "phone": "+70986615923"}
0005434142701	236425	6181 670660	NINA POPOVA	{"email": "popovanina_091971@postgrespro.ru", "phone": "+70493054508"}
0005434142703	FD72BD	3752 696972	ALEKSEY PETROV	{"email": "a_petrov-011972@postgrespro.ru", "phone": "+70396089207"}
0005434142704	B21EFC	4550 645086	PAVEL KOZLOV	{"email": "pavelkozlov-01071961@postgrespro.ru", "phone": "+70771928775"}
0005434142705	B21EFC	1733 350310	VITALIY CHERNOV	{"email": "vitaliy.chernov.121978@postgrespro.ru", "phone": "+70126020159"}
0005434142706	0D5AE3	9480 616882	KLAVDIYA SMIRNOVA	{"phone": "+70169089520"}
0005434142707	8DD685	4259 705361	ALENA FOMINA	{"email": "fomina.alena1973@postgrespro.ru", "phone": "+70195009912"}
0005434142708	8DD685	3356 223726	VIKTOR MAKAROV	{"phone": "+70847472759"}
0005434142709	FEC53B	3864 534934	MARINA ZHURAVLEVA	{"email": "zhuravlevamarina10121974@postgrespro.ru", "phone": "+70197028641"}
0005434142710	2E1BFD	1331 189213	ALEKSEY GORBUNOV	{"phone": "+70445658720"}
0005434142711	2E1BFD	1928 267667	VLADIMIR VASILEV	{"email": "vladimir-vasilev.121985@postgrespro.ru", "phone": "+70037449085"}
0005434142712	2E1BFD	9365 714524	BORIS VOROBEV	{"email": "boris.vorobev_121949@postgrespro.ru", "phone": "+70420243757"}
0005434142713	5DE5BA	6952 630684	ANDREY YAKOVLEV	{"phone": "+70697673829"}
0005434142714	3C9DE8	8367 658200	ELENA BELOVA	{"email": "ebelova.1986@postgrespro.ru", "phone": "+70840475951"}
0005434142715	87CA07	4350 118028	ANDREY ANDREEV	{"email": "andreev_andrey_20081961@postgrespro.ru", "phone": "+70483594243"}
0005434142716	87CA07	8527 685841	NIKOLAY SCHERBAKOV	{"email": "nikolayscherbakov-1962@postgrespro.ru", "phone": "+70046810884"}
0005434142717	193B4A	7458 972782	ANTON FROLOV	{"phone": "+70955964682"}
0005434142718	9A4515	7393 651250	VALENTINA ANDREEVA	{"email": "andreeva.v-071979@postgrespro.ru", "phone": "+70773278217"}
0005434142719	7BAB8F	5655 258735	LYUBOV KULIKOVA	{"phone": "+70639540014"}
0005434142720	7BAB8F	8288 029453	ALEKSEY BARANOV	{"email": "aleksey.baranov_29081969@postgrespro.ru", "phone": "+70370304960"}
0005434142721	2B1C41	5398 790939	LYUDMILA PETROVA	{"email": "petrova_l.30111972@postgrespro.ru", "phone": "+70839702804"}
0005434142722	2B1C41	5093 815717	SERGEY CHERNOV	{"phone": "+70982182311"}
0005434142723	9BA998	1324 557555	DENIS VOLKOV	{"phone": "+70088322882"}
0005434142724	9BA998	8806 602449	MARIYA NESTEROVA	{"email": "mariya_nesterova-27121962@postgrespro.ru", "phone": "+70903798966"}
0005434142725	9BA998	5933 123528	ALEKSANDR MEDVEDEV	{"phone": "+70144864565"}
0005434142726	9BA998	1593 334646	MIKHAIL SEMENOV	{"phone": "+70964811066"}
0005434142727	D4A0C5	6849 584705	LARISA ZAKHAROVA	{"phone": "+70626784093"}
0005434142728	2A61D8	4567 111989	ALEKSANDRA IVANOVA	{"phone": "+70514192051"}
0005434143698	3521CF	9405 581528	ALEKSEY NIKITIN	{"email": "nikitin-a.121964@postgrespro.ru", "phone": "+70179561235"}
0005434143699	BA1562	3608 150002	ANASTASIYA NOVIKOVA	{"email": "novikova_a051964@postgrespro.ru", "phone": "+70661234858"}
0005434143700	BA1562	4522 655697	NINA VASILEVA	{"phone": "+70294107410"}
0005434143701	DFAF72	5629 873220	DMITRIY SHEVCHENKO	{"phone": "+70248113400"}
0005434143702	927040	0716 332277	ANDREY KOROLEV	{"phone": "+70770275390"}
0005434143703	FF09CC	0817 901505	TIMUR SMIRNOV	{"email": "smirnov.timur_26081970@postgrespro.ru", "phone": "+70443465499"}
0005434143704	FF09CC	1263 405420	VARVARA BELOVA	{"email": "belova.varvara28101970@postgrespro.ru", "phone": "+70246878297"}
0005434143705	BD7CC1	9699 599371	IRINA MALYSHEVA	{"email": "malysheva-i1975@postgrespro.ru", "phone": "+70597441818"}
0005434143706	305003	6054 678747	IVAN GERASIMOV	{"email": "gerasimov-ivan-19051973@postgrespro.ru", "phone": "+70225458091"}
0005434143707	305003	7255 793131	NADEZHDA FILATOVA	{"email": "nadezhda_filatova081985@postgrespro.ru", "phone": "+70863976579"}
0005434143708	FD71BA	3462 318941	IVAN EGOROV	{"phone": "+70716529376"}
0005434143709	FD71BA	2089 384356	VLADIMIR SMIRNOV	{"phone": "+70261455212"}
0005434143710	73F98C	6515 923657	SEMEN MOISEEV	{"email": "moiseev-semen1979@postgrespro.ru", "phone": "+70495289227"}
0005434143711	73F98C	3877 834914	ARTEM NIKITIN	{"phone": "+70150412003"}
0005434143712	5D6B0B	4396 983041	DANIIL DAVYDOV	{"email": "ddavydov-041972@postgrespro.ru", "phone": "+70930774221"}
0005434143713	8F0F34	1705 751346	ANDREY FEDOROV	{"email": "fedorov_andrey.16101976@postgrespro.ru", "phone": "+70994875312"}
0005434143714	8F0F34	8769 603804	VLADIMIR EGOROV	{"email": "v_egorov.1984@postgrespro.ru", "phone": "+70166971129"}
0005434143715	42BE3D	3428 760098	ALEKSEY VASILEV	{"email": "vasilev_a.061971@postgrespro.ru", "phone": "+70587180049"}
0005434143716	42BE3D	3671 061388	ELENA STEPANOVA	{"email": "stepanova-elena1972@postgrespro.ru", "phone": "+70180661931"}
0005434143717	79A13F	9571 942156	VLADIMIR VOROBEV	{"phone": "+70593755209"}
0005434143718	394C9D	7638 744709	VLADIMIR VASILEV	{"email": "vasilevv_04041980@postgrespro.ru", "phone": "+70359191118"}
0005434143719	26A1DB	7292 716934	VLADIMIR KISELEV	{"phone": "+70976111426"}
0005434143720	26A1DB	2712 576047	ALEKSANDR KONOVALOV	{"email": "konovalova.1976@postgrespro.ru", "phone": "+70903519995"}
0005434143721	3CF161	0782 750081	TATYANA ZOTOVA	{"email": "zotova-t-1979@postgrespro.ru", "phone": "+70131807678"}
0005434143722	969003	9737 630111	YULIYA SERGEEVA	{"phone": "+70022777743"}
0005434143723	EB5A9E	1572 209160	ANNA RODIONOVA	{"phone": "+70412878056"}
0005434143724	001820	3316 587054	OLGA ROMANOVA	{"email": "romanovao11111969@postgrespro.ru", "phone": "+70189953063"}
0005434143725	2891DA	8852 143615	AYRAT PAVLOV	{"phone": "+70804247965"}
0005434143726	2891DA	1649 777912	ALEKSEY ILIN	{"phone": "+70080401618"}
0005434143727	523B20	9550 684538	YURIY GERASIMOV	{"phone": "+70731541726"}
0005434143728	307749	2135 533912	EKATERINA MALYSHEVA	{"email": "malysheva-e.27041972@postgrespro.ru", "phone": "+70573815087"}
0005434143729	4B0A17	5127 542947	VYACHESLAV OSIPOV	{"phone": "+70734543766"}
0005434143730	FF38C7	2266 341264	IRINA KUZNECOVA	{"email": "i-kuznecova_1977@postgrespro.ru", "phone": "+70193515646"}
0005434143731	08EA59	4445 210106	LYUDMILA NIKOLAEVA	{"phone": "+70706764935"}
0005434143732	4EB44B	7533 730539	LYUBOV EFIMOVA	{"email": "l-efimova31051973@postgrespro.ru", "phone": "+70764190333"}
0005434143733	16055B	4728 864617	IGOR KUZNECOV	{"phone": "+70045450025"}
0005434143734	8DA42A	5174 884268	LILIYA GRISHINA	{"email": "liliya-grishina1977@postgrespro.ru", "phone": "+70395450188"}
0005434143735	5B076E	5902 355804	ELENA TIKHONOVA	{"phone": "+70597452935"}
0005434143736	0B76CF	5749 305354	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr_12091965@postgrespro.ru", "phone": "+70841380414"}
0005434143737	58ED84	6519 956921	YANINA LAZAREVA	{"email": "y.lazareva-23031985@postgrespro.ru", "phone": "+70619247144"}
0005434143738	82A997	3668 551031	LYUDMILA ARKHIPOVA	{"email": "larkhipova.1969@postgrespro.ru", "phone": "+70291464130"}
0005434143739	88BCF2	8827 021484	ALEKSANDR ZAKHAROV	{"email": "zakharov.a.08071958@postgrespro.ru", "phone": "+70477761932"}
0005434143740	88BCF2	6983 827850	NIKITA MEDVEDEV	{"email": "nikitamedvedev.1972@postgrespro.ru", "phone": "+70945710904"}
0005434143741	E623DD	8985 805658	SVETLANA FILATOVA	{"phone": "+70921859017"}
0005434143742	E623DD	8923 168195	ALENA NIKIFOROVA	{"phone": "+70362961803"}
0005434143743	498D38	9011 013593	VALENTINA KUZNECOVA	{"phone": "+70717903839"}
0005434143744	907207	4506 435366	IRINA GAVRILOVA	{"email": "gavrilova.i-1972@postgrespro.ru", "phone": "+70289982950"}
0005434143745	16C83B	3865 779085	KLARA ANTONOVA	{"email": "antonova_k-1961@postgrespro.ru", "phone": "+70940302263"}
0005434143746	16C83B	3625 258158	MARIYA POPOVA	{"phone": "+70220429120"}
0005434143747	5835DF	6460 358297	TATYANA FEDOROVA	{"email": "t.fedorova-24081974@postgrespro.ru", "phone": "+70869914752"}
0005434143748	5835DF	9497 328321	ALEKSANDR KAZAKOV	{"email": "kazakova23081971@postgrespro.ru", "phone": "+70402164547"}
0005434143749	1658AC	6295 386570	IRAIDA FEDOROVA	{"phone": "+70749000832"}
0005434143750	1658AC	0628 929041	TAMARA IVANOVA	{"phone": "+70177173228"}
0005434143751	110F46	3493 061396	VALERIY BORISOV	{"email": "borisovvaleriy_19071969@postgrespro.ru", "phone": "+70363626045"}
0005434143752	BDE1CC	4352 144929	VLADISLAV DAVYDOV	{"phone": "+70147445979"}
0005434143753	EDCBA6	5773 387241	YURIY GAVRILOV	{"email": "gavrilovy071966@postgrespro.ru", "phone": "+70468986658"}
0005434143754	9BC3EE	9507 624765	VLADIMIR IVANOV	{"email": "vladimirivanov101969@postgrespro.ru", "phone": "+70742985127"}
0005434143755	3BCDBE	5947 173399	MIKHAIL MAKAROV	{"email": "makarov_m091967@postgrespro.ru", "phone": "+70412961323"}
0005434143756	96786D	7660 446921	REGINA SOROKINA	{"email": "sorokinar_21081960@postgrespro.ru", "phone": "+70212907709"}
0005434143757	96786D	5365 737386	VIKTORIYA SOLOVEVA	{"phone": "+70146201244"}
0005434143758	2B3816	6410 554150	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr.1976@postgrespro.ru", "phone": "+70247541310"}
0005434143759	2B3816	5596 953772	YULIYA KUZNECOVA	{"phone": "+70415299561"}
0005434143760	EA8AD2	2263 012820	MATVEY MELNIKOV	{"phone": "+70373096798"}
0005434143761	EA8AD2	6120 049935	OLGA DAVYDOVA	{"phone": "+70669960083"}
0005434143762	F06CDB	5976 300329	PAVEL STEPANOV	{"email": "pavelstepanov-1969@postgrespro.ru", "phone": "+70038458192"}
0005434143763	F06CDB	9194 053170	VLADIMIR KUZNECOV	{"phone": "+70444027762"}
0005434143764	71376C	5317 920912	EVGENIY KUZMIN	{"phone": "+70325712180"}
0005434143765	71376C	5025 222103	ALEKSANDR BORISOV	{"phone": "+70975616792"}
0005434143766	71376C	8122 312936	TATYANA ANDREEVA	{"email": "andreeva-t051973@postgrespro.ru", "phone": "+70869082428"}
0005434143767	AADFA8	7635 899113	ANDREY KOZLOV	{"email": "akozlov.1976@postgrespro.ru", "phone": "+70130303029"}
0005434143768	D8A33D	0742 411736	VIKTOR MEDVEDEV	{"phone": "+70257478940"}
0005434143769	D8A33D	4294 827086	TATYANA VLASOVA	{"email": "vlasovatatyana1973@postgrespro.ru", "phone": "+70797613091"}
0005434143770	2ED59C	0361 376151	ELENA KOZLOVA	{"phone": "+70620584382"}
0005434143771	4DF35D	8894 459858	ILGIZ YAKOVLEV	{"phone": "+70232886889"}
0005434143772	4DF35D	8013 757987	MARIYA FADEEVA	{"email": "fadeeva-m_061972@postgrespro.ru", "phone": "+70569369053"}
0005434143773	4DF35D	2206 684088	NIKOLAY KISELEV	{"email": "kiselevn-1982@postgrespro.ru", "phone": "+70265370915"}
0005434143774	48874F	1405 274599	LYUDMILA VOROBEVA	{"phone": "+70293745931"}
0005434143775	48874F	7013 247555	ROMAN KUZNECOV	{"email": "kuznecov.roman_10061970@postgrespro.ru", "phone": "+70407256627"}
0005434143776	D8531B	2462 880618	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev_031964@postgrespro.ru", "phone": "+70514277076"}
0005434143777	8A0775	0602 789463	DMITRIY PAVLOV	{"email": "pavlov-d031962@postgrespro.ru", "phone": "+70393092747"}
0005434143778	8A0775	9313 793901	ANASTASIYA RYABOVA	{"phone": "+70796628713"}
0005434143779	A90ED9	0508 209655	LYUDMILA MIKHAYLOVA	{"email": "l-mikhaylova-1972@postgrespro.ru", "phone": "+70542305390"}
0005434143780	F9A897	7884 907422	SVETLANA ALEKSANDROVA	{"email": "svetlanaaleksandrova_041976@postgrespro.ru", "phone": "+70547099600"}
0005434143781	504DBD	8930 512036	LIDIYA NIKITINA	{"email": "l.nikitina_1961@postgrespro.ru", "phone": "+70673566271"}
0005434143782	8F618C	4551 582265	ALEKSANDR NOVIKOV	{"phone": "+70456839343"}
0005434143783	8F618C	5952 617189	IRINA ILINA	{"phone": "+70173135143"}
0005434143784	240719	4625 340254	VLADISLAV EGOROV	{"email": "egorovvladislav.111990@postgrespro.ru", "phone": "+70196687945"}
0005434143785	29C7BE	6452 374563	ANDREY GUSEV	{"email": "gusev.a-14021970@postgrespro.ru", "phone": "+70087231874"}
0005434143786	DD4FD9	8126 722057	TAMARA LUKYANOVA	{"phone": "+70254777493"}
0005434143787	DD4FD9	1388 227499	ALEKSANDR NAZAROV	{"phone": "+70660490746"}
0005434143788	0322CD	2315 399400	VARVARA NIKITINA	{"email": "vnikitina26121978@postgrespro.ru", "phone": "+70711559155"}
0005434143789	1B154A	0475 078749	NATALYA ZAKHAROVA	{"email": "nzakharova1965@postgrespro.ru", "phone": "+70281495539"}
0005434143790	D183DB	2601 198802	SOFYA ZOTOVA	{"email": "zotova-s21081970@postgrespro.ru", "phone": "+70968047663"}
0005434143791	D183DB	8231 447131	MAKSIM SMIRNOV	{"email": "smirnov_maksim-061973@postgrespro.ru", "phone": "+70396431533"}
0005434143792	ED5ABE	6930 987046	ALEKSEY PETROV	{"email": "petrov-aleksey-081965@postgrespro.ru", "phone": "+70726983645"}
0005434143793	024627	0766 058595	OLGA SAVELEVA	{"email": "o_saveleva-1967@postgrespro.ru", "phone": "+70174954248"}
0005434143794	A16F18	6170 221472	MARINA ZOTOVA	{"email": "m-zotova_1979@postgrespro.ru", "phone": "+70152562436"}
0005434143795	09FB82	5434 677407	TATYANA YUDINA	{"phone": "+70601463643"}
0005434143796	8CE094	2902 061106	ALEKSANDR ZHURAVLEV	{"phone": "+70602809896"}
0005434143797	C91847	3686 996349	SALAVAT DENISOV	{"email": "denisov_s_121967@postgrespro.ru", "phone": "+70725409606"}
0005434143798	C1CE47	7106 882694	ROMAN KONOVALOV	{"phone": "+70929521955"}
0005434143799	1A2A70	5419 209442	SERGEY ZAYCEV	{"email": "s-zaycev.091970@postgrespro.ru", "phone": "+70766927457"}
0005434143800	7DA7B4	9267 122185	MARIYA MOROZOVA	{"email": "m_morozova_1969@postgrespro.ru", "phone": "+70863068934"}
0005434143801	7DA7B4	5297 861028	PETR ZAKHAROV	{"phone": "+70319219924"}
0005434143802	7DA7B4	9552 284235	AMINA KISELEVA	{"phone": "+70542957582"}
0005434143803	1E0BAE	8962 782968	EKATERINA BELYAEVA	{"email": "ekaterina-belyaeva28011979@postgrespro.ru", "phone": "+70116107040"}
0005434143804	02D370	1435 951415	SVETLANA KOVALEVA	{"email": "kovaleva.s.02121983@postgrespro.ru", "phone": "+70581472958"}
0005434143805	0DE326	7786 489170	VASILIY IVANOV	{"email": "vasiliy.ivanov.25041967@postgrespro.ru", "phone": "+70271726626"}
0005434143806	42AFF6	8563 842853	OLEG MOROZOV	{"phone": "+70699149111"}
0005434143807	42AFF6	7620 605589	VIKTOR PETROV	{"phone": "+70947093622"}
0005434143808	B4EC45	1827 151396	VITALIY KARPOV	{"email": "vitaliy_karpov-061976@postgrespro.ru", "phone": "+70143734511"}
0005434143809	B4EC45	0116 496681	VALENTINA MALYSHEVA	{"phone": "+70786473240"}
0005434143810	053332	8828 595382	EKATERINA MIKHAYLOVA	{"phone": "+70708667015"}
0005434143811	053332	0854 467243	ANATOLIY BORISOV	{"email": "anatoliy_borisov1976@postgrespro.ru", "phone": "+70750495960"}
0005434143812	053332	5786 138887	LYUBOV EFIMOVA	{"phone": "+70495236536"}
0005434143813	2FE7DD	1171 451067	EVGENIY IVANOV	{"phone": "+70560050373"}
0005434143814	2FE7DD	4003 296475	OLGA STEPANOVA	{"phone": "+70992398563"}
0005434143815	2FE7DD	1237 816092	TATYANA SOKOLOVA	{"phone": "+70234329314"}
0005434143816	5B69DA	8049 688745	VLADISLAV EGOROV	{"phone": "+70577346574"}
0005434143817	C94FB1	5580 456258	IRINA GAVRILOVA	{"phone": "+70056781477"}
0005434143818	94C19D	4599 315164	NATALYA MIKHAYLOVA	{"email": "n-mikhaylova.051965@postgrespro.ru", "phone": "+70749420948"}
0005434143819	458795	2261 947965	YULIYA DENISOVA	{"email": "denisova.y.17021972@postgrespro.ru", "phone": "+70627741709"}
0005434143820	44F4E7	0308 150633	SERGEY VOLKOV	{"email": "s_volkov.06101987@postgrespro.ru", "phone": "+70852664821"}
0005434143821	35F4EB	5106 672543	TATYANA SOKOLOVA	{"phone": "+70168096977"}
0005434143822	A1D263	3980 445871	YURIY MIKHAYLOV	{"phone": "+70734022166"}
0005434143823	479260	8359 846114	IRINA KAZAKOVA	{"email": "ikazakova1968@postgrespro.ru", "phone": "+70021615803"}
0005434143824	479260	3705 502657	TATYANA MAKAROVA	{"email": "tatyana_makarova-12021969@postgrespro.ru", "phone": "+70916948315"}
0005434143825	91BB3D	3167 376197	VALENTINA OSIPOVA	{"email": "valentina_osipova-21041970@postgrespro.ru", "phone": "+70375997448"}
0005434143826	91BB3D	8719 485467	TATYANA NESTEROVA	{"phone": "+70118711515"}
0005434143827	3D6DA5	7336 057226	ZINAIDA VLASOVA	{"phone": "+70835155946"}
0005434143828	3D6DA5	5659 571412	VIKTOR PAVLOV	{"phone": "+70908892460"}
0005434143829	3D6DA5	8801 578072	EVGENIY NAUMOV	{"email": "e.naumov_111967@postgrespro.ru", "phone": "+70706491143"}
0005434143830	2B239B	8617 717219	IVAN YAKOVLEV	{"email": "yakovlev.ivan-1966@postgrespro.ru", "phone": "+70836214176"}
0005434143831	E0DD59	7265 130441	OLGA EFIMOVA	{"phone": "+70255553076"}
0005434143832	02DCB7	4484 975915	PAVEL NIKITIN	{"phone": "+70357063214"}
0005434143833	C222D6	4702 025812	NATALYA NAUMOVA	{"phone": "+70489787186"}
0005434143834	F90AFA	6907 985131	ELENA EGOROVA	{"email": "elena_egorova.1972@postgrespro.ru", "phone": "+70600081837"}
0005434143835	90555A	2704 307223	VARVARA KUZNECOVA	{"phone": "+70202778384"}
0005434143836	90555A	7723 231967	ALENA EGOROVA	{"phone": "+70331701423"}
0005434143837	403921	7495 336753	ALEKSANDR MAKSIMOV	{"phone": "+70041033292"}
0005434143838	403921	7515 136204	DMITRIY MELNIKOV	{"phone": "+70868274127"}
0005434143839	A276D0	6050 871698	OLGA KRASNOVA	{"email": "krasnova-o.21111969@postgrespro.ru", "phone": "+70091824942"}
0005434143840	D333AE	5573 869172	SERGEY SHEVCHENKO	{"email": "s-shevchenko.30111976@postgrespro.ru", "phone": "+70953163687"}
0005434143841	88A9F6	1443 727732	MARIYA ISAEVA	{"email": "isaeva_mariya_08061970@postgrespro.ru", "phone": "+70311925885"}
0005434143842	1B2AC3	4314 802074	VLADIMIR SERGEEV	{"email": "vladimir-sergeev-1968@postgrespro.ru", "phone": "+70863001115"}
0005434143843	1926C4	9701 061515	EVGENIY KOZLOV	{"email": "ekozlov1971@postgrespro.ru", "phone": "+70918400251"}
0005434143844	0C4128	4472 420970	MARINA NAUMOVA	{"email": "naumova-marina011984@postgrespro.ru", "phone": "+70982039086"}
0005434143845	BB27A2	6693 222580	ANDREY NIKITIN	{"phone": "+70655624292"}
0005434143846	82DC8F	4807 922982	ANTONINA LUKYANOVA	{"phone": "+70776482058"}
0005434143847	14C573	0406 270753	SVETLANA NAUMOVA	{"phone": "+70642658451"}
0005434143848	14C573	2402 280130	POLINA NIKITINA	{"phone": "+70617982668"}
0005434143849	3EEC57	8793 188369	VIKTOR KUZNECOV	{"phone": "+70559841617"}
0005434143850	FE8981	1638 937386	ANASTASIYA MAKAROVA	{"email": "a_makarova_15031977@postgrespro.ru", "phone": "+70624386894"}
0005434143851	FE8981	1568 415053	ALEKSEY IVANOV	{"email": "a_ivanov-051973@postgrespro.ru", "phone": "+70510942131"}
0005434143852	D1B81C	1129 756993	NINA BOGDANOVA	{"email": "nina.bogdanova13081979@postgrespro.ru", "phone": "+70847075475"}
0005434143853	DF6154	3884 469619	TATYANA GORBUNOVA	{"email": "t-gorbunova1967@postgrespro.ru", "phone": "+70880485024"}
0005434143854	F73A45	4035 851034	RAUF KUZMIN	{"email": "kuzmin.r-1972@postgrespro.ru", "phone": "+70738484380"}
0005434143855	A79508	6027 828918	LYUDMILA SIDOROVA	{"phone": "+70444453528"}
0005434143856	A79508	5527 530922	ALEKSANDR KULIKOV	{"phone": "+70968503220"}
0005434143857	63CA9B	6350 377886	NIKOLAY BONDARENKO	{"email": "n.bondarenko_1974@postgrespro.ru", "phone": "+70306906160"}
0005434143858	B129C1	3035 198365	VYACHESLAV KUZNECOV	{"phone": "+70569508765"}
0005434143859	139B22	9637 281705	VLADISLAV KUZMIN	{"email": "vladislav-kuzmin_12011975@postgrespro.ru", "phone": "+70584200642"}
0005434149520	83A5B9	9809 459174	LEONID BORISOV	{"phone": "+70766606344"}
0005434149521	6D4A4E	2284 940679	GLEB MAKAROV	{"email": "makarov_g.14091978@postgrespro.ru", "phone": "+70476946053"}
0005434149522	C149AF	8799 548146	MARAT EGOROV	{"email": "egorov-m-1986@postgrespro.ru", "phone": "+70888640948"}
0005434149523	C149AF	7107 518834	ALINA TITOVA	{"phone": "+70296053790"}
0005434149524	C149AF	3832 901314	VALERIY KOZLOV	{"email": "kozlov-valeriy.101974@postgrespro.ru", "phone": "+70255715339"}
0005434149525	18E9DD	1350 552533	GENNADIY KOROLEV	{"email": "g-korolev1974@postgrespro.ru", "phone": "+70125324430"}
0005434149526	B3656B	3977 532230	MARINA EGOROVA	{"email": "egorovamarina_081971@postgrespro.ru", "phone": "+70145787929"}
0005434149527	B3656B	9865 349300	IRINA LUKYANOVA	{"phone": "+70078084293"}
0005434149528	B3656B	0694 348376	SVETLANA MIRONOVA	{"phone": "+70958675643"}
0005434149529	CDAE47	5785 229955	NATALYA POPOVA	{"email": "popova-n_101978@postgrespro.ru", "phone": "+70874144030"}
0005434149530	F4CDFE	4722 012647	MARIYA MATVEEVA	{"email": "matveeva-mariya051972@postgrespro.ru", "phone": "+70889458622"}
0005434149531	F4CDFE	8116 187093	RAVIL DMITRIEV	{"email": "dmitriev_ravil-24051966@postgrespro.ru", "phone": "+70609101553"}
0005434149532	66F2F8	3100 265503	ANNA KOROLEVA	{"phone": "+70794079924"}
0005434149533	66F2F8	8428 389047	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina_111970@postgrespro.ru", "phone": "+70694384339"}
0005434149534	0A92BA	6616 847233	IVAN PETROV	{"phone": "+70367222598"}
0005434149535	32AAED	8169 395273	ARTUR KRASNOV	{"phone": "+70134545796"}
0005434149536	67B106	5298 721400	ALEKSEY CHERNOV	{"email": "chernovaleksey1977@postgrespro.ru", "phone": "+70531212514"}
0005434149537	7C5124	1878 310599	ARKADIY VASILEV	{"email": "vasilevarkadiy-1982@postgrespro.ru", "phone": "+70406840821"}
0005434149538	C6937A	4251 086422	ELENA GERASIMOVA	{"phone": "+70554354377"}
0005434149539	C6937A	9704 198498	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy_1979@postgrespro.ru", "phone": "+70343930101"}
0005434149540	C6937A	8767 074405	YULIYA IVANOVA	{"email": "ivanova.yuliya_101971@postgrespro.ru", "phone": "+70774719839"}
0005434149541	7BD7B7	5363 000725	NIKOLAY FILIPPOV	{"phone": "+70206251963"}
0005434149542	E78484	0556 285517	SERGEY BORISOV	{"phone": "+70300070120"}
0005434149543	E78484	9433 925603	ANDREY MELNIKOV	{"email": "andrey.melnikov1974@postgrespro.ru", "phone": "+70356712478"}
0005434149544	D53F70	7373 909589	VIKTORIYA POPOVA	{"email": "v-popova_071966@postgrespro.ru", "phone": "+70248926370"}
0005434149545	D53F70	6508 862537	LILIYA FROLOVA	{"email": "frolova-l-1965@postgrespro.ru", "phone": "+70720656415"}
0005434149546	D53F70	6140 142220	ANASTASIYA FROLOVA	{"email": "frolova-anastasiya.051973@postgrespro.ru", "phone": "+70406487343"}
0005434149547	BB83E8	1356 158325	MARAT KARPOV	{"email": "karpov.marat.061979@postgrespro.ru", "phone": "+70507860757"}
0005434149548	A27181	7633 900158	ANDREY BONDARENKO	{"email": "bondarenko.a-1966@postgrespro.ru", "phone": "+70289912343"}
0005434149549	A27181	7135 167462	NIKITA KUZNECOV	{"email": "nikitakuznecov-1977@postgrespro.ru", "phone": "+70037182567"}
0005434149550	A27181	6960 535334	ALEKSANDR MOROZOV	{"email": "a_morozov15011971@postgrespro.ru", "phone": "+70772274386"}
0005434149551	1EEAA6	2071 205143	SERGEY SOKOLOV	{"email": "sergeysokolov_051990@postgrespro.ru", "phone": "+70498498864"}
0005434149552	41C456	4191 086599	ANATOLIY PETROV	{"email": "petrova.05041974@postgrespro.ru", "phone": "+70950932588"}
0005434149553	278B60	2393 469955	EVGENIY TIMOFEEV	{"email": "evgeniy-timofeev.1974@postgrespro.ru", "phone": "+70457463856"}
0005434149554	182415	5635 849837	VLADIMIR MELNIKOV	{"phone": "+70437243634"}
0005434149555	F3CA78	6471 126922	DENIS RODIONOV	{"email": "rodionov.d-081977@postgrespro.ru", "phone": "+70523090267"}
0005434149556	F3CA78	1811 012067	IRINA ZOTOVA	{"phone": "+70467021549"}
0005434149557	FC47AF	4186 742356	ANTONINA ORLOVA	{"phone": "+70007014183"}
0005434149558	39B1B1	9730 712039	ELIZAVETA GUSEVA	{"phone": "+70118516054"}
0005434149559	E8D612	5297 974833	DMITRIY SIDOROV	{"phone": "+70507890224"}
0005434149560	41E1CC	9119 317087	VASILIY ISAEV	{"email": "isaev_v.061968@postgrespro.ru", "phone": "+70356837688"}
0005434149561	74BA84	6199 357539	KHALIDA MELNIKOVA	{"phone": "+70555008265"}
0005434149562	A1BCE9	3508 588853	LINAR IVANOV	{"email": "ivanov.linar1967@postgrespro.ru", "phone": "+70901759595"}
0005434149563	D98496	9256 903512	YULIYA KONOVALOVA	{"phone": "+70409507130"}
0005434149564	C41211	2480 015715	KONSTANTIN POPOV	{"phone": "+70379876906"}
0005434149565	C41211	3625 472515	VERA NAZAROVA	{"email": "vnazarova.1975@postgrespro.ru", "phone": "+70514782652"}
0005434149566	E5F7AC	3513 190184	RAISA IVANOVA	{"phone": "+70201081077"}
0005434149567	B1CB36	6122 451608	PAVEL KAZAKOV	{"email": "kazakov.pavel-111974@postgrespro.ru", "phone": "+70197975618"}
0005434149568	20808F	1279 184314	STEPAN KUZNECOV	{"email": "skuznecov_091966@postgrespro.ru", "phone": "+70201105679"}
0005434149569	20808F	8328 091238	GULNARA VOROBEVA	{"email": "vorobeva.gulnara_1975@postgrespro.ru", "phone": "+70986541145"}
0005434149570	4E2512	6896 934907	YURIY ROMANOV	{"phone": "+70806848179"}
0005434149573	03CC5A	0029 534564	VYACHESLAV KARPOV	{"email": "karpovvyacheslav-1976@postgrespro.ru", "phone": "+70669970395"}
0005434149574	03CC5A	4442 978478	MAKSIM SCHERBAKOV	{"email": "scherbakov_m_111964@postgrespro.ru", "phone": "+70475655889"}
0005434149575	03CC5A	8875 345546	MARIYA KUZNECOVA	{"phone": "+70091037866"}
0005434149576	28BED8	1330 065745	TAKHIR ILIN	{"email": "t_ilin_1975@postgrespro.ru", "phone": "+70563973000"}
0005434149577	28BED8	8926 260909	ANTONINA POLYAKOVA	{"phone": "+70108166406"}
0005434149578	36EC74	7959 059068	ALEKSEY MOROZOV	{"email": "aleksey_morozov_06011972@postgrespro.ru", "phone": "+70325088085"}
0005434149579	36EC74	4258 221643	TATYANA FADEEVA	{"phone": "+70746079802"}
0005434149580	C983D4	9437 576148	MIKHAIL ROMANOV	{"email": "romanov_mikhail_20021978@postgrespro.ru", "phone": "+70052778676"}
0005434149581	C46A3F	5986 343897	VASILIY NIKITIN	{"email": "nikitin-vasiliy061967@postgrespro.ru", "phone": "+70264899514"}
0005434149582	21AF44	3096 033062	MAKSIM ANDREEV	{"phone": "+70023075548"}
0005434149583	21AF44	0052 127917	ALEKSANDR NIKOLAEV	{"email": "anikolaev.111967@postgrespro.ru", "phone": "+70527801512"}
0005434149584	94FD1D	3286 375462	YURIY IVANOV	{"email": "ivanovy1963@postgrespro.ru", "phone": "+70642135651"}
0005434149585	72C748	7380 803187	ANASTASIYA KUZNECOVA	{"phone": "+70799219389"}
0005434149586	AFC032	7856 178120	SVETLANA GAVRILOVA	{"phone": "+70216755531"}
0005434149587	F1EE4A	3304 728722	YULIYA TARASOVA	{"email": "tarasova-y1965@postgrespro.ru", "phone": "+70732705746"}
0005434149588	1A8EF0	1898 687001	LARISA DAVYDOVA	{"email": "davydova-larisa.021971@postgrespro.ru", "phone": "+70362544746"}
0005434149589	1645F1	5244 548735	VYACHESLAV GAVRILOV	{"phone": "+70210308761"}
0005434149590	1645F1	6389 074767	TATYANA KUZNECOVA	{"phone": "+70879048769"}
0005434149591	39B1B2	3573 074447	OLGA NESTEROVA	{"email": "olga.nesterova22051976@postgrespro.ru", "phone": "+70604996093"}
0005434149592	39B1B2	8397 766838	VLADIMIR MAKAROV	{"email": "makarov-v011970@postgrespro.ru", "phone": "+70831844492"}
0005434149593	21A079	3796 267666	RUFIYA GERASIMOVA	{"phone": "+70613660048"}
0005434149594	21A079	9322 960957	ZINAIDA LAZAREVA	{"email": "zinaida_lazareva_1972@postgrespro.ru", "phone": "+70097168242"}
0005434149595	30AF85	5778 799428	OKSANA VASILEVA	{"phone": "+70680804328"}
0005434149596	30AF85	5922 091988	TIMUR YAKOVLEV	{"phone": "+70891405284"}
0005434149597	49052D	3130 545394	OLGA LUKYANOVA	{"email": "olga_lukyanova.1977@postgrespro.ru", "phone": "+70001733241"}
0005434149598	49052D	2142 547317	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya.01021979@postgrespro.ru", "phone": "+70867654782"}
0005434149599	A37F29	5731 015495	ANATOLIY DMITRIEV	{"email": "dmitriev.a_04051976@postgrespro.ru", "phone": "+70703979672"}
0005434149600	202937	9059 354920	ILMIRA LUKYANOVA	{"email": "lukyanova.i-26011968@postgrespro.ru", "phone": "+70148754262"}
0005434149601	BD5299	6804 743619	ALEKSANDR GORBUNOV	{"phone": "+70176692404"}
0005434149602	BD5299	6501 625880	ANNA NIKOLAEVA	{"email": "a.nikolaeva-06041970@postgrespro.ru", "phone": "+70430948098"}
0005434149603	2E781D	9928 116170	ALEKSANDRA ZOTOVA	{"phone": "+70346769058"}
0005434149604	BB829B	2416 313115	TATYANA KALININA	{"email": "tatyana_kalinina.031976@postgrespro.ru", "phone": "+70995796064"}
0005434149605	769142	9700 729757	ALEKSANDRA BORISOVA	{"email": "borisovaaleksandra.22071980@postgrespro.ru", "phone": "+70623807343"}
0005434149606	769142	9143 646947	ANTON NIKITIN	{"email": "a-nikitin.091968@postgrespro.ru", "phone": "+70534009664"}
0005434149607	8AAE8A	9503 394928	KIRILL GRIGOREV	{"email": "kirill-grigorev.24081973@postgrespro.ru", "phone": "+70557797590"}
0005434149608	3B6901	8932 106923	LYUDMILA PAVLOVA	{"email": "pavlovalyudmila_26081970@postgrespro.ru", "phone": "+70937217391"}
0005434149609	65FAE9	8017 501190	SVETLANA PETROVA	{"email": "svetlana.petrova_06091976@postgrespro.ru", "phone": "+70813908069"}
0005434149610	699978	9346 528881	DMITRIY MIRONOV	{"phone": "+70256777089"}
0005434149611	4590E4	2554 737141	EVGENIY KRASNOV	{"email": "krasnov.e_1974@postgrespro.ru", "phone": "+70441813557"}
0005434149612	0BBEB2	1229 133179	VLADIMIR SIDOROV	{"phone": "+70766285798"}
0005434149613	19F35E	2712 017017	TATYANA MOROZOVA	{"phone": "+70715432229"}
0005434149614	19F35E	3849 334839	MAKSIM YAKOVLEV	{"email": "yakovlevmaksim111983@postgrespro.ru", "phone": "+70276396933"}
0005434149615	19F35E	0628 672093	ALFIYA IVANOVA	{"phone": "+70268494284"}
0005434149616	B9EFDD	6748 101674	ALBINA KULIKOVA	{"phone": "+70375230464"}
0005434149617	9D6E4D	1589 442491	VALENTIN SCHERBAKOV	{"email": "valentin.scherbakov-061971@postgrespro.ru", "phone": "+70695137424"}
0005434149618	1E9F98	9483 542926	ROMAN PETROV	{"phone": "+70145772328"}
0005434149619	04A790	8080 152418	LYUBOV GAVRILOVA	{"phone": "+70438586839"}
0005434149620	04A790	0704 191608	ELENA RYABOVA	{"email": "ryabova.elena_15101974@postgrespro.ru", "phone": "+70104084129"}
0005434149621	862F2B	7920 168504	YURIY NAZAROV	{"email": "ynazarov1974@postgrespro.ru", "phone": "+70845212327"}
0005434149622	862F2B	4268 010099	ARTEM MARTYNOV	{"phone": "+70933501028"}
0005434149623	5F11B7	1619 206285	ZOYA MARTYNOVA	{"phone": "+70576140678"}
0005434149624	5F11B7	1994 668995	ANATOLIY AFANASEV	{"email": "afanaseva24091972@postgrespro.ru", "phone": "+70550515947"}
0005434149625	07ADA1	0449 245993	VIKTORIYA MAKAROVA	{"email": "viktoriya.makarova.1971@postgrespro.ru", "phone": "+70753857883"}
0005434149626	7904ED	4547 504926	NATALYA KULIKOVA	{"email": "kulikova_natalya-061977@postgrespro.ru", "phone": "+70303409726"}
0005434149627	12CC46	7187 766735	DENIS MELNIKOV	{"email": "melnikov.d04081983@postgrespro.ru", "phone": "+70272978647"}
0005434149628	DFB8E2	4619 188463	OLEG KUZNECOV	{"email": "olegkuznecov.1975@postgrespro.ru", "phone": "+70177828233"}
0005434149629	E0252B	4087 956645	ANNA MIKHAYLOVA	{"email": "annamikhaylova011978@postgrespro.ru", "phone": "+70422289304"}
0005434149630	1CDBB2	5393 822113	TATYANA KOROLEVA	{"email": "koroleva.t24011965@postgrespro.ru", "phone": "+70914091689"}
0005434149631	C7D8E7	4602 512575	TATYANA ZHURAVLEVA	{"email": "zhuravleva.t.1966@postgrespro.ru", "phone": "+70103695712"}
0005434149632	CEC959	9150 190233	KRISTINA TARASOVA	{"email": "kristina.tarasova_031977@postgrespro.ru", "phone": "+70650579120"}
0005434149633	CEC959	4028 648625	RINAT TIMOFEEV	{"email": "timofeev-r_101977@postgrespro.ru", "phone": "+70181621282"}
0005434149634	2BFB56	1451 426756	ELENA FADEEVA	{"email": "e.fadeeva.1978@postgrespro.ru", "phone": "+70515459984"}
0005434149635	74333C	3180 016991	ELIZAVETA STEPANOVA	{"phone": "+70345739491"}
0005434149636	2E2643	9746 269596	GALINA EFIMOVA	{"phone": "+70186494755"}
0005434149637	2E2643	9655 403508	DENIS DENISOV	{"phone": "+70355451387"}
0005434149638	D2EC83	6268 589451	GENNADIY NIKITIN	{"email": "gennadiy.nikitin.121973@postgrespro.ru", "phone": "+70285377756"}
0005434149639	D2EC83	9430 133754	EVGENIYA ROMANOVA	{"phone": "+70697766322"}
0005434149640	27789D	4542 790665	ANDREY FOMIN	{"phone": "+70071077226"}
0005434149641	4E6FA2	4936 977678	ALEKSEY BORISOV	{"phone": "+70598022556"}
0005434149642	CCC65D	9705 787943	NATALYA LAZAREVA	{"phone": "+70844759601"}
0005434149643	CCC65D	9413 349893	NIKOLAY ZAKHAROV	{"phone": "+70897187466"}
0005434149644	1ECBE3	9071 746806	KIRILL RODIONOV	{"phone": "+70257335923"}
0005434149645	C7D401	5080 881030	RINAT TIMOFEEV	{"email": "timofeev_r22021974@postgrespro.ru", "phone": "+70919038234"}
0005434149646	C7D401	4862 440161	VALENTINA OVCHINNIKOVA	{"email": "valentina-ovchinnikova_28071964@postgrespro.ru", "phone": "+70850116682"}
0005434149647	6165F9	3615 230162	VYACHESLAV BELOV	{"phone": "+70722174779"}
0005434149648	F133B5	5656 969348	SVETLANA EGOROVA	{"email": "egorova.s.061977@postgrespro.ru", "phone": "+70890530388"}
0005434149649	F133B5	4998 401702	YURIY SAVELEV	{"email": "savelevy-1975@postgrespro.ru", "phone": "+70941702223"}
0005434149650	660ABA	6610 226253	NIKOLAY NIKITIN	{"email": "nikitin_n.05121974@postgrespro.ru", "phone": "+70665421577"}
0005434149651	660ABA	6050 821507	LYUDMILA KRASNOVA	{"email": "l-krasnova-25111977@postgrespro.ru", "phone": "+70325032415"}
0005434149652	644CE0	2775 522845	LIDIYA MOROZOVA	{"phone": "+70869830399"}
0005434149653	013099	9597 668428	VALENTINA EFREMOVA	{"email": "vefremova_13121960@postgrespro.ru", "phone": "+70537701878"}
0005434149654	869688	2071 958829	ANASTASIYA POLYAKOVA	{"phone": "+70708905007"}
0005434149655	869688	7654 439103	ANASTASIYA EFREMOVA	{"phone": "+70434182136"}
0005434149656	C90413	7929 427915	SERGEY EGOROV	{"email": "egorov-sergey_24031968@postgrespro.ru", "phone": "+70616977319"}
0005434149657	DB4706	7767 606316	TATYANA SIDOROVA	{"phone": "+70261406368"}
0005434149658	DB4706	8782 548079	EVGENIY CHERNOV	{"phone": "+70920870377"}
0005434149659	DB4706	3706 926323	YURIY MIKHAYLOV	{"email": "mikhaylov_yuriy-21061970@postgrespro.ru", "phone": "+70087544996"}
0005434149660	E93BE2	2057 253333	VALENTIN ISAEV	{"phone": "+70288946019"}
0005434149661	C92F78	8876 134975	ANDREY VOLKOV	{"phone": "+70482350535"}
0005434149662	EDD1C0	8044 390722	OLGA NAUMOVA	{"phone": "+70617046260"}
0005434149663	238878	6927 171849	ALEKSEY DENISOV	{"email": "a.denisov-1973@postgrespro.ru", "phone": "+70729310758"}
0005434149664	238878	8095 691655	OLESYA KUZNECOVA	{"phone": "+70545684871"}
0005434149665	238878	0534 128474	VIKTOR POPOV	{"email": "viktor.popov-15041981@postgrespro.ru", "phone": "+70290750273"}
0005434149666	88DAE0	1239 246137	EVGENIY STEPANOV	{"email": "e-stepanov011980@postgrespro.ru", "phone": "+70929421501"}
0005434149667	88DAE0	8092 797262	SERGEY SMIRNOV	{"email": "ssmirnov_051966@postgrespro.ru", "phone": "+70999356176"}
0005434149668	57E556	5880 402470	LIDIYA FOMINA	{"phone": "+70344366342"}
0005434149669	57E556	2199 740812	OLGA ZAKHAROVA	{"email": "o.zakharova1973@postgrespro.ru", "phone": "+70818414090"}
0005434149670	F91756	1187 414083	LYUBOV NIKITINA	{"email": "nikitina_lyubov1966@postgrespro.ru", "phone": "+70826898292"}
0005434149671	F91756	3480 880053	KSENIYA ALEKSEEVA	{"email": "alekseeva_k.1973@postgrespro.ru", "phone": "+70220768661"}
0005434149672	2ACE63	9204 839943	SVETLANA ZHURAVLEVA	{"phone": "+70725339483"}
0005434149673	29AE1E	2648 008629	ANATOLIY BARANOV	{"phone": "+70398944542"}
0005434149674	BC65FF	1862 632610	VADIM VOROBEV	{"email": "vadim-vorobev1971@postgrespro.ru", "phone": "+70962890140"}
0005434149675	1ABDC8	3692 239916	SVETLANA SOLOVEVA	{"email": "s_soloveva14111979@postgrespro.ru", "phone": "+70714441753"}
0005434149676	0423A1	4819 429361	OLGA LAZAREVA	{"email": "lazarevaolga_1971@postgrespro.ru", "phone": "+70248095588"}
0005434149677	70AA00	1170 635895	VALENTINA STEPANOVA	{"phone": "+70264503853"}
0005434149678	7370F4	8809 978949	SVETLANA NIKOLAEVA	{"phone": "+70975455205"}
0005434149679	BA582C	1537 757529	LYUDMILA SERGEEVA	{"email": "sergeeva-lyudmila-1965@postgrespro.ru", "phone": "+70645506923"}
0005434149680	BA582C	1790 802512	KONSTANTIN CHERNOV	{"email": "konstantinchernov_021969@postgrespro.ru", "phone": "+70984726892"}
0005434149681	D24704	7194 630218	VERA KUZNECOVA	{"phone": "+70864543231"}
0005434149682	D254DB	3020 551917	TATYANA VOLKOVA	{"email": "volkova-t_1974@postgrespro.ru", "phone": "+70654408110"}
0005434149683	D254DB	1250 094631	ELENA SEMENOVA	{"email": "esemenova111973@postgrespro.ru", "phone": "+70785819776"}
0005434149684	129423	3661 802653	ALEKSEY PAVLOV	{"phone": "+70210332245"}
0005434149685	31BBFE	0495 880865	NINA ZHUKOVA	{"email": "zhukova.nina-121969@postgrespro.ru", "phone": "+70292830194"}
0005434149686	E03D43	3783 819764	LEONID STEPANOV	{"phone": "+70008683011"}
0005434149687	E03D43	3342 114999	VITALIY BARANOV	{"phone": "+70740172520"}
0005434149688	CFE790	0581 679556	NIKOLAY MAKSIMOV	{"phone": "+70187962299"}
0005434149689	42BE7E	8348 026756	OKSANA TITOVA	{"phone": "+70946163260"}
0005434149690	C1EEE5	0474 193256	PAVEL NAZAROV	{"email": "pavel_nazarov-19081974@postgrespro.ru", "phone": "+70777700504"}
0005434149753	DE2D40	3689 758443	VASILIY FILIPPOV	{"phone": "+70380149446"}
0005434149691	C1EEE5	2235 729270	ANATOLIY IVANOV	{"email": "a_ivanov-081969@postgrespro.ru", "phone": "+70714638983"}
0005434149692	AA7295	1740 187991	RUSTEM OSIPOV	{"email": "osipovrustem061978@postgrespro.ru", "phone": "+70147905614"}
0005434149693	4063C4	1660 121704	VALENTINA MAKSIMOVA	{"email": "valentinamaksimova06121976@postgrespro.ru", "phone": "+70719872251"}
0005434149694	464F05	3391 685501	VITALIY MEDVEDEV	{"phone": "+70704002222"}
0005434149695	6506D8	8979 686834	DMITRIY MATVEEV	{"phone": "+70433880663"}
0005434149696	5A03FB	0787 660958	EKATERINA NAZAROVA	{"email": "nazarova_e_011972@postgrespro.ru", "phone": "+70962308888"}
0005434149697	D0CD07	4342 802150	ANZHELIKA ISAEVA	{"phone": "+70232737492"}
0005434149698	C3496C	3265 562521	EKATERINA POPOVA	{"email": "popova.e.011969@postgrespro.ru", "phone": "+70428422023"}
0005434149699	47F48F	3906 491479	NIKOLAY EGOROV	{"email": "egorov_nikolay_10091966@postgrespro.ru", "phone": "+70383842858"}
0005434149700	425250	0612 008852	SERGEY AFANASEV	{"email": "safanasev_021979@postgrespro.ru", "phone": "+70682841428"}
0005434149701	C35D49	1584 891285	ARTEM KOZLOV	{"email": "kozlov_artem-16081965@postgrespro.ru", "phone": "+70506194384"}
0005434149702	746BC1	0283 652538	VALERIYA MOROZOVA	{"phone": "+70597983297"}
0005434149703	746BC1	1323 161395	DENIS TIMOFEEV	{"phone": "+70468151140"}
0005434149704	ECEE9D	9495 773006	VLADIMIR BORISOV	{"email": "vladimir_borisov-031975@postgrespro.ru", "phone": "+70116155243"}
0005434149705	73D697	6127 983086	VALENTINA DAVYDOVA	{"email": "v.davydova.1988@postgrespro.ru", "phone": "+70825463260"}
0005434149706	C419A9	0216 228874	IRINA MARTYNOVA	{"email": "martynova-irina-121981@postgrespro.ru", "phone": "+70086413269"}
0005434149707	C419A9	9633 893777	NIKOLAY ANTONOV	{"phone": "+70284923492"}
0005434149708	C419A9	2361 629427	OLGA IVANOVA	{"email": "ivanova-o-10021982@postgrespro.ru", "phone": "+70318871313"}
0005434149709	AF0C47	0147 316651	MATVEY ZAYCEV	{"email": "zaycev_m_021961@postgrespro.ru", "phone": "+70353435828"}
0005434149710	EDF84A	2719 353743	SERGEY SERGEEV	{"phone": "+70153084619"}
0005434149711	C212CA	6752 986677	EGOR ZAKHAROV	{"phone": "+70053832477"}
0005434149712	29DF85	5355 677195	GENNADIY BORISOV	{"phone": "+70027025275"}
0005434149713	B750CC	5171 073664	OLGA MOISEEVA	{"phone": "+70800029588"}
0005434149714	B750CC	7919 136463	EDUARD OSIPOV	{"phone": "+70461225280"}
0005434149715	4943F5	2490 641281	SANIYA DENISOVA	{"email": "denisova_s-1982@postgrespro.ru", "phone": "+70100539651"}
0005434149716	C81DF8	9678 733364	VLADIMIR SMIRNOV	{"phone": "+70090538109"}
0005434149717	8599FB	6651 806735	ZINAIDA ABRAMOVA	{"email": "zinaida_abramova.081969@postgrespro.ru", "phone": "+70354061588"}
0005434149718	B15411	4344 917970	TAMARA EGOROVA	{"phone": "+70175392275"}
0005434149719	7B3167	9416 749183	DIANA SMIRNOVA	{"phone": "+70504591163"}
0005434149720	EE0BB8	8259 954322	TATYANA POPOVA	{"phone": "+70461493864"}
0005434149721	EE0BB8	9865 895207	SERGEY NAZAROV	{"phone": "+70460014106"}
0005434149722	1BE580	5517 621883	NIKOLAY ORLOV	{"email": "orlovn_23081968@postgrespro.ru", "phone": "+70681833736"}
0005434149723	1BE580	6853 982480	NATALYA KARPOVA	{"email": "karpovan.111961@postgrespro.ru", "phone": "+70982543819"}
0005434149724	18CE7F	4142 031639	IVAN GRIGOREV	{"email": "grigorevivan.071962@postgrespro.ru", "phone": "+70133470395"}
0005434149725	B70848	0030 347270	TAMARA SMIRNOVA	{"email": "t_smirnova1966@postgrespro.ru", "phone": "+70662576656"}
0005434149726	7D2E00	7850 850883	EKATERINA MAKSIMOVA	{"email": "maksimovae-011975@postgrespro.ru", "phone": "+70436293315"}
0005434149727	C81638	1629 478664	SERGEY POPOV	{"email": "popov_s-13121979@postgrespro.ru", "phone": "+70474698084"}
0005434149728	8EC6F7	6436 761800	YURIY MARTYNOV	{"email": "y-martynov.1978@postgrespro.ru", "phone": "+70979014225"}
0005434149729	8EC6F7	4777 140986	VALENTINA EFREMOVA	{"email": "valentina.efremova091978@postgrespro.ru", "phone": "+70972184440"}
0005434149730	81AEAB	6692 269446	YURIY SEMENOV	{"email": "semenov-y_1962@postgrespro.ru", "phone": "+70624501221"}
0005434149731	81AEAB	6291 089510	NIKOLAY OSIPOV	{"email": "osipov-n-1979@postgrespro.ru", "phone": "+70616398318"}
0005434149732	CA0546	6042 164122	ILYAS MEDVEDEV	{"email": "medvedev_i1989@postgrespro.ru", "phone": "+70496513492"}
0005434149733	CA0546	2036 633004	LIDIYA POTAPOVA	{"email": "potapova-lidiya_1961@postgrespro.ru", "phone": "+70859453140"}
0005434149734	CA0546	3981 969877	OLGA ZHURAVLEVA	{"phone": "+70044565875"}
0005434149735	A4651F	4431 979820	NATALYA KOVALEVA	{"phone": "+70869970181"}
0005434149736	A4651F	7834 812289	IRINA VOLKOVA	{"phone": "+70446775182"}
0005434149737	602774	2289 957399	VALENTINA ALEKSANDROVA	{"phone": "+70681547505"}
0005434149738	602774	9732 930188	VARVARA IVANOVA	{"phone": "+70489228479"}
0005434149739	3DC0B5	5570 031951	SERGEY NIKOLAEV	{"phone": "+70656409524"}
0005434149740	30B2D1	9020 213459	MARK KUZNECOV	{"phone": "+70072551790"}
0005434149741	90EAFA	8654 309364	ELENA LOGINOVA	{"email": "loginova-elena16111966@postgrespro.ru", "phone": "+70998315822"}
0005434149742	90EAFA	5747 520393	OKSANA ANTONOVA	{"phone": "+70261808995"}
0005434149743	F8E8B4	4128 235896	OKSANA GORBUNOVA	{"phone": "+70402892687"}
0005434149744	89E85B	3448 711511	LIYA POPOVA	{"phone": "+70239546159"}
0005434149745	04B251	6074 148953	ALEKSEY YAKOVLEV	{"email": "alekseyyakovlev-1974@postgrespro.ru", "phone": "+70782054699"}
0005434149746	5EC1E1	8620 671086	YURIY FEDOROV	{"email": "fedorovy.22021982@postgrespro.ru", "phone": "+70714034050"}
0005434149747	5EC1E1	6814 155665	ALLA OSIPOVA	{"phone": "+70548835724"}
0005434149748	58C68F	4501 293785	MIKHAIL MEDVEDEV	{"phone": "+70587685807"}
0005434149749	6A4842	2833 067747	ALEKSANDR SMIRNOV	{"phone": "+70395082705"}
0005434149750	E0D001	8734 177330	DARYA KUZMINA	{"email": "darya-kuzmina_04061969@postgrespro.ru", "phone": "+70149296330"}
0005434149751	DF505E	4928 353967	VLADIMIR NOVIKOV	{"phone": "+70673979089"}
0005434149754	D5C659	4474 464982	ANASTASIYA AKIMOVA	{"email": "akimova_a_081970@postgrespro.ru", "phone": "+70679055704"}
0005434149755	91370A	0589 995329	ALBINA KOZLOVA	{"email": "albinakozlova_1968@postgrespro.ru", "phone": "+70666782749"}
0005434149756	91370A	8729 333766	EVGENIY KOZLOV	{"email": "evgeniy-kozlov1963@postgrespro.ru", "phone": "+70004438109"}
0005434149757	91370A	1492 138481	SVETLANA TIMOFEEVA	{"email": "s.timofeeva-111979@postgrespro.ru", "phone": "+70077721884"}
0005434149758	B3A4B6	3447 214438	SERGEY POPOV	{"email": "popov.s.05031966@postgrespro.ru", "phone": "+70348653684"}
0005434149759	17E526	2741 938240	DMITRIY SOROKIN	{"email": "sorokin.d18011973@postgrespro.ru", "phone": "+70786690844"}
0005434149760	58D0BE	5995 793792	EVGENIY ANDREEV	{"email": "andreevevgeniy.121971@postgrespro.ru", "phone": "+70448798769"}
0005434149761	92B275	4614 964724	IRINA NAZAROVA	{"phone": "+70159463030"}
0005434149762	3B1A8D	0943 140669	VIKTOR STEPANOV	{"phone": "+70262407919"}
0005434149763	8E5450	9623 024319	LIDIYA KOZLOVA	{"email": "kozlova.l26031981@postgrespro.ru", "phone": "+70292110342"}
0005434149764	2A1CD7	7835 664874	ANDREY GUSEV	{"email": "gusev_a12011972@postgrespro.ru", "phone": "+70012807730"}
0005434149765	2A1CD7	0364 812812	MARGARITA EGOROVA	{"phone": "+70853984509"}
0005434149766	380BF1	6755 901408	ANDREY FEDOTOV	{"email": "afedotov-071973@postgrespro.ru", "phone": "+70974128070"}
0005434149767	8B362D	5012 954149	ALEKSANDR DMITRIEV	{"phone": "+70120506024"}
0005434149768	E61007	8648 173414	LIDIYA MARTYNOVA	{"phone": "+70277307663"}
0005434149769	605A67	0251 223048	EVGENIY SMIRNOV	{"phone": "+70743137060"}
0005434149770	605A67	6830 339426	ZLATA IVANOVA	{"email": "ivanovazlata1974@postgrespro.ru", "phone": "+70010122193"}
0005434149771	605A67	2691 852070	EKATERINA KUZMINA	{"email": "kuzminae.031963@postgrespro.ru", "phone": "+70174428402"}
0005434149772	AD6E70	6229 615238	KONSTANTIN NIKITIN	{"email": "konstantin-nikitin.1972@postgrespro.ru", "phone": "+70931634032"}
0005434149773	AD6E70	1365 376426	VALERIYA ROMANOVA	{"email": "romanova-v1966@postgrespro.ru", "phone": "+70102887700"}
0005434149774	6E0BB9	0789 303588	ELENA POPOVA	{"email": "popova.e-22081960@postgrespro.ru", "phone": "+70688080787"}
0005434149775	6E0BB9	1616 117406	NATALYA VASILEVA	{"phone": "+70988745351"}
0005434149776	3AFCAF	9531 761099	LIDIYA NESTEROVA	{"email": "lidiya_nesterova-08011971@postgrespro.ru", "phone": "+70692334265"}
0005434149777	3AFCAF	3665 875243	EKATERINA SOKOLOVA	{"phone": "+70007798779"}
0005434149778	6A707D	6599 506288	YURIY FILIPPOV	{"phone": "+70327022697"}
0005434149779	E6CFCD	2758 341625	RAUZA AFANASEVA	{"email": "rauza.afanaseva.081967@postgrespro.ru", "phone": "+70599200177"}
0005434149780	1144C7	9661 663336	NINA POPOVA	{"email": "popova-n-08081965@postgrespro.ru", "phone": "+70786910238"}
0005434149781	AB9095	7814 555337	MIKHAIL MAKAROV	{"phone": "+70270294975"}
0005434149782	53960E	4664 391965	ANNA KAZAKOVA	{"phone": "+70366097954"}
0005434149783	18554C	8260 819142	MAKSIM VASILEV	{"phone": "+70936675500"}
0005434149784	18554C	5605 134685	ALEKSANDRA BELOVA	{"phone": "+70355487750"}
0005434149785	291E19	8141 372759	SERGEY YAKOVLEV	{"email": "syakovlev091979@postgrespro.ru", "phone": "+70313436927"}
0005434149786	8CB072	8980 997761	ARTEM EGOROV	{"phone": "+70063817733"}
0005434149787	8CB072	2888 947583	OKSANA OSIPOVA	{"phone": "+70575837738"}
0005434149788	167129	0050 595811	OLESYA KOVALEVA	{"email": "kovaleva_o.29091971@postgrespro.ru", "phone": "+70197698684"}
0005434149789	F83424	2858 075781	NIKOLAY MOISEEV	{"phone": "+70609389724"}
0005434149790	825302	7567 661010	EVGENIYA MIKHAYLOVA	{"email": "evgeniya_mikhaylova111980@postgrespro.ru", "phone": "+70536176004"}
0005434149791	B8704E	7309 229897	GALINA YUDINA	{"email": "yudinagalina041969@postgrespro.ru", "phone": "+70687521120"}
0005434149792	6D30F5	7425 672955	LYUBOV FILATOVA	{"phone": "+70918759133"}
0005434149793	5713DB	7351 978682	TATYANA OSIPOVA	{"email": "tosipova_1971@postgrespro.ru", "phone": "+70848579907"}
0005434149794	9C13C0	2856 899046	ARSENIY KAZAKOV	{"email": "kazakov-arseniy_1961@postgrespro.ru", "phone": "+70629232083"}
0005434149795	374845	5263 894906	SERGEY SMIRNOV	{"phone": "+70157307924"}
0005434149796	374845	9757 836858	ALEKSANDRA KUZNECOVA	{"phone": "+70489799917"}
0005434149797	39E383	6863 810115	ANTON ZAYCEV	{"email": "zaycev_anton_10051972@postgrespro.ru", "phone": "+70323080879"}
0005434149798	578260	8677 423122	IGOR NIKITIN	{"email": "i.nikitin18041977@postgrespro.ru", "phone": "+70236795887"}
0005434149799	601869	4787 662955	ALENA FADEEVA	{"phone": "+70161381406"}
0005434149800	601869	1037 598628	VADIM MAKAROV	{"email": "vadim-makarov.101987@postgrespro.ru", "phone": "+70917349612"}
0005434149801	360C6F	4415 370482	SERGEY SOLOVEV	{"email": "solovev.sergey03081979@postgrespro.ru", "phone": "+70017024133"}
0005434149802	AEBC55	4100 495960	DMITRIY SMIRNOV	{"phone": "+70395271085"}
0005434149803	AD017F	1173 162961	DMITRIY RODIONOV	{"phone": "+70466756541"}
0005434149804	E7EA3B	0063 195888	RAFIK NAUMOV	{"email": "rafik-naumov_1981@postgrespro.ru", "phone": "+70642218389"}
0005434149805	55B88A	0496 312205	IRINA POPOVA	{"email": "popovairina_111974@postgrespro.ru", "phone": "+70711082022"}
0005434149806	AED912	0017 965195	VLADISLAV KOZLOV	{"email": "vladislav_kozlov03011973@postgrespro.ru", "phone": "+70958277343"}
0005434149807	72C0DF	4933 006141	ELENA NESTEROVA	{"phone": "+70269685721"}
0005434149808	520406	1352 925332	RAISA KUZNECOVA	{"email": "kuznecova.raisa-011974@postgrespro.ru", "phone": "+70141535169"}
0005434149809	134D54	2011 477995	TAMARA BORISOVA	{"email": "borisovat24101956@postgrespro.ru", "phone": "+70472542957"}
0005434149810	4EDDC7	0124 943136	SERGEY KUZNECOV	{"email": "sergeykuznecov.26091966@postgrespro.ru", "phone": "+70957609843"}
0005434149811	090B93	9548 316860	LARISA BORISOVA	{"email": "larisa-borisova1965@postgrespro.ru", "phone": "+70117053927"}
0005434149812	090B93	5957 222984	TATYANA EGOROVA	{"phone": "+70218926424"}
0005434149813	090B93	2628 055867	EVGENIY TIMOFEEV	{"phone": "+70359496109"}
0005434149814	3E7387	8950 114869	NADEZHDA NOVIKOVA	{"phone": "+70174329716"}
0005434149815	6913A7	5034 892639	OLEG VASILEV	{"email": "vasilev.o.1977@postgrespro.ru", "phone": "+70882211981"}
0005434149816	E5E236	3556 227997	VERA POPOVA	{"phone": "+70605407847"}
0005434149817	E5E236	5573 685187	STEPAN GRIGOREV	{"phone": "+70849196906"}
0005434149818	06F33A	2284 808995	ALEKSANDR GRIGOREV	{"email": "a_grigorev_081974@postgrespro.ru", "phone": "+70624573471"}
0005434149819	06F33A	8885 467153	ALEKSANDR GERASIMOV	{"phone": "+70654764372"}
0005434149820	ACF879	6025 682851	LIDIYA KOZLOVA	{"phone": "+70655393782"}
0005434149821	ACF879	7272 465378	SERGEY ZAKHAROV	{"phone": "+70896389332"}
0005434149822	E4D45E	5513 619337	KONSTANTIN ALEKSANDROV	{"email": "aleksandrov.konstantin.081967@postgrespro.ru", "phone": "+70738043367"}
0005434149823	E4D45E	6337 933378	SERGEY FILIPPOV	{"email": "filippov-sergey.13051961@postgrespro.ru", "phone": "+70374015694"}
0005434149824	E4D45E	5552 078905	LYUDMILA SMIRNOVA	{"phone": "+70522961379"}
0005434149825	5EB1AF	3389 877721	DMITRIY SOROKIN	{"email": "sorokind-091973@postgrespro.ru", "phone": "+70541663592"}
0005434149826	5EB1AF	4485 529605	MARIYA MAKAROVA	{"phone": "+70770552179"}
0005434149827	48ED36	1790 433624	NIKOLAY POPOV	{"email": "nikolay_popov-061976@postgrespro.ru", "phone": "+70542721798"}
0005434149828	48ED36	0373 911038	VIKTOR IVANOV	{"email": "ivanov-viktor30041979@postgrespro.ru", "phone": "+70462963536"}
0005434149829	48ED36	2366 537789	RASUL KONOVALOV	{"phone": "+70476823963"}
0005434149830	424434	5899 776060	NINA MOISEEVA	{"phone": "+70197953817"}
0005434149831	BD8053	8053 346084	DMITRIY MEDVEDEV	{"phone": "+70432294276"}
0005434149832	BD8053	8521 838563	SVETLANA BOGDANOVA	{"email": "svetlana-bogdanova.04021983@postgrespro.ru", "phone": "+70601890386"}
0005434149833	907BE5	2287 097483	IRINA IVANOVA	{"email": "irinaivanova_1978@postgrespro.ru", "phone": "+70482362905"}
0005434149834	907BE5	2031 069080	ELENA KOMAROVA	{"email": "komarova_e_1970@postgrespro.ru", "phone": "+70215278612"}
0005434149835	145AE9	7685 073998	SERGEY ZAYCEV	{"phone": "+70843367864"}
0005434149836	43CACF	9408 893197	ALEKSEY FROLOV	{"phone": "+70842755009"}
0005434149837	788A40	8818 443730	ALLA BELYAEVA	{"phone": "+70803895071"}
0005434149838	4AD659	6648 670367	DARYA RYABOVA	{"phone": "+70216827497"}
0005434149839	ACB4FA	2021 499126	GALINA RODIONOVA	{"email": "galina-rodionova.071977@postgrespro.ru", "phone": "+70388310412"}
0005434149840	25BEC3	3622 367743	VALENTIN ALEKSANDROV	{"email": "valentin-aleksandrov_25041961@postgrespro.ru", "phone": "+70220203031"}
0005434149841	9947CA	8924 011748	BORIS SCHERBAKOV	{"phone": "+70804860796"}
0005434149842	B4967B	1506 069676	VALENTIN PAVLOV	{"phone": "+70141544392"}
0005434149843	B8D7AF	2469 503667	MARIYA SERGEEVA	{"phone": "+70550058831"}
0005434149844	A9BC20	6882 469277	MARAT GERASIMOV	{"email": "marat.gerasimov.1976@postgrespro.ru", "phone": "+70578751807"}
0005434149845	FD11EA	8448 731781	LARISA SIDOROVA	{"phone": "+70444606267"}
0005434149846	74C3F9	8926 658507	VALENTINA KOZLOVA	{"phone": "+70142558922"}
0005434149847	74C3F9	6266 342458	NATALYA BORISOVA	{"email": "n_borisova1979@postgrespro.ru", "phone": "+70084563670"}
0005434149848	710D29	3071 225368	IRINA KONDRATEVA	{"email": "kondrateva.i-1968@postgrespro.ru", "phone": "+70161772968"}
0005434149849	710D29	1300 114729	ALEKSANDR KOZLOV	{"phone": "+70325935949"}
0005434149850	710D29	8877 408867	VIKTORIYA LEBEDEVA	{"email": "vlebedeva.28071971@postgrespro.ru", "phone": "+70383156656"}
0005434149851	183750	3927 745079	DANIIL KUZMIN	{"phone": "+70883646455"}
0005434149852	4AF811	5710 270591	IGOR MATVEEV	{"email": "matveev_i1982@postgrespro.ru", "phone": "+70178622583"}
0005434149853	69E556	7474 605367	ANDREY STEPANOV	{"email": "andrey.stepanov.1969@postgrespro.ru", "phone": "+70913898517"}
0005434149854	FB2EAD	8157 416889	ALEKSANDRA DENISOVA	{"email": "a_denisova.1987@postgrespro.ru", "phone": "+70358336587"}
0005434149855	688230	2999 623508	NATALYA PETROVA	{"email": "petrova.n-1960@postgrespro.ru", "phone": "+70876886890"}
0005434149856	AF992D	7626 909159	ALEKSANDR KUZNECOV	{"email": "kuznecova.071981@postgrespro.ru", "phone": "+70093108391"}
0005434149857	08B772	1772 446657	ANASTASIYA MIRONOVA	{"phone": "+70142939978"}
0005434149858	F665BC	2677 380613	VLADIMIR NIKITIN	{"phone": "+70832341669"}
0005434149859	717B8C	7643 758332	ALEKSANDR TARASOV	{"phone": "+70233430952"}
0005434149860	09684A	8767 529229	IRINA TIKHONOVA	{"phone": "+70515748879"}
0005434149861	09684A	5951 915077	ELENA KULIKOVA	{"phone": "+70440682089"}
0005434149862	09684A	7452 508959	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov-25121979@postgrespro.ru", "phone": "+70569207100"}
0005434149863	89A8DA	9031 393130	ELIZAVETA VOLKOVA	{"email": "e_volkova-21111978@postgrespro.ru", "phone": "+70338110324"}
0005434149864	178EEE	2695 855321	ALINA SAVELEVA	{"email": "alina.saveleva.1972@postgrespro.ru", "phone": "+70116952568"}
0005434149865	9FBFD7	3678 020211	NATALYA OSIPOVA	{"phone": "+70275334483"}
0005434149866	9FBFD7	0331 891131	ANTON MATVEEV	{"email": "a_matveev-1957@postgrespro.ru", "phone": "+70684375451"}
0005434149867	1B839D	7332 765075	MARIYA MELNIKOVA	{"phone": "+70326761805"}
0005434149868	985902	1239 841029	ANDREY SCHERBAKOV	{"email": "scherbakov-andrey-17051975@postgrespro.ru", "phone": "+70843914422"}
0005434149869	93AC0F	9887 245611	LYUDMILA ROMANOVA	{"phone": "+70968489229"}
0005434149870	93AC0F	3750 552332	TAMARA FOMINA	{"phone": "+70564902292"}
0005434149871	FE78AF	7706 010378	LYUDMILA SOLOVEVA	{"phone": "+70018569144"}
0005434149872	FE78AF	7741 759862	MARIYA POPOVA	{"phone": "+70775372631"}
0005434149873	5C9D25	0883 071060	LIDIYA SOKOLOVA	{"email": "sokolova.l.14031970@postgrespro.ru", "phone": "+70698747482"}
0005434149874	2FBA28	0035 185852	SERGEY FROLOV	{"email": "frolov.s_1972@postgrespro.ru", "phone": "+70100319560"}
0005434149875	56D45F	0899 526800	MAKSIM MELNIKOV	{"email": "melnikovm1965@postgrespro.ru", "phone": "+70614218195"}
0005434149876	1D74D1	2617 521741	DANIL KAZAKOV	{"phone": "+70499788114"}
0005434149877	0E21F9	7314 853255	MARIYA VASILEVA	{"phone": "+70290973742"}
0005434149878	94B69F	6254 429488	VYACHESLAV IVANOV	{"phone": "+70130116966"}
0005434149879	94B69F	3629 000516	ANTONINA VOROBEVA	{"phone": "+70737126292"}
0005434149880	69B85C	1551 979749	OLGA MASLOVA	{"phone": "+70241714673"}
0005434149881	69B85C	4875 108230	NINA OSIPOVA	{"email": "n-osipova-16051977@postgrespro.ru", "phone": "+70486058601"}
0005434149882	6186A3	6167 885375	SVETLANA MOROZOVA	{"phone": "+70821030119"}
0005434149883	6186A3	1157 989744	NATALYA MIKHAYLOVA	{"email": "n_mikhaylova-09101977@postgrespro.ru", "phone": "+70513032921"}
0005434149884	E379B2	9960 995849	ANTONINA MAKAROVA	{"email": "antonina_makarova061968@postgrespro.ru", "phone": "+70657045841"}
0005434149885	E379B2	2608 508522	NIKITA KUZNECOV	{"email": "n-kuznecov.25111967@postgrespro.ru", "phone": "+70397233198"}
0005434149886	02E5FE	8403 736259	ALEKSANDR VASILEV	{"phone": "+70319891353"}
0005434149887	02E5FE	3513 187594	YULIYA LUKYANOVA	{"phone": "+70221219360"}
0005434149888	52B6F2	4367 240477	NATALYA ANTONOVA	{"phone": "+70259780736"}
0005434149889	EBA71E	3360 746451	NADEZHDA SAVELEVA	{"phone": "+70907445594"}
0005434149890	D7D226	9047 237394	PETR KOZLOV	{"phone": "+70883802194"}
0005434149891	82C6FB	0777 948560	NADEZHDA ANISIMOVA	{"phone": "+70516960518"}
0005434149892	266C2B	6591 431305	GALINA PETROVA	{"email": "gpetrova-1968@postgrespro.ru", "phone": "+70959733458"}
0005434149893	266C2B	6645 315150	GALINA TIMOFEEVA	{"phone": "+70617107541"}
0005434149894	266C2B	1793 652793	ANATOLIY ALEKSEEV	{"phone": "+70745925634"}
0005434149895	29FBCA	2334 211529	ILYA TARASOV	{"phone": "+70143794362"}
0005434149896	29FBCA	1010 620891	OKSANA KOZLOVA	{"phone": "+70839020659"}
0005434149897	29FBCA	7473 037472	ALEKSANDR ORLOV	{"phone": "+70490741202"}
0005434149898	DC2597	6643 883811	NATALYA NIKITINA	{"phone": "+70377453494"}
0005434149899	DC2597	4586 484760	GALINA ZAKHAROVA	{"email": "galina_zakharova17021971@postgrespro.ru", "phone": "+70967179860"}
0005434149900	9567D6	4813 828879	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin-061970@postgrespro.ru", "phone": "+70150920675"}
0005434149901	9567D6	5785 729915	ILYA ORLOV	{"email": "orlov_i.071971@postgrespro.ru", "phone": "+70656509699"}
0005434149902	7B8F80	7870 166905	VALENTINA ROMANOVA	{"phone": "+70688962538"}
0005434149903	5B71A1	5745 483839	MARIYA ILINA	{"phone": "+70549560946"}
0005434149904	5B71A1	5683 635268	ARTEM MAKAROV	{"email": "makarov-artem_25071969@postgrespro.ru", "phone": "+70262119643"}
0005434149905	3BE634	5507 243220	VERA GRISHINA	{"email": "vera.grishina-1973@postgrespro.ru", "phone": "+70025573421"}
0005434149906	3BE634	9615 760938	TAMARA AFANASEVA	{"email": "tamara.afanaseva-091964@postgrespro.ru", "phone": "+70708540502"}
0005434149907	6D740C	5950 122749	GALINA KOROLEVA	{"phone": "+70961599346"}
0005434149908	59B2D2	5638 471538	NIKOLAY SOROKIN	{"phone": "+70980632783"}
0005434149909	854154	5190 822369	OLGA KUZNECOVA	{"phone": "+70364753161"}
0005434149910	854154	0436 776396	SHAMIL PETROV	{"phone": "+70189909998"}
0005434149911	06FE9E	8711 416509	TATYANA SEMENOVA	{"phone": "+70859220950"}
0005434149912	C7A6EE	6335 022294	IVAN KOROLEV	{"email": "i_korolev28091973@postgrespro.ru", "phone": "+70507835107"}
0005434149913	C7A6EE	0805 126293	SERGEY KUZNECOV	{"phone": "+70770125479"}
0005434149914	65E600	3409 186292	ALEKSEY VASILEV	{"email": "vasilev_aleksey_021971@postgrespro.ru", "phone": "+70408603206"}
0005434149915	D09395	1120 257124	VALENTINA FOMINA	{"phone": "+70246657323"}
0005434149916	D09395	3567 373919	GENNADIY BARANOV	{"email": "baranovg_1967@postgrespro.ru", "phone": "+70396126673"}
0005434149917	D09395	5808 864478	VYACHESLAV POPOV	{"phone": "+70428945072"}
0005434149918	393DB2	5772 683721	MAYYA KISELEVA	{"phone": "+70042685102"}
0005434149919	ABC774	2286 588191	DARINA ILINA	{"phone": "+70412155931"}
0005434149920	8A81EB	4505 135063	ALEKSANDR NOVIKOV	{"phone": "+70553745141"}
0005434149921	CA342F	3518 291477	YULIYA FADEEVA	{"phone": "+70714392306"}
0005434149922	CA342F	5930 019842	ALEKSANDR KUZNECOV	{"phone": "+70071945231"}
0005434149923	CA342F	9813 678975	TAMARA FEDOROVA	{"phone": "+70283354742"}
0005434149924	302E73	4421 544325	ALEKSANDR VOROBEV	{"phone": "+70609429433"}
0005434149925	6D7916	0970 265967	VLADIMIR BELOV	{"email": "belov.v_01101970@postgrespro.ru", "phone": "+70970786296"}
0005434149926	6D7916	6240 841370	VIKTORIYA BORISOVA	{"email": "vborisova_031977@postgrespro.ru", "phone": "+70747561951"}
0005434149927	DB4807	3166 497384	PAVEL VOROBEV	{"email": "p-vorobev_011973@postgrespro.ru", "phone": "+70402593045"}
0005434149928	EA8743	1353 439238	OLGA KONOVALOVA	{"phone": "+70815840843"}
0005434149929	EA8743	4101 047183	ALEKSANDRA IVANOVA	{"phone": "+70117717483"}
0005434149930	1F654B	5207 308617	TATYANA KUZNECOVA	{"email": "kuznecova_t031969@postgrespro.ru", "phone": "+70836957374"}
0005434149931	FE1B10	4119 932445	TATYANA ZHURAVLEVA	{"email": "tatyana-zhuravleva1980@postgrespro.ru", "phone": "+70687263940"}
0005434149932	FE1B10	7857 855673	TAMARA KOROLEVA	{"email": "tkoroleva1980@postgrespro.ru", "phone": "+70871198051"}
0005434149933	FE1B10	0152 471611	SVETLANA SCHERBAKOVA	{"email": "scherbakova-s061974@postgrespro.ru", "phone": "+70687278320"}
0005434149934	390CC5	3306 558357	OLGA MOISEEVA	{"phone": "+70777156015"}
0005434149935	D53D3C	9423 413179	RAISA NIKITINA	{"phone": "+70119456609"}
0005434149936	C2E8EF	4762 532042	VIKTORIYA MELNIKOVA	{"phone": "+70170420442"}
0005434149937	CD6DA0	5351 498853	ALENA IVANOVA	{"email": "alenaivanova_14011978@postgrespro.ru", "phone": "+70924801950"}
0005434149938	0859EC	7132 908453	YULIYA TARASOVA	{"phone": "+70347380215"}
0005434149939	4A20F6	3793 028724	VALENTINA NESTEROVA	{"email": "nesterova-v1978@postgrespro.ru", "phone": "+70816999507"}
0005434149940	04EDD0	2549 261493	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova_031975@postgrespro.ru", "phone": "+70014927091"}
0005434149941	04EDD0	6889 451755	ALEKSANDR IVANOV	{"email": "ivanov_a.25081980@postgrespro.ru", "phone": "+70077879330"}
0005434149942	C3A194	0444 474911	ANASTASIYA SIDOROVA	{"phone": "+70214190533"}
0005434149943	C3A194	9343 694522	ANNA BORISOVA	{"email": "a.borisova.1975@postgrespro.ru", "phone": "+70790520267"}
0005434149944	3C775F	0348 378849	VALENTINA FEDOROVA	{"phone": "+70820011096"}
0005434149945	3C775F	8673 636620	KIRILL FILIPPOV	{"email": "filippovk.091972@postgrespro.ru", "phone": "+70934191191"}
0005434149946	3C775F	6488 411188	DARYA POPOVA	{"phone": "+70782762532"}
0005434149947	B12960	0344 245619	OLGA PETROVA	{"phone": "+70905669655"}
0005434149948	B12960	9749 198972	IRINA KALININA	{"phone": "+70705807583"}
0005434149949	FE4E3F	8391 727138	OLESYA MELNIKOVA	{"phone": "+70078925272"}
0005434149950	5F86D0	8149 684111	IVAN GAVRILOV	{"phone": "+70643302691"}
0005434149951	04F9CB	3882 696159	MIKHAIL PAVLOV	{"phone": "+70721503243"}
0005434150064	A886E2	2012 617864	MARIYA GAVRILOVA	{"phone": "+70182107473"}
0005434149952	04F9CB	4275 056894	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev.22051976@postgrespro.ru", "phone": "+70218804042"}
0005434149953	F6493C	9525 019195	TIMOFEY PAVLOV	{"email": "pavlov-timofey-18071976@postgrespro.ru", "phone": "+70333596483"}
0005434149954	F6493C	4776 824068	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov_1970@postgrespro.ru", "phone": "+70391775658"}
0005434149955	9515EB	7096 934615	ANASTASIYA SAVELEVA	{"email": "savelevaanastasiya061982@postgrespro.ru", "phone": "+70987428315"}
0005434149956	6B5F1D	9129 713032	VLADIMIR ANDREEV	{"email": "andreev.v.09101980@postgrespro.ru", "phone": "+70231968940"}
0005434149957	4690CA	6967 956741	ANNA ANDREEVA	{"email": "andreeva-anna1981@postgrespro.ru", "phone": "+70192301310"}
0005434149958	27A454	8208 416458	VALENTINA ZOTOVA	{"email": "zotova_valentina.1980@postgrespro.ru", "phone": "+70396398346"}
0005434149959	BFDD15	4080 844364	IRINA NESTEROVA	{"phone": "+70148546040"}
0005434149960	2F3944	3424 867310	YULIYA OSIPOVA	{"phone": "+70663604508"}
0005434149961	6EB626	6720 683034	VASILIY SMIRNOV	{"email": "smirnov_v.1966@postgrespro.ru", "phone": "+70518901718"}
0005434149962	6EB626	8909 487402	GALINA SERGEEVA	{"phone": "+70217740724"}
0005434149963	08FC70	2862 317979	ALEKSEY FEDOTOV	{"email": "fedotov_a_1971@postgrespro.ru", "phone": "+70591536672"}
0005434149964	08FC70	3892 362927	VALENTINA ZAYCEVA	{"email": "v.zayceva-041972@postgrespro.ru", "phone": "+70959397088"}
0005434149965	C9125F	1534 532968	TATYANA IVANOVA	{"email": "ivanova.t.10011978@postgrespro.ru", "phone": "+70245721395"}
0005434149966	65741C	2520 018864	GALINA MATVEEVA	{"phone": "+70626018047"}
0005434149967	65741C	6062 294995	DMITRIY FEDOROV	{"phone": "+70298350634"}
0005434149968	78A072	0289 505276	OLESYA KOZLOVA	{"email": "olesya.kozlova02101963@postgrespro.ru", "phone": "+70912492489"}
0005434149969	FA38FA	3961 654462	RASIM KOZLOV	{"phone": "+70020110679"}
0005434149970	565EA3	5075 076436	IGOR DENISOV	{"phone": "+70049278169"}
0005434149971	DEE78E	4697 515946	LIDIYA YAKOVLEVA	{"phone": "+70273889228"}
0005434149972	B5EF58	9277 215890	EKATERINA ROMANOVA	{"email": "ekaterina.romanova_021968@postgrespro.ru", "phone": "+70957993420"}
0005434149973	B5EF58	0907 789527	ANNA ANTONOVA	{"phone": "+70780246924"}
0005434149974	58DA95	8819 304793	GRIGORIY ROMANOV	{"phone": "+70005633394"}
0005434149975	46C823	1308 706676	VIKTOR CHERNOV	{"phone": "+70257471066"}
0005434149976	902F1F	7812 716257	VALENTINA SMIRNOVA	{"phone": "+70625431284"}
0005434149977	902F1F	9724 861661	OLGA TIKHONOVA	{"email": "o.tikhonova_22111960@postgrespro.ru", "phone": "+70978620497"}
0005434149978	C62325	0814 837670	DMITRIY ILIN	{"email": "d_ilin-1961@postgrespro.ru", "phone": "+70087347401"}
0005434149979	7288A9	1968 630885	SERGEY FILIPPOV	{"phone": "+70467859842"}
0005434149980	7288A9	9939 688385	ANDREY IVANOV	{"email": "andrey_ivanov081976@postgrespro.ru", "phone": "+70842768414"}
0005434149981	A3AA3E	3394 572089	VARVARA IVANOVA	{"phone": "+70974618878"}
0005434149982	76C029	7247 575867	OLGA STEPANOVA	{"phone": "+70875084313"}
0005434149983	67E27A	8744 875565	IRINA ZOTOVA	{"email": "zotovai-021955@postgrespro.ru", "phone": "+70259999897"}
0005434149984	C6A26F	2860 712818	VALENTINA RODIONOVA	{"email": "v.rodionova15041971@postgrespro.ru", "phone": "+70654271806"}
0005434149985	C6A26F	0420 560837	VASILIY SOLOVEV	{"phone": "+70685222070"}
0005434149986	85E133	4281 544699	ELENA SMIRNOVA	{"phone": "+70162865628"}
0005434149987	10A50D	4980 572025	TATYANA PETROVA	{"email": "petrova_tatyana.29051978@postgrespro.ru", "phone": "+70769172198"}
0005434149988	10A50D	5342 912758	VENERA MIRONOVA	{"phone": "+70654864862"}
0005434149989	69B96A	8222 151916	ALEKSEY FROLOV	{"email": "frolov-aleksey1966@postgrespro.ru", "phone": "+70683906546"}
0005434149990	69B96A	0676 958715	SERGEY VLASOV	{"email": "sergey_vlasov_121978@postgrespro.ru", "phone": "+70698251276"}
0005434149991	69B96A	4813 059489	MAKSIM ORLOV	{"email": "orlov.maksim_1968@postgrespro.ru", "phone": "+70230457977"}
0005434149992	69B96A	6253 116714	ANDREY EGOROV	{"email": "egorova-22081961@postgrespro.ru", "phone": "+70042613849"}
0005434149993	02A067	9660 719809	TATYANA POPOVA	{"email": "popova_tatyana.1968@postgrespro.ru", "phone": "+70232154345"}
0005434149994	8E04F7	7064 064803	ALEKSANDR NAZAROV	{"email": "nazarov.a021973@postgrespro.ru", "phone": "+70430469056"}
0005434149995	5D8272	7154 599218	ELENA IVANOVA	{"email": "ivanova_elena_18051978@postgrespro.ru", "phone": "+70328501632"}
0005434149996	7199D2	2521 636395	NATALYA AFANASEVA	{"phone": "+70079588159"}
0005434149997	1A8274	5796 738344	ZINAIDA SCHERBAKOVA	{"email": "scherbakova.z.1972@postgrespro.ru", "phone": "+70881608279"}
0005434149998	879ECA	1376 163303	IRINA FOMINA	{"phone": "+70836720862"}
0005434149999	1ED3F6	5777 431715	ELENA KRASNOVA	{"phone": "+70423029221"}
0005434150000	1ED3F6	8105 652943	IVAN SCHERBAKOV	{"email": "scherbakov-ivan-1970@postgrespro.ru", "phone": "+70505915664"}
0005434150001	6A6C25	4901 204665	ANNA OVCHINNIKOVA	{"email": "anna.ovchinnikova-17101971@postgrespro.ru", "phone": "+70816059000"}
0005434150002	6A6C25	3363 252682	ELENA MOROZOVA	{"email": "elena.morozova.1970@postgrespro.ru", "phone": "+70444059892"}
0005434150003	3A3C35	2771 789097	ANTON KARPOV	{"email": "akarpov-1972@postgrespro.ru", "phone": "+70286575739"}
0005434150004	3A3C35	0523 230458	PETR EGOROV	{"phone": "+70174911303"}
0005434150005	AF7049	4699 918969	MARINA LEBEDEVA	{"phone": "+70234341948"}
0005434150006	859B37	5891 916047	OLGA IVANOVA	{"phone": "+70837291819"}
0005434150007	859B37	9719 912104	ANTONINA DAVYDOVA	{"phone": "+70853910088"}
0005434150008	731AA8	8477 331686	VYACHESLAV ANTONOV	{"email": "antonov_v_021959@postgrespro.ru", "phone": "+70865351293"}
0005434150009	151081	7888 185937	OKSANA DMITRIEVA	{"phone": "+70127007145"}
0005434150010	151081	0299 579680	OKSANA KUZNECOVA	{"email": "kuznecovaoksana1981@postgrespro.ru", "phone": "+70934763674"}
0005434150011	DFE44F	9961 764194	IVAN NAZAROV	{"email": "nazarov.ivan1958@postgrespro.ru", "phone": "+70340829575"}
0005434150012	DFE44F	2356 109447	ALEKSANDRA ANDREEVA	{"phone": "+70071945173"}
0005434150013	748D47	5099 034385	ALEKSANDR BARANOV	{"phone": "+70586358902"}
0005434150014	748D47	7374 707083	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov-1974@postgrespro.ru", "phone": "+70639530433"}
0005434150015	4E1E08	5809 414908	ALINA ALEKSANDROVA	{"email": "aleksandrova.alina11081963@postgrespro.ru", "phone": "+70573498127"}
0005434150016	4E1E08	6439 291890	SVETLANA ROMANOVA	{"email": "s_romanova29071968@postgrespro.ru", "phone": "+70553237623"}
0005434150017	A3D175	5572 652616	VLADIMIR GERASIMOV	{"phone": "+70073560083"}
0005434150018	A3D175	2617 869985	SERGEY SOKOLOV	{"phone": "+70808213549"}
0005434150019	8DE6EA	2632 728106	ANDREY VOLKOV	{"email": "volkov-a.21081973@postgrespro.ru", "phone": "+70861440709"}
0005434150020	065BAF	6781 178998	ALEKSEY KAZAKOV	{"email": "alekseykazakov1970@postgrespro.ru", "phone": "+70405905907"}
0005434150021	065BAF	1265 258087	GALINA IVANOVA	{"email": "ivanova.galina-09021969@postgrespro.ru", "phone": "+70995021141"}
0005434150022	90B281	2317 797870	VLADIMIR SCHERBAKOV	{"phone": "+70334642698"}
0005434150023	A7EF42	5092 437700	ALBINA VASILEVA	{"phone": "+70453485042"}
0005434150024	A813F7	9749 513694	NIKOLAY IVANOV	{"phone": "+70464024997"}
0005434150025	1803EB	3955 714716	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.nikolay_1964@postgrespro.ru", "phone": "+70079040391"}
0005434150026	1F12F8	1132 789098	SERGEY MAKAROV	{"phone": "+70244831400"}
0005434150027	1F12F8	3477 622796	ANATOLIY SMIRNOV	{"phone": "+70020126629"}
0005434150028	1F12F8	8447 829468	VALERIY SOKOLOV	{"email": "sokolov_v-30111967@postgrespro.ru", "phone": "+70595615915"}
0005434150029	649576	8267 552503	DMITRIY SEMENOV	{"email": "d.semenov_091988@postgrespro.ru", "phone": "+70782017364"}
0005434150030	649576	0350 557204	ANNA OSIPOVA	{"phone": "+70711003493"}
0005434150031	1AE823	2136 299713	ROMAN ROMANOV	{"phone": "+70527206515"}
0005434150032	E148B7	4786 838971	GULFIYA FEDOROVA	{"phone": "+70636278000"}
0005434150033	650304	3274 872124	TIMUR SEMENOV	{"phone": "+70940889888"}
0005434150034	650304	2129 136037	NADEZHDA MIRONOVA	{"email": "n_mironova.051965@postgrespro.ru", "phone": "+70929574312"}
0005434150035	913C3A	3175 368219	EKATERINA ALEKSANDROVA	{"phone": "+70520713721"}
0005434150036	913C3A	4333 983343	NADEZHDA TROFIMOVA	{"phone": "+70497791210"}
0005434150037	913C3A	6999 955636	NIKOLAY POPOV	{"phone": "+70380315736"}
0005434150038	913C3A	7860 355110	DMITRIY MOROZOV	{"phone": "+70047314610"}
0005434150039	86EDE0	0302 208443	ZINAIDA MIKHAYLOVA	{"phone": "+70018646975"}
0005434150040	86EDE0	9469 196965	SVETLANA EGOROVA	{"email": "egorovasvetlana_29091963@postgrespro.ru", "phone": "+70047536332"}
0005434150041	86EDE0	2191 839590	LYUDMILA KOMAROVA	{"phone": "+70819558638"}
0005434150042	73D6F8	9593 021048	PAVEL NAUMOV	{"email": "pavelnaumov1965@postgrespro.ru", "phone": "+70820304078"}
0005434150043	73D6F8	3571 735702	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova_anastasiya.041971@postgrespro.ru", "phone": "+70893671989"}
0005434150044	73D6F8	9786 805701	ALEKSANDR KUZNECOV	{"phone": "+70847572734"}
0005434150045	AD6832	5304 570321	VIKTOR OSIPOV	{"email": "viktor-osipov-30061979@postgrespro.ru", "phone": "+70483505081"}
0005434150046	633D44	9316 944201	ALEKSANDRA NESTEROVA	{"phone": "+70961174475"}
0005434150047	C4CD44	1032 951949	YULIYA SMIRNOVA	{"email": "smirnova_y.24071970@postgrespro.ru", "phone": "+70428677159"}
0005434150048	98EA25	9358 250168	ALEKSANDR KUZMIN	{"phone": "+70233333737"}
0005434150049	3B1F0A	4016 660948	ARSENIY KOROLEV	{"email": "korolev-arseniy-091970@postgrespro.ru", "phone": "+70647520105"}
0005434150050	A7A425	3566 670971	LYUBOV GORBUNOVA	{"email": "l.gorbunova_1959@postgrespro.ru", "phone": "+70426811101"}
0005434150051	86954C	3980 860038	LIDIYA GUSEVA	{"email": "guseva.lidiya-1970@postgrespro.ru", "phone": "+70603960067"}
0005434150052	E16D7A	6639 602796	ANDREY IVANOV	{"phone": "+70249945382"}
0005434150053	A51BFC	8395 046884	ALEKSANDR ROMANOV	{"email": "a_romanov_1972@postgrespro.ru", "phone": "+70596096837"}
0005434150054	9C2E24	2904 416857	OLGA SERGEEVA	{"email": "sergeeva-o-14071977@postgrespro.ru", "phone": "+70592206697"}
0005434150055	9C2E24	4534 753681	NELLYA ZAKHAROVA	{"email": "n_zakharova1981@postgrespro.ru", "phone": "+70916053394"}
0005434150056	74A4F9	5010 039710	VERA MEDVEDEVA	{"phone": "+70748944872"}
0005434150057	82A976	1368 575769	DANILA GAVRILOV	{"email": "gavrilov.danila1972@postgrespro.ru", "phone": "+70245388926"}
0005434150058	553599	9522 948498	ZOYA TARASOVA	{"email": "z_tarasova-1966@postgrespro.ru", "phone": "+70859156950"}
0005434150059	553599	6526 437379	ANASTASIYA POTAPOVA	{"phone": "+70306392126"}
0005434150060	540E5F	6626 180973	MAKSIM VASILEV	{"phone": "+70941520493"}
0005434150061	540E5F	6818 504451	LILIYA IVANOVA	{"email": "ivanova-liliya.1966@postgrespro.ru", "phone": "+70393542631"}
0005434150062	540E5F	6256 887146	SERGEY GERASIMOV	{"email": "sergey.gerasimov031954@postgrespro.ru", "phone": "+70180817411"}
0005434150063	A886E2	7854 718027	GULNAZ KRASNOVA	{"email": "gulnaz.krasnova-101970@postgrespro.ru", "phone": "+70034031068"}
0005434150065	A886E2	0520 569347	TIMUR SOLOVEV	{"phone": "+70131057682"}
0005434150066	EB2D61	2189 604430	MAKSIM GRIGOREV	{"email": "grigorev_m041958@postgrespro.ru", "phone": "+70991993090"}
0005434150067	ABF59B	5518 294649	RUSTEM KAZAKOV	{"phone": "+70460482847"}
0005434150068	1FA2CC	3569 209632	GALINA TROFIMOVA	{"phone": "+70340991146"}
0005434150069	8E3795	7932 520963	VLADIMIR PAVLOV	{"phone": "+70022449485"}
0005434150070	DD4251	3906 427510	KIRILL TIKHONOV	{"phone": "+70876038969"}
0005434150071	DD4251	7625 690531	SVETLANA STEPANOVA	{"phone": "+70330497561"}
0005434150072	ABE5BE	3248 071012	ELENA EFIMOVA	{"phone": "+70279105654"}
0005434150073	B9A9B1	1729 495444	NIKOLAY SERGEEV	{"email": "sergeev-n-11021966@postgrespro.ru", "phone": "+70105161228"}
0005434150074	B9A9B1	7413 409484	ALEKSEY BELOV	{"phone": "+70497825822"}
0005434150075	F7338B	9855 203820	SERGEY PAVLOV	{"phone": "+70703799443"}
0005434150076	07FD37	6176 302275	NINA MAKAROVA	{"email": "makarova-nina.1981@postgrespro.ru", "phone": "+70911963818"}
0005434150077	45E799	8756 268668	GENNADIY FROLOV	{"email": "frolov.g.11041964@postgrespro.ru", "phone": "+70664394459"}
0005434150078	0C254C	3871 870038	VERA MARTYNOVA	{"email": "vera_martynova101971@postgrespro.ru", "phone": "+70252066564"}
0005434150079	EB59E5	1007 890672	IRINA SERGEEVA	{"email": "irina-sergeeva071982@postgrespro.ru", "phone": "+70013285318"}
0005434150080	9DAFE4	5941 561270	VADIM TARASOV	{"email": "vtarasov-27121969@postgrespro.ru", "phone": "+70173801444"}
0005434150142	B0A34F	8411 266675	SVETLANA SOKOLOVA	{"email": "s-sokolova.23021973@postgrespro.ru", "phone": "+70993752478"}
0005434150143	519A36	9027 971200	ELVIRA FADEEVA	{"phone": "+70921004087"}
0005434150144	D49988	8100 477158	ALEKSEY VLASOV	{"email": "vlasov_aleksey1977@postgrespro.ru", "phone": "+70282033683"}
0005434150145	12B1D7	2631 632551	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila05071980@postgrespro.ru", "phone": "+70606572583"}
0005434150146	3F8DC0	7325 904247	ALEKSANDR ZAYCEV	{"phone": "+70092686773"}
0005434150147	6A8C8D	5488 173155	ELENA CHERNOVA	{"email": "chernova-e_19011964@postgrespro.ru", "phone": "+70947210851"}
0005434150148	E7ADF4	0199 446177	YURIY FOMIN	{"phone": "+70484705804"}
0005434150149	E7ADF4	7626 677768	PAVEL NAZAROV	{"email": "pnazarov041978@postgrespro.ru", "phone": "+70469184851"}
0005434150150	470A44	7179 944881	VLADIMIR KOZLOV	{"email": "kozlov-v-21111964@postgrespro.ru", "phone": "+70984282405"}
0005434150151	470A44	6799 504980	SERGEY KUDRYASHOV	{"email": "kudryashov.s_21081969@postgrespro.ru", "phone": "+70676256107"}
0005434150152	470A44	9178 189580	MIKHAIL SOLOVEV	{"email": "solovev_mikhail-011978@postgrespro.ru", "phone": "+70363758978"}
0005434150153	75E6E6	6315 821417	NATALYA KOZLOVA	{"email": "n.kozlova_061979@postgrespro.ru", "phone": "+70718337085"}
0005434150154	75E6E6	9020 730984	VIKTOR ZAYCEV	{"email": "zaycevviktor-031966@postgrespro.ru", "phone": "+70818690725"}
0005434150155	34BF51	1894 965375	GENNADIY SOROKIN	{"phone": "+70469508563"}
0005434150156	BD8D18	7168 221474	VLADIMIR POPOV	{"phone": "+70353038238"}
0005434150157	752BCC	5828 912990	VIKTOR SCHERBAKOV	{"phone": "+70297810981"}
0005434150158	0B2E97	4704 446333	PETR SIDOROV	{"phone": "+70256150033"}
0005434150159	4263A4	2344 331361	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay_031961@postgrespro.ru", "phone": "+70610280603"}
0005434150160	80B7B2	9059 695824	KSENIYA SOKOLOVA	{"email": "sokolova-k.081979@postgrespro.ru", "phone": "+70946882406"}
0005434150161	A31309	4224 717017	VLADIMIR DMITRIEV	{"phone": "+70483602911"}
0005434150162	400D19	2448 840263	RAISA SIDOROVA	{"email": "sidorova.r-031979@postgrespro.ru", "phone": "+70767978178"}
0005434150163	400D19	7401 191752	OLGA IVANOVA	{"email": "o-ivanova-1983@postgrespro.ru", "phone": "+70793870885"}
0005434150164	400D19	3915 655672	TAMARA DENISOVA	{"phone": "+70862624731"}
0005434150165	57BA42	2077 797149	ANATOLIY OSIPOV	{"email": "anatoliy-osipov.1965@postgrespro.ru", "phone": "+70413861252"}
0005434150166	57BA42	1779 335520	PAVEL KOZLOV	{"phone": "+70078330254"}
0005434150167	57BA42	0873 115371	TATYANA ROMANOVA	{"phone": "+70705475217"}
0005434150168	CAF26D	7362 675079	DMITRIY VOLKOV	{"email": "volkovdmitriy05041974@postgrespro.ru", "phone": "+70428264381"}
0005434150169	EF0F35	4208 190749	ASIYA ILINA	{"email": "a_ilina-25011967@postgrespro.ru", "phone": "+70493964418"}
0005434150170	F86812	0347 449919	KSENIYA IVANOVA	{"email": "ivanovakseniya.1960@postgrespro.ru", "phone": "+70770229387"}
0005434150171	98344B	0388 950740	GALINA MALYSHEVA	{"email": "malysheva_g.1984@postgrespro.ru", "phone": "+70677347196"}
0005434150172	A9CF2F	6456 390414	DENIS KOZLOV	{"phone": "+70974041060"}
0005434150173	7E8E4B	5416 208921	SERGEY MAKAROV	{"phone": "+70479122218"}
0005434150174	7B9248	4060 309354	ILYA STEPANOV	{"email": "stepanovi.15041971@postgrespro.ru", "phone": "+70562481827"}
0005434150175	8AF9EF	3794 645169	KLAVDIYA IVANOVA	{"phone": "+70803205439"}
0005434150176	8AF9EF	4887 941567	NATALYA ABRAMOVA	{"email": "abramovan.18041971@postgrespro.ru", "phone": "+70022823961"}
0005434150177	649EB4	2441 656583	ALEKSANDR STEPANOV	{"phone": "+70450759197"}
0005434150178	CB3AFD	2253 761672	DMITRIY RODIONOV	{"email": "dmitriy_rodionov-03021985@postgrespro.ru", "phone": "+70688643339"}
0005434150179	2A3749	4359 691362	KRISTINA FROLOVA	{"phone": "+70043436664"}
0005434150180	C7ACAF	2652 087103	MARINA SEMENOVA	{"email": "m_semenova_1964@postgrespro.ru", "phone": "+70565688452"}
0005434150181	1BF1D0	3758 284006	GALINA LAZAREVA	{"phone": "+70050540283"}
0005434150182	6AB317	1676 176427	EVGENIY MARTYNOV	{"phone": "+70816301152"}
0005434150183	7EF13E	2053 135964	ALEKSEY NIKITIN	{"phone": "+70607651918"}
0005434150184	461288	7952 355985	LYUDMILA TARASOVA	{"phone": "+70169239422"}
0005434150185	196B8A	2833 626360	NIKITA KRASNOV	{"email": "nikita.krasnov.071984@postgrespro.ru", "phone": "+70881644752"}
0005434150186	196B8A	2385 158507	IRINA ROMANOVA	{"phone": "+70647545841"}
0005434150187	C39AF1	8153 391631	ALEKSANDR ZAYCEV	{"email": "zaycevaleksandr-1978@postgrespro.ru", "phone": "+70761308791"}
0005434150188	247596	7296 889595	SOFIYA MIRONOVA	{"email": "mironovasofiya.1973@postgrespro.ru", "phone": "+70738157098"}
0005434150189	247596	9461 489041	KARINA NIKOLAEVA	{"email": "karina-nikolaeva1967@postgrespro.ru", "phone": "+70678157375"}
0005434150190	D3CF3E	3035 312474	NELLI MIRONOVA	{"phone": "+70587618075"}
0005434150191	767F8D	1380 557296	ALIYA VLASOVA	{"email": "aliya_vlasova_07031971@postgrespro.ru", "phone": "+70412164426"}
0005434150192	004666	3186 598192	SERGEY GORBUNOV	{"email": "sgorbunov.05121971@postgrespro.ru", "phone": "+70119279543"}
0005434150193	CC763F	1995 465362	IGOR STEPANOV	{"phone": "+70194550700"}
0005434150194	CC763F	1791 664058	ALENA ZAKHAROVA	{"email": "zakharova-a021986@postgrespro.ru", "phone": "+70986958700"}
0005434150195	2D7D57	8248 194865	NATALYA SOKOLOVA	{"phone": "+70218219551"}
0005434150196	2D7D57	4066 310496	NIKOLAY MAKAROV	{"phone": "+70000972723"}
0005434150197	2D7D57	7293 935964	IVAN KUZNECOV	{"email": "kuznecov_ivan.101973@postgrespro.ru", "phone": "+70478909238"}
0005434150198	9BD8A8	1773 255873	ALEKSANDR KOZLOV	{"phone": "+70664331556"}
0005434150199	06B77D	1112 814716	MIKHAIL KUZMIN	{"email": "m.kuzmin.021973@postgrespro.ru", "phone": "+70853887635"}
0005434150200	1FD5BC	5930 762256	GALINA POPOVA	{"email": "popova.galina.051973@postgrespro.ru", "phone": "+70323956853"}
0005434150201	1FD5BC	3506 757666	VLADIMIR ALEKSEEV	{"email": "v_alekseev_1988@postgrespro.ru", "phone": "+70898506424"}
0005434150202	1FD5BC	2081 143618	MARIYA ILINA	{"phone": "+70571983841"}
0005434150203	05183A	5267 394611	SERGEY FROLOV	{"phone": "+70543667099"}
0005434150204	34A648	5329 716114	SERGEY KOZLOV	{"email": "sergey-kozlov_081979@postgrespro.ru", "phone": "+70151084246"}
0005434150205	34A648	5035 162525	DMITRIY DAVYDOV	{"email": "davydov.d_09121973@postgrespro.ru", "phone": "+70357881594"}
0005434150206	020B41	8996 660824	LIDIYA KOZLOVA	{"phone": "+70124679345"}
0005434150207	9D7472	7099 141719	ALBINA TIKHONOVA	{"email": "tikhonova_a_1970@postgrespro.ru", "phone": "+70536560979"}
0005434150208	9D7472	3373 818329	IRINA GUSEVA	{"email": "guseva_irina-1974@postgrespro.ru", "phone": "+70463854089"}
0005434150209	446391	4364 033784	IVAN KOZLOV	{"phone": "+70329640514"}
0005434150210	446391	4301 636173	VLADIMIR MOROZOV	{"phone": "+70265005164"}
0005434150211	A87716	8704 437208	PETR KUZNECOV	{"email": "kuznecov.petr1958@postgrespro.ru", "phone": "+70262849969"}
0005434150212	A87716	8703 892361	OKSANA SMIRNOVA	{"phone": "+70289663453"}
0005434150213	6B8B8D	9019 021894	RAMZIYA SEMENOVA	{"email": "semenova.r_18091965@postgrespro.ru", "phone": "+70458248957"}
0005434150214	C1EDC3	6474 040538	ALEKSEY OSIPOV	{"email": "osipov-aleksey-1963@postgrespro.ru", "phone": "+70289159181"}
0005434150215	B31865	1299 298728	KARINA ZOTOVA	{"email": "zotova.karina_031981@postgrespro.ru", "phone": "+70319532042"}
0005434150216	FF91A3	3167 802214	GENNADIY OSIPOV	{"email": "osipovg051990@postgrespro.ru", "phone": "+70155072654"}
0005434150217	6FC956	8745 692514	NADEZHDA POPOVA	{"phone": "+70567553798"}
0005434150218	577AE6	9279 511391	VADIM KONOVALOV	{"email": "konovalov.vadim101985@postgrespro.ru", "phone": "+70767802632"}
0005434150219	577AE6	8967 571669	ALEKSEY BELOV	{"email": "a.belov_071980@postgrespro.ru", "phone": "+70651386595"}
0005434150220	2E73A8	6004 010038	NATALYA BELYAEVA	{"email": "belyaeva_n.021973@postgrespro.ru", "phone": "+70016966708"}
0005434150221	A829C9	8388 143492	LYUDMILA ZHUKOVA	{"email": "zhukova.lyudmila.28051968@postgrespro.ru", "phone": "+70444405124"}
0005434150222	CD96BA	6357 534970	GENNADIY FROLOV	{"email": "frolovgennadiy_1968@postgrespro.ru", "phone": "+70508137340"}
0005434150223	566B56	3242 886116	ELENA NESTEROVA	{"email": "nesterova_elena.17121983@postgrespro.ru", "phone": "+70797653912"}
0005434150224	E6C9D8	4650 968861	OLGA MATVEEVA	{"phone": "+70769166356"}
0005434150225	E6C9D8	5975 086051	TATYANA STEPANOVA	{"phone": "+70903514597"}
0005434150226	9C7C8D	1772 525294	ANASTASIYA ISAEVA	{"phone": "+70718487954"}
0005434150227	9C7C8D	8549 032771	ELENA MAKAROVA	{"phone": "+70303536127"}
0005434150228	EE689D	1909 037802	EVGENIY RODIONOV	{"phone": "+70891348686"}
0005434150229	EE689D	3101 659458	SERGEY KOZLOV	{"email": "sergeykozlov_061969@postgrespro.ru", "phone": "+70750502885"}
0005434150230	B4A0BF	4550 348879	VLADIMIR SERGEEV	{"email": "vsergeev_27071966@postgrespro.ru", "phone": "+70218801265"}
0005434150231	B4A0BF	5147 412642	ANDREY BORISOV	{"email": "borisov.andrey-101975@postgrespro.ru", "phone": "+70175414576"}
0005434150232	BC3343	5308 052544	ULYANA SERGEEVA	{"email": "sergeeva.ulyana.081982@postgrespro.ru", "phone": "+70592668365"}
0005434150233	A9A2B7	9565 625144	VALENTINA KAZAKOVA	{"phone": "+70119145828"}
0005434150234	8AA24A	5574 914140	KIRILL SMIRNOV	{"email": "k_smirnov-11101973@postgrespro.ru", "phone": "+70875093584"}
0005434150235	CE08CD	4346 670181	ELENA ALEKSEEVA	{"email": "alekseeva-elena051976@postgrespro.ru", "phone": "+70211271507"}
0005434150236	AA6688	7635 578206	YURIY VASILEV	{"phone": "+70010270742"}
0005434150237	857D07	7590 930324	SERGEY VASILEV	{"email": "s_vasilev.1968@postgrespro.ru", "phone": "+70319489803"}
0005434150238	857D07	2793 456807	ANATOLIY PAVLOV	{"phone": "+70609011180"}
0005434151707	B36FFE	6543 190702	MARIYA OSIPOVA	{"phone": "+70833743210"}
0005434151654	C661CF	8276 230069	ANATOLIY DENISOV	{"email": "adenisov.1965@postgrespro.ru", "phone": "+70765444326"}
0005434151655	BA2503	0446 846148	SVETLANA RYABOVA	{"phone": "+70518669680"}
0005434151656	FDDE19	0434 354382	NADEZHDA MIKHAYLOVA	{"phone": "+70923485570"}
0005434151657	ECD583	3357 035352	TATYANA DAVYDOVA	{"phone": "+70040006583"}
0005434151658	1979BE	4860 623446	VIKTOR STEPANOV	{"phone": "+70605456114"}
0005434151659	1979BE	9496 281210	ANDREY NIKITIN	{"email": "nikitina-031969@postgrespro.ru", "phone": "+70235121168"}
0005434151660	EBE8B7	1665 366160	MARIYA MELNIKOVA	{"email": "melnikova-m_28041976@postgrespro.ru", "phone": "+70822442706"}
0005434151661	EBE8B7	5550 676902	ALI SOKOLOV	{"phone": "+70808789970"}
0005434151662	6B8F77	4959 697629	MARINA MAKAROVA	{"email": "marina_makarova_10071970@postgrespro.ru", "phone": "+70136526484"}
0005434151663	C210C0	8933 632201	SERGEY PETROV	{"phone": "+70133474220"}
0005434151664	F09F21	5554 621067	ALEKSEY MEDVEDEV	{"email": "medvedev-a_1970@postgrespro.ru", "phone": "+70321623538"}
0005434151665	F09F21	5345 565273	NINA TIMOFEEVA	{"email": "nina-timofeeva-1980@postgrespro.ru", "phone": "+70969925584"}
0005434151666	3A8FA6	9433 226971	PETR KOZLOV	{"email": "p_kozlov-31011966@postgrespro.ru", "phone": "+70674687576"}
0005434151667	A45755	6612 989217	MARIYA STEPANOVA	{"phone": "+70455777307"}
0005434151668	576724	7944 708635	DMITRIY VOLKOV	{"phone": "+70189514289"}
0005434151669	576724	2812 501181	VIKTOR NIKITIN	{"email": "nikitin-viktor-23061972@postgrespro.ru", "phone": "+70659576944"}
0005434151670	C243B6	0476 971955	GRIGORIY STEPANOV	{"phone": "+70125573048"}
0005434151671	C243B6	2451 812155	LYUDMILA VASILEVA	{"email": "lyudmilavasileva.061974@postgrespro.ru", "phone": "+70241309620"}
0005434151672	ED165E	8849 151343	ALEKSANDR GRIGOREV	{"phone": "+70173261622"}
0005434151673	ED165E	4040 302970	ANDREY GAVRILOV	{"email": "a-gavrilov_1975@postgrespro.ru", "phone": "+70153366875"}
0005434151674	134D58	5320 567285	PAVEL SOROKIN	{"email": "psorokin.121966@postgrespro.ru", "phone": "+70804326184"}
0005434151675	04FBF1	0884 815980	IRAIDA SMIRNOVA	{"phone": "+70411973759"}
0005434151676	7F302A	9660 235233	SAMIRA SOKOLOVA	{"phone": "+70406766675"}
0005434151677	8D273C	3406 390740	TATYANA SOKOLOVA	{"phone": "+70727612781"}
0005434151678	B41100	6990 425571	ANATOLIY SOROKIN	{"phone": "+70338055795"}
0005434151679	68FB00	0865 272182	ARTEM OSIPOV	{"phone": "+70306524363"}
0005434151680	E96445	5514 907095	EVGENIY KOROLEV	{"phone": "+70498677237"}
0005434151681	14424F	4146 661362	VYACHESLAV KISELEV	{"phone": "+70259178497"}
0005434151682	14424F	2014 941157	IGOR KOROLEV	{"email": "i.korolev_101965@postgrespro.ru", "phone": "+70202012249"}
0005434151683	FFB788	8778 404629	GALINA KOROLEVA	{"email": "g-koroleva1970@postgrespro.ru", "phone": "+70571074981"}
0005434151684	C5F29C	6836 751592	ELENA DAVYDOVA	{"phone": "+70550796572"}
0005434151685	31C34E	5971 890917	ELENA IVANOVA	{"email": "elenaivanova_04091973@postgrespro.ru", "phone": "+70529563520"}
0005434151686	F6D12E	2530 021133	ELENA KONOVALOVA	{"email": "elena_konovalova081977@postgrespro.ru", "phone": "+70533094317"}
0005434151687	F6D12E	8822 551681	ROMAN KUZNECOV	{"phone": "+70957091705"}
0005434151688	F6D12E	7949 600570	LYUBOV KOROLEVA	{"phone": "+70239453455"}
0005434151689	580F0D	8651 642553	NADEZHDA GRISHINA	{"email": "nadezhdagrishina.1966@postgrespro.ru", "phone": "+70037569795"}
0005434151690	B7F173	1153 498317	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_02051983@postgrespro.ru", "phone": "+70123841734"}
0005434151691	653B4F	6274 494506	SVETLANA VASILEVA	{"email": "vasileva.s1967@postgrespro.ru", "phone": "+70627445799"}
0005434151692	8F6AE6	3436 507630	VALERIY IVANOV	{"phone": "+70395063585"}
0005434151693	555F8A	1617 755648	SVETLANA BELOVA	{"phone": "+70015795091"}
0005434151694	7B6DC3	0177 834329	EVGENIY ISAEV	{"email": "isaev.e.14061961@postgrespro.ru", "phone": "+70847554574"}
0005434151695	1CB240	7030 269268	KSENIYA MIKHAYLOVA	{"phone": "+70974392850"}
0005434151696	1CB240	1787 879707	ANATOLIY TIMOFEEV	{"email": "timofeev_anatoliy_051978@postgrespro.ru", "phone": "+70930536615"}
0005434151697	1CB240	5681 705810	LIDIYA STEPANOVA	{"email": "lstepanova-1976@postgrespro.ru", "phone": "+70494970486"}
0005434151698	AB1BF7	5974 441574	TATYANA DENISOVA	{"email": "t.denisova.011975@postgrespro.ru", "phone": "+70269237573"}
0005434151699	826A9B	9519 149343	MIKHAIL BELOV	{"phone": "+70589322251"}
0005434151700	76C181	4143 488552	VALENTINA ZHUKOVA	{"email": "v_zhukova1973@postgrespro.ru", "phone": "+70269993422"}
0005434151701	76C181	7735 856670	KRISTINA ABRAMOVA	{"email": "abramova-kristina.20011978@postgrespro.ru", "phone": "+70400593922"}
0005434151702	7F8879	4093 159925	ANASTASIYA POPOVA	{"phone": "+70178292379"}
0005434151703	7F8879	0316 334239	LYUBOV KOZLOVA	{"email": "kozlova_lyubov.051969@postgrespro.ru", "phone": "+70073370901"}
0005434151704	AD5B6B	8459 007628	TATYANA MARTYNOVA	{"phone": "+70831145922"}
0005434151705	AD5B6B	4111 488946	KSENIYA FOMINA	{"email": "fominakseniya_1975@postgrespro.ru", "phone": "+70143367991"}
0005434151706	AD5B6B	5746 632166	DAMIR ANDREEV	{"phone": "+70232202634"}
0005434151708	BAA854	3936 605167	ANATOLIY ZAKHAROV	{"phone": "+70576034105"}
0005434151709	2B78DD	3732 734022	ELENA TIMOFEEVA	{"email": "timofeeva.e_1981@postgrespro.ru", "phone": "+70151648477"}
0005434151710	DB355D	2230 915114	YULIYA MAKAROVA	{"phone": "+70023876447"}
0005434151711	6543E9	6722 361444	LARISA MOROZOVA	{"email": "morozova-l.041974@postgrespro.ru", "phone": "+70206573989"}
0005434151712	6543E9	0323 741443	ALENA FEDOROVA	{"email": "fedorova.alena.121983@postgrespro.ru", "phone": "+70856270051"}
0005434151713	FB8C50	4951 866295	NATALIYA ZAKHAROVA	{"email": "zakharova-n031979@postgrespro.ru", "phone": "+70193691357"}
0005434151714	447B49	6856 906841	ELENA MASLOVA	{"phone": "+70877758558"}
0005434151715	447B49	1474 950962	ELENA BELOVA	{"phone": "+70499733360"}
0005434151716	B8176F	6549 052184	LARISA KOZLOVA	{"phone": "+70716990675"}
0005434151717	2AF998	0695 674140	GALINA KOLESNIKOVA	{"phone": "+70153083649"}
0005434151718	11303B	6020 666856	ALEKSANDR STEPANOV	{"phone": "+70530832786"}
0005434151719	2396E6	1028 996029	VLADIMIR OSIPOV	{"email": "v.osipov14101978@postgrespro.ru", "phone": "+70344731216"}
0005434151720	2396E6	9310 699555	PELAGEYA VOLKOVA	{"phone": "+70144424474"}
0005434151721	51AB26	0692 078838	EVGENIYA PETROVA	{"email": "e-petrova_1984@postgrespro.ru", "phone": "+70539314148"}
0005434151722	51AB26	1841 650004	VIKTOR BARANOV	{"email": "v-baranov-26121971@postgrespro.ru", "phone": "+70154782552"}
0005434151723	03E2E8	5882 690489	SERGEY BORISOV	{"phone": "+70623364047"}
0005434151724	F075C4	8785 227143	MIKHAIL ANDREEV	{"phone": "+70251292773"}
0005434151725	46D952	8260 600309	POLINA NIKIFOROVA	{"phone": "+70631050565"}
0005434151726	C06296	3494 503256	VADIM BORISOV	{"phone": "+70087128348"}
0005434151727	C06296	8166 192329	DARYA SOROKINA	{"phone": "+70561309943"}
0005434151728	A618C7	3804 480901	OLEG SCHERBAKOV	{"phone": "+70533389324"}
0005434151729	A618C7	8237 635114	FEDOR KULIKOV	{"phone": "+70644265292"}
0005434151730	DAD759	6542 009661	SERGEY ANTONOV	{"phone": "+70771222502"}
0005434151731	3D7B40	0748 950018	ANGELINA LUKYANOVA	{"phone": "+70873067439"}
0005434151732	0C46E5	5080 364956	LYUBOV GAVRILOVA	{"email": "gavrilova.l26121964@postgrespro.ru", "phone": "+70614212416"}
0005434151733	71B4D0	1161 024116	VITALIY VOROBEV	{"email": "vorobev.vitaliy_1971@postgrespro.ru", "phone": "+70713788880"}
0005434151734	66CF8E	0978 013961	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov09081977@postgrespro.ru", "phone": "+70089977904"}
0005434151735	36B1D5	7583 580044	LYUDMILA KONOVALOVA	{"email": "konovalova.lyudmila.24031967@postgrespro.ru", "phone": "+70462701936"}
0005434151736	36B1D5	8583 212178	VLADIMIR MAKAROV	{"email": "vmakarov.051976@postgrespro.ru", "phone": "+70118444101"}
0005434151737	43E0CF	3186 083909	VITALIY MOISEEV	{"phone": "+70326937362"}
0005434151738	EE42E0	5932 856395	ANDREY SMIRNOV	{"email": "andrey.smirnov.1957@postgrespro.ru", "phone": "+70006067249"}
0005434151739	C26C62	1195 487776	NIKOLAY FEDOROV	{"email": "fedorov.n.07041980@postgrespro.ru", "phone": "+70546590443"}
0005434151740	016195	6415 635333	SERGEY KOZLOV	{"email": "kozlovs-1976@postgrespro.ru", "phone": "+70264675320"}
0005434151741	6598B1	5643 121431	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov22011964@postgrespro.ru", "phone": "+70230149183"}
0005434151742	1FF8D3	8100 763334	NADEZHDA FOMINA	{"phone": "+70126918809"}
0005434151743	B94E61	7057 674557	TATYANA BOGDANOVA	{"email": "bogdanova.tatyana-1968@postgrespro.ru", "phone": "+70102359830"}
0005434151744	C917B7	4672 629664	ALEKSANDR IVANOV	{"email": "a_ivanov.16041968@postgrespro.ru", "phone": "+70297675818"}
0005434151745	79D76D	5517 767021	ANATOLIY KULIKOV	{"email": "a.kulikov_091965@postgrespro.ru", "phone": "+70064922241"}
0005434151746	D3EF8A	5092 005808	DANILA SEMENOV	{"phone": "+70118961329"}
0005434151747	D3EF8A	1029 734489	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin.1977@postgrespro.ru", "phone": "+70189757604"}
0005434151748	210974	4093 486977	NATALYA MEDVEDEVA	{"email": "medvedeva_n021972@postgrespro.ru", "phone": "+70564269648"}
0005434151749	210974	5904 545340	VLADIMIR FEDOROV	{"email": "fedorov.v-1980@postgrespro.ru", "phone": "+70449752521"}
0005434151750	DB460E	0480 295536	VLADIMIR FEDOROV	{"email": "fedorov.v.021980@postgrespro.ru", "phone": "+70883417001"}
0005434151751	A4D585	6639 044245	SERGEY KUZMIN	{"phone": "+70453209958"}
0005434151752	A4D585	8159 445167	VIKTOR KUDRYASHOV	{"email": "viktor_kudryashov16091984@postgrespro.ru", "phone": "+70848750188"}
0005434151753	A4D585	9133 067366	ALEKSANDRA TITOVA	{"phone": "+70223067190"}
0005434151754	B5A5E5	9428 054115	VASILIY SERGEEV	{"email": "v_sergeev_1979@postgrespro.ru", "phone": "+70376395309"}
0005434151755	010CA7	6156 057132	VALENTINA VOROBEVA	{"phone": "+70757471583"}
0005434151756	010CA7	1215 167858	VIKTORIYA SMIRNOVA	{"phone": "+70527694970"}
0005434151757	A6B6E2	9936 618411	ARTUR ILIN	{"phone": "+70414094426"}
0005434151758	A6B6E2	7792 381032	ALENA KALININA	{"phone": "+70769007037"}
0005434151759	3F4648	0376 070648	SVETLANA ZHUKOVA	{"phone": "+70942305389"}
0005434151760	707A09	7256 024128	ANATOLIY KULIKOV	{"email": "kulikovanatoliy11031970@postgrespro.ru", "phone": "+70038278071"}
0005434151761	BBBBBD	3945 892858	ANDREY ILIN	{"email": "ailin-10031980@postgrespro.ru", "phone": "+70699995086"}
0005434151762	EF393D	6861 200799	ANZHELA PAVLOVA	{"email": "anzhela-pavlova.031973@postgrespro.ru", "phone": "+70470678540"}
0005434151763	8E79E9	5282 771803	ANTONINA VASILEVA	{"email": "vasilevaa.1975@postgrespro.ru", "phone": "+70929221376"}
0005434151764	8E79E9	3558 526095	VERA DANILOVA	{"email": "vdanilova.27091967@postgrespro.ru", "phone": "+70513822546"}
0005434151765	8E79E9	2611 722303	ALENA FOMINA	{"phone": "+70190787910"}
0005434151766	70940B	8132 390415	VALERIY ZAYCEV	{"email": "valeriyzaycev-22111967@postgrespro.ru", "phone": "+70166969333"}
0005434151767	70940B	3821 338035	IGOR GRIGOREV	{"email": "grigorev_igor_121979@postgrespro.ru", "phone": "+70996452009"}
0005434151768	5822D7	9219 351635	KRISTINA KARPOVA	{"email": "kkarpova-081974@postgrespro.ru", "phone": "+70533091723"}
0005434151769	5822D7	3018 637164	LIDIYA SERGEEVA	{"phone": "+70253080089"}
0005434151770	6D76A2	2562 975288	SVETLANA TIKHONOVA	{"phone": "+70952150109"}
0005434151771	42B55E	4124 811755	ANATOLIY MAKAROV	{"phone": "+70365414847"}
0005434151772	42B55E	8573 720386	OLEG NOVIKOV	{"email": "novikov_o_1961@postgrespro.ru", "phone": "+70415899248"}
0005434151773	FE9BCE	1974 802599	ALEKSANDR KUZMIN	{"phone": "+70134725153"}
0005434151774	FE9BCE	1232 769906	SERGEY EGOROV	{"email": "s-egorov1976@postgrespro.ru", "phone": "+70226012173"}
0005434151775	C02FE5	0809 464088	MARIYA KUZNECOVA	{"phone": "+70992715027"}
0005434151776	230935	5964 795188	RUSTAM SEMENOV	{"email": "semenov_rustam_1967@postgrespro.ru", "phone": "+70000324001"}
0005434151777	230935	7248 837695	VLADIMIR SERGEEV	{"email": "sergeev-v121963@postgrespro.ru", "phone": "+70836598293"}
0005434151778	230935	7185 986875	VIKTOR KUZMIN	{"email": "v_kuzmin-031967@postgrespro.ru", "phone": "+70395265515"}
0005434151779	230935	1186 332672	ELENA MEDVEDEVA	{"email": "medvedevaelena_1970@postgrespro.ru", "phone": "+70086436871"}
0005434151780	3AF681	2517 207617	YULIYA ZHUKOVA	{"phone": "+70881026747"}
0005434151781	3AF681	7631 138783	OLGA GAVRILOVA	{"phone": "+70711979721"}
0005434151782	EC5927	3518 247960	EDUARD ZHUKOV	{"email": "zhukov-eduard-1975@postgrespro.ru", "phone": "+70401375427"}
0005434151783	EC5927	0176 468110	ANATOLIY MATVEEV	{"phone": "+70144652619"}
0005434151784	FFEFA8	4380 098065	MARINA ISAEVA	{"phone": "+70540929257"}
0005434151785	FFEFA8	3616 359156	ELENA SMIRNOVA	{"email": "smirnova.e_011974@postgrespro.ru", "phone": "+70131268111"}
0005434151786	209FB2	4034 039266	ANDREY ISAEV	{"email": "isaev_andrey-1967@postgrespro.ru", "phone": "+70727736372"}
0005434151787	EEA454	6928 301089	IRINA MELNIKOVA	{"phone": "+70938095388"}
0005434151788	ADC782	4155 470906	NIKOLAY MOROZOV	{"phone": "+70922122008"}
0005434151789	EB4A0A	8126 848914	ALEKSANDR GRIGOREV	{"phone": "+70646701174"}
0005434151790	EB4A0A	6940 711364	IRINA MAKAROVA	{"email": "makarova.i.021979@postgrespro.ru", "phone": "+70016160458"}
0005434151791	9AEF2B	8702 449147	VYACHESLAV AFANASEV	{"phone": "+70775361274"}
0005434151792	9AEF2B	7072 132829	ALEKSANDR KUZMIN	{"phone": "+70518182235"}
0005434151793	52B91C	9073 728308	NADEZHDA FILATOVA	{"email": "filatova_n_1976@postgrespro.ru", "phone": "+70081348976"}
0005434151794	959686	4611 048139	KIRA NAZAROVA	{"email": "k.nazarova_081966@postgrespro.ru", "phone": "+70358691094"}
0005434151795	959686	9825 790858	ALEKSEY KONOVALOV	{"email": "konovalov-a-061975@postgrespro.ru", "phone": "+70745990481"}
0005434151796	091479	5444 243249	ANASTASIYA NIKITINA	{"email": "a.nikitina-1978@postgrespro.ru", "phone": "+70787584453"}
0005434151797	6EA74A	8912 014913	ALEKSEY RODIONOV	{"email": "arodionov.111977@postgrespro.ru", "phone": "+70307175724"}
0005434151798	6EA74A	1264 856165	OLGA MAKAROVA	{"phone": "+70043726829"}
0005434151799	1B664D	5047 479418	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr-08111963@postgrespro.ru", "phone": "+70764439195"}
0005434151800	A7CA08	8434 602558	TATYANA MOROZOVA	{"email": "tatyana-morozova.14021974@postgrespro.ru", "phone": "+70310955756"}
0005434151801	A7CA08	3889 984509	ANDREY NIKITIN	{"email": "nikitin-a-091975@postgrespro.ru", "phone": "+70081903180"}
0005434151802	25EDC5	1772 679513	ELIZAVETA NAZAROVA	{"phone": "+70388951417"}
0005434151803	6C67D2	7523 624409	GALINA FEDOROVA	{"email": "fedorova_g.121962@postgrespro.ru", "phone": "+70716924231"}
0005434151804	6C67D2	4679 940912	VALENTINA DENISOVA	{"phone": "+70480625186"}
0005434151805	33E8B0	4677 913244	ELENA PAVLOVA	{"email": "pavlova.elena.081973@postgrespro.ru", "phone": "+70281244823"}
0005434151806	33E8B0	7977 241253	SERGEY SCHERBAKOV	{"email": "sergey_scherbakov_031971@postgrespro.ru", "phone": "+70699914612"}
0005434151807	33E8B0	2163 195905	VLADIMIR ORLOV	{"phone": "+70720239766"}
0005434151808	05702A	5705 759870	DMITRIY KUZMIN	{"email": "dmitriy-kuzmin.1966@postgrespro.ru", "phone": "+70693835207"}
0005434151809	E83289	9285 818496	ALEKSEY FOMIN	{"phone": "+70726044161"}
0005434151810	59A4D7	6113 678376	ALEKSANDR ORLOV	{"phone": "+70884925511"}
0005434151811	B91351	6953 898036	ELENA KUDRYASHOVA	{"email": "e_kudryashova.14051971@postgrespro.ru", "phone": "+70574409157"}
0005434151812	CCACBB	2022 125364	ELMIRA KOLESNIKOVA	{"phone": "+70599931051"}
0005434151813	3375E8	0662 987885	ELENA ROMANOVA	{"email": "romanova.elena-041988@postgrespro.ru", "phone": "+70482129451"}
0005434151814	7ED39C	0866 150965	DANIL MOISEEV	{"email": "moiseev-danil_011971@postgrespro.ru", "phone": "+70983152663"}
0005434151815	7ED39C	0059 380905	VLADIMIR EGOROV	{"email": "egorov.v-041970@postgrespro.ru", "phone": "+70818557924"}
0005434151816	538363	6871 513802	YULIYA BELOVA	{"email": "y_belova021972@postgrespro.ru", "phone": "+70604637662"}
0005434151817	538363	8574 142244	IRINA TROFIMOVA	{"phone": "+70134872152"}
0005434151818	1E1FC7	5178 234167	NIKOLAY IVANOV	{"email": "ivanov-n-26091970@postgrespro.ru", "phone": "+70949745079"}
0005434151819	1E1FC7	7059 834044	SERGEY MELNIKOV	{"email": "melnikov.s_28011966@postgrespro.ru", "phone": "+70497087766"}
0005434151820	78AC4D	4288 643352	NADEZHDA FILIPPOVA	{"email": "filippova-n091975@postgrespro.ru", "phone": "+70123958200"}
0005434152771	4BF6C2	1667 633610	MARIYA NOVIKOVA	{"phone": "+70973335578"}
0005434152859	A01B19	4960 644383	NADEZHDA MOROZOVA	{"phone": "+70019721156"}
0005434152751	0406EF	1256 338889	IVAN SOLOVEV	{"email": "solovev-i.04011973@postgrespro.ru", "phone": "+70703186390"}
0005434152752	0AF4FA	7144 096059	IRINA ZHUKOVA	{"phone": "+70927349269"}
0005434152753	C0B03C	0580 374634	RINAT FROLOV	{"phone": "+70336395910"}
0005434152754	C0B03C	3724 633912	VLADISLAV TARASOV	{"phone": "+70360683624"}
0005434152755	FE57BC	0468 411059	EVGENIY KUZNECOV	{"email": "evgeniykuznecov.071961@postgrespro.ru", "phone": "+70712467492"}
0005434152756	D88193	3577 477647	ELIZAVETA PAVLOVA	{"email": "elizaveta-pavlova.27061977@postgrespro.ru", "phone": "+70795461491"}
0005434152757	51CCDA	1662 495162	DIANA POPOVA	{"phone": "+70447985993"}
0005434152758	A8F435	7018 250009	ALEKSANDR AFANASEV	{"phone": "+70790025313"}
0005434152759	A8F435	3648 224415	ALEKSANDR ZAYCEV	{"phone": "+70436637675"}
0005434152760	85BF40	1989 255802	MARINA KULIKOVA	{"email": "marina_kulikova_031961@postgrespro.ru", "phone": "+70087830605"}
0005434152761	BBC382	4703 454663	VASILIY YAKOVLEV	{"phone": "+70738309645"}
0005434152762	BBC382	5334 837005	RAISA BARANOVA	{"phone": "+70433647489"}
0005434152763	D85C9B	8249 942949	ANDREY NAZAROV	{"email": "nazarov.andrey_26101971@postgrespro.ru", "phone": "+70389456019"}
0005434152764	D85C9B	2465 706568	VALERIY PETROV	{"phone": "+70597779103"}
0005434152765	8C655C	0161 501762	TATYANA IVANOVA	{"email": "tatyanaivanova-26041978@postgrespro.ru", "phone": "+70792954080"}
0005434152766	0566CB	5879 275702	KRISTINA BORISOVA	{"email": "k_borisova08101964@postgrespro.ru", "phone": "+70577563586"}
0005434152767	D531E0	4390 712302	NIKITA SHEVCHENKO	{"phone": "+70690019795"}
0005434152768	7E904F	7406 545330	ZINAIDA FILIPPOVA	{"phone": "+70215162764"}
0005434152769	7E904F	2642 433764	ELINA KULIKOVA	{"phone": "+70535013289"}
0005434152770	7E904F	5190 968412	LYUDMILA YAKOVLEVA	{"phone": "+70522488611"}
0005434152772	4BE80C	0117 524634	ALEKSEY ROMANOV	{"email": "a-romanov_101978@postgrespro.ru", "phone": "+70309515389"}
0005434152773	4BE80C	7865 168433	LYUDMILA KONOVALOVA	{"phone": "+70706853644"}
0005434152774	13C843	8256 188369	ANDREY KOZLOV	{"email": "kozlov.andrey-071979@postgrespro.ru", "phone": "+70388640588"}
0005434152775	4E4EF6	9237 774669	DMITRIY SERGEEV	{"email": "dmitriy_sergeev_071978@postgrespro.ru", "phone": "+70362224699"}
0005434152776	C0DF40	9346 402947	MAKSIM KARPOV	{"email": "m.karpov-031977@postgrespro.ru", "phone": "+70577349006"}
0005434152777	4A7A54	1352 448538	MAKSIM POPOV	{"email": "maksimpopov_17101971@postgrespro.ru", "phone": "+70527261048"}
0005434152778	E7F8C0	1890 338372	NADEZHDA FILIPPOVA	{"email": "filippovan-1970@postgrespro.ru", "phone": "+70400034786"}
0005434152779	D2DB11	0456 141770	YULIYA GAVRILOVA	{"phone": "+70009150341"}
0005434152780	35F3EF	5236 283657	ANNA KAZAKOVA	{"email": "anna.kazakova031972@postgrespro.ru", "phone": "+70951574762"}
0005434152781	ED48E3	7672 757317	NIKITA PAVLOV	{"email": "nikita-pavlov-121963@postgrespro.ru", "phone": "+70666412273"}
0005434152782	0B0C83	5346 043269	NIKOLAY KUZNECOV	{"phone": "+70873449005"}
0005434152783	132902	8968 641707	VALENTINA KOVALEVA	{"phone": "+70883759396"}
0005434152784	A03797	2674 087403	VALERIYA MATVEEVA	{"email": "matveeva-valeriya-1967@postgrespro.ru", "phone": "+70667950117"}
0005434152785	C1DEEB	1106 912494	OLGA KONOVALOVA	{"email": "okonovalova071976@postgrespro.ru", "phone": "+70780551626"}
0005434152786	C1DEEB	9994 705590	VYACHESLAV POPOV	{"phone": "+70705653575"}
0005434152787	6E6CB3	2317 625702	ANDREY TARASOV	{"email": "a-tarasov29011978@postgrespro.ru", "phone": "+70160433172"}
0005434152788	6E6CB3	3470 832491	NINA ANISIMOVA	{"email": "anisimova.nina_1977@postgrespro.ru", "phone": "+70924404507"}
0005434152789	6E6CB3	3423 929031	ALEKSANDRA GERASIMOVA	{"phone": "+70694250066"}
0005434152790	2BF277	4788 559083	NATALYA ERMAKOVA	{"email": "natalyaermakova-1976@postgrespro.ru", "phone": "+70469107619"}
0005434152791	C1F560	4559 157443	POLINA ANDREEVA	{"phone": "+70734422002"}
0005434152792	C1F560	4477 182510	ELENA STEPANOVA	{"email": "stepanova_elena.1980@postgrespro.ru", "phone": "+70151767974"}
0005434152793	36565C	5080 672634	ALEKSANDRA ARKHIPOVA	{"phone": "+70196910930"}
0005434152794	36565C	7706 065497	VALENTINA MELNIKOVA	{"phone": "+70061075407"}
0005434152795	2F9108	0666 038859	ELENA TIKHONOVA	{"phone": "+70842444331"}
0005434152796	8E60EA	0992 867144	ELENA TIKHONOVA	{"phone": "+70350855662"}
0005434152797	2E8137	3366 993194	ALEKSEY ABRAMOV	{"phone": "+70964964536"}
0005434152798	2E8137	0809 502015	ALEKSANDR SOLOVEV	{"email": "solovev.a_061976@postgrespro.ru", "phone": "+70060313901"}
0005434152799	68D88B	8730 015022	ANASTASIYA STEPANOVA	{"email": "anastasiyastepanova_01111968@postgrespro.ru", "phone": "+70155715088"}
0005434152800	A932A1	0362 294498	LYUDMILA EFREMOVA	{"email": "efremova.lyudmila.22081967@postgrespro.ru", "phone": "+70216136210"}
0005434152801	C90E24	9092 411861	STANISLAV FILIPPOV	{"email": "filippov.stanislav.1967@postgrespro.ru", "phone": "+70532551355"}
0005434152802	C90E24	8909 118070	YULIYA ISAEVA	{"email": "yisaeva.1979@postgrespro.ru", "phone": "+70086062596"}
0005434152803	0D34ED	3901 614367	YULIYA IVANOVA	{"email": "y.ivanova.091971@postgrespro.ru", "phone": "+70342890547"}
0005434152804	255670	2597 984607	EKATERINA LUKYANOVA	{"phone": "+70083928285"}
0005434152805	255670	4048 401802	VIKTORIYA IVANOVA	{"email": "ivanova-v-25111981@postgrespro.ru", "phone": "+70312474412"}
0005434152806	1BD2F9	7623 786334	ELENA BORISOVA	{"email": "elenaborisova-1973@postgrespro.ru", "phone": "+70301323122"}
0005434152807	E8B646	7094 626832	VALENTINA DMITRIEVA	{"phone": "+70220593593"}
0005434152808	E8B646	5028 791443	DARYA KOZLOVA	{"phone": "+70566649268"}
0005434152809	E8B646	7567 366211	ALEKSANDR PETROV	{"email": "petrov_aleksandr.011969@postgrespro.ru", "phone": "+70338717680"}
0005434152810	123047	7184 013082	VASILIY SCHERBAKOV	{"phone": "+70518345187"}
0005434152811	A0B1AF	0579 369380	ALEKSANDR FOMIN	{"email": "aleksandrfomin.081973@postgrespro.ru", "phone": "+70613354519"}
0005434152812	A0B1AF	4043 382595	DMITRIY NIKITIN	{"email": "dmitriynikitin-27071975@postgrespro.ru", "phone": "+70656920193"}
0005434152813	741984	7992 368375	POLINA DMITRIEVA	{"phone": "+70317582949"}
0005434152814	9A4CD5	9876 896397	TATYANA ZAKHAROVA	{"email": "tzakharova-041983@postgrespro.ru", "phone": "+70950287803"}
0005434152815	9B69DF	0975 857739	DANIIL FROLOV	{"phone": "+70735249873"}
0005434152816	32EFED	9984 665129	LYUBOV BELOVA	{"email": "l_belova_12071972@postgrespro.ru", "phone": "+70558614528"}
0005434152817	32EFED	8748 833439	ELENA GORBUNOVA	{"phone": "+70002114619"}
0005434152818	AF4F2D	5928 941478	DMITRIY YAKOVLEV	{"email": "yakovlev.dmitriy.041972@postgrespro.ru", "phone": "+70511638078"}
0005434152819	41E180	2329 375948	VADIM PAVLOV	{"phone": "+70306743328"}
0005434152820	41E180	7821 944193	EVGENIY KISELEV	{"email": "kiselev-e-28061975@postgrespro.ru", "phone": "+70100337783"}
0005434152821	43808E	0307 845282	ALEKSEY SCHERBAKOV	{"phone": "+70059527279"}
0005434152822	65CEFD	2543 123155	OLEG VOLKOV	{"email": "volkov.o_1965@postgrespro.ru", "phone": "+70901139949"}
0005434152823	65CEFD	7590 897333	RAMIS MOISEEV	{"email": "moiseev-r071976@postgrespro.ru", "phone": "+70849117329"}
0005434152824	F9EC7F	1056 428940	TATYANA NIKOLAEVA	{"email": "nikolaeva-t25031971@postgrespro.ru", "phone": "+70522063545"}
0005434152825	87ED62	2740 118538	ELENA MELNIKOVA	{"email": "e_melnikova.121972@postgrespro.ru", "phone": "+70198823368"}
0005434152826	87ED62	6865 209233	LYUDMILA DAVYDOVA	{"phone": "+70100821530"}
0005434152827	5ED15A	7968 797864	ALSU IVANOVA	{"email": "ivanova.a_24121974@postgrespro.ru", "phone": "+70500366323"}
0005434152828	FE5A27	8037 000651	ILYA KULIKOV	{"phone": "+70713523853"}
0005434152829	FE5A27	5526 556237	ALEKSANDR KULIKOV	{"phone": "+70500237400"}
0005434152830	54ECB8	8471 875453	MARINA PAVLOVA	{"phone": "+70047024407"}
0005434152831	54ECB8	9511 152927	TATYANA SOKOLOVA	{"email": "t-sokolova.25051974@postgrespro.ru", "phone": "+70346605957"}
0005434152832	54ECB8	9763 589633	GALINA POPOVA	{"email": "popova_g_1972@postgrespro.ru", "phone": "+70491779684"}
0005434152833	5F792E	2429 464677	ANDREY ROMANOV	{"email": "a_romanov_1958@postgrespro.ru", "phone": "+70519440750"}
0005434152834	5F792E	4537 079381	NINA VASILEVA	{"phone": "+70554328312"}
0005434152835	3D5A11	4573 169194	DMITRIY MAKAROV	{"phone": "+70585140750"}
0005434152836	3D5A11	9860 000771	EKATERINA GAVRILOVA	{"phone": "+70810322251"}
0005434152837	F2107E	7523 699049	NIKITA SMIRNOV	{"email": "smirnov-n-1980@postgrespro.ru", "phone": "+70436634119"}
0005434152838	20AC85	2044 307142	SERGEY TARASOV	{"phone": "+70271340028"}
0005434152839	20AC85	8356 642540	VLADIMIR FROLOV	{"phone": "+70967451885"}
0005434152840	71D24E	3681 760956	DENIS NAZAROV	{"phone": "+70526026451"}
0005434152841	60548B	1180 951245	ANNA IVANOVA	{"phone": "+70747947841"}
0005434152842	60548B	6486 843984	ALLA PETROVA	{"phone": "+70000623545"}
0005434152843	6E5675	1968 918328	SVETLANA SOROKINA	{"phone": "+70552248451"}
0005434152844	6E5675	7243 078240	ALINA VOLKOVA	{"email": "a-volkova_081971@postgrespro.ru", "phone": "+70972542726"}
0005434152845	62869A	9580 250225	LYUBOV ALEKSANDROVA	{"phone": "+70654522370"}
0005434152846	96801F	4571 911484	MARIYA AFANASEVA	{"email": "afanaseva_mariya-19061978@postgrespro.ru", "phone": "+70137639049"}
0005434152847	51FE56	7888 991811	VALENTINA KRASNOVA	{"email": "valentina.krasnova-21021977@postgrespro.ru", "phone": "+70730611720"}
0005434152848	51FE56	5105 079374	ANNA SMIRNOVA	{"email": "annasmirnova_1974@postgrespro.ru", "phone": "+70626649762"}
0005434152849	80CA92	1576 008847	YAKOV ORLOV	{"phone": "+70217637964"}
0005434152850	80CA92	6577 139514	SERGEY SOKOLOV	{"email": "ssokolov.101980@postgrespro.ru", "phone": "+70832567269"}
0005434152851	99A79F	5830 409919	ARTEM GRIGOREV	{"email": "a_grigorev031976@postgrespro.ru", "phone": "+70629659300"}
0005434152852	508342	1982 594246	VALERIY SCHERBAKOV	{"phone": "+70810399414"}
0005434152853	508342	3042 759517	NATALYA MALYSHEVA	{"phone": "+70524331161"}
0005434152854	BAB40D	8593 738062	ALEKSANDRA KONDRATEVA	{"email": "kondrateva.aleksandra04091980@postgrespro.ru", "phone": "+70090255939"}
0005434152855	B74E2D	5732 852339	SABINA BELOVA	{"email": "s.belova-1979@postgrespro.ru", "phone": "+70499785646"}
0005434152856	B74E2D	5065 360639	VALENTINA DAVYDOVA	{"email": "davydova.v.1972@postgrespro.ru", "phone": "+70508412739"}
0005434152857	7ED24F	6260 097775	VASILIY STEPANOV	{"email": "stepanov_v.16011983@postgrespro.ru", "phone": "+70527571617"}
0005434152858	7ED24F	4743 885604	DMITRIY FROLOV	{"email": "dmitriy_frolov-061971@postgrespro.ru", "phone": "+70371036972"}
0005434152860	D06A01	7682 921308	LYUDMILA GUSEVA	{"email": "lguseva29061980@postgrespro.ru", "phone": "+70811932433"}
0005434152861	18A231	7176 655267	NINA BORISOVA	{"email": "nina_borisova25021981@postgrespro.ru", "phone": "+70681948630"}
0005434152862	36BFB8	8346 181926	ZOYA MIKHAYLOVA	{"email": "zoya-mikhaylova.1979@postgrespro.ru", "phone": "+70419213117"}
0005434152863	36BFB8	8556 168247	ARTEM BORISOV	{"email": "artemborisov1986@postgrespro.ru", "phone": "+70459289203"}
0005434152864	36BFB8	2563 499980	OLGA ABRAMOVA	{"phone": "+70662808595"}
0005434152865	3FB2F5	4306 472259	MARINA KARPOVA	{"email": "m.karpova.111972@postgrespro.ru", "phone": "+70723374057"}
0005434152866	3FB2F5	0677 587940	ANATOLIY ZAKHAROV	{"phone": "+70562482887"}
0005434152867	72B424	7555 157628	IRINA SMIRNOVA	{"email": "smirnova_irina-051978@postgrespro.ru", "phone": "+70857581346"}
0005434152868	1B8D85	0199 780498	LYUBOV ALEKSEEVA	{"email": "alekseeva-lyubov-1974@postgrespro.ru", "phone": "+70949862374"}
0005434152869	711DDA	7967 753777	KONSTANTIN FROLOV	{"phone": "+70669002187"}
0005434152870	F56227	7005 247485	SNEZHANA NESTEROVA	{"phone": "+70793002250"}
0005434152871	F56227	8203 339783	OLEG IVANOV	{"email": "oleg_ivanov06121976@postgrespro.ru", "phone": "+70206030601"}
0005434152872	3DBE82	9043 762936	IRINA VASILEVA	{"email": "vasilevai.23021976@postgrespro.ru", "phone": "+70589513735"}
0005434152873	ABD623	0623 702965	NATALIYA FROLOVA	{"email": "n-frolova.24071971@postgrespro.ru", "phone": "+70719797445"}
0005434152874	88C976	4302 803325	TATYANA STEPANOVA	{"phone": "+70058604235"}
0005434153515	EB3A8C	2665 707296	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova.mariya.011979@postgrespro.ru", "phone": "+70201282795"}
0005434153516	D752C7	6567 152538	RAFAIL POPOV	{"email": "rafailpopov051966@postgrespro.ru", "phone": "+70465338577"}
0005434153517	FFD2EC	9130 184867	EGOR KOZLOV	{"phone": "+70913295859"}
0005434153518	8A1F6D	4606 232116	STANISLAV NAZAROV	{"phone": "+70318879044"}
0005434153519	8A05EC	7310 199736	YURIY POPOV	{"email": "yuriypopov-24071967@postgrespro.ru", "phone": "+70992466996"}
0005434153520	087ABA	4009 893382	LYUDMILA RYABOVA	{"phone": "+70898031558"}
0005434153521	1A358D	8307 525927	LYUBOV ANISIMOVA	{"email": "l-anisimova04061979@postgrespro.ru", "phone": "+70326140728"}
0005434153522	1A358D	3183 444324	GALINA TIMOFEEVA	{"phone": "+70008714782"}
0005434153523	C3D900	4367 270099	NATALYA ZHURAVLEVA	{"email": "natalya.zhuravleva-121967@postgrespro.ru", "phone": "+70936735925"}
0005434153524	BF6E41	0073 059091	YAROSLAV POPOV	{"phone": "+70049691103"}
0005434153525	9CFDFE	8526 146037	EKATERINA TARASOVA	{"phone": "+70908501427"}
0005434153526	C73A4D	9501 989548	ANNA KOROLEVA	{"phone": "+70330625001"}
0005434153527	AB5710	3839 408133	SVETLANA KAZAKOVA	{"phone": "+70407454709"}
0005434153528	B45F9F	4745 522414	YULIYA ABRAMOVA	{"email": "abramova.y04041959@postgrespro.ru", "phone": "+70902318524"}
0005434153529	8E5DD6	6395 902205	MARINA KUZNECOVA	{"phone": "+70488208131"}
0005434153530	E90884	6846 253164	ILYA KONOVALOV	{"phone": "+70200592877"}
0005434153531	98A387	4940 838621	YURIY SMIRNOV	{"email": "y.smirnov26041974@postgrespro.ru", "phone": "+70990461140"}
0005434153532	2D3D51	4602 759913	ANATOLIY MATVEEV	{"phone": "+70137796802"}
0005434153533	974155	1287 948547	YULIYA KUDRYASHOVA	{"email": "kudryashova_y1972@postgrespro.ru", "phone": "+70900475906"}
0005434153534	974155	8420 656749	OKSANA KUZMINA	{"email": "kuzmina_o031978@postgrespro.ru", "phone": "+70874164244"}
0005434153535	EC75E4	1937 387651	ANASTASIYA NAUMOVA	{"phone": "+70253118203"}
0005434153536	3EE8B1	8740 376888	ELENA MALYSHEVA	{"phone": "+70898919433"}
0005434153537	389E26	5367 020745	IVAN POPOV	{"phone": "+70420298947"}
0005434153538	389E26	7367 709083	LIDIYA GORBUNOVA	{"phone": "+70515717598"}
0005434153539	DC450F	4356 392086	YULIYA MASLOVA	{"email": "y-maslova-1977@postgrespro.ru", "phone": "+70252592414"}
0005434153540	69956B	6411 831364	ELENA ABRAMOVA	{"email": "elena_abramova021976@postgrespro.ru", "phone": "+70402648198"}
0005434153541	69956B	1311 223730	VYACHESLAV MAKAROV	{"phone": "+70785572411"}
0005434153542	69C5DA	0598 713052	NIKOLAY STEPANOV	{"email": "nikolaystepanov.13071973@postgrespro.ru", "phone": "+70449788680"}
0005434153543	32A6D6	5419 772839	YURIY NIKOLAEV	{"email": "y_nikolaev_081971@postgrespro.ru", "phone": "+70213640322"}
0005434153544	5B0FB9	8219 589909	VASILIY VASILEV	{"phone": "+70537219774"}
0005434153545	AA750B	9648 826812	VASILIY KUZNECOV	{"phone": "+70912802834"}
0005434153546	B7CDC3	5374 103226	ALEKSANDRA NIKOLAEVA	{"email": "nikolaeva.aleksandra_26111974@postgrespro.ru", "phone": "+70630262541"}
0005434153547	2DC6D2	6295 183366	ANDREY MEDVEDEV	{"phone": "+70250049200"}
0005434153548	3254D3	9632 468957	EVGENIY KUZNECOV	{"phone": "+70332533697"}
0005434153549	198F78	0281 143210	IGOR GERASIMOV	{"email": "i-gerasimov.1971@postgrespro.ru", "phone": "+70244677020"}
0005434153550	5568C0	4789 292023	OLGA VOROBEVA	{"email": "olga.vorobeva_1976@postgrespro.ru", "phone": "+70734026674"}
0005434153551	185F84	9253 426099	OKSANA FILIPPOVA	{"email": "filippova-oksana031984@postgrespro.ru", "phone": "+70394903546"}
0005434153552	47FF8A	9147 564144	IVAN SIDOROV	{"email": "sidorov-ivan.1970@postgrespro.ru", "phone": "+70081484500"}
0005434153553	47FF8A	4829 851618	LYUBOV IVANOVA	{"email": "ivanova_lyubov-28071965@postgrespro.ru", "phone": "+70927506278"}
0005434153554	1BFAF7	5775 604411	TATYANA KOMAROVA	{"email": "tkomarova-23111983@postgrespro.ru", "phone": "+70168554648"}
0005434153555	72E065	1152 108117	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina-03081966@postgrespro.ru", "phone": "+70939737523"}
0005434153556	6A01F7	3624 584363	OLEG SOROKIN	{"email": "sorokin-o-27111968@postgrespro.ru", "phone": "+70005027420"}
0005434153557	6A01F7	8249 873666	ANDREY VOLKOV	{"email": "volkov_andrey1967@postgrespro.ru", "phone": "+70787107309"}
0005434153558	EE3186	5630 432282	OLGA MOROZOVA	{"email": "o-morozova1969@postgrespro.ru", "phone": "+70436467438"}
0005434153559	AD5F23	9467 406095	MARIYA SAVELEVA	{"phone": "+70162408173"}
0005434153560	F17181	7614 933750	IVAN PETROV	{"phone": "+70197282948"}
0005434153561	693672	0701 722043	NIKOLAY DAVYDOV	{"email": "davydovn-1957@postgrespro.ru", "phone": "+70366964861"}
0005434153562	693672	8369 095872	OKSANA BORISOVA	{"phone": "+70579266621"}
0005434153563	693672	7177 835800	EKATERINA DANILOVA	{"phone": "+70238979873"}
0005434153564	5824E7	7126 733073	ZINAIDA POPOVA	{"phone": "+70707117206"}
0005434153565	06D287	1671 991465	VENERA SOLOVEVA	{"email": "soloveva.v.1984@postgrespro.ru", "phone": "+70156191287"}
0005434153566	462212	8530 919257	TATYANA SERGEEVA	{"email": "tatyana-sergeeva_28031967@postgrespro.ru", "phone": "+70660373165"}
0005434153567	6F049E	8218 766894	TATYANA BARANOVA	{"phone": "+70591214933"}
0005434153568	260241	6776 149814	EVGENIY MAKAROV	{"email": "makarov_evgeniy06011980@postgrespro.ru", "phone": "+70047621978"}
0005434153569	E4CC53	6054 073656	OLGA ILINA	{"email": "o-ilina_031968@postgrespro.ru", "phone": "+70713810502"}
0005434153570	25D78B	4679 253737	IVAN MOROZOV	{"email": "morozovi.041974@postgrespro.ru", "phone": "+70574575054"}
0005434153571	4EFF14	0968 781092	VIKTOR VOLKOV	{"email": "v.volkov-03091959@postgrespro.ru", "phone": "+70172286300"}
0005434153572	CDD046	3696 559577	ALINA PETROVA	{"email": "alina_petrova-011983@postgrespro.ru", "phone": "+70097095027"}
0005434153573	B83168	0086 600966	ANTONINA KARPOVA	{"email": "akarpova.11061981@postgrespro.ru", "phone": "+70293106492"}
0005434153574	A1644C	8540 798870	VERONIKA ORLOVA	{"phone": "+70834487227"}
0005434153575	A32F73	7214 450803	VITALIY SMIRNOV	{"email": "smirnov_vitaliy041977@postgrespro.ru", "phone": "+70387248264"}
0005434153576	590389	9207 869810	ELENA ZAKHAROVA	{"email": "zakharova-e.17081977@postgrespro.ru", "phone": "+70570459466"}
0005434153577	590389	4517 198815	ALEKSEY KUDRYASHOV	{"phone": "+70264197359"}
0005434153578	27BD56	1277 254442	LYUDMILA ILINA	{"email": "l_ilina-031971@postgrespro.ru", "phone": "+70884787806"}
0005434153579	BC6D69	6750 267350	NELLYA RYABOVA	{"email": "nellya_ryabova_1979@postgrespro.ru", "phone": "+70730353390"}
0005434153580	226BF8	3593 755050	OLGA MAKAROVA	{"phone": "+70627304528"}
0005434153581	31BD3F	5351 929156	VIKTOR ZAYCEV	{"email": "viktor-zaycev-04021984@postgrespro.ru", "phone": "+70879377418"}
0005434153582	31BD3F	8281 617184	EVGENIYA IVANOVA	{"email": "e_ivanova-05121972@postgrespro.ru", "phone": "+70733654294"}
0005434153583	D35523	8102 000575	DANILA MAKAROV	{"email": "makarovdanila051978@postgrespro.ru", "phone": "+70469612137"}
0005434157399	8C325E	0402 743129	DIANA IVANOVA	{"phone": "+70493056999"}
0005434153584	5D731F	4380 140453	KSENIYA OVCHINNIKOVA	{"email": "ovchinnikova.kseniya.031980@postgrespro.ru", "phone": "+70319191241"}
0005434153585	1A3B1F	6990 283392	ROMAN ANDREEV	{"email": "andreev.roman.1983@postgrespro.ru", "phone": "+70476494784"}
0005434153586	1A3B1F	9602 572618	NADEZHDA LOGINOVA	{"phone": "+70137413100"}
0005434157341	8C6774	0281 497554	ALEKSANDR OSIPOV	{"email": "osipov.aleksandr.1973@postgrespro.ru", "phone": "+70720595610"}
0005434157342	8C6774	8660 249764	VERA KUZNECOVA	{"phone": "+70260246445"}
0005434157343	52A826	5728 810683	ANATOLIY ORLOV	{"phone": "+70930316285"}
0005434157344	539E34	2572 020527	ANNA SCHERBAKOVA	{"phone": "+70937017780"}
0005434157345	539E34	6635 245367	SVETLANA KAZAKOVA	{"phone": "+70215729914"}
0005434157346	2532DD	7571 307752	DMITRIY KOZLOV	{"phone": "+70775304075"}
0005434157347	C7F564	2922 638299	MATRENA ISAEVA	{"email": "isaeva.m-12041968@postgrespro.ru", "phone": "+70742704934"}
0005434157348	037EA7	8426 283719	EKATERINA FEDOROVA	{"phone": "+70310584324"}
0005434157349	037EA7	7045 755160	YULIYA KISELEVA	{"phone": "+70701421199"}
0005434157350	CA977A	5619 003905	NINA BORISOVA	{"phone": "+70962084767"}
0005434157351	B1E4BC	8878 733192	SVETLANA SOKOLOVA	{"phone": "+70075552074"}
0005434157352	E30E4B	9975 886899	ALEKSEY MARTYNOV	{"phone": "+70388589686"}
0005434157353	E30E4B	9986 483238	ALEKSANDR IVANOV	{"email": "ivanov_a1977@postgrespro.ru", "phone": "+70955365075"}
0005434157354	2D30A0	0421 860801	RIMMA FROLOVA	{"phone": "+70236246769"}
0005434157355	2D30A0	1598 220570	SOFIYA KOVALEVA	{"phone": "+70473270135"}
0005434157356	434911	1627 781820	PETR BORISOV	{"email": "petr_borisov1966@postgrespro.ru", "phone": "+70454383162"}
0005434157357	2D4ADB	3917 868617	OLGA NAUMOVA	{"phone": "+70689356903"}
0005434157358	9CE629	7388 463181	SVETLANA MELNIKOVA	{"email": "melnikova-s-28021977@postgrespro.ru", "phone": "+70628377668"}
0005434157359	A927AF	5639 791340	SOFYA ROMANOVA	{"phone": "+70644453064"}
0005434157360	2B05FB	3897 897240	VIKTOR MOROZOV	{"email": "morozov.viktor05101969@postgrespro.ru", "phone": "+70338198410"}
0005434157361	C2B6FE	2659 260467	VIKTOR OSIPOV	{"email": "osipov.v21071977@postgrespro.ru", "phone": "+70908874760"}
0005434157362	C2B6FE	7801 782287	ANDREY PETROV	{"email": "andrey_petrov.111962@postgrespro.ru", "phone": "+70339755642"}
0005434157363	DF072A	2124 906250	NINA KUZNECOVA	{"phone": "+70927396615"}
0005434157364	DF072A	4299 757573	NATALYA MAKAROVA	{"phone": "+70246928842"}
0005434157365	F9F780	5676 878858	ALLA VASILEVA	{"email": "vasileva.alla1965@postgrespro.ru", "phone": "+70455092920"}
0005434157366	E684CE	3176 799158	TAMARA EFIMOVA	{"phone": "+70101691243"}
0005434157367	E684CE	7894 514276	VLADISLAV FILIPPOV	{"email": "v-filippov24111978@postgrespro.ru", "phone": "+70000472818"}
0005434157368	5A20D4	0581 917425	OLGA BARANOVA	{"email": "obaranova_071970@postgrespro.ru", "phone": "+70628235885"}
0005434157369	2F5B5A	6906 784551	VLADIMIR FEDOTOV	{"phone": "+70303608831"}
0005434157370	2F5B5A	3450 571168	OLEG VOLKOV	{"email": "olegvolkov.28011976@postgrespro.ru", "phone": "+70745445514"}
0005434157371	B1C433	2425 422426	ALEKSEY NAUMOV	{"email": "a_naumov_111966@postgrespro.ru", "phone": "+70624190352"}
0005434157372	552CAC	1521 852442	YURIY NIKITIN	{"phone": "+70502111974"}
0005434157373	552CAC	5101 260819	EKATERINA KULIKOVA	{"email": "e-kulikova26011955@postgrespro.ru", "phone": "+70426849753"}
0005434157374	28E8FB	2454 345534	ANNA IVANOVA	{"email": "ivanova_anna_22021973@postgrespro.ru", "phone": "+70550999996"}
0005434157375	633931	9382 731518	ILNUR GAVRILOV	{"phone": "+70224435582"}
0005434157376	A75D5C	0412 945994	ANTON NAUMOV	{"phone": "+70901572164"}
0005434157377	A75D5C	1277 408289	OLEG ZHURAVLEV	{"phone": "+70701109139"}
0005434157378	A75D5C	1814 836500	KONSTANTIN NAZAROV	{"phone": "+70130791273"}
0005434157379	971423	2788 420190	MIKHAIL FILIPPOV	{"phone": "+70744880162"}
0005434157380	794C55	6396 031950	DMITRIY ZAYCEV	{"email": "d.zaycev-31121978@postgrespro.ru", "phone": "+70903362849"}
0005434157381	794C55	3942 152827	MARIYA KUZNECOVA	{"email": "kuznecova-mariya-18121970@postgrespro.ru", "phone": "+70560374743"}
0005434157382	794C55	7590 681859	VASILIY YAKOVLEV	{"email": "yakovlevvasiliy.1962@postgrespro.ru", "phone": "+70041703643"}
0005434157383	F9D0D6	5419 473673	LIDIYA TARASOVA	{"email": "tarasova-l16061960@postgrespro.ru", "phone": "+70078845664"}
0005434157384	A962D1	2436 158537	EKATERINA FILATOVA	{"phone": "+70684857290"}
0005434157385	A962D1	1048 139263	VLADIMIR SERGEEV	{"phone": "+70666329513"}
0005434157386	48C971	5432 638988	VADIM NOVIKOV	{"phone": "+70866123974"}
0005434157387	5EE693	4350 646009	KRISTINA KUZNECOVA	{"email": "kristina_kuznecova-1971@postgrespro.ru", "phone": "+70408221961"}
0005434157388	A247A2	5990 579961	DMITRIY ANDREEV	{"email": "andreev.d23011977@postgrespro.ru", "phone": "+70961848293"}
0005434157389	A247A2	9823 342628	NIKOLAY ALEKSANDROV	{"phone": "+70276337792"}
0005434157390	E79E5A	7405 820020	GALINA ALEKSEEVA	{"email": "galina-alekseeva-17111988@postgrespro.ru", "phone": "+70989315451"}
0005434157391	E79E5A	6415 155407	ELIZAVETA TROFIMOVA	{"email": "etrofimova1977@postgrespro.ru", "phone": "+70530035795"}
0005434157392	1B9968	7400 288882	ARTEM PAVLOV	{"email": "pavlovartem.01121970@postgrespro.ru", "phone": "+70542203641"}
0005434157393	705158	7223 785540	EKATERINA KUZMINA	{"phone": "+70140353550"}
0005434157394	705158	3769 316812	NIKOLAY GERASIMOV	{"email": "n.gerasimov.1973@postgrespro.ru", "phone": "+70386327517"}
0005434157395	93874A	8449 891784	ALEKSANDR MAKSIMOV	{"phone": "+70741553625"}
0005434157396	93874A	3240 502516	PAVEL ZAKHAROV	{"email": "p.zakharov08011958@postgrespro.ru", "phone": "+70886651194"}
0005434157397	93874A	2495 139266	ELENA KOMAROVA	{"email": "komarovaelena1969@postgrespro.ru", "phone": "+70220617740"}
0005434157398	784C78	9084 960925	EVGENIY VOROBEV	{"email": "evgeniy-vorobev.01031973@postgrespro.ru", "phone": "+70634177496"}
0005434157400	A6573C	6421 928526	OKSANA ROMANOVA	{"email": "o_romanova1973@postgrespro.ru", "phone": "+70110756297"}
0005434157401	DD517B	2956 883033	VALENTINA RODIONOVA	{"phone": "+70407658110"}
0005434157402	C726C7	4113 931536	LIDIYA POLYAKOVA	{"phone": "+70593762881"}
0005434157403	C726C7	5384 323543	VLADIMIR IVANOV	{"phone": "+70296239727"}
0005434157404	82F09D	7882 997273	VERONIKA KONDRATEVA	{"phone": "+70704822053"}
0005434157405	82F09D	9620 272871	VLADIMIR MIKHAYLOV	{"phone": "+70863881409"}
0005434157406	800B3D	7316 875506	ALEKSANDRA ZOTOVA	{"phone": "+70335663336"}
0005434157407	974CB0	6058 574500	EKATERINA IVANOVA	{"phone": "+70308660531"}
0005434157408	B70BDA	6995 111511	NATALYA FILATOVA	{"phone": "+70741033114"}
0005434157409	1C6F9B	1004 620323	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov_20041976@postgrespro.ru", "phone": "+70684238332"}
0005434157410	F8FE19	0483 083125	MARINA MAKAROVA	{"email": "makarovam.041972@postgrespro.ru", "phone": "+70617352475"}
0005434157411	F8FE19	7956 207480	ELENA KISELEVA	{"email": "kiselevaelena08101963@postgrespro.ru", "phone": "+70105741725"}
0005434157412	131E9C	9515 172430	TATYANA LEBEDEVA	{"email": "tatyana.lebedeva-021985@postgrespro.ru", "phone": "+70125926583"}
0005434157413	BC58E9	6505 218749	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova_m_23031974@postgrespro.ru", "phone": "+70427014009"}
0005434157414	340F3D	2760 899071	SERGEY RODIONOV	{"phone": "+70227841841"}
0005434157415	813CA9	4328 605843	OLGA ZAKHAROVA	{"phone": "+70528837788"}
0005434157416	A8E1A8	7799 862611	DAMIR RODIONOV	{"email": "damir-rodionov_121984@postgrespro.ru", "phone": "+70128640489"}
0005434157417	57BD61	5848 697617	TATYANA NESTEROVA	{"phone": "+70355859255"}
0005434157418	57BD61	0893 134707	OLGA EGOROVA	{"email": "o-egorova_1969@postgrespro.ru", "phone": "+70609903547"}
0005434157419	810D56	7495 934601	ELENA VOLKOVA	{"phone": "+70750064798"}
0005434157420	319E96	7989 114492	VALENTINA KUZNECOVA	{"phone": "+70280561328"}
0005434157421	B8ED35	3652 177558	SERGEY DMITRIEV	{"email": "dmitriev_sergey.1966@postgrespro.ru", "phone": "+70057202523"}
0005434157422	B8ED35	4362 105178	SERGEY POPOV	{"phone": "+70051850273"}
0005434157423	DC4A42	7050 460224	VLADISLAV SOROKIN	{"email": "vladislav_sorokin_081972@postgrespro.ru", "phone": "+70669672990"}
0005434157424	DB8404	4467 852994	ULYANA DMITRIEVA	{"phone": "+70151529960"}
0005434157425	DB8404	6019 242101	LYUBOV PETROVA	{"email": "lyubov-petrova-051967@postgrespro.ru", "phone": "+70783240421"}
0005434157426	63EDBC	3104 939041	IVAN MAKAROV	{"email": "makarovivan15081976@postgrespro.ru", "phone": "+70085658932"}
0005434157427	63EDBC	3332 745937	MARTA EFREMOVA	{"phone": "+70147861088"}
0005434157428	6F5CBA	0130 169832	EDUARD FEDOROV	{"phone": "+70244317563"}
0005434157429	046587	3348 889214	TATYANA PAVLOVA	{"email": "tatyana-pavlova.1965@postgrespro.ru", "phone": "+70037351308"}
0005434157430	1C9FA9	4672 280663	YURIY AFANASEV	{"phone": "+70840878292"}
0005434157431	D9E1C4	5148 025768	ALEKSANDR ALEKSEEV	{"phone": "+70160879069"}
0005434157432	62D01B	3444 431581	OLGA SAVELEVA	{"email": "olgasaveleva_051976@postgrespro.ru", "phone": "+70154897960"}
0005434157433	387D93	7062 097971	VASILISA ZAYCEVA	{"phone": "+70126629074"}
0005434157434	720325	6489 784107	VLADIMIR GORBUNOV	{"phone": "+70760070127"}
0005434157435	720325	4668 756582	ALEKSANDRA TITOVA	{"email": "aleksandratitova1967@postgrespro.ru", "phone": "+70825967369"}
0005434157436	09563D	0533 545647	ANATOLIY MAKSIMOV	{"email": "maksimov-a_1963@postgrespro.ru", "phone": "+70250436663"}
0005434157437	554A30	4806 314284	EVGENIY VOLKOV	{"email": "evgeniy-volkov.1977@postgrespro.ru", "phone": "+70150152563"}
0005434157438	601360	9510 595867	YURIY OSIPOV	{"phone": "+70785343936"}
0005434157439	601360	6246 391982	OLEG VOLKOV	{"email": "ovolkov.041965@postgrespro.ru", "phone": "+70828700402"}
0005434157440	0A557C	3876 439146	LYUBOV SOLOVEVA	{"email": "solovevalyubov.01111961@postgrespro.ru", "phone": "+70695311582"}
0005434157441	0A557C	8929 515287	VALENTINA ANTONOVA	{"email": "antonova.valentina_071983@postgrespro.ru", "phone": "+70093608353"}
0005434157442	0A557C	8089 054864	SERGEY MIRONOV	{"email": "mironovs-16111974@postgrespro.ru", "phone": "+70042518204"}
0005434157443	4D8EE5	5173 666240	ALEKSANDR KUDRYASHOV	{"phone": "+70958080269"}
0005434157444	4452BD	6938 600964	DMITRIY ZAKHAROV	{"email": "zakharovd-051968@postgrespro.ru", "phone": "+70231428985"}
0005434157445	35CF05	9138 365015	ALENA IVANOVA	{"email": "ivanova-a_031978@postgrespro.ru", "phone": "+70367454651"}
0005434157446	35CF05	3671 308632	ANATOLIY SEMENOV	{"phone": "+70120968735"}
0005434157447	9C98D9	6574 974433	NATALYA TARASOVA	{"email": "natalya_tarasova14021983@postgrespro.ru", "phone": "+70972698856"}
0005434157448	A0C5D8	4500 885390	VITALIY MOISEEV	{"phone": "+70112091736"}
0005434157449	51B7F1	2478 580881	ANDREY TIMOFEEV	{"email": "timofeev_andrey-22021969@postgrespro.ru", "phone": "+70186224470"}
0005434157450	D888C2	3947 613472	MARINA POPOVA	{"email": "m_popova051959@postgrespro.ru", "phone": "+70022153792"}
0005434157451	D888C2	6506 148173	DMITRIY FEDOTOV	{"email": "d-fedotov-07071970@postgrespro.ru", "phone": "+70908166134"}
0005434157452	787A2F	6777 448892	ELENA DMITRIEVA	{"email": "dmitrieva-e.1972@postgrespro.ru", "phone": "+70059336499"}
0005434157453	787A2F	7207 556299	ELENA NIKOLAEVA	{"email": "nikolaeva-e.1967@postgrespro.ru", "phone": "+70609853727"}
0005434157454	026303	5682 372193	ALEKSANDR TIKHONOV	{"email": "tikhonov-a-12091974@postgrespro.ru", "phone": "+70607019654"}
0005434157455	B2E7D5	0123 319436	YULIYA KOZLOVA	{"email": "kozlova-yuliya25081978@postgrespro.ru", "phone": "+70447456351"}
0005434157456	EBD666	9835 468666	MARIYA KOLESNIKOVA	{"phone": "+70426856089"}
0005434157457	EBD666	2633 308878	OLEG PETROV	{"email": "petrovoleg-1960@postgrespro.ru", "phone": "+70528260253"}
0005434157458	6E2959	2664 924884	SERGEY VASILEV	{"phone": "+70230218410"}
0005434157459	6E2959	4883 940424	VALENTIN IVANOV	{"phone": "+70119935735"}
0005434157460	6E2959	1239 813501	VALERIYA KOZLOVA	{"phone": "+70061257925"}
0005434157461	FB0D3F	6214 267055	VALENTINA ROMANOVA	{"email": "valentina.romanova04111982@postgrespro.ru", "phone": "+70260123722"}
0005434157462	47416E	5715 601167	ALEKSANDRA KOROLEVA	{"email": "aleksandra-koroleva_1964@postgrespro.ru", "phone": "+70330615440"}
0005434157463	47416E	1534 253222	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko_021971@postgrespro.ru", "phone": "+70631910847"}
0005434157464	63B7F4	8119 451041	ANDREY NIKOLAEV	{"email": "nikolaev-andrey_1971@postgrespro.ru", "phone": "+70879301142"}
0005434157465	8F09FB	1078 992740	DMITRIY POPOV	{"email": "popov_d-1969@postgrespro.ru", "phone": "+70832404578"}
0005434157466	8F09FB	0394 652161	ELENA ZOTOVA	{"email": "ezotova-1962@postgrespro.ru", "phone": "+70847579537"}
0005434157467	EC801C	2890 953562	ILYAS MOISEEV	{"email": "ilyas_moiseev-16121974@postgrespro.ru", "phone": "+70848648701"}
0005434157468	EC801C	0569 180627	NADEZHDA GERASIMOVA	{"email": "gerasimova_nadezhda_101972@postgrespro.ru", "phone": "+70142851809"}
0005434157469	829267	5076 295318	MIKHAIL STEPANOV	{"phone": "+70002977605"}
0005434157470	F9A436	5550 320102	RUSLAN VLASOV	{"email": "vlasov.ruslan-071970@postgrespro.ru", "phone": "+70284716737"}
0005434157471	F9A436	6956 726995	ELENA RODIONOVA	{"phone": "+70088686578"}
0005434157472	9C22AC	3038 188258	ARTEM MARTYNOV	{"phone": "+70713828871"}
0005434157473	B97DCB	4458 879759	DANILA KRASNOV	{"phone": "+70707271213"}
0005434157474	CDBD80	0989 392505	ELENA ZOTOVA	{"email": "zotova_elena_1974@postgrespro.ru", "phone": "+70157749696"}
0005434157475	559B64	3721 308883	VIKTOR GORBUNOV	{"phone": "+70003062790"}
0005434157476	559B64	1511 436494	VITALIY GAVRILOV	{"email": "gavrilov.vitaliy.07011973@postgrespro.ru", "phone": "+70336664106"}
0005434157477	908833	8178 461785	ALEKSANDR PAVLOV	{"email": "pavlov-a111972@postgrespro.ru", "phone": "+70151882467"}
0005434157478	41DE51	5699 086130	VADIM VLASOV	{"phone": "+70262816164"}
0005434157479	A5F90D	4304 785026	TATYANA TARASOVA	{"email": "tatyana-tarasova1968@postgrespro.ru", "phone": "+70142226494"}
0005434157480	56283D	8745 828679	EVGENIY KARPOV	{"phone": "+70234117079"}
0005434157481	51F6A5	4795 110562	ANDREY MATVEEV	{"phone": "+70036832581"}
0005434157482	3888D0	7320 382279	ANFISA STEPANOVA	{"email": "stepanovaanfisa-091965@postgrespro.ru", "phone": "+70973264190"}
0005434157483	3888D0	5405 138618	ANATOLIY SOROKIN	{"email": "sorokinanatoliy.15031968@postgrespro.ru", "phone": "+70455847271"}
0005434157484	534008	7958 051503	OKSANA SEMENOVA	{"phone": "+70569675778"}
0005434157485	35EBD1	3616 845429	EVGENIY KOZLOV	{"phone": "+70309980710"}
0005434157486	35EBD1	3470 350329	YURIY OSIPOV	{"phone": "+70639600146"}
0005434157487	562130	5913 581293	ANDREY FEDOROV	{"phone": "+70781418665"}
0005434157488	562130	7873 700924	VIKTOR EGOROV	{"phone": "+70338027156"}
0005434157489	E5BF58	5688 893774	OLGA ALEKSEEVA	{"phone": "+70545065202"}
0005434157490	E5BF58	8866 459575	IRINA MOROZOVA	{"email": "morozovairina-101966@postgrespro.ru", "phone": "+70864450065"}
0005434157491	CF0A24	6405 418294	VALENTIN KOZLOV	{"email": "valentin_kozlov19021974@postgrespro.ru", "phone": "+70802549641"}
0005434157492	CF0A24	5760 793114	MARIYA POLYAKOVA	{"phone": "+70764926916"}
0005434157493	A4040A	9776 879227	ANASTASIYA KOVALEVA	{"phone": "+70198591801"}
0005434157494	84C08F	5426 756381	SNEZHANA BELOVA	{"phone": "+70097216376"}
0005434157495	F4A770	6381 254279	ELENA ZAKHAROVA	{"phone": "+70684834786"}
0005434157496	F4A770	5453 446807	SERGEY BORISOV	{"email": "sergey_borisov-05021974@postgrespro.ru", "phone": "+70478098431"}
0005434157497	560CE2	2696 190682	DINA MARTYNOVA	{"email": "d.martynova-1974@postgrespro.ru", "phone": "+70008248935"}
0005434157498	560CE2	0989 807249	STEPAN GORBUNOV	{"email": "gorbunov.stepan061969@postgrespro.ru", "phone": "+70265324294"}
0005434157499	CB4BEE	9593 695109	RUFIYA ANDREEVA	{"email": "andreeva-r_1969@postgrespro.ru", "phone": "+70962782009"}
0005434157500	CB4BEE	6231 914525	ELENA NIKOLAEVA	{"email": "nikolaevaelena-1979@postgrespro.ru", "phone": "+70939903486"}
0005434157501	568E21	1504 407629	VIKTOR MAKAROV	{"phone": "+70444674531"}
0005434157893	BD42D4	3483 682895	YULIYA NOVIKOVA	{"phone": "+70383182891"}
0005434157502	84155E	7511 824094	SVETLANA LAZAREVA	{"email": "lazareva_svetlana1963@postgrespro.ru", "phone": "+70422911819"}
0005434157503	10963B	7646 831334	TAISIYA PETROVA	{"phone": "+70154527404"}
0005434157504	10963B	9264 660847	NATALYA ROMANOVA	{"email": "romanova-natalya_23031968@postgrespro.ru", "phone": "+70583305734"}
0005434157505	FAE08B	5753 387773	OLEG SOKOLOV	{"email": "sokolov-o_15011964@postgrespro.ru", "phone": "+70485783662"}
0005434157506	FAE08B	5784 740677	ALEKSANDR BELOV	{"email": "belov-a-22051961@postgrespro.ru", "phone": "+70659266161"}
0005434157507	7279C0	4019 960321	SERGEY NAUMOV	{"email": "naumov-sergey011968@postgrespro.ru", "phone": "+70234612634"}
0005434157508	7279C0	7543 924183	SERGEY ZAKHAROV	{"email": "zakharov.sergey1970@postgrespro.ru", "phone": "+70345415917"}
0005434157509	E08791	0839 954850	NATALYA FILATOVA	{"email": "filatova-n.1980@postgrespro.ru", "phone": "+70462164156"}
0005434157510	F3C05D	1294 021861	OLGA MOISEEVA	{"email": "moiseeva.o-1988@postgrespro.ru", "phone": "+70736170298"}
0005434157511	F3C05D	6108 293617	NINA GUSEVA	{"email": "gusevanina_1978@postgrespro.ru", "phone": "+70209182925"}
0005434157512	CC4A98	0110 062052	SERGEY DMITRIEV	{"email": "s-dmitriev_111979@postgrespro.ru", "phone": "+70935554942"}
0005434157513	CC4A98	7696 933918	SERGEY VASILEV	{"phone": "+70320164287"}
0005434157514	D96DD8	3431 804532	TATYANA NIKOLAEVA	{"email": "tnikolaeva_27121966@postgrespro.ru", "phone": "+70075635807"}
0005434157515	D96DD8	7161 645610	ELMIRA GAVRILOVA	{"email": "gavrilovaelmira121983@postgrespro.ru", "phone": "+70717615348"}
0005434157516	D96DD8	4892 373179	ZOYA POPOVA	{"email": "popova-z.28121967@postgrespro.ru", "phone": "+70031814106"}
0005434157517	D96DD8	2529 686559	LYUDMILA ALEKSEEVA	{"phone": "+70112602391"}
0005434157518	CADA1A	2703 070540	LILIYA KOLESNIKOVA	{"phone": "+70143425110"}
0005434157519	CADA1A	2321 714667	MIKHAIL YAKOVLEV	{"email": "m-yakovlev.061984@postgrespro.ru", "phone": "+70851607827"}
0005434157520	635519	9809 738058	MIKHAIL MOROZOV	{"email": "morozovmikhail-1974@postgrespro.ru", "phone": "+70576554932"}
0005434157521	3C2B0A	4676 173854	ARTEM KRASNOV	{"email": "krasnov_a.24011974@postgrespro.ru", "phone": "+70940966761"}
0005434157522	3C2B0A	9943 340398	ALEKSANDR FILIPPOV	{"phone": "+70355559434"}
0005434157523	D8202A	7741 643729	ELENA PETROVA	{"email": "petrovae_22031973@postgrespro.ru", "phone": "+70133913408"}
0005434157524	D8202A	3287 757993	VERA GORBUNOVA	{"phone": "+70105298381"}
0005434157525	55CAD9	9453 539579	IRINA FILIPPOVA	{"email": "filippova-i-21111968@postgrespro.ru", "phone": "+70364361211"}
0005434157526	55CAD9	9535 139833	DANILA GAVRILOV	{"phone": "+70656244399"}
0005434157527	231F43	1234 027906	SVETLANA EFREMOVA	{"phone": "+70953735117"}
0005434157528	231F43	6001 528127	ANNA POPOVA	{"email": "popova-a_14021976@postgrespro.ru", "phone": "+70803768659"}
0005434157529	21C5FA	9973 865434	VIKTOR GORBUNOV	{"email": "gorbunov_viktor-09071976@postgrespro.ru", "phone": "+70859563378"}
0005434157530	A40647	2102 474837	ALEKSANDRA NIKITINA	{"phone": "+70478643109"}
0005434157531	A40647	0564 674593	MATVEY SHEVCHENKO	{"email": "shevchenko-matvey.1965@postgrespro.ru", "phone": "+70066556849"}
0005434157532	691118	0005 055225	TATYANA FILATOVA	{"email": "filatova.t.111976@postgrespro.ru", "phone": "+70953149657"}
0005434157533	5F9648	7056 383732	NATALYA YUDINA	{"email": "n.yudina-1972@postgrespro.ru", "phone": "+70328761431"}
0005434157534	F07ECA	3260 916175	SERGEY NAUMOV	{"email": "naumov_sergey-071983@postgrespro.ru", "phone": "+70918311605"}
0005434157535	F07ECA	3150 810195	ANNA POPOVA	{"phone": "+70252345200"}
0005434157536	9E621A	4655 748550	DENIS SHEVCHENKO	{"phone": "+70830831604"}
0005434157537	FBEBB0	3180 407662	SVETLANA ZAKHAROVA	{"phone": "+70802894615"}
0005434157538	897B7F	7006 637438	GRIGORIY BORISOV	{"phone": "+70741870198"}
0005434157539	A0562A	3519 018800	VALENTINA ZHUKOVA	{"phone": "+70555733744"}
0005434157540	081270	3981 826487	ALEKSEY ZHUKOV	{"phone": "+70505098839"}
0005434157541	FE12CD	3829 227263	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr_1963@postgrespro.ru", "phone": "+70946112246"}
0005434157542	FE12CD	0760 475579	SVETLANA RODIONOVA	{"email": "s_rodionova1966@postgrespro.ru", "phone": "+70551093632"}
0005434157543	B9D463	3146 865883	LIDIYA NIKITINA	{"phone": "+70687117070"}
0005434157544	B9D463	4286 790740	VALENTINA ROMANOVA	{"phone": "+70743247152"}
0005434157545	46DACD	5564 508967	VALENTINA EGOROVA	{"phone": "+70325037358"}
0005434157546	BC6B61	0081 841796	VADIM SHEVCHENKO	{"phone": "+70464425635"}
0005434157547	BC6B61	7758 034330	IGOR IVANOV	{"phone": "+70997402500"}
0005434157548	CA9A77	0142 684602	TATYANA TARASOVA	{"phone": "+70675053834"}
0005434157549	CA9A77	7095 307911	RAISA ZHUKOVA	{"email": "raisa.zhukova_02041972@postgrespro.ru", "phone": "+70296635435"}
0005434157550	914370	5470 574932	VIKTOR MIRONOV	{"phone": "+70406332686"}
0005434157551	914370	0750 949457	EVDOKIYA KUZNECOVA	{"phone": "+70795186136"}
0005434157552	C21334	4889 637289	KARINA SIDOROVA	{"email": "k.sidorova_15101961@postgrespro.ru", "phone": "+70887125312"}
0005434157553	D13C35	4135 880638	STANISLAV TIKHONOV	{"phone": "+70941819125"}
0005434157554	D13387	2186 563613	LYUBOV FROLOVA	{"email": "frolovalyubov-18101976@postgrespro.ru", "phone": "+70920616674"}
0005434157555	D13387	2921 303775	ANASTASIYA VASILEVA	{"phone": "+70426010067"}
0005434157556	348F11	9062 400670	ELENA SIDOROVA	{"phone": "+70679137897"}
0005434157557	FBAB3C	8028 022828	OLEG SERGEEV	{"email": "sergeevoleg-11091969@postgrespro.ru", "phone": "+70231501500"}
0005434157558	D263C1	6062 044808	ALBINA FROLOVA	{"email": "frolovaalbina-011961@postgrespro.ru", "phone": "+70485683801"}
0005434157559	D263C1	2515 364508	SERGEY RODIONOV	{"email": "srodionov_101968@postgrespro.ru", "phone": "+70560671869"}
0005434157560	2865B4	7538 752640	VALENTINA NESTEROVA	{"email": "valentinanesterova-101966@postgrespro.ru", "phone": "+70142318626"}
0005434157561	CCAD27	0685 879560	VIKTOR MOROZOV	{"email": "viktor.morozov08111970@postgrespro.ru", "phone": "+70787497792"}
0005434157562	EF3446	7781 901012	ARTEM SHEVCHENKO	{"phone": "+70264671957"}
0005434157563	89B52A	5457 528792	ANATOLIY EGOROV	{"phone": "+70461827305"}
0005434157564	89B52A	7288 314840	VIKTOR FILIPPOV	{"phone": "+70072509879"}
0005434157565	1577E0	4793 534323	RUMIYA ZAYCEVA	{"phone": "+70928035938"}
0005434157566	FE3339	2795 112629	ANDREY NIKOLAEV	{"email": "nikolaev.a_1964@postgrespro.ru", "phone": "+70051190247"}
0005434157567	12CB38	2486 083974	LIDIYA KUZNECOVA	{"phone": "+70632003648"}
0005434157568	12CB38	8293 371397	LIDIYA BELOVA	{"email": "l_belova27111983@postgrespro.ru", "phone": "+70500836085"}
0005434157569	12CB38	6103 762989	KSENIYA IVANOVA	{"phone": "+70347678488"}
0005434157570	A582B3	4821 543208	NATALYA OSIPOVA	{"email": "n-osipova-031979@postgrespro.ru", "phone": "+70516243911"}
0005434157571	A582B3	9008 308742	VALENTINA SIDOROVA	{"phone": "+70547121552"}
0005434157572	D3A349	1983 293093	RINAT KUZMIN	{"email": "r-kuzmin.1976@postgrespro.ru", "phone": "+70665351395"}
0005434157573	D3A349	2615 045880	IVAN VOLKOV	{"phone": "+70339763122"}
0005434157574	770908	9084 133599	ALEKSANDR VOROBEV	{"phone": "+70596512653"}
0005434157575	770908	0773 586717	IVAN FOMIN	{"email": "ivan.fomin_01101980@postgrespro.ru", "phone": "+70376637261"}
0005434157576	770908	7523 449826	ELENA VOROBEVA	{"phone": "+70904824033"}
0005434157577	B9A475	3327 541232	ELENA NESTEROVA	{"email": "nesterova_e1988@postgrespro.ru", "phone": "+70951021507"}
0005434157578	469464	3373 228638	SVETLANA IVANOVA	{"phone": "+70193449862"}
0005434157579	3E0428	6356 289061	YURIY MIKHAYLOV	{"phone": "+70184658852"}
0005434157580	3E0428	7013 187537	ALENA VOLKOVA	{"email": "volkova_alena-1967@postgrespro.ru", "phone": "+70996719453"}
0005434157581	00C7D5	9136 988112	DMITRIY KOZLOV	{"phone": "+70243239485"}
0005434157582	9F472D	7049 098697	ALINA DMITRIEVA	{"phone": "+70639540392"}
0005434157583	CCDA9E	2345 313124	ROMAN GORBUNOV	{"email": "r.gorbunov.1974@postgrespro.ru", "phone": "+70043956094"}
0005434157584	CCDA9E	2861 566164	ALEKSANDR ZHUKOV	{"phone": "+70304842817"}
0005434157585	CCDA9E	3898 455343	MIKHAIL MAKSIMOV	{"phone": "+70679421235"}
0005434157586	746EC3	3940 564101	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov29011984@postgrespro.ru", "phone": "+70277879794"}
0005434157587	07FB55	1448 297162	KSENIYA KUZNECOVA	{"email": "kuznecova-k-1958@postgrespro.ru", "phone": "+70729293485"}
0005434157588	07FB55	1967 143856	ALEKSANDR OSIPOV	{"email": "osipova.091973@postgrespro.ru", "phone": "+70742518249"}
0005434157589	07FB55	6373 274716	ZINAIDA BORISOVA	{"phone": "+70128907275"}
0005434157590	2EFC46	7902 454891	ANDREY PAVLOV	{"email": "pavlov-andrey.021984@postgrespro.ru", "phone": "+70045299967"}
0005434157591	5FFBA6	2522 433903	IRINA FILATOVA	{"email": "filatovairina-1968@postgrespro.ru", "phone": "+70543869240"}
0005434157592	5FFBA6	2866 191630	VIKTORIYA EGOROVA	{"email": "egorova_viktoriya_18051973@postgrespro.ru", "phone": "+70919988285"}
0005434157593	916885	5585 685920	OLGA FILATOVA	{"email": "o.filatova_26041974@postgrespro.ru", "phone": "+70660738437"}
0005434157594	951E3E	4515 381642	NINA ALEKSANDROVA	{"phone": "+70347464210"}
0005434157595	951E3E	0688 002703	OLGA MIRONOVA	{"email": "mironova-o.021968@postgrespro.ru", "phone": "+70725238253"}
0005434157596	951E3E	2468 559218	OLGA PETROVA	{"email": "o-petrova-03021976@postgrespro.ru", "phone": "+70214904882"}
0005434157597	951E3E	3737 118289	VIKTOR VASILEV	{"phone": "+70042415212"}
0005434157598	39FC4B	9961 342910	KIRILL SCHERBAKOV	{"phone": "+70251583920"}
0005434157599	DE91A5	6067 300974	NINA MIKHAYLOVA	{"email": "n_mikhaylova-1976@postgrespro.ru", "phone": "+70011582954"}
0005434157600	2335FD	0494 892184	ANATOLIY MOROZOV	{"phone": "+70874025693"}
0005434157601	2335FD	0234 694211	VALENTINA VASILEVA	{"phone": "+70087485739"}
0005434157602	2335FD	6634 856243	DMITRIY PAVLOV	{"phone": "+70829112643"}
0005434157603	B5E5F5	0079 654027	ALEKSANDR NIKITIN	{"phone": "+70608223642"}
0005434157604	9263B0	7415 006589	VALENTINA IVANOVA	{"email": "ivanova.v_27081972@postgrespro.ru", "phone": "+70988318895"}
0005434157605	9263B0	5842 445715	MARINA VOROBEVA	{"phone": "+70545616281"}
0005434157606	AF5AF3	9680 167624	RAISA BORISOVA	{"email": "borisova-r.011975@postgrespro.ru", "phone": "+70045028056"}
0005434157607	AF5AF3	5584 002707	VALENTINA KOMAROVA	{"phone": "+70441116449"}
0005434157608	F8EFBA	7267 067558	GRIGORIY SEMENOV	{"phone": "+70895857245"}
0005434157609	3478F3	1028 974616	ANATOLIY DAVYDOV	{"email": "a_davydov_091968@postgrespro.ru", "phone": "+70518837299"}
0005434157610	3478F3	8015 168924	NIKOLAY POPOV	{"phone": "+70584026960"}
0005434157611	3478F3	4978 979461	LYUDMILA TIKHONOVA	{"email": "tikhonova_l1972@postgrespro.ru", "phone": "+70175822986"}
0005434157612	FAD467	3215 765691	NADEZHDA YAKOVLEVA	{"phone": "+70598307220"}
0005434157613	FAD467	3075 518202	ALEKSANDR NIKOLAEV	{"phone": "+70110759069"}
0005434157614	109214	6140 639221	EKATERINA YUDINA	{"email": "e.yudina_28111970@postgrespro.ru", "phone": "+70126935782"}
0005434157615	B40A1A	5426 464205	SVETLANA ZHUKOVA	{"email": "s.zhukova071969@postgrespro.ru", "phone": "+70784739445"}
0005434157616	B40A1A	6741 772143	RUZALIYA IVANOVA	{"phone": "+70151360960"}
0005434157617	B40A1A	8305 692905	VARVARA SMIRNOVA	{"email": "smirnovav-21081971@postgrespro.ru", "phone": "+70677938131"}
0005434157618	B9D409	9948 722465	ALEKSANDR SIDOROV	{"email": "a.sidorov18051980@postgrespro.ru", "phone": "+70617403393"}
0005434157619	B9D409	3396 936276	NIKOLAY VOROBEV	{"email": "nikolay-vorobev.101978@postgrespro.ru", "phone": "+70461429756"}
0005434157620	C7D2C8	8654 032374	VALENTINA IVANOVA	{"email": "v_ivanova-29061960@postgrespro.ru", "phone": "+70386072819"}
0005434157621	C7D2C8	7819 595380	MARIYA ZAKHAROVA	{"phone": "+70489152191"}
0005434157622	303A42	8421 611333	DANIL FEDOROV	{"email": "d.fedorov_041975@postgrespro.ru", "phone": "+70200551800"}
0005434157623	016884	2162 897838	ANDREY ZAKHAROV	{"phone": "+70558973506"}
0005434157624	016884	1070 072253	OLGA IVANOVA	{"phone": "+70285019143"}
0005434157625	394AF3	8817 779144	ANDREY PETROV	{"email": "andrey-petrov21011968@postgrespro.ru", "phone": "+70383838581"}
0005434157626	D56DA1	2372 586215	LYUBOV GUSEVA	{"phone": "+70607531002"}
0005434157627	4EC758	2898 360762	YULIYA PETROVA	{"email": "y-petrova31011971@postgrespro.ru", "phone": "+70972698833"}
0005434157628	6C696C	9732 501844	ZINAIDA KISELEVA	{"email": "kiseleva_zinaida021981@postgrespro.ru", "phone": "+70745553239"}
0005434157629	6C696C	0044 445464	VALENTINA MIKHAYLOVA	{"phone": "+70290133603"}
0005434157630	6C696C	4828 455338	PETR FILIPPOV	{"email": "petr-filippov.03051965@postgrespro.ru", "phone": "+70079810177"}
0005434157631	FE1CD7	5696 947217	SERGEY VASILEV	{"email": "s-vasilev.111962@postgrespro.ru", "phone": "+70309072513"}
0005434157632	3995D2	7718 661704	YURIY KULIKOV	{"email": "kulikovyuriy28111962@postgrespro.ru", "phone": "+70519681761"}
0005434157633	B92BC0	9154 915018	ALEKSEY IVANOV	{"phone": "+70712889977"}
0005434157634	B92BC0	3108 166956	VLADIMIR EGOROV	{"phone": "+70190987451"}
0005434157635	E0D500	2582 775856	IRINA ILINA	{"phone": "+70053229729"}
0005434157636	224ADF	3552 431010	ZINAIDA SCHERBAKOVA	{"phone": "+70123610272"}
0005434157637	E9DAB4	9192 802873	EDUARD ANDREEV	{"email": "eduardandreev_101966@postgrespro.ru", "phone": "+70146004292"}
0005434157638	E9DAB4	7807 483916	ALEKSEY FEDOROV	{"email": "fedorov.a.1979@postgrespro.ru", "phone": "+70220258964"}
0005434157639	3BD680	6115 257413	VALENTINA FEDOROVA	{"email": "fedorova-valentina_081966@postgrespro.ru", "phone": "+70137895337"}
0005434157640	846CBD	6442 168071	VLADISLAV KOROLEV	{"email": "korolev_v04101965@postgrespro.ru", "phone": "+70029511853"}
0005434157641	B6AA02	2123 689883	TAMARA GORBUNOVA	{"phone": "+70074069598"}
0005434157642	E3DD28	1655 633303	SVETLANA ZHURAVLEVA	{"email": "szhuravleva-031966@postgrespro.ru", "phone": "+70632465420"}
0005434157643	923605	6871 736781	VITALIY KUDRYASHOV	{"email": "kudryashov_vitaliy_20111970@postgrespro.ru", "phone": "+70291704609"}
0005434157644	1A4BA8	5754 956243	SERGEY ILIN	{"phone": "+70794932979"}
0005434157645	1A4BA8	0455 707787	MARIYA NIKOLAEVA	{"phone": "+70701737463"}
0005434157646	626630	8270 524913	IRINA TARASOVA	{"phone": "+70015147190"}
0005434157647	626630	8298 507873	VLADIMIR MAKAROV	{"phone": "+70383659232"}
0005434157648	857E94	0687 586545	MAKSIM PETROV	{"email": "petrov-m_1981@postgrespro.ru", "phone": "+70540703216"}
0005434157649	857E94	3694 899101	VIKTOR GORBUNOV	{"phone": "+70019665069"}
0005434157650	5690B7	0779 200422	ARINA KOZLOVA	{"email": "kozlova-arina-021972@postgrespro.ru", "phone": "+70481849553"}
0005434157651	5690B7	0817 574243	LYUDMILA GAVRILOVA	{"email": "gavrilova-l-16081980@postgrespro.ru", "phone": "+70592487050"}
0005434157652	C58C9B	2387 631089	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy-1967@postgrespro.ru", "phone": "+70550813343"}
0005434157653	36666B	6250 626118	EKATERINA KONOVALOVA	{"email": "konovalova_ekaterina_1981@postgrespro.ru", "phone": "+70540765967"}
0005434157654	F6227D	2574 005573	YURIY MATVEEV	{"email": "matveev.y1985@postgrespro.ru", "phone": "+70760386257"}
0005434157655	AE04B0	4715 008167	POLINA GUSEVA	{"phone": "+70386880419"}
0005434157656	F43CDD	0618 753822	LYUBOV DAVYDOVA	{"email": "lyubov_davydova-041974@postgrespro.ru", "phone": "+70040793006"}
0005434157657	F43CDD	5103 528119	LYUDMILA SOKOLOVA	{"email": "lyudmilasokolova_1973@postgrespro.ru", "phone": "+70524664300"}
0005434157658	2CA6B7	9372 853966	ELENA PAVLOVA	{"phone": "+70799616866"}
0005434157659	B73C10	6219 082263	MARGARITA SOROKINA	{"email": "margarita_sorokina.1981@postgrespro.ru", "phone": "+70763786661"}
0005434157660	4AFC98	8335 368675	TATYANA PETROVA	{"email": "petrova_tatyana09021970@postgrespro.ru", "phone": "+70512686921"}
0005434157661	4AFC98	4349 195080	PAVEL KISELEV	{"phone": "+70592176777"}
0005434157662	3BB66D	3320 824841	VLADIMIR MIRONOV	{"email": "mironov-v29101960@postgrespro.ru", "phone": "+70918103585"}
0005434157663	3BB66D	1770 220612	VLADIMIR ROMANOV	{"email": "v-romanov_11021976@postgrespro.ru", "phone": "+70717170070"}
0005434157664	3BB66D	2977 297414	ELENA FEDOROVA	{"phone": "+70846124772"}
0005434157665	C157DB	1937 137851	NINA IVANOVA	{"phone": "+70126340433"}
0005434157666	8B17F6	0507 009953	OLGA SAVELEVA	{"phone": "+70646386373"}
0005434157667	279820	3365 383484	VALENTINA NIKIFOROVA	{"email": "nikiforovav081977@postgrespro.ru", "phone": "+70770204559"}
0005434157668	80FB0B	7842 627558	AMINA VOLKOVA	{"phone": "+70428678312"}
0005434157669	E446AB	4822 756944	KSENIYA VLASOVA	{"email": "kvlasova1973@postgrespro.ru", "phone": "+70592685127"}
0005434157670	AE83D7	7928 696889	DENIS FEDOTOV	{"phone": "+70632432382"}
0005434157671	AE83D7	0279 192966	LYUBOV SMIRNOVA	{"email": "l_smirnova03031979@postgrespro.ru", "phone": "+70834795689"}
0005434157672	CE924A	6325 703027	ELENA NESTEROVA	{"phone": "+70998391784"}
0005434157673	CE924A	1583 719751	NINA NIKIFOROVA	{"email": "nnikiforova_05031970@postgrespro.ru", "phone": "+70590169359"}
0005434157674	6D4AE7	3675 159118	MIKHAIL MOISEEV	{"phone": "+70083580379"}
0005434157675	6D4AE7	1922 567184	KSENIYA PAVLOVA	{"phone": "+70228366248"}
0005434157676	6B0A22	4417 516361	YULIYA MAKAROVA	{"phone": "+70672946944"}
0005434157677	3FC13C	8174 900419	VALENTINA FILIPPOVA	{"phone": "+70538151520"}
0005434157678	3FC13C	0330 746997	ALEKSANDR MELNIKOV	{"phone": "+70451718156"}
0005434157679	FA1AB6	2416 310962	FEDOR VOLKOV	{"email": "volkov-f-101977@postgrespro.ru", "phone": "+70075208943"}
0005434157680	FA1AB6	8884 293093	OKSANA MIKHAYLOVA	{"email": "mikhaylova-oksana101962@postgrespro.ru", "phone": "+70673615343"}
0005434157681	FA1AB6	1836 517928	ALEKSEY BORISOV	{"phone": "+70277754822"}
0005434157682	0F800D	8426 696988	NIKITA NIKITIN	{"email": "nnikitin.041970@postgrespro.ru", "phone": "+70044369415"}
0005434157683	0F800D	6665 573418	IRINA IVANOVA	{"email": "i_ivanova06111964@postgrespro.ru", "phone": "+70912013106"}
0005434157684	8C28D1	0555 449010	PAVEL FEDOROV	{"email": "fedorov_p-1982@postgrespro.ru", "phone": "+70603312365"}
0005434157685	566409	3646 049269	LARISA KOZLOVA	{"phone": "+70578935729"}
0005434157686	D22356	1066 892326	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov-23031958@postgrespro.ru", "phone": "+70277765190"}
0005434157687	B1582C	5136 770274	NIKOLAY FROLOV	{"phone": "+70399404658"}
0005434157688	B15CB8	4360 260744	IRINA GUSEVA	{"email": "guseva-irina_101974@postgrespro.ru", "phone": "+70397911268"}
0005434157689	B15CB8	3489 167161	LYUDMILA ZHUKOVA	{"email": "zhukoval_101976@postgrespro.ru", "phone": "+70480441932"}
0005434157690	62F2D9	5542 829017	ALBINA ORLOVA	{"phone": "+70265065113"}
0005434157691	62F2D9	4597 202726	ANNA PETROVA	{"phone": "+70938902807"}
0005434157692	23DAB3	0293 449186	VITALIY ZAYCEV	{"phone": "+70119000657"}
0005434157693	0F00C5	7054 480481	VYACHESLAV SAVELEV	{"phone": "+70925611344"}
0005434157694	5B424D	9751 923938	DMITRIY BARANOV	{"email": "d_baranov1980@postgrespro.ru", "phone": "+70465346739"}
0005434157695	E51FBB	5869 928269	SERGEY BELOV	{"email": "sbelov061979@postgrespro.ru", "phone": "+70296820495"}
0005434157696	1E9AF8	8849 835323	ALEKSANDR IVANOV	{"phone": "+70099642521"}
0005434157697	1E9AF8	7991 682292	TATYANA KUZNECOVA	{"phone": "+70225322406"}
0005434157698	BDA3EE	5466 945538	YURIY SCHERBAKOV	{"email": "yuriyscherbakov-071976@postgrespro.ru", "phone": "+70610064007"}
0005434157699	BDA3EE	1296 334583	PAVEL KUDRYASHOV	{"email": "p.kudryashov1972@postgrespro.ru", "phone": "+70125955139"}
0005434157700	947400	8267 111879	ALEKSEY PAVLOV	{"email": "pavlov_aleksey1966@postgrespro.ru", "phone": "+70562947323"}
0005434157701	947400	4788 997779	ALEKSEY PETROV	{"phone": "+70868521300"}
0005434157702	B878A8	7594 127843	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-a-051965@postgrespro.ru", "phone": "+70304956953"}
0005434157703	B878A8	8869 214911	PELAGEYA TIKHONOVA	{"phone": "+70218974989"}
0005434157704	32762B	9155 675186	NATALYA GRISHINA	{"email": "grishina-natalya-031971@postgrespro.ru", "phone": "+70543107504"}
0005434157705	2CAE14	0072 207691	OLGA KUZNECOVA	{"phone": "+70791731174"}
0005434157706	4B6A38	1092 134422	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov-14121976@postgrespro.ru", "phone": "+70898182813"}
0005434157707	4B6A38	0633 612391	SERGEY ANTONOV	{"phone": "+70331979401"}
0005434157708	FC3C44	9262 742659	ANDREY KUZNECOV	{"email": "andrey.kuznecov1969@postgrespro.ru", "phone": "+70711905571"}
0005434157709	FC3C44	4978 863936	DARYA FEDOROVA	{"email": "fedorovad_1976@postgrespro.ru", "phone": "+70442450036"}
0005434157710	B82CF2	6888 848732	VITALIY SOROKIN	{"email": "sorokinv_071976@postgrespro.ru", "phone": "+70929409327"}
0005434157711	C3A630	3982 428728	TATYANA TIMOFEEVA	{"phone": "+70934004458"}
0005434157712	89BE16	0092 253493	KONSTANTIN KOZLOV	{"email": "kozlov-k1977@postgrespro.ru", "phone": "+70751294096"}
0005434157713	003D96	1563 117966	VLADIMIR SEMENOV	{"phone": "+70681739819"}
0005434157714	003D96	8398 903748	IGOR BARANOV	{"phone": "+70770952756"}
0005434157715	E94555	5734 453394	YURIY PAVLOV	{"email": "pavlov.yuriy.17101976@postgrespro.ru", "phone": "+70670670053"}
0005434157716	8E89E3	5476 373886	IVAN MOROZOV	{"phone": "+70475264515"}
0005434157717	CD4D42	5357 231606	NIKOLAY FOMIN	{"email": "n-fomin13011977@postgrespro.ru", "phone": "+70374289029"}
0005434157718	FB2B42	1909 753775	VLADIMIR SERGEEV	{"phone": "+70058830323"}
0005434157719	1D2B51	9272 157178	MIKHAIL MIKHAYLOV	{"email": "mikhaylovm.1973@postgrespro.ru", "phone": "+70470875453"}
0005434157720	1D2B51	1111 031296	DAMIR KUZNECOV	{"phone": "+70038253713"}
0005434157721	1D2B51	0669 627825	OLGA ZAKHAROVA	{"phone": "+70787687510"}
0005434157722	E955FD	7877 260345	MARIYA SCHERBAKOVA	{"phone": "+70067050035"}
0005434157723	42A836	2121 388460	LARISA VOROBEVA	{"phone": "+70272637411"}
0005434157724	8951C5	7061 294321	TAMARA KUZNECOVA	{"email": "tamara_kuznecova.26041973@postgrespro.ru", "phone": "+70220622478"}
0005434157725	459F47	8962 963135	OLGA SIDOROVA	{"phone": "+70603843196"}
0005434157726	CFEF1D	6963 552088	VIKTOR FROLOV	{"email": "viktor.frolov-091978@postgrespro.ru", "phone": "+70162973737"}
0005434157727	CFEF1D	7767 840125	OLESYA DAVYDOVA	{"phone": "+70581603829"}
0005434157728	6CFE71	0029 282454	TATYANA TARASOVA	{"email": "tatyana_tarasova011974@postgrespro.ru", "phone": "+70658602850"}
0005434157729	D853AC	0502 106878	GENNADIY MELNIKOV	{"phone": "+70946991654"}
0005434157730	E4733E	4671 536567	OLEG CHERNOV	{"email": "chernovoleg_29081965@postgrespro.ru", "phone": "+70027533897"}
0005434157731	F8ECDC	7286 052151	PAVEL MAKSIMOV	{"email": "pavel.maksimov_1970@postgrespro.ru", "phone": "+70212331810"}
0005434157732	1A0482	2291 153476	NADEZHDA OSIPOVA	{"phone": "+70684551813"}
0005434157733	EF0332	2743 067492	VALERIY IVANOV	{"email": "vivanov-121958@postgrespro.ru", "phone": "+70770834730"}
0005434157734	EF0332	1487 847311	NINA FROLOVA	{"phone": "+70376663629"}
0005434157735	240585	0379 823580	ANDREY VOLKOV	{"email": "volkov_andrey101971@postgrespro.ru", "phone": "+70981269120"}
0005434157736	3DCB11	8684 686619	OKSANA ANDREEVA	{"phone": "+70455945373"}
0005434157737	3DCB11	9819 579398	VLADIMIR POPOV	{"email": "vladimir.popov_20031974@postgrespro.ru", "phone": "+70073436619"}
0005434157738	2F9E3E	8651 519829	VALENTIN ABRAMOV	{"phone": "+70655590058"}
0005434157739	F3E680	1941 191282	GALINA PAVLOVA	{"email": "pavlova_galina.23011969@postgrespro.ru", "phone": "+70207133385"}
0005434157740	F3E680	9927 210377	OKSANA PETROVA	{"phone": "+70933352636"}
0005434157741	A9BEBC	6350 467756	VLADIMIR IVANOV	{"email": "ivanovv-121962@postgrespro.ru", "phone": "+70611011986"}
0005434157742	A4FAD5	9846 668666	ILMIR NIKOLAEV	{"email": "nikolaev-ilmir16051974@postgrespro.ru", "phone": "+70753876092"}
0005434157743	A4FAD5	7528 622502	ELENA VLASOVA	{"phone": "+70315243288"}
0005434157744	AEBCB2	5174 763700	NIKITA SIDOROV	{"email": "nikitasidorov-091980@postgrespro.ru", "phone": "+70012054609"}
0005434157745	AEBCB2	8441 033529	ELENA KUZNECOVA	{"email": "kuznecova.elena.1963@postgrespro.ru", "phone": "+70741031073"}
0005434157746	C0329A	5328 581401	IRINA ANDREEVA	{"phone": "+70611912103"}
0005434157747	C0329A	5170 840815	ALEKSANDR BELOV	{"email": "belov_aleksandr031960@postgrespro.ru", "phone": "+70763774594"}
0005434157748	DB2537	6808 021509	OLGA POPOVA	{"email": "o.popova16011985@postgrespro.ru", "phone": "+70619874559"}
0005434157749	BDA0B8	5399 407894	NATALYA KOLESNIKOVA	{"email": "kolesnikova.natalya_26111968@postgrespro.ru", "phone": "+70895496739"}
0005434157750	4711A4	7836 487234	ILGIZ EGOROV	{"email": "ilgizegorov_1985@postgrespro.ru", "phone": "+70806220048"}
0005434157751	4C6359	5852 886513	TATYANA NIKIFOROVA	{"email": "tatyana_nikiforova29011974@postgrespro.ru", "phone": "+70348266540"}
0005434157752	79C792	4844 835387	NIKOLAY IVANOV	{"phone": "+70194295621"}
0005434157753	0C7A0A	5543 453295	MARINA NOVIKOVA	{"phone": "+70415256612"}
0005434157754	0C7A0A	9696 333984	DMITRIY NAUMOV	{"phone": "+70457299216"}
0005434157755	EDD3BB	2590 712726	YANA EGOROVA	{"phone": "+70222895212"}
0005434157756	8DE4EE	1763 873895	OLGA FROLOVA	{"email": "olga.frolova.011976@postgrespro.ru", "phone": "+70004149764"}
0005434157757	24F66F	8241 434739	KSENIYA FROLOVA	{"email": "kseniyafrolova-101973@postgrespro.ru", "phone": "+70604127186"}
0005434157758	24F66F	7562 032038	TATYANA FOMINA	{"phone": "+70859658508"}
0005434157759	562A61	6746 981530	TATYANA OSIPOVA	{"email": "tatyana.osipova-10041961@postgrespro.ru", "phone": "+70551052475"}
0005434157760	562A61	0583 675303	ALEKSEY ROMANOV	{"email": "romanov_aleksey1964@postgrespro.ru", "phone": "+70541824426"}
0005434157761	959A84	7771 960544	IVAN SMIRNOV	{"email": "i.smirnov011958@postgrespro.ru", "phone": "+70289844788"}
0005434157762	959A84	5075 127670	VIKTOR ZAKHAROV	{"email": "zakharov-v_08091969@postgrespro.ru", "phone": "+70985621238"}
0005434157763	54D15B	6943 206604	EVELINA POLYAKOVA	{"phone": "+70106067466"}
0005434157764	1A4C27	1139 560560	NATALYA IVANOVA	{"email": "n_ivanova-15011963@postgrespro.ru", "phone": "+70593236610"}
0005434157765	1A4C27	3318 614472	ARINA ANDREEVA	{"email": "arinaandreeva071982@postgrespro.ru", "phone": "+70277304759"}
0005434157766	C64865	2699 028948	ALEKSANDR KUZNECOV	{"phone": "+70915253476"}
0005434157767	584A1F	0926 268993	ANDREY KUZNECOV	{"phone": "+70269711203"}
0005434157768	584A1F	7872 799463	ANNA MIKHAYLOVA	{"email": "a_mikhaylova.13041972@postgrespro.ru", "phone": "+70878811514"}
0005434157769	833184	3616 984496	VYACHESLAV SEMENOV	{"phone": "+70050726930"}
0005434157770	833184	1234 313578	VALERIY KUZNECOV	{"phone": "+70151506661"}
0005434157771	833184	7172 024450	EVGENIY IVANOV	{"phone": "+70324691069"}
0005434157772	8AC489	6285 593885	VIOLETTA SIDOROVA	{"phone": "+70230872860"}
0005434157773	8AC489	9712 235996	MIKHAIL GERASIMOV	{"phone": "+70041287807"}
0005434157774	8AC489	3025 283589	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova_1979@postgrespro.ru", "phone": "+70033248615"}
0005434157775	2C709F	7262 748343	LYUDMILA MIKHAYLOVA	{"email": "l.mikhaylova.071970@postgrespro.ru", "phone": "+70018472370"}
0005434157776	60CC67	7441 500713	KLAVDIYA KAZAKOVA	{"email": "k-kazakova1955@postgrespro.ru", "phone": "+70191630244"}
0005434157777	438FD4	5677 120615	ILYA VOLKOV	{"email": "volkovi.1981@postgrespro.ru", "phone": "+70392068469"}
0005434157778	721DF8	4357 642967	ALEKSEY MEDVEDEV	{"email": "medvedev_aleksey111974@postgrespro.ru", "phone": "+70085707273"}
0005434157779	B44AD6	2930 274887	ALLA DENISOVA	{"phone": "+70971485902"}
0005434157780	3C196F	0796 080842	VERA SAVELEVA	{"email": "vera_saveleva-091975@postgrespro.ru", "phone": "+70938445574"}
0005434157781	104397	1279 218743	ELENA KALININA	{"phone": "+70670382125"}
0005434157782	9D315E	1706 039745	ALEKSANDR MAKAROV	{"email": "a_makarov.19041969@postgrespro.ru", "phone": "+70692058126"}
0005434157783	9D315E	2040 875056	VYACHESLAV ZAYCEV	{"email": "zaycev.v.16121964@postgrespro.ru", "phone": "+70833400252"}
0005434157784	8D717A	2550 499385	GULSINA LEBEDEVA	{"email": "gulsina-lebedeva_1963@postgrespro.ru", "phone": "+70361728467"}
0005434157785	90C4DB	0394 625046	EVGENIY MOROZOV	{"phone": "+70423900973"}
0005434157786	E25BBC	5023 490186	DARYA IVANOVA	{"email": "d-ivanova_061966@postgrespro.ru", "phone": "+70333795368"}
0005434157787	E25BBC	8834 413454	ELENA MIRONOVA	{"email": "e-mironova-101966@postgrespro.ru", "phone": "+70525215540"}
0005434157788	866E31	5611 697692	ALEKSANDR MOROZOV	{"email": "morozovaleksandr02071973@postgrespro.ru", "phone": "+70147096065"}
0005434157789	866E31	7388 717936	VALERIY NIKITIN	{"email": "nikitin-v.20081967@postgrespro.ru", "phone": "+70211061058"}
0005434157790	E849B3	5445 794065	EKATERINA LUKYANOVA	{"phone": "+70873143309"}
0005434157791	CB59AE	4736 698498	KONSTANTIN NIKOLAEV	{"phone": "+70708789792"}
0005434157792	242D40	0711 271046	VALERIY KUZMIN	{"email": "valeriy-kuzmin-19121976@postgrespro.ru", "phone": "+70790024043"}
0005434157793	0832C6	2378 198504	LILIYA SOLOVEVA	{"phone": "+70518184958"}
0005434157794	A26820	2514 553378	MARK MAKAROV	{"email": "mark_makarov-22071969@postgrespro.ru", "phone": "+70856563486"}
0005434157795	BFEA14	6632 646987	VALERIYA GERASIMOVA	{"phone": "+70605290470"}
0005434157796	ECEFE1	4421 745754	KRISTINA KOROLEVA	{"email": "koroleva.k-12041964@postgrespro.ru", "phone": "+70192587247"}
0005434157797	ECEFE1	2993 668973	VALENTIN KISELEV	{"phone": "+70354172567"}
0005434157798	30D49A	0836 179564	ALEKSANDRA POPOVA	{"phone": "+70711679536"}
0005434157799	FA2C90	7215 792661	ALEKSANDR BONDARENKO	{"phone": "+70852003282"}
0005434157800	BAF588	7123 094484	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov02021977@postgrespro.ru", "phone": "+70790107615"}
0005434157801	54E09A	5742 005390	TATYANA BARANOVA	{"email": "tatyana_baranova-061964@postgrespro.ru", "phone": "+70434015143"}
0005434157802	54E09A	9603 840193	SERGEY KUZNECOV	{"phone": "+70126298996"}
0005434157803	C20555	4169 519187	MARIYA GUSEVA	{"email": "gusevamariya.06051963@postgrespro.ru", "phone": "+70384638904"}
0005434157914	9F94C2	1787 126957	ALEKSANDR YAKOVLEV	{"phone": "+70272546967"}
0005434157804	EC8939	5923 302502	DMITRIY MAKSIMOV	{"email": "d-maksimov.1984@postgrespro.ru", "phone": "+70468548269"}
0005434157805	EAD162	1985 169709	NINA MOROZOVA	{"email": "morozovanina-1961@postgrespro.ru", "phone": "+70758528832"}
0005434157806	EAD162	0046 757598	RUSLAN MEDVEDEV	{"phone": "+70165852651"}
0005434157807	EDA33D	9443 945694	RITA SEMENOVA	{"email": "rsemenova_071973@postgrespro.ru", "phone": "+70580575884"}
0005434157808	EDA33D	4826 500195	FEDOR KUZNECOV	{"email": "f-kuznecov1970@postgrespro.ru", "phone": "+70633744289"}
0005434157809	23FE0E	4026 468825	PAVEL TIKHONOV	{"phone": "+70528698076"}
0005434157810	D30457	1310 454509	YULIYA RYABOVA	{"email": "y_ryabova1985@postgrespro.ru", "phone": "+70520377109"}
0005434157811	EC69D8	3148 882914	ALEKSANDRA KALININA	{"phone": "+70539841604"}
0005434157812	EC69D8	5147 150833	NAZAR KISELEV	{"email": "n.kiselev_06121977@postgrespro.ru", "phone": "+70125140862"}
0005434157813	8174A1	2692 839440	NATALYA BARANOVA	{"phone": "+70636184788"}
0005434157814	F1B422	5457 350343	DMITRIY KONOVALOV	{"email": "konovalov_dmitriy.1976@postgrespro.ru", "phone": "+70378024572"}
0005434157815	3D8A08	5334 937719	POLINA BELOVA	{"phone": "+70734876513"}
0005434157816	805AA5	1432 619356	VADIM MIKHAYLOV	{"phone": "+70269301276"}
0005434157817	B58B3A	0197 408996	ELIZAVETA FROLOVA	{"phone": "+70260120451"}
0005434157818	B58B3A	8477 432159	ELENA ROMANOVA	{"email": "e.romanova1975@postgrespro.ru", "phone": "+70220522353"}
0005434157819	99340A	1644 480829	ALEKSEY IVANOV	{"email": "a.ivanov13011972@postgrespro.ru", "phone": "+70757820384"}
0005434157820	44B1ED	0391 611686	ELENA GRISHINA	{"email": "grishina_e-1967@postgrespro.ru", "phone": "+70669408150"}
0005434157821	981C6A	7642 240186	LIDIYA MEDVEDEVA	{"email": "lidiya-medvedeva-051977@postgrespro.ru", "phone": "+70194830272"}
0005434157822	981C6A	9553 819716	DMITRIY MARTYNOV	{"email": "martynov-dmitriy-081973@postgrespro.ru", "phone": "+70783036781"}
0005434157823	981C6A	6118 066558	SVETLANA KOVALEVA	{"phone": "+70308876357"}
0005434157824	C1E62E	6268 751727	NIKOLAY ALEKSEEV	{"email": "alekseev-n12011981@postgrespro.ru", "phone": "+70130521972"}
0005434157825	C1E62E	1355 500303	VIKTOR ILIN	{"email": "vilin-061970@postgrespro.ru", "phone": "+70487800064"}
0005434157826	C1E62E	8555 368258	LIDIYA SEMENOVA	{"phone": "+70744392826"}
0005434157827	A4F63A	4488 061971	EVGENIY NIKITIN	{"email": "nikitin.evgeniy1974@postgrespro.ru", "phone": "+70074368983"}
0005434157828	A4F63A	3460 001172	SVETLANA NIKIFOROVA	{"email": "nikiforova-s.1975@postgrespro.ru", "phone": "+70199160205"}
0005434157829	A4F63A	8367 305860	NIKOLAY KOZLOV	{"phone": "+70360906480"}
0005434157830	E1C8C8	7656 998517	IVAN KISELEV	{"email": "ivan_kiselev29121968@postgrespro.ru", "phone": "+70942702129"}
0005434157831	395AD4	7496 352712	DMITRIY TARASOV	{"phone": "+70263850507"}
0005434157832	30D191	0614 938601	AYRAT MAKSIMOV	{"phone": "+70942961126"}
0005434157833	D8C27C	3867 327562	RITA ABRAMOVA	{"email": "abramova.rita111972@postgrespro.ru", "phone": "+70749480184"}
0005434157834	D8C27C	1074 771833	GEORGIY FEDOTOV	{"email": "georgiy_fedotov-10071982@postgrespro.ru", "phone": "+70786778320"}
0005434157835	598A47	2909 504807	YURIY TIKHONOV	{"phone": "+70112078155"}
0005434157836	0F6C84	5380 255691	GALINA MELNIKOVA	{"phone": "+70694725814"}
0005434157837	31453D	5194 929819	IRINA SEMENOVA	{"phone": "+70920759452"}
0005434157838	F2ADD1	8844 503697	ALEKSANDR SMIRNOV	{"email": "smirnov-a-03031983@postgrespro.ru", "phone": "+70210735483"}
0005434157839	751EB8	8875 519115	SHAMIL VASILEV	{"phone": "+70295921416"}
0005434157840	751EB8	5903 751343	ANTONINA KONOVALOVA	{"email": "konovalova-antonina021966@postgrespro.ru", "phone": "+70883846040"}
0005434157841	316AC5	0702 137478	ELENA OSIPOVA	{"phone": "+70394034835"}
0005434157842	316AC5	3985 628154	NATALYA KUZNECOVA	{"email": "kuznecova-n_1976@postgrespro.ru", "phone": "+70285047018"}
0005434157843	DFBF18	1382 122911	DMITRIY FROLOV	{"email": "d-frolov_21071972@postgrespro.ru", "phone": "+70729080938"}
0005434157844	F9BA23	2458 044935	ANZHELIKA NIKIFOROVA	{"email": "anzhelika-nikiforova.011981@postgrespro.ru", "phone": "+70878782823"}
0005434157845	AEFCA2	1129 754009	YULIYA LEBEDEVA	{"phone": "+70702336188"}
0005434157846	16C0AE	8173 976633	PAVEL MIKHAYLOV	{"email": "pavelmikhaylov_1979@postgrespro.ru", "phone": "+70869734351"}
0005434157847	16C0AE	4728 439770	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov30111968@postgrespro.ru", "phone": "+70681301569"}
0005434157848	A530CE	0300 868709	VLADIMIR VLASOV	{"email": "vlasov_v1972@postgrespro.ru", "phone": "+70766200396"}
0005434157849	956C45	5385 598876	SERGEY OSIPOV	{"email": "s_osipov_021955@postgrespro.ru", "phone": "+70125296269"}
0005434157850	F0A286	1090 484368	OLGA SOLOVEVA	{"email": "olga-soloveva.011977@postgrespro.ru", "phone": "+70968643975"}
0005434157851	3BD051	7800 754141	EKATERINA NESTEROVA	{"phone": "+70780233987"}
0005434157852	C557F3	2608 601827	SERGEY KOZLOV	{"phone": "+70255265615"}
0005434157853	20824C	5967 362786	GALINA RYABOVA	{"phone": "+70792804881"}
0005434157854	20824C	9473 585917	VASILIY KUZNECOV	{"email": "kuznecov_v1974@postgrespro.ru", "phone": "+70800478832"}
0005434157855	1FE81B	9370 755505	ANGELINA KISELEVA	{"email": "kiseleva_angelina-29121987@postgrespro.ru", "phone": "+70535754309"}
0005434157856	0E4516	0521 706713	PAVEL MELNIKOV	{"email": "melnikov_pavel_071982@postgrespro.ru", "phone": "+70902270619"}
0005434157857	0E4516	6366 522682	RAISA MIKHAYLOVA	{"email": "mikhaylovar_03051975@postgrespro.ru", "phone": "+70963815146"}
0005434157858	3CF5CC	2841 363506	ROZALIYA ZAYCEVA	{"email": "rozaliya.zayceva1976@postgrespro.ru", "phone": "+70300620912"}
0005434157859	01796B	8347 608509	GALINA MATVEEVA	{"email": "galina.matveeva1971@postgrespro.ru", "phone": "+70762728076"}
0005434157860	822D22	8092 040868	LYUDMILA ILINA	{"email": "lyudmila_ilina_101975@postgrespro.ru", "phone": "+70108453319"}
0005434157861	822D22	9211 107718	ALEKSANDR STEPANOV	{"phone": "+70277489421"}
0005434157862	BAE969	5948 930881	ALEKSEY NAZAROV	{"email": "nazarov.a.091973@postgrespro.ru", "phone": "+70887110213"}
0005434157863	BAE969	2014 526305	DANA MEDVEDEVA	{"email": "dana-medvedeva18011966@postgrespro.ru", "phone": "+70417512960"}
0005434157864	95B640	4457 844618	VLADIMIR ILIN	{"email": "ilin.v_121977@postgrespro.ru", "phone": "+70998128876"}
0005434157865	95B640	5987 174039	VLADIMIR VASILEV	{"email": "vasilev.v.081978@postgrespro.ru", "phone": "+70972087593"}
0005434157866	5548B6	0960 966781	TATYANA MEDVEDEVA	{"phone": "+70529508578"}
0005434157867	A3AC1F	8828 915782	VERA BELYAEVA	{"email": "v-belyaeva1972@postgrespro.ru", "phone": "+70069886756"}
0005434157868	801E9E	7776 379163	ANASTASIYA SCHERBAKOVA	{"phone": "+70426796416"}
0005434157869	801E9E	7071 304938	KIRILL OSIPOV	{"phone": "+70213600761"}
0005434157870	26C4FA	1060 080698	IRINA MEDVEDEVA	{"email": "irina-medvedeva.24101982@postgrespro.ru", "phone": "+70857923157"}
0005434157871	26C4FA	0301 584213	NATALYA PAVLOVA	{"email": "pavlova.natalya-1983@postgrespro.ru", "phone": "+70825618040"}
0005434157872	21B159	2931 674670	OLGA ANTONOVA	{"email": "olgaantonova1965@postgrespro.ru", "phone": "+70566900407"}
0005434157873	DBAE73	5526 913249	DMITRIY IVANOV	{"email": "divanov.20101966@postgrespro.ru", "phone": "+70216605469"}
0005434157874	FA2DB6	7423 183468	EVGENIY MIKHAYLOV	{"phone": "+70533071579"}
0005434157875	B65636	2832 948862	VASILIY KULIKOV	{"phone": "+70696126275"}
0005434157876	B65636	5229 094298	VENIAMIN FROLOV	{"phone": "+70110130684"}
0005434157877	7E90E3	1672 590781	VALERIYA PAVLOVA	{"email": "pavlova-v.101966@postgrespro.ru", "phone": "+70846482465"}
0005434157878	7E90E3	5995 029246	OKSANA MELNIKOVA	{"email": "melnikovaoksana_1964@postgrespro.ru", "phone": "+70390438307"}
0005434157879	50899D	0703 572210	NADEZHDA DAVYDOVA	{"email": "n-davydova051981@postgrespro.ru", "phone": "+70746047510"}
0005434157880	50899D	3994 334078	ZINAIDA KOROLEVA	{"email": "z-koroleva.1985@postgrespro.ru", "phone": "+70735598589"}
0005434157881	50899D	4235 504428	NIKITA PAVLOV	{"email": "npavlov_1972@postgrespro.ru", "phone": "+70439486476"}
0005434157882	76992F	0872 683283	SERGEY ZAYCEV	{"phone": "+70285684814"}
0005434157883	37C52A	4232 127183	SERGEY SOLOVEV	{"email": "solovev.s_1967@postgrespro.ru", "phone": "+70179335695"}
0005434157884	A228FB	7053 683610	ALEKSANDR TIKHONOV	{"email": "tikhonova27041969@postgrespro.ru", "phone": "+70756002857"}
0005434157885	A228FB	6155 979765	MAKSIM SCHERBAKOV	{"email": "m_scherbakov-1964@postgrespro.ru", "phone": "+70885956361"}
0005434157886	A228FB	0298 562274	MARGARITA ARKHIPOVA	{"email": "m.arkhipova-051979@postgrespro.ru", "phone": "+70553424024"}
0005434157887	641302	4488 818800	ANTONINA PAVLOVA	{"email": "a.pavlova.23051968@postgrespro.ru", "phone": "+70201100685"}
0005434157888	6DE2E6	6260 594394	OLEG GORBUNOV	{"phone": "+70568909673"}
0005434157889	6DE2E6	3435 291708	ALEKSANDR VASILEV	{"email": "a-vasilev06051975@postgrespro.ru", "phone": "+70144204323"}
0005434157890	7CB4A0	2992 439377	VIKTOR ZHURAVLEV	{"phone": "+70937277907"}
0005434157891	7CB4A0	8732 324113	NIKITA MIKHAYLOV	{"phone": "+70404975817"}
0005434157892	BD42D4	2534 257725	SEMEN SEMENOV	{"phone": "+70502574088"}
0005434157894	BD42D4	9724 233226	MAKSIM MELNIKOV	{"email": "melnikov.maksim-061966@postgrespro.ru", "phone": "+70357610060"}
0005434157895	080A97	1459 429856	LYUDMILA YUDINA	{"email": "yudina-lyudmila_08041972@postgrespro.ru", "phone": "+70171311931"}
0005434157896	86B3B0	6410 209619	MAKSIM PETROV	{"email": "petrovmaksim18081972@postgrespro.ru", "phone": "+70237098333"}
0005434157897	6F1995	2836 892772	VLADISLAV MEDVEDEV	{"email": "vmedvedev.121975@postgrespro.ru", "phone": "+70743447880"}
0005434157898	141A1B	2744 817729	OLGA MELNIKOVA	{"email": "olgamelnikova31011967@postgrespro.ru", "phone": "+70170838045"}
0005434157899	E73E07	5338 846722	ANNA MARTYNOVA	{"email": "martynova-a_17101965@postgrespro.ru", "phone": "+70562770142"}
0005434157900	C83ADE	9114 323016	ELENA EGOROVA	{"email": "egorova_elena-021973@postgrespro.ru", "phone": "+70040765813"}
0005434157901	349BC0	7633 390087	NIKOLAY CHERNOV	{"email": "n-chernov_021978@postgrespro.ru", "phone": "+70852338462"}
0005434157902	86F3A3	8479 236287	ANASTASIYA NAZAROVA	{"email": "nazarovaanastasiya_091974@postgrespro.ru", "phone": "+70343152719"}
0005434157903	F6153F	9536 919954	LEONID SERGEEV	{"email": "sergeev_leonid071979@postgrespro.ru", "phone": "+70838513342"}
0005434157904	AB5EE3	5424 484981	KSENIYA KARPOVA	{"email": "karpova-kseniya_24081978@postgrespro.ru", "phone": "+70635194706"}
0005434157905	AB5EE3	7298 033823	EVGENIYA NIKOLAEVA	{"email": "evgeniya-nikolaeva1980@postgrespro.ru", "phone": "+70241381596"}
0005434157906	0CCE7B	2427 945258	LEONID SEMENOV	{"phone": "+70186307617"}
0005434157907	8C9F24	7110 109801	SERAFIMA MOROZOVA	{"phone": "+70716506303"}
0005434157908	8C9F24	9734 801345	DENIS DMITRIEV	{"email": "denisdmitriev_20061986@postgrespro.ru", "phone": "+70766239786"}
0005434157909	18AFFE	6463 476634	VALENTINA ZHUKOVA	{"phone": "+70078702117"}
0005434157910	8C7A67	6573 358965	BORIS MAKSIMOV	{"phone": "+70386189138"}
0005434157911	8C7A67	6258 337165	VADIM SOKOLOV	{"email": "sokolovvadim.1970@postgrespro.ru", "phone": "+70588799595"}
0005434157912	BE1CDA	3532 756795	ELENA SCHERBAKOVA	{"email": "elena-scherbakova-021969@postgrespro.ru", "phone": "+70454659789"}
0005434157913	132D41	1807 733367	TATYANA ZAKHAROVA	{"email": "zakharovat_19081972@postgrespro.ru", "phone": "+70346041273"}
0005434157915	9F94C2	9280 866705	VARVARA STEPANOVA	{"phone": "+70405458914"}
0005434157916	F480FD	8207 461488	TATYANA KUZNECOVA	{"phone": "+70688519846"}
0005434157917	F480FD	2638 109098	EVGENIY NAUMOV	{"email": "naumove1977@postgrespro.ru", "phone": "+70937992692"}
0005434157918	A6F5C5	0395 957811	OLGA EGOROVA	{"email": "egorova.o021972@postgrespro.ru", "phone": "+70826345144"}
0005434157919	D8FFAC	8405 483720	EKATERINA LOGINOVA	{"email": "loginova_ekaterina1973@postgrespro.ru", "phone": "+70214228342"}
0005434157920	27AF0D	4625 367853	VERA EGOROVA	{"phone": "+70321283540"}
0005434157921	9698EC	9651 710626	OLGA OSIPOVA	{"phone": "+70660416211"}
0005434157922	D23CBD	3484 253421	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_031966@postgrespro.ru", "phone": "+70711539049"}
0005434157923	F35807	1426 949091	IRINA SERGEEVA	{"email": "sergeeva-i_1963@postgrespro.ru", "phone": "+70793884561"}
0005434157924	EB7E68	0424 546577	VASILIY PETROV	{"email": "v.petrov.04111967@postgrespro.ru", "phone": "+70199872974"}
0005434157925	F30F68	2596 403311	VIKTOR MAKAROV	{"phone": "+70263156733"}
0005434157926	F30F68	5678 092576	VLADIMIR NIKITIN	{"phone": "+70212623593"}
0005434157927	138401	6975 749928	VIKTOR ZAKHAROV	{"email": "zakharov-viktor-101964@postgrespro.ru", "phone": "+70756887327"}
0005434157928	D2B84D	9889 803689	NIKOLAY IVANOV	{"phone": "+70921449718"}
0005434157929	D2B84D	3992 194622	NATALIYA ZOTOVA	{"email": "zotova_n.04011969@postgrespro.ru", "phone": "+70676125935"}
0005434157930	D2B84D	5071 519606	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov08051983@postgrespro.ru", "phone": "+70860665385"}
0005434157931	D35037	8234 767673	ELENA LEBEDEVA	{"phone": "+70365869152"}
0005434157932	D35037	8246 586831	ANDREY IVANOV	{"email": "a.ivanov1958@postgrespro.ru", "phone": "+70525125628"}
0005434157933	74E31F	0525 423893	OLGA KARPOVA	{"email": "olga_karpova051971@postgrespro.ru", "phone": "+70654558582"}
0005434157934	41E4E9	5381 009326	NINA LAZAREVA	{"email": "nina.lazareva-101968@postgrespro.ru", "phone": "+70684711944"}
0005434157935	41E4E9	6993 942304	SVETLANA FROLOVA	{"email": "frolova_svetlana011972@postgrespro.ru", "phone": "+70211466038"}
0005434157936	DCC9CE	5313 533736	YULIYA MOISEEVA	{"email": "moiseeva_y-1969@postgrespro.ru", "phone": "+70323430733"}
0005434157937	49C09A	6798 651205	GALINA BELOVA	{"email": "belova.g1975@postgrespro.ru", "phone": "+70958568118"}
0005434157938	914510	2662 647200	VASILIY KUZNECOV	{"phone": "+70115981482"}
0005434157939	988B25	8641 789038	VLADIMIR MOISEEV	{"email": "vladimir-moiseev-011980@postgrespro.ru", "phone": "+70561720081"}
0005434157940	4C92BB	4640 293964	NATALYA POPOVA	{"email": "popova.n_1962@postgrespro.ru", "phone": "+70387418352"}
0005434157941	4C92BB	9276 943054	DMITRIY SHEVCHENKO	{"email": "dmitriy.shevchenko.30061976@postgrespro.ru", "phone": "+70134996016"}
0005434157942	F38C62	8928 617872	ANTON NIKITIN	{"phone": "+70606243267"}
0005434157943	F38C62	5810 683304	SERGEY KUZNECOV	{"email": "kuznecovs-1973@postgrespro.ru", "phone": "+70548218125"}
0005434157944	4A0635	0509 981601	LYUDMILA ILINA	{"email": "ilina_l_091969@postgrespro.ru", "phone": "+70351506859"}
0005434157945	C7E8FE	0963 295651	NIKOLAY ANTONOV	{"phone": "+70332323068"}
0005434157946	A4F7EB	2841 439794	TATYANA BORISOVA	{"email": "tborisova.1975@postgrespro.ru", "phone": "+70243268684"}
0005434157947	A4F7EB	2150 948200	IVAN TIKHONOV	{"phone": "+70431245914"}
0005434157948	6B4987	7782 611795	VALENTINA ZAYCEVA	{"email": "v-zayceva_23061954@postgrespro.ru", "phone": "+70324316217"}
0005434157949	794733	7242 641980	IRINA ISAEVA	{"phone": "+70877262459"}
0005434157950	794733	6383 892228	PELAGEYA POPOVA	{"email": "pelageya.popova19071970@postgrespro.ru", "phone": "+70300537994"}
0005434157951	FED93C	5108 684318	KIRILL MAKAROV	{"phone": "+70402272292"}
0005434157952	A6DDFA	7653 831587	VALERIY CHERNOV	{"phone": "+70816521265"}
0005434157953	A6DDFA	7026 113194	IGOR TIMOFEEV	{"email": "igor-timofeev1972@postgrespro.ru", "phone": "+70123875430"}
0005434157954	5F4536	9656 749353	VASILIY MEDVEDEV	{"phone": "+70097505657"}
0005434157955	651FA8	3251 900371	TATYANA BARANOVA	{"email": "tatyanabaranova-051984@postgrespro.ru", "phone": "+70519694029"}
0005434157956	651FA8	2155 045240	YURIY EGOROV	{"phone": "+70333352247"}
0005434157957	B9C3A9	3389 068061	MARINA MAKAROVA	{"email": "m-makarova_1966@postgrespro.ru", "phone": "+70871326392"}
0005434157958	549733	1772 995665	OKSANA ROMANOVA	{"phone": "+70145310896"}
0005434157959	549733	8987 405534	TATYANA MELNIKOVA	{"phone": "+70513022165"}
0005434157960	FF068A	8517 446184	OLGA LUKYANOVA	{"phone": "+70143052764"}
0005434157961	FF068A	2955 027546	DMITRIY KULIKOV	{"phone": "+70706233155"}
0005434157962	92788A	3180 384792	RUSTAM POPOV	{"phone": "+70209511512"}
0005434157963	42C895	9358 319969	LARISA MIRONOVA	{"phone": "+70750759511"}
0005434157964	AD36EA	2771 230767	VLADIMIR MIRONOV	{"phone": "+70171537275"}
0005434157965	8CA726	2482 791445	OLGA KOLESNIKOVA	{"phone": "+70444996106"}
0005434157966	B0BD90	2929 054565	EVGENIY KISELEV	{"email": "kiselev_evgeniy-27071971@postgrespro.ru", "phone": "+70027128611"}
0005434157967	B0BD90	9670 141121	EVGENIY KOZLOV	{"email": "evgeniykozlov_091982@postgrespro.ru", "phone": "+70750381330"}
0005434157968	297AD4	1530 610323	ELENA AKIMOVA	{"email": "akimova.e-12051972@postgrespro.ru", "phone": "+70111702785"}
0005434157969	5062D2	6708 648363	VALERIY ALEKSEEV	{"phone": "+70062879762"}
0005434157970	531FEB	5654 226572	ELENA ROMANOVA	{"phone": "+70123031817"}
0005434157971	016445	7864 330364	MARIYA GAVRILOVA	{"email": "gavrilova.m_1972@postgrespro.ru", "phone": "+70548256427"}
0005434157972	3DEF06	6047 092313	ANASTASIYA CHERNOVA	{"phone": "+70034461836"}
0005434157973	3DEF06	8265 095444	SERGEY NAZAROV	{"email": "nazarov_s_111969@postgrespro.ru", "phone": "+70065940785"}
0005434157974	3B0A6A	3771 855153	RAIL KUZNECOV	{"phone": "+70250567250"}
0005434157975	6ABD15	6004 643079	YULIYA EFREMOVA	{"email": "y.efremova-031973@postgrespro.ru", "phone": "+70814466839"}
0005434157976	AFBE77	5501 079186	LINAR SOKOLOV	{"email": "sokolov.linar-1967@postgrespro.ru", "phone": "+70702567067"}
0005434157977	E3E479	3124 351282	SERGEY ZAYCEV	{"email": "zaycev-s.05071971@postgrespro.ru", "phone": "+70176540986"}
0005434157978	B97EC0	2084 796304	SERGEY KUZNECOV	{"email": "sergey_kuznecov061979@postgrespro.ru", "phone": "+70245875823"}
0005434157979	B97EC0	3065 700141	VERA SEMENOVA	{"email": "semenova_vera13081976@postgrespro.ru", "phone": "+70823141996"}
0005434157980	B97EC0	8793 426538	VIOLETTA VOROBEVA	{"phone": "+70953528239"}
0005434157981	D0106F	8245 860680	ALEKSANDR MIRONOV	{"email": "mironov-a-101964@postgrespro.ru", "phone": "+70498702912"}
0005434157982	938E8A	4575 184761	ALEKSANDRA VASILEVA	{"email": "aleksandra.vasileva_031964@postgrespro.ru", "phone": "+70890973287"}
0005434157983	938E8A	5492 087660	MADINA ROMANOVA	{"email": "romanovam091970@postgrespro.ru", "phone": "+70928394332"}
0005434157984	BECDBF	8919 463733	NATALYA BORISOVA	{"email": "n.borisova-1979@postgrespro.ru", "phone": "+70332686118"}
0005434157985	6291BF	0265 629516	BORIS EGOROV	{"email": "b.egorov.01111972@postgrespro.ru", "phone": "+70065718010"}
0005434157986	A48E9F	9461 677610	GALINA POTAPOVA	{"email": "potapovag-1977@postgrespro.ru", "phone": "+70085734008"}
0005434157987	BD8600	2009 263105	OLGA MELNIKOVA	{"phone": "+70678372734"}
0005434157988	EEC6BB	8828 619762	NATALYA SCHERBAKOVA	{"email": "scherbakova_natalya_071976@postgrespro.ru", "phone": "+70508577611"}
0005434157989	FB097D	1581 515025	ALEKSEY FEDOROV	{"phone": "+70470013910"}
0005434157990	B91AF8	5409 953672	ALEKSANDR NAZAROV	{"phone": "+70455712426"}
0005434157991	B91AF8	6438 791659	IRINA EFIMOVA	{"phone": "+70171358078"}
0005434157992	3A1E26	0516 194152	IRINA YUDINA	{"email": "iyudina-26061973@postgrespro.ru", "phone": "+70031260143"}
0005434157993	3A1E26	4636 021851	NATALYA EFREMOVA	{"phone": "+70786125544"}
0005434158943	1BC9C4	5770 960895	VITALIY DMITRIEV	{"email": "dmitriev-vitaliy-091967@postgrespro.ru", "phone": "+70040989659"}
0005434158944	07A062	6976 983356	KIRILL ZAKHAROV	{"email": "k.zakharov16041968@postgrespro.ru", "phone": "+70288785130"}
0005434158945	B85681	2023 484858	LYUBOV SOLOVEVA	{"phone": "+70489318167"}
0005434158946	1AC3DE	2886 303081	ALENA KAZAKOVA	{"email": "a_kazakova-091972@postgrespro.ru", "phone": "+70474176846"}
0005434158947	420EB4	3449 987561	NINA NAUMOVA	{"email": "nnaumova13011981@postgrespro.ru", "phone": "+70604272698"}
0005434158948	420EB4	8472 956172	YANA KRASNOVA	{"phone": "+70665717813"}
0005434158949	439B9B	3625 490784	OLGA MAKAROVA	{"phone": "+70033257373"}
0005434158950	BED27B	5524 720048	OLGA FADEEVA	{"email": "o_fadeeva041961@postgrespro.ru", "phone": "+70004423074"}
0005434158951	552EBD	4523 637764	NATALYA KONOVALOVA	{"email": "natalya.konovalova-1980@postgrespro.ru", "phone": "+70171860475"}
0005434158952	DE78B4	0888 744338	MARINA KISELEVA	{"phone": "+70518950069"}
0005434158953	B9CC23	9802 957795	NADEZHDA LAZAREVA	{"phone": "+70577454588"}
0005434158954	779CEA	6624 670787	VITALIY ZAYCEV	{"email": "vitaliy-zaycev25111971@postgrespro.ru", "phone": "+70453953660"}
0005434158955	779CEA	6477 447191	VYACHESLAV GERASIMOV	{"phone": "+70254513608"}
0005434158956	779CEA	7760 150214	IGOR MIKHAYLOV	{"email": "mikhaylov-i.101967@postgrespro.ru", "phone": "+70398699963"}
0005434158957	588FA3	8640 273146	ALENA VOROBEVA	{"email": "avorobeva03071970@postgrespro.ru", "phone": "+70270417013"}
0005434158958	5D17F4	2891 771233	NATALYA KAZAKOVA	{"phone": "+70992051174"}
0005434158959	B4E76F	0213 256491	SERGEY TIMOFEEV	{"phone": "+70230377204"}
0005434158960	7E7FFC	3300 352321	ALEKSANDRA SEMENOVA	{"phone": "+70563323167"}
0005434158961	89BDB7	1821 860159	SVETLANA IVANOVA	{"phone": "+70577006595"}
0005434158962	89BDB7	1742 598210	VIKTOR VLASOV	{"email": "vlasov.viktor_1971@postgrespro.ru", "phone": "+70577367492"}
0005434158963	666FD5	6662 654090	NIKOLAY IVANOV	{"email": "n-ivanov-1962@postgrespro.ru", "phone": "+70677975655"}
0005434158964	FF4D33	5570 602578	DMITRIY IVANOV	{"phone": "+70607897603"}
0005434158965	FF4D33	1094 400933	SERGEY NAZAROV	{"phone": "+70894258452"}
0005434158966	7BB53F	9454 324364	LYUDMILA DMITRIEVA	{"phone": "+70949421307"}
0005434158967	5FD8C9	3983 152609	LYUBOV ZAKHAROVA	{"email": "zakharova_l_1966@postgrespro.ru", "phone": "+70025014490"}
0005434158968	EC9484	8281 625138	DMITRIY MIKHAYLOV	{"email": "mikhaylovdmitriy_28011975@postgrespro.ru", "phone": "+70523470446"}
0005434158969	5CE25F	6529 413795	ALLA TIMOFEEVA	{"email": "timofeeva-alla_26091969@postgrespro.ru", "phone": "+70011229064"}
0005434158970	FCFC45	5299 427929	YULIYA NESTEROVA	{"email": "nesterovayuliya1980@postgrespro.ru", "phone": "+70599021876"}
0005434158971	AE853B	1941 567824	ANTON KARPOV	{"email": "karpov-anton_1988@postgrespro.ru", "phone": "+70911772806"}
0005434158972	AE853B	2288 773958	ANNA AFANASEVA	{"phone": "+70241260925"}
0005434158973	9DBFA2	4970 002200	OLGA NAZAROVA	{"email": "onazarova_1982@postgrespro.ru", "phone": "+70238377031"}
0005434158974	63A508	7459 166196	EVGENIY SOROKIN	{"email": "esorokin_01021966@postgrespro.ru", "phone": "+70048553128"}
0005434158975	F8D6AE	3264 154858	ANNA ANDREEVA	{"email": "andreeva_anna-071973@postgrespro.ru", "phone": "+70235284921"}
0005434158976	419D58	2876 275552	TATYANA KRASNOVA	{"email": "krasnova_tatyana31121963@postgrespro.ru", "phone": "+70520240583"}
0005434158977	1FC80D	9607 880221	KONSTANTIN DENISOV	{"email": "denisov-konstantin1974@postgrespro.ru", "phone": "+70553806343"}
0005434158978	237E73	6174 913804	NATALYA SOROKINA	{"phone": "+70623196982"}
0005434158979	BBC899	4009 720876	SVETLANA ANTONOVA	{"phone": "+70926253256"}
0005434158980	BBC899	1239 859468	NATALYA TIMOFEEVA	{"email": "n-timofeeva1983@postgrespro.ru", "phone": "+70684600011"}
0005434158981	80B76E	4334 717445	IVAN MEDVEDEV	{"email": "ivan.medvedev_071984@postgrespro.ru", "phone": "+70322271141"}
0005434158982	80B76E	0312 018467	VLADIMIR ISAEV	{"phone": "+70419171099"}
0005434158983	F4239D	4486 321015	MARAT TIMOFEEV	{"email": "m_timofeev-07081966@postgrespro.ru", "phone": "+70177963123"}
0005434158984	6A2A1D	0177 142029	OLGA NAZAROVA	{"email": "nazarova_olga_1967@postgrespro.ru", "phone": "+70184849329"}
0005434158985	11C306	7348 284630	YURIY KUZNECOV	{"email": "kuznecov-y_021983@postgrespro.ru", "phone": "+70836386821"}
0005434158986	11C306	5128 604952	VYACHESLAV IVANOV	{"email": "ivanov_v.1989@postgrespro.ru", "phone": "+70738830735"}
0005434158987	089339	1252 107886	OLGA KOROLEVA	{"email": "o-koroleva-011968@postgrespro.ru", "phone": "+70690161876"}
0005434158988	FA4648	5961 326553	OLEG IVANOV	{"email": "ivanov_oleg.041973@postgrespro.ru", "phone": "+70638483852"}
0005434158989	FA4648	4047 911399	LIDIYA GUSEVA	{"phone": "+70780019955"}
0005434158990	88B038	3491 021667	TALGAT BARANOV	{"email": "tbaranov-041980@postgrespro.ru", "phone": "+70263561461"}
0005434158991	033883	0479 934270	SERGEY SOKOLOV	{"email": "s_sokolov-1964@postgrespro.ru", "phone": "+70508311085"}
0005434158992	033883	6538 410113	EDUARD MAKSIMOV	{"email": "e_maksimov.1963@postgrespro.ru", "phone": "+70063403893"}
0005434158993	55C87B	8940 304886	SERGEY SCHERBAKOV	{"email": "s_scherbakov_061963@postgrespro.ru", "phone": "+70253429228"}
0005434158994	349D42	1702 822733	SERGEY ZAKHAROV	{"phone": "+70072102320"}
0005434158995	349D42	2652 834568	VERONIKA KISELEVA	{"email": "kiseleva.veronika-14121978@postgrespro.ru", "phone": "+70524213435"}
0005434158996	4DFDEF	2743 027678	ELENA GORBUNOVA	{"phone": "+70205890852"}
0005434158997	21CF10	5619 266501	SVETLANA SCHERBAKOVA	{"phone": "+70999510491"}
0005434158998	AEA0F6	9830 365408	PETR SOROKIN	{"phone": "+70208455470"}
0005434158999	D1504D	0865 825909	ALEKSEY NIKITIN	{"phone": "+70623486370"}
0005434159000	46E4DC	5745 889178	VLADIMIR STEPANOV	{"email": "vladimir_stepanov.121966@postgrespro.ru", "phone": "+70097823080"}
0005434159001	E6EE91	4850 089760	ANASTASIYA GRISHINA	{"phone": "+70484974909"}
0005434159002	82A532	7282 264832	VALERIY IVANOV	{"email": "v_ivanov_1959@postgrespro.ru", "phone": "+70621926292"}
0005434159003	006170	7534 298673	IVAN KAZAKOV	{"phone": "+70145134558"}
0005434159004	5080B5	3352 019705	SERGEY IVANOV	{"email": "sergey_ivanov_1974@postgrespro.ru", "phone": "+70043540768"}
0005434159005	5080B5	9224 673553	GALINA MIRONOVA	{"email": "mironova_galina07031972@postgrespro.ru", "phone": "+70807134640"}
0005434159006	173630	5565 746098	YANA CHERNOVA	{"email": "chernova-yana.021975@postgrespro.ru", "phone": "+70741791608"}
0005434159007	0B442A	2961 001794	ILYA ROMANOV	{"email": "romanov.i.041975@postgrespro.ru", "phone": "+70079947087"}
0005434159008	83C007	8300 999733	DMITRIY STEPANOV	{"phone": "+70443531948"}
0005434159009	83C007	5452 922965	PETR ROMANOV	{"phone": "+70333281599"}
0005434159010	DC5F16	8974 569137	IVAN KUDRYASHOV	{"email": "kudryashov-ivan_1984@postgrespro.ru", "phone": "+70182442551"}
0005434159011	DC5F16	8351 158241	VALENTINA NIKITINA	{"email": "valentinanikitina-1975@postgrespro.ru", "phone": "+70577281968"}
0005434159012	01541E	9378 795737	ALEKSANDR DENISOV	{"phone": "+70906430375"}
0005434159013	01541E	5757 200223	LYUBOV MOROZOVA	{"email": "morozova_lyubov.1967@postgrespro.ru", "phone": "+70040831170"}
0005434159014	412740	9516 933239	STANISLAV KUDRYASHOV	{"email": "skudryashov22011978@postgrespro.ru", "phone": "+70499804634"}
0005434159015	412740	5781 332919	TAMARA MIRONOVA	{"phone": "+70753199419"}
0005434159016	412740	1147 150206	OLGA MIRONOVA	{"phone": "+70159502414"}
0005434159017	4F70AE	2022 401085	ALEKSANDR BORISOV	{"phone": "+70445886252"}
0005434159018	7F5917	5076 517550	SERGEY MATVEEV	{"email": "sergey.matveev26091964@postgrespro.ru", "phone": "+70994156361"}
0005434159019	5DD0F6	3725 466496	TATYANA GERASIMOVA	{"phone": "+70899999424"}
0005434159020	4947F3	4171 905443	ELENA ZAYCEVA	{"phone": "+70735748140"}
0005434159021	56AAFF	0666 131885	TATYANA IVANOVA	{"phone": "+70039469303"}
0005434159022	E47805	7413 759224	ANDREY GUSEV	{"phone": "+70849325764"}
0005434159023	955623	7292 201654	TATYANA TIMOFEEVA	{"phone": "+70786972290"}
0005434159024	489826	9496 075078	YULIYA TROFIMOVA	{"phone": "+70004224638"}
0005434159025	6AB9FF	8229 953258	NIKOLAY PETROV	{"email": "petrov_n_041967@postgrespro.ru", "phone": "+70215254198"}
0005434159026	F9EDDE	0159 888811	NADEZHDA IVANOVA	{"email": "nadezhdaivanova-24011978@postgrespro.ru", "phone": "+70877270377"}
0005434159027	54453A	1974 279235	EVGENIYA RODIONOVA	{"email": "rodionova_evgeniya_30051975@postgrespro.ru", "phone": "+70990159069"}
0005434159028	54453A	4094 788098	ANDREY SIDOROV	{"phone": "+70665793062"}
0005434159029	04B8FF	4561 829132	PAVEL YAKOVLEV	{"email": "yakovlev.p_20061978@postgrespro.ru", "phone": "+70355817170"}
0005434159030	A55A60	7264 383964	ANATOLIY ALEKSANDROV	{"phone": "+70449805861"}
0005434159031	7DBF34	1707 287430	IRINA ZAKHAROVA	{"email": "zakharova-irina_05021962@postgrespro.ru", "phone": "+70729632101"}
0005434159032	E4FE3E	3505 327157	YULIYA MIKHAYLOVA	{"email": "yuliya.mikhaylova101958@postgrespro.ru", "phone": "+70409863583"}
0005434159033	5EAAA4	0227 218688	MILANA MASLOVA	{"phone": "+70047540922"}
0005434159034	E61958	0770 264105	ANTON KUZMIN	{"email": "akuzmin.1974@postgrespro.ru", "phone": "+70614656822"}
0005434159035	C11BB9	3707 511072	DMITRIY ILIN	{"email": "dmitriy.ilin.01021983@postgrespro.ru", "phone": "+70756626854"}
0005434159036	C11BB9	1463 741514	VALENTINA MAKAROVA	{"email": "v.makarova1975@postgrespro.ru", "phone": "+70878041918"}
0005434159037	F4EA31	9714 323681	ALEKSANDR MOROZOV	{"phone": "+70919464685"}
0005434159038	AB7288	8753 661539	ANAIT KUZNECOVA	{"email": "a_kuznecova.021974@postgrespro.ru", "phone": "+70347610715"}
0005434159039	AB7288	1512 056052	NINA PAVLOVA	{"email": "pavlova-n1968@postgrespro.ru", "phone": "+70384073467"}
0005434159040	E13CEF	4419 305984	ANASTASIYA NIKITINA	{"phone": "+70437576915"}
0005434159041	73B9F8	0167 116100	MARIYA VASILEVA	{"email": "vasileva_mariya081969@postgrespro.ru", "phone": "+70857593896"}
0005434159042	E10E2F	3812 315019	ILYA MOROZOV	{"email": "morozov.i_1972@postgrespro.ru", "phone": "+70821271583"}
0005434159043	11689F	8510 030948	ELENA BELYAEVA	{"email": "e_belyaeva13071977@postgrespro.ru", "phone": "+70017855609"}
0005434159044	74DC73	6145 470093	YURIY MAKSIMOV	{"email": "maksimov-yuriy091975@postgrespro.ru", "phone": "+70938698170"}
0005434159045	64E89C	5919 098475	REGINA MELNIKOVA	{"email": "regina-melnikova.011976@postgrespro.ru", "phone": "+70198905362"}
0005434159046	87D54C	5507 840121	ILDAR SMIRNOV	{"phone": "+70229755824"}
0005434159047	F77669	1588 107762	ELENA ALEKSEEVA	{"phone": "+70698662359"}
0005434159048	2E26FF	9001 378757	IGOR OSIPOV	{"email": "osipov_igor.031964@postgrespro.ru", "phone": "+70748009799"}
0005434159049	2E26FF	5406 299309	DMITRIY FILIPPOV	{"email": "filippov_dmitriy-1969@postgrespro.ru", "phone": "+70081116605"}
0005434159050	111ECB	0600 345335	POLINA KUZMINA	{"phone": "+70723494336"}
0005434159051	B1CD52	7376 565879	SERGEY STEPANOV	{"phone": "+70451753572"}
0005434159052	CA4C38	5444 892503	KSENIYA KUDRYASHOVA	{"phone": "+70292122134"}
0005434159053	CA4C38	3093 796191	YAROSLAV IVANOV	{"email": "ivanov.y-1969@postgrespro.ru", "phone": "+70041270853"}
0005434159054	0BD5A1	7782 729567	ROMAN NIKOLAEV	{"phone": "+70230571467"}
0005434159055	85558E	1551 705487	NINA POPOVA	{"phone": "+70008147663"}
0005434159056	85558E	2398 427980	VLADISLAV SEMENOV	{"phone": "+70712479477"}
0005434159057	BDA481	8664 880108	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova1965@postgrespro.ru", "phone": "+70857229766"}
0005434159058	BDA481	5016 247554	GALINA KALININA	{"email": "kalinina-g-051966@postgrespro.ru", "phone": "+70491898931"}
0005434159059	AB8F27	1452 386636	DMITRIY YAKOVLEV	{"email": "dmitriyyakovlev.1964@postgrespro.ru", "phone": "+70524826976"}
0005434159060	610C8F	2094 406960	ROMAN MARTYNOV	{"email": "martynov.roman-19091976@postgrespro.ru", "phone": "+70906807126"}
0005434163458	57ADB6	5091 983810	ELENA DANILOVA	{"phone": "+70824254590"}
0005434163516	E3ED6B	3078 453442	EGOR MOISEEV	{"phone": "+70193775987"}
0005434163459	99A009	0615 791703	SERGEY VLASOV	{"email": "s_vlasov.021965@postgrespro.ru", "phone": "+70879370715"}
0005434163460	FCDECC	6122 376853	SERGEY CHERNOV	{"phone": "+70159450338"}
0005434163461	67CAB2	4995 091499	MARINA NESTEROVA	{"email": "mnesterova121980@postgrespro.ru", "phone": "+70478899300"}
0005434163462	C9A84C	9562 450706	ANTONINA KUZMINA	{"email": "kuzminaantonina.1961@postgrespro.ru", "phone": "+70883524225"}
0005434163463	C9A84C	1083 866596	VERA DANILOVA	{"email": "vera.danilova_27031973@postgrespro.ru", "phone": "+70367723120"}
0005434163464	3C3DFA	8593 946724	ELENA TARASOVA	{"phone": "+70997687516"}
0005434163465	47C5E2	3124 986437	PAVEL DENISOV	{"email": "p.denisov.041987@postgrespro.ru", "phone": "+70803093244"}
0005434163466	B0BBD3	2327 202767	FEDOR KUZNECOV	{"phone": "+70926718287"}
0005434163467	30EE07	5238 366331	MARIYA LUKYANOVA	{"phone": "+70546958886"}
0005434163468	A34D3A	4396 730756	ELENA SEMENOVA	{"email": "e-semenova-031972@postgrespro.ru", "phone": "+70512801459"}
0005434163469	A34D3A	4271 918610	SERGEY ZAKHAROV	{"email": "sergey-zakharov.1974@postgrespro.ru", "phone": "+70771573442"}
0005434163470	2DE5BF	5599 908902	ANATOLIY GUSEV	{"email": "gusev_a-1973@postgrespro.ru", "phone": "+70469049983"}
0005434163471	EF193A	9657 014932	RINAT PAVLOV	{"phone": "+70588372710"}
0005434163472	60CEE0	6199 266646	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_valentina1970@postgrespro.ru", "phone": "+70599697019"}
0005434163473	60CEE0	2169 890328	TATYANA SOLOVEVA	{"email": "soloveva-t.121971@postgrespro.ru", "phone": "+70134689366"}
0005434163474	4F2747	3592 487527	IGOR TARASOV	{"phone": "+70869168006"}
0005434163475	C43BB5	3941 024088	ALEKSANDR VASILEV	{"phone": "+70568971572"}
0005434163476	D558B1	5233 254164	OLGA YUDINA	{"email": "o_yudina_29071956@postgrespro.ru", "phone": "+70888788207"}
0005434163477	D558B1	9914 236552	NATALYA IVANOVA	{"email": "n-ivanova-1969@postgrespro.ru", "phone": "+70387136196"}
0005434163478	AC5519	2864 869517	EKATERINA KALININA	{"phone": "+70990253134"}
0005434163479	AC5519	5887 206355	MAKSIM KULIKOV	{"email": "mkulikov071981@postgrespro.ru", "phone": "+70209661562"}
0005434163480	AC5519	3921 851360	ROZA RODIONOVA	{"email": "r_rodionova.1970@postgrespro.ru", "phone": "+70735106025"}
0005434163481	2926DC	6938 018773	NATALYA FROLOVA	{"email": "frolova.n_08021963@postgrespro.ru", "phone": "+70429724910"}
0005434163482	D8F7E5	2444 295041	ARTUR ANDREEV	{"email": "artur-andreev.011977@postgrespro.ru", "phone": "+70908013661"}
0005434163483	E888C1	1156 224300	OLEG SHEVCHENKO	{"email": "shevchenko_oleg_021978@postgrespro.ru", "phone": "+70537711207"}
0005434163484	7C73CB	5490 265276	OKSANA SMIRNOVA	{"email": "smirnovao_1969@postgrespro.ru", "phone": "+70021389918"}
0005434163485	1BBBD2	0418 450913	YULIYA ZHUKOVA	{"email": "zhukovayuliya-15041970@postgrespro.ru", "phone": "+70339172047"}
0005434163486	DBF3FD	1857 788504	SVETLANA YUDINA	{"email": "yudina-svetlana_06081973@postgrespro.ru", "phone": "+70237344854"}
0005434163487	DBF3FD	3177 802819	ALEKSANDR MAKAROV	{"email": "a-makarov.20071979@postgrespro.ru", "phone": "+70669380019"}
0005434163488	F0129F	0838 359361	IRINA VOROBEVA	{"email": "vorobevai.011978@postgrespro.ru", "phone": "+70014345397"}
0005434163489	F0129F	3111 016837	ANAIT MATVEEVA	{"phone": "+70136230008"}
0005434163490	84F7F5	3937 431591	TATYANA IVANOVA	{"email": "ivanova.tatyana-24041976@postgrespro.ru", "phone": "+70930167720"}
0005434163491	4BA008	2608 347645	EVGENIY FROLOV	{"email": "evgeniy-frolov.1973@postgrespro.ru", "phone": "+70036738852"}
0005434163492	5E516E	1865 250156	NINA MOROZOVA	{"email": "morozova.n.011966@postgrespro.ru", "phone": "+70132488434"}
0005434163493	5E516E	9769 058237	SERGEY FROLOV	{"phone": "+70361313196"}
0005434163494	31D721	6760 473177	ELENA MOISEEVA	{"email": "moiseeva_elena04081971@postgrespro.ru", "phone": "+70733471372"}
0005434163495	9EA4B0	1906 208121	EKATERINA SOKOLOVA	{"email": "e_sokolova13011974@postgrespro.ru", "phone": "+70517170500"}
0005434163496	52C990	4757 654454	GENNADIY ZHURAVLEV	{"email": "zhuravlev_g_1971@postgrespro.ru", "phone": "+70979561782"}
0005434163497	DD59B1	7865 135652	ZOYA MALYSHEVA	{"email": "malyshevazoya.041979@postgrespro.ru", "phone": "+70946165128"}
0005434163498	DD59B1	0509 598040	VLADIMIR ORLOV	{"phone": "+70127820920"}
0005434163499	DD59B1	8392 981583	LYUDMILA SCHERBAKOVA	{"email": "l.scherbakova1970@postgrespro.ru", "phone": "+70633154085"}
0005434163500	270B15	0389 763768	DARYA KOLESNIKOVA	{"phone": "+70772929920"}
0005434163501	B03611	9655 549660	DAMIR FILIPPOV	{"email": "filippov.d16031972@postgrespro.ru", "phone": "+70232969097"}
0005434163502	B03611	3737 386808	ILMIRA MIRONOVA	{"email": "i.mironova.06011969@postgrespro.ru", "phone": "+70501445297"}
0005434163503	CAD634	3785 819678	VLADIMIR FILIPPOV	{"email": "filippov_v_011974@postgrespro.ru", "phone": "+70947450250"}
0005434163504	D97919	0558 294943	ALINA PETROVA	{"phone": "+70926436531"}
0005434163505	D97919	2507 764520	VALERIY SCHERBAKOV	{"email": "v_scherbakov1959@postgrespro.ru", "phone": "+70766073240"}
0005434163506	679F75	9108 428741	EKATERINA KOMAROVA	{"phone": "+70992061300"}
0005434163507	68E6CF	7976 748359	SERGEY STEPANOV	{"email": "stepanov-sergey_1974@postgrespro.ru", "phone": "+70012631225"}
0005434163508	C8B64C	7307 805005	VLADIMIR STEPANOV	{"email": "stepanov-v.011968@postgrespro.ru", "phone": "+70516413810"}
0005434163509	C8B64C	9348 506955	KAMIL ANTONOV	{"phone": "+70258723955"}
0005434163510	C8B64C	5267 671519	VYACHESLAV VOLKOV	{"phone": "+70540396674"}
0005434163511	AAD1DB	3288 258815	LYUDMILA STEPANOVA	{"email": "lyudmila-stepanova_1978@postgrespro.ru", "phone": "+70901350573"}
0005434163512	AAD1DB	1957 494618	VLADIMIR PETROV	{"phone": "+70776869765"}
0005434163513	AAD1DB	9045 579923	SAVELIY TIKHONOV	{"email": "tikhonovsaveliy-011971@postgrespro.ru", "phone": "+70904487481"}
0005434163514	D39C20	2584 259076	GALINA KALININA	{"email": "kalininag_101957@postgrespro.ru", "phone": "+70682583940"}
0005434163515	E3ED6B	8404 263676	ARSENIY EGOROV	{"phone": "+70353967951"}
0005434163517	EF1422	5598 969853	NATALYA KOMAROVA	{"email": "natalya.komarova-1975@postgrespro.ru", "phone": "+70103705604"}
0005434163518	ADB2C3	3544 042695	ANASTASIYA FOMINA	{"phone": "+70539117357"}
0005434163519	BD73AE	1758 966575	SVETLANA ROMANOVA	{"email": "svetlana.romanova1968@postgrespro.ru", "phone": "+70821647042"}
0005434163520	B31810	1109 895376	ELENA BORISOVA	{"phone": "+70552470202"}
0005434163521	B31810	2869 529992	MATVEY BELOV	{"email": "matveybelov1972@postgrespro.ru", "phone": "+70367543799"}
0005434163522	C71D74	0289 106380	ALBINA NAUMOVA	{"phone": "+70405308725"}
0005434163523	3A01E8	2936 888448	SEMEN VOROBEV	{"phone": "+70238868856"}
0005434163524	3A01E8	6189 090624	DMITRIY MAKSIMOV	{"phone": "+70277534992"}
0005434163525	B6F727	7155 309560	VADIM NIKITIN	{"phone": "+70211547664"}
0005434163526	B9C76C	4178 328434	ELIZAVETA NAZAROVA	{"phone": "+70374665730"}
0005434163527	B9C76C	4224 180466	NINA STEPANOVA	{"email": "stepanova-nina-15061978@postgrespro.ru", "phone": "+70567278002"}
0005434163528	2D6F25	7407 916652	LYUDMILA KOROLEVA	{"phone": "+70450842714"}
0005434163529	2D6F25	9658 356763	ZOYA TIKHONOVA	{"phone": "+70627717206"}
0005434163530	2D6F25	8237 917578	LIDIYA LAZAREVA	{"phone": "+70965940578"}
0005434163531	BD484A	0808 951096	SERGEY NAUMOV	{"phone": "+70813191598"}
0005434163532	ED8B2B	4676 653741	TATYANA AFANASEVA	{"email": "tatyana_afanaseva-021968@postgrespro.ru", "phone": "+70471494622"}
0005434163533	65B59B	5833 181121	MIKHAIL KULIKOV	{"email": "kulikovmikhail29101972@postgrespro.ru", "phone": "+70281805294"}
0005434163534	75DD4D	8634 912308	TATYANA BELYAEVA	{"email": "belyaeva-t-08111976@postgrespro.ru", "phone": "+70063494933"}
0005434163535	019337	1277 885202	DMITRIY ZAYCEV	{"email": "d-zaycev1977@postgrespro.ru", "phone": "+70895974648"}
0005434163536	BE9332	0410 492711	OLGA KOVALEVA	{"email": "kovalevaolga_111975@postgrespro.ru", "phone": "+70797019974"}
0005434163537	4A28E4	5391 995218	ROZA SERGEEVA	{"email": "sergeeva.roza-081980@postgrespro.ru", "phone": "+70081811641"}
0005434163538	A2FA4E	8500 722615	LYUDMILA KOROLEVA	{"phone": "+70786090053"}
0005434163539	C19653	8681 701516	RAISA NIKOLAEVA	{"phone": "+70046815473"}
0005434163540	C19653	8063 354596	YURIY SMIRNOV	{"phone": "+70108509360"}
0005434163541	8CF81C	9516 701886	ALEKSEY GRIGOREV	{"email": "grigorev.aleksey1974@postgrespro.ru", "phone": "+70465800798"}
0005434163542	8CF81C	0117 586582	EVGENIY IVANOV	{"email": "ivanov.evgeniy091978@postgrespro.ru", "phone": "+70972943009"}
0005434163543	8CF81C	1824 669630	NATALYA SOKOLOVA	{"email": "nsokolova27081975@postgrespro.ru", "phone": "+70712374518"}
0005434163544	105117	0042 079365	ANDREY KUZNECOV	{"email": "kuznecov.andrey_091975@postgrespro.ru", "phone": "+70160862406"}
0005434163545	ECC6FE	7715 915412	OLGA KOZLOVA	{"email": "o-kozlova.011975@postgrespro.ru", "phone": "+70959894600"}
0005434163546	ECC6FE	1237 512979	ALEKSEY SOLOVEV	{"email": "solovevaleksey.111975@postgrespro.ru", "phone": "+70508989618"}
0005434163547	66848C	3410 424494	ILYA BORISOV	{"email": "ilya-borisov-06061972@postgrespro.ru", "phone": "+70811288429"}
0005434163548	66848C	5926 295139	MAKSIM SIDOROV	{"email": "sidorov_m.1967@postgrespro.ru", "phone": "+70283370305"}
0005434163549	A1B816	1539 510669	ALEKSANDR FEDOTOV	{"phone": "+70167271754"}
0005434163550	360D6F	1448 909591	IVAN SEMENOV	{"phone": "+70138829948"}
0005434163551	AB61B3	0061 823944	ARTEM SOKOLOV	{"email": "artemsokolov13021966@postgrespro.ru", "phone": "+70744836844"}
0005434163552	D94668	2099 507615	OLESYA SEMENOVA	{"phone": "+70648092769"}
0005434163553	BCE6E8	0159 243133	MAKSIM SEMENOV	{"phone": "+70749359513"}
0005434163554	73A43A	9862 111906	DMITRIY MAKAROV	{"email": "dmitriy.makarov-101971@postgrespro.ru", "phone": "+70345405981"}
0005434163555	73A43A	3682 942458	NIKOLAY KONOVALOV	{"phone": "+70397719713"}
0005434163556	591A5E	2575 049830	VLADIMIR STEPANOV	{"phone": "+70182485266"}
0005434163557	591A5E	3898 554366	VYACHESLAV KULIKOV	{"phone": "+70319134389"}
0005434163558	B71F6E	6391 894965	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.011967@postgrespro.ru", "phone": "+70763005966"}
0005434163559	B71F6E	5359 261254	VIKTOR SOROKIN	{"email": "sorokin.viktor101973@postgrespro.ru", "phone": "+70552968019"}
0005434163560	F29E2B	1482 767712	OLGA ZAKHAROVA	{"phone": "+70126059658"}
0005434163561	AFDB2E	8146 119519	ELIZAVETA KOROLEVA	{"email": "korolevae1975@postgrespro.ru", "phone": "+70164154687"}
0005434163562	AFDB2E	8524 063882	IGOR KUZNECOV	{"email": "kuznecov-igor.24071963@postgrespro.ru", "phone": "+70631619634"}
0005434163563	52767C	8556 937565	IVAN ANDREEV	{"phone": "+70022379975"}
0005434163564	52767C	2705 039155	NINA KUZNECOVA	{"email": "nina_kuznecova111984@postgrespro.ru", "phone": "+70109636508"}
0005434163565	D18D20	7219 481783	NATALYA TIMOFEEVA	{"phone": "+70878709918"}
0005434163566	530804	5912 487950	IGOR NAZAROV	{"email": "i_nazarov1959@postgrespro.ru", "phone": "+70088403110"}
0005434163567	CEE24C	7269 552693	VIKTOR KUZMIN	{"phone": "+70113696915"}
0005434163568	CEE24C	4135 879562	MARIYA PETROVA	{"email": "petrova-mariya_1969@postgrespro.ru", "phone": "+70340589125"}
0005434163569	2BA2B4	0601 192146	NATALYA NIKOLAEVA	{"phone": "+70676330882"}
0005434163570	2BA2B4	2838 755197	YURIY MAKAROV	{"phone": "+70703500903"}
0005434163571	625254	1074 903416	TATYANA SOROKINA	{"email": "sorokinat-1970@postgrespro.ru", "phone": "+70903988452"}
0005434163572	2ACCC7	8890 340005	DMITRIY FOMIN	{"phone": "+70984667445"}
0005434163573	2DEBD6	6831 010282	VLADIMIR MAKSIMOV	{"email": "vladimirmaksimov_1978@postgrespro.ru", "phone": "+70547286230"}
0005434163574	741363	4498 830423	DMITRIY KOZLOV	{"email": "d.kozlov1976@postgrespro.ru", "phone": "+70319324882"}
0005434163575	8B3622	6451 435180	SVETLANA POPOVA	{"email": "popova.svetlana.1964@postgrespro.ru", "phone": "+70752502641"}
0005434163576	8E8413	4694 601672	ANNA BELOVA	{"phone": "+70158527659"}
0005434163577	DF8980	4810 850243	NIKOLAY KOZLOV	{"email": "nkozlov.1976@postgrespro.ru", "phone": "+70931151304"}
0005434163578	D9389C	7168 655859	VALERIYA NESTEROVA	{"phone": "+70114841456"}
0005434163579	D9389C	1565 239686	DARYA KUDRYASHOVA	{"phone": "+70477563523"}
0005434163580	BC4D08	5190 704772	IVAN FEDOTOV	{"email": "fedotovi-1965@postgrespro.ru", "phone": "+70401481511"}
0005434163581	E3D2AE	4444 194618	VIKTORIYA GAVRILOVA	{"email": "gavrilovav.01021969@postgrespro.ru", "phone": "+70957747005"}
0005434163582	433EE7	2381 626226	VALENTINA BELYAEVA	{"email": "v_belyaeva-101978@postgrespro.ru", "phone": "+70101419329"}
0005434163583	433EE7	1585 932380	VALENTINA VOROBEVA	{"email": "v-vorobeva-031973@postgrespro.ru", "phone": "+70486823157"}
0005434163584	433EE7	0554 252493	EVGENIY POPOV	{"email": "e_popov121969@postgrespro.ru", "phone": "+70016483399"}
0005434163585	433EE7	8431 706146	VENERA ABRAMOVA	{"phone": "+70152286118"}
0005434163586	C3AEF9	2852 627802	PAVEL TIMOFEEV	{"email": "timofeev_pavel_20091970@postgrespro.ru", "phone": "+70353415890"}
0005434163587	C373A1	6639 240592	ROMAN FEDOROV	{"phone": "+70914688497"}
0005434163588	4DDCC2	1963 202359	SOFYA NESTEROVA	{"email": "s.nesterova-1976@postgrespro.ru", "phone": "+70494637429"}
0005434163589	4DDCC2	4049 164220	ALFIYA STEPANOVA	{"email": "a_stepanova-1968@postgrespro.ru", "phone": "+70656362677"}
0005434163590	19DF84	9532 887618	ANDREY NIKOLAEV	{"email": "a-nikolaev101970@postgrespro.ru", "phone": "+70137737022"}
0005434163591	C86FFF	7365 944638	SERGEY MOISEEV	{"phone": "+70621147614"}
0005434163592	86BB94	6951 992211	TATYANA POPOVA	{"phone": "+70031311208"}
0005434163593	424C3F	7770 322012	LIDIYA KOLESNIKOVA	{"email": "kolesnikova_l_111975@postgrespro.ru", "phone": "+70936751283"}
0005434163594	CFA893	8923 715002	IRINA PETROVA	{"phone": "+70799342291"}
0005434163595	51BDE9	3522 485210	NINA LOGINOVA	{"phone": "+70326598475"}
0005434163596	51BDE9	9022 294974	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov-121980@postgrespro.ru", "phone": "+70791987054"}
0005434163597	525B41	3390 771216	LYUBOV ORLOVA	{"phone": "+70663294190"}
0005434163598	525B41	8416 962118	VALENTINA ZAYCEVA	{"email": "v.zayceva-031971@postgrespro.ru", "phone": "+70047586933"}
0005434163599	B530BA	9392 582804	ALEKSANDR BORISOV	{"phone": "+70323171693"}
0005434163600	B530BA	1114 262252	MARIYA TITOVA	{"phone": "+70809542156"}
0005434163601	A8EE1E	0245 563814	ANNA ISAEVA	{"email": "anna.isaeva-23041968@postgrespro.ru", "phone": "+70904333664"}
0005434163602	AC3CAB	9379 039145	ALEKSANDR MIRONOV	{"phone": "+70029686901"}
0005434163603	2F295D	3738 619926	MARIYA ZAKHAROVA	{"phone": "+70340219378"}
0005434163604	2F295D	7528 772669	EVGENIY SERGEEV	{"email": "evgeniy_sergeev_13121973@postgrespro.ru", "phone": "+70574834624"}
0005434163605	2F295D	6501 601571	YURIY KARPOV	{"email": "ykarpov.101977@postgrespro.ru", "phone": "+70764996919"}
0005434163606	B5D8DE	0964 144475	SERGEY FEDOROV	{"phone": "+70394073781"}
0005434163607	B5D8DE	4468 908873	ANDREY ABRAMOV	{"email": "abramov-andrey.1983@postgrespro.ru", "phone": "+70292620125"}
0005434163608	3B2A70	5293 855002	ANNA MAKSIMOVA	{"phone": "+70026502084"}
0005434163609	836E32	4152 794127	ARTEM DMITRIEV	{"phone": "+70060954696"}
0005434163610	98D96D	6712 880651	VADIM KUDRYASHOV	{"phone": "+70656479520"}
0005434163611	1BE206	0717 618680	YANA LEBEDEVA	{"email": "y_lebedeva.1979@postgrespro.ru", "phone": "+70146286528"}
0005434163612	1BE206	9350 459221	NATALYA SEMENOVA	{"phone": "+70457082225"}
0005434163613	D03FB3	2605 687929	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikova-a_05081963@postgrespro.ru", "phone": "+70190594128"}
0005434163614	7F0EB2	7014 884643	ANDREY ROMANOV	{"phone": "+70526733690"}
0005434163615	7F0EB2	9314 767869	NADEZHDA SEMENOVA	{"phone": "+70520259442"}
0005434163616	158EE8	2906 929107	NIKOLAY NIKOLAEV	{"email": "nikolaev-nikolay-071978@postgrespro.ru", "phone": "+70484317649"}
0005434163617	401BF6	3602 413133	DMITRIY VASILEV	{"email": "vasilev-dmitriy_071969@postgrespro.ru", "phone": "+70384285989"}
0005434163618	401BF6	1577 391580	VALERIY GRIGOREV	{"email": "v-grigorev121975@postgrespro.ru", "phone": "+70406606794"}
0005434163619	09EAF3	2819 899157	KONSTANTIN FOMIN	{"phone": "+70575058964"}
0005434163620	CABFEC	4535 611737	ZINAIDA KAZAKOVA	{"email": "kazakova_z-051972@postgrespro.ru", "phone": "+70669836116"}
0005434163621	CABFEC	8962 603981	NATALYA SMIRNOVA	{"email": "nsmirnova30051966@postgrespro.ru", "phone": "+70415166282"}
0005434163622	D135AF	1891 041134	KLAVDIYA MOISEEVA	{"email": "moiseeva_klavdiya1967@postgrespro.ru", "phone": "+70587908612"}
0005434163623	D135AF	0130 175939	NIKITA SOKOLOV	{"email": "sokolov.nikita.1970@postgrespro.ru", "phone": "+70276215621"}
0005434163624	92954E	8715 549692	RAISA EFIMOVA	{"phone": "+70367861382"}
0005434163625	4B48BF	2433 840295	YURIY ZAYCEV	{"phone": "+70313207194"}
0005434163626	C95286	8740 485379	VALENTINA ORLOVA	{"phone": "+70378564486"}
0005434163627	F9A5DC	0536 323634	ALEKSANDR SOROKIN	{"phone": "+70498537711"}
0005434163628	F9A5DC	2403 445293	SERGEY DMITRIEV	{"email": "dmitrievs-071978@postgrespro.ru", "phone": "+70911021440"}
0005434163629	8BD5EF	6622 674755	ANASTASIYA YAKOVLEVA	{"phone": "+70963024431"}
0005434163630	8BD5EF	5799 864163	ANTONINA MIRONOVA	{"email": "mironova.antonina-051971@postgrespro.ru", "phone": "+70265495406"}
0005434163631	E1C351	7674 241966	ALEKSANDR VOROBEV	{"phone": "+70783984751"}
0005434163632	148EFD	0523 524928	TATYANA MAKAROVA	{"email": "tatyana_makarova-19071958@postgrespro.ru", "phone": "+70381145844"}
0005434163633	148EFD	9083 487730	NATALYA AFANASEVA	{"email": "natalya.afanaseva_101959@postgrespro.ru", "phone": "+70661552542"}
0005434163634	148EFD	3136 596557	MARIYA KOZLOVA	{"email": "mkozlova-1970@postgrespro.ru", "phone": "+70266589180"}
0005434163635	148EFD	3524 833502	VLADIMIR MAKAROV	{"phone": "+70736763328"}
0005434163636	B2E53B	0370 081367	KONSTANTIN FROLOV	{"phone": "+70938733273"}
0005434163637	B2E53B	4205 677990	KRISTINA KUZNECOVA	{"email": "kristina_kuznecova_04111969@postgrespro.ru", "phone": "+70342444963"}
0005434163638	93BCF9	1978 303105	YULIYA YUDINA	{"email": "yuliya_yudina-1969@postgrespro.ru", "phone": "+70661191955"}
0005434163639	259470	0319 830990	LYUDMILA ZAKHAROVA	{"email": "zakharova-lyudmila.14121975@postgrespro.ru", "phone": "+70715549557"}
0005434163640	50B2DB	6067 836551	VYACHESLAV KRASNOV	{"email": "vyacheslav-krasnov1972@postgrespro.ru", "phone": "+70784948140"}
0005434163641	50B2DB	5235 737210	SERGEY IVANOV	{"email": "sergey_ivanov_1966@postgrespro.ru", "phone": "+70705542120"}
0005434163642	21FF60	8644 953250	SERGEY NAZAROV	{"email": "nazarov-sergey-1971@postgrespro.ru", "phone": "+70086373844"}
0005434163643	21FF60	1027 249739	VIKTOR NIKOLAEV	{"email": "v.nikolaev-071977@postgrespro.ru", "phone": "+70779031175"}
0005434163644	540458	8912 782266	INNA MASLOVA	{"phone": "+70125632416"}
0005434163645	540458	8863 438657	ELENA POTAPOVA	{"phone": "+70536334330"}
0005434163646	540458	6145 011034	ZINAIDA BOGDANOVA	{"phone": "+70395799056"}
0005434163647	28A48F	1055 470898	SERGEY ALEKSEEV	{"email": "s_alekseev.03061978@postgrespro.ru", "phone": "+70579929693"}
0005434163648	739B70	0791 466393	TATYANA ROMANOVA	{"email": "romanovat.18041966@postgrespro.ru", "phone": "+70970878149"}
0005434163649	739B70	4227 977781	IRINA KRASNOVA	{"email": "irina-krasnova.011976@postgrespro.ru", "phone": "+70872615782"}
0005434163650	46A021	2560 418501	VYACHESLAV ISAEV	{"email": "isaev_vyacheslav-041983@postgrespro.ru", "phone": "+70332694722"}
0005434163651	46A021	4455 940955	NATALYA NESTEROVA	{"phone": "+70516712031"}
0005434163652	EFE9F9	5066 373443	GALINA VLASOVA	{"email": "vlasova-g1977@postgrespro.ru", "phone": "+70726854944"}
0005434163653	01B0A2	8503 467314	IGOR MOISEEV	{"email": "igor.moiseev.12111976@postgrespro.ru", "phone": "+70284133689"}
0005434163654	01B0A2	5975 385911	VYACHESLAV AFANASEV	{"email": "vyacheslav_afanasev081970@postgrespro.ru", "phone": "+70408081937"}
0005434163655	6A4835	9769 105399	GALINA MELNIKOVA	{"email": "melnikovag-1970@postgrespro.ru", "phone": "+70259180294"}
0005434163656	4E6218	9023 118323	MARGARITA AKIMOVA	{"email": "akimovam.031977@postgrespro.ru", "phone": "+70525149883"}
0005434163657	763F77	2053 649531	LYUBOV VLASOVA	{"email": "l-vlasova.051982@postgrespro.ru", "phone": "+70676165172"}
0005434163658	763F77	9023 128292	NADEZHDA VOROBEVA	{"email": "nadezhda-vorobeva1991@postgrespro.ru", "phone": "+70229636231"}
0005434163659	67F21A	8117 197430	DENIS KOROLEV	{"email": "korolev_d.31071968@postgrespro.ru", "phone": "+70474579901"}
0005434163660	67F21A	1951 180998	MARIYA MALYSHEVA	{"email": "malysheva.mariya.121964@postgrespro.ru", "phone": "+70095053665"}
0005434163661	87AFED	6975 536188	TARAS VOROBEV	{"email": "vorobev_t1977@postgrespro.ru", "phone": "+70724805066"}
0005434163662	B84E8D	0077 718001	ULYANA ANTONOVA	{"phone": "+70521512377"}
0005434163663	EDA70F	4351 658378	TATYANA ILINA	{"phone": "+70091108234"}
0005434163664	FD1BC1	8250 498469	VALERIY POPOV	{"email": "v-popov.16111980@postgrespro.ru", "phone": "+70271185232"}
0005434163665	0D2159	5639 974716	GENNADIY VLASOV	{"phone": "+70955281994"}
0005434163666	0D2159	1121 315989	MIKHAIL ANDREEV	{"email": "m.andreev-091971@postgrespro.ru", "phone": "+70711221643"}
0005434163667	7B48F7	6118 590009	RUSLAN SAVELEV	{"email": "ruslan_savelev_1973@postgrespro.ru", "phone": "+70973210385"}
0005434163668	313141	8947 428018	PETR KOZLOV	{"phone": "+70318775926"}
0005434163669	A8D2BB	6115 376497	RAUF KULIKOV	{"phone": "+70874175237"}
0005434163670	BA57B7	4787 449439	IVAN KUZNECOV	{"phone": "+70381650697"}
0005434163671	BA57B7	0390 470585	ANDREY KOROLEV	{"email": "korolevandrey.25111966@postgrespro.ru", "phone": "+70578968530"}
0005434163672	C650AC	6133 669612	SVETLANA ZHUKOVA	{"phone": "+70815149599"}
0005434163673	89D3D3	5109 377329	SERAFIMA TARASOVA	{"email": "tarasova-s051978@postgrespro.ru", "phone": "+70570243619"}
0005434163674	398877	8495 425190	GALINA KUZNECOVA	{"phone": "+70147101763"}
0005434163675	BE0376	9668 962968	ALEKSEY POPOV	{"phone": "+70862795926"}
0005434163676	09FDCE	8675 441410	TATYANA POPOVA	{"phone": "+70936576797"}
0005434163677	09FDCE	5896 123194	MARIYA MAKAROVA	{"email": "mariyamakarova.31081962@postgrespro.ru", "phone": "+70277204630"}
0005434163678	BD47BC	7202 227765	ANDREY ANDREEV	{"phone": "+70318896878"}
0005434163679	EDD384	9614 418230	VALENTINA VOROBEVA	{"phone": "+70530602486"}
0005434163680	3A69CA	9648 661907	OLGA TITOVA	{"email": "titova-o_06011972@postgrespro.ru", "phone": "+70692125040"}
0005434163681	3A69CA	1908 452793	ANTONINA AKIMOVA	{"email": "a-akimova_061959@postgrespro.ru", "phone": "+70186002054"}
0005434163682	63FC2D	2609 400851	RAISA YUDINA	{"phone": "+70438939200"}
0005434163683	9075EB	6011 281231	ANNA MOROZOVA	{"phone": "+70920362001"}
0005434163684	B966F9	9080 613461	SERGEY POPOV	{"email": "popov.sergey-071967@postgrespro.ru", "phone": "+70204649089"}
0005434163685	21D604	8355 484752	KHASAN MAKSIMOV	{"phone": "+70754671580"}
0005434163686	21D604	6699 056262	VADIM KOZLOV	{"email": "vadim-kozlov.19111969@postgrespro.ru", "phone": "+70139888439"}
0005434163687	21D604	1705 761728	SVETLANA FEDOROVA	{"phone": "+70181640989"}
0005434163688	10224F	0837 705507	VYACHESLAV IVANOV	{"email": "vyacheslavivanov.02021969@postgrespro.ru", "phone": "+70021791314"}
0005434163689	10224F	3451 980029	ZINAIDA NESTEROVA	{"phone": "+70803550832"}
0005434163690	66A4CF	9384 711544	KONSTANTIN SEMENOV	{"email": "k.semenov_02021975@postgrespro.ru", "phone": "+70621763760"}
0005434163691	66A4CF	8043 767513	VIKTOR FILIPPOV	{"phone": "+70596426851"}
0005434163692	47D142	9899 768196	PAVEL VASILEV	{"email": "vasilevpavel1972@postgrespro.ru", "phone": "+70009103008"}
0005434163693	A475E4	8987 879100	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr_1958@postgrespro.ru", "phone": "+70537261655"}
0005434163694	A475E4	7041 832253	GENNADIY EGOROV	{"email": "g.egorov-1971@postgrespro.ru", "phone": "+70842311242"}
0005434163695	A475E4	6664 262166	ALEKSANDR ZHURAVLEV	{"email": "azhuravlev-1971@postgrespro.ru", "phone": "+70573074448"}
0005434163696	1ACFDB	2700 603493	VIKTOR FEDOTOV	{"email": "viktor-fedotov.10101966@postgrespro.ru", "phone": "+70605134788"}
0005434163697	3F7258	6360 490260	VLADIMIR ILIN	{"email": "vladimir.ilin-041972@postgrespro.ru", "phone": "+70823185060"}
0005434163698	91FEC7	4031 657928	ANTONINA MAKAROVA	{"phone": "+70388196249"}
0005434163699	2C6641	8428 244578	EKATERINA ANTONOVA	{"phone": "+70545424594"}
0005434163700	2C6641	0652 693130	SERGEY NOVIKOV	{"phone": "+70188391193"}
0005434163701	0B2FE5	5077 592625	RAISA PAVLOVA	{"email": "pavlova-raisa-1977@postgrespro.ru", "phone": "+70165999461"}
0005434163702	0B2FE5	3317 089466	ANNA TIMOFEEVA	{"email": "a_timofeeva_071965@postgrespro.ru", "phone": "+70250834202"}
0005434163703	1F75D7	0721 425937	ALEKSANDRA SAVELEVA	{"email": "a.saveleva.081965@postgrespro.ru", "phone": "+70999380406"}
0005434163704	34F288	3957 501157	ANTONINA KISELEVA	{"email": "kiseleva-antonina1985@postgrespro.ru", "phone": "+70483632338"}
0005434163705	40752F	9550 898881	TATYANA TITOVA	{"phone": "+70829551668"}
0005434163706	40752F	1663 609392	SVETLANA KOVALEVA	{"phone": "+70218424224"}
0005434163707	74B7C5	4199 359813	ELENA SOROKINA	{"phone": "+70034886684"}
0005434163708	8BA106	1608 271352	DARYA MOISEEVA	{"phone": "+70310802360"}
0005434163709	22BB07	9300 511010	GALINA FADEEVA	{"phone": "+70348392022"}
0005434163710	EB8628	4698 548698	ANATOLIY IVANOV	{"phone": "+70124410698"}
0005434163711	E45F96	9110 635910	DENIS STEPANOV	{"phone": "+70654152282"}
0005434163712	E45F96	2920 757233	ANASTASIYA GERASIMOVA	{"email": "gerasimova.anastasiya.071966@postgrespro.ru", "phone": "+70708653968"}
0005434163713	80CB51	2442 195632	ANASTASIYA IVANOVA	{"phone": "+70559804481"}
0005434163714	26A768	7690 324443	GALINA GUSEVA	{"phone": "+70121942889"}
0005434163715	9FFCCE	5290 412151	LYUBOV KOZLOVA	{"phone": "+70870653218"}
0005434163716	024EB6	8773 380980	TATYANA PETROVA	{"phone": "+70135258357"}
0005434163717	40B866	8514 991332	VLADIMIR BORISOV	{"phone": "+70229142523"}
0005434163718	580742	4968 591862	TATYANA KRASNOVA	{"phone": "+70068190209"}
0005434163719	A03FF7	8250 498524	SERGEY MAKSIMOV	{"phone": "+70629859273"}
0005434163720	BD4C17	7151 916084	YULIYA SEMENOVA	{"phone": "+70065969512"}
0005434163721	084C21	1367 582068	VITALIY KULIKOV	{"phone": "+70082887414"}
0005434163722	084C21	1196 334167	SOFYA KUDRYASHOVA	{"email": "kudryashova-s.1961@postgrespro.ru", "phone": "+70507132667"}
0005434163723	2AB715	2533 094319	VLADIMIR MAKAROV	{"phone": "+70446948876"}
0005434163724	10BE44	0461 300111	SVETLANA ANDREEVA	{"email": "andreeva.svetlana.22011969@postgrespro.ru", "phone": "+70090757181"}
0005434163725	3047DA	6388 131797	LIDIYA NIKITINA	{"email": "l_nikitina_19011966@postgrespro.ru", "phone": "+70273436893"}
0005434163726	3047DA	1214 654025	ALEKSANDR MOISEEV	{"email": "aleksandr.moiseev-1965@postgrespro.ru", "phone": "+70600002842"}
0005434163727	5D991D	9248 238731	PAVEL ROMANOV	{"email": "romanov-p081977@postgrespro.ru", "phone": "+70595565663"}
0005434163728	B0B780	0357 700367	ELENA VOROBEVA	{"email": "vorobeva.elena_031969@postgrespro.ru", "phone": "+70390242740"}
0005434163729	ADF643	7615 585039	MARINA NAZAROVA	{"email": "nazarovamarina_1960@postgrespro.ru", "phone": "+70892532988"}
0005434163730	96E67E	8169 964487	ALEKSANDR EGOROV	{"email": "a-egorov19051973@postgrespro.ru", "phone": "+70923412759"}
0005434163731	96E67E	7364 206498	PAVEL MEDVEDEV	{"phone": "+70940443846"}
0005434163732	FCE3AC	7414 273639	MAKSIM EGOROV	{"email": "m-egorov08011969@postgrespro.ru", "phone": "+70489027240"}
0005434163733	3870C3	0332 038187	POLINA MAKAROVA	{"phone": "+70835547538"}
0005434163734	0A0A57	8382 458432	ALEKSANDR ORLOV	{"email": "aleksandrorlov.041973@postgrespro.ru", "phone": "+70188738884"}
0005434163735	0A0A57	0571 691825	DMITRIY POPOV	{"phone": "+70808263691"}
0005434163736	0A0A57	8583 708257	ANATOLIY SERGEEV	{"email": "sergeev.a24061979@postgrespro.ru", "phone": "+70000028109"}
0005434163737	00F598	0807 611427	NATALYA ISAEVA	{"email": "isaevanatalya-1976@postgrespro.ru", "phone": "+70786925948"}
0005434163738	00F598	6713 445344	VIKTOR VOLKOV	{"email": "volkov_viktor29101958@postgrespro.ru", "phone": "+70554678276"}
0005434163739	DB8430	4119 725905	MARGARITA KUZMINA	{"email": "kuzminamargarita-121971@postgrespro.ru", "phone": "+70648948513"}
0005434163740	DB8430	7182 039798	KIRILL GAVRILOV	{"email": "gavrilovk_02111971@postgrespro.ru", "phone": "+70366904337"}
0005434163741	C8E097	3693 337445	OLEG STEPANOV	{"email": "o-stepanov.1975@postgrespro.ru", "phone": "+70837535233"}
0005434163742	7EEE46	9400 227386	ALEKSANDR POPOV	{"email": "a_popov111976@postgrespro.ru", "phone": "+70720503466"}
0005434163743	B67FCA	4916 566271	GALINA NOVIKOVA	{"email": "galinanovikova121974@postgrespro.ru", "phone": "+70775435308"}
0005434163744	007085	1017 824269	VLADIMIR MAKAROV	{"phone": "+70846956612"}
0005434163745	007085	3029 250751	LYUDMILA YUDINA	{"phone": "+70814206741"}
0005434163746	C057BE	0408 120071	IGOR ROMANOV	{"email": "igorromanov-121974@postgrespro.ru", "phone": "+70249785375"}
0005434163747	C057BE	7273 062209	SERGEY FOMIN	{"phone": "+70010260279"}
0005434163748	E37943	7103 707131	RAISA ORLOVA	{"email": "orlova.raisa1967@postgrespro.ru", "phone": "+70117894115"}
0005434163749	8EBD2F	7514 310902	VIKTOR ROMANOV	{"phone": "+70737759591"}
0005434163750	8EBD2F	7520 550407	NIKOLAY TARASOV	{"email": "tarasov.n-111975@postgrespro.ru", "phone": "+70458082659"}
0005434163751	BB5FF5	3950 459571	YULIYA PETROVA	{"email": "y-petrova1962@postgrespro.ru", "phone": "+70873768566"}
0005434163752	3BAD12	9298 061233	DMITRIY PETROV	{"phone": "+70396176749"}
0005434163753	3BAD12	1535 197187	SVETLANA ANDREEVA	{"email": "sandreeva_081975@postgrespro.ru", "phone": "+70290820769"}
0005434163754	0BBB64	9440 757655	VLADIMIR PAVLOV	{"phone": "+70915775631"}
0005434173533	FE3E45	6122 185575	NIKOLAY ROMANOV	{"phone": "+70700831472"}
0005434163755	C58F33	6484 533148	VLADIMIR KISELEV	{"email": "v.kiselev.1964@postgrespro.ru", "phone": "+70214439548"}
0005434163756	CC2B8A	7959 912538	DMITRIY ANDREEV	{"email": "d_andreev061969@postgrespro.ru", "phone": "+70382539906"}
0005434163757	52853E	5838 598388	DMITRIY SHEVCHENKO	{"phone": "+70948226405"}
0005434163758	E3B022	6569 838047	TATYANA MELNIKOVA	{"phone": "+70212027366"}
0005434163759	01C8DA	9605 713583	EVGENIYA KUDRYASHOVA	{"phone": "+70107915922"}
0005434163760	01C8DA	9338 445694	PAVEL ZHUKOV	{"phone": "+70862295146"}
0005434163761	01C8DA	3941 056297	YURIY SAVELEV	{"email": "yuriy_savelev10121972@postgrespro.ru", "phone": "+70396940505"}
0005434163762	692799	6334 486512	OLGA FILATOVA	{"phone": "+70763938871"}
0005434163763	91F48C	9889 564266	NIKOLAY EGOROV	{"email": "egorov.n_1970@postgrespro.ru", "phone": "+70739680512"}
0005434163764	91F48C	5098 519163	NADEZHDA AKIMOVA	{"phone": "+70093157275"}
0005434163765	FECF3D	1185 136317	VASILIY SEMENOV	{"email": "v-semenov.071973@postgrespro.ru", "phone": "+70230128941"}
0005434163766	AA86F4	4520 880636	OKSANA SERGEEVA	{"email": "sergeeva-oksana061958@postgrespro.ru", "phone": "+70419156029"}
0005434163767	AA86F4	9763 668721	VALERIY IVANOV	{"email": "valeriy-ivanov.081979@postgrespro.ru", "phone": "+70556164306"}
0005434163768	8AC2FD	5915 673083	MIKHAIL SMIRNOV	{"phone": "+70228616647"}
0005434163769	4EAF22	9791 995914	ANDREY GORBUNOV	{"email": "gorbunov_andrey1979@postgrespro.ru", "phone": "+70214139363"}
0005434163770	4EAF22	2843 021253	PAVEL VASILEV	{"email": "p_vasilev.051976@postgrespro.ru", "phone": "+70348439144"}
0005434163771	FE1C11	1673 365709	EVGENIY AFANASEV	{"email": "afanasev-e_30101972@postgrespro.ru", "phone": "+70813475562"}
0005434163772	CF41FF	9529 564678	EVGENIY KUZNECOV	{"phone": "+70498355737"}
0005434163773	D11F65	5100 301394	VALENTIN ABRAMOV	{"phone": "+70472481817"}
0005434163774	D11F65	0672 834577	ELENA DAVYDOVA	{"email": "davydova.elena.1984@postgrespro.ru", "phone": "+70909883724"}
0005434163775	6CD980	4668 786357	KIRILL ISAEV	{"phone": "+70916977058"}
0005434163776	7F2733	6864 002416	OKSANA MELNIKOVA	{"email": "melnikova_oksana_16121971@postgrespro.ru", "phone": "+70859760541"}
0005434163777	FC88B9	3835 326643	NATALYA KOZLOVA	{"phone": "+70399542271"}
0005434163778	FC88B9	2935 650806	FILIPP TIMOFEEV	{"email": "timofeev_f-111971@postgrespro.ru", "phone": "+70597457812"}
0005434163779	1F6CD9	0106 427505	ANTON VOROBEV	{"phone": "+70644557617"}
0005434163780	0C38B6	4284 119088	ANASTASIYA EGOROVA	{"phone": "+70374467520"}
0005434163781	F09D8B	5147 618368	ANDREY KARPOV	{"email": "karpovandrey031978@postgrespro.ru", "phone": "+70918632783"}
0005434163782	F09D8B	5727 715856	ALEKSEY KOROLEV	{"phone": "+70880630480"}
0005434163783	C9A648	8097 730765	VLADIMIR AFANASEV	{"email": "vladimir-afanasev.111971@postgrespro.ru", "phone": "+70663590483"}
0005434163784	C9A648	2135 807746	IRINA ZHURAVLEVA	{"email": "zhuravleva-i1962@postgrespro.ru", "phone": "+70975482599"}
0005434163785	4D77C2	0801 581851	VYACHESLAV VOLKOV	{"email": "vvolkov_011983@postgrespro.ru", "phone": "+70779689590"}
0005434163786	085A8D	3434 451202	SVETLANA KOZLOVA	{"email": "kozlovas_1971@postgrespro.ru", "phone": "+70236923792"}
0005434163787	F5AADB	9399 524472	KONSTANTIN IVANOV	{"phone": "+70449136482"}
0005434163788	8C6E0D	1993 895631	ALEKSANDR SCHERBAKOV	{"phone": "+70895812425"}
0005434163789	DE37CD	2694 509158	ANATOLIY SMIRNOV	{"email": "smirnov-anatoliy121977@postgrespro.ru", "phone": "+70841667159"}
0005434163790	A1D394	6929 621534	TATYANA SEMENOVA	{"email": "tsemenova_1962@postgrespro.ru", "phone": "+70040262840"}
0005434163791	A1D394	8778 338676	EKATERINA KUZMINA	{"email": "kuzmina.ekaterina_1975@postgrespro.ru", "phone": "+70063377326"}
0005434163792	E08957	9543 390190	SERGEY KUZNECOV	{"email": "kuznecov_sergey-121970@postgrespro.ru", "phone": "+70698469887"}
0005434163793	D59246	7881 596037	SVETLANA ILINA	{"phone": "+70717521672"}
0005434163794	81BF27	4269 809224	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov051973@postgrespro.ru", "phone": "+70917090395"}
0005434163795	81BF27	8477 583052	GENNADIY PETROV	{"phone": "+70575069790"}
0005434163796	81BF27	2611 873438	DANILA POPOV	{"email": "popov_danila121977@postgrespro.ru", "phone": "+70037212044"}
0005434163797	3D3C9A	3079 876089	ALEKSANDRA NIKOLAEVA	{"phone": "+70001019629"}
0005434163798	53D317	3363 957685	ILDAR TIMOFEEV	{"email": "ildartimofeev1969@postgrespro.ru", "phone": "+70013431752"}
0005434163799	F53D7D	8853 353724	VITALIY DAVYDOV	{"phone": "+70241340345"}
0005434163800	F53D7D	6826 651079	ILGIZ GRIGOREV	{"email": "ilgiz_grigorev.041965@postgrespro.ru", "phone": "+70822092442"}
0005434163801	9197FC	0046 131332	VLADISLAV KOZLOV	{"phone": "+70470112561"}
0005434163802	9AB696	0892 282796	ALEKSANDRA MOROZOVA	{"phone": "+70779700095"}
0005434163803	71F355	7742 050319	MIKHAIL VOLKOV	{"email": "mikhailvolkov-1976@postgrespro.ru", "phone": "+70420429556"}
0005434163804	EBE3D5	6432 466133	IRINA VASILEVA	{"phone": "+70493915738"}
0005434163805	083330	0845 522782	ARKADIY FROLOV	{"phone": "+70807935653"}
0005434163806	2480E2	2037 079478	RAISA KOROLEVA	{"phone": "+70934446584"}
0005434163807	2480E2	4034 709558	TAMARA KOMAROVA	{"email": "t_komarova-07091969@postgrespro.ru", "phone": "+70067792288"}
0005434163808	FECF23	3072 952852	ANASTASIYA KOMAROVA	{"email": "komarovaa1979@postgrespro.ru", "phone": "+70685445501"}
0005434163809	76AC09	9854 738012	TAISIYA MOISEEVA	{"email": "t_moiseeva21021975@postgrespro.ru", "phone": "+70331551380"}
0005434163810	80A31B	1575 146719	OLESYA ZHUKOVA	{"phone": "+70967781595"}
0005434163811	80A31B	2805 763054	MIKHAIL ZHURAVLEV	{"email": "zhuravlevm-1972@postgrespro.ru", "phone": "+70777822254"}
0005434163812	80A31B	7662 066690	OKSANA ILINA	{"email": "oksana.ilina1968@postgrespro.ru", "phone": "+70840485233"}
0005434163813	1AB6F7	7611 692648	EVGENIY FEDOROV	{"email": "fedorovevgeniy101962@postgrespro.ru", "phone": "+70690687122"}
0005434163814	1AB6F7	4741 727429	ALEKSANDR DENISOV	{"email": "denisov.a021969@postgrespro.ru", "phone": "+70701134996"}
0005434163815	F09BF6	3696 823556	VALENTINA GERASIMOVA	{"phone": "+70064314120"}
0005434163816	806CC9	1246 154125	ARTEM NAZAROV	{"email": "nazarov_artem-1965@postgrespro.ru", "phone": "+70521461281"}
0005434163817	60BA63	4432 040693	ELENA ROMANOVA	{"phone": "+70597005249"}
0005434163818	60BA63	1568 723419	RUSLAN KUZNECOV	{"phone": "+70986946294"}
0005434163819	9BD6AC	2524 394283	VALENTINA KULIKOVA	{"email": "kulikova_valentina_1968@postgrespro.ru", "phone": "+70182971218"}
0005434163820	3AF0A7	0557 560939	ELIZAVETA KUZNECOVA	{"phone": "+70699171622"}
0005434163821	3AF0A7	4831 914431	IRINA SMIRNOVA	{"phone": "+70517440424"}
0005434163822	B86327	8829 231255	TATYANA TIMOFEEVA	{"email": "timofeeva.tatyana.1962@postgrespro.ru", "phone": "+70315415968"}
0005434163823	B86327	4013 135445	MAKSIM PETROV	{"phone": "+70391103703"}
0005434163824	B86327	3598 641414	EKATERINA VOROBEVA	{"email": "ekaterina.vorobeva_121971@postgrespro.ru", "phone": "+70484842104"}
0005434163825	CC747C	0419 765761	LYUDMILA NIKITINA	{"phone": "+70882871365"}
0005434163826	8E5C7A	9654 255898	VLADIMIR CHERNOV	{"email": "vladimir_chernov1986@postgrespro.ru", "phone": "+70871195233"}
0005434163827	8E5C7A	9649 700119	LYUBOV TARASOVA	{"email": "tarasova-l-30041968@postgrespro.ru", "phone": "+70439072056"}
0005434163828	DD43FC	7049 962386	ARTEM MIKHAYLOV	{"phone": "+70991193610"}
0005434163829	DD43FC	9533 731455	ANDREY BORISOV	{"phone": "+70503352191"}
0005434163830	6A7402	4434 812726	IVAN MAKAROV	{"phone": "+70060704089"}
0005434163831	EA7244	6068 887926	VYACHESLAV SOKOLOV	{"email": "vyacheslav-sokolov.05111964@postgrespro.ru", "phone": "+70183013991"}
0005434163832	701520	1794 237020	NATALYA SMIRNOVA	{"email": "smirnova-natalya-1969@postgrespro.ru", "phone": "+70373827743"}
0005434163833	E95C4F	6759 340650	ALEKSANDR KOZLOV	{"phone": "+70075937415"}
0005434163834	D16F64	6522 242619	DMITRIY KAZAKOV	{"email": "kazakovd-17111975@postgrespro.ru", "phone": "+70037364364"}
0005434163835	D16F64	4485 781316	DMITRIY VASILEV	{"email": "vasilev.d-09111969@postgrespro.ru", "phone": "+70001053422"}
0005434163836	A3CD1B	1643 225324	NATALYA GORBUNOVA	{"email": "gorbunova.n_18021968@postgrespro.ru", "phone": "+70578406799"}
0005434163837	A3CD1B	6537 346058	SOFYA DENISOVA	{"email": "denisova-sofya24051975@postgrespro.ru", "phone": "+70890958179"}
0005434163838	A3CD1B	3452 876512	ALENA TARASOVA	{"email": "tarasova.alena111975@postgrespro.ru", "phone": "+70717226096"}
0005434163839	998966	8700 301841	OLGA VOLKOVA	{"phone": "+70647494988"}
0005434163840	998966	1738 457596	YURIY CHERNOV	{"phone": "+70174166938"}
0005434163841	67906C	6101 816691	ALEFTINA YUDINA	{"email": "yudina-a.1974@postgrespro.ru", "phone": "+70234523103"}
0005434163842	F01290	8645 989995	ELENA NIKOLAEVA	{"phone": "+70316574614"}
0005434163843	F01290	7907 411725	VIKTOR FEDOROV	{"email": "viktor-fedorov-05091968@postgrespro.ru", "phone": "+70121969484"}
0005434163844	550DED	5958 762858	ANNA EFIMOVA	{"phone": "+70545605491"}
0005434163845	C14E44	2280 824950	TAMARA ARKHIPOVA	{"email": "t-arkhipova.071974@postgrespro.ru", "phone": "+70266216846"}
0005434163846	384244	0057 219081	YURIY CHERNOV	{"email": "yuriy.chernov09101965@postgrespro.ru", "phone": "+70135531183"}
0005434163847	3EC26C	2585 266448	KLIM DENISOV	{"email": "klim_denisov-1976@postgrespro.ru", "phone": "+70122299114"}
0005434163848	A5AC28	4761 700133	ELENA SCHERBAKOVA	{"email": "e-scherbakova_111968@postgrespro.ru", "phone": "+70608832644"}
0005434163849	A5AC28	4159 810686	DANILA MEDVEDEV	{"email": "medvedev_danila_1972@postgrespro.ru", "phone": "+70733441507"}
0005434163850	DF246F	3337 576719	VLADIMIR NAZAROV	{"phone": "+70103382403"}
0005434163851	AEA56F	0076 559086	ZOYA POPOVA	{"email": "zpopova_1962@postgrespro.ru", "phone": "+70406029800"}
0005434163852	A9E0CD	4472 198791	ANASTASIYA KUZMINA	{"email": "a-kuzmina02081967@postgrespro.ru", "phone": "+70742427682"}
0005434163853	35513B	1290 515472	VLADISLAV ZAYCEV	{"email": "vzaycev.1964@postgrespro.ru", "phone": "+70505838647"}
0005434163854	35513B	9260 945150	PAVEL KUZMIN	{"email": "kuzmin_pavel.23101965@postgrespro.ru", "phone": "+70490361782"}
0005434163855	0258FC	7354 634765	NIKOLAY MEDVEDEV	{"phone": "+70501770083"}
0005434163856	278BC9	9919 117737	ALEKSANDR MOROZOV	{"email": "morozov_a_051965@postgrespro.ru", "phone": "+70321089370"}
0005434163857	278BC9	0375 825577	NADEZHDA MASLOVA	{"phone": "+70845187618"}
0005434163858	394509	0646 617142	ELENA IVANOVA	{"email": "e.ivanova-21041976@postgrespro.ru", "phone": "+70058031814"}
0005434163859	394509	9119 531971	VLADIMIR SOLOVEV	{"phone": "+70244062536"}
0005434163860	649B2E	1237 500833	LYUDMILA BARANOVA	{"email": "baranova_l.081981@postgrespro.ru", "phone": "+70539133027"}
0005434163861	649B2E	5188 085018	EVGENIY GUSEV	{"email": "gusev-evgeniy-091971@postgrespro.ru", "phone": "+70675837469"}
0005434163862	69490D	6679 719540	NIKOLAY ISAEV	{"phone": "+70748004983"}
0005434163863	600EEA	4401 029548	LYUDMILA ZAKHAROVA	{"email": "lyudmilazakharova-04091965@postgrespro.ru", "phone": "+70086741737"}
0005434163864	600EEA	3491 842708	VLADIMIR VOLKOV	{"email": "vladimir-volkov-21051977@postgrespro.ru", "phone": "+70002417970"}
0005434163865	C67F05	6633 900369	ALEKSANDR IVANOV	{"email": "aivanov.27101976@postgrespro.ru", "phone": "+70469895632"}
0005434163866	EAE288	0906 901106	SERGEY GAVRILOV	{"email": "gavrilov.s-06061979@postgrespro.ru", "phone": "+70982102315"}
0005434163867	EBE1CC	9723 975755	IGOR KARPOV	{"email": "karpov.igor_101978@postgrespro.ru", "phone": "+70959809699"}
0005434163868	273FC7	6628 803395	ALEKSANDRA ILINA	{"phone": "+70712415835"}
0005434163869	273FC7	0906 796528	VYACHESLAV CHERNOV	{"phone": "+70826285019"}
0005434163870	24C0AD	1733 656046	VLADIMIR VOLKOV	{"phone": "+70433296741"}
0005434163871	C85479	6368 491205	ANTONINA EGOROVA	{"phone": "+70348802866"}
0005434163872	638D56	8800 144303	DMITRIY BARANOV	{"phone": "+70196920880"}
0005434163873	0EA4DE	1891 889133	MAKSIM MAKAROV	{"email": "maksimmakarov-051971@postgrespro.ru", "phone": "+70717942224"}
0005434163874	26F327	2377 591091	ARSENIY IVANOV	{"email": "ivanovarseniy-031979@postgrespro.ru", "phone": "+70021639032"}
0005434163875	FA6267	9908 053656	VERA LAZAREVA	{"phone": "+70860175127"}
0005434163876	4799B4	7273 183968	BULAT GRIGOREV	{"phone": "+70434166485"}
0005434163877	4799B4	5857 844669	ALEKSANDR EGOROV	{"phone": "+70382701340"}
0005434163878	4799B4	4760 493282	ANNA FILIPPOVA	{"email": "afilippova121964@postgrespro.ru", "phone": "+70503887834"}
0005434163879	4687E5	7648 443142	EKATERINA MELNIKOVA	{"email": "melnikova_ekaterina121963@postgrespro.ru", "phone": "+70822063716"}
0005434163880	4687E5	5795 766469	NIKITA SAVELEV	{"phone": "+70297051529"}
0005434163881	D4DF79	2635 024802	NINA MAKSIMOVA	{"phone": "+70810276370"}
0005434163882	3407BC	5021 167442	ANNA SOKOLOVA	{"phone": "+70502122199"}
0005434163883	3407BC	9596 250136	ANASTASIYA KUZNECOVA	{"email": "kuznecovaa-14021983@postgrespro.ru", "phone": "+70106084558"}
0005434163884	3407BC	8612 984867	EVGENIY SMIRNOV	{"email": "smirnov_e.01021982@postgrespro.ru", "phone": "+70632332292"}
0005434163885	5C2079	6921 908907	LYUBOV FADEEVA	{"email": "fadeeva-lyubov1983@postgrespro.ru", "phone": "+70944621261"}
0005434163886	965C8C	2766 460619	ALEKSEY SOLOVEV	{"email": "alekseysolovev-31121970@postgrespro.ru", "phone": "+70593351625"}
0005434163887	0164E1	8795 345752	YURIY ANTONOV	{"email": "antonov.y.13051960@postgrespro.ru", "phone": "+70654199307"}
0005434170797	B5B042	5442 448368	VALENTIN ZAKHAROV	{"phone": "+70281171632"}
0005434170798	3AFC33	8349 466363	YULIYA NAZAROVA	{"phone": "+70307196535"}
0005434170799	3AFC33	6613 389326	ALIYA AFANASEVA	{"email": "aliya-afanaseva.081962@postgrespro.ru", "phone": "+70974890882"}
0005434170800	A4B096	2393 264289	GLEB MAKAROV	{"phone": "+70732064900"}
0005434170801	5C3468	4934 341737	VLADISLAV NAZAROV	{"phone": "+70011907499"}
0005434170802	169F85	0695 282279	OLGA SOROKINA	{"phone": "+70884159435"}
0005434170803	169F85	0044 194272	ANASTASIYA MOROZOVA	{"phone": "+70686509939"}
0005434170804	71645A	5297 139469	EVGENIY FOMIN	{"email": "e_fomin1968@postgrespro.ru", "phone": "+70970472311"}
0005434170805	AADC83	7293 868232	ALEKSANDR ANDREEV	{"email": "andreev.a.22091978@postgrespro.ru", "phone": "+70384675217"}
0005434170806	48174C	7333 469899	GALINA LOGINOVA	{"phone": "+70201679537"}
0005434170807	10F548	7140 632470	ANTONINA RODIONOVA	{"phone": "+70906091939"}
0005434170808	10F548	1535 698549	LILIYA CHERNOVA	{"email": "chernova-liliya.1965@postgrespro.ru", "phone": "+70782635471"}
0005434170809	37D3B5	4654 512250	SERGEY SHEVCHENKO	{"phone": "+70331349475"}
0005434170810	5D8BE4	1498 474670	IVAN MOISEEV	{"phone": "+70440191527"}
0005434170811	2832DE	7583 686320	ELENA KUZNECOVA	{"email": "e_kuznecova-1975@postgrespro.ru", "phone": "+70591643193"}
0005434170812	340008	0689 140409	ALEKSANDR STEPANOV	{"phone": "+70176194058"}
0005434170813	2D3AF7	8716 267770	VIKTORIYA IVANOVA	{"email": "viktoriya-ivanova-19041976@postgrespro.ru", "phone": "+70316131330"}
0005434170814	7635EF	8916 533014	LIDIYA EGOROVA	{"phone": "+70399330001"}
0005434170815	B723E5	0714 174939	EKATERINA PAVLOVA	{"phone": "+70137547414"}
0005434170816	B723E5	0240 687375	VIKTORIYA BARANOVA	{"phone": "+70295226134"}
0005434170817	DA3915	5098 726701	ELENA FOMINA	{"email": "fomina_e091971@postgrespro.ru", "phone": "+70471990437"}
0005434170818	441CE5	5688 384377	DMITRIY ALEKSEEV	{"email": "alekseev-d_1975@postgrespro.ru", "phone": "+70304220878"}
0005434170819	49BE3E	8328 433150	DAMIR FROLOV	{"phone": "+70925201052"}
0005434170820	49BE3E	7140 125001	ALEKSANDR FOMIN	{"phone": "+70496848650"}
0005434170821	B5EEC0	4954 510953	SERGEY PAVLOV	{"phone": "+70355897220"}
0005434170822	AB8473	6836 560306	NADEZHDA KOLESNIKOVA	{"email": "nadezhda-kolesnikova-24051975@postgrespro.ru", "phone": "+70723721174"}
0005434170823	88CE6D	2013 637899	VALENTINA VOROBEVA	{"phone": "+70824791482"}
0005434170824	EAD386	4441 631206	ELIZAVETA IVANOVA	{"email": "elizavetaivanova.1959@postgrespro.ru", "phone": "+70462685216"}
0005434170825	777993	3819 786422	TAMARA FEDOROVA	{"email": "tfedorova-1971@postgrespro.ru", "phone": "+70406668486"}
0005434170826	44FB2A	1436 218164	DENIS SIDOROV	{"email": "sidorov.d1978@postgrespro.ru", "phone": "+70226991177"}
0005434170827	E826AC	6603 381025	ALEKSANDRA IVANOVA	{"phone": "+70996721465"}
0005434170828	4D4070	9843 178767	TAMARA KUZNECOVA	{"email": "t_kuznecova.081981@postgrespro.ru", "phone": "+70225348438"}
0005434170829	D8C8CD	5192 953990	KRISTINA SEMENOVA	{"email": "kristina-semenova_1954@postgrespro.ru", "phone": "+70581349430"}
0005434170830	D8C8CD	1317 500163	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov-25061970@postgrespro.ru", "phone": "+70512045097"}
0005434170831	61A318	6909 058408	VLADIMIR NOVIKOV	{"email": "novikov_vladimir_1969@postgrespro.ru", "phone": "+70533807502"}
0005434170832	9FB2AB	8849 794469	RAISA NIKITINA	{"email": "raisa.nikitina1966@postgrespro.ru", "phone": "+70667139315"}
0005434170833	83D8AC	6335 788393	ANDREY GAVRILOV	{"phone": "+70091239916"}
0005434170834	16933B	0761 431157	EKATERINA VASILEVA	{"phone": "+70755633347"}
0005434170835	6A309E	6368 863108	MARTA ZAYCEVA	{"phone": "+70732152451"}
0005434170836	6A309E	9472 172047	VLADIMIR IVANOV	{"phone": "+70299548632"}
0005434170837	E10FD4	4036 995248	DIANA IVANOVA	{"phone": "+70761575279"}
0005434170838	E10FD4	6154 230746	VYACHESLAV NIKOLAEV	{"email": "vyacheslavnikolaev_111977@postgrespro.ru", "phone": "+70169408761"}
0005434170839	6B67A6	5899 178312	IGOR SOROKIN	{"email": "sorokin-i-1966@postgrespro.ru", "phone": "+70205207422"}
0005434170840	A8A4CF	0446 580111	TIMUR PAVLOV	{"email": "t-pavlov.1973@postgrespro.ru", "phone": "+70546687360"}
0005434170841	F5C74C	0177 720708	RUDOLF SOKOLOV	{"phone": "+70132125244"}
0005434173593	A93325	6156 680436	OLGA MAKAROVA	{"phone": "+70094320592"}
0005434170842	67D570	8100 880092	ANDREY KOROLEV	{"email": "korolev.a-041975@postgrespro.ru", "phone": "+70278938326"}
0005434170843	C2F2F5	3503 905167	VIKTOR ISAEV	{"phone": "+70285375079"}
0005434170844	C2F2F5	2248 120286	SERGEY NIKOLAEV	{"email": "nikolaev-sergey_111980@postgrespro.ru", "phone": "+70141727556"}
0005434170845	4E1A94	0834 674089	GENNADIY SOKOLOV	{"email": "sokolov-gennadiy19051975@postgrespro.ru", "phone": "+70705269656"}
0005434170846	AF1EDC	1481 252690	IRINA ERMAKOVA	{"email": "ermakova_i-061960@postgrespro.ru", "phone": "+70488796302"}
0005434170847	0A66F3	9013 310095	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev1975@postgrespro.ru", "phone": "+70268621655"}
0005434170848	E511F6	2189 420751	ELENA IVANOVA	{"email": "e.ivanova101973@postgrespro.ru", "phone": "+70150694380"}
0005434170849	E511F6	9693 929103	VLADISLAV BORISOV	{"email": "borisovvladislav-23021980@postgrespro.ru", "phone": "+70810774308"}
0005434170850	E511F6	1222 368497	DENIS MOROZOV	{"phone": "+70754742747"}
0005434170851	F7EF79	9516 000710	NIKOLAY VLASOV	{"email": "n_vlasov.1969@postgrespro.ru", "phone": "+70923056286"}
0005434170852	E8EBD7	8795 117589	VLADIMIR FEDOROV	{"phone": "+70414581871"}
0005434170853	23ED34	4317 128444	ALEKSANDR GAVRILOV	{"phone": "+70382145874"}
0005434170854	E4D293	9889 575407	ANNA RYABOVA	{"email": "ryabova-anna1976@postgrespro.ru", "phone": "+70444005857"}
0005434170855	471461	2229 608214	VLADIMIR IVANOV	{"email": "ivanovvladimir.1966@postgrespro.ru", "phone": "+70021192209"}
0005434170856	2D1D4E	9189 579458	VIKTORIYA FOMINA	{"phone": "+70317926778"}
0005434170857	3499B9	3498 313507	DIANA ZHURAVLEVA	{"email": "zhuravleva_d02011983@postgrespro.ru", "phone": "+70091077032"}
0005434170858	9BC51D	9583 542730	TATYANA LAZAREVA	{"email": "tatyana-lazareva-1967@postgrespro.ru", "phone": "+70152150467"}
0005434170859	9BC51D	6766 485840	ANDREY SERGEEV	{"email": "sergeev_andrey-02021974@postgrespro.ru", "phone": "+70136589271"}
0005434170860	8C5E76	1293 665589	DMITRIY POPOV	{"email": "d.popov_1959@postgrespro.ru", "phone": "+70707563431"}
0005434170861	89DAD0	4621 908763	VIKTOR EGOROV	{"phone": "+70236413594"}
0005434170862	6ABCF9	3206 188003	EVGENIYA KULIKOVA	{"email": "kulikova_evgeniya-04091966@postgrespro.ru", "phone": "+70676377027"}
0005434170863	9D8BFE	9285 362129	MIKHAIL KUZMIN	{"email": "kuzmin_mikhail-1974@postgrespro.ru", "phone": "+70690582599"}
0005434170864	A3873A	4580 524306	VALERIY PAVLOV	{"email": "pavlov.v_1964@postgrespro.ru", "phone": "+70200504819"}
0005434170865	7A609B	5157 665156	ANTONINA FILIPPOVA	{"phone": "+70739159107"}
0005434170866	7A609B	2189 179587	PAVEL MIKHAYLOV	{"email": "pavel.mikhaylov_10011971@postgrespro.ru", "phone": "+70376164725"}
0005434170867	9818EB	3240 355714	VLADIMIR ZHUKOV	{"email": "vzhukov_1974@postgrespro.ru", "phone": "+70898331924"}
0005434170868	F1B02E	9451 841573	ANTONINA ANDREEVA	{"email": "andreeva.antonina.03041970@postgrespro.ru", "phone": "+70854414724"}
0005434170869	09C84A	5261 004921	GEORGIY KUZMIN	{"phone": "+70689739013"}
0005434170870	21381D	1531 386946	MARINA ANDREEVA	{"email": "marina.andreeva1962@postgrespro.ru", "phone": "+70159627832"}
0005434170871	21381D	3378 023781	LILIYA ALEKSANDROVA	{"email": "aleksandrova_l_041965@postgrespro.ru", "phone": "+70336968889"}
0005434170872	F1775A	3812 124828	ANATOLIY IVANOV	{"email": "aivanov.01021967@postgrespro.ru", "phone": "+70935436623"}
0005434170873	3127D2	8511 242476	LYUDMILA GERASIMOVA	{"email": "lyudmila-gerasimova-011955@postgrespro.ru", "phone": "+70858565254"}
0005434170874	0C11F6	2896 592768	ALEKSEY ALEKSEEV	{"phone": "+70263356113"}
0005434170875	0C11F6	8451 636420	EKATERINA GERASIMOVA	{"email": "gerasimovaekaterina1977@postgrespro.ru", "phone": "+70339646606"}
0005434170876	17366B	5904 409566	RAISA VASILEVA	{"email": "vasilevar02091970@postgrespro.ru", "phone": "+70870016776"}
0005434170877	17366B	1061 087041	YAKOV SHEVCHENKO	{"email": "shevchenkoyakov_23081981@postgrespro.ru", "phone": "+70243651521"}
0005434170878	3449E3	2127 401969	ANASTASIYA SEMENOVA	{"email": "semenova_a-1969@postgrespro.ru", "phone": "+70139931893"}
0005434170879	AC7E35	7178 819187	DMITRIY KOZLOV	{"email": "kozlov-d_061967@postgrespro.ru", "phone": "+70036318418"}
0005434170880	12DE90	3177 650908	OLEG POPOV	{"phone": "+70735423155"}
0005434170881	12DE90	7522 859359	NATALYA MALYSHEVA	{"email": "malysheva_natalya-101983@postgrespro.ru", "phone": "+70910810206"}
0005434170882	B4B3E3	4048 590742	RINAT FEDOROV	{"phone": "+70855848847"}
0005434170883	D7DDEA	5049 125475	GALINA IVANOVA	{"phone": "+70912191761"}
0005434170884	26C0EF	7905 170521	MARINA PETROVA	{"email": "petrova_marina_1964@postgrespro.ru", "phone": "+70828678387"}
0005434170885	73D4CC	7815 649201	KLAVDIYA FILIPPOVA	{"email": "filippova_klavdiya-1969@postgrespro.ru", "phone": "+70194463610"}
0005434170886	73D4CC	0320 418536	MIKHAIL ISAEV	{"email": "isaevmikhail1970@postgrespro.ru", "phone": "+70622825452"}
0005434170887	620EB9	5481 043203	RINAT RODIONOV	{"email": "r.rodionov.121976@postgrespro.ru", "phone": "+70262514241"}
0005434170888	5CBD80	0137 090154	SERGEY ANDREEV	{"phone": "+70055017568"}
0005434170889	0C4FA3	4788 575277	EVGENIY SOROKIN	{"email": "sorokinevgeniy_081959@postgrespro.ru", "phone": "+70773352977"}
0005434170890	370CE3	9748 629916	TALGAT MOROZOV	{"email": "talgat.morozov.20091984@postgrespro.ru", "phone": "+70731538394"}
0005434170891	370CE3	6361 470425	EVGENIY SCHERBAKOV	{"phone": "+70070072311"}
0005434170892	55B2B1	6695 177494	MAKSIM BORISOV	{"phone": "+70470314511"}
0005434170893	2131DE	5779 863589	OLGA PAVLOVA	{"email": "o.pavlova.011976@postgrespro.ru", "phone": "+70083804732"}
0005434170894	C18EC5	6729 499952	VALENTINA MIKHAYLOVA	{"phone": "+70832081873"}
0005434170895	C18EC5	5548 974248	SERGEY MATVEEV	{"email": "matveev.s.10051980@postgrespro.ru", "phone": "+70399234926"}
0005434170896	685684	7860 045401	VIKTOR SOKOLOV	{"email": "sokolov-viktor031961@postgrespro.ru", "phone": "+70875311975"}
0005434170897	685684	3026 428409	ANATOLIY DAVYDOV	{"email": "davydov-a_121972@postgrespro.ru", "phone": "+70877888461"}
0005434170898	4E7BC1	9094 283275	ANDREY DAVYDOV	{"email": "adavydov_081971@postgrespro.ru", "phone": "+70494486026"}
0005434170899	436515	6750 034358	NADEZHDA MAKAROVA	{"phone": "+70733181457"}
0005434170900	428875	7498 876317	ALEKSANDR PETROV	{"phone": "+70876856276"}
0005434170901	428875	3676 569235	NAIL BORISOV	{"phone": "+70192076784"}
0005434170902	428875	0775 901564	ANNA ANDREEVA	{"phone": "+70222634065"}
0005434170903	3C2F6C	9652 061704	YULIYA MEDVEDEVA	{"phone": "+70312610416"}
0005434170904	3C2F6C	4349 535312	ALEKSANDR GRIGOREV	{"email": "grigorev.a1978@postgrespro.ru", "phone": "+70161269305"}
0005434170905	5A5F23	0898 229135	SERGEY NIKOLAEV	{"email": "nikolaev_sergey-1968@postgrespro.ru", "phone": "+70806719654"}
0005434170906	5A5F23	6110 454759	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov_121978@postgrespro.ru", "phone": "+70011330145"}
0005434170907	A2B325	6083 047025	KRISTINA KUZNECOVA	{"phone": "+70959456880"}
0005434170908	781B58	3077 111114	ALEKSANDR NIKOLAEV	{"phone": "+70314360744"}
0005434170909	CF2410	3221 585537	ANATOLIY MIKHAYLOV	{"email": "mikhaylovanatoliy-021970@postgrespro.ru", "phone": "+70207101704"}
0005434170910	CF2410	3075 059375	YURIY ILIN	{"phone": "+70301891830"}
0005434170911	A35DE4	5618 335481	KONSTANTIN KOROLEV	{"email": "konstantin-korolev_091975@postgrespro.ru", "phone": "+70746795387"}
0005434170912	A35DE4	1320 962654	FAINA OSIPOVA	{"phone": "+70073335775"}
0005434170913	952267	6974 122771	VLADIMIR ILIN	{"email": "ilin.vladimir.061974@postgrespro.ru", "phone": "+70505092165"}
0005434170914	952267	4078 429770	NIKOLAY IVANOV	{"email": "nikolay-ivanov_11021970@postgrespro.ru", "phone": "+70203662856"}
0005434170915	FA9872	7431 761967	EVGENIY GRIGOREV	{"email": "grigorev.e.1964@postgrespro.ru", "phone": "+70060417939"}
0005434170916	B05A3C	9977 125363	VALENTIN FROLOV	{"phone": "+70713147680"}
0005434170917	8134D1	4823 442417	ALINA KOMAROVA	{"phone": "+70706758661"}
0005434170918	F33934	8872 457299	NINA ZHUKOVA	{"email": "nzhukova.101972@postgrespro.ru", "phone": "+70428567615"}
0005434170919	CAA6A6	4972 117773	ZINAIDA MIRONOVA	{"email": "mironova-z_081984@postgrespro.ru", "phone": "+70875636626"}
0005434170920	29FB47	0259 931552	SERGEY ISAEV	{"email": "sergey_isaev.091981@postgrespro.ru", "phone": "+70042630772"}
0005434170921	F7DAED	0444 864981	MAKSIM CHERNOV	{"phone": "+70362371668"}
0005434170922	184B8C	0795 224794	VALERIYA KISELEVA	{"phone": "+70447030385"}
0005434170923	BB7717	0560 952312	VASILIY GERASIMOV	{"phone": "+70528885155"}
0005434170924	C456CF	7902 879322	NADEZHDA SIDOROVA	{"email": "sidorova_nadezhda-1974@postgrespro.ru", "phone": "+70838040882"}
0005434170925	C456CF	2694 795207	EKATERINA TROFIMOVA	{"phone": "+70987433034"}
0005434170926	C6BC02	4655 298357	EVGENIY GUSEV	{"phone": "+70940882016"}
0005434170927	E3E525	6340 042960	NATALYA KOMAROVA	{"phone": "+70999540137"}
0005434170928	C203AD	6959 325471	NATALYA KUZNECOVA	{"email": "kuznecova-n.31051976@postgrespro.ru", "phone": "+70057975337"}
0005434170929	4BA650	9960 263000	IRINA PAVLOVA	{"phone": "+70936784630"}
0005434170930	4BA650	7616 777166	GALINA GERASIMOVA	{"email": "galina.gerasimova.051977@postgrespro.ru", "phone": "+70720138291"}
0005434170931	A4D5CA	3087 685750	KIRILL NIKOLAEV	{"phone": "+70273271510"}
0005434170932	5B5316	8190 447467	PETR MATVEEV	{"phone": "+70145940899"}
0005434170933	6BA9F1	3335 084604	IRINA POPOVA	{"phone": "+70922807788"}
0005434170934	8D21B3	0004 943250	NIKITA KULIKOV	{"email": "kulikovn.22111981@postgrespro.ru", "phone": "+70955105229"}
0005434170935	8D21B3	3041 763864	OLGA AKIMOVA	{"email": "oakimova.031967@postgrespro.ru", "phone": "+70676780816"}
0005434170936	ACDE9E	7309 128415	VLADIMIR AFANASEV	{"email": "vladimir-afanasev.1983@postgrespro.ru", "phone": "+70126984998"}
0005434170937	ACDE9E	8124 299525	VALERIY VLASOV	{"email": "vlasov.v-031974@postgrespro.ru", "phone": "+70990386765"}
0005434170938	0D7356	3194 058167	DIANA NOVIKOVA	{"email": "diana_novikova-1971@postgrespro.ru", "phone": "+70322079112"}
0005434170939	0D7356	6298 970214	OKSANA SOROKINA	{"phone": "+70152338241"}
0005434170940	780581	7629 255361	ELENA MAKAROVA	{"email": "makarova_e011962@postgrespro.ru", "phone": "+70141914222"}
0005434170941	1B122E	0997 869549	ELENA VASILEVA	{"phone": "+70842390915"}
0005434170942	1B122E	1163 305128	IGOR IVANOV	{"email": "ivanov.igor-18111970@postgrespro.ru", "phone": "+70247530327"}
0005434170943	4B85A8	3364 391516	ALEKSANDR DENISOV	{"email": "denisov.aleksandr14011978@postgrespro.ru", "phone": "+70510443906"}
0005434170944	4B85A8	3142 933558	VLADIMIR NAUMOV	{"email": "naumovvladimir111973@postgrespro.ru", "phone": "+70259012581"}
0005434170945	FF69D4	7454 334931	NIKOLAY MOROZOV	{"email": "nikolaymorozov.1978@postgrespro.ru", "phone": "+70991793317"}
0005434170946	FF69D4	8697 051364	VLADIMIR IVANOV	{"email": "v-ivanov.1976@postgrespro.ru", "phone": "+70730028679"}
0005434170947	197C5E	5788 664444	VLADIMIR VOROBEV	{"email": "vladimirvorobev_111963@postgrespro.ru", "phone": "+70095115031"}
0005434170948	EB7C6A	9691 657096	ALEKSEY POPOV	{"phone": "+70725656110"}
0005434170949	D63F60	3239 939106	DANILA ALEKSANDROV	{"phone": "+70021499066"}
0005434170950	969A0D	4236 118700	POLINA BORISOVA	{"email": "borisova_polina.1966@postgrespro.ru", "phone": "+70576360575"}
0005434170951	7CD44B	8862 219258	NATALIYA MIRONOVA	{"phone": "+70449451756"}
0005434170952	8C2E05	0034 913055	ALLA PAVLOVA	{"phone": "+70215234179"}
0005434170953	DE4D9D	8434 604925	VALENTINA FROLOVA	{"email": "valentina.frolova-021965@postgrespro.ru", "phone": "+70069980301"}
0005434170954	7F8665	3063 803637	LIDIYA TITOVA	{"phone": "+70624973314"}
0005434170955	79805F	2693 432238	ZINAIDA POPOVA	{"email": "z_popova1968@postgrespro.ru", "phone": "+70218061636"}
0005434170956	A7AF1D	6648 757194	ALEKSANDR TIKHONOV	{"email": "aleksandr_tikhonov.06091976@postgrespro.ru", "phone": "+70733460327"}
0005434170957	C4E92A	2666 836221	VIKTOR ANDREEV	{"phone": "+70990148672"}
0005434170958	C4E92A	0573 540464	ELENA GUSEVA	{"email": "gusevae07051967@postgrespro.ru", "phone": "+70782435023"}
0005434170959	B325AD	4539 157522	EKATERINA KUZNECOVA	{"phone": "+70424835739"}
0005434170960	A72B08	4538 712286	MARIYA TIKHONOVA	{"email": "m.tikhonova101969@postgrespro.ru", "phone": "+70665117167"}
0005434170961	A72B08	9452 694800	SERGEY ORLOV	{"phone": "+70476124458"}
0005434170962	98BEF9	3863 108901	RIMMA SEMENOVA	{"phone": "+70693757013"}
0005434170963	D90A98	8226 435895	DARYA KUZNECOVA	{"email": "darya-kuznecova.061975@postgrespro.ru", "phone": "+70312882269"}
0005434170964	D079CC	0339 495081	VIKTORIYA IVANOVA	{"email": "viktoriyaivanova1963@postgrespro.ru", "phone": "+70694879481"}
0005434170965	363442	7510 869462	ALEKSANDRA DMITRIEVA	{"phone": "+70045814420"}
0005434170966	363442	3844 165058	GERMAN ISAEV	{"phone": "+70193896893"}
0005434170967	D7A81C	2167 273325	MIKHAIL KAZAKOV	{"email": "mikhail-kazakov.031958@postgrespro.ru", "phone": "+70062384480"}
0005434170968	611CCD	6662 417414	NATALYA FEDOROVA	{"phone": "+70245890431"}
0005434170969	EA0AC8	8192 413059	ALEKSEY NIKOLAEV	{"email": "a.nikolaev11121969@postgrespro.ru", "phone": "+70170917572"}
0005434170970	EA0AC8	7278 717553	TATYANA DAVYDOVA	{"email": "davydova-t-1968@postgrespro.ru", "phone": "+70125807483"}
0005434170971	672255	4477 174220	PETR KAZAKOV	{"phone": "+70353316820"}
0005434170972	BDCCE9	4116 945692	LYUDMILA AKIMOVA	{"phone": "+70594111439"}
0005434170973	1EDA06	2931 487092	DMITRIY EGOROV	{"email": "egorov.dmitriy_071977@postgrespro.ru", "phone": "+70187675193"}
0005434170974	CE2366	1379 645030	KRISTINA VASILEVA	{"phone": "+70168960464"}
0005434170975	CE2366	2585 150749	NIKOLAY FOMIN	{"phone": "+70215396178"}
0005434170976	AF51F8	4290 835844	NIKOLAY BARANOV	{"phone": "+70759800819"}
0005434170977	AF51F8	0599 154235	ALEKSANDR ANTONOV	{"phone": "+70701349085"}
0005434170978	AF51F8	3761 715131	EKATERINA KARPOVA	{"email": "e-karpova.1977@postgrespro.ru", "phone": "+70557414654"}
0005434170979	23CB88	3720 752655	IRINA POLYAKOVA	{"email": "i_polyakova-15031976@postgrespro.ru", "phone": "+70947771778"}
0005434170980	5068E4	3700 228058	PAVEL FROLOV	{"email": "frolov-pavel-1973@postgrespro.ru", "phone": "+70858443968"}
0005434170981	C33DFA	9477 246289	VLADIMIR ISAEV	{"phone": "+70877020497"}
0005434170982	C33DFA	0260 156632	DMITRIY PETROV	{"phone": "+70539085432"}
0005434170983	2F49B8	1756 807669	NURIYA ZHURAVLEVA	{"phone": "+70601864873"}
0005434170984	E55AC7	7636 121253	ANASTASIYA ARKHIPOVA	{"email": "arkhipova-anastasiya-081972@postgrespro.ru", "phone": "+70172768565"}
0005434170985	604A64	8289 626564	NINA NIKOLAEVA	{"phone": "+70581175178"}
0005434170986	0B0819	2913 399729	NATALYA MAKAROVA	{"phone": "+70338150464"}
0005434170987	ED0D0E	5153 427224	SOFYA VOROBEVA	{"email": "vorobevas.101980@postgrespro.ru", "phone": "+70956478481"}
0005434170988	ED0D0E	9482 023825	DENIS VLASOV	{"phone": "+70132870863"}
0005434170989	B4E290	9747 570026	VALENTINA MAKAROVA	{"phone": "+70188615275"}
0005434170990	B4E290	2639 444245	SVETLANA ZHUKOVA	{"email": "zhukova.s30111969@postgrespro.ru", "phone": "+70052549265"}
0005434170991	0E0312	3266 343899	GALINA CHERNOVA	{"phone": "+70466498295"}
0005434170992	0E0312	6485 758011	RAUZA KUZNECOVA	{"phone": "+70492443911"}
0005434170993	F604B6	1007 916240	SERGEY BONDARENKO	{"email": "bondarenko_sergey1968@postgrespro.ru", "phone": "+70205509406"}
0005434170994	F604B6	4905 436908	KLAVDIYA BOGDANOVA	{"email": "bogdanova_klavdiya081959@postgrespro.ru", "phone": "+70023155949"}
0005434170995	997716	3584 925537	DMITRIY PAVLOV	{"phone": "+70828028610"}
0005434170996	4B62A5	3433 366297	ALEKSANDR SIDOROV	{"phone": "+70177995306"}
0005434170997	4B62A5	7623 123467	RAMZIYA EGOROVA	{"email": "egorova_ramziya-091978@postgrespro.ru", "phone": "+70564377308"}
0005434170998	83C57C	0593 738366	IRINA PETROVA	{"email": "i-petrova.1961@postgrespro.ru", "phone": "+70104409678"}
0005434170999	83C57C	8768 269737	IVAN DENISOV	{"email": "idenisov_1966@postgrespro.ru", "phone": "+70509695703"}
0005434171000	FCDF0C	3160 839028	ARSENIY MAKAROV	{"phone": "+70771443919"}
0005434171001	E1ABB5	7650 752649	ALEKSANDR FILIPPOV	{"phone": "+70071611780"}
0005434171002	8AEBD6	2503 707832	GRIGORIY ZAYCEV	{"phone": "+70634761606"}
0005434171003	F3C64F	5499 771438	NAZAR OSIPOV	{"email": "nazar_osipov-1984@postgrespro.ru", "phone": "+70457798339"}
0005434171004	F3C64F	3194 792783	VADIM SCHERBAKOV	{"phone": "+70253335629"}
0005434171005	16E475	4977 844504	BORIS VLASOV	{"phone": "+70262317144"}
0005434171006	CEE7B9	5985 663197	NINA MALYSHEVA	{"email": "malysheva.nina-1969@postgrespro.ru", "phone": "+70638859148"}
0005434171007	3E9228	7498 408587	ALEKSANDR STEPANOV	{"phone": "+70277959133"}
0005434171008	0D2B28	8743 519008	ALEKSANDRA ISAEVA	{"email": "isaevaaleksandra.09121974@postgrespro.ru", "phone": "+70851486804"}
0005434171009	6F6EB3	3693 390555	BORIS FEDOROV	{"phone": "+70988948954"}
0005434171010	CD9E70	3691 339976	ANDREY ZHUKOV	{"phone": "+70067895411"}
0005434171011	32DF12	0084 414318	NATALYA MOISEEVA	{"email": "moiseeva_n.021974@postgrespro.ru", "phone": "+70714684114"}
0005434171012	027A90	2408 416707	ANDREY KUZNECOV	{"email": "andrey.kuznecov.091972@postgrespro.ru", "phone": "+70559456024"}
0005434171013	71098C	2428 151866	ALEKSEY KUZMIN	{"email": "kuzmin.aleksey.021973@postgrespro.ru", "phone": "+70549522949"}
0005434171014	1FF718	7255 462476	VYACHESLAV SOKOLOV	{"email": "vyacheslavsokolov-1966@postgrespro.ru", "phone": "+70422468752"}
0005434171015	5C277E	0269 010338	DARYA OVCHINNIKOVA	{"phone": "+70768029896"}
0005434171016	4ADF67	3997 395962	YAROSLAV FEDOROV	{"email": "y-fedorov121969@postgrespro.ru", "phone": "+70780691068"}
0005434171017	9EF5F6	9326 030921	PETR ROMANOV	{"phone": "+70955608515"}
0005434171018	9EF5F6	6748 630761	ANDREY NIKITIN	{"phone": "+70002357013"}
0005434173594	3F4333	4599 574232	ALEKSANDR ZAYCEV	{"phone": "+70487915558"}
0005434171019	917B49	7071 896659	ARTEM ANDREEV	{"email": "artem-andreev_041972@postgrespro.ru", "phone": "+70535301639"}
0005434171020	917B49	4212 064196	VERA ZAKHAROVA	{"email": "v-zakharova05051966@postgrespro.ru", "phone": "+70451138901"}
0005434171021	69336B	8778 038264	ALEKSEY TIKHONOV	{"email": "a-tikhonov.111964@postgrespro.ru", "phone": "+70332408385"}
0005434171022	69336B	8023 817005	MIKHAIL KUZMIN	{"email": "kuzmin-mikhail-1970@postgrespro.ru", "phone": "+70399110060"}
0005434171023	06C187	1645 534828	MARIYA FILATOVA	{"phone": "+70394849156"}
0005434171024	466773	3162 553459	POLINA POPOVA	{"email": "popova.p.011974@postgrespro.ru", "phone": "+70648341823"}
0005434171025	466773	6298 361433	SVETLANA KONDRATEVA	{"email": "kondrateva_svetlana10101969@postgrespro.ru", "phone": "+70238418931"}
0005434171026	0A9641	7426 197223	RUSLAN POPOV	{"phone": "+70887578477"}
0005434171027	E91E3D	7011 522875	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov30061976@postgrespro.ru", "phone": "+70081695930"}
0005434171028	E91E3D	2320 191975	ALEKSEY MELNIKOV	{"phone": "+70236381742"}
0005434171029	E216D2	6006 662691	SERGEY ABRAMOV	{"email": "abramov-sergey.051962@postgrespro.ru", "phone": "+70822624675"}
0005434171030	E216D2	7862 791411	ELENA GAVRILOVA	{"phone": "+70148580943"}
0005434171031	E216D2	2878 471418	EKATERINA LEBEDEVA	{"phone": "+70966279274"}
0005434171032	AE92CB	7023 344211	ANTON KUZNECOV	{"email": "anton.kuznecov-101972@postgrespro.ru", "phone": "+70976971298"}
0005434171033	AE92CB	7469 172638	ALEKSANDR KONOVALOV	{"phone": "+70951240777"}
0005434171034	D8478B	1772 806474	SERGEY MARTYNOV	{"email": "martynov-s_05121973@postgrespro.ru", "phone": "+70846596412"}
0005434171035	D8478B	9337 554753	IRAIDA POPOVA	{"email": "i_popova_101967@postgrespro.ru", "phone": "+70623879467"}
0005434171036	84A694	8608 341403	ALBINA BARANOVA	{"phone": "+70169188881"}
0005434171037	84A694	7385 190718	NINA ERMAKOVA	{"email": "ermakova-n101968@postgrespro.ru", "phone": "+70710198458"}
0005434171038	84A694	0505 708611	ROMAN ANDREEV	{"email": "andreev.roman-14041977@postgrespro.ru", "phone": "+70566953630"}
0005434171039	56734A	0996 195431	GALINA EFIMOVA	{"email": "g-efimova_111972@postgrespro.ru", "phone": "+70453569039"}
0005434171040	BAFAB9	2333 046220	MARIYA BELOVA	{"email": "m.belova.021966@postgrespro.ru", "phone": "+70991650584"}
0005434171041	BAFAB9	0428 637894	BORIS VASILEV	{"email": "vasilev_boris-24011970@postgrespro.ru", "phone": "+70091972423"}
0005434171042	BF11CC	6739 361139	OLGA NOVIKOVA	{"phone": "+70480873448"}
0005434171043	2E40B7	4978 306171	OLGA KULIKOVA	{"phone": "+70455903869"}
0005434171044	DD747B	6271 035284	KARINA SCHERBAKOVA	{"phone": "+70310101204"}
0005434171045	69F310	2063 352816	ELENA ZAKHAROVA	{"phone": "+70265608211"}
0005434171046	074878	5669 813392	VALERIY IVANOV	{"email": "ivanov_v091967@postgrespro.ru", "phone": "+70318407628"}
0005434171047	074878	2740 075418	VALERIY POPOV	{"phone": "+70896376847"}
0005434171048	319FCF	8153 533336	MARINA ROMANOVA	{"phone": "+70616393773"}
0005434171049	319FCF	2565 053617	VLADISLAV SOROKIN	{"email": "sorokin.vladislav-1962@postgrespro.ru", "phone": "+70177296950"}
0005434171050	253D23	5008 328070	GALINA MAKAROVA	{"email": "makarova_galina.1970@postgrespro.ru", "phone": "+70683081234"}
0005434171051	FE862C	1066 744437	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey_23011973@postgrespro.ru", "phone": "+70449824351"}
0005434171052	3E1BCF	7005 251731	ANDREY DAVYDOV	{"phone": "+70120711008"}
0005434171053	F34C89	6951 190879	LIDIYA RODIONOVA	{"email": "rodionova_lidiya021966@postgrespro.ru", "phone": "+70203746947"}
0005434171054	F34C89	5343 027653	LYUDMILA TIKHONOVA	{"phone": "+70959349968"}
0005434171055	9F7668	6546 429958	ALEKSANDR BONDARENKO	{"email": "abondarenko_1973@postgrespro.ru", "phone": "+70943941865"}
0005434171056	99AA3E	0026 722602	VADIM ANTONOV	{"email": "antonov_v.091981@postgrespro.ru", "phone": "+70330085663"}
0005434171057	109D04	0762 615464	SERGEY SMIRNOV	{"email": "s.smirnov_14091967@postgrespro.ru", "phone": "+70967747026"}
0005434171058	BD2A40	5929 577030	LIDIYA ZAYCEVA	{"email": "zayceval1969@postgrespro.ru", "phone": "+70576463605"}
0005434171059	34BE75	4136 415970	ANDREY FROLOV	{"phone": "+70335554844"}
0005434171060	DF540A	5450 966829	MIKHAIL ORLOV	{"email": "orlov.m-1970@postgrespro.ru", "phone": "+70801337214"}
0005434171061	DF540A	3680 690220	EKATERINA SIDOROVA	{"phone": "+70032621073"}
0005434171062	DF540A	5003 744559	MARIYA NIKIFOROVA	{"phone": "+70652736659"}
0005434171063	D3F995	1414 709215	VERONIKA KAZAKOVA	{"email": "kazakovav-1972@postgrespro.ru", "phone": "+70591679213"}
0005434171064	D3F995	3800 011781	DENIS IVANOV	{"email": "ivanov-d_081961@postgrespro.ru", "phone": "+70566652425"}
0005434171065	D3F995	7992 260510	NIKOLAY FROLOV	{"phone": "+70112457248"}
0005434171066	E6617B	8250 149742	ANDREY MAKAROV	{"email": "makarov_andrey.14061967@postgrespro.ru", "phone": "+70619566442"}
0005434171067	E5E015	0563 503335	IRINA ANTONOVA	{"email": "antonovairina.1975@postgrespro.ru", "phone": "+70802504103"}
0005434171068	E5E015	4301 868973	ELENA OSIPOVA	{"email": "osipovae.101980@postgrespro.ru", "phone": "+70044877202"}
0005434171069	E5E015	5338 960731	NINA MEDVEDEVA	{"email": "medvedeva.n-061981@postgrespro.ru", "phone": "+70902770134"}
0005434171070	E5E015	0573 952026	NINA CHERNOVA	{"email": "nina.chernova1965@postgrespro.ru", "phone": "+70525007537"}
0005434171071	B42CC6	8789 561724	ARTEM NIKITIN	{"phone": "+70021467720"}
0005434171072	03D431	2863 939682	MATVEY MIKHAYLOV	{"email": "mikhaylov-m_1973@postgrespro.ru", "phone": "+70893476102"}
0005434171073	03D431	7843 856408	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana.05071980@postgrespro.ru", "phone": "+70115390660"}
0005434171074	27DCAB	3342 323642	NATALYA IVANOVA	{"phone": "+70036829535"}
0005434171075	2B6A24	7009 503265	NADEZHDA BELYAEVA	{"email": "belyaeva-nadezhda.021979@postgrespro.ru", "phone": "+70491188311"}
0005434171076	4096E8	7175 248686	EVDOKIYA KOZLOVA	{"phone": "+70801014957"}
0005434171077	4096E8	7892 283014	RAVIL NIKITIN	{"email": "nikitin-r_04091973@postgrespro.ru", "phone": "+70191772651"}
0005434171078	40EC81	6088 726789	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr.1965@postgrespro.ru", "phone": "+70370502762"}
0005434171079	5FA123	0393 462351	SVETLANA PAVLOVA	{"phone": "+70678856286"}
0005434171080	5FA123	8674 132925	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov.01111971@postgrespro.ru", "phone": "+70239574320"}
0005434171081	EBD482	4218 692326	ISLAM GORBUNOV	{"phone": "+70828750170"}
0005434171082	EBD482	4523 268140	OLEG POPOV	{"phone": "+70904190743"}
0005434171083	EBD482	3627 353055	MARINA SCHERBAKOVA	{"phone": "+70880614884"}
0005434171084	291A0B	7320 847867	SVETLANA NIKIFOROVA	{"phone": "+70021288542"}
0005434171085	291A0B	9886 578827	TATYANA CHERNOVA	{"email": "tatyanachernova_111965@postgrespro.ru", "phone": "+70128977722"}
0005434171086	291A0B	8549 309439	MARGARITA FEDOROVA	{"phone": "+70165232144"}
0005434171087	1D03BA	4105 624428	GALINA NESTEROVA	{"email": "nesterova-galina1974@postgrespro.ru", "phone": "+70419717509"}
0005434171088	1842E4	3630 595479	ALEKSANDR KONOVALOV	{"phone": "+70959370274"}
0005434171089	1842E4	8891 943749	VALENTINA OSIPOVA	{"email": "osipovavalentina-1957@postgrespro.ru", "phone": "+70979218370"}
0005434171090	AF369F	4735 576754	ANDREY NOVIKOV	{"email": "novikova.02041963@postgrespro.ru", "phone": "+70312339911"}
0005434171091	E86E8A	5768 307161	ANDREY BORISOV	{"email": "borisov.andrey.101971@postgrespro.ru", "phone": "+70415553049"}
0005434171092	BB6B35	2972 708027	ALEKSANDR SCHERBAKOV	{"phone": "+70233049939"}
0005434171093	BB6B35	5411 590188	PAVEL FROLOV	{"phone": "+70645151568"}
0005434171094	BB6B35	7443 407220	KIRILL SERGEEV	{"email": "sergeevkirill1975@postgrespro.ru", "phone": "+70902212142"}
0005434171095	5A8477	3863 049232	TATYANA MOROZOVA	{"email": "morozova-tatyana06121965@postgrespro.ru", "phone": "+70535880656"}
0005434171096	97FF70	0918 558013	ANNA NIKITINA	{"email": "nikitina_anna1973@postgrespro.ru", "phone": "+70652603462"}
0005434171097	ACF1A8	1702 214772	IRINA POLYAKOVA	{"email": "irina_polyakova-1970@postgrespro.ru", "phone": "+70080685647"}
0005434171098	157A5C	8500 195557	NATALYA SOROKINA	{"email": "sorokinanatalya_1979@postgrespro.ru", "phone": "+70104240906"}
0005434171099	FAFA72	0088 606423	NATALYA KOZLOVA	{"email": "kozlovanatalya-011960@postgrespro.ru", "phone": "+70569661223"}
0005434171100	FAFA72	9057 139336	YAROSLAV MOROZOV	{"email": "y.morozov-091979@postgrespro.ru", "phone": "+70159171182"}
0005434171101	1FB02E	1881 536774	ALEKSANDR AFANASEV	{"phone": "+70524896525"}
0005434171102	755A73	8796 432213	SERGEY GUSEV	{"email": "sergey_gusev.031961@postgrespro.ru", "phone": "+70693530870"}
0005434171103	593D05	3367 302451	ALEKSEY POPOV	{"email": "a-popov_041966@postgrespro.ru", "phone": "+70561560120"}
0005434171104	F94B41	4481 605719	ANASTASIYA AKIMOVA	{"phone": "+70721016570"}
0005434171105	FC114A	8503 395277	VIKTORIYA ROMANOVA	{"phone": "+70853006875"}
0005434171106	A129A1	5055 622783	STANISLAV ZAKHAROV	{"phone": "+70404638596"}
0005434171107	F870D8	6670 239572	DARYA DENISOVA	{"email": "denisova_d_28041964@postgrespro.ru", "phone": "+70034441109"}
0005434171108	28DA88	2412 835267	SERGEY SHEVCHENKO	{"phone": "+70995010249"}
0005434171109	77D4F3	2588 411078	DMITRIY GAVRILOV	{"phone": "+70242646718"}
0005434171110	02C409	2250 078256	YURIY KUZMIN	{"email": "kuzmin_y06121972@postgrespro.ru", "phone": "+70099887008"}
0005434171111	D41AE3	7006 602311	ZINAIDA KOROLEVA	{"email": "zinaida-koroleva-22091971@postgrespro.ru", "phone": "+70078721860"}
0005434171112	10E9D2	4693 613570	VITALIY CHERNOV	{"phone": "+70383218510"}
0005434171113	D22CB1	4490 064654	ALENA POPOVA	{"phone": "+70890796482"}
0005434171114	D8EC4E	5893 371672	ANNA MOROZOVA	{"email": "morozovaa.20091974@postgrespro.ru", "phone": "+70614590495"}
0005434171115	D8EC4E	9537 819799	GALINA SIDOROVA	{"phone": "+70590010675"}
0005434171116	999514	6456 660254	YURIY VLASOV	{"phone": "+70916001731"}
0005434171117	8A0FA4	6493 101247	VLADIMIR ORLOV	{"phone": "+70224508303"}
0005434171118	8A0FA4	7105 394633	POLINA MAKAROVA	{"email": "polina.makarova-1974@postgrespro.ru", "phone": "+70230971264"}
0005434171119	A94B74	0316 508494	DANILA KOZLOV	{"email": "danila-kozlov.09021982@postgrespro.ru", "phone": "+70921893191"}
0005434171120	A94B74	8956 584118	RASHID SOROKIN	{"email": "r-sorokin-071963@postgrespro.ru", "phone": "+70607353618"}
0005434171121	A94B74	7778 561496	ALEKSANDRA ZHUKOVA	{"email": "aleksandrazhukova_1953@postgrespro.ru", "phone": "+70592989172"}
0005434171122	A3A58D	2471 654077	TAISIYA TARASOVA	{"phone": "+70756951288"}
0005434171123	834F71	1595 902833	NATALYA NIKOLAEVA	{"email": "nikolaeva.natalya-11061977@postgrespro.ru", "phone": "+70492558010"}
0005434171124	8DACE2	5612 291982	NINA OVCHINNIKOVA	{"phone": "+70030318223"}
0005434171125	42F993	7510 753686	SERGEY KONOVALOV	{"phone": "+70496972491"}
0005434171126	51CA3F	3488 213767	NATALIYA ANISIMOVA	{"phone": "+70492209699"}
0005434171127	690402	9222 636039	OLGA ZAKHAROVA	{"phone": "+70589558538"}
0005434171128	690402	9211 871821	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr_031967@postgrespro.ru", "phone": "+70124676007"}
0005434171129	366324	0578 456073	ALEKSANDR SEMENOV	{"phone": "+70167513075"}
0005434171130	366324	0182 175915	SERGEY SMIRNOV	{"phone": "+70310717651"}
0005434171131	F90B3A	0049 376594	VALENTINA KUZNECOVA	{"phone": "+70692283879"}
0005434171132	02D7E5	8984 110846	OLEG DENISOV	{"email": "denisovo.1970@postgrespro.ru", "phone": "+70523885017"}
0005434171133	02D7E5	0416 610698	OKSANA VASILEVA	{"phone": "+70447472476"}
0005434171134	9A7150	9614 301764	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov_1978@postgrespro.ru", "phone": "+70535488534"}
0005434171135	9A7150	4964 705235	ALEKSEY MAKAROV	{"phone": "+70558852349"}
0005434171136	95E50D	0630 054269	IVAN SEMENOV	{"email": "isemenov25051967@postgrespro.ru", "phone": "+70343993815"}
0005434171137	62674E	6547 235603	DANILA ANTONOV	{"email": "danila_antonov-1957@postgrespro.ru", "phone": "+70646473854"}
0005434171138	569951	2021 469154	GENNADIY EGOROV	{"phone": "+70405634846"}
0005434171139	569951	0295 801137	ANNA POPOVA	{"phone": "+70093412557"}
0005434171140	A263AE	4775 629502	YANA NIKITINA	{"email": "y.nikitina1972@postgrespro.ru", "phone": "+70406116013"}
0005434171141	F4A0C1	7150 573660	ANVAR SOROKIN	{"email": "a-sorokin091965@postgrespro.ru", "phone": "+70376037065"}
0005434171142	F4A0C1	8142 071363	ALEKSANDR GERASIMOV	{"phone": "+70593762590"}
0005434171143	45EC34	7078 921903	MIKHAIL SMIRNOV	{"phone": "+70162590324"}
0005434171144	FF8834	5300 476817	ALEKSANDR MAKAROV	{"email": "a_makarov_051964@postgrespro.ru", "phone": "+70005590287"}
0005434171145	FF8834	2305 296984	ALEKSEY KOZLOV	{"phone": "+70627021266"}
0005434171146	C33F47	1382 951686	VLADIMIR KISELEV	{"email": "v-kiselev-1978@postgrespro.ru", "phone": "+70086399438"}
0005434171147	C33F47	1284 456055	OLGA VOLKOVA	{"phone": "+70885522112"}
0005434171148	C33F47	3792 641040	KONSTANTIN DAVYDOV	{"email": "k_davydov_1960@postgrespro.ru", "phone": "+70846322883"}
0005434171149	41DE84	5993 020371	NATALYA SAVELEVA	{"email": "n-saveleva31031965@postgrespro.ru", "phone": "+70632998496"}
0005434171150	A4F06E	1972 191689	TATYANA MELNIKOVA	{"email": "t_melnikova1961@postgrespro.ru", "phone": "+70817867585"}
0005434171151	A4F06E	4132 893670	ALEKSANDR ZHUKOV	{"phone": "+70296296091"}
0005434171152	A41145	2074 353019	ARTEM KOZLOV	{"phone": "+70911987259"}
0005434171153	B3A66C	1420 506589	ALEKSANDR KAZAKOV	{"phone": "+70355619730"}
0005434171154	B3A66C	9617 025004	MARIYA ABRAMOVA	{"email": "mariyaabramova1980@postgrespro.ru", "phone": "+70618976788"}
0005434171155	838FB1	5996 070912	ELVIRA KRASNOVA	{"phone": "+70148315825"}
0005434171156	838FB1	3606 601116	EVGENIY SEMENOV	{"email": "evgeniy.semenov-03041977@postgrespro.ru", "phone": "+70260510687"}
0005434171157	024D47	0272 856126	ARINA IVANOVA	{"phone": "+70420807889"}
0005434171158	6F05C7	5115 650986	IRINA KAZAKOVA	{"email": "kazakova_i-041975@postgrespro.ru", "phone": "+70720231182"}
0005434171159	6F05C7	0537 599224	TATYANA KUZNECOVA	{"phone": "+70252391623"}
0005434171160	BD61FE	5678 745738	DMITRIY POPOV	{"phone": "+70339173849"}
0005434171161	F2FE70	1556 730786	ZINAIDA NAZAROVA	{"phone": "+70207935955"}
0005434171162	14927C	0135 903941	FANIL RODIONOV	{"email": "fanilrodionov-1979@postgrespro.ru", "phone": "+70576219132"}
0005434171163	A000F3	2161 632270	IRINA KUDRYASHOVA	{"email": "i_kudryashova1965@postgrespro.ru", "phone": "+70584081766"}
0005434171164	51B132	8126 823903	NIKOLAY SAVELEV	{"phone": "+70812330486"}
0005434171165	6D6D61	9170 126785	EVGENIY ROMANOV	{"email": "romanov-evgeniy-1972@postgrespro.ru", "phone": "+70699976616"}
0005434171166	622EBF	3079 313882	DMITRIY BONDARENKO	{"phone": "+70605708670"}
0005434171167	98883C	3534 389762	LIDIYA KUZNECOVA	{"email": "lkuznecova.29121974@postgrespro.ru", "phone": "+70606632641"}
0005434171168	292354	8439 428441	SVETLANA ZHURAVLEVA	{"phone": "+70858274517"}
0005434171169	812D81	5836 120450	TATYANA ZHURAVLEVA	{"phone": "+70736086409"}
0005434171170	812D81	3398 807835	MAKSIM ANTONOV	{"phone": "+70852617851"}
0005434171171	319ECA	3491 096530	OLGA POPOVA	{"phone": "+70966921078"}
0005434171172	EC6E86	9893 086466	MAKSIM MAKAROV	{"phone": "+70289457735"}
0005434171173	9E9395	7457 512181	DMITRIY KUZNECOV	{"email": "d_kuznecov.071973@postgrespro.ru", "phone": "+70089471568"}
0005434171174	9E9395	2275 110098	ALEKSANDR BARANOV	{"phone": "+70430827675"}
0005434171175	18B7BF	5603 675595	TAISIYA DAVYDOVA	{"email": "taisiya-davydova-18071978@postgrespro.ru", "phone": "+70852791614"}
0005434171176	624B4E	8611 230166	VLADIMIR KOZLOV	{"phone": "+70529038866"}
0005434171177	8B7C34	3605 650274	VALERIY GUSEV	{"phone": "+70167730144"}
0005434171178	6AAA1F	7540 005720	ANNA KUZMINA	{"email": "anna_kuzmina.10011961@postgrespro.ru", "phone": "+70953353222"}
0005434171179	951554	6354 052316	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov-1983@postgrespro.ru", "phone": "+70774504172"}
0005434171180	951554	7298 692419	ILYA DMITRIEV	{"email": "ilya.dmitriev-17041978@postgrespro.ru", "phone": "+70931422556"}
0005434171181	92C4EF	3228 427827	ALEKSANDR POPOV	{"email": "popova_27071979@postgrespro.ru", "phone": "+70015239623"}
0005434171182	92C4EF	2751 341933	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin01121984@postgrespro.ru", "phone": "+70566495518"}
0005434171183	AEE806	3459 292327	EVGENIYA VASILEVA	{"email": "evgeniya-vasileva.1962@postgrespro.ru", "phone": "+70015475396"}
0005434171184	AEE806	6807 080607	ELENA KALININA	{"email": "elenakalinina-081978@postgrespro.ru", "phone": "+70804937292"}
0005434171185	EEE433	9191 613143	LYUDMILA KISELEVA	{"email": "l_kiseleva_111970@postgrespro.ru", "phone": "+70265745016"}
0005434171186	E379ED	9860 865879	EVGENIY POPOV	{"email": "popovevgeniy.14081988@postgrespro.ru", "phone": "+70032242682"}
0005434171187	B6E606	7721 827233	NADEZHDA GRISHINA	{"phone": "+70963617626"}
0005434171188	3C0F38	5344 134731	NIKITA DENISOV	{"phone": "+70597228421"}
0005434171189	C9CDB6	5283 962479	NADEZHDA KALININA	{"phone": "+70079526001"}
0005434171190	200FFD	8379 265975	VALENTINA OSIPOVA	{"phone": "+70497041553"}
0005434171191	A58A35	9895 950172	MAKSIM ABRAMOV	{"phone": "+70419447992"}
0005434171192	B0D1C1	7684 803635	VALENTINA NIKOLAEVA	{"phone": "+70278176934"}
0005434171193	EF6085	6093 127898	EVGENIY POPOV	{"phone": "+70280400561"}
0005434171194	CD4761	7742 618468	LILIYA EGOROVA	{"email": "liliya_egorova_09071971@postgrespro.ru", "phone": "+70625378985"}
0005434171195	CD4761	3386 032505	NINA NESTEROVA	{"phone": "+70216736674"}
0005434171196	FDF807	9332 928193	OLGA ILINA	{"email": "o.ilina.101968@postgrespro.ru", "phone": "+70569940937"}
0005434171197	C7F5BD	8625 109475	MARYAM MIRONOVA	{"phone": "+70677141144"}
0005434171198	C7F5BD	4756 133531	ALBINA NOVIKOVA	{"phone": "+70683298964"}
0005434171199	531A19	3663 556763	ANDREY ZAKHAROV	{"email": "andrey-zakharov.081967@postgrespro.ru", "phone": "+70382401192"}
0005434171200	531A19	5268 076077	VERA NAUMOVA	{"email": "vnaumova-021969@postgrespro.ru", "phone": "+70711431228"}
0005434171201	28CE3B	9207 155407	VASILIY SMIRNOV	{"email": "smirnov.v.09051965@postgrespro.ru", "phone": "+70786440946"}
0005434171202	28CE3B	2585 942488	NINA POTAPOVA	{"phone": "+70411875549"}
0005434171203	7EF534	8112 875279	FANIYA KUZMINA	{"email": "kuzminafaniya_121983@postgrespro.ru", "phone": "+70914533955"}
0005434171204	59CC5C	2437 158084	VALERIY YAKOVLEV	{"email": "v_yakovlev-1975@postgrespro.ru", "phone": "+70894540103"}
0005434171205	59CC5C	5571 135716	ANATOLIY RODIONOV	{"email": "a.rodionov_26031966@postgrespro.ru", "phone": "+70323160507"}
0005434171206	8D46AE	0179 421074	ANATOLIY SERGEEV	{"email": "anatoliy-sergeev_1971@postgrespro.ru", "phone": "+70172983904"}
0005434171207	3202CD	1518 147862	ALENA ZAKHAROVA	{"email": "zakharova.alena-1979@postgrespro.ru", "phone": "+70594788327"}
0005434171208	3202CD	5800 832193	IRAIDA MEDVEDEVA	{"email": "medvedevairaida061972@postgrespro.ru", "phone": "+70812157486"}
0005434171209	DD1D8F	2463 257479	VERA ANDREEVA	{"phone": "+70108924715"}
0005434171210	235409	4238 955261	VIKTOR TARASOV	{"email": "tarasov_viktor.111978@postgrespro.ru", "phone": "+70677670873"}
0005434171211	235409	8099 019393	ARTEMIY SOROKIN	{"phone": "+70252941883"}
0005434171212	235409	2297 057400	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir.081981@postgrespro.ru", "phone": "+70252043895"}
0005434171213	736EFA	6484 432126	EKATERINA KUZNECOVA	{"email": "kuznecova_e-27121974@postgrespro.ru", "phone": "+70796730301"}
0005434171214	736EFA	6161 325583	RAMIL ANTONOV	{"email": "antonovr1963@postgrespro.ru", "phone": "+70093066513"}
0005434171215	4BE720	0513 262094	FANIL DAVYDOV	{"phone": "+70617962996"}
0005434171216	4BE720	0544 584918	VLADIMIR TARASOV	{"email": "vladimir.tarasov121962@postgrespro.ru", "phone": "+70611316791"}
0005434171217	66225B	1405 585534	ALEKSANDR GAVRILOV	{"phone": "+70927273562"}
0005434171218	66225B	8800 667319	ANDREY BELOV	{"phone": "+70753190738"}
0005434171219	72609D	5487 858447	LIDIYA VASILEVA	{"email": "l.vasileva.121978@postgrespro.ru", "phone": "+70377859620"}
0005434171220	4BFE73	0821 555149	GALINA ANDREEVA	{"phone": "+70673945651"}
0005434171221	164A80	5624 794578	VIKTORIYA BORISOVA	{"phone": "+70927617634"}
0005434171222	78AB74	2896 263076	ALEKSANDR FEDOROV	{"phone": "+70243105950"}
0005434171223	4B985E	7072 519861	OKSANA TIMOFEEVA	{"email": "timofeeva.o_14031956@postgrespro.ru", "phone": "+70453277525"}
0005434171224	D1BDCF	4715 975545	YAROSLAV TARASOV	{"phone": "+70153404114"}
0005434171225	CC9160	9639 065795	VALERIY SOKOLOV	{"email": "sokolov-v1977@postgrespro.ru", "phone": "+70008595383"}
0005434171226	EC7FFE	2784 002723	TATYANA MOISEEVA	{"email": "t_moiseeva.25101972@postgrespro.ru", "phone": "+70618259325"}
0005434171227	EC7FFE	5336 903389	NIKOLAY MELNIKOV	{"phone": "+70796326464"}
0005434171228	6C9CA9	9958 152518	ELENA EFREMOVA	{"phone": "+70949424136"}
0005434171229	24B90A	9366 594797	VLADIMIR MOISEEV	{"email": "v-moiseev.101975@postgrespro.ru", "phone": "+70037621522"}
0005434171230	18B5E5	5622 809881	TATYANA FILIPPOVA	{"email": "tfilippova011969@postgrespro.ru", "phone": "+70575660236"}
0005434171231	F965C3	9558 322304	LYUDMILA LAZAREVA	{"email": "lyudmilalazareva081978@postgrespro.ru", "phone": "+70385796768"}
0005434171232	ED1574	6563 807020	MIKHAIL VASILEV	{"phone": "+70310216336"}
0005434171233	4FD0CD	7728 744322	LIDIYA KARPOVA	{"email": "l_karpova.101969@postgrespro.ru", "phone": "+70556495091"}
0005434171234	C7B8D8	5498 622133	IRINA ISAEVA	{"email": "irina_isaeva_1965@postgrespro.ru", "phone": "+70876746514"}
0005434171235	C7B8D8	4246 984748	ALEKSANDR KOZLOV	{"phone": "+70214608450"}
0005434171236	E35073	0992 617823	SERGEY MAKAROV	{"email": "s.makarov-1979@postgrespro.ru", "phone": "+70508991961"}
0005434171237	7BC89A	8345 782867	ANNA KISELEVA	{"email": "annakiseleva061963@postgrespro.ru", "phone": "+70792890990"}
0005434171238	2140CA	2107 280327	NATALYA MATVEEVA	{"email": "natalya_matveeva-071973@postgrespro.ru", "phone": "+70182760324"}
0005434171239	D4EAD2	2500 106452	EVGENIY IVANOV	{"email": "ivanov_evgeniy_1964@postgrespro.ru", "phone": "+70273397437"}
0005434171240	B52E90	5295 297413	NATALYA VASILEVA	{"email": "natalya-vasileva1973@postgrespro.ru", "phone": "+70915534244"}
0005434171241	0A7F74	1012 911872	GENNADIY TARASOV	{"phone": "+70796712287"}
0005434171242	0A7F74	0172 522724	STANISLAV YAKOVLEV	{"phone": "+70506530879"}
0005434171243	0A7F74	5252 574595	IVAN ANDREEV	{"email": "iandreev.23071972@postgrespro.ru", "phone": "+70565297486"}
0005434171244	AAAA19	2443 975928	VERA ZHURAVLEVA	{"phone": "+70221531077"}
0005434171245	205830	4379 296684	NIKOLAY IVANOV	{"email": "ivanov_nikolay051979@postgrespro.ru", "phone": "+70325763611"}
0005434171246	71F25A	3806 644657	VALENTINA EFIMOVA	{"email": "efimova_v101955@postgrespro.ru", "phone": "+70401893299"}
0005434171247	71F25A	3062 814469	OLGA EFREMOVA	{"phone": "+70813004193"}
0005434171248	2E7731	2861 814160	MARIYA TIKHONOVA	{"phone": "+70725829223"}
0005434171249	2E7731	7569 317242	VLADIMIR MAKAROV	{"phone": "+70932801110"}
0005434171250	10E33D	3427 066173	EVGENIY SOLOVEV	{"phone": "+70753690121"}
0005434171251	10E33D	4172 218809	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov_14031973@postgrespro.ru", "phone": "+70937182601"}
0005434171252	10E33D	7007 424828	VALERIY SIDOROV	{"phone": "+70676932209"}
0005434171253	976580	4836 324304	DANILA GAVRILOV	{"phone": "+70799025995"}
0005434171254	7054DB	0601 898368	ALEKSEY CHERNOV	{"email": "chernovaleksey-21021981@postgrespro.ru", "phone": "+70144851631"}
0005434171255	7054DB	2858 456444	ROMAN RODIONOV	{"phone": "+70849252480"}
0005434171256	9CAE50	8361 416056	AMIR ROMANOV	{"email": "romanov-amir-071968@postgrespro.ru", "phone": "+70803383647"}
0005434171257	9CAE50	4409 476938	VASILIY SEMENOV	{"phone": "+70887579472"}
0005434171258	EEB19C	0297 790186	SERGEY KOZLOV	{"email": "kozlov.sergey30051961@postgrespro.ru", "phone": "+70873645664"}
0005434171259	152CAE	8919 006969	MAKSIM ZHURAVLEV	{"email": "zhuravlev-maksim_27081974@postgrespro.ru", "phone": "+70026715356"}
0005434171260	857E29	8320 488351	VIKTOR MELNIKOV	{"phone": "+70453879316"}
0005434171261	A6B261	2992 356831	ALEKSANDR ALEKSEEV	{"phone": "+70787371846"}
0005434171262	A6B261	2800 418411	IGOR DMITRIEV	{"phone": "+70719768459"}
0005434171263	CCEEB0	9638 013524	OLEG ROMANOV	{"phone": "+70187876854"}
0005434171264	CCEEB0	9079 214955	ELENA BOGDANOVA	{"email": "e-bogdanova30031985@postgrespro.ru", "phone": "+70917021240"}
0005434171265	DD6850	0899 536545	FILIPP SEMENOV	{"phone": "+70967287335"}
0005434171266	E6C758	4426 260640	PETR ZAYCEV	{"phone": "+70553250177"}
0005434171267	8305EC	5987 476717	VERA ANDREEVA	{"phone": "+70992643583"}
0005434171268	AE1B8B	8699 858367	NINA ABRAMOVA	{"email": "abramovanina.091965@postgrespro.ru", "phone": "+70945650859"}
0005434171326	948194	4469 552771	GALINA ILINA	{"phone": "+70790451294"}
0005434171269	AE1B8B	1515 728154	LYUDMILA EGOROVA	{"email": "l.egorova14021972@postgrespro.ru", "phone": "+70492237151"}
0005434171270	79C606	2680 780036	GENNADIY MOROZOV	{"phone": "+70911612078"}
0005434171271	79C606	9967 566527	VALENTINA KRASNOVA	{"email": "krasnova_v1971@postgrespro.ru", "phone": "+70739993970"}
0005434171272	13C60B	7406 077434	ALENA NAZAROVA	{"phone": "+70377297352"}
0005434171273	9F4F81	3635 733504	ELENA MASLOVA	{"phone": "+70577231393"}
0005434171274	9F4F81	7526 176206	NATALYA KALININA	{"phone": "+70950113626"}
0005434171275	337014	0080 558674	ANNA MEDVEDEVA	{"phone": "+70819066781"}
0005434171276	4F3F41	3715 566322	YULIYA FEDOROVA	{"phone": "+70107494784"}
0005434171277	4F3F41	1574 102337	ELENA IVANOVA	{"phone": "+70346268864"}
0005434171278	D334BA	2169 229948	NINA CHERNOVA	{"email": "n_chernova1978@postgrespro.ru", "phone": "+70764355598"}
0005434171279	15025E	0081 291525	NADEZHDA KUDRYASHOVA	{"phone": "+70317788361"}
0005434171280	0AE9DF	2926 830548	IRINA FROLOVA	{"email": "frolova-i.031974@postgrespro.ru", "phone": "+70611923862"}
0005434171281	9BCD14	1193 722871	MIKHAIL FILIPPOV	{"phone": "+70717527272"}
0005434171282	BD21A6	9216 841788	LARISA BELYAEVA	{"email": "belyaevalarisa031956@postgrespro.ru", "phone": "+70195174966"}
0005434171283	BD21A6	3947 998306	VALENTIN KUZNECOV	{"phone": "+70656885103"}
0005434171284	BD21A6	8331 489580	EVGENIYA KOROLEVA	{"email": "e-koroleva-081983@postgrespro.ru", "phone": "+70486848644"}
0005434171285	05FD06	1937 464630	GENNADIY BARANOV	{"email": "gennadiy.baranov101973@postgrespro.ru", "phone": "+70519777173"}
0005434171286	F3AC3B	3851 792994	OLESYA MAKAROVA	{"email": "makarova.olesya-1965@postgrespro.ru", "phone": "+70889464838"}
0005434171287	F3AC3B	7801 881937	YULIYA GAVRILOVA	{"email": "gavrilova-y.31011967@postgrespro.ru", "phone": "+70245707970"}
0005434171288	6931DB	5209 197743	PELAGEYA FROLOVA	{"email": "pfrolova.1971@postgrespro.ru", "phone": "+70324307554"}
0005434171289	6931DB	0066 897287	IVAN DENISOV	{"email": "ivan.denisov-1986@postgrespro.ru", "phone": "+70116731111"}
0005434171290	0F5F54	8247 276468	SVETLANA GUSEVA	{"phone": "+70750454730"}
0005434171291	B21E73	8441 957855	NADEZHDA KOZLOVA	{"phone": "+70155914481"}
0005434171292	44516A	9446 691981	ARTEM NIKOLAEV	{"email": "nikolaev-a-041978@postgrespro.ru", "phone": "+70503170091"}
0005434171293	44516A	2734 554477	NIKOLAY VASILEV	{"email": "vasilev_nikolay02101970@postgrespro.ru", "phone": "+70768197189"}
0005434171294	760173	1821 792378	ALEKSEY SOKOLOV	{"phone": "+70136561614"}
0005434171295	6DE0BB	8974 066520	KONSTANTIN ZHURAVLEV	{"phone": "+70249876593"}
0005434171296	6DE0BB	9848 583104	OLGA IVANOVA	{"phone": "+70005291610"}
0005434171297	1FC302	3333 811234	NINA DENISOVA	{"email": "nina_denisova.17121992@postgrespro.ru", "phone": "+70866382264"}
0005434171298	1FC302	4395 969825	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev-24101961@postgrespro.ru", "phone": "+70843943238"}
0005434171299	64A1AF	4608 839658	YURIY ZAKHAROV	{"email": "zakharovyuriy051960@postgrespro.ru", "phone": "+70503364794"}
0005434171300	6FFFC4	5865 543975	PETR FEDOROV	{"phone": "+70295898852"}
0005434171301	FFA9AC	0608 595269	KLAVDIYA ZAYCEVA	{"phone": "+70770926008"}
0005434171302	FFA9AC	9743 199974	LYUDMILA MASLOVA	{"email": "l.maslova_1970@postgrespro.ru", "phone": "+70771400269"}
0005434171303	91647E	0025 105072	VYACHESLAV KUZMIN	{"email": "kuzmin.v_1986@postgrespro.ru", "phone": "+70698717609"}
0005434171304	91647E	4970 059642	ALEKSEY SERGEEV	{"phone": "+70100622656"}
0005434171305	ECBA4B	5555 063337	YURIY MAKAROV	{"phone": "+70191636292"}
0005434171306	6B8598	8443 452057	EVGENIY MEDVEDEV	{"phone": "+70400113286"}
0005434171307	81DF99	8384 183799	ELENA VOLKOVA	{"email": "volkova.elena.1972@postgrespro.ru", "phone": "+70689864337"}
0005434171308	81DF99	8204 360108	MARINA MEDVEDEVA	{"phone": "+70200863804"}
0005434171309	C455B9	0579 763783	VALERIY MATVEEV	{"phone": "+70984986744"}
0005434171310	5F11BE	3656 575682	ALEKSANDR MAKSIMOV	{"phone": "+70498929238"}
0005434171311	ACC7D7	9214 490427	YURIY BARANOV	{"email": "baranov_y_03041975@postgrespro.ru", "phone": "+70289668677"}
0005434171312	C3F256	2385 161090	VASILIY TIKHONOV	{"email": "tikhonov_vasiliy_12071969@postgrespro.ru", "phone": "+70868700168"}
0005434171313	DF3C4E	0209 794090	ANDREY SCHERBAKOV	{"phone": "+70878721383"}
0005434171314	DF3C4E	8579 528255	OLGA MAKAROVA	{"phone": "+70754906926"}
0005434171315	89D1E4	0773 930549	MIKHAIL NOVIKOV	{"email": "mikhail.novikov-051981@postgrespro.ru", "phone": "+70985750859"}
0005434171316	89D1E4	1286 442871	ANASTASIYA LOGINOVA	{"email": "anastasiya.loginova.09091964@postgrespro.ru", "phone": "+70413493826"}
0005434171317	89D1E4	9686 854892	NIKOLAY SOLOVEV	{"phone": "+70097462160"}
0005434171318	CDF8EE	0133 999338	VLADIMIR MIKHAYLOV	{"phone": "+70957860713"}
0005434171319	BB467D	0035 569651	EVGENIY VLASOV	{"email": "vlasov-e_22021973@postgrespro.ru", "phone": "+70842103308"}
0005434171320	08479D	7337 151831	SVETLANA BELOVA	{"phone": "+70442487580"}
0005434171321	08479D	2462 374447	TATYANA BORISOVA	{"phone": "+70236103541"}
0005434171322	26681D	0438 065503	SOFYA FILIPPOVA	{"phone": "+70707730780"}
0005434171323	26681D	7603 417041	ALEKSANDRA ALEKSEEVA	{"phone": "+70439943046"}
0005434171324	AA0B20	7685 616944	ALEKSANDR KOROLEV	{"phone": "+70372178516"}
0005434171325	948194	9372 467409	ARTEM ISAEV	{"phone": "+70429499976"}
0005434171327	948194	6215 577505	MIKHAIL OSIPOV	{"email": "osipov.mikhail_041969@postgrespro.ru", "phone": "+70808065735"}
0005434171328	948194	2672 187914	DMITRIY ALEKSANDROV	{"email": "aleksandrov_dmitriy.13081977@postgrespro.ru", "phone": "+70000293097"}
0005434171329	335FAB	1795 981632	VLADIMIR DAVYDOV	{"phone": "+70366100046"}
0005434171330	335FAB	9872 012182	BORIS DAVYDOV	{"phone": "+70027612746"}
0005434171331	335FAB	1844 720014	MARINA BARANOVA	{"email": "m_baranova_1965@postgrespro.ru", "phone": "+70030494672"}
0005434171332	A84897	2112 453778	SVETLANA TITOVA	{"phone": "+70463088025"}
0005434171333	EB9B53	5058 918922	MARIYA MIRONOVA	{"phone": "+70526403726"}
0005434171334	EB9B53	9153 320243	EVGENIY TARASOV	{"phone": "+70282123971"}
0005434171335	EB9B53	1380 893587	ALEKSANDR NOVIKOV	{"phone": "+70413387785"}
0005434171336	487DD5	5989 908604	LYUBOV MAKAROVA	{"phone": "+70953264021"}
0005434171337	C764AC	3330 885939	DANIIL BONDARENKO	{"email": "d-bondarenko_1975@postgrespro.ru", "phone": "+70973915978"}
0005434171338	C6704A	4820 323455	ALEKSEY RODIONOV	{"phone": "+70284492658"}
0005434171339	A338F1	7692 059490	TATYANA MARTYNOVA	{"phone": "+70474635036"}
0005434171340	EE3B7C	4230 720345	GENNADIY POPOV	{"phone": "+70670496699"}
0005434171341	9B7587	4979 625197	GALINA YUDINA	{"email": "yudinagalina_101964@postgrespro.ru", "phone": "+70149204529"}
0005434171342	7A86D8	0033 959427	EKATERINA IVANOVA	{"email": "ekaterina-ivanova-121972@postgrespro.ru", "phone": "+70993740692"}
0005434171343	65C06D	7587 214402	EVGENIY VASILEV	{"email": "vasilev.evgeniy17111972@postgrespro.ru", "phone": "+70716727971"}
0005434171344	65C06D	6485 697823	SERGEY KUZMIN	{"phone": "+70108440723"}
0005434171345	9BA0D4	3597 146600	GALINA EGOROVA	{"phone": "+70303004035"}
0005434171346	7D2AA1	8852 678256	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-031983@postgrespro.ru", "phone": "+70437031624"}
0005434171347	2B1DDF	8263 378162	INGA LAZAREVA	{"email": "ingalazareva-071970@postgrespro.ru", "phone": "+70541248260"}
0005434171348	34C6FF	8273 611013	YULIYA FILATOVA	{"phone": "+70728287268"}
0005434171349	E825C4	3646 621303	SERGEY NAZAROV	{"phone": "+70410651201"}
0005434171350	8D3B5C	2854 221833	YULIYA DENISOVA	{"email": "denisova.yuliya.1972@postgrespro.ru", "phone": "+70645114615"}
0005434171351	A7F1B3	6801 347628	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov-1970@postgrespro.ru", "phone": "+70433794944"}
0005434171352	4517FA	9506 389124	EVGENIY DENISOV	{"phone": "+70101892765"}
0005434171353	4517FA	4844 146673	GALINA SOKOLOVA	{"email": "sokolovagalina_17071973@postgrespro.ru", "phone": "+70217897223"}
0005434171354	63C0C0	4793 779506	DIANA POPOVA	{"email": "diana-popova_1979@postgrespro.ru", "phone": "+70346380409"}
0005434171355	A382D0	5624 532304	VLADISLAV ANTONOV	{"email": "antonov.vladislav.1974@postgrespro.ru", "phone": "+70766621393"}
0005434171356	A382D0	4900 027996	VALERIY VASILEV	{"email": "vasilevvaleriy_1971@postgrespro.ru", "phone": "+70547143496"}
0005434171357	F13BE7	7782 952209	EVGENIY BONDARENKO	{"phone": "+70382923510"}
0005434171358	AFF564	9417 146796	ALEKSEY ISAEV	{"email": "isaev_aleksey-14021968@postgrespro.ru", "phone": "+70538048482"}
0005434171359	AFF564	8165 170462	GALINA VASILEVA	{"email": "g_vasileva28121972@postgrespro.ru", "phone": "+70191708005"}
0005434171360	67BC54	6508 722848	IGOR VASILEV	{"email": "vasilev.igor-03111972@postgrespro.ru", "phone": "+70788568961"}
0005434171361	40B374	2095 593762	ILYA SOLOVEV	{"phone": "+70890105685"}
0005434171362	07CD75	6728 590650	NATALYA MAKAROVA	{"email": "makarova-n1961@postgrespro.ru", "phone": "+70736293221"}
0005434171363	6A066C	2226 597827	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr_1973@postgrespro.ru", "phone": "+70556636596"}
0005434171364	86E0C7	2430 423914	KONSTANTIN FEDOROV	{"email": "k_fedorov-1954@postgrespro.ru", "phone": "+70758781812"}
0005434171365	6C9A82	0722 695750	ARINA TIKHONOVA	{"email": "tikhonova.a_1963@postgrespro.ru", "phone": "+70476315412"}
0005434171366	6C9A82	5367 792722	YURIY BORISOV	{"phone": "+70542243447"}
0005434171367	64AF88	4982 823709	ILYA YAKOVLEV	{"email": "yakovlevilya.011957@postgrespro.ru", "phone": "+70416441800"}
0005434171368	64AF88	0101 125581	YURIY MELNIKOV	{"phone": "+70337073093"}
0005434171369	7ACD58	0082 629532	ASIYA TARASOVA	{"email": "tarasova.asiya-021974@postgrespro.ru", "phone": "+70806672740"}
0005434171370	0EBE30	3857 637943	EVGENIYA PETROVA	{"email": "evgeniya_petrova121969@postgrespro.ru", "phone": "+70169701933"}
0005434171371	18B0FD	9623 266754	DENIS MAKSIMOV	{"email": "maksimovdenis-1977@postgrespro.ru", "phone": "+70250667782"}
0005434171372	821750	8412 083581	DMITRIY MAKAROV	{"phone": "+70697854567"}
0005434171373	821750	8972 483822	LYUDMILA NOVIKOVA	{"email": "novikova.lyudmila-03111975@postgrespro.ru", "phone": "+70734431503"}
0005434171374	310C60	9303 110926	SVETLANA RODIONOVA	{"email": "rodionovas021974@postgrespro.ru", "phone": "+70319601034"}
0005434171375	310C60	8030 591517	OLGA KOROLEVA	{"email": "korolevaolga15031966@postgrespro.ru", "phone": "+70695967190"}
0005434171376	6A04A5	3943 017142	ARTEM DENISOV	{"phone": "+70085616279"}
0005434171377	1A2551	9930 608180	YULIYA KOVALEVA	{"phone": "+70244426493"}
0005434171378	CE24F9	1965 451058	NIKOLAY POPOV	{"phone": "+70514931152"}
0005434171379	CD8E5A	3954 804964	VALERIY DAVYDOV	{"phone": "+70137704569"}
0005434171380	CD8E5A	1026 212342	IRINA SERGEEVA	{"email": "i-sergeeva28011973@postgrespro.ru", "phone": "+70219235520"}
0005434171381	CD8E5A	2228 861257	RINAT KUZNECOV	{"email": "rkuznecov1960@postgrespro.ru", "phone": "+70299996949"}
0005434171382	E51EAA	8094 847474	TATYANA MAKAROVA	{"phone": "+70741990481"}
0005434171383	E51EAA	5350 651262	TAMARA RYABOVA	{"email": "tryabova_1962@postgrespro.ru", "phone": "+70681456163"}
0005434171384	A89BEE	4974 680214	ALEKSEY GORBUNOV	{"email": "gorbunov-aleksey.01021981@postgrespro.ru", "phone": "+70596172573"}
0005434171385	A89BEE	9638 949426	ANASTASIYA NIKOLAEVA	{"phone": "+70411066798"}
0005434171386	A89BEE	3951 299340	VALERIY RODIONOV	{"email": "rodionov_valeriy1979@postgrespro.ru", "phone": "+70509496602"}
0005434171387	E1E438	2898 632016	ALEKSEY NIKOLAEV	{"phone": "+70278925308"}
0005434171388	E1E438	4115 877708	ARINA IVANOVA	{"email": "ivanova_a.121987@postgrespro.ru", "phone": "+70172394386"}
0005434171389	68C81E	3362 149150	EVGENIY KOZLOV	{"phone": "+70144158518"}
0005434171390	20A663	5620 095857	LIDIYA MIRONOVA	{"phone": "+70107269927"}
0005434171391	D7D4B7	2060 529305	ZINAIDA IVANOVA	{"phone": "+70938428394"}
0005434171392	F8DED6	7308 137211	PETR FROLOV	{"phone": "+70712495875"}
0005434171393	DC34A6	3867 182009	DMITRIY GORBUNOV	{"email": "gorbunovdmitriy1974@postgrespro.ru", "phone": "+70271648832"}
0005434171394	DC34A6	4367 324371	YULIYA VLASOVA	{"phone": "+70689543086"}
0005434171395	237ED0	7707 288881	ALEKSANDR ISAEV	{"email": "a-isaev-121972@postgrespro.ru", "phone": "+70994794603"}
0005434171396	237ED0	3896 473026	OLEG KUDRYASHOV	{"email": "kudryashov_oleg25011965@postgrespro.ru", "phone": "+70187246595"}
0005434171397	237ED0	1077 761563	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr_021976@postgrespro.ru", "phone": "+70007285184"}
0005434171398	ED156F	0434 052413	AYRAT VLASOV	{"email": "ayratvlasov.1963@postgrespro.ru", "phone": "+70313695988"}
0005434171399	ED156F	6319 758860	VADIM KUZNECOV	{"email": "kuznecov.v-1966@postgrespro.ru", "phone": "+70199143422"}
0005434171400	FB925F	9007 918383	ILYA ZAYCEV	{"email": "zaycev_ilya.061975@postgrespro.ru", "phone": "+70875171733"}
0005434171401	D60214	5569 457459	VLADIMIR STEPANOV	{"email": "v_stepanov-1975@postgrespro.ru", "phone": "+70829329430"}
0005434171402	598F36	9417 499325	VALERIYA GORBUNOVA	{"email": "gorbunovavaleriya-14081977@postgrespro.ru", "phone": "+70599941138"}
0005434171403	C51D9B	0628 796851	ALEKSANDR MIRONOV	{"phone": "+70498075358"}
0005434171404	E0C0F2	2878 332377	ALEKSEY MAKSIMOV	{"email": "maksimova091975@postgrespro.ru", "phone": "+70392910869"}
0005434171405	2AC704	8646 585005	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov_26051969@postgrespro.ru", "phone": "+70770553795"}
0005434171406	CEA5CC	8383 119687	ALEKSANDR FROLOV	{"email": "aleksandrfrolov_1960@postgrespro.ru", "phone": "+70276966632"}
0005434171407	CEA5CC	4249 234997	VLADIMIR FOMIN	{"phone": "+70158393278"}
0005434171408	7E012D	5232 768702	IRINA BOGDANOVA	{"phone": "+70822605405"}
0005434171409	513C83	0508 250256	ALEKSANDR ISAEV	{"phone": "+70135086961"}
0005434171410	513C83	5454 905957	DMITRIY ZAKHAROV	{"phone": "+70783213355"}
0005434171411	513C83	7636 231928	NINA SOKOLOVA	{"phone": "+70186181804"}
0005434171412	555FFF	2862 861685	VASILIY NAZAROV	{"email": "vasiliy-nazarov_28121964@postgrespro.ru", "phone": "+70861542805"}
0005434171413	555FFF	0188 627822	VADIM KUZNECOV	{"email": "vadim.kuznecov071980@postgrespro.ru", "phone": "+70203190620"}
0005434171414	3F15CE	5743 176751	EKATERINA KAZAKOVA	{"phone": "+70893517488"}
0005434171415	7078EE	9915 726392	POLINA VOLKOVA	{"phone": "+70400850514"}
0005434171416	7078EE	7557 258086	MIKHAIL PETROV	{"email": "petrov-m24081972@postgrespro.ru", "phone": "+70104814034"}
0005434171417	9649F3	8450 164412	OLGA NIKITINA	{"email": "o-nikitina-1965@postgrespro.ru", "phone": "+70889707281"}
0005434171418	9649F3	1541 436196	YAKOV SMIRNOV	{"email": "smirnov-y-1970@postgrespro.ru", "phone": "+70681400375"}
0005434171419	488438	7157 601755	ANNA MOROZOVA	{"phone": "+70754029857"}
0005434171420	E2FA78	0863 232257	MILANA ZAKHAROVA	{"email": "zakharova-m051967@postgrespro.ru", "phone": "+70433380395"}
0005434171421	E2FA78	7720 375906	TATYANA MAKAROVA	{"phone": "+70293113245"}
0005434171422	E2FA78	9634 938540	LARISA MOROZOVA	{"email": "l_morozova_061958@postgrespro.ru", "phone": "+70790646799"}
0005434171423	E44A75	2008 448027	SERGEY AFANASEV	{"phone": "+70568964224"}
0005434171424	048EAF	9698 437158	OLEG ANDREEV	{"phone": "+70705731992"}
0005434171425	6EAAA8	1097 295031	ALINA LEBEDEVA	{"email": "lebedeva_alina08081967@postgrespro.ru", "phone": "+70685680286"}
0005434171426	35A553	5666 346518	DANIIL TIKHONOV	{"phone": "+70776152693"}
0005434171427	35A553	8870 213404	VASILIY SOKOLOV	{"email": "sokolov.vasiliy-1970@postgrespro.ru", "phone": "+70903081765"}
0005434171428	1E485F	2106 278666	RIMMA MATVEEVA	{"phone": "+70699665256"}
0005434171429	1E485F	4508 171016	EGOR OSIPOV	{"phone": "+70644276349"}
0005434171430	463EA0	1870 458358	OLGA VLASOVA	{"email": "olgavlasova-1965@postgrespro.ru", "phone": "+70449235303"}
0005434171431	FB2AB2	4239 624056	DMITRIY MIRONOV	{"phone": "+70931880866"}
0005434171432	6FD247	5097 450299	VASILIY DENISOV	{"phone": "+70442135461"}
0005434171433	6FD247	9698 252856	VALENTINA ANISIMOVA	{"phone": "+70628499049"}
0005434171434	F7819D	4925 744626	EVGENIY NIKOLAEV	{"email": "nikolaev.e011974@postgrespro.ru", "phone": "+70467985190"}
0005434171435	D0868A	9099 128369	IRINA KUZNECOVA	{"email": "kuznecova-i_08081975@postgrespro.ru", "phone": "+70874997726"}
0005434171436	D0868A	4865 195714	ALINA NAZAROVA	{"phone": "+70674160328"}
0005434171437	00E56B	2356 748257	VLADIMIR ANDREEV	{"phone": "+70836670340"}
0005434171438	FF3CB1	7207 455571	ALEKSEY SHEVCHENKO	{"email": "a-shevchenko021966@postgrespro.ru", "phone": "+70065018261"}
0005434171439	F31E86	5986 274726	OLGA SEMENOVA	{"email": "olga-semenova111975@postgrespro.ru", "phone": "+70537550325"}
0005434171440	F31E86	6146 647822	SERGEY ZHUKOV	{"email": "sergey_zhukov.08051969@postgrespro.ru", "phone": "+70928982310"}
0005434171441	578A6E	6571 359022	NIKOLAY POPOV	{"email": "popov_n-28021970@postgrespro.ru", "phone": "+70761881706"}
0005434171442	578A6E	2273 839233	ANTONINA ABRAMOVA	{"email": "abramovaa-24101980@postgrespro.ru", "phone": "+70221461172"}
0005434171443	ADC57B	5549 555580	OLEG MIRONOV	{"email": "o_mironov.20071971@postgrespro.ru", "phone": "+70890928787"}
0005434171444	291839	6421 283849	MIKHAIL KUZNECOV	{"email": "mkuznecov_1980@postgrespro.ru", "phone": "+70580368182"}
0005434171445	EC50D5	8496 617255	RAISA LOGINOVA	{"phone": "+70542145880"}
0005434171446	524EF7	3529 078004	KONSTANTIN KONOVALOV	{"email": "konovalovk-13051977@postgrespro.ru", "phone": "+70283750830"}
0005434171447	812F08	6041 698093	ALEKSEY BONDARENKO	{"phone": "+70603419369"}
0005434171448	44AF1E	2357 594098	VIKTOR VASILEV	{"email": "vvasilev.1978@postgrespro.ru", "phone": "+70957452674"}
0005434171449	44AF1E	5936 185946	ALEKSANDR KARPOV	{"email": "karpov-aleksandr051968@postgrespro.ru", "phone": "+70573905597"}
0005434171450	D6633B	2042 823826	ALEKSEY BELOV	{"phone": "+70586836069"}
0005434171451	37B184	2904 732923	LYUBOV GRISHINA	{"phone": "+70114615431"}
0005434171452	37B184	2865 340878	ALEKSANDR SOKOLOV	{"email": "a_sokolov.03081970@postgrespro.ru", "phone": "+70906608950"}
0005434171453	37B184	9971 948115	YULIYA ZHUKOVA	{"email": "y_zhukova_10021971@postgrespro.ru", "phone": "+70526846963"}
0005434171454	D50B60	3724 363749	GALINA PAVLOVA	{"phone": "+70325653575"}
0005434171455	36A3D4	2356 315736	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy17071968@postgrespro.ru", "phone": "+70256344547"}
0005434171456	36A3D4	6735 239300	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov_051968@postgrespro.ru", "phone": "+70224036533"}
0005434171457	1CCF49	4101 332008	VALERIYA VOLKOVA	{"email": "volkova-valeriya-121983@postgrespro.ru", "phone": "+70093750588"}
0005434171458	3D0473	0608 395181	OLGA SERGEEVA	{"email": "osergeeva11121969@postgrespro.ru", "phone": "+70720878329"}
0005434171459	3D0473	7444 400080	OLGA KISELEVA	{"email": "okiseleva-1960@postgrespro.ru", "phone": "+70989339618"}
0005434171460	A675DB	2266 617144	EVGENIY SHEVCHENKO	{"email": "evgeniy-shevchenko-081984@postgrespro.ru", "phone": "+70552768792"}
0005434171461	A675DB	0421 766752	NIKOLAY ZHUKOV	{"phone": "+70026405542"}
0005434171462	A675DB	4404 769857	ANATOLIY ISAEV	{"phone": "+70878327716"}
0005434171463	6E8464	6540 937994	SERGEY KUZNECOV	{"email": "kuznecov_s_061970@postgrespro.ru", "phone": "+70333598576"}
0005434171464	034B1A	2263 163038	SERGEY BELOV	{"email": "sergey.belov.28051978@postgrespro.ru", "phone": "+70773058563"}
0005434171465	434FC3	9158 502151	OLGA MOISEEVA	{"phone": "+70479358914"}
0005434171466	040615	4595 828544	POLINA VASILEVA	{"email": "vasilevapolina1973@postgrespro.ru", "phone": "+70888465919"}
0005434171467	0FC27D	3404 862194	ANDREY SAVELEV	{"phone": "+70756452994"}
0005434171468	0FC27D	0092 911170	NINA ZAKHAROVA	{"email": "nina_zakharova1969@postgrespro.ru", "phone": "+70561101812"}
0005434171469	D02008	0957 590750	OLGA KULIKOVA	{"phone": "+70997357240"}
0005434171513	AC0806	3733 767219	ANTONINA EGOROVA	{"phone": "+70858886473"}
0005434171514	AC0806	7214 007627	DMITRIY CHERNOV	{"email": "dmitriychernov-15121969@postgrespro.ru", "phone": "+70327758216"}
0005434173473	F65436	0361 854093	IRINA YAKOVLEVA	{"phone": "+70055064943"}
0005434173450	193D60	8687 370231	ALEKSANDR MOROZOV	{"email": "a.morozov.1987@postgrespro.ru", "phone": "+70721639152"}
0005434173451	9B3B54	9205 934899	NIKOLAY VOROBEV	{"email": "vorobev.n.021978@postgrespro.ru", "phone": "+70969972729"}
0005434173452	3478B7	7735 030470	ALBINA ALEKSEEVA	{"phone": "+70167957355"}
0005434173453	3478B7	5215 408893	ALEKSEY RODIONOV	{"phone": "+70647428708"}
0005434173454	8E31F6	2476 681230	SVETLANA MATVEEVA	{"email": "smatveeva.111979@postgrespro.ru", "phone": "+70280476410"}
0005434173455	3A2151	6146 461284	ALEKSANDR BONDARENKO	{"phone": "+70872807508"}
0005434173456	A1E2AD	6884 188820	KIRILL KUDRYASHOV	{"email": "kkudryashov-061976@postgrespro.ru", "phone": "+70885593569"}
0005434173457	A8E8AB	1510 033408	PAVEL VOROBEV	{"email": "pavel-vorobev-1979@postgrespro.ru", "phone": "+70919869598"}
0005434173458	CBF3B2	8032 290538	ALEKSANDR VOROBEV	{"phone": "+70608178346"}
0005434173459	CBF3B2	8137 951951	OLEG ALEKSEEV	{"email": "o.alekseev-23061985@postgrespro.ru", "phone": "+70711746973"}
0005434173460	2D3678	0884 627492	OLEG GORBUNOV	{"email": "o-gorbunov101966@postgrespro.ru", "phone": "+70331619284"}
0005434173461	2D3678	0519 025112	KIRILL GAVRILOV	{"email": "k-gavrilov-1965@postgrespro.ru", "phone": "+70922230571"}
0005434173462	A63907	6127 908300	ALEKSANDR NAZAROV	{"email": "nazarov-a081982@postgrespro.ru", "phone": "+70813257421"}
0005434173463	9E080E	7842 053637	LARISA ANDREEVA	{"email": "l-andreeva-111965@postgrespro.ru", "phone": "+70702850491"}
0005434173464	9E080E	6487 742388	VALENTINA VASILEVA	{"phone": "+70106941281"}
0005434173465	0F0682	5017 764577	YULIYA ZHUKOVA	{"email": "yzhukova061974@postgrespro.ru", "phone": "+70008765832"}
0005434173466	F76C91	5409 294735	ARTEM GORBUNOV	{"phone": "+70106509370"}
0005434173467	5B9146	4243 555862	VARVARA KUDRYASHOVA	{"email": "kudryashova-varvara031971@postgrespro.ru", "phone": "+70380988091"}
0005434173468	0A6530	2500 498253	ANDREY SEMENOV	{"email": "andreysemenov_1986@postgrespro.ru", "phone": "+70763980030"}
0005434173469	0A6530	6413 852543	VALENTINA DENISOVA	{"email": "v_denisova_1974@postgrespro.ru", "phone": "+70421499743"}
0005434173470	DF3901	4395 739463	YURIY SOLOVEV	{"phone": "+70482354679"}
0005434173471	DF3901	8387 521099	LYUBOV KOROLEVA	{"email": "lyubovkoroleva_18011980@postgrespro.ru", "phone": "+70230346063"}
0005434173472	94122E	1099 809876	ELENA SERGEEVA	{"email": "e_sergeeva-1967@postgrespro.ru", "phone": "+70085131084"}
0005434173474	16F31F	8328 032490	YULIYA FROLOVA	{"email": "yuliya.frolova_021970@postgrespro.ru", "phone": "+70228873090"}
0005434173475	6AC10F	8703 173052	LYUBOV EGOROVA	{"email": "egorova-l_081974@postgrespro.ru", "phone": "+70318594592"}
0005434173476	CCC7EE	0330 558029	MIKHAIL KUDRYASHOV	{"email": "m_kudryashov.06101962@postgrespro.ru", "phone": "+70682793019"}
0005434173477	CCC7EE	6330 700807	OLEG KOZLOV	{"email": "kozlov.oleg.02031979@postgrespro.ru", "phone": "+70836594959"}
0005434173478	0953D0	4870 011444	NAIL GERASIMOV	{"phone": "+70977275948"}
0005434173479	DBD357	5323 601322	ANDREY ZHUKOV	{"email": "zhukov_a.091966@postgrespro.ru", "phone": "+70606681182"}
0005434173480	5D72F8	8566 593584	IGOR VASILEV	{"email": "vasilev.igor1974@postgrespro.ru", "phone": "+70308130495"}
0005434173481	B5A82B	1220 292475	SERGEY FOMIN	{"email": "fomin-s.22081973@postgrespro.ru", "phone": "+70154981860"}
0005434173482	B5A82B	6723 852636	STEPAN DENISOV	{"email": "denisov.stepan08101973@postgrespro.ru", "phone": "+70336193405"}
0005434173483	91DEF6	2274 438707	NATALIYA POPOVA	{"phone": "+70641416860"}
0005434173484	6DE9E4	5741 272868	OLEG VOROBEV	{"phone": "+70657721424"}
0005434173485	3E0CE5	0634 432925	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya.mikhaylova_1974@postgrespro.ru", "phone": "+70351138638"}
0005434173486	D998A2	3781 959807	EVDOKIYA YUDINA	{"email": "eyudina_101968@postgrespro.ru", "phone": "+70716644155"}
0005434173487	D998A2	8451 462241	TAMARA TIKHONOVA	{"email": "ttikhonova-1958@postgrespro.ru", "phone": "+70483392087"}
0005434173488	9010D1	1919 605817	MARIYA NAZAROVA	{"email": "nazarova-mariya_10081960@postgrespro.ru", "phone": "+70222931931"}
0005434173489	FE85D0	3519 664735	OLESYA KOMAROVA	{"phone": "+70815955399"}
0005434173490	DAB60B	3527 730299	ALEKSANDR PETROV	{"phone": "+70542743874"}
0005434173491	DAB60B	9318 419995	IGOR FOMIN	{"email": "fomin_i-03101970@postgrespro.ru", "phone": "+70686708745"}
0005434173492	6C6D6A	9491 639667	YULIYA SOROKINA	{"email": "y.sorokina.081971@postgrespro.ru", "phone": "+70906444500"}
0005434173493	F97CC5	5869 230423	ANTONINA KOLESNIKOVA	{"email": "kolesnikovaantonina_1978@postgrespro.ru", "phone": "+70151527881"}
0005434173494	29E2C1	7705 049117	PAVEL KUZNECOV	{"phone": "+70457759716"}
0005434173495	507A50	8438 826146	NATALIYA ROMANOVA	{"email": "nataliya.romanova-11101969@postgrespro.ru", "phone": "+70673233274"}
0005434173496	477C58	5738 693124	PAVEL ZHURAVLEV	{"email": "p_zhuravlev.101966@postgrespro.ru", "phone": "+70912222100"}
0005434173497	477C58	9850 645960	SOFIYA RYABOVA	{"email": "ryabova-s.05111975@postgrespro.ru", "phone": "+70440860906"}
0005434173498	93779C	9907 075778	MARINA KISELEVA	{"phone": "+70963248408"}
0005434173499	7D5714	1618 018116	ALEKSANDR VOLKOV	{"phone": "+70930109969"}
0005434173500	A8021D	0665 618136	DZHAMILYA KOZLOVA	{"email": "dzhamilya_kozlova_26081979@postgrespro.ru", "phone": "+70287974093"}
0005434173501	D4707F	3653 870919	ALEKSEY MARTYNOV	{"email": "a_martynov_051979@postgrespro.ru", "phone": "+70534228979"}
0005434173502	C98083	3214 973196	VLADIMIR TARASOV	{"phone": "+70998610484"}
0005434173503	C98083	5611 342693	VALENTINA KOROLEVA	{"email": "vkoroleva-041963@postgrespro.ru", "phone": "+70774768042"}
0005434173504	E46CB1	7589 135851	RUSLAN KULIKOV	{"phone": "+70298350618"}
0005434173505	E46CB1	4049 280204	NINA ANISIMOVA	{"phone": "+70055346047"}
0005434173506	ADD4FC	2793 568000	IGOR DMITRIEV	{"email": "idmitriev1970@postgrespro.ru", "phone": "+70968961828"}
0005434173507	ADD4FC	0151 324345	LYUDMILA DENISOVA	{"email": "denisova-l-071966@postgrespro.ru", "phone": "+70220202234"}
0005434173508	F70F3D	1562 539081	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov_18051970@postgrespro.ru", "phone": "+70690876400"}
0005434173509	952964	9191 465027	SERGEY POPOV	{"email": "sergey-popov_25041969@postgrespro.ru", "phone": "+70440516821"}
0005434173510	C8358F	4265 495916	IRINA ZHURAVLEVA	{"phone": "+70637760558"}
0005434173511	C8358F	3546 171296	ALLA PETROVA	{"email": "alla_petrova.061972@postgrespro.ru", "phone": "+70119925787"}
0005434173512	B00744	2424 508198	GALINA ZAYCEVA	{"email": "zaycevag09121975@postgrespro.ru", "phone": "+70277273454"}
0005434173513	43E892	6061 768373	ALENA BORISOVA	{"phone": "+70937012803"}
0005434173514	61BCE0	9306 960297	SERGEY BORISOV	{"phone": "+70234651113"}
0005434173515	201352	0266 161831	VALERIY ISAEV	{"phone": "+70290754426"}
0005434173516	201352	9997 965077	ALEKSANDR MAKSIMOV	{"email": "a_maksimov_1979@postgrespro.ru", "phone": "+70358342837"}
0005434173517	1C8630	4619 605347	IRINA LUKYANOVA	{"email": "i.lukyanova-091968@postgrespro.ru", "phone": "+70870987874"}
0005434173518	4780C1	1812 508628	VERONIKA SAVELEVA	{"email": "savelevav1968@postgrespro.ru", "phone": "+70504368461"}
0005434173519	338D58	3423 602209	VALENTIN VOROBEV	{"phone": "+70149873218"}
0005434173520	D2B325	3429 773221	LYUBOV PETROVA	{"phone": "+70567811787"}
0005434173521	E31C62	6529 927196	OLGA KOZLOVA	{"email": "kozlovaolga-1977@postgrespro.ru", "phone": "+70696550630"}
0005434173522	B7B0C6	4406 048060	NIKOLAY GERASIMOV	{"email": "n-gerasimov-101977@postgrespro.ru", "phone": "+70554933848"}
0005434173523	B7B0C6	8962 109914	VLADIMIR VOROBEV	{"email": "vorobev.vladimir-1961@postgrespro.ru", "phone": "+70454897466"}
0005434173524	6829BA	0069 285834	NIKITA SIDOROV	{"email": "sidorov-nikita091973@postgrespro.ru", "phone": "+70847613677"}
0005434173525	295997	2774 810568	YURIY KOZLOV	{"email": "y.kozlov_04021963@postgrespro.ru", "phone": "+70919273975"}
0005434173526	5CF68A	4224 007078	RIMMA KUDRYASHOVA	{"phone": "+70190699293"}
0005434173527	F75166	9358 629506	NADEZHDA KONDRATEVA	{"email": "kondrateva-n.1971@postgrespro.ru", "phone": "+70702159261"}
0005434173528	FDE83A	2894 359030	ANATOLIY GRIGOREV	{"email": "grigorevanatoliy-1970@postgrespro.ru", "phone": "+70228248896"}
0005434173529	FDE83A	3686 132731	SVETLANA TIMOFEEVA	{"phone": "+70193906953"}
0005434173530	FDE83A	6008 745289	ALEKSANDR KISELEV	{"phone": "+70518978149"}
0005434173531	4D27CE	6862 087644	NADEZHDA GUSEVA	{"phone": "+70264779370"}
0005434173532	4D27CE	5926 034371	ANDREY BELOV	{"email": "belov_andrey.24051981@postgrespro.ru", "phone": "+70019322822"}
0005434173534	FFA84D	7969 567765	SVETLANA BELOVA	{"email": "s_belova-041977@postgrespro.ru", "phone": "+70941036049"}
0005434173535	B98936	4669 612100	OKSANA FEDOROVA	{"email": "fedorova_o081971@postgrespro.ru", "phone": "+70022945112"}
0005434173536	1BBB79	0879 126743	EKATERINA YAKOVLEVA	{"email": "yakovleva.ekaterina_101974@postgrespro.ru", "phone": "+70452812442"}
0005434173537	1BBB79	2619 604483	LYUBOV MIKHAYLOVA	{"email": "lyubov.mikhaylova.021979@postgrespro.ru", "phone": "+70658104477"}
0005434173538	8FA726	8002 390039	EVGENIY SIDOROV	{"phone": "+70309902087"}
0005434173539	C82F20	9700 321333	ALEKSEY TIKHONOV	{"email": "a_tikhonov-061980@postgrespro.ru", "phone": "+70964348104"}
0005434173540	FEE58C	5814 205837	TATYANA DENISOVA	{"email": "tdenisova091973@postgrespro.ru", "phone": "+70421299512"}
0005434173541	1CD1CF	3998 274034	DMITRIY IVANOV	{"email": "ivanov_dmitriy.1976@postgrespro.ru", "phone": "+70305742008"}
0005434173542	1CD1CF	4668 803527	VERA KISELEVA	{"email": "kiseleva_v061980@postgrespro.ru", "phone": "+70299564954"}
0005434173543	04F170	1499 131376	ANDREY IVANOV	{"email": "andrey.ivanov-23021970@postgrespro.ru", "phone": "+70234557968"}
0005434173544	04F170	5459 763429	EVGENIY MIKHAYLOV	{"phone": "+70298243586"}
0005434173545	04F170	3095 952163	ANNA MOROZOVA	{"phone": "+70985144811"}
0005434173546	ABB3D8	2281 628973	IVAN KULIKOV	{"phone": "+70853481848"}
0005434173547	AD9EDB	4210 905000	VYACHESLAV MIKHAYLOV	{"phone": "+70356003830"}
0005434173548	AD9EDB	1012 542119	YULIYA ZAYCEVA	{"email": "zayceva-y031968@postgrespro.ru", "phone": "+70233671070"}
0005434173549	3AD6F4	2592 848128	RINAT SAVELEV	{"phone": "+70074315853"}
0005434173550	6A1FBD	1704 194408	TAMARA POTAPOVA	{"email": "tpotapova-1977@postgrespro.ru", "phone": "+70693260198"}
0005434173551	6A1FBD	3031 649768	ALEKSANDR ANDREEV	{"email": "andreev_a1981@postgrespro.ru", "phone": "+70047294576"}
0005434173552	7C8C30	2127 066242	PAVEL PETROV	{"email": "p-petrov_19071979@postgrespro.ru", "phone": "+70899897894"}
0005434173553	CE2B71	0695 795914	NINA KAZAKOVA	{"phone": "+70007602867"}
0005434173554	CE2B71	2596 504950	YULIYA IVANOVA	{"email": "ivanova.y_031974@postgrespro.ru", "phone": "+70611581182"}
0005434173555	2CC2ED	7987 417654	FANIL TIKHONOV	{"phone": "+70992817926"}
0005434173556	2CC2ED	6596 070567	NATALYA VLASOVA	{"phone": "+70108222861"}
0005434173557	A2B668	0133 298021	SERGEY ROMANOV	{"email": "romanov_s.24011977@postgrespro.ru", "phone": "+70669917844"}
0005434173558	8C4637	0740 871163	EKATERINA ALEKSANDROVA	{"email": "ekaterina-aleksandrova.03111973@postgrespro.ru", "phone": "+70585824616"}
0005434173559	8C4637	2433 147287	IRINA KUZNECOVA	{"email": "irina_kuznecova.031975@postgrespro.ru", "phone": "+70216773952"}
0005434173560	95BDA0	3741 645936	RAISA KOZLOVA	{"email": "kozlovar_1972@postgrespro.ru", "phone": "+70577848368"}
0005434173561	95BDA0	2376 349963	VALENTINA MELNIKOVA	{"phone": "+70109673299"}
0005434173562	95BDA0	6909 691035	MIKHAIL SOKOLOV	{"phone": "+70897449368"}
0005434173563	95BDA0	9347 384043	KIRILL ZHURAVLEV	{"email": "zhuravlev_kirill_071973@postgrespro.ru", "phone": "+70503185310"}
0005434173564	289A59	9942 120700	SVETLANA SOKOLOVA	{"phone": "+70515138632"}
0005434173565	289A59	7762 971690	VLADISLAV MOROZOV	{"email": "morozovv1972@postgrespro.ru", "phone": "+70006530402"}
0005434173566	EBB6D5	6849 059668	LYUDMILA MASLOVA	{"email": "maslova_lyudmila-031977@postgrespro.ru", "phone": "+70051428946"}
0005434173567	E1E68E	5980 204480	ALEKSANDR KUZNECOV	{"phone": "+70429959255"}
0005434173568	E1E68E	6022 711135	EKATERINA KUZNECOVA	{"phone": "+70304433002"}
0005434173569	34C307	9115 102004	ALEKSANDR FROLOV	{"email": "a.frolov_101978@postgrespro.ru", "phone": "+70403345222"}
0005434173570	7BF785	0913 492838	MARIYA SOKOLOVA	{"phone": "+70550244500"}
0005434173571	593DFC	0963 638364	LYUDMILA SMIRNOVA	{"phone": "+70806968311"}
0005434173572	EC566A	9417 211767	GALINA NAUMOVA	{"email": "naumovagalina_1985@postgrespro.ru", "phone": "+70643174926"}
0005434173573	261616	6610 636381	NATALYA PAVLOVA	{"phone": "+70935601115"}
0005434173574	DC315C	9852 338826	MARINA FOMINA	{"phone": "+70024881227"}
0005434173575	1D8052	2140 546865	VADIM NAZAROV	{"phone": "+70325825148"}
0005434173576	1D8052	0458 282132	VALENTINA TIKHONOVA	{"email": "tikhonova_v_1981@postgrespro.ru", "phone": "+70623866992"}
0005434173577	29032D	0638 750770	TATYANA KUZNECOVA	{"email": "kuznecova.t011974@postgrespro.ru", "phone": "+70306339325"}
0005434173578	29032D	6966 964650	SERGEY KRASNOV	{"phone": "+70914584994"}
0005434173579	4A202F	7224 117928	ANASTASIYA KALININA	{"email": "a.kalinina-081976@postgrespro.ru", "phone": "+70099286283"}
0005434173580	95810F	6648 688315	RAUZA EFIMOVA	{"email": "r_efimova1972@postgrespro.ru", "phone": "+70177700583"}
0005434173581	95810F	3944 658231	NIKITA MELNIKOV	{"phone": "+70933004668"}
0005434173582	CE6757	4135 156633	SERGEY SOLOVEV	{"phone": "+70013187623"}
0005434173583	707919	6310 755882	NATALIYA KONDRATEVA	{"email": "nataliyakondrateva-08081975@postgrespro.ru", "phone": "+70691338385"}
0005434173584	4F26A5	0175 327142	SVETLANA BORISOVA	{"phone": "+70480122652"}
0005434173585	2D7513	1271 860396	YURIY IVANOV	{"phone": "+70835687686"}
0005434173586	719AE2	7991 342966	EVDOKIYA ROMANOVA	{"phone": "+70579257181"}
0005434173587	127C7D	2212 819881	EVGENIY PETROV	{"email": "evgeniypetrov-1985@postgrespro.ru", "phone": "+70985563789"}
0005434173588	A5CAC8	4392 748108	VERA YAKOVLEVA	{"email": "yakovleva.v_111964@postgrespro.ru", "phone": "+70948810759"}
0005434173589	F59A4F	4391 390871	VLADIMIR BELOV	{"phone": "+70303143144"}
0005434173590	F59A4F	0832 301577	ELENA FEDOROVA	{"phone": "+70041987166"}
0005434173591	7191E8	5866 241255	PRASKOVYA IVANOVA	{"email": "ivanova_praskovya-1966@postgrespro.ru", "phone": "+70607261680"}
0005434173592	A93325	5372 496191	ALEKSANDR BARANOV	{"email": "baranovaleksandr-27051975@postgrespro.ru", "phone": "+70218251296"}
0005434173595	3F4333	4020 395000	ALIYA KUZNECOVA	{"email": "a-kuznecova28051970@postgrespro.ru", "phone": "+70548880400"}
0005434173596	3F4333	4284 524922	ALEKSANDR KUZNECOV	{"phone": "+70734625859"}
0005434173597	F5841A	9406 960873	LARISA KULIKOVA	{"email": "kulikova.l-11051978@postgrespro.ru", "phone": "+70071933423"}
0005434173598	0DA870	3585 871505	SERGEY YAKOVLEV	{"phone": "+70925852122"}
0005434173599	B5AFF5	4168 402009	VLADIMIR KRASNOV	{"phone": "+70379513417"}
0005434173600	5F43F0	3798 793359	VALENTINA KRASNOVA	{"phone": "+70970921726"}
0005434173601	5F43F0	6699 013880	KSENIYA FADEEVA	{"email": "k.fadeeva_011977@postgrespro.ru", "phone": "+70651094253"}
0005434173602	5F43F0	5729 517220	ALEKSEY PAVLOV	{"email": "pavlov-aleksey.14081968@postgrespro.ru", "phone": "+70080894166"}
0005434173603	F004A8	2790 567847	VIKTORIYA ZHUKOVA	{"email": "zhukova.v-021977@postgrespro.ru", "phone": "+70588825536"}
0005434173604	F004A8	1132 086375	DENIS MIKHAYLOV	{"email": "mikhaylov.denis-25091971@postgrespro.ru", "phone": "+70028219511"}
0005434173605	F004A8	9404 034926	VALENTINA KISELEVA	{"email": "kiseleva_valentina.28011969@postgrespro.ru", "phone": "+70160183942"}
0005434173606	946DF5	7252 869711	TATYANA PETROVA	{"email": "petrova-tatyana-19111970@postgrespro.ru", "phone": "+70750089189"}
0005434173607	D927DB	3229 266130	TAMARA ZAYCEVA	{"phone": "+70440761873"}
0005434173608	D927DB	7556 401964	OLGA MAKAROVA	{"email": "makarova_o-16101979@postgrespro.ru", "phone": "+70305803582"}
0005434173609	4810A9	4311 063963	ALEKSEY SHEVCHENKO	{"phone": "+70470186235"}
0005434173610	4810A9	4853 337514	VLADIMIR KAZAKOV	{"email": "kazakov.vladimir1980@postgrespro.ru", "phone": "+70037568957"}
0005434173611	4810A9	3837 956509	OLGA ZAYCEVA	{"email": "o-zayceva-1974@postgrespro.ru", "phone": "+70022741529"}
0005434173612	D94E60	0282 727708	ROMAN ABRAMOV	{"phone": "+70242279457"}
0005434173613	6726CA	9880 740099	OLGA KARPOVA	{"email": "o_karpova28111983@postgrespro.ru", "phone": "+70258176780"}
0005434173614	093AAE	9112 545656	ELENA MAKSIMOVA	{"email": "maksimova_elena-27121973@postgrespro.ru", "phone": "+70653956066"}
0005434173615	8F86A3	5014 828450	ANDREY KUZMIN	{"phone": "+70848426320"}
0005434173616	8F86A3	8464 233687	VALERIYA KOROLEVA	{"phone": "+70070495622"}
0005434173617	AC5A1A	5959 742316	TATYANA VOROBEVA	{"phone": "+70227738368"}
0005434173618	AC5A1A	0258 163234	VADIM SAVELEV	{"email": "savelev_v22081980@postgrespro.ru", "phone": "+70586321338"}
0005434173619	52030A	1294 152525	ALEKSANDR KUZNECOV	{"phone": "+70713352887"}
0005434173620	52030A	4783 960129	OLESYA FILATOVA	{"email": "o_filatova.1979@postgrespro.ru", "phone": "+70225574933"}
0005434173621	7BDD86	5546 626025	KARINA POPOVA	{"phone": "+70800247385"}
0005434173622	6D3E49	8716 685621	GALINA MIRONOVA	{"email": "galinamironova1971@postgrespro.ru", "phone": "+70611256009"}
0005434173623	8A8E27	1345 003125	ALEKSANDR ILIN	{"email": "ilin-aleksandr_17111969@postgrespro.ru", "phone": "+70978978605"}
0005434173624	4F5207	4579 509741	NIKOLAY MELNIKOV	{"phone": "+70609067390"}
0005434173625	71F961	9040 228691	ANGELINA KOZLOVA	{"phone": "+70899122592"}
0005434173626	9794F3	2245 180459	DENIS ZHURAVLEV	{"phone": "+70871884715"}
0005434173627	9794F3	2083 011200	TAMARA BORISOVA	{"phone": "+70317408061"}
0005434173628	21D326	0899 576253	VALERIY MATVEEV	{"phone": "+70672713548"}
0005434173629	A1EAFE	8211 211818	SERGEY FROLOV	{"phone": "+70987530049"}
0005434173630	16A99C	0533 937027	TATYANA MATVEEVA	{"email": "tatyanamatveeva_051965@postgrespro.ru", "phone": "+70722695787"}
0005434173631	16A99C	0969 530262	VALENTINA KUZMINA	{"email": "v_kuzmina-021976@postgrespro.ru", "phone": "+70667224574"}
0005434173632	740C54	3337 124798	IGOR SCHERBAKOV	{"email": "scherbakov-igor-051973@postgrespro.ru", "phone": "+70070422077"}
0005434173633	740C54	2047 276950	LYUDMILA DAVYDOVA	{"phone": "+70172316673"}
0005434173634	3F85A2	6627 767733	ALENA SIDOROVA	{"email": "sidorovaalena22121977@postgrespro.ru", "phone": "+70004348195"}
0005434173635	AF2E97	5042 592250	VASILIY SEMENOV	{"phone": "+70136699123"}
0005434173636	ABF61A	1444 613123	LARISA IVANOVA	{"phone": "+70055076678"}
0005434173637	19BD6F	0633 087392	MARINA TROFIMOVA	{"email": "m.trofimova1975@postgrespro.ru", "phone": "+70121181273"}
0005434173638	B33CBD	1842 444445	MARAT IVANOV	{"email": "ivanov.marat1975@postgrespro.ru", "phone": "+70395308106"}
0005434173639	B33CBD	3467 455314	ALEVTINA KARPOVA	{"phone": "+70391906282"}
0005434173640	B33CBD	7021 831620	YULIYA ROMANOVA	{"phone": "+70202244235"}
0005434173641	4B2896	1715 845508	SERGEY SMIRNOV	{"email": "s_smirnov_1966@postgrespro.ru", "phone": "+70570564455"}
0005434173642	23C1FE	7150 342318	SERGEY SIDOROV	{"email": "sidorov-sergey30081968@postgrespro.ru", "phone": "+70160892149"}
0005434173643	ECF162	7437 452289	SERGEY KUZMIN	{"email": "kuzmin-sergey_23071969@postgrespro.ru", "phone": "+70283956483"}
0005434173644	79E3DE	8527 713793	NINA ANDREEVA	{"phone": "+70996167617"}
0005434173645	248D5C	0459 501884	GLEB VOROBEV	{"email": "vorobev.gleb-1976@postgrespro.ru", "phone": "+70890418571"}
0005434173646	36B02D	9090 860661	VALERIY KUDRYASHOV	{"email": "kudryashov_v18101964@postgrespro.ru", "phone": "+70389310055"}
0005434173647	36B02D	9484 981640	YURIY POPOV	{"email": "popov.yuriy011974@postgrespro.ru", "phone": "+70933615146"}
0005434173648	2CAAA6	8533 700292	SERGEY KUZNECOV	{"phone": "+70792363680"}
0005434173649	B975C6	7600 227416	ARTEM POPOV	{"phone": "+70521956051"}
0005434173650	0ADE1E	8596 535578	GALINA NAUMOVA	{"phone": "+70884220921"}
0005434173651	019FE1	5059 816275	OLGA ZHUKOVA	{"phone": "+70966339649"}
0005434173652	019FE1	4849 365352	ANDREY GORBUNOV	{"phone": "+70600888660"}
0005434173653	B472D3	0689 483848	ELIZAVETA MIKHAYLOVA	{"email": "mikhaylova-e-1986@postgrespro.ru", "phone": "+70620653276"}
0005434173654	1A5B4B	4252 053673	NATALYA KISELEVA	{"phone": "+70343958331"}
0005434175784	6C31E2	0781 008903	VALENTINA ZAKHAROVA	{"phone": "+70951593725"}
0005434173655	1A5B4B	5249 703163	LYUBOV SAVELEVA	{"email": "lyubov-saveleva-13061965@postgrespro.ru", "phone": "+70058397124"}
0005434173656	AF3890	2884 846342	SERGEY SOKOLOV	{"phone": "+70478738620"}
0005434173657	E5DDD9	1857 957440	GALINA IVANOVA	{"phone": "+70936835184"}
0005434173658	E5DDD9	4890 295135	SEMEN VOLKOV	{"email": "volkov.s_061974@postgrespro.ru", "phone": "+70346501720"}
0005434173659	7CB609	8414 495312	KAMILA GRISHINA	{"email": "grishina.k-1972@postgrespro.ru", "phone": "+70309414001"}
0005434173660	D88C00	1772 869348	ILYA FROLOV	{"phone": "+70668297612"}
0005434173661	E5A373	9264 414398	EVGENIY FEDOTOV	{"phone": "+70520496180"}
0005434173662	F1C8C0	5190 900550	ELENA SOROKINA	{"email": "sorokina.elena-1970@postgrespro.ru", "phone": "+70714918425"}
0005434173663	F1C8C0	7724 265586	OLGA DANILOVA	{"email": "danilova.o-1962@postgrespro.ru", "phone": "+70235295826"}
0005434173664	400AC9	5670 597419	DANILA BORISOV	{"email": "borisov.danila25031978@postgrespro.ru", "phone": "+70476054455"}
0005434173665	682EB2	0267 640446	VIOLETTA ANDREEVA	{"phone": "+70588047399"}
0005434173666	682EB2	7256 582786	DENIS SEMENOV	{"phone": "+70607491814"}
0005434173667	ADCDB6	5523 069869	TATYANA SERGEEVA	{"email": "tsergeeva1976@postgrespro.ru", "phone": "+70222566344"}
0005434175678	E4B80B	8488 432233	VIKTORIYA POPOVA	{"email": "popovav-17101980@postgrespro.ru", "phone": "+70706713432"}
0005434175679	E4B80B	1679 797620	ALEKSEY ORLOV	{"phone": "+70292102951"}
0005434175680	63C070	2487 386019	TAISIYA NIKIFOROVA	{"email": "nikiforova.taisiya-011962@postgrespro.ru", "phone": "+70452819496"}
0005434175681	8B9FEB	0308 136383	KLAVDIYA AFANASEVA	{"phone": "+70030064467"}
0005434175682	8B9FEB	3926 439037	SVETLANA MATVEEVA	{"email": "s_matveeva24091964@postgrespro.ru", "phone": "+70409209876"}
0005434175683	37BCED	0848 690690	MARINA KARPOVA	{"email": "karpovamarina.22081982@postgrespro.ru", "phone": "+70555844746"}
0005434175684	B59D9B	3150 870478	VALERIYA GUSEVA	{"email": "valeriya.guseva-121972@postgrespro.ru", "phone": "+70475175408"}
0005434175685	B59D9B	3751 592859	IRINA KOZLOVA	{"email": "kozlova_irina05121980@postgrespro.ru", "phone": "+70502054061"}
0005434175686	F7D9A4	5306 557544	NINA ZAKHAROVA	{"email": "n.zakharova_1978@postgrespro.ru", "phone": "+70014097234"}
0005434175687	FEED23	6863 497917	KONSTANTIN SCHERBAKOV	{"phone": "+70691506974"}
0005434175688	88ADF5	7066 084675	SERGEY GAVRILOV	{"phone": "+70249856349"}
0005434175689	F6DB95	4351 282070	IGOR CHERNOV	{"email": "i_chernov.1976@postgrespro.ru", "phone": "+70043644271"}
0005434175690	5A373C	3683 656618	NATALYA NAZAROVA	{"phone": "+70405369595"}
0005434175691	4AFDA2	6500 087371	MAKSIM CHERNOV	{"phone": "+70489077852"}
0005434175692	4AFDA2	3086 574469	ANDREY ANTONOV	{"email": "a-antonov.101974@postgrespro.ru", "phone": "+70501609874"}
0005434175693	4C8AA4	7642 883881	ELENA TIKHONOVA	{"phone": "+70407926475"}
0005434175694	B8A579	2227 915634	ELENA SERGEEVA	{"phone": "+70494889037"}
0005434175695	BCA7BE	0587 486035	LYUBOV KISELEVA	{"email": "l-kiseleva20121971@postgrespro.ru", "phone": "+70109658346"}
0005434175696	6AF419	9618 352450	MAKSIM BELOV	{"phone": "+70860098729"}
0005434175697	6AF419	2859 188697	BORIS KUZNECOV	{"phone": "+70812222156"}
0005434175698	161A50	8933 268276	MAKSIM MIRONOV	{"phone": "+70333869207"}
0005434175699	99B28D	4425 732921	ALENA KRASNOVA	{"email": "alena_krasnova_01071964@postgrespro.ru", "phone": "+70770154800"}
0005434175700	0ADE91	5473 068257	ALEKSANDR MAKSIMOV	{"phone": "+70251791443"}
0005434175701	6EFF9E	7569 440528	VLADIMIR SMIRNOV	{"phone": "+70139916505"}
0005434175702	24BB4D	5549 245396	GALINA KUZNECOVA	{"email": "galinakuznecova.28011976@postgrespro.ru", "phone": "+70523072146"}
0005434175703	9463BA	9336 453301	ANDREY ZAYCEV	{"email": "zaycev.andrey-1961@postgrespro.ru", "phone": "+70524688254"}
0005434175704	89281B	4930 737334	LYUDMILA NESTEROVA	{"phone": "+70180951347"}
0005434175705	FCE1CC	6665 034630	NATALYA MOISEEVA	{"email": "moiseeva.natalya.29051968@postgrespro.ru", "phone": "+70048112329"}
0005434175706	FCE1CC	6533 867919	VALERIY RODIONOV	{"phone": "+70627856314"}
0005434175707	FCE1CC	7922 016729	MARINA KOZLOVA	{"phone": "+70784237361"}
0005434175708	4B7E7B	3530 724225	NIKOLAY VOROBEV	{"email": "vorobev-n01081965@postgrespro.ru", "phone": "+70986749355"}
0005434175709	4B7E7B	1073 072305	OLGA GAVRILOVA	{"phone": "+70646144270"}
0005434175710	BED719	7386 930437	KSENIYA ABRAMOVA	{"phone": "+70072749763"}
0005434175711	CBE8A6	5786 944447	SERGEY SCHERBAKOV	{"phone": "+70467941590"}
0005434175712	1D766D	9817 418460	VALENTINA PETROVA	{"email": "valentina-petrova01091974@postgrespro.ru", "phone": "+70018730008"}
0005434175713	1D766D	8792 729574	VALENTINA IVANOVA	{"phone": "+70663868449"}
0005434175714	FB65AA	5215 968769	ARTEM NIKOLAEV	{"email": "nikolaev.artem1982@postgrespro.ru", "phone": "+70056413442"}
0005434175715	AD1080	4117 527000	VLADIMIR FEDOTOV	{"phone": "+70196140023"}
0005434175716	6FF405	2309 396919	PAVEL KUZNECOV	{"email": "kuznecovpavel-101970@postgrespro.ru", "phone": "+70599579526"}
0005434175717	10DE0B	2527 890840	MARIYA DMITRIEVA	{"phone": "+70864480749"}
0005434175718	10DE0B	9925 285594	LARISA BORISOVA	{"email": "borisova_larisa-20051972@postgrespro.ru", "phone": "+70369688078"}
0005434175719	E2BAB8	0601 209415	OLGA MIRONOVA	{"phone": "+70912209867"}
0005434175720	EC5153	2684 086607	NATALYA IVANOVA	{"email": "natalyaivanova-21071970@postgrespro.ru", "phone": "+70916430033"}
0005434175721	2CD0F6	6335 559568	VALENTINA KOZLOVA	{"email": "kozlova.v06091974@postgrespro.ru", "phone": "+70067669703"}
0005434175722	2CD0F6	9586 429717	ALEKSANDR MAKAROV	{"phone": "+70562004198"}
0005434175723	2CD0F6	0369 136840	POLINA STEPANOVA	{"phone": "+70063947264"}
0005434175724	9D020C	3835 489802	MIKHAIL SEMENOV	{"email": "mikhail-semenov07031973@postgrespro.ru", "phone": "+70593130413"}
0005434175725	77D1D1	3307 373319	VLADIMIR DENISOV	{"email": "vladimirdenisov_1970@postgrespro.ru", "phone": "+70709108924"}
0005434175726	DE9AAA	9912 336416	RAZIYA DMITRIEVA	{"email": "dmitrieva-raziya_20111975@postgrespro.ru", "phone": "+70880006953"}
0005434175727	148871	9609 964878	VALENTINA SOROKINA	{"phone": "+70980682956"}
0005434175728	148871	4757 851657	DMITRIY DMITRIEV	{"email": "dmitrievdmitriy.20091970@postgrespro.ru", "phone": "+70463004167"}
0005434175729	A2345C	3838 246471	ROMAN KULIKOV	{"email": "r.kulikov_1970@postgrespro.ru", "phone": "+70281727013"}
0005434175730	00C45C	8913 140009	DANILA KOROLEV	{"email": "korolevdanila.051965@postgrespro.ru", "phone": "+70830260622"}
0005434175731	600100	3704 352564	LIDIYA FILATOVA	{"phone": "+70217029595"}
0005434175732	FB55D4	5690 289672	GALIYA MOROZOVA	{"phone": "+70261940475"}
0005434175733	913A07	7140 656553	MARGARITA CHERNOVA	{"email": "mchernova_25071982@postgrespro.ru", "phone": "+70795322624"}
0005434175734	34C856	2476 012034	NADEZHDA NIKIFOROVA	{"phone": "+70831655857"}
0005434175735	34C856	3696 386048	YURIY KONOVALOV	{"phone": "+70815250823"}
0005434175736	ED0F9E	3291 592336	MIKHAIL STEPANOV	{"email": "stepanov_mikhail-1978@postgrespro.ru", "phone": "+70672926300"}
0005434175737	168AC8	1976 545918	NIKOLAY STEPANOV	{"email": "stepanov_n-1983@postgrespro.ru", "phone": "+70980493109"}
0005434175738	39B090	4623 826429	MAKSIM ISAEV	{"phone": "+70490355256"}
0005434175739	39B090	2731 884458	MARIYA ALEKSEEVA	{"email": "alekseeva-mariya-05051973@postgrespro.ru", "phone": "+70170564523"}
0005434175740	7CCBDA	1375 358574	OLEG OSIPOV	{"email": "o_osipov_1968@postgrespro.ru", "phone": "+70517213287"}
0005434175741	68AE98	7409 772153	VITALIY KUZMIN	{"email": "kuzminvitaliy_1959@postgrespro.ru", "phone": "+70494078134"}
0005434175742	13E65A	5680 922114	MARINA ZAKHAROVA	{"phone": "+70788517084"}
0005434175743	13E65A	0816 633262	VALENTINA IVANOVA	{"phone": "+70745020047"}
0005434175744	5F2956	5935 587729	EKATERINA PETROVA	{"phone": "+70439592567"}
0005434175745	5F2956	3454 089781	VLADIMIR SOKOLOV	{"email": "v-sokolov_25021966@postgrespro.ru", "phone": "+70525610958"}
0005434175746	20816B	1357 866922	VLADIMIR KUDRYASHOV	{"phone": "+70725593528"}
0005434175747	6ED3CC	3944 368718	GULNARA VASILEVA	{"email": "vasileva_gulnara.091978@postgrespro.ru", "phone": "+70805348751"}
0005434175748	89F817	4441 628822	NADEZHDA KUZMINA	{"email": "n_kuzmina.011976@postgrespro.ru", "phone": "+70064317948"}
0005434175749	89F817	0694 185769	VASILIY ALEKSEEV	{"email": "vasiliyalekseev1971@postgrespro.ru", "phone": "+70790801520"}
0005434175750	6098D2	3040 766954	KONSTANTIN MAKAROV	{"phone": "+70322109974"}
0005434175751	6098D2	9932 714565	DENIS VOLKOV	{"email": "volkovd.10071974@postgrespro.ru", "phone": "+70171742810"}
0005434175752	FF9594	6419 040969	ANDREY KULIKOV	{"email": "andrey-kulikov.121981@postgrespro.ru", "phone": "+70824361027"}
0005434175753	5C2D12	0680 811368	SERGEY KAZAKOV	{"email": "kazakov_sergey-03111974@postgrespro.ru", "phone": "+70848052057"}
0005434175754	E2A35C	7834 445803	NATALYA MOROZOVA	{"phone": "+70704570785"}
0005434175755	0318A8	9607 879926	DIANA NAUMOVA	{"email": "naumova-diana.031975@postgrespro.ru", "phone": "+70527515074"}
0005434175756	22B4FD	9236 708014	LYUBOV DMITRIEVA	{"phone": "+70920667431"}
0005434175813	E85E21	7062 767521	TATYANA NESTEROVA	{"phone": "+70825696005"}
0005434175757	22B4FD	2037 679665	KONSTANTIN NAZAROV	{"email": "nazarov.konstantin-041973@postgrespro.ru", "phone": "+70716690259"}
0005434175758	9570EB	3879 587303	SVETLANA MOROZOVA	{"email": "s_morozova_1972@postgrespro.ru", "phone": "+70407744596"}
0005434175759	3AACC0	6836 928280	GLEB KUDRYASHOV	{"phone": "+70372481714"}
0005434175760	5849AB	7602 179440	SERGEY KAZAKOV	{"phone": "+70405766235"}
0005434175761	AB844C	2322 164997	SERGEY SIDOROV	{"email": "s-sidorov19061985@postgrespro.ru", "phone": "+70590793031"}
0005434175762	AB844C	5536 330238	MATRENA ABRAMOVA	{"email": "m.abramova.03031979@postgrespro.ru", "phone": "+70602721847"}
0005434175763	467C80	2348 626603	VLADIMIR KARPOV	{"phone": "+70959792751"}
0005434175764	A72801	3196 557024	LYUBOV MATVEEVA	{"phone": "+70225477028"}
0005434175765	0A6397	6881 135927	SVETLANA TITOVA	{"phone": "+70223929571"}
0005434175766	708A1E	0919 823763	ANDREY ZHUKOV	{"email": "zhukov-a011964@postgrespro.ru", "phone": "+70585356109"}
0005434175767	679C52	4967 488284	VADIM TARASOV	{"email": "tarasovvadim07111953@postgrespro.ru", "phone": "+70007226903"}
0005434175768	081967	0248 415685	YULIYA MIRONOVA	{"phone": "+70329740981"}
0005434175769	9B8EB2	4396 876948	ALEKSEY NIKITIN	{"email": "nikitin-aleksey101974@postgrespro.ru", "phone": "+70035028308"}
0005434175770	9B8EB2	9516 133592	MARIYA LOGINOVA	{"email": "loginovamariya_05051979@postgrespro.ru", "phone": "+70924690602"}
0005434175771	5F4904	8473 927362	MAKSIM TIKHONOV	{"email": "tikhonov.m_1960@postgrespro.ru", "phone": "+70483885345"}
0005434175772	5F4904	6923 908977	ANDREY AFANASEV	{"email": "andreyafanasev1985@postgrespro.ru", "phone": "+70955116565"}
0005434175773	8CEE39	7477 660226	OLGA KOROLEVA	{"email": "korolevaolga1967@postgrespro.ru", "phone": "+70813405371"}
0005434175774	E9C8CE	5187 436293	SERGEY ANTONOV	{"phone": "+70062274963"}
0005434175775	8854CB	5445 984587	MAKSIM EGOROV	{"phone": "+70326877046"}
0005434175776	8854CB	7032 084888	ALEKSEY RODIONOV	{"phone": "+70073857875"}
0005434175777	109193	1586 350737	ELMIRA POPOVA	{"email": "e.popova22121972@postgrespro.ru", "phone": "+70831014581"}
0005434175778	109193	1479 812241	IGOR FEDOTOV	{"email": "ifedotov_05061975@postgrespro.ru", "phone": "+70838743660"}
0005434175779	C54A56	6226 114083	ALSU YAKOVLEVA	{"phone": "+70958687923"}
0005434175780	5AD609	0666 136807	ALINA ERMAKOVA	{"email": "alinaermakova_1971@postgrespro.ru", "phone": "+70259077343"}
0005434175781	8DD8D7	9257 665325	NIKOLAY NAZAROV	{"email": "nikolay_nazarov-1959@postgrespro.ru", "phone": "+70642855227"}
0005434175782	8DD8D7	2734 146429	NINA KISELEVA	{"phone": "+70077320847"}
0005434175783	6C31E2	9612 296264	ANDREY MELNIKOV	{"email": "melnikov_andrey_1975@postgrespro.ru", "phone": "+70622852044"}
0005434175785	1FABA7	4703 076833	SVETLANA ZHURAVLEVA	{"email": "svetlana-zhuravleva12091973@postgrespro.ru", "phone": "+70232151626"}
0005434175786	1DC74B	5884 267992	EVGENIY VASILEV	{"phone": "+70417624136"}
0005434175787	1DC74B	5074 053289	VALERIY EGOROV	{"email": "egorov_v-011972@postgrespro.ru", "phone": "+70817490907"}
0005434175788	BEF815	2384 799409	NIKOLAY MOROZOV	{"phone": "+70953209421"}
0005434175789	BEF815	6525 322578	ANNA NAUMOVA	{"email": "naumova-a.1962@postgrespro.ru", "phone": "+70262671371"}
0005434175790	645668	1779 682966	SERGEY AFANASEV	{"phone": "+70365401259"}
0005434175791	B07FEA	0188 932533	EKATERINA ANTONOVA	{"email": "antonovae-071965@postgrespro.ru", "phone": "+70789520766"}
0005434175792	D3A93D	7692 628325	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey011979@postgrespro.ru", "phone": "+70413850022"}
0005434175793	D3A93D	3205 668447	TAMARA KISELEVA	{"email": "tamara-kiseleva_071970@postgrespro.ru", "phone": "+70640737675"}
0005434175794	A069B2	5636 041273	ANASTASIYA NESTEROVA	{"phone": "+70278313661"}
0005434175795	A069B2	3061 198298	VALENTINA MAKSIMOVA	{"email": "maksimova_v17111976@postgrespro.ru", "phone": "+70045944183"}
0005434175796	05F983	0989 306405	LYUDMILA NOVIKOVA	{"email": "l_novikova021973@postgrespro.ru", "phone": "+70961037186"}
0005434175797	05F983	4869 715161	GRIGORIY PETROV	{"phone": "+70401314903"}
0005434175798	6F7CFA	9219 164775	LIDIYA VOROBEVA	{"phone": "+70692829064"}
0005434175799	6F7CFA	0126 820032	NIKOLAY DENISOV	{"email": "n_denisov15061980@postgrespro.ru", "phone": "+70469212284"}
0005434175800	FEAAB9	1165 356951	VYACHESLAV ANDREEV	{"phone": "+70176615235"}
0005434175801	FEAAB9	3435 040357	NADEZHDA LEBEDEVA	{"email": "n-lebedeva-051975@postgrespro.ru", "phone": "+70109681452"}
0005434175802	E384CD	0369 527641	NIKITA FEDOTOV	{"email": "n.fedotov04091966@postgrespro.ru", "phone": "+70670166768"}
0005434175803	B3FCE1	7733 674086	ANTONINA SEMENOVA	{"phone": "+70333238865"}
0005434175804	B3FCE1	6648 152557	ALEKSANDR VOROBEV	{"email": "vorobev-a.1967@postgrespro.ru", "phone": "+70192136949"}
0005434175805	2136C4	2246 331595	ARTEM POPOV	{"email": "popov_artem27101961@postgrespro.ru", "phone": "+70555745214"}
0005434175806	450B83	6328 712333	DMITRIY EGOROV	{"phone": "+70272976366"}
0005434175807	450B83	4296 764995	ELENA NESTEROVA	{"phone": "+70866399078"}
0005434175808	790027	8958 685299	ARTEM KUZNECOV	{"email": "artem-kuznecov.1983@postgrespro.ru", "phone": "+70038814830"}
0005434175809	790027	9927 066207	LYUBOV KARPOVA	{"email": "karpova_l_17061972@postgrespro.ru", "phone": "+70867832570"}
0005434175810	BF1CA7	1933 889620	NINA GUSEVA	{"email": "nguseva-101968@postgrespro.ru", "phone": "+70764564163"}
0005434175811	F3E9EA	1335 475763	VIKTOR ORLOV	{"phone": "+70911186895"}
0005434175812	F3E9EA	6017 013047	KRISTINA TIKHONOVA	{"phone": "+70125956647"}
0005434175814	E85E21	3662 163101	NIKOLAY VOROBEV	{"phone": "+70096286995"}
0005434175815	FE1D93	6537 815469	NATALYA MIKHAYLOVA	{"email": "n_mikhaylova_091975@postgrespro.ru", "phone": "+70043923866"}
0005434175816	4B3493	9320 435092	IRINA ZAKHAROVA	{"email": "i.zakharova-121969@postgrespro.ru", "phone": "+70809151078"}
0005434175817	4B3493	5746 997149	OLGA PETROVA	{"email": "petrova-o.031979@postgrespro.ru", "phone": "+70068598392"}
0005434175818	1E3B35	1442 281199	KONSTANTIN GRIGOREV	{"phone": "+70349533462"}
0005434175819	1E3B35	2417 590146	SOFYA IVANOVA	{"email": "s_ivanova.1969@postgrespro.ru", "phone": "+70335435062"}
0005434175820	1E3B35	6859 198941	ANNA KOVALEVA	{"email": "annakovaleva.061973@postgrespro.ru", "phone": "+70695303034"}
0005434175821	4F368B	1176 436045	NATALIYA CHERNOVA	{"email": "chernova-n-31121965@postgrespro.ru", "phone": "+70194957915"}
0005434175822	07B2D9	9144 275238	NATALYA VOROBEVA	{"phone": "+70584960664"}
0005434175823	F002E8	7345 278078	ANTONINA RODIONOVA	{"phone": "+70072413962"}
0005434175824	3EBEDB	4929 721853	IVAN POPOV	{"phone": "+70979341855"}
0005434175825	B059B1	4188 852669	DENIS KUZNECOV	{"phone": "+70938464570"}
0005434175826	CA3CDB	7074 305977	ANDREY YAKOVLEV	{"phone": "+70902962447"}
0005434175827	CA3CDB	9009 657516	TAISIYA NESTEROVA	{"phone": "+70965813011"}
0005434175828	3FC6A7	0023 607206	ALEKSANDR MEDVEDEV	{"email": "aleksandr-medvedev-11041963@postgrespro.ru", "phone": "+70483602792"}
0005434175829	F6E948	5272 413444	ALEKSANDR ILIN	{"phone": "+70381478953"}
0005434175830	56DC7C	2479 838448	DMITRIY SOLOVEV	{"phone": "+70196260023"}
0005434175831	BA42CD	8504 232949	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov-16071973@postgrespro.ru", "phone": "+70408467580"}
0005434175832	BA42CD	2830 663148	SERGEY POPOV	{"email": "popov_s-24121965@postgrespro.ru", "phone": "+70845433455"}
0005434175833	2BBC51	2118 806520	ALEKSANDRA KOROLEVA	{"phone": "+70956736951"}
0005434175834	F4A853	3008 640998	OLGA DMITRIEVA	{"email": "dmitrieva.o28081968@postgrespro.ru", "phone": "+70734709128"}
0005434175835	D256D4	3875 141108	EVGENIY BONDARENKO	{"phone": "+70775681466"}
0005434175836	2C4A17	6792 714962	TATYANA NAZAROVA	{"phone": "+70463679635"}
0005434175837	2C4A17	0169 996611	MIKHAIL ORLOV	{"email": "orlov-mikhail.1965@postgrespro.ru", "phone": "+70012881190"}
0005434175838	2AD53F	3414 805205	ANDREY IVANOV	{"phone": "+70476189378"}
0005434175839	9FD70E	4407 884722	EVGENIY IVANOV	{"email": "ivanove_061964@postgrespro.ru", "phone": "+70186888645"}
0005434175840	A5CE94	7295 069269	VLADIMIR PETROV	{"email": "petrov-vladimir_1971@postgrespro.ru", "phone": "+70119286328"}
0005434175841	69B3AC	1605 052227	NIKOLAY MELNIKOV	{"email": "n.melnikov_091978@postgrespro.ru", "phone": "+70618311377"}
0005434175842	69B3AC	1052 559047	DENIS MATVEEV	{"phone": "+70823720265"}
0005434175843	69B3AC	2624 956614	ALEKSEY FILIPPOV	{"email": "a.filippov.021973@postgrespro.ru", "phone": "+70333889873"}
0005434175844	3A84F6	9691 497085	OLEG VOLKOV	{"email": "volkov.o23051966@postgrespro.ru", "phone": "+70322897972"}
0005434175845	3A84F6	0579 315663	PAVEL RODIONOV	{"phone": "+70275543194"}
0005434175846	4C42D5	9658 273367	OKSANA ANDREEVA	{"email": "andreeva.o.1978@postgrespro.ru", "phone": "+70374526182"}
0005434175847	EAFF4F	5420 778034	SERGEY KOZLOV	{"phone": "+70888379519"}
0005434175848	EAFF4F	5561 155670	ALEKSEY DAVYDOV	{"email": "davydovaleksey1976@postgrespro.ru", "phone": "+70973273541"}
0005434175849	F30F07	6129 178137	ELENA NOVIKOVA	{"email": "novikova-elena_031975@postgrespro.ru", "phone": "+70481107521"}
0005434175850	F30F07	2019 440040	VLADIMIR MATVEEV	{"email": "v.matveev_1954@postgrespro.ru", "phone": "+70153002859"}
0005434175851	9F6C02	0660 826416	NELLI DANILOVA	{"email": "nelli.danilova-10011972@postgrespro.ru", "phone": "+70869604387"}
0005434175852	B49A8A	6655 263774	ANDREY AFANASEV	{"phone": "+70167871093"}
0005434175853	DE7383	7792 117491	VLADIMIR NIKOLAEV	{"phone": "+70898153433"}
0005434175854	97FF96	3929 068305	VASILIY MEDVEDEV	{"email": "v.medvedev1966@postgrespro.ru", "phone": "+70970811207"}
0005434175855	C213B0	5375 854055	IRINA KRASNOVA	{"email": "krasnovairina_1965@postgrespro.ru", "phone": "+70114142394"}
0005434175856	57EE35	1591 593747	RAISA EFIMOVA	{"phone": "+70201773578"}
0005434175857	57EE35	1081 630328	VALENTINA SMIRNOVA	{"email": "valentina_smirnova19071960@postgrespro.ru", "phone": "+70275890876"}
0005434175858	E57CBA	2339 266097	ELENA KRASNOVA	{"email": "elena.krasnova.23101978@postgrespro.ru", "phone": "+70215749533"}
0005434175859	31AB6A	4362 979615	YULIYA ZAKHAROVA	{"phone": "+70876454264"}
0005434175860	D303C0	9615 973684	YULIYA SOKOLOVA	{"phone": "+70622485740"}
0005434175861	F30E3C	9228 431416	DMITRIY BELOV	{"email": "belov.dmitriy-061971@postgrespro.ru", "phone": "+70489365265"}
0005434175862	F30E3C	4748 945549	SERGEY KUZNECOV	{"phone": "+70925113641"}
0005434175863	0D53FC	0493 188903	VASILIY YAKOVLEV	{"phone": "+70739749145"}
0005434175864	4CA994	1991 516442	ANATOLIY ORLOV	{"phone": "+70519224605"}
0005434175865	4CA994	0318 509636	KLAVDIYA FADEEVA	{"email": "fadeevaklavdiya.28091982@postgrespro.ru", "phone": "+70626040871"}
0005434175866	037250	1778 230739	ROMAN SCHERBAKOV	{"email": "scherbakov-roman121974@postgrespro.ru", "phone": "+70341707570"}
0005434175867	B47488	3799 543611	ELENA VOLKOVA	{"email": "e_volkova1965@postgrespro.ru", "phone": "+70515184275"}
0005434175868	9DC844	9913 577790	VARVARA AKIMOVA	{"email": "v.akimova_011973@postgrespro.ru", "phone": "+70804834435"}
0005434175869	1A751D	2744 772789	ALEKSANDR EGOROV	{"phone": "+70681388295"}
0005434175870	1A751D	1643 619624	KONSTANTIN VASILEV	{"phone": "+70469404081"}
0005434175871	426FAE	2983 971408	YURIY SEMENOV	{"email": "semenov-yuriy13071984@postgrespro.ru", "phone": "+70950158560"}
0005434175872	FEC5E0	8215 096859	KSENIYA NIKITINA	{"phone": "+70249631331"}
0005434175873	726EA3	7715 467946	VALENTINA YAKOVLEVA	{"email": "v-yakovleva-05091983@postgrespro.ru", "phone": "+70462421257"}
0005434175874	CE49CE	2318 798381	MARGARITA MIKHAYLOVA	{"email": "mikhaylova_margarita-071974@postgrespro.ru", "phone": "+70589176130"}
0005434175875	CE49CE	2231 898748	EKATERINA ROMANOVA	{"phone": "+70472140500"}
0005434175876	5D1A7B	2745 830780	EKATERINA LOGINOVA	{"email": "e.loginova.121971@postgrespro.ru", "phone": "+70034077992"}
0005434175877	5D1A7B	1540 018330	MARIYA SERGEEVA	{"phone": "+70326033444"}
0005434175878	BAB56E	6889 715795	IGOR MAKSIMOV	{"email": "igor_maksimov.051966@postgrespro.ru", "phone": "+70277007443"}
0005434175879	BAB56E	5100 867207	IRINA ANISIMOVA	{"phone": "+70457367715"}
0005434175880	BAB56E	4542 990564	IGOR KISELEV	{"phone": "+70016915031"}
0005434175881	D60E15	1762 304527	ALEKSANDR ISAEV	{"email": "isaev.aleksandr.1980@postgrespro.ru", "phone": "+70724991043"}
0005434175882	D60E15	4723 488907	LYUBOV NAUMOVA	{"email": "naumova_lyubov_1968@postgrespro.ru", "phone": "+70272904634"}
0005434182008	7E5A4A	9564 671867	EVGENIY MIRONOV	{"phone": "+70818827275"}
0005434181957	698FD0	8539 274291	ALEKSANDR ZAYCEV	{"phone": "+70896615862"}
0005434181958	7D6DAA	3453 632713	SERGEY ALEKSEEV	{"phone": "+70162598293"}
0005434181959	202DEE	3014 635000	ILNUR BORISOV	{"email": "ilnur_borisov_1965@postgrespro.ru", "phone": "+70114828788"}
0005434181960	4F3B83	2241 651783	SERGEY PAVLOV	{"email": "pavlov-sergey.021968@postgrespro.ru", "phone": "+70023044372"}
0005434181961	4F3B83	4466 490991	NIKOLAY IVANOV	{"phone": "+70188000297"}
0005434181962	89744A	3492 400437	SVETLANA GAVRILOVA	{"phone": "+70594292764"}
0005434181963	48B416	8941 099635	ANATOLIY KARPOV	{"phone": "+70701543797"}
0005434181964	48B416	6782 616238	ELENA VASILEVA	{"phone": "+70160703476"}
0005434181965	ABE273	3340 370699	ROMAN POPOV	{"phone": "+70027797747"}
0005434181966	ABE273	0840 568334	PETR KUZNECOV	{"email": "kuznecovp.1974@postgrespro.ru", "phone": "+70678535749"}
0005434181967	E6C8BD	5575 132080	ALEKSEY FILIPPOV	{"email": "filippov-a.041968@postgrespro.ru", "phone": "+70428182751"}
0005434181968	E6C8BD	8042 347275	ALEKSANDR VOROBEV	{"email": "a_vorobev_09121967@postgrespro.ru", "phone": "+70390759833"}
0005434181969	2C96EB	9471 046062	FAINA NIKOLAEVA	{"email": "nikolaeva_faina-22081973@postgrespro.ru", "phone": "+70045925291"}
0005434181970	2C96EB	5207 177664	ANDREY MATVEEV	{"email": "matveevandrey05121964@postgrespro.ru", "phone": "+70753888471"}
0005434181971	B422DF	8767 683919	YURIY KOZLOV	{"phone": "+70855317002"}
0005434181972	A9BDBC	4040 574614	ROMAN PAVLOV	{"phone": "+70408680754"}
0005434181973	A9BDBC	6503 802749	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov.111979@postgrespro.ru", "phone": "+70955304762"}
0005434181974	8439B7	2401 700370	MARK SEMENOV	{"phone": "+70075279577"}
0005434181975	ABAB67	7714 009057	YURIY SMIRNOV	{"email": "smirnovyuriy-19011972@postgrespro.ru", "phone": "+70202564011"}
0005434181976	A05828	7829 032449	GALINA SMIRNOVA	{"phone": "+70263117963"}
0005434181977	31F0B8	7956 868442	EVA ABRAMOVA	{"phone": "+70196126663"}
0005434181978	6B1479	1342 006556	VLADIMIR POPOV	{"phone": "+70055575930"}
0005434181979	7ADC4D	5917 752413	TATYANA MEDVEDEVA	{"phone": "+70473282163"}
0005434181980	F6D8BC	9321 119581	VITALIY PETROV	{"phone": "+70470530024"}
0005434181981	F38304	9191 890196	VITALIY MATVEEV	{"phone": "+70702427352"}
0005434181982	DE0856	5698 553828	ALEKSEY PAVLOV	{"phone": "+70132898319"}
0005434181983	DE0856	7642 077399	ANNA MIKHAYLOVA	{"email": "mikhaylovaanna021983@postgrespro.ru", "phone": "+70194666473"}
0005434181984	F6D418	0400 903736	VALENTINA BORISOVA	{"phone": "+70091672791"}
0005434181985	3BF193	4005 082919	VALENTINA MOISEEVA	{"email": "valentina-moiseeva_051963@postgrespro.ru", "phone": "+70614021781"}
0005434181986	FF8976	5413 094433	EKATERINA MAKSIMOVA	{"email": "ekaterina.maksimova_1961@postgrespro.ru", "phone": "+70921943699"}
0005434181987	FF8976	2358 785941	MARIYA EGOROVA	{"phone": "+70382173450"}
0005434181988	114977	7104 515946	ALEKSANDR SOKOLOV	{"phone": "+70336554478"}
0005434181989	B80A14	4973 668076	SVETLANA BELOVA	{"phone": "+70571413389"}
0005434181990	B80A14	0057 770900	VLADIMIR EGOROV	{"phone": "+70531771009"}
0005434181991	B80A14	1538 951801	SVETLANA FEDOROVA	{"phone": "+70804318028"}
0005434181992	BA7688	5378 049276	ALINA VASILEVA	{"email": "alinavasileva.1965@postgrespro.ru", "phone": "+70426318349"}
0005434181993	BA7688	5558 916351	YULIYA FILATOVA	{"email": "filatovayuliya-031975@postgrespro.ru", "phone": "+70761830987"}
0005434181994	5DFD5A	0748 934997	EVGENIY SERGEEV	{"email": "sergeev.evgeniy-16021981@postgrespro.ru", "phone": "+70645595228"}
0005434181995	CF1796	2230 917914	YURIY KRASNOV	{"phone": "+70780309705"}
0005434181996	1EFFE3	4805 347187	VALERIY STEPANOV	{"email": "stepanov.valeriy121972@postgrespro.ru", "phone": "+70446640055"}
0005434181997	24DD10	2046 445151	VYACHESLAV IVANOV	{"email": "ivanov-vyacheslav_1971@postgrespro.ru", "phone": "+70523249871"}
0005434181998	24DD10	9244 075036	ALEKSANDR MATVEEV	{"email": "matveeva15051980@postgrespro.ru", "phone": "+70958894500"}
0005434181999	C51E00	3499 777465	DMITRIY FEDOTOV	{"email": "d.fedotov121973@postgrespro.ru", "phone": "+70571598807"}
0005434182000	3DEBBA	2736 134599	VALENTINA VOROBEVA	{"email": "vorobeva-v-081972@postgrespro.ru", "phone": "+70217077950"}
0005434182001	053667	5197 596505	ANGELINA KOROLEVA	{"phone": "+70246493548"}
0005434182002	A689C0	8819 222164	ANNA GUSEVA	{"phone": "+70183540531"}
0005434182003	459D99	1456 162739	EVGENIY SERGEEV	{"email": "e_sergeev_1968@postgrespro.ru", "phone": "+70596346697"}
0005434182004	459D99	1459 945891	DIANA BORISOVA	{"phone": "+70802053077"}
0005434182005	749B95	7894 995345	ANASTASIYA KOROLEVA	{"email": "akoroleva-17081963@postgrespro.ru", "phone": "+70186847923"}
0005434182006	42082B	1008 498224	ANNA IVANOVA	{"phone": "+70120943907"}
0005434182007	50A3D3	3796 187623	TATYANA RODIONOVA	{"phone": "+70104843925"}
0005434182009	0C5E7A	6328 620422	VALENTIN ALEKSEEV	{"email": "valentin-alekseev-1975@postgrespro.ru", "phone": "+70512330906"}
0005434182010	932F5A	8542 345233	NIKOLAY CHERNOV	{"phone": "+70753913289"}
0005434182011	8C9E78	9950 372833	ROMAN PETROV	{"phone": "+70837083450"}
0005434182012	907D4C	0013 640805	ALEKSANDR PAVLOV	{"phone": "+70279895898"}
0005434182013	58AC40	5980 227900	VLADIMIR GAVRILOV	{"phone": "+70316328257"}
0005434182014	D441F4	9217 913421	MARIYA LEBEDEVA	{"phone": "+70914197159"}
0005434182015	D441F4	0906 613097	ALEKSANDR RODIONOV	{"email": "rodionov_aleksandr_061976@postgrespro.ru", "phone": "+70612685930"}
0005434182016	4F27B7	8404 206840	DARYA NIKOLAEVA	{"phone": "+70170115221"}
0005434182017	648CF2	1801 607409	TATYANA NIKIFOROVA	{"phone": "+70801252041"}
0005434182018	D7BB50	7415 705911	YULIYA EGOROVA	{"email": "yuliyaegorova_091959@postgrespro.ru", "phone": "+70307268701"}
0005434182019	334310	2670 295727	LARISA VLASOVA	{"phone": "+70252442747"}
0005434182020	30B70F	1289 712176	VIKTOR SEMENOV	{"phone": "+70879072110"}
0005434182021	30B70F	6332 897073	SERGEY PETROV	{"email": "petrovs-1979@postgrespro.ru", "phone": "+70274418255"}
0005434182022	699F3E	7189 714069	DMITRIY VOROBEV	{"email": "d-vorobev_071989@postgrespro.ru", "phone": "+70050277705"}
0005434182023	699F3E	7594 276262	ANDREY KULIKOV	{"email": "a_kulikov.1981@postgrespro.ru", "phone": "+70648508844"}
0005434182024	537501	7069 434030	NELLI NIKITINA	{"email": "n_nikitina_111976@postgrespro.ru", "phone": "+70710843846"}
0005434182025	537501	7834 053069	MIKHAIL KUZNECOV	{"email": "kuznecov-m_1956@postgrespro.ru", "phone": "+70291015688"}
0005434182026	D4543E	9540 756891	VIKTORIYA VASILEVA	{"phone": "+70049243313"}
0005434182027	6D7865	0671 759707	POLINA BORISOVA	{"email": "borisova-p1967@postgrespro.ru", "phone": "+70788436865"}
0005434182028	11105E	9404 829896	INNA FROLOVA	{"email": "inna_frolova-1971@postgrespro.ru", "phone": "+70964557237"}
0005434182029	119E0C	0350 827432	ALEKSANDR GUSEV	{"phone": "+70520445751"}
0005434182030	F07D79	0378 738234	KRISTINA KUZNECOVA	{"email": "k_kuznecova1961@postgrespro.ru", "phone": "+70002636137"}
0005434182031	F07D79	5087 533699	VALERIY ZAYCEV	{"email": "v_zaycev_011986@postgrespro.ru", "phone": "+70250556583"}
0005434182032	F07D79	8306 842574	NIKOLAY SERGEEV	{"phone": "+70806594365"}
0005434182033	40D953	5971 386675	MARGARITA ABRAMOVA	{"email": "m.abramova031969@postgrespro.ru", "phone": "+70619458407"}
0005434182034	40D953	2132 256457	MAKSIM KOZLOV	{"phone": "+70400042919"}
0005434182035	AE2F40	2399 790244	GALINA PETROVA	{"email": "galinapetrova.16061981@postgrespro.ru", "phone": "+70716652683"}
0005434182036	078EBE	1286 368177	ANASTASIYA KUZNECOVA	{"email": "kuznecova.anastasiya-20021973@postgrespro.ru", "phone": "+70623714482"}
0005434182037	B55D9B	1864 234053	SVETLANA YAKOVLEVA	{"email": "yakovleva_svetlana-03081979@postgrespro.ru", "phone": "+70994272695"}
0005434182038	876AFD	8553 240999	ANTONINA MIRONOVA	{"email": "mironova-a-071962@postgrespro.ru", "phone": "+70503492606"}
0005434182039	876AFD	9759 736957	OLGA MOROZOVA	{"email": "morozova.olga_08061963@postgrespro.ru", "phone": "+70510141044"}
0005434182040	876AFD	2505 885414	POLINA EFREMOVA	{"phone": "+70619982801"}
0005434182041	27E841	4157 773278	GALINA SOROKINA	{"email": "galina_sorokina-18021962@postgrespro.ru", "phone": "+70037030174"}
0005434182042	44A917	9331 620819	OLESYA GORBUNOVA	{"phone": "+70357690194"}
0005434182043	A5B9B3	0362 995260	ANNA GORBUNOVA	{"phone": "+70408203210"}
0005434182044	A5B9B3	2447 908623	ALEKSANDR VASILEV	{"phone": "+70379211849"}
0005434182045	7CF322	1815 039513	VALENTINA MELNIKOVA	{"email": "melnikova-v.27021984@postgrespro.ru", "phone": "+70126632587"}
0005434182046	7D5C66	3606 783417	ALEKSANDRA KUZNECOVA	{"phone": "+70150004167"}
0005434182047	66C681	6147 141407	VASILIY SOKOLOV	{"email": "sokolov.v061982@postgrespro.ru", "phone": "+70478369088"}
0005434182048	DA1098	2519 338803	MILANA MAKAROVA	{"email": "makarova_m.19091972@postgrespro.ru", "phone": "+70550331668"}
0005434182049	DA1098	2675 694228	VIKTOR ZHURAVLEV	{"email": "zhuravlev-viktor.1965@postgrespro.ru", "phone": "+70671093196"}
0005434182050	877EB0	7491 394748	TATYANA TIKHONOVA	{"phone": "+70392066488"}
0005434182051	877EB0	7753 334437	SERGEY GUSEV	{"email": "s_gusev.1969@postgrespro.ru", "phone": "+70206471438"}
0005434182052	643B4A	3288 878621	ALEKSANDRA OSIPOVA	{"phone": "+70513364961"}
0005434182053	6D827D	9462 718252	EKATERINA STEPANOVA	{"email": "stepanova-ekaterina_1973@postgrespro.ru", "phone": "+70157339090"}
0005434182054	6D827D	5512 658941	EVGENIY ALEKSEEV	{"phone": "+70486809085"}
0005434182055	341299	5815 000741	MARIYA AKIMOVA	{"email": "m.akimova10071964@postgrespro.ru", "phone": "+70320795194"}
0005434182056	341299	0885 598891	POLINA MELNIKOVA	{"phone": "+70060062277"}
0005434182057	9B4909	5293 366485	VALENTINA NESTEROVA	{"email": "nesterova_valentina26081980@postgrespro.ru", "phone": "+70310140867"}
0005434182058	819396	4238 992641	SERGEY DAVYDOV	{"phone": "+70817510193"}
0005434182059	819396	8485 578693	VLADIMIR ZAYCEV	{"phone": "+70569805594"}
0005434182060	D77083	7626 855800	ELENA PAVLOVA	{"phone": "+70336046469"}
0005434182061	0BBF0F	6397 111832	YULIYA SERGEEVA	{"email": "y_sergeeva.021966@postgrespro.ru", "phone": "+70052766941"}
0005434182062	A54576	8702 194942	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin23081969@postgrespro.ru", "phone": "+70061594250"}
0005434182063	A54576	7732 916366	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov-1973@postgrespro.ru", "phone": "+70270390431"}
0005434182231	0A6CB0	2216 643161	POLINA NIKOLAEVA	{"phone": "+70546097183"}
0005434182064	A54576	3000 783069	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr.1973@postgrespro.ru", "phone": "+70718631221"}
0005434182065	598AEA	0314 550224	IRINA POTAPOVA	{"phone": "+70394498132"}
0005434182066	598AEA	0004 079767	SERGEY KUZNECOV	{"phone": "+70521364555"}
0005434182067	2A3D69	8215 293874	DINA MIKHAYLOVA	{"email": "dina-mikhaylova1982@postgrespro.ru", "phone": "+70454105570"}
0005434182068	5F6F83	2522 661568	GEORGIY SHEVCHENKO	{"phone": "+70862045853"}
0005434182069	F28FF6	6827 235767	ALEKSANDR ABRAMOV	{"email": "a_abramov-1985@postgrespro.ru", "phone": "+70413501387"}
0005434182070	5BD796	6789 080662	MARIYA BELOVA	{"email": "belova_mariya.02051974@postgrespro.ru", "phone": "+70295315628"}
0005434182071	38F116	9804 803449	VLADIMIR FROLOV	{"phone": "+70121953658"}
0005434182072	EC78DC	2252 876809	IRINA MAKAROVA	{"phone": "+70841707361"}
0005434182073	78177F	1985 713256	NADEZHDA SCHERBAKOVA	{"email": "n_scherbakova.01021968@postgrespro.ru", "phone": "+70902626381"}
0005434182074	78177F	1596 944250	VYACHESLAV IVANOV	{"phone": "+70711411752"}
0005434182075	78177F	8334 742327	NADEZHDA POLYAKOVA	{"email": "polyakova_nadezhda1958@postgrespro.ru", "phone": "+70406364893"}
0005434182076	89BDC2	1798 512400	NINA MAKAROVA	{"phone": "+70522982272"}
0005434182077	504F03	9645 933672	NIKOLAY ZAYCEV	{"email": "nikolay-zaycev17021963@postgrespro.ru", "phone": "+70818028608"}
0005434182078	504F03	4870 021778	VERA ERMAKOVA	{"email": "ermakovavera051962@postgrespro.ru", "phone": "+70135024865"}
0005434182079	F1EBA7	5528 435220	YULIYA NOVIKOVA	{"phone": "+70233528197"}
0005434182080	7D2B68	4381 174324	NIKOLAY MEDVEDEV	{"email": "medvedev_nikolay.041975@postgrespro.ru", "phone": "+70140222685"}
0005434182081	7D2B68	1545 140294	FARID SEMENOV	{"email": "farid.semenov-1985@postgrespro.ru", "phone": "+70524408881"}
0005434182082	E2A336	7827 836051	DMITRIY NIKITIN	{"phone": "+70670747809"}
0005434182083	E2A336	3029 202567	ALEKSANDR DMITRIEV	{"phone": "+70481400009"}
0005434182084	83A571	1922 570215	VASILIY ANDREEV	{"phone": "+70553721888"}
0005434182085	16D30A	7389 587896	ALEKSANDRA PETROVA	{"email": "aleksandra.petrova_041971@postgrespro.ru", "phone": "+70570443396"}
0005434182086	2EB320	7495 847350	IRINA NAZAROVA	{"email": "inazarova11021990@postgrespro.ru", "phone": "+70982665563"}
0005434182087	EAC76D	6318 842053	ALEKSANDRA SOROKINA	{"email": "aleksandrasorokina.13061970@postgrespro.ru", "phone": "+70108354188"}
0005434182088	EBF567	9579 483151	LIDIYA ROMANOVA	{"email": "lidiya_romanova_021964@postgrespro.ru", "phone": "+70732935542"}
0005434182089	8BA40E	2580 181724	ALEKSEY YAKOVLEV	{"phone": "+70548232617"}
0005434182090	A3B288	8205 221685	IRINA SEMENOVA	{"email": "semenova-irina-1968@postgrespro.ru", "phone": "+70017251100"}
0005434182091	0259CE	5136 000932	MADINA KOROLEVA	{"phone": "+70035351841"}
0005434182092	24D7F1	5501 836227	VLADIMIR PETROV	{"phone": "+70030066997"}
0005434182093	24D7F1	1091 598177	RAISA MIKHAYLOVA	{"phone": "+70636360559"}
0005434182094	24D7F1	3610 737425	ANATOLIY FROLOV	{"email": "frolovanatoliy-1967@postgrespro.ru", "phone": "+70995962433"}
0005434182095	5CB697	6956 840627	MARIYA MASLOVA	{"email": "maslovamariya.061965@postgrespro.ru", "phone": "+70202472024"}
0005434182096	A66C84	7101 022942	ROZA POTAPOVA	{"phone": "+70660483562"}
0005434182097	E6456D	5390 301603	NIKITA STEPANOV	{"phone": "+70295010859"}
0005434182098	E6456D	2256 193046	VERA SAVELEVA	{"phone": "+70715857570"}
0005434182099	FCBD79	4363 367670	GENNADIY TARASOV	{"email": "gtarasov1973@postgrespro.ru", "phone": "+70658765295"}
0005434182100	E3950F	8544 719489	EKATERINA SAVELEVA	{"phone": "+70361037788"}
0005434182101	E3950F	9580 356900	IVAN FEDOROV	{"phone": "+70816081609"}
0005434182102	B2F670	9316 916844	VLADIMIR TARASOV	{"email": "v-tarasov.03021979@postgrespro.ru", "phone": "+70590045492"}
0005434182103	0E4318	4544 873763	MARFA KONDRATEVA	{"email": "marfa.kondrateva.1973@postgrespro.ru", "phone": "+70892071910"}
0005434182104	EDC492	1705 372147	VALENTINA KOLESNIKOVA	{"phone": "+70443631680"}
0005434182105	1C9178	2999 054733	VALENTINA IVANOVA	{"email": "ivanovav_1976@postgrespro.ru", "phone": "+70558818772"}
0005434182106	2FC8FB	2773 610085	ALEKSANDR PETROV	{"phone": "+70550363655"}
0005434182107	DFB9F2	4799 609236	GALINA GORBUNOVA	{"phone": "+70445410135"}
0005434182108	495A66	1691 136101	NATALYA DANILOVA	{"email": "danilova.n18011976@postgrespro.ru", "phone": "+70040992479"}
0005434182109	53514E	9609 132816	NIKOLAY TIKHONOV	{"email": "tikhonov.n.30081959@postgrespro.ru", "phone": "+70718375202"}
0005434182110	53514E	1037 841826	PAVEL IVANOV	{"email": "ivanov.p19051971@postgrespro.ru", "phone": "+70964492972"}
0005434182111	1F6D03	1895 412262	IRINA KOROLEVA	{"email": "irina_koroleva.1963@postgrespro.ru", "phone": "+70453561685"}
0005434182112	1F6D03	1491 685582	RINAT MOROZOV	{"email": "morozov-r_091978@postgrespro.ru", "phone": "+70580234948"}
0005434182113	BF4F89	5140 679947	VALENTINA GRISHINA	{"phone": "+70491958345"}
0005434182114	7E0CEA	3540 632016	NIKITA MAKSIMOV	{"email": "maksimov-nikita_1962@postgrespro.ru", "phone": "+70938239923"}
0005434182115	3EB620	0671 564543	NIKITA ILIN	{"phone": "+70403444031"}
0005434182116	FDBD11	1864 178202	SERGEY ALEKSANDROV	{"phone": "+70663934322"}
0005434182117	0FBD7F	5235 924466	OLGA MOROZOVA	{"email": "omorozova-1971@postgrespro.ru", "phone": "+70832140993"}
0005434182118	D57418	8376 570388	ANNA ANDREEVA	{"phone": "+70057922656"}
0005434182119	7A1482	5246 087390	MARGARITA KAZAKOVA	{"email": "kazakovam.041968@postgrespro.ru", "phone": "+70665882931"}
0005434182120	7A1482	6661 612502	VITALIY MELNIKOV	{"email": "vitaliy.melnikov_1962@postgrespro.ru", "phone": "+70396973398"}
0005434182121	3A3EE4	8761 413505	VALENTINA VLASOVA	{"email": "v-vlasova-121970@postgrespro.ru", "phone": "+70883991607"}
0005434182122	2358B5	9686 292538	NATALYA ISAEVA	{"email": "isaevanatalya_101975@postgrespro.ru", "phone": "+70621590211"}
0005434182123	3AEFA7	0344 326888	ALENA FEDOROVA	{"phone": "+70450415517"}
0005434182124	7443B8	6040 761729	ELENA CHERNOVA	{"email": "e.chernova-25021970@postgrespro.ru", "phone": "+70601800150"}
0005434182125	B652A6	1483 784665	YULIYA IVANOVA	{"email": "ivanovay-031978@postgrespro.ru", "phone": "+70145418902"}
0005434182126	C6A4CD	9947 537344	NADEZHDA POLYAKOVA	{"phone": "+70143955598"}
0005434182127	298C29	9955 692901	ELENA ALEKSEEVA	{"email": "alekseeva.e1959@postgrespro.ru", "phone": "+70691307329"}
0005434182128	926FE0	3124 844184	VITALIY EGOROV	{"email": "vitaliy_egorov031976@postgrespro.ru", "phone": "+70454922949"}
0005434182129	3213DB	2736 360806	GENNADIY SHEVCHENKO	{"email": "shevchenko-g-011986@postgrespro.ru", "phone": "+70369150141"}
0005434182130	41CC59	2187 387271	NATALIYA FROLOVA	{"email": "nataliya.frolova101970@postgrespro.ru", "phone": "+70076131904"}
0005434182131	41CC59	4661 927676	ALEKSEY NOVIKOV	{"email": "a.novikov031971@postgrespro.ru", "phone": "+70650954586"}
0005434182132	32B87A	7732 547398	SEMEN KOROLEV	{"email": "korolev.s_081972@postgrespro.ru", "phone": "+70321354837"}
0005434182133	2495DF	4884 552623	BORIS DMITRIEV	{"email": "boris.dmitriev-1972@postgrespro.ru", "phone": "+70087529566"}
0005434182134	B8DE19	2782 086640	OLGA LUKYANOVA	{"phone": "+70311928268"}
0005434182135	818EA9	6613 184297	POLINA IVANOVA	{"phone": "+70647307216"}
0005434182136	C8AEE7	7866 599965	VASILIY SOKOLOV	{"email": "vasiliy.sokolov_051974@postgrespro.ru", "phone": "+70454252747"}
0005434182137	709F9A	2335 469225	EKATERINA BELYAEVA	{"phone": "+70479312836"}
0005434182138	411D36	7275 858707	VLADIMIR FOMIN	{"phone": "+70033765288"}
0005434182139	E0C4C8	6621 303572	FATIMA PETROVA	{"phone": "+70758704494"}
0005434182140	E55FE1	4634 495794	ELENA BELOVA	{"email": "belovaelena_1971@postgrespro.ru", "phone": "+70263531582"}
0005434182141	9A60EC	0820 919658	VASILIY ALEKSANDROV	{"email": "aleksandrov.vasiliy.1980@postgrespro.ru", "phone": "+70013353339"}
0005434182142	9A60EC	4780 224111	LYUDMILA KRASNOVA	{"phone": "+70763688087"}
0005434182143	D83C9B	3789 405121	KLAVDIYA ZOTOVA	{"email": "k-zotova-30121976@postgrespro.ru", "phone": "+70328316817"}
0005434182144	4F5A65	6028 548309	IRINA FEDOROVA	{"phone": "+70288481196"}
0005434182145	781519	0145 544551	VIKTOR ALEKSEEV	{"email": "v.alekseev1975@postgrespro.ru", "phone": "+70088015148"}
0005434182146	15551C	3664 843017	RAISA KUZMINA	{"email": "r-kuzmina_1976@postgrespro.ru", "phone": "+70214753315"}
0005434182147	A0960A	0021 731111	PETR BELOV	{"email": "belov.petr.04031969@postgrespro.ru", "phone": "+70801670824"}
0005434182148	A0960A	5841 544969	SANIYA ZOTOVA	{"email": "s-zotova.091967@postgrespro.ru", "phone": "+70172382055"}
0005434182149	A0960A	5789 201009	ALISHER ANTONOV	{"phone": "+70198087949"}
0005434182150	03D507	1260 599841	IRINA DANILOVA	{"email": "i-danilova.25111976@postgrespro.ru", "phone": "+70136704319"}
0005434182151	03D507	0611 192891	LYUDMILA SEMENOVA	{"email": "semenova_lyudmila011989@postgrespro.ru", "phone": "+70455542441"}
0005434182152	B29D54	2531 009695	ALEKSANDR ROMANOV	{"phone": "+70880785189"}
0005434182153	3ACE8A	2220 862827	ELENA ARKHIPOVA	{"phone": "+70779031898"}
0005434182154	D525A6	8990 936241	INNA TARASOVA	{"email": "innatarasova.021988@postgrespro.ru", "phone": "+70565580909"}
0005434182155	531213	2950 007011	VALERIY MOISEEV	{"email": "v_moiseev-24121963@postgrespro.ru", "phone": "+70553176947"}
0005434182156	67C2B3	9044 388937	YULIYA MASLOVA	{"email": "yuliya.maslova.24101971@postgrespro.ru", "phone": "+70858625489"}
0005434182157	F42B0A	3453 563959	YULIYA ANDREEVA	{"email": "andreevay-12111975@postgrespro.ru", "phone": "+70914987516"}
0005434182158	5C6851	3878 636979	VITALIY KUZMIN	{"email": "vitaliy_kuzmin031971@postgrespro.ru", "phone": "+70132526983"}
0005434182159	96AA09	6831 637851	MARIYA POLYAKOVA	{"phone": "+70589401726"}
0005434182160	9D42F5	7613 162358	NIKITA IVANOV	{"phone": "+70415816577"}
0005434182161	2847B0	4403 804762	OLGA KUZNECOVA	{"phone": "+70387968706"}
0005434182162	9DBFB9	4433 060132	RAISA SEMENOVA	{"email": "r.semenova1967@postgrespro.ru", "phone": "+70178821993"}
0005434182163	9DBFB9	7178 399360	SVETLANA VASILEVA	{"email": "svetlanavasileva_15111963@postgrespro.ru", "phone": "+70467684920"}
0005434182164	A6709A	5505 444121	NATALYA STEPANOVA	{"phone": "+70009887412"}
0005434182165	455299	2274 815035	ALEKSANDR EGOROV	{"phone": "+70648352815"}
0005434182166	F0EF31	5199 407771	OLGA NIKITINA	{"email": "nikitinao1983@postgrespro.ru", "phone": "+70453388526"}
0005434182167	C161A6	2688 491632	IVAN VLASOV	{"phone": "+70850605392"}
0005434182168	CF84F6	1398 565632	LARISA ROMANOVA	{"phone": "+70229135180"}
0005434182169	CF84F6	3575 308172	EVGENIY SOKOLOV	{"phone": "+70613595664"}
0005434182170	A6636B	7806 645483	OLGA KUZMINA	{"email": "kuzminaolga1973@postgrespro.ru", "phone": "+70508439452"}
0005434182171	45A2B5	5661 106077	ALEKSANDR ABRAMOV	{"email": "abramov.a-1980@postgrespro.ru", "phone": "+70174432094"}
0005434182172	25CFDB	6808 556488	EVGENIYA NIKIFOROVA	{"phone": "+70869669406"}
0005434182173	C0394A	0325 720575	LARISA PAVLOVA	{"email": "pavloval_1974@postgrespro.ru", "phone": "+70275025973"}
0005434182174	299B1C	6230 522280	ALLA SMIRNOVA	{"email": "alla-smirnova1974@postgrespro.ru", "phone": "+70551282377"}
0005434182175	31346C	0853 948687	ELENA DANILOVA	{"email": "danilova_elena.1972@postgrespro.ru", "phone": "+70890185012"}
0005434182176	31346C	9925 632329	NIKOLAY YAKOVLEV	{"email": "nikolayyakovlev-14051973@postgrespro.ru", "phone": "+70548496782"}
0005434182177	1C12D7	1368 274362	VIKTOR BONDARENKO	{"phone": "+70183871280"}
0005434182178	6F7AA3	5065 193191	ALEKSANDR NIKITIN	{"email": "a-nikitin.121972@postgrespro.ru", "phone": "+70450360221"}
0005434182179	6F7AA3	6378 047648	ROZA TIKHONOVA	{"phone": "+70083622815"}
0005434182180	A32999	7650 429013	ELENA TARASOVA	{"email": "tarasova.e-031979@postgrespro.ru", "phone": "+70575902476"}
0005434182181	708262	7406 387728	SERGEY ANDREEV	{"email": "andreev_s-041971@postgrespro.ru", "phone": "+70180884420"}
0005434182182	70B771	0292 029718	DMITRIY DENISOV	{"email": "denisov-dmitriy_021982@postgrespro.ru", "phone": "+70261825342"}
0005434182183	70B771	5109 551912	ANASTASIYA GORBUNOVA	{"email": "gorbunova-anastasiya121972@postgrespro.ru", "phone": "+70815833830"}
0005434182184	B9DEE0	3057 508244	SVETLANA FILATOVA	{"phone": "+70479757783"}
0005434182185	FC419E	3890 308375	IRINA IVANOVA	{"email": "i-ivanova1972@postgrespro.ru", "phone": "+70887531984"}
0005434182186	FC419E	0525 274236	IGOR TIKHONOV	{"phone": "+70153541952"}
0005434182187	BA24F5	1111 906228	NINA KRASNOVA	{"phone": "+70917988519"}
0005434182188	BA24F5	2112 285337	IVAN ABRAMOV	{"email": "abramov.i.29041960@postgrespro.ru", "phone": "+70815451149"}
0005434182189	20B9D0	0512 419439	OLGA TITOVA	{"email": "o.titova.091985@postgrespro.ru", "phone": "+70922084852"}
0005434182190	7BA2E4	4371 012676	KONSTANTIN PETROV	{"email": "petrov_konstantin.1967@postgrespro.ru", "phone": "+70809558621"}
0005434182191	1AAFED	5918 602343	ANDREY TARASOV	{"phone": "+70554902484"}
0005434182192	1AAFED	1524 014090	VALENTINA ROMANOVA	{"phone": "+70488743556"}
0005434182193	993AF0	5989 282962	NADEZHDA KISELEVA	{"email": "kiseleva-n_1972@postgrespro.ru", "phone": "+70769806629"}
0005434182194	AA1916	2892 115020	VLADIMIR PAVLOV	{"phone": "+70244472146"}
0005434182195	12C82D	3213 410289	EGOR ZHUKOV	{"phone": "+70129470715"}
0005434182196	538665	1262 943716	VERA FILIPPOVA	{"email": "v-filippova-28091965@postgrespro.ru", "phone": "+70874602621"}
0005434182197	B2F246	3894 060731	VLADIMIR KONOVALOV	{"phone": "+70410860568"}
0005434182198	B2F246	7739 899020	NATALYA SOKOLOVA	{"email": "sokolova_natalya-1976@postgrespro.ru", "phone": "+70535115650"}
0005434182199	320C21	7871 518949	ALEVTINA MIKHAYLOVA	{"email": "mikhaylovaalevtina_121970@postgrespro.ru", "phone": "+70705605890"}
0005434182200	DD41CD	2580 553760	NATALYA SMIRNOVA	{"email": "smirnova.n23111968@postgrespro.ru", "phone": "+70773214629"}
0005434182201	E86055	3687 207709	OLEG ILIN	{"phone": "+70276815029"}
0005434182202	4783EA	1665 852881	ALEKSEY TARASOV	{"phone": "+70534777020"}
0005434182203	4783EA	7897 836942	VIKTOR KARPOV	{"email": "karpovv-1972@postgrespro.ru", "phone": "+70126558260"}
0005434182204	196956	2780 490263	VLADIMIR KARPOV	{"phone": "+70745817149"}
0005434182205	B25455	9479 324979	SERGEY MAKAROV	{"email": "sergey_makarov1969@postgrespro.ru", "phone": "+70525517280"}
0005434182206	B25455	5404 184522	OLGA ANDREEVA	{"phone": "+70114900006"}
0005434182207	8F4450	9588 621638	MIKHAIL ZHURAVLEV	{"email": "m_zhuravlev_1982@postgrespro.ru", "phone": "+70742256784"}
0005434182208	D43023	8992 290868	NATALYA SIDOROVA	{"email": "natalya_sidorova-1977@postgrespro.ru", "phone": "+70047198382"}
0005434182209	7F0A6F	9832 134594	SNEZHANA SMIRNOVA	{"email": "s.smirnova_10051967@postgrespro.ru", "phone": "+70177731621"}
0005434182210	72B0C2	8775 950113	ALEKSANDR KOROLEV	{"email": "koroleva-24111959@postgrespro.ru", "phone": "+70059972478"}
0005434182211	72B0C2	6186 873849	MARINA ZAKHAROVA	{"email": "zakharova_marina091976@postgrespro.ru", "phone": "+70894991735"}
0005434182212	72B0C2	9965 766380	ELENA YUDINA	{"phone": "+70477977019"}
0005434182213	5A53A8	0541 434439	IVAN ANDREEV	{"phone": "+70585501822"}
0005434182214	38F392	0443 345323	EVGENIYA MALYSHEVA	{"phone": "+70924660557"}
0005434182215	38F392	8255 999044	STEPAN FEDOTOV	{"email": "s.fedotov-30041970@postgrespro.ru", "phone": "+70005343921"}
0005434182216	F81CB6	9224 328456	EVGENIY MAKAROV	{"phone": "+70010948347"}
0005434182217	383AEE	6645 733115	ALEKSEY NIKITIN	{"email": "aleksey_nikitin-091975@postgrespro.ru", "phone": "+70706644691"}
0005434182218	859D13	2849 785155	VERA MOROZOVA	{"email": "v_morozova-1977@postgrespro.ru", "phone": "+70918676210"}
0005434182219	859D13	7826 002776	SEMEN BONDARENKO	{"phone": "+70337650140"}
0005434182220	9F1E59	9576 172762	VALERIYA BORISOVA	{"phone": "+70693873216"}
0005434182221	9F1E59	5813 640869	ALEKSANDR MAKAROV	{"phone": "+70433657947"}
0005434182222	668109	3486 425900	LYUDMILA SAVELEVA	{"email": "lyudmila.saveleva-27051981@postgrespro.ru", "phone": "+70923381826"}
0005434182223	955DAA	8965 309603	TATYANA PETROVA	{"phone": "+70435221532"}
0005434182224	955DAA	2826 522283	SVETLANA FROLOVA	{"email": "svetlana-frolova_1980@postgrespro.ru", "phone": "+70178597693"}
0005434182225	0CAF79	5754 793000	SERGEY NIKITIN	{"email": "nikitinsergey14081973@postgrespro.ru", "phone": "+70882178568"}
0005434182226	629786	2015 251491	ASIYA FOMINA	{"phone": "+70961993896"}
0005434182227	FF0AF2	7692 195890	VLADA PETROVA	{"email": "petrovav.011972@postgrespro.ru", "phone": "+70596870237"}
0005434182228	FF0AF2	4813 906163	SERAFIM BELOV	{"phone": "+70562455520"}
0005434182229	0FE286	2991 619196	ANASTASIYA AKIMOVA	{"email": "akimovaanastasiya.021965@postgrespro.ru", "phone": "+70339949809"}
0005434182230	641AF2	6839 657260	RAMIL SMIRNOV	{"phone": "+70199681933"}
0005434182232	1545BC	1868 061249	NATALYA POPOVA	{"email": "natalyapopova-081968@postgrespro.ru", "phone": "+70101875370"}
0005434182233	2219E0	2521 470135	ALEKSANDR ZHUKOV	{"email": "zhukov-aleksandr.22041984@postgrespro.ru", "phone": "+70653551340"}
0005434182234	1860A4	7956 710881	ZHANNA MOROZOVA	{"phone": "+70342422089"}
0005434182235	C5D6EB	4264 839153	VYACHESLAV SIDOROV	{"phone": "+70738191506"}
0005434182236	C5D6EB	7629 540287	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay.081974@postgrespro.ru", "phone": "+70632279484"}
0005434182237	E1F049	4772 580795	SERGEY KAZAKOV	{"phone": "+70023241912"}
0005434182238	E1F049	8787 195264	ELENA LAZAREVA	{"email": "e.lazareva_1971@postgrespro.ru", "phone": "+70248603721"}
0005434182239	3015DA	1131 385132	NADEZHDA SOLOVEVA	{"email": "solovevanadezhda-1959@postgrespro.ru", "phone": "+70034078943"}
0005434182240	3015DA	2991 337974	EKATERINA MAKSIMOVA	{"email": "e_maksimova-1970@postgrespro.ru", "phone": "+70457220223"}
0005434182241	A29D25	7872 811542	NIKOLAY OSIPOV	{"email": "osipov.nikolay-111963@postgrespro.ru", "phone": "+70377842928"}
0005434182242	A29D25	1619 271458	PAVEL FILIPPOV	{"email": "p-filippov111966@postgrespro.ru", "phone": "+70001528571"}
0005434182243	292E3C	6751 668932	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana021974@postgrespro.ru", "phone": "+70373332334"}
0005434182244	292E3C	2615 771314	YULIYA ZOTOVA	{"email": "zotova.y_051982@postgrespro.ru", "phone": "+70603840526"}
0005434182245	663CBC	7954 679578	ELENA DMITRIEVA	{"email": "elenadmitrieva.101975@postgrespro.ru", "phone": "+70002664445"}
0005434182246	663CBC	8056 185769	IVAN YAKOVLEV	{"email": "yakovlev-i-1981@postgrespro.ru", "phone": "+70920185482"}
0005434182247	663CBC	7027 492501	ANNA KRASNOVA	{"phone": "+70695404361"}
0005434182248	79520C	3875 532455	DANIL TIKHONOV	{"email": "d_tikhonov-061974@postgrespro.ru", "phone": "+70711888599"}
0005434182249	79520C	4432 907042	IRINA MAKAROVA	{"email": "i.makarova-1973@postgrespro.ru", "phone": "+70670380344"}
0005434182250	37BD48	4604 949715	ALEVTINA ISAEVA	{"email": "a-isaeva-13091970@postgrespro.ru", "phone": "+70567842858"}
0005434182251	D2C897	7799 787204	GALINA MOROZOVA	{"email": "morozova.galina08121963@postgrespro.ru", "phone": "+70343043193"}
0005434182252	3563C1	6545 201533	KLAVDIYA VASILEVA	{"phone": "+70746914077"}
0005434182253	22CED3	0166 223170	VALENTINA KUZNECOVA	{"email": "kuznecova-v-1976@postgrespro.ru", "phone": "+70771604696"}
0005434182254	0085F1	1638 739780	LILIYA KOROLEVA	{"email": "koroleva_liliya15051971@postgrespro.ru", "phone": "+70270355606"}
0005434182255	4103FC	8940 357461	ELENA STEPANOVA	{"email": "stepanovae.1985@postgrespro.ru", "phone": "+70568941529"}
0005434182256	8A356A	8467 086409	MIKHAIL ZHUKOV	{"email": "zhukov-mikhail1979@postgrespro.ru", "phone": "+70926085257"}
0005434182257	084200	7241 902248	ANASTASIYA EGOROVA	{"phone": "+70009604948"}
0005434182258	084200	0158 420741	ANDREY MATVEEV	{"email": "matveev-andrey-031965@postgrespro.ru", "phone": "+70536518423"}
0005434182259	56AFF5	0654 089640	NATALYA STEPANOVA	{"phone": "+70251485769"}
0005434182260	842572	6174 071525	VALENTINA SOKOLOVA	{"phone": "+70654106372"}
0005434182261	1DAD4B	2140 238681	SVETLANA ZAKHAROVA	{"phone": "+70550067032"}
0005434182262	1DAD4B	3896 343730	NIKOLAY ILIN	{"email": "nikolay.ilin061975@postgrespro.ru", "phone": "+70994769099"}
0005434182263	0CFB8B	4808 438650	LYUBOV VOLKOVA	{"email": "l_volkova-121964@postgrespro.ru", "phone": "+70595563772"}
0005434182264	0CFB8B	5149 572240	ARTEM SOLOVEV	{"phone": "+70182372976"}
0005434182265	0CFB8B	8292 333595	MARIYA SEMENOVA	{"email": "semenova-mariya-071980@postgrespro.ru", "phone": "+70154459226"}
0005434182266	7EEEFC	7452 550863	NATALYA KISELEVA	{"email": "natalya-kiseleva.041967@postgrespro.ru", "phone": "+70690810599"}
0005434182267	2CF1AC	5355 317355	VLADISLAV BARANOV	{"email": "vbaranov081979@postgrespro.ru", "phone": "+70483291261"}
0005434182268	010FD3	0334 683859	ALEKSANDR KUZNECOV	{"phone": "+70936804475"}
0005434182269	904F23	2460 960521	ALEKSANDR SEMENOV	{"phone": "+70270445572"}
0005434182270	47E029	6838 806398	SERGEY SEMENOV	{"email": "sergey_semenov1977@postgrespro.ru", "phone": "+70211968340"}
0005434182271	47E029	3407 625018	TATYANA VASILEVA	{"email": "vasilevatatyana_1969@postgrespro.ru", "phone": "+70663416084"}
0005434182272	944817	7559 754560	ALEVTINA MELNIKOVA	{"phone": "+70072815512"}
0005434182273	B0D64D	8786 032376	DMITRIY KUZMIN	{"email": "dmitriy-kuzmin.22101974@postgrespro.ru", "phone": "+70605848205"}
0005434182274	8A3B36	2393 373791	NINA SIDOROVA	{"email": "nina.sidorova_1967@postgrespro.ru", "phone": "+70069754734"}
0005434182275	B3F600	9031 967218	IGOR MAKAROV	{"email": "i.makarov.1975@postgrespro.ru", "phone": "+70392041317"}
0005434182276	B3F600	5695 526494	VLADIMIR SAVELEV	{"phone": "+70480394773"}
0005434182277	60099E	1752 401667	LYUDMILA PAVLOVA	{"phone": "+70533795417"}
0005434182278	60099E	8141 671529	OLEG POPOV	{"phone": "+70623852305"}
0005434182279	63DE87	1896 311446	ALINA STEPANOVA	{"phone": "+70477060296"}
0005434182280	63DE87	2365 427222	NATALYA EGOROVA	{"phone": "+70659580822"}
0005434182281	D19B4B	4610 692370	MIKHAIL EGOROV	{"phone": "+70052563412"}
0005434182282	D19B4B	9113 759707	VERA SOKOLOVA	{"email": "sokolova-v_18041976@postgrespro.ru", "phone": "+70034934269"}
0005434182283	CCF46B	1394 444420	ELENA IVANOVA	{"phone": "+70774511344"}
0005434182284	EE557F	3344 921575	LYUBOV KALININA	{"email": "lyubov-kalinina.051975@postgrespro.ru", "phone": "+70326804026"}
0005434182285	EE557F	7828 856754	IRINA VASILEVA	{"email": "irinavasileva1975@postgrespro.ru", "phone": "+70880819678"}
0005434182286	62A34D	3040 680296	TATYANA NOVIKOVA	{"email": "novikova_t.19111971@postgrespro.ru", "phone": "+70343173689"}
0005434182287	99EE7E	5994 259878	TATYANA MOROZOVA	{"email": "t.morozova_011975@postgrespro.ru", "phone": "+70407262800"}
0005434182288	743D2D	8202 240311	ALEKSANDR KULIKOV	{"phone": "+70379818242"}
0005434182289	743D2D	9802 702416	OLGA SCHERBAKOVA	{"phone": "+70102282657"}
0005434182290	C20BC8	6545 757141	EVA NIKOLAEVA	{"phone": "+70403925232"}
0005434182291	5DCD9D	3198 809457	ALEKSEY FILIPPOV	{"phone": "+70980682543"}
0005434182292	0B68C2	3560 853447	ROMAN ZHURAVLEV	{"email": "zhuravlev-roman.06111977@postgrespro.ru", "phone": "+70872850699"}
0005434182293	0B68C2	2929 816670	MARIYA SOROKINA	{"phone": "+70472680811"}
0005434182294	00ED25	1403 500761	IRINA KUZNECOVA	{"email": "kuznecova_irina1963@postgrespro.ru", "phone": "+70372888903"}
0005434182295	CC9C62	5611 934599	DMITRIY EGOROV	{"phone": "+70888461692"}
0005434182296	3D0D80	3664 033481	MIKHAIL GRIGOREV	{"phone": "+70968100992"}
0005434182297	F6B455	7640 946275	YURIY POPOV	{"email": "popov-yuriy1959@postgrespro.ru", "phone": "+70938903943"}
0005434182298	F6B455	2878 384406	LYUBOV VASILEVA	{"phone": "+70675212572"}
0005434182299	32281E	7910 028859	SERGEY TARASOV	{"email": "tarasovsergey101978@postgrespro.ru", "phone": "+70262088025"}
0005434182300	2FE30D	9232 282514	SERGEY IVANOV	{"phone": "+70046731921"}
0005434182301	DD75BB	4875 077647	ANNA SOKOLOVA	{"email": "sokolova_anna_121975@postgrespro.ru", "phone": "+70693101652"}
0005434182302	DD75BB	6708 940082	NINA SEMENOVA	{"email": "semenova_nina-111964@postgrespro.ru", "phone": "+70951263866"}
0005434182303	88928B	7823 837931	VLADIMIR MELNIKOV	{"email": "melnikovv061974@postgrespro.ru", "phone": "+70354501769"}
0005434182304	42B9BF	1016 311386	ALEKSANDR IVANOV	{"email": "a.ivanov-27071975@postgrespro.ru", "phone": "+70649498382"}
0005434182305	C9BCCD	3576 234741	ANTON POPOV	{"email": "anton_popov05091969@postgrespro.ru", "phone": "+70455120335"}
0005434182306	E9F884	1885 126508	GALINA SOLOVEVA	{"phone": "+70022677835"}
0005434182307	E9F884	2887 252903	OLGA KUDRYASHOVA	{"email": "okudryashova-06031969@postgrespro.ru", "phone": "+70272463487"}
0005434182308	0B40CE	9670 116144	PETR VOLKOV	{"phone": "+70069427516"}
0005434182309	0B40CE	6710 651620	ANATOLIY ABRAMOV	{"email": "anatoliy.abramov101967@postgrespro.ru", "phone": "+70414727228"}
0005434182310	33550C	2877 349961	SERGEY VASILEV	{"email": "vasilev.s_061968@postgrespro.ru", "phone": "+70821487433"}
0005434182311	310E33	7221 353358	ALEKSANDR KARPOV	{"email": "karpova031965@postgrespro.ru", "phone": "+70046122397"}
0005434182312	AD2DD6	8785 193414	NIKOLAY ZAYCEV	{"email": "zaycev_nikolay1971@postgrespro.ru", "phone": "+70899508365"}
0005434182313	8BFE3C	0964 476463	TATYANA MOROZOVA	{"email": "tatyana-morozova-111973@postgrespro.ru", "phone": "+70057009190"}
0005434182314	FC00DE	3212 406614	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana-1958@postgrespro.ru", "phone": "+70571283178"}
0005434182315	FC00DE	9734 878022	TATYANA IVANOVA	{"email": "ivanova.tatyana071971@postgrespro.ru", "phone": "+70883184076"}
0005434182316	1824E2	7557 295067	STEPAN FROLOV	{"phone": "+70976345337"}
0005434182317	F4678E	5857 989914	VLADIMIR MOROZOV	{"email": "vladimirmorozov071984@postgrespro.ru", "phone": "+70677170528"}
0005434182318	AFCFC3	8791 306918	ALEKSANDR POPOV	{"phone": "+70675354408"}
0005434182319	A6F3AC	5964 560587	ELENA ORLOVA	{"phone": "+70867762783"}
0005434182320	A6F3AC	7011 455558	ELENA DANILOVA	{"phone": "+70923503130"}
0005434182321	F03B7B	8689 604486	ANTON FILIPPOV	{"email": "a_filippov081970@postgrespro.ru", "phone": "+70728356783"}
0005434182322	076F16	2429 221539	YULIYA KOMAROVA	{"phone": "+70986849371"}
0005434182323	61A867	0305 245109	ANTON NIKITIN	{"email": "anton_nikitin17091977@postgrespro.ru", "phone": "+70427125551"}
0005434182324	61A867	4332 504470	LYUBOV IVANOVA	{"email": "l_ivanova1977@postgrespro.ru", "phone": "+70041325430"}
0005434182325	0E50EB	0306 495280	ALEKSEY KULIKOV	{"email": "a.kulikov021970@postgrespro.ru", "phone": "+70461200272"}
0005434182326	B089FE	9494 901611	ALEKSANDRA NIKOLAEVA	{"phone": "+70463050248"}
0005434182327	B089FE	1847 867615	IRINA KALININA	{"phone": "+70004409838"}
0005434182328	B089FE	6869 956605	ANNA EGOROVA	{"phone": "+70624399588"}
0005434182329	F15CB6	6343 245708	LYUBOV FROLOVA	{"phone": "+70432964915"}
0005434182330	5BDF2A	7004 751666	SERGEY SAVELEV	{"email": "savelev-s16081966@postgrespro.ru", "phone": "+70410074080"}
0005434182331	84A1D1	6090 042540	SVETLANA ALEKSANDROVA	{"email": "s_aleksandrova.011970@postgrespro.ru", "phone": "+70308392307"}
0005434182332	1E689F	9776 567943	DMITRIY IVANOV	{"email": "ivanov-dmitriy_101976@postgrespro.ru", "phone": "+70860358885"}
0005434182333	E32902	5135 078653	IRINA NIKITINA	{"phone": "+70469882394"}
0005434182334	E32902	9019 027468	VALENTINA KALININA	{"email": "kalinina.valentina.08051984@postgrespro.ru", "phone": "+70997213163"}
0005434182335	447437	4248 481591	RAFAEL KUZNECOV	{"phone": "+70497059392"}
0005434182336	906088	5846 693719	EKATERINA DANILOVA	{"email": "danilova_e-071977@postgrespro.ru", "phone": "+70311400344"}
0005434182337	906088	0103 524573	DENIS KONOVALOV	{"phone": "+70703166477"}
0005434182338	D5D692	0118 282225	YULIYA ANTONOVA	{"email": "y-antonova-111967@postgrespro.ru", "phone": "+70278940983"}
0005434182339	D5E68C	9479 220503	ILYAS KUZNECOV	{"email": "ilyas-kuznecov-15071974@postgrespro.ru", "phone": "+70693367316"}
0005434182340	43EB15	4714 984067	LIDIYA ZAYCEVA	{"phone": "+70975808555"}
0005434182341	43EB15	8133 425300	VALENTINA KOZLOVA	{"phone": "+70467385968"}
0005434182342	F4C765	8051 036704	VLADIMIR ROMANOV	{"email": "romanov.v-021972@postgrespro.ru", "phone": "+70586428865"}
0005434182343	855E34	8696 057004	NIKOLAY ZHUKOV	{"email": "zhukov.nikolay101963@postgrespro.ru", "phone": "+70267142192"}
0005434182344	855E34	3100 297323	ANDREY GUSEV	{"email": "gusev-andrey08081968@postgrespro.ru", "phone": "+70403702460"}
0005434182345	8CB2CE	1623 911762	SERGEY NAZAROV	{"phone": "+70041350408"}
0005434182346	8CB2CE	2508 841386	TATYANA MELNIKOVA	{"phone": "+70089340220"}
0005434182347	B9D52B	0405 162968	SERGEY ALEKSEEV	{"phone": "+70236535269"}
0005434182348	82E06B	1361 331445	DENIS KUDRYASHOV	{"email": "denis_kudryashov-02081964@postgrespro.ru", "phone": "+70162980633"}
0005434182349	6E1522	5576 931844	EVGENIY KULIKOV	{"phone": "+70060642812"}
0005434182350	9B9A96	7189 462555	EKATERINA DMITRIEVA	{"email": "dmitrievaekaterina-22061971@postgrespro.ru", "phone": "+70462273684"}
0005434182351	FF6713	7861 105690	DINA RODIONOVA	{"email": "drodionova081974@postgrespro.ru", "phone": "+70795969101"}
0005434182352	5A0A5D	0345 081506	GRIGORIY PAVLOV	{"phone": "+70365424133"}
0005434182353	953F5F	2820 848087	ANTON ILIN	{"email": "anton_ilin1987@postgrespro.ru", "phone": "+70535632568"}
0005434182354	953F5F	2142 068600	NADEZHDA PETROVA	{"phone": "+70161989471"}
0005434182355	06154E	6459 936605	SERGEY SOKOLOV	{"email": "sergeysokolov.31121967@postgrespro.ru", "phone": "+70614309785"}
0005434182356	9AE539	7704 496253	VITALIY NIKITIN	{"email": "nikitin_vitaliy-111968@postgrespro.ru", "phone": "+70291389863"}
0005434182357	1A88B8	3306 818350	ELENA GUSEVA	{"email": "elena.guseva_111981@postgrespro.ru", "phone": "+70855635448"}
0005434182358	6B3FC3	7216 641765	NADEZHDA ZAYCEVA	{"phone": "+70877289131"}
0005434182359	6B3FC3	7976 927854	DMITRIY PETROV	{"phone": "+70530256508"}
0005434182360	991ACE	1038 405434	KIRILL PAVLOV	{"email": "pavlov_kirill-29081959@postgrespro.ru", "phone": "+70327127275"}
0005434182361	E59D9D	2894 420324	IRINA ZAKHAROVA	{"email": "izakharova.1968@postgrespro.ru", "phone": "+70666783953"}
0005434182362	E59D9D	1749 052146	ELENA DMITRIEVA	{"email": "dmitrieva_elena1986@postgrespro.ru", "phone": "+70942159006"}
0005434182363	CAC087	9965 451270	ZULFIYA GAVRILOVA	{"email": "gavrilova_z1967@postgrespro.ru", "phone": "+70167011981"}
0005434182364	D14EFB	8680 553165	BORIS STEPANOV	{"phone": "+70370464932"}
0005434182365	4E9928	8498 490213	VLADIMIR KISELEV	{"email": "vladimir.kiselev-121974@postgrespro.ru", "phone": "+70166295693"}
0005434182366	6222F6	7832 227954	ANDREY MARTYNOV	{"email": "martynov.andrey031985@postgrespro.ru", "phone": "+70315176130"}
0005434182367	6222F6	2085 237338	YULIYA ZAYCEVA	{"phone": "+70385410685"}
0005434182368	2BDDD1	2767 027577	VLADIMIR VOLKOV	{"email": "volkovv-051975@postgrespro.ru", "phone": "+70005107035"}
0005434182369	36FFF0	6197 778521	ELENA VOROBEVA	{"email": "vorobeva.e-041970@postgrespro.ru", "phone": "+70741298971"}
0005434182370	9DCCEF	1051 336697	SVETLANA VLASOVA	{"email": "svetlana-vlasova_121972@postgrespro.ru", "phone": "+70502386492"}
0005434182371	DC9266	7226 778987	GALINA KOVALEVA	{"email": "g.kovaleva.1978@postgrespro.ru", "phone": "+70538647815"}
0005434182372	37A900	3299 146536	YURIY ORLOV	{"phone": "+70049947852"}
0005434182373	617350	8316 233091	IVAN ANDREEV	{"email": "i_andreev-051972@postgrespro.ru", "phone": "+70160457329"}
0005434182374	59AEC7	3704 953032	ANASTASIYA IVANOVA	{"email": "ivanova.a-12011976@postgrespro.ru", "phone": "+70204581531"}
0005434182375	59AEC7	1617 948425	ALENA POLYAKOVA	{"email": "polyakova_alena1972@postgrespro.ru", "phone": "+70113148015"}
0005434182376	927E50	5947 936920	ALEKSANDR VLASOV	{"phone": "+70561355275"}
0005434182377	927E50	8928 611455	EKATERINA MARTYNOVA	{"phone": "+70227650048"}
0005434182378	E4FF73	3926 173556	VLADIMIR NAUMOV	{"phone": "+70580895087"}
0005434182379	E4FF73	4078 673828	RITA PAVLOVA	{"email": "pavlova_rita17091978@postgrespro.ru", "phone": "+70271024175"}
0005434182380	BAE613	0099 674953	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev_041968@postgrespro.ru", "phone": "+70589463989"}
0005434182381	0A87F7	2426 798462	DMITRIY SERGEEV	{"email": "sergeev_dmitriy1962@postgrespro.ru", "phone": "+70610108420"}
0005434182382	3B7F51	2147 850825	ANATOLIY ALEKSEEV	{"phone": "+70514129457"}
0005434182383	A964EF	6643 414055	OLEG SCHERBAKOV	{"email": "oscherbakov-1968@postgrespro.ru", "phone": "+70848407128"}
0005434182384	4DE558	2538 821498	ALEKSEY MAKSIMOV	{"phone": "+70256657119"}
0005434182385	4DE558	1715 567306	VERONIKA ZAKHAROVA	{"phone": "+70506298116"}
0005434182386	BE5E7D	4897 309135	YURIY POPOV	{"email": "y.popov_22071964@postgrespro.ru", "phone": "+70547183216"}
0005434182387	049134	9974 531036	MARIYA IVANOVA	{"phone": "+70340827816"}
0005434182388	7A02B2	8359 154929	RAFAIL NIKITIN	{"email": "nikitin.rafail-1971@postgrespro.ru", "phone": "+70260226637"}
0005434182389	ECB2A4	0119 151556	DENIS PAVLOV	{"email": "pavlov_d16091970@postgrespro.ru", "phone": "+70137843373"}
0005434182390	C5BBAA	4817 551129	MAKSIM GAVRILOV	{"email": "maksim_gavrilov1974@postgrespro.ru", "phone": "+70545662707"}
0005434182391	D093D4	1845 314480	VALERIY FOMIN	{"phone": "+70288415635"}
0005434182392	CB2189	5583 416588	SERGEY SCHERBAKOV	{"phone": "+70577403445"}
0005434182393	CB2189	8187 640956	DMITRIY STEPANOV	{"phone": "+70008210209"}
0005434182394	CB2189	3961 407903	YAN DAVYDOV	{"phone": "+70024945090"}
0005434182395	2E020D	8256 335484	LINAR MARTYNOV	{"email": "martynovl.081973@postgrespro.ru", "phone": "+70371058720"}
0005434182396	2E020D	7731 631359	INGA ZAYCEVA	{"email": "zayceva.i.16011969@postgrespro.ru", "phone": "+70912014008"}
0005434182397	2E020D	9215 369441	MARAT PAVLOV	{"email": "marat.pavlov-081978@postgrespro.ru", "phone": "+70544434211"}
0005434182398	2E020D	5131 182146	ALEKSANDR KULIKOV	{"phone": "+70408840887"}
0005434182399	27AB2D	6822 765799	NINA VASILEVA	{"email": "vasileva.nina-1987@postgrespro.ru", "phone": "+70235628935"}
0005434182400	0303CF	7974 312846	LARISA PETROVA	{"phone": "+70796437374"}
0005434182401	EDC458	0723 710556	EKATERINA TARASOVA	{"phone": "+70027266588"}
0005434182402	6B73F6	7408 644648	VLADIMIR FROLOV	{"email": "frolovv_1967@postgrespro.ru", "phone": "+70486240890"}
0005434182403	3B1DFA	9418 283728	MARIYA POPOVA	{"email": "m_popova_17121964@postgrespro.ru", "phone": "+70550972465"}
0005434182404	2E6CC5	1660 757809	ALEKSANDRA KARPOVA	{"phone": "+70703661785"}
0005434182405	19F417	7370 200687	NATALYA IVANOVA	{"email": "n.ivanova.1975@postgrespro.ru", "phone": "+70133503929"}
0005434182406	F0FDDC	5949 455154	GEORGIY RODIONOV	{"email": "g_rodionov07021965@postgrespro.ru", "phone": "+70397192050"}
0005434182407	0F9912	4697 683437	TATYANA ZHUKOVA	{"email": "tatyanazhukova.02021967@postgrespro.ru", "phone": "+70746792204"}
0005434182408	E5CA4A	9376 705635	VASILIY CHERNOV	{"phone": "+70718682787"}
0005434182409	2569B0	9633 659861	FARID ZAKHAROV	{"phone": "+70269769440"}
0005434182410	2569B0	8074 850658	ALEKSEY BARANOV	{"phone": "+70929296095"}
0005434182411	BF460F	1596 705384	VALENTINA VLASOVA	{"email": "vlasovav.1970@postgrespro.ru", "phone": "+70764495661"}
0005434182412	BF460F	8668 310085	KLIM BELOV	{"email": "klim-belov.1969@postgrespro.ru", "phone": "+70712344077"}
0005434182413	BF460F	8230 829741	ANASTASIYA POLYAKOVA	{"phone": "+70675581082"}
0005434182414	61CE79	0842 211409	MIKHAIL ALEKSANDROV	{"phone": "+70742335741"}
0005434182415	628C94	7963 582689	DARYA KALININA	{"email": "d.kalinina_111965@postgrespro.ru", "phone": "+70491213763"}
0005434182416	E9D9A2	0633 004944	YURIY MARTYNOV	{"email": "martynovyuriy_15091972@postgrespro.ru", "phone": "+70051017907"}
0005434182417	72487B	9252 874170	TATYANA SEMENOVA	{"email": "t-semenova07021967@postgrespro.ru", "phone": "+70074707731"}
0005434182418	38541D	5396 422093	ALEKSANDR ALEKSEEV	{"phone": "+70879531378"}
0005434182419	D8B22D	8969 681240	ALEKSANDRA POPOVA	{"email": "aleksandra_popova-1962@postgrespro.ru", "phone": "+70873045553"}
0005434182420	0DA38F	4732 443725	ZOYA IVANOVA	{"email": "zivanova17011968@postgrespro.ru", "phone": "+70669712728"}
0005434182421	0DA38F	8003 789252	OLGA POLYAKOVA	{"phone": "+70407605037"}
0005434182422	D22969	5682 709587	VADIM MELNIKOV	{"phone": "+70714897415"}
0005434182423	4BA5EC	7386 667944	ANATOLIY SAVELEV	{"email": "a-savelev-121964@postgrespro.ru", "phone": "+70922146727"}
0005434182424	4BA5EC	9248 913284	VERA VASILEVA	{"email": "v-vasileva-1979@postgrespro.ru", "phone": "+70366956938"}
0005434182425	AEABC8	1147 449140	MARAT POPOV	{"phone": "+70719881668"}
0005434182426	DED4A8	8025 978229	GALINA KUZMINA	{"phone": "+70741003021"}
0005434182427	DED4A8	8824 215225	MARIYA SCHERBAKOVA	{"email": "mariya-scherbakova_09091984@postgrespro.ru", "phone": "+70909983036"}
0005434182428	D42CFC	3271 640981	ANATOLIY VOLKOV	{"phone": "+70926584913"}
0005434182429	D42CFC	7315 976762	NATALYA FILATOVA	{"email": "n.filatova_1977@postgrespro.ru", "phone": "+70729014464"}
0005434182430	6E3A81	9771 165183	MIKHAIL SOROKIN	{"phone": "+70261842847"}
0005434182431	59061D	1779 014206	EVELINA MOROZOVA	{"email": "morozova_evelina1964@postgrespro.ru", "phone": "+70634470497"}
0005434182432	480111	5987 467431	ALEKSANDR NAZAROV	{"phone": "+70656965084"}
0005434182433	480111	7924 727187	ALEKSANDR KOZLOV	{"email": "kozlov.a_20111976@postgrespro.ru", "phone": "+70991391065"}
0005434182434	480111	6334 459604	OKSANA MIKHAYLOVA	{"phone": "+70008078240"}
0005434182435	814A49	2417 558776	YURIY KOROLEV	{"email": "y.korolev.1972@postgrespro.ru", "phone": "+70658063282"}
0005434182436	3FCC41	1728 857632	ANATOLIY KUZNECOV	{"phone": "+70216346412"}
0005434182437	10E848	0234 103338	ANTON MIRONOV	{"email": "anton_mironov-121981@postgrespro.ru", "phone": "+70293211343"}
0005434182438	F08A3A	9883 640507	NADEZHDA SOROKINA	{"email": "nadezhdasorokina_1963@postgrespro.ru", "phone": "+70709804082"}
0005434182439	0AA5A5	8467 620230	LYUBOV NAZAROVA	{"phone": "+70596648782"}
0005434182440	0AA5A5	7488 540279	ALEKSANDR FILIPPOV	{"phone": "+70243714527"}
0005434182441	19F85C	6979 036649	OLEG PETROV	{"email": "opetrov.081961@postgrespro.ru", "phone": "+70989564735"}
0005434182442	19F85C	1442 967823	ALEKSANDR KUZNECOV	{"phone": "+70383688817"}
0005434182443	EAF5A6	0015 312401	VITALIY SEMENOV	{"email": "vsemenov.07011969@postgrespro.ru", "phone": "+70525745501"}
0005434182444	41BDBC	8333 469331	MARAT MAKAROV	{"phone": "+70112084570"}
0005434182445	904561	6958 332058	SERGEY VOLKOV	{"email": "sergey_volkov.041965@postgrespro.ru", "phone": "+70034009806"}
0005434182446	904561	3439 786733	NATALYA MEDVEDEVA	{"email": "natalya_medvedeva-1984@postgrespro.ru", "phone": "+70925535802"}
0005434182447	425021	0536 984222	ELVIRA SERGEEVA	{"phone": "+70280982028"}
0005434182448	F9FAD9	7777 107829	IRINA NOVIKOVA	{"phone": "+70666941548"}
0005434182449	F9FAD9	4358 860101	ANASTASIYA NIKOLAEVA	{"phone": "+70729538306"}
0005434182450	087B49	3507 061421	MARIYA SCHERBAKOVA	{"phone": "+70008735202"}
0005434182451	087B49	7451 520250	ELENA RYABOVA	{"email": "elenaryabova-30091976@postgrespro.ru", "phone": "+70745408852"}
0005434182452	CC7D9E	0821 483245	ALEKSANDR PETROV	{"email": "a_petrov-031979@postgrespro.ru", "phone": "+70120358878"}
0005434182453	FABD6D	8805 729113	YURIY FILIPPOV	{"email": "filippov-yuriy-1983@postgrespro.ru", "phone": "+70982168114"}
0005434182454	1BE95A	6659 282559	LARISA FEDOROVA	{"email": "l-fedorova1977@postgrespro.ru", "phone": "+70203551434"}
0005434182455	A25A87	8249 989276	SERGEY NIKITIN	{"email": "s_nikitin071979@postgrespro.ru", "phone": "+70107987750"}
0005434182456	7A0218	7528 722116	YANA KULIKOVA	{"phone": "+70052997688"}
0005434182457	5B4DBA	9244 271247	ELENA KOZLOVA	{"email": "kozlova-elena011987@postgrespro.ru", "phone": "+70508023336"}
0005434182458	CD13AD	9671 039560	MIKHAIL EGOROV	{"phone": "+70612369988"}
0005434182459	CD13AD	8269 417979	RUSLAN PAVLOV	{"email": "r.pavlov.111981@postgrespro.ru", "phone": "+70217088026"}
0005434182460	CD13AD	3516 828427	YURIY DENISOV	{"phone": "+70944085012"}
0005434182461	F66F65	5975 395014	NADEZHDA DAVYDOVA	{"phone": "+70570670422"}
0005434182462	F66F65	3815 815035	ALEKSANDR VASILEV	{"phone": "+70623674492"}
0005434182463	A5CA86	1554 147106	ALEKSANDR ILIN	{"phone": "+70282399320"}
0005434182464	D3BA7E	7397 580719	FEDOR SMIRNOV	{"email": "fedor-smirnov.23071975@postgrespro.ru", "phone": "+70986557822"}
0005434182465	D3BA7E	8381 880763	MARIYA KUZNECOVA	{"phone": "+70554875526"}
0005434182466	2C1213	5782 533158	ALEKSEY VASILEV	{"phone": "+70953679748"}
0005434182467	29D040	4333 297676	OLEG VOROBEV	{"phone": "+70806842845"}
0005434182468	860757	2286 630040	TAMARA GERASIMOVA	{"email": "gerasimova_tamara.16021975@postgrespro.ru", "phone": "+70163222805"}
0005434182469	BC26F8	7468 748272	NINA KAZAKOVA	{"phone": "+70501463027"}
0005434182470	BC26F8	7490 581254	TAMARA DANILOVA	{"phone": "+70496879149"}
0005434182471	BC26F8	9099 526321	DARYA NIKITINA	{"phone": "+70979200600"}
0005434182472	209981	3139 046354	LYUDMILA MAKAROVA	{"phone": "+70865072593"}
0005434182473	209981	0706 576964	TAMARA TITOVA	{"email": "titovatamara_13101976@postgrespro.ru", "phone": "+70832584775"}
0005434182474	3417AF	7972 180738	SVETLANA SERGEEVA	{"phone": "+70060936665"}
0005434182475	F46AB8	3597 163650	TATYANA BELYAEVA	{"email": "belyaeva_tatyana_1977@postgrespro.ru", "phone": "+70915907257"}
0005434182476	F46AB8	7701 904378	VIKTOR ZAKHAROV	{"email": "zakharov.viktor_11081977@postgrespro.ru", "phone": "+70452219957"}
0005434182477	3CDE65	4935 646407	NATALYA PETROVA	{"phone": "+70287204576"}
0005434182478	3CDE65	2710 976521	VIKTOR MELNIKOV	{"phone": "+70451909645"}
0005434182479	C622AE	3009 811520	SERGEY FILIPPOV	{"email": "filippov-s-031982@postgrespro.ru", "phone": "+70813027871"}
0005434182480	5068D3	6014 752261	SERGEY ROMANOV	{"phone": "+70872051662"}
0005434182481	5068D3	6085 492956	OLEG MATVEEV	{"phone": "+70584444980"}
0005434182482	7A7D01	5782 590156	ARTEM BONDARENKO	{"email": "bondarenkoa1968@postgrespro.ru", "phone": "+70156920287"}
0005434182483	295978	6642 580895	MIKHAIL BELOV	{"phone": "+70685209285"}
0005434182484	295978	6360 082093	DMITRIY DMITRIEV	{"email": "dmitriev_d08021965@postgrespro.ru", "phone": "+70962433250"}
0005434182485	900050	2305 509730	SVETLANA VOLKOVA	{"phone": "+70046605245"}
0005434182486	900050	4724 748021	DMITRIY MARTYNOV	{"email": "martynovd.29091972@postgrespro.ru", "phone": "+70089241634"}
0005434182487	900050	4304 303861	ELIZAVETA ANTONOVA	{"phone": "+70960856761"}
0005434182488	11AC4B	0372 698599	NADEZHDA PAVLOVA	{"email": "nadezhda-pavlova.061977@postgrespro.ru", "phone": "+70771943202"}
0005434182489	11AC4B	4294 225266	DAMIR KONOVALOV	{"email": "konovalovdamir.21031952@postgrespro.ru", "phone": "+70724984732"}
0005434182490	58884C	1924 315042	TATYANA MIRONOVA	{"email": "mironovat-1968@postgrespro.ru", "phone": "+70500183744"}
0005434182491	CFEBA0	8514 767276	NIKOLAY FROLOV	{"email": "frolov_nikolay_22011988@postgrespro.ru", "phone": "+70300964604"}
0005434182492	B425A9	5061 723482	VALENTIN SAVELEV	{"phone": "+70643034776"}
0005434182493	3B4278	2224 373672	SERGEY ILIN	{"email": "ilin.s111972@postgrespro.ru", "phone": "+70562939374"}
0005434182494	2BAE3F	2954 459591	DMITRIY FOMIN	{"email": "fomin_d031977@postgrespro.ru", "phone": "+70262593100"}
0005434182495	CD4312	6220 663208	TAMARA RODIONOVA	{"email": "rodionova-t-1965@postgrespro.ru", "phone": "+70705063829"}
0005434182496	8D1EEC	6178 436828	SERGEY KAZAKOV	{"phone": "+70141132331"}
0005434182497	E794AD	6017 467951	PETR POPOV	{"phone": "+70051162051"}
0005434182498	DC0168	5540 316601	YURIY ZAKHAROV	{"email": "zakharov-yuriy.011972@postgrespro.ru", "phone": "+70267748509"}
0005434182499	F439EA	0314 034918	NIKOLAY POPOV	{"email": "popov-nikolay.061963@postgrespro.ru", "phone": "+70437080665"}
0005434182500	82D76C	4951 912425	VALENTINA POPOVA	{"email": "popovavalentina.101972@postgrespro.ru", "phone": "+70656772887"}
0005434182501	73455E	9220 461565	DMITRIY KISELEV	{"phone": "+70430464968"}
0005434182502	8C86A4	1133 034660	SERGEY BELOV	{"email": "s-belov-1974@postgrespro.ru", "phone": "+70357468859"}
0005434182503	8C86A4	3181 715698	ALEKSANDR DMITRIEV	{"email": "admitriev-1966@postgrespro.ru", "phone": "+70259909882"}
0005434182504	48BD4C	8762 659590	SERGEY VASILEV	{"email": "s-vasilev091975@postgrespro.ru", "phone": "+70419319649"}
0005434182505	48BD4C	9880 333559	NIKOLAY IVANOV	{"email": "nikolay_ivanov.1972@postgrespro.ru", "phone": "+70018968108"}
0005434182506	E05196	2125 812446	VALENTINA MEDVEDEVA	{"phone": "+70931496378"}
0005434182507	E05196	0751 685872	NIKOLAY FEDOTOV	{"email": "fedotov-nikolay29121973@postgrespro.ru", "phone": "+70064984405"}
0005434182508	8599BB	1749 238013	IRINA KUZNECOVA	{"email": "kuznecova_irina-1979@postgrespro.ru", "phone": "+70428147635"}
0005434182509	D35A03	7024 769481	MURAT BORISOV	{"email": "murat.borisov051980@postgrespro.ru", "phone": "+70707074059"}
0005434182510	1638E4	6376 929099	IVAN ZAKHAROV	{"phone": "+70758366638"}
0005434182511	860625	8227 813090	VIKTOR MAKSIMOV	{"email": "maksimov-viktor-121979@postgrespro.ru", "phone": "+70178355840"}
0005434182512	32F412	9251 083642	NATALYA ANDREEVA	{"email": "andreevanatalya.05071967@postgrespro.ru", "phone": "+70297398594"}
0005434182513	921101	9982 163280	IRINA KOLESNIKOVA	{"email": "kolesnikovairina-1974@postgrespro.ru", "phone": "+70348522602"}
0005434183560	427517	9886 416709	VALENTINA MIKHAYLOVA	{"phone": "+70366713318"}
0005434182514	F4D638	2385 075663	IRINA ANTONOVA	{"email": "irina.antonova_25111968@postgrespro.ru", "phone": "+70159534370"}
0005434182515	419DCF	9680 017939	NIKOLAY BONDARENKO	{"email": "n.bondarenko_07031964@postgrespro.ru", "phone": "+70010235460"}
0005434182516	3F9F17	9157 665068	SEMEN IVANOV	{"phone": "+70422113457"}
0005434182517	F24F0B	1968 176053	OLGA NESTEROVA	{"phone": "+70159870114"}
0005434182518	F24F0B	2476 938936	ANASTASIYA GAVRILOVA	{"phone": "+70877102598"}
0005434182519	9116F2	5480 368802	OLEG DENISOV	{"email": "olegdenisov_05121972@postgrespro.ru", "phone": "+70543938599"}
0005434182520	9116F2	5299 730025	GALINA FILIPPOVA	{"email": "filippova_galina.051974@postgrespro.ru", "phone": "+70522273454"}
0005434182521	E93D67	5048 682660	DMITRIY ZHUKOV	{"email": "zhukov_dmitriy-031973@postgrespro.ru", "phone": "+70131490785"}
0005434182522	00C387	5775 825938	VIKTOR TIKHONOV	{"email": "tikhonovv031976@postgrespro.ru", "phone": "+70290435697"}
0005434182523	1C9C6B	3383 160945	DMITRIY FOMIN	{"email": "fomin_dmitriy_02081970@postgrespro.ru", "phone": "+70657606552"}
0005434182524	A58326	1167 157898	NADEZHDA OVCHINNIKOVA	{"phone": "+70587256974"}
0005434182525	7DEFF4	5151 545934	ALEKSANDRA KUZNECOVA	{"phone": "+70002007663"}
0005434182526	7DEFF4	8544 025083	DAMIR MIRONOV	{"email": "d.mironov_06021966@postgrespro.ru", "phone": "+70038988844"}
0005434182527	9790BA	7138 550340	SERGEY TIKHONOV	{"email": "tikhonov.sergey.1971@postgrespro.ru", "phone": "+70327508600"}
0005434182528	676AE3	8089 516525	GALINA PETROVA	{"email": "g-petrova-1973@postgrespro.ru", "phone": "+70666687284"}
0005434182529	8C26C5	9459 732214	VADIM SAVELEV	{"phone": "+70014494233"}
0005434182530	6F0507	8809 320385	NIKOLAY VOROBEV	{"phone": "+70419471457"}
0005434182531	2C6DE6	6402 508630	OKSANA YUDINA	{"phone": "+70015531420"}
0005434182532	2C6DE6	0350 277104	TATYANA DAVYDOVA	{"email": "t-davydova_1977@postgrespro.ru", "phone": "+70083159341"}
0005434182533	2C6DE6	3807 747181	ALEKSEY MIRONOV	{"email": "aleksey_mironov_051970@postgrespro.ru", "phone": "+70197684602"}
0005434182534	C1308E	5303 694036	IRINA LEBEDEVA	{"phone": "+70657538648"}
0005434182535	255BD3	2467 902594	NIKOLAY NAUMOV	{"phone": "+70952481589"}
0005434182536	255BD3	4994 527871	ALEKSANDR VASILEV	{"phone": "+70148821986"}
0005434182537	5FE3B5	7178 535387	MIKHAIL FEDOTOV	{"phone": "+70509802543"}
0005434182538	9CA4C6	9410 243315	ZOYA NIKIFOROVA	{"email": "nikiforova_z.01021979@postgrespro.ru", "phone": "+70273489857"}
0005434182539	9CA4C6	6771 522746	EKATERINA KUZNECOVA	{"email": "e_kuznecova.17111975@postgrespro.ru", "phone": "+70984586279"}
0005434182540	B3E13F	1380 507695	VALERIY FOMIN	{"email": "valeriy-fomin-081971@postgrespro.ru", "phone": "+70623545913"}
0005434182541	75FAE4	4634 416842	RAFAEL VASILEV	{"email": "rvasilev.21121973@postgrespro.ru", "phone": "+70568035952"}
0005434182542	B3EA42	7221 886191	ANTONINA EGOROVA	{"email": "egorovaantonina-1977@postgrespro.ru", "phone": "+70751977313"}
0005434182543	B3EA42	7441 443702	PAVEL ILIN	{"phone": "+70767410321"}
0005434182544	5F7CFF	6541 711231	GENNADIY YAKOVLEV	{"phone": "+70874978333"}
0005434182545	45CB0F	1912 980464	NATALYA ALEKSEEVA	{"phone": "+70885769757"}
0005434182546	E20E5C	4222 449305	INNA NIKITINA	{"email": "nikitinai.061965@postgrespro.ru", "phone": "+70708499089"}
0005434182547	E20E5C	8483 855338	VALENTINA KAZAKOVA	{"email": "kazakova_v_14061956@postgrespro.ru", "phone": "+70715752134"}
0005434182548	DC8A62	7105 231834	TATYANA PAVLOVA	{"email": "t_pavlova.1971@postgrespro.ru", "phone": "+70806629662"}
0005434182549	1062A3	8441 402225	NINA IVANOVA	{"email": "ninaivanova.061981@postgrespro.ru", "phone": "+70012995048"}
0005434182550	1062A3	4826 684200	TIMUR GAVRILOV	{"phone": "+70577649118"}
0005434182551	60F527	8083 618850	LILIYA KOROLEVA	{"email": "l.koroleva-19111972@postgrespro.ru", "phone": "+70635586840"}
0005434182552	5BFE8D	5360 056245	VERA DAVYDOVA	{"email": "vera_davydova071978@postgrespro.ru", "phone": "+70802024308"}
0005434182553	5BFE8D	1640 014484	MAKSIM NIKITIN	{"phone": "+70209829048"}
0005434182554	BCE898	2809 480397	SVETLANA IVANOVA	{"phone": "+70110466236"}
0005434182555	BCE898	8809 775442	VYACHESLAV TIKHONOV	{"email": "vyacheslav.tikhonov1983@postgrespro.ru", "phone": "+70315996741"}
0005434183543	7B2674	9382 232936	ANNA NAZAROVA	{"phone": "+70493507945"}
0005434183544	03D27B	8186 908954	ALEKSEY BONDARENKO	{"email": "bondarenko_a-01111961@postgrespro.ru", "phone": "+70050447616"}
0005434183545	EB2C00	5233 660357	VALERIY PETROV	{"phone": "+70301129435"}
0005434183546	EB2C00	6596 719973	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov-13091973@postgrespro.ru", "phone": "+70863886614"}
0005434183547	40882D	7166 768065	SERGEY TIKHONOV	{"phone": "+70877995912"}
0005434183548	1A1DF4	3327 717045	ELENA DMITRIEVA	{"email": "dmitrieva_elena-13031977@postgrespro.ru", "phone": "+70323071602"}
0005434183549	1A1DF4	2791 420107	IGOR OSIPOV	{"email": "osipov-igor_1970@postgrespro.ru", "phone": "+70626659030"}
0005434183550	6DB056	7248 491452	POLINA EFREMOVA	{"phone": "+70524793608"}
0005434183551	2CDC00	0759 672921	NADEZHDA CHERNOVA	{"phone": "+70876951863"}
0005434183552	5346DF	2415 277787	VLADIMIR VOLKOV	{"email": "v.volkov01011964@postgrespro.ru", "phone": "+70068093191"}
0005434183553	6E4D5E	0044 480386	ANDREY SEMENOV	{"phone": "+70110759352"}
0005434183554	6E4D5E	3227 897461	IRINA ERMAKOVA	{"email": "irina_ermakova_04061966@postgrespro.ru", "phone": "+70211314098"}
0005434183555	4DF920	0156 149024	SERGEY PETROV	{"email": "petrovs1987@postgrespro.ru", "phone": "+70076223509"}
0005434183556	1D09ED	2406 923257	TATYANA BARANOVA	{"phone": "+70968727948"}
0005434183557	743747	6756 617581	MARINA KISELEVA	{"email": "mkiseleva.121981@postgrespro.ru", "phone": "+70109049956"}
0005434183558	C6819D	8180 401791	VIKTORIYA KUZNECOVA	{"phone": "+70330523866"}
0005434183559	C6819D	1155 815392	EKATERINA VOLKOVA	{"email": "ekaterina.volkova_1970@postgrespro.ru", "phone": "+70449064378"}
0005434183561	3C42A3	8329 556324	VLADIMIR KAZAKOV	{"email": "v_kazakov1971@postgrespro.ru", "phone": "+70770376266"}
0005434183562	3C42A3	8566 783464	OLGA BORISOVA	{"phone": "+70625076175"}
0005434183563	25EACD	0128 915066	VIKTOR SERGEEV	{"email": "sergeev.viktor.09021981@postgrespro.ru", "phone": "+70408852701"}
0005434183564	3E80DE	0671 079441	YURIY KUZMIN	{"email": "y-kuzmin121968@postgrespro.ru", "phone": "+70612580194"}
0005434183565	3E80DE	5078 211720	VLADIMIR FEDOROV	{"email": "fedorovvladimir_15041974@postgrespro.ru", "phone": "+70191820360"}
0005434183566	A03D50	6412 820327	ANASTASIYA MELNIKOVA	{"phone": "+70704700011"}
0005434183567	A03D50	0860 606757	SERGEY KRASNOV	{"phone": "+70984652339"}
0005434183568	22173F	0808 229538	VALERIY KONOVALOV	{"email": "v-konovalov.1972@postgrespro.ru", "phone": "+70451522011"}
0005434183569	22173F	8924 980374	YURIY POPOV	{"email": "popov_y_1978@postgrespro.ru", "phone": "+70517875988"}
0005434183570	22173F	0186 146997	NIKOLAY KUZNECOV	{"email": "kuznecov-n.23041974@postgrespro.ru", "phone": "+70208445907"}
0005434183571	5C9912	0534 163181	SVETLANA ZHUKOVA	{"phone": "+70272191305"}
0005434183572	612E9D	2349 104837	LYUBOV CHERNOVA	{"phone": "+70153376372"}
0005434183573	D99B0A	4016 492158	SEMEN STEPANOV	{"email": "stepanov.semen_081975@postgrespro.ru", "phone": "+70187407897"}
0005434183574	B99818	5023 227121	ELENA KRASNOVA	{"phone": "+70957271092"}
0005434183575	B99818	8387 194391	TATYANA GUSEVA	{"email": "tatyana-guseva-20101979@postgrespro.ru", "phone": "+70452594668"}
0005434183576	811F35	5501 713422	NATALYA SOKOLOVA	{"email": "sokolova.natalya.17081976@postgrespro.ru", "phone": "+70982412148"}
0005434183577	D1473E	5016 699072	ANNA SOLOVEVA	{"phone": "+70869810756"}
0005434183578	800E33	5262 653021	FLYURA LEBEDEVA	{"email": "lebedeva-flyura.111980@postgrespro.ru", "phone": "+70543124239"}
0005434183579	BC94B7	5888 486175	ANATOLIY SCHERBAKOV	{"email": "scherbakov.a.1962@postgrespro.ru", "phone": "+70245941414"}
0005434183580	26A1E7	0786 594214	ANASTASIYA GORBUNOVA	{"email": "anastasiya.gorbunova.22051971@postgrespro.ru", "phone": "+70479251465"}
0005434183581	71BB61	2133 637196	VLADIMIR FEDOROV	{"phone": "+70040307207"}
0005434183582	9F22B7	8281 816849	SERGEY KUZNECOV	{"phone": "+70650049136"}
0005434183583	9F22B7	8407 105905	MARINA MAKAROVA	{"email": "mmakarova.1963@postgrespro.ru", "phone": "+70370504492"}
0005434183584	63556E	6711 733361	DMITRIY VASILEV	{"email": "dmitriyvasilev011979@postgrespro.ru", "phone": "+70781241302"}
0005434183585	63556E	8944 319449	NATALYA KOZLOVA	{"email": "natalya_kozlova-031972@postgrespro.ru", "phone": "+70196129229"}
0005434183586	691352	0975 340129	ALEKSANDR IVANOV	{"phone": "+70666938805"}
0005434183587	1CDB4B	5049 951929	YURIY ORLOV	{"phone": "+70803601654"}
0005434183588	F571D6	1384 661847	ROMAN MELNIKOV	{"phone": "+70253674272"}
0005434183589	F571D6	6077 043617	ANDREY POPOV	{"email": "popov-andrey_061972@postgrespro.ru", "phone": "+70942641388"}
0005434183590	C54F58	9300 631388	GENNADIY KOZLOV	{"email": "g_kozlov_1982@postgrespro.ru", "phone": "+70885148757"}
0005434183591	5E6A60	1732 075213	NIKOLAY POPOV	{"phone": "+70466078370"}
0005434183592	5E6A60	9618 719179	ANATOLIY VLASOV	{"email": "a.vlasov_18041966@postgrespro.ru", "phone": "+70961143968"}
0005434183593	FDD4DC	9233 233754	GALINA ALEKSEEVA	{"phone": "+70683126036"}
0005434183594	3AA7D8	1810 020609	VITALIY KOZLOV	{"email": "v_kozlov.051978@postgrespro.ru", "phone": "+70888055514"}
0005434183595	3AA7D8	6590 076622	MARINA NIKIFOROVA	{"email": "nikiforova_m_21061966@postgrespro.ru", "phone": "+70464596050"}
0005434183596	25039A	8285 729070	VLADIMIR FILIPPOV	{"phone": "+70097408914"}
0005434183597	4570DD	9054 404720	DENIS GAVRILOV	{"email": "denis-gavrilov.1968@postgrespro.ru", "phone": "+70327157310"}
0005434183598	530542	6511 018624	SVETLANA MAKAROVA	{"email": "makarovas_1981@postgrespro.ru", "phone": "+70684988933"}
0005434183599	8EA1D4	4508 598506	NATALYA YUDINA	{"email": "natalya.yudina_031973@postgrespro.ru", "phone": "+70746887636"}
0005434183600	B512AE	3634 830032	OLGA VASILEVA	{"phone": "+70175335429"}
0005434183601	B512AE	7971 197765	TAMARA EFIMOVA	{"email": "tamara_efimova1974@postgrespro.ru", "phone": "+70178226929"}
0005434183602	409319	4102 784227	DARYA SOLOVEVA	{"email": "solovevad091976@postgrespro.ru", "phone": "+70499898909"}
0005434183603	409319	7070 891501	MARINA MAKAROVA	{"email": "m.makarova.051979@postgrespro.ru", "phone": "+70094986526"}
0005434183604	73FEF6	7078 830878	LYUDMILA KUZMINA	{"phone": "+70420413452"}
0005434183605	8F55BF	3424 597060	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev-02071967@postgrespro.ru", "phone": "+70588564976"}
0005434183606	92B6EB	3226 524757	LUIZA PAVLOVA	{"email": "pavlova-l.1976@postgrespro.ru", "phone": "+70341934263"}
0005434183607	92B6EB	1950 262654	DANILA IVANOV	{"phone": "+70572682135"}
0005434183608	48DC5E	5524 034410	LYUBOV KARPOVA	{"email": "karpovalyubov_1961@postgrespro.ru", "phone": "+70505416403"}
0005434183609	48DC5E	9514 232252	RUSTAM MAKAROV	{"email": "makarov_rustam_13121974@postgrespro.ru", "phone": "+70260265431"}
0005434183610	B769AC	3923 713760	SERGEY VASILEV	{"phone": "+70163788955"}
0005434183611	81D279	2891 787079	VALENTINA MIKHAYLOVA	{"phone": "+70143871568"}
0005434183612	0AE231	7105 924276	MARGARITA MEDVEDEVA	{"email": "margarita-medvedeva1971@postgrespro.ru", "phone": "+70063282104"}
0005434183613	F2C1A0	3800 684813	ARTEM KARPOV	{"email": "artem_karpov-1972@postgrespro.ru", "phone": "+70299156459"}
0005434183614	2DBEF0	9112 665781	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov.091976@postgrespro.ru", "phone": "+70959993612"}
0005434183615	AD6736	4258 943232	ELENA TARASOVA	{"phone": "+70562236038"}
0005434183616	040865	9905 502787	VLADIMIR TIMOFEEV	{"phone": "+70503465581"}
0005434183617	040865	0338 346312	ANDREY IVANOV	{"phone": "+70087192902"}
0005434183618	6EE75C	8400 449297	SVETLANA AKIMOVA	{"phone": "+70356872683"}
0005434183619	810EEC	0126 474320	INESSA SAVELEVA	{"phone": "+70884498491"}
0005434183620	739165	1754 618952	NADEZHDA KULIKOVA	{"email": "kulikova_n-12011973@postgrespro.ru", "phone": "+70422965333"}
0005434183621	0A83E2	3807 227977	ANATOLIY MAKSIMOV	{"phone": "+70999167735"}
0005434183622	A64F9F	7814 284243	VALENTINA SOROKINA	{"email": "valentina-sorokina.111967@postgrespro.ru", "phone": "+70828312644"}
0005434183623	A64F9F	3840 366244	ANGELINA EGOROVA	{"phone": "+70604552242"}
0005434183624	D516FA	7065 098378	RINAT MIKHAYLOV	{"email": "rinat.mikhaylov_021973@postgrespro.ru", "phone": "+70707840210"}
0005434183625	F23F00	8709 299173	ILYA FEDOROV	{"email": "fedorov-ilya_13011967@postgrespro.ru", "phone": "+70243386557"}
0005434183626	E678F5	6059 936065	YURIY ZAKHAROV	{"phone": "+70221980061"}
0005434183627	E678F5	5665 334660	EKATERINA MATVEEVA	{"email": "matveevaekaterina.111967@postgrespro.ru", "phone": "+70411044183"}
0005434183628	94E3C3	6051 697071	ALEKSANDR VASILEV	{"email": "aleksandrvasilev_1964@postgrespro.ru", "phone": "+70066417306"}
0005434183629	5BCD62	7452 966070	OLGA MIKHAYLOVA	{"phone": "+70392586797"}
0005434183630	5F8549	9683 850004	IRINA MOISEEVA	{"email": "moiseeva_irina-1975@postgrespro.ru", "phone": "+70067267440"}
0005434183631	5956BC	0365 490009	VLADIMIR PETROV	{"email": "vladimirpetrov.081964@postgrespro.ru", "phone": "+70393752774"}
0005434183632	5956BC	8678 187050	OKSANA LUKYANOVA	{"email": "o-lukyanova_1963@postgrespro.ru", "phone": "+70213069010"}
0005434183633	5956BC	3482 169285	VIKTORIYA IVANOVA	{"email": "viktoriya-ivanova20111965@postgrespro.ru", "phone": "+70136059815"}
0005434183634	212402	6598 742587	SERGEY KAZAKOV	{"phone": "+70870679750"}
0005434183635	9BCCA9	2842 923187	ELENA ARKHIPOVA	{"phone": "+70665590753"}
0005434183636	9BCCA9	0718 455638	MARIYA KARPOVA	{"phone": "+70471697657"}
0005434183637	9BCCA9	2139 328829	ANGELINA NAUMOVA	{"phone": "+70669497502"}
0005434183638	A0A967	5887 294648	ALEKSEY TIMOFEEV	{"email": "a.timofeev_081962@postgrespro.ru", "phone": "+70013883147"}
0005434183639	A0A967	9536 851943	IRINA SERGEEVA	{"phone": "+70530057160"}
0005434184629	392EB9	2350 381397	IGOR GAVRILOV	{"phone": "+70001358895"}
0005434184630	392EB9	3927 170684	EVGENIY NIKITIN	{"email": "evgeniynikitin-101972@postgrespro.ru", "phone": "+70145464656"}
0005434184631	9BAA61	6350 700591	ELENA GERASIMOVA	{"email": "gerasimova.elena_041970@postgrespro.ru", "phone": "+70980827393"}
0005434184632	9BAA61	8506 333718	ALENA GERASIMOVA	{"phone": "+70942947537"}
0005434184633	8BAD52	7514 671328	ZOYA GORBUNOVA	{"email": "gorbunova-z.121971@postgrespro.ru", "phone": "+70185813195"}
0005434184634	20EC34	4571 484513	LYUDMILA BORISOVA	{"phone": "+70151766985"}
0005434184635	20EC34	1523 332779	DMITRIY SEMENOV	{"phone": "+70090764240"}
0005434184636	A65723	8412 869634	IGOR FOMIN	{"phone": "+70273825874"}
0005434184637	525443	9007 926143	LYUBOV KAZAKOVA	{"email": "lyubov_kazakova-1976@postgrespro.ru", "phone": "+70598060850"}
0005434184638	57E8E3	1410 675945	IVAN PAVLOV	{"phone": "+70491911500"}
0005434184639	57E8E3	9770 624399	MARIYA KUZMINA	{"phone": "+70202463046"}
0005434184640	72A609	6975 148139	VERA NAUMOVA	{"email": "naumovavera25041980@postgrespro.ru", "phone": "+70966202629"}
0005434184641	1498D0	0013 825077	ELENA DAVYDOVA	{"email": "e-davydova-1980@postgrespro.ru", "phone": "+70494217811"}
0005434184642	E030CB	0592 781977	RAVZA KUZMINA	{"email": "kuzmina_ravza-101981@postgrespro.ru", "phone": "+70377064723"}
0005434184643	E9B0D5	3869 994746	VALENTINA STEPANOVA	{"phone": "+70967449843"}
0005434184644	E9B0D5	5480 263765	VADIM NOVIKOV	{"phone": "+70543603195"}
0005434184645	8CEC74	8850 785735	ALEKSANDR MOROZOV	{"email": "morozovaleksandr.111985@postgrespro.ru", "phone": "+70133112719"}
0005434184646	8CEC74	8590 058163	BORIS KUZMIN	{"email": "bkuzmin.021966@postgrespro.ru", "phone": "+70539668085"}
0005434184647	062C53	4245 775689	SVETLANA POTAPOVA	{"phone": "+70898553030"}
0005434184648	062C53	1674 334868	VALERIY NOVIKOV	{"email": "vnovikov_031973@postgrespro.ru", "phone": "+70454718815"}
0005434184649	9293D8	2883 588187	LEONID ALEKSANDROV	{"email": "leonidaleksandrov_1971@postgrespro.ru", "phone": "+70392869072"}
0005434184650	4E753A	8520 292258	KRISTINA YAKOVLEVA	{"email": "k-yakovleva.30061966@postgrespro.ru", "phone": "+70723073620"}
0005434184651	4E753A	1608 842952	LEONID ROMANOV	{"email": "l.romanov-121979@postgrespro.ru", "phone": "+70833786553"}
0005434184652	908BC6	9260 634778	VALENTINA NOVIKOVA	{"phone": "+70784475155"}
0005434184653	6E339D	1750 583047	ALEKSANDR IVANOV	{"phone": "+70039899219"}
0005434184654	515ECC	9672 845777	ELENA ZHUKOVA	{"phone": "+70235480643"}
0005434184655	515ECC	4916 465578	MIKHAIL MOISEEV	{"email": "moiseev_m.1975@postgrespro.ru", "phone": "+70532162493"}
0005434184656	F5114E	8356 066782	VALERIY ANTONOV	{"phone": "+70601280268"}
0005434184657	8C29C5	6703 515323	DINARA SOLOVEVA	{"phone": "+70479476166"}
0005434184658	8C29C5	0379 049178	VLADIMIR VOROBEV	{"phone": "+70519430982"}
0005434184659	B5D006	2177 557474	IRINA POLYAKOVA	{"email": "i.polyakova-1965@postgrespro.ru", "phone": "+70256933411"}
0005434184660	25520B	8177 941066	VLADIMIR ALEKSANDROV	{"email": "valeksandrov1966@postgrespro.ru", "phone": "+70706921465"}
0005434184661	25520B	7883 461243	ANFISA AKIMOVA	{"email": "a_akimova-1982@postgrespro.ru", "phone": "+70242657770"}
0005434184662	A263FD	0525 258188	LYUDMILA POTAPOVA	{"email": "potapova.lyudmila-111971@postgrespro.ru", "phone": "+70053622821"}
0005434184663	C7F476	4201 458076	GALINA KOROLEVA	{"email": "galinakoroleva_1979@postgrespro.ru", "phone": "+70714439058"}
0005434184664	A0B255	2937 600171	BORIS KONOVALOV	{"email": "boris-konovalov-18031968@postgrespro.ru", "phone": "+70082232836"}
0005434184665	8A4FAB	5954 336592	NIKOLAY VLASOV	{"phone": "+70360658894"}
0005434184666	8A4FAB	3337 878274	ANNA FILATOVA	{"email": "a_filatova051960@postgrespro.ru", "phone": "+70042555765"}
0005434184667	63EF41	6665 720302	ANDREY VOROBEV	{"phone": "+70808528620"}
0005434186203	328DD9	6627 834614	LARISA PETROVA	{"phone": "+70825467726"}
0005434184668	9F8CF9	4430 692195	ANATOLIY ANTONOV	{"email": "a_antonov071961@postgrespro.ru", "phone": "+70427236583"}
0005434184669	C59165	4482 661240	IVAN TARASOV	{"email": "ivan.tarasov.28111977@postgrespro.ru", "phone": "+70152664130"}
0005434184670	C59165	2811 126187	VALENTINA SIDOROVA	{"email": "sidorova_valentina.061979@postgrespro.ru", "phone": "+70681647696"}
0005434184671	967496	5702 925767	NATALYA GERASIMOVA	{"email": "natalyagerasimova-1982@postgrespro.ru", "phone": "+70479522244"}
0005434184672	967496	1650 964976	ANNA TROFIMOVA	{"email": "trofimovaa-091971@postgrespro.ru", "phone": "+70682134796"}
0005434184673	796AEB	1214 197691	NIKOLAY SAVELEV	{"phone": "+70582533012"}
0005434184674	5E93F1	0710 986138	ALEKSEY ALEKSEEV	{"phone": "+70988293490"}
0005434184675	614223	7916 472668	GALINA BOGDANOVA	{"email": "bogdanova_galina.1962@postgrespro.ru", "phone": "+70966571942"}
0005434184676	F2B117	3146 168149	IGOR SOLOVEV	{"phone": "+70430548357"}
0005434184677	9BC3E3	2913 578526	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr021980@postgrespro.ru", "phone": "+70102109283"}
0005434184678	9BC3E3	9774 191793	VLADIMIR VLASOV	{"phone": "+70409776291"}
0005434184679	C19005	1121 093250	VALENTIN FOMIN	{"phone": "+70956974293"}
0005434184680	974C84	1054 937378	NATALIYA ZAKHAROVA	{"email": "nataliya.zakharova.1971@postgrespro.ru", "phone": "+70926504682"}
0005434184681	974C84	4463 831573	EKATERINA POLYAKOVA	{"email": "epolyakova-041975@postgrespro.ru", "phone": "+70038337423"}
0005434184682	520A26	8758 217089	NATALYA KARPOVA	{"phone": "+70117360779"}
0005434184683	4ECD2A	4263 090662	ANNA AFANASEVA	{"phone": "+70686936860"}
0005434184684	51A7FF	7393 594165	TATYANA KUZNECOVA	{"phone": "+70956207686"}
0005434184685	C61ABF	5849 533339	ELENA ZAKHAROVA	{"email": "e-zakharova_051966@postgrespro.ru", "phone": "+70659915278"}
0005434184686	AFBA12	6408 223750	ZINAIDA YAKOVLEVA	{"phone": "+70217063019"}
0005434184687	AFBA12	8040 112862	MARINA VOLKOVA	{"email": "marina-volkova.21071978@postgrespro.ru", "phone": "+70689522711"}
0005434184688	330703	6613 525544	NADEZHDA ZHURAVLEVA	{"email": "nzhuravleva_1968@postgrespro.ru", "phone": "+70481816247"}
0005434184689	AE3D07	7028 715536	RIMMA SMIRNOVA	{"phone": "+70917433812"}
0005434184690	AE3D07	1026 070401	MAKSIM NIKITIN	{"email": "m.nikitin-1978@postgrespro.ru", "phone": "+70933908925"}
0005434184691	EBA06F	4131 927020	IVAN IVANOV	{"email": "i_ivanov19081968@postgrespro.ru", "phone": "+70781608684"}
0005434184692	784512	1511 631586	MIKHAIL SEMENOV	{"email": "mikhailsemenov.1971@postgrespro.ru", "phone": "+70523801104"}
0005434184693	D0AECD	9393 554932	ELENA VOLKOVA	{"email": "volkova_elena.061974@postgrespro.ru", "phone": "+70146973701"}
0005434184694	0D3BAD	7828 898181	ALEKSANDR OSIPOV	{"email": "aleksandrosipov.1969@postgrespro.ru", "phone": "+70744682460"}
0005434184695	0D3BAD	9374 968911	KSENIYA SOLOVEVA	{"phone": "+70023212041"}
0005434184696	425D72	2145 166954	RASHID KONOVALOV	{"email": "konovalovrashid_011973@postgrespro.ru", "phone": "+70180415421"}
0005434184697	4E314C	2028 834013	DMITRIY MAKAROV	{"email": "makarovdmitriy.1980@postgrespro.ru", "phone": "+70586524827"}
0005434184698	9A5E19	0083 440449	DMITRIY IVANOV	{"email": "ivanov-dmitriy_09081956@postgrespro.ru", "phone": "+70228041499"}
0005434184699	D7EFDA	6109 674220	DENIS ISAEV	{"email": "isaevd_021972@postgrespro.ru", "phone": "+70810890868"}
0005434184700	5182E6	5558 336159	KIRILL SMIRNOV	{"phone": "+70891950899"}
0005434184701	783D8C	1854 877735	NIKOLAY KUZNECOV	{"phone": "+70706235711"}
0005434184702	783D8C	4131 086140	ANNA DAVYDOVA	{"email": "annadavydova.041979@postgrespro.ru", "phone": "+70617881400"}
0005434184703	A55F86	7793 512925	GALINA FILIPPOVA	{"phone": "+70768631969"}
0005434184704	A55F86	5890 676358	ELENA ANISIMOVA	{"phone": "+70561674493"}
0005434184705	A55F86	1606 539229	EKATERINA KONOVALOVA	{"phone": "+70157954011"}
0005434184706	658A73	4778 576580	MARIYA KUZNECOVA	{"email": "m-kuznecova.31071968@postgrespro.ru", "phone": "+70063719822"}
0005434184707	EAA12E	9407 623721	SERGEY BELOV	{"email": "belovs_12071969@postgrespro.ru", "phone": "+70242963563"}
0005434184708	AC31C3	8549 504637	NATALYA DAVYDOVA	{"phone": "+70028544909"}
0005434184709	C6EE6B	3957 374152	ELENA EFREMOVA	{"email": "efremova_e.1974@postgrespro.ru", "phone": "+70410468699"}
0005434184710	D79AFD	9839 657966	ELENA LAZAREVA	{"phone": "+70179556182"}
0005434184711	D79AFD	8304 401171	SVETLANA TIKHONOVA	{"email": "tikhonova-svetlana.1980@postgrespro.ru", "phone": "+70356980931"}
0005434184712	CA9159	8499 392551	ALEKSANDR MAKAROV	{"email": "a-makarov.111974@postgrespro.ru", "phone": "+70739464949"}
0005434184713	B6BF55	4038 380400	SERGEY GERASIMOV	{"email": "sergeygerasimov061975@postgrespro.ru", "phone": "+70109000634"}
0005434184714	F82278	3319 264863	IVAN TARASOV	{"email": "tarasovi031974@postgrespro.ru", "phone": "+70411608858"}
0005434184715	F82278	4912 883086	ANNA SOROKINA	{"email": "a-sorokina.28051976@postgrespro.ru", "phone": "+70476271033"}
0005434184716	A61FD1	7822 888073	ANATOLIY SIDOROV	{"email": "sidorov.anatoliy_1956@postgrespro.ru", "phone": "+70939388515"}
0005434184717	D12FBD	6661 553321	MAKSIM ILIN	{"email": "ilinmaksim.09061963@postgrespro.ru", "phone": "+70443628673"}
0005434184718	C10AEB	9446 259610	SERGEY KUDRYASHOV	{"email": "skudryashov_011980@postgrespro.ru", "phone": "+70477561118"}
0005434184719	D9FF49	9982 790752	GRIGORIY FROLOV	{"phone": "+70125226394"}
0005434184720	D9FF49	0574 410314	VLADIMIR VOROBEV	{"phone": "+70407609847"}
0005434184721	69B8BE	2491 179543	NINA BORISOVA	{"email": "nina.borisova.011955@postgrespro.ru", "phone": "+70219011864"}
0005434184722	40D2E9	4361 065628	DANIIL KAZAKOV	{"email": "kazakovd05051974@postgrespro.ru", "phone": "+70281421170"}
0005434184723	30E3C3	9022 181835	NADEZHDA TROFIMOVA	{"email": "trofimovan05121977@postgrespro.ru", "phone": "+70936610468"}
0005434184724	305E3E	1043 826106	NATALYA KUZNECOVA	{"email": "n.kuznecova_07081971@postgrespro.ru", "phone": "+70380951516"}
0005434186263	94328B	2731 915720	VIKTOR IVANOV	{"phone": "+70021374618"}
0005434184725	69CEB0	2048 653141	MIKHAIL DMITRIEV	{"email": "mikhaildmitriev.24061976@postgrespro.ru", "phone": "+70694865820"}
0005434184726	6CA339	3499 425504	IVAN NIKITIN	{"email": "i-nikitin-18071963@postgrespro.ru", "phone": "+70272008844"}
0005434184727	6CA339	8259 274554	VLADIMIR MATVEEV	{"email": "matveev.vladimir13071961@postgrespro.ru", "phone": "+70399557028"}
0005434184728	7C3D5E	6617 781971	IVAN VOROBEV	{"phone": "+70807611934"}
0005434186147	25BAD4	0782 909420	ALEKSANDR MOROZOV	{"phone": "+70122100052"}
0005434186148	EBA0A6	3044 025111	GALINA KONOVALOVA	{"email": "g-konovalova-12021976@postgrespro.ru", "phone": "+70429843808"}
0005434186149	EBA0A6	1533 499705	VADIM SCHERBAKOV	{"email": "v.scherbakov-04051969@postgrespro.ru", "phone": "+70513003015"}
0005434186150	B133D8	0201 890286	GALINA KALININA	{"phone": "+70993930211"}
0005434186151	B133D8	7861 428960	POLINA DAVYDOVA	{"phone": "+70276667266"}
0005434186152	B133D8	4290 997118	MARINA PAVLOVA	{"phone": "+70782587220"}
0005434186153	FE2D72	0752 680889	NINA NESTEROVA	{"email": "nesterova.n_13011981@postgrespro.ru", "phone": "+70564899135"}
0005434186154	5527CA	0978 101246	VLADIMIR KUZMIN	{"email": "vladimirkuzmin-23111969@postgrespro.ru", "phone": "+70885658237"}
0005434186155	278759	7690 045611	NATALYA FOMINA	{"phone": "+70145665612"}
0005434186156	278759	7155 453416	YULIYA EGOROVA	{"phone": "+70880846994"}
0005434186157	67F014	2164 321276	SVETLANA ANTONOVA	{"email": "antonova-s-26111973@postgrespro.ru", "phone": "+70505873975"}
0005434186158	35A1D6	9866 566107	RADIK SEMENOV	{"email": "semenov-radik-25051970@postgrespro.ru", "phone": "+70457192608"}
0005434186159	35A1D6	3363 302125	VALENTINA TITOVA	{"phone": "+70639692188"}
0005434186160	B3315C	7169 243526	YULIYA ZHUKOVA	{"phone": "+70521371435"}
0005434186161	FB6FED	9254 815108	VLADIMIR NOVIKOV	{"email": "novikov_vladimir_111977@postgrespro.ru", "phone": "+70466439213"}
0005434186162	FB6FED	0455 525560	ALEKSEY VOLKOV	{"phone": "+70033535303"}
0005434186163	55F027	6468 925475	RENAT MAKSIMOV	{"phone": "+70983106247"}
0005434186164	55F027	0018 577534	MARIYA SIDOROVA	{"phone": "+70072398153"}
0005434186165	380CBF	9421 639051	VIKTOR ANTONOV	{"phone": "+70915576945"}
0005434186166	14A5E0	1273 808912	VIKTORIYA POPOVA	{"email": "popovav_1969@postgrespro.ru", "phone": "+70412537904"}
0005434186167	CB9D70	1058 659804	RUSTAM SAVELEV	{"email": "savelev-rustam_021968@postgrespro.ru", "phone": "+70104691202"}
0005434186168	7ED474	9610 829050	DMITRIY MEDVEDEV	{"phone": "+70887482160"}
0005434186169	B8FBD7	7931 964379	MARIYA MOROZOVA	{"phone": "+70771915930"}
0005434186170	14755F	0624 905286	NIKOLAY PAVLOV	{"email": "pavlov-n.121975@postgrespro.ru", "phone": "+70480768481"}
0005434186171	14755F	9626 749250	KLAVDIYA MAKAROVA	{"email": "makarova-klavdiya.19081973@postgrespro.ru", "phone": "+70619286896"}
0005434186172	6D4F70	5092 432770	ALEKSANDR DENISOV	{"phone": "+70374506215"}
0005434186173	BC3F02	0967 558990	NIKOLAY FOMIN	{"email": "nikolay_fomin-25021970@postgrespro.ru", "phone": "+70317954408"}
0005434186174	BC3F02	0916 341840	ELENA FILATOVA	{"email": "filatova.e_1979@postgrespro.ru", "phone": "+70904806704"}
0005434186175	1D8BE2	6591 508241	ALEKSEY RODIONOV	{"phone": "+70587966597"}
0005434186176	B1B065	8552 540905	VLADIMIR NIKOLAEV	{"phone": "+70391904118"}
0005434186177	B1B065	5101 768970	MIKHAIL FEDOROV	{"email": "mikhail.fedorov_13111964@postgrespro.ru", "phone": "+70647312754"}
0005434186178	A3FBF8	6387 757258	EVGENIY PETROV	{"email": "evgeniypetrov-121974@postgrespro.ru", "phone": "+70002648366"}
0005434186179	FA46C0	4064 914968	VLADIMIR VASILEV	{"email": "vladimir.vasilev-111963@postgrespro.ru", "phone": "+70960815861"}
0005434186180	60507A	5688 303556	ALEVTINA KUZNECOVA	{"email": "a-kuznecova-071973@postgrespro.ru", "phone": "+70108970971"}
0005434186181	8127BB	9544 727478	ALLA VASILEVA	{"phone": "+70320611045"}
0005434186182	4BBBF4	6606 275298	ALEKSANDR BELOV	{"phone": "+70824055099"}
0005434186183	111260	6363 596478	EVGENIYA ROMANOVA	{"phone": "+70213449115"}
0005434186184	5EA0D0	5183 815184	EGOR ALEKSANDROV	{"phone": "+70540999682"}
0005434186185	7799AF	5542 215832	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_18081977@postgrespro.ru", "phone": "+70833735665"}
0005434186186	7799AF	6319 874675	VIKTOR SOROKIN	{"email": "sorokin.viktor_12061978@postgrespro.ru", "phone": "+70055855286"}
0005434186187	487964	0008 001913	BORIS FROLOV	{"email": "bfrolov_1967@postgrespro.ru", "phone": "+70449348255"}
0005434186188	487964	3634 211717	NATALIYA VOLKOVA	{"email": "n-volkova1977@postgrespro.ru", "phone": "+70572136507"}
0005434186189	BC895B	6998 613986	VIKTOR MOROZOV	{"email": "viktor-morozov.05121960@postgrespro.ru", "phone": "+70465141639"}
0005434186190	BC895B	1359 715689	TATYANA POPOVA	{"phone": "+70623576845"}
0005434186191	85FBA9	2127 267952	ANTONINA KUZNECOVA	{"email": "kuznecova-antonina-1973@postgrespro.ru", "phone": "+70731066568"}
0005434186192	AEFB94	9225 725656	ALEKSEY SERGEEV	{"email": "a.sergeev.1970@postgrespro.ru", "phone": "+70583118985"}
0005434186193	0C61DE	4046 869060	NADEZHDA NIKITINA	{"phone": "+70733357422"}
0005434186194	C0BC7A	5748 029404	EVGENIYA IVANOVA	{"phone": "+70717521827"}
0005434186195	C0BC7A	5191 099221	TAISIYA MATVEEVA	{"email": "matveeva.t.1968@postgrespro.ru", "phone": "+70690965741"}
0005434186196	D3CEA5	4398 634215	EVGENIY VOLKOV	{"phone": "+70885298549"}
0005434186197	D3CEA5	0305 589981	ANNA FOMINA	{"email": "a_fomina_1969@postgrespro.ru", "phone": "+70498330876"}
0005434186198	70F0B0	6961 336544	VLADIMIR KUDRYASHOV	{"phone": "+70640277463"}
0005434186199	4A05D9	1617 612230	OLGA PAVLOVA	{"phone": "+70203274343"}
0005434186200	20B392	4972 335496	EVGENIY KUZMIN	{"email": "e_kuzmin_041974@postgrespro.ru", "phone": "+70036588194"}
0005434186201	BD8B59	0062 417207	OLEG KOZLOV	{"email": "kozlov.oleg06011974@postgrespro.ru", "phone": "+70317621907"}
0005434186202	47A81B	7070 534924	EKATERINA YUDINA	{"email": "yudina_e-17021976@postgrespro.ru", "phone": "+70035272032"}
0005434186204	472272	5206 281911	SERGEY TIMOFEEV	{"email": "timofeev.sergey.10041974@postgrespro.ru", "phone": "+70231667221"}
0005434186205	472272	2863 813015	ANASTASIYA NOVIKOVA	{"email": "novikova.a-021977@postgrespro.ru", "phone": "+70979532640"}
0005434186206	D414B7	4015 725609	EKATERINA KOROLEVA	{"email": "e.koroleva.27111967@postgrespro.ru", "phone": "+70737012251"}
0005434186207	D414B7	5317 782586	GENNADIY ROMANOV	{"phone": "+70491979888"}
0005434186208	4C2A79	9855 193408	ALEKSANDR MEDVEDEV	{"email": "a_medvedev051979@postgrespro.ru", "phone": "+70732844771"}
0005434186209	71CC4A	2220 660364	SERGEY MOISEEV	{"phone": "+70789529071"}
0005434186210	71CC4A	2912 899151	MARINA KUZNECOVA	{"email": "kuznecovamarina1982@postgrespro.ru", "phone": "+70387812173"}
0005434186211	5B682F	5621 055436	PAVEL SOROKIN	{"email": "sorokin_p.1966@postgrespro.ru", "phone": "+70412069511"}
0005434186212	29EA5D	7483 890607	ANDREY IVANOV	{"phone": "+70599676660"}
0005434186213	29EA5D	5325 097254	VIKTOR SEMENOV	{"email": "v_semenov13061972@postgrespro.ru", "phone": "+70333054749"}
0005434186214	4548B0	6855 576775	ELENA RYABOVA	{"phone": "+70911454883"}
0005434186215	087AA8	4012 070837	ANATOLIY SCHERBAKOV	{"phone": "+70568851686"}
0005434186216	C01A62	0182 080397	ALEKSEY SOROKIN	{"email": "sorokinaleksey_011960@postgrespro.ru", "phone": "+70287394466"}
0005434186217	16B584	6701 473271	VERA MIRONOVA	{"phone": "+70779487443"}
0005434186218	16B584	5170 319090	KRISTINA POTAPOVA	{"phone": "+70623032121"}
0005434186219	D0D593	6278 547359	DANILA FROLOV	{"email": "frolov-danila-111960@postgrespro.ru", "phone": "+70656434383"}
0005434186220	94290F	5844 986522	SERGEY NAZAROV	{"email": "nazarov_s_1974@postgrespro.ru", "phone": "+70870835371"}
0005434186221	95C88F	3558 819095	IGOR VOLKOV	{"phone": "+70199643197"}
0005434186222	98EE34	1128 301725	NATALIYA KULIKOVA	{"phone": "+70466580761"}
0005434186223	8494B0	6680 324931	KONSTANTIN ISAEV	{"email": "isaevkonstantin.1975@postgrespro.ru", "phone": "+70290312541"}
0005434186224	8494B0	3858 534870	VLADIMIR GRIGOREV	{"email": "v.grigorev031971@postgrespro.ru", "phone": "+70138461456"}
0005434186225	A7A88F	7634 301436	TATYANA MAKSIMOVA	{"email": "t.maksimova_051977@postgrespro.ru", "phone": "+70386233507"}
0005434186226	6F8819	8115 339673	PAVEL IVANOV	{"email": "p_ivanov.12121960@postgrespro.ru", "phone": "+70954196724"}
0005434186227	C1CCAB	8427 920829	ANNA DENISOVA	{"email": "anna_denisova-1971@postgrespro.ru", "phone": "+70102767889"}
0005434186228	C1CCAB	1028 207809	VALENTINA IVANOVA	{"phone": "+70826774007"}
0005434186229	26B540	7300 789686	LYUBOV LEBEDEVA	{"phone": "+70248455762"}
0005434186230	CDFAE2	1882 659077	LYUBOV IVANOVA	{"phone": "+70123798536"}
0005434186231	914A81	1755 362953	MARINA IVANOVA	{"phone": "+70084401704"}
0005434186232	16D1FF	4897 438434	EVGENIY MOROZOV	{"phone": "+70482642461"}
0005434186233	9BFFC8	0542 446467	NADEZHDA NIKITINA	{"email": "nadezhda.nikitina-121965@postgrespro.ru", "phone": "+70255756432"}
0005434186234	59EF30	0412 501942	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov121966@postgrespro.ru", "phone": "+70858390774"}
0005434186235	60362B	3762 466803	ROMAN EGOROV	{"phone": "+70414400119"}
0005434186236	60362B	5738 411764	ALEKSANDR TIKHONOV	{"phone": "+70833352959"}
0005434186237	60362B	7631 706794	NIKITA KOZLOV	{"email": "nkozlov-071968@postgrespro.ru", "phone": "+70069458909"}
0005434186238	FF8A25	0132 813699	SVETLANA NIKOLAEVA	{"email": "s.nikolaeva-061962@postgrespro.ru", "phone": "+70123181989"}
0005434186239	FF8A25	2483 863559	RAISA GERASIMOVA	{"phone": "+70102648161"}
0005434186240	482235	3274 621486	ALEKSANDR IVANOV	{"phone": "+70382866202"}
0005434186241	CE383E	4448 259645	DMITRIY SIDOROV	{"email": "d_sidorov.01041982@postgrespro.ru", "phone": "+70202622734"}
0005434186242	E1AE8A	4744 591330	ILYA SIDOROV	{"email": "i.sidorov_15071967@postgrespro.ru", "phone": "+70607809110"}
0005434186243	8364AD	9487 160344	SOFYA ROMANOVA	{"email": "romanova_s1974@postgrespro.ru", "phone": "+70712941572"}
0005434186244	50BA85	8652 635083	VALERIY BARANOV	{"phone": "+70169853665"}
0005434186245	738193	2181 755765	NATALYA TIMOFEEVA	{"email": "timofeeva_n-26111970@postgrespro.ru", "phone": "+70553488885"}
0005434186246	738193	1226 524703	NADEZHDA ZHURAVLEVA	{"email": "nadezhda-zhuravleva.061975@postgrespro.ru", "phone": "+70882565926"}
0005434186247	738193	2685 085827	ALEKSEY POPOV	{"email": "aleksey_popov-18071973@postgrespro.ru", "phone": "+70862439344"}
0005434186248	734736	8447 050301	GALINA GAVRILOVA	{"email": "gavrilovag.1975@postgrespro.ru", "phone": "+70417626144"}
0005434186249	9F5DB0	5205 806037	MARAT DENISOV	{"phone": "+70803324547"}
0005434186250	9F5DB0	8165 370143	LYUBOV KONOVALOVA	{"email": "konovaloval.1969@postgrespro.ru", "phone": "+70217626351"}
0005434186251	E99EAD	9289 937994	VLADISLAV MIRONOV	{"email": "v_mironov20011963@postgrespro.ru", "phone": "+70373208766"}
0005434186252	E99EAD	5127 023329	ARTEM NIKOLAEV	{"phone": "+70204526304"}
0005434186253	EAB200	3919 014772	NADEZHDA LEBEDEVA	{"email": "lebedeva-nadezhda.1965@postgrespro.ru", "phone": "+70659489325"}
0005434186254	FF8EC8	8133 337049	LYUDMILA CHERNOVA	{"email": "chernovalyudmila101975@postgrespro.ru", "phone": "+70583845440"}
0005434186255	FF8EC8	0876 453114	ALEKSANDR SHEVCHENKO	{"phone": "+70065688114"}
0005434186256	FCE781	0785 026452	NIKOLAY ABRAMOV	{"email": "abramovnikolay.081963@postgrespro.ru", "phone": "+70836815579"}
0005434186257	FCE781	5156 411062	SERGEY PAVLOV	{"email": "spavlov_1973@postgrespro.ru", "phone": "+70566038573"}
0005434186258	FCE781	5104 433507	RAISA EGOROVA	{"phone": "+70350342847"}
0005434186259	48BA99	4164 099752	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d.1982@postgrespro.ru", "phone": "+70284248768"}
0005434186260	225981	2450 534800	ZINAIDA MAKAROVA	{"email": "z-makarova_1972@postgrespro.ru", "phone": "+70509947940"}
0005434186261	8175D3	6932 309442	GENNADIY MIKHAYLOV	{"email": "mikhaylov_g1978@postgrespro.ru", "phone": "+70316306591"}
0005434186262	94328B	7506 518109	LILIYA SMIRNOVA	{"phone": "+70276213336"}
0005434186264	94328B	2551 824374	ANDREY ALEKSEEV	{"email": "andreyalekseev1970@postgrespro.ru", "phone": "+70638684939"}
0005434186265	6659AF	2101 294170	LYUDMILA KOMAROVA	{"phone": "+70547993108"}
0005434186266	6659AF	4662 781218	NADEZHDA ZHURAVLEVA	{"phone": "+70793101199"}
0005434186267	3D37C8	3273 648130	EVGENIYA ZOTOVA	{"email": "zotova.evgeniya061968@postgrespro.ru", "phone": "+70882220907"}
0005434186268	C0A224	9132 970366	EVGENIYA POTAPOVA	{"email": "evgeniya_potapova.18051976@postgrespro.ru", "phone": "+70664179734"}
0005434186269	9CD06E	8791 001073	VASILIY GRIGOREV	{"email": "vasiliygrigorev-1970@postgrespro.ru", "phone": "+70985928848"}
0005434186270	EDE950	9664 611508	VIKTOR NOVIKOV	{"phone": "+70691756655"}
0005434186271	D2337D	7628 329535	VLADIMIR ANTONOV	{"email": "vladimirantonov1966@postgrespro.ru", "phone": "+70569058827"}
0005434186272	ADE20E	2460 187404	NATALYA FROLOVA	{"phone": "+70633766615"}
0005434186273	4B2A8F	7498 407387	ANDREY KUDRYASHOV	{"phone": "+70995542096"}
0005434186274	BB986A	0370 081817	OLGA KOLESNIKOVA	{"email": "kolesnikovaolga.1975@postgrespro.ru", "phone": "+70765914302"}
0005434186275	BB986A	7239 835351	ELENA BOGDANOVA	{"email": "elena-bogdanova_071968@postgrespro.ru", "phone": "+70088811342"}
0005434186276	987395	0972 884562	NIKOLAY SHEVCHENKO	{"email": "nshevchenko-1973@postgrespro.ru", "phone": "+70684835966"}
0005434186277	987395	9475 494664	OLEG SCHERBAKOV	{"phone": "+70774178261"}
0005434186278	42BF90	6882 972227	ALEKSEY FROLOV	{"email": "alekseyfrolov-081985@postgrespro.ru", "phone": "+70063177605"}
0005434186279	1683C4	9535 992421	MAKSIM FEDOROV	{"email": "m.fedorov_1981@postgrespro.ru", "phone": "+70929564228"}
0005434186280	D54B1E	4036 166462	ILYA YAKOVLEV	{"email": "yakovlev_i-081972@postgrespro.ru", "phone": "+70188789937"}
0005434186281	249393	2633 618215	ALENA MATVEEVA	{"phone": "+70660784939"}
0005434186282	6CBFC9	2467 841919	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr-28011980@postgrespro.ru", "phone": "+70964144966"}
0005434186283	6CBFC9	4225 815206	IVAN SEMENOV	{"phone": "+70737283522"}
0005434186284	6CBFC9	3888 771508	DMITRIY SHEVCHENKO	{"phone": "+70920421604"}
0005434186285	21B5BD	0841 626754	SERGEY SOROKIN	{"phone": "+70205575901"}
0005434186286	DBBE5F	3290 809120	DMITRIY TIKHONOV	{"phone": "+70775221584"}
0005434189245	F3CEBB	1269 852348	YURIY ZHUKOV	{"phone": "+70796448513"}
0005434189075	B6E10D	0304 742771	SERGEY MOROZOV	{"email": "s.morozov_071962@postgrespro.ru", "phone": "+70267907385"}
0005434189076	7BE90A	1722 120833	NIKOLAY ILIN	{"email": "ilin-n_011975@postgrespro.ru", "phone": "+70062277327"}
0005434189077	FFAD18	5199 217141	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova.1972@postgrespro.ru", "phone": "+70064582856"}
0005434189078	AEF210	9344 481801	AYRAT MOROZOV	{"email": "morozov-ayrat_1962@postgrespro.ru", "phone": "+70300894798"}
0005434189079	AEF210	8605 156596	SERGEY OSIPOV	{"email": "osipov-s.11101964@postgrespro.ru", "phone": "+70639222094"}
0005434189080	3F53CC	7746 124827	LARISA ROMANOVA	{"phone": "+70195420263"}
0005434189081	91A414	6329 329527	LEV KOZLOV	{"phone": "+70928964600"}
0005434189082	45C7AB	1117 123103	ALEKSEY MIKHAYLOV	{"email": "alekseymikhaylov-10051976@postgrespro.ru", "phone": "+70684089097"}
0005434189083	45C7AB	4021 580971	MIKHAIL KISELEV	{"email": "mkiselev_1968@postgrespro.ru", "phone": "+70621416206"}
0005434189084	84749F	4672 736916	VERA MASLOVA	{"phone": "+70629841158"}
0005434189085	643502	9013 410215	VIKTOR NAZAROV	{"phone": "+70194331989"}
0005434189086	0EF99A	9047 160721	PETR MAKSIMOV	{"phone": "+70799882833"}
0005434189087	28217C	0079 824980	VALERIY MAKSIMOV	{"phone": "+70818859562"}
0005434189088	87D7D2	2152 266934	TATYANA BOGDANOVA	{"phone": "+70450136392"}
0005434189089	545C9A	2126 810833	ALEKSEY SCHERBAKOV	{"email": "scherbakovaleksey-1979@postgrespro.ru", "phone": "+70796380776"}
0005434189090	EA535E	0247 610352	OLEG NIKOLAEV	{"phone": "+70568484222"}
0005434189091	203698	5869 276739	IVAN FILIPPOV	{"phone": "+70478489726"}
0005434189092	B5CC01	3343 088487	OLGA MAKAROVA	{"phone": "+70062832664"}
0005434189093	616F54	5875 108927	ELENA MOROZOVA	{"phone": "+70084467901"}
0005434189094	C06BF3	5670 040857	RAISA KUZMINA	{"email": "r.kuzmina_111956@postgrespro.ru", "phone": "+70456729997"}
0005434189095	5E6180	6303 730019	ELENA DENISOVA	{"email": "denisovaelena111965@postgrespro.ru", "phone": "+70286682934"}
0005434189096	D73CD8	4796 083736	ANNA ABRAMOVA	{"email": "abramova-anna_071971@postgrespro.ru", "phone": "+70404695421"}
0005434189097	CBA226	3971 821917	ARKADIY ANDREEV	{"email": "arkadiy_andreev_26011969@postgrespro.ru", "phone": "+70193177117"}
0005434189098	CBA226	1332 179584	MARGARITA STEPANOVA	{"phone": "+70695112797"}
0005434189099	18789F	1090 284913	ELLA MATVEEVA	{"email": "matveeva-ella.1975@postgrespro.ru", "phone": "+70636502390"}
0005434189100	4A1B92	3290 835590	SERGEY FOMIN	{"phone": "+70466291783"}
0005434189101	4A1B92	7682 053496	SERGEY NIKOLAEV	{"phone": "+70740527527"}
0005434189102	6EB605	2355 752054	DANIIL KUDRYASHOV	{"phone": "+70451056376"}
0005434189103	C84485	6307 448714	IRINA FEDOROVA	{"phone": "+70914064875"}
0005434189104	29A722	9614 241987	EKATERINA PETROVA	{"phone": "+70542751223"}
0005434189105	923F06	4248 058249	VADIM SMIRNOV	{"phone": "+70903600403"}
0005434189106	539BB2	1756 061270	RUSLAN SEMENOV	{"email": "semenov-ruslan_031971@postgrespro.ru", "phone": "+70430273688"}
0005434189107	539BB2	3376 090515	VIKTOR BONDARENKO	{"email": "bondarenko-viktor_031971@postgrespro.ru", "phone": "+70296332296"}
0005434189108	B9B308	9249 703868	DMITRIY ORLOV	{"phone": "+70880895630"}
0005434189109	734087	9226 419744	KLAVDIYA FEDOROVA	{"phone": "+70782468179"}
0005434189110	029626	8966 502397	MURAT MAKSIMOV	{"phone": "+70030573413"}
0005434189111	5A9624	7915 147195	VALERIYA BORISOVA	{"email": "borisova_v-08041984@postgrespro.ru", "phone": "+70220008694"}
0005434189112	5A9624	1819 953626	PAVEL KUDRYASHOV	{"email": "kudryashov-pavel_011959@postgrespro.ru", "phone": "+70352983452"}
0005434189113	5A9624	7803 068520	ALEKSEY KOZLOV	{"email": "kozlov-aleksey101966@postgrespro.ru", "phone": "+70279188513"}
0005434189114	46FCC8	1646 159073	VLADIMIR MAKAROV	{"email": "vladimir.makarov-01051966@postgrespro.ru", "phone": "+70971249635"}
0005434189115	46FCC8	0591 546988	LARISA DMITRIEVA	{"email": "larisa-dmitrieva-061976@postgrespro.ru", "phone": "+70087191362"}
0005434189116	46FCC8	1918 571856	LYUDMILA SIDOROVA	{"phone": "+70500191604"}
0005434189117	1BFB59	6461 363609	ELENA RODIONOVA	{"email": "rodionovaelena.1972@postgrespro.ru", "phone": "+70343299214"}
0005434189118	1BFB59	4379 268085	VLADIMIR SOLOVEV	{"phone": "+70831251580"}
0005434189119	B5FC94	2634 715225	LYUDMILA VOROBEVA	{"phone": "+70477950616"}
0005434189120	0AABD6	6520 944506	PETR CHERNOV	{"email": "chernov-petr_091977@postgrespro.ru", "phone": "+70954405247"}
0005434189121	0AABD6	9321 708331	NIKITA NIKOLAEV	{"phone": "+70358959184"}
0005434189122	5746E7	2550 884531	MARIYA MAKAROVA	{"email": "makarovamariya-24121965@postgrespro.ru", "phone": "+70371763128"}
0005434189123	187089	7266 153070	OLGA IVANOVA	{"email": "ivanova.olga011989@postgrespro.ru", "phone": "+70573634229"}
0005434189124	187089	4841 547827	KRISTINA MATVEEVA	{"phone": "+70295149359"}
0005434189125	187089	3227 274233	MARIYA STEPANOVA	{"email": "mariyastepanova1976@postgrespro.ru", "phone": "+70010277803"}
0005434189126	A81BA7	6266 130375	DENIS POPOV	{"phone": "+70731554711"}
0005434189127	A81BA7	2510 442567	IVAN IVANOV	{"phone": "+70202366343"}
0005434189128	780786	5574 577554	ALEKSEY ALEKSEEV	{"email": "alekseev-a-041964@postgrespro.ru", "phone": "+70579494436"}
0005434189129	CC5885	0007 510605	NINA BOGDANOVA	{"email": "bogdanova-n_1969@postgrespro.ru", "phone": "+70599008550"}
0005434189130	CC5885	2674 850026	DENIS ABRAMOV	{"phone": "+70893389738"}
0005434189131	E8FCAD	8841 825666	OLGA KUZNECOVA	{"phone": "+70481158602"}
0005434189132	2A7CB0	6802 929379	VARVARA POPOVA	{"email": "popovav-1971@postgrespro.ru", "phone": "+70839142187"}
0005434189246	FEED08	8835 561478	VLADIMIR VLASOV	{"phone": "+70697977299"}
0005434189133	2A7CB0	9813 459310	LYUDMILA SIDOROVA	{"email": "lyudmila.sidorova01041976@postgrespro.ru", "phone": "+70359786386"}
0005434189134	2A7CB0	7626 375089	SERGEY EGOROV	{"phone": "+70773343466"}
0005434189135	F15034	7712 184193	VASILIY ANTONOV	{"phone": "+70208157704"}
0005434189136	F15034	5185 411945	VLADISLAV IVANOV	{"phone": "+70549381277"}
0005434189137	E72379	5151 805804	YULIYA NESTEROVA	{"phone": "+70041422052"}
0005434189138	E72379	4553 937353	VIKTOR FROLOV	{"phone": "+70167225234"}
0005434189139	58A614	2775 438087	ALEKSANDR FILIPPOV	{"email": "filippov-a-1976@postgrespro.ru", "phone": "+70915213091"}
0005434189140	58A614	8692 739269	TATYANA ANTONOVA	{"email": "tantonova1956@postgrespro.ru", "phone": "+70998388868"}
0005434189141	A78FD0	7178 627642	ELENA LAZAREVA	{"phone": "+70358383443"}
0005434189142	56E491	3683 051511	ELENA NIKITINA	{"phone": "+70573769947"}
0005434189143	689575	6898 618664	VALENTINA KOZLOVA	{"email": "kozlova_v_021962@postgrespro.ru", "phone": "+70542426709"}
0005434189144	FCB217	5515 878351	MARINA YAKOVLEVA	{"email": "m_yakovleva_1973@postgrespro.ru", "phone": "+70639891181"}
0005434189145	FCB217	4388 024445	SERGEY SAVELEV	{"phone": "+70333599983"}
0005434189146	286379	0276 514300	ZOYA ROMANOVA	{"email": "zromanova1974@postgrespro.ru", "phone": "+70994659882"}
0005434189147	668396	9906 849465	IRINA SIDOROVA	{"email": "i-sidorova_011961@postgrespro.ru", "phone": "+70820342182"}
0005434189148	668396	2514 369220	ANFISA ZHUKOVA	{"email": "a-zhukova_1965@postgrespro.ru", "phone": "+70430801911"}
0005434189149	91BFBF	7917 164272	KSENIYA KUZNECOVA	{"email": "k-kuznecova071975@postgrespro.ru", "phone": "+70151668998"}
0005434189150	00F618	2992 147370	IGOR AFANASEV	{"email": "afanasev-i.22031966@postgrespro.ru", "phone": "+70897671487"}
0005434189151	00F618	9113 312082	PAVEL NIKOLAEV	{"email": "pavel.nikolaev081976@postgrespro.ru", "phone": "+70524363315"}
0005434189152	05EC68	2226 938122	NADEZHDA FILIPPOVA	{"email": "nadezhda_filippova1970@postgrespro.ru", "phone": "+70633422843"}
0005434189153	9EF7D1	9729 780809	LYUBOV BELOVA	{"phone": "+70868829834"}
0005434189154	FA25E8	8472 340122	ALEKSANDR VOLKOV	{"email": "volkova.051965@postgrespro.ru", "phone": "+70927537918"}
0005434189155	FA25E8	2200 211734	MAKSIM IVANOV	{"phone": "+70081402625"}
0005434189156	6BB89B	3574 286254	VALENTINA PAVLOVA	{"phone": "+70583030824"}
0005434189157	B75570	5256 733117	ALEKSANDR NOVIKOV	{"email": "novikov-a1982@postgrespro.ru", "phone": "+70192267350"}
0005434189158	B75570	6146 571976	ALENA MATVEEVA	{"email": "a.matveeva021976@postgrespro.ru", "phone": "+70217308835"}
0005434189159	DF2263	7118 651940	EVGENIY ANDREEV	{"email": "evgeniy_andreev.051976@postgrespro.ru", "phone": "+70531882989"}
0005434189160	0A8D90	1820 575172	VIKTOR NIKITIN	{"phone": "+70551271705"}
0005434189161	0A8D90	7538 604408	SERGEY GERASIMOV	{"email": "s.gerasimov.091967@postgrespro.ru", "phone": "+70866191509"}
0005434189162	7E076D	1489 151696	ILYA KULIKOV	{"email": "kulikov_i-13101972@postgrespro.ru", "phone": "+70351738088"}
0005434189163	742BAA	1859 594894	GALINA ILINA	{"email": "galina-ilina_061964@postgrespro.ru", "phone": "+70504191724"}
0005434189164	742BAA	5331 855336	ANNA KOROLEVA	{"phone": "+70708768508"}
0005434189165	37F3C0	6699 527027	VALERIY KOROLEV	{"phone": "+70338421912"}
0005434189166	1718BB	3546 539681	VYACHESLAV FROLOV	{"phone": "+70018468003"}
0005434189167	03E65D	6870 999396	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana.22101974@postgrespro.ru", "phone": "+70467008855"}
0005434189168	03E65D	3624 082104	VLADIMIR ILIN	{"phone": "+70209156782"}
0005434189169	03E65D	5848 648016	ALEKSANDR BONDARENKO	{"phone": "+70947309071"}
0005434189170	F17E67	2932 399908	OLESYA KOLESNIKOVA	{"email": "olesya.kolesnikova.30121972@postgrespro.ru", "phone": "+70590134167"}
0005434189171	F17E67	3065 381023	KRISTINA ORLOVA	{"phone": "+70427731741"}
0005434189172	67BD8F	1804 976242	ROZALIYA IVANOVA	{"email": "ivanovar-26071980@postgrespro.ru", "phone": "+70845942945"}
0005434189173	0AA5D1	9608 875853	MIKHAIL ANDREEV	{"phone": "+70794818514"}
0005434189174	4E7774	0134 512306	LYUDMILA ROMANOVA	{"phone": "+70089875981"}
0005434189175	7B7BDC	1598 880991	VERA YAKOVLEVA	{"email": "yakovleva-v-31081971@postgrespro.ru", "phone": "+70900163205"}
0005434189176	7B7BDC	4036 243008	DINA ZAKHAROVA	{"phone": "+70554271294"}
0005434189177	7B7BDC	4160 713274	YULIYA RODIONOVA	{"email": "rodionova_yuliya1970@postgrespro.ru", "phone": "+70389808312"}
0005434189178	D3CB60	1941 715573	SVETLANA ALEKSEEVA	{"phone": "+70461320731"}
0005434189179	3A75CB	2192 018778	VALENTIN ZAKHAROV	{"phone": "+70771342975"}
0005434189180	3A75CB	4632 349467	EKATERINA KISELEVA	{"email": "ekaterinakiseleva-1985@postgrespro.ru", "phone": "+70847728736"}
0005434189181	686F6B	7246 401194	ANDREY GORBUNOV	{"phone": "+70881698758"}
0005434189182	7E9567	6275 157371	NATALYA LAZAREVA	{"phone": "+70929742781"}
0005434189183	7E9567	7897 065377	NINA KOROLEVA	{"email": "nina.koroleva-1972@postgrespro.ru", "phone": "+70789072218"}
0005434189184	7E9567	7573 912664	ANTONINA ZAYCEVA	{"email": "zayceva.antonina-1972@postgrespro.ru", "phone": "+70507788077"}
0005434189185	B2D2D0	5335 118142	PETR SCHERBAKOV	{"email": "pscherbakov1964@postgrespro.ru", "phone": "+70908356056"}
0005434189186	B2D2D0	0656 700243	NIKOLAY AFANASEV	{"phone": "+70176058569"}
0005434189187	2B4D5F	5777 933463	VLADIMIR YAKOVLEV	{"email": "yakovlev.v-25091983@postgrespro.ru", "phone": "+70877330463"}
0005434189188	E8393B	4156 403710	GENNADIY SEMENOV	{"phone": "+70178340981"}
0005434189189	4191B2	7543 028604	ANATOLIY IVANOV	{"email": "ivanov.anatoliy_1963@postgrespro.ru", "phone": "+70602728928"}
0005434189190	E9B59F	4681 187147	DMITRIY GAVRILOV	{"email": "dmitriy_gavrilov_1978@postgrespro.ru", "phone": "+70424706983"}
0005434189191	AE1CCF	6768 546194	STEPAN OSIPOV	{"phone": "+70796559785"}
0005434189192	7E031B	0394 876554	ELENA GRISHINA	{"phone": "+70314598154"}
0005434189193	AC8FA9	0938 237365	VLADIMIR SOKOLOV	{"email": "vsokolov031966@postgrespro.ru", "phone": "+70180637699"}
0005434189194	5C2964	9189 446424	NINA MAKAROVA	{"phone": "+70152968803"}
0005434189195	C66AD4	1720 428457	ALEKSEY OSIPOV	{"email": "osipov.a-07111969@postgrespro.ru", "phone": "+70932661229"}
0005434189196	C66AD4	2623 012297	DENIS EGOROV	{"email": "d.egorov.031978@postgrespro.ru", "phone": "+70127334708"}
0005434189197	C66AD4	4290 708574	VALENTINA KOLESNIKOVA	{"email": "kolesnikova.v_071975@postgrespro.ru", "phone": "+70536634705"}
0005434189198	CF0134	7814 900210	LYUBOV ANDREEVA	{"phone": "+70016059723"}
0005434189199	CF0134	0540 525956	ALEKSEY ILIN	{"email": "a-ilin-071966@postgrespro.ru", "phone": "+70368476165"}
0005434189200	948726	0917 471101	ALEKSEY CHERNOV	{"phone": "+70687065410"}
0005434189201	C88A3B	7530 224450	ROMAN POPOV	{"email": "roman-popov1966@postgrespro.ru", "phone": "+70175507717"}
0005434189202	C88A3B	0633 088196	ALEKSANDR DAVYDOV	{"email": "davydov_a.02011988@postgrespro.ru", "phone": "+70384852699"}
0005434189203	0A41A4	5140 874128	ANDREY DAVYDOV	{"email": "davydovandrey051977@postgrespro.ru", "phone": "+70936491896"}
0005434189204	103C5E	3532 691028	EKATERINA VASILEVA	{"email": "vasilevaekaterina_23031964@postgrespro.ru", "phone": "+70628843059"}
0005434189205	0CE3A1	7187 688437	TATYANA ZAKHAROVA	{"phone": "+70004585868"}
0005434189206	0CE3A1	5548 950022	POLINA RYABOVA	{"phone": "+70083988577"}
0005434189207	B5B3A5	9975 886861	IVAN GRIGOREV	{"phone": "+70940791178"}
0005434189208	B5B3A5	8575 759669	KRISTINA KULIKOVA	{"phone": "+70041491463"}
0005434189209	5D83D5	1197 609107	IRINA NIKITINA	{"email": "nikitinai.021956@postgrespro.ru", "phone": "+70306742780"}
0005434189210	6C659B	1316 914403	NIKOLAY ORLOV	{"email": "orlov_n051966@postgrespro.ru", "phone": "+70760751563"}
0005434189211	7225DA	2929 893372	EVGENIY KUZNECOV	{"email": "evgeniykuznecov_28081961@postgrespro.ru", "phone": "+70283800064"}
0005434189212	130BE3	1915 896722	ANNA BARANOVA	{"phone": "+70902753975"}
0005434189213	130BE3	5990 435282	DIANA KALININA	{"email": "d_kalinina.28051983@postgrespro.ru", "phone": "+70680089456"}
0005434189214	ECE96F	8215 287863	TATYANA SIDOROVA	{"phone": "+70275993166"}
0005434189215	ECE96F	7505 259804	EKATERINA STEPANOVA	{"email": "ekaterina-stepanova-31071966@postgrespro.ru", "phone": "+70225510692"}
0005434189216	4F0DFF	3691 186387	TATYANA KONOVALOVA	{"phone": "+70633990999"}
0005434189217	4F0DFF	6605 726775	TATYANA PETROVA	{"email": "petrova.t051981@postgrespro.ru", "phone": "+70465393920"}
0005434189218	5BDD28	7062 085082	OLGA FOMINA	{"phone": "+70892316667"}
0005434189219	5BDD28	3611 267264	VLADIMIR BONDARENKO	{"email": "v-bondarenko_12091965@postgrespro.ru", "phone": "+70022551799"}
0005434189220	5BDD28	0357 316280	FATIMA EFIMOVA	{"phone": "+70048343424"}
0005434189221	3F86D0	3930 680307	FEDOR MAKSIMOV	{"email": "fmaksimov.07071990@postgrespro.ru", "phone": "+70807537073"}
0005434189222	2F84BC	4297 216736	VLADIMIR ALEKSANDROV	{"phone": "+70173583135"}
0005434189223	2F84BC	7964 759742	LYUDMILA ZAYCEVA	{"email": "lyudmila.zayceva1974@postgrespro.ru", "phone": "+70869159488"}
0005434189224	2F84BC	8624 103925	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_011976@postgrespro.ru", "phone": "+70026385141"}
0005434189225	2F84BC	2543 209771	EKATERINA ANDREEVA	{"phone": "+70962437718"}
0005434189226	829E05	7324 478725	KIRILL ORLOV	{"email": "orlov-k05061960@postgrespro.ru", "phone": "+70611632013"}
0005434189227	0B6584	3969 086854	NADEZHDA FROLOVA	{"phone": "+70699260785"}
0005434189228	1841A5	4237 732011	IVAN KONOVALOV	{"phone": "+70176742382"}
0005434189229	1841A5	5265 042797	DENIS ZAKHAROV	{"email": "zakharov-d1968@postgrespro.ru", "phone": "+70247910691"}
0005434189230	F94573	6889 322795	MARINA MIKHAYLOVA	{"phone": "+70655014949"}
0005434189231	F94573	1396 407146	ANASTASIYA MAKAROVA	{"email": "makarova_anastasiya_121972@postgrespro.ru", "phone": "+70583783175"}
0005434189232	14FB7F	7847 793920	SERGEY NAZAROV	{"email": "nazarov-sergey_1978@postgrespro.ru", "phone": "+70150950843"}
0005434189233	14FB7F	5773 832269	SERGEY SAVELEV	{"email": "s.savelev-11081975@postgrespro.ru", "phone": "+70693873750"}
0005434189234	9B6893	3619 782951	ARTUR ABRAMOV	{"phone": "+70992246614"}
0005434189235	454BBC	5734 267656	ELENA ANDREEVA	{"email": "e.andreeva.1971@postgrespro.ru", "phone": "+70067356540"}
0005434189236	89FBC1	0221 578953	GEORGIY KUZNECOV	{"email": "kuznecov.georgiy-041976@postgrespro.ru", "phone": "+70316278428"}
0005434189237	9873AA	4351 586203	VALENTINA BORISOVA	{"phone": "+70018197274"}
0005434189238	9873AA	2220 737884	TATYANA NAUMOVA	{"email": "naumova.tatyana_23061969@postgrespro.ru", "phone": "+70788787228"}
0005434189239	3AD049	1143 738621	NATALYA KOROLEVA	{"phone": "+70030130826"}
0005434189240	BBDBE2	9291 308618	NATALIYA KUZNECOVA	{"email": "kuznecova-n_01101967@postgrespro.ru", "phone": "+70164614804"}
0005434189241	79F275	2455 104880	VLADIMIR CHERNOV	{"phone": "+70740244939"}
0005434189242	297211	1748 013168	PAVEL MEDVEDEV	{"phone": "+70978964778"}
0005434189243	8CC33F	8643 394242	VALENTINA VASILEVA	{"phone": "+70017497616"}
0005434189244	8CC33F	0974 335475	OLESYA IVANOVA	{"phone": "+70273572322"}
0005434189247	BEF0A2	6630 532801	GALINA GERASIMOVA	{"email": "gerasimova-galina-071965@postgrespro.ru", "phone": "+70438978761"}
0005434189248	006B2A	1977 569416	DMITRIY ZAKHAROV	{"phone": "+70739129764"}
0005434189249	552788	0221 129645	ANTONINA EGOROVA	{"email": "a.egorova-1964@postgrespro.ru", "phone": "+70685938932"}
0005434189250	381D32	4252 231130	ALEKSEY NAZAROV	{"email": "nazarov_aleksey-05091976@postgrespro.ru", "phone": "+70262071017"}
0005434189251	AE5E07	5921 655337	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_1975@postgrespro.ru", "phone": "+70636105619"}
0005434189252	AE5E07	8173 761091	VALERIYA ZAKHAROVA	{"phone": "+70023725591"}
0005434189253	1B3830	7243 197328	ANTON ZHUKOV	{"phone": "+70607940774"}
0005434189254	7B7872	2202 651593	NATALYA KUZNECOVA	{"phone": "+70401728723"}
0005434189255	7B7872	8366 806073	NADEZHDA DMITRIEVA	{"phone": "+70984631539"}
0005434189256	3739E6	1169 252426	ALEKSANDRA AFANASEVA	{"email": "aleksandra.afanaseva.111966@postgrespro.ru", "phone": "+70528729042"}
0005434189257	1CBF77	3596 703948	MARINA PETROVA	{"phone": "+70863120207"}
0005434189258	E5CF64	5052 719865	TATYANA FEDOROVA	{"phone": "+70605262541"}
0005434189259	2AAE2D	6917 642127	IRINA VLASOVA	{"email": "irina.vlasova-121973@postgrespro.ru", "phone": "+70986738674"}
0005434189260	522FF1	0885 858502	GALINA FROLOVA	{"phone": "+70572156311"}
0005434189261	522FF1	4675 014420	VITALIY MATVEEV	{"email": "vitaliy_matveev.1969@postgrespro.ru", "phone": "+70518015342"}
0005434189262	522FF1	3670 072776	ANASTASIYA SAVELEVA	{"email": "saveleva_anastasiya121969@postgrespro.ru", "phone": "+70616909905"}
0005434189263	FDC8DD	9281 619951	YURIY ZHURAVLEV	{"phone": "+70150109790"}
0005434189264	4D5552	0116 125339	ANNA NIKOLAEVA	{"email": "nikolaevaa08081972@postgrespro.ru", "phone": "+70665585203"}
0005434189265	4D5552	8967 942673	ANNA IVANOVA	{"email": "ivanova-a.12091970@postgrespro.ru", "phone": "+70972816591"}
0005434189266	84DA5A	6191 387225	ALEKSANDR SOKOLOV	{"phone": "+70409169630"}
0005434189267	59C58E	5763 814033	ZINAIDA YUDINA	{"email": "z_yudina_091973@postgrespro.ru", "phone": "+70816292029"}
0005434189268	0F8D44	0595 872817	MAKSIM GRIGOREV	{"phone": "+70024414642"}
0005434189269	0F8D44	7254 540532	ELIZAVETA STEPANOVA	{"phone": "+70535294998"}
0005434189270	B76FB7	8831 470245	LYUBOV BOGDANOVA	{"phone": "+70922066141"}
0005434189271	B76FB7	9037 541783	VERA DMITRIEVA	{"phone": "+70483241709"}
0005434189272	995347	7972 874876	ANNA ZHUKOVA	{"email": "zhukovaa.15121988@postgrespro.ru", "phone": "+70140536496"}
0005434189273	61B1D4	3261 296138	RIMA DANILOVA	{"email": "danilovarima-1977@postgrespro.ru", "phone": "+70046252027"}
0005434189274	2450A4	9528 104987	SVETLANA EFIMOVA	{"phone": "+70514803483"}
0005434189275	D90BFB	1904 759524	ANDREY FOMIN	{"phone": "+70547982424"}
0005434189276	D90BFB	5664 233814	VALENTINA VASILEVA	{"phone": "+70919954835"}
0005434189277	205193	8125 403750	TATYANA ABRAMOVA	{"phone": "+70454772789"}
0005434189278	205193	3978 012729	ANDREY NIKITIN	{"email": "andrey_nikitin26091974@postgrespro.ru", "phone": "+70821240972"}
0005434189279	5BBFCF	1688 384861	IVAN SIDOROV	{"email": "ivan.sidorov071978@postgrespro.ru", "phone": "+70019193473"}
0005434189280	82DF15	8069 240666	MARIYA NIKITINA	{"phone": "+70844073916"}
0005434189281	9F52EF	1358 387891	IRINA PAVLOVA	{"phone": "+70825034476"}
0005434189282	9F52EF	6204 081745	SERGEY KOZLOV	{"phone": "+70713255413"}
0005434189283	616389	0196 229871	DANIIL FEDOROV	{"email": "fedorov_d_011963@postgrespro.ru", "phone": "+70429461237"}
0005434189284	8A8A40	2964 830087	IRINA PETROVA	{"email": "petrova_irina_101985@postgrespro.ru", "phone": "+70993056579"}
0005434189285	8691B4	4877 797629	VASILIY KONOVALOV	{"email": "vkonovalov031982@postgrespro.ru", "phone": "+70612895166"}
0005434189286	F9311F	8996 062212	SERGEY KARPOV	{"phone": "+70931195815"}
0005434189287	6E6E29	4476 128311	FEDOR FEDOROV	{"phone": "+70467364595"}
0005434189288	84787A	5899 975188	ILYAS NIKITIN	{"email": "nikitin_i-1963@postgrespro.ru", "phone": "+70994427557"}
0005434189289	D362F5	1587 726543	VIKTOR ALEKSANDROV	{"phone": "+70114146921"}
0005434189290	F9EABF	2643 256548	ANTONINA NIKITINA	{"email": "a-nikitina031975@postgrespro.ru", "phone": "+70286652579"}
0005434189291	F9EABF	3441 423833	ZOYA DMITRIEVA	{"phone": "+70528283916"}
0005434189292	6CAB36	6604 410502	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr.21041970@postgrespro.ru", "phone": "+70746296508"}
0005434189293	A59C05	6675 085428	ALEKSANDRA LUKYANOVA	{"phone": "+70257274565"}
0005434189294	444E42	6846 555201	VIKTOR KUZNECOV	{"email": "v-kuznecov-081972@postgrespro.ru", "phone": "+70928980139"}
0005434189295	57A6B2	6837 656864	IVAN YAKOVLEV	{"phone": "+70515729551"}
0005434189296	EF4471	8324 973730	YURIY ANTONOV	{"email": "antonov-yuriy1969@postgrespro.ru", "phone": "+70009052912"}
0005434189297	B4846D	3037 922448	MAKSIM ORLOV	{"phone": "+70176066832"}
0005434189298	205108	3038 837364	NADEZHDA NIKOLAEVA	{"email": "nikolaevan-03101967@postgrespro.ru", "phone": "+70423428176"}
0005434189299	46BCDC	6734 823586	LYUDMILA SMIRNOVA	{"phone": "+70798457312"}
0005434189300	5B934A	1912 106359	NIKITA VASILEV	{"phone": "+70806327571"}
0005434189301	39E196	9045 479817	OLGA KUZNECOVA	{"email": "kuznecova-o.1977@postgrespro.ru", "phone": "+70580766938"}
0005434189302	39E196	9771 870738	VALENTINA SIDOROVA	{"phone": "+70888660530"}
0005434189303	B2BE24	4115 044029	ROMAN NOVIKOV	{"email": "novikov_roman-011978@postgrespro.ru", "phone": "+70093199459"}
0005434189304	B2BE24	3976 911588	VLADIMIR STEPANOV	{"email": "v-stepanov.1965@postgrespro.ru", "phone": "+70351004882"}
0005434189305	F709B9	1849 401042	LYUDMILA ROMANOVA	{"phone": "+70454522684"}
0005434189306	DC0D8B	0690 028242	TATYANA KUZMINA	{"email": "kuzmina_tatyana29111983@postgrespro.ru", "phone": "+70926356267"}
0005434189307	90C8DA	4809 987316	NINA ORLOVA	{"phone": "+70589223907"}
0005434189308	321965	8604 856782	ALEKSANDR EGOROV	{"email": "aegorov-05041973@postgrespro.ru", "phone": "+70825304363"}
0005434189309	321965	2076 024648	EVGENIYA ALEKSEEVA	{"email": "alekseeva_e-011990@postgrespro.ru", "phone": "+70891064202"}
0005434189310	6CDC47	3144 328058	PETR KOZLOV	{"email": "kozlov.petr.13051966@postgrespro.ru", "phone": "+70469842569"}
0005434189311	6CDC47	5498 107313	NATALYA NAZAROVA	{"email": "nnazarova-081971@postgrespro.ru", "phone": "+70539891412"}
0005434189312	01FCB1	2307 842192	ALENA PETROVA	{"phone": "+70004651709"}
0005434189313	0678CA	6613 743833	TAMARA ERMAKOVA	{"phone": "+70314526888"}
0005434189314	0678CA	9881 193602	VALENTINA VOROBEVA	{"email": "vorobeva_v1974@postgrespro.ru", "phone": "+70718971136"}
0005434189315	E70627	2675 601664	LARISA KUZMINA	{"email": "l_kuzmina_071975@postgrespro.ru", "phone": "+70516246624"}
0005434189316	9CB8FD	7759 309669	SERGEY PETROV	{"phone": "+70325304444"}
0005434189317	2E963E	8926 171431	ANNA ERMAKOVA	{"email": "a-ermakova-081981@postgrespro.ru", "phone": "+70995172661"}
0005434189318	86EBAD	2628 818296	GALINA POLYAKOVA	{"email": "polyakova-galina_061964@postgrespro.ru", "phone": "+70872183944"}
0005434189319	86EBAD	7382 132311	DMITRIY SERGEEV	{"phone": "+70395263789"}
0005434189320	62D087	3971 283127	ALEKSEY SEMENOV	{"email": "a_semenov091979@postgrespro.ru", "phone": "+70169354374"}
0005434189321	EDDFD9	0700 828026	GENNADIY SOROKIN	{"phone": "+70958301964"}
0005434189322	EDDFD9	8496 117332	VALERIY KAZAKOV	{"phone": "+70118041488"}
0005434189323	800F95	1092 907886	KLARA MELNIKOVA	{"email": "klaramelnikova061967@postgrespro.ru", "phone": "+70276320874"}
0005434189324	F39824	4034 186282	SEMEN FOMIN	{"phone": "+70196971031"}
0005434189325	8E3B5F	7026 863426	DMITRIY YAKOVLEV	{"phone": "+70402230518"}
0005434189326	8E3B5F	7268 643705	VALERIY MOISEEV	{"email": "moiseev_valeriy.07021979@postgrespro.ru", "phone": "+70151719606"}
0005434189327	C832EC	0482 339754	ANNA MOROZOVA	{"email": "anna_morozova-1978@postgrespro.ru", "phone": "+70462738798"}
0005434189328	8F9C99	9864 517822	GENNADIY PAVLOV	{"phone": "+70793638612"}
0005434189329	8F9C99	0640 727135	YURIY SOROKIN	{"phone": "+70336080291"}
0005434189330	3291A8	2722 379933	OLGA BELOVA	{"email": "obelova10101971@postgrespro.ru", "phone": "+70273260941"}
0005434189331	D39BB7	0770 944967	VALENTINA POPOVA	{"phone": "+70303002785"}
0005434189332	21C4BC	1984 929526	IRINA EFREMOVA	{"phone": "+70524555640"}
0005434189333	689AC0	3088 075374	NURLAN MIKHAYLOV	{"email": "mikhaylov_n20101971@postgrespro.ru", "phone": "+70138786942"}
0005434189334	689AC0	0659 060742	ALEKSANDR KOZLOV	{"phone": "+70665050791"}
0005434189335	602F4F	0023 315661	ALEKSANDR KUDRYASHOV	{"email": "aleksandrkudryashov_05031974@postgrespro.ru", "phone": "+70725569908"}
0005434189336	A2A474	0588 027645	ZINAIDA KUDRYASHOVA	{"phone": "+70240348325"}
0005434189337	A2A474	4397 862975	ALEKSEY ISAEV	{"email": "alekseyisaev-18041961@postgrespro.ru", "phone": "+70343266237"}
0005434189338	A2A474	0002 797807	VASILIY MOROZOV	{"phone": "+70398635777"}
0005434189339	8AFD12	7686 724219	YURIY ILIN	{"email": "ilinyuriy_1968@postgrespro.ru", "phone": "+70868054728"}
0005434189340	94E25F	5120 821290	KONSTANTIN CHERNOV	{"phone": "+70689431325"}
0005434189341	5F6EA7	2588 541695	MARINA VOLKOVA	{"phone": "+70218529402"}
0005434189342	D30BF9	1725 972164	VALERIYA YAKOVLEVA	{"email": "yakovlevav-04111968@postgrespro.ru", "phone": "+70759721032"}
0005434189343	D30BF9	3548 845094	ALEKSANDR FILIPPOV	{"phone": "+70795147157"}
0005434189344	022422	5742 429688	IVAN BELOV	{"email": "belovi-061986@postgrespro.ru", "phone": "+70908568218"}
0005434189345	F2E518	1793 434681	VLADISLAV VOROBEV	{"email": "vvorobev_081978@postgrespro.ru", "phone": "+70099810479"}
0005434189346	F2E518	5248 350009	TAMARA STEPANOVA	{"email": "tstepanova1973@postgrespro.ru", "phone": "+70771873175"}
0005434190367	B0C263	0775 248835	SERGEY KAZAKOV	{"email": "sergey_kazakov.08011982@postgrespro.ru", "phone": "+70934091477"}
0005434190368	B6F717	0602 036317	TATYANA RODIONOVA	{"phone": "+70706327201"}
0005434190369	7A8C1A	4630 334937	POLINA KOZLOVA	{"phone": "+70835896055"}
0005434190370	06ECDB	4897 410398	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov14011971@postgrespro.ru", "phone": "+70583024290"}
0005434190371	8E2678	3077 950269	TATYANA FILATOVA	{"email": "t.filatova_1973@postgrespro.ru", "phone": "+70815512381"}
0005434190372	06DBB4	5681 398625	MARIYA ZHUKOVA	{"email": "zhukovam_1972@postgrespro.ru", "phone": "+70901643529"}
0005434190373	37DFC1	1885 422972	ALEKSANDR FROLOV	{"email": "frolov.aleksandr_011974@postgrespro.ru", "phone": "+70117692339"}
0005434190374	2D0054	6475 274911	RITA DAVYDOVA	{"phone": "+70709225745"}
0005434190375	2D0054	6602 731194	ANATOLIY MARTYNOV	{"email": "anatoliy-martynov_06091968@postgrespro.ru", "phone": "+70741268721"}
0005434190376	2597CC	4536 294736	EDUARD NOVIKOV	{"phone": "+70856950788"}
0005434190377	D9818D	5786 793623	ANDREY GUSEV	{"phone": "+70958067237"}
0005434190378	D9818D	1127 245220	DARYA ZHUKOVA	{"email": "daryazhukova121968@postgrespro.ru", "phone": "+70395515308"}
0005434190379	AF5C7E	3161 918681	IVAN KULIKOV	{"email": "kulikov_ivan30031976@postgrespro.ru", "phone": "+70283505045"}
0005434190380	233012	5706 579091	DARYA TITOVA	{"email": "titova.darya_23061977@postgrespro.ru", "phone": "+70466512043"}
0005434190381	1E90E3	7431 778233	ELIZAVETA GUSEVA	{"phone": "+70464581384"}
0005434190382	1E90E3	3070 112869	ANASTASIYA DENISOVA	{"email": "a_denisova.1978@postgrespro.ru", "phone": "+70913538555"}
0005434190383	54221B	0848 638689	ANATOLIY FROLOV	{"email": "frolov_a_1986@postgrespro.ru", "phone": "+70898564094"}
0005434190384	54221B	3146 956261	OLGA MOROZOVA	{"phone": "+70691806948"}
0005434190385	0CE86F	4308 609297	ANDREY IVANOV	{"phone": "+70108394248"}
0005434190386	6393A5	3137 196734	VALENTINA SOKOLOVA	{"phone": "+70467302834"}
0005434190387	6393A5	9409 390461	IRINA IVANOVA	{"email": "irina.ivanova1971@postgrespro.ru", "phone": "+70319863668"}
0005434190388	1BC9DC	6580 336899	VADIM SIDOROV	{"email": "v_sidorov-22111978@postgrespro.ru", "phone": "+70192151628"}
0005434190389	7A9355	7838 629512	ALEKSANDRA GUSEVA	{"email": "guseva_a_1966@postgrespro.ru", "phone": "+70172066325"}
0005434190390	815542	0545 852633	DENIS VOLKOV	{"email": "d-volkov-10101969@postgrespro.ru", "phone": "+70919178557"}
0005434190391	815542	5989 728463	MIKHAIL DMITRIEV	{"phone": "+70946218824"}
0005434190392	2BA22F	8452 202672	KONSTANTIN KULIKOV	{"phone": "+70508880518"}
0005434190393	7A335B	4908 001419	GALINA IVANOVA	{"phone": "+70244692169"}
0005434190394	7A335B	3428 432754	ANNA FROLOVA	{"phone": "+70834577338"}
0005434190395	6287B8	3224 837530	EVGENIY DENISOV	{"phone": "+70990321273"}
0005434190396	7DC89F	4871 808925	ANNA TITOVA	{"email": "anna-titova1975@postgrespro.ru", "phone": "+70317817449"}
0005434190397	2D87D9	8006 599058	RUSLAN SIDOROV	{"email": "r-sidorov_1966@postgrespro.ru", "phone": "+70927105159"}
0005434190398	2D87D9	3458 334354	SERGEY SERGEEV	{"phone": "+70841725675"}
0005434190399	C2036B	0711 967438	PRASKOVYA KUZNECOVA	{"email": "praskovya.kuznecova1976@postgrespro.ru", "phone": "+70457775697"}
0005434190400	7D7ED8	6475 152928	IGOR EGOROV	{"email": "egorov_igor091971@postgrespro.ru", "phone": "+70581538585"}
0005434190401	5F72AB	2764 072714	VLADIMIR KRASNOV	{"phone": "+70368350769"}
0005434190402	5F72AB	5973 717459	RAMIL ABRAMOV	{"phone": "+70926087539"}
0005434190403	B1924E	9866 476996	VALENTINA NESTEROVA	{"phone": "+70840877076"}
0005434190404	E7C42F	8851 996821	KLAVDIYA YUDINA	{"phone": "+70724977262"}
0005434190405	57F7B9	6980 817639	KIRILL BARANOV	{"email": "kirill-baranov-1973@postgrespro.ru", "phone": "+70220620764"}
0005434190406	BC9E3C	8586 379607	LIDIYA CHERNOVA	{"email": "lidiya-chernova.1965@postgrespro.ru", "phone": "+70968567908"}
0005434190407	BC9E3C	0407 275068	LARISA DANILOVA	{"email": "l_danilova.1979@postgrespro.ru", "phone": "+70499255872"}
0005434190408	BC9E3C	6874 909418	VALENTINA MATVEEVA	{"phone": "+70925941775"}
0005434190409	04959E	4523 026112	ELENA ILINA	{"phone": "+70590223383"}
0005434190410	64ED2C	2163 064223	SVETLANA SEMENOVA	{"phone": "+70993257936"}
0005434190411	68881A	8627 059880	ALEKSANDR KUZNECOV	{"phone": "+70555912750"}
0005434190412	021BDA	9754 534990	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana031980@postgrespro.ru", "phone": "+70281589051"}
0005434190413	2685F7	5067 961394	KIRILL CHERNOV	{"email": "chernov_kirill_1986@postgrespro.ru", "phone": "+70997288374"}
0005434190414	2685F7	4453 859849	SERGEY GORBUNOV	{"phone": "+70881505306"}
0005434190415	2131AF	1610 874471	OLGA SERGEEVA	{"email": "sergeevaolga.091978@postgrespro.ru", "phone": "+70107066047"}
0005434190416	C69D3D	5061 866026	NADEZHDA POPOVA	{"email": "popova_nadezhda_1973@postgrespro.ru", "phone": "+70930274945"}
0005434190417	4A3AF0	0543 779086	VADIM TIKHONOV	{"email": "v_tikhonov.051971@postgrespro.ru", "phone": "+70612279938"}
0005434190418	47BEEF	9599 008339	SOFYA AKIMOVA	{"phone": "+70115951536"}
0005434190419	9E31AC	9055 490803	IGOR KOZLOV	{"phone": "+70142877790"}
0005434190420	9E31AC	0216 564127	ZOYA LEBEDEVA	{"email": "zoyalebedeva_01111974@postgrespro.ru", "phone": "+70906599394"}
0005434190421	4AFB13	2692 608334	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_1984@postgrespro.ru", "phone": "+70825200408"}
0005434190422	D89FD7	9085 116818	KIRILL GAVRILOV	{"phone": "+70090390928"}
0005434190423	D89FD7	8181 798711	GALINA ZAYCEVA	{"phone": "+70021496112"}
0005434190424	9C6E44	0561 396123	LARISA SOROKINA	{"phone": "+70743811435"}
0005434190425	9C6E44	0923 793016	DARYA KOROLEVA	{"phone": "+70498605371"}
0005434190426	B5D984	9578 563734	ELENA MARTYNOVA	{"email": "martynova_e.06101971@postgrespro.ru", "phone": "+70939288372"}
0005434190427	9C5FA1	3001 597706	ROMAN VASILEV	{"phone": "+70223998000"}
0005434190428	E89FF0	2551 772173	VLADIMIR PETROV	{"email": "vladimir-petrov1957@postgrespro.ru", "phone": "+70634887268"}
0005434190429	E89FF0	6288 561873	ANNA IVANOVA	{"email": "a-ivanova1981@postgrespro.ru", "phone": "+70616168893"}
0005434190430	97D80C	6801 609420	YULIYA MARTYNOVA	{"phone": "+70350065310"}
0005434190431	7C35D7	6667 842985	VALENTINA TIMOFEEVA	{"phone": "+70858332782"}
0005434190432	67EF1E	7247 181008	DIANA KUZNECOVA	{"email": "diana.kuznecova_121970@postgrespro.ru", "phone": "+70792803506"}
0005434190433	5E276F	4438 131609	VYACHESLAV BARANOV	{"email": "baranovvyacheslav101978@postgrespro.ru", "phone": "+70677822739"}
0005434190434	5E276F	9078 977074	OLGA NOVIKOVA	{"email": "olga.novikova_031964@postgrespro.ru", "phone": "+70256416030"}
0005434190435	5E276F	9025 687799	GALINA VOLKOVA	{"phone": "+70140599152"}
0005434190436	DDEC5D	7370 089796	ALEKSEY PETROV	{"email": "petrov.aleksey-1962@postgrespro.ru", "phone": "+70460280973"}
0005434190437	A85F3C	2581 023024	ALEKSANDR KOROLEV	{"email": "koroleva.09061975@postgrespro.ru", "phone": "+70664190880"}
0005434190438	91F587	1134 130738	GENNADIY VASILEV	{"email": "vasilevgennadiy_14061960@postgrespro.ru", "phone": "+70922166209"}
0005434190439	91F587	9508 185494	ANNA PAVLOVA	{"phone": "+70257029133"}
0005434190440	2BDC2A	1321 841948	LYUBOV SIDOROVA	{"email": "sidorova_lyubov_1963@postgrespro.ru", "phone": "+70294969758"}
0005434190441	58C1EF	6413 340273	LEONID KUZMIN	{"phone": "+70157937637"}
0005434190442	4B98F7	0378 961946	ALEKSEY POPOV	{"phone": "+70112070927"}
0005434190443	6459AD	7537 021326	ILDAR ANDREEV	{"email": "andreev.ildar_15081983@postgrespro.ru", "phone": "+70340880226"}
0005434190444	5616CF	9725 672336	ELENA ALEKSANDROVA	{"email": "aleksandrova_elena_04081974@postgrespro.ru", "phone": "+70767078701"}
0005434190445	5616CF	0922 357350	ANTON KUDRYASHOV	{"email": "kudryashov.anton_011973@postgrespro.ru", "phone": "+70605037997"}
0005434190446	C8F91C	5834 379536	TATYANA VASILEVA	{"phone": "+70407083863"}
0005434190447	06BB37	6200 690917	RAISA STEPANOVA	{"phone": "+70827242731"}
0005434190448	06BB37	5975 359296	SVETLANA SERGEEVA	{"email": "ssergeeva121979@postgrespro.ru", "phone": "+70914516494"}
0005434190449	174E07	5941 523647	TATYANA IVANOVA	{"email": "t-ivanova15111974@postgrespro.ru", "phone": "+70837127637"}
0005434190450	FCB568	2242 856309	DARYA MATVEEVA	{"phone": "+70881374388"}
0005434190451	BEDFB5	1689 269509	IVAN MATVEEV	{"email": "ivan.matveev_29071969@postgrespro.ru", "phone": "+70294172303"}
0005434190452	48C322	6079 710479	SOFIYA KOROLEVA	{"phone": "+70401295664"}
0005434190453	F64AF6	3839 034244	LYUBOV BELYAEVA	{"phone": "+70615252461"}
0005434190454	F64AF6	6496 513305	VIKTOR SCHERBAKOV	{"email": "scherbakov-v_1977@postgrespro.ru", "phone": "+70055991380"}
0005434190455	71DA23	8414 134859	IRINA MOROZOVA	{"phone": "+70926163053"}
0005434190456	ECD7D8	4844 128135	ROMAN IVANOV	{"email": "ivanov_roman-011979@postgrespro.ru", "phone": "+70077564570"}
0005434190457	2BE384	8168 729769	EVGENIYA MAKAROVA	{"email": "makarova-evgeniya-1978@postgrespro.ru", "phone": "+70119266046"}
0005434190458	2BE384	5474 465939	RUSLAN BELOV	{"email": "r-belov.041966@postgrespro.ru", "phone": "+70689240054"}
0005434190459	B080FC	2581 170854	TATYANA NAZAROVA	{"phone": "+70408085416"}
0005434190460	CE5487	5981 323870	ALEKSANDR CHERNOV	{"email": "a.chernov_03041962@postgrespro.ru", "phone": "+70865136776"}
0005434190461	CE5487	3030 027846	ELENA MATVEEVA	{"phone": "+70493847880"}
0005434190462	8307B3	3613 708096	SERGEY GRIGOREV	{"email": "grigorevsergey.02081968@postgrespro.ru", "phone": "+70823358028"}
0005434190463	8307B3	9419 966186	NIKOLAY ANDREEV	{"phone": "+70882957856"}
0005434190464	28F9A9	7794 335234	ANDREY SOKOLOV	{"phone": "+70376681312"}
0005434191251	E71CE1	0237 895527	PAVEL SOLOVEV	{"email": "solovev.p_03121968@postgrespro.ru", "phone": "+70362177131"}
0005434191252	E71CE1	1381 245941	SERGEY KOZLOV	{"phone": "+70175088681"}
0005434191253	E71CE1	4849 071696	MAKSIM GERASIMOV	{"phone": "+70031892645"}
0005434191254	4F3008	9465 601976	MARIYA SCHERBAKOVA	{"phone": "+70898665945"}
0005434191255	4F3008	7185 465731	SERGEY KISELEV	{"phone": "+70320515491"}
0005434191256	A10DAE	6805 104241	OLESYA MIRONOVA	{"email": "o.mironova1966@postgrespro.ru", "phone": "+70611414929"}
0005434191257	A10DAE	4225 457132	VALERIY DAVYDOV	{"email": "davydov_valeriy1966@postgrespro.ru", "phone": "+70736979001"}
0005434191258	90BD68	6636 401408	YURIY MAKAROV	{"email": "yuriy-makarov.25081970@postgrespro.ru", "phone": "+70097019400"}
0005434191259	02A438	2403 758974	ALEKSEY ALEKSEEV	{"email": "a_alekseev-121977@postgrespro.ru", "phone": "+70334282394"}
0005434191260	BAEFE1	6457 884954	KLAVDIYA KUZNECOVA	{"email": "klavdiya-kuznecova.071972@postgrespro.ru", "phone": "+70222226081"}
0005434191261	BAEFE1	2927 256549	MILENA VASILEVA	{"email": "vasileva-m.061971@postgrespro.ru", "phone": "+70013591053"}
0005434191262	B8EC3C	2931 426108	ANDREY KARPOV	{"email": "karpov-a061973@postgrespro.ru", "phone": "+70787952773"}
0005434191263	1F93C5	9429 811161	IVAN ROMANOV	{"email": "romanov_i_121972@postgrespro.ru", "phone": "+70514276139"}
0005434191264	1F93C5	2366 984210	EVGENIY DENISOV	{"email": "e-denisov_1973@postgrespro.ru", "phone": "+70693186097"}
0005434191265	21DABD	3300 493318	OLEG POPOV	{"phone": "+70558605150"}
0005434191266	2B9D21	5988 521251	MARINA MASLOVA	{"email": "maslova_m_051973@postgrespro.ru", "phone": "+70079611358"}
0005434191267	FAAE72	9019 621404	TATYANA MELNIKOVA	{"email": "tatyanamelnikova_08031970@postgrespro.ru", "phone": "+70719096198"}
0005434191268	6BA250	3969 984116	SVETLANA KRASNOVA	{"email": "s_krasnova1970@postgrespro.ru", "phone": "+70388000605"}
0005434191269	BDFFF0	0759 896841	TATYANA KOLESNIKOVA	{"email": "kolesnikova.tatyana.1958@postgrespro.ru", "phone": "+70997007578"}
0005434191270	BDFFF0	5171 021185	LYUDMILA KUZMINA	{"phone": "+70629494327"}
0005434191271	CD1BD3	8288 354082	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov.24101965@postgrespro.ru", "phone": "+70651452900"}
0005434191272	3E71BA	2910 702834	OKSANA STEPANOVA	{"email": "oksana-stepanova.1970@postgrespro.ru", "phone": "+70759603822"}
0005434191273	0EA14E	2624 532890	ALEKSANDR BONDARENKO	{"phone": "+70705583312"}
0005434191274	9FEBBD	1217 727837	ARTEM STEPANOV	{"email": "artem.stepanov.11051976@postgrespro.ru", "phone": "+70534873135"}
0005434191275	9FEBBD	9123 162113	YURIY KOZLOV	{"email": "kozlov-yuriy.1972@postgrespro.ru", "phone": "+70297179350"}
0005434191276	2C77EA	5038 422861	NIKOLAY MARTYNOV	{"email": "n.martynov_1962@postgrespro.ru", "phone": "+70302208973"}
0005434191277	079C62	8885 919313	MIKHAIL VOLKOV	{"phone": "+70293692816"}
0005434191278	913792	8766 482862	PETR SAVELEV	{"phone": "+70468114380"}
0005434213820	811F2C	2510 254605	VERA MOROZOVA	{"phone": "+70144263855"}
0005434191279	913792	0902 240619	VALENTINA OSIPOVA	{"email": "valentina.osipova_1983@postgrespro.ru", "phone": "+70140377099"}
0005434191280	271A61	0482 329599	TATYANA MAKAROVA	{"email": "makarova_t-1962@postgrespro.ru", "phone": "+70136361071"}
0005434191281	271A61	1803 012530	OLGA KUZNECOVA	{"phone": "+70299164782"}
0005434191282	CB7DBF	2849 317807	SERGEY MEDVEDEV	{"email": "s.medvedev_081980@postgrespro.ru", "phone": "+70687266951"}
0005434191283	6852E2	3006 310508	RUSLAN MELNIKOV	{"email": "r-melnikov08021976@postgrespro.ru", "phone": "+70373690756"}
0005434191284	6852E2	9097 039633	DMITRIY FOMIN	{"email": "fomin-dmitriy.1977@postgrespro.ru", "phone": "+70752815966"}
0005434191285	DD6D01	4101 374425	DMITRIY SOLOVEV	{"email": "solovev.d-27071970@postgrespro.ru", "phone": "+70079737125"}
0005434191286	DD6D01	4901 693619	SERGEY KISELEV	{"phone": "+70786252380"}
0005434191287	2BF5CE	6242 393226	MARGARITA BORISOVA	{"email": "margaritaborisova13111979@postgrespro.ru", "phone": "+70791345880"}
0005434191288	70F324	5007 283706	NATALYA MAKAROVA	{"phone": "+70680359441"}
0005434191289	83D120	1395 515586	ILYA SEMENOV	{"phone": "+70192890807"}
0005434191290	16751E	1697 981725	MIKHAIL MOROZOV	{"phone": "+70271270278"}
0005434191291	A60805	4515 478310	NATALYA MOROZOVA	{"phone": "+70416901620"}
0005434191292	0B27A1	2164 243496	TATYANA KONOVALOVA	{"email": "t.konovalova.1977@postgrespro.ru", "phone": "+70933384547"}
0005434191293	500FFD	5986 698214	ZOYA KOROLEVA	{"phone": "+70578485534"}
0005434191294	BFE3DA	8267 962709	NATALYA SOROKINA	{"email": "natalya.sorokina_18061968@postgrespro.ru", "phone": "+70544433591"}
0005434191295	514333	9131 329390	VALENTINA PETROVA	{"email": "vpetrova.1978@postgrespro.ru", "phone": "+70208587905"}
0005434191296	4C5BFF	3275 166526	NADEZHDA FILATOVA	{"phone": "+70268288363"}
0005434191297	F57246	5955 738039	OLGA GUSEVA	{"email": "o_guseva03041973@postgrespro.ru", "phone": "+70877556376"}
0005434191298	26A6BA	4270 016063	RAIS VLASOV	{"phone": "+70700195912"}
0005434191299	123988	7591 988616	ELENA ILINA	{"email": "ilina_e1971@postgrespro.ru", "phone": "+70846262062"}
0005434191300	BA133F	9224 755465	OLGA ANTONOVA	{"email": "olga-antonova.29101972@postgrespro.ru", "phone": "+70806477179"}
0005434191301	BA133F	5328 977893	MIKHAIL POPOV	{"email": "m.popov1969@postgrespro.ru", "phone": "+70212882116"}
0005434191302	BA133F	0259 083340	DMITRIY IVANOV	{"email": "d-ivanov_1974@postgrespro.ru", "phone": "+70612948511"}
0005434191303	C94AB9	9863 657067	SERGEY IVANOV	{"email": "sergey.ivanov.1966@postgrespro.ru", "phone": "+70521382802"}
0005434191304	C88B25	2758 132385	TATYANA IVANOVA	{"email": "ivanova.tatyana_1977@postgrespro.ru", "phone": "+70105700409"}
0005434191305	46999C	9581 585278	STANISLAV PAVLOV	{"email": "stanislav.pavlov02061966@postgrespro.ru", "phone": "+70596232489"}
0005434191306	028CF6	8835 790737	LEV KULIKOV	{"phone": "+70511427232"}
0005434191307	028CF6	3898 714198	VLADIMIR YAKOVLEV	{"phone": "+70093016153"}
0005434191308	97E25B	7112 117011	ZINAIDA PETROVA	{"phone": "+70304090071"}
0005434191309	97E25B	1973 243198	NADEZHDA RYABOVA	{"email": "nadezhda_ryabova.15041983@postgrespro.ru", "phone": "+70359424901"}
0005434191310	CA1735	5071 255221	DMITRIY SAVELEV	{"email": "dmitriy_savelev.111973@postgrespro.ru", "phone": "+70238106835"}
0005434191311	CA1735	3806 944214	RUSLAN DENISOV	{"phone": "+70744769895"}
0005434191312	6680AA	2839 870631	ALEKSANDR EGOROV	{"phone": "+70031044301"}
0005434191313	6680AA	9166 882204	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov031973@postgrespro.ru", "phone": "+70493906440"}
0005434191314	D9AD91	3903 768369	OLEG IVANOV	{"email": "ivanov_oleg.011968@postgrespro.ru", "phone": "+70264505778"}
0005434191315	BF1B67	3320 054701	NIKOLAY KUZNECOV	{"phone": "+70131644266"}
0005434191316	8C4775	8868 100944	TATYANA NOVIKOVA	{"phone": "+70659307772"}
0005434191317	0D9772	0470 950326	MIKHAIL PETROV	{"email": "petrovm-1975@postgrespro.ru", "phone": "+70991319321"}
0005434191318	0D9772	5637 504661	ALEKSEY FROLOV	{"phone": "+70613849108"}
0005434191319	8C7103	7500 871175	ANATOLIY FEDOROV	{"email": "fedorov-a-1963@postgrespro.ru", "phone": "+70823944353"}
0005434191320	4F4194	2354 324413	ANNA MELNIKOVA	{"email": "anna-melnikova_1974@postgrespro.ru", "phone": "+70329446668"}
0005434191321	4F4194	1119 974926	YURIY VOLKOV	{"email": "y-volkov.04031963@postgrespro.ru", "phone": "+70223048425"}
0005434191322	0BA5C8	6220 950441	GALINA NIKITINA	{"email": "nikitina-galina_1964@postgrespro.ru", "phone": "+70719561757"}
0005434191323	0BA5C8	7009 397701	PAVEL DMITRIEV	{"email": "dmitriev_p-1971@postgrespro.ru", "phone": "+70285013848"}
0005434191324	2A42D3	4614 000757	DMITRIY SOROKIN	{"phone": "+70373254417"}
0005434191325	2A42D3	5827 914106	TATYANA STEPANOVA	{"email": "t_stepanova-011963@postgrespro.ru", "phone": "+70346346402"}
0005434191326	FAD0D1	0660 577699	TATYANA FILIPPOVA	{"phone": "+70077009768"}
0005434191327	FAD0D1	7461 049870	IRINA VOLKOVA	{"email": "volkova_irina.1966@postgrespro.ru", "phone": "+70387621641"}
0005434191328	47AFEF	5936 046067	OLGA SOROKINA	{"phone": "+70842715274"}
0005434191329	5861B5	5147 936271	ALEKSEY VLASOV	{"phone": "+70175165955"}
0005434191330	50236A	2885 639960	ILYA SCHERBAKOV	{"email": "scherbakov.i_011969@postgrespro.ru", "phone": "+70938087884"}
0005434191331	C79901	6721 060982	NIKOLAY SOKOLOV	{"phone": "+70548071027"}
0005434191332	C79901	9027 892508	NIKOLAY IVANOV	{"email": "ivanovn-1970@postgrespro.ru", "phone": "+70087193258"}
0005434213789	13B0BA	9387 675953	ANASTASIYA KUZNECOVA	{"phone": "+70344534793"}
0005434213756	6758FA	6899 581006	ELENA KOROLEVA	{"phone": "+70410090858"}
0005434213698	3DAE29	6396 583682	ANATOLIY GUSEV	{"phone": "+70333962922"}
0005434213699	5D3EFA	3380 406131	TATYANA MAKSIMOVA	{"email": "maksimova_tatyana.19111982@postgrespro.ru", "phone": "+70221358502"}
0005434213700	5D3EFA	8105 942215	VLADIMIR NIKITIN	{"email": "nikitinv.15091967@postgrespro.ru", "phone": "+70154036327"}
0005434213701	C6CAF4	4159 683459	YURIY NAUMOV	{"email": "naumov_y.061968@postgrespro.ru", "phone": "+70968279786"}
0005434213702	BE00D6	9581 580973	NATALYA TITOVA	{"email": "natalya_titova-111976@postgrespro.ru", "phone": "+70786237350"}
0005434213703	BE00D6	4587 752166	POLINA FEDOROVA	{"email": "polinafedorova1977@postgrespro.ru", "phone": "+70331096527"}
0005434213704	BE00D6	7402 625511	PAVEL BONDARENKO	{"email": "pbondarenko061985@postgrespro.ru", "phone": "+70660716471"}
0005434213705	F97D44	4636 180414	VERA KOROLEVA	{"email": "v_koroleva-1967@postgrespro.ru", "phone": "+70726258132"}
0005434213706	F97D44	8859 896587	KONSTANTIN FEDOTOV	{"email": "fedotov.k.31081971@postgrespro.ru", "phone": "+70475983397"}
0005434213707	EB73C3	7212 444376	VIKTOR ZAKHAROV	{"email": "v-zakharov_19021965@postgrespro.ru", "phone": "+70157799862"}
0005434213708	E3824E	1400 577241	MAKSIM ALEKSEEV	{"email": "maksim-alekseev_111980@postgrespro.ru", "phone": "+70698361983"}
0005434213709	E3824E	7038 539088	VIKTOR KUZNECOV	{"email": "kuznecov-v_1963@postgrespro.ru", "phone": "+70816710201"}
0005434213710	E3824E	8371 319653	VLADISLAV KONOVALOV	{"email": "konovalov_v.021975@postgrespro.ru", "phone": "+70583167137"}
0005434213711	D0BEF0	3628 180960	OLGA AFANASEVA	{"phone": "+70939587169"}
0005434213712	EE04FF	2302 334870	ANDREY SCHERBAKOV	{"phone": "+70073394261"}
0005434213713	BB73AF	0131 812951	EKATERINA GORBUNOVA	{"email": "gorbunovae-1969@postgrespro.ru", "phone": "+70157920863"}
0005434213714	BB73AF	5258 895126	VLADIMIR ZHUKOV	{"email": "v-zhukov15041983@postgrespro.ru", "phone": "+70389905255"}
0005434213715	0A40E8	6477 912605	SOFYA PAVLOVA	{"phone": "+70892492589"}
0005434213716	0A40E8	4495 528591	ELENA STEPANOVA	{"phone": "+70426633251"}
0005434213717	A5AA91	4435 222275	FARIT FROLOV	{"email": "f_frolov.16101975@postgrespro.ru", "phone": "+70919380323"}
0005434213718	F149D3	6739 511623	ROMAN DENISOV	{"email": "r-denisov19101966@postgrespro.ru", "phone": "+70012329155"}
0005434213719	07CE1E	1826 593496	VLADIMIR VOROBEV	{"email": "vorobevvladimir-1961@postgrespro.ru", "phone": "+70146890428"}
0005434213720	07CE1E	2487 490248	NATALYA MOROZOVA	{"phone": "+70384639303"}
0005434213721	F87126	8586 054905	NIKOLAY BARANOV	{"phone": "+70811593711"}
0005434213722	369214	0429 345943	MIKHAIL GERASIMOV	{"email": "gerasimovm.091963@postgrespro.ru", "phone": "+70290695862"}
0005434213723	369214	1477 969910	TAMARA FOMINA	{"phone": "+70813752957"}
0005434213724	369214	4784 310243	MIKHAIL FOMIN	{"email": "m_fomin11051975@postgrespro.ru", "phone": "+70246435151"}
0005434213725	10BDB9	7176 477931	YULIYA KUZNECOVA	{"phone": "+70314080416"}
0005434213726	10BDB9	5375 087274	RAISA ALEKSANDROVA	{"phone": "+70304055391"}
0005434213727	91AAB9	2272 868144	RAISA FEDOROVA	{"email": "raisa.fedorova_011973@postgrespro.ru", "phone": "+70170225072"}
0005434213728	764052	2183 273124	ARTEM KUZNECOV	{"email": "kuznecov_artem16081970@postgrespro.ru", "phone": "+70202959656"}
0005434213729	764052	9545 859435	ARTEM KUZNECOV	{"email": "kuznecovartem.06081959@postgrespro.ru", "phone": "+70634152205"}
0005434213730	A55F63	1185 416772	MARIYA EGOROVA	{"email": "megorova-031967@postgrespro.ru", "phone": "+70198016664"}
0005434213731	813B69	9265 528300	IGOR SIDOROV	{"phone": "+70579456740"}
0005434213732	6FE4CB	6688 565598	VIKTORIYA FADEEVA	{"email": "v.fadeeva12121977@postgrespro.ru", "phone": "+70293032512"}
0005434213733	FBFB5F	0208 623896	NADEZHDA SMIRNOVA	{"phone": "+70987530568"}
0005434213734	89630D	7546 297853	NINA FROLOVA	{"email": "frolova.nina1974@postgrespro.ru", "phone": "+70816686978"}
0005434213735	A6713C	0020 588201	DANIIL SERGEEV	{"email": "sergeev.d15061967@postgrespro.ru", "phone": "+70831796195"}
0005434213736	A6713C	9492 145541	ALEKSEY STEPANOV	{"phone": "+70264639494"}
0005434213737	372C8C	1977 430436	ALEKSEY OSIPOV	{"phone": "+70816291759"}
0005434213738	62564A	4669 861516	VLADIMIR MAKAROV	{"email": "vladimir_makarov1961@postgrespro.ru", "phone": "+70075234901"}
0005434213739	6230F0	9481 140263	NATALYA NOVIKOVA	{"email": "n-novikova-031970@postgrespro.ru", "phone": "+70323238951"}
0005434213740	CECDC1	6131 983612	VYACHESLAV BARANOV	{"phone": "+70513822007"}
0005434213741	D201CA	7478 899756	NIKOLAY IVANOV	{"phone": "+70276607839"}
0005434213742	D201CA	1316 456535	VLADIMIR MELNIKOV	{"email": "v.melnikov_05111964@postgrespro.ru", "phone": "+70150813907"}
0005434213743	D201CA	3010 474489	ELENA KONDRATEVA	{"email": "elena_kondrateva22071974@postgrespro.ru", "phone": "+70818481070"}
0005434213744	164E52	0953 272085	EVGENIY NAUMOV	{"email": "naumov_evgeniy.06081967@postgrespro.ru", "phone": "+70146761503"}
0005434213745	BE032E	5212 101038	VITALIY SMIRNOV	{"phone": "+70790385900"}
0005434213746	C6940E	6044 223851	VLADIMIR KAZAKOV	{"phone": "+70555528225"}
0005434213747	C6940E	5567 859026	ALEKSEY FROLOV	{"phone": "+70889802608"}
0005434213748	D2DB10	6616 920358	NATALYA ROMANOVA	{"phone": "+70130880974"}
0005434213749	322090	3068 375409	NADEZHDA SIDOROVA	{"phone": "+70668060161"}
0005434213750	322090	2104 993545	TIMUR TARASOV	{"email": "tarasov-t1967@postgrespro.ru", "phone": "+70109664035"}
0005434213751	703B30	2548 034896	DMITRIY KOZLOV	{"email": "dmitriy.kozlov_1967@postgrespro.ru", "phone": "+70998495363"}
0005434213752	F1BF29	3280 024539	ANNA KOROLEVA	{"email": "koroleva-a1984@postgrespro.ru", "phone": "+70816471831"}
0005434213753	BF4BEC	1640 355886	MARINA GAVRILOVA	{"phone": "+70103293722"}
0005434213754	0BA528	5846 560163	LYUDMILA ISAEVA	{"phone": "+70130922634"}
0005434213755	0BA528	1308 238524	TAMARA KULIKOVA	{"phone": "+70917066824"}
0005434213757	71AC86	6811 388756	RUSLAN MIKHAYLOV	{"phone": "+70802476082"}
0005434213758	451CD5	3161 711634	MARIYA ALEKSEEVA	{"phone": "+70585096656"}
0005434213759	389690	2176 821810	SERGEY KISELEV	{"email": "kiselevsergey-20081979@postgrespro.ru", "phone": "+70132550023"}
0005434213760	84CEE0	6382 228444	KRISTINA GERASIMOVA	{"email": "kristina-gerasimova091980@postgrespro.ru", "phone": "+70044547703"}
0005434214121	C9AC9B	0151 979609	VALENTINA KUZNECOVA	{"phone": "+70473481402"}
0005434213761	84CEE0	0280 228614	SERAFIMA MOISEEVA	{"email": "s.moiseeva.1977@postgrespro.ru", "phone": "+70392474162"}
0005434213762	84CEE0	7599 607647	IVAN GERASIMOV	{"email": "ivan.gerasimov_031972@postgrespro.ru", "phone": "+70042179994"}
0005434213763	1C61A5	2761 766957	OLGA KISELEVA	{"phone": "+70666673666"}
0005434213764	1C61A5	1932 416269	VERA KALININA	{"email": "vera.kalinina1977@postgrespro.ru", "phone": "+70624856082"}
0005434213765	C93E06	7027 457060	IVAN KAZAKOV	{"phone": "+70010013413"}
0005434213766	CFE4CD	8275 253049	RUSLAN ZAYCEV	{"phone": "+70215760442"}
0005434213767	CFE4CD	0025 140266	NIKITA VASILEV	{"phone": "+70073199171"}
0005434213768	E71A73	5918 422598	ANDREY VLASOV	{"email": "vlasov.a.03111965@postgrespro.ru", "phone": "+70582852658"}
0005434213769	E71A73	5235 427158	SEMEN ALEKSANDROV	{"email": "aleksandrov_semen.08051979@postgrespro.ru", "phone": "+70813738108"}
0005434213770	6B181D	4621 481853	NIKOLAY MATVEEV	{"phone": "+70882388490"}
0005434213771	9DDABC	6259 250962	EVGENIY EGOROV	{"phone": "+70637660881"}
0005434213772	9DDABC	9925 683166	LARISA MIRONOVA	{"email": "larisa-mironova_021974@postgrespro.ru", "phone": "+70785947806"}
0005434213773	D0465E	9562 900970	ILYA SEMENOV	{"email": "ilyasemenov.1973@postgrespro.ru", "phone": "+70310207198"}
0005434213774	BA3A3B	9086 335367	MAKSIM KULIKOV	{"email": "maksim-kulikov021973@postgrespro.ru", "phone": "+70341289922"}
0005434213775	BA3A3B	3895 348725	DMITRIY MIRONOV	{"phone": "+70399385339"}
0005434213776	E97D54	7565 891700	NATALIYA TIKHONOVA	{"email": "n_tikhonova_06091969@postgrespro.ru", "phone": "+70570075318"}
0005434213777	E97D54	8714 646959	MARIANNA RODIONOVA	{"email": "rodionova.marianna.15011969@postgrespro.ru", "phone": "+70276421313"}
0005434213778	E97D54	4503 537859	IRINA MELNIKOVA	{"phone": "+70184086704"}
0005434213779	E03D9F	8863 501169	ALEKSANDR PETROV	{"phone": "+70250330218"}
0005434213780	5FE393	8320 974279	ANDREY FOMIN	{"phone": "+70999464127"}
0005434213781	BA9C93	2776 426250	GALIYA VASILEVA	{"email": "vasileva_g16111981@postgrespro.ru", "phone": "+70972219418"}
0005434213782	BA9C93	6950 904310	VLADIMIR ILIN	{"email": "ilin_vladimir.21041973@postgrespro.ru", "phone": "+70942754491"}
0005434213783	44841F	0408 580495	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr.071977@postgrespro.ru", "phone": "+70822367795"}
0005434213784	515532	8051 285555	ANNA PETROVA	{"phone": "+70442112866"}
0005434213785	E0267A	9306 961669	ANDREY GORBUNOV	{"email": "a-gorbunov_28021986@postgrespro.ru", "phone": "+70366674426"}
0005434213786	F1E45F	5784 522959	GLEB FEDOROV	{"email": "fedorov-gleb.01091982@postgrespro.ru", "phone": "+70352383472"}
0005434213787	D05F88	2334 548595	OLGA MELNIKOVA	{"phone": "+70612163629"}
0005434213788	D05F88	9840 250036	ALEKSEY SMIRNOV	{"email": "smirnov.aleksey-07021964@postgrespro.ru", "phone": "+70323953316"}
0005434213790	7E1C19	9363 661716	VLADIMIR VASILEV	{"email": "v.vasilev.23061961@postgrespro.ru", "phone": "+70705981676"}
0005434213791	4C51E6	0599 055150	SERGEY DMITRIEV	{"email": "dmitriev-sergey-1970@postgrespro.ru", "phone": "+70962677312"}
0005434213792	6CCD62	3131 111361	ANTONINA SERGEEVA	{"email": "a-sergeeva.24061978@postgrespro.ru", "phone": "+70781538153"}
0005434213793	6CCD62	9919 871555	VALENTINA LOGINOVA	{"phone": "+70798738309"}
0005434213794	D5A760	6177 215315	GALINA DMITRIEVA	{"email": "g.dmitrieva-121976@postgrespro.ru", "phone": "+70904271036"}
0005434213795	9C2A21	3438 131874	ELIZAVETA MATVEEVA	{"phone": "+70742588482"}
0005434213796	B8BE2E	3401 888937	ALBERT DENISOV	{"phone": "+70465043711"}
0005434213797	E0C807	1455 606167	ARTUR EGOROV	{"email": "artur-egorov.011974@postgrespro.ru", "phone": "+70261154807"}
0005434213798	E0C807	6710 440619	SERGEY ISAEV	{"email": "isaev.sergey-101967@postgrespro.ru", "phone": "+70103133492"}
0005434213799	AEDFEF	0949 990067	LYUDMILA NESTEROVA	{"phone": "+70718861898"}
0005434213800	AEDFEF	8583 188001	MAYA FROLOVA	{"email": "maya-frolova_19081967@postgrespro.ru", "phone": "+70520304322"}
0005434213801	05B164	0203 542427	VLADIMIR NAZAROV	{"email": "vladimirnazarov.20081973@postgrespro.ru", "phone": "+70369707810"}
0005434213802	E65584	1324 908971	VLADIMIR KUZNECOV	{"phone": "+70026633753"}
0005434213803	E65584	5291 666108	ALENA ANTONOVA	{"phone": "+70878751166"}
0005434213804	E65584	2753 203326	IGOR POPOV	{"phone": "+70219919739"}
0005434213805	3D6EC4	1359 221621	DMITRIY GRIGOREV	{"email": "d-grigorev.011967@postgrespro.ru", "phone": "+70537711789"}
0005434213806	3D6EC4	2517 749216	ELENA SCHERBAKOVA	{"email": "elena.scherbakova02091973@postgrespro.ru", "phone": "+70175186220"}
0005434213807	765027	5381 725570	VALENTINA ANDREEVA	{"email": "valentina_andreeva_1972@postgrespro.ru", "phone": "+70582975037"}
0005434213808	C78BA4	6905 481964	VLADIMIR ISAEV	{"email": "vladimir.isaev021985@postgrespro.ru", "phone": "+70239272219"}
0005434213809	022CC3	3140 508193	NATALIYA TITOVA	{"phone": "+70977510857"}
0005434213810	1B5A39	6001 129130	TATYANA MATVEEVA	{"phone": "+70155633638"}
0005434213811	1B5A39	4819 553820	NINA ZAKHAROVA	{"phone": "+70919907291"}
0005434213867	D45E3C	9327 576917	NATALYA KOZLOVA	{"phone": "+70202074051"}
0005434213812	3BC859	2650 931274	VLADIMIR SIDOROV	{"email": "vladimir_sidorov021966@postgrespro.ru", "phone": "+70617296643"}
0005434213813	1014E3	8227 841868	YULIYA DMITRIEVA	{"email": "dmitrieva-yuliya041979@postgrespro.ru", "phone": "+70601592411"}
0005434213814	4E8D85	1920 445133	ANDREY BELOV	{"phone": "+70181790377"}
0005434213815	4E8D85	7052 883670	ALEKSANDR DAVYDOV	{"email": "a_davydov.1971@postgrespro.ru", "phone": "+70596932973"}
0005434213816	F4DF07	9969 966828	ANATOLIY DENISOV	{"phone": "+70500654392"}
0005434213817	140F1A	4950 248437	PAVEL MIKHAYLOV	{"email": "mikhaylov.pavel.091975@postgrespro.ru", "phone": "+70871609893"}
0005434213818	5D1776	8442 571050	NINA KISELEVA	{"phone": "+70765378973"}
0005434213819	A6561C	2011 938835	TAMARA LOGINOVA	{"email": "tamara.loginova_23041976@postgrespro.ru", "phone": "+70244522048"}
0005434213821	811F2C	6705 356321	NINA SOROKINA	{"email": "nina_sorokina-101987@postgrespro.ru", "phone": "+70357447421"}
0005434213822	8A713C	0692 205066	IVAN SEMENOV	{"email": "semenov.ivan26071989@postgrespro.ru", "phone": "+70464428771"}
0005434213823	EFE8D9	5006 308358	MIKHAIL SHEVCHENKO	{"email": "mikhail.shevchenko.20121976@postgrespro.ru", "phone": "+70281278210"}
0005434213824	EFE8D9	1155 459107	ELENA PETROVA	{"phone": "+70879426519"}
0005434213825	A48F2E	6169 747381	NIKOLAY KOROLEV	{"phone": "+70601914830"}
0005434213826	F62BC3	0016 561998	ANDREY KAZAKOV	{"email": "andrey-kazakov-121976@postgrespro.ru", "phone": "+70563400375"}
0005434213827	F62BC3	4931 233880	ALEKSANDR VASILEV	{"email": "vasilev_a_1964@postgrespro.ru", "phone": "+70077331222"}
0005434213828	592AFD	1383 287552	LIDIYA ROMANOVA	{"email": "lidiya_romanova19051983@postgrespro.ru", "phone": "+70745663236"}
0005434213829	416615	3919 843568	MARINA DENISOVA	{"phone": "+70750179954"}
0005434213830	06E6F8	0094 242338	NIKOLAY KUZMIN	{"phone": "+70547329255"}
0005434213831	EECA40	0698 228922	VYACHESLAV ZAKHAROV	{"email": "v-zakharov-041965@postgrespro.ru", "phone": "+70532951543"}
0005434213832	3ECBAB	4661 291349	IRINA ORLOVA	{"email": "orlova.irina_1970@postgrespro.ru", "phone": "+70438003263"}
0005434213833	C458AE	3354 367338	NADEZHDA LOGINOVA	{"email": "n_loginova-28041962@postgrespro.ru", "phone": "+70299719351"}
0005434213834	C458AE	8949 736126	VIKTOR ORLOV	{"email": "v.orlov.1963@postgrespro.ru", "phone": "+70269540751"}
0005434213835	26ABCB	6026 174175	DMITRIY FROLOV	{"email": "frolov_d_1967@postgrespro.ru", "phone": "+70839211362"}
0005434213836	0070F5	4001 000680	IRINA ILINA	{"phone": "+70109376410"}
0005434213837	6F9C99	0760 421457	ALEKSEY PETROV	{"phone": "+70628915210"}
0005434213838	6F9C99	0793 757570	LIDIYA KRASNOVA	{"email": "krasnova.l.01071979@postgrespro.ru", "phone": "+70721129897"}
0005434213839	6F9C99	1290 297633	ANNA VOLKOVA	{"phone": "+70731852473"}
0005434213840	9828F2	4814 213415	DMITRIY NIKOLAEV	{"email": "nikolaev_d-12101968@postgrespro.ru", "phone": "+70100366600"}
0005434213841	0C6AC7	6023 541564	ARTEM MAKAROV	{"email": "artem.makarov_1970@postgrespro.ru", "phone": "+70350175918"}
0005434213842	6080EA	3436 917833	OLEG ZHURAVLEV	{"email": "zhuravlev.oleg_03121968@postgrespro.ru", "phone": "+70808194383"}
0005434213843	74E65F	7186 553414	NADEZHDA NESTEROVA	{"email": "nesterova.n10031977@postgrespro.ru", "phone": "+70400356728"}
0005434213844	74E65F	4039 231838	MARGARITA DAVYDOVA	{"email": "davydova_margarita_05021973@postgrespro.ru", "phone": "+70174504591"}
0005434213845	A647D6	6045 949656	VLADIMIR MOISEEV	{"email": "vladimir_moiseev.1979@postgrespro.ru", "phone": "+70014982984"}
0005434213846	67E8E0	7934 199760	NINA FOMINA	{"phone": "+70796502799"}
0005434213847	67E8E0	2010 387634	MAKSIM NOVIKOV	{"email": "m-novikov1977@postgrespro.ru", "phone": "+70409553081"}
0005434213848	881135	6648 992231	AMINA KRASNOVA	{"email": "amina-krasnova-08051977@postgrespro.ru", "phone": "+70681357465"}
0005434213849	02C6AE	8064 415298	SERGEY ANTONOV	{"email": "antonov_s-1967@postgrespro.ru", "phone": "+70680471723"}
0005434213850	02C6AE	2913 315253	VLADIMIR MAKSIMOV	{"email": "vladimir_maksimov_1970@postgrespro.ru", "phone": "+70704185725"}
0005434213851	B8C6E3	2499 958008	IGOR GERASIMOV	{"phone": "+70150052975"}
0005434213852	657C2C	3418 190065	SVETLANA FROLOVA	{"email": "s.frolova_1979@postgrespro.ru", "phone": "+70620302013"}
0005434213853	953358	4356 242197	SERGEY ALEKSANDROV	{"email": "s-aleksandrov.13121979@postgrespro.ru", "phone": "+70504564128"}
0005434213854	2D7DFC	1729 584972	VASILIY SHEVCHENKO	{"phone": "+70248996360"}
0005434213855	B61B7E	4857 101268	VLADISLAV IVANOV	{"email": "vladislav_ivanov.1977@postgrespro.ru", "phone": "+70642492217"}
0005434213856	6B1F01	2343 052534	NIKOLAY IVANOV	{"phone": "+70157919818"}
0005434213857	8B4BC4	3080 504725	ANNA NOVIKOVA	{"email": "a.novikova.1971@postgrespro.ru", "phone": "+70776156949"}
0005434213858	626BCF	2491 144960	RAISA MEDVEDEVA	{"phone": "+70322495390"}
0005434213859	626BCF	7680 122158	DENIS DMITRIEV	{"email": "d-dmitriev1982@postgrespro.ru", "phone": "+70831217213"}
0005434213860	E6A881	6658 221202	ELENA BOGDANOVA	{"phone": "+70139618520"}
0005434213861	70408A	6221 276173	VLADIMIR MIRONOV	{"phone": "+70883165066"}
0005434213862	92CAFC	1349 572394	YULIYA KRASNOVA	{"phone": "+70166318992"}
0005434213863	FBAF66	9537 420512	GALINA FROLOVA	{"email": "galina_frolova071960@postgrespro.ru", "phone": "+70263050807"}
0005434213864	53E0AF	3947 362948	MIKHAIL TIKHONOV	{"email": "m.tikhonov_1973@postgrespro.ru", "phone": "+70091903628"}
0005434213865	9A739E	3751 392776	SERGEY KARPOV	{"email": "karpov.sergey.061978@postgrespro.ru", "phone": "+70431458379"}
0005434213866	9A739E	5456 905151	TATYANA KOROLEVA	{"email": "koroleva_tatyana.14071970@postgrespro.ru", "phone": "+70510631125"}
0005434213868	16F869	2005 738869	ELENA VLASOVA	{"phone": "+70579186933"}
0005434213869	D6F0B3	8898 335516	BORIS MEDVEDEV	{"email": "medvedev.b.011978@postgrespro.ru", "phone": "+70372174194"}
0005434213870	E0304B	7081 466684	NATALIYA ANTONOVA	{"phone": "+70976572379"}
0005434213871	BE521E	8575 188204	MAKSIM NIKOLAEV	{"phone": "+70033106345"}
0005434213872	BE521E	3909 586878	GALINA STEPANOVA	{"email": "stepanovag.031964@postgrespro.ru", "phone": "+70420492276"}
0005434213873	CA616F	7241 230064	GALINA NAZAROVA	{"phone": "+70441118854"}
0005434213874	085E91	5301 493792	OLEG NAZAROV	{"email": "olegnazarov_26031989@postgrespro.ru", "phone": "+70464128586"}
0005434213875	085E91	2403 623709	ARTEM EGOROV	{"phone": "+70517684472"}
0005434213876	F681EA	3457 723724	ALEKSEY PETROV	{"email": "apetrov_11021975@postgrespro.ru", "phone": "+70311863238"}
0005434213877	3F9760	1133 818029	ANASTASIYA KUZMINA	{"phone": "+70941307650"}
0005434213878	508149	0480 609460	POLINA KUZNECOVA	{"email": "polina_kuznecova-051970@postgrespro.ru", "phone": "+70636188341"}
0005434213879	1C8F46	1204 379096	ELIZAVETA VASILEVA	{"email": "vasilevae-1967@postgrespro.ru", "phone": "+70216765323"}
0005434213880	1C8F46	9825 980587	NADEZHDA KISELEVA	{"email": "kiselevan27051970@postgrespro.ru", "phone": "+70624764070"}
0005434213881	084926	5289 710323	NIKOLAY MEDVEDEV	{"email": "nikolay_medvedev-101973@postgrespro.ru", "phone": "+70627638175"}
0005434213882	084926	3803 612844	NADEZHDA PETROVA	{"email": "nadezhda.petrova.1977@postgrespro.ru", "phone": "+70630510635"}
0005434213883	D08FDF	6087 240108	PETR POPOV	{"email": "petr.popov.111985@postgrespro.ru", "phone": "+70636798286"}
0005434213884	D08FDF	5571 715960	ALEKSANDR KUZNECOV	{"phone": "+70682961996"}
0005434213885	5827F0	2875 768303	VLADIMIR VLASOV	{"phone": "+70866317583"}
0005434213886	6916D7	0515 284539	VYACHESLAV SOLOVEV	{"phone": "+70975138558"}
0005434213887	7DD22F	8682 994652	EVGENIY FILIPPOV	{"phone": "+70858149816"}
0005434213888	7DD22F	3863 425371	DARYA KAZAKOVA	{"email": "dkazakova_1963@postgrespro.ru", "phone": "+70045273496"}
0005434213889	9D3161	3806 552086	SERGEY ZAKHAROV	{"phone": "+70216088192"}
0005434213890	2C2180	3047 012784	MARIYA YUDINA	{"email": "m.yudina.1963@postgrespro.ru", "phone": "+70598857789"}
0005434213891	2C2180	4243 899630	RAISA SOKOLOVA	{"phone": "+70061461548"}
0005434213892	2C2180	0816 376815	VIKTOR CHERNOV	{"email": "viktorchernov_031972@postgrespro.ru", "phone": "+70339634394"}
0005434213893	6B5849	8198 992974	NIKOLAY SMIRNOV	{"phone": "+70567229997"}
0005434213894	6B5849	4905 460504	DANILA ZAYCEV	{"phone": "+70374175853"}
0005434213895	6B5849	8449 549902	TATYANA SOROKINA	{"email": "sorokina.t-081972@postgrespro.ru", "phone": "+70593720065"}
0005434213896	E6AFEB	0791 631807	TATYANA IVANOVA	{"phone": "+70108693553"}
0005434213897	8FEACB	7880 466163	PAVEL ISAEV	{"phone": "+70137670720"}
0005434213898	741227	1235 713628	ANTONINA SOKOLOVA	{"phone": "+70095405321"}
0005434213899	EAF099	8932 419697	TAMARA KONDRATEVA	{"phone": "+70343924387"}
0005434213900	7F7F52	4798 509611	ALEKSANDR RODIONOV	{"phone": "+70457312629"}
0005434213901	7F7F52	4489 723794	ARTEM VOROBEV	{"email": "artem_vorobev111967@postgrespro.ru", "phone": "+70667752035"}
0005434213902	E6105B	6167 619195	VLADIMIR MAKSIMOV	{"phone": "+70630082779"}
0005434213903	C08FA3	1417 937708	ANDREY POPOV	{"phone": "+70695267979"}
0005434213904	9841AB	3899 405778	IRINA TARASOVA	{"phone": "+70253055471"}
0005434213905	C01E9B	8959 245285	MARINA NESTEROVA	{"phone": "+70044116392"}
0005434213906	B67A48	2052 015646	ALEKSANDR GORBUNOV	{"phone": "+70621899978"}
0005434213907	B2D3A9	7971 165004	VLADIMIR DMITRIEV	{"email": "dmitriev.v_111957@postgrespro.ru", "phone": "+70071417710"}
0005434213908	200367	2611 321163	DMITRIY BONDARENKO	{"email": "dbondarenko-1966@postgrespro.ru", "phone": "+70620791572"}
0005434213909	F19049	8945 293320	POLINA SMIRNOVA	{"email": "p_smirnova-1968@postgrespro.ru", "phone": "+70492216302"}
0005434213910	F19049	1597 866468	ALINA EFIMOVA	{"phone": "+70607632213"}
0005434213911	82587C	1715 105136	EKATERINA BOGDANOVA	{"email": "bogdanova.e_30061975@postgrespro.ru", "phone": "+70008746671"}
0005434213912	FCADD2	5296 356292	IGOR DMITRIEV	{"email": "igordmitriev_1966@postgrespro.ru", "phone": "+70278031874"}
0005434213913	FCADD2	5172 147296	OLGA TIKHONOVA	{"phone": "+70120330612"}
0005434213914	913917	0163 311241	OLGA BORISOVA	{"phone": "+70916266576"}
0005434213915	913917	1940 922694	NATALYA ANTONOVA	{"phone": "+70515264177"}
0005434213916	47C58F	8224 983851	STEPAN MOISEEV	{"email": "stepan_moiseev_101967@postgrespro.ru", "phone": "+70974433860"}
0005434213917	47C58F	2072 255078	EVGENIY DENISOV	{"phone": "+70756597155"}
0005434213918	EC7812	5932 280265	ANNA TARASOVA	{"phone": "+70424215095"}
0005434213919	EC7812	9226 753032	MIKHAIL GRIGOREV	{"phone": "+70371065671"}
0005434213920	427361	6239 191712	PETR IVANOV	{"email": "p-ivanov.071968@postgrespro.ru", "phone": "+70989026898"}
0005434213921	67E666	8472 257373	ALEKSEY MIKHAYLOV	{"phone": "+70333440978"}
0005434213922	67E666	7823 791920	VERA FEDOROVA	{"email": "v.fedorova1977@postgrespro.ru", "phone": "+70828423711"}
0005434213923	BA7E3C	2660 010672	YULIYA MELNIKOVA	{"email": "yuliyamelnikova-28091980@postgrespro.ru", "phone": "+70412432421"}
0005434213924	C6B830	4611 358596	SERGEY FEDOROV	{"phone": "+70576915356"}
0005434213925	82200E	3360 208009	VYACHESLAV PETROV	{"email": "petrov_vyacheslav-25071973@postgrespro.ru", "phone": "+70102505108"}
0005434213926	82200E	5177 375592	VERA MARTYNOVA	{"email": "martynova-v1974@postgrespro.ru", "phone": "+70437691442"}
0005434213927	0104BE	4428 576581	SVETLANA LAZAREVA	{"email": "lazareva-svetlana-031969@postgrespro.ru", "phone": "+70248169731"}
0005434213928	D29CEA	5778 106796	DMITRIY GERASIMOV	{"phone": "+70471177658"}
0005434213929	D29CEA	9465 930293	SERGEY VOROBEV	{"phone": "+70731942411"}
0005434213930	8DE7ED	4022 122408	NATALYA ILINA	{"email": "ilina.n_101975@postgrespro.ru", "phone": "+70484358262"}
0005434213931	A03E98	5287 357270	ALEKSANDRA AKIMOVA	{"phone": "+70507974137"}
0005434213932	A03E98	3986 277866	ALEKSEY FEDOTOV	{"email": "alekseyfedotov-31081968@postgrespro.ru", "phone": "+70264779855"}
0005434213933	574C72	5697 802404	ELENA ZAYCEVA	{"phone": "+70555958761"}
0005434213934	574C72	7600 130390	ILYA BORISOV	{"phone": "+70299638621"}
0005434213935	A0A62C	4378 125094	EVGENIYA NIKITINA	{"email": "e-nikitina111963@postgrespro.ru", "phone": "+70420322371"}
0005434213936	0423F4	4034 570073	EKATERINA AKIMOVA	{"email": "akimovae1970@postgrespro.ru", "phone": "+70901611909"}
0005434213937	D746DC	8301 508665	NATALIYA SEMENOVA	{"email": "nataliya_semenova_1974@postgrespro.ru", "phone": "+70075784391"}
0005434213938	047071	0370 366616	VLADIMIR PETROV	{"phone": "+70966513836"}
0005434213939	E6B035	8769 485103	SVETLANA ALEKSANDROVA	{"email": "aleksandrova.s.031977@postgrespro.ru", "phone": "+70087144416"}
0005434213940	EB57E5	4573 337803	ANATOLIY ALEKSANDROV	{"phone": "+70470959518"}
0005434213941	EB57E5	1024 801182	YULIYA STEPANOVA	{"email": "stepanova-yuliya.1969@postgrespro.ru", "phone": "+70717645517"}
0005434213942	A567F6	0401 892436	VIKTOR YAKOVLEV	{"email": "vyakovlev.03011969@postgrespro.ru", "phone": "+70996647819"}
0005434213943	A567F6	0000 520871	IRINA BARANOVA	{"phone": "+70047718114"}
0005434213944	A567F6	1929 956727	VYACHESLAV SAVELEV	{"phone": "+70297199277"}
0005434213945	640FF5	1787 354982	MIKHAIL MATVEEV	{"email": "matveev_m_11091965@postgrespro.ru", "phone": "+70441489930"}
0005434213946	7F22EA	0216 687881	VALENTINA SMIRNOVA	{"email": "valentinasmirnova1968@postgrespro.ru", "phone": "+70901093435"}
0005434213947	7F22EA	0943 316604	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir1974@postgrespro.ru", "phone": "+70132113056"}
0005434213948	02704D	4954 491516	MARAT TARASOV	{"email": "tarasov.marat_081973@postgrespro.ru", "phone": "+70469730202"}
0005434213949	7E36DA	8898 658599	EVGENIY SMIRNOV	{"email": "smirnove30071973@postgrespro.ru", "phone": "+70566723708"}
0005434213950	ABBC7F	5620 507171	EVGENIY MIKHAYLOV	{"phone": "+70010046410"}
0005434213951	F89D0F	3545 947211	OLGA MAKSIMOVA	{"email": "maksimova-o.1972@postgrespro.ru", "phone": "+70324410034"}
0005434213952	652659	9644 146828	VENERA KRASNOVA	{"email": "v_krasnova20091975@postgrespro.ru", "phone": "+70556678892"}
0005434213953	652659	4224 458608	ARTEM TARASOV	{"email": "tarasov_a.101977@postgrespro.ru", "phone": "+70942121626"}
0005434213954	43DEF4	4619 092219	EVGENIY KULIKOV	{"phone": "+70415001024"}
0005434213955	43DEF4	9100 606001	DANIIL MAKAROV	{"email": "d.makarov.101966@postgrespro.ru", "phone": "+70608984129"}
0005434214403	A78975	6544 685355	ELENA VLASOVA	{"phone": "+70882543489"}
0005434213956	16D176	5487 087592	ALEKSEY EGOROV	{"email": "aleksey_egorov-05041969@postgrespro.ru", "phone": "+70348101553"}
0005434213957	16D176	4979 656616	DENIS NIKITIN	{"email": "d_nikitin.1967@postgrespro.ru", "phone": "+70748556420"}
0005434213958	BE1078	7017 084928	NIKOLAY PETROV	{"email": "nikolay.petrov1975@postgrespro.ru", "phone": "+70530097613"}
0005434213959	BE1078	4647 775452	YULIYA SEMENOVA	{"email": "semenovayuliya_031972@postgrespro.ru", "phone": "+70318687506"}
0005434213960	73FEDB	4643 590780	LYUDMILA KONOVALOVA	{"phone": "+70492627378"}
0005434213961	BD903D	4399 870630	SVETLANA KONOVALOVA	{"phone": "+70414591107"}
0005434213962	BD903D	7501 682271	ALEKSEY IVANOV	{"phone": "+70201334313"}
0005434213963	942CFD	1752 918736	KARINA PETROVA	{"phone": "+70455439392"}
0005434213964	942CFD	4787 141485	SVETLANA KONDRATEVA	{"phone": "+70701018973"}
0005434213965	ABDEB6	8900 467542	VALERIYA MOISEEVA	{"email": "valeriyamoiseeva.021969@postgrespro.ru", "phone": "+70238669739"}
0005434213966	ABDEB6	5043 267220	ANTON PAVLOV	{"email": "pavlov.a_1963@postgrespro.ru", "phone": "+70244860927"}
0005434213967	254169	7196 159860	OLGA PAVLOVA	{"phone": "+70260566134"}
0005434213968	1BFDAF	8850 979523	GALINA SIDOROVA	{"phone": "+70066660441"}
0005434213969	25FA74	2402 831898	VIKTORIYA MIRONOVA	{"email": "mironova-viktoriya1966@postgrespro.ru", "phone": "+70508106557"}
0005434213970	9CAD6D	1880 018978	SVETLANA KOZLOVA	{"phone": "+70958509702"}
0005434213971	91C44F	2894 298951	GALINA ARKHIPOVA	{"email": "galina_arkhipova_121972@postgrespro.ru", "phone": "+70983286602"}
0005434213972	24A398	3025 983701	OLGA NIKITINA	{"email": "olganikitina041972@postgrespro.ru", "phone": "+70558363293"}
0005434213973	66B952	9782 389325	ELINA MIKHAYLOVA	{"phone": "+70090121823"}
0005434213974	CEFA60	5160 930642	OLGA LAZAREVA	{"email": "olgalazareva-031970@postgrespro.ru", "phone": "+70745881310"}
0005434213975	401967	1156 509772	ANATOLIY RODIONOV	{"phone": "+70534983919"}
0005434213976	401967	4641 774015	ANNA VASILEVA	{"email": "anna-vasileva.06061971@postgrespro.ru", "phone": "+70252861482"}
0005434213977	255393	2870 787124	MARIYA LEBEDEVA	{"phone": "+70909397460"}
0005434213978	255393	8494 785120	VIKTOR ZAKHAROV	{"phone": "+70729330585"}
0005434213979	A85BF9	7830 678729	ILYA PAVLOV	{"email": "ilya-pavlov_1966@postgrespro.ru", "phone": "+70971004181"}
0005434213980	B045E6	2988 545259	NATALYA IVANOVA	{"phone": "+70701939029"}
0005434213981	31791A	0977 864813	ALEKSANDR SCHERBAKOV	{"phone": "+70107022376"}
0005434213982	31791A	1070 422443	VALERIY MIKHAYLOV	{"phone": "+70228016667"}
0005434213983	0740C5	4376 805535	IVAN PAVLOV	{"email": "ivan-pavlov01081982@postgrespro.ru", "phone": "+70826956032"}
0005434213984	BE4D81	1390 269162	NINA ANDREEVA	{"phone": "+70674021695"}
0005434213985	BE4D81	3908 158175	OLESYA VLASOVA	{"email": "ovlasova1969@postgrespro.ru", "phone": "+70459935764"}
0005434213986	DB680F	8336 092039	SVETLANA ZAYCEVA	{"email": "zayceva.s011976@postgrespro.ru", "phone": "+70694764250"}
0005434213987	DB680F	7879 093235	NURIYA KOZLOVA	{"phone": "+70704813735"}
0005434213988	DB680F	0978 719346	IGOR KUZNECOV	{"email": "i_kuznecov-011976@postgrespro.ru", "phone": "+70411882124"}
0005434213989	108768	5405 737269	IRINA PAVLOVA	{"email": "irina_pavlova1979@postgrespro.ru", "phone": "+70326254652"}
0005434213990	72D2B5	8411 840691	ANATOLIY STEPANOV	{"email": "anatoliy.stepanov-07061973@postgrespro.ru", "phone": "+70748167236"}
0005434213991	72D2B5	7166 557483	VALENTINA BELYAEVA	{"email": "valentina.belyaeva1979@postgrespro.ru", "phone": "+70010700823"}
0005434213992	667545	4839 839443	MARIYA STEPANOVA	{"email": "stepanova-m.05031976@postgrespro.ru", "phone": "+70993441110"}
0005434213993	F0FC14	4804 068266	LARISA POPOVA	{"phone": "+70269477614"}
0005434213994	F0FC14	6964 749744	ANATOLIY ORLOV	{"phone": "+70087331900"}
0005434213995	F0FC14	6816 671310	ALENA KUZNECOVA	{"email": "alenakuznecova.1975@postgrespro.ru", "phone": "+70228568225"}
0005434213996	C49C08	3858 485017	EKATERINA GERASIMOVA	{"phone": "+70756017673"}
0005434213997	9DAD2F	9406 497782	YULIYA KOZLOVA	{"phone": "+70566229671"}
0005434213998	336B9E	2777 508582	VLADIMIR SEMENOV	{"email": "v.semenov31031966@postgrespro.ru", "phone": "+70380223322"}
0005434213999	98A35C	0861 445317	VALERIY MAKAROV	{"email": "makarov_valeriy_121969@postgrespro.ru", "phone": "+70105131966"}
0005434214000	E93E91	7750 626455	NINA ZHUKOVA	{"email": "zhukova-nina_1962@postgrespro.ru", "phone": "+70427314428"}
0005434214001	35E550	8469 051023	ILYA IVANOV	{"email": "ivanov.ilya16011978@postgrespro.ru", "phone": "+70040798891"}
0005434214002	35E550	7337 430481	LEONID ZHUKOV	{"phone": "+70438651719"}
0005434214003	2F8EFF	9686 107386	LYUBOV EFIMOVA	{"email": "efimova-l1966@postgrespro.ru", "phone": "+70510394536"}
0005434214004	FFA1A2	7588 509370	KHASAN SMIRNOV	{"phone": "+70407019986"}
0005434214005	1173C0	6469 707515	ALEKSANDR GORBUNOV	{"email": "a_gorbunov071971@postgrespro.ru", "phone": "+70629856051"}
0005434214006	4B17AE	9870 580799	TATYANA LUKYANOVA	{"email": "tatyana-lukyanova_051980@postgrespro.ru", "phone": "+70857112453"}
0005434214007	96190C	9883 674070	VALENTIN KUDRYASHOV	{"phone": "+70027375975"}
0005434214008	18BC4C	5238 146866	SOFYA MEDVEDEVA	{"phone": "+70738423888"}
0005434214009	8218BE	5681 637625	NIKOLAY MIKHAYLOV	{"phone": "+70223087861"}
0005434214010	778AF0	0352 753046	VLADIMIR MAKSIMOV	{"phone": "+70768229037"}
0005434214011	895D44	1698 665082	DMITRIY ILIN	{"phone": "+70143411506"}
0005434214012	B5B625	2928 646004	NINA IVANOVA	{"email": "ivanova_n-031984@postgrespro.ru", "phone": "+70076930338"}
0005434214013	B5B625	9319 861663	OLGA ABRAMOVA	{"phone": "+70536795902"}
0005434214014	F619FE	4686 801057	VALENTINA IVANOVA	{"phone": "+70812536035"}
0005434214015	F619FE	8884 186113	VIKTOR ZHUKOV	{"email": "v-zhukov.24021980@postgrespro.ru", "phone": "+70680093469"}
0005434214016	F619FE	1548 319742	TATYANA FILATOVA	{"email": "filatovat.29071968@postgrespro.ru", "phone": "+70832091515"}
0005434214017	B0AFE3	4026 107709	KRISTINA LEBEDEVA	{"email": "kristinalebedeva-1971@postgrespro.ru", "phone": "+70280303180"}
0005434214018	B0AFE3	4138 901231	ANDREY ORLOV	{"phone": "+70937288868"}
0005434214019	BB8223	2130 557147	YURIY SMIRNOV	{"email": "smirnovy.31031984@postgrespro.ru", "phone": "+70285200431"}
0005434214020	C4EA9B	2538 237780	OLEG IVANOV	{"phone": "+70517939211"}
0005434214021	C1A969	1950 478134	VALENTINA MALYSHEVA	{"email": "malysheva-valentina1973@postgrespro.ru", "phone": "+70973123402"}
0005434214022	C1A969	0964 837683	IRINA SAVELEVA	{"phone": "+70108288674"}
0005434214023	BFACC2	4534 830185	OLEG KUZMIN	{"phone": "+70764307994"}
0005434214024	BFACC2	9891 965253	ANDREY POPOV	{"phone": "+70648872461"}
0005434214025	6B987E	0693 545661	SERGEY GRIGOREV	{"email": "grigorevsergey.021968@postgrespro.ru", "phone": "+70379539223"}
0005434214026	2B652C	6300 570768	ANNA SOKOLOVA	{"phone": "+70682987912"}
0005434214027	D7936B	3074 167246	VIKTOR FOMIN	{"email": "v.fomin06071978@postgrespro.ru", "phone": "+70620269680"}
0005434214028	C7EA0A	8203 719961	VASILIY MOISEEV	{"email": "moiseevvasiliy.1978@postgrespro.ru", "phone": "+70443494340"}
0005434214029	30B808	1326 683796	NATALYA ZOTOVA	{"phone": "+70374215032"}
0005434214030	29AD7D	8627 814378	OLGA EGOROVA	{"email": "olga.egorova-28011963@postgrespro.ru", "phone": "+70217376419"}
0005434214031	418A12	2661 900887	LYUBOV DMITRIEVA	{"phone": "+70795507975"}
0005434214032	418A12	9060 665203	VASILIY MOISEEV	{"email": "v-moiseev_041980@postgrespro.ru", "phone": "+70834060689"}
0005434214033	8D48CA	6683 529066	IRINA RODIONOVA	{"phone": "+70310551341"}
0005434214034	8D48CA	2586 501740	ANATOLIY AFANASEV	{"phone": "+70890893128"}
0005434214035	A36BB3	5287 830760	GENNADIY KUDRYASHOV	{"email": "gennadiy.kudryashov111971@postgrespro.ru", "phone": "+70398589500"}
0005434214092	F9B907	1740 833450	LARISA EFREMOVA	{"phone": "+70379700890"}
0005434214036	110C79	3040 629628	NADEZHDA IVANOVA	{"email": "n.ivanova-1974@postgrespro.ru", "phone": "+70665701654"}
0005434214037	566A5B	1714 887339	RAISA MATVEEVA	{"email": "matveevaraisa.17101966@postgrespro.ru", "phone": "+70355927363"}
0005434214038	D7F335	9713 718137	ANASTASIYA KULIKOVA	{"phone": "+70410665198"}
0005434214039	D7F335	1323 596383	MARTA NIKIFOROVA	{"email": "mnikiforova_1985@postgrespro.ru", "phone": "+70234311131"}
0005434214040	3391A5	4645 113001	ANDREY SOKOLOV	{"email": "asokolov-1972@postgrespro.ru", "phone": "+70677421003"}
0005434214041	C96F70	9567 845318	EVGENIY KAZAKOV	{"email": "kazakov-evgeniy-01101969@postgrespro.ru", "phone": "+70216601144"}
0005434214042	E3D47B	8476 767724	KARINA IVANOVA	{"phone": "+70241934214"}
0005434214043	E3D47B	4648 693409	NINA TARASOVA	{"email": "nina_tarasova-011979@postgrespro.ru", "phone": "+70037898563"}
0005434214044	99EE9B	4514 038012	SERGEY OSIPOV	{"email": "sergey_osipov.30071963@postgrespro.ru", "phone": "+70059889012"}
0005434214045	99EE9B	5744 749427	ANNA KOZLOVA	{"phone": "+70285490507"}
0005434214046	748B34	5294 099267	TATYANA MAKSIMOVA	{"phone": "+70563917266"}
0005434214047	748B34	0790 468665	YULIYA LAZAREVA	{"phone": "+70470264287"}
0005434214048	454FD5	5436 787860	SVETLANA IVANOVA	{"phone": "+70219691625"}
0005434214049	0982B4	4800 745327	SERGEY BARANOV	{"email": "s.baranov021971@postgrespro.ru", "phone": "+70213874351"}
0005434214050	3E8E8B	3939 586076	ELENA POPOVA	{"email": "popova_e1962@postgrespro.ru", "phone": "+70155639194"}
0005434214051	3E8E8B	9328 264622	ALEKSEY ALEKSEEV	{"email": "alekseevaleksey-081983@postgrespro.ru", "phone": "+70789303611"}
0005434214052	3E8E8B	3755 728054	EKATERINA NIKOLAEVA	{"phone": "+70336485479"}
0005434214053	24127B	7673 317841	OLGA YUDINA	{"phone": "+70627780592"}
0005434214054	50AA7F	3647 449694	OKSANA KISELEVA	{"email": "o-kiseleva-011980@postgrespro.ru", "phone": "+70096650431"}
0005434214055	686AF3	9352 266411	SERGEY PAVLOV	{"email": "pavlovsergey-1976@postgrespro.ru", "phone": "+70234349794"}
0005434214056	686AF3	3773 376312	TATYANA LOGINOVA	{"email": "tatyana_loginova_27021969@postgrespro.ru", "phone": "+70517013271"}
0005434214057	EB3DC1	9622 109657	LINAR IVANOV	{"phone": "+70222830753"}
0005434214058	3ADF1D	2989 924464	VLADIMIR FEDOROV	{"phone": "+70850873830"}
0005434214059	8E91E3	5447 848895	ALEKSEY PAVLOV	{"phone": "+70088502189"}
0005434214060	429733	7096 057795	ANTONINA GORBUNOVA	{"email": "gorbunova_a-07041972@postgrespro.ru", "phone": "+70094448002"}
0005434214061	475483	1558 462012	VLADIMIR VOLKOV	{"email": "volkovvladimir-1974@postgrespro.ru", "phone": "+70691316029"}
0005434214062	16AE9E	9361 364229	RUZALIYA TROFIMOVA	{"phone": "+70818801109"}
0005434214063	46BB03	1614 145920	NADEZHDA BORISOVA	{"email": "borisova_nadezhda1975@postgrespro.ru", "phone": "+70295931348"}
0005434214064	46BB03	1328 536578	SERGEY MATVEEV	{"phone": "+70493429365"}
0005434214065	C63A1E	7166 773265	ARINA KUZMINA	{"phone": "+70607967714"}
0005434214066	8BBC42	0612 483972	ANDREY KISELEV	{"phone": "+70392894347"}
0005434214067	70BF4A	5903 641500	EVGENIYA RODIONOVA	{"phone": "+70506783235"}
0005434214068	D6AF21	5569 880811	PAVEL KOZLOV	{"email": "kozlov.p-16101963@postgrespro.ru", "phone": "+70649990169"}
0005434214069	D6AF21	7700 195165	NIKOLAY ROMANOV	{"email": "n_romanov1979@postgrespro.ru", "phone": "+70940143571"}
0005434214070	F6F7B4	5111 246438	VLADIMIR SIDOROV	{"email": "sidorovv.051970@postgrespro.ru", "phone": "+70684389751"}
0005434214071	45C204	6472 585529	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr1966@postgrespro.ru", "phone": "+70424292888"}
0005434214072	1D9841	0925 106450	OLEG AFANASEV	{"phone": "+70072717663"}
0005434214073	9E3C03	6231 173237	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda.1987@postgrespro.ru", "phone": "+70276495923"}
0005434214074	A7E6A2	7619 786334	YURIY EGOROV	{"phone": "+70023090295"}
0005434214075	A7E6A2	6035 273784	NATALYA IVANOVA	{"phone": "+70789569226"}
0005434214076	A7E6A2	7047 465949	SERGEY POPOV	{"phone": "+70432903948"}
0005434214077	F76E9E	0887 297262	NADEZHDA POLYAKOVA	{"email": "nadezhda_polyakova_23081966@postgrespro.ru", "phone": "+70185189696"}
0005434214078	25419D	9323 828529	VYACHESLAV ZAYCEV	{"phone": "+70099671221"}
0005434214079	8A5AB4	9852 926686	LYUDMILA FROLOVA	{"phone": "+70670180146"}
0005434214080	125C2B	2100 114428	ILYA OSIPOV	{"phone": "+70384893326"}
0005434214081	B8FA7D	2718 868321	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova.1977@postgrespro.ru", "phone": "+70086647476"}
0005434214082	B8FA7D	5510 052249	EVGENIY KAZAKOV	{"phone": "+70645288828"}
0005434214083	B1BD25	1226 917254	ALEKSANDR VASILEV	{"email": "a-vasilev-1966@postgrespro.ru", "phone": "+70045964618"}
0005434214084	070319	1013 714375	NATALYA SIDOROVA	{"email": "natalya.sidorova.1969@postgrespro.ru", "phone": "+70663257098"}
0005434214085	E79D62	8627 419182	DIANA ZHUKOVA	{"phone": "+70291300430"}
0005434214086	5ED768	8562 769942	EVGENIYA SMIRNOVA	{"phone": "+70055153229"}
0005434214087	5ED768	3583 596833	LARISA KARPOVA	{"email": "karpova_larisa.1975@postgrespro.ru", "phone": "+70735272102"}
0005434214088	1C487F	1401 806523	OKSANA FADEEVA	{"email": "o-fadeeva_021973@postgrespro.ru", "phone": "+70290006970"}
0005434214089	4A533A	7866 145815	ALEKSANDR FOMIN	{"phone": "+70193273383"}
0005434214090	4B1AA3	4598 820623	RIMMA LEBEDEVA	{"email": "rimmalebedeva1957@postgrespro.ru", "phone": "+70731645112"}
0005434214091	4B1AA3	6160 641327	IVAN KOROLEV	{"email": "korolevi.101969@postgrespro.ru", "phone": "+70961598625"}
0005434214093	F127D0	7838 149935	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr_10041967@postgrespro.ru", "phone": "+70627179563"}
0005434214094	C98C15	3052 914815	ANDREY KARPOV	{"phone": "+70907471645"}
0005434214095	C98C15	6106 859750	MARAT VOLKOV	{"email": "volkov_marat_051967@postgrespro.ru", "phone": "+70248175683"}
0005434214096	6C9CD1	0709 472807	NINA MARTYNOVA	{"phone": "+70510704322"}
0005434214097	6C9CD1	3817 480182	NADEZHDA ORLOVA	{"email": "n_orlova.091972@postgrespro.ru", "phone": "+70527227569"}
0005434214098	0C92B1	2685 967627	GALINA TARASOVA	{"email": "tarasovag_07091980@postgrespro.ru", "phone": "+70813451571"}
0005434214099	983759	8406 007327	TATYANA POLYAKOVA	{"phone": "+70624743204"}
0005434214100	DFDBC4	8585 502806	ARTEM PAVLOV	{"phone": "+70272821849"}
0005434214101	DDF10E	7718 962927	GALINA VLASOVA	{"email": "vlasova-galina-1976@postgrespro.ru", "phone": "+70070901708"}
0005434214102	DDF10E	7997 565978	ARTEM KUZMIN	{"email": "kuzmin-artem-121965@postgrespro.ru", "phone": "+70888768624"}
0005434214103	FC4A61	5642 724015	ANDREY MELNIKOV	{"email": "melnikov_andrey_1974@postgrespro.ru", "phone": "+70956548995"}
0005434214104	976093	0028 685943	EKATERINA FILATOVA	{"email": "filatovaekaterina_26051967@postgrespro.ru", "phone": "+70883896902"}
0005434214105	0E9523	4709 673325	YANA SMIRNOVA	{"email": "yana_smirnova071978@postgrespro.ru", "phone": "+70056614771"}
0005434214106	744735	4389 501808	VASILIY ILIN	{"email": "ilin.v.20081968@postgrespro.ru", "phone": "+70192271005"}
0005434214107	9A49E3	0862 699624	IRINA KOLESNIKOVA	{"phone": "+70905095666"}
0005434214108	B53037	2279 664077	KRISTINA KUZNECOVA	{"phone": "+70346536420"}
0005434214109	B53037	8254 542881	NINA RYABOVA	{"phone": "+70636271301"}
0005434214110	69AAE7	8305 547156	NADEZHDA KOVALEVA	{"email": "kovaleva.n_22071973@postgrespro.ru", "phone": "+70725192972"}
0005434214111	1B50FD	6723 646703	NIKOLAY TIMOFEEV	{"phone": "+70017274580"}
0005434214112	A9A7A3	9219 911438	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir1983@postgrespro.ru", "phone": "+70789739440"}
0005434214113	381396	1724 143536	ALEKSEY SOKOLOV	{"email": "sokolov.aleksey.16121965@postgrespro.ru", "phone": "+70592900141"}
0005434214114	E7B59C	4895 527463	VIKTOR ROMANOV	{"email": "v_romanov.081974@postgrespro.ru", "phone": "+70834416566"}
0005434214115	E7B59C	1302 553184	EKATERINA IVANOVA	{"phone": "+70586788577"}
0005434214116	BDC236	2888 722280	DANIIL SOKOLOV	{"email": "sokolov.daniil1974@postgrespro.ru", "phone": "+70861338199"}
0005434214117	0E604A	8548 730040	OLEG MELNIKOV	{"phone": "+70433561865"}
0005434214118	0E604A	1170 197064	ALEKSANDR MAKAROV	{"phone": "+70422651296"}
0005434214119	943BCF	3378 250704	ALEKSANDR KOZLOV	{"phone": "+70157641135"}
0005434214120	C9AC9B	9238 030737	VASILIY SERGEEV	{"email": "sergeevvasiliy_01081969@postgrespro.ru", "phone": "+70177033147"}
0005434214122	D854CC	6146 838925	ALINA VOROBEVA	{"phone": "+70135561600"}
0005434214123	D854CC	9178 715682	DANIIL MOISEEV	{"phone": "+70968925315"}
0005434214124	E41B06	4265 946088	SERGEY ALEKSANDROV	{"email": "aleksandrovs101963@postgrespro.ru", "phone": "+70933486929"}
0005434214125	1347FA	6649 796010	NINA MIKHAYLOVA	{"email": "n-mikhaylova051978@postgrespro.ru", "phone": "+70266463436"}
0005434214126	1347FA	6100 319261	SERGEY KONOVALOV	{"email": "sergey_konovalov-081972@postgrespro.ru", "phone": "+70897734961"}
0005434214127	0A1D57	8447 114033	NATALYA KUZMINA	{"email": "nkuzmina.031973@postgrespro.ru", "phone": "+70130487852"}
0005434214128	0A1D57	7387 770463	TATYANA FOMINA	{"email": "t.fomina.011961@postgrespro.ru", "phone": "+70094245125"}
0005434214129	07D017	1335 564266	SVETLANA RYABOVA	{"phone": "+70938316277"}
0005434214130	CCEDF9	2317 883009	NATALYA ISAEVA	{"email": "natalyaisaeva-031975@postgrespro.ru", "phone": "+70549240689"}
0005434214131	E27322	3143 083985	VALERIY FEDOROV	{"phone": "+70035645919"}
0005434214132	E27322	0630 371667	EKATERINA RODIONOVA	{"phone": "+70096522415"}
0005434214133	E27322	8490 667328	SVETLANA SEMENOVA	{"phone": "+70683148649"}
0005434214134	5EDC09	3663 084641	ELENA MEDVEDEVA	{"phone": "+70582171184"}
0005434214135	5EDC09	6249 718413	SERGEY GAVRILOV	{"email": "sergey_gavrilov_07081974@postgrespro.ru", "phone": "+70528932367"}
0005434214136	5EDC09	0929 465135	EVGENIY VASILEV	{"phone": "+70448243606"}
0005434214137	CDE251	2833 175224	VLADIMIR ZHURAVLEV	{"email": "vladimir-zhuravlev1963@postgrespro.ru", "phone": "+70303255243"}
0005434214138	59EECC	0527 533956	OLGA VASILEVA	{"email": "vasileva_olga.081973@postgrespro.ru", "phone": "+70715115253"}
0005434214139	6B2D9A	4438 726551	IVAN POPOV	{"phone": "+70035859397"}
0005434214140	D23178	0700 894906	ALEKSANDR KAZAKOV	{"email": "akazakov16061976@postgrespro.ru", "phone": "+70388735341"}
0005434214141	D23178	1540 833940	ELIZAVETA NAZAROVA	{"email": "e_nazarova1972@postgrespro.ru", "phone": "+70972765876"}
0005434214142	3F2306	9795 155864	YURIY RODIONOV	{"email": "rodionov-y_15121972@postgrespro.ru", "phone": "+70088751731"}
0005434214143	FA1DDC	9840 067573	TATYANA BORISOVA	{"phone": "+70919500875"}
0005434214144	7EA5A1	7445 972876	ALEKSANDR FROLOV	{"phone": "+70249113821"}
0005434214145	7EA5A1	9744 766261	OLGA LEBEDEVA	{"phone": "+70047359783"}
0005434214146	66B512	2312 690085	ALEKSEY GUSEV	{"email": "alekseygusev-101968@postgrespro.ru", "phone": "+70706188888"}
0005434214147	AD48F6	8746 151426	NIKOLAY MOISEEV	{"phone": "+70939576668"}
0005434214148	844A64	7779 771879	DIANA OVCHINNIKOVA	{"email": "d-ovchinnikova-101987@postgrespro.ru", "phone": "+70153626027"}
0005434214149	844A64	1693 961296	ROMAN SOKOLOV	{"phone": "+70910572168"}
0005434214150	501E38	9868 591899	ALEKSANDRA PETROVA	{"phone": "+70517190583"}
0005434214151	477478	6869 375917	ALEKSANDR VASILEV	{"phone": "+70105524942"}
0005434214152	B262F6	2020 820149	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov-03071960@postgrespro.ru", "phone": "+70688128872"}
0005434214153	27DC57	8106 557653	VALENTINA BORISOVA	{"phone": "+70005789997"}
0005434214154	E3EC7F	4513 117746	TAMARA GUSEVA	{"email": "t_guseva-1959@postgrespro.ru", "phone": "+70553011610"}
0005434214155	13B48A	4401 124798	KLAVDIYA KONOVALOVA	{"phone": "+70065009483"}
0005434214156	B24E2C	0714 253841	ALEKSANDR KUZMIN	{"email": "akuzmin.15021956@postgrespro.ru", "phone": "+70081458661"}
0005434214157	7705F2	3124 709584	BORIS ZHURAVLEV	{"email": "boriszhuravlev-1976@postgrespro.ru", "phone": "+70354520860"}
0005434214158	7705F2	3818 786317	POLINA ZHURAVLEVA	{"phone": "+70712328513"}
0005434214159	E1F023	6579 707009	LYUDMILA GRISHINA	{"phone": "+70579614397"}
0005434214160	E1F023	8355 699934	SVETLANA BORISOVA	{"phone": "+70807746579"}
0005434214161	C0B890	5432 475126	EKATERINA FROLOVA	{"email": "e.frolova-041970@postgrespro.ru", "phone": "+70229648273"}
0005434214162	C0B890	1052 645108	VLADIMIR ANTONOV	{"email": "v_antonov.1973@postgrespro.ru", "phone": "+70938023522"}
0005434214163	E3E3C6	6675 214597	YURIY MOROZOV	{"phone": "+70677026981"}
0005434214164	DBB1F6	6450 665307	VSEVOLOD MAKAROV	{"email": "vsevolod_makarov.081978@postgrespro.ru", "phone": "+70259408019"}
0005434214165	DBB1F6	8635 557035	DMITRIY TARASOV	{"phone": "+70855385426"}
0005434214166	D9A880	5760 676767	VALENTINA TIMOFEEVA	{"email": "timofeeva_valentina-031986@postgrespro.ru", "phone": "+70725554115"}
0005434214167	C17404	9509 644660	ELENA SOROKINA	{"email": "sorokina.elena-1973@postgrespro.ru", "phone": "+70019250911"}
0005434214168	1D81F1	0696 011845	SVETLANA YAKOVLEVA	{"phone": "+70434232958"}
0005434214169	1D81F1	0959 987478	ZINAIDA SIDOROVA	{"phone": "+70625636221"}
0005434214170	6F80F0	1460 992812	GALINA MIKHAYLOVA	{"phone": "+70939807680"}
0005434214171	6F80F0	3822 538738	YURIY IVANOV	{"phone": "+70469184041"}
0005434214172	1D9731	9163 041485	ANNA KOROLEVA	{"email": "koroleva-a1965@postgrespro.ru", "phone": "+70941339864"}
0005434214173	1D9731	9986 491763	ELENA MOROZOVA	{"email": "morozova-elena-071972@postgrespro.ru", "phone": "+70531191284"}
0005434214174	4C4107	4671 955098	SERGEY FILIPPOV	{"phone": "+70037869459"}
0005434214175	F7CA16	9085 283460	ALEKSEY ISAEV	{"email": "isaev-a.011964@postgrespro.ru", "phone": "+70934835050"}
0005434214176	E38BE3	7616 458514	GALINA KUZNECOVA	{"email": "g.kuznecova081971@postgrespro.ru", "phone": "+70770921066"}
0005434214177	56EA0E	3229 747091	ALEKSANDR SOLOVEV	{"phone": "+70348830304"}
0005434214178	BB12CD	0299 708288	NINA VOROBEVA	{"email": "vorobeva_nina-21101971@postgrespro.ru", "phone": "+70767286257"}
0005434214179	59E447	4332 140192	ELENA AFANASEVA	{"email": "afanaseva.e.081984@postgrespro.ru", "phone": "+70277175010"}
0005434214180	324DBC	1232 918828	VASILIY DMITRIEV	{"phone": "+70880391783"}
0005434214181	FC155D	8724 908823	MARIYA AKIMOVA	{"email": "akimova.mariya1964@postgrespro.ru", "phone": "+70780411644"}
0005434214182	255D01	3071 232674	TIMOFEY SOLOVEV	{"phone": "+70835473028"}
0005434214183	FFD7A0	5646 492330	ALLA IVANOVA	{"phone": "+70393111926"}
0005434214184	965B7A	1925 514374	LYUDMILA MELNIKOVA	{"phone": "+70182242092"}
0005434214185	965B7A	9212 862904	ILYA DAVYDOV	{"phone": "+70550327682"}
0005434214186	965B7A	6141 166584	ALEKSEY KRASNOV	{"email": "krasnov-a_24111976@postgrespro.ru", "phone": "+70601083709"}
0005434214187	841FED	7395 656223	ALEKSEY ANTONOV	{"phone": "+70130158990"}
0005434214188	841FED	1047 587113	FAINA OVCHINNIKOVA	{"phone": "+70281302876"}
0005434214189	F5D997	6185 999936	SERGEY POPOV	{"phone": "+70677793002"}
0005434214190	560130	3461 253432	ELENA ROMANOVA	{"email": "romanova.e.25061981@postgrespro.ru", "phone": "+70046682517"}
0005434214191	42B6B4	7056 766958	LIDIYA TARASOVA	{"phone": "+70865268085"}
0005434214192	814860	9909 453622	LARISA MAKSIMOVA	{"email": "maksimova_larisa.061979@postgrespro.ru", "phone": "+70427494552"}
0005434214193	6B95F8	1355 388451	TATYANA DANILOVA	{"phone": "+70251537021"}
0005434214194	6B95F8	4617 454779	OLEG FEDOTOV	{"email": "fedotovo_101976@postgrespro.ru", "phone": "+70339599708"}
0005434214195	10D452	0804 193718	EVGENIYA EGOROVA	{"email": "egorova_e_1987@postgrespro.ru", "phone": "+70044026439"}
0005434214196	1FF995	1108 326407	YURIY KISELEV	{"email": "yuriy.kiselev.091976@postgrespro.ru", "phone": "+70446766068"}
0005434214197	DEEBED	5356 297561	ELENA FOMINA	{"email": "fominae1970@postgrespro.ru", "phone": "+70759830334"}
0005434214198	DEEBED	6133 778630	KRISTINA VLASOVA	{"phone": "+70152486038"}
0005434214199	DEEBED	5268 352927	VLADIMIR AFANASEV	{"phone": "+70998424976"}
0005434214200	DEEBED	8855 357617	ANATOLIY OSIPOV	{"phone": "+70186009969"}
0005434214201	2E451F	6707 195302	LYUBOV GORBUNOVA	{"phone": "+70585274327"}
0005434214202	011352	0807 076075	VALENTINA SOLOVEVA	{"email": "v_soloveva.22071976@postgrespro.ru", "phone": "+70547411151"}
0005434214203	011352	2800 281767	YULIYA BORISOVA	{"phone": "+70757980347"}
0005434214204	867135	4614 875813	TATYANA PETROVA	{"email": "petrova.tatyana_1960@postgrespro.ru", "phone": "+70131837412"}
0005434214205	4BE926	1844 680367	VALERIY KOZLOV	{"phone": "+70294694639"}
0005434214206	4BE926	5833 216469	RUSLAN FROLOV	{"email": "ruslan.frolov-021976@postgrespro.ru", "phone": "+70305020026"}
0005434214207	C98459	1437 310475	NIKOLAY SEMENOV	{"email": "nikolay-semenov041981@postgrespro.ru", "phone": "+70524507802"}
0005434214208	C98459	7161 761048	ANDREY KISELEV	{"email": "a_kiselev20111966@postgrespro.ru", "phone": "+70178805022"}
0005434214209	C98459	4570 591005	ALEKSEY KUDRYASHOV	{"phone": "+70442170612"}
0005434214210	A561F8	7648 939790	GALINA STEPANOVA	{"phone": "+70394864795"}
0005434214211	879F24	8053 261224	ANASTASIYA NIKOLAEVA	{"phone": "+70919663200"}
0005434214212	B9503C	9262 890199	SVETLANA FROLOVA	{"phone": "+70682379359"}
0005434214213	D137C4	2969 717575	ALBERT KULIKOV	{"phone": "+70601021966"}
0005434214214	076EC7	2149 616854	ELENA KUZNECOVA	{"email": "elena-kuznecova.25041962@postgrespro.ru", "phone": "+70967058999"}
0005434214215	59064E	7258 158912	ANASTASIYA ROMANOVA	{"email": "romanova-a021975@postgrespro.ru", "phone": "+70840682373"}
0005434214216	E510C4	5653 656776	TATYANA PAVLOVA	{"phone": "+70449539601"}
0005434214217	E510C4	4794 968312	IRINA SAVELEVA	{"email": "savelevai1968@postgrespro.ru", "phone": "+70688218373"}
0005434214218	CFC8BC	5518 360259	LYUBOV SOROKINA	{"email": "sorokina-l1960@postgrespro.ru", "phone": "+70873342243"}
0005434214219	CFC8BC	2374 423667	VADIM ANTONOV	{"email": "antonov-v_121981@postgrespro.ru", "phone": "+70948068025"}
0005434214220	12D363	4180 345230	TATYANA FADEEVA	{"email": "fadeeva_tatyana-1966@postgrespro.ru", "phone": "+70798487978"}
0005434214221	07AED9	7872 127749	ALEVTINA IVANOVA	{"email": "ivanova-alevtina_1959@postgrespro.ru", "phone": "+70890124444"}
0005434214222	21DE1C	5249 593924	SVETLANA NIKITINA	{"phone": "+70175002348"}
0005434214223	21DE1C	1951 810005	VLADIMIR TIKHONOV	{"email": "v_tikhonov021968@postgrespro.ru", "phone": "+70332153006"}
0005434214224	01E2C6	4710 572412	ELENA IVANOVA	{"phone": "+70040511972"}
0005434214225	9204C8	2669 512570	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_04011967@postgrespro.ru", "phone": "+70312538877"}
0005434214226	C61F08	5999 219295	GULFIYA FOMINA	{"phone": "+70847986750"}
0005434214227	0F4E3E	1455 346536	ARSENIY VASILEV	{"email": "arseniy.vasilev_071967@postgrespro.ru", "phone": "+70373582680"}
0005434214228	71CF47	4393 691719	MAKSIM MAKAROV	{"phone": "+70519510119"}
0005434214229	6AE213	9876 864930	MIKHAIL KUZNECOV	{"phone": "+70021642440"}
0005434214230	0D525C	6718 721558	DMITRIY GERASIMOV	{"email": "gerasimov.d.1979@postgrespro.ru", "phone": "+70541534286"}
0005434214231	02A99B	1370 092268	ARTEMIY SEMENOV	{"phone": "+70337890962"}
0005434214232	02A99B	9934 808084	ALBINA IVANOVA	{"email": "ivanova.a.1968@postgrespro.ru", "phone": "+70924164898"}
0005434214233	02A99B	9818 146616	OLGA MAKAROVA	{"phone": "+70919923278"}
0005434214234	02A99B	2775 627148	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova-l13051974@postgrespro.ru", "phone": "+70276015454"}
0005434214235	FF96C5	7655 571437	ELENA PETROVA	{"email": "epetrova_061972@postgrespro.ru", "phone": "+70680170385"}
0005434214236	97EDF5	9881 937030	SERGEY MIRONOV	{"email": "sergey-mironov23081964@postgrespro.ru", "phone": "+70140898658"}
0005434214515	2A59FB	8133 564645	VALENTIN MOISEEV	{"phone": "+70320494106"}
0005434214237	97EDF5	4316 294435	IRINA PAVLOVA	{"email": "pavlova-irina.16021971@postgrespro.ru", "phone": "+70354431925"}
0005434214238	D52905	6343 516794	NADEZHDA BORISOVA	{"phone": "+70274340299"}
0005434214239	D52905	9123 215482	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_v.25121967@postgrespro.ru", "phone": "+70351022759"}
0005434214240	31CA17	1584 830776	KLAVDIYA SOKOLOVA	{"phone": "+70642147070"}
0005434214241	31CA17	0912 395558	EKATERINA NOVIKOVA	{"email": "novikovaekaterina.121975@postgrespro.ru", "phone": "+70217962077"}
0005434214242	26C6EC	7413 515699	SERGEY MEDVEDEV	{"phone": "+70240078735"}
0005434214243	5ECAEC	0978 107613	EKATERINA IVANOVA	{"phone": "+70013594734"}
0005434214244	CB2BC0	4726 861230	SERGEY VOLKOV	{"email": "sergeyvolkov.18031958@postgrespro.ru", "phone": "+70201389965"}
0005434214245	5AAB97	9736 355163	SERGEY PAVLOV	{"phone": "+70002086363"}
0005434214246	23DA93	5971 523908	ELENA KOZLOVA	{"email": "elena-kozlova_071977@postgrespro.ru", "phone": "+70805670560"}
0005434214247	FAB74C	0699 599441	NINA MOISEEVA	{"email": "n_moiseeva.01091965@postgrespro.ru", "phone": "+70783337425"}
0005434214248	C02975	5512 981023	EVGENIY IVANOV	{"email": "ivanove-22041977@postgrespro.ru", "phone": "+70383376809"}
0005434214249	861F52	3658 191960	VLADIMIR TIMOFEEV	{"phone": "+70125674050"}
0005434214250	95B4A7	5243 877183	ANATOLIY BELOV	{"phone": "+70274535333"}
0005434214251	173E9F	9592 046544	ELVIRA SOLOVEVA	{"phone": "+70183804806"}
0005434214252	FBE97D	6891 292782	ALEKSEY BONDARENKO	{"email": "abondarenko021973@postgrespro.ru", "phone": "+70928273363"}
0005434214253	FBE97D	0439 253699	SERGEY IVANOV	{"phone": "+70011582166"}
0005434214254	75290E	7081 855146	VALENTINA TROFIMOVA	{"email": "v-trofimova22111987@postgrespro.ru", "phone": "+70736511126"}
0005434214255	710730	4714 620181	DENIS IVANOV	{"email": "ivanovdenis-1976@postgrespro.ru", "phone": "+70860968853"}
0005434214256	1E1B1D	3313 809380	OLGA NIKITINA	{"phone": "+70105596472"}
0005434214257	6B2E0C	9441 355812	VLADIMIR POPOV	{"email": "vladimir.popov-10111969@postgrespro.ru", "phone": "+70356461434"}
0005434214258	76C533	5626 831491	VERA FILIPPOVA	{"phone": "+70279707737"}
0005434214259	FA18E0	5649 637940	SVETLANA MOISEEVA	{"email": "moiseeva_svetlana071972@postgrespro.ru", "phone": "+70996164077"}
0005434214260	F93294	8321 920247	NATALYA DMITRIEVA	{"phone": "+70471454771"}
0005434214261	F93294	2698 920421	OLGA KONDRATEVA	{"email": "kondrateva_olga.041976@postgrespro.ru", "phone": "+70702281240"}
0005434214262	C2781A	0989 087417	GALINA ZOTOVA	{"phone": "+70625343639"}
0005434214263	590A49	6744 301622	ANASTASIYA DAVYDOVA	{"phone": "+70896939518"}
0005434214264	FDB212	8431 284511	ALEKSANDR KUZNECOV	{"phone": "+70724431827"}
0005434214265	610929	5632 650369	EKATERINA ERMAKOVA	{"phone": "+70551073464"}
0005434214266	FA359A	3129 913660	OLEG FEDOROV	{"email": "o_fedorov-061972@postgrespro.ru", "phone": "+70232300760"}
0005434214267	FA359A	0553 950447	LIDIYA MIKHAYLOVA	{"email": "lidiya_mikhaylova-1971@postgrespro.ru", "phone": "+70507096903"}
0005434214268	E362F3	4037 620955	ALEKSANDR SOKOLOV	{"email": "sokolov_aleksandr101968@postgrespro.ru", "phone": "+70083028207"}
0005434214269	DBD918	9601 576222	IRINA VASILEVA	{"email": "vasileva.irina071964@postgrespro.ru", "phone": "+70078542907"}
0005434214270	DBD918	7008 557834	YULIYA EFIMOVA	{"phone": "+70397921144"}
0005434214271	F29DC2	3571 144204	EKATERINA BELOVA	{"phone": "+70024531207"}
0005434214272	F29DC2	5232 770823	ILYA EGOROV	{"email": "i.egorov.25121975@postgrespro.ru", "phone": "+70128006537"}
0005434214273	B91374	0264 059707	ALEKSEY BORISOV	{"phone": "+70655674234"}
0005434214274	B91374	4427 606309	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev.1967@postgrespro.ru", "phone": "+70631531648"}
0005434214275	199808	2751 886452	ANGELINA BORISOVA	{"email": "borisova-a.10041979@postgrespro.ru", "phone": "+70867340093"}
0005434214276	7D803B	8363 016021	EVGENIY ZHUKOV	{"phone": "+70867782409"}
0005434214277	7D803B	1011 215917	VIKTOR ORLOV	{"phone": "+70017335989"}
0005434214278	AE0376	4118 211864	DANILA IVANOV	{"phone": "+70334269808"}
0005434214279	3A81DD	6287 734275	VYACHESLAV VASILEV	{"phone": "+70891733131"}
0005434214280	F582C5	3111 482330	SOFYA ZAYCEVA	{"phone": "+70381074406"}
0005434214281	F582C5	8021 773546	IRINA KONOVALOVA	{"email": "konovalovai-021971@postgrespro.ru", "phone": "+70360041209"}
0005434214282	9F141D	5876 506301	GULIYA YAKOVLEVA	{"email": "yakovleva-guliya_051968@postgrespro.ru", "phone": "+70221726757"}
0005434214283	9F141D	2678 838413	STANISLAV ABRAMOV	{"email": "stanislavabramov_01061961@postgrespro.ru", "phone": "+70034545620"}
0005434214284	F9F9A3	5634 702222	NIKOLAY DMITRIEV	{"email": "nikolaydmitriev.06061969@postgrespro.ru", "phone": "+70118968582"}
0005434214285	767608	1276 448709	NINA LAZAREVA	{"email": "n_lazareva_05021967@postgrespro.ru", "phone": "+70669568674"}
0005434214286	767608	3292 569286	EVDOKIYA KUDRYASHOVA	{"phone": "+70223567236"}
0005434214287	513DDB	3052 145681	ALEKSEY STEPANOV	{"email": "stepanov.aleksey-101979@postgrespro.ru", "phone": "+70188926461"}
0005434214288	7B5EF8	9763 314645	OLEG STEPANOV	{"email": "oleg_stepanov_1975@postgrespro.ru", "phone": "+70746968289"}
0005434214289	7B5EF8	0969 987785	NIKOLAY TIKHONOV	{"email": "tikhonov_n-1972@postgrespro.ru", "phone": "+70876622040"}
0005434214290	7B5EF8	8641 797541	NATALYA KOLESNIKOVA	{"email": "n-kolesnikova.09081978@postgrespro.ru", "phone": "+70825575418"}
0005434214291	A9782B	6843 868512	TATYANA KONDRATEVA	{"email": "kondrateva_tatyana-1977@postgrespro.ru", "phone": "+70778441668"}
0005434214292	300A4C	7303 673381	ANTONINA MOROZOVA	{"email": "amorozova26071970@postgrespro.ru", "phone": "+70978004834"}
0005434214293	C411F1	0007 840925	VIKTOR FOMIN	{"email": "fomin.v_10091962@postgrespro.ru", "phone": "+70558284837"}
0005434214294	97B052	2150 179363	IGOR KRASNOV	{"email": "krasnov-igor.081980@postgrespro.ru", "phone": "+70364318228"}
0005434214295	97B052	1837 327618	GAGIK FROLOV	{"email": "frolov-gagik_1975@postgrespro.ru", "phone": "+70419064727"}
0005434214296	70393A	0807 959839	EDUARD IVANOV	{"email": "eduardivanov-28121969@postgrespro.ru", "phone": "+70940537992"}
0005434214297	70393A	4053 298444	VIKTORIYA ANTONOVA	{"phone": "+70116187746"}
0005434214298	A40F8E	1964 358549	SERGEY ZHURAVLEV	{"phone": "+70375766325"}
0005434214299	A5F14B	6184 825454	MARIYA FOMINA	{"phone": "+70974588673"}
0005434214300	72AE2F	7194 574326	GALINA GORBUNOVA	{"email": "gorbunovagalina021970@postgrespro.ru", "phone": "+70620186529"}
0005434214301	2EBDBE	6298 376457	TATYANA MARTYNOVA	{"email": "tatyana_martynova-1965@postgrespro.ru", "phone": "+70892294761"}
0005434214302	2EBDBE	3120 508440	ELENA MOROZOVA	{"phone": "+70336231650"}
0005434214303	8E3597	9283 959765	LEONID KUZNECOV	{"email": "l_kuznecov.04121968@postgrespro.ru", "phone": "+70764596082"}
0005434214304	8E3597	5013 167706	DARYA GUSEVA	{"email": "guseva.d_1976@postgrespro.ru", "phone": "+70857391095"}
0005434214305	8E3597	3963 055172	IRINA KUZNECOVA	{"phone": "+70124510944"}
0005434214306	C2FDFF	4991 708808	EKATERINA MOISEEVA	{"email": "ekaterina_moiseeva.08021985@postgrespro.ru", "phone": "+70565589031"}
0005434214307	15AC72	8896 966262	OKSANA MOISEEVA	{"phone": "+70024191777"}
0005434214308	67B313	5905 022252	VLADIMIR ZHUKOV	{"email": "zhukov-v_1968@postgrespro.ru", "phone": "+70817520972"}
0005434214309	587736	1798 618032	VYACHESLAV VOLKOV	{"email": "volkov_vyacheslav_1980@postgrespro.ru", "phone": "+70435400694"}
0005434214310	587736	1217 678848	MAKSIM MIRONOV	{"email": "maksimmironov.21021963@postgrespro.ru", "phone": "+70081621146"}
0005434214311	E48079	8864 208844	ELENA SAVELEVA	{"email": "elena_saveleva-10081980@postgrespro.ru", "phone": "+70023580125"}
0005434214312	D51C42	9810 310276	SERGEY KRASNOV	{"phone": "+70129833164"}
0005434214313	65890A	0563 256285	DMITRIY VLASOV	{"phone": "+70909149286"}
0005434214314	D5450B	6799 623052	YULIYA NIKOLAEVA	{"phone": "+70740140243"}
0005434214315	9E1E8B	9597 748619	ALEKSANDRA IVANOVA	{"email": "aleksandra.ivanova13091981@postgrespro.ru", "phone": "+70763855319"}
0005434214316	9E1E8B	5591 172140	ELENA KAZAKOVA	{"email": "elena_kazakova01051981@postgrespro.ru", "phone": "+70013165374"}
0005434214317	752F76	9910 595516	MIKHAIL NIKITIN	{"email": "mikhail.nikitin_061973@postgrespro.ru", "phone": "+70632054230"}
0005434214318	752F76	4632 358513	VALENTINA NAUMOVA	{"email": "valentinanaumova.13081974@postgrespro.ru", "phone": "+70797671566"}
0005434214319	F39D86	2958 460902	VALENTINA BORISOVA	{"email": "borisova_valentina.01091967@postgrespro.ru", "phone": "+70507210048"}
0005434214320	475BA5	0325 099634	RAISA NIKITINA	{"email": "nikitina-r_06021976@postgrespro.ru", "phone": "+70166609881"}
0005434214321	34BEA0	1152 426279	ELENA GUSEVA	{"email": "elena.guseva-15071979@postgrespro.ru", "phone": "+70133942005"}
0005434214322	A92D77	2393 767662	OLGA ZAYCEVA	{"email": "zayceva-olga_1972@postgrespro.ru", "phone": "+70730268856"}
0005434214323	6DC59E	4392 515351	KLAVDIYA KOMAROVA	{"phone": "+70662421154"}
0005434214324	2E1601	6832 053643	LIDIYA NIKOLAEVA	{"phone": "+70473817267"}
0005434214325	2F0655	1562 481789	SERGEY MIRONOV	{"phone": "+70419235570"}
0005434214326	5802EE	5835 710628	NATALYA FOMINA	{"email": "fominanatalya_1977@postgrespro.ru", "phone": "+70274612737"}
0005434214327	5802EE	3668 628780	NIKOLAY ZAYCEV	{"email": "zaycevn.1981@postgrespro.ru", "phone": "+70265484638"}
0005434214328	71661F	9316 751643	MARIYA ZAYCEVA	{"email": "mariya-zayceva1977@postgrespro.ru", "phone": "+70905589501"}
0005434214329	71473A	1602 638240	LYUBOV BELOVA	{"phone": "+70677326718"}
0005434214330	71473A	9686 322304	DMITRIY TARASOV	{"phone": "+70738105816"}
0005434214331	0ED9BB	9228 850200	ANASTASIYA FEDOROVA	{"email": "fedorova_a-101967@postgrespro.ru", "phone": "+70384222274"}
0005434214332	D4E70C	0912 114570	YULIYA EGOROVA	{"email": "egorova.yuliya.121984@postgrespro.ru", "phone": "+70370689139"}
0005434214333	D4E70C	8027 982113	IRINA KONOVALOVA	{"email": "konovalovai-1973@postgrespro.ru", "phone": "+70050665315"}
0005434214334	5CFD3F	1670 185785	EKATERINA ROMANOVA	{"email": "romanovae_14041982@postgrespro.ru", "phone": "+70331722994"}
0005434214335	37C849	8312 004611	DMITRIY SEMENOV	{"email": "semenov_d06051953@postgrespro.ru", "phone": "+70835410694"}
0005434214336	48189C	6377 123194	PELAGEYA DMITRIEVA	{"email": "dmitrieva-pelageya_21081975@postgrespro.ru", "phone": "+70953775361"}
0005434214337	881509	9044 893574	LYUDMILA KOROLEVA	{"phone": "+70064023040"}
0005434214338	939C05	9417 238137	MARINA IVANOVA	{"phone": "+70971544698"}
0005434214339	3EDC19	0540 066239	ILDAR KULIKOV	{"email": "kulikov-i_1975@postgrespro.ru", "phone": "+70143488226"}
0005434214340	2D08B2	0347 464778	EVGENIY FROLOV	{"email": "e-frolov17111965@postgrespro.ru", "phone": "+70168775491"}
0005434214341	2D08B2	3431 272911	EVGENIYA ISAEVA	{"email": "evgeniya.isaeva.1973@postgrespro.ru", "phone": "+70742401168"}
0005434214342	2C86AD	8604 792970	NIKOLAY DMITRIEV	{"phone": "+70586804350"}
0005434214343	2C86AD	8453 365475	ALEKSANDR MOROZOV	{"phone": "+70978398700"}
0005434214344	7D9BA0	0714 097923	ELENA SOROKINA	{"email": "sorokina-e_11061965@postgrespro.ru", "phone": "+70921719844"}
0005434214345	7D9BA0	8296 052463	RAISA PAVLOVA	{"email": "pavlova.r-1978@postgrespro.ru", "phone": "+70348209969"}
0005434214516	E0F3ED	6305 471896	TAMARA NOVIKOVA	{"phone": "+70957926682"}
0005434214346	5F8EDC	0177 149188	IRINA ZAKHAROVA	{"email": "zakharova.irina011976@postgrespro.ru", "phone": "+70075707391"}
0005434214347	1480E8	5847 405595	ARTUR SEMENOV	{"phone": "+70574119437"}
0005434214348	32EED2	7321 867972	ANNA VOLKOVA	{"email": "volkova.a_1962@postgrespro.ru", "phone": "+70388014373"}
0005434214349	565202	4176 422890	ANTON VASILEV	{"email": "a.vasilev-031972@postgrespro.ru", "phone": "+70700437001"}
0005434214350	F755A4	6016 928946	DENIS ANDREEV	{"email": "d_andreev1986@postgrespro.ru", "phone": "+70489823151"}
0005434214351	F755A4	3201 959797	SERGEY POPOV	{"phone": "+70842310749"}
0005434214352	019AFE	8246 000699	VALENTINA OSIPOVA	{"phone": "+70322029451"}
0005434214353	019AFE	3582 151402	NATALIYA TIKHONOVA	{"email": "tikhonova_nataliya.04031965@postgrespro.ru", "phone": "+70997074004"}
0005434214354	E66C95	8012 563328	ANDREY ALEKSANDROV	{"phone": "+70087480801"}
0005434214355	8EB245	8883 813767	EVGENIY PETROV	{"phone": "+70109613140"}
0005434214356	DF8C16	1437 759089	ALENA BORISOVA	{"phone": "+70110780312"}
0005434214357	CD34C4	0178 622631	ALEKSANDR BELOV	{"email": "aleksandr.belov.1980@postgrespro.ru", "phone": "+70557818825"}
0005434214358	826C05	4358 840760	NURIYA ISAEVA	{"email": "nuriya_isaeva_1969@postgrespro.ru", "phone": "+70520642827"}
0005434214359	4C65C7	9497 550293	MARINA KOLESNIKOVA	{"email": "m-kolesnikova-1972@postgrespro.ru", "phone": "+70538863042"}
0005434214360	88CE6F	2043 475242	NIKOLAY SHEVCHENKO	{"email": "nshevchenko_19071969@postgrespro.ru", "phone": "+70031799892"}
0005434214361	198EF1	4648 205715	VALENTINA ZAYCEVA	{"phone": "+70252982651"}
0005434214362	198EF1	3809 394856	PAVEL MATVEEV	{"phone": "+70914577551"}
0005434214363	3AC153	9996 907271	ANNA PETROVA	{"phone": "+70147617721"}
0005434214364	3EE195	8588 955297	MIKHAIL SCHERBAKOV	{"email": "scherbakovm-14101978@postgrespro.ru", "phone": "+70774028875"}
0005434214365	3EE195	2366 089231	NATALYA KUZMINA	{"phone": "+70172464749"}
0005434214366	46AECF	9230 208549	EKATERINA LUKYANOVA	{"email": "ekaterinalukyanova.041970@postgrespro.ru", "phone": "+70805547786"}
0005434214367	C0EA9F	4220 067372	ROZALIYA FEDOROVA	{"phone": "+70341763510"}
0005434214368	C0EA9F	6413 876453	ZHANNA GERASIMOVA	{"email": "gerasimovaz011975@postgrespro.ru", "phone": "+70533515737"}
0005434214369	C0EA9F	3587 745681	VIKTORIYA LOGINOVA	{"phone": "+70314441225"}
0005434214370	678058	4648 427301	IVAN KOROLEV	{"email": "ivankorolev-051968@postgrespro.ru", "phone": "+70980783121"}
0005434214371	678058	4895 831669	VLADIMIR POPOV	{"phone": "+70405662597"}
0005434214372	181FD9	9866 300595	ELENA MAKAROVA	{"phone": "+70678803397"}
0005434214373	0C24FA	6713 989464	GALINA KUZMINA	{"phone": "+70503795975"}
0005434214374	0C24FA	6399 374635	RASHID KARPOV	{"email": "rkarpov-051961@postgrespro.ru", "phone": "+70884336682"}
0005434214375	D013F7	8848 340067	PAVEL NIKITIN	{"email": "nikitinpavel.121967@postgrespro.ru", "phone": "+70974401742"}
0005434214376	2C501F	2341 874260	RAISA SEMENOVA	{"phone": "+70230878828"}
0005434214377	2C501F	2153 853840	ELENA POPOVA	{"email": "e.popova.08021972@postgrespro.ru", "phone": "+70172185105"}
0005434214378	C1A8D3	3408 002185	NADEZHDA MELNIKOVA	{"phone": "+70846561882"}
0005434214379	FBD79F	9527 005761	ANATOLIY KOZLOV	{"email": "kozlov-a.081972@postgrespro.ru", "phone": "+70783133140"}
0005434214380	BB010D	6478 564430	MARINA SEMENOVA	{"phone": "+70909072760"}
0005434214381	152DAA	7796 639702	ELENA KISELEVA	{"phone": "+70769974190"}
0005434214382	632A29	9497 581123	VIKTOR DENISOV	{"email": "denisovv_17081975@postgrespro.ru", "phone": "+70233194078"}
0005434214383	632A29	7867 512310	NIKITA MIRONOV	{"phone": "+70128534879"}
0005434214384	613786	3437 840686	ALEKSANDR POPOV	{"email": "aleksandr.popov-011968@postgrespro.ru", "phone": "+70134967081"}
0005434214385	613786	7885 197425	DARYA ZAYCEVA	{"email": "darya.zayceva.03031963@postgrespro.ru", "phone": "+70831267696"}
0005434214386	613786	0927 584013	TATYANA SCHERBAKOVA	{"email": "scherbakovatatyana-1974@postgrespro.ru", "phone": "+70572997366"}
0005434214387	8A88B8	2384 997920	YURIY MIKHAYLOV	{"phone": "+70017419388"}
0005434214388	5ED598	7913 798739	VLADIMIR KISELEV	{"email": "vladimir_kiselev.1966@postgrespro.ru", "phone": "+70499922579"}
0005434214389	91B3F0	5126 423096	ILYA MOROZOV	{"phone": "+70605634492"}
0005434214390	8358FF	7083 790687	VERA IVANOVA	{"email": "vivanova.1965@postgrespro.ru", "phone": "+70578446273"}
0005434214391	8358FF	3234 431887	SVETLANA FILATOVA	{"email": "s_filatova-1974@postgrespro.ru", "phone": "+70723193379"}
0005434214392	41DF39	5853 230048	YULIYA KOZLOVA	{"phone": "+70880778014"}
0005434214393	41DF39	0845 730578	VADIM TARASOV	{"phone": "+70603703370"}
0005434214394	41DF39	8834 527605	OLEG KUZNECOV	{"email": "kuznecov-o-31071967@postgrespro.ru", "phone": "+70476792099"}
0005434214395	CC0A24	1543 718589	EVDOKIYA VOLKOVA	{"phone": "+70152335152"}
0005434214396	CC0A24	1082 355712	DMITRIY SCHERBAKOV	{"email": "scherbakov.dmitriy_1970@postgrespro.ru", "phone": "+70820325824"}
0005434214397	742EE2	9735 709692	ALEKSANDR ANDREEV	{"phone": "+70551148492"}
0005434214398	742EE2	9150 319734	ELVIRA MAKAROVA	{"phone": "+70218865810"}
0005434214399	FC4FB1	8576 715475	LIDIYA GERASIMOVA	{"email": "lidiya-gerasimova-1964@postgrespro.ru", "phone": "+70428264952"}
0005434214400	7C7F8A	7994 254022	VIKTORIYA MOROZOVA	{"phone": "+70373656473"}
0005434214401	7EC1E7	7660 567144	ALEKSANDR NAZAROV	{"phone": "+70260003689"}
0005434214402	7EC1E7	3568 705218	GALINA TARASOVA	{"phone": "+70443058276"}
0005434214404	89F44E	3001 890131	VADIM MAKSIMOV	{"email": "v-maksimov-1969@postgrespro.ru", "phone": "+70123940471"}
0005434214405	70EB2E	8945 394303	KRISTINA KOMAROVA	{"phone": "+70102870417"}
0005434214406	70EB2E	4085 529461	NIKOLAY GUSEV	{"email": "n_gusev071970@postgrespro.ru", "phone": "+70223346660"}
0005434214407	761C87	2866 779795	ELENA NIKIFOROVA	{"email": "elena-nikiforova10101969@postgrespro.ru", "phone": "+70753272416"}
0005434214408	0E2BAC	3337 017150	NATALYA IVANOVA	{"email": "ivanova_natalya031973@postgrespro.ru", "phone": "+70600154209"}
0005434214409	C9B4D8	2266 059837	VALERIY POPOV	{"phone": "+70771229569"}
0005434214410	A7852E	8931 396078	MIKHAIL NOVIKOV	{"phone": "+70063761650"}
0005434214411	BB532C	5220 258924	NATALIYA KULIKOVA	{"email": "nataliya-kulikova101972@postgrespro.ru", "phone": "+70039316823"}
0005434214412	BB532C	6813 117165	VLADIMIR SMIRNOV	{"email": "smirnovv.30031975@postgrespro.ru", "phone": "+70936864450"}
0005434214413	6B1F39	0600 887749	VITALIY ZHURAVLEV	{"phone": "+70362561285"}
0005434214414	6B1F39	8059 647866	ANASTASIYA NAZAROVA	{"email": "nazarova_anastasiya_17081965@postgrespro.ru", "phone": "+70863024182"}
0005434214415	E05D61	3815 446981	DMITRIY ANTONOV	{"email": "antonov_d_1976@postgrespro.ru", "phone": "+70487175995"}
0005434214416	E05D61	3253 344281	KSENIYA KONDRATEVA	{"email": "kondratevakseniya1983@postgrespro.ru", "phone": "+70530506878"}
0005434214417	CE8982	2447 651100	EVGENIY ZAYCEV	{"phone": "+70260156861"}
0005434214418	CE8982	3525 988835	YULIYA FROLOVA	{"phone": "+70970963921"}
0005434214419	E25A9D	6983 312671	SVETLANA VASILEVA	{"phone": "+70021226296"}
0005434214420	70F7C6	8548 999932	LYUDMILA ZAKHAROVA	{"phone": "+70758164310"}
0005434214421	70F7C6	6662 712095	ANDREY SERGEEV	{"phone": "+70355687980"}
0005434214422	31A411	9108 654609	ALEKSANDRA KOZLOVA	{"phone": "+70952976678"}
0005434214423	6FACD2	7070 608245	YURIY PETROV	{"email": "y_petrov051968@postgrespro.ru", "phone": "+70752217731"}
0005434214424	1E6039	9623 729992	GALINA VASILEVA	{"email": "g-vasileva_11101975@postgrespro.ru", "phone": "+70645873279"}
0005434214425	B9EC15	9681 217703	PAVEL SOLOVEV	{"phone": "+70804568562"}
0005434214426	C65321	4266 259854	MARIYA ZAKHAROVA	{"phone": "+70292196257"}
0005434214427	957379	5716 661362	MIKHAIL SMIRNOV	{"phone": "+70972080603"}
0005434214428	9646A6	5538 235713	VALERIY FILIPPOV	{"email": "vfilippov_081976@postgrespro.ru", "phone": "+70973334334"}
0005434214429	904629	7418 898042	LYUDMILA GERASIMOVA	{"email": "gerasimova.lyudmila011971@postgrespro.ru", "phone": "+70221999164"}
0005434214430	C13EA6	8049 680650	VASILIY SERGEEV	{"phone": "+70868241459"}
0005434214431	C13EA6	2538 477417	ANASTASIYA ROMANOVA	{"phone": "+70176351282"}
0005434214432	8D65B9	0077 636925	DMITRIY ISAEV	{"email": "isaevd_1972@postgrespro.ru", "phone": "+70224685205"}
0005434214433	25723A	3126 400748	VIKTOR VOROBEV	{"phone": "+70239740539"}
0005434214434	C43C1C	3406 443563	ELENA KUZMINA	{"email": "elena_kuzmina.051973@postgrespro.ru", "phone": "+70276492424"}
0005434214435	C43C1C	7054 110797	ELENA LAZAREVA	{"email": "elena-lazareva1978@postgrespro.ru", "phone": "+70875930119"}
0005434214436	65B93F	6404 733164	SERGEY IVANOV	{"email": "sergeyivanov_1989@postgrespro.ru", "phone": "+70391401057"}
0005434214437	2ACCD3	6409 283813	TATYANA YUDINA	{"email": "yudina.t091975@postgrespro.ru", "phone": "+70578463049"}
0005434214438	08B25A	5215 769279	EKATERINA VOROBEVA	{"phone": "+70128813975"}
0005434214439	08B25A	4426 435119	KRISTINA AFANASEVA	{"phone": "+70057959907"}
0005434214440	08B25A	2606 952696	KIRILL MAKSIMOV	{"email": "maksimov.kirill.23101964@postgrespro.ru", "phone": "+70576044242"}
0005434214441	08DABE	6206 900955	VALENTINA ABRAMOVA	{"phone": "+70748339241"}
0005434214442	E92358	7260 612055	ANATOLIY MEDVEDEV	{"email": "medvedev_anatoliy_1973@postgrespro.ru", "phone": "+70006983428"}
0005434214443	E92358	5596 517293	DENIS PAVLOV	{"phone": "+70685860428"}
0005434214444	2DEECC	8005 411013	ANASTASIYA ALEKSANDROVA	{"email": "a-aleksandrova1970@postgrespro.ru", "phone": "+70538007001"}
0005434214445	061A4F	0586 298878	ALEKSEY PAVLOV	{"email": "a-pavlov-16091962@postgrespro.ru", "phone": "+70486548354"}
0005434214446	D924DC	9468 734683	DMITRIY ALEKSEEV	{"email": "dmitriy-alekseev-1962@postgrespro.ru", "phone": "+70534091137"}
0005434214447	D924DC	7037 472449	NIKITA MOISEEV	{"email": "n_moiseev-29061967@postgrespro.ru", "phone": "+70416838016"}
0005434214448	EFA276	6697 213660	NATALIYA NOVIKOVA	{"email": "novikova_nataliya-25061970@postgrespro.ru", "phone": "+70817949359"}
0005434214449	EFA276	7812 254633	NATALYA KUZNECOVA	{"email": "kuznecova_natalya.101971@postgrespro.ru", "phone": "+70359009277"}
0005434214450	755FE4	2563 000741	VIKTOR IVANOV	{"phone": "+70384009654"}
0005434214451	0B6DB9	9276 266459	ALENA STEPANOVA	{"phone": "+70399349157"}
0005434214452	ED0E74	2446 389815	VLADIMIR NAZAROV	{"email": "v.nazarov_031974@postgrespro.ru", "phone": "+70973931643"}
0005434214453	548940	3908 717348	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir_01031975@postgrespro.ru", "phone": "+70229956130"}
0005434214454	548940	7664 722382	NELLI KARPOVA	{"email": "nellikarpova-1978@postgrespro.ru", "phone": "+70036356390"}
0005434214455	49D45A	3031 317804	EVGENIYA DANILOVA	{"email": "danilovae.1977@postgrespro.ru", "phone": "+70323053251"}
0005434214456	49D45A	2433 513874	PAVEL NIKITIN	{"phone": "+70743243701"}
0005434214457	49D45A	9036 168575	ALEKSEY VOLKOV	{"phone": "+70949771098"}
0005434214458	70EBC2	6706 290738	ALEKSANDR ANDREEV	{"email": "a_andreev021967@postgrespro.ru", "phone": "+70350674055"}
0005434214459	8EF9EB	3241 761852	OLGA FADEEVA	{"email": "ofadeeva_021971@postgrespro.ru", "phone": "+70886758493"}
0005434214460	A9DDF1	1119 758059	VERA LOGINOVA	{"phone": "+70086495020"}
0005434214461	EDF058	9582 392799	VLADIMIR MAKAROV	{"phone": "+70315337795"}
0005434214462	EDF058	7480 800564	LYUBOV NIKIFOROVA	{"phone": "+70434043132"}
0005434214463	89F72E	4133 650803	TATYANA ANDREEVA	{"email": "tatyana_andreeva_04111978@postgrespro.ru", "phone": "+70530672301"}
0005434214464	89F72E	0927 627641	IRINA NIKOLAEVA	{"email": "i_nikolaeva-29011967@postgrespro.ru", "phone": "+70586920671"}
0005434214465	064147	4924 377742	YANA ZAKHAROVA	{"phone": "+70555098395"}
0005434214466	C76D07	5476 215283	RUSLAN POPOV	{"phone": "+70393343960"}
0005434214467	A9557F	3146 468980	VYACHESLAV DENISOV	{"email": "denisovvyacheslav_03091973@postgrespro.ru", "phone": "+70607630294"}
0005434214468	A474CD	4437 243248	VIKTORIYA ZHURAVLEVA	{"email": "vzhuravleva.1979@postgrespro.ru", "phone": "+70276384710"}
0005434214469	64E9FD	1922 915805	LYUDMILA KRASNOVA	{"email": "l.krasnova-021976@postgrespro.ru", "phone": "+70601634533"}
0005434214470	D9318B	2016 577992	VLADIMIR SERGEEV	{"email": "v-sergeev-13081980@postgrespro.ru", "phone": "+70130115667"}
0005434214471	A95FD5	3191 107411	OLGA KUZNECOVA	{"phone": "+70201690578"}
0005434214472	A95FD5	0827 551059	VLADISLAV SOLOVEV	{"email": "solovevv-13031973@postgrespro.ru", "phone": "+70740708455"}
0005434214473	E587A6	7510 715186	SVETLANA POPOVA	{"phone": "+70758514503"}
0005434214474	E587A6	1227 520122	ELENA LOGINOVA	{"phone": "+70969966036"}
0005434214475	77E741	2982 491153	ALEKSANDR MAKAROV	{"phone": "+70805093817"}
0005434214476	83045B	5701 924119	VALENTINA KULIKOVA	{"phone": "+70097983575"}
0005434214477	2635A5	6972 415012	VLADIMIR MATVEEV	{"email": "vladimirmatveev_1966@postgrespro.ru", "phone": "+70598784949"}
0005434214478	A7ED18	2598 207692	FARID FILIPPOV	{"email": "f_filippov21061972@postgrespro.ru", "phone": "+70495835762"}
0005434214479	A7ED18	5156 826457	NIKOLAY ALEKSEEV	{"email": "n_alekseev_07121973@postgrespro.ru", "phone": "+70693545076"}
0005434214480	3745A9	7688 372137	MIKHAIL FOMIN	{"phone": "+70119363645"}
0005434214481	9DF682	9712 304405	ZOYA ZAKHAROVA	{"email": "zoyazakharova1984@postgrespro.ru", "phone": "+70740505641"}
0005434214482	ADE25C	0582 605209	NATALYA MAKAROVA	{"phone": "+70825567309"}
0005434214483	ADE25C	4466 236323	DIANA SAVELEVA	{"phone": "+70391484024"}
0005434214484	EC1573	7572 020976	EVGENIYA FROLOVA	{"phone": "+70192433464"}
0005434214485	EC1573	7480 595853	TATYANA LUKYANOVA	{"phone": "+70590274495"}
0005434214486	EC1573	7619 074119	LYUDMILA ALEKSEEVA	{"email": "lalekseeva.091964@postgrespro.ru", "phone": "+70629510194"}
0005434214487	511575	3887 277740	ELENA OVCHINNIKOVA	{"email": "ovchinnikova-elena.12121976@postgrespro.ru", "phone": "+70239594970"}
0005434214488	28A898	2512 377242	ANNA GERASIMOVA	{"phone": "+70611380020"}
0005434214489	81EF28	9445 555490	SERGEY PETROV	{"phone": "+70549529907"}
0005434214490	7210F4	2191 414415	SVETLANA KUZNECOVA	{"phone": "+70946740680"}
0005434214491	A01772	9545 442917	LYUDMILA YAKOVLEVA	{"phone": "+70407618481"}
0005434214492	0FE41E	2976 443164	VALENTINA MEDVEDEVA	{"phone": "+70645707640"}
0005434214493	FC6F99	8753 653194	IRINA FILIPPOVA	{"phone": "+70758643502"}
0005434214494	0F0FED	3764 563616	LIDIYA ALEKSEEVA	{"phone": "+70607313302"}
0005434214495	7F7F89	1066 023439	NATALYA STEPANOVA	{"phone": "+70660842898"}
0005434214496	7F7F89	5065 128127	INNA PAVLOVA	{"phone": "+70299583867"}
0005434214497	D0F0B3	3940 478144	ROMAN ZAKHAROV	{"email": "zakharovr.011971@postgrespro.ru", "phone": "+70305626177"}
0005434214498	3D8FC5	6266 082221	VASILIY ZAYCEV	{"phone": "+70648914926"}
0005434214499	F21CE5	7311 755299	ALEKSANDR SOROKIN	{"phone": "+70185580539"}
0005434214500	3ABA1B	5236 290491	TATYANA BELOVA	{"email": "belova_tatyana_1974@postgrespro.ru", "phone": "+70797014814"}
0005434214501	48F53C	2646 521571	ILYA PETROV	{"email": "i-petrov1976@postgrespro.ru", "phone": "+70586737174"}
0005434214502	48F53C	7245 579751	VASILIY FEDOTOV	{"email": "fedotov.vasiliy_03051966@postgrespro.ru", "phone": "+70050605231"}
0005434214503	0BBD03	7406 978282	KONSTANTIN KARPOV	{"email": "karpov-k-31121961@postgrespro.ru", "phone": "+70717296413"}
0005434214504	C33990	9116 073398	ELENA PAVLOVA	{"phone": "+70349900604"}
0005434214505	2936B6	5172 306582	ALEVTINA MIKHAYLOVA	{"phone": "+70475938107"}
0005434214506	739E53	7512 671174	MARINA IVANOVA	{"phone": "+70717257986"}
0005434214507	739E53	0261 019316	VLADIMIR ROMANOV	{"email": "romanov-v1983@postgrespro.ru", "phone": "+70950955526"}
0005434214508	FE15F8	5785 199205	ANTON ZAKHAROV	{"phone": "+70528917315"}
0005434214509	FE15F8	3159 631485	ELENA GERASIMOVA	{"email": "e_gerasimova.121969@postgrespro.ru", "phone": "+70946080539"}
0005434214510	C617C4	0618 376616	NINA ZHURAVLEVA	{"email": "nina.zhuravleva_031971@postgrespro.ru", "phone": "+70562988552"}
0005434214511	C617C4	5878 011065	VALENTINA IVANOVA	{"email": "ivanovavalentina_13121970@postgrespro.ru", "phone": "+70696988494"}
0005434214512	62E057	3724 548455	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikovavalentina_121974@postgrespro.ru", "phone": "+70482979453"}
0005434214513	E7A8EE	2430 529019	EDUARD ALEKSEEV	{"email": "eduardalekseev_08051981@postgrespro.ru", "phone": "+70947674898"}
0005434214514	E7A8EE	0365 959371	VLADIMIR ANDREEV	{"email": "andreevvladimir.1977@postgrespro.ru", "phone": "+70582553747"}
0005434214517	C3DD5D	8148 862064	ANATOLIY MARTYNOV	{"phone": "+70621169022"}
0005434214518	3E7BB0	1665 239885	MARIYA POLYAKOVA	{"email": "polyakova.m.051970@postgrespro.ru", "phone": "+70429042468"}
0005434214519	27AE83	2952 280237	SERGEY VOROBEV	{"email": "vorobevsergey.21091978@postgrespro.ru", "phone": "+70462320972"}
0005434214520	7A8768	4202 055435	EVGENIY SIDOROV	{"email": "sidorov_evgeniy.1970@postgrespro.ru", "phone": "+70889692602"}
0005434214521	A5BA57	8235 902664	ULYANA SOROKINA	{"phone": "+70605157954"}
0005434214522	7D38D0	2778 231609	GENNADIY TIKHONOV	{"phone": "+70453781677"}
0005434214523	189578	2905 327962	TATYANA LUKYANOVA	{"email": "lukyanova_t-041974@postgrespro.ru", "phone": "+70595827272"}
0005434214524	ECA673	8113 798728	IRINA KOROLEVA	{"email": "irina-koroleva14061971@postgrespro.ru", "phone": "+70420242506"}
0005434214525	DF4E00	2603 413258	KONSTANTIN TIKHONOV	{"phone": "+70854826088"}
0005434214526	DF4E00	2018 146630	ANDREY KOROLEV	{"email": "a-korolev_1972@postgrespro.ru", "phone": "+70428831596"}
0005434214527	DF4E00	7713 937030	SVETLANA POPOVA	{"phone": "+70450565673"}
0005434214528	F97283	6217 156243	SOFIYA ISAEVA	{"email": "s_isaeva.1967@postgrespro.ru", "phone": "+70526184491"}
0005434214529	4BCE47	0732 266359	LYUBOV RYABOVA	{"email": "lyubovryabova061975@postgrespro.ru", "phone": "+70950537922"}
0005434214530	BCA852	1473 828097	VIKTORIYA IVANOVA	{"email": "ivanovaviktoriya071976@postgrespro.ru", "phone": "+70628320517"}
0005434214531	BCA852	1648 146902	TATYANA PETROVA	{"email": "petrovat_071972@postgrespro.ru", "phone": "+70370689086"}
0005434214532	89F70E	4480 151317	ANNA KUZMINA	{"phone": "+70241345583"}
0005434214533	626005	8249 737150	SERGEY NAZAROV	{"email": "nazarov.sergey-071975@postgrespro.ru", "phone": "+70667537995"}
0005434214534	DBDCAC	0389 927240	ROMAN SIDOROV	{"phone": "+70205938241"}
0005434214535	D6CCCB	1391 557140	ALEKSANDR GORBUNOV	{"phone": "+70105758187"}
0005434214536	3315BC	2988 403528	SERGEY KAZAKOV	{"email": "skazakov-22011974@postgrespro.ru", "phone": "+70776158401"}
0005434214537	3315BC	5115 396298	MAKSIM VLASOV	{"email": "vlasov.m.07061969@postgrespro.ru", "phone": "+70415202128"}
0005434214538	583A41	2549 098053	LARISA MIKHAYLOVA	{"phone": "+70790042360"}
0005434214539	E2C54A	6659 767539	NELYA FILIPPOVA	{"phone": "+70193169576"}
0005434214540	56357A	0803 606495	LIDIYA CHERNOVA	{"email": "lidiyachernova-101972@postgrespro.ru", "phone": "+70601092086"}
0005434214541	CECD86	8863 310091	ALEKSANDR KUZMIN	{"email": "a.kuzmin.03031968@postgrespro.ru", "phone": "+70994002426"}
0005434214542	BB1DCA	6302 221177	PAVEL SOKOLOV	{"phone": "+70373351589"}
0005434214543	22801C	8602 466337	DMITRIY DAVYDOV	{"phone": "+70480922399"}
0005434214544	22801C	7433 370390	NADEZHDA ANDREEVA	{"email": "n.andreeva.01121975@postgrespro.ru", "phone": "+70500955308"}
0005434214545	8B96B3	2764 927822	YULIYA STEPANOVA	{"email": "stepanova-yuliya_1979@postgrespro.ru", "phone": "+70551025296"}
0005434214546	5EF002	7125 808072	PAVEL TIKHONOV	{"phone": "+70880236230"}
0005434214547	DAA6C8	4143 886139	VALENTIN IVANOV	{"email": "ivanov-valentin-10061973@postgrespro.ru", "phone": "+70622881250"}
0005434214548	DAA6C8	9739 284138	ANASTASIYA KUDRYASHOVA	{"phone": "+70499231697"}
0005434214549	A4095A	1148 742105	ELINA IVANOVA	{"phone": "+70152937679"}
0005434214550	A4095A	6959 140859	VIKTOR KONOVALOV	{"phone": "+70365767231"}
0005434214551	271FF9	0030 041090	VLADIMIR VOLKOV	{"phone": "+70837745790"}
0005434214552	B8D205	3332 531766	ANASTASIYA SCHERBAKOVA	{"email": "anastasiya-scherbakova.19121971@postgrespro.ru", "phone": "+70168158835"}
0005434214553	B8D205	8074 486021	VIKTOR KUDRYASHOV	{"phone": "+70764287775"}
0005434214554	74CF09	7969 995531	IRINA SERGEEVA	{"email": "sergeeva_i071965@postgrespro.ru", "phone": "+70577919930"}
0005434214555	74CF09	3494 250324	LYUBOV ANDREEVA	{"email": "andreeva.lyubov29101977@postgrespro.ru", "phone": "+70766210369"}
0005434214556	74CF09	8234 967146	KRISTINA SAVELEVA	{"phone": "+70563525261"}
0005434214557	AC56C5	3288 280226	ELENA MELNIKOVA	{"email": "melnikovaelena1970@postgrespro.ru", "phone": "+70656465003"}
0005434214558	1E25B2	0398 426689	LEONID KISELEV	{"email": "kiselev.leonid.1969@postgrespro.ru", "phone": "+70454401848"}
0005434214559	21B516	5915 258080	SERGEY NAUMOV	{"email": "sergey-naumov-1967@postgrespro.ru", "phone": "+70048467044"}
0005434214560	21B516	1336 131751	VLADIMIR KRASNOV	{"phone": "+70321477788"}
0005434214561	8834C7	0601 374641	ALEKSANDR NAUMOV	{"phone": "+70529458927"}
0005434214562	0A4E10	4850 096685	PAVEL KUZNECOV	{"phone": "+70884729011"}
0005434214563	0A4E10	2876 239875	SERGEY SHEVCHENKO	{"phone": "+70101512736"}
0005434214564	9F313B	3690 595578	MIKHAIL YAKOVLEV	{"email": "m.yakovlev_121969@postgrespro.ru", "phone": "+70539657644"}
0005434214565	A48815	8993 998781	NARIMAN SOROKIN	{"phone": "+70209266459"}
0005434214566	A48815	2460 491150	OLGA KUZMINA	{"email": "kuzmina-o.051974@postgrespro.ru", "phone": "+70522576962"}
0005434214567	2B47E1	8365 855894	MIKHAIL FROLOV	{"email": "m_frolov.12011973@postgrespro.ru", "phone": "+70929604465"}
0005434214568	2B47E1	3774 652618	IGOR BONDARENKO	{"email": "bondarenko_i.1971@postgrespro.ru", "phone": "+70408388919"}
0005434214569	2B47E1	2859 871798	OLGA KRASNOVA	{"email": "olgakrasnova_011972@postgrespro.ru", "phone": "+70016786487"}
0005434214570	3AB923	1589 479211	OLGA TARASOVA	{"email": "o.tarasova-12081963@postgrespro.ru", "phone": "+70142366117"}
0005434214571	DDE52E	6313 430683	IVAN KUZNECOV	{"phone": "+70144339981"}
0005434214572	DDE52E	8274 383668	MARIYA FROLOVA	{"email": "mariya.frolova_081964@postgrespro.ru", "phone": "+70073391222"}
0005434214573	1F5444	1592 581329	MIKHAIL MOISEEV	{"email": "moiseev.m12101969@postgrespro.ru", "phone": "+70868242669"}
0005434214574	E78CFC	8273 036009	RIMMA MIRONOVA	{"phone": "+70201360553"}
0005434214575	E78CFC	0085 717467	NINA PAVLOVA	{"email": "nina.pavlova_081972@postgrespro.ru", "phone": "+70061362771"}
0005434214576	E78CFC	9602 529071	OLEG KARPOV	{"email": "olegkarpov.061957@postgrespro.ru", "phone": "+70043269393"}
0005434214577	E78CFC	8982 014606	YANA ANDREEVA	{"phone": "+70001625535"}
0005434214578	9342EB	6166 521174	ELENA VLASOVA	{"email": "elena-vlasova_13111975@postgrespro.ru", "phone": "+70625633977"}
0005434214579	9342EB	4523 334179	VLADIMIR GORBUNOV	{"email": "v_gorbunov.07051979@postgrespro.ru", "phone": "+70437592504"}
0005434214580	33A1D6	5168 424204	VALENTINA KUZNECOVA	{"phone": "+70194389870"}
0005434214581	272F18	3834 231112	NINA MARTYNOVA	{"email": "nina.martynova-071978@postgrespro.ru", "phone": "+70550611896"}
0005434214582	C82115	6807 837746	ILYA KONOVALOV	{"phone": "+70543271475"}
0005434214583	019C36	4999 788757	KONSTANTIN BELOV	{"phone": "+70607603178"}
0005434214584	BDFA77	2440 660973	ANGELINA CHERNOVA	{"phone": "+70087481465"}
0005434214585	5B9684	5287 267117	ALBINA BARANOVA	{"email": "baranova.albina081965@postgrespro.ru", "phone": "+70586181422"}
0005434214586	8ABDD8	8623 285316	MIKHAIL SIDOROV	{"phone": "+70011329941"}
0005434214587	8ABDD8	0420 161570	NIKOLAY TIMOFEEV	{"email": "timofeev-nikolay1981@postgrespro.ru", "phone": "+70829286171"}
0005434214588	8ABDD8	9413 746675	ALEKSANDR SOROKIN	{"phone": "+70237512063"}
0005434214589	0197A6	0681 660218	ANASTASIYA SOLOVEVA	{"email": "soloveva-a_05091971@postgrespro.ru", "phone": "+70734551670"}
0005434214590	464D13	8535 403665	ELENA PETROVA	{"phone": "+70903951491"}
0005434214591	1AC50E	7016 029308	LYUBOV KAZAKOVA	{"phone": "+70984171933"}
0005434214592	2159AA	2153 352788	NATALYA SOLOVEVA	{"phone": "+70075321558"}
0005434214593	2159AA	5691 350751	OLEG IVANOV	{"email": "oleg-ivanov-1970@postgrespro.ru", "phone": "+70009588239"}
0005434214594	F5E84F	2784 657517	ZOYA MIRONOVA	{"email": "mironova.z_01071974@postgrespro.ru", "phone": "+70415232424"}
0005434214595	0D702D	0868 725248	DARYA KOVALEVA	{"email": "d.kovaleva121983@postgrespro.ru", "phone": "+70152611230"}
0005434214596	243E07	6961 976414	ALEKSANDRA BOGDANOVA	{"email": "bogdanova_aleksandra-1965@postgrespro.ru", "phone": "+70696852275"}
0005434214597	243E07	4233 652743	EKATERINA KOLESNIKOVA	{"phone": "+70566442353"}
0005434214598	1C4C3C	8709 260213	ANASTASIYA SEMENOVA	{"email": "asemenova_1972@postgrespro.ru", "phone": "+70042710184"}
0005434214599	1C4C3C	1988 802734	VLADIMIR MAKSIMOV	{"phone": "+70360764868"}
0005434214600	1912B3	0918 610510	NATALYA KONDRATEVA	{"email": "kondratevan.121969@postgrespro.ru", "phone": "+70578197813"}
0005434214601	946964	5851 534649	VASILIY NOVIKOV	{"email": "vasiliy_novikov-16081973@postgrespro.ru", "phone": "+70818307009"}
0005434214602	49C963	0415 184078	NINA DANILOVA	{"phone": "+70090390443"}
0005434214603	28D736	6454 108237	NATALYA ZAKHAROVA	{"email": "natalya.zakharova_101981@postgrespro.ru", "phone": "+70228311646"}
0005434214604	7F95E3	2208 977741	ZINAIDA KOVALEVA	{"email": "zinaidakovaleva-16051962@postgrespro.ru", "phone": "+70933896034"}
0005434214605	7F95E3	1574 196192	MARINA IVANOVA	{"email": "m.ivanova.14071970@postgrespro.ru", "phone": "+70274249019"}
0005434214606	4915FC	8774 414778	MARIYA MIRONOVA	{"email": "mironova-mariya.1972@postgrespro.ru", "phone": "+70195346953"}
0005434214607	F0C58E	2669 743073	ARTEM VASILEV	{"email": "vasilev-a-081981@postgrespro.ru", "phone": "+70585182078"}
0005434214608	AB9CA0	7605 952396	MIKHAIL AFANASEV	{"phone": "+70076332984"}
0005434214609	2C62C1	7326 635865	ZINAIDA MIRONOVA	{"email": "z_mironova1967@postgrespro.ru", "phone": "+70797888682"}
0005434214610	2C62C1	1452 890490	RIMMA BORISOVA	{"email": "borisovar14081976@postgrespro.ru", "phone": "+70666497771"}
0005434214611	844B3F	6517 558862	ANTONINA PAVLOVA	{"email": "pavlovaantonina.021972@postgrespro.ru", "phone": "+70820111027"}
0005434214612	2B5E74	6517 957843	MARGARITA TROFIMOVA	{"email": "trofimova_margarita.1981@postgrespro.ru", "phone": "+70817719457"}
0005434214613	0697B5	2201 772023	MARIYA MOISEEVA	{"email": "moiseeva-m28051976@postgrespro.ru", "phone": "+70124006756"}
0005434214614	3CC5F2	4214 031252	SERGEY BELOV	{"email": "sbelov.031971@postgrespro.ru", "phone": "+70365350788"}
0005434214615	CA799F	2530 668811	LYUDMILA VOROBEVA	{"email": "vorobeva-lyudmila-02091963@postgrespro.ru", "phone": "+70875170487"}
0005434214616	CA799F	1563 822376	TATYANA FILATOVA	{"email": "tatyana_filatova.1994@postgrespro.ru", "phone": "+70913665117"}
0005434214617	FD4AE5	3149 549164	IGOR EGOROV	{"phone": "+70291923734"}
0005434214618	40E35B	8583 259970	NADEZHDA KONOVALOVA	{"phone": "+70133402929"}
0005434214619	40E35B	0010 605367	VALENTINA POPOVA	{"email": "valentinapopova_091966@postgrespro.ru", "phone": "+70869943090"}
0005434214620	FC311C	3871 958457	MARIYA KUZNECOVA	{"phone": "+70570651913"}
0005434214621	9A1226	1328 687123	GALINA VOROBEVA	{"email": "vorobevagalina_1972@postgrespro.ru", "phone": "+70766946614"}
0005434214622	9A1226	2092 278334	YURIY FEDOROV	{"email": "fedorovyuriy-041968@postgrespro.ru", "phone": "+70328491412"}
0005434214623	3FD52D	9899 641141	OLGA ORLOVA	{"email": "o.orlova17101959@postgrespro.ru", "phone": "+70506037167"}
0005434214624	5E541D	7207 822722	SERGEY MAKAROV	{"phone": "+70612002434"}
0005434214625	FB78AB	0753 234620	ANNA KULIKOVA	{"email": "kulikova-anna_061978@postgrespro.ru", "phone": "+70100181537"}
0005434214626	065F25	9962 262784	VALENTINA ALEKSEEVA	{"email": "alekseeva_v.06011972@postgrespro.ru", "phone": "+70266343131"}
0005434214627	FD5051	2937 272767	OLEG GUSEV	{"email": "o.gusev091974@postgrespro.ru", "phone": "+70194444429"}
0005434214628	F149F8	7089 519414	ALEKSANDR KARPOV	{"phone": "+70522238503"}
0005434214629	F149F8	7140 858095	ELENA IVANOVA	{"phone": "+70061228052"}
0005434214630	5B1227	9716 002796	PAVEL ILIN	{"email": "pavel-ilin03101979@postgrespro.ru", "phone": "+70584294399"}
0005434214631	F52A68	3166 291532	YURIY TARASOV	{"phone": "+70318407060"}
0005434214632	94FE42	2785 144487	ALEKSANDR IVANOV	{"phone": "+70817984719"}
0005434214633	43C78D	9778 958222	VALENTINA BELYAEVA	{"email": "belyaeva-valentina.05031980@postgrespro.ru", "phone": "+70191196954"}
0005434214634	43C78D	9286 931252	NADEZHDA POPOVA	{"phone": "+70178785977"}
0005434214635	98AF59	6498 100040	ALEKSANDR POPOV	{"phone": "+70003351470"}
0005434214636	98AF59	7807 860800	LYUBOV DMITRIEVA	{"phone": "+70430823593"}
0005434214637	CF4E36	2303 297974	OLEG MAKSIMOV	{"email": "maksimovoleg.25031978@postgrespro.ru", "phone": "+70522640241"}
0005434214638	736293	0641 521027	ALEKSEY VOLKOV	{"phone": "+70051703879"}
0005434214639	DE7B21	0495 892633	LYUBOV KUZMINA	{"phone": "+70599954365"}
0005434214640	DE7B21	9707 512685	VIKTOR RODIONOV	{"email": "v-rodionov.051969@postgrespro.ru", "phone": "+70688915667"}
0005434214641	BA054F	4202 469257	DMITRIY YAKOVLEV	{"email": "dmitriy-yakovlev.1975@postgrespro.ru", "phone": "+70411915598"}
0005434214642	BA054F	9544 986312	VALERIY ZHURAVLEV	{"email": "zhuravlev_valeriy-1969@postgrespro.ru", "phone": "+70625105776"}
0005434214643	08947D	8357 522502	NATALYA KISELEVA	{"email": "n.kiseleva-28081964@postgrespro.ru", "phone": "+70432185248"}
0005434214644	08947D	9569 398905	LIDIYA ILINA	{"phone": "+70449357135"}
0005434214645	F00627	4240 332929	GALINA OSIPOVA	{"email": "g-osipova.1975@postgrespro.ru", "phone": "+70080039516"}
0005434214646	0665D9	2260 378056	TAISIYA NAUMOVA	{"email": "naumova.t_11071979@postgrespro.ru", "phone": "+70064420701"}
0005434214647	06D645	5939 359015	PELAGEYA SOROKINA	{"phone": "+70931316596"}
0005434214648	6C4ACA	0209 553029	ANASTASIYA VOLKOVA	{"email": "anastasiyavolkova1975@postgrespro.ru", "phone": "+70525946139"}
0005434214649	A81DC5	6560 493821	ANDREY KUZMIN	{"phone": "+70031696160"}
0005434214650	5399E3	9373 047171	OLGA KOZLOVA	{"email": "kozlova.o1978@postgrespro.ru", "phone": "+70812361880"}
0005434214651	4A9B9A	3646 551376	STEPAN MAKSIMOV	{"email": "maksimov.s091971@postgrespro.ru", "phone": "+70739322940"}
0005434214652	810B74	0393 235302	VITALIY EGOROV	{"email": "egorov_v031968@postgrespro.ru", "phone": "+70290367383"}
0005434214653	05F506	8604 247947	EVGENIY KUZNECOV	{"phone": "+70882710358"}
0005434214654	05F506	9892 001648	EMMA ERMAKOVA	{"phone": "+70498965199"}
0005434214655	187D58	4835 903210	OLGA BELOVA	{"email": "belova.o-111970@postgrespro.ru", "phone": "+70245242349"}
0005434214656	B96991	1926 731634	LILIYA MAKAROVA	{"phone": "+70324789100"}
0005434214657	270220	5243 673877	VIKTORIYA KARPOVA	{"email": "v_karpova_07041976@postgrespro.ru", "phone": "+70510004461"}
0005434214658	270220	5457 980844	VALENTINA GORBUNOVA	{"phone": "+70092406237"}
0005434214659	E8409D	6002 741720	ANNA GUSEVA	{"phone": "+70519147675"}
0005434214660	0590BE	8680 839959	NADEZHDA AFANASEVA	{"email": "nadezhda.afanaseva.11041984@postgrespro.ru", "phone": "+70027892736"}
0005434214661	0DFBC6	2904 191381	VALENTINA POLYAKOVA	{"email": "polyakova-valentina_1964@postgrespro.ru", "phone": "+70897588560"}
0005434214662	B04669	1057 909421	ALEKSEY KULIKOV	{"email": "kulikov_aleksey.21031976@postgrespro.ru", "phone": "+70047492521"}
0005434214663	E7B933	1647 069162	VALERIY OSIPOV	{"email": "v.osipov_1960@postgrespro.ru", "phone": "+70772699345"}
0005434214664	3E5EE9	7433 340553	OLEG IVANOV	{"phone": "+70233772471"}
0005434214665	84DF99	2114 960745	VASILIY ALEKSEEV	{"email": "valekseev-04011982@postgrespro.ru", "phone": "+70293121523"}
0005434214666	84DF99	1322 513508	ANDREY MAKAROV	{"email": "a.makarov.23071972@postgrespro.ru", "phone": "+70592052153"}
0005434214667	DD8B75	7895 896601	TATYANA OSIPOVA	{"phone": "+70682773792"}
0005434214668	C1914A	5228 346671	IVAN MAKSIMOV	{"email": "maksimov-i.061963@postgrespro.ru", "phone": "+70788444416"}
0005434214669	C1914A	7208 437939	ALLA YAKOVLEVA	{"phone": "+70292995172"}
0005434214670	3570E0	5335 770991	ALEKSANDR MARTYNOV	{"phone": "+70794619873"}
0005434214671	8FA31B	2647 301090	ANTON NIKOLAEV	{"phone": "+70848001153"}
0005434214672	31949D	3511 358347	VALERIY MEDVEDEV	{"phone": "+70236482676"}
0005434214673	E06E80	7411 325147	VLADIMIR POPOV	{"phone": "+70766916521"}
0005434214674	E06E80	0140 880619	SERGEY ALEKSANDROV	{"email": "aleksandrovs-02051958@postgrespro.ru", "phone": "+70373681237"}
0005434214675	95FEAC	0902 561213	IRINA VLASOVA	{"phone": "+70646581028"}
0005434214676	95FEAC	2317 054984	NIKITA DMITRIEV	{"phone": "+70988002768"}
0005434214677	AF4449	9893 808529	MAKSIM KULIKOV	{"phone": "+70997925472"}
0005434214678	AF4449	5854 721076	ELIZAVETA POPOVA	{"email": "elizaveta_popova_29121971@postgrespro.ru", "phone": "+70638235987"}
0005434214679	AF4449	9936 540140	ALEKSEY STEPANOV	{"email": "stepanov-aleksey-1967@postgrespro.ru", "phone": "+70222641094"}
0005434214680	8FC8E1	8712 814506	VASILIY MEDVEDEV	{"email": "medvedev_vasiliy-041978@postgrespro.ru", "phone": "+70428506885"}
0005434214681	EA96DA	5656 540273	ANTON MAKSIMOV	{"email": "maksimov.a.071958@postgrespro.ru", "phone": "+70543941325"}
0005434214682	EA96DA	7461 216806	VLADISLAV KUZNECOV	{"email": "kuznecov.v.071968@postgrespro.ru", "phone": "+70350449400"}
0005434214683	6C1C2D	8188 703056	ANASTASIYA MEDVEDEVA	{"phone": "+70769697189"}
0005434214684	E330D7	5646 442067	NIKOLAY SCHERBAKOV	{"email": "nikolay.scherbakov-05111979@postgrespro.ru", "phone": "+70936729814"}
0005434214685	483959	0546 438968	SERGEY ILIN	{"phone": "+70069182634"}
0005434214686	A58FA1	0776 790089	ALENA PETROVA	{"email": "alena.petrova1981@postgrespro.ru", "phone": "+70092974050"}
0005434214687	A76ECB	4846 256699	TATYANA STEPANOVA	{"phone": "+70938356434"}
0005434214688	D3E00B	7967 457491	VALENTINA MIKHAYLOVA	{"phone": "+70540172831"}
0005434214689	D3E00B	1273 581813	DMITRIY BORISOV	{"phone": "+70387964995"}
0005434214690	D3E00B	2162 479606	PETR IVANOV	{"email": "ivanov-petr21111967@postgrespro.ru", "phone": "+70576390403"}
0005434214691	6737ED	1040 033374	ALEKSANDR SCHERBAKOV	{"phone": "+70357904832"}
0005434214692	6737ED	0212 720720	ELENA IVANOVA	{"phone": "+70973778454"}
0005434214693	6737ED	5985 980359	RAISA VOLKOVA	{"email": "r.volkova-041974@postgrespro.ru", "phone": "+70217245428"}
0005434214694	1FF1AE	6899 587277	OLGA SEMENOVA	{"email": "semenovaolga041975@postgrespro.ru", "phone": "+70590776365"}
0005434214695	0BE56A	4176 729802	VIKTOR BELOV	{"phone": "+70964075313"}
0005434214696	A796C7	6990 032378	LYUBOV EGOROVA	{"email": "egoroval-10031969@postgrespro.ru", "phone": "+70235260646"}
0005434214697	D9D264	5369 146457	ELENA NIKITINA	{"phone": "+70166889528"}
0005434214698	B73695	9610 062905	SERGEY FEDOROV	{"email": "s_fedorov.061958@postgrespro.ru", "phone": "+70220823955"}
0005434214699	B73695	5257 657280	OLGA NOVIKOVA	{"phone": "+70972524126"}
0005434214700	86B17A	5936 513435	IVAN FOMIN	{"email": "fominivan-16061972@postgrespro.ru", "phone": "+70670217340"}
0005434214701	EBD840	5687 474794	NIKOLAY KONOVALOV	{"email": "konovalov.n-25021974@postgrespro.ru", "phone": "+70107230015"}
0005434214702	33239C	3685 080842	NATALYA SAVELEVA	{"phone": "+70484844815"}
0005434214703	4E4541	2081 367980	LYUDMILA SIDOROVA	{"email": "lyudmila-sidorova1974@postgrespro.ru", "phone": "+70101107797"}
0005434214704	4E4541	0383 902242	VLADIMIR NOVIKOV	{"email": "novikov_vladimir.02091971@postgrespro.ru", "phone": "+70411253012"}
0005434214705	4E4541	3375 510730	MARIYA IVANOVA	{"phone": "+70297851579"}
0005434214706	DF5741	5918 191780	ANASTASIYA FOMINA	{"phone": "+70582490298"}
0005434214707	30C54D	7066 051724	NIKOLAY MAKSIMOV	{"phone": "+70414112542"}
0005434214708	30C54D	0412 509661	ANNA BELOVA	{"email": "a-belova101967@postgrespro.ru", "phone": "+70798746149"}
0005434214709	00A5B1	5014 641736	SERGEY KULIKOV	{"phone": "+70129811850"}
0005434214710	00A5B1	3411 478446	EKATERINA ZOTOVA	{"phone": "+70470759563"}
0005434214711	5412B5	5236 188339	ELENA VOLKOVA	{"email": "volkovaelena.10101974@postgrespro.ru", "phone": "+70631556486"}
0005434214712	6039F7	1981 465676	VLADIMIR SHEVCHENKO	{"email": "shevchenko-vladimir-09021970@postgrespro.ru", "phone": "+70425418403"}
0005434214713	6039F7	0409 244353	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov22041969@postgrespro.ru", "phone": "+70328436064"}
0005434214714	B9B423	4854 941440	SEMEN NOVIKOV	{"email": "novikov.s07011985@postgrespro.ru", "phone": "+70813650587"}
0005434214715	DFE56C	1105 104834	OLGA VASILEVA	{"email": "vasileva_o-041982@postgrespro.ru", "phone": "+70888638698"}
0005434214716	B23BCB	3376 123626	ROSTISLAV DMITRIEV	{"email": "dmitriev_r.09061971@postgrespro.ru", "phone": "+70114982360"}
0005434214717	3F6E6A	3839 121767	DIANA YAKOVLEVA	{"email": "dyakovleva.091973@postgrespro.ru", "phone": "+70019710780"}
0005434214718	A40CAD	5734 858377	VIKTOR NAZAROV	{"email": "nazarovv-04121974@postgrespro.ru", "phone": "+70468464698"}
0005434214719	3875F5	1061 009737	SAMVEL IVANOV	{"email": "samvel-ivanov28091971@postgrespro.ru", "phone": "+70933921704"}
0005434214720	3875F5	8208 855875	ALEKSANDR IVANOV	{"phone": "+70283560123"}
0005434214721	05D0BF	8802 899768	NINA PETROVA	{"email": "petrovan13111978@postgrespro.ru", "phone": "+70939647317"}
0005434214722	D73509	6773 584948	DARYA VOLKOVA	{"phone": "+70610819675"}
0005434214723	D7152A	5680 206326	DARYA BELYAEVA	{"phone": "+70293046218"}
0005434214724	D7152A	9220 818338	EKATERINA KUZNECOVA	{"email": "ekuznecova-051978@postgrespro.ru", "phone": "+70978708357"}
0005434214725	1555FE	4606 487177	ARSENIY SCHERBAKOV	{"email": "scherbakovarseniy011959@postgrespro.ru", "phone": "+70260748296"}
0005434214726	B9793D	0294 952537	LIYA GRISHINA	{"email": "grishina_liya.061976@postgrespro.ru", "phone": "+70039852777"}
0005434214727	318CA3	8267 511439	BORIS NIKOLAEV	{"phone": "+70053649408"}
0005434214728	318CA3	8364 710606	VLADIMIR FOMIN	{"phone": "+70636453826"}
0005434214729	D12458	1347 886462	MIKHAIL EGOROV	{"email": "egorov-mikhail_101972@postgrespro.ru", "phone": "+70368193458"}
0005434214730	083207	5282 310262	MAKSIM KUZMIN	{"phone": "+70599950248"}
0005434214731	083207	1054 555504	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila-1971@postgrespro.ru", "phone": "+70733363697"}
0005434214732	8800B0	2550 980505	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail.021970@postgrespro.ru", "phone": "+70450585559"}
0005434214733	8800B0	0592 175683	ALEKSANDRA MIRONOVA	{"phone": "+70852626096"}
0005434214734	8800B0	3367 957264	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a-22121978@postgrespro.ru", "phone": "+70193935513"}
0005434214735	0C720E	8884 333860	ALEKSEY KUZNECOV	{"phone": "+70948652724"}
0005434214736	83CC10	4580 480063	NADEZHDA KISELEVA	{"phone": "+70531789943"}
0005434214737	B52028	6698 433641	OLEG PAVLOV	{"phone": "+70042390163"}
0005434214738	0DD584	6070 220110	YULIYA ISAEVA	{"email": "isaeva.yuliya-1975@postgrespro.ru", "phone": "+70082708434"}
0005434215073	260500	5729 534390	GALINA OVCHINNIKOVA	{"phone": "+70502554576"}
0005434214739	25A109	7327 945290	OLEG SIDOROV	{"email": "sidorov-oleg011964@postgrespro.ru", "phone": "+70318215433"}
0005434214740	E84111	3013 630376	VADIM TIMOFEEV	{"phone": "+70022104231"}
0005434214741	8E84A7	2268 837717	GALIYA SOKOLOVA	{"phone": "+70202985987"}
0005434214742	D6E77B	0830 004248	NINA AKIMOVA	{"email": "nina.akimova06121960@postgrespro.ru", "phone": "+70610219065"}
0005434214743	D6E77B	3400 728119	ANTONINA PETROVA	{"phone": "+70671721354"}
0005434214744	018220	3762 012308	PETR POPOV	{"phone": "+70916160656"}
0005434214745	3E90A3	8568 185594	GALINA SOKOLOVA	{"phone": "+70145313578"}
0005434214746	797ED6	8409 053895	ILDAR ZHUKOV	{"email": "i_zhukov-011967@postgrespro.ru", "phone": "+70843853718"}
0005434214747	640774	5676 792993	NATALYA OSIPOVA	{"email": "natalya.osipova081974@postgrespro.ru", "phone": "+70551714901"}
0005434214748	640774	5920 514030	YURIY GERASIMOV	{"phone": "+70673182202"}
0005434214749	640774	2883 965805	IVAN ZAKHAROV	{"email": "ivan-zakharov_24101974@postgrespro.ru", "phone": "+70648061875"}
0005434214750	640774	6839 942887	ELENA NAZAROVA	{"email": "nazarova-e-1987@postgrespro.ru", "phone": "+70387028367"}
0005434214751	D16104	4019 194806	ARTEM DENISOV	{"email": "artem_denisov.051970@postgrespro.ru", "phone": "+70615332428"}
0005434214752	8AF49C	8225 292494	GALINA MAKAROVA	{"email": "makarova_g.09031962@postgrespro.ru", "phone": "+70113255194"}
0005434214753	11EEE9	7632 282649	ELENA KARPOVA	{"phone": "+70885232387"}
0005434214754	B5CA6D	9450 588551	NIKOLAY NAZAROV	{"email": "nnazarov21031970@postgrespro.ru", "phone": "+70177982400"}
0005434214755	865E04	6394 877641	NIKOLAY BORISOV	{"email": "borisov.n1974@postgrespro.ru", "phone": "+70437791271"}
0005434214756	865E04	1670 641439	MARIYA KISELEVA	{"phone": "+70697649758"}
0005434214757	865E04	1994 844538	YULIYA POTAPOVA	{"phone": "+70063537657"}
0005434214758	2883EA	9953 954597	EKATERINA KOROLEVA	{"phone": "+70917105642"}
0005434214759	2883EA	5408 349566	ROZA PETROVA	{"phone": "+70992208481"}
0005434214760	2883EA	1738 592723	LYUDMILA GAVRILOVA	{"email": "lyudmila_gavrilova_07031965@postgrespro.ru", "phone": "+70315878760"}
0005434214761	929BBB	7638 718660	DENIS MOROZOV	{"phone": "+70814819031"}
0005434214762	735FCC	3870 708240	SERGEY ABRAMOV	{"phone": "+70230124842"}
0005434214763	21BBF1	3640 456617	ELENA ALEKSEEVA	{"phone": "+70555479650"}
0005434214764	97527D	8013 076820	NIKOLAY KULIKOV	{"phone": "+70314612664"}
0005434214765	97527D	8865 093019	MARGARITA VASILEVA	{"email": "m_vasileva_1967@postgrespro.ru", "phone": "+70703444877"}
0005434214766	58B79B	6873 409531	ZHANNA NOVIKOVA	{"email": "novikova.zhanna14091975@postgrespro.ru", "phone": "+70800818054"}
0005434214767	EA72B5	6033 591236	VALENTINA TARASOVA	{"email": "valentina-tarasova01011967@postgrespro.ru", "phone": "+70536213655"}
0005434214768	EA72B5	5295 220965	NINA POLYAKOVA	{"phone": "+70491492503"}
0005434214769	D0036D	5754 245276	RUSTAM SEMENOV	{"email": "r-semenov-1973@postgrespro.ru", "phone": "+70059121538"}
0005434214770	8AC643	4904 816902	ALEFTINA NESTEROVA	{"phone": "+70408667170"}
0005434214771	4A82AE	9410 597857	KRISTINA BELOVA	{"email": "kristinabelova.081968@postgrespro.ru", "phone": "+70633919990"}
0005434214772	4A82AE	1552 095469	VASILIY SCHERBAKOV	{"email": "v-scherbakov071979@postgrespro.ru", "phone": "+70056133727"}
0005434214773	4A82AE	9652 104074	IGOR ROMANOV	{"email": "romanov.i.1978@postgrespro.ru", "phone": "+70169440495"}
0005434214774	4A82AE	6507 695064	VALENTINA NIKIFOROVA	{"phone": "+70538167820"}
0005434214775	1A9907	2835 351171	NATALYA PAVLOVA	{"email": "pavlova.natalya-011972@postgrespro.ru", "phone": "+70726235781"}
0005434214776	E714AD	4597 798565	EVGENIY KUZMIN	{"email": "kuzmin_evgeniy-1974@postgrespro.ru", "phone": "+70760153399"}
0005434214777	6B9B69	6723 085607	VADIM ILIN	{"email": "vadimilin_30101967@postgrespro.ru", "phone": "+70154114904"}
0005434214778	7FC646	3247 598075	PETR PETROV	{"email": "petrov.p_1972@postgrespro.ru", "phone": "+70344262708"}
0005434214779	D5031D	7909 773833	VIKTORIYA EGOROVA	{"phone": "+70683932808"}
0005434214780	D5031D	4875 007625	ZINAIDA TIKHONOVA	{"email": "zinaida_tikhonova22101958@postgrespro.ru", "phone": "+70218579375"}
0005434214781	1582B2	0030 908985	OLGA SEMENOVA	{"email": "osemenova04041976@postgrespro.ru", "phone": "+70082480705"}
0005434214782	1582B2	2543 907491	VIKTORIYA RODIONOVA	{"phone": "+70896983397"}
0005434214783	1582B2	6525 838305	ANDREY TARASOV	{"email": "tarasovandrey-101961@postgrespro.ru", "phone": "+70493927578"}
0005434214784	772BB7	4746 444485	VALENTIN NAZAROV	{"phone": "+70409108463"}
0005434214785	772BB7	5932 630484	ALEKSANDR GAVRILOV	{"email": "a.gavrilov14081964@postgrespro.ru", "phone": "+70885855418"}
0005434214786	772BB7	7571 828332	ALEKSEY STEPANOV	{"phone": "+70382447487"}
0005434214787	19E399	0001 687917	NATALYA KONDRATEVA	{"phone": "+70436096556"}
0005434214788	19E399	9010 218167	VALENTINA ZHUKOVA	{"email": "zhukovav.16121967@postgrespro.ru", "phone": "+70252763879"}
0005434214789	19E399	1463 064580	ALEKSEY KAZAKOV	{"phone": "+70048055025"}
0005434214790	B38E2A	3849 475542	ARTEM STEPANOV	{"phone": "+70213684802"}
0005434214791	B38E2A	8860 764301	ALEKSEY MIRONOV	{"email": "a_mironov-051979@postgrespro.ru", "phone": "+70949902772"}
0005434214792	B38E2A	1165 351817	ANDREY MAKAROV	{"email": "makarov-andrey_1983@postgrespro.ru", "phone": "+70705209283"}
0005434214793	2D15AF	6485 015526	TATYANA MAKAROVA	{"email": "tatyana_makarova_1987@postgrespro.ru", "phone": "+70098326345"}
0005434214794	AC93FD	4853 692971	VALERIY IVANOV	{"phone": "+70570699995"}
0005434214795	AC93FD	2236 660216	NADEZHDA MEDVEDEVA	{"email": "medvedeva.nadezhda-01051976@postgrespro.ru", "phone": "+70550079804"}
0005434214796	3CA0CD	6745 596626	TATYANA GERASIMOVA	{"phone": "+70636956853"}
0005434214797	688219	7232 425256	ANTON MAKSIMOV	{"email": "amaksimov-081975@postgrespro.ru", "phone": "+70143249725"}
0005434214798	688219	4618 008197	MARAT PETROV	{"email": "marat.petrov-1969@postgrespro.ru", "phone": "+70744608252"}
0005434214799	635663	6782 341300	YULIYA KOROLEVA	{"phone": "+70615255997"}
0005434214800	BC9FBB	2312 870119	DANIIL SEMENOV	{"email": "d_semenov-14021971@postgrespro.ru", "phone": "+70353979230"}
0005434214801	BC9FBB	9778 823801	ANNA KOZLOVA	{"phone": "+70509364639"}
0005434214802	BC9FBB	8556 395231	ASKHAT KOZLOV	{"email": "kozlov_a_1982@postgrespro.ru", "phone": "+70795693590"}
0005434214803	C7BD44	8932 136539	NINA DENISOVA	{"email": "denisova-n_1964@postgrespro.ru", "phone": "+70868303340"}
0005434214804	C7BD44	5718 545820	MIKHAIL KUDRYASHOV	{"phone": "+70692448322"}
0005434214805	17088C	9690 255303	LIDIYA EFREMOVA	{"phone": "+70018450672"}
0005434214806	2A4ABA	9019 767218	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrovaanastasiya_07081980@postgrespro.ru", "phone": "+70480911503"}
0005434214807	1189B4	6697 098298	LIDIYA TARASOVA	{"phone": "+70705638115"}
0005434214808	961FC6	4916 155112	NIKOLAY MIRONOV	{"email": "n-mironov-061974@postgrespro.ru", "phone": "+70021575086"}
0005434214809	A1737F	2593 663426	PETR MAKSIMOV	{"phone": "+70599038821"}
0005434214810	A1737F	5803 386015	MIKHAIL MELNIKOV	{"phone": "+70661139335"}
0005434214811	A1737F	8459 604439	YURIY SAVELEV	{"phone": "+70201353396"}
0005434214812	EF8677	6407 827618	ANTON IVANOV	{"email": "ivanov-anton-1980@postgrespro.ru", "phone": "+70604217710"}
0005434214813	FBE9C3	4450 576379	DMITRIY VASILEV	{"phone": "+70034843987"}
0005434214814	2A3225	7063 126876	VLADIMIR PETROV	{"email": "v_petrov07061968@postgrespro.ru", "phone": "+70934433657"}
0005434214815	9D7D75	9849 317443	TATYANA SAVELEVA	{"phone": "+70424448677"}
0005434214816	71B679	8983 080455	ALEKSANDR ORLOV	{"email": "orlov.a-101963@postgrespro.ru", "phone": "+70204332094"}
0005434214817	1BA7EA	7177 326388	VLADIMIR VOLKOV	{"phone": "+70987577640"}
0005434214818	1BA7EA	4072 771491	OKSANA KUDRYASHOVA	{"email": "kudryashova.oksana_1983@postgrespro.ru", "phone": "+70848135840"}
0005434214819	3B0C97	2665 661582	GERMAN ALEKSEEV	{"email": "galekseev-15071975@postgrespro.ru", "phone": "+70942838001"}
0005434214820	F5EEF7	0869 658790	ANASTASIYA GAVRILOVA	{"email": "gavrilova-anastasiya-16081970@postgrespro.ru", "phone": "+70928246830"}
0005434214821	8B2A95	5654 712620	ILMIRA PETROVA	{"email": "ilmira-petrova17041967@postgrespro.ru", "phone": "+70672771573"}
0005434214822	10A604	7003 355322	ALEKSANDR PETROV	{"phone": "+70268718284"}
0005434214823	10A604	4834 105877	VALENTINA NAZAROVA	{"email": "v-nazarova071962@postgrespro.ru", "phone": "+70712291203"}
0005434214824	6C693C	7972 437265	VALENTINA FOMINA	{"email": "valentina.fomina111973@postgrespro.ru", "phone": "+70485805619"}
0005434214825	2CD69B	3876 489140	TAMARA GRISHINA	{"email": "grishinatamara-18041966@postgrespro.ru", "phone": "+70009995858"}
0005434214826	892793	2518 126593	VALERIY SMIRNOV	{"email": "valeriy.smirnov.1967@postgrespro.ru", "phone": "+70328645423"}
0005434214827	892793	3893 120486	EVGENIY TARASOV	{"email": "tarasovevgeniy_16121967@postgrespro.ru", "phone": "+70735504522"}
0005434214828	68D3C2	0039 739391	ALEKSEY SHEVCHENKO	{"phone": "+70480652479"}
0005434214829	A754CC	7996 738500	IGOR KUZMIN	{"phone": "+70163815796"}
0005434214830	2A65C2	4540 231652	VIKTOR KARPOV	{"phone": "+70334325141"}
0005434214831	891449	2748 170859	MAKSIM ALEKSEEV	{"phone": "+70973566610"}
0005434214832	5F3231	0649 283566	YURIY ILIN	{"email": "yuriy-ilin.1960@postgrespro.ru", "phone": "+70352863655"}
0005434214833	4E563D	7472 801011	ANDREY MOROZOV	{"email": "amorozov.111966@postgrespro.ru", "phone": "+70887954111"}
0005434214834	4AC8DB	1230 504504	POLINA ZAKHAROVA	{"phone": "+70434999926"}
0005434214835	EDE292	6365 530126	NIKOLAY ISAEV	{"phone": "+70827813425"}
0005434215072	260500	9978 621125	ARTUR KOZLOV	{"phone": "+70742856009"}
0005434214836	EDE292	9984 811766	INNA DANILOVA	{"email": "inna-danilova1965@postgrespro.ru", "phone": "+70303658915"}
0005434214837	DEE02D	8526 300199	YURIY KISELEV	{"email": "kiselevyuriy.02011975@postgrespro.ru", "phone": "+70772666573"}
0005434214838	C6DC6C	8344 946071	ALEKSANDR SERGEEV	{"phone": "+70888866691"}
0005434214839	B379FC	4950 717887	FAINA KOMAROVA	{"email": "fainakomarova1976@postgrespro.ru", "phone": "+70509848290"}
0005434214840	A3FE98	1843 229875	SVETLANA ISAEVA	{"phone": "+70666429717"}
0005434214841	E63E32	1866 375271	VERONIKA EFREMOVA	{"email": "v_efremova-13121975@postgrespro.ru", "phone": "+70927097112"}
0005434214842	40C149	0256 955734	ANNA ZAKHAROVA	{"email": "zakharova_anna10051979@postgrespro.ru", "phone": "+70923127560"}
0005434214843	2979A4	9596 092258	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr-1968@postgrespro.ru", "phone": "+70341143604"}
0005434214844	F3B430	4776 181539	VYACHESLAV ZAYCEV	{"email": "zaycev.v_1973@postgrespro.ru", "phone": "+70163259433"}
0005434214845	315DD8	9172 244625	IGOR EGOROV	{"phone": "+70286571462"}
0005434214846	581EF7	1102 726481	VITALIY SIDOROV	{"phone": "+70876855627"}
0005434214847	CBEC7A	1683 950924	TATYANA LEBEDEVA	{"email": "tlebedeva.24061972@postgrespro.ru", "phone": "+70910551250"}
0005434214848	14CC0A	8856 621959	DENIS MARTYNOV	{"email": "martynov_d.1978@postgrespro.ru", "phone": "+70899075392"}
0005434214849	D45EDE	0512 093238	RAISA EFREMOVA	{"email": "raisa_efremova-1970@postgrespro.ru", "phone": "+70449283097"}
0005434214850	D45EDE	6401 676013	ARTEM MARTYNOV	{"email": "a.martynov.1974@postgrespro.ru", "phone": "+70781340697"}
0005434214851	57B5A9	7514 121434	KLAVDIYA SERGEEVA	{"email": "klavdiya-sergeeva.03061977@postgrespro.ru", "phone": "+70151774721"}
0005434214852	57B5A9	7234 499081	GERMAN MOISEEV	{"email": "moiseevg101979@postgrespro.ru", "phone": "+70846706245"}
0005434214853	17D0B2	1340 275866	ANASTASIYA KOMAROVA	{"email": "komarova.a15031980@postgrespro.ru", "phone": "+70201712010"}
0005434214854	6083CF	0421 246738	VIKTOR DENISOV	{"phone": "+70463393369"}
0005434214855	77F3B9	3677 236733	EVGENIY ISAEV	{"phone": "+70065433503"}
0005434214856	77F3B9	5419 220120	NIKOLAY VLASOV	{"phone": "+70400580007"}
0005434214857	9698AC	9286 918694	GALINA SOROKINA	{"email": "sorokina.galina_041968@postgrespro.ru", "phone": "+70871015914"}
0005434214858	C6C598	9501 937875	SHAMIL SEMENOV	{"phone": "+70346703789"}
0005434214859	C6C598	6286 548088	GALINA MELNIKOVA	{"phone": "+70102891238"}
0005434214860	4B8344	4185 057579	YULIYA KUZNECOVA	{"email": "kuznecova.y.011972@postgrespro.ru", "phone": "+70938643364"}
0005434214861	E09607	3625 902943	LYUDMILA MOROZOVA	{"email": "morozova_l.071969@postgrespro.ru", "phone": "+70349312650"}
0005434214862	BF6271	8345 274483	MAKSIM IVANOV	{"phone": "+70852915429"}
0005434214863	19F037	5754 143745	ELENA POPOVA	{"email": "e-popova_031979@postgrespro.ru", "phone": "+70131286926"}
0005434214864	819E4C	4989 567895	ARTEM POPOV	{"email": "popov_artem.14071987@postgrespro.ru", "phone": "+70672488711"}
0005434214865	819E4C	6985 412482	IGOR SERGEEV	{"email": "sergeev-i-1980@postgrespro.ru", "phone": "+70834577161"}
0005434214866	819E4C	1129 127598	ANATOLIY MAKAROV	{"email": "makarova1977@postgrespro.ru", "phone": "+70620728624"}
0005434214867	71AC85	6372 830695	NIKOLAY MATVEEV	{"phone": "+70135157166"}
0005434214868	534E4A	2081 678206	ROZA SEMENOVA	{"email": "semenova_r.061967@postgrespro.ru", "phone": "+70817817306"}
0005434214869	534E4A	4280 165086	FAINA SMIRNOVA	{"email": "smirnova.f121971@postgrespro.ru", "phone": "+70985975961"}
0005434214870	970C9E	3613 383883	TATYANA ZAYCEVA	{"email": "tatyana_zayceva_1969@postgrespro.ru", "phone": "+70177653228"}
0005434214871	C28328	0772 750564	SERGEY CHERNOV	{"phone": "+70328539375"}
0005434214872	C28328	0839 671354	SERGEY VLASOV	{"phone": "+70092313519"}
0005434214873	8CD9CF	1139 042570	PAVEL PAVLOV	{"email": "pavelpavlov1960@postgrespro.ru", "phone": "+70455274072"}
0005434214874	8CD9CF	2898 949421	ROSTISLAV KUZNECOV	{"phone": "+70388342089"}
0005434214875	B4CB11	7452 126129	VIKTOR VOLKOV	{"email": "v_volkov-1985@postgrespro.ru", "phone": "+70333556842"}
0005434214876	C8C30F	3751 867203	MARIYA ALEKSANDROVA	{"phone": "+70175808681"}
0005434214877	D09B38	2409 052756	MARIYA BARANOVA	{"phone": "+70120098193"}
0005434214878	275581	0960 696250	ALEKSEY SIDOROV	{"phone": "+70522482375"}
0005434214879	275581	3114 768478	TATYANA FROLOVA	{"phone": "+70391393256"}
0005434214880	83DD07	5104 179313	MIKHAIL BELOV	{"phone": "+70666974880"}
0005434214881	78EDED	2679 509633	ANASTASIYA CHERNOVA	{"email": "anastasiya.chernova-1962@postgrespro.ru", "phone": "+70595084727"}
0005434214882	077153	6916 524148	OLEG KAZAKOV	{"email": "kazakov_oleg-101966@postgrespro.ru", "phone": "+70875926650"}
0005434214883	077153	8549 708026	ALEKSANDR TIKHONOV	{"email": "a.tikhonov-31081985@postgrespro.ru", "phone": "+70472573692"}
0005434214884	D4C724	7346 205026	DMITRIY KISELEV	{"email": "kiselev-dmitriy_1971@postgrespro.ru", "phone": "+70153145865"}
0005434214885	D4C724	9529 296991	IRINA ROMANOVA	{"email": "romanova-irina18121978@postgrespro.ru", "phone": "+70441310056"}
0005434214886	8692CE	6343 614297	EVGENIY KULIKOV	{"phone": "+70876832815"}
0005434214887	8692CE	5555 226056	ILYA POPOV	{"phone": "+70532862629"}
0005434214888	89BC9C	2331 150028	ANNA SEMENOVA	{"phone": "+70822626069"}
0005434214889	3238DE	9824 849298	MIKHAIL PETROV	{"email": "petrov.mikhail_051968@postgrespro.ru", "phone": "+70313260169"}
0005434214890	465B44	8754 409930	YULIYA SAVELEVA	{"email": "yuliya_saveleva.051969@postgrespro.ru", "phone": "+70603954630"}
0005434214891	465B44	8831 689698	SERGEY NOVIKOV	{"phone": "+70701971728"}
0005434214892	7A8D5F	4166 014933	ELENA YUDINA	{"phone": "+70663547583"}
0005434214893	7A8D5F	5789 512735	LUIZA GUSEVA	{"phone": "+70395902421"}
0005434214894	9FBBCF	0021 704175	IRINA KUZNECOVA	{"email": "kuznecova-irina_111961@postgrespro.ru", "phone": "+70817065858"}
0005434214895	DF944E	7101 304700	IRINA NIKITINA	{"email": "irina.nikitina-1980@postgrespro.ru", "phone": "+70270439785"}
0005434214896	DF944E	6993 939349	VITALIY IVANOV	{"phone": "+70512357353"}
0005434214897	81C22C	6666 648177	NATALYA IVANOVA	{"phone": "+70961623359"}
0005434214898	9DEC78	1451 652180	VLADIMIR BELOV	{"email": "belov.vladimir_15011971@postgrespro.ru", "phone": "+70444229439"}
0005434214899	33498F	8395 140716	LYUBOV SIDOROVA	{"phone": "+70047722957"}
0005434214900	94B190	1132 893018	VIKTOR NIKOLAEV	{"phone": "+70142133055"}
0005434214901	4B73A1	9194 567869	SVETLANA IVANOVA	{"phone": "+70890117051"}
0005434214902	4B73A1	6733 923462	VASILIY ZAYCEV	{"email": "zaycev_v_10071985@postgrespro.ru", "phone": "+70371067685"}
0005434214903	D97FD7	9471 956071	ADELINA RYABOVA	{"phone": "+70949981472"}
0005434214904	D97FD7	0503 023860	VALENTINA VOLKOVA	{"email": "volkova-valentina-011975@postgrespro.ru", "phone": "+70493530381"}
0005434214905	93C38D	8483 884230	ALBINA BARANOVA	{"email": "abaranova_17051973@postgrespro.ru", "phone": "+70667469737"}
0005434214906	93C38D	4657 682928	NIKOLAY ZHUKOV	{"email": "nzhukov-25031968@postgrespro.ru", "phone": "+70631687859"}
0005434214907	28D362	9475 538495	YULIYA BARANOVA	{"email": "yuliya-baranova_06091974@postgrespro.ru", "phone": "+70690399593"}
0005434214908	437E7A	9832 226532	ANATOLIY PAVLOV	{"email": "anatoliy-pavlov-061975@postgrespro.ru", "phone": "+70760194935"}
0005434214909	393598	8522 543892	TATYANA NIKOLAEVA	{"phone": "+70596583208"}
0005434214910	8E22D7	8495 569243	EVGENIY VOLKOV	{"phone": "+70920667135"}
0005434214911	8E22D7	9766 718022	IRINA SIDOROVA	{"phone": "+70178232097"}
0005434214912	8E22D7	8270 986460	GALINA BOGDANOVA	{"email": "bogdanova_galina.041978@postgrespro.ru", "phone": "+70132339530"}
0005434214913	8480E8	4612 724570	EKATERINA VLASOVA	{"phone": "+70900362701"}
0005434214914	3F62E3	3755 056023	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr_23041977@postgrespro.ru", "phone": "+70061263058"}
0005434214915	1CF0FA	2686 568261	ALEKSANDRA KOZLOVA	{"phone": "+70285164389"}
0005434214916	6DF315	5884 691289	LIDIYA MOISEEVA	{"email": "moiseeval-011971@postgrespro.ru", "phone": "+70755726196"}
0005434214917	6DF315	6098 217038	IVAN IVANOV	{"phone": "+70740997396"}
0005434214918	C01ABC	0973 438730	NIKOLAY KARPOV	{"phone": "+70299722208"}
0005434214919	5E92E7	6467 918951	ALEKSANDR PETROV	{"email": "petrovaleksandr-121986@postgrespro.ru", "phone": "+70320315876"}
0005434214920	5E92E7	5631 182172	LEV SCHERBAKOV	{"phone": "+70304352650"}
0005434214921	3C7058	1118 227594	VALENTINA POPOVA	{"email": "popova.v031972@postgrespro.ru", "phone": "+70360344944"}
0005434214922	C880FF	4242 117714	VALENTINA VOROBEVA	{"email": "vorobeva.v.1974@postgrespro.ru", "phone": "+70056718376"}
0005434214923	C880FF	6631 184662	ANGELINA STEPANOVA	{"email": "stepanova_angelina-091985@postgrespro.ru", "phone": "+70620038744"}
0005434214924	FE107F	1016 476503	ALEKSANDR VOROBEV	{"phone": "+70799251184"}
0005434214925	A95EF0	1318 907371	VASILIY SOROKIN	{"email": "sorokin-v-08101977@postgrespro.ru", "phone": "+70909376242"}
0005434214926	21FDB3	7504 831649	ALEKSANDR EGOROV	{"email": "aegorov_24061966@postgrespro.ru", "phone": "+70586261461"}
0005434214927	DFB99A	6870 732190	ANNA SMIRNOVA	{"phone": "+70604188907"}
0005434214928	1626FC	5470 310955	RAISA KONDRATEVA	{"email": "kondrateva_raisa_1968@postgrespro.ru", "phone": "+70535208440"}
0005434214929	70FC0E	0092 760342	IVAN ZAYCEV	{"phone": "+70661019869"}
0005434214930	70FC0E	1415 560706	NADEZHDA BELYAEVA	{"email": "n.belyaeva-081965@postgrespro.ru", "phone": "+70367336505"}
0005434214931	6E7AE4	9474 464729	ALIYA BELOVA	{"email": "belova.a-1970@postgrespro.ru", "phone": "+70937089979"}
0005434214932	6E7AE4	6262 342088	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov_051975@postgrespro.ru", "phone": "+70417269271"}
0005434214933	6E7AE4	2016 207473	SERGEY SOKOLOV	{"phone": "+70267577266"}
0005434214934	544363	6266 607473	ALEKSEY KUZNECOV	{"phone": "+70921975311"}
0005434214935	544363	1545 007978	IGOR MIRONOV	{"email": "mironov-i.041970@postgrespro.ru", "phone": "+70400449485"}
0005434214936	544363	3198 175765	MARINA ARKHIPOVA	{"phone": "+70478988753"}
0005434214937	544363	7318 094115	SERGEY VOLKOV	{"phone": "+70585623587"}
0005434214938	B38D91	7108 677882	VALENTIN BONDARENKO	{"email": "bondarenko-v.1978@postgrespro.ru", "phone": "+70177397914"}
0005434214939	E6FDFB	0626 407006	ALEKSEY SAVELEV	{"phone": "+70694938216"}
0005434214940	61676E	4803 173414	EKATERINA ZHURAVLEVA	{"phone": "+70664317439"}
0005434214941	CBB855	9647 333371	LIDIYA KALININA	{"phone": "+70148731406"}
0005434214942	FF95E4	6081 706771	TATYANA POTAPOVA	{"phone": "+70646635755"}
0005434214943	FF95E4	2694 922129	OLGA ZAKHAROVA	{"email": "olgazakharova.1975@postgrespro.ru", "phone": "+70445273108"}
0005434214944	15AE4C	9883 651935	TIMOFEY SERGEEV	{"phone": "+70204265691"}
0005434214945	3D5781	3346 339002	SVETLANA TROFIMOVA	{"email": "svetlana_trofimova-17031968@postgrespro.ru", "phone": "+70123969241"}
0005434214946	3D5781	5736 743607	ANNA FOMINA	{"email": "anna_fomina-1974@postgrespro.ru", "phone": "+70046191185"}
0005434214947	2FAC4F	3385 229389	EVGENIY KUZNECOV	{"phone": "+70896773155"}
0005434214948	9C635B	0946 720833	VALERIY VASILEV	{"email": "valeriy_vasilev_1958@postgrespro.ru", "phone": "+70498600958"}
0005434214949	E07209	5081 941986	NATALYA ISAEVA	{"email": "n.isaeva_091980@postgrespro.ru", "phone": "+70052642999"}
0005434214950	4E5886	6190 405982	VERA ANDREEVA	{"email": "andreevavera1971@postgrespro.ru", "phone": "+70318026805"}
0005434214951	4E5886	7530 784378	DENIS SOKOLOV	{"phone": "+70273042679"}
0005434214952	F775C5	4049 617034	ROZA KONDRATEVA	{"email": "kondrateva-r.101972@postgrespro.ru", "phone": "+70145601191"}
0005434214953	F38AEE	5426 024557	EKATERINA EGOROVA	{"phone": "+70022792196"}
0005434214954	F38AEE	3193 167011	VLADIMIR BARANOV	{"phone": "+70083495626"}
0005434214955	F38AEE	8615 492522	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov-111975@postgrespro.ru", "phone": "+70829107521"}
0005434214956	A37E36	7223 811068	OLGA GORBUNOVA	{"email": "olga.gorbunova-1975@postgrespro.ru", "phone": "+70978957810"}
0005434214957	A37E36	1262 173047	ANASTASIYA LEBEDEVA	{"phone": "+70312249381"}
0005434214958	904532	1373 999550	LIDIYA MOROZOVA	{"email": "lidiyamorozova.041971@postgrespro.ru", "phone": "+70556340380"}
0005434214959	9D1212	6841 119337	DANIIL KISELEV	{"phone": "+70745380723"}
0005434214960	5D3CE5	1583 713136	SERGEY VASILEV	{"email": "vasilev-sergey06031975@postgrespro.ru", "phone": "+70972774568"}
0005434214961	5D3CE5	8636 994880	ANDREY SEMENOV	{"email": "andrey_semenov_1970@postgrespro.ru", "phone": "+70772725383"}
0005434214962	9928EC	6546 609143	ANTON DAVYDOV	{"email": "anton_davydov.15081979@postgrespro.ru", "phone": "+70451404453"}
0005434214963	B6C0D5	0040 000426	NATALYA FROLOVA	{"phone": "+70135835585"}
0005434214964	ABB273	2386 441045	ALENA MOROZOVA	{"email": "morozova_alena1977@postgrespro.ru", "phone": "+70837144369"}
0005434214965	3BBC3E	2286 972165	ANDREY ORLOV	{"phone": "+70596936838"}
0005434214966	947F32	5115 917361	TATYANA ZOTOVA	{"email": "tatyana.zotova_17121967@postgrespro.ru", "phone": "+70659820411"}
0005434214967	947F32	1387 490031	VALENTINA KONOVALOVA	{"phone": "+70586278668"}
0005434214968	3D9CB5	1659 481009	MIKHAIL SCHERBAKOV	{"phone": "+70394183180"}
0005434214969	BB29F7	8118 344532	NATALYA MASLOVA	{"phone": "+70490382786"}
0005434214970	BB29F7	4533 149626	STANISLAV ZAKHAROV	{"phone": "+70016806093"}
0005434214971	5D0CB9	2553 478515	LYUDMILA ZAKHAROVA	{"email": "zakharova_lyudmila_041966@postgrespro.ru", "phone": "+70319627636"}
0005434214972	AE0E13	9184 741781	MIKHAIL VASILEV	{"email": "vasilevmikhail-1974@postgrespro.ru", "phone": "+70104612930"}
0005434214973	AE0E13	3846 373801	IRINA GORBUNOVA	{"phone": "+70119737146"}
0005434214974	604307	5147 325559	ANASTASIYA TITOVA	{"phone": "+70740559443"}
0005434214975	604307	9273 761351	PAVEL MATVEEV	{"phone": "+70520217559"}
0005434214976	BD9E70	8018 884396	OLESYA EGOROVA	{"email": "olesya.egorova_111975@postgrespro.ru", "phone": "+70492294570"}
0005434214977	BD9E70	9652 664516	POLINA BELOVA	{"phone": "+70695038184"}
0005434214978	339068	1192 100272	YAROSLAV KUZNECOV	{"email": "y.kuznecov.051975@postgrespro.ru", "phone": "+70028970130"}
0005434214979	339068	2300 202564	MARINA FADEEVA	{"phone": "+70675050381"}
0005434214980	6A9104	3750 005197	VIKTOR KRASNOV	{"phone": "+70053188570"}
0005434214981	6A9104	8209 525977	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova.tamara24081968@postgrespro.ru", "phone": "+70045176171"}
0005434214982	36BEA0	3282 611106	VADIM KOROLEV	{"email": "vadim_korolev.19111962@postgrespro.ru", "phone": "+70748636849"}
0005434214983	0ADD82	0808 686429	YURIY SERGEEV	{"email": "yuriysergeev03101967@postgrespro.ru", "phone": "+70865225029"}
0005434214984	2950EC	1468 245118	VALERIY GORBUNOV	{"email": "valeriygorbunov.061983@postgrespro.ru", "phone": "+70911184934"}
0005434214985	2950EC	2667 819250	OLGA MOROZOVA	{"phone": "+70737220999"}
0005434214986	53FA61	6652 473985	DANILA SIDOROV	{"phone": "+70719050200"}
0005434214987	7708FB	8453 409249	EGOR FEDOROV	{"email": "e-fedorov.011973@postgrespro.ru", "phone": "+70515162843"}
0005434214988	7708FB	5219 912577	LYUDMILA KRASNOVA	{"email": "l_krasnova.13091962@postgrespro.ru", "phone": "+70404857567"}
0005434214989	4C34CA	7333 088303	ALEKSEY KISELEV	{"phone": "+70242211945"}
0005434214990	4C34CA	1697 680141	VALENTINA YUDINA	{"phone": "+70539065127"}
0005434214991	4C34CA	5712 839587	VADIM IVANOV	{"email": "ivanov_v_021970@postgrespro.ru", "phone": "+70165537541"}
0005434214992	B554A3	2473 678515	VYACHESLAV MOISEEV	{"phone": "+70466128639"}
0005434214993	D0BC25	9773 699721	NINA PETROVA	{"email": "nina_petrova_24081975@postgrespro.ru", "phone": "+70740719333"}
0005434214994	72A2B0	2245 370765	ANTONINA POPOVA	{"email": "antoninapopova-1972@postgrespro.ru", "phone": "+70320543226"}
0005434214995	72A2B0	9073 653186	LIDIYA MOISEEVA	{"phone": "+70452868023"}
0005434214996	D17DE6	7708 797468	YURIY ANTONOV	{"phone": "+70430800510"}
0005434214997	FF04BB	1067 069856	ELENA MIRONOVA	{"phone": "+70877570367"}
0005434214998	482707	5124 336476	DMITRIY MAKAROV	{"phone": "+70075374514"}
0005434214999	77FEEE	3724 158774	OLEG ROMANOV	{"email": "o-romanov-18051981@postgrespro.ru", "phone": "+70851022339"}
0005434215000	F9EAB0	5128 732475	NADEZHDA ZOTOVA	{"email": "zotova.n-1969@postgrespro.ru", "phone": "+70948523353"}
0005434215001	64FB39	2363 231318	ZOYA KUDRYASHOVA	{"email": "zoya.kudryashova02011981@postgrespro.ru", "phone": "+70859615812"}
0005434215002	821094	1530 989272	ALEKSANDR ANTONOV	{"phone": "+70504077641"}
0005434215003	98A0C9	8375 486358	NADEZHDA SOKOLOVA	{"phone": "+70254014330"}
0005434215004	AA8D6D	6956 659253	GALINA PETROVA	{"phone": "+70178465422"}
0005434215005	78C123	1973 006296	TATYANA ZHURAVLEVA	{"phone": "+70997782022"}
0005434215006	78C123	1833 348681	ALEKSEY KOZLOV	{"phone": "+70519608524"}
0005434215007	78C123	6883 259863	SERGEY VASILEV	{"email": "sergeyvasilev.02101975@postgrespro.ru", "phone": "+70560406959"}
0005434215008	2747D4	5427 979430	NIKITA GERASIMOV	{"phone": "+70065196429"}
0005434215009	2D07FC	0591 288808	EKATERINA ZAKHAROVA	{"email": "zakharova_e21031973@postgrespro.ru", "phone": "+70632131843"}
0005434215010	00EE1A	5084 337595	VLADISLAV DENISOV	{"email": "denisov_v_1977@postgrespro.ru", "phone": "+70813709610"}
0005434215011	81B629	7777 524699	TATYANA VASILEVA	{"email": "tatyana_vasileva_31011965@postgrespro.ru", "phone": "+70670344183"}
0005434215012	930E9D	6629 360066	ELIZAVETA ORLOVA	{"email": "orlovae_29101959@postgrespro.ru", "phone": "+70859866070"}
0005434215013	8E24E2	5554 298354	FARIT SIDOROV	{"email": "fsidorov-07051965@postgrespro.ru", "phone": "+70526911758"}
0005434215014	DC9A3E	3867 887750	SERGEY DMITRIEV	{"phone": "+70227187396"}
0005434215015	E5F195	8408 396943	DMITRIY GUSEV	{"email": "gusev.d.28121962@postgrespro.ru", "phone": "+70752348353"}
0005434215016	DE20F3	5248 625251	ARMEN MAKSIMOV	{"email": "armen_maksimov.1970@postgrespro.ru", "phone": "+70694691259"}
0005434215017	8DAE4D	8558 322427	ELVIRA NOVIKOVA	{"email": "elvira_novikova-1970@postgrespro.ru", "phone": "+70488135329"}
0005434215018	195E77	7009 042184	LARISA ZHURAVLEVA	{"email": "larisa-zhuravleva.021972@postgrespro.ru", "phone": "+70519177932"}
0005434215019	A2A8FE	0999 778546	MARINA VLASOVA	{"email": "vlasovamarina-03071966@postgrespro.ru", "phone": "+70928147036"}
0005434215020	3D5FDB	9256 094167	IRINA EFREMOVA	{"phone": "+70391640854"}
0005434215021	3D5FDB	4494 754209	OLGA KARPOVA	{"email": "o-karpova-1965@postgrespro.ru", "phone": "+70459926936"}
0005434215022	7552BF	3672 449851	YANA ZAYCEVA	{"email": "zaycevayana_1964@postgrespro.ru", "phone": "+70285217579"}
0005434215023	97CCF5	6240 741551	SVETLANA FEDOROVA	{"phone": "+70291648054"}
0005434215024	2FBE42	4669 044301	KARINA KISELEVA	{"phone": "+70453956132"}
0005434215025	2BE292	0286 857128	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov.1971@postgrespro.ru", "phone": "+70089142303"}
0005434215026	4806CE	2666 867822	ALENA SEMENOVA	{"email": "semenova_alena_31011972@postgrespro.ru", "phone": "+70475205481"}
0005434215027	34362B	3927 942528	ANDREY STEPANOV	{"phone": "+70455599631"}
0005434215028	7695A6	2699 152372	EGOR BONDARENKO	{"email": "egorbondarenko-07061970@postgrespro.ru", "phone": "+70345441064"}
0005434215029	49E45D	3620 162173	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov01041972@postgrespro.ru", "phone": "+70515588790"}
0005434215030	B6F709	1883 524880	VIKTOR DMITRIEV	{"phone": "+70105371745"}
0005434215031	E98FE0	6694 764289	ALEKSEY MOROZOV	{"phone": "+70976077102"}
0005434215032	E98FE0	8052 688639	OKSANA YUDINA	{"email": "oksana.yudina_101962@postgrespro.ru", "phone": "+70831967498"}
0005434215033	E98FE0	2525 002129	ALEKSANDR IVANOV	{"email": "ivanov_a03071972@postgrespro.ru", "phone": "+70148874323"}
0005434215034	61BA37	3797 229416	ALEKSEY SOKOLOV	{"phone": "+70978576355"}
0005434215035	4C7ED5	1505 776215	ANDREY ALEKSEEV	{"phone": "+70674592242"}
0005434215036	5D928C	4136 751230	VALENTINA CHERNOVA	{"email": "chernova_valentina.1971@postgrespro.ru", "phone": "+70245408445"}
0005434215037	5356BB	0473 945225	ALEKSANDR VASILEV	{"email": "a-vasilev.06101959@postgrespro.ru", "phone": "+70128018901"}
0005434215038	C5ED17	6127 459590	MARINA OVCHINNIKOVA	{"phone": "+70045784370"}
0005434215039	0EA892	7782 703788	YULIYA POPOVA	{"email": "ypopova_1965@postgrespro.ru", "phone": "+70764871718"}
0005434215040	0EA892	3226 266465	EKATERINA IVANOVA	{"phone": "+70797147720"}
0005434215041	0272BB	2163 016424	RIFAT SEMENOV	{"email": "semenov-r-1972@postgrespro.ru", "phone": "+70951504523"}
0005434215042	0272BB	4620 489834	SVETLANA MOISEEVA	{"phone": "+70093600518"}
0005434215043	CEBEF0	8645 236676	VLADIMIR NOVIKOV	{"phone": "+70601675565"}
0005434215044	B58DF3	9931 886074	OLGA MOISEEVA	{"phone": "+70869907598"}
0005434215045	09052F	4392 115678	NATALYA EFIMOVA	{"email": "n-efimova.041966@postgrespro.ru", "phone": "+70658903071"}
0005434215046	8EE560	8874 006876	GRIGORIY KUZMIN	{"email": "kuzmingrigoriy-101972@postgrespro.ru", "phone": "+70687191485"}
0005434215047	8EE560	2588 631376	ELENA KISELEVA	{"email": "kiselevaelena_1981@postgrespro.ru", "phone": "+70195684758"}
0005434215048	8EE560	3244 804990	ALLA SOKOLOVA	{"email": "sokolovaalla-121972@postgrespro.ru", "phone": "+70917774165"}
0005434215049	5A0BB6	4124 190083	VIKTOR VASILEV	{"email": "vasilev.viktor.1969@postgrespro.ru", "phone": "+70937133696"}
0005434215050	9DD092	8094 586246	DENIS TIMOFEEV	{"email": "timofeevdenis05041974@postgrespro.ru", "phone": "+70261681645"}
0005434215051	5C4CA2	8900 127730	IVAN MATVEEV	{"phone": "+70713612818"}
0005434215052	A0D9F8	5072 170767	EKATERINA CHERNOVA	{"email": "chernova.ekaterina20111981@postgrespro.ru", "phone": "+70515246246"}
0005434215053	1AB213	8446 315199	VLADIMIR FOMIN	{"email": "vladimir.fomin-1968@postgrespro.ru", "phone": "+70446590089"}
0005434215054	1AB213	0670 943033	ALEKSANDR PETROV	{"email": "apetrov-071971@postgrespro.ru", "phone": "+70164609249"}
0005434215055	070B92	7792 342898	YURIY BELOV	{"email": "ybelov-1968@postgrespro.ru", "phone": "+70253251242"}
0005434215056	070B92	7650 140300	ANZHELIKA GERASIMOVA	{"email": "anzhelika.gerasimova1967@postgrespro.ru", "phone": "+70072147312"}
0005434215057	B09221	2106 421787	NADEZHDA MAKAROVA	{"phone": "+70646961143"}
0005434215058	B09221	5498 804031	SERGEY GERASIMOV	{"email": "s.gerasimov_101968@postgrespro.ru", "phone": "+70622187864"}
0005434215059	B09221	9033 994539	NIKOLAY SOROKIN	{"email": "sorokin_n-1979@postgrespro.ru", "phone": "+70815299048"}
0005434215060	291D99	9706 856179	EKATERINA KOLESNIKOVA	{"email": "e_kolesnikova_01101957@postgrespro.ru", "phone": "+70590396338"}
0005434215061	ABB9E3	0876 970595	EVGENIYA ORLOVA	{"email": "evgeniya.orlova1968@postgrespro.ru", "phone": "+70331595486"}
0005434215062	5B1461	0596 798782	SERGEY KISELEV	{"email": "kiselev.s111970@postgrespro.ru", "phone": "+70467429417"}
0005434215063	5B1461	6652 440417	MARIYA KONDRATEVA	{"phone": "+70121410851"}
0005434215064	C6957D	8423 728113	TAMARA ANISIMOVA	{"email": "anisimova.tamara1972@postgrespro.ru", "phone": "+70667487988"}
0005434215065	BF6558	5792 099577	VALERIY STEPANOV	{"phone": "+70001494414"}
0005434215066	BDADC3	9106 568956	VASILIY BORISOV	{"email": "borisov_vasiliy_24011972@postgrespro.ru", "phone": "+70119467350"}
0005434215067	261F2D	2238 716185	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov22011972@postgrespro.ru", "phone": "+70611244087"}
0005434215068	E64E79	2529 369811	MIKHAIL ABRAMOV	{"phone": "+70516949991"}
0005434215069	C388F8	5206 607288	GALINA YAKOVLEVA	{"phone": "+70992376115"}
0005434215070	DC8CF3	8763 993245	YULIYA KUZNECOVA	{"email": "y-kuznecova_011959@postgrespro.ru", "phone": "+70212136747"}
0005434215071	1498FE	1880 974252	OLGA VASILEVA	{"email": "olga_vasileva_121964@postgrespro.ru", "phone": "+70696476944"}
0005434215074	84B980	1770 568878	DMITRIY GERASIMOV	{"phone": "+70043379734"}
0005434215075	36FD38	6549 744830	ANDREY MIRONOV	{"phone": "+70743072773"}
0005434215076	BD348A	1113 358265	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr-22071976@postgrespro.ru", "phone": "+70120661200"}
0005434215077	BD348A	3557 366559	VALENTINA ALEKSEEVA	{"phone": "+70051228498"}
0005434215078	017ED8	4152 400755	KONSTANTIN KULIKOV	{"phone": "+70808376111"}
0005434215079	017ED8	0154 188717	NIKOLAY KUZNECOV	{"phone": "+70445675959"}
0005434215080	017ED8	3862 873627	ALEKSANDR FROLOV	{"email": "aleksandr.frolov.111975@postgrespro.ru", "phone": "+70724062800"}
0005434215081	9451AD	0361 334863	MARIYA KONOVALOVA	{"phone": "+70646156417"}
0005434215082	F765E1	5972 347010	ELENA MARTYNOVA	{"email": "e_martynova_1974@postgrespro.ru", "phone": "+70966581913"}
0005434215083	B5B7C4	7744 579153	ALEKSANDR BONDARENKO	{"email": "a-bondarenko19061964@postgrespro.ru", "phone": "+70989565683"}
0005434215084	B5B7C4	4777 620740	LARISA KISELEVA	{"phone": "+70154977509"}
0005434215085	324879	5251 103726	VIKTOR TIKHONOV	{"phone": "+70312118922"}
0005434215086	51F724	5651 310888	ANASTASIYA STEPANOVA	{"phone": "+70467221165"}
0005434215087	1A6D38	0156 404641	ALEKSANDR SIDOROV	{"email": "a.sidorov_1977@postgrespro.ru", "phone": "+70921256360"}
0005434215088	FA3174	3440 672985	ANGELINA ALEKSANDROVA	{"phone": "+70507163380"}
0005434215089	B56D92	6110 597379	VALENTINA NIKITINA	{"email": "nikitina_valentina.061957@postgrespro.ru", "phone": "+70472562414"}
0005434215090	AFC0C5	1113 174369	VLADISLAV SEMENOV	{"email": "semenov.vladislav_26051969@postgrespro.ru", "phone": "+70508939314"}
0005434215091	C2E8FE	3169 606842	VLADIMIR MAKSIMOV	{"phone": "+70260333949"}
0005434215092	C2E8FE	4398 176487	DMITRIY KONOVALOV	{"phone": "+70406038160"}
0005434215093	A6CEE2	1022 361690	LYUBOV TIKHONOVA	{"email": "l_tikhonova.21121964@postgrespro.ru", "phone": "+70592403265"}
0005434215094	A6CEE2	9914 107824	EVGENIY ZAKHAROV	{"email": "e_zakharov02081969@postgrespro.ru", "phone": "+70204745849"}
0005434215095	F2B463	6276 491573	GEORGIY TARASOV	{"email": "g.tarasov03111972@postgrespro.ru", "phone": "+70386690930"}
0005434215096	AB33CC	5034 164396	SERGEY DMITRIEV	{"email": "s_dmitriev_011976@postgrespro.ru", "phone": "+70077978810"}
0005434215097	CCAB68	6618 363871	YULIYA KOZLOVA	{"phone": "+70574229010"}
0005434215098	A7BA2A	8945 430371	VIKTOR BARANOV	{"email": "vbaranov.031965@postgrespro.ru", "phone": "+70031258778"}
0005434215099	86A6BC	4220 447858	SERGEY KONOVALOV	{"email": "s_konovalov17061969@postgrespro.ru", "phone": "+70365946112"}
0005434215100	4757AC	9204 930209	RAISA NESTEROVA	{"email": "rnesterova-101980@postgrespro.ru", "phone": "+70975655863"}
0005434215101	026821	1751 821335	OKSANA GERASIMOVA	{"phone": "+70436510275"}
0005434215102	026821	3961 612216	ANATOLIY POPOV	{"email": "popov_anatoliy1983@postgrespro.ru", "phone": "+70573779334"}
0005434215103	026821	6683 487874	MARIYA CHERNOVA	{"phone": "+70078433669"}
0005434215104	DD074C	0524 977558	RUSLAN BORISOV	{"email": "ruslanborisov1984@postgrespro.ru", "phone": "+70060753772"}
0005434215105	91DD5E	6624 916906	LYUBOV OVCHINNIKOVA	{"email": "l_ovchinnikova1991@postgrespro.ru", "phone": "+70344809638"}
0005434215106	F8E671	5188 423334	ALEKSEY NAZAROV	{"email": "alekseynazarov.1975@postgrespro.ru", "phone": "+70377766471"}
0005434215107	E9BAB3	1130 740117	ANNA FEDOROVA	{"phone": "+70078560418"}
0005434215108	7F9421	1629 619669	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova1961@postgrespro.ru", "phone": "+70916881376"}
0005434215109	7E9B2E	9794 130146	VARVARA KUZMINA	{"phone": "+70121324995"}
0005434215110	DAB188	1938 633469	ALEKSEY KUZNECOV	{"phone": "+70273969186"}
0005434215111	DAB188	9252 572998	VIKTORIYA SEMENOVA	{"email": "semenovav_031967@postgrespro.ru", "phone": "+70153800687"}
0005434215112	DFF6D5	2420 252728	POLINA YAKOVLEVA	{"email": "yakovleva-p.011976@postgrespro.ru", "phone": "+70306495436"}
0005434215113	DFF6D5	1442 395713	VASILIY SEMENOV	{"email": "v_semenov11051970@postgrespro.ru", "phone": "+70474348244"}
0005434215114	DFF6D5	1208 202810	ELENA OSIPOVA	{"email": "osipova_e-07071971@postgrespro.ru", "phone": "+70962172251"}
0005434215115	7A81E2	4215 065794	RIMMA IVANOVA	{"email": "rimma-ivanova.081976@postgrespro.ru", "phone": "+70925345465"}
0005434215116	529644	2227 259642	VIKTOR KUDRYASHOV	{"phone": "+70134820039"}
0005434215117	529644	6202 281365	DMITRIY POPOV	{"phone": "+70120028778"}
0005434215118	B9B700	7890 072686	DAVID ABRAMOV	{"phone": "+70534579212"}
0005434215119	3E47D9	1540 057216	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov-011969@postgrespro.ru", "phone": "+70839386684"}
0005434215120	437CD4	9737 030613	MILANA VOLKOVA	{"email": "milana_volkova1976@postgrespro.ru", "phone": "+70426399568"}
0005434215121	7481AE	9025 611963	ALEKSEY IVANOV	{"email": "aleksey.ivanov.1973@postgrespro.ru", "phone": "+70455254881"}
0005434215122	7481AE	0760 485091	DANIL SIDOROV	{"phone": "+70352927631"}
0005434215123	E3E2D3	5637 354737	EKATERINA NIKIFOROVA	{"email": "ekaterina.nikiforova1973@postgrespro.ru", "phone": "+70459549256"}
0005434215124	CD0B6F	7080 817752	KRISTINA KARPOVA	{"phone": "+70122163470"}
0005434215125	CD0B6F	0087 372000	VYACHESLAV BORISOV	{"email": "borisov.v.111971@postgrespro.ru", "phone": "+70880088775"}
0005434215126	6627C7	4074 771906	ILDAR VOROBEV	{"email": "vorobev_ildar_1971@postgrespro.ru", "phone": "+70698794701"}
0005434215127	6627C7	8686 563945	MATVEY MAKAROV	{"email": "makarov.m-1961@postgrespro.ru", "phone": "+70559453508"}
0005434215128	5B2ACE	7879 622971	ALEKSANDR POPOV	{"phone": "+70216495762"}
0005434215129	9894C4	1577 931803	VENERA SOROKINA	{"email": "v.sorokina021972@postgrespro.ru", "phone": "+70035450837"}
0005434215130	57DE6D	9590 862877	TAGIR ORLOV	{"phone": "+70883314272"}
0005434215131	46745F	9567 678411	NIKOLAY MOROZOV	{"email": "morozov_n_1973@postgrespro.ru", "phone": "+70354627269"}
0005434215132	C49DC9	8745 848204	VIKTORIYA ALEKSEEVA	{"email": "alekseevav_061982@postgrespro.ru", "phone": "+70180788907"}
0005434215133	CFB0A4	6795 421000	YULIYA TROFIMOVA	{"email": "yuliya.trofimova-121977@postgrespro.ru", "phone": "+70913314154"}
0005434215134	CFB0A4	2143 507228	TATYANA KISELEVA	{"email": "kiseleva.t-051974@postgrespro.ru", "phone": "+70418102593"}
0005434215135	C8343A	2968 804354	PAVEL PETROV	{"phone": "+70929606168"}
0005434215136	97D0F0	6559 947238	ELENA KUZMINA	{"phone": "+70582359774"}
0005434215137	49A2F4	6489 725305	DARYA ZOTOVA	{"phone": "+70089575671"}
0005434215138	49A2F4	2468 598312	NINA VLASOVA	{"phone": "+70303729134"}
0005434215139	49A2F4	5002 952011	ILDAR ABRAMOV	{"phone": "+70295859776"}
0005434215140	57E9ED	6229 451657	IGOR BORISOV	{"email": "borisovigor.09021969@postgrespro.ru", "phone": "+70804032812"}
0005434215141	57E9ED	2754 044692	LIDIYA ZHUKOVA	{"email": "lidiya_zhukova_1969@postgrespro.ru", "phone": "+70788933886"}
0005434215142	95BCDF	3437 544632	LARISA MAKAROVA	{"email": "makarova.larisa-031975@postgrespro.ru", "phone": "+70418479623"}
0005434215143	9529B8	7776 311343	NIKOLAY PETROV	{"phone": "+70034592644"}
0005434215144	741166	6567 760256	MARGARITA MELNIKOVA	{"phone": "+70746681891"}
0005434215145	A77C5C	3993 127281	ALEKSANDR VOLKOV	{"phone": "+70675512812"}
0005434215146	EC2ACF	5306 206158	VASILIY KARPOV	{"phone": "+70422991501"}
0005434215147	EC2ACF	9499 007311	DANILA GUSEV	{"email": "d-gusev-14101973@postgrespro.ru", "phone": "+70358310274"}
0005434215148	10B889	7815 521603	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov_16061974@postgrespro.ru", "phone": "+70973857103"}
0005434215149	348001	3327 561192	MARINA ANTONOVA	{"phone": "+70616923729"}
0005434215150	348001	2504 704348	SVETLANA IVANOVA	{"email": "svetlana.ivanova.111967@postgrespro.ru", "phone": "+70701801417"}
0005434215151	6D4DB9	0755 639175	KARINA SERGEEVA	{"phone": "+70306093168"}
0005434215152	6D4DB9	2159 598974	ALEKSANDR PAVLOV	{"phone": "+70348340810"}
0005434215153	C42F2E	6895 227598	MIKHAIL NAUMOV	{"phone": "+70770945560"}
0005434215154	C42F2E	9903 522258	TIMOFEY TARASOV	{"email": "timofeytarasov1969@postgrespro.ru", "phone": "+70443560937"}
0005434215155	FE54C5	9331 838246	VALERIY CHERNOV	{"email": "chernov-valeriy-021972@postgrespro.ru", "phone": "+70830752298"}
0005434215156	11077D	7197 400967	SERGEY KOZLOV	{"phone": "+70308184928"}
0005434215157	11077D	6236 872757	LARISA SCHERBAKOVA	{"email": "scherbakoval101976@postgrespro.ru", "phone": "+70397598481"}
0005434215158	53A821	8195 488408	YULIYA KALININA	{"email": "kalinina.yuliya_121982@postgrespro.ru", "phone": "+70708442371"}
0005434215159	53A821	6148 479264	NIKOLAY VASILEV	{"email": "vasilev_n-26111966@postgrespro.ru", "phone": "+70850663713"}
0005434215160	54BF3A	1530 478956	VALERIY BORISOV	{"email": "valeriy_borisov_13051964@postgrespro.ru", "phone": "+70812019765"}
0005434215161	54BF3A	9371 048461	ALBINA MARTYNOVA	{"email": "albina_martynova_1974@postgrespro.ru", "phone": "+70412480860"}
0005434215162	54BF3A	2319 861233	ELENA VLASOVA	{"phone": "+70897091845"}
0005434215163	3DC6AF	8159 370410	BORIS SERGEEV	{"email": "b.sergeev.1974@postgrespro.ru", "phone": "+70166914198"}
0005434215164	D7C6CC	5894 252967	ELENA KOROLEVA	{"email": "e_koroleva.1971@postgrespro.ru", "phone": "+70396345270"}
0005434215165	AED736	6495 810337	ALEKSANDR MATVEEV	{"email": "matveevaleksandr031966@postgrespro.ru", "phone": "+70504227282"}
0005434215166	ABC164	4969 874717	YULIYA VASILEVA	{"phone": "+70843254726"}
0005434215167	BE8B6B	9655 155226	SVETLANA NOVIKOVA	{"email": "novikova_s.1974@postgrespro.ru", "phone": "+70637135324"}
0005434215168	104C0B	3533 722377	NADEZHDA ERMAKOVA	{"phone": "+70222788152"}
0005434215169	B905A2	8223 803788	OLGA ZOTOVA	{"email": "o_zotova1986@postgrespro.ru", "phone": "+70835003567"}
0005434215170	B94DBA	5822 359867	ARINA POPOVA	{"email": "popova-a13051978@postgrespro.ru", "phone": "+70001186921"}
0005434215171	B94DBA	0616 650250	ILYA SERGEEV	{"phone": "+70820373330"}
0005434215172	344A37	7911 786029	YAKOV NIKOLAEV	{"email": "nikolaev.yakov_1975@postgrespro.ru", "phone": "+70528095701"}
0005434215173	69B2BE	5698 760189	VALERIY MAKAROV	{"email": "makarov.valeriy-121972@postgrespro.ru", "phone": "+70043633638"}
0005434215174	B83E8E	7494 920107	LARISA KUZNECOVA	{"email": "lkuznecova-1976@postgrespro.ru", "phone": "+70127555952"}
0005434215175	5C48F3	9301 284014	NIKITA SERGEEV	{"phone": "+70712521471"}
0005434215176	536587	5180 224914	STANISLAV NIKITIN	{"email": "nikitin-stanislav.041982@postgrespro.ru", "phone": "+70835331928"}
0005434215177	536587	6596 686587	ANATOLIY MELNIKOV	{"phone": "+70848666927"}
0005434215178	E8FD45	7413 707921	OLEG STEPANOV	{"phone": "+70099427904"}
0005434215179	555C86	8911 634425	PRASKOVYA NIKITINA	{"email": "nikitina-praskovya1976@postgrespro.ru", "phone": "+70365538725"}
0005434215180	555C86	2470 160684	TATYANA BELYAEVA	{"phone": "+70472763575"}
0005434215181	131893	1945 349687	DMITRIY IVANOV	{"email": "dmitriy_ivanov031984@postgrespro.ru", "phone": "+70349118848"}
0005434215182	87C2C8	9319 659594	PAVEL IVANOV	{"email": "pivanov.13051975@postgrespro.ru", "phone": "+70563527127"}
0005434215183	87C2C8	0812 300198	ANTONINA FROLOVA	{"email": "antoninafrolova_1967@postgrespro.ru", "phone": "+70354129901"}
0005434215184	ECCE28	6551 951901	ALEKSANDRA GERASIMOVA	{"phone": "+70018351290"}
0005434215185	A728D9	3755 644039	NINA IVANOVA	{"email": "nina_ivanova.24091965@postgrespro.ru", "phone": "+70207230096"}
0005434215186	C1C7E1	0704 369126	KRISTINA RYABOVA	{"phone": "+70534427639"}
0005434215187	5A00AD	5451 113239	ROZA BOGDANOVA	{"phone": "+70467777459"}
0005434215188	5A00AD	5038 426254	OLGA TIKHONOVA	{"email": "tikhonova.o_1976@postgrespro.ru", "phone": "+70718199818"}
0005434215189	5A00AD	8455 726338	DMITRIY BORISOV	{"email": "borisovdmitriy.1975@postgrespro.ru", "phone": "+70461981192"}
0005434215190	2A02E3	8470 663508	SERGEY ILIN	{"email": "ilin-sergey.031978@postgrespro.ru", "phone": "+70968083472"}
0005434215191	3646DF	5819 871993	GENNADIY SERGEEV	{"phone": "+70674701393"}
0005434215192	8E8E21	4220 617198	LYUBOV SOKOLOVA	{"email": "l-sokolova1966@postgrespro.ru", "phone": "+70074076910"}
0005434215193	8E8E21	7927 580808	YULIYA OVCHINNIKOVA	{"phone": "+70633949458"}
0005434215194	8E8E21	3100 833683	TATYANA KOVALEVA	{"email": "tatyana_kovaleva.01121970@postgrespro.ru", "phone": "+70580836988"}
0005434215195	8E8E21	6899 503297	ANTONINA NIKITINA	{"phone": "+70361887606"}
0005434215196	BB8210	9720 654086	EVGENIY VOLKOV	{"phone": "+70579138945"}
0005434215197	BB8210	3504 731074	TATYANA KARPOVA	{"email": "t.karpova-01021985@postgrespro.ru", "phone": "+70655036753"}
0005434215198	C94F95	8506 327340	DMITRIY GUSEV	{"phone": "+70413288703"}
0005434215199	44DDE8	4991 133724	VALENTINA FILATOVA	{"email": "filatova_valentina1977@postgrespro.ru", "phone": "+70818127785"}
0005434215200	860CCC	7136 879700	SERGEY DMITRIEV	{"email": "s-dmitriev041964@postgrespro.ru", "phone": "+70023672069"}
0005434215201	860CCC	9606 694001	ELENA EGOROVA	{"email": "elenaegorova1967@postgrespro.ru", "phone": "+70904240064"}
0005434215202	FDAE3D	0847 135085	DENIS GERASIMOV	{"email": "gerasimov.d.24081974@postgrespro.ru", "phone": "+70159673941"}
0005434215203	A2C12B	1503 857234	OKSANA FROLOVA	{"email": "ofrolova_15051977@postgrespro.ru", "phone": "+70891432865"}
0005434215204	F31BAD	5979 337787	ANNA FEDOROVA	{"email": "fedorova_anna-1980@postgrespro.ru", "phone": "+70256663033"}
0005434215205	670727	8959 392104	VALERIY NIKOLAEV	{"email": "v.nikolaev_04101967@postgrespro.ru", "phone": "+70242691642"}
0005434215206	A0F443	4643 811839	NIKOLAY EGOROV	{"phone": "+70218938549"}
0005434215207	A0F443	2426 176732	VIKTOR ANDREEV	{"email": "v_andreev-12061956@postgrespro.ru", "phone": "+70668153492"}
0005434215208	612B77	5459 268035	SVETLANA PETROVA	{"email": "petrova-svetlana-121972@postgrespro.ru", "phone": "+70462898502"}
0005434215209	7A163F	5454 685879	ANNA SERGEEVA	{"phone": "+70879710156"}
0005434215210	7A163F	1821 318152	MAKSIM PETROV	{"email": "petrov-maksim07101967@postgrespro.ru", "phone": "+70778243234"}
0005434215211	F48396	7614 784931	MARINA ANISIMOVA	{"email": "m-anisimova_1963@postgrespro.ru", "phone": "+70326596271"}
0005434215212	F9CDD0	3096 606217	ANDREY CHERNOV	{"phone": "+70423382590"}
0005434215213	2E038D	9803 892000	LARISA ORLOVA	{"phone": "+70840498332"}
0005434215214	25D057	6653 361209	OLGA EFREMOVA	{"email": "oefremova041968@postgrespro.ru", "phone": "+70212601106"}
0005434215215	3E6A03	7758 159193	DMITRIY NOVIKOV	{"phone": "+70860354088"}
0005434215216	3E6A03	0672 996539	NIKITA AFANASEV	{"email": "afanasev_n14051969@postgrespro.ru", "phone": "+70992522679"}
0005434215217	3E6A03	8847 757353	ANNA MOROZOVA	{"email": "annamorozova.1965@postgrespro.ru", "phone": "+70184813730"}
0005434215218	E00830	4967 211613	VLADIMIR VOROBEV	{"email": "vladimir_vorobev1981@postgrespro.ru", "phone": "+70147796826"}
0005434215219	ECA349	2689 786690	VALENTINA TARASOVA	{"email": "tarasova_valentina_06051973@postgrespro.ru", "phone": "+70686101643"}
0005434215220	ECA349	9955 490759	VIKTOR TIMOFEEV	{"email": "timofeev_viktor.16041976@postgrespro.ru", "phone": "+70952856999"}
0005434215221	ECA349	1513 945379	IRINA KOROLEVA	{"phone": "+70909433034"}
0005434215222	D2DBCF	2566 050807	MARGARITA SMIRNOVA	{"phone": "+70028452858"}
0005434215223	B4C759	3151 431809	ALEKSANDRA ZAKHAROVA	{"phone": "+70861012093"}
0005434215224	B4C759	5873 768850	SERGEY SIDOROV	{"phone": "+70567169482"}
0005434215225	B4C759	3282 973723	LYUBOV ISAEVA	{"phone": "+70176086345"}
0005434215226	7C4F9F	5593 782387	VIKTORIYA KOVALEVA	{"email": "v_kovaleva-17011973@postgrespro.ru", "phone": "+70515273319"}
0005434215227	7C4F9F	5023 877126	TATYANA RODIONOVA	{"phone": "+70545867038"}
0005434215228	E095C5	6947 416565	SVETLANA DAVYDOVA	{"email": "davydova-s.101975@postgrespro.ru", "phone": "+70281154425"}
0005434215229	530A0B	0043 888166	VALENTINA KONDRATEVA	{"email": "v.kondrateva_031983@postgrespro.ru", "phone": "+70640590674"}
0005434215230	FEF285	8907 455456	LYUDMILA VOLKOVA	{"email": "l-volkova_1960@postgrespro.ru", "phone": "+70768522887"}
0005434215231	FEF285	8763 077026	IRINA NIKOLAEVA	{"email": "i.nikolaeva051962@postgrespro.ru", "phone": "+70073107278"}
0005434215232	FEF285	9143 940878	ANZHELA ARKHIPOVA	{"phone": "+70057986233"}
0005434215233	FEF285	4838 404284	IVAN OSIPOV	{"email": "osipov_ivan.23021977@postgrespro.ru", "phone": "+70359310409"}
0005434215234	F19B9D	1207 694624	SVETLANA NOVIKOVA	{"email": "svetlana_novikova_1971@postgrespro.ru", "phone": "+70414581522"}
0005434215235	457243	6394 041094	EKATERINA BORISOVA	{"phone": "+70558343452"}
0005434215236	866EF8	1784 491687	PETR SIDOROV	{"email": "p.sidorov-031977@postgrespro.ru", "phone": "+70262581287"}
0005434215237	866EF8	2345 189876	ALSU SMIRNOVA	{"email": "alsu.smirnova.23051972@postgrespro.ru", "phone": "+70481875479"}
0005434215238	5636DB	7844 432030	IRINA ORLOVA	{"email": "orlovairina_021978@postgrespro.ru", "phone": "+70478263866"}
0005434215239	97D971	8770 951854	SERGEY KUZMIN	{"phone": "+70713340555"}
0005434215240	DBE7F2	3514 638795	ANASTASIYA ABRAMOVA	{"phone": "+70425357922"}
0005434215241	DBE7F2	3930 184528	NADEZHDA DENISOVA	{"email": "denisova_nadezhda1970@postgrespro.ru", "phone": "+70631246905"}
0005434215242	DBE7F2	8035 899949	IRINA VOLKOVA	{"phone": "+70542682774"}
0005434215243	59BDAC	0744 405517	EKATERINA KUZNECOVA	{"phone": "+70391276211"}
0005434215244	FAE3E6	0629 187694	ILSHAT GRIGOREV	{"email": "i_grigorev1966@postgrespro.ru", "phone": "+70101643850"}
0005434215245	1BA197	5424 759500	ALEKSEY AFANASEV	{"phone": "+70548273803"}
0005434215246	A205FA	6027 675720	MARIYA MELNIKOVA	{"email": "melnikovam_081968@postgrespro.ru", "phone": "+70991978908"}
0005434215247	A205FA	7396 403647	VLADIMIR ANTONOV	{"email": "v_antonov-1971@postgrespro.ru", "phone": "+70536550295"}
0005434215248	A205FA	7808 029065	ALEKSANDR ROMANOV	{"phone": "+70429217241"}
0005434215249	40C22C	7858 813928	MAKSIM FEDOTOV	{"email": "fedotov_m.1980@postgrespro.ru", "phone": "+70392805973"}
0005434215250	BA8C48	3848 606098	ELENA FILIPPOVA	{"phone": "+70027442393"}
0005434215251	D72DF2	7480 809476	ELENA KONOVALOVA	{"phone": "+70052850674"}
0005434215252	D72DF2	5723 946474	ANDREY MARTYNOV	{"phone": "+70739973953"}
0005434215253	D72DF2	7330 907146	GENNADIY ZHURAVLEV	{"phone": "+70736007377"}
0005434215254	7CFBAA	6517 574838	TATYANA MOROZOVA	{"email": "tatyana-morozova11081963@postgrespro.ru", "phone": "+70011793525"}
0005434215255	198183	1715 935542	TATYANA KRASNOVA	{"phone": "+70330877419"}
0005434215256	3D988D	7061 504323	VALENTINA ROMANOVA	{"email": "v-romanova031967@postgrespro.ru", "phone": "+70324845949"}
0005434215257	3D988D	6679 378447	VERA ABRAMOVA	{"phone": "+70297245703"}
0005434215258	454AAE	5803 510717	MIKHAIL SHEVCHENKO	{"email": "m-shevchenko-051976@postgrespro.ru", "phone": "+70161007112"}
0005434215259	454AAE	3227 845281	TATYANA ZOTOVA	{"phone": "+70518379567"}
0005434215260	2852B4	7136 723079	IGOR SIDOROV	{"email": "sidorov-igor-051969@postgrespro.ru", "phone": "+70749274068"}
0005434215261	F5501A	9317 612212	IRINA NIKITINA	{"phone": "+70561345348"}
0005434215262	B595C4	6914 270320	MARGARITA KUZNECOVA	{"email": "kuznecova.margarita_1959@postgrespro.ru", "phone": "+70346232960"}
0005434215263	B595C4	4913 241318	MARINA POPOVA	{"phone": "+70100031962"}
0005434215264	681159	3128 364239	MARINA BARANOVA	{"phone": "+70423574334"}
0005434215265	EBC2F9	7679 733458	VASILIY MELNIKOV	{"phone": "+70614637574"}
0005434215266	B23E50	5262 353258	YULIYA VLASOVA	{"phone": "+70418727585"}
0005434215267	D8F2F9	0084 724772	IVAN STEPANOV	{"email": "i-stepanov-12011973@postgrespro.ru", "phone": "+70027243787"}
0005434215268	208AF1	1434 506751	EKATERINA ANDREEVA	{"email": "andreeva.ekaterina.16121970@postgrespro.ru", "phone": "+70229008857"}
0005434215269	E451F7	4171 996407	VLADIMIR KUZMIN	{"email": "v-kuzmin1976@postgrespro.ru", "phone": "+70338017601"}
0005434215270	E451F7	6239 228134	ALEKSEY NIKITIN	{"phone": "+70190334209"}
0005434215271	62CB94	0964 067239	SERGEY KRASNOV	{"email": "s_krasnov_09051973@postgrespro.ru", "phone": "+70374279295"}
0005434215272	62CB94	3308 174869	EMMA VASILEVA	{"phone": "+70488312325"}
0005434215273	FEBBE2	7522 991590	ANDREY MIKHAYLOV	{"phone": "+70281791367"}
0005434215274	FEBBE2	8143 515131	EVGENIYA YUDINA	{"email": "e.yudina-011972@postgrespro.ru", "phone": "+70919474863"}
0005434215275	858358	6773 164553	VIOLETTA POTAPOVA	{"phone": "+70566112744"}
0005434215276	316290	9886 120902	YURIY MATVEEV	{"email": "yuriymatveev25051978@postgrespro.ru", "phone": "+70604103640"}
0005434215277	735B77	7303 636709	NADEZHDA EGOROVA	{"email": "egorovan_081974@postgrespro.ru", "phone": "+70786048143"}
0005434215278	735B77	2863 685710	NATALYA KOLESNIKOVA	{"email": "kolesnikova-n011958@postgrespro.ru", "phone": "+70637811165"}
0005434215279	735B77	0688 060295	DMITRIY DENISOV	{"email": "denisov.dmitriy-01101973@postgrespro.ru", "phone": "+70533677321"}
0005434215280	3C3C9F	8724 494121	ANDREY FOMIN	{"phone": "+70748690271"}
0005434215281	391984	2556 858499	OLGA SOKOLOVA	{"phone": "+70926452142"}
0005434215282	391984	0116 493652	VLADIMIR BELOV	{"email": "belov-vladimir-1975@postgrespro.ru", "phone": "+70633143561"}
0005434215283	390E78	4432 605000	OKSANA VOROBEVA	{"email": "vorobeva-oksana-18111970@postgrespro.ru", "phone": "+70175066322"}
0005434215284	5F9BA8	0614 254421	ALEKSANDR NIKOLAEV	{"phone": "+70245629544"}
0005434215285	F985FC	4811 823820	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov-1971@postgrespro.ru", "phone": "+70462555479"}
0005434215286	94A6C2	6527 305874	LYUBOV STEPANOVA	{"email": "lyubovstepanova.1979@postgrespro.ru", "phone": "+70526260544"}
0005434215287	FDD4E6	2980 309337	KRISTINA LOGINOVA	{"phone": "+70826012406"}
0005434215288	883089	8514 158035	NATALYA MIRONOVA	{"email": "mironovanatalya_1986@postgrespro.ru", "phone": "+70021607098"}
0005434215289	C8C771	1869 577576	VLADIMIR FEDOTOV	{"phone": "+70339777174"}
0005434215290	C8C771	8940 566934	EVGENIY VOLKOV	{"email": "volkovevgeniy1965@postgrespro.ru", "phone": "+70143256611"}
0005434215291	B93180	4838 946780	TATYANA POPOVA	{"phone": "+70416272150"}
0005434215292	E47B92	2663 246937	SVETLANA PAVLOVA	{"phone": "+70529279470"}
0005434215293	E47B92	5505 203305	SERGEY KUZNECOV	{"phone": "+70912612116"}
0005434215294	8622C7	5702 650788	VALENTINA KUZNECOVA	{"phone": "+70161439401"}
0005434215295	8622C7	1875 244298	VITALIY KUZNECOV	{"phone": "+70785006044"}
0005434215296	8622C7	1404 117136	ANNA KUZNECOVA	{"phone": "+70610870613"}
0005434215297	806ACC	1841 353114	TAISIYA BELOVA	{"email": "belovataisiya.1980@postgrespro.ru", "phone": "+70266586268"}
0005434215298	806ACC	2661 301260	RAISA SOLOVEVA	{"email": "raisa.soloveva081967@postgrespro.ru", "phone": "+70947806538"}
0005434215299	AD7B2D	2362 121256	ELENA ZAYCEVA	{"email": "zayceva_e.1972@postgrespro.ru", "phone": "+70931732722"}
0005434215300	A2CF9B	9686 179207	NIKOLAY FOMIN	{"phone": "+70916197389"}
0005434215301	97575B	2154 281762	ALEKSEY VOLKOV	{"phone": "+70874825035"}
0005434215302	EEE275	8079 346248	ZAKHAR FILIPPOV	{"email": "zakhar.filippov.17021978@postgrespro.ru", "phone": "+70099266237"}
0005434215303	FD666F	6303 618271	ALBERT GAVRILOV	{"phone": "+70773262856"}
0005434215304	F888CD	3941 337044	ALEKSANDR MIRONOV	{"phone": "+70994589042"}
0005434215305	8D76F1	7841 695285	GENNADIY FROLOV	{"email": "frolov-gennadiy_1969@postgrespro.ru", "phone": "+70451026583"}
0005434215306	A48F76	6596 221656	ANDREY BARANOV	{"phone": "+70440564845"}
0005434215307	A48F76	9583 329205	ALEKSANDR ANDREEV	{"phone": "+70708577771"}
0005434215308	A48F76	0667 892221	OKSANA IVANOVA	{"email": "ivanova_o_1979@postgrespro.ru", "phone": "+70564504877"}
0005434215309	B9DAC2	9217 727939	ALEKSEY IVANOV	{"phone": "+70982788015"}
0005434215310	641AA1	6712 433331	IVAN ZHUKOV	{"phone": "+70983881934"}
0005434215311	399D93	5802 683138	ANASTASIYA IVANOVA	{"phone": "+70136856854"}
0005434215312	399D93	9690 171612	BORIS VOROBEV	{"email": "borisvorobev.22031979@postgrespro.ru", "phone": "+70190188558"}
0005434215313	D77F6F	2439 998281	IRINA NIKOLAEVA	{"phone": "+70742371824"}
0005434215314	3EB406	0722 429220	NATALYA NIKOLAEVA	{"phone": "+70519334409"}
0005434215315	BCC4F0	3403 175617	SERGEY KUZNECOV	{"email": "kuznecov.s_011978@postgrespro.ru", "phone": "+70277423099"}
0005434215316	28B2A9	8055 165959	VERA EFREMOVA	{"phone": "+70346213244"}
0005434215317	3E7A5E	8340 980746	VLADIMIR NOVIKOV	{"phone": "+70188188437"}
0005434215318	3E7A5E	8957 572094	OLESYA KRASNOVA	{"phone": "+70158380756"}
0005434215319	A95828	1446 983922	LIDIYA NAZAROVA	{"email": "lidiya.nazarova1977@postgrespro.ru", "phone": "+70176638416"}
0005434215320	9BF638	1757 596270	YULIYA FOMINA	{"email": "fomina.y041965@postgrespro.ru", "phone": "+70705404847"}
0005434215321	8B53AF	6152 582891	SAMVEL PETROV	{"phone": "+70512901114"}
0005434215322	176529	7835 219511	ILYA DMITRIEV	{"phone": "+70884621961"}
0005434215323	3B0476	6838 483892	MIKHAIL KUZNECOV	{"phone": "+70467768769"}
0005434215324	3B0476	2666 077250	YURIY KUZMIN	{"phone": "+70930996971"}
0005434215325	DA8F09	9053 806403	VADIM NAZAROV	{"email": "v-nazarov-061965@postgrespro.ru", "phone": "+70020073577"}
0005434215326	DA8F09	3365 626211	ALEKSANDR VASILEV	{"email": "a-vasilev081984@postgrespro.ru", "phone": "+70946330986"}
0005434215327	F7FF64	0989 721881	LYUBOV ORLOVA	{"phone": "+70492493520"}
0005434215328	31BCF0	1798 207376	NATALYA POPOVA	{"phone": "+70431403092"}
0005434215329	9EE72B	4482 031016	OLEG PAVLOV	{"email": "oleg.pavlov-1975@postgrespro.ru", "phone": "+70669789000"}
0005434215330	3F8376	1352 999630	VLADIMIR FILIPPOV	{"phone": "+70079348237"}
0005434215331	3F8376	5799 501912	ANATOLIY KISELEV	{"phone": "+70721580650"}
0005434215332	281434	7205 570417	OLGA BARANOVA	{"phone": "+70345508873"}
0005434215333	19E70D	7690 145064	YURIY ZAKHAROV	{"phone": "+70005493468"}
0005434215334	CCB145	9790 519849	ALEKSEY ZAKHAROV	{"email": "zakharov.a_30051976@postgrespro.ru", "phone": "+70934397003"}
0005434215335	CCB145	0961 065510	VIKTOR SMIRNOV	{"phone": "+70336351169"}
0005434215336	8228F3	4297 842675	ALEKSANDR ZAYCEV	{"phone": "+70733628637"}
0005434215337	B7A90B	9606 320813	MIKHAIL SAVELEV	{"phone": "+70423052399"}
0005434215338	B7A90B	1816 127859	TATYANA DENISOVA	{"phone": "+70033244199"}
0005434215339	5B540F	3038 350446	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya.1977@postgrespro.ru", "phone": "+70920494210"}
0005434215340	A2B4B1	9732 460542	RAISA POPOVA	{"phone": "+70104007296"}
0005434215341	4170E3	6650 497846	ALEKSEY FEDOROV	{"email": "fedorova-091978@postgrespro.ru", "phone": "+70102318427"}
0005434215342	8522FB	2899 538194	LYUDMILA ROMANOVA	{"phone": "+70257822985"}
0005434215343	8522FB	4082 215422	NATALYA BORISOVA	{"email": "borisova-natalya_1979@postgrespro.ru", "phone": "+70594850798"}
0005434215344	9F0CCD	8256 593283	ALEKSANDRA MEDVEDEVA	{"email": "medvedeva.a091979@postgrespro.ru", "phone": "+70905594640"}
0005434215345	86ABCB	2336 399599	ZOYA SMIRNOVA	{"phone": "+70996982135"}
0005434215346	DD3A27	5837 242808	MILENA NIKITINA	{"phone": "+70683063172"}
0005434215347	707B91	4194 307462	SEMEN ANTONOV	{"phone": "+70331575132"}
0005434215348	707B91	1108 872612	ANTONINA VLASOVA	{"phone": "+70831341769"}
0005434215349	7190B3	3540 563875	ELENA POTAPOVA	{"phone": "+70434699033"}
0005434215350	B8C2D2	9426 306726	SERGEY FROLOV	{"phone": "+70862549717"}
0005434215351	602A1C	2692 844337	NADEZHDA MASLOVA	{"email": "n-maslova_1974@postgrespro.ru", "phone": "+70415489948"}
0005434215352	0A9F30	8442 816195	ALEKSANDR IVANOV	{"email": "ivanovaleksandr10121972@postgrespro.ru", "phone": "+70566093478"}
0005434215353	0A9F30	4543 239903	ULYANA ANTONOVA	{"email": "ulyanaantonova.1975@postgrespro.ru", "phone": "+70132083619"}
0005434215354	31D7D0	4605 596489	ELENA VASILEVA	{"email": "vasileva_elena-08061959@postgrespro.ru", "phone": "+70040807509"}
0005434215355	279446	1776 653856	SERGEY KUZNECOV	{"email": "s-kuznecov25051982@postgrespro.ru", "phone": "+70822811071"}
0005434215356	B8FA27	9648 544075	SERGEY POPOV	{"phone": "+70108276180"}
0005434215357	B8FA27	3721 351386	VYACHESLAV ALEKSEEV	{"email": "v_alekseev.041980@postgrespro.ru", "phone": "+70419107688"}
0005434215358	B8FA27	2709 568022	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr_101974@postgrespro.ru", "phone": "+70057649449"}
0005434215359	9776CE	0987 355854	LIDIYA MARTYNOVA	{"phone": "+70987347502"}
0005434215360	9776CE	8776 113922	TATYANA NIKOLAEVA	{"email": "tatyana.nikolaeva-1968@postgrespro.ru", "phone": "+70347589103"}
0005434215361	768637	7650 950785	DENIS KOZLOV	{"phone": "+70214397248"}
0005434215362	E48E2C	8843 941604	KLAVDIYA SERGEEVA	{"phone": "+70588374515"}
0005434215363	A5E442	1391 780605	ANDREY OSIPOV	{"phone": "+70560293457"}
0005434215364	BE910F	8349 041083	ANTONINA GUSEVA	{"phone": "+70274331200"}
0005434215365	EC1334	1294 957268	VALENTINA ORLOVA	{"email": "valentina.orlova021970@postgrespro.ru", "phone": "+70073239684"}
0005434215366	EC3759	9348 922804	YANA KOZLOVA	{"phone": "+70424219945"}
0005434215367	D28E86	4019 876931	ZINAIDA SOLOVEVA	{"email": "solovevaz061964@postgrespro.ru", "phone": "+70455383083"}
0005434215368	BBCE20	1854 093981	IVAN MATVEEV	{"email": "i-matveev_12091971@postgrespro.ru", "phone": "+70813860997"}
0005434215369	C2883F	9449 285586	DMITRIY OSIPOV	{"email": "osipov-d.27011975@postgrespro.ru", "phone": "+70880753008"}
0005434215370	646CFC	8703 813334	ANNA MAKAROVA	{"phone": "+70299951793"}
0005434215371	4153CA	7856 144587	ALEFTINA PETROVA	{"phone": "+70064304701"}
0005434215372	0220A7	8081 126315	DANIL IVANOV	{"phone": "+70428533912"}
0005434215373	0220A7	7539 858644	YULIYA ANDREEVA	{"email": "yuliya_andreeva_07111970@postgrespro.ru", "phone": "+70986764500"}
0005434215374	3B8AD1	4177 070614	NADEZHDA AFANASEVA	{"email": "nadezhda_afanaseva051981@postgrespro.ru", "phone": "+70475066926"}
0005434215375	3B8AD1	4743 387645	ALEKSANDR EGOROV	{"email": "aleksandr-egorov-1968@postgrespro.ru", "phone": "+70638804589"}
0005434215376	0BF633	6804 861573	NIKOLAY NIKITIN	{"phone": "+70300669007"}
0005434215377	1E8697	9619 919135	VLADIMIR KARPOV	{"phone": "+70126801756"}
0005434215378	925AC6	0697 897956	ANDREY KAZAKOV	{"phone": "+70749613571"}
0005434215379	925AC6	9420 435341	LARISA VASILEVA	{"email": "larisa-vasileva_10021959@postgrespro.ru", "phone": "+70755336001"}
0005434215380	73887A	5680 115800	SVETLANA NESTEROVA	{"email": "snesterova1966@postgrespro.ru", "phone": "+70415416186"}
0005434215381	4D16F3	2529 363252	IVAN MIKHAYLOV	{"email": "imikhaylov081971@postgrespro.ru", "phone": "+70220405517"}
0005434215382	27F0C4	4386 282428	SOFYA KOROLEVA	{"email": "koroleva-s_30111983@postgrespro.ru", "phone": "+70289530984"}
0005434215383	8FA431	2204 395036	MAKSIM MATVEEV	{"phone": "+70145927870"}
0005434215384	8FA431	3055 729150	ARTEM KARPOV	{"phone": "+70362175416"}
0005434215385	8FA431	0082 673910	YANA ORLOVA	{"phone": "+70976270841"}
0005434215386	8FA431	1907 546045	ELENA SOKOLOVA	{"phone": "+70320734478"}
0005434215387	E8F534	6870 233739	ALEKSEY MELNIKOV	{"email": "melnikov_aleksey-1968@postgrespro.ru", "phone": "+70920894324"}
0005434215388	3BBCCC	8430 797543	SHAMIL IVANOV	{"email": "ivanov_shamil-101976@postgrespro.ru", "phone": "+70072543995"}
0005434215389	8D19E5	5087 814898	NIKOLAY PETROV	{"phone": "+70678962235"}
0005434215390	1DCD29	2993 610301	NIKOLAY KOZLOV	{"email": "kozlov-nikolay.011966@postgrespro.ru", "phone": "+70681553064"}
0005434215391	1DCD29	8065 616628	LYUDMILA PETROVA	{"phone": "+70079783144"}
0005434215392	115DD9	4359 283619	NIKITA RODIONOV	{"email": "rodionov_n_081968@postgrespro.ru", "phone": "+70347238879"}
0005434215393	988917	8374 116048	ELIZAVETA KUZNECOVA	{"phone": "+70743334638"}
0005434215394	9CDB92	0991 064374	EVGENIY PAVLOV	{"phone": "+70522486352"}
0005434215395	429F14	6536 129246	GALINA ROMANOVA	{"email": "galina.romanova.1967@postgrespro.ru", "phone": "+70578545444"}
0005434215396	429F14	5437 159909	TATYANA KOROLEVA	{"email": "korolevatatyana061963@postgrespro.ru", "phone": "+70276884281"}
0005434215397	2CACCE	1506 497886	LILIYA ORLOVA	{"email": "orlova.l_19061980@postgrespro.ru", "phone": "+70846966562"}
0005434215398	2CACCE	4265 346832	YANA MOROZOVA	{"email": "yana.morozova1974@postgrespro.ru", "phone": "+70803765177"}
0005434215399	91DE55	9168 254400	VADIM AFANASEV	{"email": "vadim-afanasev-1970@postgrespro.ru", "phone": "+70109718727"}
0005434215400	E2048B	6391 423481	OLGA ALEKSANDROVA	{"phone": "+70996678184"}
0005434215401	9DB47E	4975 566395	OLGA KISELEVA	{"email": "o.kiseleva1981@postgrespro.ru", "phone": "+70346734438"}
0005434215402	9DB47E	4131 084763	VASILIY NOVIKOV	{"email": "novikovvasiliy.07021972@postgrespro.ru", "phone": "+70825271950"}
0005434215403	DE30D6	3491 164666	TAMARA NIKITINA	{"email": "nikitina_tamara12021970@postgrespro.ru", "phone": "+70666313242"}
0005434215404	2EBAAD	7585 670342	ANDREY GRIGOREV	{"email": "andreygrigorev.1970@postgrespro.ru", "phone": "+70253886176"}
0005434215405	2EBAAD	1848 681609	ANATOLIY NOVIKOV	{"email": "novikovanatoliy-25121962@postgrespro.ru", "phone": "+70330609679"}
0005434215406	2EBAAD	9253 918657	KONSTANTIN ALEKSEEV	{"phone": "+70163990804"}
0005434215407	4805CD	6999 324316	ANDREY YAKOVLEV	{"email": "yakovlev-andrey-1969@postgrespro.ru", "phone": "+70666927469"}
0005434215408	D5BB5B	8545 040908	LARISA MAKAROVA	{"phone": "+70116659984"}
0005434215409	D5BB5B	3209 097064	LIDIYA POLYAKOVA	{"email": "polyakova.lidiya.1966@postgrespro.ru", "phone": "+70277154311"}
0005434215410	A8D14B	9649 230424	ARTEM SHEVCHENKO	{"phone": "+70086116205"}
0005434215411	D079A9	5845 525368	ALEKSEY TARASOV	{"email": "tarasovaleksey-1967@postgrespro.ru", "phone": "+70310950237"}
0005434215412	3AD30B	9360 498116	MIKHAIL GRIGOREV	{"phone": "+70755336183"}
0005434215413	4149DA	5980 538717	VITALIY PETROV	{"phone": "+70157387945"}
0005434215414	92FF46	8525 283114	DANIIL ZAKHAROV	{"email": "zakharov_d_1981@postgrespro.ru", "phone": "+70382318748"}
0005434215415	92FF46	9216 591924	ANASTASIYA VASILEVA	{"email": "a.vasileva-1976@postgrespro.ru", "phone": "+70778025445"}
0005434215416	E58FD7	0768 114132	OKSANA KOZLOVA	{"email": "oksanakozlova-01031962@postgrespro.ru", "phone": "+70440890575"}
0005434215417	985168	9902 037709	STANISLAV MATVEEV	{"phone": "+70291264831"}
0005434215418	985168	9691 925904	VIKTOR ANDREEV	{"email": "andreev_v_081972@postgrespro.ru", "phone": "+70137230916"}
0005434215419	491BD6	1503 694630	NATALYA GRISHINA	{"phone": "+70658979341"}
0005434215420	8DAD71	7200 574910	MARAT NIKOLAEV	{"email": "mnikolaev-091974@postgrespro.ru", "phone": "+70647889777"}
0005434215421	A98D49	5746 792067	EMIL EGOROV	{"email": "egorov-emil30101967@postgrespro.ru", "phone": "+70633861866"}
0005434215422	57C5E1	0072 307590	VIKTOR DENISOV	{"phone": "+70352268903"}
0005434215423	03FB96	5605 219804	NINA DENISOVA	{"email": "denisova_nina_1981@postgrespro.ru", "phone": "+70411201362"}
0005434215424	03FB96	8983 217232	LIDIYA DENISOVA	{"phone": "+70997493432"}
0005434215425	2DEE95	2573 070861	VALENTINA KOZLOVA	{"email": "kozlova_valentina-18071966@postgrespro.ru", "phone": "+70530392526"}
0005434215426	A84DEA	1439 779004	VLADIMIR KOROLEV	{"email": "korolevv.121976@postgrespro.ru", "phone": "+70292707689"}
0005434215427	A84DEA	5840 249732	NADEZHDA DENISOVA	{"email": "denisova.nadezhda-11041979@postgrespro.ru", "phone": "+70999653969"}
0005434215428	54C77C	8881 781314	ANDREY ZHUKOV	{"phone": "+70197349792"}
0005434215429	CDA805	6473 353540	GALINA LEBEDEVA	{"email": "glebedeva_1978@postgrespro.ru", "phone": "+70808531071"}
0005434215430	45A93E	3761 801390	YURIY SERGEEV	{"email": "yuriysergeev_1973@postgrespro.ru", "phone": "+70879098907"}
0005434215431	FE8C21	5282 754135	NIKOLAY SMIRNOV	{"phone": "+70104842092"}
0005434215432	FE8C21	3325 445663	YURIY MARTYNOV	{"phone": "+70751914049"}
0005434215433	5242D0	1206 317344	VASILIY ZHURAVLEV	{"email": "zhuravlev-vasiliy_20051979@postgrespro.ru", "phone": "+70087563701"}
0005434215434	E19FA8	5040 398385	FARIT NIKOLAEV	{"phone": "+70200352552"}
0005434215435	E19FA8	7310 290212	TAMARA MIKHAYLOVA	{"phone": "+70533995948"}
0005434215436	4021C0	4169 106988	SANIYA ZAYCEVA	{"email": "zaycevas_18101975@postgrespro.ru", "phone": "+70206811220"}
0005434215437	FB8C1C	1937 444660	DANIL ZHURAVLEV	{"email": "zhuravlev-d.16071968@postgrespro.ru", "phone": "+70180004665"}
0005434215438	FB8C1C	3310 686718	DMITRIY STEPANOV	{"email": "dmitriy-stepanov_23071969@postgrespro.ru", "phone": "+70268199422"}
0005434215439	FB8C1C	9058 818204	SERGEY BELOV	{"phone": "+70540318542"}
0005434215440	5240BC	1116 117673	EDUARD VASILEV	{"phone": "+70297223429"}
0005434215441	B892E1	1854 805223	RAISA MIKHAYLOVA	{"email": "r_mikhaylova_25021973@postgrespro.ru", "phone": "+70964755591"}
0005434215442	B892E1	0238 956625	ELENA FROLOVA	{"phone": "+70237219899"}
0005434215443	785866	3634 151806	ROMAN KISELEV	{"phone": "+70899171467"}
0005434215444	B84838	4678 473434	EVGENIY POPOV	{"email": "evgeniypopov_27081965@postgrespro.ru", "phone": "+70763683631"}
0005434215445	C22061	5852 049978	EVGENIY DMITRIEV	{"phone": "+70831630304"}
0005434215446	77FC95	6100 256060	GALINA KAZAKOVA	{"phone": "+70332046805"}
0005434215447	EFB8F2	1259 169647	TATYANA MIRONOVA	{"email": "mironovat_101979@postgrespro.ru", "phone": "+70195057602"}
0005434215448	77A9D3	1675 303990	LILIYA ZAKHAROVA	{"phone": "+70095402360"}
0005434215449	7EC7EB	3272 184671	MIKHAIL VLASOV	{"email": "vlasovmikhail1967@postgrespro.ru", "phone": "+70679315531"}
0005434215450	BFAC31	9461 781849	ANNA AFANASEVA	{"email": "a.afanaseva.11101967@postgrespro.ru", "phone": "+70292405118"}
0005434215451	A6EB17	7453 679979	VALENTINA NIKOLAEVA	{"phone": "+70354118878"}
0005434215452	E81337	3033 758753	SERGEY ALEKSEEV	{"phone": "+70447306639"}
0005434215453	BCCE99	7200 767599	ANDREY VASILEV	{"email": "andrey_vasilev-25111969@postgrespro.ru", "phone": "+70863547355"}
0005434215454	5A4061	3343 081972	ARTEM KOROLEV	{"phone": "+70560391265"}
0005434215455	AFEC10	3785 178332	ELENA SEMENOVA	{"email": "semenovaelena1965@postgrespro.ru", "phone": "+70333928278"}
0005434215456	F0EB6C	4413 563100	ANATOLIY GERASIMOV	{"email": "anatoliygerasimov_1977@postgrespro.ru", "phone": "+70403635403"}
0005434215457	76F8C9	2831 135382	SERGEY PETROV	{"email": "spetrov.1958@postgrespro.ru", "phone": "+70751523759"}
0005434215458	5837A2	1757 266760	ALEKSANDR PAVLOV	{"phone": "+70823666414"}
0005434215459	734097	4508 014378	MARIYA FEDOROVA	{"phone": "+70125512413"}
0005434215460	734097	4065 218054	ELENA ZAKHAROVA	{"email": "elenazakharova_18071968@postgrespro.ru", "phone": "+70311630558"}
0005434215461	EBEC24	4313 105003	NATALYA MAKAROVA	{"phone": "+70659246117"}
0005434215462	EBEC24	7130 001000	GEORGIY SOKOLOV	{"phone": "+70804820780"}
0005434215463	771B8D	1339 651086	GENNADIY SMIRNOV	{"email": "smirnov-gennadiy_121979@postgrespro.ru", "phone": "+70741454884"}
0005434215464	88ECC6	6477 776863	EKATERINA DMITRIEVA	{"email": "e_dmitrieva-20011974@postgrespro.ru", "phone": "+70137237962"}
0005434215465	4AD08D	5785 214706	ANDREY POPOV	{"email": "andrey-popov-10121969@postgrespro.ru", "phone": "+70599697426"}
0005434215633	FCD65F	8622 611195	EVGENIY SOKOLOV	{"phone": "+70543203358"}
0005434215466	65DC70	8199 054824	DANIIL VOROBEV	{"email": "vorobev.daniil.011966@postgrespro.ru", "phone": "+70772448446"}
0005434215467	CF9B28	0909 906363	ELENA FILATOVA	{"email": "filatova.elena_101980@postgrespro.ru", "phone": "+70324891206"}
0005434215468	63AF76	1453 651142	ALEKSEY POPOV	{"phone": "+70834647805"}
0005434215469	F1B5E5	7637 730511	VALENTINA LAZAREVA	{"phone": "+70318844486"}
0005434215470	919294	7709 442378	TATYANA KUZNECOVA	{"phone": "+70973308028"}
0005434215471	27CFA3	3156 519507	EKATERINA PAVLOVA	{"phone": "+70373281966"}
0005434215472	27CFA3	8803 096104	ANASTASIYA IVANOVA	{"phone": "+70031867858"}
0005434215473	27CFA3	7352 035958	EVGENIYA EGOROVA	{"email": "egorova.e.12011967@postgrespro.ru", "phone": "+70878621133"}
0005434215474	AB11C7	8049 338390	TATYANA CHERNOVA	{"email": "chernova_t_011970@postgrespro.ru", "phone": "+70035147078"}
0005434215475	AB11C7	9105 921797	MAKSIM MAKAROV	{"email": "mmakarov-27091967@postgrespro.ru", "phone": "+70580999915"}
0005434215476	72572B	4073 289481	ILMIR KARPOV	{"phone": "+70378105885"}
0005434215477	8EA715	9575 552598	DARYA KUZNECOVA	{"phone": "+70827888982"}
0005434215478	8EA715	6921 478429	VALENTINA MASLOVA	{"email": "maslovavalentina_031983@postgrespro.ru", "phone": "+70585400547"}
0005434215479	8EA715	4641 629548	TIMUR KARPOV	{"phone": "+70338376462"}
0005434215480	32B9FB	1494 289708	VALERIY NAUMOV	{"email": "naumov-valeriy-111978@postgrespro.ru", "phone": "+70032131694"}
0005434215481	ED2927	3146 712322	ROMAN KONOVALOV	{"phone": "+70649080213"}
0005434215482	B41C58	9809 344358	ARTEM NIKITIN	{"email": "nikitin_artem-091968@postgrespro.ru", "phone": "+70331281911"}
0005434215483	60CC6E	2954 924928	NIKOLAY SMIRNOV	{"email": "n-smirnov-1964@postgrespro.ru", "phone": "+70069482205"}
0005434215484	CF0D48	3970 037939	NATALIYA ZHUKOVA	{"phone": "+70054923169"}
0005434215485	CF0D48	0278 640138	GULFIYA VOROBEVA	{"phone": "+70033447833"}
0005434215486	BAD1BC	9321 585063	NADEZHDA OSIPOVA	{"phone": "+70424549439"}
0005434215487	107BDD	9189 070614	NIKOLAY GUSEV	{"phone": "+70046689054"}
0005434215488	0FFE36	2960 376440	OKSANA TIMOFEEVA	{"email": "oksana_timofeeva23081974@postgrespro.ru", "phone": "+70944404482"}
0005434215489	602C68	5434 056008	SERGEY MAKSIMOV	{"phone": "+70351227838"}
0005434215490	A0F1AC	2160 194709	VALENTINA BOGDANOVA	{"phone": "+70813612881"}
0005434215491	2D4006	3471 810856	IRINA YAKOVLEVA	{"email": "yakovleva_i-1973@postgrespro.ru", "phone": "+70963873880"}
0005434215492	2D4006	0913 830643	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-03021971@postgrespro.ru", "phone": "+70397442470"}
0005434215493	03F84A	8977 838727	VIKTOR SIDOROV	{"email": "v-sidorov-20041961@postgrespro.ru", "phone": "+70494652516"}
0005434215494	94E840	7170 340907	ALEVTINA IVANOVA	{"email": "ivanova.alevtina26061967@postgrespro.ru", "phone": "+70244666989"}
0005434215495	831A57	4706 330998	VLADIMIR KUDRYASHOV	{"email": "v_kudryashov.21101969@postgrespro.ru", "phone": "+70432432684"}
0005434215496	58BD73	6407 336399	ANATOLIY MATVEEV	{"email": "matveev_a.061978@postgrespro.ru", "phone": "+70616488418"}
0005434215497	9CA368	3557 729973	YANA ERMAKOVA	{"email": "ermakova_y.02061965@postgrespro.ru", "phone": "+70645675110"}
0005434215498	9CA368	4774 733592	ALEKSANDRA LUKYANOVA	{"email": "lukyanova_aleksandra_23061965@postgrespro.ru", "phone": "+70749044671"}
0005434215499	7CC4BE	1554 674691	DMITRIY YAKOVLEV	{"email": "dmitriy_yakovlev_1965@postgrespro.ru", "phone": "+70369649162"}
0005434215500	7CC4BE	9767 759750	NATALYA SOLOVEVA	{"phone": "+70912594620"}
0005434215501	082667	6298 369321	VYACHESLAV VASILEV	{"email": "vasilev-vyacheslav_081971@postgrespro.ru", "phone": "+70578788391"}
0005434215502	38973E	8229 825510	NATALYA AFANASEVA	{"phone": "+70814573789"}
0005434215503	38973E	6384 834385	VLADIMIR TIKHONOV	{"phone": "+70986549772"}
0005434215504	2D7470	7306 734930	SAMIR SIDOROV	{"email": "sidorov_s-03041965@postgrespro.ru", "phone": "+70334582676"}
0005434215505	6B6F14	9056 682160	IRINA PAVLOVA	{"email": "i-pavlova011983@postgrespro.ru", "phone": "+70171674666"}
0005434215506	6B6F14	4944 024412	EKATERINA ANDREEVA	{"email": "e-andreeva_06091976@postgrespro.ru", "phone": "+70862131641"}
0005434215507	053EDA	2033 203714	EKATERINA YAKOVLEVA	{"email": "ekaterina_yakovleva031974@postgrespro.ru", "phone": "+70264023274"}
0005434215508	053EDA	0246 312448	LYUBOV NIKOLAEVA	{"email": "lnikolaeva-27091969@postgrespro.ru", "phone": "+70812254037"}
0005434215509	053EDA	0318 449968	MARIYA ZHURAVLEVA	{"email": "zhuravlevam1978@postgrespro.ru", "phone": "+70904437349"}
0005434215510	C32296	4554 473388	ALEKSANDR VASILEV	{"phone": "+70228628298"}
0005434215511	C32296	9379 059192	SERGEY POPOV	{"email": "sergey_popov_25021975@postgrespro.ru", "phone": "+70801902704"}
0005434215512	8720F1	9468 424174	LYUDMILA FADEEVA	{"phone": "+70967713971"}
0005434215513	3FEBE1	3975 238413	EKATERINA MOISEEVA	{"phone": "+70302825143"}
0005434215514	45CFB7	4701 543962	YULIYA ALEKSEEVA	{"phone": "+70723942739"}
0005434215515	45CFB7	4260 693096	VLADISLAV BORISOV	{"phone": "+70741389736"}
0005434215516	CDB7EB	9910 557786	SEMEN MOROZOV	{"email": "s.morozov_1978@postgrespro.ru", "phone": "+70163610420"}
0005434215517	FA570E	0273 705577	INNA POPOVA	{"phone": "+70041366404"}
0005434215518	54F0C8	3725 962061	MARGARITA NAUMOVA	{"phone": "+70007789227"}
0005434215519	54F0C8	0484 497931	VLADIMIR OSIPOV	{"email": "vladimir.osipov_041960@postgrespro.ru", "phone": "+70408068728"}
0005434215520	EB7805	1555 333903	ALEKSANDR MOISEEV	{"email": "moiseeva-101970@postgrespro.ru", "phone": "+70183965589"}
0005434215521	E13A4B	5814 313402	VLADISLAV KOZLOV	{"phone": "+70265720172"}
0005434215522	52A678	0159 501421	NADEZHDA EGOROVA	{"email": "egorova-nadezhda-051980@postgrespro.ru", "phone": "+70104857382"}
0005434215523	581266	9688 506830	IGOR MOROZOV	{"email": "igor_morozov.14031978@postgrespro.ru", "phone": "+70930989951"}
0005434215524	581266	0137 567742	MAKSIM ZAYCEV	{"email": "zaycevmaksim.18041974@postgrespro.ru", "phone": "+70554534289"}
0005434215525	35DC1B	0040 490756	ALEKSANDR POPOV	{"email": "popovaleksandr_06061964@postgrespro.ru", "phone": "+70528361051"}
0005434215526	88CF9C	3647 421371	PAVEL POPOV	{"phone": "+70408311718"}
0005434215527	B5D244	8878 108595	KSENIYA MATVEEVA	{"email": "k.matveeva-1967@postgrespro.ru", "phone": "+70293180390"}
0005434215528	6A5344	4124 563874	IGOR VASILEV	{"email": "i-vasilev-08111965@postgrespro.ru", "phone": "+70688727587"}
0005434215529	9542DE	5075 664364	SVETLANA MARTYNOVA	{"phone": "+70779893997"}
0005434215530	9542DE	7355 744042	VLADIMIR KONOVALOV	{"phone": "+70841806745"}
0005434215531	44349A	9636 507059	TATYANA IVANOVA	{"phone": "+70523214903"}
0005434215532	13B231	4419 723954	ANDREY VOLKOV	{"email": "volkov_andrey1968@postgrespro.ru", "phone": "+70266755516"}
0005434215533	8B5BFA	7988 618082	NADEZHDA ISAEVA	{"email": "isaeva_nadezhda_18081965@postgrespro.ru", "phone": "+70294182485"}
0005434215534	981A26	0365 010535	ANTON MIRONOV	{"phone": "+70564333493"}
0005434215535	752604	5432 147850	SVETLANA MIKHAYLOVA	{"phone": "+70846923009"}
0005434215536	752604	6905 657013	DMITRIY SCHERBAKOV	{"phone": "+70919232813"}
0005434215537	AABAB5	8212 299478	ILYA TARASOV	{"email": "ilya.tarasov.15041965@postgrespro.ru", "phone": "+70267588359"}
0005434215538	AABAB5	7004 546158	LYUDMILA VOLKOVA	{"email": "volkova_l081962@postgrespro.ru", "phone": "+70626177759"}
0005434215539	96A651	7665 869168	ANDREY KOZLOV	{"phone": "+70123634102"}
0005434215540	5E6B14	6756 203898	OLGA KRASNOVA	{"email": "krasnova-olga-1976@postgrespro.ru", "phone": "+70199542999"}
0005434215541	DB1718	0609 433939	DIANA AKIMOVA	{"email": "d-akimova.04011972@postgrespro.ru", "phone": "+70609158690"}
0005434215542	DB1718	2938 841991	DENIS FILIPPOV	{"phone": "+70164505209"}
0005434215543	DB1718	9730 891771	ELENA FILIPPOVA	{"email": "filippovaelena031971@postgrespro.ru", "phone": "+70853664029"}
0005434215544	DB1718	0889 661148	VALENTINA SOROKINA	{"email": "sorokina_v-16091961@postgrespro.ru", "phone": "+70929870161"}
0005434215545	4F96C9	8228 399697	SERGEY BELOV	{"email": "belov_s1975@postgrespro.ru", "phone": "+70426794373"}
0005434215546	4AAB07	2388 254534	YURIY GAVRILOV	{"email": "gavrilov-yuriy_15051966@postgrespro.ru", "phone": "+70164156722"}
0005434215547	EEA823	0165 210239	EVGENIY FILIPPOV	{"phone": "+70389693697"}
0005434215548	0733FF	6186 004353	NIKOLAY ZHUKOV	{"phone": "+70436524096"}
0005434215549	5A9F67	7551 512793	GALINA SOROKINA	{"phone": "+70105395861"}
0005434215550	5A9F67	0414 994541	DMITRIY ZAKHAROV	{"email": "d-zakharov_18011962@postgrespro.ru", "phone": "+70626206669"}
0005434215551	426A02	2330 861112	IRINA FILATOVA	{"email": "filatova-i_121973@postgrespro.ru", "phone": "+70432172280"}
0005434215552	426A02	0672 797826	ANTON NAZAROV	{"phone": "+70757870271"}
0005434215553	D141FF	2071 141142	KONSTANTIN KUZNECOV	{"email": "k-kuznecov-081963@postgrespro.ru", "phone": "+70876551896"}
0005434215554	991E5C	8023 814071	NATALYA KUZNECOVA	{"email": "n_kuznecova_16051969@postgrespro.ru", "phone": "+70882812517"}
0005434215555	0D0D77	2170 231403	OLGA MIKHAYLOVA	{"email": "mikhaylova-olga.1980@postgrespro.ru", "phone": "+70701795847"}
0005434215556	E84FB6	3367 344788	ALEKSANDR SEMENOV	{"phone": "+70111388524"}
0005434215557	E84FB6	4780 164265	YULIYA IVANOVA	{"email": "yivanova.03121969@postgrespro.ru", "phone": "+70770343938"}
0005434215558	49C355	8890 050338	MARFA VOLKOVA	{"email": "volkova_m.09031969@postgrespro.ru", "phone": "+70917722802"}
0005434215559	68C7E7	1651 358963	OKSANA YUDINA	{"phone": "+70491244705"}
0005434215560	68C7E7	2677 948900	YURIY ISAEV	{"email": "yisaev-1972@postgrespro.ru", "phone": "+70925435613"}
0005434215561	68C7E7	3244 298502	OKSANA SMIRNOVA	{"email": "o.smirnova.14071981@postgrespro.ru", "phone": "+70964519390"}
0005434215562	843744	0704 040427	ALEKSANDR ZAYCEV	{"phone": "+70779256912"}
0005434215563	30DD37	1777 061781	ALEKSANDR NAUMOV	{"phone": "+70643726454"}
0005434215564	30DD37	1215 580581	DARYA ABRAMOVA	{"email": "abramova_d_1966@postgrespro.ru", "phone": "+70766290799"}
0005434215565	30DD37	7756 119118	VLADIMIR KUZMIN	{"email": "kuzminv-16121967@postgrespro.ru", "phone": "+70384210046"}
0005434215566	CBCDB2	7845 306830	IVAN KOROLEV	{"phone": "+70181855540"}
0005434215567	C356AB	6863 806920	TATYANA MAKAROVA	{"email": "makarova.t-071972@postgrespro.ru", "phone": "+70114450549"}
0005434215568	ABA9F6	5817 166871	ARTEM DMITRIEV	{"phone": "+70983918983"}
0005434215569	A47531	8540 849919	GENNADIY ISAEV	{"phone": "+70046652216"}
0005434215570	235A50	1413 695603	NADEZHDA SEMENOVA	{"phone": "+70156369231"}
0005434215571	DEAE72	5622 276740	NATALYA NIKITINA	{"email": "n.nikitina-03061977@postgrespro.ru", "phone": "+70349461157"}
0005434215572	27C557	7705 089647	ALEKSANDR FILIPPOV	{"phone": "+70283839319"}
0005434215573	AA5768	3783 001167	MARIYA ALEKSEEVA	{"email": "alekseeva_mariya071966@postgrespro.ru", "phone": "+70327799155"}
0005434215574	D7D80E	6561 412196	VLADIMIR GUSEV	{"email": "vladimir.gusev.17071984@postgrespro.ru", "phone": "+70551901429"}
0005434215575	25A0AC	6190 680061	DMITRIY FEDOROV	{"phone": "+70550058223"}
0005434215576	C89B87	7855 761145	VLADIMIR SOLOVEV	{"phone": "+70483322035"}
0005434215634	F6DE4F	8140 453392	NADEZHDA KISELEVA	{"phone": "+70048926068"}
0005434215577	972B39	6774 352021	KHALIDA NOVIKOVA	{"email": "novikova.khalida-22101964@postgrespro.ru", "phone": "+70177890460"}
0005434215578	619AC2	9827 496674	NADEZHDA ANTONOVA	{"phone": "+70164876850"}
0005434215579	619AC2	6919 978466	NATALIYA ROMANOVA	{"email": "romanova_nataliya.1982@postgrespro.ru", "phone": "+70355738566"}
0005434215580	619AC2	9366 801920	ELENA KOLESNIKOVA	{"email": "elena-kolesnikova-1982@postgrespro.ru", "phone": "+70412829021"}
0005434215581	8AF709	8983 233275	VLADIMIR ILIN	{"email": "ilin.v-31101967@postgrespro.ru", "phone": "+70540944346"}
0005434215582	F042E7	1890 829184	ANDREY POPOV	{"phone": "+70899767729"}
0005434215583	015909	3610 172844	NIKITA FEDOROV	{"phone": "+70840588010"}
0005434215584	55FF9D	4771 550745	EVGENIY VOLKOV	{"phone": "+70542571692"}
0005434215585	065074	9996 927509	YULIYA BOGDANOVA	{"email": "bogdanovay.091970@postgrespro.ru", "phone": "+70145604477"}
0005434215586	065074	0429 373097	ANDREY IVANOV	{"email": "ivanov-andrey-15091974@postgrespro.ru", "phone": "+70530503674"}
0005434215587	C87335	6392 919550	DMITRIY ALEKSANDROV	{"phone": "+70917665498"}
0005434215588	541595	9343 186947	VALENTINA KUDRYASHOVA	{"email": "kudryashova.v.081972@postgrespro.ru", "phone": "+70249620818"}
0005434215589	346F6D	6631 241487	ZLATA KUZNECOVA	{"phone": "+70494676763"}
0005434215590	B6470E	2659 912673	VALERIY ALEKSANDROV	{"phone": "+70544982060"}
0005434215591	3C83FE	0736 352833	MARINA SAVELEVA	{"email": "saveleva_marina19101968@postgrespro.ru", "phone": "+70742418682"}
0005434215592	3C83FE	0887 965951	ANNA POPOVA	{"email": "a.popova111974@postgrespro.ru", "phone": "+70112657758"}
0005434215593	E6D8D7	1973 510322	GYUZEL SERGEEVA	{"phone": "+70601787796"}
0005434215594	C36A1B	1605 074750	NATALYA MAKAROVA	{"phone": "+70989007788"}
0005434215595	6F1911	5172 388063	TATYANA NIKITINA	{"phone": "+70803242387"}
0005434215596	461B71	5039 045533	ZOYA AFANASEVA	{"email": "afanaseva_z-101969@postgrespro.ru", "phone": "+70847102186"}
0005434215597	C31C36	2404 736736	IRINA IVANOVA	{"email": "irinaivanova_02091970@postgrespro.ru", "phone": "+70354542745"}
0005434215598	128AF5	9426 077123	NATALYA ZHURAVLEVA	{"email": "nzhuravleva.021975@postgrespro.ru", "phone": "+70576535687"}
0005434215599	409155	3419 046477	ANDREY PETROV	{"email": "andrey-petrov.1977@postgrespro.ru", "phone": "+70809427085"}
0005434215600	4438BC	5544 707710	ANATOLIY POPOV	{"email": "popov_a-27091980@postgrespro.ru", "phone": "+70769687681"}
0005434215601	F711D4	8451 518369	VALERIY ORLOV	{"email": "valeriy-orlov111963@postgrespro.ru", "phone": "+70550566216"}
0005434215602	3137FB	1297 799495	NATALYA VASILEVA	{"email": "vasileva.natalya.1968@postgrespro.ru", "phone": "+70928341043"}
0005434215603	3137FB	9956 880433	KONSTANTIN CHERNOV	{"phone": "+70609872045"}
0005434215604	362BA9	9119 931198	VALERIY ZHURAVLEV	{"phone": "+70055955908"}
0005434215605	DF2C76	6832 040373	MARIYA KUZNECOVA	{"phone": "+70743021750"}
0005434215606	9A3D6D	2154 122346	ANATOLIY GRIGOREV	{"phone": "+70120056736"}
0005434215607	9A3D6D	0115 225981	ALEKSANDRA KAZAKOVA	{"email": "kazakova_a-1960@postgrespro.ru", "phone": "+70313161731"}
0005434215608	A384C7	7347 226647	ALEKSANDR STEPANOV	{"phone": "+70577925541"}
0005434215609	998165	9676 932848	TAISIYA BORISOVA	{"email": "borisova-t31031976@postgrespro.ru", "phone": "+70512760890"}
0005434215610	998165	0339 596191	MARINA AKIMOVA	{"phone": "+70941938733"}
0005434215611	57EFFE	4724 826788	ILNUR MAKSIMOV	{"phone": "+70352200834"}
0005434215612	7300A4	2209 988188	KONSTANTIN GUSEV	{"phone": "+70174304046"}
0005434215613	FAD6DB	5843 081289	ELENA IVANOVA	{"phone": "+70319302535"}
0005434215614	FAD6DB	2570 303135	NIKITA YAKOVLEV	{"email": "n.yakovlev-1978@postgrespro.ru", "phone": "+70996818114"}
0005434215615	D37BCA	8397 937840	ANASTASIYA SEMENOVA	{"email": "semenova_anastasiya_1965@postgrespro.ru", "phone": "+70822004908"}
0005434215616	B58EDF	6963 746543	GENNADIY ORLOV	{"email": "gorlov041966@postgrespro.ru", "phone": "+70860795913"}
0005434215617	40200B	1386 856296	VADIM KRASNOV	{"phone": "+70602213165"}
0005434215618	40200B	4324 151576	ELENA SOROKINA	{"phone": "+70594157822"}
0005434215619	40200B	5632 325849	VITALIY SEMENOV	{"phone": "+70807980654"}
0005434215620	782AD5	5957 390238	GRIGORIY DAVYDOV	{"email": "gdavydov-16111972@postgrespro.ru", "phone": "+70256909982"}
0005434215621	782AD5	6341 584660	VALENTINA NOVIKOVA	{"phone": "+70872873632"}
0005434215622	97837A	9615 720540	TATYANA KUZMINA	{"email": "kuzmina-t_1967@postgrespro.ru", "phone": "+70773691661"}
0005434215623	566406	1215 359531	NADEZHDA SERGEEVA	{"phone": "+70127496924"}
0005434215624	566406	2004 618028	VALERIY PAVLOV	{"phone": "+70307704667"}
0005434215625	E55491	0903 691287	ELENA POLYAKOVA	{"phone": "+70542096738"}
0005434215626	6E94F1	5540 690979	VLADIMIR PAVLOV	{"email": "vladimir.pavlov_27121954@postgrespro.ru", "phone": "+70568800095"}
0005434215627	6E94F1	2704 301488	VYACHESLAV DMITRIEV	{"phone": "+70184048781"}
0005434215628	62CC18	6009 830393	DMITRIY VASILEV	{"phone": "+70025388274"}
0005434215629	AC8212	3066 043093	ALEKSEY NAZAROV	{"email": "alekseynazarov-26071956@postgrespro.ru", "phone": "+70231899816"}
0005434215630	AC8212	1360 934946	GALINA MOROZOVA	{"phone": "+70291060852"}
0005434215631	B751D4	4066 972890	ELIZAVETA BOGDANOVA	{"email": "elizaveta-bogdanova_101976@postgrespro.ru", "phone": "+70786232475"}
0005434215632	52DB40	6330 493476	DANIIL TIKHONOV	{"phone": "+70388504738"}
0005434215635	F6DE4F	0274 044689	SERGEY SCHERBAKOV	{"email": "scherbakovsergey-021983@postgrespro.ru", "phone": "+70510832694"}
0005434215636	4FCD33	7625 483328	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov11111975@postgrespro.ru", "phone": "+70028045871"}
0005434215637	BC56E1	5657 848679	TATYANA YAKOVLEVA	{"phone": "+70279849161"}
0005434215638	AA6B31	6628 278421	VLADIMIR NIKOLAEV	{"phone": "+70327725072"}
0005434215639	D7C9A6	9870 709576	OKSANA KONDRATEVA	{"email": "kondrateva_o_1970@postgrespro.ru", "phone": "+70889811210"}
0005434215640	E43CB8	9223 858757	VADIM STEPANOV	{"phone": "+70110614413"}
0005434215641	E43CB8	5080 714085	OLEG MELNIKOV	{"email": "melnikov-o.1967@postgrespro.ru", "phone": "+70428035539"}
0005434215642	AC61C2	1441 029986	DANIIL KAZAKOV	{"phone": "+70486705845"}
0005434215643	A61E8F	1877 341960	ALEKSEY IVANOV	{"email": "ivanov-aleksey_051980@postgrespro.ru", "phone": "+70713803878"}
0005434215644	42D38A	0508 310740	MARIYA LEBEDEVA	{"email": "mlebedeva.071981@postgrespro.ru", "phone": "+70396464802"}
0005434215645	8BAE65	4194 148560	DANILA SOLOVEV	{"phone": "+70968027667"}
0005434215646	567900	8780 449195	IRINA DAVYDOVA	{"email": "idavydova101964@postgrespro.ru", "phone": "+70808735876"}
0005434215647	567900	6650 873057	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr.10071973@postgrespro.ru", "phone": "+70727373215"}
0005434215648	019E60	9266 101624	IRINA OSIPOVA	{"phone": "+70175583474"}
0005434215649	66A6BB	5103 293073	VLADIMIR KRASNOV	{"phone": "+70525997805"}
0005434215650	7766A3	5671 950754	ANASTASIYA MAKAROVA	{"phone": "+70152219095"}
0005434215651	7766A3	3857 757824	ANNA EGOROVA	{"email": "egorova_anna1973@postgrespro.ru", "phone": "+70836906390"}
0005434215652	7766A3	4343 158249	GLEB KISELEV	{"phone": "+70591971748"}
0005434215653	6C034E	0557 364598	EGOR MAKSIMOV	{"email": "maksimov.e111972@postgrespro.ru", "phone": "+70575082935"}
0005434215654	6C034E	6319 150624	MARIYA SOROKINA	{"email": "m_sorokina-1973@postgrespro.ru", "phone": "+70932750299"}
0005434215655	7B3FA4	9030 518603	TAMARA GUSEVA	{"phone": "+70468466472"}
0005434215656	2164AA	8560 055153	ILDAR SOLOVEV	{"email": "solovev.ildar_16121975@postgrespro.ru", "phone": "+70909375176"}
0005434215657	2164AA	1550 592014	NIKOLAY PETROV	{"phone": "+70420702715"}
0005434215658	2164AA	0336 199720	NINA CHERNOVA	{"phone": "+70409970176"}
0005434215659	32ADF1	0295 610467	NINA GERASIMOVA	{"email": "nina.gerasimova041961@postgrespro.ru", "phone": "+70933561128"}
0005434215660	CC3381	7106 818751	ANASTASIYA NIKITINA	{"email": "a.nikitina081969@postgrespro.ru", "phone": "+70613936449"}
0005434215661	1C24E9	8928 577038	EVGENIYA BELOVA	{"phone": "+70541219883"}
0005434215662	65F4F8	1858 655073	ANNA FADEEVA	{"email": "a-fadeeva.1965@postgrespro.ru", "phone": "+70434697817"}
0005434215663	9E5388	2125 692977	OLESYA KONDRATEVA	{"email": "olesya_kondrateva_041976@postgrespro.ru", "phone": "+70153568313"}
0005434215664	72FF90	5737 579838	MARIYA POPOVA	{"email": "popova_m_1974@postgrespro.ru", "phone": "+70717831849"}
0005434215665	72FF90	4272 886153	NIKOLAY KARPOV	{"phone": "+70678025746"}
0005434215666	72FF90	7677 042761	NATALYA VLASOVA	{"email": "natalya-vlasova-06021975@postgrespro.ru", "phone": "+70793279615"}
0005434215667	5437C8	0092 362770	LYUDMILA YUDINA	{"email": "lyudmilayudina.12101968@postgrespro.ru", "phone": "+70711505583"}
0005434215668	9C0189	0183 904750	IVAN IVANOV	{"email": "ivanivanov-1974@postgrespro.ru", "phone": "+70971986158"}
0005434215669	53328C	3616 489222	VYACHESLAV IVANOV	{"phone": "+70693113406"}
0005434215670	83329C	3601 388013	IGOR FOMIN	{"phone": "+70734638870"}
0005434215671	C4E4FB	8854 123682	LYUBOV ISAEVA	{"phone": "+70971285578"}
0005434215672	C4E4FB	9904 886173	ANATOLIY SMIRNOV	{"phone": "+70520872687"}
0005434215673	D65CB3	0688 209136	PAVEL NIKITIN	{"email": "pavelnikitin.24021971@postgrespro.ru", "phone": "+70840159895"}
0005434215674	8B0C3A	5360 792124	ELENA GRISHINA	{"phone": "+70267823285"}
0005434215675	75DC80	4870 506247	VIKTORIYA BARANOVA	{"phone": "+70845870436"}
0005434215676	80DEB2	1812 008138	PAVEL ZHURAVLEV	{"phone": "+70100579588"}
0005434215677	05D3A1	0943 990369	YULIYA GERASIMOVA	{"phone": "+70819116138"}
0005434215678	358C15	6022 785845	GALINA AKIMOVA	{"email": "akimova_galina.24101980@postgrespro.ru", "phone": "+70911007541"}
0005434215679	76F39C	2514 976924	RUSLAN PETROV	{"phone": "+70671451793"}
0005434215680	76F39C	9017 327328	STANISLAV MAKSIMOV	{"email": "stanislavmaksimov.08091969@postgrespro.ru", "phone": "+70541966379"}
0005434215681	DAFBC8	3256 222900	SERGEY STEPANOV	{"phone": "+70077561293"}
0005434215682	3A8B0E	9519 632876	NINA PAVLOVA	{"email": "n-pavlova10031974@postgrespro.ru", "phone": "+70330827179"}
0005434215683	3A8B0E	3821 437510	ALEKSANDR SOROKIN	{"phone": "+70788609935"}
0005434215684	3A8B0E	7771 295678	MARINA GAVRILOVA	{"phone": "+70434725729"}
0005434215685	210638	9341 367203	EKATERINA GUSEVA	{"phone": "+70974356451"}
0005434215686	0BB74D	3659 080246	SVETLANA POPOVA	{"phone": "+70140990544"}
0005434215687	3A3647	0572 477017	RAISA ZAYCEVA	{"phone": "+70696345731"}
0005434215688	274DF3	6425 639537	ANDREY GUSEV	{"email": "a.gusev_061976@postgrespro.ru", "phone": "+70255081134"}
0005434215689	274DF3	4029 968355	NATALYA MOISEEVA	{"phone": "+70381596394"}
0005434215690	A4F0F4	1085 390697	SVETLANA DMITRIEVA	{"email": "dmitrieva_s_041961@postgrespro.ru", "phone": "+70752277285"}
0005434215746	5088E8	6094 353708	ANNA ANDREEVA	{"phone": "+70235804488"}
0005434215691	82EE3E	7256 333215	ALEKSANDR MAKAROV	{"email": "a.makarov.011967@postgrespro.ru", "phone": "+70298662989"}
0005434215692	DFA2E0	4387 682599	ANATOLIY ALEKSEEV	{"email": "anatoliy_alekseev-121968@postgrespro.ru", "phone": "+70373448036"}
0005434215693	FFEA04	0262 552146	OLEG IVANOV	{"email": "olegivanov-23041971@postgrespro.ru", "phone": "+70252253182"}
0005434215694	E5B330	6514 677606	MIKHAIL ALEKSANDROV	{"email": "aleksandrovmikhail30041973@postgrespro.ru", "phone": "+70301730473"}
0005434215695	394AD1	6603 659964	VIKTOR KUZMIN	{"email": "viktorkuzmin.1973@postgrespro.ru", "phone": "+70665152997"}
0005434215696	394AD1	0502 738464	NATALYA VASILEVA	{"email": "vasileva-n_18101974@postgrespro.ru", "phone": "+70080873933"}
0005434215697	C33C9E	5551 330157	YURIY SOLOVEV	{"phone": "+70661361492"}
0005434215698	C33C9E	8733 411162	NINA MAKSIMOVA	{"email": "maksimova.n-111967@postgrespro.ru", "phone": "+70406171647"}
0005434215699	F9C47D	7284 389350	ELENA MOISEEVA	{"email": "e-moiseeva.031961@postgrespro.ru", "phone": "+70404942244"}
0005434215700	6E0DD7	8576 639048	NIKOLAY ZHUKOV	{"email": "zhukovnikolay_11121974@postgrespro.ru", "phone": "+70140496997"}
0005434215701	6E0DD7	0068 820708	ANTONINA SOLOVEVA	{"phone": "+70761772854"}
0005434215702	D26CD6	2379 222974	ELENA TROFIMOVA	{"phone": "+70499223449"}
0005434215703	AEFF7C	8785 946944	NIKITA KUDRYASHOV	{"email": "kudryashovnikita13011970@postgrespro.ru", "phone": "+70158610704"}
0005434215704	C370E5	0124 505833	ELENA SEMENOVA	{"email": "semenova-e121966@postgrespro.ru", "phone": "+70332517755"}
0005434215705	7A6DBF	3153 032072	IRINA DMITRIEVA	{"email": "idmitrieva-111974@postgrespro.ru", "phone": "+70368291619"}
0005434215706	FC425C	3489 816254	MARIYA ABRAMOVA	{"phone": "+70817338440"}
0005434215707	FC425C	2130 108715	RAISA NOVIKOVA	{"email": "novikova_r.061979@postgrespro.ru", "phone": "+70690052007"}
0005434215708	FC425C	3686 706870	NADEZHDA YUDINA	{"email": "yudina-nadezhda1965@postgrespro.ru", "phone": "+70397636619"}
0005434215709	C5CD03	8615 215908	LIDIYA PAVLOVA	{"email": "lidiyapavlova.111964@postgrespro.ru", "phone": "+70000120680"}
0005434215710	C5CD03	2165 841013	ANNA ILINA	{"email": "ilina_a-1984@postgrespro.ru", "phone": "+70479143047"}
0005434215711	BCEDCC	8837 963008	OLGA VASILEVA	{"email": "o_vasileva_091971@postgrespro.ru", "phone": "+70108669549"}
0005434215712	BCEDCC	6085 751185	RAILYA ANDREEVA	{"email": "andreeva-r.051974@postgrespro.ru", "phone": "+70132203764"}
0005434215713	CAEA13	0518 195820	ELENA BELYAEVA	{"phone": "+70117637497"}
0005434215714	CAEA13	3416 279243	EVDOKIYA YUDINA	{"phone": "+70066164165"}
0005434215715	A75497	0568 091255	ALEKSEY KOROLEV	{"phone": "+70638681362"}
0005434215716	A75497	7431 738310	ALEKSEY IVANOV	{"phone": "+70687976874"}
0005434215717	A75497	9649 556720	ELENA SAVELEVA	{"email": "elena-saveleva061962@postgrespro.ru", "phone": "+70219416528"}
0005434215718	A75497	2507 459763	OLGA TIMOFEEVA	{"email": "timofeeva-o.17021968@postgrespro.ru", "phone": "+70862861503"}
0005434215719	302B8D	7024 525583	ANNA NAUMOVA	{"phone": "+70304812188"}
0005434215720	46CE28	7937 703658	VALENTINA KUZNECOVA	{"phone": "+70550035493"}
0005434215721	46CE28	5814 642968	NINA NIKOLAEVA	{"phone": "+70153562158"}
0005434215722	FED4F0	8362 587843	IRINA MATVEEVA	{"email": "irina_matveeva-031966@postgrespro.ru", "phone": "+70523602596"}
0005434215723	FED4F0	1466 682080	PAVEL SMIRNOV	{"phone": "+70864752823"}
0005434215724	EF305A	4333 592994	DINARA VOLKOVA	{"phone": "+70280669110"}
0005434215725	EF305A	3596 888862	ANNA GORBUNOVA	{"phone": "+70250026625"}
0005434215726	B8D098	9909 657846	ALEKSANDR SIDOROV	{"phone": "+70517663745"}
0005434215727	B8D098	2543 920881	ALEKSANDR FOMIN	{"email": "aleksandr.fomin_1974@postgrespro.ru", "phone": "+70481829182"}
0005434215728	A5F0B4	3890 562312	TATYANA KOLESNIKOVA	{"email": "kolesnikova_tatyana07061970@postgrespro.ru", "phone": "+70720777311"}
0005434215729	A5F0B4	3165 379451	VERONIKA GUSEVA	{"phone": "+70603337971"}
0005434215730	49B258	2331 274878	NINA TARASOVA	{"email": "n_tarasova.1970@postgrespro.ru", "phone": "+70196342126"}
0005434215731	607B52	3677 905797	MARGARITA ANDREEVA	{"phone": "+70575040046"}
0005434215732	967580	7476 626522	OLEG GUSEV	{"email": "oleg_gusev-1981@postgrespro.ru", "phone": "+70115429684"}
0005434215733	967580	5002 617241	VASILIY KOROLEV	{"phone": "+70124754139"}
0005434215734	3B7920	1772 759918	GALINA AKIMOVA	{"email": "akimova_galina1983@postgrespro.ru", "phone": "+70903795933"}
0005434215735	49837C	3223 545003	LADA IVANOVA	{"email": "l-ivanova_1989@postgrespro.ru", "phone": "+70022807908"}
0005434215736	49837C	2557 748502	SVETLANA VASILEVA	{"phone": "+70576112484"}
0005434215737	49837C	9896 121809	ANTONINA TIKHONOVA	{"phone": "+70752162490"}
0005434215738	673385	7595 644238	MATVEY KOZLOV	{"email": "matvey.kozlov-19041965@postgrespro.ru", "phone": "+70350940430"}
0005434215739	B555B0	4013 540550	GALINA MIKHAYLOVA	{"email": "g-mikhaylova-1968@postgrespro.ru", "phone": "+70320488225"}
0005434215740	B555B0	3547 138821	YANA KUZMINA	{"email": "kuzmina_yana24041979@postgrespro.ru", "phone": "+70428585628"}
0005434215741	EEA9DA	2992 015350	ALEKSANDR GAVRILOV	{"email": "gavrilov.aleksandr011978@postgrespro.ru", "phone": "+70613038131"}
0005434215742	EEA9DA	6314 622650	GENNADIY KOZLOV	{"phone": "+70266488025"}
0005434215743	EEA9DA	8718 881996	OKSANA ZHUKOVA	{"phone": "+70911118828"}
0005434215744	888730	1144 254019	ARTEM SEMENOV	{"email": "a.semenov_12051976@postgrespro.ru", "phone": "+70048502862"}
0005434215745	36F692	9211 064541	ANATOLIY KUZMIN	{"email": "kuzmin.anatoliy.051972@postgrespro.ru", "phone": "+70797281888"}
0005434215747	F68F46	8959 427179	VYACHESLAV MOROZOV	{"phone": "+70728985299"}
0005434215748	017158	2278 180696	EKATERINA VLASOVA	{"phone": "+70655363197"}
0005434215749	5A6F23	3109 549043	NATALYA FROLOVA	{"email": "frolova.n.031969@postgrespro.ru", "phone": "+70930058340"}
0005434215750	12C62F	1706 391979	ZOYA KUZNECOVA	{"phone": "+70376829951"}
0005434215751	DA9005	4300 563712	ALEKSEY GRIGOREV	{"email": "grigorev.aleksey.29011975@postgrespro.ru", "phone": "+70389765793"}
0005434215752	E39992	9248 221408	DMITRIY OSIPOV	{"phone": "+70138149148"}
0005434215753	E39992	1915 268723	VLADIMIR SOROKIN	{"email": "v_sorokin-01021984@postgrespro.ru", "phone": "+70035076519"}
0005434215754	E39992	0889 193678	ALEKSANDR KUZNECOV	{"phone": "+70373562730"}
0005434215755	E391B4	4932 690278	ELENA BORISOVA	{"email": "e.borisova-1973@postgrespro.ru", "phone": "+70188964915"}
0005434215756	5E9F2D	9625 678317	ALEKSANDRA ANDREEVA	{"email": "a.andreeva-031973@postgrespro.ru", "phone": "+70393588856"}
0005434215757	E80F3C	1661 638855	ANATOLIY GUSEV	{"email": "a.gusev-1989@postgrespro.ru", "phone": "+70586119312"}
0005434215758	8AA4D2	7610 343087	IVAN OSIPOV	{"phone": "+70388076596"}
0005434215759	C88B87	4686 037730	RAZIYA LAZAREVA	{"email": "r-lazareva.021975@postgrespro.ru", "phone": "+70334800451"}
0005434215760	5012C0	3714 698692	PAVEL VOROBEV	{"phone": "+70086606537"}
0005434215761	9D62F8	0093 451990	SERGEY SMIRNOV	{"phone": "+70970326640"}
0005434215762	9D62F8	8549 575406	IRINA ZAKHAROVA	{"email": "zakharova.i_21011974@postgrespro.ru", "phone": "+70159391396"}
0005434215763	9D62F8	1213 459581	NIKOLAY NIKOLAEV	{"email": "nikolaevnikolay.10041971@postgrespro.ru", "phone": "+70490919565"}
0005434215764	AAFA35	4365 273912	MARAT MAKAROV	{"email": "makarov_marat041969@postgrespro.ru", "phone": "+70469190626"}
0005434215765	8E2875	4090 237389	MAKSIM NAZAROV	{"phone": "+70427828880"}
0005434215766	D98AEF	0931 873251	ANDREY FEDOROV	{"email": "afedorov_1977@postgrespro.ru", "phone": "+70954413100"}
0005434215767	79D503	2322 695087	ALEKSANDR VOLKOV	{"phone": "+70068555636"}
0005434215768	79D503	4543 546342	LEONID MIRONOV	{"email": "mironov-leonid21041972@postgrespro.ru", "phone": "+70659608077"}
0005434215825	96B502	7156 702546	VIKTOR GERASIMOV	{"phone": "+70119139601"}
0005434215769	199948	3597 683254	TATYANA MALYSHEVA	{"email": "malysheva-tatyana_011972@postgrespro.ru", "phone": "+70125558627"}
0005434215770	97944E	0350 383372	ANDREY KARPOV	{"email": "a-karpov.1981@postgrespro.ru", "phone": "+70922281665"}
0005434215771	FC4DE0	5174 858417	DMITRIY SEMENOV	{"email": "dmitriy-semenov.1971@postgrespro.ru", "phone": "+70486763439"}
0005434215772	FC4DE0	2124 938321	RISHAT BORISOV	{"phone": "+70302902179"}
0005434215773	A17DAE	9537 751107	RAVIL KAZAKOV	{"phone": "+70980020502"}
0005434215774	A17DAE	7628 796727	GALINA ZHURAVLEVA	{"phone": "+70785818415"}
0005434215775	FD0E2D	3427 569612	YAROSLAV SCHERBAKOV	{"phone": "+70353727052"}
0005434215776	975D35	2409 726069	KSENIYA SOLOVEVA	{"phone": "+70771659439"}
0005434215777	55C836	5510 179968	ALBINA IVANOVA	{"phone": "+70418541061"}
0005434215778	3265B4	8433 083590	SERGEY MELNIKOV	{"phone": "+70742362366"}
0005434215779	2DEBAB	7133 486109	MARIYA DENISOVA	{"phone": "+70243472190"}
0005434215780	98F4C2	1363 949724	NATALYA MEDVEDEVA	{"phone": "+70392330644"}
0005434215781	994EEC	2409 130346	YURIY KUDRYASHOV	{"phone": "+70282161643"}
0005434215782	832AA6	2068 925873	RUSTAM MAKAROV	{"email": "r-makarov-02111977@postgrespro.ru", "phone": "+70212982169"}
0005434215783	92C95F	6776 188391	IVAN SCHERBAKOV	{"phone": "+70188347266"}
0005434215784	98BDB3	0712 827419	ANNA PAVLOVA	{"email": "pavlovaa071973@postgrespro.ru", "phone": "+70523964067"}
0005434215785	FF289F	9428 384006	VYACHESLAV SEMENOV	{"email": "vsemenov-1970@postgrespro.ru", "phone": "+70545046471"}
0005434215786	FF289F	3933 294279	KLAVDIYA MELNIKOVA	{"email": "k_melnikova-15011967@postgrespro.ru", "phone": "+70691996836"}
0005434215787	602021	1401 490044	VITALIY NIKOLAEV	{"email": "nikolaevvitaliy25091962@postgrespro.ru", "phone": "+70301738918"}
0005434215788	BA5CFD	6836 360721	YURIY TARASOV	{"email": "tarasov.y17021965@postgrespro.ru", "phone": "+70168618708"}
0005434215789	9DC856	5821 813792	VALENTINA BELYAEVA	{"email": "belyaeva_v_30071972@postgrespro.ru", "phone": "+70508899942"}
0005434215790	D6FCD4	4728 779459	SANIYA POTAPOVA	{"phone": "+70917110388"}
0005434215791	F7B45D	0255 642738	YULIYA SOLOVEVA	{"email": "soloveva.y.091972@postgrespro.ru", "phone": "+70303644691"}
0005434215792	F7B45D	3655 969349	POLINA MAKAROVA	{"phone": "+70188561715"}
0005434215793	71DD7E	4960 583543	IGOR MELNIKOV	{"email": "igor_melnikov-08021980@postgrespro.ru", "phone": "+70946846018"}
0005434215794	637CA0	7744 849058	OLGA IVANOVA	{"phone": "+70579410335"}
0005434215795	CA5B76	2376 003673	VENIAMIN NAUMOV	{"email": "naumov_veniamin11121964@postgrespro.ru", "phone": "+70379820203"}
0005434215796	2CBB43	2933 307808	MARIYA KOVALEVA	{"email": "kovaleva_mariya28041978@postgrespro.ru", "phone": "+70969323918"}
0005434215797	2CBB43	7434 013359	ALEKSEY SEMENOV	{"email": "alekseysemenov17091973@postgrespro.ru", "phone": "+70770960598"}
0005434215798	F9576D	7916 517565	MARGARITA AKIMOVA	{"phone": "+70459854227"}
0005434215799	F9576D	7511 270477	VERA EFREMOVA	{"email": "efremovav.081971@postgrespro.ru", "phone": "+70253957895"}
0005434215800	F9576D	3933 705391	ALEKSANDR SCHERBAKOV	{"phone": "+70537453082"}
0005434215801	C4A194	9251 032006	PAVEL SMIRNOV	{"email": "smirnov-pavel_121959@postgrespro.ru", "phone": "+70558545893"}
0005434215802	AE7FCB	6444 010979	NINA BORISOVA	{"email": "ninaborisova_061982@postgrespro.ru", "phone": "+70951307189"}
0005434215803	0102D8	6604 181676	VIKTORIYA FEDOROVA	{"email": "fedorova.viktoriya-31031977@postgrespro.ru", "phone": "+70021381579"}
0005434215804	91C46C	5137 328200	SEMEN SOROKIN	{"email": "semensorokin-1980@postgrespro.ru", "phone": "+70667045865"}
0005434215805	91C46C	6515 924429	MARIYA BORISOVA	{"email": "borisova.mariya.101969@postgrespro.ru", "phone": "+70196574216"}
0005434215806	41CF5A	7403 923696	SVETLANA TIKHONOVA	{"phone": "+70822109551"}
0005434215807	09E281	7139 934499	NIKOLAY SMIRNOV	{"phone": "+70921248548"}
0005434215808	09E281	7534 429740	ALEVTINA RYABOVA	{"email": "ryabova_alevtina_051970@postgrespro.ru", "phone": "+70782283382"}
0005434215809	219044	5968 341250	DMITRIY MELNIKOV	{"email": "dmelnikov_021969@postgrespro.ru", "phone": "+70625247949"}
0005434215810	069FDE	5117 704259	YULIYA MAKAROVA	{"phone": "+70502094736"}
0005434215811	069FDE	4668 575153	VALERIY SMIRNOV	{"phone": "+70620266183"}
0005434215812	069FDE	3009 198408	ANNA DENISOVA	{"email": "denisova.anna03031972@postgrespro.ru", "phone": "+70618436703"}
0005434215813	7E276F	7039 513971	YULIYA VOROBEVA	{"phone": "+70582104706"}
0005434215814	17C5AF	9117 382924	SERGEY MOROZOV	{"email": "morozov.s_1958@postgrespro.ru", "phone": "+70237812185"}
0005434215815	17C5AF	7432 694884	IRINA ARKHIPOVA	{"email": "i.arkhipova14071969@postgrespro.ru", "phone": "+70255247564"}
0005434215816	AE0588	9039 149525	GALINA YAKOVLEVA	{"phone": "+70835537212"}
0005434215817	5259C4	3794 174681	NIKOLAY BONDARENKO	{"phone": "+70647090534"}
0005434215818	4F255E	8780 624384	MAKSIM FOMIN	{"email": "maksim_fomin_091977@postgrespro.ru", "phone": "+70411572452"}
0005434215819	742C6D	7081 706723	TATYANA MASLOVA	{"phone": "+70589589875"}
0005434215820	AE2EA5	5193 050060	SERGEY KOROLEV	{"email": "s.korolev.031977@postgrespro.ru", "phone": "+70864513099"}
0005434215821	CCCBD8	0784 873190	NIKOLAY KOZLOV	{"phone": "+70383333570"}
0005434215822	CCCBD8	2509 652925	OLGA KOLESNIKOVA	{"phone": "+70862641006"}
0005434215823	931338	4915 942569	ALEKSANDR SERGEEV	{"phone": "+70456073162"}
0005434215824	931338	1181 734247	VALERIY KOZLOV	{"email": "kozlov_v-1984@postgrespro.ru", "phone": "+70657556266"}
0005434215826	30D362	2060 697754	NATALYA AKIMOVA	{"phone": "+70823590611"}
0005434215827	30D362	2085 680777	VALERIYA NAZAROVA	{"email": "nazarovav07011970@postgrespro.ru", "phone": "+70962054582"}
0005434215828	00EBC0	7254 735791	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova.31011974@postgrespro.ru", "phone": "+70631702822"}
0005434215829	00EBC0	7766 089649	LYUDMILA AKIMOVA	{"phone": "+70637787720"}
0005434215830	271B97	6410 127219	ANTONINA POPOVA	{"email": "a_popova.30031968@postgrespro.ru", "phone": "+70177090652"}
0005434215831	2A8394	3493 556101	YURIY SERGEEV	{"email": "sergeev.yuriy.1970@postgrespro.ru", "phone": "+70771242508"}
0005434215832	26FB28	5349 362886	SERGEY SMIRNOV	{"phone": "+70276381972"}
0005434215833	26FB28	3476 178743	VITALIY TIKHONOV	{"phone": "+70492926999"}
0005434215834	26DD23	5715 091045	ANNA VOROBEVA	{"email": "anna-vorobeva-01111982@postgrespro.ru", "phone": "+70537335237"}
0005434215835	26DD23	9240 301228	ALEKSEY YAKOVLEV	{"phone": "+70000420950"}
0005434215836	CD2040	1166 728949	SOFIYA IVANOVA	{"phone": "+70575752728"}
0005434215837	CD2040	1293 428018	EDUARD KAZAKOV	{"email": "eduard-kazakov-25061974@postgrespro.ru", "phone": "+70484722732"}
0005434215838	CD2040	6131 168555	LYUBOV NAZAROVA	{"email": "l-nazarova.1972@postgrespro.ru", "phone": "+70864468013"}
0005434215839	29940D	7725 223365	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr.031975@postgrespro.ru", "phone": "+70094758349"}
0005434215840	BD1C1B	4831 245726	ANNA NIKIFOROVA	{"email": "anna_nikiforova1971@postgrespro.ru", "phone": "+70633980933"}
0005434215841	BD4CED	7110 876235	VIKTOR GRIGOREV	{"phone": "+70106157445"}
0005434215842	BD4CED	1224 483588	DARYA KRASNOVA	{"phone": "+70373193867"}
0005434215843	50A848	2149 132309	GALINA KOROLEVA	{"email": "koroleva-g.27031976@postgrespro.ru", "phone": "+70826330300"}
0005434215844	50A848	7331 392473	ELENA CHERNOVA	{"email": "elena-chernova1975@postgrespro.ru", "phone": "+70895124590"}
0005434215845	8D4108	7196 947654	RAISA FADEEVA	{"email": "fadeeva-raisa_1964@postgrespro.ru", "phone": "+70730180657"}
0005434215846	EAE6B5	9746 343378	LYUDMILA DMITRIEVA	{"email": "dmitrieval051976@postgrespro.ru", "phone": "+70614499852"}
0005434215847	40CA10	9804 043359	OKSANA KUZNECOVA	{"phone": "+70329716898"}
0005434215848	F935C4	2587 875089	ALEKSANDR MOROZOV	{"email": "a_morozov-03121977@postgrespro.ru", "phone": "+70410290485"}
0005434215849	73897C	2718 142534	TAMARA KALININA	{"phone": "+70185186672"}
0005434215850	73897C	4510 204042	ANTON GAVRILOV	{"email": "anton-gavrilov-04011974@postgrespro.ru", "phone": "+70358219786"}
0005434215851	7D1419	8356 345577	NINA STEPANOVA	{"email": "nina_stepanova_01051969@postgrespro.ru", "phone": "+70939565669"}
0005434215852	7D1419	3687 496214	YURIY NOVIKOV	{"phone": "+70048407402"}
0005434215853	FFFB27	9825 850339	ALENA YAKOVLEVA	{"email": "yakovleva_alena-14011971@postgrespro.ru", "phone": "+70174954738"}
0005434215854	DA88B0	0184 625467	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev_1973@postgrespro.ru", "phone": "+70077576518"}
0005434215855	DA88B0	7228 414192	SVETLANA NIKIFOROVA	{"email": "s_nikiforova-28021977@postgrespro.ru", "phone": "+70646469379"}
0005434215856	1983C9	6704 538182	LIDIYA NIKITINA	{"phone": "+70231696110"}
0005434215857	1F2231	4929 716472	LYUBOV KOZLOVA	{"phone": "+70675733307"}
0005434215858	2C05DA	6888 020378	ALEKSANDR VOLKOV	{"phone": "+70347227093"}
0005434215859	2A4A28	9362 719919	VIKTOR BARANOV	{"email": "viktor-baranov_04051962@postgrespro.ru", "phone": "+70235683698"}
0005434215860	2A4A28	3252 100878	ALFIYA IVANOVA	{"phone": "+70377649297"}
0005434215861	B16A66	9356 695632	NATALYA MAKSIMOVA	{"email": "n_maksimova_061983@postgrespro.ru", "phone": "+70604984691"}
0005434215862	B16A66	7715 097449	LYUDMILA KAZAKOVA	{"phone": "+70681666554"}
0005434215863	E31712	6921 626935	GRIGORIY ROMANOV	{"phone": "+70434261457"}
0005434215864	E31712	5637 912307	YAROSLAV KUZNECOV	{"email": "y.kuznecov091967@postgrespro.ru", "phone": "+70455726742"}
0005434215865	3CC4E0	8575 496874	VALENTINA VOROBEVA	{"email": "valentina_vorobeva.1984@postgrespro.ru", "phone": "+70515056813"}
0005434215866	3CC4E0	9004 289102	ALEKSANDR ILIN	{"phone": "+70724277419"}
0005434215867	6D8303	3663 355495	VLADIMIR ALEKSANDROV	{"email": "v-aleksandrov_19091970@postgrespro.ru", "phone": "+70057256029"}
0005434215868	7D64F0	4250 650805	MARIYA KOLESNIKOVA	{"phone": "+70858211632"}
0005434215869	0411E9	1461 474739	IRINA STEPANOVA	{"email": "istepanova1974@postgrespro.ru", "phone": "+70558379688"}
0005434215870	0411E9	9881 425410	VLADIMIR KUZNECOV	{"email": "kuznecov-v-23101965@postgrespro.ru", "phone": "+70123359953"}
0005434215871	BE6D9F	7751 407840	ALEKSANDR MAKSIMOV	{"email": "maksimov_aleksandr-28121964@postgrespro.ru", "phone": "+70821210844"}
0005434215872	10E9F7	4938 524610	LARISA MALYSHEVA	{"phone": "+70602226033"}
0005434215873	173689	5320 273188	ALEKSEY EGOROV	{"email": "egorov-aleksey.10041988@postgrespro.ru", "phone": "+70280195939"}
0005434215874	1C63E9	6073 151296	ALBERT IVANOV	{"email": "albert-ivanov.081973@postgrespro.ru", "phone": "+70921089808"}
0005434215875	1C63E9	5471 141439	VALENTIN VOLKOV	{"email": "valentinvolkov.29111968@postgrespro.ru", "phone": "+70041033648"}
0005434215876	0E67AB	3129 201058	VLADIMIR GERASIMOV	{"phone": "+70597148458"}
0005434215877	0E67AB	4931 624289	SERGEY TARASOV	{"phone": "+70906498674"}
0005434215878	CE9690	3920 350060	SERGEY ILIN	{"email": "s_ilin.121985@postgrespro.ru", "phone": "+70484992000"}
0005434215879	44D4FD	2832 799568	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_26021964@postgrespro.ru", "phone": "+70073523913"}
0005434215880	44D4FD	0719 223220	IVAN ROMANOV	{"email": "ivan_romanov_1963@postgrespro.ru", "phone": "+70838935168"}
0005434215881	8F3C35	4430 881982	YURIY ORLOV	{"email": "y_orlov-1963@postgrespro.ru", "phone": "+70595386752"}
0005434215882	6FDC22	4339 112179	ELENA DENISOVA	{"email": "denisovae-05081974@postgrespro.ru", "phone": "+70047171015"}
0005434215883	6FDC22	5973 481458	SERGEY SCHERBAKOV	{"phone": "+70034663137"}
0005434215884	6FDC22	8376 075685	ALEKSANDR MOROZOV	{"phone": "+70603640346"}
0005434215885	554F08	0033 626339	SERGEY GRIGOREV	{"email": "grigorevs.30061968@postgrespro.ru", "phone": "+70904895416"}
0005434215886	554F08	4414 463504	MARIYA VLASOVA	{"phone": "+70565396220"}
0005434215887	839944	2632 103694	ALEKSANDR MEDVEDEV	{"phone": "+70133658187"}
0005434215888	46CEA0	5208 970664	VIKTOR FROLOV	{"email": "viktor_frolov.15041969@postgrespro.ru", "phone": "+70023135243"}
0005434215889	FCF5F7	5899 530341	GALINA YAKOVLEVA	{"email": "galinayakovleva-1977@postgrespro.ru", "phone": "+70647634455"}
0005434215890	FCF5F7	3002 939945	ALEKSANDR IVANOV	{"phone": "+70419849737"}
0005434215891	19B493	7558 635112	VASILIY MOROZOV	{"email": "morozov_v-07111967@postgrespro.ru", "phone": "+70514375624"}
0005434215892	AE9CF7	9396 080906	ARTEM IVANOV	{"phone": "+70090285114"}
0005434215893	5FAF2B	0273 300357	ELENA ANDREEVA	{"phone": "+70598131615"}
0005434215894	1F3737	1944 050258	VIKTOR ILIN	{"email": "viktorilin_121972@postgrespro.ru", "phone": "+70243301178"}
0005434215895	CFA3E7	9542 636833	VIKTOR ROMANOV	{"phone": "+70244198105"}
0005434215896	CFA3E7	5927 403058	VALENTINA BELOVA	{"email": "belova_valentina1973@postgrespro.ru", "phone": "+70442082365"}
0005434215897	CFA3E7	8035 795529	ANNA MATVEEVA	{"phone": "+70990835627"}
0005434215898	F675CA	9178 411843	OLEG SMIRNOV	{"email": "smirnov-oleg_20051981@postgrespro.ru", "phone": "+70290468462"}
0005434215899	F675CA	0010 815095	VLADIMIR BARANOV	{"email": "vladimir_baranov061964@postgrespro.ru", "phone": "+70597263803"}
0005434215900	110B82	8704 248755	ALEKSANDR ZAKHAROV	{"email": "azakharov_071979@postgrespro.ru", "phone": "+70332139109"}
0005434215901	110B82	8843 809101	DMITRIY KOROLEV	{"phone": "+70802276506"}
0005434215902	3155F5	4365 522542	VALENTINA ZOTOVA	{"phone": "+70305539004"}
0005434215903	D1234D	3601 125383	YULIYA NOVIKOVA	{"phone": "+70741387581"}
0005434215904	D1234D	1156 783146	NINA ALEKSANDROVA	{"phone": "+70305979109"}
0005434215905	1F9605	0076 544041	NIKOLAY CHERNOV	{"email": "chernov.nikolay061974@postgrespro.ru", "phone": "+70111142538"}
0005434215906	1F9605	9275 736893	TATYANA ABRAMOVA	{"phone": "+70622559975"}
0005434215907	758B23	9925 900427	ALEKSEY NAZAROV	{"phone": "+70107084494"}
0005434215908	AE0881	6013 925543	ALEKSANDR ANTONOV	{"phone": "+70784929394"}
0005434215909	AE0881	6409 519346	NATALYA PETROVA	{"email": "n-petrova-18071971@postgrespro.ru", "phone": "+70487118962"}
0005434215910	26DC41	0261 655501	OKSANA KUZNECOVA	{"email": "oksana-kuznecova_021979@postgrespro.ru", "phone": "+70008663977"}
0005434217894	BE14E8	6118 918116	ALEKSANDRA ANTONOVA	{"email": "a.antonova.011983@postgrespro.ru", "phone": "+70098159570"}
0005434217895	9529FE	4325 454468	MAKSIM NAZAROV	{"phone": "+70673844865"}
0005434217896	9529FE	6980 026897	GALINA GORBUNOVA	{"email": "g_gorbunova1962@postgrespro.ru", "phone": "+70520922294"}
0005434217897	12175C	9824 265940	VIKTORIYA POPOVA	{"email": "popova-v1983@postgrespro.ru", "phone": "+70493521185"}
0005434217898	12175C	4802 644190	VALENTIN TARASOV	{"phone": "+70946349311"}
0005434217899	52291E	8443 278704	NATALYA BORISOVA	{"email": "n.borisova1976@postgrespro.ru", "phone": "+70885793484"}
0005434217900	52291E	8204 898558	ALEKSANDR MOISEEV	{"email": "a-moiseev.121975@postgrespro.ru", "phone": "+70376761913"}
0005434217901	F10E60	7223 198284	VALERIY SHEVCHENKO	{"email": "v_shevchenko-1991@postgrespro.ru", "phone": "+70352735421"}
0005434217902	063F05	0697 773713	OLEG DMITRIEV	{"email": "oleg_dmitriev011974@postgrespro.ru", "phone": "+70957191722"}
0005434217903	05E0BA	0184 897404	MARIYA MOROZOVA	{"phone": "+70179522233"}
0005434217904	05E0BA	5199 754936	ELENA LOGINOVA	{"email": "loginova-e1972@postgrespro.ru", "phone": "+70842532550"}
0005434217905	CDE8A7	4782 167165	YULIYA POLYAKOVA	{"phone": "+70133439641"}
0005434217906	114E8B	7059 687016	NAILYA NIKOLAEVA	{"email": "nikolaevanailya.1967@postgrespro.ru", "phone": "+70641660742"}
0005434217907	114E8B	5567 532256	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev.12101973@postgrespro.ru", "phone": "+70180601589"}
0005434217908	5E280B	6354 592511	NATALYA KUZNECOVA	{"phone": "+70585211814"}
0005434217909	257C3C	7927 693709	TATYANA EGOROVA	{"email": "t-egorova_041981@postgrespro.ru", "phone": "+70890662790"}
0005434217910	DE6028	2520 708756	OLGA STEPANOVA	{"phone": "+70188150909"}
0005434217911	DE6028	1201 321848	VIKTORIYA DANILOVA	{"phone": "+70250397061"}
0005434217912	5BC5C2	0083 312712	SVETLANA KULIKOVA	{"email": "skulikova_25071975@postgrespro.ru", "phone": "+70811101465"}
0005434217913	9A8F5D	2296 057344	FAIL FEDOTOV	{"phone": "+70832988659"}
0005434217914	9A8F5D	6872 607943	BORIS IVANOV	{"email": "ivanov.boris_14121976@postgrespro.ru", "phone": "+70201485783"}
0005434217915	9A8F5D	4547 187920	NIKOLAY NAZAROV	{"phone": "+70163274541"}
0005434217916	A751FA	7888 389046	LIDIYA ROMANOVA	{"phone": "+70391843598"}
0005434217917	A751FA	6701 609855	ALEKSANDR MAKAROV	{"phone": "+70611828190"}
0005434217918	A751FA	3623 132379	SVETLANA NIKIFOROVA	{"email": "s.nikiforova.031967@postgrespro.ru", "phone": "+70678678567"}
0005434217919	B0B239	6082 769919	TATYANA BELOVA	{"email": "belovatatyana-27071981@postgrespro.ru", "phone": "+70778865651"}
0005434217920	B0B239	4486 746539	ANNA ZAYCEVA	{"phone": "+70382152117"}
0005434217921	DADE3E	1596 806163	TATYANA TITOVA	{"email": "titova-tatyana26011968@postgrespro.ru", "phone": "+70421381507"}
0005434217922	DADE3E	8094 077336	VLADIMIR KUZNECOV	{"email": "v.kuznecov.13121980@postgrespro.ru", "phone": "+70720460918"}
0005434217923	35EB69	4592 656169	YULIYA AFANASEVA	{"email": "y_afanaseva_1986@postgrespro.ru", "phone": "+70498078207"}
0005434217924	35EB69	0681 172552	ALEKSANDRA KONDRATEVA	{"email": "kondrateva-aleksandra_101967@postgrespro.ru", "phone": "+70369968224"}
0005434217925	221C1C	7851 525423	VITALIY IVANOV	{"phone": "+70067200968"}
0005434217926	75D5F4	8771 800503	ANDREY MIKHAYLOV	{"phone": "+70371261663"}
0005434217927	C3F479	8989 001740	TATYANA FOMINA	{"email": "tatyanafomina_29121968@postgrespro.ru", "phone": "+70466191054"}
0005434217928	607A13	7092 789450	IVAN FROLOV	{"phone": "+70068286714"}
0005434217929	607A13	1248 331224	ROMAN IVANOV	{"email": "ivanovroman_101967@postgrespro.ru", "phone": "+70930781453"}
0005434217930	6F23DB	8181 202933	ANATOLIY MOROZOV	{"phone": "+70510457947"}
0005434217931	D2CD04	2186 266513	ZINAIDA MASLOVA	{"phone": "+70724665539"}
0005434217932	BC3131	3343 433647	VYACHESLAV ALEKSEEV	{"email": "vyacheslav.alekseev_021968@postgrespro.ru", "phone": "+70767659125"}
0005434217933	842508	9312 720837	SOFYA ANDREEVA	{"email": "andreeva.sofya_081965@postgrespro.ru", "phone": "+70663945571"}
0005434217934	BBFAB3	9697 316221	KLAVDIYA BELOVA	{"phone": "+70194605847"}
0005434217935	BBFAB3	9065 857876	SVETLANA SOROKINA	{"email": "s.sorokina14121965@postgrespro.ru", "phone": "+70463224122"}
0005434217936	01EFE7	8124 725167	LIDIYA YUDINA	{"phone": "+70308966309"}
0005434217937	01EFE7	1631 930012	VERONIKA FILIPPOVA	{"email": "filippova_v.23111980@postgrespro.ru", "phone": "+70333491521"}
0005434217938	4F3822	9378 161569	NADEZHDA FEDOROVA	{"email": "fedorova-n_1973@postgrespro.ru", "phone": "+70116140766"}
0005434217939	4F3822	0516 579828	YANA FILATOVA	{"phone": "+70762599296"}
0005434217940	A5B00D	8743 980487	ANATOLIY DENISOV	{"email": "anatoliydenisov01041987@postgrespro.ru", "phone": "+70355119113"}
0005434217941	B6CD5F	3859 369096	DANILA NIKITIN	{"phone": "+70957268962"}
0005434217942	B6CD5F	9664 473163	LYUDMILA KUZMINA	{"email": "kuzminalyudmila031979@postgrespro.ru", "phone": "+70824475709"}
0005434217943	5F5B9A	2170 085070	VLADIMIR MATVEEV	{"phone": "+70475386333"}
0005434217944	076472	5415 258896	RAISA TIKHONOVA	{"phone": "+70177091949"}
0005434217945	6994D2	3844 918978	VITALIY SERGEEV	{"email": "v-sergeev.06121975@postgrespro.ru", "phone": "+70566321065"}
0005434217946	20B0A2	0930 911507	OLGA MAKAROVA	{"phone": "+70501945008"}
0005434217947	20B0A2	9349 277860	ARTUR MOROZOV	{"email": "arturmorozov.1958@postgrespro.ru", "phone": "+70717868250"}
0005434217948	224149	1009 616708	SERGEY FEDOTOV	{"email": "fedotov.s1971@postgrespro.ru", "phone": "+70140693173"}
0005434217949	224149	3611 181879	YANA AKIMOVA	{"email": "yana-akimova_031987@postgrespro.ru", "phone": "+70707620756"}
0005434217950	2B09E6	4723 552218	ALINA KISELEVA	{"phone": "+70462597999"}
0005434217951	2B09E6	1439 113852	TIMUR DMITRIEV	{"email": "dmitriev.timur-19121976@postgrespro.ru", "phone": "+70988758470"}
0005434217952	A9EC5F	3806 335118	ALEKSEY VOROBEV	{"email": "vorobeva_1981@postgrespro.ru", "phone": "+70961920974"}
0005434217953	698FCF	8112 661597	DANIL MOROZOV	{"phone": "+70681936240"}
0005434217954	165916	4736 678156	GALINA SMIRNOVA	{"email": "smirnovagalina_26031978@postgrespro.ru", "phone": "+70169662284"}
0005434217955	165916	3906 356527	VLADIMIR SMIRNOV	{"phone": "+70543970053"}
0005434217956	B9F093	1033 101970	ALEKSANDR MOROZOV	{"phone": "+70075248845"}
0005434217957	788731	5899 673068	MARINA KUZNECOVA	{"phone": "+70790442242"}
0005434217958	788731	3509 945506	MAKSIM KUZNECOV	{"phone": "+70559092143"}
0005434217959	D67BD0	4577 115801	NADEZHDA POPOVA	{"email": "popova-n17051982@postgrespro.ru", "phone": "+70015095367"}
0005434217960	D67BD0	3952 363412	ANASTASIYA MARTYNOVA	{"email": "amartynova_1963@postgrespro.ru", "phone": "+70489805014"}
0005434217961	D67BD0	4452 287871	SERGEY KUZNECOV	{"phone": "+70838389800"}
0005434217962	EC4B71	0408 138646	EGOR NOVIKOV	{"email": "egor_novikov1982@postgrespro.ru", "phone": "+70153110530"}
0005434217963	4FF2CF	9138 918409	DARYA FADEEVA	{"email": "fadeevadarya_09051975@postgrespro.ru", "phone": "+70071894158"}
0005434217964	4F9482	1383 615289	YULIYA EGOROVA	{"phone": "+70575323025"}
0005434217965	4F9482	5284 140346	ELENA FOMINA	{"phone": "+70886561796"}
0005434217966	EDB717	0113 425407	ANNA KUDRYASHOVA	{"phone": "+70737278498"}
0005434217967	226DAD	9557 491113	SERGEY YAKOVLEV	{"email": "yakovlev_sergey1971@postgrespro.ru", "phone": "+70353984169"}
0005434217968	226DAD	0420 165404	VLADIMIR SIDOROV	{"phone": "+70029015069"}
0005434217969	34BA24	8088 533536	MARIYA IVANOVA	{"email": "mariya.ivanova-16101970@postgrespro.ru", "phone": "+70111171863"}
0005434217970	34BA24	5333 370042	EVGENIY FROLOV	{"phone": "+70564253892"}
0005434217971	34BA24	4529 724384	VLADIMIR MAKAROV	{"email": "vladimir_makarov061976@postgrespro.ru", "phone": "+70738254636"}
0005434217972	7D6ED3	8310 845404	GEORGIY MAKSIMOV	{"phone": "+70219697908"}
0005434217973	84941E	5193 862359	YURIY YAKOVLEV	{"email": "y-yakovlev.1961@postgrespro.ru", "phone": "+70296131785"}
0005434217974	84941E	4450 561640	DMITRIY NAZAROV	{"email": "nazarov_d.111976@postgrespro.ru", "phone": "+70605663249"}
0005434217975	0B1DD9	9278 949033	PELAGEYA GAVRILOVA	{"phone": "+70423449211"}
0005434217976	0B1DD9	5669 994738	VIKTOR KOROLEV	{"email": "viktor.korolev1974@postgrespro.ru", "phone": "+70136476140"}
0005434217977	0B1DD9	2609 918186	ANDREY KISELEV	{"email": "kiselev.a-22031972@postgrespro.ru", "phone": "+70605584234"}
0005434217978	EE9617	7522 563525	IVAN SEMENOV	{"phone": "+70309969528"}
0005434217979	F7EF13	9941 136490	NIKOLAY DENISOV	{"phone": "+70924355676"}
0005434217980	77300F	8163 954861	EVGENIY KUDRYASHOV	{"email": "kudryashovevgeniy.1982@postgrespro.ru", "phone": "+70804777513"}
0005434217981	77300F	7986 720021	KSENIYA ORLOVA	{"email": "orlovakseniya25081966@postgrespro.ru", "phone": "+70876428923"}
0005434217982	A85D98	8010 994304	VALENTINA AFANASEVA	{"phone": "+70175407790"}
0005434217983	A6F771	5771 520721	SVETLANA FEDOROVA	{"email": "fedorovasvetlana1966@postgrespro.ru", "phone": "+70038914324"}
0005434217984	DFE37C	2776 242991	ANNA DENISOVA	{"phone": "+70917057177"}
0005434217985	DFE37C	3095 939704	IGOR MIKHAYLOV	{"email": "mikhaylov-igor-30061970@postgrespro.ru", "phone": "+70314249303"}
0005434217986	2481D1	7642 104182	EKATERINA TROFIMOVA	{"phone": "+70962390473"}
0005434217987	2481D1	3109 237413	MARIYA ZHUKOVA	{"email": "zhukova_m-1973@postgrespro.ru", "phone": "+70354005365"}
0005434217988	270224	6750 436324	MIKHAIL DENISOV	{"email": "m-denisov111979@postgrespro.ru", "phone": "+70674211793"}
0005434217989	270224	0659 577556	VADIM SIDOROV	{"phone": "+70430275140"}
0005434217990	9A3956	7049 999063	ANDREY NIKOLAEV	{"email": "a.nikolaev-13121969@postgrespro.ru", "phone": "+70339526260"}
0005434217991	DA183D	4624 894474	ALEKSANDR FOMIN	{"phone": "+70177186365"}
0005434217992	DABC85	1588 840331	VALENTIN NIKITIN	{"email": "nikitin-v_02061972@postgrespro.ru", "phone": "+70087592771"}
0005434217993	DABC85	8874 320410	VLADIMIR VOLKOV	{"phone": "+70609455956"}
0005434217994	899FC1	1500 034631	OLESYA NIKIFOROVA	{"email": "nikiforova.o_1971@postgrespro.ru", "phone": "+70430244553"}
0005434217995	899FC1	3219 790690	MIKHAIL DENISOV	{"email": "mikhaildenisov_1972@postgrespro.ru", "phone": "+70473937037"}
0005434217996	DFB5F7	3042 055256	IRINA KOROLEVA	{"phone": "+70058526216"}
0005434217997	64A2E1	7127 018506	ALEKSANDR IVANOV	{"phone": "+70156673405"}
0005434217998	F24671	7915 232365	LIDIYA CHERNOVA	{"phone": "+70235009264"}
0005434217999	5D613A	4923 633815	GALINA ROMANOVA	{"email": "galina-romanova28121981@postgrespro.ru", "phone": "+70487947759"}
0005434218000	5D613A	0778 531098	NADEZHDA ANDREEVA	{"phone": "+70957123251"}
0005434218001	0A98DB	7447 993428	SVETLANA KOROLEVA	{"phone": "+70554887864"}
0005434218002	1E67F0	7448 621840	ALEKSANDR BONDARENKO	{"email": "bondarenkoa_02061972@postgrespro.ru", "phone": "+70694041308"}
0005434218003	E2ECB1	3862 840629	NIKOLAY SCHERBAKOV	{"phone": "+70652280576"}
0005434218004	D896FB	8761 467767	EKATERINA GUSEVA	{"email": "gusevae-31011967@postgrespro.ru", "phone": "+70549248824"}
0005434218005	610FFD	8295 994367	LYUBOV NESTEROVA	{"phone": "+70930616266"}
0005434218006	361C96	6121 355542	ALEKSANDR ZHURAVLEV	{"phone": "+70964109875"}
0005434218007	230F10	9618 375738	YULIYA KARPOVA	{"email": "yuliya.karpova.1970@postgrespro.ru", "phone": "+70586490568"}
0005434218008	18A493	4895 422934	ARINA ZOTOVA	{"phone": "+70861300962"}
0005434218009	DCC51B	9722 914805	VITALIY ANDREEV	{"email": "andreevvitaliy-27111968@postgrespro.ru", "phone": "+70487626747"}
0005434218010	E7A409	2423 825717	IGOR ZHURAVLEV	{"email": "i.zhuravlev29041980@postgrespro.ru", "phone": "+70685619528"}
0005434218011	144AE4	4428 207321	ANASTASIYA NIKITINA	{"email": "nikitina_anastasiya.1979@postgrespro.ru", "phone": "+70239045379"}
0005434218012	A13687	5364 876460	SERGEY IVANOV	{"phone": "+70634983143"}
0005434218013	A13687	5231 615028	TATYANA MALYSHEVA	{"email": "t.malysheva1967@postgrespro.ru", "phone": "+70128200142"}
0005434218014	49B774	2973 529995	TAMARA MIKHAYLOVA	{"phone": "+70024877999"}
0005434218015	49B774	2683 133209	SERGEY SOLOVEV	{"phone": "+70129792822"}
0005434218016	49B774	7187 110388	SERGEY MAKAROV	{"phone": "+70970635125"}
0005434218017	A181B3	8410 891480	ARTEM KAZAKOV	{"phone": "+70592612804"}
0005434218018	A181B3	9509 264249	ALEKSANDR IVANOV	{"email": "ivanov-a-111969@postgrespro.ru", "phone": "+70990620088"}
0005434218019	85AEAD	7510 186971	LEV SMIRNOV	{"email": "lev.smirnov10091978@postgrespro.ru", "phone": "+70238125364"}
0005434218020	85AEAD	3182 283189	NATALYA RYABOVA	{"email": "natalya.ryabova1973@postgrespro.ru", "phone": "+70087586264"}
0005434218021	9A6620	2774 781210	TATYANA ABRAMOVA	{"email": "tatyana-abramova-071962@postgrespro.ru", "phone": "+70102598962"}
0005434218022	08573A	4929 032661	NATALYA ANDREEVA	{"email": "andreeva-n.03111965@postgrespro.ru", "phone": "+70807123445"}
0005434218023	7C9146	7350 142768	YURIY MELNIKOV	{"email": "melnikovy-04011970@postgrespro.ru", "phone": "+70865758160"}
0005434218024	0C6C94	4981 628160	MARIYA KOZLOVA	{"phone": "+70133901893"}
0005434218025	0C6C94	3257 089625	MARIYA SEMENOVA	{"email": "semenova.m.08011968@postgrespro.ru", "phone": "+70557302620"}
0005434218026	0C6C94	1447 874950	DANIIL MEDVEDEV	{"phone": "+70505034620"}
0005434218027	0C6C94	6106 607979	ALEKSANDR MARTYNOV	{"email": "a_martynov19041980@postgrespro.ru", "phone": "+70801501070"}
0005434218028	490A68	5464 055954	OLGA MAKSIMOVA	{"phone": "+70904532134"}
0005434218029	490A68	5107 580096	OLGA ALEKSEEVA	{"phone": "+70564773025"}
0005434218030	092A95	0700 562481	VALERIY ZAYCEV	{"email": "v_zaycev.16091976@postgrespro.ru", "phone": "+70821635795"}
0005434218031	217E1A	5557 125078	VLADISLAV ANTONOV	{"email": "vladislav_antonov121973@postgrespro.ru", "phone": "+70999997034"}
0005434218032	217E1A	7199 548403	RINAT PETROV	{"email": "rinatpetrov.071960@postgrespro.ru", "phone": "+70784392934"}
0005434218033	6A79B5	0538 090477	DMITRIY MIRONOV	{"email": "mironov.d_23071968@postgrespro.ru", "phone": "+70777762705"}
0005434218034	7EF29A	2595 120621	VALERIY PAVLOV	{"email": "valeriypavlov-041984@postgrespro.ru", "phone": "+70401550213"}
0005434218035	31B50E	5933 493953	MARINA NIKOLAEVA	{"phone": "+70441147939"}
0005434218036	41BFEA	0018 866974	LYUBOV SOKOLOVA	{"email": "sokolova.l.16071970@postgrespro.ru", "phone": "+70711708389"}
0005434218037	4E0F01	0389 898836	LIDIYA SOKOLOVA	{"phone": "+70781337209"}
0005434218038	F7D830	0895 958364	OLEG KUDRYASHOV	{"email": "kudryashov_o051964@postgrespro.ru", "phone": "+70619339338"}
0005434218039	F7D830	0425 590421	OLGA YAKOVLEVA	{"phone": "+70149467141"}
0005434218040	F7D830	3774 899192	IRINA ISAEVA	{"email": "irina-isaeva071978@postgrespro.ru", "phone": "+70122131554"}
0005434218041	8AE3FA	6670 789487	LARISA PAVLOVA	{"phone": "+70681186977"}
0005434218042	B1625A	6884 759334	ALEKSANDR SERGEEV	{"phone": "+70541744051"}
0005434218043	B1625A	5889 560126	DANIIL PAVLOV	{"phone": "+70405776344"}
0005434218044	0189F2	2613 129645	TATYANA EFIMOVA	{"email": "efimova_tatyana_25031981@postgrespro.ru", "phone": "+70198977898"}
0005434218045	2696BE	9756 214981	GENNADIY BORISOV	{"email": "borisov.gennadiy_1987@postgrespro.ru", "phone": "+70288092945"}
0005434218046	CF400E	9395 837906	IRINA NIKOLAEVA	{"email": "nikolaeva-irina_06061961@postgrespro.ru", "phone": "+70039284756"}
0005434218047	CF400E	3835 283816	IGOR ISAEV	{"phone": "+70372968748"}
0005434218048	7C8095	4295 413037	NIKOLAY SEMENOV	{"phone": "+70607960567"}
0005434218049	45DED4	1015 817128	VLADIMIR KUZNECOV	{"phone": "+70475383821"}
0005434218050	132F5E	5377 807993	SERGEY ALEKSEEV	{"email": "alekseev-sergey1965@postgrespro.ru", "phone": "+70039043621"}
0005434218051	4E0C2F	0345 111829	NIKOLAY KONOVALOV	{"phone": "+70163203092"}
0005434218052	45D48C	3551 743351	VLADIMIR GERASIMOV	{"phone": "+70992989046"}
0005434218053	45D48C	2276 523073	YULIYA TIKHONOVA	{"email": "tikhonovayuliya24041973@postgrespro.ru", "phone": "+70617777051"}
0005434218054	35E620	6033 467041	VERONIKA ALEKSEEVA	{"email": "alekseeva_veronika011980@postgrespro.ru", "phone": "+70162772788"}
0005434218055	35E620	8665 635571	DANIIL BARANOV	{"phone": "+70407210986"}
0005434218056	35E620	7070 242198	VIKTORIYA KUZMINA	{"phone": "+70840710655"}
0005434218057	249133	4637 584505	ELENA VASILEVA	{"email": "elena_vasileva.1970@postgrespro.ru", "phone": "+70052670044"}
0005434218058	9253CF	6289 639703	ZHANNA POTAPOVA	{"email": "zhanna_potapova23031980@postgrespro.ru", "phone": "+70615102288"}
0005434218059	C73895	5519 482779	LYUBOV VLASOVA	{"phone": "+70014205634"}
0005434218060	27F836	2862 224159	ILYA GRIGOREV	{"email": "i.grigorev-17051968@postgrespro.ru", "phone": "+70105587272"}
0005434218061	27F836	6016 890683	KIRA SOLOVEVA	{"phone": "+70601705999"}
0005434218062	27F836	7677 659101	LARISA CHERNOVA	{"email": "larisa_chernova.1972@postgrespro.ru", "phone": "+70428578569"}
0005434218063	AFF20F	6307 797319	OKSANA SOKOLOVA	{"email": "sokolova_oksana-041971@postgrespro.ru", "phone": "+70554784686"}
0005434218064	AFF20F	8899 716785	RAFIK GRIGOREV	{"email": "grigorevr.13011977@postgrespro.ru", "phone": "+70757912956"}
0005434218065	FFD8D0	9510 587372	IRINA NAUMOVA	{"phone": "+70187512473"}
0005434218066	7C226C	4806 177451	MARIYA FILIPPOVA	{"phone": "+70944976909"}
0005434218067	C38BCB	4799 823446	ANATOLIY POPOV	{"phone": "+70870028808"}
0005434218068	C38BCB	4302 539780	SVETLANA NIKITINA	{"email": "svetlana.nikitina041971@postgrespro.ru", "phone": "+70588923348"}
0005434218069	5E8F7A	4915 797431	IVAN YAKOVLEV	{"email": "i-yakovlev.1966@postgrespro.ru", "phone": "+70836980878"}
0005434218070	FAB1AF	7834 614446	MIKHAIL PETROV	{"email": "petrov.m_1975@postgrespro.ru", "phone": "+70180385183"}
0005434218071	5D6E3B	0316 999579	VITALIY MIRONOV	{"phone": "+70906276802"}
0005434218072	5D6E3B	4986 363621	YAKOV BELOV	{"phone": "+70582140020"}
0005434218073	E05BC7	0160 198038	IRINA MEDVEDEVA	{"phone": "+70079879952"}
0005434218074	E05BC7	9275 092791	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_101971@postgrespro.ru", "phone": "+70599743896"}
0005434218075	2814D9	1107 730657	ANDREY IVANOV	{"email": "ivanov.andrey_05031979@postgrespro.ru", "phone": "+70351707836"}
0005434218076	344420	9087 878387	ANNA KUZNECOVA	{"email": "kuznecova.a-10121962@postgrespro.ru", "phone": "+70951129290"}
0005434218077	66C113	4221 195443	ANGELINA SCHERBAKOVA	{"email": "scherbakova.angelina27011967@postgrespro.ru", "phone": "+70084278020"}
0005434218078	542322	2862 836049	ALEKSANDR MATVEEV	{"phone": "+70929416469"}
0005434218079	559829	8607 961726	YURIY MATVEEV	{"email": "matveev-y_30061969@postgrespro.ru", "phone": "+70858292331"}
0005434218080	58B292	5898 175476	SVETLANA SMIRNOVA	{"email": "smirnova_svetlana05081971@postgrespro.ru", "phone": "+70350006106"}
0005434218081	451D41	5216 912560	ALEKSEY IVANOV	{"email": "ivanov_aleksey-28111973@postgrespro.ru", "phone": "+70670383539"}
0005434218082	B2EC60	4649 748355	OLGA DMITRIEVA	{"email": "dmitrieva_o1970@postgrespro.ru", "phone": "+70151764493"}
0005434218083	B2EC60	4753 981138	NINA MAKSIMOVA	{"email": "maksimova-nina-011967@postgrespro.ru", "phone": "+70451210565"}
0005434218084	6F0C4A	6684 745378	VALENTINA POPOVA	{"email": "v_popova1967@postgrespro.ru", "phone": "+70391883242"}
0005434218085	6F0C4A	7599 340379	OKSANA VOLKOVA	{"phone": "+70307188511"}
0005434218086	341E40	2370 325184	ANDREY CHERNOV	{"email": "a-chernov26121972@postgrespro.ru", "phone": "+70108284233"}
0005434218087	341E40	2425 294135	TATYANA POPOVA	{"email": "tatyanapopova.19031976@postgrespro.ru", "phone": "+70107679481"}
0005434218088	EF5D10	5992 791003	ANNA ISAEVA	{"email": "a-isaeva02011975@postgrespro.ru", "phone": "+70237726192"}
0005434218089	A869FB	5575 157977	VALENTINA ALEKSANDROVA	{"phone": "+70149970462"}
0005434218090	6F96FE	6954 781931	GALINA GRISHINA	{"phone": "+70500518197"}
0005434218091	6F96FE	4809 030290	ANASTASIYA BORISOVA	{"email": "borisova-a_111967@postgrespro.ru", "phone": "+70611529556"}
0005434218092	D86685	1948 875156	DMITRIY NOVIKOV	{"email": "novikov.d_1969@postgrespro.ru", "phone": "+70719436359"}
0005434218093	D86685	2630 573514	LIDIYA ZHURAVLEVA	{"phone": "+70587946710"}
0005434228966	FFEC35	1145 980234	GENNADIY SERGEEV	{"email": "g.sergeev.1980@postgrespro.ru", "phone": "+70702797894"}
0005434228967	FFEC35	7431 867262	ALEKSANDR GUSEV	{"phone": "+70204811809"}
0005434228968	FFEC35	1062 880568	TATYANA MAKAROVA	{"email": "tatyana_makarova.031978@postgrespro.ru", "phone": "+70318474871"}
0005434228969	1A8EA4	4235 210282	ALISA MAKSIMOVA	{"phone": "+70936852233"}
0005434228970	1A8EA4	1591 727162	ALEKSEY SCHERBAKOV	{"email": "a-scherbakov_031966@postgrespro.ru", "phone": "+70845328788"}
0005434228971	1A8EA4	9970 866388	NIKOLAY ROMANOV	{"email": "romanov_n-1970@postgrespro.ru", "phone": "+70653666415"}
0005434228972	FF9D56	8612 084261	SERGEY ILIN	{"email": "s-ilin-1970@postgrespro.ru", "phone": "+70926777749"}
0005434228973	690E75	2396 101146	DANIIL MAKAROV	{"phone": "+70107615637"}
0005434228974	A4FAB5	5785 022052	EKATERINA KUZNECOVA	{"email": "e-kuznecova.051973@postgrespro.ru", "phone": "+70147940071"}
0005434228975	C8D969	0838 577133	MARIYA AFANASEVA	{"phone": "+70336917520"}
0005434228976	C8D969	3615 310022	ANTON SERGEEV	{"phone": "+70733094121"}
0005434228977	193D75	8326 970924	IGOR IVANOV	{"phone": "+70699708694"}
0005434228978	773CB3	1672 419294	VYACHESLAV BELOV	{"email": "belov-v061976@postgrespro.ru", "phone": "+70341003118"}
0005434228979	1CDE62	5562 622266	ALENA RODIONOVA	{"email": "a_rodionova.24011980@postgrespro.ru", "phone": "+70621396301"}
0005434228980	638871	5784 498782	RAFAIL CHERNOV	{"email": "rafail-chernov.01091981@postgrespro.ru", "phone": "+70333666552"}
0005434228981	1D4644	3338 231842	NINA LAZAREVA	{"email": "n-lazareva_1975@postgrespro.ru", "phone": "+70670807966"}
0005434228982	98ADE8	6078 541376	ANNA SOLOVEVA	{"phone": "+70968698625"}
0005434228983	1B9CA4	1577 085326	ZINAIDA POLYAKOVA	{"email": "polyakovaz_25041980@postgrespro.ru", "phone": "+70652876408"}
0005434228984	8CD644	0622 550482	ALEKSEY VASILEV	{"email": "a.vasilev.09041976@postgrespro.ru", "phone": "+70063478873"}
0005434228985	8CD644	7593 346537	LIDIYA OSIPOVA	{"email": "osipova-lidiya04011967@postgrespro.ru", "phone": "+70189748755"}
0005434228986	3C7047	8886 141724	LYUDMILA DENISOVA	{"phone": "+70076314046"}
0005434228987	CF75F8	6615 820766	EVGENIY KAZAKOV	{"phone": "+70756557186"}
0005434228988	07950F	6448 578462	ROZA EGOROVA	{"phone": "+70724388437"}
0005434228989	E7FC15	7827 346913	SERGEY NAUMOV	{"email": "naumov-s-051979@postgrespro.ru", "phone": "+70900238053"}
0005434228990	B302E9	9034 786475	VERA MAKAROVA	{"email": "makarova.vera1977@postgrespro.ru", "phone": "+70396555434"}
0005434228991	46D154	4553 998137	MARIYA KRASNOVA	{"phone": "+70214912701"}
0005434228992	7832EE	2255 404758	NIKOLAY GUSEV	{"email": "gusev_nikolay_21091969@postgrespro.ru", "phone": "+70909334914"}
0005434228993	18A9A6	7257 387419	VALENTINA KUDRYASHOVA	{"email": "kudryashova_v-101969@postgrespro.ru", "phone": "+70175770717"}
0005434228994	796689	3642 419796	NAIL YAKOVLEV	{"phone": "+70199441381"}
0005434228995	790247	3186 818315	EKATERINA MELNIKOVA	{"email": "ekaterina-melnikova_021980@postgrespro.ru", "phone": "+70720843233"}
0005434228996	E7F4F4	7378 502189	VITALIY KUZNECOV	{"email": "v.kuznecov.20021975@postgrespro.ru", "phone": "+70587294725"}
0005434228997	E7F4F4	7002 535666	NIKITA FEDOROV	{"email": "fedorov.n.26091982@postgrespro.ru", "phone": "+70219311208"}
0005434228998	E7F4F4	4795 197540	EGOR NIKOLAEV	{"phone": "+70457113096"}
0005434228999	29B62B	0293 681393	ALEKSANDR POPOV	{"email": "popova_091963@postgrespro.ru", "phone": "+70020179720"}
0005434229000	A6A34A	6175 564959	ZOYA PETROVA	{"email": "petrovaz.1975@postgrespro.ru", "phone": "+70085642331"}
0005434229001	895845	3468 163669	STEPAN NAZAROV	{"email": "s.nazarov20101965@postgrespro.ru", "phone": "+70007017389"}
0005434229002	3F0DE9	8568 540768	NINA ERMAKOVA	{"phone": "+70722315560"}
0005434229003	9B7284	1076 144915	LYUBOV AKIMOVA	{"phone": "+70448133920"}
0005434229004	36EB86	8603 947563	OLEG BONDARENKO	{"email": "bondarenko-oleg21051972@postgrespro.ru", "phone": "+70140557328"}
0005434229005	36EB86	6835 300673	SERGEY DAVYDOV	{"email": "sdavydov121975@postgrespro.ru", "phone": "+70914462749"}
0005434229006	C1BCB3	5539 058203	VALENTINA ANTONOVA	{"email": "antonova-valentina1976@postgrespro.ru", "phone": "+70198725656"}
0005434229007	C1BCB3	3978 584520	NATALYA TARASOVA	{"phone": "+70796604060"}
0005434229008	C1BCB3	0032 984336	IRINA NESTEROVA	{"phone": "+70877347641"}
0005434229009	50FBEC	0487 073177	NIKOLAY VLASOV	{"phone": "+70762231694"}
0005434229010	3EA916	4955 359961	MARIYA EGOROVA	{"email": "mariya_egorova-011977@postgrespro.ru", "phone": "+70963875862"}
0005434229011	600902	8179 684789	TATYANA NAUMOVA	{"email": "t.naumova_051972@postgrespro.ru", "phone": "+70558151984"}
0005434229012	D01227	5038 093899	EVGENIY SHEVCHENKO	{"phone": "+70120489120"}
0005434229013	462565	3110 999047	SERGEY VASILEV	{"email": "sergey.vasilev-16121965@postgrespro.ru", "phone": "+70501079156"}
0005434229014	EE96A0	2260 851633	KONSTANTIN MOISEEV	{"email": "k.moiseev101963@postgrespro.ru", "phone": "+70118600135"}
0005434229015	EE96A0	1822 597131	OLGA OVCHINNIKOVA	{"phone": "+70283342532"}
0005434229016	4CB659	6433 094694	VLADISLAV ILIN	{"phone": "+70126646532"}
0005434229017	1B79B1	0371 542125	ALEKSANDR SCHERBAKOV	{"phone": "+70072836460"}
0005434229018	1B79B1	4315 863992	NADEZHDA EGOROVA	{"email": "negorova_1977@postgrespro.ru", "phone": "+70536306772"}
0005434229019	1B79B1	0574 244198	EVGENIY SHEVCHENKO	{"phone": "+70182181941"}
0005434229020	427415	9342 405960	VIKTOR TARASOV	{"email": "tarasovviktor23111966@postgrespro.ru", "phone": "+70208726928"}
0005434229021	427415	9544 392635	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov_051970@postgrespro.ru", "phone": "+70426811278"}
0005434229022	5A2C91	8682 418783	MARIYA IVANOVA	{"phone": "+70487987664"}
0005434229023	5F2575	0727 492708	KRISTINA VOROBEVA	{"email": "vorobeva-k081976@postgrespro.ru", "phone": "+70949959806"}
0005434229024	3A741F	2764 798670	VYACHESLAV KOZLOV	{"phone": "+70700459986"}
0005434229025	A7A019	8894 780115	KRISTINA BORISOVA	{"email": "borisova.kristina-031970@postgrespro.ru", "phone": "+70633297010"}
0005434229026	A7A019	0699 324260	KAMILLA ILINA	{"phone": "+70448569477"}
0005434229027	6A53DA	1061 269064	KLAVDIYA EGOROVA	{"email": "egorova_k-01121972@postgrespro.ru", "phone": "+70833979797"}
0005434229028	6A53DA	2450 756769	NATALYA AFANASEVA	{"phone": "+70622041177"}
0005434229029	E6FB18	5468 425919	VALENTINA NAZAROVA	{"phone": "+70226105716"}
0005434229030	37099C	4378 540805	NINA NAZAROVA	{"phone": "+70672840931"}
0005434229031	37099C	2167 115775	ELENA NAZAROVA	{"email": "e-nazarova_1983@postgrespro.ru", "phone": "+70911047765"}
0005434229032	2B3892	0579 672969	NELLI NOVIKOVA	{"email": "novikova.n_1967@postgrespro.ru", "phone": "+70133149610"}
0005434229033	2B3892	9134 409214	ELVIRA SEMENOVA	{"email": "e_semenova.27121960@postgrespro.ru", "phone": "+70232755672"}
0005434229034	820EDB	6377 409610	DMITRIY ILIN	{"email": "ilin-dmitriy.13011971@postgrespro.ru", "phone": "+70357582139"}
0005434229035	A94912	0549 904233	LYUBOV VOLKOVA	{"phone": "+70995812575"}
0005434229036	E94E21	9428 807700	NADEZHDA GAVRILOVA	{"email": "nadezhda-gavrilova_02071973@postgrespro.ru", "phone": "+70481758976"}
0005434229037	E94E21	6869 066890	SERGEY FILIPPOV	{"phone": "+70280363631"}
0005434229038	E94E21	0653 681737	MARIYA ZAYCEVA	{"phone": "+70508970885"}
0005434229039	E92DD3	2652 520265	IRINA BORISOVA	{"email": "borisova_i.04101964@postgrespro.ru", "phone": "+70677892981"}
0005434229040	E92DD3	7519 482904	OLEG ISAEV	{"email": "oleg-isaev061976@postgrespro.ru", "phone": "+70904022882"}
0005434229041	9B502B	4925 703287	ALEKSANDR MOROZOV	{"phone": "+70436225836"}
0005434229042	9B502B	6172 798319	MIKHAIL PETROV	{"email": "petrov_m.24101974@postgrespro.ru", "phone": "+70285157808"}
0005434229043	64809A	1242 904666	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr-16031973@postgrespro.ru", "phone": "+70413310119"}
0005434229044	1EBCCC	1131 932629	MARINA CHERNOVA	{"email": "chernovam.101978@postgrespro.ru", "phone": "+70745891316"}
0005434229045	1EBCCC	0076 076119	ANDREY RODIONOV	{"phone": "+70046948801"}
0005434229046	261651	3159 226408	YURIY ZAYCEV	{"email": "yuriyzaycev_15071969@postgrespro.ru", "phone": "+70179635263"}
0005434229047	9AAEF7	9770 101167	PETR GORBUNOV	{"phone": "+70392210242"}
0005434229048	9AAEF7	1093 118166	NADEZHDA NOVIKOVA	{"phone": "+70583770361"}
0005434229049	766D2A	3234 665023	VALERIY ILIN	{"phone": "+70752495810"}
0005434229050	0948D9	7290 053353	ELENA NOVIKOVA	{"phone": "+70268908964"}
0005434229051	0948D9	7949 920795	NIKOLAY SMIRNOV	{"email": "smirnov-n-1975@postgrespro.ru", "phone": "+70367872766"}
0005434229052	FD5502	4162 990123	LYUBOV ANTONOVA	{"email": "lyubov_antonova-10121978@postgrespro.ru", "phone": "+70364056572"}
0005434229053	487746	8016 154179	DENIS MARTYNOV	{"phone": "+70356144691"}
0005434229054	487746	8090 822069	ELENA KUZNECOVA	{"phone": "+70693649684"}
0005434229055	96A18E	8936 523657	VALENTINA NESTEROVA	{"email": "nesterova.valentina_081958@postgrespro.ru", "phone": "+70800348391"}
0005434229056	CBAD0C	0639 420813	YURIY SMIRNOV	{"email": "yuriy.smirnov.09101965@postgrespro.ru", "phone": "+70181271983"}
0005434229057	559C8C	5729 194249	VYACHESLAV MOISEEV	{"email": "vyacheslav_moiseev-27121980@postgrespro.ru", "phone": "+70881925869"}
0005434229058	559C8C	6420 115646	RUSTAM AFANASEV	{"email": "afanasev_r.23101968@postgrespro.ru", "phone": "+70091162030"}
0005434229059	303A9F	3167 475812	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev-1974@postgrespro.ru", "phone": "+70907688518"}
0005434229060	A94422	5020 493548	EKATERINA VOROBEVA	{"email": "vorobeva-ekaterina-081960@postgrespro.ru", "phone": "+70371251010"}
0005434229061	A94422	8463 670827	OLESYA PAVLOVA	{"email": "o.pavlova-1976@postgrespro.ru", "phone": "+70830758649"}
0005434229062	177F78	0312 649719	SERGEY ALEKSEEV	{"phone": "+70763715060"}
0005434229063	814CCB	1823 796717	ALEKSANDR STEPANOV	{"email": "stepanov-a-021971@postgrespro.ru", "phone": "+70432472357"}
0005434229064	814CCB	6211 995096	ANNA DMITRIEVA	{"phone": "+70359978500"}
0005434229065	8F1159	5403 291810	MARIYA FEDOROVA	{"phone": "+70645843965"}
0005434229066	1E09FB	9018 955811	MIKHAIL ROMANOV	{"phone": "+70387556875"}
0005434229067	CDFFB9	1981 065781	ANASTASIYA NIKIFOROVA	{"email": "nikiforova.anastasiya_1974@postgrespro.ru", "phone": "+70302818222"}
0005434229068	C0DB1D	5009 394343	VALENTINA KOROLEVA	{"email": "v-koroleva.09121976@postgrespro.ru", "phone": "+70885488077"}
0005434229069	BCE7F2	3936 619923	ILYA ILIN	{"email": "i-ilin-20121973@postgrespro.ru", "phone": "+70093952462"}
0005434229070	BCE7F2	6800 744037	VALENTINA VLASOVA	{"phone": "+70742290230"}
0005434229071	2FE3F3	2306 520140	VIKTORIYA MOISEEVA	{"email": "moiseeva.v_26051984@postgrespro.ru", "phone": "+70703612763"}
0005434229072	A0A265	2091 647867	EVGENIY PAVLOV	{"email": "pavlov.evgeniy.07061986@postgrespro.ru", "phone": "+70459208837"}
0005434229073	A0A265	2034 075481	YURIY VASILEV	{"email": "y_vasilev_011977@postgrespro.ru", "phone": "+70841937791"}
0005434229074	77D4B2	9196 425413	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila.1984@postgrespro.ru", "phone": "+70210132396"}
0005434229075	52E696	3229 779579	SERGEY ZHURAVLEV	{"phone": "+70576710945"}
0005434229076	7A1F29	5043 708336	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova1988@postgrespro.ru", "phone": "+70703739663"}
0005434229077	16E219	2494 410507	RAFAEL YAKOVLEV	{"email": "ryakovlev_1970@postgrespro.ru", "phone": "+70287648984"}
0005434229078	16E219	3886 587917	ELENA TITOVA	{"email": "elena_titova.19041972@postgrespro.ru", "phone": "+70086284059"}
0005434229079	5A2933	0003 849870	OLESYA KARPOVA	{"email": "karpova-olesya.17051973@postgrespro.ru", "phone": "+70187773140"}
0005434229080	5A2933	2022 860109	NIKITA POPOV	{"email": "popovn1967@postgrespro.ru", "phone": "+70692017061"}
0005434229081	F10C5C	7362 477937	ELENA KUZNECOVA	{"email": "kuznecovaelena.05121976@postgrespro.ru", "phone": "+70470750723"}
0005434229082	64CE20	0383 775720	SERGEY ZAKHAROV	{"email": "sergey.zakharov1969@postgrespro.ru", "phone": "+70575234037"}
0005434229083	82C305	0461 697959	ANZHELIKA IVANOVA	{"email": "anzhelikaivanova-061962@postgrespro.ru", "phone": "+70965244122"}
0005434229084	6BD345	4693 487257	VADIM KUZMIN	{"email": "vadim-kuzmin_031971@postgrespro.ru", "phone": "+70101647252"}
0005434229085	79592A	7806 908526	IRINA FADEEVA	{"email": "fadeevai.051972@postgrespro.ru", "phone": "+70907001875"}
0005434229086	488898	2811 277210	IRINA POLYAKOVA	{"phone": "+70807757036"}
0005434229087	AB0FFE	4804 515276	GENNADIY KAZAKOV	{"email": "gennadiy-kazakov1983@postgrespro.ru", "phone": "+70138984541"}
0005434229088	842148	0738 968177	DENIS BARANOV	{"email": "baranov.denis-1975@postgrespro.ru", "phone": "+70853515942"}
0005434229089	842148	5095 754109	IRINA IVANOVA	{"phone": "+70201345561"}
0005434229090	AB364E	1907 508706	ALEKSANDRA POPOVA	{"email": "apopova_11091974@postgrespro.ru", "phone": "+70421207245"}
0005434229091	AB364E	2881 635021	NATALYA GORBUNOVA	{"email": "gorbunova_n_07051978@postgrespro.ru", "phone": "+70330667564"}
0005434229092	7D0106	1048 719057	ANDREY IVANOV	{"phone": "+70520192685"}
0005434229093	A3A965	1924 127504	MILENA EGOROVA	{"email": "m.egorova-071973@postgrespro.ru", "phone": "+70887411511"}
0005434229094	243978	7056 119287	PETR IVANOV	{"email": "ivanov-p1964@postgrespro.ru", "phone": "+70527094273"}
0005434229095	243978	6376 647791	ALEKSANDR PETROV	{"email": "a.petrov-1960@postgrespro.ru", "phone": "+70458448906"}
0005434229096	243978	0982 201489	LYUBOV IVANOVA	{"email": "ivanova-lyubov-061977@postgrespro.ru", "phone": "+70890543300"}
0005434229097	1A2045	8436 154479	LIDIYA LAZAREVA	{"phone": "+70189472369"}
0005434229098	5A94B3	0016 548612	OLGA SERGEEVA	{"email": "o-sergeeva_061974@postgrespro.ru", "phone": "+70560492907"}
0005434229099	5A94B3	5679 008906	ARTEM TARASOV	{"phone": "+70064416364"}
0005434229100	D0BA56	7972 336481	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya.031958@postgrespro.ru", "phone": "+70684211127"}
0005434229101	D0BA56	3298 049496	EVGENIY BARANOV	{"email": "evgeniy-baranov-041967@postgrespro.ru", "phone": "+70662852237"}
0005434229102	F4D389	4734 060376	ANATOLIY VLASOV	{"phone": "+70061963541"}
0005434229103	6D4111	9328 449064	VLADIMIR DMITRIEV	{"email": "vdmitriev_031973@postgrespro.ru", "phone": "+70363934104"}
0005434229104	65FFEF	7819 979104	SOFIYA KUZMINA	{"phone": "+70781976915"}
0005434229105	E3708A	6368 087963	NADEZHDA PAVLOVA	{"phone": "+70682280488"}
0005434229106	8BFCD7	8038 371434	TAISIYA SOLOVEVA	{"email": "soloveva.taisiya_21061974@postgrespro.ru", "phone": "+70821938727"}
0005434229107	8BFCD7	8921 390941	NINA VASILEVA	{"phone": "+70903181973"}
0005434229108	1E2CCD	1879 623327	ANATOLIY ISAEV	{"email": "isaevanatoliy_17011973@postgrespro.ru", "phone": "+70584177029"}
0005434229109	482AD5	9548 071051	DMITRIY SCHERBAKOV	{"email": "d-scherbakov1975@postgrespro.ru", "phone": "+70832924000"}
0005434229110	69ED01	2730 804569	OLGA PAVLOVA	{"phone": "+70614163302"}
0005434229111	A82E5C	6920 481478	VERA AKIMOVA	{"email": "v-akimova_16081977@postgrespro.ru", "phone": "+70410941829"}
0005434229112	A82E5C	5748 219349	VIKTOR KRASNOV	{"phone": "+70419374131"}
0005434229113	A8413C	3307 854945	OLGA PETROVA	{"email": "petrovaolga-091974@postgrespro.ru", "phone": "+70769234472"}
0005434229114	A8413C	9350 907575	ILYA SOKOLOV	{"phone": "+70108781146"}
0005434229115	813285	9925 774725	NATALYA DENISOVA	{"phone": "+70311645483"}
0005434229116	7398CA	2970 955658	ANNA YUDINA	{"email": "annayudina_13051971@postgrespro.ru", "phone": "+70171333192"}
0005434229117	B8EDE9	2792 597338	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov111985@postgrespro.ru", "phone": "+70052921197"}
0005434229118	F63F98	0224 077301	VYACHESLAV PETROV	{"email": "petrov.vyacheslav1952@postgrespro.ru", "phone": "+70784799191"}
0005434229119	B6DEFF	9907 157318	SVETLANA BORISOVA	{"email": "borisova.s-25051960@postgrespro.ru", "phone": "+70877665117"}
0005434229120	B6DEFF	6794 306691	KSENIYA BARANOVA	{"email": "baranova-k-021969@postgrespro.ru", "phone": "+70289610324"}
0005434229121	7DE7FA	0394 008204	LYUDMILA FADEEVA	{"email": "fadeeva.l081962@postgrespro.ru", "phone": "+70031496854"}
0005434229122	BFE50C	5914 162231	VLADISLAV SMIRNOV	{"phone": "+70899900664"}
0005434229123	A05139	1470 169809	KSENIYA SOKOLOVA	{"phone": "+70086158134"}
0005434229124	D5A6B1	3672 657267	YURIY MOROZOV	{"email": "yuriy-morozov-1970@postgrespro.ru", "phone": "+70550694895"}
0005434229125	68901F	0131 757395	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr_011962@postgrespro.ru", "phone": "+70152639817"}
0005434229126	9D6645	1448 693906	IVAN SOKOLOV	{"email": "isokolov_111980@postgrespro.ru", "phone": "+70757921448"}
0005434229127	2FCEC3	5761 848352	IRINA MATVEEVA	{"email": "irinamatveeva_091972@postgrespro.ru", "phone": "+70838245339"}
0005434229128	4E7101	3861 316716	VALERIY MIKHAYLOV	{"email": "vmikhaylov_071974@postgrespro.ru", "phone": "+70171308299"}
0005434229129	4E7101	8360 112786	LYUDMILA KOMAROVA	{"phone": "+70533780004"}
0005434229130	8B1441	6480 141376	ALEKSANDR CHERNOV	{"email": "chernova_111969@postgrespro.ru", "phone": "+70455920116"}
0005434229131	20B329	6354 793599	LYUBOV BELYAEVA	{"phone": "+70785678928"}
0005434229132	CE9689	4005 543989	DARYA KUZNECOVA	{"phone": "+70957331979"}
0005434229133	E99140	5298 055626	SERGEY NIKITIN	{"phone": "+70254852259"}
0005434229134	E99140	8245 697157	ELENA NIKOLAEVA	{"phone": "+70060301034"}
0005434229135	651295	9504 751222	VITALIY OSIPOV	{"phone": "+70246161509"}
0005434229136	AFBAFD	9718 038317	VERA MAKAROVA	{"phone": "+70543052055"}
0005434229137	FA753B	0769 865940	ALEKSANDR DAVYDOV	{"phone": "+70617831705"}
0005434229138	990C06	2187 214619	VIKTOR NIKITIN	{"phone": "+70267591518"}
0005434229139	ECC3FC	6164 730234	ALEKSANDR KRASNOV	{"email": "akrasnov.06081973@postgrespro.ru", "phone": "+70754955444"}
0005434229140	ECC3FC	7197 322684	VYACHESLAV KAZAKOV	{"email": "kazakovv031979@postgrespro.ru", "phone": "+70461244497"}
0005434229141	58EBF5	4439 749376	VLADIMIR KUZNECOV	{"phone": "+70135401770"}
0005434229142	6B9EF4	1198 776535	ARTUR CHERNOV	{"phone": "+70453936203"}
0005434229143	96D44D	2654 736644	MIKHAIL KULIKOV	{"email": "kulikov_m.1978@postgrespro.ru", "phone": "+70602160881"}
0005434229144	ADB7FF	9133 527706	NATALIYA MELNIKOVA	{"email": "melnikova-n-1979@postgrespro.ru", "phone": "+70797630687"}
0005434229145	98FBE1	8163 465382	NIKOLAY ILIN	{"email": "ilinn.011969@postgrespro.ru", "phone": "+70433679640"}
0005434229146	98FBE1	0447 624083	ALBERT SCHERBAKOV	{"phone": "+70394308177"}
0005434229147	FE09DE	5606 298972	ANASTASIYA FILATOVA	{"phone": "+70937461873"}
0005434229148	EE64C2	0474 170659	NIKOLAY POPOV	{"phone": "+70634655580"}
0005434229149	EE64C2	4328 960807	ALFIYA FILIPPOVA	{"phone": "+70088807233"}
0005434229150	F3B093	4632 427479	TATYANA KOLESNIKOVA	{"phone": "+70865548257"}
0005434229151	E72B4E	1271 740560	VALENTINA KUZNECOVA	{"phone": "+70717851283"}
0005434229152	304425	0943 284334	GALINA LEBEDEVA	{"phone": "+70857205753"}
0005434229153	E62D93	7056 542070	ALEKSANDR MEDVEDEV	{"phone": "+70077809047"}
0005434229154	7A261C	8822 613016	EVGENIY ORLOV	{"phone": "+70482460451"}
0005434229155	CF94FA	2567 439455	OLEG BELOV	{"email": "obelov_1972@postgrespro.ru", "phone": "+70280147275"}
0005434229156	CF94FA	3486 644244	KSENIYA KOROLEVA	{"email": "kkoroleva_061982@postgrespro.ru", "phone": "+70887902957"}
0005434229157	CF94FA	7545 102291	VALENTINA ZAYCEVA	{"email": "zaycevav.1978@postgrespro.ru", "phone": "+70516542004"}
0005434229158	39A8A5	5290 807564	KLAVDIYA MOROZOVA	{"phone": "+70450181088"}
0005434229159	DFE66D	4984 315812	IRINA BOGDANOVA	{"email": "bogdanova_irina-18031976@postgrespro.ru", "phone": "+70243800245"}
0005434229160	BD3236	8856 713344	LIDIYA SMIRNOVA	{"email": "l.smirnova.021964@postgrespro.ru", "phone": "+70974060358"}
0005434229161	5F67EC	7325 406552	MARIYA SERGEEVA	{"phone": "+70576903476"}
0005434229162	28B4DA	9742 261558	VALENTIN BORISOV	{"phone": "+70505232268"}
0005434229163	F72E30	6169 989101	OKSANA RYABOVA	{"phone": "+70459176738"}
0005434229164	F72E30	4703 436537	ELENA VOLKOVA	{"email": "evolkova_1973@postgrespro.ru", "phone": "+70704783411"}
0005434229165	9A6ED7	7996 403828	SVETLANA SAVELEVA	{"phone": "+70487553745"}
0005434229166	499A34	0577 386862	TATYANA KOROLEVA	{"phone": "+70907633485"}
0005434229167	499A34	3798 239950	EKATERINA MIRONOVA	{"email": "mironova_ekaterina_061966@postgrespro.ru", "phone": "+70946120969"}
0005434229168	2B16C5	6733 638414	ANNA KISELEVA	{"phone": "+70623190062"}
0005434229169	26204B	0770 698832	VYACHESLAV ROMANOV	{"phone": "+70204528895"}
0005434229170	920BFF	8007 936058	ALEKSANDR KULIKOV	{"phone": "+70433228995"}
0005434229171	5FBEF8	8403 008008	ALEKSANDR PAVLOV	{"email": "pavlov.a.081970@postgrespro.ru", "phone": "+70462049725"}
0005434229172	1BE383	2088 244020	IVAN ABRAMOV	{"phone": "+70920570628"}
0005434229173	1BE383	9530 443271	MARIYA NIKOLAEVA	{"email": "m_nikolaeva22011975@postgrespro.ru", "phone": "+70621688258"}
0005434229174	4A52CD	5601 887350	FATYMA LUKYANOVA	{"phone": "+70618477101"}
0005434229175	01895E	2132 874417	MARGARITA FEDOROVA	{"email": "fedorova_margarita_081964@postgrespro.ru", "phone": "+70065359964"}
0005434229176	01895E	3942 767843	ANASTASIYA ISAEVA	{"phone": "+70732707357"}
0005434229177	01895E	3684 909072	ALLA ISAEVA	{"phone": "+70897116842"}
0005434229178	31E77B	0453 265949	VIKTOR MIKHAYLOV	{"email": "viktor.mikhaylov-1975@postgrespro.ru", "phone": "+70671127471"}
0005434229179	4A044E	0752 623181	ANDREY IVANOV	{"email": "ivanova-081974@postgrespro.ru", "phone": "+70356965028"}
0005434229180	4A044E	5891 834888	LIDIYA OSIPOVA	{"email": "osipova_lidiya20051967@postgrespro.ru", "phone": "+70789854636"}
0005434229181	458A5B	8169 165077	ELENA POLYAKOVA	{"email": "e_polyakova24111978@postgrespro.ru", "phone": "+70082332135"}
0005434229182	9C4C2A	6712 588259	ARKADIY KUZMIN	{"email": "arkadiy-kuzmin_041973@postgrespro.ru", "phone": "+70998234362"}
0005434229183	9C4C2A	2468 376180	VIKTOR MAKSIMOV	{"phone": "+70529212698"}
0005434229184	AFDA66	0695 554783	MARINA RODIONOVA	{"email": "rodionova.m_14061974@postgrespro.ru", "phone": "+70883280438"}
0005434229185	AFDA66	0968 784445	IGOR IVANOV	{"phone": "+70110208462"}
0005434229186	E6CD35	9010 480567	GALINA ROMANOVA	{"phone": "+70284445209"}
0005434229187	17C291	3963 728405	ANTONINA POPOVA	{"email": "antoninapopova29061976@postgrespro.ru", "phone": "+70019446052"}
0005434229188	17C291	3978 809935	ALEKSANDR BARANOV	{"email": "aleksandr.baranov041966@postgrespro.ru", "phone": "+70353238768"}
0005434229189	4F0D97	0278 237214	OLGA GERASIMOVA	{"phone": "+70292526359"}
0005434229190	17C4D6	8731 340914	VYACHESLAV KUZNECOV	{"email": "kuznecovvyacheslav-1970@postgrespro.ru", "phone": "+70251127719"}
0005434229191	338C0E	0280 299802	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr03091979@postgrespro.ru", "phone": "+70948785261"}
0005434229192	85E44A	2653 752745	ALEKSEY MEDVEDEV	{"email": "aleksey.medvedev1965@postgrespro.ru", "phone": "+70879646678"}
0005434229193	064766	1934 449610	NIKOLAY KULIKOV	{"email": "nikolay_kulikov1981@postgrespro.ru", "phone": "+70426312398"}
0005434229194	39BA54	9314 649208	KRISTINA NESTEROVA	{"email": "nesterova_k.091974@postgrespro.ru", "phone": "+70344066885"}
0005434229195	1B8D47	9538 313781	ELENA ERMAKOVA	{"phone": "+70538088160"}
0005434229196	0994B0	5761 174092	EVGENIY DENISOV	{"email": "denisov_e-1976@postgrespro.ru", "phone": "+70999185370"}
0005434229197	0994B0	5920 580072	PAVEL FROLOV	{"phone": "+70261015275"}
0005434229198	3214C8	0374 303215	KHALIDA FILIPPOVA	{"phone": "+70129198192"}
0005434229199	957C63	1847 015099	SVETLANA KULIKOVA	{"email": "svetlana.kulikova_061967@postgrespro.ru", "phone": "+70378667145"}
0005434229200	957C63	4906 078584	RUSLAN SOKOLOV	{"phone": "+70612470679"}
0005434229201	CA387A	2768 483669	ANDREY VLASOV	{"email": "vlasova_1965@postgrespro.ru", "phone": "+70086858550"}
0005434229202	CA387A	1264 218114	DANIIL RODIONOV	{"email": "rodionovdaniil_1977@postgrespro.ru", "phone": "+70627827873"}
0005434229203	5597F1	7953 443150	RAISA ZOTOVA	{"phone": "+70162869482"}
0005434229204	A65F0A	6527 114196	IVAN IVANOV	{"email": "iivanov_04021971@postgrespro.ru", "phone": "+70499629717"}
0005434229205	08811C	1171 738986	ALEKSANDR NIKITIN	{"email": "aleksandr-nikitin_28051975@postgrespro.ru", "phone": "+70704113491"}
0005434229206	5E7D3D	5950 114927	VERA FEDOROVA	{"email": "v_fedorova_031976@postgrespro.ru", "phone": "+70467927035"}
0005434229207	D68E4B	5696 955107	ANASTASIYA GRISHINA	{"phone": "+70831112522"}
0005434229208	832F72	4056 576553	FEDOR GERASIMOV	{"email": "gerasimov-fedor1974@postgrespro.ru", "phone": "+70107446193"}
0005434229209	65E704	8398 507967	GRIGORIY KUDRYASHOV	{"phone": "+70392400656"}
0005434229210	65E704	2177 811132	ALEKSANDR ZHUKOV	{"email": "zhukov_a-051974@postgrespro.ru", "phone": "+70061807515"}
0005434229211	E4F4A9	7709 802208	LYUDMILA EFREMOVA	{"phone": "+70803699288"}
0005434229212	57D6E0	0650 491070	DMITRIY MOROZOV	{"email": "dmitriy-morozov.121968@postgrespro.ru", "phone": "+70504078152"}
0005434229213	57D6E0	0109 322092	NATALYA KONDRATEVA	{"phone": "+70900326588"}
0005434229214	DCF988	1310 100537	VLADIMIR KUZNECOV	{"email": "v.kuznecov061969@postgrespro.ru", "phone": "+70405616488"}
0005434229215	A763EA	6695 238394	EVGENIY CHERNOV	{"phone": "+70016840406"}
0005434229216	1688EC	5915 036931	SVETLANA DMITRIEVA	{"email": "s_dmitrieva.1981@postgrespro.ru", "phone": "+70077222831"}
0005434229217	4E74B0	4776 892056	OLGA GUSEVA	{"email": "o.guseva1971@postgrespro.ru", "phone": "+70247963217"}
0005434229218	940AF2	5274 329858	OLEG ALEKSANDROV	{"email": "oleg-aleksandrov-1972@postgrespro.ru", "phone": "+70258663216"}
0005434229219	3599AF	2669 543982	ELENA KOROLEVA	{"phone": "+70538432300"}
0005434229220	BD2322	0262 558514	ALEKSEY IVANOV	{"email": "ivanovaleksey.14091972@postgrespro.ru", "phone": "+70814572259"}
0005434229221	BD2322	3407 017110	MARINA ANTONOVA	{"phone": "+70758629417"}
0005434229222	300F89	5972 431191	MARIYA LUKYANOVA	{"email": "mariya.lukyanova31051974@postgrespro.ru", "phone": "+70404103007"}
0005434229223	E31775	0619 209649	NIKOLAY NAZAROV	{"email": "nazarovn-05041965@postgrespro.ru", "phone": "+70817816410"}
0005434229224	E31775	7182 148154	NATALYA MATVEEVA	{"email": "natalya_matveeva-1978@postgrespro.ru", "phone": "+70552114681"}
0005434229225	444FFF	8361 372648	ARTEM SCHERBAKOV	{"email": "artemscherbakov.031965@postgrespro.ru", "phone": "+70310551352"}
0005434229226	444FFF	1512 727170	IGOR IVANOV	{"phone": "+70258566659"}
0005434229227	2A048B	0195 007725	VALENTINA NESTEROVA	{"email": "valentina.nesterova-12101973@postgrespro.ru", "phone": "+70638029004"}
0005434229228	2A048B	5807 614548	ZINAIDA ZHUKOVA	{"email": "z-zhukova16051973@postgrespro.ru", "phone": "+70647332776"}
0005434229229	6CB61A	8699 891716	ELINA PAVLOVA	{"phone": "+70820478308"}
0005434229230	27ACD3	0779 794613	VLADIMIR DENISOV	{"email": "denisov-vladimir1978@postgrespro.ru", "phone": "+70060534185"}
0005434229231	B1B24F	5767 420545	RAISA SMIRNOVA	{"email": "r-smirnova-02101976@postgrespro.ru", "phone": "+70370636567"}
0005434229232	B1B24F	1677 973439	ANTONINA POTAPOVA	{"email": "potapovaantonina1974@postgrespro.ru", "phone": "+70892832538"}
0005434229233	71469C	4984 046645	MARIYA EFIMOVA	{"email": "efimova.mariya_1973@postgrespro.ru", "phone": "+70111852144"}
0005434229234	563DD8	6157 698400	VALENTINA MIKHAYLOVA	{"email": "valentinamikhaylova-041978@postgrespro.ru", "phone": "+70629185704"}
0005434229235	C660DC	0552 201918	YURIY MAKAROV	{"phone": "+70706045564"}
0005434229236	57753E	1684 893839	MADINA GORBUNOVA	{"email": "gorbunova.madina.1969@postgrespro.ru", "phone": "+70556515866"}
0005434229237	73EC3C	3757 318608	DMITRIY ZHUKOV	{"phone": "+70690776807"}
0005434229238	73EC3C	3616 266119	VERA KARPOVA	{"email": "verakarpova.04041978@postgrespro.ru", "phone": "+70820099494"}
0005434229239	73EC3C	0771 011760	NADEZHDA MAKSIMOVA	{"email": "nadezhdamaksimova011968@postgrespro.ru", "phone": "+70892161545"}
0005434229240	73EC3C	6187 811413	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr.06071984@postgrespro.ru", "phone": "+70989692894"}
0005434229241	D00227	4317 327768	LYUDMILA KAZAKOVA	{"email": "lyudmilakazakova-021975@postgrespro.ru", "phone": "+70416436320"}
0005434229242	D00227	3003 733501	POLINA ABRAMOVA	{"email": "polinaabramova.021959@postgrespro.ru", "phone": "+70111314620"}
0005434229243	253F6D	1785 804850	MARIYA PAVLOVA	{"phone": "+70000115324"}
0005434229244	CB0D55	8901 001368	ANNA SMIRNOVA	{"email": "smirnova-a1963@postgrespro.ru", "phone": "+70678186097"}
0005434229245	CB0D55	3475 947749	ALEKSEY SEMENOV	{"phone": "+70090784130"}
0005434229246	4CD101	3996 964314	ILYA MAKAROV	{"email": "makarovilya-1968@postgrespro.ru", "phone": "+70214733400"}
0005434229247	DCE286	3974 940549	ALEKSEY EGOROV	{"phone": "+70276141753"}
0005434229248	1A7C1C	1115 382718	ANNA IVANOVA	{"email": "ivanova_a-061987@postgrespro.ru", "phone": "+70498720090"}
0005434229249	C31B1F	9654 349288	VYACHESLAV ABRAMOV	{"email": "vabramov-111959@postgrespro.ru", "phone": "+70551347986"}
0005434229250	C31B1F	1933 358983	YULIYA NIKOLAEVA	{"email": "nikolaeva_yuliya-23051970@postgrespro.ru", "phone": "+70294854184"}
0005434229251	9FD23C	2045 633044	NATALIYA MALYSHEVA	{"phone": "+70667200798"}
0005434229252	9FD23C	4396 153309	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko_1977@postgrespro.ru", "phone": "+70723546379"}
0005434229253	993C12	3692 673786	VIKTOR MIKHAYLOV	{"phone": "+70279187124"}
0005434229254	75621C	1870 684464	NIKOLAY IVANOV	{"phone": "+70862586325"}
0005434229255	75621C	0164 521746	VLADIMIR SERGEEV	{"phone": "+70309991396"}
0005434229256	66AE35	6116 642667	EVGENIY KUZMIN	{"phone": "+70278060955"}
0005434229257	66AE35	9838 982854	YURIY VOLKOV	{"email": "yuriy.volkov.1959@postgrespro.ru", "phone": "+70793577999"}
0005434229258	96CF33	3925 503431	YURIY MAKAROV	{"phone": "+70811624538"}
0005434229259	487A38	2951 885482	IRINA SEMENOVA	{"email": "i.semenova_1963@postgrespro.ru", "phone": "+70164998140"}
0005434229260	487A38	2087 579144	DMITRIY ISAEV	{"phone": "+70966511327"}
0005434229261	F29F40	3416 813819	ALEKSEY BORISOV	{"email": "borisovaleksey031968@postgrespro.ru", "phone": "+70008108733"}
0005434229262	44AE77	9874 210539	DMITRIY KOZLOV	{"email": "d-kozlov-27091970@postgrespro.ru", "phone": "+70632482250"}
0005434229263	44AE77	3702 424121	GENNADIY ZAYCEV	{"phone": "+70311928284"}
0005434229264	445685	2506 249034	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.28101971@postgrespro.ru", "phone": "+70579086061"}
0005434229265	694F89	7872 685601	SERGEY NIKITIN	{"phone": "+70182254673"}
0005434229266	47B676	6109 464814	ALEKSEY YAKOVLEV	{"phone": "+70681934050"}
0005434229267	47B676	1735 284351	EKATERINA ORLOVA	{"phone": "+70535340949"}
0005434229268	DF3713	4605 014454	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr.1968@postgrespro.ru", "phone": "+70221399103"}
0005434229269	1041B6	6209 039179	IGOR BONDARENKO	{"email": "bondarenko-i-091968@postgrespro.ru", "phone": "+70743508241"}
0005434229270	598A74	1893 905122	ANDREY GUSEV	{"email": "gusev.a-011966@postgrespro.ru", "phone": "+70573983061"}
0005434229271	598A74	4614 689829	NINA GORBUNOVA	{"email": "gorbunova-nina-03051964@postgrespro.ru", "phone": "+70800748869"}
0005434229272	22F475	5553 733518	OLGA GRISHINA	{"phone": "+70544038937"}
0005434229273	22F475	1209 820117	DARYA MAKSIMOVA	{"email": "maksimova-darya-1967@postgrespro.ru", "phone": "+70365933432"}
0005434229274	22F475	4143 877993	TAMARA EGOROVA	{"phone": "+70615569091"}
0005434229275	DC79A2	6262 329703	VADIM KOROLEV	{"phone": "+70099067834"}
0005434229276	4D2E03	7397 459403	VLADIMIR ANDREEV	{"email": "andreev.vladimir.121960@postgrespro.ru", "phone": "+70149251558"}
0005434229277	4D2E03	3612 704662	EKATERINA ZHURAVLEVA	{"phone": "+70542982247"}
0005434229278	AC4F29	5939 931176	IVAN OSIPOV	{"phone": "+70411861963"}
0005434229279	D25DC3	8790 398790	ZINAIDA SMIRNOVA	{"email": "smirnovazinaida_1977@postgrespro.ru", "phone": "+70734136080"}
0005434229280	D25DC3	4499 231855	ELENA POLYAKOVA	{"email": "polyakovaelena_20101981@postgrespro.ru", "phone": "+70158683718"}
0005434229281	3DEA3E	7738 971484	GALINA LUKYANOVA	{"email": "lukyanovagalina_17091976@postgrespro.ru", "phone": "+70889974763"}
0005434229282	8C6E92	4713 988160	NATALYA SOKOLOVA	{"phone": "+70539637161"}
0005434229283	8C6E92	2548 228758	VITALIY SIDOROV	{"phone": "+70889596702"}
0005434229284	52C8E0	8478 015985	VLADISLAV ALEKSANDROV	{"phone": "+70259377564"}
0005434229285	E16AD6	6820 554482	VERA ROMANOVA	{"email": "romanovavera_051972@postgrespro.ru", "phone": "+70357668801"}
0005434229286	7D70C0	5967 459498	VALENTINA SAVELEVA	{"email": "saveleva.valentina_041982@postgrespro.ru", "phone": "+70528224071"}
0005434229287	B8D9CD	5125 203980	DARYA KUZNECOVA	{"phone": "+70189402268"}
0005434229288	0C4340	7954 787989	VLADIMIR SCHERBAKOV	{"email": "scherbakovvladimir_1982@postgrespro.ru", "phone": "+70441403259"}
0005434229289	49D772	5192 758637	IRINA ALEKSANDROVA	{"phone": "+70800864056"}
0005434229290	49D772	7234 589387	MARIYA ORLOVA	{"phone": "+70924198578"}
0005434229291	F4BBA3	2036 131804	MARIYA NIKOLAEVA	{"email": "mariya-nikolaeva-1971@postgrespro.ru", "phone": "+70011923143"}
0005434229292	C9C5BE	2328 180965	TATYANA KUZNECOVA	{"phone": "+70704170830"}
0005434229293	403CD5	7281 981642	DARYA BORISOVA	{"email": "borisova.d-26061986@postgrespro.ru", "phone": "+70630323676"}
0005434229294	403CD5	5573 595200	MIKHAIL KAZAKOV	{"phone": "+70158952420"}
0005434229295	9F74DD	5915 701329	VALENTINA DAVYDOVA	{"phone": "+70272818730"}
0005434229296	CF6122	3083 973565	RAFAIL KULIKOV	{"phone": "+70175639790"}
0005434229297	14B99E	6052 178391	OKSANA KUZMINA	{"email": "o-kuzmina1973@postgrespro.ru", "phone": "+70623941875"}
0005434229298	B7CE59	0398 834178	VALERIY MOROZOV	{"phone": "+70266561910"}
0005434229299	0F5AC1	2353 818480	IRINA IVANOVA	{"phone": "+70550966771"}
0005434229300	BC7871	3153 009636	EVGENIY FEDOROV	{"email": "fedorov.evgeniy-24121976@postgrespro.ru", "phone": "+70710088274"}
0005434229301	AF7FD7	6050 719331	YURIY MIKHAYLOV	{"phone": "+70488419990"}
0005434229302	3DED7B	5291 665278	SERGEY BARANOV	{"phone": "+70937680822"}
0005434229303	B201E3	1779 805159	NINA GUSEVA	{"phone": "+70062269326"}
0005434229304	B42E4C	5785 686464	KRISTINA MOROZOVA	{"phone": "+70086226003"}
0005434229305	6F3B6B	8645 231816	ALEKSEY ORLOV	{"phone": "+70706257998"}
0005434229306	7DBD9A	0681 244120	VIKTOR VASILEV	{"email": "viktor_vasilev-051968@postgrespro.ru", "phone": "+70065753916"}
0005434229307	C248B7	3173 293040	TATYANA LOGINOVA	{"email": "tatyana.loginova_071982@postgrespro.ru", "phone": "+70670318609"}
0005434229308	77F19B	5478 515659	IGOR IVANOV	{"phone": "+70443772983"}
0005434229309	89B563	9393 250038	LYUDMILA ZAYCEVA	{"email": "lyudmilazayceva20121966@postgrespro.ru", "phone": "+70919279424"}
0005434229310	89B563	5002 298860	MIKHAIL SCHERBAKOV	{"phone": "+70924264753"}
0005434229311	CD16DA	2651 826897	ZAKHAR DMITRIEV	{"phone": "+70842788830"}
0005434229312	2C604D	8337 097044	NATALYA ZAKHAROVA	{"phone": "+70657715848"}
0005434229313	5A7D56	6659 522720	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_s-1971@postgrespro.ru", "phone": "+70606885229"}
0005434229314	5A7D56	6910 588120	ALEKSEY SERGEEV	{"phone": "+70158813810"}
0005434229315	921826	4856 137038	LYUBOV FOMINA	{"email": "fomina-l_1969@postgrespro.ru", "phone": "+70836537108"}
0005434229316	D421AA	4198 517466	ALEKSEY KUZMIN	{"email": "kuzmin.aleksey_1977@postgrespro.ru", "phone": "+70571462794"}
0005434229317	4DCAE4	8392 594549	SERGEY MOROZOV	{"email": "morozov-s.1963@postgrespro.ru", "phone": "+70223221298"}
0005434229318	216898	8303 002680	VALENTINA MATVEEVA	{"email": "v.matveeva.13041964@postgrespro.ru", "phone": "+70141521673"}
0005434229319	1CB467	4249 567549	MARIYA ANISIMOVA	{"phone": "+70728169901"}
0005434229320	1CB467	7298 361501	KRISTINA IVANOVA	{"email": "kristina-ivanova-111971@postgrespro.ru", "phone": "+70361915943"}
0005434229321	C593B3	6300 511841	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaa26081963@postgrespro.ru", "phone": "+70404344700"}
0005434229322	52781E	6436 077263	SERGEY GUSEV	{"phone": "+70155935929"}
0005434229323	52781E	3875 028888	NIKOLAY MIRONOV	{"phone": "+70889135492"}
0005434229324	BF35B6	8865 649490	RINAT KUZNECOV	{"email": "kuznecov-r_1965@postgrespro.ru", "phone": "+70915042813"}
0005434229325	BF35B6	0517 128973	NIKITA POPOV	{"phone": "+70613615578"}
0005434229326	50300B	4819 015965	VLADIMIR MOISEEV	{"email": "vladimir_moiseev.07051960@postgrespro.ru", "phone": "+70252318944"}
0005434229327	50300B	5133 483986	NADEZHDA ROMANOVA	{"phone": "+70500061841"}
0005434229328	E2D671	2478 539396	YURIY GRIGOREV	{"email": "ygrigorev.23071978@postgrespro.ru", "phone": "+70608806147"}
0005434229772	84770D	2437 055905	KIRA EFREMOVA	{"phone": "+70893460974"}
0005434229329	E2D671	5482 445383	ALEKSANDR ZAYCEV	{"email": "a-zaycev051975@postgrespro.ru", "phone": "+70331560428"}
0005434229330	D227C0	5097 014145	ANATOLIY FROLOV	{"phone": "+70769974338"}
0005434229331	6E5ACD	2855 900905	OLESYA EFIMOVA	{"phone": "+70153184226"}
0005434229332	6E5ACD	6269 672771	LYUBOV NIKITINA	{"email": "lnikitina.091970@postgrespro.ru", "phone": "+70075981488"}
0005434229333	6E5ACD	6769 756933	NIKOLAY DAVYDOV	{"phone": "+70428513098"}
0005434229334	CC7F14	2097 725234	DMITRIY VASILEV	{"phone": "+70040742635"}
0005434229335	3420A0	9993 195331	ANTON OSIPOV	{"phone": "+70306772679"}
0005434229336	3420A0	2576 294932	VALENTINA ANTONOVA	{"email": "v.antonova.1969@postgrespro.ru", "phone": "+70334039344"}
0005434229337	B98FBA	0956 213191	ALEKSANDRA MOROZOVA	{"phone": "+70390729323"}
0005434229338	B98FBA	7966 214056	VIKTOR VOLKOV	{"email": "volkovv.17071976@postgrespro.ru", "phone": "+70738601426"}
0005434229339	59B7FD	7126 845161	LYUBOV ROMANOVA	{"phone": "+70594106367"}
0005434229340	D7FB18	9757 891348	EVGENIY BELOV	{"email": "belovevgeniy.071975@postgrespro.ru", "phone": "+70980564009"}
0005434229341	D7FB18	0619 642602	TATYANA FOMINA	{"phone": "+70221506884"}
0005434229342	D7FB18	3227 340951	YURIY ALEKSANDROV	{"phone": "+70599250259"}
0005434229343	D0BD52	8388 514190	VLADIMIR KISELEV	{"email": "vladimir_kiselev.07111974@postgrespro.ru", "phone": "+70094454753"}
0005434229344	D0BD52	1675 093923	VADIM KUZNECOV	{"email": "vadim.kuznecov_101966@postgrespro.ru", "phone": "+70178816101"}
0005434229345	33386C	4152 203752	ANATOLIY PETROV	{"email": "petrovanatoliy-121960@postgrespro.ru", "phone": "+70480801476"}
0005434229346	33386C	3514 591927	DMITRIY KOZLOV	{"email": "d_kozlov-17061978@postgrespro.ru", "phone": "+70569000697"}
0005434229347	EAA81E	0351 129853	NIKITA ZAKHAROV	{"email": "zakharovn1975@postgrespro.ru", "phone": "+70986257791"}
0005434229348	D54088	4932 584008	OLGA SOROKINA	{"phone": "+70233967815"}
0005434229349	CA023B	6113 267395	NADEZHDA KULIKOVA	{"phone": "+70433413237"}
0005434229350	CA023B	2994 942656	NATALYA SOKOLOVA	{"phone": "+70019677737"}
0005434229351	FC1C45	2125 138845	SERGEY FROLOV	{"phone": "+70153546910"}
0005434229352	FC1C45	8450 596221	ANDREY SOROKIN	{"email": "sorokin_a.021968@postgrespro.ru", "phone": "+70980196666"}
0005434229353	FC1C45	9888 274595	VIKTOR MIKHAYLOV	{"email": "v_mikhaylov-21101981@postgrespro.ru", "phone": "+70527621446"}
0005434229354	0BBB89	9303 981276	MATVEY POPOV	{"phone": "+70130475805"}
0005434229355	5422F6	4355 709221	NATALYA KOZLOVA	{"phone": "+70100014978"}
0005434229356	FB570D	9297 859389	ANTONIDA TARASOVA	{"phone": "+70886346632"}
0005434229357	1E1D45	4483 632637	VADIM OSIPOV	{"email": "osipov_v.061970@postgrespro.ru", "phone": "+70702621776"}
0005434229358	1E1D45	6182 411642	DMITRIY TARASOV	{"phone": "+70156472793"}
0005434229359	C6B0B4	4902 555438	ULYANA TIMOFEEVA	{"phone": "+70765464296"}
0005434229360	C6B0B4	7404 575812	OLEG PETROV	{"phone": "+70174313261"}
0005434229361	B3CBDC	6217 689713	ALEVTINA MOISEEVA	{"phone": "+70026850867"}
0005434229362	B3CBDC	4562 192722	NADEZHDA MELNIKOVA	{"email": "melnikova_n1967@postgrespro.ru", "phone": "+70017870992"}
0005434229363	B3CBDC	4822 620325	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_1965@postgrespro.ru", "phone": "+70936500564"}
0005434229421	B369DC	9279 025893	EVA STEPANOVA	{"phone": "+70890567284"}
0005434229364	B3CBDC	2554 692463	SERGEY MELNIKOV	{"email": "melnikov-s-27061969@postgrespro.ru", "phone": "+70238226507"}
0005434229365	7DF59D	2060 476352	ANTONINA SIDOROVA	{"email": "sidorova-a_071979@postgrespro.ru", "phone": "+70991475587"}
0005434229366	7D0D57	3425 080972	ANASTASIYA YAKOVLEVA	{"email": "anastasiya.yakovleva_1962@postgrespro.ru", "phone": "+70826455692"}
0005434229367	7D0D57	8178 600681	SERGEY SMIRNOV	{"phone": "+70398384379"}
0005434229368	7D0D57	9613 881747	TATYANA RODIONOVA	{"email": "trodionova.11021965@postgrespro.ru", "phone": "+70527020159"}
0005434229369	4C1BE5	7768 429545	LIDIYA AFANASEVA	{"email": "afanaseva-lidiya.01091978@postgrespro.ru", "phone": "+70590328333"}
0005434229370	0B70CD	5154 900756	GENNADIY PAVLOV	{"email": "gennadiy.pavlov.1981@postgrespro.ru", "phone": "+70937428843"}
0005434229371	AD1331	8339 487862	NINA SEMENOVA	{"email": "nina.semenova_1970@postgrespro.ru", "phone": "+70710540388"}
0005434229372	0DAF45	4182 379406	NADEZHDA NIKITINA	{"email": "nikitina.n041961@postgrespro.ru", "phone": "+70863621064"}
0005434229373	FA6372	2152 372012	BULAT SOROKIN	{"email": "sorokin_bulat061979@postgrespro.ru", "phone": "+70434956926"}
0005434229374	BB0A34	2353 871996	LIDIYA LAZAREVA	{"phone": "+70865838782"}
0005434229375	F589E6	8014 266776	ZOYA KOVALEVA	{"email": "z.kovaleva-081968@postgrespro.ru", "phone": "+70310630190"}
0005434229376	2294B3	0361 756375	ALEKSANDR KONOVALOV	{"email": "aleksandr-konovalov.13051967@postgrespro.ru", "phone": "+70278694209"}
0005434229377	8B341C	2421 688968	GRIGORIY MATVEEV	{"email": "g_matveev-041979@postgrespro.ru", "phone": "+70884000605"}
0005434229378	88BAEB	0423 976503	STANISLAV MATVEEV	{"phone": "+70943643220"}
0005434229379	F34C19	7434 993087	TALGAT SMIRNOV	{"phone": "+70230101421"}
0005434229380	F34C19	3700 079727	ANTON CHERNOV	{"email": "chernov_a-1973@postgrespro.ru", "phone": "+70565301858"}
0005434229381	1EF696	0875 549482	ANDREY ALEKSANDROV	{"phone": "+70882987300"}
0005434229382	1EF696	3801 978804	ILYA KISELEV	{"email": "kiselev_ilya-041972@postgrespro.ru", "phone": "+70406829573"}
0005434229383	E28490	5176 754337	ANASTASIYA STEPANOVA	{"email": "stepanova.a.26061961@postgrespro.ru", "phone": "+70078555587"}
0005434229384	E28490	6564 072638	NATALYA IVANOVA	{"email": "n.ivanova-06061963@postgrespro.ru", "phone": "+70691837279"}
0005434229385	2AD85D	4968 219214	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_s-1972@postgrespro.ru", "phone": "+70707884448"}
0005434229386	2AD85D	8226 916117	OLGA FEDOROVA	{"phone": "+70255307271"}
0005434229387	2B21E7	5076 736748	ALEKSEY GORBUNOV	{"email": "gorbunov_a.111974@postgrespro.ru", "phone": "+70700188840"}
0005434229388	117CCB	0371 263820	OKSANA BOGDANOVA	{"email": "oksana-bogdanova_12041967@postgrespro.ru", "phone": "+70975978522"}
0005434229389	117CCB	1933 648988	VALENTIN MATVEEV	{"email": "valentin-matveev_03061972@postgrespro.ru", "phone": "+70148135250"}
0005434229390	021196	3312 207590	EGOR ANDREEV	{"email": "e-andreev-09061967@postgrespro.ru", "phone": "+70170986659"}
0005434229391	AAC3C2	2264 233783	ROMAN ANTONOV	{"email": "roman-antonov.121967@postgrespro.ru", "phone": "+70043215053"}
0005434229392	12A56D	5879 993560	SERGEY DAVYDOV	{"email": "davydov.s031977@postgrespro.ru", "phone": "+70631544924"}
0005434229393	04DD96	9939 677204	YULIYA ANDREEVA	{"phone": "+70706000885"}
0005434229394	04DD96	8675 085952	VALENTINA SERGEEVA	{"email": "v_sergeeva_31101976@postgrespro.ru", "phone": "+70558316470"}
0005434229395	FD1385	8808 180329	ANATOLIY KOROLEV	{"email": "korolev-a.101980@postgrespro.ru", "phone": "+70793482275"}
0005434229396	FD1385	9262 498070	OLGA NOVIKOVA	{"email": "olga_novikova-011965@postgrespro.ru", "phone": "+70905531616"}
0005434229397	E28DB4	8723 554705	ELENA KALININA	{"email": "ekalinina-05031976@postgrespro.ru", "phone": "+70029346649"}
0005434229398	6447D6	5210 117292	OKSANA SIDOROVA	{"email": "oksana-sidorova27071972@postgrespro.ru", "phone": "+70645295866"}
0005434229399	FC1A76	8706 076891	NATALYA KUZNECOVA	{"email": "kuznecova_n_28101975@postgrespro.ru", "phone": "+70930436838"}
0005434229400	FC1A76	6129 075843	TATYANA FADEEVA	{"phone": "+70555821960"}
0005434229401	EFE787	9845 917336	SNEZHANA ZAYCEVA	{"email": "zaycevas_16081972@postgrespro.ru", "phone": "+70589308644"}
0005434229402	3E48C8	9941 469481	PAVEL MEDVEDEV	{"email": "pavelmedvedev-1969@postgrespro.ru", "phone": "+70468654809"}
0005434229403	60F5EE	7602 508536	SERGEY VASILEV	{"phone": "+70808720223"}
0005434229404	2BCDCF	0799 388600	EVGENIY EGOROV	{"email": "egorov.evgeniy.071959@postgrespro.ru", "phone": "+70234819851"}
0005434229405	2BCDCF	7371 326876	TATYANA PAVLOVA	{"phone": "+70488639587"}
0005434229406	528040	2552 235530	NADEZHDA BORISOVA	{"phone": "+70430520677"}
0005434229407	1FD069	0101 520614	ALEKSEY KONOVALOV	{"email": "konovalov_aleksey1972@postgrespro.ru", "phone": "+70061057674"}
0005434229408	B8FBB0	2644 367088	NIKOLAY MATVEEV	{"phone": "+70192884201"}
0005434229409	C7EE98	6481 612133	ROZA KUZNECOVA	{"email": "rozakuznecova1976@postgrespro.ru", "phone": "+70357313605"}
0005434229410	BBEB1F	0165 162053	IRINA FOMINA	{"phone": "+70981778146"}
0005434229411	E31192	6194 574949	RAIS DMITRIEV	{"email": "dmitriev_rais-091979@postgrespro.ru", "phone": "+70537818205"}
0005434229412	996616	6809 062711	IRINA VLASOVA	{"phone": "+70926546023"}
0005434229413	996616	3573 031373	OLGA FOMINA	{"email": "o_fomina-1978@postgrespro.ru", "phone": "+70635915025"}
0005434229414	8BA611	2592 225638	MIKHAIL ILIN	{"email": "ilin.mikhail-011966@postgrespro.ru", "phone": "+70577289850"}
0005434229415	8BA611	2463 584903	VLADIMIR KISELEV	{"phone": "+70451605629"}
0005434229416	8BA611	0924 715648	KLAVDIYA POPOVA	{"phone": "+70815891758"}
0005434229417	3475F6	0412 599729	NIKOLAY SIDOROV	{"phone": "+70170044458"}
0005434229418	130152	0267 413990	ALEKSANDR MAKAROV	{"phone": "+70163684613"}
0005434229419	69B2B1	0289 258430	MARIYA MAKSIMOVA	{"email": "maksimovam-061983@postgrespro.ru", "phone": "+70164164828"}
0005434229420	2D4B9A	9378 523200	VLADIMIR FEDOTOV	{"email": "fedotovvladimir_1976@postgrespro.ru", "phone": "+70656951989"}
0005434229422	267458	3482 529290	ALEKSANDR DAVYDOV	{"phone": "+70933423508"}
0005434229423	267458	2594 919755	IGOR MOROZOV	{"email": "morozov_igor_101972@postgrespro.ru", "phone": "+70646161597"}
0005434229424	C44354	5601 353422	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.a-1973@postgrespro.ru", "phone": "+70976513824"}
0005434229425	C37389	3299 875497	GULNAZ TIKHONOVA	{"phone": "+70992711858"}
0005434229426	C37389	2804 060146	YULIYA GERASIMOVA	{"phone": "+70529653744"}
0005434229427	152F5D	0928 029756	NADEZHDA GUSEVA	{"phone": "+70913295243"}
0005434229428	152F5D	6149 824229	LYUDMILA SAVELEVA	{"email": "saveleva.lyudmila30051971@postgrespro.ru", "phone": "+70495496104"}
0005434229429	152F5D	6674 003290	ALEKSANDRA FEDOROVA	{"email": "aleksandrafedorova.16051972@postgrespro.ru", "phone": "+70671309566"}
0005434229430	D8FD88	4174 237489	VERA VASILEVA	{"phone": "+70627827460"}
0005434229431	951CE6	8714 304328	ANNA GERASIMOVA	{"email": "annagerasimova-26031982@postgrespro.ru", "phone": "+70305061634"}
0005434229432	951CE6	6967 126557	MAKSIM DAVYDOV	{"email": "davydovm.091979@postgrespro.ru", "phone": "+70845510145"}
0005434229433	1BF408	8534 419498	EKATERINA SAVELEVA	{"email": "saveleva.e.1966@postgrespro.ru", "phone": "+70548019602"}
0005434229434	1CF6F7	8818 392599	TATYANA ABRAMOVA	{"email": "abramovatatyana_10081972@postgrespro.ru", "phone": "+70698191445"}
0005434229435	5DA9FF	8726 965004	ALEKSANDR KARPOV	{"phone": "+70114755994"}
0005434229436	92B09B	1077 428621	ELENA KUDRYASHOVA	{"email": "elena_kudryashova-1964@postgrespro.ru", "phone": "+70092223622"}
0005434229437	7EECE2	0832 652091	TATYANA IVANOVA	{"email": "tivanova-091972@postgrespro.ru", "phone": "+70170186719"}
0005434229438	7EECE2	1071 587519	YURIY MATVEEV	{"phone": "+70274090084"}
0005434229439	DE48AD	2502 624631	ALEKSANDR ISAEV	{"phone": "+70979611211"}
0005434229440	DE48AD	8033 731411	ALEKSANDR ALEKSEEV	{"email": "a.alekseev-03111973@postgrespro.ru", "phone": "+70656860568"}
0005434229441	4BB047	6061 341637	RODION ANTONOV	{"phone": "+70540128674"}
0005434229442	0158F8	2572 645509	VLADIMIR ILIN	{"email": "ilin-v-18111970@postgrespro.ru", "phone": "+70114917731"}
0005434229443	275E75	3565 719663	SERGEY PAVLOV	{"email": "pavlov_sergey_031976@postgrespro.ru", "phone": "+70702800236"}
0005434229444	A13743	7072 002857	MARTA ARKHIPOVA	{"email": "m_arkhipova22011969@postgrespro.ru", "phone": "+70852616615"}
0005434229445	A13743	4946 658710	IRINA LEBEDEVA	{"phone": "+70303673301"}
0005434229446	A13743	3203 713739	ALBERT MIRONOV	{"email": "albert_mironov.17061981@postgrespro.ru", "phone": "+70357227029"}
0005434229447	68BF61	4901 623764	ELENA NAUMOVA	{"email": "naumova_elena04051972@postgrespro.ru", "phone": "+70138485697"}
0005434229448	68BF61	3430 631066	ALEKSEY FEDOROV	{"phone": "+70310787957"}
0005434229449	BA0C54	9829 137102	KLAVDIYA MIRONOVA	{"phone": "+70519778043"}
0005434229450	A0B41B	5892 052171	ELENA MIKHAYLOVA	{"email": "mikhaylova_e-09101964@postgrespro.ru", "phone": "+70324675348"}
0005434229451	DD3971	9422 487694	NIKITA PAVLOV	{"phone": "+70995898482"}
0005434229452	DC96E1	0970 513193	VERA ANDREEVA	{"email": "vera.andreeva091972@postgrespro.ru", "phone": "+70049510768"}
0005434229453	558E75	6945 906478	VIKTOR CHERNOV	{"email": "chernovviktor.081966@postgrespro.ru", "phone": "+70091624172"}
0005434229454	558E75	8823 042888	TAMARA POPOVA	{"phone": "+70943197267"}
0005434229455	D0433C	6759 999412	OLGA OSIPOVA	{"phone": "+70468343836"}
0005434229456	D0433C	8480 314722	SERGEY IVANOV	{"email": "sivanov1975@postgrespro.ru", "phone": "+70661404933"}
0005434229457	253D1F	0896 121388	PAVEL KONOVALOV	{"phone": "+70447572286"}
0005434229458	1A111D	2794 697042	ALEKSANDR SHEVCHENKO	{"email": "aleksandr.shevchenko1962@postgrespro.ru", "phone": "+70846217725"}
0005434229459	1A111D	2436 667847	GALINA KUZNECOVA	{"email": "kuznecova_galina.1975@postgrespro.ru", "phone": "+70415987671"}
0005434229460	79C9AF	6744 466924	NATALYA VASILEVA	{"email": "vasileva-n.1967@postgrespro.ru", "phone": "+70157074006"}
0005434229461	79C9AF	7896 686094	RAISA FILATOVA	{"email": "filatova-r1957@postgrespro.ru", "phone": "+70644372932"}
0005434229462	5096C3	3716 428978	DENIS BORISOV	{"phone": "+70754120326"}
0005434229463	1D3C2A	4648 912704	MARIYA SMIRNOVA	{"email": "smirnova.mariya041969@postgrespro.ru", "phone": "+70868325010"}
0005434229464	1D3C2A	5607 280258	YANA STEPANOVA	{"phone": "+70399002050"}
0005434229465	DE5298	5307 902186	ANDREY BELOV	{"email": "a_belov-081977@postgrespro.ru", "phone": "+70450424786"}
0005434229466	DE5298	6376 572101	TATYANA KUZMINA	{"email": "t.kuzmina.08011973@postgrespro.ru", "phone": "+70478575668"}
0005434229467	6BC28C	7299 274289	MARIYA ROMANOVA	{"email": "m-romanova-14071975@postgrespro.ru", "phone": "+70740355260"}
0005434229468	6E892C	1364 001988	DMITRIY GUSEV	{"phone": "+70361128047"}
0005434229469	6E892C	2639 174319	ALEKSANDR MATVEEV	{"email": "a.matveev_031972@postgrespro.ru", "phone": "+70899607162"}
0005434229470	6E892C	1985 715156	VITALIY PETROV	{"phone": "+70066228883"}
0005434229471	72CD55	3886 703280	GALINA EFIMOVA	{"email": "efimovag.101984@postgrespro.ru", "phone": "+70057051964"}
0005434229472	7E5251	5037 635103	VLADIMIR BELOV	{"email": "v-belov-1970@postgrespro.ru", "phone": "+70882595212"}
0005434229473	8B5FA1	3744 964995	VALENTINA STEPANOVA	{"email": "stepanova-v1971@postgrespro.ru", "phone": "+70577897035"}
0005434229474	7EE8CB	7967 091215	LYUDMILA BELOVA	{"phone": "+70584351884"}
0005434229475	738380	1040 680569	ANATOLIY MOISEEV	{"phone": "+70187636394"}
0005434229476	C5EFEA	7485 873174	POLINA DANILOVA	{"phone": "+70781739656"}
0005434229477	C5EFEA	9085 794639	POLINA NIKOLAEVA	{"email": "nikolaevapolina-011963@postgrespro.ru", "phone": "+70729434034"}
0005434229478	4A7F49	4529 910248	ELENA GERASIMOVA	{"email": "elenagerasimova_25071974@postgrespro.ru", "phone": "+70681775632"}
0005434229479	5F1CF5	1390 715222	SERGEY SAVELEV	{"phone": "+70805827517"}
0005434229480	87F367	0540 124640	ALEKSANDR ZAYCEV	{"email": "a_zaycev-111962@postgrespro.ru", "phone": "+70693809909"}
0005434229481	87F367	9275 130881	OKSANA VASILEVA	{"email": "vasileva_oksana_1974@postgrespro.ru", "phone": "+70148090005"}
0005434229482	B47178	0032 323362	ANDREY FEDOROV	{"email": "andrey-fedorov07121966@postgrespro.ru", "phone": "+70262632804"}
0005434229483	B47178	5160 092199	VALENTINA ZAYCEVA	{"email": "v-zayceva-18091971@postgrespro.ru", "phone": "+70848631589"}
0005434229484	B47178	1912 141837	VALERIY SOROKIN	{"phone": "+70946532887"}
0005434229485	CB00D5	8196 038663	GALINA KISELEVA	{"email": "gkiseleva.1963@postgrespro.ru", "phone": "+70864322647"}
0005434229486	1C46FD	1844 535452	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.31121978@postgrespro.ru", "phone": "+70982935964"}
0005434229487	AB1251	9819 830114	SERGEY RODIONOV	{"phone": "+70792739151"}
0005434229488	BBA538	1476 641830	NIKITA BELOV	{"email": "nikitabelov.21011970@postgrespro.ru", "phone": "+70168749901"}
0005434229489	EC4481	2474 040076	ELENA ZHUKOVA	{"phone": "+70201501346"}
0005434229490	093377	1385 334051	SERGEY KUZNECOV	{"phone": "+70874798235"}
0005434229491	6E5CB2	2206 909055	EVGENIY BONDARENKO	{"phone": "+70114914047"}
0005434229492	C9C0C4	5743 856412	IRINA BELOVA	{"phone": "+70518976107"}
0005434229493	6D7DC0	6793 074844	EVGENIY TIKHONOV	{"phone": "+70426818390"}
0005434229494	329122	4004 251391	NIKOLAY POPOV	{"email": "popov-nikolay_1973@postgrespro.ru", "phone": "+70037912036"}
0005434229773	2D965D	7613 566937	NATALYA PETROVA	{"phone": "+70115384634"}
0005434229495	01922F	1007 233683	ALINA FEDOROVA	{"email": "alina_fedorova_21031960@postgrespro.ru", "phone": "+70287384463"}
0005434229496	B4A40B	7523 409586	LYUDMILA KUZNECOVA	{"phone": "+70006013022"}
0005434229497	F7CDEB	3407 959217	NINA MELNIKOVA	{"phone": "+70770359921"}
0005434229498	DEC443	6476 878223	EVGENIYA NAZAROVA	{"email": "nazarova_e-15051973@postgrespro.ru", "phone": "+70141528832"}
0005434229499	1FC4E9	1004 613362	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana_091972@postgrespro.ru", "phone": "+70572610999"}
0005434229500	163E02	7979 844063	VLADISLAV POPOV	{"phone": "+70038240483"}
0005434229501	163E02	0465 400840	VLADIMIR KISELEV	{"email": "kiselev_vladimir_1978@postgrespro.ru", "phone": "+70301605757"}
0005434229502	B753F5	6144 943434	VERA EGOROVA	{"email": "veraegorova_16071964@postgrespro.ru", "phone": "+70069540258"}
0005434229503	8BD554	0325 302883	LYUBOV VASILEVA	{"phone": "+70256662818"}
0005434229504	A849D2	0349 513829	GALINA MOROZOVA	{"email": "gmorozova1966@postgrespro.ru", "phone": "+70670109563"}
0005434229505	14DFC2	0074 419269	PETR IVANOV	{"email": "p_ivanov_081973@postgrespro.ru", "phone": "+70118182341"}
0005434229506	CE377E	2245 666221	NIKOLAY SERGEEV	{"email": "nikolay-sergeev111974@postgrespro.ru", "phone": "+70677901478"}
0005434229507	CE377E	2040 969745	GALINA GERASIMOVA	{"phone": "+70875058844"}
0005434229508	D68A58	5643 236318	VALENTINA KOVALEVA	{"email": "valentina-kovaleva041959@postgrespro.ru", "phone": "+70584447492"}
0005434229509	7A4C72	7271 348718	EVGENIYA PAVLOVA	{"email": "epavlova_29121978@postgrespro.ru", "phone": "+70844940817"}
0005434229510	F42C51	7290 516895	ZLATA SOKOLOVA	{"phone": "+70601373930"}
0005434229511	928D8D	2978 226111	EVGENIY BELOV	{"email": "evgeniy_belov_02031966@postgrespro.ru", "phone": "+70733924247"}
0005434229512	C8B77E	2020 474854	VALENTINA SOROKINA	{"email": "sorokina-v1968@postgrespro.ru", "phone": "+70333648483"}
0005434229513	CE6F92	8901 316305	VALERIY SOKOLOV	{"email": "v-sokolov-071979@postgrespro.ru", "phone": "+70010987036"}
0005434229514	8BC8DF	1306 633349	NIKOLAY ANTONOV	{"phone": "+70117712402"}
0005434229515	FDBAC3	5594 295315	LYUDMILA ZHURAVLEVA	{"phone": "+70288621011"}
0005434229516	F5A36C	9842 045608	NATALYA STEPANOVA	{"email": "natalya_stepanova-16121979@postgrespro.ru", "phone": "+70830991963"}
0005434229517	B95198	2832 822152	MIKHAIL MEDVEDEV	{"phone": "+70429799271"}
0005434229518	401F62	5245 432624	VERONIKA KULIKOVA	{"phone": "+70218858669"}
0005434229519	57CA0F	7714 376134	ROMAN KULIKOV	{"email": "r-kulikov101962@postgrespro.ru", "phone": "+70528422349"}
0005434229964	5F0A07	4207 632348	IRINA MOROZOVA	{"phone": "+70434426465"}
0005434229520	EF9FD4	2450 210733	INNA KUDRYASHOVA	{"email": "innakudryashova.101980@postgrespro.ru", "phone": "+70826015143"}
0005434229521	831C26	3918 210397	EVA SIDOROVA	{"email": "eva-sidorova.12071975@postgrespro.ru", "phone": "+70435487073"}
0005434229522	D00C4A	8056 155571	ANATOLIY GERASIMOV	{"email": "anatoliygerasimov_07041953@postgrespro.ru", "phone": "+70912268978"}
0005434229523	F004EB	8723 286599	OLGA AFANASEVA	{"email": "afanaseva-o_1971@postgrespro.ru", "phone": "+70892810457"}
0005434229524	D8FC31	3243 403707	VERA AKIMOVA	{"email": "vakimova.1967@postgrespro.ru", "phone": "+70592033291"}
0005434229525	FFC620	4637 429070	EKATERINA NESTEROVA	{"phone": "+70553788319"}
0005434229526	557736	5064 286484	SALAVAT PAVLOV	{"email": "pavlov-s-1979@postgrespro.ru", "phone": "+70895359098"}
0005434229527	9999F1	6541 346926	LYUDMILA GAVRILOVA	{"email": "lyudmila-gavrilova.051969@postgrespro.ru", "phone": "+70116922396"}
0005434229528	9999F1	8082 878342	SERGEY ABRAMOV	{"email": "sergey.abramov.071971@postgrespro.ru", "phone": "+70377319615"}
0005434229529	A02671	8284 481727	IVAN CHERNOV	{"phone": "+70300686236"}
0005434229530	F20784	0968 734253	EVDOKIYA ALEKSANDROVA	{"email": "aleksandrovaevdokiya1972@postgrespro.ru", "phone": "+70466238829"}
0005434229531	F20784	2823 790901	ALEKSANDR MAKAROV	{"email": "makarova.101978@postgrespro.ru", "phone": "+70305212058"}
0005434229532	BC45B5	3755 380631	LEV ZAYCEV	{"phone": "+70209102351"}
0005434229533	8506C8	6580 183936	ALEVTINA KUDRYASHOVA	{"phone": "+70903767316"}
0005434229534	8D19EF	2540 554951	VLADIMIR EGOROV	{"email": "v_egorov071975@postgrespro.ru", "phone": "+70131383099"}
0005434229535	781802	6482 841863	OLEG ANTONOV	{"email": "antonovoleg.24011973@postgrespro.ru", "phone": "+70804698663"}
0005434229536	AD6131	8592 507832	OLGA FROLOVA	{"email": "olga_frolova1980@postgrespro.ru", "phone": "+70250071346"}
0005434229537	DA05C3	8230 630465	OLEG KAZAKOV	{"phone": "+70981385345"}
0005434229538	3A0319	2244 507494	NIKOLAY KAZAKOV	{"phone": "+70781134422"}
0005434229539	E27ECE	0073 085511	VLADIMIR IVANOV	{"phone": "+70569510150"}
0005434229540	E27ECE	5528 676524	NIKITA SAVELEV	{"phone": "+70261889531"}
0005434229541	48A1E3	6389 196031	IRINA TIKHONOVA	{"phone": "+70820445412"}
0005434229542	0D804B	1867 214891	YULIYA BOGDANOVA	{"email": "y.bogdanova_101962@postgrespro.ru", "phone": "+70561234013"}
0005434229543	F54619	3119 639897	VIKTOR ZHURAVLEV	{"email": "zhuravlev_viktor_17031978@postgrespro.ru", "phone": "+70310675931"}
0005434229544	F54619	2980 185164	ILYA MATVEEV	{"email": "i-matveev31121974@postgrespro.ru", "phone": "+70997567404"}
0005434229545	E8415C	0557 233218	ALEKSEY IVANOV	{"email": "ivanovaleksey.091975@postgrespro.ru", "phone": "+70920243166"}
0005434229546	E8415C	6885 487964	OLGA STEPANOVA	{"email": "olga-stepanova.14121970@postgrespro.ru", "phone": "+70437559066"}
0005434229547	E8415C	2058 347127	NIKOLAY FROLOV	{"email": "frolovnikolay.1967@postgrespro.ru", "phone": "+70539132900"}
0005434229548	E6014D	5961 520953	VLADIMIR ZHUKOV	{"email": "zhukovv.02031969@postgrespro.ru", "phone": "+70534765959"}
0005434229549	EB6B7B	3959 652936	ALEKSEY MOISEEV	{"email": "alekseymoiseev.121965@postgrespro.ru", "phone": "+70529067807"}
0005434229550	D8C609	0648 036357	ILYA ALEKSEEV	{"email": "ilyaalekseev-031985@postgrespro.ru", "phone": "+70207909864"}
0005434229551	8DE91B	9202 909091	TATYANA KOMAROVA	{"email": "komarova_tatyana111974@postgrespro.ru", "phone": "+70515113469"}
0005434229552	33A4BD	5886 250897	ANDREY SCHERBAKOV	{"phone": "+70892579851"}
0005434229553	65DCC6	1808 578728	POLINA STEPANOVA	{"phone": "+70061575235"}
0005434229554	5E32A7	1863 306795	ALEKSEY ANDREEV	{"phone": "+70652831551"}
0005434229555	5E32A7	6638 522494	ELENA EGOROVA	{"phone": "+70316118616"}
0005434229556	A9F83B	4609 078977	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr.02081966@postgrespro.ru", "phone": "+70330432363"}
0005434229557	ED2ECB	1017 000554	VASILIY MAKAROV	{"email": "makarov-vasiliy.13021959@postgrespro.ru", "phone": "+70939210606"}
0005434229558	1F53D1	3095 634866	ANASTASIYA ZHURAVLEVA	{"email": "a_zhuravleva1973@postgrespro.ru", "phone": "+70418644235"}
0005434229559	67F92A	2661 753015	NIKOLAY ABRAMOV	{"phone": "+70917435663"}
0005434229560	67F92A	2324 053367	NADEZHDA FOMINA	{"email": "fomina.n-10031979@postgrespro.ru", "phone": "+70684606165"}
0005434229561	F2AFDE	7909 372859	MIKHAIL BELOV	{"phone": "+70372398857"}
0005434229562	D5CE62	3367 581664	VERA PETROVA	{"email": "petrova_v1967@postgrespro.ru", "phone": "+70245789025"}
0005434229563	D5CE62	2792 315479	YULIYA PETROVA	{"email": "petrova.y-081961@postgrespro.ru", "phone": "+70431853600"}
0005434229564	253E1B	2523 397611	SERGEY DENISOV	{"phone": "+70086073454"}
0005434229565	D9F6CB	5948 590509	ANDREY SCHERBAKOV	{"phone": "+70395163058"}
0005434229566	D9F6CB	2805 902544	NATALYA FOMINA	{"phone": "+70333501161"}
0005434229567	A34DEC	7929 509919	MAKSIM FOMIN	{"phone": "+70254302791"}
0005434229568	7F9613	1689 732010	ALINA STEPANOVA	{"phone": "+70700459658"}
0005434229569	7F9613	0819 223414	YULIYA ALEKSANDROVA	{"email": "aleksandrova-y15101974@postgrespro.ru", "phone": "+70877583084"}
0005434229570	91D72A	6430 229732	ANNA TARASOVA	{"phone": "+70566365173"}
0005434229571	91D72A	6479 500364	OLGA SAVELEVA	{"phone": "+70143111637"}
0005434229572	F60E2B	2540 132973	TATYANA SOKOLOVA	{"email": "sokolova.tatyana-1966@postgrespro.ru", "phone": "+70393319739"}
0005434229573	F60E2B	0525 411690	EKATERINA MOROZOVA	{"phone": "+70766560228"}
0005434229574	B4339A	6466 387700	ILYA KULIKOV	{"phone": "+70135944195"}
0005434229575	B4339A	1352 197778	ALEKSANDR TIKHONOV	{"email": "a.tikhonov-111974@postgrespro.ru", "phone": "+70114765731"}
0005434229576	9C9215	0651 483286	ANATOLIY NIKOLAEV	{"email": "nikolaev.anatoliy_08081961@postgrespro.ru", "phone": "+70941483105"}
0005434229577	F78B75	2294 611540	MARINA SMIRNOVA	{"email": "smirnova-m-1973@postgrespro.ru", "phone": "+70474378184"}
0005434229578	F78B75	4351 470476	ILYA GORBUNOV	{"email": "igorbunov-1975@postgrespro.ru", "phone": "+70401462688"}
0005434229579	8879DF	1569 713562	VALERIY VOLKOV	{"email": "valeriy.volkov_1970@postgrespro.ru", "phone": "+70488553702"}
0005434229580	8879DF	8029 783004	ANTONINA SERGEEVA	{"email": "sergeeva-a12101965@postgrespro.ru", "phone": "+70346293463"}
0005434229581	8879DF	1646 555290	ANDREY KRASNOV	{"phone": "+70390421839"}
0005434229582	BB4798	8658 633812	OLGA TIKHONOVA	{"email": "tikhonovaolga-1986@postgrespro.ru", "phone": "+70574237417"}
0005434229583	BB4798	3672 296604	MARINA MAKSIMOVA	{"email": "m-maksimova_05091979@postgrespro.ru", "phone": "+70611538891"}
0005434229584	B3EEAC	7586 869427	ALEKSANDR FILIPPOV	{"phone": "+70004792598"}
0005434229585	F2D4D4	4755 188953	SVETLANA KUZMINA	{"email": "kuzmina.svetlana-051970@postgrespro.ru", "phone": "+70850604758"}
0005434229586	F2D4D4	2705 646206	ALIK EGOROV	{"email": "egorov_alik.26091962@postgrespro.ru", "phone": "+70045174144"}
0005434229587	502A8C	5146 104291	VALENTIN BELOV	{"phone": "+70629703989"}
0005434229588	29E082	9145 221845	DENIS MAKAROV	{"email": "makarov_denis-28041959@postgrespro.ru", "phone": "+70700510507"}
0005434229589	29E082	2695 646483	MATVEY STEPANOV	{"email": "stepanovmatvey-14081969@postgrespro.ru", "phone": "+70675159676"}
0005434229590	29E082	9920 620905	EDUARD KUZNECOV	{"phone": "+70707775962"}
0005434229591	073AF0	5937 762657	RAISA BELOVA	{"phone": "+70127591795"}
0005434229592	1C8214	7968 659052	KRISTINA TIKHONOVA	{"phone": "+70880730603"}
0005434229593	70D94A	8263 299517	IVAN GERASIMOV	{"email": "i.gerasimov-111969@postgrespro.ru", "phone": "+70304176270"}
0005434229594	DCE5C5	3025 420944	LIDIYA KAZAKOVA	{"email": "kazakova-lidiya-1971@postgrespro.ru", "phone": "+70347228661"}
0005434229595	DCE5C5	5003 937029	SERGEY SOKOLOV	{"phone": "+70995788134"}
0005434229596	BDA302	3069 360115	NADEZHDA IVANOVA	{"phone": "+70157068998"}
0005434229597	BC121C	4466 391943	ALEKSANDRA IVANOVA	{"phone": "+70992706425"}
0005434229598	BEDDAE	0141 677721	DMITRIY ALEKSANDROV	{"phone": "+70121054838"}
0005434229599	BEDDAE	0924 953216	KIRILL DAVYDOV	{"phone": "+70241588705"}
0005434229600	109B42	6351 817893	IRINA SIDOROVA	{"phone": "+70692674340"}
0005434229601	109B42	1132 942349	VALENTINA KARPOVA	{"phone": "+70808028490"}
0005434229602	109B42	1783 485806	LIDIYA EFREMOVA	{"phone": "+70383938357"}
0005434229603	45292A	9651 141736	VLADIMIR MOROZOV	{"email": "morozov_v01071963@postgrespro.ru", "phone": "+70504546283"}
0005434229604	45292A	5676 772445	MARGARITA DMITRIEVA	{"phone": "+70504679739"}
0005434229605	0DD177	6765 597195	VALENTINA MIKHAYLOVA	{"phone": "+70643733677"}
0005434229606	1BC2FE	0365 632286	OLEG GAVRILOV	{"email": "o_gavrilov-08071958@postgrespro.ru", "phone": "+70866774729"}
0005434229607	00A8C8	3340 159185	TATYANA NESTEROVA	{"email": "t.nesterova_021979@postgrespro.ru", "phone": "+70985268983"}
0005434229608	7EC787	8779 437220	VALENTINA RODIONOVA	{"phone": "+70047908741"}
0005434229609	7EC787	6932 842498	OKSANA MOROZOVA	{"phone": "+70664506750"}
0005434229610	63AD1E	8034 808499	VIKTOR MEDVEDEV	{"phone": "+70401526285"}
0005434229611	A9A128	6747 220175	LYUDMILA SOLOVEVA	{"email": "lyudmila_soloveva.30011971@postgrespro.ru", "phone": "+70864477569"}
0005434229612	A8C4A8	9449 210805	MARINA POLYAKOVA	{"phone": "+70892794624"}
0005434229613	CB8590	3652 575382	YULIYA NAUMOVA	{"email": "yuliyanaumova_071974@postgrespro.ru", "phone": "+70620520105"}
0005434229614	A45C94	5238 556145	EVGENIYA MARTYNOVA	{"email": "martynova_evgeniya_071968@postgrespro.ru", "phone": "+70442763737"}
0005434229615	A45C94	7766 152596	NATALYA BARANOVA	{"phone": "+70071734126"}
0005434229616	704E68	3269 096788	TATYANA AFANASEVA	{"email": "afanaseva.tatyana.01051985@postgrespro.ru", "phone": "+70964847081"}
0005434229617	704E68	8279 253548	VIKTOR GAVRILOV	{"email": "viktor-gavrilov-111968@postgrespro.ru", "phone": "+70231661148"}
0005434229618	BA0511	2295 492468	NATALYA KUDRYASHOVA	{"email": "n_kudryashova_25041976@postgrespro.ru", "phone": "+70811336694"}
0005434229619	CF3846	9439 210678	NATALYA ROMANOVA	{"phone": "+70236018870"}
0005434229620	B186C4	6866 125443	VALENTINA NAZAROVA	{"email": "v-nazarova_09101967@postgrespro.ru", "phone": "+70792263401"}
0005434229621	B186C4	7531 401323	ALINA YAKOVLEVA	{"email": "alina.yakovleva_10071958@postgrespro.ru", "phone": "+70798215222"}
0005434229622	4A0F97	7647 017427	LYUBOV ABRAMOVA	{"phone": "+70203996391"}
0005434229623	014242	3418 844249	LEONID ALEKSEEV	{"email": "l_alekseev_1966@postgrespro.ru", "phone": "+70026072324"}
0005434229624	4B3FF5	8968 459447	EKATERINA TARASOVA	{"email": "tarasova_e09101967@postgrespro.ru", "phone": "+70420222385"}
0005434229625	F416DA	3337 081058	ELENA FROLOVA	{"email": "frolova_elena121978@postgrespro.ru", "phone": "+70739023590"}
0005434229626	F416DA	1779 249882	IVAN KOROLEV	{"phone": "+70358419809"}
0005434229627	F416DA	1053 840959	IGOR MELNIKOV	{"email": "melnikov_igor1968@postgrespro.ru", "phone": "+70643114695"}
0005434229628	B655A0	5428 929982	RAISA VASILEVA	{"phone": "+70081955641"}
0005434229629	B655A0	0100 721937	ELENA BELOVA	{"email": "elena_belova-13101982@postgrespro.ru", "phone": "+70754274259"}
0005434229630	B74393	5789 863070	ELENA VOROBEVA	{"email": "vorobeva-e021974@postgrespro.ru", "phone": "+70320191362"}
0005434230021	9885F5	7964 102992	VIKTOR DAVYDOV	{"phone": "+70144404673"}
0005434229631	B74393	8392 702731	GALINA SCHERBAKOVA	{"email": "gscherbakova-1972@postgrespro.ru", "phone": "+70496788270"}
0005434229632	EEEFA7	4638 840545	SERGEY NIKITIN	{"phone": "+70894284973"}
0005434229633	EEEFA7	6126 809392	NINA ZAKHAROVA	{"email": "zakharovan-1961@postgrespro.ru", "phone": "+70673292239"}
0005434229634	0457AD	1517 681992	MIKHAIL KRASNOV	{"phone": "+70083084646"}
0005434229635	25E42B	6348 950646	RAISA BOGDANOVA	{"email": "raisa_bogdanova.041972@postgrespro.ru", "phone": "+70114739784"}
0005434229636	25E42B	2100 229279	YANA VOLKOVA	{"phone": "+70928998368"}
0005434229637	25E42B	1633 980132	ALEKSEY IVANOV	{"email": "ivanov_a-21101977@postgrespro.ru", "phone": "+70807588205"}
0005434229638	25E42B	2981 114356	NATALYA KONDRATEVA	{"email": "kondrateva_n_27071965@postgrespro.ru", "phone": "+70029528520"}
0005434229639	28FAE2	4135 999973	TAMARA VOLKOVA	{"email": "tamaravolkova.1978@postgrespro.ru", "phone": "+70381496404"}
0005434229640	C552B3	1306 632761	VIKTORIYA NESTEROVA	{"phone": "+70352470236"}
0005434229641	C552B3	2299 558689	IRINA KUZNECOVA	{"email": "kuznecova.irina.101965@postgrespro.ru", "phone": "+70780643484"}
0005434229642	C552B3	0108 394286	ALLA MAKAROVA	{"email": "alla-makarova.121968@postgrespro.ru", "phone": "+70111875131"}
0005434229643	FA0029	1078 993283	IGOR SOLOVEV	{"email": "igor_solovev081984@postgrespro.ru", "phone": "+70761098400"}
0005434229644	FA0029	3186 329251	TATYANA KOVALEVA	{"email": "kovalevatatyana_1969@postgrespro.ru", "phone": "+70310681188"}
0005434229645	FA0029	9469 374905	ANASTASIYA ZAKHAROVA	{"email": "anastasiyazakharova-091964@postgrespro.ru", "phone": "+70261595248"}
0005434229646	889932	0942 423302	ALEKSEY FEDOTOV	{"phone": "+70100033063"}
0005434229647	BC5145	9965 914573	VLADIMIR SOKOLOV	{"phone": "+70693492436"}
0005434229648	578ADD	4886 583519	VLADIMIR NOVIKOV	{"email": "novikov_vladimir23041984@postgrespro.ru", "phone": "+70053960045"}
0005434229649	706349	0635 706315	SERGEY KUZNECOV	{"phone": "+70854029584"}
0005434229650	65CD34	4935 166747	EVGENIY KULIKOV	{"phone": "+70263806665"}
0005434229651	65CD34	3665 160883	NIKITA IVANOV	{"email": "ivanov_n051974@postgrespro.ru", "phone": "+70649352788"}
0005434229652	BBEC3A	9613 953449	ZOYA KAZAKOVA	{"email": "z-kazakova-1977@postgrespro.ru", "phone": "+70646198430"}
0005434229653	1E5ECC	2052 368152	DIANA ZHUKOVA	{"phone": "+70007229802"}
0005434229654	1E5ECC	4661 318466	ZOYA KOROLEVA	{"email": "koroleva.zoya.031971@postgrespro.ru", "phone": "+70903488128"}
0005434229655	28499A	9252 092757	EVGENIYA POPOVA	{"email": "popova_e051978@postgrespro.ru", "phone": "+70364556528"}
0005434229656	E112DC	7960 987366	OLEG CHERNOV	{"email": "oleg.chernov.24081979@postgrespro.ru", "phone": "+70998081501"}
0005434229657	E112DC	3520 605592	YURIY SCHERBAKOV	{"phone": "+70621253088"}
0005434229658	7ACF27	7944 808292	MIKHAIL EGOROV	{"email": "m_egorov_13071976@postgrespro.ru", "phone": "+70009365001"}
0005434229659	970760	3779 144392	MARINA RODIONOVA	{"email": "rodionova-m_26101980@postgrespro.ru", "phone": "+70603382734"}
0005434229660	0D60F8	0692 119929	VASILIY VLASOV	{"email": "vlasov.vasiliy_071973@postgrespro.ru", "phone": "+70322649711"}
0005434229661	CE2E8E	5341 587310	ELENA GUSEVA	{"email": "e.guseva.021979@postgrespro.ru", "phone": "+70782719731"}
0005434229662	9A120B	6599 725092	VERA DENISOVA	{"phone": "+70653729901"}
0005434229663	E693ED	6221 348438	VLADISLAV VASILEV	{"email": "vladislav.vasilev_19031974@postgrespro.ru", "phone": "+70908258774"}
0005434229664	B5B510	3963 045119	VALENTINA MOROZOVA	{"email": "morozova-v1961@postgrespro.ru", "phone": "+70672944434"}
0005434229665	B5B510	2301 642800	DARYA SOLOVEVA	{"phone": "+70093888374"}
0005434229666	B5B510	1685 085037	SVETLANA ANTONOVA	{"phone": "+70794471379"}
0005434229667	480079	2479 050115	MIKHAIL NOVIKOV	{"phone": "+70584389283"}
0005434229668	5AC71C	8747 100107	IOSIF GRIGOREV	{"phone": "+70992346900"}
0005434229669	47944E	5946 958363	ANASTASIYA NAUMOVA	{"phone": "+70781977256"}
0005434229670	A5F25E	0446 125611	ANASTASIYA SOKOLOVA	{"email": "sokolovaa-1968@postgrespro.ru", "phone": "+70879905081"}
0005434229671	0203F4	5290 589669	TAMARA FADEEVA	{"phone": "+70296532955"}
0005434229672	E9E382	5098 863099	ALEKSANDRA FOMINA	{"phone": "+70547094944"}
0005434229673	936CD8	5443 654637	KONSTANTIN NOVIKOV	{"email": "k.novikov_1983@postgrespro.ru", "phone": "+70753195660"}
0005434229674	9C92EE	0892 388988	ALEKSEY PAVLOV	{"email": "a.pavlov.061972@postgrespro.ru", "phone": "+70059813825"}
0005434229675	F529CA	4781 270395	TATYANA GRISHINA	{"email": "grishina-tatyana-1968@postgrespro.ru", "phone": "+70727508164"}
0005434229676	F529CA	5822 459625	ALEKSANDR NIKITIN	{"phone": "+70379961269"}
0005434229677	1F7629	1845 473293	EKATERINA BOGDANOVA	{"phone": "+70296161086"}
0005434229678	6FE419	2684 956104	OLGA DMITRIEVA	{"phone": "+70760265741"}
0005434229679	B2E56B	1704 302114	LARISA NESTEROVA	{"phone": "+70716022253"}
0005434229680	776FB5	5126 674624	OLGA PETROVA	{"phone": "+70491379886"}
0005434229681	776FB5	8655 548868	YURIY VASILEV	{"phone": "+70282457921"}
0005434229682	D29EA1	0624 775904	LARISA FILIPPOVA	{"phone": "+70609458773"}
0005434229683	F7774E	3089 063920	MIKHAIL ISAEV	{"phone": "+70559345430"}
0005434229684	B4CD84	9119 331502	ALEKSEY BORISOV	{"phone": "+70460112835"}
0005434229685	CA902D	6103 311052	EVGENIY BORISOV	{"email": "borisov.evgeniy03121968@postgrespro.ru", "phone": "+70241505493"}
0005434229686	935AEE	3887 979561	NADEZHDA SERGEEVA	{"email": "sergeeva.n-01071974@postgrespro.ru", "phone": "+70310504043"}
0005434229687	838822	3083 627367	ALEKSANDR IVANOV	{"email": "a-ivanov15051968@postgrespro.ru", "phone": "+70705611470"}
0005434229688	F0602D	9116 098477	LILIYA PAVLOVA	{"phone": "+70704382750"}
0005434229689	F0602D	2074 865007	TAMARA FILIPPOVA	{"email": "t.filippova-1972@postgrespro.ru", "phone": "+70315621544"}
0005434229690	4AE3B2	3181 444364	NADEZHDA MAKAROVA	{"phone": "+70394227857"}
0005434229691	9682F2	7510 713074	LEONID GAVRILOV	{"phone": "+70405191402"}
0005434229692	9682F2	4586 944174	ANASTASIYA MAKAROVA	{"phone": "+70876220651"}
0005434229693	9682F2	2866 590622	VALENTINA VASILEVA	{"email": "vvasileva31051973@postgrespro.ru", "phone": "+70271230585"}
0005434229694	DDC3A4	9647 532446	VALENTINA KUZNECOVA	{"phone": "+70179349414"}
0005434229695	090555	7844 501651	IGOR TIKHONOV	{"email": "tikhonov-i-22091980@postgrespro.ru", "phone": "+70109680171"}
0005434229696	3D2DA6	8132 376306	OLESYA SOROKINA	{"email": "sorokina.o.23091976@postgrespro.ru", "phone": "+70990844810"}
0005434229697	5B14EF	8565 617761	ALBINA MAKAROVA	{"phone": "+70831805662"}
0005434229698	3D282B	9701 955895	YULIYA BARANOVA	{"email": "yuliya-baranova27081978@postgrespro.ru", "phone": "+70827655199"}
0005434229699	1013AA	4105 450450	VIKTOR VASILEV	{"phone": "+70966113226"}
0005434229700	1013AA	1675 001485	PETR POPOV	{"email": "popovpetr_24121966@postgrespro.ru", "phone": "+70547105321"}
0005434229701	B85787	3942 938343	ALEKSEY ABRAMOV	{"email": "alekseyabramov_071977@postgrespro.ru", "phone": "+70054590767"}
0005434229702	B85787	6768 895019	ANNA NIKITINA	{"email": "anna-nikitina-061966@postgrespro.ru", "phone": "+70807054807"}
0005434229703	0C212E	0051 597960	MARIYA MALYSHEVA	{"phone": "+70629765712"}
0005434229704	0C212E	4343 255915	NATALYA PETROVA	{"email": "petrova-natalya-081974@postgrespro.ru", "phone": "+70588910777"}
0005434229705	01F8E4	5201 785306	SERGEY KUZNECOV	{"email": "kuznecov_s-1988@postgrespro.ru", "phone": "+70719830918"}
0005434229706	A8F8C5	2421 288646	SERGEY KAZAKOV	{"phone": "+70854190750"}
0005434229707	9F93C3	2690 750239	EVGENIY STEPANOV	{"email": "e-stepanov-25021976@postgrespro.ru", "phone": "+70048769000"}
0005434229708	D8D9E0	4868 700236	EKATERINA POPOVA	{"email": "ekaterinapopova1975@postgrespro.ru", "phone": "+70748789099"}
0005434229709	D8D9E0	4334 183019	ANASTASIYA SIDOROVA	{"phone": "+70914593693"}
0005434229710	8A5115	3406 976849	SERGEY BONDARENKO	{"email": "bondarenko-s.071975@postgrespro.ru", "phone": "+70930913474"}
0005434229711	9C8329	6962 088839	IGOR SMIRNOV	{"phone": "+70811264149"}
0005434229712	91847D	5757 893039	SVETLANA NESTEROVA	{"email": "svetlananesterova-23011978@postgrespro.ru", "phone": "+70218145934"}
0005434229713	91847D	6549 914868	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov121963@postgrespro.ru", "phone": "+70949332110"}
0005434229714	3FA3F4	7799 585310	ALEKSANDR IVANOV	{"phone": "+70001400650"}
0005434229715	AA68BD	6145 182172	RUSLAN KRASNOV	{"phone": "+70664066831"}
0005434229716	1F6D28	7699 717367	MARINA NIKIFOROVA	{"email": "marina_nikiforova11011983@postgrespro.ru", "phone": "+70346595706"}
0005434229717	9093EA	2874 594625	ALEKSEY NAUMOV	{"phone": "+70731107212"}
0005434229718	9093EA	5605 886408	GENNADIY DENISOV	{"phone": "+70798879615"}
0005434229719	414C40	5842 527693	VALERIY KUZNECOV	{"phone": "+70569593411"}
0005434229720	414C40	2786 094967	SERGEY ISAEV	{"email": "isaevsergey111962@postgrespro.ru", "phone": "+70805863688"}
0005434229721	552701	0394 889697	MIKHAIL PAVLOV	{"phone": "+70010329689"}
0005434229722	9E578B	4381 532793	LYUDMILA IVANOVA	{"phone": "+70737175029"}
0005434229723	43AEF8	1289 771454	ELENA KRASNOVA	{"email": "krasnova.e-121971@postgrespro.ru", "phone": "+70333866284"}
0005434229724	43AEF8	1854 875003	VERA FROLOVA	{"email": "v.frolova.081973@postgrespro.ru", "phone": "+70512780697"}
0005434229725	2AE041	4812 047098	TAMARA AKIMOVA	{"phone": "+70916228170"}
0005434229726	0F59A6	7463 265105	VLADIMIR GRIGOREV	{"phone": "+70984895164"}
0005434229727	A0EE2C	8129 654711	VITALIY SMIRNOV	{"email": "smirnov.v.1976@postgrespro.ru", "phone": "+70443736223"}
0005434229728	AB416B	5748 508937	IRINA NIKOLAEVA	{"phone": "+70273678935"}
0005434229729	C90771	1078 412842	VLADIMIR PETROV	{"phone": "+70735801863"}
0005434229730	A5EFE0	0499 659470	OLEG ILIN	{"email": "o.ilin.041959@postgrespro.ru", "phone": "+70421125572"}
0005434229731	4D257F	6391 616004	LYUBOV PETROVA	{"email": "petrova-lyubov.10101970@postgrespro.ru", "phone": "+70032427720"}
0005434229732	EF8747	8218 298928	PAVEL BORISOV	{"email": "pborisov.02081976@postgrespro.ru", "phone": "+70402168416"}
0005434229733	AA42B0	8931 818777	TATYANA ISAEVA	{"email": "isaevat_23011985@postgrespro.ru", "phone": "+70466229799"}
0005434229734	A51F0D	3120 376015	VIKTORIYA KOMAROVA	{"phone": "+70320330962"}
0005434229735	6B4F37	2751 013329	ALEKSANDR TIMOFEEV	{"phone": "+70780444011"}
0005434229736	6364CB	9511 279007	MIKHAIL MAKSIMOV	{"email": "m.maksimov-101975@postgrespro.ru", "phone": "+70329794799"}
0005434229737	8E40C9	6605 188981	VALENTINA CHERNOVA	{"email": "chernovav06101975@postgrespro.ru", "phone": "+70269373259"}
0005434229738	2978DD	9466 723136	GALINA IVANOVA	{"phone": "+70779535680"}
0005434229739	7B18CF	5661 196458	ANTONINA KISELEVA	{"phone": "+70116704565"}
0005434229740	6FF772	6227 222917	NATALYA MIKHAYLOVA	{"phone": "+70274926879"}
0005434229741	0F882B	7800 897644	DANILA ZAKHAROV	{"email": "danilazakharov-1972@postgrespro.ru", "phone": "+70958567498"}
0005434229742	0F882B	8506 373113	ILGIZ DMITRIEV	{"email": "dmitrievilgiz031976@postgrespro.ru", "phone": "+70001494092"}
0005434229743	ACFECC	6737 676651	ELENA NIKOLAEVA	{"email": "nikolaevaelena-061977@postgrespro.ru", "phone": "+70898375125"}
0005434229744	A37220	9351 212412	SERGEY KOZLOV	{"email": "sergeykozlov29071969@postgrespro.ru", "phone": "+70368806544"}
0005434229745	ACEC1B	9498 051048	SERGEY ZHUKOV	{"phone": "+70377393447"}
0005434229746	CD39AC	4073 843903	YANA FEDOROVA	{"phone": "+70874095527"}
0005434229747	CD39AC	1269 324583	KLAVDIYA KAZAKOVA	{"phone": "+70420110548"}
0005434229748	B3AACE	6794 622542	VIKTOR KUZNECOV	{"phone": "+70678928090"}
0005434229749	4AE7CD	9205 104123	ELENA OVCHINNIKOVA	{"phone": "+70812891030"}
0005434229750	4AE7CD	0205 955760	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy.1973@postgrespro.ru", "phone": "+70626712791"}
0005434229751	23FED5	0334 524996	ALEKSANDR ZAKHAROV	{"phone": "+70112270433"}
0005434229752	B0D050	7011 413980	ELENA GRISHINA	{"phone": "+70714904132"}
0005434229753	2C5839	6102 772260	TATYANA SIDOROVA	{"email": "tatyana_sidorova-1964@postgrespro.ru", "phone": "+70581407285"}
0005434229754	2C5839	3545 012878	EKATERINA AFANASEVA	{"email": "afanaseva.ekaterina-1982@postgrespro.ru", "phone": "+70568876933"}
0005434229755	4BC11E	7247 742034	MIKHAIL ROMANOV	{"phone": "+70130211567"}
0005434229756	4BC11E	4837 306430	ROZA ZHUKOVA	{"phone": "+70074350334"}
0005434229757	3D8998	8863 763102	ANDREY SMIRNOV	{"phone": "+70618384499"}
0005434229758	3D8998	2163 460574	STEPAN MELNIKOV	{"email": "smelnikov.04011979@postgrespro.ru", "phone": "+70667801248"}
0005434229759	53880B	0295 984814	ALLA VASILEVA	{"email": "vasileva.alla.21121970@postgrespro.ru", "phone": "+70099066526"}
0005434229760	D9FF6A	1450 311061	ANATOLIY KRASNOV	{"email": "anatoliy_krasnov.121970@postgrespro.ru", "phone": "+70577051462"}
0005434229761	048AE9	9700 293477	OKSANA KISELEVA	{"email": "oksana.kiseleva_041974@postgrespro.ru", "phone": "+70969407926"}
0005434229762	779794	3320 306634	DMITRIY FROLOV	{"phone": "+70161810744"}
0005434229763	A8D855	0351 028209	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr011961@postgrespro.ru", "phone": "+70541618471"}
0005434229764	A8D855	9808 978270	NINA SMIRNOVA	{"phone": "+70121696515"}
0005434229765	A8D855	8147 419677	ALEKSANDR NAZAROV	{"email": "nazarova.10041976@postgrespro.ru", "phone": "+70445529161"}
0005434229766	D42909	9853 398101	ANATOLIY GUSEV	{"email": "a_gusev_08091977@postgrespro.ru", "phone": "+70282787610"}
0005434229767	D42909	8197 901787	DMITRIY ABRAMOV	{"phone": "+70080864415"}
0005434229768	0663AF	7773 458990	TATYANA VASILEVA	{"email": "vasileva.tatyana-30061971@postgrespro.ru", "phone": "+70460630320"}
0005434229769	0663AF	8245 801424	ANATOLIY SOKOLOV	{"email": "asokolov-23061973@postgrespro.ru", "phone": "+70160852198"}
0005434229770	84770D	2955 809450	NATALYA ZHURAVLEVA	{"email": "nzhuravleva_121976@postgrespro.ru", "phone": "+70032576516"}
0005434229771	84770D	4935 003968	DENIS OSIPOV	{"phone": "+70174161317"}
0005434229774	2D965D	8330 964592	LYUBOV KAZAKOVA	{"phone": "+70475264042"}
0005434229775	EA0CAC	5578 875638	PETR KISELEV	{"phone": "+70630527047"}
0005434229776	60A765	6620 855431	TAISIYA FILATOVA	{"email": "tfilatova-13021978@postgrespro.ru", "phone": "+70091977417"}
0005434229777	60A765	3981 549814	KSENIYA LEBEDEVA	{"phone": "+70922268071"}
0005434229778	60A765	4092 741275	ZINAIDA MASLOVA	{"email": "maslova_zinaida1976@postgrespro.ru", "phone": "+70548614927"}
0005434229779	5BE1DF	9427 472437	OLGA ROMANOVA	{"phone": "+70071810014"}
0005434229780	5D6929	1281 403435	ANDREY KUZNECOV	{"email": "andrey-kuznecov.021968@postgrespro.ru", "phone": "+70961661666"}
0005434229781	5D6929	2211 868849	NADEZHDA LOGINOVA	{"phone": "+70925054113"}
0005434229782	254E40	7494 449037	ZINAIDA ZAYCEVA	{"email": "zinaida.zayceva.031972@postgrespro.ru", "phone": "+70321298091"}
0005434229783	71D62F	9162 913315	SVETLANA KUZMINA	{"email": "kuzmina_svetlana27121970@postgrespro.ru", "phone": "+70679109511"}
0005434229784	7F5EC7	0480 068132	ILYA POPOV	{"phone": "+70315163259"}
0005434229785	2F19F7	8531 186001	MATVEY YAKOVLEV	{"email": "matveyyakovlev.25091976@postgrespro.ru", "phone": "+70822333503"}
0005434229786	2F19F7	3731 061417	ILNUR FEDOROV	{"phone": "+70328415672"}
0005434229787	BA5857	9834 029814	ANNA POPOVA	{"email": "apopova.26021964@postgrespro.ru", "phone": "+70591186249"}
0005434229788	D1DA91	3635 782584	KSENIYA IVANOVA	{"phone": "+70720248976"}
0005434229789	D1DA91	2104 252568	ALEKSANDR NIKITIN	{"phone": "+70139151656"}
0005434229790	487D79	3331 246286	LILIYA ABRAMOVA	{"phone": "+70265732472"}
0005434229791	487D79	6172 233649	VIKTOR MIKHAYLOV	{"email": "mikhaylovv_061969@postgrespro.ru", "phone": "+70872266353"}
0005434229792	22E773	0731 929994	ELENA NIKOLAEVA	{"email": "e-nikolaeva.031975@postgrespro.ru", "phone": "+70352155934"}
0005434229793	AEFF97	6172 308690	YULIYA KUZNECOVA	{"phone": "+70424004687"}
0005434229794	AEFF97	6864 581719	MARINA IVANOVA	{"email": "ivanovam_1977@postgrespro.ru", "phone": "+70340209190"}
0005434229795	00BBCD	9402 807909	MARINA NOVIKOVA	{"phone": "+70624903507"}
0005434229796	00BBCD	7471 718060	SERGEY OSIPOV	{"phone": "+70722094261"}
0005434229797	C6CEB6	4746 946293	IRINA PETROVA	{"phone": "+70077881873"}
0005434229798	B515DB	6806 152466	ALEKSANDR MAKAROV	{"phone": "+70279254044"}
0005434229799	B515DB	8918 056005	SVETLANA BOGDANOVA	{"phone": "+70494535755"}
0005434229800	AA716B	2194 134959	ILYA GUSEV	{"email": "ilya.gusev1968@postgrespro.ru", "phone": "+70686740225"}
0005434229801	2D8BC1	3785 062280	VALENTINA POPOVA	{"email": "popova_valentina-1982@postgrespro.ru", "phone": "+70770532198"}
0005434229802	2D8BC1	6140 304710	IGOR KUZNECOV	{"email": "kuznecov.i.1965@postgrespro.ru", "phone": "+70080070387"}
0005434229803	2D8BC1	4360 455203	MARIYA VOROBEVA	{"phone": "+70073559736"}
0005434229804	F0567E	1925 407556	IVAN NAZAROV	{"email": "nazarov.ivan_101970@postgrespro.ru", "phone": "+70598437794"}
0005434229805	C362A3	5595 526811	SERGEY GERASIMOV	{"email": "gerasimov.s061971@postgrespro.ru", "phone": "+70099124605"}
0005434229806	E7ED32	4525 323524	EMIL IVANOV	{"email": "ivanov.e-1974@postgrespro.ru", "phone": "+70141522842"}
0005434229807	478F38	2636 404480	DANILA KAZAKOV	{"email": "kazakov-danila_041981@postgrespro.ru", "phone": "+70841769611"}
0005434229808	388A92	0057 303681	EVGENIY VASILEV	{"phone": "+70856787768"}
0005434229809	A35D73	6685 243463	IRINA ZAYCEVA	{"email": "zayceva.i061970@postgrespro.ru", "phone": "+70893071651"}
0005434229810	A35D73	0661 832259	TAMARA BELOVA	{"email": "t-belova09121977@postgrespro.ru", "phone": "+70971691625"}
0005434229811	0488F8	3902 517863	ANNA NAUMOVA	{"phone": "+70361974533"}
0005434229812	E66C41	1597 460326	LYUDMILA NESTEROVA	{"email": "l_nesterova_05071971@postgrespro.ru", "phone": "+70291010048"}
0005434229813	E66C41	4766 245659	ALEKSANDR ZHUKOV	{"phone": "+70040835904"}
0005434229814	03E143	4485 588082	ALEVTINA MAKAROVA	{"email": "makarova_a-16081957@postgrespro.ru", "phone": "+70400821908"}
0005434229815	03E143	3405 661729	EGOR GORBUNOV	{"email": "gorbunove-18111982@postgrespro.ru", "phone": "+70148010034"}
0005434229816	03E143	0736 573513	IRINA IVANOVA	{"phone": "+70120736723"}
0005434229817	03E143	4686 719191	TAMARA ZAKHAROVA	{"email": "zakharova_tamara-031977@postgrespro.ru", "phone": "+70145949153"}
0005434229818	BEAA0F	3995 433098	ARINA OSIPOVA	{"email": "osipova.arina1968@postgrespro.ru", "phone": "+70183690917"}
0005434229819	B3A046	7870 563118	KSENIYA MARTYNOVA	{"phone": "+70093299949"}
0005434229820	B5EB60	9667 667516	RAMIS ANTONOV	{"email": "r-antonov_31081958@postgrespro.ru", "phone": "+70432679983"}
0005434229821	B5EB60	6103 233845	SERGEY MOROZOV	{"phone": "+70976268750"}
0005434229822	58E6CA	2115 097497	MARIYA MAKAROVA	{"email": "m.makarova_041966@postgrespro.ru", "phone": "+70180904487"}
0005434229823	58E6CA	1174 192767	NADEZHDA MAKAROVA	{"phone": "+70341733096"}
0005434229824	58E6CA	8187 625480	NINA KARPOVA	{"phone": "+70736009868"}
0005434229825	3F2E75	6717 531729	SOFIYA ALEKSEEVA	{"phone": "+70101022103"}
0005434229826	3EF1E5	7874 853716	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr-041989@postgrespro.ru", "phone": "+70393455891"}
0005434229827	D13F7D	5127 160431	LIDIYA ILINA	{"email": "ilinal.101979@postgrespro.ru", "phone": "+70547071428"}
0005434229828	EF01E3	9676 227710	NATALYA NOVIKOVA	{"email": "nnovikova_101968@postgrespro.ru", "phone": "+70441732833"}
0005434229829	A8159A	2637 843322	SERGEY NOVIKOV	{"email": "sergey.novikov.061972@postgrespro.ru", "phone": "+70333959229"}
0005434229830	A8159A	4249 351252	VYACHESLAV GAVRILOV	{"email": "gavrilovv_07041975@postgrespro.ru", "phone": "+70387364796"}
0005434229831	2BB625	9052 888603	EKATERINA TARASOVA	{"email": "e-tarasova.1985@postgrespro.ru", "phone": "+70628204623"}
0005434229832	E0CEA0	1203 529621	ALEKSANDR TARASOV	{"email": "atarasov-061973@postgrespro.ru", "phone": "+70103258360"}
0005434229833	D38761	7178 987653	YURIY POPOV	{"email": "popov-y-04121972@postgrespro.ru", "phone": "+70080931850"}
0005434229834	9536B3	9523 891104	KSENIYA NOVIKOVA	{"email": "novikovakseniya_10051979@postgrespro.ru", "phone": "+70772880931"}
0005434229835	E468B9	1618 796321	TAMARA MALYSHEVA	{"phone": "+70073701446"}
0005434229836	5E7FE9	3659 493390	LEONID SMIRNOV	{"email": "smirnov_l.1969@postgrespro.ru", "phone": "+70104205490"}
0005434229837	5E7FE9	5115 443497	ALEKSANDR AFANASEV	{"phone": "+70370854349"}
0005434229838	2BC9C9	1529 259613	KIRILL MOISEEV	{"email": "kmoiseev.1964@postgrespro.ru", "phone": "+70838198675"}
0005434229839	681C26	1011 198556	SVETLANA LAZAREVA	{"email": "svetlana_lazareva1974@postgrespro.ru", "phone": "+70974719900"}
0005434229840	B34CC3	2687 030830	NIKOLAY NAZAROV	{"email": "nazarov_n-101982@postgrespro.ru", "phone": "+70874838111"}
0005434229841	B34CC3	9257 951439	SERGEY BELOV	{"phone": "+70858031139"}
0005434229842	23F1EA	6031 247956	VERA KUZNECOVA	{"email": "v-kuznecova_06121971@postgrespro.ru", "phone": "+70791349182"}
0005434229843	791960	8124 431774	MAKSIM IVANOV	{"email": "m.ivanov_121976@postgrespro.ru", "phone": "+70628141003"}
0005434229844	791960	4373 596536	ANNA MARTYNOVA	{"email": "anna_martynova_101972@postgrespro.ru", "phone": "+70581367173"}
0005434229845	AEE762	3523 443754	DMITRIY KUZNECOV	{"email": "d_kuznecov-1967@postgrespro.ru", "phone": "+70704439844"}
0005434229846	AEE762	5601 425129	SVETLANA KUZNECOVA	{"email": "s.kuznecova-21091971@postgrespro.ru", "phone": "+70201267941"}
0005434229847	BEC4B0	5731 514109	ROMAN ZHURAVLEV	{"email": "roman.zhuravlev_1958@postgrespro.ru", "phone": "+70305356753"}
0005434229848	DFA25D	7515 020820	ANDREY ILIN	{"phone": "+70931560008"}
0005434229849	DFA25D	9879 010524	NIKITA SERGEEV	{"phone": "+70144645209"}
0005434229850	0ABAED	4547 757451	SVETLANA EGOROVA	{"phone": "+70502195832"}
0005434229851	B2152E	1416 483024	YULIYA IVANOVA	{"email": "ivanovayuliya011957@postgrespro.ru", "phone": "+70733316419"}
0005434229852	B2152E	8909 211540	ELENA CHERNOVA	{"email": "chernova-elena.04031978@postgrespro.ru", "phone": "+70020471770"}
0005434229853	711725	4783 990992	NIKOLAY SHEVCHENKO	{"email": "nikolayshevchenko-051973@postgrespro.ru", "phone": "+70843735030"}
0005434230022	612CBF	8246 052034	VIKTOR BONDARENKO	{"phone": "+70358212674"}
0005434229854	688BC9	1292 933094	OLGA EFIMOVA	{"email": "olga.efimova_16021975@postgrespro.ru", "phone": "+70048941724"}
0005434229855	688BC9	0003 933165	ALEKSEY NAUMOV	{"email": "naumovaleksey-1967@postgrespro.ru", "phone": "+70072117503"}
0005434229856	F5ED89	8367 855657	YURIY POPOV	{"email": "popovyuriy-1950@postgrespro.ru", "phone": "+70746162842"}
0005434229857	EF1922	8550 143739	ALBINA MIKHAYLOVA	{"phone": "+70141479077"}
0005434229858	EF1922	0425 791585	LYUDMILA SIDOROVA	{"email": "lyudmila.sidorova_1964@postgrespro.ru", "phone": "+70884300210"}
0005434229859	FD6317	8883 996429	SVETLANA NIKOLAEVA	{"email": "snikolaeva-01061968@postgrespro.ru", "phone": "+70358217551"}
0005434229860	5E74D2	1562 076211	ALEKSEY SOKOLOV	{"phone": "+70448862164"}
0005434229861	5AFFB5	9925 144778	VLADIMIR FROLOV	{"phone": "+70325641781"}
0005434229862	D712A4	9607 308105	OLGA DANILOVA	{"email": "danilova-olga-23031971@postgrespro.ru", "phone": "+70605895493"}
0005434229863	A18C95	1057 734006	MARIYA PETROVA	{"phone": "+70098959555"}
0005434229864	A18C95	3117 148550	VALENTINA BARANOVA	{"email": "valentina.baranova_1988@postgrespro.ru", "phone": "+70657267584"}
0005434229865	59A413	4392 114504	ANDREY NIKITIN	{"phone": "+70930314558"}
0005434229866	0D9279	0041 375499	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov1970@postgrespro.ru", "phone": "+70161998014"}
0005434229867	663238	6240 366178	NURLAN TIMOFEEV	{"email": "timofeev.nurlan06051978@postgrespro.ru", "phone": "+70766483793"}
0005434229868	71A066	3537 746294	SERGEY IVANOV	{"phone": "+70808650704"}
0005434229869	959345	0304 176989	ANDREY STEPANOV	{"email": "andrey_stepanov-1971@postgrespro.ru", "phone": "+70635113446"}
0005434229870	C67CA5	0873 771157	OLGA DANILOVA	{"phone": "+70416808739"}
0005434229871	C67CA5	2444 510396	VLADIMIR ANDREEV	{"email": "andreev-v041974@postgrespro.ru", "phone": "+70473844463"}
0005434229872	2789B5	4741 676121	ALEKSANDR ZHUKOV	{"phone": "+70231741968"}
0005434229873	CD2D39	0248 992156	VLADIMIR MAKAROV	{"email": "makarov_vladimir011977@postgrespro.ru", "phone": "+70159421504"}
0005434229874	62CBFB	0212 929300	NADEZHDA ZAKHAROVA	{"email": "zakharova-n-061970@postgrespro.ru", "phone": "+70456662957"}
0005434229875	016C9C	4134 114798	MARINA KUZNECOVA	{"email": "kuznecovam_28081966@postgrespro.ru", "phone": "+70040833231"}
0005434229876	527325	8701 688338	SERGEY GERASIMOV	{"email": "gerasimov_s-23031967@postgrespro.ru", "phone": "+70663199998"}
0005434229877	D03C0D	3577 854581	GALINA ISAEVA	{"phone": "+70446769997"}
0005434229878	D03C0D	9785 245922	PAVEL GERASIMOV	{"email": "pavel_gerasimov.08061975@postgrespro.ru", "phone": "+70428108426"}
0005434229879	7FB5A9	8628 407827	VALERIYA POPOVA	{"email": "vpopova13101976@postgrespro.ru", "phone": "+70904044015"}
0005434229880	7FB5A9	7228 713536	NATALIYA OSIPOVA	{"email": "osipovanataliya_041962@postgrespro.ru", "phone": "+70031364559"}
0005434229881	ECC28E	9103 518959	LYUDMILA ANTONOVA	{"phone": "+70474133780"}
0005434229882	29C1FB	7967 211399	NINA SMIRNOVA	{"phone": "+70984169740"}
0005434229883	871CD3	6720 401764	ALEKSANDR IVANOV	{"phone": "+70036324348"}
0005434229884	F3583F	0024 877047	SVETLANA SOROKINA	{"email": "sorokina.s_10121983@postgrespro.ru", "phone": "+70961788320"}
0005434229885	1ACEE0	0439 802531	YURIY EGOROV	{"email": "egorov-yuriy-1979@postgrespro.ru", "phone": "+70097501659"}
0005434229886	3EB868	5568 881901	OLGA NIKITINA	{"email": "nikitina-olga_1969@postgrespro.ru", "phone": "+70188645885"}
0005434229887	3EB868	7024 469257	ANATOLIY POPOV	{"email": "a.popov-1955@postgrespro.ru", "phone": "+70724386766"}
0005434229888	CDED5B	7695 046870	MIKHAIL POPOV	{"phone": "+70496186321"}
0005434229889	E3283D	3413 784888	VIKTORIYA BELOVA	{"email": "vbelova.121966@postgrespro.ru", "phone": "+70818039714"}
0005434229890	FD109C	2916 732598	NIKITA GAVRILOV	{"email": "gavrilov.nikita_1964@postgrespro.ru", "phone": "+70926363245"}
0005434229891	24FCD4	1040 360155	VENERA GAVRILOVA	{"email": "v.gavrilova.031982@postgrespro.ru", "phone": "+70163834795"}
0005434229892	24FCD4	0681 994559	VERA ABRAMOVA	{"email": "vabramova11021978@postgrespro.ru", "phone": "+70925878311"}
0005434229893	24FCD4	4955 803830	ALEKSANDRA POTAPOVA	{"phone": "+70694232071"}
0005434229894	7CA01C	4167 148555	ALEKSEY KUDRYASHOV	{"email": "aleksey.kudryashov1967@postgrespro.ru", "phone": "+70867362328"}
0005434229895	7CA01C	3213 853673	DMITRIY SCHERBAKOV	{"phone": "+70740055977"}
0005434229896	06F237	1583 927990	EVGENIY MELNIKOV	{"email": "evgeniy_melnikov1964@postgrespro.ru", "phone": "+70923087386"}
0005434229897	06F237	8333 166996	ZAKHAR KISELEV	{"email": "z.kiselev_1970@postgrespro.ru", "phone": "+70107004384"}
0005434229898	06F237	9061 239343	RUSLAN IVANOV	{"email": "ruslanivanov_1967@postgrespro.ru", "phone": "+70062728186"}
0005434229899	3E72B5	9945 447851	MARIYA ORLOVA	{"phone": "+70617010921"}
0005434229900	2C7F6B	8847 349912	VALENTINA EGOROVA	{"phone": "+70583771880"}
0005434229901	E35B29	2164 026269	VLADIMIR BORISOV	{"email": "v-borisov121968@postgrespro.ru", "phone": "+70930197605"}
0005434229902	3B0007	9202 187207	ALEKSANDR FROLOV	{"email": "a.frolov071969@postgrespro.ru", "phone": "+70833580562"}
0005434229903	3B0007	2876 420874	ALEKSEY ABRAMOV	{"email": "aleksey.abramov_061980@postgrespro.ru", "phone": "+70206555389"}
0005434229904	3B0007	4946 896453	LYUDMILA KUDRYASHOVA	{"email": "lyudmila-kudryashova-041983@postgrespro.ru", "phone": "+70974049242"}
0005434229905	BD22B7	3908 338545	ALBERT ANDREEV	{"email": "albert-andreev-1973@postgrespro.ru", "phone": "+70052449463"}
0005434229906	EC0F3F	0128 128332	VALENTINA ALEKSEEVA	{"email": "valekseeva_1982@postgrespro.ru", "phone": "+70637276194"}
0005434229907	F97777	7539 903575	OLEG SOROKIN	{"email": "o-sorokin.28061982@postgrespro.ru", "phone": "+70513897738"}
0005434230247	4BE06F	1231 487971	MARIYA BELOVA	{"phone": "+70142107205"}
0005434229908	F97777	5593 053159	EKATERINA EGOROVA	{"email": "ekaterina_egorova_01121967@postgrespro.ru", "phone": "+70041347605"}
0005434229909	D1CE4B	7399 362921	ANNA SAVELEVA	{"email": "anna-saveleva-27081976@postgrespro.ru", "phone": "+70600323477"}
0005434229910	A1A921	8302 925354	VLADIMIR KUZMIN	{"phone": "+70367835475"}
0005434229911	A1A921	3315 925451	VADIM PAVLOV	{"email": "vadim.pavlov1978@postgrespro.ru", "phone": "+70572264931"}
0005434229912	30A99E	2660 213914	NADEZHDA NAZAROVA	{"phone": "+70519695727"}
0005434229913	30A99E	2073 933754	ELENA KUDRYASHOVA	{"email": "kudryashova-elena_28101971@postgrespro.ru", "phone": "+70363810841"}
0005434229914	30A99E	2266 557491	NATALYA TITOVA	{"phone": "+70237490310"}
0005434229915	69E208	3339 750410	GULFIYA VLASOVA	{"phone": "+70480649691"}
0005434229916	F10833	5629 573891	IRINA RYABOVA	{"phone": "+70836981639"}
0005434229917	F10833	8883 844647	VLADIMIR ILIN	{"email": "vladimirilin.081960@postgrespro.ru", "phone": "+70660050746"}
0005434229918	470824	9752 532163	VALENTINA KAZAKOVA	{"email": "valentina_kazakova.1971@postgrespro.ru", "phone": "+70954365955"}
0005434229919	578582	2533 090484	MILANA VLASOVA	{"email": "milanavlasova.031991@postgrespro.ru", "phone": "+70097874435"}
0005434229920	EA92A1	3298 562614	VERA MAKAROVA	{"email": "vera_makarova.051975@postgrespro.ru", "phone": "+70582550323"}
0005434229921	DE0853	9132 548417	VERA FILATOVA	{"phone": "+70293891569"}
0005434229922	DE0853	3059 049795	OLGA TIMOFEEVA	{"email": "o.timofeeva-111967@postgrespro.ru", "phone": "+70870411581"}
0005434229923	CE8259	5024 346320	SERGEY OSIPOV	{"email": "s.osipov.011964@postgrespro.ru", "phone": "+70348926848"}
0005434229924	0A3A1A	9159 702539	VALERIYA VASILEVA	{"email": "vasileva.v021976@postgrespro.ru", "phone": "+70399913265"}
0005434229925	0A3A1A	2998 152416	EVGENIYA KUZNECOVA	{"email": "evgeniyakuznecova12091970@postgrespro.ru", "phone": "+70966874948"}
0005434229926	70C451	4758 939082	VLADIMIR KOZLOV	{"email": "kozlov-v08091976@postgrespro.ru", "phone": "+70896598708"}
0005434229927	8138F9	4565 361994	VARVARA ANDREEVA	{"phone": "+70060200930"}
0005434229928	8138F9	8110 600535	DMITRIY DENISOV	{"phone": "+70694984327"}
0005434229929	EC3345	0549 576557	SEMEN DENISOV	{"phone": "+70814377819"}
0005434229930	EC3345	6417 055827	NIKOLAY FEDOROV	{"email": "fedorov-n051979@postgrespro.ru", "phone": "+70597213664"}
0005434229931	E4F35E	2764 948642	RAISA LEBEDEVA	{"phone": "+70511003772"}
0005434229932	D121CC	2132 678661	TATYANA SIDOROVA	{"phone": "+70057907343"}
0005434229933	2DCDD4	8527 731302	EMMA KUDRYASHOVA	{"email": "kudryashovaemma.07011966@postgrespro.ru", "phone": "+70274046118"}
0005434229934	FDD577	7406 394922	MAKSIM ANDREEV	{"email": "andreev-maksim-1970@postgrespro.ru", "phone": "+70900645478"}
0005434229935	1EEE14	6568 090864	MARIYA POPOVA	{"email": "mariya.popova04061980@postgrespro.ru", "phone": "+70864383503"}
0005434229936	1EEE14	5119 462098	EKATERINA POLYAKOVA	{"phone": "+70432465565"}
0005434229937	93AB3C	1353 952740	ALLA DAVYDOVA	{"email": "alla.davydova23041980@postgrespro.ru", "phone": "+70495454890"}
0005434229938	93AB3C	5277 622974	ELENA KONDRATEVA	{"phone": "+70502519914"}
0005434229939	B41E51	1932 912714	LIDIYA ANISIMOVA	{"phone": "+70423650095"}
0005434229940	07D7BD	8266 536755	SERGEY ZHUKOV	{"phone": "+70624392911"}
0005434229941	8B9A8B	5255 514557	ROMAN GUSEV	{"phone": "+70986853883"}
0005434229942	8B9A8B	9695 735268	LYUBOV SOKOLOVA	{"email": "l-sokolova26051975@postgrespro.ru", "phone": "+70547947252"}
0005434229943	7E50EE	1950 459893	ALEKSEY EGOROV	{"email": "aegorov061982@postgrespro.ru", "phone": "+70495795121"}
0005434229944	7E50EE	3691 824234	RAISA CHERNOVA	{"email": "chernova-r-11061971@postgrespro.ru", "phone": "+70857379397"}
0005434229945	CC8258	9671 547564	GEORGIY TARASOV	{"phone": "+70355692184"}
0005434229946	B92FD5	1189 793493	NADEZHDA POPOVA	{"phone": "+70216871264"}
0005434229947	9DC1CF	0713 304136	MARINA SOLOVEVA	{"email": "marina.soloveva.041974@postgrespro.ru", "phone": "+70012773483"}
0005434229948	46850C	0191 782212	ARTEM VASILEV	{"email": "vasilev.artem07061970@postgrespro.ru", "phone": "+70777167438"}
0005434229949	46850C	7366 191427	ALBINA AKIMOVA	{"phone": "+70039253685"}
0005434229950	46850C	0599 124222	IRINA PETROVA	{"phone": "+70184433223"}
0005434229951	46850C	3517 393445	TAMARA ANISIMOVA	{"email": "anisimova_t03061973@postgrespro.ru", "phone": "+70190322037"}
0005434229952	46850C	8459 365777	ALEKSANDR BORISOV	{"email": "borisov_a-09101970@postgrespro.ru", "phone": "+70208156331"}
0005434229953	3CEE4A	0285 312692	DMITRIY IVANOV	{"phone": "+70968007885"}
0005434229954	0E7FF1	8693 441861	ALEKSEY KOROLEV	{"email": "aleksey.korolev_1955@postgrespro.ru", "phone": "+70554867864"}
0005434229955	17CCB4	6487 087786	DMITRIY KUZNECOV	{"phone": "+70239902936"}
0005434229956	EAE1B6	5514 445030	IRINA KOROLEVA	{"email": "i-koroleva.08111965@postgrespro.ru", "phone": "+70585000712"}
0005434229957	EAE1B6	6035 653610	LIDIYA DAVYDOVA	{"email": "davydovalidiya.081985@postgrespro.ru", "phone": "+70090283436"}
0005434229958	EAE1B6	0070 933351	GALINA TARASOVA	{"email": "tarasova.g.101975@postgrespro.ru", "phone": "+70382230087"}
0005434229959	752375	3268 419458	EVGENIYA ORLOVA	{"email": "eorlova-05031974@postgrespro.ru", "phone": "+70812860904"}
0005434229960	8780BF	6953 777329	SVETLANA MIRONOVA	{"phone": "+70133883901"}
0005434229961	5F0A07	1578 637531	LYUDMILA FOMINA	{"email": "fomina-l1963@postgrespro.ru", "phone": "+70358512970"}
0005434229962	5F0A07	1507 210047	IRINA STEPANOVA	{"phone": "+70011450278"}
0005434229963	5F0A07	1241 468915	MARINA POLYAKOVA	{"email": "m-polyakova-1958@postgrespro.ru", "phone": "+70309174529"}
0005434229965	54AD3D	2202 314385	BORIS PETROV	{"email": "petrovb1974@postgrespro.ru", "phone": "+70193545081"}
0005434229966	E4B830	0878 467545	IVAN YAKOVLEV	{"email": "yakovlevi.081978@postgrespro.ru", "phone": "+70734450829"}
0005434229967	E4B830	3114 307490	AMINA KUZNECOVA	{"phone": "+70082085124"}
0005434229968	CBA3BE	9827 394855	DANIIL SCHERBAKOV	{"phone": "+70860580447"}
0005434229969	CBA3BE	4806 307648	VIKTOR MIKHAYLOV	{"email": "mikhaylov-v-061985@postgrespro.ru", "phone": "+70790303564"}
0005434229970	F62D24	5003 171237	VLADIMIR SCHERBAKOV	{"phone": "+70207500306"}
0005434229971	A90640	5571 295143	EVGENIY DENISOV	{"phone": "+70389482597"}
0005434229972	6CFDD0	8626 637056	GALINA KULIKOVA	{"phone": "+70120833312"}
0005434229973	6CFDD0	6272 046756	EVA VASILEVA	{"phone": "+70542376606"}
0005434229974	6CFDD0	0848 435701	ANASTASIYA KUDRYASHOVA	{"email": "anastasiya.kudryashova_1966@postgrespro.ru", "phone": "+70877792991"}
0005434229975	6CFDD0	8794 533899	NADEZHDA VOLKOVA	{"phone": "+70047644725"}
0005434229976	C0FCA8	7273 885230	YULIYA KOVALEVA	{"email": "y.kovaleva.1969@postgrespro.ru", "phone": "+70438670676"}
0005434229977	C0FCA8	6340 299101	PAVEL SOKOLOV	{"phone": "+70008426084"}
0005434229978	F25DD2	9559 852922	VERA VASILEVA	{"phone": "+70820483358"}
0005434229979	03B08B	9408 607196	NATALYA NESTEROVA	{"email": "nesterova.n_1974@postgrespro.ru", "phone": "+70566742953"}
0005434229980	03B08B	5661 146277	VITALIY AFANASEV	{"email": "vitaliyafanasev-10071976@postgrespro.ru", "phone": "+70116439788"}
0005434229981	75D650	9652 231897	SVETLANA VLASOVA	{"phone": "+70292790409"}
0005434229982	75D650	2227 468281	ALEKSEY MAKSIMOV	{"email": "aleksey_maksimov.1979@postgrespro.ru", "phone": "+70612907130"}
0005434229983	9751CA	3333 635519	DANILA VASILEV	{"email": "d.vasilev-041963@postgrespro.ru", "phone": "+70525023169"}
0005434229984	A7659F	1616 050881	ALEKSANDR MAKAROV	{"email": "makarov_a-021968@postgrespro.ru", "phone": "+70826131260"}
0005434229985	55A7E3	5412 152889	STANISLAV SOLOVEV	{"email": "solovev-stanislav-1966@postgrespro.ru", "phone": "+70816168120"}
0005434229986	117A0F	2465 577520	SERGEY FROLOV	{"phone": "+70416961247"}
0005434229987	A508D6	0652 723490	TATYANA POTAPOVA	{"email": "t_potapova-1971@postgrespro.ru", "phone": "+70753891803"}
0005434229988	0D461C	2992 384944	ANNA SERGEEVA	{"email": "sergeeva-anna.071972@postgrespro.ru", "phone": "+70848697556"}
0005434229989	79E77B	8898 817599	IVAN SOROKIN	{"email": "sorokin_ivan.111976@postgrespro.ru", "phone": "+70751828301"}
0005434229990	FA5DBC	2312 931106	DMITRIY MIRONOV	{"email": "mironov_dmitriy_1977@postgrespro.ru", "phone": "+70634584072"}
0005434229991	633F9B	2324 099051	KARINA KAZAKOVA	{"email": "kazakova_k_07091968@postgrespro.ru", "phone": "+70199406825"}
0005434229992	9B31E9	2559 613672	TATYANA AFANASEVA	{"phone": "+70772121127"}
0005434229993	A2F9D1	9427 177751	ANTON GUSEV	{"phone": "+70167129466"}
0005434229994	DD3363	0179 809803	ANDREY MELNIKOV	{"phone": "+70017442662"}
0005434229995	2EDF72	6222 739433	INESSA TIKHONOVA	{"email": "tikhonova.inessa021969@postgrespro.ru", "phone": "+70487937029"}
0005434229996	2EDF72	1034 203141	ALEKSANDR ANDREEV	{"phone": "+70492457719"}
0005434229997	0C9B97	4615 204320	ANDREY TIMOFEEV	{"email": "andrey-timofeev_1969@postgrespro.ru", "phone": "+70043023628"}
0005434229998	87E921	2398 043135	EVGENIYA NIKITINA	{"phone": "+70301374611"}
0005434229999	3DC803	2402 999837	VALENTIN STEPANOV	{"email": "stepanov-v_10021983@postgrespro.ru", "phone": "+70966873359"}
0005434230000	3DC803	7065 808979	RUSTAM SIDOROV	{"phone": "+70123387603"}
0005434230001	3DC803	0980 976902	SERGEY FEDOTOV	{"email": "fedotovs_04031966@postgrespro.ru", "phone": "+70231411036"}
0005434230002	D62397	3861 565815	MARIYA KULIKOVA	{"email": "m-kulikova-111969@postgrespro.ru", "phone": "+70732312847"}
0005434230003	1CF520	4621 667716	ALEKSANDR KULIKOV	{"phone": "+70561916223"}
0005434230004	1CF520	9326 462773	IRINA KULIKOVA	{"phone": "+70053149468"}
0005434230005	0E453A	4574 058437	SVETLANA ANDREEVA	{"phone": "+70436179910"}
0005434230006	527214	7420 647702	TATYANA OVCHINNIKOVA	{"email": "tovchinnikova.19091969@postgrespro.ru", "phone": "+70474599665"}
0005434230007	527214	5406 249407	ULYANA EGOROVA	{"email": "ulyana_egorova.01081974@postgrespro.ru", "phone": "+70482050677"}
0005434230008	527214	5184 984425	LIDIYA MASLOVA	{"phone": "+70247941599"}
0005434230009	866955	1934 300731	EKATERINA BORISOVA	{"email": "e_borisova_1973@postgrespro.ru", "phone": "+70026372599"}
0005434230010	494A69	5780 219235	ANASTASIYA ALEKSANDROVA	{"email": "a-aleksandrova30061979@postgrespro.ru", "phone": "+70165707444"}
0005434230011	5EC0B5	3374 259432	NIKOLAY SOLOVEV	{"phone": "+70568336277"}
0005434230012	4558B2	2941 189313	EGOR PETROV	{"email": "e.petrov-091969@postgrespro.ru", "phone": "+70922241904"}
0005434230013	4558B2	0549 006966	VLADIMIR ANTONOV	{"phone": "+70977006455"}
0005434230014	BB76FF	6172 374609	VLADIMIR MELNIKOV	{"phone": "+70681469973"}
0005434230015	FF2EAD	2575 484443	NATALYA MIRONOVA	{"email": "natalya_mironova.28091960@postgrespro.ru", "phone": "+70886679208"}
0005434230016	FF2EAD	6723 095041	VERA AFANASEVA	{"phone": "+70561799655"}
0005434230017	B68F87	7126 734061	NINA EGOROVA	{"phone": "+70069446808"}
0005434230018	A7105B	1382 271055	RAFIK POPOV	{"email": "popov-r_041977@postgrespro.ru", "phone": "+70956181178"}
0005434230019	A7105B	9316 426048	LYUBOV SOROKINA	{"email": "sorokina_lyubov-1971@postgrespro.ru", "phone": "+70165067754"}
0005434230020	A7105B	9286 228732	NIKITA BORISOV	{"email": "n-borisov121981@postgrespro.ru", "phone": "+70313463462"}
0005434230023	D4BDE7	3037 537276	ANASTASIYA SOROKINA	{"email": "anastasiyasorokina-22021982@postgrespro.ru", "phone": "+70159385491"}
0005434230024	D4BDE7	4741 286427	OLESYA DMITRIEVA	{"email": "dmitrieva_olesya02011977@postgrespro.ru", "phone": "+70604007737"}
0005434230025	4272F4	2476 960363	KRISTINA MATVEEVA	{"email": "matveeva.kristina.05041974@postgrespro.ru", "phone": "+70652937841"}
0005434230026	B2DD60	5350 674517	MARIYA RODIONOVA	{"phone": "+70750678640"}
0005434230027	B2DD60	3199 282365	OLGA NESTEROVA	{"email": "nesterova_olga.111980@postgrespro.ru", "phone": "+70979304990"}
0005434230028	CA2E8E	6134 049571	OLGA IVANOVA	{"email": "ivanova-olga-051973@postgrespro.ru", "phone": "+70699883511"}
0005434230029	CA2E8E	3740 392182	VALERIY NAZAROV	{"phone": "+70073574399"}
0005434230030	8B1950	1779 130641	ANNA ILINA	{"email": "ilinaa.121970@postgrespro.ru", "phone": "+70686020511"}
0005434230031	8B1950	5945 057416	NIKOLAY MARTYNOV	{"phone": "+70169913113"}
0005434230032	1D8129	5277 542542	IVAN SIDOROV	{"phone": "+70373732324"}
0005434230033	1D8129	0659 052166	TATYANA GERASIMOVA	{"email": "tgerasimova.1967@postgrespro.ru", "phone": "+70183959622"}
0005434230034	69E37B	7550 604244	YURIY TIKHONOV	{"phone": "+70082101721"}
0005434230035	6A5CF2	2668 711266	RUZALIYA POTAPOVA	{"email": "rpotapova-24081960@postgrespro.ru", "phone": "+70354940821"}
0005434230036	C13E8B	3420 524202	VALERIY SOLOVEV	{"email": "solovev.valeriy_1973@postgrespro.ru", "phone": "+70574762764"}
0005434230037	C13E8B	0725 720097	OLGA ZAYCEVA	{"phone": "+70452250724"}
0005434230038	C13E8B	2552 448010	MAKSIM KUZNECOV	{"email": "kuznecov-maksim.031969@postgrespro.ru", "phone": "+70776122415"}
0005434230039	8ED7D0	1988 906104	MAKSIM ILIN	{"email": "maksim-ilin.18011964@postgrespro.ru", "phone": "+70327039637"}
0005434230040	0C3DFF	4081 438181	BORIS IVANOV	{"email": "b-ivanov_1984@postgrespro.ru", "phone": "+70453524848"}
0005434230041	0C3DFF	1867 423750	MAKSIM CHERNOV	{"email": "maksim.chernov.081978@postgrespro.ru", "phone": "+70226856415"}
0005434230042	FD3B59	8396 764713	ELENA MIRONOVA	{"phone": "+70353519930"}
0005434230043	1001DA	2853 907154	VLADIMIR KOROLEV	{"phone": "+70003623466"}
0005434230044	458A03	4034 568081	TATYANA SIDOROVA	{"email": "tatyana_sidorova-28081974@postgrespro.ru", "phone": "+70992987863"}
0005434230045	68C7E4	3214 363564	ARTEM ZHURAVLEV	{"phone": "+70677213672"}
0005434230046	4DCD28	4118 973749	VLADIMIR GUSEV	{"email": "gusev_vladimir-26091971@postgrespro.ru", "phone": "+70565386571"}
0005434230047	57F26B	3547 581019	ANTONINA IVANOVA	{"phone": "+70696195377"}
0005434230048	57F26B	9894 910338	VLADIMIR FEDOROV	{"email": "fedorov-v.091970@postgrespro.ru", "phone": "+70062904166"}
0005434230049	57F26B	0025 131868	ELENA KONDRATEVA	{"email": "kondrateva-elena1971@postgrespro.ru", "phone": "+70961977318"}
0005434230050	D2C22C	9272 271340	YURIY FROLOV	{"email": "frolov.y-04081971@postgrespro.ru", "phone": "+70285366406"}
0005434230051	70584C	7640 893287	VLADIMIR SERGEEV	{"phone": "+70897631827"}
0005434230052	70584C	5935 702470	KRISTINA POLYAKOVA	{"email": "k_polyakova.061980@postgrespro.ru", "phone": "+70068029291"}
0005434230053	DB06E7	8801 442703	SERGEY IVANOV	{"phone": "+70674529342"}
0005434230054	817C50	2015 744573	IRINA ARKHIPOVA	{"phone": "+70628937873"}
0005434230055	817C50	3421 547605	VERA ILINA	{"phone": "+70049095239"}
0005434230056	40A7E4	5490 671774	NINA ZOTOVA	{"email": "zotova_nina.1973@postgrespro.ru", "phone": "+70453304674"}
0005434230057	9DB853	2939 479880	OKSANA RODIONOVA	{"phone": "+70576910576"}
0005434230058	9DB853	9237 723565	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_12091968@postgrespro.ru", "phone": "+70052749254"}
0005434230059	AFFE40	7456 039471	TATYANA ZHUKOVA	{"email": "zhukova-t_121966@postgrespro.ru", "phone": "+70002592846"}
0005434230060	762F50	5095 274263	NIKOLAY VOLKOV	{"phone": "+70134782858"}
0005434230061	762F50	5432 881430	ROMAN ALEKSEEV	{"email": "alekseev-roman-121962@postgrespro.ru", "phone": "+70624520750"}
0005434230062	E23D09	4791 241478	NINA SAVELEVA	{"email": "n_saveleva_04031977@postgrespro.ru", "phone": "+70761790803"}
0005434230063	0BD039	9567 935336	PAVEL SOROKIN	{"email": "p_sorokin.29061974@postgrespro.ru", "phone": "+70399114076"}
0005434230064	F2CE14	8144 055366	ANTONINA FEDOROVA	{"email": "fedorova_antonina-04061961@postgrespro.ru", "phone": "+70579852960"}
0005434230065	5E41AE	0285 416275	ILYA BONDARENKO	{"email": "bondarenko-i_1972@postgrespro.ru", "phone": "+70455879128"}
0005434230066	A64CF6	9305 883102	ELENA KUZNECOVA	{"phone": "+70064806550"}
0005434230067	D7D5B4	4095 936090	OLGA ZAYCEVA	{"phone": "+70982056937"}
0005434230068	A93980	3826 553995	EVGENIY PAVLOV	{"phone": "+70513766901"}
0005434230069	A93980	6148 572185	FEDOR VLASOV	{"email": "f-vlasov051982@postgrespro.ru", "phone": "+70641485106"}
0005434230070	8A4CD1	4910 620549	RAISA KUZNECOVA	{"phone": "+70801910871"}
0005434230071	BCA5D9	7296 621647	OLGA MIKHAYLOVA	{"phone": "+70485373042"}
0005434230072	CF0330	8830 075068	ALEKSANDR TARASOV	{"email": "tarasov.a_18061962@postgrespro.ru", "phone": "+70483275598"}
0005434230073	4CBD25	2055 229474	ZINAIDA BARANOVA	{"email": "z-baranova_061982@postgrespro.ru", "phone": "+70970305572"}
0005434230074	54C728	8945 027394	TATYANA NIKOLAEVA	{"email": "t-nikolaeva_15021967@postgrespro.ru", "phone": "+70708454712"}
0005434230075	AFD912	3157 500150	VLADIMIR BARANOV	{"phone": "+70629681909"}
0005434230076	CDD221	9087 655009	OLGA KUZNECOVA	{"email": "olgakuznecova-021972@postgrespro.ru", "phone": "+70832442810"}
0005434230077	CDD221	7150 806615	LARISA NIKITINA	{"phone": "+70890529786"}
0005434230078	CDD221	7938 521803	VIOLETTA LUKYANOVA	{"email": "lukyanova.v_061980@postgrespro.ru", "phone": "+70579412951"}
0005434230079	E53B26	4757 566474	SOFYA ZOTOVA	{"email": "zotova-s.081973@postgrespro.ru", "phone": "+70163533971"}
0005434230080	E53B26	9332 506689	IVAN IVANOV	{"email": "ivanov_ivan-1975@postgrespro.ru", "phone": "+70710072981"}
0005434230081	254EDC	3228 926123	IRINA IVANOVA	{"phone": "+70458213282"}
0005434230082	BF488E	9166 696757	EVGENIY KUZNECOV	{"email": "kuznecov-e24091970@postgrespro.ru", "phone": "+70126388857"}
0005434230083	C16BE7	5330 601381	PAVEL PETROV	{"email": "petrovp.28101967@postgrespro.ru", "phone": "+70636205409"}
0005434230084	45720F	4135 079574	IRAIDA KUZMINA	{"phone": "+70019552929"}
0005434230085	45720F	3896 930876	VLADIMIR SEMENOV	{"email": "v.semenov-071977@postgrespro.ru", "phone": "+70175058822"}
0005434230086	2C0AEF	4939 290120	NINA PETROVA	{"phone": "+70915549149"}
0005434230087	2C0AEF	5361 118516	DMITRIY DAVYDOV	{"phone": "+70414474762"}
0005434230088	93AD83	7885 883482	ALEKSEY AFANASEV	{"phone": "+70479574741"}
0005434230089	93AD83	2496 982087	SERGEY IVANOV	{"email": "sivanov_1979@postgrespro.ru", "phone": "+70383122741"}
0005434230090	70EDE3	4513 582805	NATALYA ANDREEVA	{"phone": "+70354746012"}
0005434230091	458C4F	3651 029659	VLADISLAV ILIN	{"email": "v.ilin19011976@postgrespro.ru", "phone": "+70190881374"}
0005434230092	33ADEB	7401 737525	ALEKSANDR ABRAMOV	{"phone": "+70282940434"}
0005434230093	33ADEB	4041 937312	ANNA GAVRILOVA	{"phone": "+70577246793"}
0005434230094	33F719	9609 504094	ANNA ZAKHAROVA	{"phone": "+70572711028"}
0005434230095	33F719	5619 486841	ELENA EGOROVA	{"email": "elena-egorova_21041965@postgrespro.ru", "phone": "+70606497913"}
0005434230096	33F719	2682 342825	LYUBOV MOROZOVA	{"phone": "+70505227371"}
0005434230097	5A7A03	8583 294605	ALEKSEY KULIKOV	{"email": "kulikov-aleksey.22041964@postgrespro.ru", "phone": "+70973435743"}
0005434230098	5A7A03	4056 678236	VALERIYA IVANOVA	{"phone": "+70437124333"}
0005434230099	E8079E	6518 151451	NIKOLAY KUZNECOV	{"phone": "+70832806701"}
0005434230100	E8079E	3970 890193	MIKHAIL MEDVEDEV	{"email": "mikhail-medvedev.091974@postgrespro.ru", "phone": "+70938499686"}
0005434230101	A94FC5	5549 782821	ALEKSANDRA VASILEVA	{"email": "vasileva-aleksandra28071974@postgrespro.ru", "phone": "+70838006977"}
0005434230102	A94FC5	9573 227231	YURIY ZHUKOV	{"email": "yuriyzhukov-1970@postgrespro.ru", "phone": "+70834229981"}
0005434230103	8DB19F	5061 684443	OLGA BORISOVA	{"email": "borisova_o-19061971@postgrespro.ru", "phone": "+70127019345"}
0005434230104	59E8C5	6238 328646	EVA BARANOVA	{"phone": "+70378584008"}
0005434230105	5E33DC	4427 744109	VLADIMIR SERGEEV	{"phone": "+70030488574"}
0005434230106	346A44	3101 997857	DMITRIY TARASOV	{"phone": "+70385489059"}
0005434230163	E5F30D	8606 325744	KIRILL BELOV	{"phone": "+70004914708"}
0005434230107	346A44	7869 224104	VLADIMIR VASILEV	{"email": "vasilevvladimir_091973@postgrespro.ru", "phone": "+70968706124"}
0005434230108	003D83	6930 251953	ALEKSEY SCHERBAKOV	{"phone": "+70865804397"}
0005434230109	003D83	8519 663330	GENNADIY KARPOV	{"email": "karpov-gennadiy1977@postgrespro.ru", "phone": "+70818558898"}
0005434230110	986412	1669 813301	VLADIMIR NAZAROV	{"phone": "+70743546159"}
0005434230111	986412	8886 619577	SVETLANA SMIRNOVA	{"email": "smirnova_s_1968@postgrespro.ru", "phone": "+70036718415"}
0005434230112	EF163E	2232 308948	ALEKSANDR CHERNOV	{"phone": "+70857324235"}
0005434230113	DBF23A	9339 550101	NATALYA DANILOVA	{"phone": "+70802661082"}
0005434230114	6816E7	2017 447239	VIKTOR DMITRIEV	{"email": "dmitrievv011977@postgrespro.ru", "phone": "+70352511521"}
0005434230115	6816E7	3259 405409	KIRILL VASILEV	{"phone": "+70107122012"}
0005434230116	AB6E3E	1960 990567	YURIY SEMENOV	{"phone": "+70070889609"}
0005434230117	0D95B7	7825 089071	VLADIMIR EGOROV	{"phone": "+70655239890"}
0005434230118	4E0D55	8466 922387	VYACHESLAV VLASOV	{"email": "vyacheslavvlasov1978@postgrespro.ru", "phone": "+70594156092"}
0005434230119	4E0D55	5338 473832	TATYANA LAZAREVA	{"phone": "+70635720144"}
0005434230120	6953A5	2229 840065	DANIIL AFANASEV	{"phone": "+70097830755"}
0005434230121	3AE574	8305 353616	NIKITA KAZAKOV	{"phone": "+70325589565"}
0005434230122	3AE574	6928 616323	SERGEY BONDARENKO	{"email": "s-bondarenko-09061980@postgrespro.ru", "phone": "+70084621074"}
0005434230123	4CF3C3	3242 290095	VLADIMIR FROLOV	{"phone": "+70500992780"}
0005434230124	4CF3C3	5170 109129	VERA ZAYCEVA	{"phone": "+70059129747"}
0005434230125	E81485	9720 639134	SERGEY ORLOV	{"phone": "+70723949732"}
0005434230126	5C5B67	9043 305390	TATYANA SEMENOVA	{"email": "semenovat-26071974@postgrespro.ru", "phone": "+70984666453"}
0005434230127	306CE7	7176 477171	ALEKSANDR BORISOV	{"phone": "+70585607510"}
0005434230128	684836	8989 448214	VLADIMIR VASILEV	{"phone": "+70100702616"}
0005434230129	96631F	2532 070657	DENIS NIKOLAEV	{"email": "denis-nikolaev.031974@postgrespro.ru", "phone": "+70251311939"}
0005434230130	BC62B6	7821 898107	ANDREY IVANOV	{"email": "a_ivanov-23101971@postgrespro.ru", "phone": "+70053980421"}
0005434230131	388339	7697 113924	OLESYA FEDOROVA	{"email": "o-fedorova_1966@postgrespro.ru", "phone": "+70863679227"}
0005434230132	67F800	0036 362193	YURIY NIKITIN	{"phone": "+70585363482"}
0005434230133	04494D	4821 841980	NINA ANISIMOVA	{"email": "anisimova.n_20051979@postgrespro.ru", "phone": "+70738329119"}
0005434230134	04494D	0887 816521	KLAVDIYA ALEKSEEVA	{"email": "klavdiya-alekseeva011962@postgrespro.ru", "phone": "+70217109463"}
0005434230135	42350C	8655 558467	ALEKSANDR FEDOTOV	{"email": "aleksandr_fedotov_121983@postgrespro.ru", "phone": "+70614490099"}
0005434230136	42350C	9637 316865	SERGEY GAVRILOV	{"email": "gavrilov.s.22061974@postgrespro.ru", "phone": "+70220878289"}
0005434230137	34B76B	1916 181522	OLGA MOROZOVA	{"phone": "+70314406066"}
0005434230138	34B76B	8072 509824	EKATERINA POPOVA	{"phone": "+70251148915"}
0005434230139	C2F5BC	6363 603264	VLADIMIR ANDREEV	{"email": "vladimir.andreev021982@postgrespro.ru", "phone": "+70605239044"}
0005434230140	C2F5BC	3293 277224	OLGA ZOTOVA	{"email": "zotova.olga_1966@postgrespro.ru", "phone": "+70147135427"}
0005434230141	AC11BB	2852 882412	OLEG SEMENOV	{"phone": "+70249309230"}
0005434230142	AC11BB	7956 034778	ALEKSANDRA ILINA	{"phone": "+70641031006"}
0005434230143	54BDB4	5592 033119	OLGA MIRONOVA	{"email": "mironovaolga.1979@postgrespro.ru", "phone": "+70981956294"}
0005434230144	0F6055	6868 423053	NIKOLAY YAKOVLEV	{"phone": "+70970888846"}
0005434230145	7C9D61	3547 397766	ALEKSEY BONDARENKO	{"phone": "+70943929272"}
0005434230146	CCAA8F	9707 516755	ANASTASIYA KAZAKOVA	{"email": "anastasiya-kazakova.07011967@postgrespro.ru", "phone": "+70329274806"}
0005434230147	C8D5EA	0622 885141	ELENA ZAKHAROVA	{"email": "e.zakharova.13071969@postgrespro.ru", "phone": "+70116806360"}
0005434230148	E09FA2	7198 003356	EVGENIY EGOROV	{"email": "egorov.e-1970@postgrespro.ru", "phone": "+70038515786"}
0005434230149	E09FA2	4827 543973	ALEKSEY EGOROV	{"email": "egorov-a101973@postgrespro.ru", "phone": "+70488198326"}
0005434230150	F72CF2	1571 165512	VALERIY KRASNOV	{"phone": "+70444040679"}
0005434230151	C8629A	7141 034115	ANNA SEMENOVA	{"email": "semenova.a.121990@postgrespro.ru", "phone": "+70398458609"}
0005434230152	6CB7F0	3799 708549	DMITRIY NIKITIN	{"phone": "+70053623936"}
0005434230153	6CB7F0	4150 723650	OLGA GAVRILOVA	{"phone": "+70543682039"}
0005434230154	DAD204	6695 660858	ALEKSANDR MEDVEDEV	{"email": "medvedev-a031969@postgrespro.ru", "phone": "+70294481367"}
0005434230155	DAD204	4354 569187	IGOR GUSEV	{"phone": "+70430126730"}
0005434230156	3B604D	9577 876642	ELIZAVETA ZAKHAROVA	{"phone": "+70123880157"}
0005434230157	3B604D	5641 559119	VLADIMIR ZAKHAROV	{"email": "v.zakharov28101972@postgrespro.ru", "phone": "+70215104552"}
0005434230158	5378B2	2426 549837	ALEKSEY KARPOV	{"email": "karpov_a.31051968@postgrespro.ru", "phone": "+70719249975"}
0005434230159	EEDFDE	4929 938547	ELENA KUZNECOVA	{"email": "kuznecova_elena_111971@postgrespro.ru", "phone": "+70914976412"}
0005434230160	A411B6	8801 357162	NATALYA ABRAMOVA	{"phone": "+70300534553"}
0005434230161	FDDF37	3201 287416	RAFIS TARASOV	{"email": "rafistarasov1968@postgrespro.ru", "phone": "+70354071128"}
0005434230162	FDDF37	8483 670761	GENNADIY GRIGOREV	{"email": "gennadiy-grigorev_28051975@postgrespro.ru", "phone": "+70299547402"}
0005434230164	E5F30D	5664 951142	MIKHAIL KAZAKOV	{"phone": "+70332302283"}
0005434230165	72A7E6	8884 985890	GALINA PETROVA	{"email": "petrova.g1974@postgrespro.ru", "phone": "+70168232784"}
0005434230166	72A7E6	4864 239730	NINA SCHERBAKOVA	{"phone": "+70677955371"}
0005434230167	3A9ACB	5037 789712	OLEG SMIRNOV	{"phone": "+70905015069"}
0005434230168	E707C2	6970 721763	ALEKSEY VASILEV	{"phone": "+70604970711"}
0005434230169	9403BA	0967 617879	ANTONINA PAVLOVA	{"email": "a_pavlova-31011974@postgrespro.ru", "phone": "+70877043525"}
0005434230170	ABA680	4174 159777	TATYANA BORISOVA	{"email": "borisova.t04051972@postgrespro.ru", "phone": "+70309374112"}
0005434230171	ABA680	0528 548069	SERGEY NAZAROV	{"phone": "+70579955612"}
0005434230172	46378C	9200 245701	OLGA IVANOVA	{"phone": "+70821665935"}
0005434230173	F9588F	2310 817848	VALENTINA LEBEDEVA	{"email": "lebedeva-valentina011988@postgrespro.ru", "phone": "+70906049648"}
0005434230174	F9588F	5493 376691	ELENA NAZAROVA	{"phone": "+70254503991"}
0005434230175	73053D	6108 984648	NINA ILINA	{"email": "ilina_nina1974@postgrespro.ru", "phone": "+70809129769"}
0005434230176	48E617	9052 184667	RAISA POPOVA	{"email": "popovar_011977@postgrespro.ru", "phone": "+70740312012"}
0005434230177	48E617	8794 079003	ALENA IVANOVA	{"email": "ivanovaa_27061976@postgrespro.ru", "phone": "+70469563821"}
0005434230178	48E617	7860 314428	OLGA SMIRNOVA	{"email": "smirnova_olga.1978@postgrespro.ru", "phone": "+70405828872"}
0005434230179	53D6D7	8697 089978	DINA PETROVA	{"email": "d-petrova-011974@postgrespro.ru", "phone": "+70215015568"}
0005434230180	E1369C	6142 464501	ALEKSANDR TIMOFEEV	{"phone": "+70673395020"}
0005434230181	08C3DE	0084 375044	MARIYA RODIONOVA	{"email": "rodionova_m_1973@postgrespro.ru", "phone": "+70136011302"}
0005434230182	30068C	4379 567821	RAISA RODIONOVA	{"phone": "+70646487613"}
0005434230183	EE9D36	8823 973838	DANILA MOROZOV	{"phone": "+70574653056"}
0005434230184	EE9D36	8541 740997	TAMARA ARKHIPOVA	{"phone": "+70064222903"}
0005434230185	EE9D36	2344 568768	SVETLANA STEPANOVA	{"email": "svetlana.stepanova.25101987@postgrespro.ru", "phone": "+70981415314"}
0005434230186	B7D232	3470 618457	VIKTORIYA MOISEEVA	{"email": "moiseeva-viktoriya_061964@postgrespro.ru", "phone": "+70138617500"}
0005434230187	102824	5652 348217	ALISA GORBUNOVA	{"email": "a.gorbunova.1974@postgrespro.ru", "phone": "+70110397648"}
0005434230188	228937	1018 647257	EVGENIYA SOLOVEVA	{"email": "soloveva_evgeniya.1968@postgrespro.ru", "phone": "+70303281003"}
0005434230189	228937	9646 227546	YURIY FEDOROV	{"phone": "+70610296255"}
0005434230190	B7A41E	6687 345991	NATALYA DAVYDOVA	{"email": "n_davydova_02091970@postgrespro.ru", "phone": "+70109078754"}
0005434230191	06CADA	7380 748303	TIMOFEY GUSEV	{"email": "t_gusev091966@postgrespro.ru", "phone": "+70136259469"}
0005434230192	06CADA	5012 436267	TAMARA TIMOFEEVA	{"email": "tamara.timofeeva-1969@postgrespro.ru", "phone": "+70229439605"}
0005434230193	06CADA	9675 081769	SVETLANA DANILOVA	{"email": "danilova-svetlana.1964@postgrespro.ru", "phone": "+70834486228"}
0005434230194	0C7925	1717 510212	ANATOLIY ANDREEV	{"email": "aandreev_101979@postgrespro.ru", "phone": "+70568955283"}
0005434230195	BD5604	2632 126895	SERGEY PAVLOV	{"email": "pavlovs_091981@postgrespro.ru", "phone": "+70157030408"}
0005434230196	0BD37A	1981 408921	IGOR KRASNOV	{"email": "i_krasnov_10011971@postgrespro.ru", "phone": "+70238841253"}
0005434230197	77989E	7585 721512	ANDREY SCHERBAKOV	{"phone": "+70457407421"}
0005434230198	77989E	7787 171247	SERGEY MAKAROV	{"phone": "+70665718005"}
0005434230199	1B1094	8562 229171	ANTON ILIN	{"email": "ilin-anton1972@postgrespro.ru", "phone": "+70689538080"}
0005434230200	A1B4D7	2855 124097	NATALYA KULIKOVA	{"email": "kulikova_n-08091975@postgrespro.ru", "phone": "+70254601093"}
0005434230201	A9F034	4454 228569	ANDREY KISELEV	{"phone": "+70634422109"}
0005434230202	A9F034	1076 851479	NIKOLAY ILIN	{"phone": "+70447019358"}
0005434230203	1A07F1	7381 966783	SVETLANA IVANOVA	{"phone": "+70989982639"}
0005434230204	1A07F1	2587 896046	ELENA NIKOLAEVA	{"phone": "+70455656181"}
0005434230205	BD2B4D	5656 629707	MARINA PAVLOVA	{"phone": "+70527836991"}
0005434230206	E0EC68	8931 504710	DMITRIY PETROV	{"email": "d_petrov_20011979@postgrespro.ru", "phone": "+70765835374"}
0005434230207	E0EC68	3959 248934	OLGA NESTEROVA	{"email": "o-nesterova-24021972@postgrespro.ru", "phone": "+70046025960"}
0005434230208	DC1443	5309 386188	VADIM KUZNECOV	{"email": "vkuznecov1970@postgrespro.ru", "phone": "+70498954316"}
0005434230209	9CF4AE	9182 684881	ZOYA GAVRILOVA	{"email": "gavrilovaz_1969@postgrespro.ru", "phone": "+70281521499"}
0005434230210	36DC57	9587 594648	ELIZAVETA ARKHIPOVA	{"email": "e-arkhipova-12091968@postgrespro.ru", "phone": "+70066639610"}
0005434230211	4E261A	8846 191715	VITALIY KUZNECOV	{"email": "kuznecovv_061980@postgrespro.ru", "phone": "+70010877121"}
0005434230212	448E5E	1048 686543	DMITRIY YAKOVLEV	{"email": "yakovlev_d-02071971@postgrespro.ru", "phone": "+70649808013"}
0005434230213	8D4C25	2732 591926	ALEKSANDR FOMIN	{"email": "a.fomin1970@postgrespro.ru", "phone": "+70709657230"}
0005434230214	D5CDDE	7926 301582	PAVEL RODIONOV	{"phone": "+70803848407"}
0005434230215	D5CDDE	4362 807963	SERGEY SOKOLOV	{"phone": "+70626169986"}
0005434230216	55CF99	5583 179377	ANDREY MARTYNOV	{"phone": "+70164812951"}
0005434230217	55CF99	6953 693942	ANDREY KRASNOV	{"phone": "+70903877242"}
0005434230218	243BB3	4989 778364	ANATOLIY PETROV	{"phone": "+70340139868"}
0005434230219	243BB3	2210 481424	VLADIMIR ANDREEV	{"phone": "+70929019183"}
0005434230220	22FB9F	2125 117605	LYUBOV EGOROVA	{"email": "lyubov-egorova1976@postgrespro.ru", "phone": "+70422560677"}
0005434230221	22FB9F	8945 827579	ROZA IVANOVA	{"email": "r-ivanova-1977@postgrespro.ru", "phone": "+70927943345"}
0005434230222	C58E76	1178 310273	ANDREY VLASOV	{"phone": "+70554012884"}
0005434230223	C58E76	4567 129463	TATYANA BELOVA	{"phone": "+70339196284"}
0005434230224	C58E76	6494 249508	RAISA KUZMINA	{"email": "r-kuzmina_1974@postgrespro.ru", "phone": "+70802139102"}
0005434230225	0364E0	4156 457606	DENIS KARPOV	{"email": "karpov.denis28081970@postgrespro.ru", "phone": "+70171322182"}
0005434230226	C4598F	2713 965316	STANISLAV DENISOV	{"phone": "+70067519077"}
0005434230227	7C9E7A	8175 831528	OLGA KULIKOVA	{"phone": "+70379724975"}
0005434230228	7C9E7A	7368 400212	SERGEY VASILEV	{"email": "vasilev.s_03031975@postgrespro.ru", "phone": "+70618713731"}
0005434230229	19898A	9813 083205	ALINA LUKYANOVA	{"email": "alina_lukyanova.021972@postgrespro.ru", "phone": "+70683322789"}
0005434230230	19898A	7981 425202	ALEKSEY KUZNECOV	{"phone": "+70683219297"}
0005434230231	3F7ED0	3939 016417	VITALIY VASILEV	{"email": "vvasilev.091966@postgrespro.ru", "phone": "+70669349209"}
0005434230232	8DB951	5366 179303	NIKOLAY CHERNOV	{"email": "chernov-nikolay_15091980@postgrespro.ru", "phone": "+70348085804"}
0005434230233	8DB951	9030 784775	EGOR IVANOV	{"phone": "+70397859356"}
0005434230234	8DB951	1315 783318	PAVEL CHERNOV	{"phone": "+70309626482"}
0005434230235	4DC8B3	0449 649118	NINA KOZLOVA	{"phone": "+70352961571"}
0005434230236	CEC3C3	3746 565197	VLADIMIR MIKHAYLOV	{"phone": "+70766589997"}
0005434230237	CF6C3A	3089 625150	ANNA SAVELEVA	{"email": "anna.saveleva_10091981@postgrespro.ru", "phone": "+70498370002"}
0005434230238	B6265F	3111 152821	NATALYA POTAPOVA	{"email": "potapova-natalya_24101969@postgrespro.ru", "phone": "+70175563288"}
0005434230239	024C06	3378 201359	DMITRIY SOROKIN	{"email": "sorokin_dmitriy-12091977@postgrespro.ru", "phone": "+70891058840"}
0005434230240	024C06	9661 259270	EKATERINA NIKOLAEVA	{"phone": "+70948123672"}
0005434230241	B50B2C	4465 460288	MAKSIM ZAKHAROV	{"email": "zakharovmaksim1980@postgrespro.ru", "phone": "+70959088673"}
0005434230242	B50B2C	5360 667637	VLADIMIR POPOV	{"email": "vladimirpopov.041980@postgrespro.ru", "phone": "+70271375869"}
0005434230243	D85CDA	4690 385167	ALENA MELNIKOVA	{"email": "alena.melnikova.041975@postgrespro.ru", "phone": "+70931132006"}
0005434230244	D0FA15	9812 235385	VLADIMIR VASILEV	{"email": "vladimirvasilev.051981@postgrespro.ru", "phone": "+70690597520"}
0005434230245	D0FA15	5027 127236	LIDIYA GUSEVA	{"phone": "+70652591157"}
0005434230246	EBD500	7658 603591	MIKHAIL SMIRNOV	{"phone": "+70805759425"}
0005434230248	4BE06F	9068 927838	ELENA VOLKOVA	{"email": "volkova-e_21111970@postgrespro.ru", "phone": "+70284101296"}
0005434230249	020169	9411 757358	SERGEY TIKHONOV	{"email": "tikhonovsergey_25041970@postgrespro.ru", "phone": "+70212875805"}
0005434230250	E0E877	2690 712085	IRINA PAVLOVA	{"phone": "+70809334357"}
0005434230251	E0E877	7327 599597	SVETLANA IVANOVA	{"phone": "+70682000912"}
0005434230252	0887F8	6101 360538	VLADIMIR MATVEEV	{"phone": "+70457116817"}
0005434230253	30941B	9033 781713	IVAN SAVELEV	{"phone": "+70926896293"}
0005434230254	30941B	4357 404112	ELENA ZAKHAROVA	{"email": "e_zakharova08071977@postgrespro.ru", "phone": "+70336444339"}
0005434230255	C3128B	0335 586874	ANNA MIKHAYLOVA	{"email": "anna-mikhaylova_1972@postgrespro.ru", "phone": "+70591002255"}
0005434244600	FFBC5B	6024 410366	NATALYA ORLOVA	{"phone": "+70859485366"}
0005434230256	C3128B	6042 713608	NATALYA KUZNECOVA	{"email": "natalyakuznecova1974@postgrespro.ru", "phone": "+70271253561"}
0005434230257	C3128B	6511 766194	ZOYA SIDOROVA	{"email": "zoya.sidorova.12031968@postgrespro.ru", "phone": "+70737040039"}
0005434230258	3BD667	9536 731384	ANNA EGOROVA	{"phone": "+70128067741"}
0005434230259	3BD667	1596 372051	NATALYA NAUMOVA	{"phone": "+70286148482"}
0005434230260	5C47F3	8619 512055	LYUBOV VASILEVA	{"phone": "+70715336146"}
0005434230261	B6543A	0068 455349	NATALYA ISAEVA	{"email": "isaeva-n.121966@postgrespro.ru", "phone": "+70937359566"}
0005434230262	547174	4401 975305	MIKHAIL ROMANOV	{"email": "romanov_m_21091977@postgrespro.ru", "phone": "+70469829939"}
0005434230263	547174	9222 036823	VALERIY VASILEV	{"phone": "+70095902937"}
0005434230264	BBEAB1	5772 266081	ANNA VASILEVA	{"email": "anna_vasileva101976@postgrespro.ru", "phone": "+70516045598"}
0005434230265	C32DF1	3455 016977	ANATOLIY GERASIMOV	{"email": "gerasimov-anatoliy04031971@postgrespro.ru", "phone": "+70749684734"}
0005434230266	70A39C	4937 232002	NIKOLAY NOVIKOV	{"email": "novikov-n-111977@postgrespro.ru", "phone": "+70213755068"}
0005434230267	CC9E99	8561 085167	ALEKSANDR PETROV	{"email": "petrov_aleksandr041975@postgrespro.ru", "phone": "+70737188955"}
0005434230268	C29325	1535 333057	EKATERINA POPOVA	{"phone": "+70679870581"}
0005434230269	6D40C7	2225 580665	ILYA MIRONOV	{"email": "mironovi-1976@postgrespro.ru", "phone": "+70499143555"}
0005434230270	B3196F	5410 358555	MARAT MAKAROV	{"email": "marat.makarov.091973@postgrespro.ru", "phone": "+70379877015"}
0005434230271	4D38A6	1673 830137	NINA ZAYCEVA	{"phone": "+70176724255"}
0005434230272	AB7143	5291 260524	DMITRIY BELOV	{"email": "belov_d1978@postgrespro.ru", "phone": "+70395166274"}
0005434230273	AB7143	1978 855242	YURIY ZHUKOV	{"email": "zhukov-yuriy031979@postgrespro.ru", "phone": "+70585632827"}
0005434230274	328D31	9374 135342	LEONID KUZMIN	{"email": "kuzmin.leonid_1973@postgrespro.ru", "phone": "+70478933224"}
0005434230275	328D31	5541 947604	ANNA VASILEVA	{"email": "avasileva051970@postgrespro.ru", "phone": "+70995687111"}
0005434230276	674C15	3993 312045	VLADIMIR SOROKIN	{"phone": "+70372715180"}
0005434230277	D2BEF7	2721 537760	VARVARA KAZAKOVA	{"email": "kazakova-v-02121968@postgrespro.ru", "phone": "+70327353717"}
0005434230278	D2BEF7	8421 641265	IRINA GORBUNOVA	{"phone": "+70955077969"}
0005434230279	D32575	4523 293865	VLADIMIR ILIN	{"email": "vladimir.ilin021974@postgrespro.ru", "phone": "+70987160601"}
0005434230280	8DA43F	8216 248931	DMITRIY IVANOV	{"phone": "+70178867028"}
0005434230281	8DA43F	8634 944098	SOFYA ZAKHAROVA	{"email": "zakharova.s_14051968@postgrespro.ru", "phone": "+70374398898"}
0005434230282	D44B29	9359 688959	ROMAN BORISOV	{"email": "borisov.r.101972@postgrespro.ru", "phone": "+70999626019"}
0005434230283	D44B29	5156 028070	ALLA OVCHINNIKOVA	{"phone": "+70164642278"}
0005434230284	D44B29	3760 390098	MARIYA PAVLOVA	{"phone": "+70552834186"}
0005434230285	5D1488	9379 473232	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova_tatyana_081972@postgrespro.ru", "phone": "+70008789621"}
0005434230286	5D1488	7776 797387	EVGENIYA MELNIKOVA	{"phone": "+70468920950"}
0005434230287	A19FE2	1260 682041	RAFAIL ANDREEV	{"phone": "+70250470630"}
0005434230288	2AB356	5544 254504	EKATERINA MARTYNOVA	{"phone": "+70661032280"}
0005434244572	949C6B	7754 643438	EVGENIYA VLASOVA	{"phone": "+70693144144"}
0005434244453	73CC30	4013 640732	TATYANA MOROZOVA	{"email": "morozova_t031987@postgrespro.ru", "phone": "+70278367876"}
0005434244454	A91D60	4326 041578	GALINA KUDRYASHOVA	{"email": "kudryashova_g_021983@postgrespro.ru", "phone": "+70286969509"}
0005434244455	E7865B	4670 592304	KSENIYA FEDOROVA	{"email": "kseniya-fedorova_05081965@postgrespro.ru", "phone": "+70194523200"}
0005434244456	27E835	6534 433852	SVETLANA ALEKSEEVA	{"email": "s_alekseeva-051981@postgrespro.ru", "phone": "+70801485338"}
0005434244457	52692B	1541 419031	SERGEY SERGEEV	{"email": "sergeev.sergey_1969@postgrespro.ru", "phone": "+70323505567"}
0005434244458	52692B	5494 658629	SVETLANA KULIKOVA	{"phone": "+70005247592"}
0005434244459	FB70FD	0488 248765	DAMIR PETROV	{"phone": "+70823938404"}
0005434244460	32DF7D	6585 301239	ANATOLIY ABRAMOV	{"email": "anatoliyabramov-1971@postgrespro.ru", "phone": "+70580926171"}
0005434244461	32DF7D	6653 851351	ARTEM FILIPPOV	{"email": "filippova_03111959@postgrespro.ru", "phone": "+70344035987"}
0005434244462	0CA97B	4109 053367	IRINA GAVRILOVA	{"email": "i.gavrilova.051972@postgrespro.ru", "phone": "+70392367713"}
0005434244463	0CA97B	9322 407673	OLGA NAZAROVA	{"email": "nazarova_olga_05091967@postgrespro.ru", "phone": "+70742137161"}
0005434244464	3399A2	7947 216726	NATALYA SIDOROVA	{"phone": "+70802005142"}
0005434244465	AE77C5	3534 420292	ALEKSEY KARPOV	{"phone": "+70018454365"}
0005434244466	AE77C5	5380 736492	SERGEY SERGEEV	{"phone": "+70991933878"}
0005434244467	116E65	4186 669295	MARIYA DANILOVA	{"phone": "+70874078142"}
0005434244468	116E65	5443 167850	NIKOLAY MOROZOV	{"phone": "+70816539160"}
0005434244469	1FEDB3	0575 345186	KSENIYA VASILEVA	{"email": "vasileva.k_1977@postgrespro.ru", "phone": "+70801715258"}
0005434244470	1FEDB3	3331 840017	TATYANA ABRAMOVA	{"email": "tatyanaabramova08031973@postgrespro.ru", "phone": "+70096299193"}
0005434244471	188E2B	3907 093088	VALENTINA YUDINA	{"phone": "+70187939763"}
0005434244472	188E2B	9096 044883	ELENA KUZNECOVA	{"phone": "+70713822259"}
0005434244473	C7173B	9865 793213	NATALYA TIKHONOVA	{"email": "n-tikhonova.31071975@postgrespro.ru", "phone": "+70977403659"}
0005434244474	0161C8	5242 512597	ANASTASIYA POTAPOVA	{"phone": "+70462672644"}
0005434244475	0161C8	6493 354988	ANATOLIY ABRAMOV	{"phone": "+70039257400"}
0005434244476	AC1E44	6975 186337	ANTONINA VASILEVA	{"phone": "+70782013927"}
0005434244477	528D8F	3552 091005	SERGEY VASILEV	{"email": "vasilev_s.1979@postgrespro.ru", "phone": "+70913499667"}
0005434244478	B6FA17	6078 491529	ELENA MELNIKOVA	{"phone": "+70373562774"}
0005434244479	16E1A0	8445 649992	VLADISLAV BELOV	{"email": "belov_vladislav1979@postgrespro.ru", "phone": "+70008855008"}
0005434244480	16E1A0	9794 043189	YANA OSIPOVA	{"phone": "+70992387833"}
0005434244481	581548	1831 828266	ALENA PETROVA	{"email": "alena-petrova-25071979@postgrespro.ru", "phone": "+70046220481"}
0005434244482	1B2448	8438 002976	NINA DANILOVA	{"email": "danilova.nina07071967@postgrespro.ru", "phone": "+70693380660"}
0005434244483	1B2448	6127 548765	ALEKSANDRA IVANOVA	{"phone": "+70363149380"}
0005434244484	3B3BCE	8617 507282	GRIGORIY KUZMIN	{"email": "g.kuzmin.1966@postgrespro.ru", "phone": "+70464723924"}
0005434244485	7D79EA	4350 378805	DENIS ISAEV	{"email": "isaev-d061970@postgrespro.ru", "phone": "+70387090480"}
0005434244486	7D79EA	8397 875115	EKATERINA ABRAMOVA	{"phone": "+70953639731"}
0005434244487	45C117	2117 163556	DARYA EGOROVA	{"email": "egorovad-091981@postgrespro.ru", "phone": "+70614604474"}
0005434244488	0E02BC	3302 798725	EGOR BELOV	{"email": "belov_e.29111966@postgrespro.ru", "phone": "+70319358519"}
0005434244489	0E02BC	2603 809069	DMITRIY EGOROV	{"phone": "+70592352563"}
0005434244490	C0D025	5731 802990	ANATOLIY KUDRYASHOV	{"phone": "+70888861288"}
0005434244491	078F7B	4276 075049	IRINA NESTEROVA	{"phone": "+70522977405"}
0005434244492	036DEE	6305 498016	NINA NIKITINA	{"email": "nina-nikitina-1985@postgrespro.ru", "phone": "+70106567321"}
0005434244493	63C36F	0282 886801	GALINA KOROLEVA	{"phone": "+70706578821"}
0005434244494	1275D0	6416 271027	YULIYA KOROLEVA	{"phone": "+70130431405"}
0005434244495	75DD11	2597 066436	TATYANA VASILEVA	{"phone": "+70824636549"}
0005434244496	E78459	6260 599363	TATYANA IVANOVA	{"email": "tatyana-ivanova.25091973@postgrespro.ru", "phone": "+70576832194"}
0005434244497	0DB9DB	8571 030059	ELENA DAVYDOVA	{"email": "davydovae-121966@postgrespro.ru", "phone": "+70862082754"}
0005434244498	351581	3005 856314	GALINA ALEKSEEVA	{"email": "g_alekseeva.08111973@postgrespro.ru", "phone": "+70231876675"}
0005434244499	E59AC6	0949 286132	VALERIY PETROV	{"phone": "+70422420139"}
0005434244500	FBA15F	6522 320151	ELENA KOMAROVA	{"email": "e-komarova1975@postgrespro.ru", "phone": "+70052817337"}
0005434244501	FBA15F	1959 765252	MARIYA LAZAREVA	{"phone": "+70816091447"}
0005434244502	09E7A3	3124 510799	EKATERINA KRASNOVA	{"phone": "+70496332263"}
0005434244503	C2379D	0028 968580	EKATERINA KRASNOVA	{"phone": "+70565784780"}
0005434244504	A01633	6245 633360	GALINA PAVLOVA	{"phone": "+70648353853"}
0005434244505	A01633	4350 472279	ALEKSANDR VASILEV	{"email": "aleksandrvasilev021973@postgrespro.ru", "phone": "+70306885545"}
0005434244506	A01633	5765 136553	SERGEY SEMENOV	{"email": "s_semenov-111971@postgrespro.ru", "phone": "+70277441636"}
0005434244507	7C9205	6526 029626	ALEKSANDRA KONOVALOVA	{"email": "akonovalova.021975@postgrespro.ru", "phone": "+70036197022"}
0005434244508	AB4E22	6702 079019	ALESYA IVANOVA	{"phone": "+70583886614"}
0005434244509	E22C46	3000 891028	MARGARITA TIMOFEEVA	{"email": "margaritatimofeeva061979@postgrespro.ru", "phone": "+70814698969"}
0005434244510	BDCD7A	7813 650665	ANATOLIY BORISOV	{"phone": "+70575859876"}
0005434244511	BDCD7A	5762 834617	MIKHAIL KRASNOV	{"email": "krasnov_mikhail-01011966@postgrespro.ru", "phone": "+70591012339"}
0005434244512	8056F1	1556 047033	NATALYA NIKIFOROVA	{"email": "n-nikiforova-28051969@postgrespro.ru", "phone": "+70427450989"}
0005434244513	8056F1	9243 386762	MARINA EGOROVA	{"phone": "+70819307800"}
0005434244514	8056F1	8498 417644	NATALYA LUKYANOVA	{"phone": "+70952339614"}
0005434244515	44BBE2	4586 770557	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-1963@postgrespro.ru", "phone": "+70506421686"}
0005434244516	44BBE2	3848 765698	ANDREY DENISOV	{"email": "denisov_a_121973@postgrespro.ru", "phone": "+70537252082"}
0005434244517	10BCB3	8002 065019	LYUBOV KALININA	{"phone": "+70088263973"}
0005434244518	10BCB3	6604 615846	ALENA MIKHAYLOVA	{"email": "amikhaylova1971@postgrespro.ru", "phone": "+70896184828"}
0005434244519	C774C8	7396 665555	NADEZHDA SERGEEVA	{"phone": "+70834779408"}
0005434244520	067B69	5432 118172	EVGENIYA MIKHAYLOVA	{"phone": "+70498339640"}
0005434244521	067B69	7458 345229	VYACHESLAV GAVRILOV	{"phone": "+70062200045"}
0005434244522	F0A2F5	1927 530300	KSENIYA KUZMINA	{"email": "k_kuzmina_1984@postgrespro.ru", "phone": "+70790207175"}
0005434244523	6F219A	7563 443174	RAISA MAKSIMOVA	{"email": "maksimova-r.05121971@postgrespro.ru", "phone": "+70853587123"}
0005434244524	BC9225	2471 345713	SERGEY VOLKOV	{"phone": "+70650276146"}
0005434244525	6A8128	2139 074867	MARGARITA KOMAROVA	{"email": "margaritakomarova-16081959@postgrespro.ru", "phone": "+70634709505"}
0005434244526	C3E73D	8447 675307	KIRILL POPOV	{"phone": "+70032516628"}
0005434244527	C3E73D	0385 930860	NATALYA NIKITINA	{"email": "nikitina_natalya-15101971@postgrespro.ru", "phone": "+70613908718"}
0005434244528	39F688	2011 886179	ALEVTINA EFIMOVA	{"email": "efimova_a19051971@postgrespro.ru", "phone": "+70303463272"}
0005434244529	CA6185	7256 651831	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov_1970@postgrespro.ru", "phone": "+70615429716"}
0005434244530	806749	9100 089785	ANTON SERGEEV	{"phone": "+70884663974"}
0005434244531	E43439	6998 806235	VALERIYA BOGDANOVA	{"email": "bogdanovav1961@postgrespro.ru", "phone": "+70879337781"}
0005434244532	9030C3	7678 242999	VALENTINA ALEKSEEVA	{"phone": "+70675587834"}
0005434244533	9030C3	6587 920528	ANDREY ALEKSEEV	{"email": "alekseev_andrey011982@postgrespro.ru", "phone": "+70748621992"}
0005434244534	714D5A	6673 585137	MILANA MOROZOVA	{"phone": "+70408088120"}
0005434244535	714D5A	6604 099991	ALIYA TARASOVA	{"email": "atarasova-17041974@postgrespro.ru", "phone": "+70562777679"}
0005434244536	0BF14B	7727 457698	MARTA PETROVA	{"email": "marta-petrova-20061972@postgrespro.ru", "phone": "+70049656563"}
0005434244537	22A4DB	7813 876572	YURIY SOROKIN	{"phone": "+70210417186"}
0005434244538	86E383	3910 143171	VALERIY KUZNECOV	{"phone": "+70758352879"}
0005434244539	8BD34A	5025 610792	EDUARD STEPANOV	{"email": "stepanov_eduard_27041985@postgrespro.ru", "phone": "+70805902450"}
0005434244540	F72103	3808 374123	OLGA NOVIKOVA	{"phone": "+70537646323"}
0005434244541	F72103	8225 119275	SVETLANA TITOVA	{"email": "titova.svetlana-25031979@postgrespro.ru", "phone": "+70523531352"}
0005434244542	10538F	9933 553494	OLEG KAZAKOV	{"phone": "+70380778373"}
0005434244543	10538F	6801 280409	ALEKSANDR MELNIKOV	{"email": "melnikova-121964@postgrespro.ru", "phone": "+70825235121"}
0005434244544	811D33	2240 819310	ARTEM MIRONOV	{"phone": "+70957025694"}
0005434244545	811D33	8526 682952	LYUDMILA ANDREEVA	{"phone": "+70011923724"}
0005434244546	7A36B5	5972 534993	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov_1961@postgrespro.ru", "phone": "+70946983354"}
0005434244547	FC4932	3266 066435	VLADIMIR BONDARENKO	{"phone": "+70953421730"}
0005434244548	FC4932	6560 499112	DARYA MASLOVA	{"phone": "+70969562682"}
0005434244549	B75AEA	6219 650528	ANNA BORISOVA	{"email": "borisovaa-1975@postgrespro.ru", "phone": "+70888312215"}
0005434244550	B75AEA	7599 332664	VERA MIRONOVA	{"phone": "+70315628631"}
0005434244551	D0F98A	2720 304432	YURIY EGOROV	{"email": "egorov.y1973@postgrespro.ru", "phone": "+70956567428"}
0005434244552	D0F98A	0792 479012	EVGENIY SEMENOV	{"phone": "+70910293499"}
0005434244553	D0F98A	0301 739524	ALEKSEY ALEKSANDROV	{"email": "aaleksandrov-12051979@postgrespro.ru", "phone": "+70085046157"}
0005434244554	C47F8E	9532 774739	VIKTOR GERASIMOV	{"email": "v.gerasimov_23061976@postgrespro.ru", "phone": "+70163234702"}
0005434244555	2A4234	4199 576749	VERA POPOVA	{"email": "v-popova1970@postgrespro.ru", "phone": "+70543732989"}
0005434244556	13B402	1134 972196	ALEKSANDR EGOROV	{"email": "a_egorov_091984@postgrespro.ru", "phone": "+70010636641"}
0005434244557	C6C248	2922 329609	DMITRIY VOLKOV	{"phone": "+70210240354"}
0005434244558	C6C248	2558 235215	GALINA KOROLEVA	{"phone": "+70444536117"}
0005434244559	15EC60	1964 614549	NATALIYA AFANASEVA	{"phone": "+70136871754"}
0005434244560	1868B1	9315 563010	ANDREY POPOV	{"phone": "+70278096798"}
0005434244561	1868B1	9963 335547	OLGA ANDREEVA	{"email": "andreevao-081966@postgrespro.ru", "phone": "+70861194493"}
0005434244562	63438F	2097 738004	NIKOLAY FEDOROV	{"email": "fedorovnikolay1971@postgrespro.ru", "phone": "+70832256347"}
0005434244563	0202F1	6504 895078	OKSANA BELOVA	{"phone": "+70890983887"}
0005434244564	4EFA79	7785 654034	SVETLANA PETROVA	{"email": "petrova.s-22091982@postgrespro.ru", "phone": "+70129702098"}
0005434244565	21E34A	4505 851307	IVAN KOZLOV	{"email": "kozlov_i.091971@postgrespro.ru", "phone": "+70712480349"}
0005434244566	04877D	3779 574809	VITALIY OSIPOV	{"email": "osipov.v.021975@postgrespro.ru", "phone": "+70793568518"}
0005434244567	04877D	1751 400779	ALEKSANDR ILIN	{"email": "a_ilin18101970@postgrespro.ru", "phone": "+70914333382"}
0005434244568	04877D	4196 373889	YULIYA NIKOLAEVA	{"phone": "+70705715903"}
0005434244569	1772F6	6746 449634	ALEKSANDR KUZMIN	{"phone": "+70408438302"}
0005434244570	FA382F	9484 947968	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev.23021966@postgrespro.ru", "phone": "+70124865138"}
0005434244571	EF6D76	9093 714620	LARISA ARKHIPOVA	{"phone": "+70046329847"}
0005434244573	C554BD	8255 811968	VIOLETTA LUKYANOVA	{"phone": "+70120158413"}
0005434244574	58DB16	9179 540906	VITALIY GORBUNOV	{"phone": "+70632703207"}
0005434244575	F8FA40	6397 634192	IRINA IVANOVA	{"email": "ivanovai-1967@postgrespro.ru", "phone": "+70374368631"}
0005434244576	F8FA40	8851 916499	VLADIMIR BORISOV	{"phone": "+70633281179"}
0005434244577	F8FA40	1743 132506	VALERIY SIDOROV	{"email": "v_sidorov.041980@postgrespro.ru", "phone": "+70134223392"}
0005434244578	DA26A0	3380 950615	SERGEY ROMANOV	{"email": "sromanov05091969@postgrespro.ru", "phone": "+70294116233"}
0005434244579	C35285	9137 818887	GALINA MIRONOVA	{"email": "galina-mironova.30081975@postgrespro.ru", "phone": "+70647652616"}
0005434244580	6BE0A5	4521 483491	VLADIMIR SOLOVEV	{"phone": "+70140655449"}
0005434244581	6BE0A5	9020 974699	MIKHAIL KOZLOV	{"email": "mikhail-kozlov_011978@postgrespro.ru", "phone": "+70842491327"}
0005434244582	A0C247	3572 773834	NIKITA MEDVEDEV	{"email": "n-medvedev-1962@postgrespro.ru", "phone": "+70204576481"}
0005434244583	C7336C	0494 230078	ANTON EGOROV	{"email": "egorov.anton29121982@postgrespro.ru", "phone": "+70320041124"}
0005434244584	9E5843	8826 008533	YANA ZOTOVA	{"phone": "+70784546461"}
0005434244585	DC6197	7715 847940	NIKITA NIKITIN	{"email": "nnikitin1971@postgrespro.ru", "phone": "+70047570365"}
0005434244586	05B5DE	2930 831803	OLGA GUSEVA	{"email": "olga_guseva.011977@postgrespro.ru", "phone": "+70508154614"}
0005434244587	1E6450	0480 305087	ALEKSANDR GORBUNOV	{"phone": "+70539699386"}
0005434244588	DB100E	1877 936266	MIKHAIL ZAKHAROV	{"phone": "+70543868961"}
0005434244589	AA3346	8893 352158	OLGA ISAEVA	{"email": "isaeva-olga011991@postgrespro.ru", "phone": "+70982713288"}
0005434244590	60F0B1	3531 997432	TATYANA ISAEVA	{"email": "isaeva-tatyana.18071973@postgrespro.ru", "phone": "+70281142856"}
0005434244591	F3C16B	0934 084205	PAVEL ZAKHAROV	{"email": "pavel.zakharov_1979@postgrespro.ru", "phone": "+70192623251"}
0005434244592	99A1A5	3201 621501	KONSTANTIN GERASIMOV	{"email": "k.gerasimov-03071970@postgrespro.ru", "phone": "+70264274139"}
0005434244593	99A1A5	5777 054355	LYUBOV GAVRILOVA	{"email": "lyubovgavrilova-1975@postgrespro.ru", "phone": "+70965498191"}
0005434244594	9B1D6D	6324 745867	DARYA MOISEEVA	{"phone": "+70425221902"}
0005434244595	E379C6	8111 813871	KRISTINA FILIPPOVA	{"phone": "+70492784186"}
0005434244596	E379C6	9627 992441	TATYANA ZAYCEVA	{"phone": "+70992240037"}
0005434244597	3B1D74	3838 401491	VITALIY FROLOV	{"email": "vitaliyfrolov071970@postgrespro.ru", "phone": "+70258599242"}
0005434244598	A31AC7	5601 760802	ALI SERGEEV	{"email": "ali_sergeev_1967@postgrespro.ru", "phone": "+70173061353"}
0005434244599	420E68	6608 750733	KONSTANTIN KONOVALOV	{"email": "k.konovalov1971@postgrespro.ru", "phone": "+70835298980"}
0005434244601	C49001	4620 152668	RAISA FILIPPOVA	{"email": "raisa_filippova071976@postgrespro.ru", "phone": "+70177099329"}
0005434244602	C49001	1927 790420	TATYANA PETROVA	{"email": "petrova.tatyana-061984@postgrespro.ru", "phone": "+70509297998"}
0005434244603	C49001	9092 168063	NATALYA BARANOVA	{"email": "natalya-baranova1968@postgrespro.ru", "phone": "+70709713018"}
0005434244604	E58841	9524 771650	VASILIY FEDOTOV	{"phone": "+70577771888"}
0005434244605	F44BC8	3498 504756	VERA KOROLEVA	{"phone": "+70256632775"}
0005434244606	B6C1AC	2683 661020	NINA KONOVALOVA	{"phone": "+70552236318"}
0005434244607	83816C	5571 429180	VIKTORIYA VOLKOVA	{"phone": "+70477889320"}
0005434244608	762234	0502 523536	OLEG TARASOV	{"phone": "+70175922418"}
0005434244609	762234	7547 954909	ELENA BELOVA	{"email": "belova.elena-22041971@postgrespro.ru", "phone": "+70684835118"}
0005434244610	DB2987	4476 959643	ROZA POTAPOVA	{"phone": "+70578758930"}
0005434244611	DB2987	1312 931984	NIKOLAY NAZAROV	{"email": "nikolay_nazarov1975@postgrespro.ru", "phone": "+70441768720"}
0005434244612	44C737	7140 726829	OLGA ZHUKOVA	{"email": "o-zhukova1977@postgrespro.ru", "phone": "+70767105718"}
0005434244613	44C737	5527 709523	PETR MELNIKOV	{"phone": "+70630875200"}
0005434244614	398585	0348 018844	VIKTOR GERASIMOV	{"email": "gerasimov-v1969@postgrespro.ru", "phone": "+70756928451"}
0005434244615	B238E5	9738 179544	KSENIYA NIKOLAEVA	{"email": "kseniyanikolaeva_1971@postgrespro.ru", "phone": "+70718771992"}
0005434244616	011948	1943 521304	ALEKSANDRA ANTONOVA	{"phone": "+70480116186"}
0005434244617	2FE8AB	6111 627605	SERGEY SEMENOV	{"phone": "+70257648987"}
0005434244618	2FE8AB	2523 548210	ANATOLIY SIDOROV	{"phone": "+70324644038"}
0005434244619	515DE9	4774 373554	ANATOLIY MELNIKOV	{"phone": "+70178912881"}
0005434244620	787EB3	6341 062840	VASILIY MAKAROV	{"phone": "+70455213603"}
0005434244621	8EFE73	3593 261932	YULIYA MAKAROVA	{"email": "ymakarova_26031956@postgrespro.ru", "phone": "+70007219660"}
0005434244622	1A6C2E	1994 161327	SOFYA POPOVA	{"email": "s-popova1965@postgrespro.ru", "phone": "+70297685748"}
0005434244623	4973B2	6307 756297	NIKOLAY MIRONOV	{"email": "mironov.n-121966@postgrespro.ru", "phone": "+70480293582"}
0005434244624	4973B2	3143 548769	LYUDMILA MAKSIMOVA	{"phone": "+70178343976"}
0005434244625	68357A	5553 371897	VENERA SEMENOVA	{"phone": "+70306731402"}
0005434244626	68357A	7407 516822	TATYANA NIKOLAEVA	{"phone": "+70955605640"}
0005434244627	415540	0715 843068	DARYA NAZAROVA	{"phone": "+70235674980"}
0005434244628	6C2454	8031 641018	KSENIYA KRASNOVA	{"phone": "+70957388502"}
0005434244686	221C30	3979 017217	EVGENIY PETROV	{"phone": "+70100683870"}
0005434244629	6C2454	5931 137226	VALENTINA OVCHINNIKOVA	{"email": "v.ovchinnikova-23121961@postgrespro.ru", "phone": "+70055018079"}
0005434244630	EE044E	0395 291074	ANATOLIY POPOV	{"phone": "+70007872864"}
0005434244631	EE044E	0107 728803	VASILIY PETROV	{"email": "petrov.v14111981@postgrespro.ru", "phone": "+70232235553"}
0005434244632	60088D	4929 952697	MATVEY BARANOV	{"email": "baranov-matvey-1976@postgrespro.ru", "phone": "+70038297718"}
0005434244633	C2DCB4	9264 945196	VASILIY SAVELEV	{"phone": "+70962756019"}
0005434244634	E3D79C	1407 126041	GALINA VOROBEVA	{"phone": "+70164902290"}
0005434244635	BBE5B2	1066 349070	VALENTINA POTAPOVA	{"email": "valentinapotapova-1961@postgrespro.ru", "phone": "+70220039306"}
0005434244636	B29E19	6440 671346	MARINA LEBEDEVA	{"phone": "+70620472564"}
0005434244637	B29E19	1212 237840	ALEKSEY DMITRIEV	{"phone": "+70121002181"}
0005434244638	3602E0	2207 385175	VALERIY POPOV	{"email": "v-popov-011970@postgrespro.ru", "phone": "+70395956951"}
0005434244639	D90E3C	5371 747971	ARTUR DAVYDOV	{"phone": "+70782325330"}
0005434244640	1FB8F3	5886 820769	LYUDMILA KISELEVA	{"email": "kiseleva.l_03021952@postgrespro.ru", "phone": "+70431570487"}
0005434244641	88696F	1613 963719	EKATERINA LEBEDEVA	{"phone": "+70022355385"}
0005434244642	88696F	7622 037764	MARIYA BARANOVA	{"phone": "+70666221163"}
0005434244643	8C8D8E	5100 601402	MAKSIM NIKITIN	{"phone": "+70471008728"}
0005434244644	3858CC	0859 632260	SVETLANA FILATOVA	{"phone": "+70528626362"}
0005434244645	1F2F3C	9882 182532	PAVEL KARPOV	{"email": "p.karpov041978@postgrespro.ru", "phone": "+70553351922"}
0005434244646	6F1C6F	2819 236631	SEMEN NIKOLAEV	{"phone": "+70371824224"}
0005434244647	6002E7	2431 749667	VALENTINA IVANOVA	{"email": "valentina.ivanova_081979@postgrespro.ru", "phone": "+70682810222"}
0005434244648	1C27ED	4801 525789	MARINA ORLOVA	{"phone": "+70247147831"}
0005434244649	1C27ED	5531 320793	LARISA SEMENOVA	{"phone": "+70484706843"}
0005434244650	5F5F25	5164 217400	DANIIL GAVRILOV	{"email": "gavrilovdaniil-041966@postgrespro.ru", "phone": "+70195871961"}
0005434244651	0A81AB	4032 116900	ALEKSANDRA MEDVEDEVA	{"email": "amedvedeva-1976@postgrespro.ru", "phone": "+70915240080"}
0005434244652	ED6383	7405 023958	OLESYA TIMOFEEVA	{"email": "timofeevao.1971@postgrespro.ru", "phone": "+70503093509"}
0005434244653	E24E15	6888 045473	IRINA KOLESNIKOVA	{"phone": "+70645686200"}
0005434244654	359FCA	0628 469171	IRINA KOMAROVA	{"email": "ikomarova1972@postgrespro.ru", "phone": "+70209338197"}
0005434244655	359FCA	9480 611812	DMITRIY MAKSIMOV	{"email": "dmitriy_maksimov101987@postgrespro.ru", "phone": "+70449701079"}
0005434244656	3E9402	1647 383695	ELENA ROMANOVA	{"email": "e_romanova.19071969@postgrespro.ru", "phone": "+70339847962"}
0005434244657	0E7192	0138 769433	TATYANA KUZMINA	{"email": "tatyana_kuzmina1977@postgrespro.ru", "phone": "+70114937300"}
0005434244658	0E7192	6190 944768	GLEB PETROV	{"phone": "+70781859071"}
0005434244659	0E7192	8105 277204	TATYANA KUZMINA	{"phone": "+70770049392"}
0005434244660	54DC48	8376 355778	ANNA GRISHINA	{"phone": "+70172923647"}
0005434244661	54DC48	4658 445756	ILYAS GUSEV	{"email": "gusev_ilyas_23021976@postgrespro.ru", "phone": "+70828123646"}
0005434244662	CDFE83	4866 124939	OLEG ORLOV	{"phone": "+70648553919"}
0005434244663	CDFE83	8878 083143	YURIY STEPANOV	{"email": "y-stepanov.101973@postgrespro.ru", "phone": "+70139215745"}
0005434244664	CDFE83	1812 388515	SVETLANA ZAKHAROVA	{"phone": "+70293714173"}
0005434244665	49DAF7	9823 334016	GULSHAT AKIMOVA	{"email": "gulshat.akimova_121962@postgrespro.ru", "phone": "+70259240678"}
0005434244666	35B029	5054 360696	OLEG ILIN	{"phone": "+70977171886"}
0005434244667	1F073B	7582 420011	ALEKSANDR NIKOLAEV	{"phone": "+70320863592"}
0005434244668	D2B134	3363 514705	EVGENIY NOVIKOV	{"phone": "+70911832644"}
0005434244669	14A3EB	2192 633874	VITALIY SOROKIN	{"phone": "+70122012631"}
0005434244670	E8AEA6	2339 311838	SERGEY MEDVEDEV	{"email": "sergey_medvedev_05051984@postgrespro.ru", "phone": "+70551658629"}
0005434244671	E8AEA6	8285 864539	SERGEY SMIRNOV	{"email": "smirnov_s-13091979@postgrespro.ru", "phone": "+70064247412"}
0005434244672	B396E6	5130 184445	GENNADIY TIKHONOV	{"phone": "+70957683801"}
0005434244673	BC6779	5050 828081	DMITRIY FROLOV	{"email": "dfrolov-1970@postgrespro.ru", "phone": "+70153524792"}
0005434244674	BC6779	0705 390979	ALEKSANDR VASILEV	{"email": "vasilev.a_26091974@postgrespro.ru", "phone": "+70046999383"}
0005434244675	8D996F	9678 223012	MARIYA ALEKSEEVA	{"phone": "+70717443940"}
0005434244676	8D996F	1750 753389	IRINA MOROZOVA	{"phone": "+70219281753"}
0005434244677	1E9BA6	8594 095086	ELIZAVETA KUZNECOVA	{"phone": "+70090104606"}
0005434244678	22B35D	1261 506477	NINA PETROVA	{"email": "ninapetrova-051977@postgrespro.ru", "phone": "+70934362459"}
0005434244679	D88BB1	3226 690758	VITALIY AFANASEV	{"email": "afanasevvitaliy_03061973@postgrespro.ru", "phone": "+70507534400"}
0005434244680	2FFF7E	8800 092379	VALENTINA MAKSIMOVA	{"phone": "+70966640972"}
0005434244681	5F2F8D	5769 563505	VLADISLAV TARASOV	{"phone": "+70855746214"}
0005434244682	5F2F8D	5397 424857	EGOR NIKOLAEV	{"email": "egor_nikolaev021973@postgrespro.ru", "phone": "+70483837262"}
0005434244683	5CE377	9109 436290	NATALYA DENISOVA	{"phone": "+70535023327"}
0005434244684	5CE377	9240 607760	ELENA PAVLOVA	{"phone": "+70056727045"}
0005434244685	10A476	4833 164888	ANTONINA YAKOVLEVA	{"phone": "+70686384493"}
0005434244687	221C30	8619 581077	IGOR FOMIN	{"email": "i_fomin.101970@postgrespro.ru", "phone": "+70653721164"}
0005434244688	1C105E	7912 666815	ARTEM GAVRILOV	{"phone": "+70778071190"}
0005434244689	FDE6C5	2965 401568	NINA KRASNOVA	{"email": "krasnova-nina-1974@postgrespro.ru", "phone": "+70828295583"}
0005434244690	34A002	5918 419553	VIKTOR EGOROV	{"phone": "+70753146285"}
0005434244691	34A002	0786 838639	NATALYA NOVIKOVA	{"email": "natalya-novikova_1969@postgrespro.ru", "phone": "+70409791912"}
0005434244692	8CE821	3262 328063	IVAN POPOV	{"email": "popovivan-1970@postgrespro.ru", "phone": "+70100132933"}
0005434244693	D701B0	1361 951692	SEMEN ANTONOV	{"email": "santonov-1967@postgrespro.ru", "phone": "+70862606212"}
0005434244694	C39909	8651 382668	RAISA PAVLOVA	{"phone": "+70052994423"}
0005434244695	C39909	1353 734523	GALINA NOVIKOVA	{"email": "g_novikova-1976@postgrespro.ru", "phone": "+70008701070"}
0005434244696	49F1BF	6660 519742	NINA ZHURAVLEVA	{"email": "zhuravlevanina101966@postgrespro.ru", "phone": "+70378656892"}
0005434244697	1ACDC4	1935 912511	MARGARITA AFANASEVA	{"phone": "+70771114015"}
0005434244698	96EDE3	0802 818171	TATYANA FEDOROVA	{"phone": "+70583700858"}
0005434244699	8F0B95	3676 098161	OLGA KONOVALOVA	{"email": "o_konovalova_15031976@postgrespro.ru", "phone": "+70387948380"}
0005434244700	8F0B95	8722 679789	DANIIL PETROV	{"email": "d_petrov.121975@postgrespro.ru", "phone": "+70052594230"}
0005434244701	C7B402	8730 460168	KONSTANTIN ALEKSANDROV	{"email": "k_aleksandrov_1974@postgrespro.ru", "phone": "+70095315758"}
0005434244702	C7B402	5430 699419	ANATOLIY GORBUNOV	{"email": "anatoliygorbunov_12031965@postgrespro.ru", "phone": "+70824557588"}
0005434244703	65878D	8675 117663	LIDIYA FOMINA	{"email": "l-fomina-22011979@postgrespro.ru", "phone": "+70244109033"}
0005434244704	40AD2C	0753 489150	VASILIY FEDOROV	{"email": "fedorovvasiliy_07111975@postgrespro.ru", "phone": "+70941028031"}
0005434244705	40AD2C	4371 312538	OLGA ERMAKOVA	{"email": "olga-ermakova_1965@postgrespro.ru", "phone": "+70440790097"}
0005434244706	34801E	8166 268394	PAVEL VOLKOV	{"email": "pavel_volkov_081981@postgrespro.ru", "phone": "+70192246059"}
0005434244707	34801E	9443 757092	GALINA VASILEVA	{"phone": "+70310613979"}
0005434244708	34801E	6170 115687	TAMARA NESTEROVA	{"phone": "+70548914472"}
0005434244709	4AAA18	0564 696314	POLINA ZAYCEVA	{"phone": "+70107664381"}
0005434244710	4AAA18	8815 969745	TATYANA NIKOLAEVA	{"phone": "+70022556588"}
0005434244711	05DF37	2049 405882	PAVEL MAKAROV	{"email": "pavel.makarov_03061978@postgrespro.ru", "phone": "+70094474913"}
0005434244712	C7550F	4337 872995	SERGEY OSIPOV	{"email": "osipovs.02081979@postgrespro.ru", "phone": "+70616706018"}
0005434244713	AC2611	6253 299752	LARISA NESTEROVA	{"email": "larisanesterova17041983@postgrespro.ru", "phone": "+70093254507"}
0005434244714	685861	5856 861517	NADEZHDA POPOVA	{"email": "popova.n_14101967@postgrespro.ru", "phone": "+70420527134"}
0005434244715	685861	3906 477319	OLGA BELYAEVA	{"email": "olgabelyaeva-17011964@postgrespro.ru", "phone": "+70744827171"}
0005434244716	FCFF05	0707 387848	NADEZHDA POPOVA	{"email": "n.popova-021969@postgrespro.ru", "phone": "+70123592701"}
0005434244717	2A370A	5048 280767	OLGA KUDRYASHOVA	{"phone": "+70460438976"}
0005434244718	2A370A	2886 886283	NATALYA DANILOVA	{"phone": "+70491630476"}
0005434244719	90340E	6042 254976	ANNA PETROVA	{"email": "a.petrova-051972@postgrespro.ru", "phone": "+70221420641"}
0005434244720	E0DF82	6549 916014	ANASTASIYA KISELEVA	{"phone": "+70547726732"}
0005434244721	1BEADF	3541 353076	ANTON MAKSIMOV	{"email": "a_maksimov_05021973@postgrespro.ru", "phone": "+70074660816"}
0005434244722	1BEADF	8229 380534	NIKOLAY ANTONOV	{"phone": "+70010800541"}
0005434244723	DCF59F	0694 251646	VLADISLAV POPOV	{"email": "popovv011974@postgrespro.ru", "phone": "+70959116193"}
0005434244724	DCF59F	2817 945617	VLADIMIR GUSEV	{"email": "v-gusev_08071975@postgrespro.ru", "phone": "+70362516376"}
0005434244725	AF4ED2	2047 349587	KRISTINA ORLOVA	{"email": "k-orlova08031968@postgrespro.ru", "phone": "+70280934972"}
0005434244726	AF4ED2	4351 592079	ANNA NESTEROVA	{"phone": "+70318975829"}
0005434244727	AF4ED2	9406 507720	IGOR PAVLOV	{"email": "i_pavlov.1974@postgrespro.ru", "phone": "+70139325753"}
0005434244728	C7DBA1	8052 779828	NADEZHDA ISAEVA	{"phone": "+70594584462"}
0005434244729	C7DBA1	8822 474937	LYUDMILA SIDOROVA	{"phone": "+70653452039"}
0005434244730	A8BB04	0879 913944	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr_15071975@postgrespro.ru", "phone": "+70770586341"}
0005434244731	A8BB04	7120 900995	TATYANA KISELEVA	{"phone": "+70016022259"}
0005434244732	0A7DB3	8721 236860	KONSTANTIN KUZNECOV	{"phone": "+70662302016"}
0005434244733	0A7DB3	5712 525874	PAVEL IVANOV	{"email": "pavel_ivanov1972@postgrespro.ru", "phone": "+70705342513"}
0005434244734	BED524	8326 937807	DMITRIY KUZMIN	{"phone": "+70972385675"}
0005434244735	DB7F77	1136 771374	IVAN ZAKHAROV	{"phone": "+70780007809"}
0005434244736	DB7F77	9813 729247	IRINA PAVLOVA	{"email": "pavlova_i-1973@postgrespro.ru", "phone": "+70126610657"}
0005434244737	2E4AD6	7741 873139	LYUBOV ANDREEVA	{"email": "l-andreeva_25031977@postgrespro.ru", "phone": "+70254922180"}
0005434244738	B483DC	6692 615683	SERGEY NAUMOV	{"email": "naumov_sergey_1977@postgrespro.ru", "phone": "+70639686946"}
0005434244739	879A62	7520 905462	KSENIYA ALEKSANDROVA	{"phone": "+70134308125"}
0005434244740	879A62	5852 167632	ANDREY AFANASEV	{"email": "afanasev-andrey_01091969@postgrespro.ru", "phone": "+70391776302"}
0005434244741	112D00	8753 242729	ELENA IVANOVA	{"phone": "+70876454220"}
0005434244742	112D00	7864 519888	ELENA MEDVEDEVA	{"email": "elena.medvedeva1974@postgrespro.ru", "phone": "+70555452114"}
0005434244743	7ACC81	9025 927597	VERA IVANOVA	{"email": "ivanovavera.031957@postgrespro.ru", "phone": "+70955136286"}
0005434244744	7ACC81	6986 480540	PAVEL MATVEEV	{"email": "matveev.p04121966@postgrespro.ru", "phone": "+70370727409"}
0005434244745	1E844A	3930 269952	LIDIYA MAKAROVA	{"email": "lidiya.makarova1967@postgrespro.ru", "phone": "+70362720213"}
0005434244746	1E844A	7818 687337	VLADIMIR MOROZOV	{"phone": "+70981360476"}
0005434244747	2AC100	5726 841532	ANNA IVANOVA	{"phone": "+70464009042"}
0005434244748	ABD921	2968 187407	SERGEY CHERNOV	{"phone": "+70186283020"}
0005434244749	FBB8FB	0297 957963	VERA MAKAROVA	{"email": "vera-makarova-1973@postgrespro.ru", "phone": "+70172830486"}
0005434244750	5746BB	5447 458963	SERGEY FILIPPOV	{"phone": "+70472897609"}
0005434244751	5A2086	0992 852884	SERGEY PAVLOV	{"email": "pavlov_sergey.101965@postgrespro.ru", "phone": "+70952745619"}
0005434244752	871741	7258 390336	ANDREY PETROV	{"phone": "+70053498900"}
0005434244753	E0C3DA	7212 084174	ALEKSANDR POPOV	{"phone": "+70277576394"}
0005434244754	886A1D	0850 541743	MIKHAIL VASILEV	{"email": "vasilev.mikhail111974@postgrespro.ru", "phone": "+70919812505"}
0005434244755	9ACBB7	0568 235742	ELENA KOVALEVA	{"email": "kovaleva_e-021969@postgrespro.ru", "phone": "+70328801354"}
0005434244756	4CEB45	8830 672023	OLEG NAZAROV	{"phone": "+70070139410"}
0005434244757	D27579	7680 619144	SALAVAT ZAYCEV	{"email": "s-zaycev_071975@postgrespro.ru", "phone": "+70450735308"}
0005434244758	D27579	6711 647090	ARINA ABRAMOVA	{"email": "abramova_a.051979@postgrespro.ru", "phone": "+70196086735"}
0005434244759	432FD4	6997 079777	ANDREY FROLOV	{"email": "frolov-andrey051983@postgrespro.ru", "phone": "+70310544707"}
0005434244760	432FD4	2103 562687	VALENTIN NIKITIN	{"phone": "+70893025766"}
0005434244761	432FD4	8617 206930	RAMIL ABRAMOV	{"email": "abramov.ramil_011973@postgrespro.ru", "phone": "+70588282840"}
0005434244762	633BF9	9586 363418	YAKOV KARPOV	{"phone": "+70066310721"}
0005434244763	00EFFB	8418 255675	VLADIMIR EGOROV	{"phone": "+70987403147"}
0005434244764	E6E483	6235 929070	SERGEY TIMOFEEV	{"email": "timofeevs.111958@postgrespro.ru", "phone": "+70430298701"}
0005434244765	C67AEC	8779 232229	ELENA ZOTOVA	{"phone": "+70436692183"}
0005434244766	C67AEC	5542 064650	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev-27071977@postgrespro.ru", "phone": "+70034672976"}
0005434244767	ED92B9	4167 028936	SVETLANA EGOROVA	{"email": "svetlana_egorova.121982@postgrespro.ru", "phone": "+70908129208"}
0005434244768	ED92B9	4284 072886	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.01111967@postgrespro.ru", "phone": "+70510170171"}
0005434244769	2CE781	9577 741865	LYUBOV NAUMOVA	{"phone": "+70322504443"}
0005434244770	12E744	6927 222617	RUSLAN SMIRNOV	{"email": "ruslansmirnov-1964@postgrespro.ru", "phone": "+70441905619"}
0005434244771	46B8FD	9969 262616	PELAGEYA CHERNOVA	{"email": "chernova-pelageya.29091973@postgrespro.ru", "phone": "+70762530101"}
0005434244772	46B8FD	1114 960736	SERGEY KUZNECOV	{"email": "kuznecov_sergey.1974@postgrespro.ru", "phone": "+70263262930"}
0005434244773	46B8FD	0551 680379	MARIYA SEMENOVA	{"email": "semenovam_1979@postgrespro.ru", "phone": "+70683421971"}
0005434244774	622145	8421 756863	EGOR SIDOROV	{"phone": "+70643872061"}
0005434244775	C10521	2835 768822	NIKOLAY ZAYCEV	{"phone": "+70657855922"}
0005434244776	C10521	9547 500646	KONSTANTIN VLASOV	{"phone": "+70307968198"}
0005434244777	A5A641	5292 299627	DMITRIY SHEVCHENKO	{"email": "shevchenko-d.071972@postgrespro.ru", "phone": "+70452466443"}
0005434244778	A5A641	0851 852706	ANNA KUZNECOVA	{"email": "anna_kuznecova.1972@postgrespro.ru", "phone": "+70722218948"}
0005434244779	B7CCE0	8845 535400	RAISA ZAYCEVA	{"email": "r.zayceva051984@postgrespro.ru", "phone": "+70537247090"}
0005434244780	BDA153	8452 046645	VIKTORIYA NOVIKOVA	{"email": "viktoriya.novikova-041980@postgrespro.ru", "phone": "+70969287101"}
0005434244781	AEAEF5	3795 711478	LYUDMILA SERGEEVA	{"phone": "+70820901189"}
0005434244782	AEAEF5	3387 385371	NADEZHDA ZHURAVLEVA	{"phone": "+70363636883"}
0005434244783	1C44F3	3221 871320	SERGEY DMITRIEV	{"phone": "+70281826717"}
0005434244784	1C44F3	7926 082246	IRINA BORISOVA	{"phone": "+70705054602"}
0005434244785	1C44F3	8503 076408	DMITRIY SOKOLOV	{"phone": "+70739955727"}
0005434244786	FC2F8A	0286 443491	ALEKSANDR VASILEV	{"email": "vasileva.021967@postgrespro.ru", "phone": "+70122060290"}
0005434244787	FC2F8A	6373 866805	SERGEY NIKITIN	{"email": "s-nikitin-051962@postgrespro.ru", "phone": "+70132733616"}
0005434244788	8D62B1	1619 934518	SVETLANA KOZLOVA	{"phone": "+70876261786"}
0005434244789	8D62B1	5227 998451	KLAVDIYA TROFIMOVA	{"email": "trofimova.klavdiya1967@postgrespro.ru", "phone": "+70241261392"}
0005434244790	A89CAB	0325 677379	IVAN ILIN	{"email": "ivan-ilin011979@postgrespro.ru", "phone": "+70887358136"}
0005434244791	78B3CD	7186 680189	VLADIMIR VOLKOV	{"email": "vladimir-volkov_1969@postgrespro.ru", "phone": "+70702793405"}
0005434244792	78B3CD	5560 159494	MARIYA KUZMINA	{"email": "mariya-kuzmina17051974@postgrespro.ru", "phone": "+70612498265"}
0005434244793	2DDB6A	8863 276176	MAKSIM FEDOTOV	{"email": "maksim.fedotov.1974@postgrespro.ru", "phone": "+70895124136"}
0005434244794	2DDB6A	8065 154959	SERGEY STEPANOV	{"email": "sergey-stepanov-30101966@postgrespro.ru", "phone": "+70903823575"}
0005434244795	0C968B	2116 420357	VITALIY MOROZOV	{"phone": "+70531290018"}
0005434244796	0C968B	2034 625244	ILYA MATVEEV	{"email": "matveev-i_17051991@postgrespro.ru", "phone": "+70973061207"}
0005434244797	F804F2	3718 819986	ALEKSANDR SHEVCHENKO	{"phone": "+70124154756"}
0005434244798	FB728B	3539 704386	ELENA GRISHINA	{"email": "egrishina041979@postgrespro.ru", "phone": "+70528152080"}
0005434244799	86BF27	0910 569247	GALINA LEBEDEVA	{"email": "g_lebedeva-071969@postgrespro.ru", "phone": "+70791941909"}
0005434244800	86BF27	8261 053165	SERGEY NAUMOV	{"email": "naumov_sergey_13051967@postgrespro.ru", "phone": "+70693657544"}
0005434244801	1129A4	7845 116249	PETR MIKHAYLOV	{"phone": "+70029469492"}
0005434244802	1129A4	0577 257895	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a.1972@postgrespro.ru", "phone": "+70718703997"}
0005434244803	0A93DF	4993 042574	EGOR ZAYCEV	{"email": "e_zaycev.29031973@postgrespro.ru", "phone": "+70228572780"}
0005434244804	BB0C97	6120 609871	GALIYA DENISOVA	{"email": "denisova-galiya.07111980@postgrespro.ru", "phone": "+70657417029"}
0005434244805	BAB950	1376 683353	ALEKSANDR MOISEEV	{"email": "aleksandrmoiseev021978@postgrespro.ru", "phone": "+70619445990"}
0005434244806	135BCE	7093 527893	IVAN RODIONOV	{"email": "i_rodionov.061975@postgrespro.ru", "phone": "+70710408970"}
0005434244807	135BCE	5449 343967	NATALIYA PAVLOVA	{"email": "pavlovan.1960@postgrespro.ru", "phone": "+70442971059"}
0005434244808	DFD825	1677 024398	TATYANA FILATOVA	{"phone": "+70317040620"}
0005434244809	DFD825	2729 778898	PAVEL FEDOTOV	{"phone": "+70283903320"}
0005434244810	A2AD44	2831 237722	NIKOLAY SERGEEV	{"phone": "+70150919425"}
0005434244811	62EEB1	6071 183089	VALENTINA ZAYCEVA	{"email": "v.zayceva-03071972@postgrespro.ru", "phone": "+70958969960"}
0005434244812	62EEB1	0751 747524	SERGEY DMITRIEV	{"phone": "+70186784581"}
0005434244813	2E5370	3504 575729	ALBINA FADEEVA	{"email": "fadeeva_a1970@postgrespro.ru", "phone": "+70326738518"}
0005434244814	8465E6	7501 750003	VLADIMIR SOKOLOV	{"phone": "+70790859972"}
0005434244815	8465E6	4593 792497	IVAN TARASOV	{"phone": "+70705026053"}
0005434244816	F34F2C	6164 643806	ANNA OVCHINNIKOVA	{"phone": "+70938363672"}
0005434244817	FD9F90	7945 556929	DMITRIY MOISEEV	{"phone": "+70633572257"}
0005434244818	91A4AE	0860 570921	ANATOLIY ROMANOV	{"phone": "+70111147343"}
0005434244819	A361E4	9019 825865	KLAVDIYA ALEKSANDROVA	{"phone": "+70077428563"}
0005434244820	A361E4	5755 327881	RAISA TITOVA	{"phone": "+70829949667"}
0005434244821	1DAE97	7341 147994	LIDIYA KOLESNIKOVA	{"phone": "+70243978855"}
0005434244822	1DAE97	0674 799442	NIKOLAY ILIN	{"email": "nikolay.ilin14091972@postgrespro.ru", "phone": "+70897553120"}
0005434244823	F65B37	6002 997701	LYUDMILA DENISOVA	{"phone": "+70872830412"}
0005434244824	F65B37	5846 947370	VIKTOR TARASOV	{"email": "tarasov_v031973@postgrespro.ru", "phone": "+70309359024"}
0005434244825	CB2475	5212 906016	ALEKSANDR MAKSIMOV	{"email": "amaksimov-22021971@postgrespro.ru", "phone": "+70758904243"}
0005434244826	D4F54A	8671 984965	LIDIYA POPOVA	{"email": "popoval.081989@postgrespro.ru", "phone": "+70406237155"}
0005434244827	017E63	6043 597202	NIKOLAY VOLKOV	{"email": "n-volkov1970@postgrespro.ru", "phone": "+70074152916"}
0005434244828	017E63	0397 569288	ALEKSANDR ANTONOV	{"phone": "+70702885559"}
0005434244829	017E63	7049 813945	DINARA PETROVA	{"email": "dinara-petrova-1982@postgrespro.ru", "phone": "+70030871084"}
0005434244830	8AD4B1	9499 262202	MARIYA PAVLOVA	{"email": "mariya_pavlova041962@postgrespro.ru", "phone": "+70494570409"}
0005434244831	279F96	1304 191961	GEORGIY SOLOVEV	{"phone": "+70481135225"}
0005434244832	279F96	1061 556023	VYACHESLAV ZAYCEV	{"email": "zaycevv.1975@postgrespro.ru", "phone": "+70704586694"}
0005434244833	EA5222	5247 337522	SVETLANA ILINA	{"email": "s-ilina_12121979@postgrespro.ru", "phone": "+70292947194"}
0005434244834	7BE9DE	1462 014885	ANTONINA ROMANOVA	{"email": "antonina-romanova28061971@postgrespro.ru", "phone": "+70909246907"}
0005434244835	89965C	4899 003217	ALINA LAZAREVA	{"email": "lazareva.alina_1977@postgrespro.ru", "phone": "+70474305853"}
0005434244836	D70637	9729 424043	ALEKSANDR MOISEEV	{"email": "aleksandrmoiseev041978@postgrespro.ru", "phone": "+70278754755"}
0005434244837	D70637	8660 999200	TATYANA KRASNOVA	{"phone": "+70504623087"}
0005434244838	D70637	3462 904377	OLGA YAKOVLEVA	{"phone": "+70314516948"}
0005434244839	C0A3C3	1265 652694	LYUBOV SOKOLOVA	{"phone": "+70188212200"}
0005434244840	84D4D1	7778 519300	ALEKSANDR KOZLOV	{"email": "kozlova101971@postgrespro.ru", "phone": "+70058622553"}
0005434244841	84D4D1	6734 633209	ARTEM KRASNOV	{"email": "a_krasnov011984@postgrespro.ru", "phone": "+70025306636"}
0005434244842	D14709	1754 541049	ANDREY KULIKOV	{"email": "kulikov.andrey_27011966@postgrespro.ru", "phone": "+70766205220"}
0005434244843	070CEB	6242 045511	LYUDMILA AKIMOVA	{"email": "akimova-l_15041964@postgrespro.ru", "phone": "+70375783023"}
0005434244844	E484C8	8693 101965	NIKOLAY GAVRILOV	{"email": "gavrilov-n_10081981@postgrespro.ru", "phone": "+70924342947"}
0005434244845	E484C8	2038 822934	VALENTINA GRISHINA	{"email": "grishina-valentina.071977@postgrespro.ru", "phone": "+70613869623"}
0005434244846	F7B558	6822 561401	LYUBOV ZAYCEVA	{"phone": "+70582331962"}
0005434244847	E88505	6328 532566	ALEKSANDRA ZAKHAROVA	{"phone": "+70499375111"}
0005434244848	E88505	7611 246262	TATYANA IVANOVA	{"phone": "+70817390421"}
0005434244849	5E7723	9583 695751	YULIYA FROLOVA	{"phone": "+70019796465"}
0005434244850	1CC117	3577 146968	GENNADIY ANTONOV	{"phone": "+70517177827"}
0005434244851	D843A4	2047 451655	MAKSIM IVANOV	{"email": "maksimivanov_01091958@postgrespro.ru", "phone": "+70671223986"}
0005434244852	8085C3	6684 166132	PAVEL NAZAROV	{"email": "p_nazarov_071966@postgrespro.ru", "phone": "+70749460982"}
0005434244853	3851EB	5146 890124	YURIY DMITRIEV	{"email": "y_dmitriev-061973@postgrespro.ru", "phone": "+70681507588"}
0005434244854	4D354C	5987 115332	ALEKSANDR STEPANOV	{"email": "a-stepanov13021972@postgrespro.ru", "phone": "+70447256125"}
0005434244855	3EE8B3	5914 503255	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda.12101971@postgrespro.ru", "phone": "+70759305303"}
0005434244856	3EE8B3	3261 153642	LYUDMILA ABRAMOVA	{"email": "labramova.01081979@postgrespro.ru", "phone": "+70947019524"}
0005434244857	D758F3	0203 519362	RINAT SCHERBAKOV	{"email": "r_scherbakov_28021981@postgrespro.ru", "phone": "+70013745194"}
0005434244858	9A2BBA	2270 665137	ELENA OVCHINNIKOVA	{"phone": "+70792599330"}
0005434244859	5A88D0	0693 047026	VLADIMIR NIKITIN	{"phone": "+70538832199"}
0005434244860	3671F7	6382 580297	ALEKSANDR KOZLOV	{"email": "a-kozlov-1966@postgrespro.ru", "phone": "+70056782517"}
0005434244861	B313AA	8961 835217	NATALYA LUKYANOVA	{"email": "n.lukyanova.1970@postgrespro.ru", "phone": "+70225580975"}
0005434244862	26123E	7018 594065	NATALYA KONDRATEVA	{"phone": "+70958401849"}
0005434244863	A08BB2	2766 690797	RAISA MOISEEVA	{"email": "raisamoiseeva.1965@postgrespro.ru", "phone": "+70556788885"}
0005434244864	07A9FF	8509 861258	DENIS PAVLOV	{"email": "dpavlov22061969@postgrespro.ru", "phone": "+70684517659"}
0005434244865	F98C9E	7635 932864	DARYA ZAKHAROVA	{"phone": "+70906753889"}
0005434244866	B72BF4	7472 746672	KSENIYA ORLOVA	{"phone": "+70898667033"}
0005434244867	B72BF4	1616 522341	TATYANA CHERNOVA	{"email": "chernovatatyana_17051979@postgrespro.ru", "phone": "+70757309075"}
0005434244868	1BAAE4	6185 147714	DMITRIY DENISOV	{"email": "denisovdmitriy111987@postgrespro.ru", "phone": "+70857164231"}
0005434244869	1BAAE4	4452 679421	VLADISLAV VOLKOV	{"email": "volkov.vladislav-101970@postgrespro.ru", "phone": "+70519365312"}
0005434244870	22C7DD	1244 131817	ZOYA TIKHONOVA	{"email": "zoyatikhonova03081968@postgrespro.ru", "phone": "+70519548146"}
0005434244871	BF1582	1895 748045	SERGEY GAVRILOV	{"email": "sergey.gavrilov.1970@postgrespro.ru", "phone": "+70303473570"}
0005434244872	BF1582	4259 339441	ARTEM MELNIKOV	{"phone": "+70217587526"}
0005434244873	D0C673	2469 926281	EVGENIY ISAEV	{"phone": "+70334058379"}
0005434244874	D0C673	8826 630079	ALEKSEY IVANOV	{"email": "ivanov.a.26081970@postgrespro.ru", "phone": "+70603378567"}
0005434244875	EC0A1B	3534 204763	NIKOLAY GUSEV	{"email": "n-gusev-1983@postgrespro.ru", "phone": "+70692038644"}
0005434244876	10A087	2990 557771	ALEKSANDR IVANOV	{"phone": "+70675633468"}
0005434244877	78960F	1347 850201	YURIY SAVELEV	{"phone": "+70047364827"}
0005434244878	287302	2947 481336	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir-21101977@postgrespro.ru", "phone": "+70342904807"}
0005434244879	DD8276	7901 365129	ANDREY KRASNOV	{"email": "krasnova.111987@postgrespro.ru", "phone": "+70165588432"}
0005434244880	5B5712	3811 030396	VLADIMIR POPOV	{"phone": "+70960468551"}
0005434244881	840254	2539 103083	REGINA SERGEEVA	{"phone": "+70404094615"}
0005434244882	C2B0CC	1363 586485	MAKSIM FROLOV	{"email": "frolov_maksim-071979@postgrespro.ru", "phone": "+70138736763"}
0005434244883	C2B0CC	9206 748631	ILYA PETROV	{"phone": "+70084679918"}
0005434244884	E92121	9065 887605	VYACHESLAV SERGEEV	{"email": "vyacheslavsergeev1969@postgrespro.ru", "phone": "+70258339679"}
0005434244885	12D98E	0608 752854	EKATERINA VASILEVA	{"email": "ekaterina.vasileva.1959@postgrespro.ru", "phone": "+70872172006"}
0005434244886	12D98E	5239 107977	GALINA FEDOROVA	{"email": "gfedorova19061959@postgrespro.ru", "phone": "+70145234323"}
0005434244887	2A142A	1287 208215	VERONIKA PETROVA	{"email": "petrova.veronika-061983@postgrespro.ru", "phone": "+70149516430"}
0005434244888	2A142A	6874 688239	ALEKSEY ISAEV	{"email": "isaev_aleksey-26041962@postgrespro.ru", "phone": "+70168280213"}
0005434244889	2A142A	0392 477696	ROMAN ZAKHAROV	{"email": "r.zakharov1976@postgrespro.ru", "phone": "+70773159646"}
0005434244890	637598	2993 689151	ALEKSANDR NIKITIN	{"phone": "+70756392571"}
0005434244891	0D96A3	3723 081065	ANATOLIY KUZMIN	{"email": "anatoliy-kuzmin1974@postgrespro.ru", "phone": "+70256677971"}
0005434244892	0D96A3	3848 350086	ZINAIDA KUZNECOVA	{"phone": "+70429504313"}
0005434244893	64B104	2229 768460	VLADISLAV ZAKHAROV	{"email": "zakharov.v24011980@postgrespro.ru", "phone": "+70076894368"}
0005434244894	8CC08E	9289 178932	KHALIDA DENISOVA	{"phone": "+70829515806"}
0005434244895	8CC08E	2738 922810	LYUDMILA RYABOVA	{"phone": "+70152566973"}
0005434244896	4620F4	9949 336169	ELENA TIKHONOVA	{"email": "elena_tikhonova_06111982@postgrespro.ru", "phone": "+70118270985"}
0005434244897	4620F4	2192 104571	YURIY IVANOV	{"phone": "+70038676119"}
0005434244898	44B1EB	2453 132871	EVGENIY FOMIN	{"phone": "+70897086472"}
0005434244899	44B1EB	3290 778628	IRINA SOROKINA	{"phone": "+70112493779"}
0005434244900	8F6EE3	7368 687013	IRINA VASILEVA	{"email": "vasileva_i.1975@postgrespro.ru", "phone": "+70466757883"}
0005434244901	8F6EE3	1462 274965	NINA MAKAROVA	{"phone": "+70821197406"}
0005434244902	05E8A0	5624 880744	RIMMA KOLESNIKOVA	{"email": "rimma.kolesnikova.1984@postgrespro.ru", "phone": "+70419621542"}
0005434244903	A81D5C	9641 703560	DANIIL GERASIMOV	{"email": "gerasimovdaniil_08031974@postgrespro.ru", "phone": "+70493243727"}
0005434244904	331A33	7653 921960	SVETLANA SEMENOVA	{"email": "svetlana_semenova091963@postgrespro.ru", "phone": "+70351079950"}
0005434244905	331A33	5629 939557	MARAT MAKAROV	{"email": "marat-makarov-1977@postgrespro.ru", "phone": "+70140303169"}
0005434244906	615468	6586 229290	YULIYA AFANASEVA	{"phone": "+70577318902"}
0005434244907	C25AEE	1009 914638	ELENA LEBEDEVA	{"email": "lebedeva.elena-31051976@postgrespro.ru", "phone": "+70818630949"}
0005434244908	DA25EB	7790 057664	VALENTINA POLYAKOVA	{"phone": "+70824804178"}
0005434244909	DA25EB	7062 247078	NIKITA KOZLOV	{"phone": "+70034641202"}
0005434244910	C31E19	9639 929386	TAMARA FOMINA	{"phone": "+70015243607"}
0005434244911	6324B1	1630 263148	ELENA ZOTOVA	{"phone": "+70526893634"}
0005434244912	6324B1	3953 455248	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev.031966@postgrespro.ru", "phone": "+70176600706"}
0005434244913	C922B6	3459 945997	SHAMIL KARPOV	{"email": "karpov_s031983@postgrespro.ru", "phone": "+70898170285"}
0005434244914	63109A	3991 395718	DMITRIY ANDREEV	{"phone": "+70007960795"}
0005434244915	FB50A7	2713 171531	KONSTANTIN AFANASEV	{"phone": "+70571770427"}
0005434244916	6A7A53	4899 165224	SVETLANA TITOVA	{"phone": "+70741376188"}
0005434244917	2BE4B5	5022 675577	FEDOR MOROZOV	{"phone": "+70270801527"}
0005434244918	461415	6219 109654	NIKOLAY NAZAROV	{"phone": "+70832316744"}
0005434244919	435BD2	2739 977792	OLGA KUDRYASHOVA	{"email": "okudryashova-1969@postgrespro.ru", "phone": "+70485959442"}
0005434244920	7A09CE	4632 264225	SERGEY PAVLOV	{"email": "pavlov_sergey061964@postgrespro.ru", "phone": "+70814563354"}
0005434244921	7A09CE	0363 916804	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a_02061966@postgrespro.ru", "phone": "+70152645261"}
0005434244922	F3B04F	1902 628815	VIKTORIYA MOROZOVA	{"phone": "+70160275356"}
0005434244923	4EE1EE	9926 449908	ELENA GORBUNOVA	{"phone": "+70897434537"}
0005434244924	4EE1EE	8355 749099	TAMARA LUKYANOVA	{"phone": "+70855912352"}
0005434244925	7608BD	5410 047268	VLADIMIR MIRONOV	{"email": "v_mironov_071969@postgrespro.ru", "phone": "+70150698527"}
0005434244926	E600A3	2912 954839	DMITRIY NAUMOV	{"email": "naumovd.111972@postgrespro.ru", "phone": "+70819525549"}
0005434244927	E600A3	7673 809634	ALEKSEY MOROZOV	{"phone": "+70268725101"}
0005434244928	6F6354	6086 758629	VLADIMIR BONDARENKO	{"email": "bondarenko_v_23021977@postgrespro.ru", "phone": "+70232792474"}
0005434244929	2901E1	5769 055997	ANTONINA NOVIKOVA	{"phone": "+70152633905"}
0005434244930	2901E1	0446 497099	NATALYA GERASIMOVA	{"phone": "+70374805843"}
0005434244931	2901E1	6323 571243	LARISA FROLOVA	{"email": "frolova.larisa.01031982@postgrespro.ru", "phone": "+70040812483"}
0005434244932	242069	9423 552818	VIKTORIYA PETROVA	{"email": "petrova-viktoriya.1976@postgrespro.ru", "phone": "+70410590082"}
0005434244933	09CB7B	9193 886519	VIKTOR VASILEV	{"phone": "+70255454731"}
0005434244934	09CB7B	9853 136034	GALINA KOROLEVA	{"email": "g.koroleva.1972@postgrespro.ru", "phone": "+70048630640"}
0005434244935	A3FC39	7951 809580	NINA ORLOVA	{"email": "nina-orlova-1963@postgrespro.ru", "phone": "+70979911681"}
0005434244936	91AC9D	6396 960547	NATALYA ANTONOVA	{"phone": "+70887867492"}
0005434244937	91AC9D	3207 932374	VYACHESLAV MOISEEV	{"email": "moiseev_vyacheslav.07021980@postgrespro.ru", "phone": "+70573369685"}
0005434244938	93C062	6702 861640	ZINAIDA MOISEEVA	{"email": "z_moiseeva1969@postgrespro.ru", "phone": "+70836078543"}
0005434244939	680844	6463 174214	VALERIY KRASNOV	{"email": "valeriy.krasnov-20091978@postgrespro.ru", "phone": "+70859423783"}
0005434244940	297A74	0397 831518	ALEKSANDR YAKOVLEV	{"phone": "+70167703482"}
0005434244941	03A8BF	8266 895668	IRINA NIKOLAEVA	{"email": "i.nikolaeva_23051975@postgrespro.ru", "phone": "+70095135646"}
0005434244942	A668FE	9054 156145	ELENA IVANOVA	{"phone": "+70728667824"}
0005434244943	848013	7835 803308	SERGEY KUZMIN	{"email": "sergey_kuzmin-071972@postgrespro.ru", "phone": "+70286838427"}
0005434244944	5E5803	9794 662542	IRINA ARKHIPOVA	{"email": "arkhipova.i.29061973@postgrespro.ru", "phone": "+70691129488"}
0005434244945	878F7C	2826 025420	SERGEY NIKITIN	{"email": "sergeynikitin-1981@postgrespro.ru", "phone": "+70241238183"}
0005434244946	878F7C	6923 473289	EVGENIY TIMOFEEV	{"phone": "+70635295195"}
0005434244947	70FB10	4899 582731	EKATERINA SERGEEVA	{"email": "e_sergeeva.1961@postgrespro.ru", "phone": "+70980558369"}
0005434244948	70FB10	6187 489518	NATALIYA MEDVEDEVA	{"phone": "+70966457117"}
0005434244949	19F3DF	0655 351157	OLEG NIKITIN	{"phone": "+70106013854"}
0005434244950	19F3DF	7831 782196	VIKTORIYA POPOVA	{"email": "popovav031958@postgrespro.ru", "phone": "+70458251643"}
0005434244951	860B05	1211 537512	IVAN IVANOV	{"email": "ivanovi.1967@postgrespro.ru", "phone": "+70810683954"}
0005434244952	DD6439	5435 025867	TAMARA KUZMINA	{"email": "tamara.kuzmina-1972@postgrespro.ru", "phone": "+70247369172"}
0005434244953	DD6439	7195 630077	ALEKSANDR STEPANOV	{"phone": "+70507286839"}
0005434244954	DD6439	6428 219314	KONSTANTIN VLASOV	{"email": "vlasov-k1975@postgrespro.ru", "phone": "+70892560731"}
0005434244955	1510E0	4761 475875	EGOR VOROBEV	{"email": "vorobev_e-1969@postgrespro.ru", "phone": "+70964188845"}
0005434244956	5A6E2A	3715 743574	VITALIY BONDARENKO	{"phone": "+70101294318"}
0005434244957	5A6E2A	8240 253960	VLADISLAV NAUMOV	{"phone": "+70299661433"}
0005434244958	5A6E2A	5191 292018	SERGEY SMIRNOV	{"phone": "+70679033174"}
0005434244959	5A6E2A	1013 946631	GALINA KOROLEVA	{"email": "galina.koroleva.1973@postgrespro.ru", "phone": "+70599819057"}
0005434244960	471B0C	6537 218879	OLESYA ZOTOVA	{"email": "o.zotova_081968@postgrespro.ru", "phone": "+70526188602"}
0005434244961	471B0C	9322 904225	RIMMA KUZNECOVA	{"phone": "+70806613470"}
0005434244962	D89769	3660 731198	ELENA AFANASEVA	{"phone": "+70429128640"}
0005434244963	BBAFF4	3725 466256	VADIM CHERNOV	{"phone": "+70104544319"}
0005434244964	CDFF0A	7860 522133	TIGRAN ZHURAVLEV	{"phone": "+70588086439"}
0005434244965	ECD076	1377 515417	VLADIMIR AFANASEV	{"email": "afanasev.v-19101972@postgrespro.ru", "phone": "+70141806835"}
0005434244966	0A0183	1019 393759	MIKHAIL SIDOROV	{"phone": "+70585690166"}
0005434244967	1C74CD	0792 689219	ALEKSANDR KUZNECOV	{"email": "kuznecova-061960@postgrespro.ru", "phone": "+70501907031"}
0005434244968	C3B3F0	1490 014718	ANTONINA ISAEVA	{"email": "aisaeva021969@postgrespro.ru", "phone": "+70436057089"}
0005434244969	C3B3F0	5437 109388	VALENTINA KOROLEVA	{"email": "koroleva_valentina1984@postgrespro.ru", "phone": "+70032317848"}
0005434244970	7F308F	1595 550358	VASILIY SHEVCHENKO	{"phone": "+70504178884"}
0005434244971	7F308F	8667 582275	VLADIMIR SHEVCHENKO	{"email": "shevchenko.v22031984@postgrespro.ru", "phone": "+70228531925"}
0005434244972	554183	8481 981528	ARTEM KUZMIN	{"phone": "+70436648554"}
0005434244973	554183	1611 397496	MAKSIM MAKSIMOV	{"email": "maksimov_maksim1968@postgrespro.ru", "phone": "+70812137307"}
0005434244974	B5BE64	1989 852776	VLADIMIR BORISOV	{"email": "borisov-vladimir-1963@postgrespro.ru", "phone": "+70927503099"}
0005434244975	B5BE64	2046 014655	ALEKSEY PAVLOV	{"phone": "+70918718733"}
0005434244976	625238	6630 886548	DARYA MAKAROVA	{"phone": "+70231355690"}
0005434244977	67EA4A	7089 459734	IVAN IVANOV	{"email": "ivan_ivanov_071971@postgrespro.ru", "phone": "+70190727680"}
0005434244978	3A7495	5960 346711	IGNAT BELOV	{"email": "belov.i.1966@postgrespro.ru", "phone": "+70682323008"}
0005434244979	3A7495	0939 192942	ELENA DANILOVA	{"email": "danilovaelena.071979@postgrespro.ru", "phone": "+70729386349"}
0005434244980	82E3FC	9630 220478	OLGA FROLOVA	{"phone": "+70625335236"}
0005434244981	E31F40	3500 413849	NATALYA DMITRIEVA	{"email": "n.dmitrieva-25021978@postgrespro.ru", "phone": "+70190544828"}
0005434244982	17901D	2590 788791	YULIYA TIKHONOVA	{"email": "ytikhonova-011968@postgrespro.ru", "phone": "+70055578592"}
0005434244983	8E23F8	1785 933670	SVETLANA FILATOVA	{"phone": "+70589107092"}
0005434244984	A296AD	5579 349264	ALEKSANDR GERASIMOV	{"phone": "+70023654106"}
0005434244985	A296AD	6913 781624	EKATERINA TITOVA	{"email": "titova.ekaterina-1964@postgrespro.ru", "phone": "+70949022354"}
0005434244986	719BCF	4050 331709	ROMAN VASILEV	{"email": "roman-vasilev_01011962@postgrespro.ru", "phone": "+70985526939"}
0005434244987	450970	9080 748270	LYUDMILA ANISIMOVA	{"phone": "+70440514147"}
0005434244988	450970	7505 363484	TATYANA LAZAREVA	{"email": "lazareva-t1970@postgrespro.ru", "phone": "+70959809344"}
0005434244989	B629F4	0604 571564	SERGEY VASILEV	{"email": "sergeyvasilev_24071973@postgrespro.ru", "phone": "+70255346983"}
0005434244990	B629F4	4528 474237	STEPAN OSIPOV	{"phone": "+70787915826"}
0005434244991	AAB733	2054 906517	LIDIYA NAUMOVA	{"email": "naumova_lidiya_1975@postgrespro.ru", "phone": "+70338443822"}
0005434244992	AAB733	7467 141654	NINA SERGEEVA	{"email": "n-sergeeva.28041969@postgrespro.ru", "phone": "+70421468743"}
0005434244993	0C5835	1945 043239	ILYA TIKHONOV	{"phone": "+70835308559"}
0005434244994	0C5835	4047 488910	OKSANA PAVLOVA	{"email": "pavlova.o111970@postgrespro.ru", "phone": "+70039579801"}
0005434244995	921813	5988 067796	VLADIMIR NOVIKOV	{"phone": "+70378763667"}
0005434244996	9547A8	5210 215714	ALBERT GORBUNOV	{"phone": "+70363971487"}
0005434244997	ADC256	4931 885503	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr18021962@postgrespro.ru", "phone": "+70834506620"}
0005434244998	62116D	7006 159097	ELENA SIDOROVA	{"email": "sidorova_e-17011972@postgrespro.ru", "phone": "+70215210389"}
0005434244999	112431	3263 533512	LIDIYA VASILEVA	{"email": "lvasileva.22041968@postgrespro.ru", "phone": "+70041492389"}
0005434245000	8CF19F	7929 859139	MIKHAIL ABRAMOV	{"email": "abramov-mikhail.1979@postgrespro.ru", "phone": "+70156484652"}
0005434245001	8CF19F	1710 534573	ANASTASIYA KONDRATEVA	{"email": "a_kondrateva_1965@postgrespro.ru", "phone": "+70204616874"}
0005434245002	5741D9	3553 435371	IGOR KUDRYASHOV	{"email": "igor.kudryashov061968@postgrespro.ru", "phone": "+70591301496"}
0005434245003	5257EE	7729 932787	ANASTASIYA MELNIKOVA	{"email": "melnikova-anastasiya101969@postgrespro.ru", "phone": "+70854011152"}
0005434245004	5257EE	2381 014816	NIKOLAY ZHUKOV	{"email": "nikolay.zhukov_121978@postgrespro.ru", "phone": "+70652533096"}
0005434245005	95B108	9706 794144	ELENA CHERNOVA	{"email": "chernovae_1980@postgrespro.ru", "phone": "+70027724361"}
0005434245006	930CBD	5474 912336	OLEG MAKSIMOV	{"email": "o-maksimov30111977@postgrespro.ru", "phone": "+70679889412"}
0005434245007	930CBD	0140 688176	LYUDMILA DANILOVA	{"email": "lyudmila_danilova.081976@postgrespro.ru", "phone": "+70985318157"}
0005434245008	C29090	6171 901104	VIKTOR MOROZOV	{"email": "viktor-morozov-1966@postgrespro.ru", "phone": "+70890623404"}
0005434245009	A9EF8A	1388 765783	VIKTOR NIKITIN	{"email": "nikitinv17011971@postgrespro.ru", "phone": "+70754976100"}
0005434245010	6C60C6	3797 706329	IRINA DAVYDOVA	{"email": "davydova.irina_091971@postgrespro.ru", "phone": "+70402662731"}
0005434245011	7E0CDA	3501 215443	ILYA ROMANOV	{"phone": "+70023380212"}
0005434245012	7E0CDA	5636 145894	ALEKSEY IVANOV	{"email": "aleksey-ivanov.051971@postgrespro.ru", "phone": "+70806576740"}
0005434245013	22100B	5237 522812	DMITRIY KUZMIN	{"email": "dmitriykuzmin.20041970@postgrespro.ru", "phone": "+70992037425"}
0005434245014	8B9979	6287 623367	ALBINA IVANOVA	{"email": "ivanova_a-1984@postgrespro.ru", "phone": "+70058708837"}
0005434245015	5B83FA	3176 792241	ELIZAVETA KOZLOVA	{"email": "kozlova_e_1973@postgrespro.ru", "phone": "+70386928062"}
0005434245016	CCD525	3984 592237	YURIY KOZLOV	{"phone": "+70571166861"}
0005434245017	CCD525	7991 592440	KIRILL FROLOV	{"email": "frolovkirill.031984@postgrespro.ru", "phone": "+70793204834"}
0005434245018	355B62	5568 908685	IRINA MALYSHEVA	{"phone": "+70133738275"}
0005434245130	87562E	4592 264573	TATYANA EGOROVA	{"phone": "+70865395298"}
0005434245019	355B62	5233 697853	ALEKSEY DAVYDOV	{"email": "a.davydov-23011970@postgrespro.ru", "phone": "+70702866897"}
0005434245020	C07E51	2895 196477	ALEKSANDR ANDREEV	{"phone": "+70779891703"}
0005434245021	101567	5459 523060	ELENA SOLOVEVA	{"phone": "+70985887449"}
0005434245022	5ED221	4206 764856	MIKHAIL KUZNECOV	{"phone": "+70025939345"}
0005434245023	61762A	1598 018183	VIKTOR ISAEV	{"phone": "+70722847857"}
0005434245024	B651F6	8805 596078	SERGEY GORBUNOV	{"email": "gorbunovs_031968@postgrespro.ru", "phone": "+70058320597"}
0005434245025	B651F6	8006 085409	ALEKSANDR ROMANOV	{"phone": "+70094370544"}
0005434245026	3DC4A0	7999 500649	ALEKSEY KUZNECOV	{"phone": "+70205210552"}
0005434245027	00A968	3725 634294	TATYANA CHERNOVA	{"email": "tatyana-chernova_111977@postgrespro.ru", "phone": "+70685696788"}
0005434245028	197A38	2168 845743	NIKOLAY NAUMOV	{"phone": "+70326281436"}
0005434245029	6055F5	2648 617006	YANA ZAYCEVA	{"phone": "+70046749239"}
0005434245030	6055F5	7189 529930	FILIPP KAZAKOV	{"email": "kazakov.filipp-071969@postgrespro.ru", "phone": "+70145907182"}
0005434245031	0CC396	9806 610453	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey_101981@postgrespro.ru", "phone": "+70933166367"}
0005434245032	03F933	6657 640445	ALEKSANDR VLASOV	{"email": "vlasovaleksandr_091972@postgrespro.ru", "phone": "+70506379413"}
0005434245033	C33D95	6446 689569	ANATOLIY ILIN	{"email": "anatoliy-ilin_021961@postgrespro.ru", "phone": "+70703269432"}
0005434245034	C7DBE2	5464 358013	SVETLANA PETROVA	{"email": "svetlana_petrova_051981@postgrespro.ru", "phone": "+70823734397"}
0005434245035	0C8939	2590 367469	EVDOKIYA KALININA	{"email": "evdokiya_kalinina-1972@postgrespro.ru", "phone": "+70080034602"}
0005434245036	837694	6053 783955	ANASTASIYA RODIONOVA	{"phone": "+70599472401"}
0005434245037	837694	6967 929633	VLADIMIR KRASNOV	{"phone": "+70534853008"}
0005434245038	AA385B	3241 244616	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr041969@postgrespro.ru", "phone": "+70159546060"}
0005434245039	AA385B	7014 895702	NINA ILINA	{"email": "n-ilina-111970@postgrespro.ru", "phone": "+70038618744"}
0005434245040	65ECB4	5977 568821	VALENTINA KOROLEVA	{"phone": "+70370756716"}
0005434245041	155039	5010 109853	YURIY SOLOVEV	{"email": "ysolovev011980@postgrespro.ru", "phone": "+70655648208"}
0005434245042	FD754E	9086 389907	VYACHESLAV MOROZOV	{"email": "v-morozov-051968@postgrespro.ru", "phone": "+70966721690"}
0005434245043	6822FF	2388 057002	ANATOLIY SMIRNOV	{"phone": "+70550624923"}
0005434245044	7462E4	4553 333058	OLEG DMITRIEV	{"phone": "+70802748783"}
0005434245045	87DF8E	4573 168061	ARINA ROMANOVA	{"email": "romanovaarina.121967@postgrespro.ru", "phone": "+70663348873"}
0005434245046	77CC60	3470 210068	VERA POPOVA	{"phone": "+70221462518"}
0005434245047	77CC60	6457 580242	ILYA TIKHONOV	{"phone": "+70333579248"}
0005434245048	9038BE	0029 351448	VLADIMIR ANTONOV	{"phone": "+70965867366"}
0005434245049	9038BE	4851 354384	ALEKSEY GUSEV	{"phone": "+70860453028"}
0005434245050	43B054	0321 765809	SERGEY NAZAROV	{"email": "nazarov-s.031977@postgrespro.ru", "phone": "+70334939756"}
0005434245051	C70451	7442 980827	DANIIL KUZMIN	{"email": "d.kuzmin-021972@postgrespro.ru", "phone": "+70268768322"}
0005434245052	627ECF	3468 802920	YULIYA PAVLOVA	{"phone": "+70777153571"}
0005434245053	9A3203	4832 348483	NATALYA VOLKOVA	{"email": "nvolkova-021972@postgrespro.ru", "phone": "+70509970732"}
0005434245054	A8C62D	9593 304682	GALINA ZAYCEVA	{"email": "galinazayceva_081979@postgrespro.ru", "phone": "+70459582288"}
0005434245055	BC7248	0222 717937	ANATOLIY SMIRNOV	{"email": "smirnov-anatoliy14011968@postgrespro.ru", "phone": "+70618813636"}
0005434245056	BC7248	2551 965457	YULIYA ORLOVA	{"email": "y.orlova01111975@postgrespro.ru", "phone": "+70008249158"}
0005434245057	8EEE36	5580 471720	DMITRIY VASILEV	{"phone": "+70416607786"}
0005434245058	8EEE36	7543 466321	VIKTOR TARASOV	{"email": "v_tarasov_10021976@postgrespro.ru", "phone": "+70169352357"}
0005434245059	685375	3219 883646	MARINA AKIMOVA	{"email": "makimova.31051961@postgrespro.ru", "phone": "+70353078254"}
0005434245060	685375	0464 360078	MARIYA ZAYCEVA	{"phone": "+70413575801"}
0005434245061	685375	0485 464675	KIRILL KUZMIN	{"phone": "+70152327031"}
0005434245062	9B61D7	9170 412197	VITALIY MARTYNOV	{"email": "martynov-v.29061964@postgrespro.ru", "phone": "+70439941443"}
0005434245063	9B61D7	1956 755234	RUSLAN VOLKOV	{"email": "volkov-r.31081975@postgrespro.ru", "phone": "+70947595266"}
0005434245064	43E5F9	0507 143696	STANISLAV VOLKOV	{"email": "stanislav_volkov.1969@postgrespro.ru", "phone": "+70243091074"}
0005434245065	43E5F9	2020 660791	SERGEY KARPOV	{"phone": "+70727413658"}
0005434245066	43E5F9	3676 033162	ALEKSEY BONDARENKO	{"phone": "+70724350104"}
0005434245067	E5983F	8863 992444	TATYANA DMITRIEVA	{"email": "dmitrievatatyana.041964@postgrespro.ru", "phone": "+70351020992"}
0005434245068	93740E	0930 917845	VIKTOR MIRONOV	{"phone": "+70486292170"}
0005434245069	93740E	6412 197695	YURIY NIKOLAEV	{"phone": "+70205796884"}
0005434245070	BE9A3F	7713 372973	SERGEY SERGEEV	{"phone": "+70501866009"}
0005434245071	BE9A3F	5445 548024	SERGEY FROLOV	{"email": "frolov.sergey.121967@postgrespro.ru", "phone": "+70559712094"}
0005434245072	82B4F6	3331 785758	OLGA MIRONOVA	{"email": "mironova.o_031964@postgrespro.ru", "phone": "+70216305413"}
0005434245073	CE758F	9532 013122	PAVEL OSIPOV	{"phone": "+70918265854"}
0005434245074	CE758F	5259 807483	ANDREY BORISOV	{"phone": "+70317711337"}
0005434245075	6A05D8	4620 446457	OLEG PAVLOV	{"email": "opavlov-1966@postgrespro.ru", "phone": "+70594003287"}
0005434245076	6A05D8	4882 014300	NIKOLAY POPOV	{"email": "nikolay_popov-031973@postgrespro.ru", "phone": "+70352105099"}
0005434245077	742C27	7617 260448	KIRILL MIRONOV	{"email": "mironov_k-021959@postgrespro.ru", "phone": "+70797311046"}
0005434245078	E080EA	5845 560897	ANNA AFANASEVA	{"phone": "+70020537702"}
0005434245079	A7F6DD	0477 739804	SERGEY GAVRILOV	{"phone": "+70002239618"}
0005434245080	A7F6DD	4133 645542	VLADIMIR RODIONOV	{"email": "v_rodionov.021971@postgrespro.ru", "phone": "+70804296337"}
0005434245081	E1D06F	2608 476798	TAMARA SCHERBAKOVA	{"email": "tamarascherbakova.021971@postgrespro.ru", "phone": "+70255245346"}
0005434245082	8B7D55	5356 511189	RUSLAN PETROV	{"email": "ruslanpetrov061950@postgrespro.ru", "phone": "+70075281272"}
0005434245083	2160D8	1814 357434	SOFYA BORISOVA	{"phone": "+70783505498"}
0005434245084	FC46D9	5126 779365	RAISA KRASNOVA	{"email": "r-krasnova-10081960@postgrespro.ru", "phone": "+70132131839"}
0005434245085	E90941	9579 579612	NATALYA TARASOVA	{"phone": "+70316140730"}
0005434245086	3990D2	9601 674699	OLGA FROLOVA	{"email": "o_frolova.03051982@postgrespro.ru", "phone": "+70404879379"}
0005434245087	D43642	6897 141772	INNA RODIONOVA	{"phone": "+70804050037"}
0005434245088	8D7CBE	4051 553696	PETR SOLOVEV	{"email": "petr_solovev1974@postgrespro.ru", "phone": "+70498163624"}
0005434245089	8D7CBE	6897 472737	VALENTINA VOROBEVA	{"email": "vvorobeva021960@postgrespro.ru", "phone": "+70039628611"}
0005434245090	E5E682	4819 451160	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr.101960@postgrespro.ru", "phone": "+70793290320"}
0005434245091	A67AAB	0205 179154	ANASTASIYA DENISOVA	{"email": "anastasiya_denisova_1979@postgrespro.ru", "phone": "+70130954536"}
0005434245092	A67AAB	6922 316891	DMITRIY VOROBEV	{"email": "vorobevd.051974@postgrespro.ru", "phone": "+70861034017"}
0005434245093	B9ACA2	2070 414898	SVETLANA ERMAKOVA	{"phone": "+70387055043"}
0005434245094	EB98B3	4170 237134	OLEG EGOROV	{"email": "egorov.oleg1983@postgrespro.ru", "phone": "+70998702530"}
0005434245095	622268	5067 870581	VLADIMIR ZAKHAROV	{"phone": "+70840807943"}
0005434245096	9C761A	0180 496068	GENNADIY POPOV	{"phone": "+70959503579"}
0005434245097	499111	6586 937839	LARISA FROLOVA	{"email": "frolova_l-091972@postgrespro.ru", "phone": "+70897512548"}
0005434245098	A1E0C1	6176 064240	SERGEY ALEKSEEV	{"phone": "+70180418654"}
0005434245099	A1E0C1	0026 659915	LYUDMILA TARASOVA	{"email": "lyudmila-tarasova.011976@postgrespro.ru", "phone": "+70503650081"}
0005434245100	2E6BDF	8167 306617	IRINA AKIMOVA	{"email": "irina-akimova1964@postgrespro.ru", "phone": "+70766908790"}
0005434245101	2E6BDF	3167 589442	EKATERINA IVANOVA	{"email": "ekaterinaivanova01101989@postgrespro.ru", "phone": "+70190417133"}
0005434245102	0289F2	8068 954165	EVGENIY KUZNECOV	{"phone": "+70024016632"}
0005434245103	0289F2	7947 225558	DARYA GORBUNOVA	{"phone": "+70750894822"}
0005434245104	67F993	8735 016203	GRIGORIY NAUMOV	{"email": "naumov-g24041975@postgrespro.ru", "phone": "+70155613993"}
0005434245105	E6EBC0	9493 415773	ANDREY ALEKSEEV	{"phone": "+70125191196"}
0005434245106	3B40DA	8244 070326	ANTON DMITRIEV	{"email": "anton_dmitriev.1962@postgrespro.ru", "phone": "+70449293893"}
0005434245107	3B40DA	4934 216361	NINA PETROVA	{"email": "n_petrova_031968@postgrespro.ru", "phone": "+70672502608"}
0005434245108	EE7CC3	0244 396425	GALINA NESTEROVA	{"email": "galina_nesterova_031966@postgrespro.ru", "phone": "+70176406916"}
0005434245109	13744C	2689 818084	EKATERINA RYABOVA	{"email": "ryabova_e-13011970@postgrespro.ru", "phone": "+70440004237"}
0005434245110	13744C	9417 139610	ANDREY MAKSIMOV	{"email": "maksimov-andrey_1974@postgrespro.ru", "phone": "+70117352959"}
0005434245111	7BDF29	9545 771561	ANDREY VLASOV	{"email": "andrey.vlasov1960@postgrespro.ru", "phone": "+70758495448"}
0005434245112	7BDF29	3107 461100	VITALIY ISAEV	{"phone": "+70321683966"}
0005434245113	7BDF29	4117 977360	OLEG VOLKOV	{"email": "o_volkov_1958@postgrespro.ru", "phone": "+70218686906"}
0005434245114	333A75	2456 708032	OLGA MARTYNOVA	{"phone": "+70117632609"}
0005434245115	B807D7	7267 449321	VALENTINA ANTONOVA	{"email": "v_antonova_1960@postgrespro.ru", "phone": "+70489142760"}
0005434245116	8D2E96	9736 970800	OLGA PETROVA	{"phone": "+70884547582"}
0005434245117	8D2E96	8301 203903	ANASTASIYA KOZLOVA	{"email": "kozlova.anastasiya_101975@postgrespro.ru", "phone": "+70048257679"}
0005434245118	94598D	7728 830808	SERGEY MIRONOV	{"email": "mironov_s.16021964@postgrespro.ru", "phone": "+70444194540"}
0005434245119	94598D	0555 398608	STANISLAV GRIGOREV	{"email": "grigorevstanislav.1961@postgrespro.ru", "phone": "+70561395520"}
0005434245120	764CF4	0652 423965	TATYANA MIKHAYLOVA	{"phone": "+70654150663"}
0005434245121	764CF4	5862 432473	DANIIL SEMENOV	{"phone": "+70651407862"}
0005434245122	DBCD9B	1268 746367	OLGA KULIKOVA	{"email": "kulikovaolga.071972@postgrespro.ru", "phone": "+70714803933"}
0005434245123	A93FDE	3793 502400	ALEVTINA ISAEVA	{"phone": "+70534237586"}
0005434245124	A93FDE	5926 276069	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov-04091971@postgrespro.ru", "phone": "+70905469703"}
0005434245125	A93FDE	0724 815701	SERGEY AFANASEV	{"phone": "+70528141778"}
0005434245126	B47E7D	0137 498413	VALENTINA PAVLOVA	{"email": "valentina_pavlova_1981@postgrespro.ru", "phone": "+70838681197"}
0005434245127	071401	3376 059923	YURIY KRASNOV	{"email": "krasnov-y-101982@postgrespro.ru", "phone": "+70419192143"}
0005434245128	071401	5703 621234	ALEKSEY MOROZOV	{"phone": "+70605636547"}
0005434245129	113C8B	3434 924178	KRISTINA MAKAROVA	{"phone": "+70618085432"}
0005434245131	9E231C	2461 324457	KONSTANTIN FEDOROV	{"email": "fedorov-konstantin16091978@postgrespro.ru", "phone": "+70267106323"}
0005434245132	7A3B06	2154 982250	VITALIY SMIRNOV	{"phone": "+70520951089"}
0005434245133	198B1A	2712 248240	ELENA MELNIKOVA	{"email": "elena_melnikova.1971@postgrespro.ru", "phone": "+70001431241"}
0005434245134	198B1A	5238 267424	ELENA ZAKHAROVA	{"phone": "+70568656502"}
0005434245135	3B6AE7	4780 753686	EVGENIY MIKHAYLOV	{"phone": "+70199288936"}
0005434245136	3B6AE7	5233 519235	TAISIYA NESTEROVA	{"email": "t.nesterova-011972@postgrespro.ru", "phone": "+70903430557"}
0005434245137	0A6CDC	9270 050188	ANASTASIYA TARASOVA	{"phone": "+70275902405"}
0005434245138	191343	0218 181062	GULSHAT IVANOVA	{"phone": "+70006237243"}
0005434245139	3351B7	2515 013639	SVETLANA SOKOLOVA	{"phone": "+70576675226"}
0005434245140	3351B7	3033 206259	ALEKSANDR VOLKOV	{"email": "volkov_a_021960@postgrespro.ru", "phone": "+70272356047"}
0005434245141	6AF081	7804 125019	LYUDMILA BORISOVA	{"email": "l_borisova_1967@postgrespro.ru", "phone": "+70067460297"}
0005434245142	7C40FE	2975 047978	LYUBOV ARKHIPOVA	{"email": "arkhipova.lyubov-051979@postgrespro.ru", "phone": "+70746371451"}
0005434245143	BB491D	9322 006983	NIKOLAY FOMIN	{"email": "n.fomin-091978@postgrespro.ru", "phone": "+70227337160"}
0005434245144	BB491D	1204 484232	LIDIYA DAVYDOVA	{"email": "ldavydova1967@postgrespro.ru", "phone": "+70180547548"}
0005434245145	F0FE0C	3663 102036	ILFAT KAZAKOV	{"email": "kazakovi05091966@postgrespro.ru", "phone": "+70249368808"}
0005434245146	F0FE0C	5708 409916	EKATERINA FADEEVA	{"phone": "+70306006665"}
0005434245147	8DA3E0	7442 457471	NATALYA ALEKSEEVA	{"email": "natalyaalekseeva081973@postgrespro.ru", "phone": "+70946368742"}
0005434245148	B20C5D	8996 661409	NATALYA IVANOVA	{"email": "n_ivanova041978@postgrespro.ru", "phone": "+70407833176"}
0005434245149	B20C5D	7857 537911	DMITRIY MAKAROV	{"email": "makarov-dmitriy1977@postgrespro.ru", "phone": "+70314402283"}
0005434245150	25F24A	9119 176095	TATYANA DAVYDOVA	{"phone": "+70983243669"}
0005434245151	8F578F	1333 288157	ALEKSANDR VASILEV	{"email": "a.vasilev10101971@postgrespro.ru", "phone": "+70448590732"}
0005434245152	8F578F	3368 537916	ANTON VOLKOV	{"email": "volkov.anton17021975@postgrespro.ru", "phone": "+70111367133"}
0005434245153	8F578F	5530 453294	VALENTINA ZHUKOVA	{"phone": "+70958589666"}
0005434245154	EE8740	0859 529770	MADINA IVANOVA	{"email": "ivanova.madina_13071967@postgrespro.ru", "phone": "+70397328257"}
0005434245155	EE8740	4471 220213	NATALYA FROLOVA	{"email": "frolovanatalya_1977@postgrespro.ru", "phone": "+70958948188"}
0005434245156	DFFA48	5700 279658	ELENA ZAKHAROVA	{"email": "e.zakharova-041978@postgrespro.ru", "phone": "+70193215978"}
0005434245157	ED5767	8431 051439	DMITRIY KUZNECOV	{"phone": "+70605733279"}
0005434245158	50EAC6	3489 717051	ALEKSANDR ZAYCEV	{"email": "a.zaycev02111974@postgrespro.ru", "phone": "+70496946151"}
0005434245159	1608E5	0766 022409	ALEKSANDRA POPOVA	{"email": "popova_a_29051971@postgrespro.ru", "phone": "+70137428208"}
0005434245160	1608E5	2571 911481	VERA MELNIKOVA	{"phone": "+70567892727"}
0005434245161	7689DC	2498 701536	OLGA PAVLOVA	{"phone": "+70606211987"}
0005434245162	E1CE11	1449 168420	ALEKSANDR GUSEV	{"phone": "+70499188260"}
0005434245163	44B559	6781 236611	VASILIY SEMENOV	{"email": "semenov-v1968@postgrespro.ru", "phone": "+70735275356"}
0005434245164	44B559	3066 667816	ALEKSEY SCHERBAKOV	{"phone": "+70803590157"}
0005434245165	4BC448	5306 850049	VALENTINA AFANASEVA	{"email": "afanasevav_1978@postgrespro.ru", "phone": "+70904363053"}
0005434245166	3860CB	2604 694892	ELENA VOROBEVA	{"email": "e.vorobeva.13041969@postgrespro.ru", "phone": "+70737291370"}
0005434245167	443A67	3702 182240	NADEZHDA KUZNECOVA	{"phone": "+70653385600"}
0005434245168	9AA8D3	8282 587078	MARIYA KUZNECOVA	{"email": "kuznecova.mariya041981@postgrespro.ru", "phone": "+70200565839"}
0005434245169	9AA8D3	4415 924193	PETR NAUMOV	{"phone": "+70994743713"}
0005434245170	2C0100	6825 242699	TATYANA KISELEVA	{"phone": "+70787376404"}
0005434245171	663BB3	8834 652224	NINA NIKIFOROVA	{"email": "nnikiforova-20091973@postgrespro.ru", "phone": "+70160214363"}
0005434245172	663BB3	0904 411314	VALERIY BONDARENKO	{"phone": "+70036926076"}
0005434245173	56008F	1937 207869	PETR ANDREEV	{"phone": "+70175316987"}
0005434245174	48ED8A	9686 771537	DARYA KUDRYASHOVA	{"email": "kudryashova_d.051969@postgrespro.ru", "phone": "+70981464479"}
0005434245175	48ED8A	5799 810097	ANDREY YAKOVLEV	{"phone": "+70083104471"}
0005434245176	48ED8A	4774 919207	SERGEY AFANASEV	{"email": "s_afanasev15111964@postgrespro.ru", "phone": "+70781646857"}
0005434245177	F3C9A2	1688 774524	LYUBOV CHERNOVA	{"email": "lyubov_chernova061967@postgrespro.ru", "phone": "+70784752288"}
0005434245178	F3C9A2	2654 365481	EVGENIY RODIONOV	{"email": "evgeniy_rodionov1961@postgrespro.ru", "phone": "+70883272592"}
0005434245179	F3C9A2	1381 455884	RASHID BORISOV	{"phone": "+70288129755"}
0005434245180	5338CE	5187 776247	LYUDMILA ZHURAVLEVA	{"email": "l.zhuravleva_1973@postgrespro.ru", "phone": "+70104293507"}
0005434245181	5338CE	9383 397542	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.s1975@postgrespro.ru", "phone": "+70674950282"}
0005434245182	BEB6A8	9434 942436	LYUBOV YAKOVLEVA	{"email": "yakovleva-lyubov08101970@postgrespro.ru", "phone": "+70424701646"}
0005434245183	39A187	9476 331139	ALEKSANDR NAZAROV	{"email": "nazarov_a15031968@postgrespro.ru", "phone": "+70396385640"}
0005434245184	00B45B	5538 069669	TIMUR BARANOV	{"email": "baranov.t-09061969@postgrespro.ru", "phone": "+70124783680"}
0005434245185	4CF274	2494 378764	ROMAN NIKITIN	{"email": "nikitin_roman_03051975@postgrespro.ru", "phone": "+70435717193"}
0005434245186	040E85	4005 005213	VALERIYA POPOVA	{"email": "popova-valeriya1968@postgrespro.ru", "phone": "+70452453178"}
0005434245187	040E85	1469 722471	DAVID MAKSIMOV	{"phone": "+70883135885"}
0005434245188	DE54E9	5939 510027	NATALIYA SAVELEVA	{"phone": "+70106127674"}
0005434245189	DE54E9	3692 107569	VIKTORIYA KUDRYASHOVA	{"email": "kudryashovav-1967@postgrespro.ru", "phone": "+70937242995"}
0005434245190	0A5FD9	6054 734945	MARIYA KONOVALOVA	{"email": "m-konovalova1972@postgrespro.ru", "phone": "+70543779625"}
0005434245191	CD8B2C	3935 190543	ILYA SMIRNOV	{"email": "i_smirnov.1962@postgrespro.ru", "phone": "+70821334047"}
0005434245192	FCE027	1448 373387	ALEKSANDRA ANDREEVA	{"phone": "+70768168039"}
0005434245193	90DE34	3327 436462	OLGA VASILEVA	{"phone": "+70756064901"}
0005434245194	90DE34	7494 159344	ELIZAVETA TROFIMOVA	{"email": "trofimova-e-061970@postgrespro.ru", "phone": "+70423015740"}
0005434245195	E46527	3645 895875	ALEKSANDR ZAYCEV	{"email": "a_zaycev.14111961@postgrespro.ru", "phone": "+70023768178"}
0005434245196	E46527	0110 720808	VIKTOR KULIKOV	{"phone": "+70401356160"}
0005434245197	9D538B	3296 049415	VALERIY DENISOV	{"email": "v-denisov.031983@postgrespro.ru", "phone": "+70927478754"}
0005434245198	5F1385	4254 245892	EDUARD MOISEEV	{"email": "moiseev-e-14061977@postgrespro.ru", "phone": "+70392543139"}
0005434245199	5F1385	7348 545083	RAFIK IVANOV	{"phone": "+70219450873"}
0005434245200	2D2E0C	3074 747887	ALEKSANDR PETROV	{"phone": "+70041385856"}
0005434245201	766F1F	0369 157915	NATALYA GUSEVA	{"email": "natalya_guseva08081961@postgrespro.ru", "phone": "+70245161101"}
0005434245202	766F1F	0507 206418	ANDREY KUZNECOV	{"phone": "+70590439438"}
0005434245203	8E0AD3	3821 530409	OLEG NIKITIN	{"phone": "+70148053402"}
0005434245204	21CAF2	8867 561634	SERGEY TIMOFEEV	{"phone": "+70155025963"}
0005434245205	D9F28C	5027 160955	VIKTOR SERGEEV	{"phone": "+70915086803"}
0005434245206	D9F28C	8293 828960	MAKSIM MAKSIMOV	{"phone": "+70777390379"}
0005434245207	D9F28C	3828 718510	VALERIY PETROV	{"phone": "+70835285427"}
0005434245208	A22E4E	2249 661701	ILYA VOLKOV	{"phone": "+70151065176"}
0005434245209	16CBD2	5108 553873	OLGA VOLKOVA	{"email": "volkova-o-071970@postgrespro.ru", "phone": "+70726130239"}
0005434245210	57F66B	6942 537705	VLADIMIR SOROKIN	{"email": "v-sorokin071961@postgrespro.ru", "phone": "+70932313540"}
0005434245211	57F66B	9423 055957	VITALIY ILIN	{"phone": "+70549502751"}
0005434245212	E4691F	9329 622856	OLGA TIMOFEEVA	{"email": "timofeeva.olga_1975@postgrespro.ru", "phone": "+70772219304"}
0005434245213	E4691F	6673 927375	PETR ISAEV	{"email": "p-isaev_031971@postgrespro.ru", "phone": "+70159541348"}
0005434245214	2FC982	4864 372063	ELENA PAVLOVA	{"phone": "+70408182326"}
0005434245215	E3F081	0966 296514	ELENA KUZNECOVA	{"email": "elena.kuznecova_25091970@postgrespro.ru", "phone": "+70340844408"}
0005434245216	4178C4	7277 544954	MIKHAIL SMIRNOV	{"email": "m-smirnov-22011969@postgrespro.ru", "phone": "+70977110580"}
0005434245217	4178C4	4804 859679	SVETLANA MEDVEDEVA	{"phone": "+70210260239"}
0005434245218	4178C4	1188 501692	MARAT TIMOFEEV	{"phone": "+70626089450"}
0005434245219	37B861	1704 638996	RAISA ZHURAVLEVA	{"phone": "+70790383883"}
0005434245220	9DADF8	8163 658300	MARAT EGOROV	{"email": "egorov_marat-26101982@postgrespro.ru", "phone": "+70172810395"}
0005434245221	6B027F	9330 615602	VALENTINA FROLOVA	{"email": "v-frolova-071980@postgrespro.ru", "phone": "+70381778023"}
0005434245222	6B027F	3439 069720	ALEKSEY KRASNOV	{"email": "krasnov-a-02091965@postgrespro.ru", "phone": "+70328768648"}
0005434245223	309D86	9042 201289	ELIZAVETA VLASOVA	{"email": "vlasova_elizaveta.20051968@postgrespro.ru", "phone": "+70231072023"}
0005434245224	309D86	1494 653410	OLGA ISAEVA	{"email": "isaevaolga-1961@postgrespro.ru", "phone": "+70301541491"}
0005434245225	FA3D73	0441 872861	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov.081975@postgrespro.ru", "phone": "+70966861969"}
0005434245226	B11599	1700 164644	MIKHAIL SIDOROV	{"email": "mikhail_sidorov.061961@postgrespro.ru", "phone": "+70946028900"}
0005434245227	B11599	2766 961480	VLADIMIR MEDVEDEV	{"email": "medvedevvladimir081970@postgrespro.ru", "phone": "+70396911198"}
0005434245228	810258	9221 933896	LIDIYA SMIRNOVA	{"phone": "+70844865451"}
0005434245229	3AD20B	6260 548286	OLGA YAKOVLEVA	{"email": "olgayakovleva051976@postgrespro.ru", "phone": "+70029706906"}
0005434245230	3AD20B	9757 541347	MIKHAIL KOROLEV	{"phone": "+70302450211"}
0005434245231	E9D129	6622 103344	IRINA GAVRILOVA	{"phone": "+70638442911"}
0005434245232	901465	6210 908003	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov02051986@postgrespro.ru", "phone": "+70445846712"}
0005434245233	901465	2700 060236	ELENA MAKAROVA	{"email": "elenamakarova1960@postgrespro.ru", "phone": "+70016383174"}
0005434245234	8A840E	8189 222659	VIKTOR GRIGOREV	{"email": "viktorgrigorev061979@postgrespro.ru", "phone": "+70609463833"}
0005434245235	9CD3D5	7030 294400	ALEKSANDRA ARKHIPOVA	{"email": "arkhipova-aleksandra_18021974@postgrespro.ru", "phone": "+70022833542"}
0005434245236	EE17ED	1398 710341	VERONIKA SAVELEVA	{"email": "saveleva-veronika.011970@postgrespro.ru", "phone": "+70883072939"}
0005434245237	EE17ED	6143 491485	VITALIY CHERNOV	{"phone": "+70643661849"}
0005434245238	BA3F32	2243 506337	ALEKSANDR FROLOV	{"email": "frolov.a-25021984@postgrespro.ru", "phone": "+70235921182"}
0005434245239	DD572F	8888 961361	TATYANA VLASOVA	{"email": "t.vlasova.23081965@postgrespro.ru", "phone": "+70352095170"}
0005434245240	DD572F	7290 218358	TATYANA KUDRYASHOVA	{"email": "kudryashova-tatyana.1982@postgrespro.ru", "phone": "+70991857938"}
0005434245241	F78D52	0020 665162	TAMARA KOZLOVA	{"phone": "+70776357501"}
0005434245242	B778EA	1798 673315	DARYA TITOVA	{"email": "daryatitova.061964@postgrespro.ru", "phone": "+70313936989"}
0005434245243	B778EA	6360 655488	IGOR PAVLOV	{"email": "pavlov.igor.011981@postgrespro.ru", "phone": "+70175091800"}
0005434245244	1764B9	5172 329666	LARISA FILATOVA	{"email": "filatova_larisa01071969@postgrespro.ru", "phone": "+70145433383"}
0005434245245	97CF22	4489 590800	NADEZHDA KUZNECOVA	{"phone": "+70956134437"}
0005434245246	97CF22	3235 929273	NIKOLAY NAZAROV	{"phone": "+70796936433"}
0005434245247	6CE856	0552 570515	TATYANA TIKHONOVA	{"phone": "+70688298134"}
0005434245248	6CE856	3966 243264	SERGEY KOZLOV	{"phone": "+70798387531"}
0005434245249	D08320	8466 222394	LYUBOV TIMOFEEVA	{"email": "timofeeva_lyubov_1970@postgrespro.ru", "phone": "+70891640633"}
0005434245250	D08320	8403 547423	GALINA ANTONOVA	{"phone": "+70693840884"}
0005434245251	F2D6F4	0692 985301	MARYAM ZAYCEVA	{"phone": "+70536856783"}
0005434245252	58F00F	0851 409967	LIDIYA ZAKHAROVA	{"email": "lidiya-zakharova.071976@postgrespro.ru", "phone": "+70774818435"}
0005434245253	343250	9949 684532	MIKHAIL BELOV	{"email": "mikhailbelov-21101979@postgrespro.ru", "phone": "+70990407174"}
0005434245254	343250	3430 030688	VLADIMIR ILIN	{"email": "vladimir_ilin121971@postgrespro.ru", "phone": "+70158068949"}
0005434245255	622832	8753 317575	ANASTASIYA MARTYNOVA	{"email": "martynova.a.1961@postgrespro.ru", "phone": "+70203951951"}
0005434245256	84CE09	3772 965298	TATYANA CHERNOVA	{"email": "chernova-tatyana.1976@postgrespro.ru", "phone": "+70621148465"}
0005434245257	9D4D92	1460 586318	IVAN ZAKHAROV	{"email": "zakharov.ivan1980@postgrespro.ru", "phone": "+70212947626"}
0005434245258	9D4D92	1287 551448	VALENTIN GAVRILOV	{"phone": "+70722551241"}
0005434245259	9D4D92	0445 530698	EDUARD ZAKHAROV	{"phone": "+70239011209"}
0005434245260	6691A8	2061 830198	MIKHAIL POPOV	{"email": "mikhail-popov081971@postgrespro.ru", "phone": "+70684938850"}
0005434245261	6691A8	0684 277192	SERGEY MOISEEV	{"email": "moiseev.s-1970@postgrespro.ru", "phone": "+70463030560"}
0005434245262	523711	5283 595885	ZINAIDA KALININA	{"email": "z-kalinina-06011978@postgrespro.ru", "phone": "+70388565313"}
0005434245263	FFA631	2114 998497	EKATERINA KUZNECOVA	{"phone": "+70625563527"}
0005434245264	7CBF40	7662 016889	NATALYA SOKOLOVA	{"email": "sokolova_natalya1981@postgrespro.ru", "phone": "+70982495896"}
0005434245265	7CBF40	6638 965477	ELENA MARTYNOVA	{"email": "martynova_e111979@postgrespro.ru", "phone": "+70643318346"}
0005434245266	0FD070	5521 227713	ARTEM KRASNOV	{"email": "artem.krasnov-24101967@postgrespro.ru", "phone": "+70462220088"}
0005434245267	02690E	5581 603565	VIKTOR AFANASEV	{"phone": "+70931692492"}
0005434245268	9C52D5	5454 171816	VLADIMIR NAUMOV	{"email": "naumovvladimir-1973@postgrespro.ru", "phone": "+70305884951"}
0005434245269	3A9481	3501 620940	EDUARD MARTYNOV	{"email": "martynov.eduard.1976@postgrespro.ru", "phone": "+70874192451"}
0005434245270	3A9481	8549 922644	TATYANA ZHUKOVA	{"email": "t.zhukova1968@postgrespro.ru", "phone": "+70372794079"}
0005434245271	B72150	5142 130826	NIKOLAY ORLOV	{"email": "orlovn27121963@postgrespro.ru", "phone": "+70785284745"}
0005434245272	B72150	0647 475832	OKSANA KOZLOVA	{"phone": "+70626172795"}
0005434245273	9127C4	9138 243852	MARIYA MAKAROVA	{"email": "makarova_m_29041972@postgrespro.ru", "phone": "+70485459120"}
0005434245274	C8FAF8	6797 322329	LYUBOV MASLOVA	{"email": "lyubov.maslova-09121968@postgrespro.ru", "phone": "+70701502332"}
0005434245275	E66EF7	1291 922663	SERGEY BONDARENKO	{"phone": "+70890802461"}
0005434245276	EEA5AC	6452 747981	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy18071974@postgrespro.ru", "phone": "+70281816710"}
0005434245277	91E687	0602 464699	NIKOLAY VASILEV	{"phone": "+70819743040"}
0005434245278	E477BE	3635 435791	VYACHESLAV GORBUNOV	{"email": "gorbunov-v-24011977@postgrespro.ru", "phone": "+70749619295"}
0005434245279	659176	5770 332808	FARIT SOLOVEV	{"phone": "+70699311748"}
0005434245280	B3F6A8	9707 331963	YURIY NIKITIN	{"email": "nikitin-yuriy14081987@postgrespro.ru", "phone": "+70396716817"}
0005434245281	B3F6A8	3119 586963	EVGENIY FEDOROV	{"phone": "+70655645963"}
0005434245282	B3F6A8	1092 735452	VLADIMIR MOROZOV	{"email": "v_morozov.031958@postgrespro.ru", "phone": "+70063959441"}
0005434245283	0D45C3	9549 147776	ZINAIDA ALEKSANDROVA	{"email": "aleksandrova-z-1983@postgrespro.ru", "phone": "+70510400824"}
0005434245284	0D45C3	7121 369912	SERGEY KULIKOV	{"email": "kulikov-s.041973@postgrespro.ru", "phone": "+70269097022"}
0005434245285	0D45C3	8786 718359	ANTONINA POTAPOVA	{"email": "potapova.antonina_1966@postgrespro.ru", "phone": "+70155686392"}
0005434245286	E69844	2548 524261	SERGEY PETROV	{"email": "petrovsergey-011973@postgrespro.ru", "phone": "+70875805306"}
0005434245287	E69844	9317 737046	ANASTASIYA KOROLEVA	{"phone": "+70855680760"}
0005434245288	F2843F	1162 229420	ALLA MIRONOVA	{"phone": "+70266479187"}
0005434245289	74CC59	5189 117467	DARYA FEDOROVA	{"email": "dfedorova121982@postgrespro.ru", "phone": "+70753218670"}
0005434245290	74CC59	5692 831133	VALENTINA NAUMOVA	{"phone": "+70698317792"}
0005434245291	3B04DD	4345 061886	SOFYA NESTEROVA	{"email": "sofyanesterova_1972@postgrespro.ru", "phone": "+70421885713"}
0005434245292	5B1917	4282 356424	ALEKSANDR ANDREEV	{"phone": "+70521251640"}
0005434245293	5B1917	9513 111597	MAKSIM MAKAROV	{"phone": "+70936711391"}
0005434245294	8A7D9D	6324 711294	VALENTINA NAUMOVA	{"email": "v.naumova-1971@postgrespro.ru", "phone": "+70777507804"}
0005434245295	B92B42	7299 500846	MARGARITA KONOVALOVA	{"email": "konovalova_m-12061980@postgrespro.ru", "phone": "+70648634442"}
0005434245296	B92B42	1571 456224	VLADIMIR OSIPOV	{"phone": "+70825311317"}
0005434245297	5ACB18	2258 076662	VLADIMIR RODIONOV	{"email": "rodionov.vladimir1961@postgrespro.ru", "phone": "+70711720880"}
0005434245298	8D8F46	9009 939945	SERGEY VOROBEV	{"email": "vorobev.sergey051969@postgrespro.ru", "phone": "+70263021173"}
0005434245299	F07281	8655 965829	EVGENIY KUZMIN	{"email": "evgeniykuzmin-1969@postgrespro.ru", "phone": "+70742703867"}
0005434245300	F07281	3787 780807	ALEKSANDR ALEKSANDROV	{"phone": "+70872178812"}
0005434245301	F07281	4875 775696	RENAT NOVIKOV	{"email": "renat-novikov.25061969@postgrespro.ru", "phone": "+70148598786"}
0005434245302	51010F	7095 601020	ALLA DAVYDOVA	{"phone": "+70953770539"}
0005434245303	51010F	3498 629100	ANTON KONOVALOV	{"email": "konovalov_anton061973@postgrespro.ru", "phone": "+70706024719"}
0005434245304	9F9B63	8094 596148	MARIYA NOVIKOVA	{"email": "novikova.m-1978@postgrespro.ru", "phone": "+70546102234"}
0005434245305	FC3931	5533 248253	ALEKSANDR KUZNECOV	{"phone": "+70896696092"}
0005434245306	FC3931	1119 677730	IRINA DENISOVA	{"phone": "+70615738547"}
0005434245307	D437A8	3723 550067	EVGENIY PAVLOV	{"email": "evgeniypavlov_051980@postgrespro.ru", "phone": "+70468292509"}
0005434245308	553E48	4623 962186	EGOR KULIKOV	{"phone": "+70893023799"}
0005434245309	FB075D	3836 294396	SVETLANA ZAKHAROVA	{"phone": "+70474711966"}
0005434245310	999321	2227 423065	NINA SERGEEVA	{"email": "sergeeva.n23081972@postgrespro.ru", "phone": "+70353777411"}
0005434245311	999321	8742 160169	ANASTASIYA BOGDANOVA	{"email": "bogdanovaanastasiya.101965@postgrespro.ru", "phone": "+70316603615"}
0005434245312	999321	6079 678401	VYACHESLAV GRIGOREV	{"phone": "+70456530224"}
0005434245313	9BA4D6	2841 207933	MIKHAIL BORISOV	{"email": "borisov_mikhail-091984@postgrespro.ru", "phone": "+70002714057"}
0005434245314	7617ED	7361 782958	ELENA KUZNECOVA	{"phone": "+70980038809"}
0005434245315	7617ED	8446 869981	TATYANA ZAKHAROVA	{"email": "t-zakharova-16081975@postgrespro.ru", "phone": "+70596016651"}
0005434245316	D453C3	0348 254111	ALEKSANDRA ORLOVA	{"phone": "+70472658714"}
0005434245317	F23674	3280 948718	ANNA FROLOVA	{"email": "frolova.a1967@postgrespro.ru", "phone": "+70343763754"}
0005434245318	F23674	2453 478262	VALENTIN IVANOV	{"email": "ivanov_valentin1966@postgrespro.ru", "phone": "+70175960575"}
0005434245319	F23674	5032 147220	ANTONINA FILATOVA	{"phone": "+70815709252"}
0005434245320	6AB7C6	7163 367751	TATYANA BELYAEVA	{"email": "t.belyaeva_071972@postgrespro.ru", "phone": "+70528474008"}
0005434245321	6AB7C6	1179 142598	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev-1975@postgrespro.ru", "phone": "+70057551756"}
0005434245322	5639C2	3192 273952	LYUDMILA KUZNECOVA	{"phone": "+70312600326"}
0005434245323	FE185C	0095 626335	YULIYA MAKAROVA	{"email": "yuliya_makarova_13031968@postgrespro.ru", "phone": "+70481425701"}
0005434245324	FE185C	2620 955037	ZINAIDA KUZNECOVA	{"email": "kuznecovazinaida.1955@postgrespro.ru", "phone": "+70691164378"}
0005434245325	6A7DE0	3387 081903	GALINA LAZAREVA	{"phone": "+70071088633"}
0005434245326	6A7DE0	8132 171661	ALINA FOMINA	{"email": "fomina_a.19111985@postgrespro.ru", "phone": "+70028732063"}
0005434245327	FA4886	2622 890946	ALEKSEY KUZNECOV	{"phone": "+70808207651"}
0005434245328	87B64F	3790 071269	SERGEY SERGEEV	{"email": "sergeevsergey_02051974@postgrespro.ru", "phone": "+70897278861"}
0005434245329	70354A	3583 788895	ANASTASIYA FEDOROVA	{"email": "a-fedorova_1965@postgrespro.ru", "phone": "+70054901989"}
0005434245330	E2207D	8493 661021	MIKHAIL BONDARENKO	{"email": "mbondarenko.101963@postgrespro.ru", "phone": "+70283576913"}
0005434245331	2E3206	9407 656813	DMITRIY NAZAROV	{"email": "nazarov-dmitriy_1971@postgrespro.ru", "phone": "+70296748142"}
0005434245332	2E3206	5602 720385	VASILIY GERASIMOV	{"email": "v_gerasimov.061969@postgrespro.ru", "phone": "+70875486004"}
0005434245333	C4AAE1	4530 523478	VLADIMIR KRASNOV	{"phone": "+70582438401"}
0005434245334	894142	6268 671263	MAKSIM NIKOLAEV	{"email": "nikolaevm-1966@postgrespro.ru", "phone": "+70125658157"}
0005434245335	002BED	8435 408196	ALEKSANDR MELNIKOV	{"email": "a_melnikov-1973@postgrespro.ru", "phone": "+70480594550"}
0005434245336	557E5F	1545 905371	ARTEM MIKHAYLOV	{"phone": "+70273675998"}
0005434245337	557E5F	8216 964557	SERGEY MAKAROV	{"email": "smakarov_02111980@postgrespro.ru", "phone": "+70496587894"}
0005434245338	1F2E16	8579 805523	NATALYA ZAYCEVA	{"email": "zaycevanatalya.10041973@postgrespro.ru", "phone": "+70433828980"}
0005434245339	38A91C	4066 370062	GRIGORIY DENISOV	{"email": "denisov-grigoriy-021976@postgrespro.ru", "phone": "+70239031967"}
0005434245340	D81B4B	9222 951525	VIKTOR ALEKSEEV	{"email": "viktor_alekseev-101982@postgrespro.ru", "phone": "+70099398860"}
0005434245341	D81B4B	4767 531158	ALEKSANDR ROMANOV	{"email": "aromanov011973@postgrespro.ru", "phone": "+70121573187"}
0005434245342	365E08	5167 129273	IVAN ROMANOV	{"email": "iromanov1969@postgrespro.ru", "phone": "+70205096976"}
0005434245343	22BDC2	2894 409069	MARIYA KOVALEVA	{"email": "mariya-kovaleva26121967@postgrespro.ru", "phone": "+70937137450"}
0005434245344	22BDC2	0892 604446	ANDREY ROMANOV	{"email": "romanov_a-041977@postgrespro.ru", "phone": "+70087880125"}
0005434245345	22BDC2	9365 345910	ALEKSEY AFANASEV	{"phone": "+70056641870"}
0005434245346	DC6BC7	6665 167165	KSENIYA FADEEVA	{"phone": "+70586901746"}
0005434245347	DC6BC7	5335 967451	YULIYA SEMENOVA	{"email": "yuliyasemenova_08051968@postgrespro.ru", "phone": "+70248781041"}
0005434245348	2A263E	6801 881080	SVETLANA TARASOVA	{"email": "tarasova_svetlana.1976@postgrespro.ru", "phone": "+70454638259"}
0005434245349	2A263E	1367 232850	VIKTOR KONOVALOV	{"email": "viktorkonovalov_111981@postgrespro.ru", "phone": "+70697424558"}
0005434245350	0918EB	2025 304372	OLGA MOROZOVA	{"phone": "+70623013087"}
0005434245351	0918EB	3890 179125	ROMAN SOROKIN	{"email": "r.sorokin.091979@postgrespro.ru", "phone": "+70282901738"}
0005434245352	E90C7F	5615 417424	SERGEY ALEKSEEV	{"phone": "+70303879202"}
0005434245353	BD129F	4160 367003	VIKTOR TIKHONOV	{"email": "tikhonovviktor_24021972@postgrespro.ru", "phone": "+70713484187"}
0005434245354	BD129F	9119 333791	VADIM ANDREEV	{"email": "vadim.andreev061962@postgrespro.ru", "phone": "+70823635054"}
0005434245355	BD129F	1681 856078	LYUBOV NIKOLAEVA	{"email": "l.nikolaeva1967@postgrespro.ru", "phone": "+70430710617"}
0005434245356	49A3B3	6053 688760	GALINA SOLOVEVA	{"phone": "+70774588496"}
0005434245357	FD65FD	4778 573782	ANASTASIYA GRISHINA	{"phone": "+70472174594"}
0005434245358	FD65FD	6443 173602	YURIY MAKAROV	{"phone": "+70081613570"}
0005434245359	A9A4C0	1936 636142	VLADIMIR ANDREEV	{"phone": "+70035402598"}
0005434245360	CDDD97	4673 628789	EVGENIY PETROV	{"phone": "+70050117146"}
0005434245361	CDDD97	5276 610952	MAKSIM KAZAKOV	{"email": "kazakov-maksim.041981@postgrespro.ru", "phone": "+70939953133"}
0005434245362	CDDD97	9546 348406	DARYA DENISOVA	{"phone": "+70506274099"}
0005434245363	A24066	3058 257410	LIDIYA KALININA	{"phone": "+70487967310"}
0005434245364	7E3053	2046 349717	EVGENIYA SEMENOVA	{"phone": "+70868138098"}
0005434245365	7E3053	2568 224767	ALEKSEY FROLOV	{"phone": "+70272117753"}
0005434245366	C1178F	1852 304091	ANDREY TARASOV	{"email": "andrey.tarasov-081963@postgrespro.ru", "phone": "+70990734278"}
0005434245367	C1178F	0654 869549	EVGENIY KUZMIN	{"phone": "+70141695452"}
0005434245368	C1178F	4374 608470	TATYANA KOROLEVA	{"phone": "+70643697847"}
0005434245369	AE042E	8203 026465	VALERIY TIKHONOV	{"email": "tikhonov.v29091968@postgrespro.ru", "phone": "+70878898594"}
0005434245370	42605E	5634 505865	NATALYA ALEKSEEVA	{"email": "alekseeva-n.14011972@postgrespro.ru", "phone": "+70148782681"}
0005434245371	31BF87	5411 156375	TATYANA SIDOROVA	{"phone": "+70401062657"}
0005434245431	785D2F	7745 636737	LIDIYA KONOVALOVA	{"phone": "+70575394080"}
0005434245372	070AF4	7525 049695	NIKOLAY MAKAROV	{"email": "nikolaymakarov.1965@postgrespro.ru", "phone": "+70488162960"}
0005434245373	070AF4	3126 282401	SERGEY EGOROV	{"email": "egorovs1969@postgrespro.ru", "phone": "+70099403297"}
0005434245374	F8D921	8224 342953	LYUDMILA DENISOVA	{"phone": "+70368896272"}
0005434245375	271021	1242 945655	YULIYA ERMAKOVA	{"email": "ermakovayuliya_111966@postgrespro.ru", "phone": "+70001591377"}
0005434245376	253037	6499 907054	SERGEY VASILEV	{"phone": "+70595641053"}
0005434245377	DF2455	8300 366212	MARYAM ALEKSEEVA	{"phone": "+70172475298"}
0005434245378	E8651A	1484 581372	ALEKSANDR KULIKOV	{"phone": "+70243863210"}
0005434245379	CAA3F8	6950 916180	VALENTINA KOVALEVA	{"phone": "+70263407946"}
0005434245380	E4EF67	3818 955048	SERGEY VLASOV	{"email": "sergey.vlasov.04061976@postgrespro.ru", "phone": "+70120241663"}
0005434245381	E4EF67	9431 052613	NIKOLAY SAVELEV	{"email": "n_savelev-1965@postgrespro.ru", "phone": "+70920662552"}
0005434245382	2A2E1F	1268 836776	EKATERINA BOGDANOVA	{"email": "ebogdanova04021979@postgrespro.ru", "phone": "+70448788422"}
0005434245383	2A2E1F	2519 956895	DANIIL GERASIMOV	{"email": "dgerasimov.081969@postgrespro.ru", "phone": "+70620475468"}
0005434245384	62FD19	1459 878131	TATYANA MOISEEVA	{"email": "t-moiseeva-1971@postgrespro.ru", "phone": "+70278216149"}
0005434245385	62FD19	9161 944722	DMITRIY IVANOV	{"email": "ivanovdmitriy25101980@postgrespro.ru", "phone": "+70618767113"}
0005434245386	B2AD5C	0468 994779	ARMAN ISAEV	{"phone": "+70521546352"}
0005434245387	AC587F	1926 098838	MARAT SERGEEV	{"email": "sergeev_m-041977@postgrespro.ru", "phone": "+70136298034"}
0005434245388	BA42E7	7049 550629	VLADIMIR SMIRNOV	{"email": "smirnov.v_071976@postgrespro.ru", "phone": "+70947979490"}
0005434245389	BA42E7	8997 671106	NATALYA ANDREEVA	{"phone": "+70677160151"}
0005434245390	5BFEEE	4211 587966	VYACHESLAV POPOV	{"email": "v.popov.1970@postgrespro.ru", "phone": "+70685909621"}
0005434245391	7D99BC	7098 433287	NIKOLAY IVANOV	{"phone": "+70943417514"}
0005434245392	F53746	1646 895146	VALERIY KOZLOV	{"email": "kozlov.valeriy-09111970@postgrespro.ru", "phone": "+70940993246"}
0005434245393	B8EE41	6989 493476	ANDREY TARASOV	{"phone": "+70797180216"}
0005434245394	2F72CC	9810 640683	VALERIY MAKAROV	{"email": "makarov-v_1966@postgrespro.ru", "phone": "+70818435350"}
0005434245395	FF9C06	0564 934378	VALENTINA OSIPOVA	{"email": "osipova.valentina091983@postgrespro.ru", "phone": "+70221165840"}
0005434245396	F3B206	0164 512920	YURIY MATVEEV	{"phone": "+70532921610"}
0005434245397	F3B206	9951 661718	TATYANA ISAEVA	{"email": "t.isaeva1969@postgrespro.ru", "phone": "+70180480139"}
0005434245398	DC801D	4924 277368	NATALIYA KOMAROVA	{"phone": "+70108170937"}
0005434245399	859283	0746 334842	ALEKSEY ZAYCEV	{"phone": "+70132311847"}
0005434245400	859283	9028 756238	MARINA NESTEROVA	{"email": "marinanesterova_021971@postgrespro.ru", "phone": "+70544535567"}
0005434245401	859283	0413 879367	RUDOLF NIKOLAEV	{"phone": "+70017913188"}
0005434245402	99003F	8728 229868	NIKOLAY TIKHONOV	{"email": "n_tikhonov.04091970@postgrespro.ru", "phone": "+70969892467"}
0005434245403	51F1D6	8599 745403	LYUDMILA GUSEVA	{"email": "l_guseva-14021967@postgrespro.ru", "phone": "+70070676285"}
0005434245404	1E812C	8484 879869	RUSLAN MAKAROV	{"email": "rmakarov_1968@postgrespro.ru", "phone": "+70000752931"}
0005434245405	974FC6	6372 171601	SERGEY SERGEEV	{"email": "sergeev-s.031978@postgrespro.ru", "phone": "+70319140568"}
0005434245406	4C2C85	1413 352227	ALEKSEY SCHERBAKOV	{"email": "a-scherbakov-011986@postgrespro.ru", "phone": "+70507289803"}
0005434245407	4C2C85	8901 718992	VALERIY IVANOV	{"email": "vivanov.27071979@postgrespro.ru", "phone": "+70086777895"}
0005434245408	235F91	0884 642761	ZINAIDA SIDOROVA	{"phone": "+70096131918"}
0005434245409	235F91	1308 145294	YANA ILINA	{"email": "yana_ilina_11111979@postgrespro.ru", "phone": "+70251784410"}
0005434245410	ED9D18	4872 126698	NINA GAVRILOVA	{"phone": "+70579499603"}
0005434245411	4277DA	7746 074728	VLADIMIR SIDOROV	{"email": "v-sidorov041970@postgrespro.ru", "phone": "+70892291612"}
0005434245412	F1241E	4478 251458	DMITRIY IVANOV	{"email": "dmitriyivanov29101978@postgrespro.ru", "phone": "+70939792355"}
0005434245413	59D891	1387 373710	SVETLANA PETROVA	{"phone": "+70595870396"}
0005434245414	B35BAF	1902 569923	SERGEY POPOV	{"email": "spopov051969@postgrespro.ru", "phone": "+70937877114"}
0005434245415	A3C8C9	5990 409702	MARIYA DMITRIEVA	{"phone": "+70334969478"}
0005434245416	1620B2	6761 070437	NIKOLAY TARASOV	{"phone": "+70431460417"}
0005434245417	1620B2	0753 554642	VLADIMIR ROMANOV	{"email": "romanov.vladimir.081973@postgrespro.ru", "phone": "+70179506142"}
0005434245418	1750F3	0672 549724	NIKOLAY SCHERBAKOV	{"email": "scherbakov.nikolay26071980@postgrespro.ru", "phone": "+70771689006"}
0005434245419	408C4C	4359 710907	SVETLANA DAVYDOVA	{"email": "davydovas.12081971@postgrespro.ru", "phone": "+70638938930"}
0005434245420	408C4C	4961 631697	DMITRIY ILIN	{"phone": "+70563856529"}
0005434245421	6BDF64	9178 039453	VASILIY GERASIMOV	{"email": "gerasimov-v-27111975@postgrespro.ru", "phone": "+70972219223"}
0005434245422	3D613E	1220 287695	GENNADIY BELOV	{"email": "g-belov.1979@postgrespro.ru", "phone": "+70782406487"}
0005434245423	3D613E	7545 690549	STANISLAV ZAYCEV	{"phone": "+70770722374"}
0005434245424	89F9A1	7822 097218	EVGENIY KUZNECOV	{"phone": "+70178162854"}
0005434245425	89F9A1	7542 502589	KLAVDIYA SEMENOVA	{"phone": "+70013624857"}
0005434245426	44DBA2	5311 812719	EVGENIY VASILEV	{"email": "evgeniy-vasilev21111987@postgrespro.ru", "phone": "+70702995262"}
0005434245427	F0DF6C	7775 745356	VLADIMIR STEPANOV	{"email": "v-stepanov.091971@postgrespro.ru", "phone": "+70939149703"}
0005434245428	2D9AC5	5007 416854	LYUBOV VASILEVA	{"phone": "+70813522480"}
0005434245429	2D9AC5	9124 721716	MARIYA IVANOVA	{"email": "ivanova.mariya1970@postgrespro.ru", "phone": "+70802543351"}
0005434245430	785D2F	0824 816683	PETR VOLKOV	{"phone": "+70941550528"}
0005434245432	A3475B	8206 599815	IRINA KOLESNIKOVA	{"phone": "+70423205089"}
0005434245433	7B120D	7519 955727	EKATERINA SOKOLOVA	{"phone": "+70874491958"}
0005434245434	E55890	2447 733878	RUSLAN MOROZOV	{"phone": "+70956920545"}
0005434245435	E55890	4674 758125	VLADIMIR SHEVCHENKO	{"phone": "+70932104384"}
0005434245436	A23C57	9215 894047	OLGA IVANOVA	{"phone": "+70626057336"}
0005434245437	A23C57	1706 464743	ANTONIDA MAKSIMOVA	{"phone": "+70132620262"}
0005434245438	4EFBDC	9326 451676	NATALYA NESTEROVA	{"email": "n_nesterova-1962@postgrespro.ru", "phone": "+70642691817"}
0005434245439	3C591F	7817 942026	RAISA GERASIMOVA	{"phone": "+70495065311"}
0005434245440	3C591F	7797 865319	ANATOLIY ALEKSEEV	{"email": "alekseev-anatoliy_26111971@postgrespro.ru", "phone": "+70430439013"}
0005434245441	E31B5E	1039 986836	LARISA PETROVA	{"email": "petrovalarisa26061977@postgrespro.ru", "phone": "+70683970952"}
0005434245442	629947	2198 265698	NINA KOROLEVA	{"phone": "+70422376916"}
0005434245443	88D1EB	3463 840967	SVETLANA KUZMINA	{"email": "kuzmina_svetlana15031975@postgrespro.ru", "phone": "+70563518987"}
0005434245444	D58F20	0247 642082	SVETLANA ZOTOVA	{"phone": "+70266258312"}
0005434245445	007322	7083 592176	MARIYA AFANASEVA	{"phone": "+70513256378"}
0005434245446	50FD17	5253 921689	VALENTINA TROFIMOVA	{"email": "trofimova_valentina-021971@postgrespro.ru", "phone": "+70940203442"}
0005434245447	50FD17	2846 536730	EKATERINA DANILOVA	{"phone": "+70218586919"}
0005434245448	8B49D3	8032 156555	IGOR STEPANOV	{"phone": "+70797391245"}
0005434245449	ADF5F7	8168 254364	OLEG FEDOTOV	{"email": "fedotov.oleg-1979@postgrespro.ru", "phone": "+70903662910"}
0005434245450	26FC7D	2560 288437	NATALYA MOISEEVA	{"phone": "+70503810503"}
0005434245451	26FC7D	3391 468823	SVETLANA SOLOVEVA	{"phone": "+70945068973"}
0005434245452	26FC7D	3364 145930	KSENIYA NOVIKOVA	{"email": "k-novikova111975@postgrespro.ru", "phone": "+70885002879"}
0005434245453	86687D	4482 922338	DANILA MIRONOV	{"email": "danila-mironov.1979@postgrespro.ru", "phone": "+70489838952"}
0005434245454	984A5A	0654 672597	VITALIY SERGEEV	{"email": "vitaliy-sergeev16021971@postgrespro.ru", "phone": "+70331184194"}
0005434245455	1D1A7E	4753 227595	GENNADIY NOVIKOV	{"phone": "+70546614910"}
0005434245456	1D1A7E	6838 327810	IRINA ILINA	{"phone": "+70763872941"}
0005434245457	283077	0562 363675	EVDOKIYA KAZAKOVA	{"phone": "+70599607115"}
0005434245458	283077	0857 353360	TAISIYA GORBUNOVA	{"email": "gorbunova-t_1979@postgrespro.ru", "phone": "+70876290019"}
0005434245459	283077	2934 881098	IVAN POPOV	{"phone": "+70482127523"}
0005434245460	31CEA9	0495 818096	VALENTINA ZAKHAROVA	{"email": "zakharova.v1956@postgrespro.ru", "phone": "+70492915491"}
0005434245461	8537B7	3762 881163	KONSTANTIN EGOROV	{"phone": "+70118674689"}
0005434245462	8537B7	7220 010128	LYUDMILA RODIONOVA	{"email": "l-rodionova_1968@postgrespro.ru", "phone": "+70772764429"}
0005434245463	57F430	6374 812182	SVETLANA MIKHAYLOVA	{"email": "smikhaylova021983@postgrespro.ru", "phone": "+70065808683"}
0005434245464	57F430	9402 148535	LYUBOV STEPANOVA	{"phone": "+70421279051"}
0005434245465	E7A625	7361 046400	TATYANA TITOVA	{"email": "titova.tatyana22111969@postgrespro.ru", "phone": "+70409802394"}
0005434245466	603B09	8526 700223	DMITRIY SOKOLOV	{"phone": "+70037831318"}
0005434245467	FB917A	7227 949438	YAROSLAV SEMENOV	{"email": "semenov.y_16031978@postgrespro.ru", "phone": "+70933863939"}
0005434245468	FB917A	0044 163735	GALINA KULIKOVA	{"phone": "+70665871695"}
0005434245469	ACD3C8	1155 584215	TATYANA IVANOVA	{"email": "t-ivanova_24051970@postgrespro.ru", "phone": "+70963552990"}
0005434245470	764D96	6607 192972	NADEZHDA RYABOVA	{"email": "ryabova.nadezhda1972@postgrespro.ru", "phone": "+70159538100"}
0005434245471	764D96	2058 154555	ALINA PAVLOVA	{"phone": "+70030972778"}
0005434245472	5088DB	9295 808791	NADEZHDA FEDOROVA	{"email": "fedorova.n.081971@postgrespro.ru", "phone": "+70650355719"}
0005434245473	F6C72B	6218 083067	VIKTORIYA ANDREEVA	{"phone": "+70040169111"}
0005434245474	AFD3E2	3066 124462	IRINA ISAEVA	{"email": "isaeva_i.13021972@postgrespro.ru", "phone": "+70923065483"}
0005434245475	AFD3E2	1897 722399	NIKOLAY SOKOLOV	{"email": "nikolay.sokolov24061972@postgrespro.ru", "phone": "+70706946876"}
0005434245476	319F71	3695 781033	ARTEM GAVRILOV	{"email": "agavrilov.061971@postgrespro.ru", "phone": "+70035518618"}
0005434245477	319F71	7289 079211	SVETLANA EFREMOVA	{"email": "svetlana.efremova-041980@postgrespro.ru", "phone": "+70178736437"}
0005434245478	BD1015	1045 998691	RAISA SIDOROVA	{"phone": "+70622324685"}
0005434245479	BC7E06	1981 865526	ALEKSANDR POPOV	{"phone": "+70381397966"}
0005434245480	BC7E06	1200 941262	ALEKSANDR BONDARENKO	{"phone": "+70524261361"}
0005434245481	B4599C	8334 729958	LYUDMILA SOKOLOVA	{"phone": "+70622010397"}
0005434245482	B4599C	4041 448498	ANASTASIYA ZHUKOVA	{"email": "a_zhukova24061976@postgrespro.ru", "phone": "+70258042589"}
0005434245483	158B20	8013 850785	TATYANA GUSEVA	{"email": "tatyana.guseva.27041982@postgrespro.ru", "phone": "+70771415608"}
0005434245484	158B20	3079 196039	YURIY SOROKIN	{"email": "yuriy_sorokin101969@postgrespro.ru", "phone": "+70797165274"}
0005434245485	555D04	0470 332399	RAISA LAZAREVA	{"phone": "+70610002918"}
0005434245486	95864B	8272 225155	ALEKSEY MIRONOV	{"email": "mironov_a_1967@postgrespro.ru", "phone": "+70722568676"}
0005434245487	95864B	3502 201855	ELEONORA POPOVA	{"email": "popovaeleonora041969@postgrespro.ru", "phone": "+70728209095"}
0005434245488	E44C31	5410 396470	MARIYA EFREMOVA	{"phone": "+70151321509"}
0005434245489	E44C31	1791 923450	VERA IVANOVA	{"email": "veraivanova-011965@postgrespro.ru", "phone": "+70906502475"}
0005434245490	E44C31	7595 404040	ALEKSANDR AFANASEV	{"email": "aleksandr_afanasev_1973@postgrespro.ru", "phone": "+70000350141"}
0005434245491	A7824E	2208 322533	RAISA DANILOVA	{"email": "r.danilova1964@postgrespro.ru", "phone": "+70373908582"}
0005434245492	B4E31E	1796 305071	SVETLANA NAUMOVA	{"phone": "+70547045269"}
0005434245493	B4E31E	0374 443527	KLAVDIYA ZAKHAROVA	{"email": "klavdiya_zakharova.29011975@postgrespro.ru", "phone": "+70225851462"}
0005434245494	B4E31E	2698 048567	LYUBOV KUZNECOVA	{"email": "kuznecoval_09111980@postgrespro.ru", "phone": "+70935316108"}
0005434245495	50A2DC	8980 591842	NATALYA ZHURAVLEVA	{"email": "natalya.zhuravleva.081990@postgrespro.ru", "phone": "+70301956649"}
0005434245496	D662D7	2650 580128	ALIYA LEBEDEVA	{"email": "aliya-lebedeva.16121973@postgrespro.ru", "phone": "+70993133549"}
0005434245497	84162A	0273 112282	ALEKSANDR ZHURAVLEV	{"phone": "+70454672700"}
0005434245498	84162A	5479 266433	DMITRIY GRIGOREV	{"phone": "+70005910458"}
0005434245499	BE49E7	7934 798557	VIKTOR PAVLOV	{"phone": "+70835723624"}
0005434245500	7DE9CE	6833 940138	ANNA PETROVA	{"email": "a_petrova061972@postgrespro.ru", "phone": "+70347284531"}
0005434245501	ED0FDB	7075 973373	TAMARA POPOVA	{"email": "tpopova07031976@postgrespro.ru", "phone": "+70178459400"}
0005434245502	ED0FDB	4579 826757	POLINA FROLOVA	{"phone": "+70144870916"}
0005434245503	F2045D	5716 001037	ALEKSANDR BELOV	{"phone": "+70666904498"}
0005434245504	93A9E6	0808 281178	ILYA MEDVEDEV	{"email": "i.medvedev.1964@postgrespro.ru", "phone": "+70519878433"}
0005434245505	93A9E6	8994 177477	NIKOLAY VOROBEV	{"phone": "+70481245046"}
0005434245506	332876	4708 363046	ANGELINA KUZNECOVA	{"phone": "+70372255998"}
0005434245507	332876	7409 745628	TATYANA ARKHIPOVA	{"email": "arkhipova_tatyana_051970@postgrespro.ru", "phone": "+70423388824"}
0005434245508	3D52D9	2363 560374	DMITRIY ORLOV	{"email": "d-orlov.23021974@postgrespro.ru", "phone": "+70375109598"}
0005434245509	3D52D9	7224 222026	LYUBOV VOROBEVA	{"phone": "+70487832388"}
0005434245510	3D52D9	4450 664948	YULIYA NAZAROVA	{"phone": "+70980975904"}
0005434245511	64E5B4	5393 619256	NATALYA SOKOLOVA	{"email": "sokolova.natalya-1974@postgrespro.ru", "phone": "+70809641993"}
0005434245512	64E5B4	0547 836754	KONSTANTIN KUZNECOV	{"email": "kuznecov-konstantin.121961@postgrespro.ru", "phone": "+70410539168"}
0005434245513	B53863	3078 670919	YURIY TIKHONOV	{"email": "tikhonov-y-05111972@postgrespro.ru", "phone": "+70132714841"}
0005434245514	B53863	8608 015344	MIKHAIL FEDOTOV	{"email": "fedotovmikhail_1967@postgrespro.ru", "phone": "+70575111234"}
0005434245515	A771A7	4948 427045	ZULFIYA EGOROVA	{"email": "zulfiya.egorova_1976@postgrespro.ru", "phone": "+70533397972"}
0005434245516	5FBADB	9631 280653	VITALIY GORBUNOV	{"phone": "+70723269381"}
0005434245517	4F40AF	8814 507829	OLGA SAVELEVA	{"email": "olga.saveleva1966@postgrespro.ru", "phone": "+70166440991"}
0005434245518	BB1336	9702 478180	VLADISLAV NOVIKOV	{"phone": "+70768981118"}
0005434245519	BB1336	5663 042444	ANTONINA DAVYDOVA	{"email": "a.davydova-18011968@postgrespro.ru", "phone": "+70903439328"}
0005434245520	AFE8DF	1755 164979	ANNA IVANOVA	{"phone": "+70611391762"}
0005434245521	AFE8DF	5700 948333	MARIYA STEPANOVA	{"phone": "+70600750614"}
0005434245522	0B6B18	8677 447065	SERGEY KUZNECOV	{"email": "kuznecov.s_061977@postgrespro.ru", "phone": "+70345412461"}
0005434245523	6C3508	5652 075428	OLGA IVANOVA	{"email": "ivanova-olga08011979@postgrespro.ru", "phone": "+70412184254"}
0005434245524	6C3508	6272 660021	NATALYA NESTEROVA	{"phone": "+70626719435"}
0005434245525	BA7D69	4872 926426	ARTUR PETROV	{"email": "petrov-artur_13061987@postgrespro.ru", "phone": "+70717656345"}
0005434245526	9FFFBC	7851 397819	ANASTASIYA KUZNECOVA	{"phone": "+70312918216"}
0005434245527	FBFA84	7043 969507	ELENA IVANOVA	{"email": "e-ivanova19071962@postgrespro.ru", "phone": "+70207824641"}
0005434245528	69470C	7585 716741	NADEZHDA MAKSIMOVA	{"email": "maksimova_nadezhda_1969@postgrespro.ru", "phone": "+70423813809"}
0005434245529	6DA04A	5264 667120	SERGEY NIKOLAEV	{"phone": "+70960617209"}
0005434245530	AB3422	7216 091097	TATYANA VLASOVA	{"email": "tatyana.vlasova1970@postgrespro.ru", "phone": "+70649928395"}
0005434245531	A195CA	9840 782700	ANNA FILATOVA	{"phone": "+70035061932"}
0005434245532	95199F	6345 700877	VERONIKA ZOTOVA	{"phone": "+70436735157"}
0005434245533	403B43	2911 194776	NIKOLAY DENISOV	{"phone": "+70067502290"}
0005434245534	F8AACC	3010 645109	EVGENIY SIDOROV	{"email": "e.sidorov-071980@postgrespro.ru", "phone": "+70175315473"}
0005434245535	1CFD52	9227 707820	ALEKSANDR GUSEV	{"email": "a-gusev.16101979@postgrespro.ru", "phone": "+70266199279"}
0005434245536	73B0CE	1932 595228	ALEKSEY BORISOV	{"phone": "+70298631612"}
0005434245537	1A1B86	2710 420609	NADEZHDA POPOVA	{"email": "nadezhda-popova.021983@postgrespro.ru", "phone": "+70507525102"}
0005434245538	EB8AFA	9492 465770	ELENA EGOROVA	{"email": "egorova-e111981@postgrespro.ru", "phone": "+70689220427"}
0005434245539	EB8AFA	7521 752633	VASILIY IVANOV	{"phone": "+70487744872"}
0005434245540	0CBFB9	9108 670640	SERGEY SEMENOV	{"phone": "+70278619832"}
0005434245597	AEDEB1	4923 334241	YULIYA LAZAREVA	{"phone": "+70946348539"}
0005434245541	1B5FDC	5863 770283	ALEKSEY ZAKHAROV	{"email": "azakharov1979@postgrespro.ru", "phone": "+70293062170"}
0005434245542	5F691B	7512 804112	ALEKSANDR POPOV	{"email": "aleksandr-popov.12101964@postgrespro.ru", "phone": "+70038723129"}
0005434245543	1F5872	1376 572802	AIDA KISELEVA	{"phone": "+70465930647"}
0005434245544	E52738	3804 756685	ELENA KUZNECOVA	{"email": "kuznecova_elena_111978@postgrespro.ru", "phone": "+70027041924"}
0005434245545	DD4EE5	1137 928221	ANNA LOGINOVA	{"email": "loginovaa1983@postgrespro.ru", "phone": "+70777161875"}
0005434245546	D42188	1203 545232	ELENA KAZAKOVA	{"email": "elenakazakova.051975@postgrespro.ru", "phone": "+70169075593"}
0005434245547	D42188	3494 718306	MAKSIM FROLOV	{"phone": "+70601363266"}
0005434245548	7D0C1C	1261 741480	IVAN VOROBEV	{"email": "ivan.vorobev.10111977@postgrespro.ru", "phone": "+70326398422"}
0005434245549	7D0C1C	2556 707831	NATALIYA SERGEEVA	{"phone": "+70577890218"}
0005434245550	22393A	3166 285605	MARIYA IVANOVA	{"email": "ivanovam_021977@postgrespro.ru", "phone": "+70648382932"}
0005434245551	22393A	6322 337414	NATALYA KONOVALOVA	{"phone": "+70625997899"}
0005434245552	4F1221	9829 386751	VLADIMIR FILIPPOV	{"phone": "+70547709260"}
0005434245553	B4361D	0457 662615	LYUBOV SAVELEVA	{"phone": "+70067988396"}
0005434245554	B4361D	7281 168411	TATYANA KOVALEVA	{"email": "kovaleva_tatyana-1977@postgrespro.ru", "phone": "+70535841137"}
0005434245555	5FC4C9	7020 558478	LYUBOV KOROLEVA	{"phone": "+70416201093"}
0005434245556	545006	9482 732979	VIKTORIYA IVANOVA	{"email": "viktoriyaivanova1977@postgrespro.ru", "phone": "+70603708760"}
0005434245557	25BBDF	2052 658102	ANASTASIYA PAVLOVA	{"phone": "+70307291884"}
0005434245558	B0AE01	5089 611632	VLADIMIR ANTONOV	{"phone": "+70325820301"}
0005434245559	B0AE01	4103 146755	NINA KUZNECOVA	{"email": "kuznecova-n30101966@postgrespro.ru", "phone": "+70079832615"}
0005434245560	B6B45A	0067 972305	TATYANA MIKHAYLOVA	{"phone": "+70278067573"}
0005434245561	E8992A	1248 150933	ELENA PETROVA	{"email": "elenapetrova-051969@postgrespro.ru", "phone": "+70984300618"}
0005434245562	9AE57A	9812 138676	VLADIMIR IVANOV	{"phone": "+70498968384"}
0005434245563	4DA149	4912 346710	ANASTASIYA MELNIKOVA	{"email": "melnikova_a28091972@postgrespro.ru", "phone": "+70435920823"}
0005434245564	07C808	1916 355921	LIDIYA IVANOVA	{"email": "ivanovalidiya_061970@postgrespro.ru", "phone": "+70856867345"}
0005434245565	817154	9517 187268	IRINA KOROLEVA	{"phone": "+70690983138"}
0005434245566	9C44AE	5774 492102	DENIS POPOV	{"email": "popov.denis_041983@postgrespro.ru", "phone": "+70462118358"}
0005434245567	8E3952	3009 373201	IRINA BARANOVA	{"email": "i.baranova_011974@postgrespro.ru", "phone": "+70423631352"}
0005434245568	4334BB	9611 127623	POLINA ALEKSEEVA	{"email": "alekseevapolina-051966@postgrespro.ru", "phone": "+70906927592"}
0005434245569	E19C1F	7752 869717	ANNA TIKHONOVA	{"email": "tikhonova-a-1963@postgrespro.ru", "phone": "+70569426891"}
0005434245570	765259	3947 980707	VALENTINA BORISOVA	{"email": "borisovavalentina-011975@postgrespro.ru", "phone": "+70016665539"}
0005434245571	765259	1060 784407	VLADIMIR KOROLEV	{"phone": "+70003536196"}
0005434245572	F64B7A	6492 519922	NIKOLAY ORLOV	{"email": "orlov_n.091979@postgrespro.ru", "phone": "+70110244704"}
0005434245573	4F9D85	3953 611655	OLGA SMIRNOVA	{"email": "o-smirnova_011968@postgrespro.ru", "phone": "+70012569698"}
0005434245574	0A7B2F	7526 259211	MIKHAIL ANDREEV	{"email": "m-andreev.101965@postgrespro.ru", "phone": "+70605748605"}
0005434245575	B6BABA	3239 075343	IGOR KARPOV	{"email": "i-karpov041975@postgrespro.ru", "phone": "+70673313568"}
0005434245576	965863	4124 866560	EKATERINA ZAKHAROVA	{"phone": "+70110943389"}
0005434245577	4F9105	6157 247167	KONSTANTIN TARASOV	{"email": "konstantin.tarasov18031978@postgrespro.ru", "phone": "+70322958843"}
0005434245578	2E5DE1	5135 321123	MIKHAIL VLASOV	{"email": "m-vlasov-09081976@postgrespro.ru", "phone": "+70934200003"}
0005434245579	031498	7082 706614	IGOR ANTONOV	{"phone": "+70096366048"}
0005434245580	6FDD85	7686 450026	VASILIY DMITRIEV	{"phone": "+70811520586"}
0005434245581	6FDD85	1416 926061	ANASTASIYA BORISOVA	{"phone": "+70927670533"}
0005434245582	2209B6	2311 922308	KONSTANTIN MIKHAYLOV	{"email": "k_mikhaylov_121963@postgrespro.ru", "phone": "+70212377007"}
0005434245583	5614BF	8167 281473	ALEKSANDRA KULIKOVA	{"phone": "+70572862675"}
0005434245584	5614BF	0131 012582	OLESYA VASILEVA	{"phone": "+70419160973"}
0005434245585	5614BF	2846 803991	RAISA KOROLEVA	{"phone": "+70295288492"}
0005434245586	AF458B	0696 227520	ANTON KOZLOV	{"email": "antonkozlov_10021991@postgrespro.ru", "phone": "+70019748040"}
0005434245587	97241C	8180 400271	ALEKSEY FEDOROV	{"email": "a_fedorov-07021968@postgrespro.ru", "phone": "+70047717055"}
0005434245588	896BA9	4957 780011	MATVEY SIDOROV	{"phone": "+70710772931"}
0005434245589	E99AA2	0038 254972	ALEKSEY FROLOV	{"phone": "+70453165715"}
0005434245590	E99AA2	3816 746368	MIKHAIL KUZMIN	{"phone": "+70877918365"}
0005434245591	DB7D06	2227 777066	ROSTISLAV SHEVCHENKO	{"email": "shevchenko_rostislav-19041974@postgrespro.ru", "phone": "+70287230700"}
0005434245592	DB7D06	2082 718796	IVAN POPOV	{"email": "ivan-popov_1971@postgrespro.ru", "phone": "+70910382854"}
0005434245593	DB7D06	1130 790506	NADEZHDA GUSEVA	{"phone": "+70567141703"}
0005434245594	21B59E	1744 756847	YULIYA YAKOVLEVA	{"phone": "+70887995799"}
0005434245595	B9B32B	4863 320778	VALENTINA BARANOVA	{"email": "valentina-baranova1974@postgrespro.ru", "phone": "+70980075455"}
0005434245596	B9B32B	3748 937050	LIDIYA IVANOVA	{"phone": "+70416409651"}
0005434245598	BA1E64	3786 167883	KSENIYA FEDOROVA	{"email": "k-fedorova_041964@postgrespro.ru", "phone": "+70050420448"}
0005434245599	270E38	2586 755950	AMIR MEDVEDEV	{"email": "medvedev.a_1987@postgrespro.ru", "phone": "+70471947623"}
0005434245600	270E38	8612 366787	TATYANA NIKOLAEVA	{"phone": "+70980124030"}
0005434245601	492443	0569 442791	OLGA ZAKHAROVA	{"email": "zakharova_olga-19041971@postgrespro.ru", "phone": "+70484647850"}
0005434245602	53207B	5086 768718	NINA VASILEVA	{"phone": "+70410577705"}
0005434245603	EF4292	8716 630101	KSENIYA VOROBEVA	{"phone": "+70160267085"}
0005434245604	EF4292	0551 669236	LARISA KOZLOVA	{"phone": "+70759093650"}
0005434245605	EF4292	3734 229913	ANDREY MOISEEV	{"email": "a_moiseev.27021985@postgrespro.ru", "phone": "+70476033463"}
0005434245606	5FCB7B	8189 931271	STANISLAV MOROZOV	{"email": "s-morozov031982@postgrespro.ru", "phone": "+70644081529"}
0005434245607	DB09CB	3909 306956	EVGENIY KOZLOV	{"email": "kozlov.evgeniy05061978@postgrespro.ru", "phone": "+70930170198"}
0005434245608	B73C8D	2688 226661	LYUDMILA FOMINA	{"phone": "+70583742663"}
0005434245609	D7202C	1222 178631	SERGEY FOMIN	{"phone": "+70166443692"}
0005434245610	8DFF3D	1598 000687	VERA ERMAKOVA	{"phone": "+70910764327"}
0005434245611	8DFF3D	4103 766447	SERGEY BELOV	{"phone": "+70988457318"}
0005434245612	BB41B6	7243 039501	ELENA DENISOVA	{"phone": "+70000223441"}
0005434245613	827929	0153 754545	VLADISLAV MARTYNOV	{"phone": "+70823357960"}
0005434245614	827929	9410 251111	TATYANA AKIMOVA	{"email": "akimovat_1983@postgrespro.ru", "phone": "+70849424349"}
0005434245615	C96F6C	9442 086601	MAKSIM VASILEV	{"email": "m.vasilev.20031972@postgrespro.ru", "phone": "+70335130654"}
0005434245616	ADF82E	6493 865194	TATYANA ROMANOVA	{"phone": "+70773858787"}
0005434245617	ADF82E	3801 789655	ANATOLIY MAKAROV	{"phone": "+70847331973"}
0005434245618	46640E	9033 010515	ANATOLIY KRASNOV	{"phone": "+70883063094"}
0005434245619	5320E9	7111 824578	SNEZHANA ZAKHAROVA	{"email": "snezhana_zakharova-101967@postgrespro.ru", "phone": "+70636755102"}
0005434245620	8D65FB	6255 928924	KRISTINA BELOVA	{"email": "kbelova121970@postgrespro.ru", "phone": "+70208701975"}
0005434245621	D44C85	8780 460096	KIRILL GERASIMOV	{"email": "gerasimovk.091972@postgrespro.ru", "phone": "+70747681737"}
0005434245622	B77539	9743 376836	ANNA ZOTOVA	{"phone": "+70757463693"}
0005434245623	B77539	3242 225864	OLGA NAUMOVA	{"email": "olga-naumova.121979@postgrespro.ru", "phone": "+70327070482"}
0005434245624	601CB4	0868 087350	GALINA POLYAKOVA	{"email": "galina.polyakova_26101967@postgrespro.ru", "phone": "+70866993838"}
0005434245625	601CB4	9405 998253	PETR GRIGOREV	{"email": "grigorevpetr.05071976@postgrespro.ru", "phone": "+70674782170"}
0005434245626	F2AA99	9066 606704	ANTONINA MOISEEVA	{"email": "moiseevaantonina.1969@postgrespro.ru", "phone": "+70510913648"}
0005434245627	3F2F2A	4273 548035	VALENTINA KUZNECOVA	{"phone": "+70604330907"}
0005434245628	8CC3E4	3092 286124	SERGEY VOLKOV	{"email": "volkov-sergey-1963@postgrespro.ru", "phone": "+70889239958"}
0005434245629	374828	4959 547709	NADEZHDA BORISOVA	{"phone": "+70176681788"}
0005434245630	959691	0322 248030	SERGEY MOROZOV	{"phone": "+70290038357"}
0005434245686	EAFAF8	3210 205897	ALEKSANDRA DANILOVA	{"phone": "+70349006019"}
0005434245631	9971A2	2262 125099	SEMEN ANTONOV	{"email": "antonov.semen_04041981@postgrespro.ru", "phone": "+70885764158"}
0005434245632	9971A2	0846 429223	EDUARD KISELEV	{"phone": "+70729340380"}
0005434245633	D38E72	2719 028193	ELENA LEBEDEVA	{"phone": "+70606406653"}
0005434245634	D38E72	7427 172952	SERGEY PETROV	{"email": "sergeypetrov_101976@postgrespro.ru", "phone": "+70194171572"}
0005434245635	A0B604	9531 526614	VLADIMIR SOKOLOV	{"phone": "+70058407438"}
0005434245636	150CB9	4171 562239	NADEZHDA KOLESNIKOVA	{"email": "kolesnikovanadezhda.081966@postgrespro.ru", "phone": "+70912855780"}
0005434245637	150CB9	2179 469520	ALEKSEY KOROLEV	{"email": "korolev.a_20071967@postgrespro.ru", "phone": "+70643623185"}
0005434245638	E4B909	5507 763404	DIANA ZHUKOVA	{"phone": "+70349931802"}
0005434245639	E4B909	9462 991489	OKSANA KOVALEVA	{"email": "kovaleva.o_1986@postgrespro.ru", "phone": "+70244741256"}
0005434245640	E4B909	3823 785250	NIKOLAY MAKSIMOV	{"phone": "+70528582914"}
0005434245641	335B5C	2552 169080	ALEKSANDR MARTYNOV	{"phone": "+70042432884"}
0005434245642	335B5C	5367 214249	ELENA DANILOVA	{"email": "danilova_elena05091966@postgrespro.ru", "phone": "+70114292167"}
0005434245643	5A68B3	8996 545552	LYUBOV MELNIKOVA	{"email": "melnikovalyubov-06051973@postgrespro.ru", "phone": "+70577335441"}
0005434245644	387EF3	2319 625656	SERGEY EGOROV	{"phone": "+70089811341"}
0005434245645	AA9BFF	2284 923280	TATYANA ILINA	{"email": "tilina-061967@postgrespro.ru", "phone": "+70559585098"}
0005434245646	AA9BFF	8670 726226	DENIS PETROV	{"email": "d-petrov_27121979@postgrespro.ru", "phone": "+70493510757"}
0005434245647	2B7517	7525 677970	MARINA POLYAKOVA	{"email": "polyakova_marina091974@postgrespro.ru", "phone": "+70059426875"}
0005434245648	93D51A	9014 606769	GALINA FROLOVA	{"phone": "+70506745706"}
0005434245649	15E4D6	8982 297056	VALERIY ZAKHAROV	{"email": "valeriyzakharov_1965@postgrespro.ru", "phone": "+70950064987"}
0005434245650	15E4D6	9874 806531	VERA SAVELEVA	{"email": "vera.saveleva.18081963@postgrespro.ru", "phone": "+70077502733"}
0005434245651	BAC6EE	2705 939326	ALEKSANDR IVANOV	{"phone": "+70608451555"}
0005434245652	BAC6EE	6600 861330	NIKOLAY GRIGOREV	{"email": "grigorev_n-24061976@postgrespro.ru", "phone": "+70543781562"}
0005434245653	BAC6EE	6250 998996	IRINA NIKITINA	{"phone": "+70022728311"}
0005434245654	AB79DC	5467 262798	OLEG PETROV	{"email": "opetrov-111971@postgrespro.ru", "phone": "+70039638037"}
0005434245655	EBCEBD	2877 585699	ILDAR ANDREEV	{"email": "ildar.andreev111985@postgrespro.ru", "phone": "+70574949209"}
0005434245656	A87D8F	4301 864863	NATALYA KOLESNIKOVA	{"phone": "+70353192841"}
0005434245657	A87D8F	5833 620249	PAVEL ALEKSEEV	{"phone": "+70882041648"}
0005434245658	A46EC7	0158 525894	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr_1971@postgrespro.ru", "phone": "+70465889630"}
0005434245659	A46EC7	3821 913038	NATALYA ANISIMOVA	{"email": "anisimova_natalya.1979@postgrespro.ru", "phone": "+70376556597"}
0005434245660	F59781	3035 537107	ALEKSANDR VOLKOV	{"phone": "+70524124508"}
0005434245661	F59781	3788 851526	ALINA CHERNOVA	{"phone": "+70752753672"}
0005434245662	F59781	1881 634507	ANDREY PAVLOV	{"email": "andreypavlov_24031970@postgrespro.ru", "phone": "+70057458304"}
0005434245663	70C34B	1097 302057	NIKITA IVANOV	{"email": "ivanov_nikita.02101974@postgrespro.ru", "phone": "+70722089184"}
0005434245664	C2A009	2937 860792	OLGA SERGEEVA	{"email": "o-sergeeva14121981@postgrespro.ru", "phone": "+70040535350"}
0005434245665	D1FF9B	3027 626575	ELENA TROFIMOVA	{"phone": "+70660113158"}
0005434245666	D1FF9B	3489 690567	SVETLANA DAVYDOVA	{"email": "davydova_svetlana_22101968@postgrespro.ru", "phone": "+70039943023"}
0005434245667	3BEED0	8272 182236	MARINA SIDOROVA	{"email": "marina-sidorova_1969@postgrespro.ru", "phone": "+70722580231"}
0005434245668	F41992	8076 746082	ALEKSANDR PAVLOV	{"phone": "+70390308040"}
0005434245669	EC7F35	5248 915595	VLADIMIR ZAYCEV	{"email": "zaycevv.02121972@postgrespro.ru", "phone": "+70442637475"}
0005434245670	EC7F35	9797 059934	ROMAN MAKAROV	{"email": "r.makarov_11031976@postgrespro.ru", "phone": "+70147517514"}
0005434245671	0DA4EF	4470 405175	VIKTORIYA NESTEROVA	{"email": "nesterova-v.1972@postgrespro.ru", "phone": "+70886524098"}
0005434245672	0DA4EF	8465 970772	SVETLANA AKIMOVA	{"email": "akimova-svetlana_031977@postgrespro.ru", "phone": "+70998485897"}
0005434245673	7930EE	7445 438947	ALEKSANDR ORLOV	{"phone": "+70998007727"}
0005434245674	7930EE	2891 207252	VIKTOR DAVYDOV	{"phone": "+70085517863"}
0005434245675	7930EE	9329 376616	LARISA BOGDANOVA	{"email": "larisabogdanova.1965@postgrespro.ru", "phone": "+70018282223"}
0005434245676	37CD13	0188 562925	ALEKSANDR ALEKSEEV	{"email": "alekseev-a.1981@postgrespro.ru", "phone": "+70872401900"}
0005434245677	37CD13	0022 428460	ALENA MASLOVA	{"email": "a_maslova.111972@postgrespro.ru", "phone": "+70334495902"}
0005434245678	8EA63C	6144 853367	NIKITA IVANOV	{"phone": "+70546072660"}
0005434245679	8EA63C	7697 795544	ANNA BELYAEVA	{"email": "belyaeva_a.011966@postgrespro.ru", "phone": "+70667352625"}
0005434245680	8EA63C	9467 608483	SVETLANA MOROZOVA	{"phone": "+70634917793"}
0005434245681	CD2CCC	2052 395243	SERGEY KUZMIN	{"email": "s.kuzmin10071965@postgrespro.ru", "phone": "+70302128738"}
0005434245682	CD2CCC	2542 340686	ANNA DENISOVA	{"phone": "+70607492948"}
0005434245683	320AFF	6893 908303	VLADIMIR VASILEV	{"email": "vasilev-v1966@postgrespro.ru", "phone": "+70216639800"}
0005434245684	90F9E0	8602 173969	ANZHELIKA FOMINA	{"email": "fomina.a-1982@postgrespro.ru", "phone": "+70631037457"}
0005434245685	F3EAF3	1212 586279	VLADISLAV KISELEV	{"email": "vladislav-kiselev.101976@postgrespro.ru", "phone": "+70618661657"}
0005434245687	153925	5885 019532	NIKOLAY ANTONOV	{"phone": "+70806294725"}
0005434245688	153925	6645 264916	GENNADIY DAVYDOV	{"phone": "+70787728233"}
0005434245689	153925	8196 021915	ULYANA ALEKSEEVA	{"phone": "+70943735543"}
0005434245690	153925	8311 478647	NADEZHDA BARANOVA	{"email": "baranova.n071970@postgrespro.ru", "phone": "+70892544480"}
0005434245691	F6FBA2	2258 754308	MIKHAIL KUZNECOV	{"email": "m_kuznecov.07101968@postgrespro.ru", "phone": "+70702902291"}
0005434245692	F6FBA2	9965 281012	MARIYA MOROZOVA	{"email": "morozova-mariya1969@postgrespro.ru", "phone": "+70444866007"}
0005434245693	158813	4464 563655	ALEKSANDR KUZMIN	{"email": "kuzmin.a101962@postgrespro.ru", "phone": "+70221439167"}
0005434245694	158813	9459 208891	YURIY SMIRNOV	{"phone": "+70854465912"}
0005434245695	F68C3C	3546 077062	MARGARITA KRASNOVA	{"phone": "+70380375908"}
0005434245696	5AF8FB	5432 500333	YURIY SMIRNOV	{"email": "yuriysmirnov-25071968@postgrespro.ru", "phone": "+70101246607"}
0005434245697	5AF8FB	7688 168627	LYUBOV ORLOVA	{"email": "l_orlova-1970@postgrespro.ru", "phone": "+70769929919"}
0005434245698	CC6452	6653 368897	ANTONINA DENISOVA	{"phone": "+70823202294"}
0005434245699	CC6452	3485 715064	NINA ZHUKOVA	{"phone": "+70298830710"}
0005434245700	E9FC19	2054 475277	ANASTASIYA SERGEEVA	{"email": "sergeeva.a1969@postgrespro.ru", "phone": "+70336155012"}
0005434245701	F70B7E	2168 545819	NADEZHDA NESTEROVA	{"email": "n_nesterova111986@postgrespro.ru", "phone": "+70231673012"}
0005434245702	F70B7E	4969 893650	ANISA MAKAROVA	{"email": "makarova_a15071978@postgrespro.ru", "phone": "+70683380293"}
0005434245703	A82B75	2897 937674	ROMAN ZHURAVLEV	{"phone": "+70724137683"}
0005434245704	A82B75	2046 602670	LYUBOV BARANOVA	{"phone": "+70723866365"}
0005434245705	428B94	6792 418267	MAKSIM SEMENOV	{"email": "semenov_maksim-30031979@postgrespro.ru", "phone": "+70690405318"}
0005434245706	31F627	1394 281878	VALERIY MOROZOV	{"phone": "+70031689053"}
0005434245707	F9196D	7053 949179	EVGENIY NIKITIN	{"email": "nikitin.evgeniy-091953@postgrespro.ru", "phone": "+70980910398"}
0005434245708	12AE1F	7749 307779	VERA TROFIMOVA	{"phone": "+70697119658"}
0005434245709	0B1BF9	6248 677566	GALINA NOVIKOVA	{"email": "g_novikova.121971@postgrespro.ru", "phone": "+70779557290"}
0005434245710	0B1BF9	0886 340490	ANNA CHERNOVA	{"email": "a.chernova081977@postgrespro.ru", "phone": "+70328317060"}
0005434245711	DF0652	1605 286995	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-011972@postgrespro.ru", "phone": "+70624096267"}
0005434245712	F3B359	4126 177506	LIDIYA DMITRIEVA	{"phone": "+70874906286"}
0005434245713	93B6EE	3644 251922	VALENTINA ZHUKOVA	{"phone": "+70357325586"}
0005434245714	83BE84	6816 304609	TATYANA VASILEVA	{"email": "vasilevat031956@postgrespro.ru", "phone": "+70761248256"}
0005434245715	9E8C1C	8741 002497	YULIYA ANDREEVA	{"phone": "+70937032486"}
0005434245716	4CBA4B	0131 299209	EKATERINA ALEKSEEVA	{"phone": "+70943812981"}
0005434245717	4CBA4B	0568 355712	LYUDMILA KISELEVA	{"phone": "+70840935572"}
0005434245718	31FE9B	4813 847552	ANTON CHERNOV	{"phone": "+70410404341"}
0005434245719	0EDB42	2534 407213	MIKHAIL KUZNECOV	{"email": "kuznecov_m.25061964@postgrespro.ru", "phone": "+70074662869"}
0005434245720	611694	3454 112045	OLGA SEMENOVA	{"email": "olga-semenova_011969@postgrespro.ru", "phone": "+70392200841"}
0005434245721	FA8D6B	0663 594889	VERA SOKOLOVA	{"email": "vera_sokolova-031981@postgrespro.ru", "phone": "+70343690475"}
0005434245722	763D14	3844 483666	NADEZHDA KOLESNIKOVA	{"phone": "+70138292297"}
0005434245723	219922	1054 360468	SERGEY PAVLOV	{"email": "pavlovsergey.1988@postgrespro.ru", "phone": "+70762332461"}
0005434245724	00D1F9	6861 685527	IRINA SCHERBAKOVA	{"phone": "+70520184653"}
0005434245725	00D1F9	0383 561861	MIKHAIL VASILEV	{"phone": "+70949265459"}
0005434245726	00D1F9	1095 750100	TATYANA NIKITINA	{"email": "nikitina_tatyana081972@postgrespro.ru", "phone": "+70584253481"}
0005434245727	4D7C15	4072 326098	VIKTOR FILIPPOV	{"phone": "+70680293052"}
0005434245728	2BF06A	1585 190851	TAMARA ZAKHAROVA	{"email": "zakharovatamara-031982@postgrespro.ru", "phone": "+70181317293"}
0005434245729	2BF06A	0976 023928	OLGA ZAYCEVA	{"email": "zayceva.o27051962@postgrespro.ru", "phone": "+70683928241"}
0005434245730	3EDEB9	5152 172727	YANA NIKITINA	{"email": "yana.nikitina_25081984@postgrespro.ru", "phone": "+70401799798"}
0005434245731	589374	1156 382452	GENNADIY ORLOV	{"email": "gennadiy-orlov.1957@postgrespro.ru", "phone": "+70303092440"}
0005434245732	7C292A	4693 170652	PAVEL GORBUNOV	{"email": "gorbunov.pavel_081972@postgrespro.ru", "phone": "+70656864363"}
0005434245733	7C292A	1778 619592	ANNA VASILEVA	{"phone": "+70508155617"}
0005434245734	5C9311	5845 432873	NIKOLAY DMITRIEV	{"phone": "+70457376203"}
0005434245735	5C9311	5294 902821	LYUDMILA ANTONOVA	{"phone": "+70891216127"}
0005434245736	B918FC	4385 247518	ZHANNA NIKOLAEVA	{"phone": "+70042329197"}
0005434245737	93E8E3	1168 270334	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin-16051970@postgrespro.ru", "phone": "+70245822181"}
0005434245738	93E8E3	5777 625530	SERGEY KONOVALOV	{"email": "skonovalov.1967@postgrespro.ru", "phone": "+70390155387"}
0005434245739	93E8E3	0201 956110	IRINA MAKSIMOVA	{"phone": "+70839081542"}
0005434245740	F12E62	9852 374989	TAMARA NOVIKOVA	{"email": "t-novikova-011968@postgrespro.ru", "phone": "+70705752284"}
0005434245741	F0841E	4978 144915	NATALYA MASLOVA	{"email": "nmaslova_101972@postgrespro.ru", "phone": "+70989444355"}
0005434245742	F0841E	2830 712192	OLGA BORISOVA	{"email": "borisovaolga.11111974@postgrespro.ru", "phone": "+70725551632"}
0005434245743	D88446	3361 563428	NATALIYA GUSEVA	{"email": "nataliya-guseva.1970@postgrespro.ru", "phone": "+70061456800"}
0005434245744	3C2AAD	5504 878454	IGOR IVANOV	{"email": "igor_ivanov_22081982@postgrespro.ru", "phone": "+70590434732"}
0005434245745	F3642E	5678 998808	ANNA GORBUNOVA	{"phone": "+70665751390"}
0005434245746	F8FEDE	6646 535111	ALLA SAVELEVA	{"phone": "+70539805695"}
0005434245747	F8FEDE	7434 693423	NINA MELNIKOVA	{"email": "melnikovan29091964@postgrespro.ru", "phone": "+70021795867"}
0005434245748	601F1E	4996 615778	ALEKSANDR IVANOV	{"phone": "+70633392135"}
0005434245749	601F1E	4298 359811	VLADISLAV KUZMIN	{"phone": "+70663554236"}
0005434245750	FC0B3F	5768 897314	OLGA KUZNECOVA	{"email": "kuznecova.olga.10091974@postgrespro.ru", "phone": "+70998706362"}
0005434245751	FC0B3F	7570 528308	MATVEY FROLOV	{"phone": "+70887747634"}
0005434245752	F88B60	8786 569717	ELENA SIDOROVA	{"email": "sidorova-elena1969@postgrespro.ru", "phone": "+70343126297"}
0005434245753	89CF1C	2536 664620	VIKTOR STEPANOV	{"email": "v.stepanov-081973@postgrespro.ru", "phone": "+70975614364"}
0005434245754	B3350F	2766 702978	IRINA KUZNECOVA	{"email": "ikuznecova_1987@postgrespro.ru", "phone": "+70829981065"}
0005434245755	5488C8	3616 393923	EKATERINA SEMENOVA	{"phone": "+70144641190"}
0005434245756	AC6904	3899 986341	VLADIMIR ANDREEV	{"phone": "+70020204810"}
0005434245757	0E1EEC	2380 019956	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr_1984@postgrespro.ru", "phone": "+70080863331"}
0005434245758	0E1EEC	0683 258755	VALENTINA NIKITINA	{"phone": "+70324351976"}
0005434245759	0E1EEC	5304 598934	EVGENIYA ZHUKOVA	{"email": "evgeniya_zhukova-051973@postgrespro.ru", "phone": "+70055805709"}
0005434245760	2A42FE	0610 899871	NINA KOROLEVA	{"phone": "+70850972622"}
0005434245761	2A42FE	7668 684317	NATALYA DAVYDOVA	{"email": "davydovan.071981@postgrespro.ru", "phone": "+70476155319"}
0005434245762	2A42FE	3137 700981	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana30011981@postgrespro.ru", "phone": "+70339213593"}
0005434245763	7FF607	7222 743049	YULIYA NIKIFOROVA	{"phone": "+70931578932"}
0005434245764	985810	6045 885651	VLADIMIR SCHERBAKOV	{"phone": "+70578060364"}
0005434245765	1F0FC3	6862 897293	VALENTINA POPOVA	{"email": "v.popova_021970@postgrespro.ru", "phone": "+70211766614"}
0005434245766	79E931	8207 983320	VERA TITOVA	{"email": "titova.v24091979@postgrespro.ru", "phone": "+70378761514"}
0005434245767	79E931	6997 826733	MARIYA PETROVA	{"email": "petrova_mariya24081969@postgrespro.ru", "phone": "+70827883447"}
0005434245768	DB6560	9652 692237	DENIS BARANOV	{"phone": "+70876386436"}
0005434245769	DB6560	8130 635817	SVETLANA NIKOLAEVA	{"phone": "+70256213675"}
0005434245770	14E934	1539 053568	ANASTASIYA VLASOVA	{"email": "vlasova-a-051973@postgrespro.ru", "phone": "+70303031876"}
0005434245771	65A8BA	2408 569303	ANATOLIY KISELEV	{"email": "kiselev_a031980@postgrespro.ru", "phone": "+70511175170"}
0005434245772	65A8BA	0325 838303	NIKITA IVANOV	{"phone": "+70293600324"}
0005434245773	C8449B	6776 107874	VYACHESLAV ISAEV	{"email": "isaev-vyacheslav_14031977@postgrespro.ru", "phone": "+70995176060"}
0005434245774	86B91D	6651 708350	DARYA FILIPPOVA	{"email": "filippovadarya_121971@postgrespro.ru", "phone": "+70722440671"}
0005434245775	86B91D	7929 883702	POLINA ISAEVA	{"phone": "+70201375521"}
0005434245776	D4F6A8	7429 627581	LYUBOV MOISEEVA	{"phone": "+70570433683"}
0005434245777	83C308	8062 451554	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey_1967@postgrespro.ru", "phone": "+70078923590"}
0005434245778	83C308	0587 780045	ALEKSEY MARTYNOV	{"email": "martynova-1976@postgrespro.ru", "phone": "+70032832617"}
0005434245779	3C6E3D	4324 839161	KONSTANTIN DENISOV	{"phone": "+70807104911"}
0005434245780	4C7E0D	8981 672889	OLGA RODIONOVA	{"email": "rodionova-olga-111981@postgrespro.ru", "phone": "+70843912673"}
0005434245781	6D0A29	0376 650071	LIDIYA PETROVA	{"phone": "+70210630353"}
0005434245782	1FC03A	5232 102424	ARTUR BORISOV	{"email": "a.borisov-17081962@postgrespro.ru", "phone": "+70852098635"}
0005434245783	8CD846	2027 318800	SVETLANA KOLESNIKOVA	{"phone": "+70667802927"}
0005434245784	1B92A3	5856 318399	DARINA ARKHIPOVA	{"phone": "+70212310382"}
0005434245785	A0FE9D	1194 362904	ANNA ZHURAVLEVA	{"email": "a-zhuravleva.27051979@postgrespro.ru", "phone": "+70439221798"}
0005434245786	A0FE9D	1781 267033	DARYA VOLKOVA	{"phone": "+70902092711"}
0005434245787	FC97AD	1203 748817	OLGA SEMENOVA	{"phone": "+70743263774"}
0005434245788	FC97AD	3096 280748	YURIY NOVIKOV	{"phone": "+70398099067"}
0005434245789	A4A331	8039 012253	VENERA SOROKINA	{"phone": "+70839489116"}
0005434245790	A4A331	9879 249690	EKATERINA SOLOVEVA	{"email": "soloveva.ekaterina_081969@postgrespro.ru", "phone": "+70406207203"}
0005434245791	75F0A6	7473 813111	RAFIK POPOV	{"phone": "+70866181357"}
0005434245792	75F0A6	2283 191398	ZARINA FROLOVA	{"phone": "+70950914366"}
0005434245793	373B72	0822 169121	SERGEY KAZAKOV	{"email": "kazakov_sergey041972@postgrespro.ru", "phone": "+70762701089"}
0005434245794	D2A8E9	9071 603723	VALERIY PAVLOV	{"email": "pavlov-valeriy.03041975@postgrespro.ru", "phone": "+70373286308"}
0005434245795	D2A8E9	9385 456009	KIRILL ALEKSANDROV	{"email": "kirillaleksandrov_1968@postgrespro.ru", "phone": "+70072557044"}
0005434245796	D2A8E9	9412 321940	VASILIY FEDOROV	{"email": "vasiliyfedorov07011961@postgrespro.ru", "phone": "+70416428015"}
0005434245797	5ED6BD	6081 810285	VIKTOR KAZAKOV	{"email": "v-kazakov.25021975@postgrespro.ru", "phone": "+70875945482"}
0005434245798	8B8CD2	9345 583519	VLADIMIR FEDOROV	{"phone": "+70337351557"}
0005434245799	CB7995	7797 925046	ANNA ALEKSANDROVA	{"phone": "+70573262421"}
0005434245800	CB7995	1445 581832	NADEZHDA FOMINA	{"email": "fomina_nadezhda_1980@postgrespro.ru", "phone": "+70632276395"}
0005434245801	680AD9	4688 845726	LYUDMILA NESTEROVA	{"email": "nesterova-l-1977@postgrespro.ru", "phone": "+70482317668"}
0005434245802	680AD9	5335 359063	VYACHESLAV KRASNOV	{"email": "vyacheslav.krasnov1973@postgrespro.ru", "phone": "+70219378998"}
0005434245803	041587	8238 453196	KIRILL MIKHAYLOV	{"phone": "+70986202826"}
0005434245804	CE69D3	5682 104364	ALEKSEY KUZMIN	{"phone": "+70229799355"}
0005434245805	CE69D3	6082 021344	ANASTASIYA NIKITINA	{"email": "nikitinaa1968@postgrespro.ru", "phone": "+70737675649"}
0005434245806	CE69D3	2202 963441	ANDREY SOLOVEV	{"phone": "+70071806940"}
0005434245807	77BC0E	7574 292407	KLAVDIYA SAVELEVA	{"email": "saveleva_k1966@postgrespro.ru", "phone": "+70613475920"}
0005434245808	77BC0E	2016 934116	TATYANA ALEKSEEVA	{"phone": "+70895743578"}
0005434245809	AAA65C	5374 103698	DENIS SCHERBAKOV	{"email": "d.scherbakov_011970@postgrespro.ru", "phone": "+70800980154"}
0005434245810	AAA65C	6949 923439	VLADIMIR VASILEV	{"email": "vasilevv1979@postgrespro.ru", "phone": "+70617365650"}
0005434245811	93489A	2404 505291	EVGENIY SHEVCHENKO	{"phone": "+70963506088"}
0005434245812	D3C831	2064 094335	GULNARA NIKIFOROVA	{"email": "g_nikiforova1971@postgrespro.ru", "phone": "+70187021094"}
0005434245813	F60B66	4579 109209	KSENIYA MELNIKOVA	{"phone": "+70201024508"}
0005434245814	F60B66	9748 622354	SERGEY ROMANOV	{"email": "romanov_sergey081970@postgrespro.ru", "phone": "+70443080334"}
0005434245815	36A1C8	6978 084997	ALEKSANDR ORLOV	{"email": "a_orlov_1987@postgrespro.ru", "phone": "+70005573659"}
0005434245816	45C2C2	7699 142923	IVAN GAVRILOV	{"phone": "+70873303249"}
0005434245817	8F42E7	8747 778890	ALINA ZHURAVLEVA	{"email": "zhuravleva.a_16111980@postgrespro.ru", "phone": "+70889416318"}
0005434245818	8F42E7	0229 500035	KSENIYA SOROKINA	{"phone": "+70258353207"}
0005434245819	3ADD77	9001 246656	VYACHESLAV SEMENOV	{"phone": "+70014783916"}
0005434245820	7B561A	7638 796061	SVETLANA AKIMOVA	{"phone": "+70921072633"}
0005434245821	BC9268	7802 059423	DMITRIY GUSEV	{"email": "d_gusev.09061975@postgrespro.ru", "phone": "+70356539766"}
0005434245822	BC9268	1996 363919	PAVEL GUSEV	{"phone": "+70253831070"}
0005434245823	42352F	1995 759327	POLINA ZAKHAROVA	{"email": "polina.zakharova.1966@postgrespro.ru", "phone": "+70104281348"}
0005434245824	42352F	5477 260196	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov-08121972@postgrespro.ru", "phone": "+70983572099"}
0005434245825	10D528	7733 833726	SERGEY TIKHONOV	{"phone": "+70639929324"}
0005434245826	10D528	1143 609892	MARIYA GAVRILOVA	{"phone": "+70354331172"}
0005434245827	E28064	1661 593619	DANILA BARANOV	{"phone": "+70130631875"}
0005434245828	77CB2F	8481 109267	SVETLANA KOMAROVA	{"email": "komarova.svetlana.27051971@postgrespro.ru", "phone": "+70354821589"}
0005434245829	D87FE0	3214 743440	KIRILL KOROLEV	{"email": "korolev-k.03121982@postgrespro.ru", "phone": "+70066081972"}
0005434245830	D87FE0	1304 717944	DMITRIY STEPANOV	{"email": "dmitriystepanov27051967@postgrespro.ru", "phone": "+70869543623"}
0005434245831	6F59AF	0660 900252	LYUDMILA FILIPPOVA	{"phone": "+70576188277"}
0005434245832	6F59AF	8256 574012	ANNA MAKAROVA	{"phone": "+70717496863"}
0005434245833	0A046C	8205 056721	MARIYA GRISHINA	{"email": "grishina_mariya-09081971@postgrespro.ru", "phone": "+70361987666"}
0005434245834	0E3CE0	8857 741008	MARINA CHERNOVA	{"email": "m.chernova_081975@postgrespro.ru", "phone": "+70491022105"}
0005434245835	BC15CD	8745 459723	KLARA NIKITINA	{"phone": "+70633817823"}
0005434245836	8DEC01	9133 052528	EVGENIYA SOLOVEVA	{"email": "evgeniya-soloveva_24121980@postgrespro.ru", "phone": "+70914674504"}
0005434245837	3AEBA4	8155 261848	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr-1987@postgrespro.ru", "phone": "+70786145161"}
0005434245838	4D3D61	3963 653374	SERGEY KUZNECOV	{"phone": "+70747702763"}
0005434245839	56D183	6639 414102	VALERIYA YAKOVLEVA	{"phone": "+70666494865"}
0005434245840	7464C3	3613 807485	ANTONINA FILIPPOVA	{"phone": "+70797150494"}
0005434245841	66832D	8821 144106	VITALIY ZHUKOV	{"phone": "+70749642746"}
0005434245842	66832D	1185 941229	FEDOR MELNIKOV	{"phone": "+70277410836"}
0005434245843	633B7C	2880 175268	OLGA CHERNOVA	{"email": "chernova.olga09011965@postgrespro.ru", "phone": "+70816248458"}
0005434245844	633B7C	4303 463656	SVETLANA EFIMOVA	{"email": "efimova_svetlana-1971@postgrespro.ru", "phone": "+70703902392"}
0005434245845	633B7C	1404 892678	SVETLANA YAKOVLEVA	{"phone": "+70605316190"}
0005434245846	9F1A64	3853 811912	VASILIY NAZAROV	{"email": "nazarovv_1982@postgrespro.ru", "phone": "+70720673531"}
0005434245847	A0998B	4980 433831	SERGEY PAVLOV	{"phone": "+70401837012"}
0005434245848	2A27AD	9910 642426	KONSTANTIN ANDREEV	{"phone": "+70197442169"}
0005434247100	D316F5	9300 075514	VLADIMIR ILIN	{"email": "vladimirilin.21101963@postgrespro.ru", "phone": "+70871687388"}
0005434247101	D316F5	7014 088019	VLADISLAV MELNIKOV	{"email": "melnikovvladislav.111975@postgrespro.ru", "phone": "+70914276849"}
0005434247102	5F19DD	8512 068141	VLADIMIR SMIRNOV	{"phone": "+70136320335"}
0005434247103	E88A23	8847 168883	SERGEY MAKAROV	{"phone": "+70649537933"}
0005434247104	A323FF	6292 826748	STEPAN ISAEV	{"phone": "+70272465682"}
0005434247105	03A520	4317 994541	VIKTORIYA SEMENOVA	{"phone": "+70143469154"}
0005434247106	189D7E	8973 591917	VLADIMIR KUZNECOV	{"email": "kuznecov.v20041972@postgrespro.ru", "phone": "+70704324104"}
0005434247107	74435B	7253 267619	EKATERINA NIKITINA	{"phone": "+70808833494"}
0005434247108	74435B	4770 686057	TATYANA TIKHONOVA	{"email": "tatyanatikhonova1978@postgrespro.ru", "phone": "+70850961722"}
0005434247109	74435B	7878 179063	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy27081976@postgrespro.ru", "phone": "+70934543194"}
0005434247110	74435B	7743 546889	MAKSIM SMIRNOV	{"email": "smirnov-m-1976@postgrespro.ru", "phone": "+70062050124"}
0005434247111	2C4421	9512 350361	NIKITA SOKOLOV	{"email": "sokolov.n_1969@postgrespro.ru", "phone": "+70561320038"}
0005434247112	448802	1746 191193	GENNADIY IVANOV	{"phone": "+70412847158"}
0005434247113	832F80	8198 219379	DANILA FEDOROV	{"phone": "+70727154310"}
0005434247114	01E389	1103 383902	NINA MELNIKOVA	{"phone": "+70764669535"}
0005434247115	01E389	5938 664194	DMITRIY ZAYCEV	{"email": "dmitriy-zaycev-1971@postgrespro.ru", "phone": "+70814414578"}
0005434247116	E5BE69	3962 158062	MARIYA KUZNECOVA	{"phone": "+70596618925"}
0005434247117	190E61	2033 692595	ARTUR MIKHAYLOV	{"phone": "+70166913585"}
0005434247118	DB6735	7937 874347	ELENA ZHURAVLEVA	{"phone": "+70662102472"}
0005434247119	DB6735	5731 911830	VIKTOR POPOV	{"email": "viktorpopov_01121981@postgrespro.ru", "phone": "+70511104379"}
0005434247120	D6CCB3	8638 184917	ALBERT IVANOV	{"phone": "+70952095461"}
0005434247121	D6CCB3	5363 321092	NIKOLAY IVANOV	{"phone": "+70407784266"}
0005434247122	D6CCB3	4751 047911	MAKSIM KUZNECOV	{"phone": "+70713232512"}
0005434247123	4B6D3B	9644 109586	ALEKSEY PETROV	{"phone": "+70135951042"}
0005434247124	1DA2DA	7117 891183	KSENIYA POPOVA	{"phone": "+70355921143"}
0005434247125	1DA2DA	0986 424393	MARINA VOLKOVA	{"phone": "+70940566233"}
0005434247126	CE202B	2750 541932	ALEKSANDRA IVANOVA	{"email": "ivanova.aleksandra.051973@postgrespro.ru", "phone": "+70275994745"}
0005434247127	469FA4	9217 344672	NIKOLAY IVANOV	{"email": "ivanov_nikolay_041975@postgrespro.ru", "phone": "+70284402136"}
0005434247128	D1CE5C	8100 862369	SERGEY KISELEV	{"phone": "+70581087957"}
0005434247129	D1CE5C	3333 258509	POLINA KISELEVA	{"email": "kiselevapolina.021970@postgrespro.ru", "phone": "+70313839555"}
0005434247130	E0A17D	8104 522191	IRINA PAVLOVA	{"email": "i_pavlova-10051968@postgrespro.ru", "phone": "+70923219967"}
0005434247131	E0A17D	6110 211858	NIKOLAY KAZAKOV	{"email": "nikolay_kazakov.071968@postgrespro.ru", "phone": "+70169957482"}
0005434247132	4D6DA1	8321 861671	TATYANA MATVEEVA	{"email": "tatyana.matveeva.1965@postgrespro.ru", "phone": "+70707731078"}
0005434247133	8DFDA5	4116 165491	IVAN GERASIMOV	{"email": "igerasimov_1970@postgrespro.ru", "phone": "+70860415982"}
0005434247134	8DFDA5	7957 327663	ALEKSANDR KUZNECOV	{"email": "kuznecov_a_031973@postgrespro.ru", "phone": "+70537794554"}
0005434247135	776B23	0386 990856	TATYANA NIKOLAEVA	{"email": "nikolaevat.1972@postgrespro.ru", "phone": "+70235935327"}
0005434247136	25F515	6844 262437	NIKOLAY STEPANOV	{"email": "n_stepanov_04121968@postgrespro.ru", "phone": "+70015166991"}
0005434247137	F3C427	9183 389621	ALEKSANDR ILIN	{"phone": "+70351989231"}
0005434247138	F3C427	8200 371166	VLADIMIR VLASOV	{"phone": "+70568209259"}
0005434247139	FC44BA	3582 036939	ALENA MIKHAYLOVA	{"email": "mikhaylovaa_021977@postgrespro.ru", "phone": "+70233039280"}
0005434247140	6DF757	8148 698952	ELENA NIKIFOROVA	{"phone": "+70566440613"}
0005434247141	881048	1389 616932	KIRILL IVANOV	{"email": "ivanovkirill111957@postgrespro.ru", "phone": "+70961467048"}
0005434247142	881048	9745 387710	ANNA KULIKOVA	{"phone": "+70182768169"}
0005434247143	3A8770	6104 740089	ELIZAVETA MIKHAYLOVA	{"phone": "+70591602987"}
0005434247144	64F190	5442 889940	NIKITA NOVIKOV	{"phone": "+70141039261"}
0005434247145	F1DFCF	2727 995789	MAKSIM KONOVALOV	{"email": "mkonovalov.071970@postgrespro.ru", "phone": "+70045644445"}
0005434247146	FD3935	0173 025629	ALEKSEY PETROV	{"phone": "+70289565623"}
0005434247147	8854A5	3533 385733	OLESYA ARKHIPOVA	{"email": "arkhipova-o_1977@postgrespro.ru", "phone": "+70731912277"}
0005434247148	BC9BD1	6957 880287	GULIYA DENISOVA	{"phone": "+70891236385"}
0005434247149	BC9BD1	3645 231613	DMITRIY FOMIN	{"email": "d-fomin.081960@postgrespro.ru", "phone": "+70961706693"}
0005434247150	BC9BD1	2743 270244	KIRILL GORBUNOV	{"phone": "+70196631913"}
0005434247151	B83648	2103 453938	VIKTOR MOISEEV	{"email": "v_moiseev.13051982@postgrespro.ru", "phone": "+70641016433"}
0005434247152	7AEE0D	3758 746187	DMITRIY IVANOV	{"email": "ivanov.d.041979@postgrespro.ru", "phone": "+70966512499"}
0005434247153	3D7879	3730 637792	ELENA ISAEVA	{"email": "isaeva.elena18051968@postgrespro.ru", "phone": "+70425533636"}
0005434247154	3D7879	4187 181201	ALEKSANDR SMIRNOV	{"email": "smirnova_19091972@postgrespro.ru", "phone": "+70393484572"}
0005434247155	113BBC	4314 061411	VIKTORIYA KOROLEVA	{"email": "vkoroleva-03051982@postgrespro.ru", "phone": "+70022167844"}
0005434247156	F16EE7	8223 192421	DANIIL STEPANOV	{"phone": "+70185245695"}
0005434247157	168590	8296 810048	RAISA PAVLOVA	{"email": "pavlova.r04021977@postgrespro.ru", "phone": "+70428560339"}
0005434247158	06054C	1984 389533	DMITRIY ORLOV	{"phone": "+70744492796"}
0005434247159	654B7F	8644 815388	DMITRIY BORISOV	{"email": "dborisov.1971@postgrespro.ru", "phone": "+70960760746"}
0005434247160	5B22A9	6564 943340	REGINA IVANOVA	{"email": "ivanova.r-09051968@postgrespro.ru", "phone": "+70447979065"}
0005434247161	F74375	3572 822142	LIDIYA MEDVEDEVA	{"phone": "+70952807868"}
0005434247162	F238E7	3508 394126	LYUDMILA MATVEEVA	{"phone": "+70390079524"}
0005434247163	F238E7	7471 164999	LYUDMILA SEMENOVA	{"email": "l-semenova_1976@postgrespro.ru", "phone": "+70084291049"}
0005434247164	54B083	0810 109246	GALINA POPOVA	{"email": "popovag-13061976@postgrespro.ru", "phone": "+70783574492"}
0005434247165	BBAB47	8853 497746	VLADIMIR BELOV	{"phone": "+70758580479"}
0005434247166	6C9985	1843 584065	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev_1977@postgrespro.ru", "phone": "+70671349818"}
0005434247167	6C9985	5569 149209	IVAN KOZLOV	{"phone": "+70693822740"}
0005434247168	F977BE	8913 160379	MIKHAIL VASILEV	{"email": "m-vasilev24081980@postgrespro.ru", "phone": "+70549192626"}
0005434247169	62A4E2	0533 938545	ELENA SERGEEVA	{"email": "sergeevaelena-1973@postgrespro.ru", "phone": "+70134227049"}
0005434247170	62A4E2	1653 549885	ALEKSANDR GAVRILOV	{"email": "agavrilov021970@postgrespro.ru", "phone": "+70655458215"}
0005434247171	62A4E2	1083 968189	YURIY ISAEV	{"phone": "+70115445483"}
0005434247172	520B55	5734 827727	VIKTOR ROMANOV	{"email": "v-romanov06021973@postgrespro.ru", "phone": "+70583357436"}
0005434247173	727864	5362 516606	SVETLANA LOGINOVA	{"email": "svetlana-loginova_121971@postgrespro.ru", "phone": "+70343988272"}
0005434247174	BC3728	6442 215249	DENIS PAVLOV	{"email": "pavlov-d.23101974@postgrespro.ru", "phone": "+70228328729"}
0005434247175	BC3728	6260 100655	MIKHAIL GRIGOREV	{"phone": "+70568018588"}
0005434247176	0093B2	8777 193285	DMITRIY STEPANOV	{"phone": "+70303057946"}
0005434247177	98524C	3889 127940	MARINA FEDOROVA	{"phone": "+70359759946"}
0005434247178	7F421C	5251 961153	ANTONINA FROLOVA	{"email": "frolova_antonina-1977@postgrespro.ru", "phone": "+70337857007"}
0005434247179	7F421C	3395 597260	SVETLANA IVANOVA	{"phone": "+70623320684"}
0005434247180	C08030	6284 429831	VALENTINA ORLOVA	{"phone": "+70644590138"}
0005434247181	A2CCB5	0945 709918	ALEKSEY TARASOV	{"email": "tarasov.aleksey1967@postgrespro.ru", "phone": "+70614099981"}
0005434247182	CC7133	0182 291293	KSENIYA MELNIKOVA	{"email": "k-melnikova061978@postgrespro.ru", "phone": "+70668209655"}
0005434247183	8CDBAE	6940 854177	ANASTASIYA FROLOVA	{"email": "frolova_anastasiya_28081969@postgrespro.ru", "phone": "+70154439673"}
0005434247184	B8DFA0	7887 889764	ILYA SOKOLOV	{"phone": "+70632175884"}
0005434247185	A774ED	4532 650136	OKSANA TIKHONOVA	{"email": "o_tikhonova_1974@postgrespro.ru", "phone": "+70492208958"}
0005434247186	A774ED	4564 003908	MAKSIM FEDOROV	{"email": "fedorov-m111983@postgrespro.ru", "phone": "+70189987687"}
0005434247187	C6E63F	8312 511006	ANATOLIY MATVEEV	{"email": "matveev.anatoliy.10091969@postgrespro.ru", "phone": "+70878503793"}
0005434247188	C6E63F	0267 690169	SVETLANA KONDRATEVA	{"phone": "+70491431421"}
0005434247189	7C3783	5887 608607	NIKITA NIKOLAEV	{"email": "nikita.nikolaev1981@postgrespro.ru", "phone": "+70251916652"}
0005434247190	72760E	1307 226507	FARIDA MAKSIMOVA	{"phone": "+70205093943"}
0005434247191	3FF9DA	4625 316836	VLADIMIR KISELEV	{"email": "vladimir-kiselev.011974@postgrespro.ru", "phone": "+70125390616"}
0005434247192	923ADB	3314 639415	LEONID KULIKOV	{"email": "kulikov.l.18101974@postgrespro.ru", "phone": "+70194562542"}
0005434247193	C378C2	8705 088206	RIMMA ABRAMOVA	{"phone": "+70621877509"}
0005434247194	C378C2	0341 571013	ANASTASIYA SOKOLOVA	{"email": "sokolova-a_24051973@postgrespro.ru", "phone": "+70754272189"}
0005434247195	3AF80E	8981 634970	ANNA KOROLEVA	{"phone": "+70216590276"}
0005434247196	3473BF	8040 824142	BORIS TIKHONOV	{"email": "tikhonov.boris-13051960@postgrespro.ru", "phone": "+70419371423"}
0005434247197	10972E	9909 498163	VASILIY MELNIKOV	{"email": "vasiliy-melnikov1964@postgrespro.ru", "phone": "+70328992465"}
0005434247198	10972E	5201 766577	ALEKSEY ROMANOV	{"email": "romanova-031963@postgrespro.ru", "phone": "+70961225305"}
0005434247199	A1A922	4127 523480	OLGA POPOVA	{"email": "olga-popova091969@postgrespro.ru", "phone": "+70108574129"}
0005434247200	802806	8267 178112	ANNA MASLOVA	{"email": "maslova.a061983@postgrespro.ru", "phone": "+70230517571"}
0005434247201	915B36	3405 941010	SERGEY PAVLOV	{"phone": "+70722994607"}
0005434247202	344456	8871 072284	OLEG KAZAKOV	{"email": "okazakov_07121972@postgrespro.ru", "phone": "+70014508785"}
0005434247203	344456	6460 379529	ALEKSANDR KUZNECOV	{"phone": "+70509162136"}
0005434247204	E243AA	4558 447100	NATALYA YUDINA	{"email": "natalya_yudina-051957@postgrespro.ru", "phone": "+70537452939"}
0005434247205	AC81A3	5892 858727	MARINA MIKHAYLOVA	{"phone": "+70928312079"}
0005434247206	D84FC9	7715 876222	VYACHESLAV IVANOV	{"phone": "+70824108196"}
0005434247207	C8CB94	8419 381288	MARIYA LUKYANOVA	{"email": "lukyanova.m.111956@postgrespro.ru", "phone": "+70841422162"}
0005434247208	AB58A6	2652 029217	NIKOLAY SEMENOV	{"email": "semenov_nikolay20061971@postgrespro.ru", "phone": "+70311835802"}
0005434247209	73D72E	2677 050024	OKSANA FILATOVA	{"email": "oksana_filatova-1968@postgrespro.ru", "phone": "+70200868851"}
0005434247210	73D72E	0243 433610	YULIYA ZAKHAROVA	{"email": "yuliya_zakharova-071983@postgrespro.ru", "phone": "+70166994677"}
0005434247211	4D1174	5895 585907	YULIYA ANTONOVA	{"phone": "+70315905818"}
0005434247212	4D1174	4529 084105	MARINA VLASOVA	{"phone": "+70677568410"}
0005434247213	512DC4	3528 159560	IGOR KUZMIN	{"phone": "+70578345163"}
0005434247214	E427BB	1209 090973	SVYATOSLAV ALEKSEEV	{"phone": "+70456115787"}
0005434247215	E427BB	0212 910165	GALINA KUZNECOVA	{"email": "g-kuznecova_13071966@postgrespro.ru", "phone": "+70760804169"}
0005434247216	301CF1	5535 827044	NATALYA FOMINA	{"phone": "+70962999093"}
0005434247217	0E5B31	6293 609847	NIKITA MIRONOV	{"phone": "+70605467094"}
0005434247218	0E5B31	0398 321052	MARIYA MEDVEDEVA	{"email": "medvedeva_m-1979@postgrespro.ru", "phone": "+70628613130"}
0005434247219	A16692	9318 183777	YAN BORISOV	{"email": "y-borisov.09101964@postgrespro.ru", "phone": "+70251125431"}
0005434247220	F56257	9448 093853	VYACHESLAV BARANOV	{"phone": "+70059262460"}
0005434251910	822B14	5000 854378	ALEKSEY SCHERBAKOV	{"phone": "+70872305272"}
0005434247221	814A76	1515 651919	ELENA AFANASEVA	{"email": "e.afanaseva111968@postgrespro.ru", "phone": "+70723701816"}
0005434247222	7DB501	4635 039164	ALEKSEY IVANOV	{"phone": "+70267403930"}
0005434247223	7DB501	6511 306596	YURIY FOMIN	{"phone": "+70212580372"}
0005434251858	974DA9	5386 002133	VIKTOR IVANOV	{"phone": "+70533074261"}
0005434251859	DABADF	7221 641344	NIKOLAY TIMOFEEV	{"phone": "+70815506206"}
0005434251795	4C4043	7103 758166	OLGA OSIPOVA	{"email": "osipova.o-25031970@postgrespro.ru", "phone": "+70863785907"}
0005434251796	4C4043	5760 722642	VLADIMIR BONDARENKO	{"phone": "+70269065294"}
0005434251797	6C99F5	8635 918156	GALINA EFREMOVA	{"email": "galinaefremova_02051973@postgrespro.ru", "phone": "+70440503976"}
0005434251798	5A7217	3076 196966	IRINA BELOVA	{"email": "irinabelova011976@postgrespro.ru", "phone": "+70073973898"}
0005434251799	9A0B91	0791 085335	LYUBOV ERMAKOVA	{"email": "lyubov.ermakova.28031963@postgrespro.ru", "phone": "+70227948850"}
0005434251800	62CD11	6504 941840	EVGENIY BELOV	{"phone": "+70278459851"}
0005434251801	62CD11	6406 634090	ALEKSANDRA VLASOVA	{"email": "aleksandra_vlasova.16061983@postgrespro.ru", "phone": "+70604835384"}
0005434251802	50EB2E	9594 485632	ELENA ZAYCEVA	{"email": "elena_zayceva-1961@postgrespro.ru", "phone": "+70608882586"}
0005434251803	9E83A2	2405 964252	ANNA SMIRNOVA	{"email": "smirnovaanna.081955@postgrespro.ru", "phone": "+70321255500"}
0005434251804	405835	6553 052272	DMITRIY ISAEV	{"phone": "+70625835543"}
0005434251805	7D3B68	4818 303318	EVGENIY KOROLEV	{"phone": "+70173041217"}
0005434251806	7D3B68	7184 081906	OLGA BELOVA	{"email": "olga-belova_1968@postgrespro.ru", "phone": "+70223943433"}
0005434251807	5701EC	6517 479724	GALINA NAZAROVA	{"email": "nazarovagalina.101967@postgrespro.ru", "phone": "+70826972076"}
0005434251808	920841	9783 278012	MARIYA ZAYCEVA	{"email": "mariya.zayceva.29101977@postgrespro.ru", "phone": "+70558109184"}
0005434251809	0291EC	4431 301349	IRINA SMIRNOVA	{"phone": "+70644765349"}
0005434251810	0291EC	1414 598335	ARTEM OSIPOV	{"phone": "+70573289232"}
0005434251811	D93675	9970 328540	ALEKSEY DENISOV	{"email": "denisov.aleksey-27121971@postgrespro.ru", "phone": "+70611150311"}
0005434251812	5A9E3E	1958 186639	SERGEY BARANOV	{"email": "s-baranov.1980@postgrespro.ru", "phone": "+70575685132"}
0005434251813	A08ABF	2847 950459	VLADIMIR ISAEV	{"email": "isaev.v-1974@postgrespro.ru", "phone": "+70953858587"}
0005434251814	1663B2	4477 158447	ALEKSANDR PETROV	{"email": "aleksandr-petrov061977@postgrespro.ru", "phone": "+70965296915"}
0005434251815	9D6B7A	5865 418739	MAKSIM GERASIMOV	{"phone": "+70133078859"}
0005434251816	9D6B7A	8451 193270	EKATERINA ZAKHAROVA	{"phone": "+70318412211"}
0005434251817	9D6B7A	0719 521583	ELIZAVETA GAVRILOVA	{"phone": "+70044242317"}
0005434251818	C1240D	0210 028085	ANNA KUZMINA	{"phone": "+70446683044"}
0005434251819	06BF40	6713 065938	EKATERINA EGOROVA	{"email": "egorovae-1970@postgrespro.ru", "phone": "+70228144632"}
0005434251820	06BF40	7213 437066	LYUDMILA KOROLEVA	{"email": "korolevalyudmila-1984@postgrespro.ru", "phone": "+70191200668"}
0005434251821	06BF40	0488 737135	NATALYA ZHURAVLEVA	{"phone": "+70060044495"}
0005434251822	28E90E	2480 207331	OLGA BORISOVA	{"email": "olga-borisova_29071963@postgrespro.ru", "phone": "+70842098193"}
0005434251823	B20E29	5386 788204	DMITRIY NIKOLAEV	{"email": "dnikolaev05111976@postgrespro.ru", "phone": "+70558641228"}
0005434251824	C400BB	5071 060087	ELENA ORLOVA	{"email": "elena-orlova041970@postgrespro.ru", "phone": "+70817217321"}
0005434251825	D717A6	3817 900569	LYUDMILA SOROKINA	{"email": "lyudmila-sorokina_1975@postgrespro.ru", "phone": "+70970897952"}
0005434251826	C8A994	0984 969088	EMMA NIKIFOROVA	{"email": "nikiforova.e_1954@postgrespro.ru", "phone": "+70045251657"}
0005434251827	171450	4144 062908	NATALYA AFANASEVA	{"phone": "+70687500265"}
0005434251828	C2C564	6205 977739	VERA GUSEVA	{"phone": "+70650144335"}
0005434251829	7F0EC2	8136 190789	VLADIMIR IVANOV	{"email": "ivanov_v.121968@postgrespro.ru", "phone": "+70992840211"}
0005434251830	F17989	1296 989602	DENIS BONDARENKO	{"email": "bondarenko_d_051973@postgrespro.ru", "phone": "+70369213951"}
0005434251831	F17989	5279 413230	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov.1968@postgrespro.ru", "phone": "+70779863630"}
0005434251832	A9F75C	0681 238987	ELENA SAVELEVA	{"email": "esaveleva.061976@postgrespro.ru", "phone": "+70838494206"}
0005434251833	500123	6799 332681	ANDREY MAKAROV	{"phone": "+70217355462"}
0005434251834	500123	5172 792231	GALINA ABRAMOVA	{"email": "abramovag.091973@postgrespro.ru", "phone": "+70606753976"}
0005434251835	ABB9AB	8682 540082	NIKOLAY OSIPOV	{"email": "osipov.nikolay_1966@postgrespro.ru", "phone": "+70677306434"}
0005434251836	0692AA	2692 207697	ALIYA SOROKINA	{"phone": "+70696506274"}
0005434251837	0692AA	7248 725749	MARINA EFREMOVA	{"phone": "+70935450658"}
0005434251838	0692AA	6919 308580	IGNAT KUZNECOV	{"email": "kuznecovignat_1967@postgrespro.ru", "phone": "+70267428168"}
0005434251839	0810F5	1084 143600	ALEKSANDR TIMOFEEV	{"phone": "+70078569723"}
0005434251840	F5F5D9	2011 919610	SERGEY EGOROV	{"email": "egorov_s-021966@postgrespro.ru", "phone": "+70969731334"}
0005434251841	91910E	6883 609142	IVAN MOROZOV	{"email": "imorozov-1964@postgrespro.ru", "phone": "+70570464968"}
0005434251842	7A2F33	3558 620936	KONSTANTIN DENISOV	{"phone": "+70643446139"}
0005434251843	BEA92D	2174 673875	DINA DANILOVA	{"email": "dina.danilova_06021971@postgrespro.ru", "phone": "+70924655469"}
0005434251844	6CEAFB	7985 806286	ANATOLIY BORISOV	{"phone": "+70370817193"}
0005434251845	EEB126	7359 906710	GALINA BORISOVA	{"phone": "+70689455710"}
0005434251846	10319E	6647 651659	GRIGORIY MOISEEV	{"email": "moiseev.grigoriy_041963@postgrespro.ru", "phone": "+70790070510"}
0005434251847	10319E	5932 762092	MIKHAIL IVANOV	{"phone": "+70057941842"}
0005434251848	3440C7	7806 562738	ANASTASIYA BORISOVA	{"phone": "+70519581494"}
0005434251849	C9BAD6	7731 265062	OLGA RYABOVA	{"email": "ryabova-o.1969@postgrespro.ru", "phone": "+70632110212"}
0005434251850	C9BAD6	0815 089710	GALINA ZAYCEVA	{"email": "g.zayceva-011974@postgrespro.ru", "phone": "+70701533044"}
0005434251851	76886D	4033 217446	IRINA MARTYNOVA	{"phone": "+70443108124"}
0005434251852	E1F0E2	3298 248318	ALEKSEY VASILEV	{"phone": "+70987152804"}
0005434251853	5C83A2	6729 760914	RAMIL ZHUKOV	{"phone": "+70595709218"}
0005434251854	5C83A2	2557 896811	SERGEY FEDOROV	{"phone": "+70814133861"}
0005434251855	EE0CC1	0538 525871	NIKOLAY SCHERBAKOV	{"phone": "+70479833616"}
0005434251856	EE0CC1	4701 004597	IVAN KUZNECOV	{"email": "kuznecovi26121965@postgrespro.ru", "phone": "+70785640336"}
0005434251857	847B18	8002 488011	DMITRIY STEPANOV	{"email": "stepanov-d071974@postgrespro.ru", "phone": "+70490190403"}
0005434251860	22D20C	5884 511961	ZINAIDA NOVIKOVA	{"email": "zinaida.novikova.19041960@postgrespro.ru", "phone": "+70850271753"}
0005434251861	22D20C	3958 543590	ANASTASIYA KUZMINA	{"phone": "+70513340355"}
0005434251862	078EF5	1505 826492	ALEKSANDR MAKSIMOV	{"email": "maksimov-a1966@postgrespro.ru", "phone": "+70795456298"}
0005434251863	F021B5	1912 489864	DANILA EGOROV	{"email": "degorov_031981@postgrespro.ru", "phone": "+70772873302"}
0005434251864	F021B5	9297 388222	ARTEM TARASOV	{"phone": "+70230411818"}
0005434251865	A605DB	2459 472126	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr03051955@postgrespro.ru", "phone": "+70686608730"}
0005434251866	A605DB	5284 706463	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov-1980@postgrespro.ru", "phone": "+70325829402"}
0005434251867	FBCC61	6418 386018	VITALIY IVANOV	{"email": "vitaliy-ivanov.29071970@postgrespro.ru", "phone": "+70149152453"}
0005434251868	FBCC61	7658 055313	VALENTINA KOVALEVA	{"phone": "+70843146025"}
0005434251869	FC1EB4	4652 447559	MIKHAIL NOVIKOV	{"email": "mikhail.novikov-021972@postgrespro.ru", "phone": "+70805844786"}
0005434251870	9AC0F3	0336 796360	VALENTINA VLASOVA	{"email": "vlasova.valentina.12031980@postgrespro.ru", "phone": "+70667889591"}
0005434251871	9AC0F3	1781 027458	LYUDMILA FROLOVA	{"email": "frolova.lyudmila29071976@postgrespro.ru", "phone": "+70050208021"}
0005434251872	2EF99A	0887 454215	ZINAIDA GERASIMOVA	{"email": "zinaidagerasimova.1977@postgrespro.ru", "phone": "+70428301053"}
0005434251873	FD6523	9969 736143	ALEKSEY IVANOV	{"email": "ivanov_a21011974@postgrespro.ru", "phone": "+70557461811"}
0005434251874	FD6523	5601 577252	ELENA FROLOVA	{"phone": "+70483030230"}
0005434251875	52259E	1368 289755	VALERIY VOLKOV	{"email": "volkov_valeriy1969@postgrespro.ru", "phone": "+70465919567"}
0005434251876	77F997	1939 860468	EKATERINA NOVIKOVA	{"phone": "+70672423798"}
0005434251877	2829B6	0459 943966	ROMAN SMIRNOV	{"phone": "+70227447429"}
0005434251878	9AD5FE	3036 928492	ELENA LAZAREVA	{"email": "e_lazareva-1978@postgrespro.ru", "phone": "+70349463977"}
0005434251879	9AD5FE	5131 755473	MARIYA ERMAKOVA	{"email": "ermakovamariya.27021968@postgrespro.ru", "phone": "+70820342712"}
0005434251880	9AD5FE	7330 505343	IRINA KOZLOVA	{"email": "i_kozlova_25061976@postgrespro.ru", "phone": "+70200124537"}
0005434251881	00239A	8420 347754	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-071972@postgrespro.ru", "phone": "+70838181594"}
0005434251882	9DD849	9880 706900	PETR SAVELEV	{"phone": "+70816293219"}
0005434251883	9DD849	0227 200319	VIKTOR GERASIMOV	{"phone": "+70353284173"}
0005434251884	4B4159	4838 598286	ALENA VLASOVA	{"phone": "+70966370162"}
0005434251885	496A56	7922 009055	VITALIY KOROLEV	{"email": "v.korolev.28071974@postgrespro.ru", "phone": "+70020432101"}
0005434251886	CD0A8C	5119 403682	ILYA GAVRILOV	{"phone": "+70197894561"}
0005434251887	9FEFCC	8567 148112	ALEKSEY FROLOV	{"email": "frolov.a-071972@postgrespro.ru", "phone": "+70985306554"}
0005434251888	EA7292	9792 073436	MIKHAIL KOZLOV	{"email": "m-kozlov091967@postgrespro.ru", "phone": "+70829691805"}
0005434251889	86F1DA	5299 155929	ALEKSANDR IVANOV	{"phone": "+70298980649"}
0005434251890	86F1DA	6645 319266	IGOR VASILEV	{"email": "vasilev.igor_01041969@postgrespro.ru", "phone": "+70351079425"}
0005434251891	98217B	6749 805608	SERGEY DAVYDOV	{"email": "davydovs.031969@postgrespro.ru", "phone": "+70908574027"}
0005434251892	635F47	0224 412218	BULAT POPOV	{"phone": "+70743621800"}
0005434251893	0E0403	1816 213547	TATYANA OSIPOVA	{"phone": "+70215326821"}
0005434251894	AE817A	7784 104602	LARISA POPOVA	{"phone": "+70630632207"}
0005434251895	AE817A	5903 479720	VIKTOR GRIGOREV	{"email": "grigorev_viktor-20111977@postgrespro.ru", "phone": "+70452708079"}
0005434251896	E28BA6	9910 726487	EKATERINA VASILEVA	{"phone": "+70470457683"}
0005434251897	E28BA6	6827 834054	SVETLANA DMITRIEVA	{"email": "dmitrievas-25081969@postgrespro.ru", "phone": "+70293130046"}
0005434251898	B9B06B	4183 737016	ELENA POPOVA	{"email": "e_popova_1961@postgrespro.ru", "phone": "+70860028380"}
0005434251899	E51D45	2089 491189	PRASKOVYA KONOVALOVA	{"email": "konovalova-praskovya1987@postgrespro.ru", "phone": "+70657190408"}
0005434251900	93530B	5497 359517	VALERIYA DENISOVA	{"phone": "+70949819535"}
0005434251901	6971D9	8445 024199	STANISLAV PAVLOV	{"phone": "+70644349250"}
0005434251902	F5127A	0045 567378	ILYA ANDREEV	{"email": "andreev_ilya-051963@postgrespro.ru", "phone": "+70173247474"}
0005434251903	BE8709	0023 268761	ILDAR SEMENOV	{"email": "isemenov.1974@postgrespro.ru", "phone": "+70704918704"}
0005434251904	4DDA24	7370 913298	SVETLANA KAZAKOVA	{"email": "kazakova_svetlana_1971@postgrespro.ru", "phone": "+70908701313"}
0005434251905	FF43B8	1725 231641	ANASTASIYA NIKITINA	{"phone": "+70221182086"}
0005434251906	698B22	9162 422802	NATALYA BORISOVA	{"phone": "+70248865978"}
0005434251907	57B3DC	7943 901200	EVDOKIYA RODIONOVA	{"phone": "+70880317078"}
0005434251908	57B3DC	9706 830795	ALEKSANDR VASILEV	{"email": "vasilev-a.031967@postgrespro.ru", "phone": "+70652217463"}
0005434251909	822B14	6643 276618	MARGARITA ABRAMOVA	{"phone": "+70824377919"}
0005434251911	E429B4	9314 393753	MARINA SAVELEVA	{"email": "m_saveleva_1965@postgrespro.ru", "phone": "+70896806351"}
0005434251912	13168F	8155 172382	DARYA SERGEEVA	{"phone": "+70631598247"}
0005434251913	DE961F	6597 734560	IVAN SEMENOV	{"phone": "+70057596167"}
0005434251914	2A1350	9174 913026	NIKOLAY FILIPPOV	{"email": "nikolay-filippov-1971@postgrespro.ru", "phone": "+70533363773"}
0005434252193	D59A6D	7002 939522	ANNA DMITRIEVA	{"phone": "+70183703515"}
0005434251915	2A1350	6020 370115	MARINA VLASOVA	{"email": "marina.vlasova.021981@postgrespro.ru", "phone": "+70632326615"}
0005434251916	2A1350	0536 485090	TAISIYA KUZMINA	{"email": "kuzminat-1989@postgrespro.ru", "phone": "+70566230502"}
0005434251917	01616C	4729 059381	VALENTINA SOLOVEVA	{"phone": "+70453853681"}
0005434251918	07F466	5234 574584	ANNA ILINA	{"phone": "+70336299314"}
0005434251919	07F466	2804 979240	VERA NOVIKOVA	{"phone": "+70878182908"}
0005434251920	45CFBD	5960 074240	NADEZHDA MOISEEVA	{"phone": "+70608909129"}
0005434251921	765BD8	3563 343361	ANNA FROLOVA	{"email": "annafrolova.021971@postgrespro.ru", "phone": "+70818691956"}
0005434251922	765BD8	7338 507398	VIKTOR ABRAMOV	{"phone": "+70147552374"}
0005434251923	04D6ED	2232 292448	VALERIY OSIPOV	{"email": "valeriy-osipov091962@postgrespro.ru", "phone": "+70421054132"}
0005434251924	8BD37A	8725 784716	ARTEM VOLKOV	{"email": "volkov.artem_1962@postgrespro.ru", "phone": "+70025084393"}
0005434251925	457D99	1558 709972	GALINA RYABOVA	{"phone": "+70480429469"}
0005434251926	AB1DC8	4566 929530	ALENA GORBUNOVA	{"email": "alena_gorbunova.15041968@postgrespro.ru", "phone": "+70391020611"}
0005434251927	A89748	5953 853837	PAVEL KUZNECOV	{"phone": "+70770063410"}
0005434251928	A89748	3271 076000	VLADIMIR MOISEEV	{"email": "vladimir-moiseev.10091974@postgrespro.ru", "phone": "+70004194570"}
0005434251929	A7F4F6	8844 819419	OLGA ILINA	{"email": "ilinao29101967@postgrespro.ru", "phone": "+70109572874"}
0005434251930	0E387F	0877 517796	ZINAIDA NOVIKOVA	{"email": "novikova-z071964@postgrespro.ru", "phone": "+70849164272"}
0005434251931	0E387F	3571 834698	OLGA ANDREEVA	{"email": "o-andreeva1974@postgrespro.ru", "phone": "+70596633401"}
0005434251932	00D85D	5999 625990	ANATOLIY ALEKSANDROV	{"email": "aleksandrova-081969@postgrespro.ru", "phone": "+70494881057"}
0005434251933	00D85D	7881 699076	RASHIT PAVLOV	{"phone": "+70272592533"}
0005434251934	108C86	8427 552918	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr.041981@postgrespro.ru", "phone": "+70409055034"}
0005434251935	1AAEC2	0781 803651	ELENA MASLOVA	{"email": "maslova_elena081976@postgrespro.ru", "phone": "+70986173230"}
0005434251936	1AAEC2	6571 279970	NIKOLAY NIKOLAEV	{"email": "nikolaevn1981@postgrespro.ru", "phone": "+70430615443"}
0005434251937	7E4820	4499 800543	NIKITA ZAKHAROV	{"email": "zakharovnikita-101964@postgrespro.ru", "phone": "+70721930212"}
0005434251938	7E4820	6525 150221	SOFYA KISELEVA	{"phone": "+70537472678"}
0005434251939	2A414C	5742 750803	LARISA KOROLEVA	{"phone": "+70918887925"}
0005434251940	BEB8DE	4887 066893	VALENTINA DENISOVA	{"phone": "+70543523809"}
0005434251941	BEB8DE	2429 519966	NATALYA ANTONOVA	{"email": "natalya.antonova-23111967@postgrespro.ru", "phone": "+70863168788"}
0005434251942	7D2BB5	2524 965163	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey-15051968@postgrespro.ru", "phone": "+70556089853"}
0005434251943	7D2BB5	6931 725730	VLADIMIR DAVYDOV	{"phone": "+70486473072"}
0005434251944	F9CFFD	7829 990662	MATVEY CHERNOV	{"email": "chernov_matvey.28051969@postgrespro.ru", "phone": "+70043303753"}
0005434251945	AA7EC6	7699 593081	ELENA NESTEROVA	{"email": "nesterovae16111966@postgrespro.ru", "phone": "+70601642372"}
0005434251946	232C29	7924 564890	YULIYA SEMENOVA	{"email": "ysemenova-021970@postgrespro.ru", "phone": "+70391660521"}
0005434251947	DBA87C	0655 144899	LYUDMILA POPOVA	{"phone": "+70064876095"}
0005434251948	F9858F	3974 521850	LYUBOV KULIKOVA	{"phone": "+70189244977"}
0005434251949	C39F3F	7136 693259	MIKHAIL VOROBEV	{"phone": "+70146092508"}
0005434251950	C39F3F	0975 403456	ALEKSANDR KONOVALOV	{"phone": "+70498740774"}
0005434251951	C39F3F	6543 746278	GRIGORIY ANDREEV	{"email": "grigoriyandreev-30091968@postgrespro.ru", "phone": "+70342668098"}
0005434251952	984789	8179 979046	SERGEY PETROV	{"phone": "+70714234820"}
0005434251953	37AAB4	8467 426146	ANASTASIYA ANDREEVA	{"phone": "+70693658531"}
0005434251954	D35168	7006 384028	ELENA EFREMOVA	{"email": "efremova_elena-021958@postgrespro.ru", "phone": "+70690586267"}
0005434251955	26CDA6	8588 186032	VASILIY KOZLOV	{"email": "kozlov-vasiliy-11021962@postgrespro.ru", "phone": "+70869609011"}
0005434251956	26CDA6	5453 095027	ELENA DAVYDOVA	{"email": "elena.davydova_24021979@postgrespro.ru", "phone": "+70396087168"}
0005434251957	26CDA6	1750 613854	LIDIYA IVANOVA	{"phone": "+70231690687"}
0005434251958	16D65E	1491 334202	SERGEY NIKOLAEV	{"phone": "+70723351726"}
0005434251959	E91F17	1958 446708	SERGEY KUDRYASHOV	{"email": "sergeykudryashov_031966@postgrespro.ru", "phone": "+70436096740"}
0005434251960	259D88	9120 741904	IVAN NOVIKOV	{"email": "inovikov_25081973@postgrespro.ru", "phone": "+70936741386"}
0005434251961	FF4C4F	5546 328840	GALINA KUZNECOVA	{"email": "kuznecovagalina.1971@postgrespro.ru", "phone": "+70130540241"}
0005434251962	1D2BFF	8414 914916	NATALYA KOLESNIKOVA	{"email": "kolesnikova-natalya_03021966@postgrespro.ru", "phone": "+70007011462"}
0005434251963	0327A7	6309 957511	OLGA CHERNOVA	{"email": "chernovaolga11021969@postgrespro.ru", "phone": "+70409735258"}
0005434251964	0327A7	0176 555906	VALERIY KULIKOV	{"email": "valeriy.kulikov-18061959@postgrespro.ru", "phone": "+70713830482"}
0005434251965	CF0352	8972 309794	VALENTINA POPOVA	{"phone": "+70671381437"}
0005434251966	CF0352	4595 663432	EVGENIY ALEKSANDROV	{"email": "evgeniy.aleksandrov-071974@postgrespro.ru", "phone": "+70340827620"}
0005434251967	2615D4	0331 519721	IVAN MAKSIMOV	{"phone": "+70595167119"}
0005434251968	327817	7722 745906	VASILIY FEDOROV	{"phone": "+70940124008"}
0005434251969	327817	4373 781123	IGOR NIKOLAEV	{"phone": "+70421538787"}
0005434251970	DC52B0	9857 645722	SOFYA DMITRIEVA	{"email": "dmitrieva.s.051968@postgrespro.ru", "phone": "+70616879273"}
0005434251971	1B2B0C	4722 274937	RAMILYA KONOVALOVA	{"email": "r-konovalova_1967@postgrespro.ru", "phone": "+70648651465"}
0005434251972	D75AC7	0248 993101	ALEKSANDR FILIPPOV	{"phone": "+70005521781"}
0005434251973	D75AC7	4945 195034	OLGA PAVLOVA	{"phone": "+70090982885"}
0005434251974	988DF9	1083 485435	SERGEY CHERNOV	{"email": "schernov.26111973@postgrespro.ru", "phone": "+70243011228"}
0005434251975	988DF9	3697 106635	ALEKSANDR MAKAROV	{"email": "a.makarov-1967@postgrespro.ru", "phone": "+70910349462"}
0005434251976	0960F8	8902 017684	VLADIMIR OSIPOV	{"email": "osipov_v-111974@postgrespro.ru", "phone": "+70178688883"}
0005434251977	56B371	6108 963341	VADIM ROMANOV	{"phone": "+70590392749"}
0005434251978	C548EC	9610 029097	ELENA SEMENOVA	{"phone": "+70151582380"}
0005434251979	C548EC	0894 221318	DENIS AFANASEV	{"email": "d_afanasev_1972@postgrespro.ru", "phone": "+70709686761"}
0005434251980	49A6C8	2758 940811	MAKSIM KARPOV	{"phone": "+70841120765"}
0005434251981	D42183	6437 783842	NIKOLAY NOVIKOV	{"phone": "+70566241893"}
0005434251982	9287DE	6869 418267	TATYANA IVANOVA	{"email": "ivanova_tatyana-101964@postgrespro.ru", "phone": "+70060549436"}
0005434251983	FFBCC7	0204 603698	VIKTOR KUZMIN	{"phone": "+70749052417"}
0005434251984	FFBCC7	2700 657721	ANTONINA KUZNECOVA	{"email": "a.kuznecova121975@postgrespro.ru", "phone": "+70336560074"}
0005434251985	FFBCC7	5228 869085	ROMAN KUZNECOV	{"email": "kuznecov.roman_1968@postgrespro.ru", "phone": "+70196561544"}
0005434251986	1DAF76	6839 604764	NATALYA ERMAKOVA	{"email": "ermakovan_091977@postgrespro.ru", "phone": "+70331504332"}
0005434251987	ED97CE	5738 752257	MARINA POPOVA	{"email": "m.popova.1967@postgrespro.ru", "phone": "+70225334202"}
0005434251988	77F567	3944 722039	GALINA RODIONOVA	{"phone": "+70039550167"}
0005434251989	07B4E6	6948 493847	VALENTINA KUZNECOVA	{"email": "kuznecova_v_051981@postgrespro.ru", "phone": "+70214017334"}
0005434251990	07B4E6	5054 794940	IRINA SIDOROVA	{"email": "sidorova_irina-111970@postgrespro.ru", "phone": "+70406910010"}
0005434251991	1ED991	9185 147618	DIANA LAZAREVA	{"email": "d_lazareva_19011978@postgrespro.ru", "phone": "+70876928538"}
0005434251992	1ED991	8226 505442	SVETLANA KOVALEVA	{"email": "s.kovaleva_07111974@postgrespro.ru", "phone": "+70990840904"}
0005434251993	7FE9D0	8185 869689	VLADIMIR ZHURAVLEV	{"phone": "+70956107510"}
0005434251994	F1B615	5785 552136	VIKTOR RODIONOV	{"email": "rodionov.v_31071978@postgrespro.ru", "phone": "+70100266407"}
0005434251995	4921D5	4738 438402	EVGENIY YAKOVLEV	{"phone": "+70681562640"}
0005434251996	73380E	5230 846518	IVAN KONOVALOV	{"email": "konovalov_ivan-041981@postgrespro.ru", "phone": "+70261160955"}
0005434251997	54CA0A	2125 739177	POLINA MAKSIMOVA	{"phone": "+70118201845"}
0005434251998	8BE459	2496 925408	RUSLAN MAKAROV	{"phone": "+70427144366"}
0005434251999	83185A	9843 506672	ZULFIYA NIKIFOROVA	{"email": "nikiforova.z.13071979@postgrespro.ru", "phone": "+70866547263"}
0005434252000	83185A	8108 722663	IVAN TARASOV	{"phone": "+70190652683"}
0005434252001	587D2D	2572 275886	ALEKSANDR KARPOV	{"phone": "+70024296169"}
0005434252002	631856	5061 739865	TAMARA MIKHAYLOVA	{"email": "mikhaylova-tamara-06011959@postgrespro.ru", "phone": "+70977624014"}
0005434252003	49CC14	4005 515823	ALENA ALEKSANDROVA	{"email": "aleksandrova-a_11121982@postgrespro.ru", "phone": "+70628223421"}
0005434252004	CCFEB8	4142 310710	OLESYA DMITRIEVA	{"phone": "+70356243621"}
0005434252005	CCFEB8	3684 367833	VLADIMIR VASILEV	{"email": "vasilev.v-041973@postgrespro.ru", "phone": "+70621552870"}
0005434252006	B57084	4077 110583	NIKOLAY MAKSIMOV	{"email": "maksimov-nikolay_1975@postgrespro.ru", "phone": "+70647231621"}
0005434252007	B57084	8393 026678	ANASTASIYA OSIPOVA	{"email": "a_osipova.121981@postgrespro.ru", "phone": "+70407673646"}
0005434252008	FCF67F	2383 217842	YULIYA KOVALEVA	{"email": "kovaleva_yuliya-31121975@postgrespro.ru", "phone": "+70138017638"}
0005434252009	2D8255	7907 813265	ANDREY FEDOTOV	{"phone": "+70979701992"}
0005434252010	2D8255	2277 533376	ELENA SMIRNOVA	{"email": "esmirnova.1963@postgrespro.ru", "phone": "+70129772073"}
0005434252011	2D8255	0597 655433	OLGA KRASNOVA	{"email": "o-krasnova_05041973@postgrespro.ru", "phone": "+70151564133"}
0005434252012	75418E	1994 611313	MARAT AFANASEV	{"email": "afanasev_m-121982@postgrespro.ru", "phone": "+70381869434"}
0005434252013	A4E4E3	7425 412878	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-vladimir_1988@postgrespro.ru", "phone": "+70359262143"}
0005434252014	A4E4E3	1053 135311	PAVEL POPOV	{"email": "popov-p1968@postgrespro.ru", "phone": "+70936728990"}
0005434252015	5D8A6B	0098 075304	ALEKSANDR KOROLEV	{"phone": "+70366355848"}
0005434252016	5F4F28	0739 302224	ELENA PAVLOVA	{"email": "e-pavlova03021976@postgrespro.ru", "phone": "+70851330145"}
0005434252017	468AA1	7699 970707	DENIS KOZLOV	{"email": "kozlovdenis_10121982@postgrespro.ru", "phone": "+70812440816"}
0005434252018	468AA1	9432 875728	SERGEY PAVLOV	{"phone": "+70806912080"}
0005434252019	D49A54	5717 072000	NATALYA GAVRILOVA	{"email": "natalya.gavrilova-071969@postgrespro.ru", "phone": "+70286027746"}
0005434252020	F0A2BA	6335 316447	VASILIY EGOROV	{"phone": "+70502188638"}
0005434252021	F0A2BA	5990 029149	MARINA NIKOLAEVA	{"email": "m-nikolaeva12051973@postgrespro.ru", "phone": "+70706034319"}
0005434252022	1BCED7	6493 735617	RAMIL DAVYDOV	{"email": "davydovr.02101957@postgrespro.ru", "phone": "+70946270875"}
0005434252023	1BCED7	5961 612329	OLGA MELNIKOVA	{"email": "o-melnikova-1975@postgrespro.ru", "phone": "+70724253192"}
0005434252024	BDDD5F	1282 182804	GALINA GUSEVA	{"email": "galina-guseva1964@postgrespro.ru", "phone": "+70042730603"}
0005434252025	BDDD5F	4549 362276	TATYANA KALININA	{"email": "kalinina.tatyana.08051970@postgrespro.ru", "phone": "+70766616200"}
0005434252026	0E9C57	4749 145640	NIKOLAY GERASIMOV	{"email": "ngerasimov011978@postgrespro.ru", "phone": "+70016909571"}
0005434252027	526820	0602 522462	ANZHELIKA KULIKOVA	{"email": "anzhelikakulikova05021965@postgrespro.ru", "phone": "+70068136096"}
0005434252028	6D6A06	7315 187279	EVGENIY SOLOVEV	{"email": "solovev-evgeniy.051982@postgrespro.ru", "phone": "+70715502881"}
0005434252029	955B37	8211 370842	NIKITA NAUMOV	{"email": "naumov_nikita-30071982@postgrespro.ru", "phone": "+70312785895"}
0005434252030	C4C0EF	7478 419391	MARINA MELNIKOVA	{"email": "melnikovamarina_26121984@postgrespro.ru", "phone": "+70720562912"}
0005434252031	EC783D	5947 222468	VALENTINA KARPOVA	{"email": "valentinakarpova1975@postgrespro.ru", "phone": "+70425618839"}
0005434252032	EC783D	2473 511692	DANIIL EGOROV	{"email": "egorov.d1963@postgrespro.ru", "phone": "+70851225488"}
0005434252033	B995D7	7072 352294	IGOR OSIPOV	{"phone": "+70728797284"}
0005434252034	B995D7	0050 629732	VIKTORIYA TIMOFEEVA	{"phone": "+70500346528"}
0005434252035	6EEBDE	5677 305494	NATALYA IVANOVA	{"email": "n_ivanova24121979@postgrespro.ru", "phone": "+70228198762"}
0005434252036	581E2A	7482 334345	ALEKSANDR TARASOV	{"email": "a-tarasov_1970@postgrespro.ru", "phone": "+70200523351"}
0005434252037	581E2A	0465 321719	SERGEY GRIGOREV	{"email": "s-grigorev_1962@postgrespro.ru", "phone": "+70750886837"}
0005434252038	A4919C	3069 120098	DMITRIY KONOVALOV	{"phone": "+70378182269"}
0005434252039	A4919C	3564 240291	SERGEY KUZNECOV	{"email": "s-kuznecov071960@postgrespro.ru", "phone": "+70464353265"}
0005434252040	A4919C	0846 492766	TATYANA VOLKOVA	{"email": "tvolkova-1963@postgrespro.ru", "phone": "+70507157115"}
0005434252041	AD1A13	5071 296011	VERA OVCHINNIKOVA	{"phone": "+70937623080"}
0005434252042	711E39	8388 673828	VLADIMIR FILIPPOV	{"phone": "+70955441055"}
0005434252043	933275	4589 826424	ILYA KOROLEV	{"email": "korolev-i-1966@postgrespro.ru", "phone": "+70611810238"}
0005434252044	D4E90A	8305 380032	VERA YAKOVLEVA	{"phone": "+70408126275"}
0005434252045	6C6FEE	0178 717360	ANISA KOMAROVA	{"phone": "+70743319249"}
0005434252046	6C6FEE	0562 026835	DMITRIY KOROLEV	{"email": "dkorolev091977@postgrespro.ru", "phone": "+70893889226"}
0005434252047	6C6FEE	7963 265082	VLADIMIR BELOV	{"email": "vladimir_belov_1976@postgrespro.ru", "phone": "+70149377042"}
0005434252048	A7234F	7394 883871	ZLATA ISAEVA	{"email": "isaeva.zlata.1959@postgrespro.ru", "phone": "+70439292441"}
0005434252049	EAE647	5536 630784	LUIZA MOROZOVA	{"phone": "+70619549341"}
0005434252050	246F6F	6474 935974	YULIYA GORBUNOVA	{"email": "gorbunova.yuliya1971@postgrespro.ru", "phone": "+70530131836"}
0005434252051	BF66F2	7208 262381	BORIS MOROZOV	{"email": "morozov.b.19081968@postgrespro.ru", "phone": "+70514493877"}
0005434252052	F66EF9	3900 624405	YURIY BELOV	{"phone": "+70581325471"}
0005434252053	F66EF9	0002 239347	VLADIMIR POPOV	{"email": "v_popov1978@postgrespro.ru", "phone": "+70533672843"}
0005434252054	782673	7560 914411	ANTON ABRAMOV	{"phone": "+70467346434"}
0005434252055	782673	0735 447773	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov_02081971@postgrespro.ru", "phone": "+70536683194"}
0005434252056	782673	1526 355469	OLGA KUZNECOVA	{"email": "olga_kuznecova.25041973@postgrespro.ru", "phone": "+70818286266"}
0005434252057	0C163E	6826 171117	TATYANA KOMAROVA	{"email": "t-komarova.101965@postgrespro.ru", "phone": "+70095310366"}
0005434252058	0C163E	1080 244783	EVGENIY TARASOV	{"phone": "+70063573279"}
0005434252059	4EF2E9	6576 160091	ANTONINA NIKITINA	{"phone": "+70003909170"}
0005434252060	4EF2E9	4197 697643	VLADIMIR VASILEV	{"phone": "+70201713446"}
0005434252061	E3B9FA	6493 343747	NIKITA OSIPOV	{"email": "nikita_osipov-071971@postgrespro.ru", "phone": "+70253128613"}
0005434252062	C729F8	6046 274798	TATYANA FILIPPOVA	{"phone": "+70615705084"}
0005434252063	11F5E5	5203 802139	SERGEY MATVEEV	{"email": "matveev-s041981@postgrespro.ru", "phone": "+70906926065"}
0005434252064	A75DA8	2450 106106	VADIM FROLOV	{"phone": "+70535847869"}
0005434252065	A75DA8	9299 210247	KHASAN FEDOTOV	{"phone": "+70511842433"}
0005434252066	BF158D	9947 740431	VLADIMIR KULIKOV	{"email": "v_kulikov.121969@postgrespro.ru", "phone": "+70201924660"}
0005434252067	D89B8B	9932 109718	EKATERINA TARASOVA	{"email": "tarasova_e18021975@postgrespro.ru", "phone": "+70460098953"}
0005434252068	27AF1C	4758 725498	ALEKSANDRA MOROZOVA	{"phone": "+70662578421"}
0005434252069	9CC97F	0749 333951	VALENTINA ZAYCEVA	{"phone": "+70820107839"}
0005434252070	66165A	2971 051536	BORIS TIKHONOV	{"phone": "+70212953471"}
0005434252071	E946EC	9823 182143	ANNA KUZNECOVA	{"email": "akuznecova.23061970@postgrespro.ru", "phone": "+70840616909"}
0005434252072	E0D6FF	5828 052949	LIDIYA SOKOLOVA	{"phone": "+70055175756"}
0005434252073	74E095	1757 368720	NIKOLAY IVANOV	{"email": "ivanov-n-1970@postgrespro.ru", "phone": "+70896330894"}
0005434252074	74E095	0569 167714	ARINA MOROZOVA	{"email": "morozovaa-1964@postgrespro.ru", "phone": "+70560764306"}
0005434252075	74E095	8154 105823	OLEG FOMIN	{"phone": "+70932209150"}
0005434252076	D2D75C	5452 812671	OKSANA EGOROVA	{"phone": "+70555229637"}
0005434252077	754BA2	2950 989362	OLEG ALEKSEEV	{"email": "alekseevoleg-1973@postgrespro.ru", "phone": "+70809133397"}
0005434252078	FC9A4F	1012 883360	ALEKSANDRA RYABOVA	{"phone": "+70624285901"}
0005434252079	E3D5BF	6277 459375	EKATERINA SCHERBAKOVA	{"email": "scherbakova.e_051970@postgrespro.ru", "phone": "+70787618672"}
0005434252080	1D4718	2211 154517	ANNA SOROKINA	{"email": "sorokina.a.101973@postgrespro.ru", "phone": "+70725638667"}
0005434252081	F06EA8	5938 529230	SERGEY YAKOVLEV	{"email": "s.yakovlev.041978@postgrespro.ru", "phone": "+70269424264"}
0005434252082	864FBE	0617 913391	NIKOLAY POPOV	{"email": "popov_nikolay-021978@postgrespro.ru", "phone": "+70248940380"}
0005434252083	864FBE	4116 288975	VALERIY TIKHONOV	{"phone": "+70503337635"}
0005434252084	864FBE	1262 456603	ALEKSANDR PETROV	{"email": "a.petrov-04051970@postgrespro.ru", "phone": "+70568459826"}
0005434252085	BA1FC9	8968 292017	LEONID TARASOV	{"phone": "+70954388372"}
0005434252086	477362	0268 942638	ALEKSANDR BARANOV	{"phone": "+70068864699"}
0005434252087	19BB67	6614 357379	VLADIMIR ZHUKOV	{"email": "vladimirzhukov.07091967@postgrespro.ru", "phone": "+70365749649"}
0005434252088	19BB67	9693 937757	TATYANA FEDOROVA	{"phone": "+70061584926"}
0005434252089	C56B27	7839 114599	VALENTINA FILATOVA	{"email": "v_filatova-1982@postgrespro.ru", "phone": "+70753124429"}
0005434252090	5F19C1	9350 801953	IGOR IVANOV	{"phone": "+70864804696"}
0005434252091	F638EF	7710 885730	VLADISLAV TIMOFEEV	{"email": "timofeev-v.021970@postgrespro.ru", "phone": "+70765646268"}
0005434252092	A3C7CB	6152 533878	OLGA ORLOVA	{"email": "o-orlova.1971@postgrespro.ru", "phone": "+70566186676"}
0005434252093	994DC8	1417 342678	SERGEY ROMANOV	{"phone": "+70576017470"}
0005434252094	994DC8	0408 659750	ELENA AKIMOVA	{"phone": "+70411402098"}
0005434252095	6B7377	2307 347814	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr1978@postgrespro.ru", "phone": "+70060452070"}
0005434252096	39CE42	5705 521849	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko-091963@postgrespro.ru", "phone": "+70363682053"}
0005434252097	9A4CD6	0371 820548	ALEKSANDR IVANOV	{"email": "ivanov_a.21061968@postgrespro.ru", "phone": "+70580130941"}
0005434252098	C7AEE9	0349 259318	ALEKSANDR BORISOV	{"email": "a_borisov-06071977@postgrespro.ru", "phone": "+70683151866"}
0005434252099	130166	0449 706507	NIKITA TIMOFEEV	{"email": "nikita_timofeev1983@postgrespro.ru", "phone": "+70667951033"}
0005434252100	0F13D2	5427 983743	ANASTASIYA KARPOVA	{"phone": "+70941041903"}
0005434252101	14835D	0805 602713	NATALIYA IVANOVA	{"phone": "+70925343966"}
0005434252102	BDEC2C	4989 278753	PETR IVANOV	{"phone": "+70155631373"}
0005434252103	07ED94	1938 520154	IRINA NIKOLAEVA	{"phone": "+70230329156"}
0005434252104	3B161E	7118 123208	ELENA SOKOLOVA	{"phone": "+70856250482"}
0005434252105	3B161E	2430 920043	ANDREY SAVELEV	{"phone": "+70617388397"}
0005434252106	C84CF8	9227 329530	OLEG OSIPOV	{"email": "osipov-oleg-30091978@postgrespro.ru", "phone": "+70005224221"}
0005434252107	C84CF8	0544 254798	EVGENIY FEDOROV	{"email": "evgeniyfedorov-1969@postgrespro.ru", "phone": "+70658539270"}
0005434252108	5E75F1	8619 288963	MIKHAIL FILIPPOV	{"email": "filippovmikhail041977@postgrespro.ru", "phone": "+70364657199"}
0005434252109	5E75F1	2754 201459	MAKSIM YAKOVLEV	{"phone": "+70140085249"}
0005434252110	8B9FF0	9627 895459	ELENA KUZNECOVA	{"phone": "+70933860974"}
0005434252111	4A8CCD	2813 479586	ZINAIDA SIDOROVA	{"phone": "+70108996339"}
0005434252112	72DD8E	6447 968472	MARIYA FEDOROVA	{"phone": "+70697248891"}
0005434252113	3CAE94	8728 818621	OLEG IVANOV	{"phone": "+70972958305"}
0005434252114	3CAE94	7157 055741	ALEKSEY VOROBEV	{"email": "aleksey-vorobev1960@postgrespro.ru", "phone": "+70669665541"}
0005434252115	7998D2	9633 209815	IRINA FEDOROVA	{"phone": "+70232628092"}
0005434252116	7998D2	9025 420584	OLGA DANILOVA	{"phone": "+70186196509"}
0005434252117	84A153	7677 685119	ELENA KUDRYASHOVA	{"phone": "+70664862860"}
0005434252118	81F230	6753 848503	SVETLANA DMITRIEVA	{"email": "dmitrieva.s-10101973@postgrespro.ru", "phone": "+70616510392"}
0005434252119	81F230	6357 778397	NIKOLAY NIKOLAEV	{"email": "nikolaev_n.021974@postgrespro.ru", "phone": "+70640061882"}
0005434252120	76BA68	3270 966747	VALERIY SMIRNOV	{"email": "valeriy_smirnov14111975@postgrespro.ru", "phone": "+70299922346"}
0005434252121	A6DE64	0667 960808	OLEG SCHERBAKOV	{"phone": "+70329839136"}
0005434252122	93A2FA	0018 726896	ALLA KOMAROVA	{"phone": "+70901237025"}
0005434252123	010C5C	7098 080251	ALMIRA IVANOVA	{"email": "a-ivanova_111961@postgrespro.ru", "phone": "+70332419772"}
0005434252124	B36F5D	3568 305794	VALENTINA ISAEVA	{"phone": "+70995032620"}
0005434252125	6712FF	9520 719732	VALERIY KUZNECOV	{"email": "v.kuznecov.1969@postgrespro.ru", "phone": "+70220499718"}
0005434252126	6712FF	6462 632295	VERA MAKAROVA	{"email": "v-makarova.26061972@postgrespro.ru", "phone": "+70355340564"}
0005434252127	2B7EA1	4109 836458	ALEKSANDR KUZMIN	{"phone": "+70789299044"}
0005434252128	62C590	8582 615848	DMITRIY SMIRNOV	{"phone": "+70576514313"}
0005434252129	27593B	2811 955088	MAKAR ALEKSEEV	{"email": "alekseev-makar02091974@postgrespro.ru", "phone": "+70598530603"}
0005434252130	27593B	9209 114717	IRINA GAVRILOVA	{"email": "i_gavrilova-121981@postgrespro.ru", "phone": "+70431856892"}
0005434252131	290C1D	8763 913006	TATYANA KONDRATEVA	{"email": "t.kondrateva_1971@postgrespro.ru", "phone": "+70635484177"}
0005434252132	0B722B	3108 189590	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr.121971@postgrespro.ru", "phone": "+70264020148"}
0005434252133	F88352	2873 191823	VERA MOROZOVA	{"email": "morozova_v_011975@postgrespro.ru", "phone": "+70319305770"}
0005434252134	F88352	0058 502985	LYUDMILA SOKOLOVA	{"email": "lyudmila.sokolova.26061969@postgrespro.ru", "phone": "+70198256040"}
0005434252135	E1F947	4433 822268	MAKSIM SIDOROV	{"email": "m_sidorov-04081976@postgrespro.ru", "phone": "+70536694914"}
0005434252136	E1F947	7800 844139	EKATERINA KUZNECOVA	{"phone": "+70836995552"}
0005434252137	70F637	5931 578711	ANDREY DAVYDOV	{"email": "adavydov_16071966@postgrespro.ru", "phone": "+70786342323"}
0005434252138	70F637	2934 979956	KONSTANTIN KOZLOV	{"phone": "+70023776971"}
0005434252139	85BE72	3991 329791	VADIM PAVLOV	{"email": "pavlov-vadim111982@postgrespro.ru", "phone": "+70757618136"}
0005434252140	22BD7F	5439 449375	VASILIY SIDOROV	{"email": "sidorov_vasiliy_051957@postgrespro.ru", "phone": "+70070586335"}
0005434252141	22BD7F	7285 357341	ANNA IVANOVA	{"email": "ivanovaa-1988@postgrespro.ru", "phone": "+70952599921"}
0005434252142	FD2875	1446 869596	OLEG BARANOV	{"email": "o_baranov-051979@postgrespro.ru", "phone": "+70324125330"}
0005434252143	394195	1511 211993	ANATOLIY PETROV	{"email": "a_petrov-081977@postgrespro.ru", "phone": "+70483630714"}
0005434252144	F552B9	9400 621128	LIDIYA NAZAROVA	{"phone": "+70476321781"}
0005434252145	03D7B0	3418 089482	OLEG IVANOV	{"phone": "+70575818278"}
0005434252146	F95C83	8993 052670	ARTUR ZHURAVLEV	{"email": "zhuravlev_artur_22081956@postgrespro.ru", "phone": "+70476529510"}
0005434252147	F95C83	0610 266743	IRINA MIRONOVA	{"email": "mironova_i_091967@postgrespro.ru", "phone": "+70686181729"}
0005434252148	F40C68	6879 479759	IGOR NIKITIN	{"phone": "+70034786891"}
0005434252149	F40C68	5989 109990	OLGA KUZNECOVA	{"phone": "+70622109402"}
0005434252150	1516C4	0450 019197	KSENIYA AFANASEVA	{"email": "afanaseva.k-011976@postgrespro.ru", "phone": "+70413701191"}
0005434252151	1516C4	4530 463997	TATYANA RYABOVA	{"phone": "+70432410776"}
0005434252152	8EAE1C	3667 365711	TATYANA LAZAREVA	{"email": "tlazareva_20071965@postgrespro.ru", "phone": "+70202093940"}
0005434252153	601D1C	3980 009815	LYUBOV EGOROVA	{"email": "legorova10091984@postgrespro.ru", "phone": "+70516054322"}
0005434252154	DB8C62	4998 557247	ILYA GORBUNOV	{"phone": "+70193927438"}
0005434252155	DB8C62	2659 834587	NIKOLAY IVANOV	{"phone": "+70343468700"}
0005434252156	4E669B	8016 637128	EKATERINA KOROLEVA	{"email": "koroleva-e1977@postgrespro.ru", "phone": "+70859397149"}
0005434252157	D18FDC	8088 943740	ANATOLIY BELOV	{"phone": "+70677416397"}
0005434252158	D25E83	4615 081509	SERGEY SIDOROV	{"email": "sidorov-sergey_23061964@postgrespro.ru", "phone": "+70276666433"}
0005434252159	DD7709	6333 545419	GALINA NIKOLAEVA	{"email": "galina-nikolaeva.1963@postgrespro.ru", "phone": "+70844946182"}
0005434252160	DD7709	4974 199618	VALENTINA KAZAKOVA	{"phone": "+70891842240"}
0005434252161	531B3B	1895 634707	VLADIMIR NOVIKOV	{"email": "novikov.v-121960@postgrespro.ru", "phone": "+70821807841"}
0005434252162	B3886E	8865 981177	IRINA KOLESNIKOVA	{"email": "kolesnikova-irina_21091971@postgrespro.ru", "phone": "+70569103951"}
0005434252163	949EFB	4578 223026	VALENTINA VOLKOVA	{"email": "volkovavalentina.1971@postgrespro.ru", "phone": "+70957637502"}
0005434252164	3E346A	2288 251826	DENIS GAVRILOV	{"phone": "+70441462388"}
0005434252165	A4A390	8704 598091	YURIY GORBUNOV	{"email": "yuriygorbunov011980@postgrespro.ru", "phone": "+70270312725"}
0005434252166	432E37	0749 751686	NELLI GUSEVA	{"phone": "+70210964705"}
0005434252167	680650	7067 497420	EVGENIY NAZAROV	{"email": "e_nazarov091976@postgrespro.ru", "phone": "+70712589418"}
0005434252168	E8BF15	9334 141469	ALEKSEY KUZNECOV	{"phone": "+70740649614"}
0005434252169	3BC8F9	3862 105365	LEONID SMIRNOV	{"email": "smirnov-leonid-06121966@postgrespro.ru", "phone": "+70603493833"}
0005434252170	728DD3	1099 947835	NADEZHDA KOROLEVA	{"phone": "+70883812717"}
0005434252171	3A5F7A	4928 619356	NINA ALEKSANDROVA	{"email": "naleksandrova.1961@postgrespro.ru", "phone": "+70730067544"}
0005434252172	4C5D57	2126 293454	NINA ANDREEVA	{"email": "n_andreeva_011977@postgrespro.ru", "phone": "+70936477307"}
0005434252173	008F21	6035 226489	TATYANA IVANOVA	{"email": "t_ivanova.091974@postgrespro.ru", "phone": "+70124630247"}
0005434252174	9997D2	3173 720345	VIKTOR SCHERBAKOV	{"email": "scherbakov.v-101965@postgrespro.ru", "phone": "+70592087004"}
0005434252175	1D89C4	2765 537299	YURIY POPOV	{"email": "popov_y.011986@postgrespro.ru", "phone": "+70956035944"}
0005434252176	1D89C4	2855 813983	LYUBOV IVANOVA	{"email": "ivanova_l101968@postgrespro.ru", "phone": "+70965237279"}
0005434252177	171BAF	2238 015448	VIKTOR RODIONOV	{"email": "rodionov.viktor1974@postgrespro.ru", "phone": "+70124351297"}
0005434252178	171BAF	4764 001173	ILYA KUZNECOV	{"phone": "+70711563071"}
0005434252179	C4C1F0	9453 091931	DANILA BONDARENKO	{"phone": "+70499992273"}
0005434252180	C27F37	6995 852596	VASILIY VOROBEV	{"email": "vasiliyvorobev.1974@postgrespro.ru", "phone": "+70551088109"}
0005434252181	3C7708	4052 979521	GALINA LEBEDEVA	{"phone": "+70112595377"}
0005434252182	FF36F5	7926 813025	NINA CHERNOVA	{"email": "chernova-nina.1970@postgrespro.ru", "phone": "+70865179215"}
0005434252183	FF36F5	4264 415942	FANIS PAVLOV	{"email": "fanis-pavlov_1964@postgrespro.ru", "phone": "+70201583606"}
0005434252184	4F1A6C	0480 122905	VYACHESLAV GRIGOREV	{"phone": "+70331000137"}
0005434252185	D3E220	1693 342995	DMITRIY SOROKIN	{"phone": "+70356453538"}
0005434252186	D3E220	1211 128058	LEONID ORLOV	{"email": "orlov-l-011966@postgrespro.ru", "phone": "+70783477288"}
0005434252187	A3E756	8186 921828	GALINA MARTYNOVA	{"phone": "+70424795423"}
0005434252188	A3E756	4742 682233	VALERIYA MALYSHEVA	{"phone": "+70729321713"}
0005434252189	92C91C	5358 845952	SVETLANA SOROKINA	{"phone": "+70451815722"}
0005434252190	92C91C	5519 269869	SERGEY FROLOV	{"phone": "+70436994511"}
0005434252191	4DE3B9	8478 237485	SVETLANA KOLESNIKOVA	{"email": "s.kolesnikova_011979@postgrespro.ru", "phone": "+70211869420"}
0005434252192	59511E	4628 204217	EVGENIY GAVRILOV	{"email": "e-gavrilov-19051975@postgrespro.ru", "phone": "+70242221004"}
0005434252194	84F598	5290 284065	VALERIY IVANOV	{"email": "ivanovv-27111972@postgrespro.ru", "phone": "+70032797695"}
0005434252195	84F598	8703 773373	TAMARA NOVIKOVA	{"email": "tamaranovikova.051965@postgrespro.ru", "phone": "+70776406463"}
0005434252196	95CA06	9927 804506	NATALYA KUZMINA	{"email": "kuzmina-natalya_18101964@postgrespro.ru", "phone": "+70278367729"}
0005434252197	8E6A94	5449 558403	EVGENIYA PETROVA	{"email": "evgeniyapetrova_28071978@postgrespro.ru", "phone": "+70689651595"}
0005434252198	0BD216	1007 972610	ELENA ZHUKOVA	{"phone": "+70971535648"}
0005434252199	0BD216	9895 264284	ALEKSANDR EGOROV	{"email": "aleksandregorov.15071972@postgrespro.ru", "phone": "+70369892786"}
0005434252200	93A979	2716 982367	YURIY MAKSIMOV	{"email": "maksimov-y_03071976@postgrespro.ru", "phone": "+70025817116"}
0005434252201	93A979	9358 321771	IRINA FILATOVA	{"phone": "+70086340075"}
0005434252202	4E8307	8205 583261	GENNADIY SOROKIN	{"email": "gennadiy.sorokin.031988@postgrespro.ru", "phone": "+70714286822"}
0005434252203	567A73	5565 645525	VIKTOR PETROV	{"email": "petrov.v_22021977@postgrespro.ru", "phone": "+70519140994"}
0005434252204	567A73	3705 758010	KRISTINA OVCHINNIKOVA	{"email": "ovchinnikovakristina.1980@postgrespro.ru", "phone": "+70607309697"}
0005434252205	8156EB	7001 194715	ARTEM FOMIN	{"phone": "+70165585049"}
0005434252206	D182A4	7004 907397	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr.1974@postgrespro.ru", "phone": "+70694215997"}
0005434252207	454AB1	1317 195970	IVAN SHEVCHENKO	{"phone": "+70616694374"}
0005434252208	8C05A6	9919 395870	ANFISA SIDOROVA	{"email": "a_sidorova_05021969@postgrespro.ru", "phone": "+70799521622"}
0005434252209	E09296	6616 576173	VLADIMIR GRIGOREV	{"email": "grigorev.vladimir_1967@postgrespro.ru", "phone": "+70434624993"}
0005434252210	E09296	8916 828688	KSENIYA ANTONOVA	{"phone": "+70981746379"}
0005434252211	67D7FA	9236 419311	ALEKSANDRA ALEKSANDROVA	{"phone": "+70847309153"}
0005434252212	1D2897	1854 900659	EKATERINA NAUMOVA	{"phone": "+70711935838"}
0005434252213	1D2897	4485 543519	EDGAR KAZAKOV	{"phone": "+70560930899"}
0005434252214	57ECB7	4816 920528	VIOLETTA KARPOVA	{"phone": "+70798431008"}
0005434252215	051660	4373 431491	LYUDMILA PAVLOVA	{"email": "l_pavlova_101977@postgrespro.ru", "phone": "+70426231154"}
0005434252216	83D452	2516 754592	SERGEY BELOV	{"email": "sergey-belov_111973@postgrespro.ru", "phone": "+70911043736"}
0005434252217	A330A1	3574 482799	ANDREY KUZNECOV	{"email": "andreykuznecov_051977@postgrespro.ru", "phone": "+70500204106"}
0005434252218	A330A1	6872 556789	ILNAR KUZNECOV	{"phone": "+70972599979"}
0005434252219	6FC82F	4260 097102	ALEKSEY VASILEV	{"phone": "+70175808619"}
0005434252220	6FC82F	7514 943497	YURIY FILIPPOV	{"phone": "+70470323769"}
0005434252221	87BAAE	7618 815755	MARIYA ANTONOVA	{"phone": "+70125775646"}
0005434252222	87BAAE	4697 519720	OLGA MAKAROVA	{"email": "makarova-olga061964@postgrespro.ru", "phone": "+70090392225"}
0005434252223	2E8C12	0329 836407	IRINA BELOVA	{"email": "irinabelova_101968@postgrespro.ru", "phone": "+70644193858"}
0005434252224	1A5B48	3978 326175	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov.061987@postgrespro.ru", "phone": "+70850824513"}
0005434252225	43F1D6	1510 165133	YURIY ANDREEV	{"email": "andreev_y-22071973@postgrespro.ru", "phone": "+70131084915"}
0005434252226	43F1D6	8405 192472	SERGEY SIDOROV	{"email": "ssidorov06121977@postgrespro.ru", "phone": "+70592435713"}
0005434252227	43F1D6	6062 284057	SVETLANA MAKSIMOVA	{"phone": "+70338382888"}
0005434252228	BBD96F	6351 056593	IGOR EGOROV	{"email": "egorov_i-041970@postgrespro.ru", "phone": "+70548233923"}
0005434252229	B9651A	2022 082368	KLAVDIYA YAKOVLEVA	{"phone": "+70643604274"}
0005434252230	219F01	7218 660636	ZINAIDA FADEEVA	{"phone": "+70609915126"}
0005434252231	219F01	5065 508123	DARYA BOGDANOVA	{"email": "bogdanova_darya_121968@postgrespro.ru", "phone": "+70378166161"}
0005434252232	F79B06	2106 791073	DMITRIY POPOV	{"email": "popov.dmitriy.051978@postgrespro.ru", "phone": "+70724832270"}
0005434252233	F79B06	6934 294183	SEMEN PETROV	{"email": "petrov.semen_02031970@postgrespro.ru", "phone": "+70784377981"}
0005434252234	F79B06	4547 898892	VIKTOR BORISOV	{"email": "borisovviktor1972@postgrespro.ru", "phone": "+70247151217"}
0005434252235	D863D4	8108 828109	TATYANA MATVEEVA	{"phone": "+70167038141"}
0005434252236	0E47BB	0383 981824	EVGENIY VLASOV	{"email": "e_vlasov28121961@postgrespro.ru", "phone": "+70395698468"}
0005434252237	133137	2233 828604	GENNADIY SOROKIN	{"email": "sorokingennadiy_061975@postgrespro.ru", "phone": "+70590232429"}
0005434252238	3713D0	9746 275025	NINA TIKHONOVA	{"email": "tikhonova_n.091974@postgrespro.ru", "phone": "+70238601709"}
0005434252239	9E4244	1561 893091	TATYANA KUDRYASHOVA	{"phone": "+70665408539"}
0005434252240	EEF452	6295 287672	NATALYA ANDREEVA	{"phone": "+70184033860"}
0005434252241	EEF452	1494 328490	ANDREY GERASIMOV	{"phone": "+70630467899"}
0005434252242	1DE9C6	4730 475802	SVETLANA KOROLEVA	{"phone": "+70050906093"}
0005434252243	7FBD4C	9029 448836	NIKOLAY MAKAROV	{"phone": "+70925334553"}
0005434252244	7FBD4C	2086 123676	RUSLAN PETROV	{"phone": "+70882660659"}
0005434252245	33E7A8	1157 356177	SERGEY FEDOTOV	{"email": "sergey-fedotov-081958@postgrespro.ru", "phone": "+70889118960"}
0005434264675	B88FA1	2188 083514	TATYANA IVANOVA	{"phone": "+70760524491"}
0005434264676	CABDE6	5968 580375	ARTUR RODIONOV	{"phone": "+70168288736"}
0005434264677	1E8D84	5321 265573	IRINA KUZNECOVA	{"phone": "+70935845905"}
0005434264678	91E22E	8265 490940	ARTEM KUZNECOV	{"phone": "+70423486584"}
0005434264679	91E22E	7836 454171	LYUDMILA KULIKOVA	{"phone": "+70272477227"}
0005434264680	80AF18	5813 037366	ZLATA KUZNECOVA	{"email": "z.kuznecova-1975@postgrespro.ru", "phone": "+70650297750"}
0005434264681	80AF18	0770 849920	EVGENIY FROLOV	{"email": "evgeniyfrolov121955@postgrespro.ru", "phone": "+70419965652"}
0005434264682	2B15A1	7673 991847	VADIM TIKHONOV	{"email": "v_tikhonov_091985@postgrespro.ru", "phone": "+70991249271"}
0005434264683	A51636	5776 711052	LIDIYA ZAYCEVA	{"phone": "+70637239467"}
0005434264684	A51636	4399 271513	LYUBOV VLASOVA	{"phone": "+70343057175"}
0005434264685	AB5A69	0736 553922	EVGENIY KONOVALOV	{"phone": "+70100906650"}
0005434264686	A6A45F	2707 054821	ALEKSEY NOVIKOV	{"phone": "+70473423198"}
0005434264687	21A85F	7369 174080	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov-08061978@postgrespro.ru", "phone": "+70901448396"}
0005434264688	F47959	6069 257098	MARIYA KOVALEVA	{"phone": "+70911405255"}
0005434264689	D38632	0533 182953	SVETLANA BELOVA	{"email": "s-belova-1977@postgrespro.ru", "phone": "+70541154833"}
0005434264690	D38632	3235 571053	NIKOLAY OSIPOV	{"email": "n.osipov_1959@postgrespro.ru", "phone": "+70437712837"}
0005434264691	A0E92C	4909 058720	SERGEY CHERNOV	{"phone": "+70966921417"}
0005434264692	9ECCF9	2234 655022	ALEKSANDRA KONDRATEVA	{"phone": "+70816758141"}
0005434264693	1F10EF	6389 506794	TATYANA SERGEEVA	{"phone": "+70465364323"}
0005434264694	1F10EF	8130 829605	NIKOLAY BONDARENKO	{"phone": "+70336291208"}
0005434264695	6B1FEC	0100 256631	NATALYA ABRAMOVA	{"email": "abramovanatalya.091963@postgrespro.ru", "phone": "+70036348032"}
0005434264696	E6979C	6457 665071	IRINA GUSEVA	{"phone": "+70805482813"}
0005434264697	E6979C	8995 538976	ANDREY ZAKHAROV	{"email": "zakharovandrey121974@postgrespro.ru", "phone": "+70520571132"}
0005434264698	82BE3B	8702 943361	VLADISLAV IVANOV	{"email": "ivanov-v_071975@postgrespro.ru", "phone": "+70562057295"}
0005434264699	FDBD44	3091 153656	NINA SCHERBAKOVA	{"phone": "+70250011327"}
0005434264700	16D8F9	2028 658687	SVETLANA FEDOROVA	{"phone": "+70944897868"}
0005434264701	16D8F9	9163 170919	SEMEN ISAEV	{"email": "s-isaev.12031964@postgrespro.ru", "phone": "+70743203117"}
0005434264702	90F799	5494 933561	NINA GRISHINA	{"email": "grishina_nina-01041968@postgrespro.ru", "phone": "+70826422279"}
0005434264703	90F799	9546 834927	MAKSIM FROLOV	{"phone": "+70911021808"}
0005434264704	90F799	9307 640264	VERONIKA POPOVA	{"email": "popova.veronika1973@postgrespro.ru", "phone": "+70352290425"}
0005434264705	84E1C1	4330 369599	ANDREY FILIPPOV	{"email": "a_filippov-121964@postgrespro.ru", "phone": "+70414758918"}
0005434264706	6D0EC1	2460 877091	OLEG KOZLOV	{"email": "kozlov.o.29111967@postgrespro.ru", "phone": "+70544249682"}
0005434264707	6D0EC1	7471 767707	ELENA ISAEVA	{"email": "isaeva-e1972@postgrespro.ru", "phone": "+70332920376"}
0005434264708	B3DA14	6960 433974	SVETLANA ISAEVA	{"phone": "+70182453938"}
0005434264709	B3DA14	7001 696643	NIKOLAY IVANOV	{"phone": "+70697495538"}
0005434264710	47BAA7	2728 792190	ALEKSEY EGOROV	{"email": "a-egorov_1958@postgrespro.ru", "phone": "+70587765425"}
0005434264711	316CC5	6323 363712	GENNADIY NOVIKOV	{"phone": "+70699824984"}
0005434264712	316CC5	7845 930419	LIDIYA SMIRNOVA	{"email": "l-smirnova.19011971@postgrespro.ru", "phone": "+70012900294"}
0005434264713	70296E	4467 845381	MAKSIM ILIN	{"email": "m-ilin07051972@postgrespro.ru", "phone": "+70268746000"}
0005434264714	00A9F5	0392 872030	ALEKSEY ZHUKOV	{"email": "zhukova-11021966@postgrespro.ru", "phone": "+70865033870"}
0005434264715	5053BD	9023 075779	IRINA MASLOVA	{"phone": "+70981020439"}
0005434264716	5A0E6F	9614 570459	MAKSIM MAKAROV	{"phone": "+70993221103"}
0005434264717	5A0E6F	5123 719048	GALINA SERGEEVA	{"email": "galinasergeeva_071975@postgrespro.ru", "phone": "+70965745439"}
0005434264718	214FA9	0646 900377	VLADIMIR MOROZOV	{"email": "morozovvladimir_1973@postgrespro.ru", "phone": "+70035117147"}
0005434264719	7214A3	1778 213210	OLGA SOKOLOVA	{"email": "osokolova.1971@postgrespro.ru", "phone": "+70707821434"}
0005434264720	8C6377	5900 905994	INGA EFIMOVA	{"phone": "+70840549322"}
0005434264721	263E56	5102 295818	VLADIMIR KUZMIN	{"email": "v_kuzmin.11041971@postgrespro.ru", "phone": "+70697906649"}
0005434264722	403A28	2750 590360	SOFYA SCHERBAKOVA	{"phone": "+70512251801"}
0005434264723	4294CD	4572 985728	PAVEL GUSEV	{"email": "gusevp.061972@postgrespro.ru", "phone": "+70261024702"}
0005434264724	4294CD	8654 208538	OLGA MOROZOVA	{"email": "olga_morozova-1981@postgrespro.ru", "phone": "+70000578638"}
0005434264725	6309EB	6650 966249	NATALYA NIKITINA	{"email": "nikitina_natalya1963@postgrespro.ru", "phone": "+70112278524"}
0005434264726	0A950A	9790 788724	ALEKSEY SEMENOV	{"phone": "+70635960741"}
0005434264727	0E18A8	0192 853413	ILMIRA SOKOLOVA	{"email": "sokolovailmira081964@postgrespro.ru", "phone": "+70845018334"}
0005434264728	6C00AD	7893 866318	ALEKSANDR FEDOTOV	{"email": "a-fedotov1985@postgrespro.ru", "phone": "+70288975244"}
0005434264729	7004CF	7507 082166	ZHANNA RODIONOVA	{"email": "z-rodionova1977@postgrespro.ru", "phone": "+70068977033"}
0005434264730	7004CF	3477 837129	ELENA DAVYDOVA	{"phone": "+70206648910"}
0005434264731	7004CF	0596 250894	KONSTANTIN KUDRYASHOV	{"phone": "+70006046719"}
0005434264732	3A8C2D	5482 674871	ALEKSEY FEDOTOV	{"phone": "+70534275850"}
0005434264733	508110	3058 291330	VALENTINA DMITRIEVA	{"phone": "+70061064579"}
0005434264734	AA7374	3077 378733	YULIYA MASLOVA	{"phone": "+70714300247"}
0005434264735	AA7374	3338 604380	MARINA SERGEEVA	{"email": "marina_sergeeva_1973@postgrespro.ru", "phone": "+70528824325"}
0005434264736	AA7374	6745 812672	SERGEY FEDOROV	{"email": "fedorov_sergey-031976@postgrespro.ru", "phone": "+70702320900"}
0005434264737	384BB7	4739 911964	YURIY SHEVCHENKO	{"email": "shevchenko-y011974@postgrespro.ru", "phone": "+70160452278"}
0005434264738	384BB7	7127 570034	SERGEY SAVELEV	{"phone": "+70888882676"}
0005434264739	384BB7	0172 631477	ANATOLIY ZAYCEV	{"email": "zaycev-a.1973@postgrespro.ru", "phone": "+70489204122"}
0005434264740	0C9DFD	5466 462744	OLGA EGOROVA	{"email": "egorova.o-09111964@postgrespro.ru", "phone": "+70897467667"}
0005434264741	80C54C	6976 181252	NAILYA BORISOVA	{"phone": "+70201499132"}
0005434264742	943F8F	7924 788178	LYUBOV TIMOFEEVA	{"email": "lyubov.timofeeva-23041963@postgrespro.ru", "phone": "+70783613388"}
0005434264743	943F8F	7796 016845	GENNADIY ISAEV	{"phone": "+70876318101"}
0005434264744	521F0A	7028 491180	VLADISLAV OSIPOV	{"email": "vladislav-osipov_1967@postgrespro.ru", "phone": "+70174907471"}
0005434264745	D7FED3	9089 086911	ELENA ROMANOVA	{"email": "elena-romanova_031971@postgrespro.ru", "phone": "+70926282318"}
0005434264746	A91826	7097 865072	KONSTANTIN AFANASEV	{"phone": "+70018508134"}
0005434264747	CD54BE	6753 598042	DMITRIY EGOROV	{"email": "d-egorov-1971@postgrespro.ru", "phone": "+70900874873"}
0005434264748	31717A	8465 058133	LIDIYA EGOROVA	{"email": "l.egorova-1965@postgrespro.ru", "phone": "+70205269057"}
0005434264749	BBC2BF	8038 861550	TIMUR GERASIMOV	{"phone": "+70857301035"}
0005434264750	F1B1BA	4209 459021	VITALIY KISELEV	{"email": "vitaliykiselev-101977@postgrespro.ru", "phone": "+70930610293"}
0005434264751	27DBF7	9916 966740	SVETLANA LUKYANOVA	{"phone": "+70239117887"}
0005434264752	27DBF7	9908 009077	NATALYA ZAKHAROVA	{"email": "natalya_zakharova-1982@postgrespro.ru", "phone": "+70387307807"}
0005434264753	287FB7	4302 572928	ALEKSEY SAVELEV	{"phone": "+70668645002"}
0005434264754	58246C	7005 250938	ANATOLIY KULIKOV	{"phone": "+70522340667"}
0005434264755	1ED6B9	1592 159618	IRINA ZHURAVLEVA	{"email": "i.zhuravleva-1966@postgrespro.ru", "phone": "+70050509919"}
0005434264756	CBAD46	1843 666183	NATALYA PETROVA	{"phone": "+70951795828"}
0005434264757	7D3F13	6477 465575	ILYA DENISOV	{"email": "denisov_ilya111972@postgrespro.ru", "phone": "+70039095669"}
0005434264758	7D3F13	7289 527643	ELENA TIKHONOVA	{"phone": "+70422690455"}
0005434264759	C35F68	3369 619360	NATALYA TIMOFEEVA	{"email": "natalya.timofeeva021972@postgrespro.ru", "phone": "+70803084793"}
0005434264760	C35F68	0834 512765	ANDREY FILIPPOV	{"email": "filippov-andrey_031960@postgrespro.ru", "phone": "+70323478930"}
0005434264761	A3FF4F	9607 439409	SERGEY STEPANOV	{"phone": "+70106247356"}
0005434264762	A3FF4F	9364 662148	SERGEY FROLOV	{"email": "frolov-sergey.27061969@postgrespro.ru", "phone": "+70028656479"}
0005434264763	16F0FE	9103 855871	MARIYA MALYSHEVA	{"email": "malyshevam_081974@postgrespro.ru", "phone": "+70901869782"}
0005434264764	2F1E82	4545 200996	ARTEM EGOROV	{"phone": "+70741834625"}
0005434264765	2F1E82	6738 733273	ALEKSANDR KARPOV	{"email": "a.karpov.1968@postgrespro.ru", "phone": "+70663717334"}
0005434264766	CC6E53	1366 602546	YURIY MIRONOV	{"phone": "+70720990775"}
0005434264767	FBCEB6	5534 806081	VALERIY NOVIKOV	{"email": "valeriy.novikov-1980@postgrespro.ru", "phone": "+70988220934"}
0005434264768	FBCEB6	5170 785405	EVGENIY FEDOTOV	{"phone": "+70056263027"}
0005434264769	E2C60E	3311 007873	LYUDMILA KUZNECOVA	{"email": "kuznecova.lyudmila-1972@postgrespro.ru", "phone": "+70450886878"}
0005434264770	86258D	1881 251124	IRINA TIKHONOVA	{"email": "irinatikhonova-25111972@postgrespro.ru", "phone": "+70466070119"}
0005434264771	FAEA56	5205 897457	MARIYA KISELEVA	{"phone": "+70336590061"}
0005434264772	FAEA56	2173 868679	YURIY SERGEEV	{"phone": "+70459150853"}
0005434264773	1E290B	2352 214201	VITALIY SHEVCHENKO	{"email": "vshevchenko1977@postgrespro.ru", "phone": "+70341579116"}
0005434264774	4FB38A	0611 431173	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-m_011980@postgrespro.ru", "phone": "+70863318332"}
0005434264775	6ECEB2	1377 407688	VLADIMIR KUZNECOV	{"email": "v_kuznecov.13021964@postgrespro.ru", "phone": "+70759954346"}
0005434264776	6ECEB2	6266 089318	NIKOLAY SAVELEV	{"email": "n_savelev011978@postgrespro.ru", "phone": "+70297161899"}
0005434264777	C66D51	1812 382113	ANNA NESTEROVA	{"phone": "+70242943396"}
0005434264778	C66D51	9562 842797	LYUBOV NOVIKOVA	{"email": "lyubov.novikova1968@postgrespro.ru", "phone": "+70874181696"}
0005434264779	5BAC9E	5232 476934	ALEKSEY IVANOV	{"email": "ivanov.a_09121967@postgrespro.ru", "phone": "+70290419966"}
0005434264780	5BAC9E	5808 951074	LYUBOV MOROZOVA	{"email": "morozova.l-1969@postgrespro.ru", "phone": "+70873083839"}
0005434264781	F4029E	6963 777142	NATALIYA SERGEEVA	{"email": "n-sergeeva1983@postgrespro.ru", "phone": "+70254487395"}
0005434264782	88DBB6	9785 502562	ALEKSEY FEDOTOV	{"phone": "+70042955203"}
0005434264783	23FE11	5651 238253	YURIY FROLOV	{"email": "frolov-y08051973@postgrespro.ru", "phone": "+70252410557"}
0005434264784	287622	9947 550346	GALINA TITOVA	{"email": "gtitova_1970@postgrespro.ru", "phone": "+70049368232"}
0005434264785	287622	8847 405998	ALENA MIKHAYLOVA	{"phone": "+70577199499"}
0005434264786	25EE54	9239 712854	ILDAR GORBUNOV	{"email": "i_gorbunov.081980@postgrespro.ru", "phone": "+70690507670"}
0005434264787	6F54B2	9350 611422	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov-041978@postgrespro.ru", "phone": "+70962713398"}
0005434264788	6F54B2	3191 803080	NATALYA RYABOVA	{"email": "ryabova-natalya1972@postgrespro.ru", "phone": "+70228474073"}
0005434264789	6F54B2	4451 461486	PETR KISELEV	{"email": "petr-kiselev.071981@postgrespro.ru", "phone": "+70147536703"}
0005434264790	CE5D55	9820 780048	MARIYA KUDRYASHOVA	{"email": "kudryashovam011976@postgrespro.ru", "phone": "+70468365000"}
0005434264791	0A6462	6387 261629	NIKOLAY PETROV	{"email": "petrov.nikolay1965@postgrespro.ru", "phone": "+70818085181"}
0005434264792	9D9F0C	4703 434837	OLEG ANDREEV	{"phone": "+70831278108"}
0005434264793	C6FEA6	1482 966917	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov1969@postgrespro.ru", "phone": "+70862727049"}
0005434264794	C6FEA6	6364 793614	ALEKSEY GERASIMOV	{"phone": "+70002019976"}
0005434264795	9CAB69	2285 825500	ANATOLIY KONOVALOV	{"email": "akonovalov.1959@postgrespro.ru", "phone": "+70825489639"}
0005434264796	DA4042	9771 995668	GENNADIY NIKITIN	{"email": "gennadiy-nikitin.30071975@postgrespro.ru", "phone": "+70122129586"}
0005434264797	32299A	2614 581514	IRINA NIKITINA	{"phone": "+70900003582"}
0005434264798	F203EE	7422 267624	EKATERINA ANDREEVA	{"phone": "+70277137462"}
0005434264799	1B494A	2438 764514	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir.1974@postgrespro.ru", "phone": "+70504393372"}
0005434264800	1B494A	7880 048207	LYUBOV FEDOROVA	{"phone": "+70896415317"}
0005434264801	93ACED	8542 319502	VYACHESLAV MIKHAYLOV	{"phone": "+70512162922"}
0005434264802	93ACED	2131 186471	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev-24081968@postgrespro.ru", "phone": "+70431308800"}
0005434264803	01D162	1068 370012	NINA NIKOLAEVA	{"phone": "+70783243591"}
0005434264804	423E8B	2941 579940	TAMARA KUDRYASHOVA	{"phone": "+70986675684"}
0005434264805	954DE1	7208 745009	MAKSIM GERASIMOV	{"phone": "+70061950242"}
0005434264806	954DE1	8636 842188	DMITRIY ALEKSEEV	{"phone": "+70733790150"}
0005434264807	954DE1	1085 404628	SERGEY DENISOV	{"email": "denisovsergey_111967@postgrespro.ru", "phone": "+70118476513"}
0005434264808	3BF1B6	3211 685182	YULIYA RODIONOVA	{"email": "yuliya-rodionova-1954@postgrespro.ru", "phone": "+70765039525"}
0005434264809	52EC54	7171 562531	OLGA MATVEEVA	{"phone": "+70139775320"}
0005434264810	52EC54	0248 888541	ZINAIDA SERGEEVA	{"phone": "+70632600684"}
0005434264811	06AB96	7941 389875	DMITRIY KARPOV	{"email": "karpov_d051967@postgrespro.ru", "phone": "+70121093065"}
0005434264812	06AB96	2126 486329	ANDREY GERASIMOV	{"email": "gerasimov-andrey.1968@postgrespro.ru", "phone": "+70358331167"}
0005434264813	B32390	5023 498935	VERA POTAPOVA	{"phone": "+70160871983"}
0005434264814	6D4A53	4614 664140	TALGAT PETROV	{"phone": "+70456716173"}
0005434264815	6D1F67	8280 060328	DMITRIY NOVIKOV	{"phone": "+70636490087"}
0005434264816	86B2C0	7716 560051	ELENA ISAEVA	{"phone": "+70254281700"}
0005434264817	F37E42	4987 451923	ALEKSEY ZAKHAROV	{"email": "zakharov_aleksey-27111966@postgrespro.ru", "phone": "+70421638951"}
0005434264818	A65A8C	9312 284664	KLAVDIYA NIKOLAEVA	{"email": "nikolaeva.k.1974@postgrespro.ru", "phone": "+70119410974"}
0005434264819	A65A8C	6526 806089	NATALYA MIRONOVA	{"phone": "+70302263239"}
0005434264820	9FD32D	0614 487670	SERGEY KRASNOV	{"email": "skrasnov.1969@postgrespro.ru", "phone": "+70231612317"}
0005434264821	E4ABEB	7780 998537	YULIYA IVANOVA	{"phone": "+70524356082"}
0005434264822	69DE37	2936 780510	ELENA POTAPOVA	{"phone": "+70130304947"}
0005434264823	4CCEAC	1154 572284	IRINA TARASOVA	{"email": "irinatarasova-1981@postgrespro.ru", "phone": "+70345382932"}
0005434264824	4CCEAC	3222 378532	ALEKSEY OSIPOV	{"email": "aleksey-osipov.1962@postgrespro.ru", "phone": "+70261927346"}
0005434264825	61C7F6	2125 814331	NIKOLAY STEPANOV	{"phone": "+70467565760"}
0005434264826	6498C2	6750 123157	TATYANA BELOVA	{"phone": "+70164401683"}
0005434264827	D7704A	9978 708600	ALEKSEY NIKOLAEV	{"email": "a.nikolaev-091973@postgrespro.ru", "phone": "+70448091594"}
0005434264828	D7704A	9737 632243	DANIIL TIMOFEEV	{"phone": "+70093042916"}
0005434264829	D2A336	7855 747896	ANDREY TARASOV	{"phone": "+70979504014"}
0005434264830	27D16F	5311 981584	ANNA PETROVA	{"phone": "+70398322496"}
0005434264831	B4E707	7295 921515	EVGENIY YAKOVLEV	{"phone": "+70946351984"}
0005434264832	432D6E	8716 745644	VLADIMIR KUZNECOV	{"phone": "+70967660214"}
0005434264833	993904	6528 130288	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov.16061959@postgrespro.ru", "phone": "+70593732137"}
0005434264834	993904	5431 778938	SERGEY GERASIMOV	{"email": "gerasimov-sergey.101980@postgrespro.ru", "phone": "+70200275165"}
0005434264835	1A471C	2028 242323	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov_1979@postgrespro.ru", "phone": "+70583951694"}
0005434264836	24832B	1940 038887	ANNA KOLESNIKOVA	{"email": "kolesnikovaa_1971@postgrespro.ru", "phone": "+70497275229"}
0005434264837	50817F	8728 726716	VIKTOR CHERNOV	{"phone": "+70520885056"}
0005434264838	28A3C0	8537 284510	NIKOLAY SIDOROV	{"phone": "+70992700391"}
0005434264839	38C46F	8100 161826	SHAMIL AFANASEV	{"email": "afanasev-s_101970@postgrespro.ru", "phone": "+70322728596"}
0005434264840	38C46F	9239 909232	ELENA SOLOVEVA	{"email": "soloveva_e15111975@postgrespro.ru", "phone": "+70399157774"}
0005434264841	F48CE6	2804 811540	GENNADIY BONDARENKO	{"phone": "+70800297938"}
0005434264842	F48CE6	8254 573634	ANNA PETROVA	{"email": "apetrova_02101971@postgrespro.ru", "phone": "+70336227372"}
0005434264843	F48CE6	6862 741768	ROMAN MELNIKOV	{"phone": "+70627229170"}
0005434264844	67426C	6747 560681	OKSANA GRISHINA	{"phone": "+70657284518"}
0005434265012	C6EED1	1731 405871	PAVEL VASILEV	{"phone": "+70836680926"}
0005434264845	15C55C	7808 824331	IGOR ZHURAVLEV	{"email": "igor_zhuravlev051976@postgrespro.ru", "phone": "+70132340760"}
0005434264846	15C55C	8451 287879	LYUDMILA EGOROVA	{"email": "egorova_l-1971@postgrespro.ru", "phone": "+70942579279"}
0005434264847	1772D0	5212 799570	ALEKSANDR GORBUNOV	{"email": "gorbunova.081978@postgrespro.ru", "phone": "+70010534618"}
0005434264848	F0978E	4854 637946	YURIY GRIGOREV	{"phone": "+70794299106"}
0005434264849	F0978E	4111 583320	ZINAIDA MIRONOVA	{"phone": "+70290586563"}
0005434264850	F0978E	3758 196044	OLEG ALEKSEEV	{"phone": "+70307234641"}
0005434264851	C7C680	7555 238236	ALEKSEY KOZLOV	{"email": "alekseykozlov-20051974@postgrespro.ru", "phone": "+70594277764"}
0005434264852	C7C680	5778 392517	LYUDMILA ZHUKOVA	{"phone": "+70660881709"}
0005434264853	C7C680	1776 589323	ALEKSANDR MELNIKOV	{"phone": "+70818983229"}
0005434264854	E9F1FE	7562 146075	ALEKSEY KRASNOV	{"email": "krasnov.a031962@postgrespro.ru", "phone": "+70299527995"}
0005434264855	E9F1FE	1941 204253	ANNA EFREMOVA	{"phone": "+70672842855"}
0005434264856	2698C2	9531 350325	OLGA ALEKSEEVA	{"email": "alekseevaolga-1967@postgrespro.ru", "phone": "+70614448015"}
0005434264857	2698C2	1921 712820	GUZEL ZAYCEVA	{"phone": "+70499566857"}
0005434264858	2698C2	6146 097691	ANATOLIY MIKHAYLOV	{"email": "anatoliy.mikhaylov-111973@postgrespro.ru", "phone": "+70970545342"}
0005434264859	CDF78D	0826 866864	ANDREY NAZAROV	{"phone": "+70499338312"}
0005434264860	CDF78D	4693 133100	SERGEY ALEKSANDROV	{"phone": "+70380514994"}
0005434264861	8A926B	9210 731462	IRINA MOISEEVA	{"email": "i.moiseeva_15121961@postgrespro.ru", "phone": "+70399027883"}
0005434264862	6CE871	5595 498272	IRINA BORISOVA	{"email": "borisova.irina.1974@postgrespro.ru", "phone": "+70425887628"}
0005434264863	6CE871	6782 694287	IVAN KUZNECOV	{"phone": "+70613392883"}
0005434264864	27F6D0	2172 262451	IRINA BOGDANOVA	{"email": "bogdanova.i.1980@postgrespro.ru", "phone": "+70203873242"}
0005434264865	21FF7A	3545 650742	KSENIYA KUZNECOVA	{"phone": "+70708939279"}
0005434264866	AAAA34	8888 582877	DANIYA DANILOVA	{"email": "danilova_daniya.071965@postgrespro.ru", "phone": "+70410383466"}
0005434264867	ECDC02	3328 451938	YULIYA ALEKSEEVA	{"phone": "+70305205819"}
0005434264868	306D41	1356 308652	DMITRIY PAVLOV	{"email": "pavlov-dmitriy_101962@postgrespro.ru", "phone": "+70103176820"}
0005434264869	306D41	8439 034982	KLAVDIYA PAVLOVA	{"email": "kpavlova1984@postgrespro.ru", "phone": "+70823199335"}
0005434264870	8FF3A5	9962 887116	VIKTOR SMIRNOV	{"phone": "+70756155051"}
0005434264871	4D627F	0011 050651	ALEKSEY CHERNOV	{"email": "achernov-28111970@postgrespro.ru", "phone": "+70943298353"}
0005434264872	055ED1	9939 984063	SVETLANA KUZNECOVA	{"email": "s_kuznecova_27121966@postgrespro.ru", "phone": "+70035974853"}
0005434264873	055ED1	0405 347047	PAVEL MOROZOV	{"phone": "+70342392656"}
0005434264874	9584B5	0591 331039	TAMARA PETROVA	{"email": "petrova_tamara.031971@postgrespro.ru", "phone": "+70087490570"}
0005434264875	81C279	8001 045987	SVETLANA TARASOVA	{"phone": "+70335756475"}
0005434264876	65A3E0	5781 613463	YURIY SOKOLOV	{"phone": "+70863783053"}
0005434264877	59FB0F	2126 092871	TAMARA OVCHINNIKOVA	{"phone": "+70426336942"}
0005434264878	59FB0F	8074 933187	MARIYA ANDREEVA	{"phone": "+70013819143"}
0005434264879	59FB0F	0529 826094	YURIY SMIRNOV	{"email": "y.smirnov.1975@postgrespro.ru", "phone": "+70243444437"}
0005434264880	367D99	8735 807947	PAVEL NAZAROV	{"email": "pavelnazarov_1975@postgrespro.ru", "phone": "+70373648740"}
0005434264881	5F6AD7	1609 682142	VIKTOR PAVLOV	{"phone": "+70627484422"}
0005434264882	5F6AD7	4533 973043	LILIYA ANISIMOVA	{"phone": "+70322011099"}
0005434264883	527316	9725 132587	VLADIMIR MEDVEDEV	{"email": "vladimirmedvedev_1976@postgrespro.ru", "phone": "+70804093070"}
0005434264884	12337F	6081 716055	FARIDA TIKHONOVA	{"email": "tikhonova-f101969@postgrespro.ru", "phone": "+70263404407"}
0005434264885	34E094	7771 840450	VLADIMIR PETROV	{"email": "petrov.vladimir-031969@postgrespro.ru", "phone": "+70655092691"}
0005434264886	A35455	3538 310930	IRINA KOMAROVA	{"email": "irina-komarova_1979@postgrespro.ru", "phone": "+70709158791"}
0005434264887	B07F51	4304 803557	NADEZHDA POPOVA	{"email": "popova-nadezhda30121975@postgrespro.ru", "phone": "+70020923079"}
0005434264888	AA46C8	1762 620135	INNA ALEKSANDROVA	{"phone": "+70267875633"}
0005434264889	E52D86	1368 671736	SERGEY KUZMIN	{"email": "s.kuzmin_25081966@postgrespro.ru", "phone": "+70750114951"}
0005434264890	DBF887	8835 199753	NATALYA BORISOVA	{"email": "n.borisova.1979@postgrespro.ru", "phone": "+70576013947"}
0005434264891	DBF887	8115 624999	BORIS ROMANOV	{"email": "b_romanov_1967@postgrespro.ru", "phone": "+70521391407"}
0005434264892	DBF887	9389 757577	MARINA MOROZOVA	{"email": "m.morozova.031977@postgrespro.ru", "phone": "+70052241295"}
0005434264893	F19D2E	5255 278275	SVETLANA PETROVA	{"phone": "+70295040405"}
0005434264894	FE43B0	0698 489689	ELVIRA PETROVA	{"email": "petrova.elvira-1973@postgrespro.ru", "phone": "+70036920940"}
0005434264895	BBCA0D	6400 979207	OLEG KUZNECOV	{"email": "o-kuznecov.1974@postgrespro.ru", "phone": "+70074883385"}
0005434264896	BBCA0D	5356 160665	IRAIDA YUDINA	{"phone": "+70121085127"}
0005434264897	037D22	9903 375132	SERGEY BORISOV	{"phone": "+70425407370"}
0005434264898	17BBA1	7809 480474	VASILIY KOROLEV	{"email": "v.korolev_051970@postgrespro.ru", "phone": "+70103289267"}
0005434264899	DBC906	8460 212682	ANNA FILIPPOVA	{"email": "filippova.anna.081968@postgrespro.ru", "phone": "+70621876186"}
0005434264900	C95E9C	5690 970868	NATALYA SOLOVEVA	{"email": "n_soloveva-1971@postgrespro.ru", "phone": "+70188895511"}
0005434264901	319B61	8362 283113	EVGENIY STEPANOV	{"email": "stepanov-evgeniy.1969@postgrespro.ru", "phone": "+70431583983"}
0005434264902	319B61	2952 071314	VARVARA TIKHONOVA	{"phone": "+70502472236"}
0005434264903	14DDA4	7465 565214	ALEKSANDR FEDOROV	{"phone": "+70582824837"}
0005434264904	F2CE2E	0750 359176	VITALIY GORBUNOV	{"phone": "+70340951909"}
0005434264905	9683B8	6904 847478	GALINA MAKSIMOVA	{"email": "maksimova-g_071972@postgrespro.ru", "phone": "+70551259034"}
0005434264906	9683B8	2880 330088	LYUDMILA MASLOVA	{"email": "lmaslova_1977@postgrespro.ru", "phone": "+70045420126"}
0005434264907	E782FF	4566 713530	VERONIKA ALEKSEEVA	{"phone": "+70517685375"}
0005434264908	0D6057	7458 641074	ILDAR MATVEEV	{"email": "ildar-matveev021967@postgrespro.ru", "phone": "+70580877799"}
0005434264909	454DC3	1398 888611	GALINA ARKHIPOVA	{"phone": "+70270248752"}
0005434264910	454DC3	7482 186320	MARIYA GAVRILOVA	{"email": "gavrilovamariya-021978@postgrespro.ru", "phone": "+70261534276"}
0005434264911	A10714	3838 628880	IRINA SMIRNOVA	{"email": "i_smirnova-1964@postgrespro.ru", "phone": "+70568759220"}
0005434264912	412F6A	6540 614604	SVETLANA DMITRIEVA	{"email": "s-dmitrieva.1959@postgrespro.ru", "phone": "+70414520953"}
0005434264913	412F6A	7070 334877	NATALIYA EGOROVA	{"email": "n_egorova1969@postgrespro.ru", "phone": "+70957260668"}
0005434264914	C7D3AE	4516 019772	MATVEY IVANOV	{"email": "ivanovmatvey-1971@postgrespro.ru", "phone": "+70364790326"}
0005434264915	C7D3AE	8025 146808	VERA DMITRIEVA	{"phone": "+70799975302"}
0005434264916	39BBC6	1343 061741	ARTEM KARPOV	{"email": "karpov-a041972@postgrespro.ru", "phone": "+70061375499"}
0005434264917	4EBE32	5331 207128	DARYA TITOVA	{"email": "darya_titova_011974@postgrespro.ru", "phone": "+70147084999"}
0005434264918	83E452	2350 260310	ALEKSEY FEDOROV	{"email": "fedorov_a01091976@postgrespro.ru", "phone": "+70742298617"}
0005434264919	83E452	6737 997716	EVGENIYA NIKITINA	{"phone": "+70191881770"}
0005434264920	EBF61C	6628 859324	PETR KUZNECOV	{"phone": "+70238384685"}
0005434264921	E69C8C	6800 292755	NIKOLAY SOLOVEV	{"phone": "+70453662327"}
0005434264922	E69C8C	6521 365452	ANNA DMITRIEVA	{"email": "admitrieva-091976@postgrespro.ru", "phone": "+70697281903"}
0005434264923	C6FD13	9127 984513	VLADIMIR ROMANOV	{"email": "romanov.v-13051970@postgrespro.ru", "phone": "+70640633853"}
0005434264924	C6FD13	9289 054952	MIKHAIL PETROV	{"email": "petrov-mikhail17051969@postgrespro.ru", "phone": "+70041769172"}
0005434264925	DDE65F	4418 991855	SERGEY DAVYDOV	{"email": "sergey-davydov-121971@postgrespro.ru", "phone": "+70075201084"}
0005434264926	5BE0F9	0697 789306	OLEG TIKHONOV	{"email": "tikhonov_o-1965@postgrespro.ru", "phone": "+70801474353"}
0005434264927	9426C4	8540 624948	OLGA KUZNECOVA	{"email": "o.kuznecova_1962@postgrespro.ru", "phone": "+70606450992"}
0005434264928	6FE0EB	7944 836513	ANASTASIYA MIKHAYLOVA	{"phone": "+70762005054"}
0005434264929	6FE0EB	5638 940676	ALEKSANDRA BORISOVA	{"email": "borisova_aleksandra.1980@postgrespro.ru", "phone": "+70003655939"}
0005434264930	324CDF	8145 037736	ANASTASIYA YUDINA	{"phone": "+70830636630"}
0005434264931	E47F00	9868 064006	OLGA KUZMINA	{"email": "kuzminaolga_03031976@postgrespro.ru", "phone": "+70369116363"}
0005434264932	6B61B0	0230 415560	OLGA KULIKOVA	{"phone": "+70979399153"}
0005434264933	CEEEB7	3180 367665	ELENA VLASOVA	{"email": "elenavlasova.1971@postgrespro.ru", "phone": "+70275364953"}
0005434264934	8A7D65	6084 534886	ARINA ROMANOVA	{"email": "arinaromanova121971@postgrespro.ru", "phone": "+70267251928"}
0005434264935	74B6A8	5238 785613	TAMARA IVANOVA	{"phone": "+70465594975"}
0005434264936	74B6A8	4942 917830	MIKHAIL YAKOVLEV	{"email": "m_yakovlev.12071968@postgrespro.ru", "phone": "+70228814161"}
0005434264937	72B4DF	4304 654647	VALENTIN MEDVEDEV	{"email": "valentin_medvedev-1963@postgrespro.ru", "phone": "+70662877868"}
0005434264938	72B4DF	3487 058194	SVETLANA KRASNOVA	{"email": "krasnovasvetlana_1970@postgrespro.ru", "phone": "+70912110484"}
0005434264939	18D0E0	2967 076526	IRINA MIKHAYLOVA	{"email": "mikhaylovai_20071966@postgrespro.ru", "phone": "+70320824412"}
0005434264940	18D0E0	7862 969341	MARIYA CHERNOVA	{"email": "chernova-mariya.1974@postgrespro.ru", "phone": "+70625154904"}
0005434264941	DD78BE	6683 167314	ALEKSANDRA ZAYCEVA	{"email": "a.zayceva-1977@postgrespro.ru", "phone": "+70875870256"}
0005434264942	78C671	4124 425787	NINA PETROVA	{"phone": "+70630720892"}
0005434264943	CB3588	7941 593427	KRISTINA NAZAROVA	{"phone": "+70003680685"}
0005434264944	CB3588	7325 254294	NAILYA TROFIMOVA	{"phone": "+70043257796"}
0005434264945	A01569	3838 152472	ELENA KUZNECOVA	{"phone": "+70113387782"}
0005434264946	59FF97	7010 784568	ALENA ZOTOVA	{"phone": "+70549434429"}
0005434264947	59FF97	4933 282683	TATYANA SOLOVEVA	{"phone": "+70696977865"}
0005434264948	59FF97	5851 317090	VLADIMIR DENISOV	{"email": "v.denisov-1964@postgrespro.ru", "phone": "+70991536733"}
0005434264949	659025	3222 724758	TAISIYA KOVALEVA	{"phone": "+70350515663"}
0005434264950	083CC0	0242 094982	TIMUR MOROZOV	{"phone": "+70448664966"}
0005434264951	083CC0	3421 250164	DAMIR OSIPOV	{"email": "osipov_damir19011964@postgrespro.ru", "phone": "+70976655308"}
0005434264952	083CC0	9602 509556	VASILIY ALEKSEEV	{"email": "v.alekseev-02011977@postgrespro.ru", "phone": "+70798293808"}
0005434264953	AB34A4	8516 879688	KSENIYA NESTEROVA	{"phone": "+70531469973"}
0005434264954	AB34A4	5847 539948	ALINA ANDREEVA	{"phone": "+70760782437"}
0005434264955	D4B126	7956 810230	INNA ZAKHAROVA	{"phone": "+70057480860"}
0005434264956	F4C880	5210 617073	ALEKSANDR DAVYDOV	{"email": "davydov.a-06071970@postgrespro.ru", "phone": "+70765126230"}
0005434264957	F4C880	5898 668271	ZHANNA SCHERBAKOVA	{"email": "zhanna_scherbakova-1960@postgrespro.ru", "phone": "+70491805761"}
0005434264958	F4C880	5596 630417	DAVID MOISEEV	{"email": "d_moiseev-011971@postgrespro.ru", "phone": "+70107937415"}
0005434264959	AC5B21	3602 061635	LYUDMILA NESTEROVA	{"email": "l_nesterova041981@postgrespro.ru", "phone": "+70470533079"}
0005434264960	1F611B	9112 404722	ALEKSEY BONDARENKO	{"phone": "+70848324698"}
0005434264961	89B2B0	1343 730233	IRINA KOMAROVA	{"phone": "+70510828362"}
0005434264962	89B2B0	7596 867998	NIKOLAY ABRAMOV	{"email": "nikolay_abramov.1976@postgrespro.ru", "phone": "+70413004619"}
0005434264963	BDB5F1	8901 885728	VARVARA BELOVA	{"phone": "+70873803566"}
0005434264964	3AA67D	0230 594985	NATALYA SAVELEVA	{"phone": "+70334720181"}
0005434264965	C14F84	1240 193085	VASILIY VASILEV	{"email": "vasilev-v031969@postgrespro.ru", "phone": "+70612936489"}
0005434264966	E4DF76	6115 892828	ELENA CHERNOVA	{"email": "chernova-elena.30111964@postgrespro.ru", "phone": "+70760598003"}
0005434264967	370ACF	7632 305323	ANVAR SERGEEV	{"email": "anvarsergeev_011963@postgrespro.ru", "phone": "+70861382305"}
0005434264968	594C63	9860 910268	VIKTOR KUDRYASHOV	{"phone": "+70098137515"}
0005434264969	5D7EC4	8049 514263	DINA NOVIKOVA	{"email": "dina_novikova1973@postgrespro.ru", "phone": "+70668381215"}
0005434264970	C64C90	1206 567282	IGOR VLASOV	{"email": "igor_vlasov_1964@postgrespro.ru", "phone": "+70651263063"}
0005434264971	C61C23	8776 418460	ALEKSANDR SOLOVEV	{"phone": "+70616101634"}
0005434264972	FAD6EE	2990 114199	EVGENIY ISAEV	{"email": "isaev-e12081984@postgrespro.ru", "phone": "+70543393399"}
0005434264973	FAD6EE	2511 725421	AMIR GAVRILOV	{"phone": "+70736620240"}
0005434264974	403632	8347 188077	ZINAIDA SMIRNOVA	{"phone": "+70335679182"}
0005434264975	0EA4E6	2887 960278	STANISLAV ANDREEV	{"email": "andreev_s-16031977@postgrespro.ru", "phone": "+70628709147"}
0005434264976	87C247	2120 511323	ARINA LOGINOVA	{"phone": "+70752874134"}
0005434264977	8D35FE	6484 401196	SERGEY TIKHONOV	{"phone": "+70553222837"}
0005434264978	C059CE	9333 879390	IRINA IVANOVA	{"phone": "+70079282242"}
0005434264979	ECE419	7087 439085	ANZHELA GORBUNOVA	{"phone": "+70227917654"}
0005434264980	76623C	4228 645397	PETR RODIONOV	{"phone": "+70996998399"}
0005434264981	75B645	6635 423925	GALINA LOGINOVA	{"email": "loginova_galina121964@postgrespro.ru", "phone": "+70070582550"}
0005434264982	CBDAD4	4423 738057	VADIM NAZAROV	{"email": "nazarovvadim_061973@postgrespro.ru", "phone": "+70032272362"}
0005434264983	CBDAD4	5021 774590	NATALYA MAKSIMOVA	{"phone": "+70118834935"}
0005434264984	FBF9CC	7654 595760	VIKTORIYA IVANOVA	{"email": "ivanova-v.041967@postgrespro.ru", "phone": "+70701198607"}
0005434264985	FBF9CC	6727 244618	GALINA PAVLOVA	{"email": "galina-pavlova_1970@postgrespro.ru", "phone": "+70172233310"}
0005434264986	B18EF0	6773 941191	ANDREY ALEKSANDROV	{"phone": "+70693409023"}
0005434264987	D564B5	1505 802863	SVETLANA BELOVA	{"phone": "+70948944563"}
0005434264988	D564B5	2111 799204	ANASTASIYA SOROKINA	{"email": "sorokinaanastasiya19071980@postgrespro.ru", "phone": "+70663197618"}
0005434264989	1869AA	6701 738117	IRINA KOZLOVA	{"email": "kozlova-i-08021969@postgrespro.ru", "phone": "+70190785703"}
0005434264990	D7EAFC	4147 529289	ALEKSANDR FEDOROV	{"email": "a-fedorov_30051975@postgrespro.ru", "phone": "+70981064719"}
0005434264991	D7EAFC	0750 776634	NINA IVANOVA	{"phone": "+70106552967"}
0005434264992	7B34E1	9211 212353	ELENA IVANOVA	{"phone": "+70542299321"}
0005434265053	4DDD52	5049 183812	IGOR SOKOLOV	{"phone": "+70217176679"}
0005434264993	7B34E1	1750 740520	TATYANA FROLOVA	{"email": "frolovat_18081979@postgrespro.ru", "phone": "+70917716994"}
0005434264994	CF01C0	9632 199083	VLADIMIR FEDOROV	{"phone": "+70918668553"}
0005434264995	F9922D	0599 033086	LYUBOV MAKAROVA	{"email": "lyubov-makarova.081979@postgrespro.ru", "phone": "+70291187375"}
0005434264996	C12C79	8485 953249	SERGEY PETROV	{"email": "s_petrov_011972@postgrespro.ru", "phone": "+70757136624"}
0005434264997	C12C79	5065 754022	SEMEN TARASOV	{"phone": "+70693533827"}
0005434264998	046B3A	1146 982602	ANDREY VASILEV	{"email": "a_vasilev-17091976@postgrespro.ru", "phone": "+70146648846"}
0005434264999	1A7320	0049 708544	ELMIRA KUZNECOVA	{"phone": "+70328492220"}
0005434265000	B5C4E8	9985 581691	VALENTINA KAZAKOVA	{"email": "valentina_kazakova-24011980@postgrespro.ru", "phone": "+70735765878"}
0005434265001	B5C4E8	3972 459648	KIRILL VLASOV	{"email": "vlasov-kirill081976@postgrespro.ru", "phone": "+70175184365"}
0005434265002	179CD9	0259 115664	ARTEM NAZAROV	{"email": "nazarovartem1974@postgrespro.ru", "phone": "+70119788168"}
0005434265003	179CD9	5437 885032	EKATERINA ERMAKOVA	{"email": "ekaterina-ermakova-061971@postgrespro.ru", "phone": "+70486774676"}
0005434265004	179CD9	3433 248976	ALEKSEY GRIGOREV	{"email": "aleksey-grigorev16101971@postgrespro.ru", "phone": "+70687524631"}
0005434265005	E98E0F	8039 771255	SERGEY POPOV	{"email": "popov.s-1971@postgrespro.ru", "phone": "+70634159963"}
0005434265006	1CA510	3590 776753	RAISA SOKOLOVA	{"email": "raisa_sokolova-17111976@postgrespro.ru", "phone": "+70438880182"}
0005434265007	ACEAE7	4636 465952	IGOR KUZMIN	{"email": "igorkuzmin_24031970@postgrespro.ru", "phone": "+70941295895"}
0005434265008	ACEAE7	6636 209012	DARYA MAKAROVA	{"email": "makarovad1963@postgrespro.ru", "phone": "+70076086307"}
0005434265009	F5CCDD	4004 167751	NINA ZHUKOVA	{"phone": "+70704190870"}
0005434265010	4EEEFA	0214 548041	MARINA CHERNOVA	{"email": "mchernova-04041971@postgrespro.ru", "phone": "+70369660391"}
0005434265011	23BF88	6184 645912	ANDREY SMIRNOV	{"phone": "+70635128606"}
0005434265013	E5D2F4	4713 042375	RAISA NESTEROVA	{"email": "r_nesterova.051980@postgrespro.ru", "phone": "+70900293068"}
0005434265014	F06039	6960 901540	VIKTOR MAKAROV	{"email": "makarov_v.09051972@postgrespro.ru", "phone": "+70233630685"}
0005434265015	A911C0	8147 453554	NIKITA SEMENOV	{"email": "nsemenov1983@postgrespro.ru", "phone": "+70746805316"}
0005434265016	A911C0	9638 682677	NATALYA SOKOLOVA	{"email": "natalya-sokolova-16121977@postgrespro.ru", "phone": "+70980017686"}
0005434265017	6570D3	0954 765554	EVDOKIYA KAZAKOVA	{"phone": "+70958083058"}
0005434265018	7D32A0	2479 976721	ZOYA GRISHINA	{"email": "z_grishina_09111974@postgrespro.ru", "phone": "+70849254884"}
0005434265019	A0205A	6938 922826	NADEZHDA MIRONOVA	{"phone": "+70747867023"}
0005434265020	C6D52E	1264 095386	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr-1968@postgrespro.ru", "phone": "+70939816106"}
0005434265021	72EE9F	6079 387359	VASILIY SOROKIN	{"phone": "+70511144459"}
0005434265022	2BBCAD	0570 507490	SERGEY IVANOV	{"phone": "+70679629396"}
0005434265023	3B9335	4996 242333	ANDREY BARANOV	{"email": "abaranov.29021976@postgrespro.ru", "phone": "+70205972570"}
0005434265024	906B18	8647 566256	OLGA ZAKHAROVA	{"phone": "+70876391367"}
0005434265025	9BD033	0654 214154	ELENA SMIRNOVA	{"email": "elenasmirnova-011955@postgrespro.ru", "phone": "+70452838973"}
0005434265026	91AA19	1544 221151	MAKSIM ILIN	{"phone": "+70384540484"}
0005434265027	1E5D59	7957 885942	VASILIY POPOV	{"email": "v-popov_1975@postgrespro.ru", "phone": "+70137077004"}
0005434265028	942CAA	1854 253709	VLADIMIR ZAKHAROV	{"phone": "+70926768628"}
0005434265029	2A1047	4709 279153	TATYANA BARANOVA	{"email": "baranovatatyana_09111968@postgrespro.ru", "phone": "+70368540492"}
0005434265030	E4320D	2847 097484	ALEKSANDR KAZAKOV	{"phone": "+70427838331"}
0005434265031	7FA4AB	8052 426451	ALEKSANDR DENISOV	{"phone": "+70571484249"}
0005434265032	311840	1151 852845	ANTON GORBUNOV	{"phone": "+70133137718"}
0005434265033	491B60	0999 608001	ALEKSEY KULIKOV	{"email": "kulikov-a.1964@postgrespro.ru", "phone": "+70321381929"}
0005434265034	491B60	8803 381167	SERGEY VOLKOV	{"email": "volkov_s.061975@postgrespro.ru", "phone": "+70096589477"}
0005434265035	BC591F	5143 629379	MARINA PETROVA	{"phone": "+70394251717"}
0005434265036	BB5432	4904 099786	VALENTINA PAVLOVA	{"phone": "+70429956686"}
0005434265037	8A5B26	0691 961851	LEONID ROMANOV	{"email": "l-romanov-031977@postgrespro.ru", "phone": "+70312859043"}
0005434265038	312F61	9080 388124	ALEKSANDR PETROV	{"email": "aleksandrpetrov.1966@postgrespro.ru", "phone": "+70215692002"}
0005434265039	14B2A8	8414 744286	SVETLANA SIDOROVA	{"phone": "+70670034271"}
0005434265040	14B2A8	5355 355768	LARISA NOVIKOVA	{"phone": "+70479534035"}
0005434265041	C04EBF	9225 741658	LYUBOV SMIRNOVA	{"phone": "+70272790238"}
0005434265042	C04EBF	8844 152236	GALINA LUKYANOVA	{"phone": "+70805823783"}
0005434265043	137C8A	1920 873173	VLADIMIR ZAKHAROV	{"phone": "+70702806483"}
0005434265044	137C8A	0775 482953	YURIY EGOROV	{"phone": "+70567593770"}
0005434265045	DC9020	2961 821408	VIKTOR VOLKOV	{"email": "v_volkov_22111970@postgrespro.ru", "phone": "+70933165607"}
0005434265046	5AD7E9	5729 163826	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey.101979@postgrespro.ru", "phone": "+70353190080"}
0005434265047	5AD7E9	7403 313653	OLGA GORBUNOVA	{"phone": "+70017960616"}
0005434265048	906D3C	9630 205991	GLEB KUZMIN	{"email": "g_kuzmin_30121972@postgrespro.ru", "phone": "+70247152621"}
0005434265049	906D3C	4075 955461	DARYA ANTONOVA	{"email": "antonova-d_06031969@postgrespro.ru", "phone": "+70653186687"}
0005434265050	906D3C	5403 071643	POLINA EGOROVA	{"phone": "+70103890683"}
0005434265051	21444B	9062 316072	FARIDA PAVLOVA	{"email": "pavlovaf-1974@postgrespro.ru", "phone": "+70877141481"}
0005434265052	169089	9973 597795	MIKHAIL KISELEV	{"email": "mikhailkiselev.111968@postgrespro.ru", "phone": "+70180336111"}
0005434265054	F056C1	3850 797576	ANATOLIY KUZNECOV	{"email": "kuznecov-a-16071966@postgrespro.ru", "phone": "+70582919859"}
0005434265055	D55296	0414 347839	ALEKSANDR ILIN	{"email": "ilin.aleksandr26101968@postgrespro.ru", "phone": "+70841712411"}
0005434265056	A12186	2750 055722	PETR CHERNOV	{"email": "p-chernov071978@postgrespro.ru", "phone": "+70985760624"}
0005434265057	A12186	5291 819741	LARISA NESTEROVA	{"email": "l-nesterova.021966@postgrespro.ru", "phone": "+70462692304"}
0005434265058	ACB820	1129 331325	ALEKSEY SCHERBAKOV	{"phone": "+70159728410"}
0005434265059	BD58CC	4713 882945	ARINA RODIONOVA	{"email": "rodionovaarina-081976@postgrespro.ru", "phone": "+70703652049"}
0005434265060	611470	6254 459180	SVETLANA POPOVA	{"email": "svetlana_popova-22101964@postgrespro.ru", "phone": "+70402991690"}
0005434265061	8F59B3	6381 574166	SERGEY GUSEV	{"phone": "+70105289880"}
0005434265062	8F59B3	1990 913581	RUSLAN SOKOLOV	{"email": "sokolov-r-31071959@postgrespro.ru", "phone": "+70584164721"}
0005434265063	7BCBB5	9670 287894	SERGEY SHEVCHENKO	{"email": "shevchenko-s_051980@postgrespro.ru", "phone": "+70017260732"}
0005434265064	7BCBB5	2314 064903	NIKITA KULIKOV	{"email": "kulikov-nikita_1983@postgrespro.ru", "phone": "+70924061406"}
0005434265065	7BCBB5	2613 173083	NADEZHDA BELOVA	{"email": "nadezhda_belova.25021973@postgrespro.ru", "phone": "+70204641219"}
0005434265066	0B5A37	8243 858571	MARIYA KAZAKOVA	{"email": "m_kazakova-1978@postgrespro.ru", "phone": "+70625117712"}
0005434265067	0B5A37	1905 192236	ANNA FROLOVA	{"email": "anna_frolova25111960@postgrespro.ru", "phone": "+70937408257"}
0005434265181	585AF7	1987 159496	MIKHAIL SOLOVEV	{"phone": "+70920391677"}
0005434265068	0B5A37	9549 364734	ANASTASIYA AKIMOVA	{"email": "anastasiyaakimova_1979@postgrespro.ru", "phone": "+70782293492"}
0005434265069	53B2DA	6065 100260	LARISA KAZAKOVA	{"email": "kazakoval_11111969@postgrespro.ru", "phone": "+70184228295"}
0005434265070	204F55	2860 364153	TATYANA MASLOVA	{"phone": "+70407429951"}
0005434265071	642E59	8391 710155	MIKHAIL NIKITIN	{"phone": "+70299062542"}
0005434265072	642E59	8705 719628	GALINA MOISEEVA	{"phone": "+70876133680"}
0005434265073	3E7185	8057 097673	MARIYA MAKSIMOVA	{"email": "maksimova.mariya-14021983@postgrespro.ru", "phone": "+70988650038"}
0005434265074	DC315E	6655 300133	TAMARA SAVELEVA	{"phone": "+70105464463"}
0005434265075	31E269	9283 326126	VLADIMIR PETROV	{"phone": "+70072641145"}
0005434265076	98E909	0614 284154	VLADISLAV ANTONOV	{"phone": "+70447061009"}
0005434265077	98E909	5918 734309	PRASKOVYA ORLOVA	{"email": "orlova_p_1974@postgrespro.ru", "phone": "+70567018767"}
0005434265078	7F4340	1380 656594	IVAN IVANOV	{"email": "ivanovi_24061973@postgrespro.ru", "phone": "+70241302932"}
0005434265079	5F1E38	3188 955996	MARIYA ALEKSEEVA	{"phone": "+70361641794"}
0005434265080	5F1E38	2085 943195	ALESYA KOZLOVA	{"phone": "+70989473953"}
0005434265081	B29562	8185 452704	ALEKSANDR KUZNECOV	{"phone": "+70567747350"}
0005434265082	B29562	8451 030670	SAVELIY PETROV	{"phone": "+70133351345"}
0005434265083	2FC807	4186 429110	TATYANA OSIPOVA	{"email": "tatyana_osipova09121977@postgrespro.ru", "phone": "+70229384526"}
0005434265084	2FC807	9983 789676	SVETLANA OSIPOVA	{"email": "s-osipova-02031977@postgrespro.ru", "phone": "+70821061805"}
0005434265085	B08154	7687 079727	ELENA FOMINA	{"phone": "+70192930557"}
0005434265086	091939	6379 851552	ANTONINA POPOVA	{"email": "popova.antonina091971@postgrespro.ru", "phone": "+70376766491"}
0005434265087	7BA9F1	7330 236471	ZULFIYA MAKSIMOVA	{"email": "zmaksimova-041962@postgrespro.ru", "phone": "+70462296766"}
0005434265088	3A9FE0	0723 455459	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev20091972@postgrespro.ru", "phone": "+70166652595"}
0005434265089	3A9FE0	3129 566225	TATYANA FADEEVA	{"phone": "+70834605981"}
0005434265090	061E9B	5647 131868	TATYANA LAZAREVA	{"phone": "+70462575221"}
0005434265091	712AE7	4201 231734	SERGEY NIKOLAEV	{"phone": "+70376692199"}
0005434265092	712AE7	0192 241682	LYUDMILA KULIKOVA	{"phone": "+70042472459"}
0005434265093	7E47D8	2736 646897	LIDIYA KRASNOVA	{"phone": "+70786114203"}
0005434265094	7E47D8	2656 675181	SERGEY ABRAMOV	{"phone": "+70039777847"}
0005434265095	7AA89E	4316 582277	VLADIMIR FOMIN	{"email": "fomin.v-1974@postgrespro.ru", "phone": "+70867657032"}
0005434265096	722AC7	6177 838535	ALEKSEY MAKSIMOV	{"email": "aleksey_maksimov-1969@postgrespro.ru", "phone": "+70053634089"}
0005434265097	722AC7	0102 318869	ALEKSANDR VOROBEV	{"phone": "+70887720088"}
0005434265098	722AC7	7081 877400	NATALYA RYABOVA	{"email": "ryabova_n_11071974@postgrespro.ru", "phone": "+70192205249"}
0005434265099	E11AFE	9617 401468	ROMAN SCHERBAKOV	{"email": "roman.scherbakov-1977@postgrespro.ru", "phone": "+70158859416"}
0005434265100	B9CD6D	2735 116585	OLEG DMITRIEV	{"email": "dmitriev_oleg_06031966@postgrespro.ru", "phone": "+70180395251"}
0005434265101	B9CD6D	4043 459952	VLADIMIR KUDRYASHOV	{"email": "kudryashovv121970@postgrespro.ru", "phone": "+70687380286"}
0005434265102	255987	2575 250274	NATALIYA LUKYANOVA	{"email": "n.lukyanova.041979@postgrespro.ru", "phone": "+70204343164"}
0005434265103	E64B56	8652 367403	SVYATOSLAV ZHURAVLEV	{"phone": "+70967086667"}
0005434265104	E64B56	1398 712141	ALEKSANDR MATVEEV	{"email": "a.matveev1977@postgrespro.ru", "phone": "+70556613582"}
0005434265105	E64B56	1905 164859	EKATERINA ZAKHAROVA	{"phone": "+70207238795"}
0005434265106	C8F958	6787 343679	KSENIYA ANTONOVA	{"email": "kseniyaantonova_021970@postgrespro.ru", "phone": "+70625201760"}
0005434265107	0A662A	2774 059361	NATALYA SIDOROVA	{"phone": "+70869782110"}
0005434265108	0A662A	4444 497475	VLADIMIR RODIONOV	{"email": "v-rodionov_1963@postgrespro.ru", "phone": "+70084450946"}
0005434265109	59CE05	9214 237451	ANATOLIY MEDVEDEV	{"email": "anatoliy_medvedev_101969@postgrespro.ru", "phone": "+70684325531"}
0005434265110	59CE05	5251 561009	VERA EFIMOVA	{"phone": "+70113787220"}
0005434265111	59CE05	1222 457889	ALEKSANDR VOLKOV	{"phone": "+70305613498"}
0005434265112	5DF7F6	3217 535744	OLGA MEDVEDEVA	{"email": "o_medvedeva_1974@postgrespro.ru", "phone": "+70992168379"}
0005434265113	D85C53	2047 974024	EKATERINA MALYSHEVA	{"phone": "+70129599056"}
0005434265114	4127A6	4567 400233	ALEKSEY NIKITIN	{"email": "nikitin-a-15041965@postgrespro.ru", "phone": "+70121773911"}
0005434265115	0CE296	0208 384156	ELENA YAKOVLEVA	{"email": "e-yakovleva_081975@postgrespro.ru", "phone": "+70311596733"}
0005434265116	2AFDF0	8099 365525	NATALIYA TIKHONOVA	{"phone": "+70196156034"}
0005434265117	043115	2690 311638	ALEKSANDR FILIPPOV	{"phone": "+70799624240"}
0005434265118	043115	1821 761613	ALEKSEY KULIKOV	{"email": "kulikov-a.03081994@postgrespro.ru", "phone": "+70249800265"}
0005434265119	2F2589	1460 301010	FAINA MALYSHEVA	{"phone": "+70385668180"}
0005434265120	2F2589	7438 354923	VALENTINA TIKHONOVA	{"phone": "+70691823703"}
0005434265121	1EA05C	2535 164413	ANASTASIYA MOROZOVA	{"phone": "+70682216086"}
0005434265122	1EA05C	9434 504450	EVA MIKHAYLOVA	{"email": "eva_mikhaylova_071972@postgrespro.ru", "phone": "+70041737164"}
0005434265123	ED7D32	4945 942443	VIKTOR KONOVALOV	{"email": "viktorkonovalov-1976@postgrespro.ru", "phone": "+70573738456"}
0005434265124	ED7D32	6470 637169	ELENA OSIPOVA	{"email": "e.osipova.081970@postgrespro.ru", "phone": "+70699779771"}
0005434265125	2852E6	1796 082987	TATYANA SEMENOVA	{"phone": "+70585729684"}
0005434265126	3CC49B	2508 987154	TATYANA SEMENOVA	{"email": "semenova-tatyana1965@postgrespro.ru", "phone": "+70934102444"}
0005434265127	3CC49B	7058 466233	NIKITA DMITRIEV	{"phone": "+70132293786"}
0005434265128	5212E9	4549 457359	ALEKSEY VLASOV	{"phone": "+70316513773"}
0005434265129	5ADA25	0612 681491	ANNA KONOVALOVA	{"email": "konovalova_anna_1981@postgrespro.ru", "phone": "+70362353199"}
0005434265130	D770A7	0317 941339	VALERIY IVANOV	{"phone": "+70148950201"}
0005434265131	8FEF71	1058 874502	GALINA KUZMINA	{"phone": "+70858845326"}
0005434265132	2186FC	4014 520896	EVGENIY POPOV	{"phone": "+70239267995"}
0005434265133	1C8A03	4766 824035	RUDOLF ROMANOV	{"phone": "+70791494036"}
0005434265134	183375	6507 264433	EKATERINA KOLESNIKOVA	{"phone": "+70028978993"}
0005434265135	86C6D1	6746 485621	VADIM MIKHAYLOV	{"phone": "+70284294843"}
0005434265136	86C6D1	6070 854520	OLGA DENISOVA	{"phone": "+70869213541"}
0005434265137	35E298	8724 141221	ELVIRA IVANOVA	{"phone": "+70490863113"}
0005434265138	2A0878	8939 794617	ANTON MELNIKOV	{"phone": "+70114549635"}
0005434265139	26CC8B	8914 495153	LYUDMILA NIKIFOROVA	{"email": "lyudmila-nikiforova.1967@postgrespro.ru", "phone": "+70221588213"}
0005434265140	4C1BC7	7797 256780	LYUDMILA ALEKSEEVA	{"phone": "+70790983510"}
0005434265141	8C0F12	4652 795216	ELIZAVETA VLASOVA	{"phone": "+70481831216"}
0005434265142	8C0F12	3393 087119	ANATOLIY SIDOROV	{"phone": "+70967572519"}
0005434265143	8CA4A1	9620 698019	ZOYA PAVLOVA	{"email": "pavlova.zoya_1969@postgrespro.ru", "phone": "+70918961555"}
0005434265144	B158AE	5004 919734	VARVARA OSIPOVA	{"phone": "+70025604517"}
0005434265145	9FAD76	1126 131149	SERGEY NAUMOV	{"phone": "+70261130410"}
0005434265146	EDABB5	0585 149256	IRINA DMITRIEVA	{"email": "dmitrieva_irina.1973@postgrespro.ru", "phone": "+70467700336"}
0005434265147	944ED5	1218 262389	EKATERINA PAVLOVA	{"phone": "+70145123310"}
0005434265148	4D14D1	6851 261066	OLEG FEDOTOV	{"phone": "+70796199128"}
0005434265149	E19BA5	1137 989951	ANNA KRASNOVA	{"phone": "+70866034432"}
0005434265150	E19BA5	1513 473655	TAISIYA FEDOROVA	{"email": "taisiya.fedorova05101971@postgrespro.ru", "phone": "+70352370218"}
0005434265151	D401B9	7865 016020	VIKTOR MELNIKOV	{"email": "viktormelnikov_1970@postgrespro.ru", "phone": "+70779565834"}
0005434265152	BC585F	4066 794866	EVGENIYA BOGDANOVA	{"email": "bogdanova_e.07011975@postgrespro.ru", "phone": "+70645358618"}
0005434265153	84025C	2975 446265	IRINA MEDVEDEVA	{"email": "irina.medvedeva.1975@postgrespro.ru", "phone": "+70974408791"}
0005434265154	58A4D2	4881 938674	DARYA ROMANOVA	{"email": "darya-romanova1972@postgrespro.ru", "phone": "+70926587843"}
0005434265155	58A4D2	3235 564819	VLADIMIR PETROV	{"email": "v.petrov08091977@postgrespro.ru", "phone": "+70267694907"}
0005434265156	58A4D2	2087 546511	ANNA ZHUKOVA	{"phone": "+70980180269"}
0005434265157	DF5295	6203 155418	MAKSIM KAZAKOV	{"phone": "+70382294138"}
0005434265158	A35ADA	0571 599291	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov-111978@postgrespro.ru", "phone": "+70527131870"}
0005434265159	CE55A0	8696 101304	OLGA MIKHAYLOVA	{"phone": "+70482366427"}
0005434265160	2F4E94	9260 929935	ALEKSANDR KISELEV	{"phone": "+70874915538"}
0005434265161	5797C8	8730 367455	LYUDMILA IVANOVA	{"email": "l-ivanova1979@postgrespro.ru", "phone": "+70916530138"}
0005434265162	807954	6301 871021	DMITRIY TIKHONOV	{"email": "tikhonov.d.23011983@postgrespro.ru", "phone": "+70100540645"}
0005434265163	79BC40	8970 281496	ALEKSANDR ZAYCEV	{"phone": "+70458709706"}
0005434265164	83FD6C	7963 852173	MARTA KOLESNIKOVA	{"email": "m-kolesnikova-16081973@postgrespro.ru", "phone": "+70507201771"}
0005434265165	83FD6C	5881 140009	VALERIYA IVANOVA	{"phone": "+70331182584"}
0005434265166	C76132	5444 442868	YURIY ALEKSEEV	{"phone": "+70277576197"}
0005434265167	8FFFB6	9570 926023	ALLA BELYAEVA	{"phone": "+70607916178"}
0005434265168	8FFFB6	5002 585338	LIDIYA KOROLEVA	{"email": "lidiya-koroleva24031972@postgrespro.ru", "phone": "+70468968930"}
0005434265169	8FFFB6	7325 497083	ELLA SEMENOVA	{"email": "semenova-ella_051966@postgrespro.ru", "phone": "+70269753634"}
0005434265170	A46F68	6760 539108	EVGENIY MOROZOV	{"email": "e_morozov_031967@postgrespro.ru", "phone": "+70475580149"}
0005434265171	76F4BD	8503 842963	MIKHAIL KAZAKOV	{"email": "kazakovmikhail_1973@postgrespro.ru", "phone": "+70531937939"}
0005434265172	2A87B8	9320 188602	VALERIY DMITRIEV	{"email": "dmitriev-valeriy.1962@postgrespro.ru", "phone": "+70060578230"}
0005434265173	2A87B8	0697 998232	VIKTOR GRIGOREV	{"phone": "+70053432196"}
0005434265174	866F0C	1148 367972	EKATERINA MOROZOVA	{"phone": "+70970078663"}
0005434265175	866F0C	8790 730766	ALEKSEY NIKOLAEV	{"email": "nikolaev_a_071978@postgrespro.ru", "phone": "+70337365693"}
0005434265176	CC6492	9025 429441	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev18101972@postgrespro.ru", "phone": "+70698109142"}
0005434265177	9B3928	1122 537673	DMITRIY TARASOV	{"email": "tarasov_dmitriy_16031969@postgrespro.ru", "phone": "+70664948067"}
0005434265178	9B3928	1032 969935	KLAVDIYA NIKITINA	{"phone": "+70180330298"}
0005434265179	D24BFF	6246 085387	MAKSIM ROMANOV	{"phone": "+70162344858"}
0005434265180	D24BFF	1586 810517	ANASTASIYA NIKOLAEVA	{"email": "anastasiyanikolaeva-011970@postgrespro.ru", "phone": "+70192757456"}
0005434265182	95ACF5	7660 607373	RAFAEL KAZAKOV	{"email": "rafaelkazakov_1971@postgrespro.ru", "phone": "+70783154591"}
0005434265183	95ACF5	4754 185688	SERGEY KAZAKOV	{"phone": "+70622061455"}
0005434265184	5DAE5B	2799 040628	ALEKSEY ABRAMOV	{"email": "aleksey-abramov011970@postgrespro.ru", "phone": "+70379965804"}
0005434265185	5DAE5B	6812 816712	ZINAIDA MIRONOVA	{"phone": "+70106679930"}
0005434265186	EF008D	7382 116969	VIKTOR FROLOV	{"phone": "+70410306287"}
0005434265187	815B95	3239 793799	VLADIMIR KUZNECOV	{"email": "v-kuznecov15121969@postgrespro.ru", "phone": "+70351101954"}
0005434265188	DDF8AE	7252 601530	EKATERINA IVANOVA	{"phone": "+70485297315"}
0005434265189	C5FA96	9745 889787	ZLATA ALEKSEEVA	{"email": "alekseevaz-1966@postgrespro.ru", "phone": "+70779451112"}
0005434265190	992AE6	1431 177797	VITALIY KOZLOV	{"email": "kozlov-v_1974@postgrespro.ru", "phone": "+70102175064"}
0005434265191	D56923	5563 944787	ANNA ALEKSEEVA	{"email": "a-alekseeva.1968@postgrespro.ru", "phone": "+70973111228"}
0005434265192	9D9FD7	6086 270259	NATALYA GUSEVA	{"phone": "+70129028751"}
0005434265193	9D9FD7	8451 359889	ANDREY KONOVALOV	{"email": "konovalov-andrey.09051986@postgrespro.ru", "phone": "+70000907326"}
0005434265194	6B3059	8546 809536	ROMAN MOROZOV	{"email": "morozov_r1974@postgrespro.ru", "phone": "+70462124843"}
0005434265195	DF6D5D	1647 435376	SERGEY MOROZOV	{"email": "morozov_sergey_041969@postgrespro.ru", "phone": "+70104643490"}
0005434265196	4B9FFA	8146 910470	ELENA CHERNOVA	{"phone": "+70979413647"}
0005434265197	192A43	5881 335351	SERGEY VOLKOV	{"phone": "+70586002426"}
0005434265198	8099D4	5862 836444	MIKHAIL PETROV	{"email": "mikhail-petrov121977@postgrespro.ru", "phone": "+70306387168"}
0005434265199	75F4F2	4505 131953	VALENTINA ABRAMOVA	{"email": "v.abramova-07021968@postgrespro.ru", "phone": "+70284209502"}
0005434265200	581992	1601 960150	ANTONINA YAKOVLEVA	{"phone": "+70375235009"}
0005434265201	581992	1162 820653	ROMAN KUZMIN	{"phone": "+70391195742"}
0005434265202	3D7B0F	9549 432249	ELENA ZHURAVLEVA	{"email": "zhuravlevaelena-31071973@postgrespro.ru", "phone": "+70560751789"}
0005434265203	86D028	5769 782531	SERGEY DMITRIEV	{"email": "dmitriev-s.07031966@postgrespro.ru", "phone": "+70087605927"}
0005434265204	042B6F	8546 161773	LIDIYA GORBUNOVA	{"phone": "+70322666607"}
0005434265205	042B6F	0610 517273	ANDREY CHERNOV	{"email": "chernov-andrey011978@postgrespro.ru", "phone": "+70670503212"}
0005434265206	D7C41B	1572 883504	NATALYA ORLOVA	{"phone": "+70638713016"}
0005434265207	A584D6	4289 517629	NADEZHDA KISELEVA	{"phone": "+70720336510"}
0005434265208	E93B1F	3142 202668	ALEKSANDR MOROZOV	{"phone": "+70544262216"}
0005434265209	E93B1F	6816 642082	TATYANA NIKOLAEVA	{"phone": "+70486260126"}
0005434265210	5F8056	6897 513416	IGOR BORISOV	{"phone": "+70080428768"}
0005434265211	BB2EF9	8199 773423	ALEKSANDR DMITRIEV	{"email": "dmitriev-aleksandr_01021978@postgrespro.ru", "phone": "+70454780513"}
0005434265212	DFD9B9	8151 318451	EVGENIYA SOROKINA	{"phone": "+70600550819"}
0005434265213	B5A5B8	3394 724000	NATALIYA POPOVA	{"phone": "+70974474095"}
0005434265214	BABE95	4330 238106	EVGENIY KUZNECOV	{"email": "kuznecove1969@postgrespro.ru", "phone": "+70538316943"}
0005434265215	BABE95	3163 774058	NIKOLAY POPOV	{"email": "n-popov.02091966@postgrespro.ru", "phone": "+70361293638"}
0005434265216	BABE95	6899 043705	ALEKSANDR MAKAROV	{"phone": "+70615172612"}
0005434265217	7D6C41	7387 444452	MIKHAIL ALEKSANDROV	{"email": "aleksandrovmikhail-101973@postgrespro.ru", "phone": "+70534319836"}
0005434265218	DBB06A	9924 729176	VLADIMIR MARTYNOV	{"phone": "+70874395516"}
0005434265219	592762	6449 973588	ALEKSANDRA TIKHONOVA	{"phone": "+70037673190"}
0005434265220	E964A0	7099 000494	YURIY KUZNECOV	{"phone": "+70433325792"}
0005434265221	16C29E	5402 394538	ALEKSANDRA ANISIMOVA	{"email": "anisimova.a_1978@postgrespro.ru", "phone": "+70401400123"}
0005434265222	16C29E	2001 782395	OLEG KUZMIN	{"phone": "+70140662722"}
0005434265223	16C29E	5307 741595	SERGEY KISELEV	{"phone": "+70355625703"}
0005434265224	FC2565	4424 129200	VLADISLAV ALEKSEEV	{"email": "alekseev.v1964@postgrespro.ru", "phone": "+70847620436"}
0005434265225	A2B42C	6893 625708	RIMMA OSIPOVA	{"phone": "+70762131682"}
0005434265226	A2B42C	2385 403579	YURIY KARPOV	{"email": "yuriy_karpov.031979@postgrespro.ru", "phone": "+70864382305"}
0005434265227	FC39BF	3927 756334	SVETLANA FEDOROVA	{"email": "svetlana_fedorova011976@postgrespro.ru", "phone": "+70541723955"}
0005434265228	04577A	5083 835080	VALERIY SOROKIN	{"email": "v.sorokin1965@postgrespro.ru", "phone": "+70986473908"}
0005434265229	04577A	7288 178217	VLADISLAV MOROZOV	{"email": "vladislav_morozov-1977@postgrespro.ru", "phone": "+70340313474"}
0005434265230	FFE152	8569 643156	VLADIMIR FEDOTOV	{"email": "vladimir_fedotov02111968@postgrespro.ru", "phone": "+70582856139"}
0005434265231	FFE152	6471 376301	MIKHAIL FEDOROV	{"phone": "+70648048180"}
0005434265232	E759D1	5838 136616	MIKHAIL NOVIKOV	{"email": "novikov-mikhail.15071970@postgrespro.ru", "phone": "+70197147979"}
0005434265233	B2F4C0	5076 855669	OLGA ARKHIPOVA	{"email": "arkhipova.o24101971@postgrespro.ru", "phone": "+70916926089"}
0005434265355	D70679	4331 389310	LYUDMILA ZHURAVLEVA	{"phone": "+70543479232"}
0005434265234	B2F4C0	8936 867884	EVGENIY SEMENOV	{"email": "e_semenov1981@postgrespro.ru", "phone": "+70371178766"}
0005434265235	82C43C	0584 335304	OLGA BARANOVA	{"phone": "+70183680111"}
0005434265236	A99219	7841 138841	NADEZHDA KARPOVA	{"email": "nadezhda-karpova1975@postgrespro.ru", "phone": "+70474240530"}
0005434265237	A99219	3215 187189	TATYANA NIKIFOROVA	{"email": "t_nikiforova_1986@postgrespro.ru", "phone": "+70697846564"}
0005434265238	8E6FA2	0093 005723	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir-28021971@postgrespro.ru", "phone": "+70222443299"}
0005434265239	36B286	6134 393094	LIDIYA EGOROVA	{"email": "egorova_lidiya-081966@postgrespro.ru", "phone": "+70070008992"}
0005434265240	36B286	7868 239187	VASILIY ALEKSEEV	{"phone": "+70224921995"}
0005434265241	D5B9B4	0930 060537	ALEVTINA RODIONOVA	{"phone": "+70023482970"}
0005434265242	AE940C	4425 408579	EVGENIY ZAYCEV	{"email": "evgeniyzaycev-15121974@postgrespro.ru", "phone": "+70847938604"}
0005434265243	A74AD9	4083 512953	TATYANA FOMINA	{"phone": "+70269867892"}
0005434265244	A74AD9	9171 857187	NIKITA KARPOV	{"email": "karpovnikita_1965@postgrespro.ru", "phone": "+70067309736"}
0005434265245	829D2D	3449 658579	ANNA KULIKOVA	{"phone": "+70315767461"}
0005434265246	829D2D	2371 486532	LYUBOV EGOROVA	{"email": "egorova-lyubov_031978@postgrespro.ru", "phone": "+70954186840"}
0005434265247	829D2D	5170 240832	IRINA MELNIKOVA	{"phone": "+70093488195"}
0005434265248	8D04A0	9415 108048	TAMARA SOROKINA	{"phone": "+70286382801"}
0005434265249	A61108	8792 040317	TATYANA SERGEEVA	{"phone": "+70633402488"}
0005434265250	A61108	7040 732755	ALEKSANDR BELOV	{"phone": "+70865058205"}
0005434265251	4A1FF5	1028 229037	YURIY MELNIKOV	{"email": "y-melnikov02081976@postgrespro.ru", "phone": "+70287648035"}
0005434265252	4A1FF5	6759 993838	VYACHESLAV ISAEV	{"email": "isaev.v_27111970@postgrespro.ru", "phone": "+70281615941"}
0005434265253	9C140E	1234 472454	YULIYA FOMINA	{"phone": "+70895928567"}
0005434265254	9C140E	4685 566997	TATYANA BOGDANOVA	{"phone": "+70398232047"}
0005434265255	4A8C96	1372 100747	ANNA SAVELEVA	{"email": "asaveleva.16101968@postgrespro.ru", "phone": "+70365977371"}
0005434265256	201F24	2839 250386	ARTEM POPOV	{"email": "popov.a_101981@postgrespro.ru", "phone": "+70037798356"}
0005434265257	201F24	6754 939227	OLGA EFIMOVA	{"phone": "+70801831046"}
0005434265258	90450C	1076 434389	ANDREY KUZMIN	{"phone": "+70867035328"}
0005434265259	FA616F	6661 581203	VIKTOR NIKOLAEV	{"phone": "+70360994082"}
0005434265260	FA616F	7795 098518	VYACHESLAV VASILEV	{"phone": "+70819724422"}
0005434265261	534764	7407 020360	PAVEL MARTYNOV	{"email": "pavel-martynov-25081970@postgrespro.ru", "phone": "+70737527948"}
0005434265262	96A1E6	5982 918556	MIKHAIL KOZLOV	{"email": "kozlov.m_1968@postgrespro.ru", "phone": "+70942993678"}
0005434265263	96A1E6	5672 904550	LYUBOV NIKOLAEVA	{"phone": "+70160922587"}
0005434265264	DEA25A	9011 058154	GALINA KUZNECOVA	{"email": "kuznecova_galina1967@postgrespro.ru", "phone": "+70754205940"}
0005434265265	EA751E	3099 808665	KONSTANTIN NIKOLAEV	{"email": "nikolaev-konstantin_1963@postgrespro.ru", "phone": "+70902391568"}
0005434265266	8D67F5	3454 515223	EKATERINA VLASOVA	{"phone": "+70493901279"}
0005434265267	3DEF61	5564 065830	DMITRIY FROLOV	{"email": "frolovd.23091975@postgrespro.ru", "phone": "+70324208008"}
0005434265268	7EF7ED	7160 246938	ANATOLIY FOMIN	{"phone": "+70179205256"}
0005434265269	1B5B22	4659 117546	LADA EGOROVA	{"email": "egorova-lada_16051974@postgrespro.ru", "phone": "+70487409535"}
0005434265270	E558C8	7843 727029	LYUDMILA ALEKSEEVA	{"phone": "+70807287632"}
0005434265271	C2D5CD	9456 628157	NATALYA KUZNECOVA	{"phone": "+70790331665"}
0005434265272	90E7CF	4351 287388	VLADIMIR IVANOV	{"phone": "+70318852931"}
0005434265273	F30BA6	2971 786423	KONSTANTIN ABRAMOV	{"phone": "+70645846110"}
0005434265274	F30BA6	2675 107757	MIKHAIL FROLOV	{"email": "frolovm_20041978@postgrespro.ru", "phone": "+70355518374"}
0005434265275	774D7F	2897 596359	VLADIMIR MEDVEDEV	{"email": "medvedev.v_1969@postgrespro.ru", "phone": "+70337035208"}
0005434265276	774D7F	9861 246707	ALEKSANDR IVANOV	{"email": "ivanov-a_031971@postgrespro.ru", "phone": "+70275468145"}
0005434265277	7756DF	1667 053045	IRINA MEDVEDEVA	{"phone": "+70303691120"}
0005434265278	F628D5	4896 451639	KONSTANTIN ROMANOV	{"email": "k-romanov051972@postgrespro.ru", "phone": "+70291127206"}
0005434265279	F628D5	7256 245726	RAISA RYABOVA	{"phone": "+70963072027"}
0005434265280	F628D5	7183 577602	IVAN ROMANOV	{"phone": "+70993101504"}
0005434265281	350F56	8249 165510	VALENTINA RODIONOVA	{"email": "valentina.rodionova.1974@postgrespro.ru", "phone": "+70818339175"}
0005434265282	34B786	9859 767746	ELENA CHERNOVA	{"email": "elena-chernova-19111957@postgrespro.ru", "phone": "+70109783956"}
0005434265283	34B786	7011 485018	YULIYA VASILEVA	{"email": "vasilevayuliya_031963@postgrespro.ru", "phone": "+70661983935"}
0005434265284	7A08E5	4757 885567	MADINA ANTONOVA	{"email": "mantonova20101966@postgrespro.ru", "phone": "+70891155879"}
0005434265285	7A08E5	5509 871248	SVETLANA ARKHIPOVA	{"phone": "+70503966610"}
0005434265286	7DA321	7628 315603	EVGENIYA SMIRNOVA	{"email": "e_smirnova_1970@postgrespro.ru", "phone": "+70815105745"}
0005434265287	7DA321	8120 509954	NINA TIKHONOVA	{"phone": "+70202885157"}
0005434265288	5476BF	7993 856344	VADIM FEDOROV	{"email": "v-fedorov-021966@postgrespro.ru", "phone": "+70103337971"}
0005434265289	5476BF	2157 077276	ELENA SMIRNOVA	{"email": "smirnovaelena09051954@postgrespro.ru", "phone": "+70672091227"}
0005434265290	CB8C72	3321 610644	OLGA IVANOVA	{"email": "o_ivanova071981@postgrespro.ru", "phone": "+70819343086"}
0005434265291	3D1F83	3535 627906	ANTON SHEVCHENKO	{"phone": "+70418378876"}
0005434265292	DCA4BF	4894 768111	NIKOLAY FEDOROV	{"phone": "+70576211258"}
0005434265293	E2F3C2	1106 581839	OLGA MARTYNOVA	{"phone": "+70173041508"}
0005434265294	661A97	4938 964650	ANASTASIYA SERGEEVA	{"email": "sergeeva-anastasiya.071963@postgrespro.ru", "phone": "+70618201631"}
0005434265295	661A97	1328 861602	SVETLANA SIDOROVA	{"email": "sidorova.svetlana_1964@postgrespro.ru", "phone": "+70481779525"}
0005434265296	403321	6636 328779	IVAN KONOVALOV	{"email": "ikonovalov-091970@postgrespro.ru", "phone": "+70608610604"}
0005434265297	994DCC	6717 149496	ANNA SAVELEVA	{"phone": "+70115079790"}
0005434265298	D24AF3	2958 885000	ANATOLIY PETROV	{"email": "a-petrov_25051974@postgrespro.ru", "phone": "+70630285906"}
0005434265299	D24AF3	0823 653385	NINA CHERNOVA	{"phone": "+70307269913"}
0005434265300	D24AF3	7204 626982	ANATOLIY YAKOVLEV	{"phone": "+70757684396"}
0005434265301	77AD0E	6910 776694	ELENA LUKYANOVA	{"email": "lukyanovaelena-17121973@postgrespro.ru", "phone": "+70810561398"}
0005434265302	77AD0E	4884 510317	EVGENIY KOROLEV	{"phone": "+70511394324"}
0005434265303	8122BE	1519 659262	GALINA MAKAROVA	{"phone": "+70462425306"}
0005434265304	96EAFA	7301 746787	TATYANA SCHERBAKOVA	{"phone": "+70851023411"}
0005434265305	47CEBD	9021 469462	MAKSIM SEMENOV	{"phone": "+70988713022"}
0005434265306	47CEBD	2700 695861	VLADIMIR FEDOTOV	{"email": "vfedotov_041978@postgrespro.ru", "phone": "+70542196672"}
0005434265307	E39D9D	4222 203408	MARINA MOISEEVA	{"phone": "+70380203425"}
0005434265308	0AB4D0	0421 275874	TAISIYA SERGEEVA	{"email": "sergeeva_taisiya-091970@postgrespro.ru", "phone": "+70625291662"}
0005434265309	9334AC	8228 559377	ALEKSEY MIRONOV	{"email": "aleksey_mironov-1973@postgrespro.ru", "phone": "+70483469062"}
0005434265310	272809	2305 534430	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.071968@postgrespro.ru", "phone": "+70250289613"}
0005434265311	272809	4049 057589	VIKTOR DAVYDOV	{"phone": "+70111823672"}
0005434265312	EF6522	4878 012676	ANNA ALEKSANDROVA	{"phone": "+70475547812"}
0005434265313	32570C	6041 831868	ZOYA FILIPPOVA	{"phone": "+70281756410"}
0005434265314	3B001F	4688 104942	PAVEL NIKITIN	{"phone": "+70891715454"}
0005434265315	469635	6802 377929	SVETLANA STEPANOVA	{"email": "stepanovasvetlana.22011978@postgrespro.ru", "phone": "+70721940951"}
0005434265316	469635	1655 398220	VLADIMIR PETROV	{"email": "petrovvladimir.021970@postgrespro.ru", "phone": "+70785817964"}
0005434265317	4511D3	8325 370455	ANASTASIYA FEDOROVA	{"phone": "+70691238718"}
0005434265318	4511D3	0690 304812	ANATOLIY GUSEV	{"phone": "+70724126586"}
0005434265319	AAEA85	9405 191313	ANTONINA FILIPPOVA	{"phone": "+70358012318"}
0005434265320	AEE3A9	9086 371417	EVGENIY TIKHONOV	{"email": "evgeniytikhonov_16111976@postgrespro.ru", "phone": "+70270557701"}
0005434265321	97EABB	9959 627227	VLADIMIR FROLOV	{"email": "vladimir.frolov_1968@postgrespro.ru", "phone": "+70822536316"}
0005434265322	C415AB	9512 724961	ALEKSANDR ROMANOV	{"phone": "+70698307550"}
0005434265323	B66806	6751 348189	IGOR ZAYCEV	{"phone": "+70730011261"}
0005434265324	AAA54C	4594 312286	LIDIYA SEMENOVA	{"email": "semenovalidiya1978@postgrespro.ru", "phone": "+70244963756"}
0005434265325	AAA54C	0866 646160	ALEKSEY FEDOROV	{"email": "fedorov_aleksey-031982@postgrespro.ru", "phone": "+70783374239"}
0005434265326	175206	4086 167199	VIKTOR POPOV	{"email": "vpopov10111968@postgrespro.ru", "phone": "+70707574505"}
0005434265327	A85BF8	3629 490767	IVAN FEDOTOV	{"email": "fedotov.i061969@postgrespro.ru", "phone": "+70402000703"}
0005434265328	A85BF8	7437 489296	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov-1986@postgrespro.ru", "phone": "+70413199671"}
0005434265329	318D08	0494 685196	MIKHAIL NOVIKOV	{"email": "novikovm_061973@postgrespro.ru", "phone": "+70838155404"}
0005434265330	5D7499	7812 066891	OLEG BELOV	{"phone": "+70327615232"}
0005434265331	6990C8	0426 561817	EVGENIY PETROV	{"phone": "+70929697094"}
0005434265332	7A4357	0013 608631	IRINA FADEEVA	{"phone": "+70078059520"}
0005434265333	7A4357	3919 149489	DMITRIY FROLOV	{"email": "dmitriy-frolov.1986@postgrespro.ru", "phone": "+70369489525"}
0005434265334	4B98CB	7242 314694	YURIY KARPOV	{"phone": "+70227294511"}
0005434265335	160065	8211 335763	ELENA LAZAREVA	{"email": "e-lazareva1967@postgrespro.ru", "phone": "+70707939919"}
0005434265336	160065	2285 807769	ALEKSANDR NIKOLAEV	{"phone": "+70970377432"}
0005434265337	83F09A	6672 483867	SNEZHANA KOROLEVA	{"phone": "+70065562961"}
0005434265338	83F09A	2526 711274	SVETLANA NAZAROVA	{"email": "svetlana_nazarova-111962@postgrespro.ru", "phone": "+70394537813"}
0005434265339	83F09A	1610 374264	EVGENIY ZHURAVLEV	{"email": "evgeniyzhuravlev101978@postgrespro.ru", "phone": "+70118537656"}
0005434265340	930C85	1795 891979	VALERIYA FROLOVA	{"phone": "+70635165156"}
0005434265341	69CB38	1689 942012	ALEKSANDR VASILEV	{"phone": "+70353093975"}
0005434265342	8CC49D	8730 031100	MIKHAIL YAKOVLEV	{"email": "yakovlev.m1968@postgrespro.ru", "phone": "+70599667049"}
0005434265343	9D0F53	9589 579639	STANISLAV NAZAROV	{"email": "snazarov_02101971@postgrespro.ru", "phone": "+70775128451"}
0005434265344	9D0F53	6947 239768	ANATOLIY ANDREEV	{"phone": "+70369794677"}
0005434265345	FB6E44	0485 716233	VASILIY NOVIKOV	{"email": "novikovv_051974@postgrespro.ru", "phone": "+70908445387"}
0005434265346	B6BE78	9010 233374	ALEKSANDR PETROV	{"phone": "+70391994323"}
0005434265347	CE3194	2424 636246	NATALYA MOISEEVA	{"email": "moiseeva-n.091972@postgrespro.ru", "phone": "+70692641120"}
0005434265348	8C5B94	1349 621421	SERGEY AFANASEV	{"phone": "+70924044385"}
0005434265349	E7DA28	5098 988757	ALEKSANDR GAVRILOV	{"email": "gavrilov-a-25111972@postgrespro.ru", "phone": "+70807487271"}
0005434265350	E7DA28	2882 067934	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a-1986@postgrespro.ru", "phone": "+70118402553"}
0005434265351	3C2956	3476 383983	ALEKSANDR NIKITIN	{"phone": "+70877847839"}
0005434265352	F9D8F3	8075 624087	IRINA MASLOVA	{"email": "imaslova.111982@postgrespro.ru", "phone": "+70769644998"}
0005434265353	94E3F2	5182 037575	ILYA VASILEV	{"email": "ilya-vasilev.061973@postgrespro.ru", "phone": "+70416196622"}
0005434265354	5AB4EE	9484 260249	GALINA IVANOVA	{"phone": "+70453818974"}
0005434265356	28529F	2027 754479	ANATOLIY ZAKHAROV	{"phone": "+70808516030"}
0005434265357	28529F	6785 658905	ALEKSANDR NAZAROV	{"phone": "+70115031483"}
0005434265358	28529F	8657 470140	ANATOLIY ZAKHAROV	{"email": "anatoliy.zakharov1959@postgrespro.ru", "phone": "+70981137666"}
0005434265359	0EBB95	3654 760703	VIKTORIYA RODIONOVA	{"phone": "+70256514218"}
0005434265360	0EBB95	0088 741047	MARIYA ERMAKOVA	{"email": "ermakova-m-051959@postgrespro.ru", "phone": "+70624274376"}
0005434265361	55A785	9288 472681	MAKSIM VOLKOV	{"email": "mvolkov-30011977@postgrespro.ru", "phone": "+70226591147"}
0005434265362	55A785	3859 972278	VIKTOR IVANOV	{"email": "viktor.ivanov.04111976@postgrespro.ru", "phone": "+70961378705"}
0005434265363	55A785	3166 742892	OLGA SERGEEVA	{"phone": "+70810775077"}
0005434265364	7AEE45	5855 185921	ELENA ZHURAVLEVA	{"phone": "+70251998321"}
0005434265365	139473	5728 464610	ALEKSANDR BONDARENKO	{"email": "bondarenko-a_14091975@postgrespro.ru", "phone": "+70726090601"}
0005434265366	139473	7673 447820	ALEKSANDR NAZAROV	{"email": "nazarov.a.26011978@postgrespro.ru", "phone": "+70051641241"}
0005434265367	A89994	0251 322923	NATALIYA MELNIKOVA	{"phone": "+70667284539"}
0005434265368	E3863B	8245 556655	DINA MAKAROVA	{"phone": "+70115430989"}
0005434265369	FA2552	9111 633641	RIMMA AFANASEVA	{"email": "afanasevarimma_1971@postgrespro.ru", "phone": "+70743381181"}
0005434265370	449A70	3735 486495	VLADIMIR ORLOV	{"email": "vladimir.orlov_27101966@postgrespro.ru", "phone": "+70073442794"}
0005434265371	430E9F	4821 715584	LYUDMILA LUKYANOVA	{"email": "lukyanova_lyudmila_03101980@postgrespro.ru", "phone": "+70803232407"}
0005434265372	BF05F8	5610 143584	VALENTINA OVCHINNIKOVA	{"phone": "+70760975459"}
0005434265373	C469A4	1627 681301	LIDIYA SOROKINA	{"phone": "+70537951663"}
0005434265374	FAD00E	9306 931055	NADEZHDA IVANOVA	{"email": "ivanova-nadezhda_121973@postgrespro.ru", "phone": "+70070672741"}
0005434265375	FAD00E	0046 204088	ALENA KUZNECOVA	{"email": "a-kuznecova.041983@postgrespro.ru", "phone": "+70743095733"}
0005434265376	3B501A	7519 485465	OLEG KUZMIN	{"phone": "+70554073470"}
0005434265377	1C46C9	9220 566766	VLADIMIR ZHURAVLEV	{"phone": "+70183693031"}
0005434265378	E34752	2595 873898	SERGEY SIDOROV	{"email": "sidorov.sergey.101964@postgrespro.ru", "phone": "+70454597703"}
0005434265379	F55E0A	4037 874027	ALEKSANDR KRASNOV	{"phone": "+70971607152"}
0005434265380	F55E0A	9391 658149	NINA NOVIKOVA	{"phone": "+70823135752"}
0005434265381	DE50BC	8794 313023	ALEKSEY IVANOV	{"email": "ivanov-a111973@postgrespro.ru", "phone": "+70853992127"}
0005434265382	0BB985	6516 762002	NIKITA MIKHAYLOV	{"email": "mikhaylov.nikita_041966@postgrespro.ru", "phone": "+70457326849"}
0005434265383	986A85	7894 226685	LIDIYA GUSEVA	{"phone": "+70341735881"}
0005434265384	986A85	7989 800517	ALEKSANDR ALEKSANDROV	{"phone": "+70297473127"}
0005434265385	3FF967	6054 365326	GLEB NAUMOV	{"phone": "+70863205228"}
0005434265386	3FF967	5349 389480	ANTONINA KOROLEVA	{"email": "antonina-koroleva-1966@postgrespro.ru", "phone": "+70595640617"}
0005434265387	D57D09	9254 408138	NADEZHDA GAVRILOVA	{"phone": "+70047609001"}
0005434265388	2E1ADF	3478 496536	ALEKSANDR PAVLOV	{"phone": "+70105616214"}
0005434265389	ACC667	6791 687958	MARINA KUDRYASHOVA	{"phone": "+70685867204"}
0005434265390	17D721	2857 193073	MAKSIM ZAYCEV	{"email": "maksimzaycev.1980@postgrespro.ru", "phone": "+70263894578"}
0005434265391	17D721	0368 363510	IVAN KUZMIN	{"email": "ivan.kuzmin04071970@postgrespro.ru", "phone": "+70887792700"}
0005434265392	0F691C	7481 558403	LYUBOV SIDOROVA	{"email": "lyubov.sidorova.1965@postgrespro.ru", "phone": "+70766302814"}
0005434265393	F634A0	2591 257366	ELIZAVETA TIKHONOVA	{"phone": "+70528692775"}
0005434265394	16B318	0517 800006	IRINA GORBUNOVA	{"email": "igorbunova-1972@postgrespro.ru", "phone": "+70054159942"}
0005434265395	16B318	8081 238484	ELENA SIDOROVA	{"email": "elenasidorova_1970@postgrespro.ru", "phone": "+70021604496"}
0005434265396	368FA4	1921 324356	YURIY FEDOROV	{"email": "y-fedorov05101973@postgrespro.ru", "phone": "+70102717754"}
0005434265397	1F2319	0831 706774	NONNA POPOVA	{"email": "npopova1960@postgrespro.ru", "phone": "+70890325878"}
0005434265398	BFC375	9040 072259	YULIYA FEDOROVA	{"phone": "+70884894160"}
0005434265399	BA1652	8811 246908	NIKOLAY MAKAROV	{"phone": "+70895245330"}
0005434265400	999911	4441 837809	SERGEY VASILEV	{"email": "vasilev_s-071969@postgrespro.ru", "phone": "+70834144437"}
0005434265401	4CDFC6	7529 626542	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev_1969@postgrespro.ru", "phone": "+70747935748"}
0005434265402	9ECFA6	4244 153287	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov.121972@postgrespro.ru", "phone": "+70149569391"}
0005434265403	718CD6	7133 697476	VASILIY BARANOV	{"email": "vasiliybaranov1968@postgrespro.ru", "phone": "+70650216832"}
0005434265404	718CD6	9230 653884	MARINA IVANOVA	{"email": "marina.ivanova.1977@postgrespro.ru", "phone": "+70224690333"}
0005434265405	3E7ABB	5196 155300	MARGARITA ANTONOVA	{"phone": "+70447658905"}
0005434265406	B6DCAD	9531 672904	TATYANA ANDREEVA	{"email": "tatyana_andreeva.081977@postgrespro.ru", "phone": "+70267826608"}
0005434265407	A16E45	8322 454772	VADIM VOLKOV	{"email": "vadimvolkov-1976@postgrespro.ru", "phone": "+70954827398"}
0005434265408	C159E6	3498 655254	KONSTANTIN SMIRNOV	{"email": "konstantinsmirnov121968@postgrespro.ru", "phone": "+70540924263"}
0005434265409	08FBCB	5317 457465	GALINA EFIMOVA	{"email": "galinaefimova_1966@postgrespro.ru", "phone": "+70534688353"}
0005434265410	5CCACE	2660 159864	VIKTORIYA ALEKSEEVA	{"phone": "+70145634976"}
0005434265411	0F120B	5268 596456	ALEKSANDR OSIPOV	{"phone": "+70548490798"}
0005434265412	F9786A	1241 149868	KIRILL MIKHAYLOV	{"email": "kirill-mikhaylov-29011976@postgrespro.ru", "phone": "+70026416476"}
0005434265413	16824A	3518 046186	IGOR ZAKHAROV	{"phone": "+70441718317"}
0005434265414	16824A	8863 783433	LEONID SEMENOV	{"email": "leonid-semenov-19031973@postgrespro.ru", "phone": "+70637327833"}
0005434265415	C78701	0900 016665	ILYA SMIRNOV	{"phone": "+70115815597"}
0005434265416	CB4AB4	3136 450242	ALEKSEY AFANASEV	{"email": "afanasev-aleksey-1966@postgrespro.ru", "phone": "+70683457742"}
0005434265417	F25448	5502 494781	EVGENIY DENISOV	{"phone": "+70912261010"}
0005434265418	F25448	2089 720718	MILANA OSIPOVA	{"phone": "+70495459125"}
0005434265419	6AFD41	8045 284328	EVGENIY ALEKSANDROV	{"email": "aleksandrov.e_1972@postgrespro.ru", "phone": "+70022968090"}
0005434265420	6AFD41	7411 898899	VALERIYA FOMINA	{"phone": "+70666867537"}
0005434265421	6AFD41	1521 184151	NADEZHDA POLYAKOVA	{"phone": "+70499800299"}
0005434265422	84DBD0	0603 473060	NAIL SOKOLOV	{"phone": "+70342530746"}
0005434265423	355FF7	8491 117699	ANNA KOLESNIKOVA	{"phone": "+70372048354"}
0005434265424	355FF7	7394 770771	SERGEY SEMENOV	{"phone": "+70613352164"}
0005434265425	355FF7	2945 273926	MARAT SOLOVEV	{"email": "solovevm.22101978@postgrespro.ru", "phone": "+70214048769"}
0005434265426	044AC4	3445 806190	ELENA KOMAROVA	{"phone": "+70305014308"}
0005434265427	044AC4	1993 915591	SERGEY SAVELEV	{"phone": "+70190969605"}
0005434265428	642691	8627 364735	EVGENIY OSIPOV	{"phone": "+70440171981"}
0005434265429	499F4E	8813 780985	SOFIYA KONOVALOVA	{"email": "s_konovalova121967@postgrespro.ru", "phone": "+70433666123"}
0005434265430	D5FF39	1259 552943	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-02031982@postgrespro.ru", "phone": "+70982333936"}
0005434265431	7A4CBC	6792 070765	VLADIMIR KULIKOV	{"phone": "+70181819859"}
0005434265432	7A4CBC	2351 256660	MARIYA SOLOVEVA	{"phone": "+70254015870"}
0005434265433	7A4CBC	3034 300223	ARTEM POPOV	{"phone": "+70930235155"}
0005434265434	5406F6	3700 233418	OLGA GERASIMOVA	{"phone": "+70275466631"}
0005434265435	19B2A6	0591 326140	SERGEY BORISOV	{"email": "sergey.borisov_22031958@postgrespro.ru", "phone": "+70090973556"}
0005434265436	19B2A6	7370 487112	TATYANA NOVIKOVA	{"email": "tatyananovikova-01021971@postgrespro.ru", "phone": "+70395066920"}
0005434265437	8118EE	9999 789076	ZINAIDA PETROVA	{"phone": "+70722586771"}
0005434265438	7A3C02	9522 467434	SOFYA NOVIKOVA	{"email": "sofya-novikova_1983@postgrespro.ru", "phone": "+70417389736"}
0005434265439	793DFC	8244 174036	EKATERINA ANDREEVA	{"email": "e.andreeva19121973@postgrespro.ru", "phone": "+70108119399"}
0005434265440	4B26FA	0818 601492	LYUDMILA ALEKSEEVA	{"phone": "+70915070342"}
0005434265441	4B26FA	5136 675019	VALENTINA TIKHONOVA	{"email": "vtikhonova1964@postgrespro.ru", "phone": "+70865153736"}
0005434265442	14D841	7689 533378	SERGEY KISELEV	{"email": "kiselevsergey071985@postgrespro.ru", "phone": "+70910467564"}
0005434265443	F8CCFF	2666 376987	VASILIY MIKHAYLOV	{"phone": "+70037899806"}
0005434265444	15AB32	1128 568121	NATALYA SOLOVEVA	{"phone": "+70355305956"}
0005434265445	10D529	9756 161398	RUSLAN FEDOROV	{"phone": "+70596760267"}
0005434265446	10D529	5421 121161	SOFYA NOVIKOVA	{"phone": "+70675697772"}
0005434265447	B05B1D	6315 898213	SERGEY MELNIKOV	{"phone": "+70563366236"}
0005434265448	0BE78C	2282 104889	IVAN SOKOLOV	{"phone": "+70074585728"}
0005434265449	4DB2E2	0688 738104	VLADIMIR SOROKIN	{"phone": "+70194689173"}
0005434265450	1C71A9	3183 052469	ALEKSEY IVANOV	{"email": "ivanov.a.26111964@postgrespro.ru", "phone": "+70422621238"}
0005434265451	1C71A9	1465 480536	ANATOLIY ANDREEV	{"email": "a-andreev_1980@postgrespro.ru", "phone": "+70908780641"}
0005434265452	1C71A9	3856 809276	NIKOLAY ZHURAVLEV	{"phone": "+70490987362"}
0005434265453	70611C	6373 862206	GENNADIY KUDRYASHOV	{"email": "g.kudryashov-091980@postgrespro.ru", "phone": "+70173760862"}
0005434265454	70611C	3061 848456	MIKHAIL PETROV	{"phone": "+70331778865"}
0005434265455	70611C	5958 057873	SERGEY MEDVEDEV	{"phone": "+70103612242"}
0005434265456	AB3EFF	8655 358574	ARTEM ORLOV	{"phone": "+70716126866"}
0005434265457	50A942	2259 151888	EVGENIYA KONOVALOVA	{"phone": "+70294948760"}
0005434265458	50A942	2697 679792	ALEKSEY KISELEV	{"email": "a-kiselev1977@postgrespro.ru", "phone": "+70103098052"}
0005434265459	B2539B	6210 498443	ALEKSANDR ROMANOV	{"phone": "+70381980526"}
0005434265460	B2539B	5037 264739	SERGEY EGOROV	{"email": "sergey_egorov.031975@postgrespro.ru", "phone": "+70055459498"}
0005434265461	B2539B	9033 100567	ALEKSEY OSIPOV	{"email": "osipova-081964@postgrespro.ru", "phone": "+70713168022"}
0005434265462	461A2B	4966 308052	OLGA KUZNECOVA	{"phone": "+70986467904"}
0005434265463	461A2B	6080 373139	KSENIYA ZAYCEVA	{"email": "k_zayceva.1968@postgrespro.ru", "phone": "+70852933457"}
0005434265464	0A119A	3237 918177	TATYANA MIRONOVA	{"phone": "+70952925373"}
0005434265465	0A119A	4312 425299	SERGEY ROMANOV	{"email": "romanov.s-27121970@postgrespro.ru", "phone": "+70134346444"}
0005434265466	27A722	8006 499128	EKATERINA ZAKHAROVA	{"email": "ekaterina-zakharova_1965@postgrespro.ru", "phone": "+70209929162"}
0005434265467	A38305	6423 683589	RAISA DANILOVA	{"email": "r_danilova-1971@postgrespro.ru", "phone": "+70646312666"}
0005434265468	A38305	6138 941975	IRINA NOVIKOVA	{"email": "novikovairina-1970@postgrespro.ru", "phone": "+70148606009"}
0005434265469	353553	6752 739017	ALEKSEY MOISEEV	{"email": "moiseevaleksey_091976@postgrespro.ru", "phone": "+70093348213"}
0005434265470	72F392	8484 717649	LIDIYA PETROVA	{"email": "lidiya-petrova1979@postgrespro.ru", "phone": "+70359261809"}
0005434265471	B49311	0188 385113	TATYANA MEDVEDEVA	{"phone": "+70366375698"}
0005434265472	B49311	3762 526819	YULIYA ALEKSEEVA	{"email": "alekseeva_yuliya.1966@postgrespro.ru", "phone": "+70020788365"}
0005434265473	86160B	1274 822622	DARYA KUZNECOVA	{"phone": "+70791666450"}
0005434265474	C6BB2D	7170 701153	IVAN ROMANOV	{"email": "romanov-i.12021979@postgrespro.ru", "phone": "+70512408176"}
0005434265475	C6BB2D	7588 197357	ANASTASIYA POLYAKOVA	{"email": "apolyakova.1977@postgrespro.ru", "phone": "+70745896226"}
0005434265476	3EB142	9047 291586	ELENA STEPANOVA	{"email": "elena-stepanova.01011965@postgrespro.ru", "phone": "+70574150388"}
0005434265477	2B3AE8	3436 188581	OKSANA SMIRNOVA	{"email": "oksana_smirnova1968@postgrespro.ru", "phone": "+70429911319"}
0005434265478	099579	6349 528489	ALEKSANDR AFANASEV	{"phone": "+70625618470"}
0005434265479	9CB81A	6401 108680	MARIYA GERASIMOVA	{"email": "gerasimova_m.21061975@postgrespro.ru", "phone": "+70797023381"}
0005434265480	2C924A	4257 300597	VYACHESLAV RODIONOV	{"email": "vyacheslav-rodionov_26111962@postgrespro.ru", "phone": "+70342923905"}
0005434265481	CFAEE8	3322 456229	VLADISLAV FROLOV	{"email": "vladislav_frolov-041969@postgrespro.ru", "phone": "+70819655791"}
0005434265482	CD22A5	9470 039679	ALEKSANDR BORISOV	{"email": "borisovaleksandr021975@postgrespro.ru", "phone": "+70612989444"}
0005434265483	CD22A5	8972 960096	YURIY KUZNECOV	{"email": "kuznecovyuriy071962@postgrespro.ru", "phone": "+70623072137"}
0005434265484	D7D7E1	3638 780452	YURIY ILIN	{"phone": "+70184136225"}
0005434265485	17A6CC	7722 403940	RISHAT GUSEV	{"phone": "+70470133455"}
0005434265486	17A6CC	8568 304801	SERGEY ABRAMOV	{"phone": "+70844568372"}
0005434265487	9E8E90	9968 057511	IRINA ZAYCEVA	{"phone": "+70698434469"}
0005434265488	9E8E90	1355 981667	OLEG BONDARENKO	{"phone": "+70208184313"}
0005434265489	C7B809	3609 653047	VALERIY POPOV	{"phone": "+70792205295"}
0005434265490	98ED45	9396 222150	ANATOLIY ORLOV	{"email": "orlov.anatoliy-1964@postgrespro.ru", "phone": "+70220831203"}
0005434265491	0FEAB8	7439 769962	EKATERINA NIKITINA	{"email": "ekaterina.nikitina-09091980@postgrespro.ru", "phone": "+70242818121"}
0005434265492	0E401A	5016 688611	RAMIL ANTONOV	{"phone": "+70742729969"}
0005434265493	0E401A	4450 584256	ELENA MOROZOVA	{"email": "morozova_e_1974@postgrespro.ru", "phone": "+70562592950"}
0005434265494	860DBD	5579 038918	MARIYA NAZAROVA	{"email": "m.nazarova_081978@postgrespro.ru", "phone": "+70389921046"}
0005434265495	86C651	3070 033828	NINA FROLOVA	{"email": "ninafrolova-31051976@postgrespro.ru", "phone": "+70269175619"}
0005434265496	86C651	7172 978633	OLEG OSIPOV	{"phone": "+70501180847"}
0005434265497	3A0BC0	3786 713369	SVETLANA ZOTOVA	{"email": "svetlana_zotova_15071982@postgrespro.ru", "phone": "+70794105664"}
0005434265498	15A03E	0156 603278	EKATERINA SERGEEVA	{"phone": "+70077900951"}
0005434265499	15A03E	1814 156239	KRISTINA FADEEVA	{"email": "k_fadeeva-18061965@postgrespro.ru", "phone": "+70836624563"}
0005434265500	49F224	8529 213468	MARINA CHERNOVA	{"phone": "+70109274316"}
0005434265501	49F224	9997 574971	ANNA PETROVA	{"phone": "+70339396214"}
0005434265502	BAE2E7	2236 181637	LEONID NOVIKOV	{"email": "novikov_l_081964@postgrespro.ru", "phone": "+70518503639"}
0005434265503	BAE2E7	7562 108331	SAVELIY VOROBEV	{"phone": "+70212326312"}
0005434265504	8A3001	4539 116342	NATALYA MARTYNOVA	{"phone": "+70555121319"}
0005434265505	8A3001	4173 126146	VLADIMIR ALEKSEEV	{"phone": "+70424433628"}
0005434265506	8A3001	9957 611779	LYUBOV PAVLOVA	{"phone": "+70834744810"}
0005434265507	B712C0	1776 359068	IRINA FROLOVA	{"email": "frolova-i-1978@postgrespro.ru", "phone": "+70122967756"}
0005434265508	3B70AB	3272 618413	OLGA KUZNECOVA	{"email": "kuznecova.olga_011975@postgrespro.ru", "phone": "+70769938107"}
0005434265509	3B70AB	0714 233948	VYACHESLAV VOLKOV	{"email": "volkov-vyacheslav-28041971@postgrespro.ru", "phone": "+70124717715"}
0005434265510	ECD67B	5904 413212	VALENTINA SOROKINA	{"phone": "+70085190639"}
0005434265511	CA8BB4	2668 739770	SERGEY SMIRNOV	{"phone": "+70914362838"}
0005434265512	CA8BB4	3005 283797	GALINA TITOVA	{"email": "galina.titova091954@postgrespro.ru", "phone": "+70864645994"}
0005434265513	C5DD1F	8057 960807	EGOR PETROV	{"email": "petrovegor.1966@postgrespro.ru", "phone": "+70528044552"}
0005434265514	CE0F25	6504 722334	EGOR MIRONOV	{"phone": "+70994204138"}
0005434265515	67CEC3	3501 000184	LYUDMILA MOISEEVA	{"email": "moiseeva-lyudmila-011975@postgrespro.ru", "phone": "+70344619831"}
0005434265516	448404	5069 595827	ANNA TROFIMOVA	{"email": "a.trofimova_041974@postgrespro.ru", "phone": "+70076122980"}
0005434265517	7CA9CF	5977 573549	GEORGIY KARPOV	{"phone": "+70183169580"}
0005434265518	79EB0F	1576 467585	DENIS ALEKSEEV	{"phone": "+70963299860"}
0005434265519	FE27E5	3910 585663	SERGEY BORISOV	{"phone": "+70443355057"}
0005434265520	FE27E5	9426 816628	ANNA KISELEVA	{"email": "kiseleva_a.05011982@postgrespro.ru", "phone": "+70451346515"}
0005434265521	80ABFB	0662 273679	EVGENIY GAVRILOV	{"email": "gavrilov.evgeniy_101978@postgrespro.ru", "phone": "+70614098914"}
0005434265522	1EB4ED	8644 018173	ALEKSANDR MOISEEV	{"email": "moiseev-aleksandr.041976@postgrespro.ru", "phone": "+70809405898"}
0005434265523	1EB4ED	5341 349281	SVETLANA FILATOVA	{"email": "s.filatova-1980@postgrespro.ru", "phone": "+70283010617"}
0005434265524	3B095C	4037 721321	ARKADIY BELOV	{"phone": "+70858341481"}
0005434265525	3B095C	3164 689558	VALENTINA MOROZOVA	{"email": "v-morozova-28121984@postgrespro.ru", "phone": "+70658802993"}
0005434265526	84791B	6687 094583	SVETLANA BARANOVA	{"email": "baranova.svetlana_13071974@postgrespro.ru", "phone": "+70280529585"}
0005434265527	4EB8E1	5280 435927	VIKTOR BARANOV	{"email": "vbaranov.081976@postgrespro.ru", "phone": "+70460673385"}
0005434265528	C321F6	8741 162357	LILIYA MOROZOVA	{"email": "morozovaliliya.27011965@postgrespro.ru", "phone": "+70212075430"}
0005434265529	2D6BD4	4494 255378	VLADIMIR TARASOV	{"email": "tarasov_v-011982@postgrespro.ru", "phone": "+70722604348"}
0005434265530	914598	1663 318269	ANATOLIY IVANOV	{"email": "anatoliyivanov-051978@postgrespro.ru", "phone": "+70446122502"}
0005434265531	2EC68A	2776 710512	EGOR MARTYNOV	{"email": "martynov.e.01061970@postgrespro.ru", "phone": "+70268459305"}
0005434265532	1FC6F7	1263 680097	ALEKSEY ZAKHAROV	{"email": "zakharov_a_121966@postgrespro.ru", "phone": "+70955013572"}
0005434265533	1FC6F7	8119 622981	EVGENIY VASILEV	{"email": "e.vasilev.1972@postgrespro.ru", "phone": "+70526556422"}
0005434265534	65A0D2	2959 820160	SERGEY EGOROV	{"phone": "+70697784889"}
0005434265535	65A0D2	2464 501624	TATYANA ROMANOVA	{"phone": "+70687052048"}
0005434265536	15BB9B	1408 433387	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr1967@postgrespro.ru", "phone": "+70431365038"}
0005434265537	61742C	8578 822927	DARYA KUZMINA	{"email": "kuzmina.d_071985@postgrespro.ru", "phone": "+70686552942"}
0005434265538	61742C	9077 828987	ANNA VOLKOVA	{"phone": "+70689623911"}
0005434265539	4B3D5C	3949 011175	ALEKSANDRA BORISOVA	{"email": "borisova.a.061975@postgrespro.ru", "phone": "+70359772144"}
0005434265596	4FC000	5039 311269	OKSANA KONOVALOVA	{"phone": "+70611929608"}
0005434265540	4B3D5C	4656 131822	GLEB KOZLOV	{"email": "kozlov_gleb19091978@postgrespro.ru", "phone": "+70168157370"}
0005434265541	6CAC53	0695 124100	TATYANA BELYAEVA	{"phone": "+70723398588"}
0005434265542	78EA89	8090 672289	TAMARA MALYSHEVA	{"email": "tamaramalysheva.1971@postgrespro.ru", "phone": "+70034533743"}
0005434265543	78EA89	6388 074390	VLADIMIR PAVLOV	{"email": "pavlovv-12091976@postgrespro.ru", "phone": "+70056345184"}
0005434265544	D8E9E3	4425 148383	MARINA IVANOVA	{"phone": "+70333585735"}
0005434265545	A3A2E3	0493 943257	SERGEY GORBUNOV	{"email": "sergey-gorbunov-101965@postgrespro.ru", "phone": "+70133472748"}
0005434265546	A3A2E3	8937 808660	VIKTORIYA CHERNOVA	{"phone": "+70814730663"}
0005434265547	A3A2E3	4457 483150	PAVEL SAVELEV	{"email": "p-savelev.101979@postgrespro.ru", "phone": "+70691557891"}
0005434265548	A3A2E3	6985 603150	MIKHAIL SOKOLOV	{"email": "sokolov_m-1969@postgrespro.ru", "phone": "+70035700746"}
0005434265549	5BBCA5	1238 190170	GALINA MIKHAYLOVA	{"email": "galina-mikhaylova.091976@postgrespro.ru", "phone": "+70180868801"}
0005434265550	5BBCA5	4709 699416	SERGEY POPOV	{"email": "popovsergey_18071971@postgrespro.ru", "phone": "+70008855775"}
0005434265551	A2B59A	2361 564469	VLADIMIR MEDVEDEV	{"email": "vmedvedev.031964@postgrespro.ru", "phone": "+70449556192"}
0005434265552	3F8261	1775 976882	ALEKSANDR CHERNOV	{"email": "chernov_a091971@postgrespro.ru", "phone": "+70484245498"}
0005434265553	0A1755	7087 566208	KHALIDA LUKYANOVA	{"email": "k-lukyanova_06081975@postgrespro.ru", "phone": "+70422372947"}
0005434265554	0A1755	4046 747427	TIMUR KAZAKOV	{"email": "timurkazakov_021979@postgrespro.ru", "phone": "+70783382698"}
0005434265555	EAAC34	8797 147650	NATALYA VASILEVA	{"phone": "+70890696216"}
0005434265556	996DD5	2492 881991	VLADISLAV KARPOV	{"email": "vladislav-karpov1978@postgrespro.ru", "phone": "+70078058899"}
0005434265557	996DD5	4865 098918	IVAN ILIN	{"email": "ilin.ivan27071980@postgrespro.ru", "phone": "+70769484353"}
0005434265558	587673	7167 833513	ANDREY POPOV	{"email": "andrey.popov.20081979@postgrespro.ru", "phone": "+70586553627"}
0005434265559	FF9275	3407 525640	MARIYA SAVELEVA	{"phone": "+70739352134"}
0005434265560	9F1143	4147 127019	ALEKSANDR KUZNECOV	{"phone": "+70815812859"}
0005434265561	9F1143	1657 674142	EVGENIY KARPOV	{"phone": "+70425953507"}
0005434265562	FC002A	8439 223472	SVETLANA KOROLEVA	{"phone": "+70878511592"}
0005434265563	C8A72E	8744 193965	IVAN NIKOLAEV	{"phone": "+70098370038"}
0005434265564	08DDDB	1955 227266	PETR NIKITIN	{"email": "petr_nikitin_1967@postgrespro.ru", "phone": "+70065831144"}
0005434265565	8BA295	4019 826142	YURIY VOROBEV	{"email": "yuriy.vorobev-101974@postgrespro.ru", "phone": "+70263220665"}
0005434265566	8BA295	9682 976984	ALEKSANDRA VOROBEVA	{"email": "avorobeva.091973@postgrespro.ru", "phone": "+70783259420"}
0005434265567	49A4E6	9428 599415	ALEKSEY FEDOROV	{"email": "fedorovaleksey22071978@postgrespro.ru", "phone": "+70199666080"}
0005434265568	49A4E6	1306 355842	RAVZA SEMENOVA	{"email": "ravza.semenova-021979@postgrespro.ru", "phone": "+70387823317"}
0005434265569	1F2654	0740 787238	NADEZHDA ZOTOVA	{"phone": "+70846246421"}
0005434265570	0E99EC	2831 748044	ANDREY NIKOLAEV	{"phone": "+70743956505"}
0005434265571	0E99EC	0728 479773	ANTONINA MIRONOVA	{"phone": "+70939023326"}
0005434265572	CF2FA5	0117 229721	GALINA KARPOVA	{"phone": "+70007017516"}
0005434265573	CF2FA5	6963 936685	LARISA KUZNECOVA	{"phone": "+70545121073"}
0005434265574	CF2FA5	5335 836674	IGOR SCHERBAKOV	{"email": "scherbakovi.31011991@postgrespro.ru", "phone": "+70723962097"}
0005434265575	487E0A	3063 399521	VLADISLAV RODIONOV	{"email": "rodionovv031975@postgrespro.ru", "phone": "+70256554541"}
0005434265576	640398	5025 579215	SERGEY ZHUKOV	{"phone": "+70045356062"}
0005434265577	A334F3	8089 400627	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov21011970@postgrespro.ru", "phone": "+70711460118"}
0005434265578	A334F3	2077 863094	DENIS YAKOVLEV	{"email": "yakovlev-d121968@postgrespro.ru", "phone": "+70872482761"}
0005434265579	0C441E	0065 298397	ALEKSEY MAKAROV	{"phone": "+70484144513"}
0005434265580	0C441E	9039 520774	VERA KRASNOVA	{"phone": "+70521478496"}
0005434265581	F345AE	1638 309833	EVGENIY KONOVALOV	{"phone": "+70718505128"}
0005434265582	F345AE	3956 406335	NIKITA IVANOV	{"email": "ivanov.n.1976@postgrespro.ru", "phone": "+70396958106"}
0005434265583	F345AE	4044 375231	ANDREY MAKAROV	{"email": "makarovandrey.031973@postgrespro.ru", "phone": "+70122162264"}
0005434265584	F30039	7872 016511	TAISIYA ZOTOVA	{"email": "zotovataisiya27101962@postgrespro.ru", "phone": "+70992925347"}
0005434265585	31CF46	9169 948197	ELENA IVANOVA	{"phone": "+70751341537"}
0005434265586	8FD3C8	5256 152035	OKSANA MAKSIMOVA	{"email": "omaksimova_111971@postgrespro.ru", "phone": "+70045069083"}
0005434265587	8FD3C8	2887 718072	MIKHAIL NOVIKOV	{"phone": "+70494275163"}
0005434265588	DD1B5D	7690 262263	RAISA GORBUNOVA	{"phone": "+70115786679"}
0005434265589	6589AE	3998 346695	VALENTINA FILIPPOVA	{"phone": "+70825513879"}
0005434265590	6589AE	9362 348763	ALEKSANDR SOROKIN	{"email": "sorokina.24041966@postgrespro.ru", "phone": "+70064903316"}
0005434265591	8F1415	4012 554410	ELENA BELYAEVA	{"phone": "+70220838933"}
0005434265592	A6B1DB	7796 177179	ALEKSANDRA FROLOVA	{"phone": "+70665955422"}
0005434265593	53E878	2182 968616	LARISA ZAYCEVA	{"phone": "+70284855889"}
0005434265594	E316B6	3912 628046	LEV ZAYCEV	{"phone": "+70248533937"}
0005434265595	E316B6	4248 302279	ARTEM VLASOV	{"email": "artem.vlasov.1976@postgrespro.ru", "phone": "+70068346611"}
0005434265597	8BA907	3262 678535	VERA EFIMOVA	{"phone": "+70541924058"}
0005434265598	4BB0D7	8883 554521	EDUARD NIKOLAEV	{"email": "e-nikolaev29041969@postgrespro.ru", "phone": "+70442678946"}
0005434265599	4B08FF	5665 385513	STANISLAV SHEVCHENKO	{"email": "s_shevchenko27121969@postgrespro.ru", "phone": "+70201778573"}
0005434265600	C79068	4713 350968	YURIY GERASIMOV	{"email": "y.gerasimov_1971@postgrespro.ru", "phone": "+70469400035"}
0005434265601	71CB58	7155 001074	KSENIYA BELOVA	{"email": "belova_k-18111975@postgrespro.ru", "phone": "+70433810180"}
0005434265602	F8C8C5	2370 422238	RAFAIL MAKSIMOV	{"phone": "+70954725417"}
0005434265603	F8C8C5	3452 879935	TATYANA PETROVA	{"phone": "+70584760178"}
0005434265604	F8C8C5	9608 498582	MARIYA GAVRILOVA	{"email": "mariyagavrilova111983@postgrespro.ru", "phone": "+70807965126"}
0005434265605	63FA6E	0231 507966	KAPITALINA BORISOVA	{"phone": "+70107398151"}
0005434265606	4700E7	2896 848608	ALEKSANDRA IVANOVA	{"email": "a.ivanova.051981@postgrespro.ru", "phone": "+70811541137"}
0005434265607	4700E7	7417 040596	ALEKSEY MELNIKOV	{"phone": "+70754639958"}
0005434265608	B53AA3	7486 043723	NINA SERGEEVA	{"email": "sergeeva_nina_03101977@postgrespro.ru", "phone": "+70883878925"}
0005434265609	C7FBB9	3275 458214	VALERIYA NESTEROVA	{"phone": "+70503334301"}
0005434265610	FB668C	4369 056902	TATYANA IVANOVA	{"email": "ivanova-t_061972@postgrespro.ru", "phone": "+70401745193"}
0005434265611	0A9881	5293 311255	ANTON FEDOTOV	{"phone": "+70973462992"}
0005434265612	E55A01	8667 964492	SHAVKAT BELOV	{"phone": "+70789792227"}
0005434265613	845615	0996 021985	VALENTINA KUDRYASHOVA	{"email": "vkudryashova-20061976@postgrespro.ru", "phone": "+70722585396"}
0005434265614	516A02	5090 338857	TATYANA GERASIMOVA	{"phone": "+70514512625"}
0005434265615	3721F2	1222 092013	OLGA AKIMOVA	{"email": "olgaakimova_24051971@postgrespro.ru", "phone": "+70857625872"}
0005434265616	3721F2	2274 760332	VIKTOR POPOV	{"phone": "+70588238988"}
0005434265617	15B2EA	7393 148531	ELMIRA ALEKSEEVA	{"email": "e.alekseeva.071973@postgrespro.ru", "phone": "+70710126545"}
0005434265618	15B2EA	6972 471194	SERGEY ROMANOV	{"phone": "+70744079459"}
0005434265619	F594FB	0895 811707	SERGEY PAVLOV	{"email": "sergey_pavlov-091966@postgrespro.ru", "phone": "+70553671340"}
0005434265620	FA276B	4411 673459	SERGEY GRIGOREV	{"email": "grigorev-sergey02061968@postgrespro.ru", "phone": "+70769919843"}
0005434265621	FA276B	2904 930325	NATALYA DAVYDOVA	{"phone": "+70528572428"}
0005434265622	7293F8	5083 495822	YURIY FEDOROV	{"email": "fedorovyuriy.011977@postgrespro.ru", "phone": "+70261634332"}
0005434265623	7CE0D8	7088 138288	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov.011975@postgrespro.ru", "phone": "+70988645252"}
0005434265624	7CE0D8	9472 072612	GLEB KOZLOV	{"email": "kozlovgleb_18031973@postgrespro.ru", "phone": "+70563123684"}
0005434265625	7B8CD2	2797 018634	MAKSIM ANTONOV	{"phone": "+70303418051"}
0005434265626	7D7D3F	9780 674488	ANASTASIYA NIKITINA	{"phone": "+70734480494"}
0005434265627	78D4A0	8843 357298	ALEKSEY KULIKOV	{"phone": "+70615848694"}
0005434265628	5CEE2B	6606 234774	TATYANA MIKHAYLOVA	{"phone": "+70752577033"}
0005434265629	5CEE2B	7829 510499	EVGENIY ZHUKOV	{"email": "zhukovevgeniy.1970@postgrespro.ru", "phone": "+70015289865"}
0005434265630	D20D18	5247 115845	MIKHAIL BORISOV	{"email": "mborisov.1967@postgrespro.ru", "phone": "+70736154681"}
0005434265631	238B7A	2406 127893	MAKSIM KUZNECOV	{"email": "kuznecov_maksim13021984@postgrespro.ru", "phone": "+70485796022"}
0005434265632	35BEFE	6895 773960	DMITRIY ROMANOV	{"email": "romanov_d-29011975@postgrespro.ru", "phone": "+70581383179"}
0005434265633	35BEFE	5008 556291	ELENA POPOVA	{"phone": "+70214950079"}
0005434265634	B979E2	6423 160743	IRINA RYABOVA	{"phone": "+70022370382"}
0005434265635	DD53C9	9076 712095	ANATOLIY SAVELEV	{"phone": "+70760905251"}
0005434265636	41FE40	4118 921321	MARIYA POPOVA	{"email": "mariya-popova_091969@postgrespro.ru", "phone": "+70428259346"}
0005434265637	BC9E69	8318 418311	ANTON BELOV	{"email": "belovanton081978@postgrespro.ru", "phone": "+70575780443"}
0005434265638	DFBE62	7308 384391	SVETLANA ZHUKOVA	{"email": "zhukova.svetlana.011975@postgrespro.ru", "phone": "+70114702442"}
0005434265639	C34B30	0278 927690	EVGENIY IVANOV	{"phone": "+70997118968"}
0005434265640	D0A2EC	3197 599848	PAVEL DENISOV	{"email": "denisov.pavel.1980@postgrespro.ru", "phone": "+70350833136"}
0005434265641	E161A0	9694 882910	ALEKSEY IVANOV	{"email": "alekseyivanov24061970@postgrespro.ru", "phone": "+70918066290"}
0005434265642	C095DF	9699 357567	SVETLANA KOLESNIKOVA	{"phone": "+70386232935"}
0005434265643	ABB21F	1204 372832	LYUBOV SCHERBAKOVA	{"email": "scherbakoval04041966@postgrespro.ru", "phone": "+70180132346"}
0005434265644	ABB21F	3346 706546	SVETLANA VASILEVA	{"phone": "+70296221549"}
0005434265645	DC014D	7429 845656	YURIY NAZAROV	{"phone": "+70467764091"}
0005434265646	9C48F2	9028 452757	ANASTASIYA RYABOVA	{"phone": "+70903311595"}
0005434265647	7DDBB3	1498 886117	VIKTORIYA SERGEEVA	{"phone": "+70795447563"}
0005434265648	075445	0760 842667	ANATOLIY ALEKSANDROV	{"phone": "+70805294026"}
0005434265649	B13E8A	9817 972786	MARIYA SERGEEVA	{"email": "m_sergeeva-23061974@postgrespro.ru", "phone": "+70064821296"}
0005434265650	3FA514	0655 951153	SERGEY SMIRNOV	{"phone": "+70867826787"}
0005434265651	0822C9	7994 334148	ALEKSANDRA DANILOVA	{"phone": "+70682876829"}
0005434265652	0822C9	9388 669403	ANTONINA FADEEVA	{"email": "fadeevaantonina.091959@postgrespro.ru", "phone": "+70894685390"}
0005434265653	1B264A	9639 616547	ANTON KUZNECOV	{"email": "a-kuznecov011964@postgrespro.ru", "phone": "+70187580780"}
0005434265654	624F3B	5696 321035	FAINA PETROVA	{"email": "petrovafaina_27031984@postgrespro.ru", "phone": "+70949739368"}
0005434265655	6BAF82	7639 796669	MARIYA NAUMOVA	{"phone": "+70765601550"}
0005434265656	461073	7982 468391	ALEKSEY EGOROV	{"email": "egorov_aleksey.111978@postgrespro.ru", "phone": "+70986483459"}
0005434265657	265E58	1619 337371	ELENA LAZAREVA	{"phone": "+70325489127"}
0005434265658	265E58	0150 172622	EDUARD POPOV	{"phone": "+70441371834"}
0005434265659	265E58	0463 824526	MARIYA FEDOROVA	{"phone": "+70163033387"}
0005434265660	12D372	4784 759458	ALEKSANDRA POPOVA	{"phone": "+70595992849"}
0005434265661	4ACE40	2791 954580	MARINA LUKYANOVA	{"email": "lukyanovam_081973@postgrespro.ru", "phone": "+70937767214"}
0005434265662	FEE8D9	8398 559483	ARTEM SERGEEV	{"phone": "+70626402702"}
0005434265663	FEE8D9	9902 207959	VALERIY BORISOV	{"phone": "+70064155570"}
0005434265664	B28138	1998 436875	SVETLANA SOKOLOVA	{"phone": "+70078265356"}
0005434265665	3D046D	9874 762162	LYUDMILA SAVELEVA	{"phone": "+70921850776"}
0005434265666	F4413A	9926 434109	GENNADIY ROMANOV	{"phone": "+70442885178"}
0005434265667	F4413A	7438 784971	NIKOLAY POPOV	{"email": "popov-n_1965@postgrespro.ru", "phone": "+70587282530"}
0005434265668	B5A29A	5477 017376	MARIYA SAVELEVA	{"phone": "+70238311490"}
0005434265669	5DDB4E	1226 013747	SERGEY MELNIKOV	{"email": "sergey.melnikov1969@postgrespro.ru", "phone": "+70098222114"}
0005434265670	0EEC23	5118 660189	ARTEM POPOV	{"phone": "+70317381266"}
0005434265671	0EEC23	4502 347068	ANATOLIY FILIPPOV	{"phone": "+70457388127"}
0005434265672	E832D0	2148 999375	ANZHELA FILIPPOVA	{"email": "anzhela.filippova.1975@postgrespro.ru", "phone": "+70808891079"}
0005434265673	5B25F9	1938 891235	DMITRIY IVANOV	{"phone": "+70909533242"}
0005434265674	813105	1334 065910	TATYANA ROMANOVA	{"email": "tromanova_11061976@postgrespro.ru", "phone": "+70668923644"}
0005434265675	99150B	4256 931648	ALEKSANDR RODIONOV	{"email": "a_rodionov081983@postgrespro.ru", "phone": "+70000158681"}
0005434265676	B44CFC	0010 890104	ELLA ZOTOVA	{"email": "e-zotova-011972@postgrespro.ru", "phone": "+70756845131"}
0005434265677	B44CFC	4093 899904	LIDIYA GUSEVA	{"email": "guseva_l.06041970@postgrespro.ru", "phone": "+70473137647"}
0005434265678	056C4C	5149 997762	PETR FEDOROV	{"phone": "+70241582645"}
0005434265679	D23FD9	1308 740496	LIDIYA SERGEEVA	{"email": "sergeeva-l-1970@postgrespro.ru", "phone": "+70427106997"}
0005434265680	9A7609	8733 123111	YURIY KAZAKOV	{"email": "kazakovyuriy061974@postgrespro.ru", "phone": "+70126228687"}
0005434265681	9A7609	9695 014216	MARIYA KUZNECOVA	{"phone": "+70027018484"}
0005434265682	9A7609	6770 821255	ANDREY KUZNECOV	{"email": "kuznecov.a_11031971@postgrespro.ru", "phone": "+70948780031"}
0005434265683	DD94AD	7372 962848	VITALIY KUZNECOV	{"email": "kuznecov.v.091979@postgrespro.ru", "phone": "+70671032077"}
0005434265684	F49FAA	4060 703778	OLGA NAZAROVA	{"email": "o_nazarova_081976@postgrespro.ru", "phone": "+70028155911"}
0005434265742	59DEB3	9519 741291	VITALIY KUZNECOV	{"phone": "+70082424591"}
0005434265685	A8B654	7276 092615	NINA NOVIKOVA	{"email": "n-novikova.1965@postgrespro.ru", "phone": "+70351421689"}
0005434265686	FC4F13	7317 305721	EVGENIYA POPOVA	{"phone": "+70892117019"}
0005434265687	FC4F13	1607 728780	ALEKSANDR SEMENOV	{"phone": "+70306051951"}
0005434265688	056F82	5172 768701	ALEKSANDR ANTONOV	{"email": "antonov-a101978@postgrespro.ru", "phone": "+70723597332"}
0005434265689	056F82	7867 342371	ALEKSANDR CHERNOV	{"email": "chernov_a.25041977@postgrespro.ru", "phone": "+70737596417"}
0005434265690	056F82	0816 881607	KONSTANTIN VOLKOV	{"email": "konstantin-volkov_1975@postgrespro.ru", "phone": "+70368686391"}
0005434265691	9E8BA8	1319 597749	ANNA KISELEVA	{"phone": "+70812610774"}
0005434265692	0AAF09	4894 596034	VALENTINA KUZMINA	{"email": "valentinakuzmina_29061969@postgrespro.ru", "phone": "+70649761696"}
0005434265693	0AAF09	9313 250327	TATYANA SIDOROVA	{"phone": "+70926868142"}
0005434265694	43ACFE	7723 093386	NADEZHDA SERGEEVA	{"email": "n-sergeeva-1960@postgrespro.ru", "phone": "+70074877979"}
0005434265695	43ACFE	5852 564979	MARINA DAVYDOVA	{"phone": "+70139561317"}
0005434265696	B5DD16	8059 459040	VLADIMIR DAVYDOV	{"phone": "+70792735158"}
0005434265697	FAA9F2	6916 519618	ANNA KUZMINA	{"phone": "+70187612037"}
0005434265698	FAA9F2	0778 009337	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy.021979@postgrespro.ru", "phone": "+70522934956"}
0005434265699	FAA9F2	5246 269916	ALEKSANDR STEPANOV	{"phone": "+70450183608"}
0005434265700	E176F1	7562 018833	SERGEY NIKOLAEV	{"email": "sergey_nikolaev081967@postgrespro.ru", "phone": "+70139019168"}
0005434265701	171925	2530 657447	VIKTOR MAKSIMOV	{"phone": "+70726519993"}
0005434265702	0FA1D0	6063 878169	IVAN TARASOV	{"phone": "+70033062847"}
0005434265703	0FA1D0	7363 640693	MARGARITA KALININA	{"email": "margarita.kalinina.12121982@postgrespro.ru", "phone": "+70076137255"}
0005434265704	C02C86	8664 826607	VASILIY NIKOLAEV	{"email": "v_nikolaev.15081975@postgrespro.ru", "phone": "+70241760684"}
0005434265705	C02C86	9298 522336	ARTUR KULIKOV	{"email": "artur-kulikov-1980@postgrespro.ru", "phone": "+70781483984"}
0005434265706	02A074	7965 018781	YULIANA NOVIKOVA	{"phone": "+70152482279"}
0005434265707	02A074	3256 435501	VYACHESLAV BONDARENKO	{"phone": "+70683413447"}
0005434265708	F0564F	6673 661036	ANDREY NIKOLAEV	{"email": "nikolaev.andrey-11091971@postgrespro.ru", "phone": "+70341673794"}
0005434265709	EBD050	7986 264360	DARYA BELOVA	{"phone": "+70326470649"}
0005434265710	EBD050	4566 345981	SVETLANA MAKAROVA	{"phone": "+70602626047"}
0005434265711	EBD050	3404 269596	OLESYA IVANOVA	{"email": "olesyaivanova-101969@postgrespro.ru", "phone": "+70269454163"}
0005434265712	EBD050	3470 436286	DARYA ANISIMOVA	{"phone": "+70055393502"}
0005434265713	F1FBC1	3977 388238	ALEKSEY TARASOV	{"email": "tarasova021964@postgrespro.ru", "phone": "+70113128624"}
0005434265714	D863C0	1447 401465	ANASTASIYA KUZNECOVA	{"phone": "+70297139084"}
0005434265715	D863C0	5164 316239	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir-29101968@postgrespro.ru", "phone": "+70932481203"}
0005434265716	117B0E	8134 337174	OLEG DMITRIEV	{"phone": "+70377781001"}
0005434265717	992A6A	3257 821034	EKATERINA FROLOVA	{"email": "e.frolova-10121974@postgrespro.ru", "phone": "+70929881728"}
0005434265718	9B2C70	3793 680601	STANISLAV NIKOLAEV	{"phone": "+70875040262"}
0005434265719	C17787	8781 154998	ANDREY DMITRIEV	{"phone": "+70681152758"}
0005434265720	C17787	6565 301603	ALEKSANDR POPOV	{"email": "a_popov.1977@postgrespro.ru", "phone": "+70320876048"}
0005434265721	ADAE50	1217 697045	YULIYA ARKHIPOVA	{"email": "yuliya_arkhipova-04101982@postgrespro.ru", "phone": "+70081641835"}
0005434265722	58522B	0264 179406	MATVEY KUZNECOV	{"email": "matvey-kuznecov.1976@postgrespro.ru", "phone": "+70523847821"}
0005434265723	58522B	6043 980322	IGOR DENISOV	{"phone": "+70853999243"}
0005434265724	4FEAAE	8991 633602	ANTONINA MAKAROVA	{"phone": "+70016947240"}
0005434265725	4FEAAE	2408 159642	OLGA FOMINA	{"phone": "+70826483604"}
0005434265726	DF2C79	9500 783868	MIKHAIL NOVIKOV	{"phone": "+70173089566"}
0005434265727	A3EC64	0590 581328	EVGENIY MIRONOV	{"phone": "+70685398611"}
0005434265728	A3EC64	9322 906585	TATYANA MEDVEDEVA	{"email": "medvedeva.tatyana_1975@postgrespro.ru", "phone": "+70667860573"}
0005434265729	FD2BD8	4639 397461	IRINA AFANASEVA	{"phone": "+70607252194"}
0005434265730	7670AA	0803 293729	SERGEY BORISOV	{"email": "borisovsergey-041981@postgrespro.ru", "phone": "+70967034706"}
0005434265731	97CB21	8170 759345	LYUDMILA ISAEVA	{"email": "isaeva-l11081965@postgrespro.ru", "phone": "+70432992236"}
0005434265732	97CB21	0011 685021	EKATERINA BORISOVA	{"email": "ekaterina-borisova.011968@postgrespro.ru", "phone": "+70025875281"}
0005434265733	2FFAFA	4005 821099	ANATOLIY KONOVALOV	{"phone": "+70453732775"}
0005434265734	C7E901	7817 528742	NATALYA ANDREEVA	{"phone": "+70944799571"}
0005434265735	C7E901	8938 521967	MARIYA FROLOVA	{"phone": "+70261247273"}
0005434265736	8AB9D2	4875 066422	ANDREY BORISOV	{"phone": "+70999970565"}
0005434265737	2F63C9	9792 829080	ILYA NAZAROV	{"phone": "+70349797509"}
0005434265738	62B998	0608 391781	EVGENIYA BELOVA	{"phone": "+70170820593"}
0005434265739	62B998	0659 014417	TATYANA IVANOVA	{"phone": "+70014294329"}
0005434265740	94A9C3	6321 443835	SERAFIMA SERGEEVA	{"phone": "+70463775187"}
0005434265741	6594A5	6865 592510	FARIDA ORLOVA	{"email": "orlova_f_1965@postgrespro.ru", "phone": "+70170769906"}
0005434265743	C0D0E6	5764 146138	ANNA ILINA	{"email": "ilina-anna_03091969@postgrespro.ru", "phone": "+70050133657"}
0005434265744	C0D0E6	7051 631843	KONSTANTIN CHERNOV	{"email": "kchernov-23041981@postgrespro.ru", "phone": "+70707748211"}
0005434265745	C0D0E6	8781 326024	YURIY KUDRYASHOV	{"phone": "+70004922555"}
0005434265746	B526B9	8990 287556	SVETLANA ANDREEVA	{"email": "sandreeva_22011964@postgrespro.ru", "phone": "+70816374969"}
0005434265747	0A988E	5515 260591	YURIY BONDARENKO	{"phone": "+70409251837"}
0005434265748	142AE0	8311 536592	MIKHAIL MIKHAYLOV	{"phone": "+70478725744"}
0005434265749	708972	6276 524816	EKATERINA FEDOROVA	{"phone": "+70541626991"}
0005434265750	EFFB06	4883 515287	ANTON SERGEEV	{"phone": "+70965638099"}
0005434265751	AFF7A0	3830 514963	VALENTINA TARASOVA	{"email": "v-tarasova.26081964@postgrespro.ru", "phone": "+70682353746"}
0005434265752	ADB058	2631 676980	VYACHESLAV MAKSIMOV	{"email": "v_maksimov1967@postgrespro.ru", "phone": "+70118654268"}
0005434265753	BB5579	6906 896045	ANTONINA SMIRNOVA	{"email": "antonina_smirnova_1971@postgrespro.ru", "phone": "+70799937998"}
0005434265754	011B7C	9894 261123	GULSINA MATVEEVA	{"phone": "+70902653787"}
0005434265755	011B7C	6994 004651	GRIGORIY CHERNOV	{"email": "chernov_g_1966@postgrespro.ru", "phone": "+70253595520"}
0005434265756	98EF9B	1223 836189	NATALYA POPOVA	{"email": "popova.natalya11041968@postgrespro.ru", "phone": "+70794855174"}
0005434265757	F87BE1	3579 672864	SVETLANA IVANOVA	{"phone": "+70979518746"}
0005434265758	896E52	8462 236247	ANDREY ISAEV	{"phone": "+70180921301"}
0005434265759	896E52	6102 601201	ELENA VASILEVA	{"email": "elena.vasileva_021981@postgrespro.ru", "phone": "+70843264862"}
0005434265760	3542DC	1231 651356	MILENA SMIRNOVA	{"email": "smirnova.milena.1968@postgrespro.ru", "phone": "+70995311157"}
0005434265761	3542DC	1292 576694	ANASTASIYA SEMENOVA	{"email": "anastasiya.semenova-1966@postgrespro.ru", "phone": "+70962621256"}
0005434265762	3542DC	0466 850469	POLINA GUSEVA	{"phone": "+70762666539"}
0005434265763	61A3A9	4969 417938	ALEKSANDR BARANOV	{"email": "abaranov061979@postgrespro.ru", "phone": "+70610486408"}
0005434265764	61A3A9	6157 027511	KSENIYA OSIPOVA	{"phone": "+70634161270"}
0005434265765	9FAC36	9026 142611	NADEZHDA KUZNECOVA	{"email": "n_kuznecova.011975@postgrespro.ru", "phone": "+70051487519"}
0005434265766	6F66FC	3128 899544	ELENA KOVALEVA	{"email": "kovaleva-e19091977@postgrespro.ru", "phone": "+70421415648"}
0005434265767	60E7BD	1415 755086	SERGEY IVANOV	{"email": "sergey_ivanov.051976@postgrespro.ru", "phone": "+70997318857"}
0005434265768	4B8A3D	2475 264521	EVGENIY RODIONOV	{"email": "erodionov_051978@postgrespro.ru", "phone": "+70959766287"}
0005434265769	C6E870	5919 943138	VALERIY KUZNECOV	{"phone": "+70763147991"}
0005434265770	C6E870	2018 518953	VALENTINA AFANASEVA	{"phone": "+70490192699"}
0005434265771	422212	5670 597460	VALERIY SOLOVEV	{"email": "v-solovev-1974@postgrespro.ru", "phone": "+70750141473"}
0005434265772	7F63A0	5095 680231	LIDIYA GRISHINA	{"phone": "+70431134293"}
0005434265773	7F63A0	0384 815393	NAIL KUZMIN	{"email": "nail.kuzmin_1972@postgrespro.ru", "phone": "+70906303986"}
0005434265774	3199DE	4887 300205	VALENTINA SEMENOVA	{"phone": "+70432708883"}
0005434265775	3199DE	9032 786483	LYUBOV BELYAEVA	{"email": "l-belyaeva_1957@postgrespro.ru", "phone": "+70774017667"}
0005434265776	B39023	8651 483134	OLGA MIRONOVA	{"email": "mironova.olga_101964@postgrespro.ru", "phone": "+70164377967"}
0005434265777	3ACD8B	5940 394165	SVETLANA MARTYNOVA	{"email": "martynova_svetlana_1970@postgrespro.ru", "phone": "+70494928280"}
0005434265778	3ACD8B	0703 261341	ALEKSEY FROLOV	{"email": "a.frolov.31081966@postgrespro.ru", "phone": "+70398912728"}
0005434265779	531953	6626 900051	ALEKSEY EGOROV	{"phone": "+70807864718"}
0005434265780	4D4783	7445 462918	ANASTASIYA DAVYDOVA	{"email": "davydova-a041979@postgrespro.ru", "phone": "+70084840826"}
0005434265781	1493D2	5340 357255	OLGA NIKOLAEVA	{"phone": "+70563717967"}
0005434265782	CCA325	2845 746753	LIDIYA LAZAREVA	{"email": "l-lazareva_28101971@postgrespro.ru", "phone": "+70540872667"}
0005434265783	40A141	6716 473477	LARISA IVANOVA	{"phone": "+70300407956"}
0005434265784	40A141	4149 514509	SANIYA GUSEVA	{"phone": "+70433477863"}
0005434265785	EBECF6	6460 227222	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov.1974@postgrespro.ru", "phone": "+70246646993"}
0005434265786	38B78C	5295 209152	EGOR SOROKIN	{"email": "sorokin_egor1972@postgrespro.ru", "phone": "+70813798650"}
0005434265787	38B78C	7898 905311	ALEKSANDR EGOROV	{"phone": "+70703439487"}
0005434265788	EBCA93	6470 722174	SERGEY ABRAMOV	{"email": "s.abramov031978@postgrespro.ru", "phone": "+70196834824"}
0005434265789	EBCA93	2416 658836	ELENA GUSEVA	{"phone": "+70916848823"}
0005434265790	1C1541	4155 375762	OLGA ISAEVA	{"email": "isaeva-olga-091978@postgrespro.ru", "phone": "+70689192252"}
0005434265791	A4BBD0	7709 423533	SERGEY ROMANOV	{"phone": "+70026345674"}
0005434265792	2859EB	3659 870195	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya1962@postgrespro.ru", "phone": "+70864399817"}
0005434265793	FB8656	8582 680409	NADEZHDA ARKHIPOVA	{"email": "nadezhda.arkhipova1983@postgrespro.ru", "phone": "+70798107758"}
0005434265794	3C8B3B	2190 830954	ROZA VOLKOVA	{"email": "volkova_r-071981@postgrespro.ru", "phone": "+70469203100"}
0005434265795	3C8B3B	9020 181870	NATALYA BELYAEVA	{"email": "belyaevan.17121961@postgrespro.ru", "phone": "+70325674283"}
0005434265796	C05427	7432 212329	ANNA EGOROVA	{"email": "a-egorova1980@postgrespro.ru", "phone": "+70990039285"}
0005434265797	0949BD	5016 007232	INNA KUZNECOVA	{"email": "inna-kuznecova.1975@postgrespro.ru", "phone": "+70104066232"}
0005434265798	9BA340	1694 453184	OLGA OSIPOVA	{"phone": "+70143910379"}
0005434265799	586910	7680 863912	LYUDMILA KOROLEVA	{"email": "koroleva-l1980@postgrespro.ru", "phone": "+70366573312"}
0005434265800	B459DA	1472 709589	VERONIKA MAKAROVA	{"email": "v-makarova_041968@postgrespro.ru", "phone": "+70391933890"}
0005434265801	B459DA	5361 720333	KONSTANTIN PETROV	{"phone": "+70955027859"}
0005434265802	4160A5	2683 375819	YURIY STEPANOV	{"email": "stepanov-yuriy_101968@postgrespro.ru", "phone": "+70292549762"}
0005434265803	FC98F1	0374 242877	MARYAM KUZMINA	{"phone": "+70657326547"}
0005434265804	922347	1200 639018	VLADIMIR STEPANOV	{"email": "stepanovvladimir02021977@postgrespro.ru", "phone": "+70997228088"}
0005434265805	BD660A	9537 070838	ANDREY SOLOVEV	{"email": "andreysolovev-121979@postgrespro.ru", "phone": "+70874413857"}
0005434265806	43D5BC	2639 588573	VYACHESLAV NOVIKOV	{"email": "vyacheslav.novikov-101979@postgrespro.ru", "phone": "+70526882683"}
0005434265807	D13B1B	1614 235688	ZOYA KUZMINA	{"email": "kuzminazoya26061972@postgrespro.ru", "phone": "+70289800110"}
0005434265808	380419	7473 657165	NADEZHDA GRISHINA	{"phone": "+70806997458"}
0005434265809	380419	7238 389134	ALEKSANDR FEDOROV	{"email": "fedorov_a-06031970@postgrespro.ru", "phone": "+70661918225"}
0005434265810	380419	4416 009660	ULYANA SEMENOVA	{"email": "ulyana-semenova-1960@postgrespro.ru", "phone": "+70899342255"}
0005434265811	4770E9	1896 965927	VLADIMIR IVANOV	{"email": "ivanov-vladimir011978@postgrespro.ru", "phone": "+70244566313"}
0005434265812	4770E9	7115 466075	TATYANA VOLKOVA	{"phone": "+70028845121"}
0005434265813	7E694B	2094 462604	EVGENIYA GORBUNOVA	{"email": "gorbunova-e_1969@postgrespro.ru", "phone": "+70468085931"}
0005434265814	5EB821	8284 190107	VALENTIN ZAKHAROV	{"email": "vzakharov15081965@postgrespro.ru", "phone": "+70413275413"}
0005434265815	F3BCEA	3133 765821	VERA TARASOVA	{"phone": "+70557635348"}
0005434265816	3FA936	8519 882662	VALERIY KUZNECOV	{"phone": "+70190669182"}
0005434265817	11ED83	3872 675540	VIKTOR CHERNOV	{"email": "vchernov121978@postgrespro.ru", "phone": "+70852274763"}
0005434265818	11ED83	7828 054751	VALENTINA KUZMINA	{"email": "kuzmina-v-1973@postgrespro.ru", "phone": "+70209210929"}
0005434265819	F6EA62	8473 418108	IGOR TIKHONOV	{"email": "tikhonov.i.26111973@postgrespro.ru", "phone": "+70554707170"}
0005434265820	54D1C1	4401 360980	DENIS TIKHONOV	{"email": "tikhonov-denis.18101977@postgrespro.ru", "phone": "+70899931280"}
0005434265821	AC3D93	7484 831103	IRINA MIKHAYLOVA	{"email": "irina.mikhaylova_1974@postgrespro.ru", "phone": "+70097015671"}
0005434265822	AC3D93	5251 517289	INNA KOLESNIKOVA	{"phone": "+70265248819"}
0005434265823	BE3802	8171 072970	ALEKSANDR MAKSIMOV	{"phone": "+70881363952"}
0005434265824	5C97D0	8252 296349	ANTONINA IVANOVA	{"phone": "+70083977882"}
0005434265825	E81A24	6498 691755	LILIYA FILATOVA	{"email": "filatova-l_021976@postgrespro.ru", "phone": "+70163930549"}
0005434265826	E81A24	3174 350945	SERGEY GRIGOREV	{"phone": "+70958734610"}
0005434265827	A3D5AB	2528 064768	NIKOLAY BARANOV	{"email": "baranov.n-021971@postgrespro.ru", "phone": "+70677789479"}
0005434265828	B64FAC	3013 603785	ISLAM ROMANOV	{"email": "iromanov.031988@postgrespro.ru", "phone": "+70867133112"}
0005434265829	D5A245	8933 331063	ALEKSEY BONDARENKO	{"phone": "+70073786804"}
0005434265830	6256A0	7630 143481	TATYANA FILATOVA	{"phone": "+70553254676"}
0005434265831	5DCCAE	1687 094530	GALINA ALEKSEEVA	{"phone": "+70631659449"}
0005434265832	FA79C6	4777 783175	ANDREY SHEVCHENKO	{"phone": "+70334806725"}
0005434265833	E50597	8979 411908	SERGEY NIKOLAEV	{"email": "nikolaev_s.1966@postgrespro.ru", "phone": "+70076383150"}
0005434265834	93F1B4	8493 978237	MIKHAIL KONOVALOV	{"email": "konovalov.mikhail_091979@postgrespro.ru", "phone": "+70834017104"}
0005434265835	78FD00	3769 696806	EKATERINA KUZNECOVA	{"phone": "+70723787380"}
0005434265836	44130D	8731 252063	ALEKSANDR BARANOV	{"phone": "+70481138601"}
0005434265837	7E6C7C	5178 222284	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a-021969@postgrespro.ru", "phone": "+70693146720"}
0005434265838	7E6C7C	5391 895306	NIKOLAY GRIGOREV	{"phone": "+70095108201"}
0005434265839	5CB959	7199 062714	VIKTOR FROLOV	{"email": "viktorfrolov-10051975@postgrespro.ru", "phone": "+70106316199"}
0005434265840	E903EE	3735 168920	ALEKSEY VASILEV	{"phone": "+70360108196"}
0005434265841	E903EE	5413 187289	POLINA GRISHINA	{"phone": "+70637675051"}
0005434265842	E903EE	1168 442656	ALEKSANDR KAZAKOV	{"email": "a.kazakov_061968@postgrespro.ru", "phone": "+70516794755"}
0005434265843	A77B4F	0630 735509	SERGEY YAKOVLEV	{"email": "yakovlevs_12091972@postgrespro.ru", "phone": "+70969793917"}
0005434265844	A77B4F	1169 670361	TAMARA TITOVA	{"phone": "+70842546335"}
0005434265845	6F5027	9780 147675	ANNA SMIRNOVA	{"phone": "+70320999332"}
0005434265846	402FB4	8505 120719	YURIY VASILEV	{"email": "yuriyvasilev.1966@postgrespro.ru", "phone": "+70427190796"}
0005434265847	117F03	8752 613066	VERA STEPANOVA	{"phone": "+70504459686"}
0005434265848	117F03	3315 194533	RAISA PETROVA	{"email": "r-petrova.08111977@postgrespro.ru", "phone": "+70470516172"}
0005434265849	381810	9709 465516	EVGENIY TIKHONOV	{"email": "etikhonov_091984@postgrespro.ru", "phone": "+70525320846"}
0005434265850	381810	7062 352144	SERGEY GAVRILOV	{"phone": "+70703179198"}
0005434265851	87DADB	4256 971214	VADIM KUZNECOV	{"email": "vkuznecov-071976@postgrespro.ru", "phone": "+70052309904"}
0005434265852	87DADB	2698 903998	YAROSLAV KUZNECOV	{"phone": "+70197729409"}
0005434265853	87DADB	5929 655564	ANASTASIYA KOROLEVA	{"phone": "+70224605306"}
0005434265854	DF1D53	4905 412016	NIKOLAY MATVEEV	{"email": "matveev_nikolay.1964@postgrespro.ru", "phone": "+70896075646"}
0005434265855	BE7AB9	6683 921558	YURIY DENISOV	{"phone": "+70642245275"}
0005434265856	5F02D6	2363 452899	GALINA SEMENOVA	{"email": "gsemenova-1983@postgrespro.ru", "phone": "+70529938375"}
0005434265857	5F02D6	1542 705757	SVETLANA NOVIKOVA	{"phone": "+70188853991"}
0005434265858	62CDF6	4233 296694	DENIS ABRAMOV	{"email": "abramov-denis_04021973@postgrespro.ru", "phone": "+70202896217"}
0005434265859	38B5AF	0645 821702	SERGEY KOZLOV	{"phone": "+70383041871"}
0005434265860	38B5AF	0149 980394	RIMMA SEMENOVA	{"email": "rimmasemenova-21121978@postgrespro.ru", "phone": "+70693359895"}
0005434265861	8F684E	4035 547708	MARINA KONDRATEVA	{"email": "kondrateva-marina_07091967@postgrespro.ru", "phone": "+70241112191"}
0005434265862	EBC697	3468 469565	KIRILL NAUMOV	{"email": "naumovkirill-14041972@postgrespro.ru", "phone": "+70458246555"}
0005434265863	062B46	9968 736851	ELENA MAKAROVA	{"email": "makarova.elena_1975@postgrespro.ru", "phone": "+70331225541"}
0005434265864	062B46	6955 499882	ALEKSANDRA VASILEVA	{"email": "vasileva_aleksandra10051962@postgrespro.ru", "phone": "+70157273812"}
0005434265865	AB2F99	6986 136768	RAISA CHERNOVA	{"phone": "+70135342949"}
0005434265866	A6881B	0809 570539	MARIYA SAVELEVA	{"email": "m.saveleva-1971@postgrespro.ru", "phone": "+70422046340"}
0005434265867	B9FB42	0440 785930	VALERIY TIKHONOV	{"email": "tikhonov.valeriy-1967@postgrespro.ru", "phone": "+70532689127"}
0005434265868	50E353	4710 796957	EKATERINA ZHUKOVA	{"email": "zhukova-ekaterina-1971@postgrespro.ru", "phone": "+70719370033"}
0005434265869	50E353	2035 935266	PAVEL KUZNECOV	{"email": "kuznecovp_031978@postgrespro.ru", "phone": "+70898156033"}
0005434265870	E16F6A	3984 299497	ALEKSANDR BELOV	{"phone": "+70826780546"}
0005434265871	DF6D43	9558 164414	KRISTINA KULIKOVA	{"phone": "+70625915649"}
0005434265872	DF6D43	4450 420635	PAVEL SEMENOV	{"email": "psemenov.091961@postgrespro.ru", "phone": "+70548201218"}
0005434265873	7626D6	3010 759598	ANNA KOLESNIKOVA	{"email": "a_kolesnikova_121969@postgrespro.ru", "phone": "+70357491580"}
0005434265874	FCDBD7	5721 912462	ANDREY NIKOLAEV	{"phone": "+70461265968"}
0005434265875	FCDBD7	4278 451873	MAKSIM ISAEV	{"email": "isaev_m.11061976@postgrespro.ru", "phone": "+70344049092"}
0005434265876	473F34	0129 591346	MARIYA SIDOROVA	{"phone": "+70891716664"}
0005434265877	7E1B70	6741 451568	OLEG IVANOV	{"email": "ivanov-oleg_12041970@postgrespro.ru", "phone": "+70289557066"}
0005434265878	7E1B70	3196 703027	KLAVDIYA MOROZOVA	{"email": "klavdiya-morozova31101958@postgrespro.ru", "phone": "+70144147627"}
0005434265879	0B5CD5	5032 811962	ALEKSANDR NOVIKOV	{"email": "anovikov.091975@postgrespro.ru", "phone": "+70132091297"}
0005434265880	92E8D7	6520 646080	VALERIY VOROBEV	{"email": "v.vorobev_20071978@postgrespro.ru", "phone": "+70325247517"}
0005434265881	6AE0E0	3532 083752	TATYANA SIDOROVA	{"email": "sidorova.t1970@postgrespro.ru", "phone": "+70196093318"}
0005434265882	A2635D	0637 657093	OLGA NIKITINA	{"email": "o-nikitina.1978@postgrespro.ru", "phone": "+70237136152"}
0005434265883	E7BBAA	4247 541355	OLGA NAZAROVA	{"phone": "+70559725571"}
0005434265884	154B32	5597 018752	NIKOLAY NAUMOV	{"phone": "+70735820428"}
0005434265885	CF0CFE	8082 944303	LIDIYA PETROVA	{"phone": "+70678728850"}
0005434265886	CF0CFE	9537 605854	ANDREY IVANOV	{"phone": "+70181197383"}
0005434265887	03AF22	3053 349559	VLADIMIR VOLKOV	{"email": "volkovv_11011972@postgrespro.ru", "phone": "+70784865829"}
0005434265888	059146	6802 919505	YURIY ZAYCEV	{"phone": "+70265618836"}
0005434265889	059146	7472 680853	GALINA BORISOVA	{"phone": "+70907022780"}
0005434265890	F08CBD	4126 207046	VLADIMIR PAVLOV	{"email": "vladimir-pavlov_04111966@postgrespro.ru", "phone": "+70455210025"}
0005434265891	F08CBD	3649 274926	ILYA ABRAMOV	{"phone": "+70038613654"}
0005434265892	65E861	3316 582834	NATALYA PAVLOVA	{"email": "natalyapavlova.1968@postgrespro.ru", "phone": "+70632891043"}
0005434265893	BA7228	7227 569017	MIKHAIL ZAYCEV	{"email": "mikhail.zaycev06111959@postgrespro.ru", "phone": "+70303631037"}
0005434265894	2E7EDE	4599 177881	ALEKSEY PETROV	{"email": "petrova_21061962@postgrespro.ru", "phone": "+70110415915"}
0005434265895	2E7EDE	6658 018147	ANDREY KRASNOV	{"email": "krasnov_a-061971@postgrespro.ru", "phone": "+70298985471"}
0005434265896	9FA73E	3291 239557	VITALIY GORBUNOV	{"email": "gorbunov-vitaliy.1987@postgrespro.ru", "phone": "+70773435746"}
0005434265897	9FA73E	4066 281472	OLGA TARASOVA	{"phone": "+70611226357"}
0005434265898	E573C9	9130 934894	ANASTASIYA NIKITINA	{"phone": "+70643085136"}
0005434265899	47FD37	0668 527470	NATALYA KOZLOVA	{"phone": "+70060633399"}
0005434265900	47FD37	9517 045713	VLADIMIR KISELEV	{"email": "kiselev_v_15041965@postgrespro.ru", "phone": "+70770786760"}
0005434265901	3E8354	1426 739251	ALEKSANDR ALEKSANDROV	{"email": "aleksandrova-29101977@postgrespro.ru", "phone": "+70677812799"}
0005434265902	3E8354	7826 030793	GENNADIY MOROZOV	{"email": "gennadiy-morozov1967@postgrespro.ru", "phone": "+70079842011"}
0005434265903	020F5B	7122 081816	ELENA IVANOVA	{"email": "elena.ivanova.1983@postgrespro.ru", "phone": "+70230338528"}
0005434265904	020F5B	3523 457660	ELENA AFANASEVA	{"phone": "+70426675990"}
0005434265914	5E2DF5	1264 668095	ANTONIDA GERASIMOVA	{"email": "antonida-gerasimova_101970@postgrespro.ru", "phone": "+70468796164"}
0005434265915	0953B9	5645 146977	VLADISLAV SMIRNOV	{"email": "vladislav.smirnov101971@postgrespro.ru", "phone": "+70344909552"}
0005434265916	0953B9	1302 477352	ANASTASIYA SCHERBAKOVA	{"email": "scherbakovaa_1978@postgrespro.ru", "phone": "+70358849118"}
0005434265917	84FB2C	1918 472366	YULIYA BORISOVA	{"email": "yuliyaborisova23061976@postgrespro.ru", "phone": "+70907340731"}
0005434265918	84FB2C	4815 366718	SERGEY MIKHAYLOV	{"phone": "+70232165754"}
0005434265919	84FB2C	1375 776874	LEONID NIKOLAEV	{"email": "nikolaev_l-14061969@postgrespro.ru", "phone": "+70073268699"}
0005434265920	2CA1F1	2240 636471	FANIL KAZAKOV	{"phone": "+70039886874"}
0005434265921	2CA1F1	3986 902198	KIRILL MEDVEDEV	{"email": "kirillmedvedev.07021971@postgrespro.ru", "phone": "+70343799334"}
0005434265922	2CA1F1	4513 247023	VLADIMIR POPOV	{"phone": "+70389890009"}
0005434265923	09C899	5925 048927	DMITRIY SAVELEV	{"phone": "+70149889747"}
0005434265924	654D49	5059 025775	NELLI VOLKOVA	{"phone": "+70281906453"}
0005434265925	8F26F1	3497 192838	LYUBOV GORBUNOVA	{"email": "l.gorbunova-031978@postgrespro.ru", "phone": "+70983979202"}
0005434265926	8F26F1	9515 995285	ELENA POPOVA	{"email": "popova-elena_031971@postgrespro.ru", "phone": "+70211850328"}
0005434265927	32D087	5616 309476	VIKTOR KOROLEV	{"email": "v-korolev25071983@postgrespro.ru", "phone": "+70955065707"}
0005434265928	32D087	5001 335385	MATRENA GAVRILOVA	{"email": "gavrilovamatrena_03081970@postgrespro.ru", "phone": "+70382261868"}
0005434265929	B3E0CF	9189 708675	ALEKSEY NIKITIN	{"email": "a.nikitin121981@postgrespro.ru", "phone": "+70002478080"}
0005434265930	B3E0CF	0875 686144	VERA SMIRNOVA	{"email": "smirnova_vera.1981@postgrespro.ru", "phone": "+70467984546"}
0005434265931	B3E0CF	7444 703365	VALENTINA ANTONOVA	{"phone": "+70787365949"}
0005434265932	9776BA	5963 307708	RAFIK GRIGOREV	{"email": "rafik-grigorev1962@postgrespro.ru", "phone": "+70060066174"}
0005434265933	0D2FAF	0995 567502	RUSLAN GORBUNOV	{"phone": "+70393402297"}
0005434265934	0D2FAF	3781 093191	OLEG SCHERBAKOV	{"phone": "+70247667245"}
0005434265935	151F94	2425 205070	NIKITA MELNIKOV	{"phone": "+70105509364"}
0005434265936	151F94	9726 880342	EVGENIY DAVYDOV	{"email": "davydov-evgeniy_031966@postgrespro.ru", "phone": "+70526026896"}
0005434265937	A993E3	7687 673367	ALEKSANDR BORISOV	{"email": "aleksandr_borisov1972@postgrespro.ru", "phone": "+70123819968"}
0005434265938	A993E3	3858 274663	SERGEY KOZLOV	{"email": "kozlov.sergey.041967@postgrespro.ru", "phone": "+70303832371"}
0005434265939	CFE173	8890 442277	TATYANA KARPOVA	{"phone": "+70119473441"}
0005434265940	CFE173	0393 837806	ZULFIYA ANDREEVA	{"phone": "+70574173297"}
0005434265941	3C30A1	9829 967514	VYACHESLAV NOVIKOV	{"phone": "+70858328265"}
0005434265942	B091C6	0187 959023	NATALYA CHERNOVA	{"phone": "+70956561444"}
0005434265943	B091C6	6562 460214	EVGENIY VOROBEV	{"email": "evgeniy_vorobev-021975@postgrespro.ru", "phone": "+70421201735"}
0005434265944	A47A71	2227 489609	NATALYA ZHUKOVA	{"email": "zhukova-natalya-06051969@postgrespro.ru", "phone": "+70833862068"}
0005434265945	A47A71	1506 307744	IVAN GORBUNOV	{"email": "ivangorbunov-24101964@postgrespro.ru", "phone": "+70223840466"}
0005434265946	0497F2	6041 644976	ANNA DANILOVA	{"email": "danilova.a1980@postgrespro.ru", "phone": "+70423518695"}
0005434265947	174766	1520 264111	VADIM VASILEV	{"email": "vasilev_vadim-28061980@postgrespro.ru", "phone": "+70882791299"}
0005434265948	174766	8765 021698	TATYANA KOROLEVA	{"email": "koroleva-tatyana-1960@postgrespro.ru", "phone": "+70257994868"}
0005434265949	C1C2DF	5752 656671	RAISA KUZNECOVA	{"phone": "+70239500710"}
0005434265950	9CBC63	7922 955660	OKSANA DENISOVA	{"email": "odenisova.02011971@postgrespro.ru", "phone": "+70155963659"}
0005434265951	9CBC63	2994 248130	VYACHESLAV TIKHONOV	{"email": "vyacheslav.tikhonov.031969@postgrespro.ru", "phone": "+70675423647"}
0005434265952	D54E38	4212 508922	SERGEY NAZAROV	{"phone": "+70296408321"}
0005434265953	61815F	0192 788500	ALBINA VASILEVA	{"phone": "+70051551958"}
0005434265954	61815F	6915 698865	IRINA KUZMINA	{"email": "kuzmina.irina.031980@postgrespro.ru", "phone": "+70208229598"}
0005434265955	092950	8491 504288	VLADIMIR KOZLOV	{"email": "kozlov-vladimir_01011974@postgrespro.ru", "phone": "+70638123627"}
0005434265956	F269EF	4318 107649	VALERIY SIDOROV	{"email": "sidorovvaleriy1968@postgrespro.ru", "phone": "+70375443111"}
0005434265957	4A19AC	8902 297492	DMITRIY TARASOV	{"email": "tarasov.dmitriy-23071965@postgrespro.ru", "phone": "+70434623696"}
0005434265958	B2B05F	7929 830061	GRIGORIY GAVRILOV	{"phone": "+70394542716"}
0005434265959	A9B652	9656 721559	VERA LEBEDEVA	{"phone": "+70091337082"}
0005434265960	8C5BB6	4025 609495	OKSANA FILIPPOVA	{"phone": "+70676555452"}
0005434265961	7A0926	5488 868618	MAKSIM ORLOV	{"email": "maksim.orlov011973@postgrespro.ru", "phone": "+70077469460"}
0005434265962	7A0926	3178 251457	VALENTINA GRISHINA	{"email": "grishinav_051967@postgrespro.ru", "phone": "+70041084122"}
0005434265963	3E52D7	6002 890674	ILYA ANDREEV	{"email": "ilya-andreev.1976@postgrespro.ru", "phone": "+70313057300"}
0005434265964	2516FF	2781 903030	ANDREY KAZAKOV	{"email": "andrey_kazakov.1972@postgrespro.ru", "phone": "+70893380174"}
0005434265965	0D5E43	5132 872480	SERGEY GERASIMOV	{"phone": "+70271825960"}
0005434265966	0D5E43	0620 141343	ILYA SOKOLOV	{"email": "i.sokolov-121982@postgrespro.ru", "phone": "+70797406202"}
0005434265967	0D5E43	0713 821382	GEORGIY GERASIMOV	{"phone": "+70616091057"}
0005434265968	AD7CDF	7411 079478	IGOR SOKOLOV	{"email": "sokolov.igor_1966@postgrespro.ru", "phone": "+70380822604"}
0005434265969	044C2A	6729 266949	RAISA ALEKSEEVA	{"email": "r_alekseeva.1974@postgrespro.ru", "phone": "+70666062546"}
0005434265970	D2CFF4	6074 272411	ELENA NAZAROVA	{"email": "nazarovae-1970@postgrespro.ru", "phone": "+70533139108"}
0005434265971	91825B	3557 789534	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev.061972@postgrespro.ru", "phone": "+70113715864"}
0005434265972	91825B	7393 936970	DENIS YAKOVLEV	{"email": "yakovlev_denis-23031980@postgrespro.ru", "phone": "+70327896503"}
0005434265973	B805D5	7907 387179	ALEFTINA TROFIMOVA	{"email": "trofimova.aleftina.09111956@postgrespro.ru", "phone": "+70743796604"}
0005434265974	71693D	1300 238168	IRINA LAZAREVA	{"email": "lazareva.i_03031972@postgrespro.ru", "phone": "+70174090124"}
0005434265975	71693D	3486 864224	TATYANA IVANOVA	{"phone": "+70077348214"}
0005434265976	F2E1C4	2401 543068	ANNA KONOVALOVA	{"email": "konovalovaa-14021959@postgrespro.ru", "phone": "+70157542563"}
0005434265977	F2E1C4	1294 026494	IGOR FOMIN	{"phone": "+70959217764"}
0005434265978	4738E6	7224 657948	VLADIMIR KISELEV	{"email": "kiselev-v.011976@postgrespro.ru", "phone": "+70287933079"}
0005434265979	4FA3B5	4208 592862	VLADISLAV ZHUKOV	{"email": "zhukovvladislav.30111976@postgrespro.ru", "phone": "+70409360363"}
0005434265980	211C9D	4514 202416	TATYANA SERGEEVA	{"email": "t_sergeeva.02101976@postgrespro.ru", "phone": "+70472623481"}
0005434265981	E7F3A6	2120 842370	NAILYA ISAEVA	{"phone": "+70424529331"}
0005434265982	D8063A	0167 987200	MARIYA NIKIFOROVA	{"phone": "+70328562699"}
0005434265983	D8063A	7344 797489	ILYA VASILEV	{"phone": "+70210177895"}
0005434265984	D8063A	3746 710708	VALERIYA BELOVA	{"phone": "+70663291576"}
0005434265985	001932	9237 503202	TATYANA MALYSHEVA	{"email": "tmalysheva_31121965@postgrespro.ru", "phone": "+70483243138"}
0005434265986	07BD70	9246 379011	IGOR PAVLOV	{"phone": "+70161657187"}
0005434265987	E21D58	2334 494062	SERGEY NIKOLAEV	{"email": "sergey-nikolaev.14121965@postgrespro.ru", "phone": "+70043911562"}
0005434265988	E21D58	2997 247234	NATALYA MEDVEDEVA	{"phone": "+70243627146"}
0005434265989	5A8C8E	8372 747868	RAVIL EGOROV	{"email": "r-egorov.23051960@postgrespro.ru", "phone": "+70134952217"}
0005434265990	6E79C6	8353 015617	NATALYA KOROLEVA	{"phone": "+70748373492"}
0005434265991	6E79C6	9248 513096	IVAN SIDOROV	{"email": "ivansidorov-1975@postgrespro.ru", "phone": "+70655319342"}
0005434265992	6E79C6	8668 284582	VALENTINA ERMAKOVA	{"phone": "+70444890787"}
0005434265993	A069DB	3534 203482	MIKHAIL ZAKHAROV	{"email": "m-zakharov_1973@postgrespro.ru", "phone": "+70271091425"}
0005434265994	950B44	7058 695029	SERGEY SOKOLOV	{"phone": "+70593299651"}
0005434265995	31F0DE	8320 831267	DMITRIY YAKOVLEV	{"phone": "+70060789469"}
0005434265996	31F0DE	2349 530787	RAFIS KULIKOV	{"phone": "+70259306055"}
0005434265997	BAA8EF	3852 498373	MARINA RYABOVA	{"phone": "+70799325453"}
0005434265998	BAA8EF	9149 032758	FARID ZAKHAROV	{"email": "farid_zakharov-1977@postgrespro.ru", "phone": "+70200764758"}
0005434265999	642D31	0696 844628	ANDREY MAKAROV	{"email": "makarov.a.091973@postgrespro.ru", "phone": "+70542779508"}
0005434266000	8154A5	0547 120305	TATYANA IVANOVA	{"email": "t-ivanova011973@postgrespro.ru", "phone": "+70201466767"}
0005434266001	8154A5	5709 769102	SERGEY VOLKOV	{"phone": "+70159241868"}
0005434266002	EAF48B	9181 582382	ANNA KUZMINA	{"email": "a_kuzmina_031972@postgrespro.ru", "phone": "+70435027188"}
0005434266003	AC265C	0840 095617	NATALYA KARPOVA	{"phone": "+70366883673"}
0005434266004	AC265C	1413 931185	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.031978@postgrespro.ru", "phone": "+70214179654"}
0005434266005	664E0E	0327 965178	OLGA DANILOVA	{"phone": "+70730118932"}
0005434266006	664E0E	1150 018075	LYUDMILA MASLOVA	{"phone": "+70141771704"}
0005434266007	664E0E	0169 813082	SERGEY ISAEV	{"phone": "+70375173652"}
0005434266008	47A28C	8482 694651	YULIYA ZAKHAROVA	{"phone": "+70661302430"}
0005434266009	1BFAE0	1575 317236	SVETLANA IVANOVA	{"phone": "+70208495717"}
0005434266010	1BFAE0	4397 288542	NATALYA POPOVA	{"email": "popova_n1983@postgrespro.ru", "phone": "+70271632885"}
0005434266011	C918BC	1605 457125	VALERIY KUZNECOV	{"phone": "+70603517443"}
0005434266012	7045AB	7003 721707	EVGENIY YAKOVLEV	{"phone": "+70554494091"}
0005434266013	6E3507	4885 181027	NIKOLAY SEMENOV	{"phone": "+70509079767"}
0005434266014	6E3507	1470 096028	ALEKSANDRA ROMANOVA	{"email": "romanova-a011978@postgrespro.ru", "phone": "+70584212057"}
0005434266015	90733C	7722 531793	VALENTINA SOROKINA	{"phone": "+70848125327"}
0005434266016	90733C	3042 466143	NELLI DANILOVA	{"phone": "+70233334149"}
0005434266017	28683A	5920 980361	ANNA MAKSIMOVA	{"email": "a-maksimova.071983@postgrespro.ru", "phone": "+70211148013"}
0005434266018	28683A	5373 317154	DANIL GRIGOREV	{"phone": "+70853842443"}
0005434266019	28683A	5361 248057	NIKOLAY SIDOROV	{"email": "n.sidorov.041971@postgrespro.ru", "phone": "+70902859776"}
0005434266020	16EDB7	1668 224765	YURIY BONDARENKO	{"email": "bondarenko-y_1975@postgrespro.ru", "phone": "+70991093423"}
0005434266021	16EDB7	6786 052208	ANTON YAKOVLEV	{"email": "yakovlev_a-1974@postgrespro.ru", "phone": "+70257027442"}
0005434266022	796ECE	4224 965360	ARTEM KULIKOV	{"email": "a.kulikov_1966@postgrespro.ru", "phone": "+70792373163"}
0005434266023	441DC8	7889 859861	YURIY MELNIKOV	{"phone": "+70997367570"}
0005434266024	441DC8	6249 543924	MARINA KONOVALOVA	{"email": "konovalova-marina-26041973@postgrespro.ru", "phone": "+70230242521"}
0005434266025	20A8A8	5506 791866	LYUBOV MALYSHEVA	{"email": "malyshevalyubov-101974@postgrespro.ru", "phone": "+70319191505"}
0005434266026	20A8A8	1981 947753	SERGEY MATVEEV	{"email": "s.matveev031972@postgrespro.ru", "phone": "+70320550571"}
0005434266027	A19F77	3831 299923	ALEKSANDR BELOV	{"email": "belov-a_19071976@postgrespro.ru", "phone": "+70742414128"}
0005434266028	ABFED7	4219 438916	NATALYA STEPANOVA	{"email": "stepanova-natalya23101977@postgrespro.ru", "phone": "+70192751580"}
0005434266029	DFA4B5	1382 178127	ELIZAVETA DMITRIEVA	{"phone": "+70083129807"}
0005434266030	FB18E8	0683 933558	ELENA EFIMOVA	{"phone": "+70665922453"}
0005434266031	FB18E8	0421 296811	ANTON SERGEEV	{"phone": "+70338848375"}
0005434266032	CE66F1	6413 773715	OLGA ABRAMOVA	{"email": "olga.abramova-16071978@postgrespro.ru", "phone": "+70639032665"}
0005434266033	CE66F1	3558 744795	IRINA LAZAREVA	{"email": "lazareva-irina.25121976@postgrespro.ru", "phone": "+70173485836"}
0005434266034	1F2DA3	0107 111019	NINA SOLOVEVA	{"phone": "+70021070085"}
0005434266035	9E84DD	2511 860026	YURIY EGOROV	{"phone": "+70817314343"}
0005434266036	9E84DD	5666 417745	VLADIMIR KOZLOV	{"email": "vladimir.kozlov-1971@postgrespro.ru", "phone": "+70430405886"}
0005434266037	4E0865	3115 603503	LEONID ROMANOV	{"phone": "+70359059185"}
0005434266038	680675	8879 147035	YURIY VASILEV	{"phone": "+70588984743"}
0005434266039	CCC2E0	0403 019388	MIKHAIL NAUMOV	{"email": "m.naumov-021969@postgrespro.ru", "phone": "+70897541652"}
0005434266040	3353DC	2617 581593	ANTON EGOROV	{"email": "antonegorov_15111972@postgrespro.ru", "phone": "+70739652562"}
0005434266041	37C50C	2587 106146	VALENTINA SOLOVEVA	{"phone": "+70027644613"}
0005434266042	37C50C	1603 442801	PETR KARPOV	{"phone": "+70755528812"}
0005434266043	E88133	8574 061038	VITALIY TARASOV	{"phone": "+70229210066"}
0005434266044	304732	4674 061792	NADEZHDA KOROLEVA	{"email": "n-koroleva.061967@postgrespro.ru", "phone": "+70117032972"}
0005434266045	304732	1826 869235	VLADIMIR IVANOV	{"phone": "+70114722448"}
0005434266046	150019	4925 607820	IVAN KOROLEV	{"phone": "+70256262186"}
0005434266047	7873D1	9315 014832	KONSTANTIN BARANOV	{"email": "k.baranov081972@postgrespro.ru", "phone": "+70526584769"}
0005434266048	C879BF	0633 184197	ALEKSEY STEPANOV	{"email": "a_stepanov15011976@postgrespro.ru", "phone": "+70023147241"}
0005434266049	C879BF	1792 583042	OLGA ZHURAVLEVA	{"email": "olga-zhuravleva-09011977@postgrespro.ru", "phone": "+70068068443"}
0005434266050	C879BF	0533 326114	YURIY DAVYDOV	{"phone": "+70151766190"}
0005434266051	D7A5FD	1365 476514	NADEZHDA POPOVA	{"phone": "+70143771254"}
0005434266052	04131A	6978 540864	LYUDMILA FILATOVA	{"email": "filatova_l.03041985@postgrespro.ru", "phone": "+70757848789"}
0005434266053	04131A	1810 971095	DARYA NIKIFOROVA	{"phone": "+70591768660"}
0005434266054	D6762E	0369 012223	ILYA GUSEV	{"email": "gusev.i_11111969@postgrespro.ru", "phone": "+70223188639"}
0005434266055	D6762E	1871 360339	VITALIY FEDOROV	{"email": "vitaliyfedorov.23061972@postgrespro.ru", "phone": "+70202626151"}
0005434266056	1A2526	5775 460666	SVETLANA ALEKSANDROVA	{"phone": "+70429172625"}
0005434266057	1A2526	5746 629397	ANDREY ROMANOV	{"email": "romanov.andrey.011968@postgrespro.ru", "phone": "+70001117311"}
0005434267884	3AD109	9189 024594	GENNADIY MEDVEDEV	{"phone": "+70351173405"}
0005434267885	A7519A	6492 874998	VIKTOR SOKOLOV	{"email": "sokolov.viktor-17051980@postgrespro.ru", "phone": "+70402920423"}
0005434267886	7847A2	0822 656493	OLGA FROLOVA	{"phone": "+70530077874"}
0005434267887	C6BCC5	2207 056493	EKATERINA KUZMINA	{"email": "ekaterina.kuzmina.14071981@postgrespro.ru", "phone": "+70563840835"}
0005434267888	DC5B83	2543 193748	VALERIY DMITRIEV	{"phone": "+70467065271"}
0005434267889	0D473C	5606 899133	ROMAN TARASOV	{"email": "roman_tarasov.1976@postgrespro.ru", "phone": "+70493631330"}
0005434267890	C4A27C	4723 926517	SVETLANA KOROLEVA	{"phone": "+70428273662"}
0005434267891	FE3010	8620 065298	EGOR MIKHAYLOV	{"email": "e-mikhaylov11101974@postgrespro.ru", "phone": "+70163862653"}
0005434267892	30574F	5919 680157	AZAT ROMANOV	{"phone": "+70450465547"}
0005434267893	499D73	4112 008885	NATALYA VLASOVA	{"email": "natalya.vlasova-11071974@postgrespro.ru", "phone": "+70426948063"}
0005434267894	E11BFD	1198 585476	ALEKSANDR RODIONOV	{"phone": "+70008808103"}
0005434267895	31EA04	5398 147379	ELENA FILATOVA	{"email": "elena_filatova20031968@postgrespro.ru", "phone": "+70114718888"}
0005434267896	4597A2	7196 487454	VALENTINA TIKHONOVA	{"email": "v.tikhonova-1969@postgrespro.ru", "phone": "+70562128965"}
0005434267897	4597A2	4818 917071	YULIYA KOMAROVA	{"email": "ykomarova1977@postgrespro.ru", "phone": "+70375076733"}
0005434267898	4597A2	4152 146398	DARYA BARANOVA	{"email": "dbaranova01041960@postgrespro.ru", "phone": "+70428202980"}
0005434267899	5AF166	9006 499196	ALINA GUSEVA	{"phone": "+70015089429"}
0005434267900	932F62	3825 170804	NATALYA PETROVA	{"email": "petrova_natalya071979@postgrespro.ru", "phone": "+70155851797"}
0005434267901	62B3FF	2061 618999	VLADIMIR GERASIMOV	{"email": "vladimir.gerasimov_1980@postgrespro.ru", "phone": "+70616442222"}
0005434267902	50F8DA	4214 653876	ELENA ZAKHAROVA	{"phone": "+70270336319"}
0005434267903	50F8DA	8186 254761	ALEKSANDR VOROBEV	{"phone": "+70548883171"}
0005434267904	4CECFB	3276 257265	ANGELINA EGOROVA	{"email": "egorovaangelina11051967@postgrespro.ru", "phone": "+70123606552"}
0005434267905	4CECFB	8223 026124	ILYA POPOV	{"email": "popovilya_02011974@postgrespro.ru", "phone": "+70789927718"}
0005434267906	346AA1	1023 251849	POLINA MOROZOVA	{"email": "polinamorozova.1972@postgrespro.ru", "phone": "+70922670256"}
0005434267907	346AA1	2963 218678	MARIYA GERASIMOVA	{"email": "m-gerasimova.1969@postgrespro.ru", "phone": "+70393771463"}
0005434267908	251794	7010 805460	GENNADIY DENISOV	{"email": "gennadiy.denisov1968@postgrespro.ru", "phone": "+70701359610"}
0005434267909	C1A7C1	3817 818870	YULIYA TROFIMOVA	{"phone": "+70527678196"}
0005434267910	C1A7C1	3602 005543	VIKTORIYA NAUMOVA	{"email": "naumovav_23111978@postgrespro.ru", "phone": "+70571728332"}
0005434267911	31B6AF	1549 723680	NATALYA KOZLOVA	{"phone": "+70719856284"}
0005434267912	31B6AF	9233 263878	ELENA MAKAROVA	{"email": "makarovaelena_04041975@postgrespro.ru", "phone": "+70988250709"}
0005434267913	B8ACE8	1942 502509	YURIY YAKOVLEV	{"email": "y_yakovlev-1971@postgrespro.ru", "phone": "+70717840528"}
0005434267914	CC68AC	2598 350899	ANTONINA IVANOVA	{"email": "a_ivanova_111970@postgrespro.ru", "phone": "+70311459798"}
0005434267915	743132	7472 033816	YULIYA KUZNECOVA	{"phone": "+70831098444"}
0005434267916	743132	9166 339328	NINA PETROVA	{"phone": "+70848095506"}
0005434267917	743132	2041 210272	ANASTASIYA ZHUKOVA	{"email": "a-zhukova.1978@postgrespro.ru", "phone": "+70560460049"}
0005434267918	04C575	1261 611121	VALENTINA MIKHAYLOVA	{"email": "mikhaylova.v_081972@postgrespro.ru", "phone": "+70700071197"}
0005434267919	5D4F11	6300 212371	SERGEY ANTONOV	{"phone": "+70580849279"}
0005434267920	BE84B3	0898 471197	SVETLANA KOROLEVA	{"email": "svetlana.koroleva_101987@postgrespro.ru", "phone": "+70822100010"}
0005434267921	BE84B3	9925 275179	IRINA POTAPOVA	{"phone": "+70851889265"}
0005434267922	4D6E60	6591 567802	OLGA CHERNOVA	{"email": "ochernova.07061963@postgrespro.ru", "phone": "+70090818084"}
0005434267923	4D6E60	1931 991744	SERGEY GERASIMOV	{"email": "sergey.gerasimov.18031977@postgrespro.ru", "phone": "+70710350485"}
0005434267924	74642F	0596 009321	ANDREY SOKOLOV	{"email": "sokolov.andrey.04021974@postgrespro.ru", "phone": "+70002465266"}
0005434267925	E86482	0056 094111	NATALYA MAKAROVA	{"phone": "+70036166714"}
0005434267926	36BBE0	0377 471282	ELENA ERMAKOVA	{"phone": "+70469524723"}
0005434267927	36BBE0	1917 191055	SVETLANA SMIRNOVA	{"phone": "+70229302766"}
0005434267928	E7E77B	6265 855296	YURIY NAUMOV	{"phone": "+70845251066"}
0005434267929	E7E77B	1014 705848	YURIY MEDVEDEV	{"phone": "+70669520803"}
0005434267930	B88FE5	9251 556516	VALERIY IVANOV	{"email": "valeriy-ivanov17081977@postgrespro.ru", "phone": "+70366018622"}
0005434267931	B88FE5	2023 168638	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy19041963@postgrespro.ru", "phone": "+70528852029"}
0005434267932	2E6CD4	1720 493055	VLADIMIR ABRAMOV	{"phone": "+70500235822"}
0005434267933	4C270E	9994 504138	NINA POTAPOVA	{"email": "n-potapova_1964@postgrespro.ru", "phone": "+70309955845"}
0005434267934	4C270E	5006 863640	YULIYA KOZLOVA	{"email": "kozlova_yuliya-02021971@postgrespro.ru", "phone": "+70151929787"}
0005434267935	4C270E	3902 128505	YURIY PETROV	{"phone": "+70964664249"}
0005434267936	6979D8	0436 740620	EVGENIY SMIRNOV	{"phone": "+70955942152"}
0005434267937	603558	9600 840392	VLADISLAV MARTYNOV	{"phone": "+70971409504"}
0005434267938	72C064	1264 230422	IVAN BORISOV	{"email": "ivan.borisov-121971@postgrespro.ru", "phone": "+70843952099"}
0005434267939	949736	4224 978486	VALERIY MATVEEV	{"email": "matveevvaleriy-16051981@postgrespro.ru", "phone": "+70366064099"}
0005434267940	ADABD4	6855 776590	ARTEM GORBUNOV	{"email": "a.gorbunov13061967@postgrespro.ru", "phone": "+70650882270"}
0005434267941	E72FC3	1646 266205	MIKHAIL NOVIKOV	{"email": "novikov.m1977@postgrespro.ru", "phone": "+70848195368"}
0005434267942	E72FC3	9682 821442	DARYA MARTYNOVA	{"email": "martynova-d.1966@postgrespro.ru", "phone": "+70509358905"}
0005434267943	DD9FA7	7002 508909	VLADIMIR DENISOV	{"phone": "+70719189568"}
0005434267944	2EDA5B	3564 320523	VIKTOR PAVLOV	{"email": "v_pavlov071983@postgrespro.ru", "phone": "+70904640827"}
0005434267945	2EDA5B	7402 593936	NATALYA NAUMOVA	{"phone": "+70709991659"}
0005434267946	3C64E7	0772 278930	SERGEY PAVLOV	{"phone": "+70532781489"}
0005434267947	3C64E7	3287 611050	DARYA TARASOVA	{"phone": "+70967967750"}
0005434267948	DF0786	5310 962246	SVETLANA KUZNECOVA	{"email": "kuznecova.s011974@postgrespro.ru", "phone": "+70204254235"}
0005434267949	58693D	8676 143385	ANNA NOVIKOVA	{"email": "novikova-a111979@postgrespro.ru", "phone": "+70637810487"}
0005434267950	58693D	6234 148351	ALEKSANDR SAVELEV	{"email": "a_savelev04071968@postgrespro.ru", "phone": "+70611777342"}
0005434267951	D68E09	7655 847348	ANASTASIYA IVANOVA	{"phone": "+70970398773"}
0005434267952	B2F91E	0021 781131	SERGEY SOKOLOV	{"phone": "+70106196099"}
0005434267953	28A0E0	5310 680966	SERGEY NOVIKOV	{"email": "novikov.s.1975@postgrespro.ru", "phone": "+70900466160"}
0005434267954	85DA4F	8643 910212	TATYANA KOROLEVA	{"phone": "+70254513143"}
0005434267955	B21929	1907 286056	MAKSIM EGOROV	{"phone": "+70515559110"}
0005434267956	43E30E	5031 363879	ALEKSANDRA VASILEVA	{"email": "vasileva-a081975@postgrespro.ru", "phone": "+70174333912"}
0005434267957	312337	7826 180201	NIKOLAY SEMENOV	{"email": "semenovn-13021959@postgrespro.ru", "phone": "+70240349579"}
0005434267958	E2FDF7	2050 554781	VALENTINA VOLKOVA	{"phone": "+70059221516"}
0005434267959	E2FDF7	5571 251955	DMITRIY KUZMIN	{"phone": "+70314451392"}
0005434267960	309341	3811 498813	OLESYA NIKITINA	{"email": "nikitina_o_04091966@postgrespro.ru", "phone": "+70556861306"}
0005434267961	3CF9B6	2415 613481	ELENA TIMOFEEVA	{"email": "timofeeva.elena-1972@postgrespro.ru", "phone": "+70780958169"}
0005434267962	1E72CD	6205 743241	MIKHAIL KUZNECOV	{"phone": "+70360090985"}
0005434267963	783BC0	2530 409017	SANIYA SERGEEVA	{"phone": "+70907540263"}
0005434267964	302D72	7356 674955	NIKOLAY PAVLOV	{"email": "pavlov-nikolay_26061984@postgrespro.ru", "phone": "+70505840060"}
0005434267965	73E398	1872 310576	SERGEY GUSEV	{"email": "gusevs1982@postgrespro.ru", "phone": "+70554680366"}
0005434267966	7A6ADD	2493 929232	LYUBOV ABRAMOVA	{"phone": "+70954352487"}
0005434267967	F1F25D	7380 159479	NATALYA KOZLOVA	{"phone": "+70635061166"}
0005434267968	4E9117	5893 800952	EKATERINA SEMENOVA	{"phone": "+70026334619"}
0005434267969	4E9117	9725 535024	VIKTOR SOLOVEV	{"email": "solovev-viktor111978@postgrespro.ru", "phone": "+70197707473"}
0005434267970	213CC7	0788 240840	OKSANA VASILEVA	{"phone": "+70210315975"}
0005434267971	A9A966	1494 341151	NINA ARKHIPOVA	{"email": "nina.arkhipova_13071968@postgrespro.ru", "phone": "+70576546861"}
0005434267972	A9A966	4780 619453	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov_1965@postgrespro.ru", "phone": "+70129112646"}
0005434267973	A9A966	4327 552520	ELENA VOLKOVA	{"email": "evolkova-091979@postgrespro.ru", "phone": "+70404780927"}
0005434267974	DBA8F3	0144 500361	ANTONINA ANISIMOVA	{"phone": "+70023361366"}
0005434267975	AD68BB	9859 376729	OLGA FADEEVA	{"email": "fadeeva-olga1987@postgrespro.ru", "phone": "+70592021507"}
0005434267976	D80B14	2887 196009	SERGEY KARPOV	{"phone": "+70092184151"}
0005434267977	D630CA	7407 883501	ANDREY TARASOV	{"phone": "+70593697927"}
0005434267978	A3BD23	6683 198794	NATALYA PAVLOVA	{"phone": "+70042769323"}
0005434267979	B39860	1336 564397	ELVIRA POPOVA	{"phone": "+70271532192"}
0005434267980	B39860	1396 681962	RUSLAN SEMENOV	{"email": "semenov-r1980@postgrespro.ru", "phone": "+70947110931"}
0005434267981	26D6C2	1505 360742	DMITRIY MOISEEV	{"phone": "+70156907032"}
0005434267982	F1C2A5	6892 159905	DARYA CHERNOVA	{"phone": "+70398133055"}
0005434267983	025809	4817 267435	TATYANA STEPANOVA	{"phone": "+70940716912"}
0005434267984	025809	5969 022416	VERA BELOVA	{"phone": "+70380533518"}
0005434267985	F64751	4597 072674	RASHID SCHERBAKOV	{"email": "scherbakov.r-1962@postgrespro.ru", "phone": "+70777791498"}
0005434267986	800876	4474 470520	VYACHESLAV SHEVCHENKO	{"phone": "+70933202325"}
0005434267987	A49B7C	2340 565115	MIKHAIL MAKAROV	{"phone": "+70956698018"}
0005434267988	E0E91E	1563 850397	VALENTINA TIKHONOVA	{"phone": "+70682078108"}
0005434267989	E0E91E	8941 860548	TATYANA CHERNOVA	{"phone": "+70418818688"}
0005434267990	EDFB15	4896 517713	MARINA NIKOLAEVA	{"email": "m_nikolaeva_1974@postgrespro.ru", "phone": "+70282810497"}
0005434267991	076357	4762 774153	VLADIMIR SAVELEV	{"phone": "+70501352633"}
0005434267992	573D88	7187 533176	SERGEY GRIGOREV	{"email": "grigorevs_06041968@postgrespro.ru", "phone": "+70011550051"}
0005434267993	573D88	7456 630864	EVGENIYA STEPANOVA	{"email": "stepanova.evgeniya_1966@postgrespro.ru", "phone": "+70589613849"}
0005434267994	573D88	2976 150109	SERGEY SEMENOV	{"phone": "+70145533050"}
0005434267995	865372	6493 028155	LYUDMILA POLYAKOVA	{"email": "polyakova.lyudmila_081966@postgrespro.ru", "phone": "+70922316479"}
0005434267996	C7B86B	5342 928819	ALEKSEY KOZLOV	{"phone": "+70933308756"}
0005434267997	C7B86B	5635 191343	ANDREY GRIGOREV	{"phone": "+70172383642"}
0005434267998	6E6F62	7520 819879	MARINA LUKYANOVA	{"email": "lukyanova_marina-1957@postgrespro.ru", "phone": "+70436467933"}
0005434267999	6E6F62	6925 976003	ANDREY ORLOV	{"email": "orlov.a051971@postgrespro.ru", "phone": "+70742892035"}
0005434268000	E53F5D	0002 905820	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr.071980@postgrespro.ru", "phone": "+70196657121"}
0005434268001	E56E94	6876 232841	ELENA KULIKOVA	{"phone": "+70546242191"}
0005434268002	5DC056	6244 908933	NATALYA MAKAROVA	{"phone": "+70355775842"}
0005434268003	5DC056	3945 278584	NATALYA KOMAROVA	{"email": "natalya-komarova051972@postgrespro.ru", "phone": "+70811540031"}
0005434268004	5DC056	4222 724614	YURIY KONOVALOV	{"phone": "+70586429068"}
0005434268005	C3BEC0	0982 675818	ELENA IVANOVA	{"email": "ivanovae-14061972@postgrespro.ru", "phone": "+70517352632"}
0005434268006	6706A6	0559 598098	IRINA KALININA	{"email": "irina.kalinina28111963@postgrespro.ru", "phone": "+70614799816"}
0005434268007	6706A6	2864 248820	ALEKSANDR NIKITIN	{"email": "nikitin.a.22061967@postgrespro.ru", "phone": "+70700830928"}
0005434268008	83418A	0102 342045	VASILIY ANTONOV	{"email": "vasiliy.antonov-041975@postgrespro.ru", "phone": "+70373268627"}
0005434268009	6653BF	1603 008969	YULIYA EFIMOVA	{"email": "yuliya-efimova_1962@postgrespro.ru", "phone": "+70721027974"}
0005434268010	363A10	8867 552132	ANASTASIYA MELNIKOVA	{"email": "amelnikova.1965@postgrespro.ru", "phone": "+70547709340"}
0005434268011	73FC52	8243 176082	NIKITA VOLKOV	{"email": "nikitavolkov051973@postgrespro.ru", "phone": "+70019238649"}
0005434268012	04EC52	2734 263826	NADEZHDA FROLOVA	{"email": "frolovanadezhda_061966@postgrespro.ru", "phone": "+70153128051"}
0005434268013	36E937	7964 523460	EVGENIY FEDOROV	{"phone": "+70994802769"}
0005434268014	DE3EE9	3925 148990	DARYA IVANOVA	{"email": "d-ivanova-1978@postgrespro.ru", "phone": "+70426269247"}
0005434268015	DE3EE9	1644 927459	NATALYA KISELEVA	{"email": "kiselevan_021977@postgrespro.ru", "phone": "+70104203768"}
0005434268016	75FCDF	4719 500255	ANNA AFANASEVA	{"email": "afanasevaanna-1973@postgrespro.ru", "phone": "+70729053946"}
0005434268017	75FCDF	6773 101378	SERGEY NIKOLAEV	{"email": "nikolaev.sergey.021981@postgrespro.ru", "phone": "+70139834964"}
0005434268018	B3FAA8	0096 886325	VERA ZOTOVA	{"email": "v.zotova1973@postgrespro.ru", "phone": "+70410163920"}
0005434268019	B3FBEA	0310 184237	ALEKSEY MOISEEV	{"phone": "+70508216271"}
0005434268020	B3FBEA	6415 524845	NIKOLAY TIKHONOV	{"email": "nikolay.tikhonov1964@postgrespro.ru", "phone": "+70427603048"}
0005434268021	62B69F	8960 208650	ALEKSANDR GERASIMOV	{"phone": "+70167147611"}
0005434268022	62B69F	1883 018788	GALINA NIKIFOROVA	{"email": "nikiforovagalina_091981@postgrespro.ru", "phone": "+70181131173"}
0005434268023	6385A9	2430 586380	NATALYA KOMAROVA	{"email": "natalyakomarova_1986@postgrespro.ru", "phone": "+70656196705"}
0005434268024	6385A9	8183 423361	ELENA BORISOVA	{"email": "borisova.elena_031965@postgrespro.ru", "phone": "+70231094567"}
0005434268025	FCD67C	2570 225251	GERMAN FROLOV	{"email": "frolov.german1968@postgrespro.ru", "phone": "+70986842235"}
0005434268026	FCD67C	6695 611303	ELIZAVETA MELNIKOVA	{"phone": "+70794050272"}
0005434268027	6ADD0E	2134 896889	VALERIY KAZAKOV	{"phone": "+70928971153"}
0005434268028	6ADD0E	0688 803735	ELENA KUZNECOVA	{"email": "kuznecova_elena-1976@postgrespro.ru", "phone": "+70789005281"}
0005434268029	9E28E2	1018 861329	TAMARA MOROZOVA	{"phone": "+70500659830"}
0005434268030	63DEBB	0448 455308	IVAN IVANOV	{"phone": "+70653214012"}
0005434268031	BB0EFC	3269 969063	INESSA KALININA	{"phone": "+70699621284"}
0005434268032	645850	9131 726160	ALEKSEY FEDOTOV	{"phone": "+70797703752"}
0005434268033	300DAC	0068 750397	EVGENIY KUZMIN	{"email": "evgeniy_kuzmin.1975@postgrespro.ru", "phone": "+70702023088"}
0005434268034	06709F	1389 989162	LYUBOV ANISIMOVA	{"phone": "+70181968642"}
0005434268035	0DBD83	3082 464947	MAKSIM SEMENOV	{"email": "maksim_semenov.061981@postgrespro.ru", "phone": "+70770884462"}
0005434268036	B8115E	5707 357617	MARIYA MOISEEVA	{"phone": "+70250666080"}
0005434268037	F3F0DC	7388 547973	IRINA SERGEEVA	{"email": "isergeeva_07031985@postgrespro.ru", "phone": "+70033229178"}
0005434268038	84B747	6557 057944	MARGARITA DAVYDOVA	{"phone": "+70931574610"}
0005434268039	84B747	1658 300334	MIKHAIL SMIRNOV	{"phone": "+70052022467"}
0005434268040	84B747	2088 637227	LYUDMILA MAKAROVA	{"phone": "+70860622440"}
0005434268041	45E911	2624 201630	IRINA BARANOVA	{"phone": "+70463207655"}
0005434268042	987C2F	3586 683844	ARTEM SCHERBAKOV	{"email": "scherbakov_a29091964@postgrespro.ru", "phone": "+70824092639"}
0005434268043	2ED181	0490 884806	VALENTINA KOZLOVA	{"phone": "+70579130622"}
0005434268044	70AE85	5563 702787	VIKTOR NOVIKOV	{"phone": "+70080902492"}
0005434268045	7979B9	0772 781368	ALEKSANDR GERASIMOV	{"email": "gerasimov-aleksandr1967@postgrespro.ru", "phone": "+70976653807"}
0005434268046	7979B9	9985 767027	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga.04111985@postgrespro.ru", "phone": "+70861075140"}
0005434268047	8376C6	3621 363028	NATALYA ROMANOVA	{"phone": "+70287696740"}
0005434268048	8376C6	1244 863846	GALINA KOROLEVA	{"email": "g-koroleva.091966@postgrespro.ru", "phone": "+70574270290"}
0005434268049	AB6585	1540 980540	VALENTINA KRASNOVA	{"phone": "+70907734635"}
0005434268050	A537F6	8057 081470	VIKTORIYA FEDOROVA	{"email": "viktoriya_fedorova.13031970@postgrespro.ru", "phone": "+70888138094"}
0005434268051	A537F6	1550 099716	ANNA EGOROVA	{"phone": "+70755444693"}
0005434268052	A537F6	2494 941400	VALENTINA IVANOVA	{"email": "ivanovav.031973@postgrespro.ru", "phone": "+70605903760"}
0005434268053	1AAF51	2105 333030	ALEKSANDR SHEVCHENKO	{"phone": "+70080600391"}
0005434268054	E7B5C8	1855 451174	RAISA NESTEROVA	{"phone": "+70407845627"}
0005434268055	E7B5C8	8264 534809	ANASTASIYA TROFIMOVA	{"phone": "+70912970046"}
0005434268056	3A6664	7116 156398	ALEKSANDR DAVYDOV	{"phone": "+70561921211"}
0005434268057	B8B1F0	1518 743688	TATYANA BORISOVA	{"email": "tatyanaborisova.16071967@postgrespro.ru", "phone": "+70211632539"}
0005434268058	B8B1F0	0682 402625	ELINA VOLKOVA	{"email": "volkova.elina-1979@postgrespro.ru", "phone": "+70898635915"}
0005434268059	A36C93	0943 268725	SVETLANA POPOVA	{"email": "svetlana_popova-121983@postgrespro.ru", "phone": "+70119276306"}
0005434268060	A36C93	1157 567929	DMITRIY GAVRILOV	{"email": "gavrilovd.1964@postgrespro.ru", "phone": "+70495152483"}
0005434268061	54FB1E	9794 413697	ANDREY GORBUNOV	{"phone": "+70107550369"}
0005434268062	A5351D	3054 963482	YURIY KRASNOV	{"phone": "+70793478003"}
0005434268063	01D110	3004 128913	ANDREY MEDVEDEV	{"email": "medvedev_a.011970@postgrespro.ru", "phone": "+70314634067"}
0005434268064	9343A1	6026 497119	IGOR SHEVCHENKO	{"phone": "+70180876587"}
0005434269067	5D73DD	5876 096810	NATALYA KOVALEVA	{"email": "n_kovaleva08081973@postgrespro.ru", "phone": "+70690927041"}
0005434269068	5D73DD	4403 474915	ALEKSANDR SMIRNOV	{"phone": "+70833884758"}
0005434269069	5D73DD	9075 655582	NATALYA GORBUNOVA	{"phone": "+70166372831"}
0005434269070	0C3E87	9985 933848	DMITRIY NAZAROV	{"email": "dnazarov_29081982@postgrespro.ru", "phone": "+70098005434"}
0005434269071	8D96D3	9144 200019	MARGARITA ZAKHAROVA	{"phone": "+70959791783"}
0005434269072	4E539F	3706 360724	OKSANA TITOVA	{"email": "oksana-titova-041969@postgrespro.ru", "phone": "+70832820875"}
0005434269073	4E539F	2246 104986	VITALIY BONDARENKO	{"phone": "+70265191622"}
0005434269074	724078	5999 051606	ALEKSANDR KAZAKOV	{"phone": "+70033727460"}
0005434269075	724078	0626 417162	VLADIMIR VOROBEV	{"email": "vorobevvladimir_081975@postgrespro.ru", "phone": "+70024982065"}
0005434269076	5945E5	7149 628622	VALENTINA ROMANOVA	{"email": "valentina_romanova.01041978@postgrespro.ru", "phone": "+70959468324"}
0005434269077	2A827A	5099 794801	YULIYA BELYAEVA	{"phone": "+70844427860"}
0005434269078	CF57B8	4583 481258	VIKTORIYA KUZMINA	{"phone": "+70786949213"}
0005434269079	CF57B8	9378 657039	LIDIYA ZHUKOVA	{"email": "zhukova.l-1965@postgrespro.ru", "phone": "+70946108679"}
0005434269080	37CD82	6660 681549	VLADIMIR MELNIKOV	{"phone": "+70480255781"}
0005434269081	C8C496	1447 862488	SERGEY KUZNECOV	{"email": "kuznecov-sergey-1981@postgrespro.ru", "phone": "+70582449488"}
0005434269082	C8C496	3482 046808	NINA NIKITINA	{"email": "nikitina.nina121971@postgrespro.ru", "phone": "+70427285135"}
0005434269083	05B150	9496 775307	ALEKSEY MOROZOV	{"phone": "+70632846252"}
0005434269084	05B150	3773 669810	ALEKSEY ALEKSEEV	{"phone": "+70419795527"}
0005434269085	A6E56E	6796 206679	ANASTASIYA NAUMOVA	{"email": "a_naumova-111973@postgrespro.ru", "phone": "+70672170005"}
0005434269086	4E3C99	1692 061063	GENNADIY IVANOV	{"phone": "+70107358944"}
0005434269087	0DA19F	2445 018394	INNA NAUMOVA	{"email": "naumovainna-30081976@postgrespro.ru", "phone": "+70841348285"}
0005434269088	F682E7	7481 515150	ELDAR ALEKSEEV	{"email": "alekseev_e_1972@postgrespro.ru", "phone": "+70552873714"}
0005434269089	A5FBE3	8239 549641	DIANA ROMANOVA	{"email": "romanova.diana_111974@postgrespro.ru", "phone": "+70309311695"}
0005434269090	33FD6D	8663 266079	IVAN ROMANOV	{"email": "i-romanov.031970@postgrespro.ru", "phone": "+70519721072"}
0005434269091	33FD6D	7525 894193	ANFISA NIKOLAEVA	{"phone": "+70253726070"}
0005434269092	6EF918	8282 489277	VALENTINA PAVLOVA	{"email": "valentina-pavlova-071973@postgrespro.ru", "phone": "+70622586968"}
0005434269093	C0B1A4	4427 440001	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr021968@postgrespro.ru", "phone": "+70131083920"}
0005434269094	C485AD	7705 706992	ZLATA TARASOVA	{"phone": "+70876445708"}
0005434269095	C485AD	6731 243293	SERGEY NAZAROV	{"phone": "+70472330966"}
0005434269152	980787	6152 475859	NADEZHDA EFREMOVA	{"phone": "+70794394903"}
0005434269096	2255AB	5128 877467	VERA NIKOLAEVA	{"email": "nikolaevavera1972@postgrespro.ru", "phone": "+70385511303"}
0005434269097	74EB1B	7291 651634	DMITRIY MOROZOV	{"phone": "+70659068870"}
0005434269098	74EB1B	7520 366970	SERGEY DAVYDOV	{"phone": "+70107055533"}
0005434269099	842043	3057 358432	VALENTIN FOMIN	{"email": "fomin_valentin30061964@postgrespro.ru", "phone": "+70484407034"}
0005434269100	033932	7717 683994	ANNA POPOVA	{"email": "anna.popova_28081988@postgrespro.ru", "phone": "+70314798138"}
0005434269101	15D8AC	5848 586720	MARINA LUKYANOVA	{"email": "lukyanovam_1970@postgrespro.ru", "phone": "+70288117414"}
0005434269102	054E1A	5635 337431	VLADIMIR BARANOV	{"email": "baranov-vladimir.1974@postgrespro.ru", "phone": "+70560848130"}
0005434269103	759920	9502 055905	LIDIYA KUDRYASHOVA	{"email": "kudryashova_lidiya1971@postgrespro.ru", "phone": "+70475916094"}
0005434269104	759920	6110 890234	GALINA NAZAROVA	{"phone": "+70321863581"}
0005434269105	FA69C7	9546 959460	MARIYA NAUMOVA	{"phone": "+70637991944"}
0005434269106	3ACA31	3341 091546	ELENA KOLESNIKOVA	{"email": "e.kolesnikova_071958@postgrespro.ru", "phone": "+70409502989"}
0005434269107	FEB5C3	2270 990356	ANDREY MIKHAYLOV	{"phone": "+70197385697"}
0005434269108	FEB5C3	6814 993647	DMITRIY EGOROV	{"phone": "+70821034156"}
0005434269109	3BB6B2	0324 599411	ANDREY ANTONOV	{"phone": "+70931027425"}
0005434269110	30A9DB	4816 912454	OLGA MOROZOVA	{"email": "morozova.olga1979@postgrespro.ru", "phone": "+70680566274"}
0005434269111	16998F	7565 821039	SERGEY KUZNECOV	{"email": "s_kuznecov041974@postgrespro.ru", "phone": "+70564734712"}
0005434269112	C38830	2602 886108	YAN ALEKSEEV	{"email": "y-alekseev_25091976@postgrespro.ru", "phone": "+70939852008"}
0005434269113	C38830	5862 318948	ANNA ANDREEVA	{"email": "andreeva_anna.091967@postgrespro.ru", "phone": "+70692752753"}
0005434269114	E7511E	6294 320644	NIKOLAY NIKOLAEV	{"email": "nikolaev_n011978@postgrespro.ru", "phone": "+70549053765"}
0005434269115	E7511E	9788 437937	ANNA SERGEEVA	{"phone": "+70311100924"}
0005434269116	D73E26	8394 948117	RAISA LAZAREVA	{"email": "r_lazareva_021966@postgrespro.ru", "phone": "+70207594246"}
0005434269117	D73E26	8354 208503	SEMEN MAKAROV	{"phone": "+70168201030"}
0005434269118	5F7E0C	0551 235661	NINA KUZNECOVA	{"phone": "+70831391760"}
0005434269119	5F7E0C	9661 027043	TAISIYA GUSEVA	{"email": "guseva_taisiya_03111975@postgrespro.ru", "phone": "+70408336335"}
0005434269120	5F7E0C	2375 212725	ANASTASIYA KUZMINA	{"phone": "+70758909440"}
0005434269121	6EFB8D	7257 942605	DENIS GORBUNOV	{"phone": "+70845038290"}
0005434269122	3085B0	9054 679782	DIANA KISELEVA	{"phone": "+70987698639"}
0005434269123	3085B0	5266 563463	ALEKSANDR FROLOV	{"phone": "+70326736324"}
0005434269124	3085B0	0612 527482	ANNA KUZNECOVA	{"email": "akuznecova.081972@postgrespro.ru", "phone": "+70181135933"}
0005434269125	3BC62F	9561 893952	NINA FEDOROVA	{"email": "nina_fedorova101987@postgrespro.ru", "phone": "+70220852503"}
0005434269126	4F7F8F	9338 945782	KONSTANTIN PAVLOV	{"phone": "+70883213573"}
0005434269127	EC4231	0173 859264	RADMIR IVANOV	{"phone": "+70552130405"}
0005434269128	EC4231	7538 863327	DMITRIY IVANOV	{"email": "dmitriyivanov_13081955@postgrespro.ru", "phone": "+70351233408"}
0005434269129	EC229D	3254 820786	NINA SOLOVEVA	{"phone": "+70079330478"}
0005434269130	52D5A2	3135 560047	MARINA ZHURAVLEVA	{"email": "zhuravlevamarina.15061976@postgrespro.ru", "phone": "+70819894278"}
0005434269131	2BE849	2108 671241	SERGEY POPOV	{"email": "s_popov_09091980@postgrespro.ru", "phone": "+70443525418"}
0005434269132	5AFE63	4299 486279	SERGEY DENISOV	{"email": "sdenisov-14111973@postgrespro.ru", "phone": "+70176432409"}
0005434269133	6EAEF0	5712 853280	ARTEM POPOV	{"email": "popov-a16121975@postgrespro.ru", "phone": "+70044547008"}
0005434269134	6EAEF0	4767 957086	ANTONINA IVANOVA	{"phone": "+70756467363"}
0005434269135	0AC55E	4384 960159	RIMMA IVANOVA	{"phone": "+70273895581"}
0005434269136	0AC55E	4530 669188	ELENA PAVLOVA	{"phone": "+70992244988"}
0005434269137	E4C56A	3089 388436	SERGEY BORISOV	{"email": "borisov_sergey_011972@postgrespro.ru", "phone": "+70915969284"}
0005434269138	DAE2B6	6213 814043	ELVIRA NOVIKOVA	{"email": "novikova-e_121958@postgrespro.ru", "phone": "+70723974991"}
0005434269139	360844	1019 891539	ANDREY SOROKIN	{"email": "sorokin-andrey.111977@postgrespro.ru", "phone": "+70584679613"}
0005434269140	9F281D	3671 159097	PAVEL IVANOV	{"email": "ivanov_pavel.021978@postgrespro.ru", "phone": "+70530161689"}
0005434269141	C91AE6	8656 833417	NELLI KULIKOVA	{"email": "nellikulikova_011972@postgrespro.ru", "phone": "+70736134951"}
0005434269142	C91AE6	7213 026808	EVGENIY MOROZOV	{"email": "evgeniymorozov-08021961@postgrespro.ru", "phone": "+70650900084"}
0005434269143	666A41	9424 012233	NIKOLAY ILIN	{"email": "nilin_15051961@postgrespro.ru", "phone": "+70144070646"}
0005434269144	4382AE	0992 792669	RAISA EFREMOVA	{"phone": "+70078591027"}
0005434269145	4382AE	8295 243389	VITALIY ZAYCEV	{"phone": "+70496818453"}
0005434269146	AF6388	1364 734803	BORIS OSIPOV	{"phone": "+70005485764"}
0005434269147	AF6388	3026 936922	MIKHAIL NAZAROV	{"phone": "+70835254006"}
0005434269148	690B66	1998 023427	VLADIMIR SIDOROV	{"phone": "+70192702133"}
0005434269149	78E674	8316 442206	IGOR GORBUNOV	{"phone": "+70303267248"}
0005434269150	78E674	8062 827553	VLADIMIR MAKAROV	{"email": "makarov-v30061970@postgrespro.ru", "phone": "+70500517676"}
0005434269151	294DEF	4512 076688	VLADISLAV NAUMOV	{"email": "naumov-vladislav.1967@postgrespro.ru", "phone": "+70010038044"}
0005434271339	0C7A8F	3327 355454	DIANA ANISIMOVA	{"phone": "+70198866706"}
0005434269153	980787	2441 237755	VLADIMIR KARPOV	{"email": "karpov_vladimir071971@postgrespro.ru", "phone": "+70224797868"}
0005434269154	867543	7157 412855	DANILA EGOROV	{"phone": "+70112686901"}
0005434269155	598505	8638 382792	MARINA NIKITINA	{"email": "marinanikitina_1972@postgrespro.ru", "phone": "+70857614135"}
0005434269156	35D27F	5765 844149	BORIS PETROV	{"email": "petrov-boris.031965@postgrespro.ru", "phone": "+70200530970"}
0005434269157	735D8D	9133 117323	VITALIY MEDVEDEV	{"phone": "+70250885576"}
0005434269158	653B8D	6612 470409	EKATERINA ZHURAVLEVA	{"email": "ekaterina_zhuravleva-1964@postgrespro.ru", "phone": "+70930261231"}
0005434269159	2FE22B	4076 417696	VALENTINA SOROKINA	{"email": "sorokinavalentina_1967@postgrespro.ru", "phone": "+70848235851"}
0005434269160	8B4C3A	4636 736244	ALEKSEY DENISOV	{"phone": "+70076296887"}
0005434269161	8D3948	9000 779822	VLADIMIR OSIPOV	{"email": "v.osipov_011981@postgrespro.ru", "phone": "+70300841402"}
0005434269162	FA39FB	8713 344009	SERGEY KUZNECOV	{"phone": "+70504446191"}
0005434269163	D19EB3	4357 650987	VLADIMIR MEDVEDEV	{"phone": "+70873613657"}
0005434269164	D19EB3	3394 589270	LYUBOV SERGEEVA	{"email": "lsergeeva_091974@postgrespro.ru", "phone": "+70124006011"}
0005434269165	DCDA86	9706 051000	YURIY ALEKSEEV	{"phone": "+70408357163"}
0005434269166	6BEF45	1904 493119	STANISLAV VASILEV	{"phone": "+70904955644"}
0005434270170	42FB5A	2421 347997	RINAT IVANOV	{"phone": "+70247629164"}
0005434270171	9F380C	9075 252658	LIDIYA EFREMOVA	{"phone": "+70602374411"}
0005434270172	17B541	9492 085978	ROMAN NAZAROV	{"email": "nazarovr_03091969@postgrespro.ru", "phone": "+70369619148"}
0005434270173	17B541	6584 017716	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr.03011976@postgrespro.ru", "phone": "+70976789757"}
0005434270174	A310B6	3831 231165	MARIYA ORLOVA	{"email": "orlova_mariya04101966@postgrespro.ru", "phone": "+70155560501"}
0005434270175	A310B6	7945 199978	ALEKSANDR KOZLOV	{"phone": "+70206543044"}
0005434270176	A310B6	3931 097482	VYACHESLAV BELOV	{"phone": "+70904586165"}
0005434270177	5A7345	4254 814482	EDUARD SOKOLOV	{"email": "sokolov_e.1971@postgrespro.ru", "phone": "+70903023838"}
0005434270178	DD22E9	3931 453221	NATALYA KUZNECOVA	{"phone": "+70562246667"}
0005434270179	DD22E9	7075 669347	DENIS NAZAROV	{"email": "nazarov_d071976@postgrespro.ru", "phone": "+70049395846"}
0005434270180	3E855A	7962 923198	LYUDMILA IVANOVA	{"phone": "+70968144867"}
0005434270181	14393D	4217 635293	EVGENIY ISAEV	{"phone": "+70185273291"}
0005434270182	176EB0	1582 207339	YULIYA BELOVA	{"phone": "+70816899539"}
0005434270183	176EB0	5747 211004	INESSA ANDREEVA	{"email": "andreevainessa-19111966@postgrespro.ru", "phone": "+70419901075"}
0005434270184	73A386	5597 481415	SERGEY FOMIN	{"email": "sergey.fomin-051974@postgrespro.ru", "phone": "+70941239057"}
0005434270185	73A386	6257 969833	YURIY SMIRNOV	{"email": "smirnov.yuriy1983@postgrespro.ru", "phone": "+70733791642"}
0005434270186	FAC18A	3983 996561	AMIR POPOV	{"phone": "+70055800131"}
0005434270187	2E3324	4321 259379	GALINA IVANOVA	{"email": "ivanova_g-061967@postgrespro.ru", "phone": "+70581583280"}
0005434270188	2E3324	9538 643895	PAVEL NOVIKOV	{"email": "p-novikov1976@postgrespro.ru", "phone": "+70648665224"}
0005434270189	3FE137	7675 112139	EGOR POPOV	{"phone": "+70690057964"}
0005434270190	230341	0960 157040	GLEB PAVLOV	{"email": "gpavlov_25091973@postgrespro.ru", "phone": "+70606369526"}
0005434270191	6FF9C0	6063 982518	ALEKSEY POPOV	{"phone": "+70976280271"}
0005434270192	6984FE	8455 456277	DENIS VOROBEV	{"phone": "+70810714127"}
0005434270193	50F409	8011 382083	VLADIMIR KISELEV	{"phone": "+70386632234"}
0005434270194	D9FCCB	1973 134619	VALENTINA LEBEDEVA	{"email": "lebedeva_v-061966@postgrespro.ru", "phone": "+70733554936"}
0005434270195	4BE270	6833 595299	MARIYA CHERNOVA	{"email": "chernova-m_1971@postgrespro.ru", "phone": "+70927048291"}
0005434270196	EA93B4	6400 015062	NIKOLAY GORBUNOV	{"email": "nikolay.gorbunov.041973@postgrespro.ru", "phone": "+70813915177"}
0005434270197	EA93B4	7366 035842	MAKSIM TIMOFEEV	{"email": "timofeev_maksim.10111974@postgrespro.ru", "phone": "+70352787760"}
0005434270198	EA93B4	9727 095874	OLGA ZAYCEVA	{"email": "ozayceva-1986@postgrespro.ru", "phone": "+70456420078"}
0005434270199	EDA8DE	7326 085309	POLINA FILIPPOVA	{"phone": "+70345001315"}
0005434270200	327B2C	6318 278565	NINA BORISOVA	{"email": "borisovanina1972@postgrespro.ru", "phone": "+70106849308"}
0005434270201	9ADBE5	7219 816730	ALEKSANDR FEDOROV	{"phone": "+70493237037"}
0005434270202	9ADBE5	5663 978784	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov.071967@postgrespro.ru", "phone": "+70505152657"}
0005434270203	0E85B4	0909 605405	ELENA KOVALEVA	{"phone": "+70985694827"}
0005434270204	2B767B	4116 302194	SERGEY SOROKIN	{"email": "sorokin.s-061970@postgrespro.ru", "phone": "+70058575693"}
0005434270205	2B767B	0664 454076	NATALYA MOROZOVA	{"email": "morozova.natalya-031975@postgrespro.ru", "phone": "+70158934562"}
0005434270206	A2E4F0	4482 286852	LYUBOV SOROKINA	{"phone": "+70873992605"}
0005434270207	A2E4F0	6889 747413	PETR BONDARENKO	{"email": "bondarenko-petr.1958@postgrespro.ru", "phone": "+70705869613"}
0005434270208	D7F853	6910 211056	YURIY IVANOV	{"phone": "+70839515005"}
0005434270209	7807C7	5868 970014	ALEKSEY DAVYDOV	{"email": "davydov-aleksey_1978@postgrespro.ru", "phone": "+70395431390"}
0005434270210	497315	0206 476386	TATYANA AFANASEVA	{"phone": "+70680411016"}
0005434270211	497315	6127 480243	SVETLANA NAZAROVA	{"email": "s-nazarova_11041975@postgrespro.ru", "phone": "+70789798843"}
0005434270212	CC05EE	8524 825006	ALEKSANDR POPOV	{"email": "apopov_02081979@postgrespro.ru", "phone": "+70502805022"}
0005434270213	2382A2	8793 049153	EVGENIY PETROV	{"email": "e-petrov_021969@postgrespro.ru", "phone": "+70162407232"}
0005434270214	2382A2	7313 624459	MARIYA PETROVA	{"phone": "+70664484908"}
0005434270215	EBEAF6	0983 362179	IVAN PAVLOV	{"email": "i_pavlov.28101971@postgrespro.ru", "phone": "+70679810363"}
0005434270216	08198C	4599 288893	SVETLANA RYABOVA	{"email": "ryabova_svetlana021973@postgrespro.ru", "phone": "+70903802248"}
0005434270217	C65540	0858 554585	EVGENIY RODIONOV	{"email": "rodionov-evgeniy_1980@postgrespro.ru", "phone": "+70452068045"}
0005434270218	FA2A5F	6702 255571	ANTON GORBUNOV	{"email": "gorbunov_anton1962@postgrespro.ru", "phone": "+70790673881"}
0005434270219	B3CF5C	5782 585157	ANNA KISELEVA	{"phone": "+70499774709"}
0005434270220	8563A8	1304 237522	DARYA BELOVA	{"phone": "+70499276826"}
0005434270221	B62E6F	9106 818591	SOFYA VLASOVA	{"email": "vlasova.sofya.071979@postgrespro.ru", "phone": "+70517372169"}
0005434270222	B62E6F	2922 810548	MARIYA ZOTOVA	{"email": "mariya-zotova_031970@postgrespro.ru", "phone": "+70737434736"}
0005434270223	CB4D66	4912 013154	OLGA STEPANOVA	{"email": "stepanova_olga031969@postgrespro.ru", "phone": "+70207768942"}
0005434270224	CB4D66	1573 008338	EVDOKIYA SAVELEVA	{"email": "savelevaevdokiya_1962@postgrespro.ru", "phone": "+70013576995"}
0005434270225	51F577	2294 258157	TATYANA ILINA	{"phone": "+70761885733"}
0005434270226	8419BC	4802 813401	YAROSLAV MAKAROV	{"email": "makarov-y10021980@postgrespro.ru", "phone": "+70530247746"}
0005434270227	6A09CB	2716 496203	SVETLANA VLASOVA	{"email": "vlasova-s-03041987@postgrespro.ru", "phone": "+70047933389"}
0005434270228	D43A9C	8761 545905	ALINA ARKHIPOVA	{"email": "a_arkhipova061968@postgrespro.ru", "phone": "+70456147674"}
0005434270229	2764BD	8049 955838	MARINA KOMAROVA	{"email": "marina.komarova111977@postgrespro.ru", "phone": "+70683758910"}
0005434270230	752451	2018 540530	ANATOLIY MIKHAYLOV	{"phone": "+70668466906"}
0005434270231	F63F0D	1066 408045	ALBINA KOZLOVA	{"phone": "+70019448242"}
0005434270232	F63F0D	4641 122800	ALEKSANDR MOISEEV	{"phone": "+70522885051"}
0005434270233	9FEA71	3205 713760	KONSTANTIN MELNIKOV	{"phone": "+70518080590"}
0005434270234	9FEA71	3722 497088	BORIS YAKOVLEV	{"email": "yakovlev_boris_081973@postgrespro.ru", "phone": "+70391111175"}
0005434270235	6A1F0C	0329 224091	EGOR KUZNECOV	{"email": "kuznecov-e011981@postgrespro.ru", "phone": "+70296657499"}
0005434270236	6A1F0C	7510 606867	ANDREY STEPANOV	{"phone": "+70239528052"}
0005434270237	6A1F0C	3857 431175	ELENA MELNIKOVA	{"email": "melnikovaelena.1980@postgrespro.ru", "phone": "+70605409893"}
0005434270238	E280FC	2433 947501	VLADIMIR MOROZOV	{"phone": "+70147234351"}
0005434270239	80883F	0451 753829	GALINA KOZLOVA	{"phone": "+70689044777"}
0005434270240	80883F	5194 321877	TATYANA KOZLOVA	{"email": "tatyana.kozlova-071984@postgrespro.ru", "phone": "+70993252815"}
0005434270241	D2C769	4345 466869	VIKTOR GAVRILOV	{"email": "viktor.gavrilov25021970@postgrespro.ru", "phone": "+70223993399"}
0005434270242	5A04CE	0496 826288	EVGENIYA CHERNOVA	{"phone": "+70368811583"}
0005434270243	40854D	2158 639095	VIKTOR IVANOV	{"email": "ivanov_v_121964@postgrespro.ru", "phone": "+70237716295"}
0005434270244	40854D	0704 428915	LYUDMILA KOMAROVA	{"email": "komarova_l021980@postgrespro.ru", "phone": "+70384325697"}
0005434270245	8FDFF1	2006 868615	NIKOLAY YAKOVLEV	{"email": "yakovlev-n1980@postgrespro.ru", "phone": "+70659151208"}
0005434270246	8FDFF1	5384 221782	ELIZAVETA ZOTOVA	{"email": "elizaveta_zotova-091974@postgrespro.ru", "phone": "+70155588966"}
0005434270247	0029D3	5876 755225	ELENA KUZMINA	{"email": "kuzminae121971@postgrespro.ru", "phone": "+70201028834"}
0005434270248	0029D3	0385 539379	ALEKSANDR PAVLOV	{"phone": "+70555258717"}
0005434270249	440479	7882 239201	NINA FROLOVA	{"email": "nina.frolova-22111979@postgrespro.ru", "phone": "+70959428399"}
0005434270250	440479	4278 990201	NATALYA ANDREEVA	{"email": "natalya.andreeva1976@postgrespro.ru", "phone": "+70996854774"}
0005434270251	915CFC	6018 912084	LARISA SERGEEVA	{"phone": "+70121787834"}
0005434270252	2B6EC3	7482 231231	ANATOLIY SIDOROV	{"phone": "+70058525991"}
0005434270253	2B6EC3	7607 213682	TATYANA DANILOVA	{"phone": "+70011831643"}
0005434270254	8CC24D	5006 916666	ARTEM ILIN	{"phone": "+70313676131"}
0005434270255	8CC24D	6111 961571	VLADIMIR SEMENOV	{"email": "semenov-v_1970@postgrespro.ru", "phone": "+70218304281"}
0005434270256	8CC24D	9348 715973	VASILIY VASILEV	{"phone": "+70061119943"}
0005434270257	5C43EB	3110 702137	VLADIMIR KUZNECOV	{"email": "kuznecovv-1971@postgrespro.ru", "phone": "+70006759439"}
0005434270258	4D67BB	1832 354088	GALINA MELNIKOVA	{"phone": "+70761446316"}
0005434270259	42B301	1610 605886	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev.1979@postgrespro.ru", "phone": "+70882133858"}
0005434270260	F90622	3626 676719	ZOYA FROLOVA	{"email": "zfrolova111961@postgrespro.ru", "phone": "+70114529553"}
0005434270261	F90622	9371 022496	VALENTIN FILIPPOV	{"email": "vfilippov-04041957@postgrespro.ru", "phone": "+70052729092"}
0005434270262	7B0FA2	6404 241232	NINA MARTYNOVA	{"email": "nina_martynova1968@postgrespro.ru", "phone": "+70875781641"}
0005434270263	7B0FA2	7869 387790	OLGA YAKOVLEVA	{"email": "olga-yakovleva06061976@postgrespro.ru", "phone": "+70458867121"}
0005434270264	7B0FA2	6179 552102	MATVEY DAVYDOV	{"email": "matvey_davydov-20071977@postgrespro.ru", "phone": "+70297028888"}
0005434270265	BD218F	9947 294367	ELENA SOKOLOVA	{"email": "sokolova_elena_1973@postgrespro.ru", "phone": "+70386801566"}
0005434270266	8971C0	6452 916574	STANISLAV ORLOV	{"email": "s-orlov-1968@postgrespro.ru", "phone": "+70367124548"}
0005434270267	65A258	1536 694699	ELENA PAVLOVA	{"phone": "+70848739930"}
0005434271275	DEC938	3560 596756	LARISA ORLOVA	{"email": "l_orlova_20111970@postgrespro.ru", "phone": "+70092139553"}
0005434271276	E52527	5065 580391	VALERIY ZAYCEV	{"phone": "+70365058471"}
0005434271277	D7A144	5511 969000	LILIYA AFANASEVA	{"phone": "+70675061430"}
0005434271278	14EEFC	3629 813773	LARISA OSIPOVA	{"email": "osipovalarisa_1981@postgrespro.ru", "phone": "+70081479629"}
0005434271279	14EEFC	0150 331283	NATALYA FEDOROVA	{"phone": "+70155773178"}
0005434271280	14EEFC	3017 997401	ELENA IVANOVA	{"phone": "+70806578929"}
0005434275961	40C703	3557 274551	VALERIY PETROV	{"phone": "+70992825871"}
0005434271281	51F6F3	3080 969769	KRISTINA MAKAROVA	{"email": "kristina_makarova.031982@postgrespro.ru", "phone": "+70816980866"}
0005434271282	C9D0C5	2714 921431	ALEKSEY DAVYDOV	{"phone": "+70949084105"}
0005434271283	C9D0C5	1342 686610	SERGEY IVANOV	{"email": "s.ivanov-121974@postgrespro.ru", "phone": "+70798414591"}
0005434271284	F5CF06	0685 078385	NIKOLAY TIMOFEEV	{"phone": "+70146806322"}
0005434271285	F5CF06	1677 712321	SVETLANA KUZNECOVA	{"email": "svetlana.kuznecova1970@postgrespro.ru", "phone": "+70006478442"}
0005434271286	9D8D23	7634 804455	MARIYA SMIRNOVA	{"email": "m.smirnova_1972@postgrespro.ru", "phone": "+70268430378"}
0005434271287	2EC6F9	6772 159593	ELENA ERMAKOVA	{"phone": "+70998789603"}
0005434271288	E3A5AF	7552 469772	NADEZHDA NOVIKOVA	{"email": "nadezhda_novikova-21041974@postgrespro.ru", "phone": "+70283959008"}
0005434271289	691574	2420 560374	LYUDMILA POPOVA	{"email": "popova.lyudmila.17081972@postgrespro.ru", "phone": "+70511377334"}
0005434271290	0A43DE	3337 900732	NIKOLAY MAKAROV	{"email": "makarov-n.121975@postgrespro.ru", "phone": "+70914153733"}
0005434271291	4FE002	1553 742459	ALEKSEY SMIRNOV	{"phone": "+70654421331"}
0005434271292	E08EDA	0841 478162	MARIYA NESTEROVA	{"email": "m_nesterova.10121981@postgrespro.ru", "phone": "+70559321905"}
0005434271293	0587E9	2510 724586	LYUDMILA YAKOVLEVA	{"email": "lyudmila_yakovleva12061974@postgrespro.ru", "phone": "+70052785942"}
0005434271294	0587E9	3424 149573	KLAVDIYA VASILEVA	{"email": "vasileva.klavdiya121972@postgrespro.ru", "phone": "+70142106801"}
0005434271295	E62658	4700 873123	MAKSIM NIKOLAEV	{"email": "m-nikolaev111962@postgrespro.ru", "phone": "+70936093961"}
0005434271296	5559CB	4713 852685	NIKOLAY ILIN	{"phone": "+70839914204"}
0005434271297	77BE6C	6485 541601	SERGEY MOROZOV	{"email": "morozov-sergey-021966@postgrespro.ru", "phone": "+70936123074"}
0005434271298	6BB1F6	0204 743387	LYUDMILA MARTYNOVA	{"email": "martynova_l-081969@postgrespro.ru", "phone": "+70758952593"}
0005434271299	C20E65	2854 127695	ALEKSANDR SMIRNOV	{"email": "a_smirnov_1963@postgrespro.ru", "phone": "+70478502656"}
0005434271300	C20E65	6653 498936	IRINA ANDREEVA	{"email": "iandreeva1970@postgrespro.ru", "phone": "+70474095008"}
0005434271301	41FF47	9953 144297	YURIY MAKAROV	{"phone": "+70757682501"}
0005434271302	5DBCDC	5923 902733	VALERIY KUZNECOV	{"phone": "+70136567693"}
0005434271303	5DBCDC	6798 224002	LINAR SCHERBAKOV	{"email": "linarscherbakov.18121966@postgrespro.ru", "phone": "+70230097123"}
0005434271304	B676E8	2752 599611	ANATOLIY SHEVCHENKO	{"email": "anatoliy-shevchenko-081972@postgrespro.ru", "phone": "+70943380739"}
0005434271305	214521	8947 936116	ANATOLIY ZAKHAROV	{"email": "azakharov121971@postgrespro.ru", "phone": "+70802044432"}
0005434271306	214521	8802 509364	ELENA MEDVEDEVA	{"phone": "+70572015588"}
0005434271307	95F049	6753 057610	TATYANA NAZAROVA	{"email": "tatyananazarova-19011983@postgrespro.ru", "phone": "+70473595169"}
0005434271308	C35186	3269 696845	VENIAMIN IVANOV	{"phone": "+70458165480"}
0005434271309	C83056	2268 449572	YURIY KOZLOV	{"email": "kozlovyuriy.101969@postgrespro.ru", "phone": "+70321031116"}
0005434271310	2F393A	5562 268469	KONSTANTIN ILIN	{"email": "k-ilin.021986@postgrespro.ru", "phone": "+70655960303"}
0005434271311	87B52A	0711 709019	KIRILL IVANOV	{"email": "ivanovk09111970@postgrespro.ru", "phone": "+70484566205"}
0005434271312	87B52A	5712 161911	PETR KRASNOV	{"email": "pkrasnov_1964@postgrespro.ru", "phone": "+70537134533"}
0005434271313	29F9BB	6053 291087	ANDREY PETROV	{"email": "andreypetrov_03051965@postgrespro.ru", "phone": "+70386504266"}
0005434271314	C23F86	8426 922873	SERGEY SMIRNOV	{"phone": "+70664514720"}
0005434271315	C23F86	2447 774584	OKSANA STEPANOVA	{"phone": "+70871739231"}
0005434271316	8C477B	4151 893217	ALEKSEY NAZAROV	{"phone": "+70961181681"}
0005434271317	0C0D02	8024 000161	NATALIYA KOROLEVA	{"email": "koroleva_nataliya-18081982@postgrespro.ru", "phone": "+70158230766"}
0005434271318	D2A799	0465 278495	ALEKSEY BORISOV	{"phone": "+70426054963"}
0005434271319	5C457A	6108 233321	ELENA LUKYANOVA	{"email": "lukyanova-e031970@postgrespro.ru", "phone": "+70751200220"}
0005434271320	C604AA	8240 886179	ANNA POTAPOVA	{"email": "a-potapova-1979@postgrespro.ru", "phone": "+70214067690"}
0005434271321	C604AA	1567 739674	EKATERINA POPOVA	{"email": "popova_e.09081966@postgrespro.ru", "phone": "+70461117375"}
0005434271322	140EB7	7234 276002	EKATERINA GAVRILOVA	{"email": "e-gavrilova071985@postgrespro.ru", "phone": "+70456984784"}
0005434271323	932449	6460 691690	PAVEL ALEKSEEV	{"phone": "+70537475637"}
0005434271324	BA1867	9574 357254	LYUDMILA NESTEROVA	{"email": "nesterova.l-12041966@postgrespro.ru", "phone": "+70017086402"}
0005434271325	B9953A	2623 846881	ALEKSANDR GRIGOREV	{"phone": "+70239345147"}
0005434271326	B9953A	3127 785393	MIKHAIL KARPOV	{"email": "karpov.mikhail_111983@postgrespro.ru", "phone": "+70451622550"}
0005434271327	CFCF25	2757 846870	VIKTOR VOLKOV	{"phone": "+70059724331"}
0005434271328	CFCF25	3109 085597	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-111972@postgrespro.ru", "phone": "+70115636797"}
0005434271329	A94C83	1673 366594	VERONIKA GAVRILOVA	{"phone": "+70403529100"}
0005434271330	A94C83	4637 194707	ROMAN DAVYDOV	{"phone": "+70184897785"}
0005434271331	6B1F28	7581 499610	VALENTINA DMITRIEVA	{"phone": "+70563947669"}
0005434271332	130B8D	6646 938854	ALEKSEY SOLOVEV	{"phone": "+70769675577"}
0005434271333	778A8B	8743 148052	RAMIL KRASNOV	{"email": "krasnov-ramil_1981@postgrespro.ru", "phone": "+70814110708"}
0005434271334	66F995	7925 246900	IRINA ALEKSEEVA	{"phone": "+70730024339"}
0005434271335	A14674	3744 831092	VIKTOR KUZNECOV	{"email": "vkuznecov-02071965@postgrespro.ru", "phone": "+70023503134"}
0005434271336	D47D2D	9938 171394	SVETLANA LEBEDEVA	{"email": "svetlana.lebedeva1966@postgrespro.ru", "phone": "+70774316889"}
0005434271337	726C7C	0767 481968	EKATERINA FROLOVA	{"phone": "+70105031512"}
0005434271338	1D395D	8959 181696	PAVEL MOROZOV	{"email": "morozov.pavel28011971@postgrespro.ru", "phone": "+70777555450"}
0005434271340	85C2DC	1042 186020	KIRILL KUZNECOV	{"email": "kuznecovkirill.1974@postgrespro.ru", "phone": "+70206106993"}
0005434271341	B20C67	0616 733847	VITALIY IVANOV	{"phone": "+70632719640"}
0005434271342	7E4ACB	2616 229088	IGOR ZHURAVLEV	{"phone": "+70281877969"}
0005434271343	A82F88	8594 682517	VLADIMIR MEDVEDEV	{"email": "v.medvedev_081973@postgrespro.ru", "phone": "+70544170824"}
0005434271344	BC104B	0335 576372	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova-1973@postgrespro.ru", "phone": "+70755116834"}
0005434271345	BC104B	4772 430769	TATYANA MASLOVA	{"phone": "+70575288240"}
0005434271346	CF238F	0582 100086	TATYANA GERASIMOVA	{"email": "gerasimovatatyana_1975@postgrespro.ru", "phone": "+70589134749"}
0005434271347	89CC0D	5789 871028	OLGA EFREMOVA	{"phone": "+70348807305"}
0005434271348	59635E	7799 394801	ELENA EGOROVA	{"phone": "+70099081039"}
0005434271349	F1D4DF	5829 468996	NIKOLAY BARANOV	{"email": "baranov.nikolay1968@postgrespro.ru", "phone": "+70527468072"}
0005434271350	B208B9	8841 196350	MARINA ANDREEVA	{"phone": "+70116932767"}
0005434271351	84F742	1359 577589	EKATERINA NIKITINA	{"phone": "+70981909951"}
0005434271352	84F742	3938 946972	SERGEY SERGEEV	{"email": "sergeev-s_06021964@postgrespro.ru", "phone": "+70859743227"}
0005434271353	9805D0	1968 009841	EVGENIY POPOV	{"email": "evgeniy_popov12111973@postgrespro.ru", "phone": "+70522698128"}
0005434271354	9805D0	0204 636147	VALERIY MOISEEV	{"phone": "+70242204546"}
0005434271355	94D46A	5014 294412	ARINA KOZLOVA	{"email": "akozlova-111960@postgrespro.ru", "phone": "+70347419882"}
0005434271356	94D46A	7420 059711	PAVEL SOROKIN	{"phone": "+70380796050"}
0005434271357	4B1F31	1328 925350	SERGEY KUZNECOV	{"phone": "+70839787515"}
0005434271358	46E3D4	4405 214581	LEONID ZAKHAROV	{"phone": "+70386528655"}
0005434271359	B9FA04	4694 768666	EKATERINA SEMENOVA	{"email": "semenovaekaterina15011979@postgrespro.ru", "phone": "+70967855711"}
0005434271360	B9FA04	4513 336750	NIKITA SCHERBAKOV	{"phone": "+70680352473"}
0005434271361	B9FA04	9485 004808	SVETLANA SOROKINA	{"email": "sorokina_svetlana.121975@postgrespro.ru", "phone": "+70831248932"}
0005434271362	1E91C1	2559 876093	TATYANA SMIRNOVA	{"email": "tsmirnova-21091973@postgrespro.ru", "phone": "+70287526975"}
0005434271363	F2DED0	2656 761185	OLGA LUKYANOVA	{"email": "olga_lukyanova-02051974@postgrespro.ru", "phone": "+70817015281"}
0005434271364	F2DED0	1129 265397	ELENA KOROLEVA	{"phone": "+70001667086"}
0005434271365	EA0DFC	3911 942063	EKATERINA NAZAROVA	{"phone": "+70807172113"}
0005434271366	EA0DFC	3500 532373	NATALYA EFIMOVA	{"email": "natalyaefimova16091975@postgrespro.ru", "phone": "+70804701539"}
0005434271367	EA0DFC	3336 011210	TATYANA ISAEVA	{"phone": "+70645727030"}
0005434271368	86A8A7	1389 044144	IGOR FILIPPOV	{"phone": "+70966103372"}
0005434271369	0AFB57	2265 528274	YURIY ZHURAVLEV	{"email": "y.zhuravlev_1963@postgrespro.ru", "phone": "+70732443729"}
0005434271370	6A0368	1496 818108	NATALYA PETROVA	{"email": "npetrova031978@postgrespro.ru", "phone": "+70065757559"}
0005434271371	9EEF89	9661 575521	OLGA FROLOVA	{"email": "frolova.o28051965@postgrespro.ru", "phone": "+70345943702"}
0005434271372	9EEF89	3113 865587	LYUBOV NIKOLAEVA	{"phone": "+70082502683"}
0005434271373	DC9F3F	8655 833411	EVGENIY POPOV	{"email": "evgeniy.popov.1960@postgrespro.ru", "phone": "+70251303602"}
0005434271374	DC9F3F	1431 339749	ANASTASIYA EGOROVA	{"phone": "+70476602985"}
0005434271375	58DB67	1966 755729	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.a_061959@postgrespro.ru", "phone": "+70621603383"}
0005434272161	B44775	3600 857139	TATYANA GUSEVA	{"email": "tatyanaguseva-041972@postgrespro.ru", "phone": "+70242327310"}
0005434272162	65DD85	2101 655009	VLADLEN EGOROV	{"email": "vladlen-egorov_1979@postgrespro.ru", "phone": "+70836323698"}
0005434272163	1719ED	2528 660306	ALEKSANDR MARTYNOV	{"phone": "+70301976263"}
0005434272164	1719ED	8163 910963	ALEKSANDR PAVLOV	{"phone": "+70105552335"}
0005434272165	D97928	6607 270336	ARINA DMITRIEVA	{"phone": "+70802680118"}
0005434272166	95E3AB	1371 043865	ALEKSEY CHERNOV	{"phone": "+70989680925"}
0005434272167	7AF081	4797 696918	LIDIYA POPOVA	{"phone": "+70884234160"}
0005434272168	C5C44A	4864 585180	ELENA DANILOVA	{"phone": "+70927244611"}
0005434272169	8CFBD0	1501 691809	NIKOLAY ZHUKOV	{"email": "zhukov_nikolay.041968@postgrespro.ru", "phone": "+70967853265"}
0005434272170	8CFBD0	3648 700908	MARINA MAKSIMOVA	{"phone": "+70487952699"}
0005434272171	49ADC3	6302 580773	INNA YAKOVLEVA	{"email": "i.yakovleva29091974@postgrespro.ru", "phone": "+70582555081"}
0005434272172	60837E	7166 972353	EVGENIY SHEVCHENKO	{"email": "shevchenko_evgeniy-1968@postgrespro.ru", "phone": "+70635420133"}
0005434272173	CA66DA	8675 858287	SERGEY GORBUNOV	{"phone": "+70954863624"}
0005434272174	1E8CA6	0386 308526	IRINA ANTONOVA	{"phone": "+70166438732"}
0005434272175	1E8CA6	7114 862387	NINA NESTEROVA	{"phone": "+70701394711"}
0005434272176	FE7AC1	5479 392025	VASILISA ARKHIPOVA	{"email": "v-arkhipova091975@postgrespro.ru", "phone": "+70529800739"}
0005434272177	FE7AC1	3773 627284	ELENA KOROLEVA	{"phone": "+70375070935"}
0005434272178	2EBA1E	4017 882929	TAMARA LAZAREVA	{"email": "lazarevatamara-071986@postgrespro.ru", "phone": "+70646011012"}
0005434272179	2EBA1E	7062 151805	SERGEY BORISOV	{"email": "borisov.sergey.1972@postgrespro.ru", "phone": "+70057184226"}
0005434272180	456363	8748 086582	LARISA ISAEVA	{"email": "isaeva_larisa1982@postgrespro.ru", "phone": "+70688756582"}
0005434272181	95B279	1022 712437	LYUDMILA VOROBEVA	{"email": "l.vorobeva-1977@postgrespro.ru", "phone": "+70006246123"}
0005434272182	F5240D	1265 354232	TATYANA SCHERBAKOVA	{"email": "tatyana_scherbakova011974@postgrespro.ru", "phone": "+70476316889"}
0005434272183	486287	6625 290295	ZUKHRA MAKAROVA	{"email": "makarova_zukhra27021974@postgrespro.ru", "phone": "+70987498347"}
0005434272184	D73FAB	7643 313730	ANZHELIKA PETROVA	{"email": "anzhelikapetrova.1964@postgrespro.ru", "phone": "+70049317323"}
0005434272185	D465A4	9192 820618	ALEKSANDR MOISEEV	{"email": "aleksandr-moiseev12021972@postgrespro.ru", "phone": "+70075467843"}
0005434272186	D465A4	0967 194612	RAISA AKIMOVA	{"phone": "+70943458883"}
0005434272187	0D4E9C	3861 595142	NINA MIRONOVA	{"email": "nina_mironova_1970@postgrespro.ru", "phone": "+70542585052"}
0005434272188	0D4E9C	5820 736653	ANNA DMITRIEVA	{"email": "admitrieva_26121977@postgrespro.ru", "phone": "+70513994787"}
0005434272189	71F68D	1930 095347	NATALYA KUZNECOVA	{"phone": "+70703133731"}
0005434272190	CD836D	4621 988924	IRINA NESTEROVA	{"email": "nesterova.i1971@postgrespro.ru", "phone": "+70933418675"}
0005434272191	CD836D	1803 359352	SERGEY ANTONOV	{"email": "antonov.sergey01041983@postgrespro.ru", "phone": "+70420290538"}
0005434272192	9EC9E0	7456 944940	RAVIL NIKOLAEV	{"phone": "+70095011905"}
0005434272193	3B55C1	8529 100818	YURIY MOISEEV	{"email": "moiseevyuriy1966@postgrespro.ru", "phone": "+70134167308"}
0005434272194	3B55C1	1667 263937	OLGA FOMINA	{"phone": "+70516875254"}
0005434272195	8A93FF	4982 601430	IRINA GERASIMOVA	{"email": "gerasimovairina.26011957@postgrespro.ru", "phone": "+70659184293"}
0005434272196	8A93FF	0521 683951	VERA POTAPOVA	{"phone": "+70242955148"}
0005434272197	8A93FF	8176 763040	ANDREY BELOV	{"email": "andrey.belov1970@postgrespro.ru", "phone": "+70534838838"}
0005434272198	883812	6577 348582	ANDREY KAZAKOV	{"phone": "+70239560032"}
0005434272199	FB063E	4184 838779	DANILA PETROV	{"email": "petrov.d.081968@postgrespro.ru", "phone": "+70355450578"}
0005434272200	E81B76	9791 201546	VASILIY TARASOV	{"phone": "+70848337334"}
0005434272201	A37FBD	1080 770204	SERGEY FEDOTOV	{"phone": "+70886132290"}
0005434272202	3BBCE5	9732 861656	MAKAR MIRONOV	{"email": "mironov-m_10041982@postgrespro.ru", "phone": "+70794974956"}
0005434272203	3BBCE5	0364 125050	VALENTINA PETROVA	{"email": "v-petrova02011968@postgrespro.ru", "phone": "+70311829124"}
0005434272204	B26A6A	9138 454537	MARINA GAVRILOVA	{"email": "gavrilova.m-081972@postgrespro.ru", "phone": "+70059316467"}
0005434272205	3DE701	8577 608811	NADEZHDA SEMENOVA	{"email": "nadezhda_semenova_031963@postgrespro.ru", "phone": "+70594380726"}
0005434272206	41F74A	7193 746503	ANTONIDA ZHUKOVA	{"phone": "+70959311501"}
0005434272207	41F74A	9249 248907	ANDREY SOKOLOV	{"phone": "+70450563050"}
0005434272208	CB6DB4	9817 015006	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova_a_1967@postgrespro.ru", "phone": "+70650520862"}
0005434272209	CB6DB4	6245 187194	PAVEL TARASOV	{"email": "paveltarasov071969@postgrespro.ru", "phone": "+70497023226"}
0005434272210	626789	8691 109678	DENIS PAVLOV	{"phone": "+70129110414"}
0005434272211	3F331E	0744 499821	YULIYA SEMENOVA	{"phone": "+70110459017"}
0005434272212	3C3E0D	2755 256031	MATVEY VOROBEV	{"phone": "+70364069992"}
0005434272213	9BA6C5	4882 498474	VIKTOR DAVYDOV	{"phone": "+70573629771"}
0005434272214	396962	5678 422237	ALEKSEY ZAYCEV	{"phone": "+70348438762"}
0005434272215	396962	6696 981143	OLGA ALEKSANDROVA	{"email": "o.aleksandrova.01051971@postgrespro.ru", "phone": "+70702067840"}
0005434272216	4C29E2	9478 375152	ANDREY PAVLOV	{"email": "andrey.pavlov051988@postgrespro.ru", "phone": "+70828463331"}
0005434272217	F0B388	1929 276530	OKSANA IVANOVA	{"phone": "+70609410351"}
0005434272218	BA139A	3906 246133	VALERIY BARANOV	{"phone": "+70734612960"}
0005434272219	BA139A	6588 798628	VLADISLAV PETROV	{"email": "petrovv_1973@postgrespro.ru", "phone": "+70653143470"}
0005434272220	BA139A	0690 463981	ALEKSANDR FILIPPOV	{"phone": "+70009752480"}
0005434272221	1D47B1	8612 318859	ANATOLIY DMITRIEV	{"email": "a.dmitriev_21081968@postgrespro.ru", "phone": "+70708323355"}
0005434272222	C6936A	6205 136872	IRINA GERASIMOVA	{"email": "gerasimova-i_1971@postgrespro.ru", "phone": "+70630141716"}
0005434272223	C6936A	1307 861903	LYUDMILA GRISHINA	{"phone": "+70553388592"}
0005434272224	4E00F6	1381 755414	ALENA PETROVA	{"phone": "+70588251793"}
0005434272225	4E00F6	0539 344794	RIMMA NAZAROVA	{"email": "r_nazarova14071977@postgrespro.ru", "phone": "+70060709265"}
0005434272226	D00094	0111 169747	NAIL NAUMOV	{"email": "nail_naumov081972@postgrespro.ru", "phone": "+70744081739"}
0005434272227	18496A	6298 477516	MAKSIM SERGEEV	{"email": "maksim_sergeev.27061982@postgrespro.ru", "phone": "+70424101746"}
0005434272228	70EB54	6434 678447	ARTUR GRIGOREV	{"email": "artur-grigorev.081975@postgrespro.ru", "phone": "+70668151344"}
0005434272229	70EB54	0570 959919	ALEKSEY ROMANOV	{"email": "romanov.aleksey01101974@postgrespro.ru", "phone": "+70203263851"}
0005434272230	2DC0C0	4368 090054	VLADIMIR GRIGOREV	{"email": "vladimirgrigorev11091971@postgrespro.ru", "phone": "+70497436332"}
0005434272231	8DA46D	4338 759547	YURIY MELNIKOV	{"email": "melnikov-y.1972@postgrespro.ru", "phone": "+70895349449"}
0005434272232	67802E	4143 530394	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov.101972@postgrespro.ru", "phone": "+70094800901"}
0005434272233	67802E	1810 440591	VERONIKA ZHUKOVA	{"email": "veronika.zhukova-24011969@postgrespro.ru", "phone": "+70582395167"}
0005434272234	521970	3513 951024	ANDREY PAVLOV	{"email": "pavlovandrey-041970@postgrespro.ru", "phone": "+70657475145"}
0005434272235	B95FCA	8273 128412	MATVEY ALEKSANDROV	{"email": "aleksandrov-matvey-031979@postgrespro.ru", "phone": "+70777152121"}
0005434272236	65F742	1766 803300	LYUDMILA VOLKOVA	{"phone": "+70490560713"}
0005434272237	65F742	9052 156089	EDUARD VASILEV	{"email": "vasilev-eduard-13071979@postgrespro.ru", "phone": "+70070404416"}
0005434272238	E1AAD1	5542 457593	SERGEY IVANOV	{"email": "ivanov_sergey081980@postgrespro.ru", "phone": "+70682878024"}
0005434273046	803159	4463 902301	NADEZHDA ORLOVA	{"phone": "+70979667204"}
0005434273047	75FC18	4308 968914	ALEKSANDR MIRONOV	{"phone": "+70955392568"}
0005434273048	299945	8218 336249	VLADIMIR EGOROV	{"email": "vladimir.egorov.1966@postgrespro.ru", "phone": "+70631173308"}
0005434273049	299945	7490 104010	VIKTORIYA ANTONOVA	{"phone": "+70178579333"}
0005434273050	981EB1	4071 560209	LYUDMILA ERMAKOVA	{"phone": "+70563486238"}
0005434273051	981EB1	1614 598545	ELINA BELOVA	{"email": "elinabelova-05021971@postgrespro.ru", "phone": "+70422725335"}
0005434273052	77B08D	6119 880490	GRIGORIY NOVIKOV	{"email": "grigoriy.novikov.1980@postgrespro.ru", "phone": "+70542014543"}
0005434273053	E8636C	5542 893949	NADEZHDA MEDVEDEVA	{"phone": "+70738566347"}
0005434273054	E8636C	8589 750162	OLGA TIKHONOVA	{"phone": "+70012042200"}
0005434273055	BE1108	6179 339475	GUZEL BOGDANOVA	{"email": "bogdanovag.17061981@postgrespro.ru", "phone": "+70236637454"}
0005434273056	BE1108	5857 418418	VLADIMIR NAZAROV	{"email": "nazarov-vladimir-1970@postgrespro.ru", "phone": "+70288370252"}
0005434273057	368630	2657 664964	GALINA POPOVA	{"email": "popovag-01111972@postgrespro.ru", "phone": "+70952587795"}
0005434273058	368630	3316 218133	ALEKSEY POPOV	{"phone": "+70513091338"}
0005434273059	5715FA	0159 715890	TATYANA ABRAMOVA	{"phone": "+70424096852"}
0005434273060	98929D	8098 837670	RAISA KONDRATEVA	{"phone": "+70969039910"}
0005434273061	98929D	2391 510895	MAKSIM MARTYNOV	{"email": "martynov.m071965@postgrespro.ru", "phone": "+70206785453"}
0005434273062	5C8AE5	8647 816264	SERGEY BORISOV	{"email": "s_borisov-1969@postgrespro.ru", "phone": "+70481485659"}
0005434273063	20BB69	1540 388898	LIDIYA OSIPOVA	{"email": "osipova-l16101968@postgrespro.ru", "phone": "+70145238854"}
0005434273064	20BB69	7491 692799	MARIYA SOKOLOVA	{"phone": "+70820891488"}
0005434273065	176FFE	0737 876560	VERA SMIRNOVA	{"phone": "+70404323772"}
0005434273066	176FFE	5962 186254	DMITRIY FEDOROV	{"phone": "+70723365198"}
0005434273067	5A7AE8	8784 737829	ALEKSANDR FOMIN	{"email": "a_fomin1981@postgrespro.ru", "phone": "+70837071364"}
0005434273068	5A7AE8	0369 712682	TATYANA EFREMOVA	{"phone": "+70745625598"}
0005434273069	E92548	9859 409621	DENIS FROLOV	{"phone": "+70666145127"}
0005434273070	8A0A7F	4033 212328	ALISA IVANOVA	{"phone": "+70075062418"}
0005434273071	467B2A	6309 408101	VERA MALYSHEVA	{"phone": "+70370316538"}
0005434273072	13B010	9404 800634	LYUBOV AFANASEVA	{"email": "afanaseva.l_19041953@postgrespro.ru", "phone": "+70810237854"}
0005434273073	13B010	1861 128257	RINAT BARANOV	{"email": "baranovr-111970@postgrespro.ru", "phone": "+70761891938"}
0005434273074	E8965C	0924 242773	MIKHAIL KARPOV	{"email": "karpov_mikhail.1967@postgrespro.ru", "phone": "+70302563058"}
0005434273075	BC954E	1045 687526	MARIYA POPOVA	{"email": "mariyapopova01031966@postgrespro.ru", "phone": "+70503434228"}
0005434273076	BC954E	0476 699835	SERGEY EGOROV	{"phone": "+70601573243"}
0005434273077	BC954E	2837 123001	ALINA GORBUNOVA	{"email": "gorbunova-alina_1975@postgrespro.ru", "phone": "+70701852198"}
0005434273078	FA812D	3317 619917	LYUDMILA IVANOVA	{"phone": "+70084299433"}
0005434273079	FA812D	1528 998210	ELIZAVETA POPOVA	{"email": "epopova-111959@postgrespro.ru", "phone": "+70842754587"}
0005434273080	95AA56	2537 015746	NINA KISELEVA	{"phone": "+70760484807"}
0005434273081	C81D23	9442 756973	LYUDMILA KUZMINA	{"phone": "+70316905650"}
0005434273082	E56856	4676 125477	EVGENIY NIKITIN	{"email": "e-nikitin.06121971@postgrespro.ru", "phone": "+70301405690"}
0005434273083	FD44A0	9535 166900	GALINA VOROBEVA	{"phone": "+70446465027"}
0005434273084	E5B4F4	0065 915062	VIKTOR IVANOV	{"phone": "+70316423848"}
0005434273085	E5B4F4	9159 797668	VERONIKA FOMINA	{"email": "v-fomina.011972@postgrespro.ru", "phone": "+70826086848"}
0005434273086	0C7416	3339 757196	TATYANA DANILOVA	{"phone": "+70036397852"}
0005434273087	3E9D82	2048 305242	IGOR IVANOV	{"phone": "+70979334874"}
0005434273088	C0E173	7467 781815	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov_031968@postgrespro.ru", "phone": "+70127143871"}
0005434273089	B4DCAA	1267 392340	ELENA RYABOVA	{"phone": "+70602495370"}
0005434273090	B4DCAA	8082 138128	IGOR SMIRNOV	{"phone": "+70518667667"}
0005434273091	505205	8697 739198	EKATERINA YUDINA	{"phone": "+70366651843"}
0005434273092	505205	5211 394578	POLINA ISAEVA	{"email": "isaeva.polina_28101986@postgrespro.ru", "phone": "+70267532152"}
0005434273093	874484	2237 565153	SANIYA MOROZOVA	{"phone": "+70510697594"}
0005434273094	874484	2727 781779	NATALYA FILATOVA	{"phone": "+70510257278"}
0005434273095	FA3123	8734 113092	RAISA ROMANOVA	{"phone": "+70990317026"}
0005434273096	681F8D	4528 260599	DMITRIY PETROV	{"phone": "+70828298292"}
0005434273097	2C6481	7243 847939	ILGIZ KUZNECOV	{"email": "ilgiz-kuznecov13091990@postgrespro.ru", "phone": "+70552845865"}
0005434273098	23A4F9	5166 788839	VIKTOR POPOV	{"phone": "+70902561923"}
0005434273099	1D7B2E	1413 719807	EVDOKIYA KOVALEVA	{"phone": "+70775938456"}
0005434273100	1B8332	8952 267571	VLADIMIR MELNIKOV	{"phone": "+70532184168"}
0005434273101	60DC53	7887 854130	OLGA BELOVA	{"phone": "+70337487106"}
0005434273102	D75B7A	8596 050024	GENNADIY ABRAMOV	{"phone": "+70909949116"}
0005434273103	D75B7A	8038 816750	GALINA BELOVA	{"phone": "+70435256196"}
0005434273104	0165AA	4353 974312	VALERIY ROMANOV	{"email": "romanov_v.1969@postgrespro.ru", "phone": "+70431597585"}
0005434273105	0165AA	7732 400583	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr.1979@postgrespro.ru", "phone": "+70181189750"}
0005434273106	69C8D3	4825 908361	VLADIMIR ILIN	{"phone": "+70472402903"}
0005434273107	69C8D3	2074 342736	VLADIMIR NAZAROV	{"email": "v.nazarov23031972@postgrespro.ru", "phone": "+70630110004"}
0005434273108	278246	0334 447370	ANASTASIYA KARPOVA	{"email": "anastasiya-karpova.07101977@postgrespro.ru", "phone": "+70123028281"}
0005434273109	58454C	4296 192889	IRINA FADEEVA	{"email": "fadeeva_i.1961@postgrespro.ru", "phone": "+70228819509"}
0005434273110	A94DED	4126 144769	NINA IVANOVA	{"email": "ivanova.n_1979@postgrespro.ru", "phone": "+70365000656"}
0005434273111	D54F40	4133 472590	VLADIMIR AFANASEV	{"phone": "+70612351743"}
0005434273112	4B9F22	5897 809147	NATALYA SMIRNOVA	{"phone": "+70740553396"}
0005434273113	E070C4	1518 057920	TATYANA AFANASEVA	{"email": "afanaseva_t-1970@postgrespro.ru", "phone": "+70793104203"}
0005434273114	E070C4	1090 100968	ALEKSEY FEDOTOV	{"email": "aleksey_fedotov1969@postgrespro.ru", "phone": "+70014268800"}
0005434273115	94D195	2812 305892	SERGEY IVANOV	{"email": "ivanov-sergey.101981@postgrespro.ru", "phone": "+70156406697"}
0005434273116	1C7F31	9510 148855	ELENA NAZAROVA	{"email": "nazarova_e071970@postgrespro.ru", "phone": "+70038872797"}
0005434273117	CAEDF1	0364 359155	VERA IVANOVA	{"email": "ivanovav21121972@postgrespro.ru", "phone": "+70567484178"}
0005434273118	026182	1039 848265	TATYANA NOVIKOVA	{"phone": "+70524107812"}
0005434273119	026182	3230 096593	ELENA NIKOLAEVA	{"phone": "+70006680598"}
0005434273120	5F95A6	0474 739017	NINA RODIONOVA	{"email": "rodionova-nina_1968@postgrespro.ru", "phone": "+70902687825"}
0005434273121	90D5F9	8681 978336	NINA IVANOVA	{"phone": "+70157504402"}
0005434273122	F449D6	9424 537850	VIKTOR NIKITIN	{"email": "viktor.nikitin.18081975@postgrespro.ru", "phone": "+70512044855"}
0005434273123	19BDC7	0813 395711	OLEG ZAYCEV	{"email": "o_zaycev1970@postgrespro.ru", "phone": "+70249178881"}
0005434273124	2325A7	1631 381158	ALEKSEY IVANOV	{"email": "ivanov-aleksey-23101974@postgrespro.ru", "phone": "+70432498747"}
0005434273125	F9F87F	5635 681615	EKATERINA EFREMOVA	{"email": "e-efremova04061971@postgrespro.ru", "phone": "+70565501826"}
0005434273126	026B1D	3249 561991	SEMEN NIKOLAEV	{"email": "semen-nikolaev061974@postgrespro.ru", "phone": "+70338969244"}
0005434273127	026B1D	4760 521535	EDUARD KUZNECOV	{"email": "kuznecov_e.09011971@postgrespro.ru", "phone": "+70956335194"}
0005434273131	D50E7B	2455 935832	GENNADIY ZHUKOV	{"email": "zhukov_g_121982@postgrespro.ru", "phone": "+70356450351"}
0005434273132	D50E7B	4561 862756	GENNADIY SOROKIN	{"email": "g-sorokin14011971@postgrespro.ru", "phone": "+70891571722"}
0005434273133	12A729	6980 946447	ALBERT SEMENOV	{"email": "semenov.albert.11031984@postgrespro.ru", "phone": "+70262851826"}
0005434273134	12A729	5828 482947	SVETLANA KUZMINA	{"phone": "+70501664791"}
0005434273135	EB77DD	5128 402570	NATALYA ZOTOVA	{"email": "zotova_n_1978@postgrespro.ru", "phone": "+70787106043"}
0005434273136	162A58	6240 648174	ANASTASIYA SEMENOVA	{"phone": "+70296119166"}
0005434273137	9B6E93	0837 331997	ELENA MIKHAYLOVA	{"phone": "+70948896369"}
0005434273138	9B6E93	1847 166743	SVETLANA YAKOVLEVA	{"email": "yakovleva-svetlana1978@postgrespro.ru", "phone": "+70139765164"}
0005434275934	9681F3	6937 567457	VITALIY VOLKOV	{"phone": "+70338378297"}
0005434275924	CCFB8E	7789 350060	VITALIY NIKITIN	{"phone": "+70006041873"}
0005434275925	554108	0056 578828	YULIYA KUZMINA	{"phone": "+70859771559"}
0005434275926	AD838C	6727 148674	ELENA ALEKSANDROVA	{"email": "aleksandrova.e071969@postgrespro.ru", "phone": "+70234032193"}
0005434275927	5753D7	2634 002310	VLADIMIR ORLOV	{"phone": "+70585178050"}
0005434275928	AB4170	7374 755860	ANNA ANTONOVA	{"phone": "+70357804533"}
0005434275929	832F32	4425 814508	NATALYA DMITRIEVA	{"email": "dmitrieva.n-1975@postgrespro.ru", "phone": "+70079409536"}
0005434275930	AFFD49	8718 585756	KLAVDIYA TARASOVA	{"email": "tarasova_klavdiya-07051967@postgrespro.ru", "phone": "+70125592478"}
0005434275931	F0AECB	7326 693829	NIKOLAY EGOROV	{"email": "egorov_n_031978@postgrespro.ru", "phone": "+70257160476"}
0005434275932	F0AECB	6568 610749	VALENTINA AKIMOVA	{"email": "akimova.v.111969@postgrespro.ru", "phone": "+70738744127"}
0005434275933	87944D	2604 608308	ELENA DENISOVA	{"phone": "+70871319420"}
0005434275935	9681F3	8986 323407	NADEZHDA POPOVA	{"phone": "+70921814421"}
0005434275936	9681F3	5562 254566	ANTONINA KUZNECOVA	{"email": "antonina-kuznecova-041961@postgrespro.ru", "phone": "+70424764126"}
0005434275937	9681F3	2433 098012	ALEKSANDR EGOROV	{"email": "egorovaleksandr.121959@postgrespro.ru", "phone": "+70183892185"}
0005434275938	C26E49	5600 561419	LYUBOV FADEEVA	{"phone": "+70007793468"}
0005434275939	1A3736	3709 972017	MIKHAIL FOMIN	{"phone": "+70582560752"}
0005434275940	CA2D42	9772 988081	YURIY KUZNECOV	{"phone": "+70124505659"}
0005434275941	CA2D42	4593 221687	VALENTIN FROLOV	{"email": "valentin.frolov_061968@postgrespro.ru", "phone": "+70071410562"}
0005434275942	AAD352	2824 819577	SNEZHANA IVANOVA	{"phone": "+70894952375"}
0005434275943	AAD352	6181 631546	ALEKSANDR SIDOROV	{"phone": "+70994321532"}
0005434275944	CD5806	3156 547123	ALEKSANDR MAKAROV	{"email": "makarovaleksandr_1970@postgrespro.ru", "phone": "+70403738774"}
0005434275945	CD5806	0078 526128	VIKTOR ZAKHAROV	{"email": "zakharov.viktor1979@postgrespro.ru", "phone": "+70599228876"}
0005434275946	910907	1788 438024	ANNA SEMENOVA	{"email": "semenova.anna.071970@postgrespro.ru", "phone": "+70129161272"}
0005434275947	6BE56F	2481 565483	ALEKSANDR ILIN	{"phone": "+70555012559"}
0005434275948	48AB19	6542 922463	SVETLANA NAUMOVA	{"phone": "+70119589710"}
0005434275949	48AB19	5724 411626	ARKADIY KRASNOV	{"phone": "+70294400396"}
0005434275950	CBCACA	2676 116823	ALEKSEY MOROZOV	{"email": "morozov-a_111968@postgrespro.ru", "phone": "+70089597239"}
0005434275951	AB83BF	7146 940502	ANTONINA ALEKSEEVA	{"email": "alekseevaa021966@postgrespro.ru", "phone": "+70427844400"}
0005434275952	350BF4	7375 703875	VIKTOR FEDOROV	{"phone": "+70657640003"}
0005434275953	A12F5A	8922 993666	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir_051975@postgrespro.ru", "phone": "+70381282228"}
0005434275954	09532D	2273 005223	YULIYA ROMANOVA	{"email": "romanova-y_091974@postgrespro.ru", "phone": "+70311712826"}
0005434275955	09532D	9100 051821	OKSANA VOLKOVA	{"email": "volkova.o.1986@postgrespro.ru", "phone": "+70156173403"}
0005434275956	3C0FF2	2254 899523	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy_121973@postgrespro.ru", "phone": "+70676909917"}
0005434275957	B99DB0	7266 018645	RAISA ZOTOVA	{"phone": "+70103592504"}
0005434275958	C9B251	1042 339026	IRINA GORBUNOVA	{"email": "gorbunovai_1970@postgrespro.ru", "phone": "+70367083961"}
0005434275959	29C9F9	4270 108097	YURIY KULIKOV	{"phone": "+70745830344"}
0005434275960	08FF03	0216 012583	ALEKSANDR BORISOV	{"phone": "+70303510205"}
0005434275962	195A1C	1237 111897	ELENA NIKITINA	{"phone": "+70592425266"}
0005434275963	8AFF32	4675 524796	NIKITA VASILEV	{"email": "vasilev_n_101962@postgrespro.ru", "phone": "+70153074669"}
0005434275964	49428B	8985 610163	YURIY IVANOV	{"email": "yuriyivanov-091972@postgrespro.ru", "phone": "+70939504870"}
0005434275965	9DBEC6	7388 501051	ANTONINA KRASNOVA	{"phone": "+70033709884"}
0005434275966	851864	0645 616380	LIDIYA KOVALEVA	{"phone": "+70662872623"}
0005434275967	88397F	2404 582394	ANASTASIYA NIKOLAEVA	{"phone": "+70351899660"}
0005434275968	021E75	6790 870545	OLGA SMIRNOVA	{"email": "olgasmirnova.31031970@postgrespro.ru", "phone": "+70907252997"}
0005434275969	479E20	7909 697883	VERONIKA FEDOROVA	{"phone": "+70377517779"}
0005434275970	36FB3E	6516 123441	OLGA FEDOROVA	{"phone": "+70723046321"}
0005434275971	DD8F3D	4747 167885	GRIGORIY POPOV	{"phone": "+70282322439"}
0005434275972	DD8F3D	0091 018494	ANDREY KONOVALOV	{"email": "a-konovalov-05081974@postgrespro.ru", "phone": "+70229292459"}
0005434275973	2CE270	3913 768456	ALEKSANDR MIRONOV	{"phone": "+70903762971"}
0005434275974	2CE270	4046 869309	VLADIMIR AFANASEV	{"phone": "+70271372767"}
0005434275975	BFFC8F	7395 934426	NIKOLAY BONDARENKO	{"phone": "+70258407587"}
0005434275976	BFFC8F	6033 355682	ALEKSANDR GRIGOREV	{"email": "a-grigorev03011973@postgrespro.ru", "phone": "+70968936024"}
0005434275977	C189F1	9939 867198	MAKSIM POPOV	{"phone": "+70240093008"}
0005434275978	C189F1	3083 482766	SERGEY SCHERBAKOV	{"phone": "+70880585101"}
0005434275979	749036	4481 317194	KIRILL EGOROV	{"email": "kegorov_111961@postgrespro.ru", "phone": "+70592016478"}
0005434275980	A54F77	7001 891489	DMITRIY PAVLOV	{"email": "pavlov-d-17091976@postgrespro.ru", "phone": "+70836872187"}
0005434275981	419E1B	8117 144016	VLADIMIR ZAKHAROV	{"email": "vladimir-zakharov_11101978@postgrespro.ru", "phone": "+70730471382"}
0005434275982	419E1B	8990 082217	GALINA ZHUKOVA	{"email": "zhukova-galina_03061978@postgrespro.ru", "phone": "+70211539637"}
0005434275983	C83905	8873 311787	MARINA AKIMOVA	{"email": "akimova-marina_1974@postgrespro.ru", "phone": "+70040273116"}
0005434275984	E0F421	5382 519588	NATALYA VOROBEVA	{"email": "vorobeva.natalya081966@postgrespro.ru", "phone": "+70620189051"}
0005434275985	AAA41D	9418 999253	YULIYA POPOVA	{"phone": "+70114206092"}
0005434275986	71C70A	0882 228978	NIKOLAY ILIN	{"email": "nikolay-ilin.1968@postgrespro.ru", "phone": "+70872153467"}
0005434275987	71C70A	0099 300884	NATALYA KRASNOVA	{"email": "krasnova-natalya_111960@postgrespro.ru", "phone": "+70287897050"}
0005434275988	45045C	0406 325663	ELENA NIKOLAEVA	{"phone": "+70300202840"}
0005434275989	45045C	3080 306459	DENIS SIDOROV	{"phone": "+70874798950"}
0005434275990	11F913	1073 890340	ALEKSANDRA SOLOVEVA	{"phone": "+70478569850"}
0005434276046	59B81D	2056 569600	EKATERINA MOROZOVA	{"phone": "+70211383217"}
0005434275991	11F913	4476 965900	MARIYA GORBUNOVA	{"email": "mariya-gorbunova_1978@postgrespro.ru", "phone": "+70929000044"}
0005434275992	11F913	7776 184533	MAKSIM SIDOROV	{"phone": "+70944256591"}
0005434275993	B71AD5	4002 717061	SERGEY EGOROV	{"phone": "+70289275151"}
0005434275994	00DD78	5493 790185	EVGENIY RODIONOV	{"phone": "+70671195335"}
0005434275995	DA3109	1712 925456	VIKTOR NIKOLAEV	{"email": "v-nikolaev_04021973@postgrespro.ru", "phone": "+70144408190"}
0005434275996	B64ADA	0410 972968	LILIYA VASILEVA	{"email": "vasileva_liliya011973@postgrespro.ru", "phone": "+70154204867"}
0005434275997	B64ADA	0008 129124	LYUDMILA OVCHINNIKOVA	{"phone": "+70507401823"}
0005434275998	69C9EB	8864 720587	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov.111965@postgrespro.ru", "phone": "+70842364967"}
0005434275999	31AB88	5373 232145	MIKHAIL NIKITIN	{"email": "mnikitin-011979@postgrespro.ru", "phone": "+70162728337"}
0005434276000	9E2BFA	3459 564242	GRIGORIY ZHUKOV	{"email": "grigoriy.zhukov-021977@postgrespro.ru", "phone": "+70679266080"}
0005434276001	9E2BFA	8342 591173	ELENA MELNIKOVA	{"phone": "+70050893554"}
0005434276002	9E2BFA	9919 833906	DARYA NIKOLAEVA	{"email": "darya.nikolaeva-081973@postgrespro.ru", "phone": "+70926554518"}
0005434276003	100A0B	3966 515841	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov-1972@postgrespro.ru", "phone": "+70070371175"}
0005434276004	100A0B	1819 119772	ROMAN TIKHONOV	{"email": "tikhonov.r26061964@postgrespro.ru", "phone": "+70381741827"}
0005434276005	60F1E9	3042 810642	ILYA EGOROV	{"email": "ilya.egorov081972@postgrespro.ru", "phone": "+70855884030"}
0005434276006	FC535B	7558 180906	EVGENIY ROMANOV	{"email": "romanov_e-011973@postgrespro.ru", "phone": "+70999157922"}
0005434276007	736B4E	3958 988198	PETR MIKHAYLOV	{"phone": "+70444531351"}
0005434276008	FF2239	6682 342944	EKATERINA KUDRYASHOVA	{"phone": "+70761294799"}
0005434276009	FF2239	8847 827814	GALINA KOVALEVA	{"phone": "+70184393420"}
0005434276010	928528	7904 067698	ANASTASIYA FOMINA	{"phone": "+70678413102"}
0005434276011	DB894C	5833 057244	PAVEL VOROBEV	{"phone": "+70929592087"}
0005434276012	DB894C	3782 957063	NATALYA SIDOROVA	{"phone": "+70606973102"}
0005434276013	DB894C	7833 314070	ALEKSANDR VOLKOV	{"email": "avolkov_23011970@postgrespro.ru", "phone": "+70486943768"}
0005434276014	E19683	6096 806563	VASILIY EGOROV	{"phone": "+70254268875"}
0005434276015	B61E8C	5289 992478	IRINA SMIRNOVA	{"phone": "+70673498320"}
0005434276016	B61E8C	9456 099071	ANNA KARPOVA	{"email": "karpova_a-041967@postgrespro.ru", "phone": "+70983687404"}
0005434276017	B575ED	6816 557226	VIKTOR STEPANOV	{"phone": "+70362572265"}
0005434276073	7CD4D8	1574 096763	ELIZAVETA ANTONOVA	{"phone": "+70739348903"}
0005434276018	5DADE5	6912 876869	TATYANA KARPOVA	{"email": "t.karpova20051979@postgrespro.ru", "phone": "+70425891255"}
0005434276019	0AE0D9	0934 025217	MAKSIM MIKHAYLOV	{"email": "mikhaylov.maksim-1975@postgrespro.ru", "phone": "+70371749240"}
0005434276020	0AE0D9	8269 804809	LYUDMILA KUZNECOVA	{"phone": "+70672505247"}
0005434276021	0AE0D9	3186 807349	IRINA RYABOVA	{"email": "i.ryabova.26041978@postgrespro.ru", "phone": "+70095044414"}
0005434276022	724CB5	9169 620897	LYUDMILA BELYAEVA	{"email": "belyaevalyudmila.1973@postgrespro.ru", "phone": "+70818163074"}
0005434276023	724CB5	6656 196906	ELENA NOVIKOVA	{"email": "novikova.e-1966@postgrespro.ru", "phone": "+70190986713"}
0005434276024	724CB5	3093 308551	ANASTASIYA MIRONOVA	{"email": "anastasiya.mironova_26031977@postgrespro.ru", "phone": "+70392174902"}
0005434276025	522376	4302 214022	AZAT FILIPPOV	{"phone": "+70542178430"}
0005434276026	79B4A2	3075 425424	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov_04011975@postgrespro.ru", "phone": "+70122170553"}
0005434276027	F0A029	1192 129982	NADEZHDA BORISOVA	{"email": "borisovan121962@postgrespro.ru", "phone": "+70201631365"}
0005434276028	D735BD	7855 039688	NATALYA CHERNOVA	{"email": "chernovanatalya-1960@postgrespro.ru", "phone": "+70739027816"}
0005434276029	D735BD	5102 177344	LIDIYA SAVELEVA	{"email": "saveleva_lidiya.1978@postgrespro.ru", "phone": "+70055155776"}
0005434276030	7068B8	5943 479102	LYUDMILA ROMANOVA	{"email": "lyudmila.romanova.1970@postgrespro.ru", "phone": "+70693002804"}
0005434276031	7AABE3	1639 894737	EKATERINA MIKHAYLOVA	{"email": "ekaterina_mikhaylova101975@postgrespro.ru", "phone": "+70385414064"}
0005434276032	A880A4	2181 883703	ALEKSANDR POPOV	{"email": "popov-aleksandr_21121963@postgrespro.ru", "phone": "+70286745413"}
0005434276033	47C2BF	3173 348290	TATYANA IVANOVA	{"email": "tatyana_ivanova_071976@postgrespro.ru", "phone": "+70758153251"}
0005434276034	937DAB	6188 414188	IRINA SMIRNOVA	{"email": "irina-smirnova.1961@postgrespro.ru", "phone": "+70208211258"}
0005434276035	FD13CF	2408 048465	ZOYA MAKAROVA	{"email": "makarova.zoya.1974@postgrespro.ru", "phone": "+70254191224"}
0005434276036	FD13CF	3432 644606	SERGEY KUZNECOV	{"phone": "+70624877375"}
0005434276037	45A424	4633 238174	ELENA AFANASEVA	{"phone": "+70800522983"}
0005434276038	45A424	0581 335149	ANDREY ALEKSEEV	{"email": "alekseev-andrey_121973@postgrespro.ru", "phone": "+70224751787"}
0005434276039	FE1325	5226 593659	SERGEY GUSEV	{"phone": "+70264930415"}
0005434276040	EC17EE	1235 190789	LIDIYA FEDOROVA	{"phone": "+70616630544"}
0005434276041	846F83	2076 212336	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey121976@postgrespro.ru", "phone": "+70609223519"}
0005434276042	0A429F	5999 986308	LYUBOV MOISEEVA	{"email": "lyubovmoiseeva-1972@postgrespro.ru", "phone": "+70522071715"}
0005434276043	54B651	6616 174096	ELIZAVETA MOROZOVA	{"phone": "+70967820406"}
0005434276044	54B651	3577 862579	LYUBOV IVANOVA	{"email": "lyubov_ivanova_21011973@postgrespro.ru", "phone": "+70654682937"}
0005434276045	59B81D	8660 810652	YULIYA ROMANOVA	{"email": "y.romanova-17101976@postgrespro.ru", "phone": "+70075889764"}
0005434276047	59B81D	1314 164528	NATALIYA SMIRNOVA	{"phone": "+70472114969"}
0005434276048	59B81D	3210 629277	TAMARA NIKITINA	{"email": "nikitina.tamara.25031968@postgrespro.ru", "phone": "+70560053286"}
0005434276049	9CDD35	0156 976436	SEMEN VASILEV	{"email": "vasilev_s.19081976@postgrespro.ru", "phone": "+70765230179"}
0005434276050	EDF062	9040 641881	VASILIY POPOV	{"phone": "+70328357181"}
0005434276051	EDF062	4274 998049	ALEKSANDRA VOLKOVA	{"email": "aleksandra_volkova_18111966@postgrespro.ru", "phone": "+70373227070"}
0005434276052	229FBB	5810 437809	EKATERINA KUZNECOVA	{"email": "kuznecova-ekaterina.12011977@postgrespro.ru", "phone": "+70796575685"}
0005434276053	E6BF0C	3141 954303	EVGENIY IVANOV	{"phone": "+70529098144"}
0005434276054	3EC8ED	5635 589647	DMITRIY SOROKIN	{"email": "sorokindmitriy-1985@postgrespro.ru", "phone": "+70401892125"}
0005434276055	71F624	6937 726285	RASHIT IVANOV	{"phone": "+70982467656"}
0005434276056	F1508F	4306 272722	ALEKSANDR GERASIMOV	{"email": "a-gerasimov.091970@postgrespro.ru", "phone": "+70606958132"}
0005434276057	F1508F	7092 058082	YURIY ZHURAVLEV	{"phone": "+70477403711"}
0005434276058	7538D3	0196 488636	YULIYA ANDREEVA	{"email": "andreeva_yuliya.051969@postgrespro.ru", "phone": "+70790544462"}
0005434276059	551914	1760 249219	LIDIYA ROMANOVA	{"email": "romanova_l_011971@postgrespro.ru", "phone": "+70129650120"}
0005434276060	03BC20	9619 111547	LIDIYA OSIPOVA	{"email": "lidiyaosipova1972@postgrespro.ru", "phone": "+70053259558"}
0005434276061	03BC20	7411 309459	ELENA VOLKOVA	{"phone": "+70130281906"}
0005434276062	9F3007	5823 873228	IRINA PETROVA	{"email": "irina.petrova-25011972@postgrespro.ru", "phone": "+70862216769"}
0005434276063	580174	9573 254349	DMITRIY SOKOLOV	{"phone": "+70814249078"}
0005434276064	0E19B0	9230 872111	NINA BORISOVA	{"email": "nina_borisova.061968@postgrespro.ru", "phone": "+70636570695"}
0005434276065	0E19B0	5528 492444	ALEKSANDR CHERNOV	{"phone": "+70583495366"}
0005434276066	3CCF5E	2113 643763	ALEKSEY ANDREEV	{"email": "andreev-aleksey-061974@postgrespro.ru", "phone": "+70940816118"}
0005434276067	3CCF5E	7993 740748	ALEKSANDR MAKAROV	{"phone": "+70264934912"}
0005434276068	CFA0A9	2311 079454	ELENA TARASOVA	{"phone": "+70344380002"}
0005434276069	20C043	3665 986440	MAYYA GRISHINA	{"email": "mayyagrishina1972@postgrespro.ru", "phone": "+70596205345"}
0005434276070	03808D	9293 564122	FEDOR MOISEEV	{"email": "moiseev.f.18061980@postgrespro.ru", "phone": "+70054187554"}
0005434276071	FAC98A	3619 711694	VERA KONOVALOVA	{"email": "konovalova.vera_11041974@postgrespro.ru", "phone": "+70756574252"}
0005434276072	8455A9	4750 459803	ANNA MASLOVA	{"email": "anna_maslova.25041968@postgrespro.ru", "phone": "+70535696128"}
0005434276074	7CD4D8	4114 742978	VALENTINA KRASNOVA	{"phone": "+70263072893"}
0005434276075	E7F14D	5603 453493	TATYANA MOROZOVA	{"email": "tatyana_morozova121968@postgrespro.ru", "phone": "+70521795137"}
0005434276076	F427C3	5736 505786	EGOR ILIN	{"phone": "+70240733719"}
0005434276077	D2BF72	8303 518134	ALEKSANDR PETROV	{"phone": "+70783255976"}
0005434276078	607CA8	6994 950714	NATALYA MOROZOVA	{"email": "morozova_n17051964@postgrespro.ru", "phone": "+70714603942"}
0005434276079	C733EE	8800 077221	PAVEL ORLOV	{"phone": "+70751700644"}
0005434276080	C733EE	7098 362430	RASHID NAUMOV	{"email": "rashid-naumov_19101987@postgrespro.ru", "phone": "+70414853889"}
0005434276081	23A732	7011 814272	DARYA KUZNECOVA	{"email": "kuznecovad.021967@postgrespro.ru", "phone": "+70643500898"}
0005434276082	77DEFF	4469 822638	NATALYA KUZNECOVA	{"phone": "+70112115943"}
0005434276083	C7A354	9182 077877	OLGA KOZLOVA	{"email": "o.kozlova.021974@postgrespro.ru", "phone": "+70715214254"}
0005434276084	31B7C0	1015 398016	PAVEL PETROV	{"phone": "+70953912874"}
0005434276085	AC21AB	7634 273366	ALEKSANDR VOROBEV	{"phone": "+70356095936"}
0005434276086	F7AE52	0573 297001	IRINA KUZMINA	{"phone": "+70940228702"}
0005434276087	BBD7B3	4490 356892	ALEKSANDR MOISEEV	{"email": "moiseev-aleksandr-111974@postgrespro.ru", "phone": "+70140895377"}
0005434276088	1A9BDF	0523 406263	ALEKSANDR TARASOV	{"phone": "+70693650725"}
0005434276089	D81AC7	6739 832833	GRIGORIY ROMANOV	{"email": "grigoriy-romanov.1966@postgrespro.ru", "phone": "+70081810686"}
0005434276090	D81AC7	9440 096019	IRINA AKIMOVA	{"email": "irina.akimova_1976@postgrespro.ru", "phone": "+70549502007"}
0005434276091	B44013	7218 910035	ILYA ALEKSEEV	{"phone": "+70232709227"}
0005434276092	B44013	8553 921354	IVAN MATVEEV	{"email": "matveev.i.1967@postgrespro.ru", "phone": "+70826715019"}
0005434276093	16CD13	7535 576504	VYACHESLAV SERGEEV	{"phone": "+70039612969"}
0005434276094	98DFE3	6200 511924	VALENTINA MOISEEVA	{"phone": "+70335512421"}
0005434276095	98DFE3	8840 357126	EKATERINA BOGDANOVA	{"phone": "+70168124961"}
0005434276096	6B6DF7	4785 336235	LYUDMILA KISELEVA	{"email": "l.kiseleva-1976@postgrespro.ru", "phone": "+70208456966"}
0005434276097	79CC87	3097 962076	TATYANA GORBUNOVA	{"email": "gorbunovat.10051975@postgrespro.ru", "phone": "+70607721995"}
0005434276098	79CC87	3333 295994	NADEZHDA IVANOVA	{"phone": "+70269210474"}
0005434276099	80B7A3	4569 233982	SEMEN SOKOLOV	{"email": "ssokolov.1969@postgrespro.ru", "phone": "+70805045629"}
0005434276100	C0B793	8091 389229	OLESYA YAKOVLEVA	{"phone": "+70244448892"}
0005434276101	3CE438	8691 318004	GALIYA KOROLEVA	{"phone": "+70868424953"}
0005434276102	575FF3	8558 157612	MARINA TITOVA	{"email": "m_titova-16041973@postgrespro.ru", "phone": "+70276649350"}
0005434276103	07E272	9432 788308	IRINA PETROVA	{"email": "irinapetrova_21011974@postgrespro.ru", "phone": "+70420218896"}
0005434276104	07E272	1250 157197	LYUDMILA MIKHAYLOVA	{"email": "l.mikhaylova_31101968@postgrespro.ru", "phone": "+70266693989"}
0005434276105	C1875F	8459 256782	LYUDMILA MARTYNOVA	{"phone": "+70053586352"}
0005434276106	BE6E60	6983 012405	VLADISLAV KISELEV	{"phone": "+70528742148"}
0005434276107	D12676	9288 116188	NINA KRASNOVA	{"email": "nina-krasnova04041970@postgrespro.ru", "phone": "+70393208306"}
0005434276108	DF2006	5701 601490	ALEKSEY SERGEEV	{"phone": "+70892138530"}
0005434276109	939F02	4180 797409	EKATERINA LUKYANOVA	{"phone": "+70698226896"}
0005434276110	39E59A	0549 602845	VLADIMIR KRASNOV	{"phone": "+70908627118"}
0005434276111	769BF6	4342 559303	KARINA DANILOVA	{"phone": "+70989494444"}
0005434276112	EBBF4D	6498 235048	EDUARD ZAKHAROV	{"phone": "+70817657668"}
0005434276113	FDE1E0	7346 120235	EVGENIY MAKAROV	{"phone": "+70064509279"}
0005434276114	F14F81	8223 045581	VLADIMIR KONOVALOV	{"email": "v_konovalov051973@postgrespro.ru", "phone": "+70491970080"}
0005434276115	F14F81	2374 577172	SERGEY ISAEV	{"email": "s.isaev_1968@postgrespro.ru", "phone": "+70127363869"}
0005434276116	05A25D	9370 146876	SERGEY PETROV	{"phone": "+70136803022"}
0005434276117	BE3076	5029 064690	NIKITA BARANOV	{"phone": "+70489762858"}
0005434276118	BE3076	3990 369183	ALEKSANDR SEMENOV	{"email": "semenova-021965@postgrespro.ru", "phone": "+70042702320"}
0005434276119	BE3076	0226 189487	MAKSIM EGOROV	{"email": "m_egorov.1970@postgrespro.ru", "phone": "+70340078519"}
0005434276120	1B2566	4704 096179	DMITRIY GERASIMOV	{"email": "gerasimov.dmitriy16101969@postgrespro.ru", "phone": "+70696510528"}
0005434276121	1B2566	8766 630112	VYACHESLAV MAKAROV	{"phone": "+70606578654"}
0005434276122	467D2F	8989 839913	DARYA ORLOVA	{"phone": "+70631878506"}
0005434276123	467D2F	0137 826921	ANDREY POPOV	{"email": "andrey-popov-06051957@postgrespro.ru", "phone": "+70645545967"}
0005434276124	467D2F	6362 975145	VLADISLAV MIRONOV	{"email": "vladislav-mironov121973@postgrespro.ru", "phone": "+70626957193"}
0005434276125	843C19	4852 867186	NIKOLAY BORISOV	{"email": "nikolayborisov081969@postgrespro.ru", "phone": "+70506815704"}
0005434276126	075AFA	8659 689804	ALEKSANDRA MAKAROVA	{"email": "makarovaa.27021980@postgrespro.ru", "phone": "+70739035284"}
0005434276127	7ABE62	0501 011621	NAZAR MIRONOV	{"phone": "+70525063109"}
0005434276128	7ABE62	7947 814533	SERGEY ZAYCEV	{"email": "s.zaycev16051969@postgrespro.ru", "phone": "+70777888672"}
0005434276129	7ABE62	6688 799500	NINA IVANOVA	{"phone": "+70935112413"}
0005434276130	F0F330	4801 301607	TAISIYA FOMINA	{"phone": "+70393542948"}
0005434276131	F0F330	8420 071686	NADEZHDA YUDINA	{"phone": "+70036805195"}
0005434276132	D867FA	7459 809107	SERGEY MOROZOV	{"phone": "+70483273392"}
0005434276133	D867FA	6340 114393	ROMAN FROLOV	{"phone": "+70034295294"}
0005434276134	D867FA	1269 435602	ALEKSANDR NAZAROV	{"email": "nazarov.a101972@postgrespro.ru", "phone": "+70599628250"}
0005434276135	0ADAA0	5498 628760	VITALIY MIRONOV	{"phone": "+70009648476"}
0005434276136	0FE874	5803 585184	EGOR IVANOV	{"email": "egor-ivanov-15061984@postgrespro.ru", "phone": "+70625690249"}
0005434276137	0FE874	0417 389740	YAROSLAVA NIKIFOROVA	{"phone": "+70423678286"}
0005434276138	FCC82E	6319 323462	ALEKSANDR SOROKIN	{"email": "asorokin-02071967@postgrespro.ru", "phone": "+70336320217"}
0005434276139	FCC82E	7950 184732	PETR NIKITIN	{"email": "nikitinp1974@postgrespro.ru", "phone": "+70986300779"}
0005434276140	56D840	1123 533110	NATALYA DAVYDOVA	{"email": "davydova_natalya-051969@postgrespro.ru", "phone": "+70901550670"}
0005434276141	56D840	4489 509101	TATYANA NIKOLAEVA	{"phone": "+70719664344"}
0005434276142	C06DBD	8277 248089	VALENTINA EFREMOVA	{"phone": "+70761518965"}
0005434276143	0198E9	1456 599203	IGOR VASILEV	{"phone": "+70939513541"}
0005434276144	769B05	0019 039789	PAVEL VOROBEV	{"phone": "+70956218551"}
0005434276145	328460	8598 218754	ALEKSANDR PETROV	{"email": "aleksandrpetrov23071975@postgrespro.ru", "phone": "+70859670676"}
0005434276146	708CD8	5240 763823	ELENA KRASNOVA	{"email": "elena_krasnova17071983@postgrespro.ru", "phone": "+70896483481"}
0005434276147	A29F90	0777 963698	IRINA PAVLOVA	{"phone": "+70415412404"}
0005434276148	A29F90	2959 042867	LYUDMILA VOLKOVA	{"email": "lyudmila-volkova-081979@postgrespro.ru", "phone": "+70271899290"}
0005434276149	299B9F	9921 175450	ALEKSANDR POPOV	{"phone": "+70215406075"}
0005434276150	299B9F	2161 539906	ELENA NIKITINA	{"email": "enikitina-011982@postgrespro.ru", "phone": "+70763014855"}
0005434276151	2B3133	2966 884684	ALEKSANDR VOROBEV	{"phone": "+70082131445"}
0005434276152	2B3133	2845 586442	NIKITA ABRAMOV	{"phone": "+70152192471"}
0005434276153	2B3133	1037 627331	ILNUR ROMANOV	{"email": "ilnurromanov-041970@postgrespro.ru", "phone": "+70736439616"}
0005434276154	6E32CE	2557 461801	ANASTASIYA ANISIMOVA	{"phone": "+70246893007"}
0005434276155	6E32CE	8213 704913	MARGARITA BELYAEVA	{"email": "m_belyaeva_1981@postgrespro.ru", "phone": "+70066897103"}
0005434276156	787EE2	9762 231547	MIKHAIL SERGEEV	{"email": "sergeev-m1979@postgrespro.ru", "phone": "+70134824279"}
0005434276157	7A6262	3702 438774	SERGEY SMIRNOV	{"email": "smirnov_sergey1973@postgrespro.ru", "phone": "+70618884739"}
0005434276158	CD9C7A	7880 462142	VLADIMIR KRASNOV	{"phone": "+70488927035"}
0005434276159	4C2991	3394 467373	ALEKSEY SEMENOV	{"email": "aleksey.semenov111955@postgrespro.ru", "phone": "+70944869492"}
0005434276160	842E69	5129 749140	IRINA ERMAKOVA	{"phone": "+70859694842"}
0005434276161	AE8B0A	2094 893453	TATYANA VASILEVA	{"email": "t_vasileva24081976@postgrespro.ru", "phone": "+70424573241"}
0005434276162	AE8B0A	6391 040012	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-011979@postgrespro.ru", "phone": "+70019870140"}
0005434276163	87C7F6	0644 710309	ALEKSANDR NIKITIN	{"email": "nikitin-a_17051968@postgrespro.ru", "phone": "+70503770311"}
0005434276164	87C7F6	2691 896443	LYUBOV KUZMINA	{"phone": "+70309564201"}
0005434276165	87C7F6	6904 630797	IVAN KULIKOV	{"email": "kulikov-ivan.071972@postgrespro.ru", "phone": "+70569290513"}
0005434276166	2E6591	2993 793772	SERGEY FEDOROV	{"email": "s-fedorov-18101968@postgrespro.ru", "phone": "+70335806970"}
0005434276167	ECE0B1	1089 796215	LIDIYA EGOROVA	{"email": "lidiya.egorova-1971@postgrespro.ru", "phone": "+70655307672"}
0005434276168	ECE0B1	1877 269848	NADEZHDA LAZAREVA	{"email": "lazareva.nadezhda_1981@postgrespro.ru", "phone": "+70067136579"}
0005434276169	ECE0B1	4263 473643	SERGEY PETROV	{"phone": "+70364806437"}
0005434276170	2E5229	8409 371510	RAFAEL NIKOLAEV	{"phone": "+70194446838"}
0005434276171	042CDC	9806 310136	VALERIY SEMENOV	{"email": "semenov.valeriy_1958@postgrespro.ru", "phone": "+70146884389"}
0005434276172	5F18D8	8253 869648	FARID EGOROV	{"email": "egorov_farid011967@postgrespro.ru", "phone": "+70129587836"}
0005434276173	5F18D8	8023 714725	NIKOLAY ZHUKOV	{"phone": "+70738022924"}
0005434276174	F3F4B1	5974 847164	YURIY VOLKOV	{"email": "yuriyvolkov-1962@postgrespro.ru", "phone": "+70162284336"}
0005434276175	F3F4B1	3617 264769	SERGEY FROLOV	{"email": "frolov_sergey-1970@postgrespro.ru", "phone": "+70298363231"}
0005434276176	650E56	2335 301234	VALERIY KUDRYASHOV	{"email": "vkudryashov.031956@postgrespro.ru", "phone": "+70705342239"}
0005434276177	650E56	7446 389034	VALENTINA PETROVA	{"email": "petrova.v.1966@postgrespro.ru", "phone": "+70020444453"}
0005434276178	449E88	8600 894805	ILDAR ILIN	{"email": "iilin.1965@postgrespro.ru", "phone": "+70667086926"}
0005434276179	449E88	4254 890550	ALEKSANDR SOLOVEV	{"phone": "+70587302487"}
0005434276180	49CE4F	7503 933722	NINA BELYAEVA	{"email": "nina_belyaeva-25101980@postgrespro.ru", "phone": "+70227990026"}
0005434276181	688318	1253 304365	TAMARA LUKYANOVA	{"email": "t.lukyanova-1969@postgrespro.ru", "phone": "+70268218580"}
0005434276182	E7DDFB	6176 292155	SVETLANA NIKOLAEVA	{"email": "nikolaevasvetlana-08021976@postgrespro.ru", "phone": "+70549374795"}
0005434276183	50D21E	7791 280356	SVETLANA KUZNECOVA	{"phone": "+70159879954"}
0005434276184	9CE338	3101 494989	NINA KUZNECOVA	{"phone": "+70049684269"}
0005434276185	9CE338	2662 304409	VLADIMIR ILIN	{"email": "vladimir-ilin23061967@postgrespro.ru", "phone": "+70480230744"}
0005434276186	9CE338	8057 788245	MARIYA STEPANOVA	{"email": "mariya-stepanova1966@postgrespro.ru", "phone": "+70767913935"}
0005434276187	04B780	9786 957504	ANNA KUZNECOVA	{"phone": "+70690247207"}
0005434276188	04B780	8004 054168	KARINA TIKHONOVA	{"email": "karina_tikhonova_1964@postgrespro.ru", "phone": "+70588812891"}
0005434276189	877529	3360 126524	NATALYA FILATOVA	{"email": "natalyafilatova_1965@postgrespro.ru", "phone": "+70767019496"}
0005434276190	3735B3	3819 163256	ALEKSEY SOROKIN	{"email": "sorokinaleksey_1969@postgrespro.ru", "phone": "+70362662079"}
0005434276191	C9C584	1902 418547	ROMAN SOKOLOV	{"email": "rsokolov_01081966@postgrespro.ru", "phone": "+70089522325"}
0005434276192	C9C584	2320 312183	GALINA IVANOVA	{"phone": "+70939864723"}
0005434276193	4A9BFF	0415 648416	ALEKSEY FILIPPOV	{"email": "a.filippov_091986@postgrespro.ru", "phone": "+70694421454"}
0005434276194	4A9BFF	1167 269790	ANDREY ZAKHAROV	{"phone": "+70842294023"}
0005434276195	6CEE0A	5602 035008	ALEKSANDR MAKAROV	{"phone": "+70697724666"}
0005434276196	95BC1F	3263 994009	GALINA SOKOLOVA	{"email": "galina_sokolova_111978@postgrespro.ru", "phone": "+70842148539"}
0005434276197	57290C	8244 675922	VIKTOR SOROKIN	{"phone": "+70163555167"}
0005434276198	579796	4841 695898	DARYA TIKHONOVA	{"phone": "+70582543806"}
0005434276199	579796	2008 081908	ALEKSANDR PETROV	{"phone": "+70384112483"}
0005434286892	31F284	5456 248671	MARYAM VOLKOVA	{"phone": "+70413915095"}
0005434286893	44B7A7	3295 063390	MAKSIM NIKOLAEV	{"phone": "+70804362772"}
0005434286894	A00619	9203 532430	SVETLANA LOGINOVA	{"email": "loginovasvetlana_03121968@postgrespro.ru", "phone": "+70914653721"}
0005434286895	A00619	1369 267388	ELIZAVETA KUZNECOVA	{"phone": "+70732364327"}
0005434286896	CD7E02	1698 773414	VIKTORIYA KUDRYASHOVA	{"email": "viktoriya.kudryashova.18071967@postgrespro.ru", "phone": "+70506116329"}
0005434286897	ED6514	2460 538772	ELENA SIDOROVA	{"phone": "+70165559465"}
0005434286898	C6047D	6138 575722	OLEG ALEKSEEV	{"phone": "+70552094927"}
0005434286899	C6047D	5441 162731	ELENA PAVLOVA	{"phone": "+70361320295"}
0005434286900	35B863	7278 329806	ALEKSANDR ISAEV	{"email": "isaevaleksandr-29041985@postgrespro.ru", "phone": "+70081212706"}
0005434286901	2668A6	6307 511019	TAISIYA SIDOROVA	{"email": "sidorova.taisiya.21071982@postgrespro.ru", "phone": "+70478375878"}
0005434286902	2668A6	8716 182559	SVETLANA SMIRNOVA	{"email": "smirnova.svetlana-061965@postgrespro.ru", "phone": "+70457719763"}
0005434286903	CAC37A	8606 224385	ANNA KONDRATEVA	{"email": "kondrateva_a-061974@postgrespro.ru", "phone": "+70590090923"}
0005434286904	CAC37A	1242 150870	ALEKSEY KAZAKOV	{"email": "a.kazakov.18061967@postgrespro.ru", "phone": "+70271716930"}
0005434286905	B7862C	8596 967272	YANA PAVLOVA	{"email": "y.pavlova-071976@postgrespro.ru", "phone": "+70106935775"}
0005434286906	06D4D2	0986 237228	SERGEY KUZNECOV	{"phone": "+70111656924"}
0005434286907	A02098	6323 229685	MIKHAIL KULIKOV	{"email": "kulikov-mikhail.1988@postgrespro.ru", "phone": "+70145062650"}
0005434286908	7E029E	7079 747587	SERGEY SOKOLOV	{"email": "sokolov_s011967@postgrespro.ru", "phone": "+70982001368"}
0005434286909	1C9F82	2801 046128	EKATERINA KUZNECOVA	{"phone": "+70749883229"}
0005434286910	5659A0	3063 259113	NINA ZOTOVA	{"email": "n_zotova.1963@postgrespro.ru", "phone": "+70554608529"}
0005434286911	5659A0	4965 588142	ALEKSEY KOZLOV	{"phone": "+70446009076"}
0005434286912	5659A0	6444 478777	SVETLANA KONOVALOVA	{"phone": "+70423043166"}
0005434286913	B35368	1830 516620	VARVARA VLASOVA	{"email": "vlasova.varvara.031979@postgrespro.ru", "phone": "+70444500423"}
0005434286914	5E75D6	7493 375903	EGOR TIMOFEEV	{"phone": "+70992131617"}
0005434286915	228147	8281 436554	OLGA VOLKOVA	{"email": "olgavolkova.1972@postgrespro.ru", "phone": "+70140711834"}
0005434286916	DC45E8	4741 142006	NATALYA ALEKSANDROVA	{"phone": "+70397835544"}
0005434286917	7F7B9C	8142 617711	TATYANA KONOVALOVA	{"email": "konovalova-t.051967@postgrespro.ru", "phone": "+70097790714"}
0005434286918	D90C62	8350 905509	ALEKSANDR MOISEEV	{"email": "moiseev-a03011982@postgrespro.ru", "phone": "+70642530036"}
0005434286919	C00FD3	6878 914696	RUSTEM POPOV	{"phone": "+70101100085"}
0005434286920	17CB19	1320 254952	ELIZAVETA LEBEDEVA	{"email": "lebedevaelizaveta.111968@postgrespro.ru", "phone": "+70752899714"}
0005434286921	69B3D6	3681 399759	OLGA TIKHONOVA	{"email": "tikhonova-o_26051976@postgrespro.ru", "phone": "+70678488089"}
0005434286922	DEE94D	1759 108351	FEDOR PETROV	{"phone": "+70978312635"}
0005434286923	719116	9330 975395	VLADIMIR MAKSIMOV	{"email": "maksimov.v-031980@postgrespro.ru", "phone": "+70798652386"}
0005434286924	F83624	6634 730771	IVAN KUZNECOV	{"email": "ikuznecov.1962@postgrespro.ru", "phone": "+70961069282"}
0005434286925	F83624	7331 336444	TAISIYA VASILEVA	{"email": "taisiya-vasileva_061979@postgrespro.ru", "phone": "+70408793468"}
0005434286926	537936	9990 997015	OLESYA MAKAROVA	{"email": "olesya-makarova-011975@postgrespro.ru", "phone": "+70330790990"}
0005434286927	537936	2718 953367	NADEZHDA GUSEVA	{"phone": "+70228383391"}
0005434286928	A27EF5	9433 626144	DMITRIY BELOV	{"email": "dbelov.051968@postgrespro.ru", "phone": "+70241932257"}
0005434286929	E3E14A	5237 127276	ALEKSEY AFANASEV	{"phone": "+70770434580"}
0005434286930	4C5333	7180 346214	EVGENIYA GERASIMOVA	{"phone": "+70493147439"}
0005434286931	4C5333	7918 134812	NADEZHDA KUZNECOVA	{"phone": "+70178309715"}
0005434286932	4DB887	4707 887682	NATALYA SIDOROVA	{"phone": "+70542579083"}
0005434286933	DF4E0A	0853 004795	TATYANA PETROVA	{"phone": "+70419221436"}
0005434286934	DF4E0A	7674 174139	MARINA KUZNECOVA	{"email": "kuznecova.marina.28111970@postgrespro.ru", "phone": "+70533666974"}
0005434286935	377B56	4556 110094	SVETLANA DAVYDOVA	{"phone": "+70207810328"}
0005434286936	AB36B7	5675 822940	NADEZHDA KULIKOVA	{"phone": "+70429523891"}
0005434286937	72C999	1203 645643	PAVEL ZAYCEV	{"email": "pavel_zaycev_1969@postgrespro.ru", "phone": "+70760896108"}
0005434286938	817F80	7713 673334	RAISA CHERNOVA	{"phone": "+70475805341"}
0005434286939	8B5AC4	6929 646977	TAMARA POPOVA	{"phone": "+70558102345"}
0005434286940	6DD17A	1014 906397	LILIYA KOROLEVA	{"email": "koroleva-l.081975@postgrespro.ru", "phone": "+70446247698"}
0005434286941	5F9F1F	1501 435260	ALENA MAKAROVA	{"email": "makarova.alena.03041970@postgrespro.ru", "phone": "+70160673637"}
0005434286942	5F9F1F	0924 147817	ROMAN NIKITIN	{"phone": "+70764884428"}
0005434286943	F48935	4193 311759	NATALYA KOROLEVA	{"phone": "+70169435858"}
0005434286944	AF0EC2	2751 739711	ELENA KOLESNIKOVA	{"email": "elena.kolesnikova_05031960@postgrespro.ru", "phone": "+70010033362"}
0005434286945	AF0EC2	4876 148508	IRINA VLASOVA	{"phone": "+70860190101"}
0005434286946	AF0EC2	0132 487024	DENIS FEDOROV	{"phone": "+70110226541"}
0005434286947	E9F036	3339 067177	VIKTORIYA KUZNECOVA	{"email": "v-kuznecova-051982@postgrespro.ru", "phone": "+70061809490"}
0005434286948	E9F036	3430 511306	ARTEM BARANOV	{"email": "artem_baranov.081966@postgrespro.ru", "phone": "+70889828558"}
0005434286949	2C7F21	6424 451243	LIDIYA DMITRIEVA	{"email": "l_dmitrieva-1964@postgrespro.ru", "phone": "+70113817250"}
0005434286950	2C7F21	5197 350762	KAMIL ALEKSEEV	{"email": "kamil.alekseev_23071963@postgrespro.ru", "phone": "+70009109753"}
0005434287068	288FCF	7566 170832	VALENTINA VASILEVA	{"phone": "+70366611795"}
0005434286951	4169B3	9902 377768	NATALYA ALEKSEEVA	{"email": "alekseeva_natalya1958@postgrespro.ru", "phone": "+70739201111"}
0005434286952	398339	8251 966711	ALEKSANDR POPOV	{"email": "popovaleksandr13041966@postgrespro.ru", "phone": "+70449047811"}
0005434286953	398339	5658 674422	ALEKSANDRA MIKHAYLOVA	{"phone": "+70680040834"}
0005434286954	F61CFC	4566 692563	LARISA MELNIKOVA	{"phone": "+70782045684"}
0005434286955	67A1B2	6911 233927	RAISA ZOTOVA	{"phone": "+70264433835"}
0005434286956	67A1B2	5017 692144	LYUDMILA ANTONOVA	{"phone": "+70122394927"}
0005434286957	CC31AD	5221 166761	ANDREY ZAKHAROV	{"phone": "+70060481596"}
0005434286958	7633DB	6690 695976	VLADIMIR DENISOV	{"phone": "+70054589018"}
0005434286959	817847	7810 624312	VALENTINA PETROVA	{"email": "v_petrova-1975@postgrespro.ru", "phone": "+70996472411"}
0005434286960	C42403	6090 325052	ALEKSEY VASILEV	{"email": "vasilevaleksey-1970@postgrespro.ru", "phone": "+70883483048"}
0005434286961	0942C4	8809 966178	MARIYA ZHURAVLEVA	{"email": "m-zhuravleva.16071962@postgrespro.ru", "phone": "+70185769051"}
0005434286962	293B12	2178 081851	ALEKSANDR MAKAROV	{"phone": "+70478429002"}
0005434286963	96B00B	6566 341721	VALENTINA GRISHINA	{"email": "v-grishina-1973@postgrespro.ru", "phone": "+70050062541"}
0005434286964	77D715	2849 370538	ULYANA NAUMOVA	{"email": "naumovaulyana-1968@postgrespro.ru", "phone": "+70732885779"}
0005434286965	B2DC08	7302 888005	ANASTASIYA FROLOVA	{"email": "frolova_anastasiya051978@postgrespro.ru", "phone": "+70234684550"}
0005434286966	13E70A	1908 310086	RUSLAN POPOV	{"phone": "+70028562814"}
0005434286967	13E70A	8337 070294	ANNA ZAKHAROVA	{"phone": "+70997691921"}
0005434286968	A1F66B	9679 799231	PAVEL FOMIN	{"email": "pavel_fomin13111965@postgrespro.ru", "phone": "+70466064042"}
0005434286969	A1F66B	1938 899715	VENIAMIN ANDREEV	{"email": "andreev-v-30081974@postgrespro.ru", "phone": "+70824653650"}
0005434286970	A1F66B	8484 406613	MIKHAIL MOISEEV	{"phone": "+70314245391"}
0005434286971	A9CCC7	2214 484652	LARISA MARTYNOVA	{"email": "l_martynova-011979@postgrespro.ru", "phone": "+70758269646"}
0005434286972	AD2160	9423 706401	IVAN KAZAKOV	{"email": "kazakov-i031969@postgrespro.ru", "phone": "+70996835207"}
0005434286973	ADA3BA	0828 025565	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov021975@postgrespro.ru", "phone": "+70361861047"}
0005434286974	ADA3BA	7470 273297	LIDIYA LOGINOVA	{"email": "loginova-lidiya-1966@postgrespro.ru", "phone": "+70132601729"}
0005434286975	3697F4	1266 868659	TATYANA KUZNECOVA	{"email": "t_kuznecova.1973@postgrespro.ru", "phone": "+70783208763"}
0005434286976	BC2C67	8175 333764	ROMAN ALEKSEEV	{"email": "romanalekseev11061980@postgrespro.ru", "phone": "+70089330289"}
0005434286977	EB8A0D	8421 454694	SERGEY IVANOV	{"phone": "+70109461365"}
0005434286978	EB8A0D	7554 813112	LYUDMILA SAVELEVA	{"email": "saveleva.lyudmila_12081975@postgrespro.ru", "phone": "+70997182277"}
0005434286979	28D30E	9605 277429	MIKHAIL KOZLOV	{"email": "kozlov.mikhail.17051970@postgrespro.ru", "phone": "+70493223169"}
0005434286980	28D30E	3254 443699	ANDREY SIDOROV	{"phone": "+70533230866"}
0005434286981	17A6EA	2646 285713	MIKHAIL ZAKHAROV	{"phone": "+70511038938"}
0005434286982	17A6EA	9565 097437	ALEKSEY MATVEEV	{"phone": "+70258167389"}
0005434286983	E78D32	2115 209308	SNEZHANA MAKAROVA	{"email": "snezhana.makarova19121967@postgrespro.ru", "phone": "+70885656780"}
0005434286984	991176	6920 799546	MARIYA KUZNECOVA	{"email": "kuznecovamariya.30041984@postgrespro.ru", "phone": "+70614484262"}
0005434286985	7AD0A9	8238 562185	RASIM FEDOROV	{"phone": "+70552237050"}
0005434286986	7AD0A9	6930 303649	ALEKSEY BONDARENKO	{"email": "bondarenko_a-091974@postgrespro.ru", "phone": "+70340924059"}
0005434286987	7AD0A9	7857 209069	VITALIY KOZLOV	{"phone": "+70592153092"}
0005434286988	535802	4193 535486	KSENIYA BORISOVA	{"phone": "+70411468569"}
0005434286989	2E9A52	2169 291188	GENNADIY MIRONOV	{"email": "gennadiy-mironov21121967@postgrespro.ru", "phone": "+70787345133"}
0005434286990	1B6773	7264 202936	TATYANA DENISOVA	{"email": "tdenisova.051974@postgrespro.ru", "phone": "+70502781361"}
0005434286991	AAE8DD	5558 133741	ALLA POPOVA	{"email": "alla-popova.25091970@postgrespro.ru", "phone": "+70383236450"}
0005434286992	C1E877	7544 637380	VALENTINA ORLOVA	{"email": "orlovav-1962@postgrespro.ru", "phone": "+70488801186"}
0005434286993	C1E877	0880 414801	VALENTINA ZOTOVA	{"phone": "+70325158722"}
0005434286994	A2B192	9204 401678	NADEZHDA PAVLOVA	{"email": "n.pavlova1967@postgrespro.ru", "phone": "+70275501393"}
0005434286995	53B1E4	4297 932682	STANISLAV POPOV	{"email": "stanislav.popov-22031967@postgrespro.ru", "phone": "+70844160499"}
0005434286996	FBE06D	2916 042330	ALEKSEY ILIN	{"phone": "+70518874040"}
0005434286997	1E159C	1413 125536	DINA YUDINA	{"email": "yudina-dina081985@postgrespro.ru", "phone": "+70217724932"}
0005434286998	84AAA8	0189 292244	OLGA PETROVA	{"email": "olga-petrova12071973@postgrespro.ru", "phone": "+70662680653"}
0005434286999	C1003D	5498 903567	DAMIR YAKOVLEV	{"email": "d-yakovlev1973@postgrespro.ru", "phone": "+70281836069"}
0005434287000	C1003D	9780 541892	VALENTINA ROMANOVA	{"phone": "+70567740320"}
0005434287001	AB51AC	7890 745607	DMITRIY ROMANOV	{"phone": "+70236339459"}
0005434287002	D8EDD2	3889 730019	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.091970@postgrespro.ru", "phone": "+70608684368"}
0005434287003	775DF9	6382 974707	POLINA KARPOVA	{"phone": "+70229311837"}
0005434287004	F8ACEA	9840 740558	SAMIRA KUZNECOVA	{"phone": "+70882171373"}
0005434287005	A1D742	2643 980544	LIDIYA LUKYANOVA	{"phone": "+70647853662"}
0005434287006	7E0A69	8008 038570	PAVEL MIKHAYLOV	{"phone": "+70034908995"}
0005434287007	4C3FF5	0849 655187	NADEZHDA ZHURAVLEVA	{"email": "nadezhda.zhuravleva-041979@postgrespro.ru", "phone": "+70347634913"}
0005434287008	A90123	2472 013094	LYUDMILA DANILOVA	{"phone": "+70198603919"}
0005434287009	A90123	3422 505582	NIKOLAY BARANOV	{"email": "n_baranov-011982@postgrespro.ru", "phone": "+70073260317"}
0005434287010	761EB5	3566 371388	OLGA KARPOVA	{"email": "karpova_o14061979@postgrespro.ru", "phone": "+70362936596"}
0005434287011	1D2D8E	6395 054043	YURIY KULIKOV	{"email": "y-kulikov-16051967@postgrespro.ru", "phone": "+70715640805"}
0005434287012	1D2D8E	3693 935913	VALENTINA OVCHINNIKOVA	{"email": "ovchinnikova-v_1970@postgrespro.ru", "phone": "+70570912275"}
0005434287013	D72F04	8171 961541	LARISA SCHERBAKOVA	{"email": "l.scherbakova-1961@postgrespro.ru", "phone": "+70329414377"}
0005434287014	E73DD5	7883 522341	ANDREY VASILEV	{"email": "vasilev.a1966@postgrespro.ru", "phone": "+70059394593"}
0005434287015	5F372A	9337 320063	SOFYA IVANOVA	{"email": "sivanova101977@postgrespro.ru", "phone": "+70329091079"}
0005434287016	AF108B	5355 785292	NATALYA SOROKINA	{"phone": "+70998704723"}
0005434287017	AF108B	3796 478739	VLADIMIR ANDREEV	{"email": "andreev.vladimir-101980@postgrespro.ru", "phone": "+70095986439"}
0005434287018	73CEB8	1262 087386	ANAIT ANISIMOVA	{"phone": "+70948424239"}
0005434287019	C3BC4E	9572 858517	DENIS MAKAROV	{"email": "denis-makarov1979@postgrespro.ru", "phone": "+70919465829"}
0005434287020	C3BC4E	2724 430871	MARIYA BORISOVA	{"email": "mariya.borisova_011969@postgrespro.ru", "phone": "+70359909251"}
0005434287021	C3BC4E	7853 132164	ANASTASIYA POPOVA	{"phone": "+70423723769"}
0005434287022	A196D5	7680 018982	LYUDMILA TIKHONOVA	{"phone": "+70022473069"}
0005434287023	4EC85B	3302 612480	ANDREY VASILEV	{"phone": "+70390336106"}
0005434287024	1170C8	6496 425557	VASILIY SIDOROV	{"email": "vasiliy_sidorov-1972@postgrespro.ru", "phone": "+70360527455"}
0005434287025	13C2F4	9123 420328	SERGEY FILIPPOV	{"email": "s_filippov-1977@postgrespro.ru", "phone": "+70577538327"}
0005434287026	4386B3	1032 862109	IVAN MARTYNOV	{"email": "martynov-ivan_061964@postgrespro.ru", "phone": "+70312036151"}
0005434287027	7657E4	7342 058667	ZLATA GAVRILOVA	{"email": "gavrilova_z091978@postgrespro.ru", "phone": "+70919340552"}
0005434287028	BBB8FA	5498 151889	NATALYA SAVELEVA	{"email": "natalyasaveleva_19081982@postgrespro.ru", "phone": "+70041209858"}
0005434287029	95D046	8516 105763	GENNADIY FOMIN	{"email": "g.fomin_1974@postgrespro.ru", "phone": "+70187914717"}
0005434287030	3949D1	8043 197225	MARINA PAVLOVA	{"email": "marinapavlova-091991@postgrespro.ru", "phone": "+70955992148"}
0005434287031	ECFB70	2204 314072	ELIZAVETA KRASNOVA	{"phone": "+70463572145"}
0005434287032	ECFB70	2148 434719	DANIYA KOVALEVA	{"email": "kovaleva-daniya.081959@postgrespro.ru", "phone": "+70416416815"}
0005434287033	6DED61	1983 490997	STANISLAV FEDOTOV	{"email": "stanislav_fedotov-1980@postgrespro.ru", "phone": "+70063686396"}
0005434287034	629F86	2469 301245	YURIY PAVLOV	{"email": "yuriy.pavlov.031980@postgrespro.ru", "phone": "+70316883097"}
0005434287035	629F86	8793 848523	SERGEY SIDOROV	{"phone": "+70659160478"}
0005434287036	629F86	8197 454382	OLGA GORBUNOVA	{"email": "gorbunova.o.061981@postgrespro.ru", "phone": "+70771986089"}
0005434287037	87AC4F	1701 588395	VLADIMIR NIKOLAEV	{"phone": "+70967690388"}
0005434287038	87AC4F	4911 064752	ANDREY BARANOV	{"email": "a-baranov.1977@postgrespro.ru", "phone": "+70942706672"}
0005434287039	805F0F	2432 516134	POLINA DAVYDOVA	{"email": "davydova.p081980@postgrespro.ru", "phone": "+70761017922"}
0005434287040	290904	3818 027126	RAISA DMITRIEVA	{"phone": "+70183243775"}
0005434287041	290904	5371 483467	YURIY DMITRIEV	{"email": "y_dmitriev_1970@postgrespro.ru", "phone": "+70007255530"}
0005434287042	297E21	2194 669906	ELVIRA SOLOVEVA	{"email": "elvirasoloveva.051965@postgrespro.ru", "phone": "+70549869997"}
0005434287043	D87E72	3914 135440	NATALYA STEPANOVA	{"email": "stepanova-n1969@postgrespro.ru", "phone": "+70598083186"}
0005434287044	CD5F3C	6258 291044	KIRILL FROLOV	{"email": "kirill.frolov.1968@postgrespro.ru", "phone": "+70076811959"}
0005434287045	CD5F3C	0925 289837	VERA MEDVEDEVA	{"phone": "+70898931559"}
0005434287046	B875D4	6375 107955	ANATOLIY SCHERBAKOV	{"phone": "+70271604331"}
0005434287047	EDE6D9	4490 531398	ALEKSANDR MELNIKOV	{"email": "melnikova041968@postgrespro.ru", "phone": "+70327133550"}
0005434287048	C89598	0887 640090	ALEKSANDR POPOV	{"email": "a.popov.06091974@postgrespro.ru", "phone": "+70832742941"}
0005434287049	DE40BF	6765 126275	ZOYA KUZNECOVA	{"phone": "+70674286493"}
0005434287050	DE40BF	9112 898020	EKATERINA KONDRATEVA	{"email": "kondrateva.e_06081969@postgrespro.ru", "phone": "+70983045493"}
0005434287051	2F5422	9341 942035	ALEKSEY ZAKHAROV	{"email": "zakharov-aleksey-10051980@postgrespro.ru", "phone": "+70979345203"}
0005434287052	2F5422	7039 485209	ALEKSEY DMITRIEV	{"email": "a_dmitriev_101973@postgrespro.ru", "phone": "+70576940140"}
0005434287053	951F39	9907 997986	GALINA MASLOVA	{"phone": "+70066092579"}
0005434287054	951F39	5869 051621	MARINA NIKITINA	{"email": "nikitina.m_1971@postgrespro.ru", "phone": "+70497015947"}
0005434287055	F275F2	4918 548481	PAVEL KOROLEV	{"email": "p_korolev1986@postgrespro.ru", "phone": "+70319924187"}
0005434287056	525C52	1834 241650	ALEKSANDR CHERNOV	{"phone": "+70654520564"}
0005434287057	53F558	4545 021652	SVETLANA POPOVA	{"phone": "+70244092280"}
0005434287058	53F558	4973 536566	VALENTIN PETROV	{"phone": "+70306579601"}
0005434287059	53F558	7251 003404	VERONIKA ISAEVA	{"phone": "+70817334796"}
0005434287060	693E6D	6199 408515	LILIYA SOKOLOVA	{"email": "l-sokolova011968@postgrespro.ru", "phone": "+70715761724"}
0005434287061	D4D894	3170 258932	DARYA ANTONOVA	{"phone": "+70525243315"}
0005434287062	0D8E65	5589 434745	ELENA MAKSIMOVA	{"phone": "+70832324841"}
0005434287063	A8DC16	5953 191516	NINA FEDOROVA	{"email": "fedorova.nina_1977@postgrespro.ru", "phone": "+70858451765"}
0005434287064	1D014F	8111 093855	NATALYA MAKAROVA	{"email": "makarova-n.25031985@postgrespro.ru", "phone": "+70652798792"}
0005434287065	0A74AA	6610 427693	VLADIMIR MELNIKOV	{"phone": "+70653459013"}
0005434287066	5F7D1D	8089 808378	NINA EFREMOVA	{"email": "efremova_nina-051972@postgrespro.ru", "phone": "+70918852911"}
0005434287067	8914BA	9789 820221	GEORGIY MIRONOV	{"email": "georgiymironov-1976@postgrespro.ru", "phone": "+70011935185"}
0005434287069	146E3E	2211 410899	TATYANA DMITRIEVA	{"phone": "+70752227900"}
0005434287070	146E3E	7167 726634	LYUDMILA RODIONOVA	{"phone": "+70430105365"}
0005434287071	EE28AD	5193 156572	ALEKSANDR MAKAROV	{"phone": "+70393323066"}
0005434287072	631519	6121 448678	FEDOR TARASOV	{"phone": "+70228303688"}
0005434287073	0B6155	6044 628382	ANATOLIY MIKHAYLOV	{"phone": "+70918407194"}
0005434287074	548359	5469 061644	DENIS KISELEV	{"email": "d-kiselev-1973@postgrespro.ru", "phone": "+70546529619"}
0005434287075	548359	7782 422254	ANNA VASILEVA	{"email": "vasileva_a_051982@postgrespro.ru", "phone": "+70581149186"}
0005434287076	E3354E	4626 328165	LYUBOV KAZAKOVA	{"phone": "+70271593969"}
0005434287077	E3354E	6160 521767	LIDIYA KAZAKOVA	{"phone": "+70348050561"}
0005434287078	CA8FFA	5151 604214	ALEKSANDRA NAZAROVA	{"phone": "+70166675708"}
0005434287079	920E1B	8103 059146	ANASTASIYA SERGEEVA	{"phone": "+70596823613"}
0005434287080	49756F	1784 781641	SERGEY BORISOV	{"email": "s-borisov081966@postgrespro.ru", "phone": "+70454991881"}
0005434287081	49756F	0093 598483	PAVEL ANTONOV	{"email": "pavel.antonov-25021972@postgrespro.ru", "phone": "+70919392439"}
0005434287082	3666F4	2909 440513	ALEKSANDR SOROKIN	{"email": "sorokin_a_1954@postgrespro.ru", "phone": "+70451316856"}
0005434287083	C986C1	1111 244780	TIMUR ISAEV	{"phone": "+70239707763"}
0005434287084	5D88CC	7702 214065	OLGA KUZMINA	{"email": "o.kuzmina_1968@postgrespro.ru", "phone": "+70251413147"}
0005434287085	9D691E	8642 212749	SERGEY IVANOV	{"phone": "+70394037887"}
0005434287086	A648A2	0062 176750	POLINA ROMANOVA	{"email": "romanova_polina.27071976@postgrespro.ru", "phone": "+70990081784"}
0005434287087	A648A2	4271 227898	LIDIYA FOMINA	{"email": "lidiyafomina_1980@postgrespro.ru", "phone": "+70439547157"}
0005434287088	33331D	4639 978157	MARGARITA FILIPPOVA	{"email": "margarita.filippova-15021964@postgrespro.ru", "phone": "+70971051243"}
0005434287089	D3BC51	6698 736610	NIKOLAY VOLKOV	{"phone": "+70301081510"}
0005434287090	390645	7249 064047	ALEKSEY ANTONOV	{"phone": "+70783814291"}
0005434287091	390645	7150 588306	NIKOLAY NAUMOV	{"email": "n_naumov-10021970@postgrespro.ru", "phone": "+70879615283"}
0005434287092	390645	0656 022126	RINAT KUZNECOV	{"email": "rinatkuznecov.111960@postgrespro.ru", "phone": "+70065427793"}
0005434287093	1F09B0	9939 636320	ALEKSEY TIMOFEEV	{"email": "timofeev-aleksey_091966@postgrespro.ru", "phone": "+70925845582"}
0005434287094	FC167D	3727 803044	ANDREY SERGEEV	{"email": "andrey_sergeev_05051966@postgrespro.ru", "phone": "+70170740356"}
0005434287095	41CC7B	2539 506066	SVETLANA BORISOVA	{"phone": "+70389622421"}
0005434287096	20ECE0	2685 542651	TAMARA FROLOVA	{"email": "tamara_frolova.061969@postgrespro.ru", "phone": "+70618053698"}
0005434287097	7CDF2E	7807 637150	PAVEL PAVLOV	{"phone": "+70386682852"}
0005434287098	E8AE01	3960 417729	ELENA SOROKINA	{"phone": "+70145264599"}
0005434287099	F89941	4382 511631	LIDIYA TITOVA	{"phone": "+70907469842"}
0005434287100	D81290	2064 940342	YULIYA CHERNOVA	{"phone": "+70761604401"}
0005434287101	E53806	9312 350402	VALENTIN SIDOROV	{"phone": "+70285045414"}
0005434287102	FD652A	1911 017221	NIKOLAY NAZAROV	{"phone": "+70575515265"}
0005434287103	DF6FAA	8108 961613	SERGEY MAKAROV	{"email": "makarovs.111972@postgrespro.ru", "phone": "+70110249746"}
0005434287104	E2C1A7	4448 929258	NINA SEMENOVA	{"phone": "+70480157779"}
0005434287105	E2C1A7	1273 102063	EVGENIYA MATVEEVA	{"email": "e.matveeva1968@postgrespro.ru", "phone": "+70231486217"}
0005434287106	E5D095	9560 199478	ALEKSANDR SOROKIN	{"email": "sorokin.a_021978@postgrespro.ru", "phone": "+70392911941"}
0005434287107	8ABF05	2867 784803	MARIANNA NESTEROVA	{"phone": "+70511363199"}
0005434287108	4B7818	9020 832622	PAVEL IVANOV	{"email": "ivanovp-081970@postgrespro.ru", "phone": "+70330642905"}
0005434287109	48DCA6	4542 874476	TATYANA ANTONOVA	{"email": "t.antonova.25011981@postgrespro.ru", "phone": "+70506455721"}
0005434287110	48DCA6	4771 051559	RIMMA KAZAKOVA	{"email": "r.kazakova10111974@postgrespro.ru", "phone": "+70143934410"}
0005434287111	20296D	4837 874360	VIKTOR VASILEV	{"phone": "+70481483747"}
0005434287112	81A2F2	3911 475460	ANNA SOLOVEVA	{"email": "soloveva_a021958@postgrespro.ru", "phone": "+70089475834"}
0005434287113	CD35D5	1821 201689	OLGA KOZLOVA	{"email": "olgakozlova_111980@postgrespro.ru", "phone": "+70597121257"}
0005434287114	CD35D5	8698 827352	OLGA GUSEVA	{"phone": "+70402424354"}
0005434287115	570717	0150 066179	TAMARA TIMOFEEVA	{"phone": "+70277791420"}
0005434287116	3F6E88	7863 817084	ALEKSANDR GUSEV	{"email": "gusev-aleksandr-29021976@postgrespro.ru", "phone": "+70252873695"}
0005434287117	41D827	5817 578251	PETR DMITRIEV	{"email": "dmitriev-petr.19091974@postgrespro.ru", "phone": "+70207288918"}
0005434287118	41D827	8190 276465	NADEZHDA TROFIMOVA	{"email": "n.trofimova.1981@postgrespro.ru", "phone": "+70692292921"}
0005434287119	48B606	1560 115906	SERGEY KAZAKOV	{"email": "sergeykazakov.23011978@postgrespro.ru", "phone": "+70366806807"}
0005434287120	48B606	1346 140894	MIKHAIL PETROV	{"email": "petrov.m.1969@postgrespro.ru", "phone": "+70973754498"}
0005434287121	F4880A	4602 073642	SERGEY KOZLOV	{"phone": "+70911915593"}
0005434287122	F4880A	5362 592238	SERGEY MELNIKOV	{"email": "s_melnikov-13061966@postgrespro.ru", "phone": "+70890375054"}
0005434287123	C22D03	8723 073125	NINA POPOVA	{"email": "nina.popova031969@postgrespro.ru", "phone": "+70516488176"}
0005434287124	41DEA2	0370 465193	OLGA IVANOVA	{"email": "ivanova-olga_13111956@postgrespro.ru", "phone": "+70927674123"}
0005434287125	41DEA2	8012 461454	ALEKSANDR MEDVEDEV	{"phone": "+70584458095"}
0005434287126	F8CEA5	3978 036685	ALEKSANDR AFANASEV	{"email": "afanasev-aleksandr101980@postgrespro.ru", "phone": "+70579089409"}
0005434287127	F8CEA5	0068 440107	OLGA GAVRILOVA	{"phone": "+70774561275"}
0005434287128	81A2AA	6040 860399	ALEKSANDR SOKOLOV	{"phone": "+70352342180"}
0005434287129	FF72EF	4367 405672	LARISA OSIPOVA	{"phone": "+70856247571"}
0005434287130	3F5A9A	4886 429715	ANDREY ILIN	{"email": "ilinandrey_081980@postgrespro.ru", "phone": "+70409824986"}
0005434287131	421F58	2353 512575	NIKITA MIRONOV	{"email": "mironov.nikita121960@postgrespro.ru", "phone": "+70202653394"}
0005434287132	421F58	1351 211311	ANASTASIYA LEBEDEVA	{"phone": "+70048623670"}
0005434287133	8775F3	8012 995312	RITA ROMANOVA	{"phone": "+70621322943"}
0005434287134	8775F3	0393 748304	OLEG BORISOV	{"email": "oleg.borisov.1973@postgrespro.ru", "phone": "+70499347408"}
0005434287135	8775F3	8475 171214	IRINA EGOROVA	{"email": "irinaegorova121957@postgrespro.ru", "phone": "+70470815913"}
0005434287136	4BCCCB	5847 718836	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_v03061974@postgrespro.ru", "phone": "+70672289535"}
0005434287137	4BCCCB	6134 438241	GENNADIY ZAYCEV	{"email": "gennadiy-zaycev-1977@postgrespro.ru", "phone": "+70596963307"}
0005434287138	4BCCCB	8835 403205	INNA KOLESNIKOVA	{"phone": "+70426701660"}
0005434287139	CE3E64	5664 213920	ILDUS TIKHONOV	{"email": "tikhonovildus_29061966@postgrespro.ru", "phone": "+70687660324"}
0005434287140	CE3E64	7424 106059	NATALYA ALEKSANDROVA	{"email": "naleksandrova.12121969@postgrespro.ru", "phone": "+70902359400"}
0005434287141	CE3E64	9928 207016	TATYANA KARPOVA	{"email": "karpova_tatyana_081978@postgrespro.ru", "phone": "+70646184713"}
0005434287142	79C078	8569 396366	TATYANA NOVIKOVA	{"phone": "+70658704012"}
0005434287143	79C078	2119 538803	NADEZHDA ISAEVA	{"email": "nisaeva.011969@postgrespro.ru", "phone": "+70317395935"}
0005434287144	79C078	8031 467442	IRINA ZAKHAROVA	{"phone": "+70840538342"}
0005434287145	5F9F02	6725 502020	IRINA ANTONOVA	{"email": "antonova-irina_081972@postgrespro.ru", "phone": "+70401584660"}
0005434287146	BFBF8E	9758 791745	VYACHESLAV STEPANOV	{"email": "stepanov-v-1973@postgrespro.ru", "phone": "+70763660851"}
0005434287147	8DBCBE	7986 704952	ALEKSANDR MAKSIMOV	{"phone": "+70106052992"}
0005434287148	5EA675	0777 357045	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr.101985@postgrespro.ru", "phone": "+70708498019"}
0005434287149	5EA675	2176 010070	PETR ILIN	{"phone": "+70065810699"}
0005434287150	4B069F	8645 385837	LIDIYA NIKOLAEVA	{"phone": "+70679254174"}
0005434287151	59BCAA	7795 763506	ALEKSEY NAZAROV	{"email": "anazarov.121972@postgrespro.ru", "phone": "+70351546642"}
0005434287152	0AD435	4643 572595	VLADISLAV ALEKSEEV	{"phone": "+70708465492"}
0005434287153	2EA460	0712 548285	ALLA POPOVA	{"phone": "+70764518394"}
0005434287154	93937F	9473 525494	OLGA NESTEROVA	{"email": "onesterova1970@postgrespro.ru", "phone": "+70983527158"}
0005434287155	DFA66B	1013 155462	VYACHESLAV PETROV	{"phone": "+70836491492"}
0005434287156	887986	4207 993204	ALEKSANDR DENISOV	{"phone": "+70641309311"}
0005434287157	887986	6365 715673	KSENIYA MOROZOVA	{"email": "morozovak.05011968@postgrespro.ru", "phone": "+70884722175"}
0005434287158	493314	2674 349564	NINA NOVIKOVA	{"phone": "+70219112263"}
0005434287159	672A6F	6486 086006	LIDIYA ZHURAVLEVA	{"email": "zhuravleva_lidiya-1978@postgrespro.ru", "phone": "+70806670292"}
0005434287160	64AA03	3646 618066	VYACHESLAV SIDOROV	{"phone": "+70353678629"}
0005434287161	64AA03	8383 844864	TAISIYA YAKOVLEVA	{"phone": "+70613640973"}
0005434287162	04A398	1068 673164	LYUBOV MAKAROVA	{"phone": "+70909070847"}
0005434287163	D6EA91	5492 267231	VLADIMIR NOVIKOV	{"phone": "+70436224490"}
0005434287164	D6EA91	9124 995369	MARINA MALYSHEVA	{"phone": "+70821666250"}
0005434287165	E1F4A8	3805 797507	VERA OSIPOVA	{"email": "osipovavera1973@postgrespro.ru", "phone": "+70691983179"}
0005434287166	7D9179	7864 272069	LIDIYA VASILEVA	{"email": "vasilevalidiya1969@postgrespro.ru", "phone": "+70274744935"}
0005434287167	D8B3D8	6157 874302	IRINA SIDOROVA	{"email": "irina-sidorova-071975@postgrespro.ru", "phone": "+70218666473"}
0005434287168	D8B3D8	1708 779812	ELENA ROMANOVA	{"email": "elena-romanova30071968@postgrespro.ru", "phone": "+70991821076"}
0005434287169	0F0B90	8701 300724	LYUBOV TROFIMOVA	{"email": "trofimovalyubov_111968@postgrespro.ru", "phone": "+70685679983"}
0005434287170	2EC136	7357 202832	OLGA SIDOROVA	{"email": "olga.sidorova.081974@postgrespro.ru", "phone": "+70038279342"}
0005434287171	2EC136	0557 226542	ZINAIDA MIRONOVA	{"email": "mironova.z_22091963@postgrespro.ru", "phone": "+70358524655"}
0005434287172	932E48	2781 083181	ALEKSANDR NAZAROV	{"phone": "+70340065259"}
0005434287173	35B3D9	5785 088951	YURIY DENISOV	{"email": "denisov_yuriy_011973@postgrespro.ru", "phone": "+70734996610"}
0005434287174	A21042	1361 563583	MAKSIM SIDOROV	{"email": "sidorovm.14011974@postgrespro.ru", "phone": "+70760031693"}
0005434287175	A21042	7158 285448	ELENA LEBEDEVA	{"phone": "+70706591908"}
0005434287176	CA5E32	0940 489603	ELENA OSIPOVA	{"phone": "+70865753080"}
0005434287177	786060	7340 904714	VLADIMIR ZAKHAROV	{"phone": "+70923370085"}
0005434287178	786060	6805 883738	ALEKSANDR MARTYNOV	{"phone": "+70167024215"}
0005434287179	165424	7445 907468	GALINA BOGDANOVA	{"email": "bogdanova_g_091972@postgrespro.ru", "phone": "+70814874640"}
0005434287180	165424	8145 207480	ANDREY KUZNECOV	{"email": "kuznecov-andrey1973@postgrespro.ru", "phone": "+70212524179"}
0005434287181	165424	3061 062746	NATALYA NIKITINA	{"phone": "+70790042661"}
0005434287182	165424	4283 177315	YULIYA PAVLOVA	{"email": "pavlova.yuliya1966@postgrespro.ru", "phone": "+70248961142"}
0005434287183	9F95F5	2236 997694	LARISA FILIPPOVA	{"phone": "+70314989259"}
0005434287184	9F31CD	4635 507774	VERA GRISHINA	{"email": "vgrishina_101973@postgrespro.ru", "phone": "+70021488624"}
0005434287185	12833E	4560 320119	SERGEY EGOROV	{"phone": "+70997331416"}
0005434287186	12833E	6549 097795	VLADIMIR MIRONOV	{"email": "mironovvladimir-091969@postgrespro.ru", "phone": "+70941036545"}
0005434287187	1E82DE	1579 849600	IGOR MAKSIMOV	{"phone": "+70052449292"}
0005434287188	67E3EA	3529 836611	SERGEY AFANASEV	{"email": "s_afanasev-061969@postgrespro.ru", "phone": "+70203180894"}
0005434287189	67E3EA	8933 715306	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana021974@postgrespro.ru", "phone": "+70550055174"}
0005434287190	25B12C	8187 384823	SERGEY NAZAROV	{"email": "snazarov.1976@postgrespro.ru", "phone": "+70510233389"}
0005434287191	CB1319	2656 641755	SOFYA KOVALEVA	{"email": "kovaleva_sofya_22051965@postgrespro.ru", "phone": "+70039454750"}
0005434287192	004251	4757 308048	VALENTINA DAVYDOVA	{"email": "valentina.davydova_031971@postgrespro.ru", "phone": "+70480808039"}
0005434287193	2868A8	5276 839345	LYUDMILA MELNIKOVA	{"email": "l-melnikova.071964@postgrespro.ru", "phone": "+70736729447"}
0005434287194	B89EC4	8766 634445	ANNA CHERNOVA	{"email": "chernova-a.07061975@postgrespro.ru", "phone": "+70299938628"}
0005434287195	80A047	4375 871861	MARIYA SOKOLOVA	{"phone": "+70711282265"}
0005434287196	F8C2EC	7993 143433	GALINA MEDVEDEVA	{"phone": "+70578257067"}
0005434287197	F8C2EC	1962 053183	VLADIMIR TIKHONOV	{"phone": "+70314722648"}
0005434287198	0DA40A	8170 138235	SVETLANA ROMANOVA	{"phone": "+70704269713"}
0005434287199	0F8C28	7386 624296	SERGEY POPOV	{"phone": "+70824002932"}
0005434287200	51DC8C	6530 102706	DMITRIY MATVEEV	{"email": "d_matveev01011973@postgrespro.ru", "phone": "+70909258714"}
0005434287201	CF0208	5807 130702	KIRILL NIKOLAEV	{"email": "nikolaev.k.111975@postgrespro.ru", "phone": "+70730455867"}
0005434287202	D4F398	3496 021103	ELIZAVETA FILIPPOVA	{"phone": "+70241531101"}
0005434287203	CF5F2B	6326 454685	ARSENIY ANTONOV	{"email": "a.antonov_031974@postgrespro.ru", "phone": "+70548760424"}
0005434287204	CF5F2B	5695 800785	GALINA ISAEVA	{"phone": "+70257930754"}
0005434287205	391BDF	7563 570584	ANDREY DENISOV	{"phone": "+70735598975"}
0005434287206	B203F5	6773 188225	ALEKSANDR KOZLOV	{"phone": "+70133481157"}
0005434287207	9149F7	0579 808274	VALENTINA ALEKSANDROVA	{"email": "aleksandrova.v_1973@postgrespro.ru", "phone": "+70133285994"}
0005434287208	526CF8	2319 614482	IVAN KONOVALOV	{"phone": "+70839467610"}
0005434287209	1DB69B	0295 207131	LYUDMILA KONDRATEVA	{"phone": "+70861588504"}
0005434287210	3D4B33	6406 898662	LYUBOV TIMOFEEVA	{"email": "ltimofeeva.14011970@postgrespro.ru", "phone": "+70776581312"}
0005434287211	AB4B4F	3920 287046	IVAN RODIONOV	{"phone": "+70029915901"}
0005434287212	BFA95F	7015 863609	MIKHAIL KAZAKOV	{"email": "mikhail-kazakov.021977@postgrespro.ru", "phone": "+70617316673"}
0005434287213	112226	6601 588818	VALERIYA RODIONOVA	{"email": "rodionova-valeriya_081967@postgrespro.ru", "phone": "+70480572017"}
0005434287214	112226	3718 649241	SERGEY SOROKIN	{"phone": "+70575696138"}
0005434287215	739183	5995 280947	EVGENIY ZAYCEV	{"email": "e-zaycev03071974@postgrespro.ru", "phone": "+70276717645"}
0005434287216	8C8060	2431 576769	TAMARA KOROLEVA	{"phone": "+70737993096"}
0005434287217	8C8060	1826 585117	LILIYA SEMENOVA	{"email": "liliya.semenova.051978@postgrespro.ru", "phone": "+70661358450"}
0005434287218	F78E7A	8288 611344	ALEKSANDR SMIRNOV	{"phone": "+70279122085"}
0005434287219	4D5956	0733 902387	IVAN KUZNECOV	{"email": "kuznecov.ivan.031969@postgrespro.ru", "phone": "+70661753234"}
0005434287220	4D5956	2409 070832	EKATERINA EFIMOVA	{"phone": "+70156289101"}
0005434287221	C9F40A	3011 728267	VLADIMIR KUZNECOV	{"phone": "+70739196153"}
0005434287222	C9F40A	8611 251701	VYACHESLAV MAKSIMOV	{"phone": "+70811703380"}
0005434287223	7C9628	5497 366760	ANTONINA SOROKINA	{"phone": "+70639628407"}
0005434287224	636F72	5441 645800	VALENTINA KONOVALOVA	{"email": "konovalova_v.1976@postgrespro.ru", "phone": "+70785624094"}
0005434287225	FDF49D	3740 711699	EVGENIY MEDVEDEV	{"phone": "+70116347645"}
0005434287226	E0E868	1880 221661	GENNADIY ZHUKOV	{"phone": "+70734454130"}
0005434287227	E0E868	3092 755176	DANIIL STEPANOV	{"email": "stepanovd1981@postgrespro.ru", "phone": "+70568753797"}
0005434287228	E0E868	5536 056244	ARTEM FILIPPOV	{"phone": "+70948737595"}
0005434287229	E9981F	5092 787627	SERGEY KUZNECOV	{"email": "sergeykuznecov_14041977@postgrespro.ru", "phone": "+70914869039"}
0005434287230	E9981F	5944 853770	DMITRIY KAZAKOV	{"phone": "+70512948122"}
0005434287231	BF9F90	5958 345449	ANGELINA TIKHONOVA	{"phone": "+70539033424"}
0005434287232	A3AEB8	4706 808378	ANZHELIKA YUDINA	{"phone": "+70023117879"}
0005434287233	A3AEB8	3573 723080	ALEKSANDR SCHERBAKOV	{"phone": "+70124110519"}
0005434287234	29BF4C	1695 674482	ALEKSANDR ABRAMOV	{"phone": "+70074301712"}
0005434287235	29BF4C	5717 549322	ALINA ALEKSANDROVA	{"email": "aleksandrovaalina.05121976@postgrespro.ru", "phone": "+70071538109"}
0005434287236	A1F8E5	3190 027052	YURIY YAKOVLEV	{"phone": "+70761584045"}
0005434287237	CE3EE7	2367 384148	EVGENIY RODIONOV	{"email": "rodionovevgeniy.1982@postgrespro.ru", "phone": "+70125581558"}
0005434287238	1D74E1	0719 037879	ALEKSANDR VOROBEV	{"email": "vorobeva.28071987@postgrespro.ru", "phone": "+70461365876"}
0005434287239	68CEBC	6513 363326	ELENA AKIMOVA	{"email": "akimova.elena-051968@postgrespro.ru", "phone": "+70120538547"}
0005434287240	EFB8E8	6309 183611	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov.1968@postgrespro.ru", "phone": "+70113876098"}
0005434287241	C916B0	3162 868676	NATALYA MELNIKOVA	{"phone": "+70471039262"}
0005434287242	7B8D5A	4733 282692	VERA FADEEVA	{"email": "vera_fadeeva1973@postgrespro.ru", "phone": "+70654063604"}
0005434287243	27DFA3	4446 644113	SERGEY GAVRILOV	{"phone": "+70600121639"}
0005434287244	85162D	7130 601845	ARSENIY VOROBEV	{"phone": "+70314473025"}
0005434287245	789450	3341 935237	VALENTINA KUZMINA	{"email": "kuzmina_v_18081975@postgrespro.ru", "phone": "+70089083098"}
0005434287246	1D61B9	7160 085641	GENNADIY SMIRNOV	{"email": "smirnov-gennadiy16111968@postgrespro.ru", "phone": "+70848846841"}
0005434287469	A30B64	7517 066632	NIKOLAY PETROV	{"phone": "+70524187152"}
0005434287247	12A4A0	5343 208065	IRINA SOKOLOVA	{"email": "sokolova-irina.121976@postgrespro.ru", "phone": "+70059878071"}
0005434287248	5BC2A4	0662 732609	ELENA NESTEROVA	{"email": "elena.nesterova.081976@postgrespro.ru", "phone": "+70017575801"}
0005434287249	7D29A5	6611 741798	ILYA SMIRNOV	{"phone": "+70202524617"}
0005434287250	D73758	4449 021028	MARGARITA DAVYDOVA	{"phone": "+70673252014"}
0005434287251	4ECE01	6661 479573	ALEKSEY SEMENOV	{"phone": "+70839628420"}
0005434287252	A201D3	3204 443563	ALEKSEY ROMANOV	{"email": "aleksey-romanov-1974@postgrespro.ru", "phone": "+70983928667"}
0005434287253	A201D3	7888 219216	IRINA AKIMOVA	{"email": "akimova_i-17011971@postgrespro.ru", "phone": "+70446454668"}
0005434287254	02A942	9732 918406	LARISA ZAYCEVA	{"email": "larisa-zayceva081972@postgrespro.ru", "phone": "+70592084763"}
0005434287255	0DECCB	7563 841500	ANTON ZHUKOV	{"email": "zhukov-anton-29011976@postgrespro.ru", "phone": "+70056139585"}
0005434287256	C8749F	1309 785673	YULIYA POPOVA	{"email": "popovayuliya021973@postgrespro.ru", "phone": "+70819841720"}
0005434287257	C8749F	6780 115121	NATALYA ARKHIPOVA	{"email": "arkhipova_natalya_1984@postgrespro.ru", "phone": "+70358611601"}
0005434287258	3C3377	9669 307214	ELENA IVANOVA	{"phone": "+70177239327"}
0005434287259	3C3377	1352 287640	LARISA ZHURAVLEVA	{"email": "lzhuravleva-11091972@postgrespro.ru", "phone": "+70030863842"}
0005434287260	6BB872	2150 926682	VALENTINA NOVIKOVA	{"phone": "+70674339016"}
0005434287261	D4758C	5003 830805	ZINAIDA TIKHONOVA	{"email": "z.tikhonova.101965@postgrespro.ru", "phone": "+70570341672"}
0005434287262	D4758C	3371 682244	TIGRAN KUZNECOV	{"phone": "+70564646488"}
0005434287263	217512	5330 794929	TATYANA KISELEVA	{"phone": "+70380677810"}
0005434287264	7596F5	9033 506415	OLGA KALININA	{"phone": "+70341908088"}
0005434287265	7596F5	5594 130491	ELENA VASILEVA	{"phone": "+70912600075"}
0005434287266	DC1E10	3760 496554	VLADIMIR ROMANOV	{"email": "romanov-v21081977@postgrespro.ru", "phone": "+70842875856"}
0005434287267	401DDC	5037 016874	IGOR ROMANOV	{"email": "i-romanov_23101976@postgrespro.ru", "phone": "+70137687394"}
0005434287268	93D857	4076 644511	VALERIY BONDARENKO	{"phone": "+70262260676"}
0005434287269	EE15E8	6254 847451	ALEKSANDR MARTYNOV	{"email": "a.martynov_23071968@postgrespro.ru", "phone": "+70018344962"}
0005434287270	A319FF	8187 758516	IVAN NAZAROV	{"phone": "+70070099887"}
0005434287271	FB51BD	9873 031549	MAKSIM SMIRNOV	{"phone": "+70336090541"}
0005434287272	265465	8849 478581	GALINA PETROVA	{"phone": "+70558380756"}
0005434287273	265465	5098 294099	NINA ANTONOVA	{"phone": "+70475405062"}
0005434287274	265465	1886 984786	EKATERINA ZAYCEVA	{"email": "zayceva_ekaterina06051975@postgrespro.ru", "phone": "+70998431339"}
0005434287275	6F145E	2631 031157	SVETLANA NESTEROVA	{"phone": "+70005968692"}
0005434287276	6F145E	6770 613126	ALEKSANDR ISAEV	{"email": "aleksandr_isaev.1961@postgrespro.ru", "phone": "+70032316542"}
0005434287277	F1C389	8507 579757	SERGEY SHEVCHENKO	{"email": "s_shevchenko1959@postgrespro.ru", "phone": "+70402887586"}
0005434287278	F1C389	2577 724497	DMITRIY FEDOTOV	{"phone": "+70046695874"}
0005434287279	4D0780	9594 336898	SVETLANA MIKHAYLOVA	{"email": "s-mikhaylova-1973@postgrespro.ru", "phone": "+70639057495"}
0005434287280	C89CB1	0350 644686	IRINA POPOVA	{"phone": "+70764846941"}
0005434287281	C89CB1	5066 300833	ARINA SEMENOVA	{"phone": "+70661574987"}
0005434287282	EAAB76	3157 186026	POLINA KOROLEVA	{"phone": "+70861683125"}
0005434287283	0EF4DA	7568 743153	GALINA POTAPOVA	{"email": "potapova_g1983@postgrespro.ru", "phone": "+70626661796"}
0005434287284	D5E512	0880 689867	MAKSIM ZAKHAROV	{"email": "m_zakharov_1977@postgrespro.ru", "phone": "+70557712587"}
0005434287285	D5E512	7803 959853	SVETLANA POTAPOVA	{"phone": "+70203342119"}
0005434287286	BAE656	8014 981334	EVGENIY GUSEV	{"email": "e.gusev-061980@postgrespro.ru", "phone": "+70214062703"}
0005434287287	BAE656	4174 623962	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy.1980@postgrespro.ru", "phone": "+70531132284"}
0005434287288	E96ED2	7799 271546	OLGA KONOVALOVA	{"email": "konovalova_olga101967@postgrespro.ru", "phone": "+70470647636"}
0005434287289	C729AE	1874 137818	DMITRIY KARPOV	{"phone": "+70721370778"}
0005434287290	C729AE	2557 174522	VALERIY OSIPOV	{"email": "osipov-valeriy.1970@postgrespro.ru", "phone": "+70805705153"}
0005434287291	0F534E	3720 190216	SERGEY SEMENOV	{"phone": "+70116168704"}
0005434287292	0F534E	5618 125766	ALEKSANDRA GUSEVA	{"email": "guseva.aleksandra061970@postgrespro.ru", "phone": "+70148582232"}
0005434287293	1CA2E8	2519 817159	OLGA KUDRYASHOVA	{"phone": "+70206336258"}
0005434287294	1CA2E8	7739 643311	SERGEY FROLOV	{"email": "frolov_s27021973@postgrespro.ru", "phone": "+70782100289"}
0005434287295	8480BB	5382 050010	VIKTOR IVANOV	{"phone": "+70684274267"}
0005434287296	18C8F5	2218 447164	ALEKSANDR KARPOV	{"phone": "+70933683467"}
0005434287297	4F2908	7519 912236	GALINA VASILEVA	{"email": "vasileva-g-1958@postgrespro.ru", "phone": "+70175250049"}
0005434287298	D13FF3	9370 041602	VLADIMIR KUZMIN	{"email": "kuzmin-v_1962@postgrespro.ru", "phone": "+70114745082"}
0005434287299	D13FF3	7127 318095	VITALIY GUSEV	{"email": "gusev_vitaliy1977@postgrespro.ru", "phone": "+70435794126"}
0005434287300	D13FF3	9339 665373	ANATOLIY KUZNECOV	{"phone": "+70697958887"}
0005434287301	37B1EC	2685 403231	ARTEM ANDREEV	{"email": "andreev.artem_06061963@postgrespro.ru", "phone": "+70879411243"}
0005434287302	37B1EC	2289 056673	ALEKSEY VOROBEV	{"phone": "+70406480145"}
0005434287303	978A37	4907 239683	ANASTASIYA SCHERBAKOVA	{"email": "a.scherbakova.1980@postgrespro.ru", "phone": "+70499261746"}
0005434287304	504239	6838 487307	VIKTORIYA KUZNECOVA	{"email": "viktoriyakuznecova-081970@postgrespro.ru", "phone": "+70250792179"}
0005434287305	CC65C6	5443 710209	ALEKSEY FEDOROV	{"phone": "+70212043316"}
0005434287306	42A1E3	0926 329764	EVGENIY NIKOLAEV	{"email": "nikolaev.evgeniy1973@postgrespro.ru", "phone": "+70006032870"}
0005434287307	42A1E3	9136 272228	IRINA MOISEEVA	{"email": "i_moiseeva_1980@postgrespro.ru", "phone": "+70656254483"}
0005434287308	314FA2	5821 434574	IGOR ZAYCEV	{"phone": "+70851337957"}
0005434287309	314FA2	4738 570503	LIDIYA NIKOLAEVA	{"phone": "+70945271557"}
0005434287310	7B58EF	6677 635208	ANDREY IVANOV	{"phone": "+70127273990"}
0005434287311	15E1BF	4481 927944	NIKOLAY NAUMOV	{"phone": "+70902231202"}
0005434287312	15E1BF	1723 211738	ARTEM STEPANOV	{"email": "artem_stepanov.1981@postgrespro.ru", "phone": "+70731820333"}
0005434287313	17CD81	0876 465730	NATALYA POPOVA	{"phone": "+70699143760"}
0005434287314	17CD81	6253 234860	EVGENIY MAKSIMOV	{"email": "evgeniy.maksimov_15121977@postgrespro.ru", "phone": "+70314998076"}
0005434287315	BD2178	5209 910552	OLGA KARPOVA	{"email": "karpova.o-02071981@postgrespro.ru", "phone": "+70669778717"}
0005434287316	C3EE77	6868 364932	VIOLETTA MARTYNOVA	{"email": "violetta.martynova_101983@postgrespro.ru", "phone": "+70733491677"}
0005434287317	045178	8310 883230	ELENA PAVLOVA	{"phone": "+70365463656"}
0005434287318	BE1E12	5067 575618	LIDIYA VASILEVA	{"phone": "+70135677594"}
0005434287319	BE1E12	3155 090213	VALERIY SMIRNOV	{"email": "smirnovv1964@postgrespro.ru", "phone": "+70538043535"}
0005434287320	4EB3F1	8059 891318	EKATERINA MIRONOVA	{"email": "e_mironova_101990@postgrespro.ru", "phone": "+70941753699"}
0005434287321	4113CB	6142 323209	IRINA FROLOVA	{"phone": "+70066818263"}
0005434287322	4113CB	7379 102640	VIKTOR ZAKHAROV	{"email": "zakharovviktor_1985@postgrespro.ru", "phone": "+70764687546"}
0005434287323	3F8E21	8560 606908	ANTONINA SOLOVEVA	{"email": "a-soloveva.111968@postgrespro.ru", "phone": "+70288991818"}
0005434287324	3F8E21	2826 472810	TAMARA GRISHINA	{"email": "grishina.t13051969@postgrespro.ru", "phone": "+70433209833"}
0005434287325	8DF5C1	5113 914150	DMITRIY RODIONOV	{"phone": "+70172543036"}
0005434287326	E28686	5603 845854	ALEKSANDR GUSEV	{"email": "a.gusev_1989@postgrespro.ru", "phone": "+70372824403"}
0005434287327	7B07DB	5332 998653	VALERIY MAKAROV	{"phone": "+70063638380"}
0005434287328	7B07DB	2098 884500	POLINA BELYAEVA	{"phone": "+70948280131"}
0005434287329	7B07DB	9429 768081	ALFIYA ANISIMOVA	{"phone": "+70615727785"}
0005434287330	7B07DB	1538 116420	RUSTAM MEDVEDEV	{"phone": "+70145853932"}
0005434287331	C965AA	1743 977479	ANASTASIYA VLASOVA	{"phone": "+70186277105"}
0005434287332	37A05E	4287 840203	ANNA SERGEEVA	{"phone": "+70734781740"}
0005434287333	37A05E	6692 974666	DMITRIY BARANOV	{"phone": "+70827765960"}
0005434287334	37A05E	4118 464285	VIKTOR DENISOV	{"email": "denisov-viktor.081964@postgrespro.ru", "phone": "+70346974102"}
0005434287335	37A05E	0269 319425	SVETLANA KULIKOVA	{"email": "kulikovas-1967@postgrespro.ru", "phone": "+70233852211"}
0005434287336	FEB915	1504 967564	VIKTORIYA ILINA	{"email": "viktoriya.ilina.081965@postgrespro.ru", "phone": "+70555544278"}
0005434287337	FEB915	7686 397701	VIKTOR NAZAROV	{"email": "nazarov-viktor1966@postgrespro.ru", "phone": "+70195254261"}
0005434287338	EAE272	7828 256518	OLGA ZAKHAROVA	{"phone": "+70704874457"}
0005434287339	EAE272	3815 928860	NIKOLAY VASILEV	{"email": "vasilev-n17011965@postgrespro.ru", "phone": "+70168677427"}
0005434287340	EAE272	6592 659139	ELIZAVETA ANISIMOVA	{"phone": "+70389969680"}
0005434287341	E36F5F	9792 533925	TAMARA NOVIKOVA	{"email": "novikova_tamara04031974@postgrespro.ru", "phone": "+70821503532"}
0005434287342	AA5E8E	3553 700325	NATALYA STEPANOVA	{"phone": "+70627099995"}
0005434287343	74E70E	1065 045205	RUSLAN NIKOLAEV	{"email": "nikolaevr_1975@postgrespro.ru", "phone": "+70716126828"}
0005434287344	74E70E	0375 706156	DAVID ILIN	{"phone": "+70356562971"}
0005434287345	74E70E	8893 286966	NATALYA ISAEVA	{"phone": "+70185231307"}
0005434287346	74E70E	2650 934689	OLGA FROLOVA	{"email": "olga.frolova-16121975@postgrespro.ru", "phone": "+70836965184"}
0005434287347	0B61FD	8755 207144	ALEKSEY KARPOV	{"phone": "+70931342040"}
0005434287348	012C94	7054 339032	ALEKSANDR PETROV	{"email": "petrov_a-031962@postgrespro.ru", "phone": "+70614034272"}
0005434287349	012C94	6808 657640	VLADISLAV NOVIKOV	{"email": "novikov.vladislav-1967@postgrespro.ru", "phone": "+70781023534"}
0005434287350	1BDFFC	0554 785735	NIKOLAY DMITRIEV	{"phone": "+70158452151"}
0005434287351	68F783	7012 586665	RIMMA NAZAROVA	{"phone": "+70037735742"}
0005434287352	B05916	8602 292873	OLESYA ALEKSANDROVA	{"email": "olesyaaleksandrova.031976@postgrespro.ru", "phone": "+70265191006"}
0005434287353	ED5B07	8094 225321	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev17091964@postgrespro.ru", "phone": "+70690976300"}
0005434287354	ED5B07	9146 166681	DENIS FEDOROV	{"email": "denis.fedorov_22021964@postgrespro.ru", "phone": "+70361151494"}
0005434287355	DE702A	2624 947164	ELIZAVETA KOLESNIKOVA	{"email": "elizaveta_kolesnikova_1966@postgrespro.ru", "phone": "+70138653643"}
0005434287356	1C29C1	4861 557493	MARIYA KISELEVA	{"phone": "+70649534338"}
0005434287357	1C29C1	4696 621975	EKATERINA LEBEDEVA	{"email": "e_lebedeva.1962@postgrespro.ru", "phone": "+70230913882"}
0005434287358	1C29C1	5373 927167	LARISA GORBUNOVA	{"email": "larisa.gorbunova_101972@postgrespro.ru", "phone": "+70909817695"}
0005434287359	537D66	6527 002857	VALENTINA MELNIKOVA	{"email": "valentina_melnikova.101972@postgrespro.ru", "phone": "+70539581827"}
0005434287360	D3FD35	4728 789506	PAVEL SOKOLOV	{"email": "p.sokolov.1979@postgrespro.ru", "phone": "+70251897044"}
0005434287361	D3FD35	6696 484100	ALEKSEY BORISOV	{"email": "borisovaleksey-1964@postgrespro.ru", "phone": "+70903765430"}
0005434287362	5FDC1E	1680 504141	MIKHAIL MIKHAYLOV	{"email": "mikhail-mikhaylov1974@postgrespro.ru", "phone": "+70411476743"}
0005434287363	0953C6	5436 387102	IVAN VOLKOV	{"email": "volkov.i.1982@postgrespro.ru", "phone": "+70057392385"}
0005434287364	ED45E0	5207 367278	ALEKSANDR DAVYDOV	{"email": "davydova.1981@postgrespro.ru", "phone": "+70193025575"}
0005434287365	E48A74	0483 345603	ANDREY KARPOV	{"email": "karpov-a101972@postgrespro.ru", "phone": "+70099983145"}
0005434287366	A069C5	0230 995791	VALERIY ABRAMOV	{"email": "valeriy-abramov_22091970@postgrespro.ru", "phone": "+70528556206"}
0005434287367	A7DE22	0515 299095	SOFIYA RYABOVA	{"phone": "+70251545272"}
0005434287368	C6942D	0052 151939	YANA ANISIMOVA	{"email": "yana_anisimova_1965@postgrespro.ru", "phone": "+70439492713"}
0005434287369	09F774	3038 195431	ANATOLIY ZAKHAROV	{"phone": "+70019360934"}
0005434287370	09F774	1239 247505	NIKOLAY FEDOTOV	{"phone": "+70146749015"}
0005434287371	280BD1	1848 231824	ALEKSANDR ROMANOV	{"phone": "+70826077622"}
0005434287372	280BD1	7273 797854	EKATERINA KISELEVA	{"email": "ekaterina_kiseleva1974@postgrespro.ru", "phone": "+70355057756"}
0005434287373	8EAD67	7550 715922	STANISLAV KAZAKOV	{"email": "skazakov.17091963@postgrespro.ru", "phone": "+70183588044"}
0005434287374	FD8E0F	0988 937728	ILYA MIKHAYLOV	{"phone": "+70215491360"}
0005434287375	FD8E0F	5226 513548	YAROSLAV VOROBEV	{"email": "vorobevy061984@postgrespro.ru", "phone": "+70570518860"}
0005434287376	DAF805	9456 156267	VALENTINA SMIRNOVA	{"phone": "+70565729396"}
0005434287377	DAF805	0787 030784	SERGEY NAUMOV	{"email": "naumov-sergey_26021969@postgrespro.ru", "phone": "+70797319019"}
0005434287378	0EA365	2948 517043	TATYANA SOROKINA	{"phone": "+70039022859"}
0005434287379	0EA365	4916 712503	TATYANA ZHURAVLEVA	{"phone": "+70994833236"}
0005434287380	79AE62	0913 190522	MARIYA BELOVA	{"email": "belova_m-10061973@postgrespro.ru", "phone": "+70367130304"}
0005434287381	79AE62	2366 404289	NIKOLAY KOROLEV	{"email": "n.korolev-1984@postgrespro.ru", "phone": "+70197024411"}
0005434287382	79AE62	7637 244679	ANDREY MOISEEV	{"email": "moiseev-a-10091968@postgrespro.ru", "phone": "+70159233474"}
0005434287383	D46C04	2585 405252	ALISA SIDOROVA	{"email": "sidorovaalisa.1972@postgrespro.ru", "phone": "+70162456087"}
0005434287384	6FC3AE	1029 125889	NATALYA NESTEROVA	{"email": "nesterova-natalya-21011968@postgrespro.ru", "phone": "+70369225256"}
0005434287385	F37A84	8299 124224	MARINA ZAYCEVA	{"phone": "+70864924112"}
0005434287386	208598	8208 930779	EVGENIY SAVELEV	{"phone": "+70616793511"}
0005434287387	28DE0E	3668 713035	ANNA GAVRILOVA	{"phone": "+70294774850"}
0005434287388	28DE0E	0126 503196	EKATERINA MAKAROVA	{"phone": "+70603161237"}
0005434287389	97A501	1053 122280	IGNAT RODIONOV	{"email": "rodionovi071975@postgrespro.ru", "phone": "+70824494097"}
0005434287390	4EB6EB	2840 465203	DMITRIY EGOROV	{"phone": "+70577387097"}
0005434287391	D77BCD	8481 025242	ANATOLIY SERGEEV	{"phone": "+70127176229"}
0005434287392	3449B0	7963 359095	ALEKSANDR ABRAMOV	{"email": "abramov-aleksandr_18071965@postgrespro.ru", "phone": "+70513472108"}
0005434287393	E17081	7706 997247	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov_17031979@postgrespro.ru", "phone": "+70437395080"}
0005434287394	9700D9	7101 920118	ALEKSEY MIRONOV	{"email": "a.mironov.041973@postgrespro.ru", "phone": "+70122408226"}
0005434287395	9700D9	8822 022286	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko.1967@postgrespro.ru", "phone": "+70253916303"}
0005434287396	3C7443	3495 164942	ELENA ZOTOVA	{"phone": "+70450129702"}
0005434287397	3C7443	4244 154775	NIKOLAY MELNIKOV	{"phone": "+70015255988"}
0005434287398	5926FB	4253 027342	NIKITA KOZLOV	{"phone": "+70314392124"}
0005434287399	5926FB	7389 307033	ELENA CHERNOVA	{"email": "chernova_e.09091967@postgrespro.ru", "phone": "+70372695322"}
0005434287400	96320F	7628 603474	LYUDMILA FROLOVA	{"email": "froloval_1986@postgrespro.ru", "phone": "+70803881631"}
0005434287401	96320F	9742 372934	OLGA BORISOVA	{"phone": "+70632390430"}
0005434287402	26B30F	3004 926527	ELENA FROLOVA	{"email": "e-frolova_07041972@postgrespro.ru", "phone": "+70890225489"}
0005434287403	94D01A	0955 248473	MARIYA MATVEEVA	{"email": "mmatveeva-1974@postgrespro.ru", "phone": "+70181123835"}
0005434287404	94D01A	9876 459855	PETR SCHERBAKOV	{"phone": "+70864558367"}
0005434287405	BE49AD	6268 919458	ULYANA TITOVA	{"phone": "+70602996054"}
0005434287406	6C6B5A	5898 874427	ALEKSEY PAVLOV	{"phone": "+70619332059"}
0005434287407	6C6B5A	9115 905989	ANATOLIY BELOV	{"email": "a_belov.1981@postgrespro.ru", "phone": "+70912655052"}
0005434287408	501E93	2080 200342	SERGEY SAVELEV	{"email": "savelev.s18051975@postgrespro.ru", "phone": "+70465525708"}
0005434287409	501E93	5796 561928	MIKHAIL SMIRNOV	{"email": "smirnovm_021976@postgrespro.ru", "phone": "+70833613091"}
0005434287410	501E93	5201 551679	SERGEY KULIKOV	{"email": "sergey_kulikov18061966@postgrespro.ru", "phone": "+70280944377"}
0005434287411	44038D	8384 661206	NINA OSIPOVA	{"email": "osipova_nina_061978@postgrespro.ru", "phone": "+70083094327"}
0005434287412	635FD1	6875 441091	ARTEM MIKHAYLOV	{"email": "mikhaylov-artem25111974@postgrespro.ru", "phone": "+70925300600"}
0005434287413	8EBBA9	6388 091863	IGOR IVANOV	{"email": "ivanov.igor-13111982@postgrespro.ru", "phone": "+70221567323"}
0005434287414	6BABCC	2121 070360	RIMMA VOLKOVA	{"email": "volkova-r_1971@postgrespro.ru", "phone": "+70987509379"}
0005434287415	54F99B	1227 907008	NADEZHDA IVANOVA	{"phone": "+70266625061"}
0005434287416	54F99B	5099 117011	GALINA SERGEEVA	{"phone": "+70651065594"}
0005434287417	03F220	0822 569909	VIKTOR MATVEEV	{"phone": "+70474858654"}
0005434287418	D26DAB	2053 028892	VLADIMIR ALEKSEEV	{"email": "alekseev.vladimir_091976@postgrespro.ru", "phone": "+70900355550"}
0005434287419	196A8E	2974 464335	NATALYA SEMENOVA	{"email": "natalya.semenova23051967@postgrespro.ru", "phone": "+70287354618"}
0005434287420	196A8E	9508 768785	IVAN KUZNECOV	{"phone": "+70826315987"}
0005434287421	4DC1E0	6587 246977	ANATOLIY VLASOV	{"email": "vlasova081979@postgrespro.ru", "phone": "+70060355226"}
0005434287422	1775BD	6354 360203	ANDREY FEDOROV	{"phone": "+70564641820"}
0005434287423	C9190A	0774 111917	VIKTOR KUZNECOV	{"phone": "+70113610371"}
0005434287424	8B11B6	9584 223113	SERGEY YAKOVLEV	{"email": "yakovlev.sergey.011971@postgrespro.ru", "phone": "+70633348288"}
0005434287425	8B11B6	9601 575737	TATYANA ILINA	{"email": "ilinatatyana09081977@postgrespro.ru", "phone": "+70624787702"}
0005434287426	829BD2	7210 168042	VYACHESLAV SOKOLOV	{"email": "vyacheslav.sokolov06041966@postgrespro.ru", "phone": "+70072618627"}
0005434287427	829BD2	8463 372340	VITALIY MIRONOV	{"email": "vitaliymironov1958@postgrespro.ru", "phone": "+70418528788"}
0005434287428	21EE49	5879 845875	ALEKSEY ILIN	{"email": "ilin-a-14091975@postgrespro.ru", "phone": "+70127583807"}
0005434287429	DCDFB0	5448 844433	ALEKSEY ISAEV	{"email": "isaev-a.101964@postgrespro.ru", "phone": "+70415575683"}
0005434287430	C59C64	1235 778190	ELENA MARTYNOVA	{"email": "martynova_elena_1982@postgrespro.ru", "phone": "+70974156746"}
0005434287431	1196D5	8705 499125	LYUDMILA FROLOVA	{"phone": "+70494956636"}
0005434287432	8C2E3A	4901 492384	VIKTOR PETROV	{"phone": "+70245946130"}
0005434287433	738C7B	7874 949089	VLADIMIR GAVRILOV	{"email": "v.gavrilov1951@postgrespro.ru", "phone": "+70632716389"}
0005434287434	738C7B	8786 038551	VLADIMIR NIKOLAEV	{"phone": "+70108204175"}
0005434287435	DF3B08	2494 305860	DENIS KOZLOV	{"email": "kozlovdenis-1983@postgrespro.ru", "phone": "+70419371811"}
0005434287436	B860DB	7870 551718	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev_1957@postgrespro.ru", "phone": "+70815673137"}
0005434287437	05452D	3729 013690	MIKHAIL DENISOV	{"phone": "+70768624661"}
0005434287438	05452D	2404 120369	IREK MIKHAYLOV	{"email": "irek-mikhaylov_12111968@postgrespro.ru", "phone": "+70585778631"}
0005434287439	05452D	3061 470518	VYACHESLAV VASILEV	{"email": "vasilev-vyacheslav-011971@postgrespro.ru", "phone": "+70032875910"}
0005434287440	BBAE05	7252 984979	NAIL POPOV	{"phone": "+70074281634"}
0005434287441	BBAE05	3171 562638	VITALIY GUSEV	{"email": "gusev_v061968@postgrespro.ru", "phone": "+70270847194"}
0005434287442	C266AF	3519 590186	LYUBOV NIKITINA	{"email": "nikitina_l_1976@postgrespro.ru", "phone": "+70638073802"}
0005434287443	C266AF	1969 679235	GALINA POTAPOVA	{"phone": "+70368916580"}
0005434287444	B5FF90	6870 006464	POLINA AKIMOVA	{"email": "akimova.p.1963@postgrespro.ru", "phone": "+70740437284"}
0005434287445	6FF78F	8612 629964	IGOR IVANOV	{"email": "ivanov_igor031972@postgrespro.ru", "phone": "+70559606650"}
0005434287446	1F6A03	9492 923125	TATYANA PETROVA	{"phone": "+70237408690"}
0005434287447	96934F	9821 513739	ANNA IVANOVA	{"email": "aivanova24111977@postgrespro.ru", "phone": "+70615827154"}
0005434287448	531882	7316 562791	ALEKSEY SOKOLOV	{"phone": "+70826287529"}
0005434287449	531882	3132 040142	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin-011973@postgrespro.ru", "phone": "+70459387057"}
0005434287450	3E9A93	7966 813462	GALINA IVANOVA	{"email": "g-ivanova-031978@postgrespro.ru", "phone": "+70181234821"}
0005434287451	1DA35A	5065 747424	ANATOLIY SMIRNOV	{"email": "asmirnov-12071963@postgrespro.ru", "phone": "+70803091445"}
0005434287452	1DA35A	0043 702028	SERGEY PETROV	{"email": "petrov-sergey.23071966@postgrespro.ru", "phone": "+70900345029"}
0005434287453	1DA35A	6809 419436	ANNA MEDVEDEVA	{"phone": "+70877061969"}
0005434287454	F32BEA	0415 870611	ALEKSANDR VLASOV	{"email": "vlasova.011977@postgrespro.ru", "phone": "+70837968751"}
0005434287455	F32BEA	4102 948280	SERGEY FROLOV	{"email": "sergey.frolov1976@postgrespro.ru", "phone": "+70820558830"}
0005434287456	3DC6D0	7507 622346	OLGA KUZNECOVA	{"email": "olga.kuznecova.1985@postgrespro.ru", "phone": "+70586988008"}
0005434287457	3DC6D0	1471 750384	VLADIMIR ORLOV	{"email": "orlovv_031973@postgrespro.ru", "phone": "+70345774666"}
0005434287458	747387	4356 561573	YAKOV ANDREEV	{"phone": "+70816105201"}
0005434287459	002865	2923 660149	NATALYA BELOVA	{"email": "belova_natalya.031973@postgrespro.ru", "phone": "+70564764823"}
0005434287460	FDF991	3559 135363	SERGEY ILIN	{"email": "sergey_ilin-07101971@postgrespro.ru", "phone": "+70396869948"}
0005434287461	FDF991	5355 427828	SVETLANA FROLOVA	{"email": "svetlanafrolova1968@postgrespro.ru", "phone": "+70865702628"}
0005434287462	DD5336	5551 267567	NINA KOROLEVA	{"phone": "+70695132541"}
0005434287463	DD5336	2449 981625	ELENA DENISOVA	{"email": "e_denisova_1974@postgrespro.ru", "phone": "+70259651857"}
0005434287464	6CF3B7	9109 271954	TATYANA NAZAROVA	{"email": "t.nazarova_10091966@postgrespro.ru", "phone": "+70159181187"}
0005434287465	315CB0	0611 157200	VALENTINA AKIMOVA	{"phone": "+70910103042"}
0005434287466	4E7526	7958 763366	LEONID ZAKHAROV	{"email": "zakharovleonid_08021967@postgrespro.ru", "phone": "+70242545841"}
0005434287467	4E7526	2996 033679	SERGEY ALEKSEEV	{"phone": "+70932401842"}
0005434287468	5C7572	1229 035582	VERA IVANOVA	{"email": "v-ivanova_1968@postgrespro.ru", "phone": "+70288109297"}
0005434287470	B14C27	7360 788924	YURIY BELOV	{"email": "yuriybelov-111974@postgrespro.ru", "phone": "+70974668906"}
0005434287471	8B4F26	4606 519320	VALENTINA SEMENOVA	{"phone": "+70643185763"}
0005434287472	8B4F26	1108 861310	TAMARA NOVIKOVA	{"email": "novikova-tamara-13081976@postgrespro.ru", "phone": "+70409514953"}
0005434287473	4FA81A	7795 312173	DARYA KOMAROVA	{"email": "komarova_d.06111969@postgrespro.ru", "phone": "+70506513904"}
0005434287474	9C4323	0765 624682	OLEG ZHURAVLEV	{"email": "zhuravlev.o.081967@postgrespro.ru", "phone": "+70517522157"}
0005434287475	A3B866	8173 323160	YANA TARASOVA	{"phone": "+70038773869"}
0005434287476	A3B866	5607 890759	ARTEM KISELEV	{"email": "akiselev-1978@postgrespro.ru", "phone": "+70761301287"}
0005434287477	A3B866	7146 209157	SERGEY VOLKOV	{"phone": "+70829253788"}
0005434287478	829A2B	8695 913792	SERGEY FROLOV	{"email": "sergeyfrolov_20011963@postgrespro.ru", "phone": "+70697921822"}
0005434287479	6A2A74	9157 149764	OLGA FADEEVA	{"phone": "+70225682213"}
0005434287480	1FF00B	9497 167211	VALERIY KARPOV	{"phone": "+70539297845"}
0005434287481	662EC0	6799 803446	VYACHESLAV SOLOVEV	{"phone": "+70017485310"}
0005434287482	5D82CE	9366 556442	ALEKSANDR MIRONOV	{"email": "a.mironov_071967@postgrespro.ru", "phone": "+70641998387"}
0005434287483	5D82CE	4662 146250	EVGENIY YAKOVLEV	{"phone": "+70602878956"}
0005434287484	510A90	4830 054481	KSENIYA IVANOVA	{"email": "k-ivanova-01101974@postgrespro.ru", "phone": "+70507746879"}
0005434287485	510A90	9924 957127	SERGEY ANDREEV	{"email": "s_andreev1974@postgrespro.ru", "phone": "+70984184174"}
0005434287486	510A90	3479 319140	VLADISLAV ROMANOV	{"phone": "+70836770644"}
0005434287606	4E3FDB	4998 793700	VYACHESLAV MIKHAYLOV	{"phone": "+70034738594"}
0005434287487	84CBCF	9666 611210	ALFIYA KUZNECOVA	{"email": "a_kuznecova_111965@postgrespro.ru", "phone": "+70673476831"}
0005434287488	B41F2C	3901 688805	NATALYA IVANOVA	{"email": "ivanova-natalya.19101994@postgrespro.ru", "phone": "+70816449903"}
0005434287489	B41F2C	9460 975181	TATYANA ABRAMOVA	{"email": "tatyana.abramova-1986@postgrespro.ru", "phone": "+70809401441"}
0005434287490	2B81D3	7034 387392	MIKHAIL MARTYNOV	{"email": "mikhail.martynov_1976@postgrespro.ru", "phone": "+70568268459"}
0005434287491	D3B914	0007 053079	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov-1980@postgrespro.ru", "phone": "+70107741515"}
0005434287492	36ABE0	6647 590718	MAKSIM VASILEV	{"email": "mvasilev-1959@postgrespro.ru", "phone": "+70889161604"}
0005434287493	35BB87	8109 040061	FEDOR SOLOVEV	{"email": "f_solovev_28071961@postgrespro.ru", "phone": "+70031842365"}
0005434287494	35BB87	5682 545448	YULIYA SERGEEVA	{"email": "sergeeva_y-031967@postgrespro.ru", "phone": "+70882640055"}
0005434287495	91F46B	0329 301076	DMITRIY MELNIKOV	{"email": "melnikovdmitriy_1973@postgrespro.ru", "phone": "+70628647685"}
0005434287496	86E21B	3000 412128	SERGEY YAKOVLEV	{"email": "s_yakovlev-03101962@postgrespro.ru", "phone": "+70416921989"}
0005434287497	86E21B	6625 761925	VARVARA SEMENOVA	{"email": "semenova.v_28031973@postgrespro.ru", "phone": "+70726818742"}
0005434287498	86E21B	6011 021021	ANTON FOMIN	{"email": "anton-fomin_021980@postgrespro.ru", "phone": "+70654643485"}
0005434287499	E201DB	9119 151079	ANNA NAUMOVA	{"phone": "+70161833769"}
0005434287500	0D4BE8	7652 178521	NINA IVANOVA	{"email": "nivanova_25111970@postgrespro.ru", "phone": "+70211918421"}
0005434287501	0D4BE8	7117 720863	ILYA GORBUNOV	{"email": "i.gorbunov.081970@postgrespro.ru", "phone": "+70239215492"}
0005434287502	B9C0FF	0012 869938	DARYA NIKOLAEVA	{"email": "nikolaeva-darya-111980@postgrespro.ru", "phone": "+70104703376"}
0005434287503	B9C0FF	9439 508115	KONSTANTIN FEDOTOV	{"phone": "+70793784614"}
0005434287504	860935	4971 145192	BULAT SHEVCHENKO	{"phone": "+70021762441"}
0005434287505	860935	9440 032450	VYACHESLAV BONDARENKO	{"phone": "+70556651410"}
0005434287506	FEC11C	8916 633162	SERGEY SIDOROV	{"email": "s.sidorov.1969@postgrespro.ru", "phone": "+70686256323"}
0005434287507	FEC11C	7587 522621	GALINA ILINA	{"phone": "+70405397683"}
0005434287508	441B84	6196 004904	ALEKSANDRA KOZLOVA	{"email": "kozlova_aleksandra26021976@postgrespro.ru", "phone": "+70499336897"}
0005434287509	6BAC89	6929 884031	RENAT MEDVEDEV	{"email": "medvedev-renat_041960@postgrespro.ru", "phone": "+70124304389"}
0005434287510	F8EA01	4541 185918	ALINA OVCHINNIKOVA	{"phone": "+70293874277"}
0005434287511	F8EA01	9552 637818	SERGEY KUZNECOV	{"phone": "+70485412180"}
0005434287512	F2FE44	0187 433209	OLEG ZHUKOV	{"email": "o.zhukov07091974@postgrespro.ru", "phone": "+70857584542"}
0005434287513	DA1759	3543 093306	MARINA GERASIMOVA	{"email": "gerasimova.marina_1973@postgrespro.ru", "phone": "+70126645610"}
0005434287514	57558E	7200 678946	PAVEL IVANOV	{"phone": "+70661481768"}
0005434287515	36288D	0272 056496	YURIY POPOV	{"phone": "+70593604084"}
0005434287516	267953	8510 956684	SVETLANA ISAEVA	{"email": "isaeva-s.25051975@postgrespro.ru", "phone": "+70889649505"}
0005434287517	7A73BC	6820 958677	ALEKSEY SAVELEV	{"phone": "+70042381805"}
0005434287518	764456	1948 923850	TATYANA SAVELEVA	{"email": "t_saveleva26121966@postgrespro.ru", "phone": "+70969625913"}
0005434287519	B1AEC2	1479 692342	PAVEL RODIONOV	{"phone": "+70454777030"}
0005434287520	A9F7D3	4048 831740	ELENA TIKHONOVA	{"email": "elena.tikhonova-081973@postgrespro.ru", "phone": "+70480157292"}
0005434287521	A003D6	5608 017249	ANDREY ANTONOV	{"email": "aantonov-051964@postgrespro.ru", "phone": "+70320581904"}
0005434287522	A003D6	9393 307450	LYUBOV CHERNOVA	{"email": "lchernova25071960@postgrespro.ru", "phone": "+70283512639"}
0005434287523	1839E4	9297 044726	NATALYA VASILEVA	{"email": "nvasileva_101979@postgrespro.ru", "phone": "+70481118276"}
0005434287524	AC1C39	6713 897946	VIKTORIYA KOROLEVA	{"email": "viktoriya_koroleva091976@postgrespro.ru", "phone": "+70631506640"}
0005434287525	AC1C39	6259 626403	NATALYA ZAYCEVA	{"phone": "+70497076705"}
0005434287526	EE6294	0164 631950	NATALYA KUZNECOVA	{"phone": "+70344496243"}
0005434287527	D91958	8522 049044	RUSTAM ISAEV	{"email": "r_isaev.041958@postgrespro.ru", "phone": "+70433189776"}
0005434287528	52DF38	2593 719317	IRINA KUZNECOVA	{"phone": "+70299879238"}
0005434287529	00B3EA	9664 720350	VIKTORIYA ROMANOVA	{"phone": "+70905896178"}
0005434287530	1D1AA2	1585 748293	ALEKSANDR GERASIMOV	{"email": "gerasimov-aleksandr_091969@postgrespro.ru", "phone": "+70304393206"}
0005434287531	2D4A59	4112 455914	OLGA SAVELEVA	{"phone": "+70200213892"}
0005434287532	471359	2390 422034	EDUARD BARANOV	{"email": "e-baranov091962@postgrespro.ru", "phone": "+70462084468"}
0005434287533	A81DD6	4548 079921	ANNA EGOROVA	{"phone": "+70670905020"}
0005434287534	B61406	3926 193616	VLADISLAV KULIKOV	{"phone": "+70109913574"}
0005434287535	C5C63D	4756 078756	VLADIMIR MAKAROV	{"phone": "+70604342891"}
0005434287536	30EBC8	0522 364888	VLADIMIR IVANOV	{"phone": "+70078770577"}
0005434287537	97663F	4109 433121	ANDREY AFANASEV	{"phone": "+70989800447"}
0005434287538	97663F	9896 159611	SVETLANA PETROVA	{"phone": "+70811942933"}
0005434287539	93988C	8619 257628	IGOR IVANOV	{"email": "ivanov.i.07041979@postgrespro.ru", "phone": "+70203904161"}
0005434287540	85EF65	3897 052323	EKATERINA EFIMOVA	{"email": "efimova.ekaterina-1969@postgrespro.ru", "phone": "+70673361902"}
0005434287541	85EF65	3107 899142	LYUBOV POPOVA	{"email": "popova.lyubov1978@postgrespro.ru", "phone": "+70035735861"}
0005434287542	85EF65	2854 895116	ALEKSANDR GRIGOREV	{"phone": "+70843668021"}
0005434287543	9B4816	9242 484815	VLADISLAV NOVIKOV	{"email": "novikovvladislav_1960@postgrespro.ru", "phone": "+70562289154"}
0005434287544	9B4816	7126 307488	ALEKSANDR MEDVEDEV	{"phone": "+70808864806"}
0005434287607	190AFA	9038 818549	NATALYA ANDREEVA	{"phone": "+70915620363"}
0005434287545	8C69F7	5591 743083	ELENA VOROBEVA	{"email": "elena.vorobeva_23031969@postgrespro.ru", "phone": "+70188554550"}
0005434287546	F14B02	9544 331644	LYUDMILA KUZNECOVA	{"phone": "+70173536785"}
0005434287547	D17337	2214 655237	SVETLANA IVANOVA	{"email": "ivanova_svetlana.04061979@postgrespro.ru", "phone": "+70619347926"}
0005434287548	D17337	2248 911916	EMILIYA EFREMOVA	{"phone": "+70417130406"}
0005434287549	0903CC	4668 250253	KONSTANTIN YAKOVLEV	{"email": "k_yakovlev-061984@postgrespro.ru", "phone": "+70789835335"}
0005434287550	0903CC	3969 198388	POLINA ILINA	{"email": "ilina_p-10091961@postgrespro.ru", "phone": "+70942513178"}
0005434287551	33C7F8	9415 508280	SERGEY KUZNECOV	{"email": "kuznecov_sergey-23061976@postgrespro.ru", "phone": "+70046663945"}
0005434287552	33C7F8	1023 768878	NIKOLAY VASILEV	{"phone": "+70376029029"}
0005434287553	866526	6137 564610	LYUBOV SEMENOVA	{"email": "l.semenova.1966@postgrespro.ru", "phone": "+70945954849"}
0005434287554	866526	1028 649610	OLGA GUSEVA	{"phone": "+70721355176"}
0005434287555	65D16E	7659 759983	ILYA YAKOVLEV	{"phone": "+70966144733"}
0005434287556	65D16E	4588 845150	OLGA KUZNECOVA	{"email": "o_kuznecova.22081968@postgrespro.ru", "phone": "+70739802151"}
0005434287557	EDE4FA	1099 109745	NATALYA RYABOVA	{"phone": "+70312018579"}
0005434287558	B8C59D	2050 698125	VERA EGOROVA	{"phone": "+70576599744"}
0005434287559	C1F714	1988 395155	GALINA ISAEVA	{"phone": "+70512112792"}
0005434287560	0E4C99	4165 471973	POLINA LEBEDEVA	{"phone": "+70364639858"}
0005434287561	0E4C99	9629 681580	SERGEY KRASNOV	{"email": "s-krasnov071965@postgrespro.ru", "phone": "+70474021339"}
0005434287562	0E4C99	2594 169472	KARIM VASILEV	{"email": "vasilev.k.031973@postgrespro.ru", "phone": "+70868490460"}
0005434287563	FF4AF1	9370 273907	IRINA BELOVA	{"email": "belova-irina.08111979@postgrespro.ru", "phone": "+70311530561"}
0005434287564	C3717C	7921 214595	TATYANA NOVIKOVA	{"email": "tatyana_novikova-091979@postgrespro.ru", "phone": "+70222388804"}
0005434287565	ACE216	9198 368027	OLGA MIKHAYLOVA	{"phone": "+70537819052"}
0005434287566	1993EE	9047 127224	MARINA LUKYANOVA	{"phone": "+70754558983"}
0005434287567	D738DB	2349 991065	IGOR SERGEEV	{"phone": "+70386432419"}
0005434287568	D738DB	2205 747004	TATYANA PAVLOVA	{"phone": "+70928711349"}
0005434287569	69A701	0153 744034	ANATOLIY PETROV	{"email": "a.petrov.25111978@postgrespro.ru", "phone": "+70303034654"}
0005434287570	69A701	8918 491954	OKSANA KONDRATEVA	{"email": "kondrateva.oksana1976@postgrespro.ru", "phone": "+70271713552"}
0005434287571	2A3100	7410 430931	TATYANA AFANASEVA	{"phone": "+70283178604"}
0005434287572	2A3100	0582 923827	MARINA IVANOVA	{"phone": "+70504409246"}
0005434287573	00E730	4345 825238	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin_1983@postgrespro.ru", "phone": "+70773880705"}
0005434287574	18EC3E	9660 685671	VERA MOROZOVA	{"phone": "+70288474240"}
0005434287575	18EC3E	0627 996861	LIDIYA BELYAEVA	{"email": "lidiya.belyaeva_19021976@postgrespro.ru", "phone": "+70301719276"}
0005434287576	4B38BB	2063 093809	DARYA PETROVA	{"phone": "+70352912592"}
0005434287577	C5FA1B	0278 562502	OKSANA TITOVA	{"email": "titovaoksana-071970@postgrespro.ru", "phone": "+70448761242"}
0005434287578	C5FA1B	0882 354352	DIANA MOROZOVA	{"phone": "+70316173611"}
0005434287579	3C6A5E	4985 875243	ALEKSEY GAVRILOV	{"email": "gavrilov-a1965@postgrespro.ru", "phone": "+70869926572"}
0005434287580	DE4E81	8636 218939	SERGEY BORISOV	{"phone": "+70419754493"}
0005434287581	210E97	8577 147255	DMITRIY KUZNECOV	{"phone": "+70149910415"}
0005434287582	6E1C39	8119 053375	TAISIYA ANDREEVA	{"email": "tandreeva1971@postgrespro.ru", "phone": "+70739250566"}
0005434287583	A36022	5974 195149	ALEKSEY SIDOROV	{"phone": "+70498205984"}
0005434287584	6DB8EC	5090 474996	ANASTASIYA DAVYDOVA	{"phone": "+70982905031"}
0005434287585	6DB8EC	2524 983867	TAISIYA ALEKSANDROVA	{"email": "aleksandrova-t-031980@postgrespro.ru", "phone": "+70802572907"}
0005434287586	9BFD55	5143 352482	VLADIMIR RODIONOV	{"email": "vladimir.rodionov15021968@postgrespro.ru", "phone": "+70862114344"}
0005434287587	9BFD55	2751 621145	ALINA VLASOVA	{"phone": "+70483890313"}
0005434287588	63E089	5656 146178	GALINA KOMAROVA	{"phone": "+70619707403"}
0005434287589	445B54	2263 835392	ROMAN MIRONOV	{"email": "rmironov081964@postgrespro.ru", "phone": "+70169894094"}
0005434287590	867F8D	7523 973592	ANTONINA ROMANOVA	{"phone": "+70683189137"}
0005434287591	867F8D	1860 116015	NIKOLAY KUDRYASHOV	{"phone": "+70756337023"}
0005434287592	82CB11	2962 194989	MAKSIM MOROZOV	{"email": "maksim_morozov_1975@postgrespro.ru", "phone": "+70340005520"}
0005434287593	267BA9	6443 100124	IVAN NAUMOV	{"phone": "+70911765616"}
0005434287594	DA4C8F	6224 637494	EDUARD FEDOROV	{"phone": "+70344184626"}
0005434287595	3660DB	8860 260699	VALENTINA MALYSHEVA	{"email": "valentina-malysheva.12121985@postgrespro.ru", "phone": "+70162208378"}
0005434287596	3660DB	6699 476394	NIKOLAY DMITRIEV	{"email": "n-dmitriev.051966@postgrespro.ru", "phone": "+70840882319"}
0005434287597	3660DB	4387 418167	OKSANA DANILOVA	{"email": "oksana-danilova071973@postgrespro.ru", "phone": "+70534076594"}
0005434287598	54978A	8187 624252	EVGENIY ANDREEV	{"email": "andreevevgeniy-08101975@postgrespro.ru", "phone": "+70953781626"}
0005434287599	5E2706	5395 069874	EVGENIY BONDARENKO	{"email": "e_bondarenko.1967@postgrespro.ru", "phone": "+70409696929"}
0005434287600	9E899C	8294 442419	TATYANA MOISEEVA	{"phone": "+70587710649"}
0005434287601	5B3A29	8312 058404	MARIYA SOLOVEVA	{"phone": "+70068888142"}
0005434287602	5B3A29	2150 586016	EKATERINA NAZAROVA	{"email": "nazarovaekaterina.12061973@postgrespro.ru", "phone": "+70449173715"}
0005434287603	DCFE02	2427 593702	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev_1961@postgrespro.ru", "phone": "+70286394658"}
0005434287604	10C9C1	6781 921440	ELENA ANDREEVA	{"email": "elenaandreeva_18121972@postgrespro.ru", "phone": "+70703607410"}
0005434287605	1F70A7	7434 963786	TIMOFEY RODIONOV	{"phone": "+70723286735"}
0005434287664	A810B3	5995 030259	VITALIY CHERNOV	{"phone": "+70068276577"}
0005434287608	6DCEA4	9198 544886	NINA KUZNECOVA	{"email": "kuznecova.n.031966@postgrespro.ru", "phone": "+70093741408"}
0005434287609	3F98C9	9190 299245	DMITRIY NAUMOV	{"phone": "+70733659834"}
0005434287610	C2CBF0	9510 562601	ALENA ANTONOVA	{"phone": "+70602817509"}
0005434287611	C2CBF0	0344 574565	PAVEL MELNIKOV	{"email": "melnikov-pavel.1969@postgrespro.ru", "phone": "+70235319758"}
0005434287612	128760	4460 337677	LEONID KARPOV	{"email": "l_karpov_1978@postgrespro.ru", "phone": "+70958284342"}
0005434287613	128760	5873 077926	VENIAMIN CHERNOV	{"phone": "+70362912343"}
0005434287614	56026D	0344 546399	ANATOLIY ALEKSANDROV	{"email": "aleksandrovanatoliy_02111976@postgrespro.ru", "phone": "+70714612195"}
0005434287615	62B24E	2463 774126	TATYANA SEMENOVA	{"phone": "+70984716325"}
0005434287616	C98CE6	6156 878579	IGOR AFANASEV	{"email": "i.afanasev_16091964@postgrespro.ru", "phone": "+70259381671"}
0005434287617	FBC183	2267 870894	EVGENIY ANTONOV	{"phone": "+70452993208"}
0005434287618	CA09E9	3178 987322	ARTEM KUDRYASHOV	{"email": "a-kudryashov1966@postgrespro.ru", "phone": "+70760424084"}
0005434287619	0EFDFB	6247 546064	ELENA OVCHINNIKOVA	{"phone": "+70135788522"}
0005434287620	9822C9	1810 067345	VLADIMIR KUZNECOV	{"phone": "+70063783472"}
0005434287621	9822C9	2266 035539	ANNA MIKHAYLOVA	{"phone": "+70736898005"}
0005434287622	5DFBB8	7433 978627	IRINA LAZAREVA	{"email": "irina_lazareva-061961@postgrespro.ru", "phone": "+70943018291"}
0005434287623	5DFBB8	8323 288640	ANNA ILINA	{"phone": "+70157588545"}
0005434287624	52E1E4	1257 795564	ALEKSEY SCHERBAKOV	{"phone": "+70423030478"}
0005434287625	F51115	8955 232938	VIKTOR ROMANOV	{"phone": "+70609273701"}
0005434287626	F51115	6856 852181	ALEKSEY DMITRIEV	{"email": "alekseydmitriev.1977@postgrespro.ru", "phone": "+70575551305"}
0005434287627	D23DB2	8018 869437	NATALYA ORLOVA	{"email": "orlova.natalya_021968@postgrespro.ru", "phone": "+70285075246"}
0005434287628	D23DB2	2562 347054	ALEKSANDR OSIPOV	{"phone": "+70316673536"}
0005434287629	E672CB	1198 267134	LIDIYA ZOTOVA	{"email": "zotova-lidiya091964@postgrespro.ru", "phone": "+70043559572"}
0005434287630	D7EF2B	7839 992154	YANA KUZNECOVA	{"phone": "+70226845543"}
0005434287631	74C646	7334 861340	NADEZHDA SERGEEVA	{"email": "sergeeva_n.18091973@postgrespro.ru", "phone": "+70715188128"}
0005434287632	74C646	5205 275414	OLEG ZAKHAROV	{"email": "ozakharov_07071973@postgrespro.ru", "phone": "+70495698057"}
0005434287633	63CD72	0016 455106	ALEKSANDRA AKIMOVA	{"email": "akimova.aleksandra_28041981@postgrespro.ru", "phone": "+70261048569"}
0005434287634	650566	3338 531367	MARINA MASLOVA	{"email": "maslova.m.10071958@postgrespro.ru", "phone": "+70968587117"}
0005434287635	888E70	0702 636863	VERA MAKAROVA	{"phone": "+70843683522"}
0005434287636	76E574	4040 101933	ANATOLIY DENISOV	{"phone": "+70244660279"}
0005434287637	647DCA	4708 403056	VYACHESLAV GUSEV	{"phone": "+70514342042"}
0005434287638	647DCA	3428 718642	KONSTANTIN MIRONOV	{"email": "kmironov_1980@postgrespro.ru", "phone": "+70319507941"}
0005434287639	65973C	4914 829691	YURIY MEDVEDEV	{"phone": "+70110621000"}
0005434287640	A6A6B6	0405 306510	VITALIY NIKOLAEV	{"email": "v-nikolaev1964@postgrespro.ru", "phone": "+70620087663"}
0005434287641	55FCA0	1571 800385	LEONID KUZNECOV	{"email": "kuznecov_l_1964@postgrespro.ru", "phone": "+70837567962"}
0005434287642	55FCA0	8096 872289	NADEZHDA SEMENOVA	{"phone": "+70830745506"}
0005434287643	564B20	1571 308810	SOFIYA ERMAKOVA	{"phone": "+70349538045"}
0005434287644	564B20	3647 603807	YAN SERGEEV	{"email": "sergeev_yan-091982@postgrespro.ru", "phone": "+70853078757"}
0005434287645	564B20	2062 515823	NIKOLAY MAKAROV	{"email": "makarov-n.14051979@postgrespro.ru", "phone": "+70567039925"}
0005434287646	A30B33	0573 651661	NATALYA FILIPPOVA	{"phone": "+70691422233"}
0005434287647	45FCC0	3910 844995	VASILIY ZAYCEV	{"phone": "+70346672002"}
0005434287648	D1238D	4841 865757	NINA POPOVA	{"phone": "+70909743047"}
0005434287649	1D931B	9989 736569	OKSANA PAVLOVA	{"email": "opavlova.091972@postgrespro.ru", "phone": "+70679308836"}
0005434287650	476631	4709 812099	LYUDMILA ARKHIPOVA	{"email": "arkhipova_l1961@postgrespro.ru", "phone": "+70768137752"}
0005434287651	95B462	8919 519785	DANIIL IVANOV	{"email": "daniil-ivanov1984@postgrespro.ru", "phone": "+70527820363"}
0005434287652	95B462	6558 219489	ROMAN VASILEV	{"phone": "+70749512659"}
0005434287653	9F55F6	1560 177806	ALEVTINA RYABOVA	{"phone": "+70217315439"}
0005434287654	9F55F6	5137 406553	IRINA EGOROVA	{"phone": "+70229373054"}
0005434287655	8DFDFA	6036 540521	EKATERINA POLYAKOVA	{"email": "polyakova_ekaterina26081977@postgrespro.ru", "phone": "+70360950541"}
0005434287656	5ED54F	7904 605399	DANIL YAKOVLEV	{"email": "danil.yakovlev1962@postgrespro.ru", "phone": "+70145946597"}
0005434287657	A6BAB4	9724 316111	ANATOLIY PETROV	{"email": "anatoliy-petrov_18081959@postgrespro.ru", "phone": "+70717668089"}
0005434287658	AF1F0E	9875 262630	MARINA GUSEVA	{"email": "marina.guseva.16121969@postgrespro.ru", "phone": "+70474840017"}
0005434287659	AF1F0E	5626 260952	VALENTINA KOZLOVA	{"email": "v.kozlova.11021974@postgrespro.ru", "phone": "+70284533072"}
0005434287660	58FA74	2454 904102	ILYA SEMENOV	{"phone": "+70916636103"}
0005434287661	E424B3	9615 234890	DENIS SERGEEV	{"email": "denissergeev-121967@postgrespro.ru", "phone": "+70824008043"}
0005434287662	7B8CF7	3835 308843	EGOR IVANOV	{"phone": "+70782675953"}
0005434287663	E09F49	2717 857308	YULIYA KOVALEVA	{"email": "y_kovaleva-24101981@postgrespro.ru", "phone": "+70047253941"}
0005434287665	A92EE8	9493 276577	IGOR SERGEEV	{"email": "i-sergeev.081971@postgrespro.ru", "phone": "+70144488442"}
0005434287666	7364DC	6616 627497	TATYANA DENISOVA	{"email": "denisova_t.121973@postgrespro.ru", "phone": "+70743916588"}
0005434287667	A48D09	3818 648764	TATYANA POPOVA	{"phone": "+70691246538"}
0005434287668	E34E76	0034 527499	VITALIY IVANOV	{"phone": "+70332708579"}
0005434287669	E34E76	6000 673189	GENNADIY POPOV	{"email": "gennadiy_popov_03071967@postgrespro.ru", "phone": "+70233529170"}
0005434287670	EA3A9D	1390 182061	ANVAR PAVLOV	{"phone": "+70238938545"}
0005434287671	8B3ABA	8811 226987	GALINA STEPANOVA	{"email": "galina.stepanova1970@postgrespro.ru", "phone": "+70322372405"}
0005434287672	8C857B	6727 603655	ANDREY BORISOV	{"email": "aborisov-19101984@postgrespro.ru", "phone": "+70784075986"}
0005434287673	E467DF	9541 523355	ANATOLIY VOLKOV	{"email": "a.volkov08031976@postgrespro.ru", "phone": "+70647127934"}
0005434287674	E467DF	4156 441293	LYUDMILA EFREMOVA	{"email": "efremova_l_1976@postgrespro.ru", "phone": "+70763300880"}
0005434287675	7C1FC6	8901 429969	LIDIYA DMITRIEVA	{"email": "dmitrieva_l-10091968@postgrespro.ru", "phone": "+70672620018"}
0005434287676	7B2BEA	3636 841789	OLGA MATVEEVA	{"email": "olga-matveeva-03021969@postgrespro.ru", "phone": "+70837553977"}
0005434287677	7B2BEA	6553 215298	DMITRIY DMITRIEV	{"email": "d_dmitriev1979@postgrespro.ru", "phone": "+70322937770"}
0005434287678	AF440E	7024 115332	DARYA KUZNECOVA	{"phone": "+70750882882"}
0005434287679	F2F6AD	1924 283357	SERGEY SERGEEV	{"email": "sergey_sergeev1972@postgrespro.ru", "phone": "+70886737120"}
0005434287680	F2F6AD	5638 329196	NADEZHDA MATVEEVA	{"phone": "+70388771705"}
0005434287681	9F2799	2651 919966	ANDREY ISAEV	{"phone": "+70100570659"}
0005434287682	9F2799	7249 655037	LYUDMILA YAKOVLEVA	{"email": "lyudmila-yakovleva1974@postgrespro.ru", "phone": "+70037609468"}
0005434287683	396D43	2802 820746	ANDREY MOROZOV	{"phone": "+70653262192"}
0005434287684	8832B4	9511 250577	VIKTORIYA POPOVA	{"phone": "+70157593422"}
0005434287685	8832B4	8494 785824	EVGENIYA KUZNECOVA	{"email": "e-kuznecova_16071972@postgrespro.ru", "phone": "+70703637662"}
0005434287686	D0F4C9	3282 422132	SERGEY VOROBEV	{"email": "vorobevsergey-1968@postgrespro.ru", "phone": "+70072073447"}
0005434287687	0D00C8	2228 899775	LYUDMILA PAVLOVA	{"phone": "+70052610560"}
0005434287688	0D00C8	8020 251351	IVAN MELNIKOV	{"phone": "+70826275978"}
0005434287689	622FF8	7813 823687	ALEKSEY KUZNECOV	{"email": "alekseykuznecov-101971@postgrespro.ru", "phone": "+70772601403"}
0005434287690	622FF8	0038 282102	MIKHAIL ROMANOV	{"phone": "+70802155838"}
0005434287691	622FF8	3911 787718	IRINA KUDRYASHOVA	{"email": "irina-kudryashova-05011978@postgrespro.ru", "phone": "+70129023934"}
0005434287692	18889E	2052 451760	TATYANA BOGDANOVA	{"phone": "+70873146706"}
0005434287693	18889E	6262 332340	VLADIMIR ALEKSEEV	{"phone": "+70034240376"}
0005434287694	67D798	8081 486842	ALENA RODIONOVA	{"email": "alenarodionova081973@postgrespro.ru", "phone": "+70614676055"}
0005434287695	BA7AE2	8880 921894	IRAIDA FEDOROVA	{"email": "fedorova-iraida.1984@postgrespro.ru", "phone": "+70938274211"}
0005434287696	88C121	4413 804811	PETR IVANOV	{"email": "petr.ivanov_081978@postgrespro.ru", "phone": "+70997656788"}
0005434287697	88C121	4213 937169	LYUBOV IVANOVA	{"phone": "+70979845495"}
0005434287698	DE07DF	9739 090465	VERA IVANOVA	{"phone": "+70322710777"}
0005434287699	DE07DF	4468 879713	VLADIMIR MELNIKOV	{"email": "melnikovv_091981@postgrespro.ru", "phone": "+70380754911"}
0005434287700	BC1979	7746 969063	YAROSLAV NOVIKOV	{"phone": "+70795443028"}
0005434287701	8AD91A	7273 541246	VALENTINA VOROBEVA	{"email": "vvorobeva061967@postgrespro.ru", "phone": "+70825046587"}
0005434287702	8AD91A	4632 766120	LYUDMILA PAVLOVA	{"email": "pavlova_l061973@postgrespro.ru", "phone": "+70002062944"}
0005434287703	181846	1378 048513	VIKTORIYA SOROKINA	{"email": "sorokina.viktoriya1968@postgrespro.ru", "phone": "+70769351253"}
0005434287704	82D260	3360 408533	DIANA AFANASEVA	{"email": "afanaseva.d_10081976@postgrespro.ru", "phone": "+70843528280"}
0005434287705	668E28	8284 257460	VALENTINA LOGINOVA	{"phone": "+70391414591"}
0005434287706	5BFF46	2687 760711	SVETLANA GORBUNOVA	{"email": "sgorbunova.061964@postgrespro.ru", "phone": "+70400258318"}
0005434287707	5BFF46	2513 890545	SOFIYA SAVELEVA	{"phone": "+70557488248"}
0005434287708	1CE34F	8819 408370	EGOR ALEKSEEV	{"email": "e_alekseev.06091978@postgrespro.ru", "phone": "+70089593073"}
0005434287709	1CE34F	2413 626034	EVGENIY MAKAROV	{"phone": "+70266706249"}
0005434287710	4F2169	3580 592158	OLGA OVCHINNIKOVA	{"email": "o.ovchinnikova1970@postgrespro.ru", "phone": "+70961328184"}
0005434287711	C56C31	9058 981872	ANDREY BORISOV	{"phone": "+70476055325"}
0005434287712	C56C31	0566 018361	ILGIZ MAKAROV	{"email": "ilgiz_makarov081970@postgrespro.ru", "phone": "+70535995301"}
0005434287713	201CCC	2566 227303	ELMIRA BOGDANOVA	{"email": "bogdanova_e.1971@postgrespro.ru", "phone": "+70329135801"}
0005434287714	E622EC	2004 863456	FARIT NIKITIN	{"email": "farit-nikitin.071978@postgrespro.ru", "phone": "+70805570296"}
0005434287715	E622EC	9915 295836	VALERIY ALEKSANDROV	{"phone": "+70037143116"}
0005434287716	E622EC	6185 258842	EVGENIY TIMOFEEV	{"phone": "+70327542290"}
0005434287717	99C7B0	9217 465210	ANASTASIYA POPOVA	{"email": "anastasiyapopova-1961@postgrespro.ru", "phone": "+70900593927"}
0005434287718	7F7448	8144 284227	VALERIY NIKITIN	{"email": "nikitinvaleriy1969@postgrespro.ru", "phone": "+70648415809"}
0005434287719	8C138C	1607 786267	ARTEM RODIONOV	{"phone": "+70861466991"}
0005434287830	8DB595	7650 549090	VIKTOR SEMENOV	{"phone": "+70571251946"}
0005434287720	8C138C	7669 897068	VALENTINA FILIPPOVA	{"email": "valentinafilippova_041972@postgrespro.ru", "phone": "+70191261623"}
0005434287721	4FFEC9	1731 238453	OLGA MIRONOVA	{"email": "mironovaolga_20091970@postgrespro.ru", "phone": "+70307758373"}
0005434287722	410E5B	6738 620739	VALENTINA GERASIMOVA	{"email": "vgerasimova.1973@postgrespro.ru", "phone": "+70082367823"}
0005434287723	410E5B	8292 520711	TATYANA SIDOROVA	{"phone": "+70419689168"}
0005434287724	FC45A2	0222 081138	VADIM SOKOLOV	{"phone": "+70897377617"}
0005434287725	572FCE	2275 600641	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr_1973@postgrespro.ru", "phone": "+70288582685"}
0005434287726	8AEF62	6315 738087	VIKTOR AFANASEV	{"phone": "+70837784473"}
0005434287727	8AEF62	4632 663127	RUSLAN MELNIKOV	{"email": "ruslanmelnikov-22111966@postgrespro.ru", "phone": "+70878250921"}
0005434287728	BD1D0E	3979 200321	ANTONINA MAKAROVA	{"email": "makarovaantonina.061975@postgrespro.ru", "phone": "+70979198753"}
0005434287729	A35D8E	6765 019907	OLGA PAVLOVA	{"phone": "+70557153853"}
0005434287730	A35D8E	6106 541543	EKATERINA TIKHONOVA	{"phone": "+70269992496"}
0005434287731	462AF3	5524 379624	ELENA KUZMINA	{"phone": "+70890690607"}
0005434287732	462AF3	0538 416887	ANDREY FILIPPOV	{"phone": "+70741512170"}
0005434287733	3E150E	7143 534269	ALEKSEY VOLKOV	{"phone": "+70929654206"}
0005434287734	A87B6A	9906 300158	ANGELINA POPOVA	{"email": "popova-angelina.02021969@postgrespro.ru", "phone": "+70749672793"}
0005434287735	A87B6A	4001 232635	ARTEM SAVELEV	{"phone": "+70726733586"}
0005434287736	D3C637	7195 874546	OLGA ROMANOVA	{"email": "romanovao.28071978@postgrespro.ru", "phone": "+70847647379"}
0005434287737	C01BDF	5872 672337	RADMIR PAVLOV	{"phone": "+70121906864"}
0005434287738	C01BDF	7813 820389	KSENIYA NOVIKOVA	{"email": "novikova_kseniya_23091964@postgrespro.ru", "phone": "+70472943834"}
0005434287739	C01BDF	2420 812623	ANNA DMITRIEVA	{"email": "a_dmitrieva-28081972@postgrespro.ru", "phone": "+70086925573"}
0005434287740	055858	8944 407179	NADEZHDA SOKOLOVA	{"email": "n_sokolova1978@postgrespro.ru", "phone": "+70629034965"}
0005434287741	AC5B34	9981 562554	LYUBOV NESTEROVA	{"email": "nesteroval_1973@postgrespro.ru", "phone": "+70866095931"}
0005434287742	42531E	5762 818790	MARINA BOGDANOVA	{"phone": "+70092209616"}
0005434287743	B6C099	2428 956237	ANNA NAUMOVA	{"email": "anna-naumova.111980@postgrespro.ru", "phone": "+70784289831"}
0005434287744	9AF2D7	4463 793896	VALERIY POPOV	{"email": "popov_valeriy101963@postgrespro.ru", "phone": "+70601022980"}
0005434287745	18C1F0	6017 305261	BOGDAN MATVEEV	{"email": "matveev.b121980@postgrespro.ru", "phone": "+70068175450"}
0005434287746	18C1F0	3525 870234	SERGEY GAVRILOV	{"phone": "+70424186772"}
0005434287747	18C1F0	3241 726985	NADEZHDA NIKITINA	{"email": "nadezhda.nikitina1956@postgrespro.ru", "phone": "+70803202264"}
0005434287748	DA5E31	1757 509243	EVGENIY MAKSIMOV	{"email": "maksimove03061959@postgrespro.ru", "phone": "+70985247121"}
0005434287749	97F0D3	3113 290313	ARINA IVANOVA	{"email": "ivanovaa-101978@postgrespro.ru", "phone": "+70968824933"}
0005434287750	B9A49C	8541 859827	LIDIYA ABRAMOVA	{"phone": "+70683102018"}
0005434287751	BE7278	6242 844979	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov.101972@postgrespro.ru", "phone": "+70559267681"}
0005434287752	C102C0	7012 836013	EVGENIY VASILEV	{"email": "vasilev.evgeniy-121971@postgrespro.ru", "phone": "+70014028852"}
0005434287753	70AB98	2177 902238	YURIY GORBUNOV	{"email": "yuriy_gorbunov.13031974@postgrespro.ru", "phone": "+70803623916"}
0005434287754	9367BC	4151 265644	SERGEY NAUMOV	{"email": "sergey.naumov1965@postgrespro.ru", "phone": "+70568533158"}
0005434287755	9367BC	1151 741547	VASILIY KISELEV	{"email": "vasiliy_kiselev.121969@postgrespro.ru", "phone": "+70884887473"}
0005434287756	EAD60A	0244 997101	EVELINA ANDREEVA	{"phone": "+70304349212"}
0005434287757	7C2D31	1096 582942	MARIYA BORISOVA	{"email": "mariya.borisova_1978@postgrespro.ru", "phone": "+70055613033"}
0005434287758	3E7224	0097 770868	ANTON PAVLOV	{"phone": "+70311725746"}
0005434287759	D96100	3507 088814	VLADIMIR ALEKSANDROV	{"phone": "+70070701778"}
0005434287760	D96100	2000 366192	NATALIYA FROLOVA	{"email": "nataliya.frolova.1976@postgrespro.ru", "phone": "+70044806336"}
0005434287761	4A459E	2760 144387	TAISIYA LAZAREVA	{"phone": "+70518555641"}
0005434287762	C7A889	4557 583172	ALEKSEY KRASNOV	{"email": "krasnovaleksey18041982@postgrespro.ru", "phone": "+70377509347"}
0005434287763	EFFADE	7343 531419	KIRILL STEPANOV	{"email": "stepanov.kirill-1974@postgrespro.ru", "phone": "+70334585179"}
0005434287764	EFFADE	9106 521745	NIKOLAY ILIN	{"email": "ilin.n-16091959@postgrespro.ru", "phone": "+70611038333"}
0005434287765	DBA788	1074 170863	VALERIY STEPANOV	{"email": "stepanovvaleriy.1970@postgrespro.ru", "phone": "+70437146030"}
0005434287766	DBA788	2946 194310	GEORGIY SAVELEV	{"email": "savelev-georgiy-1962@postgrespro.ru", "phone": "+70286872758"}
0005434287767	8194B5	8283 538188	VADIM ZHUKOV	{"email": "vadimzhukov-111972@postgrespro.ru", "phone": "+70435655730"}
0005434287768	014090	1024 852406	NINA KAZAKOVA	{"email": "kazakova_nina101974@postgrespro.ru", "phone": "+70557362934"}
0005434287769	014090	4661 372303	SVETLANA PETROVA	{"email": "s_petrova.1975@postgrespro.ru", "phone": "+70541431384"}
0005434287770	E960B1	3849 432816	VIKTOR STEPANOV	{"email": "stepanov.v.121975@postgrespro.ru", "phone": "+70330515907"}
0005434287771	63B45A	7654 314432	YURIY FEDOROV	{"phone": "+70840117426"}
0005434287772	29A457	4128 320614	VLADIMIR KISELEV	{"email": "kiselev.vladimir-081970@postgrespro.ru", "phone": "+70408762266"}
0005434287773	C54CA1	6513 951889	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev_1966@postgrespro.ru", "phone": "+70007041414"}
0005434287774	B5FA0D	1116 261275	ANATOLIY GRIGOREV	{"phone": "+70848039054"}
0005434287775	B5FA0D	5312 687428	ALEKSANDR SEMENOV	{"email": "a_semenov041975@postgrespro.ru", "phone": "+70852289717"}
0005434287776	B5FA0D	7231 189904	TATYANA SOLOVEVA	{"email": "t_soloveva-011969@postgrespro.ru", "phone": "+70555229950"}
0005434287777	A05823	1956 863870	SVETLANA POPOVA	{"email": "popovasvetlana05031971@postgrespro.ru", "phone": "+70175796429"}
0005434287778	A05823	2363 737574	IVAN GUSEV	{"phone": "+70693504520"}
0005434287779	4F4A70	0512 036109	SERGEY BORISOV	{"phone": "+70553138132"}
0005434287780	B20384	6071 530682	VALENTINA VLASOVA	{"phone": "+70577075863"}
0005434287781	B20384	4768 468783	NADEZHDA MOROZOVA	{"phone": "+70396760614"}
0005434287782	FB4390	9820 153086	VLADISLAV KUZNECOV	{"email": "kuznecov-vladislav_031968@postgrespro.ru", "phone": "+70152248056"}
0005434287783	186F29	4129 851229	ALEKSANDRA KISELEVA	{"email": "a.kiseleva.20021961@postgrespro.ru", "phone": "+70804273392"}
0005434287784	186F29	6750 740460	ROZA NAZAROVA	{"phone": "+70540354504"}
0005434287785	186F29	0330 703492	ELENA ANDREEVA	{"phone": "+70330887915"}
0005434287786	03B6D5	8976 705849	IGOR ABRAMOV	{"email": "abramovigor-23011971@postgrespro.ru", "phone": "+70998704536"}
0005434287787	03B6D5	7486 616488	ALEKSANDR FROLOV	{"email": "a_frolov.061960@postgrespro.ru", "phone": "+70123661288"}
0005434287788	CE9EC3	2074 933300	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr-061982@postgrespro.ru", "phone": "+70039877536"}
0005434287789	66A926	9783 618702	TAMARA ALEKSEEVA	{"email": "t-alekseeva25021977@postgrespro.ru", "phone": "+70874041359"}
0005434287790	0A786A	8418 328315	NATALYA SOLOVEVA	{"email": "n-soloveva09061982@postgrespro.ru", "phone": "+70355087038"}
0005434287791	0A786A	0580 275788	YULIYA BELYAEVA	{"phone": "+70685141184"}
0005434287792	E75AB9	7507 160978	MATVEY KUZNECOV	{"phone": "+70924825525"}
0005434287793	E75AB9	0720 715458	TAMARA LEBEDEVA	{"phone": "+70826646266"}
0005434287794	7E41E6	3692 548136	TATYANA PAVLOVA	{"phone": "+70496855057"}
0005434287795	C7ABF8	7686 756027	NINA VLASOVA	{"phone": "+70003823839"}
0005434287796	ED6C9D	9552 829717	VLADIMIR GORBUNOV	{"phone": "+70755954957"}
0005434287797	8DBE93	0564 011354	ALEKSEY DAVYDOV	{"phone": "+70641753786"}
0005434287798	8DBE93	8486 964251	LARISA BELYAEVA	{"email": "larisa-belyaeva101973@postgrespro.ru", "phone": "+70420027062"}
0005434287799	60BF3D	0806 843350	TAMARA GUSEVA	{"email": "gusevat-23071977@postgrespro.ru", "phone": "+70470719970"}
0005434287800	B42F8B	1643 945933	MARINA GRISHINA	{"email": "marinagrishina_1976@postgrespro.ru", "phone": "+70097637311"}
0005434287801	B42F8B	4822 550873	MARIYA TIKHONOVA	{"email": "tikhonova.m_26121974@postgrespro.ru", "phone": "+70470766797"}
0005434287802	B42F8B	7852 060679	SERGEY VASILEV	{"phone": "+70330400049"}
0005434287803	C1F794	4097 499027	ANDREY PAVLOV	{"email": "andrey.pavlov-041965@postgrespro.ru", "phone": "+70086348081"}
0005434287804	C1F794	7055 894551	DARYA KUZNECOVA	{"phone": "+70329633890"}
0005434287805	ED6072	5870 655058	OLEG GORBUNOV	{"email": "o.gorbunov.1969@postgrespro.ru", "phone": "+70699253870"}
0005434287806	ED6072	9215 501275	ELENA ROMANOVA	{"email": "e_romanova-041973@postgrespro.ru", "phone": "+70403439167"}
0005434287807	ADD9BA	3908 823605	VASILIY MELNIKOV	{"phone": "+70239663045"}
0005434287808	ADD9BA	3072 832119	TATYANA TITOVA	{"email": "titovatatyana_26071961@postgrespro.ru", "phone": "+70602217724"}
0005434287809	CA36F7	2671 000456	TAMARA IVANOVA	{"phone": "+70532321436"}
0005434287810	9D235E	2641 526996	OLGA ZHUKOVA	{"email": "ozhukova061980@postgrespro.ru", "phone": "+70502199666"}
0005434287811	0A216C	6722 969559	DMITRIY ALEKSANDROV	{"email": "d_aleksandrov.31081969@postgrespro.ru", "phone": "+70561912770"}
0005434287812	690A24	2400 428047	YURIY MARTYNOV	{"email": "martynov_y.101971@postgrespro.ru", "phone": "+70169764823"}
0005434287813	6784C1	4425 286236	ALEKSANDR GAVRILOV	{"email": "gavrilova-12061971@postgrespro.ru", "phone": "+70615053306"}
0005434287814	FB5204	2442 307995	YULIYA ZHUKOVA	{"phone": "+70065446773"}
0005434287815	FB5204	1954 977265	YULIYA ALEKSANDROVA	{"phone": "+70729277385"}
0005434287816	0D2B2F	9612 661498	VLADISLAV FILIPPOV	{"email": "vladislavfilippov_1976@postgrespro.ru", "phone": "+70771550925"}
0005434287817	0D2B2F	1063 565352	ANNA KONDRATEVA	{"phone": "+70464243782"}
0005434287818	6D3327	6884 111139	ANDREY ABRAMOV	{"email": "abramov_a.061971@postgrespro.ru", "phone": "+70282626141"}
0005434287819	6D3327	0497 123682	DARYA VOLKOVA	{"email": "volkova.darya_13061970@postgrespro.ru", "phone": "+70038181740"}
0005434287820	737EA4	3678 398843	MARINA ZOTOVA	{"email": "zotova-marina.121975@postgrespro.ru", "phone": "+70716187958"}
0005434287821	A33026	7037 985215	NADEZHDA MAKAROVA	{"phone": "+70934704999"}
0005434287822	90141D	7762 771393	OLGA ZHURAVLEVA	{"email": "olgazhuravleva.101973@postgrespro.ru", "phone": "+70324339654"}
0005434287823	E5557B	0875 874874	VALENTINA FILIPPOVA	{"email": "filippovav-03081971@postgrespro.ru", "phone": "+70719095028"}
0005434287824	E5557B	0105 860539	ANDREY ROMANOV	{"email": "andreyromanov.1976@postgrespro.ru", "phone": "+70089152490"}
0005434287825	E2BCA1	9343 589850	LYUBOV ERMAKOVA	{"email": "lyubov.ermakova_02071972@postgrespro.ru", "phone": "+70500701288"}
0005434287826	E0338D	9955 563625	ANATOLIY ALEKSANDROV	{"phone": "+70554865516"}
0005434287827	549C8F	7987 127912	OLGA TARASOVA	{"email": "o.tarasova-1968@postgrespro.ru", "phone": "+70088997499"}
0005434287828	CE400C	6168 999632	ARTEMIY BONDARENKO	{"email": "bondarenko-a-1987@postgrespro.ru", "phone": "+70025752079"}
0005434287829	CE400C	1089 379126	TATYANA IVANOVA	{"email": "ivanovat-101975@postgrespro.ru", "phone": "+70127708254"}
0005434287831	97FE81	7246 115479	MIKHAIL ZAKHAROV	{"phone": "+70888942138"}
0005434287832	F3BC23	3229 583751	SERGEY FEDOROV	{"email": "s-fedorov-081972@postgrespro.ru", "phone": "+70235539166"}
0005434287833	F3BC23	4321 974177	TATYANA BELOVA	{"email": "t-belova1973@postgrespro.ru", "phone": "+70248307830"}
0005434287834	D449CC	7207 817238	KLAVDIYA SMIRNOVA	{"email": "k_smirnova011976@postgrespro.ru", "phone": "+70564249613"}
0005434287835	C68277	9998 697884	IVAN ISAEV	{"email": "isaevivan1972@postgrespro.ru", "phone": "+70266663317"}
0005434287836	C68277	4949 570616	OLGA MALYSHEVA	{"email": "malysheva_o_1967@postgrespro.ru", "phone": "+70844252151"}
0005434287837	44A016	8653 969219	IVAN SAVELEV	{"email": "savelev.i-021955@postgrespro.ru", "phone": "+70966983861"}
0005434287838	44A016	9300 553461	IVAN SOROKIN	{"email": "sorokin_ivan.121973@postgrespro.ru", "phone": "+70052733670"}
0005434287839	A345F1	0888 402250	TATYANA GUSEVA	{"email": "t_guseva27021977@postgrespro.ru", "phone": "+70539553241"}
0005434287840	06B57E	8990 810562	ELENA NOVIKOVA	{"email": "novikova.elena1971@postgrespro.ru", "phone": "+70889354367"}
0005434287841	A73AC8	4836 673304	POLINA NAZAROVA	{"phone": "+70586839008"}
0005434287842	93286E	2383 104474	ARTEM SOLOVEV	{"email": "a_solovev011976@postgrespro.ru", "phone": "+70721364140"}
0005434287843	4D71B6	7931 331516	ANATOLIY KISELEV	{"phone": "+70649335913"}
0005434287844	9F8B68	1407 209857	DMITRIY ANTONOV	{"phone": "+70076610647"}
0005434287845	B0C15A	6096 032964	VITALIY ISAEV	{"email": "v-isaev.27011978@postgrespro.ru", "phone": "+70520257740"}
0005434287846	B4BE21	1983 477395	OLGA VOLKOVA	{"email": "volkovao-111976@postgrespro.ru", "phone": "+70652875557"}
0005434287847	7E515A	2521 765432	ARTEM GRIGOREV	{"email": "agrigorev-24121968@postgrespro.ru", "phone": "+70157631897"}
0005434287848	0AFC65	3574 924656	BORIS PETROV	{"email": "petrov_b.14081971@postgrespro.ru", "phone": "+70012960794"}
0005434287849	0AFC65	1886 640501	ALEKSANDR VLASOV	{"email": "vlasova_041971@postgrespro.ru", "phone": "+70577669958"}
0005434287850	CA18EC	6293 125708	ANDREY MOROZOV	{"email": "andrey-morozov.081972@postgrespro.ru", "phone": "+70219178299"}
0005434287851	352F8C	0442 637377	TATYANA ISAEVA	{"email": "isaeva_t_26021963@postgrespro.ru", "phone": "+70445307275"}
0005434287852	195400	1141 696206	NADEZHDA LAZAREVA	{"email": "n_lazareva.14041980@postgrespro.ru", "phone": "+70066477391"}
0005434287853	F6BE24	3959 241847	VIKTOR SEMENOV	{"email": "semenovv.1981@postgrespro.ru", "phone": "+70075502950"}
0005434287854	F6BE24	8328 331134	ALEKSANDR GUSEV	{"email": "gusev-aleksandr-04111974@postgrespro.ru", "phone": "+70897162072"}
0005434287855	70171D	3879 688270	ALEKSANDR GORBUNOV	{"phone": "+70769775025"}
0005434287856	9600CD	3732 749091	YURIY CHERNOV	{"email": "chernov-y_011970@postgrespro.ru", "phone": "+70474286472"}
0005434287857	9600CD	8933 728415	ARTEMIY IVANOV	{"phone": "+70435492071"}
0005434287858	39DFA9	5561 089193	OLGA ISAEVA	{"email": "o-isaeva1979@postgrespro.ru", "phone": "+70114891718"}
0005434287859	66A742	9652 792928	VERA KUZNECOVA	{"email": "kuznecova_v.1959@postgrespro.ru", "phone": "+70828446511"}
0005434287860	5A9187	0430 865948	ANASTASIYA KUZNECOVA	{"email": "akuznecova-04111961@postgrespro.ru", "phone": "+70909552096"}
0005434287861	980CBB	7463 237498	TAMARA KUZNECOVA	{"phone": "+70952493572"}
0005434287862	980CBB	7752 382675	ALEKSANDR DAVYDOV	{"phone": "+70424041350"}
0005434287863	0EE1A1	9468 402872	VALENTINA KALININA	{"email": "kalininavalentina-1974@postgrespro.ru", "phone": "+70431250229"}
0005434287864	0EE1A1	2789 683271	ALIYA VLASOVA	{"phone": "+70306375425"}
0005434287865	0EE1A1	9117 905503	TATYANA MARTYNOVA	{"email": "tatyana_martynova_31051972@postgrespro.ru", "phone": "+70871646518"}
0005434287866	DBD0BD	1878 353876	NATALYA ABRAMOVA	{"email": "n-abramova13081965@postgrespro.ru", "phone": "+70290539750"}
0005434287867	DBD0BD	5947 903571	DENIS YAKOVLEV	{"phone": "+70991250764"}
0005434287868	5D93AF	7438 615443	ALEKSEY NOVIKOV	{"phone": "+70267608120"}
0005434287869	8EDB70	4233 644565	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov_041979@postgrespro.ru", "phone": "+70394163187"}
0005434287870	8EDB70	4881 140725	SERGEY KONOVALOV	{"phone": "+70177518688"}
0005434287871	B28324	2941 670649	NATALYA TITOVA	{"phone": "+70070089079"}
0005434287872	5B5A12	0720 279328	DENIS NIKOLAEV	{"email": "d.nikolaev1963@postgrespro.ru", "phone": "+70476899681"}
0005434287873	CC323E	9144 697942	LYUBOV FILATOVA	{"email": "lfilatova-1973@postgrespro.ru", "phone": "+70685707625"}
0005434287874	EA43F3	2504 070063	ALLA MELNIKOVA	{"email": "melnikovaa18041979@postgrespro.ru", "phone": "+70995725349"}
0005434287875	EA43F3	5268 118971	LARISA KUZNECOVA	{"phone": "+70209097034"}
0005434287876	9A09A9	2634 751260	VIKTOR KUZNECOV	{"phone": "+70508783291"}
0005434287877	4A328D	3584 216046	ANATOLIY STEPANOV	{"email": "stepanov-anatoliy_061961@postgrespro.ru", "phone": "+70222105514"}
0005434287878	938CDA	0151 994308	NIKOLAY SOROKIN	{"email": "n_sorokin02121974@postgrespro.ru", "phone": "+70116115646"}
0005434287879	33AE7D	7716 279201	IVAN NOVIKOV	{"email": "inovikov.041972@postgrespro.ru", "phone": "+70117778706"}
0005434287880	31DDF0	4530 404978	ALEKSEY VASILEV	{"phone": "+70388444956"}
0005434287881	B68FA6	0221 221743	SHAMIL KUZMIN	{"phone": "+70318004117"}
0005434287882	3D376A	2888 399495	MAKSIM FEDOROV	{"phone": "+70734151648"}
0005434287883	817916	9369 918214	SARIYA BELOVA	{"email": "belova.s_19031973@postgrespro.ru", "phone": "+70074554589"}
0005434287884	89C07D	7449 216875	OLGA GUSEVA	{"email": "olgaguseva-09051973@postgrespro.ru", "phone": "+70598285582"}
0005434287885	89C07D	7583 377891	ALEKSEY KRASNOV	{"email": "krasnov-aleksey-121983@postgrespro.ru", "phone": "+70447876804"}
0005434287886	89C07D	6226 239733	VALENTINA KOZLOVA	{"phone": "+70493262157"}
0005434287887	D23497	8396 724445	NATALIYA BELOVA	{"phone": "+70816304777"}
0005434287888	CEB0D8	0295 261303	ELENA DENISOVA	{"email": "denisova-elena_24061978@postgrespro.ru", "phone": "+70834426638"}
0005434287889	5ECD20	5449 374063	VLADISLAV SHEVCHENKO	{"phone": "+70323653477"}
0005434287890	5ECD20	0794 618124	ELENA POPOVA	{"email": "popova_e.031974@postgrespro.ru", "phone": "+70490664258"}
0005434287891	68556B	2792 678456	TATYANA KONOVALOVA	{"phone": "+70895157946"}
0005434287892	F26AD6	5673 731743	TATYANA KONOVALOVA	{"phone": "+70570535015"}
0005434287893	AD5E01	2920 421020	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova.031975@postgrespro.ru", "phone": "+70011834910"}
0005434287894	AD5E01	8458 400340	NATALYA VASILEVA	{"email": "vasileva-n-1970@postgrespro.ru", "phone": "+70028523927"}
0005434287895	7DA63E	3527 029126	LARISA POPOVA	{"email": "popova.l-02121971@postgrespro.ru", "phone": "+70195199430"}
0005434287896	6A4F86	3215 175763	MARINA DMITRIEVA	{"phone": "+70323496398"}
0005434287897	FF0147	8725 176845	ALEKSANDR KUZNECOV	{"phone": "+70163020115"}
0005434287898	64AB0C	2275 541403	NATALIYA KULIKOVA	{"email": "n.kulikova101976@postgrespro.ru", "phone": "+70571356166"}
0005434287899	64AB0C	2627 994009	ANTON FOMIN	{"phone": "+70279200071"}
0005434287900	64AB0C	7080 717491	TAISIYA FOMINA	{"phone": "+70668914319"}
0005434287901	A396EB	2456 858793	SERGEY SERGEEV	{"phone": "+70682642264"}
0005434299222	5681DC	5865 133463	VLADIMIR PETROV	{"phone": "+70528333701"}
0005434287902	569A06	6554 032961	NADEZHDA STEPANOVA	{"email": "stepanovan20011970@postgrespro.ru", "phone": "+70197078127"}
0005434287903	254920	3613 285262	VERA NIKITINA	{"phone": "+70028683725"}
0005434287904	CE81D9	8698 524446	MARIYA STEPANOVA	{"phone": "+70812667410"}
0005434287905	1EF32E	4674 307239	ELENA PETROVA	{"email": "e-petrova1979@postgrespro.ru", "phone": "+70357545586"}
0005434287906	1EF32E	1803 814847	RUSTEM ROMANOV	{"email": "rustem_romanov.25071962@postgrespro.ru", "phone": "+70143827207"}
0005434287907	1EF32E	7548 040169	DMITRIY KUDRYASHOV	{"phone": "+70579851127"}
0005434287908	AF6ACD	7027 941799	VIKTOR TIKHONOV	{"phone": "+70194048120"}
0005434287909	AF6ACD	5836 721854	MIKHAIL POPOV	{"email": "m_popov-031968@postgrespro.ru", "phone": "+70999053521"}
0005434287910	45D1DC	7996 530470	KIRILL NAZAROV	{"email": "nazarov.k10071983@postgrespro.ru", "phone": "+70796165903"}
0005434287911	45D1DC	4636 766354	NIKOLAY NIKOLAEV	{"phone": "+70492337117"}
0005434287912	45D1DC	6691 087551	ELENA BELOVA	{"email": "belova.elena-23021966@postgrespro.ru", "phone": "+70643812858"}
0005434287913	ABA743	6280 599384	BORIS PETROV	{"phone": "+70018526401"}
0005434287914	85B06A	0660 537819	SERGEY MAKAROV	{"phone": "+70003786233"}
0005434287915	85B06A	9028 030321	GALINA MIRONOVA	{"email": "gmironova_05111974@postgrespro.ru", "phone": "+70993352260"}
0005434287916	F8694C	5578 476190	VITALIY VOLKOV	{"phone": "+70619629096"}
0005434287917	F8694C	2272 612335	NATALYA KONDRATEVA	{"email": "kondrateva.n-091975@postgrespro.ru", "phone": "+70502611114"}
0005434287918	56DA91	7764 827840	FANIS PAVLOV	{"email": "pavlovf_051982@postgrespro.ru", "phone": "+70276282917"}
0005434287919	56DA91	1774 726099	ANNA SIDOROVA	{"phone": "+70087599516"}
0005434287920	E641FD	7710 015789	SERGEY SEMENOV	{"email": "s_semenov.121982@postgrespro.ru", "phone": "+70203795822"}
0005434287921	E641FD	5323 383788	NADEZHDA BORISOVA	{"email": "borisova.nadezhda.041973@postgrespro.ru", "phone": "+70900926197"}
0005434287922	E641FD	1202 009920	VALENTINA MOROZOVA	{"phone": "+70239596280"}
0005434287923	1B6F31	7424 701788	MIKHAIL MAKSIMOV	{"phone": "+70004771434"}
0005434287924	1B6F31	5854 434175	YURIY KULIKOV	{"email": "yuriy.kulikov_15091972@postgrespro.ru", "phone": "+70238554004"}
0005434287925	0657AE	3704 482672	SVETLANA FILATOVA	{"email": "svetlana.filatova061976@postgrespro.ru", "phone": "+70564576004"}
0005434287926	EBB8E2	5688 328955	ANNA KUZMINA	{"email": "anna.kuzmina-1962@postgrespro.ru", "phone": "+70747579207"}
0005434287927	6F16E8	1834 900944	ANASTASIYA FROLOVA	{"email": "anastasiyafrolova.04051971@postgrespro.ru", "phone": "+70539838390"}
0005434287928	004866	4927 515294	LYUDMILA MOROZOVA	{"phone": "+70943073897"}
0005434287929	0FA5E7	4389 919192	NATALYA KULIKOVA	{"phone": "+70510424448"}
0005434287930	90F39E	9222 860113	LYUBOV KOROLEVA	{"email": "koroleva-l_1964@postgrespro.ru", "phone": "+70904297593"}
0005434287931	02572E	4783 843497	SVETLANA IVANOVA	{"phone": "+70800863723"}
0005434287932	DA4D92	6478 467926	SERGEY ANDREEV	{"phone": "+70031980007"}
0005434287933	DA4D92	2897 253461	ANNA FILIPPOVA	{"email": "a_filippova-051975@postgrespro.ru", "phone": "+70160747678"}
0005434287934	95197C	5748 840066	ALEKSANDR GUSEV	{"email": "a-gusev-021966@postgrespro.ru", "phone": "+70152991738"}
0005434287935	7D0033	0555 445278	YURIY IVANOV	{"phone": "+70156591638"}
0005434287936	7D0033	0808 083584	EGOR KUZNECOV	{"email": "kuznecov.egor.051965@postgrespro.ru", "phone": "+70783984823"}
0005434287937	24F989	7601 446975	EVGENIY MOROZOV	{"email": "evgeniy.morozov.30041969@postgrespro.ru", "phone": "+70001905207"}
0005434287938	7EA729	9736 698160	MARGARITA MAKAROVA	{"email": "makarova.m.12041970@postgrespro.ru", "phone": "+70721886617"}
0005434287939	9D96C2	5395 427665	ALEKSANDR TIKHONOV	{"phone": "+70669020215"}
0005434287940	5D425F	5192 387589	VIKTOR ANTONOV	{"phone": "+70066904157"}
0005434287941	0F0377	7976 005287	VALERIY PAVLOV	{"phone": "+70095866893"}
0005434287942	9F9B59	8618 071115	ANAIT KUZNECOVA	{"email": "anait.kuznecova_1971@postgrespro.ru", "phone": "+70536676220"}
0005434287943	9F9B59	6307 702710	GENNADIY SIDOROV	{"email": "gennadiysidorov021970@postgrespro.ru", "phone": "+70716284302"}
0005434287944	3259EF	9437 685524	KONSTANTIN GUSEV	{"phone": "+70826772936"}
0005434299147	69DCC7	6655 823429	ALEKSEY PETROV	{"phone": "+70040110447"}
0005434299148	093D41	3964 034391	MARIYA VOROBEVA	{"phone": "+70921844074"}
0005434299149	AB7FA0	3915 056207	RINAT NAZAROV	{"email": "nazarov-rinat_101965@postgrespro.ru", "phone": "+70821717308"}
0005434299150	DEE05C	7135 051216	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy.1977@postgrespro.ru", "phone": "+70096321773"}
0005434299151	0803B1	2892 124258	MARINA MARTYNOVA	{"email": "mmartynova_101967@postgrespro.ru", "phone": "+70183872116"}
0005434299152	63473B	6608 316975	IVAN TIMOFEEV	{"email": "timofeevivan_021975@postgrespro.ru", "phone": "+70605078815"}
0005434299153	63473B	3058 230202	VLADIMIR POPOV	{"email": "popov-vladimir_10121969@postgrespro.ru", "phone": "+70949799975"}
0005434299154	73F08A	7921 506230	VALERIY GORBUNOV	{"email": "v.gorbunov05111962@postgrespro.ru", "phone": "+70849867593"}
0005434299155	73F08A	1450 003190	DMITRIY ISAEV	{"email": "isaevdmitriy121976@postgrespro.ru", "phone": "+70695590738"}
0005434299156	C66671	1781 907066	DMITRIY SAVELEV	{"phone": "+70114680671"}
0005434299157	CF0C32	3373 753910	ANATOLIY IVANOV	{"email": "ivanov-a.111978@postgrespro.ru", "phone": "+70972583171"}
0005434299158	27041E	7860 025090	IRINA IVANOVA	{"phone": "+70194510464"}
0005434299159	8FB627	0299 271388	ANNA FEDOROVA	{"email": "fedorova.anna-1965@postgrespro.ru", "phone": "+70302884040"}
0005434299160	F9E379	4698 633309	ALEKSANDR ZAKHAROV	{"phone": "+70651626763"}
0005434299161	6A50F6	5523 569290	TATYANA KULIKOVA	{"phone": "+70525364897"}
0005434299162	BD1260	6724 865877	MARIYA TARASOVA	{"email": "tarasova-mariya.1968@postgrespro.ru", "phone": "+70756220455"}
0005434299163	53A173	4829 729111	EVGENIY SOKOLOV	{"phone": "+70339160009"}
0005434299164	53A173	6908 028254	ARINA OSIPOVA	{"email": "osipova.a-111979@postgrespro.ru", "phone": "+70884130145"}
0005434299165	7661F1	4549 296753	LYUDMILA POPOVA	{"email": "popova_lyudmila-24101979@postgrespro.ru", "phone": "+70804658193"}
0005434299166	30614C	0406 159038	VYACHESLAV ISAEV	{"email": "vyacheslavisaev-061975@postgrespro.ru", "phone": "+70519413045"}
0005434299167	0E40CE	3104 776412	NATALYA BELOVA	{"email": "natalya-belova18061974@postgrespro.ru", "phone": "+70241631312"}
0005434299168	7DB427	8839 179429	ELISEY VOLKOV	{"email": "volkovelisey081964@postgrespro.ru", "phone": "+70500457797"}
0005434299169	185208	7782 860494	IVAN KUDRYASHOV	{"email": "ivan.kudryashov.28081978@postgrespro.ru", "phone": "+70887311204"}
0005434299170	97D8D0	1150 960862	IRINA MALYSHEVA	{"phone": "+70071601303"}
0005434299171	97D8D0	3313 593138	IGNAT ROMANOV	{"phone": "+70868906609"}
0005434299172	ECE26A	9912 704406	OLESYA FOMINA	{"email": "fomina-olesya21051974@postgrespro.ru", "phone": "+70884747094"}
0005434299173	CAAAB4	7952 877723	ALEKSANDR SIDOROV	{"email": "a-sidorov-1962@postgrespro.ru", "phone": "+70942965075"}
0005434299174	05ABD6	6246 153390	EVGENIY MEDVEDEV	{"phone": "+70164248157"}
0005434299175	D16EE7	3193 965555	STANISLAV SEMENOV	{"email": "semenov_s_1975@postgrespro.ru", "phone": "+70369311039"}
0005434299176	758EBE	8529 130243	VALENTINA ROMANOVA	{"phone": "+70709006277"}
0005434299177	F23CCC	5416 878811	PAVEL MATVEEV	{"email": "pavelmatveev1956@postgrespro.ru", "phone": "+70940502383"}
0005434299178	F23CCC	6033 244635	OLGA FROLOVA	{"email": "olga.frolova_1964@postgrespro.ru", "phone": "+70085588090"}
0005434299179	2E9F6C	4916 060589	MARIYA MAKSIMOVA	{"email": "maksimovamariya.1970@postgrespro.ru", "phone": "+70515360460"}
0005434299180	326723	3137 520561	ANNA SMIRNOVA	{"email": "smirnovaa31051978@postgrespro.ru", "phone": "+70916138358"}
0005434299181	D2A66B	6931 048213	LARISA GRISHINA	{"email": "larisagrishina-031972@postgrespro.ru", "phone": "+70557475241"}
0005434299182	B41F78	5472 954880	EVGENIY KUZNECOV	{"email": "evgeniy-kuznecov06081973@postgrespro.ru", "phone": "+70644607466"}
0005434299183	FF500A	0792 830605	SERGEY FILIPPOV	{"email": "filippov.sergey-051971@postgrespro.ru", "phone": "+70134293386"}
0005434299184	FF500A	6266 103899	DENIS ISAEV	{"email": "denis_isaev121978@postgrespro.ru", "phone": "+70558923479"}
0005434299185	C5B9C3	4638 237826	SERGEY TIMOFEEV	{"phone": "+70159546141"}
0005434299186	C5B9C3	9446 176760	TATYANA ROMANOVA	{"email": "t.romanova051976@postgrespro.ru", "phone": "+70015699201"}
0005434299187	359E57	4494 718293	ALEKSANDR GORBUNOV	{"email": "a.gorbunov_011970@postgrespro.ru", "phone": "+70760116197"}
0005434299188	8E264E	3884 870520	NADEZHDA LEBEDEVA	{"phone": "+70743835250"}
0005434299189	1B59FD	3050 960938	DMITRIY VASILEV	{"email": "vasilev-dmitriy101960@postgrespro.ru", "phone": "+70014187069"}
0005434299190	E86600	7458 347800	VYACHESLAV ALEKSEEV	{"phone": "+70170451497"}
0005434299191	E86600	0632 992893	OLEG IVANOV	{"phone": "+70085379482"}
0005434299192	31AA97	8505 135801	ALEKSANDR PAVLOV	{"phone": "+70693632054"}
0005434299193	31AA97	6038 075037	VADIM KONOVALOV	{"email": "konovalov.v_1977@postgrespro.ru", "phone": "+70598741214"}
0005434299194	BDC206	8348 999125	OLGA NOVIKOVA	{"email": "olganovikova14121962@postgrespro.ru", "phone": "+70034169457"}
0005434299195	BDC206	0762 769873	EVGENIY GERASIMOV	{"phone": "+70161189838"}
0005434299196	E4108A	6584 469696	ZINAIDA SEMENOVA	{"phone": "+70841907142"}
0005434299197	994650	1660 509186	ALEKSANDR FOMIN	{"email": "afomin_03091978@postgrespro.ru", "phone": "+70437405269"}
0005434299198	994650	3107 582612	RUSTAM SHEVCHENKO	{"phone": "+70781751318"}
0005434299199	4D2A9B	7644 738236	VALENTINA GAVRILOVA	{"phone": "+70799437304"}
0005434299200	32A0A0	6214 181537	ARTEM PAVLOV	{"email": "a_pavlov16071981@postgrespro.ru", "phone": "+70390641631"}
0005434299201	32A0A0	3072 798203	ELENA ZAYCEVA	{"email": "zayceva_elena.21121966@postgrespro.ru", "phone": "+70483862172"}
0005434299202	0125FD	0161 055666	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov1963@postgrespro.ru", "phone": "+70431683644"}
0005434299203	0125FD	5304 430483	VADIM SHEVCHENKO	{"email": "shevchenkov-28121966@postgrespro.ru", "phone": "+70126076799"}
0005434299204	7FBD48	6626 461485	MARGARITA MIRONOVA	{"phone": "+70445395813"}
0005434299205	101DB7	7447 274472	OKSANA ANTONOVA	{"phone": "+70731245389"}
0005434299206	101DB7	5096 232523	IVAN ZAKHAROV	{"email": "izakharov081978@postgrespro.ru", "phone": "+70261296234"}
0005434299207	D21C2B	8271 231834	GALINA BORISOVA	{"email": "borisova.galina-1976@postgrespro.ru", "phone": "+70956474224"}
0005434299208	FEC447	5074 977307	EGOR DAVYDOV	{"phone": "+70463838775"}
0005434299209	A72688	3053 503467	VALENTINA MALYSHEVA	{"email": "malysheva.v_04101971@postgrespro.ru", "phone": "+70147155172"}
0005434299210	47BE9E	2778 561912	ELENA GRISHINA	{"phone": "+70185364737"}
0005434299211	212C06	6306 256489	FEDOR ILIN	{"email": "ilin-fedor.1965@postgrespro.ru", "phone": "+70757936026"}
0005434299212	1728D5	0319 488735	ELENA ZAKHAROVA	{"phone": "+70950805132"}
0005434299213	A8F4D1	7316 904972	IRINA OSIPOVA	{"email": "irina-osipova_24031974@postgrespro.ru", "phone": "+70299979784"}
0005434299214	A8F4D1	1044 258603	SHAMIL FOMIN	{"phone": "+70410823584"}
0005434299215	544451	8616 545568	SAVELIY SERGEEV	{"email": "saveliy-sergeev1966@postgrespro.ru", "phone": "+70544905166"}
0005434299216	544451	9930 842273	PAVEL IVANOV	{"email": "ivanov.pavel.21081971@postgrespro.ru", "phone": "+70660776950"}
0005434299217	1C0EFE	1401 100159	ALEKSANDR STEPANOV	{"email": "stepanov-a16121977@postgrespro.ru", "phone": "+70234695643"}
0005434299218	1C0EFE	7749 214144	NINA STEPANOVA	{"email": "nina.stepanova_1961@postgrespro.ru", "phone": "+70082105735"}
0005434299219	201860	2018 386065	IRINA MELNIKOVA	{"phone": "+70092916023"}
0005434299220	201860	2025 481724	SVETLANA ALEKSEEVA	{"email": "alekseeva.s_20081977@postgrespro.ru", "phone": "+70346824851"}
0005434299221	201860	0694 867233	NATALYA KAZAKOVA	{"phone": "+70300231571"}
0005434299223	5681DC	8459 003572	IVAN GERASIMOV	{"email": "ivan-gerasimov_1970@postgrespro.ru", "phone": "+70227716062"}
0005434299224	9EBC19	2486 111230	GALINA NESTEROVA	{"email": "nesterovag121973@postgrespro.ru", "phone": "+70609962698"}
0005434299225	9EBC19	1699 150545	NINA KULIKOVA	{"phone": "+70306762194"}
0005434299226	3F8A8A	3650 306691	SVETLANA RYABOVA	{"email": "ryabova.s_31121977@postgrespro.ru", "phone": "+70812633690"}
0005434299227	5AADF9	6187 523215	PAVEL FROLOV	{"email": "frolovpavel1971@postgrespro.ru", "phone": "+70420719456"}
0005434299228	2EF9AE	6942 443504	LARISA KRASNOVA	{"email": "larisakrasnova-1960@postgrespro.ru", "phone": "+70070469564"}
0005434299229	DC8EDF	5137 956638	ALEKSANDR DENISOV	{"email": "denisov.aleksandr.08081968@postgrespro.ru", "phone": "+70333719133"}
0005434299230	DC8EDF	3055 259660	ARTEM NAUMOV	{"email": "naumov.a.1977@postgrespro.ru", "phone": "+70100185642"}
0005434299231	16A171	9467 602157	TATYANA RODIONOVA	{"email": "rodionova-tatyana-101969@postgrespro.ru", "phone": "+70481501588"}
0005434299232	16A171	9837 400937	KAROLINA KUZNECOVA	{"email": "kuznecova-k-1965@postgrespro.ru", "phone": "+70091009825"}
0005434299233	82D05E	9191 998173	EVGENIY SEMENOV	{"email": "semenov.evgeniy061972@postgrespro.ru", "phone": "+70050167327"}
0005434299234	AF5E31	8234 828125	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr-1971@postgrespro.ru", "phone": "+70840813954"}
0005434299235	1D0B6F	0693 764511	LARISA RYABOVA	{"email": "larisa.ryabova.22041964@postgrespro.ru", "phone": "+70842797316"}
0005434299236	603B87	2242 327974	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko-1978@postgrespro.ru", "phone": "+70508244937"}
0005434299237	AEF571	8967 003314	ANATOLIY ISAEV	{"phone": "+70050919800"}
0005434299238	AEF571	9088 869750	VLADIMIR BARANOV	{"email": "v-baranov1984@postgrespro.ru", "phone": "+70642441679"}
0005434299239	5C930D	1927 960620	EGOR EGOROV	{"phone": "+70184582972"}
0005434299240	27F9FB	1216 802200	DENIS MARTYNOV	{"phone": "+70292158064"}
0005434299241	14F469	4234 315440	NATALYA NIKITINA	{"phone": "+70898558710"}
0005434299242	211817	1503 142483	MIKHAIL FOMIN	{"phone": "+70286342368"}
0005434299243	A161DF	5095 645958	NINA GERASIMOVA	{"email": "gerasimovanina-061981@postgrespro.ru", "phone": "+70194254294"}
0005434299244	16B66D	8185 366914	TATYANA KONOVALOVA	{"email": "konovalova_tatyana-1967@postgrespro.ru", "phone": "+70177729718"}
0005434299245	C6FC11	5983 676426	ALEKSEY MATVEEV	{"phone": "+70168868015"}
0005434299246	C6FC11	3256 525877	GALINA SOKOLOVA	{"email": "sokolova.g_081977@postgrespro.ru", "phone": "+70358726202"}
0005434299247	EDE6DE	1256 132305	SERGEY YAKOVLEV	{"phone": "+70261381771"}
0005434299248	D719D0	2764 742368	ALEKSANDR IVANOV	{"phone": "+70241202267"}
0005434299249	D719D0	3246 032665	NIKITA FEDOROV	{"email": "n_fedorov121962@postgrespro.ru", "phone": "+70439064131"}
0005434299250	AEFF70	6823 206609	ALEKSANDR TARASOV	{"phone": "+70492488908"}
0005434299251	AEFF70	2908 619167	TATYANA LAZAREVA	{"phone": "+70008124023"}
0005434299252	DF1831	5767 864383	VLADIMIR NIKOLAEV	{"phone": "+70612988932"}
0005434299253	6823EC	5877 117931	NATALYA POPOVA	{"phone": "+70669217574"}
0005434299254	A6892B	5164 868676	MARINA SOKOLOVA	{"email": "sokolova_marina-041966@postgrespro.ru", "phone": "+70813505986"}
0005434299255	A6892B	1106 450127	TATYANA PAVLOVA	{"phone": "+70994791728"}
0005434299256	A6892B	3719 835432	LYUDMILA MELNIKOVA	{"phone": "+70481503117"}
0005434299257	A6892B	1070 804142	RAISA FROLOVA	{"email": "frolovaraisa19111972@postgrespro.ru", "phone": "+70809248365"}
0005434299258	FF4694	2875 893787	MIKHAIL ANDREEV	{"phone": "+70335967189"}
0005434299259	16BDC7	7037 757211	DANIIL SOROKIN	{"email": "sorokind1961@postgrespro.ru", "phone": "+70025248100"}
0005434299260	EE7604	4236 225702	MARIYA POPOVA	{"email": "popova-mariya_091973@postgrespro.ru", "phone": "+70253978714"}
0005434299261	EE7604	5197 930397	MIKHAIL IVANOV	{"email": "ivanov-mikhail_011969@postgrespro.ru", "phone": "+70224650405"}
0005434299262	FFCCAD	5136 048667	RIM KUZNECOV	{"email": "kuznecov.r_051972@postgrespro.ru", "phone": "+70601653348"}
0005434299263	E0213C	4044 784662	ASIYA ZAKHAROVA	{"email": "zakharova-asiya.051979@postgrespro.ru", "phone": "+70698729310"}
0005434299264	5ADC0F	9470 460113	VLADIMIR KOZLOV	{"phone": "+70943795112"}
0005434299265	222DD3	0318 486117	EDUARD BONDARENKO	{"phone": "+70015762661"}
0005434299266	222DD3	7635 972480	TAMARA IVANOVA	{"phone": "+70328250055"}
0005434299267	3F2BAC	5600 177725	IVAN SERGEEV	{"email": "ivan-sergeev1974@postgrespro.ru", "phone": "+70108586365"}
0005434299268	644198	9731 127238	ANTON KISELEV	{"phone": "+70159912549"}
0005434299269	644198	0003 268724	OLESYA RODIONOVA	{"phone": "+70266845424"}
0005434299270	401900	3107 164239	ROMAN KULIKOV	{"phone": "+70193337388"}
0005434299271	401900	1915 424056	ANTON SAVELEV	{"email": "a.savelev121977@postgrespro.ru", "phone": "+70435874774"}
0005434299272	9F8FCC	5887 499610	SERGEY DENISOV	{"email": "denisovsergey.16061970@postgrespro.ru", "phone": "+70512205020"}
0005434299273	08993D	3010 408358	VALENTINA KUZMINA	{"phone": "+70211938932"}
0005434299274	11EADD	0995 465822	YURIY KUZNECOV	{"email": "yuriy-kuznecov031962@postgrespro.ru", "phone": "+70683392480"}
0005434299275	11EADD	8013 051587	LYUDMILA SCHERBAKOVA	{"phone": "+70027535607"}
0005434299276	313B8B	7042 925079	SERGEY SMIRNOV	{"email": "s.smirnov_051965@postgrespro.ru", "phone": "+70326685510"}
0005434299277	FA3C2A	4275 721139	OLESYA GUSEVA	{"email": "gusevaolesya1971@postgrespro.ru", "phone": "+70549394641"}
0005434299278	B79822	4793 451225	EKATERINA NIKOLAEVA	{"phone": "+70748091593"}
0005434299279	408D01	0963 491217	ZOYA EGOROVA	{"phone": "+70427877991"}
0005434299280	9F87D8	5096 591799	ALEKSANDR SEMENOV	{"phone": "+70335978517"}
0005434299281	9F87D8	6506 362700	YULIYA ZAKHAROVA	{"email": "y.zakharova-11051980@postgrespro.ru", "phone": "+70881288141"}
0005434299282	7D92F3	6900 613963	ANDREY STEPANOV	{"email": "stepanov-a051975@postgrespro.ru", "phone": "+70770809955"}
0005434299283	0490BE	9944 361153	VLADIMIR FROLOV	{"phone": "+70783985413"}
0005434299284	7CF617	7078 192452	NIKOLAY KUZNECOV	{"phone": "+70113290168"}
0005434299285	9F27F5	7267 215345	IVAN PAVLOV	{"email": "pavlovi-1957@postgrespro.ru", "phone": "+70466979793"}
0005434299286	983BE2	8501 816232	VIKTOR MATVEEV	{"email": "matveevviktor_051969@postgrespro.ru", "phone": "+70880441683"}
0005434299287	983BE2	7922 668436	MARINA AKIMOVA	{"email": "marinaakimova-111976@postgrespro.ru", "phone": "+70947987467"}
0005434299288	91F844	8362 073680	GENNADIY SOKOLOV	{"email": "sokolovg_19051980@postgrespro.ru", "phone": "+70877443772"}
0005434299289	6D7F5D	3829 043244	IGOR SIDOROV	{"email": "sidorov.i071971@postgrespro.ru", "phone": "+70764647866"}
0005434299290	6D7F5D	3858 278766	VLADIMIR STEPANOV	{"email": "stepanov-v061975@postgrespro.ru", "phone": "+70561319449"}
0005434299291	9DD3BB	9473 567677	DENIS BORISOV	{"email": "denisborisov_1971@postgrespro.ru", "phone": "+70463536573"}
0005434299292	F76C0C	0146 644538	VASILIY ANDREEV	{"phone": "+70806530500"}
0005434299293	5EB4A3	4673 472090	RUSLAN IVANOV	{"email": "ivanovruslan_031971@postgrespro.ru", "phone": "+70114559117"}
0005434299294	5EB4A3	4254 418021	VALENTINA NOVIKOVA	{"phone": "+70764593359"}
0005434299295	2892F6	3502 539906	RIMMA KOMAROVA	{"email": "komarova.r041969@postgrespro.ru", "phone": "+70629264914"}
0005434299296	2892F6	8335 330000	VASILIY PETROV	{"phone": "+70838198523"}
0005434299297	2892F6	8045 897311	ELENA YAKOVLEVA	{"phone": "+70479507428"}
0005434299298	28405A	3303 847044	TATYANA YAKOVLEVA	{"email": "yakovleva_tatyana-121968@postgrespro.ru", "phone": "+70714826741"}
0005434299299	28405A	2336 573541	FARID KAZAKOV	{"phone": "+70060159749"}
0005434299300	9430C8	3624 966557	RAISA LAZAREVA	{"phone": "+70901385300"}
0005434299301	519ACD	4527 969124	ALEKSANDR TARASOV	{"email": "tarasova.1966@postgrespro.ru", "phone": "+70336400171"}
0005434299302	519ACD	3195 142108	DMITRIY BONDARENKO	{"email": "d-bondarenko_03111976@postgrespro.ru", "phone": "+70940219268"}
0005434299303	13F408	8146 431761	VALENTIN MATVEEV	{"email": "valentin-matveev-101970@postgrespro.ru", "phone": "+70974437073"}
0005434299304	13F408	8415 863037	ELENA NIKOLAEVA	{"email": "e.nikolaeva.14041958@postgrespro.ru", "phone": "+70548584712"}
0005434299305	B1084B	8885 215146	ALEKSANDRA FILIPPOVA	{"phone": "+70800753374"}
0005434299306	EB622E	1217 675496	ARTEM ROMANOV	{"phone": "+70810554771"}
0005434299307	8592C4	2931 546516	MARINA MOISEEVA	{"phone": "+70065857203"}
0005434299308	8592C4	5625 524467	DMITRIY PETROV	{"email": "dmitriy.petrov23021978@postgrespro.ru", "phone": "+70966291963"}
0005434299309	DDF136	7093 779785	SERGEY OSIPOV	{"phone": "+70595345847"}
0005434299310	DCECA4	3924 290224	ANASTASIYA ANDREEVA	{"email": "anastasiya_andreeva051978@postgrespro.ru", "phone": "+70391485437"}
0005434299311	11F3B5	8326 981639	PAVEL GRIGOREV	{"email": "grigorev-pavel_1962@postgrespro.ru", "phone": "+70446902422"}
0005434299312	2560A5	5445 971846	PAVEL KONOVALOV	{"email": "konovalov_p.051982@postgrespro.ru", "phone": "+70866812697"}
0005434299313	2560A5	8138 049808	ANDREY ZHURAVLEV	{"email": "zhuravlev.andrey1974@postgrespro.ru", "phone": "+70210426513"}
0005434299314	2560A5	7351 728035	LARISA ANDREEVA	{"phone": "+70027779836"}
0005434299315	9D8A5B	7399 104378	MATRENA NAUMOVA	{"email": "naumova.m1967@postgrespro.ru", "phone": "+70989962442"}
0005434299316	9D8A5B	7753 060077	RAMIL MAKAROV	{"phone": "+70710277753"}
0005434299317	B8BE92	9432 358442	TAMARA NIKOLAEVA	{"phone": "+70216157049"}
0005434299318	1FE4B0	3618 101777	SERGEY NAZAROV	{"phone": "+70836101815"}
0005434299319	597450	1036 750654	ALENA OVCHINNIKOVA	{"phone": "+70978708555"}
0005434299320	C06DF7	1789 772695	ANASTASIYA MELNIKOVA	{"email": "a-melnikova-31031977@postgrespro.ru", "phone": "+70826185795"}
0005434299321	F5A347	7698 476418	SVETLANA ALEKSEEVA	{"email": "alekseevas091979@postgrespro.ru", "phone": "+70408169115"}
0005434299322	5E5219	1898 944610	ANASTASIYA KAZAKOVA	{"phone": "+70965743659"}
0005434299323	463EB1	1422 460039	VLADIMIR MARTYNOV	{"email": "v-martynov-021977@postgrespro.ru", "phone": "+70080361608"}
0005434299324	463EB1	3272 211011	ALEKSANDR ANDREEV	{"phone": "+70867355047"}
0005434299325	C6E81B	3840 902688	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev_19031982@postgrespro.ru", "phone": "+70089845108"}
0005434299326	3C3E97	9995 564124	VERONIKA EGOROVA	{"phone": "+70644387251"}
0005434299327	D3C161	8157 913771	EVDOKIYA FEDOROVA	{"phone": "+70208106165"}
0005434299328	AB74F0	7208 579082	ALEKSANDR KISELEV	{"phone": "+70273428287"}
0005434299329	B86D20	1491 290175	OKSANA TIKHONOVA	{"email": "tikhonova_oksana05011976@postgrespro.ru", "phone": "+70865799114"}
0005434299330	55252B	9523 732697	VLADIMIR SOROKIN	{"phone": "+70006849153"}
0005434299331	C1DD6A	9971 873916	SERGEY MIKHAYLOV	{"email": "mikhaylov.s.101976@postgrespro.ru", "phone": "+70576832296"}
0005434299332	DD9831	5688 380507	ARTEMIY EGOROV	{"phone": "+70698040385"}
0005434299333	5D1654	1255 769317	ZLATA POLYAKOVA	{"phone": "+70841847640"}
0005434299334	5D1654	9551 174212	ALEKSEY AFANASEV	{"email": "afanasev_aleksey.111958@postgrespro.ru", "phone": "+70671165873"}
0005434299335	0F0256	9025 521512	VALENTINA MAKAROVA	{"phone": "+70400159775"}
0005434299336	C924A5	5814 184942	TATYANA PETROVA	{"email": "tatyana-petrova.1967@postgrespro.ru", "phone": "+70061940285"}
0005434299337	C924A5	3525 238957	ALEKSEY NIKITIN	{"phone": "+70357264364"}
0005434299338	C924A5	3850 657495	VITALIY GRIGOREV	{"email": "grigorevv.1977@postgrespro.ru", "phone": "+70298661511"}
0005434299339	B574C7	1639 618156	IGOR VOLKOV	{"email": "igor.volkov12101969@postgrespro.ru", "phone": "+70073900980"}
0005434299340	E8C440	5901 970540	MARIYA FROLOVA	{"phone": "+70589045248"}
0005434299341	DBC839	7688 967538	NINA KUDRYASHOVA	{"phone": "+70196563230"}
0005434299342	DBC839	6338 289080	IRINA SERGEEVA	{"phone": "+70464217212"}
0005434299403	B2A5FE	7686 700498	ANNA KOROLEVA	{"phone": "+70141257369"}
0005434299343	B943C1	7546 350210	VIKTORIYA PAVLOVA	{"email": "vpavlova02021979@postgrespro.ru", "phone": "+70767909887"}
0005434299344	CD775A	4931 101893	DENIS KARPOV	{"phone": "+70467139623"}
0005434299345	8E323C	5764 130560	ALEKSEY KOZLOV	{"phone": "+70228980081"}
0005434299346	8E323C	9794 815222	NATALIYA ZHUKOVA	{"phone": "+70326256353"}
0005434299347	48C056	1786 944336	SERGEY ILIN	{"email": "ilin.sergey.1970@postgrespro.ru", "phone": "+70767818851"}
0005434299348	BF3287	2016 543875	TATYANA LOGINOVA	{"email": "t_loginova.061972@postgrespro.ru", "phone": "+70272042320"}
0005434299349	91F9EB	8496 240709	EGOR KARPOV	{"email": "karpov_e22071978@postgrespro.ru", "phone": "+70068815604"}
0005434299350	91F9EB	8457 651001	ALINA MIKHAYLOVA	{"email": "mikhaylova.a101974@postgrespro.ru", "phone": "+70444112695"}
0005434299351	5C70DC	9109 183652	SVETLANA ERMAKOVA	{"email": "ermakova-svetlana1975@postgrespro.ru", "phone": "+70337817063"}
0005434299352	5C70DC	8243 843566	ANASTASIYA BOGDANOVA	{"phone": "+70882645351"}
0005434299353	E2DE8E	0259 287910	MARINA MATVEEVA	{"email": "matveeva-m-06051970@postgrespro.ru", "phone": "+70256020263"}
0005434299354	60683E	9287 656507	VLADIMIR SOROKIN	{"email": "vsorokin-13031970@postgrespro.ru", "phone": "+70482314300"}
0005434299355	45E1C5	7267 657306	MARIYA MAKSIMOVA	{"email": "m-maksimova_1970@postgrespro.ru", "phone": "+70726177180"}
0005434299356	45E1C5	2569 592314	NINA ERMAKOVA	{"email": "ermakova_nina1980@postgrespro.ru", "phone": "+70669382270"}
0005434299357	C11B1C	8351 961560	ALEKSANDR AFANASEV	{"email": "a_afanasev_1966@postgrespro.ru", "phone": "+70236995557"}
0005434299358	C11B1C	6051 302257	SVETLANA STEPANOVA	{"phone": "+70043715947"}
0005434299359	54E5BF	1128 862528	LYUBOV KUDRYASHOVA	{"email": "lyubovkudryashova.011969@postgrespro.ru", "phone": "+70641610514"}
0005434299360	54E5BF	5657 353111	TATYANA PAVLOVA	{"email": "tatyana_pavlova-1974@postgrespro.ru", "phone": "+70680127279"}
0005434299361	83455D	5662 572764	LYUDMILA BORISOVA	{"email": "borisova.lyudmila061971@postgrespro.ru", "phone": "+70176809934"}
0005434299362	01A1B1	7358 238466	OLGA VOROBEVA	{"email": "o_vorobeva1964@postgrespro.ru", "phone": "+70183890676"}
0005434299363	DA87FB	5351 966806	ALEKSANDR VASILEV	{"phone": "+70400711240"}
0005434299364	A40D61	1496 916514	ALEKSEY NAZAROV	{"phone": "+70746568249"}
0005434299365	84F934	9341 423197	VASILIY FILIPPOV	{"phone": "+70199624830"}
0005434299366	84F934	2668 490029	ALEKSANDRA LAZAREVA	{"email": "aleksandra.lazareva-18051973@postgrespro.ru", "phone": "+70956695532"}
0005434299367	AA7588	2470 215908	YURIY MEDVEDEV	{"phone": "+70340024174"}
0005434299368	AA7588	1362 148802	ANNA EGOROVA	{"phone": "+70040889121"}
0005434299369	B1707E	1122 531020	MARIYA SOROKINA	{"phone": "+70665095152"}
0005434299370	BBA261	7509 594421	YULIYA BELOVA	{"email": "ybelova07111968@postgrespro.ru", "phone": "+70326249393"}
0005434299371	BBA261	0641 721928	ELIZAVETA DMITRIEVA	{"email": "dmitrieva.e.121978@postgrespro.ru", "phone": "+70121984335"}
0005434299372	EEF4C2	7986 630388	LYUDMILA BOGDANOVA	{"email": "bogdanoval.1971@postgrespro.ru", "phone": "+70878895213"}
0005434299373	093EE5	9125 453006	GENNADIY VOLKOV	{"phone": "+70383399753"}
0005434299374	7EE9C9	2760 868105	YULIYA KULIKOVA	{"phone": "+70975641898"}
0005434299375	7EE9C9	8509 642249	SVETLANA STEPANOVA	{"phone": "+70094893522"}
0005434299376	C590A2	0437 281337	ANATOLIY ABRAMOV	{"email": "abramov-a111967@postgrespro.ru", "phone": "+70254645900"}
0005434299377	6BABE8	8233 562430	DANILA MELNIKOV	{"email": "danila-melnikov_1984@postgrespro.ru", "phone": "+70199920822"}
0005434299378	22A8CE	2679 972766	ANATOLIY EGOROV	{"phone": "+70926498419"}
0005434299379	22A8CE	4124 904359	ARSENIY PAVLOV	{"email": "pavlovarseniy_1980@postgrespro.ru", "phone": "+70078509517"}
0005434299380	AC1977	2147 439411	ELENA VLASOVA	{"phone": "+70787359337"}
0005434299381	AC1977	5938 155815	IRINA NESTEROVA	{"phone": "+70255248372"}
0005434299382	B1E4B6	2358 810857	EVGENIYA POPOVA	{"phone": "+70013786979"}
0005434299383	FFF106	5493 804796	ANDREY MIRONOV	{"phone": "+70435830749"}
0005434299384	A3BC39	2656 358825	ANATOLIY PETROV	{"email": "anatoliy_petrov_08091974@postgrespro.ru", "phone": "+70176435389"}
0005434299385	3AF063	7207 653816	NATALYA VLASOVA	{"email": "vlasovan_121983@postgrespro.ru", "phone": "+70071636539"}
0005434299386	3AF063	7755 314183	NADEZHDA KOVALEVA	{"email": "kovaleva_nadezhda-06121972@postgrespro.ru", "phone": "+70046080612"}
0005434299387	C3CDEA	7466 975498	SERGEY ROMANOV	{"email": "romanov.sergey.051987@postgrespro.ru", "phone": "+70259148673"}
0005434299388	124188	8732 658935	VALERIY ABRAMOV	{"email": "abramov.v1975@postgrespro.ru", "phone": "+70884182201"}
0005434299389	124188	6561 229387	ALEKSANDR ANDREEV	{"email": "andreeva_15051967@postgrespro.ru", "phone": "+70482215784"}
0005434299390	CC30A3	6474 752724	MIKHAIL GRIGOREV	{"phone": "+70873420886"}
0005434299391	C31F79	4938 889186	ARKADIY NAUMOV	{"phone": "+70667756967"}
0005434299392	C31F79	4917 178948	IVAN KOZLOV	{"phone": "+70311954107"}
0005434299393	758492	2866 137455	NADEZHDA ORLOVA	{"email": "orlova_nadezhda1963@postgrespro.ru", "phone": "+70430348399"}
0005434299394	E48B23	0388 265679	ANASTASIYA NOVIKOVA	{"email": "novikova_anastasiya121967@postgrespro.ru", "phone": "+70480707355"}
0005434299395	86D5B2	2101 580584	MILANA NESTEROVA	{"email": "nesterova-m051981@postgrespro.ru", "phone": "+70294681685"}
0005434299396	A4ABE4	0561 956622	LYUBOV IVANOVA	{"phone": "+70918259557"}
0005434299397	A4ABE4	9682 557340	RISHAT GRIGOREV	{"phone": "+70559926301"}
0005434299398	A4ABE4	3250 798673	YANA MOROZOVA	{"phone": "+70415430633"}
0005434299399	DDCD1A	9643 755001	SERGEY NAUMOV	{"email": "sergey.naumov-051969@postgrespro.ru", "phone": "+70669378007"}
0005434299400	82010B	8556 001540	IVAN SOROKIN	{"phone": "+70569111206"}
0005434299401	82010B	3007 883545	ALEKSANDR KISELEV	{"email": "aleksandr-kiselev.031979@postgrespro.ru", "phone": "+70048129917"}
0005434299402	841F49	1765 785292	IVAN PAVLOV	{"phone": "+70068081068"}
0005434299404	8EE253	8616 479004	EVGENIY MIKHAYLOV	{"phone": "+70171825700"}
0005434299405	8EE253	2372 648870	VALENTIN NAZAROV	{"email": "nazarovv_111974@postgrespro.ru", "phone": "+70422846817"}
0005434299406	9E4844	9770 010029	NIKOLAY KUZMIN	{"phone": "+70375208113"}
0005434299407	164841	0511 067734	NADEZHDA STEPANOVA	{"email": "n.stepanova.1980@postgrespro.ru", "phone": "+70457173206"}
0005434299408	D44BEC	9983 491393	ANDREY GUSEV	{"email": "agusev-011977@postgrespro.ru", "phone": "+70851933959"}
0005434299409	D44BEC	3827 785623	SVETLANA STEPANOVA	{"phone": "+70731565816"}
0005434299410	947928	3613 780605	IGOR TIMOFEEV	{"email": "i.timofeev.1974@postgrespro.ru", "phone": "+70853914568"}
0005434299411	91C534	2459 951087	YULIYA EFREMOVA	{"email": "efremova-yuliya15061972@postgrespro.ru", "phone": "+70888441720"}
0005434299412	AFE1FE	2118 150213	NIKOLAY PAVLOV	{"email": "nikolay-pavlov.20021968@postgrespro.ru", "phone": "+70784994820"}
0005434299413	AFE1FE	5809 023364	DANIL ANDREEV	{"email": "andreevdanil_1976@postgrespro.ru", "phone": "+70779331730"}
0005434299414	A8326C	7400 186795	LYUDMILA SOROKINA	{"phone": "+70907629878"}
0005434299415	A8326C	2052 345593	TATYANA TIMOFEEVA	{"email": "timofeeva.tatyana-011972@postgrespro.ru", "phone": "+70607356203"}
0005434299416	E4AA3D	4345 059571	ALEKSEY FROLOV	{"email": "alekseyfrolov-1974@postgrespro.ru", "phone": "+70654306172"}
0005434299417	4A769D	7570 828162	ALEKSANDR FEDOROV	{"phone": "+70905120763"}
0005434299418	4A769D	4404 485179	GENNADIY KUDRYASHOV	{"email": "kudryashov_gennadiy.061986@postgrespro.ru", "phone": "+70426500088"}
0005434299419	2A51E7	7889 895425	SAMIR EGOROV	{"email": "egorov-samir.1969@postgrespro.ru", "phone": "+70275613183"}
0005434299420	FE32BA	7384 250578	ALEKSANDR BARANOV	{"email": "baranova1978@postgrespro.ru", "phone": "+70813737722"}
0005434299421	3619D5	3715 049989	NATALYA NIKOLAEVA	{"phone": "+70260549722"}
0005434299422	3A2BE7	2486 658000	BOGDAN MAKSIMOV	{"email": "maksimovbogdan_31101981@postgrespro.ru", "phone": "+70568394251"}
0005434299423	EC0E45	4849 128835	ANDREY MOROZOV	{"phone": "+70310315003"}
0005434299424	F5038F	4605 393992	EKATERINA ABRAMOVA	{"email": "abramova_ekaterina_27051968@postgrespro.ru", "phone": "+70690932265"}
0005434299425	A6794C	9053 298416	ANNA POTAPOVA	{"email": "potapova_anna.15021982@postgrespro.ru", "phone": "+70781330732"}
0005434299426	897121	2206 041637	LYUBOV KOVALEVA	{"email": "kovalevalyubov.021967@postgrespro.ru", "phone": "+70580535824"}
0005434299427	897121	5844 463355	KARINA ILINA	{"phone": "+70558353949"}
0005434299428	589776	8095 742916	FANIL ISAEV	{"phone": "+70490201537"}
0005434299429	589776	1683 292444	NATALIYA KISELEVA	{"phone": "+70885064170"}
0005434299430	572120	4465 344892	VIKTORIYA IVANOVA	{"phone": "+70217927145"}
0005434299431	54E1D0	3353 473573	SVETLANA SOROKINA	{"email": "svetlanasorokina.121966@postgrespro.ru", "phone": "+70095040666"}
0005434299432	3239B4	5992 781889	ELENA BOGDANOVA	{"email": "bogdanova-elena19111977@postgrespro.ru", "phone": "+70406848486"}
0005434299433	EC5CE9	7494 361279	OLGA RODIONOVA	{"phone": "+70029229754"}
0005434299434	C8BC37	2390 173733	NATALYA YUDINA	{"email": "yudina-natalya-121979@postgrespro.ru", "phone": "+70098939396"}
0005434299435	AC4C3A	1745 126236	TAISIYA NOVIKOVA	{"phone": "+70698420550"}
0005434299436	9DBC49	5341 295069	VLADISLAV SIDOROV	{"phone": "+70993597747"}
0005434299437	9DBC49	1413 371340	NATALYA MELNIKOVA	{"email": "melnikovan-13111960@postgrespro.ru", "phone": "+70862320317"}
0005434299438	01BB3D	8290 965218	DMITRIY SMIRNOV	{"email": "d-smirnov_121963@postgrespro.ru", "phone": "+70370571665"}
0005434299439	C76DFE	5074 341849	VLADIMIR GUSEV	{"email": "v.gusev-17031975@postgrespro.ru", "phone": "+70206423232"}
0005434299440	A4A221	6765 974646	ALEKSANDR MOROZOV	{"email": "morozov-a-28061966@postgrespro.ru", "phone": "+70747594877"}
0005434299441	A4A221	0658 729661	SVETLANA FROLOVA	{"email": "sfrolova-1976@postgrespro.ru", "phone": "+70712179693"}
0005434299442	DEC393	0281 659361	NIKITA SCHERBAKOV	{"email": "scherbakov.n031975@postgrespro.ru", "phone": "+70558848059"}
0005434299443	DEC393	4043 971556	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay.1973@postgrespro.ru", "phone": "+70007154469"}
0005434299444	963CC5	6652 533767	ELENA VOLKOVA	{"phone": "+70504627290"}
0005434299445	1D53B7	9666 617232	ANDREY NAUMOV	{"email": "naumov_andrey_20121964@postgrespro.ru", "phone": "+70835106575"}
0005434299446	1D53B7	6120 721538	VALENTINA NIKIFOROVA	{"phone": "+70268497154"}
0005434299447	058115	8837 100093	VARVARA ANDREEVA	{"email": "varvara-andreeva.031975@postgrespro.ru", "phone": "+70332407731"}
0005434299448	AF7237	6166 549921	VLADIMIR MAKAROV	{"phone": "+70518831743"}
0005434299449	AF7237	7792 853009	GENNADIY NOVIKOV	{"email": "g.novikov-011974@postgrespro.ru", "phone": "+70104392872"}
0005434299450	AF7237	2936 759029	ALEKSANDR ZAYCEV	{"phone": "+70885410602"}
0005434299451	004C8E	3050 502695	VLADIMIR GERASIMOV	{"email": "vladimir_gerasimov1967@postgrespro.ru", "phone": "+70063174638"}
0005434299452	004C8E	8736 583546	MARINA IVANOVA	{"email": "ivanova.marina_091964@postgrespro.ru", "phone": "+70048709502"}
0005434299453	45627C	4163 245906	SERGEY POPOV	{"phone": "+70311797186"}
0005434299454	45627C	9671 857933	OLGA MIRONOVA	{"phone": "+70818335980"}
0005434299455	19237E	2192 321102	VALERIYA DENISOVA	{"phone": "+70473543817"}
0005434299456	FBFDF0	3494 943852	VASILIY STEPANOV	{"phone": "+70916205829"}
0005434299457	E54EC8	3573 450232	DAMIR OSIPOV	{"email": "d.osipov.111967@postgrespro.ru", "phone": "+70542138321"}
0005434299458	4B3778	6764 429683	LARISA MAKSIMOVA	{"phone": "+70763241392"}
0005434299459	07807F	7228 790997	IRINA VLASOVA	{"phone": "+70098860947"}
0005434299460	FE8770	3182 778088	ANATOLIY SMIRNOV	{"phone": "+70728613354"}
0005434299461	34F111	3753 024511	ELENA KUZNECOVA	{"phone": "+70425569037"}
0005434299462	F731A6	1329 376395	IREK TIKHONOV	{"email": "tikhonovirek.071979@postgrespro.ru", "phone": "+70447318561"}
0005434299463	05453B	9534 753809	IGOR SEMENOV	{"phone": "+70657628320"}
0005434299464	B5D47C	4479 646310	TAMARA MOISEEVA	{"email": "moiseeva-t111968@postgrespro.ru", "phone": "+70089947518"}
0005434299465	662561	2584 419620	ALEKSANDR KUZNECOV	{"email": "kuznecova_27031970@postgrespro.ru", "phone": "+70656856100"}
0005434299466	C15DE5	8723 033546	ALEKSEY GUSEV	{"email": "aleksey.gusev.10121968@postgrespro.ru", "phone": "+70631601806"}
0005434299467	239B5B	9167 493918	IVAN DENISOV	{"phone": "+70549580398"}
0005434299468	C01F0B	9396 197969	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila-22121970@postgrespro.ru", "phone": "+70321919710"}
0005434299469	04963B	1354 423182	VENIAMIN IVANOV	{"email": "veniamin-ivanov.101983@postgrespro.ru", "phone": "+70741721656"}
0005434299470	04963B	0806 270402	DANILA PETROV	{"phone": "+70334113415"}
0005434299471	887B87	3924 071157	VITALIY SOROKIN	{"email": "vitaliy.sorokin-15071974@postgrespro.ru", "phone": "+70344936198"}
0005434299472	273517	8963 218259	OLGA MELNIKOVA	{"email": "melnikova.o.21091976@postgrespro.ru", "phone": "+70668649197"}
0005434299473	FDF470	9936 418805	SVETLANA POPOVA	{"phone": "+70890765086"}
0005434299474	143AC5	2238 561755	ILDAR DMITRIEV	{"phone": "+70992515495"}
0005434299475	143AC5	3727 280655	SVETLANA KULIKOVA	{"email": "kulikova_s-071972@postgrespro.ru", "phone": "+70105052134"}
0005434299476	89BE11	7227 507715	SERGEY SMIRNOV	{"email": "s.smirnov07011981@postgrespro.ru", "phone": "+70108089622"}
0005434299477	89BE11	4604 904915	DENIS MATVEEV	{"phone": "+70226337812"}
0005434299478	06C6CE	5977 006074	SVETLANA KUZMINA	{"email": "kuzmina_svetlana.1980@postgrespro.ru", "phone": "+70327011817"}
0005434299479	1859A2	4834 341248	SERGEY ANTONOV	{"phone": "+70627281223"}
0005434299480	B77592	9742 457914	VIKTORIYA ALEKSANDROVA	{"email": "v-aleksandrova13091963@postgrespro.ru", "phone": "+70746700821"}
0005434299481	66806D	1574 000581	SVETLANA NIKITINA	{"email": "s.nikitina-1970@postgrespro.ru", "phone": "+70654458514"}
0005434299482	BD6806	8569 283024	ALEKSANDR FOMIN	{"email": "fomin-aleksandr.29111974@postgrespro.ru", "phone": "+70229366644"}
0005434299483	BD6806	1552 515392	KONSTANTIN MOROZOV	{"phone": "+70358070975"}
0005434299484	6624C8	4875 169159	IRINA MEDVEDEVA	{"email": "medvedeva_i_27091977@postgrespro.ru", "phone": "+70399153712"}
0005434299485	6624C8	0015 531256	ANASTASIYA KOMAROVA	{"email": "a-komarova-041978@postgrespro.ru", "phone": "+70845222186"}
0005434299486	6624C8	0200 508289	NIKOLAY RODIONOV	{"phone": "+70020546762"}
0005434299487	6624C8	5710 724877	NIKOLAY MOROZOV	{"email": "n.morozov1980@postgrespro.ru", "phone": "+70293932899"}
0005434299488	56DBE5	6159 137884	YURIY KOROLEV	{"phone": "+70397553832"}
0005434299489	56DBE5	8443 309278	VALENTINA STEPANOVA	{"email": "stepanova-valentina-17041960@postgrespro.ru", "phone": "+70686133033"}
0005434299490	C6A516	5755 002375	VLADIMIR GUSEV	{"phone": "+70007868858"}
0005434299491	C6A516	6961 888326	LYUBOV BELOVA	{"email": "belovalyubov_051979@postgrespro.ru", "phone": "+70420715156"}
0005434299492	AA4923	5740 736152	YULIYA VASILEVA	{"email": "yuliya_vasileva_031974@postgrespro.ru", "phone": "+70828388768"}
0005434299493	AC708B	5891 381627	SVETLANA YAKOVLEVA	{"email": "yakovleva_svetlana_19021982@postgrespro.ru", "phone": "+70681127784"}
0005434299494	BC1BC1	5265 367650	ANDREY EGOROV	{"phone": "+70731558072"}
0005434299495	55B3C0	8540 265657	GALINA BOGDANOVA	{"phone": "+70151280255"}
0005434299496	55B3C0	3098 472734	TATYANA ZAKHAROVA	{"phone": "+70949325977"}
0005434299497	1797E5	4723 389746	SOFIYA ZOTOVA	{"email": "zotova-s.25121975@postgrespro.ru", "phone": "+70375874396"}
0005434299498	1E43A0	4077 407519	ALEKSANDR SHEVCHENKO	{"phone": "+70281388480"}
0005434299499	1E43A0	1948 913919	LYUDMILA EGOROVA	{"phone": "+70698332311"}
0005434299500	9B07DE	5148 221983	NATALYA NIKITINA	{"phone": "+70340310269"}
0005434299501	D3E9AB	2272 432417	NATALYA NIKOLAEVA	{"phone": "+70311777256"}
0005434299502	D3E9AB	0901 720712	ANATOLIY MATVEEV	{"phone": "+70826003749"}
0005434299503	3A3C38	7656 456361	MATVEY ALEKSEEV	{"phone": "+70705781011"}
0005434299504	C835DD	0329 114467	VIKTORIYA PAVLOVA	{"email": "viktoriya.pavlova_091975@postgrespro.ru", "phone": "+70885242850"}
0005434299505	C835DD	2064 272152	ALEKSEY KUDRYASHOV	{"email": "kudryashov-a-11071967@postgrespro.ru", "phone": "+70600892201"}
0005434299506	6E9FD6	2880 404718	OLEG SEMENOV	{"email": "o-semenov.1966@postgrespro.ru", "phone": "+70372221508"}
0005434299507	F6E6E1	0995 819345	SERGEY NAUMOV	{"email": "s.naumov.31051977@postgrespro.ru", "phone": "+70614319479"}
0005434299508	C3D7EF	8069 689629	DMITRIY ROMANOV	{"email": "dmitriy_romanov_1969@postgrespro.ru", "phone": "+70409988550"}
0005434299509	C3D7EF	5694 032691	NIKITA VLASOV	{"phone": "+70938184649"}
0005434299510	C3D7EF	5170 930519	TATYANA ZHUKOVA	{"phone": "+70290630861"}
0005434299511	DAAC8C	9561 364379	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov_021962@postgrespro.ru", "phone": "+70090525133"}
0005434299512	5F33E7	7495 830506	ARTEM MELNIKOV	{"phone": "+70625136513"}
0005434299513	5F33E7	3857 908514	EVGENIY SCHERBAKOV	{"phone": "+70216357042"}
0005434299514	63E8E1	3267 357498	MAKSIM MIRONOV	{"phone": "+70829397937"}
0005434299515	FDB28E	7818 085480	YURIY ABRAMOV	{"phone": "+70331023082"}
0005434299516	FDB28E	9029 906686	VASILIY SOKOLOV	{"phone": "+70908162927"}
0005434299517	0D9AD1	0926 623417	VIKTORIYA SOKOLOVA	{"email": "sokolova_v07111975@postgrespro.ru", "phone": "+70596452001"}
0005434299518	DDAC47	7723 696389	ALBERT BORISOV	{"phone": "+70696758091"}
0005434299519	89E18B	6436 379770	VLADISLAV DENISOV	{"email": "denisov.vladislav_091968@postgrespro.ru", "phone": "+70784149780"}
0005434299520	89E18B	0281 118291	IGOR SEMENOV	{"email": "semenov-i021975@postgrespro.ru", "phone": "+70512579989"}
0005434299521	70710A	7832 030832	DENIS KONOVALOV	{"phone": "+70373041976"}
0005434299522	70710A	4389 828903	MARINA POPOVA	{"email": "popova.marina1964@postgrespro.ru", "phone": "+70570959984"}
0005434299523	03FBA8	6395 545738	ARTEM DAVYDOV	{"email": "davydov_artem_061967@postgrespro.ru", "phone": "+70288072255"}
0005434299524	E5C3E5	5166 397925	OLGA ABRAMOVA	{"phone": "+70341925174"}
0005434299525	A97C97	0713 224104	RAISA KOVALEVA	{"email": "raisakovaleva_051972@postgrespro.ru", "phone": "+70893782533"}
0005434299526	A97C97	6159 392947	RAISA SMIRNOVA	{"email": "smirnova-raisa_1977@postgrespro.ru", "phone": "+70066912703"}
0005434299527	D60A2E	9676 515749	DMITRIY NIKOLAEV	{"email": "nikolaev-dmitriy.1983@postgrespro.ru", "phone": "+70927053302"}
0005434299528	D60A2E	1904 392565	SERGEY EGOROV	{"email": "sergey-egorov1969@postgrespro.ru", "phone": "+70354575552"}
0005434299639	E4A13B	8556 353911	MAKSIM SEMENOV	{"phone": "+70372721134"}
0005434299529	4D1254	5083 800962	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr.20101977@postgrespro.ru", "phone": "+70703915198"}
0005434299530	5315EE	7861 542800	NINA STEPANOVA	{"email": "stepanova_n-061961@postgrespro.ru", "phone": "+70216873840"}
0005434299531	A6623E	1400 764720	KARIM FILIPPOV	{"phone": "+70925103452"}
0005434299532	A6623E	2906 499829	NATALYA FROLOVA	{"email": "nfrolova_29031971@postgrespro.ru", "phone": "+70119695594"}
0005434299533	FA1581	7182 935861	POLINA MOISEEVA	{"email": "polina_moiseeva1975@postgrespro.ru", "phone": "+70790693699"}
0005434299534	2D3C41	6593 265200	ILYA KUZNECOV	{"email": "i_kuznecov_101972@postgrespro.ru", "phone": "+70141508701"}
0005434299535	1BF6F8	0635 561637	SERGEY ZHURAVLEV	{"email": "s-zhuravlev011973@postgrespro.ru", "phone": "+70725480308"}
0005434299536	CA8A3D	0493 557016	ALEKSANDR VLASOV	{"phone": "+70908809838"}
0005434299537	DEE12F	3304 399394	NADEZHDA ZHUKOVA	{"phone": "+70839729971"}
0005434299538	CE5B1C	6167 811714	PETR KOZLOV	{"email": "petrkozlov1961@postgrespro.ru", "phone": "+70336461521"}
0005434299539	B3FB1D	3613 498734	ALEKSEY AFANASEV	{"phone": "+70383261656"}
0005434299540	B3FB1D	8759 258806	ALEKSANDR ANDREEV	{"email": "a-andreev-051969@postgrespro.ru", "phone": "+70453248701"}
0005434299541	C38CAD	4260 358475	PAVEL RODIONOV	{"email": "prodionov.011969@postgrespro.ru", "phone": "+70996730236"}
0005434299542	D98FC3	2063 862615	LILIYA ALEKSEEVA	{"phone": "+70747782551"}
0005434299543	A0BCCB	2526 064888	ALEKSANDR PETROV	{"phone": "+70283155465"}
0005434299544	502E99	4071 953077	NATALYA GORBUNOVA	{"phone": "+70449558511"}
0005434299545	502E99	0955 025219	GALINA GAVRILOVA	{"email": "galina_gavrilova-121968@postgrespro.ru", "phone": "+70813661303"}
0005434299546	503572	4956 795699	DMITRIY DENISOV	{"phone": "+70529905700"}
0005434299547	FB194F	3908 790852	IGOR SAVELEV	{"email": "savelev_i121964@postgrespro.ru", "phone": "+70586758425"}
0005434299548	FB194F	3997 804019	ANASTASIYA KALININA	{"phone": "+70887803487"}
0005434299549	527E3F	3628 903199	MARINA FILATOVA	{"email": "filatova-m_1985@postgrespro.ru", "phone": "+70172451526"}
0005434299550	527E3F	4113 795275	NIKITA BELOV	{"email": "belov-n_1970@postgrespro.ru", "phone": "+70521011688"}
0005434299551	3ACB4E	2497 292604	DANIIL KUDRYASHOV	{"email": "kudryashovdaniil31081968@postgrespro.ru", "phone": "+70922819282"}
0005434299552	CA5573	9142 322098	OLGA NIKOLAEVA	{"email": "o_nikolaeva-14061964@postgrespro.ru", "phone": "+70913537438"}
0005434299553	CA5573	7676 536549	OLESYA DAVYDOVA	{"phone": "+70280435651"}
0005434299554	9C12B4	0226 433408	GALINA KAZAKOVA	{"phone": "+70985701916"}
0005434299555	1A1759	4307 731547	VLADIMIR BORISOV	{"email": "borisov-vladimir.101968@postgrespro.ru", "phone": "+70901604335"}
0005434299556	1A1759	6984 628806	EKATERINA KUZMINA	{"email": "kuzmina-e121970@postgrespro.ru", "phone": "+70059149330"}
0005434299557	301886	6794 342863	YURIY ALEKSEEV	{"phone": "+70819580252"}
0005434299558	61C3A1	8900 112614	SOFYA ANDREEVA	{"email": "s_andreeva.1979@postgrespro.ru", "phone": "+70080296193"}
0005434299559	7D1E4C	6221 101705	LYUDMILA ROMANOVA	{"email": "l-romanova.17101974@postgrespro.ru", "phone": "+70483016787"}
0005434299560	842EDA	1368 963758	MARIYA ZOTOVA	{"phone": "+70076611813"}
0005434299561	842EDA	8172 612030	VASILIY GUSEV	{"phone": "+70912926234"}
0005434299562	E5A363	2309 049001	ALEKSANDR DMITRIEV	{"phone": "+70796312314"}
0005434299563	AB9B0B	4020 775122	LYUBOV MAKSIMOVA	{"phone": "+70004901679"}
0005434299564	AB9B0B	0136 789321	ANDREY VOLKOV	{"email": "volkov_a-22071970@postgrespro.ru", "phone": "+70974901689"}
0005434299565	6BEB5B	7620 175875	SVETLANA MATVEEVA	{"phone": "+70474511470"}
0005434299566	6BEB5B	8455 950175	VIKTOR KUZNECOV	{"email": "viktor_kuznecov011974@postgrespro.ru", "phone": "+70612888711"}
0005434299567	FB8E8D	3529 455961	SERGEY PAVLOV	{"email": "pavlov.sergey-1977@postgrespro.ru", "phone": "+70401371245"}
0005434299568	FB8E8D	6956 042421	OLGA TIKHONOVA	{"email": "olgatikhonova_1964@postgrespro.ru", "phone": "+70194542133"}
0005434299569	FB8E8D	9813 227636	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova-031970@postgrespro.ru", "phone": "+70879758905"}
0005434299570	2FCC10	7688 332015	VALENTINA GAVRILOVA	{"phone": "+70639359937"}
0005434299571	E75112	3816 526509	STANISLAV SOROKIN	{"email": "sorokin-s23071976@postgrespro.ru", "phone": "+70559407049"}
0005434299572	E75112	6869 480589	VALERIY MOISEEV	{"email": "valeriy.moiseev081971@postgrespro.ru", "phone": "+70546936735"}
0005434299573	34786F	1172 466695	SERGEY MATVEEV	{"phone": "+70084240991"}
0005434299574	6F6756	5851 776713	ANATOLIY SOLOVEV	{"email": "anatoliy_solovev16091968@postgrespro.ru", "phone": "+70084494996"}
0005434299575	D03790	5371 784379	GALINA KAZAKOVA	{"email": "galina-kazakova.06121969@postgrespro.ru", "phone": "+70310651845"}
0005434299576	D03790	9391 422812	NIKITA KOROLEV	{"email": "korolev_nikita.121973@postgrespro.ru", "phone": "+70287854853"}
0005434299577	B6258F	5270 941887	VASILIY BELOV	{"phone": "+70405806677"}
0005434299578	B6258F	9730 500203	NINA MAKAROVA	{"email": "nina.makarova-011973@postgrespro.ru", "phone": "+70666273980"}
0005434299579	632D2D	1267 514098	SERGEY KRASNOV	{"email": "krasnovsergey.22111964@postgrespro.ru", "phone": "+70528707761"}
0005434299580	632D2D	7534 245749	VERA FILATOVA	{"phone": "+70279682053"}
0005434299581	632D2D	7085 251938	RAISA FILIPPOVA	{"email": "filippova-raisa_101971@postgrespro.ru", "phone": "+70466588916"}
0005434299582	0FEE0D	5040 453896	ANTONINA ZAKHAROVA	{"email": "zakharovaantonina.061980@postgrespro.ru", "phone": "+70072977197"}
0005434299583	35A768	8181 517808	VERA GRISHINA	{"email": "vera.grishina-08111972@postgrespro.ru", "phone": "+70807584360"}
0005434299584	35A768	8296 309845	DARYA KONOVALOVA	{"email": "konovalovad_31101957@postgrespro.ru", "phone": "+70707532276"}
0005434299585	863361	2091 982726	ELENA ROMANOVA	{"email": "eromanova.07021978@postgrespro.ru", "phone": "+70977092331"}
0005434299586	0C4ED1	3321 204565	ANNA KONDRATEVA	{"phone": "+70823671633"}
0005434299587	905161	3188 303628	OLEG TIKHONOV	{"phone": "+70590254783"}
0005434299588	56DD19	9499 210236	GEORGIY MOISEEV	{"phone": "+70399368184"}
0005434299589	56DD19	3039 926761	PAVEL RODIONOV	{"phone": "+70006195976"}
0005434299590	5C48CB	7383 630375	ALEKSANDR VOLKOV	{"email": "avolkov_22081963@postgrespro.ru", "phone": "+70315732385"}
0005434299591	46B034	1711 486829	GALINA MOISEEVA	{"phone": "+70509883571"}
0005434299592	81C8AA	1441 361656	OLESYA KUZNECOVA	{"email": "o-kuznecova.31121967@postgrespro.ru", "phone": "+70410449653"}
0005434299593	81C8AA	1919 243162	SVETLANA NIKOLAEVA	{"email": "nikolaeva.svetlana.1970@postgrespro.ru", "phone": "+70014030036"}
0005434299594	BC0C7A	6180 259899	YULIYA POPOVA	{"phone": "+70267748623"}
0005434299595	BB0886	4236 446603	TATYANA KONDRATEVA	{"email": "tatyana-kondrateva.19061962@postgrespro.ru", "phone": "+70259640946"}
0005434299596	A3DE1C	8352 840181	EKATERINA MEDVEDEVA	{"phone": "+70637294144"}
0005434299597	A3DE1C	6631 692069	VALERIY MIRONOV	{"email": "mironov-valeriy-1965@postgrespro.ru", "phone": "+70252403125"}
0005434299598	0B86EE	1206 117457	MARINA IVANOVA	{"email": "ivanova_marina18071970@postgrespro.ru", "phone": "+70655198590"}
0005434299599	687425	5975 716520	ALEKSEY KAZAKOV	{"phone": "+70059912322"}
0005434299600	687425	0517 261351	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr.1972@postgrespro.ru", "phone": "+70023141419"}
0005434299601	F7A4EC	7805 057344	ALEKSANDR EGOROV	{"phone": "+70367676831"}
0005434299602	26AE77	2275 807824	VALENTINA EGOROVA	{"email": "egorova.v-08081970@postgrespro.ru", "phone": "+70175266522"}
0005434299603	52C89D	5292 814867	MARIYA IVANOVA	{"phone": "+70037567250"}
0005434299604	733D42	3495 437635	ZOYA SOLOVEVA	{"email": "soloveva.z-111987@postgrespro.ru", "phone": "+70942401286"}
0005434299605	5B3CF9	7802 721168	MAKSIM SAVELEV	{"phone": "+70743526862"}
0005434299606	5B3CF9	6743 624141	VIKTORIYA CHERNOVA	{"email": "viktoriya-chernova_121972@postgrespro.ru", "phone": "+70386490096"}
0005434299607	41A37B	0225 113317	GALINA STEPANOVA	{"email": "gstepanova041966@postgrespro.ru", "phone": "+70333690086"}
0005434299608	71BB82	5986 130328	ANDREY FEDOROV	{"email": "fedorovandrey.18081967@postgrespro.ru", "phone": "+70105015886"}
0005434299609	0C45B7	9889 859398	VERA NOVIKOVA	{"phone": "+70836248974"}
0005434299610	7E4FF9	8873 756234	ANASTASIYA MAKAROVA	{"email": "makarovaanastasiya051977@postgrespro.ru", "phone": "+70243323918"}
0005434299611	7E4FF9	1620 773612	ANDREY KOROLEV	{"email": "korolevandrey_101978@postgrespro.ru", "phone": "+70607504270"}
0005434299612	0103BE	7978 521729	GALINA LOGINOVA	{"email": "gloginova1970@postgrespro.ru", "phone": "+70605147523"}
0005434299613	0E48CA	7846 144591	ZINAIDA KOMAROVA	{"email": "komarova.z_16121965@postgrespro.ru", "phone": "+70103241553"}
0005434299614	C62178	7479 850332	TATYANA ZHURAVLEVA	{"email": "zhuravleva.t1969@postgrespro.ru", "phone": "+70055995343"}
0005434299615	C62178	3977 346906	VLADISLAV KARPOV	{"email": "vladislav_karpov-1953@postgrespro.ru", "phone": "+70562738164"}
0005434299616	800FEB	7053 193910	NINA ZOTOVA	{"email": "zotovan.21091968@postgrespro.ru", "phone": "+70445104247"}
0005434299617	800FEB	1553 265042	ANDREY PETROV	{"email": "andrey_petrov-1965@postgrespro.ru", "phone": "+70861258184"}
0005434299618	4F2B8A	6434 445934	ALBINA NIKITINA	{"email": "albina.nikitina-081981@postgrespro.ru", "phone": "+70588964317"}
0005434299619	F12B96	2207 835309	ANNA ILINA	{"email": "ilina_a1976@postgrespro.ru", "phone": "+70621079733"}
0005434299620	464615	9603 490094	SOFYA ARKHIPOVA	{"phone": "+70846715900"}
0005434299621	464615	5219 745761	ARTEM FILIPPOV	{"phone": "+70596233931"}
0005434299622	F10C20	1949 550328	KSENIYA MELNIKOVA	{"email": "kseniya_melnikova1968@postgrespro.ru", "phone": "+70853403594"}
0005434299623	3B9D97	2052 410245	ALLA KUZNECOVA	{"email": "a-kuznecova_1968@postgrespro.ru", "phone": "+70076687454"}
0005434299624	4DB8C9	7119 285559	SERGEY IVANOV	{"phone": "+70980498923"}
0005434299625	4DB8C9	0224 681988	OLEG KAZAKOV	{"email": "kazakov-oleg_01061977@postgrespro.ru", "phone": "+70474153865"}
0005434299626	BBC36A	6997 947354	VLADIMIR KONOVALOV	{"email": "konovalov.vladimir_041964@postgrespro.ru", "phone": "+70174300850"}
0005434299627	996D31	4378 851706	NATALIYA KONDRATEVA	{"phone": "+70826364605"}
0005434299628	367508	1226 074571	KAMIL DENISOV	{"phone": "+70326850886"}
0005434299629	C7519C	1289 511152	GRIGORIY GERASIMOV	{"phone": "+70177721483"}
0005434299630	C7519C	9509 315622	SERGEY KULIKOV	{"email": "sergey_kulikov.101971@postgrespro.ru", "phone": "+70876486276"}
0005434299631	50EE0F	7514 614222	VIKTORIYA ANTONOVA	{"email": "viktoriya-antonova_081972@postgrespro.ru", "phone": "+70735893977"}
0005434299632	A4AC1B	8917 716031	NINA SOLOVEVA	{"email": "nina.soloveva1982@postgrespro.ru", "phone": "+70763508304"}
0005434299633	A4AC1B	9122 758971	KIRILL ILIN	{"email": "ilinkirill_1967@postgrespro.ru", "phone": "+70008663188"}
0005434299634	ECEDE6	4708 349025	KAMILLA POLYAKOVA	{"email": "kamillapolyakova_081971@postgrespro.ru", "phone": "+70457763439"}
0005434299635	698D5A	2266 126210	ARTUR KAZAKOV	{"email": "kazakov_a-041977@postgrespro.ru", "phone": "+70210778788"}
0005434299636	DF8CBD	3207 977988	LYUDMILA DENISOVA	{"phone": "+70500085449"}
0005434299637	5E38F2	7270 764265	VERA ANTONOVA	{"email": "antonova-v1969@postgrespro.ru", "phone": "+70878528433"}
0005434299638	E4A13B	4496 281989	EVGENIY KUZNECOV	{"email": "e_kuznecov-1958@postgrespro.ru", "phone": "+70270711912"}
0005434299640	72DB22	8290 218122	EVGENIYA ISAEVA	{"email": "isaevaevgeniya.13101976@postgrespro.ru", "phone": "+70491847064"}
0005434299641	72DB22	2327 762796	YULIYA MARTYNOVA	{"email": "martynova.y031964@postgrespro.ru", "phone": "+70158758080"}
0005434299642	72DB22	5952 113508	LARISA KONOVALOVA	{"email": "larisa-konovalova.07011978@postgrespro.ru", "phone": "+70400535145"}
0005434299643	CC9B8D	8184 817947	EGOR ILIN	{"email": "ilin.e_1976@postgrespro.ru", "phone": "+70049770111"}
0005434299644	CC9B8D	7031 613579	VLADIMIR FROLOV	{"email": "frolov.v_101971@postgrespro.ru", "phone": "+70916185248"}
0005434299645	D9C9E3	4183 595979	SVETLANA MIKHAYLOVA	{"email": "svetlana-mikhaylova-011976@postgrespro.ru", "phone": "+70897205514"}
0005434299646	F7B72C	8635 612221	ELENA RODIONOVA	{"email": "rodionova-e-1979@postgrespro.ru", "phone": "+70726354153"}
0005434299647	A4D3F0	1617 331579	YULIYA MAKSIMOVA	{"email": "maksimovay_1982@postgrespro.ru", "phone": "+70912759856"}
0005434299648	5F8D20	3218 323397	VLADIMIR MOROZOV	{"email": "morozov.vladimir02121973@postgrespro.ru", "phone": "+70536476058"}
0005434299649	5F8D20	9636 091347	RAISA KAZAKOVA	{"email": "raisa_kazakova-21121968@postgrespro.ru", "phone": "+70429369618"}
0005434299650	8DA175	1119 807346	SERGEY BONDARENKO	{"email": "s_bondarenko.041968@postgrespro.ru", "phone": "+70124070646"}
0005434299651	8DA175	8288 887774	EVGENIY ANDREEV	{"email": "e.andreev_1969@postgrespro.ru", "phone": "+70745020541"}
0005434299652	8DA175	5566 353858	GALINA NAUMOVA	{"phone": "+70247392685"}
0005434299653	26F62D	4886 731405	NADEZHDA NESTEROVA	{"email": "nesterova-nadezhda121970@postgrespro.ru", "phone": "+70925463013"}
0005434299654	0AB54F	1206 073267	KIRILL KOZLOV	{"phone": "+70948784141"}
0005434299655	8CE589	8537 083168	OLGA STEPANOVA	{"email": "stepanova-olga06091972@postgrespro.ru", "phone": "+70786831709"}
0005434299656	8CE589	4588 281028	VALENTINA TARASOVA	{"email": "tarasova.v_05011986@postgrespro.ru", "phone": "+70405273251"}
0005434299657	8CE589	3996 877049	IVAN MIRONOV	{"email": "mironov-ivan-01111972@postgrespro.ru", "phone": "+70875389901"}
0005434299658	904802	2180 379140	ELENA KUZNECOVA	{"phone": "+70733771503"}
0005434299659	0EA3E3	6677 009890	ALEKSANDRA KOZLOVA	{"phone": "+70476426368"}
0005434299660	0EA3E3	4093 084980	PETR SHEVCHENKO	{"phone": "+70629829036"}
0005434299661	218ED5	3990 595486	ELENA KONDRATEVA	{"phone": "+70680989508"}
0005434299662	1188BA	2671 558322	VALENTINA NOVIKOVA	{"phone": "+70892099441"}
0005434299663	564FAF	2426 978463	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrovaa-1972@postgrespro.ru", "phone": "+70568924969"}
0005434299664	7C0931	5762 091399	ALEKSEY AFANASEV	{"email": "afanasev_aleksey_1969@postgrespro.ru", "phone": "+70993817825"}
0005434299665	477DC5	9396 145839	ALEKSANDR MOISEEV	{"email": "aleksandr_moiseev.021972@postgrespro.ru", "phone": "+70905453632"}
0005434299666	CD726B	5366 151145	ALENA TIMOFEEVA	{"phone": "+70571462676"}
0005434299667	E9FEDF	5972 403399	TATYANA NIKOLAEVA	{"phone": "+70755388891"}
0005434299668	E9FEDF	2316 030461	MARIYA ILINA	{"phone": "+70585011598"}
0005434299669	E9FEDF	5773 845738	VERA KRASNOVA	{"phone": "+70308790640"}
0005434299670	CBD263	1980 545589	RAISA KOZLOVA	{"phone": "+70037992786"}
0005434299671	C35AFA	2209 213455	TATYANA MARTYNOVA	{"phone": "+70521887273"}
0005434299672	955586	5223 355637	ELENA NIKITINA	{"email": "elena_nikitina_06081980@postgrespro.ru", "phone": "+70325090548"}
0005434299673	55FF6F	8131 889783	KSENIYA PAVLOVA	{"phone": "+70692104822"}
0005434299674	55FF6F	5194 271492	EVGENIY IVANOV	{"phone": "+70910521396"}
0005434299675	A1EDF4	6880 239741	MATVEY KUZNECOV	{"phone": "+70886099243"}
0005434299676	442D81	9107 402930	DIANA PETROVA	{"phone": "+70298206401"}
0005434299677	224E7F	1556 841831	DMITRIY NIKITIN	{"email": "nikitin-d071976@postgrespro.ru", "phone": "+70839857198"}
0005434299678	224E7F	2256 251518	TATYANA KUZNECOVA	{"phone": "+70438534085"}
0005434299679	C6A6FE	2099 025273	NIKOLAY BONDARENKO	{"email": "n_bondarenko_02121974@postgrespro.ru", "phone": "+70462003006"}
0005434299680	D3946F	5532 319019	LILIYA KONDRATEVA	{"email": "l.kondrateva_25051977@postgrespro.ru", "phone": "+70969738353"}
0005434299681	D3946F	1842 355374	LYUBOV IVANOVA	{"email": "ivanovalyubov-121965@postgrespro.ru", "phone": "+70148190364"}
0005434299682	D3946F	1208 932085	MARINA TIKHONOVA	{"email": "tikhonova.marina15051986@postgrespro.ru", "phone": "+70930948278"}
0005434299683	DE438C	4136 787328	IRINA NOVIKOVA	{"phone": "+70633510793"}
0005434299684	AA6978	4240 687814	PETR SOROKIN	{"email": "sorokin-p_041972@postgrespro.ru", "phone": "+70505550517"}
0005434299685	1E74BB	0427 114902	DMITRIY DMITRIEV	{"email": "dmitriev.dmitriy_021982@postgrespro.ru", "phone": "+70490722261"}
0005434299686	1E74BB	9869 831388	KLAVDIYA GERASIMOVA	{"email": "gerasimova-klavdiya031961@postgrespro.ru", "phone": "+70955547261"}
0005434299687	B1444D	3502 433941	DMITRIY GUSEV	{"email": "d.gusev01061976@postgrespro.ru", "phone": "+70391074181"}
0005434299688	66D6A7	1815 253471	EVDOKIYA SAVELEVA	{"phone": "+70860527122"}
0005434299689	D6BF9A	7824 073575	EKATERINA GUSEVA	{"phone": "+70967572077"}
0005434299690	D6BF9A	0454 898364	NAILYA YUDINA	{"phone": "+70710187534"}
0005434299691	794071	3296 562037	VLADIMIR ALEKSANDROV	{"phone": "+70909741526"}
0005434299692	3AE951	3129 719999	VLADIMIR VOROBEV	{"email": "vorobev_v31051981@postgrespro.ru", "phone": "+70615277312"}
0005434299693	BD6E5B	9360 787110	ANDREY SHEVCHENKO	{"phone": "+70714436284"}
0005434299694	D8BCB6	3136 141052	SERGEY SOLOVEV	{"email": "s-solovev.121974@postgrespro.ru", "phone": "+70282243188"}
0005434299695	D8BCB6	8315 462373	SERAFIMA KOVALEVA	{"phone": "+70968367307"}
0005434299696	F10453	0771 129903	ALEKSANDR IVANOV	{"phone": "+70228212774"}
0005434299697	443AE1	3102 382854	IVAN NOVIKOV	{"email": "ivan_novikov-1975@postgrespro.ru", "phone": "+70889842748"}
0005434299698	EB8971	7396 792708	TAMARA MELNIKOVA	{"phone": "+70912623550"}
0005434299699	EB8971	5585 602135	VLADIMIR SHEVCHENKO	{"email": "vladimirshevchenko.1969@postgrespro.ru", "phone": "+70688947590"}
0005434299700	ADB5A4	4558 639576	EKATERINA KOROLEVA	{"email": "koroleva-e-121990@postgrespro.ru", "phone": "+70149415120"}
0005434299701	BB06D9	9477 459708	EKATERINA SAVELEVA	{"email": "savelevaekaterina031963@postgrespro.ru", "phone": "+70130667472"}
0005434299702	2BE234	5890 586645	ELIZAVETA KUZNECOVA	{"phone": "+70356246995"}
0005434299703	8E6B2B	4017 109401	EKATERINA MOROZOVA	{"phone": "+70878659870"}
0005434299704	5AC7E0	4728 230422	SVETLANA BORISOVA	{"phone": "+70621304846"}
0005434299705	5AC7E0	8408 775520	OLGA LEBEDEVA	{"email": "lebedeva-o_29051982@postgrespro.ru", "phone": "+70181774612"}
0005434299706	796366	1193 105880	TATYANA VASILEVA	{"email": "vasilevatatyana121969@postgrespro.ru", "phone": "+70667335316"}
0005434299707	E8A8BF	6953 063493	LARISA YAKOVLEVA	{"email": "yakovleva-larisa_1962@postgrespro.ru", "phone": "+70224189372"}
0005434299708	E8A8BF	6054 209872	OLGA VASILEVA	{"phone": "+70094991034"}
0005434299709	20277A	0252 299506	MARIYA AFANASEVA	{"email": "afanaseva_mariya-1980@postgrespro.ru", "phone": "+70295887427"}
0005434299710	CF91FA	8853 798782	LYUDMILA IVANOVA	{"phone": "+70580964650"}
0005434299711	180D36	9901 458227	GALIYA KULIKOVA	{"email": "kulikova.galiya-22111983@postgrespro.ru", "phone": "+70133684625"}
0005434299712	7B2C34	6280 962946	ALEVTINA OVCHINNIKOVA	{"email": "a_ovchinnikova-081977@postgrespro.ru", "phone": "+70962056404"}
0005434299713	352C6D	4879 355479	ANDREY BONDARENKO	{"email": "bondarenko-andrey_021970@postgrespro.ru", "phone": "+70367086223"}
0005434299714	768189	8678 677786	ALEKSANDR BORISOV	{"email": "borisov.aleksandr-13071977@postgrespro.ru", "phone": "+70049058125"}
0005434299715	170809	0110 749620	VERA GERASIMOVA	{"email": "vera-gerasimova-1959@postgrespro.ru", "phone": "+70266562670"}
0005434299716	170809	9392 037778	TATYANA DANILOVA	{"email": "t.danilova021969@postgrespro.ru", "phone": "+70793854062"}
0005434299717	08CA41	1670 082205	MARIYA DANILOVA	{"email": "m.danilova-1973@postgrespro.ru", "phone": "+70254952707"}
0005434299718	6CE389	3772 550199	EKATERINA IVANOVA	{"email": "ekaterina-ivanova.1968@postgrespro.ru", "phone": "+70612965890"}
0005434299719	78D1EB	3431 962128	ARTEM VASILEV	{"phone": "+70794924330"}
0005434299720	0363F7	1219 585952	TATYANA POTAPOVA	{"email": "potapova-tatyana_31121969@postgrespro.ru", "phone": "+70193279021"}
0005434299721	0363F7	9623 815563	ALEKSANDR VOLKOV	{"phone": "+70964983268"}
0005434299722	0363F7	9617 778727	SERAFIMA EFREMOVA	{"email": "serafima.efremova.01061966@postgrespro.ru", "phone": "+70661915381"}
0005434299723	C490CE	2794 532826	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov-1971@postgrespro.ru", "phone": "+70814778717"}
0005434299724	6DC845	8934 030199	EKATERINA POTAPOVA	{"phone": "+70644430380"}
0005434299725	16A822	0953 826992	SERGEY MATVEEV	{"phone": "+70103143674"}
0005434299726	821ADE	0753 480553	ALEKSANDR ZHUKOV	{"email": "zhukov-a_081966@postgrespro.ru", "phone": "+70168756114"}
0005434299727	A11779	6221 468261	EVGENIY FEDOROV	{"email": "e-fedorov_061969@postgrespro.ru", "phone": "+70613209597"}
0005434299728	A11779	3181 695910	ARTEM DENISOV	{"phone": "+70624035604"}
0005434299729	E7A04C	7242 155721	ALEKSANDR VLASOV	{"email": "vlasov.a_041968@postgrespro.ru", "phone": "+70275395335"}
0005434299730	E7A04C	1237 729129	ALEKSANDR BORISOV	{"phone": "+70215361944"}
0005434299731	966B4B	2372 902424	ELENA YUDINA	{"phone": "+70062720037"}
0005434299732	966B4B	1022 171330	BORIS FILIPPOV	{"email": "boris_filippov1965@postgrespro.ru", "phone": "+70784401913"}
0005434299733	6495A1	4495 139676	TATYANA ANISIMOVA	{"phone": "+70965125350"}
0005434299734	6495A1	2835 564905	ALEKSEY RODIONOV	{"phone": "+70841069775"}
0005434299735	A4A638	2085 215759	ALEKSEY SIDOROV	{"phone": "+70040587188"}
0005434299736	AF89AF	4970 131291	GLEB IVANOV	{"email": "ivanov-gleb-121979@postgrespro.ru", "phone": "+70680042767"}
0005434299737	2A6C94	0730 844353	NIKOLAY KAZAKOV	{"phone": "+70323175663"}
0005434299738	2A6C94	9543 605764	OLEG POPOV	{"phone": "+70629248723"}
0005434299739	B8F5C6	5598 723206	DANIIL IVANOV	{"email": "d-ivanov.08031964@postgrespro.ru", "phone": "+70364491418"}
0005434299740	7EBCC5	5369 077418	LYUDMILA LAZAREVA	{"phone": "+70161285058"}
0005434299741	7EBCC5	0928 455145	ALEVTINA IVANOVA	{"phone": "+70458063288"}
0005434299742	19C0F1	9302 943574	MIKHAIL IVANOV	{"phone": "+70080788564"}
0005434299743	5109C7	3227 588837	NATALYA PAVLOVA	{"email": "natalya_pavlova041977@postgrespro.ru", "phone": "+70555455607"}
0005434299744	78EA66	3449 735711	OLGA ALEKSANDROVA	{"email": "olgaaleksandrova-08061978@postgrespro.ru", "phone": "+70658146302"}
0005434299745	D5D33B	4189 441297	VALENTINA VASILEVA	{"email": "v.vasileva.091976@postgrespro.ru", "phone": "+70112943046"}
0005434299746	520CFD	1382 005015	LYUBOV AFANASEVA	{"phone": "+70660052243"}
0005434299747	0F279D	7814 735875	SERGEY MOROZOV	{"email": "sergey-morozov1978@postgrespro.ru", "phone": "+70470850394"}
0005434299748	A273B4	5672 556132	NINA OVCHINNIKOVA	{"email": "ovchinnikova.n_1973@postgrespro.ru", "phone": "+70155963216"}
0005434299749	A273B4	7636 728583	NINA MIKHAYLOVA	{"phone": "+70653039516"}
0005434299807	437D21	9635 876999	NATALYA BARANOVA	{"phone": "+70893362774"}
0005434299750	92F482	7628 442111	VITALIY SAVELEV	{"email": "savelevv-29101979@postgrespro.ru", "phone": "+70888216943"}
0005434299751	6D0AEE	1601 612935	GALINA ABRAMOVA	{"phone": "+70613561785"}
0005434299752	6D0AEE	1187 437221	LYUDMILA IVANOVA	{"phone": "+70703344013"}
0005434299753	920354	4236 864154	VERONIKA ANDREEVA	{"phone": "+70147310140"}
0005434299754	888CC7	2700 504841	SVETLANA POPOVA	{"phone": "+70343103200"}
0005434299755	0E8B4B	3318 777357	ROMAN PETROV	{"phone": "+70213061356"}
0005434299756	C07554	1708 842688	IVAN KRASNOV	{"email": "krasnov.ivan.02031964@postgrespro.ru", "phone": "+70428440356"}
0005434299757	C07554	8871 896970	FEDOR MOROZOV	{"phone": "+70012692388"}
0005434299758	30C2D8	0507 080862	RUSLAN PETROV	{"phone": "+70387687784"}
0005434299759	42C984	2043 025030	ANNA KOROLEVA	{"phone": "+70189703886"}
0005434299760	42C984	5274 541298	DANIIL KONOVALOV	{"email": "daniil.konovalov.041969@postgrespro.ru", "phone": "+70651165040"}
0005434299761	097220	9563 072645	YULIYA GORBUNOVA	{"phone": "+70724279531"}
0005434299762	C012A3	7807 071527	DENIS SMIRNOV	{"email": "d.smirnov-051982@postgrespro.ru", "phone": "+70812055505"}
0005434299763	49B754	7611 557464	NINA KISELEVA	{"email": "n-kiseleva_121968@postgrespro.ru", "phone": "+70126708552"}
0005434299764	D89DBA	3157 758940	IVAN VOROBEV	{"phone": "+70891997001"}
0005434299765	D89DBA	2345 958269	ILDAR RODIONOV	{"phone": "+70284114033"}
0005434299766	7B84CB	5544 589973	LIDIYA NIKOLAEVA	{"email": "lidiya.nikolaeva.061971@postgrespro.ru", "phone": "+70157463294"}
0005434299767	E8DCB8	3241 389796	DARYA ISAEVA	{"email": "d_isaeva021963@postgrespro.ru", "phone": "+70561421976"}
0005434299768	11281F	5080 353005	KIRILL SEMENOV	{"phone": "+70792918980"}
0005434299769	5DAEE5	6433 047205	OLGA VOROBEVA	{"phone": "+70769306486"}
0005434299770	5DAEE5	4646 195432	ALEKSANDR EGOROV	{"phone": "+70555713276"}
0005434299771	A38BEA	3320 649016	IRINA IVANOVA	{"phone": "+70761901853"}
0005434299772	07E683	1617 453956	NATALIYA ZHURAVLEVA	{"phone": "+70819273717"}
0005434299773	07E683	7835 611323	ANNA LEBEDEVA	{"email": "a.lebedeva-031969@postgrespro.ru", "phone": "+70140973932"}
0005434299774	8C3217	3825 967677	NATALYA TITOVA	{"email": "n.titova_061981@postgrespro.ru", "phone": "+70544428945"}
0005434299775	8C3217	0649 467591	OLGA IVANOVA	{"email": "o.ivanova-1979@postgrespro.ru", "phone": "+70689954118"}
0005434299776	0EC86F	5107 963383	VLADIMIR KARPOV	{"email": "v-karpov-1969@postgrespro.ru", "phone": "+70582990852"}
0005434299777	97E57A	9865 815025	VLADIMIR IVANOV	{"phone": "+70754330151"}
0005434299778	301D76	2873 252564	VALENTINA TROFIMOVA	{"email": "trofimovav-1978@postgrespro.ru", "phone": "+70680844406"}
0005434299779	301D76	7598 508800	NINA ALEKSEEVA	{"phone": "+70727293219"}
0005434299780	301D76	2467 306201	VLADIMIR KARPOV	{"email": "karpov.vladimir29051973@postgrespro.ru", "phone": "+70813309362"}
0005434299781	7DC2EB	9782 717101	VLADIMIR GAVRILOV	{"phone": "+70983540515"}
0005434299782	7DC2EB	9187 933416	VLADIMIR ZHUKOV	{"email": "vladimir_zhukov_031969@postgrespro.ru", "phone": "+70608198171"}
0005434299783	273527	7841 597950	IVAN EGOROV	{"email": "egorov_i1986@postgrespro.ru", "phone": "+70246797247"}
0005434299784	9A5B63	9471 108835	SVETLANA FROLOVA	{"email": "s.frolova_1982@postgrespro.ru", "phone": "+70117771967"}
0005434299785	9A5B63	7267 758180	VERA KARPOVA	{"phone": "+70049507982"}
0005434299786	DE3A19	6266 474489	VITALIY SIDOROV	{"email": "v.sidorov-1975@postgrespro.ru", "phone": "+70699490544"}
0005434299787	41B9ED	7415 410514	OLGA KOZLOVA	{"email": "kozlova.o_1974@postgrespro.ru", "phone": "+70689146243"}
0005434299788	F2A886	5644 969657	POLINA IVANOVA	{"phone": "+70908838763"}
0005434299789	F2A886	5859 842451	DENIS VOLKOV	{"phone": "+70057192338"}
0005434299790	E84B4E	2452 708214	VLADISLAV YAKOVLEV	{"email": "v_yakovlev_22111976@postgrespro.ru", "phone": "+70641810758"}
0005434299791	E84B4E	7069 816542	DMITRIY OSIPOV	{"email": "osipov_dmitriy.16061965@postgrespro.ru", "phone": "+70268506093"}
0005434299792	6B6C73	8656 961218	ANZHELIKA NIKITINA	{"email": "anzhelika-nikitina_1958@postgrespro.ru", "phone": "+70716947826"}
0005434299793	6B6C73	6121 932420	OLEG SEMENOV	{"phone": "+70226014644"}
0005434299794	6B6C73	8788 291642	LYUDMILA KISELEVA	{"phone": "+70997881256"}
0005434299795	F84C0A	6965 054249	IVAN IVANOV	{"email": "ivan.ivanov-071969@postgrespro.ru", "phone": "+70939975632"}
0005434299796	F84C0A	5176 443751	ALEKSANDR KOROLEV	{"phone": "+70156693525"}
0005434299797	B29992	7399 377518	VALENTINA FROLOVA	{"phone": "+70843275758"}
0005434299798	E29FDE	1642 743475	ANATOLIY MIRONOV	{"phone": "+70175916441"}
0005434299799	403C3D	6920 500688	ARSENIY FEDOTOV	{"phone": "+70981993134"}
0005434299800	0666CB	4777 556086	ELENA NAUMOVA	{"phone": "+70817749320"}
0005434299801	06CD77	2619 992487	TATYANA STEPANOVA	{"phone": "+70821600697"}
0005434299802	06CD77	6112 548447	EVGENIY KUZMIN	{"email": "evgeniy.kuzmin_1960@postgrespro.ru", "phone": "+70161790015"}
0005434299803	4851C9	7576 559317	ELENA POPOVA	{"email": "elena-popova-09051976@postgrespro.ru", "phone": "+70395701676"}
0005434299804	4851C9	0964 753343	KIRA POPOVA	{"phone": "+70141912999"}
0005434299805	46D687	0721 025252	NADEZHDA SOKOLOVA	{"email": "nadezhda_sokolova-24061956@postgrespro.ru", "phone": "+70610730696"}
0005434299806	E06D61	4594 853291	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev11101969@postgrespro.ru", "phone": "+70933368596"}
0005434299808	656808	5506 665122	SHAMIL KISELEV	{"phone": "+70209630059"}
0005434299809	9B3D46	9170 978630	GEORGIY KOZLOV	{"email": "georgiy-kozlov111973@postgrespro.ru", "phone": "+70538222165"}
0005434299810	9992E4	7877 754969	EKATERINA ANDREEVA	{"phone": "+70542583931"}
0005434299811	9992E4	5972 151437	LYUDMILA ABRAMOVA	{"email": "lyudmila_abramova-1962@postgrespro.ru", "phone": "+70443331225"}
0005434299812	062ACF	8219 580620	IRINA MELNIKOVA	{"phone": "+70792117357"}
0005434299813	062ACF	0117 639759	DMITRIY MAKAROV	{"email": "dmitriy_makarov-30091976@postgrespro.ru", "phone": "+70232049021"}
0005434299814	062ACF	5998 695305	ROZA POPOVA	{"email": "rpopova021973@postgrespro.ru", "phone": "+70130872048"}
0005434299815	D6C4FA	8631 090646	SVETLANA SERGEEVA	{"email": "sergeeva.svetlana.021986@postgrespro.ru", "phone": "+70079220521"}
0005434299816	062886	0534 673862	VITALIY MOROZOV	{"phone": "+70791580730"}
0005434299817	01F348	6171 456868	VALERIY KUZNECOV	{"phone": "+70795927424"}
0005434299818	4ADF2D	1133 703997	BORIS SEMENOV	{"phone": "+70555329938"}
0005434299819	41941E	0491 346119	YURIY PETROV	{"phone": "+70292654451"}
0005434299820	1FD207	1568 342347	SERGEY FEDOROV	{"phone": "+70025554235"}
0005434299821	9D0892	9927 905942	VLADIMIR GRIGOREV	{"email": "grigorevv.18081955@postgrespro.ru", "phone": "+70574988231"}
0005434299822	9D0892	7434 197389	ALEKSANDR NIKOLAEV	{"phone": "+70632799975"}
0005434299823	68736A	6763 905956	VIKTOR SERGEEV	{"email": "v-sergeev-1972@postgrespro.ru", "phone": "+70037757484"}
0005434299824	92D623	7599 893324	LARISA BELYAEVA	{"phone": "+70022967065"}
0005434299825	E963EE	9423 448637	ARTEM VOLKOV	{"phone": "+70726075964"}
0005434299826	26E51D	8705 533212	ROMAN DMITRIEV	{"phone": "+70460846925"}
0005434299827	26E51D	3589 838907	NADEZHDA DMITRIEVA	{"phone": "+70551932534"}
0005434299828	26E51D	5826 675839	DMITRIY VLASOV	{"email": "dmitriy-vlasov_1974@postgrespro.ru", "phone": "+70555492584"}
0005434299829	D91F51	0761 488766	DMITRIY STEPANOV	{"email": "stepanov_d_1968@postgrespro.ru", "phone": "+70028665927"}
0005434299830	4342AB	1344 941840	NATALYA FILIPPOVA	{"phone": "+70883799909"}
0005434299831	4342AB	7958 823805	VLADIMIR SOKOLOV	{"email": "sokolov-v.11021976@postgrespro.ru", "phone": "+70233347388"}
0005434299832	F64574	6582 254330	EKATERINA SMIRNOVA	{"phone": "+70911532739"}
0005434299833	B82C95	7195 755971	NATALYA KUZNECOVA	{"email": "kuznecovan_07011974@postgrespro.ru", "phone": "+70266867160"}
0005434299834	B82C95	0301 684969	VERA POTAPOVA	{"email": "potapovavera.18051978@postgrespro.ru", "phone": "+70530396304"}
0005434299835	24B4EA	5278 356546	ZAKHAR SEMENOV	{"phone": "+70437487651"}
0005434299836	89AEDF	8653 746687	DMITRIY ROMANOV	{"email": "d-romanov-1973@postgrespro.ru", "phone": "+70636544435"}
0005434299837	89AEDF	6495 261804	TATYANA DANILOVA	{"phone": "+70517712267"}
0005434299838	8B381E	4440 134230	MIKHAIL PAVLOV	{"phone": "+70470245131"}
0005434299839	093C7E	6981 815404	ALEKSANDR SAVELEV	{"phone": "+70390287717"}
0005434299840	404016	0740 586563	ANATOLIY PAVLOV	{"email": "pavlov-a_031975@postgrespro.ru", "phone": "+70280383881"}
0005434299841	94A68D	8300 336503	LYUDMILA KOVALEVA	{"email": "kovaleva-l_031981@postgrespro.ru", "phone": "+70525989604"}
0005434299842	94A68D	8856 596367	IRINA OSIPOVA	{"phone": "+70626671867"}
0005434299843	F3B488	1810 845480	NIKOLAY NIKITIN	{"email": "nikitin_n-011967@postgrespro.ru", "phone": "+70717760881"}
0005434299844	A6A482	9540 967831	SVETLANA ILINA	{"email": "ilina.svetlana_091977@postgrespro.ru", "phone": "+70492396459"}
0005434299845	A6A482	0641 992959	EKATERINA VLASOVA	{"email": "e_vlasova-02071968@postgrespro.ru", "phone": "+70812076599"}
0005434299846	A6A482	2216 598781	NINA IVANOVA	{"email": "ivanova-n111968@postgrespro.ru", "phone": "+70649670442"}
0005434299847	269166	7298 166298	DENIS ANDREEV	{"email": "denis-andreev30011985@postgrespro.ru", "phone": "+70113231522"}
0005434299848	269166	6122 674345	ALEKSANDR NAUMOV	{"phone": "+70731478254"}
0005434299849	269166	8547 277562	ALEKSANDR KUZNECOV	{"phone": "+70379429086"}
0005434299850	726D64	4520 889163	IGOR NOVIKOV	{"email": "novikov-igor15111978@postgrespro.ru", "phone": "+70208244256"}
0005434299851	726D64	5993 073934	VLADISLAV FROLOV	{"email": "v_frolov.13091976@postgrespro.ru", "phone": "+70141382173"}
0005434299852	909DB4	3678 662452	ALEKSEY CHERNOV	{"email": "chernovaleksey.1968@postgrespro.ru", "phone": "+70661876112"}
0005434299853	871CD8	9096 334971	ALEKSEY ISAEV	{"phone": "+70814818083"}
0005434299854	871CD8	5054 523598	IRINA ZAKHAROVA	{"email": "i_zakharova.1961@postgrespro.ru", "phone": "+70580254619"}
0005434299855	89361C	9824 083652	ZOYA KOROLEVA	{"phone": "+70192843434"}
0005434299856	6444AF	8941 253143	LILIYA ZHURAVLEVA	{"phone": "+70415164493"}
0005434299857	B7610B	3887 565602	GALINA ABRAMOVA	{"email": "abramovag29121983@postgrespro.ru", "phone": "+70233297362"}
0005434299858	65D0A2	3326 349601	ELENA LEBEDEVA	{"phone": "+70111281349"}
0005434299859	6E6DDF	3096 841550	ALEKSANDR KOROLEV	{"phone": "+70555727428"}
0005434299860	D9AB93	5622 142617	RADIK FROLOV	{"phone": "+70225213206"}
0005434299861	09415F	1620 591930	ANNA KALININA	{"email": "kalinina.anna071969@postgrespro.ru", "phone": "+70256378622"}
0005434299862	F04C96	3793 592512	KONSTANTIN TIKHONOV	{"phone": "+70956622972"}
0005434299863	638CCE	3697 094057	ALENA MOISEEVA	{"email": "alena_moiseeva15111971@postgrespro.ru", "phone": "+70507869926"}
0005434299864	638CCE	8313 034285	PRASKOVYA ILINA	{"phone": "+70446981818"}
0005434299865	C33C2E	9624 006498	ALEKSANDR PAVLOV	{"phone": "+70791705990"}
0005434299866	3B143B	0080 227128	EVGENIY NAZAROV	{"phone": "+70305295973"}
0005434299867	8761B9	8493 317720	YANA TIMOFEEVA	{"phone": "+70485400112"}
0005434299868	8761B9	1480 539144	MARAT IVANOV	{"phone": "+70578633686"}
0005434299869	B2B61D	3421 700584	MARIYA NIKOLAEVA	{"phone": "+70698894620"}
0005434299870	9B3703	9503 232387	LIDIYA TIKHONOVA	{"email": "tikhonova_lidiya.1965@postgrespro.ru", "phone": "+70387928129"}
0005434299871	3C18AE	6924 715975	PAVEL OSIPOV	{"email": "p.osipov_091984@postgrespro.ru", "phone": "+70461066126"}
0005434299872	79DF86	5475 328843	ELENA GORBUNOVA	{"phone": "+70217819165"}
0005434299873	9A52A4	9126 863133	ALEKSANDR FROLOV	{"email": "aleksandr_frolov12041974@postgrespro.ru", "phone": "+70455561151"}
0005434299874	9A52A4	9993 600655	ARTEM SMIRNOV	{"phone": "+70297922081"}
0005434299875	954829	5176 549974	RUSLAN BORISOV	{"phone": "+70520279324"}
0005434299876	C6F133	0680 382327	VARVARA LOGINOVA	{"email": "varvara.loginova.1974@postgrespro.ru", "phone": "+70700551620"}
0005434299877	DCBBC7	7937 639016	VENIAMIN SMIRNOV	{"phone": "+70980012004"}
0005434299878	DCBBC7	3637 809383	OLGA KARPOVA	{"email": "karpovaolga_08111982@postgrespro.ru", "phone": "+70366295925"}
0005434299879	E15698	3743 765646	ALEKSANDR FOMIN	{"email": "fomin_a_07121978@postgrespro.ru", "phone": "+70979780472"}
0005434299880	B186F1	5447 300549	ANTON SHEVCHENKO	{"phone": "+70788543003"}
0005434299881	A2C967	9583 258611	ADELINA IVANOVA	{"phone": "+70281957793"}
0005434299882	DF1D80	8202 138066	YURIY GORBUNOV	{"email": "yuriygorbunov-1958@postgrespro.ru", "phone": "+70468632057"}
0005434299883	B26588	6972 617501	SERGEY SOROKIN	{"email": "sorokinsergey_031976@postgrespro.ru", "phone": "+70298871422"}
0005434299884	088216	5706 292611	EVGENIY PETROV	{"email": "evgeniy-petrov.111959@postgrespro.ru", "phone": "+70109625700"}
0005434299885	68704B	9186 366396	NATALYA KONDRATEVA	{"email": "kondrateva.natalya.1968@postgrespro.ru", "phone": "+70274582497"}
0005434299886	6B7946	3918 078834	ALEKSANDR RODIONOV	{"email": "aleksandrrodionov_13011973@postgrespro.ru", "phone": "+70705417465"}
0005434299887	6B7946	4820 537635	TATYANA TIKHONOVA	{"email": "tikhonovatatyana04121971@postgrespro.ru", "phone": "+70500723470"}
0005434299888	B1F08A	7172 399466	ALEKSANDR FROLOV	{"phone": "+70443046768"}
0005434299889	FF2FE2	4193 817121	RUSLAN KUZNECOV	{"phone": "+70676323174"}
0005434299890	FF2FE2	7175 033019	VYACHESLAV MAKAROV	{"email": "makarovv.071970@postgrespro.ru", "phone": "+70212920284"}
0005434299891	25AFA0	8604 186242	NATALYA KULIKOVA	{"email": "natalya_kulikova_17041967@postgrespro.ru", "phone": "+70371528605"}
0005434299892	205A49	6372 583026	EVGENIYA SAVELEVA	{"phone": "+70864001608"}
0005434299893	6B9460	7821 103577	LYUDMILA KOZLOVA	{"phone": "+70036077576"}
0005434299894	4AB310	5306 704724	RAVIL BORISOV	{"phone": "+70808311188"}
0005434299895	4AB310	1863 895819	NATALYA ARKHIPOVA	{"email": "arkhipova-natalya_071972@postgrespro.ru", "phone": "+70662354826"}
0005434299896	673AD4	0712 512264	KONSTANTIN ABRAMOV	{"email": "k_abramov041967@postgrespro.ru", "phone": "+70688071189"}
0005434299897	673AD4	4287 307004	OLGA LAZAREVA	{"phone": "+70125069441"}
0005434299898	275CCA	1079 188406	EKATERINA VOROBEVA	{"email": "ekaterina-vorobeva-1962@postgrespro.ru", "phone": "+70541570264"}
0005434299899	18BA99	6005 629035	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev_1974@postgrespro.ru", "phone": "+70577534239"}
0005434299900	3B6F78	8222 585876	MARIYA STEPANOVA	{"email": "stepanova-mariya_1969@postgrespro.ru", "phone": "+70471369510"}
0005434299901	3B6F78	4075 435324	VIKTOR BORISOV	{"phone": "+70830834134"}
0005434299902	313813	2057 283302	ANNA ALEKSEEVA	{"phone": "+70616157741"}
0005434299903	285604	4470 043381	NIKOLAY AFANASEV	{"email": "n_afanasev.13101970@postgrespro.ru", "phone": "+70638630039"}
0005434299904	0AFC14	2859 619290	VLADIMIR MATVEEV	{"phone": "+70162108365"}
0005434299905	0AFC14	6262 118831	MARGARITA YAKOVLEVA	{"phone": "+70434499220"}
0005434299906	7E104B	4097 346842	NINA KONOVALOVA	{"phone": "+70179731451"}
0005434299907	B81E83	4445 818778	ALEKSEY RODIONOV	{"phone": "+70719361671"}
0005434299908	31F7F3	3677 231446	GULSHAT VOROBEVA	{"email": "vorobevagulshat.1973@postgrespro.ru", "phone": "+70937604697"}
0005434299909	31F7F3	0995 495629	ELENA FROLOVA	{"phone": "+70689960376"}
0005434299910	4BE193	2946 170880	NIKOLAY FEDOTOV	{"phone": "+70085268162"}
0005434299911	C39CF5	9763 883175	ALISA FOMINA	{"email": "alisa_fomina01031978@postgrespro.ru", "phone": "+70858376361"}
0005434299912	C39CF5	2429 366268	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina-011967@postgrespro.ru", "phone": "+70341263172"}
0005434299913	C39CF5	3237 228849	OLGA MAKSIMOVA	{"email": "maksimova.olga.091974@postgrespro.ru", "phone": "+70228020249"}
0005434299914	31F64E	4381 346257	IGOR KULIKOV	{"phone": "+70106554848"}
0005434299915	54A058	3526 444817	RUMIYA NAZAROVA	{"email": "rnazarova_25071974@postgrespro.ru", "phone": "+70004166386"}
0005434299916	54A058	7895 124715	VLADIMIR MELNIKOV	{"phone": "+70812805518"}
0005434299917	57B2C4	2524 261319	YURIY KISELEV	{"phone": "+70841495181"}
0005434299918	57B2C4	4789 111728	KIRILL MOROZOV	{"email": "kirill_morozov1968@postgrespro.ru", "phone": "+70232867123"}
0005434299919	1AA071	9561 958382	ANDREY DMITRIEV	{"email": "andrey.dmitriev111971@postgrespro.ru", "phone": "+70220352620"}
0005434299920	1AA071	6218 520637	ANASTASIYA ABRAMOVA	{"email": "abramova-a.101979@postgrespro.ru", "phone": "+70046545316"}
0005434299921	269B53	4084 053432	ALEKSANDR DAVYDOV	{"phone": "+70091895239"}
0005434299922	C8A97D	3913 460294	OLGA SAVELEVA	{"email": "olga-saveleva03081961@postgrespro.ru", "phone": "+70801866113"}
0005434299923	C8A97D	0114 182202	OLGA SOKOLOVA	{"email": "sokolovaolga1969@postgrespro.ru", "phone": "+70120471799"}
0005434299924	B739D3	8186 365006	STANISLAV POPOV	{"phone": "+70139017674"}
0005434299925	3242ED	8986 645861	NAIL SOLOVEV	{"phone": "+70040693259"}
0005434299926	42290D	4541 935805	VLADIMIR GORBUNOV	{"email": "v_gorbunov.09031974@postgrespro.ru", "phone": "+70068423862"}
0005434299927	42290D	9662 512708	ALEKSANDRA POPOVA	{"email": "popova.aleksandra-1963@postgrespro.ru", "phone": "+70443029301"}
0005434299928	C01432	8480 469716	ANDREY POPOV	{"phone": "+70720307648"}
0005434299929	C01432	5938 090005	LYUDMILA ABRAMOVA	{"phone": "+70169771221"}
0005434299930	6E4C33	9379 735116	BORIS SMIRNOV	{"email": "smirnov-b.1972@postgrespro.ru", "phone": "+70642456003"}
0005434299931	E7117F	2233 172013	KONSTANTIN NAUMOV	{"email": "konstantin-naumov121985@postgrespro.ru", "phone": "+70110181550"}
0005434299932	E7117F	3896 091308	ELENA LUKYANOVA	{"email": "elena_lukyanova.30041970@postgrespro.ru", "phone": "+70155646359"}
0005434299933	7EDD27	3346 356432	KARINA GAVRILOVA	{"email": "karina.gavrilova.24041970@postgrespro.ru", "phone": "+70131667444"}
0005434299934	957451	9639 640067	MARIYA KULIKOVA	{"email": "mariya_kulikova-16081976@postgrespro.ru", "phone": "+70257441679"}
0005434299935	957451	6417 423456	IVAN MELNIKOV	{"email": "melnikovi-02051968@postgrespro.ru", "phone": "+70085476817"}
0005434299936	5D7857	8733 934201	SVETLANA ZHURAVLEVA	{"email": "zhuravlevasvetlana021976@postgrespro.ru", "phone": "+70096813316"}
0005434299937	B6617D	3010 505870	NATALYA MIKHAYLOVA	{"email": "mikhaylova_natalya_101971@postgrespro.ru", "phone": "+70666205425"}
0005434299938	A46750	1000 289557	MARIYA ILINA	{"phone": "+70160233679"}
0005434299939	A46750	0967 162554	VLADIMIR GORBUNOV	{"email": "gorbunov_vladimir.1978@postgrespro.ru", "phone": "+70510781097"}
0005434299940	ED9E64	9937 918060	DMITRIY OSIPOV	{"email": "osipovd01081971@postgrespro.ru", "phone": "+70468381344"}
0005434299941	ED9E64	6613 846050	EVGENIY VLASOV	{"phone": "+70777681764"}
0005434299942	9DB696	3055 880487	GEORGIY MAKSIMOV	{"email": "georgiy.maksimov-041971@postgrespro.ru", "phone": "+70869929011"}
0005434299943	884E71	4135 689569	ALEKSANDR STEPANOV	{"phone": "+70026607742"}
0005434299944	37A70C	3663 573865	VLADIMIR DAVYDOV	{"phone": "+70266088041"}
0005434299945	F95D48	6255 930418	NADEZHDA PETROVA	{"phone": "+70339599390"}
0005434299946	F95D48	8486 365375	VALENTINA MARTYNOVA	{"phone": "+70957749848"}
0005434299947	6C054D	5955 502995	IGOR IVANOV	{"email": "ivanovigor-1977@postgrespro.ru", "phone": "+70135922662"}
0005434299948	2ADFE5	4708 284568	VIKTOR VOLKOV	{"phone": "+70098063422"}
0005434299949	2ADFE5	8125 351486	SVETLANA MIRONOVA	{"email": "mironova.s1982@postgrespro.ru", "phone": "+70364735817"}
0005434299950	673BFC	0316 226851	IGOR KOROLEV	{"phone": "+70426036629"}
0005434299951	7AC6E9	7413 791605	VITALIY NIKITIN	{"phone": "+70664724541"}
0005434299952	0B95BA	4548 379870	DAMIR SOROKIN	{"phone": "+70264472906"}
0005434299953	5604E0	2957 120519	RAMIL KUZMIN	{"email": "kuzmin.ramil_1982@postgrespro.ru", "phone": "+70084765148"}
0005434299954	5604E0	9253 414611	VALERIY SEMENOV	{"email": "v.semenov.1984@postgrespro.ru", "phone": "+70756063812"}
0005434299955	595609	8989 422326	NAILYA GORBUNOVA	{"email": "n.gorbunova.1962@postgrespro.ru", "phone": "+70121332843"}
0005434299956	33FB6A	2472 802426	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova-1963@postgrespro.ru", "phone": "+70875663794"}
0005434299957	33FB6A	7068 538113	ELENA MEDVEDEVA	{"email": "medvedevae-1955@postgrespro.ru", "phone": "+70288198575"}
0005434299958	74AC6E	4471 256655	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr.08061967@postgrespro.ru", "phone": "+70272040970"}
0005434299959	74AC6E	8407 519253	NATALYA BOGDANOVA	{"email": "bogdanova_natalya13051976@postgrespro.ru", "phone": "+70463202893"}
0005434299960	263EDE	3282 544675	STANISLAV ZAYCEV	{"phone": "+70901888580"}
0005434299961	4707A3	2215 545224	SERGEY YAKOVLEV	{"phone": "+70379041857"}
0005434299962	61EAF0	5789 518438	VIKTOR ZHURAVLEV	{"email": "viktor_zhuravlev.101978@postgrespro.ru", "phone": "+70722688404"}
0005434299963	5B06BE	0811 925987	MAKSIM ANDREEV	{"phone": "+70189831626"}
0005434299964	45971F	2298 009095	ALEKSEY VASILEV	{"email": "aleksey_vasilev-27071979@postgrespro.ru", "phone": "+70112743794"}
0005434299965	73EF59	5806 540188	ROMAN MIKHAYLOV	{"phone": "+70453671331"}
0005434299966	A1C72C	0580 665420	VLADISLAV KOZLOV	{"phone": "+70432865233"}
0005434299967	F991F4	2018 053508	ELENA KUZNECOVA	{"email": "kuznecova_elena_1975@postgrespro.ru", "phone": "+70286443473"}
0005434299968	05ECCD	5065 864293	VYACHESLAV BELOV	{"phone": "+70277181189"}
0005434299969	05ECCD	9883 499935	LYUBOV IVANOVA	{"phone": "+70462021953"}
0005434299970	54CDE7	3393 883727	DMITRIY PETROV	{"email": "d.petrov-24041970@postgrespro.ru", "phone": "+70277525498"}
0005434299971	E23584	8549 265190	VALERIY SOROKIN	{"phone": "+70295410472"}
0005434299972	E23584	5785 234539	VERA KUZNECOVA	{"email": "kuznecovav.1965@postgrespro.ru", "phone": "+70351332105"}
0005434299973	E8E954	4105 261702	PAVEL SOLOVEV	{"phone": "+70752872268"}
0005434299974	E95C9F	3519 307391	ALEKSANDR MATVEEV	{"email": "amatveev-14061978@postgrespro.ru", "phone": "+70104712805"}
0005434299975	E95C9F	5652 834012	MARIYA TROFIMOVA	{"email": "trofimovamariya1969@postgrespro.ru", "phone": "+70297437967"}
0005434299976	0C132A	4027 493201	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov_28041969@postgrespro.ru", "phone": "+70148635208"}
0005434299977	590A02	7080 436616	ILYA IVANOV	{"phone": "+70874858234"}
0005434299978	2B73DE	0330 726815	RINAT SCHERBAKOV	{"phone": "+70759626755"}
0005434299979	810C54	6041 812357	VALENTINA BELOVA	{"email": "v_belova031985@postgrespro.ru", "phone": "+70145844740"}
0005434299980	A2E251	9716 407470	VIOLETTA LEBEDEVA	{"phone": "+70440956048"}
0005434299981	A2E251	4664 996682	LYUDMILA KUZMINA	{"phone": "+70469277307"}
0005434299982	AB4C40	8396 165852	ANDREY VASILEV	{"phone": "+70511212922"}
0005434299983	AB4C40	0253 533411	ARTEM ILIN	{"phone": "+70403661254"}
0005434299984	9E4202	7624 517473	VIKTOR MOROZOV	{"phone": "+70915971027"}
0005434299985	9E4202	7777 287497	TATYANA ALEKSEEVA	{"phone": "+70178166985"}
0005434299986	D2E227	0329 667215	MARINA STEPANOVA	{"phone": "+70647348533"}
0005434299987	D2E227	3757 987329	IVAN KOZLOV	{"email": "kozlovivan_1972@postgrespro.ru", "phone": "+70223287836"}
0005434299988	9EC471	5143 485772	TATYANA DAVYDOVA	{"email": "davydova_t011983@postgrespro.ru", "phone": "+70817257132"}
0005434299989	FA861B	9129 087352	VLADIMIR ZAKHAROV	{"phone": "+70536814692"}
0005434299990	FA861B	0703 460837	IRINA EFIMOVA	{"email": "iefimova1975@postgrespro.ru", "phone": "+70978532234"}
0005434299991	66B3B2	7490 742265	NADEZHDA ERMAKOVA	{"phone": "+70143249124"}
0005434299992	66B3B2	7821 712207	YURIY MIRONOV	{"email": "mironov_y.1975@postgrespro.ru", "phone": "+70543046325"}
0005434299993	AAE97E	9918 844732	VALENTIN SERGEEV	{"email": "valentin.sergeev_031979@postgrespro.ru", "phone": "+70815102643"}
0005434299994	AAE97E	4315 946181	DAMIR VOLKOV	{"email": "damir-volkov-031974@postgrespro.ru", "phone": "+70968242081"}
0005434299995	AAE97E	0229 508497	SERGEY SIDOROV	{"email": "sidorov.sergey-1973@postgrespro.ru", "phone": "+70516785828"}
0005434300109	558D6C	5532 627334	ALEKSEY SEMENOV	{"phone": "+70757338291"}
0005434299996	A70824	6265 551436	TATYANA SEMENOVA	{"email": "tsemenova031977@postgrespro.ru", "phone": "+70119130940"}
0005434299997	A70824	8174 888662	ELENA LUKYANOVA	{"email": "lukyanova_elena30061976@postgrespro.ru", "phone": "+70863937343"}
0005434299998	A70824	6067 841876	LYUBOV ROMANOVA	{"phone": "+70214769315"}
0005434299999	60230C	3596 006004	DANIIL BARANOV	{"email": "baranovdaniil.1977@postgrespro.ru", "phone": "+70650325390"}
0005434300000	60230C	8601 396214	ELENA POTAPOVA	{"email": "potapova-elena19031961@postgrespro.ru", "phone": "+70988895535"}
0005434300001	60230C	7651 051453	MIKHAIL ANDREEV	{"email": "mandreev_09111966@postgrespro.ru", "phone": "+70691076315"}
0005434300002	09F3A3	0065 497375	GEORGIY BONDARENKO	{"phone": "+70630597408"}
0005434300003	09F3A3	8385 128461	TATYANA LEBEDEVA	{"email": "tatyanalebedeva-1963@postgrespro.ru", "phone": "+70527284730"}
0005434300004	09F3A3	1731 810231	YULIYA IVANOVA	{"phone": "+70281357062"}
0005434300005	9E982C	9960 795323	VERA KUZNECOVA	{"phone": "+70725498254"}
0005434300006	DDEB5E	2648 728979	ANZHELIKA MAKSIMOVA	{"email": "maksimova.a_07081989@postgrespro.ru", "phone": "+70436175967"}
0005434300007	77A07A	8709 264075	ZOYA LUKYANOVA	{"email": "lukyanova_z.081969@postgrespro.ru", "phone": "+70710483681"}
0005434300008	B0280F	7894 232785	OLEG ZAKHAROV	{"email": "olegzakharov_031972@postgrespro.ru", "phone": "+70388693476"}
0005434300009	6BB85A	1032 337549	ANASTASIYA MATVEEVA	{"email": "anastasiyamatveeva-111986@postgrespro.ru", "phone": "+70080800042"}
0005434300010	1277CB	6299 588530	DARYA KULIKOVA	{"email": "kulikova_d-1975@postgrespro.ru", "phone": "+70060476091"}
0005434300011	1277CB	9748 087073	NIKOLAY FROLOV	{"email": "frolovnikolay-111976@postgrespro.ru", "phone": "+70027636139"}
0005434300012	B69FD5	8925 795530	ANDREY VASILEV	{"phone": "+70166402445"}
0005434300013	D6F3A9	3776 692395	NATALIYA EGOROVA	{"email": "n_egorova-07011973@postgrespro.ru", "phone": "+70745035240"}
0005434300014	D6F3A9	3537 196653	KONSTANTIN KOZLOV	{"phone": "+70359075073"}
0005434300015	8167AD	7695 401334	EVGENIYA SOKOLOVA	{"phone": "+70388799408"}
0005434300016	026676	7572 920736	ANNA IVANOVA	{"email": "annaivanova.1973@postgrespro.ru", "phone": "+70789211356"}
0005434300017	1DF5CB	4431 961645	VASILIY TIKHONOV	{"email": "tikhonov_vasiliy.01051967@postgrespro.ru", "phone": "+70957052063"}
0005434300018	1DF5CB	4730 668060	ALINA SIDOROVA	{"phone": "+70978901295"}
0005434300019	221D33	9257 729996	ALEKSEY IVANOV	{"email": "ivanov-aleksey-071971@postgrespro.ru", "phone": "+70020407143"}
0005434300020	221D33	2580 088027	SERGEY ZHURAVLEV	{"phone": "+70539184235"}
0005434300021	635313	1518 037865	VASILIY NAZAROV	{"phone": "+70060357227"}
0005434300022	5D8F4C	5737 426380	TAISIYA SEMENOVA	{"phone": "+70560710664"}
0005434300023	37FA63	7962 749729	RAISA ZHURAVLEVA	{"phone": "+70607585796"}
0005434300024	37FA63	5461 687645	VALENTIN KAZAKOV	{"email": "kazakovvalentin_031976@postgrespro.ru", "phone": "+70721688363"}
0005434300025	AB0E5A	0619 999364	ELENA VASILEVA	{"email": "e.vasileva21031978@postgrespro.ru", "phone": "+70763466824"}
0005434300026	0223B1	0231 078065	KONSTANTIN EGOROV	{"email": "egorov-konstantin-091962@postgrespro.ru", "phone": "+70531046716"}
0005434300027	CCE201	6268 587540	TAMARA NOVIKOVA	{"phone": "+70633401233"}
0005434300028	3C417F	4414 581697	PAVEL FOMIN	{"phone": "+70722670279"}
0005434300029	3C417F	9023 652877	VASILIY SAVELEV	{"phone": "+70997198345"}
0005434300030	BE0B02	6847 285095	MARIYA SAVELEVA	{"email": "mariyasaveleva-1974@postgrespro.ru", "phone": "+70652318287"}
0005434300031	8E9D6D	8804 194413	VALENTINA ANDREEVA	{"phone": "+70679762200"}
0005434300032	8E9D6D	9081 158277	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev15051975@postgrespro.ru", "phone": "+70122835477"}
0005434300033	8E9D6D	0371 048272	ARINA ARKHIPOVA	{"phone": "+70167495585"}
0005434300034	23A555	3933 882386	OKSANA ZOTOVA	{"phone": "+70973670446"}
0005434300035	BBF6E7	8557 252678	YULIYA OVCHINNIKOVA	{"phone": "+70443071755"}
0005434300036	A33556	8815 765898	VIKTOR VLASOV	{"phone": "+70726627443"}
0005434300037	F4EB0C	6510 341974	ALEKSANDR GORBUNOV	{"email": "gorbunova.01101974@postgrespro.ru", "phone": "+70949324784"}
0005434300038	616A2C	2742 307277	ELENA LEBEDEVA	{"phone": "+70639649919"}
0005434300039	616A2C	8462 672566	TAMARA SEMENOVA	{"email": "semenova-t071974@postgrespro.ru", "phone": "+70831133286"}
0005434300040	ABB23B	0950 332715	VIKTOR FROLOV	{"email": "frolov_viktor-031975@postgrespro.ru", "phone": "+70928119388"}
0005434300041	894B31	3083 628268	DMITRIY TIKHONOV	{"phone": "+70804076727"}
0005434300042	06B0BC	8589 931066	MIKHAIL FOMIN	{"email": "fomin.m-091980@postgrespro.ru", "phone": "+70273156772"}
0005434300043	AC41F4	5822 350002	VADIM MAKAROV	{"phone": "+70546261693"}
0005434300044	9C4FE9	1848 866762	ARTEM KOZLOV	{"phone": "+70021196059"}
0005434300045	FCFCC4	9342 338424	VITALIY ALEKSANDROV	{"email": "valeksandrov1969@postgrespro.ru", "phone": "+70707266747"}
0005434300046	FCFCC4	9892 487631	ANDREY ZAKHAROV	{"email": "a-zakharov-30081976@postgrespro.ru", "phone": "+70824905217"}
0005434300047	FCFCC4	2946 536591	VYACHESLAV SERGEEV	{"email": "sergeev_v.1961@postgrespro.ru", "phone": "+70600080000"}
0005434300048	6A49FD	7676 895247	SVETLANA ISAEVA	{"email": "isaeva_svetlana081970@postgrespro.ru", "phone": "+70905160436"}
0005434300049	0BE000	0657 831942	IVAN SCHERBAKOV	{"email": "scherbakov-i.03041981@postgrespro.ru", "phone": "+70530247355"}
0005434300050	478775	3682 416248	ALEKSANDR KUZMIN	{"email": "kuzmin_a25091958@postgrespro.ru", "phone": "+70894283749"}
0005434300051	4EC580	6373 958632	LIDIYA MASLOVA	{"email": "maslova.l.1964@postgrespro.ru", "phone": "+70785438852"}
0005434300052	2D7C4E	9194 145957	VLADIMIR SOROKIN	{"email": "sorokin.v07091968@postgrespro.ru", "phone": "+70371226127"}
0005434300053	99C064	5355 213419	DMITRIY KUZMIN	{"phone": "+70959256672"}
0005434300054	9B7D32	1486 660036	EKATERINA ERMAKOVA	{"phone": "+70748775129"}
0005434300055	9B7D32	9203 637919	ALEKSANDR IVANOV	{"phone": "+70588457994"}
0005434300056	9B7D32	4007 962484	MARINA MARTYNOVA	{"phone": "+70328720823"}
0005434300057	86E839	6006 823408	ALEKSEY KUZNECOV	{"phone": "+70798471435"}
0005434300058	F206CE	3086 385221	LYUBOV DMITRIEVA	{"phone": "+70469418438"}
0005434300059	AD7745	2428 399164	VIKTOR DAVYDOV	{"phone": "+70998463605"}
0005434300060	D4D1D7	6172 549987	MARIYA ANDREEVA	{"phone": "+70943878363"}
0005434300061	985991	3383 499829	VITALIY DMITRIEV	{"email": "dmitriev_vitaliy1973@postgrespro.ru", "phone": "+70196929546"}
0005434300062	CB060F	9795 968501	NATALYA GUSEVA	{"email": "n-guseva-1980@postgrespro.ru", "phone": "+70197958804"}
0005434300063	8045D0	9978 322710	ALEKSEY SOKOLOV	{"email": "sokolov_aleksey_21061968@postgrespro.ru", "phone": "+70240732429"}
0005434300064	8045D0	7420 050526	LEV KOZLOV	{"phone": "+70300157661"}
0005434300065	573798	4189 766682	NIKOLAY KUZMIN	{"email": "nikolay-kuzmin.20011952@postgrespro.ru", "phone": "+70262028606"}
0005434300066	573798	2276 352525	LILIYA SERGEEVA	{"email": "liliya.sergeeva.13031975@postgrespro.ru", "phone": "+70847683916"}
0005434300067	074950	2005 372454	VLADIMIR DENISOV	{"phone": "+70921571449"}
0005434300068	074950	4716 989637	MARINA SAVELEVA	{"phone": "+70334627132"}
0005434300069	6F75E4	9615 024495	GLEB AFANASEV	{"email": "afanasev_g24021971@postgrespro.ru", "phone": "+70318650599"}
0005434300070	5DCB63	1752 542584	GALINA EGOROVA	{"phone": "+70197561985"}
0005434300071	78E4A9	2988 518591	TATYANA SCHERBAKOVA	{"phone": "+70306022259"}
0005434300072	117FB7	1340 946944	KAMIL MELNIKOV	{"phone": "+70268382600"}
0005434300073	549D7F	0048 668186	VALENTINA VLASOVA	{"phone": "+70365929381"}
0005434300074	C3EBAF	1794 077934	NINA STEPANOVA	{"email": "nina_stepanova-1963@postgrespro.ru", "phone": "+70057002529"}
0005434300075	35B879	3230 640467	KRISTINA ZAYCEVA	{"email": "zayceva_k021968@postgrespro.ru", "phone": "+70351499550"}
0005434300076	496717	1565 751281	EVGENIY MOROZOV	{"phone": "+70837168936"}
0005434300077	A13BB2	9989 609557	TATYANA MIKHAYLOVA	{"email": "tmikhaylova.20041978@postgrespro.ru", "phone": "+70455295624"}
0005434300078	A13BB2	7181 845567	YULIYA MARTYNOVA	{"email": "y-martynova_021981@postgrespro.ru", "phone": "+70082370943"}
0005434300079	A13BB2	6071 554046	SERGEY ALEKSANDROV	{"phone": "+70553021951"}
0005434300080	AB7531	1658 508633	YULIYA ZAKHAROVA	{"email": "yuliya-zakharova1979@postgrespro.ru", "phone": "+70123908344"}
0005434300081	0C2A0E	2190 466801	LIDIYA FADEEVA	{"phone": "+70558284911"}
0005434300082	9A9176	7694 205379	ALEKSANDR ROMANOV	{"phone": "+70883637044"}
0005434300083	9A9176	4319 933516	NATALYA EGOROVA	{"email": "egorova.n17011970@postgrespro.ru", "phone": "+70911303191"}
0005434300084	65BCC6	0417 515361	ILMIR MARTYNOV	{"phone": "+70543023860"}
0005434300085	65BCC6	9320 460339	ANATOLIY NIKITIN	{"phone": "+70319978559"}
0005434300086	76BFA8	0482 809163	ILYA KULIKOV	{"email": "kulikov_i071980@postgrespro.ru", "phone": "+70100735842"}
0005434300199	21FEC3	5276 267607	VYACHESLAV ZAYCEV	{"phone": "+70870617743"}
0005434300087	76BFA8	6909 025362	OLESYA GERASIMOVA	{"email": "o-gerasimova28081975@postgrespro.ru", "phone": "+70416800918"}
0005434300088	257317	2903 879924	TATYANA BARANOVA	{"email": "baranova-t.051977@postgrespro.ru", "phone": "+70280684636"}
0005434300089	257317	2201 175121	MARINA LAZAREVA	{"email": "lazareva-m_1975@postgrespro.ru", "phone": "+70170183402"}
0005434300090	67195D	8909 115750	FARID ZAKHAROV	{"phone": "+70822976367"}
0005434300091	67195D	8990 539159	ALEKSANDR ZHURAVLEV	{"email": "aleksandrzhuravlev1970@postgrespro.ru", "phone": "+70049448241"}
0005434300092	4E5302	2189 624930	ANTON DMITRIEV	{"email": "dmitriev_anton071971@postgrespro.ru", "phone": "+70997065108"}
0005434300093	4E6CFA	4371 654462	VARVARA PETROVA	{"phone": "+70389568385"}
0005434300094	29D59F	5652 817327	SERGEY SERGEEV	{"email": "s_sergeev-111970@postgrespro.ru", "phone": "+70112495177"}
0005434300095	6703CD	1982 502069	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr-091974@postgrespro.ru", "phone": "+70603955840"}
0005434300096	4183AA	6758 263241	LIDIYA GORBUNOVA	{"phone": "+70694308479"}
0005434300097	4183AA	3003 090357	NIKOLAY ORLOV	{"email": "orlov.n.061967@postgrespro.ru", "phone": "+70340960336"}
0005434300098	366176	5700 358566	IRINA IVANOVA	{"phone": "+70220372119"}
0005434300099	5F166C	1620 566414	VLADIMIR ZAKHAROV	{"email": "v.zakharov.021967@postgrespro.ru", "phone": "+70478670617"}
0005434300100	5F640C	5056 995114	GULNARA MEDVEDEVA	{"phone": "+70950409304"}
0005434300101	5F640C	1767 095745	ALEKSANDR SHEVCHENKO	{"phone": "+70272405880"}
0005434300102	8C4E3A	3597 823542	ALFIYA KAZAKOVA	{"phone": "+70756564131"}
0005434300103	8C4E3A	0745 596597	VLADIMIR ALEKSANDROV	{"phone": "+70982877088"}
0005434300104	6001D3	5789 327044	LYUDMILA DAVYDOVA	{"phone": "+70317440857"}
0005434300105	6001D3	9125 675667	PAVEL KONOVALOV	{"phone": "+70310307872"}
0005434300106	92C845	2485 129884	VLADIMIR IVANOV	{"phone": "+70057465206"}
0005434300107	6C3565	8682 609162	YURIY ZHURAVLEV	{"email": "zhuravlev.y_1965@postgrespro.ru", "phone": "+70037862998"}
0005434300108	6C3565	6841 892887	EKATERINA TARASOVA	{"email": "e.tarasova.22121967@postgrespro.ru", "phone": "+70913061687"}
0005434300110	558D6C	5816 191828	TATYANA SMIRNOVA	{"email": "tatyana-smirnova1966@postgrespro.ru", "phone": "+70125653005"}
0005434300111	8A2A21	1023 370475	EVA KULIKOVA	{"email": "eva_kulikova-1969@postgrespro.ru", "phone": "+70606629298"}
0005434300112	B106C2	5974 198827	RAVIL OSIPOV	{"email": "osipovr091978@postgrespro.ru", "phone": "+70146210558"}
0005434300113	E440F7	3489 732100	VIKTORIYA ROMANOVA	{"email": "v_romanova_1967@postgrespro.ru", "phone": "+70628086192"}
0005434300114	16547D	7681 027060	ALEKSANDRA NAUMOVA	{"email": "naumova-a.1987@postgrespro.ru", "phone": "+70424148526"}
0005434300115	9ECA50	8648 134186	YULIYA MASLOVA	{"phone": "+70780235213"}
0005434300116	BD035E	1112 980159	EDUARD VASILEV	{"email": "eduard.vasilev-101986@postgrespro.ru", "phone": "+70830954945"}
0005434300117	BD035E	8704 087480	VALENTINA OSIPOVA	{"email": "osipovav_27051973@postgrespro.ru", "phone": "+70038261696"}
0005434300118	CEB1F9	1405 094044	YULIYA LOGINOVA	{"email": "loginovayuliya.26101964@postgrespro.ru", "phone": "+70982091423"}
0005434300119	BF8F4F	0563 420830	MARINA ZHURAVLEVA	{"phone": "+70553737205"}
0005434300120	FF7C85	9379 552581	ANASTASIYA KUZNECOVA	{"email": "kuznecova_anastasiya071971@postgrespro.ru", "phone": "+70400642034"}
0005434300121	B1BDCA	5104 083190	NATALYA EFREMOVA	{"email": "n.efremova.111965@postgrespro.ru", "phone": "+70009385651"}
0005434300122	BA6685	9425 271638	ANNA VASILEVA	{"phone": "+70339390682"}
0005434300123	BA6685	1675 906024	VIOLETTA KONOVALOVA	{"email": "vkonovalova121974@postgrespro.ru", "phone": "+70658709858"}
0005434300124	A5351B	6875 055837	VIKTOR AFANASEV	{"phone": "+70686375149"}
0005434300125	7870BA	9158 624662	EKATERINA SERGEEVA	{"phone": "+70598912692"}
0005434300126	690403	1026 027744	MIKHAIL FOMIN	{"email": "m-fomin12101969@postgrespro.ru", "phone": "+70446361858"}
0005434300127	E43D37	8655 326646	IRINA OSIPOVA	{"email": "osipova_irina_051983@postgrespro.ru", "phone": "+70222230243"}
0005434300128	7B23FB	8343 119862	OLEG SAVELEV	{"phone": "+70017826156"}
0005434300129	CAE13A	3750 174984	ALEKSANDR KUZNECOV	{"phone": "+70128719658"}
0005434300130	06A5B3	6465 106315	ALEKSEY VOLKOV	{"email": "alekseyvolkov_101975@postgrespro.ru", "phone": "+70482433968"}
0005434300131	06A5B3	3838 291316	MIKHAIL KOROLEV	{"phone": "+70586104423"}
0005434300132	8F7BB3	9831 666016	SVETLANA SOROKINA	{"phone": "+70915649367"}
0005434300133	8F7BB3	9084 633358	MAKSIM KONOVALOV	{"phone": "+70215475721"}
0005434300134	8F3A9B	3192 162447	NIKOLAY MOROZOV	{"email": "nikolay.morozov_28021973@postgrespro.ru", "phone": "+70772641197"}
0005434300135	999AE8	9464 586571	EVGENIY EGOROV	{"email": "evgeniy-egorov_1974@postgrespro.ru", "phone": "+70062441855"}
0005434300136	999AE8	9546 712914	OLEG KUZMIN	{"phone": "+70391114759"}
0005434300137	0B84E9	8928 769859	YURIY SEMENOV	{"email": "semenov-y-14041976@postgrespro.ru", "phone": "+70980335511"}
0005434300138	0B84E9	9620 331102	LYUDMILA KUZNECOVA	{"email": "l-kuznecova12051979@postgrespro.ru", "phone": "+70642734599"}
0005434300139	44BF03	6287 637500	VLADIMIR MIKHAYLOV	{"phone": "+70747568244"}
0005434300140	44BF03	8018 991462	ELEONORA KUZNECOVA	{"email": "kuznecova-e_20111976@postgrespro.ru", "phone": "+70774301560"}
0005434300141	7F1C46	3428 685353	VADIM ROMANOV	{"email": "romanovv_071958@postgrespro.ru", "phone": "+70091139505"}
0005434300142	7F1C46	3396 389701	ALEKSANDR MIKHAYLOV	{"phone": "+70759494449"}
0005434300143	5BE759	4817 297393	IRINA GUSEVA	{"phone": "+70182363843"}
0005434300144	5BE759	5290 262086	YURIY STEPANOV	{"email": "stepanov.yuriy.13061967@postgrespro.ru", "phone": "+70472898244"}
0005434300145	E3F904	3871 053348	LYUDMILA FROLOVA	{"email": "frolova_lyudmila.1980@postgrespro.ru", "phone": "+70666026848"}
0005434300146	11BA94	4769 708756	ELENA MARTYNOVA	{"phone": "+70173671426"}
0005434300147	11BA94	2926 913040	MARINA MIKHAYLOVA	{"email": "mikhaylova.marina.121976@postgrespro.ru", "phone": "+70665214195"}
0005434300148	F02FB9	6754 301909	OLGA KOZLOVA	{"phone": "+70110487446"}
0005434300149	F02FB9	0722 734631	GALINA VOLKOVA	{"phone": "+70821570820"}
0005434300150	B0BC91	1007 908592	VIKTOR KUZNECOV	{"phone": "+70365284323"}
0005434300151	0D8C3B	1806 082354	KSENIYA SOLOVEVA	{"phone": "+70419569460"}
0005434300152	E01FF9	7902 284858	BORIS SCHERBAKOV	{"phone": "+70051702815"}
0005434300153	3B5637	4613 050067	NAIL NOVIKOV	{"phone": "+70281379502"}
0005434300154	7E7374	8614 248491	SEMEN ALEKSEEV	{"phone": "+70013243253"}
0005434300155	7E7374	1519 231073	LYUDMILA GUSEVA	{"phone": "+70197522794"}
0005434300156	6F741A	5920 441913	YURIY MELNIKOV	{"phone": "+70924169082"}
0005434300157	7BB456	6370 129813	VIKTOR TARASOV	{"phone": "+70903588716"}
0005434300158	80EFBB	7248 991767	FAINA IVANOVA	{"phone": "+70832292963"}
0005434300159	E58E3B	3399 894610	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov011971@postgrespro.ru", "phone": "+70307166794"}
0005434300160	01F37D	8888 471837	ANDREY CHERNOV	{"phone": "+70024994396"}
0005434300161	4A31D9	7358 053901	ANDREY KRASNOV	{"phone": "+70226162593"}
0005434300162	4A31D9	1000 820613	TATYANA SCHERBAKOVA	{"email": "tatyana-scherbakova.081959@postgrespro.ru", "phone": "+70288600781"}
0005434300163	243AF3	9592 098578	RAIL STEPANOV	{"phone": "+70338843110"}
0005434300164	FABD89	7334 628924	TATYANA KONOVALOVA	{"phone": "+70496573681"}
0005434300165	F01926	6831 779498	SERGEY ZAYCEV	{"email": "szaycev_111973@postgrespro.ru", "phone": "+70474739063"}
0005434300220	12E864	2048 627121	VALERIY SOROKIN	{"phone": "+70846590298"}
0005434300166	FE4F55	7268 712188	TATYANA FROLOVA	{"email": "frolova-tatyana.1979@postgrespro.ru", "phone": "+70330725930"}
0005434300167	FE4F55	8506 728797	SERGEY DAVYDOV	{"email": "davydov.sergey_08021965@postgrespro.ru", "phone": "+70043347935"}
0005434300168	A964C9	6627 014993	DMITRIY MIKHAYLOV	{"phone": "+70289542358"}
0005434300169	0B2491	9964 056555	NADEZHDA MAKSIMOVA	{"phone": "+70545539721"}
0005434300170	0B2491	4186 551897	VITALIY ZAKHAROV	{"phone": "+70856825129"}
0005434300171	65E4C4	7320 629319	ARINA VOLKOVA	{"email": "a-volkova.12101960@postgrespro.ru", "phone": "+70963608589"}
0005434300172	A3BAD8	2113 007874	NIKITA ZHUKOV	{"email": "zhukovnikita_031979@postgrespro.ru", "phone": "+70265842709"}
0005434300173	A3BAD8	2348 783256	LYUBOV SOKOLOVA	{"email": "lyubovsokolova.23071971@postgrespro.ru", "phone": "+70400870499"}
0005434300174	D75964	5250 376430	PETR SIDOROV	{"email": "p.sidorov12041962@postgrespro.ru", "phone": "+70563690938"}
0005434300175	CE82E5	8288 608974	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev-021968@postgrespro.ru", "phone": "+70373002884"}
0005434300176	33738D	8860 403258	ANASTASIYA YAKOVLEVA	{"email": "anastasiya_yakovleva-1965@postgrespro.ru", "phone": "+70879669822"}
0005434300177	8DFA6A	2094 562071	VALENTIN POPOV	{"email": "v.popov28031968@postgrespro.ru", "phone": "+70734830519"}
0005434300178	8DFA6A	7152 949251	VASILIY NIKOLAEV	{"phone": "+70061465395"}
0005434300179	C510D6	4329 940417	ALEKSANDRA KAZAKOVA	{"email": "kazakova.a-1980@postgrespro.ru", "phone": "+70946094751"}
0005434300180	C510D6	1290 845490	ALLA VOLKOVA	{"email": "volkovaa051969@postgrespro.ru", "phone": "+70290009583"}
0005434300181	3D43D5	5300 954362	LIDIYA POPOVA	{"phone": "+70522592597"}
0005434300182	3D43D5	6928 221174	MIKHAIL VASILEV	{"email": "m-vasilev.04021980@postgrespro.ru", "phone": "+70107433229"}
0005434300183	58D9EC	7227 237228	ANNA OVCHINNIKOVA	{"email": "anna_ovchinnikova-1979@postgrespro.ru", "phone": "+70134886874"}
0005434300184	261525	6150 550468	ALINA VASILEVA	{"phone": "+70852401063"}
0005434300185	52B567	1028 622224	PAVEL FEDOROV	{"email": "pavel_fedorov09081981@postgrespro.ru", "phone": "+70343968642"}
0005434300186	52B567	6545 007460	YURIY ZAYCEV	{"email": "yuriy.zaycev25091969@postgrespro.ru", "phone": "+70134730629"}
0005434300187	E4713E	3075 680949	ANNA ROMANOVA	{"phone": "+70766309124"}
0005434300188	CB090C	2684 086073	OKSANA SEMENOVA	{"email": "semenova_oksana_1969@postgrespro.ru", "phone": "+70569563050"}
0005434300189	25340F	3854 014354	VLADIMIR MAKAROV	{"email": "makarov_v-111960@postgrespro.ru", "phone": "+70321606972"}
0005434300190	43BBCD	6378 814485	ARTEM NOVIKOV	{"email": "artem_novikov-1962@postgrespro.ru", "phone": "+70725118926"}
0005434300191	43BBCD	3486 514910	ALINA ABRAMOVA	{"phone": "+70595220269"}
0005434300192	3C34A3	7990 649800	ROZA NIKOLAEVA	{"email": "r.nikolaeva_1980@postgrespro.ru", "phone": "+70884932729"}
0005434300193	63B688	3865 169114	OLGA VOROBEVA	{"email": "vorobeva-olga-23061965@postgrespro.ru", "phone": "+70731068674"}
0005434300194	63B688	2882 003725	IRINA KOZLOVA	{"phone": "+70205474219"}
0005434300195	5B4C30	6032 092020	VALENTINA VOLKOVA	{"email": "volkova.v_24071976@postgrespro.ru", "phone": "+70718569989"}
0005434300196	417EB4	6866 804242	NATALYA KONDRATEVA	{"phone": "+70001969973"}
0005434300197	417EB4	3908 103389	NADEZHDA POLYAKOVA	{"email": "npolyakova.021975@postgrespro.ru", "phone": "+70750007778"}
0005434300198	21FEC3	1521 853352	TATYANA KRASNOVA	{"email": "t_krasnova021968@postgrespro.ru", "phone": "+70584955526"}
0005434300200	FA0D55	6832 270190	ALEKSANDR GERASIMOV	{"phone": "+70881065345"}
0005434300201	626E41	3051 237313	SERGEY NAZAROV	{"email": "snazarov_101961@postgrespro.ru", "phone": "+70573651110"}
0005434300202	9CF7C4	6389 778569	NATALYA MOROZOVA	{"email": "n_morozova10011977@postgrespro.ru", "phone": "+70577695313"}
0005434300203	5000AA	6306 595610	YURIY ABRAMOV	{"email": "abramovyuriy.081969@postgrespro.ru", "phone": "+70290578275"}
0005434300204	59ADFA	1216 220407	VLADIMIR BORISOV	{"phone": "+70295041305"}
0005434300205	8A7B1F	5452 617909	EVGENIY SOKOLOV	{"email": "evgeniysokolov-031970@postgrespro.ru", "phone": "+70988371990"}
0005434300206	8A7B1F	4848 556939	VALENTINA SOKOLOVA	{"email": "sokolova.valentina-1973@postgrespro.ru", "phone": "+70918525780"}
0005434300207	53B6C5	3500 105251	ZINAIDA YAKOVLEVA	{"email": "yakovleva.zinaida.1976@postgrespro.ru", "phone": "+70561511277"}
0005434300208	F364DB	1508 463625	VERA ORLOVA	{"email": "vorlova_121976@postgrespro.ru", "phone": "+70972071494"}
0005434300209	88F1ED	6344 703299	VLADIMIR CHERNOV	{"phone": "+70353214705"}
0005434300210	9FC14E	2635 825378	SVETLANA BORISOVA	{"email": "s-borisova.021962@postgrespro.ru", "phone": "+70459270515"}
0005434300211	04BBAD	6717 590885	VLADIMIR KAZAKOV	{"email": "v_kazakov.081968@postgrespro.ru", "phone": "+70754938865"}
0005434300212	EA6890	8025 095363	YULIYA VASILEVA	{"email": "vasileva_y051985@postgrespro.ru", "phone": "+70838260593"}
0005434300213	30DEAA	9407 187768	RAISA SAVELEVA	{"email": "saveleva_raisa.08081975@postgrespro.ru", "phone": "+70938690489"}
0005434300214	0F7591	7047 250408	TATYANA NIKITINA	{"email": "nikitina.tatyana_011975@postgrespro.ru", "phone": "+70596215068"}
0005434300215	76FC5C	5757 106306	ANNA ROMANOVA	{"email": "a.romanova-121969@postgrespro.ru", "phone": "+70345558068"}
0005434300216	734C9E	1154 687150	ALEKSANDR MAKAROV	{"email": "makarovaleksandr041977@postgrespro.ru", "phone": "+70616476176"}
0005434300217	A15787	9513 904240	ALEKSANDR DMITRIEV	{"phone": "+70322973120"}
0005434300218	A15787	0584 284986	SVETLANA KOZLOVA	{"phone": "+70299551338"}
0005434300219	A650CA	9762 957691	OLEG KOZLOV	{"email": "olegkozlov06021975@postgrespro.ru", "phone": "+70069228325"}
0005434300221	69D9F7	9463 423004	KIRILL NIKITIN	{"phone": "+70647176453"}
0005434300222	7D17F9	4750 264685	ANDREY VOROBEV	{"phone": "+70342737405"}
0005434300223	7D17F9	5606 246632	VLADISLAV KUZNECOV	{"email": "kuznecov_v.041973@postgrespro.ru", "phone": "+70293750563"}
0005434300224	FA4158	3256 873029	POLINA POPOVA	{"phone": "+70120123783"}
0005434300225	CFA88C	5713 763003	ALBERT CHERNOV	{"phone": "+70137022816"}
0005434300226	73B1D3	7878 375695	EVDOKIYA GERASIMOVA	{"email": "gerasimova_e_09121963@postgrespro.ru", "phone": "+70783117205"}
0005434300227	8882DC	9653 213869	ALEKSANDR NIKOLAEV	{"phone": "+70334873363"}
0005434300228	8882DC	1619 349645	MADINA ZOTOVA	{"phone": "+70105199219"}
0005434300229	9B0391	0803 734542	DENIS SOROKIN	{"phone": "+70066610635"}
0005434300230	AFA135	7409 007390	ANNA SCHERBAKOVA	{"phone": "+70048580718"}
0005434300231	AFA135	9861 686417	EKATERINA DMITRIEVA	{"phone": "+70526002340"}
0005434300232	935B7E	0606 670422	NINA KULIKOVA	{"phone": "+70595328590"}
0005434300233	167D55	8485 593344	VLADIMIR IVANOV	{"phone": "+70858050348"}
0005434300234	77CF61	5481 909952	VALENTINA PAVLOVA	{"email": "valentina_pavlova-27071964@postgrespro.ru", "phone": "+70967158752"}
0005434300235	4B5748	3930 709390	LYUDMILA FEDOROVA	{"phone": "+70711550796"}
0005434300236	4B5748	0038 677216	NINA ISAEVA	{"phone": "+70818223614"}
0005434300237	2C231C	0193 266545	TALGAT KUZNECOV	{"email": "kuznecov.t1974@postgrespro.ru", "phone": "+70687632340"}
0005434300238	AC3D44	8344 682575	EKATERINA KISELEVA	{"email": "ekaterina-kiseleva_031979@postgrespro.ru", "phone": "+70409836607"}
0005434300239	C9531B	0825 228639	GALINA NIKOLAEVA	{"email": "nikolaeva_g101979@postgrespro.ru", "phone": "+70176435513"}
0005434300240	C9531B	2760 578312	LARISA ORLOVA	{"phone": "+70746337572"}
0005434300241	C9531B	8058 821991	LYUDMILA NIKITINA	{"email": "l.nikitina-111977@postgrespro.ru", "phone": "+70402533610"}
0005434300242	9D19CE	9328 037224	TATYANA NAUMOVA	{"email": "naumova_t_071979@postgrespro.ru", "phone": "+70667960414"}
0005434300243	9D19CE	2048 259102	ALEKSANDRA VOROBEVA	{"email": "aleksandra.vorobeva_011976@postgrespro.ru", "phone": "+70380746838"}
0005434300244	83C9EB	1970 907914	OLGA GRISHINA	{"email": "olgagrishina_071990@postgrespro.ru", "phone": "+70887859476"}
0005434300245	5C443A	8577 972269	ELENA SOKOLOVA	{"phone": "+70270962000"}
0005434300246	FDE86C	9336 384368	VLADIMIR ALEKSANDROV	{"email": "v_aleksandrov.031978@postgrespro.ru", "phone": "+70228503841"}
0005434300247	44BCA9	5495 030477	VLADIMIR FILIPPOV	{"phone": "+70822506296"}
0005434300248	8B3B87	4037 732411	ANNA MIKHAYLOVA	{"email": "mikhaylova-a-02061971@postgrespro.ru", "phone": "+70652675081"}
0005434300249	BF8900	5861 692247	ELEONORA ZAKHAROVA	{"phone": "+70359148119"}
0005434300250	3AF213	3958 359347	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr_12041969@postgrespro.ru", "phone": "+70082169007"}
0005434300251	5D9949	2718 780615	IGOR POPOV	{"phone": "+70861689439"}
0005434300252	77A653	9916 739975	LYUDMILA SOROKINA	{"email": "lyudmila-sorokina.011972@postgrespro.ru", "phone": "+70387875990"}
0005434300253	825F55	1866 611641	YURIY MAKAROV	{"email": "makarovyuriy-30061964@postgrespro.ru", "phone": "+70693170486"}
0005434300254	93839C	0609 640886	NATALYA ISAEVA	{"email": "natalya.isaeva.021977@postgrespro.ru", "phone": "+70641687135"}
0005434300255	93839C	0313 368482	ELVIRA KUZMINA	{"email": "kuzminaelvira.1968@postgrespro.ru", "phone": "+70187584491"}
0005434300256	93839C	6228 871690	PETR BELOV	{"phone": "+70818039193"}
0005434300257	FF9B19	8876 584765	EVGENIYA MIKHAYLOVA	{"email": "mikhaylova.e_1961@postgrespro.ru", "phone": "+70263458112"}
0005434300258	BFE729	6912 231325	VLADIMIR FEDOTOV	{"phone": "+70698879130"}
0005434300259	BFE729	6730 836983	YULIYA TIKHONOVA	{"phone": "+70490306105"}
0005434300260	9CCF1D	9376 001014	ARTEMIY OSIPOV	{"email": "osipova_121976@postgrespro.ru", "phone": "+70151595331"}
0005434300261	9CCF1D	4221 318929	VLADIMIR KUZNECOV	{"phone": "+70282011993"}
0005434300262	9CCF1D	9108 316032	EKATERINA SMIRNOVA	{"email": "smirnova_ekaterina1959@postgrespro.ru", "phone": "+70159052593"}
0005434300263	8A1D73	1287 080539	ALEKSANDR FILIPPOV	{"phone": "+70148770603"}
0005434300264	DE9A53	2624 478850	VIKTORIYA ANDREEVA	{"phone": "+70723362313"}
0005434300265	76D2CA	2396 190823	TAGIR MAKSIMOV	{"phone": "+70145780476"}
0005434300266	54C77E	0364 057013	IVAN KOROLEV	{"phone": "+70925632411"}
0005434300267	54C77E	9273 170724	SVETLANA SOROKINA	{"phone": "+70904076141"}
0005434300268	C3C579	9271 817448	LARISA SAVELEVA	{"email": "larisa.saveleva15121975@postgrespro.ru", "phone": "+70573723078"}
0005434300269	DFC722	6494 479827	ALEKSANDR KONOVALOV	{"phone": "+70331428699"}
0005434300270	0706B3	8972 399257	ZINAIDA MELNIKOVA	{"email": "melnikovazinaida1976@postgrespro.ru", "phone": "+70125879365"}
0005434300271	0706B3	3412 323097	VIKTOR VLASOV	{"email": "viktor.vlasov-101960@postgrespro.ru", "phone": "+70634020325"}
0005434302493	470B32	9478 773147	ALEKSANDR KUZMIN	{"phone": "+70652082015"}
0005434302381	E66F0E	1839 909668	KLAVDIYA IVANOVA	{"phone": "+70689789177"}
0005434302382	08885E	8979 910356	LARISA ANDREEVA	{"phone": "+70361724829"}
0005434302383	625BB5	2669 761193	VERA MIKHAYLOVA	{"email": "vmikhaylova-101989@postgrespro.ru", "phone": "+70270333356"}
0005434302384	C1FD5E	5310 730981	NIKOLAY VLASOV	{"phone": "+70428641453"}
0005434302385	41FBC9	2919 999893	EVGENIYA KOMAROVA	{"phone": "+70578511297"}
0005434302386	9E0644	2404 678546	VALENTINA BORISOVA	{"email": "vborisova.101983@postgrespro.ru", "phone": "+70792450127"}
0005434302387	9E0644	6210 812097	IGOR YAKOVLEV	{"phone": "+70805865766"}
0005434302388	9548F3	2539 472768	GALINA YUDINA	{"phone": "+70438084715"}
0005434302389	0C02C7	4873 903701	ILYA KUZNECOV	{"phone": "+70536651200"}
0005434302390	0C02C7	0482 451376	NATALIYA DMITRIEVA	{"email": "dmitrieva_nataliya04021976@postgrespro.ru", "phone": "+70839567601"}
0005434302391	EE3D02	5408 747562	ELIZAVETA ISAEVA	{"phone": "+70921302425"}
0005434302392	EE3D02	3228 663442	ALEKSANDR FOMIN	{"email": "afomin-071974@postgrespro.ru", "phone": "+70264302419"}
0005434302393	EE3D02	2062 771580	ROMAN OSIPOV	{"email": "osipov-roman_121959@postgrespro.ru", "phone": "+70411031155"}
0005434302394	0A56AB	9117 237669	ALEKSEY CHERNOV	{"phone": "+70919895974"}
0005434302395	91EC48	8947 960666	GULNARA PAVLOVA	{"phone": "+70093528171"}
0005434302396	36989A	8488 321883	VIKTOR MEDVEDEV	{"phone": "+70919862529"}
0005434302397	36989A	1793 426799	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr011969@postgrespro.ru", "phone": "+70779077029"}
0005434302398	88F1F0	7577 150968	OLEG GAVRILOV	{"email": "o-gavrilov-1974@postgrespro.ru", "phone": "+70009776885"}
0005434302399	B9C470	1690 444720	ZHANNA ALEKSANDROVA	{"email": "aleksandrova_zhanna-26041961@postgrespro.ru", "phone": "+70268298231"}
0005434302400	B9C470	1356 662980	EGOR KOROLEV	{"phone": "+70901248775"}
0005434302401	53A5C4	5731 684745	LYUDMILA YAKOVLEVA	{"email": "l-yakovleva-031964@postgrespro.ru", "phone": "+70428962940"}
0005434302402	B753CC	1076 428717	TATYANA IVANOVA	{"email": "t-ivanova-06051972@postgrespro.ru", "phone": "+70276091224"}
0005434302403	3A518E	7042 021021	ELENA PAVLOVA	{"email": "pavlovaelena1959@postgrespro.ru", "phone": "+70413321178"}
0005434302404	7CACA3	3158 440299	LYUBOV SEMENOVA	{"phone": "+70845296554"}
0005434302405	33FF35	1241 896553	SVYATOSLAV MOROZOV	{"email": "morozov-svyatoslav-18051973@postgrespro.ru", "phone": "+70568725797"}
0005434302406	33FF35	8381 219167	KONSTANTIN CHERNOV	{"phone": "+70414279692"}
0005434302407	2C9C0A	0914 629315	YURIY FROLOV	{"phone": "+70993380900"}
0005434302408	88903F	9785 519238	ELENA BELYAEVA	{"email": "belyaevaelena_1970@postgrespro.ru", "phone": "+70800701928"}
0005434302409	8FFC4E	3511 374577	NINA NIKOLAEVA	{"phone": "+70658284379"}
0005434302410	166E1E	8035 281987	ILNAR PETROV	{"phone": "+70192412125"}
0005434302411	35BA5A	1218 391106	VALERIY SOROKIN	{"phone": "+70793389407"}
0005434302412	06B5F1	5444 127230	ANASTASIYA MELNIKOVA	{"phone": "+70757211398"}
0005434302413	338737	5988 669941	EKATERINA GAVRILOVA	{"phone": "+70613039545"}
0005434302414	338737	9605 161557	YURIY FEDOROV	{"email": "fedorov.yuriy-26011979@postgrespro.ru", "phone": "+70032623539"}
0005434302415	55A609	0798 623467	ALEKSANDR KUZNECOV	{"phone": "+70245856539"}
0005434302416	B70917	1525 108039	TATYANA PETROVA	{"phone": "+70568548802"}
0005434302417	B70917	0533 099671	ALEKSEY KRASNOV	{"email": "aleksey-krasnov-1971@postgrespro.ru", "phone": "+70234194624"}
0005434302418	111A8D	1960 544304	LYUBOV KUZNECOVA	{"phone": "+70157468934"}
0005434302419	104E9C	3677 505881	DENIS AFANASEV	{"email": "afanasevd_1979@postgrespro.ru", "phone": "+70920352381"}
0005434302420	4F4F7D	3531 913965	TATYANA KONDRATEVA	{"phone": "+70842637751"}
0005434302421	754716	7245 700565	EKATERINA ALEKSEEVA	{"phone": "+70106111894"}
0005434302422	C23019	7199 716165	IRINA IVANOVA	{"phone": "+70878668217"}
0005434302423	C23019	8392 415638	NIKOLAY KUZNECOV	{"email": "nkuznecov-05011970@postgrespro.ru", "phone": "+70800349761"}
0005434302424	C23019	5015 328198	IGOR FOMIN	{"phone": "+70202351905"}
0005434302425	45D29D	9955 861809	NIKITA POPOV	{"email": "popov.n061972@postgrespro.ru", "phone": "+70328695769"}
0005434302426	45D29D	4321 315810	VLADIMIR FOMIN	{"email": "fominvladimir_14021978@postgrespro.ru", "phone": "+70732274849"}
0005434302427	0582DC	6943 956796	EKATERINA EGOROVA	{"email": "egorova_e-1976@postgrespro.ru", "phone": "+70968063699"}
0005434302428	DAB52D	7596 925203	ALEKSANDRA BELOVA	{"email": "belova_aleksandra_21031964@postgrespro.ru", "phone": "+70490017742"}
0005434302429	092AD4	0969 802204	VALENTINA VLASOVA	{"phone": "+70106865972"}
0005434302430	1044DF	6400 464195	STANISLAV PETROV	{"email": "spetrov.05031975@postgrespro.ru", "phone": "+70155074431"}
0005434302431	6A2FA9	1599 381444	ELENA KOROLEVA	{"phone": "+70096079915"}
0005434302432	289AE5	3394 184350	LYUDMILA VLASOVA	{"phone": "+70663125008"}
0005434302433	1EE159	7645 466008	SERGEY PAVLOV	{"email": "sergey-pavlov_1973@postgrespro.ru", "phone": "+70690318580"}
0005434302434	1EE159	0449 448277	VALENTINA SIDOROVA	{"phone": "+70421728568"}
0005434302435	46412E	6390 358655	IRINA ORLOVA	{"phone": "+70448955208"}
0005434302436	46412E	0742 961265	NIKITA SIDOROV	{"email": "n.sidorov_1976@postgrespro.ru", "phone": "+70758580154"}
0005434302437	46412E	6445 171889	SVETLANA BELOVA	{"email": "sbelova-061972@postgrespro.ru", "phone": "+70130453657"}
0005434302438	A515B3	0950 611017	NATALIYA SOLOVEVA	{"phone": "+70539097452"}
0005434302439	C78EF1	5098 446340	NIKOLAY EGOROV	{"phone": "+70910594836"}
0005434302440	C78EF1	6110 956909	TAMARA KALININA	{"email": "kalinina_t-101962@postgrespro.ru", "phone": "+70988934956"}
0005434302441	FFFA4C	1354 127312	VIKTORIYA IVANOVA	{"phone": "+70295999090"}
0005434302442	FFFA4C	8534 171663	MARIYA VASILEVA	{"phone": "+70276093414"}
0005434302443	6C65F9	1959 700846	VLADIMIR MAKAROV	{"email": "vladimirmakarov26081962@postgrespro.ru", "phone": "+70733042572"}
0005434302444	577246	0403 219078	ALEKSANDR ALEKSEEV	{"email": "alekseev_a.25011971@postgrespro.ru", "phone": "+70213842295"}
0005434302445	099040	0817 097114	TATYANA VOROBEVA	{"email": "t_vorobeva011974@postgrespro.ru", "phone": "+70661636944"}
0005434302446	31A32A	8232 926470	MAKSIM NIKITIN	{"phone": "+70963895969"}
0005434302447	31A32A	9391 997552	TATYANA VLASOVA	{"email": "tatyanavlasova1968@postgrespro.ru", "phone": "+70630954798"}
0005434302448	CF5271	1848 850503	MAKSIM EGOROV	{"email": "egorov_m.13041972@postgrespro.ru", "phone": "+70271654138"}
0005434302449	5E2CF8	0175 468215	ALEKSANDRA POPOVA	{"phone": "+70529005454"}
0005434302450	5E2CF8	4573 170883	MARINA ANISIMOVA	{"phone": "+70379109331"}
0005434302451	B1A81D	7569 587963	KRISTINA NAUMOVA	{"email": "naumova-k-071964@postgrespro.ru", "phone": "+70840417976"}
0005434302452	B1A81D	0178 802806	VYACHESLAV MOROZOV	{"phone": "+70618712268"}
0005434302453	2B642D	7021 318753	MARIYA SAVELEVA	{"phone": "+70281975974"}
0005434302454	2B642D	5806 132412	MARIYA SMIRNOVA	{"email": "mariya-smirnova_15041987@postgrespro.ru", "phone": "+70622933310"}
0005434302455	2B642D	9544 698918	ELENA KONOVALOVA	{"phone": "+70350237900"}
0005434302456	28D2CA	8515 548260	YURIY GAVRILOV	{"phone": "+70798640661"}
0005434302457	28D2CA	8272 014243	DANIL SCHERBAKOV	{"email": "scherbakov_danil-1975@postgrespro.ru", "phone": "+70165842232"}
0005434302458	E1447F	8309 620029	IVAN YAKOVLEV	{"email": "ivan.yakovlev.29101970@postgrespro.ru", "phone": "+70995771154"}
0005434302459	B9153F	2090 537927	NATALIYA LAZAREVA	{"email": "lazareva-nataliya_1985@postgrespro.ru", "phone": "+70709850348"}
0005434302460	B9153F	6353 308405	ZOYA SIDOROVA	{"phone": "+70891657844"}
0005434302461	94BF80	5214 736290	NIKOLAY MIRONOV	{"email": "nmironov_1949@postgrespro.ru", "phone": "+70547658877"}
0005434302462	CF41EF	2793 051561	VALENTINA SIDOROVA	{"email": "sidorova_valentina121968@postgrespro.ru", "phone": "+70772656400"}
0005434302463	C39B2F	3587 931983	ANASTASIYA KAZAKOVA	{"email": "kazakova-a-19121975@postgrespro.ru", "phone": "+70919165103"}
0005434302464	3CC67D	5208 480854	ALEKSEY ROMANOV	{"email": "a.romanov_1966@postgrespro.ru", "phone": "+70945362049"}
0005434302465	3CC67D	9438 590718	ANNA ROMANOVA	{"phone": "+70011240128"}
0005434302466	3CC67D	3109 915474	OLESYA KOZLOVA	{"phone": "+70436485177"}
0005434302467	1FBE2C	1876 588851	ANATOLIY ABRAMOV	{"email": "anatoliy_abramov18031963@postgrespro.ru", "phone": "+70425726919"}
0005434302468	1FBE2C	0628 673785	NATALYA ZAKHAROVA	{"phone": "+70182127021"}
0005434302469	3753E6	0472 330171	ANTON FEDOTOV	{"email": "fedotov.anton_1978@postgrespro.ru", "phone": "+70622491207"}
0005434302470	79855F	8853 308301	TATYANA STEPANOVA	{"phone": "+70241744162"}
0005434302471	79855F	5741 027755	ROMAN ILIN	{"phone": "+70988134585"}
0005434302472	B25C0D	8674 254174	IVAN VASILEV	{"phone": "+70237916820"}
0005434302473	B25C0D	4945 217672	EGOR GORBUNOV	{"email": "gorbunov.egor18031975@postgrespro.ru", "phone": "+70059701989"}
0005434302474	702B25	7707 530929	TAMARA BELOVA	{"email": "t-belova.1970@postgrespro.ru", "phone": "+70731208343"}
0005434302475	A19466	4596 278711	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov111972@postgrespro.ru", "phone": "+70168591164"}
0005434302476	CE3130	8712 341205	ALEKSANDRA ISAEVA	{"phone": "+70403704855"}
0005434302477	0B4ED1	3728 932686	DMITRIY ANTONOV	{"phone": "+70962368035"}
0005434302478	3E09D8	1148 623662	AYRAT SOKOLOV	{"phone": "+70280973231"}
0005434302479	13C837	1267 615316	TATYANA SMIRNOVA	{"email": "tsmirnova_051984@postgrespro.ru", "phone": "+70743445599"}
0005434302480	13C837	0428 231131	TATYANA ANDREEVA	{"email": "andreevatatyana.1977@postgrespro.ru", "phone": "+70134608593"}
0005434302481	B92D81	0547 181056	VALERIY MOISEEV	{"email": "moiseev-valeriy_081967@postgrespro.ru", "phone": "+70340552418"}
0005434302482	32050D	4018 205865	GALINA KUZNECOVA	{"phone": "+70167570197"}
0005434302483	7DE107	4607 003647	EKATERINA BELYAEVA	{"phone": "+70952329451"}
0005434302484	ED2878	1832 710080	NIKOLAY EGOROV	{"phone": "+70392928677"}
0005434302485	363AC3	4798 176795	SOFYA ISAEVA	{"email": "sofya.isaeva_011969@postgrespro.ru", "phone": "+70184938172"}
0005434302486	CF80B4	4073 763089	SOFYA SAVELEVA	{"phone": "+70996057485"}
0005434302487	2213ED	9779 791663	ANATOLIY MAKAROV	{"email": "makarov-anatoliy.29061976@postgrespro.ru", "phone": "+70365381442"}
0005434302488	58261E	4576 574297	MIKHAIL VASILEV	{"email": "vasilev.mikhail.101965@postgrespro.ru", "phone": "+70164433541"}
0005434302489	91FC31	4000 457652	NIKITA ANTONOV	{"phone": "+70334602667"}
0005434302490	7AF9A7	9481 567097	ANASTASIYA NESTEROVA	{"email": "nesterova-anastasiya_1974@postgrespro.ru", "phone": "+70744263243"}
0005434302491	88C8AD	8700 955887	ELENA SOLOVEVA	{"phone": "+70251135152"}
0005434302492	DDE138	8002 250435	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey05071976@postgrespro.ru", "phone": "+70972469529"}
0005434302494	D1F442	7409 101612	RINAT KUZNECOV	{"email": "kuznecov.r-111979@postgrespro.ru", "phone": "+70853048809"}
0005434302495	D7F773	2207 433107	LYUBOV ISAEVA	{"email": "lyubov-isaeva.1973@postgrespro.ru", "phone": "+70655626620"}
0005434302496	A4C6B6	7266 458935	YULIYA IVANOVA	{"phone": "+70353233431"}
0005434302497	A4C6B6	6722 539428	NATALYA AKIMOVA	{"phone": "+70531728024"}
0005434302498	A4C6B6	1605 739936	ZINAIDA FEDOROVA	{"email": "z.fedorova20021985@postgrespro.ru", "phone": "+70732903139"}
0005434302499	AA88B0	7652 165045	ANDREY FROLOV	{"email": "a.frolov-02061974@postgrespro.ru", "phone": "+70849809411"}
0005434302500	6CB741	9336 236006	LYUDMILA MIKHAYLOVA	{"email": "lyudmila_mikhaylova.24101968@postgrespro.ru", "phone": "+70072863137"}
0005434302501	6CB741	8479 206865	VIKTOR MAKAROV	{"phone": "+70443639554"}
0005434302502	8908BB	0768 919688	LYUDMILA SOKOLOVA	{"email": "l.sokolova09061975@postgrespro.ru", "phone": "+70470171021"}
0005434302503	B01C2A	8784 459239	SVETLANA SOKOLOVA	{"email": "s.sokolova.021966@postgrespro.ru", "phone": "+70657302256"}
0005434302504	8BFE9E	7753 850967	YULIYA ANDREEVA	{"email": "yuliya.andreeva11111979@postgrespro.ru", "phone": "+70778471378"}
0005434302505	8BFE9E	5403 903195	VASILISA NIKOLAEVA	{"email": "nikolaeva.vasilisa.1968@postgrespro.ru", "phone": "+70026820561"}
0005434302506	837226	7476 982009	MARINA PETROVA	{"phone": "+70200988401"}
0005434302507	837226	6283 166785	VASILIY ALEKSEEV	{"phone": "+70742696277"}
0005434302508	A82203	7433 161058	ALEKSANDR ORLOV	{"phone": "+70117633634"}
0005434302509	A82203	6223 684382	ANDREY STEPANOV	{"email": "stepanov.andrey.20121969@postgrespro.ru", "phone": "+70733346299"}
0005434302510	DF9C59	7872 297729	IGOR SMIRNOV	{"phone": "+70534045450"}
0005434302511	DF9C59	6296 061914	LYUDMILA MAKAROVA	{"email": "l.makarova-28111977@postgrespro.ru", "phone": "+70722070401"}
0005434302512	ABD798	8987 791129	YULIYA SOROKINA	{"email": "sorokina_yuliya.29041970@postgrespro.ru", "phone": "+70129431475"}
0005434302513	ABD798	3579 310572	VALERIY MEDVEDEV	{"email": "medvedev_v.011969@postgrespro.ru", "phone": "+70680968444"}
0005434302514	E100EE	0307 822763	DANIIL NAZAROV	{"phone": "+70044056814"}
0005434302515	E100EE	5183 949985	LYUBOV GORBUNOVA	{"phone": "+70590243049"}
0005434302516	C03DC8	3456 718049	VLADIMIR ZHUKOV	{"email": "zhukov.v_1971@postgrespro.ru", "phone": "+70108534966"}
0005434302517	F64AD5	4647 727708	ANNA KAZAKOVA	{"phone": "+70280939054"}
0005434302518	F64AD5	4070 755868	ANASTASIYA ZHUKOVA	{"email": "zhukova_a.24051980@postgrespro.ru", "phone": "+70790817972"}
0005434302519	02928B	9639 952869	KLAVDIYA KONOVALOVA	{"phone": "+70526333012"}
0005434302520	02928B	2869 162500	OLGA IVANOVA	{"email": "o_ivanova.1964@postgrespro.ru", "phone": "+70707277180"}
0005434302521	8C234F	1674 650288	ALEKSEY FILIPPOV	{"phone": "+70157994612"}
0005434302522	8C234F	3657 993842	VIKTOR ZHURAVLEV	{"email": "vzhuravlev_121979@postgrespro.ru", "phone": "+70738819473"}
0005434302523	804B48	6172 105043	VLADIMIR SHEVCHENKO	{"phone": "+70538405881"}
0005434302524	804B48	0800 852615	LILIYA PETROVA	{"email": "petrova_liliya.1968@postgrespro.ru", "phone": "+70296619258"}
0005434302525	02F9CD	4453 458757	ALEKSANDR NIKITIN	{"phone": "+70844759194"}
0005434302526	E21812	1944 823955	VALERIY ZAYCEV	{"phone": "+70746686337"}
0005434302527	E21812	5071 951986	ANASTASIYA SOKOLOVA	{"phone": "+70681832864"}
0005434302528	2B42F8	5014 264090	VALENTINA ERMAKOVA	{"email": "v_ermakova-051960@postgrespro.ru", "phone": "+70815748886"}
0005434302529	F13A37	9450 120078	OLGA BELOVA	{"email": "belova_o_111973@postgrespro.ru", "phone": "+70519454517"}
0005434302530	F13A37	8320 001110	SVETLANA CHERNOVA	{"phone": "+70961857601"}
0005434302531	41A689	5974 339343	VALENTINA GORBUNOVA	{"email": "v-gorbunova_1971@postgrespro.ru", "phone": "+70850790279"}
0005434302532	41A689	8894 624912	IVAN SCHERBAKOV	{"email": "ivan.scherbakov11091982@postgrespro.ru", "phone": "+70625987528"}
0005434302533	773EFC	5073 685001	GALINA GERASIMOVA	{"email": "gerasimova_g-02011967@postgrespro.ru", "phone": "+70081129779"}
0005434302534	773EFC	6806 925432	ELENA NIKITINA	{"email": "elena_nikitina28071979@postgrespro.ru", "phone": "+70857904237"}
0005434302535	BB65E8	7598 550965	BORIS STEPANOV	{"email": "stepanov.boris-031975@postgrespro.ru", "phone": "+70041815791"}
0005434302536	BF87C7	4286 738510	RITA ANTONOVA	{"phone": "+70896945211"}
0005434302537	B9A16C	1512 771109	NADEZHDA ZOTOVA	{"email": "n-zotova_12061977@postgrespro.ru", "phone": "+70580742834"}
0005434302538	2D6D90	3801 026016	SERGEY MIRONOV	{"phone": "+70529135364"}
0005434302539	2D6D90	0343 778986	PRASKOVYA SOKOLOVA	{"email": "praskovyasokolova-13051975@postgrespro.ru", "phone": "+70675241057"}
0005434302540	F73171	9159 397819	ANTON ALEKSEEV	{"phone": "+70370756236"}
0005434302541	F73171	8372 607917	NINA SEMENOVA	{"email": "nina-semenova.14121971@postgrespro.ru", "phone": "+70829873000"}
0005434302542	0445A4	9156 954620	ILYA KUZNECOV	{"phone": "+70100796384"}
0005434302543	0445A4	5490 058578	ALEKSANDR KUZNECOV	{"phone": "+70957516949"}
0005434302544	0445A4	0359 154097	DENIS NOVIKOV	{"phone": "+70195616712"}
0005434302545	EC3729	5527 884815	ARINA OSIPOVA	{"phone": "+70961750632"}
0005434302546	EC3729	6431 140722	OLGA BELYAEVA	{"phone": "+70940770051"}
0005434302547	7783E9	0437 687070	TIMOFEY SERGEEV	{"email": "sergeev_t_011961@postgrespro.ru", "phone": "+70711205115"}
0005434302548	5A0DBE	7210 501792	OLGA NIKITINA	{"phone": "+70145820850"}
0005434302549	96DAEC	8835 790658	NINA SOROKINA	{"phone": "+70111340229"}
0005434302550	96DAEC	7674 022993	EKATERINA LAZAREVA	{"email": "lazareva_e.101979@postgrespro.ru", "phone": "+70590944627"}
0005434302551	96DAEC	9064 001832	OLGA FILIPPOVA	{"phone": "+70526450405"}
0005434302552	6C0711	4179 717798	YULIYA PETROVA	{"phone": "+70418329487"}
0005434302553	4BD6C8	0286 613833	YULIYA FOMINA	{"email": "y_fomina061979@postgrespro.ru", "phone": "+70177168066"}
0005434302554	2B6AAF	3353 538236	OLGA LEBEDEVA	{"email": "o_lebedeva031977@postgrespro.ru", "phone": "+70303482855"}
0005434302555	E3C14E	3741 354373	IGOR BORISOV	{"phone": "+70324924911"}
0005434302556	7616E1	9000 542221	OLGA SOROKINA	{"phone": "+70190455579"}
0005434302557	0F8A31	7201 564597	ANATOLIY ZAKHAROV	{"phone": "+70280638766"}
0005434302558	C2AEDE	4675 896025	ALEKSEY FROLOV	{"phone": "+70506544069"}
0005434302559	C2AEDE	9730 524212	NINA KRASNOVA	{"phone": "+70143550130"}
0005434302560	BA1B22	0027 300504	ARINA MAKSIMOVA	{"email": "a-maksimova101975@postgrespro.ru", "phone": "+70247916376"}
0005434302561	BA1B22	4554 429464	NINA DANILOVA	{"email": "n.danilova1973@postgrespro.ru", "phone": "+70333186274"}
0005434302562	6226AD	9646 687725	MARGARITA BOGDANOVA	{"email": "margarita_bogdanova_101975@postgrespro.ru", "phone": "+70683568682"}
0005434302563	313331	9197 729791	NATALYA SOKOLOVA	{"email": "sokolova-n.1975@postgrespro.ru", "phone": "+70271377948"}
0005434302564	313331	2080 714589	YURIY VASILEV	{"phone": "+70741689350"}
0005434302565	F90AC5	7494 399555	VIKTOR KUZNECOV	{"phone": "+70795578345"}
0005434302566	1DF917	8317 578303	KSENIYA SOROKINA	{"phone": "+70836533167"}
0005434302567	B2C2EB	5031 201944	YURIY FROLOV	{"email": "y_frolov.071967@postgrespro.ru", "phone": "+70693412638"}
0005434302568	A71EE4	7379 388705	SARIYA MEDVEDEVA	{"phone": "+70375643788"}
0005434302569	FFD2C5	2310 605943	ZINAIDA SEMENOVA	{"phone": "+70624799599"}
0005434302570	D4C2E6	7216 018508	IVAN ALEKSANDROV	{"phone": "+70360285866"}
0005434302571	D4C2E6	8400 508060	ANASTASIYA ILINA	{"email": "a_ilina.061971@postgrespro.ru", "phone": "+70761391797"}
0005434302572	35FF04	3363 938725	DIANA KUZNECOVA	{"phone": "+70433863930"}
0005434302573	3C5844	3938 231295	KIRILL KULIKOV	{"email": "kulikov_k-21081974@postgrespro.ru", "phone": "+70022509035"}
0005434302574	6882DF	7089 073969	ELENA ALEKSEEVA	{"email": "elena-alekseeva-051967@postgrespro.ru", "phone": "+70930151067"}
0005434302575	434091	8052 461281	RUSLAN NOVIKOV	{"phone": "+70061456990"}
0005434302576	434091	7399 287813	DARYA IVANOVA	{"phone": "+70875117278"}
0005434302577	B38124	8103 003676	SOFIYA GERASIMOVA	{"phone": "+70527355849"}
0005434302578	F186A5	5496 526216	KAPITALINA KULIKOVA	{"email": "kapitalina.kulikova26031972@postgrespro.ru", "phone": "+70720755881"}
0005434302579	9981C1	6937 580737	ANDREY MELNIKOV	{"email": "melnikov.andrey-1968@postgrespro.ru", "phone": "+70159278004"}
0005434302580	96BD00	8847 684006	NATALYA KOROLEVA	{"email": "koroleva-natalya021969@postgrespro.ru", "phone": "+70143479638"}
0005434302581	9EB926	5800 854477	GENNADIY IVANOV	{"email": "g.ivanov14101975@postgrespro.ru", "phone": "+70869161608"}
0005434302853	AD1AAD	3174 535584	ALBINA NAZAROVA	{"email": "nazarova_albina.29101969@postgrespro.ru", "phone": "+70165957028"}
0005434302854	D7009A	0199 106151	DMITRIY VOLKOV	{"email": "dmitriy.volkov-1980@postgrespro.ru", "phone": "+70942618999"}
0005434302855	3CE2AF	8470 146941	MARIYA SCHERBAKOVA	{"phone": "+70827587658"}
0005434302856	588AD4	4848 424665	SVETLANA ZAKHAROVA	{"phone": "+70769459269"}
0005434302857	EDACC4	0830 778275	GENNADIY CHERNOV	{"phone": "+70677640178"}
0005434302858	0B490D	3849 498158	GALINA NOVIKOVA	{"email": "novikova.g26111977@postgrespro.ru", "phone": "+70654529825"}
0005434302859	9E60DE	3958 496282	LIDIYA KONDRATEVA	{"phone": "+70655231557"}
0005434302860	9E60DE	9840 126115	ALEKSANDR KUZNECOV	{"email": "kuznecov-a041977@postgrespro.ru", "phone": "+70722779723"}
0005434302861	9E60DE	1076 909433	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.1978@postgrespro.ru", "phone": "+70837870902"}
0005434302862	CFA60A	7366 539504	KSENIYA ALEKSEEVA	{"email": "kalekseeva-19011982@postgrespro.ru", "phone": "+70631650619"}
0005434302863	221F71	2388 694508	ALEKSANDR ILIN	{"phone": "+70580624820"}
0005434302864	221F71	5880 479616	SERGEY MOROZOV	{"phone": "+70110948772"}
0005434302865	080706	5511 986612	TATYANA SERGEEVA	{"phone": "+70214493137"}
0005434302866	080706	4487 301917	ILYA TARASOV	{"phone": "+70067822349"}
0005434302867	1B368F	0630 095856	MAKSIM IVANOV	{"phone": "+70504788858"}
0005434302868	1B368F	6791 284379	NATALYA KARPOVA	{"email": "n_karpova_01041983@postgrespro.ru", "phone": "+70739961723"}
0005434302869	306A29	2495 089515	KRISTINA MAKAROVA	{"phone": "+70129441691"}
0005434302870	91719B	2714 072187	ALEKSEY SOKOLOV	{"email": "sokolov_aleksey-07081971@postgrespro.ru", "phone": "+70847630952"}
0005434302871	AEAB8E	7142 051760	LYUBOV DMITRIEVA	{"phone": "+70030092269"}
0005434302872	AEAB8E	4151 093310	OLGA ALEKSANDROVA	{"email": "olga.aleksandrova_1970@postgrespro.ru", "phone": "+70545825065"}
0005434302873	32A3EB	3609 749193	IGOR KUZMIN	{"email": "igor.kuzmin.22111973@postgrespro.ru", "phone": "+70427742778"}
0005434302874	32A3EB	0110 850731	VASILIY POPOV	{"email": "popov-v.10081972@postgrespro.ru", "phone": "+70586871348"}
0005434302875	BC8E03	8913 616246	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.a041967@postgrespro.ru", "phone": "+70492752826"}
0005434302876	BC8E03	4805 325385	NATALYA KOZLOVA	{"email": "kozlova_natalya-17111969@postgrespro.ru", "phone": "+70313662777"}
0005434302877	7683D6	1618 116636	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov101978@postgrespro.ru", "phone": "+70099969239"}
0005434302878	7683D6	8780 651576	ALENA KALININA	{"email": "a.kalinina_1975@postgrespro.ru", "phone": "+70422517939"}
0005434302879	88952A	1431 798327	ANNA FILIPPOVA	{"email": "filippovaa13111977@postgrespro.ru", "phone": "+70283108398"}
0005434302880	7F485A	4291 447077	ANTONINA DAVYDOVA	{"email": "davydova.a.04051967@postgrespro.ru", "phone": "+70859811255"}
0005434302881	4D0F73	0373 774069	EVGENIY VOROBEV	{"email": "vorobev_evgeniy-02061963@postgrespro.ru", "phone": "+70896708604"}
0005434302882	4D0F73	9475 730393	ALEKSANDR SOROKIN	{"phone": "+70753919019"}
0005434302883	9030BE	1787 908871	OLGA KARPOVA	{"email": "olga_karpova-1961@postgrespro.ru", "phone": "+70329068208"}
0005434302884	9576DF	2054 487564	ALEKSANDRA MELNIKOVA	{"phone": "+70717398099"}
0005434302885	A87EF0	4080 104967	IRINA IVANOVA	{"email": "i-ivanova121977@postgrespro.ru", "phone": "+70837226351"}
0005434302886	715240	8031 885951	KAMILA NIKITINA	{"email": "k.nikitina.031981@postgrespro.ru", "phone": "+70724044353"}
0005434302887	B7311C	6508 706324	VIKTORIYA POPOVA	{"phone": "+70290417685"}
0005434302888	B7311C	3806 057332	NIKOLAY MEDVEDEV	{"email": "n_medvedev_24091972@postgrespro.ru", "phone": "+70915837493"}
0005434302889	96FA9F	0751 689235	ARINA SEMENOVA	{"email": "asemenova.26051973@postgrespro.ru", "phone": "+70351830426"}
0005434302890	96FA9F	1251 723174	ROMAN KARPOV	{"email": "karpov-r_061973@postgrespro.ru", "phone": "+70135648524"}
0005434302891	54C85B	8830 027993	ANNA LAZAREVA	{"email": "lazareva.a.1973@postgrespro.ru", "phone": "+70646061390"}
0005434302892	3044E8	3464 380061	IRINA VOLKOVA	{"phone": "+70258083894"}
0005434302893	CDA271	6837 092650	NINA ZAKHAROVA	{"email": "zakharovan031974@postgrespro.ru", "phone": "+70632061878"}
0005434302894	94C65C	7928 439790	ANTONINA LAZAREVA	{"email": "lazareva.a-08041969@postgrespro.ru", "phone": "+70253463689"}
0005434302895	E4B041	5795 890901	GALINA KONOVALOVA	{"email": "konovalova_g1964@postgrespro.ru", "phone": "+70202506536"}
0005434302896	3893A8	1756 148282	ROZA EGOROVA	{"email": "roza_egorova_011976@postgrespro.ru", "phone": "+70353076532"}
0005434302897	E5AE4D	2607 494423	SERGEY NAUMOV	{"email": "naumov-s-16021974@postgrespro.ru", "phone": "+70910817993"}
0005434302898	6E1B90	8792 089161	NADEZHDA CHERNOVA	{"phone": "+70917856329"}
0005434302899	D9F987	7150 841939	ARTUR KULIKOV	{"email": "kulikov-a_091969@postgrespro.ru", "phone": "+70305857973"}
0005434302900	D9F987	7863 618050	DARYA ZHUKOVA	{"email": "zhukova_darya_25061974@postgrespro.ru", "phone": "+70535262265"}
0005434302901	FDFE8C	5185 944218	OLEG KUZNECOV	{"email": "o_kuznecov-1971@postgrespro.ru", "phone": "+70226330772"}
0005434302902	98C5A4	8184 301159	LYUDMILA ORLOVA	{"email": "lorlova1976@postgrespro.ru", "phone": "+70510792790"}
0005434302903	AF3AFB	1586 211375	VLADIMIR ZAYCEV	{"phone": "+70699880848"}
0005434302904	3E7B8C	7477 501719	SERGEY MOROZOV	{"email": "morozovs.041977@postgrespro.ru", "phone": "+70253485447"}
0005434302905	0D92F2	3261 496216	OLEG FROLOV	{"phone": "+70508687433"}
0005434302906	FFEDBB	2868 875050	ALEKSEY TIMOFEEV	{"email": "a_timofeev.1967@postgrespro.ru", "phone": "+70524393707"}
0005434302907	FFEDBB	9726 061874	SVETLANA ANISIMOVA	{"email": "s.anisimova.1963@postgrespro.ru", "phone": "+70318690751"}
0005434302908	628E38	6367 811778	NATALYA LAZAREVA	{"email": "natalya-lazareva_05021969@postgrespro.ru", "phone": "+70522959144"}
0005434302909	628E38	7241 600416	STANISLAV VASILEV	{"phone": "+70624082085"}
0005434302910	649E7B	6077 601056	ANTONIDA KUDRYASHOVA	{"phone": "+70101257836"}
0005434309993	40051B	9223 906425	VITALIY NOVIKOV	{"phone": "+70006583832"}
0005434309500	F0478D	8691 210734	ROZA KOROLEVA	{"phone": "+70725012704"}
0005434309501	F36AB3	1886 996003	ANDREY KARPOV	{"phone": "+70317588459"}
0005434309502	28F3C2	1193 278843	VIKTOR GUSEV	{"email": "vgusev.08101967@postgrespro.ru", "phone": "+70984314641"}
0005434309503	28F3C2	6012 187394	KAMILLA OSIPOVA	{"phone": "+70688247519"}
0005434309504	A90BC5	6971 574457	OLGA ANTONOVA	{"phone": "+70883111235"}
0005434309505	C1645A	8511 663800	MIKHAIL KULIKOV	{"phone": "+70722249252"}
0005434309506	5FA34E	9804 618979	MARIYA KOZLOVA	{"email": "kozlova_m.30031979@postgrespro.ru", "phone": "+70201898445"}
0005434309507	A497EA	7397 641065	OLGA MIKHAYLOVA	{"phone": "+70801232701"}
0005434309508	D78177	1337 529630	ALEKSANDR FEDOTOV	{"email": "a-fedotov_08121972@postgrespro.ru", "phone": "+70150178438"}
0005434309509	D78177	0396 071556	YULIYA KOROLEVA	{"email": "yuliya_koroleva031964@postgrespro.ru", "phone": "+70824279688"}
0005434309510	176BC8	4000 042749	VLADIMIR TARASOV	{"email": "vtarasov_1971@postgrespro.ru", "phone": "+70909121401"}
0005434309511	176BC8	2806 669478	IRINA PAVLOVA	{"email": "pavlovai121982@postgrespro.ru", "phone": "+70624925814"}
0005434309512	9CFE59	6398 044434	OLGA FROLOVA	{"email": "olgafrolova-03111968@postgrespro.ru", "phone": "+70647518982"}
0005434309513	9CFE59	0249 561281	ALEKSANDR NAZAROV	{"email": "nazarov_a-021970@postgrespro.ru", "phone": "+70205098895"}
0005434309514	36CB70	0662 687717	VERA GERASIMOVA	{"phone": "+70433464149"}
0005434309515	FBF845	8684 139155	DMITRIY KUZNECOV	{"phone": "+70681478310"}
0005434309516	FBF845	1625 865045	OLEG MATVEEV	{"phone": "+70252429044"}
0005434309517	CDCA3D	3426 958157	NATALYA SERGEEVA	{"email": "sergeeva.n-1974@postgrespro.ru", "phone": "+70758743297"}
0005434309518	CDCA3D	3120 647460	SVETLANA IVANOVA	{"email": "s_ivanova27121978@postgrespro.ru", "phone": "+70466082776"}
0005434309519	CDCA3D	7417 903693	DENIS MAKAROV	{"email": "makarovd.071983@postgrespro.ru", "phone": "+70560171370"}
0005434309520	4A3DE8	0341 028144	LEV TARASOV	{"email": "l-tarasov041982@postgrespro.ru", "phone": "+70163480737"}
0005434309521	EF368A	4480 613920	SERGEY ZHURAVLEV	{"phone": "+70898593321"}
0005434309522	399F21	4061 110380	ANNA ANTONOVA	{"email": "antonova.anna04021969@postgrespro.ru", "phone": "+70265666659"}
0005434309523	C45AE3	3343 577075	SVETLANA MAKAROVA	{"email": "makarovasvetlana_06011977@postgrespro.ru", "phone": "+70965444639"}
0005434309524	C0001E	6055 825215	SERGEY SOLOVEV	{"email": "s_solovev1974@postgrespro.ru", "phone": "+70411252266"}
0005434309525	C0001E	5493 752106	SVETLANA IVANOVA	{"email": "ivanova.s031968@postgrespro.ru", "phone": "+70890480393"}
0005434309526	CE1382	1121 380365	ROZALIYA VLASOVA	{"phone": "+70146154033"}
0005434309527	CE1382	2065 433559	OLGA LAZAREVA	{"phone": "+70086934025"}
0005434309528	CE1382	6162 273292	VALENTINA FADEEVA	{"phone": "+70809191824"}
0005434309529	CE1382	8696 138255	VLADIMIR KONOVALOV	{"email": "konovalovv021960@postgrespro.ru", "phone": "+70029410306"}
0005434309530	C167FF	6759 359873	TATYANA SAVELEVA	{"phone": "+70901575982"}
0005434309531	E233DB	6800 415072	VALERIY DENISOV	{"email": "denisov.valeriy_101970@postgrespro.ru", "phone": "+70671515116"}
0005434309532	CB3606	5363 309078	LIDIYA SIDOROVA	{"email": "l_sidorova.1979@postgrespro.ru", "phone": "+70968193363"}
0005434309533	CB3606	4754 217641	IRINA MASLOVA	{"phone": "+70263622304"}
0005434309534	6CA2C0	1017 373160	EKATERINA GAVRILOVA	{"phone": "+70320135530"}
0005434309535	55A5D3	6309 962606	RAISA MIKHAYLOVA	{"phone": "+70878894285"}
0005434309536	BB2FE3	2533 389160	VIKTOR PETROV	{"phone": "+70917626835"}
0005434309537	BB2FE3	8152 505223	IRINA SEMENOVA	{"phone": "+70409716941"}
0005434309538	54B8F7	2494 958448	VYACHESLAV KAZAKOV	{"phone": "+70321839093"}
0005434309539	7F223A	5884 500011	LYUDMILA EGOROVA	{"phone": "+70244854461"}
0005434309540	7F223A	6718 797289	IRINA BORISOVA	{"email": "i-borisova.23011972@postgrespro.ru", "phone": "+70980589916"}
0005434309541	C685D0	3173 939003	MARINA IVANOVA	{"phone": "+70580564199"}
0005434309542	C685D0	7355 168542	VALENTINA ROMANOVA	{"phone": "+70983002835"}
0005434309543	A44CAB	8957 307697	MARGARITA KUZNECOVA	{"phone": "+70571244110"}
0005434309544	AFB5F3	7907 150515	ANDREY ANDREEV	{"phone": "+70831692753"}
0005434309545	519405	3254 715143	ANNA ERMAKOVA	{"phone": "+70975207388"}
0005434309546	E7AD71	3829 683460	VYACHESLAV KONOVALOV	{"email": "konovalov-vyacheslav-011968@postgrespro.ru", "phone": "+70788750861"}
0005434309547	E7AD71	3318 989516	DANIIL SOLOVEV	{"email": "solovev_d-061968@postgrespro.ru", "phone": "+70695232373"}
0005434309548	C5C527	1347 476691	DANIIL KONOVALOV	{"email": "d_konovalov101976@postgrespro.ru", "phone": "+70098933939"}
0005434309549	C552F4	8377 994984	IVAN KULIKOV	{"email": "kulikov_i1970@postgrespro.ru", "phone": "+70661100483"}
0005434309550	349BBA	1584 311700	DENIS SMIRNOV	{"email": "d_smirnov011975@postgrespro.ru", "phone": "+70733925060"}
0005434309551	349BBA	8609 172030	KIRILL MAKAROV	{"phone": "+70079691057"}
0005434309552	6F3C0F	5816 909832	DARYA IVANOVA	{"email": "daryaivanova_07121971@postgrespro.ru", "phone": "+70062453621"}
0005434309553	D735E4	0437 187568	GENNADIY VASILEV	{"email": "gvasilev_031969@postgrespro.ru", "phone": "+70220293414"}
0005434309554	750669	3032 979405	IRINA GUSEVA	{"email": "guseva-i.24111971@postgrespro.ru", "phone": "+70472480521"}
0005434309555	750669	9942 883159	NAIL PAVLOV	{"phone": "+70720810326"}
0005434309556	F36988	0270 431770	ILYAS VOLKOV	{"email": "volkov-i-20041965@postgrespro.ru", "phone": "+70452734908"}
0005434309557	FC8ACB	0238 515846	RAISA KALININA	{"phone": "+70260860951"}
0005434309558	8E1B3F	5866 158859	ANNA MELNIKOVA	{"email": "a-melnikova.1963@postgrespro.ru", "phone": "+70435064452"}
0005434309559	8E1B3F	1682 263442	EKATERINA IVANOVA	{"phone": "+70237684367"}
0005434309560	EBDEA3	8929 109423	VALENTINA FILIPPOVA	{"phone": "+70603092524"}
0005434309561	7EFE78	0431 940015	NATALIYA ANDREEVA	{"email": "andreeva_n.28061976@postgrespro.ru", "phone": "+70436409519"}
0005434309562	7EFE78	4997 341689	YULIYA PETROVA	{"phone": "+70038402297"}
0005434309563	1BBFC9	3948 421554	NIKOLAY IVANOV	{"email": "nikolayivanov_25061968@postgrespro.ru", "phone": "+70021362568"}
0005434309564	5BA43C	8373 531904	IGOR NAUMOV	{"email": "naumovigor-111977@postgrespro.ru", "phone": "+70243429437"}
0005434309565	1BA0B8	6568 532070	INNA YAKOVLEVA	{"email": "iyakovleva.011972@postgrespro.ru", "phone": "+70131064810"}
0005434309566	1BA0B8	0793 221087	SVETLANA MOROZOVA	{"email": "morozova.svetlana1971@postgrespro.ru", "phone": "+70389456553"}
0005434309567	4D4B8B	8587 209924	SOFYA SMIRNOVA	{"phone": "+70552288100"}
0005434309568	4D4B8B	4642 717439	NATALYA LOGINOVA	{"phone": "+70349645254"}
0005434309569	80FC8E	2775 127788	PAVEL ILIN	{"phone": "+70080845570"}
0005434309570	CEFCBC	3960 734256	EKATERINA KOLESNIKOVA	{"phone": "+70870522157"}
0005434309571	14FD57	8609 927468	GALINA PETROVA	{"phone": "+70469563809"}
0005434309572	14FD57	4926 374714	KIRILL OSIPOV	{"email": "osipov-kirill_101970@postgrespro.ru", "phone": "+70092178674"}
0005434309573	55AEC9	8011 076357	TATYANA NIKITINA	{"email": "t-nikitina-15101978@postgrespro.ru", "phone": "+70651417087"}
0005434309574	8BA13D	4321 495911	PETR KISELEV	{"email": "kiselev_petr091975@postgrespro.ru", "phone": "+70002535855"}
0005434309575	BB0989	9142 940651	RAISA VOLKOVA	{"email": "volkova.raisa021975@postgrespro.ru", "phone": "+70138582435"}
0005434309576	478F1B	1644 925598	ANNA PETROVA	{"phone": "+70495397732"}
0005434309577	186865	2761 462927	ALEKSANDR KARPOV	{"phone": "+70694516279"}
0005434309578	E068DA	4157 366964	ARTUR SOLOVEV	{"email": "artur.solovev_1971@postgrespro.ru", "phone": "+70175432226"}
0005434309579	E068DA	3007 671171	MARIYA NIKIFOROVA	{"phone": "+70760752920"}
0005434309580	B7D071	2016 642039	NIKOLAY ZAKHAROV	{"email": "zakharov.n101975@postgrespro.ru", "phone": "+70117841868"}
0005434309581	87C5C6	1568 030092	ALEKSANDR POPOV	{"email": "popovaleksandr101973@postgrespro.ru", "phone": "+70964628056"}
0005434309582	3AD4A5	4737 156599	NIKOLAY ZAKHAROV	{"email": "nikolay-zakharov_22011968@postgrespro.ru", "phone": "+70308575588"}
0005434309583	3AD4A5	2849 858056	EKATERINA SCHERBAKOVA	{"phone": "+70796604252"}
0005434309584	0A65C7	0433 898472	ELENA MOROZOVA	{"phone": "+70047478559"}
0005434309585	064312	3545 262213	VLADIMIR SEMENOV	{"email": "vsemenov.1972@postgrespro.ru", "phone": "+70971869381"}
0005434309586	064312	9461 824421	VLADISLAV VOLKOV	{"email": "volkov_v_20031964@postgrespro.ru", "phone": "+70433671677"}
0005434309587	7BCC6C	5116 713875	SERGEY IVANOV	{"email": "ivanov.sergey-051964@postgrespro.ru", "phone": "+70397392751"}
0005434309588	7BCC6C	3286 747653	VERA DMITRIEVA	{"phone": "+70719895701"}
0005434309589	EA6AF4	4928 200250	SERGEY SEMENOV	{"email": "s-semenov-1960@postgrespro.ru", "phone": "+70333831814"}
0005434309590	3C64A9	1510 698916	ELENA TARASOVA	{"email": "e.tarasova-061978@postgrespro.ru", "phone": "+70262507630"}
0005434309591	B9A074	2754 416809	ELENA MAKAROVA	{"email": "makarovae-1956@postgrespro.ru", "phone": "+70922422104"}
0005434309592	B9A074	9489 878997	LYUDMILA BORISOVA	{"email": "lyudmila-borisova.31031996@postgrespro.ru", "phone": "+70728070935"}
0005434309593	FE1001	4633 639954	DARYA DANILOVA	{"phone": "+70361717869"}
0005434309594	AA9944	5277 611530	TATYANA FROLOVA	{"phone": "+70392820856"}
0005434309595	AA9944	7118 057805	VLADISLAV AFANASEV	{"phone": "+70136779561"}
0005434309596	D92E1F	5617 719238	GALINA GUSEVA	{"email": "g_guseva_25031974@postgrespro.ru", "phone": "+70259851208"}
0005434309597	C50506	9898 301671	STEPAN STEPANOV	{"phone": "+70672814465"}
0005434309598	48428E	6380 893880	ELENA ANTONOVA	{"email": "elena_antonova-15111965@postgrespro.ru", "phone": "+70850685986"}
0005434309599	C89372	6875 072650	ELVIRA FEDOROVA	{"phone": "+70429077719"}
0005434309600	C89372	1909 814716	IVAN ABRAMOV	{"phone": "+70315594593"}
0005434309601	F14A30	0707 331247	TATYANA DAVYDOVA	{"email": "t-davydova_091970@postgrespro.ru", "phone": "+70466231467"}
0005434309602	67CEBE	5714 300074	VALENTINA SCHERBAKOVA	{"email": "v.scherbakova-031963@postgrespro.ru", "phone": "+70740224367"}
0005434309603	71F18D	2015 649933	NAILYA GUSEVA	{"phone": "+70829674630"}
0005434309604	607AB9	4530 952658	TATYANA BORISOVA	{"email": "tborisova.041967@postgrespro.ru", "phone": "+70703147730"}
0005434309605	607AB9	6284 459664	DANIIL ROMANOV	{"email": "d.romanov_1961@postgrespro.ru", "phone": "+70065986502"}
0005434309606	607AB9	5573 223702	TATYANA SOLOVEVA	{"email": "t-soloveva.1981@postgrespro.ru", "phone": "+70776363952"}
0005434309607	A45FA1	7462 761827	VLADIMIR MEDVEDEV	{"phone": "+70138416972"}
0005434309608	DA1853	1910 088837	ARTEM KUZNECOV	{"email": "kuznecov.a.031981@postgrespro.ru", "phone": "+70018511024"}
0005434309609	DA1853	6144 720264	VADIM ROMANOV	{"email": "romanov_v.05091972@postgrespro.ru", "phone": "+70171494868"}
0005434309610	CD5657	7718 112163	RENAT KUZNECOV	{"email": "kuznecov_r.10071964@postgrespro.ru", "phone": "+70920472987"}
0005434309611	CD5657	2717 327378	OLGA FILATOVA	{"phone": "+70710316536"}
0005434309612	F7C494	2758 194273	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.041961@postgrespro.ru", "phone": "+70220228027"}
0005434309613	F7C494	5588 052600	YURIY KUZNECOV	{"phone": "+70095808999"}
0005434309614	61FE89	2237 619797	TATYANA FILATOVA	{"phone": "+70650895470"}
0005434309615	61FE89	1658 851892	SVETLANA SERGEEVA	{"phone": "+70409958311"}
0005434309616	61FE89	0882 879021	SVETLANA TARASOVA	{"email": "s_tarasova.12071976@postgrespro.ru", "phone": "+70327914086"}
0005434309617	D4BD46	1404 130189	VASILIY IVANOV	{"email": "ivanov-v_041969@postgrespro.ru", "phone": "+70037268754"}
0005434309618	32D1FA	2481 994327	TATYANA FILIPPOVA	{"phone": "+70902626667"}
0005434309619	5E5D4F	3260 348862	MIKHAIL SCHERBAKOV	{"email": "mikhail_scherbakov-121970@postgrespro.ru", "phone": "+70351564269"}
0005434309620	FF3BA9	8106 800719	NIKOLAY VOLKOV	{"email": "n.volkov.1974@postgrespro.ru", "phone": "+70537996812"}
0005434309621	FF3BA9	7252 266399	YULIYA ALEKSANDROVA	{"email": "yuliya_aleksandrova-04091980@postgrespro.ru", "phone": "+70977130151"}
0005434309622	FF3BA9	9083 533117	TATYANA ZOTOVA	{"phone": "+70725338375"}
0005434309623	052D65	4397 746863	LYUDMILA ZHURAVLEVA	{"email": "lyudmilazhuravleva-21021967@postgrespro.ru", "phone": "+70257331853"}
0005434309624	019028	5316 048400	GENNADIY ALEKSANDROV	{"email": "g-aleksandrov_1981@postgrespro.ru", "phone": "+70046631221"}
0005434309625	E5F88B	3331 333585	NIKOLAY NIKITIN	{"phone": "+70899024877"}
0005434309626	E5F88B	4802 876512	TAMARA FILIPPOVA	{"email": "filippovatamara.091977@postgrespro.ru", "phone": "+70366890144"}
0005434309627	77C564	3389 703512	IVAN GUSEV	{"email": "gusevivan.081972@postgrespro.ru", "phone": "+70049408400"}
0005434309628	77C564	6998 897210	VIKTOR NAUMOV	{"email": "viktor_naumov_20051981@postgrespro.ru", "phone": "+70418766735"}
0005434309629	D53792	7474 905017	YULIYA SEMENOVA	{"email": "semenova.y_15031966@postgrespro.ru", "phone": "+70564281076"}
0005434309630	90D27D	3451 551580	DMITRIY MELNIKOV	{"email": "d-melnikov_1964@postgrespro.ru", "phone": "+70850392925"}
0005434309631	90D27D	7015 359847	VIKTOR EGOROV	{"phone": "+70222683367"}
0005434309632	938ED3	3710 847002	IRINA SMIRNOVA	{"phone": "+70375023700"}
0005434309633	938ED3	0630 382284	MAKSIM GORBUNOV	{"phone": "+70057417704"}
0005434309634	6A0340	8857 416591	PAVEL FEDOROV	{"email": "p_fedorov_01031979@postgrespro.ru", "phone": "+70715076309"}
0005434309635	6A0340	3256 385720	ANGELINA KUDRYASHOVA	{"email": "akudryashova-031979@postgrespro.ru", "phone": "+70484864634"}
0005434309636	1B210E	9455 427488	ROMAN DENISOV	{"email": "rdenisov1967@postgrespro.ru", "phone": "+70548964584"}
0005434309637	0FB51B	0369 567673	NURIYA SIDOROVA	{"phone": "+70245046002"}
0005434309638	FDA9CF	8898 459383	ANTON MOROZOV	{"phone": "+70020880214"}
0005434309639	ED29A8	9872 793583	YANA DANILOVA	{"email": "yana.danilova1960@postgrespro.ru", "phone": "+70973744591"}
0005434309640	ED29A8	3645 758709	ALEKSEY POPOV	{"email": "popov_a_1977@postgrespro.ru", "phone": "+70890284898"}
0005434309641	ED29A8	7322 495875	SERGEY KUZNECOV	{"email": "s_kuznecov-1962@postgrespro.ru", "phone": "+70228496031"}
0005434309642	19FF7C	1449 509192	VERA VOROBEVA	{"email": "vorobeva_vera-18121972@postgrespro.ru", "phone": "+70316558883"}
0005434309643	4BAFB9	5212 337466	PAVEL SMIRNOV	{"phone": "+70605114668"}
0005434309644	79B3AD	0024 474978	ARTEM KUZMIN	{"phone": "+70816273255"}
0005434309645	F3E959	3356 671424	VYACHESLAV PETROV	{"phone": "+70860003089"}
0005434309646	F3E959	6966 581430	ALINA VASILEVA	{"phone": "+70601432210"}
0005434309647	F85994	6741 972652	MARK SAVELEV	{"email": "m_savelev10071972@postgrespro.ru", "phone": "+70200287743"}
0005434309648	8DC494	8690 411060	EKATERINA MOROZOVA	{"phone": "+70547805910"}
0005434309649	484F3B	3400 876574	ALEKSANDR IVANOV	{"phone": "+70302974404"}
0005434309650	484F3B	7196 734306	VIKTORIYA YUDINA	{"email": "viktoriya.yudina_12091975@postgrespro.ru", "phone": "+70890911725"}
0005434309651	BD2766	5212 226767	ANDREY ANTONOV	{"email": "a-antonov.28071990@postgrespro.ru", "phone": "+70255876273"}
0005434309652	23D94D	6650 253108	ANNA CHERNOVA	{"phone": "+70534108639"}
0005434309653	B3B12D	9631 670693	VIKTOR IVANOV	{"email": "v.ivanov031980@postgrespro.ru", "phone": "+70802086812"}
0005434309654	B3B12D	5612 573648	VLADIMIR GERASIMOV	{"phone": "+70089225605"}
0005434309655	061D68	8652 717639	VLADIMIR KAZAKOV	{"email": "v.kazakov1974@postgrespro.ru", "phone": "+70993296699"}
0005434309656	5337DD	4431 955478	RAISA ARKHIPOVA	{"phone": "+70271121454"}
0005434309994	40051B	7609 818242	TATYANA ALEKSEEVA	{"phone": "+70762448389"}
0005434309657	5337DD	7260 083741	NIKITA FEDOROV	{"email": "nikitafedorov-06041966@postgrespro.ru", "phone": "+70233402682"}
0005434309658	D8D571	3643 796400	VIKTOR ISAEV	{"phone": "+70736349441"}
0005434309659	77C4A8	0883 527209	OLEG PETROV	{"phone": "+70901377977"}
0005434309660	5497F9	2908 332075	LYUDMILA FOMINA	{"email": "l.fomina15061970@postgrespro.ru", "phone": "+70530394395"}
0005434309661	D1C93A	4034 573655	GENNADIY KOROLEV	{"phone": "+70716935997"}
0005434309662	D1C93A	3729 601776	LYUDMILA SEMENOVA	{"email": "lsemenova_04041978@postgrespro.ru", "phone": "+70260014097"}
0005434309663	36D84E	5089 127476	ALEKSEY GORBUNOV	{"email": "alekseygorbunov-10111967@postgrespro.ru", "phone": "+70964924618"}
0005434309664	36D84E	9681 369533	ALEKSANDRA IVANOVA	{"email": "ivanova_aleksandra1964@postgrespro.ru", "phone": "+70995302020"}
0005434309665	6E5BE9	0740 775980	ANDREY ROMANOV	{"email": "andrey.romanov.1977@postgrespro.ru", "phone": "+70265451392"}
0005434309666	6E5BE9	1108 574766	GENNADIY ROMANOV	{"phone": "+70602106519"}
0005434309667	0340E6	3422 873370	ALEKSANDRA ILINA	{"email": "aleksandra-ilina19021965@postgrespro.ru", "phone": "+70892530464"}
0005434309668	0340E6	4912 222376	VALERIYA ISAEVA	{"phone": "+70647553596"}
0005434309669	0340E6	8433 465221	PAVEL ROMANOV	{"email": "p_romanov_061972@postgrespro.ru", "phone": "+70016442407"}
0005434309670	EE062B	6192 333198	YURIY MIRONOV	{"email": "yuriy.mironov_1971@postgrespro.ru", "phone": "+70003674723"}
0005434309671	EE062B	0160 949892	EVGENIY DAVYDOV	{"phone": "+70105522959"}
0005434309672	73818E	2883 285542	ALEKSANDR IVANOV	{"phone": "+70555305576"}
0005434309673	73818E	5551 795233	SERGEY ISAEV	{"phone": "+70590918825"}
0005434309674	DC5CBA	3821 799026	KLARA KRASNOVA	{"email": "krasnova.klara.061984@postgrespro.ru", "phone": "+70780327513"}
0005434309675	F12A56	6167 378611	YANA SAVELEVA	{"email": "savelevayana.041967@postgrespro.ru", "phone": "+70754699050"}
0005434309676	30DCC1	0334 911913	MARINA TROFIMOVA	{"phone": "+70521182471"}
0005434309677	30DCC1	4405 187729	ILYA NIKOLAEV	{"email": "ilya-nikolaev.09051968@postgrespro.ru", "phone": "+70722865842"}
0005434309678	E00A67	5104 167762	MARIYA NAZAROVA	{"email": "m_nazarova.1968@postgrespro.ru", "phone": "+70077021336"}
0005434309679	256634	6463 136685	DMITRIY KAZAKOV	{"email": "d-kazakov121971@postgrespro.ru", "phone": "+70693374819"}
0005434309680	49B2F1	3640 550174	LEONID BORISOV	{"phone": "+70031594675"}
0005434309681	B807A8	7753 584018	LYUDMILA SOKOLOVA	{"phone": "+70636344325"}
0005434309682	B807A8	3399 581482	VLADIMIR ANTONOV	{"phone": "+70118136421"}
0005434309683	5AEF79	6208 794959	ROMAN BELOV	{"email": "roman_belov-19101968@postgrespro.ru", "phone": "+70432191838"}
0005434309684	5AEF79	1283 888014	GALINA SAVELEVA	{"phone": "+70472301468"}
0005434309685	2E1008	0734 757980	NIKOLAY PETROV	{"phone": "+70294127155"}
0005434309686	DBA0E6	2996 594385	MATVEY ILIN	{"email": "ilin_matvey121969@postgrespro.ru", "phone": "+70838926849"}
0005434309687	DBA0E6	6847 126870	SALAVAT BELOV	{"email": "belov.s1984@postgrespro.ru", "phone": "+70209586704"}
0005434309688	28931F	8995 186771	VIKTOR KUDRYASHOV	{"email": "v-kudryashov_091975@postgrespro.ru", "phone": "+70883337820"}
0005434309689	28931F	4801 156314	DMITRIY POPOV	{"phone": "+70732360231"}
0005434309690	EC20C5	7851 940967	VERONIKA PETROVA	{"phone": "+70600840696"}
0005434309691	EA13EC	0162 731751	ALEKSANDR KONOVALOV	{"phone": "+70326408984"}
0005434309692	D69EE6	2268 436641	KIRILL KARPOV	{"email": "kirill.karpov11051982@postgrespro.ru", "phone": "+70186143449"}
0005434309693	840031	2852 747839	ELENA DANILOVA	{"phone": "+70961040585"}
0005434309694	0E0263	1454 992869	ANDREY PAVLOV	{"phone": "+70047907060"}
0005434309695	0E0263	4701 315223	PAVEL NAUMOV	{"email": "pavel.naumov.071970@postgrespro.ru", "phone": "+70161098535"}
0005434309696	430BC0	8710 113320	ILYA ZAKHAROV	{"phone": "+70320053498"}
0005434309697	5736E6	8187 973327	SERGEY BORISOV	{"email": "borisovs1969@postgrespro.ru", "phone": "+70868170869"}
0005434309698	5736E6	2366 841711	ANTON SOLOVEV	{"email": "solovev_anton-061966@postgrespro.ru", "phone": "+70019310150"}
0005434309699	5736E6	3864 094896	ALEKSANDR SERGEEV	{"phone": "+70278461865"}
0005434309700	3C5E63	6904 625212	NIKOLAY KOZLOV	{"email": "n-kozlov17071977@postgrespro.ru", "phone": "+70716220132"}
0005434309701	6BA6C9	3607 389145	MARINA SOKOLOVA	{"email": "sokolovamarina-101972@postgrespro.ru", "phone": "+70777450617"}
0005434309702	024E2D	2910 452292	NIKITA SMIRNOV	{"phone": "+70769153416"}
0005434309703	3DCDC8	3562 854612	NATALYA NAUMOVA	{"phone": "+70667715055"}
0005434309704	F1AEC2	5646 439459	MARIYA RODIONOVA	{"email": "rodionova.mariya_11051984@postgrespro.ru", "phone": "+70671581668"}
0005434309705	F1AEC2	3927 972513	GENNADIY MIKHAYLOV	{"phone": "+70823915344"}
0005434309706	4449B2	7162 852188	ANNA KOVALEVA	{"phone": "+70605460261"}
0005434309707	4449B2	1953 283719	IVAN IVANOV	{"email": "ivanovivan-1976@postgrespro.ru", "phone": "+70091818336"}
0005434309708	4EB241	1369 338187	VIKTOR MAKAROV	{"email": "vmakarov.12061976@postgrespro.ru", "phone": "+70054156016"}
0005434309709	C74BE7	7607 320497	KSENIYA OSIPOVA	{"phone": "+70463782380"}
0005434309710	ED8DE4	3498 951269	NADEZHDA ZAKHAROVA	{"phone": "+70081615308"}
0005434309711	ED8DE4	3424 288572	ALEKSEY KAZAKOV	{"email": "kazakova.09101971@postgrespro.ru", "phone": "+70492065940"}
0005434309712	8B1502	6723 502262	ALENA ZHURAVLEVA	{"email": "zhuravleva_alena_081974@postgrespro.ru", "phone": "+70665422089"}
0005434309713	8B1502	3821 462699	KIRA AKIMOVA	{"email": "akimovakira-1973@postgrespro.ru", "phone": "+70533712867"}
0005434309714	8B1502	3077 532722	GULNAZ FILIPPOVA	{"phone": "+70948457671"}
0005434309715	1DDBC4	2558 177865	MARIYA KOZLOVA	{"email": "kozlova_mariya_1961@postgrespro.ru", "phone": "+70609685446"}
0005434309716	1DDBC4	0822 888537	EKATERINA KUDRYASHOVA	{"email": "e-kudryashova-1962@postgrespro.ru", "phone": "+70049571536"}
0005434309717	B5BDA6	8348 680131	ARTEM BORISOV	{"phone": "+70824952148"}
0005434309718	583051	9518 831212	MARINA KUDRYASHOVA	{"email": "kudryashovamarina_051970@postgrespro.ru", "phone": "+70808776303"}
0005434309719	36B6F4	6538 680112	VLADIMIR NIKITIN	{"email": "vladimir.nikitin-19031970@postgrespro.ru", "phone": "+70812377711"}
0005434309720	28E106	4267 373198	MARIYA SIDOROVA	{"phone": "+70424047080"}
0005434309721	28E106	4071 416819	KRISTINA NOVIKOVA	{"phone": "+70877433790"}
0005434309722	543DA0	4257 222193	NIKOLAY POPOV	{"email": "n-popov091965@postgrespro.ru", "phone": "+70249731891"}
0005434309723	02C3B1	1532 072461	IGOR KUZMIN	{"email": "igor-kuzmin_1966@postgrespro.ru", "phone": "+70961203430"}
0005434309724	02C3B1	8294 939287	IGOR VASILEV	{"email": "vasilev.i071991@postgrespro.ru", "phone": "+70515632740"}
0005434309725	E5FC84	5866 871781	NINA YAKOVLEVA	{"email": "n-yakovleva101955@postgrespro.ru", "phone": "+70606260456"}
0005434309726	74FA5C	9436 080654	NIKOLAY KUDRYASHOV	{"phone": "+70294695849"}
0005434309727	94C871	9602 368203	ALEKSANDR OSIPOV	{"email": "osipovaleksandr.12031962@postgrespro.ru", "phone": "+70877316110"}
0005434309728	5CE897	9764 877299	SERGEY CHERNOV	{"email": "chernov-sergey1966@postgrespro.ru", "phone": "+70146084867"}
0005434309729	2C3369	0883 313035	OKSANA KUZMINA	{"phone": "+70102056749"}
0005434309730	E3FF56	2030 819163	ALEKSANDR DAVYDOV	{"email": "davydovaleksandr061975@postgrespro.ru", "phone": "+70336420392"}
0005434309731	55C7BB	7552 500930	LEONID POPOV	{"email": "popovl.031963@postgrespro.ru", "phone": "+70129271758"}
0005434309732	39EB0D	1868 647430	NATALYA DENISOVA	{"email": "n-denisova-121969@postgrespro.ru", "phone": "+70441328626"}
0005434309733	1B47DD	8498 666401	GENNADIY TIKHONOV	{"phone": "+70499669427"}
0005434309734	C41912	9024 180839	YULIYA ANISIMOVA	{"email": "anisimova_y041957@postgrespro.ru", "phone": "+70634481120"}
0005434309735	341451	0268 833041	NINA NIKOLAEVA	{"email": "nina.nikolaeva.1971@postgrespro.ru", "phone": "+70480238854"}
0005434309736	98CDAB	2593 865027	OLEG ALEKSANDROV	{"phone": "+70972342394"}
0005434309737	4CF4A4	9217 250847	TATYANA KULIKOVA	{"email": "kulikova_t101967@postgrespro.ru", "phone": "+70999501141"}
0005434309738	8B1934	6363 917654	ALINA LAZAREVA	{"email": "lazarevaa.20051978@postgrespro.ru", "phone": "+70393617695"}
0005434309739	8B1934	5204 485834	NINA CHERNOVA	{"phone": "+70564459796"}
0005434309740	6E176F	7443 250647	LYUBOV IVANOVA	{"email": "l_ivanova-28021971@postgrespro.ru", "phone": "+70993080453"}
0005434309741	3E067F	8647 367075	NADEZHDA ALEKSANDROVA	{"email": "aleksandrova-n.081966@postgrespro.ru", "phone": "+70206215834"}
0005434309742	937246	5504 370761	NIKOLAY VOROBEV	{"email": "vorobev-nikolay.27031959@postgrespro.ru", "phone": "+70626500876"}
0005434309743	937246	1319 412290	MIKHAIL SEMENOV	{"email": "mikhail.semenov_18041972@postgrespro.ru", "phone": "+70333011371"}
0005434309744	D80F19	1169 353783	SERGEY NIKOLAEV	{"email": "sergey.nikolaev-1959@postgrespro.ru", "phone": "+70453677656"}
0005434309745	DC31A6	2196 459347	ANTON POPOV	{"email": "popov.a.1972@postgrespro.ru", "phone": "+70324957055"}
0005434309746	DC31A6	6044 766878	OLGA SCHERBAKOVA	{"email": "o-scherbakova.10041954@postgrespro.ru", "phone": "+70409853607"}
0005434309747	5AC8BF	8568 927552	EGOR DMITRIEV	{"email": "dmitrievegor.12111961@postgrespro.ru", "phone": "+70013411069"}
0005434309748	24627D	3575 416963	NIKITA DAVYDOV	{"email": "davydov-nikita_1967@postgrespro.ru", "phone": "+70816146156"}
0005434309749	F94A2A	1548 751865	EVGENIYA NIKOLAEVA	{"phone": "+70892099866"}
0005434309750	CE17E0	0165 233229	ANATOLIY SIDOROV	{"phone": "+70675635310"}
0005434309751	CE17E0	3825 068535	VALENTINA DMITRIEVA	{"phone": "+70765151171"}
0005434309752	E20E59	9542 273071	VIKTOR GERASIMOV	{"email": "gerasimov_viktor.22111962@postgrespro.ru", "phone": "+70136654533"}
0005434309753	153AD3	9995 264884	KLAVDIYA ZHURAVLEVA	{"email": "klavdiya_zhuravleva-18021967@postgrespro.ru", "phone": "+70745932627"}
0005434309754	6CD5EF	3350 317501	KONSTANTIN GAVRILOV	{"email": "gavrilov_k-1970@postgrespro.ru", "phone": "+70132597394"}
0005434309755	97AAE1	9988 835482	TATYANA POPOVA	{"email": "t-popova.03011976@postgrespro.ru", "phone": "+70569535023"}
0005434309756	BCCF18	8497 454486	YULIYA BELOVA	{"phone": "+70687125233"}
0005434309757	C5330C	6348 865764	VALENTINA SERGEEVA	{"email": "valentina_sergeeva.071983@postgrespro.ru", "phone": "+70930460775"}
0005434309758	6F231D	6651 124536	ANNA VLASOVA	{"email": "annavlasova-1981@postgrespro.ru", "phone": "+70599495722"}
0005434309759	9E09D0	0079 557706	YULIYA KUZNECOVA	{"phone": "+70923288302"}
0005434309760	8E8E56	6334 923215	ALEVTINA OSIPOVA	{"email": "osipovaalevtina_041972@postgrespro.ru", "phone": "+70723170577"}
0005434309761	8E8E56	2947 166028	DMITRIY POPOV	{"phone": "+70208732071"}
0005434309762	DB50FA	8616 973374	NATALYA KOZLOVA	{"email": "kozlova_natalya.051974@postgrespro.ru", "phone": "+70498774200"}
0005434309763	1575B2	7551 065047	IRINA RODIONOVA	{"phone": "+70072963789"}
0005434309764	408613	6092 926932	ALEKSANDR DENISOV	{"phone": "+70575743738"}
0005434309765	E14674	0069 399774	ALEKSANDRA KULIKOVA	{"phone": "+70874437315"}
0005434309766	D6C9A6	4202 286432	IRINA FILATOVA	{"email": "filatovairina-1978@postgrespro.ru", "phone": "+70537266437"}
0005434309767	B4D289	0278 130139	MARGARITA SOKOLOVA	{"phone": "+70865085708"}
0005434309768	B4D289	8449 971908	NADEZHDA KULIKOVA	{"email": "kulikovanadezhda.051972@postgrespro.ru", "phone": "+70689696415"}
0005434309769	1A2C2C	4881 092866	ILYA PAVLOV	{"phone": "+70626937142"}
0005434309770	87C38B	9799 489757	DIANA DENISOVA	{"email": "dianadenisova_1970@postgrespro.ru", "phone": "+70082984030"}
0005434309771	28C659	6056 941191	ANASTASIYA IVANOVA	{"email": "ivanova.a14121978@postgrespro.ru", "phone": "+70242196596"}
0005434309772	28C659	3110 410806	NINA NIKOLAEVA	{"phone": "+70424392411"}
0005434309773	DB04EF	0731 919775	ALEKSANDR ZAKHAROV	{"email": "zakharov-a_1966@postgrespro.ru", "phone": "+70866418588"}
0005434309774	DB04EF	4713 054505	ALEKSANDR ZAYCEV	{"phone": "+70229305417"}
0005434309775	242484	8403 995947	ANTON MATVEEV	{"email": "matveev_anton.10011969@postgrespro.ru", "phone": "+70884277873"}
0005434309776	BF9D18	4959 386312	DIANA MELNIKOVA	{"phone": "+70913120715"}
0005434309777	A6BDE1	0879 515745	KLARA SERGEEVA	{"email": "sergeevak-25011978@postgrespro.ru", "phone": "+70679041426"}
0005434309778	A6BDE1	1253 782066	DENIS ZAYCEV	{"email": "denis.zaycev.30031975@postgrespro.ru", "phone": "+70384710149"}
0005434309779	F9F630	4037 331039	ALEKSEY SOROKIN	{"email": "sorokin-aleksey_031975@postgrespro.ru", "phone": "+70244016898"}
0005434309780	F9F630	2573 673136	NADEZHDA KOZLOVA	{"phone": "+70548141716"}
0005434309781	287681	0334 959466	IRINA SIDOROVA	{"phone": "+70379083141"}
0005434309782	EF6B48	3553 585007	TATYANA BELOVA	{"phone": "+70952407016"}
0005434309783	81C015	3766 867088	SERGEY SERGEEV	{"phone": "+70604047748"}
0005434309784	6E542C	6022 896986	TATYANA MIKHAYLOVA	{"email": "mikhaylovatatyana_071973@postgrespro.ru", "phone": "+70260255793"}
0005434309785	0F082E	3933 171991	RUMIYA BELOVA	{"email": "belova-rumiya-25061970@postgrespro.ru", "phone": "+70608489216"}
0005434309786	DA1E6E	4503 389609	MILANA YAKOVLEVA	{"phone": "+70898374169"}
0005434309787	AA0200	0001 799132	SERGEY MEDVEDEV	{"email": "medvedev-s_1987@postgrespro.ru", "phone": "+70404189096"}
0005434309788	BDAB1E	7659 436487	MIKHAIL SHEVCHENKO	{"phone": "+70108792171"}
0005434309789	81C356	8460 794416	ALEKSEY VOLKOV	{"email": "a-volkov_19061965@postgrespro.ru", "phone": "+70920706928"}
0005434309790	E8FAB3	1393 174979	ALBINA ROMANOVA	{"email": "a_romanova1975@postgrespro.ru", "phone": "+70028609336"}
0005434309791	AF0263	2925 599358	RENAT MAKSIMOV	{"email": "maksimov.r.1965@postgrespro.ru", "phone": "+70399080778"}
0005434309792	BE77C7	1908 088011	NATALYA TITOVA	{"phone": "+70129562620"}
0005434309793	CC1D62	3410 960002	MARIYA MATVEEVA	{"phone": "+70661896316"}
0005434309794	732294	2883 982124	NINA DENISOVA	{"phone": "+70785531962"}
0005434309795	18A04A	4613 427631	VERA KONOVALOVA	{"phone": "+70454819710"}
0005434309796	6D76B9	1073 623691	ANTON POPOV	{"email": "popov-a_1978@postgrespro.ru", "phone": "+70288279687"}
0005434309797	6D76B9	9005 058452	SERGEY STEPANOV	{"email": "stepanovs_11091968@postgrespro.ru", "phone": "+70561464478"}
0005434309798	C75BC6	6743 296796	EKATERINA ZAKHAROVA	{"email": "ezakharova_1956@postgrespro.ru", "phone": "+70187855152"}
0005434309799	DFDFB5	1032 102069	VIKTOR KUZNECOV	{"phone": "+70200551680"}
0005434309800	5D2569	7943 835611	MIKHAIL ZHUKOV	{"phone": "+70569936895"}
0005434309801	5D2569	3147 973323	LIDIYA AFANASEVA	{"email": "afanaseva.l-091967@postgrespro.ru", "phone": "+70697773686"}
0005434309802	840E18	4198 871412	NADEZHDA LOGINOVA	{"phone": "+70249667737"}
0005434309803	F2BDE3	2959 199492	MARINA ISAEVA	{"email": "misaeva-1961@postgrespro.ru", "phone": "+70919662771"}
0005434309804	0BC5AE	8067 659066	SVETLANA VASILEVA	{"email": "vasilevasvetlana091970@postgrespro.ru", "phone": "+70520272587"}
0005434309805	38BEE7	0934 779078	ALEKSANDRA KOVALEVA	{"phone": "+70481853526"}
0005434309806	38BEE7	4541 588236	NADEZHDA ABRAMOVA	{"phone": "+70137724200"}
0005434309807	38BEE7	6790 377449	VADIM KOZLOV	{"phone": "+70959763607"}
0005434309808	8A1C2E	6778 269280	IRINA MIRONOVA	{"phone": "+70171513904"}
0005434309809	8A4222	0662 327153	IRINA OSIPOVA	{"email": "osipovai_121969@postgrespro.ru", "phone": "+70851109755"}
0005434309810	8A4222	7575 883465	NATALYA BELYAEVA	{"email": "belyaeva.n101974@postgrespro.ru", "phone": "+70398274989"}
0005434309811	8A4222	1716 364628	MIKHAIL VASILEV	{"email": "mikhailvasilev.021976@postgrespro.ru", "phone": "+70935066951"}
0005434309812	A49588	0308 794208	ELVIRA FILATOVA	{"phone": "+70230620803"}
0005434309813	A49588	8209 090152	ALSU KONOVALOVA	{"phone": "+70248607899"}
0005434309814	724700	0568 532761	MADINA ZHUKOVA	{"phone": "+70086567446"}
0005434309815	2BC1FB	3918 219580	IVAN MIKHAYLOV	{"phone": "+70884487048"}
0005434309816	2BC1FB	8067 012341	EVGENIYA KUZMINA	{"phone": "+70210116145"}
0005434309817	2BC1FB	7855 942792	MARINA SCHERBAKOVA	{"phone": "+70013902662"}
0005434309818	0DDB03	1053 759968	VALERIY BORISOV	{"email": "borisovv_10071966@postgrespro.ru", "phone": "+70362574318"}
0005434309819	6E2764	1820 465953	YURIY NAUMOV	{"email": "naumov-yuriy_1978@postgrespro.ru", "phone": "+70115397956"}
0005434309820	6E2764	4000 420602	MIKHAIL SHEVCHENKO	{"email": "m_shevchenko1972@postgrespro.ru", "phone": "+70318075463"}
0005434309821	6972C4	5005 814494	NIKOLAY IVANOV	{"phone": "+70637822837"}
0005434309822	EA32A5	2400 803725	DMITRIY MELNIKOV	{"phone": "+70143062390"}
0005434309823	EA32A5	3845 258351	VLADIMIR ALEKSEEV	{"phone": "+70126597943"}
0005434309824	7E2299	6096 435683	DMITRIY ZAKHAROV	{"email": "d_zakharov081978@postgrespro.ru", "phone": "+70932650391"}
0005434309825	A25A67	2042 190547	VIKTOR YAKOVLEV	{"email": "viktor_yakovlev_061970@postgrespro.ru", "phone": "+70650518084"}
0005434309826	C3E0AF	6939 562211	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova_a.091978@postgrespro.ru", "phone": "+70480245723"}
0005434309827	E1B2BB	2532 354697	ALEKSEY GERASIMOV	{"phone": "+70153767801"}
0005434309828	04A19D	8907 945042	OLGA CHERNOVA	{"email": "o-chernova23071970@postgrespro.ru", "phone": "+70724443108"}
0005434309829	04A19D	1515 200574	LYUDMILA GORBUNOVA	{"phone": "+70992999720"}
0005434309830	04CD3D	7363 591469	STANISLAV PETROV	{"phone": "+70022380183"}
0005434309831	490792	6899 820521	OLEG KUZNECOV	{"phone": "+70473281167"}
0005434309832	490792	0272 770365	DIANA ANTONOVA	{"email": "diana-antonova061969@postgrespro.ru", "phone": "+70315306658"}
0005434309833	96E4DF	5749 530418	MIKHAIL VOROBEV	{"phone": "+70600645789"}
0005434309834	96E4DF	4896 592130	OLESYA LUKYANOVA	{"phone": "+70478925973"}
0005434309835	96E4DF	4997 715270	SERGEY SHEVCHENKO	{"phone": "+70321989158"}
0005434309836	43D22E	4192 186695	MATVEY PETROV	{"email": "m.petrov_121975@postgrespro.ru", "phone": "+70646378840"}
0005434309837	26AC7F	2761 202030	VIKTOR KONOVALOV	{"email": "vkonovalov-111978@postgrespro.ru", "phone": "+70520222764"}
0005434309838	961A6F	1744 635905	OLGA FEDOROVA	{"phone": "+70984762466"}
0005434309839	474DD6	7228 065897	SERGEY MOROZOV	{"email": "morozov-s-1978@postgrespro.ru", "phone": "+70783337979"}
0005434309840	F1EC67	0909 381853	OLGA MIKHAYLOVA	{"phone": "+70942589606"}
0005434309841	FA9884	1821 359468	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.a_1967@postgrespro.ru", "phone": "+70820903974"}
0005434309842	FA9884	9925 339344	LEONID MEDVEDEV	{"phone": "+70692281104"}
0005434309843	FA9884	0434 915029	MAKSIM MEDVEDEV	{"phone": "+70919188914"}
0005434309844	AE7CF1	5854 472606	FAINA IVANOVA	{"phone": "+70252701570"}
0005434309845	AE7CF1	2737 069906	EKATERINA KONDRATEVA	{"phone": "+70636566967"}
0005434309846	AE7CF1	3969 133762	ANNA ALEKSANDROVA	{"phone": "+70032885524"}
0005434309847	9E0D2F	4744 295492	ALEKSEY MOROZOV	{"email": "aleksey.morozov_031973@postgrespro.ru", "phone": "+70127432727"}
0005434309848	2B6B32	3139 029225	ALEKSANDR ORLOV	{"phone": "+70905686471"}
0005434309849	2B6B32	3132 448041	TATYANA BARANOVA	{"email": "tatyana_baranova-18051973@postgrespro.ru", "phone": "+70794061025"}
0005434309850	2108CA	7470 075011	YURIY EGOROV	{"phone": "+70981710754"}
0005434309851	2108CA	9399 373335	NADEZHDA IVANOVA	{"email": "nadezhda_ivanova_1979@postgrespro.ru", "phone": "+70178211320"}
0005434309852	71D15F	9051 713143	EKATERINA VOLKOVA	{"email": "volkovaekaterina_101966@postgrespro.ru", "phone": "+70759344249"}
0005434309853	71D15F	0125 063740	VALENTINA MARTYNOVA	{"phone": "+70129363065"}
0005434309854	71D15F	1703 880709	ALEKSEY MAKAROV	{"email": "makarov_aleksey.011976@postgrespro.ru", "phone": "+70693282219"}
0005434309855	ABDBC2	1684 969749	NATALYA TIKHONOVA	{"email": "tikhonova-natalya.071962@postgrespro.ru", "phone": "+70779711590"}
0005434309856	B3DAF2	2356 408504	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr1974@postgrespro.ru", "phone": "+70556240397"}
0005434309857	C2EBBD	8417 709681	VLADIMIR ANDREEV	{"email": "andreevvladimir.111961@postgrespro.ru", "phone": "+70728989344"}
0005434309858	0BD7E9	6237 357605	ALEKSEY KISELEV	{"phone": "+70389480462"}
0005434309859	AB9764	0139 827509	ANDREY KISELEV	{"email": "kiselev_andrey_21081976@postgrespro.ru", "phone": "+70093289088"}
0005434309860	30CF90	6647 532662	MAKSIM KUZNECOV	{"phone": "+70311230862"}
0005434309861	625397	3196 450448	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev.081978@postgrespro.ru", "phone": "+70244941021"}
0005434309862	625397	2609 599744	AIDA SIDOROVA	{"email": "a-sidorova-081978@postgrespro.ru", "phone": "+70945987607"}
0005434309863	625397	3227 610866	ALEKSANDR SMIRNOV	{"phone": "+70145418296"}
0005434309864	F9F519	6039 529039	TAMARA MIKHAYLOVA	{"email": "mikhaylovatamara1978@postgrespro.ru", "phone": "+70318800826"}
0005434309865	F9F519	5801 860295	VIKTORIYA KRASNOVA	{"email": "krasnovaviktoriya_1968@postgrespro.ru", "phone": "+70318820794"}
0005434309866	FB49F3	6756 136420	VLADIMIR EGOROV	{"email": "egorov.v1986@postgrespro.ru", "phone": "+70531012075"}
0005434309867	C8307C	6630 860533	VYACHESLAV KOZLOV	{"phone": "+70286153114"}
0005434309868	30E3B4	7460 031101	YANA ZHURAVLEVA	{"email": "zhuravleva_yana-09081986@postgrespro.ru", "phone": "+70138311434"}
0005434309869	4C23DE	9831 482041	ANATOLIY OSIPOV	{"email": "anatoliy_osipov_1975@postgrespro.ru", "phone": "+70633211600"}
0005434309870	4C23DE	2265 651417	ALEKSANDR DMITRIEV	{"phone": "+70901382433"}
0005434309871	E9A44F	1004 959485	ANDREY OSIPOV	{"email": "andrey.osipov.031959@postgrespro.ru", "phone": "+70439092235"}
0005434309872	E9A44F	9800 136780	YURIY KUZMIN	{"phone": "+70461762034"}
0005434309873	795509	8866 215488	MARIYA ROMANOVA	{"phone": "+70484451478"}
0005434309874	A99C30	4016 279773	NIKITA POPOV	{"phone": "+70208262081"}
0005434309875	37E620	7181 878644	OLEG ROMANOV	{"phone": "+70703245214"}
0005434309876	470A90	8899 753304	NINA NIKITINA	{"email": "ninanikitina1986@postgrespro.ru", "phone": "+70743404604"}
0005434309877	CBD735	7479 292840	OLEG FROLOV	{"email": "frolovoleg-12121963@postgrespro.ru", "phone": "+70760038474"}
0005434309878	40A9AD	6021 631426	IRINA ALEKSANDROVA	{"phone": "+70744217735"}
0005434309879	40A9AD	6649 428072	VASILIY KULIKOV	{"phone": "+70722171398"}
0005434309880	BDF838	4827 586493	ARSENIY CHERNOV	{"email": "arseniy_chernov-1964@postgrespro.ru", "phone": "+70913709314"}
0005434309881	BDF838	9676 074661	SOFYA SEMENOVA	{"email": "s.semenova-19091976@postgrespro.ru", "phone": "+70233294800"}
0005434309882	970865	6548 388153	TATYANA MEDVEDEVA	{"email": "medvedeva.tatyana.021971@postgrespro.ru", "phone": "+70908616145"}
0005434309883	CF97F9	2067 102965	YANA VASILEVA	{"phone": "+70133279154"}
0005434309884	CF97F9	5773 844726	GALINA ABRAMOVA	{"email": "abramova_galina1975@postgrespro.ru", "phone": "+70420140677"}
0005434309885	8074A8	8175 553283	STEPAN VOLKOV	{"email": "volkov_s.051972@postgrespro.ru", "phone": "+70673928582"}
0005434309886	677CCE	0185 178205	LYUBOV BOGDANOVA	{"phone": "+70219301192"}
0005434309887	677CCE	9526 785399	ELENA ISAEVA	{"email": "isaeva.elena1977@postgrespro.ru", "phone": "+70897911680"}
0005434309888	B4DF5E	9322 547472	ANATOLIY FOMIN	{"email": "fominanatoliy-28051973@postgrespro.ru", "phone": "+70344164835"}
0005434309889	B4DF5E	5911 169864	VLADIMIR EGOROV	{"email": "v-egorov10011966@postgrespro.ru", "phone": "+70216948002"}
0005434309890	DE5BCE	2599 085923	ALEKSEY VASILEV	{"phone": "+70150763818"}
0005434309891	37CE4B	2096 273129	VALENTINA GAVRILOVA	{"email": "valentina.gavrilova_031971@postgrespro.ru", "phone": "+70322193467"}
0005434309892	207C63	8214 003731	SERGEY ORLOV	{"phone": "+70168063304"}
0005434309893	207C63	7639 511793	KAMIL NOVIKOV	{"phone": "+70232408792"}
0005434309894	C8A993	1655 297184	VALERIY BORISOV	{"email": "borisovvaleriy.1966@postgrespro.ru", "phone": "+70164128092"}
0005434309895	C8A993	8704 606872	DMITRIY VASILEV	{"phone": "+70055378509"}
0005434309896	C8A993	5188 952856	YULIYA NAUMOVA	{"phone": "+70293403431"}
0005434309897	C8A993	9292 397281	SEMEN BONDARENKO	{"email": "bondarenko.s.1978@postgrespro.ru", "phone": "+70183486029"}
0005434309898	1393B0	5427 735479	ALEKSANDR ISAEV	{"phone": "+70440278122"}
0005434309899	1393B0	0972 041934	NIKITA IVANOV	{"phone": "+70241376673"}
0005434309900	DAF815	1316 384200	KONSTANTIN FROLOV	{"phone": "+70188451258"}
0005434309901	EF33BF	3744 637379	ALEKSANDR TIKHONOV	{"phone": "+70093822559"}
0005434309902	D5B4D2	6683 219705	ANNA BELOVA	{"email": "belova_anna_1973@postgrespro.ru", "phone": "+70127511282"}
0005434309903	A34E08	4137 710287	NATALYA IVANOVA	{"phone": "+70780467055"}
0005434309904	07B163	4165 297543	EKATERINA PETROVA	{"email": "petrovae-25031975@postgrespro.ru", "phone": "+70766254665"}
0005434309905	07B163	4168 827152	TATYANA FEDOROVA	{"phone": "+70844200013"}
0005434309906	877752	1361 165049	MIKHAIL KUDRYASHOV	{"email": "mikhail_kudryashov_031970@postgrespro.ru", "phone": "+70728094176"}
0005434309907	A41FB5	1147 447625	LYUDMILA ISAEVA	{"email": "lyudmila_isaeva_1972@postgrespro.ru", "phone": "+70022063490"}
0005434309908	E83E48	3631 392855	MARINA GAVRILOVA	{"email": "marinagavrilova1973@postgrespro.ru", "phone": "+70466327921"}
0005434309909	5EFBBC	8155 230910	SERGEY NIKITIN	{"phone": "+70119115395"}
0005434309910	EA0E0C	5399 883350	ANNA KOROLEVA	{"phone": "+70580577224"}
0005434309911	471B90	3594 795646	ANTONINA MOROZOVA	{"email": "antonina_morozova.081971@postgrespro.ru", "phone": "+70580459530"}
0005434309912	471B90	5418 811011	TATYANA KISELEVA	{"phone": "+70793964359"}
0005434309913	C0C3AD	5211 363239	YULIYA ORLOVA	{"email": "orlovayuliya-06101972@postgrespro.ru", "phone": "+70624111272"}
0005434309914	C0C3AD	6955 429055	ALEKSANDR ANDREEV	{"phone": "+70053937360"}
0005434309915	537CEB	7765 692087	VYACHESLAV KOZLOV	{"email": "kozlov-v.1958@postgrespro.ru", "phone": "+70126710614"}
0005434309916	53E420	5355 875789	TAMARA SAVELEVA	{"email": "savelevat121984@postgrespro.ru", "phone": "+70787045114"}
0005434309917	8518DE	5974 816403	NINA POPOVA	{"phone": "+70035789320"}
0005434309918	8518DE	7756 673095	YULIYA ANTONOVA	{"phone": "+70324645059"}
0005434309919	9C88F3	6824 897266	NATALIYA SMIRNOVA	{"phone": "+70016996803"}
0005434309920	8F95F1	0096 853687	LARISA LAZAREVA	{"email": "l-lazareva_1979@postgrespro.ru", "phone": "+70588246674"}
0005434309921	A3B3DD	9769 092638	VALERIY SEMENOV	{"phone": "+70968566933"}
0005434309922	84A776	9331 350377	ALEKSANDRA BORISOVA	{"phone": "+70152655544"}
0005434309923	85B311	5182 837076	ANDREY NIKOLAEV	{"email": "andrey_nikolaev_121961@postgrespro.ru", "phone": "+70586742876"}
0005434309924	BC16AD	4864 728700	VIKTOR ALEKSANDROV	{"email": "aleksandrov.viktor_14081971@postgrespro.ru", "phone": "+70722326818"}
0005434309925	46151D	1313 865465	IGOR BELOV	{"email": "belovigor1982@postgrespro.ru", "phone": "+70348915693"}
0005434309926	7F4662	3197 787590	NADEZHDA FADEEVA	{"email": "n.fadeeva.13091972@postgrespro.ru", "phone": "+70301551003"}
0005434309927	D5BDC1	3843 577459	DMITRIY SOKOLOV	{"email": "sokolov_dmitriy_031972@postgrespro.ru", "phone": "+70449492369"}
0005434309928	0D10B9	4429 449327	RISHAT BELOV	{"phone": "+70678296128"}
0005434309929	6198DF	0064 463651	EVGENIY SCHERBAKOV	{"email": "evgeniyscherbakov_051973@postgrespro.ru", "phone": "+70079834712"}
0005434309930	6198DF	3189 622912	RAISA MIKHAYLOVA	{"phone": "+70828910954"}
0005434309931	19F853	2070 726510	VITALIY NIKOLAEV	{"email": "vitaliy-nikolaev1965@postgrespro.ru", "phone": "+70137733768"}
0005434309932	EE5DED	4760 007877	ANATOLIY GERASIMOV	{"email": "anatoliy-gerasimov1970@postgrespro.ru", "phone": "+70829870788"}
0005434309933	55588D	2189 719459	ALEKSEY NAZAROV	{"email": "nazarov-a_041988@postgrespro.ru", "phone": "+70518561753"}
0005434309934	55588D	0663 029213	EKATERINA EFIMOVA	{"phone": "+70553257411"}
0005434309935	1D6D34	8083 386721	LIDIYA SOROKINA	{"phone": "+70623027696"}
0005434309936	F35944	5042 505912	MARIYA ZAKHAROVA	{"phone": "+70828568084"}
0005434309937	D5F214	8362 223213	VLADIMIR BORISOV	{"email": "borisov_v_1982@postgrespro.ru", "phone": "+70909344540"}
0005434309938	D5F214	9691 724200	VARVARA KISELEVA	{"phone": "+70870599232"}
0005434309939	E7BA17	5710 238598	TATYANA KOZLOVA	{"phone": "+70576293522"}
0005434309940	6610C1	3865 824057	RENAT ALEKSEEV	{"phone": "+70273579830"}
0005434309941	5D60C4	3386 326037	OLGA KUZNECOVA	{"phone": "+70290746892"}
0005434309942	801430	1880 195802	ALEKSANDR SMIRNOV	{"email": "smirnov.a-041967@postgrespro.ru", "phone": "+70124756805"}
0005434309943	82D7BD	5749 227130	MARIYA YAKOVLEVA	{"email": "myakovleva021990@postgrespro.ru", "phone": "+70756981364"}
0005434309944	828D76	5976 832112	SERGEY BONDARENKO	{"phone": "+70649339456"}
0005434309945	2CE273	1371 237044	OLEG FEDOROV	{"email": "fedorov.oleg-28071963@postgrespro.ru", "phone": "+70986663496"}
0005434309946	2CE273	7846 556002	DANIIL NIKITIN	{"email": "nikitin-d.1967@postgrespro.ru", "phone": "+70590345468"}
0005434309947	4A5E4B	9936 573743	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey-28091971@postgrespro.ru", "phone": "+70338382801"}
0005434309948	4A5E4B	1021 985352	ANGELINA DENISOVA	{"email": "angelina_denisova_1978@postgrespro.ru", "phone": "+70138602070"}
0005434309949	2951A1	9538 202228	ALEKSANDRA POLYAKOVA	{"phone": "+70205976514"}
0005434309950	2951A1	3482 788368	ANTON DMITRIEV	{"email": "admitriev-111973@postgrespro.ru", "phone": "+70686303328"}
0005434309951	04DBFB	0477 808379	DMITRIY FROLOV	{"phone": "+70352052233"}
0005434309952	04DBFB	4083 926394	VALERIYA DANILOVA	{"email": "valeriya-danilova.121975@postgrespro.ru", "phone": "+70245618608"}
0005434309953	04DBFB	3428 915994	GALINA LOGINOVA	{"phone": "+70239603190"}
0005434309954	691A1B	0977 310165	YAN ALEKSANDROV	{"email": "aleksandrov-y_06021964@postgrespro.ru", "phone": "+70241872476"}
0005434309955	6C7CE2	7305 814524	TATYANA NIKITINA	{"phone": "+70480079761"}
0005434309956	6C7CE2	2404 929132	RUSLAN IVANOV	{"phone": "+70150934559"}
0005434309957	9F9756	0310 475283	ANASTASIYA DAVYDOVA	{"phone": "+70607358464"}
0005434309958	E8E4F9	0212 404820	DMITRIY NAUMOV	{"phone": "+70670853721"}
0005434309959	E8E4F9	3900 160679	DENIS MAKSIMOV	{"phone": "+70924121994"}
0005434309960	4E903B	6366 022612	SERGEY POPOV	{"phone": "+70994210837"}
0005434309961	6C8B90	1681 113008	TATYANA ANDREEVA	{"phone": "+70219974270"}
0005434309962	6C8B90	1459 659979	NIKOLAY IVANOV	{"phone": "+70310340144"}
0005434309963	44F880	1855 670933	ANNA KOLESNIKOVA	{"email": "a_kolesnikova.031965@postgrespro.ru", "phone": "+70771652903"}
0005434309964	44F880	2353 168025	PAVEL ISAEV	{"phone": "+70266309430"}
0005434309965	400598	3180 203859	LYUBOV NAUMOVA	{"email": "l_naumova30121988@postgrespro.ru", "phone": "+70859943117"}
0005434309966	83BC7E	2843 500827	VERA KARPOVA	{"email": "karpovav_1983@postgrespro.ru", "phone": "+70894187595"}
0005434309967	D1743F	2712 881764	ELENA ISAEVA	{"email": "isaeva-e-1970@postgrespro.ru", "phone": "+70567674815"}
0005434309968	D1743F	2765 858161	DMITRIY KOZLOV	{"phone": "+70159235056"}
0005434309969	BAD50E	7166 255383	TATYANA SEMENOVA	{"email": "tatyana-semenova.31011976@postgrespro.ru", "phone": "+70973864536"}
0005434309970	BA2FDD	8867 974163	VITALIY KUDRYASHOV	{"phone": "+70236360559"}
0005434309971	930031	1795 644808	TATYANA IVANOVA	{"email": "tatyana.ivanova-26031979@postgrespro.ru", "phone": "+70579778512"}
0005434309972	930031	5344 044974	ALEKSEY KRASNOV	{"email": "krasnov_aleksey11031975@postgrespro.ru", "phone": "+70045294231"}
0005434309973	9921DA	8661 458103	SERGEY AFANASEV	{"email": "afanasev.sergey08041969@postgrespro.ru", "phone": "+70510384716"}
0005434309974	0B5937	0288 036432	ANNA ANTONOVA	{"phone": "+70505692792"}
0005434309975	0B5937	2971 673126	EVGENIY STEPANOV	{"phone": "+70144066082"}
0005434309976	1B5E20	4338 034949	YULIYA MIKHAYLOVA	{"email": "y-mikhaylova_1960@postgrespro.ru", "phone": "+70328740832"}
0005434309977	1B5E20	4463 186396	LYUDMILA SOLOVEVA	{"phone": "+70643389529"}
0005434309978	BB3AF8	2994 825760	EVGENIY POPOV	{"phone": "+70188509442"}
0005434309979	1DF27B	4701 592606	ANASTASIYA ANDREEVA	{"email": "a-andreeva051974@postgrespro.ru", "phone": "+70134310049"}
0005434309980	6D585B	8540 771700	SVETLANA FILIPPOVA	{"email": "svetlanafilippova_011973@postgrespro.ru", "phone": "+70779847955"}
0005434309981	5C0CDB	0883 280051	VALENTINA SERGEEVA	{"email": "vsergeeva-1971@postgrespro.ru", "phone": "+70808983900"}
0005434309982	CA9771	0401 536396	NATALYA RYABOVA	{"phone": "+70685867544"}
0005434309983	732DCF	6151 135613	TATYANA KONOVALOVA	{"email": "tatyana.konovalova_1965@postgrespro.ru", "phone": "+70095098736"}
0005434309984	732DCF	2706 268893	NATALYA POPOVA	{"email": "popova-natalya101973@postgrespro.ru", "phone": "+70041407637"}
0005434309985	9C92C4	4026 781387	GENNADIY PETROV	{"phone": "+70163092830"}
0005434309986	9C92C4	8097 794722	OLGA KAZAKOVA	{"email": "o.kazakova-071965@postgrespro.ru", "phone": "+70615080764"}
0005434309987	ED2CE2	6294 339713	ELENA ROMANOVA	{"email": "romanova-e041968@postgrespro.ru", "phone": "+70548187942"}
0005434309988	7B58FF	9541 565746	KSENIYA ILINA	{"phone": "+70757937936"}
0005434309989	35DE61	6184 594899	IRINA ORLOVA	{"phone": "+70530305282"}
0005434309990	35DE61	9874 143182	ALEKSANDR CHERNOV	{"email": "a.chernov-23101966@postgrespro.ru", "phone": "+70804613755"}
0005434309991	35DE61	2319 918314	ANATOLIY KUZNECOV	{"phone": "+70496202038"}
0005434309992	40051B	1906 021449	POLINA YUDINA	{"email": "yudinap.01021965@postgrespro.ru", "phone": "+70254534626"}
0005434309995	EF4F56	3406 307720	DMITRIY SMIRNOV	{"phone": "+70344611279"}
0005434309996	32FC27	1143 630603	SERGEY GERASIMOV	{"email": "gerasimov.s-27021988@postgrespro.ru", "phone": "+70587478286"}
0005434309997	FCCBF3	4233 498906	VERONIKA KAZAKOVA	{"email": "kazakova_veronika-1978@postgrespro.ru", "phone": "+70972925825"}
0005434309998	4D92CF	2062 901266	ANDREY ROMANOV	{"email": "andrey.romanov-08091962@postgrespro.ru", "phone": "+70296748158"}
0005434309999	F42122	9964 684465	ROMAN NOVIKOV	{"phone": "+70535497559"}
0005434310000	A84049	2724 383450	DENIS MIKHAYLOV	{"email": "denis_mikhaylov1957@postgrespro.ru", "phone": "+70175552679"}
0005434310001	B8046B	5517 727834	ALEKSANDR RODIONOV	{"phone": "+70032624182"}
0005434310002	B8046B	9848 214552	YANA KUZNECOVA	{"phone": "+70618160865"}
0005434310003	369D69	6603 147666	SERGEY KOZLOV	{"phone": "+70083135383"}
0005434310004	48F07A	3595 522593	EGOR ORLOV	{"email": "e_orlov.1973@postgrespro.ru", "phone": "+70971543567"}
0005434310005	CE8BB8	0313 252797	FEDOR FROLOV	{"phone": "+70616605156"}
0005434310006	A776D4	6143 480383	YURIY SOKOLOV	{"email": "sokolovyuriy1976@postgrespro.ru", "phone": "+70617491502"}
0005434310007	760C5D	1191 866362	RUSTAM KUZMIN	{"phone": "+70321450494"}
0005434310008	D6EEB1	0812 227965	VLADIMIR ANDREEV	{"email": "andreev-vladimir_05031967@postgrespro.ru", "phone": "+70395967178"}
0005434310009	B7665A	8503 347232	ALEKSEY IVANOV	{"email": "a_ivanov.11021985@postgrespro.ru", "phone": "+70746131594"}
0005434310010	B7665A	8090 844298	ELENA LEBEDEVA	{"phone": "+70763158006"}
0005434310011	EA91C8	4992 482229	SVETLANA SOKOLOVA	{"phone": "+70703681282"}
0005434310012	EA91C8	2492 163120	IGOR ROMANOV	{"phone": "+70358623856"}
0005434310013	E9F19F	4288 969452	SERGEY ZHUKOV	{"email": "sergey_zhukov-29041971@postgrespro.ru", "phone": "+70165751799"}
0005434310014	B4765B	7790 658801	ALEKSANDR NOVIKOV	{"phone": "+70974041831"}
0005434310015	7469EF	3712 058499	DMITRIY MATVEEV	{"phone": "+70113932371"}
0005434310016	CED97F	0305 035450	ALEKSANDR FOMIN	{"phone": "+70208857832"}
0005434310017	CED97F	8133 639545	NINA TIKHONOVA	{"email": "nina_tikhonova-1966@postgrespro.ru", "phone": "+70864246973"}
0005434310018	C49E4B	5080 980384	NIKOLAY GORBUNOV	{"phone": "+70191259671"}
0005434310019	60FAA6	3409 163727	SVETLANA DAVYDOVA	{"email": "davydova_s_031961@postgrespro.ru", "phone": "+70730977828"}
0005434310020	31EFDD	5946 751966	DENIS BARANOV	{"email": "denis.baranov_071967@postgrespro.ru", "phone": "+70773805942"}
0005434310021	71D4A2	2057 845849	ALEKSANDR SOLOVEV	{"phone": "+70933353727"}
0005434310022	1311B5	6570 441333	NATALYA PAVLOVA	{"phone": "+70864085406"}
0005434310023	ABF7FA	8972 808141	MARINA KUZNECOVA	{"phone": "+70466294500"}
0005434310024	ABF7FA	6517 198076	SERGEY KULIKOV	{"email": "sergey-kulikov17031972@postgrespro.ru", "phone": "+70998172144"}
0005434310025	B73869	7836 562064	YURIY SERGEEV	{"phone": "+70512159536"}
0005434310026	B73869	1557 781520	IRINA EGOROVA	{"email": "irinaegorova.091988@postgrespro.ru", "phone": "+70836914259"}
0005434310027	AB11FD	4807 924708	RAFAIL KAZAKOV	{"phone": "+70068250581"}
0005434310028	07D402	0306 251408	SERGEY KUDRYASHOV	{"phone": "+70065836517"}
0005434310029	2276D1	6379 886001	AMIR MAKAROV	{"email": "amirmakarov.11021982@postgrespro.ru", "phone": "+70494921706"}
0005434310030	E5C50A	6701 585705	EVGENIY GRIGOREV	{"email": "grigoreve.1966@postgrespro.ru", "phone": "+70075913825"}
0005434310031	9D9D3D	0824 489381	ANTON MIKHAYLOV	{"phone": "+70856553610"}
0005434310032	2E43FB	6346 206883	ANASTASIYA ABRAMOVA	{"phone": "+70434652466"}
0005434310033	259384	9131 423073	RAIL GERASIMOV	{"phone": "+70510331987"}
0005434310034	2E2106	7511 630082	ARINA ALEKSANDROVA	{"phone": "+70081561411"}
0005434310035	850361	7502 731197	KSENIYA DENISOVA	{"email": "kseniya-denisova-061967@postgrespro.ru", "phone": "+70728173235"}
0005434310036	05223F	8887 508256	NIKOLAY PAVLOV	{"email": "n.pavlov-1967@postgrespro.ru", "phone": "+70240901139"}
0005434310037	825A82	2438 945399	VALENTIN KISELEV	{"phone": "+70617890306"}
0005434310038	8AFCA8	6341 426908	VLADIMIR TARASOV	{"email": "tarasov-vladimir-101970@postgrespro.ru", "phone": "+70335654842"}
0005434310039	3BF85F	9141 013479	LYUDMILA SEMENOVA	{"phone": "+70794457245"}
0005434310040	3BF85F	9474 984986	SVETLANA GUSEVA	{"phone": "+70301220709"}
0005434310041	84A116	3544 391423	TATYANA SMIRNOVA	{"email": "smirnova-tatyana1972@postgrespro.ru", "phone": "+70891116262"}
0005434310042	871492	1743 867416	VLADIMIR POPOV	{"phone": "+70854466135"}
0005434310043	7B5545	4791 582447	ANNA GRISHINA	{"email": "agrishina-26121975@postgrespro.ru", "phone": "+70148528061"}
0005434310044	630FA8	3592 800912	YURIY BELOV	{"email": "belov.y_121985@postgrespro.ru", "phone": "+70003016143"}
0005434310045	9AE7DE	6406 213549	SERGEY SCHERBAKOV	{"phone": "+70393357616"}
0005434310046	87BCDC	0665 952865	TATYANA SOROKINA	{"phone": "+70496377369"}
0005434310047	034472	0391 630819	ANASTASIYA SOROKINA	{"phone": "+70109049738"}
0005434310048	B68884	5224 159277	MARIYA MARTYNOVA	{"phone": "+70519903846"}
0005434310049	E214A9	6819 537267	TATYANA FROLOVA	{"email": "t.frolova_111972@postgrespro.ru", "phone": "+70890120299"}
0005434310050	E214A9	7557 383356	PAVEL GRIGOREV	{"email": "grigorevpavel10031971@postgrespro.ru", "phone": "+70222711399"}
0005434310051	0E3A8F	4788 326735	VLADIMIR CHERNOV	{"email": "chernov-v.1965@postgrespro.ru", "phone": "+70341639283"}
0005434310052	0E3A8F	2138 391925	ANATOLIY ZAKHAROV	{"email": "azakharov021978@postgrespro.ru", "phone": "+70911641068"}
0005434310053	BC738B	8064 451687	ALEKSANDR SMIRNOV	{"phone": "+70555903944"}
0005434310054	BC738B	5600 974296	VIKTOR NOVIKOV	{"email": "novikov-v1965@postgrespro.ru", "phone": "+70109098378"}
0005434310055	142559	6424 235743	OLGA MOROZOVA	{"phone": "+70557237900"}
0005434310056	142559	4138 672937	ROMAN FEDOTOV	{"email": "roman.fedotov_18041976@postgrespro.ru", "phone": "+70787892197"}
0005434310057	272F3F	1830 313780	SERGEY KAZAKOV	{"email": "kazakov.sergey31071973@postgrespro.ru", "phone": "+70571561711"}
0005434310058	EF9C9A	3648 473512	FARIDA ROMANOVA	{"email": "f.romanova.25101969@postgrespro.ru", "phone": "+70164296972"}
0005434310059	EF9C9A	4196 035496	NATALYA ALEKSANDROVA	{"email": "natalya.aleksandrova051974@postgrespro.ru", "phone": "+70853613329"}
0005434310060	6F7BFF	5213 088233	RAISA BELYAEVA	{"email": "rbelyaeva_1961@postgrespro.ru", "phone": "+70723638525"}
0005434310061	6F7BFF	9494 756736	VLADIMIR POPOV	{"phone": "+70082014830"}
0005434310062	1ACFCB	4058 586477	GULFIYA MOISEEVA	{"phone": "+70490469620"}
0005434310063	8C8DC5	8714 205578	DMITRIY FEDOTOV	{"email": "fedotov_d_12101975@postgrespro.ru", "phone": "+70081348935"}
0005434310064	772A12	7557 461530	DMITRIY MIRONOV	{"email": "dmitriy_mironov-011972@postgrespro.ru", "phone": "+70045148601"}
0005434310065	E3A291	8815 548925	NIKITA NIKOLAEV	{"phone": "+70672933031"}
0005434310066	2BD736	4982 435808	MARINA MAKAROVA	{"email": "makarovam_1974@postgrespro.ru", "phone": "+70720130575"}
0005434310067	2BD736	0953 089658	DENIS KUZNECOV	{"email": "d-kuznecov_1974@postgrespro.ru", "phone": "+70436064968"}
0005434310068	99C184	6557 059667	SERGEY STEPANOV	{"email": "sergey.stepanov.011977@postgrespro.ru", "phone": "+70565562967"}
0005434310069	99C184	8351 802280	TAISIYA SMIRNOVA	{"email": "smirnova_t.26061969@postgrespro.ru", "phone": "+70981842458"}
0005434310070	99C184	2135 889370	SVETLANA TIMOFEEVA	{"phone": "+70893514497"}
0005434310071	0591CF	0766 593449	SVETLANA ANDREEVA	{"email": "andreeva-svetlana-121972@postgrespro.ru", "phone": "+70218197475"}
0005434310072	7CAC2A	6176 924552	NATALYA POPOVA	{"phone": "+70771478026"}
0005434310073	7CAC2A	1410 502401	ALEKSANDR SCHERBAKOV	{"email": "scherbakova.25011987@postgrespro.ru", "phone": "+70907836869"}
0005434310074	6894C5	7639 281937	SERGEY VOLKOV	{"email": "s_volkov.1976@postgrespro.ru", "phone": "+70317534741"}
0005434310075	16D128	1612 089637	ALEKSANDR SAVELEV	{"email": "savelev-a.1968@postgrespro.ru", "phone": "+70006089360"}
0005434310076	1DD4A9	3026 378550	VLADIMIR NOVIKOV	{"phone": "+70610798768"}
0005434310077	10196A	1266 350880	LYUBOV MALYSHEVA	{"phone": "+70844961159"}
0005434310078	E979D9	0050 714369	EKATERINA MAKSIMOVA	{"email": "maksimova_ekaterina.041975@postgrespro.ru", "phone": "+70412678004"}
0005434310079	E979D9	2954 251064	VIKTOR AFANASEV	{"phone": "+70996959907"}
0005434310080	BCB732	8061 989674	YURIY NAZAROV	{"phone": "+70968164688"}
0005434310081	4CC376	9060 150018	DENIS BONDARENKO	{"phone": "+70505855822"}
0005434310082	4CC376	5468 164666	STANISLAV VASILEV	{"phone": "+70860872911"}
0005434310083	57F279	8378 695553	NATALIYA KONDRATEVA	{"email": "kondrateva.n1976@postgrespro.ru", "phone": "+70881294285"}
0005434310084	9E0D82	1021 560781	MARIYA KOMAROVA	{"phone": "+70702496484"}
0005434310085	4CFBD8	8751 834683	ANNA KUZMINA	{"phone": "+70819662888"}
0005434310086	6F2E4E	2927 734323	VIKTOR STEPANOV	{"phone": "+70527000673"}
0005434310087	6F2E4E	3657 455404	OLGA SEMENOVA	{"email": "olga_semenova_18011964@postgrespro.ru", "phone": "+70339552729"}
0005434310088	BDDBC2	1906 872431	EKATERINA MALYSHEVA	{"phone": "+70050458858"}
0005434310089	BAA02C	2254 818522	ALINA KOVALEVA	{"phone": "+70739749651"}
0005434310090	1BDBC7	0566 901646	ALEKSANDR MAKAROV	{"phone": "+70346006500"}
0005434310091	79CABE	2204 323592	ROMAN TIKHONOV	{"email": "tikhonov-r-031963@postgrespro.ru", "phone": "+70773764764"}
0005434310092	79CABE	3987 882896	ALENA TROFIMOVA	{"phone": "+70279334188"}
0005434310093	455358	4225 435769	MARINA KUDRYASHOVA	{"phone": "+70704437901"}
0005434310094	F61BF2	1066 568586	TATYANA BELOVA	{"email": "belova.t-1960@postgrespro.ru", "phone": "+70226076252"}
0005434310095	D74B08	9106 297766	ALEKSEY SMIRNOV	{"email": "aleksey-smirnov-23011971@postgrespro.ru", "phone": "+70839965404"}
0005434310096	22D0B9	8364 296935	ANATOLIY GRIGOREV	{"email": "grigorev_anatoliy_1968@postgrespro.ru", "phone": "+70196224731"}
0005434310097	102C07	2293 658775	DMITRIY GRIGOREV	{"phone": "+70896545125"}
0005434310098	102C07	0770 424517	LIDIYA FILIPPOVA	{"email": "lidiya.filippova_041977@postgrespro.ru", "phone": "+70585058098"}
0005434310099	F472C0	5008 128498	VLADIMIR SERGEEV	{"phone": "+70554508642"}
0005434310100	F472C0	7344 196246	ALEKSANDR SMIRNOV	{"phone": "+70836245859"}
0005434310101	972296	8839 957596	DARYA BELOVA	{"email": "d-belova_1970@postgrespro.ru", "phone": "+70827538503"}
0005434310102	972296	1163 325970	VLADIMIR KOROLEV	{"phone": "+70644630689"}
0005434310103	7E5BA8	5155 489464	IRINA RODIONOVA	{"phone": "+70281269219"}
0005434310104	F8B2C5	2096 850061	ELENA ISAEVA	{"email": "isaeva-elena051965@postgrespro.ru", "phone": "+70612897342"}
0005434310105	F8B2C5	3586 544122	ALEKSANDR MAKSIMOV	{"email": "aleksandr-maksimov011961@postgrespro.ru", "phone": "+70046537568"}
0005434310106	9E3E44	3967 108981	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov-18081963@postgrespro.ru", "phone": "+70895806036"}
0005434310107	BE3B5A	6143 769269	NINEL KUZNECOVA	{"phone": "+70410483268"}
0005434310108	95FB91	2147 781451	ANASTASIYA ANTONOVA	{"phone": "+70673593177"}
0005434310109	96DB11	0408 320987	LARISA KOZLOVA	{"phone": "+70181937574"}
0005434310110	96DB11	6133 087519	ALISA ZAKHAROVA	{"email": "alisa.zakharova_1971@postgrespro.ru", "phone": "+70496634773"}
0005434310111	3D3126	5077 915325	SERGEY GUSEV	{"email": "gusev.sergey.30071966@postgrespro.ru", "phone": "+70122216990"}
0005434310112	3D3126	1771 369963	KAROLINA BELYAEVA	{"phone": "+70756142727"}
0005434310113	3648F7	1512 210623	ELENA STEPANOVA	{"phone": "+70265131521"}
0005434310114	E99E42	2079 714803	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov-011977@postgrespro.ru", "phone": "+70996420727"}
0005434310115	BF78C2	8673 188653	IRINA OSIPOVA	{"phone": "+70093328401"}
0005434310116	4B90FF	9987 719865	NIKOLAY BORISOV	{"email": "borisov_nikolay-121978@postgrespro.ru", "phone": "+70131163290"}
0005434310117	11831F	9982 635649	ELIZAVETA SAVELEVA	{"email": "e.saveleva-21081979@postgrespro.ru", "phone": "+70166572361"}
0005434310118	990AA2	1963 891883	RUSTAM CHERNOV	{"email": "chernov.rustam-16121969@postgrespro.ru", "phone": "+70830503749"}
0005434310119	F001D0	4588 298319	EVGENIY EGOROV	{"email": "egorov.evgeniy18071967@postgrespro.ru", "phone": "+70306901025"}
0005434310120	F001D0	6371 229427	ANDREY MIKHAYLOV	{"phone": "+70034174675"}
0005434310121	1B1E04	1018 932921	ALEKSEY MELNIKOV	{"phone": "+70971681138"}
0005434310122	1B1E04	1607 541049	LYUBOV BELOVA	{"email": "beloval1981@postgrespro.ru", "phone": "+70715703306"}
0005434310123	871181	3278 614513	NINA MARTYNOVA	{"email": "martynova_n1970@postgrespro.ru", "phone": "+70714133818"}
0005434310124	AE6A60	7364 452506	MAKSIM ISAEV	{"email": "isaevm.1986@postgrespro.ru", "phone": "+70290744275"}
0005434310125	C96128	4305 232873	IVAN MARTYNOV	{"phone": "+70901270774"}
0005434310126	2151CF	7354 623926	OLGA POPOVA	{"email": "popova.o.121972@postgrespro.ru", "phone": "+70867960023"}
0005434310127	2151CF	2890 353689	ALEKSANDR PETROV	{"email": "aleksandr-petrov23111981@postgrespro.ru", "phone": "+70336593246"}
0005434310128	B0B05F	9812 100375	VALENTINA KOROLEVA	{"phone": "+70944956313"}
0005434310129	E51795	0492 920568	ALEKSANDRA NESTEROVA	{"phone": "+70124577057"}
0005434310130	E51795	3950 423754	ANTONINA ALEKSEEVA	{"phone": "+70626308528"}
0005434310131	FE2B59	5080 621031	OLGA KOMAROVA	{"email": "olga.komarova.15071972@postgrespro.ru", "phone": "+70638093691"}
0005434310132	3CC50F	6130 855055	NIKOLAY DMITRIEV	{"phone": "+70247060218"}
0005434310133	BCB866	8379 021066	VENIAMIN IVANOV	{"email": "ivanov-v.061974@postgrespro.ru", "phone": "+70003150141"}
0005434310134	BCB866	6960 429140	ELENA DANILOVA	{"email": "danilova_e021973@postgrespro.ru", "phone": "+70441178928"}
0005434310135	0322A5	2990 587426	ANDREY IVANOV	{"phone": "+70745652283"}
0005434310136	D1E0CD	5915 925085	OLGA KOZLOVA	{"phone": "+70549235250"}
0005434310137	2393A8	4695 147815	VIKTOR EGOROV	{"phone": "+70686052816"}
0005434310138	6C50C7	8013 348310	ARTUR NOVIKOV	{"phone": "+70116562388"}
0005434310139	BD1924	5464 613647	LYUDMILA FROLOVA	{"phone": "+70243551389"}
0005434310140	AE3C16	8773 049585	NIKOLAY PETROV	{"email": "nikolay_petrov.081963@postgrespro.ru", "phone": "+70109753770"}
0005434310141	CB14AF	7821 373781	OLGA MIKHAYLOVA	{"email": "olga.mikhaylova_121968@postgrespro.ru", "phone": "+70054681163"}
0005434310142	3F7229	7554 400515	DMITRIY KOZLOV	{"email": "d_kozlov_1969@postgrespro.ru", "phone": "+70527065814"}
0005434310143	4D5B6E	6411 846828	ELIZAVETA ZHUKOVA	{"phone": "+70829525676"}
0005434310144	4D5B6E	4812 424226	VIKTOR PETROV	{"phone": "+70641396183"}
0005434310145	7BFE1D	6581 352514	TATYANA NESTEROVA	{"email": "t.nesterova_091968@postgrespro.ru", "phone": "+70112544315"}
0005434310146	65456B	4286 996941	LIDIYA BARANOVA	{"email": "baranova.l1968@postgrespro.ru", "phone": "+70475744888"}
0005434310147	65456B	1722 077927	TATYANA POPOVA	{"phone": "+70410537508"}
0005434310148	D88ED1	1452 342386	VALENTINA KOZLOVA	{"email": "vkozlova-1980@postgrespro.ru", "phone": "+70334374119"}
0005434310149	70F6CD	8425 761068	MARIYA VASILEVA	{"phone": "+70514775000"}
0005434310150	74E07D	5138 160614	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena.071969@postgrespro.ru", "phone": "+70872938708"}
0005434310151	6DA9A9	6568 914506	ANDREY ROMANOV	{"email": "andrey.romanov-1988@postgrespro.ru", "phone": "+70469670220"}
0005434310152	06AE15	3548 145139	ELENA ARKHIPOVA	{"email": "earkhipova-121974@postgrespro.ru", "phone": "+70638034274"}
0005434310153	06AE15	6976 921419	ALEKSANDR ANDREEV	{"phone": "+70264225986"}
0005434310154	9D0254	9435 331854	IGOR PAVLOV	{"phone": "+70957817409"}
0005434310155	EE5E8B	6850 449407	EKATERINA VOLKOVA	{"phone": "+70559423517"}
0005434310156	1F5FDB	3257 965526	LYUDMILA TIKHONOVA	{"email": "tikhonova_l_29041973@postgrespro.ru", "phone": "+70622719195"}
0005434310157	1F5FDB	8951 095908	LYUBOV BELOVA	{"email": "lyubov.belova_1963@postgrespro.ru", "phone": "+70988690147"}
0005434310158	1F5FDB	0436 970480	VALENTINA VOLKOVA	{"email": "valentina-volkova1959@postgrespro.ru", "phone": "+70643718112"}
0005434310159	2F3DF8	3105 293546	VLADIMIR DENISOV	{"email": "v-denisov_061977@postgrespro.ru", "phone": "+70397750584"}
0005434310160	2F3DF8	6020 329078	SERGEY GRIGOREV	{"email": "grigorev-sergey_1971@postgrespro.ru", "phone": "+70285080054"}
0005434310161	4A4E5F	3355 199363	ANASTASIYA MELNIKOVA	{"email": "amelnikova-1970@postgrespro.ru", "phone": "+70888136863"}
0005434310162	4A4E5F	7228 126553	ELENA LEBEDEVA	{"phone": "+70521849139"}
0005434310163	B2855F	8489 235246	NADEZHDA OVCHINNIKOVA	{"phone": "+70789758565"}
0005434310164	F16E64	1815 381680	VALENTINA AFANASEVA	{"phone": "+70319515394"}
0005434310165	BE23B7	1709 000175	SERGEY IVANOV	{"phone": "+70933658912"}
0005434310166	4AB3B8	3344 941322	ANDREY KUZNECOV	{"phone": "+70819609719"}
0005434310167	632C30	7431 718440	OLGA KUZMINA	{"email": "o.kuzmina-051972@postgrespro.ru", "phone": "+70436270716"}
0005434310168	632C30	7051 255034	EVGENIY PETROV	{"email": "epetrov22061979@postgrespro.ru", "phone": "+70294615867"}
0005434310169	61A033	5112 679460	DMITRIY EGOROV	{"email": "dmitriy-egorov_021971@postgrespro.ru", "phone": "+70383608543"}
0005434310170	61A033	1345 627901	ARTEM VOLKOV	{"email": "a-volkov_24071972@postgrespro.ru", "phone": "+70758826898"}
0005434310171	61A033	7787 443736	FARIT FEDOROV	{"phone": "+70946623950"}
0005434310172	F5A650	7804 106343	TATYANA TIMOFEEVA	{"phone": "+70310857188"}
0005434310173	F5A650	6577 944310	YURIY GERASIMOV	{"email": "yuriy_gerasimov_1973@postgrespro.ru", "phone": "+70089798764"}
0005434310174	FDF091	9342 931073	ANASTASIYA BELOVA	{"phone": "+70506474754"}
0005434310175	674970	6076 714098	SERGEY TIKHONOV	{"email": "tikhonov_sergey-041975@postgrespro.ru", "phone": "+70801820978"}
0005434310176	018009	8502 325762	EKATERINA ANDREEVA	{"email": "ekaterinaandreeva1975@postgrespro.ru", "phone": "+70011209833"}
0005434310177	018009	4548 959175	NINA ISAEVA	{"email": "isaeva.n1976@postgrespro.ru", "phone": "+70352648543"}
0005434310178	3CCBD4	2431 346866	DMITRIY POPOV	{"email": "dmitriy-popov.1972@postgrespro.ru", "phone": "+70814651519"}
0005434310179	3CCBD4	3156 343176	ELENA KOZLOVA	{"phone": "+70131464423"}
0005434310180	D4FFA6	4458 726091	GRIGORIY DAVYDOV	{"phone": "+70209310654"}
0005434310181	277045	8214 820787	DANIIL EGOROV	{"phone": "+70512860195"}
0005434310182	66E2C7	7071 484516	GALINA KOROLEVA	{"phone": "+70489335138"}
0005434310183	20EA3A	1134 102633	MARIYA NESTEROVA	{"phone": "+70657997237"}
0005434310184	037E12	7673 168464	SERGEY CHERNOV	{"email": "s_chernov111967@postgrespro.ru", "phone": "+70344051923"}
0005434310185	037E12	5992 978835	VIKTOR SOROKIN	{"email": "v_sorokin.20091974@postgrespro.ru", "phone": "+70692682956"}
0005434311181	5B70FA	2471 191954	ALEKSANDRA KOMAROVA	{"email": "aleksandra_komarova-091981@postgrespro.ru", "phone": "+70014383142"}
0005434311182	6AEDCD	5643 615838	VLADIMIR FROLOV	{"phone": "+70280163757"}
0005434311183	AA1540	4557 976929	ANTONINA KAZAKOVA	{"email": "a.kazakova-041964@postgrespro.ru", "phone": "+70758634797"}
0005434311184	AA1540	6437 939533	ALEKSANDR GAVRILOV	{"phone": "+70402728644"}
0005434311185	C98087	9204 171687	OLGA ZAKHAROVA	{"email": "ozakharova11041976@postgrespro.ru", "phone": "+70746889948"}
0005434311186	8BCDA3	0777 769792	YURIY IVANOV	{"phone": "+70097723840"}
0005434311187	8BCDA3	3372 086611	ALEKSANDR BONDARENKO	{"phone": "+70012475263"}
0005434311188	510F19	2280 837489	ALEKSEY DENISOV	{"email": "denisovaleksey_18071956@postgrespro.ru", "phone": "+70934578983"}
0005434311189	3A6CCD	8432 894994	VYACHESLAV MAKAROV	{"phone": "+70772529608"}
0005434311190	3A6CCD	5003 178091	KSENIYA TIKHONOVA	{"phone": "+70179595055"}
0005434311191	B6341F	6863 318537	ZINAIDA KUZNECOVA	{"email": "kuznecova.zinaida_18091964@postgrespro.ru", "phone": "+70466530361"}
0005434311192	1E981A	0254 108295	YULIYA KOZLOVA	{"phone": "+70754790060"}
0005434311193	1E981A	5731 369345	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr30081968@postgrespro.ru", "phone": "+70268653593"}
0005434311194	3936CB	7410 830676	NINA ZAKHAROVA	{"phone": "+70330196683"}
0005434311195	3936CB	9833 165708	ANDREY KUZMIN	{"email": "kuzminandrey28011977@postgrespro.ru", "phone": "+70549910610"}
0005434311196	3936CB	4684 894631	VIKTOR NIKOLAEV	{"phone": "+70792986629"}
0005434311197	473EFB	6509 087822	RUSTAM SCHERBAKOV	{"email": "scherbakovrustam.1965@postgrespro.ru", "phone": "+70205865148"}
0005434311198	473EFB	3406 670999	OLGA SEMENOVA	{"phone": "+70036633812"}
0005434311199	473EFB	9179 657918	LARISA VASILEVA	{"phone": "+70590236412"}
0005434311200	473EFB	9868 746841	IRINA SERGEEVA	{"email": "sergeeva.i-24081975@postgrespro.ru", "phone": "+70947877596"}
0005434311201	AAFABA	5472 511597	VIKTOR IVANOV	{"phone": "+70149753389"}
0005434311202	9B5068	0734 766542	MARINA ANDREEVA	{"email": "m-andreeva.1971@postgrespro.ru", "phone": "+70458352068"}
0005434311203	545192	9554 127851	NATALYA YUDINA	{"phone": "+70441765178"}
0005434311204	5763E5	8948 105487	VIKTOR KOZLOV	{"email": "v-kozlov_1963@postgrespro.ru", "phone": "+70879084412"}
0005434311205	5763E5	6610 937703	OLGA NESTEROVA	{"phone": "+70499550187"}
0005434311206	07CE99	7895 313105	NIKOLAY SIDOROV	{"phone": "+70646134455"}
0005434311207	ADC164	8541 331109	NINA ORLOVA	{"email": "orlova_nina_1973@postgrespro.ru", "phone": "+70251318743"}
0005434311208	ADC164	0423 401032	ANTON BORISOV	{"phone": "+70458767602"}
0005434311209	7AC6E3	5463 281806	LYUBOV KOROLEVA	{"email": "koroleval-071969@postgrespro.ru", "phone": "+70269225509"}
0005434311210	92CB54	8144 165986	ALEKSEY ORLOV	{"email": "a.orlov1956@postgrespro.ru", "phone": "+70482248389"}
0005434311211	92CB54	3367 967333	TATYANA KAZAKOVA	{"email": "t-kazakova-051972@postgrespro.ru", "phone": "+70422302159"}
0005434311212	6ADB40	9512 254626	PAVEL FILIPPOV	{"phone": "+70987593744"}
0005434311213	8C4EDA	4224 773345	VALENTINA FILIPPOVA	{"email": "v_filippova_1975@postgrespro.ru", "phone": "+70260935053"}
0005434311214	30D928	8728 924963	ZOYA ZAYCEVA	{"email": "zzayceva.31051981@postgrespro.ru", "phone": "+70596971075"}
0005434311215	30D928	0984 758391	ARKADIY KUDRYASHOV	{"email": "a.kudryashov1976@postgrespro.ru", "phone": "+70332952616"}
0005434311216	1CD5BA	1822 199410	OLGA GERASIMOVA	{"phone": "+70160779983"}
0005434311217	B7447E	4557 112535	TAMARA MELNIKOVA	{"phone": "+70102655091"}
0005434311218	FB42DD	3856 466241	ARTEM PAVLOV	{"email": "artempavlov-1970@postgrespro.ru", "phone": "+70245339598"}
0005434311219	4D1D5D	1186 051711	MIKHAIL VASILEV	{"email": "mikhail_vasilev_19051981@postgrespro.ru", "phone": "+70486304297"}
0005434311220	4D1D5D	9702 946239	ANATOLIY DENISOV	{"email": "adenisov_05071965@postgrespro.ru", "phone": "+70566425932"}
0005434311221	A24D2D	1625 212797	ANNA BELOVA	{"email": "belova-anna.30051984@postgrespro.ru", "phone": "+70090142595"}
0005434311222	0186A6	4333 600903	DMITRIY SOKOLOV	{"phone": "+70495701741"}
0005434311223	13A6F5	4943 410769	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev.051971@postgrespro.ru", "phone": "+70393306948"}
0005434311224	297510	0367 636860	MARIYA MAKSIMOVA	{"phone": "+70144346849"}
0005434311225	297510	4381 736957	DMITRIY GORBUNOV	{"phone": "+70863212360"}
0005434311226	1739A4	3440 071151	ALEKSANDR SOLOVEV	{"phone": "+70023349575"}
0005434311227	1739A4	0810 418716	ROZA MAKSIMOVA	{"email": "maksimovaroza_1974@postgrespro.ru", "phone": "+70490907709"}
0005434311228	1739A4	0505 227306	VLADIMIR VOLKOV	{"phone": "+70681949001"}
0005434311229	452D23	1056 058091	TATYANA RYABOVA	{"phone": "+70610029555"}
0005434311230	452D23	7317 672656	ALEKSANDR GORBUNOV	{"phone": "+70861974954"}
0005434311231	66CBF6	1326 900031	OLEG POPOV	{"phone": "+70763794326"}
0005434311232	66CBF6	3222 061633	ALEKSEY KULIKOV	{"phone": "+70953142273"}
0005434311233	52A037	3497 533646	ALEKSEY MEDVEDEV	{"phone": "+70805908360"}
0005434311234	EC233B	8531 523721	VALENTINA OSIPOVA	{"email": "valentina_osipova.21071965@postgrespro.ru", "phone": "+70394996798"}
0005434311235	107D51	5029 803033	IVAN GAVRILOV	{"email": "ivan.gavrilov091973@postgrespro.ru", "phone": "+70292321282"}
0005434311236	107D51	4147 610318	VERA POPOVA	{"email": "popova.v_021968@postgrespro.ru", "phone": "+70756941198"}
0005434311237	E8FBD0	3462 844287	SOFYA MOROZOVA	{"email": "morozovas12101982@postgrespro.ru", "phone": "+70297469477"}
0005434311238	1E4278	0690 999052	DENIS VLASOV	{"email": "d-vlasov-061976@postgrespro.ru", "phone": "+70870729402"}
0005434311239	1E4278	0010 399019	VALENTINA SCHERBAKOVA	{"email": "scherbakova_v_061974@postgrespro.ru", "phone": "+70050546729"}
0005434311240	336A29	8567 382235	KSENIYA KOZLOVA	{"email": "k.kozlova.22011967@postgrespro.ru", "phone": "+70310604321"}
0005434311241	336A29	1141 602892	NINA MASLOVA	{"email": "maslova.nina_1968@postgrespro.ru", "phone": "+70605235405"}
0005434311242	F29ABB	3314 402598	LYUBOV KUZNECOVA	{"phone": "+70342032013"}
0005434311243	52AAA0	8186 934237	VADIM TIKHONOV	{"phone": "+70874766503"}
0005434311244	AB7FDB	6352 074599	VASILIY SCHERBAKOV	{"email": "vasiliyscherbakov.1973@postgrespro.ru", "phone": "+70030711564"}
0005434311245	AB7FDB	9510 487017	NADEZHDA ANDREEVA	{"phone": "+70903896294"}
0005434311246	AB7FDB	3444 755067	RUSLAN MAKSIMOV	{"email": "maksimovruslan-18031982@postgrespro.ru", "phone": "+70074597860"}
0005434311247	8E7BEB	1519 674883	YURIY EGOROV	{"email": "egorov.y-1985@postgrespro.ru", "phone": "+70486058805"}
0005434311248	51281B	7840 466358	VALENTINA ERMAKOVA	{"phone": "+70740716539"}
0005434311249	ECB570	0784 086228	MIKHAIL MIKHAYLOV	{"phone": "+70299474389"}
0005434311250	DCBE68	0180 762305	VALENTINA TIMOFEEVA	{"phone": "+70691782561"}
0005434311251	DCBE68	9924 906977	NINA POPOVA	{"email": "npopova_23031985@postgrespro.ru", "phone": "+70122063386"}
0005434311252	16327F	6075 419671	DMITRIY MIRONOV	{"email": "dmitriymironov.25041970@postgrespro.ru", "phone": "+70302848456"}
0005434311253	16327F	4618 304105	TATYANA SIDOROVA	{"phone": "+70639816477"}
0005434311254	08CABE	3615 093280	OLGA ANDREEVA	{"email": "andreeva-o_071968@postgrespro.ru", "phone": "+70727458522"}
0005434311255	CC122C	6372 624626	NINA MOISEEVA	{"phone": "+70195304619"}
0005434311256	CC122C	7989 393785	NIKOLAY SERGEEV	{"phone": "+70955991471"}
0005434311257	34268E	9117 747016	ELENA LEBEDEVA	{"phone": "+70275678581"}
0005434311258	442777	3269 945375	GALINA SEMENOVA	{"phone": "+70308112261"}
0005434311259	37BAE1	3906 051012	MAKSIM EGOROV	{"email": "maksim_egorov.02081974@postgrespro.ru", "phone": "+70253009292"}
0005434311260	886DAA	4318 438634	TATYANA AKIMOVA	{"email": "t_akimova.14011972@postgrespro.ru", "phone": "+70333078204"}
0005434311261	95E0C8	0508 011711	SERGEY NIKOLAEV	{"email": "nikolaevs-23031967@postgrespro.ru", "phone": "+70621104850"}
0005434311262	26F889	8242 831376	ANASTASIYA YAKOVLEVA	{"phone": "+70397411042"}
0005434311263	52E12B	0171 448197	YURIY FEDOROV	{"phone": "+70616410530"}
0005434311264	7A1AD7	9542 543963	SERGEY ALEKSANDROV	{"phone": "+70775634455"}
0005434311265	7A1AD7	4388 174986	ANTONINA ALEKSEEVA	{"phone": "+70990434458"}
0005434311266	7A1AD7	1682 402262	OLESYA KUZMINA	{"phone": "+70901309740"}
0005434311267	BD8A5D	3277 400778	IGOR KOZLOV	{"phone": "+70272727981"}
0005434311268	490BC5	3660 433102	NADEZHDA AFANASEVA	{"email": "nadezhda.afanaseva-28111973@postgrespro.ru", "phone": "+70994259972"}
0005434311269	593539	7322 790522	MARIYA KUZMINA	{"phone": "+70078282375"}
0005434311270	593539	5741 984973	OLGA OSIPOVA	{"email": "olga-osipova-05011971@postgrespro.ru", "phone": "+70590203523"}
0005434311271	07D04C	1490 566153	KSENIYA EGOROVA	{"email": "k-egorova.1970@postgrespro.ru", "phone": "+70386030032"}
0005434311272	139FBE	9814 546022	ANDREY IVANOV	{"phone": "+70971865444"}
0005434311273	156ED4	1219 907044	LIDIYA BORISOVA	{"phone": "+70567877279"}
0005434311274	156ED4	5725 934802	VLADIMIR IVANOV	{"phone": "+70507869280"}
0005434311275	222501	9538 901978	NIKOLAY OSIPOV	{"phone": "+70736324494"}
0005434311276	815097	5227 130620	ZOYA ALEKSEEVA	{"email": "z-alekseeva-1968@postgrespro.ru", "phone": "+70162244341"}
0005434311277	815097	5565 753335	OLGA POLYAKOVA	{"email": "o-polyakova-041971@postgrespro.ru", "phone": "+70205136290"}
0005434311278	2BE6AA	5297 819401	ROZA KULIKOVA	{"phone": "+70645768673"}
0005434311279	A3B4EF	1741 384727	SVETLANA SAVELEVA	{"email": "savelevas-19111965@postgrespro.ru", "phone": "+70269522087"}
0005434311280	A3B4EF	7482 555910	VLADIMIR SIDOROV	{"phone": "+70132229946"}
0005434311281	44DF0E	1163 328698	NIKOLAY MARTYNOV	{"email": "nmartynov_051987@postgrespro.ru", "phone": "+70259086762"}
0005434311282	2DAEFC	8306 648161	DMITRIY MATVEEV	{"email": "dmitriy-matveev-1978@postgrespro.ru", "phone": "+70820346697"}
0005434311283	2DAEFC	8236 673722	VLADISLAV POPOV	{"phone": "+70554235932"}
0005434311284	366C60	1101 241634	TATYANA VOLKOVA	{"phone": "+70327110129"}
0005434311285	366C60	5009 242996	LILIYA KUZMINA	{"email": "kuzmina_liliya_14011973@postgrespro.ru", "phone": "+70204640514"}
0005434311286	24D827	7555 256731	ANNA ALEKSEEVA	{"email": "alekseevaa.121975@postgrespro.ru", "phone": "+70919617690"}
0005434311287	22DBE4	5242 102398	ANATOLIY SCHERBAKOV	{"email": "anatoliy_scherbakov-1975@postgrespro.ru", "phone": "+70605921614"}
0005434311288	ACC995	4607 023250	ELENA BARANOVA	{"email": "baranova_e.25041975@postgrespro.ru", "phone": "+70076420755"}
0005434311289	B75EA2	4279 398455	IRINA SAVELEVA	{"email": "savelevai-1975@postgrespro.ru", "phone": "+70455145556"}
0005434319164	4684EC	5555 350828	MIKHAIL YAKOVLEV	{"phone": "+70369459906"}
0005434311290	B0F5C6	0821 707548	EVGENIY SCHERBAKOV	{"email": "e_scherbakov.1972@postgrespro.ru", "phone": "+70520023263"}
0005434311291	44F421	8533 657383	NINA FILIPPOVA	{"email": "n.filippova.1962@postgrespro.ru", "phone": "+70749003911"}
0005434312329	517CFC	7015 255685	ALEKSEY ANTONOV	{"phone": "+70648103823"}
0005434312283	17C341	7376 483561	EDUARD MOROZOV	{"phone": "+70623428960"}
0005434312284	130043	6867 027203	SERGEY MAKSIMOV	{"phone": "+70599659479"}
0005434312285	A0793C	0245 015437	RUSLAN CHERNOV	{"email": "ruslan-chernov011973@postgrespro.ru", "phone": "+70589945683"}
0005434312286	A0793C	2716 450062	KONSTANTIN KONOVALOV	{"phone": "+70589558769"}
0005434312287	FAA687	5197 466210	DENIS KARPOV	{"email": "denis-karpov1968@postgrespro.ru", "phone": "+70827693294"}
0005434312288	FAA687	9364 291198	TAISIYA STEPANOVA	{"phone": "+70840444123"}
0005434312289	688577	9201 904558	VLADIMIR DMITRIEV	{"email": "dmitrievv.24081970@postgrespro.ru", "phone": "+70435261479"}
0005434312290	CC3BC9	7737 931318	EKATERINA FROLOVA	{"email": "frolova.ekaterina-29101981@postgrespro.ru", "phone": "+70993447783"}
0005434312291	FAB2B9	5345 409634	PAVEL ROMANOV	{"phone": "+70122061892"}
0005434312292	DB30AA	4310 109923	YURIY EGOROV	{"phone": "+70777136053"}
0005434312293	BEED34	4706 166183	ALEKSANDR TIMOFEEV	{"email": "timofeevaleksandr.031979@postgrespro.ru", "phone": "+70195544294"}
0005434312294	CA7809	0123 028827	MARIYA POPOVA	{"email": "mariyapopova_1974@postgrespro.ru", "phone": "+70171337942"}
0005434312295	F609AA	8825 530238	YANA AFANASEVA	{"phone": "+70052948789"}
0005434312296	DE1D4C	0770 849143	KIRILL ROMANOV	{"email": "kirillromanov-01061971@postgrespro.ru", "phone": "+70811750737"}
0005434312297	9900A1	6448 393737	MIKHAIL SEMENOV	{"email": "semenov.mikhail.1965@postgrespro.ru", "phone": "+70867321138"}
0005434312298	9070FA	2604 231024	OLGA KONOVALOVA	{"email": "o-konovalova-17061972@postgrespro.ru", "phone": "+70228817718"}
0005434312299	B5C479	2362 224350	RIMMA POPOVA	{"phone": "+70632567066"}
0005434312300	8FBAA4	9508 075400	LIDIYA NOVIKOVA	{"phone": "+70841934618"}
0005434312301	8FBAA4	7034 883045	DENIS SAVELEV	{"phone": "+70501471528"}
0005434312302	8FBAA4	9902 244527	ALEKSANDR SEMENOV	{"email": "semenov.a1979@postgrespro.ru", "phone": "+70791339335"}
0005434312303	5E4E0F	0230 256986	NATALYA PETROVA	{"email": "petrova_n-06061976@postgrespro.ru", "phone": "+70334758624"}
0005434312304	5E4E0F	9274 525727	ALEKSANDR EGOROV	{"email": "egorov_a_21121976@postgrespro.ru", "phone": "+70536954606"}
0005434312305	AF1D0A	4418 691675	GALINA NESTEROVA	{"email": "nesterovag_02021974@postgrespro.ru", "phone": "+70966558598"}
0005434312306	AF1D0A	6737 454322	YURIY MEDVEDEV	{"phone": "+70514045805"}
0005434312307	AF1D0A	5947 235166	NINA MOROZOVA	{"phone": "+70741835128"}
0005434312308	AF1D0A	4573 130039	ANTONINA MAKAROVA	{"email": "makarova-antonina.20041962@postgrespro.ru", "phone": "+70344224832"}
0005434312309	7200E7	2600 886816	ALEKSEY ISAEV	{"email": "a-isaev.15041973@postgrespro.ru", "phone": "+70842718458"}
0005434312310	7200E7	6767 286024	ALEKSANDR NOVIKOV	{"phone": "+70024152076"}
0005434312311	B096CC	8896 873071	VLADIMIR FOMIN	{"phone": "+70704765947"}
0005434312312	AEC739	7320 717482	ELENA KUDRYASHOVA	{"email": "kudryashova_e-24061972@postgrespro.ru", "phone": "+70848098481"}
0005434312313	AEC739	1773 946711	TATYANA KOMAROVA	{"email": "tatyana_komarova.17011963@postgrespro.ru", "phone": "+70954605903"}
0005434312314	A0D701	1221 526098	DENIS KULIKOV	{"email": "kulikov-denis-071978@postgrespro.ru", "phone": "+70791035236"}
0005434312315	A85356	1349 259378	ANNA NIKITINA	{"email": "annanikitina_1963@postgrespro.ru", "phone": "+70084624277"}
0005434312316	91D2E9	4988 736452	OKSANA GUSEVA	{"phone": "+70610405670"}
0005434312317	A5B540	5159 611399	ELENA NIKOLAEVA	{"email": "nikolaevaelena_1975@postgrespro.ru", "phone": "+70542767344"}
0005434312318	6F86EB	9364 764923	ALEKSEY EGOROV	{"phone": "+70463066432"}
0005434312319	520728	5164 361690	SERGEY BONDARENKO	{"email": "s_bondarenko.011968@postgrespro.ru", "phone": "+70161505521"}
0005434312320	3E198B	0617 741548	YULIYA KOROLEVA	{"phone": "+70160448000"}
0005434312321	3E198B	3486 217326	NATALYA IVANOVA	{"phone": "+70621273243"}
0005434312322	7D3C41	6437 539477	TATYANA MOROZOVA	{"email": "morozova.tatyana_1970@postgrespro.ru", "phone": "+70183087621"}
0005434312323	9FE0B7	4769 945690	MARIYA ISAEVA	{"email": "misaeva-091960@postgrespro.ru", "phone": "+70874673517"}
0005434312324	9FE0B7	5488 547483	NINA SOLOVEVA	{"email": "n.soloveva16101965@postgrespro.ru", "phone": "+70906423961"}
0005434312325	BA777B	5108 356135	RAVIL SOLOVEV	{"email": "solovev_ravil.021975@postgrespro.ru", "phone": "+70879139107"}
0005434312326	BA777B	6112 645977	VALERIY IVANOV	{"phone": "+70092836174"}
0005434312327	18ABD9	6713 220701	NIKOLAY VOROBEV	{"phone": "+70615813506"}
0005434312328	B9996D	2585 822501	VITALIY BELOV	{"phone": "+70399995177"}
0005434312330	3D79D9	2841 711470	ARTUR MOROZOV	{"phone": "+70046848007"}
0005434312331	390DB0	5761 692339	NIKOLAY VOLKOV	{"phone": "+70658151160"}
0005434312332	390DB0	3445 439607	YANA NIKOLAEVA	{"phone": "+70395561484"}
0005434312333	CDDF32	3307 538007	YANA GORBUNOVA	{"email": "gorbunova-yana_22081962@postgrespro.ru", "phone": "+70110057113"}
0005434312334	23D176	1577 869529	KONSTANTIN SCHERBAKOV	{"phone": "+70052827294"}
0005434312335	23D176	7297 682069	ARINA FEDOROVA	{"phone": "+70254741022"}
0005434312336	BE8281	3824 155736	VALENTINA VOLKOVA	{"email": "volkovav.1964@postgrespro.ru", "phone": "+70312189635"}
0005434312337	BE8281	7260 029685	ANASTASIYA TARASOVA	{"phone": "+70911093923"}
0005434312338	D1DA45	9801 366911	DANILA IVANOV	{"email": "ivanovdanila.20051974@postgrespro.ru", "phone": "+70248207613"}
0005434312339	D1DA45	0090 852591	VALERIY MIRONOV	{"email": "v_mironov.1969@postgrespro.ru", "phone": "+70606152515"}
0005434312340	A2F2F8	2518 862261	RAFAEL SERGEEV	{"email": "rafael-sergeev.041970@postgrespro.ru", "phone": "+70077933075"}
0005434312341	9F999D	8632 767748	RIMMA ALEKSEEVA	{"email": "alekseevarimma_021964@postgrespro.ru", "phone": "+70961834885"}
0005434312342	313816	6008 665533	GENNADIY ANDREEV	{"phone": "+70724748745"}
0005434312343	313816	5662 847797	YANA OSIPOVA	{"email": "osipova_yana041968@postgrespro.ru", "phone": "+70641505432"}
0005434312344	2DCA1F	3278 273946	MARINA STEPANOVA	{"phone": "+70339842934"}
0005434312345	2DCA1F	1943 576533	ULYANA DENISOVA	{"email": "denisova-ulyana.1977@postgrespro.ru", "phone": "+70425234837"}
0005434312346	B19974	8223 492923	ANATOLIY SOKOLOV	{"email": "anatoliy-sokolov_1973@postgrespro.ru", "phone": "+70213886552"}
0005434312347	B19974	1654 864754	SERGEY KRASNOV	{"email": "krasnov-sergey_1962@postgrespro.ru", "phone": "+70670998156"}
0005434312348	C8D100	6950 604066	ANDREY GERASIMOV	{"phone": "+70324523061"}
0005434312349	C8D100	9341 630884	GALINA ANDREEVA	{"email": "andreevagalina.101963@postgrespro.ru", "phone": "+70767370294"}
0005434312350	EA9F05	6340 568741	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov.041963@postgrespro.ru", "phone": "+70961583226"}
0005434312351	EA9F05	3155 302350	RINAT NIKOLAEV	{"email": "nikolaev.r-111975@postgrespro.ru", "phone": "+70906021922"}
0005434312352	DD60C0	0932 535059	TATYANA KULIKOVA	{"phone": "+70474363319"}
0005434312353	DD60C0	5281 012395	YULIYA DMITRIEVA	{"email": "dmitrieva.y-091963@postgrespro.ru", "phone": "+70261272164"}
0005434312354	E1A284	7113 828847	OKSANA ZHURAVLEVA	{"email": "oksana.zhuravleva.15041977@postgrespro.ru", "phone": "+70396406216"}
0005434312355	34965E	4677 735391	EVGENIY BELOV	{"phone": "+70700622874"}
0005434312356	99F0B4	7677 539967	MAKSIM VASILEV	{"email": "maksimvasilev_20071975@postgrespro.ru", "phone": "+70097640619"}
0005434312357	1786FC	7030 650471	NATALYA BOGDANOVA	{"email": "bogdanovan-30061970@postgrespro.ru", "phone": "+70193682943"}
0005434312358	145C40	4893 479631	SNEZHANA DAVYDOVA	{"phone": "+70540341332"}
0005434312359	145C40	6185 337754	ZINAIDA EGOROVA	{"phone": "+70161695033"}
0005434312360	FA7019	3697 443662	SVETLANA ABRAMOVA	{"email": "svetlanaabramova29041972@postgrespro.ru", "phone": "+70952329559"}
0005434312361	FA9723	6648 362120	ANATOLIY FEDOROV	{"phone": "+70343891642"}
0005434312362	415985	8520 542639	OKSANA DENISOVA	{"email": "denisovao_30051974@postgrespro.ru", "phone": "+70079137177"}
0005434312363	DBA367	0136 383585	VIKTOR ANDREEV	{"email": "andreev.viktor_1981@postgrespro.ru", "phone": "+70402823470"}
0005434312364	6D98C1	9223 982899	SERGEY NAUMOV	{"phone": "+70139242261"}
0005434312365	6D98C1	3377 492684	MAKSIM ANDREEV	{"email": "andreev-maksim-05101970@postgrespro.ru", "phone": "+70908994637"}
0005434312366	6D98C1	7925 688955	NADEZHDA TITOVA	{"email": "ntitova.15051975@postgrespro.ru", "phone": "+70109641415"}
0005434312367	FF35D7	4994 038971	VLADISLAV NIKITIN	{"phone": "+70700731950"}
0005434312368	3A5021	8991 745289	MARIYA NESTEROVA	{"email": "nesterova_m.061970@postgrespro.ru", "phone": "+70739429943"}
0005434312369	680DB8	4811 130773	ELENA ZHURAVLEVA	{"email": "ezhuravleva051970@postgrespro.ru", "phone": "+70151031265"}
0005434312370	680DB8	9988 056865	VALERIY SCHERBAKOV	{"email": "scherbakov_v.15081978@postgrespro.ru", "phone": "+70151079930"}
0005434312371	680DB8	8879 914376	MARIYA KOZLOVA	{"email": "mariya_kozlova121972@postgrespro.ru", "phone": "+70437467640"}
0005434312372	CD4012	4895 745054	ALEKSANDR ZHUKOV	{"phone": "+70777481236"}
0005434312373	0F1B8B	0616 017908	DANIIL FROLOV	{"email": "frolovdaniil_031974@postgrespro.ru", "phone": "+70278879364"}
0005434312374	140E35	2241 286793	ALEKSEY BELOV	{"email": "belov.a_041983@postgrespro.ru", "phone": "+70538199734"}
0005434312375	140E35	2286 037545	SVETLANA ORLOVA	{"email": "s.orlova.081964@postgrespro.ru", "phone": "+70066006873"}
0005434312376	AD1612	9957 027073	ANDREY MOROZOV	{"email": "morozov.andrey.1977@postgrespro.ru", "phone": "+70718102507"}
0005434312377	B15A4E	1395 220000	VYACHESLAV ALEKSEEV	{"email": "alekseev-v.14081964@postgrespro.ru", "phone": "+70993638877"}
0005434312378	F5AA4D	2646 291104	ARTUR BELOV	{"phone": "+70297879736"}
0005434312379	3D2075	2397 093021	LYUDMILA KRASNOVA	{"email": "krasnova-lyudmila1984@postgrespro.ru", "phone": "+70725398622"}
0005434312380	3D2075	6469 512044	DMITRIY KAZAKOV	{"phone": "+70720834603"}
0005434312381	63605D	2447 046955	TATYANA ROMANOVA	{"email": "tromanova-20071964@postgrespro.ru", "phone": "+70611266500"}
0005434312382	55282D	3072 498116	YULIYA DENISOVA	{"phone": "+70841323080"}
0005434312383	55282D	0613 585091	VYACHESLAV ANDREEV	{"phone": "+70192438590"}
0005434312384	55282D	0237 124942	KHALIDA RODIONOVA	{"phone": "+70454942889"}
0005434312385	19E0AC	9756 269170	DARYA ZAKHAROVA	{"email": "zakharova.d_22121975@postgrespro.ru", "phone": "+70961009102"}
0005434312386	C5A23C	5606 010534	GALINA KOROLEVA	{"phone": "+70683731324"}
0005434312387	061F25	0647 515685	SERGEY MIKHAYLOV	{"email": "mikhaylov_s_25061971@postgrespro.ru", "phone": "+70097250879"}
0005434312388	526CE4	6749 337546	ELENA MASLOVA	{"email": "e.maslova.1967@postgrespro.ru", "phone": "+70973864277"}
0005434312389	C22C7F	8014 512136	TATYANA FILATOVA	{"email": "tatyana.filatova.23071977@postgrespro.ru", "phone": "+70006159812"}
0005434312390	C22C7F	7873 006497	VIOLETTA SOLOVEVA	{"phone": "+70717387366"}
0005434312391	62BFE6	6754 114893	VADIM MAKSIMOV	{"phone": "+70782406690"}
0005434312392	28C8E8	2067 466838	DMITRIY FROLOV	{"phone": "+70673137763"}
0005434312393	6D4A82	3715 603179	VLADIMIR FROLOV	{"email": "frolov_vladimir.04091968@postgrespro.ru", "phone": "+70814608654"}
0005434312394	6D4A82	2167 986673	SERGEY ORLOV	{"email": "orlov.sergey121968@postgrespro.ru", "phone": "+70136335448"}
0005434312395	E71EE9	7180 729039	EVGENIY KONOVALOV	{"phone": "+70353513849"}
0005434312396	E71EE9	0333 638643	KONSTANTIN GERASIMOV	{"email": "k_gerasimov1965@postgrespro.ru", "phone": "+70540410065"}
0005434312397	CE90D3	9518 537647	ALEKSANDR ANTONOV	{"phone": "+70286685224"}
0005434312398	CE90D3	8834 688966	ALINA MOROZOVA	{"email": "alina-morozova_03011971@postgrespro.ru", "phone": "+70487019019"}
0005434319220	4C0570	7438 416896	VERA MAKAROVA	{"phone": "+70518121310"}
0005434319251	F6905A	7803 665251	VLADIMIR MIRONOV	{"phone": "+70380402284"}
0005434319141	DDA640	1436 009271	SVETLANA KOLESNIKOVA	{"phone": "+70488529719"}
0005434319142	DDA640	2217 560999	NATALYA LEBEDEVA	{"phone": "+70788312676"}
0005434319143	07DFE7	9693 093709	TATYANA VLASOVA	{"phone": "+70572046825"}
0005434319144	07DFE7	8494 102387	KIRILL IVANOV	{"phone": "+70956198102"}
0005434319145	A0E13A	7053 307096	EVGENIY MAKAROV	{"email": "makarovevgeniy_1973@postgrespro.ru", "phone": "+70083260516"}
0005434319146	0ABDC2	2177 594121	MARIYA POPOVA	{"email": "mariya_popova.041975@postgrespro.ru", "phone": "+70807067045"}
0005434319147	0ABDC2	2624 304042	ALEKSANDR KUZNECOV	{"phone": "+70590437287"}
0005434319148	7E02E5	1989 503907	NINA KOROLEVA	{"phone": "+70320724771"}
0005434319149	7E02E5	4541 654600	LYUBOV PETROVA	{"email": "l_petrova1973@postgrespro.ru", "phone": "+70195608837"}
0005434319150	2DFEDE	8414 442864	GENNADIY ANDREEV	{"email": "andreev-gennadiy_01021975@postgrespro.ru", "phone": "+70093703429"}
0005434319151	14400A	4394 931955	ALEKSANDR PETROV	{"phone": "+70471062531"}
0005434319152	3436D6	2652 044676	NIKITA MOISEEV	{"email": "nikita.moiseev-091968@postgrespro.ru", "phone": "+70309522197"}
0005434319153	3436D6	8504 903642	ANNA KUZNECOVA	{"phone": "+70021034434"}
0005434319154	F6B155	4931 429923	ALEKSEY OSIPOV	{"email": "aosipov-111955@postgrespro.ru", "phone": "+70552220230"}
0005434319155	852492	2924 252091	ALEKSANDR POPOV	{"phone": "+70751784165"}
0005434319156	852492	5239 903202	GRIGORIY MATVEEV	{"phone": "+70380383391"}
0005434319157	8AD1CD	7643 408208	ANATOLIY IVANOV	{"phone": "+70627871421"}
0005434319158	728765	0878 021439	OLESYA ZAKHAROVA	{"email": "o.zakharova23011981@postgrespro.ru", "phone": "+70314057674"}
0005434319159	728765	4249 468793	ANNA TROFIMOVA	{"phone": "+70584907677"}
0005434319160	4736E1	5795 038762	PETR SOROKIN	{"phone": "+70903535491"}
0005434319161	4736E1	2065 228331	VIKTOR DAVYDOV	{"email": "v-davydov-061959@postgrespro.ru", "phone": "+70508682479"}
0005434319162	4736E1	6941 570468	ALEKSANDR NIKITIN	{"phone": "+70882962955"}
0005434319163	A4A72C	8651 140314	VLADIMIR SIDOROV	{"email": "sidorovvladimir011977@postgrespro.ru", "phone": "+70261916112"}
0005434319165	3A11A5	2788 399970	OLGA SEMENOVA	{"email": "semenovao_1975@postgrespro.ru", "phone": "+70590461894"}
0005434319166	84E26C	2186 199881	ALEKSANDRA SAVELEVA	{"email": "aleksandrasaveleva_101980@postgrespro.ru", "phone": "+70332491280"}
0005434319167	84E26C	2495 235870	IRINA BARANOVA	{"phone": "+70952632894"}
0005434319168	E1AE68	5750 596722	TAISIYA NIKITINA	{"phone": "+70137950954"}
0005434319169	E1AE68	9796 607138	SNEZHANA VOLKOVA	{"email": "volkova_s.23091964@postgrespro.ru", "phone": "+70696827665"}
0005434319170	CC9699	9449 653694	VLADIMIR MAKAROV	{"phone": "+70971162919"}
0005434319171	CC9699	2853 917614	SERGEY MEDVEDEV	{"phone": "+70781231942"}
0005434319172	741C57	9165 689675	SANIYA KONOVALOVA	{"email": "s_konovalova-071975@postgrespro.ru", "phone": "+70978860939"}
0005434319173	741C57	8016 177036	EKATERINA TITOVA	{"phone": "+70056438602"}
0005434319174	08BF00	1863 420810	OLEG KOROLEV	{"phone": "+70045507847"}
0005434319175	08BF00	6023 469389	DIANA LOGINOVA	{"email": "diana.loginova23031973@postgrespro.ru", "phone": "+70858743574"}
0005434319176	068DFC	9134 801480	VLADIMIR MIKHAYLOV	{"phone": "+70804871795"}
0005434319177	4A79E4	4120 641404	ELENA ABRAMOVA	{"phone": "+70601126815"}
0005434319178	3143CC	9863 118499	ELIZAVETA KONDRATEVA	{"email": "elizaveta_kondrateva1966@postgrespro.ru", "phone": "+70704074735"}
0005434319179	958B0B	3257 281721	ALEKSEY YAKOVLEV	{"email": "yakovlevaleksey-1985@postgrespro.ru", "phone": "+70959981813"}
0005434319180	DDDAE8	4265 057517	OLGA TITOVA	{"email": "titova.o041978@postgrespro.ru", "phone": "+70075458434"}
0005434319181	4E95DA	4256 868662	IRINA GORBUNOVA	{"phone": "+70546301087"}
0005434319182	8FC680	5866 577519	ANDREY NIKOLAEV	{"phone": "+70556368905"}
0005434319183	1E9D79	5160 630629	VLADIMIR VOLKOV	{"email": "v-volkov-13071968@postgrespro.ru", "phone": "+70571664249"}
0005434319184	D290DE	3518 176563	YULIYA FADEEVA	{"email": "fadeeva-y1972@postgrespro.ru", "phone": "+70469821845"}
0005434319185	C479FC	7836 547522	IRINA ALEKSEEVA	{"email": "i.alekseeva-081980@postgrespro.ru", "phone": "+70032558817"}
0005434319186	284DCE	7122 164630	EVGENIY ALEKSEEV	{"phone": "+70598931183"}
0005434319187	8D702A	9611 120223	VLADIMIR GORBUNOV	{"email": "gorbunovvladimir-101969@postgrespro.ru", "phone": "+70500763907"}
0005434319188	C479EF	7245 467716	VLADIMIR STEPANOV	{"phone": "+70852591153"}
0005434319189	D36D6D	5984 370502	ALEKSANDR GRIGOREV	{"email": "agrigorev-1971@postgrespro.ru", "phone": "+70684198434"}
0005434319190	0F48D8	8966 355508	FARIT KOROLEV	{"phone": "+70734311657"}
0005434319191	F927DE	7408 988609	ALEKSANDRA NIKITINA	{"email": "a.nikitina.28101971@postgrespro.ru", "phone": "+70295329704"}
0005434319192	F927DE	3506 811871	MAKSIM GORBUNOV	{"email": "gorbunovmaksim-1983@postgrespro.ru", "phone": "+70917249685"}
0005434319193	201122	7639 533629	ELENA ZHURAVLEVA	{"phone": "+70792011017"}
0005434319194	86A6D8	5209 833968	ILYA KARPOV	{"email": "karpov_ilya.051975@postgrespro.ru", "phone": "+70912998164"}
0005434319195	86A6D8	0447 135582	LIDIYA FADEEVA	{"email": "lidiya-fadeeva.08011977@postgrespro.ru", "phone": "+70017167871"}
0005434319196	117572	8036 557966	SERGEY SOROKIN	{"email": "sorokin_s081986@postgrespro.ru", "phone": "+70037932581"}
0005434319197	960A17	0029 341408	ALFIYA VLASOVA	{"email": "alfiya_vlasova_1963@postgrespro.ru", "phone": "+70290669192"}
0005434319198	960A17	1361 273333	ANDREY TIKHONOV	{"email": "andrey_tikhonov.111967@postgrespro.ru", "phone": "+70465952648"}
0005434319199	23B826	1889 857768	VASILIY BONDARENKO	{"email": "vbondarenko.031977@postgrespro.ru", "phone": "+70855639503"}
0005434319200	23B826	2687 875107	POLINA NIKITINA	{"email": "pnikitina.021978@postgrespro.ru", "phone": "+70736146775"}
0005434319201	E5519C	8341 162808	VLADIMIR ABRAMOV	{"email": "vladimir.abramov26071971@postgrespro.ru", "phone": "+70976376898"}
0005434319202	D01C7D	2008 133893	LIDIYA ZAYCEVA	{"email": "lidiyazayceva_121983@postgrespro.ru", "phone": "+70860467411"}
0005434319203	D01C7D	3262 844851	VLADIMIR KOROLEV	{"email": "v_korolev.071969@postgrespro.ru", "phone": "+70346085444"}
0005434319204	D01C7D	1479 011964	GALINA KOMAROVA	{"email": "komarovagalina_081974@postgrespro.ru", "phone": "+70098382083"}
0005434319205	074B48	0924 589490	TAMARA DAVYDOVA	{"phone": "+70266318195"}
0005434319206	074B48	5759 079340	KARINA GORBUNOVA	{"phone": "+70031015639"}
0005434319207	641362	7537 146055	VLADIMIR FOMIN	{"email": "vfomin111979@postgrespro.ru", "phone": "+70504417298"}
0005434319208	641362	0862 408104	ALEKSANDR FEDOROV	{"phone": "+70103731854"}
0005434319209	C7B685	6928 841180	LEONID ZAYCEV	{"phone": "+70266794375"}
0005434319210	80E6D5	2082 862446	DMITRIY SOKOLOV	{"email": "sokolovd.051973@postgrespro.ru", "phone": "+70502918839"}
0005434319211	9CE11F	3875 321724	NADEZHDA ORLOVA	{"phone": "+70799574279"}
0005434319212	4A197C	1077 712000	ANNA PETROVA	{"email": "anna.petrova_15021977@postgrespro.ru", "phone": "+70848088008"}
0005434319213	E79297	2522 448525	NADEZHDA FILIPPOVA	{"email": "n_filippova_1965@postgrespro.ru", "phone": "+70497276772"}
0005434319214	79C27A	8031 147976	ROZALIYA IVANOVA	{"email": "r_ivanova.17011977@postgrespro.ru", "phone": "+70048595790"}
0005434319215	79C27A	4159 422632	STANISLAV KUZMIN	{"email": "s_kuzmin-04041968@postgrespro.ru", "phone": "+70175864470"}
0005434319216	7FB52D	2494 860262	MARIYA GUSEVA	{"email": "gusevam.051975@postgrespro.ru", "phone": "+70056187353"}
0005434319217	7FB52D	1525 265606	VIKTOR KOROLEV	{"email": "korolev-v_1977@postgrespro.ru", "phone": "+70560356096"}
0005434319218	D89839	2454 897047	VLADIMIR VOLKOV	{"email": "volkov-v.1961@postgrespro.ru", "phone": "+70665890721"}
0005434319219	4C0570	4158 348122	SVETLANA KONOVALOVA	{"phone": "+70192656803"}
0005434319221	8B9271	7247 805904	SVETLANA IVANOVA	{"phone": "+70560940513"}
0005434319222	C80B67	7179 700470	TATYANA SIDOROVA	{"email": "sidorova-t1975@postgrespro.ru", "phone": "+70614873776"}
0005434319223	C80B67	4452 944573	VIKTOR VOLKOV	{"email": "volkov_v-1955@postgrespro.ru", "phone": "+70135932670"}
0005434319224	3B5AC9	1288 785765	ALEKSANDR YAKOVLEV	{"phone": "+70066400349"}
0005434319225	049B82	4187 451796	PELAGEYA NIKITINA	{"email": "p_nikitina-18021969@postgrespro.ru", "phone": "+70878384040"}
0005434319226	049B82	4221 661685	GALINA ALEKSEEVA	{"email": "alekseeva_galina_111982@postgrespro.ru", "phone": "+70080060676"}
0005434319227	EBA439	0253 917355	GENNADIY ROMANOV	{"email": "romanov-gennadiy-081980@postgrespro.ru", "phone": "+70576334829"}
0005434319228	9F67E2	3627 825060	MARK MOROZOV	{"phone": "+70894488472"}
0005434319229	61842D	3076 715277	MARIYA ALEKSEEVA	{"phone": "+70971348032"}
0005434319230	61842D	0606 113149	ALEKSANDR KISELEV	{"email": "aleksandrkiselev-1979@postgrespro.ru", "phone": "+70755223000"}
0005434319231	97AE97	1750 241002	MARIYA LOGINOVA	{"phone": "+70935592598"}
0005434319232	6D4782	5510 842532	VIKTOR TIMOFEEV	{"phone": "+70782634445"}
0005434319233	029401	4639 473371	VIKTOR MIRONOV	{"email": "vmironov.18091978@postgrespro.ru", "phone": "+70465029509"}
0005434319234	029401	8075 587664	NATALYA DENISOVA	{"email": "denisova-natalya011969@postgrespro.ru", "phone": "+70035504195"}
0005434319235	029401	8117 979826	VALERIY TIMOFEEV	{"phone": "+70687667636"}
0005434319236	789F34	8647 016371	ZOYA EGOROVA	{"phone": "+70003002406"}
0005434319237	E41667	4524 561910	GENNADIY STEPANOV	{"email": "gstepanov.1971@postgrespro.ru", "phone": "+70014004461"}
0005434319238	E41667	5848 217111	ALEKSANDR ABRAMOV	{"phone": "+70090716867"}
0005434319239	C39816	2949 161119	TAMARA SOLOVEVA	{"phone": "+70546868273"}
0005434319240	C39816	7705 058231	VLADIMIR ISAEV	{"phone": "+70208474479"}
0005434319241	95B241	3255 211420	ALEKSANDR POPOV	{"email": "aleksandr_popov.1978@postgrespro.ru", "phone": "+70980699920"}
0005434319242	F066B6	2934 237526	IVAN SOKOLOV	{"phone": "+70071546626"}
0005434319243	535157	3946 864836	ALBINA MALYSHEVA	{"email": "a.malysheva-24051978@postgrespro.ru", "phone": "+70098967377"}
0005434319244	2D2669	7200 947795	YURIY ZAYCEV	{"phone": "+70267384180"}
0005434319245	F7D451	2655 097795	ANNA ALEKSANDROVA	{"phone": "+70676515463"}
0005434319246	C179BD	9094 277188	ALEKSEY SCHERBAKOV	{"email": "alekseyscherbakov1973@postgrespro.ru", "phone": "+70410342884"}
0005434319247	5E9C6F	8772 975874	EDUARD MIRONOV	{"phone": "+70713852306"}
0005434319248	DDC5E4	3013 411779	DARYA CHERNOVA	{"phone": "+70358714970"}
0005434319249	551897	7796 422545	EDGAR MAKSIMOV	{"phone": "+70249054133"}
0005434319250	551897	7950 728168	LARISA TIKHONOVA	{"phone": "+70859475008"}
0005434319252	582FBA	8962 618636	YULIYA OSIPOVA	{"phone": "+70281738817"}
0005434319253	4F9130	6819 804246	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay.13101970@postgrespro.ru", "phone": "+70884383906"}
0005434319254	E0F422	1287 090538	VIKTOR KUZNECOV	{"phone": "+70197862300"}
0005434319255	2F039F	4056 143382	VLADIMIR IVANOV	{"phone": "+70466473711"}
0005434319256	6B4E69	3580 876510	ILMIRA NAZAROVA	{"phone": "+70126896312"}
0005434319257	E19649	2891 793216	ANDREY SOROKIN	{"email": "sorokin-andrey.1977@postgrespro.ru", "phone": "+70667663686"}
0005434319258	2DEF0E	8888 912455	LYUDMILA SEMENOVA	{"phone": "+70492542883"}
0005434319259	66F7D0	9179 813012	VLADIMIR POPOV	{"phone": "+70106283339"}
0005434319260	66F7D0	8969 004528	ALEKSEY ABRAMOV	{"phone": "+70824038757"}
0005434319261	66F7D0	9608 964221	MARINA BORISOVA	{"phone": "+70078218995"}
0005434319262	E432AA	7884 610579	ROMAN KOROLEV	{"email": "korolevr.09101968@postgrespro.ru", "phone": "+70692840659"}
0005434319263	EA502B	3620 642914	VLADIMIR TIMOFEEV	{"email": "timofeev_vladimir.27091972@postgrespro.ru", "phone": "+70930195046"}
0005434319264	CA77EB	3795 028207	VERA GUSEVA	{"email": "gusevavera_23021973@postgrespro.ru", "phone": "+70993912872"}
0005434319265	CA77EB	4772 779691	ANDREY ZAKHAROV	{"email": "a.zakharov.07121974@postgrespro.ru", "phone": "+70689472004"}
0005434319266	06F27E	9886 923860	MARIYA SERGEEVA	{"email": "sergeeva_mariya_23021970@postgrespro.ru", "phone": "+70155720226"}
0005434319267	06F27E	3935 807093	NINA MATVEEVA	{"phone": "+70965996109"}
0005434319268	5F641F	2453 647710	LARISA IVANOVA	{"email": "ivanovalarisa_13121979@postgrespro.ru", "phone": "+70524397491"}
0005434319269	5DEC33	9267 138908	YAROSLAV BELOV	{"phone": "+70822568648"}
0005434319270	3D1314	0613 091677	ELIZAVETA ZAKHAROVA	{"phone": "+70125676722"}
0005434319271	31B8CA	1233 264975	EVGENIY VOROBEV	{"phone": "+70531650267"}
0005434319272	31B8CA	4119 190071	ALBINA KONOVALOVA	{"email": "konovalovaa.031955@postgrespro.ru", "phone": "+70016026314"}
0005434319273	730228	3202 387838	EVGENIY SAVELEV	{"phone": "+70127135592"}
0005434319274	730228	2693 032292	EVGENIY BONDARENKO	{"phone": "+70544701686"}
0005434319275	BE48AE	9946 082589	SOFIYA SOLOVEVA	{"phone": "+70585933667"}
0005434319276	3719B6	3461 695507	NADEZHDA FEDOROVA	{"phone": "+70375483475"}
0005434319277	40D885	1867 831670	KIRILL ALEKSEEV	{"phone": "+70786788746"}
0005434319278	40D885	9049 570724	OLGA ARKHIPOVA	{"phone": "+70480585262"}
0005434319279	2F9138	7752 437133	SERGEY NOVIKOV	{"email": "novikov_s1969@postgrespro.ru", "phone": "+70308149580"}
0005434319280	2F9138	0500 484582	VALENTINA MOISEEVA	{"phone": "+70421487508"}
0005434319281	E8B93C	5987 958983	LYUBOV KUZMINA	{"email": "kuzmina_lyubov16051961@postgrespro.ru", "phone": "+70409576742"}
0005434319282	A8E4C8	3542 327780	KARINA GUSEVA	{"email": "guseva.k_13021983@postgrespro.ru", "phone": "+70979746803"}
0005434319283	60A0BD	0250 941823	ALEKSEY KARPOV	{"phone": "+70341190872"}
0005434319284	7AC378	3563 984414	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr_10121975@postgrespro.ru", "phone": "+70538008123"}
0005434319285	7AC378	0020 893167	ANASTASIYA MEDVEDEVA	{"phone": "+70279184087"}
0005434319286	7AC378	5335 637529	STANISLAV MATVEEV	{"phone": "+70823848713"}
0005434319287	70B8C9	1117 858606	GALINA TIMOFEEVA	{"phone": "+70033769469"}
0005434319288	2EC364	7386 429817	NADEZHDA NIKOLAEVA	{"email": "nikolaeva_nadezhda.09021980@postgrespro.ru", "phone": "+70427054576"}
0005434319289	641647	7443 534900	EVGENIY ROMANOV	{"email": "evgeniy-romanov-03121970@postgrespro.ru", "phone": "+70358177513"}
0005434319290	440E5D	5483 388999	MIKHAIL VASILEV	{"email": "vasilevm-22101968@postgrespro.ru", "phone": "+70658782207"}
0005434319291	86203C	3591 129425	VALERIY ALEKSEEV	{"phone": "+70387359177"}
0005434319292	86203C	4417 091823	DMITRIY TIMOFEEV	{"email": "timofeevdmitriy30041966@postgrespro.ru", "phone": "+70269294534"}
0005434319293	6F1210	8899 857126	ANDREY MEDVEDEV	{"email": "andrey-medvedev_18101973@postgrespro.ru", "phone": "+70499499711"}
0005434319294	6F1210	4327 723676	NIKOLAY MAKAROV	{"email": "makarovnikolay_01071966@postgrespro.ru", "phone": "+70565970392"}
0005434319295	D6E017	2886 382777	ALEKSANDR MOROZOV	{"email": "morozov_a121974@postgrespro.ru", "phone": "+70031193734"}
0005434319296	D6E017	7700 112851	VLADIMIR MATVEEV	{"email": "vladimir-matveev_29061971@postgrespro.ru", "phone": "+70683591350"}
0005434319297	82F2BB	6571 168877	LARISA ISAEVA	{"email": "isaeva_l.051974@postgrespro.ru", "phone": "+70455210731"}
0005434319298	453D7F	4394 967035	VITALIY ILIN	{"email": "vitaliy-ilin-1979@postgrespro.ru", "phone": "+70880052313"}
0005434319299	7CFF10	0719 847102	NIKOLAY POPOV	{"phone": "+70173087027"}
0005434319300	E545E8	6738 249331	LYUDMILA MAKSIMOVA	{"email": "l_maksimova_13051973@postgrespro.ru", "phone": "+70920739596"}
0005434319301	E545E8	8062 584457	ALEKSEY KAZAKOV	{"email": "kazakov_a_1978@postgrespro.ru", "phone": "+70931000637"}
0005434319302	554C5C	2173 092060	VLADIMIR SHEVCHENKO	{"phone": "+70417014046"}
0005434319303	554C5C	4123 912760	ALEKSANDRA ROMANOVA	{"email": "aleksandra-romanova.1984@postgrespro.ru", "phone": "+70557796938"}
0005434319304	554C5C	6053 947452	IRINA EGOROVA	{"phone": "+70806364639"}
0005434319305	A7937E	4409 238428	DARYA FOMINA	{"email": "fominadarya-1974@postgrespro.ru", "phone": "+70918969651"}
0005434319306	FF3D12	8698 299853	GALINA ARKHIPOVA	{"email": "arkhipova-g-071961@postgrespro.ru", "phone": "+70664700438"}
0005434319307	60EEE5	6366 436389	NIKOLAY KUZMIN	{"phone": "+70894534528"}
0005434319308	19DCAE	4539 511657	ARTEM PAVLOV	{"email": "pavlov.artem_1968@postgrespro.ru", "phone": "+70442492226"}
0005434319309	D87B54	4243 898528	VLADIMIR FOMIN	{"phone": "+70083503134"}
0005434319310	C69AFA	2759 888121	MARIYA ISAEVA	{"phone": "+70687986220"}
0005434319311	88B649	8383 066113	IRINA CHERNOVA	{"email": "chernova-i_101971@postgrespro.ru", "phone": "+70922359723"}
0005434319312	59B285	9337 879436	ALEKSANDR ROMANOV	{"email": "aleksandr-romanov-1967@postgrespro.ru", "phone": "+70576605970"}
0005434319313	B24654	0580 936130	SERGEY ZAKHAROV	{"email": "s_zakharov021980@postgrespro.ru", "phone": "+70097660278"}
0005434319314	B24654	1398 727003	SVETLANA DAVYDOVA	{"email": "davydova-svetlana.27101964@postgrespro.ru", "phone": "+70792683692"}
0005434319315	78E027	4538 447254	ALEKSEY KUZMIN	{"email": "kuzmina.03061978@postgrespro.ru", "phone": "+70387972046"}
0005434319316	78E027	6694 036509	ANASTASIYA KULIKOVA	{"email": "kulikova_anastasiya_25041970@postgrespro.ru", "phone": "+70892023641"}
0005434319317	B1AAC4	6938 937357	YULIYA RODIONOVA	{"email": "yrodionova_17101966@postgrespro.ru", "phone": "+70208398965"}
0005434319318	E9E2CD	9648 343152	RITA POPOVA	{"phone": "+70416831860"}
0005434319319	A1BA7E	3573 148484	OKSANA ANTONOVA	{"phone": "+70749414101"}
0005434319320	A1BA7E	8950 201767	VERA VLASOVA	{"email": "vvlasova_041977@postgrespro.ru", "phone": "+70299871015"}
0005434319321	A1BA7E	8755 046111	EVGENIY BORISOV	{"email": "eborisov-1964@postgrespro.ru", "phone": "+70019145430"}
0005434319322	1CE16D	6216 473686	MARIYA FEDOROVA	{"phone": "+70578871901"}
0005434319323	6D3176	4023 243170	SERGEY ALEKSANDROV	{"email": "sergey-aleksandrov.1968@postgrespro.ru", "phone": "+70734181151"}
0005434319324	6D3176	1366 023437	RUMIYA DENISOVA	{"phone": "+70383139534"}
0005434319325	AA9A91	7479 142866	EVGENIY MARTYNOV	{"email": "martynov.e-071968@postgrespro.ru", "phone": "+70726171360"}
0005434319326	AA9A91	8679 782906	VLADIMIR IVANOV	{"email": "vladimir-ivanov_031970@postgrespro.ru", "phone": "+70758147959"}
0005434319327	919182	1935 877451	ELENA KARPOVA	{"phone": "+70524445845"}
0005434319328	21DAA6	8860 585573	ALEKSANDR KARPOV	{"email": "karpov_a.1966@postgrespro.ru", "phone": "+70716546985"}
0005434319329	E03900	2061 884069	ALEKSANDR KUZNECOV	{"phone": "+70385563209"}
0005434319330	703F19	5684 721234	DMITRIY GORBUNOV	{"email": "gorbunov.d071979@postgrespro.ru", "phone": "+70979028382"}
0005434319331	1743F5	2730 415645	VITALIY ALEKSEEV	{"email": "alekseev_vitaliy-30061968@postgrespro.ru", "phone": "+70434693818"}
0005434319445	1C0C6D	2476 799858	YULIYA MIRONOVA	{"phone": "+70423611309"}
0005434319332	1743F5	3704 956149	TAMARA DMITRIEVA	{"email": "tamara_dmitrieva1983@postgrespro.ru", "phone": "+70382616883"}
0005434319333	1743F5	1416 580969	EVGENIY VOLKOV	{"email": "volkov_evgeniy.28011974@postgrespro.ru", "phone": "+70208125516"}
0005434319334	1743F5	2553 672349	NADEZHDA FADEEVA	{"phone": "+70074237279"}
0005434319335	0CB7E0	3336 139829	ANDREY ZHURAVLEV	{"phone": "+70323081256"}
0005434319336	93688E	8068 761499	NADEZHDA MELNIKOVA	{"email": "melnikovan-08111973@postgrespro.ru", "phone": "+70023229138"}
0005434319337	93688E	1322 212407	GENNADIY NIKOLAEV	{"email": "nikolaev_g051969@postgrespro.ru", "phone": "+70425037508"}
0005434319338	CEBEAA	2570 193165	ARTEM KUZNECOV	{"email": "artem.kuznecov-18061973@postgrespro.ru", "phone": "+70382679991"}
0005434319339	CEBEAA	7634 644580	LYUBOV CHERNOVA	{"phone": "+70616154554"}
0005434319340	EDF05C	9253 425665	NATALYA GORBUNOVA	{"phone": "+70149944409"}
0005434319341	B01878	7994 012403	ALESYA ILINA	{"email": "ilina.alesya.031981@postgrespro.ru", "phone": "+70652043366"}
0005434319342	72E033	9656 649732	OLGA LOGINOVA	{"email": "ologinova.28081975@postgrespro.ru", "phone": "+70228167800"}
0005434319343	8147A5	6914 536152	TAMARA MIRONOVA	{"email": "tamara.mironova_051976@postgrespro.ru", "phone": "+70739302132"}
0005434319344	A12ABD	6610 630684	NIKOLAY VASILEV	{"email": "nikolay.vasilev-021976@postgrespro.ru", "phone": "+70668759738"}
0005434319345	B0D659	3895 894800	DMITRIY BELOV	{"phone": "+70203464472"}
0005434319346	AAE2A7	3872 467808	ALEKSANDR MIRONOV	{"phone": "+70844755550"}
0005434319347	4AB367	2099 914587	ELENA ANDREEVA	{"phone": "+70522965209"}
0005434319348	F7C680	1961 465435	VLADISLAV VASILEV	{"email": "vasilev_v061970@postgrespro.ru", "phone": "+70073786683"}
0005434319349	66B17D	3557 306690	YULIYA DANILOVA	{"email": "danilovayuliya.25121971@postgrespro.ru", "phone": "+70306183921"}
0005434319350	66B17D	3424 036284	SERGEY IVANOV	{"phone": "+70849333059"}
0005434319351	747995	7821 072367	DARYA ERMAKOVA	{"phone": "+70892500377"}
0005434319352	D74417	8093 268565	VLADIMIR CHERNOV	{"phone": "+70515737522"}
0005434319353	D74417	1353 004079	ANDREY RODIONOV	{"phone": "+70609040421"}
0005434319354	5BE56E	1693 657288	PAVEL ORLOV	{"email": "orlov_pavel121966@postgrespro.ru", "phone": "+70020597097"}
0005434319355	5BE56E	2729 739294	SVETLANA KOMAROVA	{"phone": "+70063130324"}
0005434319356	5BE56E	5491 068943	VIKTOR TIKHONOV	{"phone": "+70297578401"}
0005434319357	1FDD23	6592 585578	NATALYA SMIRNOVA	{"email": "smirnova.n-1978@postgrespro.ru", "phone": "+70153604741"}
0005434319358	1FDD23	7419 172980	DMITRIY DMITRIEV	{"email": "d_dmitriev-1971@postgrespro.ru", "phone": "+70399922509"}
0005434319359	3F7D88	4618 035638	ANATOLIY RODIONOV	{"phone": "+70375478088"}
0005434319360	BD9093	3502 019794	SERGEY ANDREEV	{"email": "sandreev-07011980@postgrespro.ru", "phone": "+70623511861"}
0005434319361	BD9093	7804 879447	ELENA GUSEVA	{"phone": "+70775604953"}
0005434319475	A49B00	9334 733648	SVETLANA TIKHONOVA	{"phone": "+70631489243"}
0005434319362	CC0A75	7738 310788	MIKHAIL DMITRIEV	{"email": "m.dmitriev_03061977@postgrespro.ru", "phone": "+70340865172"}
0005434319363	CC0A75	8144 311644	ELVIRA SCHERBAKOVA	{"email": "e.scherbakova-1977@postgrespro.ru", "phone": "+70538373914"}
0005434319364	564AEE	3142 375361	ANTONINA VOROBEVA	{"phone": "+70107267793"}
0005434319365	564AEE	6465 955029	ALEKSANDR ILIN	{"email": "a.ilin.041973@postgrespro.ru", "phone": "+70815493536"}
0005434319366	564AEE	7545 568924	ALEKSANDR GERASIMOV	{"email": "aleksandr.gerasimov071980@postgrespro.ru", "phone": "+70927948309"}
0005434319367	883D5C	5723 376374	BORIS ANDREEV	{"email": "boris_andreev.19061976@postgrespro.ru", "phone": "+70757421539"}
0005434319368	1FFA7B	3413 336253	ELENA VASILEVA	{"phone": "+70102436576"}
0005434319369	1FFA7B	8527 081875	ELIZAVETA ZAKHAROVA	{"email": "zakharova.elizaveta_09061965@postgrespro.ru", "phone": "+70210164592"}
0005434319370	A275A4	6291 697811	YURIY ILIN	{"email": "y.ilin20011947@postgrespro.ru", "phone": "+70346039179"}
0005434319371	A275A4	5605 198914	SERGEY ALEKSEEV	{"email": "salekseev.19021967@postgrespro.ru", "phone": "+70340245497"}
0005434319372	CFA9A1	1763 854610	ALEKSANDR ROMANOV	{"phone": "+70222989705"}
0005434319373	51C317	9758 110448	ELENA BOGDANOVA	{"email": "bogdanova_e.1966@postgrespro.ru", "phone": "+70564334887"}
0005434319374	CF9EAB	7292 702602	ANTON NOVIKOV	{"phone": "+70844617170"}
0005434319375	CF9EAB	8230 615896	NATALYA SCHERBAKOVA	{"email": "natalyascherbakova.081970@postgrespro.ru", "phone": "+70189484296"}
0005434319376	2FC376	4570 372599	SERGEY MAKSIMOV	{"phone": "+70814884349"}
0005434319377	53E62D	2705 354020	YULIYA MIRONOVA	{"phone": "+70096306134"}
0005434319378	9B76D3	7149 198477	POLINA POTAPOVA	{"phone": "+70820678835"}
0005434319379	1FD99F	6957 933895	EKATERINA MOISEEVA	{"phone": "+70473270910"}
0005434319380	1FD99F	5226 673634	VERA BOGDANOVA	{"phone": "+70865638731"}
0005434319381	F225D6	1254 093292	SERGEY KUZNECOV	{"phone": "+70995250929"}
0005434319382	6809F6	6864 727416	NIKOLAY NIKOLAEV	{"phone": "+70023699512"}
0005434319383	9C069A	3861 164600	NATALYA EGOROVA	{"email": "natalya_egorova-041968@postgrespro.ru", "phone": "+70646297795"}
0005434319384	76E807	4580 093395	NINA NESTEROVA	{"phone": "+70399252637"}
0005434319385	A17745	3774 844909	ALEKSANDR VASILEV	{"phone": "+70374362414"}
0005434319386	A17745	5157 544566	ANDREY STEPANOV	{"email": "stepanov-andrey.16051974@postgrespro.ru", "phone": "+70137549711"}
0005434319387	62717A	9969 830037	MARIYA VASILEVA	{"phone": "+70867899407"}
0005434319388	D49984	5333 163851	ANTONINA YUDINA	{"email": "yudinaa_16081966@postgrespro.ru", "phone": "+70324227814"}
0005434319389	D49984	2533 938743	ELVIRA NIKITINA	{"phone": "+70063216475"}
0005434319390	DC3F8D	7937 346110	SHAVKAT KONOVALOV	{"email": "konovalov-s1971@postgrespro.ru", "phone": "+70184269727"}
0005434319391	C0244D	9133 602223	LYUBOV PAVLOVA	{"email": "pavloval.091968@postgrespro.ru", "phone": "+70280399903"}
0005434319392	D92010	0001 064904	ELENA CHERNOVA	{"phone": "+70271028651"}
0005434319393	7A1833	2927 813237	GALINA FROLOVA	{"phone": "+70594485385"}
0005434319394	3ADF68	4805 484520	STEPAN KUZMIN	{"email": "kuzmin-stepan1978@postgrespro.ru", "phone": "+70149087174"}
0005434319395	3ADF68	6676 121520	SERGEY FEDOROV	{"email": "fedorov_s.121976@postgrespro.ru", "phone": "+70022748485"}
0005434319396	8DCADF	7917 798273	RENAT PETROV	{"phone": "+70311755336"}
0005434319397	25A92B	9230 258738	VALENTINA KOROLEVA	{"phone": "+70685926339"}
0005434319398	C7DEA3	1188 975359	GENNADIY OSIPOV	{"phone": "+70616053037"}
0005434319399	4EAEB1	3518 789854	ALEKSANDRA NESTEROVA	{"phone": "+70995861775"}
0005434319400	CC1229	1659 056260	OLGA PETROVA	{"email": "petrova-o.101959@postgrespro.ru", "phone": "+70627468780"}
0005434319401	7C0C4F	8869 679523	ANASTASIYA NOVIKOVA	{"phone": "+70505177229"}
0005434319402	12C71F	1415 173827	OLGA LOGINOVA	{"phone": "+70583177018"}
0005434319403	503A8D	6412 438807	KSENIYA KOZLOVA	{"email": "kseniya-kozlova_1979@postgrespro.ru", "phone": "+70056913827"}
0005434319404	1EB117	4492 050776	ARTEM MIKHAYLOV	{"phone": "+70005474640"}
0005434319405	DC8791	8309 284516	ALEKSANDR SOKOLOV	{"phone": "+70987969949"}
0005434319406	CA59C1	5763 684755	DENIS KOZLOV	{"email": "dkozlov.101968@postgrespro.ru", "phone": "+70478736896"}
0005434319407	C3A61F	9402 716306	OLEG TIMOFEEV	{"email": "o.timofeev_071970@postgrespro.ru", "phone": "+70220785078"}
0005434319408	EE65DE	5488 406278	NINA VASILEVA	{"email": "vasilevan_101975@postgrespro.ru", "phone": "+70300538673"}
0005434319409	094281	4820 288354	VALENTINA ANDREEVA	{"email": "andreeva-valentina_1971@postgrespro.ru", "phone": "+70226822256"}
0005434319410	D8A38B	3306 792156	ANATOLIY KUZNECOV	{"email": "anatoliy.kuznecov_1990@postgrespro.ru", "phone": "+70869367122"}
0005434319411	33DD4E	9749 960157	VIKTOR KUZMIN	{"phone": "+70549897974"}
0005434319412	33DD4E	0081 762926	TATYANA NOVIKOVA	{"phone": "+70837592337"}
0005434319413	46DF1B	4605 186345	OLGA RYABOVA	{"email": "ryabova-olga1983@postgrespro.ru", "phone": "+70983496730"}
0005434319414	358EC6	0327 660233	NATALYA KUZNECOVA	{"phone": "+70444104185"}
0005434319415	358EC6	3552 158639	IRINA ALEKSANDROVA	{"phone": "+70746059276"}
0005434319416	D7441C	2583 602129	SERGEY ILIN	{"email": "ilin.sergey01061976@postgrespro.ru", "phone": "+70464472764"}
0005434319417	D7441C	7244 106182	SERGEY AFANASEV	{"phone": "+70984809976"}
0005434319644	31A269	6927 003474	OLGA ZHUKOVA	{"phone": "+70895901707"}
0005434319418	7F7BC2	6213 480396	RAISA SMIRNOVA	{"email": "smirnova-r-1971@postgrespro.ru", "phone": "+70159918467"}
0005434319419	1641A4	4336 344886	ALEKSEY NIKITIN	{"phone": "+70113352576"}
0005434319420	1641A4	3970 285109	ZHANNA MASLOVA	{"email": "maslovazhanna_17081971@postgrespro.ru", "phone": "+70278047910"}
0005434319421	1374F3	7016 205404	LEONID IVANOV	{"phone": "+70596415605"}
0005434319422	1374F3	0692 415366	VLADISLAV EGOROV	{"email": "egorov-v_02051980@postgrespro.ru", "phone": "+70612305350"}
0005434319423	A96BA4	4484 366603	VALERIY MIRONOV	{"phone": "+70361725536"}
0005434319424	AEBB0E	4659 170603	SERGEY RODIONOV	{"email": "rodionov.sergey111967@postgrespro.ru", "phone": "+70619563202"}
0005434319425	CBE365	1764 876561	VLADIMIR MELNIKOV	{"phone": "+70013102127"}
0005434319426	BAF864	6811 615925	ALEKSANDR FEDOROV	{"phone": "+70630754026"}
0005434319427	BAF864	8355 381059	RITA TARASOVA	{"email": "r.tarasova-1956@postgrespro.ru", "phone": "+70183755754"}
0005434319428	84FF51	6854 747499	KIRILL MOROZOV	{"email": "morozov.k-1976@postgrespro.ru", "phone": "+70139995542"}
0005434319429	84FF51	9587 812163	ELENA ZAYCEVA	{"phone": "+70970742803"}
0005434319430	84FF51	4781 348021	NINA GAVRILOVA	{"email": "n-gavrilova1971@postgrespro.ru", "phone": "+70458940413"}
0005434319431	674EFB	1299 824521	NINA GAVRILOVA	{"phone": "+70364228264"}
0005434319432	12786D	0805 122031	NATALYA FROLOVA	{"phone": "+70092513985"}
0005434319433	2CFA88	7329 229211	NATALYA NIKOLAEVA	{"phone": "+70914519603"}
0005434319434	70BDD7	9970 114656	IVAN ROMANOV	{"email": "i-romanov_17071976@postgrespro.ru", "phone": "+70988021904"}
0005434319435	2938E8	3095 320404	ALEKSEY KOROLEV	{"email": "koroleva_021961@postgrespro.ru", "phone": "+70022756739"}
0005434319436	CBF1E4	6128 856795	ALENA ANTONOVA	{"email": "a.antonova.021975@postgrespro.ru", "phone": "+70231487090"}
0005434319437	50E688	4680 715298	YULIYA SAVELEVA	{"phone": "+70474452863"}
0005434319438	50E688	9117 824401	IGOR SEMENOV	{"email": "semenovi.041970@postgrespro.ru", "phone": "+70327475992"}
0005434319439	7D44C6	4560 042310	PAVEL ALEKSANDROV	{"email": "aleksandrov_p.17121972@postgrespro.ru", "phone": "+70694413610"}
0005434319440	7D44C6	5488 268031	ELENA MIRONOVA	{"email": "mironova.elena-1984@postgrespro.ru", "phone": "+70838801655"}
0005434319441	21D89F	6943 690568	LYUBOV SERGEEVA	{"phone": "+70778199433"}
0005434319442	CFB1B4	7174 275287	ALBERT SHEVCHENKO	{"phone": "+70261947529"}
0005434319443	CFB1B4	2651 997390	VLADIMIR DAVYDOV	{"phone": "+70692562822"}
0005434319444	DF5079	4654 847179	NIKOLAY STEPANOV	{"email": "n.stepanov-1967@postgrespro.ru", "phone": "+70154139585"}
0005434319446	ACEDE8	0181 977728	KARINA KONOVALOVA	{"email": "konovalova_k_051983@postgrespro.ru", "phone": "+70335516544"}
0005434319447	E1C792	8226 769563	SVETLANA BELOVA	{"phone": "+70449817811"}
0005434319448	4BD696	0602 830383	ANDREY IVANOV	{"phone": "+70770673235"}
0005434319449	4BD696	5835 925990	MIKHAIL SHEVCHENKO	{"email": "m.shevchenko041969@postgrespro.ru", "phone": "+70378867839"}
0005434319450	3BD294	0336 298760	VALENTINA ZAKHAROVA	{"phone": "+70570626979"}
0005434319451	522990	0715 481346	LEONID POPOV	{"phone": "+70815255230"}
0005434319452	CA4980	6038 696522	LIDIYA NIKITINA	{"email": "lidiya_nikitina_1980@postgrespro.ru", "phone": "+70625360171"}
0005434319453	CA4980	5445 211958	ALEKSEY ANDREEV	{"email": "andreev_a-1970@postgrespro.ru", "phone": "+70686010428"}
0005434319454	CA4980	0129 253044	ZAKHAR KULIKOV	{"email": "kulikov.zakhar-011974@postgrespro.ru", "phone": "+70516327918"}
0005434319455	A9254C	6120 147009	VLADISLAV DMITRIEV	{"phone": "+70477145373"}
0005434319456	B6AEFE	3999 259612	SERGEY MOROZOV	{"email": "s.morozov13051965@postgrespro.ru", "phone": "+70282127822"}
0005434319457	FCB196	1071 645534	DENIS DMITRIEV	{"phone": "+70776924648"}
0005434319458	4243BE	2984 939423	EGOR ABRAMOV	{"phone": "+70319235752"}
0005434319459	7E9C64	9740 132440	DARYA POLYAKOVA	{"email": "polyakova_d-011975@postgrespro.ru", "phone": "+70852773538"}
0005434319460	55C5EF	6788 183178	ANASTASIYA KOROLEVA	{"email": "akoroleva-20121973@postgrespro.ru", "phone": "+70256728260"}
0005434319461	C03EC5	8588 301005	ANNA ZAYCEVA	{"email": "zayceva-anna_1972@postgrespro.ru", "phone": "+70323720066"}
0005434319462	C03EC5	7320 277447	NATALYA MASLOVA	{"email": "n_maslova.1964@postgrespro.ru", "phone": "+70590631520"}
0005434319463	638419	9635 506211	ANASTASIYA SOROKINA	{"phone": "+70647241167"}
0005434319464	B3E504	2540 245396	VIKTOR NIKITIN	{"phone": "+70001616012"}
0005434319465	B3E504	8217 074290	NADEZHDA SMIRNOVA	{"email": "nsmirnova_1965@postgrespro.ru", "phone": "+70675076199"}
0005434319466	C5D9D6	0633 632928	KIRA NIKOLAEVA	{"phone": "+70381905954"}
0005434319467	ED8B6C	6154 949697	ANASTASIYA SOKOLOVA	{"email": "sokolova_anastasiya.1980@postgrespro.ru", "phone": "+70451702957"}
0005434319468	D1CA6D	8462 702265	ALEKSANDRA FEDOROVA	{"phone": "+70328032170"}
0005434319469	A066B5	1996 362598	SVETLANA FROLOVA	{"email": "frolovasvetlana-02051972@postgrespro.ru", "phone": "+70170954667"}
0005434319470	563D56	6400 598402	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya_12101975@postgrespro.ru", "phone": "+70096110804"}
0005434319471	6DAE23	5939 635841	EVGENIY SOROKIN	{"email": "e.sorokin_27101970@postgrespro.ru", "phone": "+70437203921"}
0005434319472	6DAE23	7703 985236	GALINA BOGDANOVA	{"email": "galina.bogdanova-081973@postgrespro.ru", "phone": "+70102495066"}
0005434319473	6DAE23	1010 536314	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov_051986@postgrespro.ru", "phone": "+70455229512"}
0005434319474	1E6B57	8725 131123	AMINA NOVIKOVA	{"email": "amina.novikova15021966@postgrespro.ru", "phone": "+70361142823"}
0005434319476	90C739	6639 430520	NINEL SERGEEVA	{"email": "sergeevaninel_101973@postgrespro.ru", "phone": "+70245224690"}
0005434319477	90C739	0916 051076	VIKTOR NIKITIN	{"email": "viktor-nikitin.1962@postgrespro.ru", "phone": "+70884831669"}
0005434319478	6FCB5A	5259 999970	KIRILL KUDRYASHOV	{"email": "k-kudryashov.051961@postgrespro.ru", "phone": "+70333804098"}
0005434319479	735A0B	2048 641869	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy_051970@postgrespro.ru", "phone": "+70467076699"}
0005434319480	2D1A82	3275 312587	IRINA AFANASEVA	{"email": "irina-afanaseva-19081962@postgrespro.ru", "phone": "+70501780711"}
0005434319481	16B907	3906 068048	ANATOLIY KUZMIN	{"email": "kuzmin-anatoliy-101970@postgrespro.ru", "phone": "+70868521722"}
0005434319482	16B907	7245 908976	LYUDMILA DENISOVA	{"email": "l_denisova_1971@postgrespro.ru", "phone": "+70580689986"}
0005434319483	CD0451	5638 725063	MIKHAIL MOROZOV	{"phone": "+70333086989"}
0005434319484	5103FF	4657 849362	ANNA CHERNOVA	{"phone": "+70599675391"}
0005434319485	AC733E	8632 281881	VLADIMIR FILIPPOV	{"phone": "+70987004547"}
0005434319486	F2EE7F	7719 211865	BORIS BELOV	{"phone": "+70644337227"}
0005434319487	F2EE7F	7586 521342	EKATERINA KOZLOVA	{"email": "kozlova-e_071974@postgrespro.ru", "phone": "+70050775113"}
0005434319488	F24694	1826 521034	ANDREY ISAEV	{"phone": "+70580084546"}
0005434319489	E3842F	6506 184536	IVAN TARASOV	{"phone": "+70705665315"}
0005434319490	E3842F	2950 410528	RAISA ANDREEVA	{"phone": "+70054940918"}
0005434319491	E3842F	6770 621868	ANNA STEPANOVA	{"phone": "+70431206184"}
0005434319492	9921D9	2520 842390	IGOR KUZMIN	{"phone": "+70190264816"}
0005434319493	21FC5D	9788 507705	NADEZHDA DAVYDOVA	{"phone": "+70214794792"}
0005434319494	3EEC17	7296 343528	NIKOLAY NIKITIN	{"phone": "+70660840937"}
0005434319495	2419DB	4810 911350	ROMAN BELOV	{"phone": "+70653737641"}
0005434319496	5FF099	1180 963934	KONSTANTIN FROLOV	{"phone": "+70983558715"}
0005434319497	C67568	0159 769194	EVGENIY SMIRNOV	{"email": "e-smirnov.19051974@postgrespro.ru", "phone": "+70062752482"}
0005434319498	966F93	9150 163975	ANASTASIYA VOLKOVA	{"phone": "+70529188808"}
0005434319499	8F41CC	2959 181365	KIRILL GORBUNOV	{"phone": "+70200710737"}
0005434319500	FC4A28	7566 367062	ALEKSANDR NAUMOV	{"email": "naumovaleksandr_28011975@postgrespro.ru", "phone": "+70531287012"}
0005434319501	888CA5	4437 678717	VIKTOR KOROLEV	{"email": "korolev.viktor_21121974@postgrespro.ru", "phone": "+70817651363"}
0005434319502	9E8442	1112 077386	EKATERINA IVANOVA	{"phone": "+70320177806"}
0005434319503	9E8442	7063 848997	NIKOLAY MOROZOV	{"email": "nikolay-morozov-061974@postgrespro.ru", "phone": "+70942252906"}
0005434319504	BACF33	0734 588676	LYUBOV OVCHINNIKOVA	{"email": "lyubovovchinnikova011971@postgrespro.ru", "phone": "+70289423614"}
0005434319505	B8076A	8774 637866	NATALYA SERGEEVA	{"email": "natalyasergeeva_1981@postgrespro.ru", "phone": "+70937207446"}
0005434319506	B8076A	7632 012057	VLADIMIR ZAKHAROV	{"phone": "+70930692700"}
0005434319507	C3D8FB	2414 777076	DMITRIY GRIGOREV	{"email": "d-grigorev_17031970@postgrespro.ru", "phone": "+70554486734"}
0005434319508	24D56C	9156 533496	VLADIMIR NAZAROV	{"phone": "+70673152985"}
0005434319509	D5C9B3	5522 397342	EKATERINA DAVYDOVA	{"email": "davydova_ekaterina19041967@postgrespro.ru", "phone": "+70836847403"}
0005434319510	7EEB4A	0619 636031	ELENA ROMANOVA	{"phone": "+70784507117"}
0005434319511	55B070	3118 788135	IVAN VASILEV	{"email": "ivan.vasilev_101975@postgrespro.ru", "phone": "+70611638634"}
0005434319512	3EEBB3	0875 132563	IVAN ISAEV	{"email": "i_isaev11051967@postgrespro.ru", "phone": "+70694003504"}
0005434319513	3EEBB3	9460 009929	VIKTOR KOZLOV	{"email": "kozlov.v_051977@postgrespro.ru", "phone": "+70691113468"}
0005434319514	8286AA	4313 542380	EKATERINA KALININA	{"phone": "+70451954993"}
0005434319515	8286AA	5218 654851	LYUDMILA KOLESNIKOVA	{"phone": "+70795307983"}
0005434319516	EBC31B	8180 322931	ALSU PAVLOVA	{"email": "pavlova.alsu031966@postgrespro.ru", "phone": "+70165545460"}
0005434319517	AAC73B	2096 100799	VALENTIN BORISOV	{"email": "borisovv.20041967@postgrespro.ru", "phone": "+70933555368"}
0005434319518	D46B89	4953 854803	ANNA KUZNECOVA	{"phone": "+70036914974"}
0005434319519	161CE7	6494 305115	VLADISLAV NIKOLAEV	{"phone": "+70699540433"}
0005434319520	A86E21	9624 379685	ANNA FOMINA	{"phone": "+70572603109"}
0005434319521	F4917F	9576 768099	OLGA ANISIMOVA	{"email": "olga_anisimova-1970@postgrespro.ru", "phone": "+70753669777"}
0005434319522	87270E	1339 739317	DMITRIY SERGEEV	{"email": "dmitriy_sergeev04091976@postgrespro.ru", "phone": "+70479742253"}
0005434319523	80375A	6370 885489	ALEKSANDR MAKAROV	{"phone": "+70939522349"}
0005434319524	516EED	9165 024106	PETR KOZLOV	{"email": "kozlov-petr24021967@postgrespro.ru", "phone": "+70281272054"}
0005434319525	77FEF4	1047 876519	NATALYA DMITRIEVA	{"email": "natalya.dmitrieva31071967@postgrespro.ru", "phone": "+70997283107"}
0005434319526	83FF27	3631 793783	LIDIYA VASILEVA	{"phone": "+70017983104"}
0005434319527	7B4E05	2248 106689	IVAN MAKSIMOV	{"phone": "+70962863317"}
0005434319528	E07DCB	0772 286986	LIDIYA NAUMOVA	{"phone": "+70310974759"}
0005434319529	D53952	2849 484339	DARYA DAVYDOVA	{"email": "davydova-d101968@postgrespro.ru", "phone": "+70122711605"}
0005434319530	D53952	9896 901736	PETR FEDOROV	{"phone": "+70765071917"}
0005434319531	175BCA	6792 329466	GENNADIY SOROKIN	{"email": "gennadiysorokin17031974@postgrespro.ru", "phone": "+70083485538"}
0005434319532	2FC55D	1954 750270	ANDREY SMIRNOV	{"email": "smirnov-a.1975@postgrespro.ru", "phone": "+70155112591"}
0005434319533	F42013	5040 827860	ALEKSANDR KOROLEV	{"email": "korolev-a_08091969@postgrespro.ru", "phone": "+70140136040"}
0005434319534	F42013	0229 452270	ANDREY SIDOROV	{"phone": "+70257176969"}
0005434319535	A89C84	0212 048199	SERGEY ALEKSANDROV	{"phone": "+70408723315"}
0005434319536	BDC6B0	0184 951879	NIKOLAY FEDOTOV	{"email": "nikolay.fedotov.14091981@postgrespro.ru", "phone": "+70157921518"}
0005434319537	09C049	0199 419557	DENIS NIKOLAEV	{"phone": "+70439421965"}
0005434319538	09C049	9770 096377	YURIY MAKSIMOV	{"phone": "+70072995169"}
0005434319539	BB261B	6182 337298	LYUDMILA ZAYCEVA	{"phone": "+70092668024"}
0005434319540	BB261B	1546 496864	NIKOLAY ANDREEV	{"phone": "+70686849937"}
0005434319541	5071B3	9454 139136	ALEKSANDR MATVEEV	{"email": "a-matveev-04051980@postgrespro.ru", "phone": "+70024213452"}
0005434319542	5FB22F	6880 600730	LYUDMILA TROFIMOVA	{"phone": "+70912955912"}
0005434319543	5FB22F	4859 215735	LYUBOV VLASOVA	{"email": "lyubov.vlasova.121961@postgrespro.ru", "phone": "+70280287227"}
0005434319544	DDAE67	9845 127117	IVAN YAKOVLEV	{"email": "i.yakovlev_1976@postgrespro.ru", "phone": "+70126821171"}
0005434319545	DDAE67	6653 385717	OLGA ILINA	{"phone": "+70393553081"}
0005434319546	5E0D63	8122 633762	VALENTINA VOROBEVA	{"email": "valentinavorobeva_05101983@postgrespro.ru", "phone": "+70205972524"}
0005434319547	24DADA	7427 240399	NIKOLAY MAKAROV	{"email": "makarovnikolay_29081970@postgrespro.ru", "phone": "+70790296207"}
0005434319548	143122	0671 289065	IRINA OSIPOVA	{"email": "iosipova.1971@postgrespro.ru", "phone": "+70478619006"}
0005434319549	6CB001	9991 782602	GALINA IVANOVA	{"email": "ivanovagalina-101983@postgrespro.ru", "phone": "+70034320566"}
0005434319550	6CB001	3530 273813	YURIY SOKOLOV	{"phone": "+70209622966"}
0005434319551	8BB20E	0079 076919	TATYANA BORISOVA	{"phone": "+70919752030"}
0005434319552	882C51	7800 299292	TATYANA PETROVA	{"email": "petrova.t101975@postgrespro.ru", "phone": "+70723988587"}
0005434319553	4D6DE7	0570 422757	LIDIYA IVANOVA	{"phone": "+70381617281"}
0005434319554	E2019A	5268 764763	NATALYA TIKHONOVA	{"email": "tikhonovanatalya1982@postgrespro.ru", "phone": "+70717457851"}
0005434319555	E2019A	2150 784817	ANTONINA ANTONOVA	{"phone": "+70641797384"}
0005434319556	B3BA7D	9287 878571	VASILIY MIKHAYLOV	{"email": "v-mikhaylov-031979@postgrespro.ru", "phone": "+70770259030"}
0005434319557	B3BA7D	4808 104326	VALERIY SOROKIN	{"email": "valeriy_sorokin.071971@postgrespro.ru", "phone": "+70631348395"}
0005434319558	A06BEF	6912 234429	NIKOLAY BORISOV	{"phone": "+70304605010"}
0005434319559	3784EC	7311 138663	ILYAS DENISOV	{"email": "denisovi.18071976@postgrespro.ru", "phone": "+70292878823"}
0005434319560	0DD70A	2778 873450	ALEKSEY PETROV	{"phone": "+70167226731"}
0005434319561	2C2030	9868 137660	DMITRIY ANTONOV	{"phone": "+70201198805"}
0005434319562	2C2030	3387 911343	NATALIYA CHERNOVA	{"phone": "+70103865717"}
0005434319563	932FD3	4907 939473	SERGEY SEMENOV	{"email": "semenov-s.11071982@postgrespro.ru", "phone": "+70660013991"}
0005434319564	7F0FF5	3203 424029	EVGENIY KISELEV	{"email": "evgeniy-kiselev-071969@postgrespro.ru", "phone": "+70031019003"}
0005434319565	7F0FF5	4579 788285	YURIY SERGEEV	{"phone": "+70903671277"}
0005434319566	6BF962	7246 223423	ROMAN KUZNECOV	{"phone": "+70342824424"}
0005434319567	95788F	7963 510381	MAKSIM SOKOLOV	{"email": "sokolov-maksim-20101971@postgrespro.ru", "phone": "+70200100074"}
0005434319568	95788F	2883 418193	NATALYA ZOTOVA	{"phone": "+70476700475"}
0005434319569	CED351	3435 182318	YULIYA FADEEVA	{"phone": "+70493019997"}
0005434319570	D64AE2	3750 163278	DMITRIY POPOV	{"email": "d-popov1972@postgrespro.ru", "phone": "+70175007253"}
0005434319571	D64AE2	1732 047559	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr-01091983@postgrespro.ru", "phone": "+70962246497"}
0005434319572	D64AE2	1371 291967	ILYA IVANOV	{"phone": "+70355661874"}
0005434319573	405CA5	9288 047438	TATYANA LOGINOVA	{"phone": "+70254761648"}
0005434319574	405CA5	8304 106211	ELENA ROMANOVA	{"email": "romanova-e1967@postgrespro.ru", "phone": "+70877798849"}
0005434319575	9F7AA2	3715 773019	PETR OSIPOV	{"phone": "+70734041898"}
0005434319576	E6CE24	3007 463800	ARTEM ALEKSANDROV	{"email": "artem-aleksandrov-101970@postgrespro.ru", "phone": "+70973944434"}
0005434319577	A67F1F	3686 220537	VALENTINA LEBEDEVA	{"email": "vlebedeva06091970@postgrespro.ru", "phone": "+70813563231"}
0005434319578	F2009A	8057 809631	TATYANA FOMINA	{"email": "tfomina_1968@postgrespro.ru", "phone": "+70532732844"}
0005434319579	E0CE99	1086 951795	GALINA SMIRNOVA	{"email": "smirnova_galina.1975@postgrespro.ru", "phone": "+70584429378"}
0005434319580	4ECD8B	1937 070494	VYACHESLAV POPOV	{"phone": "+70268446848"}
0005434319581	4ECD8B	8306 863084	ANDREY PAVLOV	{"email": "pavlov-a1981@postgrespro.ru", "phone": "+70491197706"}
0005434319582	4ECD8B	8904 601608	OLESYA KUZNECOVA	{"email": "olesyakuznecova.111973@postgrespro.ru", "phone": "+70672697356"}
0005434319583	E75EF5	1491 804674	MARIYA ERMAKOVA	{"phone": "+70970830514"}
0005434319584	86972E	0525 909114	NATALYA KUZNECOVA	{"email": "n_kuznecova.1977@postgrespro.ru", "phone": "+70969129752"}
0005434319585	DA7680	9777 112968	ALEKSANDR TARASOV	{"phone": "+70081528465"}
0005434319586	15A34C	1895 190144	LIDIYA KULIKOVA	{"phone": "+70243985399"}
0005434319587	9B1636	4620 684322	SVETLANA MELNIKOVA	{"phone": "+70078879371"}
0005434319588	FDCD2F	2073 758173	YANA NAUMOVA	{"email": "naumova.y051968@postgrespro.ru", "phone": "+70492240492"}
0005434319589	027F88	6001 162971	OKSANA PETROVA	{"email": "oksana-petrova_1989@postgrespro.ru", "phone": "+70595125677"}
0005434319590	027F88	7013 926320	ALEKSANDR CHERNOV	{"phone": "+70714492446"}
0005434319591	0E84D3	5572 645230	MARINA SMIRNOVA	{"phone": "+70292050962"}
0005434319592	0E84D3	0311 813086	MATVEY OSIPOV	{"phone": "+70545511220"}
0005434319593	BC52EE	7857 545717	ILONA FOMINA	{"phone": "+70847262403"}
0005434319594	BC52EE	0533 383013	EVGENIY OSIPOV	{"phone": "+70931045803"}
0005434319595	4E5CBF	6945 168631	ALEKSEY PETROV	{"phone": "+70187338438"}
0005434319596	4E5CBF	1931 328419	ELENA BARANOVA	{"phone": "+70925547447"}
0005434319597	9DC0FD	3853 567326	ALEKSEY KUDRYASHOV	{"phone": "+70997727213"}
0005434319598	9DC0FD	5482 674396	DMITRIY DAVYDOV	{"email": "dmitriydavydov15051970@postgrespro.ru", "phone": "+70503005135"}
0005434319599	AF40CA	7809 550392	EVGENIYA KUZMINA	{"email": "kuzmina.evgeniya.09051967@postgrespro.ru", "phone": "+70654971241"}
0005434319600	55B4AC	7996 243344	OLGA ANTONOVA	{"email": "antonovao.24011969@postgrespro.ru", "phone": "+70693360449"}
0005434319601	55B4AC	1261 862797	ELENA CHERNOVA	{"email": "echernova_011969@postgrespro.ru", "phone": "+70646801345"}
0005434319602	29F229	0477 087287	ARTEMIY PAVLOV	{"email": "artemiy.pavlov.081963@postgrespro.ru", "phone": "+70078241445"}
0005434319603	E6864F	8601 446345	ALEKSANDR FOMIN	{"email": "a_fomin.1957@postgrespro.ru", "phone": "+70593900288"}
0005434319604	B50F04	3711 156623	DENIS DMITRIEV	{"email": "denisdmitriev-1978@postgrespro.ru", "phone": "+70992098261"}
0005434319605	3C3F20	1646 089108	VIKTOR VOLKOV	{"email": "volkov.v-19011970@postgrespro.ru", "phone": "+70063548289"}
0005434319606	18B2F8	2651 374774	ALEKSANDR SCHERBAKOV	{"phone": "+70009455130"}
0005434319607	18B2F8	0949 916753	LYUBOV SOKOLOVA	{"phone": "+70190331536"}
0005434319608	6A2698	2219 034772	NINA SOKOLOVA	{"email": "nina_sokolova-011972@postgrespro.ru", "phone": "+70822307973"}
0005434319609	6A2698	6618 774808	LYUDMILA KISELEVA	{"email": "kiselevalyudmila_061973@postgrespro.ru", "phone": "+70701794179"}
0005434319610	A4C69E	4964 796284	SERGEY ABRAMOV	{"email": "sabramov.101972@postgrespro.ru", "phone": "+70576839086"}
0005434319611	B108CC	8168 253003	ALESYA FEDOROVA	{"email": "fedorovaa-051971@postgrespro.ru", "phone": "+70597209220"}
0005434319612	231775	1323 441571	OLEG NAZAROV	{"email": "oleg.nazarov-101974@postgrespro.ru", "phone": "+70949047045"}
0005434319613	231775	9533 619854	GALINA ZHURAVLEVA	{"email": "gzhuravleva08101959@postgrespro.ru", "phone": "+70802054148"}
0005434319614	C30128	5122 065187	ANNA ALEKSEEVA	{"email": "alekseeva.a-1977@postgrespro.ru", "phone": "+70934705369"}
0005434319615	C30128	1105 399684	ANDREY SOKOLOV	{"email": "andrey-sokolov-121969@postgrespro.ru", "phone": "+70945236890"}
0005434319616	DA50E3	0703 348543	VALERIY NOVIKOV	{"phone": "+70225015200"}
0005434319617	7CFCD4	4253 906130	DARYA ERMAKOVA	{"email": "ermakovadarya121969@postgrespro.ru", "phone": "+70933592868"}
0005434319618	7CFCD4	1054 529345	VASILIY IVANOV	{"email": "v.ivanov-081966@postgrespro.ru", "phone": "+70027342359"}
0005434319619	2ABDB0	0901 640271	OLGA FROLOVA	{"email": "frolova-o-041984@postgrespro.ru", "phone": "+70217936342"}
0005434319620	210076	8414 303240	RAISA ZOTOVA	{"email": "zotova.r.07101975@postgrespro.ru", "phone": "+70192309559"}
0005434319621	0E5B99	6659 367058	ALEKSANDR FEDOTOV	{"email": "fedotov-a-011972@postgrespro.ru", "phone": "+70669839377"}
0005434319622	0E5B99	2824 519629	ANATOLIY IVANOV	{"phone": "+70752489671"}
0005434319623	0E5B99	4685 649862	ALEKSANDR BORISOV	{"phone": "+70770832602"}
0005434319624	3B80BC	5480 945405	ANTON KUZMIN	{"phone": "+70472650174"}
0005434319625	3B80BC	9022 869964	ANATOLIY STEPANOV	{"phone": "+70581616083"}
0005434319626	DF5FC5	1128 843746	SERGEY TIMOFEEV	{"phone": "+70376415963"}
0005434319627	1ACF2B	7630 840928	DANIL SOKOLOV	{"email": "sokolov.danil-11121966@postgrespro.ru", "phone": "+70295283192"}
0005434319628	55A7CB	7649 677456	TAMARA SERGEEVA	{"phone": "+70953776462"}
0005434319629	35A6F4	2343 784709	ALEKSANDR PETROV	{"phone": "+70179973447"}
0005434319630	35A6F4	2836 750420	DANIL BARANOV	{"email": "d-baranov_30121968@postgrespro.ru", "phone": "+70637698395"}
0005434319631	084AA6	0992 189252	SVETLANA POPOVA	{"email": "svetlanapopova16121961@postgrespro.ru", "phone": "+70196157092"}
0005434319632	EB37C8	5164 292786	DMITRIY NAZAROV	{"phone": "+70267770087"}
0005434319633	27760C	6677 951806	ALEKSEY KUZNECOV	{"phone": "+70020158118"}
0005434319634	27760C	8963 448685	ALINA KUZNECOVA	{"phone": "+70637160534"}
0005434319635	753D59	7245 921176	PAVEL KUZNECOV	{"email": "pavelkuznecov_1974@postgrespro.ru", "phone": "+70405531529"}
0005434319636	753D59	6711 548657	PETR PETROV	{"email": "petrov-petr_13091976@postgrespro.ru", "phone": "+70775975892"}
0005434319637	FABD52	0111 441387	EKATERINA POLYAKOVA	{"phone": "+70364117440"}
0005434319638	8D15E3	3738 057145	ANZHELA LEBEDEVA	{"email": "lebedeva-a.1977@postgrespro.ru", "phone": "+70185526149"}
0005434319639	D90B41	5389 844923	ALEVTINA ZAYCEVA	{"phone": "+70606510420"}
0005434319640	1D16F8	8368 155045	NIKOLAY STEPANOV	{"phone": "+70915881594"}
0005434319641	1D16F8	2228 179634	NADEZHDA GUSEVA	{"email": "n-guseva_1982@postgrespro.ru", "phone": "+70886743012"}
0005434319642	4CBB26	4799 826949	ALEKSANDRA ZHUKOVA	{"email": "azhukova1973@postgrespro.ru", "phone": "+70269264270"}
0005434319643	32FC25	1156 849358	TATYANA MAKSIMOVA	{"phone": "+70628678481"}
0005434319645	39A5A0	5422 731296	YULIYA CHERNOVA	{"email": "yuliya_chernova.031958@postgrespro.ru", "phone": "+70835625079"}
0005434319646	4A0489	6877 158457	ALEKSANDRA EGOROVA	{"email": "egorovaaleksandra081976@postgrespro.ru", "phone": "+70897104792"}
0005434319647	AEB104	8682 372985	TATYANA GERASIMOVA	{"email": "gerasimovat.021973@postgrespro.ru", "phone": "+70838008576"}
0005434319648	70D165	8071 568193	ANNA AKIMOVA	{"email": "akimovaanna.051982@postgrespro.ru", "phone": "+70884186080"}
0005434319649	9F60D7	6625 083743	VIKTOR MAKAROV	{"phone": "+70213296544"}
0005434319650	36CB1D	7433 621699	ALEKSEY POPOV	{"email": "a.popov-09071968@postgrespro.ru", "phone": "+70577789193"}
0005434319651	3B4A70	9758 810678	ALEKSEY ALEKSANDROV	{"phone": "+70909730564"}
0005434319652	52FC3F	4327 139993	VIKTOR ZHUKOV	{"email": "zhukov-viktor-1963@postgrespro.ru", "phone": "+70506948765"}
0005434319653	52FC3F	6430 820732	ILYA ROMANOV	{"email": "romanov_i_1965@postgrespro.ru", "phone": "+70904998793"}
0005434319654	84E9B6	7321 101159	YURIY SOLOVEV	{"phone": "+70669816164"}
0005434319655	E85A53	9528 069685	ANTON NIKOLAEV	{"email": "nikolaev-a-12111977@postgrespro.ru", "phone": "+70489976950"}
0005434319656	E85A53	0401 710331	TATYANA MELNIKOVA	{"phone": "+70675353324"}
0005434319657	A7396B	1389 599814	VLADIMIR IVANOV	{"email": "ivanov.vladimir_07121973@postgrespro.ru", "phone": "+70843090118"}
0005434319658	A7396B	1825 138755	ANVAR GERASIMOV	{"phone": "+70571500056"}
0005434319659	E7F890	3441 536723	ALEKSANDR GERASIMOV	{"phone": "+70972265191"}
0005434319660	5D7187	6334 538940	LEONID MIKHAYLOV	{"phone": "+70539547122"}
0005434319661	BE21B3	9424 519537	DMITRIY EGOROV	{"phone": "+70697829871"}
0005434319662	E03F6E	5655 634364	LIDIYA ERMAKOVA	{"email": "ermakova-lidiya1976@postgrespro.ru", "phone": "+70646662114"}
0005434319663	A37486	6674 031363	VIKTOR KARPOV	{"email": "v.karpov-1982@postgrespro.ru", "phone": "+70220520949"}
0005434319664	B83C94	6569 068953	LYUBOV KONDRATEVA	{"email": "kondrateva_l-31101978@postgrespro.ru", "phone": "+70089153765"}
0005434319665	A3D7A7	1352 958078	DARYA FADEEVA	{"phone": "+70294782299"}
0005434319666	6AC6A3	7334 995643	ALENA KOROLEVA	{"phone": "+70574729659"}
0005434319667	6AC6A3	6607 389649	IVAN MEDVEDEV	{"email": "ivan_medvedev121974@postgrespro.ru", "phone": "+70609988247"}
0005434319668	294DDA	9077 186360	LYUBOV KRASNOVA	{"email": "lyubov-krasnova.1973@postgrespro.ru", "phone": "+70459403388"}
0005434319669	294DDA	0987 138059	OLGA FILIPPOVA	{"phone": "+70950360532"}
0005434319670	514892	0838 976538	LYUBOV SEMENOVA	{"email": "lyubov_semenova-051988@postgrespro.ru", "phone": "+70882369022"}
0005434319671	A6A77B	6947 267975	YURIY FROLOV	{"phone": "+70916531092"}
0005434319672	FDAF58	7653 183608	DENIS MIRONOV	{"phone": "+70982416376"}
0005434319673	54EC8A	4729 974818	NIKOLAY SOLOVEV	{"email": "solovevn-07011973@postgrespro.ru", "phone": "+70431687506"}
0005434319674	54EC8A	0541 582952	EDUARD ZAKHAROV	{"email": "zakharoveduard-16041967@postgrespro.ru", "phone": "+70072262183"}
0005434319675	BE9116	5679 334931	PETR DMITRIEV	{"phone": "+70865926842"}
0005434319676	BE9116	6315 550577	ELENA MALYSHEVA	{"email": "malysheva.e.051957@postgrespro.ru", "phone": "+70952934307"}
0005434319677	D30588	8638 341458	VLADIMIR BONDARENKO	{"phone": "+70521109404"}
0005434319678	D30588	9620 445525	SERGEY ALEKSEEV	{"email": "s.alekseev_11121968@postgrespro.ru", "phone": "+70429941722"}
0005434319679	D30588	0234 685692	VLADIMIR GRIGOREV	{"email": "v-grigorev_15031980@postgrespro.ru", "phone": "+70575491479"}
0005434319680	D28F7B	1503 539549	DMITRIY BONDARENKO	{"email": "bondarenko.d-1975@postgrespro.ru", "phone": "+70135473735"}
0005434319681	7C7ED0	8350 466202	ALEKSEY MEDVEDEV	{"email": "medvedev-aleksey_1978@postgrespro.ru", "phone": "+70397373999"}
0005434319682	7C7ED0	0261 919966	VITALIY CHERNOV	{"email": "chernov_vitaliy-051973@postgrespro.ru", "phone": "+70763647523"}
0005434319683	911CBD	0287 237075	LIDIYA VLASOVA	{"phone": "+70407036258"}
0005434319684	AECC21	9399 138666	EVGENIY VOLKOV	{"phone": "+70651985985"}
0005434319685	25BFBF	9060 951622	ALBINA ALEKSEEVA	{"email": "alekseeva.albina_02101966@postgrespro.ru", "phone": "+70543806326"}
0005434319686	6DE581	0169 966561	PAVEL MOISEEV	{"phone": "+70664280008"}
0005434319687	6DE581	8531 186125	EVGENIY KOZLOV	{"phone": "+70578251093"}
0005434319688	0D10CF	8622 325487	LIDIYA ERMAKOVA	{"email": "lermakova.1975@postgrespro.ru", "phone": "+70515721069"}
0005434319689	7941EE	3704 049966	ANATOLIY EGOROV	{"phone": "+70221801021"}
0005434319690	7941EE	2661 157120	IRINA SMIRNOVA	{"phone": "+70586757063"}
0005434319691	7941EE	5335 260123	LYUDMILA ANDREEVA	{"phone": "+70007907708"}
0005434319692	7941EE	0607 897585	SVYATOSLAV PETROV	{"phone": "+70522468388"}
0005434319693	E5CBCB	7786 738740	MAKSIM RODIONOV	{"phone": "+70479459561"}
0005434319694	DFEAB0	6676 428445	VALENTINA VASILEVA	{"email": "valentina-vasileva.28081982@postgrespro.ru", "phone": "+70897310228"}
0005434319695	DFEAB0	8699 840557	LIDIYA TARASOVA	{"email": "ltarasova_1972@postgrespro.ru", "phone": "+70730407784"}
0005434319696	DFEAB0	3783 384766	MIKHAIL KUZNECOV	{"email": "kuznecov.m_1969@postgrespro.ru", "phone": "+70391270748"}
0005434319697	A862B4	2900 006777	VLADIMIR GAVRILOV	{"email": "gavrilov_vladimir19041968@postgrespro.ru", "phone": "+70135233434"}
0005434319698	550DBD	2245 124803	ANDREY ORLOV	{"phone": "+70749751547"}
0005434319699	4EDCDB	0943 059053	MARIYA KOLESNIKOVA	{"phone": "+70431010773"}
0005434319700	668C61	0253 757179	GALINA BARANOVA	{"email": "g-baranova.1971@postgrespro.ru", "phone": "+70774371492"}
0005434319701	0EC867	6916 811125	NINA KRASNOVA	{"phone": "+70599349788"}
0005434319702	F5A524	4972 931792	ALEKSANDR MAKSIMOV	{"email": "a-maksimov091974@postgrespro.ru", "phone": "+70522939609"}
0005434319703	D8F1AC	3659 629602	TATYANA MASLOVA	{"phone": "+70392164600"}
0005434319704	7BA6BA	2757 772694	VIKTOR TIMOFEEV	{"phone": "+70133484394"}
0005434319705	9CF367	9319 885207	GEORGIY AFANASEV	{"email": "afanasev_g.25091971@postgrespro.ru", "phone": "+70527743990"}
0005434319706	27019C	7828 220767	IVAN SERGEEV	{"phone": "+70612146049"}
0005434319707	A99697	4256 946996	SOFYA KOVALEVA	{"email": "kovaleva-s.031980@postgrespro.ru", "phone": "+70356692866"}
0005434319708	90FBC9	4438 773790	ROZALIYA YAKOVLEVA	{"phone": "+70820576144"}
0005434319709	401331	9698 448587	VLADIMIR NIKITIN	{"email": "v_nikitin.101973@postgrespro.ru", "phone": "+70396036465"}
0005434319710	96965B	7411 665162	GALINA ANDREEVA	{"email": "andreeva-g.03011977@postgrespro.ru", "phone": "+70566447435"}
0005434319711	96965B	0933 236711	SERGEY SOKOLOV	{"phone": "+70262625961"}
0005434319712	2175AF	0433 481149	PETR MAKAROV	{"phone": "+70262629384"}
0005434319713	17C5F5	2076 901276	EVGENIY VOLKOV	{"phone": "+70188009661"}
0005434319714	17C5F5	2169 784313	KLAVDIYA KUZNECOVA	{"email": "kuznecova_klavdiya31011973@postgrespro.ru", "phone": "+70693954974"}
0005434319715	89D275	2382 414963	SERGEY FOMIN	{"phone": "+70886839023"}
0005434319716	89D275	7635 544516	EVGENIY FROLOV	{"email": "frolov_e1970@postgrespro.ru", "phone": "+70597319660"}
0005434319717	ED97B0	4743 025008	EKATERINA SOROKINA	{"phone": "+70834987444"}
0005434319718	6E5EEE	3795 903535	ANATOLIY AFANASEV	{"email": "anatoliyafanasev1971@postgrespro.ru", "phone": "+70394207617"}
0005434319719	BE228A	6025 085728	YURIY ORLOV	{"email": "yuriy_orlov_021971@postgrespro.ru", "phone": "+70486209714"}
0005434319720	BE228A	5761 479442	TATYANA STEPANOVA	{"phone": "+70523441051"}
0005434319721	8E64DB	5827 801858	MARGARITA ZHUKOVA	{"phone": "+70079077732"}
0005434319722	36E38F	9372 960525	TAMARA KONOVALOVA	{"email": "t_konovalova1977@postgrespro.ru", "phone": "+70473808650"}
0005434319723	6D2F12	9329 511309	YULIYA ANDREEVA	{"email": "y-andreeva091973@postgrespro.ru", "phone": "+70374542809"}
0005434319724	704E70	1225 992594	SERGEY NIKOLAEV	{"phone": "+70053619096"}
0005434319725	3160AA	3121 471584	SVETLANA POPOVA	{"phone": "+70707181618"}
0005434319726	DD5788	3917 575883	OLEG NIKITIN	{"phone": "+70187989437"}
0005434319727	79B00D	3020 235608	ANDREY KRASNOV	{"phone": "+70917179789"}
0005434319728	745599	6857 061048	MAKSIM IVANOV	{"email": "ivanov.maksim_02011973@postgrespro.ru", "phone": "+70740623026"}
0005434319729	CB82AA	4019 172589	ALEKSANDR MEDVEDEV	{"phone": "+70627907369"}
0005434319730	937B5D	5869 627090	RAMILYA AFANASEVA	{"phone": "+70809635986"}
0005434319731	E4559E	2645 859109	OKSANA MAKSIMOVA	{"phone": "+70920188035"}
0005434319732	A14687	1320 523297	VALERIY TIKHONOV	{"phone": "+70129973326"}
0005434319733	CBE13A	2117 163979	GALINA RODIONOVA	{"email": "rodionovag041967@postgrespro.ru", "phone": "+70574282713"}
0005434319734	CBE13A	1070 352635	KIRILL MOROZOV	{"email": "kmorozov.22101976@postgrespro.ru", "phone": "+70375537034"}
0005434319735	CBE13A	1491 691955	LYUBOV FROLOVA	{"email": "frolova_l1967@postgrespro.ru", "phone": "+70489297052"}
0005434319736	5D4748	4799 120608	ALEKSEY ZHURAVLEV	{"email": "a-zhuravlev_071971@postgrespro.ru", "phone": "+70198046579"}
0005434319737	5D4748	1466 729621	OLEG STEPANOV	{"email": "o.stepanov-28011975@postgrespro.ru", "phone": "+70731035828"}
0005434319738	3F730A	2875 250075	ANASTASIYA LUKYANOVA	{"email": "lukyanova_anastasiya_1973@postgrespro.ru", "phone": "+70313643133"}
0005434319739	A5BC5F	1688 500226	PETR SCHERBAKOV	{"phone": "+70358848970"}
0005434319740	2845D5	3541 758446	TATYANA ALEKSANDROVA	{"phone": "+70274588987"}
0005434319741	EA0D66	2295 994917	NATALYA AFANASEVA	{"email": "afanasevan_28061990@postgrespro.ru", "phone": "+70785695528"}
0005434319742	0D52CB	7685 042243	VIKTORIYA ANDREEVA	{"phone": "+70782526520"}
0005434319743	F602A8	6781 688055	YANA MAKAROVA	{"email": "makarovayana_1968@postgrespro.ru", "phone": "+70363356490"}
0005434319744	4AA871	8701 996180	YULIYA FILATOVA	{"email": "filatovayuliya021964@postgrespro.ru", "phone": "+70499837456"}
0005434319745	3144D2	0699 789797	DARYA MOROZOVA	{"phone": "+70116195820"}
0005434319746	859A57	6094 574803	VERA MALYSHEVA	{"phone": "+70079797254"}
0005434319747	D11BEF	8473 992807	MARIYA MALYSHEVA	{"email": "malysheva.m.1979@postgrespro.ru", "phone": "+70542406979"}
0005434319748	5D68C9	8264 377101	DANILA EGOROV	{"email": "d.egorov011973@postgrespro.ru", "phone": "+70152769285"}
0005434319749	5D68C9	0765 015845	TAMARA ZAKHAROVA	{"email": "tamara_zakharova.30031977@postgrespro.ru", "phone": "+70168239060"}
0005434319750	589F23	3897 187352	SERGEY ZHUKOV	{"phone": "+70360037497"}
0005434319751	448100	8169 965031	EVGENIY ROMANOV	{"phone": "+70864587107"}
0005434319752	448100	8344 160840	ALEKSEY MEDVEDEV	{"phone": "+70374542291"}
0005434319753	7DE5EA	0242 989937	TATYANA KONDRATEVA	{"email": "tatyana-kondrateva.061976@postgrespro.ru", "phone": "+70603398783"}
0005434319754	8F2466	2030 248457	ALIK KARPOV	{"email": "karpovalik-25101963@postgrespro.ru", "phone": "+70686603044"}
0005434319755	DA44B1	9128 000258	VLADIMIR ROMANOV	{"phone": "+70973937863"}
0005434319756	0FAA50	7501 786051	ALFIYA MIKHAYLOVA	{"phone": "+70832381728"}
0005434319757	0FAA50	3481 139673	RAIL VOLKOV	{"email": "rail.volkov_1973@postgrespro.ru", "phone": "+70293752325"}
0005434319758	596094	4724 361048	NIKOLAY KARPOV	{"email": "karpov_n-05121963@postgrespro.ru", "phone": "+70010821190"}
0005434319759	76102C	9548 648002	VLADISLAV PAVLOV	{"email": "v_pavlov16121982@postgrespro.ru", "phone": "+70085264009"}
0005434319760	ABF7EA	6510 387188	ELENA VLASOVA	{"email": "e-vlasova.041971@postgrespro.ru", "phone": "+70253587388"}
0005434319761	1959D4	9917 658410	VLADIMIR MELNIKOV	{"phone": "+70708292213"}
0005434319762	E6AA7F	9721 989812	ANASTASIYA BORISOVA	{"phone": "+70812249018"}
0005434319763	FC70F8	3895 291500	ELENA FEDOROVA	{"phone": "+70947610046"}
0005434319764	FC70F8	8967 335777	NIKOLAY KARPOV	{"email": "karpov_n-091982@postgrespro.ru", "phone": "+70343502170"}
0005434319765	D8A41E	1475 675268	SVETLANA BARANOVA	{"phone": "+70913411911"}
0005434319766	BCD946	4898 485995	VALENTINA NAUMOVA	{"email": "v_naumova1975@postgrespro.ru", "phone": "+70138306839"}
0005434319767	85C869	5599 069120	LARISA EGOROVA	{"email": "l_egorova-15121967@postgrespro.ru", "phone": "+70066861280"}
0005434319768	13B1EB	9412 561177	ALEKSANDR ZHUKOV	{"phone": "+70070897675"}
0005434319769	76D6E9	4108 961787	NATALYA BARANOVA	{"phone": "+70635265844"}
0005434319770	B59DA0	0823 566290	NATALYA ANISIMOVA	{"phone": "+70835606922"}
0005434319771	4F8AB1	0749 868188	NIKOLAY IVANOV	{"phone": "+70927379776"}
0005434319772	AE3ADD	8333 298171	ALEKSEY KRASNOV	{"phone": "+70883537981"}
0005434319773	AE3ADD	8986 526650	VASILISA FOMINA	{"phone": "+70448577455"}
0005434319774	AE3ADD	6722 515334	EVGENIYA KUZNECOVA	{"email": "kuznecova_e.04051963@postgrespro.ru", "phone": "+70441110339"}
0005434319775	AE3ADD	2682 718837	ANDREY VOROBEV	{"email": "avorobev.13061969@postgrespro.ru", "phone": "+70389019116"}
0005434319776	4A38EF	9609 259531	ANGELINA ILINA	{"email": "angelina_ilina051974@postgrespro.ru", "phone": "+70287469473"}
0005434319777	884A35	7135 765585	VALENTINA NIKOLAEVA	{"email": "nikolaeva.valentina-051978@postgrespro.ru", "phone": "+70491438339"}
0005434319778	DC4676	1744 613166	ELENA POPOVA	{"phone": "+70898535821"}
0005434319779	A5EF7E	7749 066044	NIKOLAY SCHERBAKOV	{"email": "scherbakov-n_1975@postgrespro.ru", "phone": "+70308157350"}
0005434319780	7733F1	8833 592379	DENIS IVANOV	{"phone": "+70731735168"}
0005434319781	0D74C2	8176 649676	EKATERINA CHERNOVA	{"email": "ekaterina-chernova-08101990@postgrespro.ru", "phone": "+70843942058"}
0005434319782	0D74C2	9687 550509	MARIYA FADEEVA	{"phone": "+70957748503"}
0005434319783	0A0F79	5089 917105	TATYANA ROMANOVA	{"email": "romanovatatyana1962@postgrespro.ru", "phone": "+70263447555"}
0005434319784	365AF9	8843 449698	ANDREY KOZLOV	{"phone": "+70239145385"}
0005434319785	365AF9	0818 834460	TATYANA KUZNECOVA	{"phone": "+70414037728"}
0005434319786	A1F961	8862 402645	PAVEL MARTYNOV	{"phone": "+70106701735"}
0005434319787	574C9A	7419 915314	GALINA EGOROVA	{"email": "egorovag_13011966@postgrespro.ru", "phone": "+70038572732"}
0005434319788	A0D609	8984 280722	VALENTINA SEMENOVA	{"email": "valentina_semenova.12091955@postgrespro.ru", "phone": "+70585281238"}
0005434319789	961316	3826 364467	ELENA DMITRIEVA	{"phone": "+70056181952"}
0005434319790	45DDCF	5073 183097	SOFYA SMIRNOVA	{"email": "smirnova-s-101976@postgrespro.ru", "phone": "+70383185250"}
0005434319791	4F7151	8050 998094	PAVEL YAKOVLEV	{"email": "pavelyakovlev-061969@postgrespro.ru", "phone": "+70639082445"}
0005434319792	4F7151	5445 661433	ANDREY AFANASEV	{"phone": "+70851350918"}
0005434319793	F83392	2471 112015	RASHIT FEDOROV	{"email": "rashit.fedorov-1966@postgrespro.ru", "phone": "+70204411204"}
0005434319794	F83392	8621 338508	ALEKSANDR SOKOLOV	{"email": "sokolov-a_30011974@postgrespro.ru", "phone": "+70473480397"}
0005434319795	F83392	0018 672373	PETR NIKOLAEV	{"email": "nikolaev-petr.1979@postgrespro.ru", "phone": "+70773944981"}
0005434319796	8F2160	9090 492029	VIKTOR ZAKHAROV	{"phone": "+70294213879"}
0005434319797	8F2160	7565 139141	ANTONINA RODIONOVA	{"email": "rodionova_a.041966@postgrespro.ru", "phone": "+70479298778"}
0005434319798	621CC9	2826 798714	YULIYA GAVRILOVA	{"phone": "+70845442697"}
0005434319799	379A52	7770 183166	ALEKSANDR NOVIKOV	{"email": "a-novikov-011968@postgrespro.ru", "phone": "+70939582058"}
0005434319800	379A52	8263 124007	GEORGIY NAZAROV	{"phone": "+70804402673"}
0005434319801	6A9C04	5379 760346	NADEZHDA YAKOVLEVA	{"email": "yakovleva_nadezhda11121975@postgrespro.ru", "phone": "+70179002121"}
0005434319802	5BDB02	3704 063135	ALEKSANDRA ORLOVA	{"email": "orlova.a-1969@postgrespro.ru", "phone": "+70612404181"}
0005434319803	F125F6	2308 596203	VALENTIN YAKOVLEV	{"phone": "+70728069297"}
0005434319804	F125F6	1532 018907	VASILIY ALEKSEEV	{"email": "alekseev.v.021969@postgrespro.ru", "phone": "+70775687452"}
0005434319805	EB816B	2755 285899	GALINA DENISOVA	{"email": "denisova-galina.07031969@postgrespro.ru", "phone": "+70470650926"}
0005434319806	EB816B	9479 343058	MARIYA FROLOVA	{"email": "mariya-frolova-1971@postgrespro.ru", "phone": "+70275434553"}
0005434319807	EB816B	6326 997564	LARISA RYABOVA	{"phone": "+70742657131"}
0005434319808	D11D3D	1987 843810	LIDIYA ALEKSEEVA	{"email": "alekseeva_l-1980@postgrespro.ru", "phone": "+70703661452"}
0005434319809	D11D3D	9239 077602	EVGENIY POPOV	{"email": "popovevgeniy.29091980@postgrespro.ru", "phone": "+70810052346"}
0005434319810	F8B28A	3351 439800	SVETLANA MIRONOVA	{"email": "s.mironova.011972@postgrespro.ru", "phone": "+70659047223"}
0005434319811	F8B28A	2785 839234	DANIIL GERASIMOV	{"email": "gerasimov.d-07071961@postgrespro.ru", "phone": "+70600293484"}
0005434319812	657BCC	9747 115284	ALEKSANDR ALEKSEEV	{"email": "a_alekseev081979@postgrespro.ru", "phone": "+70613225475"}
0005434319813	D7F8C8	7749 865312	BORIS KUZNECOV	{"email": "b.kuznecov-051971@postgrespro.ru", "phone": "+70853799041"}
0005434319814	235E98	6329 468950	BORIS KRASNOV	{"phone": "+70497089899"}
0005434319815	235E98	2062 906824	NATALYA VASILEVA	{"email": "n_vasileva_1973@postgrespro.ru", "phone": "+70077057194"}
0005434319816	235E98	1822 150736	ULYANA PAVLOVA	{"email": "ulyana.pavlova.1992@postgrespro.ru", "phone": "+70194417879"}
0005434319817	235E98	9266 335109	NADEZHDA DANILOVA	{"phone": "+70125062235"}
0005434319818	094A41	4263 921082	ELENA GUSEVA	{"phone": "+70805840638"}
0005434319819	A4BDED	9082 864473	NINA ALEKSANDROVA	{"phone": "+70619605111"}
0005434319820	196A63	7407 283564	VALENTINA TIKHONOVA	{"phone": "+70876491962"}
0005434319821	196A63	1895 523630	GALINA ZHUKOVA	{"email": "g.zhukova20091964@postgrespro.ru", "phone": "+70880382419"}
0005434319822	015DE3	7727 383421	OLGA ANTONOVA	{"email": "olga.antonova021965@postgrespro.ru", "phone": "+70013399539"}
0005434319823	89D418	8093 111011	VASILIY GORBUNOV	{"email": "gorbunov_v1981@postgrespro.ru", "phone": "+70784565683"}
0005434319824	1FA9AC	1140 895858	VERA FROLOVA	{"email": "frolova_v-1962@postgrespro.ru", "phone": "+70830667923"}
0005434319825	49063B	6276 195445	ALISA BOGDANOVA	{"email": "bogdanova.a_21051975@postgrespro.ru", "phone": "+70388373787"}
0005434319826	5BB6FF	8696 791199	ALEKSANDR EGOROV	{"phone": "+70678330014"}
0005434319827	942D63	9686 138866	TAMARA ARKHIPOVA	{"email": "t_arkhipova-021974@postgrespro.ru", "phone": "+70035805323"}
0005434319828	942D63	3732 508423	ALEKSANDRA VASILEVA	{"phone": "+70567739702"}
0005434319829	E5C3DC	1359 671894	ILDAR IVANOV	{"email": "ildarivanov_1969@postgrespro.ru", "phone": "+70331605420"}
0005434319830	5440DF	2300 421257	VALERIYA OVCHINNIKOVA	{"email": "ovchinnikova_valeriya_091973@postgrespro.ru", "phone": "+70095357378"}
0005434319831	5440DF	9650 289753	NIKOLAY MAKSIMOV	{"email": "maksimovnikolay.17071968@postgrespro.ru", "phone": "+70857898870"}
0005434319832	D87E8B	8692 398030	DMITRIY KOZLOV	{"email": "kozlov_dmitriy.011977@postgrespro.ru", "phone": "+70414194154"}
0005434319833	DB6971	2392 119985	RAFAIL SERGEEV	{"phone": "+70800008644"}
0005434319834	D748D3	7771 948380	NIKOLAY KOROLEV	{"phone": "+70176568908"}
0005434319835	E9DFAE	8469 805397	LYUBOV DENISOVA	{"phone": "+70139260306"}
0005434319836	929AB9	2556 318339	LADA KUDRYASHOVA	{"email": "lada-kudryashova.1974@postgrespro.ru", "phone": "+70152486314"}
0005434319837	FAA603	2339 206394	ELENA VASILEVA	{"phone": "+70660413772"}
0005434319838	FAA603	5083 443225	VYACHESLAV SOROKIN	{"email": "v.sorokin24011976@postgrespro.ru", "phone": "+70304635868"}
0005434319839	7F4917	1830 279910	PLATON KOZLOV	{"phone": "+70800772371"}
0005434319840	B297B8	4716 221631	VIKTORIYA KOLESNIKOVA	{"email": "kolesnikova.v.041975@postgrespro.ru", "phone": "+70757035897"}
0005434319841	82602C	7192 202955	ALEKSANDR NIKOLAEV	{"phone": "+70142706418"}
0005434319842	416A77	7039 275214	ELENA KUZNECOVA	{"email": "kuznecova.e-1972@postgrespro.ru", "phone": "+70570708834"}
0005434319843	262AD0	1640 374064	OLEG PETROV	{"phone": "+70654862601"}
0005434319844	262AD0	0765 833588	VALENTINA EFREMOVA	{"email": "valentina_efremova_1980@postgrespro.ru", "phone": "+70123182582"}
0005434319845	262AD0	7705 200761	VALENTINA VASILEVA	{"email": "v.vasileva_12101967@postgrespro.ru", "phone": "+70301093845"}
0005434319846	262AD0	2726 410687	NATALYA KUZNECOVA	{"phone": "+70339389955"}
0005434319847	ECF6CD	2539 139259	ALEKSANDR ZHUKOV	{"phone": "+70054832033"}
0005434319848	ECF6CD	4967 710254	ELENA MIKHAYLOVA	{"phone": "+70775564162"}
0005434319849	F825EE	0843 819265	TIMUR SHEVCHENKO	{"email": "timur_shevchenko21011974@postgrespro.ru", "phone": "+70543888876"}
0005434319850	B54516	0281 652918	EVGENIYA SOROKINA	{"phone": "+70323114137"}
0005434319851	B54516	4728 736971	ANTON VLASOV	{"phone": "+70148923942"}
0005434319852	B54516	7882 964987	SVETLANA ANISIMOVA	{"email": "anisimova.s101975@postgrespro.ru", "phone": "+70135595452"}
0005434319853	B54516	9445 365713	AMINA YAKOVLEVA	{"email": "a.yakovleva_1972@postgrespro.ru", "phone": "+70606818408"}
0005434319854	4289E0	1241 383084	DMITRIY KOROLEV	{"phone": "+70434221156"}
0005434319855	406BC2	1221 458511	ARTEM SIDOROV	{"phone": "+70777609189"}
0005434319856	406BC2	7341 514084	ALEKSANDR MOISEEV	{"phone": "+70342457251"}
0005434319857	9C0D51	2072 675155	ELENA EGOROVA	{"email": "egorovaelena081978@postgrespro.ru", "phone": "+70830409431"}
0005434319858	9C0D51	8910 551463	VERA SIDOROVA	{"phone": "+70303395136"}
0005434319859	F359F4	5715 789145	VLADIMIR ANDREEV	{"email": "andreev.vladimir_22051976@postgrespro.ru", "phone": "+70746186471"}
0005434319860	AA22E8	4157 859990	LEONID STEPANOV	{"phone": "+70550783789"}
0005434319861	AA22E8	0453 615761	SERGEY VOLKOV	{"phone": "+70782615152"}
0005434319862	AA22E8	9023 043563	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina.04111978@postgrespro.ru", "phone": "+70003134781"}
0005434319863	4CBDD7	3889 072040	ANASTASIYA BELOVA	{"phone": "+70351298543"}
0005434319864	EA930D	2573 047068	ALEKSEY POPOV	{"phone": "+70893811277"}
0005434319865	410C71	0903 979179	ELENA LOGINOVA	{"phone": "+70412042927"}
0005434319866	AADD5F	5512 937732	DMITRIY POPOV	{"email": "popov.d.24071969@postgrespro.ru", "phone": "+70825536146"}
0005434319867	5DE7C2	7884 979151	FEDOR VOLKOV	{"email": "f-volkov061967@postgrespro.ru", "phone": "+70711782774"}
0005434319868	CC57B2	1574 707297	NATALYA DANILOVA	{"phone": "+70623340443"}
0005434325443	A69644	2036 077214	LYUBOV DAVYDOVA	{"phone": "+70114028404"}
0005434325444	2B050E	0812 740484	VLADIMIR IVANOV	{"email": "ivanovvladimir.011980@postgrespro.ru", "phone": "+70794931439"}
0005434325445	EF42DB	0193 545320	MIKHAIL FOMIN	{"email": "fomin_m071966@postgrespro.ru", "phone": "+70217250849"}
0005434325446	12E0F5	1386 933164	NIKOLAY STEPANOV	{"phone": "+70854397157"}
0005434325447	4CC3D7	2095 377484	DENIS KUZMIN	{"email": "kuzmin.denis_031980@postgrespro.ru", "phone": "+70443681931"}
0005434325448	4CC3D7	4708 414366	FEDOR FEDOROV	{"phone": "+70539741226"}
0005434325449	329C5E	4671 896343	DARYA BARANOVA	{"phone": "+70240704412"}
0005434325450	329C5E	3109 029772	MAKSIM VOLKOV	{"email": "volkov_maksim_1963@postgrespro.ru", "phone": "+70497600380"}
0005434325451	329C5E	4681 368067	ILYA GERASIMOV	{"email": "ilya_gerasimov081976@postgrespro.ru", "phone": "+70303098178"}
0005434325452	39CDC4	4070 875624	NIKOLAY STEPANOV	{"phone": "+70561496984"}
0005434325453	207A03	3620 204182	NIKOLAY ROMANOV	{"email": "romanovnikolay-29031985@postgrespro.ru", "phone": "+70524063473"}
0005434325454	207A03	1204 842522	MARGARITA EGOROVA	{"email": "egorova-margarita.29111976@postgrespro.ru", "phone": "+70990686575"}
0005434325455	207A03	8499 544597	SERGEY NAZAROV	{"phone": "+70183819139"}
0005434325456	C40A7F	8403 462688	LYUBOV LUKYANOVA	{"email": "lukyanova-l_1974@postgrespro.ru", "phone": "+70978339093"}
0005434325457	DEFC85	4969 598747	DMITRIY ANDREEV	{"email": "d-andreev-28111971@postgrespro.ru", "phone": "+70996507744"}
0005434325458	DEFC85	4336 415406	MARIYA SOKOLOVA	{"phone": "+70575499102"}
0005434325459	346493	7229 184752	VLADIMIR BONDARENKO	{"email": "bondarenko_v1968@postgrespro.ru", "phone": "+70444793468"}
0005434325460	B62AD6	8346 252535	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrova.elizaveta_111963@postgrespro.ru", "phone": "+70656104417"}
0005434325461	DFE18D	1186 296615	MARIYA MIKHAYLOVA	{"email": "mikhaylova_m_21101962@postgrespro.ru", "phone": "+70570240100"}
0005434325462	D68CB1	2941 428222	ELENA NIKITINA	{"email": "nikitina.elena_041980@postgrespro.ru", "phone": "+70595780381"}
0005434325463	D68CB1	3719 835778	VIOLETTA SAVELEVA	{"email": "saveleva.violetta.071977@postgrespro.ru", "phone": "+70716061420"}
0005434325464	C392F0	4870 567703	YURIY POPOV	{"phone": "+70270572020"}
0005434325465	AFC743	8996 585806	OLGA KOVALEVA	{"phone": "+70504143146"}
0005434325466	CB1F74	5632 528723	GALINA LUKYANOVA	{"email": "lukyanova.galina_111980@postgrespro.ru", "phone": "+70952001483"}
0005434325467	CB1F74	1238 961914	KARINA OVCHINNIKOVA	{"phone": "+70663685789"}
0005434325468	45A6BA	3586 116877	PETR SCHERBAKOV	{"phone": "+70063990637"}
0005434325469	7FE907	2587 544969	ELVIRA SOKOLOVA	{"phone": "+70887059247"}
0005434325470	9CBD8D	5285 650142	LYUDMILA GRISHINA	{"email": "lyudmila.grishina_061966@postgrespro.ru", "phone": "+70522219484"}
0005434325471	DB3230	6020 689773	ALEVTINA NAZAROVA	{"email": "nazarova.alevtina-1975@postgrespro.ru", "phone": "+70475656068"}
0005434325472	90FC0E	6221 922133	VALENTINA KULIKOVA	{"email": "v.kulikova-1975@postgrespro.ru", "phone": "+70392493885"}
0005434325473	90FC0E	4684 429441	TATYANA VOLKOVA	{"phone": "+70805463729"}
0005434325474	90FC0E	8000 007233	ROZA TIKHONOVA	{"email": "roza_tikhonova-27041969@postgrespro.ru", "phone": "+70754538883"}
0005434325475	7D1457	7371 649464	VIKTOR EGOROV	{"phone": "+70877488656"}
0005434325476	01B1C9	3388 777880	VENIAMIN ISAEV	{"email": "v_isaev31011966@postgrespro.ru", "phone": "+70742449587"}
0005434325477	D4F0FE	0214 721282	SVETLANA MIKHAYLOVA	{"email": "mikhaylova.s1973@postgrespro.ru", "phone": "+70150523804"}
0005434325478	C16ED2	1131 864301	OLGA VASILEVA	{"email": "vasileva.olga-30111959@postgrespro.ru", "phone": "+70525892718"}
0005434325479	17676C	7559 087533	ELENA BORISOVA	{"email": "e-borisova_121978@postgrespro.ru", "phone": "+70060535668"}
0005434325480	17676C	9319 269538	TATYANA FOMINA	{"email": "fominatatyana.20041965@postgrespro.ru", "phone": "+70154934391"}
0005434325481	849E0C	5969 298115	EVGENIY ALEKSEEV	{"email": "e.alekseev.061981@postgrespro.ru", "phone": "+70546112107"}
0005434325482	550AC4	8087 020730	OLEG KULIKOV	{"phone": "+70084983523"}
0005434325483	3C8F77	1696 133676	ALINA NAZAROVA	{"email": "nazarovaalina.101977@postgrespro.ru", "phone": "+70292562489"}
0005434325484	3C8F77	7678 587251	ALEKSEY ANTONOV	{"email": "antonov.aleksey.20071982@postgrespro.ru", "phone": "+70847656049"}
0005434325485	3C8F77	2517 249780	ANNA POLYAKOVA	{"email": "apolyakova-17111970@postgrespro.ru", "phone": "+70447080873"}
0005434325486	7A9B53	9216 358661	OLGA ABRAMOVA	{"email": "olga-abramova_101982@postgrespro.ru", "phone": "+70256014434"}
0005434325487	877445	5575 531221	OLGA ZAKHAROVA	{"email": "o-zakharova1971@postgrespro.ru", "phone": "+70272754589"}
0005434325488	877445	5577 109717	MIKHAIL KUZNECOV	{"phone": "+70186978118"}
0005434325489	61020B	7198 331616	PAVEL KOROLEV	{"email": "korolev.pavel.1968@postgrespro.ru", "phone": "+70805562426"}
0005434325490	61020B	0452 302363	IRINA MIRONOVA	{"phone": "+70193748189"}
0005434325491	DEF10F	3243 332692	MARGARITA KOMAROVA	{"phone": "+70815603209"}
0005434325492	ABB737	2551 747891	VIKTORIYA DMITRIEVA	{"email": "dmitrieva_viktoriya-31081960@postgrespro.ru", "phone": "+70479049633"}
0005434325493	2C5F36	9153 913647	YULIYA PETROVA	{"phone": "+70466647473"}
0005434325494	2C5F36	9444 655928	ELIZAVETA MOROZOVA	{"email": "e-morozova-1965@postgrespro.ru", "phone": "+70195700864"}
0005434325495	2C5F36	1520 835131	SVETLANA ZHURAVLEVA	{"email": "s.zhuravleva041990@postgrespro.ru", "phone": "+70923807721"}
0005434325496	E80BB3	0722 025042	NINA ISAEVA	{"phone": "+70863769420"}
0005434325497	E80BB3	0871 989563	TAMARA KISELEVA	{"phone": "+70757376169"}
0005434325498	02E966	5510 673514	GALINA DANILOVA	{"email": "gdanilova-29101980@postgrespro.ru", "phone": "+70051036866"}
0005434325499	02E966	5517 442168	MARINA YAKOVLEVA	{"phone": "+70021816788"}
0005434325500	02E966	3262 350061	ROZALIYA NESTEROVA	{"phone": "+70854778293"}
0005434325501	3511D6	5618 948321	YANA EFIMOVA	{"phone": "+70967173053"}
0005434325502	3511D6	7265 915493	SERGEY ALEKSEEV	{"email": "sergeyalekseev_111967@postgrespro.ru", "phone": "+70368577032"}
0005434325503	3511D6	9931 625390	RAMZIYA SOROKINA	{"email": "r_sorokina_021973@postgrespro.ru", "phone": "+70425526955"}
0005434325504	6F690B	8396 017288	ANDREY IVANOV	{"phone": "+70299253363"}
0005434325505	A17259	8236 853559	DMITRIY MIKHAYLOV	{"phone": "+70523139412"}
0005434325506	B9FD16	4898 890960	ANATOLIY POPOV	{"email": "anatoliy.popov.1976@postgrespro.ru", "phone": "+70524766849"}
0005434325507	B9FD16	8499 867404	TATYANA LEBEDEVA	{"email": "tatyana.lebedeva-08061970@postgrespro.ru", "phone": "+70286153659"}
0005434325508	E499A6	7700 094876	VLADISLAV PETROV	{"phone": "+70986665758"}
0005434325509	9087E5	6620 603602	LYUDMILA ZAYCEVA	{"email": "zayceval-1973@postgrespro.ru", "phone": "+70526439103"}
0005434325510	827A09	7311 055175	MARINA KONOVALOVA	{"phone": "+70546085052"}
0005434325511	DA2FE6	4843 606397	YULIYA KUDRYASHOVA	{"phone": "+70147588354"}
0005434325512	D8D5D3	6201 726874	ALEKSEY ANDREEV	{"phone": "+70536099245"}
0005434325513	37AF01	0083 335201	NATALYA KULIKOVA	{"email": "natalya-kulikova_041969@postgrespro.ru", "phone": "+70603643152"}
0005434325514	6E88B3	1262 343293	VERONIKA IVANOVA	{"email": "vivanova_121978@postgrespro.ru", "phone": "+70391489341"}
0005434325515	508EFE	9968 455270	YAROSLAV BORISOV	{"phone": "+70030748961"}
0005434325516	CFED04	6241 088063	MARIYA ANTONOVA	{"email": "antonova_m1987@postgrespro.ru", "phone": "+70747366608"}
0005434325517	4FEA2A	5274 372504	TATYANA MIRONOVA	{"email": "t-mironova031962@postgrespro.ru", "phone": "+70296570334"}
0005434325518	17DEF8	0499 348861	MAKSIM IVANOV	{"phone": "+70739794779"}
0005434325519	54C879	3911 742449	MARIYA GUSEVA	{"email": "m-guseva.1960@postgrespro.ru", "phone": "+70258080572"}
0005434325520	54C879	2864 341559	LYUDMILA POPOVA	{"phone": "+70375509930"}
0005434325521	C3C6A8	9811 484482	ALEKSEY OSIPOV	{"email": "aosipov-1969@postgrespro.ru", "phone": "+70081609361"}
0005434325522	D5A1DD	1660 086567	NIKOLAY ORLOV	{"phone": "+70928268789"}
0005434325523	C6C41C	1993 847319	VALERIY PAVLOV	{"email": "v-pavlov121960@postgrespro.ru", "phone": "+70216495130"}
0005434325524	FE48EE	6419 845603	MARGARITA ZHUKOVA	{"email": "zhukovam-1966@postgrespro.ru", "phone": "+70215307542"}
0005434325525	FE48EE	0304 329534	LYUBOV VOROBEVA	{"email": "vorobeva_l011961@postgrespro.ru", "phone": "+70135690485"}
0005434325526	6BE755	5412 802519	ARTUR NAUMOV	{"email": "a-naumov01121967@postgrespro.ru", "phone": "+70162890142"}
0005434325527	AA6EBB	1226 845595	INNA SIDOROVA	{"phone": "+70812129942"}
0005434325528	AA6EBB	1110 884979	ELENA MOISEEVA	{"phone": "+70996644290"}
0005434325529	FE40B3	3847 061419	IRINA ZAKHAROVA	{"email": "irinazakharova081968@postgrespro.ru", "phone": "+70154114383"}
0005434325530	FE40B3	1725 135639	ARINA POPOVA	{"phone": "+70666106844"}
0005434325531	8D344A	0594 922711	EKATERINA KOMAROVA	{"phone": "+70906122145"}
0005434325532	1A3486	9631 276436	PAVEL SHEVCHENKO	{"phone": "+70881138524"}
0005434325533	0ABF95	9079 529678	TATYANA ORLOVA	{"email": "t-orlova31121980@postgrespro.ru", "phone": "+70356453005"}
0005434325534	0ABF95	4793 973661	TATYANA KULIKOVA	{"email": "t.kulikova_1964@postgrespro.ru", "phone": "+70288907444"}
0005434325535	0ABF95	0820 561715	MARGARITA KRASNOVA	{"phone": "+70654642766"}
0005434325536	B5A3F8	6031 570593	RASHID KULIKOV	{"email": "kulikov.rashid.071977@postgrespro.ru", "phone": "+70674244254"}
0005434325537	384A92	5726 288328	ANDREY POPOV	{"phone": "+70829964196"}
0005434325538	7C10D8	6794 805006	SVETLANA SERGEEVA	{"phone": "+70484108051"}
0005434325539	950A15	6403 978661	IVAN ZAYCEV	{"email": "ivan-zaycev-1968@postgrespro.ru", "phone": "+70414652629"}
0005434325540	762E3A	9304 365153	ANDREY KISELEV	{"phone": "+70717625101"}
0005434325541	0B440B	1562 449776	NADEZHDA NAUMOVA	{"email": "naumovanadezhda.04051972@postgrespro.ru", "phone": "+70460931592"}
0005434325542	2EDDEA	9999 817049	ANTON VOLKOV	{"phone": "+70214562826"}
0005434325543	6FADCA	9198 086076	TIMOFEY SOKOLOV	{"phone": "+70931039821"}
0005434325544	6FADCA	2592 729421	ANNA POPOVA	{"email": "popova_a-29101975@postgrespro.ru", "phone": "+70884942829"}
0005434325545	527707	8759 921888	VYACHESLAV ANDREEV	{"email": "vyacheslavandreev1965@postgrespro.ru", "phone": "+70020965236"}
0005434325546	04C513	3121 377564	OLGA NIKOLAEVA	{"phone": "+70117198666"}
0005434325547	04C513	1913 106447	VLADIMIR SMIRNOV	{"phone": "+70600410229"}
0005434325548	371DEA	9167 830075	NATALYA MASLOVA	{"email": "natalya-maslova_27081970@postgrespro.ru", "phone": "+70581604543"}
0005434325549	4F2D8C	7113 572052	OLGA DENISOVA	{"phone": "+70658328751"}
0005434325550	3603BA	4191 427504	ANDREY GORBUNOV	{"phone": "+70985017725"}
0005434325551	F897F0	4865 644059	YULIYA ZAKHAROVA	{"phone": "+70902554581"}
0005434325552	94AA97	3932 513013	EVELINA NIKOLAEVA	{"phone": "+70907311993"}
0005434325553	5C1393	5768 502237	SERGEY MEDVEDEV	{"email": "medvedevsergey-1981@postgrespro.ru", "phone": "+70202733825"}
0005434325554	3826D0	0515 784997	ALEKSEY PETROV	{"email": "petrov.aleksey.31011970@postgrespro.ru", "phone": "+70711778728"}
0005434325555	713F70	9642 091170	VALENTINA ROMANOVA	{"email": "v.romanova-061969@postgrespro.ru", "phone": "+70519559307"}
0005434325556	304B75	1375 949954	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.28061963@postgrespro.ru", "phone": "+70895023297"}
0005434325557	304B75	0219 580525	EVGENIY SCHERBAKOV	{"phone": "+70610634366"}
0005434325558	97C0FE	4074 953531	ALEKSANDR MEDVEDEV	{"email": "medvedeva051973@postgrespro.ru", "phone": "+70931825180"}
0005434325559	97C0FE	4180 638862	VLADIMIR RODIONOV	{"phone": "+70719266433"}
0005434325560	F6D8B3	1302 526100	VIKTOR ZAKHAROV	{"email": "v_zakharov.1975@postgrespro.ru", "phone": "+70699861469"}
0005434325561	529D9A	9506 923233	SVETLANA KONDRATEVA	{"phone": "+70504080180"}
0005434325562	8FFADE	8994 267986	TATYANA PETROVA	{"email": "petrova.t.101967@postgrespro.ru", "phone": "+70136593044"}
0005434325563	5035D9	6940 258565	MARINA KAZAKOVA	{"email": "m_kazakova_051968@postgrespro.ru", "phone": "+70854020763"}
0005434325564	0F41E1	7199 907082	OLGA MASLOVA	{"email": "maslova_o.18021970@postgrespro.ru", "phone": "+70009912778"}
0005434325565	0F41E1	3516 546215	LYUBOV KUZNECOVA	{"phone": "+70852023895"}
0005434325566	2685B6	0280 005995	TATYANA POPOVA	{"phone": "+70915045163"}
0005434325567	2685B6	6126 417944	NATALYA POPOVA	{"phone": "+70607140870"}
0005434325568	98FD06	0141 186054	DMITRIY PAVLOV	{"email": "pavlov_d.1972@postgrespro.ru", "phone": "+70834493914"}
0005434325569	E193A4	6311 799294	ANTONINA NOVIKOVA	{"phone": "+70443097060"}
0005434325570	E193A4	2926 984806	ANTON ZAKHAROV	{"phone": "+70093221264"}
0005434325571	E193A4	2935 226933	LYUBOV SOROKINA	{"email": "lyubov.sorokina_13051971@postgrespro.ru", "phone": "+70636241836"}
0005434325572	F15E61	3985 192215	ALEKSANDR MAKSIMOV	{"phone": "+70878017814"}
0005434325573	5D3234	8445 911188	RAISA DAVYDOVA	{"phone": "+70312078893"}
0005434325574	DB56A1	6324 161885	TAMARA ZOTOVA	{"email": "tamara_zotova-1976@postgrespro.ru", "phone": "+70393237608"}
0005434325575	6C1346	6655 800868	SERGEY NOVIKOV	{"phone": "+70602181558"}
0005434325576	6C1346	2342 550618	ALEKSANDR TIMOFEEV	{"email": "timofeev.a_1980@postgrespro.ru", "phone": "+70474590763"}
0005434325577	2F6C6E	6161 048874	SERGEY KONOVALOV	{"email": "konovalov-s121969@postgrespro.ru", "phone": "+70543138357"}
0005434325578	CF9193	4308 833872	IVAN IVANOV	{"phone": "+70598923514"}
0005434325579	CB8F51	9170 328074	OKSANA TIMOFEEVA	{"email": "timofeevao-1973@postgrespro.ru", "phone": "+70499843962"}
0005434325580	71512D	7747 590954	ALEKSEY EGOROV	{"phone": "+70024787742"}
0005434325581	CB123F	2023 617073	VLADISLAV FEDOTOV	{"phone": "+70233530822"}
0005434325582	1201D3	3070 619709	VASILIY DENISOV	{"email": "denisov_v1966@postgrespro.ru", "phone": "+70444451381"}
0005434325583	A71DF0	5968 796471	VALENTINA TIKHONOVA	{"phone": "+70005046084"}
0005434325584	A71DF0	7534 214276	OLGA MIKHAYLOVA	{"email": "mikhaylova-olga.11061970@postgrespro.ru", "phone": "+70631804805"}
0005434325585	280D81	3333 971652	LIDIYA YAKOVLEVA	{"email": "yakovlevalidiya-011971@postgrespro.ru", "phone": "+70853055881"}
0005434325586	AE592E	9620 201258	PAVEL KOZLOV	{"phone": "+70449178026"}
0005434325587	AE592E	6138 290040	IGOR PETROV	{"phone": "+70064477150"}
0005434325588	149031	0999 707492	NINA POLYAKOVA	{"email": "n.polyakova-071972@postgrespro.ru", "phone": "+70132047498"}
0005434325589	6628B8	7227 083190	OKSANA ABRAMOVA	{"phone": "+70296588897"}
0005434325590	6628B8	5887 267679	LARISA MAKSIMOVA	{"email": "maksimova.l_1977@postgrespro.ru", "phone": "+70193588438"}
0005434325591	6628B8	4954 476149	ALBINA KISELEVA	{"email": "akiseleva.1974@postgrespro.ru", "phone": "+70313496565"}
0005434325592	9DDEDA	7475 033546	IRINA GUSEVA	{"email": "i_guseva_071965@postgrespro.ru", "phone": "+70448402574"}
0005434325593	481A12	5889 096164	SVETLANA SOLOVEVA	{"email": "soloveva-svetlana.1971@postgrespro.ru", "phone": "+70600165124"}
0005434325594	481A12	1464 768619	RUSLAN KRASNOV	{"phone": "+70025624871"}
0005434325595	8269A1	1106 121057	NATALYA KUZNECOVA	{"email": "nkuznecova_1966@postgrespro.ru", "phone": "+70883983089"}
0005434325596	E3BDE4	2106 842873	SERGEY NOVIKOV	{"email": "novikov_s-061965@postgrespro.ru", "phone": "+70219846992"}
0005434325597	394824	0850 023806	DMITRIY KUZMIN	{"phone": "+70914850858"}
0005434325598	0DB457	4328 885734	VERA MATVEEVA	{"phone": "+70149094900"}
0005434325599	5F40CC	3759 435621	SERGEY VOLKOV	{"email": "s-volkov011978@postgrespro.ru", "phone": "+70805320055"}
0005434325600	433E72	5507 031744	EKATERINA RODIONOVA	{"email": "ekaterina-rodionova20091975@postgrespro.ru", "phone": "+70718103880"}
0005434325601	13E204	4041 734666	SERGEY MAKAROV	{"phone": "+70356804452"}
0005434325602	13E204	0738 191111	ANDREY NAUMOV	{"email": "anaumov_31031974@postgrespro.ru", "phone": "+70844646934"}
0005434325603	F4B402	5800 502350	LYUDMILA CHERNOVA	{"email": "l_chernova.1957@postgrespro.ru", "phone": "+70854938823"}
0005434325604	C72A89	1064 706345	ALEKSEY STEPANOV	{"email": "stepanova.121969@postgrespro.ru", "phone": "+70635379968"}
0005434325605	7FA017	8574 398506	VLADIMIR ISAEV	{"email": "isaev_vladimir11091967@postgrespro.ru", "phone": "+70754270903"}
0005434325606	21D0CB	3325 975551	SVETLANA SAVELEVA	{"email": "saveleva-s1975@postgrespro.ru", "phone": "+70899405166"}
0005434325607	C734D1	9607 516102	SVETLANA BELOVA	{"email": "s_belova1976@postgrespro.ru", "phone": "+70654568754"}
0005434325608	C734D1	1592 978959	POLINA NESTEROVA	{"phone": "+70224773098"}
0005434325609	0F3017	8258 441282	VIKTORIYA FILATOVA	{"phone": "+70906987327"}
0005434325610	A2C738	2086 821060	KIRILL YAKOVLEV	{"email": "kirillyakovlev15031969@postgrespro.ru", "phone": "+70784984227"}
0005434325611	A2C738	4058 073906	ALISA ISAEVA	{"email": "isaeva-alisa.051975@postgrespro.ru", "phone": "+70897585628"}
0005434325612	D8D17B	2765 455918	ALEKSANDR KOZLOV	{"phone": "+70246785863"}
0005434325613	D6FD99	6192 128997	ANASTASIYA AFANASEVA	{"phone": "+70882901286"}
0005434325614	4D7EC7	0812 724342	VERA ANISIMOVA	{"email": "anisimova_vera_15071962@postgrespro.ru", "phone": "+70068337553"}
0005434325615	4D7EC7	2789 936652	ELENA KALININA	{"email": "elenakalinina_1973@postgrespro.ru", "phone": "+70815798718"}
0005434325616	446D22	2517 158634	ALEKSEY ANTONOV	{"email": "antonovaleksey1969@postgrespro.ru", "phone": "+70077691412"}
0005434325617	CBF9B5	3492 878719	ILYA SEMENOV	{"email": "i_semenov_02071974@postgrespro.ru", "phone": "+70590084097"}
0005434325618	CBF9B5	6855 483912	ALEKSEY POPOV	{"email": "a-popov.1976@postgrespro.ru", "phone": "+70237745424"}
0005434325619	539A3E	6335 438339	OLGA SMIRNOVA	{"phone": "+70492028180"}
0005434325620	582685	6228 256892	NATALYA POPOVA	{"email": "popova.natalya-101978@postgrespro.ru", "phone": "+70346250131"}
0005434325621	A6BFB9	6688 315713	YURIY SIDOROV	{"email": "yuriy.sidorov.061959@postgrespro.ru", "phone": "+70835530292"}
0005434325622	E67EF8	6054 002064	ALEKSANDRA IVANOVA	{"email": "a_ivanova24121978@postgrespro.ru", "phone": "+70376136184"}
0005434325623	839DA9	0934 839212	YURIY ALEKSEEV	{"phone": "+70173033992"}
0005434325624	80564F	4897 128917	MARGARITA GAVRILOVA	{"email": "gavrilova_margarita.1985@postgrespro.ru", "phone": "+70672510630"}
0005434325625	4E8A6D	4136 296241	SERGEY TIKHONOV	{"phone": "+70637555149"}
0005434325626	590ED9	6570 888762	ALENA DENISOVA	{"phone": "+70565786847"}
0005434325627	8E7F59	9242 401318	NADEZHDA ZAKHAROVA	{"email": "nzakharova.091987@postgrespro.ru", "phone": "+70895700283"}
0005434325628	6AB3E1	2197 019304	YULIYA BOGDANOVA	{"email": "y-bogdanova011979@postgrespro.ru", "phone": "+70719145700"}
0005434325629	6AB3E1	5734 913020	ALEKSEY ISAEV	{"email": "aleksey.isaev091969@postgrespro.ru", "phone": "+70336281409"}
0005434325630	4D841A	2730 402882	VLADIMIR SOROKIN	{"email": "sorokin_vladimir_021970@postgrespro.ru", "phone": "+70818303971"}
0005434325631	4D841A	0421 157554	OLGA KOVALEVA	{"phone": "+70063987771"}
0005434325632	E7BF0B	4523 996021	OLGA KOLESNIKOVA	{"email": "kolesnikova.olga_1971@postgrespro.ru", "phone": "+70206729625"}
0005434325633	B3A18F	7526 266981	VALERIYA KUZNECOVA	{"phone": "+70827682072"}
0005434325634	918F0F	5442 393854	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov.03011968@postgrespro.ru", "phone": "+70272787119"}
0005434325635	82D806	2807 708461	EKATERINA KOROLEVA	{"email": "korolevae_1966@postgrespro.ru", "phone": "+70612236145"}
0005434325636	9AC66F	0761 173180	SVETLANA SEMENOVA	{"email": "s.semenova_01091968@postgrespro.ru", "phone": "+70629681913"}
0005434325637	9AC66F	8677 801221	TATYANA MIKHAYLOVA	{"phone": "+70525628732"}
0005434325638	B9139E	9053 749336	IGOR TIMOFEEV	{"phone": "+70610135784"}
0005434325639	1B918C	4353 992818	VLADIMIR NOVIKOV	{"email": "v-novikov_1977@postgrespro.ru", "phone": "+70039562134"}
0005434325640	E396F9	0123 129564	MARIYA IVANOVA	{"email": "m_ivanova121973@postgrespro.ru", "phone": "+70327888588"}
0005434325641	E396F9	5256 295018	ANASTASIYA BELOVA	{"phone": "+70388557462"}
0005434325642	F9EE7C	6630 131747	EVGENIY ALEKSANDROV	{"phone": "+70156025460"}
0005434325643	CCB5FC	1379 285651	LYUDMILA MARTYNOVA	{"phone": "+70796695644"}
0005434325644	D098D6	4307 046314	GENNADIY ROMANOV	{"phone": "+70526094953"}
0005434325645	D098D6	2663 013724	VALENTINA STEPANOVA	{"phone": "+70359169666"}
0005434325646	D098D6	3246 180537	YULIYA NIKIFOROVA	{"phone": "+70685192431"}
0005434325647	3B1926	7353 045503	TIMUR KUZMIN	{"phone": "+70144849910"}
0005434325648	64905F	6801 976922	ANNA STEPANOVA	{"phone": "+70927768869"}
0005434325649	BF9AF5	0348 379926	DENIS VASILEV	{"phone": "+70075748272"}
0005434325650	AF2545	0800 786539	YURIY ANTONOV	{"email": "yantonov27121976@postgrespro.ru", "phone": "+70859848087"}
0005434325651	AF2545	9605 934479	EVGENIYA POPOVA	{"email": "popovaevgeniya_20041974@postgrespro.ru", "phone": "+70557652927"}
0005434325652	AF2545	1425 489955	VALERIY KOROLEV	{"email": "v_korolev.1966@postgrespro.ru", "phone": "+70402262872"}
0005434325653	81CCA1	6828 348577	PETR NIKOLAEV	{"phone": "+70521136408"}
0005434325654	305027	1650 174581	NADEZHDA SEMENOVA	{"phone": "+70014232784"}
0005434325655	4ADFC1	8546 729548	ANASTASIYA DANILOVA	{"email": "danilova.anastasiya1978@postgrespro.ru", "phone": "+70571804091"}
0005434325656	8D9EC9	3461 834532	ANNA MALYSHEVA	{"email": "malysheva.anna_25021971@postgrespro.ru", "phone": "+70500436866"}
0005434325657	018651	2839 419183	ALISA ANISIMOVA	{"email": "alisa.anisimova-1968@postgrespro.ru", "phone": "+70566235818"}
0005434325658	018651	6484 176830	NIKOLAY NIKITIN	{"phone": "+70831454489"}
0005434325659	018651	7905 431185	SERGEY ANDREEV	{"email": "sandreev.1981@postgrespro.ru", "phone": "+70322003460"}
0005434325660	0AC688	1421 841285	ALBINA ANTONOVA	{"email": "albina_antonova.08031978@postgrespro.ru", "phone": "+70238316210"}
0005434325661	F0CE43	1565 152961	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.1972@postgrespro.ru", "phone": "+70361149259"}
0005434325662	4B32FC	0392 051995	VERA MOISEEVA	{"phone": "+70905337073"}
0005434325663	D57B7A	7060 095579	EVGENIY NIKITIN	{"phone": "+70476999146"}
0005434325664	D57B7A	1780 409551	SERGEY NIKITIN	{"email": "nikitins.15111979@postgrespro.ru", "phone": "+70147400738"}
0005434325665	D57B7A	2258 630478	LARISA MAKAROVA	{"phone": "+70769306986"}
0005434325666	851D93	6575 260752	ANNA BARANOVA	{"phone": "+70652012962"}
0005434325667	F066A5	8834 235589	DMITRIY IVANOV	{"email": "ivanov-d1977@postgrespro.ru", "phone": "+70375878296"}
0005434325668	BEEB7C	2021 326283	ANASTASIYA STEPANOVA	{"email": "anastasiya-stepanova031962@postgrespro.ru", "phone": "+70125803481"}
0005434325669	A5D3E0	3768 541245	ALEKSEY EGOROV	{"phone": "+70651057963"}
0005434325670	13FA4A	6930 382575	ANTON MAKAROV	{"email": "makarov-a.07081972@postgrespro.ru", "phone": "+70350989547"}
0005434325671	13FA4A	5687 734385	VLADIMIR BELOV	{"email": "belov.v.041974@postgrespro.ru", "phone": "+70354282386"}
0005434325672	0B501E	8997 045472	ALEKSANDR KARPOV	{"email": "karpovaleksandr.041978@postgrespro.ru", "phone": "+70667845400"}
0005434325673	0B501E	4550 645205	ARTEMIY ROMANOV	{"email": "artemiy-romanov-1964@postgrespro.ru", "phone": "+70592528697"}
0005434325674	F2A66E	1926 169958	TATYANA TIKHONOVA	{"email": "tikhonovat-1972@postgrespro.ru", "phone": "+70276292710"}
0005434325675	B9AA17	0075 602910	ALEKSANDR NIKOLAEV	{"phone": "+70145607727"}
0005434325676	B9AA17	0519 649803	EKATERINA ALEKSEEVA	{"email": "alekseeva.e.071983@postgrespro.ru", "phone": "+70457510325"}
0005434325677	DFE7AA	1072 369669	IGOR DAVYDOV	{"email": "i.davydov-1972@postgrespro.ru", "phone": "+70795726376"}
0005434325678	A33BED	4537 077183	LIDIYA BORISOVA	{"email": "borisova.l-1969@postgrespro.ru", "phone": "+70027582696"}
0005434325679	E1257F	4316 375312	IGOR MAKAROV	{"phone": "+70261123887"}
0005434325680	992D11	3282 536246	ARTUR ZHUKOV	{"email": "a_zhukov.041984@postgrespro.ru", "phone": "+70123749436"}
0005434325681	4BC679	9067 586402	LYUBOV SOROKINA	{"phone": "+70722568896"}
0005434325682	C8764C	0578 244277	VIKTOR IVANOV	{"email": "ivanov_viktor_1984@postgrespro.ru", "phone": "+70135008182"}
0005434325683	A7E0D3	5751 927591	LYUBOV KULIKOVA	{"phone": "+70745331440"}
0005434325684	B75D1C	5957 247671	IRINA AKIMOVA	{"phone": "+70255809889"}
0005434325685	D2D85D	8518 138938	ALEKSEY ANDREEV	{"phone": "+70538744643"}
0005434325686	B3FF06	9014 382288	VLADIMIR IVANOV	{"email": "v.ivanov_091983@postgrespro.ru", "phone": "+70483795926"}
0005434325687	D2C34B	6105 480999	IGOR KRASNOV	{"phone": "+70514101159"}
0005434325688	D3C03F	3825 545339	RAISA TIMOFEEVA	{"phone": "+70596052230"}
0005434325689	D3C03F	9490 960783	DENIS ANTONOV	{"email": "dantonov29041974@postgrespro.ru", "phone": "+70338144577"}
0005434325690	9ABDCD	9830 531818	MARIYA IVANOVA	{"email": "ivanovamariya_28111967@postgrespro.ru", "phone": "+70529341017"}
0005434325691	3EDAD4	2370 562141	OLESYA ISAEVA	{"phone": "+70940611836"}
0005434325692	3EDAD4	7919 648684	ELENA MOISEEVA	{"email": "moiseevae-101976@postgrespro.ru", "phone": "+70683103776"}
0005434325693	3EDAD4	6893 303540	ELIZAVETA SMIRNOVA	{"phone": "+70168720393"}
0005434325694	DBF714	1527 336794	ANZHELIKA OSIPOVA	{"phone": "+70022539923"}
0005434325695	DBF714	4939 219053	DMITRIY GERASIMOV	{"email": "gerasimov.d.1967@postgrespro.ru", "phone": "+70042336937"}
0005434325696	255481	9866 335835	YULIYA KUZNECOVA	{"email": "yuliya.kuznecova1968@postgrespro.ru", "phone": "+70088654751"}
0005434325697	255481	6120 407774	ALESYA KUZNECOVA	{"email": "kuznecova_a.1983@postgrespro.ru", "phone": "+70310045702"}
0005434325698	0D2CBF	2490 881993	EGOR POPOV	{"email": "popove29101964@postgrespro.ru", "phone": "+70861060792"}
0005434325699	B149E6	5964 971930	VERONIKA SOROKINA	{"email": "sorokina-v1977@postgrespro.ru", "phone": "+70353940383"}
0005434325700	B149E6	9763 340369	ELENA VASILEVA	{"email": "elenavasileva-041983@postgrespro.ru", "phone": "+70097504511"}
0005434325701	4FA5BB	7871 515717	SVETLANA GUSEVA	{"email": "guseva-s011969@postgrespro.ru", "phone": "+70910583183"}
0005434325702	643907	3991 979539	ZOYA MIKHAYLOVA	{"phone": "+70001959478"}
0005434325703	F08666	0372 590980	VALERIY VOLKOV	{"phone": "+70266540042"}
0005434325704	06128F	8162 020987	ANTONINA ERMAKOVA	{"email": "antonina.ermakova.111975@postgrespro.ru", "phone": "+70448064078"}
0005434325705	06128F	6993 292109	EKATERINA GAVRILOVA	{"email": "gavrilova.ekaterina021978@postgrespro.ru", "phone": "+70785218144"}
0005434325706	DD0095	9122 499120	VYACHESLAV RODIONOV	{"email": "vyacheslav.rodionov21041981@postgrespro.ru", "phone": "+70687456643"}
0005434325707	DD0095	1376 376088	FANIYA ALEKSEEVA	{"email": "f-alekseeva.1979@postgrespro.ru", "phone": "+70677992968"}
0005434325708	DD0095	6326 277510	DENIS VLASOV	{"email": "vlasovdenis22071979@postgrespro.ru", "phone": "+70511613480"}
0005434325709	9D54FD	7742 663772	EVGENIY DMITRIEV	{"phone": "+70576674392"}
0005434325710	48A23B	5551 484875	OLGA ZOTOVA	{"email": "zotova-olga.111964@postgrespro.ru", "phone": "+70719693839"}
0005434325711	91CF3B	7312 796398	ELENA KOMAROVA	{"phone": "+70028359764"}
0005434325712	91CF3B	3433 984937	ELENA KALININA	{"email": "kalinina.elena-1959@postgrespro.ru", "phone": "+70724747167"}
0005434325713	0F087C	6644 723493	OLGA KOMAROVA	{"email": "komarova_olga.30051975@postgrespro.ru", "phone": "+70450021330"}
0005434325714	1248A3	9131 287899	ANTON DENISOV	{"email": "denisov_anton071974@postgrespro.ru", "phone": "+70948848855"}
0005434325715	1248A3	8434 108201	TATYANA ZAKHAROVA	{"email": "zakharova.t-30061968@postgrespro.ru", "phone": "+70444076411"}
0005434325716	1248A3	6975 074354	OLEG PAVLOV	{"phone": "+70162776887"}
0005434325717	8F61B0	7452 471033	KRISTINA VOLKOVA	{"email": "kristina.volkova-1979@postgrespro.ru", "phone": "+70049057238"}
0005434325718	273B8A	3788 716185	VASILIY VOLKOV	{"email": "v-volkov.13071976@postgrespro.ru", "phone": "+70996928033"}
0005434325719	6A576C	6820 358719	ALI KISELEV	{"email": "a.kiselev13061960@postgrespro.ru", "phone": "+70507576819"}
0005434325720	7DC93E	1349 005313	SVETLANA KAZAKOVA	{"email": "s.kazakova-1968@postgrespro.ru", "phone": "+70970760243"}
0005434325721	7DC93E	0734 318529	LYUDMILA KUZMINA	{"phone": "+70972419036"}
0005434325722	13C42A	7619 302760	SVETLANA ARKHIPOVA	{"phone": "+70889961312"}
0005434325723	13C42A	8746 618289	VERA ALEKSANDROVA	{"email": "valeksandrova.17011979@postgrespro.ru", "phone": "+70414679782"}
0005434325724	3F257D	8000 274069	GENNADIY POPOV	{"email": "gpopov_1969@postgrespro.ru", "phone": "+70272852639"}
0005434325725	3F257D	2127 857884	TATYANA KOVALEVA	{"email": "tatyana-kovaleva.01101975@postgrespro.ru", "phone": "+70028049290"}
0005434325726	AC3A03	0765 256580	VYACHESLAV IVANOV	{"phone": "+70003477519"}
0005434325727	9245C8	9950 603312	MARIYA EFREMOVA	{"email": "mariya.efremova-111973@postgrespro.ru", "phone": "+70470122800"}
0005434325728	9245C8	2636 167368	NIKOLAY FOMIN	{"email": "fomin_nikolay071969@postgrespro.ru", "phone": "+70910185393"}
0005434325729	207241	4289 438050	EVGENIY ALEKSEEV	{"phone": "+70453705274"}
0005434325730	207241	9006 403702	YURIY IVANOV	{"email": "ivanov-yuriy.1975@postgrespro.ru", "phone": "+70386601449"}
0005434325731	323DA7	7578 934428	GALINA ABRAMOVA	{"phone": "+70490063548"}
0005434325732	323DA7	8871 197356	SOFYA KAZAKOVA	{"phone": "+70208055497"}
0005434325733	A8482C	8884 379812	YURIY ISAEV	{"email": "isaev.yuriy_011975@postgrespro.ru", "phone": "+70242754994"}
0005434325734	A8482C	8973 430636	NADEZHDA MOROZOVA	{"email": "morozovanadezhda-1964@postgrespro.ru", "phone": "+70301951932"}
0005434325735	BACF49	4924 988016	SERGEY KISELEV	{"phone": "+70091266373"}
0005434325736	79DB61	3805 168000	IVAN ROMANOV	{"email": "ivanromanov.17111972@postgrespro.ru", "phone": "+70061121594"}
0005434325737	79DB61	2765 315000	KIRILL ZAYCEV	{"phone": "+70384164151"}
0005434325738	6AC85D	6626 894178	TATYANA KULIKOVA	{"email": "kulikova.t.071970@postgrespro.ru", "phone": "+70920464957"}
0005434325739	AEC58D	0916 058149	ALEKSANDR SEMENOV	{"phone": "+70519382295"}
0005434325740	AEC58D	1692 201987	ELENA SMIRNOVA	{"phone": "+70783923946"}
0005434325741	1EE23C	9815 473752	LARISA KONDRATEVA	{"email": "kondrateva.l-071974@postgrespro.ru", "phone": "+70894693271"}
0005434325742	A33F62	1958 477043	ANNA ORLOVA	{"email": "a.orlova.04101980@postgrespro.ru", "phone": "+70720096490"}
0005434325743	C9B18E	7583 006676	POLINA MEDVEDEVA	{"email": "p-medvedeva.12011963@postgrespro.ru", "phone": "+70921263058"}
0005434325744	641DCF	8639 580521	NINA PAVLOVA	{"phone": "+70381768370"}
0005434325745	7CDCA3	5267 970971	IRINA KUDRYASHOVA	{"phone": "+70517711075"}
0005434325746	E241A5	3957 159532	ALEKSEY AFANASEV	{"phone": "+70821428845"}
0005434325747	5130CA	5333 364555	SHAMIL PETROV	{"email": "shamilpetrov1966@postgrespro.ru", "phone": "+70196808687"}
0005434325748	0E7F47	9926 412407	ANATOLIY KONOVALOV	{"email": "konovalov_anatoliy-051970@postgrespro.ru", "phone": "+70183499637"}
0005434325749	0E7F47	5417 347154	VITALIY MATVEEV	{"email": "matveev_v-05091968@postgrespro.ru", "phone": "+70367609812"}
0005434325750	BFBEE9	0712 086819	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay051963@postgrespro.ru", "phone": "+70278399195"}
0005434325751	BFBEE9	1795 990095	VIKTOR VLASOV	{"phone": "+70144576082"}
0005434325752	BFBEE9	9300 664978	ALENA IVANOVA	{"email": "a.ivanova-16011965@postgrespro.ru", "phone": "+70794675128"}
0005434325753	4F2295	7069 136046	TATYANA NAZAROVA	{"phone": "+70143974959"}
0005434325754	4F2295	7072 225720	IRINA CHERNOVA	{"phone": "+70353364522"}
0005434325755	4F2295	3306 292153	OLGA BELOVA	{"phone": "+70084974843"}
0005434325756	D0B7E2	5765 012534	ARTEM DENISOV	{"email": "a-denisov.17081959@postgrespro.ru", "phone": "+70269545057"}
0005434325757	D0B7E2	5702 302361	ILYA CHERNOV	{"phone": "+70807351150"}
0005434325758	F30E27	1739 361615	DINA SOKOLOVA	{"email": "sokolova-d_16081970@postgrespro.ru", "phone": "+70349879094"}
0005434325759	F30E27	5957 420394	OLGA KOZLOVA	{"phone": "+70683544714"}
0005434325760	F30E27	5612 293307	TATYANA LEBEDEVA	{"phone": "+70305415792"}
0005434325761	67C253	6152 003958	VLADISLAV RODIONOV	{"email": "rodionov.vladislav121983@postgrespro.ru", "phone": "+70559735704"}
0005434325762	67C253	8346 355147	SERGEY MOROZOV	{"email": "morozovs1972@postgrespro.ru", "phone": "+70086074508"}
0005434325763	6B6AC2	6743 865337	SVETLANA BORISOVA	{"phone": "+70252692947"}
0005434325764	BA746E	3217 538258	SERGEY SOROKIN	{"email": "sorokins1972@postgrespro.ru", "phone": "+70947813848"}
0005434325765	392F75	0532 735318	SERGEY ZAYCEV	{"email": "zaycevsergey061967@postgrespro.ru", "phone": "+70596625822"}
0005434325766	1DA060	4404 972897	SVETLANA SERGEEVA	{"email": "sergeeva-s_05051969@postgrespro.ru", "phone": "+70656285519"}
0005434325767	7F6FF2	4806 318069	SVETLANA SIDOROVA	{"email": "sidorova-s-041975@postgrespro.ru", "phone": "+70545643358"}
0005434325824	93307F	7059 414813	VALENTINA GORBUNOVA	{"phone": "+70404789184"}
0005434325768	2EE4F6	5163 722689	MARINA SMIRNOVA	{"email": "smirnova_m.1976@postgrespro.ru", "phone": "+70712094657"}
0005434325769	A75303	6485 623870	MARIYA ABRAMOVA	{"email": "abramova-mariya1963@postgrespro.ru", "phone": "+70910638415"}
0005434325770	E031DD	9364 855185	VLADIMIR KISELEV	{"phone": "+70852596027"}
0005434325771	4D7AD4	6157 080950	GALINA EGOROVA	{"email": "egorova_g-1980@postgrespro.ru", "phone": "+70726668624"}
0005434325772	4D7AD4	4238 568608	VLADIMIR SERGEEV	{"email": "vladimirsergeev.081974@postgrespro.ru", "phone": "+70309803372"}
0005434325773	2FBD84	8327 642538	VLADIMIR PETROV	{"phone": "+70640002078"}
0005434325774	C0A62A	7845 999602	NIKOLAY MAKAROV	{"phone": "+70439115055"}
0005434325775	A301B1	6236 016880	VLADIMIR PETROV	{"phone": "+70570528257"}
0005434325776	1AF316	8505 483100	VSEVOLOD VASILEV	{"email": "vsevolod_vasilev-061968@postgrespro.ru", "phone": "+70656669386"}
0005434325777	1AF316	7665 806420	LARISA FILIPPOVA	{"phone": "+70145767657"}
0005434325778	106645	4986 660530	ALEKSANDRA KULIKOVA	{"phone": "+70897263958"}
0005434325779	106645	7045 299293	RAISA KOZLOVA	{"email": "kozlovar-24031967@postgrespro.ru", "phone": "+70723642405"}
0005434325780	2FFB50	0689 299060	EDUARD KUZMIN	{"phone": "+70897151217"}
0005434325781	693A64	1671 873631	ALEKSANDR VASILEV	{"email": "vasileva-26111971@postgrespro.ru", "phone": "+70453152168"}
0005434325782	15A085	5425 153239	RUSLAN BORISOV	{"phone": "+70604196054"}
0005434325783	E6A23C	5436 897534	VERA SAVELEVA	{"email": "saveleva.v_1981@postgrespro.ru", "phone": "+70187664121"}
0005434325784	66D16E	1225 365906	MIKHAIL SAVELEV	{"email": "savelev.mikhail_1975@postgrespro.ru", "phone": "+70727094041"}
0005434325785	66D16E	6220 067814	TATYANA PAVLOVA	{"phone": "+70521294827"}
0005434325786	EBB588	5628 439220	ANASTASIYA KALININA	{"phone": "+70619651071"}
0005434325787	EBB588	5052 184033	ELENA BELOVA	{"email": "elena-belova04041977@postgrespro.ru", "phone": "+70946634640"}
0005434325788	29A64E	7819 903066	FARIDA KONOVALOVA	{"phone": "+70863984657"}
0005434325789	3793A0	2103 765231	GALINA ZHUKOVA	{"email": "galina-zhukova.1982@postgrespro.ru", "phone": "+70101456316"}
0005434325790	3793A0	1779 109524	IVAN KOROLEV	{"email": "i_korolev.051983@postgrespro.ru", "phone": "+70738258479"}
0005434325791	3793A0	7952 272779	PAVEL STEPANOV	{"email": "stepanovp.19121963@postgrespro.ru", "phone": "+70063874801"}
0005434325792	9BEE7D	0728 492825	ELENA RODIONOVA	{"phone": "+70316460560"}
0005434325793	061ADA	6906 078055	MAKSIM BORISOV	{"phone": "+70284275631"}
0005434325794	061ADA	0804 161687	ALINA KAZAKOVA	{"phone": "+70255815664"}
0005434325795	32259B	9345 452835	VIKTORIYA VLASOVA	{"phone": "+70385285886"}
0005434325796	B39DA4	7008 725126	VLADIMIR FEDOROV	{"email": "vladimir.fedorov-17101974@postgrespro.ru", "phone": "+70014367891"}
0005434325797	69AF5D	6094 901943	NATALYA GUSEVA	{"email": "natalya_guseva14011969@postgrespro.ru", "phone": "+70619382416"}
0005434325798	35C31E	4330 187387	ANDREY IVANOV	{"phone": "+70485871300"}
0005434325799	937E23	6184 458528	LILIYA MEDVEDEVA	{"phone": "+70216165924"}
0005434325800	0EC861	8104 449382	GALINA IVANOVA	{"email": "ivanova.galina.1975@postgrespro.ru", "phone": "+70677618124"}
0005434325801	0EC861	9033 053180	DMITRIY MAKAROV	{"email": "dmakarov18061960@postgrespro.ru", "phone": "+70918109375"}
0005434325802	DD01EE	4596 126298	NATALYA KOMAROVA	{"email": "komarova_n.041969@postgrespro.ru", "phone": "+70205855879"}
0005434325803	307D5E	7751 757327	ELENA SOROKINA	{"phone": "+70488108060"}
0005434325804	307D5E	0629 674980	ANASTASIYA VLASOVA	{"phone": "+70668429847"}
0005434325805	B91C12	9502 937573	LYUDMILA KALININA	{"phone": "+70476942978"}
0005434325806	E986C2	6920 553362	ELENA MAKAROVA	{"phone": "+70773888161"}
0005434325807	E986C2	7254 424490	ALEKSANDR MOISEEV	{"email": "moiseev-a_1974@postgrespro.ru", "phone": "+70379833233"}
0005434325808	5A0B77	0243 590566	VLADIMIR FROLOV	{"email": "vladimir_frolov.09051970@postgrespro.ru", "phone": "+70053833943"}
0005434325809	F98C8B	0126 929313	ALBINA GORBUNOVA	{"email": "albina-gorbunova.081973@postgrespro.ru", "phone": "+70710818429"}
0005434325810	F98C8B	9206 258946	VITALIY KUZNECOV	{"phone": "+70972987302"}
0005434325811	C8BE37	3187 714330	VYACHESLAV MAKSIMOV	{"phone": "+70313636697"}
0005434325812	494537	8910 051473	VLADIMIR KAZAKOV	{"phone": "+70491349812"}
0005434325813	30533B	7737 678025	SERGEY MELNIKOV	{"email": "smelnikov_26101977@postgrespro.ru", "phone": "+70758155385"}
0005434325814	47E27B	0950 497878	LEONID NIKITIN	{"email": "nikitin_leonid-121968@postgrespro.ru", "phone": "+70364458869"}
0005434325815	DC9210	4988 151184	VLADISLAV STEPANOV	{"phone": "+70172464260"}
0005434325816	DC9210	8471 811717	ELENA ANDREEVA	{"email": "e.andreeva-101975@postgrespro.ru", "phone": "+70205323206"}
0005434325817	A5BB93	6710 969967	ANGELINA ANTONOVA	{"email": "angelina_antonova-08111972@postgrespro.ru", "phone": "+70325746398"}
0005434325818	A5BB93	9213 343564	VIKTOR TARASOV	{"email": "tarasov-viktor-041972@postgrespro.ru", "phone": "+70497066849"}
0005434325819	A5BB93	1907 579570	ELENA ALEKSEEVA	{"email": "elena.alekseeva-12081971@postgrespro.ru", "phone": "+70902531678"}
0005434325820	D36D3D	9302 971366	VLADIMIR MIKHAYLOV	{"phone": "+70456909145"}
0005434325821	CCB2D9	8046 874717	SERGEY MAKAROV	{"phone": "+70252429641"}
0005434325822	F19A3C	3456 120134	LARISA IVANOVA	{"email": "ivanova-larisa1977@postgrespro.ru", "phone": "+70871414589"}
0005434325823	E06E90	3534 562444	EKATERINA YAKOVLEVA	{"phone": "+70682071025"}
0005434325825	91713E	2748 662148	GLEB OSIPOV	{"email": "osipov.g051972@postgrespro.ru", "phone": "+70374806814"}
0005434325826	7C0DC2	5018 147978	MARINA KUDRYASHOVA	{"email": "mkudryashova1973@postgrespro.ru", "phone": "+70809260012"}
0005434325827	6191F5	8573 940190	SVETLANA KONOVALOVA	{"email": "konovalova-s_081980@postgrespro.ru", "phone": "+70660788131"}
0005434325828	B49D1B	0487 628111	SERGEY ZHURAVLEV	{"email": "zhuravlev.s-041977@postgrespro.ru", "phone": "+70126696775"}
0005434325829	B49D1B	5223 753568	DMITRIY NAZAROV	{"phone": "+70892625422"}
0005434325830	824306	7243 148040	NIKOLAY KUZNECOV	{"email": "kuznecov_n-22091964@postgrespro.ru", "phone": "+70151692785"}
0005434325831	824306	8276 672435	IRINA ZHURAVLEVA	{"phone": "+70221646222"}
0005434325832	44746F	1865 276229	ELENA KALININA	{"phone": "+70108598764"}
0005434325833	04ECD2	5275 945329	MARIYA EFREMOVA	{"email": "m_efremova091974@postgrespro.ru", "phone": "+70325113313"}
0005434325834	9F8DBF	8591 993204	OLGA MELNIKOVA	{"phone": "+70536536284"}
0005434325835	9F8DBF	6840 457611	ANGELINA KONOVALOVA	{"phone": "+70024103121"}
0005434325836	9F8DBF	2864 836988	VIKTOR FROLOV	{"phone": "+70161129390"}
0005434325837	2E6C4E	7058 966406	OLEG VOLKOV	{"phone": "+70381877621"}
0005434325838	2E6C4E	5591 677167	LYUDMILA VASILEVA	{"phone": "+70895822439"}
0005434325839	80D896	4130 616220	IVAN ROMANOV	{"phone": "+70727040718"}
0005434325840	A29722	6972 059847	VYACHESLAV ANDREEV	{"email": "vyacheslav-andreev.041973@postgrespro.ru", "phone": "+70980089154"}
0005434325841	09788D	8075 324028	ANNA FADEEVA	{"email": "anna.fadeeva_051973@postgrespro.ru", "phone": "+70610936744"}
0005434325842	061E81	0850 278395	OLGA DANILOVA	{"phone": "+70846165192"}
0005434325843	4E4282	0001 335228	SVETLANA PETROVA	{"email": "s_petrova.031986@postgrespro.ru", "phone": "+70523300890"}
0005434325844	A86315	6379 533676	MARIYA KAZAKOVA	{"email": "m-kazakova.031965@postgrespro.ru", "phone": "+70222270770"}
0005434325845	A86315	9667 146460	TATYANA FEDOROVA	{"email": "tatyana_fedorova.1969@postgrespro.ru", "phone": "+70499526550"}
0005434325846	928D01	0491 515155	EKATERINA YAKOVLEVA	{"phone": "+70441199044"}
0005434325847	4E599C	9624 537895	DANILA MAKAROV	{"phone": "+70371311191"}
0005434325848	4E599C	7677 559537	LYUDMILA NESTEROVA	{"email": "l.nesterova-06061977@postgrespro.ru", "phone": "+70492865332"}
0005434325849	B22189	7712 132358	YULIYA CHERNOVA	{"email": "y.chernova.1976@postgrespro.ru", "phone": "+70208206648"}
0005434325850	4FB296	0334 020626	NATALIYA SMIRNOVA	{"phone": "+70256526119"}
0005434325851	4FB296	0754 179242	ANATOLIY MARTYNOV	{"phone": "+70947468337"}
0005434325852	A77B1B	0284 902844	IVAN SIDOROV	{"phone": "+70860479758"}
0005434325853	BE220C	4239 044879	PETR MATVEEV	{"email": "matveevp-021969@postgrespro.ru", "phone": "+70836066544"}
0005434325854	DE8C9C	9933 922150	NINA CHERNOVA	{"phone": "+70404318568"}
0005434325855	A2BEBE	0026 281745	DIANA ZAYCEVA	{"phone": "+70236876821"}
0005434325856	E9CC57	0145 258580	SVETLANA TROFIMOVA	{"email": "svetlanatrofimova.1963@postgrespro.ru", "phone": "+70786171687"}
0005434325857	9DA9EC	4893 817095	ELENA GAVRILOVA	{"phone": "+70414162078"}
0005434325858	52C4D8	5022 509409	ALBINA FOMINA	{"email": "fomina_a-1988@postgrespro.ru", "phone": "+70059069478"}
0005434325859	3D9733	5612 422586	MARIYA ISAEVA	{"email": "mariya_isaeva_1974@postgrespro.ru", "phone": "+70238179909"}
0005434325860	4F4379	4100 544531	SERGEY SOROKIN	{"phone": "+70048792981"}
0005434325861	4F4379	2157 771526	ARTEM FEDOROV	{"email": "fedorov-artem-011969@postgrespro.ru", "phone": "+70494853734"}
0005434325862	AD90B9	9242 970890	OKSANA POPOVA	{"email": "popova.o.121968@postgrespro.ru", "phone": "+70926352997"}
0005434325863	F7662A	7776 347782	VLADIMIR MARTYNOV	{"email": "martynovvladimir091976@postgrespro.ru", "phone": "+70139063537"}
0005434325864	650936	4720 275857	LARISA ZAKHAROVA	{"phone": "+70351516193"}
0005434325865	650936	1712 501119	MAKSIM FOMIN	{"email": "fominm1968@postgrespro.ru", "phone": "+70693984830"}
0005434325866	3D7E29	4595 267674	YURIY MAKAROV	{"email": "makarovy10061974@postgrespro.ru", "phone": "+70833160697"}
0005434325867	771B47	3119 673076	NINA POPOVA	{"email": "npopova-1985@postgrespro.ru", "phone": "+70501714628"}
0005434325868	395A81	2803 803793	VIKTORIYA KUZNECOVA	{"phone": "+70340453740"}
0005434325869	5D9BF7	4291 141930	VIKTOR MAKAROV	{"email": "v-makarov_21101978@postgrespro.ru", "phone": "+70823394393"}
0005434325870	7E896C	1724 481530	TATYANA NIKITINA	{"email": "tatyana_nikitina071971@postgrespro.ru", "phone": "+70002764186"}
0005434325871	7E896C	1020 027244	VLADIMIR SEMENOV	{"phone": "+70596057701"}
0005434325872	7E896C	1542 887028	ELENA KONDRATEVA	{"email": "elena-kondrateva-12111972@postgrespro.ru", "phone": "+70705678051"}
0005434325873	95C7A3	7966 560239	OLGA SIDOROVA	{"phone": "+70836848934"}
0005434325874	95C7A3	5554 208150	IRINA NESTEROVA	{"email": "nesterova_irina.05121968@postgrespro.ru", "phone": "+70815801353"}
0005434325875	9BE927	2453 053604	VASILIY SERGEEV	{"email": "sergeev-v.07051978@postgrespro.ru", "phone": "+70251043851"}
0005434325876	9BE927	7188 396443	ANDREY EGOROV	{"email": "andrey-egorov.101978@postgrespro.ru", "phone": "+70341438658"}
0005434325877	1179E5	6705 936378	SVETLANA MELNIKOVA	{"phone": "+70699642093"}
0005434325878	1179E5	7306 818938	ELENA KOLESNIKOVA	{"email": "kolesnikova.elena-1993@postgrespro.ru", "phone": "+70017592304"}
0005434325879	2530D1	7211 870147	LYUDMILA KALININA	{"email": "kalinina_lyudmila-1978@postgrespro.ru", "phone": "+70901385113"}
0005434325880	A94D1A	5604 283490	NINA MOROZOVA	{"phone": "+70181997734"}
0005434325881	0E8782	0105 201056	ALESYA MAKSIMOVA	{"email": "maksimova-a-1975@postgrespro.ru", "phone": "+70172189628"}
0005434325882	0E8782	9091 291463	SERGEY TIKHONOV	{"email": "tikhonov.s_021965@postgrespro.ru", "phone": "+70000739234"}
0005434325883	68F527	2173 217151	VALENTINA FEDOROVA	{"email": "valentina.fedorova-091975@postgrespro.ru", "phone": "+70337218784"}
0005434325884	68F527	3005 137687	VLADIMIR ILIN	{"email": "ilin-v-22041966@postgrespro.ru", "phone": "+70978155634"}
0005434325885	993415	4003 666317	SNEZHANA NESTEROVA	{"phone": "+70842435527"}
0005434325886	ACE8AF	9209 306460	NATALYA NESTEROVA	{"email": "natalya_nesterova_091976@postgrespro.ru", "phone": "+70630987284"}
0005434325887	A4AC90	8013 357762	ARSENIY POPOV	{"email": "a_popov.071972@postgrespro.ru", "phone": "+70300607024"}
0005434325888	A4AC90	3811 674277	ANDREY GORBUNOV	{"email": "andrey-gorbunov1971@postgrespro.ru", "phone": "+70752051795"}
0005434325889	F84840	1910 295237	ALEKSANDR VLASOV	{"phone": "+70492009395"}
0005434325890	F29D8E	5525 128219	ALENA OVCHINNIKOVA	{"email": "alena_ovchinnikova_1974@postgrespro.ru", "phone": "+70552519075"}
0005434325891	55C518	7428 444678	VLADIMIR BORISOV	{"email": "borisov.vladimir-17011973@postgrespro.ru", "phone": "+70856755439"}
0005434325892	2284CE	1853 955245	LYUBOV KUZNECOVA	{"phone": "+70409038828"}
0005434325893	D94111	6096 277915	IGOR MAKAROV	{"phone": "+70830020630"}
0005434325894	DE9E0B	7799 017893	LYUDMILA ILINA	{"email": "ilinalyudmila-121967@postgrespro.ru", "phone": "+70663264782"}
0005434325895	B0CE04	1475 313795	VIKTOR KUZNECOV	{"phone": "+70330718659"}
0005434325896	5FC5F4	6414 311019	GALINA GORBUNOVA	{"email": "ggorbunova.08071973@postgrespro.ru", "phone": "+70971067752"}
0005434325897	603BB5	1203 740229	ALEKSEY SAVELEV	{"phone": "+70871400721"}
0005434325898	603BB5	5380 503587	NIKITA DMITRIEV	{"email": "dmitriev_n14071971@postgrespro.ru", "phone": "+70102169118"}
0005434325899	603BB5	5078 814520	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir-1976@postgrespro.ru", "phone": "+70626806937"}
0005434325900	B1CD44	5923 250382	VALENTINA BELYAEVA	{"phone": "+70402997986"}
0005434325901	B1CD44	3814 131308	SERGEY EGOROV	{"email": "s_egorov-061968@postgrespro.ru", "phone": "+70566173430"}
0005434325902	22ECA1	3393 307196	ALEKSEY SOLOVEV	{"phone": "+70710952616"}
0005434325903	7DE911	8440 724644	YURIY GRIGOREV	{"email": "grigorev_yuriy-16121967@postgrespro.ru", "phone": "+70340326308"}
0005434325904	098729	0811 266442	ALEKSANDR EGOROV	{"email": "egorov_a.071969@postgrespro.ru", "phone": "+70644817748"}
0005434325905	098729	1312 136084	PETR STEPANOV	{"email": "stepanov.p_071973@postgrespro.ru", "phone": "+70237883953"}
0005434325906	913FE5	6403 663440	IRINA KALININA	{"phone": "+70609647822"}
0005434325907	913FE5	4868 206621	PAVEL SEMENOV	{"email": "pavel_semenov.041974@postgrespro.ru", "phone": "+70255072771"}
0005434325908	51AB60	7545 683642	NIKOLAY IVANOV	{"email": "ivanov-nikolay_021971@postgrespro.ru", "phone": "+70543556261"}
0005434325909	8A111F	3454 168789	GLEB ZHUKOV	{"phone": "+70786261782"}
0005434325910	8A111F	3903 122079	VALERIY DMITRIEV	{"phone": "+70696589637"}
0005434325911	2E149B	8618 041759	PETR VASILEV	{"email": "vasilevp_021964@postgrespro.ru", "phone": "+70655461893"}
0005434325912	C64375	6850 142119	MARIYA ERMAKOVA	{"phone": "+70752753078"}
0005434325913	C64375	8580 448359	DAMIR KULIKOV	{"email": "kulikov.d1963@postgrespro.ru", "phone": "+70586956925"}
0005434325914	699E6B	7205 693009	DMITRIY IVANOV	{"phone": "+70416428139"}
0005434325915	699E6B	4155 358942	FARIT ZAKHAROV	{"phone": "+70663311389"}
0005434325916	699E6B	0461 383244	OLGA KULIKOVA	{"phone": "+70384678477"}
0005434325917	FCC6BC	1608 935298	NIKOLAY MELNIKOV	{"email": "nikolay.melnikov_1966@postgrespro.ru", "phone": "+70603823349"}
0005434325918	FCC6BC	2032 071250	VLADIMIR KAZAKOV	{"phone": "+70679755972"}
0005434325919	E5F362	3800 051623	VLADIMIR ILIN	{"phone": "+70084464224"}
0005434325920	5D2B88	3401 368744	ALEKSEY KONOVALOV	{"email": "aleksey_konovalov-121973@postgrespro.ru", "phone": "+70149997953"}
0005434325921	B6A8B1	8235 139272	ALEKSEY KARPOV	{"email": "karpov-aleksey.081973@postgrespro.ru", "phone": "+70804503784"}
0005434325922	B6A8B1	6040 975732	OLGA SOKOLOVA	{"email": "sokolova.o1968@postgrespro.ru", "phone": "+70639923291"}
0005434325923	DFD938	0960 299860	GALINA MIKHAYLOVA	{"email": "galinamikhaylova-1978@postgrespro.ru", "phone": "+70474295368"}
0005434325924	E26064	3052 024956	SERGEY KULIKOV	{"phone": "+70424666185"}
0005434325925	60DD31	7376 667545	TATYANA SEMENOVA	{"phone": "+70269021560"}
0005434325926	60DD31	0135 608781	YURIY NAZAROV	{"phone": "+70521127216"}
0005434325927	6C03F5	3616 423828	VLADIMIR PETROV	{"phone": "+70111990752"}
0005434325928	8222A5	9868 488535	VARVARA ARKHIPOVA	{"phone": "+70969890186"}
0005434325929	8222A5	5698 299456	ANDREY IVANOV	{"phone": "+70965879941"}
0005434325930	64D422	6475 750771	ANNA KARPOVA	{"phone": "+70528904803"}
0005434325931	64D422	4394 058478	VLADIMIR NAZAROV	{"phone": "+70077679352"}
0005434325932	F6E736	3516 227827	NIKOLAY SEMENOV	{"phone": "+70656275638"}
0005434325933	683471	6410 705275	PAVEL POPOV	{"phone": "+70509754907"}
0005434325934	683471	4068 047224	NIKITA MIKHAYLOV	{"email": "mikhaylov_nikita.1974@postgrespro.ru", "phone": "+70854672240"}
0005434325935	2CB7F7	5831 816072	PAVEL KRASNOV	{"email": "pavelkrasnov-1984@postgrespro.ru", "phone": "+70910478613"}
0005434325936	36F970	9914 742053	RUZALIYA KUZNECOVA	{"email": "r_kuznecova1971@postgrespro.ru", "phone": "+70574170267"}
0005434325937	36F970	3685 410947	YURIY KULIKOV	{"phone": "+70823789111"}
0005434325938	6806F7	6074 286600	LYUDMILA SOKOLOVA	{"email": "lyudmila.sokolova_08121971@postgrespro.ru", "phone": "+70346628470"}
0005434325939	7CFFFD	7625 925267	ALEKSANDR DMITRIEV	{"email": "dmitriev.aleksandr121974@postgrespro.ru", "phone": "+70513508738"}
0005434325940	0AA41E	1835 304151	VARVARA FEDOROVA	{"email": "fedorovavarvara_1964@postgrespro.ru", "phone": "+70601384747"}
0005434325941	0AA41E	3656 876570	ANASTASIYA OSIPOVA	{"email": "osipova.anastasiya_041975@postgrespro.ru", "phone": "+70670986058"}
0005434325942	7A39CB	9870 513626	DMITRIY VASILEV	{"email": "dmitriyvasilev.1972@postgrespro.ru", "phone": "+70332063610"}
0005434325943	7A39CB	5903 271144	OKSANA MIRONOVA	{"email": "omironova-041981@postgrespro.ru", "phone": "+70909135142"}
0005434325944	6A0BFE	2936 424174	PETR BARANOV	{"phone": "+70434798824"}
0005434325945	6A0BFE	4617 592308	VALENTINA KARPOVA	{"phone": "+70101758201"}
0005434325946	A4B663	7255 938570	ZINAIDA MOROZOVA	{"phone": "+70145821139"}
0005434325947	A4B663	3994 983208	NIKOLAY MIKHAYLOV	{"phone": "+70386617775"}
0005434325948	37A282	6982 511665	VALENTINA ZOTOVA	{"email": "v.zotova-08041973@postgrespro.ru", "phone": "+70432125761"}
0005434325949	C8D918	8613 434552	VALERIY SERGEEV	{"email": "vsergeev-19071961@postgrespro.ru", "phone": "+70475622124"}
0005434325950	5AFA6E	3435 615795	NIKOLAY VLASOV	{"email": "n.vlasov-111972@postgrespro.ru", "phone": "+70910905788"}
0005434325951	82A359	9558 883035	ANASTASIYA GUSEVA	{"phone": "+70028842688"}
0005434325952	82A359	5759 759708	VERONIKA LAZAREVA	{"email": "lazareva-veronika1966@postgrespro.ru", "phone": "+70944843539"}
0005434325953	82A359	6862 368346	VYACHESLAV BORISOV	{"phone": "+70907747292"}
0005434325954	C07F9F	3007 808515	YULIYA DANILOVA	{"phone": "+70615336813"}
0005434325955	ABDA46	1417 211796	ELENA BELYAEVA	{"phone": "+70911648590"}
0005434325956	A39ECF	9394 734417	LYUDMILA STEPANOVA	{"phone": "+70345917476"}
0005434325957	1FC2ED	9913 829329	LYUBOV SMIRNOVA	{"phone": "+70897450954"}
0005434325958	5363EB	9740 995548	LYUBOV MATVEEVA	{"email": "matveevalyubov-1972@postgrespro.ru", "phone": "+70659237507"}
0005434325959	5363EB	4077 649323	OLEG SERGEEV	{"email": "olegsergeev-1964@postgrespro.ru", "phone": "+70731729084"}
0005434325960	00409D	6707 207707	SERGEY NIKOLAEV	{"phone": "+70235025014"}
0005434325961	00409D	4129 974006	ANNA ZAYCEVA	{"email": "zaycevaa.121983@postgrespro.ru", "phone": "+70229594891"}
0005434325962	00409D	1223 391701	ELINA ISAEVA	{"phone": "+70649544193"}
0005434325963	A981C9	7641 103659	LILIYA RODIONOVA	{"email": "rodionova_liliya-071975@postgrespro.ru", "phone": "+70513508863"}
0005434325964	D089A3	9524 936445	DMITRIY SHEVCHENKO	{"email": "shevchenkodmitriy17051976@postgrespro.ru", "phone": "+70677605957"}
0005434325965	31A687	4461 048111	MARINA AKIMOVA	{"email": "akimovam-10011982@postgrespro.ru", "phone": "+70288443061"}
0005434325966	31A687	4658 014706	NADEZHDA NAZAROVA	{"email": "nadezhda_nazarova30081972@postgrespro.ru", "phone": "+70223994759"}
0005434325967	3A7396	3872 809283	REGINA FOMINA	{"phone": "+70864859289"}
0005434325968	99A4C1	0978 386464	TATYANA SOLOVEVA	{"email": "tatyana_soloveva_1981@postgrespro.ru", "phone": "+70922588154"}
0005434325969	3D0EAD	2152 091670	SVETLANA GRISHINA	{"email": "sgrishina_1984@postgrespro.ru", "phone": "+70076468464"}
0005434325970	A0C795	3170 373363	VALENTINA MASLOVA	{"phone": "+70276860165"}
0005434325971	A0C795	6090 862862	ANDREY DMITRIEV	{"email": "dmitriev-a-1965@postgrespro.ru", "phone": "+70772073672"}
0005434325972	B98848	5904 591229	TATYANA FROLOVA	{"email": "frolova-t-1960@postgrespro.ru", "phone": "+70352675663"}
0005434325973	890C76	3322 496163	YAROSLAV KARPOV	{"email": "y.karpov.1972@postgrespro.ru", "phone": "+70605800545"}
0005434325974	9B079B	9906 956753	TAMARA ZAKHAROVA	{"email": "zakharova-t101972@postgrespro.ru", "phone": "+70972380388"}
0005434325975	83651C	5674 571512	TATYANA IVANOVA	{"phone": "+70235840097"}
0005434325976	DB33CB	2512 242998	ANATOLIY KUDRYASHOV	{"phone": "+70864031364"}
0005434325977	11C1F8	7223 459930	GRIGORIY ISAEV	{"phone": "+70884306454"}
0005434325978	5937B5	0124 087225	TATYANA MAKSIMOVA	{"email": "maksimovatatyana_1979@postgrespro.ru", "phone": "+70005070734"}
0005434325979	130310	9230 418384	MARINA ZAKHAROVA	{"phone": "+70242455891"}
0005434325980	130310	3730 462429	ANATOLIY ISAEV	{"phone": "+70033378730"}
0005434325981	3D66F7	4834 888311	SERGEY NOVIKOV	{"email": "novikovsergey-011977@postgrespro.ru", "phone": "+70633235030"}
0005434325982	A7E9AE	1108 845774	MARINA IVANOVA	{"email": "m-ivanova_021969@postgrespro.ru", "phone": "+70256913088"}
0005434325983	A7E9AE	6189 857189	YURIY MAKSIMOV	{"phone": "+70371149420"}
0005434325984	A7E9AE	7667 956589	ANASTASIYA KRASNOVA	{"phone": "+70985349240"}
0005434325985	6586C8	0049 865261	EVGENIY TIKHONOV	{"email": "e.tikhonov.1986@postgrespro.ru", "phone": "+70519498769"}
0005434325986	F061F0	8448 477785	ARTEM ZAKHAROV	{"phone": "+70047822734"}
0005434326047	51EB58	8130 395291	VLADIMIR NIKITIN	{"phone": "+70565102143"}
0005434326012	EAE9A7	0197 886796	NIKOLAY GERASIMOV	{"email": "gerasimov.nikolay_1972@postgrespro.ru", "phone": "+70068471863"}
0005434326013	E59C89	3866 971179	GALINA EFIMOVA	{"phone": "+70111598519"}
0005434326014	07AAC7	1982 304698	EKATERINA YAKOVLEVA	{"email": "ekaterinayakovleva.1966@postgrespro.ru", "phone": "+70100735097"}
0005434326015	97CA4D	7578 365221	ILYA STEPANOV	{"phone": "+70202711536"}
0005434326016	67E3DF	5571 506595	SERGEY BELOV	{"email": "belov_sergey_081973@postgrespro.ru", "phone": "+70433954955"}
0005434326017	67E3DF	0245 703960	NATALYA ZAKHAROVA	{"email": "natalya-zakharova.031964@postgrespro.ru", "phone": "+70130428271"}
0005434326018	F1C062	4332 436923	YANA NIKIFOROVA	{"email": "nikiforova-yana-031964@postgrespro.ru", "phone": "+70875304129"}
0005434326019	4D52D6	4876 475675	MARGARITA KOZLOVA	{"email": "m.kozlova-1980@postgrespro.ru", "phone": "+70241323988"}
0005434326020	9A3CCE	4114 806417	NADEZHDA IVANOVA	{"email": "nadezhdaivanova101975@postgrespro.ru", "phone": "+70768654329"}
0005434326021	FE0F92	6964 780370	KONSTANTIN SERGEEV	{"phone": "+70293856788"}
0005434326022	EB85CA	9437 221793	VLADIMIR VASILEV	{"email": "vladimirvasilev-081972@postgrespro.ru", "phone": "+70981307043"}
0005434326023	B15313	6916 655504	ELENA ZHURAVLEVA	{"email": "elena-zhuravleva21101974@postgrespro.ru", "phone": "+70148225934"}
0005434326024	B15313	2582 883232	VALENTINA NIKIFOROVA	{"phone": "+70326986181"}
0005434326025	AB776B	5118 222169	TIMOFEY FROLOV	{"email": "frolov.timofey.1970@postgrespro.ru", "phone": "+70983371297"}
0005434326026	009434	9175 764612	NATALYA VASILEVA	{"phone": "+70577218740"}
0005434326027	0D27B8	2797 738963	VIKTORIYA IVANOVA	{"email": "ivanovaviktoriya-28111971@postgrespro.ru", "phone": "+70794617943"}
0005434326028	43FEB9	7096 152761	YURIY SCHERBAKOV	{"email": "yuriy-scherbakov_1959@postgrespro.ru", "phone": "+70035562221"}
0005434326029	573A4F	1190 825254	VLADIMIR BORISOV	{"email": "borisov.vladimir1962@postgrespro.ru", "phone": "+70545384369"}
0005434326030	D2D591	8287 687656	SERGEY ABRAMOV	{"phone": "+70978437562"}
0005434326031	D2D591	6118 854150	GENNADIY MAKAROV	{"email": "gennadiy_makarov1968@postgrespro.ru", "phone": "+70197938727"}
0005434326032	029D70	1943 151263	RIMMA VOROBEVA	{"email": "vorobeva-r101973@postgrespro.ru", "phone": "+70879828444"}
0005434326033	28B915	2732 531402	ALEKSEY ZHUKOV	{"email": "aleksey-zhukov.021968@postgrespro.ru", "phone": "+70106858585"}
0005434326034	28B915	8307 610890	ANATOLIY FOMIN	{"phone": "+70573720390"}
0005434326035	28B915	1143 323753	ANASTASIYA SAVELEVA	{"phone": "+70372604766"}
0005434326036	06736D	9100 264948	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-24091972@postgrespro.ru", "phone": "+70923080077"}
0005434326037	4D3BC2	2864 705194	SERGEY PETROV	{"email": "s.petrov.071960@postgrespro.ru", "phone": "+70368945838"}
0005434326038	B9A638	4331 120566	ALEKSANDR ZHURAVLEV	{"phone": "+70218960479"}
0005434326039	82A21D	6940 995895	SVETLANA ABRAMOVA	{"phone": "+70105941237"}
0005434326040	A8BBF6	8656 126796	ANTONINA ZAKHAROVA	{"phone": "+70942614688"}
0005434326041	A8BBF6	6669 383422	VALENTINA ROMANOVA	{"email": "romanova_v_1978@postgrespro.ru", "phone": "+70138976914"}
0005434326042	11E219	1831 560659	LARISA POPOVA	{"email": "popova_l121971@postgrespro.ru", "phone": "+70136327992"}
0005434326043	A8839C	4394 235225	LYUDMILA MASLOVA	{"email": "lyudmilamaslova_051979@postgrespro.ru", "phone": "+70372390104"}
0005434326044	A8839C	9929 698171	EKATERINA KRASNOVA	{"email": "ekaterina_krasnova-111983@postgrespro.ru", "phone": "+70846857989"}
0005434326045	0A25AF	8345 144835	SERGEY MIKHAYLOV	{"email": "mikhaylov_sergey22011967@postgrespro.ru", "phone": "+70702048497"}
0005434326046	FA8C00	0856 304209	GEORGIY DMITRIEV	{"email": "dmitrievgeorgiy.121974@postgrespro.ru", "phone": "+70319212404"}
0005434326048	0458D4	2725 646875	ALINA KONOVALOVA	{"email": "konovalova-a_20051968@postgrespro.ru", "phone": "+70769948931"}
0005434326049	C79A10	7596 974993	ELMIRA IVANOVA	{"phone": "+70001964650"}
0005434326050	C79A10	5679 364874	ANTON DENISOV	{"email": "denisov-a_24121964@postgrespro.ru", "phone": "+70983547262"}
0005434326051	FCD9F5	2745 612803	TATYANA ZHURAVLEVA	{"phone": "+70620578092"}
0005434326052	FCD9F5	9213 509355	NINA MOROZOVA	{"phone": "+70579838217"}
0005434326053	BDDEA8	5011 397294	ALEKSANDR MAKAROV	{"phone": "+70624862445"}
0005434326054	AA899E	1727 250137	SERGEY BONDARENKO	{"email": "bondarenko.sergey.071968@postgrespro.ru", "phone": "+70975085582"}
0005434326055	FE18F9	8692 832762	NATALIYA KISELEVA	{"phone": "+70325109737"}
0005434326056	AF99BE	9827 781349	VITALIY MAKAROV	{"phone": "+70030451217"}
0005434326057	B19161	7934 921653	LYUDMILA TARASOVA	{"phone": "+70720476312"}
0005434326058	3CA69B	2593 382778	NURIYA GORBUNOVA	{"phone": "+70948941210"}
0005434326059	3CA69B	1240 830239	ANDREY TIKHONOV	{"phone": "+70905604385"}
0005434326060	384BAC	8640 232744	ALEKSANDR PAVLOV	{"email": "pavlova.081972@postgrespro.ru", "phone": "+70436163201"}
0005434326061	384BAC	2179 294591	IGOR POPOV	{"phone": "+70430425650"}
0005434326062	EABAE8	2938 767409	SVETLANA KALININA	{"phone": "+70835656763"}
0005434326063	F77440	3266 244938	TATYANA MAKSIMOVA	{"phone": "+70601202790"}
0005434326064	F77440	6736 368069	NAILYA FEDOROVA	{"email": "nailya_fedorova.03051978@postgrespro.ru", "phone": "+70154783153"}
0005434326084	5B41B3	1361 583823	ANNA ZHUKOVA	{"email": "annazhukova_091978@postgrespro.ru", "phone": "+70557848715"}
0005434326085	E1D218	4278 510064	NATALYA ALEKSEEVA	{"phone": "+70600829334"}
0005434326086	EB2624	0071 605247	ELENA FILIPPOVA	{"email": "filippova_elena-061960@postgrespro.ru", "phone": "+70821828295"}
0005434326087	BE02B8	5499 295116	TATYANA KARPOVA	{"email": "karpova-t-051968@postgrespro.ru", "phone": "+70865086734"}
0005434326088	34EF4D	0117 898241	MARIYA EGOROVA	{"email": "mariya.egorova_18121970@postgrespro.ru", "phone": "+70894219153"}
0005434326089	9D53F8	4275 937255	OLGA KOVALEVA	{"phone": "+70633756334"}
0005434326090	40E6B9	2234 880290	VALENTINA NOVIKOVA	{"email": "v.novikova-23031968@postgrespro.ru", "phone": "+70051704611"}
0005434326091	40E6B9	8802 324514	VERA ALEKSEEVA	{"email": "alekseevavera_30101970@postgrespro.ru", "phone": "+70209070179"}
0005434326092	5E0466	7099 608654	NIKOLAY SCHERBAKOV	{"email": "nscherbakov-1981@postgrespro.ru", "phone": "+70717337035"}
0005434326093	1CD5D5	2333 356581	LYUBOV DANILOVA	{"phone": "+70390870562"}
0005434326094	1CD5D5	3108 466551	MIKHAIL MELNIKOV	{"phone": "+70639417518"}
0005434326095	2D2D78	6232 183578	INNA KOZLOVA	{"email": "kozlovai031962@postgrespro.ru", "phone": "+70044679668"}
0005434326096	459851	5799 112950	TATYANA ABRAMOVA	{"email": "tatyana.abramova16121967@postgrespro.ru", "phone": "+70266685505"}
0005434326097	088C34	3055 867456	VERA SEMENOVA	{"email": "v.semenova.21101974@postgrespro.ru", "phone": "+70234900961"}
0005434326098	088C34	6153 171062	VYACHESLAV SERGEEV	{"email": "vyacheslav_sergeev051965@postgrespro.ru", "phone": "+70810486700"}
0005434326099	F7B6B6	4485 539513	GALINA ZAYCEVA	{"phone": "+70509495115"}
0005434326100	5E5C1F	5765 620838	VITALIY BONDARENKO	{"email": "v_bondarenko.04091974@postgrespro.ru", "phone": "+70864185782"}
0005434326101	5E5C1F	6724 256585	NIKOLAY ILIN	{"email": "n-ilin1967@postgrespro.ru", "phone": "+70235184459"}
0005434326102	BD7411	6478 333601	DMITRIY GRIGOREV	{"phone": "+70754794392"}
0005434326103	BD7411	2685 643414	KONSTANTIN GRIGOREV	{"email": "grigorev.konstantin_101978@postgrespro.ru", "phone": "+70131758307"}
0005434326104	52AE86	2278 844596	NIKOLAY AFANASEV	{"email": "nikolayafanasev21021962@postgrespro.ru", "phone": "+70205909719"}
0005434326105	5B3990	7975 910984	LIDIYA NOVIKOVA	{"email": "novikovalidiya.21121966@postgrespro.ru", "phone": "+70644554524"}
0005434326106	5B3990	8136 751410	ZLATA DANILOVA	{"email": "z_danilova1964@postgrespro.ru", "phone": "+70522298733"}
0005434326107	EF1D5B	5751 379555	IVAN BORISOV	{"email": "borisov.ivan_121969@postgrespro.ru", "phone": "+70282100002"}
0005434326108	DF75B6	5303 641514	ALEKSEY SOROKIN	{"email": "sorokin_a.1970@postgrespro.ru", "phone": "+70438054053"}
0005434326109	DF75B6	2331 234176	NATALYA PAVLOVA	{"phone": "+70363536912"}
0005434326259	A5B204	1560 916709	NIKOLAY SERGEEV	{"email": "nsergeev-061974@postgrespro.ru", "phone": "+70868156482"}
0005434326260	568949	2169 789780	SERGEY MOISEEV	{"email": "sergey_moiseev_1975@postgrespro.ru", "phone": "+70515515674"}
0005434326261	59C74E	9207 478781	IVAN RODIONOV	{"email": "rodionov_ivan_14061971@postgrespro.ru", "phone": "+70322771434"}
0005434326262	C152E6	0275 204609	EVGENIY CHERNOV	{"email": "chernov_evgeniy-20061974@postgrespro.ru", "phone": "+70980487600"}
0005434326263	C152E6	5707 468070	EVGENIY ORLOV	{"phone": "+70274465640"}
0005434326264	E59122	5753 728085	ALEKSANDR MOISEEV	{"email": "moiseev_aleksandr.1976@postgrespro.ru", "phone": "+70259180137"}
0005434326265	E59122	4993 228559	ALEKSANDR ANDREEV	{"email": "andreevaleksandr_051976@postgrespro.ru", "phone": "+70234066136"}
0005434326266	4AC1BC	5331 942125	LYUBOV ALEKSEEVA	{"phone": "+70365963731"}
0005434326267	4AC1BC	7528 424680	LYUDMILA ERMAKOVA	{"email": "ermakoval13071990@postgrespro.ru", "phone": "+70775684296"}
0005434326268	FC24D2	3711 679680	ALEKSANDRA MOROZOVA	{"phone": "+70359921625"}
0005434326269	5F5534	1117 075955	EVGENIY FILIPPOV	{"email": "evgeniy_filippov07031958@postgrespro.ru", "phone": "+70505836769"}
0005434326270	1CFE3C	8232 749280	YULIYA DMITRIEVA	{"phone": "+70751112348"}
0005434326271	1CFE3C	2757 946669	LYUDMILA TITOVA	{"phone": "+70985379660"}
0005434326272	4A350B	1604 832661	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey101969@postgrespro.ru", "phone": "+70012612949"}
0005434326273	4A350B	8286 072744	OLGA MOROZOVA	{"phone": "+70603223093"}
0005434326274	B3E1E6	4606 992053	EKATERINA MOROZOVA	{"phone": "+70461788895"}
0005434326275	CEB623	1409 669560	ELIZAVETA PETROVA	{"email": "petrova-e071974@postgrespro.ru", "phone": "+70657072437"}
0005434326276	40625E	6764 536565	SVETLANA SIDOROVA	{"email": "sidorovas04091983@postgrespro.ru", "phone": "+70521264719"}
0005434326277	40625E	4781 188468	GUZEL VOLKOVA	{"phone": "+70046835484"}
0005434326278	1F519F	9073 007103	SVETLANA BARANOVA	{"phone": "+70535495851"}
0005434326279	1F519F	0709 829575	KRISTINA OVCHINNIKOVA	{"email": "kristinaovchinnikova1970@postgrespro.ru", "phone": "+70025496294"}
0005434326280	4691C8	7637 034454	VASILIY DENISOV	{"email": "v-denisov.121975@postgrespro.ru", "phone": "+70894483659"}
0005434326281	B3ACAC	2130 442410	EVGENIYA VOROBEVA	{"phone": "+70012603230"}
0005434326282	6D3FBC	5153 219005	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr051971@postgrespro.ru", "phone": "+70774330502"}
0005434326283	D3D37F	1494 622246	VIKTOR KOZLOV	{"email": "kozlov.v-1980@postgrespro.ru", "phone": "+70156291322"}
0005434326284	8FF8DB	1172 308504	ALEKSANDR KUZMIN	{"phone": "+70797055286"}
0005434326285	B1A24A	2077 673875	VLADIMIR TARASOV	{"phone": "+70857297797"}
0005434326286	0019EB	4238 174672	SVETLANA NIKITINA	{"email": "s_nikitina1968@postgrespro.ru", "phone": "+70097684863"}
0005434326287	DC0D6F	2524 481860	ALEKSEY BELOV	{"email": "aleksey_belov1971@postgrespro.ru", "phone": "+70096334725"}
0005434326288	606E8F	5537 931931	MIKHAIL KOZLOV	{"phone": "+70505263988"}
0005434326289	0C688C	0540 753264	OLGA LOGINOVA	{"email": "loginova-o-25041957@postgrespro.ru", "phone": "+70936207105"}
0005434326290	1DF24D	0627 533165	GALINA IVANOVA	{"phone": "+70706183359"}
0005434326291	1DF24D	9436 157668	PAVEL ZHURAVLEV	{"phone": "+70117021850"}
0005434326292	1DF24D	4804 562397	ELENA KUZMINA	{"email": "elena-kuzmina_18081967@postgrespro.ru", "phone": "+70238916986"}
0005434326293	A17ADB	5029 830769	NIKOLAY RODIONOV	{"email": "n.rodionov1974@postgrespro.ru", "phone": "+70852442928"}
0005434326294	A17ADB	9386 517706	DARYA YUDINA	{"email": "yudinadarya071970@postgrespro.ru", "phone": "+70034852958"}
0005434326295	A17ADB	8059 788810	VALENTINA MELNIKOVA	{"phone": "+70285850330"}
0005434326296	5D598D	1232 786882	LYUDMILA IVANOVA	{"email": "lyudmila-ivanova.1975@postgrespro.ru", "phone": "+70464237684"}
0005434326297	74F01B	5951 198959	OLGA BORISOVA	{"email": "o-borisova-1971@postgrespro.ru", "phone": "+70017467884"}
0005434326298	74F01B	2794 800905	SERGEY VASILEV	{"phone": "+70673083861"}
0005434326299	6B8C77	7793 557302	NATALIYA NESTEROVA	{"phone": "+70359046664"}
0005434326300	E971A4	0057 752090	ELENA GAVRILOVA	{"phone": "+70911939218"}
0005434326301	8E0456	0751 397570	EKATERINA TIMOFEEVA	{"email": "etimofeeva.1974@postgrespro.ru", "phone": "+70284553770"}
0005434326302	F7D71C	6381 599327	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov-1971@postgrespro.ru", "phone": "+70169222347"}
0005434343583	98DCA3	5455 647225	GRIGORIY VLASOV	{"phone": "+70236952374"}
0005434343641	7815A9	3747 428685	TATYANA ORLOVA	{"phone": "+70924113353"}
0005434343582	C110E7	3169 145505	ANDREY SERGEEV	{"email": "sergeevandrey_1969@postgrespro.ru", "phone": "+70179948008"}
0005434343584	A84412	6609 498854	ELENA ILINA	{"email": "ilinae.17091976@postgrespro.ru", "phone": "+70981958710"}
0005434343585	A776F2	7480 445884	PAVEL MAKAROV	{"email": "makarovp_1981@postgrespro.ru", "phone": "+70588474125"}
0005434343586	A776F2	4649 650286	VALENTIN IVANOV	{"email": "valentin_ivanov081956@postgrespro.ru", "phone": "+70897706092"}
0005434343587	304A05	6739 271074	GALINA KOZLOVA	{"email": "kozlova_g-1972@postgrespro.ru", "phone": "+70595447020"}
0005434343588	01C738	5287 570565	KIRILL TARASOV	{"phone": "+70171343464"}
0005434343589	01C738	4284 706711	STEPAN PAVLOV	{"phone": "+70912009334"}
0005434343590	31AEA8	0767 028830	IRINA POLYAKOVA	{"email": "ipolyakova-25091980@postgrespro.ru", "phone": "+70409171947"}
0005434343591	979C59	0070 663292	MARINA AKIMOVA	{"email": "akimova_marina_121975@postgrespro.ru", "phone": "+70461519160"}
0005434343592	979C59	0061 380785	NATALYA IVANOVA	{"email": "ivanova-natalya.1978@postgrespro.ru", "phone": "+70098938181"}
0005434343593	BA3D08	0578 685375	DMITRIY POPOV	{"email": "popov_d.1980@postgrespro.ru", "phone": "+70670642080"}
0005434343594	789E1C	1622 771677	DANIL MIRONOV	{"email": "mironov_danil-081978@postgrespro.ru", "phone": "+70496062398"}
0005434343595	21A81E	8609 543269	IVAN BELOV	{"phone": "+70350524686"}
0005434343596	21A81E	1117 437101	ANASTASIYA KOVALEVA	{"email": "a_kovaleva.1983@postgrespro.ru", "phone": "+70834656060"}
0005434343597	22B61D	0261 867945	MIKHAIL GAVRILOV	{"phone": "+70238122133"}
0005434343598	22B61D	0172 655534	LYUBOV VOLKOVA	{"phone": "+70527034159"}
0005434343599	22B61D	3697 560794	DANIIL ANDREEV	{"phone": "+70852286809"}
0005434343600	4733DA	3316 728181	VLADIMIR BELOV	{"phone": "+70507971888"}
0005434343601	F7E741	1858 462349	OLEG ZAYCEV	{"phone": "+70333478496"}
0005434343602	90DECA	3878 856811	DMITRIY KOROLEV	{"phone": "+70484695129"}
0005434343603	90DECA	9463 053727	LIDIYA NAUMOVA	{"email": "lnaumova.051973@postgrespro.ru", "phone": "+70728126389"}
0005434343604	3250A3	7183 540484	ALEKSANDRA STEPANOVA	{"phone": "+70789433190"}
0005434343605	9DA545	2624 311286	ALEKSANDRA MAKAROVA	{"phone": "+70058868776"}
0005434343606	9DA545	7003 099331	LYUBOV FADEEVA	{"phone": "+70555895743"}
0005434343607	2F8213	3850 042603	ALEKSANDR DENISOV	{"email": "a.denisov.1971@postgrespro.ru", "phone": "+70327223795"}
0005434343608	D57306	3581 280684	NADEZHDA AFANASEVA	{"email": "afanasevanadezhda-13051962@postgrespro.ru", "phone": "+70278489007"}
0005434343609	0DBD60	4478 935736	ELENA FROLOVA	{"email": "elenafrolova-1965@postgrespro.ru", "phone": "+70552346059"}
0005434343610	7000F5	4619 530762	MIKHAIL FEDOROV	{"email": "fedorovm_23021971@postgrespro.ru", "phone": "+70177252329"}
0005434343611	7000F5	7952 238472	OLGA FADEEVA	{"phone": "+70361393707"}
0005434343612	83BF52	0933 899726	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.22071968@postgrespro.ru", "phone": "+70175852833"}
0005434343613	681E9B	2698 820008	ALEKSANDR FROLOV	{"phone": "+70395262935"}
0005434343614	681E9B	4960 583952	PETR YAKOVLEV	{"email": "p_yakovlev_121976@postgrespro.ru", "phone": "+70869461030"}
0005434343615	C574E6	4563 820234	VASILIY ANDREEV	{"phone": "+70304485710"}
0005434343616	751EB2	2159 789883	MAKSIM TIMOFEEV	{"email": "timofeev.maksim_04011978@postgrespro.ru", "phone": "+70267137716"}
0005434343617	BE5B7B	1965 218785	VITALIY SCHERBAKOV	{"email": "scherbakov-v_081994@postgrespro.ru", "phone": "+70657823647"}
0005434343618	D84C2C	7708 413418	ANDREY IVANOV	{"phone": "+70548050437"}
0005434343619	9EAA27	1824 193520	NIKOLAY KUZNECOV	{"phone": "+70136603500"}
0005434343620	5116DF	3574 185321	ELVIRA TARASOVA	{"phone": "+70704066893"}
0005434343621	2C1E69	2532 207820	MAKSIM ZAKHAROV	{"phone": "+70988026894"}
0005434343622	F9B96A	3060 096958	ANDREY TIKHONOV	{"phone": "+70708924263"}
0005434343623	BF1E80	3118 857915	OLGA FILATOVA	{"phone": "+70891898241"}
0005434343624	BF1E80	5725 404501	ELENA ANDREEVA	{"phone": "+70158895061"}
0005434343625	D77F9A	2718 217323	DMITRIY MATVEEV	{"email": "d_matveev.1964@postgrespro.ru", "phone": "+70799033762"}
0005434343626	AC9E4C	3664 636813	ANNA DMITRIEVA	{"phone": "+70868352645"}
0005434343627	AC9E4C	2066 806945	SVETLANA ALEKSEEVA	{"phone": "+70636106889"}
0005434343628	5C910B	5852 920576	OLEG SEMENOV	{"phone": "+70323897480"}
0005434343629	D167DF	8798 969408	ELIZAVETA SOLOVEVA	{"phone": "+70985418441"}
0005434343630	579E60	6922 084966	VALENTINA MAKAROVA	{"email": "v.makarova1982@postgrespro.ru", "phone": "+70689671435"}
0005434343631	579E60	5667 556033	IGOR ROMANOV	{"phone": "+70015664751"}
0005434343632	F50FD9	2653 674167	ALEKSANDR SOROKIN	{"phone": "+70789693927"}
0005434343633	915890	6773 468328	IGOR VLASOV	{"phone": "+70447206306"}
0005434343634	915890	3055 108168	NIKOLAY ANDREEV	{"email": "nikolay_andreev.081966@postgrespro.ru", "phone": "+70546554057"}
0005434343635	915890	1169 901003	OLEG NIKOLAEV	{"phone": "+70165680038"}
0005434343636	9715BD	2265 077231	ALEKSANDR PAVLOV	{"email": "pavlov-a021971@postgrespro.ru", "phone": "+70117341158"}
0005434343637	9715BD	7811 254189	NADEZHDA LEBEDEVA	{"email": "nadezhda-lebedeva_29071970@postgrespro.ru", "phone": "+70135854708"}
0005434343638	9E705C	0727 580446	OLGA FILIPPOVA	{"email": "olga_filippova-1970@postgrespro.ru", "phone": "+70548322131"}
0005434343639	0AB45D	0905 501933	SERGEY SOROKIN	{"phone": "+70729607654"}
0005434343640	734400	7947 338161	ANATOLIY ANTONOV	{"email": "anatoliy-antonov20111973@postgrespro.ru", "phone": "+70160461785"}
0005434343642	5FA97E	8121 134070	TATYANA SERGEEVA	{"email": "sergeeva_t_1970@postgrespro.ru", "phone": "+70415474017"}
0005434343643	288476	2041 891787	ALEKSEY GORBUNOV	{"phone": "+70480084769"}
0005434343644	288476	7327 780754	NATALYA AFANASEVA	{"email": "afanaseva_natalya_031969@postgrespro.ru", "phone": "+70234337477"}
0005434343645	AF0A28	3167 809851	VLADIMIR ILIN	{"phone": "+70303701778"}
0005434343646	6B36F0	3087 741376	NATALYA NESTEROVA	{"email": "natalyanesterova061963@postgrespro.ru", "phone": "+70474368950"}
0005434343647	6B36F0	1958 870282	YULIYA GUSEVA	{"phone": "+70228760519"}
0005434343648	BE19EC	2744 202971	OLGA IVANOVA	{"email": "o-ivanova26031961@postgrespro.ru", "phone": "+70104370809"}
0005434343649	BE19EC	9902 642721	LYUDMILA ANDREEVA	{"email": "l_andreeva-21061979@postgrespro.ru", "phone": "+70154491354"}
0005434343650	7C63EB	3758 169678	VALERIY KUZNECOV	{"email": "valeriy-kuznecov011982@postgrespro.ru", "phone": "+70894798847"}
0005434343651	CADB66	1916 537649	ROMAN NIKOLAEV	{"email": "nikolaev-r-1983@postgrespro.ru", "phone": "+70543373643"}
0005434343652	034427	5373 185564	ELENA POPOVA	{"phone": "+70556019084"}
0005434343653	24BD00	9588 449685	TATYANA ANDREEVA	{"email": "tandreeva-26011970@postgrespro.ru", "phone": "+70912748555"}
0005434343654	24BD00	1283 717774	SANIYA CHERNOVA	{"email": "s-chernova-1970@postgrespro.ru", "phone": "+70119477641"}
0005434343655	554BB0	6172 904260	MARGARITA KOLESNIKOVA	{"email": "m_kolesnikova-121976@postgrespro.ru", "phone": "+70640682861"}
0005434343656	554BB0	8812 205483	IGOR SERGEEV	{"email": "igor.sergeev_091968@postgrespro.ru", "phone": "+70528099894"}
0005434343657	ED53B6	8025 576285	NIKOLAY PAVLOV	{"phone": "+70576904789"}
0005434343658	ED53B6	5759 406855	FARIT VLASOV	{"email": "vlasov.farit_091974@postgrespro.ru", "phone": "+70603963057"}
0005434343659	32814C	0195 459540	VADIM ZAKHAROV	{"phone": "+70797078261"}
0005434343660	32814C	8732 384953	GALINA SOKOLOVA	{"email": "galinasokolova02061981@postgrespro.ru", "phone": "+70463042668"}
0005434343661	749005	0268 467115	EVGENIY GRIGOREV	{"email": "egrigorev1955@postgrespro.ru", "phone": "+70753747225"}
0005434343662	3FC2A3	0063 711223	ZINAIDA IVANOVA	{"phone": "+70724889843"}
0005434343663	FD087D	8865 252580	IGOR YAKOVLEV	{"phone": "+70620757100"}
0005434343664	994D4B	3015 621641	POLINA DAVYDOVA	{"email": "p_davydova-1969@postgrespro.ru", "phone": "+70396335198"}
0005434343665	EEB7A2	0487 995855	TAMARA KUZNECOVA	{"email": "tamarakuznecova1962@postgrespro.ru", "phone": "+70348676758"}
0005434343666	74199F	2654 662623	ALEKSANDR FROLOV	{"email": "frolov-a.041977@postgrespro.ru", "phone": "+70362874362"}
0005434343667	90776E	1000 563547	VLADISLAV GRIGOREV	{"phone": "+70515236717"}
0005434343668	E39CB2	8911 889582	LYUDMILA TIKHONOVA	{"phone": "+70004462314"}
0005434343669	76C8A1	7458 926935	VLADIMIR POPOV	{"phone": "+70532040583"}
0005434343670	75088D	4715 778805	IRINA NESTEROVA	{"phone": "+70731879509"}
0005434343671	75088D	4370 388031	ANTONINA NIKOLAEVA	{"email": "nikolaeva-a.1971@postgrespro.ru", "phone": "+70594728861"}
0005434343672	B6DA94	6793 597704	ELENA KOMAROVA	{"phone": "+70410511029"}
0005434343673	B6DA94	5681 828509	ILYA ORLOV	{"email": "orlovi_1981@postgrespro.ru", "phone": "+70755250213"}
0005434343674	07E585	5532 226406	VALENTINA ROMANOVA	{"email": "valentina.romanova_21111979@postgrespro.ru", "phone": "+70899570638"}
0005434343675	07E585	8281 972798	OKSANA GERASIMOVA	{"phone": "+70409931938"}
0005434343676	2DEDD8	9564 473701	NATALYA BOGDANOVA	{"phone": "+70064017844"}
0005434343677	243753	2347 817422	RAISA SOROKINA	{"email": "r_sorokina-1970@postgrespro.ru", "phone": "+70937610262"}
0005434343678	23301A	5132 796884	ARTEM KOROLEV	{"email": "artem-korolev-30051978@postgrespro.ru", "phone": "+70548219323"}
0005434343679	23301A	4971 359076	ANNA EFREMOVA	{"email": "efremova.a.28061976@postgrespro.ru", "phone": "+70240044885"}
0005434343680	CAB4AB	1616 482555	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov_1975@postgrespro.ru", "phone": "+70463327407"}
0005434343681	556CF2	0295 589728	TATYANA ERMAKOVA	{"email": "ermakovat-091973@postgrespro.ru", "phone": "+70092135571"}
0005434343682	74B06E	9166 737091	ANTONINA ZAYCEVA	{"phone": "+70576834047"}
0005434343683	74B06E	8394 955476	SVETLANA VASILEVA	{"email": "svetlanavasileva_20011974@postgrespro.ru", "phone": "+70937932041"}
0005434343684	5A7123	9207 253244	ANNA SAVELEVA	{"phone": "+70561138718"}
0005434343685	C88C77	9334 926683	ALEKSANDR GRIGOREV	{"email": "agrigorev.1965@postgrespro.ru", "phone": "+70053279259"}
0005434343686	FA7676	4516 770120	FATIMA VOROBEVA	{"phone": "+70425991154"}
0005434343687	FA7676	0124 191169	SVETLANA SOROKINA	{"phone": "+70273754507"}
0005434343688	4D7BB5	9409 068307	VLADISLAV MATVEEV	{"phone": "+70858995671"}
0005434343689	4D7BB5	8679 434387	NIKITA ABRAMOV	{"phone": "+70986249563"}
0005434343690	4AD76B	7047 592548	OLEG SIDOROV	{"phone": "+70323406489"}
0005434343691	1362AE	1114 164652	VADIM SOLOVEV	{"email": "solovev_v_1979@postgrespro.ru", "phone": "+70650686847"}
0005434343692	1362AE	7525 362004	ULYANA TARASOVA	{"email": "tarasova-u.011968@postgrespro.ru", "phone": "+70417883683"}
0005434343693	E36D2D	1202 622207	NATALYA RYABOVA	{"phone": "+70514430720"}
0005434343694	E36D2D	1637 301712	TATYANA MIKHAYLOVA	{"email": "mikhaylova.tatyana_091979@postgrespro.ru", "phone": "+70116404282"}
0005434343695	28D28F	5896 509646	STEPAN BORISOV	{"phone": "+70040933866"}
0005434343696	6496E1	6434 307043	VALENTINA MIKHAYLOVA	{"email": "valentina_mikhaylova.1978@postgrespro.ru", "phone": "+70937102431"}
0005434343697	52F69E	2555 283461	ANNA MELNIKOVA	{"phone": "+70521074700"}
0005434343698	CA06AF	9135 498153	KONSTANTIN MEDVEDEV	{"phone": "+70854675933"}
0005434343699	7DCFF2	8887 864805	IGOR DENISOV	{"email": "igordenisov.22121967@postgrespro.ru", "phone": "+70136490454"}
0005434343700	BC8DAE	8528 420991	MIKHAIL VOLKOV	{"phone": "+70262727124"}
0005434343701	9BCFC3	2745 201297	ALEKSEY KUZNECOV	{"phone": "+70764319429"}
0005434343702	0F5C95	6913 569726	MARIYA POTAPOVA	{"email": "potapova.mariya.061966@postgrespro.ru", "phone": "+70747835944"}
0005434343703	8AED38	3099 146676	ALLA IVANOVA	{"email": "a.ivanova.051967@postgrespro.ru", "phone": "+70524162440"}
0005434343704	55B10C	8491 007860	LYUDMILA ARKHIPOVA	{"email": "l_arkhipova-13091980@postgrespro.ru", "phone": "+70313130986"}
0005434343705	EE5C25	7427 349285	MAKSIM MIKHAYLOV	{"email": "mikhaylov.m071975@postgrespro.ru", "phone": "+70216612144"}
0005434343706	EE5C25	3037 826968	SHAVKAT MAKSIMOV	{"phone": "+70948534559"}
0005434343707	AE5E8E	1511 725924	IRINA OVCHINNIKOVA	{"email": "irina-ovchinnikova1967@postgrespro.ru", "phone": "+70930365119"}
0005434343708	489E06	9000 895899	NINA POPOVA	{"email": "nina_popova.1968@postgrespro.ru", "phone": "+70263894863"}
0005434343709	646338	0362 284996	DARYA IVANOVA	{"phone": "+70131905777"}
0005434343710	646338	6693 344089	YURIY ZAYCEV	{"email": "zaycev_yuriy_1977@postgrespro.ru", "phone": "+70134513920"}
0005434343711	B33EF5	5243 070431	ELENA NESTEROVA	{"phone": "+70019579570"}
0005434343712	11F967	5214 176604	LYUDMILA MIRONOVA	{"phone": "+70329842807"}
0005434343713	62F336	2680 102449	ALEKSEY BORISOV	{"email": "aleksey_borisov_051976@postgrespro.ru", "phone": "+70813027656"}
0005434343714	820BFC	4043 302539	ROMAN GERASIMOV	{"email": "romangerasimov_1969@postgrespro.ru", "phone": "+70897125073"}
0005434343715	41D7A0	4741 044994	GALINA BOGDANOVA	{"email": "gbogdanova.1973@postgrespro.ru", "phone": "+70774336828"}
0005434343716	41D7A0	3104 669636	VALENTINA SOKOLOVA	{"email": "sokolovav-111976@postgrespro.ru", "phone": "+70266182808"}
0005434343717	3597C6	6112 082676	NINA NESTEROVA	{"phone": "+70602450447"}
0005434343718	F61D13	5046 108667	NINA AKIMOVA	{"phone": "+70045159740"}
0005434343719	2590DA	6068 325298	IVAN SOLOVEV	{"email": "solovev.ivan_071979@postgrespro.ru", "phone": "+70779963040"}
0005434343720	FFD013	0631 786447	KSENIYA KUZMINA	{"email": "kseniya.kuzmina-1974@postgrespro.ru", "phone": "+70673276184"}
0005434343721	FFD013	1901 402888	TATYANA YAKOVLEVA	{"email": "t.yakovleva1977@postgrespro.ru", "phone": "+70015482577"}
0005434343722	FFD6E4	0171 593718	TATYANA MARTYNOVA	{"phone": "+70271362515"}
0005434343723	417864	5872 263338	VLADIMIR FEDOROV	{"email": "vladimirfedorov_14021968@postgrespro.ru", "phone": "+70749180708"}
0005434343724	417864	2147 936681	ALEKSANDR KUZNECOV	{"email": "a_kuznecov-081970@postgrespro.ru", "phone": "+70800974003"}
0005434343725	A27F78	2849 135391	EGOR FOMIN	{"email": "fominegor091978@postgrespro.ru", "phone": "+70929219815"}
0005434343782	4CCB48	1880 796571	DANIIL ORLOV	{"phone": "+70700459960"}
0005434343726	A27F78	3208 206542	TATYANA VOLKOVA	{"email": "tatyana_volkova06011971@postgrespro.ru", "phone": "+70679005627"}
0005434343727	B68425	1047 528562	VALENTINA BORISOVA	{"phone": "+70585992790"}
0005434343728	AC3CE3	5233 928127	YULIYA ZAKHAROVA	{"email": "zakharova_y061970@postgrespro.ru", "phone": "+70021534774"}
0005434343729	AC3CE3	5254 258015	MARIYA ZOTOVA	{"email": "zotova-mariya08061968@postgrespro.ru", "phone": "+70803943429"}
0005434343730	221CD6	4459 167368	RAFAIL MAKSIMOV	{"phone": "+70640443956"}
0005434343731	348C16	8553 792231	IVAN GUSEV	{"phone": "+70687086100"}
0005434343732	B7032E	8838 989326	ANATOLIY NOVIKOV	{"phone": "+70611188678"}
0005434343733	022649	7732 853579	DMITRIY ALEKSANDROV	{"phone": "+70454979056"}
0005434343734	8DBA16	2381 109374	ALEKSANDR IVANOV	{"email": "ivanov_a06081963@postgrespro.ru", "phone": "+70794277603"}
0005434343735	8DBA16	9604 953912	MARIYA PAVLOVA	{"phone": "+70420329761"}
0005434343736	A9436E	3932 443368	NATALYA ALEKSANDROVA	{"phone": "+70440161605"}
0005434343737	6017C1	0021 378598	GALINA SAVELEVA	{"phone": "+70552428271"}
0005434343738	7D3FAC	8217 585841	SERGEY EGOROV	{"email": "s-egorov111960@postgrespro.ru", "phone": "+70623008411"}
0005434343739	7D3FAC	7092 738366	LIDIYA OSIPOVA	{"phone": "+70386964145"}
0005434343740	D8D778	8634 316870	STEPAN SMIRNOV	{"email": "smirnov_stepan.16101969@postgrespro.ru", "phone": "+70545996407"}
0005434343741	73B7B7	5470 053670	SVETLANA YAKOVLEVA	{"email": "yakovlevas-1965@postgrespro.ru", "phone": "+70596170147"}
0005434343742	C0578C	3643 918337	KONSTANTIN MOISEEV	{"email": "moiseev_k.1978@postgrespro.ru", "phone": "+70430097709"}
0005434343743	73EFC7	1500 077398	MARIYA ZAYCEVA	{"phone": "+70639767662"}
0005434343744	23DAF8	8715 100419	NIKOLAY VOLKOV	{"email": "n_volkov_21011971@postgrespro.ru", "phone": "+70055043658"}
0005434343745	23DAF8	7659 455610	ANDREY VOLKOV	{"email": "volkov-andrey.21091976@postgrespro.ru", "phone": "+70321819499"}
0005434343746	2FF4D9	0501 598860	ELENA KUZNECOVA	{"email": "kuznecova.elena1987@postgrespro.ru", "phone": "+70657493942"}
0005434343747	2FF4D9	6702 800676	MARIYA MIRONOVA	{"phone": "+70039254213"}
0005434343748	95A15C	7876 623439	ANATOLIY PETROV	{"phone": "+70475434828"}
0005434343749	20C87E	3383 975587	NATALYA VASILEVA	{"email": "vasileva-n041979@postgrespro.ru", "phone": "+70803024036"}
0005434343750	D094E0	0523 721023	GALINA TARASOVA	{"phone": "+70731314261"}
0005434343751	23EECC	0957 657862	VALENTINA NIKOLAEVA	{"phone": "+70484682876"}
0005434343752	1F9A9D	3446 692001	POLINA STEPANOVA	{"phone": "+70266279082"}
0005434343753	E94ED0	5006 890572	LYUDMILA VOLKOVA	{"email": "volkova-l1975@postgrespro.ru", "phone": "+70366143672"}
0005434343754	201788	8918 995674	AMINA ZAYCEVA	{"phone": "+70565708494"}
0005434343755	2599D9	9971 179593	ELENA KUZNECOVA	{"email": "kuznecova-e081972@postgrespro.ru", "phone": "+70949604036"}
0005434343756	589702	3232 563472	TATYANA SMIRNOVA	{"phone": "+70675006960"}
0005434343757	013F90	9941 705061	ANATOLIY TIMOFEEV	{"email": "atimofeev-1983@postgrespro.ru", "phone": "+70703294807"}
0005434343758	5CA88E	0704 305925	ALEKSANDR ILIN	{"email": "aleksandr_ilin_1975@postgrespro.ru", "phone": "+70217283957"}
0005434343759	5CA88E	9032 695296	IVAN ROMANOV	{"phone": "+70701294963"}
0005434343760	B6703B	2128 806658	NINA VASILEVA	{"phone": "+70079643940"}
0005434343761	A5D113	3049 420069	DMITRIY ILIN	{"phone": "+70254367327"}
0005434343762	DD8550	6364 247181	VIKTOR SOROKIN	{"email": "sorokin_viktor1977@postgrespro.ru", "phone": "+70342144186"}
0005434343763	7B53DC	7935 323305	EVGENIY KAZAKOV	{"phone": "+70017813608"}
0005434343764	7B53DC	8969 430316	POLINA NIKITINA	{"email": "nikitina_p_111975@postgrespro.ru", "phone": "+70794904101"}
0005434343765	D6EAA7	8574 912323	DMITRIY BONDARENKO	{"email": "dmitriy-bondarenko.08081970@postgrespro.ru", "phone": "+70225665788"}
0005434343766	F75E48	0211 002786	LYUBOV BELOVA	{"email": "belova_lyubov.031975@postgrespro.ru", "phone": "+70101603775"}
0005434343767	F75E48	8674 624527	ALEKSEY MAKSIMOV	{"email": "alekseymaksimov.09011975@postgrespro.ru", "phone": "+70769537455"}
0005434343768	09287C	5826 039799	VALENTINA ZAYCEVA	{"email": "zayceva_valentina-27071977@postgrespro.ru", "phone": "+70447827103"}
0005434343769	29F721	1741 264888	IRINA SIDOROVA	{"phone": "+70395474635"}
0005434343770	877536	5865 565225	OLGA POTAPOVA	{"phone": "+70270902474"}
0005434343771	5C22F2	5859 873341	VLADIMIR SCHERBAKOV	{"phone": "+70171412649"}
0005434343772	030B52	4800 777427	VALENTINA POPOVA	{"phone": "+70601424800"}
0005434343773	030B52	1878 591845	ANDREY FEDOROV	{"phone": "+70741680578"}
0005434343774	E20BF4	2756 496003	DARYA KULIKOVA	{"email": "kulikova.darya.06031964@postgrespro.ru", "phone": "+70228422322"}
0005434343775	C22D95	2785 370497	MIKHAIL KUZNECOV	{"phone": "+70729033674"}
0005434343776	636F1D	9287 071045	LEONID MOROZOV	{"phone": "+70982910779"}
0005434343777	757EA6	3415 414870	MARIYA KOZLOVA	{"email": "mariyakozlova-111988@postgrespro.ru", "phone": "+70531348875"}
0005434343778	E4D6C4	6265 917343	VLADIMIR SIDOROV	{"email": "sidorovvladimir_1979@postgrespro.ru", "phone": "+70266485374"}
0005434343779	A8B0F8	3303 405243	TATYANA LAZAREVA	{"email": "tatyanalazareva-1976@postgrespro.ru", "phone": "+70064958636"}
0005434343780	7DFAA0	1900 064533	ALEKSANDR ABRAMOV	{"email": "aabramov-041968@postgrespro.ru", "phone": "+70326126570"}
0005434343781	4FAF4A	3936 702262	NATALYA LOGINOVA	{"email": "loginova-n-031969@postgrespro.ru", "phone": "+70237109910"}
0005434343783	539DDA	2303 331029	MARIYA ANISIMOVA	{"email": "m-anisimova_021977@postgrespro.ru", "phone": "+70010070070"}
0005434343784	81EB5C	8213 857470	ARTUR POPOV	{"email": "artur-popov13061973@postgrespro.ru", "phone": "+70215621478"}
0005434343785	81EB5C	9692 153497	ALEKSANDR IVANOV	{"phone": "+70920083453"}
0005434343786	F5FA34	3774 090248	IGOR BARANOV	{"phone": "+70188815886"}
0005434343787	DE5776	7271 893203	RUSLAN ISAEV	{"email": "ruslanisaev15091979@postgrespro.ru", "phone": "+70180313564"}
0005434343788	DE5776	5310 499370	ILYA KISELEV	{"email": "kiselev.ilya_121960@postgrespro.ru", "phone": "+70401004331"}
0005434343789	09121A	9526 454408	OLGA MASLOVA	{"email": "o-maslova-081975@postgrespro.ru", "phone": "+70325765141"}
0005434343790	D716D5	7872 579083	VALERIY KUZMIN	{"email": "valeriy-kuzmin-1970@postgrespro.ru", "phone": "+70047937275"}
0005434343791	B1B727	5545 247310	GALINA IVANOVA	{"phone": "+70299517318"}
0005434343792	B1B727	1939 596699	NATALYA BORISOVA	{"email": "borisova.n_121972@postgrespro.ru", "phone": "+70761847449"}
0005434343793	8DD96A	3138 806987	OLGA NESTEROVA	{"phone": "+70571680611"}
0005434343794	8DD96A	3999 513000	SERGEY TIKHONOV	{"email": "tikhonovs1969@postgrespro.ru", "phone": "+70150621550"}
0005434343795	D46044	5285 613504	ANDREY KUZNECOV	{"phone": "+70447645362"}
0005434343796	FFFFF7	3211 278709	NADEZHDA KOLESNIKOVA	{"phone": "+70217860938"}
0005434343797	FFFFF7	7581 746167	OLESYA GRISHINA	{"email": "grishina.olesya.1971@postgrespro.ru", "phone": "+70579826225"}
0005434343798	CF6201	8132 378659	ALEKSEY DMITRIEV	{"email": "alekseydmitriev-1971@postgrespro.ru", "phone": "+70000620385"}
0005434343799	E10D46	2251 915117	VLADIMIR VOROBEV	{"email": "vvorobev061969@postgrespro.ru", "phone": "+70153288537"}
0005434343800	4637C7	9526 978796	VLADIMIR PETROV	{"email": "v-petrov_09031964@postgrespro.ru", "phone": "+70167654345"}
0005434343801	50FB7E	2919 854520	GALINA KUZNECOVA	{"email": "kuznecova_galina-1981@postgrespro.ru", "phone": "+70627697664"}
0005434343802	DF33EA	3773 553376	MARAT FEDOROV	{"phone": "+70602309658"}
0005434343803	DF33EA	9510 806818	ALEKSANDRA MOROZOVA	{"phone": "+70428740246"}
0005434343804	59289D	8703 263318	VIKTORIYA VLASOVA	{"email": "vlasova_viktoriya.081983@postgrespro.ru", "phone": "+70945731741"}
0005434343805	14293C	2857 235338	MIKHAIL GUSEV	{"email": "gusevm091973@postgrespro.ru", "phone": "+70069672137"}
0005434343806	14293C	0502 274044	EVGENIYA KOZLOVA	{"email": "evgeniyakozlova-061968@postgrespro.ru", "phone": "+70670593726"}
0005434343807	3230AA	4074 439723	GALINA BOGDANOVA	{"email": "bogdanova-g1972@postgrespro.ru", "phone": "+70218953242"}
0005434343808	3230AA	8422 147421	VLADIMIR SERGEEV	{"email": "sergeev.vladimir02121959@postgrespro.ru", "phone": "+70678133915"}
0005434343809	C85276	2673 506995	ALEKSANDR ZAKHAROV	{"phone": "+70583520373"}
0005434343810	D222DC	1011 975663	ALEKSANDR GERASIMOV	{"email": "agerasimov121979@postgrespro.ru", "phone": "+70369158490"}
0005434343811	C3DAA2	0714 311062	ANDREY BELOV	{"email": "belov-andrey.101969@postgrespro.ru", "phone": "+70623617882"}
0005434343812	7C6DB7	8311 118068	FARID POPOV	{"email": "popov-farid15021957@postgrespro.ru", "phone": "+70013764318"}
0005434343813	7C6DB7	8731 910137	MARINA TARASOVA	{"email": "tarasovam_1967@postgrespro.ru", "phone": "+70839615654"}
0005434343814	270944	3006 697756	VALERIY KUZNECOV	{"phone": "+70863968788"}
0005434343815	270944	1322 984349	IRINA MOISEEVA	{"email": "moiseeva_i.01101979@postgrespro.ru", "phone": "+70604466953"}
0005434343816	FA9B26	4451 469398	ROMAN ALEKSEEV	{"phone": "+70517555145"}
0005434343817	FA9B26	2416 349660	NIKOLAY TIMOFEEV	{"email": "ntimofeev.081974@postgrespro.ru", "phone": "+70043228883"}
0005434343818	7FE0AD	4406 033816	ALEKSANDR NIKOLAEV	{"phone": "+70499737906"}
0005434343819	14030F	4593 391074	KARINA KOZLOVA	{"email": "k.kozlova26081975@postgrespro.ru", "phone": "+70355839334"}
0005434343820	14030F	3408 640933	SERGEY TARASOV	{"phone": "+70896253945"}
0005434343821	CAF3E1	4760 723884	NINA MASLOVA	{"phone": "+70703912117"}
0005434343822	15B25F	1049 638872	VALENTINA OSIPOVA	{"email": "osipova-v101967@postgrespro.ru", "phone": "+70655067737"}
0005434343823	F9FA53	4772 330672	ELIZAVETA GUSEVA	{"phone": "+70184854477"}
0005434343824	34F0FC	8383 821282	ROZALIYA SMIRNOVA	{"phone": "+70792748762"}
0005434343825	16B232	4634 126651	NATALYA SOKOLOVA	{"email": "sokolova.n_091967@postgrespro.ru", "phone": "+70682138792"}
0005434343826	1CC9B8	8072 909166	ALEKSEY NAUMOV	{"email": "aleksey-naumov.121961@postgrespro.ru", "phone": "+70634909323"}
0005434343827	8B86C9	0413 443070	IRINA POPOVA	{"email": "i-popova.22021967@postgrespro.ru", "phone": "+70391239440"}
0005434343828	8B86C9	5264 838777	IRINA NIKIFOROVA	{"phone": "+70033061230"}
0005434343829	473D4F	8008 724021	EKATERINA CHERNOVA	{"phone": "+70535509659"}
0005434343830	473D4F	2240 633555	VALENTINA MELNIKOVA	{"email": "melnikova-v11061983@postgrespro.ru", "phone": "+70679880608"}
0005434343831	B459C3	9387 997857	MIKHAIL MELNIKOV	{"email": "mikhail-melnikov_021981@postgrespro.ru", "phone": "+70873084891"}
0005434343832	355A31	7750 174120	ELENA KOZLOVA	{"email": "elena-kozlova.31081963@postgrespro.ru", "phone": "+70955795154"}
0005434343833	2A0B29	9427 400324	ALEKSANDR FROLOV	{"email": "frolov.aleksandr_1977@postgrespro.ru", "phone": "+70467789092"}
0005434343834	2A0B29	1497 820874	TATYANA CHERNOVA	{"phone": "+70049078656"}
0005434343835	6E419A	6216 185853	DENIS DENISOV	{"email": "denisov.denis1967@postgrespro.ru", "phone": "+70195028924"}
0005434343836	6E419A	7154 449318	PAVEL MOISEEV	{"email": "moiseev-pavel18081977@postgrespro.ru", "phone": "+70198509547"}
0005434343837	6E419A	5577 562943	DMITRIY SCHERBAKOV	{"phone": "+70948326715"}
0005434343838	F0C6D2	3927 010021	SVETLANA POLYAKOVA	{"email": "polyakova.svetlana1975@postgrespro.ru", "phone": "+70966755644"}
0005434343839	26B94B	2047 299603	KLAVDIYA CHERNOVA	{"email": "chernovaklavdiya1972@postgrespro.ru", "phone": "+70246276373"}
0005434343840	98FD24	1112 483852	ALEKSANDR DENISOV	{"phone": "+70099310243"}
0005434343841	1DD6F2	2297 117125	NIKOLAY RODIONOV	{"phone": "+70541242090"}
0005434343842	4E1F39	4152 348791	IVAN KAZAKOV	{"phone": "+70525581919"}
0005434343843	BD04B8	8989 349149	LYUDMILA KAZAKOVA	{"phone": "+70406840957"}
0005434343844	BD04B8	8175 287008	ANATOLIY KUZMIN	{"email": "a-kuzmin.101964@postgrespro.ru", "phone": "+70059559282"}
0005434343845	E8EC07	8796 468892	DMITRIY KRASNOV	{"phone": "+70051148640"}
0005434343846	E8EC07	4009 581092	VITALIY IVANOV	{"phone": "+70881792096"}
0005434343847	B808EB	4402 238558	IVAN MIKHAYLOV	{"phone": "+70668248786"}
0005434343848	222BFD	1200 935144	EVGENIY KUDRYASHOV	{"email": "e_kudryashov-081967@postgrespro.ru", "phone": "+70056049351"}
0005434343849	222BFD	3826 663220	SERGEY IVANOV	{"phone": "+70131937947"}
0005434343850	EDE4E8	9370 776471	ANASTASIYA CHERNOVA	{"phone": "+70022293366"}
0005434343851	356922	2206 990028	MIKHAIL MOROZOV	{"email": "morozov.m-1961@postgrespro.ru", "phone": "+70269008509"}
0005434343852	356922	3661 596959	ALEKSANDR KUZNECOV	{"email": "a.kuznecov.051966@postgrespro.ru", "phone": "+70024398600"}
0005434343853	C0D645	9924 631879	NINA ANISIMOVA	{"email": "anisimovanina_1976@postgrespro.ru", "phone": "+70450883884"}
0005434343854	C0D645	8950 061439	TATYANA KOROLEVA	{"email": "tatyana.koroleva-26041976@postgrespro.ru", "phone": "+70217430231"}
0005434343855	290093	7583 595450	ANGELINA EFREMOVA	{"email": "a_efremova-101973@postgrespro.ru", "phone": "+70167190724"}
0005434343856	3A94A5	3749 086131	SEMEN VOROBEV	{"email": "s.vorobev031963@postgrespro.ru", "phone": "+70910236310"}
0005434343857	96F0D1	7609 583403	ELENA KOLESNIKOVA	{"email": "kolesnikova.e.31031977@postgrespro.ru", "phone": "+70856735434"}
0005434343858	96F0D1	7461 428083	MARINA SERGEEVA	{"phone": "+70317132232"}
0005434343859	96F0D1	9065 558800	SVETLANA PETROVA	{"phone": "+70426260994"}
0005434343860	0D6434	9148 754693	OLGA IVANOVA	{"email": "ivanova.o-1976@postgrespro.ru", "phone": "+70990876368"}
0005434343861	0D6434	9477 118429	ROMAN TARASOV	{"phone": "+70570863367"}
0005434343862	535F6D	0806 057111	MAKSIM ILIN	{"email": "maksim.ilin_26121970@postgrespro.ru", "phone": "+70072714240"}
0005434343863	F36605	6083 472672	OLGA MIKHAYLOVA	{"email": "mikhaylova-o_1968@postgrespro.ru", "phone": "+70521035080"}
0005434343864	F36605	6556 355554	SERGEY NIKITIN	{"phone": "+70939080954"}
0005434343865	9D905C	6891 665212	DMITRIY MAKAROV	{"phone": "+70028883975"}
0005434343866	738365	2158 100728	GEORGIY ABRAMOV	{"email": "georgiy-abramov.111974@postgrespro.ru", "phone": "+70934456651"}
0005434343867	6A8E3C	6965 163358	VALENTINA OSIPOVA	{"phone": "+70181828445"}
0005434343868	6A8E3C	1239 961539	ARTEM VASILEV	{"email": "avasilev_091965@postgrespro.ru", "phone": "+70070379459"}
0005434343869	6A8E3C	4316 364483	MARK KULIKOV	{"email": "m.kulikov22031972@postgrespro.ru", "phone": "+70021183886"}
0005434343870	EC76A6	5382 553799	VALENTINA CHERNOVA	{"phone": "+70438712178"}
0005434343871	EC76A6	6732 323482	IVAN STEPANOV	{"email": "stepanov_i-091981@postgrespro.ru", "phone": "+70000240619"}
0005434343872	FBCCC2	2578 190538	IVAN ROMANOV	{"phone": "+70316099754"}
0005434343873	FBCCC2	3415 031562	ALEKSANDR FILIPPOV	{"phone": "+70005718175"}
0005434343874	4C4BE0	4611 400718	ANASTASIYA ANTONOVA	{"email": "aantonova_14031969@postgrespro.ru", "phone": "+70690792351"}
0005434343875	F15BB5	6747 308077	SERGEY AFANASEV	{"phone": "+70726424400"}
0005434343876	06D8B4	4294 421257	LYUBOV SAVELEVA	{"phone": "+70380145139"}
0005434343877	B78B91	4525 607501	ANATOLIY SIDOROV	{"phone": "+70855244907"}
0005434343878	4EF4DC	6535 153635	NAZIYA KOMAROVA	{"phone": "+70477290376"}
0005434343879	CD790B	1661 960260	ALEKSEY NIKOLAEV	{"email": "a-nikolaev071970@postgrespro.ru", "phone": "+70521292980"}
0005434343880	CD790B	6740 125846	NIKITA SMIRNOV	{"email": "smirnov.nikita-1975@postgrespro.ru", "phone": "+70114624670"}
0005434343881	B3DF5D	6220 271897	NATALYA MIRONOVA	{"email": "natalya-mironova.05031964@postgrespro.ru", "phone": "+70102930731"}
0005434343882	B3DF5D	7561 949149	ALEKSANDR MAKSIMOV	{"phone": "+70271035725"}
0005434343883	F4B45F	5853 370145	NATALYA KOZLOVA	{"email": "natalya-kozlova-18051971@postgrespro.ru", "phone": "+70000489476"}
0005434343884	EBCCB1	1336 886841	NIKOLAY SHEVCHENKO	{"email": "nikolay-shevchenko011973@postgrespro.ru", "phone": "+70592557640"}
0005434343885	B27404	8549 998389	GALINA DAVYDOVA	{"phone": "+70182100054"}
0005434343886	B27404	5612 867837	FEDOR MELNIKOV	{"email": "f.melnikov071969@postgrespro.ru", "phone": "+70363800983"}
0005434343887	2EDA43	7569 504054	OLEG VLASOV	{"phone": "+70014643096"}
0005434343888	D450F5	7683 223377	DENIS KUZMIN	{"email": "denis-kuzmin121973@postgrespro.ru", "phone": "+70752431517"}
0005434343889	D450F5	5911 951498	TAMARA VLASOVA	{"email": "tamara-vlasova_1976@postgrespro.ru", "phone": "+70402771413"}
0005434343890	537551	9455 291982	MAKSIM MOROZOV	{"phone": "+70521161774"}
0005434343891	C600E0	0934 945564	MILANA NOVIKOVA	{"phone": "+70619712704"}
0005434343892	0E43F5	2755 216010	ALEKSANDR KRASNOV	{"email": "a-krasnov-011967@postgrespro.ru", "phone": "+70146989797"}
0005434343893	0E43F5	8402 878580	TAMARA KULIKOVA	{"email": "kulikova-t.27031979@postgrespro.ru", "phone": "+70758297904"}
0005434343894	0E43F5	6150 372706	DMITRIY POPOV	{"phone": "+70097693451"}
0005434343895	C8DDA1	3882 854508	SERGEY FROLOV	{"email": "sergey.frolov_111983@postgrespro.ru", "phone": "+70022148964"}
0005434343896	73D5B6	5454 461722	VASILIY KUZNECOV	{"email": "kuznecov_vasiliy.1972@postgrespro.ru", "phone": "+70080377747"}
0005434343897	0477F2	4515 107453	IGOR FOMIN	{"email": "igor-fomin22051973@postgrespro.ru", "phone": "+70393773189"}
0005434343898	B660F9	9540 629974	ALEKSANDR SOKOLOV	{"email": "sokolov_a.031981@postgrespro.ru", "phone": "+70604591301"}
0005434343899	B78286	6377 168688	DMITRIY KONOVALOV	{"phone": "+70719974862"}
0005434343900	B78286	1952 632990	VIKTOR EGOROV	{"phone": "+70064849726"}
0005434343901	B78286	4432 216834	NIKOLAY MAKAROV	{"email": "makarov-nikolay09051971@postgrespro.ru", "phone": "+70651804268"}
0005434343902	B08F85	8824 770266	ALEKSANDR TARASOV	{"email": "tarasov_a_021979@postgrespro.ru", "phone": "+70977608543"}
0005434343903	106766	4974 486547	LYUDMILA MEDVEDEVA	{"phone": "+70470107082"}
0005434343904	E1F753	4942 928494	NIKOLAY STEPANOV	{"email": "n_stepanov.1973@postgrespro.ru", "phone": "+70335732368"}
0005434343905	A1A6A3	5146 590378	DMITRIY PETROV	{"phone": "+70293118073"}
0005434343906	BD08C3	9882 981837	PAVEL NOVIKOV	{"phone": "+70070781220"}
0005434343907	9635EC	1479 234435	KLAVDIYA SOLOVEVA	{"phone": "+70900038120"}
0005434343908	9635EC	3168 291639	YURIY KUDRYASHOV	{"phone": "+70777631929"}
0005434343909	436717	4576 959406	TAISIYA KONOVALOVA	{"email": "t_konovalova_061968@postgrespro.ru", "phone": "+70971660077"}
0005434343910	436717	0764 374011	SERGEY KUZMIN	{"phone": "+70486745509"}
0005434343911	C418A6	6490 846569	EVGENIY SMIRNOV	{"email": "smirnov-evgeniy.021961@postgrespro.ru", "phone": "+70689090638"}
0005434343912	44B370	1400 680775	MARIYA SERGEEVA	{"email": "m_sergeeva061957@postgrespro.ru", "phone": "+70002682488"}
0005434343913	44B370	5462 313838	IVAN FROLOV	{"phone": "+70660997546"}
0005434343914	F31E8B	5585 478570	DANIL NOVIKOV	{"email": "novikov.danil.111975@postgrespro.ru", "phone": "+70217022522"}
0005434343915	E681F0	4419 593121	KLAVDIYA VOLKOVA	{"email": "volkova-k_1966@postgrespro.ru", "phone": "+70497662726"}
0005434343916	3AC043	5551 986667	MAKSIM VASILEV	{"phone": "+70425595679"}
0005434343917	2E1DE4	0783 185098	VLADIMIR GORBUNOV	{"phone": "+70117753664"}
0005434343918	63BA41	7312 291219	TATYANA RYABOVA	{"phone": "+70812087171"}
0005434343919	63BA41	5818 877264	YULIYA SOROKINA	{"email": "yuliyasorokina1968@postgrespro.ru", "phone": "+70839422039"}
0005434343920	DD398A	3271 984749	NATALYA KALININA	{"email": "kalinina.natalya_121963@postgrespro.ru", "phone": "+70714442199"}
0005434343921	8DCB93	9749 431210	OLGA KALININA	{"phone": "+70846851819"}
0005434343922	8DCB93	5092 185420	ANASTASIYA ABRAMOVA	{"email": "aabramova071967@postgrespro.ru", "phone": "+70152772599"}
0005434343923	8DCB93	0038 020199	ANDREY KAZAKOV	{"phone": "+70761251000"}
0005434343924	5CCF00	7343 874806	ANTONINA AFANASEVA	{"phone": "+70535199066"}
0005434343925	941AD5	4797 035661	VLADIMIR NOVIKOV	{"phone": "+70786379653"}
0005434343926	D13288	4340 972911	ZINAIDA KULIKOVA	{"phone": "+70101345862"}
0005434343927	337AE7	6882 200243	NATALYA NIKOLAEVA	{"phone": "+70525060216"}
0005434343928	12F6C6	4488 617051	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov_03031976@postgrespro.ru", "phone": "+70137845768"}
0005434343929	9320CA	7688 700768	VALENTINA ALEKSANDROVA	{"email": "valeksandrova-111970@postgrespro.ru", "phone": "+70012836449"}
0005434343930	210813	2762 587271	VLADIMIR FEDOROV	{"phone": "+70375659681"}
0005434343931	210813	7356 492306	ALFIYA RODIONOVA	{"email": "rodionova.alfiya1971@postgrespro.ru", "phone": "+70297928133"}
0005434343932	213FF7	0056 545124	VLADIMIR GERASIMOV	{"email": "vgerasimov-1983@postgrespro.ru", "phone": "+70923001997"}
0005434343933	11DA83	1399 304646	ALEKSEY STEPANOV	{"phone": "+70754396828"}
0005434343934	FF29C0	3040 179740	OLGA ILINA	{"phone": "+70258291308"}
0005434343935	FF29C0	4704 810718	VIKTOR STEPANOV	{"phone": "+70540870258"}
0005434343936	1F1A8E	4140 215918	LYUBOV IVANOVA	{"email": "lyubov_ivanova121969@postgrespro.ru", "phone": "+70071097853"}
0005434343937	1F1A8E	6007 993086	VYACHESLAV SOKOLOV	{"email": "v-sokolov-061966@postgrespro.ru", "phone": "+70118128835"}
0005434343938	82E1D3	5691 012403	ALEKSANDR BELOV	{"email": "belov-aleksandr031972@postgrespro.ru", "phone": "+70599933155"}
0005434343939	E6F5E9	5867 974195	IRINA FOMINA	{"phone": "+70439764919"}
0005434343940	54CC9A	5504 791586	IVAN KUZNECOV	{"phone": "+70798737071"}
0005434343941	D553CD	8519 491629	NADEZHDA MALYSHEVA	{"phone": "+70953496802"}
0005434343942	D553CD	9516 248677	GALINA IVANOVA	{"phone": "+70660426004"}
0005434343943	0CE220	8142 286636	VYACHESLAV FEDOTOV	{"email": "fedotov_v.28051969@postgrespro.ru", "phone": "+70848472278"}
0005434343944	1738EC	5226 466190	NATALYA PETROVA	{"email": "petrovan_1981@postgrespro.ru", "phone": "+70491012542"}
0005434343945	632122	0708 822515	EVGENIY AFANASEV	{"email": "afanasev_evgeniy.071985@postgrespro.ru", "phone": "+70003815713"}
0005434343946	619321	3829 694988	ANTONINA MEDVEDEVA	{"phone": "+70177087077"}
0005434343947	813C4C	7690 339735	ANTON VASILEV	{"phone": "+70357256690"}
0005434343948	F4851F	8627 331487	LIDIYA DENISOVA	{"email": "ldenisova_20091980@postgrespro.ru", "phone": "+70806943858"}
0005434343949	DE6034	3370 562484	OLGA NESTEROVA	{"phone": "+70724420548"}
0005434344285	2907A4	4423 207309	NIKOLAY GAVRILOV	{"phone": "+70947553825"}
0005434343950	063A48	2843 932145	EKATERINA IVANOVA	{"email": "ivanova.e-29071971@postgrespro.ru", "phone": "+70386544402"}
0005434343951	9BAD1C	2161 024983	PETR MIRONOV	{"phone": "+70846116603"}
0005434343952	9BAD1C	7508 550152	MIKHAIL YAKOVLEV	{"email": "yakovlevmikhail.01061969@postgrespro.ru", "phone": "+70225901347"}
0005434343953	6DBA6A	4040 641264	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr-04091972@postgrespro.ru", "phone": "+70823717181"}
0005434343954	555F40	0752 492031	DANIL VLASOV	{"email": "vlasov-danil.09111976@postgrespro.ru", "phone": "+70767718010"}
0005434343955	033B29	6365 079135	LYUDMILA MIKHAYLOVA	{"email": "lyudmila-mikhaylova.071966@postgrespro.ru", "phone": "+70566982446"}
0005434343956	033B29	3262 852084	DARYA EGOROVA	{"email": "darya_egorova1973@postgrespro.ru", "phone": "+70073262854"}
0005434343957	3475A1	0459 143772	GALINA IVANOVA	{"phone": "+70972547340"}
0005434343958	A44633	6279 361220	ALEKSANDR NOVIKOV	{"email": "aleksandr_novikov1963@postgrespro.ru", "phone": "+70038224184"}
0005434343959	D6A6E4	7716 201523	EVGENIY MEDVEDEV	{"email": "evgeniy-medvedev-051974@postgrespro.ru", "phone": "+70238328439"}
0005434343960	B3397B	1602 438317	VERA NIKITINA	{"email": "nikitinavera091975@postgrespro.ru", "phone": "+70804396294"}
0005434343961	F29FB0	3917 471533	NATALYA KOROLEVA	{"email": "koroleva.natalya_1972@postgrespro.ru", "phone": "+70226296936"}
0005434343962	EF1D57	6339 109531	RIMMA LAZAREVA	{"phone": "+70948695163"}
0005434343963	EF1D57	3988 071187	IRINA SEMENOVA	{"phone": "+70046499054"}
0005434343964	FE0059	4850 893115	NATALIYA ANDREEVA	{"email": "andreeva_n_071974@postgrespro.ru", "phone": "+70681105001"}
0005434343965	FE0059	3945 014976	TAMARA KALININA	{"phone": "+70755086950"}
0005434343966	7B1668	4300 389106	DMITRIY VLASOV	{"phone": "+70293628743"}
0005434343967	AABFDA	4778 623478	NIKOLAY IVANOV	{"phone": "+70173837795"}
0005434343968	E7249A	0524 698997	EKATERINA DENISOVA	{"email": "ekaterina-denisova-111966@postgrespro.ru", "phone": "+70302551774"}
0005434343969	98C24E	8009 008415	ALEKSANDR ANDREEV	{"phone": "+70370954708"}
0005434343970	C6D9A5	0732 790622	OKSANA SEMENOVA	{"phone": "+70512983637"}
0005434343971	F5FDA2	6927 658437	IRINA KOZLOVA	{"phone": "+70328949473"}
0005434343972	7B4C3B	4377 898476	AMINA KRASNOVA	{"phone": "+70128136009"}
0005434343973	983BB0	3661 920952	IVAN ROMANOV	{"email": "romanov-ivan_24121964@postgrespro.ru", "phone": "+70125007360"}
0005434343974	983BB0	1884 111145	DMITRIY VLASOV	{"phone": "+70089092144"}
0005434343975	D385C4	1903 138229	STEPAN VLASOV	{"phone": "+70316765197"}
0005434343976	38EC6C	1562 509454	KIRILL MATVEEV	{"phone": "+70725933167"}
0005434344088	60BC59	1683 297306	OLGA EFIMOVA	{"phone": "+70918568005"}
0005434343977	ADDC84	7262 123317	IVAN PAVLOV	{"email": "pavlovivan10101979@postgrespro.ru", "phone": "+70935006355"}
0005434343978	887797	0966 182098	ZINAIDA ZAKHAROVA	{"email": "zakharova-zinaida_021970@postgrespro.ru", "phone": "+70579308790"}
0005434343979	6BA2F6	8058 148660	VYACHESLAV KRASNOV	{"email": "vyacheslav.krasnov1959@postgrespro.ru", "phone": "+70422364138"}
0005434343980	567D3C	3320 812481	VALERIY OSIPOV	{"phone": "+70719482392"}
0005434343981	567D3C	4137 054286	KARINA NAZAROVA	{"email": "nazarova_k-1976@postgrespro.ru", "phone": "+70445561590"}
0005434343982	9C54A7	4401 481531	LYUDMILA BARANOVA	{"phone": "+70604523916"}
0005434343983	9C54A7	0997 936767	VLADISLAV NAUMOV	{"email": "naumov-vladislav.1981@postgrespro.ru", "phone": "+70905682948"}
0005434343984	6552AD	2231 964175	VADIM GUSEV	{"email": "gusev.v-081964@postgrespro.ru", "phone": "+70545814619"}
0005434343985	79ECBE	4500 355192	KSENIYA MAKAROVA	{"phone": "+70250853520"}
0005434343986	79ECBE	4063 052507	OLGA MEDVEDEVA	{"phone": "+70777643432"}
0005434343987	79ECBE	1245 278424	SERGEY VOLKOV	{"phone": "+70568855047"}
0005434343988	21D269	6798 720295	YULIYA ALEKSEEVA	{"phone": "+70744155268"}
0005434343989	62A16C	5982 835843	MIKHAIL NIKITIN	{"phone": "+70567416962"}
0005434343990	62A16C	8676 547176	VALENTINA MELNIKOVA	{"phone": "+70388661064"}
0005434343991	AFE301	7625 450650	NIKOLAY ZAKHAROV	{"email": "nikolay.zakharov-121974@postgrespro.ru", "phone": "+70714999004"}
0005434343992	AFE301	9446 892290	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev.18111968@postgrespro.ru", "phone": "+70330014971"}
0005434343993	AFE301	2231 368445	ALEKSANDR SEMENOV	{"email": "semenovaleksandr04041975@postgrespro.ru", "phone": "+70196929362"}
0005434343994	685883	2943 272860	SERGEY ALEKSEEV	{"phone": "+70336477805"}
0005434343995	685883	9892 764622	ARSEN MAKSIMOV	{"email": "a_maksimov041978@postgrespro.ru", "phone": "+70542106326"}
0005434343996	EE2F5B	2486 596258	ANDREY NIKITIN	{"email": "andrey.nikitin_31011967@postgrespro.ru", "phone": "+70644514441"}
0005434343997	53E411	6165 857890	IVAN OSIPOV	{"email": "osipov-i-17121975@postgrespro.ru", "phone": "+70869579097"}
0005434343998	A8995F	6362 544325	ARMEN FOMIN	{"phone": "+70296625031"}
0005434343999	76BBAE	7977 970808	OLGA TIKHONOVA	{"email": "tikhonova-olga_111977@postgrespro.ru", "phone": "+70395084006"}
0005434344000	76BBAE	1367 452460	VASILIY KISELEV	{"phone": "+70125247607"}
0005434344001	309C4F	6230 918985	OLGA POPOVA	{"phone": "+70316789865"}
0005434344002	406F9D	3848 427116	NADEZHDA VOLKOVA	{"email": "volkovanadezhda011963@postgrespro.ru", "phone": "+70857081106"}
0005434344003	406F9D	0944 710834	ALEKSEY NAUMOV	{"email": "naumov.aleksey111972@postgrespro.ru", "phone": "+70273787248"}
0005434344004	F41798	9536 989152	DMITRIY KRASNOV	{"email": "dmitriy_krasnov1969@postgrespro.ru", "phone": "+70348903516"}
0005434344005	F41798	1448 554086	VASILIY ZHURAVLEV	{"email": "vasiliy_zhuravlev.1969@postgrespro.ru", "phone": "+70525104572"}
0005434344006	DAD2FF	6437 808141	VENIAMIN NIKOLAEV	{"email": "veniaminnikolaev_1970@postgrespro.ru", "phone": "+70853826139"}
0005434344007	E61753	7963 258773	VIKTOR GORBUNOV	{"phone": "+70110239815"}
0005434344008	E61753	4573 261539	ALEKSANDRA GERASIMOVA	{"phone": "+70703713007"}
0005434344009	442B35	8616 295227	SERGEY KUZNECOV	{"phone": "+70158024882"}
0005434344010	428ECE	2395 229953	YURIY MARTYNOV	{"email": "ymartynov.17011964@postgrespro.ru", "phone": "+70180674572"}
0005434344011	ED8556	2211 860345	LARISA ARKHIPOVA	{"email": "arkhipova_larisa_18051969@postgrespro.ru", "phone": "+70051546858"}
0005434344012	82FF74	5096 191108	ANDREY DENISOV	{"email": "denisov_a091984@postgrespro.ru", "phone": "+70957548828"}
0005434344013	A86D2E	6344 021460	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov.1983@postgrespro.ru", "phone": "+70001246464"}
0005434344014	B77202	2093 817821	ANNA TITOVA	{"phone": "+70830328907"}
0005434344015	A1CAE8	5671 661704	NINA PAVLOVA	{"email": "n_pavlova041964@postgrespro.ru", "phone": "+70813065737"}
0005434344016	057C3C	5895 131389	DANIIL ZAYCEV	{"email": "zaycevd-27011982@postgrespro.ru", "phone": "+70051852621"}
0005434344017	057C3C	4911 538196	GALINA NESTEROVA	{"email": "galinanesterova-20021968@postgrespro.ru", "phone": "+70974295605"}
0005434344018	212A8C	3010 359006	TATYANA POLYAKOVA	{"email": "polyakova.t1976@postgrespro.ru", "phone": "+70760467469"}
0005434344019	612F37	8798 433603	LARISA NESTEROVA	{"email": "nesterova.l-071959@postgrespro.ru", "phone": "+70553173099"}
0005434344020	5BA57A	8827 105194	IRINA MOROZOVA	{"phone": "+70356305369"}
0005434344021	0D99A6	3058 783365	SERGEY ALEKSANDROV	{"email": "s_aleksandrov.27111963@postgrespro.ru", "phone": "+70608683584"}
0005434344022	D21E00	2979 894426	NIKOLAY ANDREEV	{"phone": "+70549847436"}
0005434344023	AF1B0F	6370 610943	ELENA KOROLEVA	{"phone": "+70697282800"}
0005434344024	A99ABF	6623 727715	ASIYA IVANOVA	{"email": "a_ivanova-111966@postgrespro.ru", "phone": "+70876460089"}
0005434344025	AC5E1D	4408 464748	DMITRIY SAVELEV	{"phone": "+70186369900"}
0005434344026	7C08A0	9849 315741	NADEZHDA ANDREEVA	{"email": "andreevanadezhda10081968@postgrespro.ru", "phone": "+70861486105"}
0005434344027	7C08A0	6270 125870	OLEG FEDOTOV	{"email": "o-fedotov_101970@postgrespro.ru", "phone": "+70938774531"}
0005434344028	7C08A0	2904 113044	MIKHAIL IVANOV	{"email": "mikhail.ivanov1954@postgrespro.ru", "phone": "+70944405388"}
0005434344029	7585B6	3978 474952	ANDREY SIDOROV	{"email": "sidorov_a_1985@postgrespro.ru", "phone": "+70845278468"}
0005434344030	216D06	5714 934020	VALERIY VLASOV	{"phone": "+70643164070"}
0005434344031	AE0348	6199 505316	MIKHAIL FEDOTOV	{"email": "fedotov.mikhail-051977@postgrespro.ru", "phone": "+70982722256"}
0005434344032	BC1594	2072 294972	ZAKHAR SERGEEV	{"email": "z.sergeev28081974@postgrespro.ru", "phone": "+70971597450"}
0005434344033	BC1594	8478 929195	SERGEY TIKHONOV	{"email": "sergeytikhonov-041975@postgrespro.ru", "phone": "+70804400018"}
0005434344034	A91F92	6573 524304	RISHAT SOKOLOV	{"email": "sokolov.rishat.1961@postgrespro.ru", "phone": "+70319937293"}
0005434344035	A91F92	1702 766727	DMITRIY ANDREEV	{"email": "andreev_dmitriy26051967@postgrespro.ru", "phone": "+70914433600"}
0005434344036	A91F92	5677 256921	EKATERINA CHERNOVA	{"email": "chernova_e-28021969@postgrespro.ru", "phone": "+70598255129"}
0005434344037	7A0889	0138 314105	LYUDMILA ANTONOVA	{"phone": "+70413301209"}
0005434344038	B119B7	4033 178133	VALENTINA ZAYCEVA	{"phone": "+70613485930"}
0005434344039	B119B7	8711 683984	NATALYA PETROVA	{"phone": "+70010027045"}
0005434344040	CC82BA	9879 052545	VIKTOR BORISOV	{"email": "v-borisov1960@postgrespro.ru", "phone": "+70039344557"}
0005434344041	75A044	3250 653735	VYACHESLAV GORBUNOV	{"email": "gorbunov-vyacheslav_15011976@postgrespro.ru", "phone": "+70400521619"}
0005434344042	1E548C	0244 081764	KSENIYA BELYAEVA	{"email": "k.belyaeva-07071965@postgrespro.ru", "phone": "+70092178581"}
0005434344043	9DF8B4	8377 777207	ANTONINA KOZLOVA	{"phone": "+70456185444"}
0005434344044	9DF8B4	6795 724436	YURIY ZHUKOV	{"email": "yzhukov101966@postgrespro.ru", "phone": "+70281186031"}
0005434344045	4A63FB	1446 658226	VALENTINA SERGEEVA	{"phone": "+70491746718"}
0005434344046	320391	8939 219723	NATALYA MAKAROVA	{"email": "makarova-natalya.1971@postgrespro.ru", "phone": "+70284266362"}
0005434344047	86CDC5	3827 969081	TATYANA NOVIKOVA	{"phone": "+70313981764"}
0005434344048	CEF959	8121 550931	ALEKSANDR MOISEEV	{"phone": "+70669569878"}
0005434344049	1454BD	1258 198948	POLINA ILINA	{"phone": "+70961746106"}
0005434344050	7C2DCE	5988 349797	OLGA BARANOVA	{"email": "baranovaolga-1965@postgrespro.ru", "phone": "+70961306256"}
0005434344051	18ABD4	7058 508526	ARTUR KONOVALOV	{"email": "konovalov_artur.101970@postgrespro.ru", "phone": "+70053084531"}
0005434344052	FF9BB1	8031 723203	YURIY SMIRNOV	{"phone": "+70124373829"}
0005434344053	B63DCC	9734 361827	RUSLAN ABRAMOV	{"phone": "+70543738182"}
0005434344054	193982	3956 838248	ALEKSANDR KUZNECOV	{"email": "kuznecova_11071970@postgrespro.ru", "phone": "+70200916286"}
0005434344055	A3AC8B	0904 294315	LYUBOV KUZMINA	{"phone": "+70329073356"}
0005434344056	A3AC8B	5605 997984	PAVEL MELNIKOV	{"phone": "+70604936697"}
0005434344057	2C59ED	1776 615039	ALENA MASLOVA	{"phone": "+70730455899"}
0005434344058	2C59ED	6906 812503	SEMEN DMITRIEV	{"email": "s.dmitriev-26051976@postgrespro.ru", "phone": "+70541505381"}
0005434344059	C68350	3295 222049	NATALYA NESTEROVA	{"email": "natalya-nesterova_011979@postgrespro.ru", "phone": "+70160962123"}
0005434344060	F90B33	6722 580284	LYUBOV NAZAROVA	{"email": "nazarova-lyubov-1980@postgrespro.ru", "phone": "+70889078571"}
0005434344061	F8301C	6833 244611	ANATOLIY MIKHAYLOV	{"email": "mikhaylov.anatoliy_1981@postgrespro.ru", "phone": "+70915666836"}
0005434344062	F8F5BC	3691 904279	ANATOLIY SERGEEV	{"email": "anatoliy_sergeev.081969@postgrespro.ru", "phone": "+70687502254"}
0005434344063	1600E2	6260 111238	ALEKSANDR BORISOV	{"phone": "+70371637981"}
0005434344064	632D64	4255 428400	ANATOLIY TIMOFEEV	{"phone": "+70853544845"}
0005434344065	632D64	9702 716002	DARYA KOZLOVA	{"phone": "+70577574237"}
0005434344066	ED5D34	3225 306298	VALENTIN IVANOV	{"phone": "+70998794677"}
0005434344067	81C20E	9398 833960	MATVEY SEMENOV	{"phone": "+70031063706"}
0005434344068	6EA4E0	6077 005483	RAUF PETROV	{"phone": "+70499725520"}
0005434344069	C4878E	2938 300552	RAFAIL ZAYCEV	{"phone": "+70260723746"}
0005434344070	350C50	3602 454834	NADEZHDA NOVIKOVA	{"phone": "+70457412176"}
0005434344071	7F8D52	3731 202042	OLGA SAVELEVA	{"email": "o_saveleva-16061977@postgrespro.ru", "phone": "+70227499474"}
0005434344072	36FA89	6355 000328	NIKOLAY SOROKIN	{"phone": "+70768841421"}
0005434344073	B48FF2	3350 925559	GALINA PETROVA	{"phone": "+70684735673"}
0005434344074	6272F9	8542 545544	ROZA SAVELEVA	{"email": "saveleva_r071962@postgrespro.ru", "phone": "+70713338567"}
0005434344075	6272F9	1771 799503	MARIYA FROLOVA	{"email": "mariya-frolova-27071971@postgrespro.ru", "phone": "+70748656777"}
0005434344076	6272F9	4880 760720	VALERIY MEDVEDEV	{"phone": "+70900944897"}
0005434344077	45DEBA	8117 531338	VITALIY BARANOV	{"phone": "+70092003449"}
0005434344078	45DEBA	5627 115666	ALEKSEY ALEKSANDROV	{"email": "aleksandrov-aleksey22011966@postgrespro.ru", "phone": "+70157979270"}
0005434344079	949697	9475 415338	ANNA KUZMINA	{"phone": "+70320597832"}
0005434344080	FF3670	4761 042925	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr-30081977@postgrespro.ru", "phone": "+70966283855"}
0005434344081	FF3670	2432 742094	SOFYA MEDVEDEVA	{"phone": "+70549699238"}
0005434344082	6C467E	7120 387591	ALEKSANDR CHERNOV	{"phone": "+70700574646"}
0005434344083	6C467E	0008 328771	ALEKSANDR DMITRIEV	{"email": "a_dmitriev101982@postgrespro.ru", "phone": "+70422254421"}
0005434344084	60C572	0443 735112	TIMUR IVANOV	{"email": "ivanovtimur04021977@postgrespro.ru", "phone": "+70180155700"}
0005434344085	D14A1F	8932 572636	GALINA STEPANOVA	{"phone": "+70570636498"}
0005434344086	59F469	0722 460790	KRISTINA ZAKHAROVA	{"email": "zakharovak081966@postgrespro.ru", "phone": "+70769485064"}
0005434344087	03604F	3936 620915	ANDREY ZAKHAROV	{"phone": "+70552464570"}
0005434344089	60BC59	5847 202943	NIKOLAY SEMENOV	{"email": "nsemenov-081971@postgrespro.ru", "phone": "+70642297056"}
0005434344090	5B2E16	0505 950335	DENIS MARTYNOV	{"phone": "+70680920675"}
0005434344091	5B2E16	7360 042139	MARIYA FADEEVA	{"email": "fadeeva.m_061974@postgrespro.ru", "phone": "+70273125473"}
0005434344092	7D4386	3883 771101	GALINA BORISOVA	{"email": "galina-borisova.01041980@postgrespro.ru", "phone": "+70676332113"}
0005434344093	EB0DB9	6852 348786	EVGENIYA MIKHAYLOVA	{"email": "e-mikhaylova-031976@postgrespro.ru", "phone": "+70399282195"}
0005434344094	EC3AED	7131 408690	NATALYA EFIMOVA	{"email": "natalyaefimova-04101961@postgrespro.ru", "phone": "+70024967506"}
0005434344095	A0872E	4360 642452	ANNA TARASOVA	{"email": "atarasova-20091963@postgrespro.ru", "phone": "+70959291811"}
0005434344096	C2D0E7	3739 132539	MARIYA VASILEVA	{"email": "m_vasileva_18021970@postgrespro.ru", "phone": "+70416204597"}
0005434344097	0416C6	5403 997410	ELMIRA ALEKSEEVA	{"phone": "+70569977692"}
0005434344098	03B604	0526 806302	DMITRIY IVANOV	{"phone": "+70468891735"}
0005434344099	FD2981	8877 915431	VERA KOROLEVA	{"email": "v_koroleva.011978@postgrespro.ru", "phone": "+70139455097"}
0005434344100	C0125A	5652 915454	VLADIMIR VOROBEV	{"phone": "+70325999485"}
0005434344101	C0125A	4143 694434	GALINA MARTYNOVA	{"email": "g_martynova-16071975@postgrespro.ru", "phone": "+70585410246"}
0005434344102	25EBAF	2053 753774	TATYANA KUZNECOVA	{"phone": "+70072190412"}
0005434344103	4ED781	1781 560881	SERGEY SERGEEV	{"email": "s_sergeev.1971@postgrespro.ru", "phone": "+70379021973"}
0005434344104	4ED781	6798 658752	VALENTINA BORISOVA	{"email": "borisova-v.21051970@postgrespro.ru", "phone": "+70691542005"}
0005434344105	76207B	2091 061028	PELAGEYA MATVEEVA	{"email": "p.matveeva_30041977@postgrespro.ru", "phone": "+70884177818"}
0005434344106	76207B	9792 326321	SERGEY ALEKSANDROV	{"phone": "+70460371791"}
0005434344107	D4E9DF	8948 893388	EGOR KUZMIN	{"email": "egor.kuzmin.111974@postgrespro.ru", "phone": "+70835376489"}
0005434344108	D4E9DF	8251 197182	PAVEL MARTYNOV	{"phone": "+70110848792"}
0005434344109	C66118	4339 456585	SERGEY SCHERBAKOV	{"phone": "+70509551624"}
0005434344110	4DC2A2	0737 873808	KLAVDIYA SOKOLOVA	{"email": "klavdiya_sokolova.1981@postgrespro.ru", "phone": "+70855991811"}
0005434344111	65C8A3	0177 135668	ALEKSEY VLASOV	{"phone": "+70085577853"}
0005434344112	482827	7896 309449	SERGEY BORISOV	{"phone": "+70709927166"}
0005434344113	482827	2665 019618	ANTON PAVLOV	{"email": "pavlov.a_1957@postgrespro.ru", "phone": "+70312122644"}
0005434344114	4A5255	7167 398971	IRINA STEPANOVA	{"email": "stepanova_i_111963@postgrespro.ru", "phone": "+70701780429"}
0005434344115	54D9A1	4201 808342	ALEKSANDR PETROV	{"email": "apetrov_30101969@postgrespro.ru", "phone": "+70882775851"}
0005434344116	6EE49C	5569 164231	VLADIMIR MATVEEV	{"email": "matveev-vladimir.021978@postgrespro.ru", "phone": "+70067263685"}
0005434344117	6EE49C	2013 283990	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr-061986@postgrespro.ru", "phone": "+70868391228"}
0005434344118	1B5647	4403 375564	GEORGIY VOLKOV	{"phone": "+70811365230"}
0005434344119	48CC39	3753 234191	ALEKSEY DAVYDOV	{"phone": "+70247748426"}
0005434344120	6E5BCE	7641 676157	VIKTOR TARASOV	{"phone": "+70210131907"}
0005434344121	186E6D	3007 559744	MARIYA KOLESNIKOVA	{"email": "kolesnikova-mariya-12121980@postgrespro.ru", "phone": "+70113980277"}
0005434344122	93CF56	0605 465615	GALINA KUZNECOVA	{"email": "galina-kuznecova031958@postgrespro.ru", "phone": "+70899271273"}
0005434344123	A68195	1245 911775	TAMARA FROLOVA	{"email": "tamara.frolova_07121972@postgrespro.ru", "phone": "+70613947728"}
0005434344124	A68195	5853 006866	NIKOLAY BONDARENKO	{"phone": "+70577435289"}
0005434344125	4FEBC9	5929 266366	GALINA GAVRILOVA	{"email": "galina_gavrilova.1960@postgrespro.ru", "phone": "+70530715026"}
0005434344126	97875A	5032 001612	DANILA PAVLOV	{"email": "pavlovdanila1966@postgrespro.ru", "phone": "+70887369311"}
0005434344127	354992	6316 232601	TAISIYA KOROLEVA	{"phone": "+70556811387"}
0005434344128	B065BA	4568 854418	GENNADIY DAVYDOV	{"phone": "+70038746220"}
0005434344129	B065BA	0371 198939	VIKTOR NIKITIN	{"email": "nikitin.viktor-25091973@postgrespro.ru", "phone": "+70348333251"}
0005434344130	5F1358	1939 221583	VENERA MAKAROVA	{"phone": "+70286532435"}
0005434344131	5F1358	4678 257878	RAIL ZHUKOV	{"email": "zhukovrail.111972@postgrespro.ru", "phone": "+70492168270"}
0005434344132	D6B0B8	0595 167183	OLGA BARANOVA	{"phone": "+70702300275"}
0005434344133	3189A1	9316 537287	KIRILL SMIRNOV	{"email": "smirnov.k_051972@postgrespro.ru", "phone": "+70797020216"}
0005434344134	41F8D9	8861 480067	IRINA NESTEROVA	{"email": "nesterova.irina-29051974@postgrespro.ru", "phone": "+70258632445"}
0005434344135	6A7839	3694 666726	NELYA GORBUNOVA	{"phone": "+70150462353"}
0005434344136	509B24	6032 117888	ALEKSANDRA KUZNECOVA	{"phone": "+70936608810"}
0005434344137	D4714D	5649 821160	YULIYA MASLOVA	{"phone": "+70142540192"}
0005434344138	CDA55A	3485 754179	SERGEY KRASNOV	{"email": "krasnov.s17031979@postgrespro.ru", "phone": "+70380205779"}
0005434344139	626238	9893 022749	YURIY IVANOV	{"phone": "+70639456883"}
0005434344140	C91B4E	2803 800662	DMITRIY IVANOV	{"phone": "+70843601044"}
0005434344141	2ECA21	7320 867530	ELENA KUZNECOVA	{"email": "e.kuznecova-051973@postgrespro.ru", "phone": "+70936208221"}
0005434344142	53BAF1	3334 092403	YULIYA KOLESNIKOVA	{"email": "y_kolesnikova_081969@postgrespro.ru", "phone": "+70504381608"}
0005434344143	6048B8	7355 593560	SERGEY BONDARENKO	{"phone": "+70868094196"}
0005434344144	6048B8	0429 811400	SVETLANA PETROVA	{"phone": "+70641040672"}
0005434344145	A13B71	3431 393450	EVGENIY OSIPOV	{"phone": "+70988644002"}
0005434344146	68F0DD	7143 499225	RUSTYAM POPOV	{"email": "r-popov_10111965@postgrespro.ru", "phone": "+70768633154"}
0005434344147	A61E07	5809 019483	VLADIMIR ABRAMOV	{"phone": "+70089941558"}
0005434344148	A61E07	4235 516614	MARINA KULIKOVA	{"phone": "+70864110356"}
0005434344149	9EF58D	5637 575454	VENERA VOLKOVA	{"email": "volkova_v.1964@postgrespro.ru", "phone": "+70734340380"}
0005434344150	6B7BF4	8668 144907	DMITRIY ALEKSEEV	{"email": "alekseevd_031975@postgrespro.ru", "phone": "+70740344761"}
0005434344151	6B7BF4	2753 619369	YURIY MOROZOV	{"phone": "+70370423356"}
0005434344152	9BC1D0	8340 203848	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey-021964@postgrespro.ru", "phone": "+70457860125"}
0005434344153	9BC1D0	1721 502067	VLADIMIR GERASIMOV	{"phone": "+70564726182"}
0005434344154	9BC1D0	2766 216891	SERGEY PAVLOV	{"email": "pavlov.sergey_1976@postgrespro.ru", "phone": "+70431014370"}
0005434344155	349489	7580 688715	ZHANNA LAZAREVA	{"email": "lazareva_zhanna-1968@postgrespro.ru", "phone": "+70212616399"}
0005434344156	826F3D	5473 814111	ILYA NAZAROV	{"phone": "+70536233858"}
0005434344157	826F3D	2574 005604	NATALYA FROLOVA	{"phone": "+70563298762"}
0005434344158	826F3D	5503 387607	NIKITA POPOV	{"email": "n.popov_1974@postgrespro.ru", "phone": "+70084713185"}
0005434344159	406480	5491 972509	VITALIY KONOVALOV	{"email": "konovalov_v.25111971@postgrespro.ru", "phone": "+70497141535"}
0005434344160	AE9E54	6694 223621	SERGEY SAVELEV	{"phone": "+70679478796"}
0005434344161	AE9E54	7506 866857	ANNA MATVEEVA	{"phone": "+70201988324"}
0005434344162	BBB2B0	8721 478593	LYUDMILA FOMINA	{"email": "fomina_lyudmila_101959@postgrespro.ru", "phone": "+70648308490"}
0005434344163	E116CA	4804 022935	GENNADIY KARPOV	{"email": "karpov_g-1967@postgrespro.ru", "phone": "+70844961878"}
0005434344164	79FBA5	9094 296601	NATALYA KRASNOVA	{"email": "krasnova.natalya.1966@postgrespro.ru", "phone": "+70936724243"}
0005434344165	04DF3D	5497 925147	EVGENIYA NAZAROVA	{"phone": "+70916650046"}
0005434344166	04DF3D	5593 644771	SERGEY KOZLOV	{"email": "s_kozlov_20101973@postgrespro.ru", "phone": "+70543462514"}
0005434344167	F9D33F	4625 882583	ALEKSEY GUSEV	{"email": "gusev_aleksey.1971@postgrespro.ru", "phone": "+70351380004"}
0005434344168	16D31E	4367 345713	NADEZHDA ILINA	{"phone": "+70765903533"}
0005434344169	CFFB42	4605 758724	OLGA MOROZOVA	{"phone": "+70485175313"}
0005434344170	2AEAC8	9322 403288	NIKOLAY TIKHONOV	{"email": "tikhonovn031983@postgrespro.ru", "phone": "+70186279484"}
0005434344171	33AC76	2067 171881	DENIS KUZMIN	{"email": "d-kuzmin.02101971@postgrespro.ru", "phone": "+70717390490"}
0005434344172	68D033	9282 416717	ANAIT GORBUNOVA	{"phone": "+70785129457"}
0005434344173	184845	6104 537885	LIDIYA KOROLEVA	{"email": "l_koroleva_13021975@postgrespro.ru", "phone": "+70842793399"}
0005434344174	3AC7AC	1922 147461	ALEKSEY OSIPOV	{"phone": "+70631121643"}
0005434344175	8A926A	1624 673196	BORIS VASILEV	{"phone": "+70321013194"}
0005434344176	1B210A	4805 057245	NADEZHDA FEDOROVA	{"email": "n-fedorova-15011972@postgrespro.ru", "phone": "+70235950559"}
0005434344177	C0EC78	7608 468451	YURIY BELOV	{"email": "y-belov.1963@postgrespro.ru", "phone": "+70550863727"}
0005434344178	3100FD	2465 860201	ALEKSEY STEPANOV	{"email": "stepanovaleksey091974@postgrespro.ru", "phone": "+70379577324"}
0005434344179	2DCF3D	6739 691650	LYUBOV MOISEEVA	{"email": "moiseeva.l_111982@postgrespro.ru", "phone": "+70501283411"}
0005434344180	F6C808	9124 914438	ANATOLIY SCHERBAKOV	{"email": "anatoliyscherbakov.1969@postgrespro.ru", "phone": "+70896373452"}
0005434344181	116234	8081 312588	NADEZHDA NIKITINA	{"email": "nikitina_nadezhda111985@postgrespro.ru", "phone": "+70639349422"}
0005434344182	7D84DE	8392 339575	VALENTINA BARANOVA	{"phone": "+70426633895"}
0005434344183	7D84DE	8794 441043	LIDIYA MELNIKOVA	{"phone": "+70003299377"}
0005434344184	7ABD91	1683 926599	VALERIY DMITRIEV	{"phone": "+70329187145"}
0005434344185	7ABD91	0121 753947	TIKHON SMIRNOV	{"email": "smirnov_t-03121973@postgrespro.ru", "phone": "+70178425072"}
0005434344186	7ABD91	5177 463497	EKATERINA LAZAREVA	{"phone": "+70548999755"}
0005434344187	758A38	2585 856959	ILYA KONOVALOV	{"phone": "+70187059178"}
0005434344188	9DB3C8	3512 397093	GALINA ALEKSEEVA	{"phone": "+70776020678"}
0005434344189	9DB3C8	0128 036606	NADEZHDA CHERNOVA	{"phone": "+70585061157"}
0005434344190	11664C	6515 355469	ALEKSANDR NOVIKOV	{"phone": "+70487939856"}
0005434344191	F0A97C	5720 677218	NINA NESTEROVA	{"phone": "+70648055221"}
0005434344192	F0A97C	1589 291274	VASILIY STEPANOV	{"email": "stepanov-vasiliy_1977@postgrespro.ru", "phone": "+70278484734"}
0005434344193	BD0D62	4711 678241	YULIYA OVCHINNIKOVA	{"phone": "+70632254028"}
0005434344194	DBFF12	2176 854522	ANTONINA TROFIMOVA	{"phone": "+70143646919"}
0005434344195	065AFA	9215 540977	SERAFIMA GORBUNOVA	{"phone": "+70366334661"}
0005434344196	C912BF	8729 132893	EVGENIY STEPANOV	{"email": "evgeniystepanov.1979@postgrespro.ru", "phone": "+70661672350"}
0005434344197	E0D786	1699 471218	YULIYA NIKIFOROVA	{"email": "nikiforova-y20011961@postgrespro.ru", "phone": "+70992614787"}
0005434344198	2D321A	5477 165144	VALERIY TARASOV	{"email": "tarasovv19011964@postgrespro.ru", "phone": "+70290395884"}
0005434344199	836EBD	3898 145080	IGOR ZHURAVLEV	{"email": "i-zhuravlev121978@postgrespro.ru", "phone": "+70973028373"}
0005434344200	525F62	8139 029667	GALINA VOLKOVA	{"email": "gvolkova_25071969@postgrespro.ru", "phone": "+70489223012"}
0005434344201	525F62	6193 273975	OLGA OSIPOVA	{"email": "osipovao011976@postgrespro.ru", "phone": "+70492426438"}
0005434344202	525F62	2265 508548	SVETLANA LAZAREVA	{"phone": "+70425135021"}
0005434344203	EB0EB1	3739 521433	GALINA VASILEVA	{"phone": "+70323607206"}
0005434344204	81BE87	1785 908329	NINA ORLOVA	{"email": "orlova_n-1971@postgrespro.ru", "phone": "+70378262359"}
0005434344205	6FDD79	7895 984357	MARIYA OSIPOVA	{"phone": "+70542276882"}
0005434344206	35F518	8514 894379	ANZHELA EGOROVA	{"phone": "+70438864724"}
0005434344207	496C2F	0158 774883	MARINA NESTEROVA	{"phone": "+70623726584"}
0005434344208	FE427D	9324 151128	ANDREY MOROZOV	{"email": "andreymorozov-071969@postgrespro.ru", "phone": "+70361422263"}
0005434344209	0E880F	6279 274554	RUSLAN KAZAKOV	{"email": "r_kazakov20031974@postgrespro.ru", "phone": "+70092637577"}
0005434344210	2DC0DD	1130 433362	VLADIMIR IVANOV	{"phone": "+70501280326"}
0005434344211	0E231D	7108 688411	IRINA SCHERBAKOVA	{"email": "scherbakova_i1978@postgrespro.ru", "phone": "+70949403654"}
0005434344212	0E231D	5189 675106	GALINA SMIRNOVA	{"email": "g.smirnova_021976@postgrespro.ru", "phone": "+70704175257"}
0005434344213	44049E	6574 700382	SERGEY IVANOV	{"phone": "+70645437297"}
0005434344214	44049E	8036 133381	EKATERINA POPOVA	{"email": "popova_ekaterina-101966@postgrespro.ru", "phone": "+70804491518"}
0005434344215	44B8EA	6691 031435	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-valentina-08081964@postgrespro.ru", "phone": "+70323399699"}
0005434344216	F36711	6821 131655	GALINA ZHURAVLEVA	{"email": "zhuravlevagalina061974@postgrespro.ru", "phone": "+70324306421"}
0005434344217	CD99EE	7455 802788	ANTONINA TIKHONOVA	{"phone": "+70135441033"}
0005434344218	62C2A8	4722 021303	GALINA MOROZOVA	{"phone": "+70629602064"}
0005434344219	D445AE	1688 982949	YULIYA DAVYDOVA	{"email": "davydova.yuliya-1970@postgrespro.ru", "phone": "+70581401317"}
0005434344220	D445AE	7945 482495	ROMAN KAZAKOV	{"phone": "+70230979480"}
0005434344221	7EB2B2	4780 297063	VLADLEN ZHURAVLEV	{"phone": "+70277087021"}
0005434344222	7EB2B2	4768 871476	DMITRIY SCHERBAKOV	{"phone": "+70756454697"}
0005434344223	2EA24D	7069 350764	MAKSIM MATVEEV	{"email": "matveevmaksim-1978@postgrespro.ru", "phone": "+70240898147"}
0005434344224	2EA24D	3686 104117	ARTEM NIKOLAEV	{"phone": "+70040995331"}
0005434344225	07ECCB	7091 165795	DENIS KAZAKOV	{"email": "kazakov_d.061967@postgrespro.ru", "phone": "+70980188783"}
0005434344226	4A8352	2430 268995	ALISA TROFIMOVA	{"phone": "+70519666314"}
0005434344227	4A8352	1885 097667	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov-051967@postgrespro.ru", "phone": "+70743048221"}
0005434344228	7BDA47	2251 837432	ELENA NESTEROVA	{"phone": "+70839188202"}
0005434344229	F4B371	6239 994816	NIKITA YAKOVLEV	{"email": "yakovlevn_1969@postgrespro.ru", "phone": "+70343179338"}
0005434344230	29ED21	5026 438120	GEORGIY ANTONOV	{"phone": "+70254076041"}
0005434344231	29ED21	1886 384624	ELENA ZOTOVA	{"email": "zotova_elena_071961@postgrespro.ru", "phone": "+70670945916"}
0005434344232	29ED21	4835 944992	TATYANA BELOVA	{"phone": "+70305619684"}
0005434344233	C807AB	9042 610917	ANASTASIYA FEDOROVA	{"phone": "+70360840357"}
0005434344234	5EDA38	0485 124901	VALERIY PAVLOV	{"email": "pavlovvaleriy.051974@postgrespro.ru", "phone": "+70409941523"}
0005434344235	C40A77	1652 661694	VLADIMIR SEMENOV	{"email": "vladimir_semenov.24121966@postgrespro.ru", "phone": "+70028138451"}
0005434344236	8B8D03	6906 640813	VLADIMIR KUZMIN	{"phone": "+70591602278"}
0005434344237	F17578	7065 593332	SERGEY VASILEV	{"email": "vasilev.s-28061981@postgrespro.ru", "phone": "+70760197988"}
0005434344238	F17578	5791 820964	VIKTORIYA KAZAKOVA	{"phone": "+70137991587"}
0005434344239	16023D	0409 477232	VLADIMIR MARTYNOV	{"phone": "+70774973399"}
0005434344240	947289	7980 569701	ALEKSANDR AFANASEV	{"phone": "+70458446256"}
0005434344241	947289	9548 718137	ELENA KUDRYASHOVA	{"email": "ekudryashova02011970@postgrespro.ru", "phone": "+70274572376"}
0005434344242	37F68D	1986 435234	ANASTASIYA KOROLEVA	{"email": "akoroleva_011955@postgrespro.ru", "phone": "+70638552066"}
0005434344243	C4B776	5836 609650	ANNA KUZNECOVA	{"email": "a_kuznecova.29051971@postgrespro.ru", "phone": "+70556071159"}
0005434344244	4C6860	3427 387493	ANNA PETROVA	{"email": "petrovaanna_06021967@postgrespro.ru", "phone": "+70967230340"}
0005434344245	BB625A	7707 377585	ANTONINA MAKAROVA	{"email": "makarova.a.1976@postgrespro.ru", "phone": "+70560910516"}
0005434344246	8F3F91	7498 132727	YURIY KUZNECOV	{"email": "kuznecovyuriy_20051974@postgrespro.ru", "phone": "+70987020703"}
0005434344247	0C88AB	8378 387452	KONSTANTIN NIKOLAEV	{"email": "nikolaev.k011978@postgrespro.ru", "phone": "+70617086906"}
0005434344248	0C88AB	6235 997429	ALEKSANDR SOKOLOV	{"email": "sokolov_a-30051973@postgrespro.ru", "phone": "+70286778810"}
0005434344249	245D34	6773 628942	DANIIL GORBUNOV	{"phone": "+70549400748"}
0005434344250	245D34	4712 420798	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov_21091982@postgrespro.ru", "phone": "+70839830899"}
0005434344251	AF2032	6822 626318	OLEG ROMANOV	{"phone": "+70331777950"}
0005434344252	AF2032	8338 582037	LYUBOV ZAKHAROVA	{"email": "zakharova-lyubov_1969@postgrespro.ru", "phone": "+70610630044"}
0005434344253	DE1B03	7277 516498	IGOR TARASOV	{"phone": "+70939774551"}
0005434344254	DAA4A7	1653 088759	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov.1974@postgrespro.ru", "phone": "+70249754246"}
0005434344255	8A2111	2085 496763	OKSANA OSIPOVA	{"phone": "+70788393468"}
0005434344256	8A2111	1485 385120	LIDIYA KUZNECOVA	{"phone": "+70442258016"}
0005434344257	1F998A	4920 379912	IVAN MIRONOV	{"email": "mironov.ivan.041964@postgrespro.ru", "phone": "+70645851608"}
0005434344258	F65D10	6606 000890	ANNA TARASOVA	{"email": "a-tarasova121980@postgrespro.ru", "phone": "+70617661088"}
0005434344259	9F4B51	5622 215426	MIKHAIL FEDOROV	{"email": "mikhailfedorov_04051974@postgrespro.ru", "phone": "+70362539193"}
0005434344260	9F4B51	0144 753302	KARINA KOMAROVA	{"phone": "+70137116685"}
0005434344261	5F5202	5043 855769	TATYANA MASLOVA	{"phone": "+70239798974"}
0005434344262	4EBD40	0082 387542	RINAT DMITRIEV	{"email": "rinatdmitriev13021971@postgrespro.ru", "phone": "+70412462015"}
0005434344263	364965	2935 137960	ALEKSANDR ORLOV	{"phone": "+70035431488"}
0005434344264	6CBE35	6470 425966	SERGEY GRIGOREV	{"email": "grigorev.sergey-03081972@postgrespro.ru", "phone": "+70866150822"}
0005434344265	2266CC	4399 817686	ALEKSANDRA AKIMOVA	{"email": "aakimova.081967@postgrespro.ru", "phone": "+70121488147"}
0005434344266	1CE305	6529 236119	GALINA NIKIFOROVA	{"phone": "+70585036024"}
0005434344267	5F41FA	2288 141690	ARTEM FILIPPOV	{"phone": "+70996410683"}
0005434344268	840591	9365 692749	NATALYA BELYAEVA	{"phone": "+70103021006"}
0005434344269	840591	1084 892649	LYUBOV VASILEVA	{"email": "vasileva_l.021961@postgrespro.ru", "phone": "+70960026546"}
0005434344270	B7C38B	0509 149528	EGOR GORBUNOV	{"phone": "+70061781723"}
0005434344271	A35D06	2926 250970	YURIY NAUMOV	{"phone": "+70797956651"}
0005434344272	A35D06	7657 055189	ALEKSANDRA ZOTOVA	{"phone": "+70476642892"}
0005434344273	46BBCB	5756 684165	VIKTORIYA KULIKOVA	{"phone": "+70632688723"}
0005434344274	914793	3167 806499	SERGEY SIDOROV	{"email": "s.sidorov.1978@postgrespro.ru", "phone": "+70516201497"}
0005434344275	914793	4167 650641	ALEKSANDR SHEVCHENKO	{"phone": "+70303732584"}
0005434344276	914793	0052 772208	ANATOLIY IVANOV	{"phone": "+70262457574"}
0005434344277	134716	0640 650856	SERGEY ORLOV	{"email": "orlovsergey.1975@postgrespro.ru", "phone": "+70563051714"}
0005434344278	134716	4537 603360	LYUDMILA BOGDANOVA	{"email": "bogdanova_lyudmila.1981@postgrespro.ru", "phone": "+70753774625"}
0005434344279	AC15A0	1015 085947	VLADIMIR EGOROV	{"phone": "+70023478470"}
0005434344280	7F965F	7297 301844	NIKOLAY ISAEV	{"email": "isaevn_111972@postgrespro.ru", "phone": "+70138154138"}
0005434344281	5A31FD	7244 104084	MAKSIM FROLOV	{"email": "frolov_m_041971@postgrespro.ru", "phone": "+70104555470"}
0005434344282	76845E	9211 145020	YULIYA KOLESNIKOVA	{"phone": "+70974958923"}
0005434344283	60722A	4926 991166	SVETLANA VASILEVA	{"phone": "+70232604894"}
0005434344284	BCF2AE	1461 034929	OLGA BARANOVA	{"email": "olga.baranova_111977@postgrespro.ru", "phone": "+70549746655"}
0005434344286	AB6AC6	5286 403263	SERGEY DENISOV	{"email": "denisovs-04061977@postgrespro.ru", "phone": "+70339421096"}
0005434344287	58A7E3	8534 335808	RAMIL NIKOLAEV	{"phone": "+70757846240"}
0005434344288	58A7E3	9331 373828	LYUDMILA MIRONOVA	{"email": "mironova.l-041981@postgrespro.ru", "phone": "+70658675350"}
0005434344289	E6700A	1074 711208	EVGENIYA ANTONOVA	{"email": "antonovae101974@postgrespro.ru", "phone": "+70036692909"}
0005434344290	8E0571	2295 514395	KRISTINA KOROLEVA	{"email": "koroleva.kristina.09111972@postgrespro.ru", "phone": "+70587963119"}
0005434344291	8E0571	8553 259795	NATALYA TROFIMOVA	{"phone": "+70795250483"}
0005434344292	8E0571	7344 909697	VALERIY MEDVEDEV	{"email": "valeriymedvedev-051970@postgrespro.ru", "phone": "+70117361326"}
0005434344293	BD1B4B	0519 119283	VERA LAZAREVA	{"phone": "+70858189117"}
0005434344294	C28FCF	0709 842044	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov071979@postgrespro.ru", "phone": "+70937235423"}
0005434344295	1F3E94	8427 879577	IGOR STEPANOV	{"phone": "+70818017796"}
0005434344296	F0F357	6919 378213	VLADIMIR MOROZOV	{"email": "morozovvladimir-051974@postgrespro.ru", "phone": "+70045802947"}
0005434344297	2304C9	9476 216591	NATALIYA FEDOROVA	{"phone": "+70569788899"}
0005434344298	388D0C	1900 267313	SERGEY RODIONOV	{"phone": "+70407596692"}
0005434344299	198CF1	1364 968625	MARIYA ROMANOVA	{"phone": "+70610021466"}
0005434344300	2875E0	9071 169876	ANASTASIYA ROMANOVA	{"email": "romanovaanastasiya-1977@postgrespro.ru", "phone": "+70373550594"}
0005434344301	35651B	8456 554181	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev081964@postgrespro.ru", "phone": "+70649141771"}
0005434344302	35651B	4366 306523	MARGARITA MIRONOVA	{"email": "mironova_margarita_19061969@postgrespro.ru", "phone": "+70249492421"}
0005434344303	CE0427	5676 032836	KARINA SERGEEVA	{"email": "karina_sergeeva-30071965@postgrespro.ru", "phone": "+70187000741"}
0005434344304	7D2FB7	2853 986484	LYUDMILA FOMINA	{"phone": "+70548149130"}
0005434344305	7D2FB7	2166 843620	ILYA SOROKIN	{"phone": "+70397364554"}
0005434344306	8F63D3	7165 673465	NADEZHDA ARKHIPOVA	{"email": "nadezhda_arkhipova.01121964@postgrespro.ru", "phone": "+70741647579"}
0005434344307	37816D	1284 165682	VERA IVANOVA	{"email": "ivanova-v_25011972@postgrespro.ru", "phone": "+70487831846"}
0005434344308	D01AFC	3265 215565	TATYANA GRISHINA	{"email": "tatyana.grishina091968@postgrespro.ru", "phone": "+70497348906"}
0005434344309	6242E5	5543 206183	TAMARA VOLKOVA	{"email": "volkova_tamara081976@postgrespro.ru", "phone": "+70077700901"}
0005434344310	6242E5	4843 909567	MARINA SMIRNOVA	{"phone": "+70588353629"}
0005434344311	24A811	4878 387014	VALENTINA BARANOVA	{"email": "baranova-valentina1974@postgrespro.ru", "phone": "+70618172606"}
0005434344312	24A811	9277 234140	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov.051976@postgrespro.ru", "phone": "+70480631564"}
0005434344313	D2B546	0302 572529	ANATOLIY KISELEV	{"email": "kiselev.anatoliy1970@postgrespro.ru", "phone": "+70080041640"}
0005434344314	1A6C56	6759 233757	EVGENIY FEDOROV	{"email": "efedorov_20021964@postgrespro.ru", "phone": "+70300214559"}
0005434344315	FEB825	5140 531787	NINA TARASOVA	{"phone": "+70505543203"}
0005434344316	967ED1	5831 067297	TATYANA YUDINA	{"email": "tatyanayudina1976@postgrespro.ru", "phone": "+70456961155"}
0005434344317	967ED1	8336 443420	EVDOKIYA ABRAMOVA	{"email": "e_abramova.14121966@postgrespro.ru", "phone": "+70885750552"}
0005434344318	32DEB3	8277 207366	PAVEL SEMENOV	{"phone": "+70208618312"}
0005434344319	60329C	7197 580456	GALINA NIKITINA	{"email": "gnikitina-1972@postgrespro.ru", "phone": "+70165800421"}
0005434344320	60329C	3795 520019	VERA OVCHINNIKOVA	{"email": "ovchinnikovav.22081973@postgrespro.ru", "phone": "+70015359544"}
0005434344321	707CDE	7554 771540	NINA NESTEROVA	{"email": "nesterova_n_09121962@postgrespro.ru", "phone": "+70056306432"}
0005434344322	F39F52	7699 413246	FEDOR GRIGOREV	{"email": "fedor_grigorev-1983@postgrespro.ru", "phone": "+70030877335"}
0005434344323	951A0C	5041 990770	GALINA VASILEVA	{"phone": "+70236934340"}
0005434344324	951A0C	9424 957508	ANASTASIYA KOMAROVA	{"email": "a.komarova091975@postgrespro.ru", "phone": "+70999895305"}
0005434344325	F0CE31	7740 695692	RAISA BELOVA	{"phone": "+70000692820"}
0005434344326	F0CE31	4465 674099	NATALIYA ILINA	{"email": "ilinanataliya.1965@postgrespro.ru", "phone": "+70681684429"}
0005434344327	0F5839	2361 112157	VLADIMIR SEMENOV	{"phone": "+70755565930"}
0005434344328	CFB37F	9707 683751	EVGENIY PAVLOV	{"phone": "+70393137036"}
0005434344329	91F45D	7829 036593	SERGEY SOLOVEV	{"phone": "+70742703871"}
0005434344330	9972E5	5916 458601	MARINA NIKIFOROVA	{"phone": "+70220856169"}
0005434344331	2CB528	0960 093077	ZINAIDA VOLKOVA	{"phone": "+70125607239"}
0005434344332	2CB528	6496 438143	NIKITA DAVYDOV	{"email": "davydov.nikita_031968@postgrespro.ru", "phone": "+70659535343"}
0005434344333	9DCDB9	3967 477286	VALENTINA ZHURAVLEVA	{"phone": "+70690454277"}
0005434344334	68AEA1	4699 297044	NATALYA NIKOLAEVA	{"phone": "+70341530413"}
0005434344335	68AEA1	0091 730207	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov_1966@postgrespro.ru", "phone": "+70849013917"}
0005434344336	E1F932	8882 945811	OLEG MIKHAYLOV	{"phone": "+70148020092"}
0005434344337	63CD22	8636 216619	ALEKSEY IVANOV	{"email": "ivanov_aleksey_1966@postgrespro.ru", "phone": "+70205662103"}
0005434344338	CA82B1	1759 908559	ALEKSANDR KUZNECOV	{"phone": "+70914485162"}
0005434344339	CA82B1	0612 026564	NIKOLAY IVANOV	{"phone": "+70298309285"}
0005434344340	006149	4096 674354	ELENA ILINA	{"phone": "+70411137407"}
0005434344341	85382F	6697 322099	OLGA DANILOVA	{"phone": "+70147771229"}
0005434344342	3E5C52	5756 796033	VENIAMIN NIKOLAEV	{"email": "nikolaev_veniamin.061969@postgrespro.ru", "phone": "+70733256156"}
0005434344343	FCA75D	6310 436633	MIKHAIL TIKHONOV	{"email": "tikhonovm1970@postgrespro.ru", "phone": "+70216030104"}
0005434344344	FCA75D	3308 314603	NIKOLAY KUDRYASHOV	{"phone": "+70733965165"}
0005434344345	FCA75D	3608 539241	ALEKSANDRA ROMANOVA	{"email": "aleksandra.romanova081978@postgrespro.ru", "phone": "+70713062205"}
0005434344346	FCA75D	6792 676412	STEPAN MOROZOV	{"email": "morozov_stepan.1978@postgrespro.ru", "phone": "+70689806272"}
0005434344347	BA65CF	2736 229322	OKSANA IVANOVA	{"email": "oksana-ivanova-1971@postgrespro.ru", "phone": "+70869623316"}
0005434344348	69F1B3	2366 835002	LARISA SCHERBAKOVA	{"email": "l_scherbakova_1973@postgrespro.ru", "phone": "+70159136527"}
0005434344349	69F1B3	3552 473946	ELENA GUSEVA	{"phone": "+70207780803"}
0005434344350	2D4D55	8017 338760	NIKITA SERGEEV	{"email": "nikita-sergeev.081977@postgrespro.ru", "phone": "+70086512372"}
0005434344351	2D4D55	9558 914731	SVETLANA YUDINA	{"phone": "+70529288633"}
0005434344352	881ABC	2431 986400	VLADIMIR ZHURAVLEV	{"phone": "+70106798236"}
0005434344353	2F4F15	9833 982510	DMITRIY OSIPOV	{"phone": "+70343307143"}
0005434344354	A7DB7E	7688 949223	SERGEY VASILEV	{"email": "vasilev-s_011970@postgrespro.ru", "phone": "+70993320752"}
0005434344355	6CC3EB	6601 519922	ELENA SOROKINA	{"email": "elenasorokina-061970@postgrespro.ru", "phone": "+70987001559"}
0005434344356	98450E	6314 595719	VITALIY MAKSIMOV	{"phone": "+70822228791"}
0005434344357	98450E	9252 190446	PAVEL SOLOVEV	{"email": "solovevp11021962@postgrespro.ru", "phone": "+70593840099"}
0005434344358	74C6E0	0988 758347	ANDREY MAKAROV	{"phone": "+70455805714"}
0005434344359	8FAB6F	6630 491655	EKATERINA ZHUKOVA	{"phone": "+70493490862"}
0005434344360	4234EF	1320 273733	GALINA MEDVEDEVA	{"email": "medvedeva_galina.051970@postgrespro.ru", "phone": "+70382523556"}
0005434344361	9EC7D7	1062 913080	GALINA ALEKSEEVA	{"email": "galina.alekseeva.11021980@postgrespro.ru", "phone": "+70568956881"}
0005434344362	90510A	7626 653334	OKSANA POTAPOVA	{"email": "o_potapova-041967@postgrespro.ru", "phone": "+70178545587"}
0005434344363	7FCABD	6002 233702	YULIYA MASLOVA	{"phone": "+70979732703"}
0005434344364	9EE105	5936 888706	STANISLAV KONOVALOV	{"phone": "+70733046654"}
0005434344365	AD1056	6070 108574	NINA KUZMINA	{"phone": "+70449805521"}
0005434344366	AD1056	7262 365603	EVGENIY NIKOLAEV	{"email": "nikolaev_evgeniy.12041981@postgrespro.ru", "phone": "+70765137255"}
0005434344367	31C70D	7079 854577	ALEKSEY STEPANOV	{"phone": "+70454296587"}
0005434344368	31C70D	7897 148529	RAFAEL ANTONOV	{"email": "antonov-rafael1984@postgrespro.ru", "phone": "+70441568060"}
0005434344369	3AB108	4355 331578	SERGEY SMIRNOV	{"email": "s.smirnov-18051973@postgrespro.ru", "phone": "+70419561001"}
0005434344370	3AB108	3913 308771	ALENA OSIPOVA	{"phone": "+70096931820"}
0005434344371	48C2BA	0501 734013	YURIY ORLOV	{"email": "orlov_y_1965@postgrespro.ru", "phone": "+70298843729"}
0005434344372	A548BA	0618 461201	DMITRIY ANDREEV	{"email": "andreevd07031965@postgrespro.ru", "phone": "+70069612894"}
0005434344373	A548BA	9567 279133	YULIYA OVCHINNIKOVA	{"phone": "+70226851695"}
0005434344374	5D981F	6915 655149	KSENIYA ZAKHAROVA	{"email": "kseniya.zakharova_061960@postgrespro.ru", "phone": "+70838310768"}
0005434344375	5D981F	5576 738719	VYACHESLAV KUZNECOV	{"email": "kuznecov.v_1967@postgrespro.ru", "phone": "+70600767047"}
0005434344376	8EBB5E	7697 792704	NATALYA KUZNECOVA	{"phone": "+70106402566"}
0005434344377	8EBB5E	7291 924190	MARIYA BORISOVA	{"email": "borisova-mariya031966@postgrespro.ru", "phone": "+70180988849"}
0005434344378	CB6D71	2191 736340	YANA FILIPPOVA	{"email": "y_filippova-1970@postgrespro.ru", "phone": "+70486650047"}
0005434344379	CB6D71	8220 280142	IVAN VOLKOV	{"email": "volkov.i-1972@postgrespro.ru", "phone": "+70556020548"}
0005434344380	18F9E2	4266 760531	LYUDMILA ANDREEVA	{"email": "lyudmilaandreeva.051973@postgrespro.ru", "phone": "+70540365239"}
0005434344381	843A58	4194 520189	LEONID PAVLOV	{"email": "leonid-pavlov.111973@postgrespro.ru", "phone": "+70696389044"}
0005434344382	CABD55	4765 685489	ALEKSANDR VOLKOV	{"phone": "+70913191356"}
0005434344383	CABD55	6243 434595	OKSANA BELOVA	{"email": "oksanabelova.041974@postgrespro.ru", "phone": "+70612158978"}
0005434344384	52B665	3346 996601	NIKOLAY KOROLEV	{"email": "korolev_n.14091972@postgrespro.ru", "phone": "+70127823782"}
0005434344385	331B6E	3790 051220	IVAN KOROLEV	{"phone": "+70420376126"}
0005434344386	A886FF	5634 925723	VALENTINA ANTONOVA	{"phone": "+70129122757"}
0005434344387	78E7BE	9520 015055	VARVARA LOGINOVA	{"phone": "+70021087361"}
0005434344388	673DF4	6798 100488	MIKHAIL STEPANOV	{"phone": "+70728642354"}
0005434344389	896398	5301 596931	VALENTINA SOKOLOVA	{"email": "v.sokolova.28021970@postgrespro.ru", "phone": "+70032900624"}
0005434344390	B1BF0B	1964 334996	SERGEY ORLOV	{"email": "orlov-s1983@postgrespro.ru", "phone": "+70415231387"}
0005434344391	CDB50B	2840 666546	PAVEL TIKHONOV	{"email": "pavel_tikhonov.1971@postgrespro.ru", "phone": "+70598644435"}
0005434344392	49FC11	7946 329940	VALENTINA ISAEVA	{"email": "v_isaeva-1960@postgrespro.ru", "phone": "+70131476664"}
0005434344393	01262C	5340 999996	ELENA STEPANOVA	{"email": "e_stepanova1966@postgrespro.ru", "phone": "+70715154853"}
0005434344394	01262C	4398 113012	EGOR IVANOV	{"email": "egor.ivanov02011973@postgrespro.ru", "phone": "+70196037430"}
0005434344395	01262C	6660 082836	IVAN STEPANOV	{"email": "stepanov-i.1976@postgrespro.ru", "phone": "+70836082738"}
0005434344396	66E449	6820 047119	ALEKSANDR ALEKSANDROV	{"phone": "+70601149289"}
0005434344397	5F393C	6697 925236	IGOR NOVIKOV	{"email": "novikovi1979@postgrespro.ru", "phone": "+70092343761"}
0005434344398	1F21FB	6638 500372	OKSANA BORISOVA	{"phone": "+70862938592"}
0005434344577	1AFEAF	7099 809134	VLADIMIR ZHUKOV	{"phone": "+70916741342"}
0005434344399	8A95CA	2652 530371	NADEZHDA TIMOFEEVA	{"email": "ntimofeeva-051978@postgrespro.ru", "phone": "+70557575931"}
0005434344400	B09C94	3862 222078	PETR MEDVEDEV	{"email": "p_medvedev.26031966@postgrespro.ru", "phone": "+70515498747"}
0005434344401	015E34	3154 891157	ELIZAVETA KOZLOVA	{"phone": "+70804409260"}
0005434344402	B4EECC	4280 352869	YURIY FOMIN	{"email": "fomin.y041976@postgrespro.ru", "phone": "+70567885921"}
0005434344403	B4EECC	7679 656810	SERGEY ALEKSEEV	{"phone": "+70608345086"}
0005434344404	EF5837	5646 464344	OLGA KOROLEVA	{"phone": "+70718047684"}
0005434344405	2393CA	2457 500597	ELIZAVETA KONOVALOVA	{"email": "konovalova.elizaveta011980@postgrespro.ru", "phone": "+70017548443"}
0005434344406	BA872F	0405 510248	IRINA CHERNOVA	{"phone": "+70052282005"}
0005434344407	BA872F	7117 264540	ALEKSANDR KUZMIN	{"phone": "+70187107116"}
0005434344408	02F2AA	9835 393677	MAKSIM SMIRNOV	{"email": "smirnov_maksim_1973@postgrespro.ru", "phone": "+70177274019"}
0005434344409	02F2AA	8763 921996	GALINA PETROVA	{"email": "galina_petrova-25051982@postgrespro.ru", "phone": "+70235361320"}
0005434344410	7CE4D6	2035 712235	PELAGEYA OSIPOVA	{"email": "osipova.pelageya_1974@postgrespro.ru", "phone": "+70722248887"}
0005434344411	784EEF	8572 391258	ANDREY ILIN	{"email": "ilin-a.051982@postgrespro.ru", "phone": "+70518096082"}
0005434344412	D0F27C	1090 245983	KONSTANTIN PETROV	{"phone": "+70048745944"}
0005434344413	452633	9187 888231	NATALYA ZHURAVLEVA	{"phone": "+70283516028"}
0005434344414	49E5CE	7727 832946	BORIS EGOROV	{"email": "egorov.b1966@postgrespro.ru", "phone": "+70466790909"}
0005434344415	175530	1633 727956	GRIGORIY ALEKSANDROV	{"phone": "+70528097315"}
0005434344416	175530	3058 612509	IGOR POPOV	{"phone": "+70875544323"}
0005434344417	175530	8341 670011	OLGA PETROVA	{"email": "petrova-o_28071977@postgrespro.ru", "phone": "+70580974250"}
0005434344418	2D4449	6741 016288	ALINA KOROLEVA	{"email": "koroleva.a-091959@postgrespro.ru", "phone": "+70110835495"}
0005434344419	EF6A4A	3011 104888	ANATOLIY DMITRIEV	{"email": "a_dmitriev-011975@postgrespro.ru", "phone": "+70462810350"}
0005434344420	C7599A	0289 066279	ANDREY EGOROV	{"phone": "+70745421939"}
0005434344421	093235	3732 458147	OLEG POPOV	{"phone": "+70177331365"}
0005434344422	31D684	0297 307515	LIDIYA ALEKSANDROVA	{"phone": "+70696734437"}
0005434344423	995EAF	8457 411138	ALEKSANDR KOZLOV	{"phone": "+70299850964"}
0005434344424	D749F9	2448 298656	VALERIYA TARASOVA	{"email": "valeriya.tarasova-1978@postgrespro.ru", "phone": "+70922958163"}
0005434344425	8FB30F	4934 684817	VIKTOR BELOV	{"email": "viktor-belov-111976@postgrespro.ru", "phone": "+70936632494"}
0005434344426	8FB30F	8677 327543	VIKTOR ROMANOV	{"email": "v.romanov_031981@postgrespro.ru", "phone": "+70084379161"}
0005434344427	28A689	4843 166282	LYUBOV NIKOLAEVA	{"email": "nikolaeva.lyubov.041971@postgrespro.ru", "phone": "+70672877032"}
0005434344428	28A689	3272 894029	ANDREY IVANOV	{"email": "ivanov_a.18071970@postgrespro.ru", "phone": "+70154508396"}
0005434344429	F808DB	9230 547173	YURIY ROMANOV	{"email": "yuriy.romanov-121962@postgrespro.ru", "phone": "+70340489028"}
0005434344430	F6A407	2976 311381	VALENTINA OVCHINNIKOVA	{"phone": "+70097315554"}
0005434344431	57F8D9	7393 945528	SERGEY GAVRILOV	{"email": "s_gavrilov_031975@postgrespro.ru", "phone": "+70365010718"}
0005434344432	57F8D9	7521 816136	FEDOR MIKHAYLOV	{"email": "fedor.mikhaylov24051971@postgrespro.ru", "phone": "+70713974971"}
0005434344433	57F8D9	8367 410944	SVETLANA ABRAMOVA	{"phone": "+70670631002"}
0005434344434	4FA5AD	8007 124841	MARIYA FROLOVA	{"email": "mariya_frolova_081974@postgrespro.ru", "phone": "+70531342609"}
0005434344435	24E61D	8198 631613	SERGEY ZHURAVLEV	{"email": "zhuravlevs.1969@postgrespro.ru", "phone": "+70292299883"}
0005434344436	24E61D	2234 338537	ELENA AKIMOVA	{"email": "akimova_elena061980@postgrespro.ru", "phone": "+70487349361"}
0005434344437	57FB7A	8357 150490	LYUDMILA NAZAROVA	{"email": "l-nazarova-101964@postgrespro.ru", "phone": "+70250304161"}
0005434344438	57FB7A	3293 105778	RINAT GRIGOREV	{"email": "grigorev.r.11031969@postgrespro.ru", "phone": "+70109916624"}
0005434344439	C75F23	2917 063229	DMITRIY KONOVALOV	{"phone": "+70228678089"}
0005434344440	AF33D2	3230 974643	SERGEY KULIKOV	{"phone": "+70211812932"}
0005434344441	AF33D2	8725 154675	ELENA NESTEROVA	{"email": "enesterova24091955@postgrespro.ru", "phone": "+70470154807"}
0005434344442	FBF536	3627 678168	SERGEY SOROKIN	{"phone": "+70368203467"}
0005434344443	8ACD8E	4343 264774	NATALYA SIDOROVA	{"phone": "+70080151555"}
0005434344444	8ACD8E	7515 031831	VITALIY ORLOV	{"email": "orlovv.111967@postgrespro.ru", "phone": "+70037175041"}
0005434344445	5E0741	6279 637966	VALERIY FROLOV	{"email": "vfrolov.12071975@postgrespro.ru", "phone": "+70639105037"}
0005434344446	5E0741	0167 966850	OLGA GERASIMOVA	{"email": "gerasimova.o_09061977@postgrespro.ru", "phone": "+70218849854"}
0005434344447	06BA85	2585 396487	EVGENIYA SAVELEVA	{"email": "saveleva.e.1971@postgrespro.ru", "phone": "+70768227352"}
0005434344448	F32209	5992 574142	VERA KUZMINA	{"phone": "+70555052711"}
0005434344449	3A060D	0125 411923	MARINA KALININA	{"phone": "+70279212106"}
0005434344450	C33F0E	1544 577537	DMITRIY ROMANOV	{"email": "d.romanov1963@postgrespro.ru", "phone": "+70395719432"}
0005434344451	C33F0E	7903 089090	IVAN ANDREEV	{"phone": "+70019282285"}
0005434344452	C33F0E	9516 226548	OLGA VOLKOVA	{"email": "o.volkova_101980@postgrespro.ru", "phone": "+70291944652"}
0005434344453	4FEBA9	7991 519082	ALEKSEY FROLOV	{"email": "aleksey_frolov.26041976@postgrespro.ru", "phone": "+70975312898"}
0005434344454	34E69C	1762 702322	VYACHESLAV IVANOV	{"phone": "+70755988325"}
0005434344455	0497B6	7135 580537	NIKOLAY IVANOV	{"phone": "+70945928402"}
0005434344456	142CF5	2425 242322	EVGENIYA POPOVA	{"phone": "+70620599371"}
0005434344457	B788D0	6747 920840	YULIYA IVANOVA	{"phone": "+70095486069"}
0005434344458	986BAE	6097 622556	SERGEY MARTYNOV	{"email": "martynov.sergey_06051968@postgrespro.ru", "phone": "+70907639898"}
0005434344459	F8D3CD	3593 801163	ELENA KUDRYASHOVA	{"email": "kudryashovaelena_1979@postgrespro.ru", "phone": "+70302732446"}
0005434344460	D55495	4956 813018	IRINA FROLOVA	{"email": "i-frolova.1969@postgrespro.ru", "phone": "+70205556217"}
0005434344461	7A7968	3605 660248	ANTONINA FADEEVA	{"email": "antonina.fadeeva.101972@postgrespro.ru", "phone": "+70305212265"}
0005434344462	7A7968	5019 460006	TATYANA ZHURAVLEVA	{"email": "zhuravleva.t.08101979@postgrespro.ru", "phone": "+70355426971"}
0005434344463	18E733	6168 775798	NIKITA FEDOROV	{"email": "nikita-fedorov.19011958@postgrespro.ru", "phone": "+70734014807"}
0005434344464	03F431	8289 399391	MAKSIM GORBUNOV	{"phone": "+70897213148"}
0005434344465	03F431	6569 576250	IVAN TIMOFEEV	{"phone": "+70056058766"}
0005434344466	9B7773	0899 456953	ELENA BELYAEVA	{"email": "elenabelyaeva.16121988@postgrespro.ru", "phone": "+70544197626"}
0005434344467	5D4F01	5395 629177	ARSEN MELNIKOV	{"phone": "+70775892191"}
0005434344468	B41945	3946 668316	ANASTASIYA ANTONOVA	{"email": "anastasiya-antonova.121968@postgrespro.ru", "phone": "+70576215061"}
0005434344469	093D52	4987 001237	TATYANA DAVYDOVA	{"email": "davydova.tatyana_02031970@postgrespro.ru", "phone": "+70525858822"}
0005434344470	13E9F8	7283 235109	ELENA ZOTOVA	{"phone": "+70845096460"}
0005434344471	13E9F8	1860 223738	VLADIMIR BORISOV	{"email": "borisov_v27091975@postgrespro.ru", "phone": "+70632412441"}
0005434344472	45BE59	0173 680689	GALINA NESTEROVA	{"email": "nesterovagalina051969@postgrespro.ru", "phone": "+70177167709"}
0005434344473	47033A	7523 849588	EKATERINA TARASOVA	{"phone": "+70661319483"}
0005434344474	17F120	6037 741811	IGOR SEMENOV	{"email": "i_semenov.041975@postgrespro.ru", "phone": "+70502363882"}
0005434344475	9DD397	1082 250870	LYUBOV KOROLEVA	{"email": "korolevalyubov.10111981@postgrespro.ru", "phone": "+70241984669"}
0005434344476	AD066C	4207 169561	RUSLAN FOMIN	{"email": "fomin_r1966@postgrespro.ru", "phone": "+70566201356"}
0005434344477	AD066C	3830 259856	IGOR FOMIN	{"email": "igor.fomin.1975@postgrespro.ru", "phone": "+70155675982"}
0005434344478	01D1A9	0330 179042	VERA PAVLOVA	{"email": "pavlova_v_1970@postgrespro.ru", "phone": "+70817201150"}
0005434344479	01D1A9	2989 821399	NIKITA AFANASEV	{"phone": "+70940287944"}
0005434344480	01D1A9	4865 419839	TAMARA MARTYNOVA	{"phone": "+70554763206"}
0005434344481	05B88F	1680 248488	RAISA KRASNOVA	{"email": "raisa.krasnova_091978@postgrespro.ru", "phone": "+70920112414"}
0005434344482	DD7F85	2170 150575	SERAFIMA NAUMOVA	{"email": "s.naumova-23031973@postgrespro.ru", "phone": "+70892287363"}
0005434344483	B7E1B5	3024 183984	VLADIMIR GORBUNOV	{"email": "gorbunovv-1972@postgrespro.ru", "phone": "+70016765930"}
0005434344484	B7E1B5	2438 924390	TATYANA KOROLEVA	{"phone": "+70799584596"}
0005434344485	D70F5D	7039 588260	DMITRIY SIDOROV	{"email": "d-sidorov_061977@postgrespro.ru", "phone": "+70669349913"}
0005434344486	353C40	1186 401523	OLGA BOGDANOVA	{"phone": "+70312919990"}
0005434344487	D94F82	6276 447379	SVETLANA FILATOVA	{"phone": "+70460569706"}
0005434344488	26541B	1033 910260	SERGEY MOROZOV	{"phone": "+70524383182"}
0005434344489	0F1F55	6171 015241	VLADIMIR ILIN	{"email": "ilin.vladimir09121971@postgrespro.ru", "phone": "+70891071086"}
0005434344490	8E3BB4	1264 573694	NINA TITOVA	{"phone": "+70946066104"}
0005434344491	947E73	5120 912241	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov1970@postgrespro.ru", "phone": "+70183544057"}
0005434344492	947E73	0137 773627	NINA ILINA	{"phone": "+70513056946"}
0005434344493	36DC83	9099 412097	OLGA IVANOVA	{"email": "ivanovaolga_12061974@postgrespro.ru", "phone": "+70397260052"}
0005434344494	F53E85	9137 998407	NINA MAKSIMOVA	{"phone": "+70557676261"}
0005434344495	F53E85	1978 074533	TATYANA LOGINOVA	{"phone": "+70773554623"}
0005434344496	A4F51A	8099 646127	LEONID PETROV	{"phone": "+70823533937"}
0005434344497	593AA0	5027 794654	NATALYA MOROZOVA	{"phone": "+70883400073"}
0005434344498	3D6462	3537 590140	OLGA IVANOVA	{"email": "olgaivanova.1984@postgrespro.ru", "phone": "+70396173952"}
0005434344499	0F7478	1968 421637	OLGA POPOVA	{"phone": "+70984326268"}
0005434344500	0F7478	0584 109558	ELENA DANILOVA	{"email": "danilova.elena.1979@postgrespro.ru", "phone": "+70112484544"}
0005434344501	88C849	4462 641900	OLGA ZAYCEVA	{"phone": "+70720701989"}
0005434344502	B69FF7	5557 424448	VLADIMIR BORISOV	{"phone": "+70208717515"}
0005434344503	4C4088	6760 059840	LYUDMILA NIKITINA	{"email": "nikitina.l-25011970@postgrespro.ru", "phone": "+70525578587"}
0005434344504	A04071	9017 726154	GENNADIY ZHURAVLEV	{"phone": "+70069844945"}
0005434344505	07EB12	5310 255940	VLADIMIR BARANOV	{"email": "vbaranov03121968@postgrespro.ru", "phone": "+70098491732"}
0005434344506	2B9D5F	6776 547853	SVETLANA KONDRATEVA	{"email": "s-kondrateva-1967@postgrespro.ru", "phone": "+70570806489"}
0005434344507	43940A	0858 241414	GRIGORIY VOROBEV	{"phone": "+70711804961"}
0005434344508	BFDBE9	7491 547973	NINA ABRAMOVA	{"phone": "+70064262331"}
0005434344509	9C71C0	2899 785849	NINA NIKITINA	{"phone": "+70502540692"}
0005434344510	7371C1	5184 763284	DARYA FOMINA	{"phone": "+70679667469"}
0005434344511	E6BB0F	7827 266068	ALEKSANDR GRIGOREV	{"email": "grigoreva.30111971@postgrespro.ru", "phone": "+70137372641"}
0005434344512	0D5687	7609 363967	VLADISLAV SOROKIN	{"email": "sorokinv-1965@postgrespro.ru", "phone": "+70026136295"}
0005434344513	0D5687	3178 028527	KLARA ZAYCEVA	{"email": "zayceva_k20091969@postgrespro.ru", "phone": "+70241508359"}
0005434344514	71FD8F	7835 657406	IRINA BOGDANOVA	{"phone": "+70896781367"}
0005434344515	141AFA	4540 494006	VALENTINA MAKSIMOVA	{"email": "maksimova_valentina1970@postgrespro.ru", "phone": "+70917729176"}
0005434344516	141AFA	4502 590298	EKATERINA SEMENOVA	{"phone": "+70428958788"}
0005434344517	273475	5773 155849	ELIZAVETA ILINA	{"phone": "+70830950202"}
0005434344518	A91C3F	0957 013647	NIKOLAY KARPOV	{"email": "karpov-nikolay-20011970@postgrespro.ru", "phone": "+70376957717"}
0005434344519	6DD630	1569 655190	OLGA AFANASEVA	{"email": "afanaseva.olga-28061977@postgrespro.ru", "phone": "+70562699620"}
0005434344520	6DD630	3341 166367	ANATOLIY KULIKOV	{"phone": "+70485008307"}
0005434344521	E1E741	3029 975842	GALINA KRASNOVA	{"email": "g.krasnova.1977@postgrespro.ru", "phone": "+70580762707"}
0005434344522	E70E79	4222 635580	SERGEY CHERNOV	{"phone": "+70842085962"}
0005434344523	E70E79	6386 953186	VERONIKA VLASOVA	{"email": "vlasova_veronika-071971@postgrespro.ru", "phone": "+70628481684"}
0005434344524	17DA5E	8739 945685	GALINA VOLKOVA	{"email": "volkova-g-11111972@postgrespro.ru", "phone": "+70246336850"}
0005434344525	17DA5E	4409 474994	MIKHAIL MIKHAYLOV	{"email": "mikhailmikhaylov25061981@postgrespro.ru", "phone": "+70830762482"}
0005434344526	DA1A3D	3232 684836	ALEKSEY DAVYDOV	{"email": "davydov.aleksey.08041966@postgrespro.ru", "phone": "+70175667759"}
0005434344527	DA1A3D	1577 944308	DENIS VOROBEV	{"email": "dvorobev.12041978@postgrespro.ru", "phone": "+70402914450"}
0005434344528	DA1A3D	9487 951571	NINA ALEKSANDROVA	{"email": "ninaaleksandrova_121976@postgrespro.ru", "phone": "+70037801739"}
0005434344529	D5433E	8302 045407	MIKHAIL ALEKSEEV	{"email": "alekseev.m-061978@postgrespro.ru", "phone": "+70888487015"}
0005434344530	D5433E	9511 526583	ELENA BOGDANOVA	{"phone": "+70579294528"}
0005434344531	F5C3E9	2524 786489	VALERIY EGOROV	{"email": "egorov.v26081972@postgrespro.ru", "phone": "+70240191938"}
0005434344532	F5C3E9	6234 148219	VLADIMIR KOZLOV	{"phone": "+70266819733"}
0005434344533	AD385B	1532 502763	ALEKSEY MIRONOV	{"phone": "+70599599680"}
0005434344534	B27F23	6751 095138	EKATERINA TITOVA	{"email": "titova.ekaterina1957@postgrespro.ru", "phone": "+70934792497"}
0005434344535	B27F23	5148 739423	IRAIDA SEMENOVA	{"email": "i_semenova.22121961@postgrespro.ru", "phone": "+70376155118"}
0005434344536	C5A5B6	4736 434186	DENIS IVANOV	{"email": "ivanov.d.1968@postgrespro.ru", "phone": "+70751815090"}
0005434344537	44B63F	4640 442355	NINA ZAKHAROVA	{"email": "zakharova-nina.051977@postgrespro.ru", "phone": "+70928453810"}
0005434344538	44B63F	9907 412506	SERGEY PAVLOV	{"phone": "+70936389388"}
0005434344539	50387E	0227 345944	YULIYA LEBEDEVA	{"phone": "+70226001002"}
0005434344540	B4FE58	4006 086171	VIKTOR NAUMOV	{"phone": "+70639804125"}
0005434344541	BD3EE7	8318 947704	SHAMIL FEDOROV	{"email": "fedorov.s-041970@postgrespro.ru", "phone": "+70724080286"}
0005434344542	559D1D	6029 432499	ELENA DAVYDOVA	{"phone": "+70470019655"}
0005434344543	B5749D	9878 002835	OKSANA KUZNECOVA	{"email": "oksana_kuznecova081982@postgrespro.ru", "phone": "+70389550781"}
0005434344544	B5749D	9860 549227	EKATERINA DAVYDOVA	{"phone": "+70477681532"}
0005434344545	ED6137	6559 720495	EDUARD BELOV	{"phone": "+70716747073"}
0005434344546	44A840	9420 173983	DMITRIY ZHUKOV	{"phone": "+70540004993"}
0005434344547	44A840	3457 359338	TIMOFEY ROMANOV	{"email": "t.romanov.101973@postgrespro.ru", "phone": "+70375237079"}
0005434344548	44A840	9130 427818	DENIS MIRONOV	{"email": "mironov_denis24011970@postgrespro.ru", "phone": "+70423663571"}
0005434344549	9560B0	1323 282131	ANNA ANISIMOVA	{"phone": "+70455832808"}
0005434344550	1D2958	2464 256769	TAMARA SMIRNOVA	{"email": "tamarasmirnova_03031982@postgrespro.ru", "phone": "+70434366571"}
0005434344551	1D2958	3905 781277	VLADIMIR PAVLOV	{"email": "pavlovvladimir-02101971@postgrespro.ru", "phone": "+70642151759"}
0005434344552	AEACCA	6721 105745	IRINA IVANOVA	{"email": "iivanova.101975@postgrespro.ru", "phone": "+70042905233"}
0005434344553	D8F359	3701 281060	VALENTINA TIMOFEEVA	{"phone": "+70894085308"}
0005434344554	D8F359	3784 078300	EVGENIY STEPANOV	{"phone": "+70739799844"}
0005434344555	B5C0ED	7039 188425	RAVIL GRIGOREV	{"email": "r.grigorev.26061991@postgrespro.ru", "phone": "+70768227818"}
0005434344556	B5C0ED	0952 578693	YURIY NIKOLAEV	{"phone": "+70753377856"}
0005434344557	3AA997	5093 475104	EGOR TARASOV	{"phone": "+70524875154"}
0005434344558	C124BA	8298 845246	NADEZHDA GORBUNOVA	{"email": "n-gorbunova_20101971@postgrespro.ru", "phone": "+70909312990"}
0005434344559	C124BA	2083 501281	SERGEY POPOV	{"phone": "+70635522572"}
0005434344560	C14C79	7402 035974	ZOYA ANTONOVA	{"email": "antonovaz_1968@postgrespro.ru", "phone": "+70688420184"}
0005434344561	475B3B	8708 895945	ALEKSEY NOVIKOV	{"email": "novikov.a-20011967@postgrespro.ru", "phone": "+70144029517"}
0005434344562	5820ED	5212 301042	MARIYA NIKITINA	{"phone": "+70562859044"}
0005434344563	5820ED	4569 765897	ELLA DMITRIEVA	{"email": "dmitrievae.01091971@postgrespro.ru", "phone": "+70037376663"}
0005434344564	2D76B1	2010 432398	NATALYA NOVIKOVA	{"phone": "+70372450105"}
0005434344565	2D76B1	7488 961647	VALENTINA KUZMINA	{"email": "valentina.kuzmina_22111984@postgrespro.ru", "phone": "+70222312508"}
0005434344566	191878	9372 310446	ANTONINA MELNIKOVA	{"phone": "+70068486114"}
0005434344567	55F895	7359 536744	MAKSIM GORBUNOV	{"email": "gorbunov_maksim-091957@postgrespro.ru", "phone": "+70336569789"}
0005434344568	C1C272	3596 585604	FAINA KOVALEVA	{"email": "kovaleva.f.01041979@postgrespro.ru", "phone": "+70326089842"}
0005434344569	C1C272	5267 671870	ANATOLIY IVANOV	{"phone": "+70251361361"}
0005434344570	6C91C8	6992 617870	RAFAIL BORISOV	{"email": "borisovrafail_1968@postgrespro.ru", "phone": "+70481199834"}
0005434344571	50D190	2062 589876	NIKOLAY NOVIKOV	{"email": "n_novikov1968@postgrespro.ru", "phone": "+70997609693"}
0005434344572	50D190	1403 199752	NIKOLAY MARTYNOV	{"email": "n_martynov_08081981@postgrespro.ru", "phone": "+70501408530"}
0005434344573	9C7558	7094 219080	ANASTASIYA KUZNECOVA	{"phone": "+70013981531"}
0005434344574	9C7558	7021 169116	MARINA YUDINA	{"phone": "+70141789202"}
0005434344575	5768A8	5164 034152	DMITRIY PETROV	{"email": "petrov-d_091971@postgrespro.ru", "phone": "+70383380160"}
0005434344576	4E3E5A	9365 563058	POLINA SOROKINA	{"phone": "+70512851316"}
0005434344578	1379B9	1807 391688	MARIYA KULIKOVA	{"phone": "+70911074007"}
0005434344579	351CB2	3077 387482	OLGA BORISOVA	{"phone": "+70590845722"}
0005434344580	AD0A21	2183 975271	YAKOV ZHURAVLEV	{"phone": "+70953549996"}
0005434344581	AD0A21	5055 546129	ELENA MELNIKOVA	{"email": "melnikova.e_1974@postgrespro.ru", "phone": "+70807596438"}
0005434344582	9C9620	7527 633305	LYUDMILA SEMENOVA	{"phone": "+70276875732"}
0005434344583	E40532	3542 399713	DANIIL NOVIKOV	{"email": "novikov-d1968@postgrespro.ru", "phone": "+70646664035"}
0005434344584	2D61B0	9242 731971	ELENA KOROLEVA	{"phone": "+70931596389"}
0005434344585	E8A28A	3195 753209	ANNA LEBEDEVA	{"phone": "+70202371084"}
0005434344586	E8A28A	1169 035040	NADEZHDA KONOVALOVA	{"phone": "+70715831030"}
0005434344587	A284DA	7279 973459	MARINA IVANOVA	{"phone": "+70532574836"}
0005434344588	A284DA	0029 501449	NADEZHDA RODIONOVA	{"email": "rodionova.nadezhda-02121973@postgrespro.ru", "phone": "+70627448097"}
0005434344589	A284DA	9296 624404	VALERIY MAKAROV	{"phone": "+70243550379"}
0005434344590	2D83B6	1780 202225	NIKOLAY VLASOV	{"email": "vlasov-nikolay1960@postgrespro.ru", "phone": "+70818660727"}
0005434344591	2D83B6	4879 089931	IRINA SERGEEVA	{"phone": "+70309200798"}
0005434344592	00D766	1227 290538	PAVEL IVANOV	{"phone": "+70342068310"}
0005434344593	70F866	1343 053923	MIKHAIL KRASNOV	{"email": "krasnov-m-04081959@postgrespro.ru", "phone": "+70018620983"}
0005434344594	78BF81	3035 354629	TATYANA KUZNECOVA	{"email": "kuznecovatatyana_08071976@postgrespro.ru", "phone": "+70693331302"}
0005434344595	A5E29F	9416 537752	ANASTASIYA EFIMOVA	{"phone": "+70404256452"}
0005434344596	7EC441	4437 173208	ALEVTINA CHERNOVA	{"email": "chernova.a-18011979@postgrespro.ru", "phone": "+70775621664"}
0005434344597	7EC441	0131 010920	IGOR MIRONOV	{"phone": "+70919939439"}
0005434344598	30B8E1	9521 607462	ARKADIY KUZNECOV	{"phone": "+70302689592"}
0005434344599	30B8E1	4286 320196	ALEKSANDR NOVIKOV	{"email": "a.novikov-1967@postgrespro.ru", "phone": "+70443731727"}
0005434344600	F23CDE	9204 347049	NADEZHDA TARASOVA	{"email": "n-tarasova.10021973@postgrespro.ru", "phone": "+70515377209"}
0005434344601	F23CDE	6829 631898	FEDOR KRASNOV	{"phone": "+70205219982"}
0005434344602	801A2A	3614 895021	SERGEY MAKAROV	{"phone": "+70772643689"}
0005434344603	271331	4157 660255	NATALYA ANDREEVA	{"email": "andreevanatalya.25081970@postgrespro.ru", "phone": "+70816604372"}
0005434344604	271331	4446 935267	OLGA GRISHINA	{"email": "grishina_o-28011967@postgrespro.ru", "phone": "+70285915620"}
0005434344605	D84C64	9881 199547	IRINA AFANASEVA	{"email": "irina.afanaseva15091964@postgrespro.ru", "phone": "+70784641101"}
0005434344606	9393D6	8586 329247	IGOR ABRAMOV	{"email": "i-abramov1973@postgrespro.ru", "phone": "+70886020987"}
0005434344607	9393D6	4779 168212	SERGEY NAUMOV	{"email": "snaumov04081978@postgrespro.ru", "phone": "+70186635389"}
0005434344608	9393D6	3689 514845	IRINA ANDREEVA	{"phone": "+70655508379"}
0005434344609	426B11	8935 151357	SERGEY NAUMOV	{"email": "sergey.naumov_1979@postgrespro.ru", "phone": "+70136850683"}
0005434344610	A82A59	7663 010540	DMITRIY RODIONOV	{"phone": "+70240090495"}
0005434344611	7EC632	4421 746271	RAISA VLASOVA	{"email": "vlasova.raisa.1985@postgrespro.ru", "phone": "+70977174995"}
0005434344612	7EC632	4869 693201	KIRILL ILIN	{"email": "ilinkirill.061961@postgrespro.ru", "phone": "+70898085511"}
0005434344613	50DCA3	5852 054888	TAMARA VASILEVA	{"phone": "+70612605020"}
0005434344614	E76580	6050 093811	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov.011969@postgrespro.ru", "phone": "+70765902266"}
0005434344615	604050	0583 932583	SEMEN KUDRYASHOV	{"email": "semen_kudryashov_1981@postgrespro.ru", "phone": "+70926446340"}
0005434344616	AACA26	8710 004862	LARISA VLASOVA	{"phone": "+70826407913"}
0005434344617	AACA26	5755 810239	ANDREY FOMIN	{"email": "a_fomin.051980@postgrespro.ru", "phone": "+70147516446"}
0005434344618	DEC0C5	8324 579935	YULIYA FEDOROVA	{"phone": "+70240089658"}
0005434344619	DEC0C5	5313 122350	ALEKSANDR OSIPOV	{"phone": "+70350327362"}
0005434344620	DEC0C5	8135 611083	VERA EFIMOVA	{"email": "v.efimova-19091981@postgrespro.ru", "phone": "+70158708271"}
0005434344621	3E0B9C	2000 355777	KSENIYA KOZLOVA	{"email": "kozlovakseniya1961@postgrespro.ru", "phone": "+70473056624"}
0005434344622	3E0B9C	0206 996351	ALEKSANDRA NAUMOVA	{"phone": "+70184248130"}
0005434344623	3E0B9C	6673 359018	ARTEM NAZAROV	{"email": "a.nazarov-1981@postgrespro.ru", "phone": "+70115937239"}
0005434344624	1FD2F8	2720 852453	ALEKSEY ANTONOV	{"phone": "+70746390608"}
0005434344625	5EB925	5101 251941	NADEZHDA KALININA	{"email": "kalinina.n_22061968@postgrespro.ru", "phone": "+70369712910"}
0005434344626	5EB925	7630 440671	VLADIMIR MOISEEV	{"email": "moiseev.vladimir-1961@postgrespro.ru", "phone": "+70026679938"}
0005434344627	DFD0D4	2649 762975	OLEG NAUMOV	{"email": "naumov.oleg_071979@postgrespro.ru", "phone": "+70548446007"}
0005434344628	30CA8F	3526 635400	PAVEL KUZMIN	{"phone": "+70873102764"}
0005434344629	30CA8F	9919 175366	FAINA SAVELEVA	{"phone": "+70593383319"}
0005434344630	DE8C76	2637 214189	MARINA PETROVA	{"phone": "+70057620609"}
0005434344631	18B9F9	5453 636414	SERGEY POPOV	{"phone": "+70882269130"}
0005434344632	18B9F9	5587 197526	SERGEY SOLOVEV	{"phone": "+70925974660"}
0005434344633	422846	3038 397642	EVGENIY DMITRIEV	{"phone": "+70514283867"}
0005434344634	400E05	8324 048729	IVAN VLASOV	{"phone": "+70683628884"}
0005434344635	400E05	5321 511553	VERA MIKHAYLOVA	{"email": "mikhaylova-vera-06081972@postgrespro.ru", "phone": "+70413878290"}
0005434344636	400E05	0584 163818	ANDREY FEDOTOV	{"email": "fedotovandrey_1973@postgrespro.ru", "phone": "+70514335360"}
0005434344637	F5E5A7	4226 163691	ALEKSEY TIMOFEEV	{"phone": "+70631383796"}
0005434344638	250386	0826 814529	SERGEY BELOV	{"phone": "+70951196753"}
0005434344639	133345	3361 231522	ZINAIDA MIRONOVA	{"email": "mironova-zinaida.1967@postgrespro.ru", "phone": "+70003581852"}
0005434344640	133345	3482 787356	ANDREY KUDRYASHOV	{"email": "kudryashov_a.041968@postgrespro.ru", "phone": "+70265246370"}
0005434344641	944487	5177 714551	IGOR KOROLEV	{"email": "igor.korolev1972@postgrespro.ru", "phone": "+70373282044"}
0005434344642	944487	2612 353724	ANATOLIY ANDREEV	{"phone": "+70006513715"}
0005434344643	79349A	0387 626292	MARGARITA LOGINOVA	{"phone": "+70742961679"}
0005434344644	1F67CE	6627 814560	ALEKSEY VOLKOV	{"email": "volkova_28111974@postgrespro.ru", "phone": "+70506169379"}
0005434344645	B74859	3334 255196	VLADIMIR MATVEEV	{"email": "matveev_vladimir-19051975@postgrespro.ru", "phone": "+70074200650"}
0005434344646	B74859	9481 008147	ANATOLIY FILIPPOV	{"email": "filippov_anatoliy-1982@postgrespro.ru", "phone": "+70349048155"}
0005434344647	378095	1262 973421	ELENA BORISOVA	{"phone": "+70630027939"}
0005434344648	6CAC64	3838 500984	EKATERINA ANDREEVA	{"email": "eandreeva1965@postgrespro.ru", "phone": "+70879259506"}
0005434344649	6CAC64	5324 787463	DENIS FEDOROV	{"phone": "+70325535265"}
0005434344650	62B429	7524 997266	LYUBOV KULIKOVA	{"email": "kulikova-l_061971@postgrespro.ru", "phone": "+70740198934"}
0005434344651	B5F847	5268 754656	TATYANA MEDVEDEVA	{"phone": "+70079193528"}
0005434344652	44EAA7	2926 700319	NIKOLAY MAKAROV	{"phone": "+70219191151"}
0005434344653	E30123	3136 229316	NADEZHDA MAKSIMOVA	{"email": "maksimovan111976@postgrespro.ru", "phone": "+70809670571"}
0005434344654	3619F4	8125 778029	VYACHESLAV ANDREEV	{"email": "andreev_v-1966@postgrespro.ru", "phone": "+70044500115"}
0005434344655	3619F4	0768 892252	GALINA ZOTOVA	{"email": "galina-zotova_091972@postgrespro.ru", "phone": "+70574412227"}
0005434344656	3619F4	9681 012564	NINA YAKOVLEVA	{"email": "nina_yakovleva1969@postgrespro.ru", "phone": "+70195137111"}
0005434344657	560A57	5606 511447	OLESYA POLYAKOVA	{"email": "opolyakova_1974@postgrespro.ru", "phone": "+70436922520"}
0005434344658	B4574E	4559 603781	OLESYA KUZNECOVA	{"email": "olesyakuznecova_1966@postgrespro.ru", "phone": "+70633136791"}
0005434344659	C7393B	8142 012532	GULSINA FILATOVA	{"phone": "+70454367214"}
0005434344660	B797A4	5974 427319	LYUDMILA FILATOVA	{"phone": "+70302107068"}
0005434344661	3F0481	3691 980937	ALEKSANDR BORISOV	{"email": "a_borisov16051976@postgrespro.ru", "phone": "+70967431763"}
0005434344662	3F0481	2603 453973	SVETLANA TITOVA	{"email": "titova.s.09011982@postgrespro.ru", "phone": "+70041183181"}
0005434344663	3F0481	2581 289932	OLGA YAKOVLEVA	{"email": "olga_yakovleva.1976@postgrespro.ru", "phone": "+70928180245"}
0005434344664	957E0A	7145 239886	INNA ALEKSANDROVA	{"phone": "+70553430998"}
0005434344665	957E0A	2004 739606	NIKOLAY TIKHONOV	{"email": "tikhonov_nikolay18061977@postgrespro.ru", "phone": "+70229236279"}
0005434344666	7DC204	5830 808745	OLGA VASILEVA	{"email": "vasileva_o-1975@postgrespro.ru", "phone": "+70561978752"}
0005434344667	9F23CF	6212 277452	EKATERINA SOROKINA	{"email": "ekaterinasorokina_20091987@postgrespro.ru", "phone": "+70633230573"}
0005434344668	9F23CF	4238 731457	YURIY FEDOROV	{"phone": "+70800499028"}
0005434344669	B2FF46	8060 995955	NIKOLAY KISELEV	{"email": "nikolaykiselev_19101982@postgrespro.ru", "phone": "+70491374549"}
0005434344670	8DDC0A	5690 255996	EVGENIY ZAYCEV	{"phone": "+70641529376"}
0005434344671	8DDC0A	1555 623360	DMITRIY EGOROV	{"phone": "+70789717031"}
0005434344672	E9B339	7455 368675	VLADISLAV BONDARENKO	{"email": "v-bondarenko_1978@postgrespro.ru", "phone": "+70405713520"}
0005434344673	AB1565	5085 929629	ANTON NAZAROV	{"email": "nazarov-anton_27031972@postgrespro.ru", "phone": "+70253512903"}
0005434344674	1C5149	5746 316141	LIDIYA TROFIMOVA	{"phone": "+70577151056"}
0005434344675	EAFF99	4036 355620	ALEKSEY SHEVCHENKO	{"phone": "+70001439048"}
0005434344676	EAFF99	7989 244688	GLEB GAVRILOV	{"email": "gavrilovg10011962@postgrespro.ru", "phone": "+70413779726"}
0005434344677	90B31C	8982 574090	VITALIY SAVELEV	{"email": "savelev_v-1974@postgrespro.ru", "phone": "+70430627523"}
0005434344678	90B31C	8938 559913	VALENTINA VOLKOVA	{"email": "volkova_valentina_051965@postgrespro.ru", "phone": "+70315651811"}
0005434344679	A6F17D	5135 539749	NIKOLAY MELNIKOV	{"email": "melnikov.n27091968@postgrespro.ru", "phone": "+70567244074"}
0005434344680	A6F17D	7982 471747	NIKOLAY VOROBEV	{"phone": "+70505444721"}
0005434344681	A6F17D	1065 441183	EVGENIY ZAYCEV	{"phone": "+70451443751"}
0005434344682	A6F17D	3936 557931	LEONID ALEKSEEV	{"phone": "+70672996511"}
0005434344683	A96EEC	6212 121805	ANNA EFIMOVA	{"phone": "+70320416078"}
0005434344684	D31A13	9967 311896	VLADIMIR VASILEV	{"email": "vasilevvladimir.19111975@postgrespro.ru", "phone": "+70202350505"}
0005434344685	D31A13	9818 525065	GALINA SIDOROVA	{"email": "sidorova_galina-05111974@postgrespro.ru", "phone": "+70432154397"}
0005434344686	72D5C1	4976 259016	KLAVDIYA NESTEROVA	{"email": "nesterova.klavdiya.1976@postgrespro.ru", "phone": "+70581222063"}
0005434344687	72D5C1	6148 745728	VLADIMIR BARANOV	{"email": "baranovvladimir.121979@postgrespro.ru", "phone": "+70997806699"}
0005434344688	823BC4	9545 512831	IVAN ZAKHAROV	{"email": "ivan.zakharov.12041969@postgrespro.ru", "phone": "+70010155277"}
0005434344689	3B5EDF	4296 301411	DMITRIY PETROV	{"phone": "+70780872983"}
0005434344690	3B5EDF	8346 015021	MARGARITA NIKOLAEVA	{"email": "nikolaeva.margarita091973@postgrespro.ru", "phone": "+70061230695"}
0005434344691	B78640	9902 479784	VALENTINA ZAKHAROVA	{"phone": "+70537337453"}
0005434344692	B78640	9499 194182	LIDIYA MELNIKOVA	{"phone": "+70965873916"}
0005434344693	F9C499	1599 990557	DMITRIY ABRAMOV	{"email": "abramov.d-051977@postgrespro.ru", "phone": "+70457130598"}
0005434344694	F9C499	7565 387201	DMITRIY NAZAROV	{"phone": "+70820570566"}
0005434344695	4E5C9A	3119 423143	NINA PAVLOVA	{"email": "pavlova.nina_1975@postgrespro.ru", "phone": "+70717416234"}
0005434344696	AC9B00	4862 784649	ALEKSEY MAKAROV	{"email": "makarova031966@postgrespro.ru", "phone": "+70332606616"}
0005434344697	BC920A	9973 094169	ALEKSANDR KONOVALOV	{"email": "a_konovalov.021955@postgrespro.ru", "phone": "+70786250410"}
0005434344698	BC920A	5863 632559	TATYANA SEMENOVA	{"phone": "+70544752038"}
0005434344699	199371	7194 452790	VALERIY KUZNECOV	{"email": "kuznecov.valeriy-101974@postgrespro.ru", "phone": "+70826244789"}
0005434344700	817DDB	8094 970607	GRIGORIY ZAKHAROV	{"email": "g-zakharov_19101974@postgrespro.ru", "phone": "+70163678972"}
0005434344701	685104	3470 023953	MAKSIM VASILEV	{"phone": "+70501676326"}
0005434344702	D1D08B	9640 713599	ELVIRA SOROKINA	{"email": "elvira-sorokina-09051970@postgrespro.ru", "phone": "+70902277628"}
0005434344703	D1D08B	0405 327937	KRISTINA MIKHAYLOVA	{"phone": "+70447715801"}
0005434344704	36BD7D	6472 967122	NIKOLAY MIKHAYLOV	{"email": "mikhaylovnikolay-021974@postgrespro.ru", "phone": "+70377548312"}
0005434344705	36BD7D	4055 969071	IRINA ZHUKOVA	{"phone": "+70328618486"}
0005434344706	FB374C	1299 322608	VYACHESLAV PETROV	{"email": "vyacheslav_petrov_1965@postgrespro.ru", "phone": "+70465958864"}
0005434344707	9493CC	1426 643473	TIMUR KULIKOV	{"email": "kulikovt-05021966@postgrespro.ru", "phone": "+70404243156"}
0005434344708	D8AF9B	8923 970181	ALEKSANDR MAKSIMOV	{"email": "maksimov.aleksandr.011975@postgrespro.ru", "phone": "+70843705902"}
0005434344709	21CCEE	3399 751409	GALINA POPOVA	{"phone": "+70600425619"}
0005434344710	21CCEE	9729 529792	ANATOLIY IVANOV	{"phone": "+70586617547"}
0005434344711	1CC543	0287 015410	ANTON FILIPPOV	{"phone": "+70623210820"}
0005434344712	38C50E	7447 620167	YULIYA BORISOVA	{"phone": "+70289863986"}
0005434344713	DE5DE2	1134 852507	GRIGORIY NAZAROV	{"phone": "+70876679314"}
0005434344714	C69584	6046 936711	DMITRIY GORBUNOV	{"phone": "+70902423878"}
0005434344715	C69584	3836 767559	NINA KULIKOVA	{"phone": "+70027517692"}
0005434344716	C5A7A4	9484 993741	ZLATA MEDVEDEVA	{"email": "medvedeva-z.01091974@postgrespro.ru", "phone": "+70889013785"}
0005434344717	72C2D1	5781 106604	VLADIMIR NOVIKOV	{"phone": "+70788710666"}
0005434344718	72C2D1	7753 403758	ALLA MAKAROVA	{"phone": "+70503757936"}
0005434344719	DE1337	1927 806051	NADEZHDA KALININA	{"email": "nadezhda.kalinina29121970@postgrespro.ru", "phone": "+70187268441"}
0005434344720	DE1337	2692 626269	TAMARA BOGDANOVA	{"phone": "+70737578286"}
0005434344721	51285C	6117 855030	ALEKSANDR ISAEV	{"phone": "+70824396147"}
0005434344722	BD8149	8325 737245	MARIYA TROFIMOVA	{"phone": "+70796344988"}
0005434344723	BD8149	6255 950743	VITALIY IVANOV	{"phone": "+70695022988"}
0005434344724	4F4522	1479 339165	LYUDMILA NIKOLAEVA	{"phone": "+70291801084"}
0005434344725	62B22E	1793 797146	YULIYA NESTEROVA	{"email": "yuliya-nesterova011962@postgrespro.ru", "phone": "+70141580716"}
0005434344726	472578	2968 422166	YANA ANISIMOVA	{"email": "anisimova.yana_09051973@postgrespro.ru", "phone": "+70982164654"}
0005434344727	AEF09F	5298 752098	TATYANA KISELEVA	{"phone": "+70571090237"}
0005434344728	AEF09F	7179 427545	ILYA STEPANOV	{"phone": "+70051494531"}
0005434344729	F42BCB	5490 191320	OLESYA ZAKHAROVA	{"email": "zakharova_o091967@postgrespro.ru", "phone": "+70232200729"}
0005434344730	F42BCB	5224 372692	VALERIY ILIN	{"phone": "+70731184862"}
0005434344731	466E46	2700 179945	ELENA PAVLOVA	{"email": "pavlova-e-031971@postgrespro.ru", "phone": "+70717033302"}
0005434344732	E2BCE1	1948 148778	INNA EGOROVA	{"email": "iegorova-1978@postgrespro.ru", "phone": "+70829158644"}
0005434344733	F774F7	9879 246461	IGOR PAVLOV	{"phone": "+70425810185"}
0005434344734	F774F7	7767 852368	FARIDA KOZLOVA	{"email": "fkozlova.051966@postgrespro.ru", "phone": "+70593800295"}
0005434344735	F774F7	8308 063702	ELVIRA MOROZOVA	{"email": "e_morozova.011979@postgrespro.ru", "phone": "+70335133478"}
0005434344736	7637D4	4294 595128	NADEZHDA YUDINA	{"phone": "+70810309450"}
0005434344737	7637D4	3689 835177	ANATOLIY KRASNOV	{"email": "krasnov.a22111969@postgrespro.ru", "phone": "+70098862565"}
0005434344738	066630	9568 551402	ANVAR MIRONOV	{"phone": "+70664439618"}
0005434344739	DA1C60	3871 293763	KONSTANTIN SOROKIN	{"phone": "+70922401265"}
0005434344740	DA1C60	9945 978007	ALEKSANDR PETROV	{"email": "petrova.03011968@postgrespro.ru", "phone": "+70046795762"}
0005434344741	45B73D	1678 355296	SOFIYA RYABOVA	{"phone": "+70742135255"}
0005434344742	CD72D7	7499 412237	STEPAN ROMANOV	{"email": "romanov-s-1978@postgrespro.ru", "phone": "+70676671746"}
0005434344743	207C69	1650 738692	EVGENIYA SERGEEVA	{"phone": "+70332931346"}
0005434344744	207C69	1144 519320	ANATOLIY ZAKHAROV	{"phone": "+70920568379"}
0005434344745	6E59A0	0609 591693	MIKHAIL NIKITIN	{"phone": "+70340708925"}
0005434344746	6E59A0	5185 350004	SERGEY AFANASEV	{"email": "sergey-afanasev.28121983@postgrespro.ru", "phone": "+70182140880"}
0005434344747	6FD758	5073 677241	VADIM KARPOV	{"email": "karpov.vadim17061961@postgrespro.ru", "phone": "+70079078501"}
0005434344748	2284A5	3350 279390	MARGARITA IVANOVA	{"email": "ivanovam-13101971@postgrespro.ru", "phone": "+70326267013"}
0005434344749	2284A5	9140 934569	EVGENIYA EFREMOVA	{"phone": "+70422659733"}
0005434344750	EA7628	0043 574251	ALEKSANDR PETROV	{"email": "aleksandrpetrov-031962@postgrespro.ru", "phone": "+70580294856"}
0005434344751	D9AA9B	5704 562382	IGOR DAVYDOV	{"email": "i-davydov_071971@postgrespro.ru", "phone": "+70556822479"}
0005434344752	2BF165	5095 763526	LYUDMILA KUZNECOVA	{"phone": "+70405585640"}
0005434344753	BCA921	0698 772347	LARISA SMIRNOVA	{"phone": "+70399110689"}
0005434344754	BCA921	9587 150476	OLGA NESTEROVA	{"email": "o-nesterova_07051964@postgrespro.ru", "phone": "+70509055371"}
0005434344755	BCA921	3676 431495	DENIS IVANOV	{"phone": "+70116719822"}
0005434344756	885410	7968 118874	PAVEL KUZNECOV	{"phone": "+70933131805"}
0005434344757	F889E8	2949 140860	ANTON SOKOLOV	{"phone": "+70779732042"}
0005434344758	F889E8	6044 547291	YURIY MATVEEV	{"phone": "+70648362265"}
0005434344759	43E4CD	9603 864955	SNEZHANA MIKHAYLOVA	{"email": "mikhaylova_s_17051973@postgrespro.ru", "phone": "+70069658415"}
0005434344760	40324D	9231 903403	IVAN BELOV	{"email": "belovi01071973@postgrespro.ru", "phone": "+70733922971"}
0005434344761	C1D14F	3323 342134	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr.1975@postgrespro.ru", "phone": "+70770136034"}
0005434344762	B7C234	2101 636122	ELENA FEDOROVA	{"phone": "+70924191517"}
0005434344763	B7C234	1624 261639	VALENTINA VOROBEVA	{"email": "v-vorobeva-10021987@postgrespro.ru", "phone": "+70243004868"}
0005434344764	484C75	1544 475499	MARIYA MELNIKOVA	{"phone": "+70306088304"}
0005434344765	7D2560	5166 614532	ALEKSANDR SOLOVEV	{"phone": "+70291484529"}
0005434344766	7D2560	1502 834827	OLGA CHERNOVA	{"email": "olga.chernova.031979@postgrespro.ru", "phone": "+70565438882"}
0005434344767	A61AFB	9995 122623	DMITRIY KUDRYASHOV	{"email": "dmitriy_kudryashov-061973@postgrespro.ru", "phone": "+70085365550"}
0005434344768	5520BB	6142 331962	MIKHAIL KARPOV	{"email": "mkarpov06051980@postgrespro.ru", "phone": "+70189950096"}
0005434344769	87CC35	1609 139188	GALINA NOVIKOVA	{"phone": "+70136984771"}
0005434344770	C99E6C	1816 642658	RAILYA SMIRNOVA	{"phone": "+70576142989"}
0005434344771	A9D9F5	6885 878384	NELLYA MOROZOVA	{"phone": "+70967342834"}
0005434344772	2BA36E	2904 801962	MARINA TIMOFEEVA	{"phone": "+70985010424"}
0005434344773	A8646B	8805 863343	ALEKSANDR ABRAMOV	{"phone": "+70684812499"}
0005434344774	9ECEA7	7807 808028	NATALYA YUDINA	{"email": "yudinan031985@postgrespro.ru", "phone": "+70117732464"}
0005434344775	C44A18	7760 792084	ZOYA YAKOVLEVA	{"email": "yakovleva-z.1972@postgrespro.ru", "phone": "+70856825678"}
0005434344776	5884F9	1773 204408	MARIYA KULIKOVA	{"email": "mariya-kulikova1971@postgrespro.ru", "phone": "+70426970125"}
0005434344777	5884F9	0941 385434	DARYA TIKHONOVA	{"email": "tikhonova-d_101975@postgrespro.ru", "phone": "+70601162430"}
0005434344778	013F09	2298 531560	STANISLAV ZAYCEV	{"phone": "+70355199758"}
0005434344779	013F09	1593 856803	VALENTINA PAVLOVA	{"email": "vpavlova1977@postgrespro.ru", "phone": "+70766562328"}
0005434344780	163EAC	0647 580212	LIDIYA ZOTOVA	{"email": "zotova-l-121964@postgrespro.ru", "phone": "+70630395870"}
0005434344781	163EAC	9821 838597	VLADIMIR ILIN	{"phone": "+70675187946"}
0005434344782	D9E3B7	4257 972755	ALEKSANDR ALEKSANDROV	{"email": "aleksandr.aleksandrov_1962@postgrespro.ru", "phone": "+70698640325"}
0005434344783	41BD6E	6725 895395	IVAN MEDVEDEV	{"email": "medvedev_ivan_09031979@postgrespro.ru", "phone": "+70910892253"}
0005434344784	41BD6E	9732 341869	VLADIMIR DAVYDOV	{"phone": "+70159894312"}
0005434344785	FECEFC	4528 915063	RAISA LOGINOVA	{"email": "loginova_raisa-031984@postgrespro.ru", "phone": "+70767830738"}
0005434344786	FECEFC	0574 665014	BORIS AFANASEV	{"email": "afanasev.boris011961@postgrespro.ru", "phone": "+70106810288"}
0005434344787	8F2C3C	5535 120711	PETR SEMENOV	{"email": "p.semenov.061976@postgrespro.ru", "phone": "+70669117556"}
0005434344788	8F2C3C	0054 216908	ANDREY ILIN	{"email": "ilin.a-1958@postgrespro.ru", "phone": "+70156848146"}
0005434344789	897D72	7353 950199	ALEKSANDR ZAKHAROV	{"phone": "+70396324014"}
0005434344790	66E160	2660 488410	TATYANA LOGINOVA	{"email": "tloginova_1983@postgrespro.ru", "phone": "+70540267627"}
0005434344791	66E160	6089 190018	SERGEY KUZNECOV	{"email": "kuznecov_sergey_10041965@postgrespro.ru", "phone": "+70561503919"}
0005434344792	BFF42E	7333 044567	ALEKSANDR MOROZOV	{"email": "a.morozov-031974@postgrespro.ru", "phone": "+70774647803"}
0005434344793	BFF42E	2220 823866	TATYANA OVCHINNIKOVA	{"phone": "+70215419565"}
0005434344794	EFF3FB	1543 592431	INNA GORBUNOVA	{"phone": "+70855846529"}
0005434344795	1D51F1	0505 519938	ANDREY ANTONOV	{"email": "antonova19081974@postgrespro.ru", "phone": "+70919303414"}
0005434344796	1D51F1	8559 556410	VALENTIN NIKITIN	{"phone": "+70234450445"}
0005434344797	7A65F7	3752 580592	NADEZHDA TROFIMOVA	{"email": "n.trofimova-23071973@postgrespro.ru", "phone": "+70612955173"}
0005434344798	46E763	4594 474779	EVGENIYA NIKITINA	{"email": "evgeniya.nikitina_1981@postgrespro.ru", "phone": "+70960744998"}
0005434344799	65FB9F	4663 814959	ALEKSEY PETROV	{"email": "apetrov.1978@postgrespro.ru", "phone": "+70920605316"}
0005434344800	65FB9F	0178 146747	VASILIY IVANOV	{"phone": "+70434546620"}
0005434344801	0F5186	6823 842357	ANNA SMIRNOVA	{"email": "anna-smirnova07051979@postgrespro.ru", "phone": "+70783958728"}
0005434344802	973FA5	6112 660630	NATALYA FOMINA	{"phone": "+70707631865"}
0005434344803	973FA5	8975 496135	VLADIMIR TARASOV	{"phone": "+70738564235"}
0005434344804	973FA5	8083 560662	NATALIYA NIKITINA	{"phone": "+70179837271"}
0005434344805	40C273	9662 803589	LYUBOV PETROVA	{"phone": "+70125613934"}
0005434344806	3971E5	6930 828255	ANNA KULIKOVA	{"email": "kulikova-a-11061974@postgrespro.ru", "phone": "+70641600421"}
0005434344807	3971E5	5943 451949	KRISTINA ZHURAVLEVA	{"phone": "+70556028601"}
0005434344808	3971E5	0346 099911	SEMEN ZAYCEV	{"email": "zaycev_semen.051961@postgrespro.ru", "phone": "+70947265978"}
0005434344809	4EB6F1	4378 656865	OLGA SEMENOVA	{"phone": "+70392396100"}
0005434344810	4EB6F1	0786 240370	DENIS BORISOV	{"phone": "+70704181595"}
0005434344811	5C5B0F	0362 862809	IRINA VLASOVA	{"email": "ivlasova1963@postgrespro.ru", "phone": "+70450802062"}
0005434344812	5C5B0F	9559 374376	NADEZHDA SMIRNOVA	{"phone": "+70390977813"}
0005434344813	337D62	5102 463776	ALEKSEY ILIN	{"phone": "+70253062225"}
0005434344814	0C17FB	4150 234012	SVETLANA GORBUNOVA	{"email": "sgorbunova-31051971@postgrespro.ru", "phone": "+70144687600"}
0005434344815	267539	3388 554840	OLEG ALEKSANDROV	{"email": "aleksandrov_o15071968@postgrespro.ru", "phone": "+70246589359"}
0005434344816	03D610	6633 617609	ARTEM SAVELEV	{"email": "artem-savelev_031974@postgrespro.ru", "phone": "+70203896878"}
0005434344817	03D610	2719 127300	STANISLAV FEDOROV	{"email": "stanislav_fedorov111977@postgrespro.ru", "phone": "+70783449460"}
0005434344818	3BEF1E	8421 010475	VALENTINA ILINA	{"phone": "+70349282124"}
0005434344819	3BEF1E	4611 120125	ALBINA NESTEROVA	{"email": "nesterova.albina1973@postgrespro.ru", "phone": "+70416136614"}
0005434344820	7025CD	4004 769031	MAKSIM SAVELEV	{"email": "maksim_savelev.1974@postgrespro.ru", "phone": "+70613078579"}
0005434344821	E41454	0036 957050	SERGEY KUZNECOV	{"email": "sergeykuznecov081979@postgrespro.ru", "phone": "+70045555624"}
0005434344822	E41454	5843 460416	VITALIY ANDREEV	{"email": "andreevvitaliy-04081965@postgrespro.ru", "phone": "+70342681215"}
0005434344823	E490DA	0732 273129	KSENIYA YAKOVLEVA	{"email": "kseniyayakovleva.1965@postgrespro.ru", "phone": "+70262297926"}
0005434344824	AE4F01	6785 406476	SVETLANA TIKHONOVA	{"email": "tikhonova.s1972@postgrespro.ru", "phone": "+70820579978"}
0005434344825	59BBB7	3097 389120	IGOR ALEKSANDROV	{"phone": "+70315867719"}
0005434344826	59BBB7	4976 332997	IRINA AFANASEVA	{"phone": "+70248147675"}
0005434344827	AB4685	2474 210337	ANDREY SERGEEV	{"phone": "+70104948533"}
0005434344828	0E5477	0915 428753	ELIZAVETA TARASOVA	{"phone": "+70114875046"}
0005434344829	114821	6769 164623	IVAN SEMENOV	{"email": "semenovi041973@postgrespro.ru", "phone": "+70009448550"}
0005434344830	0D0231	0570 006314	GALIYA KUZNECOVA	{"email": "galiyakuznecova.021987@postgrespro.ru", "phone": "+70515389011"}
0005434344831	CE078D	3739 549759	SVETLANA KRASNOVA	{"email": "krasnova-s-021980@postgrespro.ru", "phone": "+70877020657"}
0005434344832	0DB6D8	4389 591565	ANASTASIYA KRASNOVA	{"phone": "+70964655714"}
0005434344833	2495C4	8821 804325	ALENA MARTYNOVA	{"phone": "+70372580946"}
0005434344834	2495C4	6250 065507	MIKHAIL BARANOV	{"email": "mikhailbaranov111971@postgrespro.ru", "phone": "+70490438628"}
0005434344835	28D648	1615 723976	ANASTASIYA IVANOVA	{"phone": "+70367176010"}
0005434344836	28D648	0818 941493	LARISA PETROVA	{"phone": "+70268175450"}
0005434344837	28D648	0368 447077	NATALYA ANTONOVA	{"phone": "+70928036193"}
0005434344838	2519A2	4769 389174	DMITRIY NIKOLAEV	{"phone": "+70517850254"}
0005434344839	B733F1	7215 455475	EKATERINA VOLKOVA	{"email": "volkova_e-011975@postgrespro.ru", "phone": "+70185614731"}
0005434344840	BBE630	0675 341320	LYUDMILA NIKITINA	{"email": "nikitina.lyudmila_101974@postgrespro.ru", "phone": "+70541953577"}
0005434344841	FD182F	9147 268469	VALENTIN KAZAKOV	{"email": "valentin.kazakov.051980@postgrespro.ru", "phone": "+70542964798"}
0005434344842	DEB563	2350 521508	MAKSIM SOLOVEV	{"email": "maksim-solovev_011970@postgrespro.ru", "phone": "+70458897524"}
0005434344843	DEB563	9198 555686	SERGEY STEPANOV	{"phone": "+70807809949"}
0005434344844	DEB563	6339 100806	IVAN GORBUNOV	{"email": "gorbunov-i_1985@postgrespro.ru", "phone": "+70062062043"}
0005434344845	FD4E87	2863 952446	ZINAIDA NESTEROVA	{"email": "z-nesterova_1972@postgrespro.ru", "phone": "+70446761896"}
0005434344846	FD4E87	8372 307157	MARINA FEDOROVA	{"email": "m_fedorova.26061946@postgrespro.ru", "phone": "+70673885629"}
0005434344847	FD4E87	0420 898427	ALEKSANDRA KISELEVA	{"email": "kiseleva_a_081983@postgrespro.ru", "phone": "+70617074940"}
0005434344848	FBE54B	3699 364598	RUSLAN IVANOV	{"email": "rivanov.10081984@postgrespro.ru", "phone": "+70527884807"}
0005434344849	02CA52	7362 289010	SERGEY MEDVEDEV	{"email": "sergeymedvedev15011975@postgrespro.ru", "phone": "+70455291568"}
0005434344850	624B6D	5090 632860	MARIYA MIKHAYLOVA	{"phone": "+70776726718"}
0005434344851	49512D	0273 608256	ALLA POPOVA	{"phone": "+70052547316"}
0005434344852	FD6545	3327 271632	ALEKSANDR TIKHONOV	{"phone": "+70595594705"}
0005434344853	FD6545	3098 296109	GALINA FEDOROVA	{"phone": "+70783888452"}
0005434344854	E02399	6825 961383	RUSLAN KARPOV	{"email": "ruslan.karpov1966@postgrespro.ru", "phone": "+70831405762"}
0005434344855	9BDF94	2563 181904	IRINA FEDOROVA	{"email": "fedorova-i-04051978@postgrespro.ru", "phone": "+70547894107"}
0005434344856	6F75C5	1163 178180	TATYANA IVANOVA	{"email": "ivanova.tatyana.061982@postgrespro.ru", "phone": "+70497824288"}
0005434344857	26B1E0	2740 355524	OLEG KOZLOV	{"email": "kozlov_oleg-051979@postgrespro.ru", "phone": "+70489822539"}
0005434344858	26B1E0	6920 547350	MARIYA ANDREEVA	{"phone": "+70180396657"}
0005434344859	3F1F54	7745 198901	ALENA NESTEROVA	{"email": "nesterova.a.031985@postgrespro.ru", "phone": "+70292308570"}
0005434344860	91F7BD	1940 863213	ALEKSEY NIKITIN	{"email": "nikitin_a_121982@postgrespro.ru", "phone": "+70411983605"}
0005434344861	8D1EFE	2236 900789	VALENTINA STEPANOVA	{"email": "stepanovavalentina-1975@postgrespro.ru", "phone": "+70213128520"}
0005434344862	00C7B1	6263 167728	IGOR FEDOTOV	{"email": "fedotovigor_17031963@postgrespro.ru", "phone": "+70619768470"}
0005434344863	00C7B1	1818 973281	ELENA KOVALEVA	{"email": "ekovaleva_061976@postgrespro.ru", "phone": "+70037756676"}
0005434344864	986629	5584 405519	MAKSIM ROMANOV	{"email": "maksim.romanov.1974@postgrespro.ru", "phone": "+70779723703"}
0005434344865	986629	4915 846392	ALLA MAKAROVA	{"phone": "+70947601772"}
0005434344866	986629	2474 475102	NADEZHDA ROMANOVA	{"phone": "+70064037896"}
0005434344867	C96FDA	1025 615299	ALEKSANDR KISELEV	{"email": "aleksandrkiselev-031972@postgrespro.ru", "phone": "+70532547401"}
0005434344868	355271	2157 417860	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov-04121970@postgrespro.ru", "phone": "+70120098725"}
0005434344869	FCE61A	4544 502168	TATYANA BARANOVA	{"email": "tbaranova.14031974@postgrespro.ru", "phone": "+70394984220"}
0005434344870	29283A	8131 369355	IGOR DMITRIEV	{"phone": "+70925287147"}
0005434344871	29283A	5716 084288	VASILIY NIKITIN	{"phone": "+70884508202"}
0005434344872	ED0242	7116 036695	ALEKSANDR TIMOFEEV	{"phone": "+70059178571"}
0005434344873	B7FAE8	4885 466744	ALEKSANDR FOMIN	{"email": "fomin-a-1964@postgrespro.ru", "phone": "+70253976209"}
0005434344874	B7FAE8	6406 095862	YULIYA POPOVA	{"phone": "+70052987366"}
0005434344875	D27823	1860 218489	ALEKSANDR KUZNECOV	{"phone": "+70821830294"}
0005434344876	DBC951	0215 678976	VALENTINA MALYSHEVA	{"phone": "+70623647516"}
0005434344877	DBC951	7642 542127	VIKTOR MELNIKOV	{"phone": "+70905770006"}
0005434344878	ED5ABA	3403 843321	DAMIR KOROLEV	{"phone": "+70658630499"}
0005434344879	CBC530	7402 660445	LYUBOV ARKHIPOVA	{"phone": "+70583743835"}
0005434344880	145BCA	2402 238897	ALEKSANDR SCHERBAKOV	{"phone": "+70076545218"}
0005434344881	D8E593	7486 374842	POLINA MOROZOVA	{"email": "morozova.polina.29011972@postgrespro.ru", "phone": "+70872270276"}
0005434344882	D1A3A8	1010 005417	VADIM PAVLOV	{"phone": "+70475289633"}
0005434344883	D1A3A8	7171 578726	ANASTASIYA AFANASEVA	{"email": "anastasiyaafanaseva_1980@postgrespro.ru", "phone": "+70546784930"}
0005434344884	395A06	6172 441704	NADEZHDA FEDOROVA	{"email": "fedorovan1981@postgrespro.ru", "phone": "+70606618912"}
0005434344885	7B43FF	7592 038127	TATYANA EFIMOVA	{"phone": "+70325342043"}
0005434344886	A94856	0806 828925	DMITRIY KUZMIN	{"email": "kuzmindmitriy.1977@postgrespro.ru", "phone": "+70401955187"}
0005434344887	7D89FA	9709 705179	VALERIY GORBUNOV	{"email": "valeriy-gorbunov121978@postgrespro.ru", "phone": "+70702089580"}
0005434344888	7D89FA	1256 373039	IRINA ZAKHAROVA	{"email": "irinazakharova-111967@postgrespro.ru", "phone": "+70040817740"}
0005434344889	6F946C	2438 566743	MIKHAIL MATVEEV	{"email": "mikhailmatveev21061975@postgrespro.ru", "phone": "+70712504490"}
0005434344890	6F946C	7980 491429	VALENTINA GORBUNOVA	{"phone": "+70538661450"}
0005434344891	3B7007	1726 015720	IVAN ANDREEV	{"phone": "+70834079441"}
0005434344892	3B7007	1100 483004	YAROSLAV SCHERBAKOV	{"email": "scherbakov-y.111986@postgrespro.ru", "phone": "+70677405972"}
0005434344893	F6C3D8	9885 880609	VYACHESLAV STEPANOV	{"email": "v_stepanov13021966@postgrespro.ru", "phone": "+70199403680"}
0005434344894	EDE062	1257 161747	ANDREY TARASOV	{"email": "andrey_tarasov.15121976@postgrespro.ru", "phone": "+70052713019"}
0005434344895	EDE062	6292 916421	KLAVDIYA ROMANOVA	{"email": "romanova_k031973@postgrespro.ru", "phone": "+70923238472"}
0005434344896	EDE062	8591 279113	OKSANA BORISOVA	{"email": "oksana.borisova_1964@postgrespro.ru", "phone": "+70523607238"}
0005434344897	0F1A9B	2116 786987	MARINA ORLOVA	{"phone": "+70589679106"}
0005434344898	E3667B	4670 705173	YULIYA ZHURAVLEVA	{"email": "y.zhuravleva-061969@postgrespro.ru", "phone": "+70006366328"}
0005434344899	E3667B	2048 822154	LYUDMILA VASILEVA	{"phone": "+70528018812"}
0005434344900	2233A6	2657 241550	ALINA MAKAROVA	{"phone": "+70878549336"}
0005434344901	2233A6	5188 476688	ALEKSANDR KUZNECOV	{"email": "a-kuznecov30091981@postgrespro.ru", "phone": "+70037925054"}
0005434344902	5FC24D	1382 788097	ZULFIYA ZOTOVA	{"phone": "+70612043305"}
0005434344903	399226	7499 112978	IVAN KOZLOV	{"email": "ivan.kozlov_22031958@postgrespro.ru", "phone": "+70153046303"}
0005434344904	C0D5A9	1051 369753	KIRILL KARPOV	{"email": "kirillkarpov021972@postgrespro.ru", "phone": "+70263673527"}
0005434344905	C0D5A9	6206 913629	MARIYA TARASOVA	{"email": "mariya-tarasova-1974@postgrespro.ru", "phone": "+70573525722"}
0005434344906	D7E444	0980 922211	VIKTOR ANDREEV	{"email": "andreev.viktor-101976@postgrespro.ru", "phone": "+70936074056"}
0005434344907	034812	9083 611636	IRINA SIDOROVA	{"email": "i-sidorova-03111968@postgrespro.ru", "phone": "+70992427045"}
0005434344908	034812	5233 633371	ALEKSANDR POPOV	{"phone": "+70538321259"}
0005434344909	CBC70D	3285 066263	DZHAMILYA KONOVALOVA	{"email": "dzhamilya_konovalova_20031969@postgrespro.ru", "phone": "+70584051709"}
0005434344910	F3E923	5785 910873	SERGEY KUZMIN	{"phone": "+70996841320"}
0005434344911	F47098	8780 467568	ANTON MAKAROV	{"email": "makarov_anton-1965@postgrespro.ru", "phone": "+70096137491"}
0005434344912	BA7878	5114 650399	TATYANA NAUMOVA	{"email": "t_naumova-1968@postgrespro.ru", "phone": "+70065220656"}
0005434344913	BA7878	9641 742994	PETR TIKHONOV	{"phone": "+70862478543"}
0005434344914	199AE6	0604 664984	IVAN TARASOV	{"email": "tarasov-i_1976@postgrespro.ru", "phone": "+70197439948"}
0005434344915	199AE6	8781 576498	VALENTINA ROMANOVA	{"phone": "+70580402681"}
0005434344916	1F6E19	2106 670637	EVGENIYA NESTEROVA	{"email": "nesterova_e-121980@postgrespro.ru", "phone": "+70153536393"}
0005434344917	1F6E19	5060 676185	ANNA SOROKINA	{"phone": "+70641639597"}
0005434344918	1F6E19	6752 411088	VIKTOR MELNIKOV	{"phone": "+70748518247"}
0005434344919	099231	0628 914902	ELENA SEMENOVA	{"phone": "+70407919971"}
0005434344920	099231	9221 161531	ANATOLIY IVANOV	{"email": "aivanov.21081971@postgrespro.ru", "phone": "+70086476073"}
0005434344921	099231	0662 596917	ALEKSANDR EGOROV	{"email": "egorovaleksandr.1962@postgrespro.ru", "phone": "+70441767957"}
0005434344922	099231	9252 599166	ANATOLIY KOROLEV	{"email": "anatoliykorolev.071973@postgrespro.ru", "phone": "+70958738546"}
0005434344923	CE57D9	2371 637124	ALEKSEY TIKHONOV	{"phone": "+70707012184"}
0005434344924	9BAFD2	9736 488804	NIKOLAY MAKSIMOV	{"phone": "+70599179438"}
0005434344925	9BAFD2	0267 693634	VARVARA YUDINA	{"email": "v-yudina071967@postgrespro.ru", "phone": "+70032141374"}
0005434344926	9BAFD2	2600 428519	ALLA IVANOVA	{"phone": "+70816080554"}
0005434344927	DC492D	9546 722125	ANNA TARASOVA	{"phone": "+70526674478"}
0005434344928	632782	5919 813405	DENIS ANDREEV	{"email": "andreev.denis.04051974@postgrespro.ru", "phone": "+70467441255"}
0005434344929	570126	2987 820786	NIKITA KOZLOV	{"email": "kozlov.n_061975@postgrespro.ru", "phone": "+70157097856"}
0005434344930	90C028	8006 167740	NADEZHDA IVANOVA	{"email": "n.ivanova_1982@postgrespro.ru", "phone": "+70220262877"}
0005434344931	90C028	2469 681680	LYUBOV GORBUNOVA	{"phone": "+70016613555"}
0005434344932	9D6592	5597 180462	TAMARA NIKIFOROVA	{"phone": "+70699795916"}
0005434344933	9D6592	4980 165146	LYUBOV CHERNOVA	{"email": "chernova.l-09021982@postgrespro.ru", "phone": "+70159452306"}
0005434344934	ABA1AD	9566 921538	EVGENIY NIKITIN	{"email": "evgeniy.nikitin.19011983@postgrespro.ru", "phone": "+70453385412"}
0005434344935	ABA1AD	7702 995720	NATALYA SOKOLOVA	{"email": "n.sokolova_02081978@postgrespro.ru", "phone": "+70392808179"}
0005434344936	A7A407	7942 667845	OLEG MAKAROV	{"phone": "+70052897715"}
0005434344937	F77F93	7247 395891	GENNADIY GUSEV	{"email": "gusevgennadiy-091964@postgrespro.ru", "phone": "+70944189695"}
0005434344938	F77F93	6745 535531	ANTON KONOVALOV	{"email": "konovalov-anton121961@postgrespro.ru", "phone": "+70828852742"}
0005434344939	E5D4FA	3852 517692	DMITRIY IVANOV	{"email": "dmitriyivanov_22011974@postgrespro.ru", "phone": "+70795813783"}
0005434344940	E58D6D	4836 505356	GENNADIY MIKHAYLOV	{"phone": "+70830354694"}
0005434344941	911D1B	1484 930972	VIKTORIYA GUSEVA	{"email": "viktoriya.guseva.1973@postgrespro.ru", "phone": "+70410042842"}
0005434344942	911D1B	5927 607135	TATYANA GRISHINA	{"email": "tgrishina-02111975@postgrespro.ru", "phone": "+70035250351"}
0005434344943	0E0C1D	5910 538389	VIKTOR MIKHAYLOV	{"email": "mikhaylov.viktor081975@postgrespro.ru", "phone": "+70389141526"}
0005434344944	0E0C1D	1460 988803	ELENA NOVIKOVA	{"phone": "+70399365595"}
0005434344945	0BA69C	2312 920873	NIKOLAY VASILEV	{"phone": "+70920008480"}
0005434344946	4D1B0B	5022 831006	ANASTASIYA ZAKHAROVA	{"email": "a_zakharova-12021967@postgrespro.ru", "phone": "+70266407088"}
0005434344947	7A1E6C	4596 003359	ANNA MEDVEDEVA	{"email": "amedvedeva_1969@postgrespro.ru", "phone": "+70023974811"}
0005434344948	7A1E6C	4133 511591	TATYANA VOLKOVA	{"phone": "+70002365642"}
0005434344949	2CD740	3527 728692	DENIS SCHERBAKOV	{"email": "denisscherbakov_061965@postgrespro.ru", "phone": "+70256222287"}
0005434344950	52E36C	3154 691336	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov-1982@postgrespro.ru", "phone": "+70532006081"}
0005434344951	52E36C	1679 021585	NADEZHDA MAKSIMOVA	{"email": "n.maksimova111970@postgrespro.ru", "phone": "+70887934596"}
0005434344952	8A4EBA	5768 161578	SERGEY PETROV	{"email": "petrov.sergey15051965@postgrespro.ru", "phone": "+70981921089"}
0005434344953	D18AF7	1028 848460	ROZA MATVEEVA	{"email": "matveeva-roza_071975@postgrespro.ru", "phone": "+70689392322"}
0005434344954	D18AF7	0406 255377	MIKHAIL VASILEV	{"email": "vasilev.mikhail.1977@postgrespro.ru", "phone": "+70674310037"}
0005434344955	D18AF7	8857 303520	MIKHAIL KUZNECOV	{"phone": "+70201404048"}
0005434344956	BEA073	4659 699919	ILYA MARTYNOV	{"email": "martynov.ilya-10101973@postgrespro.ru", "phone": "+70859876819"}
0005434344957	45A8ED	3340 002882	NINA VASILEVA	{"email": "nina_vasileva_30011989@postgrespro.ru", "phone": "+70053681633"}
0005434344958	1968DF	4012 584918	MARIYA KAZAKOVA	{"email": "m-kazakova_11061971@postgrespro.ru", "phone": "+70114356875"}
0005434344959	FCA596	1604 857475	VIKTOR KOROLEV	{"email": "korolev-v11011971@postgrespro.ru", "phone": "+70288351079"}
0005434344960	FCA596	5855 590099	ANASTASIYA TROFIMOVA	{"phone": "+70458065235"}
0005434344961	733775	1670 662417	LIDIYA STEPANOVA	{"email": "lidiyastepanova.101971@postgrespro.ru", "phone": "+70502271705"}
0005434344962	596BA7	4815 538365	EVGENIY ALEKSANDROV	{"phone": "+70535564420"}
0005434344963	596BA7	3317 896272	ALEVTINA ERMAKOVA	{"phone": "+70234710152"}
0005434344964	1F28F2	3770 333017	GEORGIY SCHERBAKOV	{"email": "g_scherbakov_1987@postgrespro.ru", "phone": "+70464481410"}
0005434344965	1F28F2	4693 380438	IRINA MATVEEVA	{"email": "i_matveeva26021958@postgrespro.ru", "phone": "+70182573044"}
0005434344966	1F28F2	9081 012791	IVAN BELOV	{"phone": "+70638709414"}
0005434344967	18B6A9	0312 784785	LYUDMILA KOMAROVA	{"email": "l-komarova-1977@postgrespro.ru", "phone": "+70711936755"}
0005434344968	18B6A9	5138 042465	VITALIY ZHURAVLEV	{"email": "v_zhuravlev-1971@postgrespro.ru", "phone": "+70479989295"}
0005434344969	B26E47	0835 208541	IRINA MAKAROVA	{"phone": "+70173962881"}
0005434344970	B38FFE	6999 785875	ANNA OSIPOVA	{"phone": "+70654741829"}
0005434344971	B38FFE	1556 357982	VALENTIN GUSEV	{"email": "valentin_gusev011979@postgrespro.ru", "phone": "+70663873080"}
0005434344972	861268	4446 811125	VADIM OSIPOV	{"email": "vadim-osipov_1970@postgrespro.ru", "phone": "+70452797678"}
0005434344973	AB59FC	2231 682050	OLGA VASILEVA	{"phone": "+70819832031"}
0005434344974	AB59FC	2982 741817	MIKHAIL MATVEEV	{"phone": "+70333560665"}
0005434344975	E6F103	7209 346054	VALERIY RODIONOV	{"email": "v.rodionov1969@postgrespro.ru", "phone": "+70096300217"}
0005434344976	E6F103	3963 675191	ROMAN SCHERBAKOV	{"email": "roman.scherbakov_1974@postgrespro.ru", "phone": "+70313570958"}
0005434344977	1B9848	1865 448693	LARISA NAUMOVA	{"phone": "+70540697538"}
0005434344978	B02559	0782 007950	ELENA MAKAROVA	{"phone": "+70138737596"}
0005434344979	B02559	9958 600537	ALBINA STEPANOVA	{"email": "stepanova-a.1977@postgrespro.ru", "phone": "+70483033202"}
0005434344980	00150A	3273 863872	IGOR OSIPOV	{"email": "osipov.igor061970@postgrespro.ru", "phone": "+70973210456"}
0005434344981	13A515	0464 278960	VLADIMIR NIKOLAEV	{"phone": "+70282838297"}
0005434344982	AB8F1E	5988 444841	REGINA VLASOVA	{"phone": "+70038398031"}
0005434344983	AB8F1E	6333 905056	DMITRIY VASILEV	{"email": "vasilev_d111959@postgrespro.ru", "phone": "+70237014039"}
0005434344984	AB8F1E	3224 016451	ANDREY GORBUNOV	{"email": "andrey_gorbunov031979@postgrespro.ru", "phone": "+70728554721"}
0005434344985	18B446	2198 296594	VALENTINA GAVRILOVA	{"email": "vgavrilova.051973@postgrespro.ru", "phone": "+70983867556"}
0005434344986	30B125	9522 094974	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova_27021978@postgrespro.ru", "phone": "+70207268137"}
0005434344987	979E39	1548 159629	SERGEY SEMENOV	{"email": "semenov.s.091970@postgrespro.ru", "phone": "+70937924811"}
0005434344988	979E39	2531 827098	VALENTINA ROMANOVA	{"phone": "+70396360183"}
0005434344989	FF7DAA	9337 632929	YULIYA IVANOVA	{"email": "ivanova_yuliya1969@postgrespro.ru", "phone": "+70841387958"}
0005434344990	FF7DAA	2419 851544	YULIYA TARASOVA	{"phone": "+70553932593"}
0005434344991	FF7DAA	9073 436491	TAMARA BELOVA	{"phone": "+70443114477"}
0005434344992	30BCB5	3599 296071	EKATERINA SOKOLOVA	{"email": "ekaterina.sokolova.1977@postgrespro.ru", "phone": "+70582109020"}
0005434344993	7E7325	3229 691784	IGOR SOLOVEV	{"email": "solovev_i_1978@postgrespro.ru", "phone": "+70153883399"}
0005434344994	DB9890	2888 947734	BORIS ALEKSANDROV	{"phone": "+70586860269"}
0005434344995	950C23	5551 116599	SERGEY VOROBEV	{"email": "vorobev.sergey1966@postgrespro.ru", "phone": "+70078080533"}
0005434344996	8199E4	4722 466436	IVAN PETROV	{"email": "petrov.ivan19091980@postgrespro.ru", "phone": "+70785093413"}
0005434344997	A75FEB	0985 840323	ZINAIDA IVANOVA	{"email": "z_ivanova-051985@postgrespro.ru", "phone": "+70877192088"}
0005434344998	C32547	4130 005560	PETR POPOV	{"phone": "+70539381526"}
0005434344999	C32547	4346 157682	ALEKSANDR ZAYCEV	{"phone": "+70088875870"}
0005434345000	4F92EE	3704 870562	VIKTOR MAKAROV	{"phone": "+70430533045"}
0005434345001	03AFDE	4450 454539	NATALYA TARASOVA	{"email": "tarasova_n-24091968@postgrespro.ru", "phone": "+70043017581"}
0005434345002	03AFDE	9838 339587	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov-31011974@postgrespro.ru", "phone": "+70561106271"}
0005434345003	880B7B	4195 944808	YURIY BONDARENKO	{"email": "bondarenko_yuriy-071979@postgrespro.ru", "phone": "+70495237061"}
0005434345004	582B95	6990 149578	OKSANA KOROLEVA	{"email": "oksana.koroleva_1966@postgrespro.ru", "phone": "+70522214040"}
0005434345005	AAB21C	5532 157377	VLADIMIR NIKITIN	{"email": "v.nikitin.111975@postgrespro.ru", "phone": "+70171964454"}
0005434345006	AAB21C	5924 924181	VIKTOR DAVYDOV	{"phone": "+70220390487"}
0005434345007	A4361E	6209 845925	TATYANA TARASOVA	{"phone": "+70196420230"}
0005434345008	FD60D0	9838 921678	VLADIMIR FOMIN	{"email": "fominvladimir_28011977@postgrespro.ru", "phone": "+70531304908"}
0005434345009	567197	8329 845552	VALERIY NIKITIN	{"phone": "+70827891281"}
0005434345010	DA4ECC	0707 888697	VLADIMIR NAUMOV	{"phone": "+70867216019"}
0005434345011	65617E	6893 556727	YULIYA DANILOVA	{"email": "yuliya-danilova.1977@postgrespro.ru", "phone": "+70771282609"}
0005434345012	F7DA53	4700 237187	ANASTASIYA FROLOVA	{"phone": "+70223634469"}
0005434345013	F7DA53	4483 550718	ZLATA GERASIMOVA	{"phone": "+70543327105"}
0005434345014	CBE2FB	4114 926892	MAKSIM PETROV	{"email": "m-petrov.081966@postgrespro.ru", "phone": "+70700285643"}
0005434345015	186374	7309 071646	DMITRIY YAKOVLEV	{"email": "yakovlev.d-1974@postgrespro.ru", "phone": "+70957976320"}
0005434345016	186374	3393 839208	VALERIY ANTONOV	{"phone": "+70537820596"}
0005434345017	A938DA	9932 114723	NIKOLAY TARASOV	{"email": "tarasovn.071967@postgrespro.ru", "phone": "+70693709980"}
0005434345018	A938DA	3435 019440	KSENIYA FEDOROVA	{"phone": "+70516714465"}
0005434345019	2A9348	0219 032550	YULIYA KONOVALOVA	{"phone": "+70648752111"}
0005434345020	EE08AE	4274 407292	ALEKSEY PAVLOV	{"email": "a-pavlov1969@postgrespro.ru", "phone": "+70521157648"}
0005434345021	EE08AE	0168 250784	ALEFTINA POPOVA	{"email": "popovaaleftina_1962@postgrespro.ru", "phone": "+70858480859"}
0005434345022	BE382A	6430 198562	OLEG ZAYCEV	{"phone": "+70778685031"}
0005434345023	BE382A	3768 630296	INNA LEBEDEVA	{"phone": "+70320647397"}
0005434345024	8B7A2E	6339 246966	IGOR ANDREEV	{"email": "i.andreev-25111964@postgrespro.ru", "phone": "+70157091999"}
0005434345025	8B7A2E	8759 437752	ZOYA DAVYDOVA	{"phone": "+70398768365"}
0005434345026	8229C1	2041 786896	SERGEY MOISEEV	{"email": "moiseevsergey-21111960@postgrespro.ru", "phone": "+70076212974"}
0005434345027	236E96	1137 288206	GALINA FROLOVA	{"phone": "+70411096692"}
0005434345028	236E96	3856 299352	LIDIYA ISAEVA	{"email": "l.isaeva-1985@postgrespro.ru", "phone": "+70537138429"}
0005434345029	5DD8D6	0539 228907	VERA ILINA	{"email": "vilina-121966@postgrespro.ru", "phone": "+70926264313"}
0005434345030	7C5DE2	4721 834546	ANASTASIYA ANDREEVA	{"phone": "+70449543203"}
0005434345031	C7C74C	0005 870605	PAVEL POPOV	{"email": "p.popov18061967@postgrespro.ru", "phone": "+70797618074"}
0005434345032	899601	6088 766544	PAVEL ISAEV	{"phone": "+70596329615"}
0005434345033	FB09A8	3200 889127	OLGA YUDINA	{"email": "yudina_olga.31031967@postgrespro.ru", "phone": "+70259087530"}
0005434345034	C36ACC	4612 029770	SVETLANA NESTEROVA	{"email": "nesterova-svetlana_091976@postgrespro.ru", "phone": "+70366210911"}
0005434345035	C36ACC	3532 971972	DMITRIY NAZAROV	{"phone": "+70658559083"}
0005434345036	15F44C	1118 330063	EKATERINA KRASNOVA	{"email": "e_krasnova_26051965@postgrespro.ru", "phone": "+70985205451"}
0005434345037	15F44C	2281 336140	TAMARA NOVIKOVA	{"email": "novikovatamara.1969@postgrespro.ru", "phone": "+70738780131"}
0005434345038	BB8009	6049 706014	EKATERINA FADEEVA	{"phone": "+70594885292"}
0005434345039	9A7B8C	1411 592670	NIKOLAY NIKOLAEV	{"phone": "+70243937418"}
0005434345040	9A7B8C	6511 363937	ALEKSANDR BORISOV	{"email": "aborisov-1982@postgrespro.ru", "phone": "+70036649659"}
0005434345041	9A7B8C	0735 769630	TATYANA OVCHINNIKOVA	{"phone": "+70257735784"}
0005434345042	7FC1A3	9340 054161	ALEKSANDR NIKITIN	{"phone": "+70497350902"}
0005434345043	7FC1A3	8910 349981	DARYA ILINA	{"email": "ilina_darya.21071974@postgrespro.ru", "phone": "+70088593315"}
0005434345044	658372	3078 673580	POLINA ORLOVA	{"email": "orlova-polina-1965@postgrespro.ru", "phone": "+70859757788"}
0005434345045	658372	2347 185940	VLADIMIR PETROV	{"phone": "+70556532024"}
0005434345046	DC9C4E	4036 577939	ANDREY KONOVALOV	{"email": "andreykonovalov_111977@postgrespro.ru", "phone": "+70280243119"}
0005434345047	DC9C4E	2187 790114	ALEKSANDR ANTONOV	{"phone": "+70092605233"}
0005434345048	48A8B7	8677 972703	ANTON GUSEV	{"phone": "+70719266533"}
0005434345049	9AEAD3	0820 475591	VLADIMIR NIKOLAEV	{"phone": "+70673250498"}
0005434345050	B6666B	9571 168093	RUSTEM GUSEV	{"phone": "+70823549208"}
0005434345051	A5AFA5	0500 974025	LYUDMILA ALEKSANDROVA	{"phone": "+70209487605"}
0005434345052	50550F	3461 384017	NIKITA TIKHONOV	{"phone": "+70873257987"}
0005434345053	AAE32E	1078 797515	SERGEY KUZNECOV	{"phone": "+70918431927"}
0005434345054	B7AC00	9183 326792	OLGA IVANOVA	{"phone": "+70270628328"}
0005434345055	06A22F	5781 030285	ANASTASIYA SCHERBAKOVA	{"email": "scherbakova_a_17031974@postgrespro.ru", "phone": "+70682863549"}
0005434345056	150087	7904 346290	OLGA GUSEVA	{"email": "oguseva-1966@postgrespro.ru", "phone": "+70333784715"}
0005434345057	CA059B	9971 831991	IRINA KUZMINA	{"email": "irina_kuzmina_1964@postgrespro.ru", "phone": "+70253587601"}
0005434345058	DF75C9	3748 419133	ELENA IVANOVA	{"phone": "+70622397597"}
0005434345059	9E11A1	1585 160498	ELENA PAVLOVA	{"email": "pavlova_e.1967@postgrespro.ru", "phone": "+70152544747"}
0005434345060	9E11A1	1554 146640	SERGEY GAVRILOV	{"email": "s.gavrilov-1982@postgrespro.ru", "phone": "+70150785356"}
0005434345061	16CFC3	5097 234708	ZINAIDA SAVELEVA	{"phone": "+70303213730"}
0005434345062	16CFC3	2168 146689	MARIYA KONOVALOVA	{"phone": "+70905732935"}
0005434345063	751F3A	6786 527036	FANIL MOROZOV	{"email": "morozovfanil071970@postgrespro.ru", "phone": "+70391290460"}
0005434345064	0A96DC	8226 840568	MARGARITA SERGEEVA	{"email": "sergeevamargarita.1975@postgrespro.ru", "phone": "+70641666724"}
0005434345065	A8F8D1	8404 565944	ELENA KUZMINA	{"email": "kuzmina_e-091976@postgrespro.ru", "phone": "+70883166951"}
0005434345066	A8F8D1	0671 855975	NADEZHDA PETROVA	{"phone": "+70030649888"}
0005434345067	650E10	1361 886001	ANNA LEBEDEVA	{"email": "lebedeva.anna_1986@postgrespro.ru", "phone": "+70177244901"}
0005434345068	650E10	4479 565393	VASILIY FEDOTOV	{"email": "vasiliy-fedotov_031985@postgrespro.ru", "phone": "+70666469692"}
0005434345069	30EEC6	3242 961379	TIMUR NIKITIN	{"phone": "+70822291206"}
0005434345070	30EEC6	9923 453281	SERGEY ANDREEV	{"email": "andreev-sergey_16021963@postgrespro.ru", "phone": "+70427168330"}
0005434345071	16B248	4990 497744	NAIL NAZAROV	{"email": "nazarovn081970@postgrespro.ru", "phone": "+70896514723"}
0005434345072	B56C76	2447 590645	ANDREY ZAYCEV	{"phone": "+70599923942"}
0005434345073	900355	4052 593954	LYUDMILA SIDOROVA	{"email": "lyudmilasidorova-22061969@postgrespro.ru", "phone": "+70761532137"}
0005434345074	900355	6050 441557	VLADIMIR POPOV	{"phone": "+70566091615"}
0005434345075	2BDD37	8604 957298	YULIYA FEDOROVA	{"email": "fedorova-y17031982@postgrespro.ru", "phone": "+70610041218"}
0005434345076	857F54	0906 605760	VLADIMIR NAUMOV	{"email": "naumov_v_041963@postgrespro.ru", "phone": "+70790823490"}
0005434345077	857F54	3529 708349	TAMARA GUSEVA	{"phone": "+70131479193"}
0005434345078	A4C43C	1242 051704	YULIYA KOROLEVA	{"phone": "+70031882941"}
0005434345079	6C457B	1148 518036	VALENTINA MIRONOVA	{"phone": "+70763806373"}
0005434345080	2A3A3C	7203 922875	YURIY STEPANOV	{"phone": "+70480307861"}
0005434345081	2CF372	6144 635871	VERA TIKHONOVA	{"email": "vera_tikhonova.081977@postgrespro.ru", "phone": "+70492748995"}
0005434345082	2CF372	4652 496204	NAILYA BOGDANOVA	{"phone": "+70723698565"}
0005434345083	6F0E55	2085 848595	VITALIY MIKHAYLOV	{"email": "vitaliy.mikhaylov.30071969@postgrespro.ru", "phone": "+70215061066"}
0005434345084	446FF1	9272 489306	ALFIYA DMITRIEVA	{"email": "alfiyadmitrieva_021971@postgrespro.ru", "phone": "+70994177727"}
0005434345085	85328F	1920 920980	ALENA SAVELEVA	{"email": "alenasaveleva_1968@postgrespro.ru", "phone": "+70553609384"}
0005434345086	85328F	7803 646098	ALIK GORBUNOV	{"email": "gorbunov-a_1974@postgrespro.ru", "phone": "+70389347522"}
0005434345087	FF3974	7135 021653	ELENA ROMANOVA	{"email": "romanova_elena-1961@postgrespro.ru", "phone": "+70101757234"}
0005434345088	FF3974	3156 870351	TATYANA IVANOVA	{"phone": "+70151333129"}
0005434345089	1ED2D6	4212 256640	OLGA GAVRILOVA	{"email": "gavrilova_olga_1961@postgrespro.ru", "phone": "+70085275911"}
0005434345090	A3E69C	6296 501560	GALINA EGOROVA	{"email": "egorova_g_1976@postgrespro.ru", "phone": "+70009701760"}
0005434345091	A3E69C	2872 405145	NIKOLAY SEMENOV	{"email": "n-semenov_11041969@postgrespro.ru", "phone": "+70987616165"}
0005434345092	ECEC57	9441 545569	ARINA IVANOVA	{"phone": "+70910830515"}
0005434345093	ECEC57	0264 438798	ELENA ZOTOVA	{"phone": "+70774476954"}
0005434345094	28CC28	6758 904444	EDUARD ZAKHAROV	{"email": "zakharov_eduard_22121970@postgrespro.ru", "phone": "+70906017764"}
0005434345095	8F3A93	6736 592427	DMITRIY SOROKIN	{"phone": "+70345051297"}
0005434345096	C62A64	2282 896451	SERGEY PAVLOV	{"email": "sergey_pavlov1972@postgrespro.ru", "phone": "+70005928286"}
0005434345097	C62A64	2048 871133	VLADIMIR MOROZOV	{"email": "vladimir-morozov_1981@postgrespro.ru", "phone": "+70191085836"}
0005434345098	C62A64	5779 246464	TATYANA MAKAROVA	{"phone": "+70926358529"}
0005434345099	FB0734	8812 120953	ARTUR PAVLOV	{"email": "a.pavlov1967@postgrespro.ru", "phone": "+70607221135"}
0005434345100	9A70C0	4817 453928	ELENA PETROVA	{"email": "petrova_e-021974@postgrespro.ru", "phone": "+70205690861"}
0005434345101	9A70C0	7865 508405	VALERIY SCHERBAKOV	{"phone": "+70629908928"}
0005434345102	A85E50	0791 036970	NATALYA NAUMOVA	{"phone": "+70130866110"}
0005434345103	13C88A	1045 146564	GENNADIY KRASNOV	{"email": "krasnov_gennadiy_111969@postgrespro.ru", "phone": "+70448655791"}
0005434345104	13C88A	1135 478091	VALENTINA POPOVA	{"email": "popova_valentina_021966@postgrespro.ru", "phone": "+70355144317"}
0005434345105	F14074	0751 582081	NINA MOISEEVA	{"email": "moiseevanina_1969@postgrespro.ru", "phone": "+70478975872"}
0005434345106	B77CE0	9371 821296	ALEKSEY YAKOVLEV	{"phone": "+70700464040"}
0005434345107	243B2C	4060 951149	IRINA KAZAKOVA	{"email": "i.kazakova15051979@postgrespro.ru", "phone": "+70783750947"}
0005434345108	1FC7CE	7134 325891	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov_06041979@postgrespro.ru", "phone": "+70533652569"}
0005434345109	7F4BD3	9322 067633	VIKTOR GERASIMOV	{"phone": "+70379235622"}
0005434345110	48061B	8761 485163	YURIY KOROLEV	{"phone": "+70158400543"}
0005434345111	0A3A44	4246 664429	GALINA KAZAKOVA	{"phone": "+70303754593"}
0005434345112	BCA362	6455 979691	OLEG KUZNECOV	{"phone": "+70862719641"}
0005434345113	9537C9	5361 743811	OLGA POLYAKOVA	{"email": "polyakovaolga_09041968@postgrespro.ru", "phone": "+70434612819"}
0005434345114	9537C9	6769 487330	VIKTOR KOZLOV	{"email": "viktor-kozlov_111976@postgrespro.ru", "phone": "+70364854720"}
0005434345115	EADB4C	5140 444387	NATALYA ANDREEVA	{"phone": "+70603295684"}
0005434345116	EADB4C	8780 554519	VALENTINA KISELEVA	{"email": "valentina-kiseleva.091976@postgrespro.ru", "phone": "+70833919335"}
0005434345117	CFF28E	6793 303890	NIKOLAY TIKHONOV	{"email": "tikhonov-n_091964@postgrespro.ru", "phone": "+70153341767"}
0005434345118	EE0B1C	0337 804595	VLADIMIR STEPANOV	{"phone": "+70926362244"}
0005434345119	0297C7	9828 208357	VIKTOR ILIN	{"email": "ilin-viktor15041974@postgrespro.ru", "phone": "+70863777116"}
0005434345120	89FD8A	5894 088724	MARGARITA MIKHAYLOVA	{"phone": "+70186628357"}
0005434345121	5E5204	9128 434177	SERGEY DMITRIEV	{"phone": "+70106530584"}
0005434345122	3F89BC	1787 951201	SERGEY ANDREEV	{"phone": "+70616649736"}
0005434345123	0FD493	2671 774487	ALEKSEY DENISOV	{"phone": "+70181823148"}
0005434345124	A7FD56	6778 855154	ALEKSANDR FEDOTOV	{"phone": "+70940317209"}
0005434345125	A7FD56	6365 795747	ALEKSANDR IVANOV	{"email": "ivanov_a.29081971@postgrespro.ru", "phone": "+70615361654"}
0005434345126	43C331	7025 609944	MIKHAIL ALEKSEEV	{"email": "alekseev-mikhail081971@postgrespro.ru", "phone": "+70055744622"}
0005434345127	8C0ECD	0592 161306	SERGEY ZAYCEV	{"phone": "+70524952639"}
0005434345128	353F39	5474 561754	TAMARA KOZLOVA	{"email": "kozlova_t1987@postgrespro.ru", "phone": "+70774638721"}
0005434345129	7ABB28	3839 040261	ILYA SOROKIN	{"phone": "+70517438096"}
0005434345130	5E6995	9319 431336	ELIZAVETA MIKHAYLOVA	{"email": "mikhaylova.elizaveta-18101965@postgrespro.ru", "phone": "+70643375513"}
0005434345131	55F18A	2797 271818	EVGENIY SEMENOV	{"email": "evgeniysemenov_1971@postgrespro.ru", "phone": "+70353083239"}
0005434345132	55F18A	5565 506803	ALEKSANDR AFANASEV	{"phone": "+70575845673"}
0005434345133	64BDFC	2547 467293	ALEKSANDR POPOV	{"email": "aleksandr.popov04101967@postgrespro.ru", "phone": "+70157648497"}
0005434345134	B2DD75	6484 246263	RAMIL KARPOV	{"phone": "+70662672161"}
0005434345135	B2DD75	3118 465339	VARVARA SCHERBAKOVA	{"email": "scherbakova.varvara.1967@postgrespro.ru", "phone": "+70832653861"}
0005434345136	B2DD75	4529 987540	ELENA MATVEEVA	{"email": "elenamatveeva.1976@postgrespro.ru", "phone": "+70268999098"}
0005434345137	9CB277	6537 726432	ANNA VOROBEVA	{"email": "vorobeva.a-071976@postgrespro.ru", "phone": "+70413616997"}
0005434345138	91A586	8554 759465	ALEKSEY MAKAROV	{"email": "makarov.aleksey.09021985@postgrespro.ru", "phone": "+70811570127"}
0005434345139	91A586	6988 732996	ANDREY IVANOV	{"phone": "+70902313765"}
0005434345140	D55798	3281 009186	REGINA FROLOVA	{"email": "frolova_regina1969@postgrespro.ru", "phone": "+70094358312"}
0005434345141	60DB06	5142 112971	SERGEY KUZNECOV	{"phone": "+70560285604"}
0005434345142	60DB06	9362 070432	ROMAN NIKOLAEV	{"phone": "+70988218702"}
0005434345143	F2DEA3	9979 734321	TATYANA NESTEROVA	{"email": "nesterova_tatyana28101961@postgrespro.ru", "phone": "+70431877909"}
0005434345144	F2DEA3	8333 026466	VASILIY PAVLOV	{"phone": "+70187527511"}
0005434345145	DFDB28	2487 919419	VIKTOR ALEKSANDROV	{"phone": "+70621850680"}
0005434345146	F937BA	8060 399393	NADEZHDA BELYAEVA	{"phone": "+70600019387"}
0005434345147	371E74	1701 483719	ALEKSANDR ANTONOV	{"phone": "+70651319031"}
0005434345148	48F9F3	9240 766571	NATALYA ANTONOVA	{"email": "natalya_antonova-12121962@postgrespro.ru", "phone": "+70409523135"}
0005434345149	FBFF7E	9710 098922	NINA GAVRILOVA	{"phone": "+70968888607"}
0005434345150	FBFF7E	6749 526115	ANNA GORBUNOVA	{"phone": "+70031142088"}
0005434345151	7997F9	3999 279522	LYUDMILA EFIMOVA	{"email": "efimova_l-1969@postgrespro.ru", "phone": "+70792239525"}
0005434345152	7997F9	0224 664049	LYUDMILA IVANOVA	{"email": "lyudmila-ivanova15101984@postgrespro.ru", "phone": "+70549970329"}
0005434345153	E80FE5	9708 034395	ANATOLIY NIKOLAEV	{"email": "nikolaev_anatoliy_1970@postgrespro.ru", "phone": "+70631813235"}
0005434345154	CED827	3160 494292	IRINA GAVRILOVA	{"email": "igavrilova_021968@postgrespro.ru", "phone": "+70472082442"}
0005434345155	F98A75	0455 802911	NINA KOMAROVA	{"email": "n-komarova1972@postgrespro.ru", "phone": "+70344318186"}
0005434345156	08459F	0686 235212	ALENA CHERNOVA	{"email": "a-chernova.1971@postgrespro.ru", "phone": "+70364674450"}
0005434345157	9D7D3B	2455 916519	GENNADIY PAVLOV	{"email": "pavlov-g_1969@postgrespro.ru", "phone": "+70875653129"}
0005434345158	1AB458	4319 230658	SERGEY IVANOV	{"phone": "+70162460419"}
0005434345159	FC17F4	3336 485553	ELIZAVETA IVANOVA	{"phone": "+70622381244"}
0005434345160	478768	1408 627085	YULIYA ISAEVA	{"phone": "+70392891314"}
0005434345161	478768	4846 479521	VIKTORIYA SOLOVEVA	{"phone": "+70043756183"}
0005434345162	17E20D	7806 263066	VALENTIN ALEKSEEV	{"phone": "+70927342092"}
0005434345163	28FA15	0925 990222	VASILIY EGOROV	{"email": "vasiliyegorov071962@postgrespro.ru", "phone": "+70846636484"}
0005434345164	38E659	3394 760173	YULIYA IVANOVA	{"email": "ivanovay-1970@postgrespro.ru", "phone": "+70813355686"}
0005434345165	77FC05	8371 258980	TATYANA BOGDANOVA	{"email": "bogdanova.t-031973@postgrespro.ru", "phone": "+70168236743"}
0005434345166	77FC05	3642 871854	YURIY TIMOFEEV	{"email": "y-timofeev-121977@postgrespro.ru", "phone": "+70532771032"}
0005434345167	5CE8B9	4679 996511	EKATERINA MOISEEVA	{"phone": "+70183319986"}
0005434345168	E1E5BA	1519 921785	NATALIYA ROMANOVA	{"phone": "+70897160709"}
0005434345169	7618BD	0809 290777	NINA AKIMOVA	{"email": "n.akimova.04121978@postgrespro.ru", "phone": "+70871931358"}
0005434345170	7EB19F	4302 132885	MARIYA TROFIMOVA	{"phone": "+70896814105"}
0005434345171	647D46	1640 328164	VLADIMIR MOROZOV	{"email": "vladimirmorozov_1979@postgrespro.ru", "phone": "+70239224634"}
0005434345172	06E62B	8610 709877	SERGEY ABRAMOV	{"phone": "+70702455067"}
0005434345173	06E62B	5256 251001	YULIYA SCHERBAKOVA	{"email": "scherbakovayuliya-081976@postgrespro.ru", "phone": "+70309337303"}
0005434345174	296007	1192 795884	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila-1968@postgrespro.ru", "phone": "+70092419890"}
0005434345175	DB2105	1054 134657	SVETLANA BOGDANOVA	{"phone": "+70600188701"}
0005434345176	DB2105	4900 789741	VIKTOR NIKOLAEV	{"email": "nikolaev_v31121969@postgrespro.ru", "phone": "+70569546326"}
0005434345177	B3E547	0128 748659	DIANA DANILOVA	{"phone": "+70395199944"}
0005434345178	68CBF7	8503 279059	VERA MIRONOVA	{"email": "mironova_vera.031983@postgrespro.ru", "phone": "+70521312120"}
0005434345179	68CBF7	1061 389804	SERGEY VLASOV	{"email": "vlasov_sergey-1979@postgrespro.ru", "phone": "+70206091698"}
0005434345180	336678	9458 235417	ALEKSEY PAVLOV	{"email": "alekseypavlov101972@postgrespro.ru", "phone": "+70382252783"}
0005434345181	64972D	6754 707896	ANNA MALYSHEVA	{"phone": "+70607157581"}
0005434345182	64972D	9001 319560	ANDREY DAVYDOV	{"email": "adavydov-03061978@postgrespro.ru", "phone": "+70420234303"}
0005434345183	0A0FA9	6442 156036	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir.1965@postgrespro.ru", "phone": "+70687925266"}
0005434345184	1E0679	3528 776565	SAVELIY ILIN	{"email": "saveliy.ilin-041972@postgrespro.ru", "phone": "+70874430721"}
0005434345185	4F0968	0782 433333	KSENIYA VLASOVA	{"phone": "+70788669678"}
0005434345186	4F0968	2824 747410	ANATOLIY ZAYCEV	{"email": "a-zaycev_21031977@postgrespro.ru", "phone": "+70245242851"}
0005434345187	CF071D	5492 433294	GENNADIY KARPOV	{"phone": "+70046206616"}
0005434345188	CF071D	7996 469943	ALEKSANDR BORISOV	{"email": "a-borisov1979@postgrespro.ru", "phone": "+70682944953"}
0005434345189	9E8708	2303 379747	VALENTINA MARTYNOVA	{"email": "martynovav.1978@postgrespro.ru", "phone": "+70484889781"}
0005434345190	9E8708	8909 534483	NATALYA SOROKINA	{"email": "sorokina-n.101975@postgrespro.ru", "phone": "+70734775333"}
0005434345191	4B607A	7951 118931	GENNADIY KRASNOV	{"phone": "+70887033467"}
0005434345192	4B607A	9490 442748	SERGEY ABRAMOV	{"phone": "+70369428334"}
0005434345193	4B607A	5762 820120	NADEZHDA KUZMINA	{"email": "nkuzmina.15061975@postgrespro.ru", "phone": "+70150217679"}
0005434345194	B26355	2626 482793	MIKHAIL PAVLOV	{"email": "pavlovmikhail-051976@postgrespro.ru", "phone": "+70753929607"}
0005434345195	E5F96D	5336 778931	GENNADIY KOZLOV	{"email": "g_kozlov10031968@postgrespro.ru", "phone": "+70616117996"}
0005434345196	83C292	9497 133887	MARIYA SIDOROVA	{"phone": "+70873463274"}
0005434345197	D02797	8821 236063	VALERIY BORISOV	{"email": "borisovv.041986@postgrespro.ru", "phone": "+70450363194"}
0005434345198	D02797	9798 549244	NIKOLAY TARASOV	{"email": "tarasov-nikolay-25111977@postgrespro.ru", "phone": "+70997230030"}
0005434345199	54A896	0807 192105	ZAKHAR MOISEEV	{"email": "zakhar-moiseev-111977@postgrespro.ru", "phone": "+70304837338"}
0005434345200	54A896	6347 451348	LIDIYA PETROVA	{"email": "lpetrova_051975@postgrespro.ru", "phone": "+70473060142"}
0005434345201	B07D35	7719 733861	ANATOLIY GORBUNOV	{"email": "a_gorbunov.041978@postgrespro.ru", "phone": "+70657016544"}
0005434345202	E6E1EE	0348 417127	PETR ANDREEV	{"phone": "+70786250795"}
0005434345203	E6E1EE	3776 151206	VLADIMIR IVANOV	{"phone": "+70863955246"}
0005434345204	B73953	7500 773606	ANATOLIY PETROV	{"email": "petrov-a-061987@postgrespro.ru", "phone": "+70628115496"}
0005434345205	3CDF29	0621 511342	SVETLANA BARANOVA	{"phone": "+70116957593"}
0005434345206	3CDF29	9477 471251	KLAVDIYA SIDOROVA	{"phone": "+70596785175"}
0005434345207	702514	7033 945956	VERA SMIRNOVA	{"phone": "+70478750510"}
0005434345208	702514	9021 819529	EKATERINA GUSEVA	{"email": "e.guseva-11121981@postgrespro.ru", "phone": "+70745604661"}
0005434345209	FE8CC4	0890 147032	IVAN MAKAROV	{"email": "makarov_i_011971@postgrespro.ru", "phone": "+70071689540"}
0005434345210	B7D3CC	9041 131860	ALEKSEY TIKHONOV	{"email": "a-tikhonov-1963@postgrespro.ru", "phone": "+70224808252"}
0005434345211	BDB467	6288 752129	KONSTANTIN BELOV	{"email": "konstantin.belov_04021970@postgrespro.ru", "phone": "+70662215245"}
0005434345212	A42E93	3409 234275	ANATOLIY MAKAROV	{"email": "a_makarov_051980@postgrespro.ru", "phone": "+70336187968"}
0005434345213	A42E93	6523 639422	EVGENIY YAKOVLEV	{"phone": "+70012018935"}
0005434345214	78FC52	9467 163823	SVETLANA SIDOROVA	{"email": "sidorova.svetlana.1970@postgrespro.ru", "phone": "+70306767697"}
0005434345215	828517	9432 775005	IRINA TIKHONOVA	{"phone": "+70342046868"}
0005434345216	828517	4556 769805	BORIS NAZAROV	{"email": "nazarovb-1968@postgrespro.ru", "phone": "+70596482092"}
0005434345217	7CCA92	8501 067439	ARTUR POPOV	{"email": "popovartur101971@postgrespro.ru", "phone": "+70292754353"}
0005434345218	7CCA92	0964 371778	SVETLANA EFIMOVA	{"phone": "+70417803503"}
0005434345219	CD7DFA	8694 148217	NIKOLAY EGOROV	{"phone": "+70245962525"}
0005434345220	CD7DFA	9122 204494	ELENA EGOROVA	{"phone": "+70796250353"}
0005434345221	CF234E	3079 453594	KSENIYA TARASOVA	{"email": "tarasova_kseniya-1969@postgrespro.ru", "phone": "+70218307727"}
0005434345222	87C255	8571 513381	ALEKSEY KUZNECOV	{"email": "a-kuznecov_1977@postgrespro.ru", "phone": "+70681167411"}
0005434345223	DF9439	3241 378670	ANTON SOKOLOV	{"email": "antonsokolov.051976@postgrespro.ru", "phone": "+70073759182"}
0005434345224	7EF48F	1782 632527	DMITRIY SCHERBAKOV	{"phone": "+70773078399"}
0005434345225	657D74	0552 806387	IRINA MAKAROVA	{"phone": "+70312427986"}
0005434345226	657D74	9486 126659	DENIS PETROV	{"email": "petrov_denis_061978@postgrespro.ru", "phone": "+70246920325"}
0005434345227	31626B	8163 487942	EKATERINA ALEKSEEVA	{"email": "e_alekseeva121966@postgrespro.ru", "phone": "+70487250515"}
0005434345228	AB2FA8	1472 568340	NIKOLAY BELOV	{"email": "n.belov-15081967@postgrespro.ru", "phone": "+70619031442"}
0005434345229	79F78B	8712 876414	GRIGORIY KOROLEV	{"phone": "+70074863827"}
0005434345230	79F78B	8412 656072	OLGA DANILOVA	{"email": "olga_danilova_1961@postgrespro.ru", "phone": "+70752843133"}
0005434345231	F86D26	5490 099264	ANASTASIYA BARANOVA	{"phone": "+70517542757"}
0005434345232	C3357D	5348 554296	MARIYA RYABOVA	{"email": "m.ryabova_29071963@postgrespro.ru", "phone": "+70452181284"}
0005434345233	461699	9870 945006	MARINA SOROKINA	{"phone": "+70747375922"}
0005434345234	461699	7898 574499	MARIYA MOISEEVA	{"phone": "+70528964614"}
0005434345235	03A0D7	7437 154508	ALENA OSIPOVA	{"email": "osipova.alena_11031981@postgrespro.ru", "phone": "+70822152868"}
0005434345236	03A0D7	9216 587810	MARGARITA KOVALEVA	{"email": "m_kovaleva-1970@postgrespro.ru", "phone": "+70010035641"}
0005434345237	FE8D58	7365 241414	IRINA YAKOVLEVA	{"email": "yakovleva.irina_021986@postgrespro.ru", "phone": "+70494816167"}
0005434345238	FE8D58	9718 138652	NATALIYA IVANOVA	{"phone": "+70211729268"}
0005434345239	3F9784	4244 047774	MARIYA RYABOVA	{"email": "mariya_ryabova_021972@postgrespro.ru", "phone": "+70020687406"}
0005434345240	3F9784	3718 352840	VALENTINA BARANOVA	{"email": "baranova_valentina-1975@postgrespro.ru", "phone": "+70389765814"}
0005434345241	3F9784	2887 991710	MARAT NIKITIN	{"phone": "+70202699388"}
0005434345242	2212D7	9406 719195	SOFIYA NESTEROVA	{"email": "sofiya-nesterova_1973@postgrespro.ru", "phone": "+70524749571"}
0005434345243	D62785	0086 281478	LYUDMILA KUZMINA	{"email": "lkuzmina021976@postgrespro.ru", "phone": "+70288374923"}
0005434345244	D62785	1211 859377	NIKOLAY POPOV	{"phone": "+70827603748"}
0005434345245	8B8E24	5984 080817	NIKOLAY KRASNOV	{"phone": "+70243607665"}
0005434345246	D309CF	4096 526487	NIKOLAY BELOV	{"phone": "+70476370898"}
0005434345247	4E2CDE	5709 308429	OLGA MELNIKOVA	{"email": "melnikova-olga.30051976@postgrespro.ru", "phone": "+70238233800"}
0005434345248	4E2CDE	7734 095802	VLADIMIR NIKOLAEV	{"email": "nikolaev.v-14091966@postgrespro.ru", "phone": "+70206321263"}
0005434345249	06AAB9	3844 662250	SERGEY SERGEEV	{"email": "sergeev.s-24051968@postgrespro.ru", "phone": "+70090909218"}
0005434345250	06AAB9	8532 689298	VITALIY SEMENOV	{"email": "v.semenov_24111961@postgrespro.ru", "phone": "+70380057496"}
0005434345251	FEBF50	7962 458567	ANTON VLASOV	{"email": "vlasov-anton-061973@postgrespro.ru", "phone": "+70055485817"}
0005434345252	81B338	7546 567398	ANTON NIKOLAEV	{"email": "nikolaeva_121978@postgrespro.ru", "phone": "+70715566531"}
0005434345253	BC3699	6733 163045	EVGENIYA OSIPOVA	{"email": "osipova_evgeniya_061966@postgrespro.ru", "phone": "+70467449107"}
0005434345254	BC3699	7149 794335	TAMARA FROLOVA	{"phone": "+70805309126"}
0005434345255	70ED9A	5077 348032	ALEVTINA EGOROVA	{"email": "a-egorova_25011979@postgrespro.ru", "phone": "+70337092163"}
0005434345256	9F6D5D	3691 259722	GEORGIY BARANOV	{"phone": "+70533163193"}
0005434345257	53141E	5516 375299	DMITRIY MOISEEV	{"phone": "+70023409146"}
0005434345258	53141E	7221 035934	ROMAN ISAEV	{"phone": "+70685358516"}
0005434345259	CEA009	3892 879711	RUSLAN SOKOLOV	{"phone": "+70902384712"}
0005434345260	D4087E	4166 963263	YULIYA OVCHINNIKOVA	{"email": "y_ovchinnikova.06061979@postgrespro.ru", "phone": "+70414095893"}
0005434345261	D4087E	3783 964465	OLGA ALEKSANDROVA	{"email": "aleksandrova_olga.1973@postgrespro.ru", "phone": "+70316698597"}
0005434345262	6BF303	7413 685620	LYUDMILA ABRAMOVA	{"phone": "+70269589927"}
0005434345263	5F17A4	1074 304019	EKATERINA MAKAROVA	{"email": "ekaterinamakarova.071974@postgrespro.ru", "phone": "+70096532380"}
0005434345264	27627F	6877 891124	ANATOLIY ANDREEV	{"phone": "+70146686054"}
0005434345265	7B295D	5741 689558	AYRAT KUZNECOV	{"phone": "+70581179848"}
0005434345266	53DCA8	4111 089920	VERA SEMENOVA	{"phone": "+70632732857"}
0005434345267	53DCA8	3645 873034	YANA ROMANOVA	{"phone": "+70182474558"}
0005434345268	B90B6A	6269 050944	IVAN SOROKIN	{"phone": "+70479978931"}
0005434345269	611A01	7175 953325	STANISLAV NAZAROV	{"phone": "+70547269331"}
0005434345270	611A01	5074 716747	NATALYA FEDOROVA	{"phone": "+70571735739"}
0005434345271	875F90	1754 950619	VYACHESLAV ZHURAVLEV	{"email": "zhuravlev.v.1977@postgrespro.ru", "phone": "+70809934417"}
0005434345272	875F90	7356 188736	NINA POPOVA	{"email": "n_popova-1970@postgrespro.ru", "phone": "+70557954276"}
0005434345273	875F90	4090 488234	OLESYA KAZAKOVA	{"email": "olesya_kazakova_07071977@postgrespro.ru", "phone": "+70319130445"}
0005434345274	A82685	2192 289055	EKATERINA KALININA	{"email": "ekaterinakalinina23091970@postgrespro.ru", "phone": "+70912301242"}
0005434345275	A82685	0204 347273	NATALYA VASILEVA	{"phone": "+70586317188"}
0005434345276	9ABF32	1641 768161	YANA STEPANOVA	{"email": "ystepanova011965@postgrespro.ru", "phone": "+70732193829"}
0005434345277	9ABF32	9910 394687	EVGENIY ZAYCEV	{"email": "e-zaycev_13101970@postgrespro.ru", "phone": "+70294007460"}
0005434345278	9ABF32	6493 266884	TATYANA KRASNOVA	{"email": "tatyana.krasnova-051970@postgrespro.ru", "phone": "+70106898010"}
0005434345279	4144CE	9579 185213	SERGEY NOVIKOV	{"phone": "+70191469911"}
0005434345280	4144CE	2687 290193	ALEKSANDR KUZNECOV	{"phone": "+70856180536"}
0005434345281	4144CE	3209 163418	LYUBOV SERGEEVA	{"phone": "+70711323608"}
0005434345282	419864	5122 867018	EVGENIYA KOROLEVA	{"email": "ekoroleva_051972@postgrespro.ru", "phone": "+70903790886"}
0005434345283	2BDC70	1198 369315	SERGEY ANDREEV	{"phone": "+70105212379"}
0005434345284	2BDC70	7624 694152	ZOYA SCHERBAKOVA	{"email": "scherbakova-z_1973@postgrespro.ru", "phone": "+70346163852"}
0005434345285	DAA4A4	7101 924002	LYUBOV ISAEVA	{"phone": "+70389142271"}
0005434345286	C4CEEA	4899 129056	LYUDMILA KULIKOVA	{"phone": "+70123366776"}
0005434345287	254EC4	7686 035446	EKATERINA KOLESNIKOVA	{"email": "e.kolesnikova.24061966@postgrespro.ru", "phone": "+70856308654"}
0005434345288	F43CF3	0452 049525	TATYANA KOMAROVA	{"phone": "+70793853250"}
0005434345289	A25A9C	7771 770058	TATYANA GERASIMOVA	{"email": "tatyanagerasimova-111974@postgrespro.ru", "phone": "+70716783617"}
0005434345290	7D51E4	2339 753107	ANDREY GORBUNOV	{"email": "gorbunov.a_121963@postgrespro.ru", "phone": "+70746361038"}
0005434345291	7D51E4	3270 043707	TATYANA SIDOROVA	{"email": "tsidorova-081972@postgrespro.ru", "phone": "+70867371522"}
0005434345292	BD6140	2707 506785	ALEKSANDR FROLOV	{"phone": "+70277357333"}
0005434345293	BD6140	5283 717116	ELIZAVETA ROMANOVA	{"email": "romanova-elizaveta-081988@postgrespro.ru", "phone": "+70538296231"}
0005434345294	BD6140	9335 665072	IVAN KUZNECOV	{"email": "ivan_kuznecov-1979@postgrespro.ru", "phone": "+70034053562"}
0005434345295	A06937	6956 429005	ALEKSANDR IVANOV	{"email": "aleksandrivanov_19091976@postgrespro.ru", "phone": "+70635271363"}
0005434345296	433C33	9975 063858	GALINA ARKHIPOVA	{"phone": "+70873015122"}
0005434345297	79EF5A	9008 578993	MIKHAIL DAVYDOV	{"email": "davydovm_081986@postgrespro.ru", "phone": "+70880810157"}
0005434345298	CD7983	6901 125197	YULIYA ORLOVA	{"phone": "+70920866201"}
0005434351501	83FB47	3141 490717	VIKTOR EGOROV	{"phone": "+70291799751"}
0005434351557	541842	7857 802097	ALEKSANDR NIKITIN	{"phone": "+70896383446"}
0005434351463	F92904	5450 929413	DMITRIY AFANASEV	{"phone": "+70382840889"}
0005434351464	0C5E65	8535 118826	ALLA GUSEVA	{"email": "aguseva071971@postgrespro.ru", "phone": "+70561988680"}
0005434351465	EE2869	4433 441450	MAKSIM SCHERBAKOV	{"email": "maksimscherbakov-1965@postgrespro.ru", "phone": "+70155823788"}
0005434351466	1791B0	3815 131161	VLADIMIR FOMIN	{"phone": "+70273270513"}
0005434351467	E358D6	8443 586786	EKATERINA ANDREEVA	{"email": "andreeva.ekaterina-1973@postgrespro.ru", "phone": "+70052810044"}
0005434351468	7C4226	0536 573665	MIKHAIL IVANOV	{"email": "mivanov-11011974@postgrespro.ru", "phone": "+70697950810"}
0005434351469	F1A887	2321 674479	EKATERINA KUZNECOVA	{"phone": "+70835609674"}
0005434351470	D4CFE6	9030 599138	FEDOR NAZAROV	{"email": "fedornazarov.1977@postgrespro.ru", "phone": "+70639346012"}
0005434351471	27F1F6	9794 929960	RADIK MELNIKOV	{"phone": "+70971034866"}
0005434351472	82A2CB	1293 100384	ALEKSEY TIMOFEEV	{"email": "aleksey-timofeev.021984@postgrespro.ru", "phone": "+70185800546"}
0005434351473	E680F6	5726 382287	IVAN YAKOVLEV	{"phone": "+70874659832"}
0005434351474	67CFEF	4531 143712	ARTEMIY GORBUNOV	{"phone": "+70535645437"}
0005434351475	8402FB	1609 082465	DMITRIY YAKOVLEV	{"phone": "+70491912092"}
0005434351476	5EC9AE	1816 848004	YURIY VOLKOV	{"email": "volkovyuriy-1979@postgrespro.ru", "phone": "+70273558013"}
0005434351477	B9F056	2876 566856	OLGA KUZNECOVA	{"phone": "+70733310350"}
0005434351478	2D7CE3	4393 651563	ELENA LUKYANOVA	{"email": "elenalukyanova1973@postgrespro.ru", "phone": "+70803696886"}
0005434351479	324F12	1164 065923	DAMIR MAKSIMOV	{"email": "damir-maksimov_061970@postgrespro.ru", "phone": "+70584335217"}
0005434351480	324F12	3249 002994	SVETLANA KUZNECOVA	{"phone": "+70565029157"}
0005434351481	EA214D	5111 523971	YULIYA MIRONOVA	{"phone": "+70853252760"}
0005434351482	086510	9744 686971	ALEKSANDR MATVEEV	{"phone": "+70070041997"}
0005434351483	C8F061	4410 729741	VALENTINA KUZNECOVA	{"email": "kuznecova-v061960@postgrespro.ru", "phone": "+70403290528"}
0005434351484	B96520	1657 781969	VIKTOR SCHERBAKOV	{"email": "scherbakov_viktor_1963@postgrespro.ru", "phone": "+70973055905"}
0005434351485	7CCDFC	7503 170147	STEPAN ANTONOV	{"email": "antonov_stepan011973@postgrespro.ru", "phone": "+70724603410"}
0005434351486	1972FE	7541 590071	MILANA IVANOVA	{"email": "ivanova-milana_16111976@postgrespro.ru", "phone": "+70351989376"}
0005434351487	1972FE	8532 138031	ELENA NIKITINA	{"phone": "+70946811908"}
0005434351488	7B0B9B	6062 945331	SOFIYA ALEKSEEVA	{"phone": "+70890375140"}
0005434351489	7B0B9B	7197 662402	MARINA MAKAROVA	{"email": "makarova_m_081973@postgrespro.ru", "phone": "+70809476905"}
0005434351490	C84E05	7763 319000	TATYANA MAKAROVA	{"phone": "+70285723987"}
0005434351491	CF3990	4681 037347	ILYAS BORISOV	{"phone": "+70089186476"}
0005434351492	625BB1	9606 017120	VYACHESLAV KISELEV	{"email": "v_kiselev_14121962@postgrespro.ru", "phone": "+70424053162"}
0005434351493	58470B	7718 209139	ANASTASIYA VOROBEVA	{"phone": "+70451184944"}
0005434351494	25F679	4842 490909	ELENA FOMINA	{"email": "efomina10101964@postgrespro.ru", "phone": "+70700297810"}
0005434351495	8A1BFA	0642 654684	NIKOLAY KUDRYASHOV	{"phone": "+70382843387"}
0005434351496	4D7E6B	6146 005539	GENNADIY KULIKOV	{"email": "gennadiy.kulikov031972@postgrespro.ru", "phone": "+70946493053"}
0005434351497	4CF547	0095 735771	IRINA KOZLOVA	{"phone": "+70055751260"}
0005434351498	4CF547	7393 194361	NIKITA SIDOROV	{"email": "sidorovn_19061975@postgrespro.ru", "phone": "+70870041383"}
0005434351499	4CF547	0743 117174	OLGA GORBUNOVA	{"phone": "+70329739954"}
0005434351500	83FB47	2122 654053	ALEKSANDR VLASOV	{"email": "vlasov_aleksandr_071976@postgrespro.ru", "phone": "+70884118365"}
0005434351502	986CDB	4113 341294	MAKSIM SAVELEV	{"email": "m_savelev_1969@postgrespro.ru", "phone": "+70687645926"}
0005434351503	0AE045	5915 923172	SOFYA ISAEVA	{"email": "isaeva_sofya-1963@postgrespro.ru", "phone": "+70432700409"}
0005434351504	4A4699	7281 348295	ANTON IVANOV	{"email": "ivanov.anton_1971@postgrespro.ru", "phone": "+70938483952"}
0005434351505	327F2B	0398 458481	VLADIMIR SEMENOV	{"email": "vsemenov_20041965@postgrespro.ru", "phone": "+70862333835"}
0005434351506	DB06B8	0283 239626	IGOR MATVEEV	{"phone": "+70512484233"}
0005434351507	DDA203	1389 789873	TAMARA FILIPPOVA	{"email": "t.filippova.05041973@postgrespro.ru", "phone": "+70209458726"}
0005434351508	DDA203	9761 390429	ARKADIY KUZNECOV	{"email": "kuznecovarkadiy_111969@postgrespro.ru", "phone": "+70846079932"}
0005434351509	26C86D	9971 501474	GALINA BELYAEVA	{"email": "galina_belyaeva_091970@postgrespro.ru", "phone": "+70843769640"}
0005434351510	9E6A26	3301 657276	ALINA BOGDANOVA	{"email": "bogdanova-a20071961@postgrespro.ru", "phone": "+70750556909"}
0005434351511	0E59E1	6088 323970	ELENA ZHURAVLEVA	{"phone": "+70327421268"}
0005434351512	7F5A0C	1242 881837	VALERIY IVANOV	{"phone": "+70707477156"}
0005434351513	DEBD58	6440 248152	ANASTASIYA FROLOVA	{"phone": "+70953917807"}
0005434351514	7EBC7F	1373 117578	NINA NIKOLAEVA	{"email": "nikolaeva-n_111967@postgrespro.ru", "phone": "+70870864396"}
0005434351515	7EBC7F	7189 771912	GALINA TARASOVA	{"email": "galinatarasova041962@postgrespro.ru", "phone": "+70618045918"}
0005434351516	28E3B9	8995 416592	TATYANA NIKOLAEVA	{"phone": "+70278401790"}
0005434351517	3F0654	0162 393714	VALERIY OSIPOV	{"email": "v.osipov.1974@postgrespro.ru", "phone": "+70588728975"}
0005434351518	CC0056	2434 842548	NINA KUZNECOVA	{"email": "nina_kuznecova_1964@postgrespro.ru", "phone": "+70002756124"}
0005434351519	1FF0DD	4634 453223	LYUDMILA SOROKINA	{"phone": "+70431448688"}
0005434351520	3E5B7F	2589 378443	ALLA ANDREEVA	{"phone": "+70342197233"}
0005434351521	3E5B7F	0236 260058	YURIY AFANASEV	{"email": "y-afanasev-23091975@postgrespro.ru", "phone": "+70131267252"}
0005434351522	61E287	9235 230953	ALEKSANDR SMIRNOV	{"email": "asmirnov1971@postgrespro.ru", "phone": "+70099443108"}
0005434351523	61E287	7596 579518	ELENA FEDOROVA	{"phone": "+70550298042"}
0005434351524	B282A9	3601 100114	VIKTORIYA KOVALEVA	{"phone": "+70546307466"}
0005434351525	03CC41	9947 757755	TATYANA GORBUNOVA	{"email": "gorbunova_tatyana-09081972@postgrespro.ru", "phone": "+70506500430"}
0005434351526	BF591B	7535 054324	PETR ANTONOV	{"email": "petr_antonov011974@postgrespro.ru", "phone": "+70915220657"}
0005434351527	4E4E0D	9031 309608	OLEG GAVRILOV	{"phone": "+70318429467"}
0005434351528	9DAF52	3698 514194	DARYA BELOVA	{"email": "d-belova.1976@postgrespro.ru", "phone": "+70896479607"}
0005434351529	F645B3	9543 680102	ANASTASIYA STEPANOVA	{"email": "stepanova-anastasiya.051975@postgrespro.ru", "phone": "+70782849203"}
0005434351530	F645B3	5106 465462	VALERIY MAKAROV	{"phone": "+70092587327"}
0005434351531	7ED8F4	2095 766178	GALINA KOZLOVA	{"email": "galina.kozlova.1977@postgrespro.ru", "phone": "+70686817130"}
0005434351532	7ED8F4	9086 618876	ANNA DENISOVA	{"phone": "+70750931757"}
0005434351533	7ED8F4	0725 691159	ALEKSANDR DENISOV	{"email": "adenisov.061976@postgrespro.ru", "phone": "+70901405571"}
0005434351534	9E3230	6878 796311	VALERIY AFANASEV	{"email": "valeriy.afanasev-1968@postgrespro.ru", "phone": "+70646029145"}
0005434351535	090117	3853 813450	ARINA RODIONOVA	{"email": "rodionova-a-121975@postgrespro.ru", "phone": "+70749756249"}
0005434351536	F5A7AE	9161 533037	ALEKSANDR KULIKOV	{"email": "kulikovaleksandr.03121970@postgrespro.ru", "phone": "+70846005902"}
0005434351537	F5A7AE	7451 833593	ANASTASIYA ANDREEVA	{"phone": "+70441626760"}
0005434351538	F5A7AE	7764 582352	ALEKSANDR VASILEV	{"phone": "+70953244229"}
0005434351539	05F064	7222 224873	TIGRAN IVANOV	{"phone": "+70270573917"}
0005434351540	8A159C	9301 550015	OLGA ANDREEVA	{"email": "andreevaolga041971@postgrespro.ru", "phone": "+70802726821"}
0005434351541	4D6265	6976 915160	IVAN YAKOVLEV	{"phone": "+70853752688"}
0005434351542	45A59E	9659 643166	LYUDMILA NIKIFOROVA	{"phone": "+70098157363"}
0005434351543	724D88	7141 355882	STEPAN ANDREEV	{"email": "andreev-s-041974@postgrespro.ru", "phone": "+70818179980"}
0005434351544	F579BC	8632 702350	SVETLANA GAVRILOVA	{"email": "gavrilova_s-14031968@postgrespro.ru", "phone": "+70669839939"}
0005434351545	E867B2	5444 303982	SERGEY VOLKOV	{"email": "volkov.sergey_22121969@postgrespro.ru", "phone": "+70586839847"}
0005434351546	885187	0610 941973	SERGEY KAZAKOV	{"email": "kazakov_sergey_18051967@postgrespro.ru", "phone": "+70867218696"}
0005434351547	857C72	9000 396042	MARIYA GRISHINA	{"email": "grishinam_061973@postgrespro.ru", "phone": "+70454013148"}
0005434351548	F81C7E	4350 917665	SERGEY KOZLOV	{"email": "kozlovsergey_18071980@postgrespro.ru", "phone": "+70915362254"}
0005434351549	F81C7E	8102 990523	ALEKSEY OSIPOV	{"phone": "+70091464766"}
0005434351550	9462ED	8723 785195	ELENA LOGINOVA	{"email": "loginova_elena12091966@postgrespro.ru", "phone": "+70276384239"}
0005434351551	134BD2	6105 130863	VALENTINA KOZLOVA	{"email": "v-kozlova-1967@postgrespro.ru", "phone": "+70193870639"}
0005434351552	134BD2	2957 311526	MARINA TARASOVA	{"email": "marinatarasova1970@postgrespro.ru", "phone": "+70862014077"}
0005434351553	334560	8444 374921	RAISA EGOROVA	{"email": "raisaegorova-1970@postgrespro.ru", "phone": "+70152682222"}
0005434351554	2EF0DE	4149 251305	MAYA ANISIMOVA	{"phone": "+70402991885"}
0005434351555	2EF0DE	8214 758714	VLADIMIR NIKITIN	{"email": "vladimir-nikitin_1979@postgrespro.ru", "phone": "+70735955082"}
0005434351556	194614	4118 951774	VLADIMIR MATVEEV	{"phone": "+70742919398"}
0005434351558	0408CA	2091 869510	ANTONINA ORLOVA	{"phone": "+70818608361"}
0005434351559	652E4F	5071 103223	VALERIY KISELEV	{"email": "kiselev-valeriy.081984@postgrespro.ru", "phone": "+70691186364"}
0005434351560	52DF40	4281 924728	GALINA LEBEDEVA	{"phone": "+70626368056"}
0005434351561	D19302	0004 949670	GALINA FEDOROVA	{"phone": "+70731573966"}
0005434351562	84F70F	6514 944187	LYUDMILA ALEKSEEVA	{"phone": "+70651193262"}
0005434351563	84F70F	5865 006255	ALEKSEY BORISOV	{"phone": "+70551139624"}
0005434351564	D48909	0085 049742	LYUBOV MASLOVA	{"phone": "+70203509174"}
0005434351565	4CA810	6915 927305	ALEKSEY ROMANOV	{"email": "romanov-aleksey.1963@postgrespro.ru", "phone": "+70273814109"}
0005434351566	061097	6788 865951	MARIYA ABRAMOVA	{"email": "mariya-abramova-1971@postgrespro.ru", "phone": "+70806457426"}
0005434351567	F0F0A8	1314 078801	LYUBOV VOLKOVA	{"email": "l.volkova_1973@postgrespro.ru", "phone": "+70167617540"}
0005434351568	066F1F	7976 585130	VYACHESLAV SEMENOV	{"phone": "+70711408241"}
0005434351569	3B4D06	7279 015545	MIKHAIL SERGEEV	{"email": "mikhailsergeev-011968@postgrespro.ru", "phone": "+70252081764"}
0005434351570	15F1EC	9546 992014	OLEG VOROBEV	{"phone": "+70851100436"}
0005434351571	568215	3707 552902	NINA KUZNECOVA	{"email": "kuznecovan041975@postgrespro.ru", "phone": "+70664549401"}
0005434351572	568215	0018 636755	LARISA TIMOFEEVA	{"email": "timofeeva_larisa-05091971@postgrespro.ru", "phone": "+70524787524"}
0005434351573	FFD7A8	2972 770432	ELENA KOROLEVA	{"email": "elena-koroleva1977@postgrespro.ru", "phone": "+70967843530"}
0005434351574	526702	6021 419345	KAMIL IVANOV	{"email": "kamil-ivanov_21011971@postgrespro.ru", "phone": "+70980234017"}
0005434351575	49CA26	6481 633690	EKATERINA NIKITINA	{"email": "nikitinaekaterina-21051973@postgrespro.ru", "phone": "+70043920084"}
0005434351576	A07B9A	2703 844342	VALERIY VASILEV	{"email": "valeriyvasilev-1966@postgrespro.ru", "phone": "+70829753167"}
0005434351577	803D2B	1178 632299	MARIYA FROLOVA	{"email": "m.frolova1968@postgrespro.ru", "phone": "+70986363848"}
0005434351578	803D2B	5577 062058	VLADIMIR ROMANOV	{"email": "v.romanov.1967@postgrespro.ru", "phone": "+70795941836"}
0005434351579	DA77F2	2541 279988	ANNA NOVIKOVA	{"phone": "+70165202769"}
0005434351580	DA77F2	1235 886671	ALEKSEY POPOV	{"email": "popov_aleksey-1968@postgrespro.ru", "phone": "+70946687646"}
0005434351581	D15E42	6632 120417	NATALYA MIKHAYLOVA	{"phone": "+70680279631"}
0005434351582	6AF091	6751 107238	ANNA MELNIKOVA	{"phone": "+70230593138"}
0005434351583	7BCCE2	6182 899338	SVETLANA KUZNECOVA	{"email": "kuznecova.s-011981@postgrespro.ru", "phone": "+70864188072"}
0005434351584	7BCCE2	9112 836045	ELENA FEDOROVA	{"phone": "+70752108861"}
0005434351585	960610	2334 003547	PETR MATVEEV	{"email": "pmatveev_08071970@postgrespro.ru", "phone": "+70577383202"}
0005434351586	0628BA	4826 487325	KSENIYA IVANOVA	{"phone": "+70294448552"}
0005434351587	0628BA	1480 136951	VSEVOLOD ALEKSANDROV	{"email": "aleksandrov_v061979@postgrespro.ru", "phone": "+70334962881"}
0005434351588	0628BA	6766 495722	ALEKSEY ZAYCEV	{"email": "aleksey-zaycev-04041966@postgrespro.ru", "phone": "+70352572425"}
0005434351589	65A97E	7636 744880	SERGEY ABRAMOV	{"phone": "+70591723343"}
0005434351590	C43BDB	3697 310258	NATALYA FEDOROVA	{"email": "n.fedorova.101969@postgrespro.ru", "phone": "+70726271931"}
0005434351591	BF2297	6022 761624	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov.1968@postgrespro.ru", "phone": "+70231600523"}
0005434351592	092611	5357 793788	SERGEY AFANASEV	{"phone": "+70461810367"}
0005434351593	092611	5601 472707	ELENA GAVRILOVA	{"email": "gavrilova_e-29121977@postgrespro.ru", "phone": "+70312312276"}
0005434351594	092611	7713 853068	YULIYA KUZNECOVA	{"phone": "+70622132302"}
0005434351595	A6ADD4	9537 259505	SERAFIMA SOROKINA	{"email": "s.sorokina_22061974@postgrespro.ru", "phone": "+70856796754"}
0005434351596	9FCB0B	6198 293784	IGOR ZAKHAROV	{"email": "igorzakharov1968@postgrespro.ru", "phone": "+70166577429"}
0005434351597	A44269	0130 707454	YULIYA ABRAMOVA	{"email": "abramovayuliya.1973@postgrespro.ru", "phone": "+70752453063"}
0005434351598	BF9DC4	9486 427937	NIKOLAY GORBUNOV	{"email": "n.gorbunov-19051963@postgrespro.ru", "phone": "+70808050385"}
0005434351599	BF9DC4	5016 897107	ANATOLIY DAVYDOV	{"phone": "+70922162989"}
0005434351600	D333E2	1216 431973	ALEKSANDR VLASOV	{"email": "a-vlasov03011968@postgrespro.ru", "phone": "+70420456319"}
0005434351601	589847	1688 036495	ANNA VASILEVA	{"email": "annavasileva031958@postgrespro.ru", "phone": "+70469488920"}
0005434351602	589847	1844 307500	VALENTINA LUKYANOVA	{"email": "lukyanova.valentina111975@postgrespro.ru", "phone": "+70181740025"}
0005434351603	36F03A	4077 282273	VERA FILIPPOVA	{"email": "verafilippova_13091976@postgrespro.ru", "phone": "+70117625898"}
0005434351604	36F03A	0006 396417	IRINA EGOROVA	{"email": "egorovairina.14031964@postgrespro.ru", "phone": "+70218592207"}
0005434351605	A9821C	9202 552869	DENIS KOROLEV	{"phone": "+70143703665"}
0005434351606	B81C7C	7096 437848	EKATERINA FEDOROVA	{"email": "e.fedorova101981@postgrespro.ru", "phone": "+70361066531"}
0005434351607	B90788	0027 136604	DMITRIY MEDVEDEV	{"phone": "+70456461176"}
0005434351608	B90788	2823 777580	ALEKSANDR EGOROV	{"email": "egorov.aleksandr1980@postgrespro.ru", "phone": "+70144096414"}
0005434351609	4C4E7C	2507 851459	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov.1974@postgrespro.ru", "phone": "+70706011493"}
0005434351610	082585	2266 183473	ALEKSANDR NAZAROV	{"phone": "+70401775159"}
0005434351611	082585	1658 158118	VLADIMIR KONOVALOV	{"email": "vladimirkonovalov111969@postgrespro.ru", "phone": "+70542978400"}
0005434351612	803AEA	7711 456689	VITALIY MIKHAYLOV	{"phone": "+70894564117"}
0005434351613	AAC509	8941 207376	IVAN ANDREEV	{"phone": "+70205903971"}
0005434351614	5FF2E5	4905 658697	MARIYA ANDREEVA	{"email": "andreeva_mariya_1976@postgrespro.ru", "phone": "+70187144333"}
0005434351615	378F4B	5597 203513	NADEZHDA KISELEVA	{"phone": "+70295978274"}
0005434351616	378F4B	1017 445391	ALEKSANDR SOKOLOV	{"email": "sokolov.a-20021968@postgrespro.ru", "phone": "+70671460798"}
0005434351617	D26A67	8725 542995	ALLA MAKSIMOVA	{"phone": "+70172213214"}
0005434351618	74A275	5885 746094	VIKTOR DMITRIEV	{"phone": "+70121054808"}
0005434351619	684FB7	7093 048392	EVGENIY IVANOV	{"phone": "+70805374097"}
0005434351620	85F32D	0314 798240	ELENA MIRONOVA	{"email": "e_mironova21011969@postgrespro.ru", "phone": "+70288053592"}
0005434351621	F2BC7F	3863 686511	TATYANA BARANOVA	{"email": "baranova_tatyana.1981@postgrespro.ru", "phone": "+70811713971"}
0005434351622	EC3D62	3620 600359	PAVEL SIDOROV	{"phone": "+70323721777"}
0005434351623	6BD915	1925 363448	ANNA SOLOVEVA	{"email": "anna.soloveva091980@postgrespro.ru", "phone": "+70169243599"}
0005434351624	6BD915	8504 336757	NINA CHERNOVA	{"email": "chernova-n_1983@postgrespro.ru", "phone": "+70813115551"}
0005434351625	23E903	1113 066092	ANDREY FOMIN	{"phone": "+70877304611"}
0005434351626	A93F8E	6613 427951	ALEKSANDR GERASIMOV	{"email": "aleksandr_gerasimov-28071962@postgrespro.ru", "phone": "+70862105854"}
0005434351627	A93F8E	7920 481074	KLAVDIYA POPOVA	{"email": "popova-klavdiya_1970@postgrespro.ru", "phone": "+70753132179"}
0005434351628	330794	0921 636914	VALENTINA STEPANOVA	{"phone": "+70604241066"}
0005434351629	330794	3159 852719	RIMMA ERMAKOVA	{"email": "ermakova.rimma-06071976@postgrespro.ru", "phone": "+70675320273"}
0005434351630	926322	9765 476297	NIKOLAY MATVEEV	{"email": "matveev.n_27051966@postgrespro.ru", "phone": "+70072347039"}
0005434351631	926322	3657 356689	VALENTINA YAKOVLEVA	{"phone": "+70690677354"}
0005434351632	FCF2FC	7909 633117	GENNADIY VOLKOV	{"email": "gvolkov_20061966@postgrespro.ru", "phone": "+70393858339"}
0005434351633	D09D83	0606 919813	VITALIY MOROZOV	{"phone": "+70615902300"}
0005434351634	D09D83	8473 116455	RUSLAN BELOV	{"phone": "+70325115168"}
0005434351635	643BDC	8102 697906	GENNADIY ANDREEV	{"email": "andreev_gennadiy-21061980@postgrespro.ru", "phone": "+70829487812"}
0005434351636	643BDC	9441 396179	LYUDMILA ROMANOVA	{"email": "lyudmilaromanova_071967@postgrespro.ru", "phone": "+70789470770"}
0005434351637	F3048C	6244 768116	EKATERINA NIKITINA	{"phone": "+70953187603"}
0005434351638	F3048C	3107 284318	VIKTORIYA BELOVA	{"phone": "+70067035700"}
0005434351639	CD17EB	5570 072397	EVGENIYA ZAKHAROVA	{"phone": "+70600238542"}
0005434351640	AA9CF3	8101 991063	TATYANA VOROBEVA	{"phone": "+70783481533"}
0005434351641	588C88	6863 434312	NIKITA AFANASEV	{"phone": "+70161511289"}
0005434351642	8A67BA	8806 937665	ELENA EGOROVA	{"phone": "+70181415591"}
0005434351643	09DA0B	0863 547858	GALINA AKIMOVA	{"email": "akimovag_021967@postgrespro.ru", "phone": "+70664421614"}
0005434351644	09DA0B	6120 717915	YULIYA FOMINA	{"email": "fominayuliya_1964@postgrespro.ru", "phone": "+70602476140"}
0005434351645	0DE1D1	6470 337002	TATYANA MOISEEVA	{"email": "tmoiseeva-1970@postgrespro.ru", "phone": "+70256117166"}
0005434351646	F11FD1	1511 162486	VLADIMIR MOROZOV	{"phone": "+70258823819"}
0005434351647	542FFB	4136 356091	RAMIL KOROLEV	{"email": "korolev-r-16061974@postgrespro.ru", "phone": "+70742537677"}
0005434351648	7E8C97	5770 733519	ANASTASIYA DAVYDOVA	{"email": "davydova.anastasiya_071977@postgrespro.ru", "phone": "+70198936681"}
0005434351649	7E8C97	2138 735365	EKATERINA KUZNECOVA	{"email": "e-kuznecova_1973@postgrespro.ru", "phone": "+70322242824"}
0005434351650	7A5072	5577 137857	NATALYA STEPANOVA	{"email": "nstepanova14101975@postgrespro.ru", "phone": "+70569694500"}
0005434351651	7A5072	0918 942287	NURLAN MAKAROV	{"phone": "+70723228078"}
0005434351652	1CA94C	2936 977723	VLADIMIR TIMOFEEV	{"email": "v_timofeev.05011972@postgrespro.ru", "phone": "+70892811370"}
0005434351653	94A126	2616 666010	TATYANA ALEKSANDROVA	{"email": "t-aleksandrova-051963@postgrespro.ru", "phone": "+70797238157"}
0005434351654	8D7951	0635 533493	EKATERINA FADEEVA	{"email": "ekaterina-fadeeva1981@postgrespro.ru", "phone": "+70477770631"}
0005434351655	8D7951	0561 223963	VALERIY FILIPPOV	{"email": "v-filippov.051980@postgrespro.ru", "phone": "+70961650744"}
0005434351656	7378CC	6149 787484	GENNADIY VASILEV	{"phone": "+70726964328"}
0005434351657	7378CC	0449 772410	DMITRIY BORISOV	{"email": "borisovdmitriy1976@postgrespro.ru", "phone": "+70075554166"}
0005434351658	D671D2	1990 856264	VIKTOR VASILEV	{"email": "v.vasilev041985@postgrespro.ru", "phone": "+70215259422"}
0005434351659	43C6A8	2995 078592	IVAN ZAYCEV	{"email": "ivanzaycev_1966@postgrespro.ru", "phone": "+70154703331"}
0005434351660	AA1D41	3031 414611	RUSLAN ABRAMOV	{"email": "abramov_r-20051971@postgrespro.ru", "phone": "+70838598588"}
0005434351661	503E7A	7927 282791	ALEKSANDR VOLKOV	{"phone": "+70432517366"}
0005434351662	503E7A	7499 119794	RAVIL FROLOV	{"email": "frolov-r.1978@postgrespro.ru", "phone": "+70850169175"}
0005434351663	E049E0	2552 606043	MARIYA GERASIMOVA	{"phone": "+70895526259"}
0005434351664	7D508C	3995 620676	NATALYA KOROLEVA	{"email": "n-koroleva.041971@postgrespro.ru", "phone": "+70830716753"}
0005434351665	0EF337	8806 482499	YULIYA ORLOVA	{"email": "orlova.yuliya_1985@postgrespro.ru", "phone": "+70177290973"}
0005434351666	39AD6B	1467 219675	TATYANA NAZAROVA	{"phone": "+70103825820"}
0005434351667	39AD6B	5703 891966	ANTONINA AFANASEVA	{"phone": "+70592319844"}
0005434351781	84799F	1184 235420	MARYAM ANDREEVA	{"phone": "+70688432430"}
0005434351668	703106	2916 203868	VALENTINA SIDOROVA	{"email": "sidorovav1987@postgrespro.ru", "phone": "+70971772039"}
0005434351669	648124	2499 808458	TATYANA PETROVA	{"email": "tatyana-petrova_1980@postgrespro.ru", "phone": "+70615839668"}
0005434351670	FDC375	9303 207882	RITA SMIRNOVA	{"email": "smirnova-r1962@postgrespro.ru", "phone": "+70919905507"}
0005434351671	F6C6C6	1818 154360	VIOLETTA SOKOLOVA	{"email": "sokolovavioletta.15071971@postgrespro.ru", "phone": "+70906427851"}
0005434351672	F6C6C6	6739 568772	VIKTOR KUZMIN	{"phone": "+70634192350"}
0005434351673	F6C6C6	5512 691146	ELENA POPOVA	{"email": "elena_popova091974@postgrespro.ru", "phone": "+70687293029"}
0005434351674	5C5701	9935 241083	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva-21031964@postgrespro.ru", "phone": "+70358463933"}
0005434351675	5C5701	8408 013233	VLADIMIR ZHUKOV	{"phone": "+70464568176"}
0005434351676	A53739	8054 973401	RUDOLF SOKOLOV	{"phone": "+70498621840"}
0005434351677	E891D1	4498 532266	LILIYA CHERNOVA	{"email": "liliyachernova.11011976@postgrespro.ru", "phone": "+70767996175"}
0005434351678	E891D1	9309 574882	VYACHESLAV KUZNECOV	{"phone": "+70080435584"}
0005434351679	E891D1	6322 410078	MAKSIM SOROKIN	{"email": "sorokinm1980@postgrespro.ru", "phone": "+70837750190"}
0005434351680	26B14D	7547 026620	SVETLANA KRASNOVA	{"phone": "+70108462188"}
0005434351681	CFFBA5	0632 237279	GALINA NIKITINA	{"phone": "+70724030350"}
0005434351682	CFFBA5	3469 148408	NIKITA SOKOLOV	{"phone": "+70076369291"}
0005434351683	55C863	6877 358641	LIDIYA ZAKHAROVA	{"phone": "+70604143529"}
0005434351684	C50D70	0506 295175	YAN STEPANOV	{"email": "stepanovy_051970@postgrespro.ru", "phone": "+70237505903"}
0005434351685	485A33	7040 725028	VALENTINA ANISIMOVA	{"phone": "+70315682449"}
0005434351686	516041	8521 613108	ALEKSANDR MAKAROV	{"email": "makarova-121966@postgrespro.ru", "phone": "+70792421549"}
0005434351687	D386F8	5278 688844	NIKOLAY ABRAMOV	{"email": "abramov_n.1979@postgrespro.ru", "phone": "+70624075261"}
0005434351688	877335	3649 915339	NINA ILINA	{"phone": "+70945877695"}
0005434351689	5F971D	9934 407944	NIKITA GORBUNOV	{"phone": "+70485736923"}
0005434351690	5F971D	5121 525797	VLADIMIR VOLKOV	{"phone": "+70234110938"}
0005434351691	A80D46	2490 597597	EVGENIYA ABRAMOVA	{"phone": "+70825513632"}
0005434351692	4289F7	1550 417075	SERGEY NIKOLAEV	{"phone": "+70168452042"}
0005434351693	9E427C	8438 457565	ALEKSANDR KULIKOV	{"phone": "+70314243019"}
0005434351694	9E427C	9337 441192	SERGEY TARASOV	{"phone": "+70196709721"}
0005434351695	48964E	7000 432056	ALEKSANDR VASILEV	{"email": "a_vasilev041971@postgrespro.ru", "phone": "+70270671264"}
0005434351696	8BD402	6829 289705	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey13051971@postgrespro.ru", "phone": "+70433320282"}
0005434351697	499E58	3547 775693	NATALYA POPOVA	{"phone": "+70294810406"}
0005434351698	FAC7C4	2056 187993	TATYANA NAZAROVA	{"email": "nazarova_tatyana-1969@postgrespro.ru", "phone": "+70892826090"}
0005434351699	142A86	1040 781116	YAROSLAV PAVLOV	{"phone": "+70309900779"}
0005434351700	EB7050	1145 297150	ANTONINA EFIMOVA	{"phone": "+70834441102"}
0005434351701	EB7050	0532 442126	SERGEY TARASOV	{"email": "sergeytarasov22071963@postgrespro.ru", "phone": "+70131137178"}
0005434351702	9481B2	3192 586928	ALEKSANDR GAVRILOV	{"phone": "+70267681451"}
0005434351703	12A9F1	9096 504639	ANNA KUZMINA	{"phone": "+70821499146"}
0005434351704	0C2971	1578 878070	EKATERINA IVANOVA	{"email": "e.ivanova1962@postgrespro.ru", "phone": "+70944620511"}
0005434351705	0C2971	0998 783768	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov-071967@postgrespro.ru", "phone": "+70063242494"}
0005434351706	C6A150	3010 483167	YULIYA ZAKHAROVA	{"phone": "+70323266468"}
0005434351707	7BA94B	1649 722340	SVETLANA IVANOVA	{"email": "s_ivanova15101970@postgrespro.ru", "phone": "+70065855099"}
0005434351708	7BA94B	6929 588327	GALINA SAVELEVA	{"email": "g-saveleva091959@postgrespro.ru", "phone": "+70259061667"}
0005434351709	9937BF	6485 644091	SERGEY SCHERBAKOV	{"phone": "+70478913611"}
0005434351710	975983	3496 250406	ELENA RODIONOVA	{"email": "elenarodionova-1971@postgrespro.ru", "phone": "+70988799454"}
0005434351711	81B2D6	8243 843922	ELENA POPOVA	{"email": "popovae_081968@postgrespro.ru", "phone": "+70193871445"}
0005434351712	5E2B11	5813 660912	RASHID ALEKSANDROV	{"phone": "+70267188270"}
0005434351713	5E2B11	7476 908593	SVETLANA FEDOROVA	{"phone": "+70770883396"}
0005434351714	C631A4	7868 814026	IVAN KUZNECOV	{"email": "ikuznecov-041974@postgrespro.ru", "phone": "+70918420294"}
0005434351715	29EF7A	6277 495573	VALERIY KUZNECOV	{"phone": "+70853912424"}
0005434351716	1785C5	4290 127952	SVETLANA POPOVA	{"phone": "+70180958775"}
0005434351717	1785C5	4499 412369	NATALIYA PAVLOVA	{"email": "pavlova.n_26011969@postgrespro.ru", "phone": "+70867707811"}
0005434351718	5A2691	4213 675188	VERA NESTEROVA	{"email": "vnesterova-20041980@postgrespro.ru", "phone": "+70590147802"}
0005434351719	E58E8B	0762 338031	SVETLANA GERASIMOVA	{"email": "gerasimova-svetlana_021975@postgrespro.ru", "phone": "+70885562036"}
0005434351720	29FD06	2451 749237	OLESYA ZHURAVLEVA	{"phone": "+70327134492"}
0005434351721	29FD06	0153 255648	NATALYA VASILEVA	{"phone": "+70221290872"}
0005434351722	B7D144	1258 982272	ANASTASIYA DAVYDOVA	{"email": "davydovaa041963@postgrespro.ru", "phone": "+70349311845"}
0005434351723	B7D144	4961 798933	VADIM MIRONOV	{"phone": "+70783521965"}
0005434351894	009954	7007 387510	SERGEY ALEKSANDROV	{"phone": "+70778604712"}
0005434351724	B7D144	4478 359173	NIKOLAY SIDOROV	{"email": "sidorov.nikolay28011974@postgrespro.ru", "phone": "+70230230579"}
0005434351725	153B91	9485 655538	ANDREY ZAKHAROV	{"phone": "+70285014092"}
0005434351726	F868F0	1460 720271	ELENA DMITRIEVA	{"phone": "+70206600977"}
0005434351727	943EC2	2940 689270	NIKITA VASILEV	{"phone": "+70579004396"}
0005434351728	33A7EA	3502 039977	ELVIRA ROMANOVA	{"phone": "+70750079947"}
0005434351729	33A7EA	0478 770726	TATYANA AFANASEVA	{"phone": "+70871110155"}
0005434351730	A36DCD	1286 593229	ALEFTINA KARPOVA	{"email": "karpovaaleftina-24051967@postgrespro.ru", "phone": "+70295954491"}
0005434351731	D425E8	9679 422790	ALEKSEY VASILEV	{"phone": "+70202378347"}
0005434351732	B7D51A	0941 048463	LYUBOV MALYSHEVA	{"phone": "+70595593071"}
0005434351733	B7D51A	7702 154289	NINA KUZNECOVA	{"phone": "+70462466408"}
0005434351734	B7D51A	5137 911903	LYUDMILA ISAEVA	{"phone": "+70947614584"}
0005434351735	39B6FD	1101 649389	MAYYA SIDOROVA	{"email": "m-sidorova1978@postgrespro.ru", "phone": "+70556242985"}
0005434351736	A0EB54	0295 065099	ALEKSEY SOKOLOV	{"phone": "+70963905441"}
0005434351737	9CB2E3	1283 376551	SERGEY KUZNECOV	{"email": "kuznecov-s041976@postgrespro.ru", "phone": "+70895356691"}
0005434351738	523528	9667 209169	NIKOLAY ROMANOV	{"email": "romanov-n_29061973@postgrespro.ru", "phone": "+70176105369"}
0005434351739	523528	8216 625778	ALEKSEY PETROV	{"phone": "+70434131405"}
0005434351740	39C10D	2170 729782	ALEKSANDR DAVYDOV	{"email": "davydov.a1974@postgrespro.ru", "phone": "+70039315984"}
0005434351741	EB3A88	8076 836338	EVGENIY MAKSIMOV	{"phone": "+70961532793"}
0005434351742	A76D33	3864 187997	ANNA PETROVA	{"phone": "+70509219913"}
0005434351743	A76D33	8669 573693	ALEKSANDR KUZNECOV	{"phone": "+70387691496"}
0005434351744	F87089	1377 304472	GALINA IVANOVA	{"phone": "+70495855959"}
0005434351745	F87089	4431 977725	IGOR SIDOROV	{"phone": "+70598281605"}
0005434351746	A95683	0902 010707	NIKITA SIDOROV	{"phone": "+70480685056"}
0005434351747	367BA0	0144 680234	VIKTOR MOROZOV	{"email": "morozovv-24011972@postgrespro.ru", "phone": "+70256492349"}
0005434351748	52B319	8733 357839	NADEZHDA GUSEVA	{"phone": "+70289484975"}
0005434351749	71B3DC	8215 023102	VERONIKA SEMENOVA	{"phone": "+70347265193"}
0005434351750	82A6FB	3052 071745	YULIYA KOROLEVA	{"phone": "+70223562256"}
0005434351751	B625D8	6428 231309	NATALYA EFIMOVA	{"phone": "+70132185740"}
0005434351752	4E544F	6980 066173	MIKHAIL MAKAROV	{"phone": "+70668473386"}
0005434351753	4E544F	7185 706764	NADEZHDA MOROZOVA	{"phone": "+70540876445"}
0005434351754	D4DB8B	7105 484063	PAVEL CHERNOV	{"phone": "+70189355014"}
0005434351755	D4DB8B	8653 197136	MARIYA SEMENOVA	{"email": "semenova.mariya13011966@postgrespro.ru", "phone": "+70943071407"}
0005434351756	FC40B6	1864 044594	GEORGIY VASILEV	{"phone": "+70082912333"}
0005434351757	FC40B6	8396 277248	VALERIY MOROZOV	{"phone": "+70171253427"}
0005434351758	535D7D	0965 232829	EKATERINA GORBUNOVA	{"phone": "+70427980437"}
0005434351759	535D7D	4978 599621	ARTEM GERASIMOV	{"phone": "+70413252718"}
0005434351760	7A0BAA	7670 144614	DMITRIY STEPANOV	{"email": "stepanov-d_1967@postgrespro.ru", "phone": "+70307761657"}
0005434351761	CEB7B2	3291 483169	NATALYA LAZAREVA	{"email": "natalya-lazareva.23051957@postgrespro.ru", "phone": "+70911171648"}
0005434351762	D4EC60	4925 169962	NIKOLAY VOLKOV	{"email": "volkov.n.12081965@postgrespro.ru", "phone": "+70409556717"}
0005434351763	8066CE	4483 707090	DARYA ABRAMOVA	{"phone": "+70371684437"}
0005434351764	8C7CD1	3916 805127	VIKTOR GUSEV	{"phone": "+70045493008"}
0005434351765	D0DD0B	0494 139708	MARIYA KONOVALOVA	{"phone": "+70251466452"}
0005434351766	B617DC	5286 388246	SERGEY ZAKHAROV	{"email": "sergeyzakharov.041970@postgrespro.ru", "phone": "+70732827563"}
0005434351767	DFB0E9	1482 371254	OLEG NOVIKOV	{"email": "novikov_oleg.11081978@postgrespro.ru", "phone": "+70994902352"}
0005434351768	DFB0E9	8882 478540	VALENTINA SOKOLOVA	{"email": "sokolova_v_1968@postgrespro.ru", "phone": "+70945018374"}
0005434351769	D89F3B	9558 270275	TAMARA ZAYCEVA	{"phone": "+70524333159"}
0005434351770	C9B761	1184 372490	SEMEN KAZAKOV	{"phone": "+70761894196"}
0005434351771	C9B761	8049 165803	VIKTOR VOROBEV	{"email": "v.vorobev-21011964@postgrespro.ru", "phone": "+70863365743"}
0005434351772	86F5F7	4886 345838	VASILIY FILIPPOV	{"phone": "+70346511939"}
0005434351773	CAF4B0	7460 658862	ALEKSANDR CHERNOV	{"email": "a-chernov_25011978@postgrespro.ru", "phone": "+70045804729"}
0005434351774	CAF4B0	8978 228180	VLADIMIR FEDOROV	{"email": "vladimir_fedorov.1982@postgrespro.ru", "phone": "+70894058079"}
0005434351775	8E81AC	8630 190125	ALEKSEY GERASIMOV	{"email": "gerasimov.aleksey_1963@postgrespro.ru", "phone": "+70094457760"}
0005434351776	D0D224	8680 013138	LYUBOV DMITRIEVA	{"email": "dmitrieval1968@postgrespro.ru", "phone": "+70112481770"}
0005434351777	A2A932	0851 053954	VASILIY FROLOV	{"email": "v_frolov-1990@postgrespro.ru", "phone": "+70193699561"}
0005434351778	280B23	8599 534553	OLGA ALEKSEEVA	{"phone": "+70669726845"}
0005434351779	54F221	5518 462572	VALERIY GUSEV	{"email": "gusev.valeriy.051972@postgrespro.ru", "phone": "+70823582474"}
0005434351780	FB0AA4	8821 676537	ANDREY FEDOTOV	{"email": "afedotov.31071970@postgrespro.ru", "phone": "+70067770947"}
0005434351782	84799F	2986 723801	VASILIY FROLOV	{"email": "vasiliy-frolov.20071976@postgrespro.ru", "phone": "+70913175493"}
0005434351783	9236FA	2898 276683	SOFYA PETROVA	{"phone": "+70872256595"}
0005434351784	9236FA	1666 424399	MAKSIM GAVRILOV	{"phone": "+70109920843"}
0005434351785	EDA1F3	0935 880390	NIKOLAY IVANOV	{"email": "ivanov.nikolay-1969@postgrespro.ru", "phone": "+70811440984"}
0005434351786	EF4005	1377 126157	DARYA MOROZOVA	{"phone": "+70294526314"}
0005434351787	32DE88	9722 702635	EVGENIY BORISOV	{"phone": "+70084430675"}
0005434351788	1A4821	6393 255902	ANASTASIYA ZHURAVLEVA	{"phone": "+70184319474"}
0005434351789	28EBC0	7935 243876	LEV BORISOV	{"phone": "+70431741191"}
0005434351790	35023C	8325 677859	SVETLANA KOVALEVA	{"email": "kovaleva-s111979@postgrespro.ru", "phone": "+70556562352"}
0005434351791	35023C	5757 502266	EVGENIY SAVELEV	{"email": "evgeniy.savelev_1975@postgrespro.ru", "phone": "+70518226764"}
0005434351792	1556FC	4034 188378	SVETLANA SMIRNOVA	{"email": "svetlana_smirnova.1972@postgrespro.ru", "phone": "+70352617915"}
0005434351793	1556FC	0462 774447	NADEZHDA DENISOVA	{"phone": "+70910179167"}
0005434351794	F770EB	7531 368702	LYUBOV KULIKOVA	{"phone": "+70101082752"}
0005434351795	B1A1C1	4315 762997	YURIY SAVELEV	{"email": "yuriysavelev-071968@postgrespro.ru", "phone": "+70197863456"}
0005434351796	B1A1C1	2073 754077	VLADIMIR TIMOFEEV	{"email": "vladimir.timofeev.121961@postgrespro.ru", "phone": "+70350490884"}
0005434351797	054A4E	5706 161678	ANDREY KOZLOV	{"email": "kozlov_andrey.111974@postgrespro.ru", "phone": "+70737558597"}
0005434351798	054A4E	3638 916138	ALEKSEY KULIKOV	{"email": "alekseykulikov041976@postgrespro.ru", "phone": "+70700443615"}
0005434351799	054A4E	6346 532783	NADEZHDA VASILEVA	{"phone": "+70961572415"}
0005434351800	0DE039	7701 236037	EVGENIY GERASIMOV	{"email": "evgeniygerasimov.041970@postgrespro.ru", "phone": "+70566737310"}
0005434351801	DF2D9B	8376 438164	OLGA YAKOVLEVA	{"phone": "+70267562692"}
0005434351802	CAC89E	0666 599192	LYUBOV POPOVA	{"phone": "+70655046286"}
0005434351803	5C45E2	5773 204301	ALBINA KOVALEVA	{"email": "albinakovaleva-121975@postgrespro.ru", "phone": "+70344806470"}
0005434351804	1EF3B8	2205 617931	EKATERINA VASILEVA	{"email": "evasileva-1971@postgrespro.ru", "phone": "+70688358982"}
0005434351805	E1E116	0163 707685	IRINA BELOVA	{"phone": "+70139988824"}
0005434351806	958489	9761 920095	DENIS ZAKHAROV	{"phone": "+70635720254"}
0005434351807	CE165D	5492 865545	ANASTASIYA KOZLOVA	{"email": "kozlova_anastasiya_29071978@postgrespro.ru", "phone": "+70904933252"}
0005434351808	CE165D	0328 102587	VIKTORIYA KULIKOVA	{"email": "kulikovav-1970@postgrespro.ru", "phone": "+70530362763"}
0005434351809	CE165D	1213 827765	ALEKSANDR ABRAMOV	{"phone": "+70274210376"}
0005434351810	93CABF	1942 373149	ALINA STEPANOVA	{"phone": "+70335316505"}
0005434351811	7DA9A2	1679 856202	YURIY VOROBEV	{"phone": "+70075396878"}
0005434351812	889DDE	2547 937850	SVETLANA GORBUNOVA	{"phone": "+70518130402"}
0005434351813	6D5C6F	7716 569850	LIDIYA KULIKOVA	{"phone": "+70005060891"}
0005434351814	1BCACE	0190 820657	ANASTASIYA KOLESNIKOVA	{"email": "a-kolesnikova.121960@postgrespro.ru", "phone": "+70805688915"}
0005434351815	465DBF	1804 114591	TAMARA POLYAKOVA	{"phone": "+70649306775"}
0005434351816	F3D87B	7771 821187	MAKSIM KUZMIN	{"email": "kuzmin_m.121986@postgrespro.ru", "phone": "+70555079201"}
0005434351817	6F6EE2	8415 483941	VALENTINA MELNIKOVA	{"email": "melnikova.valentina28071976@postgrespro.ru", "phone": "+70360383015"}
0005434351818	B18606	1360 010850	DMITRIY KULIKOV	{"phone": "+70103806078"}
0005434351819	7C3F67	9499 986031	ANTONINA KAZAKOVA	{"phone": "+70804658958"}
0005434351820	26005E	4994 713939	LYUBOV EGOROVA	{"email": "lyubov.egorova.11091967@postgrespro.ru", "phone": "+70921228719"}
0005434351821	26005E	9384 211796	MAKSIM NAZAROV	{"phone": "+70931185132"}
0005434351822	0E4689	3508 245659	VYACHESLAV IVANOV	{"phone": "+70008162253"}
0005434351823	CFF309	5073 328310	SVETLANA MAKAROVA	{"email": "svetlanamakarova_1977@postgrespro.ru", "phone": "+70424283539"}
0005434351824	97F703	5080 153086	MARIYA MIRONOVA	{"phone": "+70359497050"}
0005434351825	54D1BE	5692 529672	OLGA KULIKOVA	{"email": "kulikova-o1983@postgrespro.ru", "phone": "+70230446482"}
0005434351826	54D1BE	3277 740160	VADIM MOISEEV	{"phone": "+70727820887"}
0005434351827	0582AF	4020 654343	MARINA RODIONOVA	{"email": "rodionova-marina-10111975@postgrespro.ru", "phone": "+70588380441"}
0005434351828	349904	4751 495791	GALINA VOLKOVA	{"phone": "+70665537077"}
0005434351829	349904	0525 162637	OLGA KUZNECOVA	{"email": "o_kuznecova-021975@postgrespro.ru", "phone": "+70836702567"}
0005434351830	005C47	3780 483123	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey1987@postgrespro.ru", "phone": "+70700974807"}
0005434351831	42EA2A	8359 490446	VERONIKA IVANOVA	{"email": "vivanova.051963@postgrespro.ru", "phone": "+70798221939"}
0005434351832	E0DF7F	7058 018035	IGOR KOZLOV	{"phone": "+70050906069"}
0005434351833	E0DF7F	8203 768603	ANATOLIY ZAKHAROV	{"email": "a.zakharov-1969@postgrespro.ru", "phone": "+70273125016"}
0005434351834	3527F0	0689 495858	TATYANA STEPANOVA	{"email": "stepanova_t111971@postgrespro.ru", "phone": "+70911756108"}
0005434351835	7DB902	5776 714024	NATALYA ZHUKOVA	{"phone": "+70890479316"}
0005434351836	241492	5613 883628	NADEZHDA ALEKSEEVA	{"email": "alekseevanadezhda-30041967@postgrespro.ru", "phone": "+70214731218"}
0005434351837	241492	5499 478329	ELEONORA VOLKOVA	{"phone": "+70210877882"}
0005434351838	942FF0	2062 412953	IVAN FEDOTOV	{"email": "ivan_fedotov.17041968@postgrespro.ru", "phone": "+70227913082"}
0005434351839	942FF0	1912 600322	TATYANA KOROLEVA	{"email": "t-koroleva_051971@postgrespro.ru", "phone": "+70254164366"}
0005434351840	18094E	3205 578601	RAISA NAZAROVA	{"email": "raisanazarova121979@postgrespro.ru", "phone": "+70374259823"}
0005434351841	18094E	7050 452165	IVAN GORBUNOV	{"phone": "+70266853081"}
0005434351842	EA526D	0507 738701	IRINA KUZNECOVA	{"phone": "+70391638469"}
0005434351843	EA526D	0895 089992	ALEKSANDR KUZMIN	{"phone": "+70624400053"}
0005434351844	B08858	1748 981250	VLADIMIR SOKOLOV	{"phone": "+70270348593"}
0005434351845	B08858	9447 892819	ANDREY KOZLOV	{"email": "kozlov-andrey-08021979@postgrespro.ru", "phone": "+70849504517"}
0005434351846	001C4B	8729 472478	ANDREY PAVLOV	{"email": "pavlov_a_1963@postgrespro.ru", "phone": "+70484515131"}
0005434351847	061703	5078 575789	NIKOLAY NOVIKOV	{"email": "nnovikov.26091968@postgrespro.ru", "phone": "+70634955559"}
0005434351848	898F49	5181 388077	RAMIL SCHERBAKOV	{"phone": "+70515326838"}
0005434351849	2AA128	4049 843116	EKATERINA SMIRNOVA	{"phone": "+70283339147"}
0005434351850	2AA128	3845 032334	IVAN MEDVEDEV	{"phone": "+70544025676"}
0005434351851	FCC245	3609 758269	ALEKSANDR FEDOROV	{"phone": "+70009701405"}
0005434351852	6583B4	1750 506621	VALERIYA ABRAMOVA	{"phone": "+70545213298"}
0005434351853	6583B4	8737 245204	GEORGIY MELNIKOV	{"email": "melnikov_georgiy_031977@postgrespro.ru", "phone": "+70866190830"}
0005434351854	661452	2099 741939	MARINA AKIMOVA	{"email": "akimova-marina_021969@postgrespro.ru", "phone": "+70415443437"}
0005434351855	CBDEF3	9696 787424	VALENTIN VOLKOV	{"email": "volkovvalentin.121973@postgrespro.ru", "phone": "+70139848831"}
0005434351856	914DE8	7831 937516	EVGENIY VOROBEV	{"email": "evgeniyvorobev.051974@postgrespro.ru", "phone": "+70729402999"}
0005434351857	741B8E	1978 379660	ANDREY KISELEV	{"phone": "+70416951646"}
0005434351858	741B8E	2186 560022	SVETLANA GAVRILOVA	{"phone": "+70928884282"}
0005434351859	48D9B7	8939 640503	OKSANA KARPOVA	{"email": "karpova.oksana06071975@postgrespro.ru", "phone": "+70041098530"}
0005434351860	8060BD	2178 440096	DANILA SAVELEV	{"phone": "+70412452335"}
0005434351861	B0658E	2136 633348	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.061960@postgrespro.ru", "phone": "+70272103786"}
0005434351862	49C48D	2611 176809	SERGEY NAZAROV	{"email": "s.nazarov1981@postgrespro.ru", "phone": "+70236924558"}
0005434351863	80FFE1	1674 542371	OLGA KUZNECOVA	{"email": "olga-kuznecova_121980@postgrespro.ru", "phone": "+70321190347"}
0005434351864	BA5FF0	8104 073306	VALENTINA POLYAKOVA	{"phone": "+70819797251"}
0005434351865	E66A6E	3995 192154	DMITRIY SAVELEV	{"email": "d.savelev-061966@postgrespro.ru", "phone": "+70785982492"}
0005434351866	E66A6E	6339 720687	VALENTINA AFANASEVA	{"email": "v_afanaseva-1966@postgrespro.ru", "phone": "+70354834981"}
0005434351867	E6F5DF	3568 726579	OLESYA ANDREEVA	{"phone": "+70329022735"}
0005434351868	8B42E9	4176 071824	NIKOLAY SMIRNOV	{"phone": "+70747228733"}
0005434351869	8B42E9	6875 169509	MARINA AFANASEVA	{"email": "marinaafanaseva.1976@postgrespro.ru", "phone": "+70019408920"}
0005434351870	1C80CF	5664 813557	NADEZHDA NIKOLAEVA	{"email": "nikolaeva_nadezhda_121975@postgrespro.ru", "phone": "+70091229825"}
0005434351871	198DDD	9911 044735	ELENA NIKOLAEVA	{"phone": "+70975815945"}
0005434351872	6583F8	7796 293504	VIKTORIYA CHERNOVA	{"email": "chernova.viktoriya-28111981@postgrespro.ru", "phone": "+70882892673"}
0005434351873	6583F8	9466 820439	OLGA NAUMOVA	{"email": "naumovao-30091966@postgrespro.ru", "phone": "+70784076012"}
0005434351874	6583F8	1725 631626	LYUBOV MAKAROVA	{"phone": "+70852307576"}
0005434351875	AD14DE	1915 198685	VLADIMIR DMITRIEV	{"phone": "+70101671267"}
0005434351876	5DC0F4	8111 438301	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey-1979@postgrespro.ru", "phone": "+70606009880"}
0005434351877	622186	2218 822000	TATYANA FILIPPOVA	{"phone": "+70438790329"}
0005434351878	426C79	6333 979924	ANASTASIYA SAVELEVA	{"email": "saveleva.anastasiya1973@postgrespro.ru", "phone": "+70178134823"}
0005434351879	426C79	9053 514579	GENNADIY KAZAKOV	{"email": "kazakovg-091980@postgrespro.ru", "phone": "+70316601633"}
0005434351880	F7559A	1815 765084	NIKOLAY MIRONOV	{"email": "mironovn-041977@postgrespro.ru", "phone": "+70138506263"}
0005434351881	F7559A	7172 197499	VLADISLAV SCHERBAKOV	{"email": "v-scherbakov.1972@postgrespro.ru", "phone": "+70294805807"}
0005434351882	2A08DF	3875 712885	NINA NOVIKOVA	{"phone": "+70886592050"}
0005434351883	2A08DF	7243 117273	NATALYA SIDOROVA	{"phone": "+70067164949"}
0005434351884	D4FB59	8504 393076	VALENTINA LUKYANOVA	{"email": "lukyanova-valentina.1953@postgrespro.ru", "phone": "+70049022291"}
0005434351885	D4FB59	7976 689221	POLINA MOROZOVA	{"email": "morozovap101970@postgrespro.ru", "phone": "+70976990090"}
0005434351886	E7DC96	3653 581278	ALEKSANDR IVANOV	{"phone": "+70568199290"}
0005434351887	9769BD	7398 664655	YANA DANILOVA	{"email": "yana-danilova-27051960@postgrespro.ru", "phone": "+70471172866"}
0005434351888	66EFF2	8714 595670	LEYLA KUZNECOVA	{"phone": "+70928403846"}
0005434351889	66EFF2	8171 915643	NIKITA NIKOLAEV	{"email": "nikita-nikolaev_1968@postgrespro.ru", "phone": "+70799993340"}
0005434351890	746965	8319 657949	AMIR PAVLOV	{"email": "a.pavlov_011979@postgrespro.ru", "phone": "+70710445851"}
0005434351891	C20E5A	3338 210178	ANDREY MAKSIMOV	{"phone": "+70816783350"}
0005434351892	07A4C4	6104 024630	VLADIMIR PETROV	{"email": "petrovv1969@postgrespro.ru", "phone": "+70986235821"}
0005434351893	009954	6541 905738	VERONIKA MAKSIMOVA	{"phone": "+70014115873"}
0005434351895	7D7517	6167 378286	NADEZHDA MAKAROVA	{"email": "n_makarova.121972@postgrespro.ru", "phone": "+70627489671"}
0005434351896	F483F2	1412 983238	EVGENIY KONOVALOV	{"email": "konovalovevgeniy.04021983@postgrespro.ru", "phone": "+70904253152"}
0005434351897	45068A	7027 496719	INGA AFANASEVA	{"phone": "+70966356550"}
0005434351898	905452	6627 164984	KONSTANTIN ZHURAVLEV	{"phone": "+70907757869"}
0005434351899	577D43	1947 189307	PAVEL KRASNOV	{"phone": "+70348803080"}
0005434351900	577D43	6468 846061	ALENA NAUMOVA	{"phone": "+70968527944"}
0005434351901	C2C25A	4790 869733	ELENA GAVRILOVA	{"email": "elenagavrilova11061975@postgrespro.ru", "phone": "+70185359509"}
0005434351902	C2C25A	4350 719673	ELENA SCHERBAKOVA	{"email": "scherbakova_elena.26091977@postgrespro.ru", "phone": "+70387465665"}
0005434351903	B8C0DD	3918 737119	IVAN VASILEV	{"email": "vasilev_i1971@postgrespro.ru", "phone": "+70256182767"}
0005434351904	5DBB61	3926 591158	ALEKSANDR STEPANOV	{"phone": "+70153671375"}
0005434351905	16E6A1	3912 252793	RAVIL OSIPOV	{"email": "osipov.r_1971@postgrespro.ru", "phone": "+70300571445"}
0005434351906	78DE75	3105 289804	DMITRIY MIKHAYLOV	{"phone": "+70385236079"}
0005434351907	9408B9	2134 732459	MAKSIM SOLOVEV	{"phone": "+70956385031"}
0005434351908	36EA95	8049 327847	ARSEN MAKSIMOV	{"email": "arsen.maksimov.021977@postgrespro.ru", "phone": "+70222602213"}
0005434351909	0B9A48	7558 982074	LYUDMILA TIKHONOVA	{"phone": "+70944366757"}
0005434351910	4F5F4B	8304 462173	ARINA NIKOLAEVA	{"email": "nikolaeva_arina.1962@postgrespro.ru", "phone": "+70168060138"}
0005434351911	24EF26	4439 540401	MAKSIM PETROV	{"phone": "+70138517564"}
0005434351912	24EF26	7622 791721	VASILIY KUZMIN	{"email": "kuzmin_v-1983@postgrespro.ru", "phone": "+70974017943"}
0005434351913	2D7C9B	0457 930535	DMITRIY GRIGOREV	{"email": "grigorev_d_1960@postgrespro.ru", "phone": "+70247624016"}
0005434351914	2D7C9B	9221 930659	ALEKSANDR KAZAKOV	{"email": "kazakov-aleksandr-27121989@postgrespro.ru", "phone": "+70304951767"}
0005434351915	2D7C9B	6698 587909	NIKITA NIKOLAEV	{"email": "n.nikolaev_22121969@postgrespro.ru", "phone": "+70523229467"}
0005434351916	507A3D	4795 995098	LARISA KUZNECOVA	{"phone": "+70357574444"}
0005434351917	F182B8	4580 560265	IRINA KUZNECOVA	{"phone": "+70233963467"}
0005434351974	81B0A8	2411 106008	VLADISLAV GRIGOREV	{"phone": "+70529886260"}
0005434351918	F182B8	9349 056246	EKATERINA BARANOVA	{"email": "baranova_ekaterina-091970@postgrespro.ru", "phone": "+70016113736"}
0005434351919	F182B8	1128 333431	BORIS BORISOV	{"phone": "+70774938288"}
0005434351920	9A5309	5855 254166	ANATOLIY BARANOV	{"phone": "+70057294651"}
0005434351921	254461	2769 317337	VITALIY KAZAKOV	{"phone": "+70826131969"}
0005434351922	254461	4258 915816	VALERIY ORLOV	{"email": "v_orlov1982@postgrespro.ru", "phone": "+70354802344"}
0005434351923	7A9E21	7076 431690	VIKTOR CHERNOV	{"email": "viktor-chernov.041966@postgrespro.ru", "phone": "+70073155326"}
0005434351924	995673	8733 329673	FEDOR DMITRIEV	{"email": "f_dmitriev_09031957@postgrespro.ru", "phone": "+70904353767"}
0005434351925	AA8701	1427 102468	MIKHAIL ZAKHAROV	{"email": "zakharovmikhail20051966@postgrespro.ru", "phone": "+70395306463"}
0005434351926	AA8701	2078 815754	NATALIYA VASILEVA	{"email": "nataliya.vasileva-05091972@postgrespro.ru", "phone": "+70460285963"}
0005434351927	BE3C9A	3850 355154	DARYA SERGEEVA	{"phone": "+70619291025"}
0005434351928	5E8F04	3011 152712	LYUBOV ISAEVA	{"phone": "+70948283700"}
0005434351929	F5DF19	7793 467878	ELENA EFIMOVA	{"email": "efimova.elena_17011973@postgrespro.ru", "phone": "+70703363655"}
0005434351930	F22B45	1587 109637	ALEKSANDR SOLOVEV	{"phone": "+70043153765"}
0005434351931	500DA8	5067 542579	ALEKSEY GERASIMOV	{"phone": "+70155747083"}
0005434351932	4B6B91	4768 353604	VALERIY VOLKOV	{"email": "valeriyvolkov.10101958@postgrespro.ru", "phone": "+70412396557"}
0005434351933	EA717B	6566 432173	RAISA SOKOLOVA	{"email": "sokolova.raisa-15051969@postgrespro.ru", "phone": "+70926251431"}
0005434351934	FA2870	5656 561825	TAMARA AFANASEVA	{"email": "afanaseva.tamara.16031979@postgrespro.ru", "phone": "+70086930956"}
0005434351935	32AE49	1251 112138	SVETLANA ALEKSANDROVA	{"phone": "+70520780432"}
0005434351936	7EA879	6952 424609	NINA ALEKSEEVA	{"phone": "+70737802148"}
0005434351937	EBCC68	3933 986543	LIDIYA DMITRIEVA	{"phone": "+70088275496"}
0005434351938	752372	8801 821313	IRINA SEMENOVA	{"phone": "+70691892628"}
0005434351939	90AE51	5514 845599	OLEG SEMENOV	{"phone": "+70150715817"}
0005434351940	9E54C8	2478 828186	RUSLAN ANTONOV	{"email": "antonov.ruslan.1967@postgrespro.ru", "phone": "+70432011274"}
0005434351941	5026A0	1823 118469	LYUDMILA ZAKHAROVA	{"email": "zakharova_l.1966@postgrespro.ru", "phone": "+70340846675"}
0005434351942	DD1468	9806 072095	DMITRIY MEDVEDEV	{"phone": "+70888514397"}
0005434351943	DD1468	3647 681096	NADEZHDA KAZAKOVA	{"phone": "+70656709772"}
0005434351944	5DF4DE	8167 615881	YULIYA NAUMOVA	{"email": "naumova-yuliya-1962@postgrespro.ru", "phone": "+70536432205"}
0005434351945	AFD41B	3653 625635	OKSANA KONDRATEVA	{"phone": "+70186175981"}
0005434351946	AFD41B	7393 132698	ALEKSANDR TIKHONOV	{"email": "tikhonov-a.091980@postgrespro.ru", "phone": "+70982322706"}
0005434351947	359D80	3941 376276	MARIYA NAUMOVA	{"phone": "+70358395993"}
0005434351948	359D80	7052 013188	ALEKSANDR KOZLOV	{"email": "kozlov-a-1974@postgrespro.ru", "phone": "+70668830207"}
0005434351949	F57A28	3423 413959	SERGEY KUZNECOV	{"phone": "+70036961652"}
0005434351950	34326D	3386 176510	ANASTASIYA NIKITINA	{"phone": "+70291843847"}
0005434351951	34326D	9982 620693	DANIIL MOISEEV	{"email": "d_moiseev13101966@postgrespro.ru", "phone": "+70532396439"}
0005434351952	D888BA	5751 532049	OKSANA KAZAKOVA	{"email": "kazakovaoksana.1974@postgrespro.ru", "phone": "+70165933300"}
0005434351953	D888BA	0583 436189	ALLA MAKSIMOVA	{"phone": "+70280928818"}
0005434351954	ABD536	5211 768787	SVETLANA MEDVEDEVA	{"phone": "+70341432448"}
0005434351955	071A34	1841 666806	EGOR MIKHAYLOV	{"email": "egormikhaylov_1969@postgrespro.ru", "phone": "+70663076947"}
0005434351956	1D374F	2778 621038	VLADIMIR PETROV	{"email": "vladimir_petrov121958@postgrespro.ru", "phone": "+70277378694"}
0005434351957	92D603	6218 861853	VALENTINA GAVRILOVA	{"email": "gavrilova-v1968@postgrespro.ru", "phone": "+70673909056"}
0005434351958	D7B704	3456 351665	EVGENIY KOZLOV	{"phone": "+70389908792"}
0005434351959	D7B704	8513 574632	GALINA BOGDANOVA	{"email": "bogdanova-g121974@postgrespro.ru", "phone": "+70189358495"}
0005434351960	B24855	9826 228739	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr1966@postgrespro.ru", "phone": "+70467105103"}
0005434351961	748C24	0982 077537	TAMARA KOLESNIKOVA	{"email": "tamara-kolesnikova.22061969@postgrespro.ru", "phone": "+70224676976"}
0005434351962	5A66F6	6912 807484	RIMMA IVANOVA	{"phone": "+70825328339"}
0005434351963	5A66F6	3222 393451	OLEG SOLOVEV	{"email": "solovev.o-05021975@postgrespro.ru", "phone": "+70233861088"}
0005434351964	B5166F	6505 436770	TATYANA ZAYCEVA	{"phone": "+70453223014"}
0005434351965	8DA928	2961 221055	ALEKSANDR BARANOV	{"email": "abaranov_1979@postgrespro.ru", "phone": "+70533166750"}
0005434351966	8DA928	7858 854182	MARINA MEDVEDEVA	{"phone": "+70488190657"}
0005434351967	B13C88	8750 215071	MILENA SMIRNOVA	{"phone": "+70262057790"}
0005434351968	147B05	2463 264481	RUSLAN MIKHAYLOV	{"email": "mikhaylov.r1978@postgrespro.ru", "phone": "+70411540137"}
0005434351969	0F26B6	1520 997988	VLADIMIR ZHURAVLEV	{"email": "zhuravlevv.121965@postgrespro.ru", "phone": "+70258643939"}
0005434351970	0F26B6	2476 923569	ULYANA AKIMOVA	{"phone": "+70674714876"}
0005434351971	284116	9028 475848	IVAN MEDVEDEV	{"email": "imedvedev-091975@postgrespro.ru", "phone": "+70343652436"}
0005434351972	125D8E	3701 563917	LIDIYA GAVRILOVA	{"email": "lidiya.gavrilova-25041973@postgrespro.ru", "phone": "+70474069682"}
0005434351973	81B0A8	8750 662694	ALEKSEY ZHUKOV	{"email": "a-zhukov_1984@postgrespro.ru", "phone": "+70033212233"}
0005434351975	4CE700	0915 334499	MARAT KISELEV	{"email": "m.kiselev-29121968@postgrespro.ru", "phone": "+70673871830"}
0005434351976	6BC690	3894 904756	DMITRIY MAKAROV	{"email": "makarov_d.04021965@postgrespro.ru", "phone": "+70918702053"}
0005434351977	295C03	3309 075575	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey12071980@postgrespro.ru", "phone": "+70983637022"}
0005434351978	295C03	3937 216685	EVGENIY ZAYCEV	{"email": "zaycev.evgeniy1956@postgrespro.ru", "phone": "+70824622074"}
0005434351979	002BB2	5922 381515	LYUDMILA KARPOVA	{"phone": "+70055326844"}
0005434351980	D75481	3209 300490	ALEKSANDR DENISOV	{"phone": "+70337787065"}
0005434351981	703615	0565 276116	ARTEM TIKHONOV	{"phone": "+70157433770"}
0005434351982	864AD2	1385 582691	ANATOLIY NIKITIN	{"email": "nikitinanatoliy-29071976@postgrespro.ru", "phone": "+70994428539"}
0005434351983	CFEA66	0517 735303	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy_051982@postgrespro.ru", "phone": "+70944592153"}
0005434351984	8CBA1D	5733 966883	NADEZHDA KOVALEVA	{"phone": "+70824183519"}
0005434351985	8CBA1D	1657 550513	SVETLANA SIDOROVA	{"email": "sidorovasvetlana1962@postgrespro.ru", "phone": "+70623425566"}
0005434351986	14549D	8573 319933	DIANA KRASNOVA	{"email": "diana-krasnova1967@postgrespro.ru", "phone": "+70183033634"}
0005434351987	14549D	2125 265122	SERGEY MAKAROV	{"email": "s.makarov_061973@postgrespro.ru", "phone": "+70094416099"}
0005434351988	A9C6F7	8291 262563	GLEB ZAYCEV	{"email": "zaycevgleb_031972@postgrespro.ru", "phone": "+70402334091"}
0005434351989	499680	1285 048350	PAVEL KUZMIN	{"email": "p.kuzmin121973@postgrespro.ru", "phone": "+70833855063"}
0005434351990	670A68	5853 881207	ALEKSEY KAZAKOV	{"email": "akazakov29101969@postgrespro.ru", "phone": "+70051342848"}
0005434351991	47EBFB	9947 588926	ALEKSEY NIKITIN	{"email": "nikitin-aleksey.1979@postgrespro.ru", "phone": "+70465517832"}
0005434351992	F188A5	8025 669946	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir-121975@postgrespro.ru", "phone": "+70088114635"}
0005434351993	1CBEEE	1523 321095	NIKITA NIKITIN	{"email": "n.nikitin-07041966@postgrespro.ru", "phone": "+70326701774"}
0005434351994	FB0D39	7083 562692	KLAVDIYA PETROVA	{"email": "kpetrova.06021978@postgrespro.ru", "phone": "+70762106432"}
0005434351995	FB0D39	2521 534109	VLADIMIR ROMANOV	{"phone": "+70381267453"}
0005434351996	AE9006	3283 658600	EKATERINA MARTYNOVA	{"email": "martynova-ekaterina_21031969@postgrespro.ru", "phone": "+70568733920"}
0005434351997	AE9006	6635 224439	GALINA PAVLOVA	{"email": "pavlovagalina_101975@postgrespro.ru", "phone": "+70644214632"}
0005434351998	2FEC0D	8778 340673	NATALYA DANILOVA	{"email": "natalya_danilova_1965@postgrespro.ru", "phone": "+70341431185"}
0005434351999	B87281	0831 948088	ELENA STEPANOVA	{"email": "stepanovaelena.1973@postgrespro.ru", "phone": "+70285490952"}
0005434352000	42C914	8055 726094	ALEKSEY BORISOV	{"phone": "+70840470508"}
0005434352001	2E5D62	3220 001294	YURIY MAKSIMOV	{"phone": "+70571120734"}
0005434352002	C1D953	1770 948838	MARINA KUZNECOVA	{"email": "kuznecova-m.111987@postgrespro.ru", "phone": "+70975914705"}
0005434352003	45B6B4	4884 254461	VLADISLAV POPOV	{"phone": "+70144753818"}
0005434352004	45B6B4	1823 801279	VLADIMIR VASILEV	{"email": "vasilev.v.17121971@postgrespro.ru", "phone": "+70840095197"}
0005434352005	3C3064	0879 246402	DENIS NIKITIN	{"email": "denis-nikitin.1978@postgrespro.ru", "phone": "+70997368361"}
0005434352006	3C3064	2753 919891	ALEKSANDR TIKHONOV	{"email": "tikhonova-16031968@postgrespro.ru", "phone": "+70319430428"}
0005434352007	662905	9069 337576	ALBINA SERGEEVA	{"email": "asergeeva-1982@postgrespro.ru", "phone": "+70801576342"}
0005434352008	D4669D	5664 670319	VLADIMIR STEPANOV	{"phone": "+70720715687"}
0005434352009	8FC8CD	7941 445201	ANATOLIY ZHURAVLEV	{"phone": "+70378743734"}
0005434352010	5018DB	2391 925747	LYUBOV ZAYCEVA	{"phone": "+70837880999"}
0005434352011	A9E9A5	2450 118112	SERGEY MATVEEV	{"email": "s.matveev_051970@postgrespro.ru", "phone": "+70555611696"}
0005434352012	665DFD	7466 067273	NINA ANTONOVA	{"email": "antonovan_1963@postgrespro.ru", "phone": "+70969122342"}
0005434352013	665DFD	0254 625978	LYUDMILA DMITRIEVA	{"email": "l-dmitrieva.15051966@postgrespro.ru", "phone": "+70380938169"}
0005434352014	552F1F	8282 698420	LILIYA POPOVA	{"email": "popova.liliya-21031964@postgrespro.ru", "phone": "+70950891944"}
0005434352015	724277	9771 831557	NADEZHDA KUZMINA	{"phone": "+70106489498"}
0005434352016	724277	6376 918754	VITALIY KUZMIN	{"phone": "+70821464258"}
0005434352017	3D2AF7	3848 895275	SHAMIL SOLOVEV	{"email": "shamil_solovev_07051974@postgrespro.ru", "phone": "+70201251145"}
0005434352018	444C75	6102 741518	NATALYA VOLKOVA	{"email": "volkovan081965@postgrespro.ru", "phone": "+70594589631"}
0005434352019	120FE9	8922 460001	NATALYA ANDREEVA	{"phone": "+70079705056"}
0005434352020	120FE9	8274 438470	VIKTORIYA SMIRNOVA	{"phone": "+70077466806"}
0005434352021	CFAA8B	4912 507943	GENNADIY KOZLOV	{"phone": "+70077473173"}
0005434352022	CFAA8B	0481 751039	LIDIYA EFIMOVA	{"phone": "+70853926574"}
0005434352023	6FE7D7	9074 719753	ELENA DMITRIEVA	{"email": "edmitrieva-081970@postgrespro.ru", "phone": "+70197147415"}
0005434352024	C88E7C	8089 667195	GALINA MIRONOVA	{"email": "galina_mironova_061974@postgrespro.ru", "phone": "+70587317637"}
0005434352025	144EDE	7908 401014	VENERA OVCHINNIKOVA	{"email": "ovchinnikovavenera-1963@postgrespro.ru", "phone": "+70492423416"}
0005434352026	144EDE	9729 905822	VLADIMIR KRASNOV	{"phone": "+70315659695"}
0005434352027	6A60AB	8789 086837	IGOR ZAKHAROV	{"phone": "+70013421997"}
0005434352028	B9E790	1784 589785	ANDREY NIKOLAEV	{"phone": "+70646370038"}
0005434352029	B9E790	8619 641759	LARISA BOGDANOVA	{"email": "l-bogdanova02111974@postgrespro.ru", "phone": "+70399931351"}
0005434352030	B9E790	4280 810077	NATALYA SOROKINA	{"email": "sorokina-natalya_091971@postgrespro.ru", "phone": "+70173060052"}
0005434352031	065E1D	7156 405906	VLADIMIR KARPOV	{"phone": "+70596152391"}
0005434352032	584E33	9344 268414	LYUDMILA LUKYANOVA	{"email": "lyudmila-lukyanova-24041976@postgrespro.ru", "phone": "+70670298531"}
0005434352033	E2021F	0326 934190	VLADIMIR KAZAKOV	{"email": "kazakov.v.01041973@postgrespro.ru", "phone": "+70333413641"}
0005434352034	E2021F	7639 189105	VYACHESLAV SOKOLOV	{"phone": "+70592412678"}
0005434352035	E033E0	6494 691847	LARISA ALEKSEEVA	{"phone": "+70755722375"}
0005434352036	C95677	3105 703032	MARIYA NAUMOVA	{"phone": "+70885943150"}
0005434352037	1ADCBA	1679 035043	SERGEY IVANOV	{"email": "ivanov_sergey1976@postgrespro.ru", "phone": "+70948160463"}
0005434352038	1ADCBA	7126 351252	NADEZHDA ANTONOVA	{"phone": "+70972034691"}
0005434352039	EB9FEF	1345 296650	ELIZAVETA KUZNECOVA	{"phone": "+70537885011"}
0005434352040	EB9FEF	7841 562138	ALEKSANDRA MEDVEDEVA	{"phone": "+70388900265"}
0005434352041	4FC409	0111 948539	SERGEY PAVLOV	{"email": "pavlovsergey-081968@postgrespro.ru", "phone": "+70238011677"}
0005434352042	4FC409	2477 879078	MIKHAIL KUDRYASHOV	{"phone": "+70415527719"}
0005434352043	6A457D	1822 384217	IGOR ZAKHAROV	{"phone": "+70648310238"}
0005434352044	6A457D	9625 358033	DMITRIY EGOROV	{"phone": "+70379967060"}
0005434352045	6A457D	4217 144241	NIKOLAY ALEKSEEV	{"email": "alekseev-n_18021968@postgrespro.ru", "phone": "+70329198539"}
0005434352046	4D34A2	6770 069079	ARTEM SMIRNOV	{"phone": "+70507069240"}
0005434352047	4D34A2	9316 406637	NADEZHDA SEMENOVA	{"email": "semenovan.07011982@postgrespro.ru", "phone": "+70631024605"}
0005434352048	90079F	7676 105893	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr091982@postgrespro.ru", "phone": "+70224910614"}
0005434352049	2D6032	1273 858821	VERONIKA ERMAKOVA	{"email": "ermakova_v.121968@postgrespro.ru", "phone": "+70927122445"}
0005434352050	302D26	2207 071870	SERGEY RODIONOV	{"email": "rodionovs1969@postgrespro.ru", "phone": "+70393149875"}
0005434352051	994D4A	5708 200659	IGOR VASILEV	{"email": "ivasilev.01051971@postgrespro.ru", "phone": "+70465427071"}
0005434352052	994D4A	8656 287611	VITALIY FEDOTOV	{"phone": "+70163914866"}
0005434352053	5E5FC2	1237 664411	SVETLANA ZAYCEVA	{"email": "zayceva-s.1957@postgrespro.ru", "phone": "+70091590670"}
0005434352054	69AFBD	8202 784193	IBRAGIM NIKITIN	{"email": "nikitin.i.12081969@postgrespro.ru", "phone": "+70811615099"}
0005434352055	634393	4001 210586	VYACHESLAV VOROBEV	{"email": "vyacheslav.vorobev.031977@postgrespro.ru", "phone": "+70083936281"}
0005434352056	48D720	6676 692048	MARIYA MAKAROVA	{"phone": "+70294290908"}
0005434352057	62E85D	8263 778010	SERGEY ZAYCEV	{"phone": "+70533621629"}
0005434352058	62E85D	8972 740855	PAVEL KUZNECOV	{"phone": "+70340300358"}
0005434352059	7D0507	1511 061797	POLINA FILIPPOVA	{"phone": "+70788123780"}
0005434352060	7D0507	3691 098053	NATALIYA SOROKINA	{"email": "nataliya.sorokina_061962@postgrespro.ru", "phone": "+70649817694"}
0005434352061	F3466F	5695 943198	ALEKSEY OSIPOV	{"phone": "+70589609078"}
0005434352062	657915	9645 434149	MAKSIM PAVLOV	{"email": "pavlov-maksim.031971@postgrespro.ru", "phone": "+70846354372"}
0005434352063	657915	8371 626207	ARTEM VLASOV	{"phone": "+70210842029"}
0005434352064	C4397B	4043 131800	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev.01021968@postgrespro.ru", "phone": "+70348217541"}
0005434352065	839B85	9000 398507	NINA ISAEVA	{"email": "n_isaeva-1972@postgrespro.ru", "phone": "+70566129320"}
0005434373846	0C8A68	2117 644601	ANATOLIY YAKOVLEV	{"phone": "+70254026452"}
0005434373847	D15E8E	2199 050394	PETR MARTYNOV	{"email": "petr-martynov081980@postgrespro.ru", "phone": "+70235546062"}
0005434373848	F4640D	1476 311551	TATYANA EGOROVA	{"email": "t.egorova_041967@postgrespro.ru", "phone": "+70456564557"}
0005434373849	19C09D	1913 822159	ARTEM FROLOV	{"phone": "+70604789085"}
0005434373850	481B70	6394 551166	MARINA SOROKINA	{"phone": "+70403164715"}
0005434373851	5BE9A9	8881 471217	DMITRIY KULIKOV	{"email": "dmitriy-kulikov1966@postgrespro.ru", "phone": "+70001891292"}
0005434373852	22B409	3444 972720	LIDIYA EFREMOVA	{"email": "efremova.l-031977@postgrespro.ru", "phone": "+70374737333"}
0005434373853	AC5B97	3689 854400	VLADIMIR POPOV	{"phone": "+70876400616"}
0005434373854	C7E843	7031 828242	VALENTINA KAZAKOVA	{"phone": "+70715459262"}
0005434373855	3E4E1C	7902 646900	VARVARA NESTEROVA	{"phone": "+70217180950"}
0005434373856	E1E018	4734 824616	EVGENIY ZAKHAROV	{"phone": "+70454267765"}
0005434373857	0A6F02	5666 713839	NIKOLAY MARTYNOV	{"phone": "+70013646003"}
0005434373858	0A6F02	2018 366555	NATALYA DAVYDOVA	{"phone": "+70579920668"}
0005434373859	7DC5E1	2104 027220	IVAN KOZLOV	{"phone": "+70558814930"}
0005434373860	7DC5E1	2556 559797	LEONID PETROV	{"email": "lpetrov_1980@postgrespro.ru", "phone": "+70990992359"}
0005434373861	46741C	0216 118624	ALEKSANDR EGOROV	{"email": "egorov_a20111967@postgrespro.ru", "phone": "+70397932924"}
0005434373862	F18E57	3253 747958	LEONID FILIPPOV	{"phone": "+70505390285"}
0005434373863	F18E57	1899 619859	SERGEY DMITRIEV	{"phone": "+70592499709"}
0005434373864	6C4604	9484 684581	ANNA MAKSIMOVA	{"email": "maksimova_anna.06101965@postgrespro.ru", "phone": "+70743165184"}
0005434373865	6C4604	9672 343515	ANNA ANTONOVA	{"email": "antonova_a.16071968@postgrespro.ru", "phone": "+70536182177"}
0005434373866	F2E17E	7892 376193	VADIM MELNIKOV	{"email": "melnikov.v_1972@postgrespro.ru", "phone": "+70428702279"}
0005434373867	5579C6	0972 371377	SERGEY CHERNOV	{"email": "sergey-chernov.031983@postgrespro.ru", "phone": "+70403683890"}
0005434373868	AB66D2	3755 514067	RAISA TARASOVA	{"phone": "+70726298028"}
0005434373869	AB66D2	5227 584465	TAISIYA ROMANOVA	{"email": "t.romanova_31031970@postgrespro.ru", "phone": "+70109950509"}
0005434373870	46FEC8	6739 417199	VLADIMIR MELNIKOV	{"email": "vladimir_melnikov_1978@postgrespro.ru", "phone": "+70910471118"}
0005434373871	55B8D7	3182 939669	SERGEY ILIN	{"email": "ilin-sergey-1973@postgrespro.ru", "phone": "+70419425985"}
0005434373872	55B8D7	8358 836195	ALEKSANDR EGOROV	{"phone": "+70169056757"}
0005434373873	0B6A7C	6859 566582	ELENA ILINA	{"email": "elenailina081971@postgrespro.ru", "phone": "+70835788461"}
0005434373874	0B6A7C	5263 878126	STANISLAV ZAYCEV	{"phone": "+70185521048"}
0005434373875	5CB2D3	0165 890092	ALENA VASILEVA	{"email": "alena-vasileva_1985@postgrespro.ru", "phone": "+70777587292"}
0005434373876	4CF0D0	5333 956179	MARFA MIRONOVA	{"email": "mironovamarfa.1964@postgrespro.ru", "phone": "+70208916202"}
0005434373877	4CF0D0	2001 469648	TATYANA MATVEEVA	{"email": "matveeva-tatyana_111970@postgrespro.ru", "phone": "+70819555609"}
0005434373878	4CF0D0	6618 232016	ANTONINA BORISOVA	{"email": "borisovaa-021975@postgrespro.ru", "phone": "+70247569654"}
0005434373879	E67D00	7848 900138	YULIYA EGOROVA	{"email": "egorova.y_121975@postgrespro.ru", "phone": "+70691982312"}
0005434373880	E67D00	4960 924557	EDUARD ANDREEV	{"email": "e_andreev.1975@postgrespro.ru", "phone": "+70263176341"}
0005434373881	08AF37	6362 062379	LYUDMILA MAKSIMOVA	{"phone": "+70272638208"}
0005434373882	0F25A6	5646 603861	NIKOLAY MOISEEV	{"email": "nmoiseev-11051969@postgrespro.ru", "phone": "+70043903597"}
0005434373883	FB3028	9098 527807	NIKOLAY VASILEV	{"email": "nvasilev121963@postgrespro.ru", "phone": "+70078231339"}
0005434373884	841D93	3517 750593	NATALYA KUZNECOVA	{"phone": "+70188546952"}
0005434373885	9058ED	9726 637744	MARIYA PAVLOVA	{"email": "m.pavlova081973@postgrespro.ru", "phone": "+70119226678"}
0005434373886	EBBDFD	3556 054829	NADEZHDA MALYSHEVA	{"phone": "+70912475338"}
0005434373887	EBBDFD	0456 693855	NIKOLAY IVANOV	{"email": "nikolayivanov-30101978@postgrespro.ru", "phone": "+70364823626"}
0005434373888	6666D8	3788 427290	VIKTOR BELOV	{"email": "belov-v1976@postgrespro.ru", "phone": "+70175837731"}
0005434373889	BD2177	6110 265610	ANATOLIY MOROZOV	{"email": "morozovanatoliy.1954@postgrespro.ru", "phone": "+70454830587"}
0005434373890	E04462	7148 128385	VALENTINA KOVALEVA	{"email": "kovaleva.v.13081963@postgrespro.ru", "phone": "+70749434881"}
0005434373891	90172C	7258 224710	PLATON VOROBEV	{"email": "platonvorobev-041976@postgrespro.ru", "phone": "+70614634735"}
0005434373892	5A0A4E	9828 349912	DMITRIY SOLOVEV	{"phone": "+70633597157"}
0005434373893	5A0A4E	7500 188821	VIKTORIYA POPOVA	{"email": "popova.v_03091971@postgrespro.ru", "phone": "+70284536120"}
0005434373894	D622EA	4606 128852	STANISLAV FOMIN	{"email": "fomin.stanislav071968@postgrespro.ru", "phone": "+70624180439"}
0005434373895	D622EA	4974 782651	ELENA LOGINOVA	{"email": "loginova-e.1971@postgrespro.ru", "phone": "+70032127714"}
0005434373896	2B268D	0532 066026	TATYANA FEDOROVA	{"email": "tatyana.fedorova_031973@postgrespro.ru", "phone": "+70605912953"}
0005434373897	2B268D	4842 427057	ALEKSEY ABRAMOV	{"phone": "+70927485127"}
0005434373898	48DDBD	8087 221305	SOFYA ZHUKOVA	{"email": "zhukovasofya_06021960@postgrespro.ru", "phone": "+70803211288"}
0005434373899	457360	3931 393637	INNA YUDINA	{"phone": "+70506811576"}
0005434373900	457360	1364 983471	ALENA SMIRNOVA	{"email": "smirnova.alena_031965@postgrespro.ru", "phone": "+70670348689"}
0005434373901	36AC4E	7349 183865	DMITRIY KOROLEV	{"email": "korolev.dmitriy-05021967@postgrespro.ru", "phone": "+70722115758"}
0005434373902	36AC4E	0245 295360	ANNA IVANOVA	{"email": "aivanova07101969@postgrespro.ru", "phone": "+70151954012"}
0005434373903	E100E4	1528 468458	VLADIMIR KUZNECOV	{"phone": "+70735265376"}
0005434373904	E100E4	2678 896173	NADEZHDA GORBUNOVA	{"phone": "+70487965653"}
0005434373905	ADDE24	0525 652783	PAVEL TIKHONOV	{"email": "pavel-tikhonov041980@postgrespro.ru", "phone": "+70684313648"}
0005434373906	47656E	3207 427681	NIKOLAY POPOV	{"email": "popovnikolay_081972@postgrespro.ru", "phone": "+70000624089"}
0005434373907	A61F8C	2853 693114	OLGA FEDOROVA	{"phone": "+70669042717"}
0005434373908	3D691E	9406 691965	SVETLANA MEDVEDEVA	{"phone": "+70794517365"}
0005434373909	3D691E	5625 528541	EVGENIY ZHURAVLEV	{"email": "evgeniy-zhuravlev-051973@postgrespro.ru", "phone": "+70579991004"}
0005434373910	3D691E	6612 517040	KLAVDIYA ABRAMOVA	{"email": "klavdiyaabramova.1964@postgrespro.ru", "phone": "+70175525497"}
0005434373911	B0E8DB	1428 937570	POLINA ALEKSEEVA	{"phone": "+70437090135"}
0005434373912	B0E8DB	6766 106990	MARINA DENISOVA	{"email": "marina_denisova-1975@postgrespro.ru", "phone": "+70774600859"}
0005434373913	8B352E	3889 915226	YURIY TIKHONOV	{"phone": "+70474810338"}
0005434373914	D244C9	3895 125457	LYUDMILA RYABOVA	{"email": "ryabova.lyudmila_10101974@postgrespro.ru", "phone": "+70579039523"}
0005434373915	D244C9	5557 056623	VASILIY ORLOV	{"phone": "+70708570772"}
0005434373916	752EAB	5950 891901	IRINA ILINA	{"email": "ilina_irina.071976@postgrespro.ru", "phone": "+70600009041"}
0005434373917	155F28	9988 945808	ELENA KISELEVA	{"email": "kiseleva_e041973@postgrespro.ru", "phone": "+70434789303"}
0005434373918	A68F71	3479 198486	EVGENIYA SAVELEVA	{"email": "evgeniyasaveleva_1973@postgrespro.ru", "phone": "+70607865795"}
0005434373919	A68F71	8947 137699	KONSTANTIN ANTONOV	{"phone": "+70135763293"}
0005434373920	BBA6C2	5564 038065	OKSANA VASILEVA	{"email": "oksanavasileva1970@postgrespro.ru", "phone": "+70881753964"}
0005434373921	BBA6C2	9999 340263	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr081978@postgrespro.ru", "phone": "+70567221425"}
0005434373922	72DF52	3649 274722	KONSTANTIN FOMIN	{"phone": "+70710246317"}
0005434373923	09C786	5812 230464	SERGEY YAKOVLEV	{"email": "yakovlev.sergey-071973@postgrespro.ru", "phone": "+70546968981"}
0005434373924	09C786	7645 081052	ALEKSEY PAVLOV	{"phone": "+70236735043"}
0005434373925	8DC102	9157 681988	ELENA LOGINOVA	{"phone": "+70256061750"}
0005434373926	8DC102	4407 321676	TAMARA KOROLEVA	{"email": "tamara_koroleva-1975@postgrespro.ru", "phone": "+70186789082"}
0005434373927	8A4EBE	8775 842099	VARVARA IVANOVA	{"email": "v-ivanova-1955@postgrespro.ru", "phone": "+70791322597"}
0005434373928	8A4EBE	5177 275332	NIKOLAY SAVELEV	{"email": "savelev.n-17101966@postgrespro.ru", "phone": "+70331225645"}
0005434373929	B9B345	0861 234587	OLGA KUZNECOVA	{"email": "kuznecova-o_1957@postgrespro.ru", "phone": "+70356306231"}
0005434373930	B9B345	6712 081151	DARYA DENISOVA	{"email": "denisova.d.18111975@postgrespro.ru", "phone": "+70565901691"}
0005434373931	B9B345	3841 112669	ANASTASIYA SMIRNOVA	{"phone": "+70027726500"}
0005434373932	FA9A18	9445 536216	VERONIKA ROMANOVA	{"phone": "+70984453039"}
0005434373933	610D73	5142 807139	ANASTASIYA KUZNECOVA	{"email": "kuznecovaanastasiya-011962@postgrespro.ru", "phone": "+70631891809"}
0005434373934	610D73	5171 722954	ANASTASIYA KRASNOVA	{"email": "krasnova.anastasiya_31071967@postgrespro.ru", "phone": "+70601443763"}
0005434373935	B93AB2	2741 915169	VALENTINA FADEEVA	{"phone": "+70403963031"}
0005434373936	928C5B	1121 008816	ALINA BELOVA	{"email": "alina-belova-1975@postgrespro.ru", "phone": "+70985480216"}
0005434373937	E04FA9	0996 745461	KHALIDA KAZAKOVA	{"phone": "+70296775489"}
0005434373938	E04FA9	4119 126815	MIKHAIL SCHERBAKOV	{"phone": "+70049562597"}
0005434373939	A039C1	6644 070787	MARIYA SOKOLOVA	{"email": "mariya.sokolova_041960@postgrespro.ru", "phone": "+70737187884"}
0005434373940	A039C1	7719 185261	TAISIYA KOROLEVA	{"phone": "+70050433001"}
0005434373941	07FB59	1637 103053	VLADIMIR YAKOVLEV	{"phone": "+70383918443"}
0005434373942	07FB59	4014 207370	ALEKSANDR KOZLOV	{"email": "a-kozlov1964@postgrespro.ru", "phone": "+70901149005"}
0005434373943	11762D	5007 087211	ARTEM ABRAMOV	{"phone": "+70932972428"}
0005434373944	6A4222	3510 786904	DMITRIY VOROBEV	{"phone": "+70385162847"}
0005434373945	74851F	4749 693002	IRINA SEMENOVA	{"email": "semenovai.27031973@postgrespro.ru", "phone": "+70630427520"}
0005434373946	E02EE3	0634 975281	MARIYA ANDREEVA	{"phone": "+70364383983"}
0005434373947	E02EE3	4230 576825	NIKOLAY MEDVEDEV	{"phone": "+70281316420"}
0005434373948	B86D18	4423 382295	ALEKSEY POPOV	{"phone": "+70566247056"}
0005434373949	B86D18	4951 883667	LIDIYA MASLOVA	{"phone": "+70826687102"}
0005434373950	FAA73C	9656 575389	ZOYA EGOROVA	{"email": "egorova.zoya.101974@postgrespro.ru", "phone": "+70153889029"}
0005434373951	FAA73C	0467 080022	VIKTOR ANDREEV	{"email": "viktor.andreev-1966@postgrespro.ru", "phone": "+70025614909"}
0005434373952	9C2544	0918 573991	TAMARA YAKOVLEVA	{"email": "t_yakovleva-04121980@postgrespro.ru", "phone": "+70602483187"}
0005434373953	9C2544	4540 995663	VERONIKA KONOVALOVA	{"phone": "+70611236527"}
0005434373954	2EAA3B	9730 240765	ANDREY MIRONOV	{"phone": "+70990791839"}
0005434373955	9BE7E0	6771 020907	VERA MAKAROVA	{"phone": "+70471143220"}
0005434373956	9BE7E0	6829 489872	ANATOLIY KUZMIN	{"phone": "+70658559831"}
0005434373957	CA9F9B	9157 142543	OLEG MIRONOV	{"phone": "+70885013402"}
0005434373958	CA9F9B	7281 141165	MARINA BORISOVA	{"email": "borisova_m-23021969@postgrespro.ru", "phone": "+70067743056"}
0005434373959	167C20	2974 755318	KLAVDIYA PETROVA	{"email": "petrovak1980@postgrespro.ru", "phone": "+70103815590"}
0005434373960	B7D577	8900 236134	SERGEY BONDARENKO	{"phone": "+70508978475"}
0005434373961	B7D577	7162 125480	YULIYA ZAYCEVA	{"email": "yuliya.zayceva_1967@postgrespro.ru", "phone": "+70228341447"}
0005434373962	9C6515	4415 533732	YURIY KUZNECOV	{"email": "yuriy-kuznecov061969@postgrespro.ru", "phone": "+70635782406"}
0005434373963	7B4240	7451 596382	ANATOLIY FEDOROV	{"phone": "+70651053221"}
0005434373964	AC9902	7615 841333	DARYA FEDOROVA	{"phone": "+70039281373"}
0005434373965	AC9902	5836 096865	KIRILL NAUMOV	{"email": "naumov-k-1974@postgrespro.ru", "phone": "+70438143552"}
0005434373966	6A90BD	0445 023154	MARIYA KOZLOVA	{"email": "mariya-kozlova031972@postgrespro.ru", "phone": "+70386104550"}
0005434373967	6A90BD	8662 289016	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov101974@postgrespro.ru", "phone": "+70435591286"}
0005434373968	7F643A	6586 868486	ANFISA YUDINA	{"email": "yudina.a_1967@postgrespro.ru", "phone": "+70824015772"}
0005434373969	73A6C8	2908 172359	VYACHESLAV ANDREEV	{"phone": "+70307363269"}
0005434373970	923415	2358 493297	ALEKSANDR AFANASEV	{"phone": "+70440229016"}
0005434373971	73FC4D	2483 760961	MATVEY BELOV	{"email": "matvey.belov091965@postgrespro.ru", "phone": "+70552716052"}
0005434373972	1E9AF4	5830 422575	ALEKSEY MIKHAYLOV	{"email": "aleksey-mikhaylov071964@postgrespro.ru", "phone": "+70207096118"}
0005434373973	E1BE2E	4856 590491	DARYA FROLOVA	{"email": "daryafrolova-1972@postgrespro.ru", "phone": "+70625048458"}
0005434373974	43408A	5876 067292	VLADISLAV PETROV	{"email": "vladislav.petrov021977@postgrespro.ru", "phone": "+70483753306"}
0005434373975	09EE19	9517 504364	OLESYA ILINA	{"phone": "+70017401202"}
0005434373976	09EE19	8377 934456	SVETLANA NIKITINA	{"phone": "+70049803870"}
0005434373977	25AE6F	1592 784382	VYACHESLAV CHERNOV	{"email": "chernov_v.051968@postgrespro.ru", "phone": "+70320459600"}
0005434373978	8184C7	3900 905246	RUMIYA ANISIMOVA	{"phone": "+70714865802"}
0005434373979	8184C7	9506 971423	ALEKSANDR EGOROV	{"email": "a.egorov.1968@postgrespro.ru", "phone": "+70189678510"}
0005434373980	8B2DDA	9058 165403	VADIM SIDOROV	{"phone": "+70266165599"}
0005434373981	38BB0C	0517 330842	ANASTASIYA ANISIMOVA	{"email": "anisimovaanastasiya06011978@postgrespro.ru", "phone": "+70353811912"}
0005434373982	D989D9	9377 962015	DANIL TIMOFEEV	{"phone": "+70796675953"}
0005434373983	D989D9	3934 948074	NATALYA FADEEVA	{"phone": "+70772729566"}
0005434373984	352DDE	4772 669336	LYUDMILA FEDOROVA	{"email": "fedorova_lyudmila-081976@postgrespro.ru", "phone": "+70858338063"}
0005434373985	90CA49	8460 249267	NADEZHDA ANDREEVA	{"phone": "+70783307971"}
0005434373986	56C500	3641 918868	EDUARD PAVLOV	{"phone": "+70281390462"}
0005434373987	F8BF46	0718 679777	DENIS MIKHAYLOV	{"phone": "+70878931143"}
0005434373988	F8BF46	2222 263292	SERGEY MAKSIMOV	{"phone": "+70239373699"}
0005434373989	F8BF46	4357 525194	LYUBOV YAKOVLEVA	{"email": "yakovleva_lyubov-091983@postgrespro.ru", "phone": "+70537276727"}
0005434373990	F7A0D9	7608 976024	SVETLANA NAZAROVA	{"phone": "+70039930262"}
0005434373991	F7A0D9	2130 751275	VADIM KOZLOV	{"email": "vadimkozlov-121980@postgrespro.ru", "phone": "+70228520246"}
0005434373992	A6B4AF	2433 808522	IVAN CHERNOV	{"email": "chernovivan-071964@postgrespro.ru", "phone": "+70547315373"}
0005434373993	A6B4AF	3205 907082	OLEG ZAKHAROV	{"phone": "+70587154467"}
0005434373994	C78698	0221 950466	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev041980@postgrespro.ru", "phone": "+70424001835"}
0005434373995	C3F22D	3327 535528	DMITRIY FILIPPOV	{"phone": "+70690411871"}
0005434373996	9B9AAD	5112 182162	EKATERINA KALININA	{"phone": "+70510136491"}
0005434373997	F1C008	5409 364744	ILYA EGOROV	{"phone": "+70057548268"}
0005434373998	65CD03	4849 805138	TATYANA KUZNECOVA	{"email": "t-kuznecova12091970@postgrespro.ru", "phone": "+70423248252"}
0005434373999	309142	7048 770042	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr1963@postgrespro.ru", "phone": "+70213091467"}
0005434374000	309142	0122 884432	YULIYA ROMANOVA	{"email": "yuliya.romanova021988@postgrespro.ru", "phone": "+70398057176"}
0005434374001	83EE0F	7425 404114	ANNA KRASNOVA	{"email": "annakrasnova_061972@postgrespro.ru", "phone": "+70697454036"}
0005434374002	83EE0F	6811 335607	ALEKSANDR PETROV	{"email": "petrov-a14121964@postgrespro.ru", "phone": "+70323852293"}
0005434374003	92A0B7	0162 984454	VLADISLAV ABRAMOV	{"phone": "+70248766182"}
0005434374004	560C55	2166 759329	ELENA FROLOVA	{"phone": "+70124104637"}
0005434374005	560C55	2589 813696	VLADIMIR ANTONOV	{"email": "antonovvladimir081978@postgrespro.ru", "phone": "+70050651503"}
0005434374006	323BF9	8472 225857	ALEKSANDR FEDOROV	{"phone": "+70044243402"}
0005434374007	0C39EF	1912 887253	VLADIMIR ZHUKOV	{"email": "vzhukov_28061982@postgrespro.ru", "phone": "+70108784762"}
0005434374008	042EC2	4856 108808	EVGENIYA ZAKHAROVA	{"email": "e_zakharova_091964@postgrespro.ru", "phone": "+70340680953"}
0005434374009	158CBA	3870 840120	OLGA ANTONOVA	{"email": "antonova.olga031979@postgrespro.ru", "phone": "+70180267739"}
0005434374010	884929	9930 363495	NATALYA MAKAROVA	{"email": "n-makarova101969@postgrespro.ru", "phone": "+70402942694"}
0005434374011	3C3106	1122 713562	ROMAN BARANOV	{"phone": "+70323765920"}
0005434374012	3C3106	6541 251251	DENIS BONDARENKO	{"email": "bondarenko.d_1969@postgrespro.ru", "phone": "+70912129896"}
0005434374013	465DB7	4492 025747	EDUARD GERASIMOV	{"phone": "+70199493718"}
0005434374014	8D794D	1047 504425	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov12011976@postgrespro.ru", "phone": "+70733955505"}
0005434374015	035088	6213 109839	RAISA KUZNECOVA	{"phone": "+70349163003"}
0005434374016	B1F5E1	4515 752700	ANGELINA SEMENOVA	{"email": "angelina.semenova.26091968@postgrespro.ru", "phone": "+70685884957"}
0005434374017	D099AE	4414 312252	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev.27011979@postgrespro.ru", "phone": "+70362433142"}
0005434374018	DC1BA7	9451 280339	MARINA KOROLEVA	{"phone": "+70820270823"}
0005434374019	EDEC86	9817 669512	LEONID FEDOROV	{"phone": "+70713328980"}
0005434374020	73FEED	2826 777240	IRINA SAVELEVA	{"email": "saveleva.irina.011971@postgrespro.ru", "phone": "+70080228461"}
0005434374021	EF0D5D	2976 567310	TATYANA BOGDANOVA	{"phone": "+70932165914"}
0005434374022	24FF61	9894 380823	ALEKSANDR KUZNECOV	{"email": "kuznecov.a.15031979@postgrespro.ru", "phone": "+70881267075"}
0005434374023	DD6BFD	6091 294798	OLGA KUZMINA	{"phone": "+70148402033"}
0005434374024	4DDA2F	0752 951330	VERONIKA KOZLOVA	{"email": "kozlovav011979@postgrespro.ru", "phone": "+70319983400"}
0005434374025	3B2FE0	9634 379922	NIKOLAY KAZAKOV	{"email": "kazakov-n_1965@postgrespro.ru", "phone": "+70084907408"}
0005434374026	7F8CA1	7477 517339	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina.1984@postgrespro.ru", "phone": "+70503959910"}
0005434374027	1B53D3	1608 802799	NATALIYA STEPANOVA	{"email": "n-stepanova_1985@postgrespro.ru", "phone": "+70832415768"}
0005434374028	120438	2948 650849	ALLA PETROVA	{"email": "alla-petrova_091962@postgrespro.ru", "phone": "+70905954777"}
0005434374029	44644B	7150 508815	OLGA ISAEVA	{"email": "isaeva.o-1984@postgrespro.ru", "phone": "+70964425181"}
0005434374030	44644B	8969 830254	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov23081970@postgrespro.ru", "phone": "+70610957271"}
0005434374031	3E643A	8711 038865	EDUARD MIRONOV	{"phone": "+70377874858"}
0005434374032	3E643A	7012 709270	NATALYA KUZMINA	{"email": "kuzmina_n-1968@postgrespro.ru", "phone": "+70727641021"}
0005434374033	83E726	4339 271520	POLINA NIKIFOROVA	{"email": "polina-nikiforova.22031975@postgrespro.ru", "phone": "+70349495253"}
0005434374034	88FB88	5113 356034	VALENTINA SEMENOVA	{"email": "v-semenova.1969@postgrespro.ru", "phone": "+70984308684"}
0005434374035	88FB88	8353 002893	KIRILL ISAEV	{"email": "kirill-isaev021970@postgrespro.ru", "phone": "+70329483730"}
0005434374036	EBCB49	4116 399853	MAKSIM SOROKIN	{"email": "sorokin-m031976@postgrespro.ru", "phone": "+70333818542"}
0005434374037	3A44B9	9720 829584	VLADIMIR VOLKOV	{"email": "volkov_v.01031980@postgrespro.ru", "phone": "+70817497487"}
0005434374038	3A44B9	4256 071355	MARIYA LOGINOVA	{"email": "m-loginova.1970@postgrespro.ru", "phone": "+70659330226"}
0005434374039	9F89F9	0894 774548	VALENTINA ALEKSANDROVA	{"phone": "+70947254904"}
0005434374040	9F89F9	1679 767590	ANASTASIYA CHERNOVA	{"phone": "+70725619193"}
0005434374041	4FD02B	8092 854618	NADEZHDA BOGDANOVA	{"email": "nadezhda_bogdanova061966@postgrespro.ru", "phone": "+70715759500"}
0005434374042	374F54	6560 567526	FATIMA NESTEROVA	{"phone": "+70526648906"}
0005434374043	657F1B	9284 420337	OLGA MIRONOVA	{"phone": "+70251526489"}
0005434374044	166D2D	9396 242638	ALEKSEY CHERNOV	{"email": "a.chernov1963@postgrespro.ru", "phone": "+70603650062"}
0005434374045	B2CD30	7974 048440	AMIR OSIPOV	{"phone": "+70986583129"}
0005434374046	5E9FE0	9504 257510	GENNADIY VOLKOV	{"email": "volkov.gennadiy.19081959@postgrespro.ru", "phone": "+70537248231"}
0005434374047	21957E	4192 539923	MAKSIM VOROBEV	{"email": "vorobev_m_02041968@postgrespro.ru", "phone": "+70843034721"}
0005434374048	EF9EED	8577 549946	VLADISLAV VLASOV	{"email": "vladislav_vlasov_1966@postgrespro.ru", "phone": "+70597074062"}
0005434374049	CA150D	5624 554532	OLGA MOROZOVA	{"phone": "+70021634464"}
0005434374050	CA150D	6104 523734	STANISLAV NAUMOV	{"phone": "+70812283189"}
0005434374051	F5EAE3	5851 892089	EKATERINA TARASOVA	{"email": "ekaterina.tarasova031971@postgrespro.ru", "phone": "+70246552737"}
0005434374165	0A8F88	0238 655119	DMITRIY FROLOV	{"phone": "+70147151669"}
0005434374052	F5EAE3	8020 713466	SOFYA IVANOVA	{"email": "s.ivanova.06101979@postgrespro.ru", "phone": "+70481002258"}
0005434374053	DBB4B0	2712 505527	VIKTOR DAVYDOV	{"phone": "+70311078406"}
0005434374054	DBB4B0	0967 056874	SERGEY NAUMOV	{"email": "naumov.s-121975@postgrespro.ru", "phone": "+70072539096"}
0005434374055	BD78AE	3180 508845	IVAN EGOROV	{"email": "ivan-egorov-05041959@postgrespro.ru", "phone": "+70120914140"}
0005434374056	BD78AE	2143 583507	KSENIYA KUZNECOVA	{"email": "kuznecova_kseniya-1971@postgrespro.ru", "phone": "+70482498177"}
0005434374057	0D9774	1819 580181	LYUBOV BELYAEVA	{"phone": "+70264792724"}
0005434374058	8E36C2	5412 675934	VIKTOR NAZAROV	{"phone": "+70199461258"}
0005434374059	59533B	5266 846948	SVETLANA SMIRNOVA	{"email": "ssmirnova.041966@postgrespro.ru", "phone": "+70686693381"}
0005434374060	A52FC4	0916 974945	ANVAR MIKHAYLOV	{"phone": "+70527824662"}
0005434374061	F97694	2185 403063	NATALYA BELOVA	{"phone": "+70735639616"}
0005434374062	F97694	8358 040888	TATYANA NIKOLAEVA	{"email": "nikolaeva_t10101970@postgrespro.ru", "phone": "+70039307742"}
0005434374063	662E7F	0846 463158	YURIY ABRAMOV	{"email": "y_abramov.091963@postgrespro.ru", "phone": "+70924935217"}
0005434374064	662E7F	9625 655369	LIDIYA KALININA	{"phone": "+70813553492"}
0005434374065	4838DF	7497 519300	ANASTASIYA KUDRYASHOVA	{"phone": "+70753614429"}
0005434374066	A818AE	4890 337208	ANDREY NIKOLAEV	{"phone": "+70591882712"}
0005434374067	69A3B6	8220 368603	ANDREY ISAEV	{"phone": "+70975279730"}
0005434374068	633DD0	6740 545642	NINA TIMOFEEVA	{"email": "timofeeva-nina.1969@postgrespro.ru", "phone": "+70702152565"}
0005434374069	633DD0	3021 536497	ANDREY KUZNECOV	{"email": "kuznecovandrey.1985@postgrespro.ru", "phone": "+70911055799"}
0005434374070	633DD0	2990 105123	EKATERINA FADEEVA	{"phone": "+70431996270"}
0005434374071	F3F0B0	8700 678528	SERGEY GAVRILOV	{"email": "gavrilov.sergey-041972@postgrespro.ru", "phone": "+70059468304"}
0005434374072	F3F0B0	5051 797159	VIKTOR PETROV	{"phone": "+70526384910"}
0005434374073	E70C20	5577 696188	ELENA ABRAMOVA	{"email": "abramova-e_1967@postgrespro.ru", "phone": "+70074189444"}
0005434374074	B04D21	2283 806540	YULIYA FEDOROVA	{"email": "y.fedorova-1967@postgrespro.ru", "phone": "+70166680570"}
0005434374075	B04D21	0305 799228	SVETLANA ABRAMOVA	{"phone": "+70512439232"}
0005434374076	95D167	0997 211749	ALENA VASILEVA	{"email": "vasileva.a.021973@postgrespro.ru", "phone": "+70408182303"}
0005434374077	60DF0B	3368 457547	SVETLANA MATVEEVA	{"phone": "+70659464825"}
0005434374078	85313E	9801 232362	TATYANA CHERNOVA	{"email": "t-chernova_11111968@postgrespro.ru", "phone": "+70418447428"}
0005434374079	85313E	8397 060183	IRINA NESTEROVA	{"phone": "+70119845672"}
0005434374080	31E397	7682 348820	NATALYA KOZLOVA	{"phone": "+70770477399"}
0005434374081	31E397	2519 901659	ANDREY SIDOROV	{"email": "andrey-sidorov14091980@postgrespro.ru", "phone": "+70907169208"}
0005434374082	87E991	2922 033362	NATALYA ZHURAVLEVA	{"phone": "+70590693785"}
0005434374083	87E991	9642 742908	EKATERINA MASLOVA	{"phone": "+70020059350"}
0005434374084	719E83	1380 133817	YURIY GERASIMOV	{"email": "ygerasimov_121961@postgrespro.ru", "phone": "+70967604553"}
0005434374085	A1B987	1055 153344	DMITRIY FEDOROV	{"phone": "+70090688668"}
0005434374086	A1B987	2493 546046	OKSANA DANILOVA	{"email": "danilova-o.041974@postgrespro.ru", "phone": "+70633700449"}
0005434374087	14C328	7210 341469	VALENTINA ALEKSEEVA	{"phone": "+70188074675"}
0005434374088	FF3145	7120 117790	VIOLETTA OSIPOVA	{"email": "osipova.violetta1965@postgrespro.ru", "phone": "+70895303197"}
0005434374089	FF3145	8759 895247	VALENTINA ROMANOVA	{"email": "v_romanova.25011970@postgrespro.ru", "phone": "+70083814309"}
0005434374090	DD840B	1366 266619	DMITRIY MARTYNOV	{"email": "martynov.d-1954@postgrespro.ru", "phone": "+70103249665"}
0005434374091	155B22	6624 376618	VLADIMIR GUSEV	{"email": "gusev-v.101976@postgrespro.ru", "phone": "+70508726781"}
0005434374092	155B22	7749 544907	IRINA ILINA	{"phone": "+70407735935"}
0005434374093	EE812D	5493 500081	VYACHESLAV MOISEEV	{"phone": "+70625890140"}
0005434374094	4639DB	9366 553572	ANNA EGOROVA	{"phone": "+70717905098"}
0005434374095	FE894B	9605 181848	VALERIY KOZLOV	{"email": "kozlov-valeriy_27111965@postgrespro.ru", "phone": "+70134236693"}
0005434374096	E396E8	6052 139634	PAVEL FILIPPOV	{"email": "filippov-pavel_011983@postgrespro.ru", "phone": "+70122025196"}
0005434374097	A6FDA4	7924 152211	TAMARA KISELEVA	{"email": "kiseleva_t031975@postgrespro.ru", "phone": "+70194144028"}
0005434374098	D5E46E	1202 509045	ALEKSEY POPOV	{"phone": "+70908485989"}
0005434374099	3146DC	8590 744398	LIDIYA STEPANOVA	{"phone": "+70326773281"}
0005434374100	3B7A2B	7653 259968	EVGENIY POPOV	{"phone": "+70612600001"}
0005434374101	1B5B3D	1407 187123	OLEG MAKSIMOV	{"phone": "+70233275412"}
0005434374102	1B5B3D	4962 952248	LYUDMILA NIKOLAEVA	{"email": "l-nikolaeva06061972@postgrespro.ru", "phone": "+70098752828"}
0005434374103	5F8AED	7275 310903	DMITRIY NOVIKOV	{"email": "novikov_dmitriy30071971@postgrespro.ru", "phone": "+70581279666"}
0005434374104	7C5F3D	0833 562964	YULIYA MOISEEVA	{"email": "moiseeva.y031968@postgrespro.ru", "phone": "+70064859161"}
0005434374105	C62DF5	3005 767175	IRINA BOGDANOVA	{"email": "bogdanovai1973@postgrespro.ru", "phone": "+70032306302"}
0005434374106	C62DF5	4079 913140	FEDOR KUZNECOV	{"email": "fedor-kuznecov-1974@postgrespro.ru", "phone": "+70821434298"}
0005434374107	E51A5C	0241 287982	ALEKSANDR EGOROV	{"phone": "+70989649467"}
0005434374108	7CE5AD	1477 105446	NIKOLAY FEDOROV	{"email": "nikolayfedorov-04071972@postgrespro.ru", "phone": "+70484864367"}
0005434374109	7CE5AD	7150 558952	IRINA CHERNOVA	{"email": "ichernova_24121969@postgrespro.ru", "phone": "+70740838549"}
0005434374110	36CB8A	2422 656390	VITALIY NIKOLAEV	{"email": "nikolaev.v_25021975@postgrespro.ru", "phone": "+70507147444"}
0005434374111	A557C5	6573 814414	YAROSLAV ROMANOV	{"phone": "+70098124396"}
0005434374112	A557C5	9540 642327	NIKOLAY VASILEV	{"phone": "+70753467650"}
0005434374113	A557C5	5335 868137	TATYANA SEMENOVA	{"phone": "+70117574730"}
0005434374114	950CBD	3527 425318	ALEKSANDRA DENISOVA	{"phone": "+70763645359"}
0005434374115	F40B4D	0790 311768	NIKOLAY ANDREEV	{"phone": "+70353940534"}
0005434374116	F7C48D	7311 528158	TATYANA IVANOVA	{"phone": "+70990621122"}
0005434374117	25BB48	3885 074300	ALEKSANDR IVANOV	{"email": "aleksandrivanov.031969@postgrespro.ru", "phone": "+70892951942"}
0005434374118	41BDA3	8980 241038	SOFYA KUZNECOVA	{"phone": "+70262789597"}
0005434374119	D75087	5198 567826	VITALIY VLASOV	{"phone": "+70495302329"}
0005434374120	0424CE	4531 591026	ALEKSANDRA TARASOVA	{"email": "aleksandratarasova_12051980@postgrespro.ru", "phone": "+70323576565"}
0005434374121	4088B3	7293 076618	VLADIMIR SOKOLOV	{"email": "v_sokolov_091975@postgrespro.ru", "phone": "+70943775184"}
0005434374122	841378	6435 767198	NIKOLAY GORBUNOV	{"phone": "+70319846523"}
0005434374123	841378	6314 989210	EVGENIYA KRASNOVA	{"email": "e.krasnova1974@postgrespro.ru", "phone": "+70219023305"}
0005434374124	C7B75D	9435 013701	VALERIY KUZNECOV	{"phone": "+70209520573"}
0005434374125	C7B75D	2133 581086	SERGEY ORLOV	{"email": "sergeyorlov1962@postgrespro.ru", "phone": "+70171530712"}
0005434374126	CF3AB7	3698 335553	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov1964@postgrespro.ru", "phone": "+70729168520"}
0005434374127	EEDDD6	4925 189451	MIKHAIL FILIPPOV	{"email": "mikhail.filippov13111968@postgrespro.ru", "phone": "+70976220363"}
0005434374128	1A6A21	9126 132383	VIKTOR IVANOV	{"phone": "+70762233469"}
0005434374129	1A6A21	1296 533410	NADEZHDA STEPANOVA	{"email": "stepanova_n_021983@postgrespro.ru", "phone": "+70652876442"}
0005434374130	FFF419	8886 145714	ANDREY PETROV	{"phone": "+70633362952"}
0005434374131	37A3C5	4562 728533	LYUBOV KUZMINA	{"email": "kuzmina-lyubov_1969@postgrespro.ru", "phone": "+70258982355"}
0005434374132	2E2046	1018 140560	TAMARA ZHUKOVA	{"email": "tzhukova091968@postgrespro.ru", "phone": "+70254224780"}
0005434374133	38B8B7	7465 541829	TATYANA ZAKHAROVA	{"phone": "+70082269080"}
0005434374134	38EA41	1761 936680	KIRILL POPOV	{"phone": "+70665011879"}
0005434374135	C37A3F	9662 768828	ALEKSANDR SAVELEV	{"phone": "+70833005753"}
0005434374136	615D31	7618 288330	VERA DANILOVA	{"email": "danilova.v-051970@postgrespro.ru", "phone": "+70330445537"}
0005434374137	80584D	4926 224125	EVGENIY BELOV	{"phone": "+70321340029"}
0005434374138	773EBE	9629 608280	IRINA EGOROVA	{"email": "i.egorova_041969@postgrespro.ru", "phone": "+70501041124"}
0005434374139	9931A7	4313 800242	MARGARITA POPOVA	{"phone": "+70234647857"}
0005434374140	4EC60E	0636 824749	ANASTASIYA MELNIKOVA	{"phone": "+70722387213"}
0005434374141	4EC60E	3191 392272	GALINA NIKITINA	{"phone": "+70328426012"}
0005434374142	4EC60E	6231 164183	ELENA MOROZOVA	{"phone": "+70038896116"}
0005434374143	96ECE1	6129 365411	VLADIMIR KOZLOV	{"email": "kozlov.v1972@postgrespro.ru", "phone": "+70168462960"}
0005434374144	0AEC38	1465 515298	TATYANA ALEKSANDROVA	{"phone": "+70772175173"}
0005434374145	AA928C	0639 995424	ELENA MEDVEDEVA	{"email": "elena_medvedeva101981@postgrespro.ru", "phone": "+70208592579"}
0005434374146	2F4BF4	4667 731324	VLADIMIR KUZMIN	{"phone": "+70510513042"}
0005434374147	BCDF9E	6393 462798	MARINA CHERNOVA	{"phone": "+70461993684"}
0005434374148	BCDF9E	4809 966835	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr-081969@postgrespro.ru", "phone": "+70745379125"}
0005434374149	C2E73F	0524 485166	VERA ANDREEVA	{"email": "andreeva-vera-1968@postgrespro.ru", "phone": "+70227092240"}
0005434374150	C2E73F	3329 486741	DIANA KOZLOVA	{"email": "d.kozlova_061980@postgrespro.ru", "phone": "+70008312405"}
0005434374151	37691C	3193 423191	NIKOLAY NIKITIN	{"phone": "+70379061693"}
0005434374152	3A3472	1352 245708	GALINA GAVRILOVA	{"email": "gavrilova-g_10111965@postgrespro.ru", "phone": "+70750884792"}
0005434374153	EC4B90	5713 417557	ALEKSANDR GERASIMOV	{"phone": "+70515746416"}
0005434374154	CF4A09	4991 157693	ELENA KOROLEVA	{"phone": "+70919684735"}
0005434374155	7FD018	6475 194135	SVETLANA NAUMOVA	{"phone": "+70943602998"}
0005434374156	086D57	7138 047703	TATYANA ILINA	{"email": "ilinat01011977@postgrespro.ru", "phone": "+70007622274"}
0005434374157	086D57	7822 393069	YULIYA ZAKHAROVA	{"phone": "+70035414036"}
0005434374158	95C5FE	4899 402110	OLGA BELOVA	{"phone": "+70958686919"}
0005434374159	95C5FE	2720 240935	ANTON MOROZOV	{"email": "a_morozov.081979@postgrespro.ru", "phone": "+70339941160"}
0005434374160	EC8BAA	3888 111181	IVAN ZAYCEV	{"email": "ivanzaycev-1977@postgrespro.ru", "phone": "+70578117786"}
0005434374161	EC8BAA	6179 993271	TATYANA KONOVALOVA	{"phone": "+70012625299"}
0005434374162	2ADD41	3831 222124	NATALYA MEDVEDEVA	{"email": "n_medvedeva-081970@postgrespro.ru", "phone": "+70648199727"}
0005434374163	A4B0ED	5111 727524	VALERIY GAVRILOV	{"email": "v_gavrilov.16071967@postgrespro.ru", "phone": "+70103970792"}
0005434374164	BEF7A0	4649 847490	IVAN BORISOV	{"email": "i_borisov1981@postgrespro.ru", "phone": "+70793304049"}
0005434374166	3A0354	6459 668540	ELIZAVETA BARANOVA	{"email": "e-baranova_26061978@postgrespro.ru", "phone": "+70102068532"}
0005434374167	3A0354	2781 506519	VLADIMIR TIMOFEEV	{"email": "v-timofeev-09031970@postgrespro.ru", "phone": "+70616474382"}
0005434374168	3A0354	7201 553462	VLADIMIR SIDOROV	{"email": "sidorov_vladimir-1976@postgrespro.ru", "phone": "+70908891645"}
0005434374169	6D3A4B	3119 111121	IGOR BORISOV	{"phone": "+70839223717"}
0005434374170	D82191	2875 092755	ANNA KUZNECOVA	{"phone": "+70389441620"}
0005434374171	D82191	4213 195155	VIKTOR NOVIKOV	{"email": "v_novikov19021972@postgrespro.ru", "phone": "+70178675889"}
0005434374172	494D50	1359 772046	ILYA NIKITIN	{"phone": "+70822747317"}
0005434374173	621CCD	3815 306546	VLADIMIR MAKAROV	{"email": "vladimirmakarov-30041975@postgrespro.ru", "phone": "+70754180152"}
0005434374174	28E172	2443 175098	ANTON GERASIMOV	{"email": "gerasimov-a.03101974@postgrespro.ru", "phone": "+70369276235"}
0005434374175	A5C70F	3935 976316	IGOR MIKHAYLOV	{"phone": "+70657451144"}
0005434374176	A5C70F	5983 585737	IRINA SOROKINA	{"email": "sorokina-irina-081972@postgrespro.ru", "phone": "+70185241274"}
0005434374177	0F73B4	3026 482909	VALENTINA IVANOVA	{"phone": "+70885976012"}
0005434374178	0F73B4	3839 950281	VALERIY MOROZOV	{"email": "morozovvaleriy1973@postgrespro.ru", "phone": "+70354357410"}
0005434374179	A6ACA0	1454 007538	LIDIYA GORBUNOVA	{"phone": "+70023221541"}
0005434374180	6EECEC	6320 500680	ALEKSANDR KAZAKOV	{"email": "kazakov.a-101978@postgrespro.ru", "phone": "+70562328333"}
0005434374181	6EECEC	3534 599116	ANASTASIYA KALININA	{"phone": "+70454339785"}
0005434374182	6EECEC	5747 741801	DENIS TIKHONOV	{"phone": "+70108189085"}
0005434374183	0DF8A0	4343 333975	ANTONINA SEMENOVA	{"email": "semenova.a_091982@postgrespro.ru", "phone": "+70978803119"}
0005434374184	0DF8A0	9065 640720	OLGA MELNIKOVA	{"email": "o-melnikova021977@postgrespro.ru", "phone": "+70884241683"}
0005434374185	B16EAB	0989 810773	ALEKSANDR AFANASEV	{"phone": "+70379691018"}
0005434374186	088B04	7680 373490	OLEG EGOROV	{"phone": "+70928394753"}
0005434374187	28489F	6536 297468	OKSANA PETROVA	{"phone": "+70804873858"}
0005434374188	28489F	0701 629514	SVETLANA ANISIMOVA	{"email": "svetlanaanisimova.1976@postgrespro.ru", "phone": "+70530953531"}
0005434374189	54861D	8477 479873	VLADIMIR MIKHAYLOV	{"phone": "+70351005537"}
0005434374190	3B3842	6918 449334	ANATOLIY ROMANOV	{"email": "a_romanov-041967@postgrespro.ru", "phone": "+70135506571"}
0005434374191	34314D	7339 552842	NINA NAZAROVA	{"email": "nazarova-nina_061964@postgrespro.ru", "phone": "+70904684904"}
0005434374192	E54729	8732 940232	VIKTOR ILIN	{"email": "ilinv091972@postgrespro.ru", "phone": "+70246410219"}
0005434374193	045D86	2252 952449	LYUBOV STEPANOVA	{"phone": "+70710884975"}
0005434374194	0E2BE3	4698 815313	VIKTOR IVANOV	{"email": "viktorivanov.091970@postgrespro.ru", "phone": "+70491857344"}
0005434374195	0E2BE3	7214 365609	SVETLANA KUZNECOVA	{"phone": "+70115361977"}
0005434374196	CAACB4	3235 961735	DMITRIY TIMOFEEV	{"phone": "+70387504470"}
0005434374197	8EBDB0	9583 261915	VALENTINA ZHUKOVA	{"phone": "+70888705658"}
0005434374198	8EBDB0	6130 500069	VERA RODIONOVA	{"phone": "+70600158606"}
0005434374199	F4EB12	8280 047032	VALENTINA VASILEVA	{"phone": "+70770518605"}
0005434374200	F4EB12	6500 043722	LYUDMILA VOROBEVA	{"phone": "+70975106041"}
0005434374201	F4EB12	2018 106999	NIKOLAY MOROZOV	{"email": "n-morozov14011967@postgrespro.ru", "phone": "+70692899617"}
0005434374202	E71B94	1795 721058	YURIY GERASIMOV	{"phone": "+70218507657"}
0005434374203	0623F6	1279 314464	DMITRIY NAZAROV	{"email": "dmitriy.nazarov.1972@postgrespro.ru", "phone": "+70612916983"}
0005434374204	6CC5E4	9860 778917	KONSTANTIN PETROV	{"email": "petrov_konstantin111973@postgrespro.ru", "phone": "+70121090697"}
0005434374205	6CC5E4	4984 310905	MIKHAIL GERASIMOV	{"email": "gerasimov.m.22051956@postgrespro.ru", "phone": "+70180561600"}
0005434374206	90ACC1	0712 112096	OLGA KUZNECOVA	{"phone": "+70129502601"}
0005434374207	90ACC1	2754 160882	MARAT SMIRNOV	{"phone": "+70429887334"}
0005434374208	97E823	3835 745929	TATYANA SERGEEVA	{"email": "sergeeva_t26051967@postgrespro.ru", "phone": "+70854681744"}
0005434374209	ED6999	3050 057894	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.011972@postgrespro.ru", "phone": "+70335431331"}
0005434374210	ED6999	1906 029844	VIKTOR VOLKOV	{"email": "volkov-viktor_23061968@postgrespro.ru", "phone": "+70643768839"}
0005434374211	F928DA	3813 497044	ANTONINA ZAKHAROVA	{"email": "zakharova_a-20061971@postgrespro.ru", "phone": "+70195626165"}
0005434374212	011105	4228 634338	VIKTORIYA GUSEVA	{"email": "viktoriya.guseva_21051972@postgrespro.ru", "phone": "+70513953188"}
0005434374213	DD301E	1550 607034	ANNA SERGEEVA	{"email": "sergeeva-anna.021977@postgrespro.ru", "phone": "+70989040962"}
0005434374214	40EB64	4588 032110	LARISA ARKHIPOVA	{"email": "arkhipova-l.13031970@postgrespro.ru", "phone": "+70607441395"}
0005434374215	40EB64	9543 551607	ANDREY MOISEEV	{"phone": "+70395770764"}
0005434374216	DD8FD6	4230 584369	OLEG SERGEEV	{"phone": "+70364275900"}
0005434374217	B27C14	2253 748833	TATYANA KARPOVA	{"email": "karpova_tatyana-081978@postgrespro.ru", "phone": "+70780416637"}
0005434374218	B27C14	3724 165752	ANASTASIYA NESTEROVA	{"email": "nesterova.anastasiya_1972@postgrespro.ru", "phone": "+70262651818"}
0005434374219	3734C7	8331 762910	TAISIYA KOZLOVA	{"phone": "+70538697596"}
0005434374220	74F1E0	1306 123215	VADIM SOKOLOV	{"email": "sokolov_v.121966@postgrespro.ru", "phone": "+70045922981"}
0005434374221	0DF7F5	6609 621991	NIKITA ROMANOV	{"phone": "+70835201082"}
0005434374222	7ED2D0	3028 578988	PETR MATVEEV	{"email": "p.matveev.27101973@postgrespro.ru", "phone": "+70086834124"}
0005434374223	DACC14	9390 321738	VLADIMIR MOISEEV	{"phone": "+70338833959"}
0005434374224	DACC14	2293 490095	VLADISLAV KOZLOV	{"email": "kozlov.v-111978@postgrespro.ru", "phone": "+70667048344"}
0005434374225	F1F3AA	6831 598241	VALENTIN SOROKIN	{"email": "v-sorokin.1967@postgrespro.ru", "phone": "+70883450112"}
0005434374226	FE22E4	0618 413237	VALENTINA KOROLEVA	{"email": "v_koroleva.081980@postgrespro.ru", "phone": "+70183946427"}
0005434374227	7698F4	9507 305915	DMITRIY KAZAKOV	{"phone": "+70163089694"}
0005434374228	420A08	7374 560913	ELENA SIDOROVA	{"phone": "+70162494247"}
0005434374229	3FABCD	5089 395534	TATYANA PETROVA	{"phone": "+70684870716"}
0005434374230	7FF7BD	6915 582751	MARINA VOROBEVA	{"phone": "+70542793321"}
0005434374231	7FF7BD	1874 745387	OLGA NOVIKOVA	{"email": "o_novikova.16081980@postgrespro.ru", "phone": "+70436007490"}
0005434374232	4A5A73	3488 652697	NATALYA KONDRATEVA	{"phone": "+70260470912"}
0005434374233	4A5A73	8237 649861	NATALYA KOROLEVA	{"phone": "+70461036529"}
0005434374234	FA3DED	8020 036847	DMITRIY ZAKHAROV	{"phone": "+70312709688"}
0005434374235	EC31A9	1017 219254	VIKTOR SCHERBAKOV	{"email": "v_scherbakov.08031967@postgrespro.ru", "phone": "+70877716093"}
0005434374236	EABFD0	0637 279664	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr081977@postgrespro.ru", "phone": "+70714060458"}
0005434374237	EABFD0	0608 851110	ALEKSANDR VASILEV	{"email": "vasilev.a.25061973@postgrespro.ru", "phone": "+70420336929"}
0005434374238	C93318	5520 520712	NATALIYA PAVLOVA	{"phone": "+70884720821"}
0005434374239	D5A44B	3636 466620	MAKSIM ILIN	{"phone": "+70407846901"}
0005434374240	313F7A	2191 714387	IRINA POPOVA	{"email": "ipopova-101971@postgrespro.ru", "phone": "+70005997117"}
0005434374241	049882	3157 614319	OLGA POPOVA	{"phone": "+70055749740"}
0005434374242	EDD998	8615 608795	ASKHAT SOKOLOV	{"email": "askhat-sokolov031976@postgrespro.ru", "phone": "+70350985023"}
0005434374243	610751	1399 600101	MARINA MOROZOVA	{"email": "marina-morozova.1972@postgrespro.ru", "phone": "+70146610545"}
0005434374244	91F5D3	1269 632961	VALENTINA ERMAKOVA	{"phone": "+70771120728"}
0005434374245	841B2E	6552 824961	TAMARA GORBUNOVA	{"email": "gorbunova_t_1971@postgrespro.ru", "phone": "+70661600999"}
0005434374246	018517	9884 767489	NATALYA IVANOVA	{"email": "natalya.ivanova-02021972@postgrespro.ru", "phone": "+70488447671"}
0005434374247	018517	4917 670347	VLADIMIR FILIPPOV	{"email": "vladimir.filippov_13071964@postgrespro.ru", "phone": "+70014401080"}
0005434374248	018517	1771 808603	VIKTOR KOROLEV	{"email": "korolev_viktor.1978@postgrespro.ru", "phone": "+70261017179"}
0005434374249	5407D2	1860 325255	YURIY SAVELEV	{"email": "savelev.yuriy03061973@postgrespro.ru", "phone": "+70257320354"}
0005434374250	2F5736	4439 643402	TAMARA FOMINA	{"email": "fomina-t091966@postgrespro.ru", "phone": "+70465576131"}
0005434374251	2F5736	7407 415765	EKATERINA EFREMOVA	{"email": "ekaterinaefremova.1968@postgrespro.ru", "phone": "+70227611226"}
0005434374252	D984D9	1031 576971	MIKHAIL ALEKSEEV	{"email": "alekseev-m071988@postgrespro.ru", "phone": "+70139246928"}
0005434374253	CC04E9	9993 644302	ALEKSANDR VOROBEV	{"phone": "+70901332079"}
0005434374254	CC04E9	0797 043146	ZOYA EGOROVA	{"phone": "+70252564297"}
0005434374255	4A7989	5913 740319	ALEKSEY NIKOLAEV	{"email": "nikolaev_a_121975@postgrespro.ru", "phone": "+70201977318"}
0005434374256	4A7989	1748 559372	RAISA MALYSHEVA	{"email": "malysheva-raisa04031982@postgrespro.ru", "phone": "+70734985920"}
0005434374257	E544F4	7337 204298	ALEKSEY IVANOV	{"email": "aivanov1963@postgrespro.ru", "phone": "+70193147424"}
0005434374258	748C1D	1884 168609	VITALIY KUZMIN	{"email": "kuzmin_v-1972@postgrespro.ru", "phone": "+70999654008"}
0005434374259	BD40B2	7416 259139	IVAN YAKOVLEV	{"phone": "+70526118888"}
0005434374260	2F98FB	1685 639279	SVETLANA KUZNECOVA	{"email": "kuznecovas-06121973@postgrespro.ru", "phone": "+70946286057"}
0005434374261	8CCF45	6723 630765	KIRILL GAVRILOV	{"phone": "+70206688080"}
0005434374262	8CCF45	4724 506604	YANA KONOVALOVA	{"email": "konovalova.y1982@postgrespro.ru", "phone": "+70058684625"}
0005434374263	8CCF45	1964 190323	DMITRIY DAVYDOV	{"phone": "+70690070165"}
0005434374264	CE9759	3973 460208	EGOR FEDOTOV	{"email": "fedotov.egor121971@postgrespro.ru", "phone": "+70004040703"}
0005434374265	EEFF6B	9522 495005	ALENA SOLOVEVA	{"phone": "+70579751456"}
0005434374266	B02087	7695 555043	VIKTOR DAVYDOV	{"phone": "+70749701907"}
0005434374267	983F0E	3186 861328	TATYANA KUZNECOVA	{"phone": "+70205567176"}
0005434374268	983F0E	3768 285356	MIKHAIL MOISEEV	{"email": "moiseev-m071973@postgrespro.ru", "phone": "+70100350755"}
0005434374269	983F0E	4525 378847	EKATERINA FILIPPOVA	{"phone": "+70415148403"}
0005434374270	30FE54	0550 594844	GALINA ALEKSEEVA	{"email": "galekseeva-011970@postgrespro.ru", "phone": "+70542463703"}
0005434374271	88B6F8	5226 154756	ALEKSEY TIMOFEEV	{"email": "timofeev-aleksey-24011971@postgrespro.ru", "phone": "+70709476258"}
0005434374272	76EDDD	5835 240396	VLADIMIR FILIPPOV	{"email": "vfilippov.1969@postgrespro.ru", "phone": "+70183170183"}
0005434374273	E87CE9	3515 889728	ROMAN SAVELEV	{"phone": "+70527059174"}
0005434374274	3D6D88	1493 049809	EVGENIY IVANOV	{"email": "ivanove021965@postgrespro.ru", "phone": "+70738651130"}
0005434374275	3D6D88	1111 292935	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov091975@postgrespro.ru", "phone": "+70093743186"}
0005434374276	F4B658	1648 233940	ALEKSANDR BONDARENKO	{"email": "a_bondarenko_091971@postgrespro.ru", "phone": "+70781068299"}
0005434374277	F4B658	4078 208835	DMITRIY VASILEV	{"phone": "+70604143642"}
0005434374278	50CDA4	2665 498806	SVETLANA GRISHINA	{"email": "grishina_s011977@postgrespro.ru", "phone": "+70335055427"}
0005434374279	A0D5C7	9210 798228	DARYA MAKAROVA	{"phone": "+70839814051"}
0005434374280	AA8573	8148 076082	KSENIYA ALEKSEEVA	{"phone": "+70859764786"}
0005434374281	B5D8E3	9842 131271	ALEKSANDR KUDRYASHOV	{"email": "aleksandrkudryashov1959@postgrespro.ru", "phone": "+70532941079"}
0005434374282	1097DD	9222 688717	OLEG SCHERBAKOV	{"phone": "+70719521123"}
0005434374283	1097DD	8514 823633	ALEKSANDR KULIKOV	{"email": "kulikov_a-091959@postgrespro.ru", "phone": "+70529866766"}
0005434374284	285DC7	9521 477033	SVETLANA KALININA	{"email": "kalinina-svetlana.1971@postgrespro.ru", "phone": "+70786479439"}
0005434374285	285DC7	5103 827551	VADIM ZAYCEV	{"phone": "+70800964219"}
0005434374286	1CF6C8	2660 223683	MARINA CHERNOVA	{"phone": "+70194120770"}
0005434374287	E079B9	6241 161456	ANNA DAVYDOVA	{"email": "davydovaa1976@postgrespro.ru", "phone": "+70489901738"}
0005434374288	6199F9	3326 412901	NIKITA SHEVCHENKO	{"email": "shevchenko-n-27121967@postgrespro.ru", "phone": "+70007769353"}
0005434374289	55A97E	5052 790767	VLADIMIR TIKHONOV	{"email": "vladimir.tikhonov16031969@postgrespro.ru", "phone": "+70823953471"}
0005434374290	D56710	3701 546412	ANNA SOROKINA	{"phone": "+70215257842"}
0005434374291	8A9BFA	6934 673345	VALERIY ZAKHAROV	{"email": "zakharov-v03041971@postgrespro.ru", "phone": "+70846561297"}
0005434374292	3649AF	5171 088982	ALEKSANDR VLASOV	{"phone": "+70018189458"}
0005434374293	EF5709	9519 360356	YURIY VASILEV	{"phone": "+70808935716"}
0005434374294	8133F6	3705 169921	YURIY PETROV	{"phone": "+70345176183"}
0005434374295	8133F6	9153 444996	VIKTOR ORLOV	{"email": "orlov.viktor18021976@postgrespro.ru", "phone": "+70925186385"}
0005434374296	E4463F	5007 112968	ALEKSEY MAKSIMOV	{"email": "a_maksimov_031973@postgrespro.ru", "phone": "+70194982618"}
0005434374297	E4463F	4264 779579	MAKSIM POPOV	{"phone": "+70862813804"}
0005434374298	7A0194	9037 552910	ANASTASIYA KULIKOVA	{"phone": "+70439136266"}
0005434374299	0016D0	4109 298344	ELINA MIKHAYLOVA	{"email": "elina-mikhaylova27101965@postgrespro.ru", "phone": "+70944318611"}
0005434374300	0016D0	3666 152154	VLADIMIR KONOVALOV	{"email": "konovalov.v_25021975@postgrespro.ru", "phone": "+70904484644"}
0005434374301	70B962	4147 212293	VARVARA IVANOVA	{"phone": "+70800028434"}
0005434374302	70B962	6357 774830	VIKTOR ALEKSEEV	{"phone": "+70183205382"}
0005434374303	93D8C2	7069 569395	VALERIY TIMOFEEV	{"email": "v_timofeev22071978@postgrespro.ru", "phone": "+70421548158"}
0005434374304	03FBB4	3334 770759	ROMAN PAVLOV	{"phone": "+70220674677"}
0005434374305	E1FF9A	5677 541744	SVETLANA GERASIMOVA	{"email": "gerasimova_svetlana_19071982@postgrespro.ru", "phone": "+70702325845"}
0005434374306	E1FF9A	6720 532996	NINA ALEKSEEVA	{"email": "n_alekseeva031991@postgrespro.ru", "phone": "+70793571204"}
0005434374307	1AD66F	4241 810464	ALEKSANDR SAVELEV	{"email": "savelev-a_15051970@postgrespro.ru", "phone": "+70246043927"}
0005434374308	E002C9	2356 760612	VYACHESLAV MOROZOV	{"phone": "+70219747975"}
0005434374309	E002C9	1323 942373	ANNA SOLOVEVA	{"phone": "+70754684865"}
0005434374310	9E8BC8	1993 653507	SERGEY DMITRIEV	{"email": "dmitriev_sergey-091983@postgrespro.ru", "phone": "+70939951212"}
0005434374311	55CD96	7965 358702	YURIY YAKOVLEV	{"phone": "+70084894257"}
0005434374312	58E55D	7858 818975	RAISA PETROVA	{"phone": "+70417203495"}
0005434374313	C277C9	0531 295957	NADEZHDA SOKOLOVA	{"email": "sokolovanadezhda.17061965@postgrespro.ru", "phone": "+70659776429"}
0005434374489	4BD48A	2649 504546	OLGA MAKAROVA	{"phone": "+70079897678"}
0005434374314	C277C9	1389 516967	LARISA IVANOVA	{"email": "ivanova_larisa20071975@postgrespro.ru", "phone": "+70467222224"}
0005434374315	8A1CE7	5485 244428	YULIYA SCHERBAKOVA	{"email": "scherbakova.yuliya.1963@postgrespro.ru", "phone": "+70014316695"}
0005434374316	8A1CE7	7994 064215	RAISA MEDVEDEVA	{"email": "raisa.medvedeva1967@postgrespro.ru", "phone": "+70143415737"}
0005434374317	DAA1C5	0721 404170	SERGEY STEPANOV	{"email": "stepanov-s-1969@postgrespro.ru", "phone": "+70858631942"}
0005434374318	D9AD5F	2863 230398	SVETLANA KUZNECOVA	{"email": "kuznecova-s_081976@postgrespro.ru", "phone": "+70438290297"}
0005434374319	266D0F	4174 428778	NIKITA NOVIKOV	{"email": "novikov.n_1954@postgrespro.ru", "phone": "+70350578232"}
0005434374320	266D0F	3828 135325	SERGEY NOVIKOV	{"email": "s_novikov041970@postgrespro.ru", "phone": "+70842418003"}
0005434374321	EC08A5	7341 359632	MARIYA NIKITINA	{"email": "m-nikitina.1968@postgrespro.ru", "phone": "+70949646687"}
0005434374322	EC08A5	2423 292889	MARGARITA TROFIMOVA	{"email": "margarita-trofimova_05051968@postgrespro.ru", "phone": "+70919587613"}
0005434374323	5F7280	6163 328458	ALEKSANDR STEPANOV	{"phone": "+70599157153"}
0005434374324	E5A925	3683 242300	IRINA ALEKSANDROVA	{"email": "irina.aleksandrova1975@postgrespro.ru", "phone": "+70240044645"}
0005434374325	A5EFE9	8797 046574	ANTONINA PETROVA	{"email": "petrovaa07031976@postgrespro.ru", "phone": "+70391380949"}
0005434374326	B5676B	6061 005516	MAKSIM BONDARENKO	{"phone": "+70796800279"}
0005434374327	B5676B	5979 872536	MARINA SIDOROVA	{"phone": "+70142076751"}
0005434374328	B5676B	0676 997096	PETR FOMIN	{"email": "fomin_p.18101976@postgrespro.ru", "phone": "+70640355650"}
0005434374329	8A1190	8746 667939	EVGENIY GUSEV	{"email": "gusev.evgeniy.29061974@postgrespro.ru", "phone": "+70797356731"}
0005434374330	0899FD	3702 469131	VERA KONOVALOVA	{"email": "v.konovalova_13021970@postgrespro.ru", "phone": "+70313693508"}
0005434374331	1A1E09	8781 028317	VLADIMIR KISELEV	{"email": "kiselevv_07111980@postgrespro.ru", "phone": "+70286776948"}
0005434374332	17784A	6571 864968	TATYANA MARTYNOVA	{"email": "t_martynova-1970@postgrespro.ru", "phone": "+70623549812"}
0005434374333	D8BCAF	6978 234013	NATALYA KONDRATEVA	{"email": "natalya-kondrateva16081964@postgrespro.ru", "phone": "+70350972311"}
0005434374334	1CCC4A	3450 034300	EVGENIYA IVANOVA	{"email": "e_ivanova-041977@postgrespro.ru", "phone": "+70378158295"}
0005434374335	DBF955	1343 549823	EVGENIY SOLOVEV	{"phone": "+70858846260"}
0005434374336	2CD867	4600 334171	VITALIY BELOV	{"email": "belov_v1958@postgrespro.ru", "phone": "+70141520628"}
0005434374337	2CD867	7475 115973	YURIY SIDOROV	{"email": "y_sidorov-1968@postgrespro.ru", "phone": "+70288698639"}
0005434374338	A79622	5576 493553	VITALIY OSIPOV	{"email": "osipov_vitaliy.111973@postgrespro.ru", "phone": "+70033790781"}
0005434374339	FFD25F	2408 547105	OLGA KISELEVA	{"phone": "+70791238034"}
0005434374340	DE049B	4298 304208	ELENA SCHERBAKOVA	{"phone": "+70723246141"}
0005434374341	7D9084	7749 075439	ANATOLIY ZAKHAROV	{"phone": "+70652888301"}
0005434374342	6CCDCE	2089 834553	NATALYA FADEEVA	{"phone": "+70595948986"}
0005434374343	6CCDCE	7214 154489	IRINA KULIKOVA	{"email": "kulikova-irina1978@postgrespro.ru", "phone": "+70723819518"}
0005434374344	18696D	1895 232921	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy_021973@postgrespro.ru", "phone": "+70011438454"}
0005434374345	18696D	9709 253407	ALENA SOROKINA	{"email": "alena.sorokina_091970@postgrespro.ru", "phone": "+70538744834"}
0005434374346	CD3779	1437 783095	VALENTINA GAVRILOVA	{"email": "v_gavrilova.021972@postgrespro.ru", "phone": "+70240278949"}
0005434374347	CD3779	2588 531383	ELZA FROLOVA	{"email": "efrolova_011967@postgrespro.ru", "phone": "+70516611097"}
0005434374348	C19382	4542 962974	LYUBOV ZAKHAROVA	{"email": "zakharoval041975@postgrespro.ru", "phone": "+70922972217"}
0005434374349	EDDDC2	5859 013791	SERGEY DMITRIEV	{"phone": "+70928923011"}
0005434374350	416320	3319 080664	VIKTOR IVANOV	{"email": "ivanov-viktor14041976@postgrespro.ru", "phone": "+70239920839"}
0005434374351	70A85A	4099 819496	YURIY STEPANOV	{"email": "stepanovyuriy-1967@postgrespro.ru", "phone": "+70904501919"}
0005434374352	70A85A	4194 484773	TAMARA GORBUNOVA	{"phone": "+70155216650"}
0005434374353	7A21E3	4055 532864	LARISA TARASOVA	{"phone": "+70600782395"}
0005434374354	F2ADC7	9986 497573	NINA SCHERBAKOVA	{"email": "n.scherbakova.101976@postgrespro.ru", "phone": "+70302649990"}
0005434374355	E1070A	6837 482075	IVAN SERGEEV	{"email": "ivan_sergeev.091980@postgrespro.ru", "phone": "+70347628813"}
0005434374356	E1070A	0720 373178	VALERIY KULIKOV	{"phone": "+70430348204"}
0005434374357	E1070A	3427 163363	MILANA SERGEEVA	{"phone": "+70687961289"}
0005434374358	15EBC3	9425 112626	KONSTANTIN PETROV	{"phone": "+70477945807"}
0005434374359	15EBC3	8654 936053	MARIYA MIRONOVA	{"email": "m_mironova-06071985@postgrespro.ru", "phone": "+70326514874"}
0005434374360	C376AD	8960 015214	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_v.1969@postgrespro.ru", "phone": "+70162857645"}
0005434374361	C376AD	2115 017767	IVAN SERGEEV	{"email": "ivansergeev-08061974@postgrespro.ru", "phone": "+70157497024"}
0005434374585	DB430E	7077 363200	SERGEY POPOV	{"phone": "+70840438396"}
0005434374362	C376AD	8630 696245	TAMARA KISELEVA	{"email": "tamara-kiseleva-30091981@postgrespro.ru", "phone": "+70470633719"}
0005434374363	D8AB8C	7766 920161	ANNA GERASIMOVA	{"phone": "+70684015672"}
0005434374364	B14A96	5131 013058	YURIY STEPANOV	{"phone": "+70315418264"}
0005434374365	B14A96	6997 359296	ALEKSEY KOZLOV	{"phone": "+70344695333"}
0005434374366	00178F	0237 989520	LYUBOV NESTEROVA	{"phone": "+70516416444"}
0005434374367	7A1BBD	9422 899386	MAKSIM VASILEV	{"phone": "+70781945731"}
0005434374368	EEACEB	4553 859037	VERA IVANOVA	{"phone": "+70156413774"}
0005434374369	DB6260	7949 587892	ANDREY PAVLOV	{"phone": "+70295957801"}
0005434374370	383410	0797 771221	KSENIYA NESTEROVA	{"phone": "+70481239589"}
0005434374547	A39587	6941 599641	ALEKSEY ISAEV	{"phone": "+70085552590"}
0005434374371	383410	1692 413717	MAKSIM KRASNOV	{"email": "maksim-krasnov1981@postgrespro.ru", "phone": "+70418137282"}
0005434374372	FB91D7	3941 197735	NIKOLAY KUDRYASHOV	{"email": "n-kudryashov1963@postgrespro.ru", "phone": "+70900096199"}
0005434374373	FB91D7	1988 083751	ANDREY TARASOV	{"email": "tarasov_andrey_1971@postgrespro.ru", "phone": "+70919758446"}
0005434374374	78C290	6513 472495	ANNA MIKHAYLOVA	{"phone": "+70074480590"}
0005434374375	78CC7C	7277 385926	NATALIYA BORISOVA	{"phone": "+70789491326"}
0005434374376	D72DCD	9307 070526	LIDIYA VOROBEVA	{"email": "vorobeva.l1960@postgrespro.ru", "phone": "+70872990061"}
0005434374377	284B88	2693 601564	DMITRIY AFANASEV	{"phone": "+70274632960"}
0005434374378	68E34D	0695 570138	ALEKSEY SEMENOV	{"phone": "+70088110268"}
0005434374379	68E34D	1573 118442	YULIYA YAKOVLEVA	{"phone": "+70799788988"}
0005434374380	E23C5A	1716 892230	TATYANA BORISOVA	{"email": "tatyana_borisova1975@postgrespro.ru", "phone": "+70622382424"}
0005434374381	A47C7F	4633 916310	SOFIYA TITOVA	{"phone": "+70495152063"}
0005434374382	A47C7F	4404 621677	EVGENIY CHERNOV	{"email": "chernov_e-071975@postgrespro.ru", "phone": "+70919294338"}
0005434374383	A2FC0E	7948 411087	SERGEY ANDREEV	{"email": "sergeyandreev-021979@postgrespro.ru", "phone": "+70392397542"}
0005434374384	CD5ECE	5467 910612	ROMAN FEDOROV	{"email": "fedorov.r.091973@postgrespro.ru", "phone": "+70470968040"}
0005434374385	C233B0	9584 377507	TIMOFEY VOLKOV	{"email": "volkovtimofey_20031977@postgrespro.ru", "phone": "+70584427980"}
0005434374386	D1CE27	9814 149607	ANDREY PETROV	{"phone": "+70600485894"}
0005434374387	D1CE27	3572 361597	NIKOLAY KRASNOV	{"email": "nikolay-krasnov-1958@postgrespro.ru", "phone": "+70645056116"}
0005434374388	745555	6390 593252	RINAT SOLOVEV	{"phone": "+70549419051"}
0005434374389	98735F	4724 262935	OLGA EGOROVA	{"phone": "+70751446188"}
0005434374390	98735F	9703 338005	ALENA NIKOLAEVA	{"phone": "+70951668315"}
0005434374391	523F6C	4421 445460	RINAT VASILEV	{"phone": "+70526962246"}
0005434374392	523F6C	0482 824234	STANISLAV POPOV	{"email": "popovs-021965@postgrespro.ru", "phone": "+70358528939"}
0005434374393	FEC4EA	4500 082365	DENIS SHEVCHENKO	{"email": "shevchenko.d_1964@postgrespro.ru", "phone": "+70502752322"}
0005434374394	7FC8F7	6841 070549	PRASKOVYA EGOROVA	{"email": "egorova-praskovya_28101967@postgrespro.ru", "phone": "+70023875272"}
0005434374395	F39FAC	0804 876250	IRINA SEMENOVA	{"phone": "+70421637683"}
0005434374396	F39FAC	6518 019237	MIKHAIL POPOV	{"phone": "+70909549815"}
0005434374397	5B83C6	7327 460078	ZINAIDA POTAPOVA	{"phone": "+70599671604"}
0005434374398	5B83C6	9678 670846	YURIY PAVLOV	{"phone": "+70599120462"}
0005434374399	0BEE93	4801 531552	MARAT ZAYCEV	{"phone": "+70879652368"}
0005434374400	8F3E67	1490 870823	OLGA NESTEROVA	{"phone": "+70134391861"}
0005434374401	D4D4F4	4740 813790	ZINAIDA MELNIKOVA	{"phone": "+70847586066"}
0005434374402	D4D4F4	0577 518510	VITALIY ORLOV	{"email": "vitaliyorlov081972@postgrespro.ru", "phone": "+70031055075"}
0005434374403	4BAEDB	1533 218787	TATYANA EFIMOVA	{"phone": "+70173657474"}
0005434374404	D8E14A	9062 235224	EVGENIYA VASILEVA	{"phone": "+70724517755"}
0005434374405	B545CF	1668 620061	IVAN RODIONOV	{"email": "rodionov.ivan-30111976@postgrespro.ru", "phone": "+70780718785"}
0005434374406	6F2CE1	5083 236782	NATALYA GAVRILOVA	{"phone": "+70350803926"}
0005434374407	6F2CE1	8848 912844	RAISA ANISIMOVA	{"email": "raisa_anisimova-01061950@postgrespro.ru", "phone": "+70842970004"}
0005434374408	F1E93D	1294 828300	ALEKSANDR SEMENOV	{"email": "semenov_a-30011981@postgrespro.ru", "phone": "+70742097190"}
0005434374409	5A1DCD	1465 967824	VLADIMIR VASILEV	{"email": "vasilevvladimir.1970@postgrespro.ru", "phone": "+70085775497"}
0005434374410	5A1DCD	8351 253589	TATYANA NOVIKOVA	{"email": "novikova.tatyana1984@postgrespro.ru", "phone": "+70127230497"}
0005434374411	9E3394	8612 776384	SERGEY GORBUNOV	{"phone": "+70629132094"}
0005434374412	3055DD	5687 582092	IRINA EGOROVA	{"email": "egorovairina061975@postgrespro.ru", "phone": "+70226753405"}
0005434374413	3055DD	3610 489192	DANIIL PAVLOV	{"phone": "+70709575156"}
0005434374414	B91175	2822 935704	VIKTOR PETROV	{"phone": "+70588576478"}
0005434374415	00C72E	4531 217322	SVETLANA SMIRNOVA	{"phone": "+70848794163"}
0005434374416	CF3CCE	2067 666597	TATYANA RODIONOVA	{"email": "tatyana-rodionova_17051964@postgrespro.ru", "phone": "+70307014169"}
0005434374417	994E75	2888 124821	EVGENIYA SOKOLOVA	{"email": "sokolovaevgeniya_061968@postgrespro.ru", "phone": "+70373863123"}
0005434374418	25822C	5407 875531	SERGEY MAKAROV	{"email": "sergey-makarov071966@postgrespro.ru", "phone": "+70680455263"}
0005434374419	C800BB	7283 153991	YURIY NIKITIN	{"email": "yuriy.nikitin_1974@postgrespro.ru", "phone": "+70927702241"}
0005434374420	518AB0	8412 115347	NINA IVANOVA	{"email": "n-ivanova.08091979@postgrespro.ru", "phone": "+70079992486"}
0005434374421	795924	4809 484507	ALEKSEY ILIN	{"email": "aleksey.ilin-1973@postgrespro.ru", "phone": "+70544208362"}
0005434374422	795924	4940 393547	VASILIY DAVYDOV	{"email": "vasiliydavydov101965@postgrespro.ru", "phone": "+70541120229"}
0005434374423	AE4849	4102 991012	GALINA IVANOVA	{"phone": "+70511714018"}
0005434374424	1EEBD7	6501 783372	ZINAIDA SAVELEVA	{"email": "savelevaz_31101968@postgrespro.ru", "phone": "+70244669687"}
0005434374425	1EEBD7	0184 361870	ANASTASIYA GUSEVA	{"email": "guseva.anastasiya.20011973@postgrespro.ru", "phone": "+70375966155"}
0005434374426	2D4741	1968 351121	ANNA KOLESNIKOVA	{"phone": "+70022761036"}
0005434374427	E1F289	1172 050598	MARIYA BORISOVA	{"email": "mariyaborisova.1967@postgrespro.ru", "phone": "+70656627466"}
0005434374428	722242	6883 775207	MARGARITA NAUMOVA	{"email": "margarita_naumova06021971@postgrespro.ru", "phone": "+70603484959"}
0005434374429	911ACF	9127 976872	EKATERINA PAVLOVA	{"phone": "+70946164295"}
0005434374430	177D0E	4513 771937	ARTUR TIKHONOV	{"email": "tikhonov-artur_121975@postgrespro.ru", "phone": "+70621584271"}
0005434374431	177D0E	1936 581916	NIKITA KUZMIN	{"email": "nikita-kuzmin091969@postgrespro.ru", "phone": "+70714834810"}
0005434374432	06282D	5188 513345	IGOR MIRONOV	{"phone": "+70069409834"}
0005434374433	DFED80	3862 113242	OLGA MIRONOVA	{"email": "olga-mironova-1972@postgrespro.ru", "phone": "+70593382004"}
0005434374434	DFED80	5163 102959	SERGEY AFANASEV	{"email": "safanasev_16061965@postgrespro.ru", "phone": "+70386293775"}
0005434374435	DFED80	9455 319927	OLGA VASILEVA	{"email": "vasileva_olga_20111968@postgrespro.ru", "phone": "+70483865264"}
0005434374436	6CBBD4	9228 298386	LYUBOV YUDINA	{"email": "yudinal_07041965@postgrespro.ru", "phone": "+70132954387"}
0005434374437	B7FAF1	7346 257166	TATYANA SAVELEVA	{"email": "savelevatatyana.101974@postgrespro.ru", "phone": "+70314235331"}
0005434374438	916FF8	3715 280383	ALENA OVCHINNIKOVA	{"email": "ovchinnikova_alena_101985@postgrespro.ru", "phone": "+70352866244"}
0005434374439	BFCD50	2668 184882	TATYANA ZAKHAROVA	{"phone": "+70452882863"}
0005434374440	58F337	0730 115990	EKATERINA SAVELEVA	{"email": "esaveleva_1974@postgrespro.ru", "phone": "+70806113929"}
0005434374441	70A1B0	3275 052717	RAISA GORBUNOVA	{"email": "raisa_gorbunova_02051975@postgrespro.ru", "phone": "+70957278803"}
0005434374442	7DED5D	5480 437045	LYUDMILA KUZNECOVA	{"email": "lyudmila.kuznecova_27061970@postgrespro.ru", "phone": "+70363654744"}
0005434374443	FA6E40	9260 932393	SOFIYA LAZAREVA	{"phone": "+70600123430"}
0005434374444	FA6E40	9890 275975	DMITRIY ALEKSEEV	{"email": "alekseev.dmitriy_1973@postgrespro.ru", "phone": "+70251617644"}
0005434374445	6581FA	1506 953995	EVGENIY MEDVEDEV	{"email": "medvedev-evgeniy-1962@postgrespro.ru", "phone": "+70772335458"}
0005434374446	22D199	6905 124607	ALEKSANDR ZAYCEV	{"phone": "+70131965377"}
0005434374447	B3D99F	3107 852749	EKATERINA NAZAROVA	{"email": "nazarova_e.15041987@postgrespro.ru", "phone": "+70180711662"}
0005434374448	31ADD5	1405 221312	NADEZHDA ZHURAVLEVA	{"phone": "+70628049699"}
0005434374449	31ADD5	5318 527220	MAKSIM CHERNOV	{"email": "chernov_maksim051971@postgrespro.ru", "phone": "+70417731247"}
0005434374450	44AC39	4003 904706	NATALYA MAKSIMOVA	{"phone": "+70768956410"}
0005434374451	348820	1096 820764	NATALYA SMIRNOVA	{"phone": "+70874455317"}
0005434374452	348820	4794 198897	EGOR SEMENOV	{"phone": "+70851789788"}
0005434374453	348820	8071 213928	OKSANA PETROVA	{"phone": "+70810103779"}
0005434374454	D3B426	9672 876660	ILYA SHEVCHENKO	{"email": "i-shevchenko.1972@postgrespro.ru", "phone": "+70073091193"}
0005434374455	D3B426	7351 559184	VLADIMIR SOKOLOV	{"phone": "+70641217002"}
0005434374456	319A40	7693 624491	IRINA ANTONOVA	{"email": "i_antonova_021970@postgrespro.ru", "phone": "+70991072399"}
0005434374457	319A40	4962 843094	ANNA RYABOVA	{"email": "a.ryabova_091971@postgrespro.ru", "phone": "+70337413632"}
0005434374458	CEAAC7	2386 686960	SVETLANA KOVALEVA	{"email": "kovaleva-svetlana_1958@postgrespro.ru", "phone": "+70916942374"}
0005434374459	CEAAC7	9577 119206	DMITRIY KISELEV	{"phone": "+70629504058"}
0005434374460	F4784F	3053 750566	VARVARA EGOROVA	{"email": "v-egorova-12121959@postgrespro.ru", "phone": "+70336043418"}
0005434374461	F4784F	0592 015521	IGOR TARASOV	{"email": "tarasovigor-041973@postgrespro.ru", "phone": "+70449141931"}
0005434374462	F4784F	3429 006978	ANDREY ANDREEV	{"email": "andreev.a_1980@postgrespro.ru", "phone": "+70708911796"}
0005434374463	145FFE	1911 781474	GALINA ISAEVA	{"phone": "+70720669153"}
0005434374464	BE0469	9711 345708	ILYA GORBUNOV	{"email": "ilya_gorbunov_20071975@postgrespro.ru", "phone": "+70474715418"}
0005434374465	BE0469	7501 461252	ANTON SERGEEV	{"phone": "+70672264909"}
0005434374466	BE0469	7802 854269	IRINA NIKOLAEVA	{"email": "inikolaeva_1963@postgrespro.ru", "phone": "+70501404524"}
0005434374467	160E3C	8530 028896	ANNA CHERNOVA	{"email": "chernova.anna071962@postgrespro.ru", "phone": "+70070577085"}
0005434374468	44D6B7	4415 277641	VLADIMIR MAKSIMOV	{"email": "v-maksimov.1964@postgrespro.ru", "phone": "+70492911462"}
0005434374469	D92D42	9277 972950	MIKHAIL MAKAROV	{"phone": "+70115281372"}
0005434374470	A1175F	1793 123972	MARIYA DENISOVA	{"email": "denisovam_091964@postgrespro.ru", "phone": "+70433415364"}
0005434374471	A1175F	5800 526351	DMITRIY GRIGOREV	{"email": "grigorev_dmitriy.111966@postgrespro.ru", "phone": "+70976105301"}
0005434374472	3A3A00	4533 730697	ANASTASIYA POTAPOVA	{"phone": "+70558538435"}
0005434374473	A3CE1F	6652 164909	ALEKSANDR VLASOV	{"phone": "+70495534342"}
0005434374474	A3CE1F	3047 934118	SERGEY KUZNECOV	{"email": "skuznecov-1973@postgrespro.ru", "phone": "+70314344411"}
0005434374475	A3CE1F	0990 677685	ANDREY KUZNECOV	{"phone": "+70512297709"}
0005434374476	DC686D	7227 834476	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov_1966@postgrespro.ru", "phone": "+70522247445"}
0005434374477	AD7691	4466 928178	SERGEY NAUMOV	{"email": "naumov.sergey.1979@postgrespro.ru", "phone": "+70962388797"}
0005434374478	AD7691	8558 582799	VLADIMIR FROLOV	{"phone": "+70862921504"}
0005434374479	8BB03D	5062 391802	YULIYA BORISOVA	{"email": "borisova.y_1966@postgrespro.ru", "phone": "+70383852109"}
0005434374480	E57281	5034 051512	SERGEY ANDREEV	{"email": "andreevs21051967@postgrespro.ru", "phone": "+70424173805"}
0005434374481	E57281	4868 239081	TATYANA ANISIMOVA	{"email": "anisimova_tatyana031975@postgrespro.ru", "phone": "+70733411950"}
0005434374482	4997C7	1016 358794	EKATERINA NIKITINA	{"phone": "+70859103139"}
0005434374483	4997C7	7876 825233	ARTEM ALEKSANDROV	{"phone": "+70799920894"}
0005434374484	1380DC	3287 314030	MARK KISELEV	{"phone": "+70785977666"}
0005434374485	B21FC1	6424 750523	SERGEY GORBUNOV	{"email": "gorbunov-s_091967@postgrespro.ru", "phone": "+70789534151"}
0005434374486	5CE96E	9266 591431	ANNA SIDOROVA	{"phone": "+70798094542"}
0005434374487	5CE96E	1151 700408	NINA ROMANOVA	{"email": "romanova.nina101969@postgrespro.ru", "phone": "+70826360501"}
0005434374488	7D54E1	3727 506479	OLEG MOROZOV	{"phone": "+70279096418"}
0005434374490	A67388	5160 023418	ALEVTINA ERMAKOVA	{"email": "ermakova.a.011972@postgrespro.ru", "phone": "+70584657055"}
0005434374491	AAA748	6925 713435	NADEZHDA GUSEVA	{"email": "guseva-n_1962@postgrespro.ru", "phone": "+70473525154"}
0005434374492	AAA748	3341 158619	VLADIMIR MAKAROV	{"email": "vladimir_makarov-1968@postgrespro.ru", "phone": "+70643272226"}
0005434374493	AAA748	0244 499108	MARINA STEPANOVA	{"phone": "+70808212489"}
0005434374494	AF0F3F	7350 223660	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a-1979@postgrespro.ru", "phone": "+70600695419"}
0005434374495	AF0F3F	2074 883250	NIKOLAY IVANOV	{"email": "n.ivanov_1969@postgrespro.ru", "phone": "+70469307973"}
0005434374496	84FE5A	6190 941427	TATYANA SIDOROVA	{"email": "t-sidorova_051981@postgrespro.ru", "phone": "+70205569968"}
0005434374497	180102	6388 433636	GALINA BORISOVA	{"phone": "+70220793472"}
0005434374498	0D3623	5863 896839	OLGA FEDOROVA	{"email": "fedorovao1968@postgrespro.ru", "phone": "+70341140426"}
0005434374499	0D3623	8533 300773	PAVEL VOROBEV	{"email": "vorobev-pavel.15081980@postgrespro.ru", "phone": "+70595507800"}
0005434374500	0D3623	0852 151223	TATYANA EGOROVA	{"email": "egorovatatyana_18121970@postgrespro.ru", "phone": "+70225003702"}
0005434374501	CAB81D	7197 646091	SERGEY SOROKIN	{"phone": "+70758080146"}
0005434374502	CAB81D	0858 101404	ALEKSANDR ROMANOV	{"email": "romanovaleksandr.121958@postgrespro.ru", "phone": "+70010712578"}
0005434374503	C324DC	4170 309136	ZINAIDA DENISOVA	{"phone": "+70799846478"}
0005434374504	9099B0	2558 158106	ELENA ISAEVA	{"phone": "+70574054132"}
0005434374505	8C0FE8	1476 332819	VALERIY MEDVEDEV	{"phone": "+70859389203"}
0005434374506	AD1A94	2110 421414	YURIY POPOV	{"email": "popov-y-1968@postgrespro.ru", "phone": "+70688913875"}
0005434374507	B91CCD	4781 933476	SERGEY ORLOV	{"phone": "+70783544837"}
0005434374508	DCB49D	2172 776403	MAKSIM BONDARENKO	{"email": "bondarenkomaksim111973@postgrespro.ru", "phone": "+70072877883"}
0005434374509	DCB49D	8505 601315	VLADIMIR ALEKSANDROV	{"phone": "+70061786792"}
0005434374510	DB357C	2029 511477	LYUDMILA ZAKHAROVA	{"email": "zakharovalyudmila-13091962@postgrespro.ru", "phone": "+70391110293"}
0005434374511	DB357C	4480 830777	LIDIYA NIKITINA	{"email": "nikitina_l.121967@postgrespro.ru", "phone": "+70749954412"}
0005434374512	D9E46F	6804 095106	LYUBOV CHERNOVA	{"email": "lchernova07021969@postgrespro.ru", "phone": "+70897546250"}
0005434374513	45104B	5580 869821	ILNUR SERGEEV	{"email": "ilnur.sergeev1981@postgrespro.ru", "phone": "+70427690775"}
0005434374514	4D22C6	4366 380771	TATYANA NIKITINA	{"phone": "+70708516469"}
0005434374515	4D22C6	3303 116699	ALEKSEY ALEKSANDROV	{"email": "aleksey-aleksandrov1972@postgrespro.ru", "phone": "+70375401449"}
0005434374516	91C364	6734 167740	NIKITA TIKHONOV	{"email": "n.tikhonov28061967@postgrespro.ru", "phone": "+70031193959"}
0005434374517	3549BF	7323 902909	ANASTASIYA MARTYNOVA	{"email": "martynova.a091975@postgrespro.ru", "phone": "+70577813335"}
0005434374518	3549BF	8834 339936	VALENTINA ANDREEVA	{"email": "andreevavalentina061975@postgrespro.ru", "phone": "+70667865088"}
0005434374519	3549BF	0426 859520	ELIZAVETA LUKYANOVA	{"phone": "+70969066577"}
0005434374520	966C15	8903 140263	DANILA SHEVCHENKO	{"phone": "+70374022647"}
0005434374521	966C15	8790 591412	GALINA IVANOVA	{"email": "ivanova_g.1974@postgrespro.ru", "phone": "+70104533604"}
0005434374522	553CB5	9464 677494	VASILIY STEPANOV	{"email": "v_stepanov.1967@postgrespro.ru", "phone": "+70851126259"}
0005434374523	553CB5	7734 263214	VIKTORIYA NESTEROVA	{"phone": "+70730828209"}
0005434374524	DC10E2	8602 002840	STANISLAV MIKHAYLOV	{"email": "mikhaylov.stanislav-1972@postgrespro.ru", "phone": "+70357491683"}
0005434374525	DC10E2	5189 953706	ANNA MAKSIMOVA	{"email": "maksimovaanna1973@postgrespro.ru", "phone": "+70667463299"}
0005434374526	DF1925	6652 757036	MARINA POPOVA	{"email": "popovam_101977@postgrespro.ru", "phone": "+70896789434"}
0005434374527	DF1925	1594 632510	NIKOLAY ANTONOV	{"phone": "+70113497012"}
0005434374528	BE1DA8	6291 262167	KONSTANTIN PAVLOV	{"phone": "+70959075366"}
0005434374586	7A321E	0493 928124	TAMARA ZOTOVA	{"phone": "+70876309820"}
0005434374529	BE1DA8	6459 225844	NIKITA POPOV	{"email": "nikita_popov-04091968@postgrespro.ru", "phone": "+70594792453"}
0005434374530	12E298	2992 223769	YURIY IVANOV	{"phone": "+70225956537"}
0005434374531	12E298	5964 792780	VLADIMIR DENISOV	{"phone": "+70872815179"}
0005434374532	1A7108	5067 913768	ANTON FEDOROV	{"phone": "+70007053340"}
0005434374533	12B9A7	4575 060291	VITALIY GRIGOREV	{"email": "grigorev_vitaliy_011981@postgrespro.ru", "phone": "+70325232377"}
0005434374534	12B9A7	3378 379537	KRISTINA NESTEROVA	{"email": "nesterova.kristina-26101966@postgrespro.ru", "phone": "+70761113507"}
0005434374535	13379D	9705 368704	VALERIY NIKITIN	{"phone": "+70290806673"}
0005434374536	13379D	5531 190631	VALENTINA LEBEDEVA	{"phone": "+70818701225"}
0005434374537	13379D	0184 265174	LYUDMILA LOGINOVA	{"email": "lloginova1966@postgrespro.ru", "phone": "+70277909581"}
0005434374538	7120E0	5938 746302	NATALYA SIDOROVA	{"email": "sidorova_natalya.1968@postgrespro.ru", "phone": "+70704083609"}
0005434374539	7120E0	3139 888139	AYRAT ZAYCEV	{"phone": "+70862990551"}
0005434374540	597C86	1948 132910	NATALYA EFREMOVA	{"email": "natalya_efremova02061967@postgrespro.ru", "phone": "+70095896259"}
0005434374541	597C86	4766 710912	TATYANA YAKOVLEVA	{"phone": "+70880110639"}
0005434374542	603A6A	6396 588371	ELENA VASILEVA	{"email": "vasileva-e.13041968@postgrespro.ru", "phone": "+70580442700"}
0005434374543	976B6C	4247 391387	LYUDMILA KUZMINA	{"email": "kuzmina.lyudmila_051980@postgrespro.ru", "phone": "+70350338405"}
0005434374544	976B6C	6938 964845	SERGEY BARANOV	{"email": "sergey-baranov.16101970@postgrespro.ru", "phone": "+70420898757"}
0005434374545	976B6C	8587 335279	EVGENIY SIDOROV	{"email": "evgeniy.sidorov-1957@postgrespro.ru", "phone": "+70862574991"}
0005434374546	A39587	5511 241543	IVAN BORISOV	{"phone": "+70802790261"}
0005434374548	8FF870	4647 181652	SERGEY ZAYCEV	{"email": "zaycev.sergey1982@postgrespro.ru", "phone": "+70143953012"}
0005434374549	6AAE96	2592 134139	NADEZHDA ZHURAVLEVA	{"phone": "+70527120020"}
0005434374550	B51998	2803 134881	RUSLAN ZAKHAROV	{"phone": "+70380693267"}
0005434374551	C2A2DB	9513 187437	ALBINA ANDREEVA	{"phone": "+70103005011"}
0005434374552	CF7752	8593 425852	LYUBOV KRASNOVA	{"phone": "+70207600452"}
0005434374553	CF7752	2548 620622	ARTEM KUZNECOV	{"email": "kuznecovartem-1970@postgrespro.ru", "phone": "+70345236401"}
0005434374554	B07268	0985 563547	NINA MAKAROVA	{"phone": "+70808873689"}
0005434374555	E763D5	6448 723029	VLADIMIR DMITRIEV	{"email": "vladimir-dmitriev_1974@postgrespro.ru", "phone": "+70773002561"}
0005434374556	C89037	3509 201041	ALEKSANDR ZAYCEV	{"phone": "+70742500625"}
0005434374557	C89037	8583 059427	OLEG SERGEEV	{"email": "o_sergeev_27111976@postgrespro.ru", "phone": "+70338689703"}
0005434374558	C89037	4699 760993	SERGEY AFANASEV	{"email": "afanasev_sergey-15091971@postgrespro.ru", "phone": "+70834898020"}
0005434374559	AE8924	8057 139196	ILMIR KUZNECOV	{"phone": "+70283412541"}
0005434374560	91CBB4	3729 313146	YULIYA GERASIMOVA	{"phone": "+70789719367"}
0005434374561	FFE28D	4143 488089	ALEVTINA PETROVA	{"email": "a-petrova_1970@postgrespro.ru", "phone": "+70770627490"}
0005434374562	ABEA2C	5508 327009	SERGEY ROMANOV	{"email": "sromanov.1972@postgrespro.ru", "phone": "+70956650737"}
0005434374563	ABEA2C	8433 464953	NADEZHDA KUZNECOVA	{"phone": "+70465686038"}
0005434374564	6E3CF8	3372 428493	TARAS SHEVCHENKO	{"phone": "+70776572296"}
0005434374565	6E3CF8	6340 307311	NINA KUZMINA	{"phone": "+70188362617"}
0005434374566	6E3CF8	3535 746430	NIKOLAY KOZLOV	{"email": "nikolay_kozlov.1975@postgrespro.ru", "phone": "+70901443840"}
0005434374567	8B11C0	8641 906552	EKATERINA DAVYDOVA	{"phone": "+70704124186"}
0005434374568	569E41	7356 193792	NIKITA DMITRIEV	{"phone": "+70228338464"}
0005434374569	569E41	3433 280545	SERGEY VASILEV	{"phone": "+70266318055"}
0005434374570	FC8984	6191 227603	MIKHAIL VOLKOV	{"email": "mikhail-volkov-021976@postgrespro.ru", "phone": "+70343081710"}
0005434374571	FC8984	6458 777230	LIDIYA KOROLEVA	{"email": "lidiya.koroleva.101971@postgrespro.ru", "phone": "+70866499633"}
0005434374572	B2C3CA	5401 463547	OLGA SOKOLOVA	{"phone": "+70375494820"}
0005434374573	289637	9222 093581	VERONIKA EGOROVA	{"email": "v_egorova111976@postgrespro.ru", "phone": "+70855427733"}
0005434374574	D5422A	4090 153990	EKATERINA NIKIFOROVA	{"email": "enikiforova1971@postgrespro.ru", "phone": "+70667285504"}
0005434374575	D5422A	8812 125971	ALEKSANDRA FOMINA	{"phone": "+70201271579"}
0005434374576	778264	3655 399093	LARISA SAVELEVA	{"phone": "+70922277773"}
0005434374577	A48E3E	7429 151519	NATALYA LEBEDEVA	{"email": "natalya.lebedeva081966@postgrespro.ru", "phone": "+70038203761"}
0005434374578	2A7981	8559 724867	OLGA MAKSIMOVA	{"email": "maksimova.o1975@postgrespro.ru", "phone": "+70545757944"}
0005434374579	D5A5FA	6085 064020	LARISA KOZLOVA	{"email": "kozloval_051971@postgrespro.ru", "phone": "+70322639856"}
0005434374580	D5A5FA	9855 526137	OLGA TIKHONOVA	{"email": "tikhonova-o21051969@postgrespro.ru", "phone": "+70674003169"}
0005434374581	558DF8	0884 667859	ELENA EGOROVA	{"email": "egorova.elena.21101958@postgrespro.ru", "phone": "+70052424753"}
0005434374582	2F972A	1689 534242	NIKITA DENISOV	{"phone": "+70769945682"}
0005434374583	C922EE	5136 325608	VALENTINA ISAEVA	{"email": "isaeva_v-1970@postgrespro.ru", "phone": "+70237967702"}
0005434374584	C922EE	0984 930885	NATALIYA NESTEROVA	{"email": "n.nesterova-081987@postgrespro.ru", "phone": "+70293768198"}
0005434374587	0DA894	8459 321581	MARINA TIMOFEEVA	{"email": "timofeeva_m_11091972@postgrespro.ru", "phone": "+70748707228"}
0005434374588	702C10	0489 134767	VALERIY MAKAROV	{"phone": "+70935427105"}
0005434374589	C196EE	1570 410570	VIKTORIYA KUZNECOVA	{"phone": "+70244406719"}
0005434374590	5A82E0	1947 973271	PETR CHERNOV	{"email": "petr.chernov-121975@postgrespro.ru", "phone": "+70222292127"}
0005434374591	2C723B	3621 825108	VYACHESLAV KAZAKOV	{"phone": "+70374563377"}
0005434374592	5C80C1	6368 520549	NINA DAVYDOVA	{"phone": "+70877642509"}
0005434374593	5C80C1	3114 357469	GERMAN FEDOTOV	{"email": "g-fedotov-24061985@postgrespro.ru", "phone": "+70354146835"}
0005434374594	BD3CA9	0007 651036	INNA DENISOVA	{"email": "innadenisova_101960@postgrespro.ru", "phone": "+70171868041"}
0005434374595	BD1441	7508 941777	VLADIMIR DMITRIEV	{"email": "v-dmitriev_031978@postgrespro.ru", "phone": "+70270541910"}
0005434374596	85DF2A	8604 659075	ALEKSANDRA MOISEEVA	{"email": "a-moiseeva_031965@postgrespro.ru", "phone": "+70592624151"}
0005434374597	85DF2A	6247 648719	GULIYA NIKITINA	{"phone": "+70067557933"}
0005434374598	74CF45	0962 594861	OLGA EGOROVA	{"email": "olga_egorova011978@postgrespro.ru", "phone": "+70382645926"}
0005434374599	31C46F	0470 432464	MARINA MIKHAYLOVA	{"phone": "+70429435771"}
0005434374600	1E065C	7410 097890	VALERIYA MAKAROVA	{"email": "makarova-v091962@postgrespro.ru", "phone": "+70264650027"}
0005434374601	03E717	0829 422827	PRASKOVYA SERGEEVA	{"email": "praskovya.sergeeva081983@postgrespro.ru", "phone": "+70476775605"}
0005434374602	BBE186	5178 508425	SVETLANA KAZAKOVA	{"email": "svetlanakazakova_1968@postgrespro.ru", "phone": "+70654357883"}
0005434374603	7D41BF	9175 101685	OLGA SOLOVEVA	{"email": "soloveva_olga.1980@postgrespro.ru", "phone": "+70013185791"}
0005434374604	FB841E	0371 723399	VALERIY NIKITIN	{"email": "v_nikitin-011990@postgrespro.ru", "phone": "+70200393503"}
0005434374605	F4B1AD	6356 061421	ALEKSEY KULIKOV	{"email": "kulikovaleksey.011979@postgrespro.ru", "phone": "+70147333416"}
0005434374606	D46430	0990 345759	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey1979@postgrespro.ru", "phone": "+70300718940"}
0005434374607	D46430	9522 040536	OLGA DANILOVA	{"phone": "+70409784864"}
0005434374608	662E4F	1866 645512	EVGENIY KULIKOV	{"email": "evgeniy-kulikov_22061974@postgrespro.ru", "phone": "+70582515199"}
0005434374609	662E4F	0501 263156	OLEG KISELEV	{"phone": "+70044280174"}
0005434374610	B6D22D	3563 562474	VERA NIKOLAEVA	{"email": "vera.nikolaeva.071980@postgrespro.ru", "phone": "+70241984933"}
0005434374611	3DD534	1443 561674	LYUDMILA SEMENOVA	{"email": "lyudmila_semenova_031964@postgrespro.ru", "phone": "+70341056939"}
0005434374612	3DD534	7682 877325	DMITRIY SERGEEV	{"phone": "+70528734251"}
0005434374613	B727F7	7270 254466	TATYANA SERGEEVA	{"email": "t.sergeeva02081983@postgrespro.ru", "phone": "+70191566478"}
0005434374614	F03414	9318 123434	ANATOLIY STEPANOV	{"email": "stepanov_anatoliy051986@postgrespro.ru", "phone": "+70410196546"}
0005434374615	33EE1C	9611 387203	POLINA SEMENOVA	{"email": "p_semenova-1977@postgrespro.ru", "phone": "+70663381312"}
0005434374616	F1756E	9007 426913	VADIM PETROV	{"email": "vadim.petrov1984@postgrespro.ru", "phone": "+70495443371"}
0005434374617	1BCCD7	5196 786212	OLGA NESTEROVA	{"phone": "+70825009837"}
0005434374618	084FE8	7909 352669	ANATOLIY BORISOV	{"phone": "+70472424294"}
0005434374619	084FE8	8809 291144	NADIYA SEMENOVA	{"email": "n-semenova.071970@postgrespro.ru", "phone": "+70093152646"}
0005434374620	084FE8	4882 198751	MARIYA BORISOVA	{"email": "m-borisova03071973@postgrespro.ru", "phone": "+70848288087"}
0005434374621	8BCC52	2811 153986	OLESYA VLASOVA	{"email": "olesya_vlasova011974@postgrespro.ru", "phone": "+70054263873"}
0005434374622	8BCC52	7524 724355	DENIS KUZNECOV	{"email": "kuznecov-denis.12011964@postgrespro.ru", "phone": "+70230993414"}
0005434374623	6684CC	4140 088429	KONSTANTIN IVANOV	{"email": "konstantin.ivanov_1971@postgrespro.ru", "phone": "+70802008170"}
0005434374624	B5392E	6945 025228	ELIZAVETA SOROKINA	{"email": "sorokinaelizaveta-021964@postgrespro.ru", "phone": "+70274050359"}
0005434374625	3BCFE3	4637 451417	DENIS DAVYDOV	{"email": "davydov.denis-1979@postgrespro.ru", "phone": "+70096681408"}
0005434374626	5ED17A	9835 911792	PELAGEYA KUZNECOVA	{"email": "kuznecova_p.091979@postgrespro.ru", "phone": "+70787403192"}
0005434374627	608507	9093 047704	LILIYA SOLOVEVA	{"email": "l_soloveva-1984@postgrespro.ru", "phone": "+70582185887"}
0005434374628	CCE7CE	8997 335653	OLGA GRISHINA	{"email": "olga-grishina1974@postgrespro.ru", "phone": "+70356167817"}
0005434374629	15FAB3	6753 521631	TATYANA FILIPPOVA	{"phone": "+70615510354"}
0005434374630	F2DCA5	8531 072847	ANDREY ANDREEV	{"email": "andrey_andreev-10061953@postgrespro.ru", "phone": "+70670509302"}
0005434374631	F2DCA5	8736 445327	SERGEY POPOV	{"phone": "+70981788060"}
0005434374632	3597F5	0600 128511	INESSA DMITRIEVA	{"email": "idmitrieva.14121973@postgrespro.ru", "phone": "+70389942095"}
0005434374633	DBADC4	6772 105445	ALEKSANDR ZAYCEV	{"phone": "+70453554235"}
0005434374634	1966FD	6600 445769	NINA BELOVA	{"email": "belovanina-1975@postgrespro.ru", "phone": "+70138823337"}
0005434374635	1966FD	9979 403077	IVAN KULIKOV	{"email": "kulikov.ivan-1976@postgrespro.ru", "phone": "+70297775322"}
0005434374636	5F51AF	7276 008607	SERGEY ZAKHAROV	{"phone": "+70826961890"}
0005434374637	CC0D6A	3905 389680	DMITRIY NIKITIN	{"email": "d.nikitin-1973@postgrespro.ru", "phone": "+70541106601"}
0005434374638	CC0D6A	2522 320212	EVGENIY ILIN	{"email": "ilin.evgeniy-1964@postgrespro.ru", "phone": "+70629491640"}
0005434374639	BE5DCA	7041 371988	STEPAN KULIKOV	{"email": "stepankulikov.22061964@postgrespro.ru", "phone": "+70834464959"}
0005434374640	038C34	0133 226508	EKATERINA ROMANOVA	{"email": "romanovaekaterina_011974@postgrespro.ru", "phone": "+70417405916"}
0005434374641	746425	2667 688928	YURIY PAVLOV	{"phone": "+70983040383"}
0005434374642	746425	6316 758354	VERA MELNIKOVA	{"phone": "+70294492061"}
0005434374643	2678D3	1340 126506	OLEG OSIPOV	{"email": "osipov_oleg_1979@postgrespro.ru", "phone": "+70494942981"}
0005434374644	2678D3	3690 020215	LIDIYA EFIMOVA	{"email": "l-efimova-28111977@postgrespro.ru", "phone": "+70456659656"}
0005434374645	110E12	4586 921717	SERGEY YAKOVLEV	{"phone": "+70056109216"}
0005434374646	110E12	1885 294199	SERGEY PETROV	{"email": "petrov-s-14091974@postgrespro.ru", "phone": "+70212284394"}
0005434374647	110E12	7091 603502	MARINA KAZAKOVA	{"email": "kazakova_m.1970@postgrespro.ru", "phone": "+70676500601"}
0005434374648	E52867	8347 902971	SERGEY NIKITIN	{"email": "nikitin_sergey-28051958@postgrespro.ru", "phone": "+70710271107"}
0005434374649	7DC4C2	5712 224829	SVETLANA POPOVA	{"phone": "+70513742106"}
0005434374650	7DC4C2	1585 313564	VITALIY TIKHONOV	{"phone": "+70700578168"}
0005434374651	6C5C26	8969 002273	VIKTOR SMIRNOV	{"phone": "+70434914493"}
0005434374652	6C5C26	8403 012492	ANATOLIY FEDOROV	{"phone": "+70039754715"}
0005434374653	6C5C26	1721 707035	MIKHAIL MAKAROV	{"phone": "+70936131551"}
0005434374654	EA3E80	8171 754555	TATYANA NIKOLAEVA	{"phone": "+70798868072"}
0005434374655	389CEF	4623 755537	EVGENIY NAZAROV	{"email": "nazarov-e_29121972@postgrespro.ru", "phone": "+70743727757"}
0005434374656	2E96AE	0161 034530	VLADIMIR FROLOV	{"phone": "+70720746443"}
0005434374657	E96038	8447 470490	RASUL ORLOV	{"phone": "+70094512534"}
0005434374658	1402D2	3481 947647	NINA ANDREEVA	{"email": "nina_andreeva-101973@postgrespro.ru", "phone": "+70027794352"}
0005434374659	996BE6	5138 642256	VERA LAZAREVA	{"email": "vera.lazareva-081977@postgrespro.ru", "phone": "+70078907719"}
0005434374660	FFCC7A	2959 367346	TAMARA YAKOVLEVA	{"phone": "+70013064964"}
0005434374661	077469	2212 080850	MIKHAIL POPOV	{"phone": "+70888621734"}
0005434374662	077469	6045 711435	LIDIYA SAVELEVA	{"phone": "+70655318734"}
0005434374663	A1B5C7	5293 641208	ILYA ZAYCEV	{"email": "zaycev.i-1965@postgrespro.ru", "phone": "+70174508851"}
0005434374664	4066FB	4242 574650	OLGA ANISIMOVA	{"email": "o_anisimova-1963@postgrespro.ru", "phone": "+70220552549"}
0005434374665	35EF3E	6785 645846	ALEKSEY MOROZOV	{"email": "morozov.a1982@postgrespro.ru", "phone": "+70350036299"}
0005434374666	35EF3E	7042 698232	ALEKSANDR ZHURAVLEV	{"phone": "+70983541969"}
0005434374779	EDC452	3382 996376	ELENA IVANOVA	{"phone": "+70073486995"}
0005434374667	510D61	9504 313331	TATYANA VOLKOVA	{"email": "volkova-tatyana_06041975@postgrespro.ru", "phone": "+70592189796"}
0005434374668	D7AD6E	4844 148013	TATYANA ZAYCEVA	{"phone": "+70217962706"}
0005434374669	D7AD6E	9541 442083	LIDIYA EGOROVA	{"phone": "+70392017354"}
0005434374670	07584E	0232 249205	IRINA KOROLEVA	{"email": "korolevairina.041980@postgrespro.ru", "phone": "+70303347957"}
0005434374671	D475FF	9787 484551	DMITRIY VASILEV	{"email": "d-vasilev07101973@postgrespro.ru", "phone": "+70402522466"}
0005434374672	4C4E67	5070 731317	VERA BOGDANOVA	{"phone": "+70706099653"}
0005434374673	4C4E67	2483 331091	VLADIMIR NOVIKOV	{"email": "novikov.vladimir-13051972@postgrespro.ru", "phone": "+70659015563"}
0005434374674	E887EE	1406 768437	ALINA MIKHAYLOVA	{"phone": "+70410617114"}
0005434374675	126904	2795 602911	SERGEY GERASIMOV	{"phone": "+70839960642"}
0005434374676	C39DB0	3224 977179	FEDOR MIKHAYLOV	{"phone": "+70181725019"}
0005434374677	9E1D9F	5362 915390	GALINA OSIPOVA	{"email": "osipova_g.1965@postgrespro.ru", "phone": "+70770496190"}
0005434374678	9E1D9F	6915 148048	NATALYA ALEKSEEVA	{"email": "natalya.alekseeva121973@postgrespro.ru", "phone": "+70564336094"}
0005434374679	65374B	9263 517560	IVAN NAUMOV	{"email": "ivan-naumov-28031973@postgrespro.ru", "phone": "+70699465800"}
0005434374680	46FA22	4688 400319	SVETLANA NIKIFOROVA	{"phone": "+70702826799"}
0005434374681	11B2B8	6093 563768	NIKOLAY DAVYDOV	{"phone": "+70916193202"}
0005434374682	323AB5	5929 536653	EVGENIY KOZLOV	{"email": "evgeniy-kozlov_121965@postgrespro.ru", "phone": "+70827012477"}
0005434374683	323AB5	3594 768020	NADEZHDA SMIRNOVA	{"email": "nadezhda-smirnova.1972@postgrespro.ru", "phone": "+70200456811"}
0005434374684	24170C	0282 997359	TAMARA GAVRILOVA	{"email": "tamara-gavrilova05101969@postgrespro.ru", "phone": "+70034690813"}
0005434374685	B59E8C	4657 133590	NIKOLAY ANTONOV	{"phone": "+70606804498"}
0005434374686	264637	7756 525901	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov_1967@postgrespro.ru", "phone": "+70201109512"}
0005434374687	09E1D7	8682 108484	VIKTORIYA NAZAROVA	{"email": "vnazarova_1978@postgrespro.ru", "phone": "+70480917781"}
0005434374688	B06C6A	1016 242607	YURIY NOVIKOV	{"phone": "+70097236949"}
0005434374689	B06C6A	5990 819721	SERGEY SOKOLOV	{"phone": "+70077259471"}
0005434374690	A5A2EF	0779 988215	OLGA KONOVALOVA	{"email": "olga_konovalova03081985@postgrespro.ru", "phone": "+70966780826"}
0005434374691	E7B5AC	5594 934085	VALENTINA BORISOVA	{"email": "valentinaborisova091977@postgrespro.ru", "phone": "+70447249075"}
0005434374692	E7B5AC	5723 464475	EVELINA MAKAROVA	{"email": "makarovaevelina_1969@postgrespro.ru", "phone": "+70389862389"}
0005434374693	837336	9589 142828	VALERIY FEDOTOV	{"email": "valeriy_fedotov_081961@postgrespro.ru", "phone": "+70339364439"}
0005434374694	B0579B	2029 611051	MIKHAIL ANDREEV	{"phone": "+70630329397"}
0005434374695	B0579B	8499 634161	ANNA ZHUKOVA	{"email": "a.zhukova_031973@postgrespro.ru", "phone": "+70012016608"}
0005434374696	BB2E86	0179 163495	DENIS BORISOV	{"email": "d-borisov_1966@postgrespro.ru", "phone": "+70518190704"}
0005434374697	8E5BE2	9119 650948	ALEKSEY MOROZOV	{"phone": "+70807049931"}
0005434374698	A74750	6856 310947	YAROSLAVA KOROLEVA	{"phone": "+70427426385"}
0005434374699	50A5D0	0856 198815	STANISLAV ZHURAVLEV	{"email": "zhuravlevstanislav.121980@postgrespro.ru", "phone": "+70784067173"}
0005434374700	5F2A77	4184 130731	SVETLANA IVANOVA	{"phone": "+70380685881"}
0005434374701	5F2A77	0344 601746	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova-011959@postgrespro.ru", "phone": "+70475410160"}
0005434374702	A4754C	0381 210923	VLADIMIR MIRONOV	{"email": "mironov.v13081975@postgrespro.ru", "phone": "+70829738032"}
0005434374703	A4754C	6888 598917	VLADIMIR BARANOV	{"phone": "+70278306983"}
0005434374704	23F4E8	1758 044722	OLEG TARASOV	{"email": "tarasov_o_1968@postgrespro.ru", "phone": "+70682698859"}
0005434374705	BC01FA	2900 787735	VALENTINA MIRONOVA	{"email": "valentinamironova-1974@postgrespro.ru", "phone": "+70704623668"}
0005434374706	67B99F	7826 554249	OLGA MOROZOVA	{"email": "morozovao_1970@postgrespro.ru", "phone": "+70450188377"}
0005434374707	67B99F	7293 194026	IRINA ZHUKOVA	{"phone": "+70903741728"}
0005434374708	FCAC3F	7615 677239	VLADIMIR MOROZOV	{"phone": "+70492514249"}
0005434374709	D25A50	5509 282530	TAMARA ROMANOVA	{"email": "romanova_t081966@postgrespro.ru", "phone": "+70281475467"}
0005434374710	C43611	1456 715014	NIKOLAY ZAKHAROV	{"email": "nikolay.zakharov.25111968@postgrespro.ru", "phone": "+70071162544"}
0005434374711	C43611	9331 667698	SVETLANA SERGEEVA	{"phone": "+70542548532"}
0005434374712	92B4D8	9047 778305	MARINA SCHERBAKOVA	{"phone": "+70942551319"}
0005434374713	92B4D8	9021 857085	LYUBOV TARASOVA	{"phone": "+70157164113"}
0005434374714	D02683	0002 440753	OLESYA ROMANOVA	{"email": "romanova-o-1972@postgrespro.ru", "phone": "+70104390774"}
0005434374715	C91BC9	7019 227190	YURIY IVANOV	{"email": "yuriyivanov-061971@postgrespro.ru", "phone": "+70326168724"}
0005434374716	7C6F26	6060 509444	TAMARA PETROVA	{"phone": "+70912234981"}
0005434374717	950515	3089 845725	ALEKSEY SMIRNOV	{"phone": "+70020350448"}
0005434374718	7D7F3B	0709 175500	TATYANA KULIKOVA	{"phone": "+70580655293"}
0005434374719	C617A3	9503 420425	GRIGORIY ANDREEV	{"phone": "+70819981112"}
0005434374720	1E993B	7969 612198	VIKTOR SEMENOV	{"email": "viktorsemenov091965@postgrespro.ru", "phone": "+70305259967"}
0005434374721	1E993B	6275 307648	ILGIZ MATVEEV	{"phone": "+70408689041"}
0005434374722	C08635	5964 089915	VYACHESLAV ALEKSEEV	{"email": "vyacheslav.alekseev_1980@postgrespro.ru", "phone": "+70452045322"}
0005434374723	C08635	8633 784084	KONSTANTIN MAKAROV	{"email": "kmakarov-1985@postgrespro.ru", "phone": "+70810845966"}
0005434374724	E12A55	1144 807521	ANNA SMIRNOVA	{"email": "smirnova_a.1970@postgrespro.ru", "phone": "+70412346987"}
0005434374725	E12A55	4861 511955	VYACHESLAV NAZAROV	{"phone": "+70323909051"}
0005434374726	E12A55	7840 464041	ELIZAVETA NOVIKOVA	{"email": "e_novikova.061968@postgrespro.ru", "phone": "+70135013675"}
0005434374727	3C8572	6936 160902	VALENTINA GERASIMOVA	{"phone": "+70670884631"}
0005434374728	3C8572	9907 016029	IGOR SOKOLOV	{"phone": "+70234618115"}
0005434374729	6D2C25	8189 780383	EKATERINA KONDRATEVA	{"phone": "+70139889689"}
0005434374730	A82EEF	8442 665711	VADIM KUZMIN	{"email": "kuzmin_v_081967@postgrespro.ru", "phone": "+70068231360"}
0005434374731	A82EEF	8768 973106	FEDOR TARASOV	{"email": "fedor_tarasov.1970@postgrespro.ru", "phone": "+70952883282"}
0005434374732	81D748	7864 444166	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr1985@postgrespro.ru", "phone": "+70577402644"}
0005434374733	81D748	7725 875764	ALEKSANDRA SEMENOVA	{"phone": "+70451417470"}
0005434374734	7BA380	1882 262426	KSENIYA ORLOVA	{"phone": "+70149319396"}
0005434374735	7BA380	6736 882271	SERGEY ZHUKOV	{"email": "s.zhukov.031974@postgrespro.ru", "phone": "+70583744245"}
0005434374736	17EB91	3316 260828	TATYANA SCHERBAKOVA	{"email": "scherbakova_t.041981@postgrespro.ru", "phone": "+70175446369"}
0005434374737	2DEE9C	9426 496158	VALENTIN SERGEEV	{"phone": "+70826978970"}
0005434374738	5FA88E	5563 532760	ELENA NESTEROVA	{"phone": "+70361183020"}
0005434374739	5FA88E	5761 035634	VALERIY SEMENOV	{"email": "semenov_v.1965@postgrespro.ru", "phone": "+70370312031"}
0005434374740	441E33	2414 504512	MARIYA ABRAMOVA	{"phone": "+70329246625"}
0005434374741	441E33	0092 498742	MIKHAIL MAKAROV	{"email": "makarovmikhail_091970@postgrespro.ru", "phone": "+70531009983"}
0005434374742	4C30F3	3789 294516	FELIKS NOVIKOV	{"email": "f.novikov071976@postgrespro.ru", "phone": "+70220080866"}
0005434374743	954B6E	8697 062721	GALINA ANDREEVA	{"email": "andreeva.g-041980@postgrespro.ru", "phone": "+70051610704"}
0005434374744	61D0A6	5555 781584	LEONID NOVIKOV	{"email": "l-novikov-1973@postgrespro.ru", "phone": "+70403152875"}
0005434374745	55FE41	2634 391467	EVGENIY RODIONOV	{"email": "rodionov_evgeniy_041973@postgrespro.ru", "phone": "+70525896969"}
0005434374746	BC448D	2909 224861	ANNA IVANOVA	{"phone": "+70669274714"}
0005434374747	3F73AC	5090 395171	KLAVDIYA NIKIFOROVA	{"email": "nikiforova-k-061970@postgrespro.ru", "phone": "+70644813953"}
0005434374748	3AB8C3	1376 742125	VALENTINA SCHERBAKOVA	{"phone": "+70624215020"}
0005434374749	AAFA99	4345 046094	ANDREY KRASNOV	{"email": "krasnov.a_26101970@postgrespro.ru", "phone": "+70007830596"}
0005434374750	BAA219	5486 090709	PELAGEYA SEMENOVA	{"email": "psemenova_091961@postgrespro.ru", "phone": "+70830873580"}
0005434374751	BAA219	5524 581604	KARINA TARASOVA	{"phone": "+70154858727"}
0005434374752	062424	1852 676964	TAMARA LUKYANOVA	{"phone": "+70873159899"}
0005434374753	F2CF57	1122 816728	TATYANA LAZAREVA	{"email": "tatyana_lazareva-12111969@postgrespro.ru", "phone": "+70474298962"}
0005434374754	F72A3E	4156 837310	OLGA KOMAROVA	{"email": "o-komarova_091961@postgrespro.ru", "phone": "+70509551467"}
0005434374755	544738	4230 924191	ALEKSANDR IVANOV	{"email": "ivanov.a-27041965@postgrespro.ru", "phone": "+70814229668"}
0005434374756	544738	6002 963624	VIKTOR STEPANOV	{"email": "viktor-stepanov061973@postgrespro.ru", "phone": "+70540185112"}
0005434374757	544738	4475 688399	MARIYA ERMAKOVA	{"phone": "+70263883014"}
0005434374758	6AD4D4	7028 776021	EKATERINA PETROVA	{"phone": "+70249064826"}
0005434374759	2FDD51	8064 866953	TATYANA VLASOVA	{"phone": "+70297780511"}
0005434374760	97B655	2916 104191	DARYA SOKOLOVA	{"phone": "+70797021592"}
0005434374761	B4F357	2610 208887	DMITRIY CHERNOV	{"email": "chernovd-091983@postgrespro.ru", "phone": "+70783022259"}
0005434374762	492E00	0825 045420	EVGENIY NIKOLAEV	{"email": "nikolaev_evgeniy.21011977@postgrespro.ru", "phone": "+70647598055"}
0005434374763	261C3F	9798 223433	IRINA VOLKOVA	{"email": "i.volkova.081973@postgrespro.ru", "phone": "+70579308359"}
0005434374764	052D46	0808 502523	SERGEY TIMOFEEV	{"phone": "+70488946890"}
0005434374765	113837	3102 500562	SERGEY ILIN	{"phone": "+70220439765"}
0005434374766	596CB5	1191 548889	SEMEN MAKSIMOV	{"email": "maksimov-semen_021964@postgrespro.ru", "phone": "+70166915763"}
0005434374767	596CB5	2556 461624	NATALYA NIKIFOROVA	{"email": "nikiforova.n-071981@postgrespro.ru", "phone": "+70906975784"}
0005434374768	4E3C48	7250 681886	TATYANA KALININA	{"email": "kalinina.t.081972@postgrespro.ru", "phone": "+70561195711"}
0005434374769	82519B	4526 092960	SERGEY MAKAROV	{"phone": "+70403912580"}
0005434374770	82519B	0744 794896	VASILIY TIKHONOV	{"email": "vasiliy.tikhonov-26021979@postgrespro.ru", "phone": "+70113853376"}
0005434374771	202BD9	4302 447594	PRASKOVYA ERMAKOVA	{"phone": "+70059076398"}
0005434374772	FFB11A	0120 369335	SERGEY NIKOLAEV	{"phone": "+70013582137"}
0005434374773	391F16	2410 900414	NINA YAKOVLEVA	{"phone": "+70067898104"}
0005434374774	391F16	2632 388852	EVGENIY KAZAKOV	{"email": "evgeniy_kazakov.041968@postgrespro.ru", "phone": "+70956044088"}
0005434374775	391F16	1605 815584	DARYA KUZMINA	{"email": "dkuzmina_23041967@postgrespro.ru", "phone": "+70546474378"}
0005434374776	D2963A	3934 715272	IRINA KOZLOVA	{"phone": "+70456188354"}
0005434374777	AEE995	0137 718033	ALEKSANDR BORISOV	{"phone": "+70631751168"}
0005434374778	54F9C0	9591 059677	ELENA FADEEVA	{"email": "e-fadeeva_17101970@postgrespro.ru", "phone": "+70175648599"}
0005434374780	D1EA19	6400 704784	ELENA SMIRNOVA	{"email": "e-smirnova1969@postgrespro.ru", "phone": "+70629587050"}
0005434374781	D1EA19	8182 515461	NADEZHDA POPOVA	{"email": "popovanadezhda.081973@postgrespro.ru", "phone": "+70514984644"}
0005434374782	E3E999	7585 265652	ANDREY EGOROV	{"phone": "+70621835259"}
0005434374783	CBCB22	4871 475442	TATYANA MASLOVA	{"email": "maslova.tatyana021967@postgrespro.ru", "phone": "+70561838408"}
0005434374784	D164EA	4296 085086	OLGA SEMENOVA	{"email": "semenovaolga_101965@postgrespro.ru", "phone": "+70906270848"}
0005434374785	D164EA	4432 111194	LYUBOV MAKAROVA	{"phone": "+70655767007"}
0005434374786	93DCE8	4789 806809	ALEKSANDR VASILEV	{"phone": "+70378166667"}
0005434374787	50CFBC	9009 870398	ANATOLIY SOKOLOV	{"phone": "+70988785170"}
0005434374788	50CFBC	9889 123862	NIKOLAY PETROV	{"email": "nikolay-petrov1982@postgrespro.ru", "phone": "+70471238497"}
0005434374789	50CFBC	6087 838890	YULIYA MOISEEVA	{"email": "moiseeva_yuliya.11121967@postgrespro.ru", "phone": "+70340510343"}
0005434374790	9B9B6B	5306 041534	GULFIYA TIKHONOVA	{"phone": "+70340044649"}
0005434374791	9B9B6B	5657 627497	LARISA NESTEROVA	{"phone": "+70414370069"}
0005434374792	7F872E	7507 901439	NIKOLAY VOLKOV	{"phone": "+70365672026"}
0005434374793	187624	5037 742907	DANILA BELOV	{"email": "belovdanila-1973@postgrespro.ru", "phone": "+70726169925"}
0005434374794	187624	5297 699985	ELENA ORLOVA	{"phone": "+70075115821"}
0005434374795	6D0DB4	0848 160785	FELIKS IVANOV	{"email": "feliks_ivanov.121981@postgrespro.ru", "phone": "+70446835219"}
0005434374796	6D0DB4	1230 400962	YULIYA FILIPPOVA	{"email": "y.filippova-1983@postgrespro.ru", "phone": "+70107069628"}
0005434374797	756748	8872 290683	ANTONIDA BARANOVA	{"email": "antonidabaranova.071979@postgrespro.ru", "phone": "+70204577402"}
0005434374798	DC7E85	3601 679090	YULIYA SERGEEVA	{"phone": "+70554970865"}
0005434374799	D9CD9F	3743 445393	LYUDMILA KOROLEVA	{"phone": "+70247933371"}
0005434374800	7AACB3	0873 308846	VADIM KUZNECOV	{"email": "kuznecov-v-31121964@postgrespro.ru", "phone": "+70030162638"}
0005434374801	D30CC2	7979 716490	NADEZHDA RODIONOVA	{"phone": "+70354882828"}
0005434374802	687CA9	3735 497645	MARIYA POPOVA	{"phone": "+70508802092"}
0005434374803	687CA9	8625 124261	KONSTANTIN PETROV	{"phone": "+70808109564"}
0005434374804	687CA9	4843 826027	ALEKSANDR SEMENOV	{"phone": "+70097760064"}
0005434374805	479163	0070 845708	VIKTOR SOROKIN	{"email": "viktor.sorokin_061962@postgrespro.ru", "phone": "+70838715841"}
0005434374806	479163	7129 589511	VALERIY KRASNOV	{"email": "krasnov_v.09041966@postgrespro.ru", "phone": "+70981011522"}
0005434374807	7625EA	9099 029406	ROMAN SOLOVEV	{"email": "solovev.r.05121974@postgrespro.ru", "phone": "+70020180910"}
0005434374808	FF5400	1343 779953	IVAN ALEKSEEV	{"email": "alekseevivan.091974@postgrespro.ru", "phone": "+70701435628"}
0005434374809	B48D92	8962 919771	ZINAIDA VASILEVA	{"email": "vasileva-zinaida.03101962@postgrespro.ru", "phone": "+70050782672"}
0005434374810	3CCD86	1099 638397	VLADIMIR IVANOV	{"phone": "+70504446825"}
0005434374811	95A65F	6342 755380	IGOR EGOROV	{"email": "egorov_igor11081987@postgrespro.ru", "phone": "+70714536798"}
0005434374812	22679F	8065 739950	NATALYA ZHUKOVA	{"phone": "+70789459199"}
0005434374813	D2E2CF	3407 218998	ELENA MAKAROVA	{"email": "makarova-elena_12011976@postgrespro.ru", "phone": "+70356171634"}
0005434374814	E5976E	4066 794905	VITALIY NIKITIN	{"email": "vitaliy-nikitin-1964@postgrespro.ru", "phone": "+70526188379"}
0005434374815	E5976E	7552 815384	ALEKSANDRA BELOVA	{"phone": "+70876066263"}
0005434374816	7D86F0	9435 430428	VALERIY GRIGOREV	{"email": "v_grigorev.03121964@postgrespro.ru", "phone": "+70768868102"}
0005434374817	2A155C	5273 982504	TAMARA SAVELEVA	{"email": "saveleva_tamara05061979@postgrespro.ru", "phone": "+70726624972"}
0005434374818	BC7AFC	9717 902054	VALENTIN ALEKSEEV	{"email": "valekseev111972@postgrespro.ru", "phone": "+70780525106"}
0005434374819	BC7AFC	7344 651502	ANTONINA SMIRNOVA	{"phone": "+70727421304"}
0005434374820	40E60B	2325 029103	VASILIY BELOV	{"email": "belov_v1966@postgrespro.ru", "phone": "+70131459240"}
0005434374821	69589F	3742 196276	NINA SAVELEVA	{"email": "n_saveleva.1972@postgrespro.ru", "phone": "+70133293861"}
0005434374822	C95F28	8613 448623	ALEKSEY VOLKOV	{"phone": "+70218515346"}
0005434374823	7131E4	7973 987534	ANATOLIY FILIPPOV	{"email": "filippovanatoliy-031970@postgrespro.ru", "phone": "+70637567810"}
0005434374824	579E0E	5524 617104	NATALYA FOMINA	{"phone": "+70765156517"}
0005434374825	579E0E	8315 347829	ELENA MARTYNOVA	{"phone": "+70592492666"}
0005434374826	0D5366	0171 916124	OLGA STEPANOVA	{"phone": "+70338012067"}
0005434374827	4889C4	8060 730685	OLEG PAVLOV	{"phone": "+70237100249"}
0005434374828	8649F0	5894 052731	OLGA KAZAKOVA	{"email": "olga_kazakova_01041959@postgrespro.ru", "phone": "+70870982366"}
0005434374829	22FB31	9337 599055	ALEKSANDR MOROZOV	{"email": "amorozov051975@postgrespro.ru", "phone": "+70887380310"}
0005434374830	7DDC7E	0498 297651	OLGA KUZNECOVA	{"email": "kuznecovaolga.021982@postgrespro.ru", "phone": "+70707195635"}
0005434374831	8D9E43	5932 685580	NATALYA PAVLOVA	{"phone": "+70756774032"}
0005434374832	28144C	0272 293526	SVETLANA KUZNECOVA	{"phone": "+70005058677"}
0005434374833	28144C	0474 359924	VALENTINA IVANOVA	{"phone": "+70576693762"}
0005434374834	20CF5D	3925 966033	EKATERINA GAVRILOVA	{"email": "gavrilovae19121980@postgrespro.ru", "phone": "+70258349026"}
0005434374835	20CF5D	0193 083157	VLADIMIR IVANOV	{"phone": "+70743088723"}
0005434374836	06FECB	3474 365748	DARYA PAVLOVA	{"email": "pavlova.d.101974@postgrespro.ru", "phone": "+70053678482"}
0005434374837	06FECB	3242 517812	SERGEY SIDOROV	{"email": "s_sidorov-011975@postgrespro.ru", "phone": "+70527848735"}
0005434374838	12E4D5	0326 826264	PAVEL BORISOV	{"phone": "+70473333209"}
0005434374839	12E4D5	7059 449561	OKSANA KUZNECOVA	{"email": "o-kuznecova_22051967@postgrespro.ru", "phone": "+70603053836"}
0005434374840	DE1315	2883 202825	VALERIYA VASILEVA	{"email": "vasileva_v_24081972@postgrespro.ru", "phone": "+70583841544"}
0005434374841	1697D5	1913 181878	PETR PETROV	{"phone": "+70477650354"}
0005434374842	5BBA96	1445 723365	LYUBOV KUZNECOVA	{"phone": "+70688650309"}
0005434374843	315A84	2455 702349	RADIK KONOVALOV	{"phone": "+70190309627"}
0005434374844	315A84	8766 863807	VLADIMIR KUZMIN	{"phone": "+70649643855"}
0005434374845	7174B5	4702 554547	ARTEM NIKOLAEV	{"email": "artemnikolaev09101968@postgrespro.ru", "phone": "+70573903112"}
0005434374846	0F6AC7	4085 597297	GENNADIY FOMIN	{"email": "fomin-gennadiy.1968@postgrespro.ru", "phone": "+70711073382"}
0005434374847	0F6AC7	0258 310119	ALEKSANDR MELNIKOV	{"email": "amelnikov.20111968@postgrespro.ru", "phone": "+70903844419"}
0005434374848	B608D0	6462 441508	IGOR ALEKSEEV	{"email": "i_alekseev.1968@postgrespro.ru", "phone": "+70192078470"}
0005434374849	CB465F	6148 182469	DMITRIY KRASNOV	{"email": "krasnov_d-041979@postgrespro.ru", "phone": "+70016411979"}
0005434374850	CB465F	3953 908227	ALEKSANDR FOMIN	{"email": "fomin-a1986@postgrespro.ru", "phone": "+70261658436"}
0005434374851	B36A26	0932 749019	VIKTOR NAZAROV	{"email": "nazarov.viktor071979@postgrespro.ru", "phone": "+70135297455"}
0005434374852	B36A26	6798 471761	NIKOLAY SIDOROV	{"email": "nikolay_sidorov051977@postgrespro.ru", "phone": "+70079178880"}
0005434374853	B36A26	3663 994407	GALINA ZAKHAROVA	{"email": "galinazakharova10101971@postgrespro.ru", "phone": "+70907502909"}
0005434374854	A9D416	9413 582948	NATALYA KONDRATEVA	{"email": "kondrateva-natalya1967@postgrespro.ru", "phone": "+70908825465"}
0005434374855	FCCB8A	2812 844324	OLEG ZAYCEV	{"email": "zaycev-o26021967@postgrespro.ru", "phone": "+70472367125"}
0005434374856	9F6777	2748 685942	KONSTANTIN DMITRIEV	{"email": "dmitriev_k031981@postgrespro.ru", "phone": "+70740450799"}
0005434374857	9F6777	3618 308391	NINA FILATOVA	{"phone": "+70029339977"}
0005434374858	85C812	3439 776064	VIKTOR SEMENOV	{"email": "semenov.viktor.051967@postgrespro.ru", "phone": "+70052528436"}
0005434374859	B039E5	3329 737569	ANDREY ALEKSEEV	{"email": "a.alekseev_04011980@postgrespro.ru", "phone": "+70243808511"}
0005434374860	07CCAF	1655 263898	DARYA PETROVA	{"phone": "+70913053354"}
0005434374861	34E5A8	6514 468717	MURAD NAUMOV	{"email": "naumov-m1975@postgrespro.ru", "phone": "+70800682176"}
0005434374862	34E5A8	2182 447538	GALINA SEMENOVA	{"phone": "+70281722078"}
0005434374863	6B0D45	6315 411482	VYACHESLAV FROLOV	{"phone": "+70808568738"}
0005434374864	6B0D45	3990 574905	VYACHESLAV KUZMIN	{"phone": "+70554889985"}
0005434374865	AA01B6	3728 453700	NATALYA MIKHAYLOVA	{"phone": "+70151595446"}
0005434374866	AA01B6	0930 359344	MARIYA KOLESNIKOVA	{"email": "kolesnikovamariya_20011972@postgrespro.ru", "phone": "+70068139319"}
0005434374867	C4CD80	9268 701603	SERGEY MOROZOV	{"email": "s-morozov1976@postgrespro.ru", "phone": "+70671521808"}
0005434374868	C4CD80	5345 883892	IGOR VOLKOV	{"email": "igor_volkov-24031978@postgrespro.ru", "phone": "+70793822516"}
0005434374869	7BE5BE	6994 591861	LILIYA IVANOVA	{"email": "l_ivanova_071985@postgrespro.ru", "phone": "+70640507109"}
0005434374870	2C2D23	1684 031353	IVAN GORBUNOV	{"email": "igorbunov-1973@postgrespro.ru", "phone": "+70289490690"}
0005434374871	5FFA9C	3483 685699	ANASTASIYA SMIRNOVA	{"phone": "+70060959365"}
0005434374872	B762AE	3612 303223	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov-12101977@postgrespro.ru", "phone": "+70015418958"}
0005434374873	B762AE	9447 547688	ANDREY ZAKHAROV	{"email": "zakharov_a-041965@postgrespro.ru", "phone": "+70539592751"}
0005434374874	6A8981	4243 964435	OLGA KUZNECOVA	{"phone": "+70101676221"}
0005434374875	EE5949	9685 467426	ARTEM NAUMOV	{"phone": "+70527827868"}
0005434374876	94C470	3116 787423	VLADIMIR AFANASEV	{"phone": "+70238819860"}
0005434374877	94C470	3084 539030	LIDIYA LUKYANOVA	{"phone": "+70114106858"}
0005434374878	4F654F	1706 801745	MIKHAIL TARASOV	{"phone": "+70839822995"}
0005434374879	4F654F	7842 148066	MIKHAIL POPOV	{"phone": "+70836805255"}
0005434374880	F03CC7	9074 200756	MIKHAIL SOKOLOV	{"email": "sokolov-mikhail_1967@postgrespro.ru", "phone": "+70895737812"}
0005434374881	B5EED5	8675 483572	NATALYA MOROZOVA	{"phone": "+70863125541"}
0005434374882	7DD7EB	6556 654986	LYUDMILA DMITRIEVA	{"email": "lyudmila_dmitrieva11091968@postgrespro.ru", "phone": "+70908508795"}
0005434374883	04C3B9	3886 570326	DENIS NAZAROV	{"email": "denis-nazarov_1974@postgrespro.ru", "phone": "+70158903896"}
0005434374884	04C3B9	3108 365747	LYUBOV ANDREEVA	{"phone": "+70485153684"}
0005434374885	A42E03	5022 755587	VLADIMIR NIKITIN	{"email": "nikitinvladimir19121971@postgrespro.ru", "phone": "+70369353158"}
0005434374886	A42E03	3015 143774	BORIS SAVELEV	{"phone": "+70978067493"}
0005434374887	167F06	2152 965650	DENIS DENISOV	{"email": "denisov_d.1972@postgrespro.ru", "phone": "+70351782306"}
0005434374888	6B44AB	5572 071267	ARTUR BELOV	{"email": "a-belov-22031981@postgrespro.ru", "phone": "+70877200257"}
0005434374889	9247A4	6572 463678	MIKHAIL CHERNOV	{"email": "chernov-m1975@postgrespro.ru", "phone": "+70248066666"}
0005434374890	6D3E94	4790 882728	VLADIMIR SEMENOV	{"phone": "+70326808038"}
0005434375057	00EAD0	8071 996446	DANIIL BARANOV	{"phone": "+70043284516"}
0005434374891	33D1C2	9989 376371	RUSHANIYA VOLKOVA	{"email": "rushaniya.volkova-20041977@postgrespro.ru", "phone": "+70564675377"}
0005434374892	94E7B7	5301 840952	VLADIMIR VASILEV	{"phone": "+70976516357"}
0005434374893	94E7B7	2958 011847	NATALYA YUDINA	{"phone": "+70889389895"}
0005434374894	DDE98C	6881 664199	OLEG NOVIKOV	{"phone": "+70570601973"}
0005434374895	D4088E	1810 404853	OLGA FOMINA	{"email": "fomina-olga-081980@postgrespro.ru", "phone": "+70953964410"}
0005434374896	C16CC1	8438 964040	MARINA ANDREEVA	{"email": "marina.andreeva_1966@postgrespro.ru", "phone": "+70017508173"}
0005434374897	D2936A	3736 091945	FANIL IVANOV	{"phone": "+70919535454"}
0005434374898	2CF608	5287 763599	VIKTOR ZAKHAROV	{"email": "zakharov_viktor.16121964@postgrespro.ru", "phone": "+70329058057"}
0005434374899	1A0937	7342 055348	ANTONINA NOVIKOVA	{"email": "antonina.novikova.13041974@postgrespro.ru", "phone": "+70489265294"}
0005434374900	1A0937	5631 862534	KRISTINA SERGEEVA	{"phone": "+70334644420"}
0005434374901	370410	8397 026116	NATALYA GERASIMOVA	{"phone": "+70748802487"}
0005434374902	A17610	5322 841822	RAISA MELNIKOVA	{"email": "melnikova-r-111970@postgrespro.ru", "phone": "+70959089758"}
0005434374903	C45AAB	6654 847601	NADEZHDA POPOVA	{"email": "popovanadezhda.1976@postgrespro.ru", "phone": "+70967459164"}
0005434374904	C45AAB	8907 864099	PETR MAKSIMOV	{"phone": "+70781494217"}
0005434374905	C45AAB	5753 875674	ALEKSEY NIKITIN	{"phone": "+70126086545"}
0005434374906	94F084	7566 935917	VALERIY SIDOROV	{"phone": "+70163538108"}
0005434374907	029B79	1059 024749	SOFIYA KOVALEVA	{"email": "sofiya-kovaleva-13011953@postgrespro.ru", "phone": "+70933491622"}
0005434374908	029B79	6587 335669	VARVARA LAZAREVA	{"email": "lazareva-v_1973@postgrespro.ru", "phone": "+70374810597"}
0005434374909	029B79	2480 908593	ANDREY POPOV	{"phone": "+70805134422"}
0005434374910	0C9822	9290 919835	LYUDMILA ALEKSEEVA	{"email": "alekseevalyudmila.071960@postgrespro.ru", "phone": "+70820383744"}
0005434374911	FE30C6	7174 616399	ANDREY SHEVCHENKO	{"email": "andreyshevchenko1982@postgrespro.ru", "phone": "+70712440510"}
0005434374912	FE30C6	8132 818888	SERGEY VOROBEV	{"email": "s_vorobev-11021977@postgrespro.ru", "phone": "+70031393555"}
0005434374913	532E84	9765 851453	SVETLANA SMIRNOVA	{"phone": "+70987530551"}
0005434374914	BD2F45	6365 964050	OLGA ANTONOVA	{"email": "antonovao_05121973@postgrespro.ru", "phone": "+70057810307"}
0005434374915	ABDB7B	8451 613365	IVAN PAVLOV	{"email": "i-pavlov.121982@postgrespro.ru", "phone": "+70248909229"}
0005434374916	ABDB7B	9452 982460	KIRILL ISAEV	{"email": "isaev_kirill1964@postgrespro.ru", "phone": "+70341946881"}
0005434374917	495560	2000 133225	LYUDMILA MATVEEVA	{"email": "lyudmila-matveeva-1969@postgrespro.ru", "phone": "+70288054243"}
0005434374918	A66637	5386 713766	IGOR TIKHONOV	{"phone": "+70766652007"}
0005434374919	14FB73	5158 513609	SERGEY FROLOV	{"email": "frolovsergey_1969@postgrespro.ru", "phone": "+70048267058"}
0005434374920	8C1D07	1762 554407	DMITRIY IVANOV	{"phone": "+70951035275"}
0005434374921	8C1D07	3262 238076	ELVIRA NIKIFOROVA	{"phone": "+70737563878"}
0005434374922	477285	5958 020965	NINA KOZLOVA	{"email": "nina-kozlova.1958@postgrespro.ru", "phone": "+70823023517"}
0005434374923	BF8AA9	0171 881574	VERA ROMANOVA	{"email": "romanova-vera.02111980@postgrespro.ru", "phone": "+70798161919"}
0005434374924	02D051	5258 448766	ALEKSANDR SOROKIN	{"email": "aleksandrsorokin.20071975@postgrespro.ru", "phone": "+70125260918"}
0005434374925	A7D0F5	1518 090516	SERGEY ORLOV	{"email": "orlov.s-011958@postgrespro.ru", "phone": "+70477054035"}
0005434374926	D07247	2627 595032	VALENTINA NIKOLAEVA	{"email": "nikolaeva.v_21091970@postgrespro.ru", "phone": "+70532879691"}
0005434374927	A3DBC3	1291 558824	ALEKSANDRA GORBUNOVA	{"phone": "+70407387637"}
0005434374928	A3DBC3	6569 869063	GLEB IVANOV	{"phone": "+70853020282"}
0005434374929	A3DBC3	8438 676182	VALENTINA TROFIMOVA	{"phone": "+70805950228"}
0005434374930	3C36C2	3467 183640	ILYA KOZLOV	{"email": "ilyakozlov.14041981@postgrespro.ru", "phone": "+70353206989"}
0005434374931	1B7A61	2635 094320	ILYA ZAYCEV	{"email": "zaycev.ilya-1969@postgrespro.ru", "phone": "+70095498398"}
0005434374932	910308	3131 525844	TATYANA IVANOVA	{"email": "t-ivanova-041972@postgrespro.ru", "phone": "+70173464764"}
0005434374933	061A7A	8124 217374	TATYANA ALEKSANDROVA	{"phone": "+70950816976"}
0005434374934	061A7A	9098 515547	EVGENIYA ZOTOVA	{"email": "evgeniya.zotova-23081972@postgrespro.ru", "phone": "+70125656816"}
0005434374935	8A85E8	3116 973072	ELENA RODIONOVA	{"email": "rodionova.elena-1962@postgrespro.ru", "phone": "+70542280433"}
0005434374936	608376	3041 238999	MARIYA MOROZOVA	{"phone": "+70327139747"}
0005434374937	09B506	6720 328472	VLADIMIR KAZAKOV	{"phone": "+70142006577"}
0005434374938	09B506	1912 921746	ANDREY PAVLOV	{"phone": "+70778690221"}
0005434374939	BB48F5	7101 877470	YURIY MELNIKOV	{"email": "melnikovyuriy_061974@postgrespro.ru", "phone": "+70647833520"}
0005434374940	FD571F	0294 002850	VALENTINA SEMENOVA	{"email": "semenova_valentina111974@postgrespro.ru", "phone": "+70150882453"}
0005434374941	FD571F	0285 025324	VLADIMIR GAVRILOV	{"email": "gavrilov.vladimir.1963@postgrespro.ru", "phone": "+70314532520"}
0005434374942	FD571F	5222 793511	MAKSIM DENISOV	{"email": "denisov_m1972@postgrespro.ru", "phone": "+70765056048"}
0005434374943	F17498	8369 692674	OLGA VOROBEVA	{"phone": "+70661500961"}
0005434374944	F17498	1497 102139	VERA ILINA	{"email": "vera_ilina_1982@postgrespro.ru", "phone": "+70133786489"}
0005434374945	7148A6	5716 359250	FAINA IVANOVA	{"phone": "+70940257118"}
0005434375115	19F361	9224 536775	SERGEY KUZNECOV	{"phone": "+70175977154"}
0005434374946	70DA4D	3753 638660	GRIGORIY VOROBEV	{"email": "grigoriy_vorobev-1984@postgrespro.ru", "phone": "+70265346452"}
0005434374947	70DA4D	2251 590308	IRINA VLASOVA	{"email": "vlasova-i-1967@postgrespro.ru", "phone": "+70386535097"}
0005434374948	70DA4D	8313 631464	SVETLANA LAZAREVA	{"email": "s-lazareva27091973@postgrespro.ru", "phone": "+70940860254"}
0005434374949	E219A5	9686 812752	NIKITA NOVIKOV	{"email": "nnovikov1972@postgrespro.ru", "phone": "+70584325486"}
0005434374950	E219A5	1809 099757	OLGA ZHUKOVA	{"email": "zhukova_o-081967@postgrespro.ru", "phone": "+70931307122"}
0005434374951	EA3B50	4407 399460	MIKHAIL MELNIKOV	{"phone": "+70394243577"}
0005434374952	F9B811	2752 462020	POLINA PETROVA	{"phone": "+70331024900"}
0005434374953	16B663	1504 807383	VALENTINA ANTONOVA	{"email": "antonova.valentina.27061966@postgrespro.ru", "phone": "+70151087162"}
0005434374954	0AFB5E	6412 460335	EKATERINA ANTONOVA	{"email": "antonova-e.15031966@postgrespro.ru", "phone": "+70548927937"}
0005434374955	0AFB5E	7555 039670	MARIYA KUZNECOVA	{"email": "kuznecova.m.1971@postgrespro.ru", "phone": "+70117365278"}
0005434374956	0AFB5E	2856 850716	DMITRIY DMITRIEV	{"email": "dmitriy-dmitriev_031987@postgrespro.ru", "phone": "+70201672125"}
0005434374957	9F56AA	6194 794397	IRINA MAKAROVA	{"email": "irina_makarova_051973@postgrespro.ru", "phone": "+70037673809"}
0005434374958	E46D3B	2470 174601	LYUBOV EFIMOVA	{"email": "efimovalyubov-1970@postgrespro.ru", "phone": "+70885681262"}
0005434374959	DDDA2A	3005 696966	ANASTASIYA BELOVA	{"email": "anastasiya_belova_011970@postgrespro.ru", "phone": "+70074404504"}
0005434374960	DDDA2A	8888 719845	ELENA BARANOVA	{"phone": "+70707647102"}
0005434374961	33A110	8257 581509	OLGA KUZMINA	{"email": "kuzmina.o01071963@postgrespro.ru", "phone": "+70751075354"}
0005434374962	33A110	6163 544670	ALEKSANDR POPOV	{"email": "popov-aleksandr26021969@postgrespro.ru", "phone": "+70771615770"}
0005434374963	098FF9	7793 392700	SERGEY SMIRNOV	{"phone": "+70566335495"}
0005434374964	098FF9	8157 811559	MIKHAIL TIMOFEEV	{"email": "m-timofeev_22041977@postgrespro.ru", "phone": "+70643685817"}
0005434374965	2029A9	9382 147545	ANASTASIYA GRISHINA	{"phone": "+70750289274"}
0005434374966	2029A9	3772 324489	GALINA POPOVA	{"email": "g.popova-071968@postgrespro.ru", "phone": "+70283176384"}
0005434374967	8D002A	2535 386082	VLADIMIR MAKAROV	{"phone": "+70229348614"}
0005434374968	CE5BF0	8375 837494	EVGENIY GERASIMOV	{"phone": "+70916693293"}
0005434374969	BFE17E	5431 743315	IVAN POPOV	{"email": "popov_i.1969@postgrespro.ru", "phone": "+70699233278"}
0005434374970	BFE17E	8039 627770	SVETLANA ISAEVA	{"phone": "+70425402331"}
0005434374971	85D235	7431 472085	NADEZHDA NOVIKOVA	{"phone": "+70517139665"}
0005434374972	4BC2A1	3900 469872	EVGENIYA PETROVA	{"phone": "+70390717049"}
0005434374973	C0CE37	2456 185616	TAISIYA NOVIKOVA	{"phone": "+70728900023"}
0005434374974	684AC8	4659 645421	OLEG IVANOV	{"email": "ivanov.o16031981@postgrespro.ru", "phone": "+70500745037"}
0005434374975	9723B5	2237 236081	VLADIMIR FEDOTOV	{"email": "fedotov.vladimir121974@postgrespro.ru", "phone": "+70046013082"}
0005434374976	590B91	2040 090234	ALEKSEY ZHURAVLEV	{"email": "azhuravlev.1982@postgrespro.ru", "phone": "+70622440688"}
0005434374977	48126A	5447 892527	NIKITA KRASNOV	{"phone": "+70204325286"}
0005434374978	48126A	1458 289092	IRINA TIKHONOVA	{"email": "i_tikhonova.1976@postgrespro.ru", "phone": "+70152856671"}
0005434374979	C2DC63	7990 678377	NIKOLAY MIRONOV	{"phone": "+70138683776"}
0005434374980	A355A1	8832 036421	NIKOLAY MIKHAYLOV	{"phone": "+70127871029"}
0005434374981	3C45D4	7320 897127	NATALYA SMIRNOVA	{"phone": "+70330413171"}
0005434374982	3C45D4	1284 719688	DMITRIY SCHERBAKOV	{"email": "dmitriy_scherbakov.1985@postgrespro.ru", "phone": "+70533930242"}
0005434374983	8B57F5	2099 516429	VITALIY ANTONOV	{"phone": "+70756856089"}
0005434374984	F1B060	7476 449917	GALINA POLYAKOVA	{"email": "polyakova.galina-1975@postgrespro.ru", "phone": "+70394914468"}
0005434374985	F1B060	4760 996347	MARINA KUZMINA	{"email": "m_kuzmina061971@postgrespro.ru", "phone": "+70317559440"}
0005434374986	4E7169	8243 337187	ANTONINA EFIMOVA	{"phone": "+70578022481"}
0005434374987	561230	3149 755328	MARIYA ZAKHAROVA	{"email": "zakharova_m.061964@postgrespro.ru", "phone": "+70753374768"}
0005434374988	5A1475	9256 389197	NATALYA BORISOVA	{"phone": "+70312056995"}
0005434374989	9FD3ED	4665 930520	IRINA SAVELEVA	{"email": "saveleva-i.26061971@postgrespro.ru", "phone": "+70489139822"}
0005434374990	D948A3	4043 164048	IRINA OSIPOVA	{"email": "osipovairina_08021972@postgrespro.ru", "phone": "+70907459511"}
0005434374991	D948A3	3451 887098	GALINA KRASNOVA	{"email": "galinakrasnova_04021966@postgrespro.ru", "phone": "+70421016276"}
0005434374992	442427	4509 732235	ANTONINA VLASOVA	{"email": "vlasovaa_23121972@postgrespro.ru", "phone": "+70216216919"}
0005434374993	33E4AB	1730 714387	ALEKSANDR GORBUNOV	{"phone": "+70682954615"}
0005434374994	14DDD9	9819 086480	VLADISLAV NIKITIN	{"phone": "+70619194325"}
0005434374995	7493E4	4888 245812	ALEKSEY TIMOFEEV	{"email": "timofeev_aleksey_1957@postgrespro.ru", "phone": "+70486449258"}
0005434374996	9CF1BF	8634 956638	VALENTINA GORBUNOVA	{"phone": "+70141232951"}
0005434374997	9E839D	9620 116552	NADEZHDA STEPANOVA	{"email": "stepanovanadezhda_1971@postgrespro.ru", "phone": "+70357167663"}
0005434374998	3C1808	6761 339503	SERGEY IVANOV	{"email": "ivanov-s.011971@postgrespro.ru", "phone": "+70323983032"}
0005434374999	44B8A5	2770 034183	NIKOLAY KOROLEV	{"phone": "+70596443475"}
0005434375000	F724E4	4442 015592	VALENTINA FEDOROVA	{"email": "vfedorova-1974@postgrespro.ru", "phone": "+70053421023"}
0005434375001	AEBF7D	6614 076072	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov-18121974@postgrespro.ru", "phone": "+70199591294"}
0005434375002	AEBF7D	8033 730735	ELENA POTAPOVA	{"phone": "+70727408628"}
0005434375003	7563ED	1263 537694	LYUBOV KOLESNIKOVA	{"phone": "+70875561883"}
0005434375004	55E417	4372 837330	ROZA FILIPPOVA	{"phone": "+70019771082"}
0005434375005	604CDA	6450 670080	LARISA POPOVA	{"email": "larisa_popova_02121973@postgrespro.ru", "phone": "+70930314138"}
0005434375006	604CDA	9874 919400	KSENIYA KUZNECOVA	{"phone": "+70464853685"}
0005434375007	AFFFD0	6952 817762	TATYANA ANTONOVA	{"email": "tatyana-antonova021961@postgrespro.ru", "phone": "+70621017704"}
0005434375008	275959	3329 770797	TATYANA KOLESNIKOVA	{"phone": "+70665295089"}
0005434375009	546459	5077 029947	DARYA TIMOFEEVA	{"email": "timofeeva-d.101978@postgrespro.ru", "phone": "+70692188121"}
0005434375010	C2B3AE	9706 862404	NIKOLAY IVANOV	{"phone": "+70697484860"}
0005434375011	C2B3AE	7163 571562	VIKTORIYA DMITRIEVA	{"email": "viktoriya.dmitrieva-1981@postgrespro.ru", "phone": "+70424034000"}
0005434375012	CF6AD9	0365 232930	VADIM SCHERBAKOV	{"phone": "+70378755697"}
0005434375013	14563C	6067 474336	VALENTINA MAKAROVA	{"phone": "+70901491374"}
0005434375014	14563C	4347 417892	IRINA MIKHAYLOVA	{"email": "mikhaylova.irina-1962@postgrespro.ru", "phone": "+70151261864"}
0005434375015	1CBCA6	2479 680860	ANATOLIY PAVLOV	{"email": "a.pavlov.18061974@postgrespro.ru", "phone": "+70199234925"}
0005434375016	A8A6F6	0945 688474	MIKHAIL IVANOV	{"email": "ivanovm.011971@postgrespro.ru", "phone": "+70255947165"}
0005434375017	A8A6F6	7288 915707	OLGA YUDINA	{"email": "yudinaolga-03081964@postgrespro.ru", "phone": "+70241005348"}
0005434375018	3E6FF6	9242 842962	OKSANA ZHURAVLEVA	{"email": "zhuravleva_o.1974@postgrespro.ru", "phone": "+70833342556"}
0005434375019	FD7B15	5859 328547	YURIY CHERNOV	{"email": "y.chernov.121974@postgrespro.ru", "phone": "+70597270935"}
0005434375020	DC7E20	6542 153610	IVAN KULIKOV	{"phone": "+70222413134"}
0005434375021	DC7E20	5406 096291	VIKTOR POPOV	{"email": "popov.v-1974@postgrespro.ru", "phone": "+70546690318"}
0005434375022	7B2006	0534 808292	IRINA PETROVA	{"email": "petrovai1979@postgrespro.ru", "phone": "+70723005635"}
0005434375023	BCD969	2132 130536	GULNAZ GAVRILOVA	{"phone": "+70886774695"}
0005434375024	BCD969	4036 978387	NATALYA ANISIMOVA	{"phone": "+70924917273"}
0005434375025	90D9F4	7875 253454	KONSTANTIN MAKAROV	{"email": "k_makarov.121960@postgrespro.ru", "phone": "+70414368837"}
0005434375026	9B14FB	1676 276131	YURIY DMITRIEV	{"email": "dmitriev_y_081965@postgrespro.ru", "phone": "+70174931041"}
0005434375027	29C3FF	4923 424590	OLEG SCHERBAKOV	{"phone": "+70637622090"}
0005434375028	0163EB	1915 427501	SNEZHANA TITOVA	{"email": "titova.snezhana.1987@postgrespro.ru", "phone": "+70934260418"}
0005434375029	FCDAF9	2286 084349	EGOR MIKHAYLOV	{"phone": "+70321779702"}
0005434375030	8AABBC	1190 405994	NIKOLAY PAVLOV	{"phone": "+70935737574"}
0005434375031	8AABBC	6134 872711	MARINA ANDREEVA	{"email": "andreeva.marina-1970@postgrespro.ru", "phone": "+70617967710"}
0005434375032	A1877D	9017 156372	ZHANNA SOLOVEVA	{"phone": "+70336429931"}
0005434375033	9EA4D2	7422 096948	GEORGIY ANTONOV	{"email": "georgiy_antonov_071983@postgrespro.ru", "phone": "+70321012010"}
0005434375034	9EA4D2	1921 793663	ELENA SOKOLOVA	{"phone": "+70552721810"}
0005434375035	9EA4D2	5651 542548	OLEG GORBUNOV	{"email": "gorbunov.o1977@postgrespro.ru", "phone": "+70558084518"}
0005434375036	ACA0D9	7899 991045	SERGEY MIKHAYLOV	{"phone": "+70191366981"}
0005434375037	7C7385	9791 532577	LYUDMILA KAZAKOVA	{"email": "lkazakova.061968@postgrespro.ru", "phone": "+70993626244"}
0005434375038	BDF98C	0789 269247	VYACHESLAV KISELEV	{"phone": "+70679395219"}
0005434375039	F4A821	8345 666295	IRINA MEDVEDEVA	{"email": "medvedeva_irina.111970@postgrespro.ru", "phone": "+70251167394"}
0005434375040	F4A821	8485 897596	ANASTASIYA ALEKSEEVA	{"phone": "+70214678879"}
0005434375041	EDEE9D	0382 177905	SERGEY KAZAKOV	{"phone": "+70899684511"}
0005434375042	EDEE9D	6533 135266	DENIS KISELEV	{"phone": "+70539011254"}
0005434375043	EDEE9D	5312 592869	TATYANA FEDOROVA	{"phone": "+70827890665"}
0005434375044	B14342	2131 806834	RITA AFANASEVA	{"email": "r_afanaseva.16031966@postgrespro.ru", "phone": "+70540263701"}
0005434375045	B14342	4616 435182	NATALIYA POPOVA	{"email": "npopova.06121980@postgrespro.ru", "phone": "+70849473652"}
0005434375046	B14342	3765 513391	EVGENIY TIKHONOV	{"phone": "+70300804251"}
0005434375047	39A7C6	4367 261349	VIKTOR SHEVCHENKO	{"phone": "+70247198620"}
0005434375048	BB46B5	2704 418540	SERGEY ALEKSEEV	{"phone": "+70623906103"}
0005434375049	BB46B5	9267 066922	MARIYA KAZAKOVA	{"email": "kazakovamariya1973@postgrespro.ru", "phone": "+70179538503"}
0005434375050	A50B2F	9585 813834	IRINA KOVALEVA	{"phone": "+70274920688"}
0005434375051	B4A89A	3365 198700	ARTEM AFANASEV	{"email": "artem_afanasev.22061984@postgrespro.ru", "phone": "+70094672489"}
0005434375052	58F783	4637 580412	TATYANA MARTYNOVA	{"email": "martynova.t_01021982@postgrespro.ru", "phone": "+70080805582"}
0005434375053	75AFD7	4623 336841	LYUBOV KOROLEVA	{"email": "lkoroleva-051955@postgrespro.ru", "phone": "+70702109841"}
0005434375054	7D6BB1	7715 357926	NINA TIKHONOVA	{"email": "tikhonova.nina_051970@postgrespro.ru", "phone": "+70128578915"}
0005434375055	7D6BB1	5101 948440	OLGA GERASIMOVA	{"phone": "+70485636667"}
0005434375056	00EAD0	1597 638448	EKATERINA ROMANOVA	{"phone": "+70229335346"}
0005434375058	4102D9	7152 322441	VITALIY PAVLOV	{"email": "vitaliypavlov-041967@postgrespro.ru", "phone": "+70891315978"}
0005434375059	12DC56	8119 431574	ALEKSEY MOROZOV	{"phone": "+70344632044"}
0005434375060	9AB907	1372 606875	DMITRIY POPOV	{"phone": "+70805459397"}
0005434375061	DD4730	9616 829473	SEMEN MAKSIMOV	{"phone": "+70183564966"}
0005434375062	DBBEA2	2751 392802	DMITRIY PAVLOV	{"email": "dmitriy.pavlov_101968@postgrespro.ru", "phone": "+70589746367"}
0005434375063	6A2EC2	0195 882109	ALEKSEY MOROZOV	{"phone": "+70119572680"}
0005434375064	0B5A76	6927 820927	ALEKSANDR SCHERBAKOV	{"phone": "+70008360284"}
0005434375065	0B5A76	1697 476149	EDUARD PETROV	{"phone": "+70347186067"}
0005434375066	88A1DB	1568 932299	ALEKSANDR GUSEV	{"phone": "+70919774752"}
0005434375067	4DC778	1019 329000	RUSLAN ABRAMOV	{"email": "abramov.ruslan1976@postgrespro.ru", "phone": "+70631229724"}
0005434375068	4AD07F	3030 016579	LEONID MEDVEDEV	{"email": "medvedevl_1960@postgrespro.ru", "phone": "+70053503453"}
0005434375069	4AD07F	1923 537939	ALENA MALYSHEVA	{"phone": "+70437877248"}
0005434375070	989CAD	0303 536749	VARVARA IVANOVA	{"email": "ivanova.v1971@postgrespro.ru", "phone": "+70182046195"}
0005434375071	989CAD	4491 649500	VLADIMIR NAUMOV	{"phone": "+70868449103"}
0005434375072	EE1F86	4863 034530	MAKSIM YAKOVLEV	{"phone": "+70064462395"}
0005434375073	58160C	0907 145034	RAISA POTAPOVA	{"email": "raisapotapova-091972@postgrespro.ru", "phone": "+70012840147"}
0005434375074	E80DE1	0747 731413	IVAN NAUMOV	{"phone": "+70288566461"}
0005434375075	E80DE1	5478 516570	ELIZAVETA BELOVA	{"email": "e_belova-1965@postgrespro.ru", "phone": "+70232859909"}
0005434375076	492732	7645 922102	IRINA FEDOROVA	{"phone": "+70980373884"}
0005434375077	88D99F	3027 698255	OLGA KUZNECOVA	{"email": "olga-kuznecova121970@postgrespro.ru", "phone": "+70669608582"}
0005434375078	88D99F	8902 793314	MARGARITA NOVIKOVA	{"email": "margarita_novikova_1969@postgrespro.ru", "phone": "+70563661753"}
0005434375079	E20B03	8757 150861	SERGEY POPOV	{"email": "sergey_popov-1964@postgrespro.ru", "phone": "+70845078524"}
0005434375080	E20B03	4851 794157	SVETLANA KUZNECOVA	{"email": "kuznecova-s.1976@postgrespro.ru", "phone": "+70017243503"}
0005434375081	AABD6B	6363 391755	IRINA NOVIKOVA	{"phone": "+70408617396"}
0005434375082	47F21E	3398 246947	OKSANA FEDOROVA	{"email": "o_fedorova1971@postgrespro.ru", "phone": "+70284561432"}
0005434375083	E55339	9537 714496	ZINAIDA ORLOVA	{"phone": "+70084202717"}
0005434375084	25C038	7167 190347	NATALYA KAZAKOVA	{"email": "kazakova_n_1980@postgrespro.ru", "phone": "+70973971234"}
0005434375085	25C038	7529 296042	OLGA SOKOLOVA	{"phone": "+70955840057"}
0005434375086	7E6EE8	6345 869352	TATYANA NIKOLAEVA	{"email": "nikolaevat_08071980@postgrespro.ru", "phone": "+70452124026"}
0005434375087	75D5E5	9877 718908	YULIYA KALININA	{"email": "kalinina_y23041978@postgrespro.ru", "phone": "+70139900893"}
0005434375088	037786	0877 040116	DMITRIY AFANASEV	{"phone": "+70842540152"}
0005434375089	467F1D	8563 014197	DMITRIY GUSEV	{"phone": "+70702435270"}
0005434375090	467F1D	3373 158338	SERGEY MAKAROV	{"email": "makarov-s031975@postgrespro.ru", "phone": "+70361584696"}
0005434375091	34A370	1879 202721	RUSLAN ROMANOV	{"phone": "+70920664138"}
0005434375092	E8684E	8206 800302	MATVEY KUZNECOV	{"email": "kuznecov-matvey_1969@postgrespro.ru", "phone": "+70936835137"}
0005434375093	BCF4B1	6877 692086	EVGENIYA CHERNOVA	{"email": "e-chernova23121975@postgrespro.ru", "phone": "+70116910910"}
0005434375094	D82798	0389 105069	OLGA SOLOVEVA	{"phone": "+70056433693"}
0005434375095	722FC4	2147 045683	VERA OSIPOVA	{"phone": "+70830200073"}
0005434375096	726037	7345 333400	YURIY VASILEV	{"phone": "+70512278725"}
0005434375097	712705	5116 893396	IRINA ABRAMOVA	{"phone": "+70582986980"}
0005434375098	001547	3686 766013	SERGEY ROMANOV	{"phone": "+70600329822"}
0005434375099	001547	8786 820819	NATALYA NIKOLAEVA	{"phone": "+70409929380"}
0005434375100	326B81	8246 141679	NAIL MARTYNOV	{"email": "martynov.n_03121962@postgrespro.ru", "phone": "+70777281588"}
0005434375101	C85172	8468 826629	VASILIY SCHERBAKOV	{"email": "vasiliy_scherbakov-18101974@postgrespro.ru", "phone": "+70006312197"}
0005434375102	D85894	9469 582399	IVAN PAVLOV	{"email": "pavlov.i.111976@postgrespro.ru", "phone": "+70292354125"}
0005434375103	DF394C	5315 067401	OKSANA BORISOVA	{"phone": "+70030898641"}
0005434375104	5ACCD1	8552 809645	ALEKSANDR POPOV	{"phone": "+70221524081"}
0005434375105	57BF26	8135 021974	PAVEL OSIPOV	{"phone": "+70779902369"}
0005434375106	1A5239	8367 580042	ELENA LOGINOVA	{"phone": "+70468365320"}
0005434375107	5E20F9	7914 591808	ANTON SAVELEV	{"email": "savelev-a_07021979@postgrespro.ru", "phone": "+70304490794"}
0005434375108	867241	5825 547252	MIKHAIL NIKOLAEV	{"email": "m_nikolaev.1967@postgrespro.ru", "phone": "+70962734722"}
0005434375109	867241	8866 775195	SERGEY DENISOV	{"phone": "+70981873494"}
0005434375110	BF141A	6423 142185	ANASTASIYA KUZNECOVA	{"phone": "+70639381770"}
0005434375111	3E662E	2901 022603	ALEKSANDR BORISOV	{"phone": "+70837526981"}
0005434375112	DABFBA	2080 259711	ALEKSEY MARTYNOV	{"phone": "+70377029114"}
0005434375113	DABFBA	3605 404115	MAKSIM YAKOVLEV	{"email": "maksimyakovlev1967@postgrespro.ru", "phone": "+70769867853"}
0005434375114	82AEC6	3713 116219	ROMAN VOROBEV	{"email": "vorobev_r.051979@postgrespro.ru", "phone": "+70181119753"}
0005434375116	79B869	3699 107809	ANDREY FOMIN	{"phone": "+70870723898"}
0005434375117	1DD243	4711 607609	LIDIYA VASILEVA	{"email": "lidiyavasileva.031965@postgrespro.ru", "phone": "+70858471363"}
0005434375118	1DD243	6456 442615	MAKSIM BARANOV	{"email": "m-baranov-20021976@postgrespro.ru", "phone": "+70250036059"}
0005434375119	E2AD5B	8068 314015	OLEG SAVELEV	{"phone": "+70458037124"}
0005434375120	CDA096	5969 740829	ALEKSEY KRASNOV	{"email": "aleksey-krasnov.1966@postgrespro.ru", "phone": "+70777807898"}
0005434375121	4C9556	3611 155893	TATYANA KONDRATEVA	{"email": "kondratevatatyana-061981@postgrespro.ru", "phone": "+70544496611"}
0005434375122	B71FCB	0225 832938	VYACHESLAV VOROBEV	{"email": "vyacheslavvorobev-28111973@postgrespro.ru", "phone": "+70230771417"}
0005434375123	DE72A2	7254 281279	VIKTOR GUSEV	{"email": "gusev.viktor09101961@postgrespro.ru", "phone": "+70920599911"}
0005434375124	DE72A2	9231 008591	ALEKSEY VASILEV	{"phone": "+70989209774"}
0005434375125	138B8A	7281 022088	LYUDMILA MAKSIMOVA	{"email": "l.maksimova.1975@postgrespro.ru", "phone": "+70128155685"}
0005434375126	6E4BFB	8656 718505	TAMARA NESTEROVA	{"phone": "+70870183134"}
0005434375127	0EC9E2	3406 957858	ALEKSANDR FEDOROV	{"email": "aleksandr.fedorov.071967@postgrespro.ru", "phone": "+70937560365"}
0005434375128	191CA4	5147 480886	EKATERINA MIKHAYLOVA	{"email": "e-mikhaylova091973@postgrespro.ru", "phone": "+70466839567"}
0005434375129	4A9C62	9541 623267	ALEKSEY SAVELEV	{"email": "savelev.a_051972@postgrespro.ru", "phone": "+70286258006"}
0005434375130	4A9C62	7687 510488	NATALYA FADEEVA	{"email": "fadeeva_n_1979@postgrespro.ru", "phone": "+70992584026"}
0005434375131	86CE72	8474 028509	ANATOLIY AFANASEV	{"phone": "+70076756079"}
0005434375132	7AD088	1554 662467	ELENA CHERNOVA	{"email": "elena.chernova-081966@postgrespro.ru", "phone": "+70305219719"}
0005434375133	7AD088	5136 407314	EVGENIY IVANOV	{"email": "e_ivanov_1977@postgrespro.ru", "phone": "+70532629071"}
0005434375134	DD3C3F	4504 305418	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr_011975@postgrespro.ru", "phone": "+70142061422"}
0005434375135	DD3C3F	4629 377747	DMITRIY GERASIMOV	{"phone": "+70861390326"}
0005434375136	BB9E55	7093 114339	NINA ROMANOVA	{"phone": "+70530807255"}
0005434375137	399477	1153 579505	TAISIYA CHERNOVA	{"phone": "+70058566044"}
0005434375138	0F3375	0220 523994	EVGENIY PETROV	{"email": "e.petrov_02011981@postgrespro.ru", "phone": "+70064161378"}
0005434375139	9F944D	5133 335888	LIDIYA RODIONOVA	{"phone": "+70159498209"}
0005434375140	823AEC	4205 126129	STANISLAV MAKAROV	{"email": "stanislav_makarov-07011964@postgrespro.ru", "phone": "+70249568737"}
0005434375141	525F35	6036 401749	NADEZHDA ILINA	{"phone": "+70456966244"}
0005434375142	525F35	5392 387390	EKATERINA ORLOVA	{"email": "orlovae.041979@postgrespro.ru", "phone": "+70433599227"}
0005434375143	DA3701	2908 861762	NATALYA ZAKHAROVA	{"phone": "+70409250720"}
0005434375144	DA3701	9818 029204	ANTONINA MIRONOVA	{"phone": "+70735533402"}
0005434375145	DA3701	9869 577648	NATALYA MOROZOVA	{"phone": "+70047238274"}
0005434375146	7D8595	6990 592947	SVETLANA KUZMINA	{"email": "s_kuzmina_121966@postgrespro.ru", "phone": "+70120740875"}
0005434375147	F0B965	6099 480346	SERGEY SERGEEV	{"phone": "+70755717693"}
0005434375148	BF97BB	7295 101887	MARIYA SOKOLOVA	{"email": "m-sokolova-12011971@postgrespro.ru", "phone": "+70023200757"}
0005434375149	BF97BB	3124 476577	ANTONINA BORISOVA	{"email": "antonina-borisova_24051957@postgrespro.ru", "phone": "+70997855222"}
0005434375150	37EC7B	3633 787026	NATALYA ILINA	{"email": "ilina_natalya_031979@postgrespro.ru", "phone": "+70467593471"}
0005434375151	F360E0	7171 804666	ALEKSANDR KUZNECOV	{"phone": "+70499323499"}
0005434375152	DE2929	8420 780651	VALENTINA KAZAKOVA	{"phone": "+70634390680"}
0005434375153	70F690	8726 225251	IRINA KALININA	{"email": "kalininairina-121985@postgrespro.ru", "phone": "+70783188541"}
0005434375154	70F690	9136 420745	VSEVOLOD NIKITIN	{"phone": "+70190836343"}
0005434375155	5BC368	0851 505762	ELIZAVETA ZAKHAROVA	{"email": "elizaveta_zakharova-031960@postgrespro.ru", "phone": "+70504588339"}
0005434375156	5BC368	7870 239541	VYACHESLAV SEMENOV	{"phone": "+70630891909"}
0005434375157	BE8B56	6492 603971	ALEKSEY CHERNOV	{"email": "chernovaleksey-01011971@postgrespro.ru", "phone": "+70769496678"}
0005434375158	BE8B56	1969 141837	VLADIMIR ANDREEV	{"email": "andreev.v111971@postgrespro.ru", "phone": "+70312134380"}
0005434375159	75E24B	2597 294659	MARIYA MATVEEVA	{"email": "mariyamatveeva-111964@postgrespro.ru", "phone": "+70643650866"}
0005434375160	300F0E	7248 420917	TAGIR ROMANOV	{"phone": "+70902078150"}
0005434375161	300F0E	5114 847876	VIKTOR POPOV	{"phone": "+70536746716"}
0005434375162	E7B360	4900 640232	SERGEY PAVLOV	{"email": "sergeypavlov1974@postgrespro.ru", "phone": "+70015038075"}
0005434375163	E7B360	4598 220458	LYUDMILA MAKSIMOVA	{"email": "maksimova_l_1977@postgrespro.ru", "phone": "+70300434403"}
0005434375164	484F81	1098 023574	ANTON NIKITIN	{"phone": "+70531799000"}
0005434375165	B46BBE	6861 997787	NIKOLAY SHEVCHENKO	{"phone": "+70567912562"}
0005434375166	B46BBE	7137 678210	TAMARA EGOROVA	{"phone": "+70075099507"}
0005434375167	24A38A	9490 220045	DIANA POPOVA	{"email": "d_popova_011962@postgrespro.ru", "phone": "+70391899913"}
0005434375168	04FEB0	9458 811202	ANASTASIYA MIRONOVA	{"email": "mironova_anastasiya28031969@postgrespro.ru", "phone": "+70491449122"}
0005434375169	58B355	2338 827998	GENNADIY MOISEEV	{"phone": "+70876148033"}
0005434375170	1805CE	6337 805680	STANISLAV SHEVCHENKO	{"phone": "+70408227186"}
0005434375171	C7EED5	9975 747597	ALEVTINA POTAPOVA	{"email": "apotapova-1958@postgrespro.ru", "phone": "+70818435248"}
0005434375172	CCA3E7	4329 195912	ANDREY AFANASEV	{"email": "andrey-afanasev.15081963@postgrespro.ru", "phone": "+70400786506"}
0005434375173	CCA3E7	2433 818125	DMITRIY DMITRIEV	{"phone": "+70824262240"}
0005434375174	B10701	2810 445832	SERGEY PETROV	{"email": "petrov.s.05091981@postgrespro.ru", "phone": "+70872136166"}
0005434375175	3ED18E	0518 755899	ARKADIY VOLKOV	{"email": "arkadiy.volkov_10071978@postgrespro.ru", "phone": "+70042665554"}
0005434375176	210A54	5711 012671	TATYANA KUZMINA	{"phone": "+70144430085"}
0005434375177	1B3B61	3516 657816	VASILIY BARANOV	{"email": "baranov.vasiliy.02071966@postgrespro.ru", "phone": "+70603158351"}
0005434375178	F7597F	4184 414872	ANTONINA OSIPOVA	{"email": "antonina_osipova09081974@postgrespro.ru", "phone": "+70695782723"}
0005434375179	64E24C	3879 259759	SERGEY ANDREEV	{"email": "sergeyandreev.1950@postgrespro.ru", "phone": "+70182251278"}
0005434375180	64E24C	1761 659877	MIKHAIL MIKHAYLOV	{"email": "mmikhaylov.091972@postgrespro.ru", "phone": "+70241479701"}
0005434375181	C8B1A4	5244 001653	SHAMIL MAKSIMOV	{"email": "smaksimov-081971@postgrespro.ru", "phone": "+70612150198"}
0005434375182	02F6EC	6123 952659	YANA DMITRIEVA	{"email": "yanadmitrieva081979@postgrespro.ru", "phone": "+70773403070"}
0005434375183	6429E4	7797 595699	GENNADIY KOZLOV	{"email": "gennadiy-kozlov_26031978@postgrespro.ru", "phone": "+70127402902"}
0005434375184	8FA72A	9875 751420	EVGENIYA NIKIFOROVA	{"phone": "+70757995544"}
0005434375185	429A5B	4635 496467	ANDREY GAVRILOV	{"phone": "+70714836900"}
0005434375186	E0086B	6349 490764	ELENA SIDOROVA	{"email": "sidorova_e-111969@postgrespro.ru", "phone": "+70176375305"}
0005434375187	E0086B	0878 231250	LIDIYA SMIRNOVA	{"email": "l-smirnova_1978@postgrespro.ru", "phone": "+70670206663"}
0005434375188	B75001	5682 912312	SERGEY KUZNECOV	{"email": "kuznecov_sergey.061972@postgrespro.ru", "phone": "+70270658293"}
0005434375189	1DBE94	1653 494192	VIKTOR SHEVCHENKO	{"email": "shevchenko_v121968@postgrespro.ru", "phone": "+70401929107"}
0005434375190	864732	4856 130576	EVGENIY ANTONOV	{"phone": "+70568195380"}
0005434375191	73AB51	1272 502597	VASILIY NIKITIN	{"email": "v-nikitin_31011964@postgrespro.ru", "phone": "+70359211929"}
0005434375192	73AB51	4800 230266	TAMARA KUZNECOVA	{"email": "kuznecovatamara_031970@postgrespro.ru", "phone": "+70819119991"}
0005434375193	9CA098	7615 997612	RAISA ZAKHAROVA	{"email": "raisa_zakharova.1965@postgrespro.ru", "phone": "+70875568823"}
0005434375194	3D5270	4777 229008	EGOR GAVRILOV	{"email": "egor-gavrilov.1976@postgrespro.ru", "phone": "+70755983392"}
0005434375195	8D59C2	6385 636950	YANA FILIPPOVA	{"email": "yana-filippova-1972@postgrespro.ru", "phone": "+70196627112"}
0005434375196	95AE21	6809 717744	IGOR FOMIN	{"email": "igorfomin.18111971@postgrespro.ru", "phone": "+70508209112"}
0005434375197	95AE21	0727 369433	KLAVDIYA TIKHONOVA	{"phone": "+70733256957"}
0005434375198	BF4951	7344 764909	SERGEY CHERNOV	{"phone": "+70203271055"}
0005434375199	156E45	7884 760498	MARIYA IVANOVA	{"email": "ivanovam-1979@postgrespro.ru", "phone": "+70986176538"}
0005434375200	E52B95	1643 106593	ANNA NIKIFOROVA	{"phone": "+70251084029"}
0005434375201	E5DD00	3530 394644	YULIYA EFIMOVA	{"phone": "+70922970294"}
0005434375202	784278	9894 297868	KIRILL SHEVCHENKO	{"phone": "+70257966610"}
0005434375203	30A62B	6236 340598	NADEZHDA YAKOVLEVA	{"phone": "+70396054495"}
0005434375204	BAC69E	7162 315997	ALEKSANDR DAVYDOV	{"phone": "+70938231253"}
0005434375205	A2231D	4100 639363	NIKOLAY NAZAROV	{"email": "nazarov-nikolay1979@postgrespro.ru", "phone": "+70883789235"}
0005434375206	A2231D	7679 811836	FEDOR NIKOLAEV	{"email": "nikolaev.f031974@postgrespro.ru", "phone": "+70277108417"}
0005434375207	9F9371	7286 379780	VALERIY TIKHONOV	{"phone": "+70962679344"}
0005434375208	9F9371	0403 811228	ALEKSEY GRIGOREV	{"phone": "+70155623265"}
0005434375209	8BDC2F	6413 454044	LYUDMILA PETROVA	{"phone": "+70996971580"}
0005434375210	73DBA8	9038 338020	ANTONINA FEDOROVA	{"email": "fedorova_a101973@postgrespro.ru", "phone": "+70601918015"}
0005434375211	76F132	6913 139550	ELENA SOKOLOVA	{"phone": "+70786795435"}
0005434375212	76F132	8373 746976	VITALIY MIKHAYLOV	{"phone": "+70489315049"}
0005434375213	C001CB	5430 535909	YULIYA ROMANOVA	{"phone": "+70911882132"}
0005434375214	D669D6	1963 193445	LARISA MASLOVA	{"phone": "+70959241793"}
0005434375215	727A4E	3605 827399	ALEKSANDR FEDOROV	{"phone": "+70677506676"}
0005434375216	4DABD9	6256 620932	IVAN BARANOV	{"phone": "+70789542843"}
0005434375217	A0ABEB	4420 917119	ANASTASIYA RODIONOVA	{"email": "rodionova-anastasiya_24081976@postgrespro.ru", "phone": "+70406029807"}
0005434375218	D70508	6704 423173	NATALYA ALEKSANDROVA	{"phone": "+70334197086"}
0005434375219	890E4E	3521 557841	ALEKSEY SCHERBAKOV	{"email": "scherbakovaleksey1965@postgrespro.ru", "phone": "+70070542315"}
0005434375220	50F30B	3353 032888	SERGEY EGOROV	{"phone": "+70874333844"}
0005434375221	50F30B	8383 710618	VASILIY EGOROV	{"email": "egorov-vasiliy.021973@postgrespro.ru", "phone": "+70888897559"}
0005434375222	EFA28E	5066 726805	ELIZAVETA MAKAROVA	{"email": "e.makarova071985@postgrespro.ru", "phone": "+70181676987"}
0005434375223	EFA28E	9549 978556	NATALYA RODIONOVA	{"email": "natalya_rodionova_20121972@postgrespro.ru", "phone": "+70386260647"}
0005434375224	6834AC	3118 083397	EVGENIY MIKHAYLOV	{"email": "mikhaylov.e.16011970@postgrespro.ru", "phone": "+70070324637"}
0005434375225	E215F0	9548 777678	ALEKSEY ILIN	{"email": "ilin_aleksey-14041967@postgrespro.ru", "phone": "+70820758042"}
0005434375226	9F0C54	4466 903724	MARINA KAZAKOVA	{"email": "kazakova-m.1971@postgrespro.ru", "phone": "+70594039609"}
0005434375227	9F0C54	7101 182206	VLADIMIR FROLOV	{"email": "frolovvladimir_07051968@postgrespro.ru", "phone": "+70226267145"}
0005434375228	546779	5943 670415	EVGENIY SAVELEV	{"phone": "+70221332439"}
0005434375229	546779	1215 772644	VIKTORIYA GAVRILOVA	{"phone": "+70131075603"}
0005434375230	169396	6931 100966	PETR GAVRILOV	{"email": "p.gavrilov-1985@postgrespro.ru", "phone": "+70170777251"}
0005434375231	A8C86B	5152 449257	IGOR YAKOVLEV	{"email": "yakovlev-i031969@postgrespro.ru", "phone": "+70251755365"}
0005434375232	A8C86B	9330 783516	OLEG VASILEV	{"email": "vasilev.o_031986@postgrespro.ru", "phone": "+70095240493"}
0005434375233	97800A	4856 366743	NINA MATVEEVA	{"phone": "+70857281815"}
0005434375234	77F98F	8566 968168	MAKSIM MEDVEDEV	{"phone": "+70121893603"}
0005434375235	152DD8	1821 218036	IRINA ZAKHAROVA	{"email": "zakharova-i.23051975@postgrespro.ru", "phone": "+70681905872"}
0005434375236	152DD8	1156 032612	IRINA POPOVA	{"phone": "+70265417385"}
0005434375237	7188EA	1844 684451	KLAVDIYA FILATOVA	{"phone": "+70628384479"}
0005434375238	565B3A	4727 439811	NIKITA ROMANOV	{"email": "n-romanov_28041969@postgrespro.ru", "phone": "+70564779438"}
0005434375239	6BEC4E	3829 836541	VLADIMIR AFANASEV	{"phone": "+70740265722"}
0005434375240	753EBE	5149 149203	ALEKSEY MEDVEDEV	{"email": "a-medvedev1982@postgrespro.ru", "phone": "+70477198399"}
0005434375241	753EBE	7053 750206	ANGELINA KUZNECOVA	{"phone": "+70529150604"}
0005434375242	4C25BE	3355 106080	ELENA MIKHAYLOVA	{"email": "e_mikhaylova.091970@postgrespro.ru", "phone": "+70958763074"}
0005434375243	46AE66	2796 033538	LYUBOV IVANOVA	{"email": "ivanova-l1967@postgrespro.ru", "phone": "+70701453230"}
0005434375244	FC08C1	4266 419573	VERA SIDOROVA	{"phone": "+70082474606"}
0005434375245	71CD37	8489 989117	PAVEL BELOV	{"email": "pavel_belov.1973@postgrespro.ru", "phone": "+70694921940"}
0005434375246	71CD37	9281 033014	LYUBOV ALEKSANDROVA	{"phone": "+70591564410"}
0005434375247	A573FD	0115 021263	ALEKSANDR ALEKSEEV	{"email": "aleksandr_alekseev-061975@postgrespro.ru", "phone": "+70046832627"}
0005434375248	C1D52A	5706 402174	LIDIYA SOLOVEVA	{"phone": "+70115423986"}
0005434375249	C1D52A	6915 267621	POLINA NIKITINA	{"email": "nikitina_polina_1974@postgrespro.ru", "phone": "+70248286030"}
0005434375250	965B84	4339 608326	ELENA PAVLOVA	{"email": "elena_pavlova111965@postgrespro.ru", "phone": "+70204165148"}
0005434375251	965B84	2428 142740	LEONID ANTONOV	{"phone": "+70453339133"}
0005434375252	43B5CA	4074 362398	PAVEL KOZLOV	{"email": "kozlov.p-1977@postgrespro.ru", "phone": "+70278348562"}
0005434375253	43B5CA	2696 177457	SERGEY KUDRYASHOV	{"email": "kudryashovs_1978@postgrespro.ru", "phone": "+70407156871"}
0005434375254	728D20	0726 269136	MARINA SOLOVEVA	{"email": "m-soloveva.1987@postgrespro.ru", "phone": "+70866006843"}
0005434375255	728D20	0706 700063	ANTONINA MAKAROVA	{"email": "makarova_antonina.1965@postgrespro.ru", "phone": "+70894866967"}
0005434375256	728D20	6775 464258	VYACHESLAV OSIPOV	{"email": "osipov_vyacheslav-1968@postgrespro.ru", "phone": "+70503680513"}
0005434375257	09AFBD	3816 155302	MARIYA MAKAROVA	{"email": "m.makarova-20111962@postgrespro.ru", "phone": "+70084881056"}
0005434375258	82CA84	4631 577359	TATYANA DMITRIEVA	{"email": "tatyana_dmitrieva.1974@postgrespro.ru", "phone": "+70521752650"}
0005434375259	95009B	4534 280457	MARIYA SOKOLOVA	{"email": "sokolova-m_031976@postgrespro.ru", "phone": "+70251439819"}
0005434375260	3CD7D6	0643 316850	ELENA MAKAROVA	{"phone": "+70853956464"}
0005434375261	3CD7D6	8178 885503	EVGENIY AFANASEV	{"email": "evgeniy-afanasev1969@postgrespro.ru", "phone": "+70286062102"}
0005434375262	2BC75E	6472 031787	ALEKSEY EGOROV	{"phone": "+70635886166"}
0005434375263	5F8D59	5046 596756	NADEZHDA IVANOVA	{"phone": "+70372917431"}
0005434375264	06BE74	1320 920532	TATYANA KONOVALOVA	{"email": "konovalova-tatyana-011965@postgrespro.ru", "phone": "+70801138471"}
0005434375265	06BE74	8228 984319	ALEKSANDR PAVLOV	{"phone": "+70639493404"}
0005434375266	19254D	3662 732018	PAVEL KUZNECOV	{"email": "p-kuznecov_011967@postgrespro.ru", "phone": "+70264035737"}
0005434375267	19254D	2000 509887	ELIZAVETA KAZAKOVA	{"phone": "+70535091718"}
0005434375268	113E34	4791 531143	OLGA FILATOVA	{"email": "filatova_o_1976@postgrespro.ru", "phone": "+70846289999"}
0005434375269	113E34	6780 665902	EVGENIYA KAZAKOVA	{"phone": "+70528174022"}
0005434375270	49B9AB	1508 972773	ALEKSANDR KRASNOV	{"phone": "+70844359201"}
0005434375271	0F8D6B	6795 139026	ALEKSEY PETROV	{"phone": "+70600269355"}
0005434375272	DDAE54	3925 724519	DMITRIY ANDREEV	{"phone": "+70733115717"}
0005434375273	8C5AA8	6504 156260	VYACHESLAV KISELEV	{"email": "vyacheslav-kiselev_051976@postgrespro.ru", "phone": "+70001484345"}
0005434375274	6EB1D6	9879 415227	YULIYA KOROLEVA	{"email": "y-koroleva11081970@postgrespro.ru", "phone": "+70683110959"}
0005434375275	A00F38	5600 968663	NIKITA OSIPOV	{"email": "osipovnikita091981@postgrespro.ru", "phone": "+70848588288"}
0005434375276	A00F38	5023 475206	LYUBOV MARTYNOVA	{"email": "lyubov-martynova_1959@postgrespro.ru", "phone": "+70480396661"}
0005434375277	2F1EB2	3818 839961	MAKSIM ZAYCEV	{"phone": "+70272082995"}
0005434375278	2F1EB2	2686 848944	ALEKSEY MELNIKOV	{"phone": "+70715596397"}
0005434375279	3A149F	5861 668028	ALEKSANDR PAVLOV	{"email": "a.pavlov04121968@postgrespro.ru", "phone": "+70405115895"}
0005434375280	59521B	9123 866136	ANGELINA DANILOVA	{"phone": "+70397946769"}
0005434375281	B93641	5570 507355	YULIYA SOROKINA	{"phone": "+70693331590"}
0005434375282	868735	0974 427053	ELENA GRISHINA	{"phone": "+70730480150"}
0005434375283	A51CDC	1966 902564	VALERIY OSIPOV	{"phone": "+70997734293"}
0005434375284	DBC90F	0904 926169	YAROSLAV SEMENOV	{"email": "semenovyaroslav_031968@postgrespro.ru", "phone": "+70367633356"}
0005434375285	2560DA	7248 431655	DMITRIY DMITRIEV	{"phone": "+70669364228"}
0005434375286	2560DA	6989 501158	MARINA AFANASEVA	{"email": "mafanaseva.30081965@postgrespro.ru", "phone": "+70720311088"}
0005434375287	FE4916	5827 630866	VIKTOR NIKITIN	{"email": "nikitinv.28051960@postgrespro.ru", "phone": "+70680182425"}
0005434375288	FE4916	2025 286489	NINA BORISOVA	{"phone": "+70181696817"}
0005434375289	A5185C	7774 159196	OLGA MEDVEDEVA	{"email": "olga_medvedeva-20111967@postgrespro.ru", "phone": "+70546606113"}
0005434375290	56A2E2	8687 420307	TATYANA MAKAROVA	{"email": "makarovat-22101984@postgrespro.ru", "phone": "+70261418089"}
0005434375291	CA73D3	3756 101349	MARIYA KUZMINA	{"email": "kuzmina-m1965@postgrespro.ru", "phone": "+70321289332"}
0005434375292	7838F8	1104 099416	KSENIYA IVANOVA	{"email": "ivanova-k-031976@postgrespro.ru", "phone": "+70234470930"}
0005434375293	7838F8	6228 378572	ANASTASIYA MIRONOVA	{"email": "anastasiya_mironova05081968@postgrespro.ru", "phone": "+70007375594"}
0005434375294	07A8F1	7326 192963	VLADIMIR FROLOV	{"email": "v.frolov1981@postgrespro.ru", "phone": "+70328556865"}
0005434375295	85D85F	5140 029385	EKATERINA KUDRYASHOVA	{"email": "ekaterinakudryashova_13111969@postgrespro.ru", "phone": "+70191137328"}
0005434375296	B3CFFC	7972 599785	ANNA KUZNECOVA	{"phone": "+70868646522"}
0005434375297	D75EB6	9791 218480	MIKHAIL VASILEV	{"email": "mikhail.vasilev.111970@postgrespro.ru", "phone": "+70764564185"}
0005434375298	D75EB6	2513 802097	BOGDAN VOLKOV	{"phone": "+70862688386"}
0005434375299	380462	6654 891081	VLADIMIR POPOV	{"email": "popovvladimir-14111972@postgrespro.ru", "phone": "+70435843881"}
0005434375300	380462	9698 748915	EVGENIY KUZNECOV	{"phone": "+70032160151"}
0005434375301	B6F693	2897 453144	VALERIY BONDARENKO	{"email": "bondarenkov051974@postgrespro.ru", "phone": "+70471104239"}
0005434375302	C801F2	7631 501698	NIKOLAY TIMOFEEV	{"email": "timofeev-n18111973@postgrespro.ru", "phone": "+70519813867"}
0005434375303	5412EB	3917 693464	SVETLANA MEDVEDEVA	{"email": "medvedeva_s-041976@postgrespro.ru", "phone": "+70401823609"}
0005434375304	C1722A	3244 272260	ELENA FOMINA	{"email": "e-fomina_011975@postgrespro.ru", "phone": "+70504360393"}
0005434375305	1C1A22	1481 954624	OLGA FILIPPOVA	{"email": "ofilippova1971@postgrespro.ru", "phone": "+70312180705"}
0005434375306	1C1A22	0280 073358	KONSTANTIN NIKOLAEV	{"email": "nikolaev.konstantin-1972@postgrespro.ru", "phone": "+70134668741"}
0005434375307	00EE9F	7740 683956	NATALYA NIKOLAEVA	{"phone": "+70229667644"}
0005434375308	6A447D	8673 223175	ANVAR ANDREEV	{"email": "andreevanvar041973@postgrespro.ru", "phone": "+70757699238"}
0005434375309	B09E06	8482 952404	MARINA NOVIKOVA	{"email": "novikova_marina.1976@postgrespro.ru", "phone": "+70981620355"}
0005434375310	953533	9401 299932	ALEKSANDR VOLKOV	{"phone": "+70508192027"}
0005434375311	953533	1436 220196	TATYANA NAZAROVA	{"phone": "+70058088530"}
0005434375312	7BEC75	1086 437645	GALINA GRISHINA	{"email": "g_grishina.081971@postgrespro.ru", "phone": "+70241464517"}
0005434375313	E873C5	4567 438846	OLESYA KOROLEVA	{"email": "koroleva_olesya_011972@postgrespro.ru", "phone": "+70185987368"}
0005434375314	2D2FE6	6564 184951	SERGEY SOROKIN	{"phone": "+70070886850"}
0005434375315	CCBA6F	6306 222772	MARIYA CHERNOVA	{"phone": "+70797743389"}
0005434375316	49A0A7	5636 054632	RAMIL DENISOV	{"email": "denisov.r19011976@postgrespro.ru", "phone": "+70344234510"}
0005434375317	49A0A7	3787 815559	ANASTASIYA VOLKOVA	{"phone": "+70245873190"}
0005434375318	49A0A7	8854 865930	RAVIL DENISOV	{"phone": "+70015224998"}
0005434375319	C598EC	2356 732469	SERGEY KONOVALOV	{"email": "konovalov.s_24031965@postgrespro.ru", "phone": "+70943422351"}
0005434375320	1EC8A6	0257 584921	LEONID ROMANOV	{"email": "romanov-leonid-20111959@postgrespro.ru", "phone": "+70982443939"}
0005434375321	ADA7FC	8931 173379	VALERIY NOVIKOV	{"phone": "+70933167644"}
0005434375322	BCB985	9455 320057	NIKOLAY VASILEV	{"phone": "+70742707868"}
0005434375323	B545B7	1577 903487	YURIY PAVLOV	{"email": "yuriy_pavlov-1975@postgrespro.ru", "phone": "+70432781051"}
0005434375324	B545B7	6162 123863	ANATOLIY MELNIKOV	{"email": "melnikov.anatoliy.31071983@postgrespro.ru", "phone": "+70140522507"}
0005434375325	C9818C	3568 497096	GRIGORIY ALEKSANDROV	{"phone": "+70335195838"}
0005434375326	99ABC2	9692 206522	REGINA BORISOVA	{"phone": "+70513842715"}
0005434375327	2A6695	3420 547529	SEMEN CHERNOV	{"email": "semenchernov_031976@postgrespro.ru", "phone": "+70555303512"}
0005434375328	FDED66	2160 819731	TATYANA MAKAROVA	{"email": "tatyana-makarova071959@postgrespro.ru", "phone": "+70819998865"}
0005434375329	954246	1331 864923	YULIYA ZAYCEVA	{"phone": "+70917170929"}
0005434375330	2F038F	0360 589927	NATALYA YUDINA	{"phone": "+70691976787"}
0005434375331	AB6D31	7014 934606	VLADISLAV SOROKIN	{"phone": "+70607162707"}
0005434375332	37CFAC	1062 949299	IGOR VOROBEV	{"phone": "+70704525226"}
0005434375333	65D093	5363 395143	LYUDMILA KUZNECOVA	{"phone": "+70376078018"}
0005434375334	65D093	1200 920412	MATVEY OSIPOV	{"email": "mosipov.29031976@postgrespro.ru", "phone": "+70216701292"}
0005434375335	2D6080	6269 986314	TAMARA KONOVALOVA	{"phone": "+70807987001"}
0005434375336	2D6080	9914 341342	VALENTIN SEMENOV	{"email": "v-semenov1974@postgrespro.ru", "phone": "+70624519761"}
0005434375337	4477B0	3991 534106	SVETLANA IVANOVA	{"phone": "+70108871557"}
0005434375338	667E15	6907 309749	ANATOLIY ILIN	{"email": "ilin-anatoliy.021966@postgrespro.ru", "phone": "+70339766333"}
0005434375339	667E15	6023 448763	ARTEM KAZAKOV	{"email": "kazakov.a021982@postgrespro.ru", "phone": "+70310307854"}
0005434375340	A10B9F	1289 446243	VALENTINA TIMOFEEVA	{"email": "timofeeva-v_1968@postgrespro.ru", "phone": "+70750910716"}
0005434375341	208253	0784 133723	NADEZHDA YUDINA	{"email": "nadezhda_yudina29081968@postgrespro.ru", "phone": "+70537529993"}
0005434375342	A4561D	1128 710309	TAMARA KONDRATEVA	{"email": "t_kondrateva_011953@postgrespro.ru", "phone": "+70580353686"}
0005434375343	0C46A6	6439 612813	ELENA MAKAROVA	{"phone": "+70534286905"}
0005434375344	0C46A6	1662 378655	MARIYA PETROVA	{"email": "petrova_mariya-08101975@postgrespro.ru", "phone": "+70944540950"}
0005434375345	FF1EAA	1128 761595	DMITRIY BORISOV	{"email": "borisov-dmitriy-27101963@postgrespro.ru", "phone": "+70273491820"}
0005434375346	92BB8F	8355 285710	DARYA FILIPPOVA	{"phone": "+70554193409"}
0005434375347	ADBD98	9359 383915	YURIY KRASNOV	{"phone": "+70720617300"}
0005434375348	ADBD98	1481 302953	ANNA ANTONOVA	{"email": "aantonova-16061966@postgrespro.ru", "phone": "+70392067521"}
0005434375349	47ABE9	6315 840210	OKSANA CHERNOVA	{"email": "ochernova111971@postgrespro.ru", "phone": "+70930396160"}
0005434375350	47ABE9	8969 092477	GULSINA ROMANOVA	{"email": "romanova-gulsina-051980@postgrespro.ru", "phone": "+70943963196"}
0005434375351	CC5541	9850 972016	ANDREY KUZNECOV	{"email": "kuznecovandrey31011957@postgrespro.ru", "phone": "+70345127418"}
0005434375352	408865	3600 528894	VYACHESLAV IVANOV	{"email": "ivanov.vyacheslav_1970@postgrespro.ru", "phone": "+70632515099"}
0005434375353	86660E	7606 794903	IGOR GAVRILOV	{"phone": "+70806551721"}
0005434375354	FC2D56	3047 261517	YAKOV TIKHONOV	{"email": "tikhonov-y031966@postgrespro.ru", "phone": "+70318930599"}
0005434375355	B658F6	7655 320032	ELENA AKIMOVA	{"email": "akimovaelena.24031965@postgrespro.ru", "phone": "+70454244984"}
0005434375356	8D4AD9	1397 010763	EVGENIY PETROV	{"phone": "+70818581463"}
0005434375357	5E8CE6	2035 556304	NADEZHDA SMIRNOVA	{"phone": "+70135414971"}
0005434375358	722E4D	7115 982257	IRINA ROMANOVA	{"email": "irina_romanova.071977@postgrespro.ru", "phone": "+70095783125"}
0005434375359	C9C9A7	7764 441744	IGOR KULIKOV	{"email": "i.kulikov-1987@postgrespro.ru", "phone": "+70180818718"}
0005434375360	5C1284	4834 826962	SVETLANA PETROVA	{"phone": "+70117883970"}
0005434375361	068110	5328 101748	DMITRIY GAVRILOV	{"email": "gavrilov.d-05121966@postgrespro.ru", "phone": "+70388139972"}
0005434375362	95FCC7	8811 039591	IVAN FOMIN	{"phone": "+70138558532"}
0005434375363	1FE5C1	4912 222996	ALEKSANDR ZHUKOV	{"email": "zhukov_a.021983@postgrespro.ru", "phone": "+70401401513"}
0005434375364	708005	3363 334854	LIDIYA PETROVA	{"phone": "+70141947655"}
0005434375365	093BAC	3256 686921	ZINAIDA MAKAROVA	{"phone": "+70899616535"}
0005434375366	093BAC	6826 196849	ALEKSANDR KULIKOV	{"phone": "+70665204730"}
0005434375367	D63A59	8608 246397	MARIYA STEPANOVA	{"email": "stepanova-mariya_021968@postgrespro.ru", "phone": "+70917502110"}
0005434375368	61D102	8758 552412	ANASTASIYA KUZNECOVA	{"phone": "+70234174010"}
0005434375369	528FD3	1065 304310	NATALYA ANTONOVA	{"phone": "+70637991860"}
0005434375370	C0CB8B	9139 996307	ALEKSANDR KAZAKOV	{"email": "kazakova26011965@postgrespro.ru", "phone": "+70392428420"}
0005434375371	C0CB8B	5230 769473	VALENTINA VLASOVA	{"phone": "+70481620288"}
0005434375372	DB2159	9320 232301	YURIY IVANOV	{"phone": "+70874211235"}
0005434375373	4254C1	0129 352224	DMITRIY SIDOROV	{"email": "sidorov.dmitriy-1969@postgrespro.ru", "phone": "+70375457940"}
0005434375374	4D50F8	7202 124686	LIDIYA ZAYCEVA	{"phone": "+70410768297"}
0005434375375	18A711	3803 590482	NIKOLAY GRIGOREV	{"email": "grigorev-n-17071970@postgrespro.ru", "phone": "+70778175726"}
0005434375376	BBCA36	2492 304880	MARIYA ROMANOVA	{"email": "mromanova051968@postgrespro.ru", "phone": "+70299681468"}
0005434375377	0566A3	7270 458613	SERGEY POPOV	{"phone": "+70076501350"}
0005434375378	0566A3	9067 581762	VALERIYA SCHERBAKOVA	{"email": "scherbakova.v-1965@postgrespro.ru", "phone": "+70515198830"}
0005434375379	244E1E	5045 590410	VLADIMIR VOROBEV	{"email": "vladimir.vorobev-1976@postgrespro.ru", "phone": "+70746547958"}
0005434375380	1DEC7B	9264 637810	GALINA TIKHONOVA	{"phone": "+70731368695"}
0005434375381	F1E614	7608 691143	KONSTANTIN ALEKSANDROV	{"email": "aleksandrovkonstantin_1971@postgrespro.ru", "phone": "+70785252130"}
0005434375382	11E377	6658 754675	OLGA YUDINA	{"email": "yudina.o02121979@postgrespro.ru", "phone": "+70343008412"}
0005434375383	838780	7426 037353	ANATOLIY NIKOLAEV	{"phone": "+70596732816"}
0005434375384	52A891	5855 728785	ZINAIDA ANDREEVA	{"phone": "+70682209053"}
0005434375385	52A891	7186 736944	ELENA LAZAREVA	{"email": "e.lazareva.081971@postgrespro.ru", "phone": "+70005879949"}
0005434375386	B533EC	4515 340795	ALEKSANDR TARASOV	{"phone": "+70282072489"}
0005434375387	4F359B	6036 344147	VLADIMIR NIKOLAEV	{"phone": "+70144836611"}
0005434375388	1ACF22	6523 852256	SVETLANA PETROVA	{"phone": "+70831582653"}
0005434375389	5B0F10	0525 191216	EVGENIY VASILEV	{"email": "e.vasilev.09121971@postgrespro.ru", "phone": "+70169160556"}
0005434375390	5B0F10	0154 400399	GALINA ABRAMOVA	{"phone": "+70498644704"}
0005434375391	1D2BF0	4416 921535	EVGENIY SCHERBAKOV	{"phone": "+70098897595"}
0005434375392	B74629	2239 525746	MARINA MEDVEDEVA	{"email": "m-medvedeva.04051979@postgrespro.ru", "phone": "+70851848234"}
0005434375393	48F928	6988 437592	VIKTORIYA MIKHAYLOVA	{"phone": "+70883834162"}
0005434375394	15A1BB	8086 823557	ALEKSANDRA OSIPOVA	{"phone": "+70546118093"}
0005434375395	15A1BB	1102 988083	ALEKSEY MIRONOV	{"phone": "+70675772011"}
0005434375396	421BEA	4881 298905	RAUF MOISEEV	{"phone": "+70367010507"}
0005434375397	46E5F0	9947 932266	YURIY TARASOV	{"email": "yuriy_tarasov.12121979@postgrespro.ru", "phone": "+70120168644"}
0005434375398	F2280C	2905 970520	LYUBOV FILATOVA	{"phone": "+70987159850"}
0005434375399	F2280C	7569 521532	OLGA FEDOROVA	{"email": "fedorova_olga.011969@postgrespro.ru", "phone": "+70878493873"}
0005434375400	27C449	1965 361912	YAROSLAV SCHERBAKOV	{"phone": "+70143181633"}
0005434375401	9CA32D	6568 531489	GALINA AFANASEVA	{"email": "galinaafanaseva031978@postgrespro.ru", "phone": "+70119507701"}
0005434375402	9CA32D	9227 651967	PAVEL ILIN	{"email": "ilin.pavel_21121971@postgrespro.ru", "phone": "+70144732459"}
0005434375403	B7FBA2	0610 487861	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov07071973@postgrespro.ru", "phone": "+70830443872"}
0005434375404	74161B	1888 259762	EKATERINA KUZMINA	{"phone": "+70336268271"}
0005434375405	350DF7	9265 741641	MARIYA GORBUNOVA	{"phone": "+70231284825"}
0005434375406	DFC539	4090 665734	IRINA KUZNECOVA	{"email": "kuznecova.i_1973@postgrespro.ru", "phone": "+70836613685"}
0005434375407	DFC539	0573 947384	TATYANA DMITRIEVA	{"email": "tatyanadmitrieva_1967@postgrespro.ru", "phone": "+70520263648"}
0005434375408	357982	6936 356353	GALINA KALININA	{"phone": "+70944727846"}
0005434375409	41C758	4721 112536	VYACHESLAV ANDREEV	{"email": "vyacheslav.andreev-071972@postgrespro.ru", "phone": "+70839806377"}
0005434375410	CC262D	4247 812555	LYUBOV KOZLOVA	{"email": "kozlovalyubov04101969@postgrespro.ru", "phone": "+70783744148"}
0005434375411	DBE484	8029 988657	MARIYA ROMANOVA	{"email": "mromanova.121969@postgrespro.ru", "phone": "+70050743678"}
0005434375412	B64E7E	7201 213569	MARIYA LEBEDEVA	{"phone": "+70534964881"}
0005434375413	0EEC74	7564 880680	LYUDMILA NIKITINA	{"phone": "+70076201188"}
0005434375414	0EEC74	8093 103919	VLADIMIR FILIPPOV	{"phone": "+70729721497"}
0005434375415	46D643	3734 928505	SERGEY PETROV	{"phone": "+70203981213"}
0005434375416	4C7D31	6004 130186	VYACHESLAV IVANOV	{"email": "v_ivanov041967@postgrespro.ru", "phone": "+70373710535"}
0005434375417	E8A28D	8682 239898	ALEKSEY MIKHAYLOV	{"phone": "+70243632845"}
0005434375418	6AE196	7933 927304	EGOR DAVYDOV	{"phone": "+70230247141"}
0005434375419	6AE196	3313 510159	VALERIY YAKOVLEV	{"email": "valeriyyakovlev-1969@postgrespro.ru", "phone": "+70945833712"}
0005434375420	6265BC	1574 973846	SVETLANA NIKIFOROVA	{"email": "s_nikiforova111973@postgrespro.ru", "phone": "+70593430244"}
0005434375421	249942	6403 847129	ARTEM ZHURAVLEV	{"email": "zhuravlev.artem.1972@postgrespro.ru", "phone": "+70495695789"}
0005434375533	C0EF2D	4322 040547	ALISA NOVIKOVA	{"phone": "+70558357420"}
0005434375422	EE1B8A	7406 597177	VERA KULIKOVA	{"email": "kulikova-v.121976@postgrespro.ru", "phone": "+70438990119"}
0005434375423	EE1B8A	4402 239347	ALLA VASILEVA	{"phone": "+70595944581"}
0005434375424	589C4B	1591 632082	ALEKSANDRA DAVYDOVA	{"phone": "+70234188172"}
0005434375425	589C4B	4483 132728	VYACHESLAV SMIRNOV	{"phone": "+70496168826"}
0005434375426	FDBFB3	0041 385799	RAISA TIKHONOVA	{"phone": "+70947958285"}
0005434375427	FDBFB3	0914 969786	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila.111969@postgrespro.ru", "phone": "+70818006639"}
0005434375428	E1F40C	3710 958030	GALINA MASLOVA	{"email": "maslovag-01061973@postgrespro.ru", "phone": "+70883497501"}
0005434375429	76D1E2	0147 538294	MIKHAIL SOKOLOV	{"email": "mikhail-sokolov_021975@postgrespro.ru", "phone": "+70032725451"}
0005434375430	76D1E2	0245 572324	RINAT BONDARENKO	{"email": "rinat_bondarenko_25051978@postgrespro.ru", "phone": "+70228385129"}
0005434375431	76D1E2	1120 678834	DARYA ZAKHAROVA	{"email": "daryazakharova091974@postgrespro.ru", "phone": "+70662894496"}
0005434375432	139DD3	0285 105886	ANDREY FOMIN	{"phone": "+70087865988"}
0005434375433	23C2D0	8091 142317	EKATERINA KRASNOVA	{"email": "krasnova-e_11011965@postgrespro.ru", "phone": "+70961611609"}
0005434375434	23C2D0	1553 760566	ARINA KONDRATEVA	{"email": "arinakondrateva_1972@postgrespro.ru", "phone": "+70809468422"}
0005434375435	57EFCE	6936 606632	TATYANA BELOVA	{"email": "tatyana-belova_1969@postgrespro.ru", "phone": "+70799241694"}
0005434375436	7A7A8B	9218 874848	GALINA GRISHINA	{"phone": "+70377713753"}
0005434375437	7F808B	7717 049287	SVETLANA NIKOLAEVA	{"email": "nikolaevas_071976@postgrespro.ru", "phone": "+70510791003"}
0005434375438	8EAB33	3544 445780	VLADIMIR IVANOV	{"email": "vladimir_ivanov10061975@postgrespro.ru", "phone": "+70023473873"}
0005434375439	C787FD	9919 442601	OLEG POPOV	{"phone": "+70678590477"}
0005434375440	C787FD	8446 529661	VIKTOR BARANOV	{"email": "baranov-viktor-031968@postgrespro.ru", "phone": "+70531751565"}
0005434375441	B8EA4A	0841 951735	PETR NIKOLAEV	{"email": "nikolaevp-1972@postgrespro.ru", "phone": "+70030082578"}
0005434375442	B8EA4A	1827 099232	NATALIYA EFREMOVA	{"phone": "+70256973394"}
0005434375443	F60FB3	3370 348582	DARINA ILINA	{"phone": "+70514807152"}
0005434375444	302EF7	2828 441151	ANTON FILIPPOV	{"phone": "+70311062151"}
0005434375445	D45FC2	6131 786861	YURIY SIDOROV	{"phone": "+70556508913"}
0005434375446	513F18	8045 930352	VLADIMIR ISAEV	{"phone": "+70761451034"}
0005434375447	513F18	4548 121801	ANDREY IVANOV	{"email": "aivanov.081978@postgrespro.ru", "phone": "+70862664790"}
0005434375448	0CAAA4	8908 169872	MAKSIM IVANOV	{"email": "mivanov.27071970@postgrespro.ru", "phone": "+70681562258"}
0005434375449	3C44FA	8732 805948	ARTEM MAKSIMOV	{"email": "artem-maksimov_21031955@postgrespro.ru", "phone": "+70559296021"}
0005434375450	E7D563	8279 508576	DANIIL SMIRNOV	{"email": "smirnov.d_101970@postgrespro.ru", "phone": "+70617879830"}
0005434375451	E7D563	9784 640753	DINA BOGDANOVA	{"phone": "+70239067024"}
0005434375452	197E34	0840 507967	ANATOLIY IVANOV	{"phone": "+70830593787"}
0005434375453	BA2609	3973 979279	OLGA MAKSIMOVA	{"email": "o_maksimova.1955@postgrespro.ru", "phone": "+70627248166"}
0005434375454	21D023	0642 553658	ROMAN STEPANOV	{"phone": "+70031235212"}
0005434375455	6E4EC9	2337 447837	VADIM POPOV	{"phone": "+70260020762"}
0005434375456	53A05D	7621 010605	GEORGIY MOISEEV	{"phone": "+70975374422"}
0005434375457	53A05D	5269 017924	ZINAIDA KULIKOVA	{"phone": "+70951998354"}
0005434375458	E9F0A3	9528 416937	ILYA GUSEV	{"email": "gusev.i_041972@postgrespro.ru", "phone": "+70340279283"}
0005434375459	571EE2	1340 099146	VLADIMIR MATVEEV	{"email": "vladimirmatveev-02121974@postgrespro.ru", "phone": "+70891925046"}
0005434375460	CC6FF9	6335 265405	LIDIYA SOKOLOVA	{"email": "sokolova-l_08081959@postgrespro.ru", "phone": "+70316564669"}
0005434375461	179AF3	5022 051287	ELENA KULIKOVA	{"email": "elena.kulikova031964@postgrespro.ru", "phone": "+70330440904"}
0005434375462	179AF3	9663 271629	IVAN MOROZOV	{"email": "morozov_ivan-1965@postgrespro.ru", "phone": "+70190606307"}
0005434375463	179AF3	8022 987042	LYUDMILA ANDREEVA	{"phone": "+70488792693"}
0005434375464	D47BB3	6588 782352	ALEKSANDR GRIGOREV	{"email": "a.grigorev12041978@postgrespro.ru", "phone": "+70085282914"}
0005434375465	22E3C9	0117 733016	YULIYA DMITRIEVA	{"email": "dmitrieva_yuliya021972@postgrespro.ru", "phone": "+70974682816"}
0005434375466	42AA54	8387 816691	VLADISLAV SCHERBAKOV	{"email": "scherbakov_v_071980@postgrespro.ru", "phone": "+70098341888"}
0005434375467	6AAC05	4305 431736	ARINA BORISOVA	{"email": "borisova-arina_041968@postgrespro.ru", "phone": "+70470840959"}
0005434375468	407B7C	8407 006249	ALEKSEY FEDOTOV	{"email": "aleksey.fedotov-24071966@postgrespro.ru", "phone": "+70455240988"}
0005434375469	562B65	2001 297869	KLAVDIYA ANDREEVA	{"phone": "+70325582381"}
0005434375470	562B65	4002 084886	LARISA DMITRIEVA	{"email": "dmitrieva_larisa.1980@postgrespro.ru", "phone": "+70468547058"}
0005434375471	6A8CC0	4895 506974	ELENA BARANOVA	{"email": "elena.baranova_24021969@postgrespro.ru", "phone": "+70263133405"}
0005434375472	581A48	1105 088799	LYUDMILA SCHERBAKOVA	{"email": "scherbakoval.111966@postgrespro.ru", "phone": "+70680131477"}
0005434375473	281B1E	0869 387881	PAVEL KOZLOV	{"email": "p.kozlov.20031967@postgrespro.ru", "phone": "+70895495459"}
0005434375474	E423C5	6103 500334	OKSANA SOKOLOVA	{"phone": "+70389245916"}
0005434375475	DB3D58	8045 529654	VYACHESLAV ZAYCEV	{"email": "vyacheslav.zaycev1976@postgrespro.ru", "phone": "+70750030792"}
0005434375476	DB3D58	5469 319622	RAVIL KRASNOV	{"email": "ravil_krasnov.1988@postgrespro.ru", "phone": "+70721729440"}
0005434375477	DB3D58	3189 310293	FEDOR KULIKOV	{"email": "f.kulikov.15101967@postgrespro.ru", "phone": "+70508356364"}
0005434375478	3A1020	6568 229764	NATALYA DAVYDOVA	{"email": "natalya.davydova-05061975@postgrespro.ru", "phone": "+70685206821"}
0005434375479	369642	4118 832388	YULIYA CHERNOVA	{"phone": "+70518969277"}
0005434375480	B25592	0074 318650	VLADIMIR SERGEEV	{"phone": "+70948854925"}
0005434375481	B25592	9325 815111	POLINA ZHURAVLEVA	{"phone": "+70043677219"}
0005434375482	B7BFBE	5120 134931	LIDIYA ALEKSEEVA	{"email": "alekseeva_l-13121977@postgrespro.ru", "phone": "+70728296969"}
0005434375483	916FBE	8576 444829	PAVEL VASILEV	{"phone": "+70247761454"}
0005434375484	916FBE	4564 143699	TATYANA LUKYANOVA	{"email": "lukyanova-t31071977@postgrespro.ru", "phone": "+70520892928"}
0005434375485	6EAC12	2253 359552	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy-1967@postgrespro.ru", "phone": "+70500869754"}
0005434375486	0810EB	2388 061923	NINA AKIMOVA	{"phone": "+70249243473"}
0005434375487	9B8CCA	3990 762460	ALEKSANDRA VASILEVA	{"email": "vasilevaa-1983@postgrespro.ru", "phone": "+70822352891"}
0005434375488	5AEE6D	4137 293300	DMITRIY VASILEV	{"phone": "+70139493012"}
0005434375489	216D28	6140 710809	VALENTINA SOKOLOVA	{"email": "v-sokolova1977@postgrespro.ru", "phone": "+70556422263"}
0005434375490	216D28	7666 187613	TATYANA NESTEROVA	{"phone": "+70272992771"}
0005434375491	4CB26B	1568 628908	RENAT FEDOROV	{"phone": "+70285366071"}
0005434375492	97E172	4244 985223	VALERIY PETROV	{"email": "valeriypetrov-1978@postgrespro.ru", "phone": "+70838581967"}
0005434375493	A70A2E	7833 945086	ZHANNA DMITRIEVA	{"phone": "+70076693613"}
0005434375494	94357E	0423 444528	LYUDMILA PAVLOVA	{"phone": "+70513157226"}
0005434375495	226478	1388 397048	MAKSIM ABRAMOV	{"phone": "+70280782088"}
0005434375496	930C8C	1674 107707	SERGEY AFANASEV	{"phone": "+70416020073"}
0005434375497	1B7D52	2377 586673	SERGEY KRASNOV	{"email": "krasnovs091965@postgrespro.ru", "phone": "+70305605399"}
0005434375498	25C2F8	9299 356968	YURIY ZHUKOV	{"email": "yzhukov.28061986@postgrespro.ru", "phone": "+70132235565"}
0005434375499	EE4C09	5146 727143	TATYANA KUZNECOVA	{"phone": "+70482465752"}
0005434375500	36892B	7533 668475	ARTEMIY IVANOV	{"email": "a.ivanov.011969@postgrespro.ru", "phone": "+70688205566"}
0005434375501	79486C	9429 794606	ALEKSANDR MAKAROV	{"phone": "+70609857696"}
0005434375502	4FF999	0606 332564	KAPITALINA NIKIFOROVA	{"phone": "+70336961709"}
0005434375503	4FF999	7453 009130	EVGENIYA KUZNECOVA	{"email": "kuznecovae.1976@postgrespro.ru", "phone": "+70847104095"}
0005434375504	4FF999	8709 218342	VALERIY MAKAROV	{"phone": "+70183922246"}
0005434375505	AB36BD	3441 095946	TATYANA GRISHINA	{"email": "grishina_t23031973@postgrespro.ru", "phone": "+70149907880"}
0005434375506	B199D1	3232 008659	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana.25021978@postgrespro.ru", "phone": "+70144863114"}
0005434375507	B3CB97	7429 222156	MARINA MIKHAYLOVA	{"phone": "+70386697099"}
0005434375508	AC1F3C	4589 807099	VIKTOR FEDOROV	{"email": "vfedorov.091967@postgrespro.ru", "phone": "+70343407770"}
0005434375509	E4DCCF	3837 679549	BORIS PETROV	{"phone": "+70282634422"}
0005434375510	40B4B9	3551 632780	NATALYA MEDVEDEVA	{"phone": "+70983579332"}
0005434375511	EA1C8E	0080 993113	VLADIMIR EGOROV	{"email": "egorov-vladimir_04071972@postgrespro.ru", "phone": "+70557034872"}
0005434375512	EA1C8E	2002 421439	LYUDMILA DANILOVA	{"phone": "+70068582215"}
0005434375513	EA1C8E	7262 439191	NATALYA OSIPOVA	{"email": "osipovan_1957@postgrespro.ru", "phone": "+70616033229"}
0005434375514	EA1C8E	9650 409615	IVAN KUDRYASHOV	{"email": "ivankudryashov_021972@postgrespro.ru", "phone": "+70119387707"}
0005434375515	477E24	6334 370717	NATALYA KALININA	{"email": "natalya_kalinina.011969@postgrespro.ru", "phone": "+70643771839"}
0005434375516	8714DA	2152 657878	ALEKSANDR TIMOFEEV	{"email": "timofeev_a.061978@postgrespro.ru", "phone": "+70184986465"}
0005434375517	8714DA	4554 632579	MARIYA OSIPOVA	{"phone": "+70734150477"}
0005434375518	C8F593	1864 448854	ZOYA POLYAKOVA	{"email": "zoya-polyakova_091968@postgrespro.ru", "phone": "+70671499437"}
0005434375519	C8F593	6891 936086	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev-121974@postgrespro.ru", "phone": "+70561801192"}
0005434375520	BAEB21	1923 126833	IRINA MELNIKOVA	{"email": "melnikova_irina.041958@postgrespro.ru", "phone": "+70498891441"}
0005434375521	D605DB	5067 742319	ALEKSANDR ZAKHAROV	{"phone": "+70540571210"}
0005434375522	C8AEA2	7061 346807	ROMAN MIKHAYLOV	{"email": "mikhaylovroman_1966@postgrespro.ru", "phone": "+70986624155"}
0005434375523	C8AEA2	1643 956466	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr.101971@postgrespro.ru", "phone": "+70181033224"}
0005434375524	C8AEA2	4317 654981	YURIY IVANOV	{"phone": "+70687120817"}
0005434375525	C1D8C9	3954 256275	GALINA MAKSIMOVA	{"phone": "+70268058423"}
0005434375526	81392F	5585 053146	GALINA SIDOROVA	{"email": "sidorova_galina-24081965@postgrespro.ru", "phone": "+70551178393"}
0005434375527	1E9AAB	6888 937271	VALENTINA YUDINA	{"phone": "+70498951213"}
0005434375528	211168	3807 759017	VERA ZHURAVLEVA	{"phone": "+70726009320"}
0005434375529	14CA4A	0054 856398	GALINA ANDREEVA	{"phone": "+70263842008"}
0005434375530	2ED8DC	5380 652304	ALEKSEY NIKITIN	{"email": "nikitin.a-031970@postgrespro.ru", "phone": "+70494161153"}
0005434375531	2218D0	4834 372103	ELENA DANILOVA	{"phone": "+70986772133"}
0005434375532	258E02	3312 505980	NADEZHDA ZAKHAROVA	{"phone": "+70080431740"}
0005434375534	C1872A	0527 938347	OLGA KONOVALOVA	{"phone": "+70458218626"}
0005434375535	9C975F	7637 596881	YANA KUZMINA	{"email": "y_kuzmina_1980@postgrespro.ru", "phone": "+70261878006"}
0005434375536	37CC7B	8544 083412	ZINAIDA GUSEVA	{"email": "zinaida-guseva-1970@postgrespro.ru", "phone": "+70846297450"}
0005434375537	73E96B	3037 239129	ALEKSANDR BONDARENKO	{"phone": "+70471748392"}
0005434375538	7C4442	0094 127665	TATYANA ZAKHAROVA	{"email": "tatyana.zakharova071962@postgrespro.ru", "phone": "+70734470512"}
0005434375539	EACF76	7772 628580	YULIYA VASILEVA	{"email": "yvasileva-02091972@postgrespro.ru", "phone": "+70511469878"}
0005434375540	BC3779	5047 890061	OLGA MASLOVA	{"email": "olga_maslova24121975@postgrespro.ru", "phone": "+70885609398"}
0005434375541	BC3779	6302 666043	YULIYA DAVYDOVA	{"email": "davydova-yuliya-081972@postgrespro.ru", "phone": "+70888899664"}
0005434375542	DAB1C0	9475 980474	ANASTASIYA VOROBEVA	{"email": "anastasiyavorobeva-08031964@postgrespro.ru", "phone": "+70472991742"}
0005434375543	9EEE96	4568 159416	YULIYA MELNIKOVA	{"phone": "+70522602889"}
0005434375544	3F1159	2255 472753	SERGEY PAVLOV	{"email": "s.pavlov_07111981@postgrespro.ru", "phone": "+70083044002"}
0005434375545	3F1159	1547 119753	EKATERINA VOLKOVA	{"email": "volkova_ekaterina_1967@postgrespro.ru", "phone": "+70555401060"}
0005434375546	481AE0	0766 010618	ANTON SEMENOV	{"email": "a_semenov-17091974@postgrespro.ru", "phone": "+70782531498"}
0005434375547	481AE0	8153 489175	GALINA SOLOVEVA	{"phone": "+70260347221"}
0005434375548	AAA2ED	5501 110878	LYUBOV ORLOVA	{"email": "orlova_lyubov28021967@postgrespro.ru", "phone": "+70031305404"}
0005434375549	B88881	3100 584327	DMITRIY SAVELEV	{"email": "savelev-dmitriy.15031984@postgrespro.ru", "phone": "+70390724052"}
0005434375550	DEF435	2074 311002	LYUBOV EFIMOVA	{"email": "efimova.lyubov.091972@postgrespro.ru", "phone": "+70763990237"}
0005434375551	DEF435	6306 135423	VLADIMIR NOVIKOV	{"email": "vladimir.novikov121978@postgrespro.ru", "phone": "+70821974850"}
0005434375552	67D71D	9163 064354	IVAN SIDOROV	{"phone": "+70851855094"}
0005434375553	2FC439	3889 727008	ELENA MAKSIMOVA	{"email": "emaksimova-22021972@postgrespro.ru", "phone": "+70099663524"}
0005434375554	2FC439	7620 620138	IVAN FILIPPOV	{"phone": "+70102004943"}
0005434375555	DF82FF	6203 832931	EVGENIY ZAYCEV	{"email": "zaycev_e1963@postgrespro.ru", "phone": "+70869727966"}
0005434375556	6BFB00	3800 036194	NATALYA KUZNECOVA	{"email": "kuznecova_n071979@postgrespro.ru", "phone": "+70697377612"}
0005434375557	6BFB00	2671 337674	TATYANA ORLOVA	{"email": "orlova_t1981@postgrespro.ru", "phone": "+70718265430"}
0005434375558	BF968A	3497 511602	NATALIYA ALEKSEEVA	{"phone": "+70138560149"}
0005434375559	9E3CEA	4896 625937	NIKOLAY ANDREEV	{"phone": "+70436482447"}
0005434375560	9E3CEA	3659 357414	KARINA NIKITINA	{"phone": "+70096799101"}
0005434375561	6C6116	2058 404013	LILIYA SAVELEVA	{"email": "l.saveleva_10031973@postgrespro.ru", "phone": "+70052543855"}
0005434375562	6C6116	1938 936607	FEDOR VASILEV	{"phone": "+70508616041"}
0005434375563	406211	3141 930635	VIKTORIYA MARTYNOVA	{"phone": "+70586524513"}
0005434375564	9DEF43	0229 950455	MARINA ZHURAVLEVA	{"email": "marina-zhuravleva_12011977@postgrespro.ru", "phone": "+70701926497"}
0005434375565	9DEF43	4074 701649	GALINA KOLESNIKOVA	{"phone": "+70312252450"}
0005434375566	467D87	3495 905315	ELENA LEBEDEVA	{"email": "lebedeva_e1980@postgrespro.ru", "phone": "+70794816062"}
0005434375567	319A36	2445 033452	IRINA KUZNECOVA	{"email": "kuznecova-i-1967@postgrespro.ru", "phone": "+70753679137"}
0005434375568	319A36	4491 628362	LYUDMILA DENISOVA	{"email": "l-denisova1971@postgrespro.ru", "phone": "+70818936707"}
0005434375569	89AFE0	8096 443130	ELENA VOLKOVA	{"email": "volkova-elena111972@postgrespro.ru", "phone": "+70441364974"}
0005434375570	BF7423	9737 072567	OLESYA EFIMOVA	{"phone": "+70629268219"}
0005434375571	088DBA	7778 693722	ANNA SMIRNOVA	{"phone": "+70614754818"}
0005434375572	088DBA	2483 418157	MAKSIM ROMANOV	{"phone": "+70055201284"}
0005434375573	2D8CAC	2436 314943	IRINA GAVRILOVA	{"email": "gavrilova-i.011968@postgrespro.ru", "phone": "+70342815142"}
0005434375574	2D8CAC	4402 649422	SALAVAT KRASNOV	{"phone": "+70145704935"}
0005434375575	7CA585	5048 638275	KSENIYA ZAKHAROVA	{"email": "zakharova_kseniya1976@postgrespro.ru", "phone": "+70324404925"}
0005434375576	2ADEBE	8818 586233	ANTON MAKAROV	{"phone": "+70289438004"}
0005434375577	1541D0	3142 559090	ANATOLIY MOISEEV	{"email": "anatoliy-moiseev-081978@postgrespro.ru", "phone": "+70438406765"}
0005434375578	98EF94	3676 084324	GRIGORIY GERASIMOV	{"phone": "+70217534453"}
0005434375579	9324C3	5793 645518	IRINA LUKYANOVA	{"phone": "+70806946242"}
0005434375580	825478	9384 707229	OLGA BELOVA	{"phone": "+70362875301"}
0005434375581	C005AB	5678 079439	ANDREY MEDVEDEV	{"email": "medvedevandrey04081965@postgrespro.ru", "phone": "+70439888755"}
0005434375582	16B42F	1782 075748	SERGEY PAVLOV	{"email": "s.pavlov.081969@postgrespro.ru", "phone": "+70784027202"}
0005434375583	1FD8AC	6484 955278	TATYANA SERGEEVA	{"phone": "+70383747363"}
0005434375584	1FD8AC	0299 963891	EKATERINA SAVELEVA	{"email": "savelevaekaterina021969@postgrespro.ru", "phone": "+70013304609"}
0005434375585	3FFDB9	7697 076246	VYACHESLAV MOROZOV	{"phone": "+70834351683"}
0005434375586	3FFDB9	7469 436040	FEDOR ANTONOV	{"phone": "+70208545554"}
0005434375587	B29230	1632 463023	EGOR ANTONOV	{"email": "e_antonov.18031970@postgrespro.ru", "phone": "+70869629884"}
0005434375588	822BE7	8601 571760	VIKTOR KOZLOV	{"phone": "+70152706197"}
0005434375700	DDDE32	1427 469815	YULIYA ILINA	{"phone": "+70763043372"}
0005434375589	BAC082	5348 772780	TIMUR ANTONOV	{"email": "timurantonov-1989@postgrespro.ru", "phone": "+70367231042"}
0005434375590	BAC082	3001 003741	PETR KUZNECOV	{"email": "petr-kuznecov_071972@postgrespro.ru", "phone": "+70312944238"}
0005434375591	F457C9	4915 545371	MIKHAIL IVANOV	{"phone": "+70600220935"}
0005434375592	87A8DE	5818 492494	SVETLANA MEDVEDEVA	{"email": "s-medvedeva-10031979@postgrespro.ru", "phone": "+70489772219"}
0005434375593	87A8DE	4095 876819	ELENA IVANOVA	{"phone": "+70887426512"}
0005434375594	1CF8F5	6734 543990	VIKTOR FILIPPOV	{"email": "viktorfilippov_17111988@postgrespro.ru", "phone": "+70360312020"}
0005434375595	AEB9C6	8894 104329	IVAN BELOV	{"email": "ivan.belov_1982@postgrespro.ru", "phone": "+70737824069"}
0005434375596	E1BA29	3104 810305	GALINA EGOROVA	{"email": "galina_egorova02051963@postgrespro.ru", "phone": "+70601516170"}
0005434375597	328E97	3431 087177	ALEKSEY SERGEEV	{"email": "sergeevaleksey.30011972@postgrespro.ru", "phone": "+70194486569"}
0005434375598	328E97	4442 187161	EVGENIYA ORLOVA	{"email": "orlova-e1975@postgrespro.ru", "phone": "+70877938282"}
0005434375599	888EB9	6626 325196	IRINA LEBEDEVA	{"phone": "+70988521584"}
0005434375600	888EB9	5098 379741	MARINA AFANASEVA	{"email": "m_afanaseva-091964@postgrespro.ru", "phone": "+70083735193"}
0005434375601	2D861C	6996 957099	MARIYA YUDINA	{"email": "yudinamariya_1974@postgrespro.ru", "phone": "+70749976018"}
0005434375602	D1D74C	6127 881864	ARINA SOLOVEVA	{"phone": "+70371609125"}
0005434375603	A56216	2239 200723	VERA AKIMOVA	{"email": "akimovav.1966@postgrespro.ru", "phone": "+70955858846"}
0005434375604	A56216	9234 403151	MIKHAIL NAUMOV	{"email": "naumov_m1969@postgrespro.ru", "phone": "+70350972738"}
0005434375605	58D28F	5245 159787	ARTEM KUZNECOV	{"phone": "+70931961561"}
0005434375606	58D28F	9182 762403	OLGA KULIKOVA	{"phone": "+70249861831"}
0005434375607	3BB8D6	2967 030833	SERGEY SIDOROV	{"email": "sidorov_sergey-1977@postgrespro.ru", "phone": "+70690159783"}
0005434375608	3BB8D6	4266 718613	ALEKSEY ROMANOV	{"email": "a_romanov.1960@postgrespro.ru", "phone": "+70320746021"}
0005434375609	2521ED	1006 227347	SVETLANA MALYSHEVA	{"phone": "+70430153982"}
0005434375610	8E6ADE	2158 498573	EKATERINA DAVYDOVA	{"email": "davydova-e.081978@postgrespro.ru", "phone": "+70913898556"}
0005434375611	8E6ADE	6012 622175	GALINA MAKAROVA	{"email": "g_makarova-03041970@postgrespro.ru", "phone": "+70550528832"}
0005434375612	EADC2D	2391 569781	ANATOLIY VASILEV	{"phone": "+70353175234"}
0005434375613	541573	0784 034975	VERONIKA ILINA	{"email": "v-ilina.051973@postgrespro.ru", "phone": "+70152606528"}
0005434375614	541573	1085 039420	SERGEY MOROZOV	{"phone": "+70197570566"}
0005434375615	541573	6078 007932	ARTEM GRIGOREV	{"phone": "+70549834892"}
0005434375616	E8EF2E	8834 084356	ALINA ALEKSANDROVA	{"email": "a.aleksandrova-071976@postgrespro.ru", "phone": "+70835716237"}
0005434375617	30FEFE	7063 659658	EKATERINA DMITRIEVA	{"phone": "+70431635768"}
0005434375618	274D7A	4527 068140	VLADIMIR KULIKOV	{"email": "kulikovv_31081965@postgrespro.ru", "phone": "+70870761548"}
0005434375619	782150	7869 172847	VADIM NIKOLAEV	{"email": "nikolaev_v_1973@postgrespro.ru", "phone": "+70025002960"}
0005434375620	630982	5047 688775	OLGA KRASNOVA	{"phone": "+70473048699"}
0005434375621	C04EA2	1154 188608	ANATOLIY IVANOV	{"email": "ivanov.a.061961@postgrespro.ru", "phone": "+70432954294"}
0005434375622	0A13B3	1604 231502	LYUBOV SOROKINA	{"email": "sorokina-lyubov.1981@postgrespro.ru", "phone": "+70838873687"}
0005434375623	511EB4	1898 971814	ALEKSEY PETROV	{"phone": "+70851253800"}
0005434375624	E543CD	9318 700411	TATYANA MARTYNOVA	{"phone": "+70510865776"}
0005434375625	0B007D	4710 113904	SVETLANA ANDREEVA	{"phone": "+70062859062"}
0005434375626	5617B0	9901 977936	VLADIMIR MAKAROV	{"email": "makarovvladimir.091975@postgrespro.ru", "phone": "+70785933170"}
0005434375627	BBDF00	7742 576738	MARINA MIRONOVA	{"phone": "+70104066080"}
0005434375628	BBDF00	7745 554556	STEPAN MATVEEV	{"email": "matveev-stepan1978@postgrespro.ru", "phone": "+70568436186"}
0005434375629	28B71B	9018 714888	MAKSIM RODIONOV	{"email": "maksim-rodionov_1982@postgrespro.ru", "phone": "+70373534901"}
0005434375630	7FF2EC	2255 797274	IGOR TARASOV	{"phone": "+70028816804"}
0005434375631	249A93	4607 309608	LYUBOV FEDOROVA	{"email": "fedorova-lyubov_25051966@postgrespro.ru", "phone": "+70741346822"}
0005434375632	1B93FD	3461 456516	GALINA KONDRATEVA	{"email": "g-kondrateva081974@postgrespro.ru", "phone": "+70612400434"}
0005434375633	A058CC	4876 503510	ELIZAVETA KOROLEVA	{"phone": "+70049174676"}
0005434375634	C9F1F7	1391 191513	YULIYA NAZAROVA	{"email": "yuliya.nazarova-071981@postgrespro.ru", "phone": "+70954066011"}
0005434375635	8EC83E	8076 150682	NADEZHDA ANDREEVA	{"phone": "+70237883736"}
0005434375636	F896C3	5935 377795	YULIYA VLASOVA	{"phone": "+70049094682"}
0005434375637	8F5670	2696 936571	DENIS SIDOROV	{"phone": "+70458524544"}
0005434375638	8F5670	5949 851389	ANNA SEMENOVA	{"phone": "+70047536968"}
0005434375639	8F5670	5424 746201	ANDREY ISAEV	{"phone": "+70441627612"}
0005434375640	8F5670	8413 317075	ANATOLIY POPOV	{"email": "popov_anatoliy-061969@postgrespro.ru", "phone": "+70386621270"}
0005434375641	4260C9	6008 193967	VERA DAVYDOVA	{"email": "vera-davydova_1967@postgrespro.ru", "phone": "+70655802514"}
0005434375642	995CE6	2344 585369	VADIM ROMANOV	{"email": "vromanov.071978@postgrespro.ru", "phone": "+70745196616"}
0005434375643	05C164	2661 516844	LYUDMILA ROMANOVA	{"phone": "+70912167413"}
0005434375644	05C164	7702 283777	VALENTINA SOROKINA	{"phone": "+70443205239"}
0005434375645	05C164	4110 239482	ANDREY FEDOROV	{"email": "a_fedorov.06041964@postgrespro.ru", "phone": "+70809310377"}
0005434375646	B2E521	4083 964704	EKATERINA NIKITINA	{"phone": "+70375568789"}
0005434375647	16D0AB	9563 585647	LIDIYA NAUMOVA	{"email": "lnaumova.121967@postgrespro.ru", "phone": "+70659261580"}
0005434375648	16D0AB	9762 767656	VLADIMIR MELNIKOV	{"phone": "+70088909888"}
0005434375649	9BADA1	0841 042470	ANNA PETROVA	{"email": "anna-petrova-1968@postgrespro.ru", "phone": "+70968199161"}
0005434375650	9A03FA	2755 439325	ALEKSANDR PETROV	{"email": "aleksandr-petrov-1972@postgrespro.ru", "phone": "+70611857361"}
0005434375651	98CAC8	3784 746478	VALERIY FILIPPOV	{"email": "valeriy.filippov-28031973@postgrespro.ru", "phone": "+70614591044"}
0005434375652	D5B3B6	2080 334037	NATALIYA ANDREEVA	{"phone": "+70344369933"}
0005434375653	4D2FAB	7221 964878	DAVID KAZAKOV	{"email": "kazakov_david.1977@postgrespro.ru", "phone": "+70174988130"}
0005434375654	4D2FAB	3379 790544	OLEG MATVEEV	{"email": "matveev_o-1975@postgrespro.ru", "phone": "+70024957217"}
0005434375655	723FF5	0098 134340	VLADIMIR MOISEEV	{"email": "v-moiseev-25081975@postgrespro.ru", "phone": "+70264620155"}
0005434375656	1A0216	8716 915301	MARINA KONOVALOVA	{"email": "m_konovalova1966@postgrespro.ru", "phone": "+70573605592"}
0005434375657	52AA4E	4861 580039	NIKOLAY FEDOTOV	{"email": "n-fedotov.1963@postgrespro.ru", "phone": "+70579050544"}
0005434375658	4B309D	8930 281628	VIKTOR IVANOV	{"phone": "+70133726256"}
0005434375659	4B309D	9585 292812	VITALIY KULIKOV	{"email": "vkulikov.20021969@postgrespro.ru", "phone": "+70267601337"}
0005434375660	C88F7A	8093 949089	ANTON OSIPOV	{"phone": "+70172850878"}
0005434375661	158270	7925 232312	IRINA KOROLEVA	{"email": "korolevairina_1971@postgrespro.ru", "phone": "+70242634539"}
0005434375662	BBB947	2412 105747	VIKTOR ZAKHAROV	{"phone": "+70355778570"}
0005434375663	BBB947	3135 967738	NINA ZHURAVLEVA	{"phone": "+70802467121"}
0005434375664	08203E	9488 947111	NINA ILINA	{"email": "ilina.nina-101976@postgrespro.ru", "phone": "+70685739165"}
0005434375665	706124	0639 373908	NIKOLAY KOZLOV	{"phone": "+70352907462"}
0005434375666	BEF6BC	3662 114303	DMITRIY MEDVEDEV	{"email": "medvedevd1975@postgrespro.ru", "phone": "+70922863379"}
0005434375667	515940	4945 934041	ANNA NIKOLAEVA	{"phone": "+70329335766"}
0005434375668	4616A3	8418 612223	OLEG BORISOV	{"email": "borisov.oleg-091986@postgrespro.ru", "phone": "+70616355926"}
0005434375669	814A36	1156 262749	NIKITA ROMANOV	{"email": "romanov-nikita-1977@postgrespro.ru", "phone": "+70444895150"}
0005434375670	814A36	5227 251728	MARTA NAZAROVA	{"email": "nazarova-marta_1973@postgrespro.ru", "phone": "+70712513103"}
0005434375671	59535B	6945 859287	VASILIY YAKOVLEV	{"phone": "+70043836351"}
0005434375672	083555	8556 852137	EKATERINA FEDOROVA	{"phone": "+70326476402"}
0005434375673	85973A	3108 872772	ALEKSANDR KONOVALOV	{"email": "a-konovalov-26061978@postgrespro.ru", "phone": "+70519636294"}
0005434375674	00ED7A	3623 577351	VALENTINA MAKAROVA	{"email": "valentinamakarova-03071967@postgrespro.ru", "phone": "+70947909113"}
0005434375675	C22E6F	0317 693529	TATYANA MALYSHEVA	{"email": "malysheva_t-14061964@postgrespro.ru", "phone": "+70384781091"}
0005434375676	A4D098	4278 396902	MARIYA FEDOROVA	{"email": "m.fedorova26071968@postgrespro.ru", "phone": "+70035472167"}
0005434375677	1ECBA3	9723 664815	ALEKSANDR IVANOV	{"email": "ivanov_a1964@postgrespro.ru", "phone": "+70886383254"}
0005434375678	1ECBA3	8973 227258	VIKTORIYA VLASOVA	{"phone": "+70209688091"}
0005434375679	3680EC	1882 390899	MIKHAIL POPOV	{"phone": "+70853584174"}
0005434375680	3680EC	8659 332515	KIRILL KUZNECOV	{"phone": "+70198384111"}
0005434375681	72A20C	2848 767225	YURIY KULIKOV	{"email": "y_kulikov.24011970@postgrespro.ru", "phone": "+70866798926"}
0005434375682	812A0D	3063 267695	NINA KOLESNIKOVA	{"phone": "+70324046513"}
0005434375683	11DC6A	0077 355211	SERGEY ZAYCEV	{"email": "zaycev_s-1964@postgrespro.ru", "phone": "+70034216248"}
0005434375684	C7A96D	3200 169379	KSENIYA GAVRILOVA	{"email": "gavrilovak1982@postgrespro.ru", "phone": "+70113187094"}
0005434375685	E17923	1991 439772	ALEKSEY KOZLOV	{"phone": "+70437393063"}
0005434375686	E17923	2266 820333	EVGENIY VOLKOV	{"email": "e.volkov.061964@postgrespro.ru", "phone": "+70379528589"}
0005434375687	33D118	0864 269158	ANATOLIY MEDVEDEV	{"phone": "+70361699614"}
0005434375688	E37A8C	1033 990585	SVETLANA SIDOROVA	{"phone": "+70264384922"}
0005434375689	1DA43C	8680 979756	ANDREY STEPANOV	{"phone": "+70626676836"}
0005434375690	AEDFB6	0774 607805	MIKHAIL KISELEV	{"email": "kiselevmikhail.1981@postgrespro.ru", "phone": "+70903067323"}
0005434375691	24670A	0700 689177	VITALIY SOROKIN	{"email": "sorokinvitaliy_051976@postgrespro.ru", "phone": "+70049869953"}
0005434375692	24670A	1586 483364	ELENA SIDOROVA	{"phone": "+70560116319"}
0005434375693	9FE0FF	6076 232625	NATALIYA BELOVA	{"email": "belova_nataliya.121979@postgrespro.ru", "phone": "+70541442237"}
0005434375694	9FE0FF	7059 924768	LEONTIY NOVIKOV	{"phone": "+70440181907"}
0005434375695	3FE0AD	2233 160313	ANNA MARTYNOVA	{"email": "martynovaanna_03021976@postgrespro.ru", "phone": "+70664702191"}
0005434375696	3FE0AD	0625 214033	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey.24101974@postgrespro.ru", "phone": "+70339539272"}
0005434375697	DEF472	9372 021888	ANTON MELNIKOV	{"email": "melnikov.anton_22051973@postgrespro.ru", "phone": "+70798280797"}
0005434375698	ECC1EF	7016 994064	MAKSIM NIKOLAEV	{"email": "nikolaevm.031976@postgrespro.ru", "phone": "+70936945966"}
0005434375699	7DD59B	7843 253104	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov_051974@postgrespro.ru", "phone": "+70315511818"}
0005434375701	D7302B	5626 670581	DMITRIY KOZLOV	{"email": "dmitriy.kozlov_1984@postgrespro.ru", "phone": "+70827597272"}
0005434375702	7E6440	6343 232070	TATYANA DENISOVA	{"phone": "+70214999276"}
0005434375703	DE9B04	1995 651803	MARIYA KONOVALOVA	{"email": "konovalova.m1963@postgrespro.ru", "phone": "+70893747469"}
0005434375704	1C6A77	0108 597050	OLGA KONOVALOVA	{"email": "konovalova.olga081970@postgrespro.ru", "phone": "+70363568891"}
0005434375705	1C6A77	1390 981528	DENIS SOKOLOV	{"phone": "+70044594078"}
0005434375706	CF1BC5	0331 435497	ANNA LAZAREVA	{"email": "lazareva-anna101961@postgrespro.ru", "phone": "+70283954240"}
0005434375707	CF1BC5	4276 731534	ARTEM ZAKHAROV	{"email": "artemzakharov.05061970@postgrespro.ru", "phone": "+70061276696"}
0005434375708	CF1BC5	2836 425746	LYUBOV MAKAROVA	{"email": "makarova-lyubov-16041966@postgrespro.ru", "phone": "+70396446963"}
0005434375709	CF1BC5	3574 029976	VASILIY GRIGOREV	{"email": "grigorevv_30121970@postgrespro.ru", "phone": "+70603352006"}
0005434375710	439D75	7756 528023	NATALYA KOVALEVA	{"phone": "+70241871713"}
0005434375711	A8FE01	1936 474252	VALENTINA MOISEEVA	{"phone": "+70700146681"}
0005434375712	A1DDB9	0514 531997	VLADIMIR ZHUKOV	{"phone": "+70685258052"}
0005434375713	099E59	6483 242845	RUSLAN EGOROV	{"phone": "+70177262159"}
0005434375714	58AFD9	0693 429788	ANATOLIY STEPANOV	{"email": "anatoliy_stepanov_02101968@postgrespro.ru", "phone": "+70356871412"}
0005434375715	E9F068	3965 695227	NIKOLAY DAVYDOV	{"email": "n.davydov_101975@postgrespro.ru", "phone": "+70045893184"}
0005434375716	CA82D4	3087 284367	YURIY FEDOROV	{"phone": "+70218355626"}
0005434375717	AB83A9	0042 027609	DMITRIY SIDOROV	{"phone": "+70381501427"}
0005434375718	835548	6413 534101	NATALYA ANDREEVA	{"phone": "+70109696210"}
0005434375719	E9C936	4554 959691	MARINA NOVIKOVA	{"email": "novikova.m-01031977@postgrespro.ru", "phone": "+70655422732"}
0005434375720	E9C936	0117 563134	NINA KUZNECOVA	{"email": "nina.kuznecova-111975@postgrespro.ru", "phone": "+70168599509"}
0005434375721	6CB66F	0480 415339	NADEZHDA TARASOVA	{"email": "n-tarasova_071965@postgrespro.ru", "phone": "+70950972686"}
0005434375722	1DC414	9032 284100	VIKTOR FILIPPOV	{"email": "v-filippov26021960@postgrespro.ru", "phone": "+70645219639"}
0005434375723	1DC414	4894 911915	ANATOLIY KARPOV	{"phone": "+70854536607"}
0005434375724	F7BCF5	5595 255546	TAMARA KONOVALOVA	{"email": "t.konovalova.09011970@postgrespro.ru", "phone": "+70478548059"}
0005434375725	F7BCF5	2628 146470	ELENA NAUMOVA	{"phone": "+70388092784"}
0005434375726	C1FF3C	4607 161106	SERGEY POPOV	{"email": "sergeypopov011975@postgrespro.ru", "phone": "+70994518512"}
0005434375727	C1FF3C	4770 048448	SERGEY RODIONOV	{"email": "s_rodionov01081975@postgrespro.ru", "phone": "+70970309279"}
0005434375728	C1FF3C	5036 959206	DMITRIY SCHERBAKOV	{"email": "scherbakov.d-091976@postgrespro.ru", "phone": "+70496299910"}
0005434375729	C857A8	6601 079307	YANA FEDOROVA	{"email": "yana_fedorova.061965@postgrespro.ru", "phone": "+70600712588"}
0005434375730	C857A8	5777 374432	ALEKSEY KUZNECOV	{"email": "a-kuznecov.20031964@postgrespro.ru", "phone": "+70872242442"}
0005434375731	689043	2769 520318	SVETLANA MOISEEVA	{"phone": "+70862850729"}
0005434375732	802B13	7855 482070	TATYANA OSIPOVA	{"phone": "+70660942856"}
0005434375733	BF3A3C	3413 211019	LIDIYA FROLOVA	{"phone": "+70226798066"}
0005434375734	7B4C9B	3621 060874	RAFAIL ALEKSANDROV	{"phone": "+70788769599"}
0005434375735	B2D41B	5055 774608	VLADIMIR ANTONOV	{"email": "antonovvladimir.1974@postgrespro.ru", "phone": "+70984589488"}
0005434375736	B2D41B	2028 549522	LYUBOV SEMENOVA	{"phone": "+70971485486"}
0005434375737	B2D41B	8518 957710	GALINA GUSEVA	{"email": "g_guseva_121966@postgrespro.ru", "phone": "+70433685534"}
0005434375738	F0150F	0616 546851	OLGA DMITRIEVA	{"email": "olga.dmitrieva_051969@postgrespro.ru", "phone": "+70048795877"}
0005434375739	917715	3636 647284	MARIYA IVANOVA	{"email": "ivanova_mariya_20111972@postgrespro.ru", "phone": "+70790380585"}
0005434375740	BA53D2	4539 298721	ALEKSANDR ROMANOV	{"phone": "+70239412887"}
0005434375741	70D295	5951 475287	TAISIYA SOLOVEVA	{"phone": "+70076430349"}
0005434375742	88E661	8283 217835	TATYANA POPOVA	{"email": "popovatatyana011987@postgrespro.ru", "phone": "+70274819748"}
0005434375743	648552	9851 210657	VALERIY PAVLOV	{"phone": "+70200739972"}
0005434375744	35C90B	0307 324975	SERGEY SEMENOV	{"email": "ssemenov-23101970@postgrespro.ru", "phone": "+70044126764"}
0005434375745	61F36F	0822 190842	SERGEY SERGEEV	{"email": "sergey.sergeev091968@postgrespro.ru", "phone": "+70477554509"}
0005434375746	557ADF	5425 712626	NIKOLAY AFANASEV	{"email": "afanasev.n_031974@postgrespro.ru", "phone": "+70346814423"}
0005434375747	793CF7	3263 763474	DENIS VLASOV	{"email": "vlasovdenis_071965@postgrespro.ru", "phone": "+70633389880"}
0005434375748	919854	7853 587557	VASILIY AFANASEV	{"phone": "+70184140573"}
0005434375749	82DF60	8750 497669	SVETLANA BELOVA	{"phone": "+70173334670"}
0005434375750	8D14FF	6464 142966	VALENTINA POPOVA	{"phone": "+70636326983"}
0005434375751	8D14FF	7425 684424	TATYANA BORISOVA	{"phone": "+70982297443"}
0005434375752	28FE59	1825 987212	IVAN BONDARENKO	{"phone": "+70756306978"}
0005434375753	28FE59	2273 756631	VIKTOR BARANOV	{"phone": "+70571534133"}
0005434375754	568C2B	2994 852095	VALENTINA MALYSHEVA	{"email": "v.malysheva_111970@postgrespro.ru", "phone": "+70107282936"}
0005434375755	568C2B	9000 926649	ALEKSEY NAZAROV	{"phone": "+70983171839"}
0005434375756	3CB7CD	5534 446437	ALFIYA SEMENOVA	{"email": "asemenova.121974@postgrespro.ru", "phone": "+70374514398"}
0005434375757	3CB7CD	3985 424242	MAKSIM SMIRNOV	{"phone": "+70971648305"}
0005434375758	7DB170	5204 834773	ANNA MATVEEVA	{"phone": "+70575174190"}
0005434375759	5852E1	4038 991546	ELENA SERGEEVA	{"phone": "+70571619480"}
0005434375760	58BFC1	6920 050556	ALEKSEY ZAYCEV	{"email": "a-zaycev1982@postgrespro.ru", "phone": "+70657098482"}
0005434375761	58BFC1	4943 200634	YULIYA ALEKSEEVA	{"email": "alekseeva-yuliya_21031972@postgrespro.ru", "phone": "+70544070870"}
0005434375762	B596CC	2091 963050	ALEKSANDRA KISELEVA	{"email": "kiselevaa-1962@postgrespro.ru", "phone": "+70193960589"}
0005434375763	0BE6B7	6734 303649	ELENA TITOVA	{"phone": "+70698749068"}
0005434375764	A8F915	9372 041558	NIKOLAY SMIRNOV	{"phone": "+70678266013"}
0005434375765	472369	8305 240863	TIKHON TIKHONOV	{"phone": "+70719591890"}
0005434375766	142F7A	1177 583764	MARIYA POPOVA	{"phone": "+70464467984"}
0005434375767	93056E	5296 413387	GALINA LAZAREVA	{"email": "glazareva.10071977@postgrespro.ru", "phone": "+70166480920"}
0005434375768	21181B	7434 369379	ARTUR CHERNOV	{"email": "chernov-a-30111964@postgrespro.ru", "phone": "+70217888283"}
0005434375769	21181B	8636 398830	ANATOLIY KISELEV	{"phone": "+70865608124"}
0005434375770	5F9941	8873 316604	ANATOLIY STEPANOV	{"email": "stepanovanatoliy071981@postgrespro.ru", "phone": "+70566267550"}
0005434375771	B07562	1748 814902	ALEKSEY ROMANOV	{"email": "romanov.aleksey01041961@postgrespro.ru", "phone": "+70149754889"}
0005434375772	B07562	7672 729295	IRINA LUKYANOVA	{"phone": "+70842368509"}
0005434375773	3393B4	0093 709342	TATYANA DANILOVA	{"email": "t_danilova051974@postgrespro.ru", "phone": "+70988156854"}
0005434375774	C8315F	1648 632412	NATALYA KAZAKOVA	{"phone": "+70437063036"}
0005434375775	C8315F	3056 254083	EDUARD GERASIMOV	{"phone": "+70175356399"}
0005434375776	0E2806	7958 302831	ANNA KUZNECOVA	{"phone": "+70811266280"}
0005434375777	38DAA6	6701 630853	NATALYA KUZNECOVA	{"email": "kuznecovan_1975@postgrespro.ru", "phone": "+70462458653"}
0005434375778	38DAA6	9191 274599	EVA VOROBEVA	{"email": "vorobevae-101966@postgrespro.ru", "phone": "+70333265250"}
0005434375779	0B85F3	2940 027088	MARIYA SOLOVEVA	{"email": "solovevamariya_021969@postgrespro.ru", "phone": "+70094693435"}
0005434375780	3BB57A	5909 575113	TATYANA DENISOVA	{"phone": "+70500742285"}
0005434375781	9ED8C8	0439 940360	ANNA ILINA	{"phone": "+70699855697"}
0005434375782	9ED8C8	0026 719888	MARINA LAZAREVA	{"phone": "+70137136380"}
0005434375783	9ED8C8	2123 853480	KLAVDIYA FEDOROVA	{"email": "fedorova_k11041964@postgrespro.ru", "phone": "+70337163050"}
0005434375784	E774C5	6656 049230	SERGEY ILIN	{"phone": "+70859389542"}
0005434375785	E774C5	0869 388843	OLEG KUZNECOV	{"email": "kuznecov-oleg_041977@postgrespro.ru", "phone": "+70129133485"}
0005434375786	357738	3705 177080	LARISA BELOVA	{"email": "larisa.belova21031979@postgrespro.ru", "phone": "+70848512962"}
0005434375787	357738	7014 507399	VLADIMIR KULIKOV	{"phone": "+70468449364"}
0005434375788	09B0A7	0414 792034	MURAT ABRAMOV	{"email": "mabramov-101980@postgrespro.ru", "phone": "+70765640496"}
0005434375789	B4497D	8309 436085	DANIIL STEPANOV	{"email": "d-stepanov.071974@postgrespro.ru", "phone": "+70889077907"}
0005434375790	C0314C	8421 981226	ANDREY GUSEV	{"email": "gusev_andrey_27061965@postgrespro.ru", "phone": "+70933478843"}
0005434375791	C0314C	6546 237382	DENIS NIKOLAEV	{"phone": "+70401338161"}
0005434375792	68B401	4978 561504	OLGA KARPOVA	{"email": "o-karpova28081971@postgrespro.ru", "phone": "+70889110622"}
0005434375793	ADF590	1919 307092	VALENTINA SIDOROVA	{"email": "sidorovav-23101972@postgrespro.ru", "phone": "+70543575759"}
0005434375794	93DB67	6562 055493	NATALYA MOROZOVA	{"email": "morozova-n.15101968@postgrespro.ru", "phone": "+70556760239"}
0005434375795	44CDB2	1023 449658	DENIS NIKOLAEV	{"phone": "+70258070807"}
0005434375796	BEE065	8959 110375	MIKHAIL IVANOV	{"email": "mikhail_ivanov-1977@postgrespro.ru", "phone": "+70777719627"}
0005434375797	CB5366	4292 713084	GENNADIY NAZAROV	{"email": "nazarov-gennadiy_051975@postgrespro.ru", "phone": "+70004348147"}
0005434375798	AD5476	2190 686921	MIKHAIL NAZAROV	{"phone": "+70792240358"}
0005434375799	AD5476	0756 280967	ANTONIDA NOVIKOVA	{"phone": "+70724918685"}
0005434375800	2DEF3E	9694 340280	TATYANA IVANOVA	{"email": "ivanova-tatyana011962@postgrespro.ru", "phone": "+70831266394"}
0005434375801	2AD39B	0047 964422	RINAT SMIRNOV	{"email": "rsmirnov.051978@postgrespro.ru", "phone": "+70968390318"}
0005434375802	2AD39B	3083 225095	RAISA NESTEROVA	{"email": "nesterovaraisa_1965@postgrespro.ru", "phone": "+70250302740"}
0005434375803	CF3A55	8418 484972	MAKSIM KUDRYASHOV	{"phone": "+70483216969"}
0005434375804	C81A99	0502 204834	TIMOFEY ZAKHAROV	{"phone": "+70940997467"}
0005434375805	D7EE88	3005 022800	ANNA ROMANOVA	{"email": "romanovaanna_091969@postgrespro.ru", "phone": "+70692517496"}
0005434375806	D7EE88	9886 869619	ALEKSEY PETROV	{"phone": "+70816468755"}
0005434375807	54AA2B	8936 298309	MARIYA MIKHAYLOVA	{"phone": "+70992998275"}
0005434375808	6246EA	7286 628620	LYUDMILA ABRAMOVA	{"email": "abramova-l_1968@postgrespro.ru", "phone": "+70198519920"}
0005434375809	6246EA	6044 042399	LYUDMILA IVANOVA	{"email": "ivanoval-1968@postgrespro.ru", "phone": "+70408608805"}
0005434375810	CB995A	4224 850480	VADIM ROMANOV	{"phone": "+70244764186"}
0005434375811	54A33B	9793 633086	OLGA ZAYCEVA	{"email": "o_zayceva_081971@postgrespro.ru", "phone": "+70778660397"}
0005434375812	117BFF	4649 747181	ELENA VASILEVA	{"email": "vasileva.e011972@postgrespro.ru", "phone": "+70114026559"}
0005434375813	117BFF	7988 518392	ILYA BORISOV	{"email": "ilya-borisov_1979@postgrespro.ru", "phone": "+70308012691"}
0005434375814	2CB21D	2822 327797	GALINA SERGEEVA	{"phone": "+70201731553"}
0005434375815	2CB21D	1502 054197	DMITRIY KUZNECOV	{"email": "kuznecov_d_1972@postgrespro.ru", "phone": "+70392653734"}
0005434375816	48D866	0487 523058	DANIIL OSIPOV	{"email": "osipov_daniil.1976@postgrespro.ru", "phone": "+70864763227"}
0005434375817	7302C5	4830 802399	VLADIMIR AFANASEV	{"email": "afanasev.vladimir02121964@postgrespro.ru", "phone": "+70651378093"}
0005434375818	7302C5	8586 437548	NADEZHDA FEDOROVA	{"email": "nadezhda.fedorova-02011977@postgrespro.ru", "phone": "+70631202063"}
0005434375819	7302C5	3364 861897	LYUBOV POPOVA	{"phone": "+70284934145"}
0005434375820	97D6CF	8504 858524	MARGARITA DANILOVA	{"email": "margarita.danilova.101976@postgrespro.ru", "phone": "+70737424678"}
0005434375821	F5C3E1	5540 368594	KARINA VOROBEVA	{"email": "k_vorobeva_1983@postgrespro.ru", "phone": "+70123630389"}
0005434375822	94A22A	1803 694801	SERGEY DENISOV	{"email": "denisov-sergey_071970@postgrespro.ru", "phone": "+70846065323"}
0005434375823	94A22A	0252 239669	SVETLANA STEPANOVA	{"email": "stepanova_s-26091966@postgrespro.ru", "phone": "+70688271332"}
0005434375824	94A22A	0055 482172	ALEKSANDR DMITRIEV	{"phone": "+70308389951"}
0005434375825	C26706	2660 102245	ALEKSANDR BORISOV	{"email": "aleksandr_borisov-13021971@postgrespro.ru", "phone": "+70805513436"}
0005434375826	51B8F8	3275 605020	KRISTINA MIRONOVA	{"email": "kristinamironova.1974@postgrespro.ru", "phone": "+70594424449"}
0005434375827	5E2ABF	8413 285541	ALEKSANDR ORLOV	{"email": "orlov-aleksandr.091969@postgrespro.ru", "phone": "+70156932682"}
0005434375828	5E2ABF	8140 834643	VLADIMIR FROLOV	{"phone": "+70458435905"}
0005434375829	06669E	3634 095154	VALENTINA ORLOVA	{"phone": "+70208020170"}
0005434375830	936C7F	3201 412109	VERA DENISOVA	{"email": "denisova-vera.041983@postgrespro.ru", "phone": "+70844193079"}
0005434375831	936C7F	4884 436910	OLGA OSIPOVA	{"email": "osipova_olga1967@postgrespro.ru", "phone": "+70034758844"}
0005434375832	B60A2C	3266 857659	IGOR POPOV	{"phone": "+70531697813"}
0005434375833	9A2891	2084 744752	VIKTOR TARASOV	{"phone": "+70266866658"}
0005434375834	9A2891	1625 545899	ELENA TITOVA	{"email": "e.titova-1976@postgrespro.ru", "phone": "+70809685257"}
0005434375835	75D03F	3915 013026	SERGEY NAUMOV	{"phone": "+70380337915"}
0005434375836	75D03F	2607 099018	TATYANA ERMAKOVA	{"email": "tatyana-ermakova-051976@postgrespro.ru", "phone": "+70946735990"}
0005434375837	2A1F2A	8871 009986	VIKTOR PETROV	{"phone": "+70077916610"}
0005434375838	F2E0E8	6894 456568	PAVEL OSIPOV	{"phone": "+70230670283"}
0005434375839	EA3439	4001 896459	ALEKSANDR SOKOLOV	{"phone": "+70322546327"}
0005434375840	D57E3E	5564 674020	SERGEY SEMENOV	{"email": "s.semenov25041976@postgrespro.ru", "phone": "+70789132544"}
0005434375841	0104C7	1076 514579	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr.29051969@postgrespro.ru", "phone": "+70017081217"}
0005434375842	A93C53	4197 441650	ALEKSANDR NIKOLAEV	{"email": "anikolaev051979@postgrespro.ru", "phone": "+70515226685"}
0005434375843	A93C53	9901 488758	RASHID CHERNOV	{"phone": "+70451326959"}
0005434375844	B1D844	5900 256045	NIKOLAY FEDOROV	{"email": "fedorov_n1973@postgrespro.ru", "phone": "+70512740055"}
0005434375845	3CF6DA	8308 016645	YURIY DAVYDOV	{"phone": "+70273698095"}
0005434375846	3CF6DA	3793 573938	VYACHESLAV KUZNECOV	{"email": "kuznecov.vyacheslav_24061978@postgrespro.ru", "phone": "+70022014232"}
0005434375847	605C1A	4610 007881	ZOYA MARTYNOVA	{"phone": "+70634740980"}
0005434375848	605C1A	9528 109402	ALEKSANDR KUZNECOV	{"email": "kuznecov.a1959@postgrespro.ru", "phone": "+70909032278"}
0005434375849	A085CE	6477 394774	MARIYA IVANOVA	{"phone": "+70231508069"}
0005434375850	E949A6	4434 642366	VYACHESLAV SOLOVEV	{"email": "solovev_vyacheslav041981@postgrespro.ru", "phone": "+70037745783"}
0005434375851	C26562	4156 824027	ILYA MELNIKOV	{"phone": "+70760711375"}
0005434375852	ED860C	4830 784542	GERMAN NAZAROV	{"email": "g-nazarov_12061963@postgrespro.ru", "phone": "+70058666234"}
0005434375853	5EAB97	5210 307385	TAMARA STEPANOVA	{"phone": "+70661891405"}
0005434375854	5EAB97	9502 915054	ANASTASIYA MAKAROVA	{"email": "amakarova17121979@postgrespro.ru", "phone": "+70107842215"}
0005434375855	8FD99D	7155 039738	VLADIMIR DAVYDOV	{"email": "davydov.v-15071981@postgrespro.ru", "phone": "+70034419616"}
0005434375856	9D348B	0750 930867	VALENTINA VLASOVA	{"phone": "+70988560358"}
0005434375857	F59C93	6220 076509	ANDREY KISELEV	{"email": "andrey.kiselev1966@postgrespro.ru", "phone": "+70504169963"}
0005434375858	F59C93	3232 180360	SERGEY ROMANOV	{"email": "sergey_romanov_1969@postgrespro.ru", "phone": "+70889564097"}
0005434375859	F59C93	0327 382515	ALINA NIKIFOROVA	{"email": "anikiforova-061974@postgrespro.ru", "phone": "+70273346640"}
0005434375860	ADE4E4	7024 165465	GENNADIY ZAYCEV	{"phone": "+70911497827"}
0005434375861	6D75C3	8203 497626	GALINA DENISOVA	{"email": "gdenisova-011976@postgrespro.ru", "phone": "+70166670585"}
0005434375862	6D75C3	5880 165124	KLAVDIYA KONOVALOVA	{"email": "konovalova_k.24071977@postgrespro.ru", "phone": "+70648549773"}
0005434375863	2FAF58	2704 234620	VASILIY NIKITIN	{"phone": "+70414330098"}
0005434375864	2FAF58	8254 664988	ANTONINA BORISOVA	{"phone": "+70286654701"}
0005434375865	187014	7463 860533	NADEZHDA IVANOVA	{"email": "ivanova.nadezhda-20011977@postgrespro.ru", "phone": "+70343758962"}
0005434375866	187014	9777 985952	DARYA MELNIKOVA	{"phone": "+70816562276"}
0005434375867	2F99C3	1936 325065	VIKTOR KUZNECOV	{"email": "kuznecovv-1974@postgrespro.ru", "phone": "+70851838738"}
0005434375868	2F99C3	7379 104751	VLADIMIR ALEKSANDROV	{"email": "vladimir-aleksandrov28121979@postgrespro.ru", "phone": "+70125905716"}
0005434375869	E1BF6E	0050 104500	TATYANA FOMINA	{"email": "t.fomina_27061965@postgrespro.ru", "phone": "+70091709366"}
0005434375870	FB6278	5490 887478	TAMARA KUZNECOVA	{"email": "tamarakuznecova.21021972@postgrespro.ru", "phone": "+70144140620"}
0005434375871	11BE2E	9884 780895	MARK KONOVALOV	{"email": "markkonovalov-041967@postgrespro.ru", "phone": "+70025574755"}
0005434375872	11BE2E	8354 025230	DINA ABRAMOVA	{"email": "dina_abramova_03041964@postgrespro.ru", "phone": "+70721589251"}
0005434375873	11BE2E	7902 076974	ANDREY GRIGOREV	{"phone": "+70086217464"}
0005434375874	C7CB53	0393 902210	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_nikolay-051964@postgrespro.ru", "phone": "+70691434998"}
0005434375875	96A469	0985 761524	YULIYA MAKAROVA	{"email": "yuliyamakarova_1979@postgrespro.ru", "phone": "+70930437692"}
0005434375876	CB09B4	0573 865292	LYUDMILA POPOVA	{"phone": "+70822639607"}
0005434375877	38369D	1485 707292	ANDREY DENISOV	{"email": "andrey-denisov.031971@postgrespro.ru", "phone": "+70440425063"}
0005434375878	474259	8470 409896	LYUBOV SOROKINA	{"phone": "+70180196095"}
0005434375879	4A9B03	3363 808537	SERGEY RODIONOV	{"phone": "+70010524815"}
0005434375880	DED42A	6007 553046	ALEKSANDR IVANOV	{"phone": "+70089664151"}
0005434375881	985C19	8472 620048	ELIZAVETA MAKSIMOVA	{"phone": "+70030160746"}
0005434375882	256F70	2974 547087	IRINA YAKOVLEVA	{"phone": "+70292702544"}
0005434375883	66F70F	8718 368037	MARIYA ORLOVA	{"phone": "+70112302974"}
0005434375884	FA2F27	4291 919830	ALEKSANDR ZAKHAROV	{"phone": "+70733685583"}
0005434375885	FA2F27	3049 150190	ALEKSEY GORBUNOV	{"phone": "+70962038215"}
0005434375886	43E6D9	3582 595120	OLESYA GAVRILOVA	{"phone": "+70783551681"}
0005434375887	DB6033	9031 755476	DENIS IVANOV	{"email": "denis_ivanov-1979@postgrespro.ru", "phone": "+70906783379"}
0005434375888	B6D9DF	6378 539947	ALEKSEY SAVELEV	{"phone": "+70115702150"}
0005434375889	C066CA	1725 201133	LIDIYA POPOVA	{"phone": "+70667286024"}
0005434375890	C066CA	4839 366405	IVAN OSIPOV	{"phone": "+70765137531"}
0005434375891	D17031	8319 839575	ALEKSEY MAKSIMOV	{"email": "aleksey_maksimov-071968@postgrespro.ru", "phone": "+70153564675"}
0005434375892	D17031	4739 704450	OLEG ANTONOV	{"phone": "+70849875018"}
0005434375893	4A3994	0074 399652	MAKSIM ZAKHAROV	{"email": "maksim-zakharov-19041977@postgrespro.ru", "phone": "+70818867077"}
0005434375894	9F1E34	6388 564995	ELENA KONOVALOVA	{"phone": "+70812521778"}
0005434375895	8CAA65	5843 882524	EVGENIY BONDARENKO	{"email": "bondarenko.evgeniy-071981@postgrespro.ru", "phone": "+70964042339"}
0005434375896	C0DE24	1497 323117	GENNADIY MAKAROV	{"phone": "+70044920052"}
0005434375897	C0DE24	1194 797382	VLADISLAV MOROZOV	{"email": "morozov_v-121976@postgrespro.ru", "phone": "+70222221419"}
0005434375898	3BA217	5376 395747	TAISIYA YUDINA	{"email": "yudina.t-041971@postgrespro.ru", "phone": "+70241382609"}
0005434375899	3BA217	3618 219772	NADEZHDA SOROKINA	{"phone": "+70066659841"}
0005434375900	9F1ED1	5359 779469	MAKSIM MOROZOV	{"phone": "+70397922230"}
0005434375901	9F1ED1	3464 083751	VALERIYA GORBUNOVA	{"email": "gorbunovav.061985@postgrespro.ru", "phone": "+70480472390"}
0005434375902	4CDD3C	1800 701773	YULIYA LOGINOVA	{"phone": "+70973830843"}
0005434375903	1F7291	8967 430626	IVAN MAKAROV	{"email": "imakarov1966@postgrespro.ru", "phone": "+70410063594"}
0005434375904	DC3E35	6823 701135	VIKTORIYA PAVLOVA	{"email": "pavlova-v_02121975@postgrespro.ru", "phone": "+70212155679"}
0005434375905	B25D12	2240 238882	OKSANA DANILOVA	{"email": "o.danilova05071967@postgrespro.ru", "phone": "+70346504024"}
0005434375906	0EABDD	7344 868662	YULIYA YAKOVLEVA	{"email": "yuliya-yakovleva-14121963@postgrespro.ru", "phone": "+70185877581"}
0005434375907	D97846	8893 730857	NATALYA SOLOVEVA	{"phone": "+70501580170"}
0005434375908	2409C8	9155 500637	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin.23051959@postgrespro.ru", "phone": "+70179497278"}
0005434375909	2409C8	7820 933597	ZINAIDA VOLKOVA	{"email": "volkovaz-1952@postgrespro.ru", "phone": "+70645133588"}
0005434375910	081574	5133 118636	SERGEY NAUMOV	{"phone": "+70797698090"}
0005434375911	59F41A	4024 645824	VALENTINA ZHURAVLEVA	{"phone": "+70869041152"}
0005434375912	02F7E5	3592 093862	OKSANA ILINA	{"phone": "+70927323193"}
0005434375913	7C3B99	9695 980407	INNA BARANOVA	{"phone": "+70468764641"}
0005434375914	6071A1	5795 484612	OLGA STEPANOVA	{"email": "o-stepanova09121972@postgrespro.ru", "phone": "+70053894401"}
0005434375915	9B4F11	0947 492705	VITALIY FROLOV	{"email": "vitaliy_frolov.091970@postgrespro.ru", "phone": "+70614332890"}
0005434375916	167551	4230 019328	EVGENIY TIMOFEEV	{"email": "timofeev-evgeniy-1968@postgrespro.ru", "phone": "+70435914424"}
0005434375917	167551	6436 296701	SERGEY KISELEV	{"email": "kiselev_s091958@postgrespro.ru", "phone": "+70204514830"}
0005434375918	3F6D8E	1820 949239	OLGA KOLESNIKOVA	{"email": "olga-kolesnikova_031972@postgrespro.ru", "phone": "+70872770508"}
0005434375919	3F6D8E	4997 492122	OLGA BARANOVA	{"email": "olgabaranova1972@postgrespro.ru", "phone": "+70544913011"}
0005434375920	2EDC54	4509 938752	ILYA MATVEEV	{"phone": "+70750629390"}
0005434375921	3A5988	8765 659258	YULIYA ABRAMOVA	{"phone": "+70165957424"}
0005434375922	1AD1AA	2660 786340	VYACHESLAV KAZAKOV	{"email": "kazakov-v-051982@postgrespro.ru", "phone": "+70461638069"}
0005434375923	7A8880	7341 437179	ANASTASIYA ANTONOVA	{"email": "antonova-a-1974@postgrespro.ru", "phone": "+70118095333"}
0005434375924	7A8880	1133 522476	SERGEY ILIN	{"phone": "+70760855757"}
0005434375925	EBCE3D	9079 093032	EKATERINA MIRONOVA	{"email": "ekaterina_mironova24051980@postgrespro.ru", "phone": "+70599186233"}
0005434375926	EBCE3D	6231 798772	KIRILL EGOROV	{"email": "kirillegorov.1971@postgrespro.ru", "phone": "+70477383988"}
0005434375927	B2826F	9944 424684	LYUDMILA PETROVA	{"email": "petrova_lyudmila.1968@postgrespro.ru", "phone": "+70384605396"}
0005434375928	B2826F	6093 945550	VALENTINA BORISOVA	{"phone": "+70914528998"}
0005434375929	D6C356	0211 909136	EVDOKIYA MELNIKOVA	{"email": "evdokiya-melnikova24081973@postgrespro.ru", "phone": "+70914549094"}
0005434375930	D6C356	4377 078429	ARTUR ALEKSEEV	{"email": "alekseev_artur.1967@postgrespro.ru", "phone": "+70661904412"}
0005434375931	D3461C	5165 029957	ALEKSANDR ANDREEV	{"phone": "+70736584482"}
0005434375932	D3461C	1194 824045	MARINA NIKITINA	{"email": "mnikitina17021970@postgrespro.ru", "phone": "+70745285694"}
0005434375933	2FB503	6033 764629	ILDAR NIKOLAEV	{"email": "nikolaev.i_071971@postgrespro.ru", "phone": "+70230636589"}
0005434375934	2FB503	4042 458127	LYUBOV ZAYCEVA	{"phone": "+70994712121"}
0005434375935	BFEB2C	2950 805651	ALEKSANDR GAVRILOV	{"phone": "+70067112553"}
0005434375936	54306F	6115 731887	MAKSIM NIKOLAEV	{"email": "maksimnikolaev.081977@postgrespro.ru", "phone": "+70209999547"}
0005434375937	F92007	9680 674750	LYUDMILA SERGEEVA	{"email": "sergeeva_l-031976@postgrespro.ru", "phone": "+70957960979"}
0005434375938	4EAD2D	2220 315234	PETR AFANASEV	{"email": "petr_afanasev-1967@postgrespro.ru", "phone": "+70703535743"}
0005434375939	4EAD2D	0911 877494	LILIYA KAZAKOVA	{"phone": "+70080895924"}
0005434375940	9F4C2C	9694 914798	VALERIY PAVLOV	{"phone": "+70693228723"}
0005434375941	022763	1369 389830	ANASTASIYA PETROVA	{"email": "anastasiyapetrova-1965@postgrespro.ru", "phone": "+70666580081"}
0005434375942	F19BF3	3099 846166	DMITRIY KUZNECOV	{"email": "d.kuznecov.1965@postgrespro.ru", "phone": "+70024599247"}
0005434375943	F19BF3	0560 580049	IGOR DMITRIEV	{"phone": "+70449805728"}
0005434375944	8664E9	3128 471300	ANASTASIYA BARANOVA	{"phone": "+70827496722"}
0005434375945	C19ECC	1590 068837	ANDREY TIKHONOV	{"phone": "+70001945049"}
0005434375946	C0934F	5673 309341	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey_24081971@postgrespro.ru", "phone": "+70252880258"}
0005434375947	C0934F	3795 125364	VENERA NIKOLAEVA	{"phone": "+70788911047"}
0005434375948	C6DAE4	4270 821151	IVAN ROMANOV	{"phone": "+70232831415"}
0005434375949	CB64E4	3164 235436	ANDREY ILIN	{"email": "ilin.andrey25041978@postgrespro.ru", "phone": "+70336341653"}
0005434375950	5B5436	6530 188525	SVETLANA KARPOVA	{"email": "svetlana-karpova1976@postgrespro.ru", "phone": "+70606763704"}
0005434375951	507274	8929 774314	EVGENIY SEMENOV	{"email": "semenov_e1976@postgrespro.ru", "phone": "+70884354125"}
0005434375952	FE0E7A	6212 830611	ALSU KRASNOVA	{"email": "a_krasnova-1976@postgrespro.ru", "phone": "+70916898155"}
0005434375953	FE0E7A	4644 785395	ALEVTINA ERMAKOVA	{"phone": "+70899519793"}
0005434375954	15CE7F	4235 203928	ANNA SOKOLOVA	{"phone": "+70963258414"}
0005434375955	68750F	5169 777034	NINA KUZNECOVA	{"phone": "+70677142394"}
0005434375956	68750F	2126 256337	OLEG KONOVALOV	{"phone": "+70792218680"}
0005434375957	7CFEDC	5354 812510	SVETLANA ABRAMOVA	{"email": "svetlana.abramova-021979@postgrespro.ru", "phone": "+70441209895"}
0005434375958	192669	0051 881611	ANNA LEBEDEVA	{"email": "lebedeva-anna06071981@postgrespro.ru", "phone": "+70657750739"}
0005434375959	7AFC63	5681 986594	OKSANA MAKSIMOVA	{"email": "oksana-maksimova-1971@postgrespro.ru", "phone": "+70664083552"}
0005434375960	EA145F	2058 004499	EVGENIYA MOISEEVA	{"email": "e_moiseeva.20041966@postgrespro.ru", "phone": "+70314883662"}
0005434375961	EA145F	5694 461841	DANIIL NAUMOV	{"phone": "+70181758186"}
0005434375962	8BD3DE	6605 522291	VLADIMIR BORISOV	{"email": "borisovvladimir_091985@postgrespro.ru", "phone": "+70400085123"}
0005434375963	8BD3DE	2540 579692	VERA TIMOFEEVA	{"phone": "+70569841846"}
0005434375964	AA8ACE	4966 273651	NIKOLAY KOROLEV	{"email": "n-korolev.1973@postgrespro.ru", "phone": "+70352753804"}
0005434375965	AA8ACE	2157 411642	ELENA POPOVA	{"email": "popova.e1985@postgrespro.ru", "phone": "+70263729784"}
0005434375966	EF7F3E	4780 311085	ROZA AFANASEVA	{"phone": "+70631321772"}
0005434375967	F67F38	4339 196772	ANDREY SIDOROV	{"phone": "+70289324079"}
0005434375968	F67F38	9823 366554	VLADIMIR FEDOROV	{"phone": "+70272697034"}
0005434375969	29C8BE	2873 550396	ALLA IVANOVA	{"email": "ivanovaalla-041974@postgrespro.ru", "phone": "+70335724246"}
0005434375970	29C8BE	3052 017517	ANDREY NOVIKOV	{"email": "anovikov07051961@postgrespro.ru", "phone": "+70401719399"}
0005434375971	4F1723	9506 591126	ALENA KONOVALOVA	{"phone": "+70304860004"}
0005434375972	4F1723	1951 012633	MAKSIM FROLOV	{"phone": "+70453400910"}
0005434375973	B1444C	4078 746645	SERGEY PETROV	{"phone": "+70766193638"}
0005434375974	1F9AA1	9689 250816	ARTUR DAVYDOV	{"email": "davydov.artur_1978@postgrespro.ru", "phone": "+70210207497"}
0005434375975	3CD3B0	8514 998080	ELENA BELOVA	{"email": "belova_elena-08041969@postgrespro.ru", "phone": "+70232809867"}
0005434375976	D181E8	9347 928274	ROSTISLAV POPOV	{"phone": "+70952272695"}
0005434375977	6E8CB0	8732 921153	OLGA KOROLEVA	{"phone": "+70435789964"}
0005434375978	9A45ED	9153 575116	DENIS MEDVEDEV	{"email": "medvedevdenis20021964@postgrespro.ru", "phone": "+70860025039"}
0005434375979	DC2502	1789 858456	OLGA MAKAROVA	{"phone": "+70576174298"}
0005434375980	DC2502	3670 323449	ANASTASIYA MOISEEVA	{"phone": "+70548113910"}
0005434375981	B6A564	6229 225442	NADEZHDA ANDREEVA	{"phone": "+70228596261"}
0005434375982	4535FD	6030 897428	ANDREY IVANOV	{"phone": "+70711727432"}
0005434375983	623164	0104 714326	EVGENIY KUZMIN	{"email": "kuzmin.e_05061969@postgrespro.ru", "phone": "+70648981001"}
0005434375984	C896F5	6753 362455	MARIYA EFIMOVA	{"phone": "+70374070491"}
0005434375985	0648F6	8812 644083	VALENTINA VASILEVA	{"phone": "+70926289781"}
0005434375986	0648F6	7075 059265	GALINA NOVIKOVA	{"email": "galina-novikova24061981@postgrespro.ru", "phone": "+70682022007"}
0005434375987	0648F6	0409 488013	VIKTORIYA MATVEEVA	{"phone": "+70614945793"}
0005434375988	0BA7F5	4913 942714	SVETLANA ILINA	{"email": "s_ilina.081969@postgrespro.ru", "phone": "+70496243865"}
0005434375989	F3EABF	5500 926913	NATALYA MAKSIMOVA	{"email": "maksimova.n_1974@postgrespro.ru", "phone": "+70495505509"}
0005434375990	247C01	9142 341957	VALENTINA VLASOVA	{"phone": "+70852463689"}
0005434375991	41B320	4951 604816	DMITRIY GORBUNOV	{"phone": "+70496673131"}
0005434375992	41B320	5692 025356	EKATERINA ERMAKOVA	{"email": "ermakova-ekaterina.03031962@postgrespro.ru", "phone": "+70773450675"}
0005434375993	41B320	6559 701472	KAMIL SAVELEV	{"phone": "+70881820190"}
0005434375994	E2D813	8572 928283	ALEKSANDR DAVYDOV	{"email": "aleksandr.davydov-25011976@postgrespro.ru", "phone": "+70909293808"}
0005434375995	014056	3941 150990	ELENA KISELEVA	{"email": "kiseleva_elena-1964@postgrespro.ru", "phone": "+70955797069"}
0005434375996	2F281B	6744 416055	ELIZAVETA MOROZOVA	{"phone": "+70550766729"}
0005434375997	A908F1	4112 705425	MARIYA NAZAROVA	{"email": "nazarova-mariya081968@postgrespro.ru", "phone": "+70337035067"}
0005434375998	07E98D	2891 527420	VLADISLAV FEDOROV	{"phone": "+70112450828"}
0005434375999	B67FAE	5451 057640	VLADIMIR KISELEV	{"email": "vladimir_kiselev.18051977@postgrespro.ru", "phone": "+70352933674"}
0005434376000	B67FAE	9389 062049	NATALYA MALYSHEVA	{"phone": "+70507748662"}
0005434376001	DE86FF	8466 190963	OLGA BORISOVA	{"email": "borisova_o-041971@postgrespro.ru", "phone": "+70435065036"}
0005434376002	540A30	2312 989481	TATYANA MOISEEVA	{"email": "moiseeva_tatyana_11111975@postgrespro.ru", "phone": "+70841174556"}
0005434376003	682EBE	1424 281895	VLADIMIR FROLOV	{"phone": "+70432423206"}
0005434376004	D25052	8005 900491	ALEKSANDR KUZNECOV	{"phone": "+70582442952"}
0005434376005	D25052	7770 795986	GENNADIY ALEKSEEV	{"email": "gennadiyalekseev_1974@postgrespro.ru", "phone": "+70238952998"}
0005434376006	4CB35D	7374 534272	TATYANA ANDREEVA	{"phone": "+70589687731"}
0005434376007	08B79D	5776 932822	EVGENIYA FOMINA	{"phone": "+70195154856"}
0005434376008	B1B64F	4941 459447	ALEKSANDR IVANOV	{"phone": "+70144625580"}
0005434376009	B1B64F	9757 516282	SVETLANA EFREMOVA	{"email": "s_efremova_1980@postgrespro.ru", "phone": "+70772962822"}
0005434376010	0BBD37	2734 575716	INNA ZOTOVA	{"email": "i.zotova.111969@postgrespro.ru", "phone": "+70941990206"}
0005434376011	42A2AC	1951 179041	OKSANA PETROVA	{"email": "petrova_oksana_1972@postgrespro.ru", "phone": "+70200189872"}
0005434376012	74D5D2	9799 232637	ALEKSANDR KOZLOV	{"email": "kozlov.a-1971@postgrespro.ru", "phone": "+70958665806"}
0005434376013	0E1039	1070 486611	ANNA BELYAEVA	{"email": "a_belyaeva-021976@postgrespro.ru", "phone": "+70297422013"}
0005434376014	620426	1881 161475	NATALIYA AFANASEVA	{"phone": "+70181192331"}
0005434376015	BB8DF0	7058 415556	VLADIMIR MAKAROV	{"email": "makarov.v-121975@postgrespro.ru", "phone": "+70021355795"}
0005434376016	4F7FEC	6157 809977	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr011971@postgrespro.ru", "phone": "+70402703391"}
0005434376017	2F5E6E	6844 949600	VALENTINA SIDOROVA	{"email": "v_sidorova.05121964@postgrespro.ru", "phone": "+70247461820"}
0005434376018	B2838C	3476 022445	NATALYA EFIMOVA	{"phone": "+70401776968"}
0005434376019	85C90B	7616 698514	OLGA YAKOVLEVA	{"email": "olga_yakovleva.021969@postgrespro.ru", "phone": "+70953898554"}
0005434376020	E00E13	6937 737397	IGOR GORBUNOV	{"email": "gorbunov_i041978@postgrespro.ru", "phone": "+70553996233"}
0005434376021	D8F69E	9918 115980	GRIGORIY NIKITIN	{"email": "nikitin-grigoriy-071972@postgrespro.ru", "phone": "+70350343506"}
0005434376022	D8F69E	4302 362035	OLESYA KALININA	{"phone": "+70666732032"}
0005434376023	D37DA9	5151 676340	SVETLANA SMIRNOVA	{"phone": "+70835556744"}
0005434376024	D37DA9	9738 998026	VALENTIN SHEVCHENKO	{"phone": "+70401752667"}
0005434376025	303440	1068 843947	GALINA KRASNOVA	{"phone": "+70413054826"}
0005434376026	212586	2799 014992	NIKOLAY VOLKOV	{"email": "nikolayvolkov-1969@postgrespro.ru", "phone": "+70494930546"}
0005434376027	212586	2136 746390	LEONID ROMANOV	{"email": "romanov-leonid21061978@postgrespro.ru", "phone": "+70314742732"}
0005434376028	C0C904	4471 686280	NINA KRASNOVA	{"email": "n.krasnova-1983@postgrespro.ru", "phone": "+70517575264"}
0005434376029	C0C904	8026 343821	DENIS ILIN	{"email": "denis.ilin_1964@postgrespro.ru", "phone": "+70135646831"}
0005434376030	BB3259	4109 861404	ANDREY STEPANOV	{"phone": "+70410757367"}
0005434376031	BB3259	4985 435097	MAKSIM KONOVALOV	{"email": "mkonovalov_041973@postgrespro.ru", "phone": "+70886102762"}
0005434376032	C0CA0A	9184 803669	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr-14111988@postgrespro.ru", "phone": "+70824373179"}
0005434376033	13081C	2731 057365	DANIIL MIRONOV	{"email": "daniil-mironov20061978@postgrespro.ru", "phone": "+70317364226"}
0005434376034	DF7228	7812 761583	TATYANA GERASIMOVA	{"email": "t_gerasimova_101968@postgrespro.ru", "phone": "+70344877510"}
0005434376035	4F1844	6262 020749	YULIYA ZAYCEVA	{"phone": "+70064490653"}
0005434376036	4F1844	2759 528007	ANTON PAVLOV	{"email": "pavlov_anton071969@postgrespro.ru", "phone": "+70250520232"}
0005434376037	4F1844	7528 111087	MARINA ILINA	{"phone": "+70109819745"}
0005434376038	D5FD2E	6106 037676	ALEKSANDR SAVELEV	{"phone": "+70074531440"}
0005434376039	3E50DB	6907 195957	ALEKSEY ZAKHAROV	{"email": "zakharov-a_1978@postgrespro.ru", "phone": "+70682723903"}
0005434376040	3E50DB	1356 478536	MARINA KUZNECOVA	{"email": "m_kuznecova_1978@postgrespro.ru", "phone": "+70656613763"}
0005434376041	3E50DB	3305 393088	MAKSIM SCHERBAKOV	{"phone": "+70700486170"}
0005434376042	9C32FA	9911 275828	ANNA STEPANOVA	{"phone": "+70317962182"}
0005434376043	BC72E4	6791 068067	VASILIY ANDREEV	{"phone": "+70483485384"}
0005434376044	BC72E4	3878 759679	MIKHAIL YAKOVLEV	{"phone": "+70046931954"}
0005434376045	6D0218	8079 673549	KRISTINA BELOVA	{"email": "belova.k-1976@postgrespro.ru", "phone": "+70221315295"}
0005434376046	6D0218	7765 752193	NADEZHDA NIKITINA	{"email": "n_nikitina28051967@postgrespro.ru", "phone": "+70108464208"}
0005434376047	06825E	3418 116241	IGOR KISELEV	{"phone": "+70305471240"}
0005434376048	18D9F3	9335 058725	ROMAN MAKSIMOV	{"phone": "+70905904258"}
0005434376049	18D9F3	7083 166542	ANATOLIY POPOV	{"phone": "+70175937820"}
0005434376050	ABBD9A	9370 809015	GULNARA GUSEVA	{"email": "guseva.g.20121970@postgrespro.ru", "phone": "+70463494410"}
0005434376051	85032B	1071 629328	YAKOV KUZNECOV	{"email": "ykuznecov.13091979@postgrespro.ru", "phone": "+70746417163"}
0005434376052	63BEEC	3439 848223	NADEZHDA BELOVA	{"email": "nadezhda_belova-011973@postgrespro.ru", "phone": "+70383664005"}
0005434376053	0B826C	4822 447488	OLEG VASILEV	{"phone": "+70414497615"}
0005434376054	9F6E7F	9502 220588	ALEKSANDRA MAKAROVA	{"email": "a-makarova_1983@postgrespro.ru", "phone": "+70183034556"}
0005434376055	9F6E7F	6126 622188	KLAVDIYA TARASOVA	{"phone": "+70845240984"}
0005434376056	552B54	5584 980458	TATYANA MIRONOVA	{"phone": "+70782377660"}
0005434376057	6E971C	9916 637265	ANATOLIY TARASOV	{"phone": "+70538762814"}
0005434376058	6E971C	9138 931774	EVGENIY TARASOV	{"phone": "+70313905332"}
0005434376059	B6FFF6	8625 084807	ANNA MAKAROVA	{"email": "anna-makarova18011972@postgrespro.ru", "phone": "+70580975419"}
0005434376060	B6FFF6	3976 715879	ANNA PAVLOVA	{"email": "pavlova-a091975@postgrespro.ru", "phone": "+70323247002"}
0005434376061	B6FFF6	4896 252203	IGOR DMITRIEV	{"email": "igordmitriev.12041969@postgrespro.ru", "phone": "+70389011084"}
0005434376062	17B66D	4116 243206	TATYANA ROMANOVA	{"email": "tatyana.romanova-19031970@postgrespro.ru", "phone": "+70593637441"}
0005434376063	C1F44D	8730 673260	DMITRIY IVANOV	{"email": "d_ivanov_15121973@postgrespro.ru", "phone": "+70718840133"}
0005434376064	87871B	6960 372689	EVA SERGEEVA	{"phone": "+70551799390"}
0005434376065	AF5D77	5395 941841	TAMARA EGOROVA	{"email": "t.egorova1968@postgrespro.ru", "phone": "+70052826651"}
0005434376066	D15FC8	2252 098075	EGOR SMIRNOV	{"phone": "+70917775782"}
0005434376067	402952	3055 185493	VLADIMIR ISAEV	{"phone": "+70720369744"}
0005434376068	402952	7127 094066	NIKOLAY FOMIN	{"email": "fomin.n_14021972@postgrespro.ru", "phone": "+70768817764"}
0005434376069	FEB12B	0755 969972	VLADIMIR VASILEV	{"email": "vasilevv_1967@postgrespro.ru", "phone": "+70343865611"}
0005434376070	FEB12B	2303 025678	OLESYA SAVELEVA	{"phone": "+70318748845"}
0005434376071	FEB12B	2634 392285	ANNA POPOVA	{"email": "popova_a-22031970@postgrespro.ru", "phone": "+70003842867"}
0005434376072	61E5B1	2575 224625	TATYANA KUZNECOVA	{"phone": "+70342830768"}
0005434376159	79751A	5317 612631	TATYANA NESTEROVA	{"email": "nesterova_tatyana-15031965@postgrespro.ru", "phone": "+70103478468"}
0005434376160	0A9112	7803 671600	YURIY BORISOV	{"email": "yborisov.06121969@postgrespro.ru", "phone": "+70348586440"}
0005434376161	3A996A	5814 936885	LYUDMILA ZHURAVLEVA	{"phone": "+70406538738"}
0005434376162	80A07F	2219 434660	MARIYA KAZAKOVA	{"email": "kazakova-m-1969@postgrespro.ru", "phone": "+70928537003"}
0005434376163	80A07F	9421 380319	ALEKSANDRA STEPANOVA	{"email": "a_stepanova03121979@postgrespro.ru", "phone": "+70154301378"}
0005434376164	E6470B	4774 446714	LYUBOV LOGINOVA	{"email": "lloginova.1970@postgrespro.ru", "phone": "+70115844227"}
0005434376165	DC73B7	5749 579735	SVETLANA LAZAREVA	{"phone": "+70596429667"}
0005434376166	6E86E9	2411 503004	GRIGORIY BONDARENKO	{"email": "g.bondarenko-26091966@postgrespro.ru", "phone": "+70230305543"}
0005434376167	99B79C	7743 771597	ANDREY ANDREEV	{"email": "aandreev.27071970@postgrespro.ru", "phone": "+70605897216"}
0005434376168	EDB9A9	0705 410800	PAVEL SERGEEV	{"phone": "+70015244016"}
0005434376169	CD69E4	3861 325278	VLADIMIR ZAKHAROV	{"phone": "+70594595669"}
0005434376170	F247D7	3179 280263	GALINA TIMOFEEVA	{"email": "timofeevagalina071972@postgrespro.ru", "phone": "+70955172537"}
0005434376171	F247D7	0939 826447	IGOR SOROKIN	{"email": "sorokin_i091978@postgrespro.ru", "phone": "+70361487496"}
0005434376178	7F726E	7071 802407	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey-1959@postgrespro.ru", "phone": "+70898126311"}
0005434376179	7F726E	1462 823368	ANATOLIY KAZAKOV	{"email": "kazakovanatoliy-1972@postgrespro.ru", "phone": "+70842516635"}
0005434376180	787DED	4937 788330	IGOR KUZMIN	{"email": "kuzmin-i-011967@postgrespro.ru", "phone": "+70470172982"}
0005434376181	787DED	3720 976031	NIKOLAY NOVIKOV	{"email": "nikolay-novikov1980@postgrespro.ru", "phone": "+70937965836"}
0005434376182	31F3E8	4276 092790	VIKTOR FROLOV	{"email": "frolov.viktor-101963@postgrespro.ru", "phone": "+70629952800"}
0005434376183	81145F	5983 048047	VERA STEPANOVA	{"email": "v-stepanova.101969@postgrespro.ru", "phone": "+70038346908"}
0005434376184	77C06D	9234 870332	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva.l.20031972@postgrespro.ru", "phone": "+70739040995"}
0005434376185	9F95DF	1264 108048	VYACHESLAV GORBUNOV	{"phone": "+70503281587"}
0005434376186	2F3E4B	6556 949092	TATYANA YAKOVLEVA	{"email": "yakovleva_t.091973@postgrespro.ru", "phone": "+70590748747"}
0005434376187	91D6E8	2777 183814	ELENA MEDVEDEVA	{"email": "emedvedeva061960@postgrespro.ru", "phone": "+70349880005"}
0005434406674	ADF2DD	0725 624244	ALEKSEY KONOVALOV	{"phone": "+70072692379"}
0005434376188	E673D7	1721 981681	VITALIY ORLOV	{"email": "vitaliy_orlov.101975@postgrespro.ru", "phone": "+70328177903"}
0005434376189	188952	3029 964159	ALEKSANDRA GAVRILOVA	{"email": "aleksandra.gavrilova-091980@postgrespro.ru", "phone": "+70686111144"}
0005434376190	F72310	2316 650541	YANA KAZAKOVA	{"phone": "+70474247024"}
0005434376191	036E60	7248 516521	ALEKSANDR BELOV	{"email": "belov-aleksandr_1969@postgrespro.ru", "phone": "+70203576842"}
0005434376223	3DA14C	6924 301237	MIKHAIL RODIONOV	{"phone": "+70381481801"}
0005434376224	8CC65A	1240 050326	ANDREY MAKSIMOV	{"email": "andrey-maksimov-121965@postgrespro.ru", "phone": "+70928979992"}
0005434376225	707586	3908 171145	RAMIL ABRAMOV	{"email": "abramovramil-1979@postgrespro.ru", "phone": "+70594271457"}
0005434376226	8F2E99	4504 596518	TATYANA SIDOROVA	{"phone": "+70479037934"}
0005434376227	8F2E99	9486 186605	VITALIY NIKITIN	{"email": "vitaliy-nikitin-051976@postgrespro.ru", "phone": "+70286685097"}
0005434376228	2367FF	2080 280556	LYUDMILA GERASIMOVA	{"email": "lyudmila.gerasimova_16031974@postgrespro.ru", "phone": "+70830140949"}
0005434376229	2367FF	3090 649483	MIKHAIL ZAYCEV	{"email": "m_zaycev_101965@postgrespro.ru", "phone": "+70506727922"}
0005434376230	D24F75	6962 540607	ELENA NIKITINA	{"email": "nikitinaelena.01071970@postgrespro.ru", "phone": "+70337641762"}
0005434376231	3E7980	8507 935108	OLGA NESTEROVA	{"phone": "+70623528316"}
0005434376232	36C40D	0929 793403	VALERIY KOROLEV	{"email": "korolevv_1974@postgrespro.ru", "phone": "+70114013022"}
0005434376233	442ED0	3980 104701	ALEKSANDR BELOV	{"email": "a-belov-021978@postgrespro.ru", "phone": "+70107525832"}
0005434376234	442ED0	2362 762452	ANDREY DMITRIEV	{"email": "dmitriev.andrey.23121968@postgrespro.ru", "phone": "+70755333472"}
0005434376235	9D947C	0737 242111	ANDREY ROMANOV	{"email": "romanova.07121955@postgrespro.ru", "phone": "+70288441423"}
0005434376236	220A47	7199 776968	LIDIYA FROLOVA	{"email": "frolova.l_031974@postgrespro.ru", "phone": "+70638819490"}
0005434376237	FFC79E	1044 804339	LYUBOV ALEKSANDROVA	{"phone": "+70736366996"}
0005434376238	FFC79E	8184 888987	MIKHAIL IVANOV	{"email": "mikhail-ivanov_13101975@postgrespro.ru", "phone": "+70646423640"}
0005434376239	FFC79E	4639 452367	ZOYA ANDREEVA	{"email": "z-andreeva-26051964@postgrespro.ru", "phone": "+70306475116"}
0005434406648	397404	2077 899436	KSENIYA BELOVA	{"phone": "+70261118725"}
0005434406672	0E2290	5970 570358	SERGEY NOVIKOV	{"phone": "+70392279173"}
0005434406639	FDDC28	5285 163481	ALEKSANDRA ANDREEVA	{"email": "a-andreeva031979@postgrespro.ru", "phone": "+70259570564"}
0005434406640	54D4FE	6204 291162	ELENA LUKYANOVA	{"email": "elena-lukyanova-031981@postgrespro.ru", "phone": "+70542779493"}
0005434406641	81812D	5946 459872	TATYANA FEDOROVA	{"email": "fedorova-t_1957@postgrespro.ru", "phone": "+70932271359"}
0005434406642	F703D4	9620 460813	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr.29121976@postgrespro.ru", "phone": "+70845391386"}
0005434406643	74C3D9	8192 495417	ALEKSANDRA SOROKINA	{"email": "asorokina121975@postgrespro.ru", "phone": "+70902020107"}
0005434406644	74C3D9	6579 183782	ALEKSEY BONDARENKO	{"email": "aleksey.bondarenko_11111973@postgrespro.ru", "phone": "+70225270047"}
0005434406645	635419	7497 086878	ERIK NOVIKOV	{"phone": "+70269075601"}
0005434406646	225235	9352 670449	TATYANA NIKOLAEVA	{"email": "nikolaeva-t.22101972@postgrespro.ru", "phone": "+70139488661"}
0005434406647	250FEC	6544 943515	ALEKSEY NIKOLAEV	{"phone": "+70199833047"}
0005434406649	C213FB	0929 916252	VIKTORIYA ILINA	{"email": "ilinaviktoriya-061978@postgrespro.ru", "phone": "+70209487604"}
0005434406650	DBD70B	1643 625129	NATALYA PETROVA	{"email": "natalya_petrova051972@postgrespro.ru", "phone": "+70513491650"}
0005434406651	466766	4955 286869	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr_1971@postgrespro.ru", "phone": "+70191939102"}
0005434406652	FBEBB2	9818 661277	MARINA MIKHAYLOVA	{"email": "marina.mikhaylova-111963@postgrespro.ru", "phone": "+70911560584"}
0005434406653	FBEBB2	7050 908757	YURIY NIKOLAEV	{"phone": "+70514426058"}
0005434406654	375FA9	1705 288024	ANDREY STEPANOV	{"phone": "+70042416668"}
0005434406655	375FA9	7188 213679	VLADIMIR MAKAROV	{"email": "v.makarov-031969@postgrespro.ru", "phone": "+70873246912"}
0005434406656	375FA9	2032 919595	AYRAT KUDRYASHOV	{"email": "kudryashovayrat.1964@postgrespro.ru", "phone": "+70334913038"}
0005434406657	4DBAA9	4756 195207	ELENA SAVELEVA	{"phone": "+70874724667"}
0005434406658	4DBAA9	7787 632339	VALERIY VOLKOV	{"email": "volkov-v051970@postgrespro.ru", "phone": "+70772996485"}
0005434406659	4DBAA9	6970 408041	TAMARA TITOVA	{"phone": "+70093157586"}
0005434406660	65D299	9466 411026	DARYA MELNIKOVA	{"phone": "+70698258713"}
0005434406661	160DEA	2366 392902	EKATERINA ISAEVA	{"email": "isaeva_e.031973@postgrespro.ru", "phone": "+70890199885"}
0005434406662	564132	7294 633866	IGOR CHERNOV	{"email": "igorchernov.21081969@postgrespro.ru", "phone": "+70067952157"}
0005434406663	564132	3987 207812	YULIYA VLASOVA	{"email": "yvlasova1974@postgrespro.ru", "phone": "+70673393763"}
0005434406664	904AEA	9652 476186	NINA ABRAMOVA	{"email": "abramova-nina-16111982@postgrespro.ru", "phone": "+70981841522"}
0005434406665	904AEA	4018 854032	ANDREY SCHERBAKOV	{"phone": "+70452538419"}
0005434406666	BB7B72	0414 352891	EVGENIYA VOLKOVA	{"phone": "+70161697208"}
0005434406667	1E031E	1924 445127	OLEG PAVLOV	{"email": "pavlov-o.07111963@postgrespro.ru", "phone": "+70548838016"}
0005434406668	1E031E	8873 321515	IVAN ZAKHAROV	{"email": "izakharov-23051979@postgrespro.ru", "phone": "+70024347987"}
0005434406669	1E031E	3008 179191	LARISA KAZAKOVA	{"email": "kazakova-l-12121961@postgrespro.ru", "phone": "+70987773882"}
0005434406670	1E031E	4110 046621	OLGA IVANOVA	{"email": "ivanova-o-021980@postgrespro.ru", "phone": "+70158554795"}
0005434406671	0E2290	8459 483812	ELENA STEPANOVA	{"email": "elena_stepanova1978@postgrespro.ru", "phone": "+70262143872"}
0005434406673	99F081	4195 837789	VALENTINA MOROZOVA	{"email": "valentina_morozova.111966@postgrespro.ru", "phone": "+70352223744"}
0005434406675	CCED38	2554 207132	LYUDMILA NAZAROVA	{"email": "nazarova_l11031969@postgrespro.ru", "phone": "+70466652218"}
0005434406676	FC29ED	5009 953840	EVGENIY BARANOV	{"phone": "+70275626311"}
0005434406677	FC29ED	8731 458784	SERGEY STEPANOV	{"email": "s.stepanov-081982@postgrespro.ru", "phone": "+70221294625"}
0005434406678	87B2D6	7138 118444	ARTEM NIKOLAEV	{"phone": "+70471925676"}
0005434406679	0CFE0B	3710 151283	VERA SAVELEVA	{"email": "v-saveleva07091971@postgrespro.ru", "phone": "+70580573145"}
0005434406680	884073	6880 843117	ALEKSANDR NAZAROV	{"email": "nazarova_031974@postgrespro.ru", "phone": "+70096562761"}
0005434406681	884073	3750 022598	SVETLANA KOROLEVA	{"email": "koroleva_s-1976@postgrespro.ru", "phone": "+70646013344"}
0005434406682	61FFCE	4639 302649	SERGEY FEDOROV	{"email": "s.fedorov051971@postgrespro.ru", "phone": "+70175396186"}
0005434406683	61FFCE	2648 097011	VYACHESLAV ANDREEV	{"phone": "+70586973443"}
0005434406684	CAB3A7	1234 541083	LYUBOV CHERNOVA	{"email": "lyubovchernova_28011979@postgrespro.ru", "phone": "+70503705566"}
0005434406685	4B4E24	0642 050377	SERGEY POPOV	{"email": "popov_sergey-21111968@postgrespro.ru", "phone": "+70098550090"}
0005434406686	95A23F	6724 693912	YURIY KRASNOV	{"phone": "+70579958022"}
0005434406687	95A23F	4870 919014	VIKTORIYA DAVYDOVA	{"phone": "+70927388993"}
0005434406688	A0D730	6910 481851	NADEZHDA MASLOVA	{"email": "maslova-nadezhda_1960@postgrespro.ru", "phone": "+70632501789"}
0005434406689	A0D730	6860 916515	OKSANA NIKITINA	{"email": "onikitina.111972@postgrespro.ru", "phone": "+70906641418"}
0005434406690	6E7584	7417 525859	ALEKSEY SOKOLOV	{"phone": "+70833448616"}
0005434406691	6E7584	1416 027992	ANGELINA PETROVA	{"email": "apetrova.1967@postgrespro.ru", "phone": "+70344376738"}
0005434406692	574B94	2275 079249	SERGEY SIDOROV	{"email": "sergeysidorov15051965@postgrespro.ru", "phone": "+70586379257"}
0005434406693	91C68D	6183 246977	VERA NESTEROVA	{"phone": "+70106509841"}
0005434406694	90D07B	0096 823423	VIKTORIYA FROLOVA	{"phone": "+70273097796"}
0005434406695	C913AE	3113 282700	VLADIMIR SOKOLOV	{"phone": "+70283244463"}
0005434406696	C913AE	1803 628641	ANATOLIY ZAYCEV	{"email": "zaycevanatoliy_23071974@postgrespro.ru", "phone": "+70015030301"}
0005434406697	F44C6C	7656 089538	ANNA KOROLEVA	{"phone": "+70270644637"}
0005434406698	F44C6C	8820 694210	LYUDMILA SERGEEVA	{"email": "l-sergeeva-031964@postgrespro.ru", "phone": "+70867581556"}
0005434406699	F44C6C	2344 817788	GENNADIY MOROZOV	{"phone": "+70717419909"}
0005434406700	CF3266	5591 303876	LYUBOV NESTEROVA	{"phone": "+70166105653"}
0005434406701	E18165	5671 750894	BORIS MAKAROV	{"email": "boris_makarov.091963@postgrespro.ru", "phone": "+70095089049"}
0005434406702	CD1500	4329 630532	ANASTASIYA EFIMOVA	{"phone": "+70447418321"}
0005434406703	920375	2494 011606	YULIYA GRISHINA	{"phone": "+70502395991"}
0005434406704	33F001	6453 408368	EVGENIY ZAYCEV	{"email": "zayceve-06021971@postgrespro.ru", "phone": "+70910564803"}
0005434406705	48CC68	2730 342233	NIKOLAY PETROV	{"email": "nikolay_petrov_081989@postgrespro.ru", "phone": "+70180758456"}
0005434406706	DD0E0F	6082 929436	VALERIY NOVIKOV	{"phone": "+70282852176"}
0005434406707	44B8A1	2481 091558	NADEZHDA ARKHIPOVA	{"email": "arkhipova-nadezhda-1983@postgrespro.ru", "phone": "+70013364088"}
0005434406708	44B8A1	8104 614162	YURIY ZAYCEV	{"phone": "+70320195465"}
0005434406709	837468	5881 850559	ALEKSEY SOKOLOV	{"email": "asokolov1976@postgrespro.ru", "phone": "+70504631353"}
0005434406710	E7BF47	4461 850841	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr.121975@postgrespro.ru", "phone": "+70884127691"}
0005434406711	9A288E	8295 391649	ALEKSEY MATVEEV	{"phone": "+70525996370"}
0005434406712	9A288E	8656 073086	GENNADIY IVANOV	{"email": "ivanovg.1965@postgrespro.ru", "phone": "+70668913175"}
0005434406713	A528BA	3816 225816	GALINA KOZLOVA	{"email": "galina.kozlova1982@postgrespro.ru", "phone": "+70558487517"}
0005434406714	550860	2290 335349	IRINA FOMINA	{"phone": "+70463333206"}
0005434406715	550860	6382 595565	ELENA KUZNECOVA	{"phone": "+70219695164"}
0005434406716	596B83	1235 123403	NATALYA KISELEVA	{"phone": "+70973714531"}
0005434406717	75955F	1137 446016	VLADIMIR KOZLOV	{"phone": "+70212284825"}
0005434406718	47B105	8586 201887	SERGEY PETROV	{"email": "petrov-s.01021984@postgrespro.ru", "phone": "+70560941596"}
0005434406719	F8E8F0	0877 455105	OLEG IVANOV	{"email": "ivanov.o.061969@postgrespro.ru", "phone": "+70575986602"}
0005434406720	E11F44	4766 878393	VALENTINA VOROBEVA	{"phone": "+70013290167"}
0005434406721	E11F44	0571 421875	RAUZA BARANOVA	{"email": "baranova-rauza-1972@postgrespro.ru", "phone": "+70602113761"}
0005434406722	8DE889	4777 373647	INNA IVANOVA	{"phone": "+70242352835"}
0005434406723	78F909	5061 794431	OLGA ANTONOVA	{"email": "olgaantonova.1977@postgrespro.ru", "phone": "+70590234440"}
0005434406724	78F909	9886 983409	EKATERINA PETROVA	{"email": "petrova-ekaterina_1974@postgrespro.ru", "phone": "+70006276111"}
0005434406725	33C409	4382 668146	ALEKSANDR ANTONOV	{"phone": "+70165035963"}
0005434406726	8D4A86	0502 053137	LILIYA MIKHAYLOVA	{"phone": "+70031700761"}
0005434406727	289895	5056 415249	TATYANA LOGINOVA	{"phone": "+70171659656"}
0005434406728	289895	4659 797809	YURIY IVANOV	{"email": "ivanovy-22091966@postgrespro.ru", "phone": "+70356477041"}
0005434406729	773AC0	0665 129619	ANASTASIYA EFREMOVA	{"phone": "+70823519192"}
0005434406730	773AC0	7687 795236	GALINA KUZMINA	{"phone": "+70854437723"}
0005434406731	3B9740	8187 594556	ILYA KUZNECOV	{"email": "kuznecov-i06091973@postgrespro.ru", "phone": "+70899611839"}
0005434406732	8781C3	2212 447220	ALEKSANDR KUZNECOV	{"phone": "+70980104872"}
0005434406733	53F4C4	2477 577543	SVETLANA BELYAEVA	{"email": "belyaeva.svetlana-041975@postgrespro.ru", "phone": "+70004370165"}
0005434406734	D6A6C9	5770 042894	VERA KOZLOVA	{"phone": "+70341304283"}
0005434406795	4EDAA3	9551 660227	DANILA SOLOVEV	{"phone": "+70271241767"}
0005434406735	D6A6C9	7751 738388	SVETLANA OSIPOVA	{"email": "svetlana-osipova-26061969@postgrespro.ru", "phone": "+70666560311"}
0005434406736	0E9C18	1595 860032	DAVID FILIPPOV	{"email": "filippovdavid_1972@postgrespro.ru", "phone": "+70854986612"}
0005434406737	5E7427	4032 141581	ANATOLIY ALEKSEEV	{"email": "a.alekseev.21031990@postgrespro.ru", "phone": "+70407572549"}
0005434406738	9C2DCA	2752 166311	ANNA ABRAMOVA	{"phone": "+70953125187"}
0005434406739	9C2DCA	4614 857056	NATALYA BORISOVA	{"phone": "+70195576944"}
0005434406740	8D7A16	7538 104085	ALEKSANDRA POPOVA	{"phone": "+70852557011"}
0005434406741	8D7A16	3239 341348	DENIS KOROLEV	{"email": "korolev_denis_1966@postgrespro.ru", "phone": "+70105290414"}
0005434406742	1DDE8D	3020 248056	NIKOLAY POPOV	{"phone": "+70843664403"}
0005434406743	0A9F8D	4123 951668	ALEKSANDR KISELEV	{"phone": "+70168987668"}
0005434406744	3EC7A5	9322 153910	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev24091967@postgrespro.ru", "phone": "+70006364995"}
0005434406745	3EC7A5	4506 401045	ILYA TIKHONOV	{"email": "tikhonov_ilya-1964@postgrespro.ru", "phone": "+70514112147"}
0005434406746	95983D	1746 896039	EGOR ALEKSEEV	{"email": "egoralekseev_1966@postgrespro.ru", "phone": "+70961273432"}
0005434406747	EA0D58	7311 695533	EVGENIY KULIKOV	{"phone": "+70240432207"}
0005434406748	E158B5	0764 090554	ANASTASIYA KRASNOVA	{"phone": "+70528389784"}
0005434406749	C84DCA	5083 504569	NATALYA KUZNECOVA	{"phone": "+70360445325"}
0005434406750	3CB701	7298 466388	ANTONINA ROMANOVA	{"email": "romanovaantonina071969@postgrespro.ru", "phone": "+70734614154"}
0005434406751	EC11A9	8483 867031	RAIL EGOROV	{"phone": "+70786376925"}
0005434406752	D83450	8938 172755	LIDIYA MOROZOVA	{"email": "lidiya-morozova-1979@postgrespro.ru", "phone": "+70756218335"}
0005434406753	D83450	3692 767210	ALEKSANDR BORISOV	{"phone": "+70949179633"}
0005434406754	3F380E	1172 387520	RAMZIYA NIKOLAEVA	{"phone": "+70644772521"}
0005434406755	84EB5B	1721 689836	MARIYA PAVLOVA	{"email": "pavlova_mariya.1963@postgrespro.ru", "phone": "+70318771805"}
0005434406756	84EB5B	8664 323262	ZINAIDA PAVLOVA	{"email": "pavlova-z-1979@postgrespro.ru", "phone": "+70907429354"}
0005434406757	84EB5B	9876 675561	SERGEY ZHUKOV	{"phone": "+70501833017"}
0005434406758	CBAB95	3462 469539	DMITRIY BORISOV	{"phone": "+70118498798"}
0005434406759	CBAB95	5383 033062	VIKTOR NIKOLAEV	{"phone": "+70677315933"}
0005434406760	802AA7	4910 185868	OKSANA BOGDANOVA	{"email": "bogdanova.o.02111973@postgrespro.ru", "phone": "+70851164555"}
0005434406761	534E0F	2444 199806	MARIYA MOROZOVA	{"email": "mmorozova-1968@postgrespro.ru", "phone": "+70452949459"}
0005434406762	534E0F	7698 733681	ANDREY STEPANOV	{"email": "stepanov.a_021979@postgrespro.ru", "phone": "+70892252546"}
0005434406763	B98BC4	5110 726397	IRINA BORISOVA	{"email": "i-borisova.051966@postgrespro.ru", "phone": "+70058468115"}
0005434406764	7E9105	8229 834743	LYUBOV FADEEVA	{"phone": "+70913338539"}
0005434406765	BBE1AC	8697 446747	NINEL PETROVA	{"phone": "+70397029821"}
0005434406766	F3CA8F	8041 849938	DIANA KARPOVA	{"email": "diana-karpova_051970@postgrespro.ru", "phone": "+70305847231"}
0005434406767	F3CA8F	1643 518382	YURIY FEDOTOV	{"email": "yuriy_fedotov101974@postgrespro.ru", "phone": "+70200142246"}
0005434406768	F3CA8F	4810 426824	DANILA FROLOV	{"email": "d_frolov-1974@postgrespro.ru", "phone": "+70178875687"}
0005434406769	4A3562	2103 140296	NINA ROMANOVA	{"email": "ninaromanova.041974@postgrespro.ru", "phone": "+70126242447"}
0005434406770	153874	3172 396893	VALENTINA KRASNOVA	{"email": "krasnova_v031965@postgrespro.ru", "phone": "+70919197676"}
0005434406771	3301D8	0704 061684	TAISIYA ILINA	{"phone": "+70852136945"}
0005434406772	3301D8	0200 453799	ANASTASIYA NIKITINA	{"phone": "+70165480546"}
0005434406773	EF1F52	6288 892591	NATALYA ANDREEVA	{"email": "natalyaandreeva.071977@postgrespro.ru", "phone": "+70550634877"}
0005434406774	F7C6F6	2806 234021	OLESYA KONOVALOVA	{"phone": "+70567367610"}
0005434406775	6979C7	8822 534437	ALEKSEY ILIN	{"phone": "+70474958086"}
0005434406776	022EE2	7875 197273	GALINA MOROZOVA	{"email": "g.morozova.1973@postgrespro.ru", "phone": "+70886012324"}
0005434406777	022EE2	0088 322766	TATYANA MAKAROVA	{"email": "makarova-tatyana_051971@postgrespro.ru", "phone": "+70612990973"}
0005434406778	022EE2	2380 005289	ANGELINA FEDOROVA	{"phone": "+70219600135"}
0005434406779	F9079A	2804 642164	SERGEY TIKHONOV	{"email": "stikhonov1979@postgrespro.ru", "phone": "+70752233135"}
0005434406780	517B5C	8552 834208	TAMARA VOLKOVA	{"phone": "+70197608660"}
0005434406781	517B5C	0110 973276	ANDREY ANDREEV	{"email": "andrey_andreev_24061983@postgrespro.ru", "phone": "+70337822030"}
0005434406782	1BEA60	9665 847015	BOGDAN ZHUKOV	{"email": "b.zhukov_03051976@postgrespro.ru", "phone": "+70017956743"}
0005434406783	335015	7956 133081	LARISA KOMAROVA	{"email": "komarovalarisa1978@postgrespro.ru", "phone": "+70125602321"}
0005434406784	335015	7878 330336	MARIYA IVANOVA	{"phone": "+70365969645"}
0005434406785	06CE33	3208 756581	LIDIYA VASILEVA	{"email": "vasileva.lidiya-22081964@postgrespro.ru", "phone": "+70369693866"}
0005434406786	5EDC9C	7167 909891	MIKHAIL SEMENOV	{"phone": "+70652187404"}
0005434406787	BC276B	7161 207135	EKATERINA SOKOLOVA	{"phone": "+70840589054"}
0005434406788	7B5CEA	2074 305744	ELENA ABRAMOVA	{"email": "abramova.e_11111967@postgrespro.ru", "phone": "+70542376480"}
0005434406789	7B5CEA	7955 469531	YULIYA NAZAROVA	{"phone": "+70061028545"}
0005434406790	A36C3A	0927 386180	RUSLAN SIDOROV	{"email": "sidorov.r.29011984@postgrespro.ru", "phone": "+70036981305"}
0005434406791	A36C3A	4147 151722	VADIM EGOROV	{"email": "egorov.v.07031965@postgrespro.ru", "phone": "+70888015379"}
0005434406792	7CD04A	9803 546974	ANNA SOROKINA	{"phone": "+70946175509"}
0005434406793	F141F7	8743 518762	VIKTOR IVANOV	{"phone": "+70713191453"}
0005434406794	075839	9427 466953	ANASTASIYA KUZNECOVA	{"phone": "+70915342522"}
0005434406796	4EDAA3	4890 361709	YANA IVANOVA	{"phone": "+70629713929"}
0005434406797	F90130	5935 654234	TATYANA FILATOVA	{"email": "filatova_t-14021970@postgrespro.ru", "phone": "+70597506055"}
0005434406798	2C185C	5316 826888	NIKOLAY POPOV	{"email": "popov-n-1978@postgrespro.ru", "phone": "+70856354656"}
0005434406799	E1E7F9	9168 557596	YULIYA ALEKSANDROVA	{"phone": "+70079724213"}
0005434406800	B5805A	3869 952930	ALEKSANDRA FROLOVA	{"phone": "+70040219371"}
0005434406801	310929	0179 663818	ANNA OSIPOVA	{"email": "osipova.a.1977@postgrespro.ru", "phone": "+70305980474"}
0005434406802	0ACCC3	7429 661718	SERGEY CHERNOV	{"phone": "+70933070241"}
0005434406803	0ACCC3	2180 171679	GALINA MALYSHEVA	{"email": "g.malysheva-091976@postgrespro.ru", "phone": "+70793466266"}
0005434406804	887709	2150 835305	LYUDMILA SAVELEVA	{"email": "lyudmila-saveleva-19081977@postgrespro.ru", "phone": "+70207557823"}
0005434406805	1D6D64	1912 774820	MARIYA ZAKHAROVA	{"email": "zakharova.m.1972@postgrespro.ru", "phone": "+70553746997"}
0005434406806	1D6D64	1736 139303	PAVEL ANTONOV	{"email": "antonov-p_1967@postgrespro.ru", "phone": "+70924976858"}
0005434406807	8899E5	9261 509432	NELLI SIDOROVA	{"phone": "+70315877300"}
0005434406808	3FE3DC	9800 584166	VIKTOR BONDARENKO	{"email": "v_bondarenko071975@postgrespro.ru", "phone": "+70006549109"}
0005434406809	80268B	0229 226364	ELENA RYABOVA	{"email": "ryabova.e-1963@postgrespro.ru", "phone": "+70754319012"}
0005434406810	E049F3	1223 725973	ARTEM MELNIKOV	{"email": "a-melnikov.18031966@postgrespro.ru", "phone": "+70742511541"}
0005434406811	33731E	4522 075157	ZOYA KARPOVA	{"phone": "+70611248508"}
0005434406812	33731E	4266 033110	VLADISLAV SMIRNOV	{"email": "smirnov.vladislav-08101974@postgrespro.ru", "phone": "+70786404954"}
0005434406813	12A0DD	1232 902595	GALINA KONDRATEVA	{"phone": "+70678224133"}
0005434406814	5DC238	4023 174457	ALEKSANDR KAZAKOV	{"email": "kazakova_22021970@postgrespro.ru", "phone": "+70631472787"}
0005434406815	28105B	9107 273836	ANDREY KUZNECOV	{"email": "andreykuznecov041972@postgrespro.ru", "phone": "+70079047152"}
0005434406816	C2B28A	3981 961897	LIDIYA SCHERBAKOVA	{"phone": "+70559493623"}
0005434406817	C2B28A	2170 927713	IRINA SIDOROVA	{"phone": "+70064030424"}
0005434406818	C2B28A	5839 357686	GENNADIY KOZLOV	{"email": "kozlov.g11101969@postgrespro.ru", "phone": "+70050754519"}
0005434406819	9DCC7C	1208 807565	SERGEY MOISEEV	{"email": "sergey_moiseev05091972@postgrespro.ru", "phone": "+70404045678"}
0005434406820	9DCC7C	6158 406353	OLGA DENISOVA	{"phone": "+70828974193"}
0005434406821	105A6E	1219 595452	VLADIMIR MEDVEDEV	{"email": "vladimirmedvedev-28041969@postgrespro.ru", "phone": "+70875472174"}
0005434406822	D8D11E	7070 248325	NIKITA TARASOV	{"phone": "+70200452485"}
0005434406823	D8D11E	7811 904611	SERGEY CHERNOV	{"email": "sergey-chernov-1971@postgrespro.ru", "phone": "+70047626691"}
0005434406824	6A74CF	8637 752523	DARYA YAKOVLEVA	{"email": "d.yakovleva03061975@postgrespro.ru", "phone": "+70176742381"}
0005434406825	8327FC	8333 535808	MARIYA MALYSHEVA	{"email": "malysheva_mariya_1975@postgrespro.ru", "phone": "+70756356798"}
0005434406826	E59922	7649 134483	STEPAN ORLOV	{"email": "stepan-orlov_101970@postgrespro.ru", "phone": "+70272337748"}
0005434406827	88FA07	7197 140032	DMITRIY FOMIN	{"email": "d.fomin.1975@postgrespro.ru", "phone": "+70594583222"}
0005434406828	7C8A8A	8647 416761	VALERIYA FROLOVA	{"phone": "+70438827098"}
0005434406829	7C8A8A	9425 416767	MARIYA YAKOVLEVA	{"phone": "+70451532507"}
0005434406830	D7A0F7	6117 220367	OLGA GRISHINA	{"phone": "+70030340117"}
0005434406831	D866E4	2477 798626	TATYANA KOROLEVA	{"phone": "+70933797158"}
0005434406832	2F77C0	8027 613857	OLGA MIKHAYLOVA	{"email": "mikhaylova_o02081982@postgrespro.ru", "phone": "+70673066752"}
0005434406833	C156EC	3184 568183	VIKTOR KARPOV	{"phone": "+70362608279"}
0005434406834	0F5D8D	3512 544336	ALEKSANDR MAKSIMOV	{"email": "a-maksimov_07061969@postgrespro.ru", "phone": "+70387019363"}
0005434406835	19FE2D	7307 124011	NATALIYA DANILOVA	{"phone": "+70057769673"}
0005434406836	8C9281	1777 759278	VIKTORIYA KOZLOVA	{"phone": "+70055124713"}
0005434406837	EB3BDD	7637 052637	ALEKSANDR MATVEEV	{"phone": "+70667672320"}
0005434406838	3C197B	4316 412023	LIDIYA MATVEEVA	{"phone": "+70270429592"}
0005434406839	FD1913	8167 709772	SANIYA MASLOVA	{"phone": "+70842053013"}
0005434406840	FD1913	1632 549751	GALINA OVCHINNIKOVA	{"email": "ovchinnikova-g.24061954@postgrespro.ru", "phone": "+70299693724"}
0005434406841	62D899	8167 220900	ALEKSANDRA KOZLOVA	{"phone": "+70166006920"}
0005434406842	BAF0BD	4794 973137	TATYANA BOGDANOVA	{"phone": "+70738144483"}
0005434406843	906DE7	6752 612282	SVETLANA NIKOLAEVA	{"phone": "+70871917349"}
0005434406844	906DE7	5118 072167	ULYANA VLASOVA	{"phone": "+70628690957"}
0005434406845	B9280E	9326 101716	ALEKSEY IVANOV	{"email": "ivanov-aleksey_011976@postgrespro.ru", "phone": "+70651986175"}
0005434406846	9129C2	7857 791433	YULIYA SERGEEVA	{"phone": "+70766329161"}
0005434406847	8F2874	7177 286035	ANDREY SOKOLOV	{"email": "sokolov.a1977@postgrespro.ru", "phone": "+70441381399"}
0005434406848	BCE207	5229 966433	VASILIY ZAKHAROV	{"email": "v_zakharov_11011968@postgrespro.ru", "phone": "+70959347912"}
0005434406849	D76A7B	7704 148160	VLADISLAV FROLOV	{"email": "v-frolov16101976@postgrespro.ru", "phone": "+70436225590"}
0005434406850	720CA3	7014 597762	NINA ANDREEVA	{"email": "andreeva_n12051973@postgrespro.ru", "phone": "+70074102565"}
0005434406851	D00BA6	1544 274233	IVAN KUDRYASHOV	{"phone": "+70361925997"}
0005434406852	D00BA6	7353 879343	TATYANA SERGEEVA	{"phone": "+70467622042"}
0005434406853	F33158	0002 978887	OLESYA KISELEVA	{"email": "kiseleva.o-1984@postgrespro.ru", "phone": "+70418580534"}
0005434406854	9A8EB3	1314 501867	INNA KUZMINA	{"email": "kuzminai051974@postgrespro.ru", "phone": "+70485872153"}
0005434406855	8D91D7	8304 472431	TAMARA IVANOVA	{"phone": "+70476910103"}
0005434406856	874542	3675 841310	LYUDMILA FEDOROVA	{"phone": "+70478106749"}
0005434406857	6D6116	5346 650112	MATVEY NAUMOV	{"email": "matvey.naumov.111962@postgrespro.ru", "phone": "+70794086573"}
0005434406858	6D6116	2242 380365	SERGEY SMIRNOV	{"email": "smirnov-s.30031982@postgrespro.ru", "phone": "+70742481983"}
0005434406859	7A2D87	1747 098971	ROZA NAZAROVA	{"phone": "+70885896346"}
0005434406860	7A2D87	6104 885361	EVGENIY MAKAROV	{"email": "makarov.e-081971@postgrespro.ru", "phone": "+70632259466"}
0005434406861	8A296F	6731 327460	OLGA NOVIKOVA	{"phone": "+70802960309"}
0005434406862	748EA7	5932 651923	DARYA KRASNOVA	{"phone": "+70875995260"}
0005434406863	FAE72F	7874 310595	EVDOKIYA NESTEROVA	{"phone": "+70820554204"}
0005434406864	A4AC81	1777 020953	ALEKSANDR VASILEV	{"phone": "+70846563468"}
0005434406865	B9D550	8206 915572	OLESYA BOGDANOVA	{"phone": "+70767066446"}
0005434406866	42F28D	0411 151247	TAMARA OVCHINNIKOVA	{"email": "t_ovchinnikova.121970@postgrespro.ru", "phone": "+70420749884"}
0005434406867	0498C2	9100 029020	ALEKSANDR EGOROV	{"email": "aegorov.04021976@postgrespro.ru", "phone": "+70861652191"}
0005434406868	5A0B95	3586 356492	DARYA MEDVEDEVA	{"email": "darya-medvedeva.021975@postgrespro.ru", "phone": "+70316813761"}
0005434406869	5A0B95	4648 207383	DMITRIY MAKSIMOV	{"email": "dmitriy_maksimov-081975@postgrespro.ru", "phone": "+70294956396"}
0005434406870	D1575E	3167 246771	ANDREY FROLOV	{"phone": "+70888927605"}
0005434406871	A8461C	5680 579164	NIKOLAY ABRAMOV	{"email": "abramov.nikolay-19101969@postgrespro.ru", "phone": "+70077532267"}
0005434406872	A8461C	3531 113869	VLADIMIR IVANOV	{"email": "ivanov_vladimir.041966@postgrespro.ru", "phone": "+70501170309"}
0005434406873	A8461C	9968 064995	ALEKSANDR ZHURAVLEV	{"phone": "+70182770531"}
0005434406874	7ADC9C	5663 470443	RINAT SCHERBAKOV	{"phone": "+70350302828"}
0005434406875	6EC66F	5886 131996	IRINA SMIRNOVA	{"phone": "+70679308976"}
0005434406876	6EC66F	4327 912129	ALEKSEY KOROLEV	{"phone": "+70919172594"}
0005434406877	87A52B	3301 754368	ZINAIDA GERASIMOVA	{"phone": "+70185176176"}
0005434406878	BD68DA	8946 272634	ELENA ANDREEVA	{"phone": "+70044937298"}
0005434406879	BD68DA	8860 241518	LIDIYA IVANOVA	{"phone": "+70257503589"}
0005434406880	16A184	3150 014274	IVAN SERGEEV	{"phone": "+70027576408"}
0005434406881	16A184	5660 213961	SERGEY KARPOV	{"phone": "+70319140562"}
0005434406882	16A184	4438 105468	ANNA ROMANOVA	{"phone": "+70217805685"}
0005434406883	BEE1D4	3373 889456	ALEKSANDR ILIN	{"phone": "+70412705374"}
0005434406884	B10BF9	9792 987344	ANDREY SEMENOV	{"phone": "+70801430093"}
0005434406885	B10BF9	5575 646270	RAMIL NAZAROV	{"phone": "+70624925013"}
0005434406886	9C8370	2670 237935	MIKHAIL IVANOV	{"email": "ivanov-mikhail1978@postgrespro.ru", "phone": "+70908696951"}
0005434406887	FA21AE	1945 628359	TATYANA KUZNECOVA	{"phone": "+70783049944"}
0005434406888	FA21AE	9398 704459	NIKITA POPOV	{"email": "nikitapopov.1971@postgrespro.ru", "phone": "+70129950284"}
0005434406889	7C8031	6389 367368	PAVEL BORISOV	{"phone": "+70902510069"}
0005434406890	59F783	0330 705628	VLADIMIR KOZLOV	{"email": "kozlov_v.011973@postgrespro.ru", "phone": "+70854420277"}
0005434406891	59F783	5020 570571	ANASTASIYA KOMAROVA	{"email": "akomarova.1975@postgrespro.ru", "phone": "+70984791619"}
0005434406892	73EF04	6435 808475	ALEKSEY GERASIMOV	{"email": "a_gerasimov_1964@postgrespro.ru", "phone": "+70775767789"}
0005434406893	DDBE78	9020 933476	NATALYA GORBUNOVA	{"phone": "+70437790133"}
0005434406894	DDBE78	3115 662954	NIKOLAY POPOV	{"email": "nikolay.popov-1988@postgrespro.ru", "phone": "+70668837710"}
0005434406895	C6CB4E	3965 019196	ANDREY DAVYDOV	{"email": "davydov-andrey-041970@postgrespro.ru", "phone": "+70592270861"}
0005434406896	70CC14	3056 540232	YULIYA MIKHAYLOVA	{"email": "mikhaylova.y051966@postgrespro.ru", "phone": "+70937009977"}
0005434406897	82FD2C	5965 001653	ILYA ROMANOV	{"email": "romanovilya_1971@postgrespro.ru", "phone": "+70985911788"}
0005434406898	82FD2C	0057 874417	ANDREY KRASNOV	{"email": "krasnov-a_091975@postgrespro.ru", "phone": "+70565096801"}
0005434406899	0CE413	6821 603842	ANTON SMIRNOV	{"email": "anton-smirnov.1981@postgrespro.ru", "phone": "+70197614531"}
0005434406900	570506	8044 381127	MIKHAIL KUZNECOV	{"phone": "+70334658194"}
0005434406901	FFD025	7953 285601	VIOLETTA AKIMOVA	{"email": "akimova.violetta-091981@postgrespro.ru", "phone": "+70686199551"}
0005434406902	C07C8C	4382 891115	ANDREY ALEKSANDROV	{"phone": "+70067500650"}
0005434406903	C07C8C	7525 637651	VLADISLAV NIKITIN	{"phone": "+70365956509"}
0005434406904	A41EC5	0856 579180	GALINA SOKOLOVA	{"email": "g_sokolova06041968@postgrespro.ru", "phone": "+70031192086"}
0005434406905	A41EC5	9752 773376	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova-1978@postgrespro.ru", "phone": "+70161650293"}
0005434406906	DA915F	0588 413773	SOFYA DAVYDOVA	{"phone": "+70131778646"}
0005434406907	DA915F	2901 565445	YULIYA SEMENOVA	{"email": "y.semenova1974@postgrespro.ru", "phone": "+70763371407"}
0005434406908	B47A55	7236 237026	KSENIYA FEDOROVA	{"phone": "+70751977981"}
0005434406909	0B232C	8109 409642	ARTEM GORBUNOV	{"phone": "+70085807920"}
0005434406910	0B232C	2787 094980	ELENA MOROZOVA	{"email": "e.morozova.021961@postgrespro.ru", "phone": "+70813572379"}
0005434406911	0B232C	9909 362153	OLGA ROMANOVA	{"phone": "+70617416067"}
0005434406912	249FD2	6048 763333	EVGENIY MOROZOV	{"phone": "+70028479405"}
0005434406913	01267F	1329 740621	VYACHESLAV DENISOV	{"phone": "+70657860808"}
0005434406914	22A952	9963 473510	PAVEL FROLOV	{"phone": "+70482770041"}
0005434406915	22A952	4320 955401	PAVEL ROMANOV	{"email": "romanov_pavel-021975@postgrespro.ru", "phone": "+70353174327"}
0005434406916	F2A2DE	1339 842137	ALEKSANDRA MIKHAYLOVA	{"phone": "+70569058118"}
0005434406917	528DF7	3973 951116	IRINA YUDINA	{"phone": "+70632351614"}
0005434406918	DB0E2F	7097 124462	VASILIY MEDVEDEV	{"phone": "+70614888393"}
0005434406919	DB0E2F	5533 184405	IRINA MIKHAYLOVA	{"email": "i-mikhaylova_031966@postgrespro.ru", "phone": "+70052420907"}
0005434406920	102CCB	4137 106975	ALEKSANDR TARASOV	{"email": "tarasovaleksandr_1982@postgrespro.ru", "phone": "+70342801614"}
0005434406921	EAEAA1	5951 421853	ELENA KOROLEVA	{"email": "koroleva_elena-22071965@postgrespro.ru", "phone": "+70869839068"}
0005434406922	EAEAA1	9002 900658	DIANA NOVIKOVA	{"email": "diana_novikova.1982@postgrespro.ru", "phone": "+70484265378"}
0005434406923	F750D8	9400 371420	LIDIYA KUZNECOVA	{"phone": "+70771887306"}
0005434406924	1D5BBF	9060 267399	ALEVTINA LEBEDEVA	{"email": "lebedeva_alevtina_30031989@postgrespro.ru", "phone": "+70164716639"}
0005434406925	57E544	3896 294619	NATALYA KISELEVA	{"phone": "+70878663322"}
0005434406926	6CC382	4931 473787	TAMARA MAKSIMOVA	{"email": "tmaksimova-30071969@postgrespro.ru", "phone": "+70983942150"}
0005434406927	6CC382	4421 436882	YURIY SERGEEV	{"phone": "+70319797272"}
0005434406928	B95FF2	6737 174989	ILYA NIKITIN	{"email": "nikitin-i-121967@postgrespro.ru", "phone": "+70795447079"}
0005434406929	8D9C21	5760 631941	VLADISLAV ZHUKOV	{"phone": "+70068320404"}
0005434406930	28401F	0821 492752	VYACHESLAV PETROV	{"phone": "+70889157480"}
0005434406931	28401F	8918 685940	MIKHAIL GORBUNOV	{"email": "mikhail.gorbunov.01031968@postgrespro.ru", "phone": "+70056822600"}
0005434406932	20A2C6	9086 689529	NIKOLAY ZAKHAROV	{"email": "zakharov.n.121972@postgrespro.ru", "phone": "+70102327933"}
0005434406933	889B62	6407 413165	VARVARA KUZNECOVA	{"phone": "+70521083337"}
0005434406934	B082EB	7803 793446	SERGEY RODIONOV	{"email": "sergeyrodionov-121980@postgrespro.ru", "phone": "+70958447524"}
0005434406935	BB84C1	0538 331589	OLGA BELOVA	{"phone": "+70228276669"}
0005434406936	0A17CB	7586 584583	TAISIYA VASILEVA	{"phone": "+70488440426"}
0005434406937	C8EFA7	9265 792505	ANDREY DAVYDOV	{"phone": "+70291979951"}
0005434406938	DF55B8	8574 299594	STANISLAV TIMOFEEV	{"email": "stimofeev_29051979@postgrespro.ru", "phone": "+70243156658"}
0005434406939	DF55B8	2356 097702	IVAN MAKAROV	{"email": "i.makarov.27081979@postgrespro.ru", "phone": "+70500119518"}
0005434406940	9CFFC2	8745 236616	ELENA MELNIKOVA	{"phone": "+70371444693"}
0005434406941	9CFFC2	6535 763172	VERA KISELEVA	{"phone": "+70069448342"}
0005434406942	71586D	7583 699102	VALENTINA KOROLEVA	{"phone": "+70933737214"}
0005434406943	CAA48A	9121 371736	ALEKSANDR SMIRNOV	{"phone": "+70928138394"}
0005434406944	9D9421	4104 928764	SERGEY STEPANOV	{"phone": "+70574956685"}
0005434406945	2FB41E	7424 810951	ALENA KOZLOVA	{"email": "kozlova_a.051971@postgrespro.ru", "phone": "+70920677161"}
0005434406946	7D0DF8	9433 123215	EVGENIY RODIONOV	{"email": "evgeniy.rodionov13071982@postgrespro.ru", "phone": "+70471674662"}
0005434406947	23DD4B	4604 783394	EVGENIYA GUSEVA	{"phone": "+70041194964"}
0005434406948	CE3981	0343 264490	TIMOFEY SOKOLOV	{"phone": "+70169399982"}
0005434406949	0A50A6	1059 281358	ALEKSANDR STEPANOV	{"email": "a_stepanov26021978@postgrespro.ru", "phone": "+70076162432"}
0005434406950	547159	4029 710170	OLGA ZOTOVA	{"email": "o.zotova041970@postgrespro.ru", "phone": "+70173495545"}
0005434406951	35F243	6973 098512	VERA EFIMOVA	{"email": "efimova.vera_1977@postgrespro.ru", "phone": "+70993639070"}
0005434406952	35F243	1233 889041	SOFYA VOLKOVA	{"email": "volkova_s08101974@postgrespro.ru", "phone": "+70482648837"}
0005434406953	060FF6	2622 639055	OLEG POPOV	{"email": "popovoleg.18091970@postgrespro.ru", "phone": "+70943246786"}
0005434406954	060FF6	1760 818714	IVAN POPOV	{"phone": "+70699132317"}
0005434406955	81E9D6	8006 176227	ALEKSANDR SAVELEV	{"phone": "+70319858728"}
0005434406956	81E9D6	6753 932452	ALEKSANDR SEMENOV	{"email": "a-semenov_21101974@postgrespro.ru", "phone": "+70068687249"}
0005434406957	81E9D6	4217 714492	OLGA FADEEVA	{"phone": "+70120064999"}
0005434406958	16C629	0182 944673	MARINA KUZNECOVA	{"email": "m-kuznecova-091977@postgrespro.ru", "phone": "+70070812723"}
0005434406959	60D8C3	7448 496236	ILYA ILIN	{"phone": "+70782026195"}
0005434406960	6F2E82	0571 462894	NATALYA FROLOVA	{"email": "n-frolova-071971@postgrespro.ru", "phone": "+70518905548"}
0005434406961	6F2E82	0024 836573	SVETLANA SEMENOVA	{"email": "semenovasvetlana.121968@postgrespro.ru", "phone": "+70513601089"}
0005434406962	6F2E82	5876 574383	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr1971@postgrespro.ru", "phone": "+70609544836"}
0005434406963	DEF7C5	9118 066774	ANDREY ALEKSANDROV	{"email": "andreyaleksandrov1982@postgrespro.ru", "phone": "+70925642318"}
0005434406964	54FD8B	3343 814096	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr1973@postgrespro.ru", "phone": "+70725096327"}
0005434406965	95E108	9912 638527	VIKTOR YAKOVLEV	{"phone": "+70724324570"}
0005434406966	7C75C6	7186 840181	TATYANA MELNIKOVA	{"email": "melnikova-t1985@postgrespro.ru", "phone": "+70077408817"}
0005434406967	12F7B6	6079 918702	OLGA MOROZOVA	{"phone": "+70267728087"}
0005434406968	FE3C17	7303 982332	VIKTORIYA KOZLOVA	{"email": "viktoriya.kozlova1964@postgrespro.ru", "phone": "+70414161280"}
0005434406969	6146E5	8877 368487	VASILIY SCHERBAKOV	{"email": "scherbakov.v-031980@postgrespro.ru", "phone": "+70624441407"}
0005434406970	9CD012	2818 554969	LYUDMILA VASILEVA	{"phone": "+70829751803"}
0005434406971	C910B5	2590 524811	OLGA IVANOVA	{"phone": "+70468309896"}
0005434406972	205055	0140 813180	IVAN KARPOV	{"email": "karpov_i30071963@postgrespro.ru", "phone": "+70800446059"}
0005434406973	E4C024	6881 417149	NATALYA SOROKINA	{"email": "sorokina-n_1964@postgrespro.ru", "phone": "+70254707506"}
0005434406974	C54C04	1019 908867	IVAN SCHERBAKOV	{"email": "ivan.scherbakov_01071968@postgrespro.ru", "phone": "+70892235972"}
0005434406975	2ED942	4391 200562	VLADIMIR IVANOV	{"email": "vivanov051970@postgrespro.ru", "phone": "+70510504588"}
0005434406976	5C33DE	1303 622618	MARIYA PETROVA	{"phone": "+70524774669"}
0005434406977	FEBA7A	5023 998701	TIMUR TIKHONOV	{"phone": "+70076180869"}
0005434406978	FEBA7A	5927 281774	ELENA KUZMINA	{"phone": "+70926581078"}
0005434406979	1E3824	1028 068208	ELENA NOVIKOVA	{"phone": "+70933976069"}
0005434406980	1E3824	9082 913289	NINA VLASOVA	{"phone": "+70415253341"}
0005434406981	1E3824	9520 339674	NATALYA ORLOVA	{"email": "n_orlova_1973@postgrespro.ru", "phone": "+70747122448"}
0005434406982	9EB1B0	7708 112697	VALENTINA BELOVA	{"email": "belova.v.07101972@postgrespro.ru", "phone": "+70042543056"}
0005434406983	6E27AA	6307 814812	YAROSLAV PETROV	{"phone": "+70775654377"}
0005434406984	0E88F2	4964 868571	PAVEL VOROBEV	{"email": "pavelvorobev-06031970@postgrespro.ru", "phone": "+70093362705"}
0005434406985	0E88F2	5195 044111	LARISA IVANOVA	{"email": "larisa_ivanova.28111961@postgrespro.ru", "phone": "+70263455393"}
0005434406986	0E88F2	9133 852469	GALINA ZAYCEVA	{"phone": "+70357328680"}
0005434406987	A80F40	6807 618313	OLEG SOKOLOV	{"phone": "+70427445128"}
0005434406988	A80F40	6070 381621	ALEKSEY ROMANOV	{"email": "alekseyromanov.011973@postgrespro.ru", "phone": "+70747112921"}
0005434406989	B7EB90	0834 249613	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir-20051975@postgrespro.ru", "phone": "+70752847560"}
0005434406990	B6B3DC	7558 771830	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov-15011961@postgrespro.ru", "phone": "+70358566264"}
0005434406991	D15043	2510 010341	EVGENIY KULIKOV	{"phone": "+70673756606"}
0005434406992	FEA632	2344 727475	GALINA KOROLEVA	{"phone": "+70159723317"}
0005434406993	F05278	7758 834962	DENIS VASILEV	{"phone": "+70118581047"}
0005434406994	F05278	2224 812743	ANASTASIYA ZAKHAROVA	{"email": "zakharova-a_1965@postgrespro.ru", "phone": "+70560934824"}
0005434406995	847090	6702 970456	ELENA SOROKINA	{"phone": "+70184105840"}
0005434406996	847090	2238 929914	VYACHESLAV KUZNECOV	{"phone": "+70687514720"}
0005434406997	F5665B	3979 235934	LYUBOV ROMANOVA	{"phone": "+70966905977"}
0005434406998	AA2CBC	6344 359634	OLGA STEPANOVA	{"email": "olgastepanova-031977@postgrespro.ru", "phone": "+70695214441"}
0005434406999	AA2CBC	8865 930996	ALEKSANDR SIDOROV	{"phone": "+70232937160"}
0005434407000	AA2CBC	4409 637797	TATYANA SOROKINA	{"phone": "+70972370268"}
0005434407001	7DDD7F	4399 518008	VLADISLAV TIKHONOV	{"phone": "+70647419647"}
0005434407002	B59A90	6290 777520	ANTONINA BORISOVA	{"phone": "+70521084088"}
0005434407003	BF312A	8796 807201	EVGENIY VOROBEV	{"phone": "+70879888088"}
0005434407004	856056	4444 772968	RODION NIKOLAEV	{"email": "r.nikolaev1970@postgrespro.ru", "phone": "+70312581373"}
0005434407005	856056	9666 594818	ZHANNA AKIMOVA	{"email": "z_akimova-1967@postgrespro.ru", "phone": "+70602977423"}
0005434407006	C31AA0	4290 995987	VASILIY ISAEV	{"email": "isaev-v26031970@postgrespro.ru", "phone": "+70555825748"}
0005434407007	1CCB69	0680 958999	ALEKSANDR SEMENOV	{"email": "a_semenov.05011967@postgrespro.ru", "phone": "+70995909223"}
0005434407008	CBCD49	9060 361581	DAMIR ILIN	{"phone": "+70935938450"}
0005434407009	3B30EE	9191 586585	TAISIYA MOISEEVA	{"email": "moiseeva.t-031982@postgrespro.ru", "phone": "+70680149247"}
0005434407010	3B30EE	7855 953814	SERGEY NIKOLAEV	{"email": "s.nikolaev.13081979@postgrespro.ru", "phone": "+70636415248"}
0005434407011	85CD33	4971 224405	ANASTASIYA PETROVA	{"email": "apetrova.101975@postgrespro.ru", "phone": "+70223374284"}
0005434407012	3081AF	9496 980263	SERGEY IVANOV	{"email": "s-ivanov_13081969@postgrespro.ru", "phone": "+70406287145"}
0005434407013	079DC0	9460 939589	YURIY MATVEEV	{"email": "yuriy_matveev_29041978@postgrespro.ru", "phone": "+70098498250"}
0005434407014	079DC0	9257 861694	EVGENIY DAVYDOV	{"email": "evgeniy-davydov-1968@postgrespro.ru", "phone": "+70756766308"}
0005434407015	8AC4A1	0687 599729	DMITRIY ZHURAVLEV	{"phone": "+70755747669"}
0005434407016	8AC4A1	5360 885887	VIKTORIYA TROFIMOVA	{"email": "trofimova_viktoriya061972@postgrespro.ru", "phone": "+70507671593"}
0005434407017	E21213	9550 670073	ANAIT POPOVA	{"phone": "+70764475301"}
0005434407018	00A2B8	0034 419054	MARIYA KOZLOVA	{"email": "kozlova.mariya.1967@postgrespro.ru", "phone": "+70418375225"}
0005434407019	1B57EB	5210 230736	IRINA YAKOVLEVA	{"phone": "+70300117115"}
0005434407020	325B0C	2738 212880	OLGA ROMANOVA	{"phone": "+70428955836"}
0005434407021	738306	2770 856552	MIKHAIL IVANOV	{"phone": "+70686881362"}
0005434407022	F8D35D	9588 003878	IVAN IVANOV	{"email": "ivanovivan02121959@postgrespro.ru", "phone": "+70811861962"}
0005434407023	F8D35D	1380 229561	KLAVDIYA ILINA	{"phone": "+70541128132"}
0005434407024	2592FA	6790 952412	NATALYA PAVLOVA	{"email": "pavlova.n-26021979@postgrespro.ru", "phone": "+70767977152"}
0005434407025	3498DE	6890 658169	NADEZHDA MELNIKOVA	{"phone": "+70205174129"}
0005434407026	34DAAD	3374 925311	DENIS ZAYCEV	{"email": "zaycev-d1969@postgrespro.ru", "phone": "+70066067195"}
0005434407027	43408D	5440 460603	MAYA POTAPOVA	{"phone": "+70894965925"}
0005434407028	9E0066	1433 950671	LILIYA KUZNECOVA	{"phone": "+70154087457"}
0005434407029	94F4A5	5447 962860	ILMIRA KUZNECOVA	{"phone": "+70631458428"}
0005434407030	B0466C	4339 079999	VLADIMIR IVANOV	{"phone": "+70373446554"}
0005434407031	B0466C	5540 593110	EVGENIY NIKITIN	{"email": "e-nikitin_011959@postgrespro.ru", "phone": "+70936785374"}
0005434407032	B0466C	9619 210524	LYUDMILA MAKAROVA	{"phone": "+70332351300"}
0005434407033	CC7988	4880 712106	VLADIMIR KUZNECOV	{"phone": "+70103130170"}
0005434407034	A28657	3448 194269	VIKTOR ZAKHAROV	{"email": "viktorzakharov.19121960@postgrespro.ru", "phone": "+70698809180"}
0005434407035	F9B074	5517 445598	VIKTORIYA NESTEROVA	{"phone": "+70785863328"}
0005434407036	C1126C	5325 775511	ALEKSANDR ABRAMOV	{"email": "a_abramov061981@postgrespro.ru", "phone": "+70931591875"}
0005434407037	C1126C	6445 501446	ELENA KULIKOVA	{"phone": "+70300532433"}
0005434407038	C52F7B	2818 904263	VALERIY ANDREEV	{"email": "valeriy_andreev_1978@postgrespro.ru", "phone": "+70218835027"}
0005434407039	CCB2DC	2735 078515	ALEKSANDRA GRISHINA	{"phone": "+70752191655"}
0005434407098	113D99	2500 248454	ANNA ROMANOVA	{"phone": "+70920902852"}
0005434407040	BCBE94	1679 260149	LIDIYA MAKAROVA	{"email": "makarova-lidiya-021972@postgrespro.ru", "phone": "+70411424211"}
0005434407041	80B210	2551 923598	LIDIYA SEMENOVA	{"email": "lsemenova_071960@postgrespro.ru", "phone": "+70830291606"}
0005434407042	7610D2	8188 197989	NATALYA NIKITINA	{"phone": "+70031917665"}
0005434407043	7610D2	9963 534494	VLADIMIR ABRAMOV	{"phone": "+70310259043"}
0005434407044	FED828	9741 191583	VARVARA ORLOVA	{"email": "orlova_v.111966@postgrespro.ru", "phone": "+70674746298"}
0005434407045	6C9F30	1991 164736	AZAT RODIONOV	{"phone": "+70233613396"}
0005434407046	6C9F30	3821 845706	NINA KOMAROVA	{"phone": "+70472690838"}
0005434407047	226C35	5225 492517	NIKOLAY MOROZOV	{"email": "n_morozov-1969@postgrespro.ru", "phone": "+70963830641"}
0005434407048	27D432	7725 315940	NINA ORLOVA	{"email": "orlova_nina.20111968@postgrespro.ru", "phone": "+70189429910"}
0005434407049	A1FC40	8750 385341	NATALYA MIRONOVA	{"email": "mironova-natalya_18011969@postgrespro.ru", "phone": "+70867735233"}
0005434407050	89E786	9940 590834	VLADIMIR MOISEEV	{"phone": "+70819382474"}
0005434407051	6FB6E2	3855 834121	DIANA DENISOVA	{"email": "denisovad_1980@postgrespro.ru", "phone": "+70680870995"}
0005434407052	DD5DEA	3261 821343	TATYANA CHERNOVA	{"email": "chernova.t-27111965@postgrespro.ru", "phone": "+70774985243"}
0005434407053	68FD87	0777 281590	OLGA RODIONOVA	{"email": "orodionova_15071970@postgrespro.ru", "phone": "+70382121846"}
0005434407054	C847CF	9108 675300	ALEKSANDR ANTONOV	{"email": "aleksandr-antonov_1972@postgrespro.ru", "phone": "+70346933649"}
0005434407055	C847CF	4576 342777	OLGA RODIONOVA	{"phone": "+70262366289"}
0005434407056	9455BD	4118 127773	YULIYA IVANOVA	{"email": "ivanovayuliya.1970@postgrespro.ru", "phone": "+70351204572"}
0005434407057	6EE9A2	9795 762453	LYUDMILA KOVALEVA	{"phone": "+70515716499"}
0005434407058	0FDF23	1573 271148	VALENTINA ANDREEVA	{"email": "valentina_andreeva.23061974@postgrespro.ru", "phone": "+70292017857"}
0005434407059	46289A	8913 303093	LIDIYA MATVEEVA	{"phone": "+70204008995"}
0005434407060	4B4D49	9517 570192	MAKSIM AFANASEV	{"email": "m.afanasev1973@postgrespro.ru", "phone": "+70805389336"}
0005434407061	82FCE5	8512 694453	VERA DENISOVA	{"email": "denisova_vera1977@postgrespro.ru", "phone": "+70385394661"}
0005434407062	82FCE5	6244 777860	MIKHAIL BARANOV	{"email": "m_baranov_061980@postgrespro.ru", "phone": "+70822527768"}
0005434407063	D54826	1938 415849	ELENA SERGEEVA	{"email": "sergeevaelena_09121984@postgrespro.ru", "phone": "+70562671241"}
0005434407064	21E475	3676 379384	SVETLANA SOROKINA	{"email": "sorokina-s_071978@postgrespro.ru", "phone": "+70553071211"}
0005434407065	21E475	9389 596762	LYUBOV NAZAROVA	{"phone": "+70635398635"}
0005434407066	C6158B	0627 621169	EKATERINA GERASIMOVA	{"phone": "+70310752780"}
0005434407067	C6158B	4868 166988	MARYAM SIDOROVA	{"phone": "+70833192525"}
0005434407068	E3B32D	5725 222760	VALENTINA IVANOVA	{"email": "valentina.ivanova10031965@postgrespro.ru", "phone": "+70746757230"}
0005434407069	E3B32D	7512 360045	ANDREY ANDREEV	{"email": "andreevandrey_091971@postgrespro.ru", "phone": "+70806590301"}
0005434407070	CEC0E0	9519 708270	SVETLANA ISAEVA	{"email": "isaeva-s-111976@postgrespro.ru", "phone": "+70134664932"}
0005434407071	F2DB72	0841 001343	TIGRAN YAKOVLEV	{"phone": "+70258089405"}
0005434407072	9841F4	9369 995261	LARISA KULIKOVA	{"phone": "+70837512584"}
0005434407073	9841F4	2642 004944	ANTON VASILEV	{"phone": "+70623996784"}
0005434407074	AF7AFD	2001 735381	ANTONINA GUSEVA	{"phone": "+70654741462"}
0005434407075	229362	2963 881807	ANATOLIY ALEKSEEV	{"phone": "+70942202578"}
0005434407076	229362	6598 450022	SVETLANA ALEKSANDROVA	{"phone": "+70183380709"}
0005434407077	DC0C20	8530 319624	PAVEL DAVYDOV	{"email": "davydov.p_07101979@postgrespro.ru", "phone": "+70119320381"}
0005434407078	0C8B8E	7974 856011	OLGA BORISOVA	{"phone": "+70505894580"}
0005434407079	B7195C	6467 708046	ALEKSEY SOKOLOV	{"email": "sokolovaleksey.101975@postgrespro.ru", "phone": "+70977721331"}
0005434407080	B7195C	4038 569074	TATYANA SOKOLOVA	{"email": "sokolova.tatyana-031979@postgrespro.ru", "phone": "+70715637806"}
0005434407081	AECDAF	9889 653885	ROMAN KUDRYASHOV	{"email": "romankudryashov08121964@postgrespro.ru", "phone": "+70770144294"}
0005434407082	EA5EFE	9647 858430	VALENTIN OSIPOV	{"phone": "+70458237712"}
0005434407083	EA5EFE	4498 855937	MARINA ANTONOVA	{"email": "marina-antonova.1973@postgrespro.ru", "phone": "+70108050579"}
0005434407084	95CADF	7829 938707	ZINAIDA KOROLEVA	{"phone": "+70090726148"}
0005434407085	C99896	5716 403676	POLINA SCHERBAKOVA	{"email": "scherbakova-p.1970@postgrespro.ru", "phone": "+70399757297"}
0005434407086	922F63	5011 428282	DANIIL ANTONOV	{"email": "antonov-d_071970@postgrespro.ru", "phone": "+70282732849"}
0005434407087	6BD643	9487 674091	ALEKSEY IVANOV	{"email": "aleksey-ivanov-1972@postgrespro.ru", "phone": "+70101017424"}
0005434407088	68267F	8352 157015	YULIYA MELNIKOVA	{"phone": "+70656609252"}
0005434407089	90E371	4794 916249	VLADIMIR BORISOV	{"phone": "+70064801327"}
0005434407090	90E371	4373 804655	ANASTASIYA ROMANOVA	{"email": "romanova_anastasiya.101962@postgrespro.ru", "phone": "+70786518702"}
0005434407091	D81BF2	9229 423562	IGOR VLASOV	{"email": "vlasov-i25071972@postgrespro.ru", "phone": "+70769232133"}
0005434407092	D81BF2	4624 418021	DMITRIY BORISOV	{"email": "dmitriyborisov-14021980@postgrespro.ru", "phone": "+70400538258"}
0005434407093	10F85D	6782 836538	RAMIL NIKOLAEV	{"phone": "+70918167242"}
0005434407094	95D10D	6933 255213	LYUDMILA EGOROVA	{"email": "l.egorova1966@postgrespro.ru", "phone": "+70494956069"}
0005434407095	21F86B	1161 654488	DMITRIY SMIRNOV	{"email": "dmitriy.smirnov_021974@postgrespro.ru", "phone": "+70879131575"}
0005434407096	40A4B2	9154 396151	YURIY BORISOV	{"email": "borisov_yuriy.1974@postgrespro.ru", "phone": "+70281623030"}
0005434407097	58947D	0027 132325	TATYANA FILIPPOVA	{"email": "tatyana.filippova_14051976@postgrespro.ru", "phone": "+70727555334"}
0005434407099	C6F0DF	0859 042640	OLGA TARASOVA	{"email": "tarasovao-031980@postgrespro.ru", "phone": "+70888531297"}
0005434407100	C6F0DF	0607 332504	VYACHESLAV SEMENOV	{"phone": "+70928912007"}
0005434407101	B53BD8	5402 621506	TATYANA ANTONOVA	{"email": "antonova_tatyana-051972@postgrespro.ru", "phone": "+70247326672"}
0005434407102	607500	9725 899436	OLGA LEBEDEVA	{"email": "lebedeva.o071971@postgrespro.ru", "phone": "+70221995457"}
0005434407103	841C39	2822 452989	TAMARA SIDOROVA	{"email": "sidorova_tamara.041971@postgrespro.ru", "phone": "+70915249970"}
0005434407104	286428	5671 480559	ANNA KISELEVA	{"phone": "+70507357527"}
0005434407105	6F66A5	5750 026476	NADEZHDA KONDRATEVA	{"email": "nadezhda-kondrateva.1972@postgrespro.ru", "phone": "+70612369753"}
0005434407106	9BA9A4	0614 813512	SERGEY ZAYCEV	{"phone": "+70510388140"}
0005434407107	9BA9A4	0241 384682	TATYANA SEMENOVA	{"phone": "+70920582161"}
0005434407108	2AFD3C	9663 305050	DMITRIY FEDOTOV	{"phone": "+70267480845"}
0005434407109	88E2C0	3743 008512	DARYA ABRAMOVA	{"phone": "+70947646548"}
0005434407110	88E2C0	4917 725975	GENNADIY DENISOV	{"email": "g-denisov_101971@postgrespro.ru", "phone": "+70701441938"}
0005434407111	81BF85	8035 714509	ANNA MATVEEVA	{"email": "anna-matveeva.21101973@postgrespro.ru", "phone": "+70308816310"}
0005434407112	81BF85	7998 334106	EVGENIY KARPOV	{"email": "e-karpov08101968@postgrespro.ru", "phone": "+70800329662"}
0005434407113	844EC5	1331 954722	DANILA ANTONOV	{"email": "antonov_d_1979@postgrespro.ru", "phone": "+70828893634"}
0005434407114	844EC5	7844 177936	NATALYA ILINA	{"email": "natalya_ilina.1965@postgrespro.ru", "phone": "+70145670941"}
0005434407115	844EC5	7920 731811	NIKOLAY ZAKHAROV	{"phone": "+70707828358"}
0005434407116	BFD90D	9029 728508	TATYANA ALEKSANDROVA	{"email": "aleksandrova.tatyana.05041965@postgrespro.ru", "phone": "+70616555374"}
0005434407117	AC19A9	8666 546419	OKSANA PAVLOVA	{"phone": "+70734755000"}
0005434407118	BD9EF8	2552 528029	VIKTOR IVANOV	{"phone": "+70481371282"}
0005434407119	71EAF7	7465 167490	IVAN MAKAROV	{"email": "i_makarov.061964@postgrespro.ru", "phone": "+70177693375"}
0005434407120	71EAF7	6143 314007	POLINA POLYAKOVA	{"email": "polyakova.p.1973@postgrespro.ru", "phone": "+70330517979"}
0005434407121	DC9B1C	9508 174889	DIANA KOZLOVA	{"email": "kozlova-d051976@postgrespro.ru", "phone": "+70268262761"}
0005434407122	1A5158	0066 561963	RAMIL KUZNECOV	{"phone": "+70943810272"}
0005434407123	6BC4E3	7699 845226	GALINA KOLESNIKOVA	{"phone": "+70348178145"}
0005434407124	D93A78	1557 779346	VIKTOR GORBUNOV	{"email": "viktorgorbunov-061981@postgrespro.ru", "phone": "+70347535519"}
0005434407125	F33CC5	2236 134254	LIDIYA PETROVA	{"phone": "+70868626305"}
0005434407126	1AB5AE	4392 911331	NATALIYA AFANASEVA	{"phone": "+70187109746"}
0005434407127	988A74	7856 871824	SERGEY SOLOVEV	{"phone": "+70514541109"}
0005434407128	871037	3650 336824	VALENTINA ANTONOVA	{"email": "valentinaantonova_1975@postgrespro.ru", "phone": "+70116242710"}
0005434407129	6107F5	4868 777020	TARAS AFANASEV	{"phone": "+70807322461"}
0005434407130	182905	3473 127031	LIDIYA KOLESNIKOVA	{"phone": "+70928923570"}
0005434407131	182905	3017 269050	ANTONINA ZAYCEVA	{"email": "zaycevaa_091968@postgrespro.ru", "phone": "+70020518640"}
0005434407132	F2E06B	6545 256697	NIKITA MIRONOV	{"email": "nmironov.1965@postgrespro.ru", "phone": "+70187334327"}
0005434407133	DEBAA4	6108 989761	PAVEL YAKOVLEV	{"email": "p-yakovlev17021975@postgrespro.ru", "phone": "+70154606525"}
0005434407134	42A713	8097 026584	DMITRIY IVANOV	{"phone": "+70846593164"}
0005434407135	49ACFA	0074 925613	TATYANA MAKAROVA	{"phone": "+70032201911"}
0005434407136	49ACFA	8999 590069	ILDAR KARPOV	{"phone": "+70914334098"}
0005434407137	A9D0C0	7419 546005	ALEKSANDR BARANOV	{"email": "a-baranov.15091979@postgrespro.ru", "phone": "+70737366884"}
0005434407138	C09C67	9002 539458	ILYA MELNIKOV	{"email": "melnikov_ilya-1979@postgrespro.ru", "phone": "+70631128775"}
0005434407139	68EC25	8558 329644	TATYANA ABRAMOVA	{"phone": "+70233371494"}
0005434407140	68EC25	7188 481381	YANA ORLOVA	{"phone": "+70913326484"}
0005434407141	6A1902	5015 517260	DANILA BORISOV	{"email": "borisovd_1969@postgrespro.ru", "phone": "+70343937000"}
0005434407142	6A1902	5736 390825	NADEZHDA ALEKSANDROVA	{"email": "naleksandrova12121966@postgrespro.ru", "phone": "+70967927910"}
0005434407143	EEFED2	2569 701054	ANDREY ANDREEV	{"email": "andreev.a30041981@postgrespro.ru", "phone": "+70250671548"}
0005434407144	EEFED2	8399 235315	VASILIY FEDOROV	{"phone": "+70645671618"}
0005434407145	EEFED2	1267 889594	TATYANA VASILEVA	{"email": "vasileva.t101975@postgrespro.ru", "phone": "+70827280606"}
0005434407146	E52C02	9724 998484	IVAN DAVYDOV	{"email": "davydov_i.17071979@postgrespro.ru", "phone": "+70987759243"}
0005434407147	F9924B	8148 981541	DENIS AFANASEV	{"email": "afanasevdenis-111979@postgrespro.ru", "phone": "+70055910877"}
0005434407148	0A5C8F	7603 521877	MIKHAIL POPOV	{"phone": "+70833071495"}
0005434407149	0A5C8F	3862 575698	NADEZHDA MAKAROVA	{"email": "nadezhda_makarova.061979@postgrespro.ru", "phone": "+70715686305"}
0005434407150	737253	0638 907946	LYUDMILA MARTYNOVA	{"email": "l-martynova.25051971@postgrespro.ru", "phone": "+70030055955"}
0005434407151	737253	2431 728984	KSENIYA NIKITINA	{"phone": "+70349008962"}
0005434407152	2B95D9	8549 861056	EKATERINA ANDREEVA	{"email": "andreeva-ekaterina_091970@postgrespro.ru", "phone": "+70726065900"}
0005434407153	2B95D9	0315 675918	VIKTOR IVANOV	{"phone": "+70339857500"}
0005434407154	2B95D9	3371 578921	VADIM GORBUNOV	{"phone": "+70683018250"}
0005434407155	750D21	7377 899792	ANNA POPOVA	{"email": "annapopova.1971@postgrespro.ru", "phone": "+70473350363"}
0005434407156	750D21	7368 356276	BORIS NIKITIN	{"email": "nikitin.b_1972@postgrespro.ru", "phone": "+70069199995"}
0005434407157	1C6143	9974 380245	VIKTOR ORLOV	{"phone": "+70002317530"}
0005434407158	1C6143	6190 434979	VIKTOR ZAYCEV	{"email": "vzaycev.101975@postgrespro.ru", "phone": "+70805256895"}
0005434407159	1A15FA	1466 358242	OLEG ZAYCEV	{"phone": "+70698925789"}
0005434407160	66F19C	2164 706546	ARTEM ANDREEV	{"phone": "+70857473660"}
0005434407161	66F19C	4473 964878	VALERIY KUZNECOV	{"phone": "+70425950246"}
0005434407162	34B440	3320 233704	SERGEY DENISOV	{"email": "sergey_denisov.1975@postgrespro.ru", "phone": "+70085452224"}
0005434407163	095E30	4103 533161	ANTONINA PETROVA	{"email": "apetrova-14081962@postgrespro.ru", "phone": "+70739692388"}
0005434407164	095E30	5080 801557	ROZA KUZNECOVA	{"phone": "+70461416808"}
0005434407165	B9062E	0489 040634	NIKOLAY MAKAROV	{"phone": "+70576804654"}
0005434407166	20F39B	5193 183038	VIKTORIYA KUZMINA	{"phone": "+70261385577"}
0005434407167	E14B7F	4840 201471	ANDREY SMIRNOV	{"phone": "+70820988314"}
0005434407168	3C1394	6689 768177	OLGA FEDOROVA	{"email": "ofedorova1979@postgrespro.ru", "phone": "+70869103135"}
0005434407169	3C1394	4188 299142	MIKHAIL GERASIMOV	{"phone": "+70610775889"}
0005434407170	2ED3C7	3816 463508	ANDREY ILIN	{"phone": "+70275896914"}
0005434407171	2ED3C7	7372 434561	IRINA AKIMOVA	{"phone": "+70211257616"}
0005434407172	2E3055	8921 531258	ANDREY PAVLOV	{"email": "pavlov.andrey061966@postgrespro.ru", "phone": "+70111834389"}
0005434407173	0002E0	3986 620108	IGOR KARPOV	{"email": "karpov-igor.1970@postgrespro.ru", "phone": "+70253260520"}
0005434407174	0002E0	5699 345447	ALEKSANDR TARASOV	{"email": "tarasov.a-1972@postgrespro.ru", "phone": "+70450335494"}
0005434407175	5E878B	2370 306407	GENNADIY POPOV	{"email": "gennadiy.popov.18031969@postgrespro.ru", "phone": "+70904820093"}
0005434407176	FA9F21	3417 811572	SERGEY KRASNOV	{"email": "krasnov_sergey071973@postgrespro.ru", "phone": "+70243069828"}
0005434407177	F778EB	2247 267333	GALINA MOROZOVA	{"email": "galinamorozova_111977@postgrespro.ru", "phone": "+70035387464"}
0005434407178	4BAA6F	6439 918897	ANNA FOMINA	{"email": "fominaa101976@postgrespro.ru", "phone": "+70577824300"}
0005434407179	04449C	8166 416386	ZOYA MEDVEDEVA	{"email": "medvedeva.zoya15111964@postgrespro.ru", "phone": "+70191321294"}
0005434407180	04449C	3190 475442	ELVIRA BELOVA	{"email": "elvira_belova-071972@postgrespro.ru", "phone": "+70836366294"}
0005434407181	04449C	5877 367911	VALENTINA FILIPPOVA	{"phone": "+70559510548"}
0005434407182	E9159B	4481 382584	OLEG FEDOROV	{"email": "ofedorov_1979@postgrespro.ru", "phone": "+70748723573"}
0005434407183	E9159B	7074 859888	POLINA FOMINA	{"email": "fomina-p.01011973@postgrespro.ru", "phone": "+70875145298"}
0005434407184	E9159B	9286 508893	SOFYA EFREMOVA	{"email": "efremova-s_09061962@postgrespro.ru", "phone": "+70572835915"}
0005434407185	D28229	2024 893957	ALEKSANDR KUZMIN	{"email": "kuzmin_a061977@postgrespro.ru", "phone": "+70188510032"}
0005434407186	D28229	2263 142708	YANA KUZNECOVA	{"email": "yana_kuznecova-1964@postgrespro.ru", "phone": "+70216678991"}
0005434407187	537DE3	0008 144445	LIDIYA NAUMOVA	{"email": "lidiya_naumova1966@postgrespro.ru", "phone": "+70944953535"}
0005434407188	155AEE	8523 541576	TATYANA NESTEROVA	{"email": "nesterova.t071969@postgrespro.ru", "phone": "+70311768092"}
0005434407189	155AEE	6681 030583	VYACHESLAV KUZNECOV	{"email": "vkuznecov_061974@postgrespro.ru", "phone": "+70136897411"}
0005434407190	4CDE38	9996 937866	SVETLANA IVANOVA	{"email": "ivanova-s-121972@postgrespro.ru", "phone": "+70780038230"}
0005434407191	4CDE38	1070 116132	PAVEL ALEKSANDROV	{"email": "aleksandrov.p01011979@postgrespro.ru", "phone": "+70329581228"}
0005434407192	2BC8D3	5446 946609	SERGEY NIKITIN	{"email": "snikitin_01041979@postgrespro.ru", "phone": "+70858268037"}
0005434407193	B4B2FD	8013 881030	NATALYA ROMANOVA	{"email": "n-romanova1987@postgrespro.ru", "phone": "+70078984137"}
0005434407194	D33B32	2864 990415	LYUDMILA FOMINA	{"phone": "+70131189319"}
0005434407195	D33B32	4655 676978	ALEKSANDR RODIONOV	{"email": "a_rodionov1969@postgrespro.ru", "phone": "+70556146795"}
0005434407196	8F3C00	5282 033270	RUFINA LOGINOVA	{"phone": "+70729726414"}
0005434407197	C4C8B7	5342 631999	PETR MEDVEDEV	{"phone": "+70902766619"}
0005434407198	2A932C	6210 501623	DANIIL MAKAROV	{"phone": "+70192560207"}
0005434407199	2A932C	3417 195504	VIKTOR MIRONOV	{"phone": "+70662393214"}
0005434407200	83B7F9	4947 124000	LYUDMILA DANILOVA	{"email": "danilovalyudmila.1967@postgrespro.ru", "phone": "+70584562039"}
0005434407201	83B7F9	5254 955430	NATALYA GRISHINA	{"email": "natalyagrishina.23041972@postgrespro.ru", "phone": "+70330231025"}
0005434407202	D98703	1358 594683	YURIY SMIRNOV	{"phone": "+70090700350"}
0005434407203	4DB2F4	3882 951619	VIKTOR ANDREEV	{"phone": "+70826495854"}
0005434407204	4F45FE	8628 744526	ANGELINA SOLOVEVA	{"email": "soloveva-a.1964@postgrespro.ru", "phone": "+70979695440"}
0005434407205	C5BF00	5234 490972	POLINA ALEKSANDROVA	{"phone": "+70533706428"}
0005434407206	1E0567	2647 794024	NIKOLAY ABRAMOV	{"email": "abramov-nikolay1967@postgrespro.ru", "phone": "+70553807814"}
0005434407207	0D5C6F	9282 820823	PETR KOZLOV	{"phone": "+70564953593"}
0005434407208	726126	6362 425993	SERGEY KUZMIN	{"email": "sergey-kuzmin-27041984@postgrespro.ru", "phone": "+70231064668"}
0005434407209	B6AA85	9132 007109	ALINA SAVELEVA	{"phone": "+70519179405"}
0005434407210	5A7EE3	3925 013513	VERONIKA SIDOROVA	{"email": "sidorova_veronika.091977@postgrespro.ru", "phone": "+70316743874"}
0005434407211	D5EF7E	1741 861665	TATYANA FROLOVA	{"phone": "+70503174440"}
0005434407212	D5EF7E	4162 362950	NADEZHDA KONOVALOVA	{"phone": "+70211712064"}
0005434407213	627887	0224 010754	SERGEY MAKAROV	{"phone": "+70341711598"}
0005434407214	3FF196	4158 921945	LYUBOV SIDOROVA	{"phone": "+70465354957"}
0005434407215	3FF196	5576 554954	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov_021964@postgrespro.ru", "phone": "+70879172995"}
0005434407216	9D4D02	6644 340423	IRINA LAZAREVA	{"email": "ilazareva_091983@postgrespro.ru", "phone": "+70802061827"}
0005434407217	FA60A9	8205 322795	ANTON ABRAMOV	{"email": "aabramov.021973@postgrespro.ru", "phone": "+70487248380"}
0005434407218	BE6825	1247 751304	NIKOLAY POPOV	{"phone": "+70084872235"}
0005434407219	BE6825	6090 688382	NATALIYA DANILOVA	{"email": "danilovanataliya-071964@postgrespro.ru", "phone": "+70127392911"}
0005434407220	BE6825	6302 612816	MARINA KUZNECOVA	{"email": "m-kuznecova-1969@postgrespro.ru", "phone": "+70692271710"}
0005434407221	6C46B1	9851 288319	DMITRIY MAKSIMOV	{"email": "maksimovd-1975@postgrespro.ru", "phone": "+70382297729"}
0005434407222	2AD8A5	6026 036761	ALEKSEY CHERNOV	{"email": "aleksey.chernov041966@postgrespro.ru", "phone": "+70290169494"}
0005434407223	66D94C	8042 944687	VALENTINA SOLOVEVA	{"phone": "+70809510330"}
0005434407224	66D94C	1404 800543	YURIY ZHURAVLEV	{"phone": "+70197819559"}
0005434407225	F36F35	0861 049029	SVETLANA MALYSHEVA	{"phone": "+70508139129"}
0005434407226	F36F35	9960 445236	SERGEY MOISEEV	{"phone": "+70586339468"}
0005434407227	C0F365	1564 513788	EVGENIY KAZAKOV	{"email": "kazakov-e-121977@postgrespro.ru", "phone": "+70696804116"}
0005434407228	C0F365	9941 925373	MARIYA SMIRNOVA	{"phone": "+70281644465"}
0005434407229	1300D3	9981 471797	RINAT BELOV	{"email": "r.belov.1979@postgrespro.ru", "phone": "+70119715300"}
0005434407230	6F1AFA	1920 114578	ANATOLIY FEDOROV	{"phone": "+70367974454"}
0005434407231	6F1AFA	1958 482554	LYUBOV TIMOFEEVA	{"email": "l.timofeeva_1969@postgrespro.ru", "phone": "+70529786612"}
0005434407232	151A4B	1051 538078	SERGEY POPOV	{"email": "popov_sergey-1965@postgrespro.ru", "phone": "+70838896376"}
0005434407233	683BCA	7823 645995	YURIY FOMIN	{"phone": "+70631319779"}
0005434407234	2CABFA	0664 132696	LYUDMILA NESTEROVA	{"email": "nesterovalyudmila15121975@postgrespro.ru", "phone": "+70023825723"}
0005434407235	68C526	4684 262875	TATYANA ANDREEVA	{"email": "tatyana_andreeva_01051980@postgrespro.ru", "phone": "+70662539009"}
0005434407236	68C526	2209 110699	VLADIMIR VASILEV	{"email": "vasilevv-12041970@postgrespro.ru", "phone": "+70047907041"}
0005434407237	75B5F9	5148 768364	ARTEM GAVRILOV	{"email": "gavrilov-a.26091959@postgrespro.ru", "phone": "+70037095936"}
0005434407238	75B5F9	9838 757395	ELENA VASILEVA	{"phone": "+70831429191"}
0005434407239	630F41	6740 844549	MARINA FADEEVA	{"email": "fadeevamarina-031975@postgrespro.ru", "phone": "+70067994865"}
0005434407240	F40043	9142 519360	ANDREY IVANOV	{"email": "ivanov-andrey-031971@postgrespro.ru", "phone": "+70646050905"}
0005434407241	DED14C	8815 531358	YAKOV IVANOV	{"email": "yivanov.31121962@postgrespro.ru", "phone": "+70713114225"}
0005434407242	41779F	6635 434397	POLINA ZAKHAROVA	{"email": "p-zakharova-061971@postgrespro.ru", "phone": "+70774155716"}
0005434407243	41779F	6750 528423	NADEZHDA LUKYANOVA	{"phone": "+70653113961"}
0005434407244	14E070	0380 005404	EVGENIY KUZNECOV	{"email": "e_kuznecov.1978@postgrespro.ru", "phone": "+70817497766"}
0005434407245	3B96B1	2788 847868	NINA ZAKHAROVA	{"email": "zakharova-n.08101965@postgrespro.ru", "phone": "+70708109006"}
0005434407246	E920DF	5725 569950	ALEKSANDR SERGEEV	{"email": "sergeev_a.051978@postgrespro.ru", "phone": "+70679634116"}
0005434407247	1E69F1	0083 196278	YULIYA LAZAREVA	{"email": "yuliya_lazareva021977@postgrespro.ru", "phone": "+70910770065"}
0005434407248	DC9D98	3590 450282	VALENTINA GUSEVA	{"email": "guseva_v.041973@postgrespro.ru", "phone": "+70874237425"}
0005434407249	DC9D98	7327 075897	LIDIYA BELOVA	{"email": "lidiya-belova_1981@postgrespro.ru", "phone": "+70153211917"}
0005434407250	A2FBE9	7197 513301	KLAVDIYA ZHUKOVA	{"email": "kzhukova.1984@postgrespro.ru", "phone": "+70514894760"}
0005434407251	1DF42F	6622 826158	GEORGIY TIKHONOV	{"phone": "+70092252600"}
0005434407252	C178ED	8183 267902	ALEKSEY YAKOVLEV	{"email": "a-yakovlev1972@postgrespro.ru", "phone": "+70174573395"}
0005434407253	73760A	2763 183195	EDUARD GAVRILOV	{"phone": "+70620729023"}
0005434407254	9F4B52	4481 498433	TAMARA ANISIMOVA	{"email": "anisimovat_13011971@postgrespro.ru", "phone": "+70677377189"}
0005434407255	18BF0C	9238 714937	ANDREY MIKHAYLOV	{"phone": "+70023562336"}
0005434407256	18BF0C	8009 021356	MIKHAIL ZAYCEV	{"email": "mikhail.zaycev_1969@postgrespro.ru", "phone": "+70640658133"}
0005434407257	654844	7006 528071	MIKHAIL POPOV	{"email": "mikhail-popov-20071974@postgrespro.ru", "phone": "+70809665024"}
0005434407258	654844	8990 936178	SERGEY ZAKHAROV	{"email": "zakharov.sergey-1972@postgrespro.ru", "phone": "+70134850391"}
0005434407259	07416B	2991 039035	DARYA ABRAMOVA	{"phone": "+70330606643"}
0005434407260	3E5ACD	9261 024063	VALENTINA DENISOVA	{"phone": "+70410879255"}
0005434407261	3E5ACD	9353 116754	IRINA AKIMOVA	{"email": "akimovai-1969@postgrespro.ru", "phone": "+70919030429"}
0005434407262	91B1A6	2514 562790	ALEKSEY KUZNECOV	{"email": "a.kuznecov-091967@postgrespro.ru", "phone": "+70415827306"}
0005434407263	668D9F	0395 190159	VALENTINA KUDRYASHOVA	{"phone": "+70256728141"}
0005434407264	668D9F	7474 901421	YULIYA PAVLOVA	{"phone": "+70078083258"}
0005434407265	668D9F	8594 886186	ELENA MAKAROVA	{"phone": "+70467147562"}
0005434407266	3D4489	6646 087526	ROBERT IVANOV	{"phone": "+70042736657"}
0005434407267	3D4489	5394 391967	VLADIMIR ANDREEV	{"phone": "+70648261121"}
0005434407268	B6B6A1	6995 791241	VIKTORIYA IVANOVA	{"email": "viktoriya_ivanova15111972@postgrespro.ru", "phone": "+70936695676"}
0005434407269	4BF7EF	5381 188431	MIKHAIL MATVEEV	{"email": "matveev.m.071977@postgrespro.ru", "phone": "+70409010997"}
0005434407270	4BF7EF	7682 971882	DARYA ANISIMOVA	{"phone": "+70271899755"}
0005434407271	4BF7EF	3432 422241	VERA PETROVA	{"email": "v.petrova_10091976@postgrespro.ru", "phone": "+70242450680"}
0005434407272	201F6B	8513 028228	ELENA SOROKINA	{"email": "sorokina.elena_061971@postgrespro.ru", "phone": "+70921861023"}
0005434407273	ED2492	2013 474463	SVETLANA KUZNECOVA	{"email": "kuznecova-s_1969@postgrespro.ru", "phone": "+70139268412"}
0005434407274	0B196C	3320 341348	NADEZHDA BELOVA	{"email": "belova_n.1976@postgrespro.ru", "phone": "+70914885593"}
0005434407275	20D40C	0118 146761	MARINA ORLOVA	{"email": "m-orlova_1977@postgrespro.ru", "phone": "+70831770111"}
0005434407276	B61BCB	1656 638787	ALEKSANDR SMIRNOV	{"phone": "+70308692962"}
0005434407277	B61BCB	5972 136721	OLGA VOLKOVA	{"email": "volkova.o-081969@postgrespro.ru", "phone": "+70649645068"}
0005434407278	BFF9EB	3973 841753	ANDREY ISAEV	{"phone": "+70070811772"}
0005434407279	5F2E22	8551 723814	SERGEY GERASIMOV	{"phone": "+70756573076"}
0005434407280	EC156B	7477 963950	NATALYA ZAYCEVA	{"email": "natalyazayceva-021971@postgrespro.ru", "phone": "+70893883114"}
0005434407281	32BC4E	1357 277388	EVGENIY DAVYDOV	{"email": "e_davydov_091973@postgrespro.ru", "phone": "+70627437247"}
0005434407282	A8F1CD	5490 051680	NIKOLAY KOROLEV	{"phone": "+70305366644"}
0005434407283	A8F1CD	8759 001969	ANNA KAZAKOVA	{"email": "annakazakova1970@postgrespro.ru", "phone": "+70269451803"}
0005434407284	A8F1CD	4668 831679	ANASTASIYA POLYAKOVA	{"phone": "+70109724226"}
0005434407285	C2399A	3840 959320	KSENIYA MARTYNOVA	{"phone": "+70651952141"}
0005434407286	266A21	8438 376152	NIKOLAY AFANASEV	{"phone": "+70159288512"}
0005434407287	F90973	5892 150636	VLADISLAV FEDOROV	{"email": "vladislavfedorov-1969@postgrespro.ru", "phone": "+70682827500"}
0005434407288	F90973	1894 540729	OLGA IVANOVA	{"email": "ivanova.olga_1960@postgrespro.ru", "phone": "+70876217727"}
0005434407289	267B03	4558 474105	MARGARITA BOGDANOVA	{"email": "m.bogdanova_10021976@postgrespro.ru", "phone": "+70887925623"}
0005434407290	5EA269	7006 205826	OLGA EFIMOVA	{"phone": "+70016994117"}
0005434407291	2E6B96	8787 043704	ALEKSANDR SEMENOV	{"phone": "+70872661548"}
0005434407292	2E6B96	8900 340565	DMITRIY KARPOV	{"phone": "+70303359834"}
0005434407293	51932D	9258 226541	ANNA POPOVA	{"phone": "+70607784997"}
0005434407294	A05206	0131 124779	ALEKSANDR IVANOV	{"email": "a.ivanov-1951@postgrespro.ru", "phone": "+70978004007"}
0005434407295	A05206	8463 185568	NADEZHDA NOVIKOVA	{"email": "novikova.n-021976@postgrespro.ru", "phone": "+70782735620"}
0005434407296	5636D5	5729 102823	DILYARA VOLKOVA	{"phone": "+70089812554"}
0005434407297	59F1ED	9877 290253	ELENA SIDOROVA	{"phone": "+70673047798"}
0005434407298	1E9E2B	6091 088862	ARINA PETROVA	{"phone": "+70066636466"}
0005434407299	7426C2	4017 058401	VITALIY MAKSIMOV	{"email": "vitaliy_maksimov.01061968@postgrespro.ru", "phone": "+70958055356"}
0005434407300	7426C2	5555 520142	IGOR SOKOLOV	{"email": "i-sokolov_1978@postgrespro.ru", "phone": "+70852221576"}
0005434407301	3E6397	5714 379976	MARINA SIDOROVA	{"phone": "+70461797301"}
0005434407302	C3F1FE	5496 000281	NIKOLAY FILIPPOV	{"email": "filippov.nikolay071978@postgrespro.ru", "phone": "+70218473132"}
0005434407303	11D26E	3579 798331	LIDIYA ERMAKOVA	{"phone": "+70247227045"}
0005434407304	11D26E	8279 106391	ALEKSEY KOROLEV	{"email": "a_korolev-061978@postgrespro.ru", "phone": "+70773935196"}
0005434407305	4FDA94	9337 616943	OLGA KRASNOVA	{"phone": "+70527051613"}
0005434407306	5E9C47	5561 185296	ALEKSANDR MAKAROV	{"phone": "+70024999682"}
0005434407307	D6AFD6	0164 483134	ANNA FROLOVA	{"phone": "+70637396106"}
0005434407308	D6AFD6	9523 384906	NATALIYA MOISEEVA	{"phone": "+70060198359"}
0005434407309	D6AFD6	7484 906840	VALERIY EGOROV	{"email": "valeriy-egorov101972@postgrespro.ru", "phone": "+70896566488"}
0005434407310	C6F635	5796 216080	ALEKSANDR SAVELEV	{"email": "savelev_a-17051974@postgrespro.ru", "phone": "+70539510399"}
0005434407311	809F32	5984 877710	NADEZHDA VOLKOVA	{"email": "nadezhda_volkova_011971@postgrespro.ru", "phone": "+70272968651"}
0005434407312	A521EB	1511 671266	VITALIY GRIGOREV	{"email": "v-grigorev.121971@postgrespro.ru", "phone": "+70450504398"}
0005434407313	DBA95D	6983 527564	SERGEY TIMOFEEV	{"phone": "+70077778054"}
0005434407314	DBA95D	4547 640101	TATYANA TIKHONOVA	{"phone": "+70484341362"}
0005434407315	E7477F	7631 770153	OLESYA MAKAROVA	{"email": "makarova_o-031972@postgrespro.ru", "phone": "+70315510453"}
0005434407316	588A97	9921 701623	GALINA KOMAROVA	{"phone": "+70298863281"}
0005434407317	F9DDF5	4498 927822	ANNA MEDVEDEVA	{"phone": "+70621839632"}
0005434407318	1FECE2	5351 213912	BORIS MARTYNOV	{"phone": "+70610156403"}
0005434407319	6141DC	2487 472144	GALINA DENISOVA	{"phone": "+70096109819"}
0005434407320	6141DC	0399 047395	ALEKSEY ZHUKOV	{"email": "zhukov_aleksey_041970@postgrespro.ru", "phone": "+70751376156"}
0005434407321	A78153	2141 523029	EVGENIY IVANOV	{"email": "evgeniy.ivanov-101976@postgrespro.ru", "phone": "+70311600866"}
0005434407322	A78153	2404 731740	ALEKSANDR RODIONOV	{"phone": "+70697489336"}
0005434407323	BE226D	1528 927573	PAVEL KULIKOV	{"phone": "+70208756215"}
0005434407324	BE226D	3829 756078	OLEG SEMENOV	{"phone": "+70360924849"}
0005434407325	0E80A5	9282 860700	TIMUR MATVEEV	{"email": "matveevtimur081970@postgrespro.ru", "phone": "+70627463113"}
0005434407326	0E80A5	7830 751810	ALEKSANDR ALEKSEEV	{"phone": "+70160823290"}
0005434407327	0E80A5	0572 125920	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr_1970@postgrespro.ru", "phone": "+70604041382"}
0005434407328	64E35B	9186 781057	KSENIYA GERASIMOVA	{"email": "gerasimova_kseniya-1975@postgrespro.ru", "phone": "+70049902509"}
0005434407329	459915	1240 746761	ALEKSANDR VOLKOV	{"email": "a.volkov.031983@postgrespro.ru", "phone": "+70685659439"}
0005434407330	3489E6	6390 259632	LARISA MIKHAYLOVA	{"email": "lmikhaylova_13121967@postgrespro.ru", "phone": "+70342701769"}
0005434407331	0AAD30	6069 600595	VIKTOR SOLOVEV	{"phone": "+70471992911"}
0005434407332	3411D6	4419 115277	VLADIMIR IVANOV	{"email": "vladimir-ivanov-24061969@postgrespro.ru", "phone": "+70077817781"}
0005434407333	3411D6	5308 081203	ANATOLIY MARTYNOV	{"email": "martynova-1977@postgrespro.ru", "phone": "+70041596332"}
0005434407334	61ED10	7985 514014	ANATOLIY KUZMIN	{"email": "a.kuzmin061973@postgrespro.ru", "phone": "+70508332108"}
0005434407335	AA6AC9	9704 001058	TATYANA NIKOLAEVA	{"email": "t-nikolaeva_12111967@postgrespro.ru", "phone": "+70479751466"}
0005434407336	E8564F	4879 494987	NINA SERGEEVA	{"email": "nina_sergeeva-1967@postgrespro.ru", "phone": "+70699609699"}
0005434407337	807D4D	9543 909408	OLGA IVANOVA	{"email": "olga-ivanova_121971@postgrespro.ru", "phone": "+70933091956"}
0005434407338	5306C3	6535 378002	PAVEL KOROLEV	{"email": "pavel.korolev-1963@postgrespro.ru", "phone": "+70907655552"}
0005434407339	5306C3	1004 493997	VASILIY SAVELEV	{"phone": "+70182212177"}
0005434407340	2FC75C	4465 415868	ALEKSANDR IVANOV	{"phone": "+70475986503"}
0005434407341	39955F	3424 062774	DENIS KUZMIN	{"phone": "+70816619970"}
0005434407342	39955F	8385 329262	DARYA ALEKSEEVA	{"phone": "+70224362639"}
0005434407343	860F18	9472 396388	MIKHAIL ZAYCEV	{"phone": "+70528968371"}
0005434407344	767586	9203 208431	ALEKSANDR MAKAROV	{"phone": "+70423054941"}
0005434407345	AEBE44	8043 302512	ALEKSANDR MELNIKOV	{"email": "a.melnikov-28111976@postgrespro.ru", "phone": "+70377266228"}
0005434407512	366150	0958 234687	KONSTANTIN SMIRNOV	{"phone": "+70345852801"}
0005434407346	D7506C	6262 377984	MARINA SOROKINA	{"email": "sorokina.marina_26031990@postgrespro.ru", "phone": "+70615994535"}
0005434407347	62B356	2895 534669	EKATERINA MELNIKOVA	{"email": "ekaterina-melnikova.14081970@postgrespro.ru", "phone": "+70738596902"}
0005434407348	62B356	2596 822534	ALEKSEY PETROV	{"phone": "+70263620555"}
0005434407349	645368	0550 589100	ELENA AFANASEVA	{"email": "afanaseva_e06021981@postgrespro.ru", "phone": "+70724875703"}
0005434407350	35727A	7141 976750	KIRILL IVANOV	{"email": "ivanov.k-1969@postgrespro.ru", "phone": "+70097927991"}
0005434407351	3F86F7	1263 361239	SVETLANA BELOVA	{"phone": "+70587456706"}
0005434407352	3F86F7	1620 018567	LYUDMILA KALININA	{"email": "kalininalyudmila_081971@postgrespro.ru", "phone": "+70043902247"}
0005434407353	696C7C	2568 999518	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov.14041974@postgrespro.ru", "phone": "+70903611556"}
0005434407354	68F964	4013 233182	RAISA VOROBEVA	{"email": "vorobeva-r.1969@postgrespro.ru", "phone": "+70743617327"}
0005434407355	0196FD	5765 801825	IRINA CHERNOVA	{"email": "irina_chernova-021975@postgrespro.ru", "phone": "+70749131628"}
0005434407356	84B967	8363 858763	NATALYA OSIPOVA	{"email": "osipovanatalya101974@postgrespro.ru", "phone": "+70455314536"}
0005434407357	FC41D0	2540 763541	ARTEM TIKHONOV	{"email": "artem.tikhonov-1976@postgrespro.ru", "phone": "+70189924412"}
0005434407358	FC41D0	5166 094759	VLADIMIR BORISOV	{"email": "vladimir-borisov1982@postgrespro.ru", "phone": "+70336148305"}
0005434407359	B78C00	0058 437392	VASILIY VOROBEV	{"email": "v.vorobev1971@postgrespro.ru", "phone": "+70645246100"}
0005434407360	0DE02F	8683 668446	OLEG KULIKOV	{"email": "kulikovo_051965@postgrespro.ru", "phone": "+70428411737"}
0005434407361	0DE02F	8388 954266	MARIYA EFREMOVA	{"phone": "+70875197560"}
0005434407362	AB5D6F	1522 437082	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.31071965@postgrespro.ru", "phone": "+70787677602"}
0005434407363	C93063	1087 388797	LYUDMILA BELOVA	{"phone": "+70991532868"}
0005434407364	3873C6	2666 482055	TATYANA DANILOVA	{"phone": "+70747509416"}
0005434407365	7ABD27	5610 511497	LYUBOV BORISOVA	{"phone": "+70578182675"}
0005434407366	8518F5	6014 204415	VERA LEBEDEVA	{"email": "vera.lebedeva.041972@postgrespro.ru", "phone": "+70464107813"}
0005434407367	8518F5	9105 655130	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr_1961@postgrespro.ru", "phone": "+70954087798"}
0005434407368	574E9B	2029 885346	ALEKSEY IVANOV	{"phone": "+70353374367"}
0005434407369	26948A	5392 215141	ELENA SOKOLOVA	{"phone": "+70655706081"}
0005434407370	549C81	7360 702770	ELENA PAVLOVA	{"phone": "+70394187809"}
0005434407371	C625F9	2995 387648	MARINA KUZNECOVA	{"phone": "+70186863565"}
0005434407372	9C4663	5083 080876	VLADIMIR KUZNECOV	{"phone": "+70544617080"}
0005434407373	9C4663	3752 393096	GENNADIY KUZNECOV	{"phone": "+70656103088"}
0005434407374	DF1E76	7823 360734	EKATERINA GUSEVA	{"phone": "+70788007440"}
0005434407375	DF1E76	9231 250537	NATALYA ZAKHAROVA	{"phone": "+70572866059"}
0005434407376	035C33	1032 457298	ALEKSANDR MOROZOV	{"email": "morozov-a041969@postgrespro.ru", "phone": "+70142837562"}
0005434407377	C0CDBA	4305 717537	SVETLANA KOVALEVA	{"phone": "+70605352041"}
0005434407378	BF0D1D	5948 454095	ILYA ALEKSEEV	{"email": "ilya.alekseev_081969@postgrespro.ru", "phone": "+70921478551"}
0005434407379	BF0D1D	0353 848237	ZINAIDA ZHUKOVA	{"email": "zhukova.z_1975@postgrespro.ru", "phone": "+70540776958"}
0005434407380	2C3416	2123 599168	ANTONINA ARKHIPOVA	{"email": "a-arkhipova.1976@postgrespro.ru", "phone": "+70001413011"}
0005434407381	6BF1BA	4995 899668	VYACHESLAV YAKOVLEV	{"phone": "+70868511906"}
0005434407382	61BCEF	5294 787112	MARIYA SERGEEVA	{"email": "m-sergeeva.081961@postgrespro.ru", "phone": "+70322005631"}
0005434407383	D0BA50	9404 205536	LYUBOV NIKITINA	{"phone": "+70606014106"}
0005434407384	75518A	0345 606655	SERGEY IVANOV	{"email": "ivanov_sergey-19011979@postgrespro.ru", "phone": "+70451338391"}
0005434407385	75518A	7004 195136	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr1962@postgrespro.ru", "phone": "+70900569597"}
0005434407386	87F489	6828 081895	IRINA SIDOROVA	{"email": "sidorova.irina-111981@postgrespro.ru", "phone": "+70041207105"}
0005434407387	87F489	6012 146792	SERGEY ALEKSEEV	{"phone": "+70447870050"}
0005434407388	2ABAEC	6013 092114	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov22071974@postgrespro.ru", "phone": "+70548702450"}
0005434407389	E50C58	3715 671417	NATALYA DAVYDOVA	{"phone": "+70125999719"}
0005434407390	E07EA2	7176 237902	VALENTINA POPOVA	{"email": "popova-valentina.1965@postgrespro.ru", "phone": "+70305802387"}
0005434407391	3AE63D	4414 707010	MARIYA ANDREEVA	{"email": "m_andreeva.1967@postgrespro.ru", "phone": "+70669751611"}
0005434407392	4AC71D	3782 543419	ELENA BELOVA	{"email": "belova.e-04041991@postgrespro.ru", "phone": "+70325051816"}
0005434407393	2677AB	2258 781429	VALENTIN SIDOROV	{"phone": "+70645499365"}
0005434407394	FC356B	1727 101329	VALENTINA SCHERBAKOVA	{"phone": "+70569550684"}
0005434407395	6A7651	3692 055763	ALEKSEY ANTONOV	{"phone": "+70362043084"}
0005434407396	087942	5398 316699	VALERIY SEMENOV	{"email": "v.semenov-011982@postgrespro.ru", "phone": "+70056047483"}
0005434407397	087942	3904 140288	SVETLANA BORISOVA	{"email": "sborisova-24041977@postgrespro.ru", "phone": "+70725457647"}
0005434407398	94BA3F	4401 356845	OLGA EGOROVA	{"email": "oegorova29051968@postgrespro.ru", "phone": "+70819112596"}
0005434407399	94BA3F	3534 920038	ROMAN PAVLOV	{"phone": "+70529093694"}
0005434407400	86B214	4360 403355	EKATERINA ZAYCEVA	{"email": "e.zayceva_05111963@postgrespro.ru", "phone": "+70565654196"}
0005434407401	86B214	5157 562622	VIKTOR ILIN	{"email": "viktor.ilin-26031979@postgrespro.ru", "phone": "+70753232759"}
0005434407402	EE0B58	1063 410312	ANASTASIYA DENISOVA	{"email": "denisova-anastasiya.1956@postgrespro.ru", "phone": "+70979670257"}
0005434407403	EE0B58	7385 557420	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr-1962@postgrespro.ru", "phone": "+70046498549"}
0005434407404	E1A93E	0180 138413	SVETLANA RYABOVA	{"email": "ryabovas.02101966@postgrespro.ru", "phone": "+70036753306"}
0005434407405	89AAE5	3754 928454	ALEKSANDR VOLKOV	{"email": "avolkov081969@postgrespro.ru", "phone": "+70189318654"}
0005434407406	89AAE5	3969 605139	IVAN VOLKOV	{"email": "volkov_ivan.1988@postgrespro.ru", "phone": "+70584523980"}
0005434407407	E53CB8	3239 527675	OLGA GUSEVA	{"phone": "+70150374772"}
0005434407408	E53CB8	6344 574339	VALERIY KISELEV	{"email": "kiselev-v.1971@postgrespro.ru", "phone": "+70859058793"}
0005434407409	E3EBFE	8159 673897	ALEKSEY IVANOV	{"email": "aivanov16101968@postgrespro.ru", "phone": "+70281142244"}
0005434407410	CD2249	5808 944848	VALENTINA NIKITINA	{"email": "nikitina-v1966@postgrespro.ru", "phone": "+70315945046"}
0005434407411	CD2249	2427 327474	MARAT TARASOV	{"email": "m-tarasov_1967@postgrespro.ru", "phone": "+70323318824"}
0005434407412	CD2249	2311 275164	ALEKSEY SIDOROV	{"email": "sidorov-aleksey.1971@postgrespro.ru", "phone": "+70688690031"}
0005434407413	DD83B7	1037 100471	YURIY SOLOVEV	{"email": "ysolovev041986@postgrespro.ru", "phone": "+70966071483"}
0005434407414	5A3A49	7027 123870	MARINA EGOROVA	{"email": "m-egorova.12051968@postgrespro.ru", "phone": "+70890144172"}
0005434407415	6F0665	1567 313371	ELENA SIDOROVA	{"phone": "+70208396052"}
0005434407416	B029F8	3458 268296	NATALIYA KOMAROVA	{"email": "komarovan_091964@postgrespro.ru", "phone": "+70435269666"}
0005434407417	B029F8	7097 343626	SERGEY ZAKHAROV	{"phone": "+70790409556"}
0005434407418	0B8245	5200 646305	YURIY MAKSIMOV	{"phone": "+70347648756"}
0005434407419	93788C	3201 411141	ELENA SAVELEVA	{"email": "elena_saveleva07071977@postgrespro.ru", "phone": "+70862386960"}
0005434407420	C3082E	0575 790196	FEDOR SERGEEV	{"email": "f.sergeev_26051962@postgrespro.ru", "phone": "+70496429881"}
0005434407421	AADEE5	5145 384811	TATYANA VOROBEVA	{"phone": "+70478484368"}
0005434407422	9789DB	0797 221552	ARSEN KUDRYASHOV	{"phone": "+70650027472"}
0005434407423	9789DB	8450 436144	SVETLANA ANISIMOVA	{"phone": "+70593518147"}
0005434407424	ED47D5	9505 291163	ANNA MELNIKOVA	{"email": "anna_melnikova-031970@postgrespro.ru", "phone": "+70960405633"}
0005434407425	ED47D5	6399 181428	ALEKSANDR KUZNECOV	{"phone": "+70071990252"}
0005434407426	716A8C	6747 759852	ALEKSEY VOLKOV	{"email": "a-volkov.041968@postgrespro.ru", "phone": "+70467669144"}
0005434407427	1568BA	6901 326741	ELENA YUDINA	{"phone": "+70141321761"}
0005434407428	6E6C50	5746 042051	VALENTINA KAZAKOVA	{"email": "kazakova-v_091978@postgrespro.ru", "phone": "+70539444832"}
0005434407429	28965C	8167 286441	NIKITA KUZMIN	{"email": "nikita.kuzmin.02021968@postgrespro.ru", "phone": "+70222235559"}
0005434407430	28965C	9476 598545	EVGENIY POPOV	{"phone": "+70921025845"}
0005434407431	7D4C58	8545 838911	VALENTINA MIKHAYLOVA	{"phone": "+70146851688"}
0005434407432	76DDD6	7371 318629	DMITRIY ZAYCEV	{"phone": "+70073828305"}
0005434407433	963461	8281 526537	NELYA KARPOVA	{"email": "n.karpova1970@postgrespro.ru", "phone": "+70129569038"}
0005434407434	0F7AFB	6799 065285	ALEKSEY NAZAROV	{"phone": "+70549281263"}
0005434407435	0F7AFB	7653 452286	ALEKSANDR BELOV	{"email": "belov-aleksandr_1971@postgrespro.ru", "phone": "+70420444053"}
0005434407436	5DBDD4	5490 615640	ZARINA DAVYDOVA	{"email": "davydovazarina10011976@postgrespro.ru", "phone": "+70066923360"}
0005434407437	D9C3D8	7407 114229	TATYANA POPOVA	{"phone": "+70019453138"}
0005434407438	D9C3D8	1147 475830	DMITRIY MATVEEV	{"phone": "+70341954338"}
0005434407439	5DBEF2	7055 632735	KONSTANTIN MEDVEDEV	{"phone": "+70798415564"}
0005434407440	5DBEF2	2440 765003	OLGA KOVALEVA	{"email": "o_kovaleva_1981@postgrespro.ru", "phone": "+70395802338"}
0005434407441	D5DEBA	7361 239920	SOFIYA KUZNECOVA	{"phone": "+70392165412"}
0005434407442	2F87B6	0002 857664	SERGEY KOROLEV	{"phone": "+70723311811"}
0005434407443	2F87B6	0030 243341	MARIYA DMITRIEVA	{"email": "mdmitrieva.1968@postgrespro.ru", "phone": "+70192254929"}
0005434407444	F43CF4	7832 575252	NATALYA DENISOVA	{"email": "denisova_natalya-1962@postgrespro.ru", "phone": "+70961425353"}
0005434407445	8FF204	0110 396521	VALENTINA ANDREEVA	{"email": "andreeva_valentina-1968@postgrespro.ru", "phone": "+70337310405"}
0005434407446	29596C	8125 655993	NINA VASILEVA	{"email": "vasileva_nina.021976@postgrespro.ru", "phone": "+70498292831"}
0005434407447	432488	6800 056213	ALEKSANDRA NESTEROVA	{"email": "nesterovaa1975@postgrespro.ru", "phone": "+70760380912"}
0005434407448	FA018E	2666 399378	DANIIL DENISOV	{"email": "denisov.d1968@postgrespro.ru", "phone": "+70585975644"}
0005434407449	15B5B9	2080 842688	ILYA ISAEV	{"phone": "+70169598178"}
0005434407450	E1BA3D	1577 972701	YURIY SCHERBAKOV	{"phone": "+70531816949"}
0005434407451	E1BA3D	0759 091515	MARIANNA KAZAKOVA	{"phone": "+70901808681"}
0005434407452	BB3AD2	8402 359763	ARINA BOGDANOVA	{"email": "arina_bogdanova.1979@postgrespro.ru", "phone": "+70211276942"}
0005434407453	651F85	3260 517828	NADEZHDA GORBUNOVA	{"email": "gorbunova_nadezhda.13031976@postgrespro.ru", "phone": "+70338626311"}
0005434407454	DE2FBC	9175 879094	MIKHAIL EGOROV	{"phone": "+70036567212"}
0005434407455	A91FE8	9212 332549	OLGA STEPANOVA	{"email": "o.stepanova-011972@postgrespro.ru", "phone": "+70000569850"}
0005434407456	0227E6	2885 284722	VITALIY ROMANOV	{"phone": "+70413067885"}
0005434407457	5AFF45	3851 853592	TATYANA BARANOVA	{"email": "t.baranova.061971@postgrespro.ru", "phone": "+70426122513"}
0005434407458	E7676B	0721 751943	ANATOLIY IVANOV	{"phone": "+70046924176"}
0005434407459	E7676B	7772 381471	ELENA FILIPPOVA	{"phone": "+70970112311"}
0005434407460	D6B669	3919 705655	GRIGORIY ANTONOV	{"email": "antonov_g_1977@postgrespro.ru", "phone": "+70516015048"}
0005434407461	D6B669	3438 987801	GALINA TIKHONOVA	{"email": "tikhonova_galina.1978@postgrespro.ru", "phone": "+70538521656"}
0005434407462	598EC3	6653 920176	IRINA ARKHIPOVA	{"email": "irina-arkhipova.101975@postgrespro.ru", "phone": "+70521852057"}
0005434407463	66C55C	4833 845365	NADEZHDA FEDOROVA	{"phone": "+70509689614"}
0005434407464	68C405	5446 577205	VIKTOR SERGEEV	{"phone": "+70465341308"}
0005434407465	68C405	6546 736923	TAMARA ERMAKOVA	{"phone": "+70285632567"}
0005434407466	68C405	4155 167280	EKATERINA CHERNOVA	{"email": "chernova-ekaterina-11091961@postgrespro.ru", "phone": "+70219855233"}
0005434407467	C01AC5	6058 064290	ANDREY FILIPPOV	{"email": "filippov_andrey20061968@postgrespro.ru", "phone": "+70039459011"}
0005434407468	2AB2C3	3926 751529	RUSTEM OSIPOV	{"phone": "+70332219048"}
0005434407469	2AB2C3	2698 567728	EKATERINA DENISOVA	{"email": "ekaterina_denisova_011962@postgrespro.ru", "phone": "+70638599124"}
0005434407470	F81DCD	3157 852606	LYUDMILA TIKHONOVA	{"phone": "+70083214558"}
0005434407471	EDE04A	3076 222263	RUSLAN KUZNECOV	{"email": "kuznecov-ruslan_1968@postgrespro.ru", "phone": "+70948052906"}
0005434407472	22A720	3102 091214	TATYANA KUZNECOVA	{"phone": "+70705400146"}
0005434407473	22A720	2192 300686	ALSU KALININA	{"phone": "+70747598057"}
0005434407474	FF15E4	4448 747992	TATYANA AFANASEVA	{"email": "tatyana-afanaseva.06041975@postgrespro.ru", "phone": "+70321666622"}
0005434407475	767AC3	1721 780243	OLEG VLASOV	{"email": "o.vlasov.05101971@postgrespro.ru", "phone": "+70747522283"}
0005434407476	F18868	6485 391676	VIKTOR CHERNOV	{"email": "viktor_chernov121981@postgrespro.ru", "phone": "+70948339310"}
0005434407477	8803F0	4508 388019	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya_1970@postgrespro.ru", "phone": "+70211624949"}
0005434407478	8803F0	0652 717530	YANA NIKITINA	{"phone": "+70137460163"}
0005434407479	3EB57A	3323 320532	VERA POPOVA	{"email": "vera_popova-11031989@postgrespro.ru", "phone": "+70623742046"}
0005434407480	3EB57A	2074 561190	NADEZHDA DAVYDOVA	{"email": "nadezhda_davydova-021974@postgrespro.ru", "phone": "+70250411131"}
0005434407481	724140	2400 831689	IVAN POPOV	{"email": "popov.ivan_1978@postgrespro.ru", "phone": "+70247444995"}
0005434407482	556DDC	6260 717456	MARIYA MOROZOVA	{"phone": "+70027130243"}
0005434407483	63AC64	0365 849824	KONSTANTIN FEDOROV	{"phone": "+70930134894"}
0005434407484	AAE4FD	8330 004382	ALESYA ANISIMOVA	{"email": "anisimova_alesya1973@postgrespro.ru", "phone": "+70896973577"}
0005434407485	AF605E	3808 986764	NADEZHDA ZHURAVLEVA	{"phone": "+70360555303"}
0005434407486	187D92	8247 026808	NIKOLAY PAVLOV	{"email": "pavlovnikolay.101986@postgrespro.ru", "phone": "+70927363653"}
0005434407487	25916F	2668 128945	TAMARA SOKOLOVA	{"email": "t-sokolova_061993@postgrespro.ru", "phone": "+70891123382"}
0005434407601	15B246	5979 702857	YURIY ZAKHAROV	{"phone": "+70552990879"}
0005434407488	8C1CC5	6628 130522	IVAN KUZNECOV	{"email": "i-kuznecov.071965@postgrespro.ru", "phone": "+70303377094"}
0005434407489	4C23CB	0210 633502	VALERIY ZAYCEV	{"phone": "+70048696460"}
0005434407490	56CF04	9598 618722	NINEL NOVIKOVA	{"email": "novikovan.1967@postgrespro.ru", "phone": "+70953062426"}
0005434407491	B3D069	5691 858997	VIKTOR ISAEV	{"email": "v_isaev_111964@postgrespro.ru", "phone": "+70356159693"}
0005434407492	B3D069	4520 200594	ALEKSANDR ILIN	{"email": "ilin.a-04121974@postgrespro.ru", "phone": "+70651241908"}
0005434407493	7D9692	4386 823056	KIRILL MIKHAYLOV	{"phone": "+70700399723"}
0005434407494	096E92	9876 015610	IRINA ARKHIPOVA	{"email": "iarkhipova_111969@postgrespro.ru", "phone": "+70682704502"}
0005434407495	096E92	8593 373559	VIKTOR KONOVALOV	{"phone": "+70767831721"}
0005434407496	F410F2	3418 857250	SERGEY POPOV	{"email": "popov_sergey-01111982@postgrespro.ru", "phone": "+70539276322"}
0005434407497	9DD5E1	8167 831091	TATYANA DENISOVA	{"email": "denisova-t.22031974@postgrespro.ru", "phone": "+70095381617"}
0005434407498	9DD5E1	1017 796618	TATYANA RODIONOVA	{"email": "tatyana.rodionova1980@postgrespro.ru", "phone": "+70182922324"}
0005434407499	5E92C3	3643 574282	VALERIY ZAYCEV	{"email": "valeriy.zaycev.12121968@postgrespro.ru", "phone": "+70531896892"}
0005434407500	5E92C3	0561 531342	ALEKSANDR VASILEV	{"email": "vasilev-a.111979@postgrespro.ru", "phone": "+70490155409"}
0005434407501	8AFFFA	2865 224610	KSENIYA ILINA	{"phone": "+70280318978"}
0005434407502	8AFFFA	4008 235370	KRISTINA VOROBEVA	{"email": "vorobevakristina08041967@postgrespro.ru", "phone": "+70176396170"}
0005434407503	8AFFFA	4114 795365	YULIYA DENISOVA	{"phone": "+70504165089"}
0005434407504	086919	7614 088106	KONSTANTIN KRASNOV	{"phone": "+70754605921"}
0005434407505	173B4E	2309 107622	LYUDMILA ANTONOVA	{"email": "l.antonova-021968@postgrespro.ru", "phone": "+70417929128"}
0005434407506	173B4E	6398 543157	VIKTOR PETROV	{"phone": "+70088109618"}
0005434407507	EE060C	7958 059664	ALEKSANDR TARASOV	{"phone": "+70264979614"}
0005434407508	C7413E	1071 476518	VLADIMIR DENISOV	{"email": "vladimir-denisov26061975@postgrespro.ru", "phone": "+70840110605"}
0005434407509	C7413E	8920 512313	NINA SMIRNOVA	{"email": "smirnovanina-25051966@postgrespro.ru", "phone": "+70791819049"}
0005434407510	17FD9B	7513 701748	VALERIYA MOROZOVA	{"email": "valeriya.morozova011961@postgrespro.ru", "phone": "+70599636898"}
0005434407511	405C35	8064 854402	TATYANA NOVIKOVA	{"email": "novikova.tatyana.1975@postgrespro.ru", "phone": "+70967672497"}
0005434407513	366150	4207 423380	DMITRIY BELOV	{"email": "belovdmitriy_1971@postgrespro.ru", "phone": "+70652474142"}
0005434407514	11EABD	7070 356174	VLADIMIR KOZLOV	{"email": "kozlovvladimir_27111966@postgrespro.ru", "phone": "+70719404133"}
0005434407515	510C07	7960 061673	TAMARA DENISOVA	{"phone": "+70649377070"}
0005434407516	510C07	3518 484536	ELENA MOROZOVA	{"phone": "+70825835269"}
0005434407517	A7F639	2548 039222	OLGA SIDOROVA	{"email": "olgasidorova.111975@postgrespro.ru", "phone": "+70362243216"}
0005434407518	3F87BB	4153 283147	ALEKSANDR ALEKSANDROV	{"phone": "+70218178763"}
0005434407519	3F87BB	7880 914255	ANNA SOROKINA	{"phone": "+70636497796"}
0005434407520	8BA48B	9606 042052	ANDREY ILIN	{"email": "ilina-1968@postgrespro.ru", "phone": "+70417872091"}
0005434407521	5CCDD8	5394 488271	TATYANA NOVIKOVA	{"phone": "+70997314293"}
0005434407522	C22788	9857 883919	MIKHAIL RODIONOV	{"phone": "+70666147226"}
0005434407523	935BF1	7711 558876	SVETLANA MALYSHEVA	{"email": "malyshevasvetlana1966@postgrespro.ru", "phone": "+70729242108"}
0005434407524	935BF1	8958 217722	EVELINA SMIRNOVA	{"email": "smirnova_e16121974@postgrespro.ru", "phone": "+70586839295"}
0005434407525	584590	8839 592502	ELENA AFANASEVA	{"email": "eafanaseva01101969@postgrespro.ru", "phone": "+70316746141"}
0005434407526	2FE08F	8656 598096	VIKTOR STEPANOV	{"phone": "+70464070644"}
0005434407527	2B5C84	4914 499150	ANNA MAKAROVA	{"email": "a-makarova-28111967@postgrespro.ru", "phone": "+70103621721"}
0005434407528	B8D3E2	2203 757711	VIKTORIYA KOLESNIKOVA	{"phone": "+70979692048"}
0005434407529	B8D3E2	1667 689143	ALEKSEY PAVLOV	{"email": "pavlova_1979@postgrespro.ru", "phone": "+70294869869"}
0005434407530	B8D3E2	4774 619021	SVETLANA KUZMINA	{"email": "kuzminas.021978@postgrespro.ru", "phone": "+70139361690"}
0005434407531	652E11	2943 578471	ALSU MOROZOVA	{"email": "a.morozova_021969@postgrespro.ru", "phone": "+70284106547"}
0005434407532	652E11	9360 147968	VLADIMIR IVANOV	{"email": "vladimir-ivanov1972@postgrespro.ru", "phone": "+70678974904"}
0005434407533	C47EEC	7512 081904	LIDIYA FOMINA	{"email": "lidiya-fomina.26041968@postgrespro.ru", "phone": "+70786005771"}
0005434407534	310517	6771 694787	ZAKHAR KOZLOV	{"email": "zakhar_kozlov.19071974@postgrespro.ru", "phone": "+70756994671"}
0005434407535	F4364D	9575 109598	YANA KOROLEVA	{"phone": "+70358873191"}
0005434407536	F4364D	1122 142818	EVGENIYA FADEEVA	{"email": "e.fadeeva091975@postgrespro.ru", "phone": "+70369468704"}
0005434407537	360601	5070 628857	LYUDMILA TIKHONOVA	{"email": "lyudmila_tikhonova1976@postgrespro.ru", "phone": "+70275671727"}
0005434407538	360601	2119 923290	PAVEL ABRAMOV	{"phone": "+70816515194"}
0005434407539	220C05	7029 153674	GALINA TIMOFEEVA	{"email": "galina.timofeeva-27071967@postgrespro.ru", "phone": "+70748585481"}
0005434407540	220C05	4651 760657	ALEVTINA NESTEROVA	{"email": "nesterovaa-071973@postgrespro.ru", "phone": "+70497965270"}
0005434407541	22B729	0120 064264	IRINA TIMOFEEVA	{"phone": "+70364063110"}
0005434407542	C0E5E3	7606 694451	ELENA NAZAROVA	{"phone": "+70272474996"}
0005434407543	2EDFE4	9232 251191	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova.09111969@postgrespro.ru", "phone": "+70725193230"}
0005434407544	44FDC4	7811 364002	EGOR NAZAROV	{"email": "egor-nazarov_101965@postgrespro.ru", "phone": "+70142637756"}
0005434407545	090D99	9311 398334	SERGEY ANTONOV	{"phone": "+70475622210"}
0005434407546	090D99	6154 090783	LIDIYA ZHURAVLEVA	{"phone": "+70504265596"}
0005434407547	2CB945	2378 390275	SERGEY MIKHAYLOV	{"phone": "+70971546470"}
0005434407548	2CB945	5236 578661	ALLA KUZNECOVA	{"email": "alla-kuznecova.19091972@postgrespro.ru", "phone": "+70645714584"}
0005434407549	B1D155	0902 335831	ALIYA KUZNECOVA	{"email": "a.kuznecova-041966@postgrespro.ru", "phone": "+70090207251"}
0005434407550	57CDDB	7187 727081	RAMIS KOZLOV	{"email": "kozlovramis-1969@postgrespro.ru", "phone": "+70543526846"}
0005434407551	AF389E	3947 367442	ILYA SCHERBAKOV	{"email": "scherbakov-ilya-1977@postgrespro.ru", "phone": "+70952893456"}
0005434407552	0FEC05	1555 778430	KRISTINA GORBUNOVA	{"email": "gorbunova-kristina-061977@postgrespro.ru", "phone": "+70758556430"}
0005434407553	0FEC05	2201 849174	LIDIYA POPOVA	{"phone": "+70452765179"}
0005434407554	C7074C	3416 337343	ALEKSANDR BELOV	{"phone": "+70933430009"}
0005434407555	40B79D	8476 659592	ELENA VASILEVA	{"phone": "+70162225591"}
0005434407556	6411BE	6405 573466	IRINA KOROLEVA	{"email": "korolevai_121969@postgrespro.ru", "phone": "+70351324229"}
0005434407557	BB83A3	6295 065119	VIKTORIYA BORISOVA	{"email": "borisova.v-101974@postgrespro.ru", "phone": "+70195427646"}
0005434407558	F8C7A5	8922 987078	VLADIMIR KULIKOV	{"phone": "+70004183124"}
0005434407559	80EF15	6465 383082	NIKOLAY VOLKOV	{"email": "volkov_n1979@postgrespro.ru", "phone": "+70284035809"}
0005434407560	4E57DB	3405 620273	VITALIY DAVYDOV	{"email": "davydov_v_27121965@postgrespro.ru", "phone": "+70746472702"}
0005434407561	581B2F	9234 092647	GEORGIY SIDOROV	{"email": "sidorov-g1982@postgrespro.ru", "phone": "+70443629022"}
0005434407562	EE69A6	4323 971069	ANNA KOZLOVA	{"email": "kozlova.anna.1987@postgrespro.ru", "phone": "+70632588709"}
0005434407563	EE69A6	3897 431205	LYUDMILA ORLOVA	{"phone": "+70684689526"}
0005434407564	584239	1421 481486	ARTEM SIDOROV	{"phone": "+70220276230"}
0005434407565	B4119C	9832 265022	VALENTINA VASILEVA	{"phone": "+70019257289"}
0005434407566	9A212A	3541 455180	TATYANA YAKOVLEVA	{"phone": "+70709690621"}
0005434407567	D35EA6	8702 390183	EGOR TARASOV	{"email": "egor_tarasov.1967@postgrespro.ru", "phone": "+70932640902"}
0005434407568	91DF1E	0454 850599	ALEKSANDR POPOV	{"email": "popov.a.071962@postgrespro.ru", "phone": "+70574949950"}
0005434407569	5A5D45	9170 434692	TATYANA SERGEEVA	{"email": "tatyanasergeeva_1964@postgrespro.ru", "phone": "+70569227614"}
0005434407570	135CC3	9550 801042	VLADIMIR BELOV	{"phone": "+70753149101"}
0005434407571	D3D590	8194 905117	SERGEY GORBUNOV	{"email": "gorbunovsergey.22121976@postgrespro.ru", "phone": "+70729358457"}
0005434407572	359A58	5612 173440	ROMAN RODIONOV	{"phone": "+70339307924"}
0005434407573	9259BC	2055 502509	ARTEM TARASOV	{"email": "tarasovartem.08041967@postgrespro.ru", "phone": "+70591739732"}
0005434407574	11707B	4117 951396	VERA PAVLOVA	{"email": "pavlova_vera.08101977@postgrespro.ru", "phone": "+70772330633"}
0005434407575	11707B	2136 299944	ALEKSANDR SOLOVEV	{"email": "solovev_a.1978@postgrespro.ru", "phone": "+70094967454"}
0005434407576	F646E6	7066 901200	INESSA EGOROVA	{"email": "egorova.i-19061972@postgrespro.ru", "phone": "+70499036395"}
0005434407577	99FA85	4366 246200	LYUDMILA MIKHAYLOVA	{"phone": "+70959291975"}
0005434407578	5E04F8	2447 071339	KONSTANTIN TIKHONOV	{"email": "k-tikhonov1973@postgrespro.ru", "phone": "+70366345142"}
0005434407579	5E04F8	5102 819002	ALEKSANDR POPOV	{"email": "popov.a-14101974@postgrespro.ru", "phone": "+70712095609"}
0005434407580	5E04F8	4479 921504	OLGA NIKOLAEVA	{"phone": "+70672054762"}
0005434407581	0FA85C	1404 876031	EVGENIY GERASIMOV	{"phone": "+70961138485"}
0005434407582	A640B3	1235 436101	BORIS ALEKSEEV	{"phone": "+70417821768"}
0005434407583	0BAFBF	4908 261433	YULIYA TIKHONOVA	{"phone": "+70030503925"}
0005434407584	0BAFBF	6129 056595	EVGENIY IVANOV	{"email": "evgeniyivanov-081971@postgrespro.ru", "phone": "+70959353339"}
0005434407585	5F818F	0574 375287	ALEKSANDR KUZMIN	{"email": "a-kuzmin.24101977@postgrespro.ru", "phone": "+70970530684"}
0005434407586	EB9B76	4351 449666	TATYANA KONOVALOVA	{"phone": "+70976063667"}
0005434407587	7D85F9	4322 032185	RAISA KRASNOVA	{"phone": "+70340370835"}
0005434407588	7D85F9	0178 139105	MARIYA LAZAREVA	{"phone": "+70249314469"}
0005434407589	9AB955	7665 987115	LYUDMILA GRISHINA	{"phone": "+70555314190"}
0005434407590	C7A282	4924 893250	ANNA FILIPPOVA	{"phone": "+70468543243"}
0005434407591	C7A282	8876 191547	SERGEY KUZNECOV	{"email": "s-kuznecov_091962@postgrespro.ru", "phone": "+70171323010"}
0005434407592	1C09A3	6110 795093	VALERIY TIKHONOV	{"phone": "+70767692172"}
0005434407593	B4E9EE	5279 995955	LYUDMILA NAUMOVA	{"phone": "+70010590615"}
0005434407594	81F69D	0639 784080	YULIYA KOROLEVA	{"phone": "+70340093765"}
0005434407595	B09CFD	5164 144011	MARGARITA SMIRNOVA	{"phone": "+70538771144"}
0005434407596	1BFA38	8283 605560	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov12101979@postgrespro.ru", "phone": "+70079484841"}
0005434407597	1BFA38	4166 361698	OLGA NOVIKOVA	{"phone": "+70155171519"}
0005434407598	2B97E9	7299 218372	VYACHESLAV IVANOV	{"email": "ivanov.v-19041959@postgrespro.ru", "phone": "+70122383051"}
0005434407599	78A86C	2035 923575	LARISA ANISIMOVA	{"phone": "+70911944066"}
0005434407600	78A86C	8806 526901	YANINA ZAYCEVA	{"phone": "+70565250546"}
0005434407602	2E0864	9847 126371	MIKHAIL SCHERBAKOV	{"email": "mikhail_scherbakov-04061971@postgrespro.ru", "phone": "+70086413914"}
0005434407603	CDA65C	8474 735683	ELIZAVETA SOROKINA	{"phone": "+70862941164"}
0005434407604	CDA65C	1354 623251	TAMARA IVANOVA	{"phone": "+70736164653"}
0005434407605	CE83D2	7372 204346	ANTON VOROBEV	{"phone": "+70518694955"}
0005434407606	5B5BE3	0135 398669	YULIYA MEDVEDEVA	{"email": "yuliya.medvedeva1975@postgrespro.ru", "phone": "+70632391071"}
0005434407607	5B5BE3	8052 364073	SERGEY FEDOROV	{"email": "s_fedorov_1978@postgrespro.ru", "phone": "+70525623234"}
0005434407608	6E2367	1285 133699	VLADIMIR ANDREEV	{"phone": "+70217935090"}
0005434407609	6E2367	0082 437505	NATALYA LUKYANOVA	{"phone": "+70816028369"}
0005434407610	8C4188	0725 465870	VERA VLASOVA	{"email": "vlasova_v-18021980@postgrespro.ru", "phone": "+70378885378"}
0005434407611	8C4188	3116 022727	DMITRIY IVANOV	{"email": "dmitriy-ivanov_051974@postgrespro.ru", "phone": "+70631929639"}
0005434407612	1153EC	2155 878265	NIKITA ILIN	{"email": "n.ilin.1971@postgrespro.ru", "phone": "+70805840207"}
0005434407613	D7A105	9664 850064	ALEKSANDR KUZNECOV	{"email": "kuznecov-a111975@postgrespro.ru", "phone": "+70873107452"}
0005434407614	B74002	2667 981290	TATYANA STEPANOVA	{"email": "stepanovatatyana.1979@postgrespro.ru", "phone": "+70810012217"}
0005434407615	B74002	1754 297857	TATYANA MOROZOVA	{"email": "morozova.t031977@postgrespro.ru", "phone": "+70077878510"}
0005434407616	591473	5860 869773	KIRILL ROMANOV	{"phone": "+70609473763"}
0005434407617	B3AEEF	1300 232527	IVAN VOROBEV	{"phone": "+70924463958"}
0005434407618	AF02EF	1582 541933	ALISA SOKOLOVA	{"phone": "+70083681517"}
0005434407619	A90953	7126 409833	GENNADIY VASILEV	{"phone": "+70488086868"}
0005434407620	A90953	1664 798419	PRASKOVYA ORLOVA	{"phone": "+70494676033"}
0005434407621	B040F1	8581 711752	ANDREY SERGEEV	{"phone": "+70316203330"}
0005434407622	AF146B	1365 451396	TATYANA FROLOVA	{"phone": "+70286533571"}
0005434407623	2367FA	5450 201296	ALEKSEY ALEKSANDROV	{"phone": "+70032281480"}
0005434407624	2367FA	0269 879726	TATYANA GAVRILOVA	{"phone": "+70628450428"}
0005434407625	537912	1013 116772	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr_111973@postgrespro.ru", "phone": "+70531357062"}
0005434407626	C667AE	9997 513548	MARIYA IVANOVA	{"email": "ivanova.m.21011980@postgrespro.ru", "phone": "+70510258055"}
0005434407627	2C73ED	7016 489510	MARINA KOROLEVA	{"phone": "+70261972532"}
0005434407628	342856	2515 212029	OLGA SCHERBAKOVA	{"phone": "+70698973125"}
0005434407629	342856	7373 252877	ALEKSANDR MIRONOV	{"phone": "+70565224558"}
0005434407630	021FB2	0098 944745	ALEKSANDR PAVLOV	{"phone": "+70241588618"}
0005434407631	021FB2	9868 406553	PAVEL BARANOV	{"email": "pbaranov061971@postgrespro.ru", "phone": "+70159855603"}
0005434407632	D89603	9603 424491	GALINA DAVYDOVA	{"email": "davydova_g.111966@postgrespro.ru", "phone": "+70534068584"}
0005434407633	D89603	1562 906774	RUDOLF ISAEV	{"email": "isaev-r-101977@postgrespro.ru", "phone": "+70911616630"}
0005434407634	CAD817	8563 147718	SERGEY NAZAROV	{"email": "nazarov_s.061974@postgrespro.ru", "phone": "+70183656120"}
0005434407635	CAD817	8798 914067	ALEKSANDR VOLKOV	{"phone": "+70758203401"}
0005434407636	031998	9719 700445	ALEKSANDR ISAEV	{"email": "aleksandr.isaev-111961@postgrespro.ru", "phone": "+70994116679"}
0005434407637	031998	7499 246607	SERGEY SOLOVEV	{"phone": "+70659212151"}
0005434407638	C1F1B2	1864 899851	MAKSIM POPOV	{"email": "maksim.popov_091979@postgrespro.ru", "phone": "+70367959305"}
0005434407639	944704	2038 243123	EKATERINA MEDVEDEVA	{"email": "e.medvedeva-041971@postgrespro.ru", "phone": "+70491384797"}
0005434407640	4CE88D	8352 837041	VIKTOR KUZNECOV	{"phone": "+70648472983"}
0005434407641	CEB30A	7410 397661	ALEKSANDR KRASNOV	{"phone": "+70944445307"}
0005434407642	CEB30A	1443 956914	OLGA ZAKHAROVA	{"email": "zakharova_olga.051980@postgrespro.ru", "phone": "+70929042764"}
0005434407643	CEB30A	5197 529533	EKATERINA CHERNOVA	{"email": "chernovaekaterina20071972@postgrespro.ru", "phone": "+70088177831"}
0005434407644	59CBF5	8335 850565	ALEKSANDR KUZNECOV	{"phone": "+70455814951"}
0005434407645	C74CC9	4130 822446	ALEKSEY MIKHAYLOV	{"email": "a_mikhaylov-15071971@postgrespro.ru", "phone": "+70308102993"}
0005434407646	ABF10F	4105 969820	ALEKSANDRA GORBUNOVA	{"phone": "+70270679973"}
0005434407647	ABF10F	4717 953825	IRINA SMIRNOVA	{"phone": "+70353855406"}
0005434407648	E7DB9A	8931 798757	DMITRIY FILIPPOV	{"phone": "+70254146791"}
0005434407649	E7DB9A	5371 070773	ALEKSEY SERGEEV	{"email": "sergeev-aleksey-051971@postgrespro.ru", "phone": "+70050953682"}
0005434407650	5FA7D4	9087 907215	SERGEY ALEKSEEV	{"phone": "+70391307543"}
0005434407651	5FA7D4	2458 881686	KRISTINA KUZNECOVA	{"email": "kkuznecova_1978@postgrespro.ru", "phone": "+70883981520"}
0005434407652	3C6542	5765 010480	YURIY BORISOV	{"phone": "+70106114700"}
0005434407653	400684	3705 302774	ALEKSANDR ZHURAVLEV	{"phone": "+70423628878"}
0005434407654	B9818A	9324 503612	EVGENIY KONOVALOV	{"phone": "+70248422906"}
0005434407655	2F6BDE	2277 750351	DMITRIY FEDOROV	{"email": "fedorov_dmitriy.05091981@postgrespro.ru", "phone": "+70177407003"}
0005434407656	F7EC62	0916 971969	IVAN VASILEV	{"phone": "+70345984116"}
0005434407657	F7EC62	8597 860807	PAVEL VOLKOV	{"phone": "+70352116654"}
0005434407658	F7EC62	3593 260399	ALEKSEY KOZLOV	{"phone": "+70342958017"}
0005434407659	EB8E09	3177 902236	VLADIMIR VOLKOV	{"phone": "+70811484644"}
0005434407660	11962F	7433 924954	NADEZHDA BELOVA	{"email": "belova.nadezhda-27051983@postgrespro.ru", "phone": "+70067795428"}
0005434407661	344708	0881 783344	OLGA KOZLOVA	{"email": "kozlova-olga03051972@postgrespro.ru", "phone": "+70817178623"}
0005434407662	9B8667	7795 021994	VADIM KUDRYASHOV	{"email": "kudryashovvadim_041965@postgrespro.ru", "phone": "+70271935271"}
0005434407663	B77A5F	0919 191752	RUMIYA KONOVALOVA	{"email": "rumiya.konovalova_1982@postgrespro.ru", "phone": "+70108451722"}
0005434407664	90A3E3	3866 479351	YURIY SAVELEV	{"email": "savelevyuriy.051982@postgrespro.ru", "phone": "+70697443068"}
0005434407665	2F9C77	5196 015105	VIKTOR SMIRNOV	{"email": "viktorsmirnov26041974@postgrespro.ru", "phone": "+70926009116"}
0005434407666	2F9C77	2993 547408	DMITRIY NOVIKOV	{"phone": "+70163158657"}
0005434407667	7CEA34	1211 400836	SVETLANA NOVIKOVA	{"email": "s.novikova1966@postgrespro.ru", "phone": "+70722376654"}
0005434407668	7CEA34	8391 083691	SVETLANA DANILOVA	{"phone": "+70526720617"}
0005434407669	DA22D4	8950 509941	TATYANA ILINA	{"phone": "+70436446904"}
0005434407670	F2A3BB	5576 907700	NIKOLAY FROLOV	{"email": "frolov-nikolay-1977@postgrespro.ru", "phone": "+70733620497"}
0005434407671	F2A3BB	0609 298680	OKSANA NIKITINA	{"email": "nikitina.oksana-05031957@postgrespro.ru", "phone": "+70914005334"}
0005434407672	97B096	9254 672439	ELENA MELNIKOVA	{"phone": "+70116316244"}
0005434407673	97B096	9586 747584	TATYANA KOROLEVA	{"email": "tkoroleva-1980@postgrespro.ru", "phone": "+70663921485"}
0005434407674	D185D8	5352 415217	VALERIY NIKITIN	{"email": "nikitin.valeriy1973@postgrespro.ru", "phone": "+70937131601"}
0005434407675	5E78E6	2042 824129	RADIK PAVLOV	{"phone": "+70866943865"}
0005434407676	4C400E	3654 768824	ELENA GRISHINA	{"email": "e_grishina_1981@postgrespro.ru", "phone": "+70072691441"}
0005434407677	34447D	0405 273757	SERGEY NAUMOV	{"phone": "+70463552814"}
0005434407678	74FAF1	2000 663903	KSENIYA GAVRILOVA	{"phone": "+70502849064"}
0005434407679	74FAF1	5191 954344	LILIYA EFREMOVA	{"email": "l-efremova_06031971@postgrespro.ru", "phone": "+70834894501"}
0005434407680	9E67B6	9789 081059	VLADIMIR SOROKIN	{"email": "sorokin-vladimir-18061978@postgrespro.ru", "phone": "+70034770432"}
0005434407681	9E67B6	5804 805659	NADEZHDA BELYAEVA	{"phone": "+70282556396"}
0005434407682	411FED	1274 663600	ELENA BELYAEVA	{"phone": "+70184297752"}
0005434407683	6F0FE0	5528 174951	VLADIMIR KONOVALOV	{"phone": "+70200457776"}
0005434407684	8060FC	2573 638948	IVAN DENISOV	{"phone": "+70893538733"}
0005434407685	61F6A8	9335 822691	DMITRIY ABRAMOV	{"email": "d.abramov23011973@postgrespro.ru", "phone": "+70417520089"}
0005434407686	61F6A8	1573 709012	KSENIYA MOROZOVA	{"email": "morozova-k_041977@postgrespro.ru", "phone": "+70260244392"}
0005434407687	67D080	7873 836720	ELENA KUZNECOVA	{"email": "kuznecova-elena_071967@postgrespro.ru", "phone": "+70878463539"}
0005434407688	67D080	1693 417817	ALEKSEY SHEVCHENKO	{"email": "a-shevchenko.071973@postgrespro.ru", "phone": "+70269693706"}
0005434407689	FF7ABC	0511 798603	ALEKSANDRA MOISEEVA	{"email": "a-moiseeva.1965@postgrespro.ru", "phone": "+70011448129"}
0005434407690	85D6E6	1669 768691	TAMARA SMIRNOVA	{"phone": "+70094523113"}
0005434407691	85D6E6	8263 688024	MARIYA SIDOROVA	{"email": "sidorovam_031972@postgrespro.ru", "phone": "+70486382665"}
0005434407692	85D6E6	9830 181575	ALEKSEY SOKOLOV	{"phone": "+70068737979"}
0005434407693	FBD452	4539 342446	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr.1971@postgrespro.ru", "phone": "+70159952462"}
0005434407694	DDCDCF	4967 765947	NATALYA NOVIKOVA	{"email": "natalya-novikova-1971@postgrespro.ru", "phone": "+70788427243"}
0005434407695	89250A	5819 204901	NATALYA SMIRNOVA	{"phone": "+70978024957"}
0005434407696	BD0F25	2897 500325	LYUBOV KULIKOVA	{"phone": "+70214892295"}
0005434407697	046AFD	5473 434523	ANASTASIYA YUDINA	{"email": "anastasiya_yudina-28091970@postgrespro.ru", "phone": "+70130630559"}
0005434407698	046AFD	6014 454952	VERONIKA NAZAROVA	{"email": "veronika.nazarova-1971@postgrespro.ru", "phone": "+70001735479"}
0005434407699	046AFD	6790 046750	ANASTASIYA ALEKSEEVA	{"phone": "+70495350611"}
0005434407700	B0575E	6725 491516	IRINA STEPANOVA	{"phone": "+70311674915"}
0005434407701	2E635E	3076 273109	VLADIMIR FEDOTOV	{"email": "vladimir_fedotov09011967@postgrespro.ru", "phone": "+70069612714"}
0005434407702	350183	2528 557215	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_08111979@postgrespro.ru", "phone": "+70312778989"}
0005434407703	350183	4174 861784	YURIY VOLKOV	{"email": "volkov.y_10031979@postgrespro.ru", "phone": "+70978872610"}
0005434407704	DBD585	9889 752146	TATYANA MALYSHEVA	{"phone": "+70879065621"}
0005434407705	DBD585	1629 179413	ALEKSANDR FOMIN	{"email": "aleksandr-fomin081969@postgrespro.ru", "phone": "+70296176256"}
0005434407706	E76DE7	3258 013470	IRINA AFANASEVA	{"phone": "+70434060937"}
0005434407707	A1DC28	4240 546335	IRINA KOVALEVA	{"email": "i-kovaleva_1969@postgrespro.ru", "phone": "+70928643170"}
0005434407708	A1DC28	1750 648270	ALEKSANDR NIKOLAEV	{"phone": "+70207407697"}
0005434407709	A1DC28	4089 349895	SERGEY ORLOV	{"phone": "+70320126159"}
0005434407710	A0E2C2	4063 630253	ALEKSANDR ZAKHAROV	{"phone": "+70575682783"}
0005434407711	C1F63B	8413 392390	ANNA ANISIMOVA	{"email": "anna_anisimova_051967@postgrespro.ru", "phone": "+70217169214"}
0005434407712	77DE0C	9911 975134	ALEKSANDR VOLKOV	{"email": "volkov-a-1970@postgrespro.ru", "phone": "+70424883781"}
0005434407713	7E1D56	1402 941001	ALEKSANDRA RODIONOVA	{"email": "a-rodionova_30061972@postgrespro.ru", "phone": "+70494984792"}
0005434407714	820806	5550 390316	DMITRIY KUDRYASHOV	{"email": "dmitriy.kudryashov121976@postgrespro.ru", "phone": "+70364177284"}
0005434407715	820806	2411 433228	TAISIYA MOROZOVA	{"phone": "+70295826042"}
0005434407716	A2E78C	9272 346121	IRINA PETROVA	{"email": "i.petrova_1979@postgrespro.ru", "phone": "+70432850512"}
0005434407717	A2E78C	5300 504950	OLGA MAKSIMOVA	{"email": "maksimova_o071970@postgrespro.ru", "phone": "+70769107819"}
0005434407718	79A525	4161 368954	OLGA MALYSHEVA	{"email": "malysheva_olga-1974@postgrespro.ru", "phone": "+70487631672"}
0005434407719	F2CB48	6760 078413	IRINA ANDREEVA	{"phone": "+70544429769"}
0005434407720	F2CB48	2879 536921	GENNADIY NAZAROV	{"email": "gennadiy_nazarov-30011973@postgrespro.ru", "phone": "+70464139203"}
0005434407721	F2CB48	6647 288366	ALEKSANDR IVANOV	{"phone": "+70204416380"}
0005434407722	672BAF	7736 714266	SOFIYA MATVEEVA	{"email": "sofiyamatveeva_12051978@postgrespro.ru", "phone": "+70305132904"}
0005434407723	3F73B3	8918 032177	VIKTOR SMIRNOV	{"email": "smirnov.v.081965@postgrespro.ru", "phone": "+70378325416"}
0005434407724	0421D3	7606 465635	LIDIYA YUDINA	{"phone": "+70660903994"}
0005434407725	2B27E8	4279 680977	ARTEM POPOV	{"email": "artem-popov_091968@postgrespro.ru", "phone": "+70010607029"}
0005434407726	5454A4	7729 239552	ARTEM FEDOTOV	{"email": "fedotov-a.061973@postgrespro.ru", "phone": "+70082460271"}
0005434407727	F5D3DC	2584 028865	ALEKSEY SAVELEV	{"phone": "+70607313467"}
0005434407728	EEB81A	7456 437029	PETR TARASOV	{"email": "ptarasov011970@postgrespro.ru", "phone": "+70438587475"}
0005434407729	D107D1	8960 726136	ANDREY KUZNECOV	{"phone": "+70036109206"}
0005434407730	D26491	6452 458532	LYUBOV KOROLEVA	{"phone": "+70470418364"}
0005434407731	F146CE	3930 455059	SERGEY SOKOLOV	{"phone": "+70096244435"}
0005434407732	F146CE	3897 385188	LYUDMILA ORLOVA	{"email": "orloval-041982@postgrespro.ru", "phone": "+70058904832"}
0005434407733	F146CE	9739 670445	EVGENIYA POTAPOVA	{"phone": "+70187292626"}
0005434407734	7C5180	5740 970442	ELENA KOMAROVA	{"phone": "+70672238077"}
0005434407735	7C5180	8857 794603	IVAN RODIONOV	{"phone": "+70408410940"}
0005434407736	F73469	1212 593483	ALEKSANDR DMITRIEV	{"phone": "+70610778495"}
0005434407737	4E40DA	8600 589418	OLGA MAKAROVA	{"phone": "+70303992109"}
0005434407738	3CA64F	4594 845591	LIDIYA STEPANOVA	{"phone": "+70122079252"}
0005434407739	550F9B	5636 795321	RINAT IVANOV	{"email": "r-ivanov.061968@postgrespro.ru", "phone": "+70041800326"}
0005434407740	6B96DC	9926 975139	DANILA ANDREEV	{"phone": "+70693056173"}
0005434407741	6B96DC	2923 877260	RUSLAN KUZNECOV	{"email": "kuznecov_r.1976@postgrespro.ru", "phone": "+70907835858"}
0005434407742	A0E4AD	5677 590434	EKATERINA GORBUNOVA	{"phone": "+70757043378"}
0005434407743	B00EE1	3569 558961	VERA ALEKSANDROVA	{"phone": "+70729539201"}
0005434407744	B00EE1	2685 719066	ANDREY TIKHONOV	{"phone": "+70698536692"}
0005434407745	B00AEE	6643 835175	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova_svetlana13041972@postgrespro.ru", "phone": "+70042506065"}
0005434407746	62BB76	4575 024090	ELENA VASILEVA	{"phone": "+70677299520"}
0005434407747	DAC3B3	5958 348924	TATYANA MEDVEDEVA	{"phone": "+70002529618"}
0005434407748	41F988	1600 591757	MARINA KARPOVA	{"phone": "+70742840601"}
0005434407749	AB6771	0021 386584	DINARA ISAEVA	{"email": "isaeva_d-1982@postgrespro.ru", "phone": "+70927063754"}
0005434407750	6DCCFC	3255 064152	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.04101977@postgrespro.ru", "phone": "+70875695597"}
0005434407751	330069	7586 015585	ALEVTINA ARKHIPOVA	{"phone": "+70994963613"}
0005434407752	682CBC	7890 910016	ANATOLIY AFANASEV	{"phone": "+70582670843"}
0005434407753	7F717D	7092 326380	ELENA NESTEROVA	{"phone": "+70535628577"}
0005434407754	76EBFB	9558 801773	EVGENIY BELOV	{"phone": "+70045192700"}
0005434407755	A5F4EB	9057 862959	NIKOLAY FROLOV	{"email": "frolov-nikolay061967@postgrespro.ru", "phone": "+70072642803"}
0005434407756	064499	6245 289118	EVGENIY GRIGOREV	{"phone": "+70307937956"}
0005434407816	B48F4D	1597 297515	NIKITA GAVRILOV	{"phone": "+70003989128"}
0005434407757	064499	3833 229229	ALBERT VLASOV	{"email": "a.vlasov_23021969@postgrespro.ru", "phone": "+70370665499"}
0005434407758	114E79	3014 752313	ELIZAVETA NIKITINA	{"phone": "+70469667725"}
0005434407759	F862E2	6019 731285	NADEZHDA DANILOVA	{"phone": "+70504919177"}
0005434407760	D9BB0C	9223 258356	LYUDMILA BARANOVA	{"email": "baranova.lyudmila-03091970@postgrespro.ru", "phone": "+70437165049"}
0005434407761	3E2D88	5364 456852	IRINA ILINA	{"email": "ilina_irina.09041971@postgrespro.ru", "phone": "+70320626731"}
0005434407762	42D34F	2493 847523	YURIY ZAYCEV	{"email": "zaycev.yuriy.1963@postgrespro.ru", "phone": "+70929012521"}
0005434407763	2F90CA	3181 851515	ROMAN KONOVALOV	{"email": "r.konovalov17121972@postgrespro.ru", "phone": "+70315090872"}
0005434407764	2F90CA	1124 532547	NINA ZHUKOVA	{"phone": "+70377268417"}
0005434407765	05B66D	3820 420564	ILGIZ KARPOV	{"phone": "+70912669955"}
0005434407766	05B66D	9263 181853	OLGA MATVEEVA	{"email": "matveeva_olga.101977@postgrespro.ru", "phone": "+70178037610"}
0005434407767	C8F45F	8952 335881	SERGEY FROLOV	{"email": "s-frolov101961@postgrespro.ru", "phone": "+70957970028"}
0005434407768	D4F58A	8845 187740	OLGA ZHURAVLEVA	{"phone": "+70961078880"}
0005434407769	192E4C	9407 852521	NINA AFANASEVA	{"email": "afanaseva.nina_1974@postgrespro.ru", "phone": "+70966236215"}
0005434407770	27BD18	8655 334512	VADIM PAVLOV	{"email": "pavlovv-19051974@postgrespro.ru", "phone": "+70120432120"}
0005434407771	270FB8	4584 538551	ALEKSANDR PETROV	{"email": "aleksandr_petrov_091979@postgrespro.ru", "phone": "+70734948709"}
0005434407772	270FB8	3736 626934	SERGEY TARASOV	{"email": "sergeytarasov21081972@postgrespro.ru", "phone": "+70641445005"}
0005434407773	270FB8	4723 750713	MAKSIM NOVIKOV	{"phone": "+70061627178"}
0005434407774	4B4D2E	5051 816484	YAN BORISOV	{"phone": "+70435729446"}
0005434407775	4B4D2E	1151 245863	PAVEL SAVELEV	{"phone": "+70365312608"}
0005434407776	98399B	6371 845957	MIKHAIL MELNIKOV	{"phone": "+70375155651"}
0005434407777	CAF0C4	7822 571584	EVDOKIYA MOISEEVA	{"email": "moiseeva.e.081961@postgrespro.ru", "phone": "+70065002625"}
0005434407778	CAF0C4	1776 044527	VALENTINA FROLOVA	{"email": "v-frolova19091975@postgrespro.ru", "phone": "+70575877397"}
0005434407779	1113E5	9856 228271	YULIYA IVANOVA	{"email": "ivanovayuliya_25111968@postgrespro.ru", "phone": "+70006877443"}
0005434407780	06F5F6	1161 071152	MIKHAIL KARPOV	{"email": "mikhailkarpov.1967@postgrespro.ru", "phone": "+70106245663"}
0005434407781	06F5F6	0447 625317	GLEB KULIKOV	{"phone": "+70728766038"}
0005434407782	6D15B2	5061 729452	VIKTOR DENISOV	{"phone": "+70416100012"}
0005434407783	40D28A	7349 332281	DARYA SERGEEVA	{"email": "darya_sergeeva-021969@postgrespro.ru", "phone": "+70483300488"}
0005434407784	40D28A	3140 346469	LARISA IVANOVA	{"email": "ivanova-larisa.23081967@postgrespro.ru", "phone": "+70556521035"}
0005434407785	DA6507	2258 882457	ELIZAVETA PETROVA	{"phone": "+70146620997"}
0005434407786	DA6507	5862 021603	MIKHAIL KAZAKOV	{"phone": "+70036732419"}
0005434407787	5B7683	3396 824775	VALERIY BARANOV	{"email": "valeriy.baranov-061958@postgrespro.ru", "phone": "+70331402100"}
0005434407788	CE08F3	4501 118750	STEPAN IVANOV	{"phone": "+70769024396"}
0005434407789	CE08F3	7166 097137	IGOR DAVYDOV	{"email": "davydovi-1978@postgrespro.ru", "phone": "+70274678437"}
0005434407790	CE08F3	1498 189760	ANNA VOROBEVA	{"phone": "+70285250012"}
0005434407791	6BE7E8	4678 759242	OKSANA SMIRNOVA	{"phone": "+70667124402"}
0005434407792	91B2A2	2904 657299	ALEKSEY SCHERBAKOV	{"phone": "+70124069772"}
0005434407793	FFCFDB	2560 186486	VLADIMIR KOROLEV	{"phone": "+70218924611"}
0005434407794	FFCFDB	5217 544719	YANA ANDREEVA	{"phone": "+70065676238"}
0005434407795	E42BB5	0659 667779	VALENTINA TIKHONOVA	{"email": "tikhonovavalentina-041976@postgrespro.ru", "phone": "+70870460261"}
0005434407796	491DDF	4727 462905	DARYA KISELEVA	{"email": "d.kiseleva.1976@postgrespro.ru", "phone": "+70116064416"}
0005434407797	5A6F31	2557 822997	NINA MOISEEVA	{"phone": "+70753450374"}
0005434407798	5A6F31	8123 511100	NINA SIDOROVA	{"email": "nina.sidorova_1982@postgrespro.ru", "phone": "+70134611963"}
0005434407799	C14E4E	8757 639661	DMITRIY OSIPOV	{"email": "osipovdmitriy_081976@postgrespro.ru", "phone": "+70429788222"}
0005434407800	8C1006	7694 412394	MARGARITA MATVEEVA	{"email": "matveevamargarita13121979@postgrespro.ru", "phone": "+70602458534"}
0005434407801	8C1006	5560 634731	TATYANA ZAYCEVA	{"email": "zayceva-t-18041985@postgrespro.ru", "phone": "+70753655665"}
0005434407802	F1B67D	3315 755015	VALENTINA SOROKINA	{"email": "sorokina-valentina_08011973@postgrespro.ru", "phone": "+70375647409"}
0005434407803	6BC2B4	4983 977799	VASILIY MIKHAYLOV	{"phone": "+70121251335"}
0005434407804	B39A73	8805 442480	ELENA YUDINA	{"email": "e_yudina.011976@postgrespro.ru", "phone": "+70412161267"}
0005434407805	B39A73	9136 384036	ELENA AFANASEVA	{"email": "elena-afanaseva.20101980@postgrespro.ru", "phone": "+70545461539"}
0005434407806	B39A73	2947 874752	IGOR ALEKSANDROV	{"phone": "+70997341544"}
0005434407807	65ABB0	2431 827659	VLADIMIR MEDVEDEV	{"email": "vladimirmedvedev1983@postgrespro.ru", "phone": "+70557941276"}
0005434407808	8B1618	2143 556089	SVETLANA DAVYDOVA	{"email": "davydova_svetlana.14081980@postgrespro.ru", "phone": "+70267023366"}
0005434407809	8B1618	1426 310280	LIDIYA ANDREEVA	{"phone": "+70058796687"}
0005434407810	8B1618	5492 528953	ELIZAVETA VOROBEVA	{"email": "vorobeva-elizaveta041972@postgrespro.ru", "phone": "+70349355464"}
0005434407811	923655	9538 059559	OLGA TITOVA	{"phone": "+70709183877"}
0005434407812	D6EA61	8062 818110	OLGA KRASNOVA	{"email": "krasnovaolga.29121978@postgrespro.ru", "phone": "+70477658899"}
0005434407813	2193D9	6830 553788	NIKOLAY IVANOV	{"email": "ivanov.n.051976@postgrespro.ru", "phone": "+70636645402"}
0005434407814	FE826A	3041 799825	LYUBOV KOZLOVA	{"email": "kozlova-l-081972@postgrespro.ru", "phone": "+70020476200"}
0005434407815	16302F	9360 084611	DARINA NAUMOVA	{"phone": "+70747636200"}
0005434407817	B48F4D	3774 404207	MARINA KAZAKOVA	{"phone": "+70946932557"}
0005434407818	B48F4D	8937 648646	NATALYA MASLOVA	{"email": "n.maslova_111969@postgrespro.ru", "phone": "+70364404687"}
0005434407819	B48F4D	3877 670518	TATYANA MASLOVA	{"phone": "+70251147901"}
0005434407820	C05EA1	9805 197725	TATYANA KOLESNIKOVA	{"phone": "+70142705361"}
0005434407821	F85AB8	6954 243824	NATALYA LAZAREVA	{"phone": "+70181397335"}
0005434407822	19B03A	4745 219165	ALEKSANDR DMITRIEV	{"phone": "+70179601463"}
0005434407823	19B03A	5780 316098	VALENTINA KONOVALOVA	{"email": "konovalovav.12091965@postgrespro.ru", "phone": "+70687319649"}
0005434407824	78AC51	5150 774432	OLGA TARASOVA	{"email": "tarasova.olga091972@postgrespro.ru", "phone": "+70276595262"}
0005434407825	86E993	4533 362498	LYUBOV FROLOVA	{"phone": "+70780383721"}
0005434407826	1870E9	4543 760129	EVGENIY PETROV	{"phone": "+70736030336"}
0005434407827	A56BCB	7539 220697	EKATERINA SEMENOVA	{"phone": "+70693870850"}
0005434407828	F2121E	5592 914951	IGOR SIDOROV	{"email": "sidorov.i-051971@postgrespro.ru", "phone": "+70461073195"}
0005434407829	5E1EF1	3953 264118	SERGEY MIRONOV	{"email": "mironov.s-10061967@postgrespro.ru", "phone": "+70138150700"}
0005434407830	8FDD9B	3065 426211	EVGENIYA BARANOVA	{"phone": "+70866526807"}
0005434407831	8FDD9B	8078 804159	TAMARA MOISEEVA	{"email": "moiseeva.t_061972@postgrespro.ru", "phone": "+70146753211"}
0005434407832	F9F62E	6022 687972	LIDIYA FROLOVA	{"phone": "+70347670772"}
0005434407833	F9F62E	1623 527668	VLADISLAV PETROV	{"phone": "+70322673952"}
0005434407834	7D4B2E	0694 352743	LYUBOV TARASOVA	{"email": "ltarasova-091968@postgrespro.ru", "phone": "+70157064993"}
0005434407835	326E20	0751 079347	VALERIY IVANOV	{"phone": "+70099943095"}
0005434407836	AE3B8C	3238 768486	SERGEY IVANOV	{"phone": "+70260691753"}
0005434407837	AE3B8C	4559 405158	LEONID TIMOFEEV	{"phone": "+70239432164"}
0005434407838	1B24C1	4068 064449	SERGEY NAZAROV	{"email": "nazarov-sergey-1954@postgrespro.ru", "phone": "+70660064733"}
0005434407839	AC230C	2144 538316	MARIYA ZAKHAROVA	{"email": "zakharova.m_1966@postgrespro.ru", "phone": "+70861647245"}
0005434407840	AC230C	3805 409541	VASILIY DAVYDOV	{"phone": "+70009310498"}
0005434407841	0C8D7A	1315 249783	OKSANA ZHUKOVA	{"phone": "+70080796638"}
0005434407842	CE2F4B	3806 780509	MIKHAIL MOROZOV	{"phone": "+70246302664"}
0005434407843	CE2F4B	3622 535748	MARIYA BELOVA	{"email": "m.belova.18081990@postgrespro.ru", "phone": "+70595742213"}
0005434407844	FC0BC8	8207 112213	VIKTORIYA GAVRILOVA	{"phone": "+70578767010"}
0005434407845	FC0BC8	2874 328029	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr-26081970@postgrespro.ru", "phone": "+70135474095"}
0005434407846	FC0BC8	7254 901291	ALBINA SERGEEVA	{"email": "a_sergeeva_1970@postgrespro.ru", "phone": "+70621444661"}
0005434407847	1CA493	8308 359218	VIKTOR GORBUNOV	{"email": "gorbunovviktor03051981@postgrespro.ru", "phone": "+70076465291"}
0005434407848	C44E2C	4659 782843	ALINA GORBUNOVA	{"phone": "+70304848423"}
0005434407849	C80068	3800 418270	SVETLANA MATVEEVA	{"phone": "+70779977036"}
0005434407850	1A5221	6548 362768	ALEKSANDR MAKSIMOV	{"phone": "+70442874509"}
0005434407851	9FD087	9701 912136	OLGA DAVYDOVA	{"phone": "+70441554382"}
0005434407852	9FD087	9547 996042	TATYANA KUZNECOVA	{"email": "t_kuznecova091968@postgrespro.ru", "phone": "+70617198686"}
0005434407853	9FD087	7261 295059	YURIY DAVYDOV	{"email": "davydov_yuriy25031976@postgrespro.ru", "phone": "+70279186077"}
0005434407854	BC5A18	5326 807773	ANTON PAVLOV	{"email": "anton.pavlov.031979@postgrespro.ru", "phone": "+70857828745"}
0005434407855	111C34	4233 271864	OLESYA TARASOVA	{"email": "tarasova_olesya.081975@postgrespro.ru", "phone": "+70543855075"}
0005434407856	111C34	9188 874925	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov-1978@postgrespro.ru", "phone": "+70348242695"}
0005434407857	111C34	8825 701266	EVGENIY SOKOLOV	{"email": "esokolov_29051958@postgrespro.ru", "phone": "+70270998965"}
0005434407858	111C34	8555 023849	DANIL TIMOFEEV	{"email": "dtimofeev_04031960@postgrespro.ru", "phone": "+70103918487"}
0005434407859	111C34	7475 695996	MARINA MIKHAYLOVA	{"phone": "+70816110522"}
0005434407860	65E399	3041 171386	TATYANA RODIONOVA	{"phone": "+70204943953"}
0005434407861	307505	0218 015028	ILYA MAKSIMOV	{"email": "ilyamaksimov.121970@postgrespro.ru", "phone": "+70206785381"}
0005434407862	703476	0403 033834	SERGEY KOZLOV	{"email": "kozlovsergey_041961@postgrespro.ru", "phone": "+70839971715"}
0005434407863	703476	1632 182751	TATYANA NAUMOVA	{"email": "tatyana.naumova_30071976@postgrespro.ru", "phone": "+70790060595"}
0005434407864	2E7A7D	4247 266745	NIKOLAY SHEVCHENKO	{"email": "nikolay.shevchenko-021974@postgrespro.ru", "phone": "+70036422976"}
0005434407865	2E7A7D	1136 694258	MAKSIM DAVYDOV	{"email": "davydov.m18071973@postgrespro.ru", "phone": "+70023101630"}
0005434407866	6ECE91	2191 584807	DANIIL KUZNECOV	{"email": "kuznecovdaniil_061972@postgrespro.ru", "phone": "+70475271571"}
0005434407867	6ECE91	2530 467978	VALERIY KUZNECOV	{"phone": "+70354055707"}
0005434407868	A1A445	0748 587557	NIKOLAY MEDVEDEV	{"email": "nikolay-medvedev-1963@postgrespro.ru", "phone": "+70756209743"}
0005434407869	8686E4	4520 582051	ALEKSANDR ORLOV	{"email": "orlov-aleksandr-1967@postgrespro.ru", "phone": "+70179287849"}
0005434407870	07D7AA	3255 023312	ANATOLIY SMIRNOV	{"phone": "+70236490997"}
0005434407871	07D7AA	2687 095104	NATALYA BELYAEVA	{"phone": "+70168938193"}
0005434407872	D055FF	8928 714490	ANNA SCHERBAKOVA	{"phone": "+70418043327"}
0005434407873	6E4961	1419 444035	ALINA MIRONOVA	{"phone": "+70113650514"}
0005434407874	6E4961	8114 041822	VALENTIN POPOV	{"email": "popov-valentin031969@postgrespro.ru", "phone": "+70772776212"}
0005434407875	4EB6B6	6414 500756	NATALYA SIDOROVA	{"phone": "+70059490807"}
0005434407876	4EB6B6	3184 102365	OLGA MOISEEVA	{"email": "moiseeva.o.1961@postgrespro.ru", "phone": "+70185161740"}
0005434407877	C9C0EB	3215 882443	IRINA NAZAROVA	{"email": "nazarova_irina.011973@postgrespro.ru", "phone": "+70338785618"}
0005434407878	971B20	1510 460165	EGOR FROLOV	{"phone": "+70143054903"}
0005434407879	971B20	6435 887008	NATALYA ERMAKOVA	{"phone": "+70399950967"}
0005434407880	716EA1	6244 898321	YURIY RODIONOV	{"email": "yuriy.rodionov_21101967@postgrespro.ru", "phone": "+70467594677"}
0005434407881	716EA1	8752 111541	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva_111971@postgrespro.ru", "phone": "+70781378256"}
0005434407882	B24582	4294 071498	SVETLANA BELOVA	{"email": "belova_svetlana.29101981@postgrespro.ru", "phone": "+70953344050"}
0005434407883	D348A2	7451 274112	LEYLA FEDOROVA	{"phone": "+70368873312"}
0005434407884	D28DEA	7978 242806	GALINA FROLOVA	{"phone": "+70042502175"}
0005434407885	14D660	2568 745836	VALENTINA ISAEVA	{"email": "valentinaisaeva.011975@postgrespro.ru", "phone": "+70911435496"}
0005434407886	95C7E9	8308 957600	SERGEY STEPANOV	{"phone": "+70620774049"}
0005434407887	95C7E9	4454 223204	MAKSIM VOROBEV	{"phone": "+70926844566"}
0005434407888	95C7E9	8195 640706	ALEKSANDR PETROV	{"email": "aleksandr_petrov-1976@postgrespro.ru", "phone": "+70197624832"}
0005434407889	76792B	6020 264441	ELENA DMITRIEVA	{"email": "elena.dmitrieva.061989@postgrespro.ru", "phone": "+70676007096"}
0005434407890	76792B	9162 000290	VASILIY SMIRNOV	{"phone": "+70370761979"}
0005434407891	9CE4DB	9065 695239	VYACHESLAV BORISOV	{"email": "vyacheslavborisov.1981@postgrespro.ru", "phone": "+70457373071"}
0005434407892	773D3B	5964 431314	TAGIR SIDOROV	{"email": "sidorovtagir-27061965@postgrespro.ru", "phone": "+70513824094"}
0005434407893	8737F7	7478 416787	VYACHESLAV DAVYDOV	{"phone": "+70196728956"}
0005434407894	8737F7	5994 701486	EKATERINA SAVELEVA	{"phone": "+70866701596"}
0005434407895	BD1CF0	1877 176065	SVETLANA MIKHAYLOVA	{"email": "svetlanamikhaylova_08081972@postgrespro.ru", "phone": "+70440264089"}
0005434407896	2E83C8	9126 783321	EVGENIYA KRASNOVA	{"phone": "+70432965132"}
0005434407897	161E18	2185 730361	VASILIY SOROKIN	{"email": "vasiliysorokin_13011977@postgrespro.ru", "phone": "+70083272836"}
0005434407898	6988F2	7629 581086	ANATOLIY VOLKOV	{"phone": "+70359264479"}
0005434407899	8FE3A0	1818 442711	MARGARITA SEMENOVA	{"email": "semenova_margarita.1973@postgrespro.ru", "phone": "+70576916365"}
0005434407900	8FE3A0	8360 532801	IRINA PETROVA	{"email": "petrovairina-081972@postgrespro.ru", "phone": "+70760349011"}
0005434407901	921F04	9087 767631	DMITRIY TARASOV	{"email": "dmitriytarasov111968@postgrespro.ru", "phone": "+70482969502"}
0005434407902	F62F76	1691 098823	ELMIRA KUDRYASHOVA	{"phone": "+70268103408"}
0005434407903	32770E	3555 439165	ANASTASIYA KAZAKOVA	{"email": "kazakova_a06121969@postgrespro.ru", "phone": "+70908477716"}
0005434407904	A71BCF	6089 698195	VYACHESLAV MEDVEDEV	{"email": "medvedev.v-1966@postgrespro.ru", "phone": "+70342908869"}
0005434407905	4622FA	9622 880615	LYUDMILA POTAPOVA	{"email": "lyudmila-potapova_01071977@postgrespro.ru", "phone": "+70524667437"}
0005434407906	4622FA	7329 838628	ALSU MAKSIMOVA	{"phone": "+70223820223"}
0005434407907	EBE53E	2478 306182	ZOYA ROMANOVA	{"phone": "+70192114818"}
0005434407908	431A5B	8711 504293	DMITRIY KUZMIN	{"phone": "+70234504583"}
0005434407909	985436	2477 233980	ANATOLIY FOMIN	{"email": "anatoliyfomin021977@postgrespro.ru", "phone": "+70654713495"}
0005434407910	985436	7277 185584	LYUDMILA ZOTOVA	{"phone": "+70491789052"}
0005434407911	9947FF	5156 317404	PETR SCHERBAKOV	{"email": "p.scherbakov_1974@postgrespro.ru", "phone": "+70501593519"}
0005434407912	9947FF	9379 077795	KONSTANTIN ALEKSEEV	{"email": "alekseevk.03021972@postgrespro.ru", "phone": "+70859731156"}
0005434407913	BD8EE5	2606 395491	DANIL RODIONOV	{"phone": "+70875534368"}
0005434407914	BD8EE5	4420 975624	SERGEY SOLOVEV	{"email": "solovevs.111971@postgrespro.ru", "phone": "+70043674077"}
0005434407915	39799A	6944 049942	VALENTINA MOROZOVA	{"phone": "+70238665467"}
0005434407916	4DD9B2	7006 461243	MARINA VASILEVA	{"phone": "+70411807479"}
0005434407917	FC4E7C	4100 832474	NATALYA POPOVA	{"email": "popovanatalya-1974@postgrespro.ru", "phone": "+70097864745"}
0005434407918	689FDE	7131 734683	MARIYA MIKHAYLOVA	{"phone": "+70838303990"}
0005434407919	6E8991	2965 757662	TATYANA DMITRIEVA	{"phone": "+70224009603"}
0005434407920	5B242F	6681 518594	LILIYA KONDRATEVA	{"phone": "+70687260821"}
0005434407921	5E3366	3199 636301	NIKOLAY PETROV	{"phone": "+70640466009"}
0005434407922	FAA057	8252 413555	VYACHESLAV BARANOV	{"phone": "+70802874130"}
0005434407923	FAA057	9553 059721	ANNA KARPOVA	{"email": "karpova.anna02011984@postgrespro.ru", "phone": "+70391961118"}
0005434407924	FAA057	4179 483485	ZINAIDA KONOVALOVA	{"phone": "+70677142986"}
0005434407925	259A13	8087 965081	MARINA BORISOVA	{"email": "borisova_m071967@postgrespro.ru", "phone": "+70595186022"}
0005434407926	A86D0F	9194 729040	ALEKSANDR NIKOLAEV	{"phone": "+70341418077"}
0005434407927	72CB3A	9751 287753	IRINA MIKHAYLOVA	{"phone": "+70589606130"}
0005434407928	72CB3A	1278 295360	VIKTOR VLASOV	{"phone": "+70877449091"}
0005434407929	86EE27	2708 261997	ARTEM ZHURAVLEV	{"email": "zhuravlev_artem.011970@postgrespro.ru", "phone": "+70345854201"}
0005434407930	932D58	3624 589574	DANILA ABRAMOV	{"phone": "+70065787328"}
0005434407931	C3BBFB	9166 117750	DMITRIY SEMENOV	{"email": "dmitriy_semenov-1971@postgrespro.ru", "phone": "+70522578964"}
0005434407932	2DED6A	7738 677187	SERGEY EGOROV	{"email": "egorovs101980@postgrespro.ru", "phone": "+70169660643"}
0005434407933	2DED6A	2206 277109	ANDREY RODIONOV	{"phone": "+70784831480"}
0005434407934	A3D9B1	6084 046238	ANATOLIY NIKOLAEV	{"email": "anikolaev_19021963@postgrespro.ru", "phone": "+70250211879"}
0005434407935	A3D9B1	5598 685900	TATYANA IVANOVA	{"phone": "+70167465418"}
0005434407936	D60A22	1026 170264	SERGEY NIKOLAEV	{"email": "sergey.nikolaev-071971@postgrespro.ru", "phone": "+70325642410"}
0005434407937	C3373F	5968 904040	KONSTANTIN STEPANOV	{"email": "k.stepanov_1977@postgrespro.ru", "phone": "+70914093456"}
0005434407938	4593D2	9478 541633	NINA VOLKOVA	{"email": "n_volkova24091964@postgrespro.ru", "phone": "+70575727949"}
0005434407939	CCF742	6793 999668	ANDREY ABRAMOV	{"phone": "+70405113568"}
0005434407940	A13692	4519 015958	VIKTOR IVANOV	{"email": "ivanov.viktor_1976@postgrespro.ru", "phone": "+70002321408"}
0005434407941	F88CCE	5046 119366	ANDREY TARASOV	{"email": "tarasov_andrey.031969@postgrespro.ru", "phone": "+70365228439"}
0005434407942	B863EB	4437 316303	ALEKSANDR KISELEV	{"email": "a.kiselev-25081987@postgrespro.ru", "phone": "+70869273431"}
0005434407943	B863EB	8160 355934	NIKOLAY KUZMIN	{"email": "kuzmin.n.051975@postgrespro.ru", "phone": "+70241555180"}
0005434407944	852602	9057 816733	VYACHESLAV MIKHAYLOV	{"phone": "+70877441017"}
0005434407945	618A32	3429 152939	ELIZAVETA TITOVA	{"email": "titova.elizaveta_13091967@postgrespro.ru", "phone": "+70434438359"}
0005434407946	618A32	9537 368797	VALENTINA SERGEEVA	{"phone": "+70777028890"}
0005434407947	618A32	9007 758872	MARIYA FROLOVA	{"phone": "+70748993130"}
0005434407948	0A7710	9973 630456	NADEZHDA LUKYANOVA	{"phone": "+70886895387"}
0005434407949	93D549	8222 041943	OKSANA POLYAKOVA	{"email": "polyakova-o-12021961@postgrespro.ru", "phone": "+70080250052"}
0005434407950	A0882C	3956 049113	VERA ORLOVA	{"email": "orlova_v_02051966@postgrespro.ru", "phone": "+70566398556"}
0005434407951	963F4F	9964 864707	EDUARD IVANOV	{"phone": "+70041615348"}
0005434407952	8EE0C0	5898 498397	RINAT SCHERBAKOV	{"phone": "+70274530482"}
0005434407953	A2D64A	0392 236030	TAMARA ZOTOVA	{"email": "zotovat.1960@postgrespro.ru", "phone": "+70468163836"}
0005434407954	774DE6	6933 256436	NAILYA KRASNOVA	{"email": "nailya.krasnova_29061971@postgrespro.ru", "phone": "+70314349291"}
0005434407955	E1FED2	3172 234600	INNA ANTONOVA	{"email": "antonova-i_021979@postgrespro.ru", "phone": "+70195503067"}
0005434407956	16F4B3	2725 046235	ALEKSEY VASILEV	{"email": "a.vasilev19081966@postgrespro.ru", "phone": "+70350319167"}
0005434407957	6BD3B0	0408 172470	ELENA MIRONOVA	{"email": "elena_mironova_1968@postgrespro.ru", "phone": "+70851234648"}
0005434407958	552539	8481 488567	NINA NIKOLAEVA	{"email": "nnikolaeva-21101963@postgrespro.ru", "phone": "+70218254774"}
0005434407959	10B766	1807 204196	SERGEY NAUMOV	{"email": "sergeynaumov-06061968@postgrespro.ru", "phone": "+70849063748"}
0005434407960	10B766	1201 944419	OKSANA IVANOVA	{"email": "ivanova_o.1977@postgrespro.ru", "phone": "+70681163619"}
0005434407961	10B766	9448 036827	VARVARA POPOVA	{"email": "popova-varvara101969@postgrespro.ru", "phone": "+70647921821"}
0005434407962	10B766	5123 570626	LYUDMILA MIKHAYLOVA	{"email": "l.mikhaylova_06121981@postgrespro.ru", "phone": "+70281275445"}
0005434407963	2ED9CB	5614 600998	MARIYA ERMAKOVA	{"phone": "+70199209700"}
0005434407964	0D2799	3831 685454	ALEKSEY NAUMOV	{"email": "a.naumov.23051972@postgrespro.ru", "phone": "+70550600358"}
0005434407965	0D2799	6193 178364	ANATOLIY TIMOFEEV	{"email": "timofeev.a_011981@postgrespro.ru", "phone": "+70156059624"}
0005434407966	AE315A	2472 248808	NIKOLAY FOMIN	{"phone": "+70862232811"}
0005434407967	8F7DC8	0977 369006	DMITRIY MOROZOV	{"email": "morozov_d-061968@postgrespro.ru", "phone": "+70332890297"}
0005434407968	37F4DD	2324 418348	ANASTASIYA MELNIKOVA	{"email": "melnikova-anastasiya-1968@postgrespro.ru", "phone": "+70231665629"}
0005434407969	5B0A81	7182 783833	MAKSIM YAKOVLEV	{"email": "m.yakovlev26081971@postgrespro.ru", "phone": "+70687001361"}
0005434407970	FBD960	6945 741781	YURIY GUSEV	{"phone": "+70707086458"}
0005434407971	27212A	8692 778781	SERGEY SOROKIN	{"email": "sorokin_s1974@postgrespro.ru", "phone": "+70348246014"}
0005434407972	27212A	3273 125708	NATALYA MEDVEDEVA	{"email": "medvedeva_natalya.03041964@postgrespro.ru", "phone": "+70586867348"}
0005434407973	7FFB1C	3281 975531	ANDREY SOROKIN	{"email": "sorokin.andrey1975@postgrespro.ru", "phone": "+70109144224"}
0005434407974	8C065B	3799 489110	PAVEL KUZMIN	{"phone": "+70168706896"}
0005434407975	8C065B	0491 008589	IVAN DMITRIEV	{"phone": "+70404503447"}
0005434407976	F34AAA	6353 813015	SERGEY ORLOV	{"email": "orlovs-26121973@postgrespro.ru", "phone": "+70627197891"}
0005434407977	11AD5A	4418 647881	SERGEY TIKHONOV	{"phone": "+70813847275"}
0005434407978	9B64D1	1800 194245	ELENA ARKHIPOVA	{"email": "arkhipova_e1965@postgrespro.ru", "phone": "+70264344859"}
0005434407979	4DFCEE	2828 060132	IRINA GORBUNOVA	{"email": "gorbunova_irina.051974@postgrespro.ru", "phone": "+70241191708"}
0005434407980	6D3159	2228 826103	ANATOLIY EGOROV	{"phone": "+70646590180"}
0005434407981	2E9911	7269 591583	ANDREY KUDRYASHOV	{"email": "kudryashov.andrey25011976@postgrespro.ru", "phone": "+70304617653"}
0005434407982	2E9911	0842 833460	VERA ROMANOVA	{"phone": "+70048734347"}
0005434407983	7166D6	1678 444501	MARIYA SOROKINA	{"phone": "+70442668738"}
0005434407984	B721D5	7537 882783	VALENTINA AFANASEVA	{"email": "vafanaseva-29081968@postgrespro.ru", "phone": "+70999867016"}
0005434407985	DDBC18	8918 682241	VIKTOR ZAKHAROV	{"phone": "+70332483697"}
0005434407986	8907C0	7403 837896	IRINA CHERNOVA	{"phone": "+70672838251"}
0005434407987	8907C0	3566 592911	MAKSIM KUZNECOV	{"phone": "+70593063508"}
0005434407988	63F4B1	0668 461021	KRISTINA KUZNECOVA	{"email": "kkuznecova_051976@postgrespro.ru", "phone": "+70802668441"}
0005434407989	3D896C	4864 937216	MIKHAIL ZHURAVLEV	{"phone": "+70000864950"}
0005434407990	24B7D0	2657 019105	ELENA TIMOFEEVA	{"email": "elena-timofeeva_22061972@postgrespro.ru", "phone": "+70693765849"}
0005434407991	24B7D0	0298 605347	RAISA NOVIKOVA	{"email": "r_novikova.081968@postgrespro.ru", "phone": "+70808351569"}
0005434407992	CAAB53	7260 259237	IGOR TIKHONOV	{"phone": "+70990205298"}
0005434407993	CAAB53	8502 418831	PETR STEPANOV	{"email": "stepanov-petr.031964@postgrespro.ru", "phone": "+70801842443"}
0005434407994	853483	5804 741752	IRINA SOROKINA	{"email": "irina_sorokina.13011975@postgrespro.ru", "phone": "+70720252054"}
0005434407995	0327CC	3077 976901	NIKOLAY PETROV	{"email": "petrov-n.091966@postgrespro.ru", "phone": "+70985299783"}
0005434407996	DFE439	1800 050150	SVETLANA KULIKOVA	{"phone": "+70055370089"}
0005434407997	6A299C	2871 140928	DMITRIY SEMENOV	{"email": "d-semenov1989@postgrespro.ru", "phone": "+70836100619"}
0005434407998	1AF845	8201 438166	YURIY KOROLEV	{"phone": "+70135901561"}
0005434407999	1AF845	6195 625525	ANATOLIY ALEKSEEV	{"email": "a_alekseev.071978@postgrespro.ru", "phone": "+70682259206"}
0005434408000	3B60CA	0847 611420	VIKTORIYA PAVLOVA	{"email": "viktoriya.pavlova_1976@postgrespro.ru", "phone": "+70751550963"}
0005434408001	9B0E93	9116 838893	OLEG KUZMIN	{"phone": "+70210117641"}
0005434408002	9B0E93	0455 192662	LARISA MAKAROVA	{"email": "l_makarova-081971@postgrespro.ru", "phone": "+70692757651"}
0005434408003	8086EB	5904 166606	EKATERINA GERASIMOVA	{"phone": "+70489954793"}
0005434408004	BBBC76	4404 071031	EVGENIYA KARPOVA	{"email": "evgeniyakarpova051965@postgrespro.ru", "phone": "+70979518331"}
0005434408005	E55022	4914 767226	ANDREY KONOVALOV	{"phone": "+70468553150"}
0005434408006	E55022	8092 004014	YULIYA GORBUNOVA	{"email": "gorbunova-y.16071971@postgrespro.ru", "phone": "+70666616685"}
0005434408007	FBC18F	1442 814779	NADEZHDA NIKITINA	{"phone": "+70956837465"}
0005434408008	FBC18F	8669 434839	ANTON MARTYNOV	{"email": "a_martynov.1965@postgrespro.ru", "phone": "+70401701628"}
0005434408009	FBC18F	4160 974777	VLADIMIR BELOV	{"phone": "+70294735447"}
0005434408010	756A98	4760 289044	ANATOLIY BONDARENKO	{"email": "anatoliy.bondarenko-1967@postgrespro.ru", "phone": "+70698902938"}
0005434408011	756A98	7579 600742	MARIYA NIKITINA	{"email": "nikitinam-10041968@postgrespro.ru", "phone": "+70735911480"}
0005434408012	494A42	1421 612862	RAILYA SCHERBAKOVA	{"phone": "+70137014892"}
0005434408013	494A42	3761 172070	NATALYA SEMENOVA	{"email": "natalya.semenova.1972@postgrespro.ru", "phone": "+70498389488"}
0005434408014	D836E6	6858 888525	ALEKSANDR SMIRNOV	{"phone": "+70639521172"}
0005434408015	6C56A3	6544 274936	VALERIY GRIGOREV	{"email": "grigorevv-04031979@postgrespro.ru", "phone": "+70800582574"}
0005434408016	20D00C	3567 792410	MIKHAIL MEDVEDEV	{"phone": "+70015249623"}
0005434408017	7A66B9	3482 203380	VALENTINA GAVRILOVA	{"phone": "+70501119549"}
0005434408018	4E7E05	0569 113550	VITALIY GORBUNOV	{"phone": "+70416874864"}
0005434408019	15731E	3731 824081	OLGA ZAKHAROVA	{"email": "zakharova_olga-1975@postgrespro.ru", "phone": "+70468891617"}
0005434408020	15731E	9628 737282	VLADIMIR KUZNECOV	{"phone": "+70183540880"}
0005434408021	B36689	6544 110632	LIDIYA ALEKSANDROVA	{"email": "aleksandrova-l_1962@postgrespro.ru", "phone": "+70793056167"}
0005434408022	B36689	7036 551409	OLGA KUZNECOVA	{"email": "kuznecova-o.041968@postgrespro.ru", "phone": "+70852872439"}
0005434408023	72BAD4	4789 543135	PAVEL MATVEEV	{"phone": "+70880702277"}
0005434408024	72BAD4	6309 425749	ALEKSEY KUZNECOV	{"phone": "+70164716135"}
0005434408025	D7CA85	5698 099499	PAVEL ZAKHAROV	{"phone": "+70689454148"}
0005434408026	11A0FE	4512 082569	IRINA VOROBEVA	{"email": "vorobeva-irina.1966@postgrespro.ru", "phone": "+70605628800"}
0005434408027	987BC3	2555 882427	ALEKSEY IVANOV	{"email": "ivanov_a.101972@postgrespro.ru", "phone": "+70262909924"}
0005434408028	987BC3	9394 599302	VIKTOR DAVYDOV	{"phone": "+70141240488"}
0005434408029	5CFFB2	6066 265777	ELIZAVETA FOMINA	{"email": "fomina-elizaveta.081954@postgrespro.ru", "phone": "+70971519181"}
0005434408030	5CFFB2	6317 108545	OLGA DAVYDOVA	{"phone": "+70982259061"}
0005434408031	B3551D	6689 678576	NINA ALEKSANDROVA	{"email": "n.aleksandrova09071983@postgrespro.ru", "phone": "+70400848612"}
0005434408032	E002C4	3070 360295	KRISTINA FILIPPOVA	{"email": "filippova.k.21111987@postgrespro.ru", "phone": "+70876044580"}
0005434408033	8D9646	9957 029595	VASILIY KULIKOV	{"email": "v-kulikov_071974@postgrespro.ru", "phone": "+70779424924"}
0005434408034	009099	0794 334762	SERGEY MELNIKOV	{"email": "sergey_melnikov-1968@postgrespro.ru", "phone": "+70027144338"}
0005434408035	0BD2BB	5945 788228	TATYANA SERGEEVA	{"email": "sergeeva.tatyana-1981@postgrespro.ru", "phone": "+70797459587"}
0005434408036	3B668F	3495 894678	PELAGEYA FEDOROVA	{"phone": "+70810729730"}
0005434408037	2AE3DA	3075 316827	EKATERINA POPOVA	{"email": "ekaterina.popova-02031965@postgrespro.ru", "phone": "+70847809525"}
0005434408038	2AE3DA	0148 653938	MARINA IVANOVA	{"phone": "+70016807855"}
0005434408039	82C756	9187 882736	EKATERINA GORBUNOVA	{"phone": "+70957710173"}
0005434408040	0E286F	7040 936207	MIKHAIL MEDVEDEV	{"phone": "+70039586056"}
0005434408041	04FC3C	2923 715092	RENAT NIKITIN	{"email": "renat-nikitin.20041976@postgrespro.ru", "phone": "+70700467557"}
0005434408042	EBCE28	2058 611457	KARINA TITOVA	{"email": "titova_karina-1963@postgrespro.ru", "phone": "+70687504378"}
0005434408043	7885FB	9407 761445	KIRILL PETROV	{"email": "kirill_petrov_061976@postgrespro.ru", "phone": "+70468328194"}
0005434408044	B240E8	2787 083411	ALEKSEY ZAYCEV	{"phone": "+70874006863"}
0005434408045	267FE0	3650 106116	NIKOLAY SOROKIN	{"email": "sorokin-nikolay_1966@postgrespro.ru", "phone": "+70240523830"}
0005434408046	267FE0	6646 477354	ALEKSANDR FOMIN	{"phone": "+70615656807"}
0005434408047	496B4B	8774 359466	YURIY DENISOV	{"email": "y_denisov011981@postgrespro.ru", "phone": "+70699569508"}
0005434408048	EA9502	0419 512518	OLGA BARANOVA	{"phone": "+70624282573"}
0005434408385	285D40	1386 496208	TATYANA RODIONOVA	{"phone": "+70267830742"}
0005434408049	62406C	9602 879756	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr.101979@postgrespro.ru", "phone": "+70190865244"}
0005434408050	6A63CE	3943 548193	VLADIMIR DMITRIEV	{"phone": "+70256273636"}
0005434408051	F74DBA	8147 173336	DMITRIY KUZMIN	{"email": "kuzmin.dmitriy-26091981@postgrespro.ru", "phone": "+70268657519"}
0005434408052	D26549	7070 305655	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a-1986@postgrespro.ru", "phone": "+70760417339"}
0005434408053	C63415	2960 352064	ALEKSANDR ZHURAVLEV	{"phone": "+70597883388"}
0005434408054	59E33B	5211 422263	ALEKSANDR NIKITIN	{"phone": "+70367367102"}
0005434408055	C90B01	7255 480547	ANATOLIY GRIGOREV	{"email": "a_grigorev061975@postgrespro.ru", "phone": "+70368387158"}
0005434408056	4BEA9C	6853 326465	RINAT SOKOLOV	{"email": "r.sokolov091977@postgrespro.ru", "phone": "+70737230078"}
0005434408057	04049A	5971 201420	IRINA ANDREEVA	{"phone": "+70470409516"}
0005434408058	04049A	6951 559243	ELEONORA MELNIKOVA	{"phone": "+70027803127"}
0005434408059	04049A	3174 568844	SERGEY FEDOROV	{"email": "s.fedorov.021975@postgrespro.ru", "phone": "+70191553440"}
0005434408060	44987F	3737 962743	SVETLANA KOROLEVA	{"email": "s-koroleva_10101985@postgrespro.ru", "phone": "+70670680786"}
0005434408061	44987F	2234 471652	OLGA KOZLOVA	{"phone": "+70037984176"}
0005434408062	E4083D	7881 371982	ALEKSANDR ANTONOV	{"phone": "+70409858250"}
0005434408063	8CEEA3	7654 909651	MAKSIM POPOV	{"phone": "+70641616675"}
0005434408064	8CEEA3	8790 607489	RENAT OSIPOV	{"email": "osipovrenat_1963@postgrespro.ru", "phone": "+70472510304"}
0005434408065	D72F51	3433 746849	IVAN IVANOV	{"phone": "+70801360543"}
0005434408066	58F21E	6729 164558	ILYAS MAKSIMOV	{"email": "i.maksimov_041970@postgrespro.ru", "phone": "+70482629928"}
0005434408067	07315E	2255 571030	ELENA NOVIKOVA	{"email": "enovikova_1970@postgrespro.ru", "phone": "+70835332268"}
0005434408068	07315E	8717 386198	SERGEY MOROZOV	{"email": "morozov_s041990@postgrespro.ru", "phone": "+70094885056"}
0005434408069	C42761	2407 011007	ANDREY SMIRNOV	{"email": "andrey-smirnov101965@postgrespro.ru", "phone": "+70067941403"}
0005434408070	0CB31C	6679 138308	MARIYA MEDVEDEVA	{"email": "medvedeva_mariya_19041974@postgrespro.ru", "phone": "+70564618954"}
0005434408126	D713A3	1111 007453	MURAT STEPANOV	{"phone": "+70404611773"}
0005434408071	61F396	8235 977265	OKSANA NIKOLAEVA	{"email": "oksana-nikolaeva.28041972@postgrespro.ru", "phone": "+70974757328"}
0005434408072	194016	8999 489953	LYUBOV ANDREEVA	{"phone": "+70510125446"}
0005434408073	A7EC20	0186 388720	ROMAN KOZLOV	{"phone": "+70573673527"}
0005434408074	179880	7132 723478	MARIYA KOVALEVA	{"email": "kovaleva.mariya_02021973@postgrespro.ru", "phone": "+70844372657"}
0005434408075	179880	4610 578871	ANASTASIYA SOLOVEVA	{"phone": "+70759688398"}
0005434408076	55469F	7560 188498	VASILIY ALEKSEEV	{"phone": "+70867577136"}
0005434408077	F59AB2	5450 075640	DMITRIY SEMENOV	{"email": "dmitriy_semenov29081974@postgrespro.ru", "phone": "+70337786683"}
0005434408078	F59AB2	9779 848891	ZOYA KUZMINA	{"email": "kuzmina-zoya_11011971@postgrespro.ru", "phone": "+70306195401"}
0005434408079	11715B	2817 883237	NINA MOISEEVA	{"email": "moiseeva_n.081974@postgrespro.ru", "phone": "+70860120841"}
0005434408080	AB84F9	5095 820748	LARISA MAKAROVA	{"email": "makarova-larisa_121971@postgrespro.ru", "phone": "+70845336099"}
0005434408081	AB84F9	3226 542735	ALEKSEY DENISOV	{"email": "adenisov-041970@postgrespro.ru", "phone": "+70850002889"}
0005434408082	9DD9D9	7395 926277	ALEKSANDR KONOVALOV	{"email": "a_konovalov26081966@postgrespro.ru", "phone": "+70556199021"}
0005434408083	ED994D	6741 345198	SVETLANA LOGINOVA	{"email": "svetlana_loginova.1977@postgrespro.ru", "phone": "+70214113997"}
0005434408084	ED994D	0555 866916	TIMUR DENISOV	{"phone": "+70126040843"}
0005434408085	421BEB	9965 089217	IRAIDA POPOVA	{"phone": "+70928897032"}
0005434408086	421BEB	3533 193939	SVETLANA SERGEEVA	{"email": "svetlanasergeeva.091962@postgrespro.ru", "phone": "+70911473214"}
0005434408087	05EAB5	3565 908771	EVGENIY KULIKOV	{"email": "kulikove.24011977@postgrespro.ru", "phone": "+70988509734"}
0005434408088	7DF07E	9665 989037	SERGEY KOZLOV	{"email": "kozlov_s30071966@postgrespro.ru", "phone": "+70801730435"}
0005434408089	6A7C94	1717 506927	NIKOLAY KULIKOV	{"email": "kulikov_n-061972@postgrespro.ru", "phone": "+70156646553"}
0005434408090	891C52	9701 198911	INNA SEMENOVA	{"phone": "+70238911392"}
0005434408091	15D2C3	5770 366963	VIKTORIYA PETROVA	{"email": "v-petrova-30121966@postgrespro.ru", "phone": "+70040428603"}
0005434408092	F5CB62	8020 067595	ROZA KUZMINA	{"phone": "+70275133341"}
0005434408093	4EB1D6	2917 046452	ANDREY ZHURAVLEV	{"email": "azhuravlev_1979@postgrespro.ru", "phone": "+70157510486"}
0005434408094	4EB1D6	7350 692174	ROMAN SMIRNOV	{"email": "smirnov.r13041977@postgrespro.ru", "phone": "+70974802349"}
0005434408095	BE245C	1635 133835	ALEKSANDR ANTONOV	{"phone": "+70841340228"}
0005434408096	4381D1	0151 905788	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov_1958@postgrespro.ru", "phone": "+70223494802"}
0005434408097	5A52EC	9041 234378	ALEKSEY POPOV	{"phone": "+70824580169"}
0005434408098	5A52EC	6917 311743	ELENA KONDRATEVA	{"email": "elena_kondrateva091968@postgrespro.ru", "phone": "+70488987479"}
0005434408099	28CB56	9572 498386	MARIYA RYABOVA	{"phone": "+70260460393"}
0005434408100	28CB56	9283 050726	IRINA ZHURAVLEVA	{"phone": "+70735811348"}
0005434408101	833EB3	6058 401082	ANASTASIYA KUZMINA	{"phone": "+70269619446"}
0005434408102	8223D7	4069 062885	ARTEM ANTONOV	{"phone": "+70165859762"}
0005434408103	7F7F6C	1077 333787	OLGA MASLOVA	{"phone": "+70627859777"}
0005434408104	23A3DF	4319 410968	SVETLANA OSIPOVA	{"email": "osipovas.30101968@postgrespro.ru", "phone": "+70809536768"}
0005434408105	DCBB69	0516 844997	GALINA MOROZOVA	{"phone": "+70792484944"}
0005434408106	DCBB69	3871 345300	NIKOLAY MOROZOV	{"email": "morozov_n_07061975@postgrespro.ru", "phone": "+70877376792"}
0005434408107	98A02D	3526 521861	ANASTASIYA FROLOVA	{"email": "frolova_a111982@postgrespro.ru", "phone": "+70788339341"}
0005434408108	98A02D	9847 987737	VLADIMIR GAVRILOV	{"phone": "+70606336461"}
0005434408109	AE5351	5288 487035	YURIY FEDOTOV	{"phone": "+70360399612"}
0005434408110	7A2EBD	3706 383305	MARIYA SEMENOVA	{"email": "semenova_m_1957@postgrespro.ru", "phone": "+70902079572"}
0005434408232	E237F2	5531 113966	DMITRIY KUZMIN	{"phone": "+70455925319"}
0005434408111	7A2EBD	7552 892715	ALEKSEY GUSEV	{"email": "gusev_aleksey_1975@postgrespro.ru", "phone": "+70864604993"}
0005434408112	0FC1F1	8067 405666	YULIYA GORBUNOVA	{"email": "gorbunova_yuliya-05091973@postgrespro.ru", "phone": "+70497601492"}
0005434408113	F8C8F3	1219 457499	OLGA STEPANOVA	{"phone": "+70707250651"}
0005434408114	F8C8F3	0068 997533	ALEKSANDRA MIRONOVA	{"phone": "+70718613313"}
0005434408115	5D564D	8139 588625	OKSANA MAKAROVA	{"email": "makarovao.031988@postgrespro.ru", "phone": "+70823770142"}
0005434408116	623F57	3366 144195	LYUBOV FADEEVA	{"email": "lfadeeva_071973@postgrespro.ru", "phone": "+70103012734"}
0005434408117	80DD35	8789 052278	SVETLANA ANTONOVA	{"email": "svetlana-antonova1965@postgrespro.ru", "phone": "+70235173752"}
0005434408118	3A4A04	9315 519261	ALEKSANDRA FEDOROVA	{"email": "fedorova.a.101997@postgrespro.ru", "phone": "+70183651667"}
0005434408119	DCA92C	8266 827512	LYUDMILA MATVEEVA	{"email": "matveeva_l_071960@postgrespro.ru", "phone": "+70948085597"}
0005434408120	E751DE	6818 852218	PAVEL KOROLEV	{"phone": "+70342117439"}
0005434408121	A3C16A	6061 825036	ALEKSANDRA SERGEEVA	{"email": "a.sergeeva-1958@postgrespro.ru", "phone": "+70015722274"}
0005434408122	A3C16A	0476 118784	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr011966@postgrespro.ru", "phone": "+70959705188"}
0005434408123	458583	6042 431109	EVGENIYA DAVYDOVA	{"phone": "+70454611411"}
0005434408124	458583	3067 903458	ANASTASIYA TARASOVA	{"phone": "+70736787864"}
0005434408125	458583	9718 610228	KSENIYA FILATOVA	{"phone": "+70158748344"}
0005434408127	872746	4773 092314	TATYANA SEMENOVA	{"phone": "+70787274840"}
0005434408128	326460	2804 015325	ANATOLIY OSIPOV	{"email": "osipov_anatoliy-061963@postgrespro.ru", "phone": "+70045559864"}
0005434408129	326460	1658 300631	YULIYA KOZLOVA	{"phone": "+70029568997"}
0005434408130	8FF1D9	9720 812836	VERA CHERNOVA	{"phone": "+70402257922"}
0005434408131	E1F117	9285 613634	SVETLANA SIDOROVA	{"email": "sidorovasvetlana18011977@postgrespro.ru", "phone": "+70943248009"}
0005434408132	782766	0665 328908	ELENA NOVIKOVA	{"email": "e_novikova-1977@postgrespro.ru", "phone": "+70155746018"}
0005434408133	4B8629	1565 123435	NIKOLAY ZAKHAROV	{"email": "zakharov-n_12101966@postgrespro.ru", "phone": "+70196052276"}
0005434408134	054CD7	1884 677364	VLADIMIR FEDOROV	{"phone": "+70619393368"}
0005434408135	EF2B86	0619 195657	ELIZAVETA POPOVA	{"phone": "+70555479232"}
0005434408136	17BBE3	3451 992522	DANIL SIDOROV	{"email": "d_sidorov1976@postgrespro.ru", "phone": "+70038122490"}
0005434408137	E89792	2599 718291	TAISIYA KUZNECOVA	{"phone": "+70711548212"}
0005434408138	698440	8578 895555	ARTEM MELNIKOV	{"email": "amelnikov_1963@postgrespro.ru", "phone": "+70081401374"}
0005434408139	E575FA	3124 588583	SERGEY MOISEEV	{"phone": "+70147571067"}
0005434408140	204981	2924 202963	VIKTOR MARTYNOV	{"email": "viktormartynov.1970@postgrespro.ru", "phone": "+70327019699"}
0005434408141	204981	7143 139080	RENAT VASILEV	{"email": "renat_vasilev_121980@postgrespro.ru", "phone": "+70096644418"}
0005434408142	04D592	8440 877037	SVETLANA MIKHAYLOVA	{"email": "svetlana.mikhaylova-021974@postgrespro.ru", "phone": "+70920116553"}
0005434408143	04D592	1126 096109	DANILA NAZAROV	{"email": "danilanazarov-18031970@postgrespro.ru", "phone": "+70381793535"}
0005434408144	CD0DB9	7453 682340	SVETLANA MOROZOVA	{"email": "s.morozova_041985@postgrespro.ru", "phone": "+70836345128"}
0005434408145	BBFB4A	5489 105810	ARTEM MIRONOV	{"phone": "+70996294351"}
0005434408146	538C73	3563 373254	GALINA FOMINA	{"email": "g-fomina_09021962@postgrespro.ru", "phone": "+70171165290"}
0005434408147	538C73	4147 912137	OLGA KOLESNIKOVA	{"phone": "+70543758456"}
0005434408148	075CAF	9658 842548	NATALYA ABRAMOVA	{"phone": "+70500628828"}
0005434408149	A013CB	1242 717617	ALEKSANDR GORBUNOV	{"phone": "+70823616119"}
0005434408150	34F7AE	6308 357509	ALEKSEY KONOVALOV	{"phone": "+70942769173"}
0005434408151	34F7AE	8178 473364	TATYANA IVANOVA	{"phone": "+70239443828"}
0005434408152	B8DE14	3987 640540	GALINA NOVIKOVA	{"email": "g.novikova17031963@postgrespro.ru", "phone": "+70900510031"}
0005434408153	B8DE14	5065 679589	IVAN ABRAMOV	{"phone": "+70733864904"}
0005434408154	7BF6C5	6018 553943	EVGENIY IVANOV	{"email": "ivanov-e-101977@postgrespro.ru", "phone": "+70939564995"}
0005434408155	3EEAAE	2434 365860	EVGENIY ZAKHAROV	{"email": "ezakharov-04011971@postgrespro.ru", "phone": "+70092838323"}
0005434408156	3EEAAE	5384 494621	DAMIR ROMANOV	{"phone": "+70899735432"}
0005434408157	F7B528	0018 767213	ELENA ZOTOVA	{"email": "zotova.elena.1973@postgrespro.ru", "phone": "+70773249929"}
0005434408158	48A1FC	5969 869508	OLGA DENISOVA	{"email": "o-denisova1968@postgrespro.ru", "phone": "+70952586323"}
0005434408159	B87FFC	3476 512491	TAMARA KONDRATEVA	{"phone": "+70510567240"}
0005434408160	8A5998	1314 010765	OLEG YAKOVLEV	{"email": "olegyakovlev121963@postgrespro.ru", "phone": "+70914909063"}
0005434408161	8A5998	2844 255461	ROMAN ISAEV	{"email": "isaev-r.1964@postgrespro.ru", "phone": "+70859818369"}
0005434408162	BA4747	6813 180710	SERGEY SAVELEV	{"email": "s_savelev_1976@postgrespro.ru", "phone": "+70047414117"}
0005434408163	6E8228	2470 959422	VLADIMIR IVANOV	{"email": "ivanov.vladimir14061960@postgrespro.ru", "phone": "+70690235030"}
0005434408164	6E8228	4634 367133	KONSTANTIN NIKOLAEV	{"phone": "+70730007040"}
0005434408165	BCCB91	3890 268634	MIKHAIL SHEVCHENKO	{"email": "shevchenkom_12081980@postgrespro.ru", "phone": "+70304600009"}
0005434408166	7131AC	7239 975687	IRINA ZAYCEVA	{"phone": "+70223587077"}
0005434408167	5532F7	5993 978818	OLGA ILINA	{"phone": "+70365467676"}
0005434408168	35AC9F	2268 080440	VITALIY ZAYCEV	{"phone": "+70100100303"}
0005434408169	35AC9F	5128 728324	ANASTASIYA BELOVA	{"phone": "+70631387850"}
0005434408170	35AC9F	7417 823622	DENIS KUDRYASHOV	{"phone": "+70532427259"}
0005434408171	15899C	5665 556167	ANATOLIY CHERNOV	{"email": "chernov-anatoliy.20031971@postgrespro.ru", "phone": "+70926318232"}
0005434408172	40CDAC	2800 938026	ELENA VASILEVA	{"email": "vasileva-elena1976@postgrespro.ru", "phone": "+70385993439"}
0005434408173	40CDAC	9312 730143	ALEKSEY MAKSIMOV	{"email": "aleksey.maksimov-1963@postgrespro.ru", "phone": "+70166373816"}
0005434408174	40CDAC	7945 107319	NIKOLAY SAVELEV	{"email": "n_savelev-061956@postgrespro.ru", "phone": "+70820539404"}
0005434408175	1C3D93	3341 080769	MARIYA SOKOLOVA	{"email": "sokolovam-111969@postgrespro.ru", "phone": "+70885350933"}
0005434408176	BA9C32	1729 233053	IGOR SIDOROV	{"email": "sidorov_i_15021986@postgrespro.ru", "phone": "+70843055884"}
0005434408177	BA9C32	8536 791495	DANILA POPOV	{"phone": "+70680222207"}
0005434408178	B4DFE4	9517 017916	ALEKSEY FROLOV	{"phone": "+70494648121"}
0005434408179	C61662	5888 133509	DAVID BONDARENKO	{"email": "bondarenkod.1974@postgrespro.ru", "phone": "+70185625517"}
0005434408180	DA5EA8	7741 809975	SERGEY DMITRIEV	{"phone": "+70036974182"}
0005434408181	DA5EA8	5170 742352	MAKSIM ILIN	{"email": "ilin.maksim_1981@postgrespro.ru", "phone": "+70196214915"}
0005434408182	57AB71	0537 310793	SERGEY NAZAROV	{"phone": "+70518923869"}
0005434408183	F84289	4657 784402	ANTONINA GRISHINA	{"phone": "+70896358322"}
0005434408184	F84289	1693 716465	VASILIY KUZNECOV	{"phone": "+70654840768"}
0005434408185	C13BED	2915 764388	ALENA IVANOVA	{"phone": "+70992059697"}
0005434408186	4BB5A2	9152 514625	VLADIMIR VLASOV	{"email": "vladimir-vlasov071965@postgrespro.ru", "phone": "+70512622085"}
0005434408187	77C148	3322 439639	VADIM MATVEEV	{"email": "vadim-matveev.26121961@postgrespro.ru", "phone": "+70452234982"}
0005434408188	77C148	1017 483137	LYUBOV SOROKINA	{"email": "sorokina.l.07091967@postgrespro.ru", "phone": "+70422601996"}
0005434408189	822E87	8856 144044	RINAT BORISOV	{"phone": "+70815175297"}
0005434408190	822E87	6374 535492	RINAT MAKSIMOV	{"email": "maksimovrinat1973@postgrespro.ru", "phone": "+70942254119"}
0005434408191	F010B9	9621 719563	KIRILL POPOV	{"email": "kirill_popov-15011989@postgrespro.ru", "phone": "+70057699965"}
0005434408192	829BAC	4093 713485	PAVEL FOMIN	{"phone": "+70072323684"}
0005434408193	6CFBB5	3234 411836	PAVEL FOMIN	{"email": "fomin-pavel-06041959@postgrespro.ru", "phone": "+70508006018"}
0005434408194	6CFBB5	7474 325409	IVAN SMIRNOV	{"phone": "+70095999390"}
0005434408195	994C61	7785 459431	ARINA ANTONOVA	{"email": "arinaantonova.081961@postgrespro.ru", "phone": "+70277398745"}
0005434408196	33849A	0853 761338	ALEKSANDR SAVELEV	{"email": "savelev.a.1975@postgrespro.ru", "phone": "+70951785011"}
0005434408197	23EDFE	7770 550000	TAMARA NIKIFOROVA	{"email": "t_nikiforova_041969@postgrespro.ru", "phone": "+70775511119"}
0005434408198	F3C305	9346 380123	VLADIMIR MATVEEV	{"email": "matveev.vladimir_1975@postgrespro.ru", "phone": "+70788639337"}
0005434408199	87EB72	6145 258773	DMITRIY KUZNECOV	{"email": "kuznecov_d-1967@postgrespro.ru", "phone": "+70694100889"}
0005434408200	97898A	6813 227894	ANASTASIYA ZOTOVA	{"phone": "+70101975785"}
0005434408201	97898A	3491 984802	ANNA ILINA	{"email": "a.ilina-08031978@postgrespro.ru", "phone": "+70421208597"}
0005434408202	EB2928	6081 682942	SERGEY OSIPOV	{"phone": "+70009795138"}
0005434408203	1160D8	7781 319400	ROMAN BORISOV	{"email": "borisov-r.1988@postgrespro.ru", "phone": "+70976042373"}
0005434408204	EEB7F1	4207 780575	ALEKSANDR ANTONOV	{"email": "antonov-a-041968@postgrespro.ru", "phone": "+70883723779"}
0005434408205	D6CE31	8486 856220	ALIYA SCHERBAKOVA	{"phone": "+70585587390"}
0005434408206	D6CE31	4090 952272	VARVARA NIKIFOROVA	{"email": "v.nikiforova031980@postgrespro.ru", "phone": "+70539432253"}
0005434408207	068147	2146 834420	MARIYA MEDVEDEVA	{"email": "medvedeva-mariya_061978@postgrespro.ru", "phone": "+70838436218"}
0005434408208	D127DA	6542 784911	NATALYA KUZMINA	{"phone": "+70373118634"}
0005434408209	21A099	6514 707544	ELENA ABRAMOVA	{"email": "abramova-elena.1971@postgrespro.ru", "phone": "+70278549980"}
0005434408210	70D986	5825 419519	DMITRIY KUZNECOV	{"email": "d_kuznecov_121969@postgrespro.ru", "phone": "+70082768917"}
0005434408211	07A046	0647 003876	IRINA MOISEEVA	{"email": "moiseeva.i_1986@postgrespro.ru", "phone": "+70359515478"}
0005434408212	07A046	8259 214374	VALERIY NOVIKOV	{"phone": "+70634559281"}
0005434408213	FF8991	5663 991130	DARYA MAKAROVA	{"phone": "+70782741840"}
0005434408214	FF8991	3299 657140	VLADISLAV NOVIKOV	{"email": "novikov_v.08031964@postgrespro.ru", "phone": "+70563771793"}
0005434408215	18AB4F	5815 665772	ALEKSEY ILIN	{"email": "a_ilin_1971@postgrespro.ru", "phone": "+70781698005"}
0005434408216	84A5DD	5854 970991	OLEG KONOVALOV	{"email": "oleg.konovalov_14061981@postgrespro.ru", "phone": "+70156991088"}
0005434408217	A29D0A	7973 822050	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov.24011978@postgrespro.ru", "phone": "+70587323779"}
0005434408218	FBE6C8	1126 645959	VALENTIN ANTONOV	{"phone": "+70062599880"}
0005434408219	887A66	4052 914773	ALEKSEY MOISEEV	{"email": "aleksey-moiseev_09021967@postgrespro.ru", "phone": "+70993122359"}
0005434408220	0EAD35	8910 201407	VLADISLAV PAVLOV	{"phone": "+70393987800"}
0005434408221	0EAD35	9235 844361	IVAN POPOV	{"phone": "+70992209506"}
0005434408222	23CB24	8652 581188	IGOR VOLKOV	{"email": "volkovigor.11021978@postgrespro.ru", "phone": "+70251532393"}
0005434408223	29D3AA	7187 249203	VALENTINA GERASIMOVA	{"phone": "+70344991209"}
0005434408224	565B2A	5156 925814	OLGA LUKYANOVA	{"phone": "+70170955757"}
0005434408225	6A698E	2414 057167	BORIS SEMENOV	{"phone": "+70233910862"}
0005434408226	6A698E	5147 513888	RAISA TITOVA	{"phone": "+70795402901"}
0005434408227	C72588	4543 833716	ZOYA NAZAROVA	{"email": "nazarova_zoya-15041978@postgrespro.ru", "phone": "+70416195585"}
0005434408228	23A58C	9560 995905	SERGEY SEMENOV	{"phone": "+70983397084"}
0005434408229	23A58C	8745 417431	PAVEL ZAYCEV	{"email": "p_zaycev01061960@postgrespro.ru", "phone": "+70102480873"}
0005434408230	58D15B	5257 408999	NATALYA MAKAROVA	{"phone": "+70711349535"}
0005434408231	58D15B	0209 417940	NINA MOROZOVA	{"phone": "+70891042663"}
0005434408233	E237F2	3066 321982	ELENA PETROVA	{"email": "petrova.elena_29111978@postgrespro.ru", "phone": "+70344591747"}
0005434408234	E0A860	6873 033070	VALENTINA GUSEVA	{"email": "vguseva_21111981@postgrespro.ru", "phone": "+70400059545"}
0005434408235	3C5F5E	1514 096864	TATYANA TARASOVA	{"email": "tarasova_tatyana.21031977@postgrespro.ru", "phone": "+70116850763"}
0005434408236	C1177D	3794 402153	SERGEY PETROV	{"phone": "+70182083055"}
0005434408237	C1177D	5309 120415	ANGELINA KAZAKOVA	{"email": "kazakova_angelina-16011981@postgrespro.ru", "phone": "+70435833383"}
0005434408238	6F21E7	5714 130890	VYACHESLAV ALEKSEEV	{"phone": "+70728010513"}
0005434408239	6F21E7	1350 527218	LIDIYA MASLOVA	{"phone": "+70117597394"}
0005434408240	01D8FE	1265 831650	NINA ROMANOVA	{"email": "romanova-nina1974@postgrespro.ru", "phone": "+70204376479"}
0005434408241	78C316	7989 755966	ALEKSANDR CHERNOV	{"email": "a_chernov_121964@postgrespro.ru", "phone": "+70690099815"}
0005434408242	78C316	1029 374456	YULIYA ISAEVA	{"email": "isaevay_1978@postgrespro.ru", "phone": "+70505202110"}
0005434408243	2B9AB4	8353 129916	GENNADIY ZAKHAROV	{"email": "g-zakharov.071972@postgrespro.ru", "phone": "+70339100732"}
0005434408244	2B9AB4	2287 885811	VITALIY MOROZOV	{"phone": "+70787292805"}
0005434408245	9ECCBB	0726 194116	LYUDMILA PAVLOVA	{"email": "pavlovalyudmila_22071973@postgrespro.ru", "phone": "+70364061231"}
0005434408246	9ECCBB	4343 712337	PAVEL ILIN	{"email": "p_ilin_1972@postgrespro.ru", "phone": "+70841781948"}
0005434408247	8B6BF3	6552 440631	SERGEY KOZLOV	{"email": "kozlov.sergey-061975@postgrespro.ru", "phone": "+70798402669"}
0005434408248	D72EB1	1888 385015	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr.111971@postgrespro.ru", "phone": "+70957951373"}
0005434408249	2C6977	4706 608980	ELENA FEDOROVA	{"email": "e.fedorova24021966@postgrespro.ru", "phone": "+70957233345"}
0005434408250	4B8BEB	7945 946441	MIKHAIL IVANOV	{"email": "m_ivanov_25051978@postgrespro.ru", "phone": "+70753999053"}
0005434408251	8540EA	9170 439495	NURIYA AKIMOVA	{"email": "akimova-nuriya.30011970@postgrespro.ru", "phone": "+70623229122"}
0005434408252	8540EA	8774 402195	ELENA MARTYNOVA	{"phone": "+70291571477"}
0005434408253	8540EA	9051 645896	NADEZHDA MAKAROVA	{"email": "nadezhda_makarova.05091972@postgrespro.ru", "phone": "+70548945893"}
0005434408254	63BACD	3445 047552	TATYANA FILIPPOVA	{"phone": "+70650675096"}
0005434408255	63BACD	0737 713921	ANASTASIYA SMIRNOVA	{"phone": "+70650991567"}
0005434408256	C0E7E9	4714 910045	OLGA PETROVA	{"phone": "+70940872671"}
0005434408257	C0E7E9	8795 129311	KSENIYA EGOROVA	{"email": "k.egorova_16081960@postgrespro.ru", "phone": "+70155238971"}
0005434408258	3135ED	4672 946806	ELENA YAKOVLEVA	{"phone": "+70857951872"}
0005434408259	3135ED	2064 259434	ANNA ERMAKOVA	{"phone": "+70426107577"}
0005434408260	2D2627	3365 065953	VLADIMIR MIRONOV	{"email": "vladimir_mironov-17051979@postgrespro.ru", "phone": "+70152576569"}
0005434408261	1C7A73	4944 884991	ELENA MARTYNOVA	{"phone": "+70632883214"}
0005434408262	625516	7108 087255	VALENTINA CHERNOVA	{"phone": "+70184584476"}
0005434408263	625516	9990 253905	IVAN KRASNOV	{"email": "krasnov_i_061963@postgrespro.ru", "phone": "+70337942582"}
0005434408264	625516	7834 122714	DANIIL MELNIKOV	{"phone": "+70706259740"}
0005434408265	4B93C8	6411 563636	MARAT DMITRIEV	{"email": "dmitriev.m_041972@postgrespro.ru", "phone": "+70051409374"}
0005434408266	4B93C8	0584 351303	ALEKSANDR MELNIKOV	{"phone": "+70455543195"}
0005434408267	A073B0	7342 887359	LIDIYA NESTEROVA	{"email": "nesterova-lidiya1971@postgrespro.ru", "phone": "+70484512138"}
0005434408268	A073B0	2425 425414	VALERIYA ORLOVA	{"email": "orlova.valeriya10041969@postgrespro.ru", "phone": "+70959621528"}
0005434408269	CCEF70	8301 728518	YANINA KONOVALOVA	{"email": "yanina.konovalova-24011964@postgrespro.ru", "phone": "+70994913220"}
0005434408270	CCEF70	4615 345963	SERGEY SOROKIN	{"phone": "+70107669103"}
0005434408271	0AADE4	3385 015543	NIKOLAY MIKHAYLOV	{"phone": "+70684694648"}
0005434408272	0AADE4	3420 248715	EVGENIY ANDREEV	{"email": "evgeniy-andreev.09011962@postgrespro.ru", "phone": "+70348883269"}
0005434408273	F7E43D	7708 084055	IRINA FEDOROVA	{"email": "ifedorova.071964@postgrespro.ru", "phone": "+70405250835"}
0005434408274	E872D8	8613 879152	GEORGIY IVANOV	{"phone": "+70534162730"}
0005434408275	F7EA02	7131 963847	OLGA KRASNOVA	{"email": "olga-krasnova-1980@postgrespro.ru", "phone": "+70740358212"}
0005434408276	F7EA02	6141 817149	DANIYA MARTYNOVA	{"phone": "+70011312775"}
0005434408277	17D83D	4858 586969	MIKHAIL GRIGOREV	{"phone": "+70286128459"}
0005434408278	CD9B81	6708 389784	GALINA GERASIMOVA	{"email": "g-gerasimova06101981@postgrespro.ru", "phone": "+70189712022"}
0005434408279	DBDC58	4030 779049	KLAVDIYA KUZNECOVA	{"phone": "+70547476478"}
0005434408280	C9279F	1600 783098	TATYANA IVANOVA	{"email": "tatyana-ivanova-1976@postgrespro.ru", "phone": "+70812563120"}
0005434408281	8E0DAC	1511 505766	NATALYA ERMAKOVA	{"email": "ermakovan_1972@postgrespro.ru", "phone": "+70559752409"}
0005434408282	8B4C05	7691 542107	VALENTINA YAKOVLEVA	{"phone": "+70385585768"}
0005434408283	06F876	5169 822348	VALENTINA TIKHONOVA	{"phone": "+70631597303"}
0005434408284	EC519C	7881 739640	ALEKSEY PETROV	{"phone": "+70435926924"}
0005434408285	36C120	6097 364106	VALERIYA RYABOVA	{"email": "ryabova.v_21121968@postgrespro.ru", "phone": "+70594987993"}
0005434408286	4F8FF1	2723 889685	ALEKSANDR ZAKHAROV	{"phone": "+70298731120"}
0005434408287	E19835	9774 457243	EKATERINA KISELEVA	{"phone": "+70099896783"}
0005434408288	F6A0E2	5063 212223	SVETLANA MAKAROVA	{"phone": "+70297670546"}
0005434408289	268115	3293 972924	VALERIY KULIKOV	{"phone": "+70550344936"}
0005434408290	E74AC9	0215 919767	FARID SERGEEV	{"phone": "+70889909130"}
0005434408291	E74AC9	5570 400315	OLGA KOZLOVA	{"email": "o-kozlova_071970@postgrespro.ru", "phone": "+70891657262"}
0005434408533	8F5D94	3886 850341	NIKOLAY SAVELEV	{"phone": "+70381839564"}
0005434408292	E74AC9	5951 616305	ALBINA FILATOVA	{"email": "filatova-albina_01021975@postgrespro.ru", "phone": "+70717153039"}
0005434408293	21472F	7531 855452	NIKOLAY MIKHAYLOV	{"email": "nikolay-mikhaylov_091974@postgrespro.ru", "phone": "+70295413467"}
0005434408294	21472F	7570 807661	IRINA LUKYANOVA	{"email": "i.lukyanova-101967@postgrespro.ru", "phone": "+70072471492"}
0005434408295	920512	3501 297209	ALEKSANDR SOKOLOV	{"phone": "+70356480905"}
0005434408296	920512	6790 990744	ANNA SCHERBAKOVA	{"phone": "+70620376528"}
0005434408297	B7A699	4046 930822	ANDREY PETROV	{"phone": "+70348394719"}
0005434408298	D4F707	7814 568455	ANATOLIY VLASOV	{"email": "vlasov.a-1968@postgrespro.ru", "phone": "+70217412321"}
0005434408299	34F165	5812 875019	OLESYA TARASOVA	{"phone": "+70939317685"}
0005434408300	774F6D	3875 599013	OLGA NAUMOVA	{"email": "naumova-olga_081980@postgrespro.ru", "phone": "+70874346245"}
0005434408301	774F6D	2774 546440	NATALYA SMIRNOVA	{"phone": "+70292106026"}
0005434408302	C87EF1	5780 111132	YULIYA KOROLEVA	{"email": "koroleva_yuliya1977@postgrespro.ru", "phone": "+70768288515"}
0005434408303	EE7B8C	8008 875637	EKATERINA KUZNECOVA	{"phone": "+70781084506"}
0005434408304	3FFBFE	2046 673631	OLGA KUZMINA	{"phone": "+70416240064"}
0005434408305	3FFBFE	5343 641821	KONSTANTIN NOVIKOV	{"email": "k-novikov.1980@postgrespro.ru", "phone": "+70518695902"}
0005434408306	51349C	7512 080571	SOFYA POPOVA	{"phone": "+70361886518"}
0005434408307	C0442A	9918 265970	YULIYA ZAKHAROVA	{"email": "yzakharova081974@postgrespro.ru", "phone": "+70711928350"}
0005434408308	C0442A	3829 941515	PRASKOVYA KONDRATEVA	{"phone": "+70752414908"}
0005434408309	6F9D0A	6678 411592	DANIL TARASOV	{"phone": "+70124258319"}
0005434408310	DFA47C	1960 046191	VIKTOR DMITRIEV	{"email": "v.dmitriev_26011970@postgrespro.ru", "phone": "+70693705690"}
0005434408311	D66B76	5573 117465	SOFYA SCHERBAKOVA	{"phone": "+70593885707"}
0005434408312	95EB78	7888 648717	DMITRIY BORISOV	{"phone": "+70661252652"}
0005434408313	5D4AEE	3760 903679	YULIYA GUSEVA	{"email": "y_guseva_101967@postgrespro.ru", "phone": "+70224969891"}
0005434408314	9F10FB	6191 391926	KSENIYA KISELEVA	{"phone": "+70521225284"}
0005434408315	60542C	0461 495137	YAROSLAV MOROZOV	{"email": "y_morozov.1985@postgrespro.ru", "phone": "+70492516916"}
0005434408316	60542C	1230 017240	LYUDMILA VASILEVA	{"phone": "+70921807667"}
0005434408317	7468FC	9884 071936	OLESYA KUZNECOVA	{"email": "o.kuznecova-20011969@postgrespro.ru", "phone": "+70213921529"}
0005434408318	B764CE	1964 624109	YURIY IVANOV	{"phone": "+70396583528"}
0005434408319	6B5A0F	7971 051091	VLADIMIR KUZMIN	{"phone": "+70112437836"}
0005434408320	F5381C	4647 151234	NIKOLAY ANDREEV	{"email": "andreev-n1981@postgrespro.ru", "phone": "+70093594091"}
0005434408321	F5381C	0743 067309	RAMIL PETROV	{"phone": "+70494424440"}
0005434408322	1D8AA7	2729 436186	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva.lyudmila_01021973@postgrespro.ru", "phone": "+70907440596"}
0005434408323	2C0588	5116 435477	ALEKSANDR BELOV	{"email": "belov-aleksandr_111970@postgrespro.ru", "phone": "+70548682919"}
0005434408324	E69B4F	9391 958840	SERGEY SOROKIN	{"email": "sorokin.sergey_101964@postgrespro.ru", "phone": "+70561207244"}
0005434408325	971F48	5507 771112	IVAN SMIRNOV	{"email": "smirnovivan.17081970@postgrespro.ru", "phone": "+70259724994"}
0005434408326	971F48	9306 920371	DILYARA NIKOLAEVA	{"phone": "+70985737778"}
0005434408327	A0D132	2976 204593	GALINA DENISOVA	{"email": "galina-denisova1970@postgrespro.ru", "phone": "+70403372131"}
0005434408328	8BF8AB	2513 566264	SERGEY VOROBEV	{"email": "vorobev_sergey_1968@postgrespro.ru", "phone": "+70753183423"}
0005434408329	2A0F66	2147 290792	ALENA KOMAROVA	{"phone": "+70534477781"}
0005434408330	2A0F66	2227 199440	ALEKSANDR ISAEV	{"email": "isaev_a-1983@postgrespro.ru", "phone": "+70408744501"}
0005434408331	10C079	5020 762652	LYUDMILA PETROVA	{"phone": "+70561620442"}
0005434408332	10C079	6075 146626	ALEKSEY ROMANOV	{"email": "aromanov1966@postgrespro.ru", "phone": "+70184058334"}
0005434408333	10C079	7221 248087	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr-07041979@postgrespro.ru", "phone": "+70222740290"}
0005434408334	10C079	7701 064795	SEMEN MIRONOV	{"email": "semenmironov_07061970@postgrespro.ru", "phone": "+70452484360"}
0005434408335	ECA997	4088 193441	ANASTASIYA KUDRYASHOVA	{"email": "kudryashovaanastasiya-22091974@postgrespro.ru", "phone": "+70476344665"}
0005434408336	9C4AED	8333 713387	PETR ROMANOV	{"email": "romanov.petr-071976@postgrespro.ru", "phone": "+70946105009"}
0005434408337	9C4AED	9134 824810	GALINA MEDVEDEVA	{"phone": "+70411062988"}
0005434408338	9C4AED	8082 636782	EKATERINA MEDVEDEVA	{"email": "ekaterina-medvedeva.041976@postgrespro.ru", "phone": "+70057759031"}
0005434408339	698B41	5040 465773	VALENTINA FEDOROVA	{"email": "v_fedorova.17061976@postgrespro.ru", "phone": "+70180696557"}
0005434408340	AFD5E8	7642 858651	VITALIY IVANOV	{"phone": "+70052848227"}
0005434408341	AFD5E8	9333 891905	VITALIY CHERNOV	{"phone": "+70794479321"}
0005434408342	BA214F	4240 760066	ALEVTINA DENISOVA	{"email": "denisova.a.1972@postgrespro.ru", "phone": "+70948506906"}
0005434408343	BA214F	0581 805853	NATALYA SEMENOVA	{"email": "natalya-semenova-1983@postgrespro.ru", "phone": "+70304854032"}
0005434408344	BA214F	9519 535876	ANDREY RODIONOV	{"email": "rodionov_a-1959@postgrespro.ru", "phone": "+70115344598"}
0005434408345	EEEA30	8437 375737	NIKOLAY KAZAKOV	{"email": "n-kazakov021982@postgrespro.ru", "phone": "+70319499609"}
0005434408346	32FF56	1893 468617	ANASTASIYA SERGEEVA	{"email": "sergeeva_a-05101966@postgrespro.ru", "phone": "+70515307449"}
0005434408347	32FF56	5080 274572	NATALYA SIDOROVA	{"email": "sidorovanatalya-111971@postgrespro.ru", "phone": "+70431257198"}
0005434408348	453DB7	1640 219562	EKATERINA LAZAREVA	{"email": "e-lazareva.091978@postgrespro.ru", "phone": "+70489630185"}
0005434408349	0A7B9D	2847 365244	MARIYA ILINA	{"phone": "+70958547798"}
0005434408715	84A506	3939 237437	VYACHESLAV KUZNECOV	{"phone": "+70022027549"}
0005434408350	0A7B9D	0998 254515	YURIY DAVYDOV	{"email": "yuriydavydov1964@postgrespro.ru", "phone": "+70837744866"}
0005434408351	04ED55	0466 251428	LYUBOV VASILEVA	{"phone": "+70804363290"}
0005434408352	2CD11D	7291 302948	VLADIMIR SERGEEV	{"phone": "+70356294592"}
0005434408353	2CD11D	1877 088130	ALINA KOROLEVA	{"email": "a.koroleva_041987@postgrespro.ru", "phone": "+70950936638"}
0005434408354	539F3C	2442 911574	SERGEY PETROV	{"phone": "+70283945500"}
0005434408355	E95FDD	0568 923052	SVETLANA POPOVA	{"email": "spopova1962@postgrespro.ru", "phone": "+70420769372"}
0005434408356	2540FD	1274 440735	ARTEM ZHURAVLEV	{"phone": "+70938693460"}
0005434408357	AF283F	4905 574779	GENNADIY PAVLOV	{"email": "g.pavlov_13121978@postgrespro.ru", "phone": "+70664387142"}
0005434408358	AF283F	2015 918430	DMITRIY KUZNECOV	{"phone": "+70795670777"}
0005434408359	754A43	3187 303161	VLADIMIR SCHERBAKOV	{"email": "vladimir.scherbakov.061975@postgrespro.ru", "phone": "+70668567453"}
0005434408360	7C095A	4666 996752	GENNADIY ZAKHAROV	{"phone": "+70048681754"}
0005434408361	3A1102	0358 688499	EVGENIY ABRAMOV	{"email": "abramov-evgeniy_1970@postgrespro.ru", "phone": "+70624847479"}
0005434408362	3A1102	3452 837494	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev051970@postgrespro.ru", "phone": "+70008890830"}
0005434408363	18225E	3231 783974	LYUBOV KRASNOVA	{"email": "lyubov_krasnova_101976@postgrespro.ru", "phone": "+70775149366"}
0005434408364	67BBBB	0365 754789	YURIY ZAKHAROV	{"phone": "+70454107365"}
0005434408365	217D30	3307 288516	YULIYA IVANOVA	{"email": "y_ivanova-091968@postgrespro.ru", "phone": "+70854622536"}
0005434408366	63596E	0833 896414	ELENA STEPANOVA	{"email": "stepanova.e.1966@postgrespro.ru", "phone": "+70853261060"}
0005434408367	8CC27D	6425 908719	YURIY TIMOFEEV	{"email": "yuriy-timofeev051964@postgrespro.ru", "phone": "+70883193794"}
0005434408368	11CB39	6613 396265	ALEKSANDR FILIPPOV	{"email": "aleksandr_filippov-071977@postgrespro.ru", "phone": "+70318009436"}
0005434408369	11CB39	9807 333987	RUSLAN VLASOV	{"phone": "+70986580922"}
0005434408370	11CB39	9804 312029	ALBINA NESTEROVA	{"phone": "+70653822199"}
0005434408371	9A30CA	0287 741808	ROMAN IVANOV	{"phone": "+70298778849"}
0005434408372	9A30CA	9924 555609	ANASTASIYA ABRAMOVA	{"email": "abramova.anastasiya.24111974@postgrespro.ru", "phone": "+70574010419"}
0005434408373	17F59E	1804 810385	ALINA FILATOVA	{"phone": "+70218112096"}
0005434408374	17F59E	1079 553930	YAROSLAV ZAYCEV	{"phone": "+70154009953"}
0005434408375	BA793C	4153 219028	IRINA ALEKSANDROVA	{"phone": "+70407018657"}
0005434408376	BA793C	6761 270824	LYUBOV NAZAROVA	{"phone": "+70163567842"}
0005434408377	BA793C	5883 964067	MARIYA MARTYNOVA	{"phone": "+70857484412"}
0005434408378	677A3B	8471 115438	OLGA FEDOROVA	{"email": "o_fedorova_1975@postgrespro.ru", "phone": "+70972690651"}
0005434408379	C3B1B0	8449 209465	VLADIMIR GAVRILOV	{"email": "vgavrilov_16101975@postgrespro.ru", "phone": "+70020891037"}
0005434408380	FBEF2E	6099 478087	NATALYA FOMINA	{"email": "n-fomina.071977@postgrespro.ru", "phone": "+70637901703"}
0005434408381	E9C7A9	1369 940377	ALEKSANDR POPOV	{"email": "popov-a061971@postgrespro.ru", "phone": "+70998769141"}
0005434408382	65D0B2	8262 894975	RAISA SAVELEVA	{"phone": "+70988040817"}
0005434408383	65D0B2	6994 105294	SERGEY ABRAMOV	{"phone": "+70178833443"}
0005434408384	AAFE4F	8914 055129	TIMOFEY MATVEEV	{"phone": "+70664128738"}
0005434408386	5EFC97	1941 531799	IRINA MATVEEVA	{"email": "irina_matveeva_1970@postgrespro.ru", "phone": "+70838572612"}
0005434408387	C2DFF6	8388 113195	SERGEY PETROV	{"phone": "+70862942490"}
0005434408388	17CA0C	3383 699147	ELENA SERGEEVA	{"phone": "+70380664171"}
0005434408389	5D79EC	7448 417479	EVGENIY MIRONOV	{"phone": "+70856936273"}
0005434408390	888AB0	9261 391435	MAKSIM ABRAMOV	{"phone": "+70002624559"}
0005434408391	888AB0	9497 196912	NINA IVANOVA	{"phone": "+70656183957"}
0005434408392	E3B83D	1595 636853	VALENTINA ALEKSANDROVA	{"email": "valentina_aleksandrova.18011969@postgrespro.ru", "phone": "+70246446494"}
0005434408393	B244F3	0929 054052	OLEG FROLOV	{"phone": "+70075634080"}
0005434408394	B244F3	0357 460983	SVETLANA NIKOLAEVA	{"email": "nikolaeva-svetlana.09041966@postgrespro.ru", "phone": "+70304190807"}
0005434408395	36516E	4378 497952	ALEKSANDR KARPOV	{"email": "karpov_aleksandr.24081970@postgrespro.ru", "phone": "+70519431864"}
0005434408396	713F4B	9868 472863	YURIY SERGEEV	{"email": "y.sergeev-02101968@postgrespro.ru", "phone": "+70437915133"}
0005434408397	05FEA5	0299 353673	ARTEM BARANOV	{"phone": "+70917544038"}
0005434408398	339F86	4629 068708	PETR MIKHAYLOV	{"phone": "+70442152498"}
0005434408399	5B1B06	1266 963298	VLADIMIR ISAEV	{"phone": "+70747024803"}
0005434408400	5F5605	7027 503270	ALEKSANDR DMITRIEV	{"phone": "+70072511507"}
0005434408401	5F5605	2562 602565	ANDREY SEMENOV	{"email": "semenov_a.06081975@postgrespro.ru", "phone": "+70580888324"}
0005434408402	5F5605	3891 203155	EVGENIY KRASNOV	{"phone": "+70959322822"}
0005434408403	F77CF4	3721 325490	TATYANA KOZLOVA	{"email": "t_kozlova-24101964@postgrespro.ru", "phone": "+70555378352"}
0005434408404	F77CF4	7010 942268	YULIYA POLYAKOVA	{"email": "yuliya.polyakova-1970@postgrespro.ru", "phone": "+70985677490"}
0005434408405	0B13AE	9944 628344	SERGEY ZAYCEV	{"phone": "+70049369942"}
0005434408406	0B13AE	4774 119330	OLGA MIRONOVA	{"phone": "+70559796717"}
0005434408407	4E59C7	9374 384988	IGOR ABRAMOV	{"email": "abramov-i-11111972@postgrespro.ru", "phone": "+70094113679"}
0005434408408	4E59C7	7041 233220	NINA ANTONOVA	{"email": "nantonova_03031974@postgrespro.ru", "phone": "+70079958110"}
0005434408409	9A04AA	8149 330979	VIKTORIYA KULIKOVA	{"email": "v-kulikova091982@postgrespro.ru", "phone": "+70393039115"}
0005434408410	A0469F	4905 320268	OKSANA MIRONOVA	{"email": "mironova.oksana.1976@postgrespro.ru", "phone": "+70613133036"}
0005434408411	E735F9	2243 490830	LYUBOV POPOVA	{"phone": "+70677586222"}
0005434408412	E735F9	3276 149376	VLADIMIR BARANOV	{"email": "baranovvladimir-23091972@postgrespro.ru", "phone": "+70658928490"}
0005434408413	9B577C	1193 807978	ANNA SMIRNOVA	{"phone": "+70887971095"}
0005434408414	629CC8	2089 685977	ALEKSANDR KUZNECOV	{"phone": "+70054882643"}
0005434408415	629CC8	1299 492093	GALINA MIRONOVA	{"email": "galina-mironova_19121970@postgrespro.ru", "phone": "+70662669850"}
0005434408416	6A910B	0264 592821	OLGA IVANOVA	{"phone": "+70627250649"}
0005434408417	886FA2	1052 162609	NADEZHDA DAVYDOVA	{"phone": "+70675960690"}
0005434408418	2C373A	7109 943998	SERGEY ANTONOV	{"phone": "+70588000629"}
0005434408419	30235D	3217 792532	ELENA FROLOVA	{"phone": "+70099177127"}
0005434408420	30235D	0272 427492	ILGIZ BORISOV	{"email": "borisov.i-031979@postgrespro.ru", "phone": "+70132705959"}
0005434408421	30235D	7014 448900	OLEG DAVYDOV	{"phone": "+70652567612"}
0005434408422	7AB20B	8495 421898	TATYANA ZAKHAROVA	{"phone": "+70769412658"}
0005434408423	7AB20B	2994 138727	LYUBOV SMIRNOVA	{"email": "lyubov-smirnova30101970@postgrespro.ru", "phone": "+70958942102"}
0005434408424	9A5FF8	6694 060797	DANILA MOROZOV	{"email": "d.morozov051967@postgrespro.ru", "phone": "+70223012841"}
0005434408425	E9F357	4283 220362	OKSANA BELOVA	{"phone": "+70921992136"}
0005434408426	91FBB5	5318 185288	NINA ANTONOVA	{"phone": "+70383892126"}
0005434408427	91FBB5	3793 332944	ALEKSANDR MELNIKOV	{"phone": "+70845124132"}
0005434408428	0C1BDC	7135 352439	MARIYA YAKOVLEVA	{"phone": "+70925029638"}
0005434408429	C222DA	1585 062884	TATYANA POPOVA	{"email": "popovatatyana-07021972@postgrespro.ru", "phone": "+70654368625"}
0005434408430	C222DA	8873 438509	ELENA BOGDANOVA	{"phone": "+70084059431"}
0005434408431	B5E75E	1476 535764	ANASTASIYA MIRONOVA	{"email": "mironovaa.111971@postgrespro.ru", "phone": "+70093438332"}
0005434408432	6725A0	8774 022724	ELENA IVANOVA	{"email": "elenaivanova.081966@postgrespro.ru", "phone": "+70840694213"}
0005434408433	32DCE8	1972 513104	PAVEL VASILEV	{"email": "pavel-vasilev-13101974@postgrespro.ru", "phone": "+70363896973"}
0005434408434	0B9179	3746 971497	IRINA GERASIMOVA	{"phone": "+70095128506"}
0005434408435	63F825	1033 167174	LILIYA STEPANOVA	{"email": "stepanova.liliya08051972@postgrespro.ru", "phone": "+70292794251"}
0005434408436	7C1B67	5138 355005	ANDREY BONDARENKO	{"email": "andreybondarenko-15071975@postgrespro.ru", "phone": "+70230328989"}
0005434408437	E1D855	1854 657559	NADEZHDA SERGEEVA	{"email": "nadezhda.sergeeva_121973@postgrespro.ru", "phone": "+70694031959"}
0005434408438	E1D855	0400 040683	GULNARA SOROKINA	{"email": "gulnarasorokina_17051967@postgrespro.ru", "phone": "+70838601919"}
0005434408439	B736F1	3286 301048	VALENTINA POPOVA	{"phone": "+70114508643"}
0005434408440	C8A418	8652 359801	VLADIMIR ZAKHAROV	{"email": "zakharovv_09021978@postgrespro.ru", "phone": "+70768865570"}
0005434408441	3C72F8	9361 400959	VIKTOR FOMIN	{"email": "viktor_fomin041966@postgrespro.ru", "phone": "+70479838987"}
0005434408442	D98412	7858 601755	YURIY POPOV	{"email": "popov.yuriy25121988@postgrespro.ru", "phone": "+70732343903"}
0005434408443	51B41C	3108 782784	SERGEY ILIN	{"phone": "+70843265740"}
0005434408444	51B41C	8121 984967	NATALYA STEPANOVA	{"email": "natalya-stepanova.081965@postgrespro.ru", "phone": "+70077435940"}
0005434408445	BE86D7	0680 420583	RADIK KONOVALOV	{"phone": "+70758863144"}
0005434408446	BD9DD8	2198 248542	SVETLANA YUDINA	{"email": "s-yudina.1963@postgrespro.ru", "phone": "+70791161805"}
0005434408447	4F3A5A	3929 169097	MAKSIM MIRONOV	{"phone": "+70900012681"}
0005434408448	CB71B6	3380 495948	KLARA FEDOROVA	{"email": "klara_fedorova-1978@postgrespro.ru", "phone": "+70440804772"}
0005434408449	E6FB17	2549 612761	VALENTINA POPOVA	{"phone": "+70707752048"}
0005434408450	E6FB17	9258 064294	MARIANNA ROMANOVA	{"phone": "+70882882336"}
0005434408451	013D5A	7219 377663	ELENA EFREMOVA	{"email": "e_efremova_22071979@postgrespro.ru", "phone": "+70253502953"}
0005434408452	013D5A	4599 595421	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana.28091973@postgrespro.ru", "phone": "+70465861100"}
0005434408453	A2B091	8786 783677	LYUDMILA NAZAROVA	{"phone": "+70068306237"}
0005434408454	2AF412	0549 936430	YULIYA FROLOVA	{"phone": "+70591086704"}
0005434408455	2AF412	6781 026121	DENIS NIKITIN	{"phone": "+70481432632"}
0005434408456	F67AE7	9270 943747	SERGEY SHEVCHENKO	{"email": "shevchenko_s11061971@postgrespro.ru", "phone": "+70737175416"}
0005434408457	8ACE67	2663 906557	ALEKSANDR PAVLOV	{"phone": "+70905735738"}
0005434408458	916D98	4951 212999	EVGENIY ANTONOV	{"email": "antonove_021981@postgrespro.ru", "phone": "+70308586819"}
0005434408459	45A230	1756 931161	YURIY KAZAKOV	{"phone": "+70422943562"}
0005434408460	45A230	6715 545340	DMITRIY ZHURAVLEV	{"phone": "+70135869447"}
0005434408461	03FD3D	2445 948774	LARISA NIKITINA	{"email": "larisa.nikitina.23051969@postgrespro.ru", "phone": "+70056428314"}
0005434408462	03FD3D	6191 754581	LYUBOV KISELEVA	{"email": "kiseleva-lyubov.1977@postgrespro.ru", "phone": "+70011241459"}
0005434408463	5E94A8	8148 395841	MARINA BOGDANOVA	{"phone": "+70153810664"}
0005434408464	5E94A8	8220 555932	KARINA MAKSIMOVA	{"email": "maksimova-k-121972@postgrespro.ru", "phone": "+70381947917"}
0005434408465	5917E4	9079 111039	SVETLANA KUZNECOVA	{"phone": "+70639383941"}
0005434408466	658CFE	8975 115885	ALEKSANDR BORISOV	{"phone": "+70970953389"}
0005434408467	658CFE	6214 549223	ZINAIDA RYABOVA	{"phone": "+70883505318"}
0005434408468	96ADFD	8992 873231	NIKOLAY KOZLOV	{"email": "kozlov-n_111974@postgrespro.ru", "phone": "+70615789907"}
0005434408469	0AC046	2202 161437	VLADIMIR SCHERBAKOV	{"email": "v_scherbakov_081969@postgrespro.ru", "phone": "+70101355317"}
0005434408470	0AC046	6858 561828	ILYA ZHUKOV	{"email": "zhukov_i_1980@postgrespro.ru", "phone": "+70667998246"}
0005434408471	59B1FA	4781 538209	TAMARA FOMINA	{"phone": "+70313943076"}
0005434408774	3AFAD0	5632 070069	IVAN KUZNECOV	{"phone": "+70685246395"}
0005434408472	04B238	2732 938180	RIMMA ZAKHAROVA	{"email": "rimma.zakharova.081980@postgrespro.ru", "phone": "+70065816575"}
0005434408473	5B8463	8571 689235	MIKHAIL KRASNOV	{"phone": "+70421155105"}
0005434408474	5E8FBF	6543 692305	NIKOLAY ALEKSEEV	{"email": "n_alekseev_23011961@postgrespro.ru", "phone": "+70351744376"}
0005434408475	A86411	6223 343619	ZINAIDA LEBEDEVA	{"email": "zinaida.lebedeva_26061981@postgrespro.ru", "phone": "+70454063480"}
0005434408476	E8446E	1607 959711	SERGEY SMIRNOV	{"phone": "+70200797357"}
0005434408477	23041C	9049 750209	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov-10041972@postgrespro.ru", "phone": "+70400599700"}
0005434408478	1C6C12	0892 202315	NINA MAKAROVA	{"phone": "+70121370232"}
0005434408479	1C6C12	2471 577419	SVETLANA SOROKINA	{"email": "svetlana-sorokina-08061969@postgrespro.ru", "phone": "+70296518001"}
0005434408480	CAF38A	6551 841055	IGOR GUSEV	{"email": "gusev.i_041961@postgrespro.ru", "phone": "+70557697559"}
0005434408481	CAF38A	0334 108953	ELENA VOROBEVA	{"phone": "+70861910646"}
0005434408482	B8723A	6883 515053	ELENA NOVIKOVA	{"phone": "+70572318563"}
0005434408483	1AAF56	8794 930531	GALINA POPOVA	{"email": "popova.g_111987@postgrespro.ru", "phone": "+70551650088"}
0005434408484	459D39	8810 324245	NINA IVANOVA	{"phone": "+70707098887"}
0005434408485	8A1431	6061 785465	NIKOLAY IVANOV	{"email": "n_ivanov.011973@postgrespro.ru", "phone": "+70869785252"}
0005434408486	8A1431	7838 483420	LYUDMILA MAKAROVA	{"phone": "+70192578695"}
0005434408487	A99246	5206 501701	IRINA TARASOVA	{"phone": "+70707585023"}
0005434408488	EE2A7A	8217 396642	MARGARITA GRISHINA	{"phone": "+70938797564"}
0005434408489	EE2A7A	2896 164440	LYUDMILA KALININA	{"email": "l.kalinina-081976@postgrespro.ru", "phone": "+70387548755"}
0005434408490	233350	0618 170054	VLADIMIR KUZNECOV	{"phone": "+70011502293"}
0005434408491	233350	2534 834369	ALEKSANDR MAKAROV	{"phone": "+70079751893"}
0005434408492	7FF827	4249 844933	LYUBOV MIRONOVA	{"email": "mironova-l.1969@postgrespro.ru", "phone": "+70709213471"}
0005434408493	A420AA	2197 185502	ARTEM ZAKHAROV	{"phone": "+70667180114"}
0005434408494	CD86CF	1720 172922	OLEG RODIONOV	{"email": "rodionov_oleg-1966@postgrespro.ru", "phone": "+70907640241"}
0005434408495	42731A	6872 379304	VERA SEMENOVA	{"phone": "+70704501743"}
0005434408496	E4389A	4915 705269	VALENTINA KARPOVA	{"email": "vkarpova.28081963@postgrespro.ru", "phone": "+70068319153"}
0005434408497	E52F97	4890 589535	DANILA SIDOROV	{"phone": "+70383717087"}
0005434408498	B15C56	7192 211786	TATYANA NIKITINA	{"phone": "+70804924379"}
0005434408499	974B33	7912 372120	ARTEM FEDOTOV	{"phone": "+70591837066"}
0005434408500	974B33	9991 358434	VALENTINA TIKHONOVA	{"email": "tikhonova-v111972@postgrespro.ru", "phone": "+70692316201"}
0005434408501	76B5CC	0786 756068	ANTONINA MIKHAYLOVA	{"phone": "+70772778610"}
0005434408502	76B5CC	7501 261622	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov.03081972@postgrespro.ru", "phone": "+70931191764"}
0005434408503	120682	5750 848623	LYUDMILA ORLOVA	{"email": "orlova_lyudmila17071975@postgrespro.ru", "phone": "+70773252569"}
0005434408504	56AC16	2195 267916	SERGEY SCHERBAKOV	{"phone": "+70959279572"}
0005434408505	1661AC	6750 019185	VALENTIN BONDARENKO	{"phone": "+70722386677"}
0005434408506	3B1E92	6620 224287	SERGEY SIDOROV	{"phone": "+70486665174"}
0005434408507	6168A1	4458 940434	GALINA NESTEROVA	{"email": "g-nesterova091995@postgrespro.ru", "phone": "+70408429969"}
0005434408508	4473D5	3781 603674	ELENA ORLOVA	{"phone": "+70917341990"}
0005434408509	24ECAA	5381 326915	LYUDMILA GAVRILOVA	{"email": "gavrilova_lyudmila.051978@postgrespro.ru", "phone": "+70851146662"}
0005434408510	24ECAA	5801 870880	VALENTINA MEDVEDEVA	{"email": "valentina-medvedeva1971@postgrespro.ru", "phone": "+70555985212"}
0005434408511	34CBEA	8110 332454	TATYANA ROMANOVA	{"phone": "+70798231219"}
0005434408512	49AEE7	8735 796946	VADIM KISELEV	{"email": "vadim_kiselev.1958@postgrespro.ru", "phone": "+70542309444"}
0005434408513	9A4CE0	9716 710209	ANATOLIY KUDRYASHOV	{"email": "kudryashov.a.19111975@postgrespro.ru", "phone": "+70018729660"}
0005434408514	EF1FDB	1688 392848	ALEKSANDRA KISELEVA	{"email": "kiselevaa_1959@postgrespro.ru", "phone": "+70431324939"}
0005434408515	F624F4	0040 205687	ANNA KOVALEVA	{"phone": "+70235251499"}
0005434408516	1D473B	7689 027772	NIKOLAY KUZNECOV	{"phone": "+70827193720"}
0005434408517	E38530	5597 792617	ANATOLIY ZAKHAROV	{"phone": "+70804286206"}
0005434408518	E38530	4649 342624	IVAN KONOVALOV	{"phone": "+70104328942"}
0005434408519	F5AAF5	9541 472984	IVAN KUZNECOV	{"email": "ivankuznecov-041960@postgrespro.ru", "phone": "+70491796297"}
0005434408520	299609	8884 066128	GULFIYA PAVLOVA	{"phone": "+70483134322"}
0005434408521	A94E32	6152 054685	GALINA YAKOVLEVA	{"email": "yakovleva.galina17041966@postgrespro.ru", "phone": "+70270779775"}
0005434408522	2C9F53	2457 004017	DMITRIY MATVEEV	{"email": "dmitriy.matveev_081969@postgrespro.ru", "phone": "+70590749391"}
0005434408523	A5D4DA	6555 324281	ARTEM NIKITIN	{"email": "nikitinartem07111968@postgrespro.ru", "phone": "+70838588620"}
0005434408524	54A37E	4281 765923	ALEKSANDR YAKOVLEV	{"phone": "+70672265396"}
0005434408525	54A37E	6379 235676	NINA GAVRILOVA	{"phone": "+70471979268"}
0005434408526	633F34	3881 597218	ELENA GUSEVA	{"phone": "+70700992363"}
0005434408527	E1AD4D	6102 012265	TATYANA VOROBEVA	{"email": "vorobeva-tatyana121970@postgrespro.ru", "phone": "+70586449808"}
0005434408528	169336	0636 338638	EVGENIY IVANOV	{"phone": "+70037740290"}
0005434408529	59DEE9	0396 254001	SERGEY FROLOV	{"email": "frolovsergey.20031963@postgrespro.ru", "phone": "+70092169011"}
0005434408530	59DEE9	0146 774470	SERGEY KONOVALOV	{"phone": "+70177208528"}
0005434408531	4020E4	8672 814165	YULIYA EGOROVA	{"email": "yuliya_egorova021978@postgrespro.ru", "phone": "+70565943533"}
0005434408532	A168E8	5761 233583	IRINA MELNIKOVA	{"phone": "+70453995151"}
0005434408534	8F5D94	8769 549401	INNA KARPOVA	{"email": "i.karpova_1981@postgrespro.ru", "phone": "+70933742139"}
0005434408535	8F5D94	3999 824158	KRISTINA KOROLEVA	{"phone": "+70137228859"}
0005434408536	5B9327	4692 277960	ALEKSANDR SCHERBAKOV	{"phone": "+70122026220"}
0005434408537	669A2F	1687 360771	ANDREY SEMENOV	{"email": "semenov.a.15011976@postgrespro.ru", "phone": "+70359503769"}
0005434408538	83CA16	9056 724392	YURIY MOROZOV	{"email": "y.morozov-1976@postgrespro.ru", "phone": "+70160826635"}
0005434408539	83CA16	9378 260199	DANIIL ROMANOV	{"email": "romanov.d.1972@postgrespro.ru", "phone": "+70642721099"}
0005434408540	D9BFEE	6007 713196	SERGEY PETROV	{"email": "petrov_s-1983@postgrespro.ru", "phone": "+70647347049"}
0005434408541	5DD8CE	2866 275812	ALEKSANDR MARTYNOV	{"phone": "+70336078625"}
0005434408542	DD1F26	7765 497737	ARTUR SCHERBAKOV	{"phone": "+70932012718"}
0005434408543	1F4093	8399 596984	DENIS VASILEV	{"email": "denisvasilev.1962@postgrespro.ru", "phone": "+70467009776"}
0005434408544	1F4093	8951 151990	EKATERINA SMIRNOVA	{"phone": "+70292959479"}
0005434408545	967EED	7278 362018	ALEKSEY MIKHAYLOV	{"email": "mikhaylov-aleksey_111983@postgrespro.ru", "phone": "+70593885077"}
0005434408546	967EED	4304 521353	NATALYA KUZNECOVA	{"email": "natalyakuznecova.23041971@postgrespro.ru", "phone": "+70099985563"}
0005434408547	496916	1658 367687	SVETLANA VOLKOVA	{"email": "volkova-svetlana081975@postgrespro.ru", "phone": "+70633088141"}
0005434408548	A3269C	5657 558632	RAISA MELNIKOVA	{"email": "melnikovar18091980@postgrespro.ru", "phone": "+70122978327"}
0005434408549	A3269C	6600 665862	NIKOLAY MAKSIMOV	{"phone": "+70998141762"}
0005434408550	DB2FCA	2838 107783	ALEKSANDR BARANOV	{"email": "aleksandr_baranov_28081960@postgrespro.ru", "phone": "+70541635412"}
0005434408551	FE96C4	2848 212913	IVAN FROLOV	{"phone": "+70522967038"}
0005434408552	37B1E3	0366 154815	ARTEM MAKAROV	{"phone": "+70388478891"}
0005434408553	37B1E3	7345 419726	YURIY VLASOV	{"phone": "+70381997648"}
0005434408554	8D0846	9140 699617	NINA FOMINA	{"email": "fomina_n_031970@postgrespro.ru", "phone": "+70494020573"}
0005434408555	0F6E06	1147 118486	ANATOLIY ZAKHAROV	{"email": "azakharov_15031977@postgrespro.ru", "phone": "+70131960613"}
0005434408556	71C9EC	0066 227276	ALEKSANDR NIKITIN	{"email": "aleksandr-nikitin.061964@postgrespro.ru", "phone": "+70313950496"}
0005434408557	CB2FA2	2598 669640	LEV SHEVCHENKO	{"email": "shevchenko.l_041968@postgrespro.ru", "phone": "+70991509999"}
0005434408558	CB2FA2	2052 559894	POLINA IVANOVA	{"phone": "+70461495148"}
0005434408559	18F530	5141 236615	TATYANA TARASOVA	{"phone": "+70431705943"}
0005434408560	7A1C85	4453 152245	ELENA PETROVA	{"email": "epetrova.1961@postgrespro.ru", "phone": "+70766795791"}
0005434408561	9C8B25	9353 328185	GENNADIY MOROZOV	{"email": "morozov.g.22011982@postgrespro.ru", "phone": "+70307997922"}
0005434408562	0B88D5	2060 582507	EKATERINA NAZAROVA	{"phone": "+70132581335"}
0005434408563	0B88D5	0243 917224	MARIYA VASILEVA	{"phone": "+70936177834"}
0005434408564	61A01D	3097 326739	NIKOLAY ALEKSEEV	{"phone": "+70391087496"}
0005434408565	8F4098	2202 408317	EVGENIY IVANOV	{"email": "ivanov_e-081962@postgrespro.ru", "phone": "+70206816357"}
0005434408566	B42074	8006 674652	LYUBOV ZAYCEVA	{"phone": "+70040918472"}
0005434408567	ADA455	8617 607970	NIKOLAY DMITRIEV	{"email": "dmitriev.nikolay-1972@postgrespro.ru", "phone": "+70939663924"}
0005434408568	ADA455	0722 997733	ELENA TIKHONOVA	{"phone": "+70792510031"}
0005434408569	F95EC9	7829 329716	MIKHAIL VOLKOV	{"phone": "+70468023634"}
0005434408570	F95EC9	6801 128091	GULNARA VASILEVA	{"phone": "+70938648938"}
0005434408571	F95EC9	8878 362102	ALEKSANDR PETROV	{"phone": "+70750626405"}
0005434408572	DBC583	8566 434843	GALINA NAZAROVA	{"email": "nazarovag_061973@postgrespro.ru", "phone": "+70974230632"}
0005434408573	DBC583	6670 008123	IVAN SERGEEV	{"email": "ivan.sergeev1973@postgrespro.ru", "phone": "+70500011839"}
0005434408574	29B22B	4348 569855	TATYANA KOMAROVA	{"email": "t_komarova.1971@postgrespro.ru", "phone": "+70719226935"}
0005434408575	80A525	6069 580218	TATYANA SOKOLOVA	{"phone": "+70914439350"}
0005434408576	80A525	9540 518791	IRINA ZAYCEVA	{"phone": "+70334248940"}
0005434408577	25EFC4	4903 868585	ANASTASIYA SEMENOVA	{"email": "semenova-a-28061976@postgrespro.ru", "phone": "+70654376487"}
0005434408578	7E4EB3	7705 726350	SVETLANA POLYAKOVA	{"email": "polyakova_s.20081967@postgrespro.ru", "phone": "+70149241559"}
0005434408579	A1186B	3804 602338	NATALYA TARASOVA	{"email": "natalyatarasova-23031970@postgrespro.ru", "phone": "+70482996574"}
0005434408580	A1186B	9763 229076	ANASTASIYA RYABOVA	{"phone": "+70455572818"}
0005434408581	FC27E2	8516 656773	ARMAN IVANOV	{"phone": "+70610159778"}
0005434408582	0C9FF2	6523 572302	VALENTINA MOROZOVA	{"email": "v-morozova-021966@postgrespro.ru", "phone": "+70590054676"}
0005434408583	0C9FF2	9263 197188	MIKHAIL SOROKIN	{"email": "m-sorokin_25051973@postgrespro.ru", "phone": "+70236849005"}
0005434408584	0FEAB7	8820 000919	NIKOLAY PETROV	{"phone": "+70342516615"}
0005434408585	0FEAB7	3165 063417	RAISA VASILEVA	{"email": "vasileva-raisa_11011973@postgrespro.ru", "phone": "+70561447899"}
0005434408586	5B13D5	8002 850212	SERGEY NAZAROV	{"email": "nazarov-sergey101973@postgrespro.ru", "phone": "+70596857330"}
0005434408587	D2E981	1895 195125	VLADIMIR ZHURAVLEV	{"phone": "+70811041521"}
0005434408588	DFD425	5722 450994	VIKTORIYA ANDREEVA	{"phone": "+70991435145"}
0005434408589	8718A1	3281 743578	SERGEY SCHERBAKOV	{"phone": "+70263595707"}
0005434408590	73018F	4281 279910	INGA ZHURAVLEVA	{"phone": "+70172083327"}
0005434408591	239C17	4284 809671	LYUBOV VLASOVA	{"phone": "+70233505601"}
0005434408592	239C17	2530 433489	VALENTINA MAKAROVA	{"phone": "+70100292127"}
0005434408593	C92909	5533 849983	MARIYA SAVELEVA	{"phone": "+70427801367"}
0005434408594	F84C57	0241 530042	VLADIMIR VASILEV	{"phone": "+70465518485"}
0005434408595	F12F99	2121 469667	SERGEY SMIRNOV	{"email": "smirnov-s.1975@postgrespro.ru", "phone": "+70145888963"}
0005434408596	A1922A	2236 377080	YANA SEMENOVA	{"email": "semenova-yana-04121970@postgrespro.ru", "phone": "+70724975977"}
0005434408597	09E423	2933 681652	RUSLAN MOROZOV	{"email": "ruslan.morozov111972@postgrespro.ru", "phone": "+70462578304"}
0005434408598	BA349D	9152 777783	GENNADIY ANTONOV	{"email": "gantonov_1968@postgrespro.ru", "phone": "+70559437320"}
0005434408599	BA349D	7394 842743	IGOR CHERNOV	{"email": "chernov.igor.19101958@postgrespro.ru", "phone": "+70547923021"}
0005434408600	54874D	0825 836713	SERGEY SHEVCHENKO	{"email": "sshevchenko1964@postgrespro.ru", "phone": "+70923808987"}
0005434408601	2F4C79	2084 551094	NATALYA KAZAKOVA	{"phone": "+70813646783"}
0005434408602	2F4C79	9467 809087	IRINA ERMAKOVA	{"email": "ermakova_irina.04071972@postgrespro.ru", "phone": "+70307270270"}
0005434408603	2F4C79	2284 859772	VALENTIN VLASOV	{"email": "vlasov.v-1977@postgrespro.ru", "phone": "+70520775525"}
0005434408604	B7734F	9183 214510	MARIYA MARTYNOVA	{"phone": "+70268913102"}
0005434408605	42BC7B	0394 565376	ANASTASIYA DMITRIEVA	{"phone": "+70995003137"}
0005434408606	AC7659	6263 835420	ANATOLIY KUZNECOV	{"phone": "+70570474958"}
0005434408607	87BB1F	5716 478153	DMITRIY KAZAKOV	{"phone": "+70775457271"}
0005434408608	87BB1F	5537 567944	ALEKSANDR DAVYDOV	{"phone": "+70475326674"}
0005434408609	05583D	3407 087446	GALINA PETROVA	{"phone": "+70999314044"}
0005434408610	F9A443	9565 227832	ARINA BELOVA	{"email": "a_belova.1980@postgrespro.ru", "phone": "+70889828835"}
0005434408611	CAEFD3	6011 990166	LILIYA SOKOLOVA	{"email": "liliya-sokolova011965@postgrespro.ru", "phone": "+70050265428"}
0005434408612	CAEFD3	2654 350531	YULIYA NIKIFOROVA	{"email": "yuliya_nikiforova-091969@postgrespro.ru", "phone": "+70463372852"}
0005434408613	78326A	2994 302701	SVETLANA ISAEVA	{"email": "isaeva.svetlana101979@postgrespro.ru", "phone": "+70707519693"}
0005434408614	78326A	5690 577265	NADEZHDA ZHURAVLEVA	{"phone": "+70318914225"}
0005434408615	173F4C	6343 698430	IVAN CHERNOV	{"phone": "+70606868725"}
0005434408616	0E14E6	6939 424337	VIKTORIYA BORISOVA	{"phone": "+70878733231"}
0005434408617	9BDE0C	7006 526977	STANISLAV PAVLOV	{"email": "pavlov-s-23091959@postgrespro.ru", "phone": "+70954045738"}
0005434408618	9BDE0C	6632 299212	NATALYA FILIPPOVA	{"email": "natalyafilippova_1980@postgrespro.ru", "phone": "+70599353722"}
0005434408619	E7CBC9	6230 290954	IVAN ORLOV	{"email": "orlov_ivan1981@postgrespro.ru", "phone": "+70301219708"}
0005434408620	E7CBC9	8432 546558	OLGA MATVEEVA	{"phone": "+70556458593"}
0005434408621	340153	5719 035011	YULIYA ALEKSANDROVA	{"email": "yaleksandrova-1972@postgrespro.ru", "phone": "+70914891401"}
0005434408622	3C0EBC	9884 205201	TIMUR DENISOV	{"phone": "+70553602404"}
0005434408623	CF216A	4897 340776	ELENA CHERNOVA	{"email": "chernova_e.061983@postgrespro.ru", "phone": "+70851562358"}
0005434408624	71567A	3911 772721	ANASTASIYA MOISEEVA	{"phone": "+70048099707"}
0005434408625	D83AF8	6222 885763	NATALYA BELOVA	{"email": "n.belova.081967@postgrespro.ru", "phone": "+70423497189"}
0005434408626	D83AF8	5246 261739	ALEKSEY VASILEV	{"phone": "+70038954544"}
0005434408627	D83AF8	4162 192597	KLAVDIYA FADEEVA	{"email": "fadeevaklavdiya.081973@postgrespro.ru", "phone": "+70969521802"}
0005434408628	F585D0	6052 514662	LIDIYA MAKAROVA	{"phone": "+70678522750"}
0005434408629	560AE7	9001 543744	NATALYA VOLKOVA	{"email": "natalya.volkova.19031973@postgrespro.ru", "phone": "+70459013743"}
0005434408630	32556D	4038 604687	OLGA FROLOVA	{"email": "frolova_o_24031970@postgrespro.ru", "phone": "+70757409510"}
0005434408631	32556D	4844 602609	LYUDMILA FEDOROVA	{"email": "fedorova.l-1971@postgrespro.ru", "phone": "+70644145263"}
0005434408632	51C9C8	5302 399821	NATALYA KOZLOVA	{"email": "natalya-kozlova.1961@postgrespro.ru", "phone": "+70995318793"}
0005434408633	51C9C8	6111 802393	NIKOLAY NAUMOV	{"email": "nikolay-naumov.1969@postgrespro.ru", "phone": "+70321248343"}
0005434408634	298563	7970 758519	NATALYA KULIKOVA	{"phone": "+70623221234"}
0005434408635	298563	0191 198539	ANATOLIY STEPANOV	{"email": "anatoliystepanov-1972@postgrespro.ru", "phone": "+70283998263"}
0005434408636	298563	2559 696983	DMITRIY BELOV	{"phone": "+70296890451"}
0005434408637	907C36	0009 108961	NATALYA ALEKSEEVA	{"phone": "+70456983817"}
0005434408638	907C36	7947 034514	NADEZHDA TIMOFEEVA	{"phone": "+70706060576"}
0005434408639	EC0509	4562 921894	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov_051973@postgrespro.ru", "phone": "+70611808819"}
0005434408640	B8D6F5	1137 008488	ALEKSEY OSIPOV	{"phone": "+70408400790"}
0005434408641	DABE4D	3938 414587	NINA DMITRIEVA	{"email": "dmitrieva-nina.17041968@postgrespro.ru", "phone": "+70653930223"}
0005434408642	28BC26	3052 444782	IGOR POPOV	{"phone": "+70607287489"}
0005434408643	124CCE	9308 855007	IGOR GUSEV	{"email": "igorgusev.02091964@postgrespro.ru", "phone": "+70467907168"}
0005434408644	124CCE	3594 986821	ALEKSANDR ANTONOV	{"email": "antonov.a1967@postgrespro.ru", "phone": "+70060655805"}
0005434408645	512E25	9936 322251	TATYANA BARANOVA	{"email": "tbaranova1968@postgrespro.ru", "phone": "+70394131556"}
0005434408646	5F98D5	0587 698747	DMITRIY IVANOV	{"email": "ivanov_d-1984@postgrespro.ru", "phone": "+70336801402"}
0005434408647	8E58F1	8903 606152	ANASTASIYA OSIPOVA	{"phone": "+70618021995"}
0005434408648	FA0DFF	8112 745960	NIKOLAY SAVELEV	{"email": "nikolay-savelev_091976@postgrespro.ru", "phone": "+70755971866"}
0005434408649	143D48	1223 821350	VADIM MOROZOV	{"phone": "+70345342614"}
0005434408650	B825A3	5170 353181	EVGENIY VASILEV	{"phone": "+70152593712"}
0005434408651	953C2E	2821 230877	ANDREY KUZMIN	{"email": "a.kuzmin11051983@postgrespro.ru", "phone": "+70818153518"}
0005434408652	953C2E	3781 879460	VIKTOR VASILEV	{"phone": "+70033809062"}
0005434408653	4BA27F	5615 710003	NIKOLAY SIDOROV	{"email": "nikolaysidorov_12081972@postgrespro.ru", "phone": "+70054078330"}
0005434408654	59A567	7070 806334	VLADIMIR SAVELEV	{"email": "savelev_vladimir-31121964@postgrespro.ru", "phone": "+70967516151"}
0005434408655	1EC14D	3857 802764	SERGEY VLASOV	{"email": "vlasov-s-1973@postgrespro.ru", "phone": "+70278502049"}
0005434408656	4F21E3	5014 558990	IRINA ROMANOVA	{"phone": "+70763562839"}
0005434408657	43F5CA	8711 151899	EKATERINA ORLOVA	{"phone": "+70589796406"}
0005434408658	CD49AE	1626 046217	LYUBOV MATVEEVA	{"email": "l.matveeva-13111966@postgrespro.ru", "phone": "+70794013702"}
0005434408659	3BB2DE	9561 262263	DMITRIY DAVYDOV	{"phone": "+70289144489"}
0005434408660	B705C2	1764 500897	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy_061982@postgrespro.ru", "phone": "+70197719606"}
0005434408661	F67424	0998 006479	EKATERINA KOZLOVA	{"phone": "+70238970911"}
0005434408662	DC5EEF	6728 012239	NADEZHDA SIDOROVA	{"phone": "+70215369170"}
0005434408663	78FCE9	3668 019767	NIKOLAY MOROZOV	{"email": "nikolay.morozov-041973@postgrespro.ru", "phone": "+70412578664"}
0005434408664	78FCE9	5930 043918	ANNA GERASIMOVA	{"phone": "+70619942271"}
0005434408665	D89621	4758 883051	SERGEY GUSEV	{"email": "gusev-s.1965@postgrespro.ru", "phone": "+70033208280"}
0005434408666	46080D	5176 135755	NIKITA IVANOV	{"email": "ivanovn.26081977@postgrespro.ru", "phone": "+70832992699"}
0005434408667	0F9E46	8136 012086	YURIY KUZNECOV	{"phone": "+70019658228"}
0005434408668	0F9E46	6306 790516	NATALIYA GORBUNOVA	{"phone": "+70796943000"}
0005434408669	E82E71	7551 263837	SERGEY PAVLOV	{"email": "pavlov-sergey29111975@postgrespro.ru", "phone": "+70397970320"}
0005434408670	C86F3A	4656 348996	ARTEM KRASNOV	{"email": "krasnov_artem_26061968@postgrespro.ru", "phone": "+70924679692"}
0005434408671	D00C3E	1673 922032	LYUDMILA ZAYCEVA	{"email": "zayceva.lyudmila-1980@postgrespro.ru", "phone": "+70950653958"}
0005434408672	2BA3BE	3148 930836	ALEKSANDR FILIPPOV	{"phone": "+70870805842"}
0005434408673	8FE200	4091 855563	TATYANA OSIPOVA	{"phone": "+70855234855"}
0005434408674	ACAFAD	7886 781593	ALEKSEY VOLKOV	{"phone": "+70638348839"}
0005434408675	ACAFAD	2063 057849	OLESYA ISAEVA	{"phone": "+70294248541"}
0005434408676	B3D9EA	8810 233330	ALEKSANDR FEDOTOV	{"phone": "+70143801789"}
0005434408677	A2B0FA	9043 052387	IVAN KARPOV	{"email": "karpovivan_1974@postgrespro.ru", "phone": "+70260612618"}
0005434408678	A2B0FA	9264 635957	VALENTINA SMIRNOVA	{"email": "v_smirnova-1981@postgrespro.ru", "phone": "+70012201817"}
0005434408679	E7E8D7	8021 857952	YURIY NIKOLAEV	{"phone": "+70013751411"}
0005434408680	5FA3F7	3360 424597	ANDREY FEDOROV	{"phone": "+70679287713"}
0005434408681	5FA3F7	1359 377518	VLADIMIR KRASNOV	{"email": "krasnov.v_27071963@postgrespro.ru", "phone": "+70363187945"}
0005434408682	E6A988	5874 168644	VYACHESLAV SOKOLOV	{"email": "v-sokolov-101971@postgrespro.ru", "phone": "+70199331863"}
0005434408683	57FA65	1597 053780	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_091983@postgrespro.ru", "phone": "+70913049143"}
0005434408684	777A2C	9165 040099	OLEG IVANOV	{"phone": "+70455300249"}
0005434408685	5DC6F5	8724 416521	SERGEY KOZLOV	{"phone": "+70802136492"}
0005434408686	58F01F	1041 607077	ELENA VOROBEVA	{"phone": "+70142990137"}
0005434408687	8D92CA	1838 056166	ANASTASIYA SERGEEVA	{"phone": "+70138525979"}
0005434408688	8D92CA	6386 689535	ELENA DANILOVA	{"phone": "+70537854814"}
0005434408689	EC7CF2	9057 147964	LYUBOV ORLOVA	{"phone": "+70674651895"}
0005434408690	EC7CF2	5000 046822	ELENA MAKSIMOVA	{"phone": "+70150614369"}
0005434408691	34452F	5106 378431	MARIYA NIKOLAEVA	{"email": "nikolaeva-m.081964@postgrespro.ru", "phone": "+70872250347"}
0005434408692	9D87FA	9693 317895	ALEKSANDR ORLOV	{"email": "aorlov_031971@postgrespro.ru", "phone": "+70872272901"}
0005434408693	E0CA20	1505 412437	SVETLANA POPOVA	{"phone": "+70905827642"}
0005434408694	CCFD97	9062 703251	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr_12101972@postgrespro.ru", "phone": "+70139315903"}
0005434408695	C7DE29	2067 237381	VIKTOR SOROKIN	{"phone": "+70315842752"}
0005434408696	93BECF	6438 012701	VLADIMIR ANDREEV	{"email": "andreevvladimir1984@postgrespro.ru", "phone": "+70974625246"}
0005434408697	93BECF	8777 855054	VLADIMIR IVANOV	{"email": "ivanov-vladimir091963@postgrespro.ru", "phone": "+70884847846"}
0005434408698	329433	9443 186966	ANNA POPOVA	{"email": "popova_a_1974@postgrespro.ru", "phone": "+70591724623"}
0005434408699	2A3658	5287 972858	MARIYA KUZNECOVA	{"email": "kuznecova-mariya.1970@postgrespro.ru", "phone": "+70561804674"}
0005434408700	3AA302	2989 394736	ARINA NIKOLAEVA	{"phone": "+70219358362"}
0005434408701	56FB74	3337 328434	NATALYA VOLKOVA	{"email": "volkova_natalya_25101972@postgrespro.ru", "phone": "+70924155342"}
0005434408702	B40667	8400 182645	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr.1975@postgrespro.ru", "phone": "+70363948208"}
0005434408703	B40667	1274 378369	SERGEY EGOROV	{"email": "egorov.s1971@postgrespro.ru", "phone": "+70352046083"}
0005434408704	D7F7F3	8526 272145	ALEKSEY BELOV	{"phone": "+70431060402"}
0005434408705	D7F7F3	4122 853129	YURIY ALEKSEEV	{"phone": "+70915616453"}
0005434408706	641C85	1687 398304	OLEG MIKHAYLOV	{"phone": "+70113632082"}
0005434408707	ADD4E0	2321 097239	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev.101989@postgrespro.ru", "phone": "+70242903218"}
0005434408708	10F779	2659 655250	ANDREY SCHERBAKOV	{"phone": "+70017740227"}
0005434408709	A4E33E	0733 685781	VALENTINA LEBEDEVA	{"email": "lebedeva-v-23041980@postgrespro.ru", "phone": "+70555201903"}
0005434408710	A4E33E	2499 992103	MIKHAIL KUZMIN	{"phone": "+70930304319"}
0005434408711	EEDDC2	3462 346967	NINA ALEKSEEVA	{"phone": "+70136448840"}
0005434408712	EEDDC2	7100 246955	DMITRIY KOZLOV	{"email": "dkozlov-091973@postgrespro.ru", "phone": "+70804931605"}
0005434408713	6DB40A	3446 271870	MIKHAIL GERASIMOV	{"phone": "+70161415786"}
0005434408714	A800F0	1710 356635	VERA SMIRNOVA	{"email": "smirnovavera-031966@postgrespro.ru", "phone": "+70461700080"}
0005434408716	84A506	8430 790390	PETR ALEKSEEV	{"email": "alekseev-petr.13041970@postgrespro.ru", "phone": "+70034140058"}
0005434408717	041B94	2341 605884	EKATERINA ZAKHAROVA	{"email": "zakharova-e_01101965@postgrespro.ru", "phone": "+70367045756"}
0005434408718	041B94	4122 854994	MARIYA ANTONOVA	{"email": "antonovamariya_20101971@postgrespro.ru", "phone": "+70453977420"}
0005434408719	384F68	8001 145832	LYUDMILA LAZAREVA	{"email": "l_lazareva121971@postgrespro.ru", "phone": "+70077813116"}
0005434408720	4B7922	2672 036907	RUMIYA VASILEVA	{"phone": "+70624785124"}
0005434408721	4B7922	3434 245743	MARIYA YAKOVLEVA	{"phone": "+70873037929"}
0005434408722	5D9E95	3190 656298	OLEG MELNIKOV	{"phone": "+70183260748"}
0005434408723	B7DA13	7036 302672	RAISA STEPANOVA	{"phone": "+70964643886"}
0005434408724	B7DA13	4236 989459	DENIS MATVEEV	{"email": "d-matveev111967@postgrespro.ru", "phone": "+70135953952"}
0005434408725	9A6906	8279 860497	ANASTASIYA KOROLEVA	{"email": "akoroleva.08011973@postgrespro.ru", "phone": "+70153864984"}
0005434408726	EA456B	6502 046379	MARIYA ERMAKOVA	{"email": "ermakova_m_1986@postgrespro.ru", "phone": "+70573421670"}
0005434408727	0FFAAB	6471 040218	GERMAN KONOVALOV	{"phone": "+70211871877"}
0005434408728	C603FA	0456 931354	OLEG KUDRYASHOV	{"email": "o.kudryashov-111973@postgrespro.ru", "phone": "+70485022390"}
0005434408729	82A6D9	6604 200362	VERONIKA FEDOROVA	{"email": "veronika_fedorova_1974@postgrespro.ru", "phone": "+70939276492"}
0005434408730	82A6D9	4127 464994	KLARA FOMINA	{"phone": "+70951142027"}
0005434408731	FCD5D5	4934 271633	IGOR ANTONOV	{"email": "antonovi-061959@postgrespro.ru", "phone": "+70644132722"}
0005434408732	FCD5D5	3203 239701	ANDREY FEDOTOV	{"phone": "+70210989196"}
0005434408733	6B7CA3	6810 335416	ARINA STEPANOVA	{"email": "a.stepanova-04031972@postgrespro.ru", "phone": "+70782089408"}
0005434408734	616626	3125 635226	OLGA CHERNOVA	{"email": "o.chernova.08061978@postgrespro.ru", "phone": "+70962462813"}
0005434408735	08FE47	6001 629800	TAMARA GUSEVA	{"email": "tamara-guseva_121969@postgrespro.ru", "phone": "+70940585380"}
0005434408736	F6F853	4488 208721	NATALYA BARANOVA	{"email": "natalya.baranova-1966@postgrespro.ru", "phone": "+70897605004"}
0005434408737	151C47	5884 519898	DMITRIY ZAYCEV	{"phone": "+70915657060"}
0005434408738	151C47	7730 270687	VITALIY IVANOV	{"email": "vivanov.021956@postgrespro.ru", "phone": "+70065603557"}
0005434408739	0999BD	1212 994183	NADEZHDA TARASOVA	{"email": "tarasova_n.111976@postgrespro.ru", "phone": "+70469517991"}
0005434408740	FC490E	5992 664321	VLADIMIR SOLOVEV	{"email": "vsolovev-1968@postgrespro.ru", "phone": "+70898163755"}
0005434408741	49D790	4737 181590	NATALYA DAVYDOVA	{"email": "davydova_n-101972@postgrespro.ru", "phone": "+70319256244"}
0005434408742	49D790	0953 262124	MARINA KRASNOVA	{"phone": "+70179365000"}
0005434408743	30BE39	5249 369573	NIKOLAY VOLKOV	{"email": "volkovnikolay.021959@postgrespro.ru", "phone": "+70890065194"}
0005434408744	2DEAA8	1937 491729	NIKOLAY MAKAROV	{"email": "makarovnikolay_081969@postgrespro.ru", "phone": "+70060402854"}
0005434408745	2DEAA8	4906 546218	ANASTASIYA DAVYDOVA	{"email": "anastasiya.davydova-091975@postgrespro.ru", "phone": "+70023110488"}
0005434408746	689E94	0983 668314	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov.28071971@postgrespro.ru", "phone": "+70470052921"}
0005434408747	B16114	8292 273956	VALENTINA EGOROVA	{"email": "valentinaegorova_071976@postgrespro.ru", "phone": "+70755386776"}
0005434408748	73D4FB	4816 369808	KONSTANTIN KUZMIN	{"phone": "+70442284098"}
0005434408749	AFC943	0990 576212	MARIYA KISELEVA	{"phone": "+70746467962"}
0005434408750	086F20	8019 010337	YURIY MAKSIMOV	{"email": "maksimovyuriy.01121980@postgrespro.ru", "phone": "+70367020843"}
0005434408751	652531	9257 746913	ANTONINA SAVELEVA	{"email": "saveleva-a-1959@postgrespro.ru", "phone": "+70376807870"}
0005434408752	4CF424	0188 648043	ALEKSEY NAUMOV	{"phone": "+70665028967"}
0005434408753	B86B10	5825 856656	YURIY SCHERBAKOV	{"phone": "+70605089671"}
0005434408754	B86B10	8289 838321	OLGA IVANOVA	{"phone": "+70834292219"}
0005434408755	5FDE6C	4483 066148	TAMARA KUZNECOVA	{"email": "tamara.kuznecova_111975@postgrespro.ru", "phone": "+70049456144"}
0005434408756	5FDE6C	1527 875151	VITALIY POPOV	{"email": "popov-v081983@postgrespro.ru", "phone": "+70461655726"}
0005434408757	A36ECC	0023 094675	VLADIMIR KUZNECOV	{"email": "kuznecov-v-051973@postgrespro.ru", "phone": "+70501894248"}
0005434408758	A36ECC	0337 768302	MAKSIM KOROLEV	{"phone": "+70745103765"}
0005434408759	4C38AA	9587 443427	VYACHESLAV KARPOV	{"email": "v.karpov1974@postgrespro.ru", "phone": "+70880929426"}
0005434408760	BDC8D9	4972 173487	VADIM BELOV	{"phone": "+70406376837"}
0005434408761	1A439E	4218 225939	EVGENIY BELOV	{"phone": "+70786340261"}
0005434408762	CBEA73	9423 768270	ANTONINA MOISEEVA	{"email": "a_moiseeva.03081971@postgrespro.ru", "phone": "+70438564963"}
0005434408763	B32857	6519 481213	VALENTINA ALEKSANDROVA	{"phone": "+70589744370"}
0005434408764	B32857	6600 108972	ANNA MIRONOVA	{"email": "annamironova1972@postgrespro.ru", "phone": "+70618537628"}
0005434408765	6D9D00	1236 856882	VIKTOR DMITRIEV	{"email": "dmitriev_v.30061970@postgrespro.ru", "phone": "+70598228887"}
0005434408766	3C1939	4896 082593	GALINA KONOVALOVA	{"email": "konovalova-g_1960@postgrespro.ru", "phone": "+70013042657"}
0005434408767	3C1939	1703 295282	EVGENIY KARPOV	{"email": "karpov.e_1975@postgrespro.ru", "phone": "+70789618493"}
0005434408768	BB9AF1	4554 184454	TATYANA KAZAKOVA	{"email": "kazakova.tatyana-01091970@postgrespro.ru", "phone": "+70171295303"}
0005434408769	764B4A	2630 328231	RAISA GERASIMOVA	{"phone": "+70159810219"}
0005434408770	B7155B	5870 370598	LILIYA SERGEEVA	{"email": "sergeeva-l-12101972@postgrespro.ru", "phone": "+70277744263"}
0005434408771	82B4DC	3683 340002	NINA BOGDANOVA	{"email": "n.bogdanova_27081980@postgrespro.ru", "phone": "+70035356794"}
0005434408772	172C10	8446 748095	LYUBOV VOROBEVA	{"phone": "+70012060441"}
0005434408773	3AFAD0	9808 386391	ANZHELIKA FEDOROVA	{"phone": "+70787408922"}
0005434408775	DBCBBC	3861 818660	VALENTINA ORLOVA	{"phone": "+70418173698"}
0005434408776	DBCBBC	4316 879973	TAMARA YUDINA	{"email": "tamara-yudina1979@postgrespro.ru", "phone": "+70112617643"}
0005434408777	06CA56	0725 290586	SERGEY KUZNECOV	{"email": "s_kuznecov_021979@postgrespro.ru", "phone": "+70998205480"}
0005434408778	706C46	9473 262300	BORIS KUZMIN	{"phone": "+70832166124"}
0005434408779	706C46	7449 287193	MARINA POPOVA	{"phone": "+70338759570"}
0005434408780	706C46	4842 385837	KRISTINA FROLOVA	{"phone": "+70865357166"}
0005434408781	AA2BB1	2641 671036	MARIYA TROFIMOVA	{"email": "trofimovamariya-071970@postgrespro.ru", "phone": "+70575218663"}
0005434408782	8B1322	3237 784574	VADIM IVANOV	{"email": "vadim_ivanov_1981@postgrespro.ru", "phone": "+70626917976"}
0005434408783	8B1322	8797 659220	OLGA BELOVA	{"email": "belova.o_25011984@postgrespro.ru", "phone": "+70773087398"}
0005434408784	8B1322	4336 510189	OLEG PETROV	{"email": "opetrov1969@postgrespro.ru", "phone": "+70477112712"}
0005434408785	C058E0	5503 803061	VALERIYA SOLOVEVA	{"phone": "+70928922981"}
0005434408786	9BAE4F	7241 846368	STEPAN PETROV	{"phone": "+70015647140"}
0005434408787	1D1B8B	5481 282220	TIMUR ZAKHAROV	{"phone": "+70959140163"}
0005434408788	1D1B8B	1767 947644	OLGA MEDVEDEVA	{"phone": "+70397816612"}
0005434408789	F6F1D9	8093 548383	ALEKSEY VOROBEV	{"phone": "+70827147433"}
0005434408790	F6F1D9	1378 266780	OLEG AFANASEV	{"email": "oleg_afanasev.07101972@postgrespro.ru", "phone": "+70712907676"}
0005434408791	4B284C	6003 903961	RAISA KAZAKOVA	{"email": "r-kazakova051974@postgrespro.ru", "phone": "+70959300668"}
0005434408792	75A95B	9946 807657	NATALYA BORISOVA	{"email": "natalyaborisova.071981@postgrespro.ru", "phone": "+70665080266"}
0005434408793	349C23	4652 264018	EKATERINA BELOVA	{"phone": "+70664378033"}
0005434408794	349C23	1334 792460	NADEZHDA ANDREEVA	{"email": "n-andreeva-071971@postgrespro.ru", "phone": "+70343419820"}
0005434408795	7991B0	0412 027271	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov-10011973@postgrespro.ru", "phone": "+70770271218"}
0005434408796	D42C17	9150 960724	LYUBOV CHERNOVA	{"email": "l_chernova.22091971@postgrespro.ru", "phone": "+70827013333"}
0005434408797	A4FEB9	0510 778805	ANTONINA KONDRATEVA	{"phone": "+70739910171"}
0005434408798	A4FEB9	5324 728201	VIKTOR DMITRIEV	{"phone": "+70667840644"}
0005434408799	BAE4B5	7525 944306	OLEG SCHERBAKOV	{"email": "scherbakov_o_20021972@postgrespro.ru", "phone": "+70312899824"}
0005434408800	BAE4B5	9828 242442	VALENTINA DAVYDOVA	{"email": "davydovav-11011969@postgrespro.ru", "phone": "+70844495697"}
0005434408801	B6AE62	3698 720363	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov-041973@postgrespro.ru", "phone": "+70962278863"}
0005434408802	7D88EB	4360 642509	OLGA LAZAREVA	{"email": "lazarevaolga-011975@postgrespro.ru", "phone": "+70528430709"}
0005434408803	7D88EB	6805 195701	OLEG IVANOV	{"phone": "+70027115450"}
0005434408804	F1EA85	5476 632063	SVETLANA BARANOVA	{"phone": "+70550791166"}
0005434408805	F1EA85	4797 169779	ANATOLIY TARASOV	{"email": "anatoliytarasov.041963@postgrespro.ru", "phone": "+70289081953"}
0005434408806	053C69	0686 726066	OLGA KISELEVA	{"phone": "+70520345878"}
0005434408807	8C963F	1922 183622	TAISIYA TITOVA	{"phone": "+70388694545"}
0005434408808	8C963F	6065 851587	ELVIRA MIKHAYLOVA	{"phone": "+70335324420"}
0005434408809	ED91C0	9297 512236	NATALYA MAKAROVA	{"email": "n-makarova051968@postgrespro.ru", "phone": "+70443066019"}
0005434408810	8CAC03	6870 020082	RAMIL MEDVEDEV	{"email": "r-medvedev.1963@postgrespro.ru", "phone": "+70413884294"}
0005434408811	1FAE98	3449 041353	KONSTANTIN KUZMIN	{"phone": "+70736570575"}
0005434408812	0E4385	9705 584353	ALEKSEY PETROV	{"email": "a.petrov-1973@postgrespro.ru", "phone": "+70815870343"}
0005434408813	0E4385	3657 731533	ANDREY SAVELEV	{"phone": "+70027886260"}
0005434408814	31D163	1964 746873	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov25021967@postgrespro.ru", "phone": "+70874905818"}
0005434408815	68F910	2854 311515	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov-071972@postgrespro.ru", "phone": "+70115362698"}
0005434408816	8A5C9D	5713 445500	ZOYA NIKIFOROVA	{"email": "zoya_nikiforova1972@postgrespro.ru", "phone": "+70162219721"}
0005434408817	8A5C9D	6107 735028	SOFIYA DMITRIEVA	{"phone": "+70676739795"}
0005434408818	45ABA3	4753 537055	MARGARITA FOMINA	{"email": "margarita.fomina-13011986@postgrespro.ru", "phone": "+70085546674"}
0005434408819	0165B7	8499 294136	DMITRIY STEPANOV	{"email": "d_stepanov1978@postgrespro.ru", "phone": "+70185630870"}
0005434408820	0165B7	0897 620249	SERGEY ALEKSEEV	{"phone": "+70149386565"}
0005434408821	1E014E	4311 977597	GALINA LEBEDEVA	{"phone": "+70310415559"}
0005434408822	1E014E	4272 154054	ELENA FILIPPOVA	{"email": "efilippova.041970@postgrespro.ru", "phone": "+70852525008"}
0005434408823	0DC7A9	8313 377569	ARTEM MOROZOV	{"email": "morozov_artem-071972@postgrespro.ru", "phone": "+70209839241"}
0005434408824	0DC7A9	7449 715622	EVGENIY SOKOLOV	{"email": "sokolove-061972@postgrespro.ru", "phone": "+70284028599"}
0005434408825	63603D	9046 397079	ILGIZ KUZNECOV	{"email": "ilgizkuznecov1988@postgrespro.ru", "phone": "+70562166316"}
0005434408826	63603D	4405 712253	NATALYA NIKIFOROVA	{"email": "natalyanikiforova1980@postgrespro.ru", "phone": "+70960785151"}
0005434408827	EA48EE	2560 595409	VLADIMIR MAKAROV	{"email": "vmakarov041965@postgrespro.ru", "phone": "+70006876954"}
0005434408828	A60EEA	7672 503178	ALEKSANDR SCHERBAKOV	{"phone": "+70703417234"}
0005434408829	DE8BC5	8678 386309	ANDREY ROMANOV	{"phone": "+70604465257"}
0005434408830	CE9FB9	8655 495720	ALEKSANDR IVANOV	{"phone": "+70126798878"}
0005434408831	19E681	6021 202748	MARINA ALEKSANDROVA	{"email": "m.aleksandrova-14041972@postgrespro.ru", "phone": "+70430454510"}
0005434408832	6F4B50	1459 786863	KIRILL SEMENOV	{"email": "k_semenov091977@postgrespro.ru", "phone": "+70868646045"}
0005434408833	6F4B50	8390 630768	ALEFTINA FEDOROVA	{"email": "a_fedorova_111985@postgrespro.ru", "phone": "+70086260233"}
0005434408890	DEC2E9	9596 184455	SVETLANA PAVLOVA	{"phone": "+70461567374"}
0005434408834	6F4B50	9383 445671	YURIY MEDVEDEV	{"email": "yuriymedvedev-25111974@postgrespro.ru", "phone": "+70596142411"}
0005434408835	86B6C4	6640 469508	YURIY SOLOVEV	{"email": "y_solovev.051967@postgrespro.ru", "phone": "+70635566090"}
0005434408836	2AE143	3615 931464	SERGEY NIKOLAEV	{"email": "nikolaev-s.1974@postgrespro.ru", "phone": "+70994408568"}
0005434408837	B4A21A	7469 498410	GRIGORIY GUSEV	{"phone": "+70317451240"}
0005434408838	77D70B	0593 404440	OLGA MALYSHEVA	{"email": "o.malysheva30081974@postgrespro.ru", "phone": "+70965719753"}
0005434408839	87E49D	4749 724186	ALEKSANDR ANDREEV	{"email": "aleksandrandreev.1974@postgrespro.ru", "phone": "+70226673333"}
0005434408840	87E49D	4807 515809	ANDREY SOKOLOV	{"email": "sokolov-andrey_031974@postgrespro.ru", "phone": "+70225196527"}
0005434408841	B57186	4782 123294	VIKTOR PAVLOV	{"phone": "+70647390578"}
0005434408842	90235F	0580 876389	LIDIYA NOVIKOVA	{"phone": "+70053257448"}
0005434408843	801F7F	2834 427586	ELINA ALEKSEEVA	{"phone": "+70982783698"}
0005434408844	84D4F3	2784 503951	IRINA BELOVA	{"email": "belovai-26041969@postgrespro.ru", "phone": "+70023220034"}
0005434408845	84D4F3	9744 606793	YULIYA VASILEVA	{"email": "vasileva.y_1974@postgrespro.ru", "phone": "+70179418718"}
0005434408846	735C26	6238 867740	NATALYA GERASIMOVA	{"email": "n_gerasimova10061970@postgrespro.ru", "phone": "+70588153534"}
0005434408847	970CEA	4491 394951	KONSTANTIN SOROKIN	{"email": "ksorokin_081976@postgrespro.ru", "phone": "+70423217090"}
0005434408848	F4F4D4	8486 415425	MARIYA KALININA	{"phone": "+70791875655"}
0005434408849	F4F4D4	1427 882906	ANTONINA IVANOVA	{"phone": "+70377622815"}
0005434408850	50E4ED	4205 425603	ANATOLIY NIKOLAEV	{"email": "nikolaev_a-1968@postgrespro.ru", "phone": "+70569176484"}
0005434408851	AE4273	8272 869012	LIDIYA KUZMINA	{"phone": "+70609719762"}
0005434408852	AE4273	4596 709775	ALEKSANDR ZHURAVLEV	{"phone": "+70134308476"}
0005434408853	CC5B29	6148 271893	DMITRIY MOROZOV	{"email": "dmitriy.morozov31051982@postgrespro.ru", "phone": "+70202960473"}
0005434408854	04E73C	8706 291798	ALEKSANDR POPOV	{"email": "popovaleksandr.22111968@postgrespro.ru", "phone": "+70169394077"}
0005434408855	C900E3	3462 884259	VLADIMIR KARPOV	{"phone": "+70893695820"}
0005434408856	08FF58	7577 105386	SVETLANA NIKITINA	{"phone": "+70185040821"}
0005434408857	913120	3128 286312	ANNA MELNIKOVA	{"email": "amelnikova-1968@postgrespro.ru", "phone": "+70508341707"}
0005434408858	913120	8179 746410	PETR BONDARENKO	{"email": "p.bondarenko021970@postgrespro.ru", "phone": "+70062921041"}
0005434408859	6396DF	0410 492596	IVAN NIKOLAEV	{"phone": "+70537272167"}
0005434408860	6396DF	1018 583178	GALINA KUZNECOVA	{"phone": "+70462803232"}
0005434408861	093A3A	5393 766478	OLGA FROLOVA	{"phone": "+70604549731"}
0005434408862	093A3A	4911 452330	EVGENIY IVANOV	{"phone": "+70445849274"}
0005434408863	093A3A	0789 590435	ANATOLIY SOKOLOV	{"email": "sokolov-anatoliy.01071978@postgrespro.ru", "phone": "+70244931306"}
0005434408864	13EBC1	0754 517121	ANNA BELOVA	{"phone": "+70512438802"}
0005434408865	13EBC1	8477 431862	GALINA NIKOLAEVA	{"email": "nikolaeva-galina25091968@postgrespro.ru", "phone": "+70470743815"}
0005434408866	28C531	8483 289429	DMITRIY RODIONOV	{"email": "dmitriy-rodionov-071961@postgrespro.ru", "phone": "+70238186181"}
0005434408867	28C531	8180 999384	NADEZHDA MOROZOVA	{"phone": "+70158944497"}
0005434408868	E390AC	6679 211698	ARTEM SEMENOV	{"email": "a_semenov081976@postgrespro.ru", "phone": "+70260883627"}
0005434408869	E390AC	5732 203938	MIKHAIL BELOV	{"phone": "+70877137301"}
0005434408870	8FD001	6978 356574	ALINA KOROLEVA	{"email": "korolevaalina-13061985@postgrespro.ru", "phone": "+70354187313"}
0005434408871	8FD001	5292 561158	TATYANA NAZAROVA	{"email": "tatyananazarova031971@postgrespro.ru", "phone": "+70018065033"}
0005434408872	5E1DB8	8387 091926	LYUBOV DAVYDOVA	{"email": "davydova-lyubov_051975@postgrespro.ru", "phone": "+70430440817"}
0005434408873	EF4E7D	1430 287914	ALBINA ZAYCEVA	{"phone": "+70045999904"}
0005434408874	EF4E7D	4622 035668	VIKTORIYA FOMINA	{"email": "v_fomina.041972@postgrespro.ru", "phone": "+70022016448"}
0005434408875	72864B	0945 922671	VALENTINA NAZAROVA	{"email": "v-nazarova_31031964@postgrespro.ru", "phone": "+70682814841"}
0005434408876	72864B	8063 300126	ALEKSEY NIKITIN	{"phone": "+70837093751"}
0005434408877	85E28A	2682 169537	TATYANA ERMAKOVA	{"email": "ermakovat-1975@postgrespro.ru", "phone": "+70760453733"}
0005434408878	6DDAF7	7812 499944	VALERIY TARASOV	{"phone": "+70999081495"}
0005434408879	288957	8824 259676	EVGENIYA FEDOROVA	{"phone": "+70045464115"}
0005434408880	F81049	0524 385860	VLADISLAV SAVELEV	{"email": "savelev.v011973@postgrespro.ru", "phone": "+70329750128"}
0005434408881	B3040D	4103 977220	MARIYA OVCHINNIKOVA	{"phone": "+70679879155"}
0005434408882	B3040D	0780 994291	IGOR SEMENOV	{"email": "igor-semenov111987@postgrespro.ru", "phone": "+70015134948"}
0005434408883	8AB45B	1929 704683	ANNA YAKOVLEVA	{"phone": "+70716125940"}
0005434408884	8AB45B	8620 308879	OLGA ZAKHAROVA	{"email": "o-zakharova-1974@postgrespro.ru", "phone": "+70795874662"}
0005434408885	226A47	8423 389746	OLGA FILATOVA	{"email": "olga-filatova26021985@postgrespro.ru", "phone": "+70773540283"}
0005434408886	02F54F	4613 190409	YULIYA VASILEVA	{"phone": "+70321891161"}
0005434408887	75DD5E	7742 879533	DARYA ANDREEVA	{"email": "d.andreeva-03081971@postgrespro.ru", "phone": "+70646526147"}
0005434408888	75DD5E	7645 428569	MARGARITA FROLOVA	{"email": "margaritafrolova.041964@postgrespro.ru", "phone": "+70940188301"}
0005434408889	6A6EA3	1356 531778	YURIY CHERNOV	{"phone": "+70751149941"}
0005434408891	EF7866	0923 913890	PAVEL IVANOV	{"phone": "+70682325566"}
0005434408892	3481C5	1557 947596	NIKOLAY ZAYCEV	{"phone": "+70516744251"}
0005434408893	E25066	7691 279660	NINA ZAYCEVA	{"email": "zayceva.nina23061967@postgrespro.ru", "phone": "+70184340721"}
0005434408894	63AD9C	3037 536416	ELENA PETROVA	{"phone": "+70554534886"}
0005434408895	63AD9C	1214 156736	ALEKSANDR IVANOV	{"phone": "+70136127697"}
0005434408896	63AD9C	4242 737350	YURIY FEDOROV	{"email": "y-fedorov-091970@postgrespro.ru", "phone": "+70931935628"}
0005434408897	B64066	9839 816844	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.1971@postgrespro.ru", "phone": "+70005389859"}
0005434408898	611B9D	4804 484497	VALENTINA VLASOVA	{"phone": "+70066860955"}
0005434408899	A0E02D	2399 254826	YURIY VASILEV	{"phone": "+70378709701"}
0005434408900	A0E02D	0309 787474	NATALIYA EFIMOVA	{"phone": "+70641394297"}
0005434408901	128A59	4568 823756	MARIYA VOLKOVA	{"email": "m.volkova.1973@postgrespro.ru", "phone": "+70346420307"}
0005434408902	433AC2	5401 815868	SVETLANA VOROBEVA	{"email": "vorobevas-1970@postgrespro.ru", "phone": "+70738328378"}
0005434408903	433AC2	1477 335278	TIMUR ILIN	{"phone": "+70205100542"}
0005434408904	433AC2	6498 915416	LARISA MAKSIMOVA	{"email": "maksimova-larisa-031973@postgrespro.ru", "phone": "+70443730668"}
0005434408905	EABA15	0022 483206	VERA KUZNECOVA	{"email": "v_kuznecova061966@postgrespro.ru", "phone": "+70158649348"}
0005434408906	74CBE8	4898 275167	VYACHESLAV ROMANOV	{"email": "vromanov-091962@postgrespro.ru", "phone": "+70189591883"}
0005434408907	7FE8F7	6431 157031	ANTONINA GRISHINA	{"email": "grishina-a011978@postgrespro.ru", "phone": "+70082217429"}
0005434408908	D55698	1224 700770	OLEG VASILEV	{"email": "vasilev.oleg.1961@postgrespro.ru", "phone": "+70708313882"}
0005434408909	25155B	9576 373026	DARYA SEMENOVA	{"phone": "+70638950524"}
0005434408910	931A09	1184 538046	TATYANA VOLKOVA	{"email": "volkovat-1971@postgrespro.ru", "phone": "+70697102266"}
0005434408911	374583	7165 526383	YURIY IVANOV	{"phone": "+70105703026"}
0005434408912	374583	5481 911965	YURIY ALEKSEEV	{"email": "yuriy.alekseev.08041973@postgrespro.ru", "phone": "+70889985674"}
0005434408913	B1FCB7	8153 696802	NIKITA KULIKOV	{"email": "nikita.kulikov-1979@postgrespro.ru", "phone": "+70785936672"}
0005434408914	179DCF	9801 482695	LEV KARPOV	{"phone": "+70525841846"}
0005434408915	37D3AB	4487 061165	VALENTINA SOLOVEVA	{"email": "soloveva_valentina1971@postgrespro.ru", "phone": "+70745250254"}
0005434408916	C86D09	4030 794065	POLINA DANILOVA	{"phone": "+70276432532"}
0005434408917	C86D09	9523 525496	NINA SEMENOVA	{"phone": "+70170343520"}
0005434408918	EBA0E4	2093 600679	GALINA ABRAMOVA	{"phone": "+70596857897"}
0005434408919	EBA0E4	1877 881953	VLADIMIR DMITRIEV	{"phone": "+70201812063"}
0005434408920	7EE4A4	8436 896300	VERA GAVRILOVA	{"phone": "+70132546727"}
0005434408921	F48C7B	3736 578611	NADEZHDA VOLKOVA	{"phone": "+70776574298"}
0005434408922	AA7A25	0949 262324	MAKSIM POPOV	{"email": "popov.m111968@postgrespro.ru", "phone": "+70075495455"}
0005434408923	2D0FB6	0651 864815	VALENTINA MAKAROVA	{"email": "makarova.valentina_16061968@postgrespro.ru", "phone": "+70778540017"}
0005434408924	21A5E3	8956 366096	RAISA SAVELEVA	{"phone": "+70272729263"}
0005434408925	21A5E3	9541 692515	ELENA KUZNECOVA	{"email": "kuznecova-e_091972@postgrespro.ru", "phone": "+70367991095"}
0005434408926	3107D7	9540 551946	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay.071965@postgrespro.ru", "phone": "+70191709033"}
0005434408927	974B36	2260 221578	EKATERINA GORBUNOVA	{"phone": "+70268482377"}
0005434408928	974B36	7097 307787	NATALIYA IVANOVA	{"email": "ivanova.n.15011972@postgrespro.ru", "phone": "+70338495927"}
0005434408929	68303A	6375 369227	ALEKSEY BONDARENKO	{"email": "alekseybondarenko_1970@postgrespro.ru", "phone": "+70068628062"}
0005434408930	68303A	0595 596029	ALEKSEY KISELEV	{"phone": "+70880710096"}
0005434408931	06EFB5	7983 812833	ARTEM PETROV	{"phone": "+70932796902"}
0005434408932	16D83B	0895 959695	SERGEY KAZAKOV	{"phone": "+70907434628"}
0005434408933	CB84CF	7918 406154	ALEKSANDR GRIGOREV	{"phone": "+70142753645"}
0005434408934	CB84CF	1009 547416	ELENA ISAEVA	{"email": "elena-isaeva_03011973@postgrespro.ru", "phone": "+70997841935"}
0005434408935	9E849A	2181 425749	MIKHAIL YAKOVLEV	{"email": "yakovlevm28041975@postgrespro.ru", "phone": "+70017164774"}
0005434408936	9E849A	1988 501935	NIKOLAY KUZNECOV	{"email": "n_kuznecov_1974@postgrespro.ru", "phone": "+70336867708"}
0005434408937	9E849A	2494 438860	YURIY ZAYCEV	{"phone": "+70224847786"}
0005434408938	3E2A26	6110 996147	ANASTASIYA KUZNECOVA	{"phone": "+70062092678"}
0005434408939	3E2A26	5706 217635	ELENA KONDRATEVA	{"phone": "+70621690634"}
0005434408940	FB1E99	6714 620608	RAISA ZHURAVLEVA	{"phone": "+70714447819"}
0005434408941	4C9CF1	8688 222790	DMITRIY BORISOV	{"email": "dmitriy-borisov03101983@postgrespro.ru", "phone": "+70616643483"}
0005434408942	A3BE0B	3185 577839	MIKHAIL KRASNOV	{"phone": "+70351118898"}
0005434408943	B60881	1510 973791	GENNADIY POPOV	{"email": "gpopov_14081968@postgrespro.ru", "phone": "+70315793975"}
0005434408944	CCA2E3	6545 344706	LYUBOV MELNIKOVA	{"email": "melnikova-lyubov.07031972@postgrespro.ru", "phone": "+70752354060"}
0005434408945	E72E0E	6326 622532	SERGEY SCHERBAKOV	{"phone": "+70471752811"}
0005434408946	997871	2097 871772	NIKOLAY ZHUKOV	{"email": "nikolayzhukov-16011972@postgrespro.ru", "phone": "+70541503906"}
0005434409393	BC9C2D	1182 822770	SVETLANA ZAYCEVA	{"phone": "+70193681985"}
0005434408947	ED0803	5012 504094	VITALIY SMIRNOV	{"email": "smirnov_vitaliy_011963@postgrespro.ru", "phone": "+70943279828"}
0005434408948	159D77	7958 353551	OKSANA MIKHAYLOVA	{"phone": "+70147857873"}
0005434408949	A710EF	9496 916397	PELAGEYA MELNIKOVA	{"email": "melnikova-pelageya.1981@postgrespro.ru", "phone": "+70254723307"}
0005434408950	EC50F7	8593 966649	LYUDMILA PAVLOVA	{"phone": "+70930760216"}
0005434408951	EC50F7	5929 043937	VERA DMITRIEVA	{"phone": "+70766034099"}
0005434408952	8ED142	0682 841441	ZOYA MOISEEVA	{"phone": "+70817215114"}
0005434408953	8ED142	6934 241800	VLADIMIR FEDOROV	{"phone": "+70387023800"}
0005434408954	6C4ADC	9233 299189	OKSANA MAKAROVA	{"phone": "+70658364837"}
0005434408955	6C4ADC	9264 128406	NATALYA ANTONOVA	{"email": "natalya-antonova101965@postgrespro.ru", "phone": "+70076539183"}
0005434408956	6CD0C9	0879 448200	LYUDMILA ZAKHAROVA	{"phone": "+70565911289"}
0005434408957	215210	0177 198233	ALEKSANDR MIKHAYLOV	{"phone": "+70960019324"}
0005434408958	215210	1510 195233	NADEZHDA TIKHONOVA	{"email": "tikhonova_nadezhda-031977@postgrespro.ru", "phone": "+70631343533"}
0005434408959	31DA7C	4304 910274	ANNA MASLOVA	{"email": "maslova.anna.081971@postgrespro.ru", "phone": "+70364519378"}
0005434408960	211612	1271 902790	IRINA IVANOVA	{"email": "ivanova_irina.011970@postgrespro.ru", "phone": "+70752857491"}
0005434408961	211612	6713 634922	KRISTINA DANILOVA	{"email": "danilova_kristina-1971@postgrespro.ru", "phone": "+70205066495"}
0005434408962	211612	5132 364192	SVETLANA KARPOVA	{"phone": "+70234558851"}
0005434408963	66C16A	7368 121601	TATYANA BELOVA	{"email": "belovatatyana-18051978@postgrespro.ru", "phone": "+70611854580"}
0005434408964	57AE12	1998 344583	ELENA KUZNECOVA	{"email": "kuznecova_e.031985@postgrespro.ru", "phone": "+70881040892"}
0005434408965	E5B154	0111 211070	ANDREY ZAKHAROV	{"email": "a_zakharov_04021969@postgrespro.ru", "phone": "+70471719209"}
0005434408966	6BD54A	0363 490792	OLGA POPOVA	{"phone": "+70297320159"}
0005434408967	D581BE	5002 276677	VASILIY STEPANOV	{"email": "vasiliystepanov-1976@postgrespro.ru", "phone": "+70333447505"}
0005434408968	C90C0C	0215 482234	ILYA IVANOV	{"email": "ivanov-i_031972@postgrespro.ru", "phone": "+70158580110"}
0005434408969	C90C0C	2541 459506	VERA PETROVA	{"phone": "+70956246897"}
0005434408970	9A959C	7958 293568	GALINA SOROKINA	{"phone": "+70321589875"}
0005434408971	9A959C	2592 832507	MAKSIM ABRAMOV	{"phone": "+70567885459"}
0005434408972	D16667	5701 114350	SERGEY ZHUKOV	{"email": "zhukov-sergey.091963@postgrespro.ru", "phone": "+70210667943"}
0005434408973	CC16F8	4145 648305	SERGEY RODIONOV	{"phone": "+70854985139"}
0005434408974	CC16F8	2006 529043	ALEKSANDR MOISEEV	{"email": "amoiseev30121978@postgrespro.ru", "phone": "+70948461802"}
0005434408975	074C63	5209 543470	ANATOLIY VOLKOV	{"phone": "+70004491923"}
0005434408976	074C63	2615 288323	BOGDAN MOISEEV	{"phone": "+70647184783"}
0005434408977	074C63	5001 892037	VIKTOR SEMENOV	{"email": "semenov.v_13111980@postgrespro.ru", "phone": "+70168228846"}
0005434408978	F5FE36	9230 776107	VLADISLAV ZAYCEV	{"phone": "+70987976045"}
0005434408979	F5FE36	0517 697687	GENNADIY ALEKSEEV	{"email": "alekseev_g_061967@postgrespro.ru", "phone": "+70937198789"}
0005434408980	379178	5330 151484	ANNA SIDOROVA	{"phone": "+70350437188"}
0005434408981	356EF6	7558 079078	VALENTINA BORISOVA	{"phone": "+70384671448"}
0005434408982	311C21	3651 609728	VIKTORIYA EGOROVA	{"email": "viktoriyaegorova.19021967@postgrespro.ru", "phone": "+70757296969"}
0005434408983	D974FC	6778 694967	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey121972@postgrespro.ru", "phone": "+70991743777"}
0005434408984	F0A1C3	9902 926701	VALENTINA KONOVALOVA	{"email": "konovalova_v_08041979@postgrespro.ru", "phone": "+70021081264"}
0005434408985	B17E42	7475 772628	VLADIMIR NIKITIN	{"email": "nikitin-v.1972@postgrespro.ru", "phone": "+70323052355"}
0005434408986	F58B6A	6093 237283	SOFYA ROMANOVA	{"phone": "+70392785756"}
0005434408987	BB5A13	4043 398548	TIMUR BORISOV	{"email": "borisov_t-041968@postgrespro.ru", "phone": "+70796809938"}
0005434408988	C04901	0306 492655	ANNA KUZNECOVA	{"phone": "+70797713061"}
0005434408989	C04901	5743 139290	EVGENIYA YAKOVLEVA	{"email": "evgeniya-yakovleva-1976@postgrespro.ru", "phone": "+70480576064"}
0005434408990	C04901	4369 500895	VLADIMIR BORISOV	{"phone": "+70400582523"}
0005434408991	2134FE	8949 925973	ANASTASIYA KOZLOVA	{"email": "a_kozlova22071977@postgrespro.ru", "phone": "+70527157971"}
0005434408992	2134FE	5367 249545	EVDOKIYA ANTONOVA	{"email": "e.antonova1967@postgrespro.ru", "phone": "+70344637156"}
0005434408993	BD68B9	1349 143163	DARYA KAZAKOVA	{"email": "kazakovad091972@postgrespro.ru", "phone": "+70247705279"}
0005434408994	BD68B9	3459 593344	VYACHESLAV ORLOV	{"phone": "+70338325995"}
0005434408995	C11F6B	8583 820181	NIKOLAY NIKITIN	{"email": "nikolay.nikitin-081972@postgrespro.ru", "phone": "+70041008566"}
0005434408996	9BAF39	2951 029122	YAKOV KUZNECOV	{"phone": "+70191262702"}
0005434408997	9D45BD	4121 237283	NATALYA FROLOVA	{"phone": "+70625945581"}
0005434408998	72644D	6569 604617	VALENTINA AKIMOVA	{"email": "akimovav-081966@postgrespro.ru", "phone": "+70980218333"}
0005434408999	C77FD7	9525 985230	GALINA MAKAROVA	{"email": "makarovagalina_05021964@postgrespro.ru", "phone": "+70515111037"}
0005434409000	B5CDE0	3788 699278	SAMVEL KAZAKOV	{"email": "samvel.kazakov-011978@postgrespro.ru", "phone": "+70049893688"}
0005434409001	B5CDE0	5034 834910	MIKHAIL IVANOV	{"email": "ivanov-m.1979@postgrespro.ru", "phone": "+70889470199"}
0005434409002	84BB7A	6698 674600	OLGA NOVIKOVA	{"phone": "+70543224243"}
0005434409003	902B6B	3437 901187	STANISLAV ALEKSEEV	{"email": "alekseev_stanislav-14061972@postgrespro.ru", "phone": "+70380288812"}
0005434409004	34F4F1	6580 898312	SVETLANA NIKOLAEVA	{"email": "snikolaeva_121971@postgrespro.ru", "phone": "+70277702305"}
0005434409005	34F4F1	4888 544715	VLADISLAV MIKHAYLOV	{"email": "vladislav.mikhaylov_08011972@postgrespro.ru", "phone": "+70975184212"}
0005434409006	175256	8918 789309	TAMARA PETROVA	{"email": "tamara.petrova-1982@postgrespro.ru", "phone": "+70225944772"}
0005434409007	616F31	8918 299904	VIOLETTA SAVELEVA	{"phone": "+70725211643"}
0005434409008	7E8798	8666 637673	ANTONINA ALEKSEEVA	{"email": "antonina-alekseeva.081978@postgrespro.ru", "phone": "+70317329667"}
0005434409009	1374F4	9085 414440	GRIGORIY PETROV	{"phone": "+70062926314"}
0005434409010	49F5FD	9348 109803	TATYANA KUZMINA	{"email": "kuzmina-t_041974@postgrespro.ru", "phone": "+70492165779"}
0005434409011	A2FAD2	0953 693485	VALERIY EGOROV	{"email": "egorovvaleriy.13011971@postgrespro.ru", "phone": "+70784404591"}
0005434409012	BC4FF7	0220 440682	ZLATA IVANOVA	{"email": "zlataivanova-20051965@postgrespro.ru", "phone": "+70157766456"}
0005434409013	BC4FF7	4348 428435	ALEKSEY KULIKOV	{"email": "kulikova-041974@postgrespro.ru", "phone": "+70305512740"}
0005434409014	112AFD	6550 640394	SERGEY PETROV	{"phone": "+70610199827"}
0005434409015	A681CC	9797 817282	VALENTINA SMIRNOVA	{"phone": "+70209945626"}
0005434409016	A681CC	0564 539142	VALENTINA SIDOROVA	{"email": "valentinasidorova.1970@postgrespro.ru", "phone": "+70956064496"}
0005434409017	8215C2	0771 655307	SERGEY ANDREEV	{"email": "s_andreev.071969@postgrespro.ru", "phone": "+70276625214"}
0005434409018	CD2569	4503 408096	OLEG VASILEV	{"phone": "+70352835950"}
0005434409019	CD2569	8419 364930	KONSTANTIN NIKOLAEV	{"email": "k-nikolaev.12121965@postgrespro.ru", "phone": "+70542918322"}
0005434409020	9FA7CF	4194 636414	LYUDMILA MATVEEVA	{"phone": "+70836445178"}
0005434409021	9FA7CF	3817 013223	NIKOLAY ZAKHAROV	{"phone": "+70724035942"}
0005434409022	9FA7CF	0347 976909	ANATOLIY MAKAROV	{"phone": "+70486850635"}
0005434409023	9477A8	9673 302941	ARTEM MOROZOV	{"email": "morozov-artem-061969@postgrespro.ru", "phone": "+70312104864"}
0005434409024	9477A8	1085 834382	VLADIMIR IVANOV	{"phone": "+70005084233"}
0005434409025	2FFB5B	8455 283820	NADEZHDA ALEKSEEVA	{"phone": "+70571029457"}
0005434409026	263636	4506 178296	VIKTOR KUZNECOV	{"phone": "+70197788234"}
0005434409027	D86ED2	2648 702367	ALEKSEY GORBUNOV	{"email": "gorbunov_a_121965@postgrespro.ru", "phone": "+70386174644"}
0005434409028	70985C	3140 045028	KONSTANTIN EGOROV	{"phone": "+70118652342"}
0005434409029	9E6BD9	5931 154802	OLGA KAZAKOVA	{"email": "olga.kazakova_121973@postgrespro.ru", "phone": "+70600478130"}
0005434409030	216D8A	0460 677884	VIKTORIYA MATVEEVA	{"phone": "+70819354432"}
0005434409031	0A10AD	8994 418693	GEORGIY MAKSIMOV	{"phone": "+70374932023"}
0005434409032	9D2A93	8386 889229	ANTON ZAYCEV	{"email": "zaycev-a-061969@postgrespro.ru", "phone": "+70073675759"}
0005434409033	947984	7783 761626	LYUDMILA TIKHONOVA	{"email": "tikhonovalyudmila-10121975@postgrespro.ru", "phone": "+70268523303"}
0005434409034	6D6551	4840 281805	VITALIY BONDARENKO	{"phone": "+70443056830"}
0005434409035	5CF645	7597 312859	VLADISLAV PETROV	{"email": "petrovvladislav-111972@postgrespro.ru", "phone": "+70114979457"}
0005434409036	93BE46	6430 598635	MARIYA KOROLEVA	{"phone": "+70400852166"}
0005434409037	93BE46	7931 596326	SVETLANA DAVYDOVA	{"email": "davydova.s_051981@postgrespro.ru", "phone": "+70544569766"}
0005434409038	54E73E	8283 594453	ARTEM POPOV	{"email": "popov_a-121967@postgrespro.ru", "phone": "+70497238888"}
0005434409039	E4A804	7962 230988	IGOR FILIPPOV	{"email": "filippov-i.10021964@postgrespro.ru", "phone": "+70438649773"}
0005434409040	E4A804	6655 969728	VALENTINA KUZNECOVA	{"phone": "+70142588189"}
0005434409041	E4A804	0082 973287	MIKHAIL KUZMIN	{"email": "kuzmin.mikhail-1968@postgrespro.ru", "phone": "+70634057367"}
0005434409042	67FBB9	4898 345041	RAISA EGOROVA	{"phone": "+70374529574"}
0005434409043	4E3038	1301 011678	ELENA ANTONOVA	{"email": "eantonova111972@postgrespro.ru", "phone": "+70605646919"}
0005434409044	5F5982	1260 846470	GRIGORIY VOROBEV	{"phone": "+70615129091"}
0005434409045	C40BE1	0711 623915	NADEZHDA MELNIKOVA	{"phone": "+70469205851"}
0005434409046	D8AAFC	0967 385545	SVETLANA SOLOVEVA	{"email": "s.soloveva1966@postgrespro.ru", "phone": "+70938010151"}
0005434409047	E51E2C	4970 883857	NINA MASLOVA	{"email": "maslova_nina19021966@postgrespro.ru", "phone": "+70316272645"}
0005434409048	E51E2C	9110 695014	EVGENIYA NAZAROVA	{"phone": "+70022855615"}
0005434409049	DC8B83	5192 292309	IGOR ANTONOV	{"email": "igor-antonov-1981@postgrespro.ru", "phone": "+70190846754"}
0005434409050	A73CAA	2962 190527	TATYANA KUZMINA	{"phone": "+70979373862"}
0005434409051	A73CAA	3386 672099	VALENTINA PETROVA	{"email": "petrova.valentina1967@postgrespro.ru", "phone": "+70728099556"}
0005434409052	8CDF8C	4106 712225	ALEKSANDR POPOV	{"email": "apopov1969@postgrespro.ru", "phone": "+70262229284"}
0005434409053	8CDF8C	9534 135182	OLEG BARANOV	{"email": "obaranov.1969@postgrespro.ru", "phone": "+70910813755"}
0005434409054	8CDF8C	5448 442840	ANNA PAVLOVA	{"email": "a-pavlova-1967@postgrespro.ru", "phone": "+70296501560"}
0005434409055	719397	9056 857786	SEMEN ZAKHAROV	{"email": "zakharovsemen1968@postgrespro.ru", "phone": "+70909756986"}
0005434409056	719397	7544 414989	TATYANA ZOTOVA	{"email": "tatyana-zotova061975@postgrespro.ru", "phone": "+70872453150"}
0005434409057	6BD6CC	4412 560319	DMITRIY MELNIKOV	{"email": "d-melnikov.051957@postgrespro.ru", "phone": "+70655398304"}
0005434409058	272E35	6409 708159	ARTEM DMITRIEV	{"email": "dmitriev_a_071973@postgrespro.ru", "phone": "+70951071844"}
0005434409059	0895E8	7275 970676	ANNA MARTYNOVA	{"email": "martynova.anna041974@postgrespro.ru", "phone": "+70521764965"}
0005434409060	55C5DE	0684 571434	NIKOLAY IVANOV	{"email": "ivanov_n_08031960@postgrespro.ru", "phone": "+70936322683"}
0005434409061	C3551C	3357 104797	MARIYA GRISHINA	{"email": "m-grishina-02111962@postgrespro.ru", "phone": "+70371215787"}
0005434409062	C3551C	7437 107731	ANASTASIYA BOGDANOVA	{"email": "anastasiya_bogdanova_1967@postgrespro.ru", "phone": "+70764794742"}
0005434409063	197249	9532 312360	NATALYA ZAKHAROVA	{"email": "n_zakharova-28021968@postgrespro.ru", "phone": "+70221483437"}
0005434409064	197249	2489 792563	MIKHAIL SEMENOV	{"phone": "+70042069779"}
0005434409065	197249	1898 897695	MARINA KUZMINA	{"phone": "+70799885101"}
0005434409066	CA9E75	3231 441853	LYUBOV TITOVA	{"phone": "+70089921131"}
0005434409067	CA9E75	7791 146792	ALEKSANDR BELOV	{"email": "belov.aleksandr-011973@postgrespro.ru", "phone": "+70702845234"}
0005434409068	41F89C	0237 259773	YULIYA PAVLOVA	{"phone": "+70088221486"}
0005434409069	0CD1C7	0981 456528	ALBERT ZHURAVLEV	{"phone": "+70999576941"}
0005434409070	220EF1	4527 734948	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov1979@postgrespro.ru", "phone": "+70673364520"}
0005434409071	220EF1	6416 301489	RENATA ISAEVA	{"phone": "+70511763588"}
0005434409072	20A8EF	9900 656365	OLGA SMIRNOVA	{"phone": "+70842507216"}
0005434409073	20A8EF	8994 160399	VLADIMIR KARPOV	{"email": "karpovv061968@postgrespro.ru", "phone": "+70151495142"}
0005434409074	5EE997	1018 557223	ANNA SEMENOVA	{"phone": "+70382813353"}
0005434409075	5EE997	3917 157956	OLGA MASLOVA	{"phone": "+70611864000"}
0005434409076	B16801	4613 081878	LYUBOV OSIPOVA	{"email": "osipova-l-081963@postgrespro.ru", "phone": "+70481751784"}
0005434409077	B16801	9562 293847	ANDREY NOVIKOV	{"email": "novikovandrey-1977@postgrespro.ru", "phone": "+70894260182"}
0005434409078	4D2EE9	1369 565088	OLGA RYABOVA	{"phone": "+70403157898"}
0005434409079	4D2EE9	2666 940676	LYUDMILA BORISOVA	{"email": "lborisova-061965@postgrespro.ru", "phone": "+70382957999"}
0005434409080	77E3FB	4284 407331	NINA PAVLOVA	{"email": "pavlova-n16011985@postgrespro.ru", "phone": "+70178290060"}
0005434409081	77E3FB	5563 568616	PETR KONOVALOV	{"phone": "+70305335062"}
0005434409082	235C16	6499 592327	LARISA KARPOVA	{"email": "l.karpova_13091966@postgrespro.ru", "phone": "+70276172354"}
0005434409083	235C16	7531 970851	ANDREY MOISEEV	{"phone": "+70363457252"}
0005434409084	42466A	1027 874417	LYUDMILA ZAKHAROVA	{"phone": "+70503159095"}
0005434409085	D32905	5177 127133	TATYANA SMIRNOVA	{"email": "t-smirnova18081967@postgrespro.ru", "phone": "+70234906361"}
0005434409086	D32905	2950 157610	NIKOLAY FEDOTOV	{"email": "fedotov_nikolay.031969@postgrespro.ru", "phone": "+70126654034"}
0005434409087	8EB0C1	0377 954105	DENIS NOVIKOV	{"email": "denis-novikov_1987@postgrespro.ru", "phone": "+70434890849"}
0005434409088	8EB0C1	5385 704434	OKSANA VASILEVA	{"email": "oksana.vasileva_1972@postgrespro.ru", "phone": "+70403723311"}
0005434409089	B0D8C7	1697 233228	IVAN SMIRNOV	{"email": "smirnov.ivan111975@postgrespro.ru", "phone": "+70198521925"}
0005434409090	DF3CF8	3368 657835	KSENIYA KUZNECOVA	{"phone": "+70115890193"}
0005434409091	DF3CF8	1790 862873	VARVARA SMIRNOVA	{"phone": "+70217837624"}
0005434409092	01F13C	9933 314620	SERAFIMA VLASOVA	{"phone": "+70858156161"}
0005434409093	4736B3	0412 169123	GALINA VOROBEVA	{"phone": "+70879473541"}
0005434409094	4736B3	3809 855083	VITALIY SIDOROV	{"email": "sidorovv.1960@postgrespro.ru", "phone": "+70654094205"}
0005434409095	8FDC9D	0062 473253	REGINA MOROZOVA	{"phone": "+70186858456"}
0005434409096	5A6E20	8215 929577	NADEZHDA YAKOVLEVA	{"email": "n-yakovleva121965@postgrespro.ru", "phone": "+70059040468"}
0005434409097	8CCFB2	6147 191545	OLESYA MAKAROVA	{"phone": "+70112262903"}
0005434409098	8CCFB2	2003 492050	MAKSIM VASILEV	{"email": "vasilev-m.1966@postgrespro.ru", "phone": "+70247528779"}
0005434409099	8CCFB2	7598 851716	VALENTINA SOKOLOVA	{"email": "sokolova.valentina.01091980@postgrespro.ru", "phone": "+70505790582"}
0005434409100	384451	7381 585109	KIRILL IVANOV	{"phone": "+70383835633"}
0005434409101	E359DA	9981 322996	ALEKSANDR GRIGOREV	{"phone": "+70729695374"}
0005434409102	E359DA	9985 444875	ALEKSANDRA MOROZOVA	{"email": "a-morozova101961@postgrespro.ru", "phone": "+70281853304"}
0005434409103	973EC8	2760 095037	VLADIMIR ABRAMOV	{"email": "v.abramov_1965@postgrespro.ru", "phone": "+70251885593"}
0005434409104	BB5E43	5370 955655	OLGA KOROLEVA	{"email": "olga.koroleva021973@postgrespro.ru", "phone": "+70951529148"}
0005434409105	BB5E43	2486 068711	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey.1963@postgrespro.ru", "phone": "+70791388783"}
0005434409106	BB5E43	9587 055708	ANASTASIYA SEMENOVA	{"email": "anastasiya-semenova.27121958@postgrespro.ru", "phone": "+70513738036"}
0005434409107	75E79F	0978 976618	DMITRIY IVANOV	{"phone": "+70724071682"}
0005434409108	1F77D7	6665 302982	YULIYA FROLOVA	{"email": "frolovayuliya_041973@postgrespro.ru", "phone": "+70135764819"}
0005434409109	EF1BE1	1920 877680	DMITRIY BONDARENKO	{"email": "bondarenko_dmitriy.16091968@postgrespro.ru", "phone": "+70206902708"}
0005434409110	06D245	5405 291685	ARTEM IVANOV	{"email": "ivanov.a-121984@postgrespro.ru", "phone": "+70623767265"}
0005434409111	2540C5	8896 495317	ANTONINA BARANOVA	{"email": "abaranova-19091967@postgrespro.ru", "phone": "+70304271028"}
0005434409112	70B4FD	7115 980149	YULIYA ABRAMOVA	{"phone": "+70430189869"}
0005434409449	BA0EAC	5853 773074	SERGEY SOKOLOV	{"phone": "+70890269480"}
0005434409113	CF028A	0117 453061	ELENA KAZAKOVA	{"email": "elena-kazakova.25051971@postgrespro.ru", "phone": "+70272712750"}
0005434409114	CF028A	2956 268424	VADIM GERASIMOV	{"email": "gerasimov_vadim-1971@postgrespro.ru", "phone": "+70796238290"}
0005434409115	8983E1	8972 628344	NADEZHDA NOVIKOVA	{"email": "novikovanadezhda.26111964@postgrespro.ru", "phone": "+70616922100"}
0005434409116	2602C3	2770 732132	KARINA SERGEEVA	{"phone": "+70438442376"}
0005434409117	2602C3	4380 710839	OLEG MOROZOV	{"email": "morozov-o04081967@postgrespro.ru", "phone": "+70506788783"}
0005434409118	2602C3	0447 824295	ALEKSEY IVANOV	{"phone": "+70179703402"}
0005434409119	EBF574	7277 206258	FATIMA GUSEVA	{"email": "f_guseva-1960@postgrespro.ru", "phone": "+70508223496"}
0005434409120	EBF574	0795 665370	IGOR VOROBEV	{"phone": "+70011204714"}
0005434409121	2E8D33	0085 158287	VITALIY KUDRYASHOV	{"email": "vitaliy-kudryashov_1972@postgrespro.ru", "phone": "+70763718859"}
0005434409122	E679C6	8987 340408	IVAN ROMANOV	{"email": "i_romanov_021969@postgrespro.ru", "phone": "+70101017085"}
0005434409123	3F50CF	2011 179272	DMITRIY SOLOVEV	{"phone": "+70306261301"}
0005434409124	3F50CF	4152 396560	VALERIY IVANOV	{"phone": "+70821798936"}
0005434409125	BC2CDF	1894 534227	DMITRIY KULIKOV	{"email": "kulikov.dmitriy-10021966@postgrespro.ru", "phone": "+70044189109"}
0005434409126	550B95	0304 551493	OLGA SERGEEVA	{"email": "olga-sergeeva02041967@postgrespro.ru", "phone": "+70564647723"}
0005434409127	AE7EF8	6881 576861	VERA TIMOFEEVA	{"email": "timofeeva-v-1969@postgrespro.ru", "phone": "+70534837519"}
0005434409128	51D85F	2949 504081	DMITRIY ZAKHAROV	{"email": "dmitriy.zakharov.14091981@postgrespro.ru", "phone": "+70472068006"}
0005434409310	937728	9516 175958	ANDREY GAVRILOV	{"phone": "+70120960178"}
0005434409129	518D21	0249 160595	MARINA DENISOVA	{"email": "denisova_m_101963@postgrespro.ru", "phone": "+70478656609"}
0005434409130	518D21	7718 699160	IVAN SERGEEV	{"phone": "+70408946113"}
0005434409131	B1AA2E	7961 637414	DARYA SIDOROVA	{"phone": "+70314639459"}
0005434409132	CD262E	2641 438990	MAKSIM ABRAMOV	{"phone": "+70097615262"}
0005434409133	C74426	3528 622924	NADEZHDA FILIPPOVA	{"phone": "+70858318789"}
0005434409134	E23129	8721 158367	SERGEY OSIPOV	{"email": "sergeyosipov.28071978@postgrespro.ru", "phone": "+70361836462"}
0005434409135	E6DEE4	8973 265032	YURIY MAKAROV	{"phone": "+70973192081"}
0005434409136	B94886	8921 922834	ALEKSEY ANDREEV	{"phone": "+70104599508"}
0005434409137	58426B	9391 260245	VLADISLAV NAZAROV	{"phone": "+70328363239"}
0005434409138	3B38C7	2462 336142	IVAN KUZNECOV	{"email": "i_kuznecov071976@postgrespro.ru", "phone": "+70433957150"}
0005434409139	067DC1	8808 333079	ROMAN MOROZOV	{"email": "morozovr.24031965@postgrespro.ru", "phone": "+70886930146"}
0005434409140	64FCFF	8354 164420	ALEKSANDR KULIKOV	{"email": "kulikov_a.021967@postgrespro.ru", "phone": "+70483201669"}
0005434409141	38F1E1	4245 333407	GRIGORIY NOVIKOV	{"email": "novikovg.13111975@postgrespro.ru", "phone": "+70263629591"}
0005434409142	757156	2536 418869	ANDREY BARANOV	{"email": "baranova-011972@postgrespro.ru", "phone": "+70233991271"}
0005434409143	C65432	2705 392246	ALEKSANDR KUZNECOV	{"phone": "+70284015025"}
0005434409144	61505D	4731 966356	NATALYA VASILEVA	{"phone": "+70040357414"}
0005434409145	61505D	4076 235673	SERGEY FEDOROV	{"email": "sergeyfedorov-1972@postgrespro.ru", "phone": "+70648387407"}
0005434409146	B7C0D1	3184 359290	YULIYA MEDVEDEVA	{"email": "medvedeva_y.061970@postgrespro.ru", "phone": "+70884181180"}
0005434409147	A369C9	4560 289834	DMITRIY EGOROV	{"phone": "+70098704937"}
0005434409148	A369C9	8282 594872	MAKSIM BELOV	{"email": "mbelov_041966@postgrespro.ru", "phone": "+70313675222"}
0005434409149	B9254E	0545 098087	VASILIY DENISOV	{"email": "v-denisov111973@postgrespro.ru", "phone": "+70308488163"}
0005434409150	B9254E	3836 435195	ARTEM EGOROV	{"phone": "+70180734168"}
0005434409151	DB92A3	8551 604371	VADIM ROMANOV	{"email": "romanov_v1965@postgrespro.ru", "phone": "+70178754662"}
0005434409152	DB92A3	0166 831309	YURIY ALEKSEEV	{"phone": "+70012698096"}
0005434409153	DB92A3	4961 858717	ROMAN NAZAROV	{"phone": "+70904861105"}
0005434409154	AF4FF0	2928 948477	ELENA FEDOROVA	{"email": "elena-fedorova_1969@postgrespro.ru", "phone": "+70676381599"}
0005434409155	AF4FF0	2895 636911	ALEKSEY GUSEV	{"email": "aleksey-gusev1977@postgrespro.ru", "phone": "+70045343284"}
0005434409156	C8CB68	8850 360038	LIDIYA RODIONOVA	{"phone": "+70069833792"}
0005434409157	FC24DD	7858 387036	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov_1975@postgrespro.ru", "phone": "+70115100159"}
0005434409158	1447D8	3903 207443	KONSTANTIN ALEKSANDROV	{"phone": "+70965776175"}
0005434409159	7ECF86	6098 906701	LIDIYA ZHUKOVA	{"phone": "+70240184734"}
0005434409160	946793	8163 494725	RIMMA VOLKOVA	{"phone": "+70082589425"}
0005434409161	6FD606	6681 612782	ELENA KULIKOVA	{"phone": "+70372160542"}
0005434409162	4BBE3F	9406 798158	TATYANA BELOVA	{"phone": "+70733973570"}
0005434409163	030F75	7392 072124	NIKITA GERASIMOV	{"phone": "+70769216090"}
0005434409164	030F75	4212 791080	SERGEY SHEVCHENKO	{"phone": "+70271003354"}
0005434409165	059A9F	2894 919776	VALENTINA ZHUKOVA	{"phone": "+70869334731"}
0005434409166	A6816B	5673 772779	YANA POPOVA	{"email": "popova-y.1967@postgrespro.ru", "phone": "+70293859618"}
0005434409167	A6816B	7905 400230	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov-1967@postgrespro.ru", "phone": "+70467032661"}
0005434409168	CCC749	5579 392131	ANATOLIY KOZLOV	{"email": "kozlova19111955@postgrespro.ru", "phone": "+70349591843"}
0005434409169	BFD9C2	3816 946989	SVETLANA IVANOVA	{"email": "s.ivanova25031965@postgrespro.ru", "phone": "+70955075602"}
0005434409170	D2421B	8231 837662	VALENTINA VASILEVA	{"phone": "+70270764873"}
0005434409171	DB4D07	6376 244093	KRISTINA FILATOVA	{"phone": "+70999303608"}
0005434409172	B66407	8904 277345	ELVINA NAUMOVA	{"phone": "+70377025819"}
0005434409173	7EF017	8507 859590	YULIYA VOLKOVA	{"phone": "+70036719462"}
0005434409174	7EF017	1466 581867	VIKTOR KISELEV	{"phone": "+70944895223"}
0005434409175	999A05	9043 967816	ALEKSANDR GERASIMOV	{"email": "gerasimov-a-121981@postgrespro.ru", "phone": "+70073217565"}
0005434409176	9DC2AF	7482 260390	VASILIY SMIRNOV	{"phone": "+70435884284"}
0005434409177	609B91	8541 189182	VYACHESLAV POPOV	{"phone": "+70982400010"}
0005434409178	4DB0EE	4753 408144	NATALYA BORISOVA	{"phone": "+70154191745"}
0005434409179	4DB0EE	0372 779984	TATYANA VOLKOVA	{"phone": "+70697104853"}
0005434409180	4DB0EE	9023 545530	DAVID BORISOV	{"email": "borisov-d1967@postgrespro.ru", "phone": "+70690157201"}
0005434409181	871AF5	4012 859840	YURIY SCHERBAKOV	{"email": "yuriy-scherbakov.071975@postgrespro.ru", "phone": "+70757610202"}
0005434409182	0FE775	5011 254095	ALEKSANDR CHERNOV	{"phone": "+70355863658"}
0005434409183	20B455	6342 265300	IOSIF IVANOV	{"phone": "+70340010525"}
0005434409184	710DBC	4332 391054	YANA VASILEVA	{"email": "vasileva-yana-29061971@postgrespro.ru", "phone": "+70952772660"}
0005434409185	878845	5371 966351	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr.061986@postgrespro.ru", "phone": "+70116422458"}
0005434409186	878845	2244 911377	MAKSIM KUZNECOV	{"email": "m.kuznecov_1978@postgrespro.ru", "phone": "+70473122006"}
0005434409187	878845	6802 546721	ANDREY SOLOVEV	{"phone": "+70006920192"}
0005434409188	92DBC9	0607 155643	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr-23081971@postgrespro.ru", "phone": "+70550954725"}
0005434409189	92DBC9	7178 308054	IRINA ALEKSEEVA	{"phone": "+70362667086"}
0005434409190	92DBC9	9269 170523	MIKHAIL MAKAROV	{"email": "mikhailmakarov-06081974@postgrespro.ru", "phone": "+70197630864"}
0005434409191	3A47B9	3901 285613	ILDAR DENISOV	{"email": "denisov-ildar-24041985@postgrespro.ru", "phone": "+70065119376"}
0005434409192	84D71C	1975 416877	KIRILL FEDOTOV	{"email": "k-fedotov_121961@postgrespro.ru", "phone": "+70670644079"}
0005434409193	84D71C	4501 315494	SOFYA MAKSIMOVA	{"phone": "+70662725796"}
0005434409194	3367DA	6814 871208	IRINA DENISOVA	{"phone": "+70845700840"}
0005434409195	3367DA	7984 449890	ALEKSANDR IVANOV	{"email": "aleksandrivanov-1971@postgrespro.ru", "phone": "+70913546679"}
0005434409196	FE0D47	9716 314081	VALENTINA KOVALEVA	{"email": "vkovaleva.1974@postgrespro.ru", "phone": "+70743010499"}
0005434409197	606421	0224 325121	ANDREY KUDRYASHOV	{"email": "andreykudryashov-1982@postgrespro.ru", "phone": "+70826251545"}
0005434409198	606421	5518 022385	VALERIY VOROBEV	{"email": "valeriy-vorobev.1970@postgrespro.ru", "phone": "+70033540657"}
0005434409199	606421	7105 485355	SVETLANA FADEEVA	{"email": "fadeeva-s-031979@postgrespro.ru", "phone": "+70465380352"}
0005434409200	DFDC81	5892 660438	FEDOR GRIGOREV	{"email": "grigorev.f-20091968@postgrespro.ru", "phone": "+70101193992"}
0005434409201	31EBD2	1610 405896	VLADIMIR FEDOROV	{"phone": "+70692467292"}
0005434409202	31EBD2	8032 549136	DIANA FROLOVA	{"phone": "+70319535420"}
0005434409203	448901	2786 727156	VIKTOR KUZNECOV	{"phone": "+70816180969"}
0005434409204	448901	7467 918580	OLEG SOLOVEV	{"email": "solovev-o_17121974@postgrespro.ru", "phone": "+70531923760"}
0005434409205	0F916E	0658 389814	IRINA CHERNOVA	{"email": "chernova_i-1965@postgrespro.ru", "phone": "+70435795957"}
0005434409206	DDCA43	3569 828021	TATYANA KOLESNIKOVA	{"email": "t-kolesnikova_1971@postgrespro.ru", "phone": "+70085232132"}
0005434409207	DDCA43	7286 918837	ELENA NAUMOVA	{"email": "naumova_elena.051974@postgrespro.ru", "phone": "+70853309449"}
0005434409208	B99047	2415 871557	NATALIYA KUZMINA	{"email": "nkuzmina.16081968@postgrespro.ru", "phone": "+70512414779"}
0005434409209	503ABB	5263 231667	NINA LAZAREVA	{"phone": "+70503055115"}
0005434409210	25C34B	3441 691808	DMITRIY FEDOROV	{"phone": "+70347564368"}
0005434409211	25C34B	7547 819584	LARISA IVANOVA	{"phone": "+70959544618"}
0005434409212	E403CB	0209 267581	SERGEY KOZLOV	{"email": "sergey.kozlov1975@postgrespro.ru", "phone": "+70901039612"}
0005434409213	947175	7159 579165	ELIZAVETA MIRONOVA	{"phone": "+70592490332"}
0005434409214	72B56E	6334 878406	NATALYA VOROBEVA	{"email": "natalya.vorobeva-121961@postgrespro.ru", "phone": "+70203661197"}
0005434409215	B48A34	8293 448448	EVGENIY SOROKIN	{"phone": "+70165182743"}
0005434409216	B48A34	9534 175850	ARKADIY FEDOROV	{"phone": "+70147040607"}
0005434409217	1871E4	0427 457624	ALEKSANDR KONOVALOV	{"phone": "+70103801596"}
0005434409218	8273D5	6411 499606	YULIYA LAZAREVA	{"email": "yuliya_lazareva-081974@postgrespro.ru", "phone": "+70812221545"}
0005434409219	3406A2	5666 395228	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov_111969@postgrespro.ru", "phone": "+70136358528"}
0005434409220	3406A2	5416 803664	VALENTINA LOGINOVA	{"email": "v-loginova-101961@postgrespro.ru", "phone": "+70264006648"}
0005434409221	D913B2	7443 298275	RIMMA SEMENOVA	{"email": "rimma-semenova.10121969@postgrespro.ru", "phone": "+70868080412"}
0005434409222	D913B2	2574 642193	ANTONINA FILIPPOVA	{"phone": "+70567646951"}
0005434409223	D47626	8933 100433	VERA STEPANOVA	{"email": "stepanova-vera_081978@postgrespro.ru", "phone": "+70637177398"}
0005434409224	F7B833	2730 651425	LYUDMILA FADEEVA	{"email": "fadeeva_lyudmila19091965@postgrespro.ru", "phone": "+70497297377"}
0005434409225	FA1E5B	5068 407819	EVGENIY OSIPOV	{"email": "osipov_e-091964@postgrespro.ru", "phone": "+70624347019"}
0005434409226	069623	9621 828597	MARIYA MATVEEVA	{"email": "matveeva.mariya.101973@postgrespro.ru", "phone": "+70878518719"}
0005434409227	44ED6A	8822 692226	LEONID NAZAROV	{"email": "lnazarov_1972@postgrespro.ru", "phone": "+70187154422"}
0005434409228	B31851	1515 115024	VIKTOR IVANOV	{"phone": "+70560740963"}
0005434409229	4EE445	0872 623484	DANILA POPOV	{"email": "popovd121968@postgrespro.ru", "phone": "+70905327261"}
0005434409230	028ABF	5466 191215	STEPAN ZAYCEV	{"email": "zaycevs1962@postgrespro.ru", "phone": "+70457002034"}
0005434409231	028ABF	4729 987210	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov1969@postgrespro.ru", "phone": "+70896331195"}
0005434409232	6DBD0D	0595 609279	MIKHAIL KAZAKOV	{"phone": "+70069084169"}
0005434409233	6DBD0D	6651 733076	EVGENIY PAVLOV	{"email": "pavlov_evgeniy.14061964@postgrespro.ru", "phone": "+70734316732"}
0005434409234	BD6334	5800 624618	ALISA ISAEVA	{"email": "isaevaalisa.091970@postgrespro.ru", "phone": "+70099210397"}
0005434409235	00DA58	3475 157570	ELENA KUZMINA	{"phone": "+70365110413"}
0005434409236	B5A0C1	1749 413217	MAKSIM GAVRILOV	{"phone": "+70834476202"}
0005434409237	A4ED72	6059 486309	SERGEY KAZAKOV	{"email": "kazakov_s.031968@postgrespro.ru", "phone": "+70052271371"}
0005434409238	8DF261	3254 288735	ANNA FILATOVA	{"phone": "+70734847661"}
0005434409239	C00FFC	8877 118783	VALENTINA BELOVA	{"phone": "+70353077265"}
0005434409240	E36BED	3877 303905	OLGA SERGEEVA	{"phone": "+70842305272"}
0005434409241	77B4F2	1851 314596	ALEKSANDR PETROV	{"email": "petrova011978@postgrespro.ru", "phone": "+70472373751"}
0005434409242	938227	8146 915553	DINARA IVANOVA	{"email": "dinara_ivanova-1959@postgrespro.ru", "phone": "+70254022458"}
0005434409243	938227	8085 628381	VALERIY SOKOLOV	{"phone": "+70815686537"}
0005434409244	EDF746	1048 417165	VALERIY ALEKSANDROV	{"phone": "+70444510598"}
0005434409245	06590D	1489 247963	VLADIMIR GUSEV	{"email": "vladimir.gusev031968@postgrespro.ru", "phone": "+70923133546"}
0005434409246	2E3815	0250 280750	NIKOLAY ZAKHAROV	{"email": "zakharov.nikolay_30111970@postgrespro.ru", "phone": "+70560732374"}
0005434409247	71AC83	7865 803580	ANTONINA OSIPOVA	{"email": "antonina.osipova.1969@postgrespro.ru", "phone": "+70651467522"}
0005434409248	B85AED	0797 048571	TATYANA EFREMOVA	{"phone": "+70024982280"}
0005434409311	7F945E	9631 267483	NATALYA MAKSIMOVA	{"phone": "+70484362673"}
0005434409249	B85AED	0742 030862	IVAN KAZAKOV	{"email": "ivan-kazakov031961@postgrespro.ru", "phone": "+70650208860"}
0005434409250	EFBFF4	2948 302396	ELENA KUZNECOVA	{"phone": "+70101625724"}
0005434409251	EFBFF4	5260 882690	VALERIY DAVYDOV	{"email": "davydov_v-1969@postgrespro.ru", "phone": "+70379052711"}
0005434409252	B0712B	5783 534642	EVGENIY GAVRILOV	{"phone": "+70938511787"}
0005434409253	DF5299	3975 831365	MARINA SEMENOVA	{"email": "semenovamarina_27121964@postgrespro.ru", "phone": "+70328952814"}
0005434409254	E156A1	5970 632428	SVETLANA SERGEEVA	{"email": "sergeeva.svetlana011972@postgrespro.ru", "phone": "+70789367685"}
0005434409255	3F11D2	0577 670661	LIDIYA KOLESNIKOVA	{"phone": "+70276353012"}
0005434409256	8BFAAE	0053 347064	ALLA MARTYNOVA	{"phone": "+70118288650"}
0005434409257	50574F	6254 433036	ALEKSANDRA ANDREEVA	{"phone": "+70963928284"}
0005434409258	7FF863	3263 488555	SOFYA ROMANOVA	{"email": "sofya.romanova_31051973@postgrespro.ru", "phone": "+70433654151"}
0005434409259	7FF863	2009 284130	KLAVDIYA KUZNECOVA	{"email": "klavdiya_kuznecova-30011979@postgrespro.ru", "phone": "+70525805129"}
0005434409260	52CA6F	2158 030870	DANIL ANDREEV	{"phone": "+70993759175"}
0005434409261	85BE99	0677 026262	IRINA DENISOVA	{"email": "denisova_irina-041979@postgrespro.ru", "phone": "+70446003978"}
0005434409262	06F55C	4226 334605	ALEKSEY YAKOVLEV	{"email": "yakovlev_a-021985@postgrespro.ru", "phone": "+70954471338"}
0005434409263	C30F57	2132 366139	ANDREY FEDOROV	{"email": "andreyfedorov14031981@postgrespro.ru", "phone": "+70290319642"}
0005434409264	88D61F	3831 662971	NIKITA MOISEEV	{"phone": "+70996284589"}
0005434409265	ED26B9	5439 124892	DMITRIY GAVRILOV	{"phone": "+70092147783"}
0005434409266	ED26B9	9939 685306	GALINA NIKOLAEVA	{"phone": "+70856074520"}
0005434409267	743C9B	9010 301600	KIRILL VOROBEV	{"email": "vorobev_k.06121969@postgrespro.ru", "phone": "+70215154071"}
0005434409268	743C9B	0444 638567	NIKOLAY MAKAROV	{"email": "makarov.n.24031969@postgrespro.ru", "phone": "+70195929740"}
0005434409269	743C9B	5831 553419	NATALYA MALYSHEVA	{"email": "malysheva.n.021978@postgrespro.ru", "phone": "+70650245656"}
0005434409270	6386E1	4332 514659	ALEKSANDR EGOROV	{"phone": "+70299761517"}
0005434409271	EF841C	1669 386510	DMITRIY SIDOROV	{"email": "sidorovdmitriy.1965@postgrespro.ru", "phone": "+70366888391"}
0005434409272	EF841C	7463 214077	PETR PAVLOV	{"email": "p_pavlov.121966@postgrespro.ru", "phone": "+70418543738"}
0005434409273	8184AF	5518 353078	ANDREY MAKAROV	{"phone": "+70189247239"}
0005434409274	E21036	2283 834781	DIANA DAVYDOVA	{"phone": "+70012171288"}
0005434409275	E21036	1155 035888	NATALYA DMITRIEVA	{"phone": "+70375118961"}
0005434409276	D929E4	5291 725185	LYUBOV SOKOLOVA	{"email": "sokolovalyubov021972@postgrespro.ru", "phone": "+70175447639"}
0005434409277	7501AF	5160 435624	GENNADIY ANDREEV	{"phone": "+70964434289"}
0005434409278	6C00F1	5798 141525	ELENA TIKHONOVA	{"email": "tikhonova.elena-051983@postgrespro.ru", "phone": "+70594987093"}
0005434409279	4EEB2F	8099 420232	PAVEL IVANOV	{"phone": "+70397271517"}
0005434409280	C87062	5028 254810	ANDREY KUZNECOV	{"email": "a.kuznecov1971@postgrespro.ru", "phone": "+70110554719"}
0005434409281	C87062	9111 021200	ELENA NOVIKOVA	{"email": "e-novikova.031964@postgrespro.ru", "phone": "+70027962841"}
0005434409282	F4175D	8012 189323	ALFIYA DENISOVA	{"phone": "+70105511260"}
0005434409283	9F47D1	1208 645165	ANASTASIYA EGOROVA	{"email": "a_egorova.24021969@postgrespro.ru", "phone": "+70161708970"}
0005434409284	9F47D1	6397 069603	ALEKSEY GERASIMOV	{"phone": "+70018098664"}
0005434409285	98B0D7	5059 789176	TATYANA KOROLEVA	{"email": "tatyana_koroleva_051970@postgrespro.ru", "phone": "+70760829683"}
0005434409286	98B0D7	1342 494231	GALINA ZAKHAROVA	{"phone": "+70967082780"}
0005434409287	98B0D7	7585 470172	TATYANA ZAYCEVA	{"email": "tzayceva1966@postgrespro.ru", "phone": "+70061669040"}
0005434409288	98B0D7	7522 449934	MARIYA POLYAKOVA	{"email": "mpolyakova1980@postgrespro.ru", "phone": "+70608600963"}
0005434409289	BA0995	5872 227107	IVAN BONDARENKO	{"phone": "+70071779780"}
0005434409290	BA0995	5598 304166	SERGEY FOMIN	{"email": "fomin-sergey.1966@postgrespro.ru", "phone": "+70898372769"}
0005434409291	59DC7F	8021 774814	MIKHAIL NIKOLAEV	{"email": "m.nikolaev.12051973@postgrespro.ru", "phone": "+70862714416"}
0005434409292	59DC7F	0228 284017	BORIS FOMIN	{"email": "fomin-b_1959@postgrespro.ru", "phone": "+70729922074"}
0005434409293	59DC7F	5466 836332	ANNA ISAEVA	{"email": "anna-isaeva.1967@postgrespro.ru", "phone": "+70033787395"}
0005434409294	39ABF7	3698 802748	DMITRIY DAVYDOV	{"phone": "+70773389758"}
0005434409295	6ACFAD	8171 270493	SERGEY IVANOV	{"email": "ivanov_sergey-03101963@postgrespro.ru", "phone": "+70984381355"}
0005434409296	5DD116	3358 133606	GALINA BELOVA	{"email": "g_belova061983@postgrespro.ru", "phone": "+70510073907"}
0005434409297	5DD116	1097 418724	ALEKSANDR MELNIKOV	{"email": "melnikov.a.021967@postgrespro.ru", "phone": "+70272585076"}
0005434409298	5DD116	5925 548098	VLADIMIR BELOV	{"phone": "+70870960696"}
0005434409299	CC1BAF	0100 090135	GULFIYA EFIMOVA	{"phone": "+70619885549"}
0005434409300	CC1BAF	1559 474389	TALGAT FOMIN	{"phone": "+70002270375"}
0005434409301	BE1E44	6752 238147	ANASTASIYA KOVALEVA	{"phone": "+70550036177"}
0005434409302	DC4CF9	1890 586780	OLGA ANISIMOVA	{"phone": "+70328574066"}
0005434409303	311B53	7465 363931	MARIYA ISAEVA	{"phone": "+70367312491"}
0005434409304	87EA33	7306 171710	ELENA FROLOVA	{"email": "frolovaelena-1972@postgrespro.ru", "phone": "+70494678439"}
0005434409305	87EA33	5581 904836	YURIY GORBUNOV	{"phone": "+70778623829"}
0005434409306	E3F777	9449 655070	MARIYA FEDOROVA	{"phone": "+70280249324"}
0005434409307	E3F777	2642 294134	ANASTASIYA AFANASEVA	{"email": "a-afanaseva1988@postgrespro.ru", "phone": "+70104499030"}
0005434409308	1367A4	7801 268801	LYUBOV BARANOVA	{"phone": "+70635208886"}
0005434409309	AA63E1	2885 936493	VALENTINA MAKAROVA	{"phone": "+70611426925"}
0005434409312	D2B090	9552 093245	VITALIY PAVLOV	{"email": "pavlov-v.25121975@postgrespro.ru", "phone": "+70808445567"}
0005434409313	D2B090	1424 690090	EVGENIYA RYABOVA	{"phone": "+70406082849"}
0005434409314	D833A8	5174 464887	EVGENIY NAZAROV	{"phone": "+70543175277"}
0005434409315	1E5A2F	1945 156263	TAMARA KOROLEVA	{"phone": "+70174919335"}
0005434409316	096726	1863 314974	TAISIYA ZAYCEVA	{"email": "zayceva-taisiya061963@postgrespro.ru", "phone": "+70174950280"}
0005434409317	064D1E	7124 707320	IGOR NAZAROV	{"phone": "+70316549180"}
0005434409318	491349	9524 007454	IRINA PAVLOVA	{"phone": "+70427966003"}
0005434409319	1AF342	2168 631259	GALINA KOZLOVA	{"phone": "+70189951164"}
0005434409320	194DB2	4174 722535	GALINA KUZMINA	{"phone": "+70783502818"}
0005434409321	C7FE11	6275 511389	OLEG ZAKHAROV	{"email": "o_zakharov13011981@postgrespro.ru", "phone": "+70557667678"}
0005434409322	C7FE11	0920 516519	ALEKSANDR KUZMIN	{"phone": "+70381644905"}
0005434409323	BBE74D	1760 273552	ANTONINA KONDRATEVA	{"email": "antonina.kondrateva-021979@postgrespro.ru", "phone": "+70575190090"}
0005434409324	D01B33	0878 872201	ELENA POLYAKOVA	{"email": "elenapolyakova_071975@postgrespro.ru", "phone": "+70174807750"}
0005434409325	375E32	0588 361573	ALEKSEY KOZLOV	{"phone": "+70508827032"}
0005434409326	41D9DE	4321 865591	VALENTINA BELOVA	{"email": "valentina_belova1975@postgrespro.ru", "phone": "+70748672602"}
0005434409327	2FCB59	3115 499610	ANDREY GAVRILOV	{"phone": "+70134438219"}
0005434409328	2FCB59	6137 480316	MIKHAIL MAKAROV	{"phone": "+70619760526"}
0005434409329	0D6BF5	3200 273225	NADEZHDA MAKSIMOVA	{"email": "maksimova_n.18091965@postgrespro.ru", "phone": "+70106384763"}
0005434409330	38ADA7	5713 587824	NINA KUDRYASHOVA	{"phone": "+70723238532"}
0005434409331	4E28CA	1137 381115	TATYANA NIKITINA	{"email": "t_nikitina061967@postgrespro.ru", "phone": "+70942767850"}
0005434409332	8D393E	5664 241949	NINA FEDOROVA	{"email": "fedorova_nina-011969@postgrespro.ru", "phone": "+70006031736"}
0005434409333	8D393E	0507 547614	VLADIMIR KOZLOV	{"phone": "+70436885380"}
0005434409334	8D393E	9680 705896	DANILA KUZNECOV	{"email": "kuznecovdanila.30101960@postgrespro.ru", "phone": "+70438672668"}
0005434409335	F5501C	9594 220122	ANATOLIY SHEVCHENKO	{"email": "a.shevchenko.1970@postgrespro.ru", "phone": "+70467335589"}
0005434409336	045DCB	1685 420349	RAFAIL MAKSIMOV	{"phone": "+70454484661"}
0005434409337	94962B	0649 733794	MIKHAIL SAVELEV	{"phone": "+70814575906"}
0005434409338	94962B	0751 244901	ANTON ANTONOV	{"email": "a-antonov.16011978@postgrespro.ru", "phone": "+70078989024"}
0005434409339	602719	6752 961725	VALERIY STEPANOV	{"email": "v_stepanov_22031969@postgrespro.ru", "phone": "+70098748610"}
0005434409340	3FF55C	2055 210691	VITALIY KRASNOV	{"email": "krasnov-vitaliy.091972@postgrespro.ru", "phone": "+70133109253"}
0005434409341	3FF55C	3137 332664	OLGA BELOVA	{"email": "belova.o.29081974@postgrespro.ru", "phone": "+70556922510"}
0005434409342	3FF55C	3749 115447	PAVEL PETROV	{"email": "pavel.petrov-04071974@postgrespro.ru", "phone": "+70071691454"}
0005434409343	B5B69C	7979 545533	EVGENIY RODIONOV	{"phone": "+70230834373"}
0005434409344	B5B69C	5907 118315	RAISA POPOVA	{"phone": "+70592687665"}
0005434409345	0C07CD	9584 618819	SERGEY KRASNOV	{"email": "s-krasnov.01041973@postgrespro.ru", "phone": "+70674938039"}
0005434409346	0C07CD	9308 338208	SERGEY NOVIKOV	{"email": "novikov.sergey-07051970@postgrespro.ru", "phone": "+70942429434"}
0005434409347	955044	2606 516881	TATYANA ANDREEVA	{"email": "tatyana_andreeva091969@postgrespro.ru", "phone": "+70556482047"}
0005434409348	955044	3907 027539	SERGEY BELOV	{"phone": "+70327277848"}
0005434409349	6F791B	9037 104371	SVETLANA SCHERBAKOVA	{"email": "scherbakovasvetlana031975@postgrespro.ru", "phone": "+70842531398"}
0005434409350	3E2562	2741 153453	KONSTANTIN KOROLEV	{"phone": "+70260979626"}
0005434409351	48D36A	2594 040939	SERGEY SERGEEV	{"email": "sergeev.sergey09071981@postgrespro.ru", "phone": "+70789488365"}
0005434409352	15C896	5502 621132	SVETLANA TIKHONOVA	{"email": "s_tikhonova.24091978@postgrespro.ru", "phone": "+70463185225"}
0005434409353	C7CF98	1589 566517	ALEKSEY KISELEV	{"phone": "+70305040525"}
0005434409354	C7CF98	0146 076920	OLGA KOROLEVA	{"phone": "+70607408134"}
0005434409355	C7CF98	0561 078866	ALEKSANDR KOROLEV	{"phone": "+70336175904"}
0005434409356	A70476	5171 954143	IVAN NAUMOV	{"email": "inaumov_091970@postgrespro.ru", "phone": "+70797290792"}
0005434409357	A70476	7735 681118	VALENTINA ZHURAVLEVA	{"phone": "+70921702079"}
0005434409358	CA7851	1169 985548	YULIYA NIKOLAEVA	{"phone": "+70923383355"}
0005434409359	479F58	9280 421720	VITALIY KUZMIN	{"phone": "+70499790385"}
0005434409360	075075	2217 050139	GALINA FILATOVA	{"email": "filatova.galina.081961@postgrespro.ru", "phone": "+70046267716"}
0005434409361	E8E49B	4676 603795	MARINA POPOVA	{"phone": "+70608193010"}
0005434409362	E8E49B	5105 054374	DMITRIY MELNIKOV	{"phone": "+70427441825"}
0005434409363	BDF2DF	9514 547090	ILYA ANDREEV	{"email": "ilyaandreev1975@postgrespro.ru", "phone": "+70602232598"}
0005434409364	86640E	3477 988394	ELENA BOGDANOVA	{"phone": "+70194097461"}
0005434409365	2BF388	0833 562566	VALENTINA MAKAROVA	{"email": "vmakarova121974@postgrespro.ru", "phone": "+70823221009"}
0005434409366	2BF388	7679 209423	ALEKSANDR PETROV	{"email": "petrov-aleksandr_1968@postgrespro.ru", "phone": "+70030010356"}
0005434409367	363899	0473 658907	EDUARD VOLKOV	{"email": "eduardvolkov03071971@postgrespro.ru", "phone": "+70578944953"}
0005434409368	48CA27	2872 584073	NIKOLAY GORBUNOV	{"email": "ngorbunov121977@postgrespro.ru", "phone": "+70816931145"}
0005434409369	9F175F	2409 727318	VIKTOR TIKHONOV	{"email": "v.tikhonov_26091978@postgrespro.ru", "phone": "+70670967235"}
0005434409370	9F175F	7822 107789	VIKTOR BARANOV	{"email": "baranov-viktor_13061975@postgrespro.ru", "phone": "+70823336279"}
0005434409371	5508FE	5914 125638	DMITRIY SOKOLOV	{"phone": "+70882848307"}
0005434409372	8A0B73	1639 015348	OLGA MIKHAYLOVA	{"email": "olga-mikhaylova1961@postgrespro.ru", "phone": "+70923878880"}
0005434409373	D4C610	3498 095229	VLADISLAV NIKOLAEV	{"email": "v.nikolaev_09121979@postgrespro.ru", "phone": "+70607117619"}
0005434409374	D4C610	5993 912293	IRAIDA LEBEDEVA	{"phone": "+70749647244"}
0005434409375	289C0B	2068 664944	DENIS TIMOFEEV	{"phone": "+70918871412"}
0005434409376	B88BF4	2962 303272	VIKTOR STEPANOV	{"email": "v.stepanov16071979@postgrespro.ru", "phone": "+70262371262"}
0005434409377	B88BF4	3970 300873	VALENTINA ISAEVA	{"phone": "+70475439204"}
0005434409378	0A3399	9005 761791	DMITRIY PETROV	{"phone": "+70175558823"}
0005434409379	C19C90	7398 912352	OLGA ABRAMOVA	{"email": "o-abramova.08121969@postgrespro.ru", "phone": "+70095004676"}
0005434409380	E08076	9565 503943	EKATERINA MOROZOVA	{"email": "morozova.e051973@postgrespro.ru", "phone": "+70819317044"}
0005434409381	E08076	2056 837148	EVGENIY SOROKIN	{"email": "e-sorokin_25051965@postgrespro.ru", "phone": "+70004437292"}
0005434409382	E08076	6784 068241	ANNA IVANOVA	{"email": "a-ivanova-15071961@postgrespro.ru", "phone": "+70943723659"}
0005434409383	90222F	0300 806654	SERGEY SAVELEV	{"email": "savelevs_1984@postgrespro.ru", "phone": "+70400754211"}
0005434409384	5CE203	7135 064365	EGOR MIKHAYLOV	{"email": "mikhaylov.e-1978@postgrespro.ru", "phone": "+70802354554"}
0005434409385	36BD89	8927 885847	LYUDMILA FADEEVA	{"email": "fadeeva.l05101987@postgrespro.ru", "phone": "+70146011493"}
0005434409386	5C6902	8582 442924	EKATERINA NOVIKOVA	{"email": "e-novikova-1956@postgrespro.ru", "phone": "+70723080022"}
0005434409387	C89DED	2435 138907	NINA MIKHAYLOVA	{"email": "mikhaylova-n.02071971@postgrespro.ru", "phone": "+70246042443"}
0005434409388	12E64D	3942 414659	ANTON BARANOV	{"email": "a_baranov_1967@postgrespro.ru", "phone": "+70558959232"}
0005434409389	12E64D	4390 567050	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov1968@postgrespro.ru", "phone": "+70329783780"}
0005434409390	19A86D	1288 158720	SERGEY VOLKOV	{"phone": "+70812453164"}
0005434409391	19A86D	6277 226835	LYUDMILA MARTYNOVA	{"email": "lyudmilamartynova_121984@postgrespro.ru", "phone": "+70655358214"}
0005434409392	19A86D	7879 657583	SERGEY IVANOV	{"email": "sergey_ivanov-13101972@postgrespro.ru", "phone": "+70415425749"}
0005434409394	BC9C2D	7104 562626	ANTONINA STEPANOVA	{"email": "antonina_stepanova1979@postgrespro.ru", "phone": "+70008883714"}
0005434409395	6C21B4	6378 961028	IRINA ALEKSEEVA	{"phone": "+70950197532"}
0005434409396	10BB04	3585 896502	MARINA IVANOVA	{"email": "m-ivanova-051973@postgrespro.ru", "phone": "+70691098767"}
0005434409397	10BB04	7705 906354	YAROSLAV ZHURAVLEV	{"email": "zhuravlevy-1967@postgrespro.ru", "phone": "+70293699204"}
0005434409398	287CAD	2027 540535	ANASTASIYA MATVEEVA	{"email": "matveevaa13061982@postgrespro.ru", "phone": "+70217790113"}
0005434409399	287CAD	0332 759068	MARTA FILATOVA	{"phone": "+70437748318"}
0005434409400	73F943	9067 004540	MARINA DAVYDOVA	{"phone": "+70694449730"}
0005434409401	A94588	8691 644266	EKATERINA MATVEEVA	{"email": "matveeva-e-071972@postgrespro.ru", "phone": "+70950288522"}
0005434409402	4A4F5E	8948 654913	OLGA SIDOROVA	{"email": "o.sidorova011980@postgrespro.ru", "phone": "+70169534913"}
0005434409403	4C05E9	7953 747871	VLADISLAV MEDVEDEV	{"email": "v_medvedev.25121975@postgrespro.ru", "phone": "+70760406178"}
0005434409404	4C05E9	9793 928608	MARINA ERMAKOVA	{"phone": "+70034944733"}
0005434409405	9DEEED	4622 695607	PAVEL ABRAMOV	{"phone": "+70951511569"}
0005434409406	32E408	7726 106522	ANASTASIYA MOISEEVA	{"phone": "+70267296215"}
0005434409407	DBD33D	1286 741739	VLADIMIR FROLOV	{"phone": "+70767926706"}
0005434409408	B26F83	8116 718055	ALEKSANDR BORISOV	{"phone": "+70259475674"}
0005434409409	B26F83	4695 086787	EKATERINA MOROZOVA	{"email": "morozova.e_1968@postgrespro.ru", "phone": "+70317672468"}
0005434409410	042A79	6012 802621	MARINA MAKAROVA	{"email": "m.makarova_21111970@postgrespro.ru", "phone": "+70151358787"}
0005434409411	D091F5	9791 796872	ANASTASIYA MARTYNOVA	{"email": "a-martynova_061955@postgrespro.ru", "phone": "+70675908010"}
0005434409412	4F8530	9431 462891	VLADIMIR PAVLOV	{"phone": "+70869459941"}
0005434409413	4F8530	2101 185774	ALEKSANDR KARPOV	{"email": "karpov_aleksandr081976@postgrespro.ru", "phone": "+70875159718"}
0005434409414	3326DB	2120 698418	TAMARA FROLOVA	{"email": "t.frolova-111971@postgrespro.ru", "phone": "+70728490256"}
0005434409415	3326DB	6728 696665	TATYANA GRISHINA	{"phone": "+70488636268"}
0005434409416	3326DB	3906 933147	RUSLAN CHERNOV	{"email": "ruslan-chernov1969@postgrespro.ru", "phone": "+70560355646"}
0005434409417	5E2A78	4896 352979	VALERIY KULIKOV	{"email": "kulikov_valeriy_101980@postgrespro.ru", "phone": "+70937062708"}
0005434409418	ED3F84	0655 506709	VIKTOR TIMOFEEV	{"email": "timofeev-viktor-31051979@postgrespro.ru", "phone": "+70110778389"}
0005434409419	ED3F84	2149 103754	DMITRIY MAKAROV	{"email": "d.makarov1973@postgrespro.ru", "phone": "+70411128074"}
0005434409420	8F35AC	4668 475065	OLGA BELYAEVA	{"phone": "+70848678309"}
0005434409421	8F35AC	3659 337175	OLEG NIKOLAEV	{"phone": "+70470353091"}
0005434409422	8F35AC	1971 475448	ARTEM NIKITIN	{"phone": "+70213167893"}
0005434409423	BE742B	9791 896353	VALENTINA POTAPOVA	{"email": "potapova.valentina-111965@postgrespro.ru", "phone": "+70426135378"}
0005434409424	06D023	4234 260220	GALINA VASILEVA	{"email": "vasilevagalina051971@postgrespro.ru", "phone": "+70701092407"}
0005434409425	06D023	0284 290748	LIDIYA KAZAKOVA	{"email": "kazakoval111973@postgrespro.ru", "phone": "+70317443332"}
0005434409426	06D023	6433 689688	KIRA BELOVA	{"email": "belova_kira_08091983@postgrespro.ru", "phone": "+70267391905"}
0005434409427	06D023	2183 331145	ILGIZ KUZNECOV	{"email": "i-kuznecov_031974@postgrespro.ru", "phone": "+70690402210"}
0005434409428	5CC4AF	8681 951635	ANATOLIY PETROV	{"email": "anatoliy-petrov1978@postgrespro.ru", "phone": "+70234036114"}
0005434409429	AF1008	1219 704442	SERGEY EGOROV	{"email": "sergey.egorov.16101971@postgrespro.ru", "phone": "+70540511762"}
0005434409430	6F53E1	8572 347996	ALEKSANDR MOROZOV	{"phone": "+70852624200"}
0005434409431	6F53E1	0755 488693	DANIIL ZHURAVLEV	{"email": "daniil-zhuravlev_1978@postgrespro.ru", "phone": "+70866072259"}
0005434409432	C5F09B	8849 812498	ALEKSEY TIMOFEEV	{"email": "alekseytimofeev.1966@postgrespro.ru", "phone": "+70554380368"}
0005434409433	A99F58	2036 230483	OLGA SOROKINA	{"phone": "+70157332812"}
0005434409434	CDF881	5436 719278	YURIY PAVLOV	{"email": "pavlovyuriy-021972@postgrespro.ru", "phone": "+70680564493"}
0005434409435	CDF881	4029 011359	VALERIY ZAYCEV	{"phone": "+70414115227"}
0005434409436	43B807	4805 940969	MAKSIM GRIGOREV	{"email": "grigorev-m_13021977@postgrespro.ru", "phone": "+70333608615"}
0005434409437	43B807	6217 713860	ALEKSANDR ORLOV	{"phone": "+70783216197"}
0005434409438	496CC2	3551 476153	LYUDMILA LUKYANOVA	{"email": "lyudmila_lukyanova-111967@postgrespro.ru", "phone": "+70676921543"}
0005434409439	DA342D	9991 675775	POLINA NESTEROVA	{"email": "nesterova.p_23101972@postgrespro.ru", "phone": "+70726521497"}
0005434409440	DA342D	1139 802614	SVETLANA GORBUNOVA	{"phone": "+70443893079"}
0005434409441	33B882	7979 798546	ANDREY NAZAROV	{"email": "andrey.nazarov_1974@postgrespro.ru", "phone": "+70428271037"}
0005434409442	CF4CFA	4064 072873	SERGEY KUZMIN	{"phone": "+70651487728"}
0005434409443	46DC79	9264 229548	IRINA KOROLEVA	{"phone": "+70783343576"}
0005434409444	D4810C	9915 275861	ALEKSEY NAUMOV	{"email": "naumova-061972@postgrespro.ru", "phone": "+70073572073"}
0005434409445	D4810C	7601 924253	VLADIMIR ROMANOV	{"email": "romanovvladimir-031970@postgrespro.ru", "phone": "+70525571808"}
0005434409446	F621FD	8776 965815	SERGEY SIDOROV	{"phone": "+70979409816"}
0005434409447	F621FD	3798 865384	ALLA MAKAROVA	{"email": "makarovaa.1968@postgrespro.ru", "phone": "+70934511066"}
0005434409448	F621FD	7133 174031	ALEKSANDR VASILEV	{"phone": "+70659236948"}
0005434409450	403B25	0067 644458	ANTONINA TITOVA	{"email": "antonina.titova-111985@postgrespro.ru", "phone": "+70815343792"}
0005434409451	31CF6B	6363 875319	MARINA ANDREEVA	{"phone": "+70382015832"}
0005434409452	2006EF	7460 127597	DMITRIY SOKOLOV	{"email": "d_sokolov1976@postgrespro.ru", "phone": "+70024549166"}
0005434409453	BC26E3	8273 593397	TAMARA KUZMINA	{"email": "kuzminatamara-1967@postgrespro.ru", "phone": "+70257212872"}
0005434409454	BC26E3	9734 558630	LARISA YAKOVLEVA	{"phone": "+70812456896"}
0005434409455	215BE1	4140 011058	OLGA AKIMOVA	{"email": "akimova_o07051962@postgrespro.ru", "phone": "+70916216630"}
0005434409456	215BE1	5244 189937	ALEKSEY MAKSIMOV	{"phone": "+70670133014"}
0005434409457	ADB453	6672 802752	POLINA NIKOLAEVA	{"phone": "+70704640757"}
0005434409458	9E7AFD	3054 521074	EVGENIYA SAVELEVA	{"phone": "+70658165085"}
0005434409459	9E7AFD	0751 268774	GALINA ARKHIPOVA	{"phone": "+70743068546"}
0005434409460	F188A3	6464 138339	PAVEL FOMIN	{"phone": "+70479934181"}
0005434409461	F188A3	5892 935828	MAKSIM KARPOV	{"phone": "+70436659257"}
0005434409462	F188A3	3930 961006	MADINA FILATOVA	{"email": "m.filatova-1972@postgrespro.ru", "phone": "+70460902903"}
0005434409463	C3853E	6943 277115	EVDOKIYA MEDVEDEVA	{"email": "evdokiya_medvedeva_1969@postgrespro.ru", "phone": "+70650794403"}
0005434409464	C3853E	4104 546179	NATALYA GAVRILOVA	{"email": "gavrilova_n08121962@postgrespro.ru", "phone": "+70152493366"}
0005434409465	F2A313	0948 831629	PETR MARTYNOV	{"email": "pmartynov-13121965@postgrespro.ru", "phone": "+70138121196"}
0005434409466	7570CA	3027 981414	EKATERINA RYABOVA	{"phone": "+70576327492"}
0005434409467	A360DC	0107 603211	LYUBOV ARKHIPOVA	{"email": "arkhipova_lyubov-1971@postgrespro.ru", "phone": "+70742682603"}
0005434409468	A360DC	5643 362967	KLAVDIYA ORLOVA	{"email": "korlova02011968@postgrespro.ru", "phone": "+70115769749"}
0005434409469	4218FD	0463 371042	VASILISA VOLKOVA	{"phone": "+70367752005"}
0005434409470	7364FA	1736 857281	SVETLANA YAKOVLEVA	{"email": "yakovleva-svetlana14101963@postgrespro.ru", "phone": "+70690274871"}
0005434409471	7364FA	0058 480231	NINA CHERNOVA	{"email": "n.chernova_1967@postgrespro.ru", "phone": "+70183448826"}
0005434409472	2B9FB5	0302 300453	NIKOLAY KUDRYASHOV	{"email": "kudryashovn-1968@postgrespro.ru", "phone": "+70123338853"}
0005434409473	2B9FB5	5229 034507	VALENTINA NESTEROVA	{"email": "nesterova_valentina-1970@postgrespro.ru", "phone": "+70029409241"}
0005434409474	D8BB8C	5395 980889	GRIGORIY GERASIMOV	{"phone": "+70952088588"}
0005434409475	3C1396	7804 540168	ELENA EFIMOVA	{"email": "efimova-e-091972@postgrespro.ru", "phone": "+70083841470"}
0005434409476	9C86E7	3225 181986	ALBINA SOLOVEVA	{"email": "albina-soloveva.30011975@postgrespro.ru", "phone": "+70970184205"}
0005434409477	A38C52	9443 870928	RAISA KULIKOVA	{"email": "kulikova-raisa111976@postgrespro.ru", "phone": "+70729741424"}
0005434409478	A38C52	6271 790951	RAISA ALEKSEEVA	{"phone": "+70461789319"}
0005434409479	A38C52	6834 877985	LYUDMILA KOROLEVA	{"phone": "+70536608257"}
0005434409480	5D31E5	6615 892388	VALENTINA DENISOVA	{"phone": "+70431755094"}
0005434409481	01B0A6	7893 577985	YULIYA BORISOVA	{"phone": "+70037019735"}
0005434409482	716D0E	9218 868076	NIKITA ORLOV	{"phone": "+70838074190"}
0005434409483	74621A	2744 728227	SERGEY ALEKSANDROV	{"phone": "+70608232046"}
0005434409484	E5A425	1283 463531	DAMIR NOVIKOV	{"phone": "+70398324620"}
0005434409485	E5A425	9162 449547	NINA YUDINA	{"phone": "+70163823480"}
0005434409486	E5A425	5013 737743	ANATOLIY KOZLOV	{"phone": "+70746786606"}
0005434409487	447953	9495 958914	ANNA POLYAKOVA	{"phone": "+70839130719"}
0005434409488	8D67FA	1688 553047	YURIY KOZLOV	{"email": "kozlov-yuriy.1970@postgrespro.ru", "phone": "+70636298649"}
0005434409489	8D67FA	7179 007109	VIKTOR STEPANOV	{"email": "stepanovv.02061973@postgrespro.ru", "phone": "+70723371412"}
0005434409490	8D67FA	9846 078073	VALENTINA KOROLEVA	{"phone": "+70903669167"}
0005434409491	8D67FA	8452 021381	SOFYA AFANASEVA	{"email": "afanaseva_sofya_13051975@postgrespro.ru", "phone": "+70370543597"}
0005434409492	F2FEA4	6705 604469	NADEZHDA KUZNECOVA	{"email": "kuznecova_n061971@postgrespro.ru", "phone": "+70245453075"}
0005434409493	151DE6	9033 133352	IGOR VASILEV	{"phone": "+70286937517"}
0005434409494	151DE6	1488 387865	NINA SAVELEVA	{"email": "saveleva.n_1972@postgrespro.ru", "phone": "+70020990332"}
0005434409495	4F0F48	5146 446253	TIMUR NIKOLAEV	{"email": "nikolaevtimur_19081963@postgrespro.ru", "phone": "+70488991500"}
0005434409496	EB1329	5235 682159	VERONIKA GORBUNOVA	{"email": "gorbunova_veronika-1971@postgrespro.ru", "phone": "+70531076263"}
0005434409497	9622F3	5868 598180	VIKTORIYA ROMANOVA	{"email": "v.romanova_08051969@postgrespro.ru", "phone": "+70086905208"}
0005434409498	71A2E6	5223 128276	ELENA KAZAKOVA	{"phone": "+70604556695"}
0005434409499	5D5800	8528 422515	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr_07091962@postgrespro.ru", "phone": "+70736070670"}
0005434409500	286185	4265 547394	ALIYA NIKOLAEVA	{"email": "a_nikolaeva.04031974@postgrespro.ru", "phone": "+70094585189"}
0005434409501	881922	5403 657337	IRINA POPOVA	{"phone": "+70804074125"}
0005434409502	F1ECD4	1627 989036	VALENTINA YAKOVLEVA	{"phone": "+70814385176"}
0005434409503	F1ECD4	3133 920410	IVAN FROLOV	{"phone": "+70929660039"}
0005434409504	86E343	1528 182043	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev.061971@postgrespro.ru", "phone": "+70647475593"}
0005434409505	FA0E00	2614 508696	RAISA NESTEROVA	{"phone": "+70561817640"}
0005434409506	FA0E00	4207 961578	NIKITA KAZAKOV	{"phone": "+70251108603"}
0005434409507	E5B7D1	6736 348692	NIKITA KRASNOV	{"email": "nikita.krasnov.19051974@postgrespro.ru", "phone": "+70707196298"}
0005434409508	3DE97B	3999 292006	ALEKSEY SAVELEV	{"email": "asavelev.031992@postgrespro.ru", "phone": "+70942848545"}
0005434409509	FE942F	2921 173309	ELENA CHERNOVA	{"email": "chernova.elena-1969@postgrespro.ru", "phone": "+70495898510"}
0005434409510	598561	1188 679411	ANDREY ZAKHAROV	{"phone": "+70149887608"}
0005434409511	598561	1702 002932	SVETLANA MEDVEDEVA	{"phone": "+70439085878"}
0005434409512	10C78D	3388 704677	ALEKSEY TIKHONOV	{"phone": "+70620713869"}
0005434409513	CCB7AA	6741 277765	MARINA ROMANOVA	{"phone": "+70154671148"}
0005434409514	6BE858	7286 777846	OKSANA NIKOLAEVA	{"email": "o.nikolaeva-12061974@postgrespro.ru", "phone": "+70606683299"}
0005434409515	6BE858	1398 086142	IRINA LOGINOVA	{"phone": "+70751159306"}
0005434409516	751445	6322 381008	VIKTOR ZAYCEV	{"email": "viktorzaycev-071977@postgrespro.ru", "phone": "+70056732357"}
0005434409517	463497	3750 848795	ANTONINA NIKIFOROVA	{"email": "nikiforovaa-16091963@postgrespro.ru", "phone": "+70545248636"}
0005434409518	463497	0630 046928	LEONID KARPOV	{"phone": "+70465414444"}
0005434409519	E34091	0397 451841	ALINA YAKOVLEVA	{"email": "alina-yakovleva1972@postgrespro.ru", "phone": "+70076748021"}
0005434409520	BA43BD	5589 251075	VLADIMIR MAKAROV	{"email": "makarovv_30041962@postgrespro.ru", "phone": "+70692066793"}
0005434409521	4C34D8	3344 617669	MARIYA SERGEEVA	{"email": "sergeeva-m1969@postgrespro.ru", "phone": "+70576769227"}
0005434409522	FA785E	8898 308928	ROMAN SCHERBAKOV	{"email": "scherbakov-roman-25101984@postgrespro.ru", "phone": "+70619034945"}
0005434409523	FA785E	8542 671515	ALEKSANDR VASILEV	{"phone": "+70687564801"}
0005434409524	FA785E	7786 038583	VIKTOR FEDOTOV	{"email": "vfedotov.101974@postgrespro.ru", "phone": "+70054544880"}
0005434409525	203074	9466 118049	ALEKSANDR AFANASEV	{"email": "afanasev-a.16041968@postgrespro.ru", "phone": "+70282539398"}
0005434409526	1CFB23	9127 748837	NIKOLAY BELOV	{"email": "nikolay-belov-031982@postgrespro.ru", "phone": "+70977197747"}
0005434409527	724C91	5049 638467	ZINAIDA SCHERBAKOVA	{"email": "scherbakova.z051976@postgrespro.ru", "phone": "+70694538634"}
0005434409528	A38AEA	0269 405254	NATALYA MATVEEVA	{"email": "matveeva.natalya-1972@postgrespro.ru", "phone": "+70497717438"}
0005434409529	D7D50E	1831 115736	ELENA FROLOVA	{"email": "frolova-elena_101966@postgrespro.ru", "phone": "+70615651733"}
0005434409530	1E8FE9	5585 407594	NATALYA KOZLOVA	{"phone": "+70382675730"}
0005434409531	2BEDB4	9523 042680	ROMAN TARASOV	{"email": "tarasovr.1968@postgrespro.ru", "phone": "+70685815150"}
0005434409532	2B478A	7370 072028	SERGEY NIKOLAEV	{"phone": "+70996085315"}
0005434409533	92B158	0531 954256	GRIGORIY MAKAROV	{"email": "grigoriy_makarov-16101958@postgrespro.ru", "phone": "+70321614661"}
0005434409534	07865B	5596 674013	ANASTASIYA KUZNECOVA	{"email": "kuznecova_anastasiya-1971@postgrespro.ru", "phone": "+70106214409"}
0005434409535	487BA1	8161 110712	ALINA SERGEEVA	{"email": "alinasergeeva_1969@postgrespro.ru", "phone": "+70054564519"}
0005434409536	1548BA	4769 519367	SOFIYA PAVLOVA	{"phone": "+70951636199"}
0005434409537	1548BA	6777 106298	DENIS ALEKSEEV	{"email": "alekseev.d.121971@postgrespro.ru", "phone": "+70454519048"}
0005434409538	DFA08C	3817 473094	VALERIYA GAVRILOVA	{"email": "gavrilovavaleriya-091965@postgrespro.ru", "phone": "+70611366004"}
0005434409539	DFA08C	5996 203147	IGOR MEDVEDEV	{"email": "imedvedev-01011968@postgrespro.ru", "phone": "+70527774863"}
0005434409540	2B9D61	1365 250665	NATALYA STEPANOVA	{"email": "stepanova-natalya1973@postgrespro.ru", "phone": "+70151774456"}
0005434409541	2B9D61	7113 299935	KONSTANTIN SOROKIN	{"email": "sorokin-konstantin.23091965@postgrespro.ru", "phone": "+70417463126"}
0005434409542	2B9D61	9086 102098	SVETLANA SERGEEVA	{"phone": "+70378379844"}
0005434409543	10CF12	9551 178482	KRISTINA ANISIMOVA	{"phone": "+70124425030"}
0005434409544	960CC9	7175 280139	AYRAT SIDOROV	{"email": "sidorova_24061978@postgrespro.ru", "phone": "+70575291878"}
0005434409545	48A5B7	0216 606699	OLGA MALYSHEVA	{"email": "o.malysheva051980@postgrespro.ru", "phone": "+70422699184"}
0005434409546	DA09BC	3991 245139	GENNADIY KRASNOV	{"email": "krasnov-gennadiy.101966@postgrespro.ru", "phone": "+70043362932"}
0005434409547	84F716	0104 320444	ANNA MOROZOVA	{"email": "anna-morozova_1973@postgrespro.ru", "phone": "+70299557420"}
0005434409548	84F716	6807 287779	MIKHAIL TIKHONOV	{"email": "tikhonov_m_05021980@postgrespro.ru", "phone": "+70885060933"}
0005434409549	6A5C61	5201 683467	NADEZHDA BARANOVA	{"email": "n-baranova_051961@postgrespro.ru", "phone": "+70124498669"}
0005434409550	6A5C61	6326 189836	ALEKSANDR TIKHONOV	{"email": "a_tikhonov081975@postgrespro.ru", "phone": "+70436187890"}
0005434409551	6AF830	6115 062053	IGOR MEDVEDEV	{"email": "igormedvedev-20021972@postgrespro.ru", "phone": "+70129038498"}
0005434409552	E50C97	8417 545054	EVGENIY KUZNECOV	{"phone": "+70437075251"}
0005434409553	0D26B5	0031 396433	ALEKSANDRA GUSEVA	{"email": "guseva-a021978@postgrespro.ru", "phone": "+70331668192"}
0005434409554	F54A4B	6281 059365	ANASTASIYA KOZLOVA	{"phone": "+70511236670"}
0005434409555	F54A4B	3843 773139	KIRA FILATOVA	{"email": "k_filatova19121985@postgrespro.ru", "phone": "+70382340678"}
0005434409556	2C4A75	4725 696699	NINA FEDOROVA	{"phone": "+70613206290"}
0005434409557	2C4A75	4391 199062	SERGEY ABRAMOV	{"phone": "+70053684609"}
0005434409558	1822B8	1300 165088	ALEKSANDR KAZAKOV	{"email": "kazakov.a-04111963@postgrespro.ru", "phone": "+70204960430"}
0005434409559	B67E20	4482 709699	IRINA GUSEVA	{"phone": "+70349418083"}
0005434409560	B67E20	9393 382398	VITALIY ANDREEV	{"email": "andreev_vitaliy_111973@postgrespro.ru", "phone": "+70885816580"}
0005434409561	AB0CFE	9393 895100	EKATERINA TIKHONOVA	{"phone": "+70449526465"}
0005434409562	A1DDD7	0534 888322	VLADIMIR KUZNECOV	{"email": "kuznecov.v1975@postgrespro.ru", "phone": "+70944293587"}
0005434409563	A1DDD7	5760 364485	EVGENIY IVANOV	{"email": "ivanov-evgeniy27121977@postgrespro.ru", "phone": "+70112568796"}
0005434409564	F8B7D3	7268 123303	ELENA ZAKHAROVA	{"email": "e-zakharova-071983@postgrespro.ru", "phone": "+70469364029"}
0005434409565	F8B7D3	7370 847229	VASILIY DAVYDOV	{"email": "vasiliydavydov09061980@postgrespro.ru", "phone": "+70098412464"}
0005434409566	78D81D	9994 331966	BOGDAN SCHERBAKOV	{"email": "bogdan-scherbakov-03121976@postgrespro.ru", "phone": "+70605007483"}
0005434409567	38A69B	5931 855830	KONSTANTIN NIKOLAEV	{"phone": "+70112385170"}
0005434409568	E8800E	8216 276062	ANTON STEPANOV	{"email": "stepanov.a-14101970@postgrespro.ru", "phone": "+70501572738"}
0005434409569	AD84C1	2888 284949	VERA SEMENOVA	{"email": "semenova.vera_1971@postgrespro.ru", "phone": "+70536022040"}
0005434409570	2E8BB4	4871 558323	VERA LEBEDEVA	{"email": "v_lebedeva101969@postgrespro.ru", "phone": "+70361212164"}
0005434409571	8001A0	6347 855534	NINA SOROKINA	{"phone": "+70452156964"}
0005434409572	8001A0	0725 176374	LIDIYA VOLKOVA	{"email": "lidiya.volkova_031972@postgrespro.ru", "phone": "+70965276566"}
0005434409573	167964	8980 408307	VASILIY MIKHAYLOV	{"email": "vasiliy_mikhaylov.16111987@postgrespro.ru", "phone": "+70241421104"}
0005434409574	51DF34	2418 676257	PAVEL VOLKOV	{"email": "p.volkov.1970@postgrespro.ru", "phone": "+70602566374"}
0005434409575	4CEA96	7048 650769	VALENTINA MELNIKOVA	{"phone": "+70759832115"}
0005434409576	9E0D12	6652 798086	ALENA ZHUKOVA	{"phone": "+70961787139"}
0005434409577	6D8E0C	9480 256317	DMITRIY ALEKSANDROV	{"phone": "+70157572173"}
0005434409578	82E306	5809 501299	RAISA POPOVA	{"email": "popova_r_091965@postgrespro.ru", "phone": "+70109045919"}
0005434409579	BCBB04	6596 998303	ARTEMIY SOLOVEV	{"email": "solovev_a.1977@postgrespro.ru", "phone": "+70927512256"}
0005434409580	BCBB04	0426 103853	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov.1967@postgrespro.ru", "phone": "+70723766058"}
0005434409581	678E14	1462 512224	VALENTINA BARANOVA	{"phone": "+70341435793"}
0005434409582	678E14	9768 821062	ALEKSANDR ILIN	{"email": "ilin_a1965@postgrespro.ru", "phone": "+70534074026"}
0005434409583	E022AC	5462 309654	ANDREY PAVLOV	{"phone": "+70100143707"}
0005434409584	06963F	8185 678749	ANDREY SERGEEV	{"phone": "+70939006137"}
0005434409585	06963F	8949 586933	VALERIYA KALININA	{"phone": "+70344728835"}
0005434409586	F303B9	0793 314456	IVAN SCHERBAKOV	{"phone": "+70765395081"}
0005434409587	C59F6E	5004 690110	LIDIYA SOKOLOVA	{"email": "sokoloval.1974@postgrespro.ru", "phone": "+70872460446"}
0005434409588	573A45	9359 570208	SOFIYA ILINA	{"phone": "+70625825914"}
0005434409589	573A45	8292 257011	ANATOLIY SIDOROV	{"email": "anatoliy.sidorov.1972@postgrespro.ru", "phone": "+70657061419"}
0005434409590	D019D4	3620 895153	RUSTAM MAKSIMOV	{"email": "maksimov_rustam28031978@postgrespro.ru", "phone": "+70444776786"}
0005434409591	5E4F64	5748 193681	IVAN KULIKOV	{"phone": "+70612608130"}
0005434409592	4D342C	6146 772351	YULIYA MELNIKOVA	{"phone": "+70479741931"}
0005434409593	5176E7	0359 976353	EVGENIYA EFIMOVA	{"email": "evgeniya-efimova011979@postgrespro.ru", "phone": "+70148607301"}
0005434409594	83F8FD	7257 253570	IVAN ABRAMOV	{"email": "abramov-i_1966@postgrespro.ru", "phone": "+70917542366"}
0005434409595	83F8FD	0467 746484	SERGEY FOMIN	{"phone": "+70719986444"}
0005434409596	68237B	7134 080860	ROMAN GORBUNOV	{"email": "gorbunov.r_06111984@postgrespro.ru", "phone": "+70817653078"}
0005434409597	68237B	1355 177496	ANTON GUSEV	{"phone": "+70997898226"}
0005434409598	FD8D49	5840 284002	MARGARITA LUKYANOVA	{"email": "m_lukyanova_1974@postgrespro.ru", "phone": "+70539730308"}
0005434409599	FD8D49	0706 150382	ANASTASIYA EFIMOVA	{"email": "efimovaanastasiya.07051976@postgrespro.ru", "phone": "+70366946148"}
0005434409600	5816B7	0717 820257	ANZHELIKA LAZAREVA	{"phone": "+70712038412"}
0005434409601	7D7641	0721 475025	ALEKSEY IVANOV	{"email": "alekseyivanov-031974@postgrespro.ru", "phone": "+70273910343"}
0005434409602	A5540A	5547 970046	VYACHESLAV KUZNECOV	{"email": "v_kuznecov_051968@postgrespro.ru", "phone": "+70533672945"}
0005434409603	A69627	5920 573560	YURIY GERASIMOV	{"email": "ygerasimov.1962@postgrespro.ru", "phone": "+70507482716"}
0005434409604	A69627	8858 914820	IRINA YAKOVLEVA	{"email": "yakovleva-i-07091965@postgrespro.ru", "phone": "+70362159005"}
0005434409605	1856AE	8855 765040	ALEKSANDR VLASOV	{"phone": "+70173988066"}
0005434409606	0F7065	8941 800660	GALINA LEBEDEVA	{"email": "galinalebedeva.071970@postgrespro.ru", "phone": "+70280617332"}
0005434409607	E4531F	4548 702904	YURIY NOVIKOV	{"email": "novikov_y_041974@postgrespro.ru", "phone": "+70564626025"}
0005434409608	E4531F	2295 971767	DMITRIY ISAEV	{"phone": "+70079015034"}
0005434409609	4C4C57	5495 278892	TATYANA KONOVALOVA	{"email": "t_konovalova_20061971@postgrespro.ru", "phone": "+70379902400"}
0005434409610	4C4C57	7649 698217	TATYANA SOLOVEVA	{"email": "t.soloveva05041967@postgrespro.ru", "phone": "+70835418759"}
0005434409611	C9F992	8637 652015	VLADIMIR NIKOLAEV	{"phone": "+70802726846"}
0005434409612	591EE6	1684 316928	SERGEY FILIPPOV	{"email": "filippov-s-121970@postgrespro.ru", "phone": "+70770827105"}
0005434409613	1D0CB6	3494 183586	NINA SIDOROVA	{"phone": "+70429881450"}
0005434409614	1D0CB6	3140 982412	OLGA OSIPOVA	{"phone": "+70646337479"}
0005434409615	3DF7AA	6601 744913	ARTEM MARTYNOV	{"phone": "+70200248829"}
0005434409616	3DF7AA	2531 927639	VIKTOR FROLOV	{"phone": "+70882941642"}
0005434409617	5DDBCF	1115 522243	VALENTINA KUZMINA	{"email": "valentina.kuzmina1978@postgrespro.ru", "phone": "+70371340873"}
0005434409618	5DDBCF	3537 216979	OLGA OVCHINNIKOVA	{"email": "olga.ovchinnikova_1976@postgrespro.ru", "phone": "+70523698748"}
0005434409619	5DDBCF	1124 988555	EVGENIYA YUDINA	{"email": "yudina.e051968@postgrespro.ru", "phone": "+70607267498"}
0005434411701	3A2D99	8359 958255	NATALYA FILIPPOVA	{"email": "nfilippova.021973@postgrespro.ru", "phone": "+70395571010"}
0005434411702	A2F3D6	4013 404442	VLADIMIR STEPANOV	{"phone": "+70612458419"}
0005434411703	690903	8505 783313	ANTON GUSEV	{"phone": "+70311289563"}
0005434411704	344545	9974 747518	KRISTINA KUDRYASHOVA	{"email": "k.kudryashova_1982@postgrespro.ru", "phone": "+70332879686"}
0005434411705	4A6D06	3647 234313	RINAT MOISEEV	{"phone": "+70103356235"}
0005434411706	4A6D06	0074 921717	MARINA STEPANOVA	{"email": "mstepanova1969@postgrespro.ru", "phone": "+70634572162"}
0005434411707	775712	1512 604840	VLADISLAV TIMOFEEV	{"email": "timofeev_vladislav.20011977@postgrespro.ru", "phone": "+70668437719"}
0005434411708	336CF1	4721 949522	NATALYA SIDOROVA	{"phone": "+70497990049"}
0005434411709	A156C0	2674 351130	LARISA AKIMOVA	{"email": "larisa_akimova1971@postgrespro.ru", "phone": "+70318052523"}
0005434411710	D0099D	5940 021452	VALENTINA NIKITINA	{"email": "nikitina-v051974@postgrespro.ru", "phone": "+70988507930"}
0005434411711	D0099D	9780 025024	VADIM MATVEEV	{"phone": "+70754441657"}
0005434411712	E714CC	4030 270947	ANNA TIMOFEEVA	{"email": "timofeevaa1969@postgrespro.ru", "phone": "+70003137929"}
0005434411713	50976F	1030 555719	DARYA IVANOVA	{"email": "ivanovadarya10091984@postgrespro.ru", "phone": "+70389190502"}
0005434411714	50976F	9123 869616	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov1971@postgrespro.ru", "phone": "+70823913887"}
0005434411715	742BFB	4132 362408	ANASTASIYA MIRONOVA	{"email": "mironova-a19011970@postgrespro.ru", "phone": "+70257835061"}
0005434411716	3B26DE	0090 446180	VALERIY FEDOROV	{"email": "fedorov.v.29121966@postgrespro.ru", "phone": "+70531915193"}
0005434411717	44052D	7761 200049	ANASTASIYA IVANOVA	{"email": "anastasiyaivanova_1971@postgrespro.ru", "phone": "+70786745058"}
0005434411718	C3C276	0710 464903	MARINA NOVIKOVA	{"phone": "+70403375061"}
0005434411719	9B9A02	8379 030131	VALENTINA GORBUNOVA	{"email": "vgorbunova-1980@postgrespro.ru", "phone": "+70030336211"}
0005434411720	463446	7858 967292	ANATOLIY KUZMIN	{"phone": "+70751024744"}
0005434411721	463446	1277 032164	YURIY ZAKHAROV	{"phone": "+70581662223"}
0005434411722	99613C	9060 781756	ANATOLIY RODIONOV	{"phone": "+70769010266"}
0005434411723	99613C	5863 426968	VLADIMIR CHERNOV	{"email": "v-chernov_03081971@postgrespro.ru", "phone": "+70644927753"}
0005434411724	A3D1F8	4742 333963	NATALYA TIKHONOVA	{"phone": "+70393453463"}
0005434411725	7531B2	9691 031753	YURIY PETROV	{"email": "yuriy.petrov101967@postgrespro.ru", "phone": "+70083077844"}
0005434411726	2F1343	2145 742824	SERGEY VASILEV	{"phone": "+70254965777"}
0005434411727	6584E1	5651 005510	STANISLAV MELNIKOV	{"phone": "+70376673344"}
0005434411728	CD8F1F	7954 038984	ANASTASIYA FILATOVA	{"email": "filatova.anastasiya1972@postgrespro.ru", "phone": "+70508642708"}
0005434411729	CD8F1F	6621 396612	ALEKSANDR GORBUNOV	{"email": "gorbunova-24071983@postgrespro.ru", "phone": "+70724385177"}
0005434411730	A6F8AA	5849 404863	EVGENIY FEDOROV	{"phone": "+70575762056"}
0005434411731	E20105	2963 752765	ANATOLIY ILIN	{"email": "a.ilin_1977@postgrespro.ru", "phone": "+70460400043"}
0005434411732	C1B84B	7626 398745	ALEKSEY SOLOVEV	{"email": "a-solovev1981@postgrespro.ru", "phone": "+70722089628"}
0005434411733	C1B84B	8038 494468	ANDREY SEMENOV	{"phone": "+70190347463"}
0005434411734	99526A	1521 126010	VALENTINA IVANOVA	{"email": "v.ivanova.111968@postgrespro.ru", "phone": "+70284489293"}
0005434411735	B47F26	6759 463578	NADEZHDA GAVRILOVA	{"email": "gavrilova.nadezhda_10071981@postgrespro.ru", "phone": "+70592058998"}
0005434411792	E466AF	7711 664681	IVAN SAVELEV	{"phone": "+70984864462"}
0005434411736	B47F26	0047 505506	NATALYA SIDOROVA	{"email": "sidorova_n-1968@postgrespro.ru", "phone": "+70350890433"}
0005434411737	73ED17	2892 990878	EVGENIY BARANOV	{"phone": "+70311208804"}
0005434411738	9A188C	4911 787782	ELENA NIKITINA	{"phone": "+70404845172"}
0005434411739	33EBB1	3456 655908	KARINA MIKHAYLOVA	{"email": "mikhaylova-karina_061974@postgrespro.ru", "phone": "+70592145208"}
0005434411740	33EBB1	7130 410283	RAISA EGOROVA	{"email": "egorovaraisa081974@postgrespro.ru", "phone": "+70734452240"}
0005434411741	CDE310	1123 958969	NADEZHDA FILIPPOVA	{"email": "nadezhda.filippova_25031967@postgrespro.ru", "phone": "+70217687172"}
0005434411742	00ABE4	5346 678623	ANASTASIYA FILATOVA	{"phone": "+70831247268"}
0005434411743	48144B	5134 128726	ANATOLIY BARANOV	{"phone": "+70673847151"}
0005434411744	16052D	8917 726176	RUSTAM KULIKOV	{"phone": "+70908204503"}
0005434411745	F811AF	9741 166371	IVAN MAKSIMOV	{"email": "maksimov_ivan.04061966@postgrespro.ru", "phone": "+70849511833"}
0005434411746	E100A4	2255 336450	VLADIMIR MATVEEV	{"phone": "+70013143401"}
0005434411747	1E374E	8178 609556	NATALYA IVANOVA	{"email": "natalya_ivanova021982@postgrespro.ru", "phone": "+70650666857"}
0005434411748	97722A	9633 162727	ALEKSANDR ANDREEV	{"phone": "+70210448845"}
0005434411749	01F352	1487 192821	ELENA ZOTOVA	{"phone": "+70205043948"}
0005434411750	FD7BB1	1396 876322	EVGENIYA SMIRNOVA	{"email": "evgeniya.smirnova_051987@postgrespro.ru", "phone": "+70197842487"}
0005434411751	8E81CB	5481 058519	MARIYA TARASOVA	{"phone": "+70668322790"}
0005434411752	8E81CB	6117 002675	NATALYA FILIPPOVA	{"phone": "+70732824593"}
0005434411753	8E81CB	9459 365544	ANNA OVCHINNIKOVA	{"email": "ovchinnikova_anna.081971@postgrespro.ru", "phone": "+70800477284"}
0005434411754	652DAA	2778 353472	GALINA KOMAROVA	{"phone": "+70122693637"}
0005434411755	77117C	2867 075835	LYUBOV BELYAEVA	{"email": "lyubov-belyaeva_1963@postgrespro.ru", "phone": "+70827192641"}
0005434411756	77117C	5773 174761	NATALIYA NOVIKOVA	{"phone": "+70772209569"}
0005434411757	608031	7364 534398	OLGA MIKHAYLOVA	{"phone": "+70176036721"}
0005434411758	529F9A	7797 569995	ELENA OSIPOVA	{"email": "e_osipova.08101973@postgrespro.ru", "phone": "+70311774714"}
0005434411759	529F9A	7768 688944	ALEKSANDR POPOV	{"phone": "+70030897553"}
0005434411760	A12746	3627 594772	OLEG GAVRILOV	{"email": "gavrilovoleg-19091987@postgrespro.ru", "phone": "+70160063448"}
0005434411761	A12746	6195 018659	VLADIMIR ROMANOV	{"phone": "+70927154563"}
0005434411762	E402B7	2485 212972	ALEKSEY BARANOV	{"phone": "+70209845569"}
0005434411763	E402B7	0654 534214	VALENTINA MOISEEVA	{"phone": "+70792416815"}
0005434411764	85F924	5356 552319	NATALYA NIKOLAEVA	{"phone": "+70937280921"}
0005434411765	971BAC	2130 440826	MARIYA KISELEVA	{"phone": "+70329265342"}
0005434411766	4E6DE5	0773 367305	MIKHAIL VOLKOV	{"email": "volkov_m.031973@postgrespro.ru", "phone": "+70564577559"}
0005434411767	4E6DE5	5789 610856	DMITRIY MIRONOV	{"phone": "+70175237504"}
0005434411768	775775	5369 440863	VLADIMIR IVANOV	{"email": "ivanov_v.091972@postgrespro.ru", "phone": "+70984871469"}
0005434411769	F97695	7130 965799	LYUDMILA KUZMINA	{"email": "kuzmina.lyudmila.29091966@postgrespro.ru", "phone": "+70115784648"}
0005434411770	F97695	2976 020776	ALEKSANDR MAKAROV	{"email": "makarov_a-061971@postgrespro.ru", "phone": "+70455095408"}
0005434411771	71E7C2	0046 047300	TATYANA NIKIFOROVA	{"email": "nikiforova.t_061974@postgrespro.ru", "phone": "+70876851847"}
0005434411772	7934F3	3731 107646	DMITRIY MAKAROV	{"phone": "+70800547436"}
0005434411773	7934F3	4276 634569	ANATOLIY BELOV	{"email": "abelov-121972@postgrespro.ru", "phone": "+70596968239"}
0005434411774	DF83A8	5269 421405	MIKHAIL KUZNECOV	{"email": "m_kuznecov-1962@postgrespro.ru", "phone": "+70553949877"}
0005434411775	1A448D	4286 664812	VALENTIN ANDREEV	{"email": "andreev-v-26061979@postgrespro.ru", "phone": "+70237054291"}
0005434411776	43384E	9905 199572	SERGEY OSIPOV	{"email": "osipov_s20101962@postgrespro.ru", "phone": "+70400171420"}
0005434411777	FF37FC	1336 242292	ANDREY VLASOV	{"email": "avlasov.071974@postgrespro.ru", "phone": "+70469215964"}
0005434411778	8D9822	9683 131777	ARTUR KUZNECOV	{"email": "kuznecovartur.091978@postgrespro.ru", "phone": "+70144742888"}
0005434411779	52B06E	4439 733369	NATALYA NAZAROVA	{"email": "natalya.nazarova-011974@postgrespro.ru", "phone": "+70592820785"}
0005434411780	46CB91	6336 260389	RAILYA GRISHINA	{"email": "grishina_r1964@postgrespro.ru", "phone": "+70291451418"}
0005434411781	B115CB	8792 530113	VASILIY MIKHAYLOV	{"email": "vmikhaylov-1982@postgrespro.ru", "phone": "+70088749281"}
0005434411782	3E5309	2454 762385	DMITRIY RODIONOV	{"phone": "+70129225828"}
0005434411783	61C7FD	6119 928405	ANDREY ZAKHAROV	{"phone": "+70363907603"}
0005434411784	D07229	4195 237315	LEONID ALEKSEEV	{"phone": "+70144920137"}
0005434411785	9C5219	0803 759110	ALEKSANDRA GRISHINA	{"phone": "+70513972096"}
0005434411786	9C5219	2511 673526	ALMIRA PAVLOVA	{"email": "pavlovaalmira1970@postgrespro.ru", "phone": "+70063693643"}
0005434411787	1A4A46	3715 193175	TAMARA ZAKHAROVA	{"email": "zakharova-t-1979@postgrespro.ru", "phone": "+70775755655"}
0005434411788	4EDDEB	2471 858926	DMITRIY PETROV	{"email": "petrov.d.1957@postgrespro.ru", "phone": "+70606918264"}
0005434411789	8C7B40	5664 056977	NIKOLAY IVANOV	{"email": "n.ivanov061983@postgrespro.ru", "phone": "+70684619724"}
0005434411790	35E30B	3745 193748	MARIYA NIKITINA	{"email": "nikitina.mariya-081975@postgrespro.ru", "phone": "+70941830818"}
0005434411791	35E30B	6353 006087	VYACHESLAV ROMANOV	{"phone": "+70358674725"}
0005434411793	EA0AE4	7669 961318	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr-061966@postgrespro.ru", "phone": "+70368142659"}
0005434411794	0B986D	6119 783719	SVETLANA LAZAREVA	{"email": "s_lazareva-1973@postgrespro.ru", "phone": "+70586474198"}
0005434411795	4B3ADB	4850 185871	RUSLAN ZAYCEV	{"email": "zaycev-ruslan04101975@postgrespro.ru", "phone": "+70318792457"}
0005434411796	6F41D0	1342 061495	ALENA MIRONOVA	{"phone": "+70447371396"}
0005434411797	541116	8496 090331	VARVARA ROMANOVA	{"phone": "+70583910264"}
0005434411798	BDB016	5408 951467	OLGA SOROKINA	{"phone": "+70236149601"}
0005434411799	F0B33F	5895 288296	RAISA NAZAROVA	{"phone": "+70763338939"}
0005434411800	395898	0392 049655	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda.121984@postgrespro.ru", "phone": "+70542903712"}
0005434411801	8E719E	4878 530672	GRIGORIY OSIPOV	{"email": "osipov-grigoriy091963@postgrespro.ru", "phone": "+70507939763"}
0005434411802	BB8287	1762 749808	ALEKSANDR ZHURAVLEV	{"phone": "+70089387128"}
0005434411803	BB8287	4902 428676	TAMARA TIKHONOVA	{"email": "tikhonovatamara.30101966@postgrespro.ru", "phone": "+70018958639"}
0005434411804	4E944B	6108 688650	SERGEY TIMOFEEV	{"email": "timofeev_s051977@postgrespro.ru", "phone": "+70897618841"}
0005434411805	13DCF0	6946 695853	IVAN EGOROV	{"email": "egorovivan.1977@postgrespro.ru", "phone": "+70204405665"}
0005434411806	13DCF0	0774 155785	SERGEY CHERNOV	{"email": "chernovsergey.011973@postgrespro.ru", "phone": "+70246126293"}
0005434411807	5AB98A	0730 300651	DENIS PAVLOV	{"email": "d_pavlov-011972@postgrespro.ru", "phone": "+70582801709"}
0005434411808	34345B	7325 293912	SERGEY ROMANOV	{"phone": "+70159481980"}
0005434411809	34345B	2020 224300	SERGEY MIRONOV	{"phone": "+70420590172"}
0005434411810	8653FB	8569 370481	LILIYA ERMAKOVA	{"phone": "+70667017651"}
0005434411811	2360E8	9597 855905	ALEKSANDR MIKHAYLOV	{"phone": "+70427991598"}
0005434411812	681CFC	9941 905696	KSENIYA MAKAROVA	{"email": "makarova_kseniya-1963@postgrespro.ru", "phone": "+70782694650"}
0005434411813	681CFC	3801 510208	RUSLAN MARTYNOV	{"email": "rmartynov.1971@postgrespro.ru", "phone": "+70586142121"}
0005434411814	26D60E	5431 755514	MAKSIM GUSEV	{"email": "maksim-gusev-041965@postgrespro.ru", "phone": "+70761439178"}
0005434411815	489348	1207 590599	ANASTASIYA ALEKSEEVA	{"email": "a_alekseeva-1975@postgrespro.ru", "phone": "+70067814376"}
0005434411816	489348	4380 658675	MARIYA SOKOLOVA	{"phone": "+70246551157"}
0005434411817	489348	8892 310413	VLADIMIR SOKOLOV	{"phone": "+70692184589"}
0005434411818	6899E5	3436 888229	IVAN SOKOLOV	{"email": "sokolovi_23101970@postgrespro.ru", "phone": "+70781123473"}
0005434411819	CE0B66	1850 053599	ELENA KAZAKOVA	{"email": "kazakova_e.011961@postgrespro.ru", "phone": "+70565944509"}
0005434411820	098F6C	2381 045096	ANNA SAVELEVA	{"email": "a_saveleva-011976@postgrespro.ru", "phone": "+70158698093"}
0005434411821	4475F6	6708 132058	VLADIMIR ALEKSANDROV	{"email": "aleksandrov.v021971@postgrespro.ru", "phone": "+70943373012"}
0005434411822	F75D7E	0017 371047	ALEKSANDR VLASOV	{"email": "vlasov.a_30121951@postgrespro.ru", "phone": "+70131366156"}
0005434411823	F75D7E	3684 864276	OLGA KULIKOVA	{"phone": "+70322524935"}
0005434411824	BAB683	0023 655687	EVGENIY MAKAROV	{"email": "makarov.evgeniy.081981@postgrespro.ru", "phone": "+70516761653"}
0005434411825	BAB683	2234 180027	SERGEY SOKOLOV	{"phone": "+70983431576"}
0005434411826	D92CE8	4596 576803	TATYANA KISELEVA	{"phone": "+70049336416"}
0005434411827	019240	5889 452998	MARINA SMIRNOVA	{"email": "marina-smirnova-09101968@postgrespro.ru", "phone": "+70837049201"}
0005434411828	9CB2E6	0088 343223	ANDREY SOROKIN	{"phone": "+70882134575"}
0005434411829	9CB2E6	0593 774192	OLGA KUZNECOVA	{"email": "olga.kuznecova.1971@postgrespro.ru", "phone": "+70621705272"}
0005434411830	F93C5C	6595 597645	RUSLAN FILIPPOV	{"phone": "+70914797950"}
0005434411831	38AB6F	3916 176989	YURIY NOVIKOV	{"phone": "+70216310004"}
0005434411832	5648EA	4471 690660	RIMMA YUDINA	{"phone": "+70632711959"}
0005434411833	2FB260	7830 178385	VLADIMIR FOMIN	{"email": "vladimirfomin-13051976@postgrespro.ru", "phone": "+70114489088"}
0005434411834	C6F4F1	7203 854534	ALEKSEY CHERNOV	{"phone": "+70822812937"}
0005434411835	C6F4F1	4457 764396	GENNADIY MATVEEV	{"email": "matveev.gennadiy_16101966@postgrespro.ru", "phone": "+70136646421"}
0005434411836	5D55D6	0814 037925	PAVEL KOZLOV	{"email": "pavel_kozlov031959@postgrespro.ru", "phone": "+70456159328"}
0005434411837	3A0356	9329 830107	MARIYA ZHUKOVA	{"phone": "+70387108562"}
0005434411838	F18073	5563 919268	VERA VASILEVA	{"phone": "+70408013348"}
0005434411839	F18073	2842 657126	IVAN ANTONOV	{"phone": "+70049778264"}
0005434411840	240BC3	4280 383653	MARIYA SOKOLOVA	{"email": "m-sokolova.1975@postgrespro.ru", "phone": "+70905185398"}
0005434411841	240BC3	8332 041964	MIKHAIL EGOROV	{"phone": "+70068571400"}
0005434411842	5EBD5E	2086 958640	MARGARITA NOVIKOVA	{"phone": "+70363068580"}
0005434411843	8ACC06	0406 475604	DMITRIY GUSEV	{"email": "dmitriygusev_07011979@postgrespro.ru", "phone": "+70338279619"}
0005434411844	D725CE	4253 122067	EVGENIY BONDARENKO	{"phone": "+70970271361"}
0005434411845	16D91D	6167 104003	IRINA IVANOVA	{"phone": "+70822574793"}
0005434411846	16D91D	5198 579885	ALEKSANDRA TARASOVA	{"email": "a-tarasova-011978@postgrespro.ru", "phone": "+70601805539"}
0005434411847	EB8B29	4478 434517	ANDREY SAVELEV	{"phone": "+70990278025"}
0005434411848	8C6B88	5112 602669	RAMIL MIRONOV	{"email": "mironov.ramil1973@postgrespro.ru", "phone": "+70534935854"}
0005434411849	8C6B88	0909 308890	ALEKSANDR ORLOV	{"email": "aorlov.1986@postgrespro.ru", "phone": "+70281854624"}
0005434411850	6ACB0A	6835 283463	MARIYA STEPANOVA	{"phone": "+70073707626"}
0005434411851	6ACB0A	8567 087051	LYUBOV ZHUKOVA	{"phone": "+70392078767"}
0005434411852	85FFC5	3592 611396	KAMIL SERGEEV	{"phone": "+70670866445"}
0005434411853	E708C4	4466 493702	ROMAN KOROLEV	{"email": "korolev.r_011966@postgrespro.ru", "phone": "+70178635305"}
0005434411854	7A29AA	6422 158297	OLGA SOROKINA	{"email": "o-sorokina_031967@postgrespro.ru", "phone": "+70482385012"}
0005434411855	D54421	1302 137798	MAKSIM ABRAMOV	{"email": "abramov-m.111979@postgrespro.ru", "phone": "+70695353539"}
0005434411856	7D753A	4434 651920	IRINA VLASOVA	{"email": "i_vlasova.1973@postgrespro.ru", "phone": "+70393202070"}
0005434411857	075898	0728 465930	MIKHAIL KUZNECOV	{"phone": "+70435899040"}
0005434411858	59E161	6252 916236	ZINAIDA NIKOLAEVA	{"phone": "+70762475688"}
0005434411859	477D0B	3438 504234	VLADIMIR FROLOV	{"phone": "+70958856221"}
0005434411860	F18B63	3085 932760	VIKTOR VASILEV	{"phone": "+70125957973"}
0005434411861	031CDF	0710 662063	ALEKSANDRA TIMOFEEVA	{"email": "aleksandra_timofeeva1980@postgrespro.ru", "phone": "+70738857459"}
0005434411862	5D1D5B	2084 189627	EGOR EGOROV	{"phone": "+70657094422"}
0005434411863	5D1D5B	0592 797687	ALENA SEMENOVA	{"email": "a_semenova101970@postgrespro.ru", "phone": "+70646398504"}
0005434411864	1C2D66	0470 732296	ALEKSEY MAKAROV	{"email": "a_makarov.1975@postgrespro.ru", "phone": "+70498975777"}
0005434411865	67746B	9247 766023	ZINAIDA MASLOVA	{"email": "maslova-z-18091973@postgrespro.ru", "phone": "+70721113700"}
0005434411866	67746B	2342 456294	NIKITA FILIPPOV	{"email": "filippov-nikita_09011970@postgrespro.ru", "phone": "+70407029644"}
0005434411867	67746B	8758 675755	RINAT SEMENOV	{"email": "semenov_rinat_1974@postgrespro.ru", "phone": "+70757857362"}
0005434411868	A0A3E3	7905 828322	NATALIYA FADEEVA	{"phone": "+70595706324"}
0005434411869	5033EA	7307 772412	BORIS IVANOV	{"phone": "+70988650609"}
0005434411870	5033EA	1978 825935	DARYA SOROKINA	{"email": "sorokina_d_24121965@postgrespro.ru", "phone": "+70948651135"}
0005434411871	9B4A54	0897 079793	ANDREY PAVLOV	{"email": "pavlov.andrey-1974@postgrespro.ru", "phone": "+70150584565"}
0005434411872	44CE34	3084 915180	MARINA KUZNECOVA	{"email": "marina_kuznecova-12071967@postgrespro.ru", "phone": "+70004496757"}
0005434411873	44CE34	1595 846562	IGOR BARANOV	{"email": "baranovigor_1971@postgrespro.ru", "phone": "+70784846267"}
0005434411874	F082F1	4055 857329	NIKOLAY KUZNECOV	{"phone": "+70546854995"}
0005434411875	276A6F	2911 469182	TAMARA VLASOVA	{"phone": "+70765499898"}
0005434411876	276A6F	7812 142637	ANNA AKIMOVA	{"email": "akimova-anna-1981@postgrespro.ru", "phone": "+70865003808"}
0005434411877	77A6C9	7314 840577	IRINA FEDOROVA	{"email": "fedorova.irina1971@postgrespro.ru", "phone": "+70622287921"}
0005434411878	77A6C9	7355 205034	VERA ZHURAVLEVA	{"email": "zhuravleva.v-11111960@postgrespro.ru", "phone": "+70421663827"}
0005434411879	054988	8355 210033	IGOR NIKITIN	{"phone": "+70479349592"}
0005434411880	BE0A09	2405 791558	ANASTASIYA DENISOVA	{"phone": "+70463459512"}
0005434411881	175A93	3119 319523	NIKITA ANTONOV	{"phone": "+70250785306"}
0005434411882	579843	8509 397530	SERGEY STEPANOV	{"email": "sstepanov.1981@postgrespro.ru", "phone": "+70627038145"}
0005434411883	3D2407	3776 170455	DARYA ALEKSANDROVA	{"email": "aleksandrova_d-1976@postgrespro.ru", "phone": "+70556733847"}
0005434411884	8F4194	5354 367064	RUSTAM VLASOV	{"email": "vlasov_rustam.051979@postgrespro.ru", "phone": "+70319022170"}
0005434411885	8F4194	5571 456878	OLEG TARASOV	{"email": "oleg_tarasov_061973@postgrespro.ru", "phone": "+70527178031"}
0005434411886	362472	6692 074443	VERONIKA RYABOVA	{"email": "v_ryabova081972@postgrespro.ru", "phone": "+70519057947"}
0005434411887	0EE7DC	9672 221456	IRINA POPOVA	{"phone": "+70518514671"}
0005434411888	9E523B	5722 222192	POLINA ANTONOVA	{"email": "polinaantonova-06091975@postgrespro.ru", "phone": "+70028586831"}
0005434411889	645131	8041 074178	KHALIDA KRASNOVA	{"email": "kkrasnova-021977@postgrespro.ru", "phone": "+70019609293"}
0005434411890	0F0BF5	4552 224669	SVETLANA SOROKINA	{"email": "sorokina.svetlana_20041974@postgrespro.ru", "phone": "+70657473500"}
0005434411891	431DA7	5803 834710	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr_1976@postgrespro.ru", "phone": "+70030067040"}
0005434411892	431DA7	5097 487292	IGOR GORBUNOV	{"phone": "+70517673204"}
0005434411893	431DA7	6903 634543	EKATERINA BORISOVA	{"phone": "+70011054031"}
0005434411894	D31EBA	1424 802834	VLADIMIR DENISOV	{"email": "v-denisov_26101976@postgrespro.ru", "phone": "+70534495019"}
0005434411895	D31EBA	2300 858393	VLADIMIR VOLKOV	{"email": "vladimir.volkov.15031965@postgrespro.ru", "phone": "+70161548926"}
0005434411896	679F69	7822 406443	NINA IVANOVA	{"email": "ivanovanina.09041978@postgrespro.ru", "phone": "+70475956703"}
0005434411897	00E411	6415 135480	VIKTORIYA DAVYDOVA	{"phone": "+70903717157"}
0005434411898	00E411	3845 048379	DMITRIY KUZNECOV	{"email": "dmitriykuznecov-29121966@postgrespro.ru", "phone": "+70026355285"}
0005434411899	00E411	3062 907344	VITALIY ROMANOV	{"email": "vitaliyromanov-1976@postgrespro.ru", "phone": "+70724731344"}
0005434411900	C9C251	4976 746048	EVDOKIYA PAVLOVA	{"phone": "+70360899770"}
0005434426225	2AC5D4	3072 835760	KIRILL BONDARENKO	{"phone": "+70233855901"}
0005434426084	0A549C	9350 082143	NADEZHDA DMITRIEVA	{"phone": "+70163033611"}
0005434426085	AE1547	7767 680377	TATYANA TROFIMOVA	{"email": "trofimovat.19011969@postgrespro.ru", "phone": "+70719541134"}
0005434426086	AE1547	1011 273542	ILYA KUZNECOV	{"email": "i_kuznecov-1983@postgrespro.ru", "phone": "+70212649708"}
0005434426087	FA66F1	9206 326841	OLEG IVANOV	{"email": "oleg-ivanov-1977@postgrespro.ru", "phone": "+70550511486"}
0005434426088	21CAB8	8361 399779	ELENA CHERNOVA	{"email": "chernova-e-21091956@postgrespro.ru", "phone": "+70291327960"}
0005434426089	CD9388	2023 362318	ELENA TIMOFEEVA	{"phone": "+70444631674"}
0005434426090	CD9388	4377 780005	DMITRIY SIDOROV	{"email": "sidorov.d_13061960@postgrespro.ru", "phone": "+70209886872"}
0005434426091	774848	1007 684642	EGOR FOMIN	{"email": "fominegor.061968@postgrespro.ru", "phone": "+70535936685"}
0005434426092	B0BB64	2435 025385	OLGA SCHERBAKOVA	{"email": "scherbakova_olga_071979@postgrespro.ru", "phone": "+70580732691"}
0005434426093	70A9D6	5827 683103	LYUBOV IVANOVA	{"phone": "+70588820426"}
0005434426094	79F7A1	2197 344716	GULFIYA SOKOLOVA	{"email": "gsokolova03101977@postgrespro.ru", "phone": "+70270434489"}
0005434426095	F63939	3377 521062	VYACHESLAV MELNIKOV	{"phone": "+70129342567"}
0005434426096	122365	0335 185220	ELENA KOZLOVA	{"email": "ekozlova-051976@postgrespro.ru", "phone": "+70735276918"}
0005434426097	122365	2962 248224	YURIY MOISEEV	{"phone": "+70693103014"}
0005434426098	122365	9991 996082	BORIS PETROV	{"email": "bpetrov-08071967@postgrespro.ru", "phone": "+70834280876"}
0005434426099	1B8827	6368 913780	TATYANA MATVEEVA	{"email": "t_matveeva.25081976@postgrespro.ru", "phone": "+70174904943"}
0005434426100	E217E0	2664 610702	VADIM ABRAMOV	{"email": "vadim-abramov31071970@postgrespro.ru", "phone": "+70271260424"}
0005434426101	11D899	8132 978636	YULIYA KOVALEVA	{"email": "y.kovaleva011975@postgrespro.ru", "phone": "+70373375236"}
0005434426102	A9F32B	2658 231039	ANTONINA SERGEEVA	{"email": "sergeeva.a_081970@postgrespro.ru", "phone": "+70314809993"}
0005434426103	A89301	2161 581324	EGOR PETROV	{"phone": "+70764884160"}
0005434426104	8AF740	2941 562015	MARINA PETROVA	{"email": "petrova.marina-22091971@postgrespro.ru", "phone": "+70362795451"}
0005434426105	8AF740	0914 859342	OLGA ZAYCEVA	{"email": "olga.zayceva_1972@postgrespro.ru", "phone": "+70224938507"}
0005434426106	8AF740	6314 789740	SERGEY KAZAKOV	{"email": "kazakovsergey18061973@postgrespro.ru", "phone": "+70492383557"}
0005434426107	9CD5B3	8768 586634	SERGEY TARASOV	{"email": "s_tarasov031976@postgrespro.ru", "phone": "+70490890998"}
0005434426108	1A1051	2647 742601	VALERIY FEDOTOV	{"email": "fedotovv-011973@postgrespro.ru", "phone": "+70118636699"}
0005434426109	B6FBCD	4987 779450	DENIS OSIPOV	{"phone": "+70907532001"}
0005434426110	EC8ADC	0142 398610	RAIL MAKAROV	{"phone": "+70638075263"}
0005434426111	EC8ADC	1173 089223	SVETLANA KISELEVA	{"email": "kiseleva_svetlana-08051966@postgrespro.ru", "phone": "+70120851604"}
0005434426112	E40614	0368 416611	NATALYA KOMAROVA	{"phone": "+70556793275"}
0005434426113	DFDB25	7768 479429	AMIR MELNIKOV	{"email": "melnikov_amir-16091974@postgrespro.ru", "phone": "+70220593044"}
0005434426114	76AB92	5578 099907	TATYANA IVANOVA	{"email": "t.ivanova.17031963@postgrespro.ru", "phone": "+70804018064"}
0005434426115	76AB92	5322 754736	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov.1976@postgrespro.ru", "phone": "+70971268639"}
0005434426116	E2D1C3	7613 799684	DMITRIY RODIONOV	{"email": "dmitriyrodionov_1974@postgrespro.ru", "phone": "+70932102323"}
0005434426117	E2D1C3	9779 821503	TAMARA OVCHINNIKOVA	{"email": "tamaraovchinnikova-1974@postgrespro.ru", "phone": "+70615613584"}
0005434426118	ACDB37	1637 776332	VLADISLAV KUZNECOV	{"phone": "+70011093087"}
0005434426119	ACDB37	2761 353740	VLADIMIR IVANOV	{"phone": "+70277823683"}
0005434426120	3479AF	7105 846223	ANNA OSIPOVA	{"email": "anna.osipova_21091975@postgrespro.ru", "phone": "+70935936012"}
0005434426121	903C71	8726 378717	ZINAIDA ANISIMOVA	{"email": "zinaida-anisimova.25061964@postgrespro.ru", "phone": "+70371199761"}
0005434426122	9CBAFF	0541 622434	LYUDMILA MOISEEVA	{"email": "l.moiseeva-1967@postgrespro.ru", "phone": "+70602701036"}
0005434426123	17752B	4204 291253	LYUDMILA GERASIMOVA	{"email": "gerasimoval-31121967@postgrespro.ru", "phone": "+70419224026"}
0005434426124	23EDDE	4825 532891	NINA LEBEDEVA	{"phone": "+70470673567"}
0005434426125	52BE95	0697 932412	RUSTAM KUZNECOV	{"email": "rustam_kuznecov_071970@postgrespro.ru", "phone": "+70614703459"}
0005434426126	238389	1020 044037	MARIYA MIKHAYLOVA	{"email": "m-mikhaylova.13071968@postgrespro.ru", "phone": "+70838584556"}
0005434426127	5445CF	9067 841148	ALENA IVANOVA	{"email": "a.ivanova071975@postgrespro.ru", "phone": "+70822185054"}
0005434426128	2B4882	9344 948963	ZINAIDA OVCHINNIKOVA	{"phone": "+70849987153"}
0005434426129	2B4882	5065 313022	SERGEY KAZAKOV	{"phone": "+70332318309"}
0005434426130	0FAC8A	3773 690988	IGOR CHERNOV	{"email": "chernov_i13061974@postgrespro.ru", "phone": "+70676933614"}
0005434426131	0FAC8A	2899 788726	ALEKSANDR MEDVEDEV	{"phone": "+70814597804"}
0005434426132	088D27	6602 526629	PETR DENISOV	{"phone": "+70628793907"}
0005434426133	91EC58	7922 417393	VIKTOR PETROV	{"phone": "+70563808574"}
0005434426134	25FAF4	8287 949211	LARISA TIMOFEEVA	{"phone": "+70616370807"}
0005434426135	09D296	1945 871527	LIDIYA MASLOVA	{"email": "lidiya_maslova-13091966@postgrespro.ru", "phone": "+70665117943"}
0005434426136	09D296	9593 364033	IRINA ALEKSEEVA	{"phone": "+70328047913"}
0005434426137	EB6578	5456 024845	ELENA NAUMOVA	{"email": "naumova_e_1982@postgrespro.ru", "phone": "+70883204584"}
0005434426138	419394	0101 984571	ANNA SOKOLOVA	{"phone": "+70889002377"}
0005434426139	D69E3E	8653 143680	MARIYA STEPANOVA	{"email": "mariya.stepanova_1969@postgrespro.ru", "phone": "+70771781601"}
0005434426140	D69E3E	2349 063290	VYACHESLAV VOLKOV	{"phone": "+70466388515"}
0005434426141	E71BFE	2774 494031	ALEKSEY KUZMIN	{"phone": "+70820390420"}
0005434426142	669C0F	9339 037834	VIKTOR DAVYDOV	{"email": "davydov-v.1981@postgrespro.ru", "phone": "+70988950086"}
0005434426143	84A1CE	6324 086635	SERGEY KAZAKOV	{"email": "skazakov_23061973@postgrespro.ru", "phone": "+70598965475"}
0005434426144	84A1CE	4958 906593	ALEKSEY ANTONOV	{"email": "antonov.aleksey_1975@postgrespro.ru", "phone": "+70854726623"}
0005434426145	84A1CE	2628 661571	IGOR MIRONOV	{"email": "igor-mironov061982@postgrespro.ru", "phone": "+70029157935"}
0005434426146	E880E4	7792 018516	VASILIY MAKAROV	{"phone": "+70457591792"}
0005434426147	C9279A	9263 103273	ALEKSANDR POPOV	{"phone": "+70182688018"}
0005434426148	C9279A	8225 436553	OLEG NOVIKOV	{"phone": "+70146905644"}
0005434426149	C9279A	8918 621879	ALEKSEY MAKAROV	{"phone": "+70564966419"}
0005434426150	9A6D0A	1868 751751	YAROSLAV POPOV	{"phone": "+70822559146"}
0005434426151	9A6D0A	3678 841684	ANTONINA NIKITINA	{"email": "nikitina-antonina071976@postgrespro.ru", "phone": "+70013674796"}
0005434426152	9A6D0A	2604 834386	DMITRIY SAVELEV	{"phone": "+70915336467"}
0005434426153	DE5F24	9627 127798	ELENA MOROZOVA	{"phone": "+70453404819"}
0005434426154	804571	1199 291727	ALINA TIKHONOVA	{"phone": "+70883569166"}
0005434426155	D75243	3315 893397	VERA SEMENOVA	{"phone": "+70632160718"}
0005434426156	02D2D2	6258 774144	NATALYA VLASOVA	{"phone": "+70812517982"}
0005434426157	AD0D4B	7994 558520	MARIYA KULIKOVA	{"phone": "+70360484817"}
0005434426158	CE8730	3784 425442	LIDIYA ROMANOVA	{"email": "romanova-lidiya.1970@postgrespro.ru", "phone": "+70013657389"}
0005434426159	CE8730	9670 583322	KLAVDIYA ROMANOVA	{"email": "klavdiya_romanova-1974@postgrespro.ru", "phone": "+70503659516"}
0005434426160	854BD7	9473 930737	DMITRIY ROMANOV	{"phone": "+70556371910"}
0005434426161	854BD7	3531 432338	DMITRIY ALEKSEEV	{"phone": "+70116565229"}
0005434426162	DB70AB	6205 807641	NINA FILATOVA	{"phone": "+70549820705"}
0005434426163	4E59F5	7212 440027	ELENA FOMINA	{"email": "fomina-elena-21091980@postgrespro.ru", "phone": "+70329419463"}
0005434426164	4EF76B	0563 755791	RAISA KUZNECOVA	{"phone": "+70387236458"}
0005434426165	81FF05	4939 425037	NATALYA ZOTOVA	{"email": "nzotova.1974@postgrespro.ru", "phone": "+70020402744"}
0005434426166	9946D0	8596 658261	VIKTOR BORISOV	{"email": "borisovv-1961@postgrespro.ru", "phone": "+70718868308"}
0005434426167	9946D0	4119 650173	IVAN IVANOV	{"email": "ivanov.ivan.031975@postgrespro.ru", "phone": "+70739200679"}
0005434426168	9946D0	2131 229119	RUSTEM SOROKIN	{"email": "sorokinr-011970@postgrespro.ru", "phone": "+70205945744"}
0005434426169	D7AE2E	6881 949593	ALEKSEY MATVEEV	{"phone": "+70649016450"}
0005434426226	2AC5D4	8696 087912	ELENA ANDREEVA	{"phone": "+70712228192"}
0005434426170	FA8121	1261 786939	VASILIY GORBUNOV	{"email": "gorbunov.v-1964@postgrespro.ru", "phone": "+70854196918"}
0005434426171	FA8121	2652 644471	VLADIMIR ANDREEV	{"phone": "+70740604381"}
0005434426172	3F14C6	3999 760576	VADIM VOROBEV	{"email": "v-vorobev.071965@postgrespro.ru", "phone": "+70959066101"}
0005434426173	A6874A	2179 382215	KARINA ISAEVA	{"phone": "+70614519743"}
0005434426174	783C11	7937 307467	ILDAR BORISOV	{"email": "i-borisov.111978@postgrespro.ru", "phone": "+70067424439"}
0005434426175	7A7BBC	5454 916252	NINA MIRONOVA	{"phone": "+70648615642"}
0005434426176	44F92B	3133 759302	ROMAN ORLOV	{"email": "r.orlov1971@postgrespro.ru", "phone": "+70984363761"}
0005434426177	C8A98E	8154 438461	ANATOLIY TIKHONOV	{"phone": "+70234634150"}
0005434426178	21F5A8	1305 123687	SERGEY IVANOV	{"email": "s_ivanov_27031965@postgrespro.ru", "phone": "+70268527865"}
0005434426179	21F5A8	4975 100858	OLGA ZOTOVA	{"email": "olga_zotova.1975@postgrespro.ru", "phone": "+70756666299"}
0005434426180	47F034	7672 194116	ALEKSANDR ALEKSEEV	{"phone": "+70089739329"}
0005434426181	62BB0C	5812 696778	NATALYA SMIRNOVA	{"phone": "+70580980669"}
0005434426182	62BB0C	0513 096170	KONSTANTIN MEDVEDEV	{"phone": "+70864865996"}
0005434426183	B17C4F	0862 633109	SVETLANA POTAPOVA	{"email": "potapovas1973@postgrespro.ru", "phone": "+70867920737"}
0005434426184	D663A0	4230 654534	VALERIY GRIGOREV	{"email": "valeriy.grigorev23031981@postgrespro.ru", "phone": "+70706321929"}
0005434426185	D663A0	9267 906583	ALEKSANDR IVANOV	{"email": "aivanov_29121969@postgrespro.ru", "phone": "+70855331219"}
0005434426186	938ED7	2422 824195	NATALYA VASILEVA	{"email": "natalya_vasileva30051967@postgrespro.ru", "phone": "+70029451966"}
0005434426187	8D8F58	6697 749961	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana.1973@postgrespro.ru", "phone": "+70743908017"}
0005434426188	8D8F58	7143 996479	IVAN SEMENOV	{"phone": "+70754539841"}
0005434426189	696FF6	5675 010436	TATYANA YAKOVLEVA	{"email": "yakovleva_tatyana07081954@postgrespro.ru", "phone": "+70747347078"}
0005434426190	696FF6	4469 022475	ELENA ILINA	{"email": "eilina.16081967@postgrespro.ru", "phone": "+70139207370"}
0005434426191	5B6686	7648 173858	ALLA KALININA	{"email": "kalininaalla.011975@postgrespro.ru", "phone": "+70608395488"}
0005434426192	5B6686	6264 758128	ANDREY MOROZOV	{"email": "andreymorozov14101974@postgrespro.ru", "phone": "+70317295802"}
0005434426193	A1FAE7	1743 643370	ELDAR KUDRYASHOV	{"email": "kudryashov_e101979@postgrespro.ru", "phone": "+70797821585"}
0005434426194	56C4F7	9528 942278	SVETLANA GORBUNOVA	{"email": "gorbunovas_041975@postgrespro.ru", "phone": "+70166788252"}
0005434426195	56C4F7	6996 437767	VALERIY ZAKHAROV	{"email": "valeriy_zakharov1955@postgrespro.ru", "phone": "+70193658487"}
0005434426196	4AB837	4397 778336	TAISA ANDREEVA	{"email": "taisa.andreeva_1977@postgrespro.ru", "phone": "+70821845367"}
0005434426197	4AB837	3294 650571	ELENA PAVLOVA	{"email": "elenapavlova-071985@postgrespro.ru", "phone": "+70863325788"}
0005434426198	0090DA	7195 418527	NIKOLAY KUZMIN	{"phone": "+70387670533"}
0005434426199	BA5B55	5871 038955	EKATERINA KRASNOVA	{"email": "krasnova_ekaterina_06011975@postgrespro.ru", "phone": "+70610488429"}
0005434426200	BA5B55	2008 378818	IGOR DENISOV	{"phone": "+70657071778"}
0005434426201	1BEF6B	9286 204967	IRINA MAKAROVA	{"email": "irina-makarova_031975@postgrespro.ru", "phone": "+70232454244"}
0005434426202	1BEF6B	3535 972963	VALERIY TIMOFEEV	{"phone": "+70533387922"}
0005434426203	753F3E	0709 236538	ALBINA KAZAKOVA	{"phone": "+70342581461"}
0005434426204	291DF9	3804 613385	SERAFIM IVANOV	{"phone": "+70204625260"}
0005434426205	FABEBE	8711 844630	ALEKSEY POPOV	{"phone": "+70840830321"}
0005434426206	FABEBE	6986 044742	VALENTINA DMITRIEVA	{"email": "dmitrieva.v_04061974@postgrespro.ru", "phone": "+70548139578"}
0005434426207	FABEBE	0831 750740	ALEKSANDR VOROBEV	{"email": "aleksandr.vorobev01031973@postgrespro.ru", "phone": "+70668216022"}
0005434426208	9D4654	0338 912061	IGOR IVANOV	{"phone": "+70780136804"}
0005434426209	192E5F	3715 916583	ALEKSEY STEPANOV	{"email": "stepanov-a_1962@postgrespro.ru", "phone": "+70972947742"}
0005434426210	192E5F	2082 422044	NINA ANDREEVA	{"phone": "+70453231745"}
0005434426211	4DC974	1620 267148	VITALIY BONDARENKO	{"phone": "+70520104681"}
0005434426212	4DC974	7463 293600	KSENIYA GRISHINA	{"phone": "+70257845708"}
0005434426213	CC2640	8195 071014	LIDIYA ANTONOVA	{"phone": "+70867652593"}
0005434426214	C7C51A	5099 668837	MARGARITA ANTONOVA	{"email": "antonova_margarita-1974@postgrespro.ru", "phone": "+70506391021"}
0005434426215	80883A	8599 005259	ELVIRA EGOROVA	{"email": "egorovaelvira-1967@postgrespro.ru", "phone": "+70911415400"}
0005434426216	E34BF4	3823 216940	NATALYA MOROZOVA	{"phone": "+70703029036"}
0005434426217	E34BF4	8142 128049	STANISLAV NIKOLAEV	{"email": "nikolaev-stanislav-041971@postgrespro.ru", "phone": "+70295305890"}
0005434426218	ED09E4	8271 896884	DENIS TIMOFEEV	{"phone": "+70154609878"}
0005434426219	ED09E4	0081 606730	ZOYA CHERNOVA	{"email": "chernova.z_1976@postgrespro.ru", "phone": "+70855473141"}
0005434426220	F2DACB	5667 881319	SOFIYA KUZNECOVA	{"phone": "+70363757591"}
0005434426221	311BC2	2110 643123	NADEZHDA POPOVA	{"email": "popova.nadezhda.1976@postgrespro.ru", "phone": "+70255550756"}
0005434426222	310793	0727 165781	DANIL KUZMIN	{"email": "d.kuzmin-1964@postgrespro.ru", "phone": "+70594108290"}
0005434426223	310793	1895 604786	YURIY KUZMIN	{"phone": "+70402489291"}
0005434426224	724AE2	3776 805815	SVETLANA AFANASEVA	{"email": "svetlana.afanaseva_081966@postgrespro.ru", "phone": "+70103696452"}
0005434426227	4CE482	0891 877146	LYUDMILA MARTYNOVA	{"email": "lyudmila_martynova.31121971@postgrespro.ru", "phone": "+70461347756"}
0005434426228	E846BB	3607 494588	LYUBOV OVCHINNIKOVA	{"phone": "+70489560682"}
0005434426229	AA1639	6375 409559	ANTONINA DENISOVA	{"email": "a_denisova29101973@postgrespro.ru", "phone": "+70533554390"}
0005434426230	7FEB22	4905 682049	NIKITA ZHURAVLEV	{"email": "zhuravlev_n081974@postgrespro.ru", "phone": "+70181576474"}
0005434426231	6BC9CE	3495 428831	ALEKSEY SOROKIN	{"email": "sorokin.a1967@postgrespro.ru", "phone": "+70373483184"}
0005434426232	B6CEF3	5556 534687	SERGEY EGOROV	{"phone": "+70260082404"}
0005434426233	08FECF	5809 954154	ALEKSEY MAKAROV	{"phone": "+70404876545"}
0005434426234	0AEBBC	6951 362760	DMITRIY IVANOV	{"phone": "+70318342589"}
0005434426235	0AEBBC	8234 134004	GENNADIY GORBUNOV	{"email": "g.gorbunov-09071971@postgrespro.ru", "phone": "+70577674329"}
0005434426236	B5AF6B	8221 233819	LYUDMILA VOROBEVA	{"email": "vorobeval-101975@postgrespro.ru", "phone": "+70471090992"}
0005434426237	246417	8952 046467	SERGEY ZHURAVLEV	{"email": "s_zhuravlev_041972@postgrespro.ru", "phone": "+70224311395"}
0005434426238	246417	9304 125842	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov25121964@postgrespro.ru", "phone": "+70301918264"}
0005434426239	87520E	7636 377089	NATALYA ABRAMOVA	{"phone": "+70480405407"}
0005434426240	DD0F8B	5836 514540	ALEKSEY KULIKOV	{"email": "kulikovaleksey_1974@postgrespro.ru", "phone": "+70592510463"}
0005434426241	4432C6	6278 670501	EVGENIY MEDVEDEV	{"email": "evgeniy.medvedev061966@postgrespro.ru", "phone": "+70314378625"}
0005434426242	CB67C6	4775 958551	VASILIY IVANOV	{"phone": "+70998486107"}
0005434426243	CB67C6	2505 716198	ARTEM KUZMIN	{"phone": "+70561182333"}
0005434426244	CB67C6	0283 786985	TATYANA GERASIMOVA	{"email": "gerasimovat28021973@postgrespro.ru", "phone": "+70252397381"}
0005434426245	60E39A	8920 687142	IVAN KOZLOV	{"phone": "+70097241904"}
0005434426246	5C7425	3098 622102	OLGA IVANOVA	{"email": "ivanova_o-24101967@postgrespro.ru", "phone": "+70515269818"}
0005434426247	5C7425	3671 238340	LIDIYA DENISOVA	{"phone": "+70392719690"}
0005434426248	5C7425	2733 470823	ALSU KONDRATEVA	{"email": "a_kondrateva-18041970@postgrespro.ru", "phone": "+70386247024"}
0005434426249	9CAA90	5292 553794	ELIZAVETA SEMENOVA	{"email": "semenova.e_031970@postgrespro.ru", "phone": "+70155047701"}
0005434426250	0F76D7	0585 069973	DENIS PAVLOV	{"email": "pavlov.d-1982@postgrespro.ru", "phone": "+70087138260"}
0005434426251	A1B85B	1827 826710	OLGA ZOTOVA	{"phone": "+70876672793"}
0005434426252	A1B85B	0809 397554	GENNADIY ALEKSEEV	{"email": "alekseev_g.031971@postgrespro.ru", "phone": "+70788422273"}
0005434426253	67BBE5	8538 018704	ANASTASIYA KOMAROVA	{"phone": "+70917242975"}
0005434426254	FA34FC	0450 977700	TAMARA EGOROVA	{"phone": "+70448495675"}
0005434426255	FA34FC	9179 062816	TATYANA KUZNECOVA	{"phone": "+70517866906"}
0005434426256	1CC24D	4155 839449	SERGEY KUZMIN	{"phone": "+70987345646"}
0005434426257	99B23F	8697 132109	VLADIMIR PETROV	{"phone": "+70498284540"}
0005434426258	682838	7412 779848	SERGEY SMIRNOV	{"email": "smirnov.s_09101973@postgrespro.ru", "phone": "+70488055020"}
0005434426259	682838	3371 500933	TATYANA SIDOROVA	{"email": "tatyana_sidorova.1968@postgrespro.ru", "phone": "+70605854614"}
0005434426260	87288F	8326 592413	TATYANA SEMENOVA	{"phone": "+70832820448"}
0005434426261	42BD03	8476 391610	SVETLANA PETROVA	{"email": "petrovas-21071963@postgrespro.ru", "phone": "+70838576237"}
0005434426262	42BD03	1660 412314	DMITRIY ZHUKOV	{"email": "zhukov-dmitriy.09021970@postgrespro.ru", "phone": "+70358240083"}
0005434426263	DE063D	9598 377524	INNA CHERNOVA	{"phone": "+70919318803"}
0005434426264	DE063D	3203 717313	ANDREY KUZMIN	{"email": "akuzmin-1974@postgrespro.ru", "phone": "+70603586268"}
0005434426265	B5DC40	2806 055059	GENNADIY NOVIKOV	{"email": "g-novikov041971@postgrespro.ru", "phone": "+70003947029"}
0005434426266	50E0BB	4390 691995	NIKOLAY ALEKSANDROV	{"phone": "+70372648320"}
0005434426267	1B649E	8690 406151	ALEKSEY STEPANOV	{"email": "a_stepanov-071966@postgrespro.ru", "phone": "+70853603591"}
0005434426268	1B649E	5850 922425	VALENTINA POPOVA	{"phone": "+70844153455"}
0005434426269	1B649E	7859 112303	OLGA TARASOVA	{"email": "tarasova-olga.09071958@postgrespro.ru", "phone": "+70316976205"}
0005434426270	4CC981	4644 941517	LYUDMILA MATVEEVA	{"email": "matveeva_l1982@postgrespro.ru", "phone": "+70599342760"}
0005434426271	2ED0A3	3584 365212	MARINA SERGEEVA	{"email": "sergeeva.m.02091976@postgrespro.ru", "phone": "+70576576961"}
0005434426272	792447	1615 448905	VLADISLAV GRIGOREV	{"email": "grigorevv.071975@postgrespro.ru", "phone": "+70987704490"}
0005434426273	792447	7624 669268	VASILIY RODIONOV	{"phone": "+70318481791"}
0005434426274	0A0AFA	6576 792761	ALEKSANDRA IVANOVA	{"email": "ivanova.aleksandra.1972@postgrespro.ru", "phone": "+70113830050"}
0005434426275	0A0AFA	5306 540205	ANNA ANDREEVA	{"phone": "+70897359578"}
0005434426276	0A0AFA	2009 941187	YAROSLAV KUZNECOV	{"email": "yaroslav-kuznecov18121962@postgrespro.ru", "phone": "+70950805013"}
0005434426277	5E5CB6	0408 167778	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr_081984@postgrespro.ru", "phone": "+70390646419"}
0005434426278	23C4B8	7672 981461	NIKOLAY ZAKHAROV	{"email": "n_zakharov.041966@postgrespro.ru", "phone": "+70788629478"}
0005434426279	E66186	9476 759050	ANDREY KOZLOV	{"phone": "+70806021273"}
0005434426280	8C0A22	4664 496642	TATYANA SOKOLOVA	{"phone": "+70797115875"}
0005434426281	38A68B	2337 270795	ELVIRA ALEKSANDROVA	{"email": "elvira_aleksandrova-20021963@postgrespro.ru", "phone": "+70684259153"}
0005434426282	38A68B	0098 134600	OLGA KALININA	{"email": "olgakalinina_1977@postgrespro.ru", "phone": "+70530286425"}
0005434426283	ADD6C7	2857 655137	SERGEY MARTYNOV	{"phone": "+70370926651"}
0005434426284	ADD6C7	1312 589388	VIKTOR NIKOLAEV	{"phone": "+70309872452"}
0005434426285	61617B	8595 028661	VLADISLAV KONOVALOV	{"email": "konovalov.vladislav_091978@postgrespro.ru", "phone": "+70708923974"}
0005434426286	832716	7293 799710	NIKOLAY GRIGOREV	{"email": "n.grigorev-041978@postgrespro.ru", "phone": "+70054368599"}
0005434426287	49D214	1922 142990	SVETLANA KOLESNIKOVA	{"phone": "+70155771445"}
0005434426288	49D214	4156 863355	LIDIYA KOZLOVA	{"email": "lidiya_kozlova_14031975@postgrespro.ru", "phone": "+70128858895"}
0005434426289	463428	1202 001685	RUSTAM BORISOV	{"phone": "+70735120965"}
0005434426290	2532CE	7622 173836	YURIY MAKSIMOV	{"phone": "+70132961625"}
0005434426291	7EC090	0752 996255	TATYANA GRISHINA	{"phone": "+70026204331"}
0005434426292	CDAB71	1770 509022	VLADIMIR MATVEEV	{"phone": "+70278741638"}
0005434426293	38B41C	6267 533141	DMITRIY NAZAROV	{"phone": "+70933967829"}
0005434426294	38B41C	5235 388764	ALEKSANDR NIKOLAEV	{"phone": "+70633854208"}
0005434426295	38B41C	0551 706666	IGOR ANTONOV	{"email": "antonov_i1967@postgrespro.ru", "phone": "+70076277675"}
0005434426296	CE2D06	8198 384723	EVGENIY MAKAROV	{"email": "makarov_e-1976@postgrespro.ru", "phone": "+70620814686"}
0005434426297	664E06	2826 731575	NATALYA CHERNOVA	{"email": "natalya.chernova051979@postgrespro.ru", "phone": "+70658441771"}
0005434426298	664E06	0486 474049	YURIY IVANOV	{"email": "y-ivanov.041971@postgrespro.ru", "phone": "+70651036334"}
0005434426299	664E06	8713 807812	VADIM FEDOTOV	{"phone": "+70527818156"}
0005434426300	8EBB6C	0695 804855	DANIL FROLOV	{"phone": "+70029382924"}
0005434426301	A8FD8E	6124 402125	DANILA KUZNECOV	{"email": "kuznecov_danila06061972@postgrespro.ru", "phone": "+70008503760"}
0005434426302	A8FD8E	5339 888508	OLGA FOMINA	{"email": "olga_fomina041974@postgrespro.ru", "phone": "+70935580570"}
0005434426303	1FA789	2142 719883	NINA KOROLEVA	{"email": "ninakoroleva-04101980@postgrespro.ru", "phone": "+70104818879"}
0005434426304	1FA789	2821 901618	NIKOLAY DMITRIEV	{"phone": "+70291912046"}
0005434426305	B1460A	8830 247588	ALEKSANDR OSIPOV	{"phone": "+70880823676"}
0005434426306	B1460A	2898 472240	DENIS DMITRIEV	{"email": "d-dmitriev_1975@postgrespro.ru", "phone": "+70686429015"}
0005434426307	4EB13E	5481 606432	SERGEY RODIONOV	{"email": "sergey.rodionov.03101971@postgrespro.ru", "phone": "+70000036477"}
0005434426308	4EB13E	2532 772386	MARIYA VOLKOVA	{"phone": "+70098860405"}
0005434426309	612124	8082 734557	DARYA ALEKSANDROVA	{"phone": "+70122512165"}
0005434426310	F7B63E	1620 434212	MARIYA KUZNECOVA	{"phone": "+70348037294"}
0005434426311	F7B63E	5109 030166	GALINA DMITRIEVA	{"phone": "+70126991850"}
0005434426312	3F646A	9896 128351	FEDOR KONOVALOV	{"phone": "+70968866913"}
0005434426313	C2AD7F	0600 309875	KSENIYA NOVIKOVA	{"email": "knovikova-27061968@postgrespro.ru", "phone": "+70053387914"}
0005434426314	C2AD7F	3816 993673	BORIS KONOVALOV	{"email": "konovalovboris.13041973@postgrespro.ru", "phone": "+70279179819"}
0005434426315	7008FC	3339 807833	MAKSIM SCHERBAKOV	{"phone": "+70144532246"}
0005434426316	5DB35B	9684 676070	VALENTINA SOROKINA	{"email": "valentina_sorokina.091982@postgrespro.ru", "phone": "+70686522102"}
0005434426317	83F73B	4459 152804	OLGA BELYAEVA	{"phone": "+70096862190"}
0005434426318	5FE644	4624 483420	VITALIY ANDREEV	{"phone": "+70896352352"}
0005434426319	5B86FC	2885 351722	VLADIMIR SCHERBAKOV	{"phone": "+70622951766"}
0005434426320	C063EF	6941 728406	NINA DENISOVA	{"phone": "+70898964797"}
0005434426321	95094F	2377 080033	VLADIMIR NIKITIN	{"phone": "+70616418674"}
0005434426322	D077CD	2532 922759	EVGENIY KUZNECOV	{"phone": "+70631780408"}
0005434426323	DCB380	6305 212453	SERGEY ANDREEV	{"phone": "+70517156412"}
0005434426324	B2B304	7805 654621	IGOR SHEVCHENKO	{"phone": "+70419330149"}
0005434426325	B2B304	0399 466905	ANTON BONDARENKO	{"phone": "+70934191766"}
0005434426326	9B0905	1746 013312	RINAT IVANOV	{"email": "r.ivanov-041965@postgrespro.ru", "phone": "+70566879995"}
0005434426327	9B0905	8759 868254	VALERIY DMITRIEV	{"phone": "+70105835266"}
0005434426328	B7DA07	4140 678404	RAISA KOROLEVA	{"email": "koroleva-raisa-061973@postgrespro.ru", "phone": "+70710545546"}
0005434426329	6BAC87	3843 007927	SVETLANA EFREMOVA	{"email": "efremovasvetlana24021978@postgrespro.ru", "phone": "+70616084517"}
0005434426330	187198	0581 765175	ALEKSANDRA KONOVALOVA	{"phone": "+70146806166"}
0005434426331	8FF5FC	5764 653341	OLEG MAKAROV	{"email": "makarov_o07041975@postgrespro.ru", "phone": "+70644600714"}
0005434426332	8FF5FC	9810 601995	ILNUR KUZNECOV	{"phone": "+70837011136"}
0005434426333	377246	4478 780704	LARISA VASILEVA	{"email": "lvasileva30061980@postgrespro.ru", "phone": "+70126846619"}
0005434426334	C47C92	4461 850814	NIKOLAY POPOV	{"email": "nikolay-popov_1964@postgrespro.ru", "phone": "+70154071692"}
0005434426335	9FA214	1516 613140	ALLA DMITRIEVA	{"email": "a_dmitrieva06021968@postgrespro.ru", "phone": "+70162225022"}
0005434426336	5F1220	1983 051453	SVETLANA SAVELEVA	{"phone": "+70621535573"}
0005434426337	5F1220	8879 582047	VLADISLAV EGOROV	{"email": "egorov_vladislav-1973@postgrespro.ru", "phone": "+70114695214"}
0005434426338	CB0077	7728 178860	TAMARA ZAYCEVA	{"email": "tamarazayceva-29071973@postgrespro.ru", "phone": "+70960791061"}
0005434426339	97A401	8497 715003	MARINA KONOVALOVA	{"email": "mkonovalova-05051968@postgrespro.ru", "phone": "+70824504565"}
0005434426340	516A67	5801 227690	SERGEY SOROKIN	{"phone": "+70457722871"}
0005434426341	516A67	8712 642232	VYACHESLAV BORISOV	{"phone": "+70607694344"}
0005434426342	49902C	0097 353947	BORIS FOMIN	{"email": "b_fomin.111970@postgrespro.ru", "phone": "+70585857213"}
0005434426343	07A5E8	8535 052377	GALINA TARASOVA	{"email": "tarasova-galina.1959@postgrespro.ru", "phone": "+70299926395"}
0005434426344	8E0702	3297 965920	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev.101980@postgrespro.ru", "phone": "+70953166846"}
0005434426345	45B1A6	8570 374607	LYUBOV VASILEVA	{"email": "lyubov-vasileva_011975@postgrespro.ru", "phone": "+70526568995"}
0005434426346	B80F6D	4445 003084	MIKHAIL ZHURAVLEV	{"email": "zhuravlevmikhail1969@postgrespro.ru", "phone": "+70674000752"}
0005434426347	B80F6D	8243 655827	VLADIMIR KUZNECOV	{"phone": "+70289602328"}
0005434426348	E293D1	7162 537857	ALEKSEY VOLKOV	{"email": "alekseyvolkov-28071962@postgrespro.ru", "phone": "+70171568262"}
0005434426349	E293D1	0441 355174	VYACHESLAV VOROBEV	{"phone": "+70428817678"}
0005434426350	8A1B8F	4866 043122	ALENA VOLKOVA	{"email": "volkova.a-111966@postgrespro.ru", "phone": "+70329235431"}
0005434426351	8A1B8F	4277 871981	VERA FILATOVA	{"email": "verafilatova.11111976@postgrespro.ru", "phone": "+70631594282"}
0005434426352	436943	3767 371456	ANASTASIYA FILIPPOVA	{"phone": "+70887399117"}
0005434426353	F50BD8	6687 007080	DANIIL KUZNECOV	{"email": "kuznecov_daniil_1974@postgrespro.ru", "phone": "+70665572465"}
0005434426354	F50BD8	3082 457796	ANNA EFREMOVA	{"phone": "+70346504754"}
0005434426355	1219EA	7158 659395	ANDREY NIKITIN	{"phone": "+70721257157"}
0005434426356	954899	3395 951248	EGOR BONDARENKO	{"phone": "+70441244316"}
0005434426357	954899	1832 956448	ELENA FROLOVA	{"email": "frolova-elena_1976@postgrespro.ru", "phone": "+70891837046"}
0005434426358	16A122	9564 062510	ANASTASIYA FEDOROVA	{"phone": "+70266829321"}
0005434426359	16A122	1600 557812	GALINA MEDVEDEVA	{"email": "galina-medvedeva-27061979@postgrespro.ru", "phone": "+70838868880"}
0005434426360	18E844	4760 103816	SERGEY SCHERBAKOV	{"phone": "+70473020590"}
0005434426361	EC06B1	5524 582618	ALEKSANDR VLASOV	{"phone": "+70128874575"}
0005434426362	EC06B1	7138 937986	TATYANA IVANOVA	{"phone": "+70193408989"}
0005434426363	F2A4B8	5724 544620	EKATERINA ZHUKOVA	{"email": "zhukovaekaterina_051974@postgrespro.ru", "phone": "+70069629456"}
0005434426364	5AC5C0	6503 859058	DIANA SERGEEVA	{"email": "diana_sergeeva.101978@postgrespro.ru", "phone": "+70884965430"}
0005434426365	7CDA50	0451 940082	TAKHIR POPOV	{"email": "t.popov-021968@postgrespro.ru", "phone": "+70230706893"}
0005434426366	9CA227	9105 429431	ELENA RYABOVA	{"phone": "+70735808082"}
0005434426367	659AFE	4674 508170	ALSU KOVALEVA	{"email": "alsu_kovaleva-1967@postgrespro.ru", "phone": "+70810780768"}
0005434426368	659AFE	0876 684048	NATALYA POPOVA	{"phone": "+70440889807"}
0005434426369	B0EBF4	5703 040147	VLADISLAV ZAYCEV	{"phone": "+70913653630"}
0005434426370	03AA5B	3078 119190	ALEKSEY PETROV	{"phone": "+70438830933"}
0005434426371	03AA5B	5389 153573	NINA PAVLOVA	{"email": "pavlovan-11051972@postgrespro.ru", "phone": "+70135459788"}
0005434426372	7DA018	2631 163124	OLGA SMIRNOVA	{"email": "smirnova_olga-1969@postgrespro.ru", "phone": "+70474867777"}
0005434426373	765E02	9965 519351	YULIYA ILINA	{"email": "ilina-yuliya-051979@postgrespro.ru", "phone": "+70985129352"}
0005434426374	22310F	0097 015923	DMITRIY ZAYCEV	{"phone": "+70751113253"}
0005434426375	22310F	6125 714317	IGOR FEDOROV	{"phone": "+70586609228"}
0005434426376	22310F	1578 972476	ANTONINA MOROZOVA	{"phone": "+70696395891"}
0005434426377	FDE839	6020 902559	ALEKSEY DAVYDOV	{"email": "davydov_aleksey.1985@postgrespro.ru", "phone": "+70730099921"}
0005434426378	7F2BA2	7846 041448	DARYA AKIMOVA	{"phone": "+70409997124"}
0005434426379	889FD6	3873 740619	VALENTINA SERGEEVA	{"phone": "+70364492507"}
0005434426380	8BD013	8621 748569	TAMARA ISAEVA	{"email": "t.isaeva22091976@postgrespro.ru", "phone": "+70617503343"}
0005434426381	8BD013	1455 362911	SVETLANA POLYAKOVA	{"email": "polyakova-svetlana031968@postgrespro.ru", "phone": "+70364513933"}
0005434426382	D9EE35	6117 945716	ALEKSANDR MAKAROV	{"phone": "+70085182914"}
0005434426383	2804F0	1889 624887	LYUBOV POTAPOVA	{"email": "l.potapova.021973@postgrespro.ru", "phone": "+70412724354"}
0005434426384	CF17D0	9440 878190	LYUDMILA NIKIFOROVA	{"phone": "+70013597178"}
0005434426385	BB7CC8	4002 939256	VALENTINA NIKIFOROVA	{"phone": "+70829432665"}
0005434426386	EDC967	8878 326182	DMITRIY DENISOV	{"phone": "+70970574124"}
0005434426387	EDC967	3129 860315	ANDREY KUZNECOV	{"phone": "+70915891785"}
0005434426388	13518B	9951 394985	KONSTANTIN SCHERBAKOV	{"phone": "+70999721602"}
0005434426389	13518B	7644 362728	LYUBOV BORISOVA	{"email": "lyubov.borisova.1983@postgrespro.ru", "phone": "+70473213036"}
0005434426390	49F68E	3948 086835	IGOR KARPOV	{"phone": "+70120752388"}
0005434426391	2B4B3A	5442 143836	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova.081967@postgrespro.ru", "phone": "+70107998108"}
0005434426392	D6C47D	9414 217028	ZINAIDA FROLOVA	{"phone": "+70551730462"}
0005434426393	706D67	5148 980562	ANATOLIY DENISOV	{"phone": "+70788551553"}
0005434426394	3C0CD0	8236 236627	SERGEY MOROZOV	{"email": "sergey-morozov071967@postgrespro.ru", "phone": "+70808287935"}
0005434426672	185E41	8266 983496	ALEKSEY PAVLOV	{"phone": "+70697199961"}
0005434426395	81F991	0760 578540	YULIYA IVANOVA	{"email": "ivanova_yuliya-16091975@postgrespro.ru", "phone": "+70483688956"}
0005434426396	CF418F	1571 508301	VALENTINA VLASOVA	{"phone": "+70346969841"}
0005434426397	CF418F	3978 040195	NIKOLAY TARASOV	{"email": "tarasov.nikolay.1977@postgrespro.ru", "phone": "+70855316933"}
0005434426398	51EB63	9025 805378	SERGEY KUZNECOV	{"phone": "+70453682959"}
0005434426399	7D8807	2603 209286	ANATOLIY MIKHAYLOV	{"email": "mikhaylova-04011976@postgrespro.ru", "phone": "+70829264089"}
0005434426400	7D8807	0359 153159	NADEZHDA GRISHINA	{"phone": "+70233658716"}
0005434426401	C314EC	6011 430941	VIKTOR GAVRILOV	{"phone": "+70772994516"}
0005434426402	C314EC	0695 230324	MIKHAIL BELOV	{"email": "mikhailbelov-1972@postgrespro.ru", "phone": "+70402446324"}
0005434426403	C34375	0303 217350	NIKITA ZAYCEV	{"email": "zaycev.nikita-1978@postgrespro.ru", "phone": "+70968248880"}
0005434426404	1C1FB7	2951 653842	VALENTINA ARKHIPOVA	{"email": "valentina-arkhipova011982@postgrespro.ru", "phone": "+70708138348"}
0005434426405	1C1FB7	2622 897330	LIDIYA LOGINOVA	{"email": "loginova.lidiya-15051973@postgrespro.ru", "phone": "+70293459063"}
0005434426406	080534	9167 645402	IVAN KONOVALOV	{"phone": "+70767220077"}
0005434426407	DDAED2	2952 227119	NATALIYA DANILOVA	{"phone": "+70759498878"}
0005434426408	9D4F3F	3500 992718	DMITRIY YAKOVLEV	{"phone": "+70286830709"}
0005434426409	69B6D1	5037 509142	ANNA VOLKOVA	{"phone": "+70592753619"}
0005434426410	69E284	8264 080929	VALERIYA DAVYDOVA	{"email": "davydovavaleriya-1972@postgrespro.ru", "phone": "+70553814681"}
0005434426411	69E284	8082 197832	GALINA LEBEDEVA	{"phone": "+70924091508"}
0005434426412	52E05C	2827 909700	LIDIYA BELYAEVA	{"email": "l_belyaeva10051975@postgrespro.ru", "phone": "+70584883517"}
0005434426413	F13D02	0227 317815	DARYA KUDRYASHOVA	{"phone": "+70905311001"}
0005434426414	ECA270	5567 488599	TIMOFEY DENISOV	{"phone": "+70483643267"}
0005434426415	ECA270	4448 765131	ELENA IVANOVA	{"phone": "+70777002340"}
0005434426416	164855	2621 691931	NINA KUZNECOVA	{"phone": "+70534791537"}
0005434426417	BA402E	2287 815562	ALEKSANDR ANDREEV	{"email": "andreevaleksandr1966@postgrespro.ru", "phone": "+70124972651"}
0005434426418	E9EBCB	7548 280951	EDUARD VOLKOV	{"email": "e_volkov.1977@postgrespro.ru", "phone": "+70273929878"}
0005434426419	E9EBCB	9015 734808	SERGEY OSIPOV	{"email": "osipov.sergey26091966@postgrespro.ru", "phone": "+70509400990"}
0005434426420	E9EBCB	2113 424602	LYUBOV TARASOVA	{"email": "l_tarasova-121972@postgrespro.ru", "phone": "+70612164577"}
0005434426421	F249CA	9895 972542	MARINA KUZNECOVA	{"phone": "+70930981815"}
0005434426422	F249CA	3560 600003	ANASTASIYA IVANOVA	{"email": "ivanovaanastasiya_15031959@postgrespro.ru", "phone": "+70087400233"}
0005434426423	CFB89E	4537 603536	ANATOLIY ZHUKOV	{"email": "zhukov_anatoliy101983@postgrespro.ru", "phone": "+70666054071"}
0005434426424	AB12EF	9071 066620	KIRILL ISAEV	{"email": "isaevkirill_091976@postgrespro.ru", "phone": "+70712223600"}
0005434426425	27F55D	7459 030469	OKSANA LUKYANOVA	{"email": "lukyanovao1971@postgrespro.ru", "phone": "+70578995412"}
0005434426426	A77AAA	9656 809200	EVGENIY NIKOLAEV	{"phone": "+70902351856"}
0005434426427	CE362E	8367 162897	IVAN RODIONOV	{"email": "rodionov.i-01071975@postgrespro.ru", "phone": "+70690395814"}
0005434426428	46FE17	1041 168948	OLEG ROMANOV	{"phone": "+70420661911"}
0005434426429	3FAC4B	3444 942832	NIKOLAY KUZNECOV	{"email": "kuznecovn.121961@postgrespro.ru", "phone": "+70845820794"}
0005434426430	3FAC4B	2965 309294	TATYANA YAKOVLEVA	{"email": "tyakovleva_02121973@postgrespro.ru", "phone": "+70493045730"}
0005434426431	3FAC4B	5429 305601	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova1968@postgrespro.ru", "phone": "+70962917679"}
0005434426432	B649DA	7036 007215	DARYA KULIKOVA	{"email": "kulikovadarya_10121968@postgrespro.ru", "phone": "+70717436559"}
0005434426433	4E7C78	4510 687138	VALENTINA GRISHINA	{"email": "valentina-grishina.18061972@postgrespro.ru", "phone": "+70146914236"}
0005434426434	0B467A	9469 518772	DMITRIY KUZNECOV	{"phone": "+70463243003"}
0005434426435	8CACD7	7286 575827	ALEKSEY IVANOV	{"phone": "+70418772660"}
0005434426436	8CACD7	4123 992828	IVAN VOLKOV	{"email": "ivan.volkov.26061963@postgrespro.ru", "phone": "+70211037676"}
0005434426437	2591B7	7818 895066	SERGEY BARANOV	{"email": "s.baranov_101974@postgrespro.ru", "phone": "+70895280648"}
0005434426438	16A38F	6002 706665	ALEKSANDRA ALEKSEEVA	{"phone": "+70566721307"}
0005434426439	C31967	6460 822016	IRINA VOROBEVA	{"email": "i_vorobeva.1976@postgrespro.ru", "phone": "+70238091063"}
0005434426440	6FD771	2448 742269	GALINA PAVLOVA	{"phone": "+70281726211"}
0005434426441	AA351D	0913 820719	NINA KOMAROVA	{"phone": "+70652672659"}
0005434426442	AA351D	5934 518497	VADIM MAKAROV	{"email": "makarov.vadim-041968@postgrespro.ru", "phone": "+70358596552"}
0005434426443	B9FF1F	7752 958264	IRINA DMITRIEVA	{"email": "dmitrieva-irina-071975@postgrespro.ru", "phone": "+70855033091"}
0005434426444	E75D34	7430 720689	LYUBOV KARPOVA	{"phone": "+70349598220"}
0005434426445	CA126E	3283 805787	DMITRIY SMIRNOV	{"email": "smirnov.dmitriy-071973@postgrespro.ru", "phone": "+70330363302"}
0005434426446	CA126E	7634 241762	GALINA KULIKOVA	{"email": "kulikova-g-1968@postgrespro.ru", "phone": "+70010954037"}
0005434426447	CA126E	6452 892646	VALENTIN VASILEV	{"email": "vasilev.v.1966@postgrespro.ru", "phone": "+70004382749"}
0005434426448	99C2DF	5514 273401	ANTONINA FILIPPOVA	{"email": "filippovaantonina091971@postgrespro.ru", "phone": "+70502364459"}
0005434426449	9EE2B9	1339 873568	NATALYA ROMANOVA	{"phone": "+70227831510"}
0005434426450	AB671D	5421 737047	NINA ROMANOVA	{"email": "nromanova_031990@postgrespro.ru", "phone": "+70625298348"}
0005434426451	D7B868	0212 304706	PAVEL EGOROV	{"email": "egorov_p.061974@postgrespro.ru", "phone": "+70529764444"}
0005434426452	D7B868	2402 780466	VALENTINA SCHERBAKOVA	{"phone": "+70230054596"}
0005434426453	D7B868	2978 239861	GALINA TITOVA	{"phone": "+70443717778"}
0005434426454	D7B868	1504 575792	YULIYA TIMOFEEVA	{"phone": "+70178990475"}
0005434426455	CD5646	0849 887007	GALINA GERASIMOVA	{"email": "gerasimova-galina_1982@postgrespro.ru", "phone": "+70368755339"}
0005434426456	CD5646	3812 033705	YURIY IVANOV	{"phone": "+70876734429"}
0005434426457	EF8659	0989 380716	NATALIYA ERMAKOVA	{"email": "ermakova_nataliya_1963@postgrespro.ru", "phone": "+70025356721"}
0005434426458	CEDD81	0419 552432	SERGEY KULIKOV	{"phone": "+70934183676"}
0005434426459	8E876F	8551 673389	ANASTASIYA BORISOVA	{"email": "borisova.a1978@postgrespro.ru", "phone": "+70648469819"}
0005434426460	684016	0705 879645	DMITRIY GRIGOREV	{"email": "grigorevdmitriy.16111964@postgrespro.ru", "phone": "+70551822959"}
0005434426461	FD7AFA	2160 934907	LYUDMILA KISELEVA	{"phone": "+70072128012"}
0005434426462	419B44	9588 729832	SERGEY FILIPPOV	{"email": "filippovs.31011965@postgrespro.ru", "phone": "+70494985002"}
0005434426463	52C174	2068 214232	MARIYA IVANOVA	{"email": "ivanova-m.091978@postgrespro.ru", "phone": "+70278076395"}
0005434426464	52C174	0708 453140	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov-111979@postgrespro.ru", "phone": "+70657434226"}
0005434426465	F6CD7E	6921 233572	LYUDMILA MAKAROVA	{"email": "makarova.l.011968@postgrespro.ru", "phone": "+70028395234"}
0005434426466	39B6BD	3534 135571	TATYANA ALEKSEEVA	{"email": "tatyanaalekseeva.24081970@postgrespro.ru", "phone": "+70065967885"}
0005434426467	36192E	5027 389941	ELENA ZHUKOVA	{"email": "zhukova_elena_1979@postgrespro.ru", "phone": "+70335912822"}
0005434426468	042573	7210 594158	DMITRIY IVANOV	{"email": "d.ivanov031967@postgrespro.ru", "phone": "+70382146169"}
0005434426469	159A2F	9189 835090	VALERIY GERASIMOV	{"phone": "+70633574939"}
0005434426470	159A2F	0907 451562	NATALYA MELNIKOVA	{"email": "natalya_melnikova-081976@postgrespro.ru", "phone": "+70854138922"}
0005434426471	DD5BB2	4239 607813	YULIYA YUDINA	{"email": "yuliya.yudina_071975@postgrespro.ru", "phone": "+70409844377"}
0005434426472	FA1C55	7621 362621	ROMAN KRASNOV	{"email": "roman.krasnov_1960@postgrespro.ru", "phone": "+70302757556"}
0005434426473	E77580	6649 588551	ELENA NIKITINA	{"phone": "+70162968359"}
0005434426474	04B7D3	9679 413496	VALENTINA YAKOVLEVA	{"email": "yakovleva.valentina.11101974@postgrespro.ru", "phone": "+70513732761"}
0005434426475	04B7D3	9814 878856	VALERIY SMIRNOV	{"phone": "+70760810650"}
0005434426476	EF8F80	1237 738032	KARIM NIKITIN	{"phone": "+70365155937"}
0005434426477	3F1D26	3268 444782	DENIS ZHURAVLEV	{"phone": "+70803467046"}
0005434426478	07DB1D	7649 749337	VLADIMIR RODIONOV	{"email": "rodionov.v081968@postgrespro.ru", "phone": "+70707483993"}
0005434426479	DAB060	7216 237321	VALERIY BELOV	{"phone": "+70101445808"}
0005434426480	F2ED0D	6639 781419	ANNA KUZNECOVA	{"email": "akuznecova.111959@postgrespro.ru", "phone": "+70036165923"}
0005434426481	C1219B	4593 178184	DENIS ALEKSANDROV	{"email": "aleksandrovd011964@postgrespro.ru", "phone": "+70710649298"}
0005434426482	C1219B	0736 721050	LARISA FILIPPOVA	{"phone": "+70052645593"}
0005434426483	BF0022	1068 633345	ALEKSANDR KUZNECOV	{"phone": "+70831098839"}
0005434426484	098D7B	4285 010256	GALINA NAZAROVA	{"email": "nazarova.galina.26041980@postgrespro.ru", "phone": "+70602470409"}
0005434426485	3717F4	4082 371886	ALEKSANDRA ISAEVA	{"phone": "+70527276430"}
0005434426486	EB58E9	1955 559005	MIKHAIL VASILEV	{"phone": "+70136277096"}
0005434426487	F0306C	1539 057936	PETR ISAEV	{"phone": "+70315496288"}
0005434426488	643755	2568 280667	SERGEY ZAYCEV	{"email": "zaycev.s14021973@postgrespro.ru", "phone": "+70873748651"}
0005434426489	809BE4	5281 478185	ALEKSANDR MIRONOV	{"email": "amironov-071976@postgrespro.ru", "phone": "+70967233469"}
0005434426490	809BE4	4453 895182	ALBINA MALYSHEVA	{"email": "malysheva-albina01121967@postgrespro.ru", "phone": "+70639421030"}
0005434426491	E2C1A9	6762 192734	MARIYA KUZNECOVA	{"email": "m_kuznecova_16081968@postgrespro.ru", "phone": "+70665523759"}
0005434426492	E2C1A9	4616 480630	VLADIMIR SIDOROV	{"email": "vsidorov_1964@postgrespro.ru", "phone": "+70034245743"}
0005434426493	29BE38	5718 406358	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov-011981@postgrespro.ru", "phone": "+70735764082"}
0005434426494	29BE38	3154 368310	LYUBOV MAKAROVA	{"phone": "+70904034668"}
0005434426495	9CE9E6	0052 157347	VLADIMIR ROMANOV	{"email": "vladimir-romanov_1976@postgrespro.ru", "phone": "+70383784825"}
0005434426496	75FBEC	4838 471139	ALEKSEY ROMANOV	{"email": "romanov-aleksey-18021959@postgrespro.ru", "phone": "+70066218803"}
0005434426497	75FBEC	8710 109203	NINA TROFIMOVA	{"email": "trofimovan.07031987@postgrespro.ru", "phone": "+70513370376"}
0005434426498	E07738	0411 224911	NIKOLAY SERGEEV	{"email": "sergeev.nikolay-24081972@postgrespro.ru", "phone": "+70281347084"}
0005434426499	E07738	3873 722814	SERGEY MOISEEV	{"phone": "+70853749012"}
0005434426500	BB47CA	5349 392779	ALEKSANDR TIMOFEEV	{"email": "timofeevaleksandr_15071973@postgrespro.ru", "phone": "+70729753928"}
0005434426501	9E50BF	4518 683102	NIKOLAY VASILEV	{"email": "vasilev-n_1978@postgrespro.ru", "phone": "+70830140912"}
0005434426502	3B7ACF	7849 054979	ANNA NIKOLAEVA	{"phone": "+70512548455"}
0005434426503	7CE45F	8488 935991	ELIZAVETA MATVEEVA	{"email": "matveeva-elizaveta-051975@postgrespro.ru", "phone": "+70239199018"}
0005434426504	067BA6	4513 734721	ALEKSEY ALEKSEEV	{"phone": "+70244367503"}
0005434426505	067BA6	6290 775910	OLGA FILIPPOVA	{"email": "filippova-olga.031957@postgrespro.ru", "phone": "+70461949992"}
0005434426506	2D61F8	8334 674127	MARIYA KOVALEVA	{"phone": "+70135807282"}
0005434426507	2D61F8	4321 127206	VITALIY TARASOV	{"email": "v-tarasov081969@postgrespro.ru", "phone": "+70814541313"}
0005434426508	A43119	8576 798801	VYACHESLAV MATVEEV	{"email": "vyacheslav.matveev_031976@postgrespro.ru", "phone": "+70324447723"}
0005434426509	34B1C4	9521 103456	VALERIYA EGOROVA	{"email": "egorova_v.08071957@postgrespro.ru", "phone": "+70785474189"}
0005434426510	7A852F	0404 353232	ILYA VOROBEV	{"email": "ilya-vorobev-1982@postgrespro.ru", "phone": "+70310547531"}
0005434426511	F4593B	7478 794698	TATYANA BARANOVA	{"phone": "+70174014664"}
0005434426512	7978BB	5488 629638	MARIYA ZHURAVLEVA	{"email": "zhuravleva-mariya_111974@postgrespro.ru", "phone": "+70578307153"}
0005434426513	82FD3C	0990 153278	VLADIMIR VLASOV	{"email": "v_vlasov.25121967@postgrespro.ru", "phone": "+70958639481"}
0005434426514	82FD3C	4388 861681	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.nadezhda1977@postgrespro.ru", "phone": "+70999727019"}
0005434426515	222921	8483 853103	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_081974@postgrespro.ru", "phone": "+70810667849"}
0005434426516	222921	3321 150657	NINA OSIPOVA	{"phone": "+70279064540"}
0005434426517	9F7485	9531 365689	SERGEY IVANOV	{"phone": "+70677822024"}
0005434426518	9F7485	2837 015529	MARIYA KUZNECOVA	{"phone": "+70130112224"}
0005434426519	CAA9C5	7452 063033	LARISA SOROKINA	{"email": "l_sorokina_10091979@postgrespro.ru", "phone": "+70045663409"}
0005434426520	62DFAD	8228 397243	SVETLANA ALEKSEEVA	{"email": "alekseeva_svetlana1967@postgrespro.ru", "phone": "+70947115603"}
0005434426521	ACA6F8	6343 207473	RUSLAN KARPOV	{"email": "karpov-r_21101966@postgrespro.ru", "phone": "+70461602709"}
0005434426522	855066	1302 097101	SERGEY ANTONOV	{"email": "antonovs-11011962@postgrespro.ru", "phone": "+70278296286"}
0005434426523	335953	9956 489581	VLADISLAV ZAKHAROV	{"email": "zakharov_vladislav.09041975@postgrespro.ru", "phone": "+70856392383"}
0005434426524	C0D0F1	4210 989504	NATALYA SOROKINA	{"phone": "+70850588900"}
0005434426525	C0D0F1	8762 780303	ANASTASIYA GRISHINA	{"email": "grishina.a-091975@postgrespro.ru", "phone": "+70997175502"}
0005434426526	C0D3C9	8155 004484	FEDOR RODIONOV	{"email": "frodionov.1973@postgrespro.ru", "phone": "+70561962658"}
0005434426527	6C08EF	6017 305738	OKSANA MAKAROVA	{"phone": "+70422281992"}
0005434426528	5FCCD4	6509 619485	YAKOV VOLKOV	{"phone": "+70764105086"}
0005434426529	190812	0515 704589	ANDREY FOMIN	{"phone": "+70669793169"}
0005434426530	190812	9118 372269	ZINAIDA SOKOLOVA	{"phone": "+70367690691"}
0005434426531	EFEF5A	4050 193504	IRINA KOZLOVA	{"email": "kozlova_i_051967@postgrespro.ru", "phone": "+70703049806"}
0005434426532	EFEF5A	9094 282766	ANASTASIYA FROLOVA	{"email": "anastasiya.frolova011979@postgrespro.ru", "phone": "+70147040276"}
0005434426533	A24BDA	3156 225846	RAISA KOMAROVA	{"email": "komarova_raisa_22051966@postgrespro.ru", "phone": "+70829069402"}
0005434426534	72094B	7500 060462	NATALYA YUDINA	{"email": "natalya.yudina16091963@postgrespro.ru", "phone": "+70159141783"}
0005434426535	72094B	2756 686523	ELENA KISELEVA	{"phone": "+70377181954"}
0005434426536	D14192	7008 767172	MAKSIM ALEKSANDROV	{"email": "maksimaleksandrov101976@postgrespro.ru", "phone": "+70348741617"}
0005434426537	D14192	5478 918259	ANDREY DAVYDOV	{"phone": "+70554580222"}
0005434426538	F0B867	0396 776008	EVGENIYA IVANOVA	{"email": "ivanova_evgeniya30071969@postgrespro.ru", "phone": "+70015684420"}
0005434426539	6DEE30	3410 558500	NATALYA MOROZOVA	{"phone": "+70173436296"}
0005434426540	6DEE30	7061 239723	OKSANA KOZLOVA	{"phone": "+70120219393"}
0005434426541	365CF0	6790 637944	TATYANA NOVIKOVA	{"email": "novikovatatyana1974@postgrespro.ru", "phone": "+70849336429"}
0005434426542	4C5751	7604 897192	ALEKSANDR ALEKSEEV	{"phone": "+70812020311"}
0005434426543	E16B64	3172 655451	DARYA ALEKSANDROVA	{"email": "d.aleksandrova-121972@postgrespro.ru", "phone": "+70617530313"}
0005434426544	DD9783	4109 710661	MARINA MAKAROVA	{"email": "m-makarova-071973@postgrespro.ru", "phone": "+70001455402"}
0005434426545	3373E1	5113 957457	ALEKSEY VASILEV	{"phone": "+70260204225"}
0005434426546	9814BB	2895 362770	ILDAR GUSEV	{"email": "ildargusev_23081970@postgrespro.ru", "phone": "+70219335923"}
0005434426547	5BAAD8	0523 109105	NATALYA KOZLOVA	{"phone": "+70086679430"}
0005434426548	2F5273	9251 065420	SVETLANA FEDOROVA	{"email": "fedorova-svetlana121973@postgrespro.ru", "phone": "+70706164987"}
0005434426549	D28362	3971 975538	ALEKSEY TIKHONOV	{"phone": "+70864037931"}
0005434426550	AD4230	3622 767139	MIROSLAV SMIRNOV	{"email": "m.smirnov.061977@postgrespro.ru", "phone": "+70134869163"}
0005434426551	EAA618	8131 381029	NINA EFIMOVA	{"email": "efimova.n.1970@postgrespro.ru", "phone": "+70032361357"}
0005434426552	0D98E8	4769 863147	NATALYA KUZMINA	{"phone": "+70671611422"}
0005434426553	0B5FFA	0741 760989	NATALYA POPOVA	{"email": "n.popova_091968@postgrespro.ru", "phone": "+70288529149"}
0005434426554	45FD9B	5600 328283	ALEKSEY IVANOV	{"phone": "+70148476034"}
0005434426555	379BF2	9831 027218	VLADIMIR MAKAROV	{"phone": "+70949160864"}
0005434426556	7BD804	8664 414507	ALEKSANDR KARPOV	{"phone": "+70861294706"}
0005434426557	7BD804	4710 286694	DENIS SHEVCHENKO	{"phone": "+70648175633"}
0005434426558	7BD804	0690 453223	OLEG SOLOVEV	{"phone": "+70753211126"}
0005434426559	7BD804	2905 426503	NADEZHDA VASILEVA	{"email": "vasilevanadezhda_121962@postgrespro.ru", "phone": "+70333129984"}
0005434426560	CB2F1A	1689 699147	ALEKSANDR KARPOV	{"email": "karpovaleksandr-1976@postgrespro.ru", "phone": "+70864457735"}
0005434426561	CB2F1A	4166 078368	EVGENIY RODIONOV	{"phone": "+70788649846"}
0005434426562	EA7562	3690 731120	KIRILL ROMANOV	{"email": "romanov-k1985@postgrespro.ru", "phone": "+70956350254"}
0005434426563	F9529E	7603 559122	ALEKSANDR RODIONOV	{"phone": "+70642719722"}
0005434426564	F9529E	8587 954894	PAVEL YAKOVLEV	{"email": "p_yakovlev-18121962@postgrespro.ru", "phone": "+70960550008"}
0005434426565	F9529E	6887 275464	EKATERINA VASILEVA	{"email": "e-vasileva-041967@postgrespro.ru", "phone": "+70533221433"}
0005434426566	FA4E76	7519 112923	RAFAIL KUZMIN	{"email": "kuzmin.rafail_011973@postgrespro.ru", "phone": "+70259716145"}
0005434426567	12E74C	5167 266044	YURIY VOROBEV	{"email": "vorobev.y051975@postgrespro.ru", "phone": "+70001686661"}
0005434426568	D013EB	1175 051962	GALINA TROFIMOVA	{"email": "trofimova-galina-1963@postgrespro.ru", "phone": "+70123783331"}
0005434426569	D013EB	2952 830349	TATYANA FILATOVA	{"phone": "+70319581986"}
0005434426570	D013EB	9420 323759	NATALYA MARTYNOVA	{"phone": "+70166983947"}
0005434426571	518913	3882 103890	MARAT SOROKIN	{"phone": "+70027346433"}
0005434426572	E248BD	2955 835507	OLGA FOMINA	{"phone": "+70541359697"}
0005434426573	6E9FCA	5588 369810	LYUDMILA PAVLOVA	{"phone": "+70427163364"}
0005434426574	CC2F17	7123 882215	TATYANA ALEKSEEVA	{"phone": "+70113787057"}
0005434426575	24149C	2458 763012	DANILA VOLKOV	{"email": "volkov.d.29041967@postgrespro.ru", "phone": "+70670534290"}
0005434426576	24149C	0285 261147	ANASTASIYA NIKIFOROVA	{"email": "a.nikiforova.19071977@postgrespro.ru", "phone": "+70657845059"}
0005434426577	198EFC	6276 469071	ELENA CHERNOVA	{"phone": "+70225854545"}
0005434426578	4219ED	3187 220356	DMITRIY SEMENOV	{"email": "semenov.dmitriy03121965@postgrespro.ru", "phone": "+70157221906"}
0005434426579	7C057B	8155 671416	MARIYA ABRAMOVA	{"email": "abramova-mariya_1980@postgrespro.ru", "phone": "+70176703230"}
0005434426580	7C057B	2919 713752	YURIY SERGEEV	{"phone": "+70396444720"}
0005434426581	711265	2482 979844	OLEG BELOV	{"phone": "+70871387418"}
0005434426582	711265	7201 155435	YULIYA EGOROVA	{"email": "egorova.yuliya1977@postgrespro.ru", "phone": "+70987821029"}
0005434426642	55B0E5	9991 179154	TATYANA TITOVA	{"phone": "+70414322600"}
0005434426583	F54935	3423 343940	NIKOLAY NAUMOV	{"email": "naumov.nikolay-1959@postgrespro.ru", "phone": "+70884109468"}
0005434426584	2E136F	7549 142834	ARTEM NIKITIN	{"email": "a.nikitin06121967@postgrespro.ru", "phone": "+70349628090"}
0005434426585	C1A541	4844 133977	NIKOLAY KARPOV	{"email": "nikolaykarpov_061973@postgrespro.ru", "phone": "+70795653737"}
0005434426586	C1A541	6530 795775	LARISA ROMANOVA	{"phone": "+70045747226"}
0005434426587	58854A	2171 553883	MIKHAIL PAVLOV	{"email": "pavlov_mikhail.081958@postgrespro.ru", "phone": "+70773147927"}
0005434426588	58854A	8699 711226	ALEKSANDR FROLOV	{"phone": "+70023632289"}
0005434426589	205A18	5193 240828	ZINAIDA ARKHIPOVA	{"email": "z_arkhipova-1972@postgrespro.ru", "phone": "+70427570994"}
0005434426590	205A18	8182 640094	ALEKSANDR VASILEV	{"email": "avasilev22111976@postgrespro.ru", "phone": "+70060067574"}
0005434426591	FB14CB	0187 311507	IGOR SERGEEV	{"phone": "+70221540692"}
0005434426592	82D4EF	9983 591967	GENNADIY KAZAKOV	{"email": "kazakov_gennadiy_14101970@postgrespro.ru", "phone": "+70660320262"}
0005434426593	C956D1	8888 356446	ANNA CHERNOVA	{"phone": "+70792114930"}
0005434426594	C956D1	4342 147942	RAIL SHEVCHENKO	{"email": "r-shevchenko.101974@postgrespro.ru", "phone": "+70493866889"}
0005434426595	3D9EF2	2501 342737	TATYANA DAVYDOVA	{"email": "tdavydova091967@postgrespro.ru", "phone": "+70865237946"}
0005434426596	A39519	0783 760900	ROSTISLAV KUZNECOV	{"phone": "+70164470962"}
0005434426597	A39519	4514 962449	VERA YAKOVLEVA	{"phone": "+70485796900"}
0005434426598	6FD2BC	7393 422703	EMIL TIMOFEEV	{"phone": "+70922756941"}
0005434426599	FE6A2F	7527 414967	ALEKSANDRA GERASIMOVA	{"phone": "+70334243324"}
0005434426600	DFC9FB	4657 623456	STANISLAV SOROKIN	{"phone": "+70175446634"}
0005434426601	DFC9FB	7634 782680	ALEKSEY TIKHONOV	{"phone": "+70814492681"}
0005434426602	DFC9FB	1069 245023	DMITRIY BONDARENKO	{"email": "d.bondarenko.111969@postgrespro.ru", "phone": "+70948128058"}
0005434426603	DCD058	4868 395937	EVGENIY KOZLOV	{"email": "e.kozlov_1965@postgrespro.ru", "phone": "+70050887985"}
0005434426604	7F1852	5869 910509	ALEKSEY TIKHONOV	{"phone": "+70517990895"}
0005434426605	619DB8	9736 437306	MIKHAIL YAKOVLEV	{"email": "yakovlev_m_30011977@postgrespro.ru", "phone": "+70660901700"}
0005434426606	5904F6	1859 272313	SERGEY SOKOLOV	{"phone": "+70935207805"}
0005434426607	36B9B5	7436 573108	VALENTINA ANDREEVA	{"email": "valentina-andreeva.071966@postgrespro.ru", "phone": "+70138263266"}
0005434426608	4466D3	8097 157644	ALEKSANDR FEDOROV	{"phone": "+70884285550"}
0005434426609	4466D3	0413 534351	SVETLANA GERASIMOVA	{"phone": "+70761840968"}
0005434426610	C63E12	8565 747807	SERGEY BARANOV	{"email": "sergey_baranov-21031975@postgrespro.ru", "phone": "+70393523495"}
0005434426611	6D7BA7	2972 064703	KLAVDIYA MEDVEDEVA	{"email": "medvedeva-k.23101982@postgrespro.ru", "phone": "+70649244450"}
0005434426612	D91169	7031 581968	YAKOV KAZAKOV	{"email": "y.kazakov1966@postgrespro.ru", "phone": "+70724203507"}
0005434426613	0AA5EB	3390 802190	TATYANA KAZAKOVA	{"phone": "+70505814304"}
0005434426614	782BA2	5599 480025	NATALYA YUDINA	{"email": "yudinan_20071963@postgrespro.ru", "phone": "+70839264171"}
0005434426615	640179	2479 547998	VLADIMIR KULIKOV	{"email": "kulikovvladimir_1971@postgrespro.ru", "phone": "+70139781890"}
0005434426616	EB8DC1	2693 531527	VLADIMIR EGOROV	{"email": "egorov-vladimir_18011962@postgrespro.ru", "phone": "+70572982862"}
0005434426617	73A810	6458 567995	LYUDMILA STEPANOVA	{"phone": "+70326876435"}
0005434426618	367590	8236 630621	ANASTASIYA VASILEVA	{"phone": "+70981041937"}
0005434426619	981456	6455 172775	ELENA MOROZOVA	{"email": "elena-morozova.051973@postgrespro.ru", "phone": "+70343572016"}
0005434426620	5D9CF5	3919 479089	OLGA IVANOVA	{"phone": "+70359758537"}
0005434426621	5D9CF5	2973 477738	TAISIYA BELYAEVA	{"email": "belyaeva.t_04051972@postgrespro.ru", "phone": "+70337015313"}
0005434426622	0DC72A	3122 432930	STANISLAV PETROV	{"email": "petrov-s_1966@postgrespro.ru", "phone": "+70312949978"}
0005434426623	E7220A	7538 118560	RAUF SCHERBAKOV	{"phone": "+70823390305"}
0005434426624	C6FFE7	6122 523925	PAVEL ZAKHAROV	{"email": "p-zakharov-1976@postgrespro.ru", "phone": "+70648393883"}
0005434426625	7752E3	7796 056201	EKATERINA NIKOLAEVA	{"email": "nikolaevaekaterina.12031977@postgrespro.ru", "phone": "+70329958365"}
0005434426626	7752E3	9668 975041	TATYANA MAKSIMOVA	{"phone": "+70045945614"}
0005434426627	EE8670	6150 513386	SOFIYA EGOROVA	{"phone": "+70450573990"}
0005434426628	9E3152	5357 344379	MILANA VOROBEVA	{"email": "milanavorobeva.1963@postgrespro.ru", "phone": "+70549561888"}
0005434426629	9E3152	1273 759749	VALERIY ZHUKOV	{"phone": "+70629522257"}
0005434426630	2D1EBB	0651 013809	LILIYA YAKOVLEVA	{"phone": "+70055078201"}
0005434426631	013537	5478 879424	ILYA DAVYDOV	{"email": "davydov.i1971@postgrespro.ru", "phone": "+70679510915"}
0005434426632	013537	0902 680049	OLESYA KUZNECOVA	{"email": "okuznecova_071974@postgrespro.ru", "phone": "+70658445976"}
0005434426633	013537	2320 844218	FEDOR GUSEV	{"email": "gusev_f_101976@postgrespro.ru", "phone": "+70297531311"}
0005434426634	7808A6	7341 595868	SERGEY PETROV	{"phone": "+70504665539"}
0005434426635	7808A6	9636 559563	VLADISLAV PETROV	{"email": "vladislav_petrov.011977@postgrespro.ru", "phone": "+70636904664"}
0005434426636	024B17	8701 662192	NATALYA AKIMOVA	{"phone": "+70125087919"}
0005434426637	FF82DE	9687 817625	VIKTOR SEMENOV	{"phone": "+70931936188"}
0005434426638	C49C0A	8688 349108	NATALYA KOMAROVA	{"email": "natalya-komarova08091979@postgrespro.ru", "phone": "+70820565668"}
0005434426639	C49C0A	9901 894447	ALEKSEY ZAKHAROV	{"email": "zakharov_a.011974@postgrespro.ru", "phone": "+70104746966"}
0005434426640	A9EEC9	7623 972724	OLESYA KAZAKOVA	{"email": "o_kazakova_031974@postgrespro.ru", "phone": "+70439806284"}
0005434426641	A9EEC9	3347 725979	LYUDMILA MAKSIMOVA	{"email": "maksimova-l_1968@postgrespro.ru", "phone": "+70755622756"}
0005434426643	55B0E5	3232 978348	KRISTINA IVANOVA	{"email": "kristina-ivanova-1970@postgrespro.ru", "phone": "+70698881299"}
0005434426644	55B0E5	9755 770700	YULIYA MALYSHEVA	{"email": "malysheva_y051963@postgrespro.ru", "phone": "+70769870436"}
0005434426645	E62AF1	6186 028838	VLADIMIR STEPANOV	{"phone": "+70561260871"}
0005434426646	E62AF1	7673 317544	SERGEY TARASOV	{"email": "s.tarasov-1964@postgrespro.ru", "phone": "+70241662594"}
0005434426647	7AA8CB	8733 548216	SERGEY KARPOV	{"phone": "+70905030449"}
0005434426648	7AA8CB	3091 443247	OLEG ALEKSEEV	{"email": "alekseev.o.1971@postgrespro.ru", "phone": "+70125040459"}
0005434426649	300408	8146 629736	VERA PETROVA	{"email": "vpetrova.1963@postgrespro.ru", "phone": "+70123617005"}
0005434426650	75E86D	8930 804632	KUZMA TARASOV	{"email": "tarasov_kuzma-1976@postgrespro.ru", "phone": "+70491262319"}
0005434426651	75E86D	1576 330806	DMITRIY EGOROV	{"email": "egorov.d1961@postgrespro.ru", "phone": "+70517602745"}
0005434426652	FF7CB5	8775 556692	OLGA SMIRNOVA	{"email": "o-smirnova_1964@postgrespro.ru", "phone": "+70663424474"}
0005434426653	C3DFDB	4761 817123	PAVEL VOLKOV	{"email": "pavelvolkov_23081968@postgrespro.ru", "phone": "+70658064121"}
0005434426654	C3DFDB	5493 187276	OLEG IVANOV	{"phone": "+70042164870"}
0005434426655	0B5DC6	1736 214501	NATALYA MAKAROVA	{"phone": "+70496589037"}
0005434426656	48437E	0024 365214	OLEG KUZNECOV	{"phone": "+70511823072"}
0005434426657	07F71A	2904 988964	MARINA ANISIMOVA	{"phone": "+70328735182"}
0005434426658	532571	1183 082596	YULIYA PETROVA	{"phone": "+70765498740"}
0005434426659	A05C7D	7457 597777	VALERIY SERGEEV	{"email": "sergeev-v-1960@postgrespro.ru", "phone": "+70598802927"}
0005434426660	A05C7D	3445 542211	SVETLANA KUZNECOVA	{"phone": "+70431949770"}
0005434426661	47EFBE	6071 298156	LYUBOV GUSEVA	{"email": "l-guseva_111972@postgrespro.ru", "phone": "+70651758360"}
0005434426662	A58B77	0072 800898	TATYANA MASLOVA	{"phone": "+70673876271"}
0005434426663	1D2CB9	9062 475434	SERGEY ALEKSEEV	{"phone": "+70089770230"}
0005434426664	21BCBD	1694 310853	DMITRIY GAVRILOV	{"email": "gavrilov-d.13031982@postgrespro.ru", "phone": "+70810457997"}
0005434426665	21BCBD	9033 224050	ZINAIDA ALEKSEEVA	{"phone": "+70444513174"}
0005434426666	E21F54	8684 838476	LYUBOV KOZLOVA	{"phone": "+70914310504"}
0005434426667	F93F17	5513 105605	SERGEY PETROV	{"phone": "+70705032753"}
0005434426668	F93F17	9798 505410	SERGEY NIKOLAEV	{"email": "nikolaev_sergey021966@postgrespro.ru", "phone": "+70197327875"}
0005434426669	F93F17	3574 167499	RAFAIL SCHERBAKOV	{"email": "rscherbakov.021973@postgrespro.ru", "phone": "+70191110640"}
0005434426670	45EC2C	5809 020884	VALENTINA ZAKHAROVA	{"phone": "+70049535626"}
0005434426671	89B788	3322 491011	TAMARA VOROBEVA	{"email": "tvorobeva-021962@postgrespro.ru", "phone": "+70952366670"}
0005434426673	8176C6	3566 136549	DARYA YUDINA	{"phone": "+70880123501"}
0005434426674	114919	2676 135346	GEORGIY ROMANOV	{"phone": "+70774750130"}
0005434426675	114919	8500 872132	OLGA KOVALEVA	{"email": "kovalevao_031974@postgrespro.ru", "phone": "+70045478856"}
0005434426676	EB25AC	8659 638675	ALEKSANDR KOZLOV	{"email": "kozlov_a-1981@postgrespro.ru", "phone": "+70107020856"}
0005434426677	EB25AC	2339 949749	ALEKSEY KUZMIN	{"phone": "+70097675736"}
0005434426678	EB25AC	6716 804682	LIDIYA ERMAKOVA	{"email": "ermakova_lidiya-071978@postgrespro.ru", "phone": "+70989225885"}
0005434426679	957C4E	3087 488749	DMITRIY MELNIKOV	{"phone": "+70510992019"}
0005434426680	84749E	3154 842826	VITALIY IVANOV	{"email": "ivanovvitaliy.1968@postgrespro.ru", "phone": "+70814152986"}
0005434426681	84749E	6769 514056	IRINA ARKHIPOVA	{"email": "iarkhipova.121967@postgrespro.ru", "phone": "+70046425191"}
0005434426682	615265	8302 356126	NATALYA KAZAKOVA	{"email": "kazakova_natalya02041969@postgrespro.ru", "phone": "+70045903931"}
0005434426683	615265	8845 153264	RAISA SOLOVEVA	{"email": "raisasoloveva_081976@postgrespro.ru", "phone": "+70472359378"}
0005434426684	615265	8335 735758	VADIM CHERNOV	{"email": "chernov_vadim.121962@postgrespro.ru", "phone": "+70309582880"}
0005434426685	4551A2	1842 776248	MIKHAIL TIMOFEEV	{"phone": "+70023317226"}
0005434426686	4551A2	1762 721411	GALINA MOROZOVA	{"phone": "+70003535689"}
0005434426687	090C22	4432 271112	EKATERINA ANDREEVA	{"email": "andreevae-14051968@postgrespro.ru", "phone": "+70639151126"}
0005434426688	090C22	5796 720672	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy-111972@postgrespro.ru", "phone": "+70987071238"}
0005434426689	BADD1D	7591 008771	ANTONINA MIRONOVA	{"email": "antonina-mironova-121976@postgrespro.ru", "phone": "+70956646611"}
0005434426690	BADD1D	7542 605010	ZLATA YUDINA	{"email": "zyudina.071983@postgrespro.ru", "phone": "+70020032919"}
0005434426691	F9BA35	2562 055136	NIKITA MIKHAYLOV	{"phone": "+70291625038"}
0005434426692	F9BA35	9059 910663	KARINA MAKAROVA	{"email": "karina-makarova.1976@postgrespro.ru", "phone": "+70861369630"}
0005434426693	188769	3626 797581	ANASTASIYA MALYSHEVA	{"email": "amalysheva_1961@postgrespro.ru", "phone": "+70630056278"}
0005434426694	188769	9320 109390	DMITRIY MARTYNOV	{"email": "martynov.d-1961@postgrespro.ru", "phone": "+70945063571"}
0005434426695	0EA904	1959 870218	VALENTINA MARTYNOVA	{"phone": "+70503637131"}
0005434426696	2697EB	1541 699544	IRINA IVANOVA	{"phone": "+70883964621"}
0005434426697	ED80A2	4368 814982	ALEKSANDR MOROZOV	{"phone": "+70639677093"}
0005434426698	8F3B2D	6337 524359	ANATOLIY SEMENOV	{"email": "anatoliy.semenov.041977@postgrespro.ru", "phone": "+70365993140"}
0005434426699	8F3B2D	5524 059724	ELENA FEDOROVA	{"phone": "+70356461398"}
0005434426700	AC397C	1131 113332	NATALYA KUZMINA	{"email": "kuzmina_n-14081966@postgrespro.ru", "phone": "+70347902488"}
0005434426701	AC397C	7708 906690	SERGEY STEPANOV	{"phone": "+70651195675"}
0005434426702	6682EE	8182 028529	ALEKSANDR ILIN	{"phone": "+70934771440"}
0005434426703	6682EE	2387 889277	GALINA MIRONOVA	{"phone": "+70213536409"}
0005434426704	F89308	0601 226806	ALEKSANDRA TIMOFEEVA	{"email": "atimofeeva121967@postgrespro.ru", "phone": "+70210412222"}
0005434426705	11126F	6311 715804	KONSTANTIN IVANOV	{"email": "ivanovkonstantin_1971@postgrespro.ru", "phone": "+70222061525"}
0005434426706	2DCE25	0496 570185	GALINA EFREMOVA	{"email": "efremova_g11081966@postgrespro.ru", "phone": "+70518431919"}
0005434426707	1BBFAE	1318 619120	DMITRIY KUZNECOV	{"email": "d_kuznecov-071985@postgrespro.ru", "phone": "+70988399004"}
0005434426708	2BC58D	8543 507967	VALENTINA KOMAROVA	{"email": "valentina_komarova.1963@postgrespro.ru", "phone": "+70452389733"}
0005434426709	B79322	1685 142902	SERGEY BORISOV	{"phone": "+70284463955"}
0005434426710	759A90	3936 574620	VASILIY ALEKSEEV	{"email": "alekseev-vasiliy-1964@postgrespro.ru", "phone": "+70065088233"}
0005434426711	F38780	2071 499846	EKATERINA ZOTOVA	{"email": "zotovaekaterina.1972@postgrespro.ru", "phone": "+70767155707"}
0005434426712	4E31D3	3535 389870	NATALYA ZAKHAROVA	{"email": "zakharovan-10111965@postgrespro.ru", "phone": "+70998377370"}
0005434426713	47158C	1554 056418	DMITRIY DENISOV	{"email": "denisovd_04101975@postgrespro.ru", "phone": "+70843910293"}
0005434426714	DCED4D	4896 728780	MATVEY STEPANOV	{"phone": "+70370593252"}
0005434426715	8F7289	0388 804603	ELENA BELYAEVA	{"email": "e_belyaeva-091973@postgrespro.ru", "phone": "+70053617306"}
0005434426716	7AB59E	9466 118466	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr.19111982@postgrespro.ru", "phone": "+70585544839"}
0005434426717	4421C6	2440 752840	PAVEL PETROV	{"phone": "+70713429862"}
0005434426718	4421C6	2138 143922	DMITRIY MAKAROV	{"email": "makarovdmitriy.011977@postgrespro.ru", "phone": "+70518857021"}
0005434426719	82A81A	9029 189314	SVETLANA PETROVA	{"email": "svetlana_petrova_011971@postgrespro.ru", "phone": "+70568091291"}
0005434426720	8F91F3	7628 967556	VALERIY PETROV	{"phone": "+70758960871"}
0005434426721	B51970	2983 966091	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr_021976@postgrespro.ru", "phone": "+70629918563"}
0005434426722	D67437	1917 169079	ILGIZ KUZNECOV	{"phone": "+70285943294"}
0005434426723	031B74	9095 274709	IVAN NIKITIN	{"phone": "+70304061394"}
0005434426724	331395	0634 435777	KONSTANTIN VLASOV	{"email": "konstantin_vlasov_25061977@postgrespro.ru", "phone": "+70151529243"}
0005434426725	2B5898	9985 166796	ANNA ZAYCEVA	{"phone": "+70552018474"}
0005434426726	8B8188	4322 121761	YURIY SAVELEV	{"phone": "+70590508667"}
0005434426727	E488D0	3168 818332	GALINA KUZMINA	{"phone": "+70098854964"}
0005434426728	330E30	1360 947934	ALEKSANDRA KUZNECOVA	{"phone": "+70948181906"}
0005434426729	8D3CC0	1459 081511	DENIS FEDOTOV	{"phone": "+70886907287"}
0005434426730	B1113D	3374 982923	KIRILL SIDOROV	{"phone": "+70774510725"}
0005434426731	C357B4	2453 361329	ALEKSEY MAKSIMOV	{"phone": "+70378267370"}
0005434426732	C357B4	3718 075228	MIKHAIL SMIRNOV	{"phone": "+70923255948"}
0005434426733	D3A25A	0827 690479	VIKTOR FROLOV	{"phone": "+70352908294"}
0005434426734	D3A25A	9642 164607	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov1984@postgrespro.ru", "phone": "+70913128199"}
0005434426735	5AFADB	8444 765474	PETR TIKHONOV	{"phone": "+70937792388"}
0005434426736	5AFADB	2558 483019	ANDREY PAVLOV	{"email": "pavlov_andrey1978@postgrespro.ru", "phone": "+70869372095"}
0005434426737	266FE9	4096 052970	TATYANA KUDRYASHOVA	{"email": "tkudryashova111974@postgrespro.ru", "phone": "+70527353775"}
0005434426738	06A504	5734 933331	EVGENIY FROLOV	{"phone": "+70674097141"}
0005434426739	06A504	4796 191319	GALINA NIKITINA	{"email": "nikitinagalina.1965@postgrespro.ru", "phone": "+70864943193"}
0005434426740	9BE638	4624 376000	VLADIMIR TARASOV	{"phone": "+70506977301"}
0005434426741	65F66D	3135 843665	NIKOLAY IVANOV	{"email": "ivanov.n_15041977@postgrespro.ru", "phone": "+70541193708"}
0005434426742	45D7E9	6952 291274	YULIYA KUZNECOVA	{"email": "ykuznecova.1982@postgrespro.ru", "phone": "+70901466272"}
0005434426743	7435FA	6875 397129	ARTUR VASILEV	{"email": "vasilev-artur22031961@postgrespro.ru", "phone": "+70643839375"}
0005434426744	7435FA	4423 883754	VERONIKA ORLOVA	{"phone": "+70189830163"}
0005434426745	7FB83F	2111 405287	KLAVDIYA POPOVA	{"phone": "+70882100801"}
0005434426746	06C2E7	0909 905777	VLADIMIR NAZAROV	{"email": "nazarovv_1959@postgrespro.ru", "phone": "+70041356046"}
0005434426747	46F14E	0134 222579	ARTUR ANDREEV	{"phone": "+70191665367"}
0005434426748	96CBA9	5578 448012	KONSTANTIN SOROKIN	{"phone": "+70781957253"}
0005434426749	97DC03	1944 197666	EKATERINA NAZAROVA	{"phone": "+70268313336"}
0005434426750	958B8A	5350 988718	VLADIMIR KULIKOV	{"email": "kulikov-vladimir.30101980@postgrespro.ru", "phone": "+70697975660"}
0005434426751	1BB51C	8040 617855	DANIS MOROZOV	{"email": "morozov.d041977@postgrespro.ru", "phone": "+70210756472"}
0005434426752	1BB51C	1573 041310	YULIYA KOROLEVA	{"email": "korolevay_18111983@postgrespro.ru", "phone": "+70500901951"}
0005434426753	260CDB	4053 468072	ARTEM KOZLOV	{"email": "kozlov_artem-15041966@postgrespro.ru", "phone": "+70890431765"}
0005434426754	BE7C42	1010 303475	OLGA MASLOVA	{"email": "o_maslova-031974@postgrespro.ru", "phone": "+70229984018"}
0005434426755	BE7C42	4193 482931	ALEKSANDRA KONOVALOVA	{"email": "a.konovalova.041975@postgrespro.ru", "phone": "+70071610972"}
0005434426756	9D551D	0225 840445	VALERIY FEDOTOV	{"email": "fedotovv-1975@postgrespro.ru", "phone": "+70736023727"}
0005434426757	9D551D	3512 049411	VALENTINA VASILEVA	{"phone": "+70421600405"}
0005434426812	44BF96	2607 788149	OLGA ZAYCEVA	{"phone": "+70641280518"}
0005434426758	C919A2	6629 776641	SERGEY KUZNECOV	{"email": "sergey-kuznecov-24061978@postgrespro.ru", "phone": "+70178657797"}
0005434426759	C919A2	4571 622146	IGOR VOLKOV	{"email": "igor-volkov.1972@postgrespro.ru", "phone": "+70755844583"}
0005434426760	EF300F	4249 036987	ALEKSANDR KUZNECOV	{"email": "kuznecov-a-23011986@postgrespro.ru", "phone": "+70358278914"}
0005434426761	0B6B88	6920 812067	OLGA OVCHINNIKOVA	{"email": "ovchinnikova.olga101973@postgrespro.ru", "phone": "+70838703736"}
0005434426762	1D9428	3390 843619	ANNA TARASOVA	{"email": "tarasovaa1960@postgrespro.ru", "phone": "+70418675525"}
0005434426763	35F462	4423 875722	SERGEY KUZNECOV	{"email": "kuznecovs_09021969@postgrespro.ru", "phone": "+70633900268"}
0005434426764	4AF591	8812 939647	RENAT MARTYNOV	{"email": "renat.martynov-19031977@postgrespro.ru", "phone": "+70743221186"}
0005434426765	4AF591	2980 054915	VYACHESLAV SOROKIN	{"email": "v_sorokin-011973@postgrespro.ru", "phone": "+70348254069"}
0005434426766	CB7F8D	7376 412305	ILYA SIDOROV	{"phone": "+70521994605"}
0005434426767	A8240F	4248 628508	YURIY GORBUNOV	{"email": "yuriy-gorbunov-1973@postgrespro.ru", "phone": "+70117667024"}
0005434426768	A8240F	6614 876606	EVGENIY KUZNECOV	{"email": "kuznecov.e05031976@postgrespro.ru", "phone": "+70467491807"}
0005434426769	D13C48	5047 786242	ANDREY FEDOROV	{"email": "a.fedorov-101972@postgrespro.ru", "phone": "+70555417193"}
0005434426770	653631	8387 539647	MARAT KUZNECOV	{"email": "kuznecov.marat_1970@postgrespro.ru", "phone": "+70723623860"}
0005434426771	959FDC	0744 028897	NATALIYA MAKAROVA	{"email": "makarovan_011967@postgrespro.ru", "phone": "+70954273632"}
0005434426772	978762	7956 478189	NIKOLAY KONOVALOV	{"phone": "+70334855381"}
0005434426773	978762	2686 419659	LIDIYA DMITRIEVA	{"phone": "+70418914521"}
0005434426774	787265	5438 823467	LYUDMILA ZAKHAROVA	{"phone": "+70912162736"}
0005434426775	787265	4007 778157	EVDOKIYA KOVALEVA	{"phone": "+70615912406"}
0005434426776	9741D0	6707 988767	MARIYA TARASOVA	{"email": "tarasova-m.1965@postgrespro.ru", "phone": "+70616493008"}
0005434426777	C10EF6	4718 835974	ELENA TIKHONOVA	{"phone": "+70700633759"}
0005434426778	29DE1A	5502 208486	OLGA KUZNECOVA	{"email": "kuznecovaolga.071975@postgrespro.ru", "phone": "+70690369172"}
0005434426779	29DE1A	7132 200153	OLEG PETROV	{"email": "petrov_o.021970@postgrespro.ru", "phone": "+70824697210"}
0005434426780	A35456	5347 477017	ANDREY SOKOLOV	{"email": "sokolova.091971@postgrespro.ru", "phone": "+70922898609"}
0005434426781	A35456	6631 598809	ALEKSEY SAVELEV	{"email": "savelev-a-071972@postgrespro.ru", "phone": "+70885236382"}
0005434426782	DF2999	5435 994410	MAKSIM GAVRILOV	{"phone": "+70452782363"}
0005434426783	DF2999	2765 048381	NADEZHDA ZAYCEVA	{"email": "nzayceva_24081967@postgrespro.ru", "phone": "+70854285828"}
0005434426784	542001	8780 210745	TATYANA NAZAROVA	{"email": "tnazarova_011969@postgrespro.ru", "phone": "+70959005375"}
0005434426785	01D5F2	2033 073095	ANNA VOLKOVA	{"email": "anna-volkova1953@postgrespro.ru", "phone": "+70793886520"}
0005434426786	EB94AF	9002 955778	GENNADIY IVANOV	{"phone": "+70071746330"}
0005434426787	2F2FAF	3668 151511	GALINA KONDRATEVA	{"email": "kondrateva.galina_1974@postgrespro.ru", "phone": "+70931481786"}
0005434426788	2F2FAF	3538 842852	NIKOLAY MAKSIMOV	{"email": "maksimovnikolay-28061979@postgrespro.ru", "phone": "+70295777714"}
0005434426789	53C6A3	2776 378769	VIKTOR ZHURAVLEV	{"email": "zhuravlevviktor_051972@postgrespro.ru", "phone": "+70014308897"}
0005434426790	6C6B8D	7717 374356	MIKHAIL SAVELEV	{"email": "savelevm-081984@postgrespro.ru", "phone": "+70027377495"}
0005434426791	6C6B8D	8183 903538	LYUBOV VOROBEVA	{"email": "lvorobeva.1981@postgrespro.ru", "phone": "+70623779923"}
0005434426792	6C6B8D	6668 396717	OLGA POPOVA	{"email": "o_popova03041966@postgrespro.ru", "phone": "+70628903913"}
0005434426793	2BC200	8703 598997	NINA MIRONOVA	{"email": "nmironova.061969@postgrespro.ru", "phone": "+70780968863"}
0005434426794	7D142D	6742 039023	DARYA BOGDANOVA	{"email": "darya-bogdanova_011973@postgrespro.ru", "phone": "+70060058793"}
0005434426795	C17F39	0726 791708	NINA ERMAKOVA	{"phone": "+70372277754"}
0005434426796	C17F39	4016 611569	NATALYA NAUMOVA	{"phone": "+70438675700"}
0005434426797	C17F39	2014 087932	EVGENIY KAZAKOV	{"email": "evgeniy.kazakov30081980@postgrespro.ru", "phone": "+70481642572"}
0005434426798	36368C	3996 038236	ELENA ZHUKOVA	{"email": "e.zhukova-021985@postgrespro.ru", "phone": "+70808690253"}
0005434426799	2483B4	0573 928442	NADEZHDA MAKAROVA	{"email": "n-makarova.13031976@postgrespro.ru", "phone": "+70729164106"}
0005434426800	2483B4	1077 718651	ANASTASIYA MALYSHEVA	{"phone": "+70058101273"}
0005434426801	421494	1511 546399	IRINA KUZMINA	{"phone": "+70650459463"}
0005434426802	7E32C6	6373 122440	TAMARA VOLKOVA	{"email": "volkova.tamara.101958@postgrespro.ru", "phone": "+70819507922"}
0005434426803	7E32C6	6245 376884	OLEG IVANOV	{"phone": "+70330462962"}
0005434426804	7E32C6	1297 108368	NATALYA PAVLOVA	{"phone": "+70330948656"}
0005434426805	3487DF	7821 672098	DMITRIY MOROZOV	{"email": "dmitriy-morozov.30081969@postgrespro.ru", "phone": "+70006844056"}
0005434426806	59E487	9582 308308	RAISA NOVIKOVA	{"email": "raisa-novikova_1966@postgrespro.ru", "phone": "+70210521685"}
0005434426807	046862	7960 092830	VERA FILATOVA	{"email": "vfilatova_101962@postgrespro.ru", "phone": "+70740829310"}
0005434426808	046862	6677 252856	MARINA KOROLEVA	{"email": "korolevamarina_1969@postgrespro.ru", "phone": "+70072908854"}
0005434426809	AAE20D	1261 997579	SVETLANA LOGINOVA	{"email": "s.loginova.1974@postgrespro.ru", "phone": "+70204402572"}
0005434426810	C7F642	0112 317229	KRISTINA KUZMINA	{"phone": "+70642077568"}
0005434426811	C7F642	0928 007967	EVGENIY TIKHONOV	{"phone": "+70931640751"}
0005434426813	B045B8	0449 051172	YULIYA FROLOVA	{"phone": "+70593801477"}
0005434426814	0743CD	9653 306418	MARIYA KUZNECOVA	{"email": "mariya-kuznecova_1974@postgrespro.ru", "phone": "+70456939806"}
0005434426815	4BE0DE	8923 186250	ALEKSANDR PAVLOV	{"email": "pavlova.121974@postgrespro.ru", "phone": "+70805856831"}
0005434426816	BDA442	2110 777754	VALERIY SIDOROV	{"phone": "+70818230609"}
0005434426817	BDA442	5210 332805	MAKSIM VOLKOV	{"phone": "+70741746728"}
0005434426818	AC47A3	7057 268215	YURIY FEDOROV	{"phone": "+70353121238"}
0005434426819	05E017	5796 159341	ALEKSANDR OSIPOV	{"email": "osipov-aleksandr041968@postgrespro.ru", "phone": "+70637280288"}
0005434426820	61B7F6	7397 809595	NIKOLAY KUZNECOV	{"email": "kuznecov-n-12041977@postgrespro.ru", "phone": "+70837530501"}
0005434426821	38983B	6535 305974	LYUBOV POPOVA	{"email": "lyubov-popova-1966@postgrespro.ru", "phone": "+70720020503"}
0005434426822	38983B	4618 666947	ARSENIY MOROZOV	{"phone": "+70928718921"}
0005434426823	38983B	1212 846391	NATALYA NESTEROVA	{"email": "nnesterova081972@postgrespro.ru", "phone": "+70522409425"}
0005434426824	B4BB5F	5099 090806	VLADIMIR CHERNOV	{"phone": "+70111751234"}
0005434426825	242DD4	0880 018689	IRINA ROMANOVA	{"email": "irina-romanova-03111975@postgrespro.ru", "phone": "+70777956619"}
0005434426826	76D563	5473 672891	ILDAR VLASOV	{"email": "vlasovi.31031972@postgrespro.ru", "phone": "+70848140749"}
0005434426827	76D563	2294 672733	LEONID DENISOV	{"email": "l-denisov041972@postgrespro.ru", "phone": "+70588615490"}
0005434426828	76D563	9563 436020	VLADIMIR SHEVCHENKO	{"phone": "+70886187112"}
0005434426829	45A77F	7479 863886	LYUBOV IVANOVA	{"phone": "+70963544750"}
0005434426830	45A77F	0587 611552	ANASTASIYA FILATOVA	{"email": "anastasiya.filatova.06071977@postgrespro.ru", "phone": "+70182340190"}
0005434426831	C5EC12	9230 195813	DANILA BELOV	{"email": "belov-d-1964@postgrespro.ru", "phone": "+70116528638"}
0005434426832	E2A074	1724 540273	VALERIY TIMOFEEV	{"phone": "+70333716870"}
0005434426833	E2A074	6711 245598	NIKOLAY CHERNOV	{"email": "n-chernov.1971@postgrespro.ru", "phone": "+70245846085"}
0005434426834	820BAF	5737 733801	VASILIY KUZNECOV	{"phone": "+70827676125"}
0005434426835	820BAF	9733 612713	VLADIMIR NIKITIN	{"email": "nikitin.vladimir_1985@postgrespro.ru", "phone": "+70029796767"}
0005434426836	92717D	1333 636665	ALEKSANDR PAVLOV	{"email": "pavlov_a1971@postgrespro.ru", "phone": "+70119127779"}
0005434426837	EE8D0E	4170 220203	GALINA ORLOVA	{"email": "galina.orlova-121979@postgrespro.ru", "phone": "+70128641062"}
0005434426838	FFA946	6516 227021	ANDREY MIRONOV	{"phone": "+70993268980"}
0005434426839	A99F34	8796 611868	TATYANA SOLOVEVA	{"phone": "+70312049643"}
0005434426840	356FB1	5709 508927	OLEG DMITRIEV	{"phone": "+70478254534"}
0005434426841	20152B	6448 013459	ARTEM KULIKOV	{"phone": "+70362306385"}
0005434426842	DE73E7	4373 823115	ALEKSEY GRIGOREV	{"email": "grigorevaleksey.011976@postgrespro.ru", "phone": "+70940163382"}
0005434426843	84F7FA	4734 773057	DMITRIY GORBUNOV	{"phone": "+70955033126"}
0005434426844	6F1D5A	4436 133920	MIKHAIL MEDVEDEV	{"phone": "+70436719578"}
0005434426845	8B4629	4673 675362	OLESYA PETROVA	{"email": "olesya-petrova-05021964@postgrespro.ru", "phone": "+70018771241"}
0005434426846	4699D0	9630 575616	ALEKSEY ZAKHAROV	{"phone": "+70605222439"}
0005434426847	4699D0	4123 221796	ANTONINA GUSEVA	{"phone": "+70341192652"}
0005434426848	CEDA67	6340 111368	SERGEY DAVYDOV	{"email": "davydovs.121969@postgrespro.ru", "phone": "+70051717195"}
0005434426849	E7B131	4803 800167	ANTONINA OSIPOVA	{"phone": "+70563554588"}
0005434426850	134A28	7755 237295	PAVEL MIRONOV	{"phone": "+70283746458"}
0005434426851	B8907A	3444 024036	NATALYA TIKHONOVA	{"phone": "+70391512510"}
0005434426852	B8907A	6301 374313	LYUBOV EGOROVA	{"phone": "+70808404842"}
0005434426853	B8907A	5852 568378	KRISTINA SAVELEVA	{"phone": "+70379172580"}
0005434426854	90D7D7	9295 136250	MAKSIM MOISEEV	{"phone": "+70875796953"}
0005434426855	90D7D7	6144 223591	VALERIY ABRAMOV	{"email": "valeriy_abramov-091969@postgrespro.ru", "phone": "+70845131872"}
0005434426856	DB9FFB	8656 977844	LYUBOV IVANOVA	{"phone": "+70394087248"}
0005434426857	BE22DB	9062 674220	ALEKSANDR GORBUNOV	{"phone": "+70454493739"}
0005434426858	8129FC	5372 637306	VALENTINA DENISOVA	{"email": "valentina_denisova-15021973@postgrespro.ru", "phone": "+70230989533"}
0005434426859	CB9DF7	8738 760759	LARISA KUZNECOVA	{"email": "kuznecovalarisa-25111963@postgrespro.ru", "phone": "+70468359396"}
0005434426860	00742E	4176 041420	DMITRIY KULIKOV	{"phone": "+70508562672"}
0005434426861	00742E	2220 169850	NATALYA ZAKHAROVA	{"email": "zakharova_n1971@postgrespro.ru", "phone": "+70722453753"}
0005434426862	E69B53	4614 879094	NATALYA SOKOLOVA	{"email": "sokolova_natalya_08121970@postgrespro.ru", "phone": "+70463011651"}
0005434426863	E69B53	5984 612564	SERGEY IVANOV	{"phone": "+70290178507"}
0005434426864	06C42F	7012 367108	ALEKSANDR POPOV	{"phone": "+70761110093"}
0005434426865	E8803F	7678 636993	DENIS VLASOV	{"email": "vlasov.d_04091981@postgrespro.ru", "phone": "+70848316815"}
0005434426866	812F54	0718 162220	NATALYA ANISIMOVA	{"email": "nanisimova_15011968@postgrespro.ru", "phone": "+70255509359"}
0005434426867	7F0250	2945 110563	VERA DMITRIEVA	{"email": "dmitrieva-v.011981@postgrespro.ru", "phone": "+70341393031"}
0005434426868	32ADD5	1813 103943	KSENIYA TITOVA	{"email": "k-titova-1971@postgrespro.ru", "phone": "+70792509728"}
0005434426869	32ADD5	5747 500125	SERGEY BELOV	{"email": "belov-s-18071967@postgrespro.ru", "phone": "+70721533151"}
0005434426870	E68B22	1972 402575	SVETLANA KUZNECOVA	{"email": "s-kuznecova_031980@postgrespro.ru", "phone": "+70224937693"}
0005434426871	3C405C	2282 518381	DARYA OVCHINNIKOVA	{"email": "ovchinnikova_darya051970@postgrespro.ru", "phone": "+70949824809"}
0005434426872	3C405C	9873 431797	TATYANA MIRONOVA	{"phone": "+70232199700"}
0005434426873	83CE16	0990 907366	TATYANA MAKAROVA	{"phone": "+70426408868"}
0005434426874	55C8DC	5168 850194	ILYA VOLKOV	{"phone": "+70057201890"}
0005434426875	F224E4	9163 737663	VALENTINA ABRAMOVA	{"email": "v_abramova22071970@postgrespro.ru", "phone": "+70673580753"}
0005434426876	72E06C	6701 026804	DMITRIY KRASNOV	{"phone": "+70299836442"}
0005434426877	72E06C	2801 154353	ALEKSANDR KUZNECOV	{"email": "a_kuznecov071964@postgrespro.ru", "phone": "+70914227884"}
0005434426878	72E06C	3581 800847	NATALYA KUZNECOVA	{"phone": "+70905635030"}
0005434426879	4987A8	2095 246912	MARINA FILATOVA	{"phone": "+70347242418"}
0005434426880	FD659E	1417 728970	NADEZHDA MATVEEVA	{"email": "matveeva-n21051975@postgrespro.ru", "phone": "+70210372756"}
0005434426881	6D658E	7008 376264	ALEKSANDRA SOKOLOVA	{"email": "aleksandrasokolova_05021968@postgrespro.ru", "phone": "+70219321600"}
0005434426882	6D658E	6429 579833	IRINA SOKOLOVA	{"phone": "+70438885568"}
0005434426883	63F91C	9878 801575	KSENIYA NESTEROVA	{"phone": "+70760937624"}
0005434426884	D03636	1130 550641	VERA GUSEVA	{"phone": "+70561170291"}
0005434426885	46495A	2236 354425	ALEKSANDR STEPANOV	{"email": "stepanov-a.09091981@postgrespro.ru", "phone": "+70735792481"}
0005434426886	D48379	5691 620481	NADEZHDA ISAEVA	{"email": "nisaeva.24031964@postgrespro.ru", "phone": "+70227209583"}
0005434426887	E97FE1	6831 886965	OLGA ANISIMOVA	{"phone": "+70665895932"}
0005434426888	1A852D	7801 210430	MIKHAIL ORLOV	{"email": "orlov-m1966@postgrespro.ru", "phone": "+70995052389"}
0005434426889	D8D466	6231 420404	MARIYA ANDREEVA	{"phone": "+70316254964"}
0005434426890	B0121B	0147 670515	NATALIYA CHERNOVA	{"email": "nataliya_chernova-19121982@postgrespro.ru", "phone": "+70577460899"}
0005434426891	C9CFD2	8048 593335	NINA NIKIFOROVA	{"email": "nina-nikiforova041979@postgrespro.ru", "phone": "+70442447118"}
0005434426892	C9CFD2	3140 022476	TATYANA CHERNOVA	{"phone": "+70005156326"}
0005434426893	B5AAF4	8611 137672	KONSTANTIN OSIPOV	{"email": "k_osipov.1973@postgrespro.ru", "phone": "+70092766612"}
0005434426894	D91CAA	1385 695520	EVGENIY SAVELEV	{"phone": "+70129883207"}
0005434426895	5EC566	3536 791940	DMITRIY SOKOLOV	{"email": "sokolov-dmitriy.10081986@postgrespro.ru", "phone": "+70658977222"}
0005434426896	3AAD17	1853 791617	ALEKSEY MOISEEV	{"email": "amoiseev-26011975@postgrespro.ru", "phone": "+70097005865"}
0005434426897	3AAD17	6758 799915	SERGEY KOZLOV	{"phone": "+70444856760"}
0005434426898	0B7513	5245 232928	LARISA NIKITINA	{"phone": "+70263859095"}
0005434426899	0B7513	9218 210453	VLADIMIR BONDARENKO	{"phone": "+70495960966"}
0005434426900	816AE2	8036 886999	VALENTINA GAVRILOVA	{"phone": "+70211921048"}
0005434426901	816AE2	5905 893992	ELENA KOROLEVA	{"phone": "+70794516087"}
0005434426902	5B45BC	7540 885106	YULIYA KUZNECOVA	{"phone": "+70396515201"}
0005434426903	AB7482	0879 364476	SVETLANA EFREMOVA	{"email": "svetlana.efremova-041974@postgrespro.ru", "phone": "+70186840460"}
0005434426904	8195D1	4920 051464	NATALIYA POLYAKOVA	{"email": "polyakova-nataliya081974@postgrespro.ru", "phone": "+70083450637"}
0005434426905	8195D1	0710 617080	SERGEY MOROZOV	{"phone": "+70689263633"}
0005434426906	DD8368	0367 247471	VLADIMIR PETROV	{"email": "petrovvladimir22091976@postgrespro.ru", "phone": "+70138249979"}
0005434426907	DD8368	4244 341573	VERONIKA ZAYCEVA	{"email": "veronika-zayceva021980@postgrespro.ru", "phone": "+70630743566"}
0005434426908	A10192	7057 590345	NIKOLAY PETROV	{"email": "n.petrov_09121969@postgrespro.ru", "phone": "+70557775487"}
0005434426909	E52B36	5084 862386	VLADIMIR DENISOV	{"phone": "+70433936771"}
0005434426910	592B26	7764 079683	GALINA STEPANOVA	{"email": "stepanova.galina16111965@postgrespro.ru", "phone": "+70404900648"}
0005434426911	3C86CD	9263 145360	SVETLANA CHERNOVA	{"email": "s-chernova.051966@postgrespro.ru", "phone": "+70293512652"}
0005434426912	CCB2A6	2608 107015	ANATOLIY SEMENOV	{"email": "anatoliy.semenov_041978@postgrespro.ru", "phone": "+70337927248"}
0005434426913	8F7032	3058 605999	ELENA KUZNECOVA	{"email": "ekuznecova-09091959@postgrespro.ru", "phone": "+70672184824"}
0005434426914	106778	3378 000445	RUSTAM ALEKSEEV	{"phone": "+70733821785"}
0005434426915	486193	9604 491384	SVETLANA KUZMINA	{"phone": "+70384451044"}
0005434426916	486193	7435 899570	GENNADIY KOZLOV	{"phone": "+70956366947"}
0005434426917	BA501D	7261 597330	EVGENIY TIKHONOV	{"email": "tikhonov_evgeniy-14021967@postgrespro.ru", "phone": "+70252874577"}
0005434426918	BA501D	5121 927248	MAKSIM TIKHONOV	{"email": "tikhonovmaksim_1971@postgrespro.ru", "phone": "+70332708652"}
0005434426919	BA501D	4469 141819	ANASTASIYA GRISHINA	{"phone": "+70416585516"}
0005434426920	1C7C01	6758 555344	ANASTASIYA EGOROVA	{"email": "aegorova_28011978@postgrespro.ru", "phone": "+70588160397"}
0005434426921	CBB187	1465 621907	YURIY NIKOLAEV	{"phone": "+70465518251"}
0005434426922	CBB187	2122 985272	SVETLANA LOGINOVA	{"phone": "+70962665782"}
0005434426923	35CB48	1832 162931	ANDREY FILIPPOV	{"email": "andrey_filippov-021964@postgrespro.ru", "phone": "+70686523938"}
0005434426924	087B4C	3644 550525	IVAN SHEVCHENKO	{"phone": "+70255369252"}
0005434426925	087B4C	0184 657092	DMITRIY SOROKIN	{"phone": "+70672719858"}
0005434426926	54D3BF	2175 460199	EVGENIY SOROKIN	{"email": "sorokin.e24121970@postgrespro.ru", "phone": "+70911799458"}
0005434426927	69801A	0185 524092	PAVEL SOROKIN	{"phone": "+70006934073"}
0005434426928	69801A	1963 957691	EVGENIY MAKAROV	{"email": "makarov-e.071967@postgrespro.ru", "phone": "+70448921498"}
0005434426929	1C20A2	4566 128851	OLGA TARASOVA	{"email": "tarasova-olga091967@postgrespro.ru", "phone": "+70367621043"}
0005434426930	777D1D	0385 357418	SVETLANA EFIMOVA	{"email": "svetlana.efimova-031973@postgrespro.ru", "phone": "+70939144772"}
0005434426931	30E2C7	8814 668388	SERGEY NIKOLAEV	{"email": "nikolaev_s.061968@postgrespro.ru", "phone": "+70613104992"}
0005434426932	970B31	0668 789857	EVGENIYA KUZMINA	{"phone": "+70172233706"}
0005434426933	0101BD	5214 830649	VLADIMIR POPOV	{"phone": "+70525125116"}
0005434426934	0101BD	0787 639338	MARIYA FOMINA	{"email": "fomina.m_021970@postgrespro.ru", "phone": "+70090694200"}
0005434426935	349EF5	7122 853627	ALEKSEY BORISOV	{"phone": "+70180899130"}
0005434426936	349EF5	3019 169975	KRISTINA BARANOVA	{"phone": "+70753272895"}
0005434426937	BD5A97	8061 530825	ALEKSEY POPOV	{"email": "alekseypopov26051969@postgrespro.ru", "phone": "+70175771678"}
0005434426938	9C5551	9068 370213	VLADIMIR SEMENOV	{"email": "vladimir-semenov-1974@postgrespro.ru", "phone": "+70161295256"}
0005434426939	7922B1	8661 754300	LARISA ABRAMOVA	{"email": "l_abramova.04051974@postgrespro.ru", "phone": "+70610325790"}
0005434426940	ACFC24	9337 506164	ELENA MELNIKOVA	{"email": "melnikovae-1968@postgrespro.ru", "phone": "+70628022151"}
0005434426941	D6E4FD	3174 058658	SVETLANA MELNIKOVA	{"email": "melnikova-s.101972@postgrespro.ru", "phone": "+70145644060"}
0005434426942	D6E4FD	6452 226624	ANDREY VASILEV	{"email": "andreyvasilev-06071979@postgrespro.ru", "phone": "+70291840014"}
0005434426943	09FE9E	1723 399492	ANDREY NAZAROV	{"phone": "+70054339232"}
0005434426944	CABAA5	2200 691289	LARISA NIKIFOROVA	{"phone": "+70045263887"}
0005434426945	CABAA5	4989 041555	ANTON KONOVALOV	{"phone": "+70332978345"}
0005434426946	0E2CAD	3279 549719	ALEKSANDR PETROV	{"phone": "+70379991175"}
0005434426947	0E2CAD	8136 126960	VLADIMIR GORBUNOV	{"phone": "+70908326550"}
0005434426948	0E2CAD	4972 650150	PETR GERASIMOV	{"phone": "+70154893920"}
0005434426949	9F33A1	0398 062034	ALEKSANDR SOLOVEV	{"email": "aleksandr-solovev.22111977@postgrespro.ru", "phone": "+70733487128"}
0005434426950	40968B	3804 685441	ULYANA SAVELEVA	{"email": "ulyana-saveleva1981@postgrespro.ru", "phone": "+70786198473"}
0005434426951	3E0627	4377 659247	DMITRIY BARANOV	{"phone": "+70613664376"}
0005434426952	12DDB3	6235 770787	TAMARA TIKHONOVA	{"email": "tikhonova.tamara1972@postgrespro.ru", "phone": "+70505278718"}
0005434426953	3075BC	1219 146988	LARISA TROFIMOVA	{"email": "trofimova-l-1975@postgrespro.ru", "phone": "+70560266882"}
0005434426954	7CDA1B	8010 553976	EVGENIY GUSEV	{"email": "guseve_111979@postgrespro.ru", "phone": "+70930340079"}
0005434426955	7CDA1B	8169 921659	ALEKSEY EGOROV	{"phone": "+70792590452"}
0005434426956	7CDA1B	7661 121382	EKATERINA VOLKOVA	{"phone": "+70599554532"}
0005434426957	51B735	1266 686467	SERGEY NIKITIN	{"email": "nikitin_sergey.10071962@postgrespro.ru", "phone": "+70322224779"}
0005434426958	82486E	9459 425367	NIKOLAY NAZAROV	{"phone": "+70648238343"}
0005434426959	82486E	0711 200942	ANATOLIY GRIGOREV	{"phone": "+70599022400"}
0005434426960	6289CB	1124 192888	BORIS ILIN	{"email": "ilin.boris.061977@postgrespro.ru", "phone": "+70204605070"}
0005434426961	6289CB	4745 878662	ALEKSANDR GORBUNOV	{"phone": "+70338724875"}
0005434426962	7E7A2E	0023 294919	NATALYA NIKITINA	{"phone": "+70380702287"}
0005434426963	9D97F2	1326 822587	MIKHAIL KUZMIN	{"email": "mikhailkuzmin-1967@postgrespro.ru", "phone": "+70241392991"}
0005434426964	28EF13	8236 108108	ALEKSANDR TIKHONOV	{"phone": "+70946735592"}
0005434426965	28EF13	2884 319587	VIKTOR KOZLOV	{"phone": "+70688253839"}
0005434426966	474039	4736 050589	VALENTINA FOMINA	{"email": "valentina_fomina.051971@postgrespro.ru", "phone": "+70239653090"}
0005434426967	474039	1176 077633	EVGENIY FEDOROV	{"phone": "+70290711771"}
0005434426968	707EE3	3620 802288	GALINA ALEKSEEVA	{"phone": "+70460261922"}
0005434426969	AED0F0	5157 740830	NATALYA DANILOVA	{"phone": "+70052134708"}
0005434426970	AA06D5	9075 697087	DENIS ZAKHAROV	{"email": "d-zakharov.081965@postgrespro.ru", "phone": "+70933689576"}
0005434426971	AA06D5	1653 012445	EKATERINA MAKAROVA	{"phone": "+70708143262"}
0005434426972	B7EB3B	3430 993318	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-1975@postgrespro.ru", "phone": "+70125363263"}
0005434426973	9E09B6	0640 269570	TATYANA IVANOVA	{"email": "ivanovatatyana.071972@postgrespro.ru", "phone": "+70821111044"}
0005434426974	9E09B6	9435 195501	OLGA TIKHONOVA	{"email": "tikhonova-o091969@postgrespro.ru", "phone": "+70859554520"}
0005434426975	F17377	0024 051596	NATALYA FROLOVA	{"email": "frolova.natalya-041971@postgrespro.ru", "phone": "+70458441319"}
0005434426976	B844C0	5034 426806	DENIS SEMENOV	{"email": "d_semenov_091966@postgrespro.ru", "phone": "+70052084210"}
0005434426977	B844C0	5948 100839	LARISA DENISOVA	{"phone": "+70302358858"}
0005434426978	31BF1D	1048 308189	VASILIY MOISEEV	{"email": "vasiliymoiseev_14111987@postgrespro.ru", "phone": "+70090401302"}
0005434426979	2AB82E	8488 956519	NATALYA DENISOVA	{"email": "denisova-n_041973@postgrespro.ru", "phone": "+70723150647"}
0005434426980	D71F8A	2083 147704	SVETLANA NIKITINA	{"phone": "+70752574363"}
0005434426981	292A3C	3419 961000	ALEKSEY FEDOROV	{"email": "fedorovaleksey.1967@postgrespro.ru", "phone": "+70642478859"}
0005434426982	BEB885	9052 133954	ANASTASIYA ABRAMOVA	{"email": "a.abramova-1980@postgrespro.ru", "phone": "+70680930073"}
0005434426983	BEB885	3562 131994	KLAVDIYA ZOTOVA	{"email": "zotovaklavdiya-111982@postgrespro.ru", "phone": "+70797765062"}
0005434426984	633846	0249 944145	VLADIMIR KUZNECOV	{"email": "v-kuznecov_051974@postgrespro.ru", "phone": "+70034820207"}
0005434426985	3D2960	0595 186834	ALEKSEY GORBUNOV	{"email": "gorbunov_a_041975@postgrespro.ru", "phone": "+70834958821"}
0005434426986	3D2960	1700 247146	MARIYA MIKHAYLOVA	{"email": "mariya-mikhaylova101957@postgrespro.ru", "phone": "+70744402546"}
0005434426987	04FB60	8658 672349	SERGEY AFANASEV	{"email": "afanasev.s1973@postgrespro.ru", "phone": "+70616285588"}
0005434426988	6D6D54	6542 625171	DMITRIY OSIPOV	{"phone": "+70288029814"}
0005434426989	8DD7C1	7173 763295	ELENA MAKAROVA	{"email": "elena_makarova1974@postgrespro.ru", "phone": "+70539148886"}
0005434426990	20AFFF	4647 379243	VALERIYA SEMENOVA	{"email": "semenova-v041974@postgrespro.ru", "phone": "+70531068969"}
0005434426991	20AFFF	8082 010541	MARINA MAKAROVA	{"phone": "+70298672672"}
0005434426992	EF64A3	0043 184261	ANNA MOROZOVA	{"email": "anna.morozova-051971@postgrespro.ru", "phone": "+70893674889"}
0005434426993	EF64A3	6335 462758	SERGEY SMIRNOV	{"email": "smirnovsergey_16021968@postgrespro.ru", "phone": "+70057071009"}
0005434426994	DD5591	5782 863801	NATALYA MOISEEVA	{"email": "nmoiseeva.23051983@postgrespro.ru", "phone": "+70856883938"}
0005434426995	B5FFA3	9622 607723	VLADIMIR SOROKIN	{"email": "sorokin.vladimir1974@postgrespro.ru", "phone": "+70573869404"}
0005434426996	C15924	3308 402869	KIRILL MELNIKOV	{"email": "kirill.melnikov.21011973@postgrespro.ru", "phone": "+70537105144"}
0005434426997	C8E2B3	4607 080988	DMITRIY VASILEV	{"phone": "+70165779086"}
0005434426998	C8E2B3	3920 094499	YULIYA PAVLOVA	{"email": "pavlova_yuliya.12011968@postgrespro.ru", "phone": "+70388552943"}
0005434426999	7DF4BF	1845 063373	OLGA ANISIMOVA	{"email": "o.anisimova.1959@postgrespro.ru", "phone": "+70763144759"}
0005434427061	B57D94	6768 189259	VLADIMIR MARTYNOV	{"phone": "+70896744622"}
0005434427000	D27B3F	1136 460922	LYUDMILA RODIONOVA	{"email": "lyudmila_rodionova.081964@postgrespro.ru", "phone": "+70273561860"}
0005434427001	E29DCF	3002 971552	MAKSIM IVANOV	{"phone": "+70781295201"}
0005434427002	E9912F	4030 356964	ELENA SCHERBAKOVA	{"email": "e.scherbakova.01031980@postgrespro.ru", "phone": "+70260641955"}
0005434427003	E9912F	4380 112455	ALEKSEY KRASNOV	{"email": "krasnov.a_051961@postgrespro.ru", "phone": "+70428951397"}
0005434427004	9A71A4	8737 877950	MATRENA SOLOVEVA	{"phone": "+70896610603"}
0005434427005	E88584	6185 341517	NIKOLAY VOLKOV	{"email": "volkov-nikolay1970@postgrespro.ru", "phone": "+70900766210"}
0005434427006	B02344	3454 278541	IGOR BELOV	{"phone": "+70009267249"}
0005434427007	CC68DE	0539 621076	YURIY SCHERBAKOV	{"phone": "+70024276154"}
0005434427008	F02471	5347 120787	OLEG ABRAMOV	{"email": "oabramov_16051962@postgrespro.ru", "phone": "+70634293931"}
0005434427009	F02471	2328 435720	LYUDMILA VOLKOVA	{"phone": "+70381730123"}
0005434427010	7A8358	6630 208322	ALEKSEY ABRAMOV	{"email": "abramovaleksey12041978@postgrespro.ru", "phone": "+70348874672"}
0005434427011	BD439F	9568 636847	SERGEY TARASOV	{"email": "sergey_tarasov-12011970@postgrespro.ru", "phone": "+70860199675"}
0005434427012	BD439F	6947 381676	MARIYA DAVYDOVA	{"phone": "+70152584079"}
0005434427013	F61E15	8383 194451	VIKTOR BARANOV	{"phone": "+70513773392"}
0005434427014	4DD256	5672 450700	KSENIYA BORISOVA	{"email": "borisova-kseniya-03071973@postgrespro.ru", "phone": "+70613097842"}
0005434427015	A5319B	9376 489393	ALEKSANDR POPOV	{"email": "popovaleksandr-1974@postgrespro.ru", "phone": "+70824961243"}
0005434427016	C3CA38	6170 608642	MARIYA YAKOVLEVA	{"phone": "+70822111097"}
0005434427017	FFE482	7073 356608	NADEZHDA KUZMINA	{"email": "nadezhda-kuzmina_1969@postgrespro.ru", "phone": "+70339312508"}
0005434427018	6AEA7F	4694 217619	KONSTANTIN VASILEV	{"phone": "+70603548377"}
0005434427019	0E764D	2581 541204	ALEKSANDR PAVLOV	{"phone": "+70823418842"}
0005434427020	0E764D	9578 553908	LILIYA AFANASEVA	{"phone": "+70252459029"}
0005434427021	6FAE65	6213 280960	KIRILL ABRAMOV	{"email": "k-abramov.17031975@postgrespro.ru", "phone": "+70817464671"}
0005434427022	6FAE65	5489 511715	ALEKSEY YAKOVLEV	{"phone": "+70187254573"}
0005434427023	274EAD	1916 711671	NIKOLAY DAVYDOV	{"email": "davydovnikolay.081988@postgrespro.ru", "phone": "+70969187649"}
0005434427024	274EAD	5942 488993	YURIY POPOV	{"phone": "+70064169881"}
0005434427025	8C4340	2540 413325	VERA EGOROVA	{"phone": "+70588247035"}
0005434427026	8C4340	7659 443745	OLGA BELYAEVA	{"email": "olga.belyaeva-021972@postgrespro.ru", "phone": "+70932985616"}
0005434427027	8D414A	0152 139882	ELENA IVANOVA	{"email": "elena_ivanova_081971@postgrespro.ru", "phone": "+70021970521"}
0005434427028	8D414A	0935 745681	VALERIY SERGEEV	{"phone": "+70369798967"}
0005434427029	DF1DA3	1030 888484	VIKTOR POPOV	{"email": "popovv_121982@postgrespro.ru", "phone": "+70875392757"}
0005434427030	DF1DA3	0215 998510	SEMEN PETROV	{"phone": "+70136683673"}
0005434427031	B419AE	1357 325404	SVETLANA ZOTOVA	{"phone": "+70427803454"}
0005434427032	B419AE	6525 662566	ANNA MOROZOVA	{"phone": "+70829188973"}
0005434427033	B419AE	3739 233428	DENIS DAVYDOV	{"phone": "+70192764843"}
0005434427034	4586DB	0100 627759	SERGEY KUZMIN	{"phone": "+70339781156"}
0005434427035	646A5E	7821 358357	ALEKSANDR BONDARENKO	{"phone": "+70895573597"}
0005434427036	EE0143	8665 346931	VYACHESLAV KULIKOV	{"phone": "+70505617274"}
0005434427037	EE0143	5095 760911	OLGA SAVELEVA	{"email": "saveleva_o_1961@postgrespro.ru", "phone": "+70462891384"}
0005434427038	C117F5	5069 847096	ANATOLIY SCHERBAKOV	{"phone": "+70074752192"}
0005434427039	E47608	0236 846280	SVETLANA BORISOVA	{"phone": "+70588870288"}
0005434427040	56BC2B	9527 430907	ELENA OVCHINNIKOVA	{"email": "elena-ovchinnikova.1962@postgrespro.ru", "phone": "+70262924612"}
0005434427041	251A61	5744 954044	ALEKSEY AFANASEV	{"email": "afanasev-aleksey1965@postgrespro.ru", "phone": "+70615402425"}
0005434427042	9922CC	8357 726635	SERGEY ALEKSEEV	{"phone": "+70771002372"}
0005434427043	5ED608	0154 665055	DARYA MIKHAYLOVA	{"phone": "+70834635198"}
0005434427044	3181EF	7735 066598	SERGEY GRIGOREV	{"email": "grigorev_s_1969@postgrespro.ru", "phone": "+70950856274"}
0005434427045	C7BD2F	7077 841246	IVAN MIRONOV	{"email": "mironov-ivan-1979@postgrespro.ru", "phone": "+70355265008"}
0005434427046	C7BD2F	4994 621395	KONSTANTIN ANTONOV	{"email": "antonov_konstantin081975@postgrespro.ru", "phone": "+70840969162"}
0005434427047	4F2075	7108 491253	YURIY MIRONOV	{"email": "y-mironov.15091971@postgrespro.ru", "phone": "+70812516922"}
0005434427048	95BEB4	4700 706308	NATALIYA SOROKINA	{"phone": "+70923243439"}
0005434427049	95BEB4	3018 756422	ELENA MIKHAYLOVA	{"email": "elena.mikhaylova.081963@postgrespro.ru", "phone": "+70788658854"}
0005434427050	EED124	2136 646959	RAUF ZHURAVLEV	{"email": "zhuravlev-rauf091967@postgrespro.ru", "phone": "+70340662224"}
0005434427051	EED124	4565 579430	DANIIL MIKHAYLOV	{"phone": "+70278888197"}
0005434427052	EED124	0701 172123	YULIYA NOVIKOVA	{"email": "yuliya.novikova121970@postgrespro.ru", "phone": "+70274706676"}
0005434427053	5FA8ED	1540 640035	IGOR CHERNOV	{"email": "chernov-igor1966@postgrespro.ru", "phone": "+70002525880"}
0005434427054	5FA8ED	8537 432127	DANIIL TARASOV	{"email": "tarasov.d.1975@postgrespro.ru", "phone": "+70363839003"}
0005434427055	DCFFB1	2023 882944	TATYANA KUZNECOVA	{"email": "kuznecovat.051985@postgrespro.ru", "phone": "+70729848357"}
0005434427056	52249D	1887 062662	VLADIMIR PAVLOV	{"phone": "+70201430911"}
0005434427057	660049	8874 484147	OLGA SCHERBAKOVA	{"email": "olga_scherbakova.1983@postgrespro.ru", "phone": "+70230616726"}
0005434427058	C94C63	0970 650191	ILMIRA PETROVA	{"phone": "+70581536146"}
0005434427059	635320	1822 653170	NIKOLAY MAKSIMOV	{"phone": "+70167235518"}
0005434427060	2CBC59	0642 238585	IVAN BORISOV	{"email": "ivan.borisov.02081973@postgrespro.ru", "phone": "+70686209719"}
0005434427062	438BAE	4499 325077	NATALIYA GUSEVA	{"phone": "+70369453236"}
0005434427063	438BAE	8667 708692	VLADISLAV GAVRILOV	{"email": "gavrilov-v_111970@postgrespro.ru", "phone": "+70843403717"}
0005434427064	58B00F	3815 481174	TAMARA KOMAROVA	{"email": "tamara.komarova.28071975@postgrespro.ru", "phone": "+70986817361"}
0005434427065	58B00F	8437 296356	ZINAIDA ANTONOVA	{"phone": "+70420102656"}
0005434427066	539E6E	1148 049777	OLGA ORLOVA	{"phone": "+70904543344"}
0005434427067	539E6E	3595 049421	EKATERINA YAKOVLEVA	{"phone": "+70262788117"}
0005434427068	67A62C	3872 179033	ALEKSEY DAVYDOV	{"phone": "+70331383602"}
0005434427069	F2E20E	7433 211465	EVGENIY GORBUNOV	{"phone": "+70094571276"}
0005434427070	C4D4A9	1215 416189	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr071963@postgrespro.ru", "phone": "+70051572625"}
0005434427071	C4D4A9	4081 029130	ROMAN IVANOV	{"phone": "+70222916384"}
0005434427072	C4D4A9	6735 345256	NADEZHDA FOMINA	{"email": "nfomina.11101980@postgrespro.ru", "phone": "+70809196357"}
0005434427073	6AAA61	5050 208417	DMITRIY VOLKOV	{"email": "volkov-d_13071988@postgrespro.ru", "phone": "+70413994444"}
0005434427074	C565FC	9395 600654	FARID MARTYNOV	{"phone": "+70928177367"}
0005434427075	C565FC	0154 145989	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey-24041972@postgrespro.ru", "phone": "+70389091662"}
0005434427076	C565FC	1712 260048	YULIYA SOROKINA	{"phone": "+70670877955"}
0005434427077	75E51F	0301 524631	ALEKSANDR STEPANOV	{"phone": "+70616596116"}
0005434427078	C6997E	4396 351096	VALENTINA KUZNECOVA	{"email": "v.kuznecova_101975@postgrespro.ru", "phone": "+70645095640"}
0005434427079	C6997E	0016 322380	OLGA POPOVA	{"email": "popova-o1974@postgrespro.ru", "phone": "+70436206698"}
0005434427080	C6997E	1033 882186	ALEKSANDRA SOROKINA	{"email": "sorokina_aleksandra-1967@postgrespro.ru", "phone": "+70449071579"}
0005434427081	648CAE	3037 513243	DMITRIY KUZMIN	{"phone": "+70510567030"}
0005434427082	1BD91A	6961 276946	ANFISA ZAKHAROVA	{"email": "anfisa_zakharova-1966@postgrespro.ru", "phone": "+70778743594"}
0005434427083	E60DBE	2668 478813	EKATERINA KAZAKOVA	{"email": "ekaterina_kazakova041971@postgrespro.ru", "phone": "+70888221484"}
0005434427084	E704D4	9715 202769	ILYA ORLOV	{"email": "ilyaorlov_24091969@postgrespro.ru", "phone": "+70509749687"}
0005434427085	E704D4	7934 781410	OLGA IVANOVA	{"email": "ivanovaolga.1966@postgrespro.ru", "phone": "+70517544170"}
0005434427086	6BF7FD	5950 008268	KIRILL RODIONOV	{"phone": "+70032484769"}
0005434427087	0A9510	2034 636687	ANDREY NAZAROV	{"email": "a_nazarov_081978@postgrespro.ru", "phone": "+70840934204"}
0005434427088	C61D3E	6800 818304	IRINA VOLKOVA	{"phone": "+70038245298"}
0005434427089	5928A1	4372 893714	DMITRIY MAKAROV	{"phone": "+70444892286"}
0005434427090	CFDA63	1940 450940	ANATOLIY ZAYCEV	{"email": "anatoliy_zaycev.1983@postgrespro.ru", "phone": "+70840117108"}
0005434427091	CFDA63	2020 244529	RAMIL ZAKHAROV	{"email": "zakharov.r_041981@postgrespro.ru", "phone": "+70382579337"}
0005434427092	A59D39	9591 048680	ANTONINA TARASOVA	{"phone": "+70444078441"}
0005434427093	03835E	2477 703875	YULIYA VASILEVA	{"phone": "+70442181319"}
0005434427094	03835E	6403 006974	KSENIYA KUZNECOVA	{"phone": "+70977644986"}
0005434427095	372A71	9353 055658	SERGEY PETROV	{"phone": "+70067738206"}
0005434427096	372A71	0187 862493	NIKOLAY EGOROV	{"phone": "+70610900411"}
0005434427097	372A71	3007 956817	ELENA BELOVA	{"phone": "+70318982276"}
0005434427098	7FCED2	8517 168118	ANASTASIYA EFIMOVA	{"phone": "+70234700639"}
0005434427099	7FCED2	1485 752149	RAFIS SCHERBAKOV	{"phone": "+70736217616"}
0005434427100	52F312	0090 676066	IGOR ZHUKOV	{"phone": "+70376318971"}
0005434427101	5B5FB2	2952 781649	DENIS ZAKHAROV	{"phone": "+70924932185"}
0005434427102	5B5FB2	6693 282826	VALENTINA YUDINA	{"phone": "+70134872155"}
0005434427103	06A1AB	1726 550391	TATYANA DENISOVA	{"email": "denisova_tatyana.20041957@postgrespro.ru", "phone": "+70543679019"}
0005434427104	ECF4DC	1607 413061	ELENA TIKHONOVA	{"phone": "+70369553904"}
0005434427105	ECF4DC	2286 138538	ELENA ZHURAVLEVA	{"phone": "+70593178097"}
0005434427106	3119D7	6858 599265	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_g-09041968@postgrespro.ru", "phone": "+70871058944"}
0005434427107	5B3B82	4149 114738	EVGENIY FILIPPOV	{"email": "efilippov-051967@postgrespro.ru", "phone": "+70741980710"}
0005434427108	6386D7	2225 920688	IRINA POLYAKOVA	{"phone": "+70235460497"}
0005434427109	EE4921	6233 312671	DMITRIY MOROZOV	{"phone": "+70669908552"}
0005434427110	687126	8821 227635	VALERIY ISAEV	{"email": "v.isaev-121974@postgrespro.ru", "phone": "+70820218711"}
0005434427111	687126	2008 816082	ALEKSEY MOISEEV	{"email": "aleksey-moiseev29061971@postgrespro.ru", "phone": "+70853357830"}
0005434427112	687126	2601 778159	FARID TIMOFEEV	{"phone": "+70878956025"}
0005434427113	119769	3667 705642	ALEKSANDR STEPANOV	{"email": "a.stepanov021970@postgrespro.ru", "phone": "+70656198976"}
0005434427114	077B45	3069 537886	IRINA TIKHONOVA	{"phone": "+70275545359"}
0005434427115	077B45	8199 505187	NINA BARANOVA	{"phone": "+70131148132"}
0005434427116	87F18D	4153 877135	ANDREY VASILEV	{"email": "vasilev-a_1977@postgrespro.ru", "phone": "+70533475945"}
0005434427117	AE03D2	8011 753720	MARSEL SIDOROV	{"email": "marsel.sidorov_041978@postgrespro.ru", "phone": "+70269538189"}
0005434427118	0CF29E	4913 945860	MIKHAIL FEDOROV	{"phone": "+70048679486"}
0005434427119	33EF39	9746 506118	LYUDMILA KUZNECOVA	{"phone": "+70995020813"}
0005434427120	33EF39	2204 243885	ANASTASIYA VASILEVA	{"email": "avasileva_28021967@postgrespro.ru", "phone": "+70128105947"}
0005434427121	A8B361	1631 132519	STEPAN MIKHAYLOV	{"phone": "+70170743411"}
0005434427122	3FF9B6	3780 189221	IVAN TIMOFEEV	{"phone": "+70889536011"}
0005434427123	303ABD	5031 461309	NINA MELNIKOVA	{"phone": "+70597663923"}
0005434427124	303ABD	3283 836025	ANASTASIYA SCHERBAKOVA	{"email": "scherbakovaa17111981@postgrespro.ru", "phone": "+70675938110"}
0005434427125	303ABD	3580 431628	ARTEM SOLOVEV	{"phone": "+70254964436"}
0005434427126	21CB38	1620 923233	NIKOLAY SOKOLOV	{"email": "n-sokolov-121979@postgrespro.ru", "phone": "+70329374779"}
0005434427127	B5B4F6	8778 006208	MARIYA YAKOVLEVA	{"phone": "+70570957630"}
0005434427128	43A00A	8554 386668	RAISA ROMANOVA	{"phone": "+70461379394"}
0005434427129	DF37D9	8714 176514	LYUBOV YAKOVLEVA	{"email": "yakovleva_l_30041965@postgrespro.ru", "phone": "+70697858018"}
0005434427130	BDEA82	6274 729232	SVETLANA GORBUNOVA	{"phone": "+70592348585"}
0005434427131	BDEA82	6155 042211	VLADISLAV ROMANOV	{"email": "vladislavromanov-1969@postgrespro.ru", "phone": "+70970298701"}
0005434427132	BDEA82	6720 557747	ALEKSANDR SOLOVEV	{"phone": "+70186423738"}
0005434427133	006C5C	0748 603712	ALEKSEY PETROV	{"email": "aleksey_petrov_1963@postgrespro.ru", "phone": "+70030434245"}
0005434427134	924390	8879 886561	NATALYA TIKHONOVA	{"email": "tikhonova_natalya041968@postgrespro.ru", "phone": "+70270753855"}
0005434427135	924390	2627 684532	IRINA SERGEEVA	{"email": "sergeeva_irina.071969@postgrespro.ru", "phone": "+70467393802"}
0005434427136	B104BF	9895 473398	EKATERINA ANISIMOVA	{"phone": "+70443668771"}
0005434427137	B104BF	8085 022202	ALEKSEY MATVEEV	{"phone": "+70604728334"}
0005434427138	229F4F	1056 933664	ALEKSEY ISAEV	{"phone": "+70275737602"}
0005434427139	C426F1	8474 960097	RAVIL CHERNOV	{"phone": "+70974819865"}
0005434427140	E89BF9	5580 157981	ROMAN ORLOV	{"phone": "+70673219766"}
0005434427141	F47EB7	1072 404318	OLGA KRASNOVA	{"email": "krasnova_o_22071974@postgrespro.ru", "phone": "+70409022830"}
0005434427142	87877F	9679 574904	ALEKSEY KUZMIN	{"phone": "+70924334627"}
0005434427143	87877F	7333 607785	DMITRIY OSIPOV	{"phone": "+70139049151"}
0005434427144	E620F1	2996 179435	VASILIY ANTONOV	{"email": "vasiliyantonov.081977@postgrespro.ru", "phone": "+70434224858"}
0005434427145	965F49	9640 060872	IRINA SAVELEVA	{"email": "isaveleva-051974@postgrespro.ru", "phone": "+70655931171"}
0005434427146	2346B5	9239 712221	VALENTINA MOROZOVA	{"email": "v-morozova.061965@postgrespro.ru", "phone": "+70660645574"}
0005434427147	8187BA	1381 765783	ALEKSEY ABRAMOV	{"email": "abramovaleksey1976@postgrespro.ru", "phone": "+70974182777"}
0005434427148	8187BA	5517 687861	ALEKSANDR NIKOLAEV	{"phone": "+70340340383"}
0005434427149	2F4D36	1769 888404	KRISTINA MIRONOVA	{"phone": "+70610475683"}
0005434427150	67A496	8801 480601	MAKSIM EGOROV	{"phone": "+70514612225"}
0005434427151	67A496	1371 346396	NINA ILINA	{"phone": "+70300038452"}
0005434427152	C355F7	4140 025521	NATALYA KISELEVA	{"email": "kiselevanatalya.091959@postgrespro.ru", "phone": "+70844268966"}
0005434427153	BDAB93	3209 041084	MILENA LEBEDEVA	{"phone": "+70767266748"}
0005434427154	5643AC	9229 501588	ELENA ROMANOVA	{"phone": "+70144010091"}
0005434427155	5643AC	9964 292679	ALEKSEY DAVYDOV	{"phone": "+70951367302"}
0005434427156	5643AC	1843 619399	ANASTASIYA FILIPPOVA	{"phone": "+70291746053"}
0005434427157	5623B0	6980 178856	EVGENIY MAKSIMOV	{"phone": "+70256892013"}
0005434427158	B349C3	7858 663381	ELENA MIRONOVA	{"email": "mironova.e-1974@postgrespro.ru", "phone": "+70309131626"}
0005434427159	E283FB	7718 354278	NIKOLAY AFANASEV	{"phone": "+70052416512"}
0005434427160	E283FB	5014 316590	NIKOLAY IVANOV	{"email": "n.ivanov.1972@postgrespro.ru", "phone": "+70141927959"}
0005434427161	707D55	3372 769255	DANILA BORISOV	{"email": "borisov.danila.1980@postgrespro.ru", "phone": "+70547539336"}
0005434427162	F8FC89	2142 956186	VLADISLAV POPOV	{"email": "vladislavpopov-121974@postgrespro.ru", "phone": "+70846783678"}
0005434427163	ED29B7	0065 075320	ALINA SCHERBAKOVA	{"email": "a_scherbakova07051970@postgrespro.ru", "phone": "+70736784781"}
0005434427164	AB85D4	0561 595541	GALINA KONOVALOVA	{"phone": "+70384913848"}
0005434427165	51C975	7291 391292	KSENIYA MELNIKOVA	{"email": "melnikovak1964@postgrespro.ru", "phone": "+70316378718"}
0005434427166	89C074	5237 367726	ANDREY PETROV	{"phone": "+70980732439"}
0005434427167	89C074	3358 047966	NINA TIMOFEEVA	{"email": "timofeeva.n_21011981@postgrespro.ru", "phone": "+70488891761"}
0005434427168	32B521	3744 865134	LYUDMILA KOZLOVA	{"phone": "+70983422613"}
0005434427169	32B521	8667 276857	ALEKSANDR OSIPOV	{"email": "osipov_a-031969@postgrespro.ru", "phone": "+70129523208"}
0005434427170	E8335D	1957 629594	DARINA ZHUKOVA	{"phone": "+70537685097"}
0005434427171	CC84B6	7049 273791	TATYANA SEMENOVA	{"phone": "+70866961018"}
0005434427172	BF9DA0	8531 295759	ALLA PETROVA	{"email": "petrova.a_28031979@postgrespro.ru", "phone": "+70705799881"}
0005434427173	DF85FB	2027 886727	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev.1978@postgrespro.ru", "phone": "+70406178980"}
0005434427174	A17C9C	2320 884824	ALEVTINA KUZNECOVA	{"email": "kuznecova-alevtina14011969@postgrespro.ru", "phone": "+70049205432"}
0005434427175	E317BB	1044 566733	SVETLANA DANILOVA	{"email": "s.danilova.1977@postgrespro.ru", "phone": "+70959110896"}
0005434427176	E317BB	3843 372136	ELIZAVETA ANTONOVA	{"phone": "+70044021182"}
0005434427177	DCDDB4	9348 314301	ANNA KARPOVA	{"phone": "+70098485197"}
0005434427178	DCDDB4	1708 251795	VALENTINA MEDVEDEVA	{"phone": "+70243894203"}
0005434427179	2B238D	0578 725127	MAKSIM BORISOV	{"email": "borisov-m-1978@postgrespro.ru", "phone": "+70344122629"}
0005434427180	0DC78B	4352 389428	LIDIYA TITOVA	{"email": "ltitova_1974@postgrespro.ru", "phone": "+70021572984"}
0005434427181	E17912	8933 085176	ANNA DAVYDOVA	{"email": "a.davydova121977@postgrespro.ru", "phone": "+70028753456"}
0005434427182	E17912	6731 165569	DANIL SIDOROV	{"email": "sidorovd1965@postgrespro.ru", "phone": "+70730721211"}
0005434427183	1CEC7D	0052 259595	MAKSIM ZHURAVLEV	{"email": "zhuravlevmaksim14101966@postgrespro.ru", "phone": "+70363808698"}
0005434427184	2746AA	0172 158611	DMITRIY KUZNECOV	{"email": "kuznecov_d.121964@postgrespro.ru", "phone": "+70483280190"}
0005434435151	C2B9EB	4450 514024	IGOR KUZNECOV	{"phone": "+70190455520"}
0005434427185	38D647	2908 384029	VASILISA PETROVA	{"email": "petrova.v-081976@postgrespro.ru", "phone": "+70373919303"}
0005434427186	CDD28C	4386 911019	IGOR ZHUKOV	{"phone": "+70898092269"}
0005434427187	06D080	4725 431012	VALERIY NAZAROV	{"email": "valeriy.nazarov.081981@postgrespro.ru", "phone": "+70526217176"}
0005434427188	8FF59C	2705 591891	GALINA KONOVALOVA	{"email": "konovalova-g-1968@postgrespro.ru", "phone": "+70787313471"}
0005434427189	8FF59C	4879 274114	SERGEY SCHERBAKOV	{"email": "scherbakov.s26101967@postgrespro.ru", "phone": "+70273278065"}
0005434427190	205699	1486 108584	ALEKSANDRA KAZAKOVA	{"phone": "+70830546475"}
0005434427191	205699	3975 137227	ANASTASIYA PAVLOVA	{"email": "pavlovaa-071984@postgrespro.ru", "phone": "+70488292076"}
0005434427192	7BF674	0524 203491	SERGEY IVANOV	{"email": "ivanov_sergey-18051978@postgrespro.ru", "phone": "+70056757356"}
0005434427193	7BF674	8829 967239	YURIY ANDREEV	{"phone": "+70626734135"}
0005434427194	013426	8571 362321	LYUBOV NESTEROVA	{"phone": "+70304163132"}
0005434427195	C8AA6B	3572 856786	SVETLANA IVANOVA	{"email": "s-ivanova-21121966@postgrespro.ru", "phone": "+70086520856"}
0005434427196	C8AA6B	4728 939814	GULNARA POTAPOVA	{"email": "potapova-g.1973@postgrespro.ru", "phone": "+70753538275"}
0005434427197	0CA197	5923 792340	ROZA MOROZOVA	{"email": "r.morozova_1969@postgrespro.ru", "phone": "+70804111472"}
0005434427198	ACE290	5390 042206	TATYANA NESTEROVA	{"email": "tatyana-nesterova121975@postgrespro.ru", "phone": "+70567402065"}
0005434427199	5BA948	7811 418976	ALBINA KISELEVA	{"phone": "+70828767246"}
0005434427200	C50C14	1560 763994	RAISA KOMAROVA	{"phone": "+70307645447"}
0005434427201	5AD33E	3069 643663	ELENA KONOVALOVA	{"email": "konovalova_e031966@postgrespro.ru", "phone": "+70160831550"}
0005434427202	CA75B5	4085 410389	VLADIMIR BARANOV	{"email": "baranov-v_29081967@postgrespro.ru", "phone": "+70178566692"}
0005434427203	CA75B5	8818 496233	RUSTAM EGOROV	{"phone": "+70182181350"}
0005434427204	A764DF	7465 556425	OLGA EFIMOVA	{"email": "efimova.olga_021974@postgrespro.ru", "phone": "+70058199208"}
0005434427205	B5A46C	1552 152277	OLEG VOROBEV	{"email": "oleg.vorobev.15091968@postgrespro.ru", "phone": "+70338932303"}
0005434427261	1851EE	5160 578317	RUSLAN ILIN	{"phone": "+70001901210"}
0005434427206	6E9B5C	0524 270558	ANTON SOKOLOV	{"email": "sokolov.a_18061976@postgrespro.ru", "phone": "+70679094082"}
0005434427207	6E9B5C	2750 402567	SERGEY ZHURAVLEV	{"email": "zhuravlev_sergey15061972@postgrespro.ru", "phone": "+70450308361"}
0005434427208	E7F575	6080 584367	SVETLANA BORISOVA	{"phone": "+70533730071"}
0005434427209	E7F575	0786 170871	MARINA ORLOVA	{"email": "marina.orlova07121974@postgrespro.ru", "phone": "+70609650632"}
0005434427210	A51640	0834 222628	NIKOLAY NOVIKOV	{"email": "novikov-nikolay.031967@postgrespro.ru", "phone": "+70185271180"}
0005434427211	A2DD82	0293 080305	DMITRIY SCHERBAKOV	{"phone": "+70002216226"}
0005434427212	3D8371	8514 649170	VALENTINA ANDREEVA	{"email": "valentina.andreeva.26071961@postgrespro.ru", "phone": "+70055977015"}
0005434427213	3D8371	3924 859274	DMITRIY BORISOV	{"email": "dmitriyborisov.10061968@postgrespro.ru", "phone": "+70158776157"}
0005434427214	3D8371	6952 832765	KLAVDIYA AKIMOVA	{"email": "akimovak02021964@postgrespro.ru", "phone": "+70981807403"}
0005434427215	E21650	5489 804902	GALINA ROMANOVA	{"email": "romanova_galina-01081968@postgrespro.ru", "phone": "+70310263151"}
0005434427216	E21650	3881 765503	IVAN NOVIKOV	{"phone": "+70931181984"}
0005434427217	EEE1F2	6935 095994	OLEG KOROLEV	{"phone": "+70663138233"}
0005434427218	EEE1F2	7323 426310	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev1981@postgrespro.ru", "phone": "+70453419332"}
0005434427219	9FA0D3	2462 240489	VIKTORIYA NIKOLAEVA	{"email": "viktoriyanikolaeva-021964@postgrespro.ru", "phone": "+70388307855"}
0005434427220	5FE926	7529 351244	ANASTASIYA TIKHONOVA	{"email": "tikhonovaa.1960@postgrespro.ru", "phone": "+70618579470"}
0005434427221	0A93AF	5770 934332	VIKTOR NIKOLAEV	{"phone": "+70688842270"}
0005434427222	0A93AF	9111 431128	ANTONINA KRASNOVA	{"phone": "+70026487039"}
0005434427223	0A93AF	1114 227725	GEORGIY OSIPOV	{"email": "g-osipov30061969@postgrespro.ru", "phone": "+70195209563"}
0005434427224	598FF8	0574 199696	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana_051965@postgrespro.ru", "phone": "+70769774593"}
0005434427225	92E021	9317 521022	ZAKHAR IVANOV	{"phone": "+70082629153"}
0005434427226	92E021	4354 216557	GALINA STEPANOVA	{"phone": "+70234772975"}
0005434427227	964995	1363 659767	VALENTINA SERGEEVA	{"phone": "+70991788201"}
0005434427228	860BFF	6897 581217	ALEKSANDR KUZNECOV	{"email": "a.kuznecov_1972@postgrespro.ru", "phone": "+70110111010"}
0005434427229	5997D1	4110 197131	VIKTORIYA STEPANOVA	{"phone": "+70544542023"}
0005434427230	5997D1	3725 222832	TAMARA KOROLEVA	{"email": "korolevat-25031972@postgrespro.ru", "phone": "+70629922268"}
0005434427231	56838D	6394 968151	GALINA KARPOVA	{"phone": "+70770891154"}
0005434427232	CF9DE0	0290 498482	VIKTOR BORISOV	{"email": "viktorborisov101968@postgrespro.ru", "phone": "+70274982382"}
0005434427233	AD4EA3	3976 682582	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov-07011980@postgrespro.ru", "phone": "+70451567528"}
0005434427234	AD4EA3	4991 408874	ARTUR KUDRYASHOV	{"email": "artur-kudryashov-1979@postgrespro.ru", "phone": "+70373466389"}
0005434427235	B43955	1409 094901	DARYA FILIPPOVA	{"email": "filippova-darya.031961@postgrespro.ru", "phone": "+70306562289"}
0005434427236	B43955	5283 659065	ALIYA POLYAKOVA	{"phone": "+70815428456"}
0005434427237	5BAB8E	7938 487680	IVAN EGOROV	{"email": "egorovivan.04041969@postgrespro.ru", "phone": "+70348350901"}
0005434427238	AE7347	7434 725120	ANDREY KUDRYASHOV	{"email": "kudryashov.andrey_1974@postgrespro.ru", "phone": "+70256227510"}
0005434427239	AE7347	9257 127578	NIKOLAY ORLOV	{"phone": "+70339913833"}
0005434427240	25B9EC	7603 017296	NATALYA VOLKOVA	{"phone": "+70158014396"}
0005434427302	2E0BB2	2672 973071	TATYANA MAKAROVA	{"email": "makarovatatyana.13041967@postgrespro.ru", "phone": "+70644431252"}
0005434427241	25B9EC	5392 879896	EKATERINA TROFIMOVA	{"email": "trofimova-ekaterina_081977@postgrespro.ru", "phone": "+70673706834"}
0005434427242	5BC363	1206 990768	NINA MOROZOVA	{"phone": "+70724776620"}
0005434427243	452042	4389 434007	IRINA KOLESNIKOVA	{"phone": "+70424180769"}
0005434427244	452042	5846 500251	TATYANA IVANOVA	{"phone": "+70057159343"}
0005434427245	AF19A6	7883 215538	LYUBOV SEMENOVA	{"phone": "+70964704994"}
0005434427246	AF19A6	1277 361695	YANA ROMANOVA	{"phone": "+70435377091"}
0005434427247	AF19A6	6366 249605	NIKOLAY EGOROV	{"email": "n_egorov.021965@postgrespro.ru", "phone": "+70216669104"}
0005434427248	95CBE8	3328 882334	MIKHAIL GRIGOREV	{"email": "mikhail_grigorev-10111975@postgrespro.ru", "phone": "+70184779730"}
0005434427249	95CBE8	6109 857456	KONSTANTIN POPOV	{"phone": "+70114169391"}
0005434427250	A3C436	9878 562186	MARIYA SERGEEVA	{"email": "sergeeva_mariya-10021975@postgrespro.ru", "phone": "+70670768130"}
0005434427251	427B19	8346 540983	EVGENIY VOLKOV	{"email": "volkov_evgeniy_1970@postgrespro.ru", "phone": "+70124325885"}
0005434427252	427B19	9920 388645	OKSANA KRASNOVA	{"email": "krasnovaoksana-09031966@postgrespro.ru", "phone": "+70392292520"}
0005434427253	55B1DF	6207 257912	PAVEL FOMIN	{"email": "p.fomin-051974@postgrespro.ru", "phone": "+70424091550"}
0005434427254	5A3BFA	8864 380643	ANDREY BORISOV	{"email": "a-borisov.10051971@postgrespro.ru", "phone": "+70389750298"}
0005434427255	703448	2102 247899	VLADIMIR KONOVALOV	{"phone": "+70714502616"}
0005434427256	A950C7	0560 239273	VALERIY ALEKSANDROV	{"phone": "+70357664695"}
0005434427257	A950C7	0507 393125	NADEZHDA IVANOVA	{"email": "ivanova-nadezhda.28101977@postgrespro.ru", "phone": "+70413119497"}
0005434427258	CCB915	6357 770092	MAKSIM VLASOV	{"phone": "+70077829825"}
0005434427259	CCB915	5755 166473	VLADIMIR MIRONOV	{"email": "vmironov27061985@postgrespro.ru", "phone": "+70071923805"}
0005434427260	A70BF8	0666 673080	ALEKSEY FOMIN	{"email": "fomin_a.1967@postgrespro.ru", "phone": "+70878806741"}
0005434427262	1851EE	7551 448733	LEONID NIKOLAEV	{"phone": "+70919230371"}
0005434427263	7A307C	7477 802913	ILFAT KUDRYASHOV	{"email": "ikudryashov-1972@postgrespro.ru", "phone": "+70772031350"}
0005434427264	D830CC	6640 364086	IRINA CHERNOVA	{"phone": "+70625928232"}
0005434427265	D830CC	0618 283658	ARTEM SCHERBAKOV	{"phone": "+70287679123"}
0005434427266	B911AB	2028 444501	VERA ORLOVA	{"email": "v-orlova1972@postgrespro.ru", "phone": "+70338906356"}
0005434427267	334FB2	7038 452008	YURIY ROMANOV	{"email": "y.romanov_1966@postgrespro.ru", "phone": "+70490562131"}
0005434427268	334FB2	2807 550193	TATYANA GUSEVA	{"email": "tatyana-guseva031973@postgrespro.ru", "phone": "+70342881956"}
0005434427269	02772D	6444 769130	OLGA SOROKINA	{"email": "sorokina_o-091983@postgrespro.ru", "phone": "+70063536121"}
0005434427270	2652D4	5082 575175	SERGEY KUZNECOV	{"phone": "+70841117422"}
0005434427271	DB56AE	7770 216224	IVAN POPOV	{"email": "popov-ivan07111975@postgrespro.ru", "phone": "+70629110228"}
0005434427272	478B0A	9004 606261	ANASTASIYA MALYSHEVA	{"phone": "+70649553497"}
0005434427273	C4E7C6	3442 625780	NADEZHDA KUZMINA	{"email": "nadezhda-kuzmina.1965@postgrespro.ru", "phone": "+70713417155"}
0005434427274	C4E7C6	4181 321294	NIKOLAY MARTYNOV	{"phone": "+70257007120"}
0005434427275	57EB19	4411 354179	VLADISLAV GRIGOREV	{"email": "grigorev.vladislav-03111968@postgrespro.ru", "phone": "+70065442945"}
0005434427276	F2F7BC	5258 719795	GALINA PAVLOVA	{"phone": "+70702675818"}
0005434427277	BBE1C7	6826 296336	ANDREY SIDOROV	{"email": "sidorovandrey.01031975@postgrespro.ru", "phone": "+70065306294"}
0005434427278	3B5E4F	6064 941807	SVETLANA POPOVA	{"email": "s-popova-27081985@postgrespro.ru", "phone": "+70450149813"}
0005434427279	3DF359	3275 696285	PAVEL EGOROV	{"email": "egorov.p-021973@postgrespro.ru", "phone": "+70013495030"}
0005434427280	E5C4F6	6388 155312	NIKOLAY FEDOROV	{"email": "fedorov_nikolay.20101968@postgrespro.ru", "phone": "+70541333955"}
0005434427281	2E5D7B	3081 965058	ANDREY IVANOV	{"email": "ivanov-a-28051971@postgrespro.ru", "phone": "+70636000002"}
0005434427282	2E5D7B	2843 218746	TATYANA SERGEEVA	{"phone": "+70492420352"}
0005434427283	24F266	4892 405678	VALENTINA MAKAROVA	{"phone": "+70093818730"}
0005434427284	C6711C	3126 695976	RUFINA BORISOVA	{"phone": "+70013415673"}
0005434427285	3D7565	1866 746439	SHAMIL KUZNECOV	{"email": "kuznecov-s1980@postgrespro.ru", "phone": "+70465257951"}
0005434427286	27E63B	6556 363011	IVAN MAKSIMOV	{"phone": "+70122113852"}
0005434427287	6A0AC2	0748 657429	NIKOLAY KARPOV	{"phone": "+70852683435"}
0005434427288	6A0AC2	6527 910402	ANDREY MAKAROV	{"email": "amakarov.09021986@postgrespro.ru", "phone": "+70516128911"}
0005434427289	E6D50C	5126 624910	ANASTASIYA ZAKHAROVA	{"email": "zakharova_anastasiya_111975@postgrespro.ru", "phone": "+70559612020"}
0005434427290	98749A	0754 438184	MIKHAIL BELOV	{"email": "belovm-071977@postgrespro.ru", "phone": "+70789754355"}
0005434427291	98749A	1515 674962	LYUDMILA MARTYNOVA	{"phone": "+70161061595"}
0005434427292	A5AAB9	4950 891827	PETR TIMOFEEV	{"email": "timofeev_petr-1979@postgrespro.ru", "phone": "+70420754227"}
0005434427293	A5AAB9	8664 170293	ZOYA MATVEEVA	{"phone": "+70974154955"}
0005434427294	349375	7321 240851	SVETLANA VLASOVA	{"email": "vlasova_svetlana.091966@postgrespro.ru", "phone": "+70701345485"}
0005434427295	B23AED	0186 314278	VIKTOR BARANOV	{"phone": "+70128000964"}
0005434427296	B23AED	7863 146686	RAISA DMITRIEVA	{"email": "dmitrieva-r071960@postgrespro.ru", "phone": "+70891689984"}
0005434427297	4B41E6	6812 293308	ANATOLIY BORISOV	{"phone": "+70971927069"}
0005434427298	4F411D	2491 914733	VERA KONOVALOVA	{"email": "v-konovalova.011966@postgrespro.ru", "phone": "+70834500890"}
0005434427299	41CF22	4655 374463	EKATERINA OVCHINNIKOVA	{"phone": "+70713538512"}
0005434427300	6624A2	2741 265661	VLADIMIR SCHERBAKOV	{"phone": "+70211610941"}
0005434427301	6374CE	7420 621854	ALEKSANDR MARTYNOV	{"phone": "+70221561251"}
0005434427303	7D94B2	2141 201336	EKATERINA GAVRILOVA	{"email": "gavrilovaekaterina.1980@postgrespro.ru", "phone": "+70183931983"}
0005434427304	7D94B2	3999 326245	LIDIYA KUZNECOVA	{"email": "lidiya.kuznecova-031977@postgrespro.ru", "phone": "+70059516383"}
0005434427305	959B84	2403 231367	IVAN VASILEV	{"email": "ivan_vasilev_27021974@postgrespro.ru", "phone": "+70015981351"}
0005434427306	959B84	3769 012481	ALEKSANDR YAKOVLEV	{"phone": "+70619531578"}
0005434427307	B6EA85	2367 670243	SERGEY MAKAROV	{"email": "s-makarov.101972@postgrespro.ru", "phone": "+70961625510"}
0005434427308	1C2D20	2939 182721	OLGA FOMINA	{"phone": "+70804649987"}
0005434427309	1C2D20	4725 096371	VIKTOR KRASNOV	{"phone": "+70854694773"}
0005434427310	B4BDC0	9210 948951	VLADIMIR GERASIMOV	{"phone": "+70682664342"}
0005434427311	B4BDC0	3179 258238	SVETLANA KUDRYASHOVA	{"phone": "+70780025110"}
0005434427312	1F377E	2055 687072	OLESYA ZOTOVA	{"email": "zotova-o.28021982@postgrespro.ru", "phone": "+70545848626"}
0005434427313	1F377E	8510 305657	ALEKSANDR SIDOROV	{"email": "sidorov_a.1963@postgrespro.ru", "phone": "+70983537173"}
0005434427314	6200FB	2947 467184	NATALYA PETROVA	{"email": "n-petrova-121967@postgrespro.ru", "phone": "+70954390972"}
0005434427315	AE0241	1167 635983	SVETLANA KOVALEVA	{"email": "kovaleva_s.101979@postgrespro.ru", "phone": "+70547683407"}
0005434427316	AE0241	9886 482003	NINA SIDOROVA	{"email": "n-sidorova031976@postgrespro.ru", "phone": "+70184111174"}
0005434427317	7BEFD7	4833 951486	DANIIL VOLKOV	{"phone": "+70836531719"}
0005434427318	7BEFD7	6456 122936	NATALYA PETROVA	{"phone": "+70849824669"}
0005434427319	7BEFD7	4592 335734	ROMAN EGOROV	{"email": "r-egorov1969@postgrespro.ru", "phone": "+70734740405"}
0005434427320	A0F6D6	4443 646691	OKSANA SERGEEVA	{"phone": "+70745111526"}
0005434427321	A0F6D6	6713 581081	OLGA MIRONOVA	{"phone": "+70787192160"}
0005434427322	9A78FE	5130 279463	VASILIY KUZNECOV	{"phone": "+70984154388"}
0005434427323	E308A9	9841 706190	IGOR MELNIKOV	{"phone": "+70260581290"}
0005434427324	E308A9	7197 155993	SERGEY KUDRYASHOV	{"phone": "+70486076600"}
0005434427325	60C6C2	9928 666635	TATYANA ZAYCEVA	{"email": "tzayceva031966@postgrespro.ru", "phone": "+70159344077"}
0005434427326	773BF2	9713 674025	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_23071965@postgrespro.ru", "phone": "+70672427485"}
0005434427327	99110A	3193 424131	ALEKSANDR NAZAROV	{"phone": "+70514083639"}
0005434427328	99110A	7471 533929	VERA OVCHINNIKOVA	{"phone": "+70472612878"}
0005434427329	99110A	1479 599871	GENNADIY SCHERBAKOV	{"phone": "+70788364678"}
0005434427330	7E51FA	7200 984576	VERA MATVEEVA	{"phone": "+70668060145"}
0005434427331	119065	2829 220466	ALEKSEY NIKOLAEV	{"phone": "+70984466523"}
0005434427332	4B9285	5304 439249	EVGENIY KUZNECOV	{"phone": "+70406950347"}
0005434427333	4B9285	9578 741360	EVGENIYA PETROVA	{"email": "petrova-evgeniya_041970@postgrespro.ru", "phone": "+70304156283"}
0005434427334	F67BCC	5227 994723	SERGEY ZHUKOV	{"email": "s-zhukov.22071986@postgrespro.ru", "phone": "+70297509145"}
0005434427335	F67BCC	8424 438277	TATYANA ANISIMOVA	{"email": "tatyana_anisimova121982@postgrespro.ru", "phone": "+70454521454"}
0005434427336	97558A	5951 786911	VALENTINA KRASNOVA	{"email": "valentinakrasnova05031971@postgrespro.ru", "phone": "+70168302131"}
0005434427337	152DA3	3222 312226	LEONID PETROV	{"email": "leonid.petrov-1978@postgrespro.ru", "phone": "+70409335909"}
0005434427338	74F1F4	3836 111805	SERGEY MIKHAYLOV	{"phone": "+70824793939"}
0005434427339	74F1F4	1245 948339	FEDOR TIMOFEEV	{"phone": "+70060304507"}
0005434427340	3D3E03	7822 938732	VSEVOLOD MAKSIMOV	{"phone": "+70645576012"}
0005434427341	3D3E03	9531 178089	NATALYA ZAKHAROVA	{"phone": "+70751850858"}
0005434427342	58CD5D	2123 096445	ANATOLIY MEDVEDEV	{"phone": "+70828372706"}
0005434427343	58CD5D	2004 554777	NATALYA NESTEROVA	{"email": "natalya_nesterova041976@postgrespro.ru", "phone": "+70165697696"}
0005434427344	4C2D2D	0383 448225	TIMUR NAUMOV	{"phone": "+70574258352"}
0005434427345	77D730	7646 477498	ANATOLIY DAVYDOV	{"email": "anatoliy.davydov1971@postgrespro.ru", "phone": "+70246395854"}
0005434427346	B8427D	4312 363170	LYUBOV KAZAKOVA	{"email": "kazakova-lyubov-071963@postgrespro.ru", "phone": "+70601133060"}
0005434427347	0D4CA1	7153 791352	DANILA ALEKSANDROV	{"email": "aleksandrovdanila_121973@postgrespro.ru", "phone": "+70023356461"}
0005434427348	0D4CA1	3905 083724	IRINA ISAEVA	{"email": "isaeva.irina121984@postgrespro.ru", "phone": "+70652872921"}
0005434427349	5A56A0	9954 463992	DMITRIY BORISOV	{"email": "borisovdmitriy.1970@postgrespro.ru", "phone": "+70746493825"}
0005434427350	19C7FB	8901 352801	PAVEL NIKITIN	{"email": "pavel.nikitin_061969@postgrespro.ru", "phone": "+70969332847"}
0005434427351	19C7FB	3636 293411	GENNADIY VOLKOV	{"phone": "+70299642139"}
0005434427352	62499E	2887 484530	TATYANA KISELEVA	{"phone": "+70790248292"}
0005434427353	62499E	7111 796673	NATALYA SEMENOVA	{"phone": "+70253224856"}
0005434427354	B81E9F	5191 616939	IVAN NOVIKOV	{"email": "novikovivan-071970@postgrespro.ru", "phone": "+70257115950"}
0005434427355	B81E9F	4366 517217	VALENTINA SERGEEVA	{"phone": "+70719683361"}
0005434427356	6999F7	4172 915330	VIKTORIYA TROFIMOVA	{"phone": "+70367457453"}
0005434427357	6999F7	7153 154959	ALSU SOLOVEVA	{"email": "soloveva.alsu_051979@postgrespro.ru", "phone": "+70364361750"}
0005434427358	5AEC80	5359 892614	VLADIMIR ILIN	{"phone": "+70888028757"}
0005434427359	0817B2	5726 894976	TAMARA MAKSIMOVA	{"phone": "+70518967502"}
0005434427360	0817B2	1409 987744	LARISA EFREMOVA	{"email": "efremova_larisa1966@postgrespro.ru", "phone": "+70848193647"}
0005434427361	B6A672	1387 178559	LILIYA PAVLOVA	{"email": "l-pavlova.031981@postgrespro.ru", "phone": "+70732035460"}
0005434427362	B6A672	1260 766227	BORIS VLASOV	{"email": "boris-vlasov-09071969@postgrespro.ru", "phone": "+70382423032"}
0005434434913	42BE20	5132 313310	NIKOLAY YAKOVLEV	{"phone": "+70441342105"}
0005434427363	32FAC6	5435 571994	NIKOLAY KUZNECOV	{"email": "kuznecov-n.1974@postgrespro.ru", "phone": "+70604110133"}
0005434427364	32FAC6	7514 562273	IVAN IVANOV	{"phone": "+70633666452"}
0005434427365	7CBD14	6762 925537	VLADIMIR BELOV	{"email": "belov.vladimir-081975@postgrespro.ru", "phone": "+70352856798"}
0005434427366	7CBD14	1344 364395	ANASTASIYA MEDVEDEVA	{"email": "anastasiya_medvedeva_11011979@postgrespro.ru", "phone": "+70495728512"}
0005434427367	54E1FF	7582 455819	FARIDA NAUMOVA	{"email": "naumova_farida.011970@postgrespro.ru", "phone": "+70929616448"}
0005434427368	2C69D5	0101 426931	GALINA PETROVA	{"phone": "+70426112420"}
0005434427369	8396B2	3859 706826	LYUDMILA NOVIKOVA	{"phone": "+70255075471"}
0005434427370	B34DF9	8910 153471	NATALYA EGOROVA	{"email": "egorova_n-091967@postgrespro.ru", "phone": "+70525408913"}
0005434427371	0B7406	2154 049801	LILIYA MOROZOVA	{"phone": "+70726515451"}
0005434427372	0B7406	2702 006659	VITALIY NAUMOV	{"email": "v_naumov-13101969@postgrespro.ru", "phone": "+70535251618"}
0005434427373	8C4E81	7853 587696	VALENTINA RYABOVA	{"phone": "+70180545531"}
0005434427374	F08852	6649 730393	VLADIMIR MIRONOV	{"phone": "+70025817947"}
0005434427375	F08852	8026 480828	TATYANA ZHUKOVA	{"email": "t-zhukova-031968@postgrespro.ru", "phone": "+70630431799"}
0005434427376	934333	0282 553889	ROMAN VOLKOV	{"email": "volkov-roman1964@postgrespro.ru", "phone": "+70727021434"}
0005434427377	9F2880	7159 641066	VLADISLAV SMIRNOV	{"phone": "+70838075627"}
0005434427378	2C358A	2026 096019	ALLA OVCHINNIKOVA	{"email": "a-ovchinnikova051973@postgrespro.ru", "phone": "+70544865825"}
0005434427379	4500CE	1242 835523	SERGEY DMITRIEV	{"email": "s-dmitriev021975@postgrespro.ru", "phone": "+70266645718"}
0005434427380	4500CE	8430 726295	TATYANA KOROLEVA	{"email": "koroleva_t061987@postgrespro.ru", "phone": "+70525280834"}
0005434427381	4500CE	1803 443146	VLADIMIR SIDOROV	{"email": "v_sidorov.12051961@postgrespro.ru", "phone": "+70310418546"}
0005434427382	364A2A	5634 720035	VALERIY ZAKHAROV	{"phone": "+70092160330"}
0005434427383	7C7B0F	7650 801236	VLADIMIR IVANOV	{"email": "v.ivanov_02051974@postgrespro.ru", "phone": "+70287181738"}
0005434427384	7C7B0F	8630 252440	OKSANA MIRONOVA	{"email": "mironova-o1979@postgrespro.ru", "phone": "+70418063012"}
0005434427385	30C0AD	3482 472759	EVGENIY ALEKSEEV	{"phone": "+70495709387"}
0005434427386	30C0AD	7853 165748	OKSANA KISELEVA	{"phone": "+70357350287"}
0005434427387	E52363	4786 885394	SERGEY KUZMIN	{"email": "s.kuzmin1977@postgrespro.ru", "phone": "+70488756746"}
0005434427388	F7144B	4454 129089	SERGEY MATVEEV	{"email": "matveev_s.091973@postgrespro.ru", "phone": "+70006188482"}
0005434427389	136183	3677 891132	SERGEY SOKOLOV	{"phone": "+70413550950"}
0005434427390	8D6089	9280 264434	SERGEY ALEKSANDROV	{"email": "sergey_aleksandrov.011957@postgrespro.ru", "phone": "+70084216767"}
0005434427391	8D6089	0806 256534	SVETLANA MOISEEVA	{"email": "s_moiseeva31101979@postgrespro.ru", "phone": "+70764239487"}
0005434427392	F85875	7961 976665	SERGEY DAVYDOV	{"email": "davydovs-24101967@postgrespro.ru", "phone": "+70049033856"}
0005434427393	F85875	9578 230999	EVGENIY ALEKSEEV	{"email": "e-alekseev1973@postgrespro.ru", "phone": "+70152932827"}
0005434427394	08352C	1151 005786	SERGEY KISELEV	{"phone": "+70208741572"}
0005434427395	9836E9	8486 252459	NATALIYA TITOVA	{"phone": "+70305635554"}
0005434427396	76FA1C	3005 109627	MARINA FEDOROVA	{"email": "fedorovamarina-1980@postgrespro.ru", "phone": "+70931346679"}
0005434427397	FF14D0	9258 892126	VALERIY KUZMIN	{"email": "kuzmin.valeriy061963@postgrespro.ru", "phone": "+70516621498"}
0005434427398	CB9BA5	9095 305242	YURIY EGOROV	{"phone": "+70647903352"}
0005434427399	CB9BA5	0004 295198	NIKOLAY FEDOROV	{"phone": "+70603365070"}
0005434427400	4C928F	9545 400382	YURIY KOROLEV	{"phone": "+70948718180"}
0005434427401	BD138C	5365 924594	GALINA SMIRNOVA	{"email": "g-smirnova_26041972@postgrespro.ru", "phone": "+70012908774"}
0005434427402	AC5C7E	0004 408134	ANDREY KOZLOV	{"phone": "+70662379728"}
0005434427403	B87C4A	0120 160876	EGOR NIKOLAEV	{"phone": "+70942465673"}
0005434427404	E922F5	9018 729263	VERA ANISIMOVA	{"phone": "+70772651824"}
0005434427405	92F276	1174 412221	ROMAN PETROV	{"email": "roman_petrov-071968@postgrespro.ru", "phone": "+70418421409"}
0005434427406	FEE7EC	7186 009452	VALERIY ALEKSEEV	{"email": "v_alekseev31101969@postgrespro.ru", "phone": "+70821315256"}
0005434427407	75B1B8	1164 815476	YURIY GUSEV	{"email": "y.gusev_28041962@postgrespro.ru", "phone": "+70698839886"}
0005434427408	D86FBA	8383 735814	EKATERINA BORISOVA	{"email": "borisova-e_1966@postgrespro.ru", "phone": "+70013376895"}
0005434427409	D86FBA	1519 760722	NINA ZHUKOVA	{"phone": "+70641634496"}
0005434427410	359303	4332 202009	IGOR RODIONOV	{"phone": "+70728873084"}
0005434427411	040F27	5099 212356	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-13081967@postgrespro.ru", "phone": "+70082430540"}
0005434427412	C15B25	6883 102206	ANASTASIYA MELNIKOVA	{"email": "anastasiya.melnikova-1967@postgrespro.ru", "phone": "+70468631150"}
0005434427413	B44D91	5829 715921	RAISA FOMINA	{"email": "r_fomina_061971@postgrespro.ru", "phone": "+70202789828"}
0005434427414	E8A2CF	3179 707152	ZINAIDA FILIPPOVA	{"email": "z_filippova_061983@postgrespro.ru", "phone": "+70016300699"}
0005434427415	E8A2CF	5165 000937	OLGA SOLOVEVA	{"phone": "+70410510649"}
0005434427416	EDAADB	1966 054801	ALEKSANDR TIMOFEEV	{"phone": "+70593845538"}
0005434427417	EDAADB	4468 322372	LYUDMILA VASILEVA	{"email": "lvasileva_121983@postgrespro.ru", "phone": "+70601211334"}
0005434427418	EDAADB	6059 162395	VALERIY GAVRILOV	{"email": "gavrilovv-22061978@postgrespro.ru", "phone": "+70606471572"}
0005434427419	8BAE8A	3429 511127	NINA DANILOVA	{"email": "n_danilova_11111970@postgrespro.ru", "phone": "+70060779848"}
0005434427420	8BAE8A	2551 812867	MIKHAIL NIKITIN	{"phone": "+70200409656"}
0005434427421	81F4FD	9513 972774	VLADIMIR GORBUNOV	{"phone": "+70781489673"}
0005434427422	10FB79	5447 900334	VIKTOR NOVIKOV	{"email": "viktornovikov.061966@postgrespro.ru", "phone": "+70095742426"}
0005434427423	BEF11F	6958 168188	PAVEL VOROBEV	{"email": "p_vorobev-111973@postgrespro.ru", "phone": "+70201143740"}
0005434427424	BEF11F	8141 542032	YULIYA GUSEVA	{"email": "yuliya.guseva.15021973@postgrespro.ru", "phone": "+70318903990"}
0005434427425	AF799C	1965 832251	GENNADIY SHEVCHENKO	{"email": "g_shevchenko.12081961@postgrespro.ru", "phone": "+70891693823"}
0005434427426	4EE58A	8160 449881	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov24101972@postgrespro.ru", "phone": "+70478196081"}
0005434427427	5CD5AF	4010 248124	MARGARITA BELOVA	{"email": "margarita_belova-31011963@postgrespro.ru", "phone": "+70301983436"}
0005434427428	C120C3	2215 524597	VALERIY OSIPOV	{"phone": "+70708447596"}
0005434427429	DA5E36	9969 013657	DMITRIY BORISOV	{"email": "borisov_d.09021986@postgrespro.ru", "phone": "+70535420178"}
0005434427430	0547AC	3523 699872	ELENA POPOVA	{"email": "popovae041977@postgrespro.ru", "phone": "+70963458302"}
0005434427431	0547AC	0130 061374	NATALYA OSIPOVA	{"email": "osipova_n-19101963@postgrespro.ru", "phone": "+70063524796"}
0005434427432	C7A4B4	8628 367075	GALINA YAKOVLEVA	{"phone": "+70016013613"}
0005434427433	D92913	9620 046360	KIRILL ORLOV	{"phone": "+70649872028"}
0005434427434	25C5DE	7632 206118	NADEZHDA BOGDANOVA	{"email": "nadezhda.bogdanova_1977@postgrespro.ru", "phone": "+70511062975"}
0005434427435	0167CA	8815 712484	ANDREY SEMENOV	{"email": "andrey-semenov_061965@postgrespro.ru", "phone": "+70001716834"}
0005434427436	7B22ED	9727 538439	ALEKSEY SEMENOV	{"email": "a-semenov_1982@postgrespro.ru", "phone": "+70924477136"}
0005434427437	F7BDEF	9513 559818	ALEKSANDRA SOLOVEVA	{"email": "aleksandrasoloveva1966@postgrespro.ru", "phone": "+70251460129"}
0005434427438	F7BDEF	4789 196914	ELENA FROLOVA	{"phone": "+70083680634"}
0005434427439	F44459	8611 236606	VALERIY MAKSIMOV	{"phone": "+70113289376"}
0005434427440	6231BC	0024 469365	IRINA MOROZOVA	{"email": "imorozova.22011975@postgrespro.ru", "phone": "+70568558120"}
0005434427441	F57D5C	4060 771624	DARINA KOROLEVA	{"email": "d.koroleva_25121973@postgrespro.ru", "phone": "+70801598794"}
0005434427442	F57D5C	8001 167195	OLGA KUZNECOVA	{"phone": "+70164100121"}
0005434427443	F57D5C	6629 713963	VALERIY ABRAMOV	{"email": "valeriy-abramov.29101971@postgrespro.ru", "phone": "+70604860657"}
0005434427444	168998	9865 717195	ALBINA BORISOVA	{"email": "a.borisova_20111970@postgrespro.ru", "phone": "+70295729112"}
0005434427445	F18F17	2015 338274	ANASTASIYA KUZMINA	{"phone": "+70670187680"}
0005434427446	32ED71	9220 718986	YULIYA KOZLOVA	{"phone": "+70545805386"}
0005434427447	32ED71	6129 471642	GALINA FROLOVA	{"phone": "+70645430953"}
0005434427448	F86C88	6078 539271	YAROSLAV MIKHAYLOV	{"phone": "+70337427475"}
0005434427449	F86C88	2045 149938	MARIYA NOVIKOVA	{"phone": "+70221373853"}
0005434427450	67EA59	1952 205085	MARIYA FROLOVA	{"email": "frolova.m_15111977@postgrespro.ru", "phone": "+70932140625"}
0005434427451	E29E37	5057 576383	VLADIMIR POPOV	{"email": "vladimir_popov-111965@postgrespro.ru", "phone": "+70952080160"}
0005434427452	63083A	1848 636387	VLADIMIR IVANOV	{"email": "ivanov-vladimir_081976@postgrespro.ru", "phone": "+70446801989"}
0005434427453	3BC806	6878 107904	VALENTIN RODIONOV	{"email": "v-rodionov_1972@postgrespro.ru", "phone": "+70608914147"}
0005434427454	5E269D	0765 698703	IGOR MIRONOV	{"phone": "+70693349210"}
0005434427455	5E269D	5139 281997	EVGENIY VASILEV	{"email": "evgeniyvasilev_1964@postgrespro.ru", "phone": "+70310698485"}
0005434427456	5E269D	6304 557339	OLGA TIMOFEEVA	{"phone": "+70925336353"}
0005434427457	518403	5608 187516	VIKTOR FEDOTOV	{"email": "fedotov-v29061981@postgrespro.ru", "phone": "+70333595336"}
0005434427458	987425	3292 126250	SERGEY CHERNOV	{"email": "chernovs.11021969@postgrespro.ru", "phone": "+70973228231"}
0005434427459	987425	7743 408153	FAIL ANTONOV	{"phone": "+70843457849"}
0005434427460	DFFCBC	7326 173687	ANASTASIYA PAVLOVA	{"phone": "+70552575127"}
0005434427461	DFFCBC	0311 478649	LYUDMILA ISAEVA	{"email": "l_isaeva-1969@postgrespro.ru", "phone": "+70674077080"}
0005434427462	7B2C26	8987 654380	VITALIY MAKAROV	{"phone": "+70416802193"}
0005434427463	998DAD	5286 878365	EKATERINA KONOVALOVA	{"email": "konovalova.e081967@postgrespro.ru", "phone": "+70456969164"}
0005434427464	C1E348	6728 992610	SERGEY AFANASEV	{"phone": "+70102730019"}
0005434427465	C1E348	2732 618498	NADEZHDA MALYSHEVA	{"phone": "+70271802003"}
0005434427466	C1E348	5006 249647	KSENIYA KUZNECOVA	{"phone": "+70609853152"}
0005434427467	624432	1177 330029	YANA ZAKHAROVA	{"email": "y-zakharova_091963@postgrespro.ru", "phone": "+70652040403"}
0005434427468	BFB26A	7631 494440	TATYANA ROMANOVA	{"phone": "+70136023307"}
0005434427469	A506A1	3713 025612	GENNADIY TIKHONOV	{"email": "tikhonov.gennadiy.1975@postgrespro.ru", "phone": "+70587436448"}
0005434427470	A506A1	8326 644245	SERGEY SEMENOV	{"email": "sergey-semenov1956@postgrespro.ru", "phone": "+70165263655"}
0005434427471	66631C	9559 084900	GALINA LEBEDEVA	{"phone": "+70712212799"}
0005434427472	822BAF	5891 818188	SERGEY FROLOV	{"email": "frolov_sergey041975@postgrespro.ru", "phone": "+70940847593"}
0005434427473	C6A30A	9954 056436	FANIYA IVANOVA	{"email": "ivanovafaniya23011972@postgrespro.ru", "phone": "+70688764808"}
0005434427474	C6A30A	8884 379964	ELENA SEMENOVA	{"email": "elenasemenova-031975@postgrespro.ru", "phone": "+70798488022"}
0005434427475	0417EC	1142 601823	ALEKSEY VOROBEV	{"email": "alekseyvorobev.1965@postgrespro.ru", "phone": "+70603868631"}
0005434434909	5C2365	2069 093565	MARINA IVANOVA	{"email": "ivanova-m24081972@postgrespro.ru", "phone": "+70689017445"}
0005434434910	368286	7451 325789	SERGEY PAVLOV	{"email": "sergey_pavlov-19081973@postgrespro.ru", "phone": "+70442968103"}
0005434434911	368286	9332 400513	EVGENIY BONDARENKO	{"phone": "+70784959843"}
0005434434912	8CE837	1541 202632	SHAMIL KRASNOV	{"email": "shamil.krasnov1973@postgrespro.ru", "phone": "+70385401393"}
0005434434914	A825CC	8398 232917	LYUDMILA ANTONOVA	{"email": "antonovalyudmila05031969@postgrespro.ru", "phone": "+70723342464"}
0005434434915	DB6399	3877 686325	ILYA MEDVEDEV	{"phone": "+70890929846"}
0005434434916	DB6399	5494 773245	IGOR NAZAROV	{"email": "i_nazarov.20011972@postgrespro.ru", "phone": "+70589606520"}
0005434434917	6C368D	0991 947488	LILIYA SAVELEVA	{"email": "l_saveleva.1966@postgrespro.ru", "phone": "+70170115251"}
0005434434918	399046	7354 661909	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov_03021966@postgrespro.ru", "phone": "+70115588722"}
0005434434919	7CA8D8	4858 087832	ALEKSANDR MELNIKOV	{"phone": "+70981001529"}
0005434434920	836504	4184 083562	ALEKSANDR IVANOV	{"email": "ivanov.a_20031963@postgrespro.ru", "phone": "+70410648466"}
0005434434921	05FA60	2507 141468	ELIZAVETA AFANASEVA	{"email": "elizaveta-afanaseva.04031979@postgrespro.ru", "phone": "+70668191089"}
0005434434922	05FA60	7919 417528	RAISA BORISOVA	{"email": "borisova.raisa_1976@postgrespro.ru", "phone": "+70386192695"}
0005434434923	25D60A	3273 545748	ALEFTINA EFREMOVA	{"phone": "+70343127440"}
0005434434924	25D60A	0752 652271	VLADIMIR SHEVCHENKO	{"email": "vladimir.shevchenko08071976@postgrespro.ru", "phone": "+70716469852"}
0005434434925	A8DB39	7434 030754	ANDREY DMITRIEV	{"phone": "+70715785786"}
0005434434926	8AABA5	6660 882847	MIKHAIL MAKAROV	{"email": "mikhail_makarov_12021966@postgrespro.ru", "phone": "+70744317792"}
0005434434927	8AABA5	3826 286934	EVGENIY ORLOV	{"email": "orlove_1971@postgrespro.ru", "phone": "+70594107230"}
0005434434928	512DBF	3084 394977	SERGEY KUZNECOV	{"email": "kuznecov_sergey-21081963@postgrespro.ru", "phone": "+70666534015"}
0005434434929	D5F062	1274 839057	PAVEL NIKITIN	{"email": "nikitinpavel.101970@postgrespro.ru", "phone": "+70808380456"}
0005434434930	AB3023	4135 737896	ELENA ANDREEVA	{"email": "andreeva.elena.25101985@postgrespro.ru", "phone": "+70425819277"}
0005434434931	AB3023	0102 774602	VERONIKA MALYSHEVA	{"email": "malysheva.veronika13061976@postgrespro.ru", "phone": "+70843811447"}
0005434434932	4DB1BD	0763 397481	YURIY KRASNOV	{"email": "krasnov-y19041966@postgrespro.ru", "phone": "+70314479107"}
0005434434933	CFF4FA	3994 274095	TATYANA TITOVA	{"email": "tatyana_titova-1973@postgrespro.ru", "phone": "+70268130919"}
0005434434934	2EE583	9450 891992	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr061978@postgrespro.ru", "phone": "+70812931612"}
0005434434935	2EE583	7737 686991	ROZA KUZNECOVA	{"email": "kuznecovar_1979@postgrespro.ru", "phone": "+70283178412"}
0005434434936	D99229	2634 456227	ANTONINA IVANOVA	{"email": "a-ivanova02071982@postgrespro.ru", "phone": "+70510374483"}
0005434434937	5DF1D1	1330 382242	VALENTINA ILINA	{"email": "valentinailina-1954@postgrespro.ru", "phone": "+70795139286"}
0005434434938	5DF1D1	6620 698497	NADEZHDA BORISOVA	{"email": "n.borisova.1971@postgrespro.ru", "phone": "+70953658520"}
0005434434939	650537	5364 753148	VIKTOR NOVIKOV	{"email": "novikov-viktor021979@postgrespro.ru", "phone": "+70283916052"}
0005434434940	650537	6444 057050	VIKTOR KUZNECOV	{"email": "viktorkuznecov.1969@postgrespro.ru", "phone": "+70131589075"}
0005434434941	113267	2993 352959	PRASKOVYA PETROVA	{"phone": "+70813209469"}
0005434434942	113267	2309 958008	LYUBOV ANISIMOVA	{"phone": "+70792945513"}
0005434434943	23C3BA	4920 846681	NATALIYA KOROLEVA	{"email": "koroleva.n-1960@postgrespro.ru", "phone": "+70450046657"}
0005434434944	FFCA81	2611 038691	VERA POPOVA	{"email": "verapopova.28051977@postgrespro.ru", "phone": "+70736561791"}
0005434434945	2149F7	6062 312692	EKATERINA ANDREEVA	{"phone": "+70049853867"}
0005434434946	860511	1363 212653	ANASTASIYA ZAKHAROVA	{"phone": "+70286374071"}
0005434434947	E9AB53	4257 046114	NATALYA EGOROVA	{"phone": "+70250965759"}
0005434434948	E9AB53	6591 005133	OLEG SMIRNOV	{"phone": "+70393881208"}
0005434434949	4E741B	4176 071689	ANNA VOLKOVA	{"phone": "+70938199266"}
0005434434950	4E741B	5004 092942	OLEG BELOV	{"email": "oleg.belov061968@postgrespro.ru", "phone": "+70757663161"}
0005434434951	8DF02F	7207 282289	EKATERINA NESTEROVA	{"email": "e-nesterova-051985@postgrespro.ru", "phone": "+70506035883"}
0005434434952	8DF02F	1865 650177	KIRILL ANTONOV	{"email": "antonov-k_15071965@postgrespro.ru", "phone": "+70148943335"}
0005434434953	8DF02F	7711 124842	SERGEY SOKOLOV	{"email": "sokolov.s28121963@postgrespro.ru", "phone": "+70586060956"}
0005434434954	86FECA	4578 228229	ANTONINA SEMENOVA	{"email": "antoninasemenova121975@postgrespro.ru", "phone": "+70244065250"}
0005434434955	86FECA	6650 045231	VLADIMIR SCHERBAKOV	{"email": "v-scherbakov-1972@postgrespro.ru", "phone": "+70273841036"}
0005434434956	EA81BB	9582 402432	NATALYA SIDOROVA	{"phone": "+70940423271"}
0005434434957	EA81BB	8394 801810	TATYANA STEPANOVA	{"phone": "+70017769394"}
0005434434958	6583E8	6374 712634	ANDREY BONDARENKO	{"phone": "+70463754603"}
0005434434959	1051B4	6001 281645	VLADIMIR SAVELEV	{"email": "vladimir_savelev.1968@postgrespro.ru", "phone": "+70017490456"}
0005434434960	0540B2	7587 515356	SVETLANA LAZAREVA	{"phone": "+70396441614"}
0005434434961	D3EA37	0717 720010	TATYANA MEDVEDEVA	{"phone": "+70529611479"}
0005434434962	D3EA37	6350 865664	VALENTINA NAZAROVA	{"phone": "+70562703938"}
0005434434963	0C155A	9539 651189	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov.061960@postgrespro.ru", "phone": "+70490765266"}
0005434434964	E2C7C5	1633 105394	LYUBOV SOROKINA	{"email": "sorokina_lyubov07121971@postgrespro.ru", "phone": "+70838868047"}
0005434434965	DF66E3	8591 747096	ELENA PAVLOVA	{"phone": "+70827841156"}
0005434434966	DF66E3	8351 441561	YURIY KAZAKOV	{"phone": "+70366527225"}
0005434434967	B247F9	0761 264790	ANDREY TARASOV	{"phone": "+70426218723"}
0005434434968	B247F9	7375 343947	ALEKSANDR KUZNECOV	{"email": "akuznecov.15051972@postgrespro.ru", "phone": "+70487556979"}
0005434434969	6BFB93	0271 531240	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.061977@postgrespro.ru", "phone": "+70633094885"}
0005434434970	6BFB93	9232 980780	OLGA KOLESNIKOVA	{"email": "olga-kolesnikova.1983@postgrespro.ru", "phone": "+70243421507"}
0005434434971	9ABC74	3527 431899	VLADIMIR SOLOVEV	{"email": "v-solovev.22051974@postgrespro.ru", "phone": "+70403753167"}
0005434434972	FBA1EF	2148 655616	VALERIY MAKAROV	{"phone": "+70736126012"}
0005434434973	FBA1EF	3634 988892	YAROSLAV GERASIMOV	{"phone": "+70331955962"}
0005434434974	DAAA87	6665 083221	VALENTINA EGOROVA	{"email": "egorova-v.111968@postgrespro.ru", "phone": "+70220147008"}
0005434434975	DAAA87	8645 227515	VLADIMIR EGOROV	{"phone": "+70027279432"}
0005434434976	136496	5393 772018	MIKHAIL KULIKOV	{"email": "m-kulikov-06101975@postgrespro.ru", "phone": "+70752707505"}
0005434434977	4A1A9D	2005 752652	NATALYA DMITRIEVA	{"email": "n_dmitrieva_30041972@postgrespro.ru", "phone": "+70957237932"}
0005434434978	4A1A9D	7588 534250	ANDREY SOKOLOV	{"phone": "+70993247648"}
0005434434979	4A1A9D	2597 096133	DMITRIY KUZNECOV	{"phone": "+70031142050"}
0005434434980	0F704A	4206 345901	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-05011982@postgrespro.ru", "phone": "+70368512335"}
0005434434981	0F704A	3861 752865	ANDREY BORISOV	{"email": "andreyborisov061968@postgrespro.ru", "phone": "+70704613372"}
0005434434982	6BC36E	2615 622378	SVETLANA MAKAROVA	{"phone": "+70851890958"}
0005434434983	33DD59	7768 707822	VLADIMIR ALEKSANDROV	{"email": "vladimir.aleksandrov-1979@postgrespro.ru", "phone": "+70244582611"}
0005434434984	33DD59	9894 915392	LIDIYA KUDRYASHOVA	{"email": "kudryashoval.21011967@postgrespro.ru", "phone": "+70722040408"}
0005434434985	76D150	1819 134405	VALENTINA FROLOVA	{"phone": "+70350058203"}
0005434434986	A1833C	8091 951563	ALEKSEY SOKOLOV	{"email": "aleksey_sokolov-091971@postgrespro.ru", "phone": "+70817488275"}
0005434434987	520082	1795 745694	VALERIYA KAZAKOVA	{"email": "vkazakova_16081975@postgrespro.ru", "phone": "+70023992749"}
0005434434988	5A53D7	8752 436148	LIDIYA FILATOVA	{"phone": "+70621189312"}
0005434434989	6FFD82	2664 656913	VALENTINA POPOVA	{"email": "v-popova-111965@postgrespro.ru", "phone": "+70560437037"}
0005434434990	BC5DA7	3484 440119	VIKTORIYA KUZNECOVA	{"phone": "+70307629444"}
0005434434991	434F7C	9526 269482	LYUBOV ANTONOVA	{"email": "antonova-lyubov_091970@postgrespro.ru", "phone": "+70257004943"}
0005434434992	434F7C	7516 946568	VIKTORIYA BORISOVA	{"phone": "+70595212823"}
0005434434993	434F7C	7600 747791	KARINA ROMANOVA	{"phone": "+70565254928"}
0005434434994	D1D056	1091 502590	GENNADIY GUSEV	{"phone": "+70010966932"}
0005434434995	7FBD40	8741 529553	NATALYA KOROLEVA	{"phone": "+70773639829"}
0005434434996	255D21	8079 016545	STANISLAV GORBUNOV	{"phone": "+70256551812"}
0005434434997	6FDD04	5924 793067	ALEKSANDRA ANTONOVA	{"phone": "+70682771101"}
0005434434998	6FDD04	5266 154704	ALEKSANDR KOROLEV	{"email": "korolevaleksandr_091968@postgrespro.ru", "phone": "+70286920808"}
0005434434999	51DB44	9535 319447	EVGENIY SMIRNOV	{"phone": "+70912272811"}
0005434435000	51DB44	1894 471372	ARSENIY EGOROV	{"email": "egorova_071979@postgrespro.ru", "phone": "+70548780819"}
0005434435001	01BEBA	7738 024698	ANTON BONDARENKO	{"email": "bondarenko-anton.021958@postgrespro.ru", "phone": "+70518952352"}
0005434435002	22340F	7701 244188	ELENA MAKAROVA	{"email": "makarova-elena_19081976@postgrespro.ru", "phone": "+70054608952"}
0005434435003	73E1B9	8073 081857	DARYA PETROVA	{"email": "dpetrova26101976@postgrespro.ru", "phone": "+70307720947"}
0005434435004	73E1B9	4438 443038	ARTEM IVANOV	{"phone": "+70673000873"}
0005434435005	8810AC	8049 807068	ELVIRA RYABOVA	{"phone": "+70616511378"}
0005434435006	ABDF69	7263 207409	EVGENIY SAVELEV	{"phone": "+70477707556"}
0005434435007	792FE8	7399 176062	MIKHAIL DENISOV	{"email": "mikhail_denisov_091974@postgrespro.ru", "phone": "+70731105291"}
0005434435008	792FE8	9628 848375	ANASTASIYA ZAKHAROVA	{"phone": "+70161331806"}
0005434435009	966665	7254 860912	ELENA BELOVA	{"email": "e.belova-08011973@postgrespro.ru", "phone": "+70115428547"}
0005434435010	3E9AFD	2309 502932	ALEKSANDR PAVLOV	{"phone": "+70651976072"}
0005434435011	3E9AFD	5115 070495	ZLATA NOVIKOVA	{"email": "zlatanovikova.051972@postgrespro.ru", "phone": "+70534500489"}
0005434435012	3E9AFD	9740 670764	VLADIMIR SEMENOV	{"phone": "+70051062968"}
0005434435013	3647FA	4056 920099	DMITRIY TARASOV	{"phone": "+70298213815"}
0005434435014	3647FA	5209 188735	ANASTASIYA DAVYDOVA	{"phone": "+70228401810"}
0005434435015	EF7DF0	7824 787397	IVAN ZHUKOV	{"email": "zhukovivan.1975@postgrespro.ru", "phone": "+70743913661"}
0005434435016	74B897	4717 103140	ANDREY VOROBEV	{"email": "vorobev_a_1978@postgrespro.ru", "phone": "+70260696559"}
0005434435017	74B897	7185 159781	PELAGEYA ALEKSEEVA	{"email": "p_alekseeva-1965@postgrespro.ru", "phone": "+70132262624"}
0005434435018	CA7419	1708 520892	VLADIMIR KISELEV	{"phone": "+70284318424"}
0005434435019	CA7419	4477 303913	RUSLAN AFANASEV	{"email": "afanasevr-1970@postgrespro.ru", "phone": "+70582525343"}
0005434435020	91D763	8389 203400	VIKTOR ANDREEV	{"email": "andreev.viktor.1972@postgrespro.ru", "phone": "+70518002087"}
0005434435021	91D763	3628 852681	KLAVDIYA POTAPOVA	{"email": "klavdiya_potapova071973@postgrespro.ru", "phone": "+70407118955"}
0005434435022	91D763	1162 910758	VALENTINA ARKHIPOVA	{"email": "valentina.arkhipova_051963@postgrespro.ru", "phone": "+70422954012"}
0005434435023	41DED4	5784 086358	PAVEL EGOROV	{"email": "egorov.p1960@postgrespro.ru", "phone": "+70353042091"}
0005434435024	41DED4	9221 602274	MILANA NOVIKOVA	{"email": "m-novikova-1967@postgrespro.ru", "phone": "+70484568733"}
0005434435025	87EA1E	8401 092285	ALEKSANDR ALEKSEEV	{"email": "aleksandr_alekseev.1969@postgrespro.ru", "phone": "+70512545346"}
0005434435026	A93DA8	5250 079971	NIKOLAY KARPOV	{"phone": "+70151391719"}
0005434435027	81CBFD	2196 662216	ROMAN IVANOV	{"phone": "+70955671093"}
0005434435028	81CBFD	9169 096222	ANDREY ABRAMOV	{"phone": "+70057156067"}
0005434435029	2A8A13	1211 566578	GEORGIY IVANOV	{"phone": "+70042337813"}
0005434435030	D47A9F	2053 806417	EVGENIY FROLOV	{"email": "evgeniy.frolov_071965@postgrespro.ru", "phone": "+70584957288"}
0005434435031	D47A9F	8667 784714	VIKTOR ALEKSEEV	{"email": "valekseev031979@postgrespro.ru", "phone": "+70810643160"}
0005434435032	D47A9F	6958 030234	EKATERINA MAKAROVA	{"phone": "+70876956516"}
0005434435033	02266C	4859 726792	IVAN IVANOV	{"email": "i-ivanov_22081965@postgrespro.ru", "phone": "+70182888089"}
0005434435034	B9FE2F	0550 621158	ZOYA SMIRNOVA	{"email": "smirnova_z_1971@postgrespro.ru", "phone": "+70249560308"}
0005434435035	1E847E	6024 340457	DENIS KULIKOV	{"email": "d_kulikov.31011966@postgrespro.ru", "phone": "+70854412407"}
0005434435036	13C9BB	3587 453486	DMITRIY OSIPOV	{"phone": "+70398605413"}
0005434435037	13C9BB	9364 386756	ALEKSANDR SOLOVEV	{"phone": "+70494522383"}
0005434435038	376E95	4724 075417	OLGA ZAYCEVA	{"email": "o.zayceva17051960@postgrespro.ru", "phone": "+70315552610"}
0005434435039	DFD69F	9555 987806	ARTEM NAUMOV	{"email": "artem.naumov-1982@postgrespro.ru", "phone": "+70942125683"}
0005434435040	DFD69F	6474 725123	ELENA CHERNOVA	{"phone": "+70583936281"}
0005434435041	2C36F0	2146 796430	OLGA KOMAROVA	{"email": "komarova_olga_1975@postgrespro.ru", "phone": "+70245775908"}
0005434435042	285B55	9569 859325	SERGEY MOROZOV	{"phone": "+70831765751"}
0005434435043	B0F177	3335 085657	KSENIYA KOLESNIKOVA	{"phone": "+70931031279"}
0005434435044	EE8CCC	8729 345179	ANDREY ZHURAVLEV	{"phone": "+70317825093"}
0005434435045	9C8BD0	0978 203178	VASILIY KUZNECOV	{"email": "kuznecov_v.30101981@postgrespro.ru", "phone": "+70240970218"}
0005434435046	CB9B75	8023 169015	ALEKSANDR VOROBEV	{"phone": "+70044393096"}
0005434435047	DD5BF2	9132 107540	LYUDMILA MIKHAYLOVA	{"email": "lyudmila-mikhaylova.041962@postgrespro.ru", "phone": "+70180934700"}
0005434435048	DD5BF2	1320 070022	ALEKSEY SAVELEV	{"email": "aleksey-savelev_031964@postgrespro.ru", "phone": "+70824251620"}
0005434435049	F0A6AB	7241 436435	MARINA ALEKSEEVA	{"email": "marina-alekseeva_1971@postgrespro.ru", "phone": "+70092399922"}
0005434435050	F0A6AB	5576 765449	ANNA KOVALEVA	{"phone": "+70633376018"}
0005434435051	C45CB6	0955 740547	IRINA STEPANOVA	{"email": "irina-stepanova.28031978@postgrespro.ru", "phone": "+70733390323"}
0005434435052	C45CB6	1152 945410	YULIYA ROMANOVA	{"email": "romanova-y.10041970@postgrespro.ru", "phone": "+70509543551"}
0005434435053	C45CB6	8299 441737	YURIY SOKOLOV	{"phone": "+70342273726"}
0005434435054	22B7BC	9561 331934	ANATOLIY MIKHAYLOV	{"email": "amikhaylov-24071975@postgrespro.ru", "phone": "+70075575095"}
0005434435055	22B7BC	6508 388822	ALENA NIKOLAEVA	{"email": "nikolaeva-alena-1973@postgrespro.ru", "phone": "+70703621410"}
0005434435056	22B7BC	2635 356923	ALEKSANDR KUZNECOV	{"phone": "+70428771100"}
0005434435057	162174	7434 134290	ELENA SOROKINA	{"email": "elena.sorokina18071979@postgrespro.ru", "phone": "+70312511548"}
0005434435058	525D14	5111 869231	LYUBOV SOROKINA	{"phone": "+70932352173"}
0005434435059	D0DB6D	1232 851705	ELENA ZHURAVLEVA	{"email": "zhuravleva_elena-041975@postgrespro.ru", "phone": "+70262158898"}
0005434435060	BEE235	0233 780834	VALERIY SEMENOV	{"email": "semenov_valeriy_28031982@postgrespro.ru", "phone": "+70692745169"}
0005434435061	BEE235	6469 079408	ANDREY YAKOVLEV	{"email": "ayakovlev1975@postgrespro.ru", "phone": "+70958166423"}
0005434435062	2FE306	9388 255509	GALINA STEPANOVA	{"email": "stepanovagalina-25111965@postgrespro.ru", "phone": "+70233186605"}
0005434435063	9B3528	3662 584738	VADIM NOVIKOV	{"phone": "+70930822218"}
0005434435064	A4991D	8850 553781	ANATOLIY KONOVALOV	{"email": "anatoliy.konovalov.091970@postgrespro.ru", "phone": "+70888709677"}
0005434435065	44448D	6528 070854	GENNADIY ZAYCEV	{"email": "zaycev-g.1977@postgrespro.ru", "phone": "+70527282723"}
0005434435066	318B2A	7858 917125	DMITRIY POPOV	{"phone": "+70035020219"}
0005434435067	316E06	6967 071946	GALINA OSIPOVA	{"email": "galina-osipova.30111983@postgrespro.ru", "phone": "+70541487190"}
0005434435068	3EB5D2	9663 783781	IRINA KOROLEVA	{"phone": "+70864194104"}
0005434435069	C6D0E1	7061 913465	ANNA FILIPPOVA	{"email": "a_filippova_14071975@postgrespro.ru", "phone": "+70480726479"}
0005434435070	E4C0D4	7364 072005	DARYA GUSEVA	{"phone": "+70714308599"}
0005434435071	2DC135	0490 752929	ALEKSANDR ZAYCEV	{"email": "zaycev_a.20011973@postgrespro.ru", "phone": "+70293200138"}
0005434435072	6F443D	4223 216595	ALEKSEY ISAEV	{"email": "a.isaev_18091974@postgrespro.ru", "phone": "+70829675370"}
0005434435073	972636	7049 673613	ANASTASIYA VOROBEVA	{"email": "anastasiya_vorobeva_27121951@postgrespro.ru", "phone": "+70627147560"}
0005434435074	ED37A6	0985 859486	TAISIYA KOVALEVA	{"email": "t_kovaleva.1969@postgrespro.ru", "phone": "+70439083634"}
0005434435075	60E97D	3673 169874	ANTONINA SERGEEVA	{"email": "asergeeva1972@postgrespro.ru", "phone": "+70468453220"}
0005434435076	B40692	3237 570248	EVGENIYA KAZAKOVA	{"phone": "+70476296367"}
0005434435077	D66F26	1201 928095	ANNA MAKAROVA	{"phone": "+70846477930"}
0005434435078	23FCBF	2471 547087	KONSTANTIN SERGEEV	{"email": "sergeev_k-1975@postgrespro.ru", "phone": "+70239750383"}
0005434435079	35AE5F	9030 984866	NATALYA SIDOROVA	{"email": "sidorovan-011976@postgrespro.ru", "phone": "+70782539062"}
0005434435080	185A3E	7991 964166	ILMIRA EGOROVA	{"phone": "+70712436619"}
0005434435081	E4B74C	6236 220806	MARIYA MIKHAYLOVA	{"email": "mikhaylova-m_111978@postgrespro.ru", "phone": "+70920834121"}
0005434435082	4050FF	6936 623793	NINA PETROVA	{"phone": "+70084181614"}
0005434435083	4050FF	1977 992263	ELENA MATVEEVA	{"phone": "+70811039078"}
0005434435084	163555	7200 501167	ALEKSANDRA KUZNECOVA	{"phone": "+70916148547"}
0005434435085	94919D	1103 519108	YURIY KUZMIN	{"phone": "+70825611524"}
0005434435086	94919D	4623 917723	OLGA KOROLEVA	{"phone": "+70716724862"}
0005434435087	058A7C	1362 394668	NIKOLAY SIDOROV	{"email": "nikolay.sidorov.1966@postgrespro.ru", "phone": "+70675849131"}
0005434435088	0080AB	1419 209478	VADIM BORISOV	{"email": "borisovv1986@postgrespro.ru", "phone": "+70797882844"}
0005434435089	0080AB	7844 762816	SVETLANA BARANOVA	{"phone": "+70623904016"}
0005434435090	950C1E	6319 030836	RAISA DAVYDOVA	{"email": "davydova.raisa1964@postgrespro.ru", "phone": "+70412111841"}
0005434435091	BC0512	4364 920756	DANILA POPOV	{"email": "danila-popov1979@postgrespro.ru", "phone": "+70810664058"}
0005434435092	57C39F	6968 588792	LIDIYA DAVYDOVA	{"phone": "+70957390953"}
0005434435093	57C39F	0163 172220	GALINA POPOVA	{"email": "g.popova101970@postgrespro.ru", "phone": "+70266070513"}
0005434435094	389C42	3173 441547	NIKITA IVANOV	{"phone": "+70956733366"}
0005434435095	8D7A33	3341 434093	OLGA BOGDANOVA	{"email": "olgabogdanova.08081970@postgrespro.ru", "phone": "+70104258848"}
0005434435096	8D7A33	2666 393302	NADEZHDA KARPOVA	{"phone": "+70723283102"}
0005434435097	1EF6E4	9291 051741	MARIYA KOZLOVA	{"phone": "+70836357205"}
0005434435098	1EF6E4	2948 623953	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-m-1980@postgrespro.ru", "phone": "+70957012402"}
0005434435099	D24EAE	6834 914985	FARID RODIONOV	{"email": "rodionovf-1969@postgrespro.ru", "phone": "+70122156912"}
0005434435100	C58C62	2456 066498	OLGA NOVIKOVA	{"phone": "+70081452574"}
0005434435101	993BB8	8308 125224	EGOR IVANOV	{"phone": "+70356035067"}
0005434435102	1F5882	0085 980962	DMITRIY ISAEV	{"phone": "+70889377312"}
0005434435103	03864B	4882 549898	ROZALIYA GORBUNOVA	{"email": "gorbunovar091970@postgrespro.ru", "phone": "+70232556270"}
0005434435104	03864B	2743 407730	ANDREY BORISOV	{"phone": "+70243914772"}
0005434435105	6EAAF2	7089 581998	ELENA KISELEVA	{"email": "elena-kiseleva31031969@postgrespro.ru", "phone": "+70493193493"}
0005434435106	031994	0362 060809	VALENTINA MIKHAYLOVA	{"phone": "+70789908978"}
0005434435107	031994	5232 895033	ANDREY GERASIMOV	{"phone": "+70180541690"}
0005434435108	031994	1646 704846	NADEZHDA MIKHAYLOVA	{"phone": "+70812419178"}
0005434435109	D1218B	1970 151763	SVETLANA MOISEEVA	{"email": "moiseeva.svetlana.11091979@postgrespro.ru", "phone": "+70114917583"}
0005434435110	D1218B	5174 165328	LYUDMILA MIRONOVA	{"email": "mironova_lyudmila-1973@postgrespro.ru", "phone": "+70714052661"}
0005434435111	85BC89	0981 551790	TATYANA SOKOLOVA	{"phone": "+70350562711"}
0005434435112	DCB945	1549 766460	YURIY NOVIKOV	{"phone": "+70695055612"}
0005434435113	5CD72C	6291 391056	ZINAIDA MIKHAYLOVA	{"email": "mikhaylovazinaida.031979@postgrespro.ru", "phone": "+70303261266"}
0005434435114	9DC740	5215 734291	DENIS DAVYDOV	{"phone": "+70069092557"}
0005434435115	5BEC11	6698 412708	VITALIY SAVELEV	{"email": "v.savelev.021970@postgrespro.ru", "phone": "+70948813192"}
0005434435116	F8BBB9	5519 630696	ANDREY ANDREEV	{"email": "andrey_andreev081973@postgrespro.ru", "phone": "+70777384869"}
0005434435117	F8BBB9	5446 688677	TIMOFEY VLASOV	{"phone": "+70647164530"}
0005434435118	6ED14F	5174 748201	IRINA IVANOVA	{"phone": "+70114012622"}
0005434435119	6ED14F	7314 778865	ELENA VASILEVA	{"email": "vasileva-elena_11091967@postgrespro.ru", "phone": "+70594182852"}
0005434435120	6ED14F	7342 437559	ANDREY SOROKIN	{"email": "sorokin-andrey.02101964@postgrespro.ru", "phone": "+70096569183"}
0005434435121	50EA9E	9699 355491	IVAN NOVIKOV	{"phone": "+70620198553"}
0005434435122	3F9EE9	1530 883988	ALEKSANDR FROLOV	{"email": "aleksandr-frolov.05071968@postgrespro.ru", "phone": "+70164854894"}
0005434435123	3F9EE9	9631 020831	VLADIMIR KRASNOV	{"email": "krasnov.vladimir.1959@postgrespro.ru", "phone": "+70278745843"}
0005434435124	C5009A	0936 914990	OLGA ALEKSEEVA	{"email": "olgaalekseeva.18031973@postgrespro.ru", "phone": "+70769912769"}
0005434435125	C5009A	5292 828875	OLEG SOROKIN	{"phone": "+70533032002"}
0005434435126	0A062C	0901 545502	ELIZAVETA ALEKSANDROVA	{"email": "elizaveta_aleksandrova_041973@postgrespro.ru", "phone": "+70933084443"}
0005434435127	0A062C	3486 572993	ELENA NIKOLAEVA	{"email": "enikolaeva.1970@postgrespro.ru", "phone": "+70741848903"}
0005434435128	0A062C	0616 112255	NATALYA OVCHINNIKOVA	{"email": "ovchinnikovanatalya-23011963@postgrespro.ru", "phone": "+70154274358"}
0005434435129	4AE7B3	7258 475273	IRINA DENISOVA	{"email": "irinadenisova19111977@postgrespro.ru", "phone": "+70123900484"}
0005434435130	0F5E50	5856 570528	ARMAN MOROZOV	{"email": "morozov.arman-24101966@postgrespro.ru", "phone": "+70459297205"}
0005434435131	CF4A6E	5285 366948	LARISA EGOROVA	{"phone": "+70702593818"}
0005434435132	FBE835	0129 804698	ISLAM KUDRYASHOV	{"phone": "+70098468567"}
0005434435133	FBE835	0722 870800	SERGEY OSIPOV	{"phone": "+70101017089"}
0005434435134	FBE835	8520 657993	POLINA SOROKINA	{"email": "psorokina-1963@postgrespro.ru", "phone": "+70128433863"}
0005434435135	98497E	2787 912359	OLEG PETROV	{"phone": "+70042781309"}
0005434435136	3E0F01	2506 006153	VALENTINA MAKAROVA	{"phone": "+70708856142"}
0005434435137	7B9058	7233 157065	IRINA KULIKOVA	{"phone": "+70075769776"}
0005434435138	51DA6F	0113 286199	MARINA AFANASEVA	{"phone": "+70274836452"}
0005434435139	51DA6F	2632 583637	IRINA KAZAKOVA	{"phone": "+70446852299"}
0005434435140	CA2AFE	6356 764352	DAMIR SCHERBAKOV	{"phone": "+70041154441"}
0005434435141	696563	8763 375765	GALINA SOROKINA	{"email": "sorokina-galina1971@postgrespro.ru", "phone": "+70646536475"}
0005434435142	696563	7297 285268	IGOR KUZMIN	{"phone": "+70229636022"}
0005434435143	5B89FA	0780 782447	ANDREY DENISOV	{"email": "andrey_denisov_15041967@postgrespro.ru", "phone": "+70197521263"}
0005434435144	5B89FA	3259 587162	OLGA TROFIMOVA	{"phone": "+70897044659"}
0005434435145	5A9B19	2798 013129	VERA KOLESNIKOVA	{"phone": "+70130631962"}
0005434435146	5A9B19	6466 574777	NATALYA IVANOVA	{"phone": "+70805254188"}
0005434435147	926048	7235 246692	VIKTOR MARTYNOV	{"email": "martynov.viktor14071974@postgrespro.ru", "phone": "+70924212369"}
0005434435148	1C7806	2767 214585	LYUDMILA DAVYDOVA	{"email": "lyudmila.davydova-121975@postgrespro.ru", "phone": "+70229564094"}
0005434435149	082100	5691 163900	VIKTOR ILIN	{"email": "ilinv_11051971@postgrespro.ru", "phone": "+70152410610"}
0005434435150	15D291	2374 094648	LARISA KONDRATEVA	{"phone": "+70335039220"}
0005434435152	9F4955	1246 830929	MARIYA MARTYNOVA	{"phone": "+70853483801"}
0005434435153	9F4955	7625 612243	ALEKSANDR BORISOV	{"phone": "+70301797504"}
0005434435154	F1328B	1075 836384	EGOR MIKHAYLOV	{"phone": "+70635641166"}
0005434435155	07A2C5	8864 303536	VALERIY SCHERBAKOV	{"phone": "+70185040703"}
0005434435156	BF641A	3449 221661	VASILIY ISAEV	{"phone": "+70455698966"}
0005434435157	E178DB	0964 285118	GENNADIY ZAYCEV	{"email": "gennadiyzaycev25071980@postgrespro.ru", "phone": "+70178485291"}
0005434435158	666C2D	8853 608915	OLGA STEPANOVA	{"phone": "+70812897624"}
0005434435159	666C2D	7029 889657	ANASTASIYA VLASOVA	{"phone": "+70300189140"}
0005434435160	D661CD	8282 651807	MARINA KOROLEVA	{"email": "koroleva-marina1977@postgrespro.ru", "phone": "+70766784729"}
0005434435161	7F7896	5375 388511	VLADIMIR MELNIKOV	{"email": "melnikov_v-1968@postgrespro.ru", "phone": "+70268144883"}
0005434435162	04E285	7757 831593	EVGENIY ORLOV	{"email": "orlov_e071974@postgrespro.ru", "phone": "+70003072054"}
0005434435163	04E285	3058 425584	SVETLANA MIRONOVA	{"phone": "+70889511392"}
0005434435164	50A288	5484 268399	VALENTINA VOLKOVA	{"phone": "+70612057230"}
0005434435165	50A288	6184 566194	ANASTASIYA ANISIMOVA	{"email": "anastasiya-anisimova.1976@postgrespro.ru", "phone": "+70010543651"}
0005434435166	F3B0EB	6883 944448	VIKTOR KUZNECOV	{"email": "vkuznecov-22081969@postgrespro.ru", "phone": "+70165511637"}
0005434435167	4B316E	8660 331309	MIKHAIL AFANASEV	{"email": "afanasev_mikhail051985@postgrespro.ru", "phone": "+70198951455"}
0005434435168	85EC8A	4072 442788	NINA KOROLEVA	{"phone": "+70176555887"}
0005434435169	66FAB8	1136 389588	VALERIY KOZLOV	{"email": "kozlovvaleriy_1966@postgrespro.ru", "phone": "+70686561633"}
0005434435170	6CAA77	5856 334835	ZAKHAR SOLOVEV	{"email": "solovevzakhar-07111970@postgrespro.ru", "phone": "+70318758609"}
0005434435171	B2B7F6	0078 987888	ALEKSANDRA KOROLEVA	{"phone": "+70879501113"}
0005434435172	B2B7F6	2965 640520	KIRILL ZAYCEV	{"email": "zaycev-k051979@postgrespro.ru", "phone": "+70837450211"}
0005434435173	9898BC	2119 834469	ALEKSANDR GRIGOREV	{"email": "grigorev_a121982@postgrespro.ru", "phone": "+70742903324"}
0005434435174	459C49	5704 849481	VALENTINA EGOROVA	{"phone": "+70555978465"}
0005434435175	459C49	9741 269817	TATYANA ZOTOVA	{"email": "t-zotova_01121969@postgrespro.ru", "phone": "+70479746349"}
0005434435176	D59F6D	8286 481502	OKSANA ISAEVA	{"email": "isaevao25011979@postgrespro.ru", "phone": "+70880674935"}
0005434435177	985238	1417 669147	TATYANA KUZNECOVA	{"phone": "+70658916466"}
0005434435178	9DC8BC	3263 303597	EVGENIY KARPOV	{"phone": "+70180797999"}
0005434435290	F7D454	1514 361009	VLADIMIR VASILEV	{"phone": "+70325298615"}
0005434435179	7CC2F6	3886 010050	NADEZHDA STEPANOVA	{"email": "stepanova.n.111972@postgrespro.ru", "phone": "+70021088232"}
0005434435180	B52064	0367 185961	EVGENIY VASILEV	{"email": "evasilev081975@postgrespro.ru", "phone": "+70105997035"}
0005434435181	A95440	9760 567959	YAROSLAV ROMANOV	{"email": "romanov-y-04081975@postgrespro.ru", "phone": "+70889223500"}
0005434435182	A95440	8791 248743	GLEB ALEKSEEV	{"phone": "+70749701442"}
0005434435183	4DCA85	0049 563058	MARIYA MALYSHEVA	{"email": "m-malysheva-101975@postgrespro.ru", "phone": "+70521882388"}
0005434435184	C2F18C	9545 172615	SVETLANA PETROVA	{"phone": "+70632712579"}
0005434435185	C4D176	4822 967382	MATVEY CHERNOV	{"phone": "+70402500754"}
0005434435186	FB0606	1673 975461	ILYA POPOV	{"email": "ilyapopov_061972@postgrespro.ru", "phone": "+70506836468"}
0005434435187	C871D8	8348 067997	NIKOLAY YAKOVLEV	{"phone": "+70181323044"}
0005434435188	3BB5D0	9462 727360	NATALYA MAKSIMOVA	{"phone": "+70762038499"}
0005434435189	0F56D0	0981 351580	RAMILYA LEBEDEVA	{"email": "lebedeva-r27091980@postgrespro.ru", "phone": "+70908971971"}
0005434435190	0F56D0	1837 792585	IVAN ANTONOV	{"phone": "+70588720812"}
0005434435191	F7A503	4583 536533	IRINA KOROLEVA	{"email": "koroleva.irina-23091982@postgrespro.ru", "phone": "+70185751059"}
0005434435192	16F3AF	3854 328025	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr-1966@postgrespro.ru", "phone": "+70917704764"}
0005434435193	BFF36D	9932 389445	DMITRIY ANTONOV	{"email": "antonovdmitriy.22081961@postgrespro.ru", "phone": "+70938151860"}
0005434435194	BFF36D	7074 218913	ALEKSANDR KUZNECOV	{"phone": "+70838656972"}
0005434435195	0E8E78	1963 710601	VADIM SERGEEV	{"email": "sergeev_v.1964@postgrespro.ru", "phone": "+70296993849"}
0005434435196	D6131F	3967 626629	ILYA KUZMIN	{"phone": "+70400649871"}
0005434435197	9AC6F8	9477 792119	NIKOLAY BORISOV	{"phone": "+70092479691"}
0005434435198	B14758	2488 043896	LYUBOV MAKSIMOVA	{"phone": "+70816865519"}
0005434435199	B14758	5519 316184	ANNA MIRONOVA	{"email": "mironova-a-041973@postgrespro.ru", "phone": "+70919246691"}
0005434435200	D14773	0823 609504	DENIS BORISOV	{"phone": "+70159158134"}
0005434435201	D14773	7600 672687	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir.02061966@postgrespro.ru", "phone": "+70447164931"}
0005434435202	E56E28	8466 994482	OLGA POPOVA	{"email": "popova-olga_1973@postgrespro.ru", "phone": "+70910126454"}
0005434435203	E56E28	7966 401192	TAMARA BARANOVA	{"phone": "+70245301258"}
0005434435204	09FAF3	1478 575869	ANATOLIY MELNIKOV	{"email": "a-melnikov.081970@postgrespro.ru", "phone": "+70325422986"}
0005434435205	09FAF3	6711 304589	TAISIYA LUKYANOVA	{"email": "lukyanova-t.05121980@postgrespro.ru", "phone": "+70296096136"}
0005434435206	328E13	5902 713599	EVGENIY MARTYNOV	{"phone": "+70316816575"}
0005434435207	328E13	2500 875169	ANDREY KOROLEV	{"email": "korolev.a.111972@postgrespro.ru", "phone": "+70735625341"}
0005434435208	328E13	2519 632387	YURIY VOLKOV	{"phone": "+70612416269"}
0005434435209	482C0A	8616 558509	SVETLANA GERASIMOVA	{"email": "svetlana_gerasimova_02051965@postgrespro.ru", "phone": "+70393796286"}
0005434435210	9F7B99	8120 522872	TATYANA TIMOFEEVA	{"phone": "+70590532418"}
0005434435211	9353FA	9959 588046	VLADIMIR KOZLOV	{"email": "kozlov_vladimir27111966@postgrespro.ru", "phone": "+70327156764"}
0005434435212	9353FA	3080 439026	ELENA VASILEVA	{"phone": "+70014321707"}
0005434435213	E7EC12	6985 735521	TAMARA SIDOROVA	{"phone": "+70968037768"}
0005434435214	E7EC12	6271 500372	NINA MIKHAYLOVA	{"phone": "+70717644725"}
0005434435215	D562D0	9763 123538	YULIYA BELOVA	{"email": "belova-yuliya-111981@postgrespro.ru", "phone": "+70736778294"}
0005434435216	6134A3	8152 971174	OLEG RODIONOV	{"email": "o-rodionov-08091977@postgrespro.ru", "phone": "+70209724785"}
0005434435217	6134A3	8768 586619	SERGEY NIKOLAEV	{"email": "s.nikolaev_081980@postgrespro.ru", "phone": "+70448009791"}
0005434435218	68DB01	5553 938263	YULIYA ZAYCEVA	{"phone": "+70125940052"}
0005434435219	D8EA61	9955 628379	ELENA IVANOVA	{"email": "ivanova.e.1979@postgrespro.ru", "phone": "+70852104533"}
0005434435220	D8EA61	0199 658669	VYACHESLAV POPOV	{"phone": "+70068895117"}
0005434435221	6034EC	5420 733401	GENNADIY KUZMIN	{"email": "kuzmin_gennadiy_13011969@postgrespro.ru", "phone": "+70521867019"}
0005434435222	6034EC	4483 959112	GALINA CHERNOVA	{"phone": "+70286796395"}
0005434435223	BD0CFB	4433 722221	ELENA POPOVA	{"email": "popovae_1970@postgrespro.ru", "phone": "+70535894236"}
0005434435224	BD0CFB	0840 699258	NINA SEMENOVA	{"email": "semenova_nina.26071971@postgrespro.ru", "phone": "+70010266086"}
0005434435225	E4DE9B	2451 245765	VIKTOR BORISOV	{"email": "v-borisov_07081980@postgrespro.ru", "phone": "+70800443455"}
0005434435226	F26BCA	7094 803711	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin1974@postgrespro.ru", "phone": "+70719184185"}
0005434435227	689824	7432 564016	VLADIMIR MOROZOV	{"email": "morozov_vladimir_1981@postgrespro.ru", "phone": "+70315491177"}
0005434435228	04A402	5045 237940	VIKTOR MIKHAYLOV	{"phone": "+70522220731"}
0005434435229	04A402	0367 315919	NATALYA VLASOVA	{"phone": "+70614497114"}
0005434435230	0D5FE6	7497 892323	YULIYA CHERNOVA	{"email": "chernova-yuliya22021963@postgrespro.ru", "phone": "+70275981419"}
0005434435231	9A55E4	0752 353649	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr1979@postgrespro.ru", "phone": "+70928061539"}
0005434435232	DEF0DB	9668 664407	POLINA KISELEVA	{"phone": "+70914168425"}
0005434435233	D69005	6521 817730	OLGA FILATOVA	{"email": "filatova.olga.111978@postgrespro.ru", "phone": "+70317433693"}
0005434435400	D6D19C	9861 020167	VLADIMIR KULIKOV	{"phone": "+70791877476"}
0005434435234	D69005	1323 701095	VALERIYA NAUMOVA	{"email": "naumova-valeriya071966@postgrespro.ru", "phone": "+70359289911"}
0005434435235	893D60	1969 158243	OLGA FILIPPOVA	{"phone": "+70501591089"}
0005434435236	893D60	5504 724165	SERGEY DENISOV	{"email": "s-denisov_17121960@postgrespro.ru", "phone": "+70578880008"}
0005434435237	893D60	6858 897010	SERGEY VASILEV	{"phone": "+70442220143"}
0005434435238	5B37BD	3246 183814	SERGEY IVANOV	{"email": "ivanov-sergey_031967@postgrespro.ru", "phone": "+70345429970"}
0005434435239	B9520D	0606 906662	ANNA ZAKHAROVA	{"email": "a_zakharova29061974@postgrespro.ru", "phone": "+70229707786"}
0005434435240	D88FAA	9690 728889	DARYA MOISEEVA	{"phone": "+70470112259"}
0005434435241	D88FAA	6588 825762	NATALYA SERGEEVA	{"phone": "+70445028287"}
0005434435242	0DE131	7048 830505	LYUDMILA KUZNECOVA	{"phone": "+70863470181"}
0005434435243	1A8AAE	6753 824585	ILYAS AFANASEV	{"phone": "+70603442174"}
0005434435244	1A8AAE	6414 767539	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko_031974@postgrespro.ru", "phone": "+70720093332"}
0005434435245	0883F7	5091 080969	BORIS CHERNOV	{"email": "boris.chernov051973@postgrespro.ru", "phone": "+70869716544"}
0005434435246	0883F7	6871 231413	SANIYA POPOVA	{"phone": "+70226688639"}
0005434435247	CC0097	2895 596898	OLGA NIKOLAEVA	{"email": "olga_nikolaeva.121975@postgrespro.ru", "phone": "+70985374989"}
0005434435248	EE9E34	6380 740978	MARIYA MAKSIMOVA	{"email": "maksimova.mariya.1968@postgrespro.ru", "phone": "+70524631369"}
0005434435249	74548D	0238 413571	NADEZHDA DAVYDOVA	{"phone": "+70124271254"}
0005434435250	44BB85	0284 044816	ALEFTINA ILINA	{"email": "a.ilina_101979@postgrespro.ru", "phone": "+70603201030"}
0005434435251	F0D8D9	6125 624618	VALENTINA BOGDANOVA	{"phone": "+70130498508"}
0005434435252	A9BDFE	5705 024655	NATALYA DENISOVA	{"email": "denisovan1982@postgrespro.ru", "phone": "+70572438026"}
0005434435253	A15B2B	4506 065795	GALINA ZAKHAROVA	{"email": "g.zakharova.081979@postgrespro.ru", "phone": "+70446783676"}
0005434435254	5AB3BA	5624 676324	MIKHAIL SMIRNOV	{"phone": "+70623069226"}
0005434435255	D7045B	4166 898333	DMITRIY NIKOLAEV	{"phone": "+70595153468"}
0005434435256	0225AE	1196 114015	ALEKSEY OSIPOV	{"phone": "+70671957747"}
0005434435257	0225AE	0925 085323	VLADIMIR KOZLOV	{"phone": "+70523639906"}
0005434435258	9E4D23	5650 679697	LADA STEPANOVA	{"email": "lada.stepanova_091973@postgrespro.ru", "phone": "+70534261272"}
0005434435259	26C23B	3126 403973	MARINA CHERNOVA	{"email": "chernovam.10091979@postgrespro.ru", "phone": "+70611829985"}
0005434435260	4ED934	4139 093307	ILYA IVANOV	{"email": "ilya-ivanov.05081970@postgrespro.ru", "phone": "+70527352781"}
0005434435261	4ED934	5779 621790	VALERIY DMITRIEV	{"phone": "+70300019364"}
0005434435262	545F2A	9937 554018	GEORGIY MARTYNOV	{"phone": "+70692539467"}
0005434435263	6B8FDE	1734 520549	ANASTASIYA NESTEROVA	{"email": "nesterovaanastasiya-1974@postgrespro.ru", "phone": "+70604903877"}
0005434435264	EEDF25	4479 307753	RIFAT MEDVEDEV	{"phone": "+70402911711"}
0005434435265	8BBA48	6365 262167	MIKHAIL NOVIKOV	{"email": "m-novikov-1974@postgrespro.ru", "phone": "+70074386276"}
0005434435266	6823EB	2131 996976	MARINA ROMANOVA	{"email": "m_romanova-1980@postgrespro.ru", "phone": "+70997599040"}
0005434435267	7AF999	1696 901214	GLEB ANDREEV	{"phone": "+70261182063"}
0005434435268	63654B	9549 851141	DMITRIY FEDOROV	{"phone": "+70166327185"}
0005434435269	63654B	2377 739571	YURIY YAKOVLEV	{"email": "yuriy_yakovlev.1975@postgrespro.ru", "phone": "+70025405688"}
0005434435270	E66286	7448 027967	VIKTOR ANTONOV	{"phone": "+70327546450"}
0005434435271	D0D111	1091 277536	MARINA LOGINOVA	{"phone": "+70650391016"}
0005434435272	0C5D58	4965 036846	NATALYA YUDINA	{"phone": "+70022856657"}
0005434435273	0C5D58	4280 102126	SERGEY SMIRNOV	{"phone": "+70351559379"}
0005434435274	03CE4D	8347 531554	OLGA KOZLOVA	{"phone": "+70424853758"}
0005434435275	F4290D	1273 613234	ANASTASIYA ZAKHAROVA	{"email": "zakharova_a-021970@postgrespro.ru", "phone": "+70114447563"}
0005434435276	14A940	5275 368623	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir_28061965@postgrespro.ru", "phone": "+70995631817"}
0005434435277	565F89	3765 359334	SVETLANA POPOVA	{"phone": "+70238332919"}
0005434435278	565F89	5659 729184	EKATERINA ALEKSEEVA	{"email": "ekaterina.alekseeva_1979@postgrespro.ru", "phone": "+70928246035"}
0005434435279	E04AFC	1449 592797	IVAN FROLOV	{"email": "ivan-frolov.1979@postgrespro.ru", "phone": "+70200643686"}
0005434435280	15F945	9829 213317	SERGEY GAVRILOV	{"email": "s_gavrilov-20011969@postgrespro.ru", "phone": "+70643770781"}
0005434435281	15F945	4746 291905	VALERIY DMITRIEV	{"phone": "+70461462319"}
0005434435282	24487B	6963 863524	PETR SCHERBAKOV	{"email": "petr.scherbakov1970@postgrespro.ru", "phone": "+70484066984"}
0005434435283	56995B	8079 284202	ANDREY NAZAROV	{"email": "a_nazarov22091975@postgrespro.ru", "phone": "+70884308509"}
0005434435284	B0BE3C	6911 485280	ALEKSANDR ZAKHAROV	{"email": "a-zakharov20011986@postgrespro.ru", "phone": "+70096780779"}
0005434435285	234680	3695 348053	NADEZHDA FADEEVA	{"email": "fadeeva.n-26021970@postgrespro.ru", "phone": "+70452388954"}
0005434435286	34D24A	4011 063852	KIRILL VOLKOV	{"email": "volkovk-1977@postgrespro.ru", "phone": "+70372284192"}
0005434435287	5570A0	5718 686498	NINA KARPOVA	{"phone": "+70498372643"}
0005434435288	5570A0	2312 399178	ANNA PAVLOVA	{"phone": "+70172452925"}
0005434435289	B69053	1589 294278	ALEKSANDR OSIPOV	{"email": "osipov.aleksandr13071971@postgrespro.ru", "phone": "+70470961102"}
0005434435291	AC164A	4492 448413	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr081967@postgrespro.ru", "phone": "+70045791860"}
0005434435292	C6EAF8	5021 262593	ALEKSANDR NIKOLAEV	{"phone": "+70426639371"}
0005434435293	3DB04D	3252 201743	ELENA VOROBEVA	{"email": "e-vorobeva.1978@postgrespro.ru", "phone": "+70668106527"}
0005434435294	14F1C0	5715 790595	EVGENIYA NAUMOVA	{"email": "naumova.evgeniya_061970@postgrespro.ru", "phone": "+70129429698"}
0005434435295	14F1C0	5393 670296	TATYANA FOMINA	{"email": "fominatatyana-1968@postgrespro.ru", "phone": "+70812679312"}
0005434435296	14F1C0	7394 052191	GALINA SEMENOVA	{"email": "g.semenova-1972@postgrespro.ru", "phone": "+70487432816"}
0005434435297	A4CEEB	4335 683669	MIKHAIL ISAEV	{"email": "m-isaev12051976@postgrespro.ru", "phone": "+70142578423"}
0005434435298	0C8E81	5176 403062	EGOR KOZLOV	{"email": "kozlov.egor_101972@postgrespro.ru", "phone": "+70665993698"}
0005434435299	0D0B81	4997 071481	EKATERINA SOLOVEVA	{"email": "ekaterina-soloveva-1960@postgrespro.ru", "phone": "+70636232845"}
0005434435300	82010A	8320 859955	VYACHESLAV GRIGOREV	{"email": "grigorev-vyacheslav.03041956@postgrespro.ru", "phone": "+70349724098"}
0005434435301	82010A	7959 815908	SVETLANA BOGDANOVA	{"phone": "+70313225810"}
0005434435302	A2109A	6869 049360	TAMARA CHERNOVA	{"phone": "+70487254372"}
0005434435303	A2109A	5575 950409	ZINAIDA SAVELEVA	{"phone": "+70254376112"}
0005434435304	DAF464	0220 887820	ANDREY POPOV	{"phone": "+70649588634"}
0005434435305	5B6C2E	0722 818859	LYUDMILA ARKHIPOVA	{"phone": "+70069528436"}
0005434435306	BA95C7	2611 317084	NATALYA MATVEEVA	{"phone": "+70803569860"}
0005434435307	490698	6771 153214	VERA KOZLOVA	{"email": "vera.kozlova_021974@postgrespro.ru", "phone": "+70123254885"}
0005434435308	E6CA0F	2257 751085	NATALYA BOGDANOVA	{"email": "nbogdanova.051967@postgrespro.ru", "phone": "+70382549572"}
0005434435309	BFBD34	8108 484996	ELIZAVETA DAVYDOVA	{"email": "davydovaelizaveta-1959@postgrespro.ru", "phone": "+70802974625"}
0005434435310	940913	8892 658512	ANNA FEDOROVA	{"phone": "+70439047906"}
0005434435311	48DB14	1745 103934	LYUBOV IVANOVA	{"email": "ivanova-lyubov-17031975@postgrespro.ru", "phone": "+70083656198"}
0005434435312	96B25D	8517 189242	ANASTASIYA TITOVA	{"email": "anastasiya-titova1960@postgrespro.ru", "phone": "+70927461796"}
0005434435313	D7B7B5	0396 642692	ELMIRA NIKITINA	{"phone": "+70461255493"}
0005434435314	D7B7B5	6862 557733	ANASTASIYA VOLKOVA	{"phone": "+70537059049"}
0005434435315	A8ADAB	2970 295790	ANDREY SMIRNOV	{"phone": "+70120423148"}
0005434435316	A8ADAB	2895 450399	TIMUR ISAEV	{"phone": "+70415213287"}
0005434435317	3BD1F8	1537 926160	IRINA ILINA	{"email": "irina.ilina1977@postgrespro.ru", "phone": "+70231983998"}
0005434435318	EF3C52	6631 383489	ANTONINA BELOVA	{"email": "belova.antonina_121973@postgrespro.ru", "phone": "+70647917100"}
0005434435319	EF3C52	4945 876467	TATYANA ORLOVA	{"phone": "+70722367128"}
0005434435320	EF3C52	5037 209425	VIKTOR KONOVALOV	{"email": "konovalov.v-081972@postgrespro.ru", "phone": "+70984096142"}
0005434435321	253421	2860 553460	GALINA MIKHAYLOVA	{"phone": "+70271567341"}
0005434435322	EE4654	2928 346624	ANGELINA TIMOFEEVA	{"phone": "+70553274981"}
0005434435323	B1BD7C	3925 268820	ZHANNA BELOVA	{"email": "belova.z071979@postgrespro.ru", "phone": "+70850998025"}
0005434435324	B1BD7C	7744 856179	TAMARA ANTONOVA	{"phone": "+70468580415"}
0005434435325	9390D5	8297 619211	GRIGORIY KOZLOV	{"email": "g.kozlov-031970@postgrespro.ru", "phone": "+70083122179"}
0005434435326	9BE645	8973 198706	DARYA KRASNOVA	{"phone": "+70347533540"}
0005434435327	9BE645	4783 447904	ZINAIDA GUSEVA	{"email": "z-guseva1962@postgrespro.ru", "phone": "+70679188614"}
0005434435328	AB6F5F	8422 904915	EMMA SOROKINA	{"email": "sorokina_emma111961@postgrespro.ru", "phone": "+70470828740"}
0005434435329	B1FE05	7010 639378	PETR GAVRILOV	{"phone": "+70636300428"}
0005434435447	3E644D	1320 486877	SERGEY ABRAMOV	{"phone": "+70163428352"}
0005434435330	B1FE05	1698 121793	EVGENIYA MAKAROVA	{"email": "evgeniya-makarova1967@postgrespro.ru", "phone": "+70761288826"}
0005434435331	981720	8130 850507	ANDREY FOMIN	{"email": "a.fomin.1975@postgrespro.ru", "phone": "+70142147463"}
0005434435332	591ECB	0950 520778	KSENIYA ANTONOVA	{"phone": "+70299342916"}
0005434435333	591ECB	4809 942550	ALEKSANDR NAZAROV	{"phone": "+70047559742"}
0005434435334	3A7E85	7717 516392	YURIY KUZNECOV	{"email": "y_kuznecov.18051967@postgrespro.ru", "phone": "+70407108057"}
0005434435335	9E69A1	9169 897122	VYACHESLAV NIKOLAEV	{"email": "nikolaevv121979@postgrespro.ru", "phone": "+70168896066"}
0005434435336	9E69A1	6995 692194	IVAN IVANOV	{"email": "iivanov_051971@postgrespro.ru", "phone": "+70928260811"}
0005434435337	9E69A1	2691 890889	YULIYA KISELEVA	{"email": "yuliya-kiseleva.121975@postgrespro.ru", "phone": "+70102922187"}
0005434435338	B60AB5	6889 903129	ERIK IVANOV	{"email": "e-ivanov-041975@postgrespro.ru", "phone": "+70567063871"}
0005434435339	0DC9A0	8782 181464	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov-1987@postgrespro.ru", "phone": "+70916848987"}
0005434435340	503AD3	7748 254588	TIMUR KARPOV	{"email": "t.karpov_1995@postgrespro.ru", "phone": "+70566155861"}
0005434435341	503AD3	5831 676344	ZINAIDA PETROVA	{"phone": "+70790777451"}
0005434435342	A29140	3186 714480	VLADISLAV KONOVALOV	{"phone": "+70144892522"}
0005434435343	A4502F	9574 966692	ZINAIDA BELOVA	{"email": "belovazinaida18071972@postgrespro.ru", "phone": "+70676641234"}
0005434435344	E48FEB	8584 747632	IVAN STEPANOV	{"email": "stepanov_ivan1973@postgrespro.ru", "phone": "+70095713867"}
0005434435345	E48FEB	6473 379962	ALEKSANDR IVANOV	{"phone": "+70426119719"}
0005434435401	B5FD48	9593 956077	NATALYA KOROLEVA	{"phone": "+70815101615"}
0005434435346	DC5967	4778 763308	EVGENIYA TARASOVA	{"email": "tarasova_e.081970@postgrespro.ru", "phone": "+70920213799"}
0005434435347	DC5967	2941 982883	TATYANA NIKITINA	{"phone": "+70334168491"}
0005434435348	9E1AD8	4576 122465	ALIYA KRASNOVA	{"phone": "+70649715816"}
0005434435349	15AC32	3236 696626	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr.011974@postgrespro.ru", "phone": "+70196420980"}
0005434435350	41C324	7694 146433	MARINA NAZAROVA	{"email": "nazarovam1967@postgrespro.ru", "phone": "+70012149996"}
0005434435351	429A8A	0937 709254	LYUDMILA ILINA	{"email": "lyudmilailina.1969@postgrespro.ru", "phone": "+70387555293"}
0005434435352	DBD794	6817 608200	ALEKSANDRA DMITRIEVA	{"email": "aleksandra-dmitrieva.1971@postgrespro.ru", "phone": "+70832778837"}
0005434435353	2CD9DC	4483 577759	TAMARA ROMANOVA	{"phone": "+70486732934"}
0005434435354	559AB0	4897 030685	PETR MIRONOV	{"email": "mironov-p.26071971@postgrespro.ru", "phone": "+70712083238"}
0005434435355	559AB0	8839 801541	YULIYA SMIRNOVA	{"phone": "+70765215251"}
0005434435356	559AB0	1519 811513	RUMIYA PAVLOVA	{"email": "pavlova_rumiya1966@postgrespro.ru", "phone": "+70869256188"}
0005434435357	E444D3	1799 198112	ANNA SOKOLOVA	{"email": "sokolova-anna.31051974@postgrespro.ru", "phone": "+70906952355"}
0005434435358	A1D2D6	5777 421610	ELENA ANDREEVA	{"email": "elena.andreeva_11021973@postgrespro.ru", "phone": "+70340696078"}
0005434435359	F2AB5C	0796 935616	NATALYA ZHUKOVA	{"email": "nzhukova-17011981@postgrespro.ru", "phone": "+70163865963"}
0005434435360	62507E	3569 157358	DANIL STEPANOV	{"email": "stepanovd27041974@postgrespro.ru", "phone": "+70561569416"}
0005434435361	269C53	6799 556925	VALERIYA ORLOVA	{"phone": "+70472862113"}
0005434435362	269C53	1339 096707	EVGENIYA PETROVA	{"email": "petrovaevgeniya_30071976@postgrespro.ru", "phone": "+70116642631"}
0005434435363	55FE5E	3128 614714	DMITRIY EGOROV	{"phone": "+70405323895"}
0005434435364	8A2B8B	6750 371551	PAVEL STEPANOV	{"email": "p_stepanov-011975@postgrespro.ru", "phone": "+70157713162"}
0005434435365	A6D911	6047 598363	VIKTORIYA FEDOROVA	{"phone": "+70069080255"}
0005434435366	A6D911	7093 642806	SVETLANA NOVIKOVA	{"email": "novikova.svetlana-121979@postgrespro.ru", "phone": "+70703204298"}
0005434435367	423AFC	8355 501148	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov021985@postgrespro.ru", "phone": "+70253098409"}
0005434435368	9540F3	5114 495261	RUFINA MARTYNOVA	{"email": "martynovarufina-1969@postgrespro.ru", "phone": "+70787100290"}
0005434435369	36E3CC	1145 677897	ALEKSANDR PAVLOV	{"phone": "+70842474645"}
0005434435370	7789B8	7007 650402	ALBINA KARPOVA	{"phone": "+70480210500"}
0005434435371	7789B8	0170 672105	LEONID SIDOROV	{"phone": "+70782444822"}
0005434435372	5BBCD2	6975 564737	NIKOLAY MARTYNOV	{"email": "martynov-nikolay_111969@postgrespro.ru", "phone": "+70817729517"}
0005434435373	3F393C	0657 380928	ANNA STEPANOVA	{"phone": "+70442632497"}
0005434435374	2E66D3	0154 739478	DMITRIY VASILEV	{"email": "vasilev_dmitriy.1972@postgrespro.ru", "phone": "+70174577542"}
0005434435375	E42A3B	8074 082190	MAKSIM GUSEV	{"phone": "+70413770189"}
0005434435376	BC6389	1906 796649	VALERIY MARTYNOV	{"email": "martynov_v.27041974@postgrespro.ru", "phone": "+70332115801"}
0005434435377	9449C3	6421 348094	SERGEY AFANASEV	{"email": "afanasev-s021978@postgrespro.ru", "phone": "+70971618099"}
0005434435378	771651	4561 089039	VLADIMIR SAVELEV	{"email": "vladimir-savelev-041959@postgrespro.ru", "phone": "+70606555823"}
0005434435379	9453A7	6138 795942	MARIYA MAKAROVA	{"phone": "+70625717964"}
0005434435380	9453A7	8999 230445	ALLA POPOVA	{"email": "apopova071972@postgrespro.ru", "phone": "+70550395274"}
0005434435381	E0A255	2731 193498	MIKHAIL FEDOTOV	{"email": "m_fedotov_1971@postgrespro.ru", "phone": "+70928955308"}
0005434435382	E0A255	3957 621669	VLADIMIR KAZAKOV	{"email": "kazakov-v-121972@postgrespro.ru", "phone": "+70723132975"}
0005434435383	6C5F97	8615 565529	ELENA IVANOVA	{"email": "elena_ivanova-06111969@postgrespro.ru", "phone": "+70298384379"}
0005434435384	81CCC4	1805 519337	ARTEM MAKAROV	{"email": "artem-makarov_1976@postgrespro.ru", "phone": "+70129681577"}
0005434435385	91ECF3	1589 651985	SERGEY KULIKOV	{"phone": "+70791298522"}
0005434435386	91ECF3	5523 695706	ANZHELA MAKSIMOVA	{"email": "a-maksimova-28021982@postgrespro.ru", "phone": "+70924954500"}
0005434435387	182BF2	8284 173589	MARIYA GORBUNOVA	{"email": "m-gorbunova_071961@postgrespro.ru", "phone": "+70341760658"}
0005434435388	137E13	0407 705598	ZULFIYA NOVIKOVA	{"phone": "+70887737166"}
0005434435389	87BFCA	4294 564842	ALEKSANDR ALEKSANDROV	{"email": "a_aleksandrov_101962@postgrespro.ru", "phone": "+70383916348"}
0005434435390	101F05	8795 013340	VLADISLAV PAVLOV	{"email": "v_pavlov.011983@postgrespro.ru", "phone": "+70827119752"}
0005434435391	101F05	5395 159185	VLADIMIR MEDVEDEV	{"email": "medvedev-vladimir.1977@postgrespro.ru", "phone": "+70721736420"}
0005434435392	066DEE	6930 202647	DMITRIY IVANOV	{"email": "ivanov.d041959@postgrespro.ru", "phone": "+70324218463"}
0005434435393	274051	9142 114905	MARIYA MOROZOVA	{"email": "m.morozova_1969@postgrespro.ru", "phone": "+70573192095"}
0005434435394	1E89BA	0290 482839	GRIGORIY NIKITIN	{"email": "nikiting_1987@postgrespro.ru", "phone": "+70784052811"}
0005434435395	603C68	6476 484735	ALEKSANDR ILIN	{"phone": "+70575592610"}
0005434435396	293276	1151 360528	VALERIY ZHUKOV	{"email": "valeriy.zhukov_041964@postgrespro.ru", "phone": "+70559365658"}
0005434435397	D90AEF	8835 082161	NADEZHDA PETROVA	{"email": "petrovanadezhda-1980@postgrespro.ru", "phone": "+70752569680"}
0005434435398	D90AEF	5780 177964	LYUDMILA DANILOVA	{"email": "danilova_lyudmila-1967@postgrespro.ru", "phone": "+70156718382"}
0005434435399	D90AEF	5984 760655	VALERIY TIKHONOV	{"phone": "+70871296153"}
0005434435402	F6A1EB	8228 725928	ANDREY KUZMIN	{"email": "kuzmina.08051964@postgrespro.ru", "phone": "+70124478104"}
0005434435403	745B2B	7041 330667	SERGEY KUZNECOV	{"phone": "+70972383393"}
0005434435404	745B2B	1103 873026	TATYANA PETROVA	{"email": "petrova_tatyana26101978@postgrespro.ru", "phone": "+70837255056"}
0005434435405	7168B4	6000 721164	IRINA PETROVA	{"phone": "+70399052905"}
0005434435406	F24916	3609 008071	NATALYA SCHERBAKOVA	{"email": "natalya-scherbakova1969@postgrespro.ru", "phone": "+70134974895"}
0005434435407	36B112	6073 009329	NIKOLAY NAUMOV	{"phone": "+70285591494"}
0005434435408	DCCBE2	2637 050088	LIDIYA POPOVA	{"phone": "+70750944774"}
0005434435409	50EBAE	0505 880793	ELENA LAZAREVA	{"email": "e_lazareva_1978@postgrespro.ru", "phone": "+70737585525"}
0005434435410	AEC5EF	4612 925539	MARAT MIRONOV	{"email": "m-mironov.1977@postgrespro.ru", "phone": "+70668195831"}
0005434435411	B7BD28	1789 978510	VERA MATVEEVA	{"email": "v_matveeva_14101964@postgrespro.ru", "phone": "+70978297024"}
0005434435412	B7BD28	2609 489978	MIKHAIL DENISOV	{"phone": "+70021102909"}
0005434435413	50C702	7320 251148	VLADIMIR DENISOV	{"email": "denisov.v29111979@postgrespro.ru", "phone": "+70938643647"}
0005434435414	7F10CC	9457 728371	IVAN SOKOLOV	{"phone": "+70280863017"}
0005434435415	ED3180	4707 123170	MAKSIM ANDREEV	{"email": "m_andreev_20101972@postgrespro.ru", "phone": "+70872226462"}
0005434435416	1FEB79	3034 147396	ELENA MARTYNOVA	{"phone": "+70096111331"}
0005434435417	9B79D9	1651 764398	OLEG PAVLOV	{"phone": "+70022632665"}
0005434435418	2DA564	1202 495627	NADEZHDA ZHUKOVA	{"phone": "+70813155223"}
0005434435419	4072DA	1989 931706	EKATERINA GUSEVA	{"email": "eguseva-1966@postgrespro.ru", "phone": "+70908269882"}
0005434435420	CFCF99	5057 087694	VERA TARASOVA	{"phone": "+70317913624"}
0005434435421	55088B	1601 627819	SERGEY NAUMOV	{"email": "s-naumov02011975@postgrespro.ru", "phone": "+70444725060"}
0005434435422	55088B	0641 291796	OLESYA VASILEVA	{"email": "vasileva_olesya_07011978@postgrespro.ru", "phone": "+70095951441"}
0005434435423	55088B	0409 867894	IVAN SERGEEV	{"phone": "+70708639494"}
0005434435424	3FB485	2868 652874	NATALYA BOGDANOVA	{"email": "bogdanova.natalya-051974@postgrespro.ru", "phone": "+70496902925"}
0005434435425	3FB485	5602 047635	ALEKSANDR PETROV	{"phone": "+70345346704"}
0005434435426	213840	9838 214927	IGOR MATVEEV	{"email": "matveev_igor.031978@postgrespro.ru", "phone": "+70043378491"}
0005434435427	213840	1292 545480	VASILIY KOROLEV	{"phone": "+70669138678"}
0005434435428	841E9E	4043 687333	GALINA ZHURAVLEVA	{"email": "gzhuravleva1981@postgrespro.ru", "phone": "+70064408931"}
0005434435429	841E9E	5889 977173	ANASTASIYA KUZMINA	{"email": "kuzmina.a.29091974@postgrespro.ru", "phone": "+70106296608"}
0005434435430	0921DC	6031 935865	YULIYA KOLESNIKOVA	{"email": "yuliya.kolesnikova25101965@postgrespro.ru", "phone": "+70534426428"}
0005434435431	0921DC	3987 633745	DARYA ANDREEVA	{"phone": "+70043572355"}
0005434435432	120D7F	8019 468409	DANIIL KONOVALOV	{"email": "konovalovd.29021972@postgrespro.ru", "phone": "+70171725429"}
0005434435433	630410	7379 869528	TATYANA KISELEVA	{"email": "t_kiseleva_091967@postgrespro.ru", "phone": "+70547910191"}
0005434435434	5EA731	4748 992441	ALEKSEY KRASNOV	{"email": "aleksey_krasnov-051971@postgrespro.ru", "phone": "+70198882093"}
0005434435435	AE08FB	9190 556118	VALENTINA KOVALEVA	{"email": "valentina_kovaleva1971@postgrespro.ru", "phone": "+70812891840"}
0005434435436	13E7C8	9718 690915	ALEKSEY KUZNECOV	{"phone": "+70730645269"}
0005434435437	A929CF	4804 750228	KIRILL BORISOV	{"email": "borisov.kirill-121971@postgrespro.ru", "phone": "+70462630631"}
0005434435438	478042	6263 321382	KONSTANTIN BORISOV	{"email": "k.borisov111981@postgrespro.ru", "phone": "+70632073780"}
0005434435439	478042	3441 815344	EVGENIY SAVELEV	{"email": "savelev.evgeniy.1970@postgrespro.ru", "phone": "+70714622154"}
0005434435440	3202CB	2569 111135	BORIS MOISEEV	{"phone": "+70487280502"}
0005434435441	3202CB	5837 696073	NATALYA KALININA	{"email": "natalyakalinina_081971@postgrespro.ru", "phone": "+70494631261"}
0005434435442	3202CB	5819 426308	SERGEY ILIN	{"phone": "+70315642881"}
0005434435443	8C94D7	1352 446648	SVETLANA FEDOROVA	{"email": "fedorova_s051968@postgrespro.ru", "phone": "+70987253072"}
0005434435444	30271B	4124 327929	YULIYA KUDRYASHOVA	{"email": "yuliyakudryashova.1986@postgrespro.ru", "phone": "+70491210980"}
0005434435445	30271B	7648 515806	OLGA GAVRILOVA	{"email": "gavrilova_olga-08061979@postgrespro.ru", "phone": "+70209973183"}
0005434435446	30271B	3327 176954	MARIYA TROFIMOVA	{"phone": "+70210182023"}
0005434435448	9D7420	6515 652318	TATYANA MIKHAYLOVA	{"phone": "+70936582844"}
0005434435449	204B29	4720 845990	VLADIMIR SOKOLOV	{"email": "sokolovv031989@postgrespro.ru", "phone": "+70145065665"}
0005434435450	48921B	0065 229183	MARINA YUDINA	{"email": "yudina.m_27071963@postgrespro.ru", "phone": "+70584005530"}
0005434435451	250C38	7822 171437	SVETLANA ISAEVA	{"email": "isaeva-s.021981@postgrespro.ru", "phone": "+70698578223"}
0005434435452	FE0040	3277 450397	LYUDMILA POPOVA	{"phone": "+70441549029"}
0005434435453	978467	4318 507510	IRINA PETROVA	{"phone": "+70303936515"}
0005434435454	978467	0670 049422	YURIY DAVYDOV	{"phone": "+70668534472"}
0005434435455	D4C92E	0043 506955	TATYANA ZAKHAROVA	{"phone": "+70173820980"}
0005434435456	6CEF54	2188 286708	NIKOLAY ZAKHAROV	{"email": "zakharov-nikolay.09031969@postgrespro.ru", "phone": "+70859576625"}
0005434435457	6CEF54	2816 249296	VALERIYA IVANOVA	{"phone": "+70996604402"}
0005434435458	DD0A2C	1069 761058	KIRILL KUZNECOV	{"phone": "+70815237813"}
0005434435459	BF842A	7588 380930	DMITRIY MELNIKOV	{"email": "melnikov_d.021965@postgrespro.ru", "phone": "+70892719250"}
0005434435460	BF842A	2574 328962	ALEKSEY BONDARENKO	{"phone": "+70396796670"}
0005434435461	BF842A	5192 772627	TATYANA KISELEVA	{"email": "kiseleva-tatyana1972@postgrespro.ru", "phone": "+70860929910"}
0005434435462	97A28D	5257 283999	EKATERINA EGOROVA	{"email": "eegorova-1974@postgrespro.ru", "phone": "+70164497353"}
0005434435463	97A28D	2408 315023	YAROSLAV SOKOLOV	{"phone": "+70260316596"}
0005434435464	F50F9F	0182 398230	ELENA CHERNOVA	{"email": "chernova-elena.13011969@postgrespro.ru", "phone": "+70870351618"}
0005434435465	7BDC07	1137 672046	NINA NOVIKOVA	{"email": "novikova-n-01041977@postgrespro.ru", "phone": "+70078383726"}
0005434435466	7BDC07	4540 922358	VERA KAZAKOVA	{"email": "kazakovav-1974@postgrespro.ru", "phone": "+70901736158"}
0005434435467	FDE340	1199 191666	VALENTINA MEDVEDEVA	{"email": "v_medvedeva_081971@postgrespro.ru", "phone": "+70078091669"}
0005434435468	D0F94B	6925 056089	RUFINA YAKOVLEVA	{"email": "yakovleva-rufina-091976@postgrespro.ru", "phone": "+70609090970"}
0005434435469	E98CF0	4588 681992	ELENA MIKHAYLOVA	{"email": "emikhaylova.1964@postgrespro.ru", "phone": "+70569707125"}
0005434435470	2E2E49	3629 264452	TATYANA AKIMOVA	{"email": "t.akimova_24091968@postgrespro.ru", "phone": "+70437729775"}
0005434435471	B23EDD	7690 959304	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov.061973@postgrespro.ru", "phone": "+70258473126"}
0005434435472	7BA77D	9012 383110	EVGENIY ZHURAVLEV	{"phone": "+70029889232"}
0005434435473	766A2A	2763 559227	VALENTIN POPOV	{"email": "popov.v121971@postgrespro.ru", "phone": "+70988252961"}
0005434435474	7FF4B6	2766 371966	OLGA VLASOVA	{"email": "vlasovao-021961@postgrespro.ru", "phone": "+70478568155"}
0005434435475	907686	8706 465743	DMITRIY SCHERBAKOV	{"email": "scherbakov.dmitriy_031979@postgrespro.ru", "phone": "+70107137172"}
0005434435476	907686	6489 484368	DANILA EGOROV	{"phone": "+70205578988"}
0005434435477	C76556	2552 084837	MAKSIM STEPANOV	{"email": "maksim.stepanov_101975@postgrespro.ru", "phone": "+70029621130"}
0005434435478	611913	4772 536211	ANDREY ABRAMOV	{"email": "abramov_andrey-1971@postgrespro.ru", "phone": "+70973850489"}
0005434435479	6D8E46	1087 567138	VALERIY SHEVCHENKO	{"email": "shevchenko_v-17011970@postgrespro.ru", "phone": "+70614541118"}
0005434435480	6D8E46	2109 683713	VLADIMIR GAVRILOV	{"email": "v.gavrilov27091975@postgrespro.ru", "phone": "+70218133566"}
0005434435481	482246	3937 991020	ALEKSANDR ZAKHAROV	{"phone": "+70001066538"}
0005434435482	10AA8C	4192 968956	MAKSIM STEPANOV	{"phone": "+70287534356"}
0005434435483	10AA8C	6115 056158	ELENA VASILEVA	{"email": "elenavasileva27081976@postgrespro.ru", "phone": "+70080664769"}
0005434435484	B0270D	4574 375764	EVGENIYA MATVEEVA	{"email": "matveeva.evgeniya061974@postgrespro.ru", "phone": "+70797477422"}
0005434435485	429248	8777 893038	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva081978@postgrespro.ru", "phone": "+70133007144"}
0005434435486	EDA87B	5936 553778	DMITRIY SOKOLOV	{"phone": "+70897036099"}
0005434435487	EDA87B	6940 517890	IGOR KUDRYASHOV	{"phone": "+70693815705"}
0005434435488	DB2184	8922 934663	ALBINA MARTYNOVA	{"email": "albina-martynova_1963@postgrespro.ru", "phone": "+70274664247"}
0005434435489	DB2184	7606 604939	VERA CHERNOVA	{"phone": "+70644168445"}
0005434435490	B00A21	2147 040994	NINA NIKOLAEVA	{"phone": "+70624542910"}
0005434435491	B00A21	0350 392322	VYACHESLAV GAVRILOV	{"phone": "+70179105057"}
0005434435492	03ADBD	8144 396967	EKATERINA KULIKOVA	{"phone": "+70631473948"}
0005434435493	262907	0763 087397	IRINA NOVIKOVA	{"phone": "+70872771146"}
0005434435494	738467	6953 921113	ANDREY KOZLOV	{"phone": "+70887669215"}
0005434435495	738467	9833 469390	NATALYA ZAKHAROVA	{"phone": "+70654342546"}
0005434435496	1BB15A	9365 692087	VLADIMIR BORISOV	{"phone": "+70616618885"}
0005434435497	1BB15A	6508 719517	ELENA MAKAROVA	{"email": "makarova-elena1975@postgrespro.ru", "phone": "+70027755574"}
0005434435498	5EA946	2021 512876	SERGEY SAVELEV	{"phone": "+70515883265"}
0005434435499	5EA946	1133 028046	NATALYA NIKOLAEVA	{"email": "natalya-nikolaeva.08011971@postgrespro.ru", "phone": "+70780528512"}
0005434435500	5EA946	1695 439985	YURIY KULIKOV	{"email": "yuriy_kulikov-1977@postgrespro.ru", "phone": "+70241690880"}
0005434435501	7C4B4B	9917 297120	ALENA KUZNECOVA	{"phone": "+70352638711"}
0005434435502	F6FD87	1415 693350	ELENA MAKAROVA	{"phone": "+70521941853"}
0005434435503	ECA59C	9124 431999	ANTONINA ZAYCEVA	{"phone": "+70257275007"}
0005434435504	78A30B	4974 247037	IRINA SOROKINA	{"phone": "+70436963890"}
0005434435505	78A30B	6826 705274	VIKTOR SERGEEV	{"phone": "+70488893651"}
0005434435506	5E4243	8465 774385	YULIYA DMITRIEVA	{"phone": "+70447674094"}
0005434435507	3C7CA2	7248 123429	VITALIY MAKAROV	{"email": "makarov-vitaliy.021957@postgrespro.ru", "phone": "+70833502339"}
0005434435508	3C7CA2	0029 191646	NATALYA CHERNOVA	{"email": "chernova-natalya.13051965@postgrespro.ru", "phone": "+70807340924"}
0005434435509	3C7CA2	4142 360709	DMITRIY SCHERBAKOV	{"email": "dmitriy.scherbakov051974@postgrespro.ru", "phone": "+70634475845"}
0005434435510	861E53	9585 665451	VERA KARPOVA	{"phone": "+70660965025"}
0005434435511	861E53	2821 116922	ALEKSANDR DENISOV	{"email": "denisov.a_1978@postgrespro.ru", "phone": "+70349656138"}
0005434435512	43B76A	2764 277199	VALENTIN VASILEV	{"email": "vasilev_valentin_021957@postgrespro.ru", "phone": "+70180618403"}
0005434435513	970900	4269 460316	NIKOLAY BELOV	{"phone": "+70170041961"}
0005434435514	970900	7402 941369	ALEKSANDR FROLOV	{"phone": "+70099448285"}
0005434435515	16E365	1781 951752	ALENA KUZMINA	{"email": "kuzminaalena.1965@postgrespro.ru", "phone": "+70346011414"}
0005434435516	1AD28B	6313 699441	KLAVDIYA SOKOLOVA	{"email": "sokolova_k17111975@postgrespro.ru", "phone": "+70139995259"}
0005434435517	52D305	3200 902988	EVGENIY BELOV	{"phone": "+70897156132"}
0005434435518	987492	0150 798283	VLADIMIR FEDOTOV	{"email": "vladimir.fedotov-071975@postgrespro.ru", "phone": "+70534780657"}
0005434435519	9D7CAD	8323 829741	ALSU TARASOVA	{"email": "tarasovaalsu-11021967@postgrespro.ru", "phone": "+70927526828"}
0005434435520	CB8E08	0158 856401	VYACHESLAV NAUMOV	{"email": "vyacheslav.naumov_091965@postgrespro.ru", "phone": "+70840962786"}
0005434435521	414D70	1896 944758	RAISA KOROLEVA	{"email": "koroleva-r-31101971@postgrespro.ru", "phone": "+70880269225"}
0005434435522	72E92C	5409 496572	VIKTOR KUZMIN	{"email": "viktor.kuzmin.1971@postgrespro.ru", "phone": "+70795208274"}
0005434435523	72E92C	4017 159036	OLEG DAVYDOV	{"email": "davydov.o_1974@postgrespro.ru", "phone": "+70962269289"}
0005434435524	094778	0772 232461	ILYA GERASIMOV	{"email": "i.gerasimov-1980@postgrespro.ru", "phone": "+70466912484"}
0005434435525	38266A	4392 353517	ANDREY ZAYCEV	{"phone": "+70147478582"}
0005434435526	4E184D	1402 339288	EKATERINA KUZNECOVA	{"email": "kuznecova_e_04031970@postgrespro.ru", "phone": "+70134425131"}
0005434435527	4E184D	6965 315079	SERGEY NOVIKOV	{"phone": "+70564097282"}
0005434435528	C8DF5E	3211 493790	ELENA NESTEROVA	{"email": "enesterova081968@postgrespro.ru", "phone": "+70153652994"}
0005434435529	C8DF5E	9859 936548	VIKTOR ANTONOV	{"email": "antonov_viktor-03091978@postgrespro.ru", "phone": "+70520629521"}
0005434435530	B36651	1745 478807	VALERIY PAVLOV	{"email": "pavlov-v15031969@postgrespro.ru", "phone": "+70155281674"}
0005434435531	F24E99	3744 249838	YURIY KULIKOV	{"email": "yuriy-kulikov28031974@postgrespro.ru", "phone": "+70260103698"}
0005434435532	F24E99	0888 222345	ALEKSEY NIKITIN	{"phone": "+70208628869"}
0005434435533	EDDB81	4724 265384	KRISTINA IVANOVA	{"email": "kristinaivanova.111960@postgrespro.ru", "phone": "+70959829259"}
0005434435534	EDDB81	0904 688093	ALBERT FROLOV	{"email": "frolov.a051977@postgrespro.ru", "phone": "+70019190394"}
0005434435535	29271A	6305 726807	ELENA MIKHAYLOVA	{"phone": "+70258858239"}
0005434435536	1CAD71	4614 439594	ANDREY YAKOVLEV	{"phone": "+70802820927"}
0005434435537	5C6760	0199 985367	ALEKSANDR GRIGOREV	{"phone": "+70874580796"}
0005434435538	7F9107	2319 203721	KSENIYA TARASOVA	{"email": "tarasova_kseniya-1984@postgrespro.ru", "phone": "+70058077527"}
0005434435539	7F9107	8522 125630	ALEKSANDR ILIN	{"phone": "+70133224128"}
0005434435540	C86AEF	2363 169813	DANIIL IVANOV	{"phone": "+70006323431"}
0005434435541	C86AEF	4207 361366	ALEKSANDR YAKOVLEV	{"email": "yakovleva_101971@postgrespro.ru", "phone": "+70304150513"}
0005434435542	27E9CD	0872 184710	LYUDMILA FADEEVA	{"phone": "+70416357711"}
0005434435543	27E9CD	5799 797723	LIDIYA KOROLEVA	{"phone": "+70180506524"}
0005434435544	FA310F	2290 086952	TATYANA TIKHONOVA	{"phone": "+70303138108"}
0005434435545	FA310F	4376 981956	NIKITA MIRONOV	{"phone": "+70799418354"}
0005434435546	258A9F	9255 390832	NATALYA POPOVA	{"email": "popova.n_1963@postgrespro.ru", "phone": "+70298215833"}
0005434435547	E547B1	4565 044998	ANNA NESTEROVA	{"email": "annanesterova_1968@postgrespro.ru", "phone": "+70430919823"}
0005434435548	DE24F5	6249 005856	VENERA SEMENOVA	{"phone": "+70083335379"}
0005434435549	FA8B8A	1062 974810	GRIGORIY BONDARENKO	{"phone": "+70735913969"}
0005434435550	979A3D	2945 740330	VALENTINA FILIPPOVA	{"phone": "+70505632805"}
0005434435551	979A3D	3623 390893	GALINA KOROLEVA	{"email": "koroleva_g1967@postgrespro.ru", "phone": "+70662566590"}
0005434435552	979A3D	9718 540457	ALEKSANDR GRIGOREV	{"email": "aleksandrgrigorev_021986@postgrespro.ru", "phone": "+70081389134"}
0005434435553	EC02C0	0741 945762	GYUZEL NIKOLAEVA	{"phone": "+70586720316"}
0005434435554	FD75B6	1871 679542	ALEKSEY KONOVALOV	{"email": "a.konovalov_011971@postgrespro.ru", "phone": "+70444050188"}
0005434435555	DD46CE	5720 763433	LYUDMILA NOVIKOVA	{"email": "l_novikova_1975@postgrespro.ru", "phone": "+70706214186"}
0005434435556	A47E40	5237 449929	ALEKSEY MAKAROV	{"phone": "+70410476418"}
0005434435557	A47E40	5314 800736	YULIYA IVANOVA	{"email": "y-ivanova-101969@postgrespro.ru", "phone": "+70174176220"}
0005434435558	2BF530	5485 572900	EVGENIY ZHURAVLEV	{"phone": "+70524198407"}
0005434435559	9564E0	6198 761573	ALEKSANDR NAZAROV	{"email": "anazarov_061960@postgrespro.ru", "phone": "+70348924005"}
0005434435560	7BD4EF	3066 765683	OLGA ANDREEVA	{"phone": "+70636403401"}
0005434435561	C0A82C	6265 281935	NIKOLAY KULIKOV	{"email": "n.kulikov-101973@postgrespro.ru", "phone": "+70323240673"}
0005434435562	AA9481	5293 069534	DAVID KUZMIN	{"phone": "+70314652062"}
0005434435563	AA9481	4008 096877	KSENIYA OVCHINNIKOVA	{"phone": "+70774942760"}
0005434435564	A4AD0B	0024 996723	LIDIYA FILIPPOVA	{"email": "filippova_lidiya_081975@postgrespro.ru", "phone": "+70886961545"}
0005434435565	1EFD64	5339 102124	OLGA ANDREEVA	{"phone": "+70609282714"}
0005434435566	749AFA	2999 016794	TATYANA KAZAKOVA	{"email": "tatyanakazakova-031967@postgrespro.ru", "phone": "+70324139690"}
0005434435567	749AFA	3525 413764	SVETLANA ROMANOVA	{"phone": "+70982334614"}
0005434435568	ED39A5	6779 652420	LYUBOV KOROLEVA	{"phone": "+70237622194"}
0005434435569	ED39A5	9775 969894	IRINA ALEKSEEVA	{"email": "i.alekseeva-1968@postgrespro.ru", "phone": "+70556467709"}
0005434435570	9803CB	3748 056255	EKATERINA ERMAKOVA	{"phone": "+70776222831"}
0005434435571	9803CB	7799 629079	VLADIMIR RODIONOV	{"email": "rodionov-v-05021983@postgrespro.ru", "phone": "+70011522835"}
0005434435572	07823F	5409 266329	LYUBOV LOGINOVA	{"email": "loginova-lyubov_1968@postgrespro.ru", "phone": "+70234909831"}
0005434435573	07823F	8089 668595	ANDREY BORISOV	{"phone": "+70885829191"}
0005434435574	F6FD16	1630 340729	ILYA MIKHAYLOV	{"email": "mikhaylovi-29121980@postgrespro.ru", "phone": "+70115437056"}
0005434435575	F6FD16	1760 561611	OLGA ALEKSEEVA	{"phone": "+70906422340"}
0005434435576	9E4B52	0892 892359	TATYANA MAKAROVA	{"phone": "+70297895950"}
0005434435577	07D029	0071 668908	ANNA ALEKSANDROVA	{"phone": "+70829328987"}
0005434435578	434F49	6548 371622	ALEKSANDR NAUMOV	{"phone": "+70198633550"}
0005434435579	C1967A	8910 774546	ANATOLIY RODIONOV	{"phone": "+70686800493"}
0005434435580	C1967A	8778 895706	ILDAR KUZNECOV	{"email": "ildarkuznecov_04021989@postgrespro.ru", "phone": "+70888701716"}
0005434435581	6756CD	7593 854590	MAKSIM FROLOV	{"email": "frolov_maksim_1977@postgrespro.ru", "phone": "+70055462855"}
0005434435582	9008FC	5960 004065	NIKOLAY MOROZOV	{"email": "morozov-nikolay-1969@postgrespro.ru", "phone": "+70465447575"}
0005434435583	9008FC	7270 241253	ALEKSANDR MAKAROV	{"email": "a.makarov091975@postgrespro.ru", "phone": "+70307265168"}
0005434435584	B544E0	5149 145081	YURIY IVANOV	{"email": "ivanov_y.111975@postgrespro.ru", "phone": "+70549486257"}
0005434435585	B544E0	6481 145654	SERGEY KUZNECOV	{"phone": "+70411258918"}
0005434435586	B544E0	2971 105475	MARIYA IVANOVA	{"email": "m-ivanova-26091973@postgrespro.ru", "phone": "+70254635183"}
0005434435587	58C07B	3672 809152	DANILA NOVIKOV	{"phone": "+70886320495"}
0005434435588	3E384C	2675 602793	OLGA ROMANOVA	{"email": "romanova.o.121965@postgrespro.ru", "phone": "+70600803097"}
0005434435589	3E384C	9208 199616	ALEKSANDR YAKOVLEV	{"phone": "+70262497793"}
0005434435590	3E384C	3535 214696	SERGEY PETROV	{"phone": "+70013323724"}
0005434435591	9A4E3E	7232 493679	GALINA LOGINOVA	{"phone": "+70320527718"}
0005434435592	9A4E3E	9095 632001	SVETLANA KUZMINA	{"email": "svetlana.kuzmina081972@postgrespro.ru", "phone": "+70296405249"}
0005434435593	CB0942	3598 651878	IRINA SMIRNOVA	{"phone": "+70600827645"}
0005434435594	4A62B3	3920 055977	ANDREY SMIRNOV	{"phone": "+70346090483"}
0005434435595	DC8596	3806 101397	KIRILL ORLOV	{"phone": "+70857552156"}
0005434435596	9366CE	6530 736295	MARIYA TROFIMOVA	{"email": "mtrofimova_01041971@postgrespro.ru", "phone": "+70329669523"}
0005434435597	F59961	2701 968730	NINA FILATOVA	{"email": "filatovan-11081965@postgrespro.ru", "phone": "+70009938779"}
0005434435598	6BB0E0	1789 973514	SVETLANA LEBEDEVA	{"phone": "+70320458166"}
0005434435599	3B2BB7	7946 447528	EKATERINA BORISOVA	{"phone": "+70400517217"}
0005434435600	055BAD	2465 519280	ILYA YAKOVLEV	{"email": "yakovlev_ilya.31031968@postgrespro.ru", "phone": "+70635567179"}
0005434435601	D5D607	7866 961268	VYACHESLAV KOZLOV	{"phone": "+70548584831"}
0005434435602	D5D607	2693 421124	TAMARA NIKOLAEVA	{"phone": "+70912032378"}
0005434435603	D5D607	5669 163154	ALEKSANDR ROMANOV	{"phone": "+70251104719"}
0005434435604	EF6677	4426 984704	ALSU ZAYCEVA	{"email": "alsuzayceva_20121972@postgrespro.ru", "phone": "+70195771496"}
0005434435605	EF6677	6068 303225	ALEKSANDR NOVIKOV	{"email": "a_novikov-14091974@postgrespro.ru", "phone": "+70356828180"}
0005434435606	2A0AF1	6407 031519	VALENTINA ARKHIPOVA	{"phone": "+70589446247"}
0005434435607	59BD2D	7970 730036	NATALIYA SEMENOVA	{"phone": "+70171200068"}
0005434435608	59BD2D	2646 054343	BORIS SIDOROV	{"phone": "+70338335897"}
0005434435609	E87397	6793 787732	MAKSIM STEPANOV	{"phone": "+70859954911"}
0005434435610	E87397	4703 863337	LYUDMILA SAVELEVA	{"phone": "+70067357899"}
0005434435611	844F13	2782 584737	ALEKSEY NAZAROV	{"email": "aleksey.nazarov1965@postgrespro.ru", "phone": "+70320542165"}
0005434435612	A30231	1959 660661	EKATERINA EFREMOVA	{"email": "efremova_ekaterina1986@postgrespro.ru", "phone": "+70400074350"}
0005434435613	0D10AA	7349 656417	ANDREY SMIRNOV	{"phone": "+70378902993"}
0005434435614	306AC9	6787 807788	FLYURA FILIPPOVA	{"phone": "+70588265006"}
0005434435615	10C0B2	5962 196263	ELENA VASILEVA	{"email": "elena_vasileva.031970@postgrespro.ru", "phone": "+70894262845"}
0005434435616	745284	2564 250276	OLGA TIMOFEEVA	{"email": "olga_timofeeva021978@postgrespro.ru", "phone": "+70896625619"}
0005434435617	F456B2	3865 313764	PETR IVANOV	{"email": "petr_ivanov_1968@postgrespro.ru", "phone": "+70710447765"}
0005434435618	5AF092	7986 529541	ZINAIDA KUDRYASHOVA	{"phone": "+70270623951"}
0005434435619	5AF092	7236 632548	TATYANA MIKHAYLOVA	{"phone": "+70787938310"}
0005434435620	AEB3A0	1641 434611	ARTUR BORISOV	{"phone": "+70229000625"}
0005434435621	C058AF	3988 384621	ELENA FOMINA	{"email": "fominae_12071978@postgrespro.ru", "phone": "+70581760335"}
0005434435622	D9872F	6230 555878	IGOR GUSEV	{"email": "igor.gusev.26021969@postgrespro.ru", "phone": "+70560035533"}
0005434435623	8FD27B	3144 129019	LYUDMILA KUDRYASHOVA	{"email": "kudryashova_l.121971@postgrespro.ru", "phone": "+70731430761"}
0005434435624	DE99F2	8918 232931	OLGA MAKAROVA	{"email": "o.makarova.06091972@postgrespro.ru", "phone": "+70604040262"}
0005434435625	36674E	2188 274981	OLEG BARANOV	{"email": "obaranov.111972@postgrespro.ru", "phone": "+70746591119"}
0005434435626	F0F5D8	9358 074243	VALENTIN MOROZOV	{"email": "morozovvalentin01031975@postgrespro.ru", "phone": "+70110005596"}
0005434435627	3FAB90	6364 453967	LYUDMILA IVANOVA	{"email": "ivanova-l.111976@postgrespro.ru", "phone": "+70233051371"}
0005434435628	981919	8317 170148	KHALIDA KOMAROVA	{"phone": "+70264567986"}
0005434435629	63B35A	9867 129833	VLADIMIR SMIRNOV	{"phone": "+70499981117"}
0005434435630	798524	6007 597037	SERGEY ANTONOV	{"email": "sergey_antonov_19081973@postgrespro.ru", "phone": "+70239196271"}
0005434435631	D8021B	7521 519458	ANNA FEDOROVA	{"phone": "+70001420073"}
0005434435632	D8021B	5880 320540	IVAN SHEVCHENKO	{"email": "shevchenkoivan.19101974@postgrespro.ru", "phone": "+70359875108"}
0005434435633	032632	1212 401457	NATALYA SOKOLOVA	{"phone": "+70495325502"}
0005434435634	032632	8657 535458	VALERIY MAKAROV	{"email": "makarov_v-081978@postgrespro.ru", "phone": "+70981685785"}
0005434435635	032632	5927 180426	VYACHESLAV PAVLOV	{"phone": "+70576609447"}
0005434435636	CDE02A	8531 577107	OLGA DAVYDOVA	{"phone": "+70715230938"}
0005434435637	CDE02A	8769 228848	ELENA PETROVA	{"phone": "+70722430091"}
0005434435638	22AEB5	9683 844247	LYUBOV KOZLOVA	{"phone": "+70689424643"}
0005434443424	5B5745	0008 506861	RAISA BOGDANOVA	{"email": "r_bogdanova.1967@postgrespro.ru", "phone": "+70249125074"}
0005434443425	1A9469	8424 033825	OLGA ILINA	{"phone": "+70858516326"}
0005434443426	703B0A	5719 872376	ALEKSEY DAVYDOV	{"email": "davydov-aleksey_031967@postgrespro.ru", "phone": "+70698136672"}
0005434443427	703B0A	7085 399079	NATALYA GORBUNOVA	{"phone": "+70928434919"}
0005434443428	08595C	4942 011225	MAGOMED GORBUNOV	{"email": "mgorbunov-011977@postgrespro.ru", "phone": "+70422155198"}
0005434443429	7EEDBE	8026 711548	TATYANA TITOVA	{"phone": "+70282263689"}
0005434443430	7EEDBE	5827 094165	OLEG ROMANOV	{"email": "romanov-o.1967@postgrespro.ru", "phone": "+70808721588"}
0005434443431	EEE08A	7028 239450	DMITRIY ILIN	{"email": "ilin.dmitriy_1972@postgrespro.ru", "phone": "+70820529350"}
0005434443432	016832	8183 667174	ARTEM VOLKOV	{"email": "volkova041983@postgrespro.ru", "phone": "+70378234151"}
0005434443433	FDD5D2	8257 624571	ILYA MIKHAYLOV	{"email": "i.mikhaylov-1980@postgrespro.ru", "phone": "+70639012364"}
0005434443434	FDD5D2	3194 667141	NATALYA ANTONOVA	{"email": "antonova.natalya_1970@postgrespro.ru", "phone": "+70841877967"}
0005434443435	9E3C71	3594 317661	EKATERINA YUDINA	{"email": "ekaterina.yudina-04061974@postgrespro.ru", "phone": "+70067023690"}
0005434443436	0F13F3	8552 566580	ANASTASIYA LOGINOVA	{"phone": "+70383547870"}
0005434443437	0F13F3	4364 182740	NINA KUZNECOVA	{"email": "nina_kuznecova.02061974@postgrespro.ru", "phone": "+70139219445"}
0005434443438	688677	7063 756062	PAVEL ILIN	{"email": "pavel.ilin_041966@postgrespro.ru", "phone": "+70403350295"}
0005434443439	F54C3A	7705 514340	NIKOLAY MIKHAYLOV	{"email": "nikolaymikhaylov1964@postgrespro.ru", "phone": "+70531020811"}
0005434443440	E94933	7321 210051	OLGA KULIKOVA	{"phone": "+70502341586"}
0005434443441	86F92A	7548 744693	ALEKSANDR BARANOV	{"phone": "+70155633274"}
0005434443442	29928B	1530 960805	IVAN KRASNOV	{"phone": "+70853557186"}
0005434443443	B66DE3	0124 732925	ANTONINA BELYAEVA	{"email": "belyaeva.a-051971@postgrespro.ru", "phone": "+70242102973"}
0005434443444	EA6150	6556 480017	OLGA ZHURAVLEVA	{"email": "zhuravleva_o121971@postgrespro.ru", "phone": "+70176820691"}
0005434443445	8699A1	3358 007487	ALEKSANDR ZAKHAROV	{"phone": "+70570612280"}
0005434443446	36BC25	2751 476484	ROMAN RODIONOV	{"email": "roman.rodionov1955@postgrespro.ru", "phone": "+70794139816"}
0005434443447	8DF13A	6129 631124	ELENA ISAEVA	{"phone": "+70629567619"}
0005434443448	9AEFEB	9674 139775	MIKHAIL MATVEEV	{"phone": "+70725366214"}
0005434443449	066B4C	9190 962175	MIKHAIL GORBUNOV	{"email": "gorbunov_mikhail041969@postgrespro.ru", "phone": "+70959725004"}
0005434443450	B53E79	6759 189102	EVGENIY NAZAROV	{"email": "e.nazarov01101969@postgrespro.ru", "phone": "+70649656900"}
0005434443451	B53E79	6917 473659	LIDIYA KUZMINA	{"email": "l_kuzmina_22071972@postgrespro.ru", "phone": "+70552728038"}
0005434443452	A240DD	2426 553253	ULYANA RYABOVA	{"email": "ulyana.ryabova_071973@postgrespro.ru", "phone": "+70157287462"}
0005434443453	6DB8BB	5045 068926	VALERIY TIMOFEEV	{"email": "timofeev_valeriy-22021970@postgrespro.ru", "phone": "+70830657411"}
0005434443454	51FEA7	3194 879447	IGOR SEMENOV	{"phone": "+70305636150"}
0005434443455	EAC471	3026 440560	STEPAN KUZNECOV	{"email": "stepan.kuznecov_061966@postgrespro.ru", "phone": "+70406164257"}
0005434443456	F994B3	3117 062152	YURIY KUZMIN	{"phone": "+70487585276"}
0005434443457	FD941A	2646 445637	LYUBOV MOISEEVA	{"email": "moiseeva.lyubov.1974@postgrespro.ru", "phone": "+70512976362"}
0005434443514	FA9FFA	2368 145651	NIKOLAY KUZMIN	{"phone": "+70851941849"}
0005434443458	281FA8	9733 547628	PETR CHERNOV	{"email": "pchernov.09061976@postgrespro.ru", "phone": "+70851205281"}
0005434443459	F26FD0	1164 808691	TAMARA NIKOLAEVA	{"email": "t.nikolaeva.05031968@postgrespro.ru", "phone": "+70547960099"}
0005434443460	F26FD0	3365 327531	ALEKSEY KISELEV	{"email": "aleksey.kiselev101973@postgrespro.ru", "phone": "+70355437632"}
0005434443461	EB9438	0843 265327	ALEKSEY KONOVALOV	{"phone": "+70579706277"}
0005434443462	A60972	6731 840014	VALENTINA FOMINA	{"email": "fominavalentina.051962@postgrespro.ru", "phone": "+70513032634"}
0005434443463	D21ACC	5536 500466	NINA EGOROVA	{"email": "egorova_nina-1981@postgrespro.ru", "phone": "+70232232350"}
0005434443464	5A41E3	6147 771117	VIKTOR KULIKOV	{"phone": "+70090214503"}
0005434443465	6E009D	0446 344743	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov011976@postgrespro.ru", "phone": "+70526269155"}
0005434443466	6E009D	9905 771104	ANDREY CHERNOV	{"phone": "+70453542240"}
0005434443467	D5DBDC	7501 242231	ELENA GUSEVA	{"email": "guseva.elena_28031965@postgrespro.ru", "phone": "+70616343418"}
0005434443468	F534E3	8487 335736	DINARA KUZMINA	{"email": "dinara_kuzmina-12121976@postgrespro.ru", "phone": "+70429785650"}
0005434443469	777BEC	8405 097789	DMITRIY GERASIMOV	{"phone": "+70342150497"}
0005434443470	777BEC	4706 332029	NATALYA NIKOLAEVA	{"email": "natalya.nikolaeva.041971@postgrespro.ru", "phone": "+70324578552"}
0005434443471	8CA64B	0211 409994	ALEKSANDR KUZMIN	{"phone": "+70453378232"}
0005434443472	196270	8725 111216	DMITRIY KARPOV	{"email": "dkarpov.081965@postgrespro.ru", "phone": "+70298308634"}
0005434443473	3FBDB0	2720 863490	OLEG KULIKOV	{"email": "kulikov.o1982@postgrespro.ru", "phone": "+70172368491"}
0005434443474	6F7E30	1450 126408	SVETLANA GAVRILOVA	{"phone": "+70250092719"}
0005434443475	62ADE6	5493 280193	VLADIMIR ABRAMOV	{"phone": "+70470416257"}
0005434443476	62ADE6	2034 423130	KIRILL KULIKOV	{"phone": "+70317433212"}
0005434443477	9EB6D4	0121 454196	VIKTOR KUDRYASHOV	{"email": "v-kudryashov_081979@postgrespro.ru", "phone": "+70307490949"}
0005434443478	F2C716	1481 361856	ALEKSANDR MARTYNOV	{"phone": "+70046015446"}
0005434443479	F2C716	4878 125062	DMITRIY MATVEEV	{"phone": "+70376313924"}
0005434443480	A47A80	9368 918562	ALEKSEY FILIPPOV	{"phone": "+70612473374"}
0005434443481	22615C	1445 476512	IVAN GAVRILOV	{"phone": "+70913367536"}
0005434443482	FDDFCF	8582 583482	EKATERINA MOROZOVA	{"phone": "+70939947500"}
0005434443483	D75A69	2187 395460	SERGEY ZHURAVLEV	{"email": "zhuravlevs-11061974@postgrespro.ru", "phone": "+70887204316"}
0005434443484	BE1F2C	5565 422958	TATYANA YUDINA	{"phone": "+70682774730"}
0005434443485	88B2E6	3317 131105	YURIY SHEVCHENKO	{"phone": "+70161235649"}
0005434443486	83EA7C	3605 214429	NIKOLAY ANTONOV	{"email": "n-antonov-1974@postgrespro.ru", "phone": "+70260028495"}
0005434443487	83EA7C	9430 768029	ALEKSANDR BORISOV	{"phone": "+70964584189"}
0005434443488	83EA7C	0656 557164	FEDOR EGOROV	{"phone": "+70554956284"}
0005434443489	E3D573	7884 860802	NATALYA MAKSIMOVA	{"phone": "+70622554998"}
0005434443490	E3D573	1705 963675	VALENTINA ANISIMOVA	{"email": "valentina-anisimova-23041977@postgrespro.ru", "phone": "+70546688042"}
0005434443491	96B18E	1793 524985	ANTON DMITRIEV	{"phone": "+70082329160"}
0005434443492	6DC64F	1631 704027	MIKHAIL NAUMOV	{"phone": "+70234121965"}
0005434443493	6DC64F	0553 358078	MIKHAIL KISELEV	{"email": "mikhailkiselev.05011983@postgrespro.ru", "phone": "+70546812737"}
0005434443494	6DC64F	3244 625566	NADEZHDA KOMAROVA	{"email": "komarova_nadezhda05071963@postgrespro.ru", "phone": "+70908576815"}
0005434443495	E6DE8B	8759 092687	NIKOLAY SAVELEV	{"email": "savelevnikolay.1981@postgrespro.ru", "phone": "+70032332760"}
0005434443496	79ADE0	9791 761714	KLAVDIYA FILATOVA	{"phone": "+70430407604"}
0005434443497	435075	3524 918797	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov-29111982@postgrespro.ru", "phone": "+70098489106"}
0005434443498	ABDC05	1842 956370	DMITRIY CHERNOV	{"phone": "+70536861823"}
0005434443499	70A7B8	2506 054250	PAVEL MEDVEDEV	{"phone": "+70525615689"}
0005434443500	179397	0271 695309	RAISA MALYSHEVA	{"email": "raisamalysheva.1980@postgrespro.ru", "phone": "+70927422538"}
0005434443501	90B8A8	5479 017920	LYUDMILA KONDRATEVA	{"email": "kondrateval13051975@postgrespro.ru", "phone": "+70457014346"}
0005434443502	F32445	9287 640470	ALEKSEY VASILEV	{"phone": "+70588974073"}
0005434443503	35D29D	8186 812363	VLADIMIR STEPANOV	{"phone": "+70649434230"}
0005434443504	798025	8527 937734	YULIYA VLASOVA	{"email": "y_vlasova-081975@postgrespro.ru", "phone": "+70149925951"}
0005434443505	9F4C01	2406 425343	MAKSIM KUZNECOV	{"phone": "+70659488780"}
0005434443506	9F4C01	1472 363725	ALEKSEY PETROV	{"email": "aleksey-petrov_30011976@postgrespro.ru", "phone": "+70175542664"}
0005434443507	DC4A54	1079 588726	DARYA NIKOLAEVA	{"email": "nikolaeva-d1963@postgrespro.ru", "phone": "+70036824382"}
0005434443508	BC9569	1902 451647	MIKHAIL NIKOLAEV	{"email": "m-nikolaev-1958@postgrespro.ru", "phone": "+70943896337"}
0005434443509	BC9569	5437 127714	TATYANA ANTONOVA	{"phone": "+70889873130"}
0005434443510	CDD723	3440 888313	DANIIL POPOV	{"phone": "+70136876168"}
0005434443511	767562	1348 248482	ELVIRA SIDOROVA	{"phone": "+70980718302"}
0005434443512	767562	5646 250926	GUZEL MAKSIMOVA	{"email": "g.maksimova-111963@postgrespro.ru", "phone": "+70275677286"}
0005434443513	FA9FFA	9784 459681	NIKOLAY POPOV	{"phone": "+70373823233"}
0005434443515	D3EFAE	6236 588723	ARTEM SMIRNOV	{"email": "smirnov_artem-121969@postgrespro.ru", "phone": "+70185952848"}
0005434443516	D3EFAE	6972 881977	MAKSIM KONOVALOV	{"email": "mkonovalov02081979@postgrespro.ru", "phone": "+70368987176"}
0005434443517	4F6C68	1300 604632	VALENTINA BELOVA	{"phone": "+70989488992"}
0005434443518	9E72D7	5034 897425	SOFYA BORISOVA	{"phone": "+70974778306"}
0005434443519	1014F4	8834 070455	MIKHAIL SHEVCHENKO	{"phone": "+70308437262"}
0005434443520	E9E704	7649 427388	EDUARD PAVLOV	{"phone": "+70290531320"}
0005434443521	317790	6016 150680	ALEKSEY ZHURAVLEV	{"email": "aleksey-zhuravlev.23111985@postgrespro.ru", "phone": "+70647066282"}
0005434443522	93CB35	6152 441979	ELENA MELNIKOVA	{"email": "elena.melnikova-16071982@postgrespro.ru", "phone": "+70676647938"}
0005434443523	A18F8A	9390 924511	YULIYA ZHURAVLEVA	{"phone": "+70320365913"}
0005434443524	451B47	0489 681173	ANASTASIYA SIDOROVA	{"phone": "+70464272272"}
0005434443525	9620B2	5418 517949	VITALIY EGOROV	{"email": "v-egorov_101976@postgrespro.ru", "phone": "+70726604693"}
0005434443526	4631D7	5238 677666	ANNA TIMOFEEVA	{"phone": "+70570700543"}
0005434443527	782774	1874 226095	VADIM ZAKHAROV	{"email": "zakharov.vadim-101974@postgrespro.ru", "phone": "+70237412324"}
0005434443528	782774	9580 533657	NATALYA KRASNOVA	{"email": "n-krasnova-1967@postgrespro.ru", "phone": "+70371845714"}
0005434443529	D5892C	5913 834336	SHAVKAT NIKITIN	{"phone": "+70889747620"}
0005434443530	D5892C	5367 367444	LYUBOV MOROZOVA	{"phone": "+70935117430"}
0005434443531	1C2C16	8635 617344	EKATERINA KOROLEVA	{"email": "korolevae_07071972@postgrespro.ru", "phone": "+70489261689"}
0005434443532	1C2C16	9579 558454	EGOR STEPANOV	{"email": "stepanovegor.1977@postgrespro.ru", "phone": "+70462428177"}
0005434443533	1ED033	3711 404938	NADEZHDA MAKSIMOVA	{"email": "n_maksimova-051972@postgrespro.ru", "phone": "+70549141158"}
0005434443534	1ED033	7019 051500	NATALIYA FILIPPOVA	{"email": "nataliyafilippova_04081965@postgrespro.ru", "phone": "+70096215645"}
0005434443535	F23A86	7819 768106	ALEKSEY MAKAROV	{"email": "a-makarov031979@postgrespro.ru", "phone": "+70392662244"}
0005434443536	9613CA	7999 964296	IVAN MATVEEV	{"phone": "+70265188196"}
0005434443537	3CF575	1346 267739	IRINA BORISOVA	{"email": "i.borisova.051975@postgrespro.ru", "phone": "+70311919458"}
0005434443538	40B762	6215 023567	EVGENIY SAVELEV	{"email": "esavelev121973@postgrespro.ru", "phone": "+70843519166"}
0005434443539	143284	6178 567144	LYUDMILA SAVELEVA	{"email": "saveleva_l_041978@postgrespro.ru", "phone": "+70656852847"}
0005434443540	EEF317	7012 635183	ANATOLIY TIKHONOV	{"email": "tikhonov-a1964@postgrespro.ru", "phone": "+70012380713"}
0005434443541	47D961	9812 488435	MAKSIM MAKSIMOV	{"email": "maksimov-maksim1976@postgrespro.ru", "phone": "+70879974523"}
0005434443542	6F1891	3418 337443	VALENTINA ANISIMOVA	{"email": "anisimova_v_1961@postgrespro.ru", "phone": "+70637501537"}
0005434443543	6B3F1C	9219 569288	ZINAIDA POPOVA	{"phone": "+70580382937"}
0005434443600	7B8028	4782 147585	GALINA BELOVA	{"phone": "+70965674748"}
0005434443544	F6DE74	0900 070885	NATALYA KONOVALOVA	{"email": "n.konovalova_1970@postgrespro.ru", "phone": "+70787205047"}
0005434443545	7264AE	4052 536501	VLADIMIR ZAKHAROV	{"phone": "+70244004636"}
0005434443546	7264AE	9320 430838	DENIS KUZMIN	{"phone": "+70137383044"}
0005434443547	7264AE	9928 924331	ANASTASIYA VLASOVA	{"email": "vlasovaanastasiya_1972@postgrespro.ru", "phone": "+70715952356"}
0005434443548	AD39D8	0846 334088	ARTEM ZAKHAROV	{"phone": "+70648452127"}
0005434443549	AD39D8	3399 574109	DMITRIY FEDOROV	{"email": "dfedorov_23101974@postgrespro.ru", "phone": "+70979097883"}
0005434443550	AD39D8	9607 409179	IRINA FROLOVA	{"email": "i-frolova-1975@postgrespro.ru", "phone": "+70571695155"}
0005434443551	F06818	7273 642188	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-19041976@postgrespro.ru", "phone": "+70309663559"}
0005434443552	609A58	7729 021671	ANASTASIYA MEDVEDEVA	{"email": "medvedeva.anastasiya-081969@postgrespro.ru", "phone": "+70872276987"}
0005434443553	1CC247	9506 307735	ALEKSANDR TARASOV	{"phone": "+70621714712"}
0005434443554	7B6893	9292 834869	STANISLAV SOROKIN	{"phone": "+70551620463"}
0005434443555	7B6893	3978 538388	VIKTOR DAVYDOV	{"phone": "+70469123836"}
0005434443556	542D63	1799 787434	ANNA VASILEVA	{"email": "vasileva.a03071976@postgrespro.ru", "phone": "+70394797317"}
0005434443557	542D63	9893 169341	ALEKSANDR PAVLOV	{"email": "pavlov.a_081974@postgrespro.ru", "phone": "+70470324981"}
0005434443558	9CEA09	9191 478867	TATYANA MAKSIMOVA	{"email": "tatyana-maksimova_091964@postgrespro.ru", "phone": "+70293551957"}
0005434443559	DED96B	2976 912669	ANNA ZHUKOVA	{"phone": "+70929804061"}
0005434443560	DED96B	9487 387309	DENIS SOLOVEV	{"email": "solovev.denis-1974@postgrespro.ru", "phone": "+70969975225"}
0005434443561	D3554A	5589 413171	ARTUR ABRAMOV	{"phone": "+70317159356"}
0005434443562	9F7FA5	5258 140784	LILIYA RODIONOVA	{"phone": "+70359452317"}
0005434443563	ED8A6A	1749 474242	ANNA MIRONOVA	{"email": "mironova.anna-1964@postgrespro.ru", "phone": "+70169011720"}
0005434443564	213E22	2704 146167	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.29091978@postgrespro.ru", "phone": "+70947579498"}
0005434443565	EE9812	0238 406784	ARTEM ZHURAVLEV	{"email": "zhuravlevartem23121974@postgrespro.ru", "phone": "+70233976924"}
0005434443566	EE9812	4089 682472	ANNA SERGEEVA	{"phone": "+70414595192"}
0005434443567	CC2DC2	8571 491547	OLESYA RODIONOVA	{"email": "olesya.rodionova_09061971@postgrespro.ru", "phone": "+70741454655"}
0005434443568	CC2DC2	2954 312507	MIKHAIL ROMANOV	{"phone": "+70832544448"}
0005434443569	2A3E3F	7577 856574	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova1973@postgrespro.ru", "phone": "+70609447037"}
0005434443570	AB236A	1675 511352	RAVIL VOLKOV	{"email": "ravilvolkov1982@postgrespro.ru", "phone": "+70939152306"}
0005434443571	AB236A	2099 510466	RAISA ZHUKOVA	{"phone": "+70758027991"}
0005434443572	AA9133	7623 763666	TAISIYA BORISOVA	{"email": "t.borisova_12041968@postgrespro.ru", "phone": "+70069957776"}
0005434443573	AA9133	6889 876843	VALENTINA ALEKSANDROVA	{"phone": "+70765476381"}
0005434443574	4E12E4	1550 252124	VIKTORIYA MALYSHEVA	{"phone": "+70555765886"}
0005434443575	61C033	1367 311586	EVGENIYA MIRONOVA	{"phone": "+70101340651"}
0005434443576	61C033	9715 882862	YURIY ORLOV	{"phone": "+70141544369"}
0005434443577	266C88	2070 495241	VALENTINA FEDOROVA	{"email": "valentinafedorova.101972@postgrespro.ru", "phone": "+70342948005"}
0005434443578	C1E66A	9986 391731	ILYA SMIRNOV	{"phone": "+70793936182"}
0005434443579	EC5256	4070 473626	LILIYA STEPANOVA	{"email": "stepanova_liliya1978@postgrespro.ru", "phone": "+70843951127"}
0005434443580	A35860	0532 820848	ALEKSEY MAKAROV	{"email": "alekseymakarov-01051962@postgrespro.ru", "phone": "+70146724019"}
0005434443581	A35860	8367 050726	SERGEY DENISOV	{"email": "denisov.s-21111964@postgrespro.ru", "phone": "+70646544719"}
0005434443582	354919	0591 728073	VADIM TARASOV	{"phone": "+70672765134"}
0005434443583	D6363A	8004 807510	ANATOLIY CHERNOV	{"email": "chernov_anatoliy-1975@postgrespro.ru", "phone": "+70827866297"}
0005434443584	D6363A	1329 067270	EVGENIYA FILIPPOVA	{"email": "e-filippova.17121985@postgrespro.ru", "phone": "+70255291785"}
0005434443585	C1EA68	2862 926451	ALEKSANDR SOROKIN	{"phone": "+70127775582"}
0005434443586	655C00	8983 792693	KRISTINA RODIONOVA	{"phone": "+70535172829"}
0005434443587	7FFBCB	8578 826420	EKATERINA POLYAKOVA	{"email": "epolyakova.25061977@postgrespro.ru", "phone": "+70890045434"}
0005434443588	9904FC	1941 204024	YURIY FEDOTOV	{"email": "fedotov_yuriy_1971@postgrespro.ru", "phone": "+70163618755"}
0005434443589	9904FC	1811 557041	ALEKSANDR MATVEEV	{"email": "a.matveev07101976@postgrespro.ru", "phone": "+70698512595"}
0005434443590	663F51	0368 001472	KSENIYA ORLOVA	{"email": "orlova_kseniya051975@postgrespro.ru", "phone": "+70986184022"}
0005434443591	6A51BF	2964 746354	ISLAM ANTONOV	{"phone": "+70217721799"}
0005434443592	48B2B5	0998 487955	VALENTIN NAUMOV	{"phone": "+70000945964"}
0005434443593	77F318	1990 498041	IVAN MELNIKOV	{"phone": "+70840030300"}
0005434443594	0873CF	8749 459293	DANIIL VOLKOV	{"phone": "+70373327535"}
0005434443595	F557A0	2427 394235	ALEKSEY KAZAKOV	{"phone": "+70961710936"}
0005434443596	070004	5680 141681	ANDREY NOVIKOV	{"email": "novikov_a_1979@postgrespro.ru", "phone": "+70729134657"}
0005434443597	070004	7985 008103	ARTUR RODIONOV	{"phone": "+70656373026"}
0005434443598	2ED652	9306 947208	DMITRIY TIKHONOV	{"email": "dmitriy_tikhonov.1969@postgrespro.ru", "phone": "+70394609247"}
0005434443599	2ED652	0140 380886	OKSANA FILATOVA	{"email": "oksanafilatova-1968@postgrespro.ru", "phone": "+70808384782"}
0005434443601	C7E075	5272 650811	ALEKSANDR VOLKOV	{"email": "volkovaleksandr.1973@postgrespro.ru", "phone": "+70810638026"}
0005434443602	098BA5	4492 488007	YULIYA MIRONOVA	{"email": "mironova-yuliya111960@postgrespro.ru", "phone": "+70929180110"}
0005434443603	CB98C7	1108 483756	GALINA FILIPPOVA	{"email": "gfilippova18071969@postgrespro.ru", "phone": "+70401381311"}
0005434443604	CB98C7	3242 711981	VASILIY OSIPOV	{"phone": "+70261833023"}
0005434443605	4A5BFB	0302 313873	VALENTIN TARASOV	{"email": "v.tarasov03011988@postgrespro.ru", "phone": "+70970009572"}
0005434443606	4A5BFB	0612 437148	VLADIMIR SOLOVEV	{"email": "solovev-v1968@postgrespro.ru", "phone": "+70667658471"}
0005434443607	CDE07F	6235 133433	MIKHAIL FEDOROV	{"email": "fedorov.m_121976@postgrespro.ru", "phone": "+70104259129"}
0005434443608	FA89B0	3342 598245	LYUDMILA CHERNOVA	{"phone": "+70532069702"}
0005434443609	D2AB6A	3696 476448	MARIYA PAVLOVA	{"email": "pavlovamariya-19091977@postgrespro.ru", "phone": "+70754580436"}
0005434443610	D2AB6A	7437 186746	ANDREY GERASIMOV	{"email": "gerasimova-1972@postgrespro.ru", "phone": "+70610568723"}
0005434443611	D2AB6A	1710 828935	VALERIYA ROMANOVA	{"phone": "+70914848100"}
0005434443612	A5AA16	7822 780677	NINA RODIONOVA	{"email": "nina_rodionova.091959@postgrespro.ru", "phone": "+70948005292"}
0005434443613	A5AA16	5782 905318	TATYANA DMITRIEVA	{"phone": "+70214494166"}
0005434443614	DA3929	2906 607001	ANNA EGOROVA	{"phone": "+70366328932"}
0005434443615	DA3929	0984 342332	NINA KISELEVA	{"email": "nina.kiseleva-15041974@postgrespro.ru", "phone": "+70758726358"}
0005434443616	64F36A	3682 357584	NINA MOROZOVA	{"phone": "+70068126564"}
0005434443617	64F36A	7749 279296	VYACHESLAV POPOV	{"phone": "+70180593345"}
0005434443618	504C55	3607 179739	VLADIMIR RODIONOV	{"phone": "+70293054286"}
0005434443619	504C55	6983 736408	VLADIMIR PETROV	{"email": "vpetrov_101970@postgrespro.ru", "phone": "+70368312124"}
0005434443620	34E45F	4419 296058	LIDIYA VOROBEVA	{"email": "lvorobeva-1983@postgrespro.ru", "phone": "+70449753569"}
0005434443621	34E45F	0249 785428	ZOYA LAZAREVA	{"email": "zlazareva11071967@postgrespro.ru", "phone": "+70084709368"}
0005434443622	51401B	6812 767040	ALEKSANDR MOROZOV	{"phone": "+70323621128"}
0005434443623	1FBBA5	6458 212587	NADEZHDA LEBEDEVA	{"email": "lebedeva-n-06021959@postgrespro.ru", "phone": "+70019102866"}
0005434443624	547514	8490 390507	DINARA EFIMOVA	{"email": "dinara.efimova051985@postgrespro.ru", "phone": "+70737077815"}
0005434443625	D439B4	6549 804768	ANTON IVANOV	{"email": "antonivanov-1966@postgrespro.ru", "phone": "+70722438301"}
0005434443626	590A16	7247 026007	NATALIYA DAVYDOVA	{"phone": "+70378876118"}
0005434443627	590A16	0084 562769	KAMILA KUZNECOVA	{"phone": "+70488163283"}
0005434443628	590A16	7182 620904	TATYANA SCHERBAKOVA	{"email": "tatyana.scherbakova.021963@postgrespro.ru", "phone": "+70347979662"}
0005434443629	8DE8F8	7118 087332	VLADIMIR NAZAROV	{"email": "v.nazarov-101979@postgrespro.ru", "phone": "+70667463461"}
0005434443630	8DE8F8	2484 458556	VALENTINA ILINA	{"phone": "+70740673331"}
0005434443631	8DE8F8	5830 657061	STANISLAV KOROLEV	{"email": "stanislav-korolev071964@postgrespro.ru", "phone": "+70681576523"}
0005434443632	9BF8BB	0187 997042	MARGARITA ORLOVA	{"phone": "+70545888368"}
0005434443633	9BF8BB	8484 050697	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev-28021977@postgrespro.ru", "phone": "+70893823091"}
0005434443634	129B7A	5302 409041	OLGA GORBUNOVA	{"phone": "+70118973272"}
0005434443635	DC7D70	2882 441684	NADEZHDA YAKOVLEVA	{"phone": "+70682360292"}
0005434443636	8A99AA	2492 480325	VALENTINA ORLOVA	{"email": "v_orlova-13011972@postgrespro.ru", "phone": "+70814696483"}
0005434443637	F1D5D2	9393 495726	ALEKSANDR SIDOROV	{"phone": "+70050408329"}
0005434443638	1BA95A	9139 032719	VLADIMIR FEDOROV	{"email": "vladimir-fedorov.071968@postgrespro.ru", "phone": "+70854119940"}
0005434443639	770EC1	4471 543986	MARGARITA SAVELEVA	{"email": "m.saveleva021971@postgrespro.ru", "phone": "+70934966506"}
0005434443640	D1194C	5046 814531	IRINA BELYAEVA	{"phone": "+70905270779"}
0005434443641	2DFB1E	8395 950575	TAMARA DAVYDOVA	{"email": "davydova-t-1972@postgrespro.ru", "phone": "+70734201045"}
0005434443642	83AB39	8390 397632	ELENA MIRONOVA	{"phone": "+70128478549"}
0005434443643	83AB39	1375 013579	NADEZHDA POTAPOVA	{"email": "potapova_nadezhda-06011962@postgrespro.ru", "phone": "+70600944263"}
0005434443644	A4B7D2	8668 032901	OLEG GUSEV	{"phone": "+70007836179"}
0005434443645	CA0448	8496 100765	ILYA NOVIKOV	{"email": "novikov_ilya.031972@postgrespro.ru", "phone": "+70051254324"}
0005434443646	09212E	8288 741783	OLGA NESTEROVA	{"email": "onesterova1971@postgrespro.ru", "phone": "+70161490841"}
0005434443647	C4842B	6466 336141	YURIY SIDOROV	{"phone": "+70485424778"}
0005434443648	3F5705	1201 542180	OLGA KULIKOVA	{"email": "olga-kulikova-26121978@postgrespro.ru", "phone": "+70078963713"}
0005434443649	E774D7	5382 911334	GALINA LEBEDEVA	{"email": "lebedevagalina.27041963@postgrespro.ru", "phone": "+70976007146"}
0005434443650	4D5265	2457 399444	IVAN MOROZOV	{"phone": "+70675509139"}
0005434443651	4D5265	9737 480220	PAVEL DENISOV	{"email": "denisov_p_021978@postgrespro.ru", "phone": "+70568806628"}
0005434443652	4EDAC0	4595 507327	ANGELINA LEBEDEVA	{"email": "a-lebedeva_021968@postgrespro.ru", "phone": "+70106262016"}
0005434443653	4EDAC0	4494 550523	VADIM IVANOV	{"phone": "+70571011793"}
0005434443654	33D97E	5469 960142	ALEKSANDR SOLOVEV	{"phone": "+70525840904"}
0005434443655	41009E	3554 233208	ANTONINA CHERNOVA	{"email": "antonina.chernova21071969@postgrespro.ru", "phone": "+70766304563"}
0005434443821	508A22	1436 322014	SERGEY IVANOV	{"phone": "+70558702320"}
0005434443656	7DC2BE	7570 161795	DARYA SOKOLOVA	{"email": "darya_sokolova1972@postgrespro.ru", "phone": "+70285848562"}
0005434443657	DCE1FB	9520 648226	TIMUR ILIN	{"phone": "+70298195817"}
0005434443658	DCE1FB	9453 183915	VITALIY PETROV	{"phone": "+70030367465"}
0005434443659	498025	3230 511896	VYACHESLAV FROLOV	{"phone": "+70400979459"}
0005434443660	F190EA	1528 813813	ALEKSEY FILIPPOV	{"phone": "+70869827986"}
0005434443661	360F49	4697 892640	KSENIYA KRASNOVA	{"phone": "+70942138048"}
0005434443662	360F49	8418 826496	NIKOLAY NIKOLAEV	{"email": "nikolaev-n.22101974@postgrespro.ru", "phone": "+70500461201"}
0005434443663	E6D913	7002 155862	MARINA ANTONOVA	{"phone": "+70105296704"}
0005434443664	781427	4354 194391	DMITRIY IVANOV	{"phone": "+70323668927"}
0005434443665	375C2F	1222 812304	DMITRIY KRASNOV	{"phone": "+70324516095"}
0005434443666	375C2F	5427 189587	VYACHESLAV TARASOV	{"phone": "+70470010059"}
0005434443667	9AB57D	6356 113894	NIKOLAY DENISOV	{"phone": "+70100771228"}
0005434443668	9AB57D	2350 701578	OLGA KOZLOVA	{"email": "o-kozlova12021972@postgrespro.ru", "phone": "+70571811564"}
0005434443669	6FC9C4	4946 028374	TATYANA PAVLOVA	{"email": "tpavlova.26031981@postgrespro.ru", "phone": "+70586795678"}
0005434443670	E1DFBE	3868 030006	SERGEY KUZMIN	{"email": "sergey_kuzmin.20031966@postgrespro.ru", "phone": "+70030858790"}
0005434443671	CD53C1	1150 913424	VIOLETTA FADEEVA	{"email": "fadeevav.21021970@postgrespro.ru", "phone": "+70125268580"}
0005434443672	6C4053	6986 758871	ALEKSEY SMIRNOV	{"email": "smirnov.aleksey.031972@postgrespro.ru", "phone": "+70811049142"}
0005434443673	6C4053	6987 815005	LILIYA KOZLOVA	{"email": "liliyakozlova-01051969@postgrespro.ru", "phone": "+70712376135"}
0005434443674	71EEBB	6917 595709	ALLA POPOVA	{"phone": "+70597928300"}
0005434443675	E0550A	1548 123988	ALEKSEY SOROKIN	{"phone": "+70937708085"}
0005434443676	23ABA2	3667 654785	ANASTASIYA KUZNECOVA	{"email": "anastasiya-kuznecova1985@postgrespro.ru", "phone": "+70531720740"}
0005434443677	23ABA2	7644 984066	ALENA EGOROVA	{"email": "a.egorova-25081972@postgrespro.ru", "phone": "+70216511666"}
0005434443678	51FBA7	9534 463918	ANNA VOLKOVA	{"email": "volkova.a_1981@postgrespro.ru", "phone": "+70090709040"}
0005434443679	58BBDF	5428 825665	ALBINA MAKAROVA	{"email": "albina-makarova.1963@postgrespro.ru", "phone": "+70062843113"}
0005434443680	6F788B	0847 561797	IGOR NAUMOV	{"phone": "+70604073694"}
0005434443681	6F788B	8010 205953	EGOR SCHERBAKOV	{"phone": "+70977166488"}
0005434443682	43EA36	8069 486167	OKSANA BELYAEVA	{"email": "belyaevaoksana.1977@postgrespro.ru", "phone": "+70345843921"}
0005434443683	5A221D	4270 025213	DARYA RODIONOVA	{"email": "rodionova.darya_03071962@postgrespro.ru", "phone": "+70220686944"}
0005434443684	03C2F9	8022 372801	NATALYA DANILOVA	{"email": "danilova_n.1988@postgrespro.ru", "phone": "+70561093022"}
0005434443685	61E7BD	1414 058339	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikovalyudmila.22121978@postgrespro.ru", "phone": "+70637731324"}
0005434443686	61E7BD	8183 838715	YURIY MOROZOV	{"phone": "+70030429050"}
0005434443687	6A5174	7760 121997	IRINA KUZNECOVA	{"email": "ikuznecova1969@postgrespro.ru", "phone": "+70738357418"}
0005434443688	EC8C48	5075 013487	VALENTINA MELNIKOVA	{"phone": "+70197534920"}
0005434443689	3970A9	2090 727439	FAINA MAKAROVA	{"email": "fainamakarova-051971@postgrespro.ru", "phone": "+70684486770"}
0005434443690	3970A9	1673 677492	PETR ANTONOV	{"phone": "+70115103102"}
0005434443691	9E1A3B	4365 657299	PETR OSIPOV	{"email": "osipovpetr.02031970@postgrespro.ru", "phone": "+70764247907"}
0005434443692	F4AE65	2829 352203	ANATOLIY BONDARENKO	{"email": "bondarenkoanatoliy.1974@postgrespro.ru", "phone": "+70678959662"}
0005434443693	11751A	7352 244179	VALENTINA MAKAROVA	{"phone": "+70266119573"}
0005434443694	11751A	0904 976085	ALEKSANDR DMITRIEV	{"email": "dmitriev.aleksandr.071973@postgrespro.ru", "phone": "+70411688765"}
0005434443695	27EB85	8277 854709	VALERIY MOISEEV	{"phone": "+70474595975"}
0005434443696	27EB85	5212 098434	MIKHAIL KAZAKOV	{"email": "mikhail-kazakov.111970@postgrespro.ru", "phone": "+70464984337"}
0005434443697	27EB85	3921 679975	MARIYA BORISOVA	{"phone": "+70136590393"}
0005434443698	27EB85	1293 512289	ALEKSANDRA KOMAROVA	{"email": "komarova.aleksandra-21051952@postgrespro.ru", "phone": "+70699893856"}
0005434443699	BA3D7D	1388 209171	ALEKSANDR KUZNECOV	{"phone": "+70071375272"}
0005434443700	38D7D1	1880 924281	LARISA ERMAKOVA	{"phone": "+70436705044"}
0005434443701	6F641F	8303 186772	YULIYA NIKOLAEVA	{"email": "nikolaevay12031977@postgrespro.ru", "phone": "+70113184887"}
0005434443702	F044AF	8904 432703	LYUDMILA SERGEEVA	{"email": "lyudmilasergeeva1958@postgrespro.ru", "phone": "+70409637440"}
0005434443703	750B81	1193 804575	ARINA SEMENOVA	{"email": "arina.semenova1968@postgrespro.ru", "phone": "+70971835111"}
0005434443704	3CE3A8	8314 614217	NAILYA VASILEVA	{"phone": "+70724482837"}
0005434443705	5770EF	1015 478350	EVGENIY SMIRNOV	{"email": "smirnov-evgeniy.09101972@postgrespro.ru", "phone": "+70324937043"}
0005434443706	F30F2E	6389 121770	VASILIY FILIPPOV	{"email": "filippov-vasiliy_03021959@postgrespro.ru", "phone": "+70052540553"}
0005434443707	F30F2E	6132 410959	VADIM BONDARENKO	{"email": "v.bondarenko.061961@postgrespro.ru", "phone": "+70304538825"}
0005434443708	120752	6378 869266	EKATERINA YAKOVLEVA	{"email": "yakovleva.e_22041986@postgrespro.ru", "phone": "+70571426210"}
0005434443709	145A76	2984 759381	IRINA MAKAROVA	{"phone": "+70822876410"}
0005434443710	145A76	2440 768025	TATYANA KOZLOVA	{"phone": "+70451195608"}
0005434443822	438F0B	0457 833890	GLEB MARTYNOV	{"phone": "+70563110691"}
0005434443711	4A15BE	8241 402424	ANATOLIY GERASIMOV	{"email": "gerasimov-anatoliy021975@postgrespro.ru", "phone": "+70418813808"}
0005434443712	2A1FA8	1468 957851	YULIYA BARANOVA	{"phone": "+70177866264"}
0005434443713	C39131	3600 552836	ELENA KUZNECOVA	{"phone": "+70346555704"}
0005434443714	C39131	7582 154307	NADEZHDA DMITRIEVA	{"email": "nadezhda_dmitrieva-031964@postgrespro.ru", "phone": "+70880621914"}
0005434443715	3D0898	7442 505135	VIKTOR DMITRIEV	{"email": "v.dmitriev.1977@postgrespro.ru", "phone": "+70844755996"}
0005434443716	641E12	1592 523169	GALINA EFREMOVA	{"email": "g.efremova1980@postgrespro.ru", "phone": "+70543695312"}
0005434443717	5F2D11	9958 585204	ELENA YAKOVLEVA	{"email": "e_yakovleva06041968@postgrespro.ru", "phone": "+70847656372"}
0005434443718	A37228	0323 839383	VALERIY BORISOV	{"phone": "+70689165533"}
0005434443719	F5C80D	8823 821157	FLYURA VASILEVA	{"email": "flyura.vasileva011978@postgrespro.ru", "phone": "+70379673607"}
0005434443720	8A0CBD	1901 361267	NATALYA LUKYANOVA	{"phone": "+70686620075"}
0005434443721	574861	8193 926064	NIKOLAY KUZNECOV	{"email": "nkuznecov_18081971@postgrespro.ru", "phone": "+70106123617"}
0005434443722	251DA3	4836 917692	ZARINA NAZAROVA	{"email": "nazarova_z1971@postgrespro.ru", "phone": "+70030537458"}
0005434443723	5DB492	5948 056611	VYACHESLAV IVANOV	{"phone": "+70224495430"}
0005434443724	5DB492	6849 368703	NADEZHDA STEPANOVA	{"email": "stepanova_n.011977@postgrespro.ru", "phone": "+70836138295"}
0005434443725	69100A	3547 671298	LIDIYA SOKOLOVA	{"email": "lsokolova-29061966@postgrespro.ru", "phone": "+70031207699"}
0005434443726	69100A	4176 328420	ALEKSEY EGOROV	{"email": "alekseyegorov.26081976@postgrespro.ru", "phone": "+70645732210"}
0005434443727	82FB5B	6958 456888	VLADISLAV MIRONOV	{"phone": "+70566011208"}
0005434443728	7EAFF2	0201 173224	ALEKSANDR DAVYDOV	{"phone": "+70607929654"}
0005434443729	FFA176	4329 645094	ANASTASIYA PETROVA	{"email": "petrovaanastasiya051975@postgrespro.ru", "phone": "+70901561880"}
0005434443730	A986E8	6082 818256	GALINA BARANOVA	{"phone": "+70952605666"}
0005434443731	71ED09	7693 616064	DENIS KAZAKOV	{"phone": "+70705277192"}
0005434443732	D55E16	5177 650558	EKATERINA FOMINA	{"phone": "+70770695472"}
0005434443733	D55E16	0584 316769	ELENA OVCHINNIKOVA	{"email": "e.ovchinnikova.091977@postgrespro.ru", "phone": "+70891654091"}
0005434443734	3FA664	2686 673142	TAMARA MIRONOVA	{"phone": "+70606168271"}
0005434443735	3FA664	0253 423787	OLGA FILATOVA	{"phone": "+70259366350"}
0005434443736	E47040	0962 501226	NINA VASILEVA	{"email": "n_vasileva.1980@postgrespro.ru", "phone": "+70086624160"}
0005434443737	B0ACA7	7636 320164	LYUBOV FOMINA	{"email": "fominalyubov03121981@postgrespro.ru", "phone": "+70323816582"}
0005434443738	B63B47	0673 669740	ALEKSANDR KARPOV	{"email": "karpov-a081963@postgrespro.ru", "phone": "+70293117762"}
0005434443739	B63B47	4813 644719	OLEG RODIONOV	{"phone": "+70886711943"}
0005434443740	698A3A	9542 172346	VITALIY MARTYNOV	{"email": "martynov.vitaliy.011965@postgrespro.ru", "phone": "+70107420289"}
0005434443741	D6FB7D	3065 978299	SERGEY YAKOVLEV	{"email": "yakovlev-s011971@postgrespro.ru", "phone": "+70309276506"}
0005434443742	D6FB7D	7927 340453	SERGEY FEDOROV	{"email": "fedorov_s-061968@postgrespro.ru", "phone": "+70307662969"}
0005434443743	7186B2	8526 852276	VLADIMIR MAKAROV	{"phone": "+70440843445"}
0005434443744	7186B2	0337 838193	LYUDMILA FROLOVA	{"email": "frolova-lyudmila_16071974@postgrespro.ru", "phone": "+70071678685"}
0005434443745	0D09AC	0165 521607	TAMARA SOLOVEVA	{"phone": "+70647995061"}
0005434443746	A8E848	3588 821304	ALINA LAZAREVA	{"email": "alina_lazareva01061973@postgrespro.ru", "phone": "+70561634996"}
0005434443747	04D24E	7981 155458	SERGEY POPOV	{"phone": "+70074287998"}
0005434443748	04D24E	2908 895214	VALENTINA TIMOFEEVA	{"phone": "+70698500134"}
0005434443749	86624E	4593 857381	ZINAIDA FOMINA	{"email": "fomina_zinaida_071969@postgrespro.ru", "phone": "+70120440284"}
0005434443750	B7133B	1247 907637	VIKTOR MIRONOV	{"phone": "+70758172244"}
0005434443751	01C9A4	8180 004900	YULIYA SERGEEVA	{"email": "y-sergeeva.071974@postgrespro.ru", "phone": "+70666189989"}
0005434443752	01C9A4	4639 645241	MARIYA SOKOLOVA	{"phone": "+70942866934"}
0005434443753	E81F12	5046 523678	ALEKSANDR KRASNOV	{"phone": "+70119331676"}
0005434443754	E81F12	6579 285733	ALEKSANDR SAVELEV	{"phone": "+70688374706"}
0005434443755	1CAE06	2305 114967	LYUBOV KUZNECOVA	{"email": "l_kuznecova09091974@postgrespro.ru", "phone": "+70653029897"}
0005434443756	CB300A	2904 625721	NATALIYA GAVRILOVA	{"phone": "+70430980522"}
0005434443757	CB300A	7165 358351	SVETLANA KOROLEVA	{"email": "s_koroleva-051971@postgrespro.ru", "phone": "+70417554729"}
0005434443758	CB300A	1251 168988	YULIYA IVANOVA	{"email": "ivanova.y-021958@postgrespro.ru", "phone": "+70922175438"}
0005434443759	8828F4	3248 585978	IGOR SERGEEV	{"email": "sergeev_igor-31081968@postgrespro.ru", "phone": "+70867383686"}
0005434443760	E843A8	3177 980654	YURIY RODIONOV	{"email": "yuriy.rodionov-1976@postgrespro.ru", "phone": "+70854162557"}
0005434443761	F57FC8	4890 904208	ELENA SMIRNOVA	{"email": "smirnovaelena_20101959@postgrespro.ru", "phone": "+70577929152"}
0005434443762	F57FC8	4628 029130	MIKHAIL MOISEEV	{"phone": "+70713012918"}
0005434443763	135A00	5710 071845	SERGEY STEPANOV	{"email": "stepanov.s021966@postgrespro.ru", "phone": "+70328640818"}
0005434443764	135A00	7308 020711	OLGA VLASOVA	{"phone": "+70974827858"}
0005434443765	62AE65	8710 413542	ALEKSANDR MARTYNOV	{"email": "martynov-aleksandr1966@postgrespro.ru", "phone": "+70768416426"}
0005434443823	185D34	3030 299227	ROMAN IVANOV	{"phone": "+70417462277"}
0005434443766	FF3C3C	3808 103738	TATYANA TARASOVA	{"email": "tatyanatarasova031969@postgrespro.ru", "phone": "+70813604221"}
0005434444067	F6D779	8616 717038	SERAFIMA KUZMINA	{"phone": "+70760822338"}
0005434443767	DF1323	0702 068894	YULIYA KARPOVA	{"email": "yuliyakarpova091973@postgrespro.ru", "phone": "+70191365038"}
0005434443768	F0DDCB	5658 398943	ALEKSANDR GERASIMOV	{"phone": "+70017930937"}
0005434443769	75159A	4649 830246	MARIYA AKIMOVA	{"email": "akimova.mariya1973@postgrespro.ru", "phone": "+70607792292"}
0005434443770	F8ADB0	5437 069751	SERGEY SERGEEV	{"email": "sergeev_sergey.20101963@postgrespro.ru", "phone": "+70863413166"}
0005434443771	2C34A7	3426 351210	OLEG SERGEEV	{"email": "oleg.sergeev07011979@postgrespro.ru", "phone": "+70889430390"}
0005434443772	8E83FE	3895 903262	ANATOLIY MOISEEV	{"phone": "+70352726655"}
0005434443773	8E83FE	4388 305868	VIKTOR MELNIKOV	{"phone": "+70515282000"}
0005434443774	AEA7ED	0301 600184	ANDREY BORISOV	{"phone": "+70492596809"}
0005434443775	2AB6C2	4324 893371	VLADIMIR KUZMIN	{"phone": "+70650904004"}
0005434443776	2AB6C2	1500 152867	ALEKSANDR FILIPPOV	{"email": "filippov_aleksandr-1976@postgrespro.ru", "phone": "+70800805577"}
0005434443777	189F1A	4072 444787	ALBINA YAKOVLEVA	{"phone": "+70375030955"}
0005434443778	189F1A	9963 398238	ANDREY POPOV	{"phone": "+70243883092"}
0005434443779	C2155E	1925 299198	VALENTINA KOVALEVA	{"email": "valentinakovaleva021975@postgrespro.ru", "phone": "+70204602056"}
0005434443780	C2155E	8649 613599	LYUBOV ZAKHAROVA	{"email": "l-zakharova_1976@postgrespro.ru", "phone": "+70701269268"}
0005434443781	0FF126	5976 716737	TATYANA KUDRYASHOVA	{"phone": "+70522011561"}
0005434443782	988089	8565 203940	MARIYA DMITRIEVA	{"email": "m_dmitrieva_1975@postgrespro.ru", "phone": "+70945450959"}
0005434443783	988089	5141 036411	OLGA POLYAKOVA	{"email": "olga-polyakova.011968@postgrespro.ru", "phone": "+70644638875"}
0005434443784	A5C490	5626 044803	MAKSIM MARTYNOV	{"email": "maksim-martynov021969@postgrespro.ru", "phone": "+70182910945"}
0005434443785	38F725	5077 268705	VYACHESLAV MOISEEV	{"email": "moiseevv_1977@postgrespro.ru", "phone": "+70759467764"}
0005434443786	38F725	7787 921051	MARIYA MOROZOVA	{"email": "m.morozova-1987@postgrespro.ru", "phone": "+70421675131"}
0005434443787	C2B68F	4764 479892	VALERIY GERASIMOV	{"phone": "+70498809815"}
0005434443788	00F256	3903 397392	LYUDMILA ZAKHAROVA	{"email": "l_zakharova_27011974@postgrespro.ru", "phone": "+70261538040"}
0005434443789	00F256	6895 862684	IRINA ZHURAVLEVA	{"phone": "+70319960375"}
0005434443790	6B2587	8629 572897	YULIYA ZAKHAROVA	{"email": "yuliya.zakharova.031965@postgrespro.ru", "phone": "+70097706632"}
0005434443791	6B2587	5462 868046	ELIZAVETA FILATOVA	{"phone": "+70807298178"}
0005434443792	8D9280	4028 012043	NINA LOGINOVA	{"phone": "+70763694093"}
0005434443793	8D9280	5183 341946	DANIIL KUZMIN	{"email": "kuzmind-1973@postgrespro.ru", "phone": "+70858127668"}
0005434443794	694705	6567 286257	NATALYA OSIPOVA	{"phone": "+70895874347"}
0005434443795	AFC94E	1701 686064	ZOYA MASLOVA	{"email": "zoyamaslova.1970@postgrespro.ru", "phone": "+70173452756"}
0005434443796	1152A7	5378 735138	LIDIYA POPOVA	{"email": "lidiya-popova31071972@postgrespro.ru", "phone": "+70235659034"}
0005434443797	B2B242	3048 269560	INESSA NOVIKOVA	{"email": "i.novikova.19041978@postgrespro.ru", "phone": "+70811934732"}
0005434443798	B2B242	0223 793543	MARIYA EFREMOVA	{"email": "efremova_mariya-10081975@postgrespro.ru", "phone": "+70169505846"}
0005434443799	AD3363	6264 935210	ALEKSANDR KAZAKOV	{"phone": "+70882970029"}
0005434443800	AD3363	3650 481176	SERGEY PETROV	{"email": "sergey-petrov-021967@postgrespro.ru", "phone": "+70058796242"}
0005434443801	AD3363	6903 514951	OKSANA TIMOFEEVA	{"phone": "+70816187019"}
0005434443802	C0CFD2	6921 906803	NIKOLAY FILIPPOV	{"email": "n-filippov.121982@postgrespro.ru", "phone": "+70048327188"}
0005434443803	D04E54	8099 672959	NADEZHDA FROLOVA	{"email": "nadezhda_frolova-1970@postgrespro.ru", "phone": "+70527662751"}
0005434443804	D04E54	1026 904978	VALENTINA LAZAREVA	{"email": "valentina_lazareva091971@postgrespro.ru", "phone": "+70204421203"}
0005434443805	ADDE22	7983 276791	VALENTINA ZAKHAROVA	{"phone": "+70787460193"}
0005434443806	E28AB7	4458 962477	PETR KUZMIN	{"phone": "+70765251938"}
0005434443807	0897EF	6267 640339	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev.1967@postgrespro.ru", "phone": "+70118962941"}
0005434443808	1E7932	6692 082774	OLGA VOROBEVA	{"email": "vorobevao_10111967@postgrespro.ru", "phone": "+70463121255"}
0005434443809	1E7932	5116 629945	MAKSIM FEDOROV	{"email": "m.fedorov.18071967@postgrespro.ru", "phone": "+70004768423"}
0005434443810	B63ED8	1751 328478	NATALIYA PAVLOVA	{"email": "nataliya_pavlova1981@postgrespro.ru", "phone": "+70656221585"}
0005434443811	B63ED8	7192 024596	MARINA VASILEVA	{"email": "vasileva.m.10051967@postgrespro.ru", "phone": "+70290432837"}
0005434443812	AE853D	4976 637561	SERGEY VLASOV	{"phone": "+70283463622"}
0005434443813	55B092	8234 742412	TATYANA NAZAROVA	{"email": "t_nazarova_071973@postgrespro.ru", "phone": "+70698636883"}
0005434443814	466710	6398 244273	MIKHAIL SCHERBAKOV	{"email": "mikhail.scherbakov-21071969@postgrespro.ru", "phone": "+70585975330"}
0005434443815	466710	8606 861891	ALEKSEY IVANOV	{"email": "ivanov_a_14031964@postgrespro.ru", "phone": "+70034033006"}
0005434443816	466710	5886 544292	KONSTANTIN IVANOV	{"email": "k.ivanov_061958@postgrespro.ru", "phone": "+70907223582"}
0005434443817	B68CEB	0864 402487	ANDREY AFANASEV	{"phone": "+70254514504"}
0005434443818	B68CEB	9953 340340	MIKHAIL VASILEV	{"email": "mvasilev.26121965@postgrespro.ru", "phone": "+70342888158"}
0005434443819	B68CEB	0430 773490	DMITRIY MAKAROV	{"phone": "+70922311115"}
0005434443820	508A22	7062 975784	LYUBOV KRASNOVA	{"email": "l_krasnova.11061985@postgrespro.ru", "phone": "+70161503307"}
0005434443824	084198	4361 573763	ANNA POTAPOVA	{"phone": "+70066797078"}
0005434443825	073E8A	7067 699876	ALEKSEY MAKAROV	{"phone": "+70037394629"}
0005434443826	61EBA8	2273 452020	SVETLANA POPOVA	{"phone": "+70149901621"}
0005434443827	650CA1	2451 071659	VLADIMIR SERGEEV	{"email": "sergeev-v_31011971@postgrespro.ru", "phone": "+70638685465"}
0005434443828	5EA861	8991 803797	MARINA VOROBEVA	{"email": "vorobeva-marina_27051975@postgrespro.ru", "phone": "+70400433385"}
0005434443829	CE8716	3316 244931	RAISA DMITRIEVA	{"phone": "+70998361800"}
0005434443830	D4E079	5035 284085	EVGENIY PAVLOV	{"email": "pavlov-e-081971@postgrespro.ru", "phone": "+70101562086"}
0005434443831	D4E079	3293 280868	TATYANA STEPANOVA	{"phone": "+70846640524"}
0005434443832	7897FF	6958 266362	EGOR ZAYCEV	{"phone": "+70608982247"}
0005434443833	E432EE	3366 607474	ROBERT STEPANOV	{"email": "robertstepanov1975@postgrespro.ru", "phone": "+70079064194"}
0005434443834	E432EE	6752 086210	VYACHESLAV DMITRIEV	{"email": "vdmitriev_1967@postgrespro.ru", "phone": "+70380973236"}
0005434443835	79FA92	8108 030525	KLAVDIYA KRASNOVA	{"phone": "+70333169922"}
0005434443836	79FA92	6175 918011	ANNA MATVEEVA	{"email": "amatveeva.101968@postgrespro.ru", "phone": "+70520598376"}
0005434443837	668E9D	7326 533977	ROMAN NIKITIN	{"email": "rnikitin30091971@postgrespro.ru", "phone": "+70105163771"}
0005434443838	BDECC8	0285 169764	LYUBOV IVANOVA	{"email": "lyubovivanova.011981@postgrespro.ru", "phone": "+70558891862"}
0005434443839	2C3C45	9353 212829	SERGEY ANTONOV	{"phone": "+70489881312"}
0005434443840	9664B6	3252 535057	OKSANA PETROVA	{"phone": "+70292020244"}
0005434443841	614879	1416 664670	LIDIYA SCHERBAKOVA	{"email": "l-scherbakova_1976@postgrespro.ru", "phone": "+70267960924"}
0005434443842	DC660C	9439 266821	NIKOLAY STEPANOV	{"email": "stepanov-n_1977@postgrespro.ru", "phone": "+70065776761"}
0005434443843	187A79	9277 079737	IGOR IVANOV	{"email": "ivanov_igor011968@postgrespro.ru", "phone": "+70221164478"}
0005434443844	E992D7	8807 403650	SERGEY KRASNOV	{"email": "s-krasnov-01101968@postgrespro.ru", "phone": "+70458711370"}
0005434443845	D5EB46	9313 164793	OLGA NIKOLAEVA	{"email": "olga-nikolaeva_24111971@postgrespro.ru", "phone": "+70230407219"}
0005434443846	723D09	7798 540711	MARIYA TARASOVA	{"phone": "+70720891687"}
0005434443847	723D09	1349 147911	ALEKSANDR BONDARENKO	{"phone": "+70645965611"}
0005434443848	366409	4094 568678	ALEKSEY GRIGOREV	{"phone": "+70085469333"}
0005434443849	33EA17	2861 738870	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev.21021974@postgrespro.ru", "phone": "+70837558174"}
0005434443850	3E0EAC	8246 090657	VIKTORIYA KOROLEVA	{"phone": "+70359803492"}
0005434443851	3E0EAC	7693 150424	NINA MOROZOVA	{"email": "morozova_n-24081977@postgrespro.ru", "phone": "+70409356358"}
0005434443852	D00169	4541 874905	YULIYA SOLOVEVA	{"phone": "+70784634830"}
0005434443853	511B59	4925 598010	NIKOLAY KULIKOV	{"phone": "+70347007838"}
0005434443854	06BA19	1384 682812	RUSHANIYA TIMOFEEVA	{"phone": "+70015210302"}
0005434443855	06BA19	9811 682974	ANTON SIDOROV	{"email": "sidorov.anton-1978@postgrespro.ru", "phone": "+70229492910"}
0005434443856	F3A929	2460 116717	SERGEY VOROBEV	{"phone": "+70010968221"}
0005434443857	D79AC5	9379 936748	EVGENIY PAVLOV	{"phone": "+70944002366"}
0005434443858	F1571E	3496 385083	MIKHAIL VASILEV	{"email": "mikhail_vasilev-1955@postgrespro.ru", "phone": "+70330850792"}
0005434443859	E9B757	6001 436260	VIKTOR MELNIKOV	{"phone": "+70819146466"}
0005434443860	85CD16	4846 924189	MAKSIM KULIKOV	{"phone": "+70418085389"}
0005434443861	85CD16	3963 737514	SVETLANA MIKHAYLOVA	{"phone": "+70711763965"}
0005434443862	8E8906	4369 934168	ALEKSEY ZAYCEV	{"email": "a.zaycev_12021963@postgrespro.ru", "phone": "+70335298875"}
0005434443863	304C77	1682 982569	VALENTINA DAVYDOVA	{"phone": "+70330863250"}
0005434443864	96E2B2	1052 064435	SERGEY TARASOV	{"email": "tarasov-s-21021968@postgrespro.ru", "phone": "+70547254374"}
0005434443865	96E2B2	7697 368017	NAILYA NOVIKOVA	{"email": "novikova_nailya.021966@postgrespro.ru", "phone": "+70285557433"}
0005434443866	76CA68	3528 560859	VALENTINA NOVIKOVA	{"phone": "+70452729498"}
0005434443867	87C95C	7470 362174	ANATOLIY EGOROV	{"email": "anatoliy.egorov_101979@postgrespro.ru", "phone": "+70227488476"}
0005434443868	064887	5806 482421	SEMEN PAVLOV	{"email": "s-pavlov-10021991@postgrespro.ru", "phone": "+70412550874"}
0005434443869	7A179A	6035 677224	VADIM VOROBEV	{"email": "vorobev-vadim28101965@postgrespro.ru", "phone": "+70029219542"}
0005434443870	AA4C8F	7285 255487	ARTEM SIDOROV	{"email": "sidorov-artem_1971@postgrespro.ru", "phone": "+70312333555"}
0005434443871	6B5DE7	6919 784153	ROMAN SEMENOV	{"email": "semenovroman_121975@postgrespro.ru", "phone": "+70182151099"}
0005434443872	6B5DE7	4166 861766	MARGARITA GRISHINA	{"email": "grishina-m.011971@postgrespro.ru", "phone": "+70368376052"}
0005434443873	D20854	5264 769662	VLADIMIR NIKOLAEV	{"phone": "+70874934926"}
0005434443874	A24B30	2100 378333	SVETLANA KISELEVA	{"email": "kiseleva_s-1962@postgrespro.ru", "phone": "+70242859543"}
0005434443875	318AFB	1408 696070	VLADIMIR ROMANOV	{"email": "vladimir-romanov_1973@postgrespro.ru", "phone": "+70037810050"}
0005434443876	9DBF5B	4411 277051	SERGEY MEDVEDEV	{"email": "sergey-medvedev1971@postgrespro.ru", "phone": "+70061286655"}
0005434443877	623EB5	9589 114750	NADEZHDA NESTEROVA	{"email": "n-nesterova.29101963@postgrespro.ru", "phone": "+70974582312"}
0005434443878	152B78	1658 461715	VLADIMIR SOLOVEV	{"phone": "+70028384835"}
0005434443879	83B86F	7953 594533	ALEKSANDR MIRONOV	{"email": "mironov-a_04081976@postgrespro.ru", "phone": "+70197921239"}
0005434443880	A705B0	3989 279140	TAISIYA NOVIKOVA	{"phone": "+70249539006"}
0005434443881	A705B0	3164 837557	VALENTINA POLYAKOVA	{"email": "v-polyakova1970@postgrespro.ru", "phone": "+70041008639"}
0005434443882	FC1A2C	1410 887837	ELENA MOROZOVA	{"phone": "+70608861298"}
0005434443883	FC1A2C	4959 131736	VALENTINA ILINA	{"phone": "+70038481384"}
0005434443884	F11C2D	6989 717636	YULIYA PETROVA	{"phone": "+70551164107"}
0005434443885	F11C2D	8376 240290	ANNA KUZNECOVA	{"email": "kuznecova.a_021973@postgrespro.ru", "phone": "+70376718789"}
0005434443886	7C5FE1	4250 954546	VALENTINA VASILEVA	{"email": "v-vasileva_1968@postgrespro.ru", "phone": "+70836249384"}
0005434443887	4ECA14	8175 670667	ANDREY ROMANOV	{"email": "romanov.a-1979@postgrespro.ru", "phone": "+70624267516"}
0005434443888	B3DC8D	9748 171929	VLADIMIR TIKHONOV	{"phone": "+70746237368"}
0005434443889	B3DC8D	2163 573122	MARIYA TITOVA	{"phone": "+70622364107"}
0005434443890	E67DAF	3165 067577	GALINA VASILEVA	{"email": "galina.vasileva101977@postgrespro.ru", "phone": "+70849658819"}
0005434443891	E67DAF	5090 597351	SERGEY SAVELEV	{"phone": "+70391341935"}
0005434443892	BD8828	9885 045502	VLADIMIR EGOROV	{"email": "egorovvladimir.1971@postgrespro.ru", "phone": "+70795376781"}
0005434443893	BD8828	8662 365459	ANNA ZAKHAROVA	{"email": "anna.zakharova_121979@postgrespro.ru", "phone": "+70553746775"}
0005434443894	D4BEA8	8818 528121	VALERIY ZAKHAROV	{"email": "v_zakharov031967@postgrespro.ru", "phone": "+70373588406"}
0005434443895	D1BAF4	0235 745003	NATALYA SERGEEVA	{"phone": "+70536589677"}
0005434443896	D1BAF4	2080 228406	ALINA KOLESNIKOVA	{"email": "a_kolesnikova1985@postgrespro.ru", "phone": "+70387074561"}
0005434443897	D1BAF4	7706 205293	NADEZHDA IVANOVA	{"phone": "+70545850075"}
0005434443898	D51935	1404 119095	PETR NAUMOV	{"phone": "+70954385929"}
0005434443899	EDBE76	2980 797246	ELENA KISELEVA	{"phone": "+70663621158"}
0005434443900	D35328	1964 705598	LUIZA IVANOVA	{"email": "ivanova_luiza051962@postgrespro.ru", "phone": "+70587876833"}
0005434443901	4C670D	3471 342623	DMITRIY YAKOVLEV	{"email": "yakovlev_d_1965@postgrespro.ru", "phone": "+70976843921"}
0005434443902	4FBF46	5634 273410	SVETLANA VOLKOVA	{"phone": "+70073054581"}
0005434443903	E6245C	5828 127332	MARGARITA KUZNECOVA	{"email": "margarita-kuznecova_21111977@postgrespro.ru", "phone": "+70707500211"}
0005434443904	E6245C	7824 511514	NADEZHDA TARASOVA	{"phone": "+70500012641"}
0005434443905	B92C1D	9493 464301	DMITRIY GERASIMOV	{"email": "d-gerasimov.14091967@postgrespro.ru", "phone": "+70883187663"}
0005434443906	B92C1D	2163 771114	RAVILYA KOZLOVA	{"phone": "+70576698858"}
0005434443907	B92C1D	8761 820130	EKATERINA VOLKOVA	{"email": "volkova.ekaterina-04121972@postgrespro.ru", "phone": "+70899888930"}
0005434443908	5CB38D	8671 342904	PAVEL YAKOVLEV	{"email": "yakovlev_p.1964@postgrespro.ru", "phone": "+70243918939"}
0005434443909	5CB38D	0899 620933	PAVEL RODIONOV	{"email": "rodionovp-02121978@postgrespro.ru", "phone": "+70741772302"}
0005434443910	4FDF6C	3472 058503	OLGA TROFIMOVA	{"phone": "+70657121707"}
0005434443911	B9B93C	5917 925912	TATYANA GERASIMOVA	{"phone": "+70829181112"}
0005434443912	600CE2	3204 701293	VALENTINA BORISOVA	{"phone": "+70984652600"}
0005434443913	600CE2	6746 444032	LYUDMILA KUZNECOVA	{"phone": "+70092256230"}
0005434443914	6E4956	0205 247725	ALEKSEY ORLOV	{"email": "orlov.aleksey.071972@postgrespro.ru", "phone": "+70583093591"}
0005434443915	6E4956	8291 157204	MARINA FROLOVA	{"email": "marina_frolova_03091971@postgrespro.ru", "phone": "+70932929499"}
0005434443916	63738D	4273 014344	ELENA GUSEVA	{"email": "guseva_elena1974@postgrespro.ru", "phone": "+70489588742"}
0005434443917	63738D	6899 330180	EKATERINA BELOVA	{"phone": "+70363148858"}
0005434443918	E0D125	9821 456927	ALEKSANDR NIKITIN	{"email": "nikitina.021965@postgrespro.ru", "phone": "+70225561198"}
0005434443919	33D09E	8098 288951	LIDIYA MOISEEVA	{"email": "lidiyamoiseeva-16021976@postgrespro.ru", "phone": "+70210656307"}
0005434443920	DB59BD	7049 911767	SNEZHANA NAUMOVA	{"phone": "+70922478252"}
0005434443921	DB59BD	0574 078677	EVGENIY BARANOV	{"phone": "+70597362857"}
0005434443922	974BE6	4511 220192	NIKOLAY ANTONOV	{"email": "n-antonov-1972@postgrespro.ru", "phone": "+70235318010"}
0005434443923	E55876	1478 749521	TATYANA ALEKSEEVA	{"email": "t.alekseeva_1970@postgrespro.ru", "phone": "+70666091175"}
0005434443924	E55876	2444 018641	ELIZAVETA KUZMINA	{"email": "kuzmina-elizaveta_1975@postgrespro.ru", "phone": "+70564097397"}
0005434443925	71847B	0762 625085	ARMEN MELNIKOV	{"email": "a-melnikov-1968@postgrespro.ru", "phone": "+70476790435"}
0005434443926	71847B	7355 446047	NINA AFANASEVA	{"email": "nafanaseva.06121968@postgrespro.ru", "phone": "+70200250596"}
0005434443927	F8F431	8627 965181	TATYANA NESTEROVA	{"phone": "+70884190232"}
0005434443928	F8F431	2930 299698	ALEKSANDR ZAKHAROV	{"phone": "+70974843345"}
0005434443929	420A5C	9341 727798	LYUBOV KULIKOVA	{"phone": "+70800392754"}
0005434443930	420A5C	0720 068000	MIKHAIL GAVRILOV	{"phone": "+70079677474"}
0005434443931	20893B	7816 178909	ANASTASIYA VOROBEVA	{"email": "a.vorobeva25061977@postgrespro.ru", "phone": "+70377762590"}
0005434443932	20893B	6958 350919	NINA SCHERBAKOVA	{"phone": "+70099807733"}
0005434443933	59DF97	8145 912088	NINA DMITRIEVA	{"email": "n_dmitrieva-041966@postgrespro.ru", "phone": "+70675631511"}
0005434443934	BD75D1	9469 871927	IVAN CHERNOV	{"email": "i.chernov-31121972@postgrespro.ru", "phone": "+70615188790"}
0005434443935	F65D34	6885 238957	SERGEY KOZLOV	{"phone": "+70266743993"}
0005434443936	3AC623	6679 743361	SEMEN MOISEEV	{"phone": "+70225470437"}
0005434443937	3AC623	7194 505514	MARGARITA ABRAMOVA	{"phone": "+70403390083"}
0005434443938	2F3E62	9413 530363	DARYA IVANOVA	{"phone": "+70531235448"}
0005434443939	2F3E62	7011 228784	VLADISLAV MEDVEDEV	{"email": "vmedvedev041969@postgrespro.ru", "phone": "+70563982851"}
0005434443940	31DE37	8071 551106	LYUDMILA NAZAROVA	{"phone": "+70251294137"}
0005434443941	6BEBC9	7115 986928	ALEKSEY FEDOROV	{"email": "fedorova011969@postgrespro.ru", "phone": "+70470924899"}
0005434443942	DE84D6	3983 636741	VYACHESLAV DAVYDOV	{"email": "davydov-v.09041973@postgrespro.ru", "phone": "+70421389343"}
0005434443943	DE84D6	3196 859625	ALEKSEY GRIGOREV	{"email": "aleksey-grigorev-29091963@postgrespro.ru", "phone": "+70141853296"}
0005434443944	C1DC80	5040 830822	GULNARA KOROLEVA	{"phone": "+70434633068"}
0005434443945	C27C0B	1067 106644	TATYANA KUZNECOVA	{"phone": "+70922205019"}
0005434443946	E8B171	4955 433470	SVETLANA IVANOVA	{"email": "svetlana-ivanova-021968@postgrespro.ru", "phone": "+70379835999"}
0005434443947	1F1319	5197 720164	ZHANNA BELYAEVA	{"email": "belyaeva_z-30071989@postgrespro.ru", "phone": "+70505401655"}
0005434443948	473E3F	2266 521555	ANASTASIYA SOLOVEVA	{"phone": "+70027970090"}
0005434443949	473E3F	1604 827344	VALENTINA MASLOVA	{"phone": "+70330347191"}
0005434443950	C643D7	6961 917460	VLADIMIR SCHERBAKOV	{"phone": "+70162485807"}
0005434443951	1732B1	4289 854676	NINA FEDOROVA	{"phone": "+70624972474"}
0005434443952	837F68	5484 181973	ELENA ORLOVA	{"phone": "+70849772475"}
0005434443953	D3F7B4	3769 899806	ANDREY KUZNECOV	{"email": "andreykuznecov-071974@postgrespro.ru", "phone": "+70684008867"}
0005434443954	7B4121	5795 328735	ANATOLIY DENISOV	{"email": "denisov-a-11031965@postgrespro.ru", "phone": "+70302401144"}
0005434443955	FE056F	7527 602478	SVETLANA PETROVA	{"email": "petrovas-061973@postgrespro.ru", "phone": "+70074985946"}
0005434443956	FE056F	9498 235919	NATALYA KOROLEVA	{"email": "natalya-koroleva.111979@postgrespro.ru", "phone": "+70755319610"}
0005434443957	961531	6954 826491	TATYANA ZHURAVLEVA	{"phone": "+70641488838"}
0005434443958	961531	1357 503981	DANILA SHEVCHENKO	{"phone": "+70464457485"}
0005434443959	F674DF	8999 165228	MIKHAIL SOKOLOV	{"phone": "+70609179812"}
0005434443960	6BA24D	3366 362957	NINA MARTYNOVA	{"phone": "+70661008210"}
0005434443961	2D9D5C	0110 804684	EKATERINA YAKOVLEVA	{"phone": "+70547261381"}
0005434443962	2D9D5C	5752 485562	YULIYA LAZAREVA	{"phone": "+70266694780"}
0005434443963	FDABC0	3065 644939	ALINA ARKHIPOVA	{"email": "alina.arkhipova-051966@postgrespro.ru", "phone": "+70060975229"}
0005434443964	988583	0435 536146	OLGA NIKITINA	{"phone": "+70339552514"}
0005434443965	E3C726	2777 389478	SERGEY SHEVCHENKO	{"email": "s.shevchenko14021980@postgrespro.ru", "phone": "+70375886624"}
0005434443966	3E2E17	7701 063853	DMITRIY NOVIKOV	{"email": "dmitriynovikov05051980@postgrespro.ru", "phone": "+70029669183"}
0005434443967	0C8D17	6066 471713	SVETLANA TITOVA	{"email": "svetlana-titova.20081969@postgrespro.ru", "phone": "+70190836046"}
0005434443968	0C8D17	6859 109984	SERGEY VOLKOV	{"email": "sergey.volkov.1978@postgrespro.ru", "phone": "+70338357081"}
0005434443969	A23145	0707 867347	VERA IVANOVA	{"phone": "+70264841071"}
0005434443970	9B2F2A	4634 013912	YURIY TIKHONOV	{"phone": "+70224960935"}
0005434443971	B9E3B7	0178 345799	OLGA DMITRIEVA	{"email": "dmitrievaolga11121972@postgrespro.ru", "phone": "+70043763072"}
0005434443972	F3AB6B	6277 082440	GULSHAT KRASNOVA	{"phone": "+70315464784"}
0005434443973	04A2E0	4897 135651	OLGA NOVIKOVA	{"email": "novikova-o_1965@postgrespro.ru", "phone": "+70679662496"}
0005434443974	0B05C9	4950 953040	VERONIKA NESTEROVA	{"email": "v-nesterova_1964@postgrespro.ru", "phone": "+70405099111"}
0005434443975	F9BC43	0076 281734	ELIZAVETA VASILEVA	{"email": "evasileva_061972@postgrespro.ru", "phone": "+70276630909"}
0005434443976	F9BC43	2626 730352	ARINA ORLOVA	{"phone": "+70616494970"}
0005434443977	47E71A	1187 610838	RUSTAM BELOV	{"email": "r.belov1979@postgrespro.ru", "phone": "+70603229091"}
0005434443978	47E71A	5056 485984	ANTONINA KOLESNIKOVA	{"phone": "+70007974016"}
0005434443979	458AFD	1159 781489	SEMEN ZAKHAROV	{"email": "szakharov1979@postgrespro.ru", "phone": "+70058067476"}
0005434443980	A79735	2764 950769	RENAT SOLOVEV	{"email": "solovev-r_13101966@postgrespro.ru", "phone": "+70918501616"}
0005434443981	A79735	6139 495945	DENIS PAVLOV	{"phone": "+70383065325"}
0005434443982	5F237F	0962 235832	IRINA ANDREEVA	{"phone": "+70464387075"}
0005434443983	D28EC3	0577 255357	ANASTASIYA ANISIMOVA	{"email": "anastasiya.anisimova-021981@postgrespro.ru", "phone": "+70388583768"}
0005434443984	C2E4F9	9909 116365	ALEKSANDR KUZNECOV	{"email": "kuznecova.011969@postgrespro.ru", "phone": "+70644465127"}
0005434443985	C2E4F9	2584 128616	IGOR DMITRIEV	{"email": "dmitrievigor.06081972@postgrespro.ru", "phone": "+70077092607"}
0005434443986	E703D8	5220 499556	RENAT OSIPOV	{"phone": "+70390186835"}
0005434443987	D29C85	3646 997312	ALEKSANDR SOLOVEV	{"phone": "+70598974784"}
0005434443988	D9CC88	2023 918576	VALENTINA IVANOVA	{"email": "ivanova-valentina_111971@postgrespro.ru", "phone": "+70934035089"}
0005434443989	D9CC88	9259 852245	IGOR IVANOV	{"phone": "+70809347040"}
0005434443990	6791FB	3294 106057	VLADIMIR GORBUNOV	{"phone": "+70788886507"}
0005434443991	0A8203	8362 062255	ANNA KUZNECOVA	{"email": "kuznecova_a08011976@postgrespro.ru", "phone": "+70524920289"}
0005434443992	0A8203	2937 049295	ANATOLIY SOROKIN	{"phone": "+70759343834"}
0005434443993	91F71D	2316 835276	VLADIMIR MOROZOV	{"email": "vmorozov.101965@postgrespro.ru", "phone": "+70878163038"}
0005434443994	626CED	7713 890452	ALEKSANDR ORLOV	{"email": "orlov_a1965@postgrespro.ru", "phone": "+70348335181"}
0005434443995	6B8EDC	3635 012578	SVETLANA DENISOVA	{"email": "svetlana-denisova1967@postgrespro.ru", "phone": "+70785889986"}
0005434443996	08A919	9271 525804	EVGENIY ORLOV	{"email": "evgeniy-orlov.011975@postgrespro.ru", "phone": "+70758841566"}
0005434443997	2F21EB	5382 026832	RAISA KUZNECOVA	{"phone": "+70669794904"}
0005434443998	28284B	4691 071877	DANIL KUZNECOV	{"email": "kuznecov.danil20071968@postgrespro.ru", "phone": "+70977122417"}
0005434443999	4DE904	8716 684340	ANTON SMIRNOV	{"email": "anton_smirnov_051974@postgrespro.ru", "phone": "+70732741667"}
0005434444000	0C4AD9	9997 591596	OLEG STEPANOV	{"email": "o-stepanov_091973@postgrespro.ru", "phone": "+70598009489"}
0005434444001	0C4AD9	0750 902225	RAIS AFANASEV	{"phone": "+70679549651"}
0005434444002	418EA8	4461 154655	NATALIYA POTAPOVA	{"phone": "+70506799336"}
0005434444003	418EA8	9612 880753	ALBERT GUSEV	{"email": "gusev_a-121964@postgrespro.ru", "phone": "+70626257745"}
0005434444004	772AD8	0206 876050	ALEKSANDRA BELOVA	{"email": "belovaa_061966@postgrespro.ru", "phone": "+70548776602"}
0005434444005	772AD8	3547 861226	ALEKSANDR MELNIKOV	{"phone": "+70499366731"}
0005434444006	DFEC11	8503 930551	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov.071977@postgrespro.ru", "phone": "+70392443387"}
0005434444007	DFEC11	3245 354535	ANDREY MELNIKOV	{"email": "andrey_melnikov-1967@postgrespro.ru", "phone": "+70482820287"}
0005434444008	107EF1	4147 395553	VITALIY ISAEV	{"phone": "+70546315074"}
0005434444009	EBCB2B	3702 259456	SERGEY PETROV	{"email": "petrov.sergey.28121971@postgrespro.ru", "phone": "+70599198635"}
0005434444010	78E8CE	5015 612438	ARTEM BONDARENKO	{"phone": "+70656864778"}
0005434444011	27D6E2	6767 624982	DANILA NOVIKOV	{"phone": "+70112911869"}
0005434444012	27D6E2	2291 380255	TATYANA DAVYDOVA	{"email": "davydova_tatyana.06091974@postgrespro.ru", "phone": "+70587767238"}
0005434444013	268822	7069 824865	ANNA SIDOROVA	{"email": "sidorova_a_111965@postgrespro.ru", "phone": "+70271980024"}
0005434444014	0BA319	2142 494142	SERGEY DENISOV	{"email": "sergey.denisov1974@postgrespro.ru", "phone": "+70264079105"}
0005434444015	1232A5	8121 298753	OKSANA ALEKSEEVA	{"email": "o-alekseeva1969@postgrespro.ru", "phone": "+70595193118"}
0005434444016	1232A5	6362 649837	DMITRIY GRIGOREV	{"email": "grigorevd-1959@postgrespro.ru", "phone": "+70438909272"}
0005434444017	935AFA	2914 384698	MAKSIM SEMENOV	{"phone": "+70579504486"}
0005434444018	03BAE7	5646 301951	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr_1968@postgrespro.ru", "phone": "+70307587342"}
0005434444019	9DAF38	0227 022864	OLGA MIRONOVA	{"email": "mironovaolga_041973@postgrespro.ru", "phone": "+70061873323"}
0005434444020	9DAF38	3971 180959	LYUDMILA FEDOROVA	{"email": "fedorova-lyudmila-04031968@postgrespro.ru", "phone": "+70618577241"}
0005434444021	D9E828	7764 774628	EKATERINA SOROKINA	{"email": "sorokina_e.1976@postgrespro.ru", "phone": "+70755428980"}
0005434444022	D9E828	9760 413463	MARIYA POLYAKOVA	{"phone": "+70012194538"}
0005434444023	1D20B2	9705 034828	MILANA SCHERBAKOVA	{"email": "scherbakova_milana011981@postgrespro.ru", "phone": "+70773173854"}
0005434444024	1D20B2	0421 164702	EVDOKIYA OSIPOVA	{"phone": "+70782071595"}
0005434444025	1D20B2	7897 804578	ALINA SOROKINA	{"email": "sorokina_alina-051971@postgrespro.ru", "phone": "+70432721141"}
0005434444026	DF49B7	5674 095975	VALENTINA PETROVA	{"phone": "+70966616509"}
0005434444027	7CA22E	6127 009413	VALERIY ZAKHAROV	{"email": "v.zakharov.111973@postgrespro.ru", "phone": "+70206560283"}
0005434444028	7CA22E	7167 673756	VLADIMIR MEDVEDEV	{"email": "v_medvedev1967@postgrespro.ru", "phone": "+70574203988"}
0005434444029	925266	1362 268142	DMITRIY CHERNOV	{"email": "d_chernov091976@postgrespro.ru", "phone": "+70658068304"}
0005434444030	5BCCFC	4810 009287	TATYANA SEMENOVA	{"phone": "+70866975394"}
0005434444031	99CA24	5210 884554	GALINA POPOVA	{"phone": "+70404739287"}
0005434444032	98CDC5	7986 911749	POLINA POLYAKOVA	{"email": "polyakova_p.041963@postgrespro.ru", "phone": "+70325520838"}
0005434444033	422F74	8845 188977	SVETLANA KOZLOVA	{"email": "kozlova-svetlana01051968@postgrespro.ru", "phone": "+70887241419"}
0005434444034	422F74	3486 415409	LYUBOV SEMENOVA	{"email": "lsemenova.051988@postgrespro.ru", "phone": "+70616870821"}
0005434444035	4D5B55	5323 279252	YURIY PAVLOV	{"phone": "+70393689271"}
0005434444036	12495B	0599 127767	VALENTINA TIKHONOVA	{"phone": "+70627064205"}
0005434444037	573673	6387 874755	LYUBOV FROLOVA	{"email": "lyubovfrolova.1976@postgrespro.ru", "phone": "+70057008931"}
0005434444038	573673	0901 515604	NIKOLAY IVANOV	{"phone": "+70447008576"}
0005434444039	573673	3351 124192	ALEKSANDR FROLOV	{"phone": "+70480507925"}
0005434444040	4D7339	1636 552797	TAMARA IVANOVA	{"phone": "+70554244203"}
0005434444041	9CAFB7	2475 557127	NINA FROLOVA	{"phone": "+70995493706"}
0005434444042	F63739	9293 354799	NATALIYA SEMENOVA	{"email": "semenova.nataliya14041974@postgrespro.ru", "phone": "+70424924618"}
0005434444043	F63739	6628 412017	YANA KONOVALOVA	{"phone": "+70115945856"}
0005434444044	CD9A87	2886 365642	NIKOLAY IVANOV	{"email": "ivanov.nikolay-06121969@postgrespro.ru", "phone": "+70981653718"}
0005434444045	466802	9248 392713	MAKSIM RODIONOV	{"phone": "+70932962959"}
0005434444046	A00D81	3296 645612	ALEKSANDR POPOV	{"email": "aleksandr_popov29071974@postgrespro.ru", "phone": "+70043562601"}
0005434444047	6E94B2	0740 645025	ALEKSANDR VOLKOV	{"email": "volkova.12011980@postgrespro.ru", "phone": "+70548497780"}
0005434444048	FA9351	8189 072083	EVGENIYA ZHURAVLEVA	{"email": "zhuravlevaevgeniya1980@postgrespro.ru", "phone": "+70073487832"}
0005434444049	FA9351	9599 625534	ALEKSANDR TARASOV	{"email": "atarasov15111967@postgrespro.ru", "phone": "+70442932807"}
0005434444050	F3F40C	1922 213699	DIANA POLYAKOVA	{"phone": "+70378993056"}
0005434444051	12E512	1227 738146	SERGEY GERASIMOV	{"email": "sergey_gerasimov081974@postgrespro.ru", "phone": "+70345243019"}
0005434444052	12E512	9361 059112	OLGA MAKAROVA	{"phone": "+70026703334"}
0005434444053	12E512	1722 201816	RAMIL KRASNOV	{"email": "krasnov-ramil.26011966@postgrespro.ru", "phone": "+70006523025"}
0005434444054	850172	1777 660709	EKATERINA NAUMOVA	{"phone": "+70993880267"}
0005434444055	1A871A	1104 935278	IRINA ARKHIPOVA	{"phone": "+70623253345"}
0005434444056	1A871A	4705 594399	VLADIMIR PAVLOV	{"email": "pavlov-v.24101972@postgrespro.ru", "phone": "+70855017973"}
0005434444057	5C7B25	9632 399808	VITALIY NOVIKOV	{"phone": "+70014643315"}
0005434444058	5C7B25	6610 875849	VLADIMIR POPOV	{"phone": "+70073203740"}
0005434444059	9AD93F	9794 884235	BORIS ALEKSANDROV	{"email": "aleksandrov-b091975@postgrespro.ru", "phone": "+70570029035"}
0005434444060	40436B	1381 443042	SANIYA SAVELEVA	{"phone": "+70549914457"}
0005434444061	40436B	3681 364031	DMITRIY ABRAMOV	{"phone": "+70284011791"}
0005434444062	B5947F	6364 040474	IVAN KISELEV	{"phone": "+70447038574"}
0005434444063	37C9AF	0575 816486	NADEZHDA MALYSHEVA	{"phone": "+70679775616"}
0005434444064	37C9AF	3088 159735	SEMEN POPOV	{"email": "popovsemen-1978@postgrespro.ru", "phone": "+70793451458"}
0005434444065	37C9AF	6711 438074	ALEKSANDR FROLOV	{"phone": "+70109252265"}
0005434444066	5EC1BE	2079 280394	NATALYA POPOVA	{"phone": "+70759155297"}
0005434444068	AF6B8C	9202 534768	TAISIYA DAVYDOVA	{"email": "t_davydova.1971@postgrespro.ru", "phone": "+70177568667"}
0005434444069	06C06B	7174 209658	ROMAN MAKSIMOV	{"email": "maksimov_roman111978@postgrespro.ru", "phone": "+70975001473"}
0005434444070	5395C6	5869 466985	VIKTORIYA EGOROVA	{"phone": "+70543900724"}
0005434444071	5395C6	7541 943403	ANASTASIYA CHERNOVA	{"email": "a.chernova-021966@postgrespro.ru", "phone": "+70653263324"}
0005434444072	7D32F3	5697 955532	ELIZAVETA KOROLEVA	{"email": "ekoroleva-1973@postgrespro.ru", "phone": "+70122399482"}
0005434444073	F0E6EB	3604 575180	ALEKSEY ROMANOV	{"email": "romanov.aleksey.18031977@postgrespro.ru", "phone": "+70482443074"}
0005434444074	5C1B18	5276 203292	ELENA MIKHAYLOVA	{"phone": "+70571861142"}
0005434444075	5C1B18	4631 663470	TIMUR ANDREEV	{"phone": "+70088786474"}
0005434444076	B05821	8938 976743	MIKHAIL KOZLOV	{"phone": "+70893436704"}
0005434444077	3EED88	7969 551285	ANTONINA SOROKINA	{"email": "asorokina_20091977@postgrespro.ru", "phone": "+70607476351"}
0005434444078	E532CB	6029 313568	SVYATOSLAV ISAEV	{"phone": "+70539607228"}
0005434444079	27BD29	4656 752019	SERGEY MAKAROV	{"email": "makarov_s31101976@postgrespro.ru", "phone": "+70004400980"}
0005434444080	082565	8774 162179	ANASTASIYA SAVELEVA	{"phone": "+70205850081"}
0005434444081	082565	6970 428281	ANASTASIYA PAVLOVA	{"email": "pavlovaanastasiya_25121969@postgrespro.ru", "phone": "+70571828723"}
0005434444082	082565	4295 353809	DMITRIY MIKHAYLOV	{"email": "mikhaylovd_19041981@postgrespro.ru", "phone": "+70175766423"}
0005434444083	3C06E1	9029 611098	MARIYA OSIPOVA	{"email": "m.osipova-15051969@postgrespro.ru", "phone": "+70422830657"}
0005434444084	3C06E1	8884 383792	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr_30081962@postgrespro.ru", "phone": "+70384233006"}
0005434444085	0BD7C7	7657 016872	ALEKSANDR CHERNOV	{"email": "chernov-a111980@postgrespro.ru", "phone": "+70113560073"}
0005434444086	90335B	2953 993879	ANASTASIYA PETROVA	{"email": "petrova_a17081977@postgrespro.ru", "phone": "+70793050891"}
0005434444087	CE9ADD	7657 789045	VERA SMIRNOVA	{"phone": "+70820550402"}
0005434444088	D3720F	5447 974219	ZOYA KONDRATEVA	{"email": "zkondrateva-25091956@postgrespro.ru", "phone": "+70609829016"}
0005434444089	F6A2DD	6430 606998	MAKSIM NAUMOV	{"phone": "+70141701296"}
0005434444090	92188F	5245 976745	PETR AFANASEV	{"email": "afanasev_petr.15121979@postgrespro.ru", "phone": "+70757370784"}
0005434444091	92188F	3096 694729	ELENA ORLOVA	{"email": "e-orlova-25041979@postgrespro.ru", "phone": "+70083784894"}
0005434444092	F50722	2471 614228	SERGEY SIDOROV	{"phone": "+70086414889"}
0005434444093	72BA2B	7945 070430	ELENA RODIONOVA	{"phone": "+70741266160"}
0005434444094	584B3D	6797 131181	VLADISLAV VOLKOV	{"phone": "+70680841933"}
0005434444095	584B3D	7068 601471	LYUDMILA BELYAEVA	{"phone": "+70987895700"}
0005434444096	B011E8	0010 773360	ALEKSANDR POPOV	{"email": "popov-aleksandr_091960@postgrespro.ru", "phone": "+70619592386"}
0005434444097	999E2B	3760 541068	ZOYA EGOROVA	{"phone": "+70444431765"}
0005434444098	954737	2285 370296	ELMIRA POTAPOVA	{"email": "potapovaelmira.30071974@postgrespro.ru", "phone": "+70828214086"}
0005434444099	17C1A5	4643 144967	GALINA STEPANOVA	{"email": "stepanova.g-18011966@postgrespro.ru", "phone": "+70692848265"}
0005434444100	3B4B98	7016 724853	TAMARA MAKAROVA	{"email": "tamara.makarova.061966@postgrespro.ru", "phone": "+70491089571"}
0005434444101	3B4B98	1204 669927	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy.1951@postgrespro.ru", "phone": "+70203087633"}
0005434444102	63B0E4	9846 063876	LYUDMILA VASILEVA	{"email": "l_vasileva_081981@postgrespro.ru", "phone": "+70360603024"}
0005434444103	14BC48	0712 765920	ILYA SEMENOV	{"phone": "+70643973486"}
0005434444104	ABD4EF	2006 159308	LYUDMILA ALEKSEEVA	{"email": "alekseeva_lyudmila.041970@postgrespro.ru", "phone": "+70677537122"}
0005434444105	ABD4EF	6070 503193	NATALYA FILIPPOVA	{"phone": "+70694600316"}
0005434444106	1627FA	1872 151674	NADEZHDA POPOVA	{"email": "n.popova.121972@postgrespro.ru", "phone": "+70119657535"}
0005434444107	1627FA	4214 719955	VLADISLAV IVANOV	{"phone": "+70118684780"}
0005434444108	88E09C	4960 622164	EGOR ZAYCEV	{"phone": "+70432388062"}
0005434444109	7F690B	4877 717754	MARINA KAZAKOVA	{"email": "marinakazakova.1976@postgrespro.ru", "phone": "+70209347527"}
0005434444110	8C3E0A	2031 748673	MIKHAIL ZHUKOV	{"phone": "+70225286474"}
0005434444111	B4B93A	2238 499849	VITALIY PAVLOV	{"email": "pavlov-vitaliy-051979@postgrespro.ru", "phone": "+70282633364"}
0005434444112	0B9F8B	4226 083317	ANNA ERMAKOVA	{"phone": "+70225521354"}
0005434444113	B101D4	2439 077061	VLADIMIR SCHERBAKOV	{"phone": "+70184728819"}
0005434444114	2636B9	5649 078014	VASILIY MAKAROV	{"phone": "+70559122564"}
0005434444115	2636B9	5389 601479	NATALYA FILIPPOVA	{"phone": "+70592384564"}
0005434444116	C2A8C9	4019 689450	ALEKSANDR ILIN	{"email": "a.ilin-111966@postgrespro.ru", "phone": "+70981548327"}
0005434444117	CDD207	4009 853025	NADEZHDA BOGDANOVA	{"phone": "+70812158930"}
0005434444118	CDD207	1569 511004	NAILYA RODIONOVA	{"email": "nailya-rodionova-1974@postgrespro.ru", "phone": "+70185591504"}
0005434444119	CDD207	0522 061697	NIKOLAY GERASIMOV	{"phone": "+70030433482"}
0005434444120	81F2ED	9358 698551	LYUDMILA KONOVALOVA	{"phone": "+70547337746"}
0005434444121	B20757	5213 118899	SVETLANA NAZAROVA	{"email": "nazarova.s-1973@postgrespro.ru", "phone": "+70836087256"}
0005434444122	B20757	1440 470420	LYUBOV NIKOLAEVA	{"phone": "+70178478794"}
0005434444123	D37D43	7209 531836	NINA KUZMINA	{"phone": "+70379388871"}
0005434444124	D37D43	0700 071800	NATALYA DAVYDOVA	{"phone": "+70976754638"}
0005434444125	330741	5647 102881	MARIYA KUZMINA	{"phone": "+70957517768"}
0005434444126	330741	9955 676091	TATYANA DMITRIEVA	{"email": "dmitrievat-25051976@postgrespro.ru", "phone": "+70016656086"}
0005434444127	E986E3	7868 073081	VLADIMIR KISELEV	{"email": "kiselev_v_03051979@postgrespro.ru", "phone": "+70359003618"}
0005434444128	069412	6052 146887	NIKOLAY KUZNECOV	{"phone": "+70156854978"}
0005434444129	CE9C57	2506 207455	RAISA FOMINA	{"phone": "+70215587264"}
0005434444130	CE9C57	2745 034105	DARYA FEDOROVA	{"email": "fedorova-d-091972@postgrespro.ru", "phone": "+70077861072"}
0005434444131	7AA689	3628 636307	DANILA MAKAROV	{"email": "d.makarov_111977@postgrespro.ru", "phone": "+70336053479"}
0005434444132	7AA689	4503 538211	ALEKSANDR BORISOV	{"phone": "+70269624869"}
0005434444133	7FC774	1073 541490	ALEKSANDR MARTYNOV	{"email": "martynov_a_27081965@postgrespro.ru", "phone": "+70688740237"}
0005434444134	310D04	4519 646665	VLADIMIR SERGEEV	{"phone": "+70983892291"}
0005434444135	9684FC	6333 573154	ANASTASIYA AKIMOVA	{"phone": "+70600274732"}
0005434444136	6CCDC4	7019 854590	VLADIMIR EGOROV	{"email": "egorovvladimir_1972@postgrespro.ru", "phone": "+70014741057"}
0005434444137	1696E2	7160 697654	MAKSIM KRASNOV	{"phone": "+70605493015"}
0005434444138	203129	7463 778014	NIKOLAY IVANOV	{"email": "nikolayivanov051971@postgrespro.ru", "phone": "+70984774447"}
0005434444139	560235	4198 034926	GENNADIY ZAYCEV	{"email": "gennadiy-zaycev10061965@postgrespro.ru", "phone": "+70529184424"}
0005434444140	5FB540	3352 398286	ALEKSEY MAKAROV	{"email": "alekseymakarov_19091970@postgrespro.ru", "phone": "+70656820867"}
0005434444141	732058	1954 872052	ANATOLIY GUSEV	{"email": "anatoliy.gusev051975@postgrespro.ru", "phone": "+70459288985"}
0005434444142	732058	6590 415278	MARIYA IVANOVA	{"phone": "+70072570770"}
0005434444143	783E80	4701 029280	ELVIRA TIKHONOVA	{"phone": "+70107907362"}
0005434444144	2615E0	9504 685972	TATYANA KOROLEVA	{"email": "tatyana_koroleva_1967@postgrespro.ru", "phone": "+70084148499"}
0005434444145	1AF279	5221 593472	ALEKSANDR ANTONOV	{"email": "aleksandrantonov_051980@postgrespro.ru", "phone": "+70803509664"}
0005434444146	4E673E	3250 298462	ALEKSANDR FILIPPOV	{"email": "filippov.a.081986@postgrespro.ru", "phone": "+70676388245"}
0005434444147	694DF5	8272 093524	TATYANA OSIPOVA	{"email": "osipova_tatyana.1963@postgrespro.ru", "phone": "+70577631371"}
0005434444148	694DF5	2923 726130	GALIYA SERGEEVA	{"phone": "+70407084809"}
0005434444149	C18AD6	6892 095194	LYUDMILA FROLOVA	{"email": "frolova_l.041960@postgrespro.ru", "phone": "+70617042852"}
0005434444150	C18AD6	0300 168625	ALEKSEY IVANOV	{"phone": "+70517561333"}
0005434444151	56D36D	8923 232324	VLADIMIR TARASOV	{"email": "tarasovvladimir031979@postgrespro.ru", "phone": "+70142800659"}
0005434444152	001164	5218 227155	VLADISLAV ROMANOV	{"email": "vromanov081978@postgrespro.ru", "phone": "+70431920378"}
0005434444153	001164	3117 644674	IRINA KALININA	{"email": "kalinina-i-031970@postgrespro.ru", "phone": "+70758255151"}
0005434444154	B19600	3912 736027	ALEKSANDR ISAEV	{"phone": "+70854327477"}
0005434444155	B19600	1685 679544	NATALYA KAZAKOVA	{"email": "kazakova_natalya1970@postgrespro.ru", "phone": "+70858163153"}
0005434444156	A92565	9053 390390	IVAN IVANOV	{"email": "ivanovivan.18021975@postgrespro.ru", "phone": "+70220841609"}
0005434444157	A92565	3878 544315	GENNADIY SERGEEV	{"email": "sergeev-g.091982@postgrespro.ru", "phone": "+70370758271"}
0005434444158	6403C1	2348 991946	GALINA TIMOFEEVA	{"phone": "+70088675056"}
0005434444159	18CA46	4056 914107	OLGA NOVIKOVA	{"phone": "+70958917076"}
0005434444160	7DE210	5766 392201	ALEKSANDR PETROV	{"email": "aleksandrpetrov10071976@postgrespro.ru", "phone": "+70666283694"}
0005434444161	7DE210	3373 683879	VADIM TARASOV	{"email": "vtarasov-1967@postgrespro.ru", "phone": "+70797477235"}
0005434444162	52BB15	1956 945555	VALERIY SERGEEV	{"phone": "+70360424915"}
0005434444163	52BB15	5920 704195	ALEKSEY GAVRILOV	{"email": "gavrilov.aleksey_011972@postgrespro.ru", "phone": "+70755220098"}
0005434444164	D57A8F	4804 895769	NIKOLAY RODIONOV	{"phone": "+70961785358"}
0005434444165	D57A8F	3736 010163	ARTEM KISELEV	{"email": "artem-kiselev.091977@postgrespro.ru", "phone": "+70031593447"}
0005434444166	9E0DA5	0647 123960	MIKHAIL SOROKIN	{"phone": "+70140063313"}
0005434444167	683FA1	2487 020912	NIKOLAY IVANOV	{"phone": "+70426977526"}
0005434444168	762A00	8291 387205	OLGA ARKHIPOVA	{"email": "olgaarkhipova-30081978@postgrespro.ru", "phone": "+70984549134"}
0005434444169	762A00	6235 459920	IVAN ALEKSEEV	{"email": "ialekseev12051962@postgrespro.ru", "phone": "+70595940667"}
0005434444170	762A00	6027 850165	ALEKSANDR MEDVEDEV	{"phone": "+70029661309"}
0005434444171	AD4ACE	8252 595968	VADIM ANTONOV	{"phone": "+70694900722"}
0005434444172	AD4ACE	5311 694590	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov25081960@postgrespro.ru", "phone": "+70755917332"}
0005434444173	930D91	4125 676323	VIKTOR ABRAMOV	{"email": "abramov.viktor.25031960@postgrespro.ru", "phone": "+70887860721"}
0005434444174	930D91	2768 036313	VLADIMIR ROMANOV	{"email": "romanov_vladimir_1974@postgrespro.ru", "phone": "+70583326206"}
0005434444175	0F1D39	4989 927593	OLGA EGOROVA	{"email": "egorovao-111965@postgrespro.ru", "phone": "+70012493330"}
0005434444176	0F1D39	3611 888277	YAROSLAV ILIN	{"phone": "+70123440344"}
0005434444177	CDF4D0	4582 378712	SERGEY FEDOROV	{"email": "fedorov_s-1967@postgrespro.ru", "phone": "+70550968064"}
0005434444178	CDF4D0	9879 353593	RASHID GAVRILOV	{"email": "gavrilov-r.05081976@postgrespro.ru", "phone": "+70565097704"}
0005434444179	85F185	8032 490559	VALENTINA BORISOVA	{"phone": "+70032892300"}
0005434444180	3ECD3A	4929 870417	ALEKSANDR IVANOV	{"phone": "+70293163036"}
0005434444181	58C773	2638 348863	ALEKSEY EGOROV	{"email": "aleksey.egorov-041981@postgrespro.ru", "phone": "+70420449365"}
0005434444182	F14C7A	7581 704245	RIMMA MELNIKOVA	{"email": "melnikovarimma_1973@postgrespro.ru", "phone": "+70159744329"}
0005434444183	F14C7A	7541 355418	NADEZHDA KUZMINA	{"email": "nadezhda.kuzmina21021962@postgrespro.ru", "phone": "+70098574916"}
0005434444184	13EA4A	3240 406390	LYUBOV SAVELEVA	{"phone": "+70645253679"}
0005434444185	13EA4A	3560 393405	EKATERINA KONOVALOVA	{"email": "ekonovalova_091971@postgrespro.ru", "phone": "+70090611305"}
0005434444186	3FD516	6051 929405	VITALIY KULIKOV	{"email": "kulikovvitaliy.14071971@postgrespro.ru", "phone": "+70841052698"}
0005434444187	98B810	0676 865248	NINA EFREMOVA	{"email": "n_efremova-061976@postgrespro.ru", "phone": "+70505436432"}
0005434444188	D741A2	7956 966123	INNA ROMANOVA	{"email": "inna.romanova-041976@postgrespro.ru", "phone": "+70369257843"}
0005434444189	5ED46E	4879 797989	EVGENIY KUZNECOV	{"phone": "+70730564112"}
0005434444190	5ED46E	7241 644221	SERGEY KONOVALOV	{"phone": "+70601095326"}
0005434444191	738325	8922 408031	VIKTORIYA IVANOVA	{"email": "ivanova-v.1973@postgrespro.ru", "phone": "+70974777281"}
0005434444192	E8F3F5	7004 202300	IRINA SAVELEVA	{"phone": "+70350920536"}
0005434444193	B8F7A4	3380 789835	NINA KOROLEVA	{"email": "korolevan.031966@postgrespro.ru", "phone": "+70314250511"}
0005434445207	9F0B89	0777 259121	ELENA KOLESNIKOVA	{"email": "e_kolesnikova-03091963@postgrespro.ru", "phone": "+70065947369"}
0005434445208	11E4F8	8858 717607	PETR MOROZOV	{"phone": "+70265829345"}
0005434445209	11E4F8	7735 815748	SVETLANA VASILEVA	{"email": "vasileva_s-081974@postgrespro.ru", "phone": "+70659248915"}
0005434445210	C1AFA1	4079 755448	SVETLANA LUKYANOVA	{"email": "lukyanova.svetlana_031969@postgrespro.ru", "phone": "+70173979263"}
0005434445211	5FCCEA	0795 777943	ANDREY ABRAMOV	{"email": "abramovandrey_23031972@postgrespro.ru", "phone": "+70793303344"}
0005434445212	64E3EE	1632 440797	TATYANA NIKIFOROVA	{"email": "t-nikiforova061979@postgrespro.ru", "phone": "+70822730902"}
0005434445213	49918B	2532 063287	LARISA MEDVEDEVA	{"email": "l-medvedeva.1967@postgrespro.ru", "phone": "+70049258639"}
0005434445214	D679BD	5364 294142	ALLA ALEKSANDROVA	{"email": "a_aleksandrova-28041968@postgrespro.ru", "phone": "+70139173789"}
0005434445215	4D07F2	5815 288495	ALEKSEY BORISOV	{"phone": "+70037344723"}
0005434445216	B85044	0295 328311	ALEKSANDR NIKOLAEV	{"phone": "+70239936889"}
0005434445217	2F6F59	3710 324632	OLGA SMIRNOVA	{"email": "smirnova-o_02061972@postgrespro.ru", "phone": "+70360207872"}
0005434445218	2F6F59	0771 754080	ANTONINA TROFIMOVA	{"phone": "+70980542477"}
0005434445219	D6A3EC	4716 005463	NATALYA ZOTOVA	{"email": "n_zotova_02051972@postgrespro.ru", "phone": "+70985300779"}
0005434445220	D6A3EC	1702 446637	ANTONINA MARTYNOVA	{"phone": "+70392275876"}
0005434445221	0CE43F	5867 154822	ELENA DAVYDOVA	{"phone": "+70992308728"}
0005434445222	0CE43F	5155 240959	NADEZHDA KUZNECOVA	{"email": "kuznecovan.12021982@postgrespro.ru", "phone": "+70702653658"}
0005434445223	633EB9	7140 206506	ANNA SEMENOVA	{"email": "a-semenova03111972@postgrespro.ru", "phone": "+70726655251"}
0005434445224	9ACADB	1942 133785	DANIIL KUZNECOV	{"email": "kuznecov.daniil.091985@postgrespro.ru", "phone": "+70618070753"}
0005434445225	D7F9B6	4554 044890	BOGDAN GAVRILOV	{"email": "bgavrilov.041977@postgrespro.ru", "phone": "+70377495098"}
0005434445226	3C03B4	1442 783846	MARAT NAUMOV	{"phone": "+70732603778"}
0005434445227	3C03B4	0450 090300	ALENA YAKOVLEVA	{"phone": "+70373896247"}
0005434445228	86253B	3797 516040	VALENTINA YAKOVLEVA	{"email": "yakovleva_valentina.1976@postgrespro.ru", "phone": "+70869981612"}
0005434445229	3ACE04	8999 396967	PAVEL STEPANOV	{"email": "stepanovpavel.011962@postgrespro.ru", "phone": "+70200787479"}
0005434445230	4A26BA	5054 228130	ANTONINA TARASOVA	{"email": "tarasova_antonina1975@postgrespro.ru", "phone": "+70840918599"}
0005434445231	1D5E97	8672 986178	TATYANA KOZLOVA	{"phone": "+70081671334"}
0005434445232	1D5E97	6267 533881	VALENTINA VASILEVA	{"email": "vasilevav.051970@postgrespro.ru", "phone": "+70207724516"}
0005434445233	658D6A	8967 543281	MARIYA KUZNECOVA	{"email": "mkuznecova.051970@postgrespro.ru", "phone": "+70750414169"}
0005434445234	7ED8BA	1486 081737	KAPITALINA TITOVA	{"email": "titovak-29041976@postgrespro.ru", "phone": "+70690033759"}
0005434445235	19B9DD	6390 625369	VALERIY ROMANOV	{"phone": "+70215114264"}
0005434445236	16384C	3805 546577	LARISA KISELEVA	{"email": "larisa-kiseleva1966@postgrespro.ru", "phone": "+70533978311"}
0005434445237	B3F7C1	3319 255265	MARIYA TROFIMOVA	{"email": "m_trofimova-1977@postgrespro.ru", "phone": "+70687399577"}
0005434445238	19C071	8539 386584	NATALYA OSIPOVA	{"email": "osipova.n_11061968@postgrespro.ru", "phone": "+70698887169"}
0005434445239	19C071	5256 784738	EKATERINA ZHUKOVA	{"email": "zhukova.e_1983@postgrespro.ru", "phone": "+70828249560"}
0005434445240	69C17F	6549 495342	ELENA ANDREEVA	{"email": "andreeva.e.011974@postgrespro.ru", "phone": "+70645859284"}
0005434445241	573FDE	5687 192840	VASILIY KOZLOV	{"phone": "+70527986904"}
0005434445242	573FDE	8281 560090	NATALYA MARTYNOVA	{"email": "martynova-natalya_10121964@postgrespro.ru", "phone": "+70975410812"}
0005434445243	268484	8351 977134	NATALYA MELNIKOVA	{"email": "melnikova_n-031973@postgrespro.ru", "phone": "+70194865946"}
0005434445244	E84F83	1476 164521	IRINA SOROKINA	{"phone": "+70965099275"}
0005434445245	841D9B	4508 102486	STEPAN BORISOV	{"email": "s_borisov.081971@postgrespro.ru", "phone": "+70542943301"}
0005434445246	7A5CD8	2995 504118	EKATERINA ROMANOVA	{"email": "romanova_ekaterina.1973@postgrespro.ru", "phone": "+70079849936"}
0005434445247	D238B6	0645 835042	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov.081985@postgrespro.ru", "phone": "+70385311104"}
0005434445248	D238B6	5020 859282	ANDREY SIDOROV	{"email": "andreysidorov-011970@postgrespro.ru", "phone": "+70556437013"}
0005434445249	5D5619	8775 330766	TATYANA SAVELEVA	{"email": "tatyanasaveleva_11051962@postgrespro.ru", "phone": "+70263622229"}
0005434445250	B45EC1	4359 945319	ANDREY EGOROV	{"phone": "+70441238733"}
0005434445251	C37A46	8152 006708	NIKITA BELOV	{"phone": "+70514618183"}
0005434445252	080806	4864 969043	RAVIL NIKITIN	{"email": "nikitin.ravil_15021982@postgrespro.ru", "phone": "+70995503348"}
0005434445253	080806	8147 060520	TAISIYA BORISOVA	{"email": "taisiya_borisova121975@postgrespro.ru", "phone": "+70336701140"}
0005434445254	99AF06	8407 941008	ANDREY GORBUNOV	{"email": "gorbunov_andrey-1989@postgrespro.ru", "phone": "+70455773612"}
0005434445255	DF99F3	7383 909575	NATALYA MALYSHEVA	{"phone": "+70091088965"}
0005434445256	622DE2	5248 169328	ALEKSANDR GUSEV	{"email": "a_gusev-09121967@postgrespro.ru", "phone": "+70317248645"}
0005434445257	724E60	4431 924547	DMITRIY BELOV	{"phone": "+70530629530"}
0005434445258	3F9389	1128 859790	DENIS KUZNECOV	{"phone": "+70118623507"}
0005434445259	D0D07E	9714 719265	ALEKSANDR TIKHONOV	{"phone": "+70837265323"}
0005434445260	0D9A68	8417 416501	IVAN KOZLOV	{"email": "kozlov.i27081976@postgrespro.ru", "phone": "+70979584427"}
0005434445261	5D6921	7896 387134	TATYANA ALEKSEEVA	{"phone": "+70853305781"}
0005434445262	E4A683	0913 863165	VALENTIN KUZNECOV	{"email": "valentinkuznecov.061977@postgrespro.ru", "phone": "+70356451385"}
0005434445263	BA8EE6	2492 922909	VLADIMIR DMITRIEV	{"phone": "+70593898315"}
0005434445264	BA8EE6	4840 070633	OLGA KUDRYASHOVA	{"phone": "+70428079257"}
0005434445265	BA8EE6	0899 875730	ROMAN MATVEEV	{"email": "r_matveev-16041973@postgrespro.ru", "phone": "+70484368709"}
0005434445266	FBC204	2351 567121	GALINA MALYSHEVA	{"email": "g.malysheva31101965@postgrespro.ru", "phone": "+70252600354"}
0005434445267	DFF1BD	8202 472450	MARIYA VOROBEVA	{"phone": "+70380803895"}
0005434445268	DFF1BD	0819 610680	IVAN KUZNECOV	{"email": "kuznecov-ivan25111969@postgrespro.ru", "phone": "+70537884975"}
0005434445269	AC20F9	8075 691094	VALENTINA ALEKSEEVA	{"phone": "+70485549814"}
0005434445270	169EEC	9253 049356	FLYURA DENISOVA	{"email": "denisova.flyura.1978@postgrespro.ru", "phone": "+70194491618"}
0005434445271	7D89E5	2560 845343	EKATERINA BELOVA	{"email": "ebelova.1968@postgrespro.ru", "phone": "+70239098569"}
0005434445272	2AEF22	4396 167452	ALEKSEY TARASOV	{"email": "alekseytarasov_091971@postgrespro.ru", "phone": "+70306299191"}
0005434445273	B9091A	6884 406129	ALIK KOZLOV	{"phone": "+70152448769"}
0005434445274	D0C1A5	0303 772256	MARIYA AFANASEVA	{"phone": "+70384419379"}
0005434445275	F887B1	4693 615972	PETR VOROBEV	{"phone": "+70735818022"}
0005434445276	C9F539	7914 450309	ANNA VOROBEVA	{"phone": "+70362257766"}
0005434445277	3CF60F	3451 968406	VLADIMIR ROMANOV	{"email": "v_romanov.011969@postgrespro.ru", "phone": "+70228316641"}
0005434445278	5BFD67	5632 851277	MARINA ERMAKOVA	{"email": "ermakova_marina-1975@postgrespro.ru", "phone": "+70464468017"}
0005434445279	EE95C3	2054 760270	VITALIY DAVYDOV	{"phone": "+70414533287"}
0005434445280	87B162	3820 149143	MARINA POTAPOVA	{"email": "potapova-m.091977@postgrespro.ru", "phone": "+70915634268"}
0005434445281	8F6915	4297 602704	ANASTASIYA PAVLOVA	{"phone": "+70768565413"}
0005434445282	C9ED74	0458 210469	ALEKSANDR MOROZOV	{"email": "morozov.a101963@postgrespro.ru", "phone": "+70092663014"}
0005434445283	C9ED74	4007 589100	IVAN IVANOV	{"phone": "+70735244517"}
0005434445284	D958A0	8312 683553	OLEG ZAKHAROV	{"email": "ozakharov-1979@postgrespro.ru", "phone": "+70908857196"}
0005434445285	2A1AC3	5432 554216	DMITRIY KUZMIN	{"phone": "+70585822093"}
0005434445286	2A1AC3	8940 694510	ALEKSANDR MAKAROV	{"email": "a-makarov-011974@postgrespro.ru", "phone": "+70801961013"}
0005434445287	5134BC	8616 633936	YULIYA STEPANOVA	{"phone": "+70056890009"}
0005434445288	2D1454	0567 424010	BORIS SEMENOV	{"phone": "+70906400570"}
0005434445289	96EBFC	5253 742572	SERGEY KUZNECOV	{"email": "sergey_kuznecov_18061978@postgrespro.ru", "phone": "+70315423079"}
0005434445290	E09AF6	2248 006570	NATALYA AFANASEVA	{"email": "afanaseva-n-051979@postgrespro.ru", "phone": "+70365443816"}
0005434445291	AE7B47	1395 436471	ALEKSANDR ILIN	{"email": "ilin_aleksandr-16121983@postgrespro.ru", "phone": "+70419912708"}
0005434445292	13AB20	9436 434845	MAKSIM OSIPOV	{"phone": "+70559395487"}
0005434445293	8ACCEC	7102 831671	NIKITA SERGEEV	{"email": "n_sergeev.011966@postgrespro.ru", "phone": "+70391952198"}
0005434445294	527645	2213 560872	ARTUR ANTONOV	{"phone": "+70654175653"}
0005434445295	4CEC33	7908 987482	ANDREY NOVIKOV	{"phone": "+70018783575"}
0005434445296	2421DB	8896 011835	ARINA LEBEDEVA	{"phone": "+70637929653"}
0005434445297	2421DB	5884 228315	YURIY ISAEV	{"email": "yuriy-isaev-23011981@postgrespro.ru", "phone": "+70001332250"}
0005434445298	C74C54	4526 674217	ALENA MALYSHEVA	{"phone": "+70395131347"}
0005434445299	F20FC6	4262 421276	LYUDMILA AFANASEVA	{"email": "afanaseva_lyudmila-20021978@postgrespro.ru", "phone": "+70820616527"}
0005434445300	350E2F	6994 267269	VLADISLAV FEDOROV	{"email": "fedorov-vladislav1976@postgrespro.ru", "phone": "+70955381628"}
0005434445301	493540	5075 403312	ANTON NAZAROV	{"phone": "+70979919599"}
0005434445302	4CB6C9	7315 014833	ALEKSEY FOMIN	{"email": "fomin.aleksey-27031963@postgrespro.ru", "phone": "+70490884769"}
0005434445303	BB395F	9288 888846	ALEKSEY SOLOVEV	{"email": "solovev-a.091981@postgrespro.ru", "phone": "+70234844871"}
0005434445304	086AF9	7395 187160	ELENA SERGEEVA	{"email": "sergeeva-e-021976@postgrespro.ru", "phone": "+70453948475"}
0005434445305	7D66CC	6373 134710	MIKHAIL NIKOLAEV	{"email": "mnikolaev_011983@postgrespro.ru", "phone": "+70483697262"}
0005434445306	7BBEF7	6849 533721	NIKITA SOKOLOV	{"email": "nikita.sokolov.071973@postgrespro.ru", "phone": "+70129474809"}
0005434445307	1FE166	6849 760649	VLADIMIR NOVIKOV	{"phone": "+70014206237"}
0005434445308	0D219A	1522 236287	VYACHESLAV KUZNECOV	{"phone": "+70730233924"}
0005434445309	83F83D	8809 151686	MARIYA NIKOLAEVA	{"phone": "+70941157870"}
0005434445310	7D94B4	9748 938070	MARIYA MEDVEDEVA	{"email": "medvedeva.m.1975@postgrespro.ru", "phone": "+70649624059"}
0005434445311	550724	9587 498115	NIKITA NAUMOV	{"email": "naumov_nikita061974@postgrespro.ru", "phone": "+70380266825"}
0005434445312	9311E2	1153 166949	ANTONINA NESTEROVA	{"phone": "+70261905389"}
0005434445313	9311E2	3580 623007	VALENTINA IVANOVA	{"email": "v-ivanova_14091974@postgrespro.ru", "phone": "+70597370558"}
0005434445314	6ECF35	2406 447069	MIKHAIL FEDOTOV	{"phone": "+70267355647"}
0005434445315	EA1BFC	9130 800620	ANATOLIY FOMIN	{"phone": "+70827735087"}
0005434445316	EF9FC3	5198 908515	OLEG MARTYNOV	{"email": "martynovo.1978@postgrespro.ru", "phone": "+70521522344"}
0005434445317	92791A	6391 563407	PRASKOVYA GERASIMOVA	{"phone": "+70921989554"}
0005434445318	92791A	3475 723839	VALENTINA MARTYNOVA	{"phone": "+70733908469"}
0005434445319	FCB6DC	8007 061070	SERGEY KOROLEV	{"phone": "+70754897169"}
0005434445320	FCB6DC	3367 938275	FEDOR VLASOV	{"email": "fedor_vlasov.27071972@postgrespro.ru", "phone": "+70290015613"}
0005434445321	A1E7F7	9877 523426	YURIY ANDREEV	{"phone": "+70638522333"}
0005434445322	9B2A5C	4422 341292	TATYANA FOMINA	{"email": "fomina_t-13041982@postgrespro.ru", "phone": "+70346599073"}
0005434445323	518EC5	1433 749229	DARYA FILATOVA	{"email": "filatova.darya.18031967@postgrespro.ru", "phone": "+70853992045"}
0005434445324	518EC5	3875 356708	EVGENIY MOISEEV	{"phone": "+70619695018"}
0005434445325	518EC5	6563 434313	MARIYA KULIKOVA	{"email": "kulikova_m-021986@postgrespro.ru", "phone": "+70309513344"}
0005434446476	447B34	4326 923834	BORIS SCHERBAKOV	{"phone": "+70301564645"}
0005434446477	32D4E2	3120 589476	ALEKSANDR TIMOFEEV	{"email": "timofeeva-16101976@postgrespro.ru", "phone": "+70446071525"}
0005434446478	32D4E2	0694 069394	ALEKSANDR IVANOV	{"phone": "+70017170779"}
0005434446479	AA57AA	1842 746047	DMITRIY GRIGOREV	{"email": "dmitriy-grigorev-111967@postgrespro.ru", "phone": "+70715857000"}
0005434446480	0D1E31	2829 467300	ANTON ABRAMOV	{"phone": "+70751361387"}
0005434446481	1313CA	0677 842307	OLGA MAKSIMOVA	{"phone": "+70615344611"}
0005434446482	703DE3	5210 491940	NIKOLAY PAVLOV	{"phone": "+70052955678"}
0005434446483	703DE3	8122 793559	ALBERT TARASOV	{"phone": "+70935338619"}
0005434446484	60D165	5742 379351	ALEKSANDRA ZAYCEVA	{"email": "zayceva-aleksandra_021966@postgrespro.ru", "phone": "+70692935367"}
0005434446485	AC2528	2091 334676	NADEZHDA KALININA	{"phone": "+70740170320"}
0005434446486	AC2528	3954 615153	ANATOLIY KARPOV	{"phone": "+70568267364"}
0005434446487	422E8C	2965 776191	VIKTOR MATVEEV	{"phone": "+70361314083"}
0005434446488	422E8C	3029 271808	MARINA IVANOVA	{"email": "m-ivanova-011965@postgrespro.ru", "phone": "+70215348802"}
0005434446489	BBF44A	5607 055647	NADEZHDA KOMAROVA	{"phone": "+70368345078"}
0005434446490	E16307	4211 415928	DINA BARANOVA	{"email": "dbaranova-1982@postgrespro.ru", "phone": "+70213250959"}
0005434446491	95EC6E	9527 243804	SERGEY POPOV	{"email": "s_popov061972@postgrespro.ru", "phone": "+70191909120"}
0005434446492	6D10A4	6219 707641	ALEKSANDRA ORLOVA	{"phone": "+70284888005"}
0005434446493	6D10A4	0584 203314	MIKHAIL EGOROV	{"phone": "+70437688422"}
0005434446494	6D10A4	2494 907969	ALEKSANDR STEPANOV	{"email": "astepanov31081970@postgrespro.ru", "phone": "+70438901161"}
0005434446495	20EDD6	0873 913694	MARIYA IVANOVA	{"phone": "+70378714597"}
0005434446496	AB3BD7	9553 501916	TATYANA SIDOROVA	{"email": "sidorovat.15071979@postgrespro.ru", "phone": "+70709067200"}
0005434446497	AB3BD7	0380 017224	SERGEY NIKOLAEV	{"phone": "+70547945850"}
0005434446498	90D148	6608 693338	VALERIYA MATVEEVA	{"phone": "+70599923491"}
0005434446499	ECFE08	6196 682435	NIKOLAY SEMENOV	{"phone": "+70833864327"}
0005434446500	ECFE08	8025 529910	ALINA KOZLOVA	{"email": "a-kozlova-1968@postgrespro.ru", "phone": "+70131725048"}
0005434446501	6ADE76	5553 380969	OKSANA VOROBEVA	{"phone": "+70480705127"}
0005434446502	17A45B	1422 988416	TATYANA PETROVA	{"phone": "+70643246275"}
0005434446503	5103B5	4496 148964	ALEKSEY BORISOV	{"phone": "+70839280474"}
0005434446504	B1DFD6	7647 542304	ALEKSANDR KUZMIN	{"email": "akuzmin1981@postgrespro.ru", "phone": "+70984024728"}
0005434446505	503DAB	3825 229267	NAILYA ALEKSANDROVA	{"phone": "+70599721868"}
0005434446506	503DAB	2475 362723	EVDOKIYA AFANASEVA	{"phone": "+70666684804"}
0005434446507	FEB66E	2505 880224	NADEZHDA NOVIKOVA	{"phone": "+70064351865"}
0005434446508	A26EF7	8459 056677	NATALYA ALEKSEEVA	{"phone": "+70351596727"}
0005434446509	A26EF7	1494 076400	RAFAIL KOZLOV	{"phone": "+70422576490"}
0005434446510	A26EF7	2205 113947	ELENA FOMINA	{"email": "fominae_111976@postgrespro.ru", "phone": "+70771554377"}
0005434446511	B5054D	7278 346675	SERGEY NIKITIN	{"email": "nikitins_04031977@postgrespro.ru", "phone": "+70594931562"}
0005434446512	9DD341	0012 679095	ROZALIYA ZAKHAROVA	{"email": "zakharovarozaliya.031976@postgrespro.ru", "phone": "+70457861316"}
0005434446513	9DD341	0428 814237	ALENA SIDOROVA	{"phone": "+70087482360"}
0005434446514	27B0C1	9339 824689	VYACHESLAV IVANOV	{"email": "v-ivanov06101966@postgrespro.ru", "phone": "+70709755158"}
0005434446515	86D741	4685 876401	NIKOLAY KULIKOV	{"email": "nikolay-kulikov-1967@postgrespro.ru", "phone": "+70321323447"}
0005434446516	ABE0B2	7053 733020	MAKSIM PETROV	{"email": "petrovmaksim.1971@postgrespro.ru", "phone": "+70742886516"}
0005434446517	2FBA92	0961 838435	LYUDMILA DANILOVA	{"email": "danilova-l_1978@postgrespro.ru", "phone": "+70610266336"}
0005434446518	17311F	3037 238059	ELENA GAVRILOVA	{"email": "elena.gavrilova.1977@postgrespro.ru", "phone": "+70739449908"}
0005434446519	912641	8061 136528	EKATERINA AFANASEVA	{"phone": "+70900407662"}
0005434446520	0A18CF	0313 340467	ALEKSEY EGOROV	{"phone": "+70549987361"}
0005434446521	407D76	6501 107093	ZOYA KRASNOVA	{"phone": "+70913186337"}
0005434446522	407D76	1788 857467	TAMARA LOGINOVA	{"email": "tamara.loginova04051967@postgrespro.ru", "phone": "+70080919374"}
0005434446523	4A1F34	5832 268782	EVGENIYA DAVYDOVA	{"email": "davydovaevgeniya_111970@postgrespro.ru", "phone": "+70835241357"}
0005434446524	4A1F34	4546 407908	VALENTINA SOKOLOVA	{"email": "sokolova_v-1978@postgrespro.ru", "phone": "+70259051177"}
0005434446525	1139D4	2635 720990	VLADIMIR ANDREEV	{"email": "andreev.vladimir_28121976@postgrespro.ru", "phone": "+70135867947"}
0005434446526	1139D4	5612 647328	SERGEY BORISOV	{"phone": "+70190757391"}
0005434446527	8A9FBD	5184 381713	SVETLANA KUZNECOVA	{"email": "s.kuznecova.011977@postgrespro.ru", "phone": "+70720458694"}
0005434446528	8A9FBD	3987 544585	RAFAIL MELNIKOV	{"email": "melnikov-r.091971@postgrespro.ru", "phone": "+70946706145"}
0005434446529	2488FE	7145 205653	PETR SMIRNOV	{"phone": "+70688752423"}
0005434446530	2488FE	2077 880145	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-01091965@postgrespro.ru", "phone": "+70011436677"}
0005434446531	E5F4FA	7326 219493	ELENA SMIRNOVA	{"email": "smirnova.elena.09081966@postgrespro.ru", "phone": "+70499344385"}
0005434446588	35FF32	4113 858875	ANATOLIY ZAKHAROV	{"phone": "+70220481857"}
0005434446532	9CE7DC	6752 768619	ALEKSANDR ZAYCEV	{"email": "aleksandrzaycev_121968@postgrespro.ru", "phone": "+70560107394"}
0005434446533	0CD07D	9202 892954	ANATOLIY MOROZOV	{"email": "morozov.a-081972@postgrespro.ru", "phone": "+70801302175"}
0005434446534	1A1897	8446 966568	NATALYA OVCHINNIKOVA	{"email": "novchinnikova12021965@postgrespro.ru", "phone": "+70074845462"}
0005434446535	8C7E32	9891 606833	SERGEY MAKAROV	{"email": "sergey-makarov-021990@postgrespro.ru", "phone": "+70686557267"}
0005434446536	8C7E32	7394 808947	EVGENIY KONOVALOV	{"phone": "+70966138552"}
0005434446537	891338	3706 033654	ANZHELIKA PETROVA	{"email": "petrova-anzhelika.121974@postgrespro.ru", "phone": "+70040220985"}
0005434446538	4AC8C7	3531 022135	YURIY POPOV	{"email": "yuriypopov_1969@postgrespro.ru", "phone": "+70139500195"}
0005434446539	4AC8C7	4767 174130	ALEKSANDR BELOV	{"phone": "+70809974614"}
0005434446540	77C0DD	3620 839241	SERGEY FEDOROV	{"email": "sfedorov031968@postgrespro.ru", "phone": "+70079474159"}
0005434446541	77C0DD	9858 671244	ALEKSANDR ROMANOV	{"email": "a_romanov_081985@postgrespro.ru", "phone": "+70776469352"}
0005434446542	EE83E2	0843 037262	YULIYA KUDRYASHOVA	{"phone": "+70674548680"}
0005434446543	EE83E2	1605 244235	ELENA POPOVA	{"phone": "+70267451949"}
0005434446544	A3AF1F	1672 547147	VALENTINA ROMANOVA	{"email": "romanova_valentina.121964@postgrespro.ru", "phone": "+70951653969"}
0005434446545	A3AF1F	9592 817655	VYACHESLAV ALEKSANDROV	{"email": "aleksandrov_vyacheslav.1977@postgrespro.ru", "phone": "+70885649704"}
0005434446546	654A71	2710 690157	NATALYA FROLOVA	{"phone": "+70609528263"}
0005434446547	654A71	0884 762540	ALEKSANDR SIDOROV	{"email": "sidorov-aleksandr_12051968@postgrespro.ru", "phone": "+70189956412"}
0005434446548	42F090	0136 605821	VALENTINA SOLOVEVA	{"phone": "+70168506198"}
0005434446549	CCD8F9	9403 995508	ARMAN POPOV	{"phone": "+70354518446"}
0005434446550	CCD8F9	5900 591204	LYUDMILA KUZNECOVA	{"phone": "+70737143135"}
0005434446551	D0B5A9	2740 521439	ELENA STEPANOVA	{"phone": "+70889238468"}
0005434446552	3E9E4B	4639 565632	ANATOLIY MELNIKOV	{"phone": "+70123313891"}
0005434446553	9F4CCE	3292 894507	MARIYA MOROZOVA	{"email": "morozova-m-02091962@postgrespro.ru", "phone": "+70051703243"}
0005434446554	B4F9D7	1580 727157	IRINA YUDINA	{"email": "yudina-irina_19091977@postgrespro.ru", "phone": "+70051628879"}
0005434446555	584465	4818 486965	INGA MATVEEVA	{"phone": "+70150750968"}
0005434446556	583769	5202 307838	VLADLEN VASILEV	{"phone": "+70263993656"}
0005434446557	583769	1826 447223	OKSANA BELYAEVA	{"phone": "+70031222830"}
0005434446558	8C88BF	4175 604854	ELENA BORISOVA	{"phone": "+70518636925"}
0005434446559	48804C	9070 254584	SVETLANA SOKOLOVA	{"email": "sokolova_svetlana12101976@postgrespro.ru", "phone": "+70792260729"}
0005434446560	DEAE16	6451 911945	SERGEY KOZLOV	{"email": "kozlov.s_071977@postgrespro.ru", "phone": "+70493214434"}
0005434446561	06394E	6099 400788	GALINA NAUMOVA	{"email": "naumova_g1969@postgrespro.ru", "phone": "+70927602869"}
0005434446562	E12F2C	4512 786151	OKSANA TIKHONOVA	{"phone": "+70011618102"}
0005434446563	E12F2C	5838 207904	KLAVDIYA IVANOVA	{"email": "klavdiya.ivanova-07121975@postgrespro.ru", "phone": "+70066182320"}
0005434446564	CF378A	2203 603459	VALERIY BELOV	{"email": "belov-valeriy.10041974@postgrespro.ru", "phone": "+70502861269"}
0005434446565	ABB638	7176 221369	ANATOLIY RODIONOV	{"email": "anatoliyrodionov_081977@postgrespro.ru", "phone": "+70634654829"}
0005434446566	ABB638	1404 083384	NINA PAVLOVA	{"email": "ninapavlova_1977@postgrespro.ru", "phone": "+70869644320"}
0005434446567	D071A5	3237 587046	DENIS MAKAROV	{"email": "d.makarov_1977@postgrespro.ru", "phone": "+70868926089"}
0005434446568	5E7E43	9727 049752	ANATOLIY PETROV	{"phone": "+70485441286"}
0005434446569	FD6CB7	0767 866061	YURIY ZAKHAROV	{"phone": "+70002547537"}
0005434446570	FD6CB7	3807 730488	LYUDMILA ANDREEVA	{"phone": "+70676310078"}
0005434446571	701741	7795 334419	VYACHESLAV ANDREEV	{"email": "andreevv01051978@postgrespro.ru", "phone": "+70122693366"}
0005434446572	18BDDC	0956 727687	ALEKSANDR ZAYCEV	{"phone": "+70961367583"}
0005434446573	F401D4	8120 520225	ALEKSANDR SIDOROV	{"phone": "+70794911102"}
0005434446574	CC92B6	1490 733830	RAVIL KULIKOV	{"email": "kulikovr_101971@postgrespro.ru", "phone": "+70834800058"}
0005434446575	364C1C	2580 259358	ANATOLIY KAZAKOV	{"phone": "+70749349694"}
0005434446576	5170AF	1911 858987	LYUBOV TIMOFEEVA	{"phone": "+70543222638"}
0005434446577	88C6EA	0121 833461	SERGEY KARPOV	{"phone": "+70388446871"}
0005434446578	C81145	7412 607066	EVGENIY PAVLOV	{"email": "e_pavlov031988@postgrespro.ru", "phone": "+70342991299"}
0005434446579	C81145	1247 105177	TATYANA POLYAKOVA	{"email": "tatyana-polyakova_071971@postgrespro.ru", "phone": "+70206450757"}
0005434446580	1865C3	9806 289899	ALEKSEY SMIRNOV	{"email": "smirnov-aleksey_1985@postgrespro.ru", "phone": "+70540578005"}
0005434446581	1865C3	5708 968139	VLADIMIR KUZNECOV	{"phone": "+70840021328"}
0005434446582	5B813D	8206 176231	ELENA POTAPOVA	{"phone": "+70496730778"}
0005434446583	D42D5C	8650 737113	EVGENIY KUZMIN	{"phone": "+70265644109"}
0005434446584	D42D5C	2752 212694	VALENTINA MATVEEVA	{"email": "v_matveeva21041958@postgrespro.ru", "phone": "+70103134324"}
0005434446585	D42D5C	6338 152140	SVETLANA OSIPOVA	{"phone": "+70645887188"}
0005434446586	F7D366	6212 109978	ILYA KOROLEV	{"phone": "+70000117451"}
0005434446587	63C031	2430 222622	VIKTORIYA GORBUNOVA	{"phone": "+70446411288"}
0005434446589	88842A	3953 399313	ARTEM TARASOV	{"phone": "+70772464718"}
0005434446590	AAC616	1723 242923	GENNADIY ZAYCEV	{"phone": "+70996622527"}
0005434446591	AAC616	6875 231111	VALERIY FROLOV	{"email": "v.frolov.121970@postgrespro.ru", "phone": "+70815925474"}
0005434446592	D0F722	0136 188919	ANASTASIYA ROMANOVA	{"phone": "+70615688929"}
0005434448253	BB4727	9685 636781	NADEZHDA MOISEEVA	{"email": "moiseevan.1972@postgrespro.ru", "phone": "+70438826969"}
0005434448254	1064DD	0352 532395	VALENTINA IVANOVA	{"phone": "+70771013690"}
0005434448255	1064DD	1646 512500	ALEKSEY FEDOTOV	{"email": "fedotov_aleksey1964@postgrespro.ru", "phone": "+70289836003"}
0005434448256	1064DD	0284 802719	TATYANA ALEKSANDROVA	{"phone": "+70341797809"}
0005434448257	F32DA1	4282 187260	KSENIYA BORISOVA	{"phone": "+70167522219"}
0005434448258	48C65C	0610 079405	SERGEY VOLKOV	{"email": "volkovs.04101973@postgrespro.ru", "phone": "+70491403948"}
0005434448259	F72388	9818 308090	RENAT KUZNECOV	{"phone": "+70190347674"}
0005434448260	F72388	0100 558568	RUSLAN BORISOV	{"phone": "+70005270063"}
0005434448261	F277B8	6064 417570	VLADIMIR VLASOV	{"phone": "+70474136435"}
0005434448262	4B6EB2	6017 114416	ELMIRA MELNIKOVA	{"email": "melnikovae_1973@postgrespro.ru", "phone": "+70132372404"}
0005434448263	4B6EB2	4012 307365	SVETLANA SAVELEVA	{"email": "saveleva.svetlana021962@postgrespro.ru", "phone": "+70804168101"}
0005434448264	4B6EB2	8429 908565	EGOR NIKITIN	{"email": "egor_nikitin.1961@postgrespro.ru", "phone": "+70302555572"}
0005434448265	54ECED	1804 036995	ANNA ANDREEVA	{"email": "andreeva_anna_061982@postgrespro.ru", "phone": "+70633361314"}
0005434448266	DF30EB	3112 731408	LYUBOV MASLOVA	{"phone": "+70886735851"}
0005434448267	308F2E	6032 100772	OLGA NAZAROVA	{"email": "nazarovao-17071968@postgrespro.ru", "phone": "+70819399896"}
0005434448268	7A474E	8845 347542	ELENA KUZNECOVA	{"phone": "+70065038914"}
0005434448269	675155	7850 611322	VADIM KUZNECOV	{"phone": "+70084321743"}
0005434448270	3CC2E7	1286 852997	RAISA ZAYCEVA	{"phone": "+70070030313"}
0005434448271	BACCCF	6127 705141	ELLA ZHUKOVA	{"phone": "+70839028767"}
0005434448272	CC4813	8079 812145	NATALYA KONOVALOVA	{"email": "natalya_konovalova-03121971@postgrespro.ru", "phone": "+70029032681"}
0005434448273	E034FC	5260 520339	MIKHAIL ILIN	{"phone": "+70185057093"}
0005434448274	E034FC	3093 364515	ANASTASIYA MASLOVA	{"phone": "+70262527640"}
0005434448275	2ED8E7	7409 215962	VIKTOR GERASIMOV	{"email": "viktorgerasimov_081976@postgrespro.ru", "phone": "+70485432082"}
0005434448276	2ED8E7	2750 422477	ALEKSANDRA POPOVA	{"email": "a.popova26031968@postgrespro.ru", "phone": "+70990521219"}
0005434448277	6F2AE9	3657 393371	VALENTINA EGOROVA	{"email": "v.egorova06111968@postgrespro.ru", "phone": "+70652368298"}
0005434448278	137960	7588 672812	ANASTASIYA BORISOVA	{"phone": "+70394123752"}
0005434448279	B59C4B	9817 032934	ALEKSANDR STEPANOV	{"email": "stepanov-a-051970@postgrespro.ru", "phone": "+70587017737"}
0005434448280	2CDB4E	5796 257350	STANISLAV ROMANOV	{"email": "stanislavromanov-24101966@postgrespro.ru", "phone": "+70733100257"}
0005434448281	77C924	6602 584834	GEORGIY FOMIN	{"email": "fomin.georgiy101968@postgrespro.ru", "phone": "+70632176231"}
0005434448282	D8EE2D	2140 160126	NATALYA PETROVA	{"email": "petrova_natalya-111981@postgrespro.ru", "phone": "+70585124389"}
0005434448283	F90D98	0651 471859	ILDAR VASILEV	{"phone": "+70816846654"}
0005434448284	9D2229	5974 996579	SERGEY EGOROV	{"phone": "+70986951933"}
0005434448285	72133E	1292 371271	ALEKSEY ANDREEV	{"email": "alekseyandreev.1974@postgrespro.ru", "phone": "+70751635623"}
0005434448286	72133E	9574 735507	VITALIY STEPANOV	{"email": "stepanov_vitaliy_1969@postgrespro.ru", "phone": "+70856347714"}
0005434448287	82DA26	7239 163436	MARIYA MELNIKOVA	{"email": "melnikova-m-121977@postgrespro.ru", "phone": "+70033654003"}
0005434448288	60BA8C	6220 026463	INNA IVANOVA	{"email": "ivanova.inna.011973@postgrespro.ru", "phone": "+70069426368"}
0005434448289	60BA8C	7891 244809	IVAN YAKOVLEV	{"email": "yakovlev.ivan051987@postgrespro.ru", "phone": "+70524526582"}
0005434448290	1B528E	6448 471151	ILYA MOROZOV	{"phone": "+70842672003"}
0005434448291	95383D	5567 142230	VALENTINA MOROZOVA	{"email": "morozova-valentina-14011978@postgrespro.ru", "phone": "+70188459539"}
0005434448292	95383D	8170 734600	ANNA NOVIKOVA	{"phone": "+70033918303"}
0005434448293	0005FF	4270 986567	VALERIY MOROZOV	{"email": "v_morozov-03011977@postgrespro.ru", "phone": "+70244439027"}
0005434448294	0005FF	4351 004268	MARINA SOROKINA	{"phone": "+70587628638"}
0005434448295	BC5CF9	1507 637716	SERGEY SEMENOV	{"email": "semenovsergey-14121968@postgrespro.ru", "phone": "+70929551937"}
0005434448296	4C9E84	3450 232888	ELIZAVETA BELYAEVA	{"phone": "+70936014031"}
0005434448297	C25411	2927 633970	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev.1975@postgrespro.ru", "phone": "+70866805272"}
0005434448298	B4B9FE	9310 562035	RUSTYAM SEMENOV	{"email": "rustyamsemenov-051957@postgrespro.ru", "phone": "+70474174765"}
0005434448299	50FB58	8523 922072	OKSANA BOGDANOVA	{"phone": "+70621005106"}
0005434448300	F2EFD7	1089 075213	ALEKSEY NIKOLAEV	{"email": "a.nikolaev_1972@postgrespro.ru", "phone": "+70158318243"}
0005434448301	45B95D	9816 063101	RAISA SEMENOVA	{"email": "raisa_semenova_30011973@postgrespro.ru", "phone": "+70856094837"}
0005434448302	45B95D	9982 644518	NIKITA ISAEV	{"email": "isaev-nikita.25021970@postgrespro.ru", "phone": "+70533584573"}
0005434448303	45B95D	4985 435145	DANIIL PETROV	{"phone": "+70459602267"}
0005434448304	0FE42A	1771 224916	OLEG IVANOV	{"phone": "+70051147896"}
0005434448305	0FE42A	1382 123643	TATYANA RYABOVA	{"email": "tatyana.ryabova_1974@postgrespro.ru", "phone": "+70809495674"}
0005434448306	81F8FD	1728 831974	ARTEM VASILEV	{"phone": "+70858429376"}
0005434448307	403589	5140 404636	TATYANA DENISOVA	{"email": "denisova_tatyana-1967@postgrespro.ru", "phone": "+70342327367"}
0005434448308	403589	9132 890829	SERGEY KARPOV	{"phone": "+70717266286"}
0005434448309	BC2845	3490 626477	ALEKSANDR BONDARENKO	{"phone": "+70112905213"}
0005434448310	4E4712	2374 701080	LYUDMILA SOROKINA	{"email": "l_sorokina_26011970@postgrespro.ru", "phone": "+70614927582"}
0005434448311	7365DB	2153 765279	ZINAIDA ISAEVA	{"phone": "+70647321454"}
0005434448312	BC18C4	0611 153293	RAISA TARASOVA	{"phone": "+70564390247"}
0005434448313	D6696C	2385 638404	NIKITA DAVYDOV	{"phone": "+70756843428"}
0005434448314	E716E5	1407 179960	PAVEL OSIPOV	{"email": "pavel.osipov-07071975@postgrespro.ru", "phone": "+70969377441"}
0005434448315	B2AFAE	1457 938568	YULIYA KUZNECOVA	{"phone": "+70561256052"}
0005434448316	B2AFAE	7158 221969	VLADIMIR NIKOLAEV	{"email": "v_nikolaev1969@postgrespro.ru", "phone": "+70281760831"}
0005434448317	C75CA1	1693 385912	NATALYA KOZLOVA	{"email": "kozlova-natalya_041972@postgrespro.ru", "phone": "+70449472652"}
0005434448318	047367	6465 889630	GALINA OSIPOVA	{"email": "osipovag1962@postgrespro.ru", "phone": "+70179042952"}
0005434448319	119562	0938 224469	VALENTINA SEMENOVA	{"email": "v.semenova1978@postgrespro.ru", "phone": "+70692569026"}
0005434448320	5A2768	0569 857725	OLGA AKIMOVA	{"phone": "+70079796613"}
0005434448321	E545EC	8956 488513	SVETLANA NAUMOVA	{"email": "snaumova-31101974@postgrespro.ru", "phone": "+70689898808"}
0005434448322	E545EC	9884 372959	VIKTOR VLASOV	{"email": "vlasovv.01111963@postgrespro.ru", "phone": "+70276849402"}
0005434448323	27F5C5	0779 179119	ARTEM MIKHAYLOV	{"phone": "+70491425582"}
0005434448324	27F5C5	0819 472954	ANNA ZAYCEVA	{"email": "annazayceva-121975@postgrespro.ru", "phone": "+70333486171"}
0005434448325	27F5C5	6721 546001	VLADIMIR ZAYCEV	{"phone": "+70462550774"}
0005434448326	3B34C6	0710 182046	EGOR VOLKOV	{"email": "e-volkov081974@postgrespro.ru", "phone": "+70104570772"}
0005434448327	370122	5969 469468	DENIS KULIKOV	{"email": "kulikov-d041969@postgrespro.ru", "phone": "+70595014718"}
0005434448328	370122	3420 483325	YURIY PETROV	{"phone": "+70415699515"}
0005434448329	75DE74	0136 786043	NIKOLAY PETROV	{"email": "npetrov-1979@postgrespro.ru", "phone": "+70174843600"}
0005434448330	75DE74	6157 957196	RAFAIL VASILEV	{"phone": "+70269598980"}
0005434448331	75DE74	0352 452594	SERGEY VASILEV	{"email": "s-vasilev091976@postgrespro.ru", "phone": "+70751146639"}
0005434448332	A35398	7373 085648	GALINA FROLOVA	{"email": "galina.frolova.121978@postgrespro.ru", "phone": "+70234197963"}
0005434448333	944652	3309 937399	OLGA VASILEVA	{"phone": "+70159018476"}
0005434448334	1A9426	7954 154431	ILMIRA GRISHINA	{"email": "grishina_i.061969@postgrespro.ru", "phone": "+70421949675"}
0005434448335	447CBB	4273 721006	IVAN SERGEEV	{"phone": "+70844642782"}
0005434448336	332D99	3794 956958	PETR NAUMOV	{"phone": "+70769000203"}
0005434448337	F1F87F	4307 052605	MARINA BELOVA	{"phone": "+70535497145"}
0005434448338	C175A2	1542 987005	ALEKSEY KUZMIN	{"phone": "+70555784646"}
0005434448339	C175A2	3650 740300	MARINA DMITRIEVA	{"phone": "+70360995736"}
0005434448340	C175A2	1635 410869	YULIYA ALEKSEEVA	{"phone": "+70989175736"}
0005434448341	35B273	7449 084619	GALINA KOLESNIKOVA	{"email": "gkolesnikova-1979@postgrespro.ru", "phone": "+70931743690"}
0005434448342	35B273	9645 390063	LYUBOV ZAYCEVA	{"email": "l.zayceva_1973@postgrespro.ru", "phone": "+70777983384"}
0005434448343	144B6A	1077 119643	VLADIMIR FEDOTOV	{"email": "vladimir_fedotov_01041972@postgrespro.ru", "phone": "+70955313769"}
0005434448344	96E3A2	6275 395040	VITALIY ZAKHAROV	{"phone": "+70430014969"}
0005434448345	96E3A2	2221 898255	ANDREY ZHURAVLEV	{"phone": "+70112152841"}
0005434448346	05AC07	4944 113064	VALENTIN ILIN	{"phone": "+70570804932"}
0005434448347	05AC07	3721 424626	NATALYA GORBUNOVA	{"email": "natalya_gorbunova_071962@postgrespro.ru", "phone": "+70820630409"}
0005434448348	71811E	7908 364119	EMILIYA DANILOVA	{"email": "e-danilova.1968@postgrespro.ru", "phone": "+70283361263"}
0005434448349	71811E	2700 296487	IRINA ZAKHAROVA	{"email": "zakharova-i.08031972@postgrespro.ru", "phone": "+70100415257"}
0005434448350	B28683	3740 550651	YULIYA KOMAROVA	{"phone": "+70721623974"}
0005434448351	C62902	9566 226583	VLADIMIR KUZNECOV	{"phone": "+70189961515"}
0005434448352	CEBDEC	3381 147899	EDUARD FROLOV	{"phone": "+70239821462"}
0005434448353	CEBDEC	8359 644165	ALLA NIKITINA	{"phone": "+70278131330"}
0005434448354	D35DA3	9411 608773	SERGEY KUZNECOV	{"phone": "+70650183661"}
0005434448355	D35DA3	4652 540863	IGOR CHERNOV	{"email": "chernov_igor.061963@postgrespro.ru", "phone": "+70205487501"}
0005434448356	6E482F	8836 261662	LYUBOV ZHURAVLEVA	{"phone": "+70243093950"}
0005434448357	1E3D5B	2848 719543	ALEKSANDR ALEKSANDROV	{"phone": "+70173864002"}
0005434448358	F5E171	0871 638780	GEORGIY ANTONOV	{"email": "georgiy.antonov-1981@postgrespro.ru", "phone": "+70104188824"}
0005434448359	F5E171	0174 593549	VIKTORIYA TARASOVA	{"email": "viktoriya-tarasova07041973@postgrespro.ru", "phone": "+70737028970"}
0005434448360	D8545D	7048 402049	ALEKSEY GORBUNOV	{"email": "gorbunova1968@postgrespro.ru", "phone": "+70318044623"}
0005434448361	7153DF	0120 214161	VLADIMIR GAVRILOV	{"phone": "+70228804308"}
0005434448362	7153DF	5576 465860	ANASTASIYA SMIRNOVA	{"phone": "+70767109823"}
0005434448363	375BDD	6058 735347	OLESYA ROMANOVA	{"phone": "+70823662390"}
0005434448364	511510	7863 055711	VIKTOR ROMANOV	{"email": "viktor.romanov1977@postgrespro.ru", "phone": "+70795199062"}
0005434448365	E9EC64	4601 100960	EKATERINA SAVELEVA	{"email": "saveleva_ekaterina061970@postgrespro.ru", "phone": "+70416245417"}
0005434448366	E41C72	3346 535496	RAFAIL ANDREEV	{"email": "randreev.18111991@postgrespro.ru", "phone": "+70244224519"}
0005434448367	E41C72	8675 051620	MARIYA GRISHINA	{"email": "mariya_grishina1969@postgrespro.ru", "phone": "+70864141926"}
0005434448368	675564	7368 654177	DMITRIY KULIKOV	{"phone": "+70318500537"}
0005434448369	941E3E	8512 896804	MATVEY EGOROV	{"email": "egorov_m-08101975@postgrespro.ru", "phone": "+70471912289"}
0005434448370	941E3E	2998 641726	ALLA ROMANOVA	{"phone": "+70326758145"}
0005434448371	3683B1	6897 915641	VLADIMIR KISELEV	{"email": "vladimirkiselev-011962@postgrespro.ru", "phone": "+70725854739"}
0005434448372	3EA67D	6646 944573	VENERA CHERNOVA	{"phone": "+70250658299"}
0005434448373	68F3A8	9297 074326	MARINA GUSEVA	{"email": "m_guseva051974@postgrespro.ru", "phone": "+70419852613"}
0005434448374	68F3A8	9415 748308	DARYA VOLKOVA	{"email": "volkovadarya.12071987@postgrespro.ru", "phone": "+70295785493"}
0005434448375	B29485	8393 512453	OLESYA PAVLOVA	{"email": "pavlova-o.031981@postgrespro.ru", "phone": "+70585282539"}
0005434448376	78AC29	6136 623899	EVGENIY TIMOFEEV	{"phone": "+70688217677"}
0005434448377	78AC29	8332 702008	ALEKSANDR KULIKOV	{"phone": "+70510014013"}
0005434448378	78AC29	4535 648348	EVGENIY EGOROV	{"email": "egorov_e.1972@postgrespro.ru", "phone": "+70241453627"}
0005434448379	87C9E3	7183 611891	IRINA SEMENOVA	{"email": "i.semenova011978@postgrespro.ru", "phone": "+70292501979"}
0005434448380	FA7A30	3757 933269	EVGENIY ANDREEV	{"email": "evgeniy_andreev-15101974@postgrespro.ru", "phone": "+70800012683"}
0005434448381	FA7A30	4034 233848	ALENA KOZLOVA	{"email": "kozlova-a091973@postgrespro.ru", "phone": "+70478730529"}
0005434448382	F9BB9D	3779 943941	DMITRIY NAZAROV	{"email": "dmitriy.nazarov.031968@postgrespro.ru", "phone": "+70990123256"}
0005434448383	387FEF	4059 766524	OLEG ZAYCEV	{"email": "oleg-zaycev.041976@postgrespro.ru", "phone": "+70368099630"}
0005434448384	C259DC	1344 137609	NIKOLAY SAVELEV	{"email": "savelevn_1969@postgrespro.ru", "phone": "+70980587659"}
0005434448385	C259DC	6551 032045	ANTONINA MAKAROVA	{"email": "amakarova-1976@postgrespro.ru", "phone": "+70986208061"}
0005434448386	C4DFF6	8420 485495	LYUBOV KOZLOVA	{"phone": "+70353421524"}
0005434448387	14BDF5	8419 214808	NADEZHDA GAVRILOVA	{"phone": "+70031115450"}
0005434448388	BCD179	0105 613725	ANATOLIY GRIGOREV	{"email": "anatoliy-grigorev-111971@postgrespro.ru", "phone": "+70566559728"}
0005434448389	717AAA	3390 374022	DENIS IVANOV	{"email": "denis_ivanov.01021979@postgrespro.ru", "phone": "+70173755540"}
0005434448390	717AAA	2697 074066	ILYA FEDOROV	{"phone": "+70067570570"}
0005434448391	70AB4D	6849 418123	ANASTASIYA LAZAREVA	{"email": "lazarevaanastasiya-121967@postgrespro.ru", "phone": "+70728245470"}
0005434448392	122303	3815 832357	ELIZAVETA TIMOFEEVA	{"phone": "+70004147495"}
0005434448393	36D92E	4735 217423	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey1977@postgrespro.ru", "phone": "+70021009370"}
0005434448394	67D9D2	2495 374131	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir1964@postgrespro.ru", "phone": "+70221816663"}
0005434448395	67D9D2	4652 546489	ELENA KOROLEVA	{"email": "e.koroleva_1967@postgrespro.ru", "phone": "+70079073622"}
0005434448396	1C71A1	3490 367293	NATALIYA KOLESNIKOVA	{"phone": "+70113762227"}
0005434448397	1C71A1	9322 272849	EVGENIY MAKSIMOV	{"phone": "+70254664839"}
0005434448398	8F126D	7368 409521	VALENTINA MAKAROVA	{"phone": "+70380499731"}
0005434448399	068EAF	5324 460030	ALEKSANDR KOROLEV	{"email": "a_korolev081970@postgrespro.ru", "phone": "+70111118787"}
0005434448400	41681E	6642 621683	VALENTINA GAVRILOVA	{"phone": "+70360404406"}
0005434448401	6F2556	4141 374979	VYACHESLAV ANTONOV	{"phone": "+70432475132"}
0005434448402	897BE7	9406 343396	ZOYA KUZNECOVA	{"phone": "+70833855161"}
0005434448403	22F581	9393 202766	EKATERINA PETROVA	{"email": "e.petrova031971@postgrespro.ru", "phone": "+70538660180"}
0005434448404	8BA9FC	8861 895283	LIDIYA KULIKOVA	{"email": "kulikova-l.1981@postgrespro.ru", "phone": "+70548898650"}
0005434448405	FBF2F5	5136 116461	VADIM KRASNOV	{"email": "krasnov_vadim-051977@postgrespro.ru", "phone": "+70620645171"}
0005434448406	6C0A1D	0628 715573	SERGEY ISAEV	{"phone": "+70727112724"}
0005434448407	2101DF	4184 339650	OLGA MIKHAYLOVA	{"email": "mikhaylova.olga.1965@postgrespro.ru", "phone": "+70570884490"}
0005434448408	2101DF	4671 039756	YURIY VASILEV	{"email": "y-vasilev111980@postgrespro.ru", "phone": "+70209090549"}
0005434448409	FE25EE	4388 636611	VYACHESLAV TIKHONOV	{"phone": "+70218818385"}
0005434448410	FE25EE	1248 967868	ELENA ALEKSEEVA	{"phone": "+70270149293"}
0005434448411	62D959	9770 587759	NADEZHDA LEBEDEVA	{"email": "nadezhdalebedeva_1982@postgrespro.ru", "phone": "+70140681935"}
0005434448412	B0AA9C	2479 174753	DAMIR PETROV	{"email": "petrov-d.021974@postgrespro.ru", "phone": "+70986958297"}
0005434448413	34AF6C	4496 783225	EVGENIY TARASOV	{"phone": "+70806907307"}
0005434448414	34AF6C	5111 499979	YURIY ABRAMOV	{"phone": "+70730738898"}
0005434448415	408F77	1091 081005	NIKOLAY BORISOV	{"phone": "+70434980462"}
0005434448416	8342D3	4606 258934	VALERIYA ANDREEVA	{"email": "vandreeva.08091977@postgrespro.ru", "phone": "+70809246580"}
0005434448417	8342D3	3156 947900	VALENTINA EGOROVA	{"phone": "+70131165184"}
0005434448418	8342D3	7292 459806	VALENTINA ALEKSEEVA	{"email": "valentina_alekseeva_1972@postgrespro.ru", "phone": "+70681632692"}
0005434458433	0913FE	6751 999758	EVGENIYA SOROKINA	{"email": "sorokina_e-15101972@postgrespro.ru", "phone": "+70796524378"}
0005434458434	8547BE	3920 105047	NIKOLAY MELNIKOV	{"email": "nikolay_melnikov_031974@postgrespro.ru", "phone": "+70553835534"}
0005434458435	AECAAE	9532 360973	GENNADIY MOROZOV	{"phone": "+70527428481"}
0005434458436	AECAAE	2589 030403	NIKOLAY MOROZOV	{"phone": "+70641308040"}
0005434458437	929836	7589 608512	VIKTOR KOROLEV	{"phone": "+70223837846"}
0005434458438	DF7A7E	1381 516917	IBRAGIM DMITRIEV	{"phone": "+70565307782"}
0005434458439	DF7A7E	1490 799592	EVGENIY MIKHAYLOV	{"phone": "+70296895583"}
0005434458440	3A8B7F	8687 097437	ALEKSANDR NAUMOV	{"email": "a_naumov_20101982@postgrespro.ru", "phone": "+70081587770"}
0005434458441	3A8B7F	2246 075554	ANASTASIYA GRISHINA	{"phone": "+70149300047"}
0005434458442	9ABA6E	3496 610100	TATYANA KOLESNIKOVA	{"email": "kolesnikovatatyana.061962@postgrespro.ru", "phone": "+70003359611"}
0005434458443	9ABA6E	8367 425614	VALENTINA ALEKSEEVA	{"phone": "+70942832126"}
0005434458444	99C1C6	9948 182549	DANIIL TIMOFEEV	{"phone": "+70012624460"}
0005434458445	99C1C6	1217 374488	NIKOLAY PETROV	{"email": "nikolay_petrov.19031968@postgrespro.ru", "phone": "+70571277547"}
0005434458446	4E286B	4487 394510	OLGA KARPOVA	{"email": "karpova_olga.07121987@postgrespro.ru", "phone": "+70745056541"}
0005434458447	4E286B	5856 139927	KLARA FILIPPOVA	{"email": "filippova_k_07091978@postgrespro.ru", "phone": "+70015940292"}
0005434458448	9EA631	7070 234766	ELIZAVETA KARPOVA	{"email": "ekarpova02041975@postgrespro.ru", "phone": "+70827821704"}
0005434458449	9EA631	7812 034975	ANATOLIY TIMOFEEV	{"phone": "+70113723574"}
0005434458450	CAA397	6767 768463	NIKITA POPOV	{"email": "nikitapopov_05011974@postgrespro.ru", "phone": "+70338734658"}
0005434458451	CAA397	4891 271177	DMITRIY BARANOV	{"phone": "+70235807475"}
0005434458452	A5BB5E	6689 980711	RAUF BELOV	{"email": "r_belov-19091972@postgrespro.ru", "phone": "+70076567213"}
0005434458453	FD83DF	1752 745509	KSENIYA PETROVA	{"email": "petrova-k_1969@postgrespro.ru", "phone": "+70968391431"}
0005434458454	09D2FC	2701 436023	NADEZHDA ALEKSEEVA	{"email": "nadezhda_alekseeva_1972@postgrespro.ru", "phone": "+70765286374"}
0005434458455	B4C5DE	4096 059362	ALEKSANDR SERGEEV	{"phone": "+70888539602"}
0005434458456	B4C5DE	6807 136602	SERGEY KARPOV	{"email": "karpov-s.121969@postgrespro.ru", "phone": "+70836079240"}
0005434458457	C69210	2470 869780	ALEKSANDRA PAVLOVA	{"email": "aleksandrapavlova-13091972@postgrespro.ru", "phone": "+70889874241"}
0005434458458	C19791	5795 883475	ELENA IVANOVA	{"phone": "+70207468531"}
0005434458459	C19791	5723 444997	GENNADIY NIKOLAEV	{"email": "g.nikolaev-061984@postgrespro.ru", "phone": "+70123162545"}
0005434458460	C19791	8096 900521	ROMAN VOLKOV	{"phone": "+70765154375"}
0005434458461	384795	1644 847524	LYUBOV IVANOVA	{"email": "ivanova-lyubov.121970@postgrespro.ru", "phone": "+70069971852"}
0005434458462	3C7A5C	0887 903836	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov-27111967@postgrespro.ru", "phone": "+70941241609"}
0005434458463	3C7A5C	7625 826102	IVAN SEMENOV	{"email": "i_semenov.1979@postgrespro.ru", "phone": "+70664880343"}
0005434458464	11C215	3326 736510	SVETLANA KRASNOVA	{"email": "s-krasnova.17011974@postgrespro.ru", "phone": "+70438030086"}
0005434458465	11C215	1530 470854	ALEKSEY ISAEV	{"email": "isaevaleksey_1964@postgrespro.ru", "phone": "+70730591462"}
0005434458466	655F5B	7733 938905	MURAT SOLOVEV	{"phone": "+70323389026"}
0005434458467	CFAA1F	2314 080911	KIRILL ZAKHAROV	{"email": "k-zakharov_1966@postgrespro.ru", "phone": "+70163740063"}
0005434458468	9345AB	1295 297047	DMITRIY ZAYCEV	{"email": "d_zaycev091968@postgrespro.ru", "phone": "+70772016663"}
0005434458469	FF2F4B	7828 790464	SERGEY OSIPOV	{"phone": "+70559765475"}
0005434458470	913BA6	1872 499246	ANTON SERGEEV	{"email": "asergeev1976@postgrespro.ru", "phone": "+70971389931"}
0005434458471	D9E622	8409 414224	ANATOLIY TIMOFEEV	{"phone": "+70001284528"}
0005434458472	2BE4B1	1146 421351	ELENA EFIMOVA	{"phone": "+70677516323"}
0005434458473	2BE4B1	5246 187407	OLGA PETROVA	{"phone": "+70972537386"}
0005434458474	B2E1FA	5406 868318	TIMUR ANTONOV	{"email": "t_antonov_26101970@postgrespro.ru", "phone": "+70020603390"}
0005434458475	0D20CC	1956 288096	OLGA SEMENOVA	{"phone": "+70235413443"}
0005434458476	FCAC67	4698 504642	DMITRIY NAZAROV	{"phone": "+70519361070"}
0005434458477	DBC2D5	3569 646978	ANNA SERGEEVA	{"phone": "+70081975609"}
0005434458478	6BCE84	4178 436958	YURIY SEMENOV	{"phone": "+70827402577"}
0005434458479	6D00C5	3652 941436	LYUDMILA KUZNECOVA	{"phone": "+70419642443"}
0005434458480	58B74B	8960 240107	BORIS BARANOV	{"email": "borisbaranov-22041966@postgrespro.ru", "phone": "+70700578056"}
0005434458481	58B74B	7847 964215	IRINA KOROLEVA	{"phone": "+70603157031"}
0005434458482	BDEC81	4601 408525	RUSLAN ILIN	{"phone": "+70435663022"}
0005434458483	BDEC81	3244 696862	MIKHAIL KAZAKOV	{"phone": "+70976895396"}
0005434458484	DC569D	1353 255201	MARINA NIKOLAEVA	{"email": "m.nikolaeva.101972@postgrespro.ru", "phone": "+70479417250"}
0005434458485	7D9998	5685 904084	VALENTINA FILIPPOVA	{"email": "filippovav-1972@postgrespro.ru", "phone": "+70744392421"}
0005434458486	41AAF7	6502 916696	PAVEL SOLOVEV	{"email": "pavel-solovev_051968@postgrespro.ru", "phone": "+70664082498"}
0005434458487	01C2DD	5677 502174	LYUDMILA KOVALEVA	{"phone": "+70933027178"}
0005434458488	31BF82	0220 641581	PETR ABRAMOV	{"phone": "+70784375396"}
0005434458489	EFA26A	8001 673719	SVETLANA KARPOVA	{"phone": "+70224328945"}
0005434458490	B7C772	0569 843394	GALINA SMIRNOVA	{"email": "smirnova.galina_071970@postgrespro.ru", "phone": "+70275637672"}
0005434458491	882A7F	9331 420753	VLADIMIR FROLOV	{"email": "v-frolov_07111972@postgrespro.ru", "phone": "+70288299360"}
0005434458492	B0FACB	3019 326266	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr19031972@postgrespro.ru", "phone": "+70261642151"}
0005434458493	B0FACB	3674 728690	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya_091971@postgrespro.ru", "phone": "+70183271711"}
0005434458494	F33C88	4506 508935	VERA FILATOVA	{"email": "filatova_vera.051971@postgrespro.ru", "phone": "+70505905210"}
0005434458495	F33C88	6580 798984	ILYA KUZNECOV	{"phone": "+70315594260"}
0005434458496	9EBB1A	0801 895350	SERGEY EGOROV	{"phone": "+70771509920"}
0005434458497	6BFD7C	2114 231992	GALINA VOROBEVA	{"email": "g_vorobeva_011975@postgrespro.ru", "phone": "+70644337230"}
0005434458498	4F88D2	1464 720975	NATALIYA PETROVA	{"email": "petrova-nataliya.071970@postgrespro.ru", "phone": "+70805260563"}
0005434458499	AB106F	7517 331250	VYACHESLAV KULIKOV	{"phone": "+70119513157"}
0005434458500	021077	0338 558703	PETR KUZNECOV	{"phone": "+70326546694"}
0005434458501	290EC2	0416 963958	IRINA KONDRATEVA	{"email": "kondratevairina_091965@postgrespro.ru", "phone": "+70571723407"}
0005434458502	4C08D2	5309 211909	VALENTINA KONOVALOVA	{"phone": "+70284153439"}
0005434458503	4C08D2	2702 752277	KAROLINA NESTEROVA	{"phone": "+70663425155"}
0005434458504	4C08D2	1144 807196	ANNA ARKHIPOVA	{"email": "arkhipova.anna061973@postgrespro.ru", "phone": "+70991319463"}
0005434458505	CD96E6	0113 882232	GALINA KOMAROVA	{"phone": "+70699227097"}
0005434458506	CD96E6	7815 964385	YULIYA ILINA	{"phone": "+70675740221"}
0005434458507	0CE4B3	0052 106079	DENIS IVANOV	{"email": "d-ivanov-08061969@postgrespro.ru", "phone": "+70408713601"}
0005434458508	54A64E	1777 079166	ANASTASIYA LEBEDEVA	{"email": "anastasiyalebedeva.30031972@postgrespro.ru", "phone": "+70316258571"}
0005434458509	54A64E	2414 256403	ALISA KARPOVA	{"phone": "+70268443596"}
0005434458510	9D0015	0901 568483	MAKSIM IVANOV	{"phone": "+70357174510"}
0005434458511	9D0015	3682 245120	ALEKSANDR FOMIN	{"email": "aleksandr_fomin-1979@postgrespro.ru", "phone": "+70026638573"}
0005434458512	9D0015	8020 365587	VALENTINA ILINA	{"phone": "+70687316667"}
0005434458513	AB19D0	4349 199694	EVGENIY ISAEV	{"phone": "+70396685294"}
0005434458514	0BBEAC	9402 162704	TATYANA OSIPOVA	{"email": "osipova-t_1980@postgrespro.ru", "phone": "+70064111211"}
0005434458515	894BA3	4800 729270	IVAN FEDOTOV	{"phone": "+70079349254"}
0005434458516	A82C2A	5530 979779	TAISIYA AFANASEVA	{"email": "tafanaseva_22041980@postgrespro.ru", "phone": "+70737110569"}
0005434458517	AC1772	7538 782994	ALEKSANDR GUSEV	{"email": "aleksandr.gusev-011961@postgrespro.ru", "phone": "+70059182843"}
0005434458518	AC1772	0219 779268	PAVEL POPOV	{"phone": "+70813307371"}
0005434458519	5BCC78	2349 228360	VALENTINA IVANOVA	{"phone": "+70253331990"}
0005434458520	5BCC78	9763 208014	ALEKSANDRA ARKHIPOVA	{"email": "arkhipovaaleksandra-031968@postgrespro.ru", "phone": "+70646682978"}
0005434458521	250D63	9975 931625	VERA SOKOLOVA	{"phone": "+70661042443"}
0005434458522	78E30E	9893 758318	ANNA FROLOVA	{"email": "afrolova.071964@postgrespro.ru", "phone": "+70697541072"}
0005434458523	74C664	7480 384655	ALEKSANDR BELOV	{"phone": "+70780311180"}
0005434458524	F9BDEF	5833 222058	ALEKSEY MIRONOV	{"email": "mironov_aleksey_1968@postgrespro.ru", "phone": "+70819245075"}
0005434458525	CBF81E	9583 316767	RAISA VOLKOVA	{"phone": "+70353141332"}
0005434458526	CBF81E	8654 577559	NATALIYA DAVYDOVA	{"phone": "+70940132260"}
0005434458527	CBF81E	5258 301186	SERGEY NIKITIN	{"email": "nikitin.s.071969@postgrespro.ru", "phone": "+70101243061"}
0005434458528	748EFD	3816 883689	OLESYA MEDVEDEVA	{"email": "medvedeva-o-30061974@postgrespro.ru", "phone": "+70635275710"}
0005434458529	BAD52A	8995 935502	STANISLAV KOZLOV	{"phone": "+70401995979"}
0005434458530	31D90D	7089 900046	SVETLANA MOROZOVA	{"email": "morozova.svetlana.121993@postgrespro.ru", "phone": "+70498604505"}
0005434458531	F8DD9E	4259 705122	NIKOLAY ILIN	{"email": "ilinnikolay17021978@postgrespro.ru", "phone": "+70924574622"}
0005434458532	F8DD9E	9140 467786	NIKOLAY NAUMOV	{"email": "n.naumov18101957@postgrespro.ru", "phone": "+70493891810"}
0005434458533	599E9B	2226 810340	TATYANA ANDREEVA	{"phone": "+70388917576"}
0005434458534	E6F349	0851 761845	ELENA MELNIKOVA	{"phone": "+70128300016"}
0005434458535	E6F349	6927 035354	FARID VOLKOV	{"phone": "+70284579544"}
0005434458536	DC0DB4	8822 411854	ELENA IVANOVA	{"phone": "+70182934829"}
0005434458537	DC0DB4	2240 187171	NIKOLAY DMITRIEV	{"phone": "+70108103457"}
0005434458538	DC0DB4	7573 241742	DMITRIY MAKSIMOV	{"email": "dmitriymaksimov.12101971@postgrespro.ru", "phone": "+70549143023"}
0005434458539	00F7B1	0444 821040	MARIYA KUZNECOVA	{"phone": "+70019954247"}
0005434458540	BFFDA1	7688 501760	VIKTOR AFANASEV	{"phone": "+70588173558"}
0005434458541	49C2B9	3982 835929	DANIIL YAKOVLEV	{"email": "yakovlev_d30031968@postgrespro.ru", "phone": "+70141122121"}
0005434458542	49C2B9	8041 705719	VLADIMIR ANTONOV	{"phone": "+70750322535"}
0005434458543	780D9F	2463 591617	NATALYA KOZLOVA	{"email": "natalya_kozlova-1975@postgrespro.ru", "phone": "+70948035755"}
0005434458544	780D9F	4925 580848	ARTEM POPOV	{"email": "popov_artem-1968@postgrespro.ru", "phone": "+70040035512"}
0005434458545	FB3A7B	2880 238573	VADIM KUZMIN	{"email": "vadim.kuzmin16051969@postgrespro.ru", "phone": "+70323730106"}
0005434458546	48CE7B	7452 076489	TATYANA ZAKHAROVA	{"phone": "+70747500361"}
0005434458547	48CE7B	5733 423575	ROMAN NAZAROV	{"email": "r.nazarov-20021978@postgrespro.ru", "phone": "+70727089941"}
0005434458548	EB3782	1200 756515	MIKHAIL MATVEEV	{"email": "mikhailmatveev_071969@postgrespro.ru", "phone": "+70916197771"}
0005434458549	790F5A	5803 885122	FATIMA GRISHINA	{"phone": "+70845751047"}
0005434458550	F1641E	9296 200912	RAFAEL MOROZOV	{"phone": "+70633736395"}
0005434458551	F1641E	5503 328437	SERGEY ORLOV	{"phone": "+70372537563"}
0005434458552	3C1F56	0089 361366	YULIYA KUZMINA	{"phone": "+70209070456"}
0005434458553	9F3696	0924 376020	ANASTASIYA IVANOVA	{"phone": "+70262443325"}
0005434458554	FECB62	9504 571000	IVAN FEDOROV	{"phone": "+70769605659"}
0005434458555	C59464	6740 803191	VALENTINA ANDREEVA	{"email": "valentina-andreeva-111969@postgrespro.ru", "phone": "+70799338095"}
0005434458556	048E3A	0420 704588	MIKHAIL EGOROV	{"phone": "+70197518229"}
0005434458557	048E3A	4192 140326	GALINA NIKIFOROVA	{"email": "nikiforova_g05081975@postgrespro.ru", "phone": "+70060323713"}
0005434458558	0F44A0	5336 339455	MAKSIM BONDARENKO	{"email": "maksim.bondarenko.31051966@postgrespro.ru", "phone": "+70836919769"}
0005434458559	0A73E7	6805 164145	ANTON STEPANOV	{"phone": "+70742269654"}
0005434458560	41E2F8	1689 620719	POLINA MOISEEVA	{"phone": "+70031402521"}
0005434458561	F2CB23	3337 188005	NATALYA SEMENOVA	{"phone": "+70301457346"}
0005434458562	4D7894	6201 877590	PAVEL DMITRIEV	{"phone": "+70190257231"}
0005434458563	A2EC6D	9497 098810	VALENTINA ABRAMOVA	{"phone": "+70609198537"}
0005434458564	A2EC6D	7766 683719	VIKTORIYA SOROKINA	{"phone": "+70165405827"}
0005434458565	921DF5	0068 631086	ANASTASIYA TITOVA	{"phone": "+70306109492"}
0005434458566	921DF5	8088 026489	DMITRIY MOROZOV	{"email": "dmorozov-041976@postgrespro.ru", "phone": "+70825748532"}
0005434458623	67BBE6	5050 197741	MIKHAIL KONOVALOV	{"phone": "+70018745943"}
0005434458567	728F32	8710 272620	OLGA MELNIKOVA	{"email": "olga.melnikova.1978@postgrespro.ru", "phone": "+70668787191"}
0005434458568	747619	2859 342096	ANTONINA SIDOROVA	{"email": "antonina_sidorova.041969@postgrespro.ru", "phone": "+70884412732"}
0005434458569	6B4A6D	7299 607575	ALEKSANDR KRASNOV	{"phone": "+70424134019"}
0005434458570	61267B	6022 716403	MIKHAIL DAVYDOV	{"phone": "+70166605688"}
0005434458571	61267B	5054 354474	ANATOLIY VLASOV	{"email": "vlasov-a.18111977@postgrespro.ru", "phone": "+70698626143"}
0005434458572	9451BB	8349 138793	ARTEM FROLOV	{"email": "artemfrolov.1964@postgrespro.ru", "phone": "+70345721393"}
0005434458573	9451BB	1692 010830	ALENA NIKOLAEVA	{"email": "nikolaeva.alena_1970@postgrespro.ru", "phone": "+70106577997"}
0005434458574	EA5749	5732 111854	NATALYA MAKAROVA	{"email": "nmakarova-1970@postgrespro.ru", "phone": "+70290945199"}
0005434458575	9C9A6E	7949 672617	ANTON MATVEEV	{"phone": "+70352127351"}
0005434458576	FB11FF	2174 840510	LILIYA FILATOVA	{"email": "filatova_liliya_051974@postgrespro.ru", "phone": "+70264212820"}
0005434458577	FB11FF	8163 198595	PELAGEYA NIKITINA	{"email": "nikitina.p-17111971@postgrespro.ru", "phone": "+70223806099"}
0005434458578	34D94B	3786 899541	DMITRIY KUZNECOV	{"phone": "+70689063320"}
0005434458633	7EDD44	9979 656885	MIKHAIL KUZNECOV	{"phone": "+70478466317"}
0005434458579	34D94B	4258 276963	ANASTASIYA ROMANOVA	{"email": "romanovaanastasiya-11011972@postgrespro.ru", "phone": "+70961368192"}
0005434458580	645AC6	7586 495728	YURIY BONDARENKO	{"email": "bondarenkoyuriy121979@postgrespro.ru", "phone": "+70530474451"}
0005434458581	645AC6	0445 521070	LYUDMILA ANDREEVA	{"phone": "+70339687145"}
0005434458582	645AC6	0445 619364	ARTEM FOMIN	{"email": "a-fomin111975@postgrespro.ru", "phone": "+70915023333"}
0005434458583	32C707	8550 765178	NATALYA YAKOVLEVA	{"email": "yakovlevanatalya-1981@postgrespro.ru", "phone": "+70795710150"}
0005434458584	ED497C	8560 526322	ALEKSANDR KUZMIN	{"phone": "+70368987482"}
0005434458585	ED497C	1694 537677	BORIS MIRONOV	{"phone": "+70023547469"}
0005434458586	39D238	2288 592059	MAKSIM SEMENOV	{"email": "semenov-m.30071968@postgrespro.ru", "phone": "+70755170657"}
0005434458587	64AB51	4720 935329	ANASTASIYA KISELEVA	{"phone": "+70561235960"}
0005434458588	64AB51	2013 844482	ALEKSANDR VASILEV	{"phone": "+70078944342"}
0005434458589	AC3922	5173 293589	GALINA KUZNECOVA	{"phone": "+70584722147"}
0005434458590	280EFC	6487 214488	ARTEM VOLKOV	{"email": "volkova-051973@postgrespro.ru", "phone": "+70067115118"}
0005434458591	280EFC	1597 840100	SEMEN SIDOROV	{"phone": "+70893037269"}
0005434458592	31A32B	4429 656533	OLGA ORLOVA	{"email": "orlova_olga11051980@postgrespro.ru", "phone": "+70717023831"}
0005434458593	F0273B	1801 475985	NATALYA POLYAKOVA	{"email": "polyakova-natalya_041989@postgrespro.ru", "phone": "+70956280363"}
0005434458594	F0273B	9197 745916	GULFIYA ALEKSANDROVA	{"email": "g_aleksandrova121979@postgrespro.ru", "phone": "+70804581266"}
0005434458595	F0273B	8622 597967	ALINA ZHURAVLEVA	{"phone": "+70410928376"}
0005434458596	9395F3	0055 574126	VALENTINA ILINA	{"phone": "+70474561721"}
0005434458597	5EFEC6	5233 963446	ROMAN ZHURAVLEV	{"email": "zhuravlev.roman.18061970@postgrespro.ru", "phone": "+70548341009"}
0005434458598	524541	5108 943168	TATYANA KRASNOVA	{"email": "krasnova.t-19061954@postgrespro.ru", "phone": "+70733211043"}
0005434458599	2F8DD3	4253 680979	EKATERINA DMITRIEVA	{"email": "dmitrieva_ekaterina-081965@postgrespro.ru", "phone": "+70260154723"}
0005434458600	2F8DD3	2951 924621	VLADIMIR KAZAKOV	{"phone": "+70863140319"}
0005434458601	D59802	3481 912837	SVETLANA KRASNOVA	{"phone": "+70480683877"}
0005434458602	D59802	3793 248716	VITALIY VASILEV	{"email": "vitaliy-vasilev_071979@postgrespro.ru", "phone": "+70706021177"}
0005434458603	DA0585	7177 184653	EMMA TITOVA	{"email": "titova-emma051976@postgrespro.ru", "phone": "+70752657090"}
0005434458604	DBF6A2	8769 226041	ALEKSEY FROLOV	{"email": "frolova041967@postgrespro.ru", "phone": "+70180724705"}
0005434458605	DBF6A2	9494 938120	TAMARA NIKITINA	{"email": "tamara.nikitina.15031965@postgrespro.ru", "phone": "+70220339380"}
0005434458606	DB0619	9696 498484	NIKOLAY POPOV	{"email": "n.popov121972@postgrespro.ru", "phone": "+70628524615"}
0005434458607	9311EE	9241 946379	ELENA DANILOVA	{"phone": "+70221014602"}
0005434458608	F31DF1	6320 471728	VIKTOR NAUMOV	{"email": "viktor_naumov071969@postgrespro.ru", "phone": "+70613910837"}
0005434458609	5CC6BB	9158 722215	LYUDMILA MIKHAYLOVA	{"email": "lyudmilamikhaylova.121968@postgrespro.ru", "phone": "+70434056258"}
0005434458610	90C438	2379 550454	ILYA VASILEV	{"email": "vasilevi-20051961@postgrespro.ru", "phone": "+70918090747"}
0005434458611	6D3F8B	9328 420760	ALEKSEY ZAYCEV	{"email": "zaycev_a_25051974@postgrespro.ru", "phone": "+70501578324"}
0005434458612	485AF0	8529 060408	DMITRIY MOISEEV	{"email": "d-moiseev_041976@postgrespro.ru", "phone": "+70825415173"}
0005434458613	485AF0	3707 067446	KRISTINA KUZNECOVA	{"email": "kuznecova_k15071970@postgrespro.ru", "phone": "+70180729105"}
0005434458614	5797C7	4114 863622	NATALYA KOROLEVA	{"email": "natalya-koroleva_1976@postgrespro.ru", "phone": "+70776565075"}
0005434458615	26A4E1	3494 832942	GALINA MEDVEDEVA	{"email": "g-medvedeva061973@postgrespro.ru", "phone": "+70539851397"}
0005434458616	F6D1AB	7137 748447	LYUBOV PAVLOVA	{"email": "l_pavlova081978@postgrespro.ru", "phone": "+70957597678"}
0005434458617	F6D1AB	8334 294517	OLEG VASILEV	{"email": "oleg-vasilev051977@postgrespro.ru", "phone": "+70948733765"}
0005434458618	AFB57D	3227 026408	OKSANA MELNIKOVA	{"email": "melnikova_oksana.27041957@postgrespro.ru", "phone": "+70312027465"}
0005434458619	CAEEDC	9260 479551	DAVID FROLOV	{"email": "dfrolov.15121986@postgrespro.ru", "phone": "+70778618786"}
0005434458620	12B5CA	6476 265808	MARIYA NOVIKOVA	{"email": "mariya.novikova-16081976@postgrespro.ru", "phone": "+70319288605"}
0005434458621	D750CF	4960 651884	SOFIYA TITOVA	{"phone": "+70049877994"}
0005434458622	D750CF	1294 225334	TAMARA NAZAROVA	{"email": "nazarovatamara_27071972@postgrespro.ru", "phone": "+70603995367"}
0005434458624	162B89	3709 669383	RAIS PETROV	{"phone": "+70374379679"}
0005434458625	B3A607	3717 819284	ALEFTINA ANTONOVA	{"email": "aleftinaantonova-1965@postgrespro.ru", "phone": "+70830819755"}
0005434458626	1C1F5D	5920 699249	ALEKSANDR KAZAKOV	{"phone": "+70774291337"}
0005434458627	1C1F5D	0159 735495	SERGEY NIKOLAEV	{"email": "s-nikolaev.01031982@postgrespro.ru", "phone": "+70617478886"}
0005434458628	26AF89	4480 716756	GENNADIY MAKSIMOV	{"email": "maksimov.gennadiy-10081972@postgrespro.ru", "phone": "+70876189161"}
0005434458629	791841	4775 022501	TAMARA FROLOVA	{"email": "tamara-frolova_1976@postgrespro.ru", "phone": "+70008973521"}
0005434458630	4414BA	0137 320154	VIKTOR DMITRIEV	{"phone": "+70873936978"}
0005434458631	0AA8E6	3908 057534	VIKTOR SIDOROV	{"phone": "+70798982622"}
0005434458632	7EDD44	6238 923160	MARIYA FADEEVA	{"email": "m.fadeeva07041972@postgrespro.ru", "phone": "+70718472826"}
0005434458634	B51067	8202 903114	ANASTASIYA VOLKOVA	{"email": "volkova-a_1968@postgrespro.ru", "phone": "+70373625935"}
0005434458635	E0F34C	1629 010273	DMITRIY MOROZOV	{"phone": "+70062022298"}
0005434458636	82B4EF	8119 806556	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-27121976@postgrespro.ru", "phone": "+70903173173"}
0005434458637	A36230	8426 131154	NADIYA NIKITINA	{"email": "nikitina-nadiya-1968@postgrespro.ru", "phone": "+70122053321"}
0005434458638	C8BD83	5153 451568	ANASTASIYA KUZMINA	{"phone": "+70642322966"}
0005434458639	7AC5A7	6515 350202	ANATOLIY STEPANOV	{"phone": "+70674449772"}
0005434458640	722CEC	8742 046183	ALEKSEY MOISEEV	{"phone": "+70839459430"}
0005434458641	5FB1E2	1276 255568	LYUDMILA MAKAROVA	{"email": "makarovalyudmila_04011982@postgrespro.ru", "phone": "+70742145011"}
0005434458642	A625E4	5309 622969	OKSANA FOMINA	{"email": "fomina_oksana.15101979@postgrespro.ru", "phone": "+70920973612"}
0005434458643	A625E4	4814 003594	LEV ABRAMOV	{"phone": "+70877770441"}
0005434458644	A625E4	9171 266172	YURIY SMIRNOV	{"email": "y_smirnov121979@postgrespro.ru", "phone": "+70928290273"}
0005434458645	02CB91	1994 446670	VIKTOR ILIN	{"phone": "+70667860948"}
0005434458646	02CB91	5020 179742	OLGA KALININA	{"phone": "+70507663080"}
0005434458647	BCB93C	9594 130866	DANILA ZHUKOV	{"email": "zhukov-danila081960@postgrespro.ru", "phone": "+70754639877"}
0005434458648	5AA45D	8151 942201	ZINAIDA FOMINA	{"phone": "+70523701519"}
0005434458649	1BD164	7218 617528	MAKSIM FEDOROV	{"phone": "+70656813497"}
0005434458650	1BD164	4604 176970	NATALYA TARASOVA	{"phone": "+70533795662"}
0005434458651	679D99	6820 639448	RAISA MATVEEVA	{"email": "rmatveeva_1974@postgrespro.ru", "phone": "+70827204778"}
0005434458652	679D99	4902 518123	MIKHAIL BONDARENKO	{"phone": "+70282880149"}
0005434458653	679D99	5840 684376	ELVIRA GUSEVA	{"phone": "+70375478872"}
0005434458654	10CC0F	0851 337340	TATYANA RODIONOVA	{"email": "t.rodionova_1980@postgrespro.ru", "phone": "+70490750551"}
0005434458655	DCA382	6410 940211	DMITRIY FOMIN	{"email": "dmitriyfomin-08091964@postgrespro.ru", "phone": "+70710917100"}
0005434458656	CC41CD	9195 770304	DMITRIY ROMANOV	{"phone": "+70966931668"}
0005434458657	32CA63	2148 345595	ALEKSANDR ROMANOV	{"email": "romanov.a_061964@postgrespro.ru", "phone": "+70165812756"}
0005434458658	29122C	2084 812730	NADEZHDA YAKOVLEVA	{"email": "yakovleva_nadezhda1963@postgrespro.ru", "phone": "+70894040127"}
0005434458659	922029	9512 617530	GYUZEL KUZNECOVA	{"phone": "+70383120238"}
0005434458660	922029	3589 003386	GALINA DMITRIEVA	{"phone": "+70591303534"}
0005434458661	0097BD	1755 899598	VLADIMIR TARASOV	{"email": "vladimirtarasov-20071968@postgrespro.ru", "phone": "+70282693186"}
0005434458662	0097BD	3442 546260	EVGENIY FOMIN	{"phone": "+70382324620"}
0005434458663	8F50A5	3267 139675	VLADISLAV MEDVEDEV	{"phone": "+70313405928"}
0005434458664	8A7850	1840 472724	ELENA GAVRILOVA	{"email": "elena.gavrilova_051974@postgrespro.ru", "phone": "+70720682171"}
0005434458665	8A7850	3367 013742	MIKHAIL ISAEV	{"phone": "+70864156759"}
0005434458666	06C59E	9392 612244	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir_05061979@postgrespro.ru", "phone": "+70291491253"}
0005434458667	1EEF6B	5705 932135	VALENTINA KUDRYASHOVA	{"email": "kudryashova_v_20021963@postgrespro.ru", "phone": "+70764720157"}
0005434458668	128FE8	6897 291512	SERGEY SMIRNOV	{"phone": "+70497528443"}
0005434458669	FB7191	4202 964690	IRINA STEPANOVA	{"phone": "+70830579281"}
0005434458670	DBF8D5	2704 830621	RAFIK ROMANOV	{"email": "rafik-romanov_1983@postgrespro.ru", "phone": "+70249694577"}
0005434458671	2D7485	5467 353519	ANDREY VOLKOV	{"phone": "+70292549188"}
0005434458672	2D7485	9534 376084	TIMOFEY KUZNECOV	{"email": "kuznecov.timofey-121980@postgrespro.ru", "phone": "+70795681009"}
0005434458673	036ACD	6489 646501	VLADIMIR SCHERBAKOV	{"phone": "+70933856212"}
0005434458674	036ACD	7513 140652	MARIYA BORISOVA	{"phone": "+70211465885"}
0005434458675	58B76A	6340 625849	KLAVDIYA TITOVA	{"email": "klavdiya_titova_15011971@postgrespro.ru", "phone": "+70967663069"}
0005434458676	BBD8D4	0968 824757	YULIYA PETROVA	{"phone": "+70792939025"}
0005434458677	0F7152	2699 281945	LYUDMILA NESTEROVA	{"email": "nesterova_l06091966@postgrespro.ru", "phone": "+70968723820"}
0005434458678	0F7152	6957 226248	MARIYA GERASIMOVA	{"phone": "+70326873095"}
0005434458679	E14B6B	6775 513257	OLGA FILATOVA	{"email": "o.filatova-1979@postgrespro.ru", "phone": "+70338821689"}
0005434458680	D9A7EB	7656 796776	ARTEM GERASIMOV	{"phone": "+70731034445"}
0005434458681	CDE75A	6687 148677	NATALYA SAVELEVA	{"email": "natalyasaveleva-031975@postgrespro.ru", "phone": "+70847566768"}
0005434458682	CDE75A	8869 843682	YURIY SERGEEV	{"email": "ysergeev-011974@postgrespro.ru", "phone": "+70858477179"}
0005434458683	D75DA0	2457 067919	SERGEY ORLOV	{"email": "orlovs06091965@postgrespro.ru", "phone": "+70445055620"}
0005434458684	47A438	2099 332439	LYUBOV KISELEVA	{"email": "kiseleva-lyubov.1967@postgrespro.ru", "phone": "+70232485242"}
0005434458685	47A438	9898 006318	SERGEY CHERNOV	{"email": "chernov-sergey06031965@postgrespro.ru", "phone": "+70762556003"}
0005434458686	E450EF	4597 558875	ILYA KISELEV	{"phone": "+70344340383"}
0005434458687	E450EF	1476 374689	TATYANA ANTONOVA	{"phone": "+70711013175"}
0005434458688	3F689A	8796 380292	GALINA LUKYANOVA	{"phone": "+70489107365"}
0005434458689	3F689A	8203 490095	OLEG TARASOV	{"phone": "+70036805707"}
0005434458690	1DF2C7	3739 230865	SERGEY ABRAMOV	{"phone": "+70085962908"}
0005434458691	7A4305	4763 502697	ANATOLIY ZHURAVLEV	{"email": "zhuravlev_anatoliy_1968@postgrespro.ru", "phone": "+70313649879"}
0005434458692	7A4305	3942 777659	TATYANA MATVEEVA	{"email": "matveevatatyana-02081981@postgrespro.ru", "phone": "+70182635544"}
0005434458693	C99141	7331 706454	VERA KISELEVA	{"phone": "+70236131881"}
0005434458694	74DE0C	8272 041809	SVETLANA ZAKHAROVA	{"email": "zakharova_s_1971@postgrespro.ru", "phone": "+70730106389"}
0005434458695	A152EE	9059 926504	ANNA NIKITINA	{"phone": "+70318899460"}
0005434458696	8A2014	7616 508434	VADIM MOISEEV	{"phone": "+70671296597"}
0005434458697	8A2014	1548 399477	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev071975@postgrespro.ru", "phone": "+70339339845"}
0005434458698	9932D8	6762 908074	ANNA DENISOVA	{"email": "denisova_anna-1984@postgrespro.ru", "phone": "+70141958467"}
0005434458699	305A5D	1253 456449	DMITRIY MATVEEV	{"phone": "+70234243107"}
0005434458700	305A5D	5848 527164	TATYANA KOLESNIKOVA	{"email": "t_kolesnikova-011971@postgrespro.ru", "phone": "+70429395435"}
0005434458701	2146FC	5604 485408	ANASTASIYA KOZLOVA	{"email": "a.kozlova.12051971@postgrespro.ru", "phone": "+70908699342"}
0005434458702	7E367C	3538 280548	EVGENIY ANTONOV	{"phone": "+70699562613"}
0005434458703	F7EA91	5639 000663	NINA DANILOVA	{"email": "danilova-n_1963@postgrespro.ru", "phone": "+70738397477"}
0005434458704	F7EA91	9655 812623	ANNA TARASOVA	{"phone": "+70286768342"}
0005434458705	040781	2008 801700	VALENTINA KOZLOVA	{"email": "v_kozlova.03021969@postgrespro.ru", "phone": "+70645508239"}
0005434458706	040781	8841 950366	ANTONINA SOLOVEVA	{"phone": "+70848275670"}
0005434458707	B0B9C2	5533 390729	LYUBOV LOGINOVA	{"phone": "+70227368121"}
0005434458708	0ED031	3774 915322	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova.1967@postgrespro.ru", "phone": "+70049635235"}
0005434458709	83CE92	6775 888463	ANATOLIY NAZAROV	{"phone": "+70154358055"}
0005434458710	83CE92	3183 344004	ELENA KUZNECOVA	{"phone": "+70428378921"}
0005434458711	83CE92	6940 987657	MARIYA NOVIKOVA	{"email": "novikova.m01121979@postgrespro.ru", "phone": "+70588117383"}
0005434458712	E649DF	9915 356317	KSENIYA POLYAKOVA	{"email": "k_polyakova_17011980@postgrespro.ru", "phone": "+70415616133"}
0005434458713	E649DF	1333 035316	MARINA TITOVA	{"email": "mtitova.081978@postgrespro.ru", "phone": "+70252970682"}
0005434458714	C05DC8	0259 524985	MAKSIM SMIRNOV	{"email": "m_smirnov-28101965@postgrespro.ru", "phone": "+70533494893"}
0005434458715	C05DC8	7513 033453	VLADIMIR BELOV	{"email": "v_belov15021969@postgrespro.ru", "phone": "+70909935256"}
0005434458716	C05DC8	8121 625031	VLADIMIR BELOV	{"email": "vladimir-belov.24021964@postgrespro.ru", "phone": "+70592975945"}
0005434458717	99A45F	0629 023536	ANNA ERMAKOVA	{"phone": "+70992707038"}
0005434458718	13326C	5743 111629	YURIY PAVLOV	{"email": "pavlov-y_15041976@postgrespro.ru", "phone": "+70644000385"}
0005434458719	D60BB6	4722 780181	ALEKSANDR KUZNECOV	{"phone": "+70759622511"}
0005434458720	D60BB6	3880 727651	VALENTIN PAVLOV	{"email": "pavlovv.1972@postgrespro.ru", "phone": "+70615094687"}
0005434458721	474BE2	1379 326253	ILYA DMITRIEV	{"email": "dmitrievilya.101964@postgrespro.ru", "phone": "+70481471396"}
0005434458722	474BE2	8769 356442	VITALIY ALEKSEEV	{"email": "valekseev_1968@postgrespro.ru", "phone": "+70083075173"}
0005434458723	2B9336	3064 179100	ALEKSEY TIKHONOV	{"phone": "+70042944973"}
0005434458724	2B9336	0452 361412	ALEKSANDR BELOV	{"phone": "+70830572138"}
0005434458725	08C33F	3918 067882	YURIY PAVLOV	{"email": "yuriy-pavlov.25021974@postgrespro.ru", "phone": "+70862974346"}
0005434458726	08C33F	4390 480585	VIKTOR KULIKOV	{"email": "kulikov_viktor.17091969@postgrespro.ru", "phone": "+70518735556"}
0005434458727	2A2EEA	7029 124673	ALEKSANDR FROLOV	{"email": "a.frolov_061971@postgrespro.ru", "phone": "+70293305050"}
0005434458728	859499	4495 360215	RAVIL IVANOV	{"phone": "+70524780897"}
0005434458729	BCDF2F	2012 836385	NADEZHDA KRASNOVA	{"phone": "+70835798491"}
0005434458730	BCDF2F	2256 930968	EVGENIY KONOVALOV	{"email": "konovalov_evgeniy.1982@postgrespro.ru", "phone": "+70349056258"}
0005434458731	98A12F	1674 850843	LYUDMILA PETROVA	{"email": "petrova_l041981@postgrespro.ru", "phone": "+70543106825"}
0005434458732	98A12F	0834 139219	ALEKSEY MATVEEV	{"email": "matveevaleksey.011974@postgrespro.ru", "phone": "+70910526476"}
0005434458733	EFC750	8926 581537	FARID SOLOVEV	{"email": "solovevfarid.021981@postgrespro.ru", "phone": "+70821806690"}
0005434458734	DA450B	8183 521303	ANASTASIYA NIKITINA	{"phone": "+70534839516"}
0005434458735	CE7C4C	9880 593655	ELENA MIRONOVA	{"email": "mironova_e18071969@postgrespro.ru", "phone": "+70089904349"}
0005434458736	CE7C4C	1731 057349	ALEKSEY KOZLOV	{"email": "a.kozlov-1980@postgrespro.ru", "phone": "+70371814932"}
0005434458737	77B87A	6821 097514	ELENA BELYAEVA	{"phone": "+70098748960"}
0005434458738	7E12DD	7100 570638	MARINA KOMAROVA	{"email": "komarova-m-081969@postgrespro.ru", "phone": "+70799445438"}
0005434458739	EAB973	1368 389385	NINA RODIONOVA	{"phone": "+70305737595"}
0005434458740	168424	3429 880361	ALLA KONDRATEVA	{"phone": "+70986634447"}
0005434458741	9361F3	5924 403546	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr.20061978@postgrespro.ru", "phone": "+70104491795"}
0005434458742	9361F3	8903 497184	VERA SEMENOVA	{"email": "semenova_v071985@postgrespro.ru", "phone": "+70475778744"}
0005434458743	C45521	2753 014092	PAVEL MAKAROV	{"email": "makarov.p.111972@postgrespro.ru", "phone": "+70998729241"}
0005434458744	AF7E9D	8438 350837	ANATOLIY ABRAMOV	{"email": "abramova1960@postgrespro.ru", "phone": "+70468794949"}
0005434458745	50C6AE	9491 782043	IGOR ALEKSANDROV	{"email": "i-aleksandrov.19111958@postgrespro.ru", "phone": "+70503130394"}
0005434458746	361C0E	5710 771200	OLGA STEPANOVA	{"email": "stepanovaolga24101964@postgrespro.ru", "phone": "+70552704146"}
0005434458747	361C0E	2105 544950	TATYANA KOROLEVA	{"email": "korolevat071978@postgrespro.ru", "phone": "+70515004089"}
0005434458748	361C0E	0925 017985	ANDREY ILIN	{"email": "ilina.091978@postgrespro.ru", "phone": "+70881453432"}
0005434458749	CF8F6A	7608 786190	ANDREY KISELEV	{"phone": "+70398024906"}
0005434458750	5E8199	4332 919219	LEONID BORISOV	{"email": "lborisov-06091974@postgrespro.ru", "phone": "+70299978693"}
0005434458751	5E8199	7101 601103	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr06071972@postgrespro.ru", "phone": "+70711847851"}
0005434458752	439547	1341 844795	ANNA LEBEDEVA	{"email": "lebedevaa.071972@postgrespro.ru", "phone": "+70279550306"}
0005434458753	2C143D	8510 776365	STEPAN GAVRILOV	{"phone": "+70997651928"}
0005434458754	2C143D	6463 837562	GALINA FROLOVA	{"email": "g-frolova-1972@postgrespro.ru", "phone": "+70564769999"}
0005434458755	2C143D	3500 969996	MARINA ANTONOVA	{"phone": "+70190880122"}
0005434458756	553FE9	7028 557623	NATALYA MASLOVA	{"email": "n_maslova1960@postgrespro.ru", "phone": "+70722917882"}
0005434458757	553FE9	4568 713209	KLAVDIYA MOISEEVA	{"email": "klavdiya_moiseeva-041969@postgrespro.ru", "phone": "+70513958134"}
0005434458758	D93359	5258 688682	MARIYA KUZNECOVA	{"email": "kuznecovamariya011971@postgrespro.ru", "phone": "+70028962457"}
0005434458759	8AC5F9	0975 510282	SVETLANA VLASOVA	{"phone": "+70205909698"}
0005434458760	6C9E9B	9289 890870	IVAN ILIN	{"email": "i.ilin.111961@postgrespro.ru", "phone": "+70928898160"}
0005434458761	6C9E9B	0176 053954	ELENA ABRAMOVA	{"phone": "+70761263047"}
0005434458762	6C9E9B	2615 173671	GEORGIY ZAKHAROV	{"phone": "+70857465845"}
0005434458763	EF8578	8936 485421	MATVEY KUZNECOV	{"email": "kuznecov-matvey-15101972@postgrespro.ru", "phone": "+70986613750"}
0005434458764	EF8578	0671 747135	PAVEL POPOV	{"phone": "+70908944705"}
0005434458765	1D7C08	3770 801639	ANATOLIY KULIKOV	{"email": "a_kulikov_071983@postgrespro.ru", "phone": "+70879597226"}
0005434458766	9DC695	9304 994168	ANDREY FEDOTOV	{"email": "andrey_fedotov_021975@postgrespro.ru", "phone": "+70094791121"}
0005434458767	9DC695	7217 978346	ELENA POPOVA	{"phone": "+70033041683"}
0005434458768	7BB75D	8555 312651	AMIR OSIPOV	{"phone": "+70497220026"}
0005434458769	6D6655	3715 759231	SERGEY OSIPOV	{"phone": "+70314877261"}
0005434458770	77CFC3	1432 945153	VALENTINA KOLESNIKOVA	{"email": "kolesnikova-v_25121978@postgrespro.ru", "phone": "+70604509337"}
0005434458771	856B2D	5021 528852	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.13011975@postgrespro.ru", "phone": "+70126602341"}
0005434458772	FA4478	9476 609837	DARYA TROFIMOVA	{"phone": "+70743922103"}
0005434458773	FA4478	0757 663997	SVETLANA KUZNECOVA	{"email": "s-kuznecova_22031977@postgrespro.ru", "phone": "+70004031027"}
0005434458774	70AAA1	7923 869470	VIKTORIYA DENISOVA	{"email": "viktoriya_denisova-19121967@postgrespro.ru", "phone": "+70865005519"}
0005434458775	738EDA	1400 935940	MIKHAIL ANDREEV	{"email": "andreev_mikhail_1973@postgrespro.ru", "phone": "+70864621480"}
0005434458776	738EDA	3301 540858	RAMIL BELOV	{"email": "belov_ramil.29071969@postgrespro.ru", "phone": "+70298407816"}
0005434458777	0617E0	1001 053869	NIKOLAY SCHERBAKOV	{"phone": "+70517900679"}
0005434458778	11AF72	6529 732286	DMITRIY NIKITIN	{"phone": "+70274267368"}
0005434458779	75A34A	0201 402540	ANNA MOISEEVA	{"email": "moiseeva-anna25041976@postgrespro.ru", "phone": "+70656712184"}
0005434458780	75A34A	9813 287571	ELENA MAKAROVA	{"email": "makarova-elena_1983@postgrespro.ru", "phone": "+70609596848"}
0005434458781	890E19	9227 583684	LYUCIYA SCHERBAKOVA	{"phone": "+70566656164"}
0005434458782	890E19	2739 345514	ALEKSANDR KAZAKOV	{"phone": "+70469990161"}
0005434458783	7BAFDF	1513 746894	SERGEY POPOV	{"phone": "+70458374608"}
0005434458784	93B3B2	2480 318147	KIRILL BORISOV	{"email": "borisovkirill_121979@postgrespro.ru", "phone": "+70240580459"}
0005434458785	343A64	3407 435171	ALEKSANDR NAUMOV	{"phone": "+70532282669"}
0005434458786	343A64	3001 481976	VALENTINA YUDINA	{"phone": "+70424026097"}
0005434458787	FC1F29	3984 092828	MARIYA NIKITINA	{"phone": "+70425402684"}
0005434458788	6C7F37	7008 335332	GALINA ILINA	{"email": "ilina_galina.1972@postgrespro.ru", "phone": "+70446718337"}
0005434458789	0F4AE8	6120 983997	YULIYA GERASIMOVA	{"email": "y_gerasimova_1976@postgrespro.ru", "phone": "+70769942165"}
0005434458790	0F4AE8	3746 756394	DMITRIY MOROZOV	{"email": "d-morozov.101970@postgrespro.ru", "phone": "+70050683833"}
0005434458791	F2402C	4058 986799	RAISA TIKHONOVA	{"phone": "+70379655759"}
0005434458792	1B6E76	3900 749332	SERGEY SEMENOV	{"phone": "+70044672329"}
0005434458793	1B6E76	0184 397521	OLGA MASLOVA	{"email": "maslovaolga-101970@postgrespro.ru", "phone": "+70142386723"}
0005434458794	1B6E76	0328 075226	MIKHAIL PETROV	{"phone": "+70118006581"}
0005434458795	1BBE24	9950 928985	EVGENIYA VASILEVA	{"phone": "+70646478211"}
0005434458796	485662	9397 602422	EDUARD MELNIKOV	{"phone": "+70071260830"}
0005434458797	FD5E8B	3388 376757	GALINA BELOVA	{"email": "belovagalina_12101965@postgrespro.ru", "phone": "+70347303092"}
0005434458798	FD5E8B	3468 044869	VLADIMIR ABRAMOV	{"phone": "+70912425802"}
0005434458799	9B90F3	9217 820645	MARIYA ZAYCEVA	{"email": "zayceva_mariya_03111968@postgrespro.ru", "phone": "+70443192428"}
0005434458800	9065AF	5174 454078	VERA BOGDANOVA	{"phone": "+70405442734"}
0005434458801	9065AF	6346 603631	VIKTOR SAVELEV	{"email": "savelevviktor15071969@postgrespro.ru", "phone": "+70280944165"}
0005434458802	68F1FE	0885 764700	VLADIMIR FOMIN	{"phone": "+70273319923"}
0005434458803	E45ABA	7187 600019	NATALYA FEDOROVA	{"email": "fedorova-n11021973@postgrespro.ru", "phone": "+70902433778"}
0005434458804	5E43E4	2658 627559	NATALYA ILINA	{"email": "ilina_n_02121986@postgrespro.ru", "phone": "+70997852578"}
0005434458805	C50C70	8232 187185	ALEKSEY ROMANOV	{"phone": "+70466386419"}
0005434458806	C50C70	6404 827557	NADEZHDA MIKHAYLOVA	{"phone": "+70612928982"}
0005434458807	74996F	3576 020360	NINA NIKOLAEVA	{"email": "nikolaeva_nina_1977@postgrespro.ru", "phone": "+70353932050"}
0005434458808	74996F	2948 862606	GALINA NIKITINA	{"phone": "+70562540955"}
0005434458809	74996F	6513 676662	VALENTINA BORISOVA	{"email": "vborisova-15071979@postgrespro.ru", "phone": "+70517730340"}
0005434458810	309741	1961 556201	ALLA PETROVA	{"phone": "+70693467679"}
0005434458811	0AC59E	6606 730725	ALEKSANDRA KOROLEVA	{"phone": "+70576642729"}
0005434458812	C43CEA	0054 322241	VLADA POPOVA	{"phone": "+70347869101"}
0005434458813	D60B07	6959 947214	LILIYA LUKYANOVA	{"phone": "+70703202532"}
0005434458814	3396A5	4785 985450	ANDREY NIKOLAEV	{"phone": "+70562223695"}
0005434458815	E7BF44	7861 953127	NIKOLAY IVANOV	{"phone": "+70949888147"}
0005434458816	5B0225	6204 592828	IVAN MAKSIMOV	{"email": "maksimov-ivan1970@postgrespro.ru", "phone": "+70891175612"}
0005434458817	830A93	8928 770730	YURIY VOLKOV	{"email": "volkov_yuriy18051975@postgrespro.ru", "phone": "+70171913907"}
0005434458818	20DB7F	3863 324885	POLINA KOZLOVA	{"email": "kozlova.p.081973@postgrespro.ru", "phone": "+70267681606"}
0005434458819	20DB7F	4251 800894	VIKTORIYA BELOVA	{"email": "belovav-1971@postgrespro.ru", "phone": "+70080500181"}
0005434458820	20DB7F	2833 126712	OKSANA AKIMOVA	{"email": "o_akimova.081970@postgrespro.ru", "phone": "+70562633049"}
0005434458876	27D41F	7984 003306	TATYANA VASILEVA	{"phone": "+70371808865"}
0005434458821	A5EB6E	1718 837335	EVGENIY DAVYDOV	{"email": "edavydov27061967@postgrespro.ru", "phone": "+70959754254"}
0005434458822	C36273	9312 855371	KLAVDIYA STEPANOVA	{"email": "stepanova_k.091979@postgrespro.ru", "phone": "+70576887543"}
0005434458823	DA2840	3052 499902	DANIIL ILIN	{"phone": "+70320611878"}
0005434458824	60486D	5404 001012	VYACHESLAV ZHUKOV	{"email": "zhukov-vyacheslav1967@postgrespro.ru", "phone": "+70521872062"}
0005434458825	8EDC97	0668 746363	LIDIYA VLASOVA	{"phone": "+70785065717"}
0005434458826	8EDC97	7185 322243	ALEKSEY ROMANOV	{"email": "romanovaleksey011969@postgrespro.ru", "phone": "+70560860147"}
0005434458827	D63644	2403 968492	ELENA KUZMINA	{"email": "kuzmina_e.031969@postgrespro.ru", "phone": "+70847058137"}
0005434458828	2EC083	7792 871364	VLADIMIR KUZMIN	{"email": "kuzmin.v-021975@postgrespro.ru", "phone": "+70153729973"}
0005434458829	AE2CF7	2107 597002	SERGEY SOROKIN	{"phone": "+70356551402"}
0005434458830	AC85C1	7105 463848	VALENTINA KUZMINA	{"email": "valentina-kuzmina1982@postgrespro.ru", "phone": "+70888898559"}
0005434458831	78F7AE	6957 893358	VERA EFIMOVA	{"phone": "+70256908458"}
0005434458832	B05485	9717 158024	ANASTASIYA ZAKHAROVA	{"phone": "+70776412541"}
0005434458833	B05485	1239 048149	ANASTASIYA TARASOVA	{"email": "anastasiya.tarasova1978@postgrespro.ru", "phone": "+70988051597"}
0005434458834	EB24BE	7196 040795	VYACHESLAV KRASNOV	{"phone": "+70194559639"}
0005434458835	9BD884	1049 941305	VALENTINA BORISOVA	{"email": "borisovavalentina_1976@postgrespro.ru", "phone": "+70430440578"}
0005434458836	FAF46F	6633 561627	VLADIMIR MELNIKOV	{"email": "melnikov_v_041978@postgrespro.ru", "phone": "+70100589242"}
0005434458837	FAF46F	9226 564924	GALINA NIKIFOROVA	{"email": "gnikiforova.16031965@postgrespro.ru", "phone": "+70333028628"}
0005434458838	11DAE1	8583 369914	NATALYA LUKYANOVA	{"email": "n_lukyanova_10011977@postgrespro.ru", "phone": "+70189358579"}
0005434458839	081CEC	1369 256339	NATALYA CHERNOVA	{"email": "natalya-chernova.091979@postgrespro.ru", "phone": "+70477012954"}
0005434458840	A14CCC	0544 772078	ANDREY BONDARENKO	{"email": "bondarenkoandrey.071974@postgrespro.ru", "phone": "+70917495998"}
0005434458841	84B299	1471 127899	ELENA SEMENOVA	{"email": "semenova.e_1979@postgrespro.ru", "phone": "+70565024340"}
0005434458842	84B299	8337 971213	MARINA KUZNECOVA	{"email": "mkuznecova.1990@postgrespro.ru", "phone": "+70924554665"}
0005434458843	84B299	4578 532118	VALERIY KUZNECOV	{"email": "kuznecovvaleriy051969@postgrespro.ru", "phone": "+70389328606"}
0005434458844	71FC58	7048 429237	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr_051977@postgrespro.ru", "phone": "+70598274631"}
0005434458845	945075	8441 307567	VADIM POPOV	{"phone": "+70845102748"}
0005434458846	75879D	0933 102842	VLADIMIR FOMIN	{"email": "vladimir-fomin_1980@postgrespro.ru", "phone": "+70854317532"}
0005434458847	75879D	9440 521183	RUSLAN ORLOV	{"email": "orlov_r.02081975@postgrespro.ru", "phone": "+70010240560"}
0005434458848	4FC776	7609 831191	YULIYA SERGEEVA	{"phone": "+70804811263"}
0005434458849	4FC776	8681 350409	IRINA STEPANOVA	{"phone": "+70462123376"}
0005434458850	E2F33E	4460 990411	ELENA MAKAROVA	{"phone": "+70211580456"}
0005434458851	7E8A12	0428 462579	YURIY KISELEV	{"email": "kiselev.y_071978@postgrespro.ru", "phone": "+70062461963"}
0005434458852	AEEBDA	7357 642917	TATYANA EGOROVA	{"phone": "+70763465742"}
0005434458853	AEEBDA	5321 325652	ALEKSANDR ZHURAVLEV	{"phone": "+70747436167"}
0005434458854	AEEBDA	4328 749788	NATALYA ZAKHAROVA	{"phone": "+70281171974"}
0005434458855	DB69DA	7659 547766	SERGEY ANTONOV	{"phone": "+70816410356"}
0005434458856	050678	1015 029646	ELENA KOROLEVA	{"email": "e_koroleva.111973@postgrespro.ru", "phone": "+70496303612"}
0005434458857	C9946E	2672 775966	DMITRIY VASILEV	{"email": "dvasilev_1979@postgrespro.ru", "phone": "+70791056303"}
0005434458858	52C839	8112 253243	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr-1959@postgrespro.ru", "phone": "+70290368912"}
0005434458859	1902A0	3915 502863	OLESYA ALEKSEEVA	{"phone": "+70513810159"}
0005434458860	1902A0	6278 107211	VERA ROMANOVA	{"email": "vera_romanova.081963@postgrespro.ru", "phone": "+70329698558"}
0005434458861	D77507	5873 086142	ALEKSANDR MELNIKOV	{"phone": "+70473137846"}
0005434458862	D77507	8594 265057	NINA SIDOROVA	{"email": "sidorova_nina09041974@postgrespro.ru", "phone": "+70575048004"}
0005434458863	0EF448	6354 268538	MAKSIM ANDREEV	{"email": "mandreev.071971@postgrespro.ru", "phone": "+70790075767"}
0005434458864	30EDD7	0810 276023	VIKTOR ROMANOV	{"phone": "+70410716671"}
0005434458865	2E194D	8183 377173	OLGA BARANOVA	{"phone": "+70787051118"}
0005434458866	2E194D	2965 114450	EVGENIYA MAKSIMOVA	{"email": "maksimova.e_25041982@postgrespro.ru", "phone": "+70551355264"}
0005434458867	10BF32	7987 458160	NADEZHDA IVANOVA	{"email": "n_ivanova-121963@postgrespro.ru", "phone": "+70081508854"}
0005434458868	5D7DEF	4913 904159	YURIY SEMENOV	{"email": "semenovy-1982@postgrespro.ru", "phone": "+70218664805"}
0005434458869	5D7DEF	0184 600299	YANA VOROBEVA	{"phone": "+70314476083"}
0005434458870	3869A1	4139 262354	OKSANA KUZNECOVA	{"email": "o-kuznecova-11041969@postgrespro.ru", "phone": "+70498564235"}
0005434458871	3869A1	5363 475999	NADEZHDA MAKSIMOVA	{"email": "n_maksimova.011970@postgrespro.ru", "phone": "+70085245806"}
0005434458872	5FCB06	0262 796222	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov_051976@postgrespro.ru", "phone": "+70723996004"}
0005434458873	40C6E2	8106 045095	FEDOR FILIPPOV	{"email": "filippov-f.041977@postgrespro.ru", "phone": "+70206144994"}
0005434458874	CE22E6	3146 414122	TIMUR POPOV	{"phone": "+70387741887"}
0005434458875	49FC29	5296 285102	EKATERINA MEDVEDEVA	{"email": "medvedeva_e-08071969@postgrespro.ru", "phone": "+70601350356"}
0005434458877	B66587	9993 924807	EVA SEMENOVA	{"email": "semenovae101972@postgrespro.ru", "phone": "+70570229063"}
0005434458878	65E7AC	3312 863187	SVETLANA KOROLEVA	{"phone": "+70841202554"}
0005434458879	65E7AC	6369 535755	TATYANA RODIONOVA	{"phone": "+70527121362"}
0005434458880	330FBC	5661 934615	MIKHAIL SOLOVEV	{"email": "solovev-m_1976@postgrespro.ru", "phone": "+70287238402"}
0005434458881	330FBC	6309 021113	ALEKSANDR TARASOV	{"email": "atarasov.1973@postgrespro.ru", "phone": "+70720944985"}
0005434458882	17AC31	5247 657113	OKSANA SOROKINA	{"email": "o-sorokina-23021965@postgrespro.ru", "phone": "+70128042700"}
0005434458883	655CD2	1852 513861	NATALYA KOLESNIKOVA	{"phone": "+70424101811"}
0005434458884	655CD2	1734 154075	SERGEY MAKAROV	{"phone": "+70750169390"}
0005434458885	4D9719	8015 107040	VERA POPOVA	{"email": "popova-v.05051969@postgrespro.ru", "phone": "+70246142648"}
0005434458886	4D9719	8134 774495	GENNADIY SOKOLOV	{"email": "sokolov_g.29011979@postgrespro.ru", "phone": "+70979549258"}
0005434458887	DA8758	5180 694770	DANIIL POPOV	{"email": "popov-d.14051971@postgrespro.ru", "phone": "+70893460735"}
0005434458888	BBC26F	0366 776262	ELENA EFIMOVA	{"email": "efimova-e1975@postgrespro.ru", "phone": "+70968888112"}
0005434458889	BBC26F	0952 343305	SERGEY NIKOLAEV	{"phone": "+70827330773"}
0005434458890	15B7C4	9821 312654	EKATERINA FILATOVA	{"phone": "+70847268783"}
0005434458891	15B7C4	5061 388108	BORIS SCHERBAKOV	{"phone": "+70199103069"}
0005434458892	3D63E7	8403 999205	VALENTINA ZOTOVA	{"email": "v.zotova-1974@postgrespro.ru", "phone": "+70905589983"}
0005434458893	3D63E7	0566 945789	VYACHESLAV KOZLOV	{"phone": "+70413663958"}
0005434458894	0E00BC	7951 042191	GALINA NAZAROVA	{"email": "nazarova.g-30081972@postgrespro.ru", "phone": "+70884268233"}
0005434458895	0E00BC	4436 885217	EVGENIY SHEVCHENKO	{"email": "shevchenko.evgeniy27101975@postgrespro.ru", "phone": "+70103131361"}
0005434458896	4C0EF9	5837 252184	OLEG ALEKSEEV	{"email": "alekseev_oleg13011968@postgrespro.ru", "phone": "+70091367012"}
0005434458897	4C0EF9	8210 999170	NADEZHDA TARASOVA	{"email": "nadezhda.tarasova-021957@postgrespro.ru", "phone": "+70555326211"}
0005434458898	E5B1CD	5156 865833	GEORGIY DAVYDOV	{"phone": "+70281663709"}
0005434458899	E3802D	8394 398323	MARINA VASILEVA	{"email": "vasilevamarina_1976@postgrespro.ru", "phone": "+70981299847"}
0005434458900	E3802D	9787 588903	SERGEY KUZNECOV	{"email": "s_kuznecov091962@postgrespro.ru", "phone": "+70842787275"}
0005434458901	E3802D	8949 843207	MARINA ANDREEVA	{"phone": "+70003126499"}
0005434458902	12AC37	0766 380077	EVGENIY KAZAKOV	{"email": "e-kazakov_20081967@postgrespro.ru", "phone": "+70610538441"}
0005434458903	6A67FB	3418 420894	NADEZHDA KOMAROVA	{"phone": "+70655577590"}
0005434458904	9185D4	3142 954121	LYUBOV ANDREEVA	{"phone": "+70590302492"}
0005434458905	9185D4	0453 074105	VERA YUDINA	{"email": "v.yudina.1968@postgrespro.ru", "phone": "+70254920606"}
0005434458906	97FA0A	0201 711647	YURIY MOROZOV	{"phone": "+70301308871"}
0005434458907	97FA0A	2917 202828	DANIIL KONOVALOV	{"email": "konovalov_daniil-1979@postgrespro.ru", "phone": "+70174720142"}
0005434458908	C1EF47	6963 229152	NADEZHDA KAZAKOVA	{"email": "nadezhda.kazakova_1968@postgrespro.ru", "phone": "+70485578669"}
0005434458909	8E5BA3	7862 107406	ROMAN KULIKOV	{"email": "rkulikov_1986@postgrespro.ru", "phone": "+70813627196"}
0005434458910	1789DD	0865 728560	SERGEY ZAYCEV	{"phone": "+70033385325"}
0005434458911	A849AA	7602 906109	TAMARA SIDOROVA	{"email": "tamara-sidorova-18101983@postgrespro.ru", "phone": "+70359475880"}
0005434458912	A849AA	5024 847848	OLESYA MIKHAYLOVA	{"email": "mikhaylova.olesya_121974@postgrespro.ru", "phone": "+70317298196"}
0005434458913	1ED9B0	7700 424661	ELIZAVETA VASILEVA	{"email": "vasilevaelizaveta-13071970@postgrespro.ru", "phone": "+70289299328"}
0005434458914	1ED9B0	4384 226054	EKATERINA BORISOVA	{"phone": "+70728078356"}
0005434458915	D30B2F	9881 986883	ALEKSEY CHERNOV	{"phone": "+70643107493"}
0005434458916	D30B2F	6235 280073	GALINA BORISOVA	{"email": "g.borisova_1963@postgrespro.ru", "phone": "+70411138644"}
0005434458917	60F837	7031 097514	ROMAN FROLOV	{"phone": "+70503802112"}
0005434458918	DB15E8	6411 706309	SERGEY MARTYNOV	{"phone": "+70002727115"}
0005434458919	0F7524	6269 566617	ILYA KUZNECOV	{"email": "kuznecov-i.11021970@postgrespro.ru", "phone": "+70522226117"}
0005434458920	0F7524	8395 741284	VLADIMIR IVANOV	{"phone": "+70724960638"}
0005434458921	D6658A	3273 478463	NATALYA KUDRYASHOVA	{"phone": "+70537673439"}
0005434458922	F8D9D6	8154 200744	VIKTOR SHEVCHENKO	{"phone": "+70276576567"}
0005434458923	F8D9D6	4862 593497	VLADIMIR IVANOV	{"phone": "+70754691843"}
0005434458924	B4C9FD	2126 562925	ALEKSEY ANDREEV	{"email": "andreev-a.28011978@postgrespro.ru", "phone": "+70270576857"}
0005434458925	A55D0B	0850 894350	MARGARITA MIRONOVA	{"email": "mironova.margarita_26051974@postgrespro.ru", "phone": "+70685957968"}
0005434458926	57FDEB	5516 004433	VALENTINA KOVALEVA	{"email": "valentina_kovaleva.06011972@postgrespro.ru", "phone": "+70880449733"}
0005434458927	5F3CF1	9664 058619	NINA KISELEVA	{"email": "kiseleva.nina_121967@postgrespro.ru", "phone": "+70971476165"}
0005434458928	5F3CF1	6165 398608	VSEVOLOD SERGEEV	{"email": "sergeev.vsevolod.09081978@postgrespro.ru", "phone": "+70849051356"}
0005434458929	24011F	9516 805607	IVAN PETROV	{"email": "petrov_ivan.1966@postgrespro.ru", "phone": "+70763850781"}
0005434458930	BF8ECF	4204 552179	IREK MAKSIMOV	{"phone": "+70909186200"}
0005434458931	6E8BBD	8053 861889	NINA VOROBEVA	{"email": "nina_vorobeva031974@postgrespro.ru", "phone": "+70960920615"}
0005434459100	B9AF01	9870 529953	VLADIMIR SCHERBAKOV	{"phone": "+70309879227"}
0005434458932	6E8BBD	1841 731809	FEDOR SOROKIN	{"email": "f.sorokin_1962@postgrespro.ru", "phone": "+70221817756"}
0005434458933	58F2BD	7951 722266	VLADIMIR MOROZOV	{"email": "vladimir.morozov.041979@postgrespro.ru", "phone": "+70917393680"}
0005434458934	0C58DD	5679 116647	MARIYA VOROBEVA	{"email": "vorobeva-m-27081973@postgrespro.ru", "phone": "+70938142239"}
0005434458935	49FE7F	4582 115395	LARISA DENISOVA	{"phone": "+70708786338"}
0005434458936	49FE7F	5501 453041	ELENA MOROZOVA	{"phone": "+70888595767"}
0005434458937	3E244B	5638 029286	VERONIKA SERGEEVA	{"phone": "+70668079693"}
0005434458938	399E18	9445 537898	ELENA EGOROVA	{"email": "egorova_elena.101981@postgrespro.ru", "phone": "+70343909456"}
0005434458939	406B21	9743 365440	VYACHESLAV OSIPOV	{"phone": "+70331126071"}
0005434458940	406B21	2677 706852	VYACHESLAV ILIN	{"email": "ilin_vyacheslav.031978@postgrespro.ru", "phone": "+70166851230"}
0005434458941	DD7FD0	7828 294596	SVETLANA KALININA	{"email": "kalininasvetlana_091967@postgrespro.ru", "phone": "+70629393518"}
0005434458942	DD7FD0	5084 081185	ANNA EGOROVA	{"phone": "+70817006528"}
0005434458943	662564	1791 858013	NINA NOVIKOVA	{"phone": "+70815314278"}
0005434458944	F857BA	4111 784376	TATYANA VOLKOVA	{"phone": "+70421851401"}
0005434458945	F857BA	7266 213546	ALEKSANDR FEDOTOV	{"phone": "+70707109973"}
0005434458946	F857BA	2954 030767	TAMARA ANDREEVA	{"phone": "+70851024898"}
0005434458947	A5F59D	4167 637847	VALENTINA ZHURAVLEVA	{"email": "valentina-zhuravleva_27121967@postgrespro.ru", "phone": "+70221514218"}
0005434458948	EB3707	6021 628945	MIKHAIL KULIKOV	{"email": "m-kulikov061973@postgrespro.ru", "phone": "+70866765273"}
0005434458949	CE1DCF	9760 275070	MAYYA FOMINA	{"email": "fomina_mayya-1974@postgrespro.ru", "phone": "+70334471369"}
0005434458950	30BDC6	2886 268314	IRINA SERGEEVA	{"email": "isergeeva_011979@postgrespro.ru", "phone": "+70742627789"}
0005434458951	95612F	0794 184561	ZOYA MASLOVA	{"email": "maslova_zoya-20121959@postgrespro.ru", "phone": "+70473200794"}
0005434458952	BFE48D	3689 560522	GALINA TIMOFEEVA	{"phone": "+70735803853"}
0005434458953	BFE48D	8816 814940	MIKHAIL AFANASEV	{"phone": "+70128671734"}
0005434458954	6FB8AA	3584 467058	EDUARD KOZLOV	{"phone": "+70098047814"}
0005434458955	1438BD	5402 340502	EVGENIY YAKOVLEV	{"email": "e.yakovlev.18051974@postgrespro.ru", "phone": "+70395678368"}
0005434458956	696176	0204 945021	ALEKSANDR VASILEV	{"phone": "+70005511764"}
0005434458957	18A6CF	0234 344470	NATALIYA TARASOVA	{"email": "n.tarasova-22111960@postgrespro.ru", "phone": "+70797283311"}
0005434458958	18A6CF	0790 675232	OLEG SOLOVEV	{"email": "solovev_o_03071970@postgrespro.ru", "phone": "+70743956514"}
0005434458959	F5EA1B	6384 199838	ALEKSANDR POPOV	{"email": "popov.a021975@postgrespro.ru", "phone": "+70177343401"}
0005434458960	07C94C	0054 278734	VLADIMIR ILIN	{"phone": "+70938774713"}
0005434458961	07C94C	6260 430014	VYACHESLAV KUZMIN	{"phone": "+70519730917"}
0005434458962	6ADA64	6838 633361	NADEZHDA KUZNECOVA	{"phone": "+70992568937"}
0005434458963	6ADA64	6537 880898	ALEVTINA KONOVALOVA	{"email": "a.konovalova.1975@postgrespro.ru", "phone": "+70060728237"}
0005434458964	6FB34A	9340 629705	ROMAN SOKOLOV	{"phone": "+70665352015"}
0005434458965	334390	6441 750533	LYUBOV MOISEEVA	{"email": "l-moiseeva-20111975@postgrespro.ru", "phone": "+70550821371"}
0005434458966	EA024E	2642 634981	ANNA EFIMOVA	{"email": "annaefimova_111975@postgrespro.ru", "phone": "+70141127442"}
0005434458967	3F6089	8071 336692	ELENA MASLOVA	{"email": "maslova_elena1980@postgrespro.ru", "phone": "+70185734802"}
0005434458968	5BF9A7	3033 922521	VLADIMIR SAVELEV	{"email": "vladimir.savelev1972@postgrespro.ru", "phone": "+70659083852"}
0005434458969	671B23	7149 415179	ALEKSANDR SHEVCHENKO	{"phone": "+70601647311"}
0005434458970	82C502	0443 178111	LYUDMILA KISELEVA	{"email": "kiseleval_1969@postgrespro.ru", "phone": "+70593361094"}
0005434458971	82C502	3227 086242	IRINA POTAPOVA	{"email": "potapova.irina_1981@postgrespro.ru", "phone": "+70535411161"}
0005434458972	82C502	8580 513493	LYUDMILA KONDRATEVA	{"phone": "+70507997914"}
0005434458973	364AEE	2793 391594	BORIS ANDREEV	{"email": "andreev.boris_021976@postgrespro.ru", "phone": "+70066325176"}
0005434458974	364AEE	7550 978187	NIKOLAY POPOV	{"email": "npopov071976@postgrespro.ru", "phone": "+70581944595"}
0005434458975	DB1D12	9819 079700	OLGA SAVELEVA	{"email": "saveleva-olga.1964@postgrespro.ru", "phone": "+70809244097"}
0005434458976	A79CDF	5047 692093	VALENTINA MATVEEVA	{"phone": "+70933103928"}
0005434458977	93DE2C	3551 821862	SERGEY RODIONOV	{"email": "s_rodionov011976@postgrespro.ru", "phone": "+70757203146"}
0005434458978	93DE2C	1371 964319	ALEKSANDR SOROKIN	{"email": "a_sorokin_1977@postgrespro.ru", "phone": "+70931947627"}
0005434458979	93DE2C	7596 520881	VERA NIKIFOROVA	{"phone": "+70160494993"}
0005434458980	61E4B4	2989 775031	OLGA PETROVA	{"email": "o_petrova29051975@postgrespro.ru", "phone": "+70196519809"}
0005434458981	B7931E	5527 235207	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr_20051980@postgrespro.ru", "phone": "+70175138684"}
0005434458982	B7931E	1749 358007	ANTONINA NAZAROVA	{"phone": "+70054133370"}
0005434458983	F7A082	4790 159957	NIKOLAY ORLOV	{"phone": "+70584077603"}
0005434458984	5C0854	9690 569862	VALERIY SERGEEV	{"phone": "+70719604503"}
0005434458985	5C0854	9255 697329	NAIL SIDOROV	{"email": "sidorov.nail_011971@postgrespro.ru", "phone": "+70520972565"}
0005434458986	5C0854	0894 882488	ROMAN NIKOLAEV	{"email": "nikolaev.r_1963@postgrespro.ru", "phone": "+70960024763"}
0005434458987	1C43C6	6530 901165	GALINA SIDOROVA	{"email": "sidorova-g.1980@postgrespro.ru", "phone": "+70971652895"}
0005434458988	62C3C4	3205 758006	TATYANA IVANOVA	{"email": "tatyanaivanova-26091967@postgrespro.ru", "phone": "+70135577377"}
0005434458989	62C3C4	1134 546741	ANDREY ALEKSANDROV	{"email": "aleksandrov_andrey081977@postgrespro.ru", "phone": "+70003141568"}
0005434458990	61E2B5	4885 972484	ALEKSANDR ANDREEV	{"phone": "+70242876249"}
0005434458991	7C4CBA	3959 265850	ANDREY ILIN	{"phone": "+70630800754"}
0005434458992	7B93A4	4758 089580	ANDREY ZAKHAROV	{"phone": "+70733327855"}
0005434458993	7B93A4	3219 276602	ELENA KALININA	{"phone": "+70781386855"}
0005434458994	F76EA4	7164 998779	NADEZHDA FEDOROVA	{"phone": "+70600633133"}
0005434458995	F76EA4	4013 903076	VALERIY KARPOV	{"phone": "+70421066629"}
0005434458996	CB6E2F	1401 619858	ELENA TROFIMOVA	{"email": "e-trofimova.1974@postgrespro.ru", "phone": "+70297051406"}
0005434458997	B698F7	0503 247711	DMITRIY FEDOROV	{"phone": "+70146724267"}
0005434458998	B698F7	2034 625259	SERGEY SCHERBAKOV	{"email": "s-scherbakov.031984@postgrespro.ru", "phone": "+70005556020"}
0005434458999	9733A3	8390 775393	MARIYA ZHURAVLEVA	{"email": "zhuravlevam.19071971@postgrespro.ru", "phone": "+70153588472"}
0005434459000	B7B0F7	9246 107763	ALEKSANDR MIRONOV	{"email": "aleksandr_mironov051984@postgrespro.ru", "phone": "+70909044731"}
0005434459001	B7B0F7	1936 724983	ALEKSANDR ZAKHAROV	{"phone": "+70880792659"}
0005434459002	DC2B06	3402 300727	MIKHAIL ZAKHAROV	{"phone": "+70456326983"}
0005434459003	218A0D	8753 314495	GALINA MATVEEVA	{"phone": "+70960958793"}
0005434459004	218A0D	1139 386787	ALEVTINA KALININA	{"email": "kalinina.alevtina-1986@postgrespro.ru", "phone": "+70199547145"}
0005434459005	218A0D	0881 517023	DMITRIY BONDARENKO	{"email": "bondarenko_dmitriy_1980@postgrespro.ru", "phone": "+70429273756"}
0005434459006	C6C9D7	5777 385542	NIKOLAY VASILEV	{"email": "vasilev-nikolay.1963@postgrespro.ru", "phone": "+70271748359"}
0005434459007	9EEBB5	0158 360330	LARISA VOROBEVA	{"phone": "+70136278385"}
0005434459008	2FFAC0	4217 657623	OLEG SEMENOV	{"phone": "+70819699209"}
0005434459009	2FFAC0	3340 836862	ALEKSANDR PETROV	{"email": "a_petrov_1965@postgrespro.ru", "phone": "+70429404803"}
0005434459010	3BF897	0941 567851	IGOR NIKOLAEV	{"email": "inikolaev-04061960@postgrespro.ru", "phone": "+70792174245"}
0005434459011	B9BF41	8325 930571	VIKTORIYA NAZAROVA	{"email": "nazarova.v_121976@postgrespro.ru", "phone": "+70353809994"}
0005434459012	B9BF41	7420 486857	ALEKSANDR SMIRNOV	{"phone": "+70499444266"}
0005434459013	879E0B	0370 537509	ALEKSANDR ROMANOV	{"email": "aleksandrromanov_21041984@postgrespro.ru", "phone": "+70383662293"}
0005434459014	19D077	5782 404436	ANTONIDA IVANOVA	{"email": "a-ivanova.051976@postgrespro.ru", "phone": "+70477091435"}
0005434459015	19D077	4133 083490	VALENTINA YUDINA	{"email": "yudina_valentina.1984@postgrespro.ru", "phone": "+70041496138"}
0005434459016	41E609	6199 934960	NIKITA KISELEV	{"email": "n_kiselev.1967@postgrespro.ru", "phone": "+70317850574"}
0005434459017	5F64F8	5016 299906	KRISTINA KAZAKOVA	{"email": "kristina-kazakova.081972@postgrespro.ru", "phone": "+70615514897"}
0005434459018	8A3D0B	4059 846947	IRINA NOVIKOVA	{"phone": "+70229934243"}
0005434459019	264AB9	6504 587317	EKATERINA MEDVEDEVA	{"phone": "+70125779153"}
0005434459020	264AB9	3758 285273	LYUDMILA ANTONOVA	{"phone": "+70807222203"}
0005434459021	DA7BA4	0252 364972	IRINA KALININA	{"phone": "+70958856280"}
0005434459078	13F7B5	5742 931080	ELENA SOROKINA	{"phone": "+70666017128"}
0005434459022	DA7BA4	0987 291417	SERGEY TIMOFEEV	{"email": "sergey.timofeev071977@postgrespro.ru", "phone": "+70095931671"}
0005434459023	D9AB83	6123 358483	VYACHESLAV STEPANOV	{"phone": "+70473383960"}
0005434459024	D0E7F3	5719 201077	NATALYA MARTYNOVA	{"phone": "+70690888065"}
0005434459025	1C9C4C	3752 086257	ALEKSEY ROMANOV	{"phone": "+70413699077"}
0005434459026	644E67	6829 341972	LYUBOV SAVELEVA	{"phone": "+70728296407"}
0005434459027	644E67	2619 163617	NINA ARKHIPOVA	{"email": "arkhipova.nina_041985@postgrespro.ru", "phone": "+70190433116"}
0005434459028	DAADC4	4127 611377	NINA MASLOVA	{"phone": "+70265537275"}
0005434459029	DAADC4	7047 053468	IVAN TIKHONOV	{"phone": "+70947096766"}
0005434459030	DAADC4	1374 216203	EVA KAZAKOVA	{"email": "kazakova-e-1978@postgrespro.ru", "phone": "+70865820732"}
0005434459031	FADA63	6813 872344	ALEKSEY TARASOV	{"email": "atarasov-1971@postgrespro.ru", "phone": "+70249447419"}
0005434459032	FADA63	1025 673787	EKATERINA YAKOVLEVA	{"email": "ekaterina-yakovleva091973@postgrespro.ru", "phone": "+70533600954"}
0005434459033	FADA63	9933 306614	ELENA YUDINA	{"phone": "+70621293750"}
0005434459034	21E4C3	2096 069395	SVETLANA KUZMINA	{"phone": "+70548106705"}
0005434459035	B84CF5	0513 437216	POLINA IVANOVA	{"email": "polina-ivanova_111980@postgrespro.ru", "phone": "+70976548872"}
0005434459036	B84CF5	2614 992341	ANDREY PAVLOV	{"phone": "+70934057523"}
0005434459037	62DD57	9064 777440	DENIS SEMENOV	{"email": "semenov.denis-19041961@postgrespro.ru", "phone": "+70782732646"}
0005434459038	62DD57	7633 920082	NIKOLAY MATVEEV	{"phone": "+70112686177"}
0005434459039	8E5AF6	3530 349083	ALEKSANDRA KOLESNIKOVA	{"phone": "+70731694853"}
0005434459040	E148A0	7379 628150	EMIL POPOV	{"email": "e.popov_24041980@postgrespro.ru", "phone": "+70945811391"}
0005434459041	4CB2A2	0591 849094	OLGA GAVRILOVA	{"phone": "+70670131297"}
0005434459042	4CB2A2	9094 080477	ANNA IVANOVA	{"email": "a.ivanova1962@postgrespro.ru", "phone": "+70494490786"}
0005434459043	38D418	2182 249015	EVGENIY ORLOV	{"email": "eorlov-1967@postgrespro.ru", "phone": "+70832065516"}
0005434459044	38D418	9954 924587	ELENA DENISOVA	{"email": "elenadenisova-1971@postgrespro.ru", "phone": "+70014153767"}
0005434459045	38D418	8663 477732	TATYANA SERGEEVA	{"email": "sergeeva.tatyana09081981@postgrespro.ru", "phone": "+70258160780"}
0005434459046	AE1806	5501 679671	VALENTINA ALEKSANDROVA	{"email": "v_aleksandrova-101979@postgrespro.ru", "phone": "+70342221544"}
0005434459047	ECA6A7	7440 575097	DENIS ZHURAVLEV	{"email": "zhuravlev.d1981@postgrespro.ru", "phone": "+70802455696"}
0005434459048	ECA6A7	7217 423467	DAMIR SOLOVEV	{"email": "d-solovev.051989@postgrespro.ru", "phone": "+70215921222"}
0005434459049	4A1771	8108 419227	SVYATOSLAV SERGEEV	{"email": "s-sergeev.16011955@postgrespro.ru", "phone": "+70678253888"}
0005434459050	4A1771	9278 778090	ANTONIDA FOMINA	{"phone": "+70052301368"}
0005434459051	AEA2C1	6011 431779	ELENA VLASOVA	{"phone": "+70881447091"}
0005434459052	451FBB	3107 188140	ALEKSANDR ZAYCEV	{"phone": "+70394642158"}
0005434459053	06FEE5	4621 530751	GALINA ZHURAVLEVA	{"email": "gzhuravleva.19051971@postgrespro.ru", "phone": "+70606991110"}
0005434459054	62A184	9925 232629	IRINA MAKAROVA	{"email": "imakarova.1980@postgrespro.ru", "phone": "+70248340965"}
0005434459055	7599F5	8000 721865	ANNA ANISIMOVA	{"email": "anna-anisimova_081977@postgrespro.ru", "phone": "+70251194017"}
0005434459056	CF078A	6246 737784	NIKOLAY EGOROV	{"phone": "+70748917122"}
0005434459057	CF078A	5442 590153	ALEKSEY BARANOV	{"email": "baranov_aleksey.071969@postgrespro.ru", "phone": "+70569609230"}
0005434459058	0BDFF1	9017 674524	ELENA VOLKOVA	{"phone": "+70814703717"}
0005434459059	0BDFF1	4140 886620	LIDIYA GRISHINA	{"phone": "+70137530170"}
0005434459060	6229DD	8890 499822	NAILYA NIKIFOROVA	{"email": "nikiforova_n_05061964@postgrespro.ru", "phone": "+70906894703"}
0005434459061	12F11E	7794 245236	ANNA KOROLEVA	{"phone": "+70232301212"}
0005434459062	918582	7181 190460	LYUBOV ZHUKOVA	{"phone": "+70768510507"}
0005434459063	B12EF1	3400 576740	NIKOLAY MIKHAYLOV	{"phone": "+70711072090"}
0005434459064	75BEBA	5691 527820	VSEVOLOD ILIN	{"email": "ilinv_28071962@postgrespro.ru", "phone": "+70988017163"}
0005434459065	75BEBA	8100 717106	MARINA OSIPOVA	{"email": "m_osipova.1969@postgrespro.ru", "phone": "+70144499724"}
0005434459066	60AFF3	7270 017023	ALEKSANDR KOZLOV	{"email": "kozlov_a-021978@postgrespro.ru", "phone": "+70186526022"}
0005434459067	2368CF	7971 803491	VLADIMIR ALEKSANDROV	{"email": "vladimir.aleksandrov-1965@postgrespro.ru", "phone": "+70375496577"}
0005434459068	2368CF	2751 314444	NIKITA KONOVALOV	{"phone": "+70579314796"}
0005434459069	4394B7	6520 836596	MIKHAIL GUSEV	{"phone": "+70285360259"}
0005434459070	4394B7	8288 536960	LYUBOV KULIKOVA	{"email": "lyubovkulikova1974@postgrespro.ru", "phone": "+70463546900"}
0005434459071	A89334	1304 236336	VITALIY SMIRNOV	{"email": "v-smirnov.17051968@postgrespro.ru", "phone": "+70967800974"}
0005434459072	A89334	0650 322017	YURIY ZAYCEV	{"phone": "+70043092411"}
0005434459073	122FE0	4878 761918	ELENA ABRAMOVA	{"phone": "+70158851648"}
0005434459074	122FE0	9590 191046	ALEKSANDR IVANOV	{"email": "a_ivanov-20041978@postgrespro.ru", "phone": "+70848686744"}
0005434459075	4BF0B7	5400 287518	NADEZHDA GUSEVA	{"phone": "+70407518975"}
0005434459076	4BF0B7	2684 654342	GUZEL GERASIMOVA	{"email": "gerasimova_guzel1973@postgrespro.ru", "phone": "+70699828528"}
0005434459077	0B86C2	3365 263874	OLGA SCHERBAKOVA	{"email": "scherbakovaolga_1972@postgrespro.ru", "phone": "+70790905276"}
0005434459079	E66855	6708 681463	IVAN MEDVEDEV	{"phone": "+70503301101"}
0005434459080	E66855	2530 357017	VLADIMIR IVANOV	{"email": "ivanov-vladimir.111972@postgrespro.ru", "phone": "+70400350219"}
0005434459081	488375	8151 532791	VERA GUSEVA	{"phone": "+70371734548"}
0005434459082	1EA7B0	3922 567013	LIDIYA KOVALEVA	{"email": "l-kovaleva071961@postgrespro.ru", "phone": "+70825695366"}
0005434459083	399A42	8509 732168	LYUBOV VASILEVA	{"phone": "+70424085942"}
0005434459084	399A42	8467 918217	STEPAN STEPANOV	{"email": "stepanov-stepan-1971@postgrespro.ru", "phone": "+70562014711"}
0005434459085	056D4E	8352 656282	NATALYA VOROBEVA	{"phone": "+70617121376"}
0005434459086	7B0259	9210 080047	LYUDMILA NIKOLAEVA	{"email": "lyudmila_nikolaeva_1979@postgrespro.ru", "phone": "+70197923691"}
0005434459087	7B0259	5044 908555	IRINA SMIRNOVA	{"email": "i-smirnova-1976@postgrespro.ru", "phone": "+70620697443"}
0005434459088	EDE624	4077 614263	YAROSLAV ILIN	{"email": "ilin.y-04041972@postgrespro.ru", "phone": "+70769879569"}
0005434459089	BB1EC4	4484 812004	DANIIL ALEKSEEV	{"phone": "+70946103171"}
0005434459090	BB1EC4	1778 613634	POLINA LOGINOVA	{"phone": "+70644035947"}
0005434459091	7F9250	6578 973374	ELENA IVANOVA	{"phone": "+70019626270"}
0005434459092	6F5CCE	0395 476650	VALENTINA KRASNOVA	{"email": "v_krasnova28101980@postgrespro.ru", "phone": "+70027050975"}
0005434459093	6F5CCE	3877 926436	VADIM NAUMOV	{"email": "naumovvadim.101977@postgrespro.ru", "phone": "+70466362231"}
0005434459094	0808F5	3908 702486	LYUDMILA ROMANOVA	{"email": "lyudmilaromanova-15021961@postgrespro.ru", "phone": "+70666003675"}
0005434459095	F35345	5090 085965	ANATOLIY ROMANOV	{"email": "romanov_anatoliy.1963@postgrespro.ru", "phone": "+70537843039"}
0005434459096	E616DA	9555 931496	NATALYA SCHERBAKOVA	{"phone": "+70852066831"}
0005434459097	33ADE7	6868 600954	ROMAN ROMANOV	{"email": "r.romanov1968@postgrespro.ru", "phone": "+70705754918"}
0005434459098	4B745E	0729 424008	VIKTOR KONOVALOV	{"phone": "+70177575562"}
0005434459099	4B745E	7612 570649	ANATOLIY ROMANOV	{"phone": "+70993255477"}
0005434459101	B9AF01	7057 682435	YULIYA MEDVEDEVA	{"phone": "+70074440245"}
0005434459102	EA8FD6	7950 469791	IRINA KARPOVA	{"phone": "+70444203297"}
0005434459103	BDB61A	2317 525741	SERGEY BONDARENKO	{"email": "bondarenko_sergey_1974@postgrespro.ru", "phone": "+70416590574"}
0005434459104	BDB61A	3318 678068	ALEKSANDR PETROV	{"email": "apetrov_061971@postgrespro.ru", "phone": "+70251751350"}
0005434459105	BDB61A	4279 241124	VLADIMIR POPOV	{"phone": "+70269812533"}
0005434459106	375958	9588 290036	VLADIMIR NAUMOV	{"email": "vladimir-naumov_1973@postgrespro.ru", "phone": "+70403474091"}
0005434459107	931445	2166 693024	ANTONINA FROLOVA	{"email": "frolova.a.061973@postgrespro.ru", "phone": "+70088508599"}
0005434459108	2B1748	8784 453838	NATALYA BELOVA	{"phone": "+70491983413"}
0005434459109	2B1748	8190 856227	NATALYA ROMANOVA	{"email": "romanova_n.111983@postgrespro.ru", "phone": "+70534851511"}
0005434459110	2B1748	2129 284525	VLADIMIR YAKOVLEV	{"email": "v.yakovlev-06071977@postgrespro.ru", "phone": "+70799028077"}
0005434459111	C25403	3580 332324	VIKTOR MAKAROV	{"email": "makarov.v_27011980@postgrespro.ru", "phone": "+70510304389"}
0005434459112	773D4C	9172 913965	IVAN MATVEEV	{"phone": "+70131125896"}
0005434459113	FC622B	4817 923762	IRINA IVANOVA	{"email": "i_ivanova_17031973@postgrespro.ru", "phone": "+70895186154"}
0005434459114	4180A3	8305 996219	MARINA VASILEVA	{"email": "vasileva-marina.1965@postgrespro.ru", "phone": "+70148399607"}
0005434459115	0DC679	5899 501719	NATALIYA STEPANOVA	{"phone": "+70626421365"}
0005434459116	47C613	3270 361694	ALSU IVANOVA	{"phone": "+70491305771"}
0005434459117	47C613	1170 448422	ANASTASIYA LAZAREVA	{"email": "alazareva_09121963@postgrespro.ru", "phone": "+70407856189"}
0005434459118	EB6D7C	2517 050058	EVGENIYA NIKOLAEVA	{"email": "nikolaevae.10051976@postgrespro.ru", "phone": "+70895909368"}
0005434459119	EB6D7C	9488 408473	LIDIYA KOLESNIKOVA	{"email": "kolesnikova.l081969@postgrespro.ru", "phone": "+70297117195"}
0005434459120	62B2AB	2915 534984	IVAN SOLOVEV	{"phone": "+70990547295"}
0005434459121	62B2AB	8251 867340	DMITRIY ZAYCEV	{"phone": "+70157741369"}
0005434459122	DDE0BC	4293 524328	GENNADIY ZAKHAROV	{"phone": "+70878902586"}
0005434459123	623D57	8426 994681	IVAN KOZLOV	{"email": "kozlov-i101974@postgrespro.ru", "phone": "+70704103854"}
0005434459124	AF0812	5535 803946	VALENTINA NAZAROVA	{"email": "v.nazarova1963@postgrespro.ru", "phone": "+70979760768"}
0005434459125	AF0812	1117 198091	DMITRIY MOROZOV	{"email": "dmitriy-morozov_1970@postgrespro.ru", "phone": "+70353199615"}
0005434459126	F924D7	0765 094877	ELENA ANISIMOVA	{"email": "elena-anisimova_101977@postgrespro.ru", "phone": "+70548681598"}
0005434459127	2EF14E	2515 384865	VADIM KUZNECOV	{"email": "v-kuznecov-1983@postgrespro.ru", "phone": "+70274844803"}
0005434459128	2EF14E	0206 186242	ANASTASIYA DENISOVA	{"email": "adenisova-011970@postgrespro.ru", "phone": "+70836904084"}
0005434459129	2EF14E	9795 579930	LYUDMILA BELOVA	{"phone": "+70041133668"}
0005434459130	989A14	8623 374150	LYUDMILA MAKSIMOVA	{"email": "maksimova_l-27111981@postgrespro.ru", "phone": "+70827010431"}
0005434459131	989A14	8084 272421	OLEG KONOVALOV	{"phone": "+70737047037"}
0005434459132	D2A9AF	2173 181695	NATALYA POTAPOVA	{"phone": "+70800286261"}
0005434459133	14A0CE	7805 522744	ANNA VOROBEVA	{"email": "vorobeva-anna031985@postgrespro.ru", "phone": "+70800769833"}
0005434459134	64ABB9	3247 114545	SVETLANA OVCHINNIKOVA	{"email": "s.ovchinnikova.031958@postgrespro.ru", "phone": "+70786360275"}
0005434459247	58AB19	1695 691325	VITALIY MIKHAYLOV	{"phone": "+70412722249"}
0005434459135	64ABB9	9194 275304	TAMARA ZAKHAROVA	{"email": "tamarazakharova101982@postgrespro.ru", "phone": "+70490883207"}
0005434459136	4477EC	4989 021709	ALEKSANDR MAKAROV	{"phone": "+70697568416"}
0005434459137	A5038F	6541 277723	ELENA KISELEVA	{"phone": "+70439933322"}
0005434459138	0B39FF	0382 345835	MAKSIM EGOROV	{"email": "egorov_maksim_10061972@postgrespro.ru", "phone": "+70529539976"}
0005434459139	39A0FD	8187 266559	YURIY BELOV	{"email": "belovy_1969@postgrespro.ru", "phone": "+70142732897"}
0005434459140	BAD518	8926 010352	ANASTASIYA KUZNECOVA	{"phone": "+70979243548"}
0005434459141	BAD518	7960 596197	GALINA RODIONOVA	{"email": "galina.rodionova.1977@postgrespro.ru", "phone": "+70902528122"}
0005434459142	1AD57A	6931 870384	IGOR ZHUKOV	{"email": "zhukovi-1962@postgrespro.ru", "phone": "+70699600721"}
0005434459143	8BE20B	0466 946584	ALLA GERASIMOVA	{"phone": "+70933516224"}
0005434459144	8BE20B	3976 495443	VLADIMIR DENISOV	{"phone": "+70804666658"}
0005434459145	A0EDD1	9561 082535	ANZHELIKA SERGEEVA	{"phone": "+70036041677"}
0005434459146	5F09EE	8247 453870	ALLA OSIPOVA	{"email": "osipova_a1971@postgrespro.ru", "phone": "+70400278777"}
0005434459147	5F09EE	7336 024350	SOFYA ROMANOVA	{"email": "romanovas051963@postgrespro.ru", "phone": "+70372690288"}
0005434459148	5F09EE	7067 975037	ARTEM GAVRILOV	{"phone": "+70000617414"}
0005434459149	0A6267	5211 257892	EKATERINA SOROKINA	{"email": "e_sorokina101967@postgrespro.ru", "phone": "+70012576843"}
0005434459150	21BB6C	8640 487077	VYACHESLAV MARTYNOV	{"email": "v-martynov_061969@postgrespro.ru", "phone": "+70510653878"}
0005434459151	804748	8061 644678	ALEKSANDR NOVIKOV	{"email": "novikova-12011969@postgrespro.ru", "phone": "+70129546616"}
0005434459152	B7A366	0540 955358	ALINA IVANOVA	{"phone": "+70096475484"}
0005434459153	B7A366	9391 613759	ALEKSEY PETROV	{"email": "aleksey-petrov_1957@postgrespro.ru", "phone": "+70083997674"}
0005434459154	343133	9034 100802	LYUBOV LEBEDEVA	{"email": "l-lebedeva.1964@postgrespro.ru", "phone": "+70028498762"}
0005434459155	343133	0862 764682	VALERIYA OSIPOVA	{"phone": "+70420548540"}
0005434459156	425BBE	9222 499401	NIKITA SERGEEV	{"phone": "+70284398938"}
0005434459157	425BBE	2412 908197	VLADIMIR MAKSIMOV	{"phone": "+70763857553"}
0005434459158	816CA7	2984 097161	ANDREY VOROBEV	{"email": "vorobev.a-26121974@postgrespro.ru", "phone": "+70019897852"}
0005434459159	816CA7	8622 602760	VYACHESLAV BELOV	{"phone": "+70030801813"}
0005434459160	AF28C8	3996 910544	ANASTASIYA ISAEVA	{"email": "isaeva.a-091972@postgrespro.ru", "phone": "+70379423287"}
0005434459161	AF28C8	4196 631749	ARTUR BELOV	{"email": "belov-a_08121973@postgrespro.ru", "phone": "+70064549520"}
0005434459162	0B9F61	2395 303489	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr.1966@postgrespro.ru", "phone": "+70902717129"}
0005434459163	94D7D8	0253 550682	MATVEY SERGEEV	{"email": "m.sergeev_041976@postgrespro.ru", "phone": "+70131273358"}
0005434459164	6F698E	4814 606503	MARINA MOISEEVA	{"phone": "+70362293750"}
0005434459165	A7F7FA	1043 039533	NATALYA SOKOLOVA	{"phone": "+70368898543"}
0005434459166	A7F7FA	1509 262896	SVETLANA FROLOVA	{"email": "frolova-svetlana_091966@postgrespro.ru", "phone": "+70834884974"}
0005434459167	9556AC	7207 523788	EGOR MIRONOV	{"email": "egormironov-081975@postgrespro.ru", "phone": "+70047851697"}
0005434459168	43CAEC	2914 974268	NINA SEMENOVA	{"phone": "+70823110147"}
0005434459169	BC5C12	4473 323419	SERGEY KUZMIN	{"phone": "+70814816886"}
0005434459170	07E2AB	7833 383433	ANNA MAKAROVA	{"email": "makarova-a.021965@postgrespro.ru", "phone": "+70948572859"}
0005434459171	07E2AB	9109 665706	YURIY FEDOROV	{"email": "fedorovyuriy1981@postgrespro.ru", "phone": "+70138941337"}
0005434459172	80CC69	2502 843545	VIKTORIYA GUSEVA	{"email": "v-guseva_1985@postgrespro.ru", "phone": "+70061499071"}
0005434459173	640A52	4917 541360	LILIYA SOKOLOVA	{"phone": "+70632583654"}
0005434459174	057207	4748 439900	RAISA ZHUKOVA	{"email": "raisa.zhukova1964@postgrespro.ru", "phone": "+70043720393"}
0005434459175	DFF6CA	1532 862464	VIKTORIYA KALININA	{"phone": "+70262255452"}
0005434459176	3AEBC9	0271 725401	MARINA ZAYCEVA	{"email": "m.zayceva_1973@postgrespro.ru", "phone": "+70537376126"}
0005434459177	6D70E0	0196 278019	AZAT NOVIKOV	{"phone": "+70128550693"}
0005434459178	F7946B	9504 341453	POLINA ALEKSEEVA	{"phone": "+70755435637"}
0005434459179	4B4309	4293 791450	DMITRIY BORISOV	{"email": "dmitriyborisov_01061975@postgrespro.ru", "phone": "+70579417730"}
0005434459180	4B4309	6453 048238	GALINA MAKSIMOVA	{"email": "maksimova.galina_121970@postgrespro.ru", "phone": "+70649179084"}
0005434459181	ECB6F6	4693 608698	VIKTOR ZAYCEV	{"email": "viktor-zaycev.04101958@postgrespro.ru", "phone": "+70170755371"}
0005434459182	ECB6F6	1742 036315	GALINA FILATOVA	{"email": "filatova-galina_31121971@postgrespro.ru", "phone": "+70972829583"}
0005434459183	6942B6	4370 772185	ROMAN ZAKHAROV	{"phone": "+70906494626"}
0005434459184	107431	1989 150515	NIKOLAY VOLKOV	{"phone": "+70098664207"}
0005434459185	648736	8030 083815	VIKTOR KOROLEV	{"email": "korolevv.1973@postgrespro.ru", "phone": "+70334812519"}
0005434459186	08A612	9764 041113	EVGENIY STEPANOV	{"phone": "+70373947780"}
0005434459187	CF980C	4105 223191	ALEKSANDR GORBUNOV	{"email": "gorbunov_aleksandr1983@postgrespro.ru", "phone": "+70432163951"}
0005434459188	74E59D	3462 855440	ALBINA OSIPOVA	{"email": "albina_osipova-1971@postgrespro.ru", "phone": "+70281609152"}
0005434459189	74E59D	7400 482033	ALEKSEY SIDOROV	{"email": "a-sidorov_1978@postgrespro.ru", "phone": "+70761039400"}
0005434459190	562850	4488 408136	YAKOV MIKHAYLOV	{"phone": "+70723762975"}
0005434459191	562850	7200 540866	TATYANA MIKHAYLOVA	{"email": "mikhaylova-t-23101968@postgrespro.ru", "phone": "+70993492941"}
0005434459192	B307CE	4510 097882	TATYANA GORBUNOVA	{"email": "gorbunova.tatyana.041968@postgrespro.ru", "phone": "+70505157734"}
0005434459193	6A49C9	0573 558376	NATALYA YAKOVLEVA	{"email": "yakovleva_natalya12111980@postgrespro.ru", "phone": "+70514943520"}
0005434459194	6A49C9	0944 263302	KSENIYA ZAYCEVA	{"phone": "+70816834906"}
0005434459195	538F12	8097 717121	TATYANA MEDVEDEVA	{"phone": "+70551094581"}
0005434459196	538F12	4961 817505	YULIYA KOZLOVA	{"email": "yuliya.kozlova_15051981@postgrespro.ru", "phone": "+70107482990"}
0005434459197	8CFD3D	5025 862693	NADEZHDA NAZAROVA	{"email": "nazarovanadezhda-1961@postgrespro.ru", "phone": "+70577679346"}
0005434459198	F9B184	8007 032917	ELVIRA IVANOVA	{"email": "e_ivanova.11081981@postgrespro.ru", "phone": "+70135559880"}
0005434459199	F9B184	4377 888651	ALEKSEY SMIRNOV	{"email": "asmirnov20111967@postgrespro.ru", "phone": "+70382807666"}
0005434459200	F755AF	6765 654363	ILYA BONDARENKO	{"phone": "+70853276364"}
0005434459201	FBF4A1	0526 436513	ARTEM ZAKHAROV	{"email": "zakharov_artem_091966@postgrespro.ru", "phone": "+70574576512"}
0005434459202	E1812A	7695 078634	ANASTASIYA KUZMINA	{"email": "kuzmina_a.23051970@postgrespro.ru", "phone": "+70202145739"}
0005434459203	FCDCDE	5214 712908	RAIS SCHERBAKOV	{"phone": "+70665960640"}
0005434459204	AF635D	1058 221112	ANDREY MOROZOV	{"email": "andrey_morozov_021974@postgrespro.ru", "phone": "+70517784428"}
0005434459205	1FF25E	8532 794971	MARIYA ABRAMOVA	{"phone": "+70081846791"}
0005434459206	1FF25E	3383 417437	IRINA EGOROVA	{"phone": "+70633624168"}
0005434459207	7F5F31	4672 992031	EVGENIY MELNIKOV	{"email": "evgeniy_melnikov-1973@postgrespro.ru", "phone": "+70524309120"}
0005434459208	40CB51	5223 406664	LYUDMILA VASILEVA	{"email": "lyudmila-vasileva.19071969@postgrespro.ru", "phone": "+70586260197"}
0005434459209	159184	6547 163802	ANDREY BORISOV	{"phone": "+70280234964"}
0005434459210	6C1778	2591 985341	DANIIL MOROZOV	{"phone": "+70114537710"}
0005434459211	E2D3C5	9192 887416	EVGENIYA EGOROVA	{"phone": "+70744904631"}
0005434459212	E8CDC4	4225 104292	VIKTOR GERASIMOV	{"email": "gerasimov.viktor_1969@postgrespro.ru", "phone": "+70795739791"}
0005434459213	E8CDC4	7919 897401	ALEKSEY STEPANOV	{"email": "a_stepanov.18101961@postgrespro.ru", "phone": "+70501549235"}
0005434459214	9AB2C5	0924 707828	NATALYA YAKOVLEVA	{"email": "natalyayakovleva_051976@postgrespro.ru", "phone": "+70286010029"}
0005434459215	FEAC12	9884 187443	DMITRIY ZAKHAROV	{"phone": "+70391118385"}
0005434459216	E50371	1440 893746	KSENIYA FOMINA	{"email": "kseniya.fomina1973@postgrespro.ru", "phone": "+70372630121"}
0005434459217	E50371	2646 594185	VLADIMIR BORISOV	{"email": "vladimirborisov1977@postgrespro.ru", "phone": "+70765066919"}
0005434459218	409183	4834 554231	DARYA DANILOVA	{"phone": "+70416328104"}
0005434459219	7D2E29	7978 354554	PAVEL NIKOLAEV	{"phone": "+70710437408"}
0005434459220	7FAABD	2920 295218	SVETLANA KUZMINA	{"phone": "+70200967708"}
0005434459221	278DFB	0872 224413	PAVEL BELOV	{"phone": "+70746870668"}
0005434459222	D98939	5878 088147	VADIM ALEKSEEV	{"email": "alekseev-v.1963@postgrespro.ru", "phone": "+70298400342"}
0005434459223	D98939	3856 363744	LIDIYA MARTYNOVA	{"phone": "+70845153433"}
0005434459224	DE21F8	5852 261247	ELENA ABRAMOVA	{"email": "e_abramova_041974@postgrespro.ru", "phone": "+70725409925"}
0005434459225	DE21F8	6833 808249	LEYLA KOZLOVA	{"email": "leyla.kozlova_21051969@postgrespro.ru", "phone": "+70440312116"}
0005434459226	9F3D7C	5659 034330	KLAVDIYA ERMAKOVA	{"phone": "+70448500724"}
0005434459227	9141D6	9829 486064	VLADIMIR PETROV	{"email": "vladimir_petrov021970@postgrespro.ru", "phone": "+70304431209"}
0005434459228	41AA8D	6836 528580	SVETLANA ZAYCEVA	{"email": "zayceva.svetlana-1969@postgrespro.ru", "phone": "+70403367517"}
0005434459229	002371	6921 039647	SOFYA RODIONOVA	{"email": "rodionova-s_1975@postgrespro.ru", "phone": "+70053930791"}
0005434459230	183F2B	8849 951884	KSENIYA KOROLEVA	{"phone": "+70488660904"}
0005434459231	183F2B	7862 606305	SERGEY KUZMIN	{"phone": "+70350502674"}
0005434459232	A7D908	4255 541479	TATYANA VASILEVA	{"email": "vasileva.t1979@postgrespro.ru", "phone": "+70072274439"}
0005434459233	0EDDEF	3519 091881	NADEZHDA OSIPOVA	{"email": "osipova.n_1983@postgrespro.ru", "phone": "+70392965215"}
0005434459234	C8E06C	8423 412508	MARTA ALEKSEEVA	{"email": "alekseeva_m-1979@postgrespro.ru", "phone": "+70980834161"}
0005434459235	41D229	2892 959691	GALINA IVANOVA	{"phone": "+70600155528"}
0005434459236	6E93CC	1456 849345	EVGENIY KOROLEV	{"email": "korolevevgeniy-111973@postgrespro.ru", "phone": "+70761418699"}
0005434459237	6E93CC	5978 915937	OLGA IVANOVA	{"phone": "+70908615651"}
0005434459238	739A60	0518 058646	ELENA EFREMOVA	{"email": "efremova_elena-051967@postgrespro.ru", "phone": "+70297905302"}
0005434459239	9D9E6E	1181 218689	ALLA ALEKSANDROVA	{"phone": "+70934175826"}
0005434459240	9D9E6E	0583 392617	SVETLANA NIKIFOROVA	{"phone": "+70292636324"}
0005434459241	79315E	1940 600311	LYUDMILA SMIRNOVA	{"email": "smirnoval_1966@postgrespro.ru", "phone": "+70682467104"}
0005434459242	ED6B20	4390 054935	IRINA LUKYANOVA	{"phone": "+70797053602"}
0005434459243	8321BA	5026 279774	VIKTOR KISELEV	{"email": "kiselev_viktor-1976@postgrespro.ru", "phone": "+70952694479"}
0005434459244	8321BA	4334 486924	NATALYA MAKSIMOVA	{"phone": "+70403676840"}
0005434459245	8321BA	5711 338158	ROSTISLAV FILIPPOV	{"phone": "+70508444112"}
0005434459246	7EC000	5337 566278	PAVEL SERGEEV	{"phone": "+70475385760"}
0005434459248	5C7E96	0274 663811	SERGEY DMITRIEV	{"phone": "+70371491912"}
0005434459249	5C7E96	9093 875109	ALBINA MARTYNOVA	{"email": "martynovaalbina1976@postgrespro.ru", "phone": "+70351211759"}
0005434459250	5C7E96	8933 438666	ELENA KALININA	{"email": "kalinina.e.20081963@postgrespro.ru", "phone": "+70045258397"}
0005434459251	E79F86	9397 037829	ZINAIDA VASILEVA	{"phone": "+70231508666"}
0005434459252	A4FF19	0881 409030	MIKHAIL KOROLEV	{"phone": "+70374642372"}
0005434459253	674AC3	1048 386258	VIKTOR TIKHONOV	{"email": "tikhonov_v_101969@postgrespro.ru", "phone": "+70410862183"}
0005434459254	674AC3	6751 161537	RUSLAN GRIGOREV	{"phone": "+70009818972"}
0005434459255	6C8582	3817 414894	NIKOLAY MAKAROV	{"email": "nikolay_makarov081969@postgrespro.ru", "phone": "+70065990622"}
0005434459256	015EE7	4460 577326	ANASTASIYA EGOROVA	{"email": "anastasiya_egorova_1963@postgrespro.ru", "phone": "+70821626822"}
0005434459257	C3E953	7398 237516	ANATOLIY SHEVCHENKO	{"email": "shevchenko.anatoliy.051975@postgrespro.ru", "phone": "+70854554785"}
0005434459258	737865	5668 439243	KRISTINA KULIKOVA	{"phone": "+70999636420"}
0005434459259	67F78A	9583 856534	ZOYA DMITRIEVA	{"email": "dmitrieva_zoya_20041983@postgrespro.ru", "phone": "+70867223610"}
0005434459260	66FEBB	9869 136324	ALEKSEY VASILEV	{"email": "vasilev_aleksey_071978@postgrespro.ru", "phone": "+70738555054"}
0005434459261	5AE02B	9285 046714	YULIYA EGOROVA	{"phone": "+70334824168"}
0005434459262	5AE02B	8413 192766	VYACHESLAV ZHUKOV	{"email": "zhukov.v1979@postgrespro.ru", "phone": "+70331527517"}
0005434459263	79DE4D	3619 054524	DENIS DENISOV	{"phone": "+70007377418"}
0005434459264	7FE0F4	0400 719445	EKATERINA BORISOVA	{"email": "borisovaekaterina.071969@postgrespro.ru", "phone": "+70565997490"}
0005434459265	7FE0F4	9406 400309	OLEG FILIPPOV	{"phone": "+70722092089"}
0005434459266	0494C9	5136 249050	VALENTINA DMITRIEVA	{"email": "valentina_dmitrieva-22091967@postgrespro.ru", "phone": "+70988655340"}
0005434459267	0494C9	3673 875389	NATALYA ANDREEVA	{"email": "n.andreeva121964@postgrespro.ru", "phone": "+70349152818"}
0005434459268	B5C043	6200 387072	VALERIYA SMIRNOVA	{"email": "vsmirnova_1971@postgrespro.ru", "phone": "+70871055143"}
0005434459269	2F2EEB	0596 480617	YANA NAUMOVA	{"phone": "+70114437730"}
0005434459270	E851DC	8475 334896	VLADIMIR ZAKHAROV	{"phone": "+70926735786"}
0005434459271	E851DC	1989 423630	GENNADIY MIKHAYLOV	{"phone": "+70251980440"}
0005434459272	F1F42B	0025 991934	MARIYA NAZAROVA	{"phone": "+70676627830"}
0005434459273	858E0D	4656 380763	ANATOLIY MAKAROV	{"email": "a.makarov121967@postgrespro.ru", "phone": "+70171891335"}
0005434459274	DE9270	0773 164832	ELENA OSIPOVA	{"phone": "+70641229695"}
0005434459275	DE9270	3706 538669	ALEKSEY KAZAKOV	{"email": "aleksey-kazakov.1976@postgrespro.ru", "phone": "+70704285368"}
0005434459276	BB8F91	2244 840254	NINA ANISIMOVA	{"email": "n_anisimova_1986@postgrespro.ru", "phone": "+70761201321"}
0005434459277	BAEAAE	1118 850662	ANNA TIKHONOVA	{"email": "a.tikhonova-1986@postgrespro.ru", "phone": "+70755531077"}
0005434459278	BAEAAE	6643 044186	ANATOLIY ZAKHAROV	{"email": "a-zakharov091976@postgrespro.ru", "phone": "+70756306448"}
0005434459279	77B4C5	3390 004833	GULFIYA KOZLOVA	{"phone": "+70897740581"}
0005434459280	77B4C5	8017 161909	SVETLANA GUSEVA	{"email": "guseva.svetlana_1965@postgrespro.ru", "phone": "+70333443144"}
0005434459281	D5E56D	5248 634675	ALEKSANDR SOROKIN	{"email": "aleksandr.sorokin-1964@postgrespro.ru", "phone": "+70844289513"}
0005434459282	D5E56D	4335 767885	DENIS NIKITIN	{"email": "nikitin-denis1982@postgrespro.ru", "phone": "+70626880077"}
0005434459283	BAE6CB	5639 437752	MAKSIM MIKHAYLOV	{"phone": "+70116466480"}
0005434459284	BBCE02	8216 726344	MARIYA KONOVALOVA	{"phone": "+70200434000"}
0005434459285	F8199C	5265 071459	SERGEY BONDARENKO	{"email": "bondarenko.s.051971@postgrespro.ru", "phone": "+70753670948"}
0005434459286	EBA4F7	4929 496337	ANDREY AFANASEV	{"email": "a-afanasev.09061974@postgrespro.ru", "phone": "+70451151230"}
0005434459287	BC3133	3495 419886	ARKADIY IVANOV	{"phone": "+70897923474"}
0005434459288	4B9515	7685 888649	DENIS IVANOV	{"email": "d-ivanov_27051971@postgrespro.ru", "phone": "+70002727936"}
0005434459289	6715CD	5057 148461	TATYANA OSIPOVA	{"email": "osipova-tatyana-1978@postgrespro.ru", "phone": "+70167612813"}
0005434459290	5E1206	8086 703895	MAKSIM POPOV	{"phone": "+70841316053"}
0005434459291	5E1206	5324 248076	TATYANA SIDOROVA	{"email": "t.sidorova1965@postgrespro.ru", "phone": "+70770114873"}
0005434459292	764C3C	7667 053588	POLINA KULIKOVA	{"email": "kulikova.polina1972@postgrespro.ru", "phone": "+70137200426"}
0005434459293	764C3C	6100 101079	VERA SOKOLOVA	{"phone": "+70560752791"}
0005434459294	86D8D2	3659 342657	OLESYA SAVELEVA	{"email": "o_saveleva-13111970@postgrespro.ru", "phone": "+70129374440"}
0005434459295	EC7DD0	0908 429002	GALINA FILIPPOVA	{"email": "galina.filippova-22051976@postgrespro.ru", "phone": "+70415885015"}
0005434459296	424484	1378 202627	LYUBOV BARANOVA	{"email": "lyubov_baranova1975@postgrespro.ru", "phone": "+70834920531"}
0005434459297	C6B69F	6243 492254	VITALIY TIMOFEEV	{"phone": "+70406434058"}
0005434459298	CFFAC3	5680 662244	NINA DAVYDOVA	{"email": "n_davydova-101968@postgrespro.ru", "phone": "+70167601749"}
0005434459299	CDBBE6	5452 126392	VLADIMIR MEDVEDEV	{"email": "medvedev.vladimir_091979@postgrespro.ru", "phone": "+70186018647"}
0005434459300	CDBBE6	9513 250877	GALINA MARTYNOVA	{"phone": "+70687893540"}
0005434459301	CDBBE6	0530 325949	ALEKSEY KUZNECOV	{"email": "a_kuznecov-051972@postgrespro.ru", "phone": "+70651399772"}
0005434459302	474C77	2526 384597	NATALYA BELOVA	{"phone": "+70183664477"}
0005434459303	474C77	3376 178550	ANATOLIY KULIKOV	{"email": "kulikov.anatoliy.1967@postgrespro.ru", "phone": "+70224698597"}
0005434459304	A6ED62	6001 463104	ALEKSEY ABRAMOV	{"phone": "+70300412767"}
0005434459305	154085	2275 416278	VIKTORIYA EGOROVA	{"email": "v.egorova.021965@postgrespro.ru", "phone": "+70099870791"}
0005434459306	95A08D	0614 124413	YULIYA KOROLEVA	{"email": "ykoroleva-10111969@postgrespro.ru", "phone": "+70850460653"}
0005434459307	56E0D5	3810 308739	EKATERINA GUSEVA	{"phone": "+70085840167"}
0005434459308	0D7F43	4394 084586	MARIYA KONOVALOVA	{"email": "konovalova_m-29091973@postgrespro.ru", "phone": "+70966410546"}
0005434459309	967114	4604 308467	VLADIMIR ALEKSANDROV	{"phone": "+70993222822"}
0005434459310	D844E4	1982 954143	ANZHELIKA NESTEROVA	{"email": "nesterovaanzhelika-021979@postgrespro.ru", "phone": "+70842606476"}
0005434459311	501B6B	7453 396217	PAVEL SCHERBAKOV	{"phone": "+70475331382"}
0005434459312	9424B6	0190 993091	PAVEL MOROZOV	{"email": "morozovpavel_091968@postgrespro.ru", "phone": "+70913417568"}
0005434459313	9424B6	5453 517049	NURLAN IVANOV	{"email": "nurlan-ivanov_1981@postgrespro.ru", "phone": "+70704853135"}
0005434459314	47563B	8022 510334	ANTON BELOV	{"email": "a-belov.1973@postgrespro.ru", "phone": "+70490806981"}
0005434459315	47563B	6472 596686	SOFIYA KOVALEVA	{"email": "kovaleva-sofiya_101963@postgrespro.ru", "phone": "+70836066640"}
0005434459316	47563B	8215 785701	ILYA KRASNOV	{"email": "krasnov-i-1962@postgrespro.ru", "phone": "+70710006719"}
0005434459317	47563B	3731 610804	ALEKSEY SEMENOV	{"phone": "+70965501005"}
0005434459318	B5AA5F	1055 140810	POLINA VLASOVA	{"email": "vlasova_polina-1966@postgrespro.ru", "phone": "+70508858246"}
0005434459319	9700E0	1033 585175	LIDIYA KULIKOVA	{"email": "kulikova.lidiya.30121969@postgrespro.ru", "phone": "+70756810828"}
0005434459320	9700E0	8617 803565	KRISTINA IVANOVA	{"phone": "+70696500047"}
0005434459321	9700E0	6137 623620	TAMARA MATVEEVA	{"email": "matveeva_t_20101965@postgrespro.ru", "phone": "+70226214772"}
0005434459322	6B7232	8843 643858	NIKOLAY NIKOLAEV	{"email": "nikolaev-nikolay111981@postgrespro.ru", "phone": "+70660790737"}
0005434459323	24A248	8721 403551	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakova-aleksandra-12111968@postgrespro.ru", "phone": "+70784848435"}
0005434459324	FF1365	4567 668496	ALEKSANDRA KONOVALOVA	{"phone": "+70789399506"}
0005434459325	5F4CFB	4966 023813	NATALYA NAZAROVA	{"email": "nazarova.n-061975@postgrespro.ru", "phone": "+70546154397"}
0005434459326	39A96B	7794 349699	VYACHESLAV KARPOV	{"email": "karpov_vyacheslav_19111974@postgrespro.ru", "phone": "+70307358389"}
0005434459327	AABFB4	7771 999628	TAMARA KALININA	{"phone": "+70181524670"}
0005434459328	2ACA76	4418 019738	DENIS VLASOV	{"phone": "+70283299861"}
0005434459329	2ACA76	5070 728104	ELENA IVANOVA	{"phone": "+70887277359"}
0005434459330	FDE64B	8203 073135	VERA STEPANOVA	{"phone": "+70294763425"}
0005434459331	FDE64B	0611 266943	IGOR ANDREEV	{"phone": "+70825967397"}
0005434459332	BA5317	7115 126604	MIKHAIL IVANOV	{"phone": "+70613176416"}
0005434459333	BA5317	0214 924315	SVETLANA DENISOVA	{"phone": "+70100065631"}
0005434459334	5EB99D	1664 341845	ILYA SERGEEV	{"email": "ilyasergeev-011967@postgrespro.ru", "phone": "+70280153046"}
0005434459335	FA2065	4278 749121	PRASKOVYA BOGDANOVA	{"email": "bogdanova-praskovya.09071974@postgrespro.ru", "phone": "+70314806083"}
0005434459336	FA2065	4494 979529	DMITRIY ZHUKOV	{"phone": "+70697703379"}
0005434461655	08420A	1346 221233	VALENTINA SAVELEVA	{"phone": "+70805475377"}
0005434459337	9FBEB5	6808 199899	ALEKSANDR STEPANOV	{"email": "stepanova.081971@postgrespro.ru", "phone": "+70021789730"}
0005434459338	C46DC4	2800 211941	VLADIMIR SOROKIN	{"phone": "+70764662088"}
0005434459339	B35FE5	2644 091634	SERGEY BARANOV	{"email": "baranov.sergey.111963@postgrespro.ru", "phone": "+70418403494"}
0005434459340	3DD999	7198 379202	ALEKSANDR KUZNECOV	{"email": "a-kuznecov031969@postgrespro.ru", "phone": "+70866391710"}
0005434459341	A43CDE	9001 186824	OLGA SEMENOVA	{"email": "semenovao19011974@postgrespro.ru", "phone": "+70141374546"}
0005434459342	02C8B3	8443 855215	EVGENIY BORISOV	{"email": "borisov_e.081989@postgrespro.ru", "phone": "+70199405126"}
0005434459343	B57B8C	7356 842343	MAKSIM ROMANOV	{"email": "maksimromanov.1964@postgrespro.ru", "phone": "+70982460254"}
0005434459344	D2F72A	7891 394597	SERGEY VASILEV	{"email": "vasilev-s.031975@postgrespro.ru", "phone": "+70550813075"}
0005434459345	ADEECF	5349 756677	VALENTINA CHERNOVA	{"email": "chernova_valentina10051986@postgrespro.ru", "phone": "+70632395397"}
0005434459346	ADEECF	1960 012969	DMITRIY ILIN	{"email": "dmitriy_ilin111972@postgrespro.ru", "phone": "+70729405894"}
0005434459347	1ABC70	3607 521098	TAMARA FILATOVA	{"email": "filatovatamara-121969@postgrespro.ru", "phone": "+70989092343"}
0005434459348	1ABC70	7356 941445	IRINA FROLOVA	{"email": "frolova.irina_1978@postgrespro.ru", "phone": "+70318424302"}
0005434459349	594046	3021 091950	NIKOLAY KOZLOV	{"email": "n.kozlov24121971@postgrespro.ru", "phone": "+70420087344"}
0005434459350	6C5DAE	4000 294518	VIKTOR BELOV	{"phone": "+70512376792"}
0005434459351	250EEA	0520 628159	BORIS FROLOV	{"email": "frolov_b.111969@postgrespro.ru", "phone": "+70618782864"}
0005434459352	8D73E5	7938 004865	ANTONINA ORLOVA	{"phone": "+70548858039"}
0005434459353	A34233	3805 108126	ALEKSANDR ABRAMOV	{"phone": "+70132587577"}
0005434459354	A34233	9298 639555	ANASTASIYA BARANOVA	{"phone": "+70009068097"}
0005434459355	7D6584	5944 600572	VALENTINA SOROKINA	{"phone": "+70205281164"}
0005434459356	7D6584	6576 264769	NATALYA SERGEEVA	{"email": "sergeeva_n_29121965@postgrespro.ru", "phone": "+70531308000"}
0005434459357	2D032F	0253 895923	NATALYA VLASOVA	{"phone": "+70301047969"}
0005434459358	DAFC81	7602 630124	RUSLAN SOKOLOV	{"phone": "+70206291701"}
0005434459359	4CEE91	0525 679698	ARTUR DENISOV	{"phone": "+70897851606"}
0005434459360	4CEE91	2585 869295	ALEKSANDR MEDVEDEV	{"phone": "+70842455960"}
0005434459361	1217A0	1651 881754	YURIY ALEKSEEV	{"phone": "+70126761651"}
0005434459362	1217A0	1471 958334	ZOYA KOROLEVA	{"email": "zoya_koroleva.1974@postgrespro.ru", "phone": "+70900036441"}
0005434459363	1217A0	5399 592692	YURIY BONDARENKO	{"email": "bondarenko_yuriy-1971@postgrespro.ru", "phone": "+70960284980"}
0005434459364	B64F9B	9175 398179	ALEKSANDR POPOV	{"phone": "+70258654610"}
0005434459365	C90E15	9012 851272	IRINA SERGEEVA	{"email": "i_sergeeva.121978@postgrespro.ru", "phone": "+70038539965"}
0005434459366	EEF01D	4736 599321	ALEKSEY SIDOROV	{"email": "sidorov.aleksey_1977@postgrespro.ru", "phone": "+70686040087"}
0005434459367	EEF01D	5044 938255	PETR STEPANOV	{"phone": "+70620571039"}
0005434459368	CD012F	1586 143438	ALEKSEY VLASOV	{"email": "aleksey-vlasov.1975@postgrespro.ru", "phone": "+70268403274"}
0005434459369	1FED52	2695 831092	VASILIY STEPANOV	{"phone": "+70067701347"}
0005434459370	1FED52	4650 805139	VARVARA MOROZOVA	{"email": "v-morozova.1978@postgrespro.ru", "phone": "+70676924657"}
0005434459371	1FED52	1860 199996	VERA POPOVA	{"phone": "+70360720363"}
0005434459372	6B6A59	6928 050207	SVETLANA FROLOVA	{"email": "sfrolova1971@postgrespro.ru", "phone": "+70745245463"}
0005434459373	ED0B4C	7658 339169	VLADISLAV DMITRIEV	{"email": "v_dmitriev-1961@postgrespro.ru", "phone": "+70260921396"}
0005434459374	08D8CF	9979 396616	SOFYA KUZNECOVA	{"email": "kuznecova.s_111972@postgrespro.ru", "phone": "+70907834499"}
0005434459375	F4A4CD	1489 066909	TATYANA NAZAROVA	{"phone": "+70743619146"}
0005434459376	3EFFB9	2992 433511	RAISA YAKOVLEVA	{"phone": "+70431053101"}
0005434459377	DDCD77	9869 056612	EVGENIYA NESTEROVA	{"email": "evgeniya_nesterova-12101970@postgrespro.ru", "phone": "+70455906689"}
0005434459378	1232D3	7107 862898	GALINA VLASOVA	{"phone": "+70374444900"}
0005434459379	97BF41	0743 272065	EVGENIY ANDREEV	{"email": "evgeniyandreev_1975@postgrespro.ru", "phone": "+70244052934"}
0005434459380	619FEA	9911 352071	EVGENIY SEMENOV	{"email": "e_semenov_1977@postgrespro.ru", "phone": "+70260089415"}
0005434459381	F4AE80	1450 694805	YURIY ANDREEV	{"phone": "+70627217393"}
0005434459382	D851CB	2602 647062	DINARA ZHUKOVA	{"email": "zhukovad-22121984@postgrespro.ru", "phone": "+70290356568"}
0005434459383	DD3CBF	6233 167846	ALEKSANDR CHERNOV	{"phone": "+70476812446"}
0005434459384	F26D4D	8100 924805	VERA MATVEEVA	{"phone": "+70897890440"}
0005434459385	F26D4D	4008 205082	EVGENIY PETROV	{"phone": "+70242875860"}
0005434459386	3CB5D4	6985 089915	DMITRIY ZAYCEV	{"email": "zaycev-dmitriy_04061974@postgrespro.ru", "phone": "+70412409729"}
0005434459387	3CB5D4	3594 386358	EKATERINA KONDRATEVA	{"email": "kondratevae1974@postgrespro.ru", "phone": "+70513496617"}
0005434459388	F30CDB	6345 119292	NIKOLAY DMITRIEV	{"email": "dmitriev.nikolay.041967@postgrespro.ru", "phone": "+70420870456"}
0005434459389	F30CDB	6627 388148	MARINA MATVEEVA	{"email": "matveeva-m_19031961@postgrespro.ru", "phone": "+70028540506"}
0005434459390	C01F57	4018 064767	MARIYA GAVRILOVA	{"phone": "+70430110174"}
0005434459391	A3F678	2509 143461	OKSANA KRASNOVA	{"phone": "+70132736174"}
0005434459392	6BA21C	1842 570382	LARISA MELNIKOVA	{"phone": "+70707665099"}
0005434459393	76A085	8718 829912	EKATERINA PAVLOVA	{"phone": "+70429116196"}
0005434459394	809AA1	3475 529295	ALEKSEY GERASIMOV	{"email": "aleksey_gerasimov_21121989@postgrespro.ru", "phone": "+70929671722"}
0005434459395	E1AF7E	1905 395915	TATYANA KUZMINA	{"phone": "+70531084660"}
0005434459396	E1AF7E	3391 422675	VERONIKA ZHUKOVA	{"phone": "+70773586868"}
0005434459397	C7D2DD	8646 331459	ELENA VASILEVA	{"email": "evasileva-14091968@postgrespro.ru", "phone": "+70574105485"}
0005434459398	032D37	0220 862749	NIKOLAY NIKOLAEV	{"email": "n.nikolaev-1977@postgrespro.ru", "phone": "+70497567934"}
0005434459399	A99318	4757 142107	LIDIYA ARKHIPOVA	{"email": "arkhipova.l021973@postgrespro.ru", "phone": "+70278843345"}
0005434459400	9AF7DC	2421 432003	DMITRIY DAVYDOV	{"email": "davydov-d.12011984@postgrespro.ru", "phone": "+70596588319"}
0005434459401	882429	2636 465486	LEONID MAKSIMOV	{"phone": "+70763061656"}
0005434459402	8B3D6F	8058 038607	ANNA MELNIKOVA	{"email": "melnikova_a-06121966@postgrespro.ru", "phone": "+70601677560"}
0005434459403	BC5EE8	3586 162279	PAVEL MIKHAYLOV	{"email": "mikhaylovp17031974@postgrespro.ru", "phone": "+70855756447"}
0005434459404	85DDDA	3626 395592	MARTA LAZAREVA	{"phone": "+70586109827"}
0005434459405	3399F9	6795 639713	KSENIYA BORISOVA	{"email": "k_borisova-061974@postgrespro.ru", "phone": "+70876383612"}
0005434459406	064DBA	9561 066110	NATALIYA ZHUKOVA	{"email": "zhukova.n-07071970@postgrespro.ru", "phone": "+70041503022"}
0005434459407	064DBA	8147 520471	VALENTINA NESTEROVA	{"email": "nesterova-valentina-08101965@postgrespro.ru", "phone": "+70846034949"}
0005434459408	355DB1	8616 109274	ANDREY MOROZOV	{"email": "morozov.andrey10011963@postgrespro.ru", "phone": "+70156356947"}
0005434459409	DD664D	9034 773436	ALEKSANDR TARASOV	{"email": "aleksandrtarasov-22031971@postgrespro.ru", "phone": "+70537599240"}
0005434459410	DD664D	2690 842707	ALEKSANDR KOROLEV	{"phone": "+70148434310"}
0005434459411	8A4C46	1514 765623	VYACHESLAV NIKITIN	{"phone": "+70830721039"}
0005434459412	C59F96	5817 983658	MIKHAIL KARPOV	{"phone": "+70261353361"}
0005434459413	54CDF1	0794 694709	TATYANA ZHURAVLEVA	{"email": "zhuravleva-t_031968@postgrespro.ru", "phone": "+70421374875"}
0005434459414	DC9B7A	9137 550478	GALINA OSIPOVA	{"phone": "+70483939785"}
0005434459415	361F1E	6202 136351	VYACHESLAV FEDOROV	{"email": "vfedorov_1965@postgrespro.ru", "phone": "+70905741788"}
0005434459416	FBAB1B	6623 125870	PETR MOISEEV	{"email": "p-moiseev-1969@postgrespro.ru", "phone": "+70643408014"}
0005434459417	969965	5062 617514	TATYANA SMIRNOVA	{"email": "smirnova_tatyana.111976@postgrespro.ru", "phone": "+70409710410"}
0005434459418	969965	6468 826437	GEORGIY SIDOROV	{"phone": "+70007381327"}
0005434459419	C2B904	8319 143706	VLADIMIR MOROZOV	{"email": "vladimir.morozov1964@postgrespro.ru", "phone": "+70871722040"}
0005434459420	C2B904	3643 107223	MAKSIM SOKOLOV	{"phone": "+70443944972"}
0005434459421	E8793A	1370 516162	ANNA KUZNECOVA	{"email": "anna-kuznecova.051969@postgrespro.ru", "phone": "+70002185329"}
0005434459422	6C9CDC	5680 163824	OKSANA BARANOVA	{"email": "baranova-oksana01071972@postgrespro.ru", "phone": "+70671819918"}
0005434459423	0402ED	1603 157732	VLADIMIR STEPANOV	{"phone": "+70169195854"}
0005434460466	05C1EC	6385 480825	ELENA MOROZOVA	{"phone": "+70103814812"}
0005434460467	DE7E40	8260 544749	ALEKSEY SIDOROV	{"phone": "+70152097735"}
0005434460468	A75FD0	8877 358043	EDUARD FILIPPOV	{"email": "e_filippov_1969@postgrespro.ru", "phone": "+70504458844"}
0005434460469	E23F99	4735 735503	IRINA BARANOVA	{"email": "irina-baranova111977@postgrespro.ru", "phone": "+70765001285"}
0005434460470	A74454	9828 210362	OKSANA NOVIKOVA	{"email": "oksana.novikova021969@postgrespro.ru", "phone": "+70851286258"}
0005434460471	990327	9541 559484	KIRILL AFANASEV	{"email": "kirill-afanasev_091973@postgrespro.ru", "phone": "+70356054396"}
0005434460472	A31C21	5608 143707	KONSTANTIN DENISOV	{"email": "konstantindenisov07101962@postgrespro.ru", "phone": "+70169988139"}
0005434460473	30EF32	9102 622177	VALENTINA GERASIMOVA	{"email": "gerasimovav.051986@postgrespro.ru", "phone": "+70660907617"}
0005434460474	405DAD	7882 940461	ANDREY EGOROV	{"email": "a_egorov25111975@postgrespro.ru", "phone": "+70377426986"}
0005434460475	130C04	3406 067756	DARYA KUZMINA	{"email": "kuzmina_d.061975@postgrespro.ru", "phone": "+70411603783"}
0005434460476	977041	8342 949542	FATIMA MAKAROVA	{"email": "fatima.makarova.111979@postgrespro.ru", "phone": "+70067900837"}
0005434460477	D8B01F	4899 266169	ANASTASIYA ABRAMOVA	{"email": "abramovaanastasiya.101966@postgrespro.ru", "phone": "+70928292570"}
0005434460478	0BD6F7	6613 512574	RUSTAM VOLKOV	{"phone": "+70728857056"}
0005434460479	1F2CDD	5042 790823	YULIYA BELYAEVA	{"phone": "+70465807545"}
0005434460480	FD2A00	1539 492671	VITALIY DENISOV	{"phone": "+70848201602"}
0005434460481	012076	2596 834938	VIKTOR NIKOLAEV	{"phone": "+70581701505"}
0005434460482	012076	4686 847937	MAKSIM SMIRNOV	{"email": "maksim-smirnov.091966@postgrespro.ru", "phone": "+70348638811"}
0005434460483	012076	4456 314294	ANATOLIY YAKOVLEV	{"email": "yakovlev_anatoliy-04111975@postgrespro.ru", "phone": "+70611934339"}
0005434460484	6B83E0	9431 099824	ILNUR ALEKSANDROV	{"email": "aleksandrov.i-04061969@postgrespro.ru", "phone": "+70633621768"}
0005434460485	825A44	4062 237880	ALEKSANDRA LEBEDEVA	{"phone": "+70798748996"}
0005434460486	825A44	6028 780917	TATYANA MAKAROVA	{"phone": "+70822405516"}
0005434460487	244AF7	3612 663854	DMITRIY SIDOROV	{"email": "sidorovd-1960@postgrespro.ru", "phone": "+70837658676"}
0005434460488	C175F1	0999 708464	YULIYA PAVLOVA	{"email": "ypavlova1960@postgrespro.ru", "phone": "+70102089068"}
0005434460489	C175F1	4299 671662	VALERIYA STEPANOVA	{"email": "valeriyastepanova-1981@postgrespro.ru", "phone": "+70442668010"}
0005434460490	C175F1	5989 202813	IRINA SOLOVEVA	{"phone": "+70816432509"}
0005434460491	FCE4C4	1165 902144	ANATOLIY KUDRYASHOV	{"phone": "+70238822479"}
0005434460492	FCE4C4	0915 835351	ILSHAT KULIKOV	{"phone": "+70774140243"}
0005434460493	D27ED2	5765 667786	ILYA KUZNECOV	{"phone": "+70060056311"}
0005434460494	D27ED2	5340 544193	MARIYA SERGEEVA	{"email": "sergeevam-1974@postgrespro.ru", "phone": "+70428146009"}
0005434460495	B9EEE8	7483 878844	NINA DMITRIEVA	{"email": "dmitrieva_nina11051979@postgrespro.ru", "phone": "+70045458864"}
0005434460496	B9EEE8	2751 052297	VALERIY BELOV	{"phone": "+70518081766"}
0005434460497	E957D5	8616 876537	GENNADIY OSIPOV	{"email": "osipov-gennadiy-051983@postgrespro.ru", "phone": "+70405765082"}
0005434460498	51735D	2256 905105	YAROSLAV VASILEV	{"phone": "+70449329086"}
0005434460499	F3F726	2127 192392	ANATOLIY ISAEV	{"email": "isaev-anatoliy.081977@postgrespro.ru", "phone": "+70416660889"}
0005434460500	864BEC	9258 973076	MARIYA KALININA	{"phone": "+70400427758"}
0005434460501	819B53	5029 996758	TATYANA AFANASEVA	{"phone": "+70490303874"}
0005434460502	7AB094	2070 433735	ELENA SOKOLOVA	{"email": "sokolova.e.1972@postgrespro.ru", "phone": "+70965060755"}
0005434460503	7AB094	6006 907793	ALEKSANDRA SOKOLOVA	{"email": "aleksandra.sokolova.13091979@postgrespro.ru", "phone": "+70583079968"}
0005434460504	781369	5339 465740	SERGEY RODIONOV	{"phone": "+70470258831"}
0005434460505	A350B9	0794 857550	ELIZAVETA RODIONOVA	{"email": "rodionova-elizaveta_05061977@postgrespro.ru", "phone": "+70693264608"}
0005434460506	C74BF2	0932 820842	VIKTOR IVANOV	{"phone": "+70847119206"}
0005434460507	C74BF2	1053 762429	ALEKSEY SEMENOV	{"email": "a-semenov.12071974@postgrespro.ru", "phone": "+70267835249"}
0005434460508	BF4071	6856 370299	OLGA IVANOVA	{"email": "o-ivanova_27111972@postgrespro.ru", "phone": "+70277113342"}
0005434460509	2E73F5	2546 308038	SVETLANA SEMENOVA	{"phone": "+70020563339"}
0005434460510	2E73F5	4267 314828	IGOR KUZNECOV	{"email": "igorkuznecov_03051961@postgrespro.ru", "phone": "+70004206244"}
0005434460511	CBE801	1151 892019	MAKSIM ALEKSANDROV	{"email": "aleksandrov.maksim.25051973@postgrespro.ru", "phone": "+70819606194"}
0005434460512	FD76DF	4747 787786	NATALYA RYABOVA	{"phone": "+70368117108"}
0005434460513	A729A0	5767 206559	VLADIMIR GUSEV	{"phone": "+70682842725"}
0005434460514	835F34	8360 993169	VLADIMIR POPOV	{"phone": "+70276845518"}
0005434460515	23D655	6215 951431	IRINA EGOROVA	{"email": "egorova-irina021973@postgrespro.ru", "phone": "+70821217510"}
0005434460516	23D655	0804 496600	ANDREY KULIKOV	{"phone": "+70581732575"}
0005434460517	F5D0EA	8695 653322	GALINA KULIKOVA	{"email": "galina-kulikova22101976@postgrespro.ru", "phone": "+70642142998"}
0005434460518	531F71	8795 006930	EKATERINA DANILOVA	{"phone": "+70444231935"}
0005434460519	A9299E	6594 813796	MARIYA NIKIFOROVA	{"email": "nikiforova-m041974@postgrespro.ru", "phone": "+70410462289"}
0005434460520	A9299E	0842 064900	ARTEM ROMANOV	{"email": "romanov.artem-24051981@postgrespro.ru", "phone": "+70843470452"}
0005434460521	CD4569	3157 107506	NINA ZHUKOVA	{"phone": "+70448928800"}
0005434460522	CD4569	4072 016986	VLADIMIR KOROLEV	{"phone": "+70434882448"}
0005434460523	A3C80C	1064 480749	LYUDMILA ALEKSEEVA	{"email": "lyudmila-alekseeva.1976@postgrespro.ru", "phone": "+70343552271"}
0005434460524	E47378	6970 143874	OLGA KOROLEVA	{"phone": "+70422123842"}
0005434460525	A6620D	5697 305251	SERGEY MARTYNOV	{"phone": "+70692111117"}
0005434460526	7228DC	2166 265276	IRINA NESTEROVA	{"email": "nesterova.i.31051970@postgrespro.ru", "phone": "+70928946134"}
0005434460527	1B3867	7427 456673	GALIYA DAVYDOVA	{"phone": "+70865114433"}
0005434460528	1B3867	8701 124806	OLEG BELOV	{"email": "oleg_belov22031964@postgrespro.ru", "phone": "+70082558710"}
0005434460529	A18A71	3119 255846	VALERIY NAZAROV	{"email": "v.nazarov_051975@postgrespro.ru", "phone": "+70748615751"}
0005434460530	A18A71	3000 378586	TATYANA SCHERBAKOVA	{"email": "tatyana_scherbakova.061983@postgrespro.ru", "phone": "+70328800004"}
0005434460531	5E7985	4076 653109	ALEKSANDR ALEKSEEV	{"phone": "+70346548210"}
0005434460532	5E7985	0263 974254	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova.mariya.05121959@postgrespro.ru", "phone": "+70728056755"}
0005434460533	5BD9BD	1617 908898	ANASTASIYA NIKOLAEVA	{"email": "nikolaeva-anastasiya_061968@postgrespro.ru", "phone": "+70259522707"}
0005434460534	4BA2E4	2781 851123	SERGEY KRASNOV	{"email": "krasnov_sergey_041982@postgrespro.ru", "phone": "+70718499429"}
0005434460535	4803BD	9943 481656	OLGA LOGINOVA	{"email": "olga-loginova.051968@postgrespro.ru", "phone": "+70311061806"}
0005434460536	4803BD	6255 905749	ANASTASIYA VOLKOVA	{"email": "anastasiya.volkova_04111962@postgrespro.ru", "phone": "+70146952376"}
0005434460537	83AE86	6674 155243	VALENTINA MATVEEVA	{"email": "vmatveeva22051981@postgrespro.ru", "phone": "+70857524774"}
0005434460538	B5BF55	2244 161383	LYUDMILA GAVRILOVA	{"email": "gavrilova.lyudmila08011963@postgrespro.ru", "phone": "+70911873052"}
0005434460539	05FD42	3953 378225	ZINAIDA MIKHAYLOVA	{"email": "mikhaylova_z021974@postgrespro.ru", "phone": "+70710263998"}
0005434460540	3EFA3A	9648 425599	KLAVDIYA SEMENOVA	{"phone": "+70253542729"}
0005434460541	63C369	1170 672060	OLGA KUZNECOVA	{"phone": "+70022433428"}
0005434460542	4B1A92	8663 264361	ZOYA LAZAREVA	{"phone": "+70767461489"}
0005434460543	4B1A92	0026 890694	ANDREY ROMANOV	{"phone": "+70045243635"}
0005434460544	356C46	7156 334487	OLESYA LOGINOVA	{"email": "loginovao27121967@postgrespro.ru", "phone": "+70382281864"}
0005434460545	B69EA5	1878 761507	VLADIMIR MAKAROV	{"email": "vmakarov_19041980@postgrespro.ru", "phone": "+70075143258"}
0005434460546	B69EA5	7414 640147	VALENTINA TIKHONOVA	{"phone": "+70264670443"}
0005434460547	1263CE	9870 540172	KSENIYA KARPOVA	{"email": "k-karpova-031982@postgrespro.ru", "phone": "+70676967484"}
0005434460548	1B31FB	0896 229906	KIRA ARKHIPOVA	{"phone": "+70187368734"}
0005434460549	1B31FB	4754 288463	ARTEM SHEVCHENKO	{"email": "a.shevchenko.25071977@postgrespro.ru", "phone": "+70206464049"}
0005434460550	151786	9072 371689	STANISLAV OSIPOV	{"email": "osipov.stanislav25111988@postgrespro.ru", "phone": "+70415907685"}
0005434460551	151786	9442 877753	OLEG BONDARENKO	{"email": "olegbondarenko-1969@postgrespro.ru", "phone": "+70105775732"}
0005434460552	151786	0136 337566	SERGEY STEPANOV	{"email": "sergey.stepanov_071979@postgrespro.ru", "phone": "+70507910135"}
0005434460553	5A3436	2089 999542	VIKTOR FROLOV	{"phone": "+70056103876"}
0005434460554	5A3436	6291 049073	NATALYA KULIKOVA	{"email": "kulikovanatalya29081966@postgrespro.ru", "phone": "+70132861315"}
0005434460555	F4B1C2	6217 759904	PETR FILIPPOV	{"email": "filippovpetr-18031966@postgrespro.ru", "phone": "+70827394398"}
0005434460556	F4B1C2	0748 953306	NIKOLAY EGOROV	{"phone": "+70327771685"}
0005434460557	0E8B7A	3846 987494	VIKTORIYA TARASOVA	{"email": "tarasova_viktoriya.02081966@postgrespro.ru", "phone": "+70270032991"}
0005434460558	0E8B7A	0308 120273	TATYANA RYABOVA	{"email": "ryabova.t_061969@postgrespro.ru", "phone": "+70193276881"}
0005434460559	0E8B7A	2279 507043	ALINA SOLOVEVA	{"email": "alinasoloveva_121958@postgrespro.ru", "phone": "+70345159986"}
0005434460560	28C83E	0659 756270	OLGA RODIONOVA	{"phone": "+70318346001"}
0005434460561	AB8A1A	9075 364093	YANA VOLKOVA	{"email": "y_volkova_1980@postgrespro.ru", "phone": "+70124440371"}
0005434460562	AB8A1A	6048 420236	DARYA GUSEVA	{"email": "guseva-d.061974@postgrespro.ru", "phone": "+70227819687"}
0005434460563	03F407	4208 326092	VITALIY IVANOV	{"email": "vitaliy-ivanov.051976@postgrespro.ru", "phone": "+70413491820"}
0005434460564	03F407	5526 367633	GALINA NIKOLAEVA	{"phone": "+70894780127"}
0005434460565	9AE021	0052 670439	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana_1968@postgrespro.ru", "phone": "+70241018382"}
0005434460566	9AE021	5306 324471	GENNADIY ZHURAVLEV	{"phone": "+70072378634"}
0005434461608	51F050	1942 443523	YURIY VLASOV	{"email": "vlasov.yuriy.061972@postgrespro.ru", "phone": "+70634509683"}
0005434461609	2B9C9B	6857 762127	OKSANA KOROLEVA	{"email": "o_koroleva.22071965@postgrespro.ru", "phone": "+70474730695"}
0005434461610	2B9C9B	1319 372967	ELENA NIKITINA	{"phone": "+70175655922"}
0005434461611	9D37B0	6450 361177	NATALYA KULIKOVA	{"phone": "+70002962347"}
0005434461612	A8CEDD	1540 784687	VALERIY ILIN	{"email": "valeriy.ilin1963@postgrespro.ru", "phone": "+70060520667"}
0005434461613	590C2A	0403 130719	NATALYA VASILEVA	{"phone": "+70693487535"}
0005434461614	AD4A04	5440 764406	TAISIYA ANTONOVA	{"email": "taisiya_antonova031973@postgrespro.ru", "phone": "+70222055384"}
0005434461615	7B2D44	5684 822580	INNA KULIKOVA	{"email": "kulikova_inna.10031985@postgrespro.ru", "phone": "+70448451764"}
0005434461616	C772A3	2112 823589	ANDREY KUDRYASHOV	{"email": "andrey_kudryashov.111973@postgrespro.ru", "phone": "+70277993245"}
0005434461617	C772A3	2298 052462	NADEZHDA VOROBEVA	{"email": "vorobevan1974@postgrespro.ru", "phone": "+70488933405"}
0005434461618	2E5CA0	2999 098693	NIKOLAY SOROKIN	{"email": "nikolay-sorokin.051974@postgrespro.ru", "phone": "+70889406497"}
0005434461619	2E5CA0	6067 209552	ARTEM VOLKOV	{"phone": "+70977264414"}
0005434461620	2E5CA0	7916 112166	LYUDMILA PAVLOVA	{"email": "l.pavlova1968@postgrespro.ru", "phone": "+70234330977"}
0005434461621	BEF93E	9780 871902	DENIS VOLKOV	{"email": "volkov.denis.111978@postgrespro.ru", "phone": "+70274147174"}
0005434461622	801B18	6085 770445	NADEZHDA NESTEROVA	{"phone": "+70976595345"}
0005434461623	801B18	1106 851815	VLADIMIR BORISOV	{"phone": "+70865365952"}
0005434461624	262BD9	8521 244438	NATALYA TROFIMOVA	{"phone": "+70864930580"}
0005434461625	02BBB5	7781 267311	ANDREY NAUMOV	{"email": "naumov_andrey09041969@postgrespro.ru", "phone": "+70491961105"}
0005434461626	02BBB5	0266 724702	ELENA KOLESNIKOVA	{"email": "kolesnikovae_121977@postgrespro.ru", "phone": "+70238894745"}
0005434461627	02BBB5	2770 610604	ALEKSEY NAUMOV	{"phone": "+70714698893"}
0005434461628	7DB97E	3819 842958	VITALIY ANTONOV	{"phone": "+70419842420"}
0005434461629	FBF098	3152 159292	ANDREY EGOROV	{"email": "egorov-andrey_10101972@postgrespro.ru", "phone": "+70508455595"}
0005434461630	FBF098	0979 567233	EKATERINA SCHERBAKOVA	{"email": "scherbakova_e_14121964@postgrespro.ru", "phone": "+70259883855"}
0005434461631	4FCA92	6710 450268	ANNA KALININA	{"phone": "+70128464894"}
0005434461632	E4C0CD	0066 334484	VALERIY ILIN	{"email": "ilin.valeriy_071975@postgrespro.ru", "phone": "+70881051777"}
0005434461633	E4C0CD	3442 574374	ALEKSEY FROLOV	{"email": "frolov.aleksey_061980@postgrespro.ru", "phone": "+70532422708"}
0005434461634	1A5A34	0703 680533	SOFYA IVANOVA	{"email": "ivanova-sofya.31031963@postgrespro.ru", "phone": "+70679738361"}
0005434461635	A25E57	9213 256849	EMILIYA NIKITINA	{"email": "nikitina_emiliya13011967@postgrespro.ru", "phone": "+70915466595"}
0005434461636	A25E57	9681 295466	LIDIYA IVANOVA	{"email": "lidiya.ivanova101977@postgrespro.ru", "phone": "+70229827454"}
0005434461637	A25E57	7790 755544	ELIZAVETA ZHURAVLEVA	{"phone": "+70830870340"}
0005434461638	432E36	6662 914166	ALEKSEY SEMENOV	{"email": "semenov.aleksey.11011985@postgrespro.ru", "phone": "+70656812197"}
0005434461639	629EF8	5718 399837	VERA MOROZOVA	{"email": "morozova_v1963@postgrespro.ru", "phone": "+70315283472"}
0005434461640	A988A9	8680 427352	MARIYA MOISEEVA	{"email": "mariya-moiseeva-1990@postgrespro.ru", "phone": "+70285962662"}
0005434461641	A988A9	3022 143665	ANDREY KOZLOV	{"phone": "+70578954987"}
0005434461642	410A9C	7895 132643	NATALYA RODIONOVA	{"email": "rodionova-n_13011971@postgrespro.ru", "phone": "+70757420947"}
0005434461643	410A9C	7459 015219	ALEKSANDR KOROLEV	{"phone": "+70247963981"}
0005434461644	410A9C	7442 231262	ALEKSANDR KUZNECOV	{"phone": "+70989757979"}
0005434461645	38D4BF	8830 135989	SERGEY MARTYNOV	{"email": "sergeymartynov.1966@postgrespro.ru", "phone": "+70287791010"}
0005434461646	E79CA9	5821 484841	ALEKSANDR ABRAMOV	{"phone": "+70975621815"}
0005434461647	E79CA9	7198 076383	DARYA BORISOVA	{"phone": "+70207398711"}
0005434461648	DF602F	3464 657970	GALINA ANTONOVA	{"phone": "+70648656388"}
0005434461649	87906D	4793 684891	IGOR IVANOV	{"phone": "+70218147232"}
0005434461650	78D230	8416 939335	NINA ANISIMOVA	{"phone": "+70570472466"}
0005434461651	65CEF0	9407 537937	MARINA KOZLOVA	{"phone": "+70702019928"}
0005434461652	65CEF0	4220 162802	IVAN NIKITIN	{"email": "nikitin-ivan22041965@postgrespro.ru", "phone": "+70686494506"}
0005434461653	CF6D05	1641 863675	IRINA FROLOVA	{"email": "frolova.i051971@postgrespro.ru", "phone": "+70811263593"}
0005434461654	EDEEB4	6728 427703	SVETLANA KONDRATEVA	{"phone": "+70003784968"}
0005434461656	3EA7DD	4702 448810	INESSA PETROVA	{"email": "petrova.i-111978@postgrespro.ru", "phone": "+70799736878"}
0005434461657	658A3C	5477 482533	PETR OSIPOV	{"phone": "+70041589461"}
0005434461658	96AFB1	9145 448511	NIKOLAY PETROV	{"email": "n-petrov_1973@postgrespro.ru", "phone": "+70549809319"}
0005434461659	96AFB1	8393 860241	NATALYA ROMANOVA	{"email": "romanova-natalya-1969@postgrespro.ru", "phone": "+70452825884"}
0005434461660	EF1824	6035 711940	VITALIY MEDVEDEV	{"email": "vitaliy_medvedev10061968@postgrespro.ru", "phone": "+70931427755"}
0005434461661	EF1824	8007 975637	IRINA KUZNECOVA	{"email": "kuznecovai_051972@postgrespro.ru", "phone": "+70645194507"}
0005434461662	E6EA69	2219 251403	IRINA EFIMOVA	{"email": "irinaefimova1966@postgrespro.ru", "phone": "+70646115840"}
0005434461663	E6EA69	2290 021695	VIKTORIYA KUZMINA	{"phone": "+70228564951"}
0005434461664	E01C3B	5954 996279	KONSTANTIN NIKOLAEV	{"email": "knikolaev-1974@postgrespro.ru", "phone": "+70508622569"}
0005434461665	E01C3B	2160 741211	ALEKSEY FOMIN	{"phone": "+70465716914"}
0005434461666	17D31C	0487 958708	YURIY POPOV	{"email": "popov.yuriy.121972@postgrespro.ru", "phone": "+70210877047"}
0005434461667	E7A8E0	7906 461270	KLAVDIYA ARKHIPOVA	{"email": "arkhipova_klavdiya07121962@postgrespro.ru", "phone": "+70277963506"}
0005434461668	A7434B	3371 708046	ALEKSANDR GAVRILOV	{"email": "gavrilov-a_20111978@postgrespro.ru", "phone": "+70651586424"}
0005434461669	A7434B	0171 041683	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov12061973@postgrespro.ru", "phone": "+70439261596"}
0005434461670	BAC1C9	8277 851024	MARGARITA MATVEEVA	{"email": "margarita.matveeva.30091983@postgrespro.ru", "phone": "+70787784796"}
0005434461671	BAC1C9	9737 633079	VLADIMIR MOISEEV	{"phone": "+70612042533"}
0005434461672	997128	8610 670630	SVETLANA OSIPOVA	{"email": "osipova-svetlana.011975@postgrespro.ru", "phone": "+70506811227"}
0005434461673	997128	1449 788545	ALEKSANDR FEDOTOV	{"phone": "+70049534144"}
0005434461674	034C4D	4679 214466	ANTON SOLOVEV	{"email": "solovev-a.041972@postgrespro.ru", "phone": "+70160267856"}
0005434461675	034C4D	5562 969412	VLADIMIR IVANOV	{"phone": "+70159993754"}
0005434461676	086220	2091 544227	ALEKSEY PAVLOV	{"email": "pavlova1969@postgrespro.ru", "phone": "+70629189732"}
0005434461677	666C69	4452 880764	VITALIY MELNIKOV	{"phone": "+70034172238"}
0005434461678	BD3F3D	0191 021426	TATYANA TROFIMOVA	{"email": "tatyana.trofimova-1968@postgrespro.ru", "phone": "+70115632888"}
0005434461679	EA3202	6541 474142	ANATOLIY IVANOV	{"email": "ivanov-a.03031971@postgrespro.ru", "phone": "+70822364299"}
0005434461680	EA3202	5359 446092	LARISA IVANOVA	{"phone": "+70423448036"}
0005434461681	701D18	5824 095390	GALIYA GERASIMOVA	{"email": "galiya-gerasimova-05061982@postgrespro.ru", "phone": "+70193283032"}
0005434461682	2ED38A	9069 720951	IGOR POPOV	{"phone": "+70293750521"}
0005434461683	451FC3	8638 320197	IVAN MIKHAYLOV	{"email": "i_mikhaylov-041968@postgrespro.ru", "phone": "+70312413188"}
0005434461684	DF579B	9075 838493	VYACHESLAV NOVIKOV	{"email": "novikov_vyacheslav.14071964@postgrespro.ru", "phone": "+70937461076"}
0005434461685	3CF8CA	6189 542941	MARIYA ORLOVA	{"phone": "+70264622580"}
0005434461686	3CF8CA	7943 260381	VALENTINA DAVYDOVA	{"phone": "+70702796821"}
0005434461687	6F42EE	7222 041901	MARIYA IVANOVA	{"phone": "+70180484136"}
0005434461688	6F42EE	1069 995475	LYUBOV MIKHAYLOVA	{"phone": "+70376258829"}
0005434461689	824F23	1551 595307	OLESYA VASILEVA	{"phone": "+70808175043"}
0005434461690	7E8138	7911 959723	ANASTASIYA MOROZOVA	{"phone": "+70236016603"}
0005434461691	A6AC4F	2768 441598	ALEKSANDR STEPANOV	{"phone": "+70333356676"}
0005434461692	B91DF6	1087 491823	VALENTINA VLASOVA	{"email": "vlasova-valentina.1969@postgrespro.ru", "phone": "+70335622821"}
0005434461693	B91DF6	9219 209693	SERGEY FROLOV	{"email": "sfrolov-1984@postgrespro.ru", "phone": "+70517087085"}
0005434461694	8A4A35	6189 563384	NATALYA MASLOVA	{"email": "natalya.maslova081975@postgrespro.ru", "phone": "+70451325205"}
0005434461695	294178	6418 403981	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy02011965@postgrespro.ru", "phone": "+70481532976"}
0005434461696	7CAC56	5764 797442	ZHANNA MAKSIMOVA	{"email": "maksimova-zhanna_091973@postgrespro.ru", "phone": "+70175111948"}
0005434461697	19C43E	7455 590449	SVETLANA FOMINA	{"email": "fomina-s_13051977@postgrespro.ru", "phone": "+70223248935"}
0005434461698	19C43E	6467 033290	REGINA ZAKHAROVA	{"email": "zakharovar111975@postgrespro.ru", "phone": "+70956164398"}
0005434461699	FDDA2C	6222 811521	RAMIS MAKSIMOV	{"email": "maksimov.ramis_1976@postgrespro.ru", "phone": "+70062429590"}
0005434461700	BC1AD8	4574 249520	VLADISLAV VASILEV	{"phone": "+70601283285"}
0005434461701	BC1AD8	9491 609019	NATALYA ABRAMOVA	{"email": "n-abramova17041977@postgrespro.ru", "phone": "+70887167230"}
0005434461702	404908	1318 856779	KRISTINA ABRAMOVA	{"phone": "+70108618479"}
0005434461703	404908	4804 514052	IGOR MOROZOV	{"phone": "+70173409317"}
0005434461704	BAB98B	5785 996072	ALEKSANDR MOROZOV	{"phone": "+70509046124"}
0005434461705	362AEB	9765 746263	BOGDAN BONDARENKO	{"email": "bogdan.bondarenko-061964@postgrespro.ru", "phone": "+70711669819"}
0005434461706	90BB6A	3017 628327	VLADIMIR VASILEV	{"email": "vladimir.vasilev-1968@postgrespro.ru", "phone": "+70799530450"}
0005434461707	13974D	8280 947832	DMITRIY KUZMIN	{"email": "d-kuzmin.1971@postgrespro.ru", "phone": "+70722066560"}
0005434461708	5C6A70	8945 210167	EDUARD KRASNOV	{"phone": "+70078604572"}
0005434461709	36C5C5	8774 596332	VIKTOR FROLOV	{"phone": "+70780150005"}
0005434461710	36C5C5	7807 577918	ANATOLIY ABRAMOV	{"email": "anatoliyabramov.31031972@postgrespro.ru", "phone": "+70345409529"}
0005434461711	BF2DCB	6762 777378	ARTEMIY KULIKOV	{"email": "kulikov.artemiy-24011979@postgrespro.ru", "phone": "+70062130438"}
0005434461712	BF2DCB	6741 517724	DARYA KUDRYASHOVA	{"email": "darya_kudryashova16031968@postgrespro.ru", "phone": "+70735960449"}
0005434462812	346DE5	6128 243475	ELENA IVANOVA	{"phone": "+70385209602"}
0005434462752	CCE882	7104 496610	OKSANA SOROKINA	{"email": "sorokina.oksana_061979@postgrespro.ru", "phone": "+70573521800"}
0005434462753	99A5D2	3846 889108	VLADIMIR MOISEEV	{"phone": "+70918776275"}
0005434462754	038247	2225 247376	YURIY BORISOV	{"email": "borisovyuriy_1977@postgrespro.ru", "phone": "+70977211761"}
0005434462755	AFF7B2	3034 901947	ELENA TARASOVA	{"phone": "+70855793011"}
0005434462756	341E34	2841 143921	GULFIYA NIKOLAEVA	{"phone": "+70485668241"}
0005434462757	8EAEB0	7129 935074	ALEKSANDR FOMIN	{"email": "aleksandrfomin_1966@postgrespro.ru", "phone": "+70612780075"}
0005434462758	F12CEA	7994 139465	DINARA ZHURAVLEVA	{"phone": "+70855090168"}
0005434462759	C479B1	3883 916711	KLAVDIYA POTAPOVA	{"email": "potapova_klavdiya1975@postgrespro.ru", "phone": "+70207392983"}
0005434462760	8B3A42	0340 209107	DINARA NIKOLAEVA	{"phone": "+70176657757"}
0005434462761	938A5D	3486 873741	EVDOKIYA BARANOVA	{"phone": "+70854053390"}
0005434462762	DB652C	5732 271715	OLGA IVANOVA	{"phone": "+70946687222"}
0005434462763	DB652C	8514 349210	LYUDMILA NESTEROVA	{"email": "nesterova_l.1976@postgrespro.ru", "phone": "+70317370426"}
0005434462764	5B2BDF	5509 890174	LYUDMILA OSIPOVA	{"email": "lyudmila.osipova-121978@postgrespro.ru", "phone": "+70610221970"}
0005434462765	F47B82	5658 303167	VALENTINA EGOROVA	{"email": "egorova_v_1954@postgrespro.ru", "phone": "+70450688396"}
0005434462766	2C8C73	3225 216463	NATALYA GERASIMOVA	{"email": "gerasimovan-1967@postgrespro.ru", "phone": "+70664221754"}
0005434462767	0DC9A5	8083 538358	ANNA MOROZOVA	{"phone": "+70979731284"}
0005434462768	967FA2	3101 907740	ALEKSANDRA CHERNOVA	{"email": "achernova_1980@postgrespro.ru", "phone": "+70719761113"}
0005434462769	C77FA2	8413 575203	NIKOLAY VASILEV	{"phone": "+70439171040"}
0005434462770	52EFF5	1364 811274	YULIYA FADEEVA	{"email": "fadeeva-yuliya_17041976@postgrespro.ru", "phone": "+70686154903"}
0005434462771	A76A94	6883 349003	OLGA MELNIKOVA	{"email": "melnikova-olga-28041970@postgrespro.ru", "phone": "+70793462222"}
0005434462772	6A1F2B	9705 125921	VLADIMIR KAZAKOV	{"email": "vkazakov.10081968@postgrespro.ru", "phone": "+70984631605"}
0005434462773	9C8139	5079 736858	OKSANA GRISHINA	{"phone": "+70040416560"}
0005434462774	A7A40B	6317 430545	NADEZHDA STEPANOVA	{"phone": "+70528045984"}
0005434462775	22DFA3	3813 118816	TATYANA DENISOVA	{"phone": "+70318036994"}
0005434462776	AABCC6	6406 500939	ALEKSEY NIKITIN	{"phone": "+70997701961"}
0005434462777	9693E7	2625 085386	NIKITA BELOV	{"phone": "+70457296140"}
0005434462778	9693E7	8333 507520	SERGEY TIMOFEEV	{"email": "sergey-timofeev-19061963@postgrespro.ru", "phone": "+70122027277"}
0005434462779	9693E7	6771 530653	ELENA SERGEEVA	{"phone": "+70749473179"}
0005434462780	75A6B0	7459 327953	KRISTINA NOVIKOVA	{"email": "novikova-k_1980@postgrespro.ru", "phone": "+70121714825"}
0005434462781	E8272D	0031 972512	VIKTOR ILIN	{"email": "ilin.v_111973@postgrespro.ru", "phone": "+70444647522"}
0005434462782	61A393	2289 344554	ALENA PETROVA	{"phone": "+70338995373"}
0005434462783	33BFA0	3231 182651	GALINA SEMENOVA	{"phone": "+70853125851"}
0005434462784	D508D4	8598 710130	ANATOLIY ILIN	{"email": "ilin.a-021965@postgrespro.ru", "phone": "+70688966437"}
0005434462785	9680DB	8482 438219	DMITRIY STEPANOV	{"phone": "+70247870045"}
0005434462786	9680DB	6633 194616	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr.031979@postgrespro.ru", "phone": "+70467651290"}
0005434462787	9E13F8	4950 985537	VLADIMIR GAVRILOV	{"phone": "+70194286151"}
0005434462788	6A732D	5670 673122	VITALIY RODIONOV	{"email": "vrodionov.061967@postgrespro.ru", "phone": "+70907056697"}
0005434462789	E85F16	3803 040478	SVETLANA ROMANOVA	{"phone": "+70477057259"}
0005434462790	19BE1F	6107 126757	EGOR AFANASEV	{"phone": "+70190564481"}
0005434462791	475BAB	5486 715641	PAVEL MOROZOV	{"email": "p_morozov_28081984@postgrespro.ru", "phone": "+70350388074"}
0005434462792	475BAB	6115 720967	TATYANA KISELEVA	{"email": "tatyana.kiseleva.08031975@postgrespro.ru", "phone": "+70806111592"}
0005434462793	0FDEB0	4729 334975	EVDOKIYA KRASNOVA	{"email": "ekrasnova_041968@postgrespro.ru", "phone": "+70784249028"}
0005434462794	C2FBB2	7949 416521	DENIS IVANOV	{"email": "ivanov_denis18111976@postgrespro.ru", "phone": "+70499901400"}
0005434462795	A2079F	4574 448679	LYUBOV GERASIMOVA	{"phone": "+70654874074"}
0005434462796	A2079F	4128 968040	KSENIYA ARKHIPOVA	{"phone": "+70188227410"}
0005434462797	13621E	3443 705929	ZINAIDA MAKAROVA	{"email": "makarovazinaida111972@postgrespro.ru", "phone": "+70844083198"}
0005434462798	1AD9E3	4075 221966	ANASTASIYA GAVRILOVA	{"phone": "+70009196176"}
0005434462799	2AFCC6	8470 067672	SERGEY DAVYDOV	{"email": "davydov_sergey_08041968@postgrespro.ru", "phone": "+70992578584"}
0005434462800	298715	0341 688017	TAMARA KOLESNIKOVA	{"email": "tkolesnikova_031980@postgrespro.ru", "phone": "+70222253176"}
0005434462801	298715	3755 557165	LYUDMILA POLYAKOVA	{"phone": "+70715652617"}
0005434462802	AA2157	3225 424530	DMITRIY MIRONOV	{"email": "mironov-d-15041991@postgrespro.ru", "phone": "+70172724716"}
0005434462803	AA2157	8633 285815	TATYANA FEDOROVA	{"phone": "+70955997696"}
0005434462804	05B829	0878 061725	OLGA POPOVA	{"email": "popova-olga_1992@postgrespro.ru", "phone": "+70782054682"}
0005434462805	AD0DC6	4920 350982	IVAN ALEKSEEV	{"email": "i.alekseev.05121972@postgrespro.ru", "phone": "+70750457812"}
0005434462806	60583A	3738 614849	ANATOLIY ISAEV	{"phone": "+70521926627"}
0005434462807	60583A	7912 056820	ALEKSANDR GORBUNOV	{"email": "gorbunov.a26021977@postgrespro.ru", "phone": "+70254589942"}
0005434462808	60583A	6988 536871	ALEKSEY DAVYDOV	{"phone": "+70929648957"}
0005434462809	12BFFE	8059 683611	ARTEM SMIRNOV	{"email": "artem.smirnov1976@postgrespro.ru", "phone": "+70811430121"}
0005434462810	BE8625	8582 005843	TATYANA LUKYANOVA	{"email": "lukyanova_tatyana.1973@postgrespro.ru", "phone": "+70636430949"}
0005434462811	B3C5C1	2513 018043	SERGEY SERGEEV	{"email": "sergeysergeev111975@postgrespro.ru", "phone": "+70956527976"}
0005434462813	9EBE33	0104 616717	TAMARA ALEKSANDROVA	{"email": "t_aleksandrova_21051960@postgrespro.ru", "phone": "+70804526918"}
0005434462814	9EBE33	2214 307512	MARINA DANILOVA	{"email": "marinadanilova.16091982@postgrespro.ru", "phone": "+70061885397"}
0005434462815	7A68C6	7752 020998	ALEKSANDRA GRISHINA	{"email": "a_grishina_23021978@postgrespro.ru", "phone": "+70722713938"}
0005434462816	7C8A14	4388 275768	ELENA KOVALEVA	{"email": "elenakovaleva.1969@postgrespro.ru", "phone": "+70201438296"}
0005434462817	5C9433	6029 284452	YULIYA ABRAMOVA	{"email": "abramova_yuliya1964@postgrespro.ru", "phone": "+70501134482"}
0005434462818	5C9433	9016 210741	VLADIMIR SEMENOV	{"phone": "+70779939568"}
0005434462819	69DF52	4808 488601	YULIYA TIKHONOVA	{"phone": "+70134988833"}
0005434462820	69DF52	0287 835403	ALEKSANDR GAVRILOV	{"email": "a-gavrilov.09081970@postgrespro.ru", "phone": "+70994864538"}
0005434462821	E5AAE2	3662 606070	MIKHAIL GRIGOREV	{"email": "mikhail.grigorev011969@postgrespro.ru", "phone": "+70108620992"}
0005434462822	E5AAE2	8673 562053	ALEKSANDR GUSEV	{"email": "aleksandr.gusev031977@postgrespro.ru", "phone": "+70667380203"}
0005434462823	B82197	3039 483953	ARTEM PAVLOV	{"phone": "+70320905064"}
0005434462824	4A749C	3276 985278	ELENA STEPANOVA	{"email": "stepanova_e.1981@postgrespro.ru", "phone": "+70242064494"}
0005434462825	E2A2A4	8418 482915	PAVEL ALEKSEEV	{"phone": "+70993762641"}
0005434462826	E2A2A4	9634 190198	SOFYA KALININA	{"email": "kalinina-sofya.021975@postgrespro.ru", "phone": "+70524241976"}
0005434462827	69734B	9404 324027	VALERIY KISELEV	{"phone": "+70654275676"}
0005434462828	69734B	3435 806802	LIDIYA SEMENOVA	{"phone": "+70409671785"}
0005434462829	69734B	0406 811895	MARINA NAZAROVA	{"phone": "+70155082121"}
0005434462830	EF00D7	8135 581996	ANASTASIYA VOROBEVA	{"phone": "+70640706409"}
0005434462831	EF00D7	3476 867125	DMITRIY TARASOV	{"phone": "+70520255064"}
0005434462832	FC7860	0883 728374	ELENA ZAYCEVA	{"phone": "+70680459964"}
0005434462833	F386B1	6642 065863	VASILIY MIKHAYLOV	{"email": "v.mikhaylov091971@postgrespro.ru", "phone": "+70259136888"}
0005434462834	EA51B8	4091 231860	TAMARA KOLESNIKOVA	{"email": "kolesnikova_tamara-121971@postgrespro.ru", "phone": "+70066911985"}
0005434462835	CE03E2	1038 082303	MAKSIM FOMIN	{"phone": "+70416046805"}
0005434462836	929C49	2178 707002	NATALIYA POPOVA	{"email": "popova.n_1961@postgrespro.ru", "phone": "+70470919900"}
0005434462837	D2CBE9	7790 397868	PAVEL MAKAROV	{"phone": "+70577632429"}
0005434462838	D2CBE9	8281 957168	ANATOLIY SMIRNOV	{"phone": "+70036540399"}
0005434462839	E2FAF3	0127 137659	DMITRIY MIRONOV	{"email": "dmitriymironov_1974@postgrespro.ru", "phone": "+70356131618"}
0005434462840	F4A0BD	2799 492777	IGOR PETROV	{"phone": "+70822239933"}
0005434462841	F4A0BD	5373 955649	ELVIRA SOLOVEVA	{"phone": "+70398938241"}
0005434462842	43D9E1	4462 764798	ELENA ILINA	{"phone": "+70652037165"}
0005434462843	189C4F	8242 595097	TATYANA SOKOLOVA	{"email": "sokolova_tatyana021970@postgrespro.ru", "phone": "+70317912630"}
0005434462844	3072A9	9694 098859	YULIYA SERGEEVA	{"email": "y_sergeeva_121962@postgrespro.ru", "phone": "+70982843253"}
0005434462845	AAF6AF	8497 215723	DANILA SCHERBAKOV	{"email": "scherbakov_danila-011959@postgrespro.ru", "phone": "+70393998232"}
0005434462846	AAF6AF	6802 450628	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov101958@postgrespro.ru", "phone": "+70259448055"}
0005434462847	41742D	0930 262083	TATYANA KOROLEVA	{"email": "koroleva_t1978@postgrespro.ru", "phone": "+70655144576"}
0005434462848	0207DA	2018 084818	EKATERINA SAVELEVA	{"phone": "+70859184650"}
0005434462849	DFC14C	9885 084609	VYACHESLAV SEMENOV	{"email": "vyacheslavsemenov-11031963@postgrespro.ru", "phone": "+70733040876"}
0005434462850	71FE13	6589 625966	NIKOLAY SEMENOV	{"phone": "+70124680539"}
0005434462851	75783D	2318 735757	VLADIMIR KUZNECOV	{"email": "v.kuznecov_021966@postgrespro.ru", "phone": "+70963466886"}
0005434462852	C794CF	2297 160838	VALERIY NIKITIN	{"phone": "+70200357376"}
0005434462853	C794CF	9458 713811	LILIYA TIKHONOVA	{"email": "liliya-tikhonova.1967@postgrespro.ru", "phone": "+70982049943"}
0005434462854	EEFFD0	4368 313130	NIKOLAY GRIGOREV	{"phone": "+70272585004"}
0005434462855	EEFFD0	7901 743420	GALINA ALEKSEEVA	{"email": "alekseeva-galina.05081972@postgrespro.ru", "phone": "+70484053012"}
0005434463891	595547	1738 428737	DARYA PETROVA	{"email": "daryapetrova-25081966@postgrespro.ru", "phone": "+70085965097"}
0005434463892	595547	7120 659932	VYACHESLAV MOROZOV	{"phone": "+70432176973"}
0005434463893	1D90AC	2802 258264	ROMAN RODIONOV	{"phone": "+70833299901"}
0005434463894	1D90AC	4478 335837	LYUBOV ANDREEVA	{"email": "landreeva1966@postgrespro.ru", "phone": "+70340798521"}
0005434463895	1D90AC	1363 050805	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova.m-19101967@postgrespro.ru", "phone": "+70412018391"}
0005434463896	86B1E9	1354 699420	EKATERINA MASLOVA	{"email": "ekaterinamaslova01111965@postgrespro.ru", "phone": "+70258316386"}
0005434463897	86B1E9	1988 597185	ALSU IVANOVA	{"email": "ivanova-alsu_011973@postgrespro.ru", "phone": "+70464553678"}
0005434463898	9374E0	9188 245425	ELLA FADEEVA	{"email": "efadeeva-1972@postgrespro.ru", "phone": "+70102699188"}
0005434463899	485EA2	3748 774945	MIKHAIL KOZLOV	{"phone": "+70266361229"}
0005434463900	7D59D1	7198 212240	ANDREY MOROZOV	{"phone": "+70126190715"}
0005434463901	5C28AD	7481 455910	SERGEY KUZNECOV	{"email": "s_kuznecov-081967@postgrespro.ru", "phone": "+70011674765"}
0005434463902	5C28AD	5209 946416	YULIYA GERASIMOVA	{"phone": "+70413283819"}
0005434463903	CCB995	9995 211296	GALINA DENISOVA	{"email": "galina.denisova.1970@postgrespro.ru", "phone": "+70263616889"}
0005434463904	559052	3725 314315	NATALYA BARANOVA	{"email": "baranova_natalya.31071974@postgrespro.ru", "phone": "+70871680786"}
0005434463905	8EB1B9	8512 746519	VIKTORIYA MIRONOVA	{"email": "mironova.viktoriya-1976@postgrespro.ru", "phone": "+70744785950"}
0005434463906	380500	4855 055294	NADEZHDA GAVRILOVA	{"email": "ngavrilova.031972@postgrespro.ru", "phone": "+70683108770"}
0005434463907	E0E4B7	6935 145356	ARTEM KISELEV	{"email": "kiseleva051981@postgrespro.ru", "phone": "+70299861012"}
0005434463908	43FE99	6382 107360	VERA AFANASEVA	{"email": "v_afanaseva.1968@postgrespro.ru", "phone": "+70629787638"}
0005434463909	EBF35E	9381 614187	ARTEM EGOROV	{"phone": "+70889298634"}
0005434463910	EBF35E	2943 132733	LEONID IVANOV	{"phone": "+70803931228"}
0005434463911	1DADA0	7667 311394	DARYA OVCHINNIKOVA	{"phone": "+70652715767"}
0005434463912	1DADA0	7026 772502	RINAT BARANOV	{"email": "r-baranov071969@postgrespro.ru", "phone": "+70459962738"}
0005434463913	1DADA0	7604 433806	SERGEY NAZAROV	{"phone": "+70399287063"}
0005434463914	2A81C6	6070 275280	MARIYA KULIKOVA	{"email": "mariya_kulikova.21121974@postgrespro.ru", "phone": "+70748652957"}
0005434463915	B9537B	3516 321602	GALINA BOGDANOVA	{"email": "g.bogdanova-1967@postgrespro.ru", "phone": "+70694190287"}
0005434463916	B9537B	8636 251001	NATALYA IVANOVA	{"email": "ivanova-n.101975@postgrespro.ru", "phone": "+70645342152"}
0005434463917	ED9742	9828 153311	ARTEM SERGEEV	{"email": "sergeev_artem.18041967@postgrespro.ru", "phone": "+70809415453"}
0005434463918	E9FD97	0202 784158	VALERIY CHERNOV	{"email": "valeriy-chernov_1968@postgrespro.ru", "phone": "+70920266206"}
0005434463919	E9FD97	6148 760943	RAISA NIKITINA	{"email": "nikitina_raisa-1977@postgrespro.ru", "phone": "+70770007765"}
0005434463920	D1520B	3654 833836	ANASTASIYA BELOVA	{"phone": "+70266881299"}
0005434463921	C7F0F1	1045 680901	ZINAIDA AFANASEVA	{"email": "zafanaseva.1970@postgrespro.ru", "phone": "+70688373672"}
0005434463922	16EE11	7107 619403	ILYA SAVELEV	{"email": "i-savelev25101976@postgrespro.ru", "phone": "+70145773553"}
0005434463923	16EE11	4303 804752	PETR NIKOLAEV	{"phone": "+70352586870"}
0005434463924	5D446F	5206 320307	GENNADIY ILIN	{"phone": "+70127957460"}
0005434463925	1961F1	3501 240438	NADEZHDA ANDREEVA	{"email": "andreeva.nadezhda-1973@postgrespro.ru", "phone": "+70881538811"}
0005434463926	61B8CA	0772 375047	VIKTOR MAKAROV	{"email": "vmakarov27071973@postgrespro.ru", "phone": "+70044774464"}
0005434463927	CFE768	9579 191574	LARISA SEMENOVA	{"email": "larisasemenova.1970@postgrespro.ru", "phone": "+70841205364"}
0005434463928	CFE768	4660 320979	KRISTINA IVANOVA	{"phone": "+70241856625"}
0005434463929	5A42E5	3695 529700	TATYANA TROFIMOVA	{"phone": "+70459447990"}
0005434463930	ACE698	1737 774132	ALINA MELNIKOVA	{"email": "melnikova.alina021969@postgrespro.ru", "phone": "+70650711261"}
0005434463931	49075A	7896 075479	SOFYA FOMINA	{"phone": "+70130952109"}
0005434463932	49075A	2055 841098	ALEKSEY NOVIKOV	{"email": "a_novikov_061971@postgrespro.ru", "phone": "+70762532387"}
0005434463933	49075A	3209 420057	VERA MAKSIMOVA	{"email": "maksimova_vera051963@postgrespro.ru", "phone": "+70281877404"}
0005434463934	50B71B	7133 631252	YURIY BELOV	{"email": "belov.y_011973@postgrespro.ru", "phone": "+70422476962"}
0005434463935	50B71B	5903 991629	KONSTANTIN ISAEV	{"email": "isaev_konstantin_1959@postgrespro.ru", "phone": "+70714637326"}
0005434463936	10CF18	6576 312899	ELENA YAKOVLEVA	{"phone": "+70700196271"}
0005434463937	400B5C	6500 213899	NIKOLAY KUZNECOV	{"phone": "+70758368109"}
0005434463938	C7821E	2565 980591	IBRAGIM POPOV	{"email": "popovibragim-1974@postgrespro.ru", "phone": "+70332131850"}
0005434463939	D96645	3262 222825	SERGEY ROMANOV	{"email": "romanov.s.1956@postgrespro.ru", "phone": "+70387648706"}
0005434463940	235BFF	1079 585758	PAVEL MOISEEV	{"email": "moiseev-p-111968@postgrespro.ru", "phone": "+70531738270"}
0005434463941	BF1017	1189 342500	TATYANA PETROVA	{"phone": "+70922761771"}
0005434463942	9FD6D7	7408 532731	ALEKSANDR BELOV	{"email": "belova.111979@postgrespro.ru", "phone": "+70485410661"}
0005434463943	E77CB3	0162 821930	ALEKSANDR SMIRNOV	{"email": "smirnov.a-03041979@postgrespro.ru", "phone": "+70000792656"}
0005434463944	896D21	4499 501763	MIKHAIL ALEKSEEV	{"email": "alekseev-m-091969@postgrespro.ru", "phone": "+70171132742"}
0005434463945	896D21	8712 769407	EVA KOZLOVA	{"phone": "+70750337821"}
0005434463946	950493	6830 908624	LYUDMILA ARKHIPOVA	{"phone": "+70379313915"}
0005434463947	9D7DDD	3353 129457	IRINA ZAYCEVA	{"email": "zayceva-i-081979@postgrespro.ru", "phone": "+70618807396"}
0005434463948	9D7DDD	4550 717968	POLINA ZHUKOVA	{"phone": "+70348624779"}
0005434463949	330CF5	0845 228834	RAISA TROFIMOVA	{"email": "trofimovaraisa_04091967@postgrespro.ru", "phone": "+70734188984"}
0005434463950	544775	9225 343051	ALLA GORBUNOVA	{"email": "a-gorbunova011972@postgrespro.ru", "phone": "+70853668512"}
0005434463951	544775	7868 583947	KRISTINA KISELEVA	{"email": "k-kiseleva_061976@postgrespro.ru", "phone": "+70498706363"}
0005434463952	106284	4704 188718	ELENA ISAEVA	{"email": "isaeva.elena_031973@postgrespro.ru", "phone": "+70494269340"}
0005434463953	106284	3124 431801	DMITRIY DENISOV	{"email": "d_denisov051974@postgrespro.ru", "phone": "+70176976133"}
0005434463954	91ADF5	5017 728028	TAKHIR ALEKSANDROV	{"email": "aleksandrov.t-1978@postgrespro.ru", "phone": "+70255039185"}
0005434463955	55BE41	9133 535515	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr1986@postgrespro.ru", "phone": "+70221539515"}
0005434463956	55BE41	4480 029919	ELENA KUZNECOVA	{"phone": "+70521393484"}
0005434463957	EED8C7	7875 054418	OLGA NIKOLAEVA	{"email": "olganikolaeva_041974@postgrespro.ru", "phone": "+70836284534"}
0005434463958	596255	3520 727368	EVGENIY ZAKHAROV	{"email": "e.zakharov08081975@postgrespro.ru", "phone": "+70584943903"}
0005434463959	2C9091	4658 089978	IGOR ORLOV	{"email": "i-orlov11031970@postgrespro.ru", "phone": "+70389223820"}
0005434463960	2C9091	6704 461875	TATYANA MOROZOVA	{"phone": "+70305044358"}
0005434463961	E730F9	8971 569929	VASILIY PETROV	{"email": "vasiliy_petrov-111972@postgrespro.ru", "phone": "+70990650645"}
0005434463962	E730F9	8976 973413	PETR DENISOV	{"email": "denisovpetr_121968@postgrespro.ru", "phone": "+70148201349"}
0005434463963	60907E	3659 469518	TATYANA PETROVA	{"email": "petrova.t1967@postgrespro.ru", "phone": "+70422754034"}
0005434463964	60907E	9379 010409	ALENA POPOVA	{"phone": "+70106832238"}
0005434463965	78360C	3779 580646	VALENTINA PETROVA	{"phone": "+70531269397"}
0005434463966	78360C	8807 727372	SERGEY EGOROV	{"email": "sergeyegorov10081970@postgrespro.ru", "phone": "+70663326902"}
0005434463967	78360C	9013 986135	OLGA KAZAKOVA	{"email": "kazakova.olga091970@postgrespro.ru", "phone": "+70727036235"}
0005434463968	12DEAA	9769 151709	MARIYA MIKHAYLOVA	{"phone": "+70272377603"}
0005434463969	12DEAA	9459 382828	OLEG ORLOV	{"phone": "+70967893882"}
0005434463970	AA8036	2817 122936	RUSLAN ORLOV	{"email": "orlovr-1972@postgrespro.ru", "phone": "+70027056488"}
0005434463971	AA8036	0336 824185	LIDIYA PAVLOVA	{"email": "pavlova.lidiya_1969@postgrespro.ru", "phone": "+70268966254"}
0005434463972	82DEC6	5444 830997	KARINA ZAKHAROVA	{"phone": "+70540738664"}
0005434463973	82DEC6	8674 062889	NIKOLAY NOVIKOV	{"phone": "+70216614963"}
0005434463974	5BD997	5783 025694	LYUDMILA KALININA	{"email": "kalinina-l_13071964@postgrespro.ru", "phone": "+70307134869"}
0005434463975	7584F6	3353 238521	ANASTASIYA ROMANOVA	{"email": "romanova_anastasiya05121968@postgrespro.ru", "phone": "+70689711705"}
0005434463976	7584F6	8955 105679	ELENA VASILEVA	{"email": "vasileva-elena_17111968@postgrespro.ru", "phone": "+70934833899"}
0005434463977	D8EB6E	5878 945989	ANATOLIY TIKHONOV	{"phone": "+70767372786"}
0005434463978	D8EB6E	1042 565444	ANDREY ALEKSEEV	{"email": "alekseev_a08091971@postgrespro.ru", "phone": "+70344369232"}
0005434463979	D8EB6E	4592 595672	VALENTINA SEMENOVA	{"phone": "+70804681620"}
0005434463980	E7A29C	4965 002459	ANATOLIY KRASNOV	{"phone": "+70340901749"}
0005434463981	E7A29C	4122 258089	ALINA PETROVA	{"phone": "+70431102875"}
0005434463982	C324D2	8521 287209	ANATOLIY KONOVALOV	{"email": "a.konovalov.1976@postgrespro.ru", "phone": "+70418675110"}
0005434463983	29CC1D	1790 492888	NATALYA LOGINOVA	{"email": "loginovanatalya051965@postgrespro.ru", "phone": "+70589074000"}
0005434463984	29CC1D	1545 486179	VALENTINA VLASOVA	{"email": "v.vlasova_061970@postgrespro.ru", "phone": "+70631601701"}
0005434463985	29CC1D	7897 443654	NATALYA MAKAROVA	{"email": "n_makarova1976@postgrespro.ru", "phone": "+70263995615"}
0005434463986	68629E	2209 872896	ZINAIDA MOROZOVA	{"phone": "+70423226344"}
0005434463987	68629E	7943 058190	GALINA TROFIMOVA	{"email": "trofimova.galina_12041978@postgrespro.ru", "phone": "+70610090274"}
0005434463988	03C63D	4786 738551	OLGA ALEKSANDROVA	{"email": "aleksandrova_o-121960@postgrespro.ru", "phone": "+70861652034"}
0005434463989	C0864F	5469 266274	EKATERINA MIRONOVA	{"email": "mironova-ekaterina.29021964@postgrespro.ru", "phone": "+70362960421"}
0005434463990	C0864F	8138 646961	YURIY STEPANOV	{"email": "stepanov.yuriy_1973@postgrespro.ru", "phone": "+70163534244"}
0005434463991	BF740F	8154 743899	VLADIMIR CHERNOV	{"phone": "+70770223709"}
0005434463992	AD46E7	9003 921402	GENNADIY MAKAROV	{"email": "makarovg-01071979@postgrespro.ru", "phone": "+70873479250"}
0005434463993	AD46E7	1321 895230	ZINAIDA GAVRILOVA	{"phone": "+70151898203"}
0005434463994	B26F86	0367 039957	NINA KUDRYASHOVA	{"email": "nina_kudryashova041986@postgrespro.ru", "phone": "+70117974877"}
0005434463995	B26F86	7020 032959	ILDAR SERGEEV	{"phone": "+70132347636"}
0005434463996	B61E29	4076 048714	GALINA KOVALEVA	{"phone": "+70808473515"}
0005434466488	11C969	3440 437997	ANASTASIYA FROLOVA	{"phone": "+70329921127"}
0005434466372	852C15	4602 157659	LYUBOV MELNIKOVA	{"phone": "+70060473276"}
0005434466373	FA8F2C	4640 317343	ANDREY SOROKIN	{"phone": "+70850262822"}
0005434466374	0DE811	4397 107808	VLADIMIR SOLOVEV	{"email": "vladimir.solovev-17081969@postgrespro.ru", "phone": "+70121654021"}
0005434466375	4CB2DB	6300 213467	OLGA TIKHONOVA	{"phone": "+70453289737"}
0005434466376	5AC2AD	4387 174846	NINA GAVRILOVA	{"email": "gavrilova-nina23011976@postgrespro.ru", "phone": "+70005083638"}
0005434466377	A21DB3	2759 997145	RUSLAN ZAKHAROV	{"email": "zakharovr1963@postgrespro.ru", "phone": "+70665265683"}
0005434466378	A21DB3	9150 881459	OLESYA TIKHONOVA	{"phone": "+70441232172"}
0005434466379	5F406D	4028 210205	EVGENIY PAVLOV	{"email": "pavlovevgeniy.1972@postgrespro.ru", "phone": "+70384006488"}
0005434466380	5F406D	4811 685437	YURIY ALEKSEEV	{"phone": "+70553715945"}
0005434466381	E7A68C	4376 837443	VLADIMIR NAUMOV	{"phone": "+70906660727"}
0005434466382	A15535	3071 164145	NIKOLAY YAKOVLEV	{"phone": "+70128838857"}
0005434466383	A15535	2238 396409	TATYANA PAVLOVA	{"phone": "+70915002923"}
0005434466384	B87850	7531 761174	LIDIYA FADEEVA	{"email": "fadeeva.l17121975@postgrespro.ru", "phone": "+70322244303"}
0005434466385	23C778	2336 641674	VIKTORIYA GAVRILOVA	{"email": "v.gavrilova-28041962@postgrespro.ru", "phone": "+70140615114"}
0005434466386	23C778	7109 244968	ANNA SMIRNOVA	{"email": "smirnova-a_101975@postgrespro.ru", "phone": "+70225986255"}
0005434466387	EFFC5F	0680 986306	NATALYA EFREMOVA	{"email": "efremova_natalya_101978@postgrespro.ru", "phone": "+70759446222"}
0005434466388	1A4BE8	7956 997558	EMIL SAVELEV	{"phone": "+70282459248"}
0005434466389	B34FED	0182 337499	ALEKSANDRA DANILOVA	{"phone": "+70908671942"}
0005434466390	B34FED	7941 223456	RAISA ILINA	{"email": "r.ilina-1963@postgrespro.ru", "phone": "+70696150544"}
0005434466391	99995E	3845 529332	ELENA FILATOVA	{"email": "filatova_e_031966@postgrespro.ru", "phone": "+70303421172"}
0005434466392	3132BA	3536 905587	VLADIMIR ANDREEV	{"email": "v.andreev-071985@postgrespro.ru", "phone": "+70114422470"}
0005434466393	BA9E1E	4184 964998	EKATERINA OVCHINNIKOVA	{"phone": "+70588112496"}
0005434466394	16709F	6762 125613	ARTEM SHEVCHENKO	{"phone": "+70469194867"}
0005434466395	16709F	5026 198031	NATALYA LUKYANOVA	{"email": "lukyanova.n.1970@postgrespro.ru", "phone": "+70772923651"}
0005434466396	6549CA	7349 204092	NIKOLAY SIDOROV	{"email": "sidorovn.111972@postgrespro.ru", "phone": "+70313142743"}
0005434466397	6549CA	0261 672420	ALEKSANDRA MOROZOVA	{"phone": "+70160372158"}
0005434466457	CE78C9	8322 274235	LYUDMILA GORBUNOVA	{"email": "lyudmila_gorbunova11091970@postgrespro.ru", "phone": "+70723172902"}
0005434466398	03DE1E	3519 384723	SVETLANA NIKIFOROVA	{"email": "svetlana-nikiforova-15021975@postgrespro.ru", "phone": "+70072307265"}
0005434466399	03DE1E	2077 872623	MAKSIM SOLOVEV	{"phone": "+70830889198"}
0005434466400	03DE1E	4530 210325	ALEKSANDR RODIONOV	{"phone": "+70821693580"}
0005434466401	DB102E	8087 486204	NATALIYA KUZMINA	{"phone": "+70279921597"}
0005434466402	DB102E	1614 597813	TATYANA TIKHONOVA	{"phone": "+70650420718"}
0005434466403	EB09BA	9349 241626	DMITRIY KAZAKOV	{"phone": "+70878349930"}
0005434466404	B0B8D7	9213 765044	SERGEY KUZNECOV	{"phone": "+70692065380"}
0005434466405	F4A3A7	3199 663798	TATYANA ABRAMOVA	{"email": "abramova-t.1985@postgrespro.ru", "phone": "+70890835600"}
0005434466406	F4A3A7	9811 416172	ILYA POPOV	{"phone": "+70645494519"}
0005434466407	FF485C	0465 534611	SERGEY MAKAROV	{"email": "s.makarov-31101981@postgrespro.ru", "phone": "+70237495462"}
0005434466408	FF485C	8928 788652	VLADIMIR BARANOV	{"email": "baranov_v27041963@postgrespro.ru", "phone": "+70108582177"}
0005434466409	BCD968	3593 991891	SERGEY ZAKHAROV	{"email": "zakharov.s.08041967@postgrespro.ru", "phone": "+70308826381"}
0005434466410	BCD968	4393 868850	VASILIY STEPANOV	{"email": "stepanov_vasiliy.041970@postgrespro.ru", "phone": "+70811580236"}
0005434466411	02F736	2668 666660	SERGEY GUSEV	{"phone": "+70402378210"}
0005434466412	02F736	0230 229146	MIKHAIL GERASIMOV	{"phone": "+70071114818"}
0005434466413	02F736	3174 835781	LYUBOV PETROVA	{"phone": "+70148286687"}
0005434466414	C93CB8	4291 027093	ANDREY SEMENOV	{"phone": "+70998322126"}
0005434466415	DCC4BB	2382 340573	VIKTOR TIKHONOV	{"phone": "+70160642386"}
0005434466416	DCC4BB	8452 832648	IVAN NOVIKOV	{"email": "ivan.novikov.1966@postgrespro.ru", "phone": "+70473131911"}
0005434466417	4267FB	5460 878405	GULNARA DANILOVA	{"phone": "+70944428430"}
0005434466418	4267FB	6235 476756	DMITRIY MEDVEDEV	{"email": "dmitriy_medvedev_041969@postgrespro.ru", "phone": "+70161743910"}
0005434466419	0B44AB	1010 207156	VLADIMIR KOROLEV	{"phone": "+70760031811"}
0005434466420	1EA83A	6934 305023	DARINA NESTEROVA	{"phone": "+70574033980"}
0005434466421	EDF192	9732 119681	GENNADIY KUZNECOV	{"email": "gennadiy_kuznecov.1970@postgrespro.ru", "phone": "+70496473034"}
0005434466422	8C32CC	3072 161677	NIKOLAY GORBUNOV	{"email": "gorbunov_n-22041978@postgrespro.ru", "phone": "+70970949000"}
0005434466423	8C32CC	7953 058176	YULIYA NAUMOVA	{"phone": "+70088822634"}
0005434466424	8C32CC	2446 068857	GALINA ZHUKOVA	{"email": "zhukova_galina_20101962@postgrespro.ru", "phone": "+70979051201"}
0005434466425	8C32CC	2067 417341	MARIYA FILATOVA	{"phone": "+70537355885"}
0005434466426	44FCEF	7165 183996	VALERIY ABRAMOV	{"phone": "+70866842725"}
0005434466427	44FCEF	8960 671020	ANASTASIYA FEDOROVA	{"email": "fedorova.anastasiya011980@postgrespro.ru", "phone": "+70963437226"}
0005434466428	743AA0	3643 504239	EVGENIYA ANTONOVA	{"email": "antonova.e-1963@postgrespro.ru", "phone": "+70814559571"}
0005434466429	F2D472	5669 780793	SABINA PETROVA	{"email": "petrova_s15101980@postgrespro.ru", "phone": "+70789146002"}
0005434466430	779CF2	1620 411772	VALERIY MOROZOV	{"email": "morozov_valeriy_021980@postgrespro.ru", "phone": "+70041973170"}
0005434466431	13CB2D	8078 062403	ALEKSANDR PETROV	{"email": "aleksandr.petrov_19121976@postgrespro.ru", "phone": "+70497424477"}
0005434466432	13CB2D	8270 573888	VADIM FROLOV	{"email": "frolov-vadim.031988@postgrespro.ru", "phone": "+70411777316"}
0005434466433	220954	2672 974899	NATALYA NAZAROVA	{"email": "nnazarova.09031968@postgrespro.ru", "phone": "+70163110037"}
0005434466434	220954	5743 584515	SVETLANA KULIKOVA	{"phone": "+70751316668"}
0005434466435	1F5888	7137 286857	ALEKSEY MEDVEDEV	{"email": "alekseymedvedev15011977@postgrespro.ru", "phone": "+70019294644"}
0005434466436	7A1185	1177 215769	TATYANA IVANOVA	{"phone": "+70647414652"}
0005434466437	73E17D	0224 303683	NADEZHDA BELYAEVA	{"email": "n.belyaeva_1976@postgrespro.ru", "phone": "+70584504725"}
0005434466438	2019D9	7713 567735	MARIYA TARASOVA	{"phone": "+70324571955"}
0005434466439	BC4833	8045 947747	ELENA GORBUNOVA	{"email": "gorbunova_elena-01091978@postgrespro.ru", "phone": "+70506985480"}
0005434466440	BC4833	7358 269113	IVAN VLASOV	{"email": "ivlasov_21111969@postgrespro.ru", "phone": "+70767758123"}
0005434466441	03025E	0026 810983	YULIYA ZOTOVA	{"email": "y.zotova-1983@postgrespro.ru", "phone": "+70275076574"}
0005434466442	03025E	9964 194902	ARTEM EGOROV	{"phone": "+70153420227"}
0005434466443	D180EF	2923 857313	NAIL GORBUNOV	{"email": "gorbunovnail-1975@postgrespro.ru", "phone": "+70045454795"}
0005434466444	CAC204	4879 174100	DMITRIY MAKAROV	{"email": "makarovd06091971@postgrespro.ru", "phone": "+70186070088"}
0005434466445	226A5F	1218 120257	DARYA ALEKSEEVA	{"phone": "+70064727313"}
0005434466446	C71997	0286 062924	IRINA KOLESNIKOVA	{"phone": "+70079373147"}
0005434466447	CA33A8	2584 309543	YULIYA KAZAKOVA	{"email": "kazakova_yuliya.101966@postgrespro.ru", "phone": "+70633094013"}
0005434466448	FEBCFD	8552 021029	VYACHESLAV MATVEEV	{"phone": "+70855479602"}
0005434466449	FEBCFD	3094 349890	OLEG KUZNECOV	{"email": "o_kuznecov_031966@postgrespro.ru", "phone": "+70934713490"}
0005434466450	04DF89	3016 670667	ANTONINA KOZLOVA	{"email": "antonina_kozlova_1988@postgrespro.ru", "phone": "+70922273894"}
0005434466451	793440	9236 839686	ANATOLIY NAZAROV	{"phone": "+70533223078"}
0005434466452	793440	3555 299733	RUMIYA KUDRYASHOVA	{"email": "rumiya.kudryashova-24061961@postgrespro.ru", "phone": "+70503298903"}
0005434466453	CA3B82	2861 984933	TATYANA MAKAROVA	{"email": "makarovatatyana-04071965@postgrespro.ru", "phone": "+70535917767"}
0005434466454	C6D879	9163 870289	ANNA ZAYCEVA	{"phone": "+70510206420"}
0005434466455	C6D879	7592 407974	BORIS SERGEEV	{"email": "sergeevb-1976@postgrespro.ru", "phone": "+70995538883"}
0005434466456	CE78C9	3910 152906	VITALIY ZAKHAROV	{"email": "v.zakharov051975@postgrespro.ru", "phone": "+70776467043"}
0005434466458	29408B	6605 124667	LYUDMILA NIKITINA	{"email": "nikitina_l111977@postgrespro.ru", "phone": "+70457172794"}
0005434466459	726C16	7887 501069	DARYA YAKOVLEVA	{"phone": "+70520851332"}
0005434466460	1FCADB	1678 393055	SERGEY PETROV	{"email": "spetrov1969@postgrespro.ru", "phone": "+70087957990"}
0005434466461	52E69E	4790 502890	VALERIY KUZMIN	{"phone": "+70292004801"}
0005434466462	93B05D	9469 952870	VLADIMIR ZAYCEV	{"phone": "+70399880080"}
0005434466463	93B05D	2849 090153	ALEKSANDR DENISOV	{"phone": "+70028416432"}
0005434466464	93B05D	6307 585844	ELENA KRASNOVA	{"email": "e-krasnova-09061973@postgrespro.ru", "phone": "+70101881561"}
0005434466465	93B05D	0137 896546	RAISA IVANOVA	{"email": "ivanova.r.25071969@postgrespro.ru", "phone": "+70220258507"}
0005434466466	CDE01C	0785 128281	GALINA MAKAROVA	{"phone": "+70497371517"}
0005434466467	CDE01C	8542 613681	VIKTOR ZAKHAROV	{"email": "zakharov_viktor_1976@postgrespro.ru", "phone": "+70267487088"}
0005434466468	CDE01C	7538 568359	NADEZHDA IVANOVA	{"phone": "+70357541840"}
0005434466469	1CED8B	0838 373152	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov.1966@postgrespro.ru", "phone": "+70539469065"}
0005434466470	B617BD	7393 714064	PETR TARASOV	{"phone": "+70951400685"}
0005434466471	B617BD	8254 082474	SVETLANA VLASOVA	{"phone": "+70139687075"}
0005434466472	968513	6733 651147	SVETLANA GORBUNOVA	{"phone": "+70495312269"}
0005434466473	968513	7612 221193	MAYA KOZLOVA	{"phone": "+70391390662"}
0005434466474	93B230	7969 850671	NATALYA FROLOVA	{"phone": "+70159789532"}
0005434466475	816904	4616 873918	TATYANA MAKSIMOVA	{"email": "maksimova_tatyana_26111975@postgrespro.ru", "phone": "+70909780414"}
0005434466476	CF1BEF	3367 329632	ANATOLIY POPOV	{"email": "anatoliy.popov_091971@postgrespro.ru", "phone": "+70102009185"}
0005434466477	948C25	2266 826514	NATALIYA KOROLEVA	{"email": "koroleva_n_1973@postgrespro.ru", "phone": "+70076197425"}
0005434466478	C3942C	1282 498266	SERGEY SCHERBAKOV	{"phone": "+70018648145"}
0005434466479	839BF6	3133 326843	NIKOLAY VOROBEV	{"phone": "+70700078974"}
0005434466480	839BF6	0681 486159	NATALYA ALEKSANDROVA	{"phone": "+70900853588"}
0005434466481	386D36	6838 331566	SERGEY FOMIN	{"email": "fomin.sergey-1974@postgrespro.ru", "phone": "+70499886411"}
0005434466482	16F031	2415 634574	IRINA ANISIMOVA	{"email": "i.anisimova-14021988@postgrespro.ru", "phone": "+70438114331"}
0005434466483	16F031	2119 063625	TAISIYA DANILOVA	{"email": "danilova_t-101986@postgrespro.ru", "phone": "+70375832418"}
0005434466484	28AEA5	9202 761518	ANNA VLASOVA	{"phone": "+70157592369"}
0005434466485	0FDA16	9991 411150	YURIY POPOV	{"email": "popovyuriy_1967@postgrespro.ru", "phone": "+70186745470"}
0005434466486	61BFE5	4475 128077	LYUBOV SOKOLOVA	{"phone": "+70787620198"}
0005434466487	C94116	4979 121989	IRINA LOGINOVA	{"phone": "+70291108252"}
0005434466489	11C969	2418 485904	TAMARA DAVYDOVA	{"phone": "+70030674586"}
0005434466490	D07643	9836 012039	LYUDMILA VASILEVA	{"phone": "+70518575804"}
0005434466491	72BEB6	8244 354516	OLGA EGOROVA	{"email": "egorovao.30071977@postgrespro.ru", "phone": "+70011605967"}
0005434466492	68F48A	4972 526573	MIKHAIL GUSEV	{"phone": "+70059780070"}
0005434466493	A7478F	4752 665161	LYUBOV RYABOVA	{"email": "lyubov.ryabova_02101978@postgrespro.ru", "phone": "+70379284547"}
0005434466494	A220FA	9919 187842	VASILIY GERASIMOV	{"phone": "+70334774111"}
0005434466495	FC9BA0	8075 846569	VLADIMIR SEMENOV	{"phone": "+70451372927"}
0005434466496	6AD992	5630 117988	MARINA MAKAROVA	{"email": "marinamakarova-1981@postgrespro.ru", "phone": "+70186432097"}
0005434466497	7A5D86	8935 232098	ANASTASIYA SERGEEVA	{"email": "anastasiya_sergeeva.081967@postgrespro.ru", "phone": "+70326830337"}
0005434466498	CD7E52	3070 201900	VIKTOR BORISOV	{"phone": "+70636863180"}
0005434466499	47B597	1378 047979	MAKSIM VOLKOV	{"phone": "+70397459945"}
0005434466500	47B597	9372 398357	ALEKSANDR MAKAROV	{"phone": "+70075099460"}
0005434466501	47B597	4516 897135	EGOR MIRONOV	{"email": "mironov.egor-31051967@postgrespro.ru", "phone": "+70109258456"}
0005434466502	C36169	7102 812985	LYUDMILA MAKSIMOVA	{"email": "maksimova-l_011980@postgrespro.ru", "phone": "+70218464952"}
0005434466503	C36169	9889 164490	EKATERINA ARKHIPOVA	{"email": "arkhipova-ekaterina_1971@postgrespro.ru", "phone": "+70716008637"}
0005434466504	C36169	9775 167512	NATALYA KOVALEVA	{"email": "kovaleva.natalya.10101974@postgrespro.ru", "phone": "+70450266501"}
0005434466505	6C2C0C	8405 236369	LYUBOV SOLOVEVA	{"email": "l_soloveva_1964@postgrespro.ru", "phone": "+70240605004"}
0005434466506	6C2C0C	0517 394356	LYUDMILA ERMAKOVA	{"phone": "+70410205061"}
0005434466507	115CDC	5992 026272	GRIGORIY KAZAKOV	{"phone": "+70963221796"}
0005434466508	115CDC	9411 373954	MIKHAIL DMITRIEV	{"phone": "+70161399203"}
0005434466509	035BCD	3420 436044	EVGENIY NAZAROV	{"email": "nazarove.17081972@postgrespro.ru", "phone": "+70237128869"}
0005434466510	5D1194	8175 846332	VALENTINA MELNIKOVA	{"email": "v-melnikova.081964@postgrespro.ru", "phone": "+70345913683"}
0005434466511	5D1194	5327 886868	ALEKSANDR ROMANOV	{"email": "aromanov-091969@postgrespro.ru", "phone": "+70105343488"}
0005434466512	5D1194	2444 131469	OLGA KALININA	{"email": "olga-kalinina.081968@postgrespro.ru", "phone": "+70128714661"}
0005434466513	9A3AD5	6737 644226	VLADIMIR SHEVCHENKO	{"email": "shevchenkovladimir_101982@postgrespro.ru", "phone": "+70118529712"}
0005434466514	9A3AD5	9423 514498	NIKOLAY PAVLOV	{"phone": "+70478868364"}
0005434466515	5C05B0	9627 726413	VALENTINA DANILOVA	{"phone": "+70582935662"}
0005434466516	B7300C	9216 198729	LYUDMILA KAZAKOVA	{"email": "kazakova-lyudmila1968@postgrespro.ru", "phone": "+70800423897"}
0005434466517	E19C85	4225 970137	ELENA ISAEVA	{"email": "e-isaeva011966@postgrespro.ru", "phone": "+70623606440"}
0005434466518	E19C85	0180 018480	SERGEY IVANOV	{"email": "ivanovs.04031979@postgrespro.ru", "phone": "+70096677109"}
0005434466519	E4DE59	8475 441386	YURIY SOKOLOV	{"phone": "+70010943899"}
0005434466520	F646C8	0652 083198	ALEKSANDR SAVELEV	{"phone": "+70105889955"}
0005434466521	4F8A27	2030 389937	DMITRIY ROMANOV	{"phone": "+70402761314"}
0005434466522	D4F9BD	5949 033199	VASILIY MEDVEDEV	{"email": "vasiliy_medvedev_091967@postgrespro.ru", "phone": "+70961223443"}
0005434466523	D4F9BD	6573 539185	VALENTINA SIDOROVA	{"email": "sidorova.v-101974@postgrespro.ru", "phone": "+70834655843"}
0005434466524	C3580F	6227 712717	DMITRIY MIKHAYLOV	{"phone": "+70622171040"}
0005434466525	E7872B	5819 289308	OLGA ZAKHAROVA	{"phone": "+70739869666"}
0005434466526	07B8B9	2003 846276	VERA FILIPPOVA	{"phone": "+70626386236"}
0005434466527	E1239B	3111 865486	ALEKSANDR TIMOFEEV	{"phone": "+70688414318"}
0005434466528	CC698F	3189 456967	LILIYA KUZNECOVA	{"email": "liliya.kuznecova_11081962@postgrespro.ru", "phone": "+70340710878"}
0005434466529	6CC65C	0451 376461	YAROSLAV RODIONOV	{"email": "rodionovy-011974@postgrespro.ru", "phone": "+70340372930"}
0005434466530	86DD25	0191 249384	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy_041967@postgrespro.ru", "phone": "+70939423337"}
0005434466531	8FDB3E	7601 275024	NIKOLAY KARPOV	{"email": "n.karpov-111975@postgrespro.ru", "phone": "+70685358099"}
0005434466532	062A85	6224 825654	LIDIYA SMIRNOVA	{"phone": "+70515870748"}
0005434466533	335D3A	2957 495036	VASILIY NIKITIN	{"phone": "+70528673494"}
0005434466534	7D7AE4	0349 924517	KLAVDIYA FILIPPOVA	{"phone": "+70577252408"}
0005434466535	7D7AE4	1225 166086	IGOR ALEKSEEV	{"email": "alekseev.igor_01081974@postgrespro.ru", "phone": "+70548410870"}
0005434466536	849F63	6567 623745	NATALYA OSIPOVA	{"phone": "+70571771233"}
0005434466537	849F63	3453 119889	ALENA FILATOVA	{"email": "filatovaalena.021974@postgrespro.ru", "phone": "+70323595452"}
0005434466538	22A542	2866 996072	DANIIL KRASNOV	{"email": "krasnov.daniil121968@postgrespro.ru", "phone": "+70946191746"}
0005434466539	22A542	0418 861829	TATYANA NIKITINA	{"email": "tatyana_nikitina1966@postgrespro.ru", "phone": "+70512669539"}
0005434466540	E1BC68	1709 199544	DMITRIY NOVIKOV	{"email": "dmitriy-novikov-1981@postgrespro.ru", "phone": "+70915751059"}
0005434466541	E1BC68	3232 631376	ALEKSEY SCHERBAKOV	{"phone": "+70582378840"}
0005434466542	63E9BC	0567 192442	VLADIMIR NIKITIN	{"phone": "+70586405270"}
0005434466543	63E9BC	2639 559279	VLADIMIR KRASNOV	{"email": "v_krasnov27121978@postgrespro.ru", "phone": "+70423783307"}
0005434466544	07E76D	1255 790458	GEORGIY SEMENOV	{"phone": "+70947867831"}
0005434466545	07E76D	6766 311642	NATALYA CHERNOVA	{"phone": "+70464017743"}
0005434466546	A30A6E	4311 791161	KRISTINA MAKAROVA	{"email": "kristina_makarova-18111984@postgrespro.ru", "phone": "+70188390657"}
0005434466547	A30A6E	9899 328263	NONNA LAZAREVA	{"phone": "+70751910666"}
0005434466548	78A279	2317 988749	ANDREY IVANOV	{"phone": "+70691323649"}
0005434466549	6DB742	6001 375069	LYUDMILA KUZNECOVA	{"email": "lkuznecova.04051970@postgrespro.ru", "phone": "+70701148607"}
0005434466550	0DF729	6559 643518	ALLA SERGEEVA	{"phone": "+70674875805"}
0005434466551	0DF729	4988 580401	ELENA ABRAMOVA	{"phone": "+70469906176"}
0005434466552	7106D6	4923 011875	SEMEN BORISOV	{"phone": "+70102473094"}
0005434466553	95F555	7012 442884	LYUBOV LEBEDEVA	{"phone": "+70780307936"}
0005434466554	615B4B	9498 843307	TATYANA KUZNECOVA	{"phone": "+70344216280"}
0005434466555	624F2B	6096 441995	KRISTINA KOROLEVA	{"email": "k.koroleva_051961@postgrespro.ru", "phone": "+70942439474"}
0005434466556	624F2B	8736 840994	VERA KOZLOVA	{"email": "kozlova-vera-1963@postgrespro.ru", "phone": "+70820504086"}
0005434466557	311C69	1084 912266	SVETLANA STEPANOVA	{"phone": "+70653034446"}
0005434466558	311C69	1619 419041	TATYANA VASILEVA	{"phone": "+70631497951"}
0005434466559	1E68EF	0725 179647	GULSINA MIKHAYLOVA	{"email": "mikhaylova.gulsina-1967@postgrespro.ru", "phone": "+70900309642"}
0005434466560	56BFE4	4397 320071	TAISIYA MAKSIMOVA	{"email": "maksimova-t01111967@postgrespro.ru", "phone": "+70443708205"}
0005434466561	D46C99	9270 777800	LYUDMILA SMIRNOVA	{"email": "smirnova.l-26061954@postgrespro.ru", "phone": "+70416281932"}
0005434466562	B9C8B0	6954 651901	ELENA KONOVALOVA	{"email": "ekonovalova_22071966@postgrespro.ru", "phone": "+70653194976"}
0005434466563	99250F	4341 385131	YULIYA SERGEEVA	{"phone": "+70962987037"}
0005434466564	3357D7	5764 889750	YURIY KUZMIN	{"email": "ykuzmin.1970@postgrespro.ru", "phone": "+70517417492"}
0005434466565	D0386D	3770 757640	ALEKSANDR VLASOV	{"email": "vlasov_aleksandr-1975@postgrespro.ru", "phone": "+70415261542"}
0005434466566	EA895B	0041 331819	EVDOKIYA POTAPOVA	{"phone": "+70936421644"}
0005434466567	69FE58	3944 758730	LYUBOV MIRONOVA	{"phone": "+70629868771"}
0005434466568	3A7990	6367 998258	NATALYA BOGDANOVA	{"phone": "+70880149018"}
0005434466569	3A7990	0751 748015	ANDREY DENISOV	{"phone": "+70745098180"}
0005434466570	7E4201	6765 104625	TATYANA ROMANOVA	{"phone": "+70715789891"}
0005434466571	0E297E	8585 279584	OKSANA ZAKHAROVA	{"email": "o-zakharova_1986@postgrespro.ru", "phone": "+70641325685"}
0005434466572	0E297E	5757 036145	LYUDMILA NOVIKOVA	{"email": "novikovalyudmila_101971@postgrespro.ru", "phone": "+70347915586"}
0005434466573	C28584	8883 302341	NINA ALEKSEEVA	{"email": "n_alekseeva14101961@postgrespro.ru", "phone": "+70173336992"}
0005434466574	416D26	8606 932705	IREK KARPOV	{"phone": "+70353554108"}
0005434466575	72375C	5458 937519	TATYANA ZAYCEVA	{"phone": "+70896003598"}
0005434466576	72375C	3465 943215	GALINA ZAYCEVA	{"email": "zayceva.g_021969@postgrespro.ru", "phone": "+70213695153"}
0005434466577	9335CF	1025 637795	VADIM VLASOV	{"phone": "+70052293907"}
0005434466578	9335CF	3814 585893	NATALYA FOMINA	{"phone": "+70171877480"}
0005434466579	E58B66	0639 459448	ANDREY MEDVEDEV	{"email": "a-medvedev.28121974@postgrespro.ru", "phone": "+70429355778"}
0005434466580	E58B66	5532 647668	ALENA VOLKOVA	{"phone": "+70302172328"}
0005434466581	884876	3055 516212	ANDREY IVANOV	{"email": "a-ivanov1959@postgrespro.ru", "phone": "+70777475104"}
0005434466582	884876	3990 440695	ALEKSEY ILIN	{"email": "aleksey-ilin-051973@postgrespro.ru", "phone": "+70317278306"}
0005434466583	6868D0	7577 079799	ANASTASIYA SOLOVEVA	{"phone": "+70777264127"}
0005434466584	D29D64	9339 393260	STANISLAV GRIGOREV	{"email": "grigorevs-05121963@postgrespro.ru", "phone": "+70069202572"}
0005434466585	20D721	5929 188431	SERGEY ZHURAVLEV	{"email": "s.zhuravlev_011975@postgrespro.ru", "phone": "+70162504506"}
0005434466586	9A1403	3011 527260	VERA VOROBEVA	{"phone": "+70593567322"}
0005434466587	9A1403	3685 201467	GENNADIY ANDREEV	{"phone": "+70506385095"}
0005434466588	6C7E1F	5142 781648	LEONID NOVIKOV	{"phone": "+70389227192"}
0005434466589	09FAB4	0120 484743	ALEKSANDR BORISOV	{"email": "a-borisov.15091966@postgrespro.ru", "phone": "+70185141510"}
0005434466590	09FAB4	4309 835696	VALERIY MOISEEV	{"phone": "+70919275629"}
0005434466591	576DDB	3370 434259	ANDREY MEDVEDEV	{"phone": "+70922324222"}
0005434466592	D45A61	6669 123443	OLGA BORISOVA	{"email": "borisova_olga-011967@postgrespro.ru", "phone": "+70310766564"}
0005434466593	C754F0	5510 073845	SERGEY IVANOV	{"phone": "+70928829338"}
0005434466594	C754F0	0756 419095	EVA ZHURAVLEVA	{"phone": "+70710342858"}
0005434466595	861494	9035 120352	ZOYA FADEEVA	{"email": "zoya-fadeeva-121980@postgrespro.ru", "phone": "+70603843935"}
0005434466596	861494	6126 369127	ELVINA BARANOVA	{"phone": "+70137841607"}
0005434466597	861494	5872 659795	ALEKSANDR SOROKIN	{"phone": "+70190734035"}
0005434466598	861494	9484 749493	ANDREY TARASOV	{"phone": "+70272110381"}
0005434466599	E5E940	9841 360934	ALEKSEY GERASIMOV	{"phone": "+70748548739"}
0005434466600	C2027E	2007 394563	GALINA KOVALEVA	{"phone": "+70808337664"}
0005434466601	F48413	8486 094089	ALEKSANDR FROLOV	{"email": "aleksandr_frolov.1971@postgrespro.ru", "phone": "+70142079495"}
0005434466602	F48413	7793 256565	PAVEL VLASOV	{"phone": "+70125963794"}
0005434466603	339738	7670 500177	DANIIL ZAKHAROV	{"email": "zakharov.d-101969@postgrespro.ru", "phone": "+70868660950"}
0005434466604	339738	1621 923352	TATYANA VASILEVA	{"phone": "+70789145884"}
0005434466605	B63F09	8230 288518	VALENTINA KUZNECOVA	{"phone": "+70425903863"}
0005434466606	B63F09	0003 353907	IRINA TIKHONOVA	{"email": "tikhonova_i_01121975@postgrespro.ru", "phone": "+70262881062"}
0005434466607	D3FAB6	7608 527893	NIKOLAY NIKITIN	{"email": "nikolay_nikitin031978@postgrespro.ru", "phone": "+70219682886"}
0005434466608	D3FAB6	4245 255061	ALEKSANDR FEDOROV	{"email": "a-fedorov.081971@postgrespro.ru", "phone": "+70547516022"}
0005434466609	EC3104	7619 988355	LYUDMILA MAKAROVA	{"email": "makarovalyudmila.111964@postgrespro.ru", "phone": "+70442315727"}
0005434466610	605EF9	8088 329830	ANDREY KUZNECOV	{"phone": "+70065687752"}
0005434466611	E0C127	1770 291499	SERGEY ZAKHAROV	{"email": "s_zakharov.08031973@postgrespro.ru", "phone": "+70081129212"}
0005434467723	019975	5521 878617	MATVEY KISELEV	{"phone": "+70666978121"}
0005434467724	019975	4793 448389	ANDREY MEDVEDEV	{"email": "a.medvedev.111968@postgrespro.ru", "phone": "+70628234277"}
0005434467725	DD88F5	9367 855489	VLADIMIR POPOV	{"email": "popov_vladimir.12111974@postgrespro.ru", "phone": "+70236674737"}
0005434467726	F6E92D	3008 960394	EKATERINA GERASIMOVA	{"email": "ekaterina_gerasimova-111964@postgrespro.ru", "phone": "+70572938783"}
0005434467727	3BEDA0	8385 556125	YULIYA GAVRILOVA	{"phone": "+70125441470"}
0005434467728	CC9491	1239 294850	ALLA ZHUKOVA	{"email": "azhukova.18061984@postgrespro.ru", "phone": "+70871033221"}
0005434467729	CC9491	7279 924411	NIKOLAY ABRAMOV	{"phone": "+70521138681"}
0005434467730	AEE8E8	6459 580829	ELENA ALEKSEEVA	{"phone": "+70291221782"}
0005434467731	E521E8	1956 456472	ALEKSANDR MELNIKOV	{"phone": "+70627968183"}
0005434467732	E6226C	7092 177837	VIKTOR KOZLOV	{"phone": "+70662324328"}
0005434467733	5470A0	1091 496339	LYUBOV NAZAROVA	{"email": "nazarova_lyubov-03101976@postgrespro.ru", "phone": "+70270144061"}
0005434467734	150AEE	6566 980358	DMITRIY DMITRIEV	{"email": "dmitrievdmitriy031958@postgrespro.ru", "phone": "+70428642935"}
0005434467735	150AEE	2942 695443	GALIYA MEDVEDEVA	{"phone": "+70583137945"}
0005434467736	F9BA71	5255 879267	ROMAN ROMANOV	{"phone": "+70356211199"}
0005434467737	8773C1	9342 083413	MARIYA MEDVEDEVA	{"email": "medvedeva.m.1967@postgrespro.ru", "phone": "+70480238454"}
0005434467738	8773C1	6922 471759	VALENTINA MALYSHEVA	{"phone": "+70940994609"}
0005434467739	94EB2C	6205 178298	ANDREY ALEKSEEV	{"phone": "+70005003683"}
0005434467740	A6D80A	2897 591969	MARIYA FEDOROVA	{"email": "fedorovamariya31031970@postgrespro.ru", "phone": "+70488835329"}
0005434467741	FD7197	7557 173856	ELENA SMIRNOVA	{"phone": "+70674690538"}
0005434467742	E54E56	1178 601509	ARTEM ZAKHAROV	{"email": "a-zakharov_04021967@postgrespro.ru", "phone": "+70001292406"}
0005434467743	B86563	2777 358871	EVGENIY TIKHONOV	{"phone": "+70606567898"}
0005434467744	18172D	2469 460445	SERGEY MOISEEV	{"email": "sergey.moiseev.03071972@postgrespro.ru", "phone": "+70945068915"}
0005434467745	18172D	4851 924963	ALEKSANDR MARTYNOV	{"email": "martynovaleksandr.19061969@postgrespro.ru", "phone": "+70086154395"}
0005434467746	328F5F	1989 301114	IRINA ROMANOVA	{"email": "iromanova.071956@postgrespro.ru", "phone": "+70055968299"}
0005434467747	E82487	2431 517797	YAROSLAV KULIKOV	{"phone": "+70355531481"}
0005434467748	C725E1	1475 040609	IRINA MIRONOVA	{"phone": "+70346712078"}
0005434467749	E3667D	0245 971569	NATALYA MARTYNOVA	{"email": "n_martynova-08031973@postgrespro.ru", "phone": "+70403289173"}
0005434467750	E3667D	8701 829226	NATALYA NAZAROVA	{"email": "natalya-nazarova09031971@postgrespro.ru", "phone": "+70153100408"}
0005434467751	6517C1	8901 806710	TATYANA KAZAKOVA	{"phone": "+70840700581"}
0005434467752	3CB8CB	4144 135181	BORIS RODIONOV	{"phone": "+70262575564"}
0005434467753	59D05F	4101 903879	ANTONINA EFIMOVA	{"phone": "+70532060946"}
0005434480037	97B9DC	0551 298377	SERGEY SAVELEV	{"phone": "+70379580968"}
0005434467754	70653D	7929 924653	TAISIYA IVANOVA	{"email": "ivanovataisiya18101972@postgrespro.ru", "phone": "+70219765985"}
0005434467755	F0FBCA	5437 310500	EVA DMITRIEVA	{"email": "dmitrievaeva-1977@postgrespro.ru", "phone": "+70116691572"}
0005434467756	F0FBCA	7650 672333	ANATOLIY EGOROV	{"email": "egorovanatoliy.1974@postgrespro.ru", "phone": "+70876089896"}
0005434467757	FAC06E	6703 545403	NIKITA KUDRYASHOV	{"phone": "+70003170155"}
0005434467758	F9DDEB	9002 121157	IRINA LAZAREVA	{"phone": "+70229185906"}
0005434467759	414CCE	4239 661846	MIKHAIL SMIRNOV	{"email": "smirnovm16091978@postgrespro.ru", "phone": "+70468025163"}
0005434467760	414CCE	6041 419744	EKATERINA MAKSIMOVA	{"email": "emaksimova121975@postgrespro.ru", "phone": "+70940416128"}
0005434467761	F845FD	6473 866309	SERGEY VASILEV	{"phone": "+70443240912"}
0005434467762	BD0CC1	0069 098179	PAVEL BONDARENKO	{"phone": "+70780998882"}
0005434467763	4E20C9	1096 942190	RAMIL BELOV	{"email": "r_belov30091972@postgrespro.ru", "phone": "+70328509388"}
0005434467764	4E20C9	1813 835906	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda1965@postgrespro.ru", "phone": "+70059192784"}
0005434467765	5B788C	6470 329407	VIKTOR EGOROV	{"phone": "+70218328790"}
0005434467766	5B788C	9465 465562	KONSTANTIN VASILEV	{"email": "konstantin-vasilev_1970@postgrespro.ru", "phone": "+70399350865"}
0005434467767	72347D	4317 446491	SERGEY KUZMIN	{"email": "skuzmin1967@postgrespro.ru", "phone": "+70687000773"}
0005434467768	72347D	1559 006320	NINA DANILOVA	{"email": "ndanilova.24121957@postgrespro.ru", "phone": "+70058711412"}
0005434467769	F073DC	8314 490961	KSENIYA KOVALEVA	{"email": "kovaleva_kseniya09031971@postgrespro.ru", "phone": "+70058718275"}
0005434467770	70D0FF	2482 045675	ROMAN DAVYDOV	{"email": "davydov-roman.1961@postgrespro.ru", "phone": "+70882437444"}
0005434467771	70D0FF	7064 676618	EVGENIY ZAKHAROV	{"phone": "+70845882031"}
0005434467772	80941F	1735 085154	ANATOLIY IVANOV	{"phone": "+70700604318"}
0005434467773	80941F	3589 962703	NIKOLAY POPOV	{"email": "nikolay_popov.051985@postgrespro.ru", "phone": "+70568269955"}
0005434467774	80941F	3665 574869	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov011960@postgrespro.ru", "phone": "+70587209469"}
0005434467775	8034A2	9053 640880	VLADIMIR KUZNECOV	{"phone": "+70661247396"}
0005434467776	8034A2	4258 106918	DANIIL GAVRILOV	{"email": "d-gavrilov-04101962@postgrespro.ru", "phone": "+70533014881"}
0005434467777	8E5515	9447 014216	ELENA CHERNOVA	{"email": "e-chernova091971@postgrespro.ru", "phone": "+70187300342"}
0005434467778	B58780	7793 140327	VALENTINA OSIPOVA	{"email": "valentina-osipova_1972@postgrespro.ru", "phone": "+70712662557"}
0005434467779	3F5CAB	5433 413554	ANGELINA NAZAROVA	{"phone": "+70910195614"}
0005434467780	54CEBD	5249 551996	EVGENIY EGOROV	{"phone": "+70079985139"}
0005434467781	BBE8F8	2658 703297	ANTON ILIN	{"phone": "+70392297982"}
0005434467782	1ACEF8	3008 982558	VLADIMIR GUSEV	{"email": "vgusev_21021970@postgrespro.ru", "phone": "+70436763493"}
0005434467783	894D16	3944 193897	MIKHAIL GRIGOREV	{"email": "mikhail.grigorev_091981@postgrespro.ru", "phone": "+70862976697"}
0005434467784	1B285D	5184 555623	SERGEY ALEKSEEV	{"email": "sergey_alekseev-1966@postgrespro.ru", "phone": "+70461842203"}
0005434467785	1B285D	9247 656645	NATALYA NOVIKOVA	{"phone": "+70266797870"}
0005434467786	A279EE	5639 153487	AMINA DMITRIEVA	{"email": "a.dmitrieva.01101971@postgrespro.ru", "phone": "+70366145508"}
0005434467787	1909F8	9709 480157	VALERIY KOZLOV	{"email": "kozlov.valeriy.29101966@postgrespro.ru", "phone": "+70446548429"}
0005434467788	D68392	4933 946852	ALEKSEY MAKAROV	{"phone": "+70268110861"}
0005434467789	B66E19	0495 525495	VIKTOR DMITRIEV	{"phone": "+70559706515"}
0005434467790	606765	7861 272083	IRINA MIKHAYLOVA	{"email": "imikhaylova1968@postgrespro.ru", "phone": "+70596917766"}
0005434467791	EBFC48	3273 332508	VALERIY PAVLOV	{"phone": "+70931372810"}
0005434467792	AB772A	5698 987166	VALENTINA PETROVA	{"email": "valentina_petrova.26051973@postgrespro.ru", "phone": "+70349419938"}
0005434467793	FE9F43	8585 303730	LYUBOV FROLOVA	{"phone": "+70382977760"}
0005434467794	FBC9C7	9560 715164	ALEKSANDR ROMANOV	{"email": "romanov-a14031971@postgrespro.ru", "phone": "+70492885360"}
0005434467795	FBC9C7	3319 199310	FEDOR KUZNECOV	{"email": "f_kuznecov-1981@postgrespro.ru", "phone": "+70907996416"}
0005434467796	83FE7D	2646 943230	MARIYA TIKHONOVA	{"email": "mariyatikhonova-1977@postgrespro.ru", "phone": "+70886377479"}
0005434467797	949057	2565 607842	TATYANA FILIPPOVA	{"email": "filippovat.081969@postgrespro.ru", "phone": "+70278973522"}
0005434467798	5C0892	9358 627889	VLADIMIR VOROBEV	{"phone": "+70644030958"}
0005434467799	CD81E3	0375 877315	ALEKSEY SEMENOV	{"email": "asemenov_1964@postgrespro.ru", "phone": "+70971525479"}
0005434467800	CD81E3	5608 087012	VALENTIN ROMANOV	{"email": "romanov.v011983@postgrespro.ru", "phone": "+70382558375"}
0005434467801	CB09A5	8200 314443	EVGENIY KUZNECOV	{"email": "e.kuznecov.1967@postgrespro.ru", "phone": "+70905863494"}
0005434467802	CB09A5	7862 603157	SVETLANA BORISOVA	{"phone": "+70562727144"}
0005434467803	BDE1B6	9895 628364	SERGEY FEDOTOV	{"email": "sergey_fedotov-20111972@postgrespro.ru", "phone": "+70876583076"}
0005434467804	BDE1B6	9879 289071	SVETLANA ISAEVA	{"phone": "+70589897415"}
0005434467805	BDFBE4	4613 229059	MARINA SOROKINA	{"phone": "+70201566900"}
0005434467806	8650C4	1453 449779	RAISA POLYAKOVA	{"email": "polyakova-r.1973@postgrespro.ru", "phone": "+70900425231"}
0005434467807	5B3C4F	1543 273429	VLADIMIR PAVLOV	{"email": "vladimirpavlov_031967@postgrespro.ru", "phone": "+70689081665"}
0005434467808	5B3C4F	2407 446663	SVETLANA LAZAREVA	{"email": "lazareva.svetlana1976@postgrespro.ru", "phone": "+70306123988"}
0005434467809	4B7434	6746 958252	NIKOLAY OSIPOV	{"phone": "+70848311230"}
0005434467810	BF8CB9	5650 687599	ALEKSANDRA PAVLOVA	{"email": "aleksandra_pavlova1975@postgrespro.ru", "phone": "+70484450611"}
0005434467811	1F6012	8588 805996	ARTEM SHEVCHENKO	{"email": "a_shevchenko_061977@postgrespro.ru", "phone": "+70860968826"}
0005434467812	1F6012	0531 330764	VITALIY NIKITIN	{"email": "nikitin_v.021969@postgrespro.ru", "phone": "+70767218328"}
0005434467813	3CA5ED	2566 778303	ALEKSEY KOROLEV	{"phone": "+70915828411"}
0005434467814	6AA4CE	3173 564449	GALINA IVANOVA	{"phone": "+70653819335"}
0005434467815	4A2855	1691 083411	TATYANA SERGEEVA	{"phone": "+70747782602"}
0005434467816	BA1EC2	4184 110794	ALEKSEY ZAKHAROV	{"phone": "+70856149404"}
0005434467817	BA1EC2	1579 722210	OLGA VOLKOVA	{"phone": "+70405045147"}
0005434467818	26AB42	9376 175549	SEMEN VASILEV	{"email": "svasilev_1975@postgrespro.ru", "phone": "+70402292744"}
0005434467819	26AB42	9405 790879	ANATOLIY ALEKSEEV	{"phone": "+70680562481"}
0005434467820	26AB42	2178 531826	VASILIY DAVYDOV	{"email": "davydovv_10071977@postgrespro.ru", "phone": "+70631328619"}
0005434467821	A4A943	9006 942442	IVAN SOKOLOV	{"email": "ivan_sokolov.22051973@postgrespro.ru", "phone": "+70403297393"}
0005434467822	2EE987	2020 979652	YURIY SMIRNOV	{"email": "smirnov-yuriy_16121970@postgrespro.ru", "phone": "+70127077050"}
0005434467823	2EE987	2773 100876	NIKITA FILIPPOV	{"phone": "+70081049521"}
0005434467824	CBC001	6476 052782	NADEZHDA GRISHINA	{"phone": "+70384181070"}
0005434467825	90BBF2	3047 531260	VLADIMIR MAKSIMOV	{"phone": "+70196439898"}
0005434467826	90BBF2	4800 727326	ANDREY DAVYDOV	{"email": "davydov.andrey-06021971@postgrespro.ru", "phone": "+70668509767"}
0005434467827	119806	9539 725332	NATALYA LEBEDEVA	{"phone": "+70423363251"}
0005434467828	3C3596	8423 729058	TATYANA ZHUKOVA	{"phone": "+70345147220"}
0005434467829	6B5547	3286 193216	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov.08091974@postgrespro.ru", "phone": "+70337602192"}
0005434467830	4DB194	7992 208318	ILDAR SEMENOV	{"email": "semenov-i-1972@postgrespro.ru", "phone": "+70146028418"}
0005434467831	4DB194	0687 417975	NATALIYA MATVEEVA	{"email": "matveeva-n-1972@postgrespro.ru", "phone": "+70084957617"}
0005434479878	05D482	5262 633554	VIKTOR FOMIN	{"phone": "+70491004191"}
0005434479879	05D482	8846 778647	ALBINA ZAKHAROVA	{"phone": "+70557194056"}
0005434479880	05D482	0786 151043	EKATERINA VOLKOVA	{"phone": "+70117990358"}
0005434479881	F9A833	1452 988905	MAKSIM SIDOROV	{"phone": "+70018763555"}
0005434479882	46A1D6	4279 573013	ELENA MIKHAYLOVA	{"email": "mikhaylovae02111977@postgrespro.ru", "phone": "+70158174328"}
0005434479883	C424A8	8773 178135	ALEKSANDR MAKAROV	{"phone": "+70304596265"}
0005434479884	89437D	0318 348118	VITALIY RODIONOV	{"email": "rodionov_vitaliy.091973@postgrespro.ru", "phone": "+70696702026"}
0005434479885	89437D	2606 145492	OLGA GAVRILOVA	{"email": "gavrilova_o1974@postgrespro.ru", "phone": "+70197848511"}
0005434479886	A658A4	7673 758972	ANATOLIY ORLOV	{"email": "a_orlov1964@postgrespro.ru", "phone": "+70721052208"}
0005434479887	3124E5	6930 052728	LYUBOV PETROVA	{"phone": "+70795379338"}
0005434479888	A2A7D5	0355 384249	GALINA BOGDANOVA	{"phone": "+70754156149"}
0005434479889	A2A7D5	4785 610061	ALEKSANDR MAKAROV	{"email": "amakarov-071971@postgrespro.ru", "phone": "+70384942510"}
0005434479890	3613E8	6504 240356	ALENA OSIPOVA	{"email": "osipova-a-081968@postgrespro.ru", "phone": "+70105746241"}
0005434479891	3613E8	3842 841097	LYUBOV MAKAROVA	{"email": "makarova_lyubov11061969@postgrespro.ru", "phone": "+70367385224"}
0005434479892	2743C6	5990 183430	VIKTORIYA KONDRATEVA	{"phone": "+70533169746"}
0005434479893	00C2A5	8524 426625	ANATOLIY MAKAROV	{"email": "makarov_anatoliy-30081966@postgrespro.ru", "phone": "+70938312265"}
0005434479894	839496	2951 316589	VLADISLAV ANTONOV	{"email": "antonov.v.101965@postgrespro.ru", "phone": "+70269501110"}
0005434479895	839496	9425 753188	MARIYA POTAPOVA	{"phone": "+70905200338"}
0005434479896	EB7EFB	5046 041195	VALERIY FILIPPOV	{"phone": "+70629953220"}
0005434479897	4743ED	5747 455206	DMITRIY BORISOV	{"phone": "+70420865617"}
0005434479898	DC021C	1472 170516	ANATOLIY DMITRIEV	{"email": "dmitriev-anatoliy111968@postgrespro.ru", "phone": "+70223393900"}
0005434479899	26A10E	2646 096363	YULIYA POPOVA	{"email": "popovayuliya_121970@postgrespro.ru", "phone": "+70528253962"}
0005434479900	26A10E	5170 008543	LYUBOV NESTEROVA	{"email": "l-nesterova31081980@postgrespro.ru", "phone": "+70865700922"}
0005434479901	66841C	8068 018238	ALEKSEY MOROZOV	{"email": "morozov.aleksey.091975@postgrespro.ru", "phone": "+70589966257"}
0005434479902	A8E7EB	6362 841704	VALERIY FROLOV	{"email": "valeriy-frolov031976@postgrespro.ru", "phone": "+70108881059"}
0005434479903	9845B1	7369 112095	EVGENIY ANDREEV	{"phone": "+70301154040"}
0005434479904	F1BAF1	5033 391771	YAROSLAV ANDREEV	{"email": "y-andreev-121973@postgrespro.ru", "phone": "+70862602275"}
0005434479905	B85F73	2678 825667	VLADIMIR KONOVALOV	{"email": "vladimir-konovalov_1968@postgrespro.ru", "phone": "+70235698842"}
0005434479906	626543	2821 357679	ANASTASIYA MAKAROVA	{"phone": "+70729206916"}
0005434479907	626543	1638 633056	ELENA POPOVA	{"email": "elenapopova.091971@postgrespro.ru", "phone": "+70061335911"}
0005434479908	4DF550	4612 231390	LYUDMILA LOGINOVA	{"email": "lyudmila-loginova1981@postgrespro.ru", "phone": "+70340202908"}
0005434479909	CC1364	2602 494895	DARYA FILATOVA	{"email": "darya_filatova_29051974@postgrespro.ru", "phone": "+70333173297"}
0005434479910	3D794C	8005 473116	ALEKSANDR KOZLOV	{"email": "kozlov-a-1982@postgrespro.ru", "phone": "+70012980125"}
0005434479911	3D794C	2045 928315	ALEKSEY PETROV	{"email": "petrov-a_20011973@postgrespro.ru", "phone": "+70660609566"}
0005434479912	4E1B93	9530 316121	YURIY ORLOV	{"email": "y-orlov.1976@postgrespro.ru", "phone": "+70270157193"}
0005434479913	E861CF	9694 034663	YULIYA KONOVALOVA	{"email": "y-konovalova-26111962@postgrespro.ru", "phone": "+70995470368"}
0005434479914	7BC5C7	6705 968583	YAROSLAV BORISOV	{"phone": "+70013412902"}
0005434479915	2D4928	4444 121348	GALINA IVANOVA	{"phone": "+70688258064"}
0005434479916	2D4928	8300 033652	VLADIMIR MEDVEDEV	{"phone": "+70154242069"}
0005434480038	9F1BE3	4531 906734	EKATERINA BELOVA	{"phone": "+70412212256"}
0005434479917	ACA325	0243 424918	NATALYA MASLOVA	{"email": "maslova-natalya-071976@postgrespro.ru", "phone": "+70764543203"}
0005434479918	BAFB9D	2897 800409	YURIY SOKOLOV	{"email": "sokolovy091966@postgrespro.ru", "phone": "+70642390816"}
0005434479919	7ED625	0237 873550	GENNADIY SERGEEV	{"phone": "+70849794878"}
0005434479920	7ED625	0087 081510	OKSANA FOMINA	{"email": "fomina.oksana1974@postgrespro.ru", "phone": "+70545024707"}
0005434479921	2EDB04	0146 544050	ALEKSEY TIMOFEEV	{"phone": "+70525581779"}
0005434479922	14B871	1086 884983	EVGENIY NIKITIN	{"phone": "+70871008555"}
0005434479923	510E4B	9480 859136	NADEZHDA PETROVA	{"email": "petrova-n1972@postgrespro.ru", "phone": "+70696081037"}
0005434479924	A05884	7936 840607	GENNADIY VOROBEV	{"email": "vorobev.gennadiy081973@postgrespro.ru", "phone": "+70237624991"}
0005434479925	9647ED	0445 194221	YANA KRASNOVA	{"email": "krasnovay071984@postgrespro.ru", "phone": "+70247926038"}
0005434479926	7392F5	5767 626789	NIKOLAY PAVLOV	{"email": "pavlov_n_11061976@postgrespro.ru", "phone": "+70839011325"}
0005434479927	2CD455	5444 069995	SEMEN NIKOLAEV	{"email": "s-nikolaev.101971@postgrespro.ru", "phone": "+70023071940"}
0005434479928	6CC952	0180 421829	OLGA POLYAKOVA	{"email": "olga-polyakova-21061966@postgrespro.ru", "phone": "+70846649042"}
0005434479929	34DAB9	5446 325674	ANAIT SOLOVEVA	{"email": "anaitsoloveva_1972@postgrespro.ru", "phone": "+70780255854"}
0005434479930	2F2A5F	4706 540166	VLADIMIR MOISEEV	{"phone": "+70247651139"}
0005434479931	A2E17D	7645 389698	YURIY SEMENOV	{"email": "semenovy.041967@postgrespro.ru", "phone": "+70155138397"}
0005434479932	A2E17D	9962 828774	LIDIYA KOZLOVA	{"phone": "+70249524794"}
0005434479933	77B638	9705 965367	ANNA NOVIKOVA	{"phone": "+70986236438"}
0005434479934	501645	4416 537748	VIKTOR SOROKIN	{"email": "v.sorokin_19071963@postgrespro.ru", "phone": "+70912896906"}
0005434479935	C5D254	0667 119365	ANDREY IVANOV	{"phone": "+70656286890"}
0005434479936	AAE3A5	1918 497956	NIKOLAY KARPOV	{"email": "karpovnikolay-1976@postgrespro.ru", "phone": "+70873897445"}
0005434479937	ECB550	6392 591065	PETR CHERNOV	{"phone": "+70637367833"}
0005434479938	C182F2	4741 861533	ALEKSEY MIRONOV	{"email": "a.mironov-051968@postgrespro.ru", "phone": "+70093796441"}
0005434479939	D2CB54	1432 236216	VIKTOR ROMANOV	{"phone": "+70608468154"}
0005434479940	4C9E8B	5851 074094	ROZA MAKAROVA	{"email": "makarova-r1972@postgrespro.ru", "phone": "+70700025031"}
0005434479941	4C9E8B	1843 075987	VASILIY ROMANOV	{"phone": "+70228566832"}
0005434479942	4C9E8B	4646 861000	SERGEY NIKOLAEV	{"email": "sergeynikolaev-1957@postgrespro.ru", "phone": "+70857722339"}
0005434479943	4C9E8B	2968 121611	VLADIMIR MARTYNOV	{"phone": "+70544813503"}
0005434479944	061F1C	0192 663782	PETR ANDREEV	{"email": "andreev-petr041976@postgrespro.ru", "phone": "+70857750953"}
0005434479945	485631	0488 864529	MARGARITA VASILEVA	{"phone": "+70254306644"}
0005434479946	3A76EA	6730 559148	VALERIY SIDOROV	{"email": "sidorov-valeriy.10121969@postgrespro.ru", "phone": "+70831536443"}
0005434479947	57CB50	4323 236533	ANDREY ILIN	{"phone": "+70379219407"}
0005434479948	7994B3	7206 972783	IRAIDA KOROLEVA	{"email": "koroleva-iraida121975@postgrespro.ru", "phone": "+70446948890"}
0005434479949	7994B3	6841 325763	VERA ANISIMOVA	{"email": "anisimova_v121961@postgrespro.ru", "phone": "+70008891515"}
0005434479950	CADFA5	2431 416323	KIRILL ABRAMOV	{"phone": "+70358575408"}
0005434479951	ABD558	8421 541172	VALENTINA ZAKHAROVA	{"email": "zakharova-v1973@postgrespro.ru", "phone": "+70658664983"}
0005434479952	28458B	5609 075274	VALENTINA MOISEEVA	{"email": "v-moiseeva_1965@postgrespro.ru", "phone": "+70210339613"}
0005434479953	28458B	2875 650347	ANASTASIYA SMIRNOVA	{"email": "anastasiya_smirnova1970@postgrespro.ru", "phone": "+70092378978"}
0005434479954	F5F41C	7615 821133	DANILA KUZMIN	{"phone": "+70546466481"}
0005434479955	16558C	9796 935555	VALERIYA MAKAROVA	{"phone": "+70706749160"}
0005434479956	8A1CF4	4926 046292	RAMILYA ROMANOVA	{"email": "r.romanova_21051971@postgrespro.ru", "phone": "+70711026617"}
0005434479957	8A1CF4	2610 514793	ANATOLIY BONDARENKO	{"phone": "+70283413001"}
0005434479958	EE72EB	1879 513964	KLAVDIYA TIMOFEEVA	{"phone": "+70208518856"}
0005434479959	0F4577	0624 647721	ILYA ANTONOV	{"email": "i-antonov-1979@postgrespro.ru", "phone": "+70352111924"}
0005434479960	10145F	0967 352963	KONSTANTIN AFANASEV	{"email": "konstantinafanasev041974@postgrespro.ru", "phone": "+70120125965"}
0005434479961	4B8582	8326 058489	ELENA MALYSHEVA	{"email": "elena_malysheva071969@postgrespro.ru", "phone": "+70903880868"}
0005434479962	4B8582	4802 961723	YURIY MELNIKOV	{"email": "melnikov-y-051975@postgrespro.ru", "phone": "+70866094902"}
0005434479963	B03106	0634 819431	MIKHAIL SMIRNOV	{"email": "smirnov_m1968@postgrespro.ru", "phone": "+70983643355"}
0005434479964	942C7E	6995 968847	ANASTASIYA BELYAEVA	{"phone": "+70482599770"}
0005434479965	3D7463	0862 055713	DENIS ILIN	{"phone": "+70136697271"}
0005434479966	C850D0	5371 060182	OLGA PAVLOVA	{"email": "pavlova.olga_041976@postgrespro.ru", "phone": "+70910869749"}
0005434479967	C850D0	1456 336668	VIKTORIYA KUZMINA	{"phone": "+70698747247"}
0005434479968	305E11	5744 413315	ANDREY ZAYCEV	{"phone": "+70923232504"}
0005434479969	305E11	2003 476302	TATYANA VOROBEVA	{"email": "vorobeva.t1966@postgrespro.ru", "phone": "+70052109444"}
0005434479970	55F69D	3805 000208	VERONIKA PETROVA	{"email": "petrovav_011977@postgrespro.ru", "phone": "+70205531911"}
0005434479971	B3D06B	3510 577108	DANIL MAKAROV	{"email": "makarov_d.031980@postgrespro.ru", "phone": "+70102502668"}
0005434479972	A7CC5D	8236 471408	ARMAN ZAKHAROV	{"email": "zakharov-arman_18021966@postgrespro.ru", "phone": "+70353890834"}
0005434479973	A7CC5D	0459 543177	MARIYA KOZLOVA	{"email": "kozlova-m1964@postgrespro.ru", "phone": "+70197166726"}
0005434479974	33C52D	3536 833906	ALEKSEY NAZAROV	{"email": "aleksey.nazarov.1972@postgrespro.ru", "phone": "+70044396928"}
0005434479975	33C52D	7859 252585	VALENTIN POPOV	{"phone": "+70168150614"}
0005434479976	0FC1D3	8211 098320	VLADIMIR ZHURAVLEV	{"email": "v-zhuravlev111973@postgrespro.ru", "phone": "+70655006640"}
0005434479977	0FC1D3	2256 729769	DIANA POLYAKOVA	{"phone": "+70829522692"}
0005434479978	96ED92	2573 114706	MIKHAIL SOROKIN	{"email": "sorokin.mikhail-22121976@postgrespro.ru", "phone": "+70981171478"}
0005434479979	96ED92	6900 147517	DMITRIY NIKITIN	{"phone": "+70030914837"}
0005434479980	96ED92	5112 892625	VLADIMIR ANTONOV	{"email": "vladimirantonov-30121971@postgrespro.ru", "phone": "+70161301763"}
0005434479981	5B11A5	0141 106785	IGOR ILIN	{"phone": "+70126456381"}
0005434479982	5B11A5	6592 927934	LIDIYA VLASOVA	{"phone": "+70279558986"}
0005434479983	3B466E	8643 094750	ANDREY IVANOV	{"email": "andreyivanov_03081972@postgrespro.ru", "phone": "+70415958077"}
0005434479984	FC300C	1732 446395	NATALYA PAVLOVA	{"phone": "+70161476359"}
0005434479985	B38F3C	7631 432225	OLGA NESTEROVA	{"phone": "+70446909894"}
0005434479986	9FDAB7	9430 619672	ANTONINA TIMOFEEVA	{"phone": "+70741148206"}
0005434479987	EEEB61	0734 605650	SERGEY KUZNECOV	{"email": "s_kuznecov071946@postgrespro.ru", "phone": "+70430398313"}
0005434479988	EEEB61	0309 571076	ANNA MOROZOVA	{"phone": "+70378927088"}
0005434479989	FD13C4	0757 140562	KLAVDIYA KUZNECOVA	{"phone": "+70569868993"}
0005434479990	FD13C4	4302 493141	YULIYA CHERNOVA	{"email": "yuliya.chernova.1977@postgrespro.ru", "phone": "+70919844306"}
0005434479991	263789	8126 963508	VYACHESLAV KUZMIN	{"email": "kuzminvyacheslav061972@postgrespro.ru", "phone": "+70025288173"}
0005434479992	263789	8535 159195	ALEKSANDR BONDARENKO	{"email": "aleksandr_bondarenko.1968@postgrespro.ru", "phone": "+70397043691"}
0005434479993	E00ABF	3351 780103	TATYANA AKIMOVA	{"phone": "+70110339239"}
0005434479994	E00ABF	4315 970922	ELENA NIKIFOROVA	{"email": "nikiforova.e1978@postgrespro.ru", "phone": "+70260025261"}
0005434479995	A4F6A8	9182 710969	VIKTOR KUZNECOV	{"phone": "+70618112561"}
0005434479996	A4F6A8	0986 361620	VARVARA DANILOVA	{"email": "v-danilova_081973@postgrespro.ru", "phone": "+70323751467"}
0005434479997	A4F6A8	6252 087230	SVETLANA KOVALEVA	{"phone": "+70163273204"}
0005434479998	B12C13	9844 888711	MAKSIM KUZNECOV	{"phone": "+70690673399"}
0005434479999	3D31AF	3689 754685	VYACHESLAV ROMANOV	{"phone": "+70144015136"}
0005434480000	64F899	3745 246448	GUZEL YUDINA	{"email": "yudina.g.1964@postgrespro.ru", "phone": "+70621878634"}
0005434480001	AE75BF	7662 737789	ANTONINA SIDOROVA	{"email": "a_sidorova-1980@postgrespro.ru", "phone": "+70234243724"}
0005434480002	AE75BF	6758 387764	ALEKSANDR SOKOLOV	{"phone": "+70015987761"}
0005434480003	58D85A	6923 884400	ANDREY MELNIKOV	{"email": "amelnikov_16011980@postgrespro.ru", "phone": "+70336852978"}
0005434480004	1ADE84	1541 029065	ZINAIDA LUKYANOVA	{"email": "lukyanova-zinaida_1958@postgrespro.ru", "phone": "+70436553895"}
0005434480005	B71570	1298 583608	ALEKSANDR GAVRILOV	{"phone": "+70666756177"}
0005434480006	7C3551	9593 054030	VLADIMIR KOZLOV	{"email": "kozlov_vladimir_1973@postgrespro.ru", "phone": "+70604768422"}
0005434480007	36E927	9540 765761	ELENA LOGINOVA	{"phone": "+70794266925"}
0005434480008	36E927	2543 511616	MARINA KOMAROVA	{"email": "marina.komarova_1966@postgrespro.ru", "phone": "+70871098522"}
0005434480009	5D571C	8477 190124	ZINAIDA KUZNECOVA	{"phone": "+70145523803"}
0005434480010	F7665B	6729 545217	SVETLANA SAVELEVA	{"email": "ssaveleva-1975@postgrespro.ru", "phone": "+70537700591"}
0005434480011	37D67C	3338 288256	MIKHAIL TIMOFEEV	{"phone": "+70930908794"}
0005434480012	37D67C	7718 258840	RUSLAN FROLOV	{"email": "frolov_ruslan.061974@postgrespro.ru", "phone": "+70153906801"}
0005434480013	842E94	3648 293139	TATYANA POPOVA	{"email": "popovat-1982@postgrespro.ru", "phone": "+70268138008"}
0005434480014	A6FF84	9286 477546	ZOYA STEPANOVA	{"phone": "+70408744316"}
0005434480015	C7BF2E	1771 393913	MAKSIM GERASIMOV	{"email": "gerasimovm1974@postgrespro.ru", "phone": "+70465871242"}
0005434480016	8F1503	0800 229280	NADEZHDA NIKITINA	{"phone": "+70351149559"}
0005434480017	BFF089	3475 027645	SERGEY IVANOV	{"email": "ivanovsergey1962@postgrespro.ru", "phone": "+70826961755"}
0005434480018	BFF089	9029 042145	ALEKSEY BELOV	{"phone": "+70369655192"}
0005434480019	2CF190	6551 256264	VLADIMIR ZAKHAROV	{"phone": "+70567666021"}
0005434480020	A8C7F1	2972 762081	ELENA IVANOVA	{"phone": "+70830834411"}
0005434480021	A8C7F1	2080 989630	ALEKSEY FOMIN	{"email": "fomin.aleksey.011975@postgrespro.ru", "phone": "+70860184264"}
0005434480022	409D19	3228 886563	ANTONINA KRASNOVA	{"phone": "+70902665573"}
0005434480023	A02ACF	3000 148456	IVAN NAUMOV	{"phone": "+70321580953"}
0005434480024	81AEB0	6749 779616	ALEKSEY KUDRYASHOV	{"phone": "+70449677191"}
0005434480025	A44D3D	1835 467781	DARYA ORLOVA	{"phone": "+70365752645"}
0005434480026	3FC43B	8018 421329	YULIYA SERGEEVA	{"phone": "+70566804687"}
0005434480027	3FC43B	5181 901397	SERGEY ANDREEV	{"email": "andreevs.06031961@postgrespro.ru", "phone": "+70834981658"}
0005434480028	89E573	6676 934980	VASILIY FILIPPOV	{"phone": "+70526407790"}
0005434480029	D77079	7637 955959	SERGEY KUZNECOV	{"email": "skuznecov.031975@postgrespro.ru", "phone": "+70217410178"}
0005434480030	D77079	8205 584998	ELIZAVETA DENISOVA	{"phone": "+70247150578"}
0005434480031	147306	6965 599580	EKATERINA CHERNOVA	{"email": "chernovaekaterina-26041968@postgrespro.ru", "phone": "+70671841571"}
0005434480032	147306	7847 500348	OLGA AFANASEVA	{"email": "afanaseva-olga.29041964@postgrespro.ru", "phone": "+70120514043"}
0005434480033	147306	2805 855828	MAKSIM ORLOV	{"email": "orlovmaksim.081979@postgrespro.ru", "phone": "+70150341355"}
0005434480034	BB331C	4145 668744	YURIY MIRONOV	{"phone": "+70885932804"}
0005434480035	B7995F	7669 759837	ANDREY MEDVEDEV	{"email": "andrey_medvedev051968@postgrespro.ru", "phone": "+70177478477"}
0005434480036	B7995F	5366 271767	VIKTOR POPOV	{"phone": "+70276036656"}
0005434480039	AB96AD	9832 010667	NINA KOZLOVA	{"phone": "+70633059312"}
0005434480040	4A5054	2119 226380	LARISA POPOVA	{"email": "popova_l_051978@postgrespro.ru", "phone": "+70723183008"}
0005434480041	4A5054	4916 713711	ANNA DAVYDOVA	{"phone": "+70445070726"}
0005434480042	CF6556	6201 911834	ROMAN KRASNOV	{"email": "r.krasnov061964@postgrespro.ru", "phone": "+70699065931"}
0005434480043	CF6556	7407 263386	ANTONINA MAKAROVA	{"email": "makarova-a_03111970@postgrespro.ru", "phone": "+70119502174"}
0005434480044	518A88	6039 422682	VYACHESLAV MOROZOV	{"email": "vyacheslav_morozov_121973@postgrespro.ru", "phone": "+70800092621"}
0005434480045	518A88	3372 365484	ALEKSANDR TARASOV	{"email": "a-tarasov-1968@postgrespro.ru", "phone": "+70620922942"}
0005434480046	F1A9D9	6376 116308	ALEKSANDR FROLOV	{"email": "frolov.aleksandr1961@postgrespro.ru", "phone": "+70517986846"}
0005434480047	A66A4E	6328 064209	ANNA DENISOVA	{"email": "denisova_anna-1971@postgrespro.ru", "phone": "+70721571570"}
0005434480048	FED871	3477 253090	VITALIY NOVIKOV	{"email": "vnovikov29031979@postgrespro.ru", "phone": "+70617382134"}
0005434480049	87F36B	1765 576176	ANTONINA TITOVA	{"email": "titova.a.111972@postgrespro.ru", "phone": "+70949453138"}
0005434480050	87F36B	4085 038423	VALENTINA TIMOFEEVA	{"email": "valentina_timofeeva1975@postgrespro.ru", "phone": "+70180716759"}
0005434480051	2F7F85	9772 797730	SERGEY OSIPOV	{"email": "sergey.osipov_101983@postgrespro.ru", "phone": "+70780114604"}
0005434480052	2F7F85	1346 339785	ROMAN SCHERBAKOV	{"email": "scherbakov_roman1968@postgrespro.ru", "phone": "+70933691687"}
0005434480053	66A338	7661 451512	GALINA SMIRNOVA	{"email": "smirnova.g.05021962@postgrespro.ru", "phone": "+70474093884"}
0005434480054	325CA6	2904 694348	ELENA POPOVA	{"phone": "+70558327462"}
0005434480055	CB8C94	4936 421152	SERGEY ROMANOV	{"email": "sergey-romanov041966@postgrespro.ru", "phone": "+70346301048"}
0005434480056	9BDEBB	2237 994762	VALENTINA MIRONOVA	{"email": "valentina.mironova051974@postgrespro.ru", "phone": "+70498833658"}
0005434480057	9BDEBB	6155 786124	VIKTOR IVANOV	{"phone": "+70298708658"}
0005434480058	340974	5401 874743	ANNA YUDINA	{"phone": "+70533952766"}
0005434480059	F0219E	8320 170814	OLGA KULIKOVA	{"email": "olga.kulikova111974@postgrespro.ru", "phone": "+70924387911"}
0005434480060	A4A10E	6192 883936	MAKSIM MIKHAYLOV	{"phone": "+70515091663"}
0005434480061	A4A10E	3443 034399	ALEKSANDRA BOGDANOVA	{"email": "aleksandra.bogdanova-021961@postgrespro.ru", "phone": "+70800994547"}
0005434480062	5660F0	5730 842645	MIKHAIL SCHERBAKOV	{"email": "scherbakovm081985@postgrespro.ru", "phone": "+70330288169"}
0005434480063	E8A2EF	4601 380862	SERGEY GRIGOREV	{"phone": "+70599508278"}
0005434480064	DDE387	0827 600563	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova-lyudmila-051966@postgrespro.ru", "phone": "+70535436175"}
0005434480065	4DD316	0176 901190	ANTONINA GORBUNOVA	{"email": "antonina-gorbunova.08031977@postgrespro.ru", "phone": "+70954473887"}
0005434480066	44F722	4405 405338	ALEKSEY VASILEV	{"phone": "+70527706556"}
0005434480067	44F722	0956 984939	ARTEM GRIGOREV	{"email": "grigoreva.1981@postgrespro.ru", "phone": "+70925836487"}
0005434480068	DB2C45	4244 107682	ALEKSANDR ZHURAVLEV	{"email": "a.zhuravlev-071977@postgrespro.ru", "phone": "+70129854178"}
0005434480069	DB2C45	1475 494966	TATYANA MELNIKOVA	{"email": "melnikova-tatyana-051962@postgrespro.ru", "phone": "+70398882402"}
0005434480070	DB2C45	2968 216416	VERA KALININA	{"phone": "+70589653992"}
0005434480071	E488A7	0326 318290	SVETLANA MAKAROVA	{"phone": "+70825918478"}
0005434480072	E488A7	3667 268236	EVGENIYA MAKAROVA	{"phone": "+70915528492"}
0005434480073	AA150C	3059 795636	VALERIYA GERASIMOVA	{"phone": "+70535263211"}
0005434480074	AA150C	3612 022423	VIKTOR SOLOVEV	{"phone": "+70555448228"}
0005434480075	AA150C	4826 131017	ANDREY KISELEV	{"phone": "+70279417851"}
0005434480076	CCA42B	9257 533431	EVGENIY DMITRIEV	{"phone": "+70220831998"}
0005434480077	BB9D76	2175 502746	ALENA STEPANOVA	{"phone": "+70147106303"}
0005434480078	BB9D76	7127 726055	NINA VOLKOVA	{"email": "volkova-n_1978@postgrespro.ru", "phone": "+70247374568"}
0005434480079	35717A	4742 555528	YURIY KULIKOV	{"email": "yuriy.kulikov-101973@postgrespro.ru", "phone": "+70456638516"}
0005434480134	0ED623	9156 659174	KRISTINA DENISOVA	{"phone": "+70729432073"}
0005434480080	35717A	3151 879453	VERA ZAYCEVA	{"email": "zayceva.vera_1967@postgrespro.ru", "phone": "+70165331590"}
0005434480081	35717A	0250 629700	PAVEL MIRONOV	{"email": "mironov.pavel.11071968@postgrespro.ru", "phone": "+70157392028"}
0005434480082	0BE443	4535 145807	MARIYA POPOVA	{"phone": "+70837538379"}
0005434480083	0BE443	5490 045182	ELENA STEPANOVA	{"email": "stepanovae_04031964@postgrespro.ru", "phone": "+70206256762"}
0005434480084	679BE7	7121 698151	VALENTINA FILATOVA	{"phone": "+70770012816"}
0005434480085	037BA0	7861 971180	BORIS MAKAROV	{"phone": "+70302412686"}
0005434480086	9F1DFB	3656 520855	LIDIYA KRASNOVA	{"email": "krasnova_l1969@postgrespro.ru", "phone": "+70699666807"}
0005434480087	4915F1	9943 485677	ELENA ROMANOVA	{"email": "romanova-elena-04041972@postgrespro.ru", "phone": "+70247821868"}
0005434480088	58930A	4247 759543	ALEKSANDRA MEDVEDEVA	{"email": "medvedevaaleksandra-101981@postgrespro.ru", "phone": "+70631748625"}
0005434480089	3BF792	8695 468520	DARYA PETROVA	{"email": "petrovadarya-1979@postgrespro.ru", "phone": "+70538172367"}
0005434480090	9A7992	6927 026512	EVGENIY IVANOV	{"email": "evgeniyivanov.1989@postgrespro.ru", "phone": "+70395551485"}
0005434480091	9A7992	5575 445410	MATVEY ANDREEV	{"email": "andreev.matvey23111967@postgrespro.ru", "phone": "+70576005021"}
0005434480092	27B943	9088 295866	ANDREY KAZAKOV	{"email": "kazakova-091970@postgrespro.ru", "phone": "+70609795330"}
0005434480093	0BAD7F	3224 585313	TATYANA FROLOVA	{"email": "frolova-tatyana1960@postgrespro.ru", "phone": "+70025555477"}
0005434480094	54652D	9177 169368	ELENA OSIPOVA	{"email": "osipova-elena_27041959@postgrespro.ru", "phone": "+70398810156"}
0005434480095	CF97C4	6627 806235	ALEKSANDRA ISAEVA	{"phone": "+70862707295"}
0005434480096	0BBB76	9448 970189	TATYANA DENISOVA	{"phone": "+70084368368"}
0005434480097	A2A453	8456 097721	FEDOR VLASOV	{"phone": "+70143326546"}
0005434480098	8BA90F	0438 484019	YULIYA KALININA	{"email": "kalininay-31101963@postgrespro.ru", "phone": "+70284585201"}
0005434480099	8BA90F	0330 569994	MARINA FEDOROVA	{"email": "marinafedorova-27081972@postgrespro.ru", "phone": "+70644555562"}
0005434480100	FE364B	9702 261202	TATYANA TARASOVA	{"email": "tarasova.tatyana-031981@postgrespro.ru", "phone": "+70212464621"}
0005434480101	FE364B	4178 535773	VLADIMIR IVANOV	{"email": "ivanov-v26081978@postgrespro.ru", "phone": "+70504185188"}
0005434480102	3A6788	1881 239970	LYUBOV POPOVA	{"email": "popova-lyubov_07091975@postgrespro.ru", "phone": "+70503178990"}
0005434480103	87A2F6	9175 514658	EKATERINA VOROBEVA	{"phone": "+70529181107"}
0005434480104	6EB5E1	4554 257435	OLEG NIKOLAEV	{"email": "o.nikolaev_20051973@postgrespro.ru", "phone": "+70991641520"}
0005434480105	37E38E	2739 311934	MIKHAIL DMITRIEV	{"email": "m-dmitriev-101969@postgrespro.ru", "phone": "+70209775523"}
0005434480106	25E9A6	6835 776218	ALEKSANDR SIDOROV	{"phone": "+70329536795"}
0005434480107	D9D64D	1115 852066	RASHID ANDREEV	{"phone": "+70985474743"}
0005434480108	B4B1FD	2063 838348	VLADIMIR MIRONOV	{"phone": "+70444362558"}
0005434480109	47A227	0184 403611	ALINA ARKHIPOVA	{"email": "alina_arkhipova.111966@postgrespro.ru", "phone": "+70724546103"}
0005434480110	47A227	1009 123026	LARISA LOGINOVA	{"email": "l-loginova08051982@postgrespro.ru", "phone": "+70157366511"}
0005434480111	27EA83	8232 592423	ANTON MIRONOV	{"email": "mironov.anton_25021971@postgrespro.ru", "phone": "+70578838288"}
0005434480112	8E7B3C	5289 367599	IRINA KOZLOVA	{"email": "ikozlova_021980@postgrespro.ru", "phone": "+70268402609"}
0005434480113	6104FB	6081 297454	VALERIYA TITOVA	{"phone": "+70019392351"}
0005434480114	1A03CB	3759 791356	NINA ROMANOVA	{"phone": "+70996817350"}
0005434480115	1A03CB	6407 328349	ALENA BORISOVA	{"phone": "+70366653609"}
0005434480116	708B2E	7620 461191	BORIS MELNIKOV	{"email": "boris.melnikov_26071977@postgrespro.ru", "phone": "+70467063830"}
0005434480117	803CC4	6951 120008	MARIANNA DENISOVA	{"email": "mdenisova_1980@postgrespro.ru", "phone": "+70413752191"}
0005434480118	2353CE	2307 784333	ALEKSANDR SEMENOV	{"phone": "+70647505471"}
0005434480119	2353CE	8847 584628	SNEZHANA SERGEEVA	{"email": "snezhana.sergeeva1982@postgrespro.ru", "phone": "+70357145088"}
0005434480120	8322CC	5575 661803	ALEKSANDR KONOVALOV	{"phone": "+70724330972"}
0005434480121	5B9073	4744 204965	LYUDMILA AKIMOVA	{"email": "lyudmila.akimova.061974@postgrespro.ru", "phone": "+70866868021"}
0005434480122	5B9073	0494 131926	DARYA MELNIKOVA	{"email": "d.melnikova041979@postgrespro.ru", "phone": "+70250888286"}
0005434480123	4EA201	0983 147365	ALEKSANDR PETROV	{"email": "petrov_a011974@postgrespro.ru", "phone": "+70433921569"}
0005434480124	02FB09	3228 061286	EVGENIY SAVELEV	{"email": "savelev_e-061971@postgrespro.ru", "phone": "+70066036664"}
0005434480125	02FB09	2910 347844	ALEKSANDRA LUKYANOVA	{"email": "aleksandralukyanova_051973@postgrespro.ru", "phone": "+70823616619"}
0005434480126	B29999	7163 129330	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana.05111973@postgrespro.ru", "phone": "+70441825635"}
0005434480127	3EBEE6	6873 134069	VIKTOR ZAKHAROV	{"phone": "+70245397368"}
0005434480128	461F22	4801 313324	OLGA MAKSIMOVA	{"email": "maksimovaolga111963@postgrespro.ru", "phone": "+70044729635"}
0005434480129	B8F13F	7363 493551	VLADIMIR GERASIMOV	{"email": "gerasimovvladimir-15041960@postgrespro.ru", "phone": "+70599313792"}
0005434480130	B8F13F	8405 807652	MIKHAIL MIRONOV	{"phone": "+70325028099"}
0005434480131	B8F13F	9936 398636	NINA DANILOVA	{"phone": "+70199773807"}
0005434480132	F0A060	9381 676990	YULIYA ROMANOVA	{"email": "romanovay_1983@postgrespro.ru", "phone": "+70803721371"}
0005434480133	2A73A1	0233 301724	VIKTOR SMIRNOV	{"email": "viktorsmirnov.061972@postgrespro.ru", "phone": "+70920634674"}
0005434480135	E3D9BA	6202 763276	NATALYA KUZNECOVA	{"phone": "+70064888344"}
0005434480136	E3D9BA	8033 380599	ANDREY SERGEEV	{"email": "sergeev-andrey1967@postgrespro.ru", "phone": "+70480552021"}
0005434480137	E3D9BA	0727 363420	ELENA TROFIMOVA	{"phone": "+70878601865"}
0005434480138	1E620B	9543 655247	EVGENIY DMITRIEV	{"phone": "+70095200736"}
0005434480139	1E620B	5984 365911	NATALYA GUSEVA	{"email": "guseva-natalya-111982@postgrespro.ru", "phone": "+70939266642"}
0005434480140	3DF790	8636 405917	ALEKSANDR FILIPPOV	{"phone": "+70017405715"}
0005434480141	40ED34	5030 372957	YULIYA KISELEVA	{"phone": "+70947793442"}
0005434480142	40ED34	1068 844068	VIKTOR SMIRNOV	{"phone": "+70219186657"}
0005434480143	673842	0365 046946	FEDOR MAKSIMOV	{"phone": "+70180918335"}
0005434480144	B5F1A7	6013 730896	MAKSIM ZAKHAROV	{"email": "zakharov.m_28041975@postgrespro.ru", "phone": "+70223025210"}
0005434480145	B99296	0727 235752	NATALYA MOROZOVA	{"phone": "+70381820144"}
0005434480146	5DBD66	8966 707875	ANASTASIYA DMITRIEVA	{"email": "anastasiya_dmitrieva_23051977@postgrespro.ru", "phone": "+70842741106"}
0005434480147	BA370A	0766 461444	MARIYA NESTEROVA	{"email": "nesterova-mariya_1975@postgrespro.ru", "phone": "+70412598133"}
0005434480148	BA370A	3831 570937	ALEKSANDR SMIRNOV	{"email": "a.smirnov-06041977@postgrespro.ru", "phone": "+70948678119"}
0005434480149	F98938	1605 998684	ANDREY MOROZOV	{"phone": "+70966582346"}
0005434480150	4D96B0	5103 297587	YANA ROMANOVA	{"phone": "+70636022965"}
0005434480151	922099	3129 934057	LYUDMILA NIKOLAEVA	{"phone": "+70028875826"}
0005434480152	50D848	5776 012855	ALINA POPOVA	{"email": "a_popova-1970@postgrespro.ru", "phone": "+70851009029"}
0005434480153	09C3EE	7655 148591	ANDREY ANDREEV	{"phone": "+70264015173"}
0005434480154	09C3EE	0272 373904	ANZHELA NESTEROVA	{"email": "anzhelanesterova.011972@postgrespro.ru", "phone": "+70279569182"}
0005434480155	51AEAD	2046 979951	EDUARD POPOV	{"email": "eduard-popov-101961@postgrespro.ru", "phone": "+70284271417"}
0005434480156	7B5665	9223 936720	MARIYA DENISOVA	{"email": "denisova_mariya05101982@postgrespro.ru", "phone": "+70406133548"}
0005434480157	7B5665	2292 062002	SERGEY GAVRILOV	{"email": "s_gavrilov.091975@postgrespro.ru", "phone": "+70040147984"}
0005434480158	A8CDA0	4704 364996	VIKTOR MAKAROV	{"email": "makarov_v24111980@postgrespro.ru", "phone": "+70449204902"}
0005434480159	A8CDA0	6460 525736	PETR ROMANOV	{"email": "romanov_p1965@postgrespro.ru", "phone": "+70563816425"}
0005434480160	0693CB	4339 210815	SVETLANA MATVEEVA	{"phone": "+70455603249"}
0005434480161	0693CB	2076 996641	RASHIT SCHERBAKOV	{"email": "rashitscherbakov091964@postgrespro.ru", "phone": "+70415723113"}
0005434480162	305F3B	9751 247363	EGOR VLASOV	{"email": "vlasove.1976@postgrespro.ru", "phone": "+70169045089"}
0005434480163	FEF95E	5853 323289	TATYANA KOMAROVA	{"email": "tatyana-komarova1967@postgrespro.ru", "phone": "+70113957445"}
0005434480164	FEF95E	2766 617085	IGOR DAVYDOV	{"email": "igor_davydov-011974@postgrespro.ru", "phone": "+70644893942"}
0005434480165	D3E39A	5433 214320	ANATOLIY MEDVEDEV	{"phone": "+70625183702"}
0005434480166	D3E39A	2564 594266	ANDREY FEDOROV	{"phone": "+70109553704"}
0005434480167	AD3D39	1074 332857	NATALYA ANDREEVA	{"email": "andreeva.natalya081969@postgrespro.ru", "phone": "+70163972419"}
0005434480168	AD3D39	7323 708217	VLADIMIR FEDOROV	{"email": "v-fedorov19061980@postgrespro.ru", "phone": "+70931298456"}
0005434480169	3F07F5	6497 610983	RAFAIL GAVRILOV	{"phone": "+70501850762"}
0005434480170	F9D074	0198 981791	VYACHESLAV MEDVEDEV	{"email": "medvedev_vyacheslav1974@postgrespro.ru", "phone": "+70021611911"}
0005434480171	AB109C	8033 579218	NINA AFANASEVA	{"phone": "+70843698958"}
0005434480172	AB109C	8148 087987	ALEKSEY KUZMIN	{"phone": "+70083683747"}
0005434480173	75B24A	0041 880227	ALEKSANDR ORLOV	{"phone": "+70796287183"}
0005434480174	A11AD1	4781 907073	ZHANNA PETROVA	{"email": "zhanna_petrova041977@postgrespro.ru", "phone": "+70528586967"}
0005434480175	42A057	0184 858517	NIKOLAY TIMOFEEV	{"email": "n-timofeev1962@postgrespro.ru", "phone": "+70764960711"}
0005434480176	42A057	2953 922331	KUZMA DENISOV	{"email": "denisov_k-25061969@postgrespro.ru", "phone": "+70445209685"}
0005434480177	22F780	9760 859728	KIRILL CHERNOV	{"email": "kirill.chernov.091977@postgrespro.ru", "phone": "+70848978919"}
0005434480178	B8C979	8045 272698	NIKOLAY GORBUNOV	{"phone": "+70970959205"}
0005434480179	5B3736	7458 610836	OKSANA ALEKSEEVA	{"email": "oksanaalekseeva-24031977@postgrespro.ru", "phone": "+70130464672"}
0005434480180	137177	7773 851413	ANASTASIYA FILATOVA	{"email": "filatova-a.25091975@postgrespro.ru", "phone": "+70569544906"}
0005434480181	9D1278	7412 566350	NIKOLAY VLASOV	{"phone": "+70673882008"}
0005434480182	9D1278	9819 576885	KSENIYA CHERNOVA	{"email": "k.chernova.1969@postgrespro.ru", "phone": "+70454643341"}
0005434480183	081D4E	0984 889922	VIKTOR BELOV	{"email": "belovv_081980@postgrespro.ru", "phone": "+70751439766"}
0005434480184	DC4A14	9787 635433	ALEKSANDRA KULIKOVA	{"phone": "+70602529210"}
0005434480185	DC4A14	4866 890497	LYUDMILA MASLOVA	{"phone": "+70136792670"}
0005434480186	914ED3	0462 130418	PETR ZAYCEV	{"phone": "+70175466037"}
0005434480187	CCBBAB	7103 027071	VLADIMIR DAVYDOV	{"phone": "+70509626138"}
0005434480188	CCBBAB	2313 633826	ANNA ROMANOVA	{"phone": "+70475560926"}
0005434480189	509B6B	9500 525600	ANNA KRASNOVA	{"email": "krasnova_a.1977@postgrespro.ru", "phone": "+70128021980"}
0005434480190	DD18AA	8984 975186	VYACHESLAV MAKAROV	{"phone": "+70838678667"}
0005434480191	98DE8F	2656 152835	SERGEY BARANOV	{"phone": "+70022235941"}
0005434480192	19A7E3	7083 416349	NIKOLAY PAVLOV	{"email": "nikolaypavlov_04041969@postgrespro.ru", "phone": "+70233688054"}
0005434480193	5324ED	4665 111547	VIKTOR MARTYNOV	{"phone": "+70171064100"}
0005434480194	D26BCE	5668 466244	NATALYA VLASOVA	{"email": "natalya.vlasova_101964@postgrespro.ru", "phone": "+70905126861"}
0005434480195	DE4F2D	6482 454015	OLEG NIKITIN	{"email": "nikitin_oleg_111969@postgrespro.ru", "phone": "+70669607876"}
0005434480196	474B0D	0115 726511	NIKOLAY SOROKIN	{"email": "sorokin-n_1968@postgrespro.ru", "phone": "+70155701247"}
0005434480197	67B4DC	7127 059278	ILYA KONOVALOV	{"email": "konovalov.ilya-121971@postgrespro.ru", "phone": "+70588382467"}
0005434480198	C8F787	8361 423383	SERGEY ZHUKOV	{"phone": "+70388236192"}
0005434480199	DE93DA	8860 864829	TATYANA ROMANOVA	{"email": "romanovatatyana1966@postgrespro.ru", "phone": "+70605896856"}
0005434480200	2170FB	9826 054231	DAVID ISAEV	{"email": "disaev101967@postgrespro.ru", "phone": "+70948451950"}
0005434480201	808030	0480 521683	SERGEY BELOV	{"phone": "+70634327177"}
0005434480202	808030	3294 786659	MIKHAIL MELNIKOV	{"email": "mikhailmelnikov-1957@postgrespro.ru", "phone": "+70793244531"}
0005434480203	994304	5785 440786	DANILA BARANOV	{"phone": "+70509008053"}
0005434480204	994304	1249 079484	OLGA ABRAMOVA	{"phone": "+70753159958"}
0005434480205	994304	0603 917307	GALINA FEDOROVA	{"phone": "+70624283269"}
0005434480206	828393	7206 392233	DMITRIY ZHURAVLEV	{"email": "zhuravlevd05041970@postgrespro.ru", "phone": "+70937063696"}
0005434480207	0DC3E2	2998 832866	PAVEL SMIRNOV	{"phone": "+70409078380"}
0005434480208	B5BB9E	8701 135726	ANDREY KUZNECOV	{"phone": "+70427111775"}
0005434480209	335C8B	7579 403599	ALEKSANDR POPOV	{"phone": "+70878374924"}
0005434480210	953088	5923 773635	TATYANA KONOVALOVA	{"email": "konovalova.tatyana_17121967@postgrespro.ru", "phone": "+70839115898"}
0005434480211	953088	2426 247637	ALFIYA SCHERBAKOVA	{"phone": "+70330443566"}
0005434480212	4E997F	3680 293263	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov.061973@postgrespro.ru", "phone": "+70518960827"}
0005434480213	4E997F	7226 631104	KSENIYA DAVYDOVA	{"email": "kseniya_davydova021969@postgrespro.ru", "phone": "+70382218919"}
0005434480214	A9330E	9781 480321	NIKOLAY KUZMIN	{"email": "nikolaykuzmin1963@postgrespro.ru", "phone": "+70550134733"}
0005434480215	A9330E	6306 248740	ELENA TIKHONOVA	{"phone": "+70522957772"}
0005434480216	22AD65	7585 383849	ARTEM ZHUKOV	{"phone": "+70699035430"}
0005434480217	F6A03C	0508 352981	ALEKSANDR KUZNECOV	{"phone": "+70539732008"}
0005434480218	F6A03C	1738 972134	ALEKSEY KUZNECOV	{"email": "akuznecov-021970@postgrespro.ru", "phone": "+70043216523"}
0005434480219	CEAF55	2040 084579	NIKITA VASILEV	{"phone": "+70149830158"}
0005434480220	8EE9FC	1774 293415	VLADIMIR CHERNOV	{"email": "chernov_v.051991@postgrespro.ru", "phone": "+70365119257"}
0005434480221	1A6738	5981 752226	OLGA VOROBEVA	{"email": "o.vorobeva-29091983@postgrespro.ru", "phone": "+70915224536"}
0005434480222	7F198A	7328 977943	MARINA DANILOVA	{"email": "danilovamarina.1960@postgrespro.ru", "phone": "+70807031313"}
0005434480223	CD9603	2709 913574	ANATOLIY SIDOROV	{"email": "sidorov.anatoliy_1974@postgrespro.ru", "phone": "+70249918354"}
0005434480224	CD9603	4294 063167	NATALYA ILINA	{"email": "nilina-22121974@postgrespro.ru", "phone": "+70065184450"}
0005434480225	F53CD9	4007 943763	NATALYA MIRONOVA	{"phone": "+70370818518"}
0005434480226	7E477E	4001 748433	STANISLAV FEDOROV	{"phone": "+70294558933"}
0005434480227	AE8942	0628 796289	ALEKSEY BARANOV	{"email": "abaranov_09091970@postgrespro.ru", "phone": "+70113549171"}
0005434480228	1F75CF	2332 605615	NATALYA KUZNECOVA	{"phone": "+70144061457"}
0005434480229	1F75CF	3066 622789	MIKHAIL VOROBEV	{"email": "vorobev_m-18111980@postgrespro.ru", "phone": "+70828068670"}
0005434480230	44B69C	1130 818289	VALERIY ILIN	{"phone": "+70884231643"}
0005434480231	44B69C	1926 020443	MARINA KALININA	{"email": "m-kalinina1972@postgrespro.ru", "phone": "+70300503509"}
0005434480232	AA0BAC	4595 383336	VALENTINA MAKAROVA	{"phone": "+70791349592"}
0005434480233	8EFCF8	1351 675358	ALEKSANDR BARANOV	{"email": "baranov.aleksandr-12041975@postgrespro.ru", "phone": "+70494132561"}
0005434480234	221851	6383 500083	DMITRIY ALEKSEEV	{"phone": "+70315836845"}
0005434480235	221851	9403 906080	TATYANA NIKITINA	{"phone": "+70987586882"}
0005434480236	221851	0602 593827	NATALIYA EFIMOVA	{"email": "n-efimova.121972@postgrespro.ru", "phone": "+70803274600"}
0005434480237	838067	0229 897099	IRINA FROLOVA	{"email": "frolovai_20021966@postgrespro.ru", "phone": "+70411825307"}
0005434480238	838067	1489 326809	GALINA NIKOLAEVA	{"phone": "+70264423948"}
0005434480239	799305	0135 264128	ANASTASIYA SAVELEVA	{"phone": "+70534766434"}
0005434480240	B0AF87	6232 454035	MAKSIM IVANOV	{"email": "maksimivanov111976@postgrespro.ru", "phone": "+70662751447"}
0005434480241	B0AF87	4161 926753	TATYANA AKIMOVA	{"phone": "+70628844828"}
0005434480242	0A008D	0107 450295	VLADIMIR VOLKOV	{"email": "volkovvladimir.071965@postgrespro.ru", "phone": "+70669748528"}
0005434480243	0A008D	8273 360496	LILIYA VASILEVA	{"phone": "+70263597207"}
0005434480244	0BCF03	4325 295510	VALERIY SEMENOV	{"phone": "+70320949072"}
0005434480245	21A944	7903 623408	SVETLANA CHERNOVA	{"email": "svetlana-chernova-27041973@postgrespro.ru", "phone": "+70686249161"}
0005434480246	21A944	5418 802252	ELMIRA BOGDANOVA	{"phone": "+70035827195"}
0005434480247	ADBF9A	1196 058401	VALENTINA POLYAKOVA	{"email": "valentina-polyakova1975@postgrespro.ru", "phone": "+70828438626"}
0005434480248	ADBF9A	9327 197419	ALEKSEY SMIRNOV	{"email": "smirnov-a-1962@postgrespro.ru", "phone": "+70179934988"}
0005434480249	ADBF9A	6032 432540	YULIYA DENISOVA	{"email": "denisova-y.14051964@postgrespro.ru", "phone": "+70865023551"}
0005434480250	ADBF9A	9387 204446	VALENTINA MOROZOVA	{"email": "valentina-morozova_111974@postgrespro.ru", "phone": "+70176880593"}
0005434480251	D7AAEB	3466 209354	VALENTINA ZAKHAROVA	{"email": "valentina-zakharova.111967@postgrespro.ru", "phone": "+70606113060"}
0005434480252	A84148	7506 523018	PAVEL SCHERBAKOV	{"email": "scherbakovp031985@postgrespro.ru", "phone": "+70584596083"}
0005434480253	D0E7B3	0518 538624	ELENA MAKSIMOVA	{"phone": "+70194948983"}
0005434480254	32FDA6	6153 376448	VALENTINA MATVEEVA	{"email": "matveeva-valentina-081965@postgrespro.ru", "phone": "+70538741682"}
0005434480255	CD1CE9	6470 407304	NATALYA KUZNECOVA	{"email": "natalya.kuznecova_18081971@postgrespro.ru", "phone": "+70056004109"}
0005434480256	CD1CE9	8705 143533	TATYANA IVANOVA	{"email": "ivanova_tatyana-22091974@postgrespro.ru", "phone": "+70524829596"}
0005434480257	CD8AEB	0445 681393	SERGEY POPOV	{"email": "sergey-popov091970@postgrespro.ru", "phone": "+70547914431"}
0005434480258	6AFF90	8383 644930	VLADIMIR MATVEEV	{"email": "matveev.v071973@postgrespro.ru", "phone": "+70395918531"}
0005434480259	6AFF90	4178 803382	SERGEY FROLOV	{"phone": "+70753974588"}
0005434480260	6B8A0D	3784 602779	EKATERINA IVANOVA	{"email": "eivanova_07121971@postgrespro.ru", "phone": "+70016864772"}
0005434480261	BC936E	5698 424439	VENIAMIN SMIRNOV	{"phone": "+70341118645"}
0005434480262	8E3B53	7497 500452	EKATERINA NAUMOVA	{"email": "naumova_ekaterina_24111974@postgrespro.ru", "phone": "+70978647753"}
0005434480263	1208D0	5700 171675	EKATERINA BELOVA	{"email": "e_belova_22081964@postgrespro.ru", "phone": "+70490200433"}
0005434480264	732B5F	6279 670888	SERGEY SEMENOV	{"email": "semenov.sergey1957@postgrespro.ru", "phone": "+70928342332"}
0005434480265	96F15F	4984 047634	ILMIR CHERNOV	{"email": "i_chernov.071974@postgrespro.ru", "phone": "+70475050576"}
0005434480266	6C63F5	9079 171668	SERGEY KARPOV	{"email": "sergeykarpov-101968@postgrespro.ru", "phone": "+70547518890"}
0005434480267	6C63F5	6567 954509	IGOR MEDVEDEV	{"email": "medvedev-i.121977@postgrespro.ru", "phone": "+70457992194"}
0005434480268	DBAC1D	3907 657050	SERGEY FROLOV	{"email": "frolov-sergey.1973@postgrespro.ru", "phone": "+70744045368"}
0005434480269	DA2939	6573 239997	ANTONINA PAVLOVA	{"email": "antonina-pavlova011987@postgrespro.ru", "phone": "+70586790286"}
0005434480270	43C134	4260 162862	MARIYA KONDRATEVA	{"phone": "+70773324949"}
0005434480271	AEB0FF	1895 413536	NIKOLAY NIKITIN	{"phone": "+70735264852"}
0005434480272	E682FC	4030 929400	GAGIK SOKOLOV	{"email": "gagik-sokolov-1971@postgrespro.ru", "phone": "+70763281880"}
0005434480273	CDA0C2	3725 157095	YULIYA LAZAREVA	{"phone": "+70645046686"}
0005434480274	8434DA	6010 847218	ELENA SOKOLOVA	{"phone": "+70355713902"}
0005434480275	8434DA	5558 597379	YULIYA SOLOVEVA	{"phone": "+70226243430"}
0005434480276	AA7C3E	4136 670912	ALEKSANDR DENISOV	{"email": "denisov-aleksandr.051981@postgrespro.ru", "phone": "+70770713138"}
0005434480277	8258A4	1013 662635	LYUDMILA KUZMINA	{"phone": "+70428350232"}
0005434480278	97D28D	1451 251652	VLADIMIR BARANOV	{"phone": "+70621400687"}
0005434480279	97D28D	6779 534658	TATYANA BORISOVA	{"phone": "+70885756711"}
0005434480280	97D28D	2701 216217	DARYA ALEKSEEVA	{"email": "alekseeva-d08061966@postgrespro.ru", "phone": "+70163489557"}
0005434480281	EB4827	2900 482919	ALEKSANDR MAKSIMOV	{"email": "maksimov.aleksandr-1963@postgrespro.ru", "phone": "+70781091547"}
0005434480282	6A8229	9873 829901	TATYANA VOLKOVA	{"email": "tatyana_volkova.1974@postgrespro.ru", "phone": "+70752263009"}
0005434480283	6A8229	3688 710346	VYACHESLAV PETROV	{"phone": "+70725896277"}
0005434480284	5C461A	1294 642008	SVETLANA YAKOVLEVA	{"email": "s_yakovleva1968@postgrespro.ru", "phone": "+70230454284"}
0005434480285	473471	5317 089910	EKATERINA ZHURAVLEVA	{"email": "zhuravlevae061972@postgrespro.ru", "phone": "+70201017618"}
0005434480286	209839	5314 732179	PAVEL PETROV	{"email": "pavelpetrov1970@postgrespro.ru", "phone": "+70734161322"}
0005434480287	209839	6260 896124	ALFIYA NAZAROVA	{"phone": "+70362522523"}
0005434480288	F8F4A3	2480 474454	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a09051962@postgrespro.ru", "phone": "+70787488100"}
0005434480289	480129	9704 312030	VLADIMIR KUZNECOV	{"email": "v-kuznecov.1966@postgrespro.ru", "phone": "+70789323364"}
0005434480290	CE290A	6295 152268	NATALYA TIMOFEEVA	{"email": "timofeeva-n-13011969@postgrespro.ru", "phone": "+70110527016"}
0005434480291	30ACAD	4016 238050	VIKTORIYA DMITRIEVA	{"phone": "+70269980595"}
0005434480292	EC4853	3915 002882	ELENA ERMAKOVA	{"phone": "+70631014835"}
0005434480293	DFF3D7	8758 008110	VLADISLAV ABRAMOV	{"email": "abramov_v011977@postgrespro.ru", "phone": "+70140108477"}
0005434480294	DFF3D7	5597 231574	IGOR RODIONOV	{"email": "rodionovi1977@postgrespro.ru", "phone": "+70980210195"}
0005434480295	F2EA4C	7107 136825	SERGEY MOROZOV	{"phone": "+70260276115"}
0005434480296	5F23CD	8390 849080	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr01051975@postgrespro.ru", "phone": "+70178661443"}
0005434480297	1CB9B4	4327 549680	TATYANA MIRONOVA	{"email": "mironova-tatyana-091978@postgrespro.ru", "phone": "+70574979613"}
0005434480298	0DC4FF	9552 967853	IVAN PAVLOV	{"email": "ipavlov01051972@postgrespro.ru", "phone": "+70903497834"}
0005434480299	E6CB1B	2960 075531	IGOR NIKOLAEV	{"email": "nikolaevigor.101969@postgrespro.ru", "phone": "+70407500362"}
0005434480300	FFB422	7116 872347	ROZA MOROZOVA	{"phone": "+70720092416"}
0005434480301	FFB422	8506 581061	SALAVAT GAVRILOV	{"email": "gavrilovsalavat-121975@postgrespro.ru", "phone": "+70047012043"}
0005434480302	96F003	5831 863302	SHAVKAT SEMENOV	{"email": "shavkat_semenov_1961@postgrespro.ru", "phone": "+70892676037"}
0005434480303	5D83BE	7939 789172	EVGENIY ORLOV	{"email": "evgeniyorlov02071963@postgrespro.ru", "phone": "+70935792978"}
0005434480304	7721E4	6202 026518	ALEKSEY KAZAKOV	{"phone": "+70446221987"}
0005434480305	4CCF4D	8411 415682	TAMARA ANDREEVA	{"phone": "+70728201444"}
0005434480306	4CCF4D	7368 070495	ALEKSEY SHEVCHENKO	{"email": "shevchenko_aleksey051959@postgrespro.ru", "phone": "+70092345410"}
0005434480307	06EAAC	0571 966904	GALINA MIKHAYLOVA	{"email": "mikhaylova.g.09081972@postgrespro.ru", "phone": "+70745977223"}
0005434480308	06EAAC	5592 346475	TATYANA AFANASEVA	{"email": "tatyana.afanaseva_1970@postgrespro.ru", "phone": "+70600826892"}
0005434480309	A92877	6880 360273	ALEKSANDR BARANOV	{"phone": "+70307163101"}
0005434480310	173375	4421 957858	ALEKSANDRA ZAKHAROVA	{"email": "aleksandrazakharova_091966@postgrespro.ru", "phone": "+70493183680"}
0005434480311	173375	1423 455548	DMITRIY BORISOV	{"email": "d.borisov_1966@postgrespro.ru", "phone": "+70803189070"}
0005434480312	9CAABA	0703 588473	ALEVTINA SMIRNOVA	{"phone": "+70145590185"}
0005434480313	9CAABA	8568 766383	VALENTINA NIKITINA	{"email": "nikitina.v_1977@postgrespro.ru", "phone": "+70993078561"}
0005434480314	F6FC75	3033 201564	EVGENIY PAVLOV	{"phone": "+70902184262"}
0005434480315	F6FC75	2916 446060	VADIM KUZNECOV	{"email": "kuznecov-vadim1961@postgrespro.ru", "phone": "+70365024165"}
0005434480316	78F266	7890 724311	NATALYA ALEKSANDROVA	{"phone": "+70905822405"}
0005434480317	78F266	2087 968542	VYACHESLAV BARANOV	{"phone": "+70031381290"}
0005434480318	2E7E16	0632 600974	ALEKSANDR GRIGOREV	{"phone": "+70395552008"}
0005434480319	1E22ED	7619 829842	IVAN MATVEEV	{"email": "ivan.matveev_16041962@postgrespro.ru", "phone": "+70043343894"}
0005434480320	1E22ED	6736 899758	ZOYA NOVIKOVA	{"phone": "+70487057028"}
0005434480321	5C8D7C	7190 270930	EKATERINA SERGEEVA	{"phone": "+70023266772"}
0005434480322	DE0BDC	0903 331856	TATYANA GRISHINA	{"phone": "+70563529003"}
0005434480323	DE0BDC	8567 808023	ALEKSEY MEDVEDEV	{"phone": "+70131895357"}
0005434480324	F042DB	5030 251542	GEORGIY GRIGOREV	{"email": "grigorev.g011977@postgrespro.ru", "phone": "+70087947500"}
0005434480325	F042DB	9372 638654	YULIYA ZHURAVLEVA	{"phone": "+70488807101"}
0005434480326	149AB8	7070 874687	TAISIYA FEDOROVA	{"phone": "+70648480414"}
0005434480327	BDC402	9440 842658	ZOYA EFIMOVA	{"phone": "+70736769614"}
0005434480328	143C00	4101 870687	KIRILL SEMENOV	{"phone": "+70850693191"}
0005434480329	892091	8597 564596	GLEB IVANOV	{"email": "gleb-ivanov.071966@postgrespro.ru", "phone": "+70627506005"}
0005434480330	892091	2920 383082	GALINA GRISHINA	{"email": "grishina_g.041968@postgrespro.ru", "phone": "+70616110656"}
0005434480331	F68DF1	7638 885964	NATALYA KOMAROVA	{"phone": "+70024410970"}
0005434480332	F68DF1	0381 863285	OKSANA KULIKOVA	{"phone": "+70705700933"}
0005434480333	4AB3D1	0742 056819	RUSLAN SIDOROV	{"phone": "+70354532000"}
0005434480334	0213B7	0102 743245	VARVARA FILATOVA	{"email": "v_filatova_1972@postgrespro.ru", "phone": "+70738210844"}
0005434480335	0213B7	2968 059627	IRINA LUKYANOVA	{"phone": "+70492971688"}
0005434480336	D2DEF4	5724 647018	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr_101968@postgrespro.ru", "phone": "+70359318363"}
0005434480337	A9119B	2393 823483	OLGA NESTEROVA	{"email": "nesterova.olga06101974@postgrespro.ru", "phone": "+70411322346"}
0005434480338	21DFB4	1077 199663	VLADIMIR OSIPOV	{"email": "osipov-vladimir1968@postgrespro.ru", "phone": "+70075647606"}
0005434480339	21DFB4	5708 795829	ANDREY PAVLOV	{"phone": "+70096101867"}
0005434480340	0D95E5	2528 397135	ELENA GERASIMOVA	{"email": "gerasimova-e-14041964@postgrespro.ru", "phone": "+70561024793"}
0005434480341	25CE07	5660 809954	ANATOLIY MIKHAYLOV	{"email": "a_mikhaylov051978@postgrespro.ru", "phone": "+70842863640"}
0005434480342	80E85D	2604 451466	KIRILL KOROLEV	{"phone": "+70197022331"}
0005434480343	80E85D	3125 723554	KIRILL NIKOLAEV	{"email": "kirillnikolaev-081973@postgrespro.ru", "phone": "+70174830659"}
0005434480344	BF1F96	3955 212276	ALEKSANDR KONOVALOV	{"phone": "+70058767914"}
0005434480345	5F1083	0711 520001	ANDREY PETROV	{"phone": "+70033392301"}
0005434480346	BE6E92	6166 876260	VALERIY ROMANOV	{"email": "vromanov26041966@postgrespro.ru", "phone": "+70037505876"}
0005434480347	00144F	3424 431592	ALEVTINA GERASIMOVA	{"phone": "+70099610587"}
0005434480348	00144F	9806 587946	NIKOLAY KUZNECOV	{"email": "kuznecov-n-02021975@postgrespro.ru", "phone": "+70475502478"}
0005434480349	59C2F0	6693 772367	MIKHAIL FROLOV	{"phone": "+70908842608"}
0005434480350	59C2F0	3733 834005	ALEKSEY POPOV	{"phone": "+70286362498"}
0005434480351	851F9C	8374 372065	ALEKSANDR IVANOV	{"email": "ivanov.a_23111969@postgrespro.ru", "phone": "+70506643901"}
0005434480352	4BFE93	3933 646694	DARYA SAVELEVA	{"email": "savelevad_1968@postgrespro.ru", "phone": "+70037518690"}
0005434480353	4BFE93	2192 626556	IGOR NOVIKOV	{"email": "igor-novikov.05071962@postgrespro.ru", "phone": "+70788201427"}
0005434480354	BF6635	0344 712976	ROMAN GORBUNOV	{"phone": "+70312158412"}
0005434480355	BF6635	3021 369054	ANDREY SMIRNOV	{"phone": "+70552524920"}
0005434480356	502CED	5108 500863	ANGELINA KOZLOVA	{"email": "angelina.kozlova.15061972@postgrespro.ru", "phone": "+70575681707"}
0005434480357	E181A4	3871 587198	SERGEY ZAKHAROV	{"email": "zakharov_sergey_081963@postgrespro.ru", "phone": "+70916607629"}
0005434480358	1A4E1B	6647 399703	EVGENIY KOROLEV	{"phone": "+70390410230"}
0005434480359	1A4E1B	1081 919624	MARAT NIKOLAEV	{"phone": "+70010699162"}
0005434480360	1A4E1B	1691 055818	NATALYA IVANOVA	{"email": "ivanova-n_04101967@postgrespro.ru", "phone": "+70304039264"}
0005434480361	9D9FC9	9254 859199	NIKOLAY MAKAROV	{"email": "makarovn-101971@postgrespro.ru", "phone": "+70104847436"}
0005434480362	77A3A2	7521 366737	IRINA SAVELEVA	{"phone": "+70199801453"}
0005434480363	9AF722	9557 452049	GALINA PAVLOVA	{"email": "pavlova-g-071969@postgrespro.ru", "phone": "+70964905765"}
0005434480364	9AF722	1179 267991	SERGEY POPOV	{"phone": "+70282242827"}
0005434480365	E6C052	4010 760730	DMITRIY AFANASEV	{"email": "dmitriy.afanasev.08021966@postgrespro.ru", "phone": "+70456524962"}
0005434480366	FDCAE0	4936 114000	MARIYA SEMENOVA	{"email": "m_semenova.1980@postgrespro.ru", "phone": "+70499448924"}
0005434480367	8D4A00	2774 592915	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr.23011965@postgrespro.ru", "phone": "+70193586164"}
0005434480368	8D4A00	0667 375288	NATALIYA FILATOVA	{"email": "filatova-n1973@postgrespro.ru", "phone": "+70886539705"}
0005434480369	44293B	2128 240417	NATALYA PAVLOVA	{"email": "natalya.pavlova-041978@postgrespro.ru", "phone": "+70960053557"}
0005434480370	44293B	0182 842733	ANDREY MIRONOV	{"email": "mironov_a061975@postgrespro.ru", "phone": "+70774549256"}
0005434480371	34EAA9	6144 685013	PAVEL NIKITIN	{"phone": "+70472417878"}
0005434480372	743E6E	4037 069240	IRINA LAZAREVA	{"email": "lazareva_i.1976@postgrespro.ru", "phone": "+70411531851"}
0005434480373	408EA4	3241 699769	GALINA NAZAROVA	{"email": "gnazarova-17101972@postgrespro.ru", "phone": "+70085719245"}
0005434480374	408EA4	2426 186636	LYUDMILA OSIPOVA	{"email": "l-osipova.081971@postgrespro.ru", "phone": "+70342964647"}
0005434480375	8B01EA	3873 246549	SVETLANA FILIPPOVA	{"phone": "+70075432213"}
0005434480376	8B01EA	0485 339724	SVETLANA IVANOVA	{"email": "ivanovas-31121984@postgrespro.ru", "phone": "+70061124546"}
0005434480377	998C96	5260 410224	ALEKSANDR DMITRIEV	{"phone": "+70030667626"}
0005434480378	7752A2	9981 812568	ALEKSANDR KRASNOV	{"email": "krasnov-a.041970@postgrespro.ru", "phone": "+70831487115"}
0005434480379	655DD6	1750 341295	ZOYA KARPOVA	{"email": "zoyakarpova1974@postgrespro.ru", "phone": "+70948472376"}
0005434480380	B421BC	3903 515621	ANNA SOLOVEVA	{"email": "anna-soloveva-1964@postgrespro.ru", "phone": "+70513439302"}
0005434480381	FDD2C5	3519 595124	LYUDMILA TARASOVA	{"email": "ltarasova_06111975@postgrespro.ru", "phone": "+70424973579"}
0005434480382	B1DDFA	1580 773403	NATALYA NIKOLAEVA	{"phone": "+70382858972"}
0005434480383	2B5B62	9426 038419	MARINA DENISOVA	{"phone": "+70847342388"}
0005434480384	FA8C7D	8905 328550	VLADIMIR SCHERBAKOV	{"email": "v_scherbakov_07101974@postgrespro.ru", "phone": "+70620337996"}
0005434480385	AD279B	4062 165681	SERGEY FEDOTOV	{"phone": "+70731531964"}
0005434480386	2F998B	5097 290045	ELENA RYABOVA	{"email": "elena.ryabova_1964@postgrespro.ru", "phone": "+70503389716"}
0005434480387	2F998B	3049 710096	MARIYA RYABOVA	{"phone": "+70772801081"}
0005434480388	A4CA6A	6264 977004	VALENTINA ALEKSEEVA	{"email": "alekseevavalentina.02011977@postgrespro.ru", "phone": "+70756865762"}
0005434480389	AF2FAF	3871 050097	VITALIY GERASIMOV	{"email": "v_gerasimov03041984@postgrespro.ru", "phone": "+70929606573"}
0005434480390	A72F57	4995 222070	VITALIY PAVLOV	{"email": "pavlov.vitaliy1977@postgrespro.ru", "phone": "+70599883226"}
0005434480391	7B160B	8845 798809	VENERA EGOROVA	{"email": "venera_egorova_071976@postgrespro.ru", "phone": "+70234296972"}
0005434480392	32C7EC	0417 782872	VIKTOR PAVLOV	{"phone": "+70810013889"}
0005434480393	15B0CE	6412 338746	MAKSIM OSIPOV	{"phone": "+70901950791"}
0005434480394	6A6282	5098 254265	FEDOR ZAKHAROV	{"phone": "+70036774420"}
0005434480395	6A6282	0572 338464	MATRENA POLYAKOVA	{"email": "mpolyakova-1978@postgrespro.ru", "phone": "+70100922555"}
0005434480396	7CB0EE	8544 228940	NADEZHDA VOLKOVA	{"email": "nadezhdavolkova_121960@postgrespro.ru", "phone": "+70402148524"}
0005434480397	C7579D	8083 022245	ALEKSEY MELNIKOV	{"phone": "+70857463243"}
0005434480398	F80537	3427 846148	VLADIMIR NAUMOV	{"phone": "+70640994017"}
0005434480399	40DAEC	2217 485438	ALEKSANDR CHERNOV	{"phone": "+70985042745"}
0005434480400	49F3A1	4940 183724	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey14081978@postgrespro.ru", "phone": "+70375913470"}
0005434480401	145563	8570 902596	PAVEL NIKITIN	{"email": "nikitin-p-27101963@postgrespro.ru", "phone": "+70163953406"}
0005434480402	145563	8609 674679	LIDIYA ZHUKOVA	{"phone": "+70186958257"}
0005434480403	DA3E0C	8686 833986	ANATOLIY ZHUKOV	{"email": "zhukovanatoliy-1987@postgrespro.ru", "phone": "+70193363784"}
0005434480404	092CFB	7645 593880	DENIS GRIGOREV	{"email": "d-grigorev-011979@postgrespro.ru", "phone": "+70166636777"}
0005434480405	6C9E56	2554 721539	ANDREY YAKOVLEV	{"email": "yakovlev.andrey1974@postgrespro.ru", "phone": "+70104305847"}
0005434480406	6C9E56	6905 004092	KLAVDIYA AKIMOVA	{"email": "k.akimova.07121976@postgrespro.ru", "phone": "+70028946146"}
0005434480407	389F70	3569 143058	TATYANA POPOVA	{"phone": "+70880727160"}
0005434480408	4F2E33	4785 988710	YURIY ALEKSEEV	{"phone": "+70633896259"}
0005434480409	872C92	6968 166961	ALEKSANDRA KOMAROVA	{"phone": "+70347308263"}
0005434480410	872C92	3981 292689	ANASTASIYA AFANASEVA	{"email": "a.afanaseva-16121969@postgrespro.ru", "phone": "+70932939401"}
0005434480411	023B46	3471 365559	OLGA FOMINA	{"email": "fominaolga.011981@postgrespro.ru", "phone": "+70954275823"}
0005434480412	DBC7B4	6973 959730	VERONIKA KULIKOVA	{"phone": "+70560144850"}
0005434480413	C2FAAF	2191 332300	ALEKSANDR MAKAROV	{"phone": "+70903390917"}
0005434480414	8FB6A6	3577 736566	ALEKSANDR STEPANOV	{"email": "aleksandrstepanov_1966@postgrespro.ru", "phone": "+70312646127"}
0005434480415	8FB6A6	1429 065172	IVAN IVANOV	{"email": "ivanov-ivan.11111971@postgrespro.ru", "phone": "+70205534201"}
0005434480416	D7FB3D	9583 588605	NIKOLAY KUZMIN	{"email": "n-kuzmin-041978@postgrespro.ru", "phone": "+70239806715"}
0005434480417	CA9760	2924 456178	LIDIYA MOROZOVA	{"email": "morozova_l121973@postgrespro.ru", "phone": "+70315127577"}
0005434480418	70144F	3670 141350	NADEZHDA VOROBEVA	{"phone": "+70186549320"}
0005434480419	EE94B6	3391 679403	MARIYA TITOVA	{"email": "mariya-titova-31031970@postgrespro.ru", "phone": "+70350149622"}
0005434480420	F008A9	5686 106686	ALEKSANDR VASILEV	{"phone": "+70617984050"}
0005434480421	ADC4B9	0139 871322	LILIYA TIKHONOVA	{"phone": "+70851864219"}
0005434480422	15B8A2	6590 664248	LYUBOV VLASOVA	{"email": "l.vlasova-121973@postgrespro.ru", "phone": "+70211847368"}
0005434480423	15B8A2	5372 026480	LYUDMILA LEBEDEVA	{"email": "lebedeva_l-24061972@postgrespro.ru", "phone": "+70594513829"}
0005434480424	15B8A2	5218 907998	EVGENIY FILIPPOV	{"email": "e-filippov.12031970@postgrespro.ru", "phone": "+70247402421"}
0005434480425	8141B5	0488 452328	YURIY MIKHAYLOV	{"phone": "+70910865876"}
0005434480426	8141B5	3405 701889	VALERIY KAZAKOV	{"email": "valeriykazakov-13101964@postgrespro.ru", "phone": "+70746819686"}
0005434480427	652A6B	0137 747507	OLEG IVANOV	{"email": "o.ivanov.1971@postgrespro.ru", "phone": "+70045229497"}
0005434480428	462349	3430 205562	NIKITA BORISOV	{"email": "borisov.nikita-051985@postgrespro.ru", "phone": "+70869469035"}
0005434480429	964C16	7090 405169	EVDOKIYA NESTEROVA	{"phone": "+70391134470"}
0005434480430	B934E2	9576 149428	SERGEY SMIRNOV	{"phone": "+70630374751"}
0005434480431	B934E2	1032 438118	TATYANA DANILOVA	{"phone": "+70835116494"}
0005434480432	7C3070	4752 400129	GEORGIY NIKOLAEV	{"phone": "+70389368121"}
0005434480433	C9F66A	6529 262533	MARINA KALININA	{"email": "marina_kalinina.101980@postgrespro.ru", "phone": "+70245793411"}
0005434480434	1DE512	0349 337473	ALEKSANDR IVANOV	{"phone": "+70359046382"}
0005434480435	1DE512	8979 232103	YULIYA MELNIKOVA	{"email": "melnikova-yuliya-11081983@postgrespro.ru", "phone": "+70194763333"}
0005434480436	BE0567	8419 752882	STEPAN POPOV	{"email": "popov_s.101966@postgrespro.ru", "phone": "+70768269361"}
0005434480437	BE0567	4983 296869	VALERIY FEDOTOV	{"email": "fedotov.valeriy.26031976@postgrespro.ru", "phone": "+70395637951"}
0005434480438	47748F	5614 616208	SERGEY ANDREEV	{"phone": "+70775677033"}
0005434480439	11B345	7342 520947	ALEKSANDRA BELYAEVA	{"email": "aleksandra.belyaeva.011975@postgrespro.ru", "phone": "+70685151072"}
0005434480440	531982	3665 885998	ALEKSANDR KUZMIN	{"email": "kuzmin-a_1985@postgrespro.ru", "phone": "+70011022448"}
0005434480441	680FC2	1101 076504	ALEKSEY MIKHAYLOV	{"phone": "+70194633951"}
0005434480442	680FC2	2490 785818	ALEKSANDR VOROBEV	{"email": "a.vorobev1973@postgrespro.ru", "phone": "+70686389877"}
0005434480443	4E1796	0549 903615	SERGEY MAKAROV	{"phone": "+70444636316"}
0005434480444	4E1796	5493 088187	NIKOLAY MIKHAYLOV	{"phone": "+70854147043"}
0005434480445	4E1796	0696 339546	MARIYA GERASIMOVA	{"phone": "+70267503286"}
0005434480446	BDB008	3944 630874	VALENTIN SOKOLOV	{"phone": "+70051630762"}
0005434480447	14D4A6	1734 460236	RUSLAN BARANOV	{"phone": "+70366646397"}
0005434480448	5653E4	6735 416980	TATYANA POPOVA	{"email": "tpopova.061981@postgrespro.ru", "phone": "+70342507937"}
0005434480449	119D0A	9086 178677	EVGENIY SMIRNOV	{"phone": "+70230440496"}
0005434480450	119D0A	6610 268415	IRINA NIKITINA	{"email": "nikitina.irina-061976@postgrespro.ru", "phone": "+70347237453"}
0005434480451	DE58D0	0958 845354	LYUBOV VASILEVA	{"phone": "+70800376355"}
0005434480452	0FBA2D	4465 429661	VIKTOR KOZLOV	{"phone": "+70162294591"}
0005434480453	0FBA2D	0266 869745	SERGEY MOROZOV	{"email": "sergeymorozov1961@postgrespro.ru", "phone": "+70940038466"}
0005434480454	52E492	4219 735781	ELENA GAVRILOVA	{"email": "e-gavrilova041967@postgrespro.ru", "phone": "+70917590100"}
0005434480455	B62AF6	8770 431138	ANDREY MAKAROV	{"email": "andrey.makarov1969@postgrespro.ru", "phone": "+70405253992"}
0005434480456	78D4F7	8508 360176	MARAT ORLOV	{"email": "m.orlov021974@postgrespro.ru", "phone": "+70939836659"}
0005434480457	8ADB3C	5129 984390	GALINA IVANOVA	{"phone": "+70100459203"}
0005434480458	8ADB3C	5378 171749	ANZHELA KONOVALOVA	{"phone": "+70549968060"}
0005434480459	3ED054	0377 380321	EKATERINA OSIPOVA	{"phone": "+70765959950"}
0005434480460	CDC098	0108 110671	VIKTOR IVANOV	{"phone": "+70596010677"}
0005434480461	3C24E3	0530 639858	VLADIMIR SCHERBAKOV	{"phone": "+70103344883"}
0005434480462	A95347	3459 124117	ANTON NIKOLAEV	{"phone": "+70089220290"}
0005434480463	AA1FCC	4783 601675	ANTON PETROV	{"email": "petrovanton_21081973@postgrespro.ru", "phone": "+70597594745"}
0005434480464	0D9A62	4193 192232	NATALYA ABRAMOVA	{"email": "abramova.n_011978@postgrespro.ru", "phone": "+70275508828"}
0005434480465	0D9A62	3465 402507	VALERIY GORBUNOV	{"phone": "+70312399193"}
0005434480466	7D3BF3	3599 539028	ARINA MELNIKOVA	{"email": "a_melnikova.021971@postgrespro.ru", "phone": "+70201843065"}
0005434480467	9D524D	2362 516024	ALEKSANDRA VASILEVA	{"email": "vasilevaa19081959@postgrespro.ru", "phone": "+70239729642"}
0005434480468	2134EC	9357 945366	NINA SMIRNOVA	{"email": "nina_smirnova_1963@postgrespro.ru", "phone": "+70586621663"}
0005434480469	FC7099	4130 022973	LEONID DENISOV	{"email": "leonid.denisov_29051977@postgrespro.ru", "phone": "+70783236426"}
0005434480470	3361CE	4725 470509	ALEKSEY PAVLOV	{"email": "a_pavlov_1963@postgrespro.ru", "phone": "+70533126239"}
0005434480471	3361CE	0071 450623	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.01011965@postgrespro.ru", "phone": "+70746279046"}
0005434480472	62FB69	1592 658544	MIKHAIL ILIN	{"email": "mikhail-ilin_1963@postgrespro.ru", "phone": "+70765636156"}
0005434480473	62FB69	3467 822658	MILANA PETROVA	{"phone": "+70800402216"}
0005434480474	99E2BD	0238 376150	YULIYA KISELEVA	{"phone": "+70475684339"}
0005434480475	EB3A86	4019 780656	ALEKSANDR KOROLEV	{"email": "korolevaleksandr_031967@postgrespro.ru", "phone": "+70539633118"}
0005434480476	9139CF	6677 154123	ALEKSEY GORBUNOV	{"phone": "+70787597753"}
0005434480477	9139CF	0368 544498	DENIS ZAYCEV	{"phone": "+70748354337"}
0005434480478	3E556C	8155 731834	DMITRIY VASILEV	{"phone": "+70211513540"}
0005434480479	3E556C	7666 347963	ELIZAVETA EFREMOVA	{"email": "efremova-e_23021976@postgrespro.ru", "phone": "+70689562244"}
0005434480480	CED8CB	6544 837685	IVAN SCHERBAKOV	{"email": "ivan-scherbakov-051968@postgrespro.ru", "phone": "+70981541655"}
0005434480481	CED8CB	7802 242861	YURIY ISAEV	{"email": "yuriy-isaev-061973@postgrespro.ru", "phone": "+70407652085"}
0005434480482	5D774F	5248 963677	KONSTANTIN MAKAROV	{"phone": "+70869472962"}
0005434480483	5D774F	9136 435876	ELIZAVETA SMIRNOVA	{"email": "smirnova.elizaveta1975@postgrespro.ru", "phone": "+70615381240"}
0005434480484	7EFE7E	4244 960373	LYUBOV MEDVEDEVA	{"email": "medvedeva.l.03041981@postgrespro.ru", "phone": "+70088512849"}
0005434480485	EFD728	9156 971240	NATALYA DAVYDOVA	{"email": "davydova.n_121976@postgrespro.ru", "phone": "+70956998281"}
0005434480486	2FE9A2	0394 616296	ALEKSEY FOMIN	{"email": "aleksey_fomin-1977@postgrespro.ru", "phone": "+70197859471"}
0005434480487	569E47	9621 969996	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov_091976@postgrespro.ru", "phone": "+70058524280"}
0005434480488	0463BC	5060 633384	MARIYA KUZMINA	{"phone": "+70597887918"}
0005434480489	F8501E	3079 677674	EKATERINA EGOROVA	{"email": "e_egorova_13021979@postgrespro.ru", "phone": "+70109619092"}
0005434480490	BD0959	6773 400095	MARGARITA SERGEEVA	{"email": "m_sergeeva_1961@postgrespro.ru", "phone": "+70997973602"}
0005434480491	BD0959	6016 158577	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana.041982@postgrespro.ru", "phone": "+70850844867"}
0005434480492	8BB027	6110 866942	DMITRIY PAVLOV	{"email": "pavlov_dmitriy30121968@postgrespro.ru", "phone": "+70186188043"}
0005434480493	FC50F9	0246 397217	SERGEY SERGEEV	{"email": "sergeev_s-1978@postgrespro.ru", "phone": "+70666046305"}
0005434480494	27A9D9	5700 517636	DARYA SIDOROVA	{"phone": "+70325146187"}
0005434480495	27A9D9	8947 534420	OLGA RYABOVA	{"email": "ryabovao.071967@postgrespro.ru", "phone": "+70963792809"}
0005434480496	4F2206	3507 689888	VYACHESLAV PAVLOV	{"phone": "+70366803714"}
0005434480497	441DCE	5576 883253	VADIM KUZMIN	{"email": "kuzmin-vadim1980@postgrespro.ru", "phone": "+70831337897"}
0005434480498	441DCE	9698 510253	VLADIMIR NIKITIN	{"email": "vnikitin-16051975@postgrespro.ru", "phone": "+70825810900"}
0005434480499	87D3C8	9297 250849	YAROSLAVA YUDINA	{"email": "yudina.y101971@postgrespro.ru", "phone": "+70145633148"}
0005434480500	46BCCE	2102 609560	NADEZHDA FEDOROVA	{"phone": "+70632770321"}
0005434480501	C0E048	1636 128106	TATYANA KUZNECOVA	{"phone": "+70112991357"}
0005434480502	096D17	4150 853229	KONSTANTIN ZAYCEV	{"email": "k.zaycev-14041980@postgrespro.ru", "phone": "+70368476790"}
0005434480503	9FC537	0548 507190	ANNA KOZLOVA	{"phone": "+70276748047"}
0005434480504	9FC537	5165 551862	DENIS DAVYDOV	{"email": "davydov-denis.061971@postgrespro.ru", "phone": "+70021284805"}
0005434480505	09A842	7456 965023	MARINA LEBEDEVA	{"phone": "+70178240748"}
0005434480506	1E00E4	1892 981359	FEDOR FEDOTOV	{"phone": "+70230325231"}
0005434480562	6634E9	0662 107540	MARINA VOLKOVA	{"phone": "+70030110333"}
0005434480507	0C888C	5254 268306	DIANA MELNIKOVA	{"email": "d.melnikova_28061956@postgrespro.ru", "phone": "+70914467314"}
0005434480508	0C888C	9899 183316	IRINA PETROVA	{"phone": "+70162557354"}
0005434480509	EBB827	0209 034047	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya-08101985@postgrespro.ru", "phone": "+70477367957"}
0005434480510	EBB827	8851 864915	RENAT DMITRIEV	{"phone": "+70725698891"}
0005434480511	EBB827	5813 427442	NATALYA MOISEEVA	{"email": "nmoiseeva_17081964@postgrespro.ru", "phone": "+70958106979"}
0005434480512	63DA74	7654 597206	NADEZHDA POLYAKOVA	{"phone": "+70047505371"}
0005434480513	63DA74	2117 034373	ALIYA MARTYNOVA	{"email": "martynova-aliya_031984@postgrespro.ru", "phone": "+70568414581"}
0005434480514	63DA74	0710 756896	NADEZHDA ARKHIPOVA	{"email": "n-arkhipova1968@postgrespro.ru", "phone": "+70269472880"}
0005434480515	F3630B	9991 122326	VASILIY KOROLEV	{"email": "korolev_vasiliy-15031978@postgrespro.ru", "phone": "+70918284443"}
0005434480516	1FD20A	0123 200461	MARIYA ARKHIPOVA	{"email": "m-arkhipova101982@postgrespro.ru", "phone": "+70128598992"}
0005434480517	1FD20A	5507 619393	LYUDMILA FROLOVA	{"phone": "+70624600616"}
0005434480518	C89950	9531 736966	ALEKSANDRA GAVRILOVA	{"email": "agavrilova1984@postgrespro.ru", "phone": "+70675454808"}
0005434480519	3A8548	7015 508288	ANASTASIYA TIMOFEEVA	{"email": "timofeeva.anastasiya-021971@postgrespro.ru", "phone": "+70888790231"}
0005434480520	331E2D	0798 075904	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-t.081974@postgrespro.ru", "phone": "+70048602528"}
0005434480521	331E2D	9130 759688	MIKHAIL TIMOFEEV	{"email": "m-timofeev_051978@postgrespro.ru", "phone": "+70053491153"}
0005434480522	331E2D	0723 343917	SVETLANA LEBEDEVA	{"phone": "+70267604812"}
0005434480523	C9AADD	0364 440270	SERGEY ROMANOV	{"phone": "+70407297268"}
0005434480524	75342A	6890 681589	ARTEM ANDREEV	{"email": "artem.andreev.1972@postgrespro.ru", "phone": "+70428569188"}
0005434480525	EB9D04	5758 315319	OLGA MARTYNOVA	{"phone": "+70522005649"}
0005434480526	809626	8170 243002	ANNA CHERNOVA	{"email": "annachernova.1972@postgrespro.ru", "phone": "+70510881170"}
0005434480527	D68F83	3561 341545	ILYA SOROKIN	{"email": "i.sorokin.071962@postgrespro.ru", "phone": "+70156764207"}
0005434480528	D68F83	9611 649165	ANASTASIYA VASILEVA	{"phone": "+70839144311"}
0005434480529	0E32D0	0208 887542	IRINA DENISOVA	{"phone": "+70927264944"}
0005434480530	0E32D0	2968 317150	SERGEY DAVYDOV	{"email": "sergey-davydov19061976@postgrespro.ru", "phone": "+70804330967"}
0005434480531	0E32D0	3148 970774	VASILISA SERGEEVA	{"email": "sergeeva-vasilisa-051975@postgrespro.ru", "phone": "+70421152840"}
0005434480532	081383	1794 636702	ALEKSEY ZAKHAROV	{"phone": "+70012390836"}
0005434480533	4A16B3	6274 202386	MARIYA BARANOVA	{"phone": "+70082286221"}
0005434480534	B5ED60	1478 116533	ANDREY MATVEEV	{"phone": "+70551017262"}
0005434480535	B5ED60	4073 324896	POLINA BOGDANOVA	{"email": "bogdanova-p.12071980@postgrespro.ru", "phone": "+70141553710"}
0005434480536	0B5BF0	1977 657206	ALEKSEY KUZNECOV	{"phone": "+70073095383"}
0005434480537	C676EA	8080 802346	ANNA AFANASEVA	{"phone": "+70490206751"}
0005434480538	4709E8	6457 295594	OLESYA IVANOVA	{"email": "ivanovaolesya.16111966@postgrespro.ru", "phone": "+70999963050"}
0005434480539	688743	4430 085712	KUZMA POPOV	{"email": "popovk.1967@postgrespro.ru", "phone": "+70760015978"}
0005434480540	28A610	0538 883454	ANNA MASLOVA	{"phone": "+70235108786"}
0005434480541	0008DF	1671 081472	ALEKSANDR FEDOROV	{"email": "fedorova_20021972@postgrespro.ru", "phone": "+70520265814"}
0005434480542	0008DF	1838 085482	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila_01021973@postgrespro.ru", "phone": "+70576244013"}
0005434480543	8FE8E1	2225 974873	VALENTINA KUDRYASHOVA	{"email": "v_kudryashova.071976@postgrespro.ru", "phone": "+70137913920"}
0005434480544	367553	5568 548533	ANTONINA POPOVA	{"email": "popovaantonina-25111974@postgrespro.ru", "phone": "+70367914520"}
0005434480545	367553	3408 288833	OLEG NOVIKOV	{"phone": "+70064739514"}
0005434480546	B64FC6	1514 496988	EKATERINA KOZLOVA	{"email": "ekozlova.071977@postgrespro.ru", "phone": "+70076599155"}
0005434480547	964268	9478 257662	ALEKSANDR NIKITIN	{"email": "anikitin-1973@postgrespro.ru", "phone": "+70709173868"}
0005434480548	1AB413	7985 798230	YANA GERASIMOVA	{"phone": "+70922506649"}
0005434480549	95AF9F	3256 774316	ARTUR NAUMOV	{"email": "a-naumov-07101971@postgrespro.ru", "phone": "+70850963853"}
0005434480550	6947AC	6697 696209	YANA CHERNOVA	{"email": "yana.chernova_1970@postgrespro.ru", "phone": "+70393595863"}
0005434480551	6947AC	8557 405203	LYUDMILA EFIMOVA	{"email": "lyudmila-efimova05101978@postgrespro.ru", "phone": "+70328829651"}
0005434480552	4204C3	8748 888252	ANTON SIDOROV	{"email": "sidorov.anton07081968@postgrespro.ru", "phone": "+70215609341"}
0005434480553	AB26F7	2212 231064	ALINA FOMINA	{"email": "a_fomina.121974@postgrespro.ru", "phone": "+70374535724"}
0005434480554	AB26F7	4106 708059	ANDREY ZAYCEV	{"email": "zaycev-andrey_07041975@postgrespro.ru", "phone": "+70454552098"}
0005434480555	99D652	1830 810978	TATYANA KUZNECOVA	{"phone": "+70951866212"}
0005434480556	99D652	0356 565020	ANATOLIY ANDREEV	{"phone": "+70674654698"}
0005434480557	99D652	1839 958431	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov1962@postgrespro.ru", "phone": "+70111879300"}
0005434480558	11E1C6	8883 911136	ROMAN PAVLOV	{"email": "r.pavlov01081961@postgrespro.ru", "phone": "+70959350386"}
0005434480559	530808	3702 075047	LYUBOV NESTEROVA	{"email": "nesterova_l_1969@postgrespro.ru", "phone": "+70894599038"}
0005434480560	530808	0057 376983	PAVEL KARPOV	{"email": "karpov_pavel26031965@postgrespro.ru", "phone": "+70482524841"}
0005434480561	10154F	7963 419148	YAROSLAV FILIPPOV	{"phone": "+70049592565"}
0005434480563	543AD8	5962 526520	YURIY BELOV	{"phone": "+70872321453"}
0005434480564	543AD8	8610 194826	ELENA MAKSIMOVA	{"phone": "+70167176659"}
0005434480565	89CC0F	4144 700253	ELENA MATVEEVA	{"phone": "+70209907486"}
0005434480566	FB6CFE	9771 157109	ALEKSANDR NAZAROV	{"phone": "+70025783231"}
0005434480567	DE495A	7137 734602	NATALYA YAKOVLEVA	{"email": "yakovlevan-1980@postgrespro.ru", "phone": "+70806730696"}
0005434480568	DE495A	2357 902071	VLADIMIR BORISOV	{"email": "v.borisov.17031964@postgrespro.ru", "phone": "+70113134185"}
0005434480569	D9F9C9	5189 674152	LILIYA ZAKHAROVA	{"phone": "+70969239576"}
0005434480570	3B9A63	9592 154866	VALERIY KUDRYASHOV	{"phone": "+70357488524"}
0005434480571	C67068	0932 017217	SERGEY ISAEV	{"phone": "+70145403076"}
0005434480572	C67068	0998 602514	GALINA NESTEROVA	{"email": "nesterova-galina-061966@postgrespro.ru", "phone": "+70085783292"}
0005434480573	C67068	0766 424758	NINA NIKOLAEVA	{"email": "nikolaeva_nina_071972@postgrespro.ru", "phone": "+70570731535"}
0005434480574	92F950	7096 915500	ALEKSANDR VLASOV	{"email": "vlasovaleksandr061972@postgrespro.ru", "phone": "+70819925661"}
0005434480575	92F950	4812 521184	SERGEY OSIPOV	{"email": "osipov.s.031979@postgrespro.ru", "phone": "+70444231386"}
0005434480576	C1940D	4483 456270	NIKOLAY BELOV	{"phone": "+70744568149"}
0005434480577	973362	8285 655834	LYUDMILA VASILEVA	{"phone": "+70023584726"}
0005434480578	C8CD39	3865 891979	ALEKSEY FEDOROV	{"email": "fedorov_aleksey.011971@postgrespro.ru", "phone": "+70471260876"}
0005434480579	C8CD39	7252 410097	MIKHAIL KRASNOV	{"phone": "+70364961520"}
0005434480580	4C6C0D	1890 241747	NADEZHDA BELYAEVA	{"email": "belyaeva_nadezhda_101968@postgrespro.ru", "phone": "+70616660444"}
0005434480581	E380DA	6403 029324	SEMEN EGOROV	{"phone": "+70030644504"}
0005434480582	E380DA	2360 472661	IRINA SEMENOVA	{"phone": "+70062731503"}
0005434480583	E380DA	0458 262472	ANNA AFANASEVA	{"email": "annaafanaseva1973@postgrespro.ru", "phone": "+70753245470"}
0005434480584	AF871D	6188 429144	DMITRIY AFANASEV	{"phone": "+70415848066"}
0005434480585	F319A6	0519 601446	NIKOLAY IVANOV	{"phone": "+70239829141"}
0005434480586	F319A6	3905 550758	IVAN FEDOROV	{"email": "fedorov.ivan_121966@postgrespro.ru", "phone": "+70340813545"}
0005434480587	5BBA54	4613 558059	PAVEL IVANOV	{"email": "ivanov-pavel021959@postgrespro.ru", "phone": "+70027027019"}
0005434480588	5BBA54	3663 753226	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay-1979@postgrespro.ru", "phone": "+70360049768"}
0005434480589	4C2EA4	6875 070717	SEMEN IVANOV	{"email": "semenivanov091972@postgrespro.ru", "phone": "+70600879937"}
0005434480590	4C2EA4	8995 486905	ANDREY PETROV	{"phone": "+70129383219"}
0005434480591	F3F8C8	8397 411919	ANDREY VLASOV	{"email": "vlasov.a121971@postgrespro.ru", "phone": "+70778488055"}
0005434480592	F3F8C8	5222 423329	ROMAN OSIPOV	{"phone": "+70480801999"}
0005434480593	9A39AF	0775 967425	ALEKSANDR VOROBEV	{"email": "vorobev.aleksandr-24051973@postgrespro.ru", "phone": "+70558430308"}
0005434480594	9A39AF	1136 638169	YURIY KUZNECOV	{"phone": "+70233816606"}
0005434480595	AF285D	2719 189315	ELIZAVETA BOGDANOVA	{"email": "e_bogdanova.061988@postgrespro.ru", "phone": "+70406086468"}
0005434480596	0B1DBA	8792 451888	ALEKSANDR POPOV	{"email": "a-popov.1975@postgrespro.ru", "phone": "+70783393132"}
0005434480597	05E3CA	8968 928591	LYUBOV VLASOVA	{"email": "l.vlasova-15051976@postgrespro.ru", "phone": "+70657547915"}
0005434480598	C16538	4300 298770	DANIIL ORLOV	{"phone": "+70418837100"}
0005434480599	C0D307	1415 837383	NADEZHDA ERMAKOVA	{"email": "ermakova-nadezhda_071979@postgrespro.ru", "phone": "+70354948160"}
0005434480600	8D2E71	9157 402222	VITALIY SEMENOV	{"email": "semenov_v.1979@postgrespro.ru", "phone": "+70886337325"}
0005434480601	49B950	1668 452681	DARYA ABRAMOVA	{"phone": "+70603949268"}
0005434480602	B35A8E	8283 749930	INNA SOROKINA	{"email": "sorokina_inna.1980@postgrespro.ru", "phone": "+70979444697"}
0005434480603	C28D8E	7517 900161	ELIZAVETA VOLKOVA	{"email": "volkovaelizaveta1973@postgrespro.ru", "phone": "+70784023055"}
0005434480604	C28D8E	9369 437218	DINARA IVANOVA	{"email": "dinara.ivanova.101976@postgrespro.ru", "phone": "+70600045306"}
0005434480605	78F1D8	6350 439227	NIKITA GRIGOREV	{"email": "nikitagrigorev-121975@postgrespro.ru", "phone": "+70689881844"}
0005434480606	78F1D8	2479 607067	VALERIY VOROBEV	{"phone": "+70679790752"}
0005434480607	818322	7160 666641	ANASTASIYA YAKOVLEVA	{"email": "yakovlevaa061959@postgrespro.ru", "phone": "+70433277605"}
0005434480608	818322	0912 695625	ALENA GORBUNOVA	{"phone": "+70713938031"}
0005434480609	501AC7	8404 581565	EDUARD YAKOVLEV	{"phone": "+70064506040"}
0005434480610	469DD2	6129 583527	OLGA FEDOROVA	{"email": "fedorova_o041963@postgrespro.ru", "phone": "+70594452082"}
0005434480611	469DD2	6408 881481	LYUDMILA MELNIKOVA	{"email": "melnikoval.31011970@postgrespro.ru", "phone": "+70452089887"}
0005434480612	967BA6	8251 324622	NATALIYA KONOVALOVA	{"email": "konovalova-n1967@postgrespro.ru", "phone": "+70717511979"}
0005434480613	AB3BD3	4304 535553	DARYA DANILOVA	{"email": "danilova_d.1976@postgrespro.ru", "phone": "+70897068727"}
0005434480614	C11A65	6260 335145	TAMARA VASILEVA	{"email": "tamara-vasileva-24061971@postgrespro.ru", "phone": "+70509859951"}
0005434480615	B20E41	0961 581137	VLADIMIR TARASOV	{"phone": "+70156726956"}
0005434480616	55F4DB	5686 568143	ALEKSANDR VASILEV	{"phone": "+70431953445"}
0005434480617	55F4DB	9525 757946	ALBINA KAZAKOVA	{"phone": "+70760303789"}
0005434480618	481594	6589 877340	ALENA IVANOVA	{"email": "ivanova.alena051973@postgrespro.ru", "phone": "+70783051374"}
0005434480619	481594	1057 200095	GENNADIY SOLOVEV	{"phone": "+70786771906"}
0005434480620	8A77A4	5322 396003	YULIYA KONOVALOVA	{"phone": "+70407839110"}
0005434480621	6C8188	6246 560867	VALENTINA POPOVA	{"phone": "+70008971409"}
0005434480622	6C8188	2115 655851	YURIY ALEKSEEV	{"email": "y.alekseev041968@postgrespro.ru", "phone": "+70552607258"}
0005434480623	960A4C	7170 975482	VIKTOR BORISOV	{"email": "viktor_borisov13031967@postgrespro.ru", "phone": "+70533608192"}
0005434480624	FFA6B1	7637 599330	IVAN SOROKIN	{"phone": "+70389666564"}
0005434480625	3A2B4B	3526 038864	OLGA POTAPOVA	{"email": "potapova-o.1968@postgrespro.ru", "phone": "+70375663151"}
0005434480626	3A2B4B	0989 191328	ANDREY SMIRNOV	{"email": "a.smirnov-12081975@postgrespro.ru", "phone": "+70684486228"}
0005434480627	16A567	7110 367537	LYUBOV PETROVA	{"phone": "+70974415252"}
0005434480628	556659	9063 376307	ELIZAVETA KUZMINA	{"email": "elizaveta_kuzmina.1969@postgrespro.ru", "phone": "+70532719252"}
0005434480629	20260E	1053 696715	OLGA PETROVA	{"email": "o.petrova-06081971@postgrespro.ru", "phone": "+70480968032"}
0005434480630	20260E	6650 684564	EKATERINA GUSEVA	{"phone": "+70770323228"}
0005434480631	7D7609	9858 551517	ALEKSEY KOROLEV	{"email": "a_korolev1971@postgrespro.ru", "phone": "+70640256071"}
0005434480632	7D7609	3448 018014	ELENA PAVLOVA	{"email": "e_pavlova121980@postgrespro.ru", "phone": "+70629715210"}
0005434480633	E6B736	7548 856178	ANDREY ANDREEV	{"email": "andrey-andreev.071977@postgrespro.ru", "phone": "+70872131842"}
0005434480634	6AAF12	2149 133486	VIKTOR VOROBEV	{"phone": "+70781263627"}
0005434480635	A60D8F	9466 032076	ANNA KONOVALOVA	{"email": "konovalovaanna-111976@postgrespro.ru", "phone": "+70302269711"}
0005434480636	56FD58	2150 269273	ZOYA MALYSHEVA	{"email": "zoyamalysheva1972@postgrespro.ru", "phone": "+70302357420"}
0005434480637	56FD58	2122 725694	PETR ISAEV	{"phone": "+70830787550"}
0005434480638	12BE4C	5188 882714	ANDREY ANTONOV	{"email": "antonov_a_1969@postgrespro.ru", "phone": "+70816593619"}
0005434480639	A203BD	0976 431712	YURIY KUZNECOV	{"email": "y-kuznecov.13091968@postgrespro.ru", "phone": "+70263584444"}
0005434480640	A203BD	1636 560446	MIKHAIL GUSEV	{"email": "mikhail_gusev1977@postgrespro.ru", "phone": "+70599560177"}
0005434480641	0C1E7C	9346 685403	NIKOLAY ROMANOV	{"email": "nikolay-romanov-02061969@postgrespro.ru", "phone": "+70589118497"}
0005434480642	39E431	4577 376569	PAVEL SOROKIN	{"email": "pavel.sorokin1970@postgrespro.ru", "phone": "+70218886548"}
0005434480643	1EF606	6919 648368	MARIYA VOLKOVA	{"phone": "+70711700449"}
0005434480644	F16897	6702 385205	ROMAN DAVYDOV	{"email": "roman.davydov-06031959@postgrespro.ru", "phone": "+70881122175"}
0005434480645	F79655	7709 306717	YULIYA MARTYNOVA	{"phone": "+70525169436"}
0005434480646	F79655	1055 741466	SVETLANA KRASNOVA	{"email": "krasnova_s.25021966@postgrespro.ru", "phone": "+70358062113"}
0005434480647	B236DF	8829 820380	EVGENIY ZHUKOV	{"email": "ezhukov1968@postgrespro.ru", "phone": "+70510691563"}
0005434480648	91CD42	6344 451310	VYACHESLAV ZAKHAROV	{"phone": "+70346617204"}
0005434480649	E4D867	7115 570375	DMITRIY KOZLOV	{"phone": "+70587715234"}
0005434480650	6C6FCC	7234 871484	SVETLANA PETROVA	{"email": "petrova.svetlana.1964@postgrespro.ru", "phone": "+70695304499"}
0005434480651	0D3A2F	3998 062132	VLADIMIR GORBUNOV	{"email": "gorbunov.v.17011971@postgrespro.ru", "phone": "+70075136048"}
0005434480652	0D3A2F	9600 927758	MARIYA KRASNOVA	{"phone": "+70202932340"}
0005434480653	0D3A2F	2573 108382	SERGEY SOROKIN	{"email": "sorokin_s-12101975@postgrespro.ru", "phone": "+70825498399"}
0005434480654	413B19	5755 748786	EVGENIY IVANOV	{"phone": "+70318477143"}
0005434480655	413B19	9828 408292	NATALYA FROLOVA	{"email": "frolova-n.041976@postgrespro.ru", "phone": "+70293306837"}
0005434480656	413B19	4210 823784	ANNA KISELEVA	{"email": "akiseleva.18121972@postgrespro.ru", "phone": "+70952770942"}
0005434480657	5C9674	0688 826174	VLADIMIR BORISOV	{"email": "borisov-v-16091971@postgrespro.ru", "phone": "+70877299439"}
0005434480658	5C9674	5412 404537	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin1962@postgrespro.ru", "phone": "+70591536346"}
0005434480659	D749B2	7127 447519	ANATOLIY BONDARENKO	{"phone": "+70005080164"}
0005434480660	775387	4945 482890	SERGEY NIKOLAEV	{"phone": "+70794691773"}
0005434480661	775387	1661 071930	SVETLANA AFANASEVA	{"phone": "+70890862621"}
0005434480662	FFF278	6225 280957	OLGA ANISIMOVA	{"phone": "+70879036994"}
0005434480663	422D5A	1655 148384	ALEKSANDR SIDOROV	{"email": "a_sidorov-071971@postgrespro.ru", "phone": "+70120160052"}
0005434480664	05E07C	7494 358286	MIKHAIL KAZAKOV	{"phone": "+70937963715"}
0005434480665	05E07C	5328 053999	YURIY SIDOROV	{"phone": "+70419530405"}
0005434480666	05E07C	2521 091795	NATALYA KOZLOVA	{"email": "natalya.kozlova-25021973@postgrespro.ru", "phone": "+70004393816"}
0005434480667	2736E0	1319 480254	EKATERINA KUZMINA	{"phone": "+70529897637"}
0005434480668	0C4FCF	7038 856658	MAKSIM MAKSIMOV	{"email": "mmaksimov06111946@postgrespro.ru", "phone": "+70786909451"}
0005434480669	98C6A0	0673 661392	NATALYA POPOVA	{"phone": "+70600304649"}
0005434480670	622488	0501 595295	ELENA STEPANOVA	{"phone": "+70021046984"}
0005434480671	1D6C8A	1039 581100	ULYANA SOLOVEVA	{"email": "ulyana.soloveva_22101970@postgrespro.ru", "phone": "+70655490239"}
0005434480672	BB7343	9248 289126	SVETLANA MOROZOVA	{"phone": "+70785053310"}
0005434480673	308D86	2907 157630	NIKOLAY POPOV	{"email": "popov-n101967@postgrespro.ru", "phone": "+70999922382"}
0005434480674	D3DC2F	2357 385878	DMITRIY KOROLEV	{"email": "d-korolev011963@postgrespro.ru", "phone": "+70102758836"}
0005434480675	D3DC2F	6079 171144	SVETLANA ILINA	{"email": "ilina_s1972@postgrespro.ru", "phone": "+70129735354"}
0005434480676	993BC2	1569 551080	TATYANA VOLKOVA	{"phone": "+70552309342"}
0005434480677	F071F5	4273 724723	NATALYA IVANOVA	{"email": "ivanova_n-08061969@postgrespro.ru", "phone": "+70595720537"}
0005434480678	F071F5	9334 300106	VALENTINA BORISOVA	{"email": "borisova-valentina29111972@postgrespro.ru", "phone": "+70142805612"}
0005434480679	FE2257	4025 483585	TAMARA SIDOROVA	{"phone": "+70251623938"}
0005434480680	FE2257	7970 630246	GENNADIY BARANOV	{"email": "baranov.gennadiy-111955@postgrespro.ru", "phone": "+70256555027"}
0005434480681	F805C9	6319 134281	VALERIY PAVLOV	{"phone": "+70132315509"}
0005434480682	F805C9	0897 876757	ANDREY MAKAROV	{"phone": "+70320107056"}
0005434480683	1BF7D1	5385 917955	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov-121976@postgrespro.ru", "phone": "+70254759779"}
0005434480684	E48324	9754 210311	ELENA ZAYCEVA	{"email": "e-zayceva27101974@postgrespro.ru", "phone": "+70530988290"}
0005434480685	1BED52	5701 852158	VLADIMIR ORLOV	{"email": "vorlov.121974@postgrespro.ru", "phone": "+70310544769"}
0005434480686	7F20CA	2556 794997	KSENIYA GRISHINA	{"email": "k_grishina_121985@postgrespro.ru", "phone": "+70817130213"}
0005434480687	ABD757	5884 376974	NATALYA MOROZOVA	{"email": "natalya.morozova.23121975@postgrespro.ru", "phone": "+70403637110"}
0005434480688	ABD757	3940 326323	SERGEY BELOV	{"email": "belov.sergey-28011981@postgrespro.ru", "phone": "+70687426874"}
0005434480689	ABD757	4077 711775	ALEKSEY NIKITIN	{"email": "a_nikitin-041957@postgrespro.ru", "phone": "+70874735885"}
0005434480690	DD04F0	5247 585099	ALEVTINA MIRONOVA	{"phone": "+70672699555"}
0005434480691	DD04F0	3584 907244	ALBERT MIKHAYLOV	{"email": "amikhaylov-041981@postgrespro.ru", "phone": "+70083782660"}
0005434480692	DD04F0	8610 066498	TATYANA KOZLOVA	{"email": "t-kozlova_17101985@postgrespro.ru", "phone": "+70572948009"}
0005434480693	DFFFE2	6676 099250	VALERIYA BORISOVA	{"email": "valeriya-borisova25091975@postgrespro.ru", "phone": "+70312106442"}
0005434480694	DFFFE2	9980 563212	VALENTIN MAKAROV	{"phone": "+70970823307"}
0005434480695	0F7A12	1194 433598	NATALYA TROFIMOVA	{"phone": "+70732086271"}
0005434480696	E3FE66	0067 089757	VALENTIN SHEVCHENKO	{"email": "valentin.shevchenko1968@postgrespro.ru", "phone": "+70218491839"}
0005434480697	E3FE66	0438 126339	ELENA VOLKOVA	{"phone": "+70734084092"}
0005434480698	061712	6022 535702	TATYANA MIRONOVA	{"email": "mironovat30071981@postgrespro.ru", "phone": "+70395642823"}
0005434480699	114E7E	4459 130198	NATALYA YAKOVLEVA	{"phone": "+70348918235"}
0005434480700	114E7E	3844 905947	MATVEY AFANASEV	{"phone": "+70614818195"}
0005434480701	ABA4F9	3772 642265	YURIY ZAKHAROV	{"phone": "+70779331904"}
0005434480702	ABA4F9	1052 984933	YULIYA LEBEDEVA	{"email": "yuliyalebedeva-1975@postgrespro.ru", "phone": "+70537390893"}
0005434480703	205CEE	3093 795895	IRINA KOMAROVA	{"email": "irinakomarova_1972@postgrespro.ru", "phone": "+70805267094"}
0005434480704	782A50	9365 781078	OLGA KUZNECOVA	{"email": "o.kuznecova-1976@postgrespro.ru", "phone": "+70919468875"}
0005434480705	782A50	6679 269535	PAVEL MAKAROV	{"phone": "+70265959591"}
0005434480706	0EC015	0111 216335	NADEZHDA SOKOLOVA	{"email": "nadezhdasokolova22101974@postgrespro.ru", "phone": "+70040702888"}
0005434480707	35964E	9577 085708	VASILIY GORBUNOV	{"phone": "+70818709541"}
0005434480708	C77592	9065 132620	DMITRIY PETROV	{"phone": "+70917041256"}
0005434480709	C77592	9035 727286	NATALYA BOGDANOVA	{"email": "natalyabogdanova_1977@postgrespro.ru", "phone": "+70014435832"}
0005434480710	BF76EB	4781 345416	YURIY MATVEEV	{"phone": "+70476545297"}
0005434480711	7C97D3	6550 083294	PAVEL DMITRIEV	{"email": "pavel-dmitriev_11091966@postgrespro.ru", "phone": "+70601494763"}
0005434480712	0A7A81	3423 009033	EVGENIY PETROV	{"phone": "+70823937865"}
0005434480713	575C28	8862 290446	YURIY GUSEV	{"phone": "+70148679891"}
0005434480714	9E4228	7291 529470	ALEVTINA CHERNOVA	{"phone": "+70078936025"}
0005434480715	9E4228	0984 227459	ALEKSANDR BARANOV	{"phone": "+70363254080"}
0005434480716	E699EC	7810 771473	MIKHAIL POPOV	{"email": "popovm_1976@postgrespro.ru", "phone": "+70885874503"}
0005434480717	8CB3B0	5200 104649	ANATOLIY KONOVALOV	{"phone": "+70134891530"}
0005434480718	51002A	1324 727419	ALEKSEY KUZMIN	{"email": "aleksey.kuzmin.081978@postgrespro.ru", "phone": "+70112936540"}
0005434480719	51002A	3338 770171	ALEKSANDR KUZNECOV	{"phone": "+70516365825"}
0005434480720	336BBB	6076 037335	VYACHESLAV POPOV	{"phone": "+70340928159"}
0005434480721	78B3E7	0419 936932	NIKOLAY KISELEV	{"phone": "+70559689984"}
0005434480722	70B338	6327 748359	TATYANA IVANOVA	{"email": "ivanova_tatyana.04031962@postgrespro.ru", "phone": "+70414675615"}
0005434480723	5ECCA7	5468 094287	RUSLAN ROMANOV	{"phone": "+70056649906"}
0005434480724	E56C27	6902 292816	ROMAN AFANASEV	{"email": "afanasevroman29051970@postgrespro.ru", "phone": "+70666022337"}
0005434480725	89E58E	8551 119357	VLADIMIR POPOV	{"phone": "+70289197988"}
0005434480726	89E58E	5329 962891	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov101974@postgrespro.ru", "phone": "+70297013499"}
0005434480727	89E58E	7134 215778	VLADIMIR ZAKHAROV	{"phone": "+70605522042"}
0005434480728	6E68E5	7891 948722	EKATERINA NOVIKOVA	{"email": "novikova-ekaterina1962@postgrespro.ru", "phone": "+70259204799"}
0005434480729	6E68E5	5877 993875	VLADIMIR ZAKHAROV	{"email": "v_zakharov081975@postgrespro.ru", "phone": "+70163647946"}
0005434480730	E0DCA1	1411 107754	VLADIMIR BARANOV	{"phone": "+70866478876"}
0005434480731	E0DCA1	9011 546624	EDUARD MEDVEDEV	{"email": "e.medvedev.091965@postgrespro.ru", "phone": "+70728630628"}
0005434480732	E5BA3F	1454 290025	ANATOLIY GORBUNOV	{"email": "gorbunov-a-031976@postgrespro.ru", "phone": "+70644748469"}
0005434480733	6AE6FC	8903 683913	TAMARA NOVIKOVA	{"email": "novikova_t.1969@postgrespro.ru", "phone": "+70543085530"}
0005434480734	6AE6FC	4900 477164	MARYAM TITOVA	{"email": "titovam.1983@postgrespro.ru", "phone": "+70336622079"}
0005434480735	B2D92D	0085 789414	IRINA AFANASEVA	{"email": "afanasevai1972@postgrespro.ru", "phone": "+70465398216"}
0005434480736	7AD453	4945 606888	SERGEY MARTYNOV	{"phone": "+70653273672"}
0005434480737	B4207E	6461 906093	EVGENIY MAKAROV	{"email": "makarovevgeniy.1966@postgrespro.ru", "phone": "+70755519072"}
0005434480738	B4207E	2581 288730	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-1983@postgrespro.ru", "phone": "+70279673622"}
0005434480739	94DF05	5644 288410	ILYA BORISOV	{"email": "ilya-borisov.1966@postgrespro.ru", "phone": "+70088449982"}
0005434480740	963F35	2956 670486	GERMAN MOROZOV	{"email": "morozov.german-1976@postgrespro.ru", "phone": "+70886528879"}
0005434480741	963F35	3715 618930	DARYA MAKSIMOVA	{"phone": "+70580692033"}
0005434480742	35BD1A	5342 531602	EVGENIY ALEKSANDROV	{"email": "aleksandrov.e.1976@postgrespro.ru", "phone": "+70936096959"}
0005434480743	35BD1A	9492 282781	ANATOLIY KARPOV	{"email": "a-karpov1968@postgrespro.ru", "phone": "+70987931418"}
0005434480744	35BD1A	3753 158915	ANDREY SEMENOV	{"phone": "+70625194065"}
0005434480745	FA1E15	8693 870204	ANDREY CHERNOV	{"email": "chernov.a-051963@postgrespro.ru", "phone": "+70793270388"}
0005434480746	474E32	3911 956638	ALEKSANDR PAVLOV	{"email": "pavlov-a_071965@postgrespro.ru", "phone": "+70194971314"}
0005434480747	22B869	2947 626289	KONSTANTIN YAKOVLEV	{"phone": "+70310110896"}
0005434480748	83034D	6366 012174	MARINA NIKITINA	{"phone": "+70202955774"}
0005434480749	22131B	2753 123006	DARYA GAVRILOVA	{"email": "dgavrilova-29041965@postgrespro.ru", "phone": "+70775363024"}
0005434480750	3DE2D3	8585 989161	ANDREY STEPANOV	{"phone": "+70606806554"}
0005434480751	CFD74D	6119 230054	KSENIYA MOISEEVA	{"phone": "+70783107404"}
0005434480752	5E708C	9084 170070	RAISA KOVALEVA	{"email": "r.kovaleva-031974@postgrespro.ru", "phone": "+70329076984"}
0005434480753	72729A	5554 993760	EGOR KAZAKOV	{"email": "egor.kazakov_1975@postgrespro.ru", "phone": "+70696585199"}
0005434480754	9EB6F4	4104 052516	NATALYA ANTONOVA	{"email": "nantonova.021975@postgrespro.ru", "phone": "+70141380073"}
0005434480755	96746E	1344 505726	YULIYA LUKYANOVA	{"email": "lukyanova-y-1973@postgrespro.ru", "phone": "+70679302283"}
0005434480756	3A94CB	1381 625815	ELENA FADEEVA	{"email": "fadeeva_e_1970@postgrespro.ru", "phone": "+70312851616"}
0005434480757	F4D7F5	0154 682083	SVETLANA TARASOVA	{"email": "svetlana.tarasova_24051979@postgrespro.ru", "phone": "+70988559953"}
0005434480758	DB97BD	1553 584403	ALEKSEY ZAYCEV	{"email": "a-zaycev.081978@postgrespro.ru", "phone": "+70288617220"}
0005434480759	DB97BD	8234 711346	VERA IVANOVA	{"phone": "+70692776929"}
0005434480760	D242AC	6225 835361	PAVEL ANTONOV	{"phone": "+70839290007"}
0005434480761	9630F0	2226 946504	VYACHESLAV MOROZOV	{"phone": "+70398384200"}
0005434480762	9630F0	7463 539994	VLADIMIR MELNIKOV	{"phone": "+70714511781"}
0005434480763	9630F0	3543 574779	IVAN YAKOVLEV	{"email": "iyakovlev1976@postgrespro.ru", "phone": "+70952546667"}
0005434480764	22FE81	4605 512308	VALERIY MOROZOV	{"phone": "+70041251396"}
0005434480765	CE4BD8	5677 637835	VIKTOR FEDOROV	{"email": "fedorovv13111968@postgrespro.ru", "phone": "+70389414457"}
0005434480766	ED9CB8	1630 119239	SVETLANA SERGEEVA	{"phone": "+70271526586"}
0005434480767	8D241C	9584 321974	YULIYA TITOVA	{"phone": "+70757698315"}
0005434480768	51A764	2376 923755	LYUDMILA ABRAMOVA	{"phone": "+70073811514"}
0005434480769	51A764	5631 819788	VALERIY NAZAROV	{"phone": "+70755445152"}
0005434480770	51A764	2939 499118	EGOR SOLOVEV	{"email": "egor.solovev_25081974@postgrespro.ru", "phone": "+70035304551"}
0005434480771	51A764	4677 695055	LYUDMILA FADEEVA	{"email": "l-fadeeva-1966@postgrespro.ru", "phone": "+70251760503"}
0005434480772	1F8A44	9560 650785	NADEZHDA FILIPPOVA	{"phone": "+70987370971"}
0005434480773	54BAA3	6256 262221	SERGEY SCHERBAKOV	{"email": "s_scherbakov.26011968@postgrespro.ru", "phone": "+70179444468"}
0005434480774	A6C508	6163 506820	YURIY SAVELEV	{"email": "savelev.yuriy_1970@postgrespro.ru", "phone": "+70058747426"}
0005434480775	E65781	6225 210125	YURIY SMIRNOV	{"phone": "+70586391828"}
0005434480776	18B579	1471 203509	VITALIY ORLOV	{"email": "vitaliy_orlov.1969@postgrespro.ru", "phone": "+70324235100"}
0005434480777	DE4398	4045 322013	TATYANA NIKOLAEVA	{"phone": "+70686388075"}
0005434480778	DE4398	2285 645652	GALINA PAVLOVA	{"email": "galina-pavlova-17011978@postgrespro.ru", "phone": "+70783715157"}
0005434480779	CB0131	9194 782481	VIKTOR GUSEV	{"phone": "+70371781400"}
0005434480780	2B622D	3951 806979	DENIS FEDOTOV	{"phone": "+70570482604"}
0005434480781	1B375A	2623 994755	SERGEY BARANOV	{"email": "baranovs-1980@postgrespro.ru", "phone": "+70725456151"}
0005434480782	1B375A	2232 133843	ALEKSANDR IVANOV	{"email": "ivanov-a_071965@postgrespro.ru", "phone": "+70117185750"}
0005434480783	0638FD	1069 163704	ELENA SIDOROVA	{"email": "sidorova_e.1971@postgrespro.ru", "phone": "+70844752516"}
0005434480784	9BFC9E	5236 773076	LIDIYA IVANOVA	{"phone": "+70665781565"}
0005434480785	709DEA	4015 682825	MARIYA ZAKHAROVA	{"phone": "+70652250630"}
0005434480786	709DEA	8510 005635	ALEKSANDR RODIONOV	{"phone": "+70350518624"}
0005434480787	99A7A6	8199 563724	SVETLANA YUDINA	{"email": "s-yudina.28021968@postgrespro.ru", "phone": "+70022299834"}
0005434480788	99A7A6	0896 304378	ANTONINA ERMAKOVA	{"email": "ermakova_antonina22101975@postgrespro.ru", "phone": "+70618096042"}
0005434480789	0C5AC5	6892 906700	YULIYA FILIPPOVA	{"email": "yuliyafilippova-121978@postgrespro.ru", "phone": "+70083904586"}
0005434480790	0C5AC5	0896 706368	EKATERINA KOZLOVA	{"email": "ekaterina-kozlova_15031977@postgrespro.ru", "phone": "+70965902335"}
0005434480791	F6FB4A	4414 142426	ARKADIY ALEKSEEV	{"email": "aalekseev-051975@postgrespro.ru", "phone": "+70187229612"}
0005434480792	8A2814	1431 980282	GALINA SIDOROVA	{"email": "g.sidorova.01051970@postgrespro.ru", "phone": "+70895926280"}
0005434480793	909BED	0760 558908	RAFIK KAZAKOV	{"email": "kazakov-rafik.1967@postgrespro.ru", "phone": "+70112118031"}
0005434480794	F2D021	9906 061226	LARISA KULIKOVA	{"email": "larisa_kulikova25011968@postgrespro.ru", "phone": "+70911187904"}
0005434480795	F41562	5490 478248	LYUDMILA FOMINA	{"phone": "+70406600689"}
0005434480796	2E615B	3151 631216	STANISLAV ALEKSEEV	{"email": "alekseev_s_101968@postgrespro.ru", "phone": "+70262178802"}
0005434480797	7250E8	3950 374086	YURIY ALEKSANDROV	{"phone": "+70324493794"}
0005434480798	02F8BE	2797 044203	OLGA NESTEROVA	{"phone": "+70498243639"}
0005434480799	02F8BE	7762 881449	ALEKSANDR KARPOV	{"phone": "+70275084734"}
0005434480800	E9C63B	1757 103131	SERGEY EGOROV	{"phone": "+70112461698"}
0005434480801	65C76F	7505 541118	MIKHAIL MOROZOV	{"phone": "+70457242020"}
0005434480802	65C76F	4151 846311	KSENIYA BELOVA	{"email": "belova_k111973@postgrespro.ru", "phone": "+70679587003"}
0005434480803	A60426	0278 103809	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir-1972@postgrespro.ru", "phone": "+70470640384"}
0005434480804	A60426	7358 307267	GALINA VOLKOVA	{"phone": "+70892939364"}
0005434480805	A60426	7619 989675	GLEB PETROV	{"email": "g_petrov.09071983@postgrespro.ru", "phone": "+70268695809"}
0005434480806	E4AB95	4248 579453	EKATERINA EGOROVA	{"email": "eegorova14061973@postgrespro.ru", "phone": "+70229335637"}
0005434480807	CE34F2	3154 632495	DMITRIY NAZAROV	{"email": "dnazarov.14091963@postgrespro.ru", "phone": "+70879034349"}
0005434480808	CE34F2	8572 939607	GULSINA MEDVEDEVA	{"email": "gulsinamedvedeva031979@postgrespro.ru", "phone": "+70384270569"}
0005434480809	7993AE	5886 207412	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a-121975@postgrespro.ru", "phone": "+70317302926"}
0005434480810	3F4908	2324 690757	SERGEY PAVLOV	{"phone": "+70832586746"}
0005434480811	744941	2127 171096	IVAN ZHURAVLEV	{"email": "zhuravlev_i-081974@postgrespro.ru", "phone": "+70763972180"}
0005434480812	B65307	9963 315162	SVETLANA LAZAREVA	{"phone": "+70751287159"}
0005434480813	B65307	3240 986184	MIKHAIL PETROV	{"phone": "+70854436821"}
0005434480814	EBFD26	1254 553216	ANNA KISELEVA	{"email": "kiseleva_a.1964@postgrespro.ru", "phone": "+70860756007"}
0005434480815	B3C452	7127 876434	VLADISLAV SMIRNOV	{"email": "smirnov.v-15071977@postgrespro.ru", "phone": "+70034361376"}
0005434480816	7CEF9E	1443 646293	ANASTASIYA ABRAMOVA	{"email": "a_abramova-04071973@postgrespro.ru", "phone": "+70601014152"}
0005434480817	FC5800	7912 976403	IGOR MAKAROV	{"email": "makarov.i1962@postgrespro.ru", "phone": "+70256658886"}
0005434480818	FC5800	1415 682762	VITALIY SOKOLOV	{"email": "sokolov-vitaliy-1974@postgrespro.ru", "phone": "+70703774338"}
0005434480819	7D4FC9	0944 594730	ROMAN BONDARENKO	{"email": "bondarenko_roman1971@postgrespro.ru", "phone": "+70389791852"}
0005434480820	7D4FC9	1598 327571	MIKHAIL CHERNOV	{"phone": "+70235884292"}
0005434480821	44FE4B	2356 624945	VLADIMIR DAVYDOV	{"phone": "+70901095226"}
0005434480822	44FE4B	3261 757539	NADEZHDA SOKOLOVA	{"email": "n.sokolova091972@postgrespro.ru", "phone": "+70704395884"}
0005434480823	6116BD	3920 806405	YAKOV MIRONOV	{"email": "yakov-mironov031972@postgrespro.ru", "phone": "+70297308989"}
0005434480824	389E17	2415 279795	RAISA SEMENOVA	{"phone": "+70958957099"}
0005434480825	70F798	0673 262974	DARYA KALININA	{"email": "kalinina-d-11031964@postgrespro.ru", "phone": "+70511203491"}
0005434480826	1BD1F7	9411 757847	EMILIYA SOROKINA	{"email": "sorokinae_1968@postgrespro.ru", "phone": "+70419309796"}
0005434480827	D77374	2134 318111	ALSU AKIMOVA	{"email": "akimova_alsu_031979@postgrespro.ru", "phone": "+70255556319"}
0005434480828	D77374	5799 687746	NATALYA MIKHAYLOVA	{"email": "mikhaylova-n-091967@postgrespro.ru", "phone": "+70742280999"}
0005434480829	1BF171	4768 813265	LYUBOV GRISHINA	{"email": "lgrishina_05111968@postgrespro.ru", "phone": "+70995645023"}
0005434480830	07AD10	7426 822145	ALEKSANDR SOLOVEV	{"phone": "+70399638552"}
0005434480831	07AD10	8463 416672	OLGA ANTONOVA	{"email": "antonova.olga-1960@postgrespro.ru", "phone": "+70253107542"}
0005434480832	481765	7759 577691	ARTEM KULIKOV	{"email": "kulikovartem1973@postgrespro.ru", "phone": "+70879912961"}
0005434480833	43A0EF	7813 512409	VIKTORIYA KISELEVA	{"email": "kiseleva_v.28101973@postgrespro.ru", "phone": "+70615134066"}
0005434480834	43A0EF	5386 969690	ELIZAVETA FROLOVA	{"phone": "+70001431374"}
0005434480835	862520	2251 684099	DMITRIY MARTYNOV	{"phone": "+70318170349"}
0005434480836	A8543E	2164 128973	VALERIY MIKHAYLOV	{"email": "v_mikhaylov22081971@postgrespro.ru", "phone": "+70583117487"}
0005434480837	7B66C4	6448 072717	SERGEY ZAYCEV	{"phone": "+70285581812"}
0005434480838	5F55C2	5359 374299	SERGEY KARPOV	{"phone": "+70426255933"}
0005434480839	71414A	3960 187902	NATALYA TARASOVA	{"email": "tarasovanatalya_1968@postgrespro.ru", "phone": "+70634706478"}
0005434480840	B76740	5455 522858	ELENA SERGEEVA	{"phone": "+70458909574"}
0005434480841	B76740	5181 728998	ANTON MATVEEV	{"phone": "+70644752846"}
0005434480842	7437E4	5966 255731	GERMAN GAVRILOV	{"phone": "+70262001248"}
0005434480843	056A33	2970 036869	DENIS KOZLOV	{"email": "d-kozlov_1973@postgrespro.ru", "phone": "+70717972310"}
0005434480844	056A33	4949 019230	ELENA OVCHINNIKOVA	{"phone": "+70466368818"}
0005434480845	4DC1A7	8591 624434	OLEG ALEKSEEV	{"phone": "+70799298966"}
0005434480846	100CB3	1093 082906	ALEKSANDR TARASOV	{"email": "a_tarasov02081980@postgrespro.ru", "phone": "+70942861988"}
0005434480847	758BE4	3536 754038	NADEZHDA OVCHINNIKOVA	{"email": "n.ovchinnikova_031972@postgrespro.ru", "phone": "+70881881264"}
0005434480848	2188A5	6000 008898	DMITRIY KULIKOV	{"email": "dmitriy.kulikov021984@postgrespro.ru", "phone": "+70895622794"}
0005434480849	78791F	8882 556084	KRISTINA BORISOVA	{"email": "borisova.k_1981@postgrespro.ru", "phone": "+70200277228"}
0005434480850	5F9E84	6814 494519	RAFIK BONDARENKO	{"email": "bondarenko.r_021975@postgrespro.ru", "phone": "+70899230010"}
0005434480851	6EA89C	7561 056106	GALINA FROLOVA	{"phone": "+70168344646"}
0005434480852	4B6BA3	8411 615453	SERGEY FILIPPOV	{"email": "filippov.s-1971@postgrespro.ru", "phone": "+70033743291"}
0005434480853	3F24A5	2216 604704	NIKOLAY FROLOV	{"email": "frolov.nikolay-18121979@postgrespro.ru", "phone": "+70131780608"}
0005434480854	C9B505	5229 885481	GALINA PETROVA	{"phone": "+70484759478"}
0005434480855	6E2901	1354 680663	ALSU FILIPPOVA	{"email": "filippovaalsu-31081967@postgrespro.ru", "phone": "+70049586375"}
0005434480856	6E2901	6758 916165	VYACHESLAV EGOROV	{"phone": "+70805993899"}
0005434480857	6E2901	4956 224451	DANIIL GORBUNOV	{"phone": "+70141392245"}
0005434480858	96586A	5270 706183	VITALIY OSIPOV	{"phone": "+70859311682"}
0005434480859	96586A	9837 539220	BORIS KARPOV	{"phone": "+70307742626"}
0005434480860	C1DA03	6202 779773	IRINA GUSEVA	{"email": "irina.guseva-21111972@postgrespro.ru", "phone": "+70601725662"}
0005434480861	8BEA61	4916 315544	IRINA MARTYNOVA	{"phone": "+70547351372"}
0005434480862	8BEA61	2963 520138	NATALYA NIKITINA	{"phone": "+70749559833"}
0005434480863	D646CA	1297 138966	ALEKSANDR ANDREEV	{"phone": "+70650685233"}
0005434480864	595BAB	8480 041438	ANNA NIKOLAEVA	{"phone": "+70362513351"}
0005434480865	595BAB	4391 180293	NATALYA POPOVA	{"phone": "+70091007259"}
0005434480866	151525	4698 175342	NINA KULIKOVA	{"phone": "+70041130937"}
0005434480867	151525	4436 114281	ANATOLIY OSIPOV	{"phone": "+70752429157"}
0005434480868	EB9E2E	5329 564578	LYUDMILA KOROLEVA	{"email": "korolevalyudmila.29061976@postgrespro.ru", "phone": "+70279803305"}
0005434480869	EB9E2E	6474 302078	FEDOR GAVRILOV	{"email": "fedor-gavrilov_091969@postgrespro.ru", "phone": "+70895819582"}
0005434480870	A38E5A	2779 744103	SEMEN VOLKOV	{"phone": "+70885939034"}
0005434480871	8DE75D	1515 772713	SOFYA OSIPOVA	{"email": "osipovasofya.03071961@postgrespro.ru", "phone": "+70901940819"}
0005434480872	C0B194	6403 997592	NIKOLAY GERASIMOV	{"email": "gerasimov_n_1964@postgrespro.ru", "phone": "+70083522342"}
0005434480873	729FCC	0768 313231	DMITRIY PETROV	{"email": "dmitriypetrov16121962@postgrespro.ru", "phone": "+70165434418"}
0005434480874	547744	3881 554219	NIKOLAY TIMOFEEV	{"email": "n_timofeev-111975@postgrespro.ru", "phone": "+70917721441"}
0005434480875	547744	6028 292273	TATYANA MASLOVA	{"email": "maslovat1971@postgrespro.ru", "phone": "+70211348979"}
0005434480876	17534D	3270 656767	GALINA SIDOROVA	{"email": "sidorova.g_1971@postgrespro.ru", "phone": "+70265585220"}
0005434480877	17534D	4006 598010	VALENTINA ZOTOVA	{"email": "zotova.valentina-31051975@postgrespro.ru", "phone": "+70143516405"}
0005434480878	E3F63C	0284 497480	ELENA POPOVA	{"email": "popovaelena.041981@postgrespro.ru", "phone": "+70030135417"}
0005434480879	6397E5	0372 350182	EVGENIY IVANOV	{"email": "evgeniy_ivanov-031969@postgrespro.ru", "phone": "+70588243448"}
0005434480880	705772	9333 222918	ALEKSANDR FILIPPOV	{"phone": "+70397161609"}
0005434480881	4B44AF	6372 749454	LUIZA RYABOVA	{"email": "ryabova.l_1964@postgrespro.ru", "phone": "+70920135841"}
0005434480882	22472F	7101 713486	EVDOKIYA DENISOVA	{"email": "denisova_evdokiya.031970@postgrespro.ru", "phone": "+70292890824"}
0005434480883	F5D6C4	3130 766790	AYRAT SOROKIN	{"phone": "+70760613871"}
0005434480884	F343BE	8813 582517	OLGA MASLOVA	{"email": "olga_maslova.21121981@postgrespro.ru", "phone": "+70224919893"}
0005434480885	35B346	9765 857933	MARIYA DANILOVA	{"email": "danilova-m.02101985@postgrespro.ru", "phone": "+70066381753"}
0005434480886	D3208C	8895 511710	IVAN DMITRIEV	{"email": "ivan.dmitriev_1961@postgrespro.ru", "phone": "+70636385333"}
0005434480887	D3208C	7307 476565	DZHAMILYA BELYAEVA	{"email": "dzhamilyabelyaeva071976@postgrespro.ru", "phone": "+70500665702"}
0005434480888	D3208C	3868 619476	ANNA SMIRNOVA	{"phone": "+70721402014"}
0005434480889	80E0D5	8552 931082	ALEKSEY MIRONOV	{"phone": "+70653886134"}
0005434480890	80E0D5	8691 930183	IRINA PETROVA	{"email": "petrova-i-111963@postgrespro.ru", "phone": "+70380736417"}
0005434480891	B95B49	3776 753882	NIKOLAY KRASNOV	{"email": "n_krasnov101963@postgrespro.ru", "phone": "+70162707833"}
0005434480892	B95B49	5277 489541	IRINA SOKOLOVA	{"phone": "+70295443799"}
0005434480893	4A1775	9559 135530	NATALYA ORLOVA	{"email": "orlova-natalya_1970@postgrespro.ru", "phone": "+70822865863"}
0005434480894	B614DB	5348 612435	ALEKSANDR KULIKOV	{"email": "a-kulikov.11111969@postgrespro.ru", "phone": "+70397181027"}
0005434480895	7959F5	1111 663204	OKSANA EGOROVA	{"email": "o.egorova17071962@postgrespro.ru", "phone": "+70700701003"}
0005434480896	4AD787	0574 511675	SERGEY FILIPPOV	{"email": "sergey-filippov.14051980@postgrespro.ru", "phone": "+70972107764"}
0005434480897	149FE2	8143 294327	LYUDMILA MOROZOVA	{"email": "morozova_l.041974@postgrespro.ru", "phone": "+70182493829"}
0005434480898	149FE2	0386 564333	MAKSIM ZAYCEV	{"phone": "+70744206237"}
0005434480899	683FF2	9650 503307	TATYANA GORBUNOVA	{"phone": "+70753457439"}
0005434480900	84D261	0763 318573	VADIM FILIPPOV	{"phone": "+70689295115"}
0005434480901	9F6431	1261 939312	LIDIYA BORISOVA	{"phone": "+70900583604"}
0005434480902	9F5F16	5197 483911	OLEG MARTYNOV	{"phone": "+70953058206"}
0005434480903	3D0645	3092 400191	VLADISLAV IVANOV	{"email": "vladislav_ivanov-081969@postgrespro.ru", "phone": "+70572513808"}
0005434480904	3D0645	7383 845069	LEV CHERNOV	{"email": "lev-chernov.051966@postgrespro.ru", "phone": "+70239543646"}
0005434480905	76EDF1	5383 891156	VLADIMIR GORBUNOV	{"email": "vgorbunov.021982@postgrespro.ru", "phone": "+70583452944"}
0005434480906	FA583D	3369 602772	NATALYA VOROBEVA	{"phone": "+70860432009"}
0005434480907	7E50E9	7440 563421	VITALIY FROLOV	{"email": "frolov.vitaliy_1964@postgrespro.ru", "phone": "+70973542264"}
0005434480908	AD5E6E	7338 806698	EKATERINA POPOVA	{"phone": "+70428628204"}
0005434480909	4607A9	0087 319698	IRINA VOLKOVA	{"phone": "+70683536048"}
0005434480910	807BF0	6641 071031	YURIY ORLOV	{"email": "y.orlov14101968@postgrespro.ru", "phone": "+70039536884"}
0005434480911	EFE080	2627 049754	ANDREY BONDARENKO	{"phone": "+70713372137"}
0005434480912	EFE080	8957 215583	IRINA TIKHONOVA	{"email": "tikhonova_irina-13121973@postgrespro.ru", "phone": "+70125713127"}
0005434480913	D19A1E	3032 009574	MIKHAIL NIKOLAEV	{"phone": "+70894493703"}
0005434480914	D19A1E	3578 013238	GALINA MATVEEVA	{"phone": "+70959990124"}
0005434480915	7D25CA	2293 535170	IRINA SAVELEVA	{"email": "irina-saveleva.031972@postgrespro.ru", "phone": "+70855131463"}
0005434480916	379A07	6697 156635	VIKTOR DMITRIEV	{"phone": "+70931330240"}
0005434480917	908468	7698 609734	NINA ZOTOVA	{"email": "nzotova1975@postgrespro.ru", "phone": "+70267082776"}
0005434480918	908468	9412 040931	TAMARA ILINA	{"email": "tamara_ilina.17101974@postgrespro.ru", "phone": "+70640520988"}
0005434480919	B41A7C	2552 355872	ALINA MIKHAYLOVA	{"phone": "+70789054075"}
0005434480920	EC6BB0	6503 792785	SVETLANA KUZMINA	{"email": "s.kuzmina.18011978@postgrespro.ru", "phone": "+70757571565"}
0005434480921	80F238	0703 264715	ANNA MEDVEDEVA	{"phone": "+70351838618"}
0005434480922	3CBFE3	7149 494507	SERGEY BELOV	{"phone": "+70383053997"}
0005434480923	3CBFE3	5425 408211	GEORGIY SOLOVEV	{"email": "g.solovev111966@postgrespro.ru", "phone": "+70517989437"}
0005434480924	DF3441	0380 255929	ELENA ZAYCEVA	{"email": "zayceva.elena_031961@postgrespro.ru", "phone": "+70723510660"}
0005434480925	DF3441	5047 964684	LIDIYA BORISOVA	{"email": "lidiya_borisova27071969@postgrespro.ru", "phone": "+70428329447"}
0005434480926	DF3441	5825 605645	ROMAN GRIGOREV	{"phone": "+70569074822"}
0005434480927	DF3441	9369 325073	MAKSIM KRASNOV	{"email": "maksim_krasnov-1963@postgrespro.ru", "phone": "+70949082170"}
0005434480928	903EF0	7847 058931	ZOYA OSIPOVA	{"email": "zoya-osipova-1973@postgrespro.ru", "phone": "+70070046148"}
0005434480929	831FDF	3332 908227	DMITRIY NAUMOV	{"email": "naumov.dmitriy-1973@postgrespro.ru", "phone": "+70685728440"}
0005434480930	831FDF	6683 967567	YULIYA SERGEEVA	{"phone": "+70345654469"}
0005434480931	1B55EE	1659 997355	NIKOLAY ZAYCEV	{"phone": "+70984564901"}
0005434480932	6C3471	2033 282406	TATYANA TIKHONOVA	{"email": "t.tikhonova.081982@postgrespro.ru", "phone": "+70013177409"}
0005434480933	6C3471	1996 180540	ALEKSANDR IVANOV	{"phone": "+70251623278"}
0005434480934	6C3471	4976 486451	ELENA KOLESNIKOVA	{"email": "kolesnikovaelena_23121972@postgrespro.ru", "phone": "+70446343870"}
0005434480935	59273C	2448 060751	EVGENIYA LEBEDEVA	{"phone": "+70464152989"}
0005434480936	59273C	6684 620050	NADEZHDA ANTONOVA	{"phone": "+70311741584"}
0005434480937	D11681	3539 830060	VYACHESLAV VOROBEV	{"phone": "+70041995669"}
0005434480938	D11681	7933 727552	TAISIYA FROLOVA	{"phone": "+70413325583"}
0005434480939	E8D583	1387 265721	GALINA YAKOVLEVA	{"email": "yakovleva-g_041970@postgrespro.ru", "phone": "+70192785856"}
0005434480940	E8D583	8891 277394	ALIYA NOVIKOVA	{"email": "novikova_a_031980@postgrespro.ru", "phone": "+70279182577"}
0005434480941	54EEFE	3992 529276	KRISTINA KUDRYASHOVA	{"email": "k_kudryashova.1969@postgrespro.ru", "phone": "+70412798846"}
0005434480942	36D044	6476 633089	DMITRIY MIRONOV	{"email": "dmironov.071965@postgrespro.ru", "phone": "+70625281659"}
0005434480943	197A6D	8072 357824	VITALIY ZAYCEV	{"email": "zaycev-v1966@postgrespro.ru", "phone": "+70956430087"}
0005434480944	197A6D	6938 471499	ANNA KOLESNIKOVA	{"email": "anna_kolesnikova_29081974@postgrespro.ru", "phone": "+70821506762"}
0005434480945	197A6D	3705 298389	YURIY ANDREEV	{"email": "andreev.y081981@postgrespro.ru", "phone": "+70494263786"}
0005434480946	7A4E0A	1805 480645	IGOR TIMOFEEV	{"phone": "+70781476279"}
0005434480947	143355	2325 973763	SVETLANA FROLOVA	{"phone": "+70013624720"}
0005434480948	7BAAC0	5653 442157	ARSENIY MAKAROV	{"phone": "+70345520494"}
0005434480949	7BAAC0	3307 512820	BORIS VASILEV	{"email": "vasilevboris-02081963@postgrespro.ru", "phone": "+70892821414"}
0005434480950	7BAAC0	9112 157406	ANTON ROMANOV	{"email": "antonromanov-1970@postgrespro.ru", "phone": "+70394155881"}
0005434480951	A3AEC0	8055 191342	KSENIYA NAZAROVA	{"email": "kseniya.nazarova-071972@postgrespro.ru", "phone": "+70860705351"}
0005434480952	A7CBDE	9213 346570	IVAN SOROKIN	{"phone": "+70438077483"}
0005434480953	550F76	9034 427954	YULIYA DAVYDOVA	{"phone": "+70418170895"}
0005434480954	F323A9	3263 176635	LARISA DAVYDOVA	{"email": "davydova.larisa.101959@postgrespro.ru", "phone": "+70642844200"}
0005434480955	136DF5	3286 317686	GEORGIY SAVELEV	{"email": "g.savelev_081974@postgrespro.ru", "phone": "+70844544011"}
0005434480956	96EEA5	6572 257849	SVETLANA KISELEVA	{"email": "kiseleva.s-1972@postgrespro.ru", "phone": "+70933640239"}
0005434480957	96EEA5	2955 610157	NATALIYA ZAKHAROVA	{"phone": "+70280059632"}
0005434480958	A31110	2744 673506	NATALYA KUDRYASHOVA	{"email": "natalyakudryashova.011965@postgrespro.ru", "phone": "+70224458460"}
0005434480959	A31110	6384 999470	VASILIY MAKAROV	{"phone": "+70915445378"}
0005434480960	962B53	3115 091427	VLADIMIR PETROV	{"phone": "+70039115772"}
0005434480961	962B53	5918 839653	SVETLANA IVANOVA	{"email": "svetlana.ivanova19111984@postgrespro.ru", "phone": "+70313673195"}
0005434480962	567EED	3316 131308	MIKHAIL MOISEEV	{"phone": "+70429285022"}
0005434480963	DB0CF8	5686 472572	EVGENIY KONOVALOV	{"email": "konovalov_evgeniy_1983@postgrespro.ru", "phone": "+70329799167"}
0005434480964	4014A8	7893 426205	NIKOLAY ANDREEV	{"phone": "+70704859480"}
0005434480965	040F26	9678 976007	ELENA KULIKOVA	{"email": "e-kulikova-03101987@postgrespro.ru", "phone": "+70509088382"}
0005434480966	F64934	8001 053297	LEONID NAUMOV	{"email": "lnaumov011973@postgrespro.ru", "phone": "+70625766915"}
0005434480967	546242	0441 392419	LILIYA KUDRYASHOVA	{"email": "kudryashova_liliya031979@postgrespro.ru", "phone": "+70426276175"}
0005434480968	9F7C68	4114 670085	NIKOLAY ZAKHAROV	{"phone": "+70863010072"}
0005434480969	9F7C68	3285 163172	VERA FILATOVA	{"phone": "+70132394212"}
0005434480970	C41ADC	8959 960632	VIKTOR IVANOV	{"email": "viktor-ivanov.1959@postgrespro.ru", "phone": "+70591608668"}
0005434480971	054636	1915 299732	YURIY PETROV	{"email": "y_petrov-12051979@postgrespro.ru", "phone": "+70044028077"}
0005434480972	73F80B	7748 064493	VERA ALEKSEEVA	{"email": "alekseevavera051976@postgrespro.ru", "phone": "+70168895360"}
0005434480973	73F80B	4495 172190	GALINA YUDINA	{"phone": "+70986857839"}
0005434480974	AAAF58	6880 848165	ALEFTINA GUSEVA	{"email": "gusevaaleftina041959@postgrespro.ru", "phone": "+70232120785"}
0005434480975	AAAF58	5872 999564	ELENA KUZNECOVA	{"phone": "+70959793055"}
0005434480976	8B82E3	7052 082256	DMITRIY SMIRNOV	{"phone": "+70687461128"}
0005434480977	CFCF49	7350 767787	NINA MOROZOVA	{"email": "morozova-n_30071981@postgrespro.ru", "phone": "+70773391384"}
0005434480978	CFCF49	3044 513485	VADIM KUZMIN	{"phone": "+70837257365"}
0005434480979	D4CCA5	4341 615002	NELLI KUDRYASHOVA	{"phone": "+70268592353"}
0005434480980	D4CCA5	8712 052976	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr_05081979@postgrespro.ru", "phone": "+70375274509"}
0005434480981	BA17AA	7483 444934	TATYANA KUZMINA	{"email": "kuzmina.t011981@postgrespro.ru", "phone": "+70304945091"}
0005434480982	80621B	9961 617963	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov-011965@postgrespro.ru", "phone": "+70497967625"}
0005434480983	C3CA35	1334 420517	GULNARA ROMANOVA	{"email": "gulnara_romanova1971@postgrespro.ru", "phone": "+70657896491"}
0005434480984	C3CA35	1514 254948	OLGA BELOVA	{"email": "olga-belova-1984@postgrespro.ru", "phone": "+70288230086"}
0005434480985	1342E8	2570 458898	YURIY MELNIKOV	{"email": "melnikov_y091975@postgrespro.ru", "phone": "+70321233292"}
0005434480986	928F2D	5033 262508	ANATOLIY SMIRNOV	{"phone": "+70116822625"}
0005434480987	928F2D	9512 703873	ANTON SOKOLOV	{"email": "sokolovanton_021975@postgrespro.ru", "phone": "+70237995075"}
0005434480988	928F2D	2838 942814	MIKHAIL MATVEEV	{"email": "mikhailmatveev19031986@postgrespro.ru", "phone": "+70261188306"}
0005434480989	30F8DE	0053 872099	MAKSIM MAKSIMOV	{"phone": "+70742998763"}
0005434480990	B1B980	1065 817494	ANDREY SIDOROV	{"phone": "+70951662381"}
0005434480991	5A4A47	9008 021031	ANDREY MARTYNOV	{"email": "a.martynov_111964@postgrespro.ru", "phone": "+70341095436"}
0005434480992	093EE1	7087 898763	ALEKSEY GAVRILOV	{"email": "gavrilov_aleksey.121966@postgrespro.ru", "phone": "+70907018932"}
0005434480993	E66FB6	2787 668509	VLADIMIR ISAEV	{"phone": "+70761233719"}
0005434480994	31470C	3687 790100	ARINA IVANOVA	{"email": "ivanova_arina_1976@postgrespro.ru", "phone": "+70258020217"}
0005434480995	8A9B17	4828 861381	TATYANA VASILEVA	{"email": "vasileva-t.09031979@postgrespro.ru", "phone": "+70110263937"}
0005434480996	69087B	4471 008881	BORIS STEPANOV	{"phone": "+70643578290"}
0005434480997	01DC3C	7195 388078	MIKHAIL NIKOLAEV	{"email": "mikhailnikolaev_101989@postgrespro.ru", "phone": "+70518844663"}
0005434480998	01DC3C	1194 087987	IRINA STEPANOVA	{"phone": "+70070060830"}
0005434480999	01DC3C	3199 541559	EVGENIYA AFANASEVA	{"phone": "+70795784192"}
0005434481000	E2B17D	1180 453431	NIKOLAY SERGEEV	{"phone": "+70424569087"}
0005434481001	81BC91	3495 781428	VLADIMIR GAVRILOV	{"email": "gavrilov_v_041975@postgrespro.ru", "phone": "+70069264299"}
0005434481002	C26EAA	1831 651200	FATIMA BELYAEVA	{"phone": "+70671820609"}
0005434481003	C26EAA	6565 179817	OLGA BELOVA	{"phone": "+70206364263"}
0005434481004	237A1C	4848 620306	DARYA KONDRATEVA	{"phone": "+70259297418"}
0005434481005	237A1C	4855 508829	LYUBOV GERASIMOVA	{"phone": "+70320440260"}
0005434481006	237A1C	7673 960044	NIKOLAY VLASOV	{"email": "vlasovnikolay.1976@postgrespro.ru", "phone": "+70308512850"}
0005434481007	2A8947	2841 996829	VALENTINA POPOVA	{"phone": "+70699613276"}
0005434481008	2A8947	4664 187653	RAFIK PAVLOV	{"email": "pavlov.rafik1967@postgrespro.ru", "phone": "+70057960180"}
0005434481009	8DE121	7040 805103	BOGDAN KUZNECOV	{"email": "b-kuznecov.14101979@postgrespro.ru", "phone": "+70410777245"}
0005434481010	8DE121	0546 264165	SERGEY KONOVALOV	{"phone": "+70799058820"}
0005434481011	22F5B1	1697 474622	ROMAN VLASOV	{"phone": "+70558224507"}
0005434481012	40EC3E	7086 034914	ULYANA SEMENOVA	{"email": "semenova_ulyana-1968@postgrespro.ru", "phone": "+70538185783"}
0005434481013	40EC3E	1408 771193	DMITRIY MIKHAYLOV	{"phone": "+70947600526"}
0005434481014	664115	5883 048160	NATALYA YUDINA	{"email": "n_yudina-1961@postgrespro.ru", "phone": "+70225956902"}
0005434481015	664115	1768 757353	SVETLANA YAKOVLEVA	{"email": "yakovleva-s-121976@postgrespro.ru", "phone": "+70981194746"}
0005434481016	BFF29D	9100 121738	GALINA GAVRILOVA	{"email": "gavrilova-galina-17101973@postgrespro.ru", "phone": "+70538411350"}
0005434481017	BFF29D	7411 524327	ALEKSEY FEDOROV	{"phone": "+70347066572"}
0005434481018	C26E6A	7135 132076	TATYANA LAZAREVA	{"email": "lazareva.t_20021974@postgrespro.ru", "phone": "+70644245240"}
0005434481019	3FB3DB	7444 150503	ALEKSANDR FEDOTOV	{"email": "a-fedotov011966@postgrespro.ru", "phone": "+70527400762"}
0005434481020	3FB3DB	8647 828134	ALLA FROLOVA	{"email": "frolova-alla21021980@postgrespro.ru", "phone": "+70798069758"}
0005434481021	633B71	5027 818301	ANNA ANDREEVA	{"phone": "+70070694208"}
0005434481022	70263E	2697 856461	RAISA NESTEROVA	{"email": "nesterova_raisa_021979@postgrespro.ru", "phone": "+70481023809"}
0005434481023	7BF3C9	7753 146063	ANDREY MOROZOV	{"phone": "+70073267349"}
0005434481024	892C65	9665 724212	OLGA OSIPOVA	{"email": "osipovaolga.1968@postgrespro.ru", "phone": "+70620476312"}
0005434481025	00D92E	7839 907243	ANDREY ZHURAVLEV	{"email": "zhuravlev.andrey.1979@postgrespro.ru", "phone": "+70372987524"}
0005434481026	BC9E54	7653 940037	NADEZHDA KUZMINA	{"email": "n_kuzmina.1978@postgrespro.ru", "phone": "+70970605567"}
0005434481027	905428	6667 335216	LIDIYA ANDREEVA	{"email": "l_andreeva_23051978@postgrespro.ru", "phone": "+70470967958"}
0005434481028	E0C23A	1900 827899	IVAN GAVRILOV	{"phone": "+70041807885"}
0005434481029	E0C23A	6830 308130	DARYA KISELEVA	{"email": "darya_kiseleva1973@postgrespro.ru", "phone": "+70544290399"}
0005434481030	95A1E6	3186 932504	VERA PETROVA	{"phone": "+70682878472"}
0005434481031	9FEEEA	2631 851996	VALENTINA OVCHINNIKOVA	{"email": "valentina_ovchinnikova.1981@postgrespro.ru", "phone": "+70694289549"}
0005434481032	9C32CA	6637 715077	DENIS BELOV	{"phone": "+70300128627"}
0005434481033	3251FE	4526 095838	SERGEY ILIN	{"email": "s_ilin-121963@postgrespro.ru", "phone": "+70933850264"}
0005434481034	3251FE	8375 432506	YULIYA MOROZOVA	{"email": "morozova-y021978@postgrespro.ru", "phone": "+70743895813"}
0005434481035	2E5965	7971 636932	ANDREY ANTONOV	{"phone": "+70185149627"}
0005434481036	2E5965	3814 077754	ANNA KUZNECOVA	{"email": "kuznecova-anna.1980@postgrespro.ru", "phone": "+70037833670"}
0005434481037	2E5965	3926 154443	NINA NIKOLAEVA	{"email": "nikolaevanina.091971@postgrespro.ru", "phone": "+70743116175"}
0005434481038	CAEBB3	7191 117807	LYUBOV ANDREEVA	{"email": "l.andreeva.30011963@postgrespro.ru", "phone": "+70859079490"}
0005434481039	CAEBB3	8143 489112	REGINA YAKOVLEVA	{"phone": "+70579361445"}
0005434481040	12602C	3341 825223	ALEKSEY CHERNOV	{"email": "achernov-1962@postgrespro.ru", "phone": "+70914640215"}
0005434481041	1F53DC	4173 815683	PAVEL TIMOFEEV	{"phone": "+70763707779"}
0005434481042	85DEAA	3206 258286	VALENTINA VASILEVA	{"phone": "+70708170109"}
0005434481043	85DEAA	9226 327803	VADIM KUDRYASHOV	{"email": "vadimkudryashov-1968@postgrespro.ru", "phone": "+70165821767"}
0005434481044	89479E	3643 087624	VALENTINA IVANOVA	{"email": "v.ivanova1969@postgrespro.ru", "phone": "+70746839154"}
0005434481045	9DDC5A	0708 146190	VALENTINA MIRONOVA	{"email": "mironova-v03121966@postgrespro.ru", "phone": "+70229265916"}
0005434481046	2ABE00	2895 829955	ANTONINA SOKOLOVA	{"phone": "+70469643439"}
0005434481047	7B9229	9923 110747	ALEKSANDR FROLOV	{"phone": "+70887415178"}
0005434481048	7B9229	4104 611495	LYUDMILA DAVYDOVA	{"phone": "+70677754676"}
0005434481049	E69F48	5244 742899	LARISA FROLOVA	{"email": "larisa-frolova-22021981@postgrespro.ru", "phone": "+70756944766"}
0005434481050	0E0934	2553 397225	ALEKSANDR MOROZOV	{"phone": "+70914062300"}
0005434481051	0E0934	2412 470488	NIKITA CHERNOV	{"email": "chernov_nikita051977@postgrespro.ru", "phone": "+70779275829"}
0005434481052	F516AB	2635 746529	IVAN GORBUNOV	{"phone": "+70049994485"}
0005434481053	78DF0C	3614 668305	VALENTINA KALININA	{"email": "valentinakalinina.091974@postgrespro.ru", "phone": "+70124532454"}
0005434481054	0ABE0E	2352 321540	ANDREY DENISOV	{"phone": "+70505069172"}
0005434481055	23300B	1130 152971	VLADIMIR ZHUKOV	{"phone": "+70834512172"}
0005434481056	23300B	3867 896289	VIKTOR KUZNECOV	{"phone": "+70313506775"}
0005434484231	92378D	7030 687057	TAMARA KUZMINA	{"phone": "+70494544194"}
0005434484232	92378D	8281 457925	LYUBOV ORLOVA	{"phone": "+70402692828"}
0005434484233	EDDE8D	1591 147272	NIKOLAY GORBUNOV	{"phone": "+70239727696"}
0005434484234	8D304A	0447 547397	ELENA SOROKINA	{"email": "e-sorokina_1966@postgrespro.ru", "phone": "+70843926577"}
0005434484235	8D304A	1516 424669	ANATOLIY NIKOLAEV	{"email": "anikolaev_19021978@postgrespro.ru", "phone": "+70842225562"}
0005434484236	CCF761	4537 752502	NATALYA ARKHIPOVA	{"phone": "+70706608330"}
0005434484237	5401F7	4340 080981	NATALYA KUDRYASHOVA	{"email": "kudryashova-natalya11101975@postgrespro.ru", "phone": "+70493592495"}
0005434484238	B36A63	5410 942448	VALENTINA KONOVALOVA	{"email": "konovalova-valentina.04091962@postgrespro.ru", "phone": "+70824079163"}
0005434484239	B36A63	7490 217157	VASILIY TARASOV	{"email": "vasiliy_tarasov.18091979@postgrespro.ru", "phone": "+70787697891"}
0005434484240	1F0C64	4572 449809	KONSTANTIN MOISEEV	{"phone": "+70909690436"}
0005434484241	1F0C64	6973 611103	ANDREY ZHUKOV	{"email": "a-zhukov.051966@postgrespro.ru", "phone": "+70966604040"}
0005434484242	08521F	6060 169782	VLADIMIR BELOV	{"email": "vladimir-belov_091962@postgrespro.ru", "phone": "+70122953277"}
0005434484243	08EFB3	6238 470293	SERGEY NAUMOV	{"phone": "+70535111365"}
0005434484244	08EFB3	0615 561726	GALINA FROLOVA	{"email": "frolovagalina29111954@postgrespro.ru", "phone": "+70766475175"}
0005434484245	64A037	2393 663461	LYUDMILA MARTYNOVA	{"phone": "+70782729925"}
0005434484246	64A037	8441 630628	SERGEY SMIRNOV	{"phone": "+70198940248"}
0005434484247	956D84	6404 293818	GALINA KUZNECOVA	{"phone": "+70581581213"}
0005434484248	79E94A	0471 422580	ALEKSANDR KOZLOV	{"email": "kozlov_a-041970@postgrespro.ru", "phone": "+70187591305"}
0005434484249	219387	9552 139042	ALINA MELNIKOVA	{"email": "a.melnikova021970@postgrespro.ru", "phone": "+70967092967"}
0005434484250	2ACB67	7769 045869	NATALYA TITOVA	{"phone": "+70999650121"}
0005434484251	2ACB67	8396 057705	OLGA PETROVA	{"phone": "+70611136782"}
0005434484252	2F99FC	8886 805180	MAKSIM ISAEV	{"phone": "+70302671084"}
0005434484253	80DE60	1753 729266	ELENA KOVALEVA	{"email": "elena-kovaleva16121977@postgrespro.ru", "phone": "+70346622227"}
0005434484254	80DE60	8582 652952	ANZHELIKA TARASOVA	{"email": "tarasova-a_1969@postgrespro.ru", "phone": "+70480060119"}
0005434484255	79546C	3615 883419	DANILA MOROZOV	{"phone": "+70704274791"}
0005434484256	79546C	6118 815125	ALEKSANDR SOROKIN	{"phone": "+70357037488"}
0005434484257	79546C	4977 180035	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1971@postgrespro.ru", "phone": "+70061001774"}
0005434484258	82D7D4	8603 755445	LYUBOV TARASOVA	{"email": "tarasova-l_081969@postgrespro.ru", "phone": "+70058594303"}
0005434484259	2DD184	3781 397694	IRINA KRASNOVA	{"phone": "+70507094365"}
0005434484260	A50861	3343 196983	ALINA VOLKOVA	{"phone": "+70052496301"}
0005434484261	E00C8A	5102 522122	SVETLANA TROFIMOVA	{"phone": "+70933777665"}
0005434484262	BADF28	4568 102088	ZOYA SMIRNOVA	{"phone": "+70726099333"}
0005434484263	BADF28	3316 654975	YULIYA MIRONOVA	{"email": "mironova.yuliya061971@postgrespro.ru", "phone": "+70409916772"}
0005434484264	BA1AB1	7835 653598	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov-1970@postgrespro.ru", "phone": "+70047434022"}
0005434484265	2EB408	4078 018457	MARIYA KAZAKOVA	{"phone": "+70680002751"}
0005434484266	A1EC36	2322 425911	DARYA DMITRIEVA	{"phone": "+70481630694"}
0005434484267	0BBCB7	7844 330045	GEORGIY ZHURAVLEV	{"email": "zhuravlev-georgiy-23101973@postgrespro.ru", "phone": "+70109609922"}
0005434484268	C967C6	7805 278572	SVETLANA FROLOVA	{"email": "frolova.svetlana.24061976@postgrespro.ru", "phone": "+70965657173"}
0005434484269	7D6549	8050 565298	DAMIR VASILEV	{"phone": "+70781447643"}
0005434484270	0F455A	1238 807184	ANNA KAZAKOVA	{"email": "a-kazakova.08071972@postgrespro.ru", "phone": "+70498301053"}
0005434484271	8CFA33	2234 771933	IRINA EFIMOVA	{"email": "efimova-i01121962@postgrespro.ru", "phone": "+70964389837"}
0005434484272	7A9B27	4181 014541	MARINA KOZLOVA	{"email": "kozlovam-1965@postgrespro.ru", "phone": "+70964248835"}
0005434484273	7A9B27	5109 928469	LYUBOV MOROZOVA	{"phone": "+70925769758"}
0005434484274	C17634	0671 742107	ELENA KUDRYASHOVA	{"phone": "+70546943743"}
0005434484275	C17634	2155 375087	VLADIMIR SERGEEV	{"email": "sergeev.vladimir_05111977@postgrespro.ru", "phone": "+70540248218"}
0005434484276	2CBEA8	2173 772533	ALSU STEPANOVA	{"phone": "+70071705858"}
0005434484277	4BA049	1430 310416	NURIYA POPOVA	{"phone": "+70930495271"}
0005434484278	143F31	6681 738181	OLGA KUZNECOVA	{"phone": "+70230953409"}
0005434484279	8D6981	5834 915553	ELENA NOVIKOVA	{"phone": "+70121134116"}
0005434484280	09CCBB	2279 635718	DMITRIY MATVEEV	{"email": "matveev_d.1978@postgrespro.ru", "phone": "+70495722712"}
0005434484281	09CCBB	9571 341421	NIKOLAY NOVIKOV	{"phone": "+70993817633"}
0005434484282	464754	5333 139956	ZINAIDA KONOVALOVA	{"email": "konovalova-z_091970@postgrespro.ru", "phone": "+70574141823"}
0005434484283	1D69D0	9089 378207	LYUDMILA AKIMOVA	{"phone": "+70655680531"}
0005434484284	8082CE	1750 254748	IVAN MOROZOV	{"email": "morozovivan_091963@postgrespro.ru", "phone": "+70889979478"}
0005434484285	CCADD8	2563 905319	DENIS ANDREEV	{"email": "andreevdenis.02101962@postgrespro.ru", "phone": "+70877573328"}
0005434484286	57C525	1362 197836	VALENTINA KUDRYASHOVA	{"email": "kudryashovav_28111975@postgrespro.ru", "phone": "+70026400702"}
0005434484287	57C525	5119 635907	VYACHESLAV NIKOLAEV	{"email": "vnikolaev_28051977@postgrespro.ru", "phone": "+70371662858"}
0005434484288	3BEC07	5454 863192	ARTEM GAVRILOV	{"email": "gavrilov-a011979@postgrespro.ru", "phone": "+70111342498"}
0005434484289	3BEC07	0194 348075	ANVAR SAVELEV	{"email": "a_savelev.1977@postgrespro.ru", "phone": "+70350859667"}
0005434484290	00D240	5493 473436	DANIIL ANTONOV	{"email": "antonovd.06111966@postgrespro.ru", "phone": "+70922135898"}
0005434484291	00D240	9085 707658	OLGA EGOROVA	{"email": "o.egorova_1977@postgrespro.ru", "phone": "+70682068115"}
0005434484292	5B5747	4366 157193	ANASTASIYA DANILOVA	{"email": "anastasiya_danilova_20011981@postgrespro.ru", "phone": "+70603340087"}
0005434484293	5B5747	4723 064638	ELEONORA ZHUKOVA	{"email": "zhukova_eleonora22041971@postgrespro.ru", "phone": "+70157059197"}
0005434484294	AB71C5	6454 405046	MARAT KULIKOV	{"email": "kulikov.marat031980@postgrespro.ru", "phone": "+70966719711"}
0005434484295	AB71C5	3987 368222	DENIS KUZMIN	{"phone": "+70894090549"}
0005434484296	9DC064	4818 539164	IRINA CHERNOVA	{"email": "chernovairina.1974@postgrespro.ru", "phone": "+70795380467"}
0005434484297	D1C55D	7215 673692	VIKTOR MOISEEV	{"email": "moiseevv_1983@postgrespro.ru", "phone": "+70044170652"}
0005434484298	52BC5B	8301 391511	SVETLANA ORLOVA	{"phone": "+70905152422"}
0005434484299	52BC5B	5155 305685	ALEKSEY FEDOROV	{"phone": "+70478098273"}
0005434484300	E1E920	5923 473602	PAVEL FEDOTOV	{"phone": "+70396981132"}
0005434484301	8B9A0C	2630 259094	OLGA SMIRNOVA	{"email": "o-smirnova091965@postgrespro.ru", "phone": "+70427729601"}
0005434484302	E30637	0088 239653	EKATERINA SERGEEVA	{"email": "e.sergeeva_1971@postgrespro.ru", "phone": "+70510507690"}
0005434484303	E30637	7902 145054	IRINA TITOVA	{"phone": "+70881095268"}
0005434484304	8EF609	6960 665854	VERA FOMINA	{"phone": "+70452772131"}
0005434484305	8EF609	0548 183691	MAKSIM ANTONOV	{"phone": "+70153961718"}
0005434484306	8EF609	3238 886312	EVGENIYA NESTEROVA	{"phone": "+70519816342"}
0005434484307	314AF0	1002 544760	ARTUR GORBUNOV	{"email": "arturgorbunov27021977@postgrespro.ru", "phone": "+70182513505"}
0005434484308	A210C5	0884 308031	EVGENIYA CHERNOVA	{"email": "e-chernova.121960@postgrespro.ru", "phone": "+70323650564"}
0005434484309	D33DFF	1528 319310	TAMARA ALEKSEEVA	{"phone": "+70643864222"}
0005434484310	D33DFF	1220 806195	ROZA KUZNECOVA	{"email": "kuznecovaroza.22051990@postgrespro.ru", "phone": "+70231898113"}
0005434484311	82DEAE	6826 512083	EVGENIY KONOVALOV	{"phone": "+70115561420"}
0005434484312	39CE5E	5248 939362	NADEZHDA DAVYDOVA	{"phone": "+70865373593"}
0005434484313	F414E5	8756 122391	ANDREY IVANOV	{"phone": "+70290697815"}
0005434484314	271AE0	3007 834316	EVGENIY NIKOLAEV	{"phone": "+70156518002"}
0005434484315	6C0B11	1059 326746	YULIYA CHERNOVA	{"email": "chernova-yuliya-101965@postgrespro.ru", "phone": "+70802383255"}
0005434484316	6C0B11	0916 582520	VIKTORIYA PETROVA	{"email": "viktoriya_petrova-1971@postgrespro.ru", "phone": "+70689541682"}
0005434484317	A52977	8901 368182	DMITRIY STEPANOV	{"phone": "+70264305747"}
0005434484318	A52977	9629 225211	ALEKSANDR NIKOLAEV	{"phone": "+70323545572"}
0005434484319	A52977	8539 570138	LYUBOV DENISOVA	{"phone": "+70299253496"}
0005434484320	EFDB89	1799 315587	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov-1962@postgrespro.ru", "phone": "+70246705525"}
0005434484321	EFDB89	6410 881761	ANNA ZHURAVLEVA	{"phone": "+70721473282"}
0005434484322	952623	9639 929526	ALIYA MOROZOVA	{"phone": "+70045261439"}
0005434484323	09CE93	3563 455146	DARYA MIRONOVA	{"email": "mironova-d021962@postgrespro.ru", "phone": "+70328564310"}
0005434484324	67D8E5	7369 545375	ANATOLIY SERGEEV	{"email": "sergeev_anatoliy_1986@postgrespro.ru", "phone": "+70115923801"}
0005434484325	99EB6B	6315 552888	ALEKSEY KOZLOV	{"phone": "+70190364849"}
0005434484326	99EB6B	7338 507341	YULIYA RYABOVA	{"email": "ryabova.yuliya1973@postgrespro.ru", "phone": "+70891315940"}
0005434484327	543FB7	4768 987841	ALEKSANDR KUZNECOV	{"phone": "+70285260893"}
0005434484328	DC4331	8330 196832	ELENA MOROZOVA	{"email": "morozovae.031970@postgrespro.ru", "phone": "+70767257849"}
0005434484329	2E992A	5758 424991	ANATOLIY STEPANOV	{"email": "stepanov.anatoliy_111970@postgrespro.ru", "phone": "+70461539751"}
0005434484330	666FF3	5755 858889	LYUBOV KONOVALOVA	{"phone": "+70761822231"}
0005434484331	221697	7361 551900	VASILIY VASILEV	{"phone": "+70594909312"}
0005434484332	812342	3459 903709	TATYANA MAKSIMOVA	{"phone": "+70470650112"}
0005434484333	FF155D	0469 971858	ANNA VASILEVA	{"email": "vasileva-anna-08071976@postgrespro.ru", "phone": "+70393006622"}
0005434484334	7D6EF5	1797 410656	PAVEL KISELEV	{"email": "kiselev-p.25101976@postgrespro.ru", "phone": "+70963177921"}
0005434484335	B79543	0348 253984	FEDOR SCHERBAKOV	{"phone": "+70091250274"}
0005434484336	8A4CE3	4223 376948	MARIYA SOROKINA	{"phone": "+70429813112"}
0005434484337	FB284D	5107 072057	SERGEY NIKOLAEV	{"phone": "+70370635311"}
0005434484338	34A6FE	4884 477081	LYUDMILA KOROLEVA	{"phone": "+70446554034"}
0005434484339	4A6A7B	7156 424207	VALENTINA MOROZOVA	{"phone": "+70001894814"}
0005434484340	6EC1E0	9454 174947	ANDREY PETROV	{"phone": "+70669330401"}
0005434484341	0D1CBF	9567 067908	NIKOLAY CHERNOV	{"email": "n_chernov011969@postgrespro.ru", "phone": "+70151422695"}
0005434484342	0D1CBF	9585 028669	ALEKSANDR MAKSIMOV	{"phone": "+70098481525"}
0005434484343	2D182D	9780 968929	ANGELINA AFANASEVA	{"email": "afanaseva.a-16021974@postgrespro.ru", "phone": "+70485788083"}
0005434484344	27142D	8198 972945	VLADIMIR DENISOV	{"phone": "+70436639124"}
0005434484345	902502	1310 723677	ARINA AKIMOVA	{"phone": "+70272064524"}
0005434484346	36F9DB	1075 403518	MIKHAIL FOMIN	{"email": "mikhail-fomin_1972@postgrespro.ru", "phone": "+70595536085"}
0005434484347	59FD46	4966 218851	ANASTASIYA GORBUNOVA	{"email": "a.gorbunova.21111982@postgrespro.ru", "phone": "+70745294216"}
0005434484348	DB2D08	1670 716697	TATYANA ALEKSEEVA	{"email": "talekseeva.011972@postgrespro.ru", "phone": "+70605501588"}
0005434484349	97AB0B	4090 257767	RAISA MAKAROVA	{"email": "makarovaraisa-12031978@postgrespro.ru", "phone": "+70769369818"}
0005434484350	97AB0B	1161 350528	VALERIY GAVRILOV	{"email": "gavrilov-valeriy.1966@postgrespro.ru", "phone": "+70470061725"}
0005434484351	61EAA7	7011 130683	VALERIY PETROV	{"email": "petrov-valeriy.1977@postgrespro.ru", "phone": "+70550278667"}
0005434484352	2ACB40	2614 158251	ALEKSEY KONOVALOV	{"email": "konovalov.a_1973@postgrespro.ru", "phone": "+70041616716"}
0005434484353	44FF7E	2765 651003	MARINA RODIONOVA	{"phone": "+70948965399"}
0005434484354	44FF7E	1063 882246	VLADISLAV ANTONOV	{"email": "vladislav.antonov031970@postgrespro.ru", "phone": "+70629677567"}
0005434484355	4FFD2C	6974 039569	OLGA BELOVA	{"email": "olgabelova121964@postgrespro.ru", "phone": "+70778823573"}
0005434484356	3A35C3	0674 128871	GALINA POPOVA	{"phone": "+70025878859"}
0005434484357	025130	5588 245469	ELEONORA PAVLOVA	{"phone": "+70209000453"}
0005434484358	025130	7159 551497	STEPAN YAKOVLEV	{"email": "stepan_yakovlev_1970@postgrespro.ru", "phone": "+70606203450"}
0005434484359	2261B7	5462 551954	SERGEY KISELEV	{"email": "kiselev.s_10091968@postgrespro.ru", "phone": "+70120186050"}
0005434484360	72B918	2423 171522	VERA NOVIKOVA	{"phone": "+70459045639"}
0005434484361	72B918	5364 630108	VALENTINA GUSEVA	{"email": "guseva-valentina-1966@postgrespro.ru", "phone": "+70814107970"}
0005434484362	E487EC	2390 092501	DARYA NIKITINA	{"email": "nikitina_darya_1969@postgrespro.ru", "phone": "+70068915730"}
0005434484363	2EF70E	9673 968217	IRINA SIDOROVA	{"email": "sidorova.i.13111968@postgrespro.ru", "phone": "+70434874297"}
0005434484364	E9A151	9910 640430	ARTEM RODIONOV	{"email": "rodionov_artem_12021969@postgrespro.ru", "phone": "+70403022982"}
0005434484365	E9A151	9946 926450	SVETLANA TARASOVA	{"email": "tarasova.s_15041969@postgrespro.ru", "phone": "+70951323269"}
0005434484366	C67C14	6123 090441	GALINA IVANOVA	{"phone": "+70696121294"}
0005434484367	E4E4ED	3962 413543	SVETLANA ROMANOVA	{"phone": "+70901211656"}
0005434484368	393976	5026 847621	GALINA YAKOVLEVA	{"phone": "+70164510303"}
0005434484369	80C694	6024 448602	RUSTAM IVANOV	{"email": "rustam-ivanov_13041979@postgrespro.ru", "phone": "+70837483031"}
0005434484370	BBF04D	2000 489178	TATYANA KOZLOVA	{"email": "kozlova_tatyana081967@postgrespro.ru", "phone": "+70484925470"}
0005434484371	7A3952	6833 466249	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey061969@postgrespro.ru", "phone": "+70865669383"}
0005434484372	7A3952	4184 705727	DENIS KUZNECOV	{"phone": "+70507435354"}
0005434484373	634A7D	5317 266842	RUSLAN STEPANOV	{"phone": "+70399792271"}
0005434484374	634A7D	4606 870367	ALENA SOKOLOVA	{"email": "sokolovaalena.27101971@postgrespro.ru", "phone": "+70296723666"}
0005434484375	A4D4B6	7957 646788	RUFINA ABRAMOVA	{"email": "abramova_rufina_01051965@postgrespro.ru", "phone": "+70517149966"}
0005434484376	A4D4B6	6083 040730	TAGIR MAKAROV	{"email": "makarovtagir_08021982@postgrespro.ru", "phone": "+70660269834"}
0005434484377	A4D4B6	8431 691519	RAIL SAVELEV	{"email": "r.savelev.101972@postgrespro.ru", "phone": "+70698186389"}
0005434484378	7AE2B1	3296 497089	NATALYA GERASIMOVA	{"phone": "+70884491643"}
0005434484379	7AE2B1	1831 407896	TATYANA ANTONOVA	{"phone": "+70426690097"}
0005434484380	AED5DE	7748 658157	GENNADIY EGOROV	{"email": "gegorov101981@postgrespro.ru", "phone": "+70273094811"}
0005434484381	E0246C	0782 880586	NADEZHDA ANISIMOVA	{"phone": "+70378901287"}
0005434484382	6D4A86	6658 627881	MIKHAIL NAZAROV	{"phone": "+70829496390"}
0005434484383	50639B	1633 036363	MARIYA DMITRIEVA	{"phone": "+70221164461"}
0005434484384	50639B	1166 663948	IVAN MIRONOV	{"phone": "+70607230054"}
0005434484385	669388	7483 303725	EKATERINA VOLKOVA	{"email": "ekaterinavolkova-1974@postgrespro.ru", "phone": "+70907302366"}
0005434484386	21EBB6	9350 937643	IVAN STEPANOV	{"email": "stepanov.ivan_1964@postgrespro.ru", "phone": "+70219311891"}
0005434484387	8C117B	2126 830362	NATALYA DAVYDOVA	{"phone": "+70086821664"}
0005434484388	4D0545	7983 046978	MIKHAIL TARASOV	{"email": "mikhail-tarasov.051973@postgrespro.ru", "phone": "+70403133375"}
0005434484389	3C5F2C	4235 167053	NIKITA STEPANOV	{"phone": "+70685176770"}
0005434484390	EAAD6A	2535 031918	SOFYA MOISEEVA	{"phone": "+70086892803"}
0005434484391	C7065B	4640 440247	NADEZHDA DAVYDOVA	{"phone": "+70971682505"}
0005434484392	262FA4	1734 438725	NINA SERGEEVA	{"email": "nina_sergeeva04121966@postgrespro.ru", "phone": "+70011428475"}
0005434484393	262FA4	7548 891846	ALENA GAVRILOVA	{"email": "a-gavrilova_091966@postgrespro.ru", "phone": "+70457890138"}
0005434484394	3BA657	0524 579745	ALIK POPOV	{"phone": "+70400226655"}
0005434484395	3BA657	8439 967071	ULYANA SIDOROVA	{"email": "sidorova.ulyana.1970@postgrespro.ru", "phone": "+70649470623"}
0005434484396	AA0CBF	1504 217126	YURIY SHEVCHENKO	{"phone": "+70302277876"}
0005434484397	AA0CBF	6837 122787	GALINA FEDOROVA	{"email": "fedorova.g_1962@postgrespro.ru", "phone": "+70566403389"}
0005434484398	A3618C	2323 060731	TATYANA FROLOVA	{"email": "frolova_t-03071981@postgrespro.ru", "phone": "+70201529183"}
0005434484399	E042A1	9738 170577	ALEKSEY FILIPPOV	{"email": "a_filippov-081967@postgrespro.ru", "phone": "+70482725835"}
0005434484400	076584	3052 095717	LYUDMILA TIMOFEEVA	{"email": "timofeeva-l_04011971@postgrespro.ru", "phone": "+70867463295"}
0005434484401	076584	2731 659435	YAKOV RODIONOV	{"phone": "+70260032912"}
0005434484402	BDFD2F	0560 090232	DMITRIY SIDOROV	{"phone": "+70937420154"}
0005434484403	BDFD2F	1245 169106	DMITRIY FILIPPOV	{"email": "filippovdmitriy-1979@postgrespro.ru", "phone": "+70177847907"}
0005434484404	51714A	3466 921520	EVGENIY ILIN	{"email": "iline_29051969@postgrespro.ru", "phone": "+70156114971"}
0005434484405	51714A	1135 800697	ALEKSANDRA ABRAMOVA	{"phone": "+70674347481"}
0005434484406	6CA0AE	2781 261053	OLGA ALEKSEEVA	{"email": "alekseeva-o-1982@postgrespro.ru", "phone": "+70360842881"}
0005434484407	34D649	4472 493757	ANASTASIYA FROLOVA	{"phone": "+70149643424"}
0005434484408	34D649	1814 734379	ALEKSANDR IVANOV	{"phone": "+70265487172"}
0005434484409	DA7368	7768 307455	ARINA KOROLEVA	{"email": "arina.koroleva.091973@postgrespro.ru", "phone": "+70076753260"}
0005434484410	74B65E	1277 010050	GALINA KUZNECOVA	{"phone": "+70343872483"}
0005434484411	D3ABA4	1076 648149	PAVEL NAUMOV	{"email": "pavel.naumov-18011964@postgrespro.ru", "phone": "+70190736794"}
0005434484412	D3ABA4	1390 063209	SERGEY SMIRNOV	{"phone": "+70940465583"}
0005434484413	89DA5D	6972 147420	LARISA GORBUNOVA	{"phone": "+70323229282"}
0005434484414	E3D0EF	7131 643175	SERGEY IVANOV	{"phone": "+70822811706"}
0005434484415	A9F185	0186 698177	EVGENIY IVANOV	{"email": "e.ivanov-04041974@postgrespro.ru", "phone": "+70554697264"}
0005434484416	A9F185	5328 621685	RIMMA MARTYNOVA	{"email": "martynova.rimma-15091988@postgrespro.ru", "phone": "+70947705683"}
0005434484417	A115DC	9774 167143	TAMARA TARASOVA	{"email": "tarasova_tamara-1992@postgrespro.ru", "phone": "+70148340061"}
0005434484418	649880	6551 332023	ALEKSEY PETROV	{"email": "aleksey.petrov19061966@postgrespro.ru", "phone": "+70796348559"}
0005434484419	DDCABC	6068 556356	TATYANA VOLKOVA	{"phone": "+70571123551"}
0005434484420	E3288D	3427 296440	NINA NAZAROVA	{"phone": "+70688132153"}
0005434484421	8B2092	2827 094503	ELENA GORBUNOVA	{"email": "elenagorbunova_03021963@postgrespro.ru", "phone": "+70391229131"}
0005434484422	1219D3	6474 360539	VALENTIN ROMANOV	{"phone": "+70232464893"}
0005434484423	F78E55	4406 166364	VIKTOR TIKHONOV	{"email": "tikhonov_viktor21111973@postgrespro.ru", "phone": "+70027392428"}
0005434484424	F78E55	9950 340470	ALEKSEY IVANOV	{"email": "alekseyivanov-011960@postgrespro.ru", "phone": "+70382029525"}
0005434484425	8CBB3A	6434 772792	VLADIMIR POPOV	{"phone": "+70338244045"}
0005434484426	96B3C4	6865 287986	NIKITA IVANOV	{"phone": "+70317431711"}
0005434484427	96B3C4	0265 474186	GLEB NIKOLAEV	{"email": "nikolaev_gleb-1965@postgrespro.ru", "phone": "+70089825792"}
0005434484428	7C632C	8249 138129	VERA TARASOVA	{"phone": "+70392808364"}
0005434484429	7C632C	3366 756567	STEPAN KONOVALOV	{"email": "stepan.konovalov-081974@postgrespro.ru", "phone": "+70778136172"}
0005434484430	98D539	7945 326119	TATYANA ANTONOVA	{"phone": "+70811348420"}
0005434484431	98D539	6600 661618	DAMIR ABRAMOV	{"phone": "+70938995874"}
0005434484432	8A1125	2515 946539	GALINA ARKHIPOVA	{"phone": "+70912724109"}
0005434484433	F9D72A	1938 192125	ALEKSANDR MAKAROV	{"email": "amakarov21071978@postgrespro.ru", "phone": "+70667549239"}
0005434484434	F9D72A	4354 081167	VALENTINA NESTEROVA	{"email": "vnesterova031965@postgrespro.ru", "phone": "+70884989350"}
0005434484435	E5E4CA	9271 056975	YURIY ISAEV	{"phone": "+70861525487"}
0005434484436	13ACE7	2800 449884	GALINA KOMAROVA	{"phone": "+70994029915"}
0005434484437	E5400E	4196 121385	ALEKSANDR ANTONOV	{"phone": "+70733972308"}
0005434484438	E0794C	7268 457811	LYUBOV CHERNOVA	{"phone": "+70532243554"}
0005434484439	EA333C	2486 974277	VASILIY VASILEV	{"email": "vasilev-vasiliy-1981@postgrespro.ru", "phone": "+70692728001"}
0005434484440	5B5E19	9569 239904	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov.21091986@postgrespro.ru", "phone": "+70882670325"}
0005434484441	5B5E19	8788 537957	NATALYA SOKOLOVA	{"email": "nsokolova-09061969@postgrespro.ru", "phone": "+70285113868"}
0005434484442	184CA4	3129 511129	ALEKSANDR MOISEEV	{"phone": "+70558782592"}
0005434484443	33CC56	8499 256315	DMITRIY SERGEEV	{"email": "dmitriy_sergeev-08101965@postgrespro.ru", "phone": "+70742363084"}
0005434484444	05494F	4721 802664	EVGENIY POPOV	{"email": "e-popov-101978@postgrespro.ru", "phone": "+70925703628"}
0005434484445	05494F	0246 031514	LYUDMILA MATVEEVA	{"phone": "+70722893348"}
0005434484446	4DE888	6581 610030	ALEKSANDR FOMIN	{"phone": "+70804991280"}
0005434484447	4DE888	2669 371484	IRINA FOMINA	{"phone": "+70829932780"}
0005434484448	16B5BD	8479 454494	NINA NIKOLAEVA	{"phone": "+70494751234"}
0005434484449	16B5BD	6013 285711	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova.17021975@postgrespro.ru", "phone": "+70756898186"}
0005434484450	F0EB41	8045 555021	VLADIMIR KAZAKOV	{"phone": "+70739660887"}
0005434484451	57ADC9	8207 402071	ANTON SIDOROV	{"phone": "+70259673933"}
0005434484452	ED7D29	0687 583601	VALERIY NAZAROV	{"email": "valeriy-nazarov-031974@postgrespro.ru", "phone": "+70866505486"}
0005434484453	ED7D29	7212 824517	SERGEY SERGEEV	{"email": "sergeev-s_081970@postgrespro.ru", "phone": "+70307846857"}
0005434484454	4FE7DE	3729 370956	GLEB EGOROV	{"email": "egorovgleb-25051971@postgrespro.ru", "phone": "+70451123001"}
0005434484455	4FE7DE	0636 574835	SERGEY VOROBEV	{"phone": "+70535381576"}
0005434484456	4FE7DE	6633 907454	ALINA NOVIKOVA	{"phone": "+70119431292"}
0005434484457	60F944	8143 239962	SERGEY ILIN	{"email": "ilin-sergey_081975@postgrespro.ru", "phone": "+70265328954"}
0005434484458	D90602	5724 266845	VLADIMIR NOVIKOV	{"phone": "+70075089816"}
0005434484459	D90602	5728 761703	SERGEY MAKSIMOV	{"phone": "+70986312376"}
0005434484460	D6D4DA	7639 074819	SVETLANA ZHUKOVA	{"email": "zhukova.svetlana.051974@postgrespro.ru", "phone": "+70574155066"}
0005434484461	DFDC3E	0142 946490	VALENTINA GRISHINA	{"phone": "+70653512593"}
0005434484462	DFDC3E	1405 400208	KLAVDIYA GORBUNOVA	{"phone": "+70131402892"}
0005434484463	F6C426	1654 215124	IVAN VOROBEV	{"phone": "+70602576955"}
0005434484464	AF05CA	4507 790706	MIKHAIL RODIONOV	{"email": "m.rodionov_071958@postgrespro.ru", "phone": "+70770909610"}
0005434484465	FB3D2B	0935 828138	ANASTASIYA NIKITINA	{"email": "nikitina.anastasiya-1978@postgrespro.ru", "phone": "+70582134319"}
0005434484466	843B2F	1879 726652	YURIY DMITRIEV	{"phone": "+70689180623"}
0005434484467	326F8C	3829 049818	ROMAN KONOVALOV	{"email": "konovalov-roman-091970@postgrespro.ru", "phone": "+70628895167"}
0005434484468	056E59	1275 219433	YULIYA TARASOVA	{"email": "y_tarasova1962@postgrespro.ru", "phone": "+70627412441"}
0005434484469	056E59	4130 564537	MIKHAIL ZAYCEV	{"email": "zaycevmikhail.29111967@postgrespro.ru", "phone": "+70180631624"}
0005434484470	FB6415	7026 914504	IRINA KUZNECOVA	{"phone": "+70782983174"}
0005434484471	880E41	4888 980361	ANZHELA TIMOFEEVA	{"phone": "+70068733981"}
0005434484472	22E790	3955 126341	YURIY MEDVEDEV	{"phone": "+70352380496"}
0005434484473	819231	1080 948532	TATYANA LAZAREVA	{"email": "t-lazareva-011986@postgrespro.ru", "phone": "+70436475440"}
0005434484474	082E6A	6258 305385	NATALYA BARANOVA	{"email": "natalyabaranova-10011976@postgrespro.ru", "phone": "+70571547607"}
0005434484475	082E6A	7458 489888	NINA AKIMOVA	{"phone": "+70388983811"}
0005434484476	C39E0A	9246 075370	ELENA MOROZOVA	{"email": "morozova_e_02101978@postgrespro.ru", "phone": "+70653710625"}
0005434484477	B6CE0C	6308 947093	ANATOLIY KOROLEV	{"email": "korolevanatoliy-031975@postgrespro.ru", "phone": "+70845852945"}
0005434484534	7EB1D1	3951 490565	MARIYA GAVRILOVA	{"phone": "+70473340924"}
0005434484478	3C113D	3317 421629	VITALIY KONOVALOV	{"email": "konovalov-v041974@postgrespro.ru", "phone": "+70261553708"}
0005434484479	FF426F	8279 740876	LYUDMILA ORLOVA	{"email": "orlova.l011983@postgrespro.ru", "phone": "+70045102220"}
0005434484480	B6292A	1595 322022	MARINA KOVALEVA	{"email": "mkovaleva1978@postgrespro.ru", "phone": "+70370568721"}
0005434484481	B6292A	8578 861163	VIKTORIYA POLYAKOVA	{"phone": "+70890327302"}
0005434484482	661CE2	8625 487798	LARISA TITOVA	{"email": "titova.larisa-091971@postgrespro.ru", "phone": "+70091406130"}
0005434484483	07B2F0	9038 293270	EKATERINA EGOROVA	{"phone": "+70904035966"}
0005434484484	CCED68	3710 916925	SERGEY MOISEEV	{"phone": "+70874750562"}
0005434484485	4B1F37	3663 844670	ARTEM SOROKIN	{"phone": "+70312391073"}
0005434484486	642423	0054 994186	GALINA SOKOLOVA	{"phone": "+70095311052"}
0005434484487	69EDAA	3687 430862	DARYA MAKAROVA	{"phone": "+70051327744"}
0005434484488	F3D901	9492 106745	LEONID KUZMIN	{"phone": "+70481940697"}
0005434484489	F3D901	9425 533624	ANASTASIYA YUDINA	{"email": "anastasiyayudina09051978@postgrespro.ru", "phone": "+70476699762"}
0005434484490	33B579	6503 844510	YURIY SERGEEV	{"email": "sergeev.y091974@postgrespro.ru", "phone": "+70154156901"}
0005434484491	C45712	1699 079630	EVGENIY MAKAROV	{"email": "e_makarov_1963@postgrespro.ru", "phone": "+70113295787"}
0005434484492	0CFC56	9293 496625	ALEKSANDR BARANOV	{"phone": "+70708981972"}
0005434484493	F19F5E	1134 240679	RUSTEM SAVELEV	{"phone": "+70658682466"}
0005434484494	7792FA	2963 005299	KONSTANTIN DENISOV	{"email": "konstantin_denisov-111971@postgrespro.ru", "phone": "+70907006233"}
0005434484495	7792FA	6044 588962	YULIYA SOROKINA	{"email": "sorokina_y.13121987@postgrespro.ru", "phone": "+70399396164"}
0005434484496	1BDFF8	5043 091638	DMITRIY SOROKIN	{"email": "dsorokin-091970@postgrespro.ru", "phone": "+70519270926"}
0005434484497	1BDFF8	7559 776978	INNA MAKAROVA	{"email": "i.makarova_08041966@postgrespro.ru", "phone": "+70109237797"}
0005434484498	986FC5	1183 497590	MARIYA MAKSIMOVA	{"email": "m_maksimova1977@postgrespro.ru", "phone": "+70304007909"}
0005434484499	986FC5	3156 586519	ANATOLIY DMITRIEV	{"email": "dmitrievanatoliy15101960@postgrespro.ru", "phone": "+70834923310"}
0005434484500	B9EFCC	8699 695364	ELIZAVETA DMITRIEVA	{"email": "dmitrievae.06051973@postgrespro.ru", "phone": "+70574779490"}
0005434484501	86B893	6787 808647	NATALIYA MARTYNOVA	{"phone": "+70499910612"}
0005434484502	86B893	2893 428629	SERGEY YAKOVLEV	{"email": "sergey-yakovlev_12011971@postgrespro.ru", "phone": "+70297838843"}
0005434484503	66726E	4823 047507	NINA AFANASEVA	{"email": "afanaseva_nina.23011967@postgrespro.ru", "phone": "+70865670024"}
0005434484504	66726E	2866 228093	ANNA PAVLOVA	{"email": "pavlova.a-1976@postgrespro.ru", "phone": "+70268292467"}
0005434484505	65B539	6986 985511	ANNA KOVALEVA	{"phone": "+70503989164"}
0005434484506	766D54	0732 332304	GALINA TARASOVA	{"email": "tarasovagalina_1970@postgrespro.ru", "phone": "+70847392209"}
0005434484507	766D54	1691 753449	ELENA ANTONOVA	{"phone": "+70573859179"}
0005434484508	B31225	7010 941847	TATYANA SOLOVEVA	{"email": "tatyana.soloveva-1968@postgrespro.ru", "phone": "+70767580217"}
0005434484509	4BDE4B	9436 046649	VIKTOR DENISOV	{"email": "denisov-v-121964@postgrespro.ru", "phone": "+70552081345"}
0005434484510	4BDE4B	6744 572038	VLADIMIR POPOV	{"email": "popov.vladimir-1971@postgrespro.ru", "phone": "+70875220761"}
0005434484511	F98774	3079 659527	YANA ANISIMOVA	{"phone": "+70716489192"}
0005434484512	5BFD9B	6398 315389	TATYANA FROLOVA	{"phone": "+70683651532"}
0005434484513	5BFD9B	5413 356991	VITALIY SEMENOV	{"email": "semenov-vitaliy.011968@postgrespro.ru", "phone": "+70102905571"}
0005434484514	5BFD9B	1986 735809	EKATERINA EGOROVA	{"phone": "+70091733155"}
0005434484515	4C98B4	8135 974880	ALEKSANDR ZAYCEV	{"email": "zaycev-aleksandr1967@postgrespro.ru", "phone": "+70430610809"}
0005434484516	895FBA	8819 720811	NINA IVANOVA	{"email": "ivanova.nina-21091967@postgrespro.ru", "phone": "+70346264925"}
0005434484517	61B644	4421 816324	KSENIYA PAVLOVA	{"email": "kseniya-pavlova1979@postgrespro.ru", "phone": "+70664695414"}
0005434484518	155ED6	8283 435585	TATYANA POPOVA	{"phone": "+70882738914"}
0005434484519	BE5419	1633 298770	VALERIY SOKOLOV	{"email": "sokolov.v061965@postgrespro.ru", "phone": "+70822422123"}
0005434484520	BE5419	8934 156016	ALEKSANDR NAUMOV	{"phone": "+70888822034"}
0005434484521	0D16EC	0881 513402	DMITRIY MOROZOV	{"email": "morozov_dmitriy_081967@postgrespro.ru", "phone": "+70012572933"}
0005434484522	40E822	1581 345318	TATYANA LEBEDEVA	{"phone": "+70457263530"}
0005434484523	31F4DA	5886 056988	MATVEY TARASOV	{"phone": "+70283910449"}
0005434484524	E534C3	7267 920813	OLEG VOLKOV	{"phone": "+70267294660"}
0005434484525	28C88B	1463 611635	LYUDMILA SEMENOVA	{"phone": "+70917145608"}
0005434484526	013294	5323 336556	VLADIMIR CHERNOV	{"email": "vladimirchernov_1982@postgrespro.ru", "phone": "+70333459223"}
0005434484527	8FDB24	7296 092625	MIKHAIL DAVYDOV	{"phone": "+70908019222"}
0005434484528	8FDB24	8097 901152	IRINA NOVIKOVA	{"phone": "+70950508434"}
0005434484529	35D3DC	1681 814277	NATALYA CHERNOVA	{"email": "chernova.n-1973@postgrespro.ru", "phone": "+70794239070"}
0005434484530	DD8E1A	7785 239930	ROMAN SEMENOV	{"phone": "+70167154758"}
0005434484531	6A8E47	3344 405500	VIKTORIYA AKIMOVA	{"phone": "+70254949152"}
0005434484532	6A8E47	5603 430262	GEORGIY NAUMOV	{"email": "naumov.georgiy-061975@postgrespro.ru", "phone": "+70351829475"}
0005434484533	7EB1D1	9788 621603	ROMAN KOZLOV	{"phone": "+70175807182"}
0005434484535	5D1678	9940 074218	ANNA NOVIKOVA	{"email": "anna.novikova-09101987@postgrespro.ru", "phone": "+70001687727"}
0005434484536	5D1678	7851 811453	EGOR DAVYDOV	{"phone": "+70534081785"}
0005434484537	4599C5	6125 448415	DAVID ALEKSANDROV	{"phone": "+70831468168"}
0005434484538	4599C5	2994 123159	LYUBOV IVANOVA	{"email": "ivanova-l011963@postgrespro.ru", "phone": "+70081036562"}
0005434484539	EE3C7B	3610 195641	TATYANA PAVLOVA	{"phone": "+70413128449"}
0005434484540	592175	9168 863739	KARINA OSIPOVA	{"phone": "+70638321486"}
0005434484541	A387A9	7669 170679	VALENTINA KOZLOVA	{"phone": "+70852824184"}
0005434484542	797792	9098 875947	YULIYA KUZMINA	{"phone": "+70537482369"}
0005434503458	391B8A	3541 089861	OLGA GUSEVA	{"email": "gusevao_26011980@postgrespro.ru", "phone": "+70847638246"}
0005434503459	1CB04B	9277 675414	MIKHAIL IVANOV	{"email": "ivanov-m-011979@postgrespro.ru", "phone": "+70474515713"}
0005434503460	1CB04B	7154 084395	VALENTINA NOVIKOVA	{"email": "novikova.valentina1960@postgrespro.ru", "phone": "+70041147689"}
0005434503461	7F691B	7683 951249	SVETLANA GAVRILOVA	{"email": "gavrilova.svetlana.30101978@postgrespro.ru", "phone": "+70021614522"}
0005434503462	7F691B	4155 215367	YURIY MAKSIMOV	{"email": "maksimov.y-1978@postgrespro.ru", "phone": "+70495168827"}
0005434503463	B751BC	3881 064655	IGOR GRIGOREV	{"email": "igrigorev15111966@postgrespro.ru", "phone": "+70293380999"}
0005434503464	B751BC	1760 128720	VALENTINA SERGEEVA	{"email": "v_sergeeva-1970@postgrespro.ru", "phone": "+70712626414"}
0005434503465	6BA07D	8832 672292	MARINA DENISOVA	{"email": "denisovam-051975@postgrespro.ru", "phone": "+70286331732"}
0005434503466	6BA07D	8817 908711	IRINA NOVIKOVA	{"email": "novikova_i1974@postgrespro.ru", "phone": "+70733930005"}
0005434503467	908B28	9353 295597	ALEKSANDR KRASNOV	{"email": "aleksandr-krasnov_13021978@postgrespro.ru", "phone": "+70411909302"}
0005434503468	908B28	3683 793357	VALENTINA IVANOVA	{"phone": "+70914549936"}
0005434503469	50D09C	7261 553589	ANTONINA ANDREEVA	{"email": "andreeva.a-21031969@postgrespro.ru", "phone": "+70680677983"}
0005434503470	618FCB	2641 163391	NATALIYA PETROVA	{"email": "petrova-n-061970@postgrespro.ru", "phone": "+70376153999"}
0005434503471	618FCB	3923 226006	MARIYA KOZLOVA	{"phone": "+70496093066"}
0005434503472	618FCB	2203 612556	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev_051966@postgrespro.ru", "phone": "+70998338172"}
0005434503473	41F7D0	6699 601007	OLGA MASLOVA	{"email": "maslova_o24061972@postgrespro.ru", "phone": "+70203354518"}
0005434503474	3CBD85	1067 740385	GUZEL YAKOVLEVA	{"phone": "+70484077324"}
0005434503475	3CBD85	9103 879845	MATVEY YAKOVLEV	{"phone": "+70466673148"}
0005434503476	CECE19	3078 356753	NIKOLAY KUZMIN	{"phone": "+70407094973"}
0005434503477	91BAEE	5921 139068	DENIS FOMIN	{"email": "dfomin-15091970@postgrespro.ru", "phone": "+70037426344"}
0005434503478	91BAEE	0207 944875	ROMAN KUZNECOV	{"phone": "+70101597720"}
0005434503479	7C4199	8654 642331	RODION MOROZOV	{"email": "rodion-morozov_22021974@postgrespro.ru", "phone": "+70128824083"}
0005434503480	7C4199	6779 912558	DMITRIY SOKOLOV	{"email": "dmitriy-sokolov_061968@postgrespro.ru", "phone": "+70982055894"}
0005434503481	7C4199	8639 404347	NIKOLAY AFANASEV	{"email": "n-afanasev.1966@postgrespro.ru", "phone": "+70595604971"}
0005434503482	4919BE	0626 925298	TATYANA FILIPPOVA	{"phone": "+70776036103"}
0005434503483	C7A588	7053 050982	EVGENIY BONDARENKO	{"email": "bondarenko.evgeniy14081973@postgrespro.ru", "phone": "+70497635424"}
0005434503484	2A22B2	9943 169604	GRIGORIY KOZLOV	{"email": "kozlovg17101966@postgrespro.ru", "phone": "+70031083178"}
0005434503485	031BC0	1925 890607	VALENTINA KRASNOVA	{"phone": "+70182372627"}
0005434503486	5E93F6	0819 100435	IRINA LAZAREVA	{"phone": "+70366211847"}
0005434503487	636E81	2476 551424	SERGEY MAKSIMOV	{"phone": "+70873182538"}
0005434503488	4471BB	2656 761003	ALENA KONOVALOVA	{"phone": "+70473452375"}
0005434503489	AA36B3	4936 142980	MIKHAIL DMITRIEV	{"email": "mdmitriev_1963@postgrespro.ru", "phone": "+70445422281"}
0005434503490	AA36B3	4831 109223	NADEZHDA ORLOVA	{"email": "nadezhda-orlova111968@postgrespro.ru", "phone": "+70871520235"}
0005434503491	E95F78	3923 253019	GALINA PAVLOVA	{"email": "pavlovagalina.1967@postgrespro.ru", "phone": "+70750744164"}
0005434503492	B1C232	2492 755512	ANATOLIY ORLOV	{"email": "anatoliy_orlov-13111957@postgrespro.ru", "phone": "+70272638385"}
0005434503493	6FFE97	7279 369929	IRINA SERGEEVA	{"phone": "+70974236630"}
0005434503494	6FFE97	9190 338709	RUSLAN GAVRILOV	{"email": "gavrilov-ruslan.04111971@postgrespro.ru", "phone": "+70351219258"}
0005434503495	BC4EFE	0427 845350	DANIIL FEDOTOV	{"email": "daniil.fedotov.021969@postgrespro.ru", "phone": "+70714020084"}
0005434503496	750336	6082 535069	SVETLANA DAVYDOVA	{"email": "svetlana.davydova_051970@postgrespro.ru", "phone": "+70610813488"}
0005434503497	B65A2E	7641 107315	ALEKSEY KUZNECOV	{"phone": "+70613991040"}
0005434503498	B65A2E	4740 496911	NIKOLAY KUZNECOV	{"email": "nkuznecov-1971@postgrespro.ru", "phone": "+70072875054"}
0005434503499	3B8A1B	8415 340711	EKATERINA LUKYANOVA	{"phone": "+70390493937"}
0005434503500	A06E72	3847 043527	MARAT SCHERBAKOV	{"phone": "+70042568821"}
0005434503501	A06E72	1453 935459	NATALYA ALEKSEEVA	{"phone": "+70638233024"}
0005434503502	FE004B	8322 124807	YULIYA VOLKOVA	{"phone": "+70287741136"}
0005434503503	FE004B	3647 622518	ALEKSANDRA KRASNOVA	{"email": "aleksandra-krasnova_23081973@postgrespro.ru", "phone": "+70686663051"}
0005434503504	C4DEF5	6932 480524	TAMARA GAVRILOVA	{"phone": "+70694213285"}
0005434503505	C4DEF5	0850 624390	ANDREY PAVLOV	{"phone": "+70198019059"}
0005434503506	C286E3	7794 527815	VLADIMIR KUZNECOV	{"phone": "+70732560260"}
0005434503507	0F7A2D	8373 618079	NIKOLAY ANTONOV	{"phone": "+70923676630"}
0005434503508	0F7A2D	4696 057899	YULIYA STEPANOVA	{"phone": "+70975660827"}
0005434503509	6FE37F	4910 214063	VYACHESLAV GRIGOREV	{"email": "vyacheslav.grigorev.24041973@postgrespro.ru", "phone": "+70430425875"}
0005434503510	6A767A	0839 517947	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_041975@postgrespro.ru", "phone": "+70355047661"}
0005434503511	6A767A	1196 738958	ALINA EFIMOVA	{"email": "efimova.alina-1978@postgrespro.ru", "phone": "+70245684447"}
0005434503512	084E0B	9927 506823	ELENA MIRONOVA	{"phone": "+70422604049"}
0005434503513	6E2D82	2541 830712	LIDIYA DAVYDOVA	{"phone": "+70819433948"}
0005434503514	6E2D82	4059 681764	MIKHAIL PAVLOV	{"phone": "+70421409868"}
0005434503515	633C90	2403 546481	ELENA IVANOVA	{"phone": "+70552973381"}
0005434503516	F2DE28	9364 746714	EVGENIY RODIONOV	{"email": "e.rodionov_01061959@postgrespro.ru", "phone": "+70667965598"}
0005434503517	E77A72	8796 860404	ANDREY ILIN	{"email": "ilin_a.14101980@postgrespro.ru", "phone": "+70565586880"}
0005434503518	D251F6	9836 193995	VIKTORIYA SOLOVEVA	{"email": "soloveva-viktoriya.05081964@postgrespro.ru", "phone": "+70061476111"}
0005434503519	D251F6	8364 958197	ALEKSANDR GUSEV	{"phone": "+70074854323"}
0005434503520	76557E	7932 007282	NINA KARPOVA	{"phone": "+70735585851"}
0005434503521	2B6CF1	2850 231330	MARIYA BELOVA	{"email": "belova.mariya.121977@postgrespro.ru", "phone": "+70302855625"}
0005434503522	C35F94	7251 817910	EKATERINA POPOVA	{"email": "e.popova29061976@postgrespro.ru", "phone": "+70810469096"}
0005434503523	C35F94	0312 016671	ELENA SMIRNOVA	{"phone": "+70731982562"}
0005434503524	C35F94	4082 281954	TATYANA BORISOVA	{"phone": "+70200295873"}
0005434503525	B960A0	8019 115579	MARAT POPOV	{"email": "popovmarat-03061972@postgrespro.ru", "phone": "+70388205981"}
0005434503526	C42D37	2884 593149	ANNA PETROVA	{"phone": "+70441204404"}
0005434503527	A67C5A	8043 087129	IRINA MOROZOVA	{"email": "morozovairina_22121980@postgrespro.ru", "phone": "+70172271262"}
0005434503528	6E2ED9	9840 809342	NINA FILIPPOVA	{"phone": "+70904900463"}
0005434503529	BBA6EE	0259 226187	MARINA KOROLEVA	{"phone": "+70484161480"}
0005434503530	BBA6EE	8700 418792	SERGEY BORISOV	{"phone": "+70565859244"}
0005434503531	E7B980	1390 139528	PAVEL ILIN	{"email": "ilin.pavel091967@postgrespro.ru", "phone": "+70202758296"}
0005434503532	0F8A16	0690 690463	TATYANA NIKIFOROVA	{"phone": "+70012422096"}
0005434503533	1C25B4	1067 642284	ANDREY SMIRNOV	{"email": "smirnova-04021983@postgrespro.ru", "phone": "+70924282131"}
0005434503534	2F33D3	9499 073401	ALEKSANDR VLASOV	{"phone": "+70659388552"}
0005434503535	2F33D3	8187 535895	VALERIY VOLKOV	{"phone": "+70898046997"}
0005434503536	2F33D3	0193 872416	SERGEY MIRONOV	{"email": "mironov_s_19011979@postgrespro.ru", "phone": "+70896431090"}
0005434503537	17886C	6406 147535	VLADIMIR NIKITIN	{"phone": "+70185584314"}
0005434503538	4700F1	9579 784950	VLADISLAV ROMANOV	{"email": "vladislav_romanov_02021964@postgrespro.ru", "phone": "+70264266079"}
0005434503539	A52617	5984 014092	ANASTASIYA ANDREEVA	{"email": "anastasiya.andreeva-061962@postgrespro.ru", "phone": "+70101306916"}
0005434503540	B8D79D	1894 053792	TATYANA TIKHONOVA	{"email": "tikhonova_tatyana_051969@postgrespro.ru", "phone": "+70799212913"}
0005434503541	B8D79D	9093 084922	YULIYA MAKAROVA	{"phone": "+70179693268"}
0005434503542	B8D79D	8019 495730	GENNADIY VASILEV	{"email": "vasilev_g-091966@postgrespro.ru", "phone": "+70095886245"}
0005434503543	121E73	5307 667489	DAVID KOROLEV	{"email": "korolev_d081960@postgrespro.ru", "phone": "+70770755188"}
0005434503544	E5D6CD	5023 776652	OLGA POPOVA	{"email": "o_popova.1970@postgrespro.ru", "phone": "+70979310166"}
0005434503545	E5D6CD	6664 414818	ALEKSEY BARANOV	{"phone": "+70072133519"}
0005434503546	E5D6CD	0743 998954	YURIY SHEVCHENKO	{"email": "y.shevchenko.29011961@postgrespro.ru", "phone": "+70494610901"}
0005434503547	56E93C	3531 503296	VITALIY KUZNECOV	{"email": "vitaliykuznecov.111964@postgrespro.ru", "phone": "+70674106328"}
0005434503548	FECBFC	4069 515959	NATALYA KUZNECOVA	{"phone": "+70443047114"}
0005434503549	FECBFC	9113 334739	YULIYA FEDOROVA	{"phone": "+70405877007"}
0005434503550	FECBFC	0978 687608	RAISA YAKOVLEVA	{"email": "yakovleva_raisa.1973@postgrespro.ru", "phone": "+70356384311"}
0005434503551	1A5C99	3655 519349	LYUDMILA SAVELEVA	{"email": "saveleva.lyudmila02061974@postgrespro.ru", "phone": "+70322045034"}
0005434503552	942E32	9799 167509	ANDREY PETROV	{"email": "petrovandrey-10021976@postgrespro.ru", "phone": "+70253311700"}
0005434503553	942E32	9130 684790	NINA POPOVA	{"email": "popova.n-1968@postgrespro.ru", "phone": "+70760422497"}
0005434503554	9D9986	4294 869569	TATYANA AKIMOVA	{"phone": "+70882455946"}
0005434503555	700E78	9957 459036	IRINA MAKSIMOVA	{"phone": "+70219096536"}
0005434503556	3841DB	8481 831210	OLGA PETROVA	{"phone": "+70626463499"}
0005434503557	3841DB	8227 904665	OLGA KUZNECOVA	{"email": "o_kuznecova041970@postgrespro.ru", "phone": "+70492583270"}
0005434503558	6D6676	1908 888506	ZOYA MELNIKOVA	{"email": "melnikovaz.051968@postgrespro.ru", "phone": "+70240092478"}
0005434503559	6D6676	0329 328245	ALEKSANDR MEDVEDEV	{"email": "medvedev.a_011973@postgrespro.ru", "phone": "+70821255363"}
0005434503560	FA0EC2	7664 481905	ANNA MOROZOVA	{"phone": "+70373975899"}
0005434503561	FA0EC2	9029 991596	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila.101971@postgrespro.ru", "phone": "+70235813294"}
0005434503562	CFCA41	4516 707876	DMITRIY POPOV	{"phone": "+70211327953"}
0005434503563	984829	8841 684954	TATYANA MELNIKOVA	{"email": "melnikovat_1973@postgrespro.ru", "phone": "+70380060114"}
0005434503564	984829	8145 836065	PAVEL POPOV	{"phone": "+70864544290"}
0005434503565	E05D20	8482 932642	ZINAIDA ANDREEVA	{"phone": "+70863603207"}
0005434503566	30E923	9227 055464	VERA TROFIMOVA	{"email": "v-trofimova-30041977@postgrespro.ru", "phone": "+70901646406"}
0005434503567	04EA3C	3465 073666	EKATERINA NESTEROVA	{"email": "ekaterina-nesterova101974@postgrespro.ru", "phone": "+70316907648"}
0005434503568	09DD28	3153 734259	SERGEY KONOVALOV	{"email": "skonovalov021972@postgrespro.ru", "phone": "+70807319480"}
0005434503569	FDCC75	1027 692629	KONSTANTIN MATVEEV	{"email": "matveev-konstantin-1978@postgrespro.ru", "phone": "+70208462388"}
0005434503570	FDCC75	0990 724022	NATALYA ALEKSEEVA	{"phone": "+70608350512"}
0005434503571	CDEA17	1680 931287	OLGA ARKHIPOVA	{"phone": "+70276431732"}
0005434503572	CDEA17	3285 738984	MIKHAIL ZAKHAROV	{"phone": "+70508917365"}
0005434503573	99FE2F	8778 559653	NIKOLAY SOLOVEV	{"phone": "+70462770933"}
0005434503574	690ADD	2509 075715	IGOR KULIKOV	{"email": "kulikov.igor.1979@postgrespro.ru", "phone": "+70294944970"}
0005434503575	5E3BB2	8578 224072	PETR FOMIN	{"phone": "+70180032526"}
0005434503576	9865EF	8739 473190	ALINA EGOROVA	{"email": "egorovaalina.1975@postgrespro.ru", "phone": "+70824017086"}
0005434503577	447E0F	6036 703765	MAKSIM SCHERBAKOV	{"email": "scherbakov.m.01051976@postgrespro.ru", "phone": "+70755479312"}
0005434503578	B30D2C	3185 916266	RAISA POPOVA	{"phone": "+70040174078"}
0005434503579	B30D2C	3886 645700	ALEKSANDRA SIDOROVA	{"email": "sidorova.aleksandra1983@postgrespro.ru", "phone": "+70093353879"}
0005434503580	D4189F	2610 310370	NIKOLAY CHERNOV	{"email": "chernov_n-1971@postgrespro.ru", "phone": "+70098255672"}
0005434503581	D4189F	5296 844263	ALEKSANDR PETROV	{"email": "aleksandr_petrov-1972@postgrespro.ru", "phone": "+70143221129"}
0005434503582	3A23D4	0576 102048	ANDREY EGOROV	{"email": "egorovandrey_041985@postgrespro.ru", "phone": "+70570625507"}
0005434503583	E1CCB4	2696 267719	ANASTASIYA FILIPPOVA	{"phone": "+70234986628"}
0005434503584	A00BDF	8559 281128	ALIYA KAZAKOVA	{"email": "kazakova_aliya.14061974@postgrespro.ru", "phone": "+70744321081"}
0005434503585	E959A8	3210 888316	IVAN ORLOV	{"email": "ivan-orlov.1964@postgrespro.ru", "phone": "+70847089785"}
0005434503586	591218	7804 180253	NONNA KOVALEVA	{"email": "nonnakovaleva.07081972@postgrespro.ru", "phone": "+70976184630"}
0005434503587	591218	8793 819844	VLADIMIR PAVLOV	{"phone": "+70499338903"}
0005434503588	0FE75D	5898 694435	SERGEY MIKHAYLOV	{"phone": "+70563502266"}
0005434503589	F71821	7143 115004	VLADIMIR KULIKOV	{"email": "kulikov.vladimir.1972@postgrespro.ru", "phone": "+70344235999"}
0005434503590	E4DF0D	9551 730487	ALEKSEY NIKITIN	{"email": "a.nikitin.06051976@postgrespro.ru", "phone": "+70142661278"}
0005434503591	FC943C	6940 209676	GALINA STEPANOVA	{"phone": "+70989492417"}
0005434503592	68F3C2	1410 715464	SVETLANA MAKSIMOVA	{"email": "maksimovasvetlana.1961@postgrespro.ru", "phone": "+70112760742"}
0005434503593	E79E50	0187 151116	VLADIMIR NOVIKOV	{"phone": "+70898718742"}
0005434503594	E13EF2	5999 038711	YULIYA SAVELEVA	{"phone": "+70659802714"}
0005434503595	E13EF2	6281 757950	EVGENIY ALEKSEEV	{"phone": "+70954907610"}
0005434503596	F0C247	0215 420257	ALEKSANDRA ABRAMOVA	{"email": "aleksandra-abramova17111962@postgrespro.ru", "phone": "+70287635273"}
0005434503597	2640A9	4623 171280	KARINA MALYSHEVA	{"phone": "+70589151820"}
0005434503598	AC5A84	1957 315951	DMITRIY PETROV	{"email": "petrov.d-1959@postgrespro.ru", "phone": "+70180280345"}
0005434503599	AB9E45	4304 555748	VADIM TIKHONOV	{"phone": "+70150317287"}
0005434503600	B518D8	4372 389205	ALEKSANDR KRASNOV	{"email": "a_krasnov_101977@postgrespro.ru", "phone": "+70449645645"}
0005434503601	B518D8	4093 317072	VYACHESLAV DAVYDOV	{"email": "davydovvyacheslav-1970@postgrespro.ru", "phone": "+70884473641"}
0005434503602	B518D8	8974 962013	ALEKSANDR ILIN	{"email": "ilinaleksandr-17061976@postgrespro.ru", "phone": "+70332128485"}
0005434503603	8C92D5	5253 895979	ELENA EFIMOVA	{"phone": "+70487963093"}
0005434503604	142BDF	8134 442532	NIKOLAY PETROV	{"phone": "+70701256258"}
0005434503605	10B916	0944 485682	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr26021981@postgrespro.ru", "phone": "+70627332430"}
0005434503606	10B916	8224 194434	LYUDMILA SEMENOVA	{"phone": "+70059907025"}
0005434503607	2AA020	8431 023999	ALINA SMIRNOVA	{"email": "smirnova-a-1969@postgrespro.ru", "phone": "+70146207035"}
0005434503608	C8D036	9639 951887	GALINA KAZAKOVA	{"email": "galina.kazakova18011974@postgrespro.ru", "phone": "+70148804424"}
0005434503609	559E90	5855 206986	MARIYA MELNIKOVA	{"phone": "+70994279982"}
0005434503610	A29677	4169 918743	VSEVOLOD KOZLOV	{"email": "vsevolodkozlov-011978@postgrespro.ru", "phone": "+70504892771"}
0005434503611	A29677	1377 168744	ROMAN VOLKOV	{"phone": "+70790280674"}
0005434503612	555C30	8710 251451	TAMARA KISELEVA	{"email": "tamara_kiseleva081977@postgrespro.ru", "phone": "+70318489094"}
0005434503613	CBB5E7	9583 955308	ANDREY MIKHAYLOV	{"email": "amikhaylov-1966@postgrespro.ru", "phone": "+70399462111"}
0005434503614	CBB5E7	1420 884748	IGOR TARASOV	{"phone": "+70529695726"}
0005434503615	D6BA7A	7195 546700	TATYANA ANDREEVA	{"email": "tatyana-andreeva081986@postgrespro.ru", "phone": "+70419529675"}
0005434503616	3300BF	2470 826650	NATALYA POPOVA	{"email": "popova.natalya_021967@postgrespro.ru", "phone": "+70434296210"}
0005434503617	3300BF	1114 853229	DMITRIY FROLOV	{"email": "frolov_d-121984@postgrespro.ru", "phone": "+70142332951"}
0005434503618	693B95	3733 876267	OLGA GRISHINA	{"email": "grishinaolga_091981@postgrespro.ru", "phone": "+70908214396"}
0005434503619	04452D	7534 484061	ANTON SIDOROV	{"email": "sidorovanton.111963@postgrespro.ru", "phone": "+70373046214"}
0005434503620	04452D	2297 412736	GENNADIY OSIPOV	{"phone": "+70031274410"}
0005434503621	4C3CB1	9948 756250	EKATERINA EGOROVA	{"email": "egorovaekaterina.1976@postgrespro.ru", "phone": "+70232126911"}
0005434503622	E2D858	3130 002028	MILANA AKIMOVA	{"phone": "+70599156156"}
0005434503623	FCE628	3904 720358	NADEZHDA FILATOVA	{"email": "filatova_nadezhda-26091974@postgrespro.ru", "phone": "+70401079690"}
0005434503624	305EF6	9299 226511	NINA IVANOVA	{"email": "ivanovanina-011972@postgrespro.ru", "phone": "+70175136686"}
0005434503625	9DACE0	3287 565783	NATALYA DANILOVA	{"email": "danilova.n_1973@postgrespro.ru", "phone": "+70171908863"}
0005434503626	81DA23	2026 613698	VIKTOR IVANOV	{"phone": "+70064325052"}
0005434503627	8DF7D2	2779 789025	SERGEY SOKOLOV	{"phone": "+70568992114"}
0005434503628	8DF7D2	7478 438818	VALERIY TIMOFEEV	{"email": "valeriy-timofeev_091973@postgrespro.ru", "phone": "+70432477538"}
0005434503629	8DF7D2	1575 148179	SERGEY ALEKSANDROV	{"email": "s_aleksandrov_091980@postgrespro.ru", "phone": "+70358327696"}
0005434503630	A3C713	0250 404235	PAVEL KOZLOV	{"phone": "+70657222916"}
0005434503631	2CEB0B	1205 496154	EKATERINA SERGEEVA	{"email": "ekaterina.sergeeva-13011972@postgrespro.ru", "phone": "+70590914907"}
0005434503632	2CEB0B	3360 845975	ALEKSANDR KUZNECOV	{"phone": "+70226409724"}
0005434503633	2CEB0B	4758 810560	SERGEY IVANOV	{"email": "ivanov_s_111980@postgrespro.ru", "phone": "+70159433878"}
0005434503634	1036E8	6742 178178	MIKHAIL ZAKHAROV	{"phone": "+70247785274"}
0005434503635	1036E8	0649 982904	MARIYA ANTONOVA	{"phone": "+70051321060"}
0005434503636	54C616	1130 548141	VALENTINA ALEKSEEVA	{"phone": "+70943512918"}
0005434503637	5EA97B	2272 212231	MARINA RYABOVA	{"email": "ryabova-m1964@postgrespro.ru", "phone": "+70372259288"}
0005434503638	FBEB8F	7026 809126	SERGEY MIKHAYLOV	{"email": "mikhaylov-sergey-031967@postgrespro.ru", "phone": "+70753739451"}
0005434503639	FBEB8F	5407 954209	DMITRIY KULIKOV	{"phone": "+70729962023"}
0005434503640	AEC0DC	4197 114306	ANGELINA NIKOLAEVA	{"phone": "+70528502045"}
0005434503641	DFF993	0535 426947	NADEZHDA FEDOROVA	{"email": "fedorova-n.1965@postgrespro.ru", "phone": "+70447298276"}
0005434503642	DFF993	4729 004420	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova-121982@postgrespro.ru", "phone": "+70151681664"}
0005434503643	C4F92C	2942 624376	IGOR SERGEEV	{"phone": "+70577700582"}
0005434503644	BBF027	8384 300820	SERGEY IVANOV	{"phone": "+70229207707"}
0005434503645	BBF027	1544 622863	DARYA FILIPPOVA	{"email": "d.filippova.021970@postgrespro.ru", "phone": "+70028450014"}
0005434503646	E842D5	3389 155526	VERA LOGINOVA	{"phone": "+70219947787"}
0005434503647	E842D5	1327 462530	KONSTANTIN SMIRNOV	{"phone": "+70029249974"}
0005434503648	58A9F3	0399 764822	VALENTINA POTAPOVA	{"email": "potapova.valentina19041972@postgrespro.ru", "phone": "+70326605506"}
0005434503762	376166	3192 711527	MARIYA SOLOVEVA	{"phone": "+70991009849"}
0005434503649	6318BD	0584 631435	LIDIYA NIKITINA	{"email": "l.nikitina11091977@postgrespro.ru", "phone": "+70886119105"}
0005434503650	626081	8683 761069	SERGEY GERASIMOV	{"phone": "+70722166684"}
0005434503651	7C9BCF	8860 860050	VYACHESLAV KAZAKOV	{"email": "v-kazakov1984@postgrespro.ru", "phone": "+70802763480"}
0005434503652	B055CF	6924 749641	GALINA ZHURAVLEVA	{"phone": "+70144873501"}
0005434503653	B055CF	2825 319586	VLADIMIR GRIGOREV	{"phone": "+70571456134"}
0005434503654	ED93D1	7279 512089	EVGENIY IVANOV	{"email": "evgeniy.ivanov-1973@postgrespro.ru", "phone": "+70310962854"}
0005434503655	E4873C	4920 544080	ILNAR MARTYNOV	{"phone": "+70959086230"}
0005434503656	E4873C	5622 000313	LINAR DENISOV	{"phone": "+70276488837"}
0005434503657	237267	2885 080993	TAMARA EGOROVA	{"phone": "+70993776156"}
0005434503658	DDFEE6	3141 291383	ALEKSANDR OSIPOV	{"phone": "+70799087477"}
0005434503659	C29848	6704 569026	SERGEY FEDOTOV	{"phone": "+70000873043"}
0005434503660	2F540D	1989 276651	LARISA POLYAKOVA	{"phone": "+70775160773"}
0005434503661	45109E	1455 212701	NARIMAN VASILEV	{"email": "vasilevnariman.1968@postgrespro.ru", "phone": "+70753155882"}
0005434503662	45109E	8224 867812	VERA BORISOVA	{"phone": "+70476971996"}
0005434503663	49DA02	7368 823529	OLEG ANDREEV	{"email": "oleg_andreev_061969@postgrespro.ru", "phone": "+70961867241"}
0005434503664	2100C0	6882 433179	TATYANA VASILEVA	{"phone": "+70566810021"}
0005434503665	36C3A7	9550 568762	NATALYA IVANOVA	{"email": "ivanova_n_1967@postgrespro.ru", "phone": "+70385034116"}
0005434503666	922356	3546 438253	KIRILL FOMIN	{"phone": "+70348201027"}
0005434503667	E59C26	5079 137028	ELENA MAKSIMOVA	{"phone": "+70095372278"}
0005434503668	AA57B7	6031 341646	MIKHAIL BARANOV	{"email": "baranov_m.26081975@postgrespro.ru", "phone": "+70042272564"}
0005434503669	B737C4	3682 122901	MARINA ARKHIPOVA	{"phone": "+70624621401"}
0005434503670	A75688	5610 626173	NIKOLAY SERGEEV	{"email": "n.sergeev1977@postgrespro.ru", "phone": "+70779500659"}
0005434503671	C2D3F2	9416 270887	MIKHAIL FEDOROV	{"email": "mikhailfedorov1963@postgrespro.ru", "phone": "+70205742336"}
0005434503672	C2D3F2	0763 170406	SVETLANA FILATOVA	{"phone": "+70604705675"}
0005434503673	5BF52F	2293 488085	OLGA VOLKOVA	{"email": "olgavolkova_24121975@postgrespro.ru", "phone": "+70875122814"}
0005434503674	32C9B8	9283 798852	NADEZHDA ZHURAVLEVA	{"email": "nadezhdazhuravleva.1966@postgrespro.ru", "phone": "+70674880427"}
0005434503675	926C79	6030 810074	DMITRIY ORLOV	{"phone": "+70584859213"}
0005434503676	25972D	3907 185715	ARTEM KUZNECOV	{"email": "artem_kuznecov-1974@postgrespro.ru", "phone": "+70954558463"}
0005434503677	2A031F	9630 793693	TATYANA KOROLEVA	{"phone": "+70984690889"}
0005434503678	F5CD9E	9822 539990	DMITRIY FEDOTOV	{"phone": "+70085451379"}
0005434503679	A1D58F	8035 996746	VLADIMIR EGOROV	{"phone": "+70390347577"}
0005434503680	A1D58F	1769 298895	NADEZHDA VOROBEVA	{"phone": "+70853957596"}
0005434503681	D78959	7698 763637	GALINA KARPOVA	{"email": "galina-karpova1981@postgrespro.ru", "phone": "+70825944632"}
0005434503682	828BD8	8285 194176	GALINA KRASNOVA	{"phone": "+70807155611"}
0005434503683	5ECF0F	4946 508685	ANATOLIY TIKHONOV	{"phone": "+70229729276"}
0005434503684	2111BB	6783 986412	EKATERINA ANISIMOVA	{"email": "anisimova-e.081979@postgrespro.ru", "phone": "+70949326863"}
0005434503685	22F96A	2569 851973	MARINA VASILEVA	{"phone": "+70508764535"}
0005434503686	22F96A	5654 047716	SERGEY KARPOV	{"email": "karpovsergey_07091976@postgrespro.ru", "phone": "+70949946424"}
0005434503687	22F96A	3480 937227	ANTONINA ROMANOVA	{"email": "romanova-antonina_061976@postgrespro.ru", "phone": "+70484014144"}
0005434503688	C75924	5126 275449	IGOR SIDOROV	{"email": "igor.sidorov1959@postgrespro.ru", "phone": "+70702716552"}
0005434503689	19A2FF	7400 141993	NAILYA FOMINA	{"phone": "+70795284024"}
0005434503690	B45F43	5345 837152	DANILA ZAKHAROV	{"email": "zakharov.d_23031978@postgrespro.ru", "phone": "+70197968573"}
0005434503691	B45F43	6208 846982	OLGA CHERNOVA	{"email": "chernova.o.04111974@postgrespro.ru", "phone": "+70509369137"}
0005434503692	B3832D	5562 062586	RIMMA KUZMINA	{"email": "kuzmina.r.1973@postgrespro.ru", "phone": "+70945971554"}
0005434503693	97B64E	2937 121714	DMITRIY KAZAKOV	{"email": "kazakov.d-15081960@postgrespro.ru", "phone": "+70501252458"}
0005434503694	3334CA	7691 437971	KLAVDIYA BORISOVA	{"email": "klavdiyaborisova.22051976@postgrespro.ru", "phone": "+70786819151"}
0005434503695	057045	9382 597078	MARIYA NIKOLAEVA	{"phone": "+70628838444"}
0005434503696	BA9B93	6272 247786	ALEKSANDR SOROKIN	{"phone": "+70541252230"}
0005434503697	8D6245	6325 887184	ALLA SOLOVEVA	{"email": "a_soloveva_1962@postgrespro.ru", "phone": "+70008057069"}
0005434503698	FEF343	1612 508852	VLADIMIR GRIGOREV	{"phone": "+70005413190"}
0005434503699	8E30D2	5398 588532	RAISA ILINA	{"phone": "+70345513579"}
0005434503700	883BFE	9340 841404	YULIYA BOGDANOVA	{"email": "bogdanova.y.03091974@postgrespro.ru", "phone": "+70820138105"}
0005434503701	C73EF1	2015 169248	OLEG SCHERBAKOV	{"email": "scherbakov.oleg111978@postgrespro.ru", "phone": "+70836231866"}
0005434503702	C73EF1	9307 429518	YULIYA POPOVA	{"phone": "+70492030291"}
0005434503703	5B3BFF	1725 466139	ANASTASIYA ALEKSEEVA	{"phone": "+70705812910"}
0005434503704	EFDD20	9908 738782	MIKHAIL MELNIKOV	{"email": "melnikov.mikhail_25121969@postgrespro.ru", "phone": "+70360865583"}
0005434503705	D4BAD5	4136 784349	IRINA SAVELEVA	{"email": "irinasaveleva.1971@postgrespro.ru", "phone": "+70281111437"}
0005434503706	7789CF	9663 730476	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila-1976@postgrespro.ru", "phone": "+70739217469"}
0005434503707	E6B40C	5328 926540	GALINA GORBUNOVA	{"email": "galina.gorbunova.1972@postgrespro.ru", "phone": "+70519070853"}
0005434503708	AA3BD8	6436 444651	IVAN VOLKOV	{"email": "i_volkov10061976@postgrespro.ru", "phone": "+70471505403"}
0005434503709	AA3BD8	5301 452423	LILIYA NOVIKOVA	{"email": "novikova_liliya_121973@postgrespro.ru", "phone": "+70916346359"}
0005434503710	4BE2A6	1141 180603	VASILIY IVANOV	{"email": "v.ivanov-05071971@postgrespro.ru", "phone": "+70537524691"}
0005434503711	4BE2A6	9061 634038	TATYANA ANTONOVA	{"phone": "+70984932512"}
0005434503712	4BE2A6	1665 392659	NADEZHDA IVANOVA	{"phone": "+70195366447"}
0005434503713	863123	9946 672875	NATALYA MAKAROVA	{"phone": "+70898944019"}
0005434503714	E20755	5567 324798	VIKTOR SCHERBAKOV	{"email": "viktor.scherbakov_091967@postgrespro.ru", "phone": "+70414884621"}
0005434503715	E7C984	0311 509009	ALEKSEY SEMENOV	{"email": "semenov_aleksey.021971@postgrespro.ru", "phone": "+70273752253"}
0005434503716	A6C2C9	9034 798384	OLEG MATVEEV	{"email": "oleg_matveev-23111965@postgrespro.ru", "phone": "+70040770018"}
0005434503717	A6C2C9	7459 031863	OLEG SHEVCHENKO	{"email": "oleg.shevchenko.121976@postgrespro.ru", "phone": "+70594993393"}
0005434503718	62CCFD	6489 715919	ALEKSEY ROMANOV	{"phone": "+70817346159"}
0005434503719	72A41F	3580 960068	ELENA ANDREEVA	{"email": "elena.andreeva_101980@postgrespro.ru", "phone": "+70460270056"}
0005434503720	C43AF9	8060 636937	ELENA IVANOVA	{"phone": "+70904578999"}
0005434503721	E8F8D1	6409 092382	ANNA BELOVA	{"email": "a_belova_04011980@postgrespro.ru", "phone": "+70969350325"}
0005434503722	D8C42C	8653 600538	NATALIYA TARASOVA	{"email": "n.tarasova-1974@postgrespro.ru", "phone": "+70398034939"}
0005434503723	3B2BB2	6383 483174	LYUBOV BORISOVA	{"email": "borisova_lyubov-17081956@postgrespro.ru", "phone": "+70843303871"}
0005434503724	52A436	8753 179733	ALEKSEY KARPOV	{"phone": "+70310788923"}
0005434503725	52A436	8903 631827	SVETLANA BORISOVA	{"phone": "+70329662623"}
0005434503726	D62DB2	8472 056967	VITALIY KUZNECOV	{"email": "kuznecov.vitaliy09121973@postgrespro.ru", "phone": "+70086875731"}
0005434503727	95559F	8445 174115	OLGA SEMENOVA	{"phone": "+70994154211"}
0005434503728	F7288B	6020 079998	NADEZHDA KOVALEVA	{"phone": "+70420322121"}
0005434503729	F7288B	7640 842529	ANATOLIY AFANASEV	{"phone": "+70939085862"}
0005434503730	7B96ED	4759 211484	NIKOLAY KRASNOV	{"phone": "+70084972482"}
0005434503731	7B96ED	2614 968000	VIKTOR MOROZOV	{"phone": "+70807804086"}
0005434503732	32A845	9477 331729	ANDREY KUZNECOV	{"phone": "+70517968572"}
0005434503733	068A84	2957 838805	LYUDMILA FADEEVA	{"phone": "+70790354042"}
0005434503734	EF923C	1028 351461	SERGEY VLASOV	{"phone": "+70610712619"}
0005434503735	EF923C	8683 755909	OKSANA BELOVA	{"phone": "+70111867615"}
0005434503736	99623B	6843 046873	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova.18061969@postgrespro.ru", "phone": "+70032487246"}
0005434503737	4FC236	9433 375696	VLADIMIR MOROZOV	{"phone": "+70830902856"}
0005434503738	4FC236	0656 856189	ANDREY ZHUKOV	{"email": "andrey_zhukov041978@postgrespro.ru", "phone": "+70015784999"}
0005434503739	CA9B36	0696 674435	NATALYA SERGEEVA	{"email": "sergeevan24121974@postgrespro.ru", "phone": "+70858193508"}
0005434503740	CA9B36	0004 311516	OLGA GORBUNOVA	{"email": "olgagorbunova1981@postgrespro.ru", "phone": "+70248562983"}
0005434503741	A08554	7053 855638	RAISA MAKAROVA	{"email": "makarova-r.1978@postgrespro.ru", "phone": "+70780518736"}
0005434503742	09759A	5728 616764	ALEKSANDRA KUZMINA	{"phone": "+70615082377"}
0005434503743	09759A	6204 367176	ANNA YAKOVLEVA	{"phone": "+70233388835"}
0005434503744	013EFC	6383 550673	GENNADIY NAUMOV	{"email": "naumovgennadiy.101971@postgrespro.ru", "phone": "+70315112149"}
0005434503745	013EFC	6477 715650	IRINA KAZAKOVA	{"email": "i-kazakova-04041971@postgrespro.ru", "phone": "+70279407795"}
0005434503746	BCAF84	0157 118630	TATYANA TARASOVA	{"phone": "+70482460274"}
0005434503747	BCAF84	0795 868805	ELENA MEDVEDEVA	{"phone": "+70419593748"}
0005434503748	BE11DC	8056 852744	KONSTANTIN VASILEV	{"email": "vasilev.k-1963@postgrespro.ru", "phone": "+70033059391"}
0005434503749	A6E7C0	2928 581880	KSENIYA KAZAKOVA	{"email": "k.kazakova.21031970@postgrespro.ru", "phone": "+70296577812"}
0005434503750	A6E7C0	3100 691898	TATYANA FILIPPOVA	{"phone": "+70597441330"}
0005434503751	A6E7C0	8717 733690	IRINA IVANOVA	{"phone": "+70530367569"}
0005434503752	6351BE	2752 897254	ANDREY FEDOROV	{"email": "afedorov_1983@postgrespro.ru", "phone": "+70958328600"}
0005434503753	1FE866	0910 995557	ALEKSANDR NAUMOV	{"email": "aleksandr.naumov-1972@postgrespro.ru", "phone": "+70534034728"}
0005434503754	9FA238	0357 330376	ALEKSANDR SHEVCHENKO	{"phone": "+70631897112"}
0005434503755	9FA238	9227 677635	TATYANA KALININA	{"email": "tatyanakalinina_1966@postgrespro.ru", "phone": "+70666004182"}
0005434503756	3990E4	9709 770049	ALEKSANDR KOZLOV	{"phone": "+70972319716"}
0005434503757	F37FAA	0987 216578	ALEKSANDR KOROLEV	{"email": "aleksandrkorolev061965@postgrespro.ru", "phone": "+70182960159"}
0005434503758	13D431	9599 785588	IGOR IVANOV	{"email": "ivanov-igor-1969@postgrespro.ru", "phone": "+70551060809"}
0005434503759	34F1CE	2617 478400	EKATERINA YUDINA	{"phone": "+70515923432"}
0005434503760	FCBC68	7534 704569	OLGA YAKOVLEVA	{"email": "olga-yakovleva1968@postgrespro.ru", "phone": "+70087139735"}
0005434503761	3DBA71	2301 468005	ARTEM ANDREEV	{"phone": "+70424667546"}
0005434503763	18B948	3015 512004	VYACHESLAV ILIN	{"phone": "+70107271451"}
0005434503764	65F8B5	3010 909119	RASIM CHERNOV	{"phone": "+70179978217"}
0005434503765	65F8B5	7491 996878	IRINA NIKIFOROVA	{"email": "irinanikiforova_1973@postgrespro.ru", "phone": "+70149711539"}
0005434503766	01831E	2521 615526	ALEKSANDR KUDRYASHOV	{"email": "aleksandr_kudryashov111969@postgrespro.ru", "phone": "+70904497024"}
0005434503767	1FAB43	0699 530696	ALEKSANDR RODIONOV	{"email": "rodionov.a27011960@postgrespro.ru", "phone": "+70781054673"}
0005434503768	1FAB43	8897 513432	VERA GRISHINA	{"phone": "+70717605059"}
0005434503769	64AFE1	5373 273674	DANIIL MELNIKOV	{"phone": "+70742102705"}
0005434503770	64AFE1	6149 789239	TATYANA KUZMINA	{"email": "kuzmina_t1983@postgrespro.ru", "phone": "+70598888787"}
0005434503771	64AFE1	8607 303113	ANTONIDA MIRONOVA	{"phone": "+70341589181"}
0005434503772	FBA18F	6202 793840	OLGA GAVRILOVA	{"phone": "+70784679038"}
0005434503773	5ABDD0	0657 075243	TATYANA BOGDANOVA	{"email": "tbogdanova.04121965@postgrespro.ru", "phone": "+70034689028"}
0005434503774	F07406	4919 785946	ARINA ILINA	{"email": "ilina-arina.15101967@postgrespro.ru", "phone": "+70314014012"}
0005434503775	88BF87	1800 989867	MIKHAIL MOROZOV	{"email": "mikhail-morozov-051976@postgrespro.ru", "phone": "+70924868562"}
0005434503776	C5448C	7369 547920	VALERIY FILIPPOV	{"phone": "+70056837769"}
0005434503777	3FE3D6	5555 159300	VALENTINA KOZLOVA	{"phone": "+70408858318"}
0005434503778	8EF982	7397 817100	MIKHAIL KARPOV	{"phone": "+70387764413"}
0005434503779	8EF982	1962 161210	NATALYA TARASOVA	{"phone": "+70428735190"}
0005434503780	8EF982	7897 128056	ALEKSEY POPOV	{"phone": "+70571169651"}
0005434503781	0F067A	6178 172718	TATYANA ZAKHAROVA	{"phone": "+70433272055"}
0005434503782	0F067A	0710 993794	ANNA LAZAREVA	{"email": "lazareva-anna.1964@postgrespro.ru", "phone": "+70799572321"}
0005434503783	549910	3688 120992	TATYANA IVANOVA	{"email": "ivanova-t.31081977@postgrespro.ru", "phone": "+70761009720"}
0005434503784	549910	5931 881090	VYACHESLAV NIKITIN	{"phone": "+70763752087"}
0005434503785	057D64	8674 430499	GALINA KOROLEVA	{"phone": "+70329613218"}
0005434503786	25B262	3756 167128	VALERIY ABRAMOV	{"email": "abramov-valeriy.1968@postgrespro.ru", "phone": "+70366410472"}
0005434503787	21796C	0511 339808	DENIS SCHERBAKOV	{"phone": "+70236070833"}
0005434503788	21796C	2516 007087	OLGA MAKAROVA	{"phone": "+70736913698"}
0005434503789	608EE6	6384 040349	TATYANA DENISOVA	{"email": "denisova-t.1971@postgrespro.ru", "phone": "+70113499153"}
0005434503790	3B3A1E	6770 338479	VIKTOR KUZNECOV	{"email": "viktor_kuznecov121978@postgrespro.ru", "phone": "+70643935512"}
0005434503791	3B3A1E	2874 921602	IVAN GAVRILOV	{"phone": "+70950637914"}
0005434503792	E09C9E	3971 698747	LYUDMILA SERGEEVA	{"phone": "+70897150514"}
0005434503793	B19531	0794 802205	FARID KUZMIN	{"email": "farid.kuzmin.22081978@postgrespro.ru", "phone": "+70266973866"}
0005434503794	5F5B13	3059 583070	NADEZHDA MARTYNOVA	{"email": "martynova.nadezhda-1971@postgrespro.ru", "phone": "+70128201394"}
0005434503795	E30AFD	4037 286066	ALEKSANDR MOROZOV	{"email": "morozova_1969@postgrespro.ru", "phone": "+70201913314"}
0005434503796	E30AFD	0124 131998	NINA RYABOVA	{"phone": "+70658185743"}
0005434503797	0F59AE	0373 327190	RIMMA EGOROVA	{"phone": "+70137688595"}
0005434503798	B3E94B	7709 605114	LIDIYA IVANOVA	{"phone": "+70405996966"}
0005434503799	B3E94B	5060 969969	VLADIMIR KUZMIN	{"phone": "+70954422368"}
0005434503800	6F7624	1708 750641	DMITRIY OSIPOV	{"phone": "+70717517200"}
0005434503801	6F7624	9814 164060	SVETLANA VOROBEVA	{"email": "svetlana_vorobeva_08081974@postgrespro.ru", "phone": "+70390863266"}
0005434503802	F8DB2D	3113 567742	LILIYA IVANOVA	{"phone": "+70685283369"}
0005434503803	7321C5	1057 374465	SERGEY TIMOFEEV	{"email": "timofeevsergey_27081977@postgrespro.ru", "phone": "+70972275441"}
0005434503804	A48CCD	6551 591872	DMITRIY STEPANOV	{"phone": "+70482321666"}
0005434503805	A48CCD	1257 921933	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr_19081972@postgrespro.ru", "phone": "+70026518812"}
0005434503806	3BBA0D	8284 782936	IRINA DANILOVA	{"phone": "+70973621615"}
0005434503807	3BBA0D	1327 446575	KRISTINA PAVLOVA	{"phone": "+70567640068"}
0005434503808	3BBA0D	5240 562512	ELENA ALEKSANDROVA	{"email": "elena_aleksandrova-1965@postgrespro.ru", "phone": "+70296540593"}
0005434503809	AA20BA	9415 474622	MARINA SEMENOVA	{"email": "semenova_marina.041967@postgrespro.ru", "phone": "+70615545964"}
0005434503810	AA20BA	3071 473045	IVAN STEPANOV	{"email": "i.stepanov-08071962@postgrespro.ru", "phone": "+70947243309"}
0005434503811	8EE86A	9003 311895	SERGEY TIKHONOV	{"email": "tikhonov_sergey.041969@postgrespro.ru", "phone": "+70374337552"}
0005434503812	8EE86A	2109 068429	OLGA MOROZOVA	{"phone": "+70781483591"}
0005434503813	E06D5F	1371 665470	NADEZHDA ANDREEVA	{"email": "andreeva.nadezhda-23091984@postgrespro.ru", "phone": "+70237711766"}
0005434503814	E06D5F	9216 717128	ELENA EFIMOVA	{"email": "eefimova01081972@postgrespro.ru", "phone": "+70979584835"}
0005434503815	2A94F0	4740 992155	KSENIYA BORISOVA	{"email": "borisova.k24091966@postgrespro.ru", "phone": "+70854136106"}
0005434503816	99FE5C	6292 713760	ELENA PETROVA	{"email": "petrova-elena.20101978@postgrespro.ru", "phone": "+70978019712"}
0005434503817	99FE5C	3795 961985	SVETLANA VOROBEVA	{"email": "vorobeva-s-1968@postgrespro.ru", "phone": "+70881810233"}
0005434503818	7FEA16	2106 831806	VERA TIKHONOVA	{"email": "vtikhonova-08061955@postgrespro.ru", "phone": "+70202664853"}
0005434503819	EAD1B5	1040 028016	VLADIMIR SHEVCHENKO	{"phone": "+70701326617"}
0005434503820	192DCE	5694 028493	VIKTORIYA KISELEVA	{"phone": "+70766189964"}
0005434503821	2A70F5	3011 534999	VLADIMIR SIDOROV	{"phone": "+70726237201"}
0005434503822	2A70F5	7847 828642	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev121971@postgrespro.ru", "phone": "+70878065270"}
0005434503823	576774	2448 081839	ANNA ZHURAVLEVA	{"email": "zhuravleva-anna-031977@postgrespro.ru", "phone": "+70169395041"}
0005434503824	9959D2	1265 935243	INNA GAVRILOVA	{"email": "inna-gavrilova.1979@postgrespro.ru", "phone": "+70159608628"}
0005434503825	27CA05	7007 045602	MAKSIM SEMENOV	{"email": "msemenov111984@postgrespro.ru", "phone": "+70805301042"}
0005434503826	E5E260	1736 922866	POLINA LEBEDEVA	{"phone": "+70792982110"}
0005434503827	89E8DE	6446 813083	VIKTOR GORBUNOV	{"email": "vgorbunov_18021973@postgrespro.ru", "phone": "+70050669380"}
0005434503828	7E2959	1037 068592	ANDREY KUZNECOV	{"phone": "+70850502156"}
0005434503829	7E2959	4687 173283	DMITRIY GERASIMOV	{"phone": "+70347804236"}
0005434503830	6144FE	5520 130640	ANASTASIYA NIKIFOROVA	{"email": "anastasiya-nikiforova_101956@postgrespro.ru", "phone": "+70215722082"}
0005434503831	6144FE	3916 085697	GALINA NAUMOVA	{"email": "naumova_galina_021983@postgrespro.ru", "phone": "+70310227109"}
0005434503832	6144FE	7882 418745	ARTUR KISELEV	{"email": "a.kiselev_1970@postgrespro.ru", "phone": "+70862880129"}
0005434503833	36A6AA	8687 761845	ALENA ZAKHAROVA	{"email": "zakharova-a_17021989@postgrespro.ru", "phone": "+70374696773"}
0005434503834	B1EBFC	0452 247541	ANASTASIYA SMIRNOVA	{"email": "a.smirnova021984@postgrespro.ru", "phone": "+70452839217"}
0005434503835	6E5E44	0350 043032	TATYANA MELNIKOVA	{"email": "t_melnikova081965@postgrespro.ru", "phone": "+70173491024"}
0005434503836	FC456D	8656 024285	KRISTINA ZAYCEVA	{"email": "zayceva.kristina-1979@postgrespro.ru", "phone": "+70975973230"}
0005434503837	386EB1	2721 228668	NIKOLAY KUZNECOV	{"email": "kuznecov-n081977@postgrespro.ru", "phone": "+70198448450"}
0005434503838	3A10B7	4829 006901	GENNADIY PETROV	{"email": "petrovg16061964@postgrespro.ru", "phone": "+70141939183"}
0005434503839	C297A3	4252 900859	EVGENIY ROMANOV	{"email": "romanovevgeniy1967@postgrespro.ru", "phone": "+70627446861"}
0005434503840	C297A3	8948 390992	VLADIMIR PETROV	{"phone": "+70172532842"}
0005434503841	207E79	5711 638763	LARISA KONDRATEVA	{"phone": "+70059372179"}
0005434503842	D5A5A5	1480 887724	VERA KONOVALOVA	{"email": "v_konovalova1970@postgrespro.ru", "phone": "+70750816426"}
0005434503843	D5A5A5	5521 525608	VLADIMIR BELOV	{"email": "vladimir.belov.111971@postgrespro.ru", "phone": "+70372686607"}
0005434503844	FA8EBA	8301 812014	NINA SMIRNOVA	{"phone": "+70662208954"}
0005434503845	FA8EBA	8170 133559	IVAN MARTYNOV	{"email": "i-martynov_1972@postgrespro.ru", "phone": "+70672196196"}
0005434503846	5A7287	4969 609188	ELENA ERMAKOVA	{"email": "ermakova_e-31121975@postgrespro.ru", "phone": "+70862157250"}
0005434503847	B5DA3C	3506 488796	GERMAN VLASOV	{"phone": "+70677096443"}
0005434503848	5D2377	7049 210559	NATALYA VOLKOVA	{"email": "volkova-natalya-051980@postgrespro.ru", "phone": "+70181881977"}
0005434503849	5D2377	9609 648223	ALEKSANDR GORBUNOV	{"phone": "+70930901937"}
0005434503850	F5EAE8	8071 233997	GUZEL KONDRATEVA	{"phone": "+70451846066"}
0005434503851	27DC01	7996 151977	PAVEL MOROZOV	{"phone": "+70657117103"}
0005434503852	87B795	6465 453612	ALEKSEY IVANOV	{"phone": "+70016855909"}
0005434503853	DD0DD4	9607 472881	LYUBOV IVANOVA	{"email": "lyubov_ivanova.23091959@postgrespro.ru", "phone": "+70537125091"}
0005434503854	E9D376	1882 352673	NIKITA MATVEEV	{"email": "matveev_nikita.07051978@postgrespro.ru", "phone": "+70662025367"}
0005434503855	E1750C	7905 995560	VALENTIN KULIKOV	{"phone": "+70700714449"}
0005434503856	90875B	4643 291674	PAVEL KONOVALOV	{"email": "konovalov.p_1976@postgrespro.ru", "phone": "+70112328853"}
0005434503857	7A8644	7589 707010	ANATOLIY STEPANOV	{"email": "stepanov_a_101971@postgrespro.ru", "phone": "+70383796702"}
0005434503858	F6E313	9236 113708	ALEKSANDR FROLOV	{"phone": "+70214605639"}
0005434503859	F6E313	4950 794504	EVGENIY ZHUKOV	{"email": "e-zhukov_1972@postgrespro.ru", "phone": "+70141311167"}
0005434503860	3A6B21	2064 961824	LYUBOV ROMANOVA	{"email": "l.romanova_1963@postgrespro.ru", "phone": "+70980817851"}
0005434503861	3A6B21	2501 342798	VLADIMIR BELOV	{"email": "vladimir-belov.1969@postgrespro.ru", "phone": "+70822576513"}
0005434503862	9C2412	4207 800764	SERGEY BELOV	{"phone": "+70720257321"}
0005434503863	9A1CC4	3147 483213	SERGEY KUDRYASHOV	{"phone": "+70795412266"}
0005434503864	B56A43	2186 784721	ILNUR STEPANOV	{"email": "stepanov_ilnur101969@postgrespro.ru", "phone": "+70698240111"}
0005434503865	A36835	0177 248874	VALERIY SMIRNOV	{"phone": "+70629654038"}
0005434503866	A36835	1286 477951	ALEKSEY ZHUKOV	{"email": "zhukov.aleksey091977@postgrespro.ru", "phone": "+70822575209"}
0005434503867	0A967E	9622 052907	ALEKSEY KUZNECOV	{"email": "kuznecov_a011977@postgrespro.ru", "phone": "+70015871871"}
0005434503868	EF40F2	2699 907017	MARIYA NOVIKOVA	{"phone": "+70457916821"}
0005434503869	EF40F2	8156 260648	NATALYA EFIMOVA	{"phone": "+70325558054"}
0005434503870	0E7184	9313 604386	VALERIY ZAYCEV	{"email": "v.zaycev-30061973@postgrespro.ru", "phone": "+70190577575"}
0005434503871	0E7184	6272 419021	VLADIMIR KULIKOV	{"email": "kulikov.v-16061965@postgrespro.ru", "phone": "+70014176400"}
0005434503872	9EED42	3652 678463	TATYANA MATVEEVA	{"phone": "+70741523974"}
0005434503873	1CDAEA	5160 177750	LARISA ZOTOVA	{"phone": "+70317267324"}
0005434503874	4661E5	3562 886322	MIKHAIL FEDOROV	{"phone": "+70121684553"}
0005434503875	4661E5	3273 288880	ANDREY MATVEEV	{"phone": "+70923286100"}
0005434503876	06549F	8235 095062	DENIS STEPANOV	{"phone": "+70607744464"}
0005434503877	4D1F04	0114 930030	GALINA FILATOVA	{"email": "filatova-galina-28031967@postgrespro.ru", "phone": "+70239920965"}
0005434503878	DC8040	1479 279565	VASILIY PAVLOV	{"email": "pavlovv.011976@postgrespro.ru", "phone": "+70404204557"}
0005434503879	BEADAB	2653 119066	KIRILL GUSEV	{"phone": "+70103722213"}
0005434503880	08F425	4914 076644	EVGENIY SEMENOV	{"phone": "+70318054166"}
0005434503881	10F558	6420 624662	NINA ANDREEVA	{"email": "andreevan031978@postgrespro.ru", "phone": "+70172511126"}
0005434503882	AC12D9	1793 342800	NAILYA EGOROVA	{"phone": "+70496592942"}
0005434503883	DF6C08	7465 446304	GENNADIY ROMANOV	{"phone": "+70199773546"}
0005434503884	54BBBA	5994 550279	VARVARA NIKOLAEVA	{"phone": "+70848780853"}
0005434503885	54BBBA	4949 568381	VYACHESLAV NOVIKOV	{"phone": "+70905082553"}
0005434503886	B9CD89	5008 923071	NIKOLAY ZAYCEV	{"phone": "+70178562032"}
0005434503887	E82A63	2304 036923	MAKSIM KAZAKOV	{"email": "kazakovm_1978@postgrespro.ru", "phone": "+70432000599"}
0005434503888	EC8A4E	6472 612356	KSENIYA FOMINA	{"email": "fomina_k031975@postgrespro.ru", "phone": "+70011055078"}
0005434503889	544FBF	3512 589034	LYUDMILA TIMOFEEVA	{"phone": "+70359798906"}
0005434503890	00B99F	1003 869492	NIKOLAY POPOV	{"email": "popov_n_15011968@postgrespro.ru", "phone": "+70521735623"}
0005434503891	00B99F	0626 302303	VERA YAKOVLEVA	{"email": "yakovlevavera.1972@postgrespro.ru", "phone": "+70153039976"}
0005434503892	A2FA3D	6119 004294	ALEKSANDR DENISOV	{"phone": "+70904247226"}
0005434503893	4A791D	7775 857543	ANDREY FOMIN	{"phone": "+70491790563"}
0005434503894	F90D86	9645 695030	MAKSIM KRASNOV	{"email": "krasnov_m_1969@postgrespro.ru", "phone": "+70444030534"}
0005434503895	F90D86	8240 262850	ALEKSANDRA ALEKSEEVA	{"email": "aleksandra.alekseeva_011975@postgrespro.ru", "phone": "+70450661087"}
0005434503896	98DD24	2345 307802	TATYANA DENISOVA	{"email": "denisova.t1973@postgrespro.ru", "phone": "+70849029056"}
0005434503897	98DD24	6763 180086	LYUDMILA KAZAKOVA	{"phone": "+70523757239"}
0005434503898	6749DD	4298 690352	ZHANNA ABRAMOVA	{"email": "zhannaabramova.051972@postgrespro.ru", "phone": "+70246838999"}
0005434503899	99D16C	0403 010193	NINA EFIMOVA	{"email": "efimova_nina_031975@postgrespro.ru", "phone": "+70554138302"}
0005434503900	5E90E0	3082 493208	ALEKSANDR FEDOROV	{"phone": "+70061376993"}
0005434503901	5964C5	0795 020109	NIKITA NIKITIN	{"phone": "+70945780095"}
0005434503902	5964C5	6446 385671	NINA YAKOVLEVA	{"phone": "+70678002116"}
0005434503903	F7B3B6	6717 379096	OLGA NESTEROVA	{"email": "olga_nesterova_11121982@postgrespro.ru", "phone": "+70551452511"}
0005434503904	2B74A3	1670 337133	NIKOLAY MOROZOV	{"email": "morozov.nikolay21081971@postgrespro.ru", "phone": "+70828056240"}
0005434503905	DFA514	8344 252435	NATALIYA FILIPPOVA	{"email": "nfilippova_07121974@postgrespro.ru", "phone": "+70178313813"}
0005434503906	332EE6	5231 009110	ALEKSANDRA KUZMINA	{"email": "kuzminaa-021974@postgrespro.ru", "phone": "+70840936738"}
0005434503907	C7D305	0674 807378	OLGA NIKOLAEVA	{"email": "nikolaeva.o20111968@postgrespro.ru", "phone": "+70846614782"}
0005434503908	C7D305	7556 877928	ANNA SMIRNOVA	{"phone": "+70440626994"}
0005434503909	C7D305	5358 796585	ILYA POPOV	{"email": "ilya-popov-1964@postgrespro.ru", "phone": "+70785710921"}
0005434503910	BEF3EA	9448 455501	EVDOKIYA LOGINOVA	{"email": "evdokiyaloginova_041967@postgrespro.ru", "phone": "+70108867496"}
0005434503911	BEF3EA	9495 504502	EKATERINA KONOVALOVA	{"email": "konovalova-ekaterina.30101967@postgrespro.ru", "phone": "+70962770730"}
0005434503912	658757	6571 528451	VLADISLAV SEMENOV	{"phone": "+70582791813"}
0005434503913	658757	8458 488944	ANDREY BORISOV	{"email": "borisovandrey18071975@postgrespro.ru", "phone": "+70411276440"}
0005434503914	13DEAE	6346 634378	NIKOLAY KUZNECOV	{"phone": "+70098387125"}
0005434503915	13DEAE	9662 667011	SOFIYA SMIRNOVA	{"phone": "+70021457282"}
0005434503916	3FE0AF	0313 359810	YURIY ROMANOV	{"email": "romanovyuriy1960@postgrespro.ru", "phone": "+70467033820"}
0005434503917	6B410C	4299 500763	SERGEY MIRONOV	{"phone": "+70751596764"}
0005434503918	FE4146	5791 515075	VYACHESLAV RODIONOV	{"email": "rodionov_vyacheslav-10091976@postgrespro.ru", "phone": "+70941397369"}
0005434503919	A79E92	8494 788942	VERA MAKAROVA	{"email": "vera.makarova_1972@postgrespro.ru", "phone": "+70251517470"}
0005434503920	BBB431	6781 260465	DMITRIY KOROLEV	{"phone": "+70651903285"}
0005434503921	B7B681	8200 078422	VLADIMIR SIDOROV	{"email": "v_sidorov.09041971@postgrespro.ru", "phone": "+70191152658"}
0005434503922	FB6105	0566 592904	EVGENIY MAKAROV	{"email": "evgeniy_makarov.29111954@postgrespro.ru", "phone": "+70911881050"}
0005434503923	A1B92A	3601 222113	RAFAIL DENISOV	{"email": "rafail_denisov_1975@postgrespro.ru", "phone": "+70069818857"}
0005434503924	E7113A	0320 844519	IVAN VASILEV	{"phone": "+70783304665"}
0005434503925	E7113A	8901 020309	PETR ALEKSEEV	{"phone": "+70323435370"}
0005434503926	47E7F0	2298 439990	SVETLANA MATVEEVA	{"phone": "+70301876986"}
0005434503927	47E7F0	8503 673403	SERGEY SIDOROV	{"phone": "+70646055669"}
0005434503928	45A386	6511 250557	VIKTOR KRASNOV	{"phone": "+70368376173"}
0005434503929	DEC3E1	0858 928199	DARYA MIKHAYLOVA	{"email": "darya-mikhaylova.1968@postgrespro.ru", "phone": "+70444810561"}
0005434503930	D06F40	6857 544097	VIKTOR DENISOV	{"phone": "+70681530315"}
0005434503931	E1211E	2198 229633	ANNA MOROZOVA	{"email": "morozova.a121977@postgrespro.ru", "phone": "+70149573535"}
0005434503932	97C3E0	9181 872080	RODION VASILEV	{"email": "rodion.vasilev.06091980@postgrespro.ru", "phone": "+70022125610"}
0005434503933	97C3E0	7694 548482	VIKTOR PAVLOV	{"phone": "+70326670768"}
0005434503934	5DB96D	5303 135331	ALEKSANDRA KUZNECOVA	{"phone": "+70442440271"}
0005434503935	5DB96D	5891 056797	VERA KALININA	{"phone": "+70186451669"}
0005434503936	63EA18	2724 563644	PAVEL NIKITIN	{"phone": "+70796101540"}
0005434503937	3249DE	7286 772214	EKATERINA DAVYDOVA	{"phone": "+70249311244"}
0005434503938	821B3D	7118 767173	DARYA SERGEEVA	{"email": "sergeeva_darya-26121972@postgrespro.ru", "phone": "+70088454494"}
0005434503939	821B3D	3261 810507	MARIYA ZAKHAROVA	{"email": "zakharova_mariya.19101967@postgrespro.ru", "phone": "+70328914622"}
0005434503940	61EDFE	6507 362905	YURIY PAVLOV	{"phone": "+70655720029"}
0005434503941	3A405A	2277 739334	RUSHANIYA SIDOROVA	{"phone": "+70634348571"}
0005434503942	3A405A	0039 524872	IVAN KUZNECOV	{"phone": "+70979450526"}
0005434503943	239143	1687 111785	MARAT IVANOV	{"email": "ivanovm1971@postgrespro.ru", "phone": "+70954042193"}
0005434503944	239143	5924 010980	ALEKSANDR ALEKSEEV	{"email": "a_alekseev.1961@postgrespro.ru", "phone": "+70358050365"}
0005434503945	239143	5111 991613	ALEKSEY ZHUKOV	{"phone": "+70826529518"}
0005434503946	A55DFD	9222 954003	OLEG IVANOV	{"email": "o.ivanov_071977@postgrespro.ru", "phone": "+70402925205"}
0005434503947	A55DFD	9161 788978	ANTON AFANASEV	{"phone": "+70680027271"}
0005434503948	FCFF10	4326 760287	OLEG KRASNOV	{"phone": "+70987665146"}
0005434503949	F238CF	6692 701252	LYUBOV FILATOVA	{"phone": "+70030751844"}
0005434503950	F238CF	8718 339649	MAKSIM BARANOV	{"phone": "+70512689848"}
0005434503951	F238CF	9009 033342	NINA LUKYANOVA	{"phone": "+70939086347"}
0005434503952	BBA24C	1607 779719	ILYA BELOV	{"email": "belov-ilya.1987@postgrespro.ru", "phone": "+70758616309"}
0005434503953	9B752B	0331 546249	ALEKSANDR PETROV	{"email": "aleksandr_petrov081974@postgrespro.ru", "phone": "+70371497201"}
0005434503954	9B752B	1984 559019	EVGENIY FILIPPOV	{"email": "filippov.evgeniy_021975@postgrespro.ru", "phone": "+70393079673"}
0005434503955	B24FA1	7286 105549	ALEKSEY KISELEV	{"email": "kiselevaleksey-1975@postgrespro.ru", "phone": "+70237873043"}
0005434503956	79C8F4	7877 323028	TAMARA ROMANOVA	{"phone": "+70051312311"}
0005434503957	89DE4D	0335 787956	ELENA MATVEEVA	{"phone": "+70084617463"}
0005434503958	89DE4D	7867 161806	ALEKSANDR VLASOV	{"email": "vlasova.1977@postgrespro.ru", "phone": "+70896401137"}
0005434503959	382BA1	3079 136469	NATALYA NESTEROVA	{"phone": "+70122304804"}
0005434503960	382BA1	0346 751142	NIKOLAY NAUMOV	{"email": "naumovn.081972@postgrespro.ru", "phone": "+70788933164"}
0005434503961	A0E149	3621 398726	LYUDMILA TARASOVA	{"phone": "+70355680263"}
0005434503962	A6C80A	8852 380318	SERGEY BORISOV	{"phone": "+70764655769"}
0005434503963	6BDBEC	2548 157935	MARIYA SMIRNOVA	{"email": "mariya.smirnova_1981@postgrespro.ru", "phone": "+70801347125"}
0005434503964	BC2533	5891 527256	MIKHAIL MELNIKOV	{"phone": "+70638413503"}
0005434503965	BC2533	5979 869231	YURIY NOVIKOV	{"email": "ynovikov-121966@postgrespro.ru", "phone": "+70498517613"}
0005434503966	166E10	3867 221408	LYUBOV KONOVALOVA	{"email": "lyubov-konovalova-041972@postgrespro.ru", "phone": "+70470613282"}
0005434503967	3C240D	3707 987098	VYACHESLAV SIDOROV	{"phone": "+70388044932"}
0005434503968	02662C	1554 574033	YULIYA KUZNECOVA	{"phone": "+70186748502"}
0005434503969	4BFF3E	1234 987729	ELENA ZHUKOVA	{"phone": "+70627811266"}
0005434503970	4BFF3E	4740 168593	MARINA STEPANOVA	{"email": "stepanova-marina1974@postgrespro.ru", "phone": "+70797315227"}
0005434503971	90B9DF	3032 193593	POLINA SCHERBAKOVA	{"email": "pscherbakova_061984@postgrespro.ru", "phone": "+70096780488"}
0005434503972	AFECC3	2747 311555	ELENA DENISOVA	{"phone": "+70836872505"}
0005434503973	15C764	1801 892687	GENNADIY TIMOFEEV	{"phone": "+70632675350"}
0005434503974	5F014A	4651 176015	MIKHAIL SEMENOV	{"phone": "+70378356445"}
0005434503975	5F014A	4930 878749	VIKTORIYA NESTEROVA	{"email": "nesterovav_071971@postgrespro.ru", "phone": "+70024839205"}
0005434503976	C597CC	6354 113922	VALENTINA MAKSIMOVA	{"phone": "+70565974182"}
0005434503977	1755A4	0045 671321	SERGEY BORISOV	{"email": "borisov_s_1975@postgrespro.ru", "phone": "+70335353720"}
0005434503978	443BB7	0872 426142	LARISA DENISOVA	{"email": "denisova.larisa.1987@postgrespro.ru", "phone": "+70227882921"}
0005434503979	443BB7	9711 250697	YAROSLAV DENISOV	{"phone": "+70244037949"}
0005434503980	FBE3D2	7470 633218	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr.17021976@postgrespro.ru", "phone": "+70346500113"}
0005434503981	FBE3D2	6303 957561	LIDIYA ARKHIPOVA	{"phone": "+70374986627"}
0005434503982	1B0508	8911 815045	NAIL BELOV	{"email": "belov.nail_04041965@postgrespro.ru", "phone": "+70047531205"}
0005434503983	0B563A	4092 381974	ELENA BELYAEVA	{"phone": "+70312037874"}
0005434503984	73FF97	1158 191476	YURIY ALEKSANDROV	{"phone": "+70734453073"}
0005434503985	73FF97	8433 254002	LYUDMILA BELYAEVA	{"phone": "+70469137547"}
0005434503986	8E0D05	4411 013632	RAVIL ZAYCEV	{"phone": "+70006148442"}
0005434503987	9EE33D	2487 621677	FEDOR KOROLEV	{"email": "fkorolev_06081972@postgrespro.ru", "phone": "+70156433631"}
0005434503988	2431AC	8989 267326	SERGEY POPOV	{"phone": "+70653894034"}
0005434503989	C6C364	2896 537047	MARGARITA LEBEDEVA	{"email": "m.lebedeva22041977@postgrespro.ru", "phone": "+70379598531"}
0005434503990	7009C1	6596 165490	KIRILL NAUMOV	{"email": "naumov.k.051966@postgrespro.ru", "phone": "+70770309310"}
0005434503991	09ABB7	6679 772672	LYUDMILA POPOVA	{"email": "popoval.1965@postgrespro.ru", "phone": "+70283439842"}
0005434503992	03C3B3	2709 817939	ARTEM TIKHONOV	{"email": "artem-tikhonov26051971@postgrespro.ru", "phone": "+70821711075"}
0005434503993	EEDF8C	1800 816680	ALEKSANDRA ZAKHAROVA	{"phone": "+70145522683"}
0005434503994	EEDF8C	4614 822018	EKATERINA VOLKOVA	{"phone": "+70166894155"}
0005434503995	D97021	9465 432910	VALERIYA ROMANOVA	{"email": "valeriyaromanova_1973@postgrespro.ru", "phone": "+70029758384"}
0005434503996	D07ACD	1218 496214	DAMIR STEPANOV	{"email": "stepanovd1971@postgrespro.ru", "phone": "+70713284578"}
0005434503997	D07ACD	9348 475463	IVAN IVANOV	{"email": "ivanov_ivan.23041984@postgrespro.ru", "phone": "+70524441362"}
0005434503998	DBB1FA	1671 580768	NIKOLAY SMIRNOV	{"email": "smirnovn.1973@postgrespro.ru", "phone": "+70087657977"}
0005434503999	116318	7313 599906	LILIYA SCHERBAKOVA	{"phone": "+70720564680"}
0005434504000	6F70F2	4152 357669	ILYA BELOV	{"phone": "+70591931548"}
0005434504001	064AD8	2659 778874	KSENIYA KONOVALOVA	{"email": "konovalova_kseniya-18011967@postgrespro.ru", "phone": "+70924989124"}
0005434504002	86634E	3895 568593	DMITRIY IVANOV	{"phone": "+70217967032"}
0005434504003	86634E	9600 915644	VALENTINA NIKIFOROVA	{"email": "vnikiforova1966@postgrespro.ru", "phone": "+70411073577"}
0005434504004	A0F22A	4073 832019	ANNA ALEKSEEVA	{"phone": "+70447496320"}
0005434504005	3BADE3	1443 329293	TAMARA NIKIFOROVA	{"phone": "+70366947080"}
0005434504006	7A09FB	4417 748088	ELENA VASILEVA	{"email": "e.vasileva_1966@postgrespro.ru", "phone": "+70544991596"}
0005434504007	3A569F	4496 613051	EGOR SHEVCHENKO	{"email": "e-shevchenko_1953@postgrespro.ru", "phone": "+70281610122"}
0005434504008	F40F63	5316 686315	ELENA KALININA	{"phone": "+70244796006"}
0005434504009	AF34DF	2625 080685	ALEKSEY KUZNECOV	{"phone": "+70114405048"}
0005434504010	49D965	9579 294006	SERGEY IVANOV	{"phone": "+70163405158"}
0005434504011	9D8DDC	3104 665590	MIKHAIL KUZMIN	{"email": "mikhailkuzmin13051972@postgrespro.ru", "phone": "+70586769580"}
0005434504012	E2DD2E	9209 479647	KRISTINA ANDREEVA	{"phone": "+70131158649"}
0005434504013	E2DD2E	6719 407584	ALEKSANDR AFANASEV	{"email": "afanaseva1968@postgrespro.ru", "phone": "+70728864014"}
0005434504014	D22BFF	5437 035437	GALINA KULIKOVA	{"email": "g.kulikova101968@postgrespro.ru", "phone": "+70279165273"}
0005434504015	D22BFF	9556 318932	LYUDMILA MALYSHEVA	{"email": "l_malysheva.061983@postgrespro.ru", "phone": "+70642808441"}
0005434504016	BBA76B	8527 169852	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova071973@postgrespro.ru", "phone": "+70626732462"}
0005434504017	489D61	2682 664392	DENIS IVANOV	{"phone": "+70709077017"}
0005434504018	F3853D	3397 597739	ALEKSANDR VOLKOV	{"phone": "+70928819430"}
0005434504019	0BA94C	8078 516714	OLEG IVANOV	{"email": "oivanov1972@postgrespro.ru", "phone": "+70089020260"}
0005434504020	2F267A	5885 618230	RASUL ORLOV	{"email": "r.orlov.091976@postgrespro.ru", "phone": "+70096422775"}
0005434504021	2F267A	3927 226239	OLGA MIRONOVA	{"phone": "+70419343284"}
0005434504022	69E7FF	4740 456600	ROMAN ABRAMOV	{"email": "roman.abramov-11101965@postgrespro.ru", "phone": "+70720995250"}
0005434504023	17042C	2557 297077	VLADIMIR RODIONOV	{"email": "vladimirrodionov.30121975@postgrespro.ru", "phone": "+70850058154"}
0005434504024	BE2F7A	3579 981606	RAISA ALEKSANDROVA	{"phone": "+70509215439"}
0005434504025	C5E63D	1750 803657	NIKITA VOLKOV	{"email": "nvolkov.081965@postgrespro.ru", "phone": "+70095331836"}
0005434504026	BB58CA	4945 844561	ALEKSANDR ANTONOV	{"phone": "+70602202667"}
0005434504027	E664B7	8867 640877	OLESYA ABRAMOVA	{"email": "o_abramova_1981@postgrespro.ru", "phone": "+70715697575"}
0005434504028	E664B7	8704 809610	TATYANA SOROKINA	{"phone": "+70141731174"}
0005434504029	F740D1	6143 124896	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova1972@postgrespro.ru", "phone": "+70785388383"}
0005434504030	1BFE34	2632 945309	VERA MOISEEVA	{"phone": "+70759354876"}
0005434504031	5CA4F2	4065 338798	LIDIYA NOVIKOVA	{"email": "novikova.lidiya1962@postgrespro.ru", "phone": "+70795780589"}
0005434504032	5CA4F2	8175 431023	ANASTASIYA ARKHIPOVA	{"phone": "+70496194293"}
0005434504033	BE0C9A	6766 471774	SERGEY DENISOV	{"phone": "+70457495582"}
0005434504034	BE0C9A	5990 976498	ALEKSEY NIKITIN	{"email": "nikitin-aleksey_071974@postgrespro.ru", "phone": "+70832321043"}
0005434504035	1DDADF	2790 599212	OLEG KUZNECOV	{"phone": "+70860973378"}
0005434504036	410C51	8004 407127	ANATOLIY ZAYCEV	{"phone": "+70766839685"}
0005434504037	410C51	1715 671529	RAFAIL AFANASEV	{"phone": "+70218172119"}
0005434504038	410C51	6202 537914	ANNA NAZAROVA	{"phone": "+70253794786"}
0005434504039	2495FA	3248 364678	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylovaaleksandra07051968@postgrespro.ru", "phone": "+70560310103"}
0005434504040	7AAFD2	4053 752380	EDUARD KISELEV	{"email": "kiselev.eduard101969@postgrespro.ru", "phone": "+70426058796"}
0005434504041	1DAA3B	4438 854120	NADEZHDA EFIMOVA	{"email": "efimova-nadezhda-25111970@postgrespro.ru", "phone": "+70417658940"}
0005434504042	1DAA3B	7869 235150	ANDREY TIMOFEEV	{"email": "andrey.timofeev_081972@postgrespro.ru", "phone": "+70119692238"}
0005434504043	1DAA3B	3544 252774	ALEKSANDR MIKHAYLOV	{"phone": "+70803647546"}
0005434504044	099FAD	0852 698287	DMITRIY CHERNOV	{"email": "chernov.d-071972@postgrespro.ru", "phone": "+70199784213"}
0005434504045	15A467	1998 728055	SERGEY SCHERBAKOV	{"email": "scherbakovsergey14011968@postgrespro.ru", "phone": "+70994190039"}
0005434504046	86F8B3	5825 824547	SVETLANA SOKOLOVA	{"email": "ssokolova-061973@postgrespro.ru", "phone": "+70738956719"}
0005434504047	44C746	3196 808182	ARTEM POPOV	{"email": "artem_popov-011972@postgrespro.ru", "phone": "+70602352232"}
0005434504048	44C746	9725 898921	EVGENIY ALEKSANDROV	{"phone": "+70312914010"}
0005434504049	6C4C8F	7056 467548	TATYANA SERGEEVA	{"phone": "+70914266387"}
0005434504050	04E969	4806 362460	ALEKSANDR PETROV	{"email": "aleksandr.petrov-1983@postgrespro.ru", "phone": "+70866132838"}
0005434504051	BC1F4C	9934 831494	GALINA KONDRATEVA	{"email": "kondrateva.galina.1983@postgrespro.ru", "phone": "+70176723437"}
0005434504052	8E4574	2072 715716	KAMILLA ZAKHAROVA	{"phone": "+70684920550"}
0005434504053	AE43A6	0558 040570	MARAT NIKITIN	{"phone": "+70895605522"}
0005434504054	0768BB	5737 723818	NADEZHDA MIRONOVA	{"email": "mironova-nadezhda.101985@postgrespro.ru", "phone": "+70584800716"}
0005434504055	BF71F7	5326 913299	OLGA DMITRIEVA	{"email": "olga.dmitrieva_021970@postgrespro.ru", "phone": "+70314673933"}
0005434504056	BF71F7	0194 179167	IRINA BELOVA	{"email": "irina.belova.11071974@postgrespro.ru", "phone": "+70602367706"}
0005434504057	2714E5	6466 745679	IVAN MATVEEV	{"email": "matveev.i.1979@postgrespro.ru", "phone": "+70217318815"}
0005434504058	570987	5599 874637	VLADIMIR TARASOV	{"email": "tarasov-vladimir.1966@postgrespro.ru", "phone": "+70917740818"}
0005434504059	96A181	2437 079207	IRINA ZAKHAROVA	{"phone": "+70972691187"}
0005434504060	96A181	8231 645229	ALEKSANDR MOISEEV	{"email": "moiseev-a.091976@postgrespro.ru", "phone": "+70088560648"}
0005434504061	825488	8836 075749	VIKTOR SCHERBAKOV	{"phone": "+70935036860"}
0005434504062	41E102	4240 061027	TATYANA KOVALEVA	{"phone": "+70352277969"}
0005434504063	429009	7322 115533	VERA KOZLOVA	{"phone": "+70755203071"}
0005434504064	429009	3296 202621	IRINA EGOROVA	{"email": "iegorova20071985@postgrespro.ru", "phone": "+70315948620"}
0005434504065	779A72	4796 308481	TAMARA ABRAMOVA	{"phone": "+70287477163"}
0005434504066	61DB09	7632 338394	TATYANA ZOTOVA	{"email": "zotova.tatyana_03081975@postgrespro.ru", "phone": "+70512189242"}
0005434504067	B80191	8748 677521	LYUDMILA SOKOLOVA	{"phone": "+70346602295"}
0005434504068	EE11A7	4315 496972	IRINA GORBUNOVA	{"phone": "+70312308901"}
0005434504069	158AB1	0158 683251	VERA SAVELEVA	{"phone": "+70946613054"}
0005434504070	5B0D39	5533 914944	OKSANA MAKAROVA	{"phone": "+70045879485"}
0005434504071	DA5BCD	4350 282432	VALENTINA BARANOVA	{"email": "baranova.valentina081978@postgrespro.ru", "phone": "+70850638887"}
0005434504072	878487	9975 916645	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr.06101969@postgrespro.ru", "phone": "+70471059282"}
0005434504073	878487	7516 048399	GALINA ROMANOVA	{"email": "romanova_g_121978@postgrespro.ru", "phone": "+70614766090"}
0005434504074	190FE9	8407 313117	VIKTOR ANDREEV	{"phone": "+70319706979"}
0005434504075	51BA6C	5879 124867	VADIM STEPANOV	{"phone": "+70713313033"}
0005434504076	FD29A1	2225 151201	ILYA FILIPPOV	{"email": "filippov.i01091971@postgrespro.ru", "phone": "+70457741049"}
0005434504077	1F4F3E	9177 295246	OLGA KOZLOVA	{"email": "kozlova.olga-091967@postgrespro.ru", "phone": "+70646769428"}
0005434504078	A8BE2B	6065 748648	VENERA EGOROVA	{"email": "venera_egorova_061973@postgrespro.ru", "phone": "+70524983183"}
0005434504079	9437D2	5179 836923	IRAIDA ZAKHAROVA	{"phone": "+70916862376"}
0005434504080	9437D2	7360 224376	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr_061956@postgrespro.ru", "phone": "+70727644234"}
0005434504081	94B686	8359 658483	EVGENIY POPOV	{"email": "e_popov.09091976@postgrespro.ru", "phone": "+70973702759"}
0005434504082	748FEF	7473 474373	ALEKSANDR IVANOV	{"phone": "+70736365863"}
0005434504083	748FEF	9789 997786	NADIYA EFREMOVA	{"email": "efremova_nadiya.061980@postgrespro.ru", "phone": "+70629198524"}
0005434504084	31C736	0488 458665	ARTEM KRASNOV	{"phone": "+70822213057"}
0005434504085	306CC2	1277 762237	EKATERINA RYABOVA	{"phone": "+70666981188"}
0005434504086	1D40CA	2735 805411	RUSLAN TARASOV	{"phone": "+70377508983"}
0005434504087	1D40CA	6929 470213	MIKHAIL ISAEV	{"email": "isaev_m1972@postgrespro.ru", "phone": "+70154211794"}
0005434504088	0B00B9	5724 651248	IGOR SAVELEV	{"phone": "+70907116927"}
0005434504089	F7147E	0544 780690	NATALYA SOKOLOVA	{"email": "n_sokolova_1985@postgrespro.ru", "phone": "+70615052760"}
0005434504090	F7147E	4145 292254	VYACHESLAV BARANOV	{"phone": "+70090901262"}
0005434504091	1A97C6	8683 215038	LIDIYA RYABOVA	{"phone": "+70618113106"}
0005434504092	4FFE43	7288 325400	SERAFIMA MOROZOVA	{"email": "smorozova.1972@postgrespro.ru", "phone": "+70671555287"}
0005434504093	EAE244	6274 343608	EVGENIYA YAKOVLEVA	{"email": "yakovleva.e-17121965@postgrespro.ru", "phone": "+70108318493"}
0005434504094	70A4F0	1092 915269	MARIYA KUZNECOVA	{"email": "mariyakuznecova-121972@postgrespro.ru", "phone": "+70182662260"}
0005434504095	C74166	2467 308476	GALINA KAZAKOVA	{"email": "kazakova_galina.1967@postgrespro.ru", "phone": "+70687209761"}
0005434504096	D5C992	6069 528820	GALINA FOMINA	{"email": "g-fomina-011976@postgrespro.ru", "phone": "+70418207635"}
0005434504097	91623A	3619 355787	YURIY STEPANOV	{"email": "stepanov.yuriy041964@postgrespro.ru", "phone": "+70101576554"}
0005434504098	C8C54B	0960 818566	YURIY GUSEV	{"phone": "+70218838983"}
0005434504099	963E3E	6758 020802	VALERIY BORISOV	{"phone": "+70326797841"}
0005434504100	963E3E	2413 237145	IRINA DAVYDOVA	{"phone": "+70781052180"}
0005434504101	326FAF	5839 565418	LARISA BORISOVA	{"email": "borisova.l-05011967@postgrespro.ru", "phone": "+70464439203"}
0005434504102	25EE43	6058 816670	MARIYA POPOVA	{"phone": "+70339160268"}
0005434504103	25EE43	6515 869010	VASILIY ANTONOV	{"phone": "+70164580568"}
0005434504104	A03E49	5718 483595	ELENA FEDOROVA	{"phone": "+70306561795"}
0005434504105	AA62DD	4260 890374	GALINA KUZMINA	{"phone": "+70833160086"}
0005434504106	AA62DD	0565 740274	POLINA KUZNECOVA	{"phone": "+70280755634"}
0005434504107	DCE193	9766 216684	ULYANA MIRONOVA	{"email": "mironova_u_07121978@postgrespro.ru", "phone": "+70116238879"}
0005434504108	A0C4DA	7095 523994	STEPAN DMITRIEV	{"email": "s_dmitriev_13071976@postgrespro.ru", "phone": "+70107464957"}
0005434504109	076770	8176 211225	ALEKSANDR SAVELEV	{"email": "a_savelev1961@postgrespro.ru", "phone": "+70231122008"}
0005434504110	076770	9721 168702	IRINA KARPOVA	{"email": "karpova-irina30011969@postgrespro.ru", "phone": "+70457516021"}
0005434504111	2E0C71	6984 063405	SVETLANA EGOROVA	{"email": "egorova-svetlana-1975@postgrespro.ru", "phone": "+70813434150"}
0005434504112	0F295E	7747 613161	DARYA KUZNECOVA	{"phone": "+70521161480"}
0005434504113	D5AE3E	2463 186951	ALISA FEDOROVA	{"phone": "+70709518004"}
0005434504114	D5AE3E	9174 948929	NATALYA ARKHIPOVA	{"phone": "+70890186853"}
0005434504115	AC932C	5916 802827	IRINA OSIPOVA	{"phone": "+70021933036"}
0005434504116	AC932C	1456 936271	ELENA LAZAREVA	{"phone": "+70685754771"}
0005434504117	BEEC94	7975 745287	SERGEY KOZLOV	{"phone": "+70827294658"}
0005434504118	BEEC94	0221 971735	GENNADIY ZAKHAROV	{"email": "zakharov_gennadiy041972@postgrespro.ru", "phone": "+70382445993"}
0005434504119	CC7FEE	1804 300295	ALEKSEY TIKHONOV	{"phone": "+70524916020"}
0005434504120	EE6A13	4380 055333	MARIYA DANILOVA	{"phone": "+70224928397"}
0005434504121	EE6A13	7929 751503	ALEKSEY POPOV	{"email": "a-popov.16021962@postgrespro.ru", "phone": "+70369216521"}
0005434504122	5EEA4A	8023 321176	VALERIY MOROZOV	{"email": "valeriy.morozov_061976@postgrespro.ru", "phone": "+70252767394"}
0005434504123	073546	1881 103395	ANDREY DENISOV	{"email": "andrey.denisov.051973@postgrespro.ru", "phone": "+70793795270"}
0005434504124	073546	8655 636605	VALENTINA DENISOVA	{"email": "denisova.valentina.1981@postgrespro.ru", "phone": "+70775430361"}
0005434504125	073546	6627 925470	ALFIYA MEDVEDEVA	{"email": "alfiya.medvedeva.24091975@postgrespro.ru", "phone": "+70738444494"}
0005434504126	48BAC1	3639 879409	ANNA NIKOLAEVA	{"email": "anna.nikolaeva.1970@postgrespro.ru", "phone": "+70012838256"}
0005434504127	CEF2A0	1035 973676	VERA NESTEROVA	{"email": "nesterovavera-071970@postgrespro.ru", "phone": "+70029512984"}
0005434504128	CEF2A0	4790 596971	LIDIYA SOKOLOVA	{"email": "lidiya_sokolova_041975@postgrespro.ru", "phone": "+70676723477"}
0005434504129	269936	3255 374488	ELENA KONOVALOVA	{"phone": "+70279034558"}
0005434504130	D8C77C	0108 013400	STANISLAV YAKOVLEV	{"email": "yakovlev-stanislav.081977@postgrespro.ru", "phone": "+70625836262"}
0005434504131	498488	0273 543587	ALEKSEY KUZNECOV	{"email": "a.kuznecov.1960@postgrespro.ru", "phone": "+70454268462"}
0005434504132	48B358	0956 933931	OLGA TARASOVA	{"email": "tarasova_o-1971@postgrespro.ru", "phone": "+70924459565"}
0005434504133	4B7355	8771 464267	OKSANA ILINA	{"email": "oksana_ilina.1968@postgrespro.ru", "phone": "+70436857796"}
0005434504134	5714E7	7458 616581	VALENTINA GERASIMOVA	{"email": "gerasimova.valentina1974@postgrespro.ru", "phone": "+70526538348"}
0005434504135	5714E7	7114 203557	DENIS FEDOTOV	{"email": "fedotov.d.27031971@postgrespro.ru", "phone": "+70326986461"}
0005434504136	D7B065	7679 189939	EVGENIY MEDVEDEV	{"phone": "+70602950605"}
0005434504137	6F2DDE	3501 671145	EVGENIY BARANOV	{"phone": "+70644047581"}
0005434504138	551CDE	8621 525727	LIDIYA SOLOVEVA	{"phone": "+70300946355"}
0005434504139	4FEEB7	2661 688518	NIKOLAY ALEKSANDROV	{"email": "n.aleksandrov_1980@postgrespro.ru", "phone": "+70184120149"}
0005434504140	4FEEB7	2876 565946	MIKHAIL ALEKSANDROV	{"email": "aleksandrov-mikhail.25031984@postgrespro.ru", "phone": "+70243835915"}
0005434504141	536AD9	9389 216328	BOGDAN ZAYCEV	{"email": "zaycev-bogdan_101974@postgrespro.ru", "phone": "+70952235747"}
0005434504142	9F31AF	5864 872211	VIKTOR GERASIMOV	{"phone": "+70587464151"}
0005434504143	9F31AF	6736 460236	TAISIYA KOZLOVA	{"phone": "+70582301374"}
0005434504144	8E9530	4314 856473	KRISTINA NOVIKOVA	{"phone": "+70408628430"}
0005434504145	DC88AF	8783 063256	OLGA EFREMOVA	{"phone": "+70754422429"}
0005434504146	4B7B88	2962 315759	ARTUR ZAKHAROV	{"email": "zakharov.artur1973@postgrespro.ru", "phone": "+70057429924"}
0005434504147	913B90	0993 567398	OLGA NIKITINA	{"phone": "+70564980737"}
0005434504148	C33C59	6312 348469	ALEKSANDR TARASOV	{"phone": "+70522625329"}
0005434504149	C33C59	5193 101620	VALENTINA KUZMINA	{"phone": "+70014703267"}
0005434504150	3FC16B	3907 345635	VLADIMIR PETROV	{"email": "v-petrov_1973@postgrespro.ru", "phone": "+70243505149"}
0005434504151	FCEE02	8163 104294	DENIS ANTONOV	{"phone": "+70027163881"}
0005434504152	1EAEB6	2719 322609	DANIL AFANASEV	{"email": "dafanasev21041973@postgrespro.ru", "phone": "+70757754240"}
0005434504153	1EAEB6	9099 498049	ALEVTINA ZAKHAROVA	{"email": "zakharova_alevtina.121974@postgrespro.ru", "phone": "+70806854131"}
0005434504154	DB7687	5003 250902	GRIGORIY VOLKOV	{"email": "gvolkov-28101967@postgrespro.ru", "phone": "+70978353160"}
0005434504155	BC4378	3056 495834	VALENTIN PAVLOV	{"phone": "+70560217147"}
0005434504156	2AF560	3587 892549	NINA ISAEVA	{"phone": "+70162193020"}
0005434504157	FD8A79	4330 835618	LYUBOV FILIPPOVA	{"phone": "+70860788500"}
0005434504158	EC662D	2401 840424	RUSLAN AFANASEV	{"email": "ruslan.afanasev_1963@postgrespro.ru", "phone": "+70536786993"}
0005434504159	EC662D	5353 004902	TATYANA LUKYANOVA	{"email": "lukyanova_tatyana-101971@postgrespro.ru", "phone": "+70551516527"}
0005434504160	E3C8C4	4619 270314	YAKOV KOZLOV	{"email": "kozlovy.1963@postgrespro.ru", "phone": "+70035647334"}
0005434504161	E3C8C4	6656 869719	MARIYA YAKOVLEVA	{"email": "m-yakovleva_1970@postgrespro.ru", "phone": "+70331303235"}
0005434504162	34919D	6493 197026	VIKTOR BARANOV	{"phone": "+70735519665"}
0005434504163	C8993C	9245 861735	DMITRIY TIKHONOV	{"phone": "+70348156543"}
0005434504164	718AAB	9049 503288	SERGEY SAVELEV	{"email": "savelev.s.16031965@postgrespro.ru", "phone": "+70441668495"}
0005434504165	18055F	1066 774771	ELENA DAVYDOVA	{"phone": "+70426754940"}
0005434504166	EAF95E	9730 139288	IVAN ORLOV	{"phone": "+70941091267"}
0005434504167	EAF95E	4495 886094	DARYA OSIPOVA	{"phone": "+70641122207"}
0005434504168	63AF42	3772 745913	VALENTINA SOKOLOVA	{"email": "sokolova.v23031972@postgrespro.ru", "phone": "+70728398681"}
0005434504169	63AF42	9586 771201	ELENA POPOVA	{"phone": "+70710393239"}
0005434504170	6353F8	4839 620228	ELENA MATVEEVA	{"phone": "+70571294531"}
0005434504171	FBD5B6	3709 762910	NINA DENISOVA	{"email": "nina_denisova.1969@postgrespro.ru", "phone": "+70712991380"}
0005434504172	506321	3277 122936	NINA ILINA	{"email": "nina_ilina-1957@postgrespro.ru", "phone": "+70818722576"}
0005434504173	0ABE65	7863 067929	EKATERINA MIRONOVA	{"phone": "+70692169959"}
0005434504174	4D634E	7635 742546	ANNA GERASIMOVA	{"phone": "+70299170824"}
0005434504175	4D634E	8474 156862	GRIGORIY ZAYCEV	{"phone": "+70461465471"}
0005434504176	3AAA9E	0786 249178	LYUBOV KOMAROVA	{"phone": "+70261434026"}
0005434504177	3AAA9E	5819 357105	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila.03111977@postgrespro.ru", "phone": "+70598610871"}
0005434504178	5959CF	1066 827739	ALFIYA KOZLOVA	{"phone": "+70779187225"}
0005434504179	5959CF	4905 866779	RAISA SAVELEVA	{"email": "r.saveleva02041971@postgrespro.ru", "phone": "+70574885945"}
0005434504180	BED929	4447 654382	ELENA GUSEVA	{"email": "eguseva28071977@postgrespro.ru", "phone": "+70861047632"}
0005434504181	E5EEDC	4997 618688	ALENA FEDOROVA	{"email": "fedorova_a-1986@postgrespro.ru", "phone": "+70566416885"}
0005434504182	BB6978	3286 457258	IRINA NIKITINA	{"phone": "+70570914659"}
0005434504183	34CE7B	1213 785794	TATYANA IVANOVA	{"phone": "+70150421628"}
0005434504184	34CE7B	0233 815536	LYUDMILA RODIONOVA	{"phone": "+70750944519"}
0005434504185	D73ACE	8044 497466	INNA KUZMINA	{"email": "kuzmina_inna-1968@postgrespro.ru", "phone": "+70166606636"}
0005434504186	D73ACE	5778 425858	VALERIY MAKSIMOV	{"phone": "+70201377884"}
0005434504187	92375E	0669 968715	SERGEY KUDRYASHOV	{"phone": "+70474583304"}
0005434504188	43BE19	2221 603695	MARIYA FEDOROVA	{"email": "fedorova.mariya01061967@postgrespro.ru", "phone": "+70328437542"}
0005434504189	2C5395	1875 859817	LYUDMILA TROFIMOVA	{"phone": "+70063975303"}
0005434504190	6A04F8	4402 447416	DENIS KRASNOV	{"email": "denis-krasnov_011973@postgrespro.ru", "phone": "+70240351752"}
0005434504191	7151DF	0253 830042	LYUBOV ILINA	{"phone": "+70463606966"}
0005434504192	DFF8DC	6587 393963	ANDREY OSIPOV	{"email": "osipovandrey_21051973@postgrespro.ru", "phone": "+70092794957"}
0005434504193	B22898	8020 730029	OLESYA MAKSIMOVA	{"email": "olesyamaksimova_081974@postgrespro.ru", "phone": "+70283400335"}
0005434504194	5BDA99	2857 060497	PAVEL KUDRYASHOV	{"email": "kudryashov.p_081975@postgrespro.ru", "phone": "+70403766711"}
0005434504195	8D751B	9727 084033	ALEKSEY FROLOV	{"phone": "+70280022041"}
0005434504196	DCD98C	7736 268905	ANASTASIYA SAVELEVA	{"email": "saveleva_anastasiya-041967@postgrespro.ru", "phone": "+70279318480"}
0005434504197	DCD98C	1785 397976	TATYANA SERGEEVA	{"email": "sergeevatatyana-1968@postgrespro.ru", "phone": "+70554835901"}
0005434504198	6FFB6A	6367 703996	VADIM IVANOV	{"phone": "+70119084159"}
0005434504199	6FFB6A	5214 685382	SERGEY SOLOVEV	{"email": "solovev-s.051977@postgrespro.ru", "phone": "+70504069522"}
0005434504200	67966A	9956 691752	DENIS MAKSIMOV	{"email": "dmaksimov_031979@postgrespro.ru", "phone": "+70796145984"}
0005434504201	6DD1F0	6672 031967	DMITRIY IVANOV	{"email": "dmitriyivanov_28121972@postgrespro.ru", "phone": "+70221337551"}
0005434504202	6DD1F0	7731 383265	TATYANA EFIMOVA	{"phone": "+70649585620"}
0005434504203	DFF3D3	1354 305541	GRIGORIY BORISOV	{"email": "borisov_g-061969@postgrespro.ru", "phone": "+70486551692"}
0005434504204	EC18A5	6755 872759	ROZA GUSEVA	{"email": "rguseva_011977@postgrespro.ru", "phone": "+70847181253"}
0005434504205	682525	8409 726819	FEDOR FOMIN	{"email": "ffomin_031979@postgrespro.ru", "phone": "+70595643008"}
0005434504206	22A330	7684 223369	ALEKSANDR PETROV	{"email": "aleksandr-petrov.20021967@postgrespro.ru", "phone": "+70546458869"}
0005434504207	E84F6C	4265 935892	GENNADIY MOROZOV	{"phone": "+70060644249"}
0005434504208	E84F6C	3536 277109	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov-1969@postgrespro.ru", "phone": "+70454767272"}
0005434504209	3D674C	5848 830431	IVAN CHERNOV	{"email": "chernovi05051978@postgrespro.ru", "phone": "+70324662888"}
0005434504210	24C29D	3580 829664	GALINA MAKAROVA	{"phone": "+70470622481"}
0005434504211	24C29D	3957 107391	ELENA AKIMOVA	{"phone": "+70203938187"}
0005434504212	13BE18	1629 732655	NINA ZHUKOVA	{"email": "zhukova-nina-091971@postgrespro.ru", "phone": "+70977415742"}
0005434504213	13BE18	5506 829410	IRINA OSIPOVA	{"phone": "+70674790549"}
0005434504214	0E7815	5744 881948	DAMIR VLASOV	{"email": "vlasov_damir_1969@postgrespro.ru", "phone": "+70599153434"}
0005434504215	7B6FBF	8074 852956	KHALIDA KOLESNIKOVA	{"email": "kolesnikova-k-011985@postgrespro.ru", "phone": "+70523170740"}
0005434504216	4D9FCA	0933 808048	VIKTOR KISELEV	{"email": "kiselev.viktor-02081991@postgrespro.ru", "phone": "+70430969013"}
0005434504276	E35AD1	8061 077674	ANNA NESTEROVA	{"phone": "+70399823160"}
0005434504217	755CDC	2679 022857	VLADISLAV EGOROV	{"email": "vladislavegorov1971@postgrespro.ru", "phone": "+70196977518"}
0005434504218	27DE43	1645 981596	EVGENIY SMIRNOV	{"email": "e.smirnov_29011972@postgrespro.ru", "phone": "+70873382622"}
0005434504219	0B4904	8856 631984	MARIYA TIMOFEEVA	{"phone": "+70610168874"}
0005434504220	76AD50	8288 737374	EVGENIY KUZNECOV	{"phone": "+70392131062"}
0005434504221	ADFA58	7619 155471	SVETLANA ZHURAVLEVA	{"phone": "+70117946812"}
0005434504222	ADFA58	0237 237859	MAKSIM SAVELEV	{"email": "savelevmaksim_111969@postgrespro.ru", "phone": "+70143350480"}
0005434504223	FF037D	4769 278456	ALEVTINA NIKITINA	{"email": "anikitina061961@postgrespro.ru", "phone": "+70511865041"}
0005434504224	775C9D	8786 064913	OLGA VLASOVA	{"phone": "+70687591572"}
0005434504225	775C9D	5438 838468	MAKSIM SERGEEV	{"phone": "+70550679339"}
0005434504226	16FE5A	2559 314423	SVETLANA FEDOROVA	{"phone": "+70660861447"}
0005434504227	16FE5A	2120 706814	NATALYA MOISEEVA	{"phone": "+70302954626"}
0005434504228	60D151	0444 704861	DMITRIY PAVLOV	{"phone": "+70347648253"}
0005434504229	60D151	8338 224178	SERGEY MIKHAYLOV	{"phone": "+70068206868"}
0005434504230	192A12	3279 601550	GALINA KALININA	{"phone": "+70389370942"}
0005434504231	F9C67F	5557 781211	VLADIMIR EGOROV	{"email": "vladimir-egorov1978@postgrespro.ru", "phone": "+70731481723"}
0005434504232	F9C67F	9348 226089	GALINA ROMANOVA	{"email": "romanova-galina.051972@postgrespro.ru", "phone": "+70040115726"}
0005434504233	3D68D9	1897 572842	ALEKSEY BORISOV	{"email": "borisova1982@postgrespro.ru", "phone": "+70383694144"}
0005434504234	C37B81	6183 213985	SERGEY KUDRYASHOV	{"phone": "+70638151055"}
0005434504235	C37B81	1114 122747	EDUARD TARASOV	{"phone": "+70466012423"}
0005434504236	67C1FF	5997 891910	ARTEM MAKAROV	{"email": "makarov_artem.1962@postgrespro.ru", "phone": "+70914724901"}
0005434504237	67C1FF	0477 749042	ANTON ZAKHAROV	{"phone": "+70168510375"}
0005434504238	67C1FF	6459 063420	EVGENIY FILIPPOV	{"email": "evgeniyfilippov.08011960@postgrespro.ru", "phone": "+70500255258"}
0005434504239	EA31B6	8631 993744	MAKSIM MAKAROV	{"phone": "+70264105950"}
0005434504240	EA31B6	1207 869057	VALENTINA PETROVA	{"email": "petrova-valentina.27051983@postgrespro.ru", "phone": "+70341769386"}
0005434504241	7DA240	2080 037834	VALENTINA FROLOVA	{"phone": "+70288911968"}
0005434504242	7DA240	4577 653587	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr-081962@postgrespro.ru", "phone": "+70236330966"}
0005434504243	230A78	6537 101554	MILENA LOGINOVA	{"email": "loginova-m16101979@postgrespro.ru", "phone": "+70680408156"}
0005434504244	6C0AE4	2270 484179	DMITRIY MIKHAYLOV	{"email": "dmitriy-mikhaylov-071971@postgrespro.ru", "phone": "+70028450142"}
0005434504245	6C0AE4	4965 979834	MARIYA FILIPPOVA	{"phone": "+70322902644"}
0005434504246	38792A	5946 936563	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov041973@postgrespro.ru", "phone": "+70209410469"}
0005434504247	047392	6105 922781	YULIYA NESTEROVA	{"phone": "+70637554857"}
0005434504248	047392	5835 824503	ANDREY GRIGOREV	{"phone": "+70048621682"}
0005434504249	470878	9310 747161	RUSLAN IVANOV	{"email": "r.ivanov10061981@postgrespro.ru", "phone": "+70343046143"}
0005434504250	66380E	4885 805707	EVGENIY VOROBEV	{"email": "vorobev_evgeniy1966@postgrespro.ru", "phone": "+70155940636"}
0005434504251	66380E	2427 604783	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov071973@postgrespro.ru", "phone": "+70670207346"}
0005434504252	85A297	1982 898698	ANTONINA GUSEVA	{"email": "aguseva_13021971@postgrespro.ru", "phone": "+70747051805"}
0005434504309	3333D0	4501 888966	VALERIY MELNIKOV	{"phone": "+70027315518"}
0005434504253	213548	7065 252308	EKATERINA ANISIMOVA	{"email": "ekaterina.anisimova.031979@postgrespro.ru", "phone": "+70487260475"}
0005434504254	E92C36	2485 941154	NATALIYA DENISOVA	{"email": "denisova_nataliya_28101978@postgrespro.ru", "phone": "+70749014389"}
0005434504255	64F494	1487 947611	TATYANA GORBUNOVA	{"email": "tatyanagorbunova-021975@postgrespro.ru", "phone": "+70244582957"}
0005434504256	93EC50	3023 105301	OLGA KULIKOVA	{"email": "o.kulikova.021972@postgrespro.ru", "phone": "+70855786888"}
0005434504257	93EC50	7627 681206	LYUBOV GERASIMOVA	{"email": "l_gerasimova.1989@postgrespro.ru", "phone": "+70536008837"}
0005434504258	14415B	7477 693194	YURIY ISAEV	{"email": "isaev_y-1969@postgrespro.ru", "phone": "+70393424335"}
0005434504259	20F1AD	9576 013842	VIKTOR KAZAKOV	{"email": "kazakov-v1983@postgrespro.ru", "phone": "+70250365462"}
0005434504260	20F1AD	6920 584837	ALEKSANDR TIKHONOV	{"phone": "+70833659473"}
0005434504261	7C0FBC	6686 298818	DMITRIY ANTONOV	{"phone": "+70269827509"}
0005434504262	7C0FBC	2385 002277	ELIZAVETA SCHERBAKOVA	{"phone": "+70135045665"}
0005434504263	BC9075	1838 447002	MARIYA LOGINOVA	{"phone": "+70596387623"}
0005434504264	BC9075	6847 050760	VYACHESLAV MOROZOV	{"email": "vyacheslavmorozov.22021978@postgrespro.ru", "phone": "+70385681202"}
0005434504265	DE5C23	5641 589935	YULIYA LEBEDEVA	{"phone": "+70585890209"}
0005434504266	A3B51C	7075 265553	VLADIMIR FROLOV	{"email": "frolov_vladimir.1983@postgrespro.ru", "phone": "+70303397509"}
0005434504267	A3B51C	0009 742159	TATYANA KOZLOVA	{"phone": "+70331009725"}
0005434504268	A3B51C	0968 041386	NATALYA PETROVA	{"phone": "+70233856357"}
0005434504269	30357B	2556 376782	MIKHAIL NIKITIN	{"phone": "+70168453308"}
0005434504270	9A7CBB	4624 998901	NINA KUZMINA	{"phone": "+70524507443"}
0005434504271	6FEE74	3396 004728	SVETLANA ORLOVA	{"email": "orlova_svetlana26051973@postgrespro.ru", "phone": "+70827938997"}
0005434504272	67F4AA	8853 941088	VALENTINA ANTONOVA	{"email": "antonova-valentina1978@postgrespro.ru", "phone": "+70514017346"}
0005434504273	40C8AF	3439 164651	ANATOLIY NOVIKOV	{"email": "novikov.a-05041969@postgrespro.ru", "phone": "+70822346179"}
0005434504274	E89AB4	7724 067137	VIKTOR DAVYDOV	{"email": "davydov_v121973@postgrespro.ru", "phone": "+70180283160"}
0005434504275	E89AB4	5346 487936	IVAN MAKSIMOV	{"phone": "+70142474989"}
0005434504277	E35AD1	9994 921947	ALEKSANDR ILIN	{"email": "aleksandr.ilin_101971@postgrespro.ru", "phone": "+70485732082"}
0005434504278	419CAA	3202 158518	LARISA IVANOVA	{"email": "larisa_ivanova.051993@postgrespro.ru", "phone": "+70890004362"}
0005434504279	6ABAB4	0043 217211	EVGENIY YAKOVLEV	{"email": "yakovlev-e22071976@postgrespro.ru", "phone": "+70210177649"}
0005434504280	86AE49	8142 056467	YURIY PAVLOV	{"email": "pavlovy_1975@postgrespro.ru", "phone": "+70733846117"}
0005434504281	86AE49	4245 777386	GALINA TIKHONOVA	{"phone": "+70778376885"}
0005434504282	8BF93A	7639 074286	LILIYA NESTEROVA	{"email": "nesterovaliliya_04031984@postgrespro.ru", "phone": "+70301189080"}
0005434504283	8BF93A	4884 624291	GALINA ALEKSEEVA	{"phone": "+70283574130"}
0005434504284	8F3A0E	8055 632441	OLGA NIKITINA	{"email": "nikitina_olga-04071967@postgrespro.ru", "phone": "+70458823603"}
0005434504285	BD9643	6427 034331	MARGARITA KOROLEVA	{"phone": "+70677187120"}
0005434504286	BD9643	6965 106106	IRINA EGOROVA	{"email": "iegorova-03071960@postgrespro.ru", "phone": "+70428391714"}
0005434504287	63E8F6	0361 929310	VERA AKIMOVA	{"email": "vera_akimova_121980@postgrespro.ru", "phone": "+70886639337"}
0005434504288	63E8F6	8099 175395	VLADIMIR IVANOV	{"email": "vladimir_ivanov_091969@postgrespro.ru", "phone": "+70472224322"}
0005434504289	9BED09	8572 580940	IRINA SCHERBAKOVA	{"phone": "+70090767616"}
0005434504290	4CCE92	3016 203103	ALENA EFIMOVA	{"phone": "+70396288471"}
0005434504291	1A0355	6966 624661	SERGEY FILIPPOV	{"phone": "+70079466366"}
0005434504292	DC3EA1	0257 817210	NIKOLAY KUZNECOV	{"phone": "+70957590648"}
0005434504293	8E8F49	0938 999727	ANDREY MELNIKOV	{"email": "melnikov_a-081986@postgrespro.ru", "phone": "+70699573774"}
0005434504294	10B50D	5254 377405	OLGA PAVLOVA	{"phone": "+70425431406"}
0005434504295	B5F7E5	1091 100332	GALINA DENISOVA	{"email": "g.denisova_07101970@postgrespro.ru", "phone": "+70632433873"}
0005434504296	B5F7E5	6720 895571	RAFAIL VOROBEV	{"phone": "+70358667075"}
0005434504297	6F3D44	3543 544506	MIKHAIL VOLKOV	{"phone": "+70309975154"}
0005434504298	123C1C	9983 095677	IRINA GORBUNOVA	{"email": "irinagorbunova071970@postgrespro.ru", "phone": "+70407411337"}
0005434504299	FC7086	7891 307981	LYUDMILA KOZLOVA	{"email": "lyudmila-kozlova-21031970@postgrespro.ru", "phone": "+70958469692"}
0005434504300	FC7086	1650 816672	VERA MELNIKOVA	{"phone": "+70443726343"}
0005434504301	42AE81	6675 854644	VLADIMIR BONDARENKO	{"email": "bondarenko_v1977@postgrespro.ru", "phone": "+70069714828"}
0005434504302	F0D181	3911 642648	ANATOLIY BARANOV	{"email": "baranov_anatoliy121974@postgrespro.ru", "phone": "+70075599297"}
0005434504303	DA8888	8950 258697	TATYANA LOGINOVA	{"phone": "+70336248753"}
0005434504304	D08CA7	8948 917067	VERONIKA MIRONOVA	{"phone": "+70826872292"}
0005434504305	BE8EC3	7962 798442	NINA OVCHINNIKOVA	{"email": "n_ovchinnikova_031978@postgrespro.ru", "phone": "+70212766902"}
0005434504306	4EDB91	8676 401053	NADEZHDA KONOVALOVA	{"phone": "+70359820604"}
0005434504307	C75C1B	4552 920596	DENIS MEDVEDEV	{"phone": "+70517047839"}
0005434504308	3333D0	5684 476800	MARINA KUZNECOVA	{"phone": "+70967448170"}
0005434504310	55A940	1989 964843	DARYA MIRONOVA	{"email": "mironovad10021981@postgrespro.ru", "phone": "+70507715084"}
0005434504311	8B552D	2708 734031	OLEG GAVRILOV	{"email": "gavrilov_oleg_111975@postgrespro.ru", "phone": "+70084906428"}
0005434504312	8B552D	7298 581617	STANISLAV KUZNECOV	{"email": "stanislav_kuznecov1982@postgrespro.ru", "phone": "+70386029448"}
0005434504313	ED851F	8340 028575	MIKHAIL TIKHONOV	{"email": "mikhailtikhonov_1964@postgrespro.ru", "phone": "+70755237830"}
0005434504314	9ED2EF	7258 344548	EVGENIY ZHURAVLEV	{"email": "evgeniy.zhuravlev.051972@postgrespro.ru", "phone": "+70619286661"}
0005434504315	666D27	1875 206692	SVETLANA STEPANOVA	{"email": "svetlana.stepanova.1969@postgrespro.ru", "phone": "+70374653905"}
0005434504316	666D27	5906 084355	ELENA STEPANOVA	{"phone": "+70354888323"}
0005434504317	666D27	4574 623481	DMITRIY NIKOLAEV	{"email": "dmitriy_nikolaev_1976@postgrespro.ru", "phone": "+70956457127"}
0005434504318	172C8B	9327 259122	SERGEY ROMANOV	{"email": "romanov-sergey.1965@postgrespro.ru", "phone": "+70774928347"}
0005434504319	595E43	1980 285254	ALEKSEY IVANOV	{"email": "aivanov-041979@postgrespro.ru", "phone": "+70865206103"}
0005434504320	595E43	1930 981477	SERGEY MATVEEV	{"email": "matveevs-24071966@postgrespro.ru", "phone": "+70888988750"}
0005434504321	BA26C0	0309 108632	DENIS SIDOROV	{"phone": "+70911243203"}
0005434504322	A04C48	3511 862436	VERA ZOTOVA	{"email": "v_zotova-071954@postgrespro.ru", "phone": "+70236220395"}
0005434504323	007066	8234 327285	OKSANA KONDRATEVA	{"phone": "+70385516471"}
0005434504324	B1E2D7	7855 714399	MAKSIM TIKHONOV	{"email": "m-tikhonov-041971@postgrespro.ru", "phone": "+70341724593"}
0005434504325	8C75FC	0804 646176	ALEKSEY ZAYCEV	{"email": "a-zaycev.061970@postgrespro.ru", "phone": "+70820902151"}
0005434504326	BEA8BD	8225 083013	VLADIMIR PETROV	{"email": "vladimir-petrov.07021976@postgrespro.ru", "phone": "+70986809823"}
0005434504327	C02E98	2772 378705	ALEKSANDR FOMIN	{"phone": "+70298117076"}
0005434504328	62AA9A	2475 299356	LYUBOV FADEEVA	{"email": "l_fadeeva011968@postgrespro.ru", "phone": "+70783520298"}
0005434504329	C2A82B	6212 443705	YURIY FROLOV	{"email": "y-frolov.10051980@postgrespro.ru", "phone": "+70252373148"}
0005434504330	5F3EEC	4103 257283	VASILIY ZHUKOV	{"phone": "+70115148164"}
0005434504331	6446C7	2671 931070	ARTUR ZAKHAROV	{"phone": "+70160558592"}
0005434504332	6446C7	3524 210881	VIKTOR FROLOV	{"phone": "+70299537353"}
0005434504333	827A66	1739 694625	ANNA SERGEEVA	{"phone": "+70286515721"}
0005434504334	40BFC0	4870 043018	NATALYA SIDOROVA	{"phone": "+70510776500"}
0005434504335	FBBA41	4267 703380	NINA SERGEEVA	{"phone": "+70312962229"}
0005434504336	FBBA41	3481 841706	DMITRIY ALEKSEEV	{"phone": "+70445209766"}
0005434504337	5EEBB2	8673 372860	VERA EGOROVA	{"email": "v-egorova-10101968@postgrespro.ru", "phone": "+70397863413"}
0005434504338	5EEBB2	1496 841821	SERGEY KOZLOV	{"phone": "+70088135137"}
0005434504339	5EEBB2	4370 772290	ARKADIY VLASOV	{"phone": "+70457774526"}
0005434504340	AC169B	4116 091742	VADIM ALEKSEEV	{"email": "vadim-alekseev-021975@postgrespro.ru", "phone": "+70328002662"}
0005434504341	385458	5726 556675	MARIYA MEDVEDEVA	{"phone": "+70612790490"}
0005434504342	74B279	9511 030471	KRISTINA VOLKOVA	{"email": "volkova-k1993@postgrespro.ru", "phone": "+70164029814"}
0005434504343	74B279	4309 519762	ANDREY IVANOV	{"phone": "+70330041179"}
0005434504344	8539C6	6973 280075	PAVEL KUZMIN	{"phone": "+70189906994"}
0005434504345	0B1E26	8326 399072	IVAN CHERNOV	{"phone": "+70069238413"}
0005434504346	6D4DDB	8684 886481	OKSANA VASILEVA	{"email": "vasilevaoksana1965@postgrespro.ru", "phone": "+70455788823"}
0005434504347	25A1E3	2587 544304	DMITRIY PAVLOV	{"email": "pavlov.d-121972@postgrespro.ru", "phone": "+70000929300"}
0005434504348	CB1019	6708 046661	VALENTINA BELYAEVA	{"email": "belyaevav_23101970@postgrespro.ru", "phone": "+70171968507"}
0005434504349	D47569	6182 455044	NADEZHDA NAZAROVA	{"email": "nazarovan_18081963@postgrespro.ru", "phone": "+70194550632"}
0005434504350	D47569	1600 889080	ALEKSEY ZHUKOV	{"email": "zhukov.a.1966@postgrespro.ru", "phone": "+70803723489"}
0005434504351	2A3D81	5626 042088	ANDREY ZHUKOV	{"email": "a-zhukov17091966@postgrespro.ru", "phone": "+70041964439"}
0005434504352	A735AE	1986 482415	ANASTASIYA EGOROVA	{"phone": "+70322131201"}
0005434504353	2CD783	5921 403818	YURIY SMIRNOV	{"phone": "+70815332721"}
0005434504354	0BFEAC	1414 578198	ALEKSANDRA MIRONOVA	{"phone": "+70640168533"}
0005434504355	BCE6D1	9971 682095	DMITRIY KOZLOV	{"phone": "+70489467733"}
0005434504356	108547	0363 856822	VLADIMIR SOROKIN	{"email": "v.sorokin11021984@postgrespro.ru", "phone": "+70265900593"}
0005434504357	35A5F1	1102 841905	VALERIY CHERNOV	{"email": "valeriychernov.1971@postgrespro.ru", "phone": "+70050252831"}
0005434504358	35A5F1	1915 296271	ALEKSEY FILIPPOV	{"email": "a_filippov-071974@postgrespro.ru", "phone": "+70307528573"}
0005434504359	620B3D	7965 332249	KONSTANTIN SEMENOV	{"phone": "+70221983806"}
0005434504360	0D5E7E	9454 530123	VIKTOR PETROV	{"email": "viktor.petrov.1968@postgrespro.ru", "phone": "+70817095586"}
0005434504361	0D5E7E	1900 267421	MIKHAIL KOZLOV	{"email": "mikhail.kozlov.13051971@postgrespro.ru", "phone": "+70538952568"}
0005434504362	12C5B1	5017 695044	DANILA IVANOV	{"email": "danilaivanov.24061963@postgrespro.ru", "phone": "+70260317652"}
0005434504363	D71962	1271 320519	NATALYA PAVLOVA	{"email": "pavlovanatalya28081975@postgrespro.ru", "phone": "+70289802680"}
0005434504364	D71962	7673 456218	IGOR ANDREEV	{"email": "andreev-i.1970@postgrespro.ru", "phone": "+70955913354"}
0005434504365	028E4C	6364 568784	VIKTOR BORISOV	{"phone": "+70447881467"}
0005434504366	CA836D	2728 475383	PAVEL FEDOROV	{"email": "pavelfedorov_12031971@postgrespro.ru", "phone": "+70490406919"}
0005434504367	34F471	0184 239870	ALEKSANDR SIDOROV	{"email": "a_sidorov_111978@postgrespro.ru", "phone": "+70585119718"}
0005434504368	34F471	6128 976346	NATALYA SOKOLOVA	{"email": "sokolova_natalya_1966@postgrespro.ru", "phone": "+70541358492"}
0005434504369	395115	7850 934628	DARYA DENISOVA	{"phone": "+70982656467"}
0005434504370	F07298	4962 637191	RUSLAN ISAEV	{"phone": "+70568477988"}
0005434504371	62C967	0224 177699	ALEKSEY KOROLEV	{"email": "aleksey.korolev1958@postgrespro.ru", "phone": "+70841020737"}
0005434504372	ACC35B	4031 482443	GALINA KUZNECOVA	{"phone": "+70492987874"}
0005434504373	ACC35B	8694 639314	RIMMA ROMANOVA	{"phone": "+70881648620"}
0005434504374	FBEAE0	6437 730584	IGOR FEDOROV	{"phone": "+70576333497"}
0005434504375	FBEAE0	1306 836475	MARIYA MIKHAYLOVA	{"phone": "+70420045216"}
0005434504376	335498	6209 679904	SERGEY IVANOV	{"email": "sivanov-09071973@postgrespro.ru", "phone": "+70807343662"}
0005434504377	5CA088	2280 228700	EDUARD ALEKSANDROV	{"email": "eduard-aleksandrov051969@postgrespro.ru", "phone": "+70107279472"}
0005434504378	4BB0D9	7854 188515	EVGENIY MOISEEV	{"phone": "+70563447015"}
0005434504547	88F4AC	9069 686983	ALEKSANDRA OSIPOVA	{"phone": "+70287189832"}
0005434504379	4BB0D9	4102 291026	MAKSIM SCHERBAKOV	{"email": "scherbakov_m031979@postgrespro.ru", "phone": "+70677937130"}
0005434504380	8E3466	7823 349002	DARYA SOROKINA	{"email": "d_sorokina-031975@postgrespro.ru", "phone": "+70761638408"}
0005434504381	3DC379	1199 787376	ELENA FROLOVA	{"email": "frolovaelena-031970@postgrespro.ru", "phone": "+70193620288"}
0005434504382	A8F1F4	0497 890943	ALIYA KUDRYASHOVA	{"email": "a_kudryashova.091971@postgrespro.ru", "phone": "+70838766291"}
0005434504383	095E0B	2609 004045	ANNA PETROVA	{"email": "annapetrova.1972@postgrespro.ru", "phone": "+70887162259"}
0005434504384	9EFDBE	1812 737350	IGOR KRASNOV	{"email": "krasnov-igor_1969@postgrespro.ru", "phone": "+70681548774"}
0005434504385	027896	7764 629501	ELENA MASLOVA	{"email": "maslovaelena-101977@postgrespro.ru", "phone": "+70367860874"}
0005434504386	027896	1482 713614	OLGA IVANOVA	{"phone": "+70535517271"}
0005434504387	027896	2677 098286	VIKTORIYA FROLOVA	{"email": "viktoriya.frolova-091977@postgrespro.ru", "phone": "+70629483994"}
0005434504388	7E8406	5568 256000	TATYANA VASILEVA	{"email": "vasileva_t04051964@postgrespro.ru", "phone": "+70022755996"}
0005434504389	B3C301	0481 890990	ANTON RODIONOV	{"phone": "+70627905031"}
0005434504390	B3C301	9275 586792	NINA KUZNECOVA	{"phone": "+70705138030"}
0005434504391	2A5578	3924 088402	OLEG KUZMIN	{"email": "kuzminoleg-011961@postgrespro.ru", "phone": "+70580343005"}
0005434504392	2A5578	7450 177097	OLGA NIKIFOROVA	{"email": "olga_nikiforova-01081979@postgrespro.ru", "phone": "+70668282038"}
0005434504393	2A5578	8470 172794	MARINA MELNIKOVA	{"email": "melnikova-m-111972@postgrespro.ru", "phone": "+70193509108"}
0005434504394	66C6D0	6914 767981	ANDREY MAKAROV	{"phone": "+70022251035"}
0005434504395	CA9131	7447 742152	ANASTASIYA CHERNOVA	{"email": "anastasiya.chernova081970@postgrespro.ru", "phone": "+70637079326"}
0005434504396	D4B358	0474 141114	IVAN MOISEEV	{"phone": "+70157673250"}
0005434504397	28B69F	0318 077785	DMITRIY KUZNECOV	{"email": "kuznecovd-081965@postgrespro.ru", "phone": "+70950493457"}
0005434504398	28B69F	7090 296534	YULIYA KUZNECOVA	{"phone": "+70245387888"}
0005434504399	28B69F	8587 807858	ANDREY PAVLOV	{"email": "pavlovandrey061978@postgrespro.ru", "phone": "+70775488809"}
0005434504400	28B69F	8122 436172	RAISA VLASOVA	{"email": "vlasovaraisa-061970@postgrespro.ru", "phone": "+70236937193"}
0005434504401	A08114	6426 857132	KRISTINA AKIMOVA	{"phone": "+70999157161"}
0005434504402	8A51C2	3340 331078	GALINA MIKHAYLOVA	{"email": "galina.mikhaylova-1981@postgrespro.ru", "phone": "+70904137286"}
0005434504403	100ABB	1521 861209	ALEKSANDR STEPANOV	{"email": "a_stepanov.121968@postgrespro.ru", "phone": "+70672902013"}
0005434504404	4E8806	1836 871097	NIKITA SEMENOV	{"email": "nikitasemenov.1969@postgrespro.ru", "phone": "+70531133227"}
0005434504405	330F9D	7563 917066	SVETLANA DMITRIEVA	{"phone": "+70763813050"}
0005434504406	44ECD3	2090 706940	ANNA RYABOVA	{"phone": "+70816011077"}
0005434504407	44ECD3	0473 534044	LYUBOV KUZNECOVA	{"email": "kuznecova-l-1955@postgrespro.ru", "phone": "+70603800711"}
0005434504408	350FD1	4597 544419	VALENTINA POPOVA	{"email": "popova_v_121972@postgrespro.ru", "phone": "+70498337721"}
0005434504409	FDD441	5386 896727	ALEKSEY KOROLEV	{"phone": "+70843263497"}
0005434504410	68ECEF	2660 070398	ELENA BELOVA	{"email": "e_belova.1973@postgrespro.ru", "phone": "+70142518472"}
0005434504411	68ECEF	4342 411407	NATALYA KUZMINA	{"email": "nkuzmina081972@postgrespro.ru", "phone": "+70256704437"}
0005434504412	0C836D	3030 733225	VITALIY MOISEEV	{"email": "vitaliy_moiseev_20041971@postgrespro.ru", "phone": "+70463758567"}
0005434504413	60D319	8258 847348	DAVID MEDVEDEV	{"email": "medvedev.d_071980@postgrespro.ru", "phone": "+70412810117"}
0005434504414	F178EA	2037 712748	NINA EGOROVA	{"email": "n.egorova.081980@postgrespro.ru", "phone": "+70409299990"}
0005434504415	F178EA	5031 459508	NATALYA DANILOVA	{"email": "n-danilova.041979@postgrespro.ru", "phone": "+70631923863"}
0005434504416	8D55B8	3575 424149	ALEKSANDR STEPANOV	{"phone": "+70761938324"}
0005434504417	CCCCDD	3281 973859	IRINA ROMANOVA	{"phone": "+70788863263"}
0005434504418	B4CDE5	5378 791160	ANDREY BORISOV	{"email": "borisov-andrey_1967@postgrespro.ru", "phone": "+70421604215"}
0005434504419	4C1E01	1098 729769	MAKSIM PETROV	{"email": "petrov-maksim041971@postgrespro.ru", "phone": "+70728206177"}
0005434504420	ED9BDB	6736 697848	LYUBOV YAKOVLEVA	{"email": "lyubov.yakovleva_101971@postgrespro.ru", "phone": "+70157686602"}
0005434504421	FEF63A	3406 842111	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov.041974@postgrespro.ru", "phone": "+70474716864"}
0005434504422	4395DD	6531 458710	ALEKSEY FOMIN	{"phone": "+70277077595"}
0005434504423	7FE0B8	4953 983395	NIKITA DMITRIEV	{"phone": "+70997629002"}
0005434504424	6184F5	8991 030788	NIKOLAY MAKSIMOV	{"phone": "+70504912286"}
0005434504425	7C36B3	4879 135505	LYUDMILA VOLKOVA	{"email": "lyudmilavolkova_1959@postgrespro.ru", "phone": "+70488412897"}
0005434504426	5852F9	7713 977596	GENNADIY KULIKOV	{"email": "kulikovg_091970@postgrespro.ru", "phone": "+70075394822"}
0005434504427	61B316	4298 520236	LYUBOV ORLOVA	{"email": "orlova_l.06111969@postgrespro.ru", "phone": "+70228514112"}
0005434504428	0C6CEE	6887 522311	OLEG MOROZOV	{"phone": "+70311141128"}
0005434504429	EBED69	5423 342258	SVETLANA FROLOVA	{"email": "svetlana.frolova071974@postgrespro.ru", "phone": "+70962702027"}
0005434504430	72E9D6	9988 267680	EVGENIY MIRONOV	{"email": "mironov.evgeniy.1975@postgrespro.ru", "phone": "+70485590632"}
0005434504431	9E991B	5282 598518	LYUBOV ALEKSANDROVA	{"email": "l_aleksandrova-1974@postgrespro.ru", "phone": "+70053100236"}
0005434504432	9E991B	5802 437859	ANTONINA KONDRATEVA	{"phone": "+70437138971"}
0005434504433	F4FCF5	1175 999834	VIKTOR NOVIKOV	{"phone": "+70676959472"}
0005434504434	B73621	0897 219742	ELENA SERGEEVA	{"email": "e_sergeeva-041976@postgrespro.ru", "phone": "+70000658123"}
0005434504435	B73621	4783 555852	VLADLEN KOZLOV	{"email": "kozlovv-18031985@postgrespro.ru", "phone": "+70436774523"}
0005434504436	A40DAA	6156 814671	YURIY RODIONOV	{"phone": "+70612692812"}
0005434504437	A40DAA	1230 078778	NATALYA ZAKHAROVA	{"email": "zakharova.natalya_18031970@postgrespro.ru", "phone": "+70182490848"}
0005434504438	A40DAA	6571 740931	MARINA VOLKOVA	{"phone": "+70837284392"}
0005434504439	17FD13	2061 054609	YULIYA BOGDANOVA	{"phone": "+70617281540"}
0005434504440	17FD13	8373 972035	ANTON KULIKOV	{"email": "kulikova.031971@postgrespro.ru", "phone": "+70040734991"}
0005434504441	321374	8503 329771	VLADIMIR SOKOLOV	{"phone": "+70855532632"}
0005434504442	CD857D	4389 557975	ILYA ABRAMOV	{"phone": "+70239824718"}
0005434504443	727A2E	2204 495778	ALEKSANDR KRASNOV	{"phone": "+70573319024"}
0005434504444	727A2E	3283 747944	NINA IVANOVA	{"phone": "+70823207782"}
0005434504445	659A60	5759 276576	VASILIY MIKHAYLOV	{"email": "vmikhaylov071967@postgrespro.ru", "phone": "+70835038926"}
0005434504446	659A60	8127 833496	TATYANA STEPANOVA	{"email": "tatyana-stepanova.17101969@postgrespro.ru", "phone": "+70569583373"}
0005434504447	527D81	1796 974952	NIKOLAY SMIRNOV	{"email": "n.smirnov-121976@postgrespro.ru", "phone": "+70394944935"}
0005434504448	6AC520	4033 826813	ANASTASIYA ILINA	{"email": "ilinaa081974@postgrespro.ru", "phone": "+70019728864"}
0005434504449	0D2525	8233 042946	IRINA ABRAMOVA	{"phone": "+70860728329"}
0005434504450	0D2525	4449 141022	PETR IVANOV	{"phone": "+70794734163"}
0005434504451	8A3F5E	7072 397851	NIKOLAY ZHURAVLEV	{"email": "zhuravlev_n-091977@postgrespro.ru", "phone": "+70621257396"}
0005434504452	51A133	2074 753576	NATALYA TIKHONOVA	{"email": "n-tikhonova-1964@postgrespro.ru", "phone": "+70287592989"}
0005434504453	C69004	5032 274778	ANNA ZOTOVA	{"email": "a_zotova1973@postgrespro.ru", "phone": "+70282204116"}
0005434504454	366EE2	5639 091374	TATYANA SEMENOVA	{"email": "tatyana-semenova-17101965@postgrespro.ru", "phone": "+70882447105"}
0005434504455	40946D	8379 583272	EVGENIY SERGEEV	{"email": "sergeev_evgeniy_011969@postgrespro.ru", "phone": "+70980374202"}
0005434504456	40946D	9115 937279	VIKTOR PAVLOV	{"email": "pavlov_viktor22091978@postgrespro.ru", "phone": "+70930603326"}
0005434504457	06889B	2952 383222	ALEKSEY KONOVALOV	{"phone": "+70546880762"}
0005434504458	051269	5643 586217	INNA FEDOROVA	{"phone": "+70897760047"}
0005434504459	051269	0346 852281	VERA DMITRIEVA	{"email": "v-dmitrieva.011979@postgrespro.ru", "phone": "+70166474863"}
0005434504460	E6C51E	7243 437068	MIKHAIL STEPANOV	{"phone": "+70806194266"}
0005434504461	342956	6819 085278	NATALYA VOROBEVA	{"phone": "+70621054613"}
0005434504462	342956	5710 410210	ALEKSANDRA PAVLOVA	{"email": "aleksandra.pavlova_1973@postgrespro.ru", "phone": "+70919376657"}
0005434504463	9FD723	7256 281675	MIKHAIL VOLKOV	{"email": "mvolkov.31121973@postgrespro.ru", "phone": "+70189450443"}
0005434504464	BC07CC	3323 535164	VIKTORIYA GUSEVA	{"phone": "+70961213909"}
0005434504465	BC07CC	1334 853731	TAMARA ZAKHAROVA	{"phone": "+70189942750"}
0005434504466	732E6B	2239 925042	MARIYA GAVRILOVA	{"phone": "+70106948111"}
0005434504467	732E6B	3453 338109	IGOR AFANASEV	{"email": "igor.afanasev.14071972@postgrespro.ru", "phone": "+70002875596"}
0005434504468	732E6B	3063 620697	GALINA ALEKSEEVA	{"email": "galina.alekseeva091975@postgrespro.ru", "phone": "+70397247594"}
0005434504469	CB3659	2814 458983	LARISA SMIRNOVA	{"email": "larisa.smirnova_14071971@postgrespro.ru", "phone": "+70261111858"}
0005434504470	CB3659	4355 123685	VYACHESLAV PAVLOV	{"email": "pavlov_vyacheslav.15081967@postgrespro.ru", "phone": "+70476129074"}
0005434504471	71D640	6003 138559	ALEKSANDR SHEVCHENKO	{"phone": "+70022561877"}
0005434504472	71D640	1991 105890	VALENTINA VOLKOVA	{"email": "volkova_v-07111979@postgrespro.ru", "phone": "+70354581281"}
0005434504473	2B2FC0	7981 162020	ELIZAVETA EGOROVA	{"phone": "+70020807920"}
0005434504474	2B2FC0	9850 080080	NIKOLAY FROLOV	{"email": "n.frolov.16071973@postgrespro.ru", "phone": "+70624631537"}
0005434504475	BB91DA	0354 429357	OLGA VASILEVA	{"phone": "+70609931061"}
0005434504476	BB91DA	1439 307873	TATYANA DMITRIEVA	{"phone": "+70677969465"}
0005434504477	3D14B4	0547 566034	ALEKSANDRA VOROBEVA	{"email": "aleksandra.vorobeva02111966@postgrespro.ru", "phone": "+70349457926"}
0005434504478	73C426	6665 118044	ALEKSANDR NAZAROV	{"phone": "+70831001569"}
0005434504479	606146	1488 782394	DARYA MAKAROVA	{"phone": "+70397531343"}
0005434504480	498F1A	9944 891783	OKSANA FADEEVA	{"phone": "+70564157344"}
0005434504481	125D9D	8925 405923	TATYANA MASLOVA	{"email": "maslovatatyana_041965@postgrespro.ru", "phone": "+70137763274"}
0005434504482	125D9D	7269 311658	ALEKSEY ISAEV	{"phone": "+70897791032"}
0005434504483	18793A	1755 768610	ALEKSANDR SAVELEV	{"email": "a.savelev_16121985@postgrespro.ru", "phone": "+70719626158"}
0005434504484	7DA5A6	4456 242044	SVETLANA SMIRNOVA	{"email": "smirnova_s111966@postgrespro.ru", "phone": "+70073638808"}
0005434504485	08AA28	1706 604043	DANIIL OSIPOV	{"phone": "+70502799800"}
0005434504486	DF7632	1152 355968	GALINA MAKAROVA	{"phone": "+70173472138"}
0005434504487	32EDEB	5343 231105	NIKOLAY ALEKSEEV	{"email": "alekseev-n_1968@postgrespro.ru", "phone": "+70642466762"}
0005434504488	32EDEB	2689 888027	VLADIMIR FROLOV	{"phone": "+70998360876"}
0005434504489	A46573	1803 477987	IRINA VASILEVA	{"phone": "+70800831379"}
0005434504490	85F2AA	1287 417974	DARYA KOROLEVA	{"email": "darya_koroleva_10111965@postgrespro.ru", "phone": "+70154759026"}
0005434504491	85F2AA	1867 950308	VLADIMIR FOMIN	{"phone": "+70574152114"}
0005434504492	5DD58C	2035 705694	ELENA KUZNECOVA	{"email": "kuznecova.e-101967@postgrespro.ru", "phone": "+70359294577"}
0005434504493	8E515A	0120 027109	ILYA KISELEV	{"phone": "+70847537833"}
0005434504494	BE221A	5058 268948	ANNA ZHUKOVA	{"email": "a-zhukova_121986@postgrespro.ru", "phone": "+70036762468"}
0005434504495	BE221A	8067 957874	KLAVDIYA FILATOVA	{"phone": "+70405889718"}
0005434504496	B5831B	9691 312183	SERGEY BELOV	{"email": "belov-sergey.061964@postgrespro.ru", "phone": "+70041487534"}
0005434504497	B5831B	5207 403748	ANATOLIY DMITRIEV	{"email": "dmitriev_anatoliy-051974@postgrespro.ru", "phone": "+70275671775"}
0005434504498	4F87C5	3357 737598	MIKHAIL KUZMIN	{"phone": "+70916228015"}
0005434504499	433C3D	2326 126315	LYUBOV KUZNECOVA	{"phone": "+70557532775"}
0005434504500	433C3D	7739 695480	OLGA NIKIFOROVA	{"email": "nikiforova-o1963@postgrespro.ru", "phone": "+70270771780"}
0005434504501	253C5B	6174 275512	TAISIYA SOKOLOVA	{"email": "tsokolova.10011969@postgrespro.ru", "phone": "+70126683818"}
0005434504502	E5F242	3631 875724	NADEZHDA VLASOVA	{"phone": "+70107105531"}
0005434504503	F477A4	0264 854632	VALENTINA GRISHINA	{"email": "grishina-valentina-1980@postgrespro.ru", "phone": "+70815135597"}
0005434504504	F477A4	0593 111019	ANGELINA NOVIKOVA	{"phone": "+70041285822"}
0005434504505	F21BDB	3030 072631	SVETLANA BELYAEVA	{"email": "svetlana_belyaeva-12031963@postgrespro.ru", "phone": "+70684108441"}
0005434504506	0BCC6D	1849 051304	ANDREY MIRONOV	{"email": "mironovandrey1974@postgrespro.ru", "phone": "+70968506866"}
0005434504507	0BCC6D	2774 535767	OLEG PAVLOV	{"phone": "+70655027607"}
0005434504508	6A655F	9531 883697	ELENA IVANOVA	{"email": "elenaivanova.1971@postgrespro.ru", "phone": "+70032553846"}
0005434504509	6A655F	2447 959895	LIDIYA MOROZOVA	{"email": "lidiya.morozova-1972@postgrespro.ru", "phone": "+70382381964"}
0005434504510	EE6FC3	2469 362831	VALENTINA IVANOVA	{"phone": "+70407703316"}
0005434504511	EE6FC3	7820 809683	ELENA OSIPOVA	{"phone": "+70320430177"}
0005434504512	3C25E0	7620 238496	VLADIMIR MEDVEDEV	{"phone": "+70168193297"}
0005434504513	3C25E0	1042 660216	DARYA MOROZOVA	{"phone": "+70004973273"}
0005434504514	0D3544	2594 523492	TATYANA ILINA	{"phone": "+70167236302"}
0005434504515	BE5133	5316 975241	MARIYA ORLOVA	{"phone": "+70823611632"}
0005434504516	BE5133	9324 166475	LYUBOV ISAEVA	{"email": "isaeval121968@postgrespro.ru", "phone": "+70984486049"}
0005434504517	5D2B05	6458 174569	ALLA EGOROVA	{"email": "a.egorova.28071976@postgrespro.ru", "phone": "+70813857655"}
0005434504518	5D2B05	4880 761655	EKATERINA AFANASEVA	{"email": "ekaterina.afanaseva_17101970@postgrespro.ru", "phone": "+70844181013"}
0005434504519	35B035	6629 505744	TATYANA ISAEVA	{"phone": "+70857719542"}
0005434504520	35B035	3218 833620	ANNA IVANOVA	{"email": "ivanova-anna.081963@postgrespro.ru", "phone": "+70447413949"}
0005434504521	5D17C4	3048 303008	YANA POLYAKOVA	{"phone": "+70268427840"}
0005434504522	D42954	7954 912007	ARTEM SMIRNOV	{"phone": "+70518253896"}
0005434504523	1C8D44	8614 966955	YANA MARTYNOVA	{"phone": "+70327429214"}
0005434504524	1C8D44	0273 203181	MAKSIM FOMIN	{"phone": "+70896274090"}
0005434504525	93CA56	8337 208895	VALENTINA POPOVA	{"phone": "+70855574042"}
0005434504526	93CA56	5922 051844	YULIYA NOVIKOVA	{"email": "novikova_y_12031974@postgrespro.ru", "phone": "+70172343424"}
0005434504527	2AFD10	1207 747000	MIKHAIL VOLKOV	{"email": "mvolkov.07061971@postgrespro.ru", "phone": "+70715421005"}
0005434504528	7D6759	6698 332682	GALINA KRASNOVA	{"phone": "+70748081824"}
0005434504529	7D6759	7639 349947	STANISLAV MAKAROV	{"phone": "+70416118120"}
0005434504530	EE0E86	4163 768161	DMITRIY PAVLOV	{"email": "dmitriy_pavlov.081972@postgrespro.ru", "phone": "+70906458927"}
0005434504531	EE0E86	4270 953637	SVETLANA KAZAKOVA	{"phone": "+70268925941"}
0005434504532	75B385	1510 602404	NIKOLAY NOVIKOV	{"phone": "+70782611647"}
0005434504533	75B385	5895 496041	IGOR GAVRILOV	{"email": "gavrilov.igor_061975@postgrespro.ru", "phone": "+70909037549"}
0005434504534	445BF2	8816 210893	EKATERINA NIKOLAEVA	{"email": "e_nikolaeva.1982@postgrespro.ru", "phone": "+70480906141"}
0005434504535	6DD6D0	6000 456869	RUSLAN KUZMIN	{"phone": "+70860148277"}
0005434504536	731EC8	7346 690631	KRISTINA DANILOVA	{"phone": "+70576450066"}
0005434504537	36FA1B	3900 987692	NADEZHDA GUSEVA	{"phone": "+70978623074"}
0005434504538	D5AACA	2948 116252	DMITRIY GUSEV	{"phone": "+70514800747"}
0005434504539	86C613	4805 561368	PAVEL EGOROV	{"email": "pavelegorov1977@postgrespro.ru", "phone": "+70420199658"}
0005434504540	86C613	0453 200762	VYACHESLAV DENISOV	{"email": "denisov-vyacheslav-12041986@postgrespro.ru", "phone": "+70921292590"}
0005434504541	431848	8344 788075	ROMAN PAVLOV	{"phone": "+70306041929"}
0005434504542	431848	9393 477498	IVAN SOROKIN	{"email": "sorokin_ivan-10111979@postgrespro.ru", "phone": "+70722769385"}
0005434504543	3EB81B	9342 913456	LILIYA TIKHONOVA	{"phone": "+70395247659"}
0005434504544	ADDC1C	4572 430466	MARIYA EFREMOVA	{"phone": "+70479889132"}
0005434504545	ADDC1C	0287 977909	ALEKSANDR FROLOV	{"phone": "+70262674321"}
0005434504546	729C8E	9864 967097	ALEKSEY BELOV	{"phone": "+70031183381"}
0005434504548	88F4AC	6033 522665	ALEKSEY FEDOROV	{"phone": "+70837193203"}
0005434504549	33A587	1502 219654	ANASTASIYA NESTEROVA	{"phone": "+70183902954"}
0005434504550	C68FAA	1398 128131	ANDREY NAZAROV	{"email": "nazarov_andrey1994@postgrespro.ru", "phone": "+70454669253"}
0005434504551	B6864A	0776 392473	TAMARA NIKITINA	{"email": "nikitina-t.09081987@postgrespro.ru", "phone": "+70203534224"}
0005434504552	F17268	6604 166345	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev1973@postgrespro.ru", "phone": "+70024205953"}
0005434504553	3AD52A	9789 280519	SERGEY FEDOROV	{"email": "fedorov-sergey-24061953@postgrespro.ru", "phone": "+70200521371"}
0005434504554	E73880	9025 785962	ALEKSANDR CHERNOV	{"email": "a-chernov_16081963@postgrespro.ru", "phone": "+70129961967"}
0005434504555	E73880	3771 324084	ANTON ILIN	{"email": "a.ilin_121974@postgrespro.ru", "phone": "+70343611131"}
0005434504556	AAD7B4	1709 024311	DMITRIY MATVEEV	{"email": "matveev.dmitriy061974@postgrespro.ru", "phone": "+70127463176"}
0005434504557	9E5DCC	3138 358450	DMITRIY KUZNECOV	{"phone": "+70989485307"}
0005434504558	6496F9	6550 368969	ARTEM TIMOFEEV	{"email": "timofeev-a.17011972@postgrespro.ru", "phone": "+70198821638"}
0005434504559	7C4BC4	3155 874750	OLGA ABRAMOVA	{"phone": "+70927856505"}
0005434504560	7C4BC4	5065 434739	OLGA ZHUKOVA	{"phone": "+70408434289"}
0005434504561	16F2E1	4246 819853	YULIYA MIRONOVA	{"phone": "+70944209403"}
0005434504562	16F2E1	9877 576437	ALEKSANDR ZHUKOV	{"phone": "+70472524670"}
0005434504563	725E5E	2946 556328	GALINA PETROVA	{"phone": "+70466617848"}
0005434504564	3F14AE	3359 693207	MARGARITA OSIPOVA	{"email": "osipovam091986@postgrespro.ru", "phone": "+70830330000"}
0005434504565	F0C6E7	1578 101123	VALENTINA ANDREEVA	{"phone": "+70065321979"}
0005434504566	AAE3CE	1539 643552	ELENA YUDINA	{"email": "e_yudina091975@postgrespro.ru", "phone": "+70179015039"}
0005434504567	AAE3CE	9717 519970	IRINA DANILOVA	{"email": "i_danilova1962@postgrespro.ru", "phone": "+70761135161"}
0005434504568	4FD1AE	2663 299541	TATYANA KOROLEVA	{"phone": "+70141470913"}
0005434504569	C35B66	9219 924477	ALEKSANDRA RODIONOVA	{"phone": "+70704105120"}
0005434504570	24C989	3537 538885	YULIYA ANTONOVA	{"email": "yuliya.antonova_071964@postgrespro.ru", "phone": "+70061113536"}
0005434504571	24C989	3098 851466	POLINA NIKIFOROVA	{"email": "nikiforovap1966@postgrespro.ru", "phone": "+70604519785"}
0005434504572	06DA9D	0654 883025	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova12011970@postgrespro.ru", "phone": "+70524377325"}
0005434504573	767B30	6799 041297	TATYANA EGOROVA	{"phone": "+70883034367"}
0005434504574	B45039	4761 454497	DENIS RODIONOV	{"email": "rodionovd-10011973@postgrespro.ru", "phone": "+70502892402"}
0005434504575	CE85AC	5527 873248	ALEKSEY SERGEEV	{"email": "alekseysergeev-1972@postgrespro.ru", "phone": "+70041535853"}
0005434504576	8E4246	6908 271001	LYUDMILA VOLKOVA	{"phone": "+70753764602"}
0005434504577	4CCC6C	2183 154069	MAKSIM SOKOLOV	{"email": "maksim_sokolov_1963@postgrespro.ru", "phone": "+70591735450"}
0005434504578	4CCC6C	9934 535716	IRINA ROMANOVA	{"phone": "+70239200757"}
0005434504579	EBB522	6254 924409	MIKHAIL NOVIKOV	{"email": "novikov_mikhail011970@postgrespro.ru", "phone": "+70930426315"}
0005434504580	E4E69C	6149 386103	ELENA FILATOVA	{"email": "elena.filatova_1965@postgrespro.ru", "phone": "+70945229407"}
0005434504581	E4E69C	5754 631013	NADEZHDA BELOVA	{"email": "belova-nadezhda1975@postgrespro.ru", "phone": "+70003594147"}
0005434504582	19CA99	1859 900598	ELENA SEMENOVA	{"email": "e-semenova-18021974@postgrespro.ru", "phone": "+70725491154"}
0005434504583	311958	8460 906902	GALINA MATVEEVA	{"phone": "+70814406594"}
0005434504584	311958	0016 056627	ANDREY RODIONOV	{"email": "a_rodionov.011962@postgrespro.ru", "phone": "+70197596845"}
0005434504585	DCA903	2554 990071	EVGENIY NAZAROV	{"email": "nazarov_e.10021975@postgrespro.ru", "phone": "+70548502039"}
0005434504586	586BC8	7865 585398	MARINA FROLOVA	{"phone": "+70013448989"}
0005434504587	586BC8	9248 042496	YURIY DAVYDOV	{"email": "davydov_yuriy011980@postgrespro.ru", "phone": "+70199240465"}
0005434504588	C43DF0	2672 358113	ILYA CHERNOV	{"email": "i_chernov.16091975@postgrespro.ru", "phone": "+70775368305"}
0005434504589	A71A12	5967 160561	GALINA SIDOROVA	{"email": "sidorova_g1968@postgrespro.ru", "phone": "+70985475041"}
0005434504590	7CE9B3	5192 222267	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova_1982@postgrespro.ru", "phone": "+70953188018"}
0005434504591	358183	5985 715486	VLADIMIR MOISEEV	{"phone": "+70117790439"}
0005434504592	EFA7A0	6796 765843	ANTON VLASOV	{"email": "vlasovanton03121967@postgrespro.ru", "phone": "+70786397281"}
0005434504593	2ABD65	1933 156757	PAVEL KARPOV	{"phone": "+70373434187"}
0005434504594	456396	1617 501874	ALEKSEY CHERNOV	{"email": "chernov_aleksey-111976@postgrespro.ru", "phone": "+70733435967"}
0005434504595	83D54E	8405 788454	GALINA MIKHAYLOVA	{"email": "mikhaylova-g-09011974@postgrespro.ru", "phone": "+70639693903"}
0005434504596	59E018	8996 409041	VALENTINA KULIKOVA	{"phone": "+70479069551"}
0005434504597	9716A3	7997 830961	PETR GRIGOREV	{"phone": "+70574899489"}
0005434504598	9716A3	1359 911087	TAMARA SCHERBAKOVA	{"phone": "+70990367606"}
0005434504599	95803D	8262 704892	SVETLANA POPOVA	{"phone": "+70801569569"}
0005434504600	95803D	0377 757272	VLADIMIR NOVIKOV	{"phone": "+70953730804"}
0005434504601	95803D	5284 053741	ARTEM SOKOLOV	{"email": "a-sokolov.1967@postgrespro.ru", "phone": "+70912357128"}
0005434504602	55A864	5835 752518	EVDOKIYA MARTYNOVA	{"email": "evdokiya-martynova-1974@postgrespro.ru", "phone": "+70029597932"}
0005434504603	AEFCBE	7975 691721	ALEKSANDR SERGEEV	{"phone": "+70169175308"}
0005434504604	A96088	5718 326986	SERGEY SOROKIN	{"email": "sergey.sorokin1957@postgrespro.ru", "phone": "+70133394584"}
0005434504605	80519A	7492 095715	VERA SMIRNOVA	{"email": "vsmirnova04051966@postgrespro.ru", "phone": "+70539629388"}
0005434504606	80519A	4450 180246	NADEZHDA ZOTOVA	{"email": "zotovan28031972@postgrespro.ru", "phone": "+70605667715"}
0005434504607	EDCB70	9991 914740	VARVARA NIKIFOROVA	{"email": "nikiforova.v-041974@postgrespro.ru", "phone": "+70165909907"}
0005434504608	42FAB7	7257 992416	ANNA GRISHINA	{"email": "anna_grishina.1961@postgrespro.ru", "phone": "+70541290031"}
0005434504609	515361	9180 499918	NADEZHDA AFANASEVA	{"email": "afanaseva_nadezhda-1974@postgrespro.ru", "phone": "+70506020157"}
0005434504610	6509AA	2520 180431	VALENTINA FILATOVA	{"email": "filatova.v1959@postgrespro.ru", "phone": "+70453070682"}
0005434504611	B84EF5	6415 738699	TAMARA NIKIFOROVA	{"phone": "+70827835323"}
0005434504612	61085C	1305 772932	DENIS ZAYCEV	{"phone": "+70475744344"}
0005434504613	61085C	2079 039177	VIKTOR OSIPOV	{"email": "v-osipov.27071984@postgrespro.ru", "phone": "+70940668799"}
0005434504614	61085C	9226 486890	RUSLAN TIKHONOV	{"email": "tikhonov.r.111966@postgrespro.ru", "phone": "+70355931121"}
0005434504615	83F128	7351 214546	VIKTORIYA VASILEVA	{"email": "v-vasileva1972@postgrespro.ru", "phone": "+70966413862"}
0005434504616	774A48	7152 802050	DMITRIY BONDARENKO	{"phone": "+70879818103"}
0005434504617	CC08E0	7952 768273	IRINA KUZNECOVA	{"email": "irinakuznecova.091976@postgrespro.ru", "phone": "+70456766350"}
0005434504618	AF847B	0888 422346	ANASTASIYA FADEEVA	{"phone": "+70892044844"}
0005434504619	AF847B	1626 489689	ALEKSANDR RODIONOV	{"email": "rodionov_a.021974@postgrespro.ru", "phone": "+70280074660"}
0005434504620	BD5D98	2793 840316	NATALYA IVANOVA	{"email": "ivanova.natalya-091962@postgrespro.ru", "phone": "+70388674788"}
0005434504621	D9E3AC	5954 721983	LILIYA SOROKINA	{"email": "sorokinal_21071975@postgrespro.ru", "phone": "+70554013570"}
0005434504622	722998	5227 618548	TATYANA SERGEEVA	{"email": "sergeeva-tatyana.27081967@postgrespro.ru", "phone": "+70333819713"}
0005434504623	1B638E	1076 276359	LYUDMILA BORISOVA	{"email": "borisova-lyudmila.1975@postgrespro.ru", "phone": "+70681223369"}
0005434504624	1B638E	7426 981360	VALENTINA FILATOVA	{"phone": "+70752511813"}
0005434504625	0C3229	9283 727788	ELENA RODIONOVA	{"email": "rodionova-e_10031976@postgrespro.ru", "phone": "+70606166491"}
0005434504626	0C3229	7515 608192	ALEKSANDR FEDOTOV	{"phone": "+70483188823"}
0005434504627	40CEA9	2864 475887	TATYANA KONOVALOVA	{"phone": "+70220368488"}
0005434504628	40CEA9	3679 199910	GALINA ALEKSEEVA	{"email": "galina-alekseeva.09111975@postgrespro.ru", "phone": "+70943504577"}
0005434504629	40CEA9	1465 416229	ARTEM ORLOV	{"email": "orlov.a021959@postgrespro.ru", "phone": "+70343061533"}
0005434504630	390666	6901 501836	MAKSIM FILIPPOV	{"email": "filippov.maksim051970@postgrespro.ru", "phone": "+70132919531"}
0005434504631	390666	1702 494983	VALENTINA VASILEVA	{"phone": "+70341076455"}
0005434504632	8FE7BD	5389 813961	NATALYA EGOROVA	{"email": "n.egorova-111975@postgrespro.ru", "phone": "+70287877639"}
0005434504633	0A6976	8518 096679	IVAN BARANOV	{"phone": "+70236832858"}
0005434504634	48FD6D	9410 333481	EVGENIY STEPANOV	{"email": "estepanov-24111973@postgrespro.ru", "phone": "+70543710886"}
0005434504635	DEDC52	8519 220469	EVGENIY YAKOVLEV	{"phone": "+70131398366"}
0005434504636	7D768A	5150 473650	LYUDMILA KALININA	{"phone": "+70730937503"}
0005434504637	C30057	8238 707887	MARGARITA KOROLEVA	{"phone": "+70918629308"}
0005434504638	E81B1A	7295 992051	EVGENIY MIKHAYLOV	{"email": "mikhaylov-evgeniy.1971@postgrespro.ru", "phone": "+70146802279"}
0005434504639	7BEC8E	7947 153023	SERGEY KUZMIN	{"email": "kuzmin_sergey_111979@postgrespro.ru", "phone": "+70808353592"}
0005434504640	7BEC8E	0737 828258	VALERIYA EFIMOVA	{"email": "efimovav071975@postgrespro.ru", "phone": "+70928469728"}
0005434504641	F446C8	5449 807297	MARIYA KUZMINA	{"email": "m_kuzmina.051975@postgrespro.ru", "phone": "+70014082295"}
0005434504642	DBC29B	2541 785564	YURIY OSIPOV	{"phone": "+70714142194"}
0005434504643	C9D78F	9654 175466	VALENTINA EFIMOVA	{"phone": "+70845504672"}
0005434504644	C9D78F	4602 666131	GENNADIY IVANOV	{"email": "g-ivanov091968@postgrespro.ru", "phone": "+70125193991"}
0005434504645	E56221	6626 092532	VITALIY GUSEV	{"email": "v.gusev04041967@postgrespro.ru", "phone": "+70044356524"}
0005434504646	370E2B	1243 761315	NADEZHDA SOKOLOVA	{"email": "sokolova_n_1962@postgrespro.ru", "phone": "+70305626173"}
0005434504647	033BD1	6234 117881	MARINA MARTYNOVA	{"email": "marina_martynova_111970@postgrespro.ru", "phone": "+70453814694"}
0005434504648	033BD1	3567 687056	SERGEY EGOROV	{"phone": "+70561406426"}
0005434504649	2575D5	0250 679810	ALEKSEY KARPOV	{"phone": "+70502460251"}
0005434504650	A3D388	1154 850375	SERGEY GAVRILOV	{"phone": "+70436185539"}
0005434504651	A3D388	3645 620608	IRINA KARPOVA	{"phone": "+70262085947"}
0005434504652	2B007A	1718 083197	FEDOR KUZNECOV	{"phone": "+70055790994"}
0005434504653	2B007A	7507 762284	SVETLANA KOVALEVA	{"phone": "+70641448198"}
0005434504654	3C04C1	2151 200565	MARIYA SOROKINA	{"phone": "+70309679308"}
0005434504655	762DD8	3304 150899	LYUBOV RODIONOVA	{"phone": "+70895189394"}
0005434504656	146F3C	9539 120138	VLADIMIR SAVELEV	{"phone": "+70125094267"}
0005434504657	834A81	0709 510911	VIKTOR RODIONOV	{"email": "vrodionov_011977@postgrespro.ru", "phone": "+70298055847"}
0005434504658	817EF1	1727 667326	VIKTORIYA YUDINA	{"phone": "+70153976096"}
0005434504659	817EF1	0346 062138	VLADIMIR ANDREEV	{"phone": "+70258955340"}
0005434504660	6038AF	7058 400349	NINA ALEKSANDROVA	{"phone": "+70897570385"}
0005434504661	6038AF	6650 843598	SERGEY ABRAMOV	{"email": "abramov.sergey04091967@postgrespro.ru", "phone": "+70670358728"}
0005434504662	6038AF	5376 422946	NATALYA MASLOVA	{"phone": "+70150628813"}
0005434504663	F24989	4855 682297	OLGA ALEKSEEVA	{"phone": "+70414730097"}
0005434504664	0A5CEA	1364 052982	VITALIY MIRONOV	{"email": "vitaliy_mironov.11061970@postgrespro.ru", "phone": "+70129655368"}
0005434504665	6E81B8	9679 037789	ANDREY VASILEV	{"email": "vasilev.andrey-1983@postgrespro.ru", "phone": "+70688521701"}
0005434504666	C26240	7725 982758	LIDIYA SEMENOVA	{"phone": "+70844304079"}
0005434504667	C26240	8211 761019	KSENIYA TIKHONOVA	{"email": "k-tikhonova-101979@postgrespro.ru", "phone": "+70021974917"}
0005434504668	C26240	8472 553092	YURIY ABRAMOV	{"phone": "+70078035139"}
0005434504669	9B4553	5304 384721	IVAN TARASOV	{"email": "i-tarasov_1971@postgrespro.ru", "phone": "+70026447680"}
0005434504670	646491	1758 513908	ZOYA ROMANOVA	{"phone": "+70240399160"}
0005434504671	646491	6534 087084	RIMMA FEDOROVA	{"email": "r.fedorova.031971@postgrespro.ru", "phone": "+70444453087"}
0005434504672	C8D52B	9536 892937	LYUBOV VOLKOVA	{"phone": "+70373924430"}
0005434504673	42F4FC	7119 675459	MILENA ZHUKOVA	{"email": "zhukova_m071967@postgrespro.ru", "phone": "+70236520040"}
0005434504674	42F4FC	4291 444777	NADEZHDA FOMINA	{"phone": "+70316723485"}
0005434504675	42F4FC	1160 240452	ALEKSANDR ORLOV	{"email": "aleksandrorlov_06111966@postgrespro.ru", "phone": "+70970874495"}
0005434504676	C3D834	6371 440691	VIKTORIYA LEBEDEVA	{"email": "lebedeva.viktoriya.1978@postgrespro.ru", "phone": "+70094366725"}
0005434504677	C3D834	7596 447342	VALENTINA STEPANOVA	{"phone": "+70337076760"}
0005434504678	EAF10F	9210 919322	IRINA KUZMINA	{"email": "irinakuzmina_111963@postgrespro.ru", "phone": "+70701117502"}
0005434504679	F04FFF	0623 624121	MARIYA AFANASEVA	{"phone": "+70958348520"}
0005434504680	547BD2	5311 117757	ALEKSEY BELOV	{"email": "belov_aleksey_041966@postgrespro.ru", "phone": "+70826186725"}
0005434504681	267D81	9392 365802	OKSANA FEDOROVA	{"phone": "+70167629193"}
0005434504682	267D81	3256 974699	MARINA KUZNECOVA	{"email": "kuznecovamarina_091975@postgrespro.ru", "phone": "+70360972855"}
0005434504683	44F7AC	2547 787835	DANILA ANDREEV	{"email": "danila.andreev_1973@postgrespro.ru", "phone": "+70486789685"}
0005434504684	44F7AC	5755 332628	MARIYA SOKOLOVA	{"email": "mariya-sokolova_1981@postgrespro.ru", "phone": "+70519044268"}
0005434504685	A47BC8	3216 158827	VYACHESLAV ALEKSEEV	{"email": "valekseev-1969@postgrespro.ru", "phone": "+70235571068"}
0005434504686	A8D1E2	7143 303897	NATALYA NIKOLAEVA	{"email": "nikolaevanatalya041983@postgrespro.ru", "phone": "+70723030984"}
0005434504687	1D434C	8456 884598	NADEZHDA VLASOVA	{"phone": "+70566695510"}
0005434504688	5A36A0	9849 687085	ANDREY NIKOLAEV	{"email": "nikolaev-andrey-031976@postgrespro.ru", "phone": "+70559307608"}
0005434504689	43E00F	0337 448827	ANASTASIYA KOROLEVA	{"email": "korolevaanastasiya1973@postgrespro.ru", "phone": "+70609777918"}
0005434504690	43E00F	6275 979263	ILYA IVANOV	{"phone": "+70069152240"}
0005434504691	46F975	2256 096083	DMITRIY FEDOROV	{"phone": "+70119817530"}
0005434504692	06D7FB	2851 907113	VLADIMIR SOROKIN	{"email": "sorokin_vladimir.1966@postgrespro.ru", "phone": "+70955171011"}
0005434504693	06D7FB	5355 791624	NADEZHDA KAZAKOVA	{"email": "kazakova_n-14071962@postgrespro.ru", "phone": "+70800469624"}
0005434504694	A9CECA	8440 886161	DIANA AFANASEVA	{"phone": "+70600358608"}
0005434504695	39C363	5954 894669	OLEG ISAEV	{"phone": "+70475211766"}
0005434504696	C17467	6520 614580	ELENA ARKHIPOVA	{"email": "e-arkhipova-1967@postgrespro.ru", "phone": "+70928621512"}
0005434504697	C17467	3647 328657	TAMARA MATVEEVA	{"email": "matveeva_tamara-24081955@postgrespro.ru", "phone": "+70561057518"}
0005434504698	88D265	5508 844892	ANASTASIYA ROMANOVA	{"phone": "+70193393105"}
0005434504699	88D265	7037 321355	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov1975@postgrespro.ru", "phone": "+70011743518"}
0005434504700	0E1F2E	8961 815267	MARIYA DAVYDOVA	{"phone": "+70127058691"}
0005434504701	247598	2202 428364	ILYA SHEVCHENKO	{"email": "ilyashevchenko_1978@postgrespro.ru", "phone": "+70818540622"}
0005434504702	79103E	5973 021364	NATALYA KULIKOVA	{"phone": "+70666866947"}
0005434504703	C60E0C	3293 609825	ALEKSANDR IVANOV	{"phone": "+70862157288"}
0005434504704	693376	2886 094520	SVETLANA ZAKHAROVA	{"email": "svetlana_zakharova.31081972@postgrespro.ru", "phone": "+70083305773"}
0005434504705	70F93E	3336 567137	OLGA NESTEROVA	{"email": "o.nesterova_1976@postgrespro.ru", "phone": "+70599069794"}
0005434504706	819A2E	1170 602153	NATALYA KOZLOVA	{"email": "kozlova-natalya_17101975@postgrespro.ru", "phone": "+70318569067"}
0005434504707	3ED6CC	7539 423011	YURIY ZHURAVLEV	{"email": "y_zhuravlev_13051975@postgrespro.ru", "phone": "+70375653250"}
0005434504708	3ED6CC	9131 660597	ZINAIDA SOKOLOVA	{"phone": "+70880103817"}
0005434504709	74614C	3663 281444	OKSANA IVANOVA	{"phone": "+70713691104"}
0005434504710	74614C	8929 363538	NIKOLAY SAVELEV	{"email": "savelev.n_1984@postgrespro.ru", "phone": "+70608772202"}
0005434504711	1B1B40	5626 016767	IRINA NAZAROVA	{"email": "nazarova.i28071959@postgrespro.ru", "phone": "+70760594230"}
0005434504712	5B06E8	2584 457572	VALENTINA VOROBEVA	{"email": "vorobevavalentina_121971@postgrespro.ru", "phone": "+70563758355"}
0005434504713	4224A0	5171 927956	SERGEY BELOV	{"email": "sergey-belov-1974@postgrespro.ru", "phone": "+70365698986"}
0005434504714	EA4AAE	4225 736822	SVETLANA YUDINA	{"email": "yudina_s_24021975@postgrespro.ru", "phone": "+70472676519"}
0005434504715	A66855	9094 531828	EVGENIY FILIPPOV	{"phone": "+70019134066"}
0005434504716	186BA7	1182 807984	NATALYA ZAKHAROVA	{"phone": "+70711495850"}
0005434504717	186BA7	6985 570222	MARIYA KONDRATEVA	{"phone": "+70847496114"}
0005434504718	432D16	7370 341676	SAMIRA EGOROVA	{"email": "egorova_s_06021981@postgrespro.ru", "phone": "+70430184093"}
0005434504719	432D16	7019 776019	SERGEY ANTONOV	{"email": "antonov.sergey081976@postgrespro.ru", "phone": "+70650208977"}
0005434504720	3DD46B	8926 028036	ILMIRA VASILEVA	{"email": "ilmira_vasileva-061981@postgrespro.ru", "phone": "+70294428838"}
0005434504721	3DD46B	9571 228550	VERONIKA KUZNECOVA	{"email": "kuznecova-v-1974@postgrespro.ru", "phone": "+70527347351"}
0005434504722	60CE6E	2954 014790	NATALYA PAVLOVA	{"email": "natalyapavlova22061969@postgrespro.ru", "phone": "+70120823526"}
0005434504723	B2219C	0861 302820	NATALYA PAVLOVA	{"phone": "+70797743830"}
0005434504724	B2219C	5505 958490	ANASTASIYA ANDREEVA	{"phone": "+70106652628"}
0005434504725	3D1C12	0364 060387	VLADIMIR FILIPPOV	{"email": "filippovv.19081971@postgrespro.ru", "phone": "+70254600899"}
0005434504726	C25613	2428 077402	DMITRIY VLASOV	{"email": "vlasovdmitriy13021979@postgrespro.ru", "phone": "+70413612615"}
0005434504727	C25613	4394 912772	ALEKSANDR YAKOVLEV	{"email": "aleksandr_yakovlev021979@postgrespro.ru", "phone": "+70849286275"}
0005434504728	CA9E1E	1295 279406	SERGEY SMIRNOV	{"phone": "+70613637758"}
0005434504729	FB0BBF	1222 267190	VALENTINA LAZAREVA	{"email": "valentinalazareva.1971@postgrespro.ru", "phone": "+70825854308"}
0005434504730	E489D7	8255 514248	VALENTINA KOROLEVA	{"phone": "+70766726641"}
0005434504731	EE54E5	6123 906860	DMITRIY OSIPOV	{"email": "osipov.d-04091967@postgrespro.ru", "phone": "+70505483948"}
0005434504732	09FC99	8897 512411	NIKOLAY SEMENOV	{"phone": "+70418711655"}
0005434504733	FCE5F2	9199 656514	ALEVTINA KOZLOVA	{"phone": "+70805678342"}
0005434504734	FCE5F2	8052 917472	ALEKSANDR KARPOV	{"phone": "+70037443053"}
0005434504735	256CBF	8174 067008	YULIYA KUZNECOVA	{"phone": "+70178001849"}
0005434504736	256CBF	9452 305078	VLADIMIR DAVYDOV	{"email": "davydov_v-031969@postgrespro.ru", "phone": "+70385639494"}
0005434504737	B7D972	1387 396397	ALEKSANDRA ZAKHAROVA	{"email": "zakharova.aleksandra-16021971@postgrespro.ru", "phone": "+70980671984"}
0005434504738	B7D972	4773 288094	VASILIY VASILEV	{"email": "vasiliy.vasilev.1971@postgrespro.ru", "phone": "+70904151996"}
0005434504739	28F7AD	3167 773506	VIKTORIYA MOROZOVA	{"email": "v.morozova.101958@postgrespro.ru", "phone": "+70522987494"}
0005434504740	28F7AD	5525 226305	SERGEY ABRAMOV	{"phone": "+70923585712"}
0005434504741	0EE58E	7452 855569	VYACHESLAV ZAYCEV	{"phone": "+70113687470"}
0005434504742	0E3A35	4801 272412	FATIMA SEMENOVA	{"email": "semenova_fatima071972@postgrespro.ru", "phone": "+70034957556"}
0005434504743	F89A5A	2518 917666	VLADISLAV KUZNECOV	{"email": "v_kuznecov.28021968@postgrespro.ru", "phone": "+70389416910"}
0005434504744	2B0195	6727 235391	GENNADIY MATVEEV	{"phone": "+70752492710"}
0005434504745	CC4077	8393 934325	GALINA NESTEROVA	{"phone": "+70003862777"}
0005434504746	6DF571	9009 467783	GLEB VOROBEV	{"email": "gvorobev_121963@postgrespro.ru", "phone": "+70556651926"}
0005434504747	8917BF	6268 834547	RAISA SIDOROVA	{"email": "r-sidorova.24051979@postgrespro.ru", "phone": "+70534049326"}
0005434504748	8917BF	4988 326441	MARINA KALININA	{"email": "mkalinina-1982@postgrespro.ru", "phone": "+70152332959"}
0005434504749	EEC159	7024 028188	NATALYA MAKAROVA	{"email": "nmakarova_1963@postgrespro.ru", "phone": "+70188333645"}
0005434504750	EB5272	7519 303006	SVETLANA GORBUNOVA	{"email": "s-gorbunova1961@postgrespro.ru", "phone": "+70462120904"}
0005434504751	EB5272	6904 284779	ARTEM MAKAROV	{"email": "makarov-artem.1971@postgrespro.ru", "phone": "+70584355157"}
0005434504752	87F004	7475 878248	ANATOLIY ALEKSEEV	{"phone": "+70128522182"}
0005434504753	87F004	2189 845837	PAVEL IVANOV	{"email": "pavel-ivanov-14031976@postgrespro.ru", "phone": "+70989685739"}
0005434504754	481010	9361 964403	ALEKSANDR ALEKSEEV	{"email": "alekseev_a051976@postgrespro.ru", "phone": "+70425968033"}
0005434504755	C4FD02	0521 990798	SERGEY BARANOV	{"email": "s_baranov.071982@postgrespro.ru", "phone": "+70778428487"}
0005434504756	83A8C7	1642 923858	VALENTINA KOROLEVA	{"email": "koroleva_valentina.1971@postgrespro.ru", "phone": "+70126359992"}
0005434504757	AB5C12	2508 242411	OKSANA FOMINA	{"email": "o.fomina-111961@postgrespro.ru", "phone": "+70099383004"}
0005434504758	AB5C12	7553 803886	TATYANA TARASOVA	{"email": "tarasova-tatyana17061971@postgrespro.ru", "phone": "+70104357324"}
0005434504759	80785E	1762 064805	ANTON KISELEV	{"email": "akiselev121974@postgrespro.ru", "phone": "+70600951659"}
0005434504760	FA3F68	9891 107725	VIKTOR FOMIN	{"email": "viktorfomin_1959@postgrespro.ru", "phone": "+70332480203"}
0005434504761	FA3F68	4739 297870	RUSLAN DAVYDOV	{"phone": "+70127189757"}
0005434504762	A58C6F	1003 292819	NATALYA KONDRATEVA	{"email": "kondrateva_natalya031965@postgrespro.ru", "phone": "+70387606754"}
0005434504763	892B8F	2750 481934	YAROSLAV SCHERBAKOV	{"email": "yaroslavscherbakov.031980@postgrespro.ru", "phone": "+70576278487"}
0005434504764	892B8F	7978 155456	IRINA NIKIFOROVA	{"phone": "+70050640677"}
0005434504765	7C91CE	4700 366022	EVGENIY VOLKOV	{"email": "e-volkov1954@postgrespro.ru", "phone": "+70723572256"}
0005434504766	028F52	8445 956968	DARYA ZAYCEVA	{"email": "d_zayceva-18021975@postgrespro.ru", "phone": "+70924933664"}
0005434504767	028F52	3204 610466	GALINA KOZLOVA	{"phone": "+70670640967"}
0005434504768	AF4F98	8188 885712	TATYANA SERGEEVA	{"email": "t.sergeeva_1972@postgrespro.ru", "phone": "+70009364659"}
0005434504769	EC271D	1638 806408	GENNADIY VASILEV	{"email": "gvasilev-1966@postgrespro.ru", "phone": "+70192840439"}
0005434504770	D4C12F	9111 755977	RUSLAN FEDOTOV	{"email": "r_fedotov021974@postgrespro.ru", "phone": "+70809337715"}
0005434504771	D4C12F	8559 653110	VALERIY ROMANOV	{"email": "vromanov.1966@postgrespro.ru", "phone": "+70485617613"}
0005434504772	D4C12F	0747 758719	ALEKSANDR SHEVCHENKO	{"phone": "+70847751049"}
0005434504773	8D46B6	3597 645666	SVETLANA EFREMOVA	{"email": "s.efremova_19061964@postgrespro.ru", "phone": "+70995260217"}
0005434504774	8D46B6	0914 772324	EVGENIY ZHURAVLEV	{"email": "zhuravlevevgeniy.20111969@postgrespro.ru", "phone": "+70633491897"}
0005434504775	8D46B6	4463 008340	ILYA EGOROV	{"phone": "+70115582217"}
0005434504776	C7F0B7	3107 926070	YULIYA MEDVEDEVA	{"email": "y-medvedeva.27011985@postgrespro.ru", "phone": "+70320957420"}
0005434504777	5B0E56	5907 673827	LILIYA KOZLOVA	{"email": "lkozlova_1973@postgrespro.ru", "phone": "+70083148805"}
0005434504778	CFA967	8837 855060	OLGA KOZLOVA	{"phone": "+70541599159"}
0005434504779	FA0040	2077 149929	YURIY PAVLOV	{"email": "pavlovy_11111970@postgrespro.ru", "phone": "+70976475043"}
0005434504780	2D407B	0720 024430	VIKTOR GRIGOREV	{"email": "grigorev-viktor-1966@postgrespro.ru", "phone": "+70237567128"}
0005434504781	AE6853	0843 312820	DENIS KUZNECOV	{"phone": "+70544688207"}
0005434504782	D765EA	6708 852515	LARISA IVANOVA	{"phone": "+70039222080"}
0005434504783	03F06D	0215 632160	TATYANA POTAPOVA	{"phone": "+70472078497"}
0005434504784	548035	8076 506008	MARINA FOMINA	{"email": "marina.fomina_051966@postgrespro.ru", "phone": "+70428710880"}
0005434504785	C10629	3057 563992	DENIS KISELEV	{"phone": "+70381573868"}
0005434504786	C10629	7500 354080	NADEZHDA STEPANOVA	{"phone": "+70868770419"}
0005434504787	996E8F	4280 864343	MARGARITA ZAKHAROVA	{"phone": "+70501538374"}
0005434504788	8D95A3	8059 117514	SERGEY TARASOV	{"email": "sergey_tarasov_1966@postgrespro.ru", "phone": "+70079723100"}
0005434504789	C97788	6708 695687	IGOR OSIPOV	{"phone": "+70525918341"}
0005434504790	C97788	1412 489022	ALEKSANDR SCHERBAKOV	{"phone": "+70976260032"}
0005434504791	7EAB92	4737 931129	MARINA NIKITINA	{"email": "marina.nikitina-10071971@postgrespro.ru", "phone": "+70755807659"}
0005434504792	1D8A53	5754 118462	MARAT FROLOV	{"phone": "+70059157928"}
0005434504793	43101D	1219 630848	IRINA KOZLOVA	{"phone": "+70941038475"}
0005434504794	43101D	7600 026997	ANATOLIY BONDARENKO	{"email": "anatoliy.bondarenko10061981@postgrespro.ru", "phone": "+70254423200"}
0005434504795	E49D71	5936 179423	LARISA MIKHAYLOVA	{"phone": "+70070141364"}
0005434504796	EE43B2	0711 688390	OLEG PAVLOV	{"email": "pavlov_oleg1971@postgrespro.ru", "phone": "+70244470646"}
0005434504797	90A508	5933 824761	NATALYA AFANASEVA	{"phone": "+70417385858"}
0005434504798	90A508	4631 175483	RAMAZAN PETROV	{"phone": "+70041028829"}
0005434504799	146669	6099 467667	ARTEM MAKAROV	{"email": "makarov_a-091968@postgrespro.ru", "phone": "+70876626655"}
0005434504800	146669	8230 821033	ANDREY FEDOROV	{"email": "andrey.fedorov.121972@postgrespro.ru", "phone": "+70985149649"}
0005434504801	0C7B5F	1233 618471	VALENTINA FILIPPOVA	{"phone": "+70006398863"}
0005434504802	3DCB09	4160 956338	ALEKSANDR NIKOLAEV	{"email": "nikolaev_aleksandr_06031976@postgrespro.ru", "phone": "+70354660642"}
0005434504803	FE144F	6883 422727	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov_081978@postgrespro.ru", "phone": "+70968016158"}
0005434504804	FE144F	5641 668858	YULIYA ALEKSEEVA	{"phone": "+70627850152"}
0005434504805	E10159	0180 008080	VASILIY KULIKOV	{"email": "kulikov-v.061972@postgrespro.ru", "phone": "+70258979970"}
0005434504806	E10159	6443 251173	DMITRIY DMITRIEV	{"email": "d_dmitriev.071975@postgrespro.ru", "phone": "+70092247217"}
0005434504807	70E9C6	4931 104035	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov.041966@postgrespro.ru", "phone": "+70081485650"}
0005434504808	BFB34E	9212 678133	IVAN SMIRNOV	{"phone": "+70800149812"}
0005434504809	BFB34E	0783 633848	SEMEN IVANOV	{"email": "ivanovsemen_1969@postgrespro.ru", "phone": "+70486564385"}
0005434504810	A6E3C4	5575 449763	ANTONINA BELOVA	{"phone": "+70894149563"}
0005434504811	A6E3C4	1530 841360	KONSTANTIN KUZNECOV	{"phone": "+70248854438"}
0005434504812	F3AA04	6333 668247	VLADIMIR OSIPOV	{"phone": "+70759578691"}
0005434504813	924679	4503 052127	YAROSLAV KUDRYASHOV	{"email": "kudryashov.y28121976@postgrespro.ru", "phone": "+70216250175"}
0005434504814	1AA810	1611 276750	SERGEY KUZNECOV	{"phone": "+70314347874"}
0005434504815	1AA810	8011 528889	RAISA ROMANOVA	{"email": "romanovaraisa-071975@postgrespro.ru", "phone": "+70727353214"}
0005434504816	0F9D78	3886 838124	PAVEL MIKHAYLOV	{"phone": "+70841637159"}
0005434504817	647854	2549 154854	GALINA RYABOVA	{"email": "gryabova1971@postgrespro.ru", "phone": "+70457630664"}
0005434504818	647854	7792 563875	LYUDMILA ANTONOVA	{"phone": "+70962618596"}
0005434504819	B3E9D7	9928 749090	VALENTINA BELOVA	{"email": "belova.valentina20081968@postgrespro.ru", "phone": "+70988199462"}
0005434504820	1D5F57	9585 301748	SERGEY VASILEV	{"phone": "+70354021650"}
0005434504821	EA048F	5944 218723	RAFAIL NIKITIN	{"phone": "+70395439178"}
0005434504822	EA048F	2170 649594	ANDREY KAZAKOV	{"email": "a-kazakov-081976@postgrespro.ru", "phone": "+70788436159"}
0005434504823	0FA0F2	7764 748901	DENIS ALEKSEEV	{"phone": "+70111683752"}
0005434504824	F1F2D3	6600 943532	ALEKSANDR MIRONOV	{"phone": "+70253227311"}
0005434504825	F1F2D3	4080 260884	GALINA BELOVA	{"phone": "+70900729041"}
0005434504826	B09B90	8865 983709	ROMAN VLASOV	{"email": "romanvlasov_1971@postgrespro.ru", "phone": "+70809556688"}
0005434504827	B09B90	3154 021580	EVGENIY ALEKSANDROV	{"phone": "+70642987489"}
0005434504828	B71AED	8081 033414	NIKITA KUDRYASHOV	{"phone": "+70073440862"}
0005434504829	52D43D	3361 726308	EKATERINA ROMANOVA	{"email": "ekaterina.romanova.1969@postgrespro.ru", "phone": "+70664626422"}
0005434504830	FBEB11	4562 123204	ALEKSANDR ORLOV	{"phone": "+70221408870"}
0005434504831	0EC0BC	6082 186989	VASILIY GRIGOREV	{"email": "grigorev_v-1975@postgrespro.ru", "phone": "+70920588553"}
0005434504832	0EC0BC	8072 474963	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya031970@postgrespro.ru", "phone": "+70504344947"}
0005434504833	482DB7	1389 866436	LYUDMILA EFIMOVA	{"phone": "+70254925288"}
0005434504834	51C8ED	3293 495776	ALEKSEY PAVLOV	{"phone": "+70111050746"}
0005434504835	CC13E1	1764 863943	SERGEY CHERNOV	{"phone": "+70337411342"}
0005434504836	85070C	1476 485581	TATYANA MEDVEDEVA	{"phone": "+70801273465"}
0005434504837	0BF359	6245 149399	EGOR ZHURAVLEV	{"phone": "+70644517528"}
0005434504838	23D68E	2866 167346	ZOYA GORBUNOVA	{"phone": "+70072794919"}
0005434504839	4DCAAA	6348 014291	MARIYA NAUMOVA	{"email": "m.naumova_1969@postgrespro.ru", "phone": "+70197306640"}
0005434504840	9814AD	1352 857323	MARGARITA KALININA	{"phone": "+70434394874"}
0005434504841	27FDD7	5169 818646	ALEKSEY MATVEEV	{"phone": "+70759952507"}
0005434504842	DC2A20	5762 524686	VERA KONDRATEVA	{"phone": "+70359536620"}
0005434504843	DC2A20	6935 308119	VALERIYA SCHERBAKOVA	{"email": "scherbakova-v_011969@postgrespro.ru", "phone": "+70175495738"}
0005434504844	D35C55	4673 298713	OKSANA FILIPPOVA	{"email": "filippova.oksana1961@postgrespro.ru", "phone": "+70989076478"}
0005434504845	2EDC8C	5033 272135	ANZHELA KUZNECOVA	{"email": "anzhela-kuznecova_1972@postgrespro.ru", "phone": "+70572110617"}
0005434504846	ADEFBE	3347 924474	ARTUR YAKOVLEV	{"phone": "+70450595708"}
0005434504847	61AA81	3229 516130	SVETLANA DAVYDOVA	{"phone": "+70196032809"}
0005434504848	61AA81	8441 613674	VLADIMIR MIRONOV	{"phone": "+70376904811"}
0005434504849	8E1619	4013 099289	VIKTORIYA FOMINA	{"email": "fomina-v-1975@postgrespro.ru", "phone": "+70766624447"}
0005434504850	8E1619	5746 445935	SERGEY CHERNOV	{"email": "schernov_061980@postgrespro.ru", "phone": "+70590869241"}
0005434504851	F4ED39	9103 445647	NAILYA NIKOLAEVA	{"phone": "+70854462551"}
0005434504852	26680D	7460 421742	ALEKSANDR KUZNECOV	{"email": "akuznecov_23061970@postgrespro.ru", "phone": "+70948539270"}
0005434504853	26680D	0134 910755	KONSTANTIN IVANOV	{"email": "ivanov-k_1979@postgrespro.ru", "phone": "+70718454236"}
0005434504854	26680D	8840 491295	MARIYA DMITRIEVA	{"phone": "+70043457352"}
0005434504855	0D60AD	2377 103236	SERGEY ORLOV	{"phone": "+70135418027"}
0005434504856	7F46D8	6761 151643	TATYANA KUZNECOVA	{"phone": "+70933101508"}
0005434504857	7F46D8	6894 939616	OLGA LAZAREVA	{"email": "olgalazareva111972@postgrespro.ru", "phone": "+70767195069"}
0005434504858	350D38	4639 115860	ANTONINA MIRONOVA	{"email": "mironovaa-011967@postgrespro.ru", "phone": "+70173833851"}
0005434504859	345EAA	5547 798018	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov091969@postgrespro.ru", "phone": "+70104631839"}
0005434504860	867AF8	3162 924270	ANASTASIYA NAZAROVA	{"email": "a.nazarova-05121967@postgrespro.ru", "phone": "+70451773060"}
0005434504861	CD81FC	9216 803176	VLADIMIR TIKHONOV	{"phone": "+70760006601"}
0005434504862	98A642	5945 342908	VIKTORIYA MARTYNOVA	{"email": "v_martynova10061976@postgrespro.ru", "phone": "+70813369969"}
0005434504863	6FBEAE	2127 695512	SERGEY MARTYNOV	{"email": "martynov-sergey.30051972@postgrespro.ru", "phone": "+70802155550"}
0005434504864	EC96ED	4788 298273	ANDREY SHEVCHENKO	{"phone": "+70704011455"}
0005434504865	EC96ED	0258 849372	TATYANA MIKHAYLOVA	{"phone": "+70139078952"}
0005434504866	E41344	3017 068219	TATYANA NIKOLAEVA	{"email": "nikolaeva-tatyana.22061968@postgrespro.ru", "phone": "+70809530992"}
0005434504867	C9FC0E	1114 298743	SERGEY ZHURAVLEV	{"phone": "+70652562364"}
0005434504868	24EF62	6266 246735	VALENTINA KISELEVA	{"phone": "+70897283659"}
0005434504869	C94154	7034 471980	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev_081974@postgrespro.ru", "phone": "+70769867396"}
0005434504870	5F51EE	2541 215388	GRIGORIY SOKOLOV	{"email": "sokolov-g.1979@postgrespro.ru", "phone": "+70843217368"}
0005434504871	D1FD17	3330 124130	ZLATA SAVELEVA	{"email": "saveleva.zlata-05051973@postgrespro.ru", "phone": "+70543896271"}
0005434504872	323984	7091 868904	ELENA MIRONOVA	{"phone": "+70651860856"}
0005434504873	394528	4941 215042	SERGEY VASILEV	{"phone": "+70148735150"}
0005434504874	394528	2019 688765	ALEKSANDR ALEKSANDROV	{"phone": "+70448778798"}
0005434504875	A236B5	5385 608420	LYUBOV STEPANOVA	{"email": "l_stepanova-081973@postgrespro.ru", "phone": "+70430524893"}
0005434504876	BF717F	2304 444678	NIKITA SCHERBAKOV	{"email": "n_scherbakov_1966@postgrespro.ru", "phone": "+70564956438"}
0005434504877	BF717F	7536 800543	SERGEY MOROZOV	{"email": "s-morozov111976@postgrespro.ru", "phone": "+70262915728"}
0005434504878	43063A	8224 902797	VLADIMIR ILIN	{"phone": "+70673006854"}
0005434504879	43063A	0751 796660	VIKTOR VOLKOV	{"phone": "+70200948502"}
0005434504880	71A720	4176 802936	EVGENIY CHERNOV	{"phone": "+70689278944"}
0005434504881	92D329	1728 326765	NINA KUZNECOVA	{"phone": "+70112020302"}
0005434504882	F89684	8956 892202	VALENTINA POLYAKOVA	{"email": "valentina-polyakova_1975@postgrespro.ru", "phone": "+70837111200"}
0005434504883	F34261	6010 884919	TATYANA SEMENOVA	{"email": "semenova_tatyana-30071967@postgrespro.ru", "phone": "+70939681101"}
0005434504884	F4FD82	8972 149681	NIKITA MELNIKOV	{"phone": "+70391523538"}
0005434504885	F4FD82	3965 943308	NIKITA STEPANOV	{"email": "stepanov-nikita22021975@postgrespro.ru", "phone": "+70790135715"}
0005434504886	BFC744	8955 161663	DMITRIY KULIKOV	{"email": "dmitriy_kulikov_031962@postgrespro.ru", "phone": "+70651084142"}
0005434504887	58AA1C	6988 182067	ANNA ROMANOVA	{"email": "annaromanova.01031963@postgrespro.ru", "phone": "+70783131042"}
0005434504888	82C45E	0904 075350	VADIM IVANOV	{"email": "ivanov_v.081975@postgrespro.ru", "phone": "+70177867301"}
0005434504889	E88942	3966 565933	LYUBOV FADEEVA	{"phone": "+70861457833"}
0005434504890	264F87	0531 731865	MIKHAIL KUZMIN	{"phone": "+70876019909"}
0005434504891	264F87	3932 136613	YURIY ZAYCEV	{"phone": "+70429766846"}
0005434504892	67373A	0958 962658	SVETLANA MAKSIMOVA	{"email": "maksimova_svetlana_22101977@postgrespro.ru", "phone": "+70750286367"}
0005434504893	954832	8730 391721	IVAN OSIPOV	{"email": "osipov_ivan-06061973@postgrespro.ru", "phone": "+70864054087"}
0005434504894	749FCE	3288 332334	YURIY MAKSIMOV	{"email": "maksimov.yuriy_15041967@postgrespro.ru", "phone": "+70232271432"}
0005434504895	B7498E	3377 196257	PAVEL KUZNECOV	{"phone": "+70321464883"}
0005434504896	F4FCC8	6899 864425	POLINA BELYAEVA	{"phone": "+70074342778"}
0005434504897	F4FCC8	7105 072090	IGOR ISAEV	{"email": "isaevi.25101965@postgrespro.ru", "phone": "+70553488924"}
0005434504898	477F5B	0032 603344	EDUARD ORLOV	{"email": "e_orlov.031977@postgrespro.ru", "phone": "+70619357996"}
0005434504899	C80B96	9920 476681	ZOYA KULIKOVA	{"phone": "+70331082546"}
0005434504900	9BD5BC	2261 717611	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy_11041970@postgrespro.ru", "phone": "+70625350020"}
0005434504901	9BD5BC	5879 306959	POLINA FILIPPOVA	{"email": "filippovap-1982@postgrespro.ru", "phone": "+70961792197"}
0005434504902	FDDAB7	1488 055340	NADEZHDA KRASNOVA	{"email": "n-krasnova_1973@postgrespro.ru", "phone": "+70906562216"}
0005434504903	4C3F46	3283 090544	KONSTANTIN MARTYNOV	{"phone": "+70807274652"}
0005434504904	C00050	7990 561702	NINA KISELEVA	{"email": "nina_kiseleva_05121982@postgrespro.ru", "phone": "+70138310256"}
0005434504905	C00050	1154 391438	DIANA IVANOVA	{"email": "d_ivanova.031972@postgrespro.ru", "phone": "+70377094490"}
0005434504906	991230	5481 954300	IVAN VOLKOV	{"phone": "+70155434160"}
0005434504907	E0BAAD	9733 706789	FEDOR KUZMIN	{"phone": "+70396802714"}
0005434504908	7B0F03	4674 880591	TATYANA PETROVA	{"email": "petrova-t.22121977@postgrespro.ru", "phone": "+70185953138"}
0005434504909	3327DD	6643 799068	OLGA KUZNECOVA	{"phone": "+70038423600"}
0005434504910	2A052D	8531 231580	NIKITA KONOVALOV	{"email": "n-konovalov18011960@postgrespro.ru", "phone": "+70763974933"}
0005434504911	C7C715	5841 026166	LYUDMILA KONDRATEVA	{"phone": "+70667296398"}
0005434504912	57308C	1328 089114	VIKTORIYA PAVLOVA	{"email": "pavlova.viktoriya071964@postgrespro.ru", "phone": "+70239472157"}
0005434504913	0A9B5F	6932 833774	NATALYA KAZAKOVA	{"email": "kazakova_natalya-08081968@postgrespro.ru", "phone": "+70445443472"}
0005434504914	10203D	9947 588207	SERGEY MOISEEV	{"email": "moiseev.s.1969@postgrespro.ru", "phone": "+70450899385"}
0005434504915	9FB647	8593 114252	NATALIYA GAVRILOVA	{"email": "n.gavrilova-06031971@postgrespro.ru", "phone": "+70426015882"}
0005434504916	83357C	1283 013591	SEMEN SOLOVEV	{"phone": "+70015146682"}
0005434504917	EDA909	4083 308469	MARINA VASILEVA	{"email": "vasilevam_1976@postgrespro.ru", "phone": "+70304567371"}
0005434504918	147266	4761 774593	ANDREY MAKSIMOV	{"email": "maksimova_121964@postgrespro.ru", "phone": "+70800575734"}
0005434504919	A4E149	7468 251000	SERGEY GORBUNOV	{"email": "sgorbunov-1965@postgrespro.ru", "phone": "+70841204379"}
0005434504920	21472C	0471 629895	SERGEY GAVRILOV	{"email": "gavrilov-s22021971@postgrespro.ru", "phone": "+70993728086"}
0005434504921	BF16B0	5661 003046	MIKHAIL PETROV	{"phone": "+70175384162"}
0005434504922	F39B84	2005 877129	PETR TIKHONOV	{"email": "tikhonov_petr.111967@postgrespro.ru", "phone": "+70511673135"}
0005434504923	29B087	8835 499137	ALEKSANDR MOROZOV	{"phone": "+70968666490"}
0005434504924	747BCD	3499 123658	NATALYA LAZAREVA	{"phone": "+70776540918"}
0005434504925	83B458	0463 459983	IRINA KOROLEVA	{"email": "irina_koroleva1966@postgrespro.ru", "phone": "+70100403863"}
0005434504926	26D557	0505 302079	NATALYA FEDOROVA	{"phone": "+70826660914"}
0005434504927	26D557	5272 302320	MARIYA BARANOVA	{"phone": "+70251161280"}
0005434504928	0A569C	4120 431840	ALEKSANDR MAKAROV	{"phone": "+70245859627"}
0005434504929	6C0995	4535 210650	ANNA TIMOFEEVA	{"phone": "+70775701466"}
0005434504930	241DC0	8625 300911	VALENTINA MELNIKOVA	{"phone": "+70532632177"}
0005434504931	17EF58	7802 408612	KLAVDIYA SAVELEVA	{"phone": "+70655424122"}
0005434504932	C4C36E	3871 411374	GENNADIY PAVLOV	{"email": "g_pavlov.101967@postgrespro.ru", "phone": "+70959888245"}
0005434504933	A0A696	5672 150460	ALEKSANDR BELOV	{"email": "belov.a-13021970@postgrespro.ru", "phone": "+70081907612"}
0005434504934	9BCA65	0083 712110	PETR MARTYNOV	{"email": "martynov_p.051972@postgrespro.ru", "phone": "+70321066967"}
0005434504935	0A5406	8860 726925	DANILA KUZMIN	{"email": "danila-kuzmin-1967@postgrespro.ru", "phone": "+70151709832"}
0005434504936	0A5406	6686 170506	OLGA MELNIKOVA	{"phone": "+70161672748"}
0005434504937	A360EB	8585 040670	NIKOLAY BARANOV	{"phone": "+70347917997"}
0005434504938	E7161F	5698 493941	NADEZHDA POPOVA	{"email": "nadezhda_popova_1973@postgrespro.ru", "phone": "+70376469284"}
0005434504939	358BE2	7621 514773	MAKSIM TARASOV	{"email": "mtarasov07051969@postgrespro.ru", "phone": "+70715482060"}
0005434504940	15537A	7804 066389	ELENA BORISOVA	{"phone": "+70345930640"}
0005434504941	15537A	2513 149957	PAVEL PETROV	{"email": "petrovp.011975@postgrespro.ru", "phone": "+70761167667"}
0005434504942	820DD6	7692 433997	YANA PAVLOVA	{"email": "pavlova-yana.07071975@postgrespro.ru", "phone": "+70731948985"}
0005434504943	8E808B	7814 674517	ALEKSANDR FROLOV	{"email": "frolovaleksandr_19021970@postgrespro.ru", "phone": "+70841876423"}
0005434504944	F656C7	5497 484704	LEONID ANDREEV	{"email": "l_andreev_02081974@postgrespro.ru", "phone": "+70648745232"}
0005434504945	E745AF	8344 191745	ELENA LUKYANOVA	{"email": "lukyanova_elena_23071976@postgrespro.ru", "phone": "+70168811009"}
0005434504946	E745AF	8396 553024	DARYA KUZNECOVA	{"phone": "+70009001388"}
0005434504947	D28DBA	5027 461869	MARINA LUKYANOVA	{"email": "lukyanovamarina_07081975@postgrespro.ru", "phone": "+70960394551"}
0005434504948	D28DBA	8568 249300	ANNA IVANOVA	{"phone": "+70981741577"}
0005434504949	6D3FC3	2210 025173	IRINA SEMENOVA	{"email": "semenova-i_071977@postgrespro.ru", "phone": "+70712247971"}
0005434504950	79E259	7567 148099	LYUBOV IVANOVA	{"phone": "+70900249119"}
0005434504951	0B9EB6	6346 466043	DMITRIY TARASOV	{"phone": "+70144190303"}
0005434504952	0B9EB6	1949 460879	IRINA BARANOVA	{"email": "baranova-i-121976@postgrespro.ru", "phone": "+70860256909"}
0005434504953	4B854F	9234 616217	ALENA KOZLOVA	{"email": "a.kozlova20111970@postgrespro.ru", "phone": "+70908893726"}
0005434504954	4B854F	0673 796187	VERA LOGINOVA	{"phone": "+70601548181"}
0005434504955	DD7018	8237 306103	MAKSIM MATVEEV	{"phone": "+70947560875"}
0005434504956	EA07AD	5805 186551	EVGENIY ZAKHAROV	{"phone": "+70288435380"}
0005434504957	C41BEE	6188 273235	RAISA DMITRIEVA	{"phone": "+70208033144"}
0005434504958	CFFA15	3533 050419	OLGA SOKOLOVA	{"email": "olga.sokolova.1969@postgrespro.ru", "phone": "+70227862392"}
0005434504959	9D277F	6932 994298	SVETLANA YAKOVLEVA	{"phone": "+70835081355"}
0005434504960	6EB71D	7068 158579	VLADIMIR MELNIKOV	{"phone": "+70110107377"}
0005434504961	C2691B	1005 031657	NIKOLAY DENISOV	{"phone": "+70739158214"}
0005434504962	C2691B	1743 079899	SERGEY MATVEEV	{"email": "matveev_s-091981@postgrespro.ru", "phone": "+70365167671"}
0005434504963	3FE8D1	5160 685991	IGOR MAKAROV	{"email": "makarov.igor15111983@postgrespro.ru", "phone": "+70259525865"}
0005434504964	F6097A	0439 794262	VALENTINA NAZAROVA	{"phone": "+70611029859"}
0005434504965	C7FF68	5712 347975	VLADISLAV MARTYNOV	{"email": "v-martynov_16021976@postgrespro.ru", "phone": "+70486292052"}
0005434504966	C7FF68	4823 600755	VERA VOLKOVA	{"phone": "+70161666427"}
0005434504967	4115D3	7715 793040	ALEKSANDR GERASIMOV	{"phone": "+70445689440"}
0005434504968	4115D3	7465 281387	POLINA NIKITINA	{"phone": "+70985256250"}
0005434504969	413C80	3509 849741	VIKTOR TIKHONOV	{"email": "tikhonov_viktor.11111982@postgrespro.ru", "phone": "+70797288199"}
0005434504970	413C80	1284 048987	ELENA MOROZOVA	{"phone": "+70641008675"}
0005434504971	229A64	7649 865188	EVGENIY KULIKOV	{"email": "evgeniy.kulikov.101978@postgrespro.ru", "phone": "+70074580341"}
0005434504972	0704FB	3932 180981	SVETLANA MIRONOVA	{"phone": "+70448233280"}
0005434504973	CF07AA	6642 866536	VLADIMIR ZHUKOV	{"email": "zhukov_vladimir.051973@postgrespro.ru", "phone": "+70545167635"}
0005434504974	045F41	5884 708977	GALINA DANILOVA	{"phone": "+70207654744"}
0005434504975	045F41	6432 261312	NINA ABRAMOVA	{"email": "abramova_nina1977@postgrespro.ru", "phone": "+70749696647"}
0005434504976	BA6887	4152 261862	TAMARA FEDOROVA	{"phone": "+70054066024"}
0005434504977	5E534E	3328 546212	VITALIY MATVEEV	{"phone": "+70263082064"}
0005434504978	FA38B4	3656 694767	IGOR NOVIKOV	{"email": "igornovikov_1971@postgrespro.ru", "phone": "+70460668393"}
0005434504979	05929A	1384 055177	VERONIKA STEPANOVA	{"phone": "+70257158957"}
0005434504980	05929A	1588 787183	IRINA VASILEVA	{"phone": "+70033180571"}
0005434504981	2C1CE4	4667 214144	FEDOR KUZNECOV	{"email": "kuznecovfedor_30061970@postgrespro.ru", "phone": "+70181225098"}
0005434504982	2C1CE4	1053 863364	ALEKSEY KOZLOV	{"email": "kozlov_aleksey_01031972@postgrespro.ru", "phone": "+70610044645"}
0005434504983	C06639	0451 351605	VYACHESLAV KUZNECOV	{"email": "kuznecov.vyacheslav_081984@postgrespro.ru", "phone": "+70884795978"}
0005434504984	D4C529	6378 725487	ILYA FROLOV	{"email": "frolovilya-071978@postgrespro.ru", "phone": "+70628117992"}
0005434504985	EB1832	6458 636853	ILYA ISAEV	{"phone": "+70590786342"}
0005434504986	EB1832	5038 989431	ELENA SIDOROVA	{"email": "e-sidorova.021974@postgrespro.ru", "phone": "+70154374218"}
0005434504987	1B3376	2058 526185	SVETLANA FOMINA	{"phone": "+70859516287"}
0005434504988	0A48C8	9113 706634	EMMA SMIRNOVA	{"email": "esmirnova-13041960@postgrespro.ru", "phone": "+70653575542"}
0005434504989	F33C54	9529 827437	NATALYA MAKAROVA	{"email": "makarova.natalya_011977@postgrespro.ru", "phone": "+70799118662"}
0005434504990	A29FEE	2427 994727	ELENA MAKAROVA	{"phone": "+70085822425"}
0005434504991	1DDFB3	5432 463483	ANTONINA KRASNOVA	{"phone": "+70005580353"}
0005434504992	1DDFB3	7716 424465	YULIYA FADEEVA	{"email": "fadeeva.y-101970@postgrespro.ru", "phone": "+70866696784"}
0005434504993	1DDFB3	0808 445672	SERGEY ALEKSANDROV	{"email": "aleksandrov.s_1980@postgrespro.ru", "phone": "+70882859159"}
0005434504994	6FCCB1	6449 470547	VYACHESLAV BORISOV	{"email": "borisov.vyacheslav_101971@postgrespro.ru", "phone": "+70344715099"}
0005434504995	D48BDE	8769 252382	DARYA SOROKINA	{"email": "sorokina_d-051976@postgrespro.ru", "phone": "+70171396839"}
0005434504996	D48BDE	3779 799357	LYUBOV PETROVA	{"phone": "+70156896984"}
0005434504997	B55B15	1354 435940	OLGA MAKAROVA	{"phone": "+70849458502"}
0005434504998	358E43	9816 767169	OLGA TITOVA	{"phone": "+70162386638"}
0005434504999	358E43	2126 866074	EKATERINA KAZAKOVA	{"phone": "+70708657536"}
0005434505000	C1B87A	3544 469253	ELENA POPOVA	{"email": "popova.e-1963@postgrespro.ru", "phone": "+70350686387"}
0005434505001	C1B87A	7371 444828	VALENTIN GAVRILOV	{"email": "valentin_gavrilov-01061979@postgrespro.ru", "phone": "+70031276885"}
0005434505002	E34723	4017 971798	NIKOLAY FILIPPOV	{"email": "n-filippov-1970@postgrespro.ru", "phone": "+70610107490"}
0005434505003	E8BAE1	6320 979674	BORIS SOROKIN	{"email": "borissorokin1988@postgrespro.ru", "phone": "+70241287466"}
0005434505004	555485	0876 067481	LYUDMILA EFIMOVA	{"email": "lefimova.04051964@postgrespro.ru", "phone": "+70661726932"}
0005434505005	BBCBC2	4371 292172	ZOYA MATVEEVA	{"phone": "+70663445100"}
0005434505006	E87F8E	6534 417947	SERGEY ORLOV	{"email": "orlov.s_06031974@postgrespro.ru", "phone": "+70341722757"}
0005434505007	5C4F31	9650 479597	YURIY MAKAROV	{"email": "makarovy-051964@postgrespro.ru", "phone": "+70176370545"}
0005434505008	F682AE	5523 920811	ALEKSANDRA KONOVALOVA	{"email": "konovalova-a-051969@postgrespro.ru", "phone": "+70266110868"}
0005434505009	541AE3	1354 019327	VERA DANILOVA	{"phone": "+70436093924"}
0005434505010	541AE3	4202 276601	ANTON SOROKIN	{"email": "sorokin-anton021980@postgrespro.ru", "phone": "+70247160184"}
0005434505011	E15F62	4755 600774	ALEKSEY MOISEEV	{"email": "a_moiseev-1966@postgrespro.ru", "phone": "+70999450392"}
0005434505012	E15F62	0219 613598	SERGEY NIKOLAEV	{"phone": "+70502953718"}
0005434505013	343863	3453 395722	DARYA KRASNOVA	{"phone": "+70702395221"}
0005434505014	E29AE6	8317 134835	SERGEY IVANOV	{"phone": "+70993611752"}
0005434505015	61A358	6808 487368	DENIS TARASOV	{"phone": "+70467576122"}
0005434505016	61A358	8124 165208	EKATERINA CHERNOVA	{"email": "chernova-e23101974@postgrespro.ru", "phone": "+70811952181"}
0005434505017	F80A98	3257 726144	VLADIMIR PAVLOV	{"phone": "+70002569433"}
0005434505018	8B39A4	9995 023337	YULIYA NIKITINA	{"email": "yuliya.nikitina1969@postgrespro.ru", "phone": "+70635356256"}
0005434505019	042223	5326 770382	VLADIMIR VASILEV	{"email": "v_vasilev-23071976@postgrespro.ru", "phone": "+70987567710"}
0005434505020	042223	3126 372600	ANDREY KOZLOV	{"email": "a-kozlov.1963@postgrespro.ru", "phone": "+70372199420"}
0005434505021	AE1561	9216 877708	IRINA KOLESNIKOVA	{"phone": "+70346461872"}
0005434505022	E1C36D	2842 389558	TAMARA PETROVA	{"email": "petrova_t.1981@postgrespro.ru", "phone": "+70696062389"}
0005434505023	E1C36D	4939 813377	ANASTASIYA EGOROVA	{"email": "egorova-anastasiya.011969@postgrespro.ru", "phone": "+70649029914"}
0005434505024	DEDA62	9704 732553	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov.v1964@postgrespro.ru", "phone": "+70597046862"}
0005434505025	DEDA62	1552 499718	NADEZHDA KAZAKOVA	{"email": "kazakova.n-06111965@postgrespro.ru", "phone": "+70375662957"}
0005434505026	47A027	9690 203940	PETR ABRAMOV	{"email": "petrabramov_1970@postgrespro.ru", "phone": "+70237496950"}
0005434505027	2DBBA8	3492 028645	GALINA VOLKOVA	{"email": "volkova-galina-071983@postgrespro.ru", "phone": "+70870178191"}
0005434505028	2DBBA8	5647 462941	MARGARITA NIKOLAEVA	{"email": "nikolaeva.margarita-031972@postgrespro.ru", "phone": "+70493411157"}
0005434505029	45F584	5216 703352	ALEKSEY SOROKIN	{"phone": "+70356054085"}
0005434505030	45F584	1830 518374	ANASTASIYA YAKOVLEVA	{"email": "anastasiya-yakovleva041989@postgrespro.ru", "phone": "+70288785220"}
0005434505031	1251C7	4049 921604	SERGEY MOISEEV	{"phone": "+70313156155"}
0005434505032	90F557	9873 391964	PAVEL PAVLOV	{"phone": "+70871629227"}
0005434505033	04A64E	1097 624059	MAKSIM KOROLEV	{"email": "maksim.korolev-031971@postgrespro.ru", "phone": "+70146538954"}
0005434505034	04BE3D	2353 276302	ZULFIYA KUZNECOVA	{"phone": "+70476162015"}
0005434505035	7EFAD1	7973 165356	EVGENIY GAVRILOV	{"phone": "+70280237294"}
0005434505036	0CD678	6087 818635	EVDOKIYA KUZNECOVA	{"phone": "+70269866556"}
0005434505037	0CD678	9421 484482	ELENA AFANASEVA	{"email": "afanaseva-elena.25111984@postgrespro.ru", "phone": "+70243486918"}
0005434505038	FE3413	0748 852616	TATYANA ANDREEVA	{"phone": "+70828905597"}
0005434505039	FE3413	7135 531552	LARISA DMITRIEVA	{"phone": "+70185561098"}
0005434505040	CE4757	1830 843697	GRIGORIY MOISEEV	{"phone": "+70245108162"}
0005434505041	CE4757	9068 310021	NIKOLAY IVANOV	{"email": "nivanov-02031973@postgrespro.ru", "phone": "+70697605244"}
0005434505042	DE186C	5295 532360	TATYANA ILINA	{"email": "tatyanailina1974@postgrespro.ru", "phone": "+70489109728"}
0005434505043	DE186C	8224 323968	VYACHESLAV PETROV	{"email": "vyacheslav.petrov_1979@postgrespro.ru", "phone": "+70789097189"}
0005434505044	DE186C	3501 598616	RINAT KAZAKOV	{"phone": "+70597742430"}
0005434505045	2AC40F	0339 970779	DARYA EGOROVA	{"email": "d.egorova.021972@postgrespro.ru", "phone": "+70252321580"}
0005434505046	28AA90	5392 233061	ROMAN TIKHONOV	{"email": "roman-tikhonov.071973@postgrespro.ru", "phone": "+70677100182"}
0005434505047	28AA90	6792 687664	DMITRIY NAZAROV	{"email": "nazarov-d_041975@postgrespro.ru", "phone": "+70658583064"}
0005434505048	28AA90	6781 309470	MARINA IVANOVA	{"phone": "+70770039466"}
0005434505049	FA8943	6396 308759	TATYANA MAKSIMOVA	{"email": "maksimova_t-031973@postgrespro.ru", "phone": "+70481410640"}
0005434505050	EA4425	3959 065393	FARIDA ALEKSEEVA	{"phone": "+70636840723"}
0005434505051	EA4425	4260 110511	EKATERINA KOZLOVA	{"phone": "+70806203239"}
0005434505052	805218	9910 409007	PAVEL VOLKOV	{"phone": "+70392498268"}
0005434505053	805218	1133 663427	SVETLANA ANISIMOVA	{"phone": "+70625300626"}
0005434505054	A5EF4E	2521 232866	IRINA FEDOROVA	{"email": "irina-fedorova.1980@postgrespro.ru", "phone": "+70804770505"}
0005434505055	A5EF4E	2285 687483	YULIYA BORISOVA	{"phone": "+70570139784"}
0005434505056	009CF6	2023 714017	ALEKSANDR VOLKOV	{"phone": "+70467308625"}
0005434505057	009CF6	2092 257278	ALEKSEY ZAKHAROV	{"email": "a-zakharov_091968@postgrespro.ru", "phone": "+70870081984"}
0005434505058	4176F4	9679 767000	VITALIY MOISEEV	{"email": "vmoiseev_1973@postgrespro.ru", "phone": "+70040578448"}
0005434505059	B071F2	1140 253226	NINA ZOTOVA	{"email": "n-zotova_121975@postgrespro.ru", "phone": "+70043467137"}
0005434505060	5D90E8	6303 530204	DMITRIY ROMANOV	{"phone": "+70566718374"}
0005434505061	D93342	2634 377117	YULIYA MAKAROVA	{"phone": "+70169462392"}
0005434505062	386FD4	1407 700293	YURIY SMIRNOV	{"email": "smirnovyuriy-10061990@postgrespro.ru", "phone": "+70367410498"}
0005434505063	3052BA	3587 487643	GRIGORIY ZHURAVLEV	{"email": "zhuravlev.g021976@postgrespro.ru", "phone": "+70072328206"}
0005434505064	3052BA	1074 268457	VALENTINA KISELEVA	{"email": "kiselevav.1979@postgrespro.ru", "phone": "+70121065927"}
0005434505065	9C8652	2906 912697	VALENTINA MASLOVA	{"phone": "+70558344620"}
0005434505066	05EED3	5598 462610	YURIY SMIRNOV	{"phone": "+70004482741"}
0005434505067	06B8F4	1989 470760	DANIIL SMIRNOV	{"email": "smirnov-daniil1968@postgrespro.ru", "phone": "+70642477466"}
0005434505068	564853	8996 201382	TAMARA KRASNOVA	{"email": "krasnova_t-27041963@postgrespro.ru", "phone": "+70522508124"}
0005434505069	53E37C	1818 596401	VLADISLAV KUZNECOV	{"email": "kuznecov.v_1959@postgrespro.ru", "phone": "+70398178412"}
0005434505070	50E1B1	1370 853893	ALEKSANDR PETROV	{"phone": "+70955186554"}
0005434505071	50E1B1	5703 889860	VALERIYA MOROZOVA	{"phone": "+70164329533"}
0005434505072	8238DD	6541 894693	SVETLANA MAKAROVA	{"email": "svetlana_makarova-111976@postgrespro.ru", "phone": "+70712302941"}
0005434505073	FF20F7	1908 241178	ANNA IVANOVA	{"phone": "+70759245401"}
0005434505074	1B5E7A	6904 470817	DIANA TROFIMOVA	{"email": "d.trofimova_1975@postgrespro.ru", "phone": "+70585046609"}
0005434505075	1B5E7A	2770 199792	LARISA FADEEVA	{"email": "fadeeval07101967@postgrespro.ru", "phone": "+70951581811"}
0005434505076	1B5E7A	3214 092331	ALEKSANDRA KULIKOVA	{"email": "aleksandrakulikova-1973@postgrespro.ru", "phone": "+70964826933"}
0005434505077	5226EB	5477 296195	ANDREY TARASOV	{"email": "andrey.tarasov-051977@postgrespro.ru", "phone": "+70015469929"}
0005434505078	77C903	9423 640849	VLADIMIR BELOV	{"email": "v.belov_30061980@postgrespro.ru", "phone": "+70317300032"}
0005434505079	77C903	2913 317122	NINA MOROZOVA	{"phone": "+70764834205"}
0005434505080	C47DD5	4232 150391	EKATERINA SERGEEVA	{"phone": "+70694096297"}
0005434505081	C47DD5	3945 368243	TATYANA FEDOROVA	{"email": "fedorova_tatyana.08061962@postgrespro.ru", "phone": "+70146714430"}
0005434505082	8E4B1C	0191 400148	ALEKSANDR FEDOROV	{"phone": "+70902124863"}
0005434505083	DF0515	3340 211944	ZOYA SOLOVEVA	{"phone": "+70842562623"}
0005434505084	DF0515	2023 990074	DANIIL POPOV	{"phone": "+70477734585"}
0005434505085	E2FA48	1120 217877	YAROSLAV DENISOV	{"email": "denisovyaroslav28011974@postgrespro.ru", "phone": "+70127702140"}
0005434505086	6E84E5	7126 019639	VYACHESLAV NIKITIN	{"phone": "+70110178322"}
0005434505087	5C67F6	4237 032003	ANASTASIYA KOMAROVA	{"phone": "+70302646359"}
0005434505088	5C67F6	8360 710083	TATYANA KONOVALOVA	{"email": "tatyanakonovalova071981@postgrespro.ru", "phone": "+70981830220"}
0005434505089	BFA063	7385 929282	NIKOLAY SIDOROV	{"phone": "+70441626147"}
0005434505090	D57C8E	4254 270760	VLADISLAV ABRAMOV	{"email": "v-abramov_09011968@postgrespro.ru", "phone": "+70160288167"}
0005434505091	6A8EB9	8320 665662	EVGENIY KOROLEV	{"email": "evgeniy-korolev-1970@postgrespro.ru", "phone": "+70145119005"}
0005434505092	6A8EB9	6186 100377	MAKSIM PAVLOV	{"phone": "+70843517774"}
0005434505093	6A8EB9	2325 712849	ANNA NIKITINA	{"email": "nikitina_a-05041966@postgrespro.ru", "phone": "+70551767161"}
0005434505094	62145C	1105 085855	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina.1976@postgrespro.ru", "phone": "+70518751365"}
0005434505095	6BAA88	7494 829542	NATALYA NIKIFOROVA	{"email": "nikiforova.n.071978@postgrespro.ru", "phone": "+70500087483"}
0005434505096	ABDC25	5385 870927	VLADIMIR NAZAROV	{"email": "nazarov_v.111980@postgrespro.ru", "phone": "+70648837478"}
0005434505097	81C6D5	3820 831574	EKATERINA KONOVALOVA	{"phone": "+70089893187"}
0005434505098	A1506D	9004 622270	ANDREY IVANOV	{"phone": "+70856473085"}
0005434505099	F81E70	5868 471019	ELENA KUDRYASHOVA	{"phone": "+70113607671"}
0005434505100	F81E70	1123 923406	OLGA MEDVEDEVA	{"email": "olga-medvedeva_18011967@postgrespro.ru", "phone": "+70102132011"}
0005434505101	8477DD	3432 439258	ROZALIYA ILINA	{"phone": "+70303142857"}
0005434505102	8477DD	3779 645052	ANDREY MATVEEV	{"email": "a_matveev-1977@postgrespro.ru", "phone": "+70520227094"}
0005434505103	0C41FB	3057 698357	LYUBOV MOISEEVA	{"email": "moiseeva_lyubov-04091965@postgrespro.ru", "phone": "+70659471735"}
0005434505104	9C4FCB	6848 525322	YULIYA ERMAKOVA	{"phone": "+70772458839"}
0005434505105	6D195D	0908 033421	YURIY DENISOV	{"email": "denisov_y_1977@postgrespro.ru", "phone": "+70086726418"}
0005434505106	6D195D	4699 647835	LYUBOV ROMANOVA	{"phone": "+70403788613"}
0005434505107	80FFFB	7190 809022	ALEKSANDR FROLOV	{"email": "frolov.aleksandr.121986@postgrespro.ru", "phone": "+70776575305"}
0005434505108	80FFFB	5940 282130	OLGA SOLOVEVA	{"phone": "+70588584535"}
0005434505109	15E2C5	5410 569142	SERGEY NOVIKOV	{"phone": "+70945584096"}
0005434505110	4607DA	0974 004324	OLGA SEMENOVA	{"phone": "+70942061144"}
0005434505111	89C1F3	8987 381268	ELENA ALEKSEEVA	{"phone": "+70124694197"}
0005434505112	89C1F3	7169 576123	ANASTASIYA GRISHINA	{"phone": "+70033390691"}
0005434505113	4C0B93	1409 229244	ALEKSANDR VLASOV	{"email": "vlasov_a.051975@postgrespro.ru", "phone": "+70810902487"}
0005434505114	4C0B93	7339 441858	VIKTOR FILIPPOV	{"email": "filippov.viktor-1964@postgrespro.ru", "phone": "+70289903773"}
0005434505115	4A7047	0300 985094	ANNA SEMENOVA	{"email": "anna_semenova-091979@postgrespro.ru", "phone": "+70266814983"}
0005434505116	4A7047	8531 181248	IRINA TIKHONOVA	{"email": "tikhonova.irina_081971@postgrespro.ru", "phone": "+70153923808"}
0005434505117	C2F782	8476 975456	NATALYA KOLESNIKOVA	{"phone": "+70940556530"}
0005434505118	C2F782	3172 170726	PAVEL BORISOV	{"phone": "+70754449372"}
0005434505119	F8A544	2577 723902	VLADISLAV TIMOFEEV	{"email": "timofeevvladislav.1969@postgrespro.ru", "phone": "+70566218004"}
0005434505120	C0C3E2	9323 917911	KIRILL MIKHAYLOV	{"email": "mikhaylovk.051968@postgrespro.ru", "phone": "+70287630807"}
0005434505121	91E8D2	4149 165560	SERGEY EGOROV	{"phone": "+70904350614"}
0005434505122	D9EBEC	9956 630681	SVETLANA AKIMOVA	{"email": "sakimova_09031976@postgrespro.ru", "phone": "+70847990462"}
0005434505123	D9EBEC	6417 232437	VITALIY FEDOTOV	{"phone": "+70363180441"}
0005434505124	5D3B3A	3547 809778	SERGEY KRASNOV	{"email": "sergey-krasnov1962@postgrespro.ru", "phone": "+70785109987"}
0005434505125	AEE0D5	6797 546531	IRINA MELNIKOVA	{"email": "melnikova.irina.29081977@postgrespro.ru", "phone": "+70033907733"}
0005434505126	AEE0D5	1409 940353	VALENTINA FEDOROVA	{"phone": "+70585325787"}
0005434505127	037E4E	8829 474264	VALERIY VASILEV	{"email": "vasilev.valeriy031975@postgrespro.ru", "phone": "+70273154281"}
0005434505128	0D87DF	9560 381108	ALEKSANDR MATVEEV	{"email": "amatveev_1980@postgrespro.ru", "phone": "+70100407641"}
0005434505129	E4964C	7631 026025	IRINA ILINA	{"phone": "+70149346986"}
0005434505130	716EAD	4315 934134	GRIGORIY NIKITIN	{"phone": "+70970571090"}
0005434505131	3A24EE	3833 126358	LYUDMILA KAZAKOVA	{"email": "kazakova-l-09041976@postgrespro.ru", "phone": "+70801494678"}
0005434505132	3A24EE	2335 712726	ZINAIDA ANDREEVA	{"phone": "+70798955116"}
0005434505133	6E6B98	8199 586277	NIKOLAY MARTYNOV	{"email": "n-martynov-04051971@postgrespro.ru", "phone": "+70430711971"}
0005434505134	905DC3	3721 889466	ARTUR ROMANOV	{"phone": "+70998299088"}
0005434505135	1467DB	4739 114721	ELENA NIKIFOROVA	{"email": "nikiforovaelena_1976@postgrespro.ru", "phone": "+70049238631"}
0005434505136	2182C3	5680 652083	ALEKSEY SAVELEV	{"email": "savelev-aleksey_071979@postgrespro.ru", "phone": "+70765496408"}
0005434505137	2182C3	9699 994498	SVETLANA PAVLOVA	{"email": "pavlova.s_15011961@postgrespro.ru", "phone": "+70251857541"}
0005434505138	5B6292	7725 496219	YURIY AFANASEV	{"phone": "+70922431955"}
0005434505139	5B6292	3836 161150	ELENA CHERNOVA	{"phone": "+70835714144"}
0005434505140	51FF83	0909 483749	VIKTORIYA TIKHONOVA	{"phone": "+70717480729"}
0005434505141	51FF83	9194 099860	TATYANA NIKITINA	{"phone": "+70328648135"}
0005434505142	4E48A0	9535 465775	VITALIY TARASOV	{"email": "vtarasov.101966@postgrespro.ru", "phone": "+70080632072"}
0005434505143	4E48A0	1002 367443	KIRILL POPOV	{"email": "popovk_1966@postgrespro.ru", "phone": "+70263377478"}
0005434505144	39A113	8027 615891	LIYA MOROZOVA	{"email": "morozova_l.1972@postgrespro.ru", "phone": "+70660925059"}
0005434505145	615BD8	1771 984223	SERGEY VASILEV	{"email": "s-vasilev1961@postgrespro.ru", "phone": "+70881011405"}
0005434505146	615BD8	1937 509560	ARTEM RODIONOV	{"email": "artem.rodionov061972@postgrespro.ru", "phone": "+70709004986"}
0005434505147	615BD8	1308 922283	ALEKSANDR TIMOFEEV	{"email": "timofeeva121980@postgrespro.ru", "phone": "+70747911269"}
0005434505148	616417	8594 350214	TATYANA KUZNECOVA	{"phone": "+70156667853"}
0005434505149	616417	3087 818807	VLADIMIR BONDARENKO	{"email": "vladimir-bondarenko.091977@postgrespro.ru", "phone": "+70916727303"}
0005434505150	50DC01	5523 879640	NIKOLAY ZAKHAROV	{"phone": "+70826750955"}
0005434505151	50DC01	4885 191205	YULIYA VOROBEVA	{"phone": "+70477466765"}
0005434505152	2C0BBB	4869 115282	ELENA POPOVA	{"email": "e_popova_12041967@postgrespro.ru", "phone": "+70742529927"}
0005434505153	2C0BBB	0568 959761	DENIS KUZMIN	{"phone": "+70575560464"}
0005434505154	E643A0	2039 221658	MARINA FILIPPOVA	{"email": "filippova_m_19051979@postgrespro.ru", "phone": "+70962526266"}
0005434505155	E643A0	3981 218178	VIKTORIYA LUKYANOVA	{"phone": "+70537411511"}
0005434505156	2CBC8D	3737 776792	TATYANA EFIMOVA	{"email": "tatyanaefimova_13111972@postgrespro.ru", "phone": "+70722139282"}
0005434505157	2CBC8D	4621 003309	ARTEM KUZNECOV	{"phone": "+70647948065"}
0005434505158	FE686D	9470 107193	TIMUR IVANOV	{"email": "ivanov_t-1971@postgrespro.ru", "phone": "+70023287194"}
0005434505159	9661A7	0977 080041	SVETLANA ILINA	{"email": "ilina-s15121968@postgrespro.ru", "phone": "+70286454992"}
0005434505160	3B9359	7849 006898	RAISA NOVIKOVA	{"phone": "+70522529426"}
0005434505161	3B9359	3810 647345	ALEKSANDR SMIRNOV	{"phone": "+70190269154"}
0005434505162	D027EB	5664 872783	YURIY VASILEV	{"phone": "+70482893245"}
0005434505163	D027EB	8243 697775	OLGA NIKOLAEVA	{"email": "olga.nikolaeva.051969@postgrespro.ru", "phone": "+70616522363"}
0005434505164	71D591	3342 208667	TATYANA PAVLOVA	{"email": "t.pavlova-1962@postgrespro.ru", "phone": "+70367867102"}
0005434505165	BA676E	4638 679662	DENIS SEMENOV	{"email": "semenovdenis.1968@postgrespro.ru", "phone": "+70530755247"}
0005434505166	3F1BDC	2871 639784	NINA ANTONOVA	{"phone": "+70308260517"}
0005434505167	13794D	1985 713788	ALEKSEY MOISEEV	{"phone": "+70821324381"}
0005434505168	3E9C67	7431 719954	NADEZHDA POPOVA	{"email": "nadezhda-popova_1976@postgrespro.ru", "phone": "+70682450167"}
0005434505169	C01057	3647 095392	TATYANA ANISIMOVA	{"email": "anisimova_t_081962@postgrespro.ru", "phone": "+70285136951"}
0005434505170	77B2F4	2508 563421	ROMAN KUDRYASHOV	{"phone": "+70828678677"}
0005434505171	8CCE53	8951 222786	YAKOV DENISOV	{"phone": "+70976997612"}
0005434505172	05A96D	3877 164685	VALERIY KOZLOV	{"phone": "+70527278911"}
0005434505173	0DAAA2	4374 099654	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr-01111968@postgrespro.ru", "phone": "+70512215899"}
0005434505174	9787D5	7498 564321	TATYANA KONDRATEVA	{"email": "t_kondrateva_17081975@postgrespro.ru", "phone": "+70174809297"}
0005434505175	679BD6	1084 915345	TAGIR BELOV	{"email": "belov.t12121975@postgrespro.ru", "phone": "+70807255090"}
0005434505176	679BD6	3529 606166	MAKSIM MAKAROV	{"email": "makarov-maksim.061979@postgrespro.ru", "phone": "+70855353010"}
0005434505177	A6904D	5695 881181	EKATERINA SERGEEVA	{"email": "ekaterinasergeeva27111964@postgrespro.ru", "phone": "+70005948886"}
0005434505178	A6904D	7883 749570	IRINA NESTEROVA	{"phone": "+70640339620"}
0005434505179	D71043	3580 283303	VASILIY SOROKIN	{"email": "sorokinv1962@postgrespro.ru", "phone": "+70002881757"}
0005434505180	4A5216	0721 878037	VALENTINA GUSEVA	{"email": "guseva-valentina_1971@postgrespro.ru", "phone": "+70698409071"}
0005434505181	4AE280	1537 593463	VADIM MAKAROV	{"email": "vadim-makarov_1970@postgrespro.ru", "phone": "+70814844032"}
0005434505182	71E49A	5668 885001	SVETLANA PETROVA	{"phone": "+70648059524"}
0005434505183	868094	7770 611311	NIKOLAY FOMIN	{"email": "fomin_nikolay-20111965@postgrespro.ru", "phone": "+70118378397"}
0005434505184	D1B794	9585 895674	VLADIMIR KONOVALOV	{"email": "konovalov-v031975@postgrespro.ru", "phone": "+70999515570"}
0005434505185	BD95B6	0445 621855	DMITRIY GERASIMOV	{"phone": "+70847299520"}
0005434505186	BD95B6	3873 650356	LARISA SMIRNOVA	{"email": "l_smirnova.081972@postgrespro.ru", "phone": "+70677102904"}
0005434505187	6AB62F	6009 961540	ANNA EFIMOVA	{"email": "a-efimova.05071969@postgrespro.ru", "phone": "+70305219931"}
0005434505188	6AB62F	1145 933713	ARTEM OSIPOV	{"email": "artem.osipov1979@postgrespro.ru", "phone": "+70549169493"}
0005434505189	1854A4	1971 232766	VLADIMIR SMIRNOV	{"phone": "+70630583691"}
0005434505190	1854A4	5908 566651	ARINA LOGINOVA	{"phone": "+70644759248"}
0005434505191	7962C5	1011 433792	ZOYA SAVELEVA	{"phone": "+70292888152"}
0005434505192	7962C5	6405 747415	ELENA GERASIMOVA	{"email": "gerasimova_elena.1974@postgrespro.ru", "phone": "+70709375047"}
0005434505193	7962C5	6026 991307	IRINA DMITRIEVA	{"phone": "+70771782744"}
0005434505194	92AD85	8275 135725	DANIL VOLKOV	{"email": "volkov_d031975@postgrespro.ru", "phone": "+70828881151"}
0005434505195	92AD85	2635 241631	ALEKSEY NIKITIN	{"email": "anikitin101984@postgrespro.ru", "phone": "+70778818366"}
0005434505196	045DC1	5979 582231	NIKOLAY MOROZOV	{"phone": "+70754884714"}
0005434505197	045DC1	4232 889718	ANNA VASILEVA	{"phone": "+70015181476"}
0005434505198	A33E6A	4628 542478	VLADIMIR ANDREEV	{"phone": "+70744054061"}
0005434505199	F4B419	7240 115054	NINA LUKYANOVA	{"email": "n_lukyanova-05121970@postgrespro.ru", "phone": "+70490665211"}
0005434505200	F3C1A3	7004 990984	ANNA KULIKOVA	{"email": "kulikova-a.05041958@postgrespro.ru", "phone": "+70086199085"}
0005434505201	C29303	1955 535003	VADIM ZHURAVLEV	{"email": "zhuravlev_vadim1983@postgrespro.ru", "phone": "+70816162698"}
0005434505202	16029B	7091 028944	NIKITA BARANOV	{"phone": "+70322920717"}
0005434505203	154BC3	0299 973818	OLGA KISELEVA	{"phone": "+70309857511"}
0005434505204	B1EDBC	0599 480006	NINA NIKOLAEVA	{"phone": "+70927055843"}
0005434505205	65B9E4	7620 267273	ALEKSEY ANDREEV	{"phone": "+70984220195"}
0005434505206	07394B	5683 464907	MARIYA SOROKINA	{"phone": "+70356292660"}
0005434505207	07394B	3566 012488	IRINA SERGEEVA	{"email": "sergeeva_irina111986@postgrespro.ru", "phone": "+70955990808"}
0005434505208	D283E0	8080 671534	VASILIY KISELEV	{"phone": "+70076441802"}
0005434505209	AA72D3	3208 865032	NIKOLAY MIRONOV	{"email": "n-mironov.121979@postgrespro.ru", "phone": "+70263062726"}
0005434505210	AA72D3	3654 832279	ANDREY BARANOV	{"email": "andrey.baranov-1971@postgrespro.ru", "phone": "+70623490596"}
0005434505211	F9C4DE	4318 992528	ELENA FILATOVA	{"email": "filatova.e.011977@postgrespro.ru", "phone": "+70671964484"}
0005434505212	37671E	0780 174267	EVGENIY KARPOV	{"phone": "+70539803767"}
0005434505213	1C08C3	1133 219346	OLEG SMIRNOV	{"email": "osmirnov.111974@postgrespro.ru", "phone": "+70225424059"}
0005434505214	60B430	2122 225637	LILIYA SERGEEVA	{"phone": "+70158226692"}
0005434505215	5E36B6	9451 337981	VASILIY TARASOV	{"email": "tarasovv.071969@postgrespro.ru", "phone": "+70786860433"}
0005434505216	5E36B6	2101 624304	NATALYA SMIRNOVA	{"phone": "+70178307021"}
0005434505217	5E36B6	5435 700071	ALINA ISAEVA	{"email": "isaeva-alina-21091969@postgrespro.ru", "phone": "+70316618539"}
0005434505218	74D7FE	8020 717627	ALINA KOMAROVA	{"email": "akomarova.1981@postgrespro.ru", "phone": "+70964609832"}
0005434505219	74D7FE	1516 692658	GLEB SOKOLOV	{"email": "sokolov.gleb20101967@postgrespro.ru", "phone": "+70143548751"}
0005434505220	28C810	3189 836013	TATYANA PAVLOVA	{"email": "tatyana.pavlova-091972@postgrespro.ru", "phone": "+70039442306"}
0005434505221	57E99A	6410 053605	ALEKSANDRA VLASOVA	{"email": "aleksandra.vlasova.1967@postgrespro.ru", "phone": "+70904109341"}
0005434505222	57E99A	2966 932352	VITALIY KAZAKOV	{"email": "vkazakov-1978@postgrespro.ru", "phone": "+70612632760"}
0005434505223	CAE031	9888 710046	GALINA KUZNECOVA	{"email": "gkuznecova_091974@postgrespro.ru", "phone": "+70602568956"}
0005434505224	4A6042	9688 537282	ALBINA NIKIFOROVA	{"phone": "+70433664191"}
0005434505225	4A6042	7598 002355	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr-051976@postgrespro.ru", "phone": "+70802684674"}
0005434505226	8AECDE	2554 794702	IVAN MEDVEDEV	{"email": "medvedev-ivan.011988@postgrespro.ru", "phone": "+70922699548"}
0005434505227	BFA27B	0399 434116	ANNA SOKOLOVA	{"email": "anna-sokolova-27041974@postgrespro.ru", "phone": "+70445862668"}
0005434505228	167EAF	7436 195126	EVGENIY KUZNECOV	{"email": "e.kuznecov111979@postgrespro.ru", "phone": "+70987796437"}
0005434505229	4698E9	2796 173364	SEMEN KUZMIN	{"email": "kuzmin.semen13021968@postgrespro.ru", "phone": "+70135051876"}
0005434505230	4698E9	9826 066877	VLADIMIR KOZLOV	{"email": "v_kozlov22071977@postgrespro.ru", "phone": "+70305246413"}
0005434505231	4698E9	5320 017024	NIKOLAY KAZAKOV	{"email": "kazakov_nikolay_26111980@postgrespro.ru", "phone": "+70079538922"}
0005434505232	3ABF4D	3462 717820	NINA MEDVEDEVA	{"phone": "+70844598512"}
0005434505233	C77F99	0779 145794	ZAKHAR KUDRYASHOV	{"email": "kudryashov.z-21081977@postgrespro.ru", "phone": "+70193874635"}
0005434505234	301619	4614 967185	TATYANA POTAPOVA	{"email": "potapova.t-1975@postgrespro.ru", "phone": "+70244143614"}
0005434505235	C6446E	9792 325121	VALENTINA MAKAROVA	{"email": "v_makarova.1971@postgrespro.ru", "phone": "+70356684270"}
0005434505236	C0BE91	5119 012158	ANNA AKIMOVA	{"phone": "+70557584455"}
0005434505237	C7B086	4842 886696	DARYA MOROZOVA	{"email": "morozova_d1973@postgrespro.ru", "phone": "+70004649126"}
0005434505238	C7B086	2927 650682	EKATERINA KOZLOVA	{"phone": "+70559227099"}
0005434505239	97EEC5	5776 072204	NATALYA BARANOVA	{"phone": "+70870064214"}
0005434505240	C74A23	8273 696368	VLADIMIR IVANOV	{"email": "ivanov.v.1984@postgrespro.ru", "phone": "+70549497615"}
0005434505241	6E2EE3	3477 952760	MAKSIM FOMIN	{"email": "maksimfomin-1963@postgrespro.ru", "phone": "+70463996104"}
0005434505242	E43436	1889 764289	ANTON VOROBEV	{"phone": "+70937101732"}
0005434505243	6B1ED2	8514 055351	RINAT KULIKOV	{"email": "kulikov-rinat.27061971@postgrespro.ru", "phone": "+70061130656"}
0005434505244	5B2E2D	5072 180446	ANTONINA ARKHIPOVA	{"phone": "+70206608945"}
0005434505245	D2954B	2174 931255	ALEKSANDR PETROV	{"email": "aleksandr.petrov-06111981@postgrespro.ru", "phone": "+70947205889"}
0005434505246	83B269	7429 350013	GENNADIY PAVLOV	{"email": "gennadiy_pavlov1970@postgrespro.ru", "phone": "+70042511548"}
0005434505247	3909EE	7177 951902	YURIY IVANOV	{"phone": "+70734316149"}
0005434505248	EA6328	2950 974503	YULIYA VASILEVA	{"email": "vasilevay091978@postgrespro.ru", "phone": "+70407391108"}
0005434505249	926E8E	2479 686672	YAKOV SIDOROV	{"phone": "+70250272190"}
0005434505250	1834B6	8090 366397	SVETLANA TIKHONOVA	{"phone": "+70625587043"}
0005434505251	8F34C2	1984 453611	VLADIMIR ZAYCEV	{"email": "zaycev.vladimir-101968@postgrespro.ru", "phone": "+70801745712"}
0005434505252	DFC839	4083 166928	VITALIY VOLKOV	{"email": "vvolkov_13081974@postgrespro.ru", "phone": "+70764647953"}
0005434505253	DFC839	5052 452643	VLADIMIR SOROKIN	{"email": "vladimir-sorokin-25041976@postgrespro.ru", "phone": "+70038380352"}
0005434505254	0C768B	9420 164710	RUSLAN KOZLOV	{"email": "r-kozlov.1971@postgrespro.ru", "phone": "+70075256034"}
0005434505255	79C354	8169 705740	NIKOLAY IVANOV	{"email": "ivanov-nikolay-1964@postgrespro.ru", "phone": "+70206978452"}
0005434505256	205607	3267 013165	ANZHELIKA SEMENOVA	{"email": "anzhelika_semenova-24121967@postgrespro.ru", "phone": "+70071192154"}
0005434505257	205607	5877 645348	ASKHAT PETROV	{"phone": "+70822098715"}
0005434505258	B36D33	0337 475693	VLADIMIR TIKHONOV	{"email": "tikhonov_vladimir_051968@postgrespro.ru", "phone": "+70172320482"}
0005434505259	39606F	3368 949117	MARIYA POTAPOVA	{"email": "potapova-m.1973@postgrespro.ru", "phone": "+70098968148"}
0005434505260	39606F	5781 867505	ELENA SAVELEVA	{"email": "savelevaelena_1973@postgrespro.ru", "phone": "+70831083873"}
0005434505261	75748E	4220 296232	ROMAN ZAYCEV	{"phone": "+70952816874"}
0005434505262	75748E	8903 915076	NADEZHDA FOMINA	{"email": "fomina_n.051968@postgrespro.ru", "phone": "+70434759912"}
0005434505263	1D3F43	8622 028263	LARISA POPOVA	{"email": "l-popova_031966@postgrespro.ru", "phone": "+70189189596"}
0005434505264	1D3F43	0581 034707	DMITRIY ROMANOV	{"phone": "+70140529088"}
0005434505265	F3C7B7	7567 651927	ALEKSANDR BARANOV	{"email": "baranova-1964@postgrespro.ru", "phone": "+70330731106"}
0005434505266	1E1E41	8797 941495	ALEKSEY NIKOLAEV	{"phone": "+70133172353"}
0005434505267	1E1E41	3916 676709	VIKTOR BONDARENKO	{"phone": "+70959828824"}
0005434505268	2D868E	4966 553258	LARISA STEPANOVA	{"email": "larisa_stepanova.111967@postgrespro.ru", "phone": "+70339166836"}
0005434505269	2D868E	3725 826286	RAMIS GORBUNOV	{"email": "r-gorbunov26091972@postgrespro.ru", "phone": "+70834773593"}
0005434505270	D5E89B	5128 631196	TATYANA SOROKINA	{"phone": "+70133041455"}
0005434505271	59A59C	0396 996807	EVGENIY GERASIMOV	{"email": "egerasimov_08091969@postgrespro.ru", "phone": "+70518333561"}
0005434505272	59A59C	7223 188743	ALEKSANDR MIKHAYLOV	{"phone": "+70885421928"}
0005434505273	26E1FF	0878 901583	LYUBOV VOLKOVA	{"phone": "+70395460267"}
0005434505274	1EC2D0	4120 831081	OLEG ANTONOV	{"email": "oleg-antonov_11101978@postgrespro.ru", "phone": "+70131987805"}
0005434505275	1EC2D0	4195 987675	VASILIY DAVYDOV	{"phone": "+70956295956"}
0005434505276	E45D87	9112 125742	GALINA ZAYCEVA	{"email": "zaycevag121973@postgrespro.ru", "phone": "+70705389193"}
0005434505277	843237	7567 782462	TAMARA DAVYDOVA	{"phone": "+70401813404"}
0005434505278	843237	6848 799459	LYUBOV KULIKOVA	{"email": "lyubov_kulikova_1971@postgrespro.ru", "phone": "+70518805882"}
0005434505279	843237	1726 319544	VIKTORIYA RODIONOVA	{"email": "rodionova_viktoriya_071964@postgrespro.ru", "phone": "+70091222773"}
0005434505280	5591AD	0375 797446	SERGEY KOROLEV	{"phone": "+70113612139"}
0005434505281	5591AD	5200 472029	ANDREY GRIGOREV	{"email": "grigoreva091970@postgrespro.ru", "phone": "+70302665531"}
0005434505282	21929C	7982 839469	ANDREY KUDRYASHOV	{"email": "a_kudryashov04011976@postgrespro.ru", "phone": "+70122974759"}
0005434505283	D4F31B	1091 825226	PELAGEYA FEDOROVA	{"phone": "+70355657159"}
0005434505284	FCF8BA	9899 863253	LYUDMILA KAZAKOVA	{"email": "kazakova_lyudmila.1965@postgrespro.ru", "phone": "+70861784953"}
0005434505285	FCF8BA	9448 219678	SERGEY NIKITIN	{"email": "s-nikitin_1983@postgrespro.ru", "phone": "+70136562164"}
0005434505286	1E6A37	1092 221322	SERGEY KUZNECOV	{"email": "kuznecovs1983@postgrespro.ru", "phone": "+70237303283"}
0005434505287	FC0ABB	1570 436654	YURIY SOROKIN	{"phone": "+70496137263"}
0005434505288	3D6433	0774 622449	KLAVDIYA KUZMINA	{"phone": "+70807255723"}
0005434505289	86661C	0900 526104	ELENA BELOVA	{"phone": "+70581733808"}
0005434505290	8A0698	2618 356261	KONSTANTIN OSIPOV	{"phone": "+70339730832"}
0005434505291	EBF32A	1517 660696	OLESYA LUKYANOVA	{"phone": "+70807083943"}
0005434505292	D6EF78	6958 881778	SERGEY ISAEV	{"phone": "+70632549978"}
0005434505293	BA3CA6	9349 915933	NATALYA DENISOVA	{"phone": "+70841881831"}
0005434505294	914998	4804 575989	VALENTINA LEBEDEVA	{"email": "lebedeva_valentina.30031978@postgrespro.ru", "phone": "+70847904968"}
0005434505295	55A7AE	9746 646135	ALEKSEY KUZMIN	{"phone": "+70155680579"}
0005434505296	7AB0EE	4713 116841	MIKHAIL ANTONOV	{"email": "mikhail_antonov1964@postgrespro.ru", "phone": "+70935051446"}
0005434505297	7AB0EE	4247 166942	IRINA ALEKSEEVA	{"phone": "+70176984630"}
0005434505298	3E498E	4616 940565	LEONID IVANOV	{"phone": "+70376104846"}
0005434505299	9E28E4	1906 484734	SERGEY FEDOTOV	{"email": "fedotov.sergey.041981@postgrespro.ru", "phone": "+70958873128"}
0005434505300	9E28E4	8804 535866	NINA KOZLOVA	{"email": "nkozlova_15101979@postgrespro.ru", "phone": "+70574725631"}
0005434505301	52A5C0	8510 434059	IRINA KUZNECOVA	{"phone": "+70246134522"}
0005434505302	52A5C0	9973 346080	ELENA GAVRILOVA	{"email": "e-gavrilova_24071968@postgrespro.ru", "phone": "+70099198425"}
0005434505303	F1E962	8468 536493	EKATERINA KUZMINA	{"email": "e.kuzmina_101974@postgrespro.ru", "phone": "+70321698787"}
0005434505304	F1E962	9920 601259	LYUDMILA OVCHINNIKOVA	{"phone": "+70606501867"}
0005434505305	F1E962	4685 935874	LYUBOV IVANOVA	{"email": "ivanova_lyubov-01081965@postgrespro.ru", "phone": "+70218143650"}
0005434505306	B23E13	0129 521774	IRINA FILIPPOVA	{"email": "filippovai.1975@postgrespro.ru", "phone": "+70449484288"}
0005434505307	B23E13	5390 557499	ANDREY NIKOLAEV	{"phone": "+70882228346"}
0005434505308	12F1D3	6226 078751	ANATOLIY SMIRNOV	{"email": "smirnov-anatoliy29081968@postgrespro.ru", "phone": "+70068365655"}
0005434505309	8178D2	2944 660885	ALEKSANDR MELNIKOV	{"email": "melnikov.a_18091972@postgrespro.ru", "phone": "+70900376750"}
0005434505310	8178D2	9455 410136	POLINA ZOTOVA	{"email": "zotovapolina-1964@postgrespro.ru", "phone": "+70782112590"}
0005434505311	384574	9067 554182	ANATOLIY MAKAROV	{"email": "makarov.anatoliy_081974@postgrespro.ru", "phone": "+70253161502"}
0005434505312	384574	2682 971131	VLADIMIR SCHERBAKOV	{"phone": "+70025291199"}
0005434505313	19492D	3982 223962	ANDREY NAZAROV	{"phone": "+70430231993"}
0005434505314	19492D	6428 246623	VLADISLAV SOLOVEV	{"phone": "+70727028878"}
0005434505315	19492D	8715 025932	KONSTANTIN KULIKOV	{"email": "kulikovkonstantin-1986@postgrespro.ru", "phone": "+70750849691"}
0005434505316	41E79B	3826 019444	VALENTINA SERGEEVA	{"phone": "+70317931419"}
0005434505317	CCD82E	1294 807515	EKATERINA FADEEVA	{"phone": "+70021208364"}
0005434505318	0E0972	0613 008450	LIDIYA ZAYCEVA	{"phone": "+70967759261"}
0005434505319	43AED4	8283 217695	VERONIKA NIKIFOROVA	{"email": "nikiforova-v_011968@postgrespro.ru", "phone": "+70833955515"}
0005434505320	0DA2B7	9315 090118	VALENTINA KISELEVA	{"phone": "+70731676158"}
0005434505321	314579	3394 693665	MARIYA MASLOVA	{"email": "mariya_maslova-02051980@postgrespro.ru", "phone": "+70515136987"}
0005434505322	314579	5707 416641	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr-20051964@postgrespro.ru", "phone": "+70945097783"}
0005434505323	A79685	2729 629378	ANGELINA MALYSHEVA	{"phone": "+70880630324"}
0005434505324	A79685	5839 125041	VALENTINA KOLESNIKOVA	{"email": "v-kolesnikova_1965@postgrespro.ru", "phone": "+70893161550"}
0005434505325	808671	3320 568336	VIKTOR FROLOV	{"phone": "+70219768658"}
0005434505326	3A85EA	3034 961589	IRINA EFIMOVA	{"email": "efimovairina_071963@postgrespro.ru", "phone": "+70584151628"}
0005434509014	10C2CB	1669 674292	ALEKSANDR NAUMOV	{"email": "aleksandr_naumov-111961@postgrespro.ru", "phone": "+70181244275"}
0005434509015	8725A3	5017 921716	STANISLAV GAVRILOV	{"email": "stanislav.gavrilov_1969@postgrespro.ru", "phone": "+70324342085"}
0005434509016	8725A3	3372 639580	YULIYA LEBEDEVA	{"phone": "+70475549012"}
0005434509017	BEBD78	8711 829113	YULIYA OSIPOVA	{"phone": "+70866551523"}
0005434509018	BEBD78	0311 577729	GALINA OVCHINNIKOVA	{"phone": "+70525191550"}
0005434509019	B76191	1308 596524	IRINA CHERNOVA	{"phone": "+70251424988"}
0005434509020	0134D5	3953 167331	YURIY ANDREEV	{"phone": "+70293575975"}
0005434509021	0134D5	4332 449182	MARINA POPOVA	{"email": "marina-popova.031970@postgrespro.ru", "phone": "+70418551340"}
0005434509022	702C6C	4154 074394	MARINA ARKHIPOVA	{"phone": "+70257012906"}
0005434509023	07E3AC	8277 075998	EVGENIY ALEKSEEV	{"phone": "+70736950136"}
0005434509024	78AA01	5406 925678	IGOR FILIPPOV	{"phone": "+70599442266"}
0005434509025	96AF04	6390 089975	ILYA CHERNOV	{"email": "ichernov.031979@postgrespro.ru", "phone": "+70713872866"}
0005434509026	96AF04	7823 037844	VALERIY FOMIN	{"phone": "+70097069613"}
0005434509027	386344	8854 804888	ZOYA ROMANOVA	{"phone": "+70327473974"}
0005434509028	386344	5189 640217	NIKITA FROLOV	{"email": "nikita.frolov.11071984@postgrespro.ru", "phone": "+70188772497"}
0005434509029	901719	5335 418135	SERGEY TIKHONOV	{"email": "sergey_tikhonov111975@postgrespro.ru", "phone": "+70165355566"}
0005434509030	901719	4649 141369	IVAN MIKHAYLOV	{"email": "mikhaylovi-1970@postgrespro.ru", "phone": "+70625936044"}
0005434509031	02FC66	3582 954823	RAISA EGOROVA	{"phone": "+70423628438"}
0005434509032	02FC66	6425 251621	EVDOKIYA ZHURAVLEVA	{"email": "zhuravlevaevdokiya-09101976@postgrespro.ru", "phone": "+70660536570"}
0005434509033	DCC5FA	0211 572255	ANTON ZAKHAROV	{"email": "zakharovanton031982@postgrespro.ru", "phone": "+70742416422"}
0005434509034	693417	8044 184442	VERONIKA SMIRNOVA	{"phone": "+70547422448"}
0005434509035	E349A3	4320 269094	VYACHESLAV PETROV	{"phone": "+70516825237"}
0005434509036	E349A3	5214 366292	TAMARA SOROKINA	{"phone": "+70746599301"}
0005434509037	127682	9812 065669	VLADIMIR VOROBEV	{"email": "vvorobev03091971@postgrespro.ru", "phone": "+70262981893"}
0005434509038	CF0654	4880 456260	VITALIY MELNIKOV	{"phone": "+70374808682"}
0005434509160	845D48	2018 497875	GALINA ANTONOVA	{"phone": "+70961970708"}
0005434509039	CF0654	7318 752080	MARIYA CHERNOVA	{"email": "chernova-m-101972@postgrespro.ru", "phone": "+70240485058"}
0005434509040	4500FA	7706 822607	VIKTOR GORBUNOV	{"phone": "+70369897316"}
0005434509041	4500FA	3303 157070	NINA SOKOLOVA	{"phone": "+70404985146"}
0005434509042	E94EB8	8744 480992	DARYA RODIONOVA	{"email": "rodionova-darya041979@postgrespro.ru", "phone": "+70991805528"}
0005434509043	DA2E06	5558 172379	IRINA NAZAROVA	{"email": "inazarova19031987@postgrespro.ru", "phone": "+70005094593"}
0005434509044	DA2E06	6407 013167	ALENA GRISHINA	{"email": "grishina_a-14051960@postgrespro.ru", "phone": "+70210286563"}
0005434509045	EEC69A	1212 637635	TATYANA KUZNECOVA	{"phone": "+70675016688"}
0005434509046	EEC69A	0246 965898	NADEZHDA PAVLOVA	{"phone": "+70923378383"}
0005434509047	CC2064	8185 604720	SERGEY SAVELEV	{"phone": "+70892298971"}
0005434509048	CC2064	4697 917097	VIKTOR IVANOV	{"email": "viktor.ivanov26021973@postgrespro.ru", "phone": "+70791743259"}
0005434509049	428F73	3447 399214	NATALYA GRISHINA	{"phone": "+70879737123"}
0005434509050	5E86B5	9191 783177	LYUBOV PETROVA	{"email": "lyubov-petrova.051971@postgrespro.ru", "phone": "+70936896425"}
0005434509051	5E86B5	9424 547076	VERONIKA SMIRNOVA	{"phone": "+70168442088"}
0005434509052	8E968C	1170 434997	MIKHAIL ZAKHAROV	{"email": "zakharovmikhail_1970@postgrespro.ru", "phone": "+70409899549"}
0005434509053	834B22	8394 409296	LARISA ANDREEVA	{"phone": "+70663413662"}
0005434509054	5DE0B9	8996 299445	LIDIYA FILIPPOVA	{"phone": "+70479242784"}
0005434509055	5DE0B9	3635 290820	ARTEM YAKOVLEV	{"phone": "+70132835447"}
0005434509056	4B91BA	5950 698135	LYUBOV SCHERBAKOVA	{"phone": "+70850211694"}
0005434509057	4B91BA	6232 135199	KONSTANTIN MOROZOV	{"email": "k.morozov.14111977@postgrespro.ru", "phone": "+70236205687"}
0005434509058	906549	0187 696658	ELIZAVETA GRISHINA	{"phone": "+70674242649"}
0005434509059	9734C5	3049 139362	IVAN GUSEV	{"email": "ivan.gusev.12011966@postgrespro.ru", "phone": "+70803745127"}
0005434509060	852B5E	3616 723291	ALEKSANDRA FOMINA	{"email": "fominaaleksandra.29031973@postgrespro.ru", "phone": "+70026902960"}
0005434509061	257DE2	7703 489676	ALEKSANDR DMITRIEV	{"email": "dmitriev.aleksandr.15121974@postgrespro.ru", "phone": "+70187739488"}
0005434509062	671914	1487 807898	OLGA MALYSHEVA	{"email": "malysheva-olga-061965@postgrespro.ru", "phone": "+70955744168"}
0005434509063	671914	3309 207928	VITALIY MELNIKOV	{"phone": "+70141469515"}
0005434509064	9DF249	0916 534792	GERMAN GRIGOREV	{"email": "grigorev.german_1964@postgrespro.ru", "phone": "+70462647346"}
0005434509065	9DF249	2483 474235	ALBINA TITOVA	{"email": "albinatitova-1978@postgrespro.ru", "phone": "+70007272269"}
0005434509066	9DF249	4801 320101	LARISA LEBEDEVA	{"email": "l.lebedeva12021965@postgrespro.ru", "phone": "+70226934427"}
0005434509067	9DF249	1276 870849	VITALIY DMITRIEV	{"phone": "+70622387659"}
0005434509068	EF564E	7849 028454	YURIY NOVIKOV	{"email": "novikov.y.1984@postgrespro.ru", "phone": "+70814688937"}
0005434509069	2130B0	7712 674255	STEPAN ALEKSEEV	{"email": "stepan.alekseev07061974@postgrespro.ru", "phone": "+70276639595"}
0005434509070	8B1DD9	8930 874736	MIKHAIL MAKAROV	{"email": "makarovm.061982@postgrespro.ru", "phone": "+70172282886"}
0005434509071	9FAEC6	5043 902409	ANDREY ZAKHAROV	{"phone": "+70613425029"}
0005434509072	AE5D31	5347 025123	MARGARITA DAVYDOVA	{"phone": "+70319969328"}
0005434509073	AE5D31	9694 788581	PAVEL ALEKSANDROV	{"email": "p-aleksandrov_22011969@postgrespro.ru", "phone": "+70376939866"}
0005434509074	709360	3953 162010	ILYA FILIPPOV	{"email": "filippov_ilya.081973@postgrespro.ru", "phone": "+70085035790"}
0005434509075	E0ECBA	7987 752982	ALEKSEY RODIONOV	{"email": "rodionov_aleksey081977@postgrespro.ru", "phone": "+70780943440"}
0005434509076	FCD007	0775 975667	NIKITA POPOV	{"email": "popov_nikita_29091964@postgrespro.ru", "phone": "+70365996665"}
0005434509077	81C39F	3026 332898	NATALYA SIDOROVA	{"phone": "+70446072834"}
0005434509078	81C39F	9598 201196	MAKSIM VLASOV	{"email": "vlasov_m_1970@postgrespro.ru", "phone": "+70342249995"}
0005434509079	2BBA28	3349 117288	ANASTASIYA CHERNOVA	{"phone": "+70761021871"}
0005434509080	00B407	4645 067225	VITALIY ZHUKOV	{"phone": "+70939118211"}
0005434509081	84A1DB	8553 558153	VALERIYA PETROVA	{"email": "v-petrova.1981@postgrespro.ru", "phone": "+70011478788"}
0005434509082	87CDF2	3402 029654	YAROSLAV MEDVEDEV	{"email": "medvedev.y03081980@postgrespro.ru", "phone": "+70125843429"}
0005434509083	AF8090	8692 818038	NADEZHDA FROLOVA	{"phone": "+70964556675"}
0005434509084	AF8090	3837 704288	ANDREY BONDARENKO	{"email": "abondarenko.031981@postgrespro.ru", "phone": "+70147333651"}
0005434509085	FD49AF	8407 922789	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr08111958@postgrespro.ru", "phone": "+70869071925"}
0005434509086	A2E144	2667 385148	VIKTOR ZAYCEV	{"email": "zaycevviktor.1970@postgrespro.ru", "phone": "+70006525212"}
0005434509087	605000	4828 202702	ELENA CHERNOVA	{"email": "e.chernova-031975@postgrespro.ru", "phone": "+70367459382"}
0005434509088	63D327	6026 952024	POLINA KUZNECOVA	{"phone": "+70681451022"}
0005434509089	2DAAF7	1186 374251	ALENA DMITRIEVA	{"email": "alenadmitrieva_16021968@postgrespro.ru", "phone": "+70252040383"}
0005434509090	ADD947	0697 051820	STEPAN FROLOV	{"email": "frolov_s.071971@postgrespro.ru", "phone": "+70893141051"}
0005434509091	6072CE	9359 295311	ANDREY ANDREEV	{"email": "andreev_andrey-041973@postgrespro.ru", "phone": "+70178355951"}
0005434509092	6072CE	8905 277600	VALENTINA VASILEVA	{"email": "vasileva_valentina_07081981@postgrespro.ru", "phone": "+70541870841"}
0005434509093	69F260	7861 135911	OLEG SEMENOV	{"phone": "+70145536260"}
0005434509094	5B2505	2743 462130	FATIMA OSIPOVA	{"phone": "+70974169986"}
0005434509095	2E839A	7722 898401	GALINA POPOVA	{"phone": "+70554704475"}
0005434509096	6F2842	3364 664097	ROZA KUZNECOVA	{"phone": "+70663571482"}
0005434509097	148650	5608 285734	NATALYA KARPOVA	{"email": "n-karpova.1969@postgrespro.ru", "phone": "+70257746286"}
0005434509098	8E9045	6356 201080	ALEKSANDR FOMIN	{"email": "fomin.aleksandr091974@postgrespro.ru", "phone": "+70189138281"}
0005434509099	30D650	6312 136952	ANATOLIY EGOROV	{"phone": "+70830809412"}
0005434509100	30D650	2692 916004	VARVARA KOROLEVA	{"email": "koroleva-v1969@postgrespro.ru", "phone": "+70282394662"}
0005434509101	B15786	4910 446663	MIKHAIL IVANOV	{"phone": "+70662759788"}
0005434509102	8CCE64	7787 661986	ALEKSANDR ANTONOV	{"phone": "+70560284275"}
0005434509103	646504	2036 788878	VLADIMIR STEPANOV	{"email": "v.stepanov_20071967@postgrespro.ru", "phone": "+70360701416"}
0005434509104	646504	1762 213576	DMITRIY SOLOVEV	{"phone": "+70277150307"}
0005434509105	E4280A	2225 778601	GENNADIY DENISOV	{"phone": "+70874242174"}
0005434509106	2F7570	0279 323867	NATALYA MOROZOVA	{"email": "morozovan-011977@postgrespro.ru", "phone": "+70643510326"}
0005434509107	2F7570	4773 671605	LIDIYA SCHERBAKOVA	{"phone": "+70231157355"}
0005434509108	0FC16B	1400 705659	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-06081985@postgrespro.ru", "phone": "+70356292147"}
0005434509109	9FDF8A	5183 794965	MAKSIM KISELEV	{"phone": "+70535288464"}
0005434509110	9FDF8A	4222 898880	GALINA BOGDANOVA	{"phone": "+70333982107"}
0005434509111	8457F2	8603 305314	SEMEN IVANOV	{"email": "ivanov.semen.01071972@postgrespro.ru", "phone": "+70575237751"}
0005434509112	8457F2	6868 812567	ANDREY ANTONOV	{"phone": "+70372151916"}
0005434509113	42AF43	2974 448935	TAMARA LOGINOVA	{"phone": "+70522026683"}
0005434509114	1DCB18	0460 551619	RUSLAN ILIN	{"email": "r.ilin-1970@postgrespro.ru", "phone": "+70693375053"}
0005434509115	1DCB18	0638 493038	KRISTINA POPOVA	{"phone": "+70250006038"}
0005434509116	10DA68	4970 534960	ANASTASIYA OSIPOVA	{"phone": "+70746619669"}
0005434509117	2C32DD	3992 573949	ELENA KOZLOVA	{"phone": "+70539981455"}
0005434509118	303DB2	1674 818821	TIGRAN ISAEV	{"email": "isaev-t.23061982@postgrespro.ru", "phone": "+70752584901"}
0005434509119	303DB2	4541 889448	VLADIMIR AFANASEV	{"phone": "+70775709605"}
0005434509120	2F4478	0258 009044	GALINA IVANOVA	{"email": "ivanova_galina.101967@postgrespro.ru", "phone": "+70172331515"}
0005434509121	AD4706	4342 835343	RAFIK NIKOLAEV	{"phone": "+70842698873"}
0005434509122	11FC42	9864 921472	KIRA SAVELEVA	{"email": "saveleva.kira-121975@postgrespro.ru", "phone": "+70924714992"}
0005434509123	EFD343	2280 059521	NAZAR GERASIMOV	{"phone": "+70315097083"}
0005434509124	3BCF57	2581 292474	ANNA NAUMOVA	{"phone": "+70790957043"}
0005434509125	3BCF57	0838 893640	ANDREY VLASOV	{"phone": "+70248124840"}
0005434509126	8A2C9B	8209 659381	VALENTINA MATVEEVA	{"phone": "+70430350948"}
0005434509127	F30584	4457 888899	VLADIMIR MEDVEDEV	{"email": "medvedev_v.1978@postgrespro.ru", "phone": "+70769954956"}
0005434509128	F30584	8290 241133	PAVEL RODIONOV	{"email": "p_rodionov_1967@postgrespro.ru", "phone": "+70925048937"}
0005434509129	AC5262	0747 881848	VALENTINA NESTEROVA	{"phone": "+70271917227"}
0005434509130	F05CDC	3620 636468	PAVEL BARANOV	{"email": "baranov.pavel1972@postgrespro.ru", "phone": "+70539039910"}
0005434509131	F05CDC	9015 833920	EGOR MOROZOV	{"phone": "+70753999689"}
0005434509132	F05CDC	5827 804244	ANASTASIYA NIKITINA	{"email": "nikitina-anastasiya-1982@postgrespro.ru", "phone": "+70449354782"}
0005434509133	52D8B7	9638 598008	NIKOLAY IVANOV	{"phone": "+70024910365"}
0005434509134	52D8B7	5847 651243	MARIYA MARTYNOVA	{"phone": "+70293292683"}
0005434509135	880944	5688 278292	SERGEY POPOV	{"email": "sergeypopov1982@postgrespro.ru", "phone": "+70242628084"}
0005434509136	56A367	5959 087186	ANATOLIY MARTYNOV	{"email": "amartynov-021973@postgrespro.ru", "phone": "+70894139803"}
0005434509137	1F29BF	8466 798864	MAKSIM SERGEEV	{"phone": "+70049181436"}
0005434509138	1F29BF	9125 357460	VLADIMIR SERGEEV	{"phone": "+70815848287"}
0005434509139	D87DFC	1130 948075	MARGARITA FILIPPOVA	{"email": "filippovamargarita.1977@postgrespro.ru", "phone": "+70014666408"}
0005434509140	EB35B6	1404 320462	KONSTANTIN TIKHONOV	{"phone": "+70750244099"}
0005434509141	EB35B6	6956 794705	SVETLANA KOLESNIKOVA	{"email": "kolesnikovasvetlana_27121968@postgrespro.ru", "phone": "+70451148662"}
0005434509142	EB35B6	5682 831960	ELENA KUZMINA	{"phone": "+70250613237"}
0005434509143	1CEDCF	4946 306867	GEORGIY KOZLOV	{"phone": "+70142758764"}
0005434509144	7CEBBF	4158 087389	SERGEY MEDVEDEV	{"email": "sergey-medvedev_24111971@postgrespro.ru", "phone": "+70335230760"}
0005434509145	8FC263	5847 154333	DARYA TARASOVA	{"email": "d-tarasova_121968@postgrespro.ru", "phone": "+70371579738"}
0005434509146	8B18BE	5342 745934	VALENTINA ILINA	{"email": "ilinav_1969@postgrespro.ru", "phone": "+70611764235"}
0005434509147	645F4C	0104 192065	OLGA PAVLOVA	{"phone": "+70602184388"}
0005434509148	645F4C	7581 371801	ELENA MIKHAYLOVA	{"email": "mikhaylova_e051967@postgrespro.ru", "phone": "+70285220732"}
0005434509149	0D8DE8	3864 404784	ELENA KOZLOVA	{"phone": "+70304128745"}
0005434509150	0D8DE8	2568 871532	DARYA BARANOVA	{"phone": "+70845582618"}
0005434509151	81B4BD	5100 736180	NIKOLAY ZAYCEV	{"email": "n-zaycev.071975@postgrespro.ru", "phone": "+70278632630"}
0005434509152	2ACBA4	4512 523422	DMITRIY DENISOV	{"phone": "+70048586211"}
0005434509153	7A98B0	3965 133281	ALEKSANDR VOROBEV	{"phone": "+70138123054"}
0005434509154	7A98B0	6379 385125	NADEZHDA NAUMOVA	{"email": "naumova.n081971@postgrespro.ru", "phone": "+70936725163"}
0005434509155	7A98B0	7438 870935	MARINA KISELEVA	{"phone": "+70209804639"}
0005434509156	9F3929	4456 407997	LYUDMILA TARASOVA	{"email": "tarasova.lyudmila.071968@postgrespro.ru", "phone": "+70736999967"}
0005434509157	4E246D	9886 422070	TATYANA KOZLOVA	{"email": "kozlova.tatyana.1969@postgrespro.ru", "phone": "+70443696257"}
0005434509158	FC424B	9359 603534	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey.1975@postgrespro.ru", "phone": "+70261503924"}
0005434509159	C198B3	7499 281934	YURIY PETROV	{"phone": "+70965881832"}
0005434509161	E107A7	1648 126736	MARINA NESTEROVA	{"phone": "+70027638734"}
0005434509162	0DB2A2	2946 423612	SERGEY MOROZOV	{"phone": "+70677805302"}
0005434509163	19365F	6301 334075	SERGEY VLASOV	{"phone": "+70870632381"}
0005434509164	DD3AF6	5476 394384	ARTEM ANTONOV	{"phone": "+70514068426"}
0005434509165	215E46	2748 331568	EKATERINA PAVLOVA	{"email": "pavlova_e.25011979@postgrespro.ru", "phone": "+70267806395"}
0005434509166	817D1A	5978 784847	ALEKSEY SAVELEV	{"email": "savelev-aleksey08011961@postgrespro.ru", "phone": "+70037543739"}
0005434509167	1C44D8	1676 377990	ALEKSEY ZAKHAROV	{"phone": "+70619958725"}
0005434509168	115923	0565 366836	ANASTASIYA KISELEVA	{"email": "kiselevaanastasiya_20051968@postgrespro.ru", "phone": "+70160410361"}
0005434509169	231D60	8593 717847	MIKHAIL KUZMIN	{"phone": "+70334380320"}
0005434509170	EF9792	4464 593491	POLINA GUSEVA	{"email": "polina_guseva-1965@postgrespro.ru", "phone": "+70221844158"}
0005434509171	82386A	4196 714607	ALINA MELNIKOVA	{"phone": "+70988552870"}
0005434509172	82386A	7960 544552	ALEKSANDR SEMENOV	{"email": "semenovaleksandr-30071974@postgrespro.ru", "phone": "+70486935302"}
0005434509173	613765	6778 213213	LYUDMILA EGOROVA	{"email": "egorova.lyudmila1964@postgrespro.ru", "phone": "+70795431985"}
0005434509174	204DEC	6992 878381	SERGEY SCHERBAKOV	{"email": "scherbakov-s.011965@postgrespro.ru", "phone": "+70518471203"}
0005434509175	812BDB	7802 622854	TIMOFEY SERGEEV	{"email": "timofey.sergeev_111973@postgrespro.ru", "phone": "+70367245336"}
0005434509176	812BDB	0620 666365	MAKSIM KISELEV	{"phone": "+70968646850"}
0005434509177	BF5B59	5728 632002	ALEKSEY EGOROV	{"email": "egorova-1976@postgrespro.ru", "phone": "+70819516230"}
0005434509178	6F78FB	4422 657493	NATALYA OSIPOVA	{"phone": "+70790293017"}
0005434509179	6F78FB	7363 387055	TAGIR KOROLEV	{"email": "korolevtagir_1965@postgrespro.ru", "phone": "+70759623064"}
0005434509180	6F78FB	1740 090323	ALINA VOROBEVA	{"phone": "+70066089128"}
0005434509181	66FE97	9320 437828	ANNA NESTEROVA	{"phone": "+70476874221"}
0005434509182	C4534D	1880 917591	SVETLANA EFIMOVA	{"phone": "+70097071909"}
0005434509183	A1F9F9	3155 060083	ANNA KARPOVA	{"email": "a_karpova28051996@postgrespro.ru", "phone": "+70006826353"}
0005434509184	3AB1EA	2738 154824	OLGA VASILEVA	{"phone": "+70851742688"}
0005434509185	8868B8	3328 250884	EVGENIY ISAEV	{"phone": "+70856711843"}
0005434509186	8868B8	5397 122793	SERGEY KULIKOV	{"phone": "+70373709121"}
0005434509187	89E6F9	0754 919842	ALEKSEY POPOV	{"phone": "+70645696594"}
0005434509188	EE239A	0351 899089	EKATERINA OSIPOVA	{"phone": "+70636703521"}
0005434509189	F6E139	0422 078140	PAVEL SEMENOV	{"email": "pavel.semenov1967@postgrespro.ru", "phone": "+70036127404"}
0005434509190	F6E139	1708 933536	LARISA ERMAKOVA	{"email": "ermakova-l_1975@postgrespro.ru", "phone": "+70540440903"}
0005434509191	8BD3A2	4844 491881	NIKOLAY MAKAROV	{"phone": "+70446793302"}
0005434509192	0909A0	6266 799132	ALEKSANDR ROMANOV	{"phone": "+70798461559"}
0005434509193	6C4922	8506 854600	OLGA MEDVEDEVA	{"email": "olga.medvedeva_23101965@postgrespro.ru", "phone": "+70644720974"}
0005434509194	AA7729	2037 413118	DANIIL KUZNECOV	{"phone": "+70679709195"}
0005434509195	D78869	3480 899955	ANATOLIY KUDRYASHOV	{"email": "kudryashov-anatoliy_081977@postgrespro.ru", "phone": "+70780593269"}
0005434509196	AEC79C	2754 154963	DENIS PAVLOV	{"email": "denis_pavlov_1969@postgrespro.ru", "phone": "+70238766399"}
0005434509197	AEC79C	4267 767291	IRINA SEMENOVA	{"email": "semenova_i-1963@postgrespro.ru", "phone": "+70215623531"}
0005434509198	E135BF	4938 454679	ANDREY ALEKSEEV	{"email": "alekseev-andrey_15081978@postgrespro.ru", "phone": "+70023903702"}
0005434509199	7717AD	3696 487577	NADEZHDA STEPANOVA	{"email": "nadezhda.stepanova-06111972@postgrespro.ru", "phone": "+70318756145"}
0005434509200	7717AD	4834 071935	ANDREY KULIKOV	{"email": "andrey.kulikov1970@postgrespro.ru", "phone": "+70100964265"}
0005434509201	7717AD	7111 611047	VITALIY PAVLOV	{"phone": "+70481194728"}
0005434509202	0B70E0	9170 455818	IDA MAKSIMOVA	{"email": "maksimova_i.121972@postgrespro.ru", "phone": "+70634789091"}
0005434509203	85B122	8680 748701	PAVEL FROLOV	{"email": "p-frolov_041969@postgrespro.ru", "phone": "+70922049626"}
0005434509204	85B122	1777 925152	DANIIL KUZNECOV	{"email": "daniilkuznecov_27101969@postgrespro.ru", "phone": "+70361423184"}
0005434509205	2830FB	7588 969410	OKSANA KOMAROVA	{"phone": "+70271146457"}
0005434509206	7DDBF7	8754 061687	SERGEY VASILEV	{"phone": "+70154651746"}
0005434509207	6C2AFB	9090 835015	ALEKSANDR KAZAKOV	{"phone": "+70988921792"}
0005434509208	6C2AFB	8099 225642	NATALYA ROMANOVA	{"email": "natalyaromanova_1968@postgrespro.ru", "phone": "+70460542144"}
0005434509209	A0BB53	8316 787356	LIDIYA ZAKHAROVA	{"phone": "+70430299115"}
0005434509210	A0BB53	0230 227320	VERA SIDOROVA	{"phone": "+70179974668"}
0005434509211	D5FB31	6922 464479	ALEKSEY ALEKSEEV	{"email": "aalekseev.1978@postgrespro.ru", "phone": "+70519777999"}
0005434509212	78457A	2076 793612	STANISLAV ZHUKOV	{"email": "s.zhukov.1966@postgrespro.ru", "phone": "+70399483673"}
0005434509213	202DAA	7064 682794	NATALYA FROLOVA	{"email": "frolovanatalya.1982@postgrespro.ru", "phone": "+70992901287"}
0005434509214	B85F2F	6004 649691	OLGA SERGEEVA	{"phone": "+70442372594"}
0005434509215	059B03	6713 309924	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov021976@postgrespro.ru", "phone": "+70622194648"}
0005434509216	059B03	4557 246929	IVAN YAKOVLEV	{"phone": "+70390827815"}
0005434509217	F514DB	4296 898007	NIKOLAY SOROKIN	{"email": "sorokin_n1976@postgrespro.ru", "phone": "+70932816015"}
0005434509218	94FF5B	3611 200448	MARIYA BOGDANOVA	{"phone": "+70405739161"}
0005434509219	14ED0B	3401 689616	ANDREY KUZMIN	{"phone": "+70182830673"}
0005434509220	14ED0B	3916 358604	ANNA ANDREEVA	{"email": "andreeva.anna1976@postgrespro.ru", "phone": "+70687491620"}
0005434509280	444576	1885 551562	EVGENIYA ILINA	{"phone": "+70560071282"}
0005434509221	14ED0B	7816 665073	OLGA DENISOVA	{"email": "o_denisova.19121983@postgrespro.ru", "phone": "+70829286138"}
0005434509222	0CD7D4	7184 823379	VADIM IVANOV	{"phone": "+70438117888"}
0005434509223	376A3C	3219 728428	NIKOLAY DENISOV	{"email": "denisovn-091975@postgrespro.ru", "phone": "+70814831545"}
0005434509224	376A3C	7054 211769	ALEKSANDR ROMANOV	{"email": "a-romanov25011969@postgrespro.ru", "phone": "+70245889547"}
0005434509225	376A3C	3338 780076	IGOR MAKSIMOV	{"phone": "+70455100293"}
0005434509226	E9C449	3592 539100	ALEKSEY EGOROV	{"email": "a.egorov15051980@postgrespro.ru", "phone": "+70731052696"}
0005434509227	9AD882	6924 617916	ARTEM DAVYDOV	{"email": "artem.davydov-121975@postgrespro.ru", "phone": "+70322221193"}
0005434509228	9AD882	4638 007650	PAVEL KUZNECOV	{"email": "pavel-kuznecov-1975@postgrespro.ru", "phone": "+70976462347"}
0005434509229	9AD882	6317 816279	VITALIY OSIPOV	{"phone": "+70125550346"}
0005434509230	D207E8	6490 143990	NATALYA FILIPPOVA	{"phone": "+70272631881"}
0005434509231	5D41D5	7558 003680	ANZHELA KOVALEVA	{"phone": "+70772831062"}
0005434509232	8FDF7F	1727 725702	VLADIMIR FEDOROV	{"phone": "+70099006682"}
0005434509233	D6CF8D	0730 844455	YURIY PAVLOV	{"email": "pavlov-y.1977@postgrespro.ru", "phone": "+70197429493"}
0005434509234	D6CF8D	9897 945368	ALEKSANDR NIKITIN	{"phone": "+70269158888"}
0005434509235	36A9C9	8026 046025	VLADIMIR SEMENOV	{"phone": "+70311259069"}
0005434509236	690199	5041 233787	SVETLANA FADEEVA	{"email": "svetlanafadeeva.1966@postgrespro.ru", "phone": "+70223088432"}
0005434509237	690199	7072 709839	SERGEY KUZNECOV	{"email": "kuznecov.sergey.14011975@postgrespro.ru", "phone": "+70944635603"}
0005434509238	8E3868	2286 248033	KONSTANTIN IVANOV	{"email": "k-ivanov-1982@postgrespro.ru", "phone": "+70116512801"}
0005434509239	0A103F	3711 258760	VLADISLAV POPOV	{"phone": "+70551207009"}
0005434509240	5B990C	2899 278844	TATYANA YAKOVLEVA	{"phone": "+70460262214"}
0005434509241	6C1FB0	6217 746395	VIKTOR STEPANOV	{"email": "viktor-stepanov-1973@postgrespro.ru", "phone": "+70431117082"}
0005434509242	6C1FB0	9552 423749	NINA MIRONOVA	{"email": "n-mironova.081966@postgrespro.ru", "phone": "+70399747663"}
0005434509243	6516A8	8273 621041	VLADISLAV POPOV	{"email": "popov.vladislav-1964@postgrespro.ru", "phone": "+70601461790"}
0005434509244	C79D56	2712 713688	NATALYA ORLOVA	{"email": "natalya_orlova_1987@postgrespro.ru", "phone": "+70751894483"}
0005434509245	CCA967	4690 587076	YURIY ILIN	{"email": "y-ilin_061981@postgrespro.ru", "phone": "+70750940596"}
0005434509246	2CB0D4	0365 857777	ELENA ZAKHAROVA	{"phone": "+70586860139"}
0005434509247	9926EE	6274 786885	OLGA DAVYDOVA	{"phone": "+70924921719"}
0005434509248	9926EE	7393 546497	NATALYA LOGINOVA	{"email": "loginovanatalya-30031984@postgrespro.ru", "phone": "+70093201495"}
0005434509249	9926EE	7811 051798	EVGENIYA TIMOFEEVA	{"email": "evgeniya_timofeeva_22071977@postgrespro.ru", "phone": "+70266800571"}
0005434509250	9926EE	7279 214608	SERGEY KUZNECOV	{"email": "sergeykuznecov-1981@postgrespro.ru", "phone": "+70378260004"}
0005434509251	851B52	2434 528327	NIKOLAY SERGEEV	{"email": "nikolay.sergeev_121960@postgrespro.ru", "phone": "+70749117126"}
0005434509252	B301C9	7181 578813	ANNA ANTONOVA	{"email": "antonova.anna.30071980@postgrespro.ru", "phone": "+70842661744"}
0005434509253	69F272	1434 730413	DMITRIY FEDOROV	{"phone": "+70768656046"}
0005434509254	69F272	7119 610989	NATALYA ZAYCEVA	{"email": "zayceva-n1970@postgrespro.ru", "phone": "+70584184329"}
0005434509255	2C5C0B	2229 047469	KONSTANTIN NIKITIN	{"phone": "+70430009906"}
0005434509256	DB838A	8627 826330	OLGA SOROKINA	{"email": "sorokina.o.1965@postgrespro.ru", "phone": "+70403770596"}
0005434509257	05F996	0553 006882	EVGENIY POPOV	{"phone": "+70400923716"}
0005434509258	8A9F2B	1779 357264	SERGEY KULIKOV	{"email": "kulikov_sergey_031965@postgrespro.ru", "phone": "+70763225800"}
0005434509259	263103	6946 244484	ELENA FROLOVA	{"email": "frolova_e-06101982@postgrespro.ru", "phone": "+70381222475"}
0005434509260	263103	8628 383596	SERGEY ALEKSEEV	{"email": "alekseev.sergey1976@postgrespro.ru", "phone": "+70206026517"}
0005434509261	868392	3157 702134	NIKOLAY KARPOV	{"email": "karpov_nikolay_05061965@postgrespro.ru", "phone": "+70053573509"}
0005434509262	868392	7163 936568	PETR ANDREEV	{"phone": "+70101142515"}
0005434509263	5263C9	6909 918156	LARISA ERMAKOVA	{"phone": "+70841580159"}
0005434509264	FCE0CF	9681 335342	LYUBOV FEDOROVA	{"phone": "+70820689320"}
0005434509265	F40ABF	0892 728532	ANDREY MEDVEDEV	{"email": "medvedev_andrey16051971@postgrespro.ru", "phone": "+70883021881"}
0005434509266	A72EDE	9543 083623	GRIGORIY KUZNECOV	{"email": "g.kuznecov.111959@postgrespro.ru", "phone": "+70889932011"}
0005434509267	A72EDE	2871 537139	NATALYA IVANOVA	{"email": "natalyaivanova.1969@postgrespro.ru", "phone": "+70447036930"}
0005434509268	72A780	4310 714617	ALEKSEY DENISOV	{"phone": "+70765809328"}
0005434509269	72A780	2525 110684	ILYA VASILEV	{"email": "vasilev-ilya1974@postgrespro.ru", "phone": "+70812394691"}
0005434509270	0D2CF3	2521 576311	ALEKSEY NOVIKOV	{"phone": "+70135454185"}
0005434509271	179297	9882 173705	EKATERINA KOZLOVA	{"phone": "+70320699026"}
0005434509272	43568B	1882 650352	PAVEL BORISOV	{"phone": "+70550393340"}
0005434509273	43568B	7353 542426	VASILIY FOMIN	{"email": "fominv03071980@postgrespro.ru", "phone": "+70294051913"}
0005434509274	03968D	8335 029204	VASILIY STEPANOV	{"email": "stepanov_v_1974@postgrespro.ru", "phone": "+70373141320"}
0005434509275	FA3A35	9605 517526	OLESYA IVANOVA	{"email": "o-ivanova.1966@postgrespro.ru", "phone": "+70454873121"}
0005434509276	8BF2E4	0851 915184	TATYANA VOLKOVA	{"phone": "+70083347165"}
0005434509277	EF0BB0	8087 948014	ALEKSANDR PAVLOV	{"phone": "+70534769961"}
0005434509278	1579D7	8208 739872	VALENTINA POPOVA	{"email": "valentinapopova.04011979@postgrespro.ru", "phone": "+70434787103"}
0005434509279	6B2A05	8701 760794	EVGENIY IVANOV	{"email": "e-ivanov-02041976@postgrespro.ru", "phone": "+70943794851"}
0005434509281	CCAFD5	6127 496848	SERGEY GUSEV	{"email": "gusev.sergey04071983@postgrespro.ru", "phone": "+70780494838"}
0005434509282	AA9141	7409 210535	ALEKSEY ANDREEV	{"email": "aleksey-andreev_071968@postgrespro.ru", "phone": "+70119926995"}
0005434509283	CD9A7F	1874 905612	DARYA SMIRNOVA	{"email": "darya_smirnova1961@postgrespro.ru", "phone": "+70958280117"}
0005434509284	B89C83	2670 858910	ANNA MIRONOVA	{"phone": "+70677254988"}
0005434509285	B89C83	0425 242889	ALEKSANDR EGOROV	{"phone": "+70866003551"}
0005434509286	9AB777	8722 020807	ALEKSANDR RODIONOV	{"email": "rodionov-a-24061974@postgrespro.ru", "phone": "+70953655489"}
0005434509287	9AB777	7267 722843	LYUDMILA KULIKOVA	{"email": "lkulikova_07021965@postgrespro.ru", "phone": "+70181513179"}
0005434509288	768337	6948 998410	OKSANA ABRAMOVA	{"phone": "+70122007302"}
0005434509289	078B96	7792 466066	GULFIYA SOLOVEVA	{"email": "g-soloveva.1973@postgrespro.ru", "phone": "+70383010165"}
0005434509290	68FD9F	3340 820718	SERGEY IVANOV	{"email": "ivanovsergey.27091979@postgrespro.ru", "phone": "+70793935182"}
0005434509291	9A4731	8921 335516	YANA SOROKINA	{"email": "sorokinay011974@postgrespro.ru", "phone": "+70554881673"}
0005434509292	9A4731	5456 728277	SERGEY VOLKOV	{"email": "sergey-volkov.12081980@postgrespro.ru", "phone": "+70081586597"}
0005434509293	9A4731	7348 579303	VLADISLAV IVANOV	{"email": "vladislav.ivanov-07081981@postgrespro.ru", "phone": "+70167733854"}
0005434509294	DE852D	6821 406484	TATYANA POTAPOVA	{"phone": "+70224386088"}
0005434509295	F75D51	7481 589132	DAMIR SOROKIN	{"email": "damir-sorokin1968@postgrespro.ru", "phone": "+70942606098"}
0005434509296	8754C4	7508 399368	DMITRIY MIRONOV	{"email": "mironovdmitriy.1983@postgrespro.ru", "phone": "+70990264437"}
0005434509297	5680B8	4504 595317	ALEKSEY MAKAROV	{"email": "amakarov_031968@postgrespro.ru", "phone": "+70164514737"}
0005434509298	5680B8	6733 377064	TAISIYA ISAEVA	{"email": "isaeva.taisiya.1978@postgrespro.ru", "phone": "+70408372193"}
0005434509299	71EE26	6800 306319	ILDUS GRIGOREV	{"email": "i.grigorev-041974@postgrespro.ru", "phone": "+70851716166"}
0005434509300	BD7625	1602 261516	SVETLANA AFANASEVA	{"email": "svetlanaafanaseva-1971@postgrespro.ru", "phone": "+70581031795"}
0005434509301	5D0DE1	3978 325161	MARINA KARPOVA	{"phone": "+70641946762"}
0005434509302	5D0DE1	9419 356814	VALENTINA BORISOVA	{"email": "valentina.borisova-21091977@postgrespro.ru", "phone": "+70040538662"}
0005434509303	FCBC59	6139 074889	DMITRIY DMITRIEV	{"email": "dmitriy.dmitriev061968@postgrespro.ru", "phone": "+70659485905"}
0005434509304	6B71F6	1900 881702	TATYANA KUDRYASHOVA	{"phone": "+70930331238"}
0005434509305	93064E	8587 308245	NATALYA CHERNOVA	{"email": "chernova.n11071977@postgrespro.ru", "phone": "+70541342005"}
0005434509306	819A26	3505 041196	MIKHAIL KUZNECOV	{"email": "kuznecovm071953@postgrespro.ru", "phone": "+70804396673"}
0005434509307	946CA1	5518 439884	EVGENIYA KAZAKOVA	{"phone": "+70587293700"}
0005434509308	4A0BDB	6137 848464	VASILIY PAVLOV	{"phone": "+70402222139"}
0005434509309	44D8A6	5949 355755	GALINA MOROZOVA	{"email": "morozova_galina_011972@postgrespro.ru", "phone": "+70734985952"}
0005434509310	AB6C29	2859 020415	EVGENIY SCHERBAKOV	{"email": "scherbakov-e1973@postgrespro.ru", "phone": "+70409542854"}
0005434509311	DF83A6	7838 406778	IVAN NAUMOV	{"email": "naumovivan.15121973@postgrespro.ru", "phone": "+70312008932"}
0005434509312	AA62AD	5192 701925	VYACHESLAV VASILEV	{"email": "vasilevv.14011973@postgrespro.ru", "phone": "+70621578603"}
0005434509313	AA62AD	3591 460606	OLGA FEDOROVA	{"phone": "+70301201454"}
0005434509314	9C8F13	7221 021741	ANNA GORBUNOVA	{"email": "anna_gorbunova.091974@postgrespro.ru", "phone": "+70173586849"}
0005434509315	4BBDEF	1500 587930	TATYANA ORLOVA	{"email": "orlova_tatyana_1977@postgrespro.ru", "phone": "+70953347064"}
0005434509316	4BBDEF	7611 503059	ELENA MOROZOVA	{"phone": "+70526509333"}
0005434509317	40F9F8	5396 602558	IRINA GUSEVA	{"email": "i.guseva_01121974@postgrespro.ru", "phone": "+70176856312"}
0005434509318	40F9F8	0220 880463	SVETLANA FILIPPOVA	{"phone": "+70712270799"}
0005434509319	A9A31B	0915 824826	VIKTOR POPOV	{"email": "popov_viktor1970@postgrespro.ru", "phone": "+70338249634"}
0005434509320	91EE3B	0900 392958	OLGA ZAKHAROVA	{"phone": "+70304555864"}
0005434509321	91EE3B	3930 366687	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila.31121976@postgrespro.ru", "phone": "+70553340125"}
0005434509322	22C8FE	7501 287472	MAKSIM PETROV	{"email": "mpetrov_091968@postgrespro.ru", "phone": "+70122047139"}
0005434509323	22C8FE	1342 472463	ALBINA SEMENOVA	{"email": "semenovaalbina.1978@postgrespro.ru", "phone": "+70076311464"}
0005434509324	585E82	1769 457484	TATYANA MAKAROVA	{"email": "makarova_t.14081966@postgrespro.ru", "phone": "+70426845104"}
0005434509325	1D3044	3910 315487	ALEKSANDR POPOV	{"email": "popovaleksandr-061966@postgrespro.ru", "phone": "+70311113098"}
0005434509326	D3B84D	8417 674029	TATYANA OVCHINNIKOVA	{"phone": "+70722577155"}
0005434509327	D3B84D	2934 472149	NADEZHDA IVANOVA	{"email": "ivanova-n.06071981@postgrespro.ru", "phone": "+70363479722"}
0005434509328	FF9B2C	7834 092041	DMITRIY PETROV	{"email": "petrov-dmitriy081973@postgrespro.ru", "phone": "+70828996222"}
0005434509329	0BBCC1	5668 807454	VLADIMIR ORLOV	{"email": "vladimirorlov.1974@postgrespro.ru", "phone": "+70060506139"}
0005434509330	83A6FF	3834 324798	TIMOFEY GORBUNOV	{"email": "tgorbunov_121975@postgrespro.ru", "phone": "+70438304782"}
0005434509331	F7B26F	2830 213502	ANATOLIY GRIGOREV	{"phone": "+70644702736"}
0005434509332	567C2B	3134 469033	VITALIY VASILEV	{"email": "vitaliyvasilev_18091963@postgrespro.ru", "phone": "+70923908516"}
0005434509333	2F02BD	9014 874699	ALBINA KRASNOVA	{"phone": "+70597179125"}
0005434509334	2F02BD	5655 874800	ALINA AKIMOVA	{"phone": "+70434449808"}
0005434509335	848919	4489 112021	SVETLANA ANISIMOVA	{"email": "anisimova.s_12011977@postgrespro.ru", "phone": "+70224080802"}
0005434509336	97852C	1571 800831	NIKOLAY IVANOV	{"phone": "+70759341042"}
0005434512152	B12729	7416 934036	ELENA ZHURAVLEVA	{"phone": "+70939804448"}
0005434509337	59B480	2557 598683	SERGEY ZHUKOV	{"email": "sergey-zhukov-05101979@postgrespro.ru", "phone": "+70562929044"}
0005434509338	3495BB	6983 994312	NINA RYABOVA	{"phone": "+70004102048"}
0005434509339	B64C85	2240 316118	ALEKSEY OSIPOV	{"email": "osipova.031982@postgrespro.ru", "phone": "+70202087269"}
0005434509340	B64C85	5939 211496	KIRILL KONOVALOV	{"phone": "+70015436944"}
0005434509341	A7DAE1	6731 766542	MARIYA IVANOVA	{"email": "m_ivanova_1973@postgrespro.ru", "phone": "+70365574040"}
0005434509342	A7DAE1	3473 209275	MARIYA LEBEDEVA	{"email": "m-lebedeva081969@postgrespro.ru", "phone": "+70943115147"}
0005434509343	420140	4832 438219	ALEKSANDR KUZNECOV	{"phone": "+70763285140"}
0005434509344	420140	9900 617815	LIDIYA IVANOVA	{"email": "livanova.17041973@postgrespro.ru", "phone": "+70599701689"}
0005434509345	420140	6840 817075	ALEKSEY TIKHONOV	{"email": "aleksey.tikhonov30071965@postgrespro.ru", "phone": "+70024866420"}
0005434509346	86BFF9	6286 301625	TATYANA SERGEEVA	{"email": "tatyana.sergeeva_12011969@postgrespro.ru", "phone": "+70315562253"}
0005434509347	1FA88A	4404 532632	YANA KUZNECOVA	{"email": "kuznecova_y_1964@postgrespro.ru", "phone": "+70841239375"}
0005434509348	1FA88A	4972 246521	VITALIY SAVELEV	{"phone": "+70078600331"}
0005434509349	342556	6897 939329	DMITRIY GAVRILOV	{"phone": "+70407259338"}
0005434509350	816B82	8901 617813	ALEKSANDRA GAVRILOVA	{"email": "a-gavrilova_061969@postgrespro.ru", "phone": "+70738133520"}
0005434509351	D598F3	3850 930677	GALINA BELYAEVA	{"phone": "+70371412804"}
0005434509352	D598F3	3585 326303	MARINA ISAEVA	{"phone": "+70139080443"}
0005434509353	0BA8DB	4913 713079	ANDREY SMIRNOV	{"phone": "+70316874817"}
0005434509354	EEC58E	1392 161293	RUSLAN IVANOV	{"email": "ruslan.ivanov.29051970@postgrespro.ru", "phone": "+70774879794"}
0005434509355	F95FCF	8742 177417	YULIYA NIKOLAEVA	{"email": "nikolaeva.yuliya1985@postgrespro.ru", "phone": "+70190670864"}
0005434509356	270E53	4487 700300	NIKOLAY IVANOV	{"email": "ivanovn_101973@postgrespro.ru", "phone": "+70564526138"}
0005434509357	270E53	1144 110663	LYUDMILA YUDINA	{"email": "lyudmila_yudina_081972@postgrespro.ru", "phone": "+70237536336"}
0005434509358	2E58CC	1866 960993	ROMAN ANDREEV	{"email": "andreev-roman1970@postgrespro.ru", "phone": "+70517452260"}
0005434509359	2E58CC	0510 269880	YULIYA ORLOVA	{"phone": "+70156215469"}
0005434509360	D7D611	2066 877374	ZOYA KONDRATEVA	{"email": "kondrateva-zoya-111969@postgrespro.ru", "phone": "+70146525441"}
0005434509361	D7D611	1632 939254	VLADIMIR ZHUKOV	{"email": "v_zhukov.1975@postgrespro.ru", "phone": "+70663951155"}
0005434509362	D7D611	5664 125400	MATVEY DENISOV	{"email": "m.denisov.16061973@postgrespro.ru", "phone": "+70721270406"}
0005434509363	32D786	8490 048260	OKSANA GERASIMOVA	{"phone": "+70007578719"}
0005434509364	791F89	4238 664159	ILYA MAKSIMOV	{"phone": "+70099226394"}
0005434509365	C4119F	5520 251910	YURIY ZHUKOV	{"phone": "+70533635363"}
0005434509366	C4119F	3536 665001	ALEKSEY MIKHAYLOV	{"phone": "+70817172526"}
0005434509367	70E707	2008 720080	ANATOLIY GUSEV	{"phone": "+70294896120"}
0005434509368	BBA5BC	9813 002046	OLGA NOVIKOVA	{"email": "novikova-o_20101979@postgrespro.ru", "phone": "+70443867503"}
0005434509369	BBA5BC	4167 857523	TATYANA ABRAMOVA	{"phone": "+70856831671"}
0005434509370	18E9D3	0094 057020	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov.091972@postgrespro.ru", "phone": "+70711445645"}
0005434509371	C65372	5597 800818	EVGENIY NIKITIN	{"phone": "+70466411784"}
0005434509372	E1A5E2	8081 384395	LIDIYA PETROVA	{"phone": "+70518827085"}
0005434509373	E1A5E2	6299 674262	ALEKSANDR MARTYNOV	{"email": "martynov-aleksandr071959@postgrespro.ru", "phone": "+70163246149"}
0005434509374	2EFA5C	8624 893318	ANNA MIKHAYLOVA	{"phone": "+70537736415"}
0005434509375	2EFA5C	1821 233722	ANDREY EGOROV	{"phone": "+70575357943"}
0005434509376	78CC25	9206 507724	SERGEY KARPOV	{"email": "karpov.sergey-091978@postgrespro.ru", "phone": "+70144103107"}
0005434509377	78CC25	1873 848994	KIRILL KOZLOV	{"phone": "+70879131160"}
0005434509378	406A3C	0571 318773	NATALIYA SERGEEVA	{"phone": "+70513611971"}
0005434509379	6D2824	4534 022405	DANIL IVANOV	{"phone": "+70393675245"}
0005434509380	64E2B0	3495 582223	ARTEM DENISOV	{"email": "artem-denisov.20051979@postgrespro.ru", "phone": "+70391203044"}
0005434509381	86C2BD	2906 151369	VASILIY VOROBEV	{"email": "vorobev.vasiliy_1963@postgrespro.ru", "phone": "+70178761557"}
0005434512015	6AD0D5	1224 997865	EVA FEDOROVA	{"email": "eva.fedorova_12051974@postgrespro.ru", "phone": "+70516159653"}
0005434512016	6AD0D5	3272 136080	DAMIR IVANOV	{"phone": "+70858905621"}
0005434512017	2D5923	2921 350853	OLGA KOMAROVA	{"email": "komarovaolga_13061971@postgrespro.ru", "phone": "+70102207318"}
0005434512018	CB9B54	3227 291372	GALINA ZHURAVLEVA	{"phone": "+70652411914"}
0005434512019	CB9B54	4359 047830	GALINA MEDVEDEVA	{"phone": "+70645023366"}
0005434512020	CB9B54	3730 670021	VLADIMIR SOROKIN	{"email": "v.sorokin011977@postgrespro.ru", "phone": "+70806709593"}
0005434512021	18A17E	8312 732733	VALERIYA NIKITINA	{"phone": "+70554215729"}
0005434512022	D66A1B	7392 083284	ELENA IVANOVA	{"phone": "+70574484133"}
0005434512023	D66A1B	4293 365480	KIRILL KUZMIN	{"email": "k.kuzmin.081971@postgrespro.ru", "phone": "+70336979036"}
0005434512024	379935	0023 727012	DANILA NAZAROV	{"phone": "+70306398320"}
0005434512025	73E180	8439 157562	VLADIMIR TARASOV	{"phone": "+70231507674"}
0005434512026	73E180	4951 087762	ALEKSANDR VASILEV	{"phone": "+70477892735"}
0005434512027	383464	8459 085309	DMITRIY GERASIMOV	{"phone": "+70089286917"}
0005434512028	E9C23C	9778 191441	MAKSIM ZAKHAROV	{"email": "zakharov_maksim.1977@postgrespro.ru", "phone": "+70345897046"}
0005434512029	E9C23C	9306 412716	MARIYA NIKOLAEVA	{"email": "mariya-nikolaeva_091971@postgrespro.ru", "phone": "+70782810537"}
0005434512030	183A76	9881 052854	VIKTOR EGOROV	{"phone": "+70304725888"}
0005434512031	BE1720	9707 513247	IVAN TARASOV	{"email": "tarasov-ivan041977@postgrespro.ru", "phone": "+70709015081"}
0005434512032	8558C3	8071 713539	DMITRIY FILIPPOV	{"phone": "+70729445583"}
0005434512033	8558C3	7479 641187	ANNA ZAKHAROVA	{"email": "a.zakharova1982@postgrespro.ru", "phone": "+70672273115"}
0005434512034	E3FD4B	1293 447945	MARINA VLASOVA	{"phone": "+70512517599"}
0005434512035	87ED67	3182 120233	VASILIY PETROV	{"email": "v-petrov-081968@postgrespro.ru", "phone": "+70838135947"}
0005434512036	6BE374	9866 414471	EKATERINA VASILEVA	{"email": "vasileva-ekaterina_17101975@postgrespro.ru", "phone": "+70372550803"}
0005434512037	B0EE5A	9538 760110	ANDREY SHEVCHENKO	{"email": "andrey_shevchenko.1972@postgrespro.ru", "phone": "+70443942345"}
0005434512038	292901	7845 325814	LEV VASILEV	{"phone": "+70493124955"}
0005434512039	292901	0078 681432	ALEKSEY FEDOROV	{"email": "fedorova_09031977@postgrespro.ru", "phone": "+70721632744"}
0005434512040	C1F20B	0623 548678	SERGEY FROLOV	{"email": "sergey_frolov_20031981@postgrespro.ru", "phone": "+70649156359"}
0005434512041	010E6F	5605 951506	VALENTINA NIKIFOROVA	{"email": "nikiforovav.1974@postgrespro.ru", "phone": "+70976721100"}
0005434512042	BC7E2D	5537 001003	TATYANA MIKHAYLOVA	{"phone": "+70969391317"}
0005434512043	E520A3	8130 053040	VALERIYA VOLKOVA	{"phone": "+70757010466"}
0005434512044	9EC67A	7637 847730	ANASTASIYA IVANOVA	{"email": "ivanovaa.17081982@postgrespro.ru", "phone": "+70647998644"}
0005434512045	9EC67A	5929 872914	OKSANA MAKAROVA	{"phone": "+70059909940"}
0005434512046	CEE329	6544 688160	ELVIRA SEMENOVA	{"phone": "+70938227560"}
0005434512047	BD59E7	5143 127820	EKATERINA IVANOVA	{"phone": "+70213254503"}
0005434512048	2F019E	3377 644774	ROMAN MELNIKOV	{"email": "melnikov-r1967@postgrespro.ru", "phone": "+70607755686"}
0005434512049	2F019E	4825 823251	OLGA ZHUKOVA	{"phone": "+70498305024"}
0005434512050	F9D4D7	4082 593697	RISHAT PAVLOV	{"email": "rishat_pavlov.041970@postgrespro.ru", "phone": "+70814801660"}
0005434512051	6A8816	8757 381452	GALINA KALININA	{"email": "kalinina-galina.06091966@postgrespro.ru", "phone": "+70116465468"}
0005434512052	868D89	0984 787802	TATYANA TARASOVA	{"email": "t_tarasova1953@postgrespro.ru", "phone": "+70963812346"}
0005434512053	123BC8	3652 868537	ALEKSANDR VOLKOV	{"phone": "+70990316608"}
0005434512054	74792B	3123 241266	NINA NOVIKOVA	{"phone": "+70756426054"}
0005434512055	74792B	6666 638968	ALEKSANDR IVANOV	{"phone": "+70434259333"}
0005434512056	AFA3CF	3479 505231	YULIYA GAVRILOVA	{"phone": "+70133633440"}
0005434512057	1E8B45	1346 744811	NAIL SOKOLOV	{"email": "sokolov.nail041974@postgrespro.ru", "phone": "+70437896627"}
0005434512058	1E8B45	6907 533227	VITALIY KULIKOV	{"phone": "+70216559171"}
0005434512059	4F584D	5249 469972	IGOR ORLOV	{"email": "i_orlov-30041972@postgrespro.ru", "phone": "+70688080027"}
0005434512060	24187F	4471 212086	DMITRIY KISELEV	{"email": "dkiselev.1973@postgrespro.ru", "phone": "+70894349527"}
0005434512061	24187F	3240 860304	SVETLANA YAKOVLEVA	{"phone": "+70333887680"}
0005434512062	E7752C	2709 086779	TATYANA KUZNECOVA	{"email": "t.kuznecova.041969@postgrespro.ru", "phone": "+70103993806"}
0005434512063	DF7ECA	1326 293159	VERA POPOVA	{"email": "v-popova-031968@postgrespro.ru", "phone": "+70053556328"}
0005434512064	FE1D82	5983 851609	NIKOLAY SAVELEV	{"phone": "+70587739024"}
0005434512065	FE1D82	2992 123656	YAROSLAV ABRAMOV	{"phone": "+70031720556"}
0005434512066	FE1D82	0956 333974	MAKSIM MELNIKOV	{"email": "melnikov-maksim-1973@postgrespro.ru", "phone": "+70880131409"}
0005434512067	C4F672	9706 790753	MILENA FEDOROVA	{"email": "fedorovam-24121976@postgrespro.ru", "phone": "+70956382211"}
0005434512068	C4F672	1448 681455	NATALIYA KOVALEVA	{"phone": "+70580376875"}
0005434512069	FEB0DE	2533 424774	LYUBOV DMITRIEVA	{"phone": "+70337802856"}
0005434512070	FEB0DE	9877 025350	OLGA KOLESNIKOVA	{"phone": "+70140959391"}
0005434512071	24E10E	5591 675332	KARINA YAKOVLEVA	{"email": "k.yakovleva.061970@postgrespro.ru", "phone": "+70536366407"}
0005434512072	4EA29F	0830 186373	VYACHESLAV MOROZOV	{"phone": "+70741956433"}
0005434512073	47869E	2209 245285	NATALYA BOGDANOVA	{"email": "bogdanova_natalya.091974@postgrespro.ru", "phone": "+70721813953"}
0005434512074	E703D0	1197 672315	MAKSIM PAVLOV	{"email": "pavlov-m-1970@postgrespro.ru", "phone": "+70962977879"}
0005434512075	9FF807	6954 585019	GALINA MAKAROVA	{"email": "galina.makarova.031984@postgrespro.ru", "phone": "+70194918167"}
0005434512076	9FF807	5071 703961	LYUBOV SMIRNOVA	{"phone": "+70476753729"}
0005434512077	9FF807	8346 358530	VLADIMIR FOMIN	{"email": "fomin.vladimir1977@postgrespro.ru", "phone": "+70871689374"}
0005434512078	68814D	0454 484792	ANATOLIY IVANOV	{"phone": "+70056300428"}
0005434512079	68814D	5726 119143	ALEKSEY PAVLOV	{"email": "pavlov_a.041967@postgrespro.ru", "phone": "+70932794223"}
0005434512080	68814D	1918 918391	VIKTORIYA SEMENOVA	{"email": "vsemenova_111968@postgrespro.ru", "phone": "+70951279217"}
0005434512081	E096E2	4683 454883	VERA MARTYNOVA	{"phone": "+70882188878"}
0005434512082	0E425C	5807 071864	KLAVDIYA MOROZOVA	{"phone": "+70971976319"}
0005434512083	85E3DD	9065 381116	ANDREY KUZNECOV	{"phone": "+70713967076"}
0005434512084	A64F38	5140 343292	ALEKSEY MAKSIMOV	{"phone": "+70876151551"}
0005434512085	390AE8	1540 946716	ALEKSANDR KISELEV	{"email": "kiselev-a_101968@postgrespro.ru", "phone": "+70235460600"}
0005434512086	50C4C5	0193 412618	POLINA MASLOVA	{"phone": "+70149954978"}
0005434512087	8B8100	3351 525891	NADEZHDA ANISIMOVA	{"email": "anisimova_n_26071977@postgrespro.ru", "phone": "+70976528054"}
0005434512088	8B8100	7169 226042	ZHANNA CHERNOVA	{"phone": "+70171325742"}
0005434512089	DB47DF	7648 120106	SERGEY KAZAKOV	{"phone": "+70111062972"}
0005434512090	E66BDC	0944 874860	VIKTORIYA NOVIKOVA	{"phone": "+70004855153"}
0005434512091	05DAC4	6593 329778	ELIZAVETA NAZAROVA	{"phone": "+70613424817"}
0005434512092	81EB18	0003 937998	DMITRIY PETROV	{"email": "petrov.d_20031979@postgrespro.ru", "phone": "+70177410161"}
0005434512093	DC0B4B	1013 630106	IRINA FEDOROVA	{"phone": "+70593959830"}
0005434512094	A92921	6149 293224	PAVEL ROMANOV	{"email": "p-romanov-071979@postgrespro.ru", "phone": "+70472257118"}
0005434512095	A92921	5622 716300	ANASTASIYA SEMENOVA	{"phone": "+70220052732"}
0005434512096	7B16AA	1801 561628	VERA KUZNECOVA	{"phone": "+70659228208"}
0005434512097	B7C406	8004 887497	LYUBOV ABRAMOVA	{"phone": "+70298767535"}
0005434512098	B7C406	7684 811928	ANASTASIYA ANDREEVA	{"phone": "+70246363687"}
0005434512099	B7C406	2226 777074	EVGENIY MAKSIMOV	{"email": "emaksimov.21031982@postgrespro.ru", "phone": "+70591886549"}
0005434512100	23A1AE	3927 604021	ALEKSANDR MOISEEV	{"email": "a_moiseev_1972@postgrespro.ru", "phone": "+70161305876"}
0005434512101	449CC9	1060 193298	ILYA POPOV	{"email": "popov-i1973@postgrespro.ru", "phone": "+70977919275"}
0005434512102	449CC9	8291 096808	VLADIMIR MOROZOV	{"phone": "+70709315230"}
0005434512103	FBEC2E	5568 725629	LYUDMILA NESTEROVA	{"email": "lnesterova_1959@postgrespro.ru", "phone": "+70050930577"}
0005434512104	270B4B	8568 667505	VLADIMIR BARANOV	{"phone": "+70017444580"}
0005434512105	270B4B	7211 371761	YULIYA DMITRIEVA	{"phone": "+70987597150"}
0005434512106	BF1556	8484 778607	NINA TIMOFEEVA	{"phone": "+70699295413"}
0005434512107	40F6C4	9199 887217	DENIS MATVEEV	{"email": "matveevd1976@postgrespro.ru", "phone": "+70032654649"}
0005434512108	271DAE	6632 314844	VIKTOR VOROBEV	{"phone": "+70903923519"}
0005434512109	81FDDE	2196 233368	NIKOLAY EGOROV	{"phone": "+70284020190"}
0005434512110	6E8055	5935 158927	IGOR MEDVEDEV	{"email": "medvedev-igor_021984@postgrespro.ru", "phone": "+70857503917"}
0005434512111	6E8055	2397 442861	ANATOLIY AFANASEV	{"phone": "+70662131005"}
0005434512112	44CDD2	9616 378011	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr09071978@postgrespro.ru", "phone": "+70228565614"}
0005434512113	44CDD2	9744 536936	LARISA CHERNOVA	{"email": "larisachernova1975@postgrespro.ru", "phone": "+70310453657"}
0005434512114	495D21	1353 668359	OLGA MEDVEDEVA	{"phone": "+70700739920"}
0005434512115	BDA80F	5677 214863	SVETLANA FROLOVA	{"email": "svetlana.frolova_05091974@postgrespro.ru", "phone": "+70815179722"}
0005434512116	BDA80F	7149 707783	NIKOLAY DAVYDOV	{"phone": "+70645393739"}
0005434512117	7730D4	6918 188463	ELENA IVANOVA	{"email": "ivanovae081968@postgrespro.ru", "phone": "+70463359088"}
0005434512118	7730D4	9031 697588	TATYANA RODIONOVA	{"phone": "+70327935571"}
0005434512119	7730D4	5354 646392	OLGA TIKHONOVA	{"phone": "+70562892013"}
0005434512120	EE237A	0542 055376	NIKITA MAKSIMOV	{"email": "nmaksimov-1970@postgrespro.ru", "phone": "+70684126133"}
0005434512121	44A307	4112 285570	VASILIY IVANOV	{"email": "ivanov-vasiliy.09101972@postgrespro.ru", "phone": "+70137066385"}
0005434512122	FF5B39	4794 957535	ANDREY SCHERBAKOV	{"email": "ascherbakov.1968@postgrespro.ru", "phone": "+70902526964"}
0005434512123	A17365	2924 598269	OLGA ZAYCEVA	{"phone": "+70189888324"}
0005434512124	A17365	6328 224175	IRINA ANDREEVA	{"phone": "+70616788991"}
0005434512125	7B7FFA	9975 058749	KSENIYA FADEEVA	{"phone": "+70800262392"}
0005434512126	7B7FFA	8584 331363	ELENA ALEKSANDROVA	{"phone": "+70051868943"}
0005434512127	3FFCCA	3755 425516	LYUBOV NIKITINA	{"phone": "+70295890142"}
0005434512128	3FFCCA	3927 162259	ANDREY SOROKIN	{"phone": "+70945678248"}
0005434512129	E2ECD9	6187 972595	ALEKSEY GORBUNOV	{"phone": "+70955845234"}
0005434512130	3844A7	8710 659841	ANDREY NAZAROV	{"email": "a-nazarov_1972@postgrespro.ru", "phone": "+70579534225"}
0005434512131	3844A7	4743 173979	EVGENIY NIKOLAEV	{"email": "nikolaeve.26071976@postgrespro.ru", "phone": "+70883041092"}
0005434512132	3844A7	0964 858868	NINA KRASNOVA	{"email": "krasnova_nina101980@postgrespro.ru", "phone": "+70353304555"}
0005434512133	2ACBA2	8547 703949	GALINA NIKITINA	{"email": "nikitinag1964@postgrespro.ru", "phone": "+70441064980"}
0005434512134	787624	3173 206994	VYACHESLAV IVANOV	{"email": "ivanovv.111971@postgrespro.ru", "phone": "+70116505889"}
0005434512135	3DF83A	2536 318688	ILYA MEDVEDEV	{"email": "medvedev_i1959@postgrespro.ru", "phone": "+70466421598"}
0005434512136	4B39BB	9399 321631	LIDIYA BELYAEVA	{"email": "belyaeva.l.101955@postgrespro.ru", "phone": "+70863411836"}
0005434512137	4B39BB	8089 940633	LYUDMILA MATVEEVA	{"phone": "+70468565351"}
0005434512138	82DF9F	5677 565271	KIRILL MIKHAYLOV	{"email": "k_mikhaylov101960@postgrespro.ru", "phone": "+70634583285"}
0005434512139	02D6E2	0342 906382	ANATOLIY ALEKSANDROV	{"email": "anatoliy.aleksandrov-1966@postgrespro.ru", "phone": "+70693488634"}
0005434512140	1EED15	2652 533420	SOFYA BORISOVA	{"email": "borisova_s091983@postgrespro.ru", "phone": "+70696570517"}
0005434512141	0D7DD3	7001 949217	SERGEY KAZAKOV	{"email": "kazakov.sergey-1971@postgrespro.ru", "phone": "+70915554948"}
0005434512142	0D7DD3	4769 104863	GALINA NIKOLAEVA	{"email": "nikolaeva_g-02081974@postgrespro.ru", "phone": "+70833066508"}
0005434512143	B7EF55	9862 637274	ARTEM YAKOVLEV	{"email": "ayakovlev07051965@postgrespro.ru", "phone": "+70931598407"}
0005434512144	B7EF55	0380 898339	ARKADIY ANDREEV	{"email": "andreev.arkadiy.20111966@postgrespro.ru", "phone": "+70428731917"}
0005434512145	A89AD3	4285 601379	IRINA KOZLOVA	{"email": "kozlova_i-1969@postgrespro.ru", "phone": "+70496623192"}
0005434512146	A9C94E	6079 942483	GENNADIY ANDREEV	{"email": "andreevgennadiy1977@postgrespro.ru", "phone": "+70851981671"}
0005434512147	4589D0	7991 313860	VLADIMIR SAVELEV	{"phone": "+70201655935"}
0005434512148	FF9D39	8104 654971	ANNA POLYAKOVA	{"phone": "+70698786909"}
0005434512149	FF9D39	0723 212298	POLINA ILINA	{"phone": "+70124335358"}
0005434512150	EE7F13	9958 289342	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov.1974@postgrespro.ru", "phone": "+70065086885"}
0005434512151	0322D9	7715 767822	ARTEM FEDOROV	{"email": "fedorovartem.20091975@postgrespro.ru", "phone": "+70315333672"}
0005434512153	B12729	4438 676187	ALEKSEY MIRONOV	{"phone": "+70878653248"}
0005434512154	7B3375	1795 578846	MARIYA TIMOFEEVA	{"email": "mariya_timofeeva_071973@postgrespro.ru", "phone": "+70053768896"}
0005434512155	7B3375	9423 615424	MARIYA MALYSHEVA	{"email": "m-malysheva-051962@postgrespro.ru", "phone": "+70759540860"}
0005434512156	E46F6E	3450 975914	MAKSIM IVANOV	{"phone": "+70794031617"}
0005434512157	466B63	1198 601985	EKATERINA KISELEVA	{"email": "kiseleva-ekaterina_1972@postgrespro.ru", "phone": "+70645749122"}
0005434512158	1C5D32	2422 519785	RUSLAN NAZAROV	{"email": "ruslan-nazarov051969@postgrespro.ru", "phone": "+70110826042"}
0005434512159	86B823	5267 132703	FANIS KUZNECOV	{"phone": "+70016574704"}
0005434512160	86B823	0398 571033	VALENTINA POPOVA	{"email": "popova.v_1973@postgrespro.ru", "phone": "+70124932658"}
0005434512161	B2CA18	9204 724445	ELENA PETROVA	{"phone": "+70775701780"}
0005434512162	901165	4749 904161	SERGEY MAKSIMOV	{"phone": "+70580966951"}
0005434512163	B42FFD	4136 053903	NADEZHDA SOKOLOVA	{"email": "sokolova_n1965@postgrespro.ru", "phone": "+70925627353"}
0005434512164	90CA79	5182 481391	ELENA ZHUKOVA	{"phone": "+70764777922"}
0005434512165	D66715	9985 547232	TAMARA IVANOVA	{"phone": "+70236887314"}
0005434512166	EE47C9	2107 873240	ALI ZAYCEV	{"email": "zaycevali.06041968@postgrespro.ru", "phone": "+70804577255"}
0005434512167	6ADFFB	3180 957401	LYUDMILA SCHERBAKOVA	{"phone": "+70543689282"}
0005434512168	4EE813	2089 166720	TAMARA MOROZOVA	{"email": "morozovat_011975@postgrespro.ru", "phone": "+70478847949"}
0005434512169	4EE813	5458 680396	MAKSIM KOZLOV	{"phone": "+70443903756"}
0005434512170	FF8571	6901 111204	TATYANA KULIKOVA	{"phone": "+70373181422"}
0005434512171	1E16B7	9996 775681	YURIY SCHERBAKOV	{"phone": "+70938273268"}
0005434512172	5D66B0	6032 099419	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy-061962@postgrespro.ru", "phone": "+70150880233"}
0005434512173	5D66B0	1457 182105	ANTON TARASOV	{"phone": "+70636373407"}
0005434512174	57C950	1606 005477	ANASTASIYA GRISHINA	{"phone": "+70998129849"}
0005434512175	D6600C	7070 859167	NIKOLAY PETROV	{"phone": "+70403396526"}
0005434512176	319B7E	0495 985997	NINA TIKHONOVA	{"phone": "+70840911926"}
0005434512177	319B7E	4969 861023	VLADIMIR KUZMIN	{"email": "vkuzmin081978@postgrespro.ru", "phone": "+70707661932"}
0005434512178	DB7F0D	8817 570796	YULIYA KOZLOVA	{"phone": "+70522185519"}
0005434512179	B916C3	7201 670830	SVETLANA KUZNECOVA	{"phone": "+70173988552"}
0005434512180	C08004	9694 221637	NIKOLAY IVANOV	{"phone": "+70787081720"}
0005434512181	E4D4A1	7393 479671	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr_1975@postgrespro.ru", "phone": "+70594607256"}
0005434512182	146BB7	0335 613155	TATYANA KONOVALOVA	{"email": "tatyana-konovalova06041970@postgrespro.ru", "phone": "+70646814220"}
0005434512183	03242D	0947 844917	LYUBOV ALEKSEEVA	{"phone": "+70810914463"}
0005434512184	303C54	7866 487758	ANGELINA KOZLOVA	{"email": "kozlova_angelina-1974@postgrespro.ru", "phone": "+70103551550"}
0005434512185	C6B730	7757 898823	EKATERINA KUZNECOVA	{"email": "kuznecova-e17081963@postgrespro.ru", "phone": "+70801050434"}
0005434512186	8EFFE9	4982 835984	NATALYA KOMAROVA	{"phone": "+70835733207"}
0005434512187	99DDD3	2454 218570	DMITRIY NIKOLAEV	{"email": "d_nikolaev_30101977@postgrespro.ru", "phone": "+70250560073"}
0005434512188	452E91	2580 204285	YANA OSIPOVA	{"email": "osipova_y_1969@postgrespro.ru", "phone": "+70195797475"}
0005434512189	B28034	8221 369552	LYUBOV ILINA	{"phone": "+70500056325"}
0005434512190	18DA38	9278 857230	IVAN ZAKHAROV	{"phone": "+70387242687"}
0005434512191	75E118	8194 547043	ELENA KUZNECOVA	{"email": "kuznecova-elena1977@postgrespro.ru", "phone": "+70821734812"}
0005434512192	2512A2	1265 580094	IRINA IVANOVA	{"email": "ivanova-i28041974@postgrespro.ru", "phone": "+70674637672"}
0005434512193	B6261B	0317 360570	ELENA DAVYDOVA	{"email": "e-davydova.081959@postgrespro.ru", "phone": "+70487045451"}
0005434512194	B6261B	4671 413799	OLESYA MAKAROVA	{"phone": "+70512390830"}
0005434512195	A1FA9F	2307 779314	DARYA CHERNOVA	{"phone": "+70461946630"}
0005434512196	017507	2083 650268	VLADIMIR FROLOV	{"email": "vfrolov-121962@postgrespro.ru", "phone": "+70153308506"}
0005434512197	017507	6362 389793	NATALYA SOKOLOVA	{"email": "natalya_sokolova25031971@postgrespro.ru", "phone": "+70312270970"}
0005434512198	98716D	2314 735706	EVGENIY POPOV	{"phone": "+70526998022"}
0005434512199	34368D	2113 118274	ELENA KONDRATEVA	{"phone": "+70992245662"}
0005434512200	8981A0	0956 313520	ALEKSEY BORISOV	{"phone": "+70674069954"}
0005434512201	8981A0	4777 756663	PETR NIKOLAEV	{"email": "pnikolaev20011974@postgrespro.ru", "phone": "+70403809361"}
0005434512202	0ED769	3277 244860	ALEKSANDR PETROV	{"phone": "+70422253893"}
0005434512203	0ED769	4795 193044	ANNA ABRAMOVA	{"email": "a_abramova-031974@postgrespro.ru", "phone": "+70452329245"}
0005434512204	8757F6	3766 291583	POLINA KULIKOVA	{"email": "kulikova_p_30101979@postgrespro.ru", "phone": "+70411359903"}
0005434512205	8757F6	6769 495385	ALEKSANDR NAZAROV	{"phone": "+70014141258"}
0005434512206	F9437B	4910 129781	SVETLANA RYABOVA	{"phone": "+70779835679"}
0005434512207	5D23F7	4232 059900	SERGEY MAKAROV	{"email": "smakarov_1963@postgrespro.ru", "phone": "+70456274567"}
0005434512208	432E3F	4912 667999	MARINA VOLKOVA	{"phone": "+70616168327"}
0005434512209	432E3F	3117 904819	DMITRIY MOISEEV	{"phone": "+70068665444"}
0005434512210	076175	1655 989165	MARIYA KAZAKOVA	{"email": "kazakova.mariya1972@postgrespro.ru", "phone": "+70679430239"}
0005434512211	076175	6240 596241	MIKHAIL MELNIKOV	{"email": "m_melnikov.091974@postgrespro.ru", "phone": "+70079348551"}
0005434512212	076175	7063 515449	IVAN SEMENOV	{"phone": "+70340827108"}
0005434512213	160D78	4238 528881	DMITRIY FROLOV	{"email": "frolov_dmitriy_111971@postgrespro.ru", "phone": "+70855937154"}
0005434512214	160D78	8573 296720	MARIYA ZHURAVLEVA	{"email": "m_zhuravleva-26061961@postgrespro.ru", "phone": "+70663824635"}
0005434512215	4CAE68	9499 473682	LYUDMILA KONDRATEVA	{"phone": "+70304225365"}
0005434512216	3C0BD0	5168 924372	ALEKSANDR KUZNECOV	{"phone": "+70691553192"}
0005434512217	59DD43	2619 231250	OLGA PETROVA	{"phone": "+70734520875"}
0005434512218	C82586	1749 157140	ARTEM GERASIMOV	{"phone": "+70350996137"}
0005434512219	27DDD0	6671 224573	ANNA MOROZOVA	{"phone": "+70390280341"}
0005434512220	27DDD0	6410 221259	IRINA MARTYNOVA	{"phone": "+70954194351"}
0005434512221	CA7C41	3886 277503	BORIS GORBUNOV	{"email": "b-gorbunov-041977@postgrespro.ru", "phone": "+70104521418"}
0005434512222	F0E36A	9191 389662	ALBINA CHERNOVA	{"phone": "+70325190850"}
0005434512223	7E0753	6141 172581	VLADIMIR SERGEEV	{"phone": "+70279650017"}
0005434512224	7E0753	9452 787136	EGOR IVANOV	{"phone": "+70417837660"}
0005434512225	3F39C2	9058 976869	OLGA YAKOVLEVA	{"email": "oyakovleva_111974@postgrespro.ru", "phone": "+70777851959"}
0005434512226	54E67A	6343 868419	IRINA FOMINA	{"phone": "+70311839640"}
0005434512227	B86808	2578 535024	MARIYA MALYSHEVA	{"phone": "+70278694828"}
0005434512228	4D1BF3	8850 056680	NIKOLAY GORBUNOV	{"email": "gorbunovnikolay031977@postgrespro.ru", "phone": "+70419348378"}
0005434512229	DE4963	2524 588344	ELENA VOROBEVA	{"email": "elenavorobeva1970@postgrespro.ru", "phone": "+70331947736"}
0005434512230	DE4963	7607 977694	VLADIMIR IVANOV	{"email": "v-ivanov-051971@postgrespro.ru", "phone": "+70649363494"}
0005434512231	4C8358	0276 162418	OLGA MAKSIMOVA	{"phone": "+70430960331"}
0005434512232	4C8358	7460 494739	IVAN ZAYCEV	{"phone": "+70514097484"}
0005434512233	7363AB	6117 215128	NINA POLYAKOVA	{"phone": "+70563440794"}
0005434512234	A55531	7657 699447	VLADIMIR NIKITIN	{"phone": "+70617681248"}
0005434512235	852E5F	9603 440567	KUZMA GAVRILOV	{"phone": "+70301474083"}
0005434512236	F8D70D	1013 682874	VLADIMIR ISAEV	{"phone": "+70009704819"}
0005434512237	F8D70D	5172 938415	ELENA NIKOLAEVA	{"email": "nikolaeva-elena08091974@postgrespro.ru", "phone": "+70786413201"}
0005434512238	1ECE0E	5020 185978	ALEKSEY ZAYCEV	{"phone": "+70087066911"}
0005434512239	AF2EDC	9749 926951	VLADIMIR FILIPPOV	{"email": "vladimir-filippov_1972@postgrespro.ru", "phone": "+70405658768"}
0005434512240	481A2A	5541 162024	LYUDMILA ZAKHAROVA	{"email": "zakharoval-24061973@postgrespro.ru", "phone": "+70666319403"}
0005434512241	481A2A	8670 961503	VLADIMIR ISAEV	{"phone": "+70608249435"}
0005434512242	B6E138	4119 623398	VYACHESLAV MAKAROV	{"email": "makarov.vyacheslav_1967@postgrespro.ru", "phone": "+70774266345"}
0005434512243	B6E138	9843 502234	DMITRIY SAVELEV	{"phone": "+70334744580"}
0005434512244	92C901	6013 017109	TAMARA EGOROVA	{"phone": "+70591423886"}
0005434512245	92C901	5367 597785	ANATOLIY KAZAKOV	{"phone": "+70455235988"}
0005434512246	B74646	1797 340127	DMITRIY SMIRNOV	{"phone": "+70256196417"}
0005434512247	9E9E8E	8048 053090	SERGEY BORISOV	{"phone": "+70454318342"}
0005434512248	DCE6C6	2037 441870	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov.021971@postgrespro.ru", "phone": "+70904172671"}
0005434512249	38C871	1488 194424	ANTONINA ANDREEVA	{"email": "andreeva_a-1974@postgrespro.ru", "phone": "+70567666203"}
0005434512250	0D7C22	3497 861052	ARSENIY KUZNECOV	{"phone": "+70659465819"}
0005434512251	0D7C22	8363 931445	VALENTINA KAZAKOVA	{"email": "kazakova_v-14071973@postgrespro.ru", "phone": "+70797630632"}
0005434512252	0D7C22	1520 016481	ANASTASIYA NESTEROVA	{"email": "nesterovaanastasiya041974@postgrespro.ru", "phone": "+70038838163"}
0005434512253	DF8AA9	2567 268095	ILYA ILIN	{"phone": "+70280287628"}
0005434512254	6A5498	7656 116253	NINA KISELEVA	{"phone": "+70937904919"}
0005434512255	6A5498	7871 054924	ANDREY KAZAKOV	{"email": "andrey.kazakov_1982@postgrespro.ru", "phone": "+70524466077"}
0005434512256	5BBAE9	6815 064338	OLGA STEPANOVA	{"email": "stepanova-olga.081972@postgrespro.ru", "phone": "+70685783108"}
0005434512257	5BBAE9	1145 905475	EKATERINA NAZAROVA	{"email": "enazarova1969@postgrespro.ru", "phone": "+70071956169"}
0005434512258	5BBAE9	0233 742840	ANATOLIY IVANOV	{"email": "anatoliy-ivanov-26071968@postgrespro.ru", "phone": "+70734297483"}
0005434512259	E26597	0349 635080	IVAN VASILEV	{"email": "ivan-vasilev-1956@postgrespro.ru", "phone": "+70524792209"}
0005434512260	4F0739	1249 767754	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr_1967@postgrespro.ru", "phone": "+70747204787"}
0005434512261	4F0739	5530 142575	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikova.lyudmila.071972@postgrespro.ru", "phone": "+70100903332"}
0005434513533	587B5E	0486 829503	FEDOR MARTYNOV	{"phone": "+70718652947"}
0005434513534	2A2625	5120 112339	TATYANA ZOTOVA	{"phone": "+70223443252"}
0005434513535	2A2625	7866 771889	YURIY IVANOV	{"phone": "+70524095001"}
0005434513536	7517CC	3417 756178	SVETLANA ANISIMOVA	{"phone": "+70296615984"}
0005434513537	F8DD25	4836 165657	VLADIMIR DAVYDOV	{"email": "davydov_v-031973@postgrespro.ru", "phone": "+70143082114"}
0005434513538	827137	0886 804788	FARIT DAVYDOV	{"phone": "+70704887214"}
0005434513539	827137	6331 061353	ANDREY ZAKHAROV	{"email": "a-zakharov_25031972@postgrespro.ru", "phone": "+70693960120"}
0005434513540	B9398B	4834 513459	KSENIYA KUZNECOVA	{"phone": "+70854458846"}
0005434513541	293499	1703 285267	ALEKSANDR FEDOTOV	{"phone": "+70747014802"}
0005434513542	0D9521	6254 575857	ANDREY KUZNECOV	{"email": "kuznecov.andrey_1967@postgrespro.ru", "phone": "+70399827617"}
0005434513543	1661E2	4106 522900	SERGEY SMIRNOV	{"email": "smirnov.s-20071985@postgrespro.ru", "phone": "+70828341331"}
0005434513544	6DDBE2	1142 732027	VASILIY KRASNOV	{"email": "krasnov_vasiliy1978@postgrespro.ru", "phone": "+70204916443"}
0005434513545	8F3E30	8547 771610	NATALYA GRISHINA	{"phone": "+70958100382"}
0005434513546	8F3E30	7071 339867	LARISA KONDRATEVA	{"phone": "+70705234614"}
0005434513547	16274A	5747 628998	OLGA ANTONOVA	{"email": "o-antonova091971@postgrespro.ru", "phone": "+70010181170"}
0005434513548	15B599	7950 948463	STANISLAV BARANOV	{"email": "sbaranov_30061969@postgrespro.ru", "phone": "+70606199820"}
0005434513549	D0CE04	3375 484593	ANDREY MARTYNOV	{"email": "andrey-martynov-13081968@postgrespro.ru", "phone": "+70425679351"}
0005434513550	EE1CA3	7351 232905	VERA POTAPOVA	{"phone": "+70439047107"}
0005434513551	8AE0E4	4294 921203	OLGA IVANOVA	{"phone": "+70124143533"}
0005434513552	61AEBC	3289 892053	VLADIMIR ZAKHAROV	{"phone": "+70926011517"}
0005434513553	61AEBC	4881 626160	ALEKSANDR ROMANOV	{"email": "romanov_a_01111979@postgrespro.ru", "phone": "+70894008301"}
0005434513554	CBADA2	0834 598905	YANA MOROZOVA	{"email": "morozova-yana_31011970@postgrespro.ru", "phone": "+70035424357"}
0005434513555	0E4414	2196 773608	MIKHAIL PAVLOV	{"email": "mikhail.pavlov_02081968@postgrespro.ru", "phone": "+70283493406"}
0005434513556	0E4414	0664 166311	LYUBOV DMITRIEVA	{"phone": "+70844432735"}
0005434513557	429849	2324 274398	SERAFIM KOZLOV	{"email": "s-kozlov05081972@postgrespro.ru", "phone": "+70457058623"}
0005434513558	0F53C4	1229 381211	ALEKSEY KUZMIN	{"phone": "+70083077895"}
0005434513559	68E09D	4812 067657	IRINA GUSEVA	{"email": "irinaguseva02021966@postgrespro.ru", "phone": "+70462461273"}
0005434513560	68E09D	9368 519275	SVETLANA NOVIKOVA	{"email": "snovikova-061962@postgrespro.ru", "phone": "+70635919466"}
0005434513561	FCAB1C	2471 076313	LYUBOV TROFIMOVA	{"phone": "+70598318552"}
0005434513562	FCAB1C	8892 512004	NINA NIKOLAEVA	{"phone": "+70224000546"}
0005434513563	FCAB1C	2712 566957	MIKHAIL SMIRNOV	{"email": "mikhail.smirnov.1976@postgrespro.ru", "phone": "+70980836170"}
0005434513564	FCAB1C	4616 337932	NADEZHDA KOVALEVA	{"email": "kovaleva.nadezhda02061966@postgrespro.ru", "phone": "+70919262640"}
0005434513565	BFDB1C	2235 163139	MARIYA LUKYANOVA	{"phone": "+70895770732"}
0005434513566	8C2AE0	8529 058395	KONSTANTIN YAKOVLEV	{"phone": "+70921635190"}
0005434513567	4194AD	8289 658562	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov-1961@postgrespro.ru", "phone": "+70970451759"}
0005434513568	4194AD	2572 747960	VALENTINA ZOTOVA	{"email": "zotova-valentina.111979@postgrespro.ru", "phone": "+70326129430"}
0005434513569	75451F	9362 304897	ALEKSANDR PETROV	{"email": "petrov_aleksandr-051973@postgrespro.ru", "phone": "+70478929001"}
0005434513570	9981F9	0340 242934	MIKHAIL ANTONOV	{"email": "mikhail.antonov_1977@postgrespro.ru", "phone": "+70987786911"}
0005434513571	38775C	1092 906830	PELAGEYA LEBEDEVA	{"phone": "+70975219360"}
0005434513572	CEE1EE	1542 163049	TAGIR MELNIKOV	{"phone": "+70283824990"}
0005434513573	9EBE55	0553 269827	DMITRIY DMITRIEV	{"email": "dmitriydmitriev091967@postgrespro.ru", "phone": "+70141849147"}
0005434513574	645495	2851 728251	TATYANA NESTEROVA	{"phone": "+70176416791"}
0005434513575	AC9991	3268 487391	ELENA NESTEROVA	{"email": "nesterovae_1968@postgrespro.ru", "phone": "+70874859392"}
0005434513576	07CB66	5591 845605	VYACHESLAV GORBUNOV	{"phone": "+70501677536"}
0005434513577	07CB66	7610 477496	EMIL NIKOLAEV	{"phone": "+70447760761"}
0005434513578	5892AF	4663 548217	ALEKSANDRA ZAKHAROVA	{"phone": "+70269845838"}
0005434513579	26F44E	6524 600654	DAMIR CHERNOV	{"phone": "+70045430648"}
0005434513580	EDBBFB	1310 913506	MARIYA KOROLEVA	{"email": "m.koroleva_12021972@postgrespro.ru", "phone": "+70150343645"}
0005434513581	1687EC	9952 612811	ZINAIDA SEMENOVA	{"email": "semenova-zinaida_1989@postgrespro.ru", "phone": "+70865298988"}
0005434513582	5700A6	5596 076257	ALEKSANDR ZAYCEV	{"phone": "+70940632374"}
0005434513583	6E4109	9442 526370	NATALYA KUZNECOVA	{"phone": "+70913242912"}
0005434513584	6FC4B7	0258 427913	LYUDMILA KRASNOVA	{"phone": "+70514902145"}
0005434513585	6FC4B7	8255 245672	IRINA KUZNECOVA	{"email": "kuznecovairina.1969@postgrespro.ru", "phone": "+70295792672"}
0005434513586	A61597	3478 350548	VALENTINA ABRAMOVA	{"phone": "+70371829449"}
0005434513587	A61597	1647 685037	LYUDMILA FOMINA	{"email": "fomina.lyudmila_061969@postgrespro.ru", "phone": "+70431489053"}
0005434513588	B5793A	0389 202267	ALEKSANDR SAVELEV	{"email": "saveleva1976@postgrespro.ru", "phone": "+70841539869"}
0005434513589	D3FB1F	3606 834019	ELENA LEBEDEVA	{"email": "lebedeva.e1967@postgrespro.ru", "phone": "+70663474140"}
0005434513590	D3FB1F	8434 254374	EVGENIYA SMIRNOVA	{"email": "smirnova.e_1982@postgrespro.ru", "phone": "+70537715066"}
0005434513591	D3FB1F	9123 269759	ANNA PETROVA	{"phone": "+70185041590"}
0005434513592	6AF0D3	5732 737953	ALEKSANDRA FROLOVA	{"phone": "+70572468556"}
0005434513593	048808	4240 945912	ZINAIDA NAZAROVA	{"email": "zinaida.nazarova.1959@postgrespro.ru", "phone": "+70917778779"}
0005434513594	57C297	5012 660698	ALEKSANDR BELOV	{"phone": "+70210908496"}
0005434513595	474596	2458 241789	VLADIMIR IVANOV	{"phone": "+70031301628"}
0005434513596	AEFA14	7488 532352	RAISA ANISIMOVA	{"email": "anisimova_r-13071972@postgrespro.ru", "phone": "+70377297874"}
0005434513597	AEFA14	7331 598812	SERGEY SOROKIN	{"email": "sorokins-1974@postgrespro.ru", "phone": "+70001126686"}
0005434513598	F802DC	6523 876458	NADEZHDA POPOVA	{"email": "popova-nadezhda-15061961@postgrespro.ru", "phone": "+70127948622"}
0005434513599	F802DC	6762 507064	KLAVDIYA MELNIKOVA	{"phone": "+70771314122"}
0005434513600	342F2F	8895 265004	GALINA KOLESNIKOVA	{"phone": "+70239890706"}
0005434513601	838C4C	0809 451710	NINA ZHUKOVA	{"email": "zhukova.n-22101963@postgrespro.ru", "phone": "+70538478065"}
0005434513602	838C4C	2882 283946	ANGELINA OVCHINNIKOVA	{"phone": "+70926684138"}
0005434513603	28514D	1785 918935	MARINA KOZLOVA	{"email": "mkozlova_121985@postgrespro.ru", "phone": "+70711543912"}
0005434513604	B26362	4100 085301	MIKHAIL VASILEV	{"phone": "+70898504126"}
0005434513605	B26362	8114 203726	VLADIMIR GORBUNOV	{"email": "vgorbunov-21121980@postgrespro.ru", "phone": "+70902263305"}
0005434513606	9692EC	7995 027270	NATALYA SMIRNOVA	{"email": "smirnova.natalya_12071977@postgrespro.ru", "phone": "+70194266055"}
0005434513607	06E049	5366 115300	DARYA MATVEEVA	{"email": "d-matveeva.1969@postgrespro.ru", "phone": "+70301509007"}
0005434513608	393DF4	4052 264113	ANATOLIY IVANOV	{"email": "ivanovanatoliy_011977@postgrespro.ru", "phone": "+70465852954"}
0005434513609	14A1F7	0658 340561	LYUDMILA POPOVA	{"email": "popova-l.04061974@postgrespro.ru", "phone": "+70808582851"}
0005434513610	9E590C	7738 828189	ELENA MARTYNOVA	{"phone": "+70423517431"}
0005434513611	9FE72C	7942 971548	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.a_1973@postgrespro.ru", "phone": "+70474615750"}
0005434513612	9FE72C	5962 870816	SERGEY MOROZOV	{"email": "s.morozov_061972@postgrespro.ru", "phone": "+70682802625"}
0005434513613	9FE72C	5347 429228	VLADIMIR SERGEEV	{"phone": "+70415644974"}
0005434513614	D02B98	6854 130805	NADEZHDA TIMOFEEVA	{"email": "timofeeva_n1979@postgrespro.ru", "phone": "+70249879741"}
0005434513615	F6FC09	5878 311318	MARINA ANTONOVA	{"email": "antonova.m_1974@postgrespro.ru", "phone": "+70359827066"}
0005434513616	B5EB9B	4100 294128	GALINA GORBUNOVA	{"phone": "+70608843492"}
0005434513617	A039A6	4844 120988	VIKTOR SHEVCHENKO	{"email": "shevchenkoviktor.051962@postgrespro.ru", "phone": "+70618406343"}
0005434513618	A039A6	7687 963709	ANATOLIY ZHURAVLEV	{"phone": "+70548472398"}
0005434513619	BB2BBB	9460 118145	NIKOLAY NIKITIN	{"email": "nikitin.nikolay_13111974@postgrespro.ru", "phone": "+70434964244"}
0005434513620	BB2BBB	1871 929693	NADEZHDA SEMENOVA	{"email": "nadezhda-semenova111971@postgrespro.ru", "phone": "+70809718127"}
0005434513621	F5A321	7971 524605	NINA NIKITINA	{"phone": "+70514047324"}
0005434513622	843652	9842 379171	YULIYA GORBUNOVA	{"phone": "+70119572352"}
0005434513623	843652	8082 345766	TATYANA ZOTOVA	{"phone": "+70860029542"}
0005434513624	07E323	0601 209587	ROMAN BORISOV	{"email": "borisov.r.011962@postgrespro.ru", "phone": "+70416954446"}
0005434513625	07E323	3041 829910	KHALIDA FILATOVA	{"email": "khalida.filatova.23101981@postgrespro.ru", "phone": "+70477826060"}
0005434513626	70C12D	2566 956494	TATYANA MELNIKOVA	{"email": "tatyana.melnikova-121987@postgrespro.ru", "phone": "+70893933497"}
0005434513627	70C12D	8712 315048	ANDREY BARANOV	{"email": "baranovandrey_111977@postgrespro.ru", "phone": "+70010462366"}
0005434513628	CB8F87	9981 150837	OLGA SOKOLOVA	{"email": "o_sokolova-1982@postgrespro.ru", "phone": "+70897563387"}
0005434513629	894914	0450 745403	DENIS IVANOV	{"phone": "+70872657444"}
0005434513630	894914	3683 593962	EKATERINA MOROZOVA	{"email": "morozova_ekaterina-031971@postgrespro.ru", "phone": "+70261148820"}
0005434513631	894914	2926 945585	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev_061985@postgrespro.ru", "phone": "+70947500151"}
0005434513632	D2C349	3038 497502	EKATERINA KUZMINA	{"phone": "+70528501051"}
0005434513633	9F806E	3425 886156	IVAN SMIRNOV	{"email": "ismirnov.011982@postgrespro.ru", "phone": "+70366975587"}
0005434513634	35CEB2	8194 088794	ANATOLIY DAVYDOV	{"email": "anatoliy.davydov.111986@postgrespro.ru", "phone": "+70681432166"}
0005434513635	851419	1785 828096	MAKSIM TIKHONOV	{"email": "m-tikhonov.011971@postgrespro.ru", "phone": "+70417333144"}
0005434513636	6D5CF7	1074 513524	OLGA ANTONOVA	{"email": "antonovao05091967@postgrespro.ru", "phone": "+70033571117"}
0005434513637	0BCBE0	6506 888181	GALINA POPOVA	{"email": "galina_popova061976@postgrespro.ru", "phone": "+70700418799"}
0005434513638	A9342C	9698 078074	YURIY BELOV	{"email": "ybelov021976@postgrespro.ru", "phone": "+70885819833"}
0005434513639	A20B5D	6481 303503	OLGA ANDREEVA	{"phone": "+70434847238"}
0005434513640	A20B5D	4602 469768	EVDOKIYA LOGINOVA	{"phone": "+70930432758"}
0005434513641	89C7E0	3292 250577	ELENA KRASNOVA	{"phone": "+70896681347"}
0005434513642	833E1A	4861 812818	EKATERINA TROFIMOVA	{"phone": "+70169202162"}
0005434513643	5DCB7C	6731 931977	VERA BARANOVA	{"phone": "+70417641917"}
0005434513644	D4584E	8904 347896	VITALIY EGOROV	{"phone": "+70185897727"}
0005434513645	D4584E	7826 127531	ALEKSANDR SIDOROV	{"phone": "+70862781372"}
0005434513646	159B82	0345 026931	OLGA TROFIMOVA	{"email": "olga.trofimova071965@postgrespro.ru", "phone": "+70995315317"}
0005434513647	1763D9	8610 670200	ELENA MELNIKOVA	{"email": "elena_melnikova1968@postgrespro.ru", "phone": "+70830775485"}
0005434513648	7E301D	6335 030528	ALBERT RODIONOV	{"email": "rodionovalbert.1970@postgrespro.ru", "phone": "+70990349926"}
0005434513649	7E301D	9863 438524	GALINA PETROVA	{"phone": "+70574762582"}
0005434513650	8808FE	3800 338645	OLEG FILIPPOV	{"email": "oleg_filippov011960@postgrespro.ru", "phone": "+70233331131"}
0005434513651	9772A3	2935 670105	ALEKSEY STEPANOV	{"email": "stepanov_a_01111966@postgrespro.ru", "phone": "+70767319442"}
0005434513652	9772A3	2705 775917	LYUDMILA KUZNECOVA	{"phone": "+70397905623"}
0005434513653	451049	1635 576900	TATYANA STEPANOVA	{"phone": "+70808500763"}
0005434513654	34F7F0	6647 357550	MARGARITA EFREMOVA	{"email": "efremova-margarita-071979@postgrespro.ru", "phone": "+70608790159"}
0005434513655	34F7F0	7754 501254	MARIYA ZAYCEVA	{"phone": "+70391993342"}
0005434513656	176DC8	2223 876993	MARIYA MAKAROVA	{"email": "mmakarova.121972@postgrespro.ru", "phone": "+70574225396"}
0005434513657	176DC8	4738 520981	DMITRIY BORISOV	{"email": "d-borisov23011972@postgrespro.ru", "phone": "+70259267923"}
0005434513658	18986C	3067 835664	ALEKSANDR PETROV	{"phone": "+70614699328"}
0005434513659	1E8C33	2142 447888	DENIS IVANOV	{"email": "ivanov.denis.081967@postgrespro.ru", "phone": "+70674552412"}
0005434513660	1E8C33	9047 479408	ANNA VLASOVA	{"email": "vlasova_a081977@postgrespro.ru", "phone": "+70004070825"}
0005434513661	D5E742	8621 483577	DARYA IVANOVA	{"email": "ivanovad.15021967@postgrespro.ru", "phone": "+70783096544"}
0005434514923	9AC92A	8921 086704	ALEKSANDR POPOV	{"phone": "+70106915474"}
0005434514921	58327E	9840 299110	LYUDMILA MAKSIMOVA	{"email": "maksimova_l-101973@postgrespro.ru", "phone": "+70799824595"}
0005434514922	9AC92A	3171 375160	ALEKSANDRA AKIMOVA	{"email": "aleksandra-akimova_1966@postgrespro.ru", "phone": "+70904721891"}
0005434514924	1C6A99	8043 418653	SERGEY POPOV	{"email": "popovsergey_031968@postgrespro.ru", "phone": "+70949091023"}
0005434514925	1C6A99	3082 259857	DANIIL GERASIMOV	{"phone": "+70560129042"}
0005434514926	A6F166	4771 619462	IGOR TIMOFEEV	{"email": "igortimofeev.05101973@postgrespro.ru", "phone": "+70931620042"}
0005434514927	AC30FB	0773 437792	DMITRIY ZAYCEV	{"phone": "+70763630830"}
0005434514928	AC30FB	5164 019391	MARIYA ZHUKOVA	{"email": "mariya_zhukova-051959@postgrespro.ru", "phone": "+70389860842"}
0005434514929	AFBF3C	9423 925583	LIDIYA ZAYCEVA	{"email": "zayceva.l021967@postgrespro.ru", "phone": "+70124298093"}
0005434514930	5FA0FF	4110 918868	LYUBOV GORBUNOVA	{"email": "gorbunova-lyubov-28011978@postgrespro.ru", "phone": "+70407509225"}
0005434514931	34C285	3766 416175	MIKHAIL KUZNECOV	{"email": "kuznecov-m-1971@postgrespro.ru", "phone": "+70475748470"}
0005434514932	3F83A1	8607 110623	NINA POTAPOVA	{"email": "potapova.nina_1980@postgrespro.ru", "phone": "+70698621123"}
0005434514933	16CD2F	6857 960521	DMITRIY ZHUKOV	{"phone": "+70581035162"}
0005434514934	E2E3B4	9941 124739	YULIYA SCHERBAKOVA	{"email": "scherbakovay1980@postgrespro.ru", "phone": "+70857024607"}
0005434514935	E2E3B4	4149 955963	ANASTASIYA FROLOVA	{"phone": "+70995236204"}
0005434514936	54E114	5962 427716	TATYANA SOKOLOVA	{"phone": "+70306827614"}
0005434514937	870555	9493 726970	NIKOLAY FOMIN	{"email": "nikolayfomin_30101965@postgrespro.ru", "phone": "+70672609372"}
0005434514938	59CA5F	4379 957171	TATYANA FADEEVA	{"phone": "+70505791067"}
0005434514939	59CA5F	9398 956349	GALINA ROMANOVA	{"phone": "+70083364890"}
0005434514940	C8745E	9352 812627	EKATERINA SEMENOVA	{"phone": "+70873120465"}
0005434514941	C8745E	6307 995399	IVAN MIKHAYLOV	{"email": "mikhaylov_i-1965@postgrespro.ru", "phone": "+70739915872"}
0005434514942	406A5C	3456 625870	ALEKSANDR MAKAROV	{"email": "a_makarov.07101965@postgrespro.ru", "phone": "+70822659119"}
0005434514943	372309	8096 001591	ILMIR PAVLOV	{"phone": "+70377407449"}
0005434514944	1687C3	5495 344683	DAMIR STEPANOV	{"email": "stepanov-d1974@postgrespro.ru", "phone": "+70477924447"}
0005434514945	DB2C51	1431 084756	IVAN VLASOV	{"email": "ivlasov031973@postgrespro.ru", "phone": "+70262126699"}
0005434514946	7F7646	8744 493091	VALENTINA EFIMOVA	{"email": "efimova-v_1991@postgrespro.ru", "phone": "+70942029997"}
0005434514947	4EEE61	1879 456282	NINA IVANOVA	{"phone": "+70317336007"}
0005434514948	285FEF	9997 952592	MAKSIM IVANOV	{"email": "ivanovm.011975@postgrespro.ru", "phone": "+70652101648"}
0005434514949	BB2CF3	4514 711247	ALEKSEY VLASOV	{"phone": "+70977042179"}
0005434514950	2E273C	2079 845491	MARYAM MOISEEVA	{"email": "moiseeva.maryam1966@postgrespro.ru", "phone": "+70892301705"}
0005434514951	AE1AC3	6104 929827	ALEKSANDR PETROV	{"phone": "+70794272664"}
0005434514952	797E09	5368 888122	VIKTORIYA VLASOVA	{"email": "v_vlasova-1975@postgrespro.ru", "phone": "+70648703840"}
0005434514953	797E09	1839 327573	MARIYA MIRONOVA	{"phone": "+70495836898"}
0005434514954	646FF2	4301 448544	NIKOLAY MOISEEV	{"phone": "+70339906796"}
0005434514955	2321AD	7634 078865	DARYA IVANOVA	{"phone": "+70950009122"}
0005434514956	2321AD	5411 869324	VALENTINA KUZNECOVA	{"email": "v_kuznecova02061972@postgrespro.ru", "phone": "+70682570560"}
0005434514957	5F765A	8440 866876	ROMAN NIKOLAEV	{"email": "nikolaevr.1969@postgrespro.ru", "phone": "+70799018675"}
0005434514958	9B8914	9950 768229	LIDIYA MOROZOVA	{"email": "lidiyamorozova-04111978@postgrespro.ru", "phone": "+70229945866"}
0005434514959	09F570	1207 673401	ILMIRA DANILOVA	{"email": "danilova.ilmira-011978@postgrespro.ru", "phone": "+70828098404"}
0005434514960	09F570	8535 802802	IRINA PAVLOVA	{"phone": "+70809026601"}
0005434514961	09F570	7019 338462	ANNA STEPANOVA	{"phone": "+70259255665"}
0005434514962	10079F	7571 430932	IVAN KULIKOV	{"phone": "+70349249004"}
0005434514963	9F045C	1112 579968	ZINAIDA MATVEEVA	{"phone": "+70900192894"}
0005434514964	9F045C	6577 114837	NATALIYA GAVRILOVA	{"email": "n-gavrilova.23021975@postgrespro.ru", "phone": "+70178615651"}
0005434514965	78E178	9394 546289	ELENA MAKSIMOVA	{"phone": "+70532078537"}
0005434514966	A10592	0957 382458	LYUBOV NIKIFOROVA	{"email": "nikiforova_lyubov_14061970@postgrespro.ru", "phone": "+70128528341"}
0005434514967	A10592	5730 029967	YURIY SERGEEV	{"email": "y.sergeev.20111971@postgrespro.ru", "phone": "+70826240970"}
0005434514968	900AD9	4112 702606	VIKTOR NOVIKOV	{"phone": "+70606291376"}
0005434514969	8B3E57	0889 784946	VYACHESLAV SAVELEV	{"email": "vyacheslav_savelev_1966@postgrespro.ru", "phone": "+70249540584"}
0005434514970	8B3E57	3896 893317	LIDIYA MARTYNOVA	{"phone": "+70324230109"}
0005434514971	1B15D5	0806 510944	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila1971@postgrespro.ru", "phone": "+70321356957"}
0005434514972	E6E70A	4273 910556	ANASTASIYA POTAPOVA	{"email": "potapova-anastasiya_1968@postgrespro.ru", "phone": "+70726162090"}
0005434514973	E6E70A	3656 407280	ANATOLIY VASILEV	{"email": "vasilev-anatoliy_30101971@postgrespro.ru", "phone": "+70024711897"}
0005434514974	1F1712	3312 315476	DMITRIY ANTONOV	{"phone": "+70370405259"}
0005434514975	32B528	0125 875972	SERGEY CHERNOV	{"phone": "+70984873737"}
0005434514976	DB2B71	4178 233481	OLGA LAZAREVA	{"email": "lazareva-o30061969@postgrespro.ru", "phone": "+70888299030"}
0005434514977	DB2B71	3816 312789	SERGEY SOROKIN	{"phone": "+70835405126"}
0005434514978	6C926E	4255 610829	VALENTINA LAZAREVA	{"email": "valentina_lazareva.05021975@postgrespro.ru", "phone": "+70300960850"}
0005434514979	6C926E	5697 781600	RINAT MOROZOV	{"email": "r-morozov-23101986@postgrespro.ru", "phone": "+70090445464"}
0005434514980	DBC63E	3102 116502	NADEZHDA BORISOVA	{"email": "n.borisova_091971@postgrespro.ru", "phone": "+70168723988"}
0005434514981	8B97A9	1282 035192	ANASTASIYA SAVELEVA	{"email": "savelevaa031962@postgrespro.ru", "phone": "+70119673263"}
0005434514982	FE7D80	1658 742997	MARIYA YUDINA	{"phone": "+70248926012"}
0005434515039	36DF69	9258 175184	SERGEY ANTONOV	{"phone": "+70042527676"}
0005434514983	FE7D80	3770 826700	ARINA IVANOVA	{"email": "ivanova_arina1963@postgrespro.ru", "phone": "+70481433023"}
0005434514984	A06DB8	5739 674123	TAMARA ROMANOVA	{"email": "romanova_t-011981@postgrespro.ru", "phone": "+70291599651"}
0005434514985	6ECD4B	0697 301362	ANDREY KUZNECOV	{"email": "a_kuznecov_01051977@postgrespro.ru", "phone": "+70920387508"}
0005434514986	5FEA02	7869 222857	VLADISLAV MAKAROV	{"email": "vladislav.makarov-061986@postgrespro.ru", "phone": "+70587919250"}
0005434514987	4E03C9	2670 837529	NADEZHDA NOVIKOVA	{"phone": "+70017565481"}
0005434514988	A603EF	4413 315678	NIKITA GAVRILOV	{"phone": "+70477952130"}
0005434514989	5A5BA1	9406 793609	MARINA DENISOVA	{"email": "mdenisova-101967@postgrespro.ru", "phone": "+70687702917"}
0005434514990	5A5BA1	6455 406507	ALEKSEY NAZAROV	{"email": "aleksey.nazarov.1976@postgrespro.ru", "phone": "+70154766014"}
0005434514991	E26956	2674 735572	VERA ANTONOVA	{"email": "vantonova_01021981@postgrespro.ru", "phone": "+70799731169"}
0005434514992	4B041D	4427 117436	NINA IVANOVA	{"email": "ivanovan.07111968@postgrespro.ru", "phone": "+70476314931"}
0005434514993	DDAD14	0832 887611	VERA POTAPOVA	{"phone": "+70620858826"}
0005434514994	3EFCA1	5166 722696	ANDREY VOROBEV	{"phone": "+70692363687"}
0005434514995	97DEEF	8702 266079	ELENA MATVEEVA	{"email": "matveeva_e_031967@postgrespro.ru", "phone": "+70383149269"}
0005434514996	AB42EC	3895 991814	EKATERINA EGOROVA	{"email": "egorovaekaterina25101970@postgrespro.ru", "phone": "+70743233042"}
0005434514997	90DDB8	3251 198425	ARTEM SCHERBAKOV	{"email": "scherbakovartem-06121974@postgrespro.ru", "phone": "+70231185980"}
0005434514998	A7721C	7439 072043	ALEKSANDR ANTONOV	{"email": "aleksandr_antonov25111976@postgrespro.ru", "phone": "+70686966374"}
0005434514999	A7721C	5180 667129	BORIS ALEKSEEV	{"phone": "+70757301721"}
0005434515000	9917C8	7951 040582	DENIS RODIONOV	{"email": "rodionov-d_15071970@postgrespro.ru", "phone": "+70299325882"}
0005434515001	9917C8	3107 246744	MIKHAIL IVANOV	{"phone": "+70432233120"}
0005434515002	578D6C	8243 888111	LYUBOV NIKITINA	{"email": "lyubov_nikitina1976@postgrespro.ru", "phone": "+70017593700"}
0005434515003	578D6C	5251 060637	VALENTINA FADEEVA	{"email": "valentina-fadeeva-111969@postgrespro.ru", "phone": "+70837246220"}
0005434515004	E0A9DC	9564 916742	MARINA KOMAROVA	{"phone": "+70195178453"}
0005434515005	8F0F0C	7509 195659	EVGENIY KUDRYASHOV	{"email": "e-kudryashov.19121981@postgrespro.ru", "phone": "+70109390713"}
0005434515006	1DBCA9	6428 998769	IRINA FEDOROVA	{"phone": "+70720965472"}
0005434515007	3B6AA1	2325 462702	DMITRIY BONDARENKO	{"email": "bondarenko-d-08121971@postgrespro.ru", "phone": "+70695168430"}
0005434515008	3B6AA1	4920 000484	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr.16031974@postgrespro.ru", "phone": "+70362522557"}
0005434515009	B13E5F	1191 500348	PAVEL BORISOV	{"email": "borisov-pavel.23121978@postgrespro.ru", "phone": "+70435182677"}
0005434515010	B13E5F	1804 248011	ANTON KUZNECOV	{"email": "antonkuznecov-1972@postgrespro.ru", "phone": "+70755268018"}
0005434515011	62E034	1045 596331	ANATOLIY MIKHAYLOV	{"phone": "+70478162541"}
0005434515012	612214	6930 034331	ANDREY NIKOLAEV	{"email": "nikolaev.a.041975@postgrespro.ru", "phone": "+70117843447"}
0005434515013	94BCAE	3870 550542	VLADISLAV BARANOV	{"phone": "+70726443115"}
0005434515014	9052DC	1066 308259	ALEKSANDR IVANOV	{"phone": "+70526574259"}
0005434515015	9052DC	7348 730579	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.1980@postgrespro.ru", "phone": "+70779695784"}
0005434515016	B027FA	6880 577940	DARYA VOLKOVA	{"email": "volkovad-1980@postgrespro.ru", "phone": "+70591889674"}
0005434515017	EB3F6C	1715 571040	RAFAIL DENISOV	{"phone": "+70727449978"}
0005434515018	ACEDF4	6254 199420	NATALYA KISELEVA	{"email": "kiseleva.n.021975@postgrespro.ru", "phone": "+70422151612"}
0005434515019	2E5F69	8365 037428	ALEKSANDR ZAKHAROV	{"phone": "+70596505524"}
0005434515020	B35DD5	3901 363727	VITALIY SAVELEV	{"email": "vitaliysavelev.081966@postgrespro.ru", "phone": "+70094401105"}
0005434515021	3C8902	2759 035234	DMITRIY ANDREEV	{"email": "andreev_d_1973@postgrespro.ru", "phone": "+70106991865"}
0005434515022	564200	1952 465847	ANDREY NIKOLAEV	{"phone": "+70076620667"}
0005434515023	765BD2	8119 671691	SERGEY NIKITIN	{"email": "nikitins.101982@postgrespro.ru", "phone": "+70791134625"}
0005434515024	A347A7	3771 992198	TAMARA PAVLOVA	{"phone": "+70119004369"}
0005434515025	A347A7	7598 969183	MARINA BELOVA	{"email": "belova-marina-24121980@postgrespro.ru", "phone": "+70157503705"}
0005434515026	E13DF6	4562 475485	ELENA BELOVA	{"email": "belova.e.081964@postgrespro.ru", "phone": "+70039546469"}
0005434515027	E13DF6	6286 245563	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov1971@postgrespro.ru", "phone": "+70513148017"}
0005434515028	5621BF	3805 961951	GENNADIY EGOROV	{"email": "gennadiyegorov.1972@postgrespro.ru", "phone": "+70825293495"}
0005434515029	6E5993	8543 551753	TIMUR NIKITIN	{"email": "nikitin_timur-1982@postgrespro.ru", "phone": "+70056831264"}
0005434515030	FA4379	5924 498659	KONSTANTIN FROLOV	{"email": "frolov_konstantin1971@postgrespro.ru", "phone": "+70275230843"}
0005434515031	BEA1EB	3905 288357	DMITRIY MOROZOV	{"email": "morozov_dmitriy_01021969@postgrespro.ru", "phone": "+70436846214"}
0005434515032	89E243	6114 777470	ZOYA MALYSHEVA	{"email": "malysheva-zoya.051980@postgrespro.ru", "phone": "+70682590071"}
0005434515033	174551	7539 232305	YURIY PETROV	{"email": "y.petrov1975@postgrespro.ru", "phone": "+70226113168"}
0005434515034	174551	5727 322627	ROMAN KULIKOV	{"email": "kulikovr_1977@postgrespro.ru", "phone": "+70718637666"}
0005434515035	174551	8235 085100	MARIYA LEBEDEVA	{"email": "lebedeva_m14011968@postgrespro.ru", "phone": "+70338219705"}
0005434515036	22F8FE	9668 717791	EVGENIY RODIONOV	{"phone": "+70142497744"}
0005434515037	E1B82F	4149 514618	ELENA STEPANOVA	{"email": "elenastepanova.24061965@postgrespro.ru", "phone": "+70075327730"}
0005434515038	E1B82F	9125 293193	SERGEY IVANOV	{"email": "sergey_ivanov.1954@postgrespro.ru", "phone": "+70467361758"}
0005434515040	36DF69	9757 386964	SVETLANA KUDRYASHOVA	{"email": "kudryashova_s-1964@postgrespro.ru", "phone": "+70395461235"}
0005434515041	9729CA	8986 355370	ALEKSANDR SCHERBAKOV	{"phone": "+70943985934"}
0005434515042	040CEF	7552 883798	RAFAEL SCHERBAKOV	{"email": "scherbakov_rafael-1978@postgrespro.ru", "phone": "+70743620198"}
0005434515043	C300EB	2453 677451	VLADIMIR TIKHONOV	{"email": "vladimirtikhonov121973@postgrespro.ru", "phone": "+70060550997"}
0005434515044	C300EB	7495 066271	ANASTASIYA VOROBEVA	{"phone": "+70311465962"}
0005434515045	C300EB	2874 019693	NIKOLAY SMIRNOV	{"phone": "+70460903470"}
0005434515046	6DD957	3880 188295	SERGEY SEMENOV	{"email": "semenov-s.06041963@postgrespro.ru", "phone": "+70841889049"}
0005434516043	6F9DE9	1043 122113	OLEG BELOV	{"email": "belovoleg.1973@postgrespro.ru", "phone": "+70501783069"}
0005434516044	6F9DE9	3034 050514	ZAKHAR PAVLOV	{"email": "z-pavlov1963@postgrespro.ru", "phone": "+70736573500"}
0005434516045	6F9DE9	2482 288352	ALEKSANDR VOROBEV	{"email": "aleksandrvorobev-121979@postgrespro.ru", "phone": "+70480674172"}
0005434516046	E32460	5760 850672	MARINA KUZNECOVA	{"phone": "+70917160411"}
0005434516047	D4D5DD	2389 903268	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey_20031962@postgrespro.ru", "phone": "+70839557030"}
0005434516048	4B2E9D	8041 157165	DMITRIY BARANOV	{"email": "baranov-d-071969@postgrespro.ru", "phone": "+70585376595"}
0005434516049	766E8E	3163 777839	GALINA DMITRIEVA	{"email": "g_dmitrieva1976@postgrespro.ru", "phone": "+70591616162"}
0005434516050	766E8E	2159 066550	VERONIKA MASLOVA	{"email": "maslova.veronika.081972@postgrespro.ru", "phone": "+70678823095"}
0005434516051	DF02CA	1317 917519	VIKTOR KAZAKOV	{"email": "viktor_kazakov-021971@postgrespro.ru", "phone": "+70898156489"}
0005434516052	DF02CA	2369 039487	OLEG KOZLOV	{"email": "kozlov.o29051967@postgrespro.ru", "phone": "+70670386105"}
0005434516053	BA2005	4883 239184	SVETLANA SIDOROVA	{"phone": "+70148433169"}
0005434516054	873821	1220 292440	OLGA KOZLOVA	{"email": "olgakozlova.1968@postgrespro.ru", "phone": "+70515609442"}
0005434516055	7E0EA0	6404 700324	GENNADIY KUZNECOV	{"phone": "+70145063424"}
0005434516056	7E0EA0	6476 691921	IGOR ZHURAVLEV	{"phone": "+70216112905"}
0005434516057	3893D6	0325 498500	ANDREY SOROKIN	{"phone": "+70227198331"}
0005434516058	4A1729	2344 953296	KONSTANTIN ALEKSEEV	{"email": "k.alekseev.011961@postgrespro.ru", "phone": "+70297872568"}
0005434516059	4A1729	1913 467396	DMITRIY FROLOV	{"email": "frolov.d_1971@postgrespro.ru", "phone": "+70966221050"}
0005434516060	8FFD05	9589 333861	DARYA EFREMOVA	{"email": "d_efremova_1977@postgrespro.ru", "phone": "+70064875896"}
0005434516061	C4FFEC	3877 553130	VALERIY CHERNOV	{"email": "chernov_valeriy.011976@postgrespro.ru", "phone": "+70052162299"}
0005434516062	5D524D	1205 252150	ILYA KOZLOV	{"phone": "+70341507422"}
0005434516063	0C418E	2713 125105	NADEZHDA PETROVA	{"phone": "+70640328207"}
0005434516064	986740	2806 121494	DANIL ZAKHAROV	{"phone": "+70525289130"}
0005434516065	31077C	8403 109065	ANDREY MARTYNOV	{"phone": "+70952791805"}
0005434516066	31077C	7710 928943	LIDIYA MEDVEDEVA	{"phone": "+70414062043"}
0005434516067	C692FD	9721 837664	SVETLANA ARKHIPOVA	{"phone": "+70046629643"}
0005434516068	C692FD	1722 822587	SERGEY PETROV	{"phone": "+70814704213"}
0005434516069	5BE43D	6986 867701	ELENA VASILEVA	{"email": "e.vasileva_17111971@postgrespro.ru", "phone": "+70109440058"}
0005434516070	40378F	6876 217887	OKSANA DANILOVA	{"email": "danilova_o02091978@postgrespro.ru", "phone": "+70040548500"}
0005434516071	40378F	5102 260856	ANDREY NIKITIN	{"phone": "+70066085758"}
0005434516072	58F1B9	3512 086599	DENIS IVANOV	{"phone": "+70928035052"}
0005434516073	58F1B9	0604 963867	DARYA SAVELEVA	{"email": "darya-saveleva_1963@postgrespro.ru", "phone": "+70987051821"}
0005434516074	1355B9	6681 525383	VLADISLAV NOVIKOV	{"email": "novikov_v26121976@postgrespro.ru", "phone": "+70716416675"}
0005434516075	1253E4	5111 080636	SERGEY PAVLOV	{"email": "pavlovs.061974@postgrespro.ru", "phone": "+70028366148"}
0005434516076	00A3E0	3891 473248	GULSINA SMIRNOVA	{"phone": "+70807179030"}
0005434516077	626DFB	6345 902378	ALEKSANDR BARANOV	{"email": "baranov.a.081985@postgrespro.ru", "phone": "+70237500820"}
0005434516078	FAE8A6	2740 984616	SERGEY MOROZOV	{"email": "morozov_s-1980@postgrespro.ru", "phone": "+70728780216"}
0005434516079	625722	6705 054977	MIKHAIL SEMENOV	{"email": "m_semenov-051976@postgrespro.ru", "phone": "+70440855608"}
0005434516080	2D97D3	0603 368331	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov-14091968@postgrespro.ru", "phone": "+70482479323"}
0005434516081	774078	0159 782273	DIANA POPOVA	{"email": "dianapopova1987@postgrespro.ru", "phone": "+70115291406"}
0005434516082	86D30B	5137 457251	NADEZHDA ZHUKOVA	{"phone": "+70399219752"}
0005434516083	35612D	8997 407942	NINA KAZAKOVA	{"email": "nina-kazakova_1979@postgrespro.ru", "phone": "+70068455458"}
0005434516084	B0DCEC	3788 965806	IRINA KUZNECOVA	{"phone": "+70699701485"}
0005434516085	B0DCEC	7263 552009	ANDREY KONOVALOV	{"email": "konovalov-andrey1977@postgrespro.ru", "phone": "+70138478593"}
0005434516086	9203DB	1141 924351	KRISTINA IVANOVA	{"email": "ivanova_kristina061971@postgrespro.ru", "phone": "+70518191004"}
0005434516087	9203DB	1780 058907	GALINA ABRAMOVA	{"email": "galina.abramova.29121969@postgrespro.ru", "phone": "+70337612243"}
0005434516088	29DD41	2112 188772	ELIZAVETA GUSEVA	{"phone": "+70076914377"}
0005434516089	4C660D	4250 899891	VALERIYA ROMANOVA	{"phone": "+70839226701"}
0005434516090	4C660D	9221 391709	ELENA VLASOVA	{"phone": "+70620235235"}
0005434516091	4C660D	3051 287653	KIRILL FEDOROV	{"email": "fedorov.kirill-071970@postgrespro.ru", "phone": "+70072076389"}
0005434516092	C2F809	1235 872716	VALENTINA MAKAROVA	{"phone": "+70555108382"}
0005434516093	993EAA	3297 585912	MARINA MAKAROVA	{"email": "marinamakarova.01011972@postgrespro.ru", "phone": "+70903880749"}
0005434516094	8FEDA1	3219 008208	VLADIMIR ILIN	{"email": "ilin-vladimir111974@postgrespro.ru", "phone": "+70001000199"}
0005434516095	621FE2	4769 160520	PAVEL BARANOV	{"email": "pavelbaranov_091965@postgrespro.ru", "phone": "+70831797715"}
0005434516096	9267CD	3043 576908	SERGEY MAKSIMOV	{"email": "sergeymaksimov-08111969@postgrespro.ru", "phone": "+70721752301"}
0005434516097	7E4B6A	2428 977536	LYUDMILA FADEEVA	{"phone": "+70210425439"}
0005434516098	7E4B6A	0785 240200	ALEKSEY KOZLOV	{"email": "kozlovaleksey.041967@postgrespro.ru", "phone": "+70612221281"}
0005434516099	9189D0	4490 439422	ALEKSANDRA TIKHONOVA	{"email": "tikhonova-aleksandra_12081951@postgrespro.ru", "phone": "+70194796109"}
0005434516100	9189D0	0773 034013	ALEKSEY BONDARENKO	{"email": "bondarenko_aleksey-13071980@postgrespro.ru", "phone": "+70780994839"}
0005434516101	8A604D	7287 400403	VALENTINA KUZNECOVA	{"phone": "+70532229318"}
0005434516102	DC7BDB	8710 548431	ELENA VOLKOVA	{"phone": "+70477061813"}
0005434516103	CD717B	5948 328056	TATYANA ALEKSANDROVA	{"email": "aleksandrova-tatyana01021971@postgrespro.ru", "phone": "+70451709226"}
0005434516104	0CDE73	2611 403648	NIKOLAY KISELEV	{"email": "kiselev_nikolay_121978@postgrespro.ru", "phone": "+70048663594"}
0005434516105	9FE303	4268 180271	SERGEY RODIONOV	{"phone": "+70704438264"}
0005434516106	79FBEA	7352 944280	ANATOLIY BARANOV	{"phone": "+70729538676"}
0005434516107	9BD083	1215 694837	TAMARA MAKAROVA	{"phone": "+70147038311"}
0005434516108	AE33CE	1100 223586	OLGA POPOVA	{"phone": "+70582959165"}
0005434516109	24B6EE	8136 676472	MAKSIM MAKAROV	{"email": "maksim.makarov.111962@postgrespro.ru", "phone": "+70670895282"}
0005434516110	023F88	0821 024509	IGOR SOKOLOV	{"phone": "+70722501268"}
0005434516111	023F88	7543 074647	MIKHAIL ALEKSANDROV	{"email": "aleksandrovm-1964@postgrespro.ru", "phone": "+70983146170"}
0005434516112	023F88	3010 764490	VLADIMIR KUZNECOV	{"phone": "+70908966181"}
0005434516113	BF7E11	8773 458106	ELENA YAKOVLEVA	{"phone": "+70821872152"}
0005434516114	B342B4	2836 222632	ALEKSEY SIDOROV	{"email": "sidorov-a-031974@postgrespro.ru", "phone": "+70071425593"}
0005434516115	EC038E	1092 010780	NATALYA ALEKSEEVA	{"email": "n-alekseeva-111966@postgrespro.ru", "phone": "+70545752169"}
0005434516116	1503A2	3159 540912	GENNADIY MATVEEV	{"email": "matveev_g_1971@postgrespro.ru", "phone": "+70252987757"}
0005434516117	F7364A	3297 196252	ELENA SMIRNOVA	{"email": "smirnova-elena_1970@postgrespro.ru", "phone": "+70084486906"}
0005434516118	ABAB36	2287 278420	OLEG KUZNECOV	{"phone": "+70965903204"}
0005434516119	6A7E86	7322 893191	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a-27111955@postgrespro.ru", "phone": "+70424769759"}
0005434516120	6A7E86	7397 115929	ANDREY TIMOFEEV	{"phone": "+70321813807"}
0005434516121	EFC5FC	6069 039435	ELENA KOROLEVA	{"email": "koroleva-elena-1976@postgrespro.ru", "phone": "+70236487556"}
0005434516122	D062C4	9991 511160	OKSANA GUSEVA	{"email": "guseva-o.01051977@postgrespro.ru", "phone": "+70515272155"}
0005434516123	D062C4	1909 536427	YULIYA TIMOFEEVA	{"email": "yuliyatimofeeva.041963@postgrespro.ru", "phone": "+70989960771"}
0005434516124	0DD474	3659 846230	NADEZHDA PAVLOVA	{"phone": "+70734247088"}
0005434516125	E75685	8687 011142	NATALIYA KUZNECOVA	{"phone": "+70671903373"}
0005434516126	CCB594	0974 381947	NIKITA ALEKSEEV	{"phone": "+70938640418"}
0005434516127	93C481	8461 718581	ARTUR IVANOV	{"email": "ivanov_a14081975@postgrespro.ru", "phone": "+70264357306"}
0005434516128	93C481	2638 457334	VENERA KOLESNIKOVA	{"email": "kolesnikova_v.05031979@postgrespro.ru", "phone": "+70079062181"}
0005434516129	063E4D	4314 633284	VIKTOR NAZAROV	{"phone": "+70681384944"}
0005434516130	AAA50E	5110 634779	ROMAN PETROV	{"email": "r.petrov_05021969@postgrespro.ru", "phone": "+70490150337"}
0005434516131	A6498E	4632 708757	VALENTINA VASILEVA	{"phone": "+70747978865"}
0005434516132	315436	2794 295523	MARINA ERMAKOVA	{"email": "marinaermakova-101983@postgrespro.ru", "phone": "+70377109786"}
0005434516133	BB46B3	0774 205031	ANDREY FILIPPOV	{"email": "andreyfilippov.29091973@postgrespro.ru", "phone": "+70404265233"}
0005434516134	3CECEA	6484 390957	OLGA MIRONOVA	{"email": "mironovao_031979@postgrespro.ru", "phone": "+70607394781"}
0005434516135	C3A9EB	9461 658030	ANTONINA YAKOVLEVA	{"email": "yakovleva_a-011974@postgrespro.ru", "phone": "+70586270483"}
0005434516136	6773AB	3491 969494	ANDREY NIKITIN	{"email": "nikitin.andrey16091961@postgrespro.ru", "phone": "+70321826206"}
0005434516137	6773AB	8150 842177	NADEZHDA GRISHINA	{"phone": "+70013841610"}
0005434516138	84A19D	0255 226752	SERGEY NAZAROV	{"email": "sergey.nazarov.121971@postgrespro.ru", "phone": "+70617174400"}
0005434516139	84A19D	6127 233333	LYUBOV NESTEROVA	{"phone": "+70077363395"}
0005434516140	45F129	6859 909267	VALENTINA MALYSHEVA	{"email": "valentinamalysheva.091970@postgrespro.ru", "phone": "+70192112081"}
0005434516141	F52515	6065 684393	YULIYA SCHERBAKOVA	{"phone": "+70508946859"}
0005434520126	802BBB	5949 680850	LYUDMILA DANILOVA	{"phone": "+70145419012"}
0005434520127	802BBB	4870 860216	SVETLANA FILATOVA	{"phone": "+70843894672"}
0005434520128	180178	5006 538094	LYUBOV FILATOVA	{"phone": "+70798040324"}
0005434520129	180178	2160 932135	TATYANA NIKITINA	{"email": "tatyana-nikitina091972@postgrespro.ru", "phone": "+70330987097"}
0005434520130	394198	3109 361285	ZINAIDA KUZNECOVA	{"email": "z_kuznecova_21101978@postgrespro.ru", "phone": "+70232507565"}
0005434520131	35D21C	6248 634669	ALEKSEY NIKITIN	{"phone": "+70835133857"}
0005434520132	F1D3EF	2310 871783	ANASTASIYA MALYSHEVA	{"phone": "+70915670862"}
0005434520133	E06DA1	7447 708964	ANNA ORLOVA	{"phone": "+70021204525"}
0005434520134	E06DA1	5912 460954	VIKTORIYA EFIMOVA	{"phone": "+70830444840"}
0005434520135	F767FF	2021 314825	ALEKSANDR ILIN	{"email": "aleksandr_ilin_1981@postgrespro.ru", "phone": "+70511337167"}
0005434520136	3DCC1A	6315 670966	DMITRIY ISAEV	{"email": "isaev-dmitriy031968@postgrespro.ru", "phone": "+70992282624"}
0005434520137	7341AE	4292 305827	VLADISLAV KUZNECOV	{"phone": "+70155545985"}
0005434520138	0F0DE2	3463 184346	ANATOLIY MOROZOV	{"email": "amorozov_1959@postgrespro.ru", "phone": "+70013485644"}
0005434520139	0F0DE2	5729 703156	ELENA KULIKOVA	{"phone": "+70754695786"}
0005434520140	6738CC	2179 186914	MAKSIM KARPOV	{"phone": "+70500294706"}
0005434520141	B62C5E	2009 130991	VASILIY TARASOV	{"email": "vasiliy_tarasov-1975@postgrespro.ru", "phone": "+70118481260"}
0005434520142	27B448	9032 606612	VARVARA VOLKOVA	{"phone": "+70671862157"}
0005434520143	AB898C	5017 790470	ROMAN MAKSIMOV	{"email": "roman.maksimov1970@postgrespro.ru", "phone": "+70011161404"}
0005434520144	517596	6656 310381	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.24021975@postgrespro.ru", "phone": "+70264527266"}
0005434520145	517596	6157 506843	SERGEY SOROKIN	{"phone": "+70008403245"}
0005434520146	949E60	0947 362867	MARIYA KOVALEVA	{"phone": "+70762718385"}
0005434520147	7700B3	8047 420759	RINAT MELNIKOV	{"email": "r-melnikov.1973@postgrespro.ru", "phone": "+70837565252"}
0005434520148	7700B3	2767 700177	YURIY SIDOROV	{"phone": "+70426070811"}
0005434520149	1B5F9D	9156 064833	IRINA FADEEVA	{"phone": "+70301330350"}
0005434520150	CDAAFD	5788 898723	NINA PETROVA	{"phone": "+70665911575"}
0005434520151	9D59A9	2211 046788	VALENTINA ALEKSEEVA	{"phone": "+70771589400"}
0005434520152	A895E2	5455 425231	KSENIYA DAVYDOVA	{"phone": "+70480969878"}
0005434520153	6E61F0	0451 713754	VIKTOR SHEVCHENKO	{"email": "shevchenkoviktor.23021977@postgrespro.ru", "phone": "+70480987158"}
0005434520154	6E61F0	7524 220823	MARGARITA KUDRYASHOVA	{"phone": "+70745398253"}
0005434520155	65409D	5923 606180	VALERIY ANTONOV	{"phone": "+70633540403"}
0005434520156	665753	6124 499947	ANATOLIY VLASOV	{"phone": "+70673397207"}
0005434520157	F9C5A5	1555 931135	VALENTINA ALEKSEEVA	{"phone": "+70175019132"}
0005434520158	E75662	9285 094724	ANNA CHERNOVA	{"email": "chernova_anna.28061971@postgrespro.ru", "phone": "+70501445909"}
0005434520159	E75662	0503 233238	IRINA VLASOVA	{"phone": "+70617143744"}
0005434520160	E69F47	4893 602112	VASILIY IVANOV	{"email": "vasiliy_ivanov-27121977@postgrespro.ru", "phone": "+70023650040"}
0005434520161	E69F47	5687 179567	MARINA KUZMINA	{"email": "m.kuzmina13041969@postgrespro.ru", "phone": "+70075480888"}
0005434520162	E69F47	1023 887322	IRINA MOROZOVA	{"email": "morozova-irina-26051972@postgrespro.ru", "phone": "+70396799134"}
0005434520163	6C573D	0536 469626	VALENTIN MAKAROV	{"phone": "+70246784346"}
0005434520164	6C573D	8851 647677	ELENA ZHURAVLEVA	{"email": "zhuravleva_e.081983@postgrespro.ru", "phone": "+70913001723"}
0005434520165	4E64BA	8020 727307	ROSTISLAV IVANOV	{"email": "ivanov-r_1972@postgrespro.ru", "phone": "+70024023892"}
0005434520166	415F71	7618 968648	VLADISLAV BELOV	{"email": "vladislav-belov.021983@postgrespro.ru", "phone": "+70080870724"}
0005434520167	415F71	5672 842042	OLGA KOLESNIKOVA	{"email": "kolesnikova.olga.011973@postgrespro.ru", "phone": "+70048824548"}
0005434520168	415F71	2622 052071	SERGEY MATVEEV	{"email": "matveev_s_071979@postgrespro.ru", "phone": "+70299657783"}
0005434520169	2CE7B7	7718 034356	SERGEY KUZNECOV	{"email": "s_kuznecov09011973@postgrespro.ru", "phone": "+70424418264"}
0005434520170	2CE7B7	7089 434592	ALEKSANDR BORISOV	{"email": "aborisov-03031967@postgrespro.ru", "phone": "+70502271132"}
0005434520171	634D73	8045 343200	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr_1965@postgrespro.ru", "phone": "+70573588644"}
0005434520172	E548D0	0984 903660	ILYA MAKAROV	{"phone": "+70197001426"}
0005434520173	E548D0	3913 430950	ELINA PETROVA	{"phone": "+70784206359"}
0005434520174	0476FB	9787 120517	ANDREY TIKHONOV	{"email": "tikhonova_28031972@postgrespro.ru", "phone": "+70108845120"}
0005434520175	07BC7A	2286 814004	SERGEY GERASIMOV	{"phone": "+70918584693"}
0005434520176	7131C5	5182 426629	MARTA KUZNECOVA	{"email": "marta_kuznecova_25091979@postgrespro.ru", "phone": "+70087179956"}
0005434520177	8CCC92	9687 911878	SVETLANA BELYAEVA	{"email": "svetlana_belyaeva_1968@postgrespro.ru", "phone": "+70124039224"}
0005434520178	0F0A14	7691 319808	SERGEY MOISEEV	{"email": "s.moiseev-11081960@postgrespro.ru", "phone": "+70808910367"}
0005434520179	0F0A14	3928 498604	ANNA IVANOVA	{"email": "a.ivanova.091978@postgrespro.ru", "phone": "+70526472026"}
0005434520180	95513C	1332 932506	OLGA SOLOVEVA	{"email": "olga.soloveva18021974@postgrespro.ru", "phone": "+70166622251"}
0005434520181	E54622	6210 719487	ALEKSANDRA IVANOVA	{"phone": "+70327997098"}
0005434520182	E54622	4707 143224	ANDREY SOLOVEV	{"phone": "+70035805020"}
0005434520183	E54622	7657 789968	OLGA SOLOVEVA	{"email": "olgasoloveva18011971@postgrespro.ru", "phone": "+70082971785"}
0005434520184	C556EE	5530 954982	VIKTOR KISELEV	{"email": "kiselev.viktor-10081961@postgrespro.ru", "phone": "+70986986038"}
0005434520185	C556EE	9185 440630	YULIYA NOVIKOVA	{"phone": "+70674709656"}
0005434520186	946278	9386 464013	IGOR DENISOV	{"email": "i-denisov_121974@postgrespro.ru", "phone": "+70772105553"}
0005434520187	BA2FA3	1361 959269	ANNA KOROLEVA	{"email": "a.koroleva03121966@postgrespro.ru", "phone": "+70528114485"}
0005434520188	379B66	5893 728544	NATALYA KONOVALOVA	{"email": "n_konovalova101969@postgrespro.ru", "phone": "+70785842723"}
0005434520189	E7BFDD	7748 386482	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav24061964@postgrespro.ru", "phone": "+70258271026"}
0005434520190	858A7E	3612 012374	ALEKSANDRA FEDOROVA	{"email": "fedorova-a-10041967@postgrespro.ru", "phone": "+70968537037"}
0005434520191	858A7E	3608 340433	IGOR IVANOV	{"email": "igor-ivanov-03121966@postgrespro.ru", "phone": "+70550904446"}
0005434520192	858A7E	3282 093135	IRINA OSIPOVA	{"email": "osipova.irina_1987@postgrespro.ru", "phone": "+70736148239"}
0005434520193	3D06B7	1766 231144	PAVEL BARANOV	{"email": "p.baranov.06031967@postgrespro.ru", "phone": "+70878452912"}
0005434520194	3D06B7	4775 073514	VERA PAVLOVA	{"phone": "+70740340309"}
0005434520195	2FE648	1012 848906	DMITRIY PAVLOV	{"phone": "+70765325721"}
0005434520315	5613A6	7791 769401	ALEKSEY SOKOLOV	{"phone": "+70371281599"}
0005434520196	F36540	2054 430500	KIRILL ABRAMOV	{"email": "abramov-kirill_111960@postgrespro.ru", "phone": "+70360789386"}
0005434520197	F36540	1082 086042	VLADIMIR MAKAROV	{"phone": "+70092098446"}
0005434520198	7783CC	0981 987634	VLADIMIR IVANOV	{"phone": "+70724159409"}
0005434520199	81BFD6	8908 364155	NINA ALEKSEEVA	{"email": "alekseevan_091980@postgrespro.ru", "phone": "+70910431733"}
0005434520200	314CF3	5568 610577	NINA BELOVA	{"email": "belova-n1987@postgrespro.ru", "phone": "+70918418619"}
0005434520201	314CF3	3002 015959	ARSENIY KONOVALOV	{"email": "konovalov.arseniy.1971@postgrespro.ru", "phone": "+70129596033"}
0005434520202	4A6F63	2894 889013	DENIS NAZAROV	{"phone": "+70331629814"}
0005434520203	869C05	8307 943312	TATYANA KALININA	{"phone": "+70427784686"}
0005434520204	869C05	4977 702759	VALENTINA MATVEEVA	{"phone": "+70719244556"}
0005434520205	47CE54	3529 352180	ELENA MAKSIMOVA	{"phone": "+70946843931"}
0005434520206	EBE1C1	3036 232282	INNA LEBEDEVA	{"phone": "+70169047750"}
0005434520207	EBE1C1	9900 598123	ARSENIY SCHERBAKOV	{"phone": "+70107597169"}
0005434520208	AAC851	9412 405581	VLADIMIR KONOVALOV	{"email": "konovalov.v_12051983@postgrespro.ru", "phone": "+70057010760"}
0005434520209	47B1AD	6910 731888	YULIYA MIKHAYLOVA	{"email": "mikhaylova-y.05051960@postgrespro.ru", "phone": "+70661739960"}
0005434520210	15CD3C	9842 946303	NINA ZAYCEVA	{"phone": "+70894164788"}
0005434520211	CDCADD	9958 569656	EKATERINA NIKIFOROVA	{"phone": "+70221920001"}
0005434520212	262864	6897 898228	OLEG IVANOV	{"phone": "+70027869548"}
0005434520213	FC725A	0084 789001	LIDIYA SOROKINA	{"email": "lidiyasorokina_041970@postgrespro.ru", "phone": "+70802060825"}
0005434520214	B8B7D6	2864 496846	LYUDMILA RYABOVA	{"email": "l-ryabova.021974@postgrespro.ru", "phone": "+70742163084"}
0005434520215	853707	5841 137924	VASILIY DAVYDOV	{"phone": "+70120706246"}
0005434520216	853707	0373 488469	ALEKSANDRA SIDOROVA	{"phone": "+70328486354"}
0005434520217	9B78B5	2533 528061	VALERIY ANDREEV	{"email": "valeriyandreev.111976@postgrespro.ru", "phone": "+70186284860"}
0005434520218	90B623	7748 108069	DMITRIY CHERNOV	{"email": "dmitriychernov091978@postgrespro.ru", "phone": "+70763363262"}
0005434520219	90B623	4594 135021	ANNA EGOROVA	{"email": "egorova_a-1975@postgrespro.ru", "phone": "+70887027060"}
0005434520220	98671C	4080 230854	OLGA GERASIMOVA	{"email": "gerasimovao.061979@postgrespro.ru", "phone": "+70626160814"}
0005434520221	98671C	0951 730128	VLADIMIR SCHERBAKOV	{"email": "scherbakov.vladimir041976@postgrespro.ru", "phone": "+70920149423"}
0005434520222	8339F6	5863 517892	PAVEL KAZAKOV	{"email": "kazakov_p.1973@postgrespro.ru", "phone": "+70576896147"}
0005434520223	310CF3	7235 369447	TATYANA BORISOVA	{"phone": "+70278905534"}
0005434520224	39672F	3180 439164	TATYANA ZAYCEVA	{"phone": "+70489639827"}
0005434520225	94F2D3	3616 740761	DENIS ZAYCEV	{"email": "deniszaycev.1971@postgrespro.ru", "phone": "+70465355040"}
0005434520226	94F2D3	9574 777095	ALEKSEY ZAKHAROV	{"phone": "+70402718339"}
0005434520227	59267F	7106 398924	OLGA BORISOVA	{"email": "olga_borisova-081976@postgrespro.ru", "phone": "+70465326905"}
0005434520228	DAC46F	0274 982994	VIKTORIYA SMIRNOVA	{"email": "smirnova-viktoriya-081966@postgrespro.ru", "phone": "+70026096602"}
0005434520229	EEB071	2227 036632	SEMEN MIRONOV	{"email": "semenmironov02121982@postgrespro.ru", "phone": "+70702986035"}
0005434520230	7E6A4B	4256 969460	EVGENIY NAZAROV	{"phone": "+70585564156"}
0005434520231	7E6A4B	9574 327053	VYACHESLAV GAVRILOV	{"email": "gavrilov-vyacheslav15051965@postgrespro.ru", "phone": "+70026641482"}
0005434520232	1FF256	3842 348396	MARINA SEMENOVA	{"phone": "+70797670402"}
0005434520233	1FF256	8260 724399	TATYANA NAZAROVA	{"email": "tatyana_nazarova_1975@postgrespro.ru", "phone": "+70479398519"}
0005434520234	BE9282	9759 166004	VIKTORIYA NAUMOVA	{"email": "naumova-viktoriya-1969@postgrespro.ru", "phone": "+70901202173"}
0005434520235	08859B	4272 843444	LYUDMILA MIRONOVA	{"phone": "+70010222887"}
0005434520236	E7C90A	7985 517643	SVETLANA KUZMINA	{"phone": "+70102116733"}
0005434520237	E7C90A	5445 201078	ALEKSANDR MIKHAYLOV	{"phone": "+70986995080"}
0005434520238	F9D765	2046 921199	OLGA KOROLEVA	{"email": "olga-koroleva_081984@postgrespro.ru", "phone": "+70172914969"}
0005434520239	F9D765	9155 979041	ANVAR IVANOV	{"email": "ivanov-anvar-21111977@postgrespro.ru", "phone": "+70395591857"}
0005434520240	CEE884	0089 284309	VIKTOR VOLKOV	{"email": "volkov.viktor-18051977@postgrespro.ru", "phone": "+70076818668"}
0005434520241	CEE884	2371 028608	YULIYA NIKITINA	{"email": "nikitina.y_1976@postgrespro.ru", "phone": "+70117712938"}
0005434520242	A8F110	0798 699802	VALERIY DMITRIEV	{"email": "v-dmitriev_051979@postgrespro.ru", "phone": "+70694466492"}
0005434520243	5B7AEA	1928 048569	VALENTINA GORBUNOVA	{"phone": "+70818577831"}
0005434520244	5B7AEA	2327 658487	IRINA VASILEVA	{"email": "vasileva-irina-1963@postgrespro.ru", "phone": "+70266235518"}
0005434520245	764916	3340 521330	ELENA SOROKINA	{"email": "sorokina_elena_30121974@postgrespro.ru", "phone": "+70090133311"}
0005434520246	1FF295	8820 973074	FEDOR KONOVALOV	{"phone": "+70743380309"}
0005434520247	848947	5005 616021	NATALIYA NOVIKOVA	{"email": "nataliya.novikova_17081958@postgrespro.ru", "phone": "+70022131474"}
0005434520248	FAD04E	9971 087014	VIKTORIYA POPOVA	{"email": "viktoriya.popova-22071978@postgrespro.ru", "phone": "+70820804746"}
0005434520249	FAD04E	4358 497367	ANNA DANILOVA	{"phone": "+70995358621"}
0005434520250	C7432D	5617 464041	MARIYA SAVELEVA	{"phone": "+70241314028"}
0005434520251	1110D7	3486 032453	EKATERINA KONOVALOVA	{"phone": "+70238137004"}
0005434520252	1929AD	5237 870545	ELENA IVANOVA	{"email": "e.ivanova_121964@postgrespro.ru", "phone": "+70438872603"}
0005434520253	EFFBE3	7780 088676	LIDIYA DAVYDOVA	{"phone": "+70677887448"}
0005434520254	EFFBE3	8384 438338	EKATERINA KOROLEVA	{"phone": "+70220204730"}
0005434520255	187870	8035 565130	ROMAN FEDOTOV	{"email": "roman_fedotov-041968@postgrespro.ru", "phone": "+70365785957"}
0005434520256	DA7B7C	7526 345335	ALEKSEY GAVRILOV	{"email": "aleksey-gavrilov-1963@postgrespro.ru", "phone": "+70987685874"}
0005434520257	E79305	9778 567749	ANATOLIY ANTONOV	{"phone": "+70241899349"}
0005434520258	A38C00	0904 075956	IVAN RODIONOV	{"phone": "+70306608410"}
0005434520259	BADDE4	8105 352837	GALINA TARASOVA	{"phone": "+70876298819"}
0005434520260	BADDE4	1277 028386	LYUDMILA SCHERBAKOVA	{"email": "scherbakoval1977@postgrespro.ru", "phone": "+70825816952"}
0005434520261	BADDE4	8248 606561	ANASTASIYA MOISEEVA	{"phone": "+70105828392"}
0005434520262	F7D8D1	5506 085376	MIKHAIL GUSEV	{"email": "gusevm18091968@postgrespro.ru", "phone": "+70828218491"}
0005434520263	F7D8D1	9519 577855	ILYA FOMIN	{"email": "i-fomin_1973@postgrespro.ru", "phone": "+70541820767"}
0005434520264	FE9D80	7037 531970	IVAN PETROV	{"phone": "+70982450875"}
0005434520265	3B3149	7665 778536	SOFIYA ALEKSANDROVA	{"email": "s.aleksandrova_05011964@postgrespro.ru", "phone": "+70189401036"}
0005434520266	27BE93	0965 359009	OLGA NIKITINA	{"phone": "+70475736470"}
0005434520267	27BE93	2175 683652	IRINA TIMOFEEVA	{"phone": "+70429169379"}
0005434520268	70FC9D	5186 358633	VIKTORIYA NOVIKOVA	{"email": "viktoriyanovikova.041983@postgrespro.ru", "phone": "+70301108393"}
0005434520269	70FC9D	3653 452862	SVETLANA ROMANOVA	{"email": "svetlanaromanova-19111965@postgrespro.ru", "phone": "+70297792247"}
0005434520270	CD3378	5888 262739	VALENTINA OSIPOVA	{"email": "osipova.v_29091966@postgrespro.ru", "phone": "+70740334826"}
0005434520271	CD3378	4551 507798	ELENA NIKITINA	{"email": "nikitina.e.1980@postgrespro.ru", "phone": "+70141998684"}
0005434520272	31C0D3	6387 513882	TAMARA SOKOLOVA	{"email": "sokolova-tamara_071973@postgrespro.ru", "phone": "+70920206808"}
0005434520273	F5825E	3225 243621	VERA NIKOLAEVA	{"email": "nikolaeva_vera17051970@postgrespro.ru", "phone": "+70597577163"}
0005434520274	8D6415	1755 298747	IVAN BORISOV	{"email": "borisov.ivan-111970@postgrespro.ru", "phone": "+70010673635"}
0005434520275	8D6415	6346 714721	KIRILL DMITRIEV	{"email": "dmitriev-k_28111973@postgrespro.ru", "phone": "+70304573648"}
0005434520276	1AD76D	2281 083429	DENIS KUZNECOV	{"phone": "+70984335437"}
0005434520277	5B2263	2127 806856	VERA KAZAKOVA	{"phone": "+70266204168"}
0005434520278	5B2263	4894 642326	OKSANA EGOROVA	{"phone": "+70784397868"}
0005434520279	23AAD4	9302 431015	ELENA ANTONOVA	{"phone": "+70208817381"}
0005434520280	FEC36B	0044 594138	MAKSIM TARASOV	{"phone": "+70386192654"}
0005434520281	FEC36B	8760 848084	ALEKSANDR DENISOV	{"email": "denisov_a.021968@postgrespro.ru", "phone": "+70357549200"}
0005434520282	FA2AEC	7554 610315	MATVEY SHEVCHENKO	{"email": "m-shevchenko_051976@postgrespro.ru", "phone": "+70225389649"}
0005434520283	FA2AEC	5425 498992	POLINA ROMANOVA	{"phone": "+70100247168"}
0005434520284	053A1A	3303 622791	STANISLAV ABRAMOV	{"email": "abramov-stanislav_01081965@postgrespro.ru", "phone": "+70486977212"}
0005434520285	9B8C00	9959 795509	OKSANA SERGEEVA	{"email": "sergeeva_oksana071967@postgrespro.ru", "phone": "+70449541319"}
0005434520286	31A797	1083 467563	KLAVDIYA ALEKSANDROVA	{"phone": "+70668581375"}
0005434520287	6ED8FA	3907 858105	GALINA KRASNOVA	{"email": "gkrasnova.22071978@postgrespro.ru", "phone": "+70860905330"}
0005434520288	6ED8FA	8013 471500	SVETLANA KOLESNIKOVA	{"phone": "+70075093938"}
0005434520289	9FDB82	7945 041251	ELIZAVETA SOKOLOVA	{"email": "esokolova-101967@postgrespro.ru", "phone": "+70837367199"}
0005434520290	4A506D	7448 475397	KRISTINA MOROZOVA	{"email": "morozovakristina.1987@postgrespro.ru", "phone": "+70093179874"}
0005434520291	B5C29E	5536 056040	VLADIMIR SIDOROV	{"email": "sidorovvladimir_081981@postgrespro.ru", "phone": "+70675520979"}
0005434520292	934429	0954 365414	DARYA NOVIKOVA	{"email": "novikova.d-051976@postgrespro.ru", "phone": "+70330015710"}
0005434520293	934429	1428 819092	OLEG MIKHAYLOV	{"phone": "+70260122646"}
0005434520294	273CED	1081 643049	NINA PAVLOVA	{"phone": "+70024924676"}
0005434520295	273CED	0373 896685	YANA MIKHAYLOVA	{"email": "yana_mikhaylova.1975@postgrespro.ru", "phone": "+70061781303"}
0005434520296	50A673	5199 739007	PAVEL MOISEEV	{"email": "moiseev.pavel27081979@postgrespro.ru", "phone": "+70887864299"}
0005434520297	50A673	5392 243666	GALINA MIKHAYLOVA	{"email": "mikhaylova.g_021962@postgrespro.ru", "phone": "+70316586869"}
0005434520298	50A673	4465 687159	ANNA KRASNOVA	{"email": "anna_krasnova_17111977@postgrespro.ru", "phone": "+70833439908"}
0005434520299	945117	0146 932927	VIKTORIYA VOLKOVA	{"phone": "+70907484109"}
0005434520300	945117	1305 746569	ELENA LEBEDEVA	{"email": "elena-lebedeva-111962@postgrespro.ru", "phone": "+70646594304"}
0005434520301	02F8D0	0823 783254	IGOR FEDOROV	{"email": "i-fedorov111974@postgrespro.ru", "phone": "+70538884771"}
0005434520302	02F8D0	4455 087854	KSENIYA BORISOVA	{"phone": "+70893132456"}
0005434520303	741328	7634 170666	ROMAN AFANASEV	{"phone": "+70288122168"}
0005434520304	68A710	7354 939047	VITALIY BONDARENKO	{"phone": "+70618502462"}
0005434520305	68A710	1552 190621	YURIY KARPOV	{"email": "yuriy.karpov.1969@postgrespro.ru", "phone": "+70319332748"}
0005434520306	D37904	0367 576787	TATYANA SEMENOVA	{"phone": "+70467229018"}
0005434520307	F5CEF1	5888 518726	SVETLANA ANISIMOVA	{"email": "anisimova-svetlana-1969@postgrespro.ru", "phone": "+70457031480"}
0005434520308	684E19	5111 414014	LYUDMILA SCHERBAKOVA	{"email": "lyudmila-scherbakova_1978@postgrespro.ru", "phone": "+70216350197"}
0005434520309	CDAECB	6464 455483	ALEKSANDR KUZNECOV	{"email": "akuznecov101975@postgrespro.ru", "phone": "+70864009843"}
0005434520310	408D12	8960 974126	PAVEL BORISOV	{"email": "borisov.pavel-1977@postgrespro.ru", "phone": "+70209593071"}
0005434520311	56F5E7	1169 881323	VALENTINA VASILEVA	{"phone": "+70179624987"}
0005434520312	9E0A29	4680 387432	NINA NESTEROVA	{"phone": "+70732159167"}
0005434520313	C75D02	6085 535628	MARINA FILATOVA	{"email": "filatova_m_28021975@postgrespro.ru", "phone": "+70236461651"}
0005434520314	6901CD	0523 377269	ALEKSEY ZAKHAROV	{"phone": "+70952697531"}
0005434520316	9B17E6	3538 685456	ANNA DENISOVA	{"email": "denisovaanna_121970@postgrespro.ru", "phone": "+70982671279"}
0005434520317	6633EC	2616 926469	OLGA MAKAROVA	{"phone": "+70793444981"}
0005434520318	6633EC	9381 173269	EVGENIY ROMANOV	{"phone": "+70488032872"}
0005434520319	6633EC	5885 506365	DENIS DAVYDOV	{"email": "davydov-denis_1957@postgrespro.ru", "phone": "+70646169226"}
0005434520320	FDBE1F	7564 220927	IRINA KUZMINA	{"email": "irinakuzmina1963@postgrespro.ru", "phone": "+70717000991"}
0005434520321	F318B2	9898 274558	SVETLANA KISELEVA	{"email": "s.kiseleva111977@postgrespro.ru", "phone": "+70683546276"}
0005434520322	F318B2	4790 390414	ILYA KOZLOV	{"email": "kozlov.i_03021967@postgrespro.ru", "phone": "+70639150446"}
0005434520323	611B82	7057 492200	IRAIDA KOROLEVA	{"phone": "+70507245542"}
0005434520324	41F811	0940 276703	IRAIDA PETROVA	{"email": "petrova-iraida_21111971@postgrespro.ru", "phone": "+70499556872"}
0005434520325	11FE1E	7550 215268	SVETLANA KUZMINA	{"email": "svetlana-kuzmina_29031957@postgrespro.ru", "phone": "+70868506056"}
0005434520326	1BBF1B	2795 511799	FEDOR ILIN	{"email": "fedor_ilin_111974@postgrespro.ru", "phone": "+70415756892"}
0005434520327	B8EA50	3846 485157	YULIYA BOGDANOVA	{"phone": "+70131272903"}
0005434520328	B8EA50	0929 694899	NATALYA TITOVA	{"email": "ntitova1979@postgrespro.ru", "phone": "+70373125866"}
0005434520329	11A9F6	5136 534882	IVAN KISELEV	{"email": "ivan.kiselev.101968@postgrespro.ru", "phone": "+70250847657"}
0005434520330	11A9F6	4791 590485	TAMARA KOLESNIKOVA	{"phone": "+70496477471"}
0005434520331	3D90C4	9093 853658	NINA VOLKOVA	{"phone": "+70162146634"}
0005434520332	CC45F3	3089 769800	DMITRIY STEPANOV	{"email": "d.stepanov05111956@postgrespro.ru", "phone": "+70183143484"}
0005434520333	CC45F3	2908 545246	ANATOLIY TIMOFEEV	{"email": "timofeev.a_031978@postgrespro.ru", "phone": "+70226105039"}
0005434520334	B5F09A	6041 425752	VYACHESLAV ZAKHAROV	{"phone": "+70046173271"}
0005434520335	0B95E9	5037 495266	NATALYA ANISIMOVA	{"phone": "+70466883711"}
0005434520336	25A4A5	3737 935557	ANTON NAZAROV	{"email": "a_nazarov-09051971@postgrespro.ru", "phone": "+70837274637"}
0005434520337	55058B	8292 418296	ANASTASIYA ERMAKOVA	{"email": "ermakova.anastasiya.081978@postgrespro.ru", "phone": "+70314205529"}
0005434520338	55058B	7910 039770	MILENA ARKHIPOVA	{"phone": "+70668601113"}
0005434520339	95746F	3805 303946	ELENA POPOVA	{"email": "popova.elena1983@postgrespro.ru", "phone": "+70162074530"}
0005434520340	95746F	0835 209043	PAVEL FOMIN	{"email": "pfomin.041971@postgrespro.ru", "phone": "+70994551812"}
0005434520341	100C48	2184 277142	ANDREY NAUMOV	{"email": "naumova_15041979@postgrespro.ru", "phone": "+70897636686"}
0005434520342	100C48	8899 983645	OLGA NIKITINA	{"phone": "+70509450321"}
0005434520343	E7121B	0493 164804	IRINA FILIPPOVA	{"phone": "+70156571373"}
0005434520344	E7121B	0580 434947	SERGEY GERASIMOV	{"phone": "+70515677386"}
0005434520345	540E7F	9151 547940	SERGEY IVANOV	{"phone": "+70653754943"}
0005434520346	C1434E	3563 203722	KIRILL SAVELEV	{"email": "k_savelev1976@postgrespro.ru", "phone": "+70641852459"}
0005434520347	C1434E	9784 922426	ALEKSEY SCHERBAKOV	{"phone": "+70370693466"}
0005434520348	A05086	8781 430289	ALEFTINA KARPOVA	{"phone": "+70242151512"}
0005434520349	35D5F5	7543 263561	VALERIYA MATVEEVA	{"phone": "+70256660220"}
0005434520350	852521	8509 785258	NIKITA KOZLOV	{"email": "kozlovnikita28021972@postgrespro.ru", "phone": "+70805845036"}
0005434520351	61C884	4925 892493	OLGA ARKHIPOVA	{"email": "olga.arkhipova_091966@postgrespro.ru", "phone": "+70589305586"}
0005434520352	61C884	6992 349471	TAMARA POPOVA	{"phone": "+70841347460"}
0005434520353	8276E9	9109 500477	VASILIY SCHERBAKOV	{"email": "scherbakovv25111972@postgrespro.ru", "phone": "+70432746267"}
0005434520354	099855	0724 653701	LIDIYA IVANOVA	{"email": "l.ivanova19081971@postgrespro.ru", "phone": "+70398158490"}
0005434520355	336C6A	3883 551471	TATYANA MAKAROVA	{"phone": "+70699107172"}
0005434520356	336C6A	5128 207710	VLADISLAV SAVELEV	{"phone": "+70245222667"}
0005434520357	4EFA6E	9522 913588	IVAN ABRAMOV	{"email": "iabramov_14081969@postgrespro.ru", "phone": "+70066626741"}
0005434520358	049E06	0761 154589	RAVIL KOZLOV	{"phone": "+70514203784"}
0005434520359	34D63D	8848 606830	NATALYA SOKOLOVA	{"email": "natalya_sokolova_1972@postgrespro.ru", "phone": "+70031167731"}
0005434520360	548A1E	9662 051777	TAMARA MOROZOVA	{"email": "t.morozova.09111979@postgrespro.ru", "phone": "+70299321974"}
0005434520361	548A1E	7458 543961	ALEKSEY SHEVCHENKO	{"email": "aleksey-shevchenko.08101981@postgrespro.ru", "phone": "+70996068788"}
0005434520362	78EE8D	7901 455667	SERGEY ANDREEV	{"email": "sergeyandreev-031974@postgrespro.ru", "phone": "+70487817918"}
0005434520363	B28DD3	5219 822326	IGOR POPOV	{"phone": "+70073180251"}
0005434520364	11C43F	6998 436700	KONSTANTIN GAVRILOV	{"email": "gavrilov-konstantin-07081968@postgrespro.ru", "phone": "+70882166355"}
0005434520365	11C43F	8532 995304	IRINA SERGEEVA	{"phone": "+70051183194"}
0005434520366	DEFCCA	1369 231146	PAVEL PETROV	{"phone": "+70615706276"}
0005434520367	78E828	4734 775919	LEONID NOVIKOV	{"phone": "+70965268157"}
0005434520368	430819	9138 852831	ANGELINA KOZLOVA	{"email": "kozlovaangelina.1965@postgrespro.ru", "phone": "+70991322132"}
0005434520369	31CD72	0709 124840	LARISA KUZNECOVA	{"phone": "+70196191166"}
0005434520370	31CD72	9769 329237	YANA PAVLOVA	{"email": "yana.pavlova1968@postgrespro.ru", "phone": "+70989469243"}
0005434520371	C6ABB2	8043 824081	SVETLANA CHERNOVA	{"email": "svetlana_chernova_041959@postgrespro.ru", "phone": "+70861963931"}
0005434520372	C6ABB2	6845 582996	YURIY KAZAKOV	{"phone": "+70564427068"}
0005434520373	AC8B1E	7121 071880	TATYANA IVANOVA	{"phone": "+70490835663"}
0005434520374	2ABBBB	4196 796237	IRINA NIKOLAEVA	{"phone": "+70431894744"}
0005434520375	2ABBBB	8494 685405	MARINA ZAKHAROVA	{"email": "zakharova.marina-041971@postgrespro.ru", "phone": "+70945432985"}
0005434520376	AF7B4F	9632 448732	ANASTASIYA STEPANOVA	{"email": "anastasiya_stepanova1974@postgrespro.ru", "phone": "+70141960683"}
0005434520377	18126E	9562 512705	VITALIY ANTONOV	{"email": "v_antonov091978@postgrespro.ru", "phone": "+70661757928"}
0005434520378	6977F3	8682 980436	ANZHELA STEPANOVA	{"email": "stepanovaa.121976@postgrespro.ru", "phone": "+70011873365"}
0005434520379	D754DB	0562 413393	ELLA MAKAROVA	{"email": "makarova.ella081976@postgrespro.ru", "phone": "+70456816037"}
0005434520380	D523C7	7028 108621	ANNA FROLOVA	{"email": "annafrolova_23081964@postgrespro.ru", "phone": "+70473920494"}
0005434520381	383FE4	3373 709513	MIKHAIL KUZNECOV	{"phone": "+70515104906"}
0005434520382	0E5540	5172 441918	VLADIMIR PAVLOV	{"email": "v.pavlov_061968@postgrespro.ru", "phone": "+70156027205"}
0005434520383	7EB1CE	2946 296062	ANDREY ZAKHAROV	{"email": "zakharov_a_1974@postgrespro.ru", "phone": "+70461401061"}
0005434520384	3D2FE0	0613 311120	MIKHAIL BELOV	{"email": "belov-m031972@postgrespro.ru", "phone": "+70795991796"}
0005434520385	A38C3C	3843 653569	ALEKSEY BARANOV	{"email": "baranov-a_14091967@postgrespro.ru", "phone": "+70050210694"}
0005434520386	EB9F81	8032 373896	ALEKSANDR SOKOLOV	{"phone": "+70330229287"}
0005434520387	57194B	9339 189191	SERGEY KRASNOV	{"phone": "+70277457368"}
0005434520388	F37CBC	6603 528341	ANASTASIYA PETROVA	{"phone": "+70736023737"}
0005434520389	638100	0159 312391	SVETLANA IVANOVA	{"email": "svetlana_ivanova.17031968@postgrespro.ru", "phone": "+70500179517"}
0005434520390	F3B6B7	8516 224710	TATYANA SOKOLOVA	{"email": "tatyana-sokolova-08101967@postgrespro.ru", "phone": "+70739857626"}
0005434520391	F3B6B7	0687 526246	OLEG MOISEEV	{"email": "olegmoiseev-16111963@postgrespro.ru", "phone": "+70518398715"}
0005434520392	A46171	1605 765965	MARIYA NESTEROVA	{"email": "nesterovam031984@postgrespro.ru", "phone": "+70913228562"}
0005434520393	182EFA	0321 418992	EKATERINA MARTYNOVA	{"email": "ekaterina.martynova.1973@postgrespro.ru", "phone": "+70350186913"}
0005434520394	F10150	2494 608221	EKATERINA POPOVA	{"phone": "+70444202161"}
0005434520395	F10150	5707 939109	VYACHESLAV MOROZOV	{"phone": "+70632932339"}
0005434520396	4C4B8B	5879 663159	VLADIMIR MOROZOV	{"email": "vladimir-morozov051977@postgrespro.ru", "phone": "+70369795072"}
0005434520397	EAE548	5929 848600	ALEKSANDR GORBUNOV	{"phone": "+70136762761"}
0005434520398	D4FDAE	9773 252746	SVETLANA NESTEROVA	{"email": "nesterova-svetlana-121979@postgrespro.ru", "phone": "+70545080719"}
0005434520399	796BC2	5131 285955	VLADIMIR ALEKSEEV	{"email": "vladimiralekseev-11041975@postgrespro.ru", "phone": "+70997605932"}
0005434520400	796BC2	2844 398286	TATYANA AFANASEVA	{"email": "afanaseva-tatyana_22101967@postgrespro.ru", "phone": "+70558341830"}
0005434520401	B67434	2636 743884	EVDOKIYA IVANOVA	{"email": "e_ivanova.1974@postgrespro.ru", "phone": "+70845797147"}
0005434520402	67975D	1554 622789	MARINA AFANASEVA	{"email": "afanaseva-marina-1959@postgrespro.ru", "phone": "+70338974994"}
0005434520403	6CDDF3	4612 551611	LYUDMILA MAKAROVA	{"email": "makarova_l-121967@postgrespro.ru", "phone": "+70284121292"}
0005434520404	425000	7774 438689	IGOR PETROV	{"email": "petrov-igor-1970@postgrespro.ru", "phone": "+70286580219"}
0005434520405	382843	7228 413817	VALENTINA MATVEEVA	{"email": "matveeva.v1973@postgrespro.ru", "phone": "+70950534847"}
0005434520406	DA3202	8142 346710	SERGEY KOROLEV	{"phone": "+70561462778"}
0005434520407	DA3202	4198 876765	GENNADIY SMIRNOV	{"email": "gennadiy.smirnov.011969@postgrespro.ru", "phone": "+70806778059"}
0005434520408	7CC98E	6963 725972	ANATOLIY MAKAROV	{"phone": "+70033020906"}
0005434520409	83EF2A	0618 446054	IRINA MIKHAYLOVA	{"phone": "+70897617567"}
0005434520410	28E7DC	3432 201035	MARGARITA MAKAROVA	{"phone": "+70956022514"}
0005434520411	FB4077	8510 572495	ANNA FILATOVA	{"email": "afilatova.21011975@postgrespro.ru", "phone": "+70402318298"}
0005434520412	FB4077	2646 638237	YURIY KOROLEV	{"email": "korolev_y12011973@postgrespro.ru", "phone": "+70746065967"}
0005434520413	069E2C	6563 508788	TATYANA FADEEVA	{"phone": "+70428301011"}
0005434520414	3A7D74	2698 204170	IGOR KOZLOV	{"email": "kozlov_i.021969@postgrespro.ru", "phone": "+70615466014"}
0005434520415	3A7D74	8081 422104	ALEKSANDR VLASOV	{"email": "a-vlasov_111972@postgrespro.ru", "phone": "+70228151924"}
0005434520416	E83295	9553 657759	VALERIY OSIPOV	{"email": "valeriy-osipov10041975@postgrespro.ru", "phone": "+70389801454"}
0005434520417	7BB36C	1730 798445	ANDREY GUSEV	{"email": "gusev.a.30061964@postgrespro.ru", "phone": "+70953776433"}
0005434520418	AC3B8A	2695 765185	NATALYA KOVALEVA	{"phone": "+70159014914"}
0005434520419	59A191	7794 301435	EKATERINA EGOROVA	{"phone": "+70927774126"}
0005434520420	D06F14	8741 700111	ALEKSEY POPOV	{"email": "a.popov-021975@postgrespro.ru", "phone": "+70485006616"}
0005434520421	DBE5A9	5197 705680	STEPAN AFANASEV	{"email": "afanasevstepan-111977@postgrespro.ru", "phone": "+70360790829"}
0005434520422	DBE5A9	9369 014639	TATYANA KRASNOVA	{"email": "tatyanakrasnova.1964@postgrespro.ru", "phone": "+70144566759"}
0005434520423	798DD8	5753 758214	OLGA ANTONOVA	{"phone": "+70232171962"}
0005434520424	B7CE02	7818 373168	EKATERINA SEMENOVA	{"phone": "+70937175771"}
0005434520425	54957D	9714 501753	ANATOLIY POPOV	{"email": "apopov_101968@postgrespro.ru", "phone": "+70704261087"}
0005434520426	E70004	1375 852706	YURIY FROLOV	{"email": "frolov.y.1971@postgrespro.ru", "phone": "+70620291883"}
0005434520427	876082	7860 348979	TATYANA KOROLEVA	{"email": "t_koroleva-15081966@postgrespro.ru", "phone": "+70376704188"}
0005434520428	779F2C	6676 924037	TATYANA FEDOROVA	{"email": "tatyana_fedorova-1970@postgrespro.ru", "phone": "+70785827338"}
0005434520429	779F2C	1293 705131	SERGEY BELOV	{"email": "s_belov.091976@postgrespro.ru", "phone": "+70912381564"}
0005434520430	EECD20	9841 051594	VLADISLAV OSIPOV	{"phone": "+70389558116"}
0005434520431	EECD20	1400 901788	NIKOLAY STEPANOV	{"email": "n_stepanov_1977@postgrespro.ru", "phone": "+70340323397"}
0005434520432	F86DA7	4608 831219	MARAT FEDOTOV	{"phone": "+70080831873"}
0005434520433	47751E	4984 836371	OLGA ZHUKOVA	{"email": "ozhukova_01051970@postgrespro.ru", "phone": "+70082660921"}
0005434520434	47751E	0155 834737	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov1969@postgrespro.ru", "phone": "+70756590663"}
0005434520435	89FF4B	4800 784564	TATYANA KULIKOVA	{"email": "kulikova-t-28061965@postgrespro.ru", "phone": "+70942477830"}
0005434520436	5E1416	6014 110519	NELLI SMIRNOVA	{"phone": "+70021511528"}
0005434520437	421EB7	0100 062529	ALEKSANDR EGOROV	{"phone": "+70058189990"}
0005434520438	421EB7	5473 896074	ELENA KOZLOVA	{"phone": "+70162709521"}
0005434520439	1E9B1B	3065 583987	LYUDMILA LAZAREVA	{"email": "lazareva_l_09021977@postgrespro.ru", "phone": "+70451755524"}
0005434520440	B43CAD	8111 472450	MIKHAIL KUZNECOV	{"phone": "+70674703667"}
0005434520441	DF7408	1768 095385	ANTON KUDRYASHOV	{"email": "a.kudryashov_13111977@postgrespro.ru", "phone": "+70799818922"}
0005434520442	DF7408	4075 944895	ANATOLIY PETROV	{"email": "anatoliy.petrov_03101970@postgrespro.ru", "phone": "+70270510674"}
0005434520443	C36E89	3670 294848	VALERIYA VOROBEVA	{"email": "v.vorobeva_091984@postgrespro.ru", "phone": "+70119130207"}
0005434520444	890741	5845 164611	DMITRIY FROLOV	{"phone": "+70670420092"}
0005434520445	890741	8286 119783	VYACHESLAV MOROZOV	{"email": "v-morozov-10041973@postgrespro.ru", "phone": "+70734142188"}
0005434520446	155554	3491 915681	OLGA IVANOVA	{"email": "oivanova31081975@postgrespro.ru", "phone": "+70285818132"}
0005434520447	155554	9961 026215	MARIYA VASILEVA	{"email": "vasileva-m.24061963@postgrespro.ru", "phone": "+70494200417"}
0005434520448	3C619F	1622 988394	VIKTORIYA RODIONOVA	{"phone": "+70775539441"}
0005434520449	494591	0181 975294	ANNA VASILEVA	{"email": "a-vasileva-081966@postgrespro.ru", "phone": "+70893927960"}
0005434520450	F25D57	8985 470278	SVETLANA ROMANOVA	{"email": "s-romanova031985@postgrespro.ru", "phone": "+70228871619"}
0005434520451	776402	9819 277736	VLADIMIR KUDRYASHOV	{"email": "v.kudryashov061984@postgrespro.ru", "phone": "+70297889737"}
0005434520452	776402	8796 317924	GENNADIY IVANOV	{"email": "gennadiyivanov091977@postgrespro.ru", "phone": "+70414384078"}
0005434520453	237BC6	6407 865553	SERGEY VASILEV	{"phone": "+70881232256"}
0005434520454	237BC6	5593 056518	ELENA ALEKSANDROVA	{"phone": "+70338467874"}
0005434520455	39FBC1	5642 949785	NADEZHDA KOZLOVA	{"email": "nadezhda_kozlova.1965@postgrespro.ru", "phone": "+70409705215"}
0005434520456	81C09D	2727 315672	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey12111975@postgrespro.ru", "phone": "+70230548267"}
0005434520457	115F0F	0498 537011	LYUBOV EFIMOVA	{"email": "efimova.lyubov-031976@postgrespro.ru", "phone": "+70977702065"}
0005434520458	136025	3202 392682	KRISTINA ZHUKOVA	{"email": "zhukova.kristina.121977@postgrespro.ru", "phone": "+70113717394"}
0005434520459	E29568	0675 801911	GENNADIY MAKSIMOV	{"phone": "+70751888748"}
0005434520460	A48A15	9887 830508	ANATOLIY BELOV	{"email": "anatoliybelov-1976@postgrespro.ru", "phone": "+70666936165"}
0005434520461	A48A15	6679 222566	ALEKSANDR CHERNOV	{"phone": "+70157221176"}
0005434520462	613B4B	0900 975546	ALEKSANDR DMITRIEV	{"phone": "+70986530688"}
0005434520463	613B4B	6520 049395	KLAVDIYA SEMENOVA	{"phone": "+70770188862"}
0005434520464	13B667	0388 654561	IVAN KULIKOV	{"phone": "+70985867892"}
0005434520465	C8A59A	6880 305900	STANISLAV TIMOFEEV	{"email": "timofeev-stanislav-051965@postgrespro.ru", "phone": "+70210825746"}
0005434520466	FB1C10	7497 095523	GALINA GAVRILOVA	{"phone": "+70771268784"}
0005434520467	B599DF	7930 851385	KONSTANTIN MOROZOV	{"email": "k_morozov_091970@postgrespro.ru", "phone": "+70819653308"}
0005434520468	B599DF	0572 131383	ALBINA MATVEEVA	{"email": "albina.matveeva-1967@postgrespro.ru", "phone": "+70694459081"}
0005434520469	E811ED	5726 630350	ARINA ALEKSEEVA	{"email": "arina.alekseeva041977@postgrespro.ru", "phone": "+70838901167"}
0005434520470	095130	0492 731144	ZULFIYA LUKYANOVA	{"phone": "+70534070668"}
0005434520471	095130	0005 173587	ILYA ZHUKOV	{"email": "ilya.zhukov_1977@postgrespro.ru", "phone": "+70600323729"}
0005434520472	8B745E	3309 627151	ALEKSANDRA AFANASEVA	{"phone": "+70152441215"}
0005434520473	8B745E	9341 208577	VIKTOR POPOV	{"phone": "+70215742991"}
0005434520474	D34836	8099 079019	YURIY KOZLOV	{"phone": "+70916331222"}
0005434520475	716DCA	9845 031105	KONSTANTIN KAZAKOV	{"phone": "+70754788418"}
0005434520476	687864	0268 947224	DAMIR IVANOV	{"email": "d-ivanov.20121972@postgrespro.ru", "phone": "+70138118520"}
0005434520477	687864	2499 069072	YURIY AFANASEV	{"email": "y_afanasev_061972@postgrespro.ru", "phone": "+70124659511"}
0005434520478	55D6EA	9084 083225	IRINA IVANOVA	{"email": "ivanova-irina-1975@postgrespro.ru", "phone": "+70007459142"}
0005434520479	CFB5F6	1348 022206	NIKOLAY MIKHAYLOV	{"email": "nikolay-mikhaylov_101973@postgrespro.ru", "phone": "+70356433799"}
0005434520480	CFB5F6	9890 967735	NINA LAZAREVA	{"email": "n.lazareva101975@postgrespro.ru", "phone": "+70692035129"}
0005434520481	20BB68	6988 403869	NIKOLAY SCHERBAKOV	{"email": "nikolay-scherbakov-1967@postgrespro.ru", "phone": "+70260381164"}
0005434520482	4830A6	8247 879107	EVGENIY MAKAROV	{"phone": "+70005199017"}
0005434520483	4830A6	1660 634140	SVETLANA DAVYDOVA	{"phone": "+70573739329"}
0005434520484	79DAB8	3713 390051	ALEKSANDRA CHERNOVA	{"email": "chernova-a.1969@postgrespro.ru", "phone": "+70169943332"}
0005434520485	626D6C	9535 235515	ALEKSANDR OSIPOV	{"email": "osipov-a.051963@postgrespro.ru", "phone": "+70034718194"}
0005434520486	7C76A0	0679 721066	ARTEM KARPOV	{"email": "artemkarpov121973@postgrespro.ru", "phone": "+70344033352"}
0005434520487	7C76A0	8378 855881	LYUDMILA KISELEVA	{"email": "kiselevalyudmila_13061962@postgrespro.ru", "phone": "+70905866253"}
0005434520488	EB19E5	9367 186274	VLADIMIR KISELEV	{"phone": "+70398501512"}
0005434520489	85C690	7382 622931	NATALYA ZAKHAROVA	{"phone": "+70031716848"}
0005434520490	309541	1661 333600	ELENA EFIMOVA	{"phone": "+70587882885"}
0005434520491	309541	9023 115013	DARYA KUZMINA	{"email": "darya-kuzmina_21081979@postgrespro.ru", "phone": "+70121846409"}
0005434520492	58314B	1951 475520	EKATERINA SMIRNOVA	{"phone": "+70450730308"}
0005434520493	58314B	6552 907305	SVETLANA NAZAROVA	{"phone": "+70724303786"}
0005434520494	F7DD4B	1152 158836	ARTEM DAVYDOV	{"email": "davydov.a051975@postgrespro.ru", "phone": "+70035098119"}
0005434520495	F7DD4B	6260 298035	TATYANA KONOVALOVA	{"email": "konovalova_t-30011969@postgrespro.ru", "phone": "+70823321794"}
0005434520496	84B887	9410 278832	VLADIMIR KOZLOV	{"email": "kozlov.vladimir051971@postgrespro.ru", "phone": "+70328878239"}
0005434520497	84B887	7430 404472	ELENA KUZNECOVA	{"email": "elena_kuznecova_21051965@postgrespro.ru", "phone": "+70473667260"}
0005434520498	0EAC84	4259 093950	IRINA MOROZOVA	{"email": "i.morozova17091971@postgrespro.ru", "phone": "+70945000006"}
0005434520499	0EAC84	6071 491596	ANATOLIY VOROBEV	{"email": "avorobev_1967@postgrespro.ru", "phone": "+70748784124"}
0005434520500	CD8FAA	5693 573689	LILIYA MALYSHEVA	{"email": "malyshevaliliya-1972@postgrespro.ru", "phone": "+70140676472"}
0005434520501	CD8FAA	1164 321165	IRINA NOVIKOVA	{"email": "irina-novikova.1968@postgrespro.ru", "phone": "+70032752067"}
0005434520502	4D7BE3	8501 576442	DARYA EGOROVA	{"email": "egorova.darya-111967@postgrespro.ru", "phone": "+70004187468"}
0005434520503	4D7BE3	9391 083124	ELDAR FEDOROV	{"email": "fedorov.eldar.09051968@postgrespro.ru", "phone": "+70021335038"}
0005434520504	598221	2775 974867	IRINA PAVLOVA	{"email": "pavlova.irina02101965@postgrespro.ru", "phone": "+70126639047"}
0005434520505	21BCD5	7886 193532	ALEKSEY BORISOV	{"email": "aborisov_26061973@postgrespro.ru", "phone": "+70257487872"}
0005434520506	67E60A	3355 689399	SVYATOSLAV SMIRNOV	{"phone": "+70411466616"}
0005434520507	118C47	3035 451341	YURIY BORISOV	{"email": "y_borisov-07051973@postgrespro.ru", "phone": "+70814448582"}
0005434520508	118C47	1800 074338	YULIYA GRISHINA	{"phone": "+70409426496"}
0005434520509	5E16B3	4556 128834	NADEZHDA IVANOVA	{"phone": "+70462065235"}
0005434520510	9BDC60	7375 736598	KSENIYA IVANOVA	{"phone": "+70130777864"}
0005434520511	9BDC60	6018 202928	OLEG ZAYCEV	{"email": "zaycev-oleg23041965@postgrespro.ru", "phone": "+70845093816"}
0005434520512	4DA382	1636 411075	ALEKSANDRA IVANOVA	{"phone": "+70426624604"}
0005434520513	6A4812	6493 189843	VLADIMIR KULIKOV	{"email": "vkulikov26011972@postgrespro.ru", "phone": "+70666633972"}
0005434520514	4B16D6	2820 608194	NIKOLAY SEMENOV	{"phone": "+70255107679"}
0005434520515	E044A0	5912 782874	NADEZHDA MAKSIMOVA	{"phone": "+70246722398"}
0005434520516	E044A0	4267 319866	LYUDMILA FEDOROVA	{"phone": "+70607192502"}
0005434520517	E044A0	4639 044798	RAFAEL KUZNECOV	{"phone": "+70762858587"}
0005434522376	39EC64	6418 636533	TAMARA KONDRATEVA	{"phone": "+70540537176"}
0005434522377	0E7905	8798 864004	TATYANA NIKOLAEVA	{"email": "t.nikolaeva-021977@postgrespro.ru", "phone": "+70712646055"}
0005434522378	15E64B	3283 472654	ANASTASIYA TIKHONOVA	{"phone": "+70216696813"}
0005434522379	64A579	8936 935474	ALEKSANDR BORISOV	{"email": "a_borisov15031977@postgrespro.ru", "phone": "+70796520239"}
0005434522380	98BD0C	2617 728204	RAISA VASILEVA	{"email": "raisa-vasileva_091976@postgrespro.ru", "phone": "+70664925087"}
0005434522381	77F3FC	9951 989161	EKATERINA SAVELEVA	{"email": "ekaterina-saveleva-26061962@postgrespro.ru", "phone": "+70092969177"}
0005434522382	47B4C2	9612 513502	OLGA DMITRIEVA	{"phone": "+70254947127"}
0005434522383	BCB6A7	5384 014022	ANASTASIYA MARTYNOVA	{"phone": "+70579099189"}
0005434522384	BCB6A7	7923 821528	SERGEY RODIONOV	{"phone": "+70934785950"}
0005434522385	14853A	2225 769564	SVETLANA KUZMINA	{"email": "s_kuzmina02121971@postgrespro.ru", "phone": "+70546509338"}
0005434522386	3D4D9D	8926 733443	VITALIY MARTYNOV	{"email": "martynov_vitaliy04121977@postgrespro.ru", "phone": "+70639339934"}
0005434522387	3DFBF8	8845 985091	TATYANA ZHURAVLEVA	{"phone": "+70765117810"}
0005434522388	534E3B	1240 251353	VERA IVANOVA	{"email": "vera_ivanova.1969@postgrespro.ru", "phone": "+70721126694"}
0005434522389	534E3B	2705 795227	OLGA FROLOVA	{"email": "frolova_olga_1983@postgrespro.ru", "phone": "+70747542817"}
0005434522390	534E3B	1807 050387	ALEKSEY KARPOV	{"phone": "+70924535325"}
0005434522391	2F2130	6264 355940	VLADIMIR AFANASEV	{"phone": "+70219428223"}
0005434522392	9EF443	4506 488798	DMITRIY PETROV	{"phone": "+70251279561"}
0005434522393	D117CF	1822 539509	ELENA FROLOVA	{"phone": "+70358565767"}
0005434522394	343901	2996 142306	VLADIMIR KUZNECOV	{"phone": "+70045832678"}
0005434522395	AA852C	8588 409521	OLGA CHERNOVA	{"phone": "+70478691957"}
0005434522396	BB6D26	2703 145632	VLADIMIR MATVEEV	{"email": "matveevv.031983@postgrespro.ru", "phone": "+70668179201"}
0005434522397	F4D753	8113 542317	KSENIYA ANDREEVA	{"phone": "+70055576024"}
0005434522398	F4D753	6972 672874	OKSANA KRASNOVA	{"phone": "+70894559903"}
0005434522399	582E93	3203 179354	KRISTINA DAVYDOVA	{"phone": "+70707309636"}
0005434522400	582E93	9725 675739	ANTONINA KAZAKOVA	{"phone": "+70862773313"}
0005434522401	8E153C	7495 969694	ALEKSEY MAKSIMOV	{"email": "aleksey_maksimov_21041979@postgrespro.ru", "phone": "+70275853198"}
0005434522402	8E153C	8250 530094	ALEKSANDR NIKITIN	{"email": "nikitina_15021972@postgrespro.ru", "phone": "+70110838053"}
0005434522403	97C5B9	6849 845420	KSENIYA FROLOVA	{"email": "kseniya_frolova_1970@postgrespro.ru", "phone": "+70004369579"}
0005434522404	1291B6	9018 549057	VADIM DAVYDOV	{"phone": "+70609539541"}
0005434522405	1C3BCB	8247 777280	VYACHESLAV VASILEV	{"email": "vasilev_vyacheslav_061966@postgrespro.ru", "phone": "+70748987528"}
0005434522406	8688FA	5454 508907	IRINA VLASOVA	{"phone": "+70991946076"}
0005434522407	9A9019	8318 312090	OLGA SERGEEVA	{"phone": "+70332236506"}
0005434522408	9A9019	6136 019703	ANNA EGOROVA	{"email": "egorova.a-1966@postgrespro.ru", "phone": "+70500557324"}
0005434522409	1A8851	3064 035187	VIOLETTA LAZAREVA	{"email": "lazarevav081978@postgrespro.ru", "phone": "+70759497458"}
0005434522410	73E915	4210 043730	PELAGEYA NESTEROVA	{"phone": "+70473331673"}
0005434522411	27AA1E	4750 001010	NATALYA KUZMINA	{"email": "kuzminan.1958@postgrespro.ru", "phone": "+70050013077"}
0005434522412	27AA1E	8607 687278	LYUDMILA ORLOVA	{"phone": "+70235408851"}
0005434522413	AD91C0	4883 469804	MIKHAIL GERASIMOV	{"email": "m_gerasimov_061968@postgrespro.ru", "phone": "+70455780083"}
0005434522414	AD91C0	6306 337981	TATYANA MALYSHEVA	{"email": "malysheva-t_1972@postgrespro.ru", "phone": "+70050348993"}
0005434522415	C42A17	8655 112959	GALINA VLASOVA	{"phone": "+70620838832"}
0005434522416	C42A17	1905 888753	GALINA IVANOVA	{"email": "ivanova_galina.14111965@postgrespro.ru", "phone": "+70593239352"}
0005434522417	18799B	4665 583193	ANNA VOROBEVA	{"phone": "+70711541446"}
0005434522418	18799B	5806 076250	MARIYA ROMANOVA	{"phone": "+70787758667"}
0005434522419	872A2C	3461 349141	VLADIMIR KRASNOV	{"email": "krasnov-vladimir-1973@postgrespro.ru", "phone": "+70746564036"}
0005434522420	872A2C	0605 375139	SVETLANA IVANOVA	{"phone": "+70913029926"}
0005434522421	872A2C	6387 629171	OLEG VOROBEV	{"phone": "+70708565540"}
0005434522422	2F1031	5030 379871	VERA FROLOVA	{"phone": "+70083903830"}
0005434522423	421377	3667 738440	VLADIMIR IVANOV	{"email": "v.ivanov12011988@postgrespro.ru", "phone": "+70858403177"}
0005434522424	62255E	6498 831136	MIKHAIL KAZAKOV	{"email": "kazakov_mikhail-031967@postgrespro.ru", "phone": "+70107608218"}
0005434522425	247900	1903 936402	ANATOLIY NAZAROV	{"email": "nazarov_a_101960@postgrespro.ru", "phone": "+70347726000"}
0005434522426	247900	5740 659438	PRASKOVYA IVANOVA	{"email": "p-ivanova-02111973@postgrespro.ru", "phone": "+70154502087"}
0005434522427	19616F	9926 750248	SERGEY ALEKSANDROV	{"email": "saleksandrov_041972@postgrespro.ru", "phone": "+70315405578"}
0005434522428	F54017	9219 030889	IGOR NAZAROV	{"phone": "+70097559164"}
0005434522429	7D4F94	8814 738739	DAVID TIKHONOV	{"email": "david.tikhonov_1965@postgrespro.ru", "phone": "+70743462467"}
0005434522430	C13699	3210 179646	KIRILL PETROV	{"email": "petrovkirill1965@postgrespro.ru", "phone": "+70586458282"}
0005434522431	122B99	1570 391261	PETR ANTONOV	{"phone": "+70290310400"}
0005434522432	074511	0999 219947	DANIIL IVANOV	{"email": "d-ivanov23101971@postgrespro.ru", "phone": "+70349114755"}
0005434522433	58AB79	0868 860250	VASILIY ANTONOV	{"phone": "+70910714903"}
0005434522434	58AB79	9403 714742	IRINA DENISOVA	{"phone": "+70745230746"}
0005434522435	E6A0A9	8167 719064	FANIL GUSEV	{"email": "fanilgusev-16111970@postgrespro.ru", "phone": "+70037485373"}
0005434522436	E6A0A9	0407 482598	LYUBOV MAKAROVA	{"phone": "+70238702107"}
0005434522437	0AEB6C	9942 220437	ANNA KUZNECOVA	{"phone": "+70684301659"}
0005434522438	2C7397	6534 495273	TAISIYA IVANOVA	{"email": "ivanova.t.061960@postgrespro.ru", "phone": "+70632088110"}
0005434522439	13E54F	5373 596706	TAMARA GAVRILOVA	{"phone": "+70548613416"}
0005434522440	B5D917	7586 433252	YURIY SOROKIN	{"phone": "+70257400987"}
0005434522441	B5D917	3336 706135	YULIYA MELNIKOVA	{"email": "yuliya.melnikova_061988@postgrespro.ru", "phone": "+70359816247"}
0005434522442	6008E0	8976 282941	ALEKSANDRA NOVIKOVA	{"phone": "+70467401089"}
0005434522443	6008E0	0328 812803	PETR IVANOV	{"phone": "+70778926389"}
0005434522444	21E63E	8169 260117	ELENA VASILEVA	{"email": "e-vasileva101968@postgrespro.ru", "phone": "+70843988449"}
0005434522445	E175E7	9290 863466	ANATOLIY MEDVEDEV	{"phone": "+70973562525"}
0005434522446	CBC37B	2579 307737	ALEKSANDR ANTONOV	{"phone": "+70907899659"}
0005434522447	D8481E	6095 315073	VIKTOR BARANOV	{"phone": "+70747563984"}
0005434522448	D8481E	7722 823454	ALEKSANDR TIMOFEEV	{"phone": "+70673023356"}
0005434522449	648FD0	0105 688571	NINA MIRONOVA	{"email": "nina-mironova101983@postgrespro.ru", "phone": "+70500819745"}
0005434522450	5B45CE	0706 070969	TATYANA IVANOVA	{"email": "ivanova_t.27071970@postgrespro.ru", "phone": "+70255050013"}
0005434522451	58A41D	1155 308973	ILYA TIMOFEEV	{"email": "i.timofeev.1969@postgrespro.ru", "phone": "+70296996336"}
0005434522452	07FD65	0441 670952	PETR MAKSIMOV	{"email": "maksimovpetr_05051965@postgrespro.ru", "phone": "+70952574396"}
0005434522453	07FD65	8535 128226	SERGEY TIMOFEEV	{"phone": "+70966739504"}
0005434522454	07FD65	3087 170600	GRIGORIY MEDVEDEV	{"phone": "+70876122491"}
0005434522455	A65F26	2519 784131	SVETLANA EGOROVA	{"phone": "+70903862822"}
0005434522456	479185	8046 130131	GALINA PAVLOVA	{"email": "galina_pavlova-12021974@postgrespro.ru", "phone": "+70445953443"}
0005434522457	E74AA1	5956 869393	ALEKSANDR POPOV	{"email": "a-popov12091965@postgrespro.ru", "phone": "+70031367771"}
0005434522458	FFA3C1	5212 972721	DMITRIY MAKAROV	{"phone": "+70636483995"}
0005434522459	FFA3C1	0784 586803	YULIYA MAKAROVA	{"phone": "+70544684857"}
0005434522460	1F78A3	4068 889540	EVGENIY SOROKIN	{"email": "sorokin_evgeniy-1971@postgrespro.ru", "phone": "+70266344793"}
0005434522461	1F78A3	9594 330280	VALENTINA PETROVA	{"email": "petrova-v-05061969@postgrespro.ru", "phone": "+70870070669"}
0005434522462	E6C63A	6958 622073	ALEKSANDR SCHERBAKOV	{"phone": "+70211897121"}
0005434522463	E6C63A	3433 460897	KIRILL MIKHAYLOV	{"phone": "+70565342091"}
0005434522464	C42BEE	1967 081261	ALEKSEY ABRAMOV	{"email": "abramov-a1965@postgrespro.ru", "phone": "+70615833629"}
0005434522465	A09F50	8218 986361	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov28011963@postgrespro.ru", "phone": "+70524780322"}
0005434522466	89C9CB	1231 518144	MARIYA POTAPOVA	{"email": "mariya_potapova-051976@postgrespro.ru", "phone": "+70403581948"}
0005434522467	3B025A	5227 824068	OLGA BELOVA	{"email": "belova-olga.08091969@postgrespro.ru", "phone": "+70936835339"}
0005434522468	F64F6B	6587 248592	LILIYA LUKYANOVA	{"email": "liliya_lukyanova.091968@postgrespro.ru", "phone": "+70422451212"}
0005434522469	F64F6B	2416 536810	GLEB NOVIKOV	{"phone": "+70286500026"}
0005434522470	F64F6B	0701 860875	YULIYA TIKHONOVA	{"email": "tikhonova_yuliya_051985@postgrespro.ru", "phone": "+70616164254"}
0005434522471	A8CD38	0572 917259	VYACHESLAV KUZNECOV	{"phone": "+70384244014"}
0005434522472	C5B3DB	0127 438296	OLGA MOROZOVA	{"phone": "+70241030096"}
0005434522473	C5B3DB	5155 367003	EKATERINA PETROVA	{"phone": "+70709319888"}
0005434522474	6BA7B5	8173 927997	ALEKSANDR DMITRIEV	{"email": "dmitriev-aleksandr.021965@postgrespro.ru", "phone": "+70873543532"}
0005434522475	6BA7B5	1414 061794	LARISA BELYAEVA	{"email": "larisabelyaeva.1972@postgrespro.ru", "phone": "+70976556553"}
0005434522476	A0D49F	0552 404783	DMITRIY ZHURAVLEV	{"email": "d.zhuravlev1982@postgrespro.ru", "phone": "+70134292461"}
0005434522477	CFE656	5186 137547	OLGA FILIPPOVA	{"phone": "+70980058728"}
0005434522478	F39370	8119 220440	IVAN NOVIKOV	{"email": "novikov_ivan_27061964@postgrespro.ru", "phone": "+70446407045"}
0005434522479	BB5645	1564 521529	VLADIMIR MAKSIMOV	{"phone": "+70060724171"}
0005434522480	92C498	7842 510392	VLADIMIR IVANOV	{"email": "vladimir_ivanov-25061977@postgrespro.ru", "phone": "+70283894597"}
0005434522481	92C498	7499 920073	VIKTOR FILIPPOV	{"phone": "+70078399367"}
0005434522482	92C498	5844 944001	VIKTOR VOLKOV	{"email": "viktor-volkov-17031977@postgrespro.ru", "phone": "+70622300366"}
0005434522483	3D07E1	0795 015464	VADIM SERGEEV	{"phone": "+70689756802"}
0005434522484	80241D	4823 050501	TATYANA PETROVA	{"email": "petrova_tatyana_091965@postgrespro.ru", "phone": "+70102243536"}
0005434522485	D22552	8602 158302	IRINA NESTEROVA	{"phone": "+70182306794"}
0005434522486	95F076	3507 224213	GALINA BOGDANOVA	{"phone": "+70731288578"}
0005434522487	95F076	0969 947945	VALENTINA VOROBEVA	{"email": "valentina.vorobeva_101975@postgrespro.ru", "phone": "+70514202532"}
0005434522488	95F076	8926 845970	TATYANA ANDREEVA	{"phone": "+70496910576"}
0005434522489	8846FF	8311 824640	DMITRIY PETROV	{"phone": "+70247241857"}
0005434522490	87C110	6674 291493	ANNA GORBUNOVA	{"email": "a.gorbunova-011976@postgrespro.ru", "phone": "+70179453631"}
0005434522491	87C110	8257 875074	VITALIY BELOV	{"phone": "+70044743098"}
0005434522492	725F2F	9794 484927	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy.031962@postgrespro.ru", "phone": "+70268897022"}
0005434522493	725F2F	8578 628495	NIKOLAY ANTONOV	{"email": "antonov_nikolay16121964@postgrespro.ru", "phone": "+70679710695"}
0005434522494	725F2F	2848 599095	DMITRIY DMITRIEV	{"email": "dmitriy.dmitriev1965@postgrespro.ru", "phone": "+70618685532"}
0005434522495	59410F	8327 938341	EVGENIY SEMENOV	{"email": "semenov-evgeniy_111990@postgrespro.ru", "phone": "+70731929333"}
0005434522496	8A49E7	9562 210202	ALEKSANDR KAZAKOV	{"phone": "+70851941644"}
0005434522497	8F75AE	9863 267208	ANDREY MELNIKOV	{"phone": "+70755296872"}
0005434522498	C37357	4253 373884	ANTON KARPOV	{"email": "antonkarpov.1962@postgrespro.ru", "phone": "+70510692025"}
0005434522499	D74FC3	5837 640517	GENNADIY KRASNOV	{"phone": "+70710757611"}
0005434522500	D74FC3	9950 867521	ALIYA STEPANOVA	{"email": "aliyastepanova-12061970@postgrespro.ru", "phone": "+70336889622"}
0005434522501	1D883D	7077 868738	ALENA DAVYDOVA	{"email": "davydova_alena101974@postgrespro.ru", "phone": "+70561476688"}
0005434522502	FBC82F	8534 090536	ANDREY IVANOV	{"phone": "+70245613755"}
0005434522503	FBC82F	5355 190251	TATYANA MARTYNOVA	{"email": "martynova_t_091971@postgrespro.ru", "phone": "+70983393962"}
0005434522504	C6749D	6093 138891	AIDA KUZNECOVA	{"phone": "+70589088232"}
0005434522505	C6749D	4797 774301	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova_1979@postgrespro.ru", "phone": "+70666869575"}
0005434522506	69BD4A	4640 404293	PETR KUZNECOV	{"email": "kuznecov.petr.021984@postgrespro.ru", "phone": "+70326527201"}
0005434522507	C9F79C	7663 460777	GRIGORIY ALEKSANDROV	{"phone": "+70987411859"}
0005434522508	BDFE6B	5607 924324	NINA ABRAMOVA	{"phone": "+70229862126"}
0005434522509	A1ED50	6466 017607	ALEKSANDR BORISOV	{"phone": "+70444035805"}
0005434522510	4BC07B	8823 915199	TAMARA LUKYANOVA	{"email": "lukyanovat.01121981@postgrespro.ru", "phone": "+70142669557"}
0005434522511	4BC07B	0681 751194	VLADIMIR PAVLOV	{"phone": "+70962680226"}
0005434522512	4BC07B	2791 157573	VALERIY AFANASEV	{"phone": "+70081469400"}
0005434522513	846EE1	5868 285672	VYACHESLAV AFANASEV	{"phone": "+70427006048"}
0005434522514	6021AB	5019 147948	DARYA ZHURAVLEVA	{"phone": "+70072113558"}
0005434522515	E61A69	0805 948899	YULIYA SERGEEVA	{"phone": "+70648230616"}
0005434522516	887F42	1826 715461	DANILA SEMENOV	{"email": "semenov-d11011983@postgrespro.ru", "phone": "+70234554392"}
0005434522517	989B14	1503 080603	OLGA ANDREEVA	{"email": "o_andreeva1970@postgrespro.ru", "phone": "+70590622948"}
0005434522518	DC6567	8135 782549	VLADIMIR KAZAKOV	{"phone": "+70599848064"}
0005434522519	DC6567	4652 299895	OLEG MAKAROV	{"email": "olegmakarov_1969@postgrespro.ru", "phone": "+70102779684"}
0005434522520	208700	3607 213750	SERGEY BARANOV	{"email": "s_baranov.051968@postgrespro.ru", "phone": "+70376858249"}
0005434522521	09293E	6742 135295	VLADIMIR DMITRIEV	{"phone": "+70678703203"}
0005434522522	09293E	9502 741307	ELENA SMIRNOVA	{"phone": "+70045423064"}
0005434522523	CE9E9D	1399 969546	ANASTASIYA AFANASEVA	{"phone": "+70551163120"}
0005434522524	3BD54B	7288 784457	EVGENIY MAKAROV	{"email": "e-makarov-05121969@postgrespro.ru", "phone": "+70112174630"}
0005434522525	B4EE87	8608 573748	NADEZHDA SMIRNOVA	{"phone": "+70454642900"}
0005434522526	3AA883	1826 340660	IGOR ORLOV	{"email": "orlov.i.13071972@postgrespro.ru", "phone": "+70620632530"}
0005434522527	2F62DD	6410 305752	ALEKSANDR FROLOV	{"email": "aleksandr-frolov.1979@postgrespro.ru", "phone": "+70273809029"}
0005434522528	BD8CF1	8276 737690	OLESYA ANDREEVA	{"email": "olesya_andreeva061966@postgrespro.ru", "phone": "+70557393524"}
0005434522529	81A3B3	7316 493476	LYUDMILA KOROLEVA	{"email": "koroleva.l.05041964@postgrespro.ru", "phone": "+70858343402"}
0005434522530	9BA677	7993 162305	ALEKSEY SCHERBAKOV	{"phone": "+70332584463"}
0005434522531	9BA677	7334 664963	IGOR MATVEEV	{"phone": "+70315423224"}
0005434522532	288F25	7497 904013	ALEKSEY KUZNECOV	{"email": "kuznecova021977@postgrespro.ru", "phone": "+70776119953"}
0005434522533	288F25	8463 438838	SERGEY DENISOV	{"email": "denisov_s_1982@postgrespro.ru", "phone": "+70575868464"}
0005434522534	D0DC53	9557 694450	EKATERINA LAZAREVA	{"email": "lazareva.e-23011979@postgrespro.ru", "phone": "+70880549672"}
0005434522535	D245C4	5738 847524	ROMAN PAVLOV	{"email": "pavlov-r_1971@postgrespro.ru", "phone": "+70426334392"}
0005434522536	FB457B	1265 068972	KIRILL KARPOV	{"email": "kkarpov-031980@postgrespro.ru", "phone": "+70110213133"}
0005434522537	42A391	5725 243895	KRISTINA FROLOVA	{"email": "frolova.k.091975@postgrespro.ru", "phone": "+70767165149"}
0005434522538	A0EBF1	7452 059026	EVGENIYA NIKITINA	{"phone": "+70343163172"}
0005434522539	C7934B	3551 071047	SERGEY SCHERBAKOV	{"email": "scherbakov.s_1970@postgrespro.ru", "phone": "+70941816748"}
0005434522540	C7934B	0989 046926	ILYA ALEKSEEV	{"phone": "+70723177343"}
0005434522541	A24943	8897 130422	VIKTOR NAZAROV	{"phone": "+70138470758"}
0005434522542	52C6AD	9770 250592	VYACHESLAV SHEVCHENKO	{"email": "shevchenko_vyacheslav-1973@postgrespro.ru", "phone": "+70203848180"}
0005434522543	526A36	8917 702646	VALENTINA SMIRNOVA	{"phone": "+70852046306"}
0005434522544	E2FF56	2150 752239	LYUBOV SOLOVEVA	{"email": "lsoloveva.15091977@postgrespro.ru", "phone": "+70507331446"}
0005434522545	E2FF56	3017 871798	SVETLANA DENISOVA	{"email": "denisovas.101977@postgrespro.ru", "phone": "+70110522363"}
0005434522546	A17FAA	7259 333465	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov1990@postgrespro.ru", "phone": "+70118104084"}
0005434522547	3A1946	1191 495049	VLADISLAV KARPOV	{"email": "vladislav_karpov111982@postgrespro.ru", "phone": "+70192882924"}
0005434522548	3A1946	4623 644617	VLADIMIR IVANOV	{"phone": "+70043361257"}
0005434522549	0FFAA1	9506 000374	TARAS SEMENOV	{"phone": "+70710719760"}
0005434522550	0FFAA1	7935 509852	NADEZHDA FADEEVA	{"phone": "+70850493463"}
0005434522551	071532	5825 963698	LEONID GAVRILOV	{"email": "l_gavrilov_10041974@postgrespro.ru", "phone": "+70501331314"}
0005434522552	071532	5534 105162	ANDREY DMITRIEV	{"email": "dmitriev-andrey071970@postgrespro.ru", "phone": "+70880418229"}
0005434522553	71930D	0390 772408	VALERIY POPOV	{"email": "v_popov.071974@postgrespro.ru", "phone": "+70188713946"}
0005434522554	D3E2BE	9884 931345	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.19041982@postgrespro.ru", "phone": "+70376608501"}
0005434522555	D3E2BE	0915 759342	KONSTANTIN AFANASEV	{"phone": "+70723306471"}
0005434522556	2B0132	2323 578128	MARIYA FILIPPOVA	{"email": "mariya-filippova.1972@postgrespro.ru", "phone": "+70635921043"}
0005434522557	682E2D	0050 054597	ALEKSANDR GORBUNOV	{"phone": "+70721298208"}
0005434522558	637593	7796 987141	MARINA BOGDANOVA	{"phone": "+70526215338"}
0005434522559	637593	7718 441675	OLEG ZHUKOV	{"email": "o-zhukov-1975@postgrespro.ru", "phone": "+70392431533"}
0005434522560	637593	6771 910147	YURIY SIDOROV	{"phone": "+70762377499"}
0005434523734	A9287E	1417 882966	ANTONINA ABRAMOVA	{"phone": "+70525602153"}
0005434523731	92BB2D	5453 857767	IGOR KISELEV	{"email": "kiselev-i.051966@postgrespro.ru", "phone": "+70229115526"}
0005434523732	92BB2D	0302 571784	TATYANA ZAKHAROVA	{"phone": "+70969147468"}
0005434523733	5B5639	3957 904422	VYACHESLAV KARPOV	{"phone": "+70690072918"}
0005434523735	8BEC0B	9097 221972	EVDOKIYA IVANOVA	{"phone": "+70190325801"}
0005434523736	956E79	4062 435009	GENNADIY DMITRIEV	{"email": "gdmitriev_1979@postgrespro.ru", "phone": "+70039075275"}
0005434523737	956E79	1488 269826	ALEKSEY SHEVCHENKO	{"phone": "+70923090361"}
0005434523738	F062B6	7864 980011	ROZA NIKITINA	{"phone": "+70016289914"}
0005434523739	18403E	1965 822912	ANDREY BELOV	{"email": "belov_andrey-1968@postgrespro.ru", "phone": "+70562338774"}
0005434523740	18403E	7257 015765	SERGEY SMIRNOV	{"email": "smirnovsergey-1963@postgrespro.ru", "phone": "+70332396569"}
0005434523741	FC7BD2	3299 782999	ALEKSEY SOROKIN	{"phone": "+70819020664"}
0005434523742	C286E9	5381 419451	ELENA MOISEEVA	{"email": "elenamoiseeva12021959@postgrespro.ru", "phone": "+70175956565"}
0005434523743	C286E9	7363 762051	NATALYA POPOVA	{"email": "popova_n-011986@postgrespro.ru", "phone": "+70853254008"}
0005434523744	391AF3	4500 633670	DMITRIY VASILEV	{"phone": "+70098189674"}
0005434523745	E6F1B0	8874 967613	MIKHAIL ALEKSEEV	{"email": "m_alekseev.071969@postgrespro.ru", "phone": "+70813201980"}
0005434523746	E6F1B0	5323 854204	ANNA SOKOLOVA	{"email": "sokolova_a_1965@postgrespro.ru", "phone": "+70968099749"}
0005434523747	5CA5A3	3759 202063	IVAN SCHERBAKOV	{"phone": "+70312294318"}
0005434523748	3B136E	6255 024244	TATYANA MELNIKOVA	{"email": "tmelnikova071975@postgrespro.ru", "phone": "+70610978916"}
0005434523749	1616CA	5911 147128	KONSTANTIN IVANOV	{"phone": "+70376505057"}
0005434523750	22280E	6764 517953	ASIYA STEPANOVA	{"phone": "+70495375258"}
0005434523751	54BF54	1452 657436	SERGEY KOROLEV	{"email": "korolev.s-14111971@postgrespro.ru", "phone": "+70230885091"}
0005434523752	D2F813	2380 429795	YULIYA LEBEDEVA	{"phone": "+70766908695"}
0005434523753	EB60C4	2034 990871	PAVEL TIKHONOV	{"phone": "+70839057070"}
0005434523754	BC3FBD	9052 004428	KONSTANTIN ZHURAVLEV	{"phone": "+70321340230"}
0005434523755	BC3FBD	5622 601852	ALEKSANDR VLASOV	{"phone": "+70411324795"}
0005434523756	BC3FBD	1292 241940	ILMIRA KUDRYASHOVA	{"phone": "+70102139791"}
0005434523757	BC3FBD	3674 890952	ANATOLIY MIRONOV	{"email": "mironov-anatoliy30031965@postgrespro.ru", "phone": "+70772948999"}
0005434523758	61C845	7499 704972	IVAN NAZAROV	{"phone": "+70500868600"}
0005434523759	61C845	6725 451210	NATALYA MEDVEDEVA	{"phone": "+70084631719"}
0005434523760	1570E6	9044 788711	ALEKSEY MOISEEV	{"phone": "+70941688325"}
0005434523761	814388	8728 786546	ANASTASIYA IVANOVA	{"phone": "+70975071111"}
0005434523762	D8C751	8132 197025	BORIS VASILEV	{"email": "boris_vasilev-1971@postgrespro.ru", "phone": "+70373420070"}
0005434523763	D8C751	8232 667795	VALERIYA KAZAKOVA	{"email": "kazakova-valeriya1964@postgrespro.ru", "phone": "+70683860936"}
0005434523764	D8C751	2255 263274	ALEKSANDR PETROV	{"phone": "+70452932795"}
0005434523765	32ED5D	6780 314027	ELENA SOROKINA	{"email": "e_sorokina.18011970@postgrespro.ru", "phone": "+70862309357"}
0005434523766	32ED5D	1787 240967	OKSANA GUSEVA	{"phone": "+70632305731"}
0005434523767	7E613C	8714 942783	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_30041978@postgrespro.ru", "phone": "+70351345840"}
0005434523768	A659E2	8187 747992	OLGA NESTEROVA	{"email": "nesterova-o031971@postgrespro.ru", "phone": "+70512666785"}
0005434523769	3C82A5	0032 395794	NATALYA MASLOVA	{"email": "maslova.natalya-1980@postgrespro.ru", "phone": "+70396567954"}
0005434523770	87134F	1029 998367	NIKOLAY ZAKHAROV	{"phone": "+70171797422"}
0005434523771	6E3BD1	5139 414525	STEPAN PAVLOV	{"email": "s.pavlov.1984@postgrespro.ru", "phone": "+70158520279"}
0005434523772	1E5E7C	5019 934609	DENIS ALEKSEEV	{"phone": "+70936486229"}
0005434523773	1E5E7C	1706 239594	NADEZHDA POTAPOVA	{"email": "potapova.n_05041970@postgrespro.ru", "phone": "+70419896191"}
0005434523774	1F8D40	1436 385458	SERGEY PETROV	{"email": "petrov.sergey_011976@postgrespro.ru", "phone": "+70847397866"}
0005434523775	1F8D40	2519 702321	SERGEY NAUMOV	{"email": "s.naumov1988@postgrespro.ru", "phone": "+70650089301"}
0005434523776	3FED11	4280 310556	SERGEY SOLOVEV	{"email": "s_solovev-05101978@postgrespro.ru", "phone": "+70639913991"}
0005434523777	32F400	5667 483389	EKATERINA VASILEVA	{"email": "ekaterina_vasileva16041969@postgrespro.ru", "phone": "+70497449687"}
0005434523778	800662	1065 181187	SERGEY BONDARENKO	{"email": "s.bondarenko-05101973@postgrespro.ru", "phone": "+70754397157"}
0005434523779	641385	4958 676853	NATALYA SMIRNOVA	{"email": "smirnova.n-01061973@postgrespro.ru", "phone": "+70113009212"}
0005434523780	05152A	8856 635316	TATYANA ILINA	{"email": "ilina-tatyana-081976@postgrespro.ru", "phone": "+70527284745"}
0005434523781	05152A	7351 807110	ALEKSEY DENISOV	{"email": "denisov-aleksey-1954@postgrespro.ru", "phone": "+70317999313"}
0005434523782	60C757	2378 391936	ELENA TARASOVA	{"email": "etarasova121968@postgrespro.ru", "phone": "+70504091852"}
0005434523783	24BAB5	5513 964415	ANATOLIY NIKOLAEV	{"phone": "+70481338057"}
0005434523784	2E2146	6322 965829	NIKOLAY NIKOLAEV	{"phone": "+70457250292"}
0005434523785	2E2146	5285 902832	IRINA SERGEEVA	{"email": "irina-sergeeva.1978@postgrespro.ru", "phone": "+70909871753"}
0005434523786	071E3A	5161 891043	IGOR SCHERBAKOV	{"phone": "+70160793735"}
0005434523787	86FD6E	3967 494847	ALEKSEY NIKOLAEV	{"phone": "+70830368150"}
0005434523788	86FD6E	6907 513278	OLEG IVANOV	{"email": "ivanov_oleg24041975@postgrespro.ru", "phone": "+70436855390"}
0005434523789	A5E86D	0503 374440	NIKOLAY MIRONOV	{"email": "mironov.nikolay12041970@postgrespro.ru", "phone": "+70624273988"}
0005434523790	E6F95E	8218 345543	NATALYA MATVEEVA	{"email": "natalya.matveeva-29011963@postgrespro.ru", "phone": "+70174602737"}
0005434523791	B82DE3	3257 316160	ALEKSANDR POPOV	{"phone": "+70266082446"}
0005434523792	10C118	3056 399550	MAKSIM DENISOV	{"email": "denisovmaksim011977@postgrespro.ru", "phone": "+70901377539"}
0005434523793	3CE99C	2988 493269	DMITRIY ALEKSANDROV	{"email": "d.aleksandrov-1978@postgrespro.ru", "phone": "+70591064576"}
0005434523794	3CE99C	7392 513162	ELENA FOMINA	{"email": "fomina_elena.1977@postgrespro.ru", "phone": "+70602163471"}
0005434523795	D7FDD4	8948 482281	NATALIYA KULIKOVA	{"phone": "+70394541485"}
0005434523796	C4918B	2839 757357	VALENTINA PAVLOVA	{"phone": "+70282077898"}
0005434523797	FAD494	7571 432022	LYUBOV VASILEVA	{"email": "l_vasileva.13021977@postgrespro.ru", "phone": "+70166778523"}
0005434523798	D2FDA6	7586 947428	EVELINA ZAYCEVA	{"phone": "+70776737331"}
0005434523799	D2FDA6	3572 064123	ALEKSANDR IVANOV	{"phone": "+70725195354"}
0005434523800	522F39	1739 197718	ALEKSANDR BORISOV	{"email": "borisov_a.071967@postgrespro.ru", "phone": "+70474044080"}
0005434523801	3976F7	0563 914756	IVAN KOROLEV	{"phone": "+70920299320"}
0005434523802	C1BD7F	4965 714411	MIKHAIL SOROKIN	{"email": "mikhail_sorokin.03091971@postgrespro.ru", "phone": "+70050187067"}
0005434523803	FEED5C	5553 114442	MAKSIM KUDRYASHOV	{"phone": "+70433721337"}
0005434523804	EA1B6B	2219 403762	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov-03051977@postgrespro.ru", "phone": "+70583480525"}
0005434523805	BB9F4F	3506 483043	MARIANNA KUDRYASHOVA	{"email": "kudryashova.m_20031963@postgrespro.ru", "phone": "+70780222194"}
0005434523806	37844B	3470 555074	LYUBOV KULIKOVA	{"email": "lyubov.kulikova_09101968@postgrespro.ru", "phone": "+70742349530"}
0005434523807	582C2C	1537 219933	ALEKSEY EGOROV	{"email": "egorov.a-1962@postgrespro.ru", "phone": "+70301074736"}
0005434523808	9284ED	8560 779328	ANDREY SCHERBAKOV	{"email": "andreyscherbakov.22041975@postgrespro.ru", "phone": "+70395212744"}
0005434523809	B13B17	1772 773378	ELENA DAVYDOVA	{"phone": "+70462786377"}
0005434523810	7AB2A5	2950 885073	VLADIMIR SIDOROV	{"email": "vladimirsidorov.031971@postgrespro.ru", "phone": "+70176547274"}
0005434523811	231248	4847 091995	EVGENIY MOROZOV	{"email": "evgeniy_morozov_1973@postgrespro.ru", "phone": "+70057088398"}
0005434523812	231248	2046 127415	ELENA GERASIMOVA	{"phone": "+70776816975"}
0005434523813	54D53A	4487 176708	NIKITA GERASIMOV	{"phone": "+70402580278"}
0005434523814	42D60F	1581 578028	IRINA GAVRILOVA	{"phone": "+70472267896"}
0005434523815	3215E2	7825 383198	DANILA RODIONOV	{"email": "d.rodionov-1972@postgrespro.ru", "phone": "+70178634819"}
0005434523816	3215E2	7413 713787	NATALYA YAKOVLEVA	{"phone": "+70219660238"}
0005434523817	6831C1	9636 180996	GENNADIY SEMENOV	{"email": "g-semenov_10021971@postgrespro.ru", "phone": "+70300143307"}
0005434523818	739FDA	2752 051594	OLGA DMITRIEVA	{"email": "dmitrievao-1972@postgrespro.ru", "phone": "+70532946985"}
0005434523819	739FDA	2173 532588	EVGENIYA IVANOVA	{"phone": "+70171888224"}
0005434523820	BD1589	0726 140579	GENNADIY ALEKSEEV	{"email": "alekseevgennadiy-14091975@postgrespro.ru", "phone": "+70846898630"}
0005434523821	BD1589	9137 122164	YURIY ANDREEV	{"phone": "+70936339845"}
0005434523822	BD1589	6039 783494	ALEKSEY TARASOV	{"email": "alekseytarasov-20051974@postgrespro.ru", "phone": "+70246984258"}
0005434523823	334111	2724 514626	NIKITA ZAYCEV	{"email": "nikita-zaycev061965@postgrespro.ru", "phone": "+70665015939"}
0005434523824	D7CA65	4162 337588	LARISA FEDOROVA	{"phone": "+70798328055"}
0005434523825	034516	5676 374754	DARYA KOROLEVA	{"phone": "+70851506657"}
0005434523826	581550	1366 960498	VLADIMIR SMIRNOV	{"phone": "+70583527295"}
0005434523827	883003	1862 386383	ALENA ZAKHAROVA	{"email": "a_zakharova.1975@postgrespro.ru", "phone": "+70255693998"}
0005434523828	29F126	2555 305167	MARAT GERASIMOV	{"phone": "+70644000153"}
0005434523829	29F126	7344 756929	ALEKSEY ROMANOV	{"email": "aleksey.romanov_15021967@postgrespro.ru", "phone": "+70901603954"}
0005434523830	FA170D	5511 056392	NIKITA CHERNOV	{"phone": "+70851988220"}
0005434523831	FA170D	4025 878253	GULNARA STEPANOVA	{"email": "stepanovag_101980@postgrespro.ru", "phone": "+70298941539"}
0005434523832	EC8BFB	5694 788417	IRINA KISELEVA	{"phone": "+70303728671"}
0005434523833	2D3DA3	4245 830144	GALINA VLASOVA	{"phone": "+70597606179"}
0005434523834	3DA423	0424 534647	EKATERINA MASLOVA	{"email": "maslovaekaterina_1973@postgrespro.ru", "phone": "+70610578113"}
0005434523835	3DA423	1497 318303	SERGEY ALEKSEEV	{"email": "salekseev_071973@postgrespro.ru", "phone": "+70020953113"}
0005434523836	D56438	9643 434562	IRINA PETROVA	{"phone": "+70392700336"}
0005434523837	D52F97	2364 989031	VALENTINA DMITRIEVA	{"phone": "+70303270601"}
0005434523838	005492	0777 444411	ELENA ABRAMOVA	{"phone": "+70928343507"}
0005434523839	5AF831	0129 825604	ARTEM NIKOLAEV	{"phone": "+70866393643"}
0005434523840	5AF831	5093 557173	NATALYA YAKOVLEVA	{"email": "yakovleva_n_04091980@postgrespro.ru", "phone": "+70410438790"}
0005434523841	CDC055	1000 996100	LILIYA PAVLOVA	{"phone": "+70250777385"}
0005434523842	C1B7C3	6215 005185	PELAGEYA MOISEEVA	{"email": "pelageya_moiseeva.091979@postgrespro.ru", "phone": "+70965662841"}
0005434523843	0B89C4	3537 100695	VASILIY GAVRILOV	{"phone": "+70103430604"}
0005434523844	0B89C4	9824 366161	ELENA KUZNECOVA	{"email": "kuznecovae-1969@postgrespro.ru", "phone": "+70160603645"}
0005434523845	0B89C4	9937 495091	SVETLANA MAKAROVA	{"email": "s.makarova01021973@postgrespro.ru", "phone": "+70447896099"}
0005434523846	FB2630	3118 314800	NATALYA FADEEVA	{"phone": "+70176552201"}
0005434550256	6426BE	3087 577879	OLGA KUZNECOVA	{"email": "kuznecovao-1971@postgrespro.ru", "phone": "+70964768933"}
0005434550257	6426BE	7006 518542	LIDIYA MIKHAYLOVA	{"phone": "+70184834099"}
0005434550258	6426BE	0762 803158	NINA RODIONOVA	{"phone": "+70858186031"}
0005434550259	B2F85F	6520 860162	VASILISA MALYSHEVA	{"email": "malysheva_vasilisa_1981@postgrespro.ru", "phone": "+70872909127"}
0005434550260	B2F85F	2649 740851	MARIYA MARTYNOVA	{"email": "m-martynova.071988@postgrespro.ru", "phone": "+70621274293"}
0005434550261	885621	4555 227559	ANDREY ISAEV	{"email": "isaevandrey.051966@postgrespro.ru", "phone": "+70574306196"}
0005434550262	337484	6444 080211	DENIS SIDOROV	{"email": "sidorov.d_1976@postgrespro.ru", "phone": "+70818891897"}
0005434550263	90806D	8548 935163	KLAVDIYA GORBUNOVA	{"email": "klavdiyagorbunova-031964@postgrespro.ru", "phone": "+70477011750"}
0005434550264	D4B43D	9640 768597	TATYANA MAKAROVA	{"email": "t_makarova-031979@postgrespro.ru", "phone": "+70136135078"}
0005434550265	A43D82	4595 364864	SERGEY ZAYCEV	{"email": "zaycev-sergey_031979@postgrespro.ru", "phone": "+70436713477"}
0005434550266	A43D82	1976 347885	OLGA ZAYCEVA	{"email": "olgazayceva_061974@postgrespro.ru", "phone": "+70389896874"}
0005434550267	4789C4	8945 280172	NIKITA ZAYCEV	{"email": "zaycev-nikita.061969@postgrespro.ru", "phone": "+70466605101"}
0005434550268	4789C4	5491 092885	IRINA BARANOVA	{"email": "baranova.irina-041977@postgrespro.ru", "phone": "+70338594602"}
0005434550269	5D6B64	6206 718850	ALEKSANDRA KUZNECOVA	{"phone": "+70827301569"}
0005434550270	617499	1222 941194	ANATOLIY BELOV	{"email": "anatoliy-belov.14071971@postgrespro.ru", "phone": "+70737410421"}
0005434550271	B7F442	3305 870463	VLADIMIR SOROKIN	{"email": "sorokinv_1970@postgrespro.ru", "phone": "+70147435200"}
0005434550272	B7F442	2579 995954	KLAVDIYA GAVRILOVA	{"phone": "+70922500305"}
0005434550273	9F592A	3870 401720	SVETLANA NESTEROVA	{"email": "svetlana-nesterova_1971@postgrespro.ru", "phone": "+70527137627"}
0005434550274	495DA7	5043 255695	ELENA POPOVA	{"phone": "+70075565967"}
0005434550275	495DA7	3364 296328	FEDOR ISAEV	{"email": "isaev.f_1991@postgrespro.ru", "phone": "+70168275248"}
0005434550276	F1FE32	2889 474235	ALEKSANDR MARTYNOV	{"email": "martynova_1970@postgrespro.ru", "phone": "+70185735137"}
0005434550277	772CF8	4488 490771	DMITRIY FEDOROV	{"email": "fedorov-dmitriy02051973@postgrespro.ru", "phone": "+70158043105"}
0005434550278	8C3D3C	9324 653281	GENNADIY ZHURAVLEV	{"phone": "+70949356005"}
0005434550279	8C3D3C	1963 513910	ALBINA AKIMOVA	{"email": "albina_akimova.111972@postgrespro.ru", "phone": "+70545599092"}
0005434550280	222391	8704 927139	SERGEY MAKSIMOV	{"email": "maksimov_s11121976@postgrespro.ru", "phone": "+70998642824"}
0005434550281	222391	2352 364013	NINA POTAPOVA	{"phone": "+70650352169"}
0005434550282	259CBE	5268 386310	ALEKSEY ZAYCEV	{"email": "zaycev-aleksey04011979@postgrespro.ru", "phone": "+70529975415"}
0005434550283	259CBE	5990 702595	DMITRIY SMIRNOV	{"email": "d-smirnov_01091970@postgrespro.ru", "phone": "+70565500261"}
0005434550284	0928F0	1211 024687	DARYA MOROZOVA	{"email": "darya_morozova-031962@postgrespro.ru", "phone": "+70157763441"}
0005434550285	497344	3043 892495	ZOYA SOKOLOVA	{"email": "zoya_sokolova061965@postgrespro.ru", "phone": "+70867024697"}
0005434550286	FE7455	1253 576350	ALEKSANDR TIKHONOV	{"phone": "+70451354535"}
0005434550287	FE7455	2674 051417	ELENA KARPOVA	{"email": "karpova.e-29081970@postgrespro.ru", "phone": "+70733380938"}
0005434550288	34FA2D	8555 787288	TATYANA KUZMINA	{"phone": "+70664470965"}
0005434550289	212E9E	8481 839153	ANASTASIYA SEMENOVA	{"email": "a_semenova_27091973@postgrespro.ru", "phone": "+70396827391"}
0005434550290	0C02D4	6104 925589	NATALYA NOVIKOVA	{"phone": "+70200857039"}
0005434550291	0C02D4	6825 658619	NIKOLAY ABRAMOV	{"phone": "+70867374348"}
0005434550292	B710FF	8588 499523	ALEKSANDR GUSEV	{"email": "a.gusev.15101967@postgrespro.ru", "phone": "+70956428699"}
0005434550293	3837E9	5735 672685	NATALYA MIRONOVA	{"email": "mironovan_1973@postgrespro.ru", "phone": "+70873432061"}
0005434550294	3837E9	3247 650940	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr-27121973@postgrespro.ru", "phone": "+70448349086"}
0005434550295	0DCDEF	2068 635038	OLGA KISELEVA	{"email": "o_kiseleva-091976@postgrespro.ru", "phone": "+70108590308"}
0005434550296	0DCDEF	5244 379851	NIKITA MAKAROV	{"phone": "+70335289227"}
0005434550297	EE845D	3376 254394	OLGA DENISOVA	{"phone": "+70823314721"}
0005434550298	8BF359	8181 157163	ELENA IVANOVA	{"phone": "+70646407154"}
0005434550299	BF6522	2692 082118	SERGEY ANDREEV	{"phone": "+70551895603"}
0005434550300	17BB82	4006 697239	MAKSIM KARPOV	{"phone": "+70351876885"}
0005434550301	E4CD92	9522 605023	DMITRIY KULIKOV	{"email": "dkulikov_01101968@postgrespro.ru", "phone": "+70782444574"}
0005434550302	38B3C5	7681 375211	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr.061969@postgrespro.ru", "phone": "+70560339392"}
0005434550303	38B3C5	6508 096774	SERGEY OSIPOV	{"email": "osipov_s_1968@postgrespro.ru", "phone": "+70146086733"}
0005434550304	F9383C	8941 044800	ILYA SIDOROV	{"email": "sidorov_ilya1979@postgrespro.ru", "phone": "+70649621099"}
0005434550305	A453A2	1352 296489	DARYA NIKIFOROVA	{"email": "d-nikiforova_05091975@postgrespro.ru", "phone": "+70089025067"}
0005434550306	334E56	4624 799529	LARISA ANTONOVA	{"phone": "+70908792040"}
0005434550307	52CE12	3832 677992	VYACHESLAV SOKOLOV	{"email": "v.sokolov-1959@postgrespro.ru", "phone": "+70201444654"}
0005434550308	2014B6	9553 333563	ILYA STEPANOV	{"phone": "+70948124557"}
0005434550309	2014B6	4669 396640	ALEKSANDR SOLOVEV	{"email": "solovev-aleksandr.081971@postgrespro.ru", "phone": "+70841799531"}
0005434550310	09653E	3188 615346	LIDIYA GAVRILOVA	{"email": "gavrilova-l.18101981@postgrespro.ru", "phone": "+70095719772"}
0005434550311	A95520	7880 955952	ELIZAVETA GUSEVA	{"email": "guseva_e_05061981@postgrespro.ru", "phone": "+70476403764"}
0005434550312	C13345	4182 260468	MAKAR EGOROV	{"email": "egorov.m.071975@postgrespro.ru", "phone": "+70483346221"}
0005434550313	C13345	3338 422138	ANASTASIYA KONOVALOVA	{"phone": "+70821945646"}
0005434550314	FFD033	0716 759358	ANNA MASLOVA	{"phone": "+70954304539"}
0005434550315	FFD033	0349 493214	SVETLANA GRISHINA	{"email": "svetlanagrishina021972@postgrespro.ru", "phone": "+70029342108"}
0005434550316	FFD033	8376 942726	ALENA DAVYDOVA	{"email": "a_davydova1972@postgrespro.ru", "phone": "+70690649510"}
0005434550317	CEB21F	0143 029398	VALENTIN ALEKSANDROV	{"phone": "+70991331830"}
0005434550318	9E0D81	3648 159208	TATYANA MATVEEVA	{"email": "t_matveeva_011976@postgrespro.ru", "phone": "+70048100979"}
0005434550319	491869	1828 782781	ALEKSANDR FOMIN	{"phone": "+70649923301"}
0005434550320	30B87B	9608 752882	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov111967@postgrespro.ru", "phone": "+70593621552"}
0005434550321	0D9AFE	5153 633604	LYUDMILA SOKOLOVA	{"email": "l.sokolova081982@postgrespro.ru", "phone": "+70441077027"}
0005434550322	BEF144	9881 873784	EKATERINA NOVIKOVA	{"email": "novikova.e081977@postgrespro.ru", "phone": "+70910868963"}
0005434550323	74B4EF	2913 346912	TATYANA NESTEROVA	{"email": "t_nesterova-061973@postgrespro.ru", "phone": "+70833817920"}
0005434550324	74B4EF	9641 957925	ALEVTINA BELYAEVA	{"phone": "+70110571259"}
0005434550325	E5A613	1826 831582	NATALYA RODIONOVA	{"phone": "+70640372471"}
0005434550326	E5A613	7604 439334	MARIYA BOGDANOVA	{"email": "mariyabogdanova_091964@postgrespro.ru", "phone": "+70074116974"}
0005434550327	8118FD	8081 408611	EKATERINA TIKHONOVA	{"email": "ekaterina.tikhonova-20111969@postgrespro.ru", "phone": "+70371473580"}
0005434550328	6BD12A	2415 469938	NATALYA KUZNECOVA	{"email": "natalya-kuznecova_1975@postgrespro.ru", "phone": "+70580651201"}
0005434550329	087C96	2872 272139	ALEKSEY GRIGOREV	{"phone": "+70216628885"}
0005434550330	087C96	3540 744990	IGOR ISAEV	{"phone": "+70597066465"}
0005434550331	EE543F	2237 134449	EVGENIY EGOROV	{"email": "egorov-evgeniy011966@postgrespro.ru", "phone": "+70071099724"}
0005434550332	55E7FA	1083 238322	ANGELINA KUZNECOVA	{"email": "kuznecova_a.041974@postgrespro.ru", "phone": "+70715983422"}
0005434550333	723C6C	5795 938971	ALEKSEY MELNIKOV	{"email": "aleksey.melnikov.041975@postgrespro.ru", "phone": "+70717741213"}
0005434550334	723C6C	7220 785275	MARAT ZHURAVLEV	{"phone": "+70677854682"}
0005434550335	D74769	6294 351427	VASILIY MOROZOV	{"email": "morozov_v-061980@postgrespro.ru", "phone": "+70434063036"}
0005434550336	1E6B37	5449 841570	NINA EGOROVA	{"email": "egorova_nina_1967@postgrespro.ru", "phone": "+70052398395"}
0005434550337	41C6BF	8494 012235	ELENA IVANOVA	{"phone": "+70339792826"}
0005434550338	0A8228	8619 571116	LARISA TIKHONOVA	{"phone": "+70746128917"}
0005434550339	4EB91C	7741 022473	VALERIY KRASNOV	{"phone": "+70414878170"}
0005434550340	D06CF0	6030 925865	DMITRIY MIKHAYLOV	{"phone": "+70944715456"}
0005434550341	03D215	3707 024248	EVGENIY EGOROV	{"phone": "+70353931312"}
0005434550342	03D215	9747 397137	VLADIMIR KUZNECOV	{"phone": "+70345680107"}
0005434550343	590218	2256 413915	SERGEY MAKSIMOV	{"email": "maksimov.sergey-061968@postgrespro.ru", "phone": "+70304258391"}
0005434550344	3A798E	3908 817091	IRINA PAVLOVA	{"phone": "+70951371161"}
0005434550345	3A798E	9211 552355	LIDIYA MELNIKOVA	{"email": "lidiya-melnikova.30111967@postgrespro.ru", "phone": "+70715498346"}
0005434550346	7B3EB8	4892 343845	ALEKSEY BORISOV	{"phone": "+70889858947"}
0005434550347	0A53D2	2829 203194	ALEKSEY BONDARENKO	{"email": "bondarenko-a-08081969@postgrespro.ru", "phone": "+70700790870"}
0005434550348	518D52	6151 420456	VALERIYA KRASNOVA	{"email": "v-krasnova1980@postgrespro.ru", "phone": "+70603445826"}
0005434550349	79DDF9	1928 271526	ELENA SAVELEVA	{"email": "e-saveleva_1982@postgrespro.ru", "phone": "+70353190593"}
0005434550350	79DDF9	1357 030609	BORIS RODIONOV	{"email": "b.rodionov_061967@postgrespro.ru", "phone": "+70264036896"}
0005434550351	020CE2	8460 776163	LYUDMILA VOLKOVA	{"email": "lvolkova.05061978@postgrespro.ru", "phone": "+70075077400"}
0005434550352	90E528	0786 122551	KSENIYA EFIMOVA	{"email": "k-efimova-1968@postgrespro.ru", "phone": "+70863212854"}
0005434550353	D844DF	2197 937022	ELENA KUZMINA	{"email": "e.kuzmina_071973@postgrespro.ru", "phone": "+70099868358"}
0005434550354	ECE5A6	6505 284714	LYUDMILA ABRAMOVA	{"phone": "+70204357372"}
0005434550355	821E63	1247 692351	NATALIYA IVANOVA	{"email": "nataliya_ivanova.091971@postgrespro.ru", "phone": "+70375832578"}
0005434550356	CA90BB	3028 400718	OLGA GRISHINA	{"email": "olgagrishina081976@postgrespro.ru", "phone": "+70273436694"}
0005434550357	A66C1A	9754 414898	TATYANA GUSEVA	{"phone": "+70293664752"}
0005434550358	F86D82	4727 746697	ALEKSANDR KRASNOV	{"phone": "+70562034982"}
0005434550359	C2D90E	0307 640807	ELENA GORBUNOVA	{"phone": "+70295650082"}
0005434550360	7A061A	9435 964614	YURIY ZAYCEV	{"email": "yuriyzaycev.021973@postgrespro.ru", "phone": "+70904504536"}
0005434550361	7A061A	7946 103817	KONSTANTIN SOROKIN	{"email": "sorokin.k021985@postgrespro.ru", "phone": "+70535629952"}
0005434550362	5CE2DC	3919 882915	PAVEL YAKOVLEV	{"email": "yakovlevp23061969@postgrespro.ru", "phone": "+70952265952"}
0005434550363	5CE2DC	3857 262105	VIKTOR ZAKHAROV	{"email": "zakharov.viktor.18101973@postgrespro.ru", "phone": "+70460457416"}
0005434550364	0A271B	4877 181206	DMITRIY NIKITIN	{"phone": "+70750207053"}
0005434550365	3DAEB1	5141 293666	STANISLAV NAUMOV	{"email": "naumov_s-23011980@postgrespro.ru", "phone": "+70470616535"}
0005434550366	3DAEB1	5910 936861	ELIZAVETA KUZNECOVA	{"phone": "+70403699525"}
0005434550367	705838	4969 091298	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov1971@postgrespro.ru", "phone": "+70029909186"}
0005434550368	705838	6871 438980	ANDREY GORBUNOV	{"phone": "+70065308934"}
0005434550369	68D67F	6958 935386	LIDIYA FILIPPOVA	{"email": "lidiya.filippova_1966@postgrespro.ru", "phone": "+70001977939"}
0005434550370	0BE78F	6083 988875	VLADIMIR CHERNOV	{"email": "v.chernov031968@postgrespro.ru", "phone": "+70085167291"}
0005434550371	93D738	0090 902176	ANATOLIY KARPOV	{"email": "anatoliykarpov.1964@postgrespro.ru", "phone": "+70720874494"}
0005434550372	F4FBDF	7982 273770	VLADIMIR MIKHAYLOV	{"email": "mikhaylovvladimir_081976@postgrespro.ru", "phone": "+70334996669"}
0005434550373	C1B385	7706 628010	DMITRIY MARTYNOV	{"phone": "+70596588831"}
0005434550374	B0C09C	2878 788354	TAMARA ZHUKOVA	{"email": "zhukova.tamara.091965@postgrespro.ru", "phone": "+70943891880"}
0005434550375	B0C09C	1344 007199	OLGA TARASOVA	{"phone": "+70983816987"}
0005434550376	B0C09C	2668 708599	VALENTINA AFANASEVA	{"email": "afanaseva-valentina1970@postgrespro.ru", "phone": "+70310160063"}
0005434550377	8063D2	4704 040510	SERGEY STEPANOV	{"phone": "+70539166817"}
0005434550378	B4B089	7152 761421	VLADISLAV NAZAROV	{"email": "nazarov.v_16051971@postgrespro.ru", "phone": "+70051854782"}
0005434550379	C1CEA4	6588 340033	IVAN FOMIN	{"phone": "+70293344775"}
0005434550380	59E56C	6106 576086	MARINA DAVYDOVA	{"email": "m_davydova091973@postgrespro.ru", "phone": "+70847594082"}
0005434550381	488F37	2439 224170	ANGELINA EGOROVA	{"email": "egorova-a071964@postgrespro.ru", "phone": "+70038414485"}
0005434550382	7A3C9F	3892 417504	YURIY PAVLOV	{"phone": "+70480897548"}
0005434550383	A5854E	4798 242009	NINA KULIKOVA	{"email": "kulikovanina1971@postgrespro.ru", "phone": "+70419661663"}
0005434550384	7D9097	7209 508091	SERGEY GRIGOREV	{"email": "grigorevsergey.031973@postgrespro.ru", "phone": "+70416661690"}
0005434550385	A4CF08	6865 949718	VLADA KOROLEVA	{"phone": "+70460160273"}
0005434550386	0B7DEC	7495 086735	SOFYA PETROVA	{"email": "petrovasofya_23011963@postgrespro.ru", "phone": "+70850313237"}
0005434550387	CC5816	9121 644251	ILYA FEDOTOV	{"phone": "+70422425853"}
0005434550388	1E4E9A	0718 866055	TATYANA MASLOVA	{"email": "maslova.t_04011977@postgrespro.ru", "phone": "+70511127385"}
0005434550389	1E4E9A	4528 176434	ANDREY KONOVALOV	{"phone": "+70141776846"}
0005434550390	02F425	3299 410202	TATYANA KISELEVA	{"email": "kiseleva-t-091982@postgrespro.ru", "phone": "+70352248571"}
0005434550391	02F425	2130 906978	ALINA CHERNOVA	{"phone": "+70307482185"}
0005434550392	AB5076	3216 331578	ELENA ZHURAVLEVA	{"email": "elena.zhuravleva_26041976@postgrespro.ru", "phone": "+70086194862"}
0005434550393	7EFE0E	9914 195001	KONSTANTIN ZHUKOV	{"email": "k-zhukov_061985@postgrespro.ru", "phone": "+70024680864"}
0005434550394	25EBEA	7887 015380	POLINA BOGDANOVA	{"email": "bogdanova_polina-1977@postgrespro.ru", "phone": "+70692331407"}
0005434550395	25EBEA	3029 280109	ELENA EGOROVA	{"phone": "+70289458479"}
0005434550396	25EBEA	0589 029315	DAMIR POPOV	{"email": "popov-d.091965@postgrespro.ru", "phone": "+70865026839"}
0005434550397	951BCD	3851 454432	OLGA ZOTOVA	{"email": "olga_zotova_1967@postgrespro.ru", "phone": "+70311659145"}
0005434550398	9A369F	4451 726882	SERGEY MIKHAYLOV	{"phone": "+70540452585"}
0005434550399	9A369F	9530 516978	ALEKSANDR BARANOV	{"email": "baranov.aleksandr.1974@postgrespro.ru", "phone": "+70413669166"}
0005434550400	9A369F	0470 401094	MAKSIM NIKOLAEV	{"email": "nikolaev_maksim22111978@postgrespro.ru", "phone": "+70679987320"}
0005434550401	E44CCF	9972 781738	IVAN FROLOV	{"email": "i.frolov-1964@postgrespro.ru", "phone": "+70828450254"}
0005434550402	A70B9E	4003 401522	MAKSIM OSIPOV	{"phone": "+70350324501"}
0005434550403	A70B9E	7485 798213	OLESYA POLYAKOVA	{"email": "olesya-polyakova_1962@postgrespro.ru", "phone": "+70059475811"}
0005434550404	CCC9D0	9064 002964	OLGA VASILEVA	{"phone": "+70392443075"}
0005434550405	2F18BF	7958 455331	ALEKSEY SEMENOV	{"email": "semenov.aleksey1971@postgrespro.ru", "phone": "+70079410387"}
0005434550406	2F18BF	0446 336903	LYUBOV LAZAREVA	{"phone": "+70476580405"}
0005434550407	796A96	2598 176727	ELENA SIDOROVA	{"email": "sidorova_e_101974@postgrespro.ru", "phone": "+70415336963"}
0005434550408	796A96	8362 472400	ALMIRA NESTEROVA	{"email": "nesterovaalmira_041974@postgrespro.ru", "phone": "+70424751018"}
0005434550409	796A96	4333 570291	ANNA PAVLOVA	{"phone": "+70314068762"}
0005434550410	4C112E	8631 022193	PETR DENISOV	{"email": "denisovpetr.1965@postgrespro.ru", "phone": "+70543304972"}
0005434550411	4C112E	7392 430641	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova17111964@postgrespro.ru", "phone": "+70369347933"}
0005434550412	791083	8353 819304	MAKSIM SOROKIN	{"phone": "+70959066546"}
0005434550413	E57F0C	4631 948235	IRINA EFIMOVA	{"email": "efimova-i_25091973@postgrespro.ru", "phone": "+70001489368"}
0005434550414	12D581	8933 171022	RAMILYA BELOVA	{"phone": "+70665342832"}
0005434550415	3130F7	0708 716264	VALENTINA EFREMOVA	{"email": "efremova.v-06091978@postgrespro.ru", "phone": "+70464918811"}
0005434550416	036CD0	4542 113113	NIKOLAY DENISOV	{"email": "ndenisov-23021971@postgrespro.ru", "phone": "+70579545521"}
0005434550417	036CD0	4650 636012	ALEKSANDR ISAEV	{"email": "aleksandr_isaev-28041966@postgrespro.ru", "phone": "+70026908262"}
0005434550418	036CD0	9020 206506	LIDIYA POPOVA	{"phone": "+70209333329"}
0005434550419	6C6DA6	5753 207076	VLADISLAV NOVIKOV	{"phone": "+70324232997"}
0005434550420	688443	5130 161167	VIKTORIYA VASILEVA	{"email": "viktoriyavasileva15101971@postgrespro.ru", "phone": "+70444824399"}
0005434550421	688443	5271 013440	VLADIMIR SIDOROV	{"phone": "+70491567991"}
0005434550422	688443	7824 226745	NIKOLAY NOVIKOV	{"email": "nikolaynovikov_1979@postgrespro.ru", "phone": "+70143976575"}
0005434550423	83D748	5996 947921	LYUDMILA ORLOVA	{"phone": "+70184266329"}
0005434550424	CF52F8	7947 435832	GALINA ILINA	{"email": "ilinagalina-28071963@postgrespro.ru", "phone": "+70687162835"}
0005434550425	6CCCF3	1260 659332	NINA KUZNECOVA	{"email": "ninakuznecova.1983@postgrespro.ru", "phone": "+70300593719"}
0005434550426	A7CA49	4887 474516	MARIYA VOLKOVA	{"email": "volkovam.1974@postgrespro.ru", "phone": "+70672863007"}
0005434550427	239D02	5203 792689	ANDREY BELOV	{"phone": "+70668909969"}
0005434550428	82F09E	3598 410828	ELIZAVETA KARPOVA	{"email": "elizaveta-karpova-021968@postgrespro.ru", "phone": "+70184131965"}
0005434550429	6B0F80	0122 552642	MARINA KRASNOVA	{"phone": "+70090564893"}
0005434550430	6B0F80	3776 954880	MIKHAIL GERASIMOV	{"email": "m.gerasimov.061959@postgrespro.ru", "phone": "+70728461084"}
0005434550431	A61E7A	8114 879169	LYUDMILA DAVYDOVA	{"email": "ldavydova-1974@postgrespro.ru", "phone": "+70446417241"}
0005434550432	57F8E5	7883 123140	LYUDMILA EGOROVA	{"email": "egorova.l_091973@postgrespro.ru", "phone": "+70099425509"}
0005434550433	8D6F96	8044 479485	NATALYA KOLESNIKOVA	{"phone": "+70662188027"}
0005434550434	09D460	0454 032447	SERGEY KUZNECOV	{"phone": "+70781828404"}
0005434550435	09D460	8126 961673	NIKOLAY GAVRILOV	{"email": "gavrilov-nikolay.30111969@postgrespro.ru", "phone": "+70427701584"}
0005434550436	E7A6F7	5885 679509	ALEKSANDR VOROBEV	{"phone": "+70694433501"}
0005434550437	209E08	6229 887973	LYUDMILA ANTONOVA	{"email": "lyudmila_antonova1969@postgrespro.ru", "phone": "+70194513539"}
0005434550438	7F8BE4	1536 687707	DENIS GAVRILOV	{"phone": "+70448429588"}
0005434550439	7F8BE4	3759 172292	OLGA SEMENOVA	{"email": "semenova_o_021972@postgrespro.ru", "phone": "+70673141461"}
0005434550440	858140	1903 629967	TATYANA LOGINOVA	{"phone": "+70948623540"}
0005434550441	858140	0405 701765	ANDREY SEMENOV	{"phone": "+70481890490"}
0005434550442	858140	9929 013743	SERGEY MOISEEV	{"email": "moiseev.s1971@postgrespro.ru", "phone": "+70342790301"}
0005434550443	6ACB71	3962 280588	DANIYA PETROVA	{"phone": "+70097834407"}
0005434550444	A5AEB2	3717 859333	ALEKSANDR FEDOTOV	{"email": "afedotov_05041976@postgrespro.ru", "phone": "+70589349641"}
0005434550445	A5AEB2	0278 520918	ALEKSEY NAUMOV	{"email": "a.naumov101967@postgrespro.ru", "phone": "+70611864220"}
0005434550446	6A4351	1259 889242	MARIYA MARTYNOVA	{"email": "m-martynova.1969@postgrespro.ru", "phone": "+70511737369"}
0005434550447	45078C	5058 586446	ZOYA IVANOVA	{"phone": "+70301303166"}
0005434550448	A262E9	6307 070979	MIKHAIL SOLOVEV	{"phone": "+70889294830"}
0005434550449	1F7116	0598 638878	OLGA SCHERBAKOVA	{"email": "scherbakovao31031953@postgrespro.ru", "phone": "+70617204949"}
0005434550450	E9EE3B	6569 483972	PAVEL SIDOROV	{"phone": "+70907136852"}
0005434550451	DDFA6B	6318 864586	MARINA KRASNOVA	{"email": "krasnova-marina1970@postgrespro.ru", "phone": "+70521295327"}
0005434550452	4011B5	9913 491994	IRINA BORISOVA	{"phone": "+70986478078"}
0005434550453	4011B5	1682 837870	OLGA ZAKHAROVA	{"phone": "+70409384544"}
0005434550454	4011B5	2948 921394	ALEKSANDRA KOROLEVA	{"email": "koroleva-a_06021970@postgrespro.ru", "phone": "+70809525082"}
0005434550455	45DAFB	4077 692447	IRINA ALEKSANDROVA	{"phone": "+70653819230"}
0005434550456	45DAFB	4029 975670	ANASTASIYA POPOVA	{"phone": "+70647171378"}
0005434550457	7BC62B	6735 336033	YURIY IVANOV	{"email": "yuriyivanov-1977@postgrespro.ru", "phone": "+70569234084"}
0005434550458	7BC62B	7995 768620	IRINA KULIKOVA	{"phone": "+70793900834"}
0005434550459	1B0621	7278 298110	MARIYA SCHERBAKOVA	{"email": "m-scherbakova1974@postgrespro.ru", "phone": "+70313874292"}
0005434550460	4EDE96	1804 174610	ELENA KUZMINA	{"email": "kuzmina_elena_1980@postgrespro.ru", "phone": "+70021437705"}
0005434550461	755ABD	9238 270630	ELENA BELOVA	{"email": "elena_belova091971@postgrespro.ru", "phone": "+70541956709"}
0005434550462	755ABD	0946 841658	SERGEY KUZNECOV	{"phone": "+70668681309"}
0005434550463	EFF2FC	5827 263155	VLADIMIR KUZMIN	{"phone": "+70720339313"}
0005434550464	5ECF74	2407 364486	VASILIY KARPOV	{"phone": "+70767376809"}
0005434550465	5ECF74	8115 278451	DARYA IVANOVA	{"phone": "+70233469940"}
0005434550466	BA3F49	0691 656341	VASILISA NIKIFOROVA	{"email": "nikiforova-vasilisa-09101969@postgrespro.ru", "phone": "+70077522623"}
0005434550467	BA3F49	0645 905526	ALEKSANDR PAVLOV	{"email": "apavlov.03021982@postgrespro.ru", "phone": "+70933375528"}
0005434550468	9AECAB	7763 740628	VLADISLAV BONDARENKO	{"email": "v.bondarenko_081973@postgrespro.ru", "phone": "+70722448738"}
0005434550469	9AECAB	6702 600640	VASILIY FILIPPOV	{"phone": "+70532087880"}
0005434550470	981A80	7285 751781	STANISLAV SMIRNOV	{"email": "smirnov.s_111969@postgrespro.ru", "phone": "+70772356827"}
0005434550471	981A80	1169 097581	ELENA SMIRNOVA	{"email": "elena.smirnova.1979@postgrespro.ru", "phone": "+70375771982"}
0005434550472	7C5367	6942 657246	GULIYA FILIPPOVA	{"email": "g.filippova.1972@postgrespro.ru", "phone": "+70927837646"}
0005434550473	D0CF19	8169 838198	ANATOLIY VOROBEV	{"phone": "+70727646203"}
0005434550474	505198	7710 976604	VALENTINA TIKHONOVA	{"email": "v_tikhonova.01081973@postgrespro.ru", "phone": "+70739000570"}
0005434550475	153E42	1002 166310	OKSANA KOZLOVA	{"email": "kozlova_oksana-101977@postgrespro.ru", "phone": "+70194669989"}
0005434550476	9AE197	4510 192276	TATYANA SIDOROVA	{"email": "tatyana-sidorova.121980@postgrespro.ru", "phone": "+70427106198"}
0005434550477	886383	9728 266795	ANTONINA TARASOVA	{"email": "tarasovaantonina.111973@postgrespro.ru", "phone": "+70164226433"}
0005434550478	886383	6290 590230	GENNADIY POPOV	{"email": "gpopov_1977@postgrespro.ru", "phone": "+70136371404"}
0005434550479	76E950	7097 738834	TATYANA VLASOVA	{"email": "vlasova.t1966@postgrespro.ru", "phone": "+70761386776"}
0005434550480	55349A	8305 508152	MAKSIM SAVELEV	{"email": "savelev_m.1967@postgrespro.ru", "phone": "+70875036426"}
0005434550481	55349A	6190 793710	PAVEL CHERNOV	{"phone": "+70080570836"}
0005434550482	FFA333	1774 038537	ANATOLIY PAVLOV	{"email": "pavlov_a_18071964@postgrespro.ru", "phone": "+70843490146"}
0005434550483	FFADF2	1372 428838	VERA ZAKHAROVA	{"phone": "+70940907232"}
0005434550596	389C04	4164 016994	IRINA KUZNECOVA	{"phone": "+70422050584"}
0005434550484	FFADF2	1091 928427	ALEKSANDR KARPOV	{"email": "karpov_aleksandr.01111972@postgrespro.ru", "phone": "+70063557750"}
0005434550485	D54628	0027 354000	IRINA PETROVA	{"phone": "+70215989749"}
0005434550486	D54628	1351 638489	KONSTANTIN GERASIMOV	{"email": "gerasimov-konstantin.1978@postgrespro.ru", "phone": "+70892572470"}
0005434550487	86C6FF	2025 861652	ALEKSEY IVANOV	{"email": "ivanovaleksey24031985@postgrespro.ru", "phone": "+70266406218"}
0005434550488	8AB522	1764 549874	ELIZAVETA BELOVA	{"email": "ebelova-19021971@postgrespro.ru", "phone": "+70373085990"}
0005434550489	B4DC72	4403 692058	ALEKSANDR EGOROV	{"email": "egorov.a.19081976@postgrespro.ru", "phone": "+70482149111"}
0005434550490	1DBC8E	6193 793593	LYUBOV KUZMINA	{"email": "l.kuzmina04101973@postgrespro.ru", "phone": "+70965707872"}
0005434550491	25405E	9751 616014	SAVELIY PETROV	{"phone": "+70360926182"}
0005434550492	25405E	2292 412301	ANASTASIYA KUZMINA	{"email": "anastasiya.kuzmina09101978@postgrespro.ru", "phone": "+70832073625"}
0005434550493	E7892F	0121 670106	TIMOFEY KONOVALOV	{"email": "t_konovalov.031963@postgrespro.ru", "phone": "+70700364589"}
0005434550494	97D34E	1056 865050	DMITRIY TIMOFEEV	{"email": "timofeev_d051969@postgrespro.ru", "phone": "+70986923742"}
0005434550495	D8FCC5	0822 902167	DENIS ANTONOV	{"phone": "+70832675392"}
0005434550496	68A80C	4962 619638	GALINA KOROLEVA	{"email": "g-koroleva-1959@postgrespro.ru", "phone": "+70718545327"}
0005434550497	3CD348	1714 774285	TATYANA DMITRIEVA	{"email": "dmitrieva_t_101961@postgrespro.ru", "phone": "+70979901899"}
0005434550498	9ACDA4	4123 781466	DMITRIY NOVIKOV	{"phone": "+70283347442"}
0005434550499	414C8B	4497 891749	GERMAN BELOV	{"phone": "+70422610315"}
0005434550500	199BAF	3127 128297	SVETLANA MIKHAYLOVA	{"phone": "+70621985688"}
0005434550501	199BAF	1248 699285	NATALYA SAVELEVA	{"phone": "+70742025669"}
0005434550502	B6A814	5502 073096	YULIYA VLASOVA	{"email": "y.vlasova-18031976@postgrespro.ru", "phone": "+70628019128"}
0005434550503	FC21D9	6118 594775	SVETLANA SIDOROVA	{"phone": "+70189490512"}
0005434550504	37BFB7	8860 587241	ELMIRA YAKOVLEVA	{"phone": "+70292094054"}
0005434550505	D32352	7331 617449	VALERIY KUZNECOV	{"phone": "+70411385574"}
0005434550506	6B250C	7939 947287	SVETLANA BARANOVA	{"email": "svetlanabaranova011969@postgrespro.ru", "phone": "+70203242672"}
0005434550507	6B250C	1953 877132	VALENTINA MASLOVA	{"phone": "+70974466279"}
0005434550508	B2E55A	9280 768121	SERGEY POPOV	{"email": "popov.s_03051974@postgrespro.ru", "phone": "+70500151987"}
0005434550509	BBCD71	7688 951360	SERGEY ILIN	{"phone": "+70758516319"}
0005434550510	355D88	9465 866300	LYUDMILA POPOVA	{"email": "lpopova_27111977@postgrespro.ru", "phone": "+70930731070"}
0005434550511	4B4164	3118 895259	EVGENIY NIKOLAEV	{"email": "nikolaev_e_18061964@postgrespro.ru", "phone": "+70192950124"}
0005434550512	6C6C42	5786 295496	EVGENIY MIKHAYLOV	{"phone": "+70472294507"}
0005434550513	6C6C42	8845 072922	NINA SOROKINA	{"email": "sorokina.nina1972@postgrespro.ru", "phone": "+70766601694"}
0005434550514	298D1F	3418 310444	EKATERINA NOVIKOVA	{"email": "novikova.e07031973@postgrespro.ru", "phone": "+70670954286"}
0005434550515	5E65DB	1220 594347	OLGA DMITRIEVA	{"email": "dmitrieva_o-081979@postgrespro.ru", "phone": "+70706094591"}
0005434550516	5E65DB	2755 548422	DMITRIY MATVEEV	{"email": "matveevd-101972@postgrespro.ru", "phone": "+70202822930"}
0005434550517	76F8CF	0999 563630	ANDREY SOKOLOV	{"phone": "+70442956122"}
0005434550518	76F8CF	8187 868716	VLADISLAV ZHURAVLEV	{"phone": "+70286707769"}
0005434550519	880BF7	0072 079836	PETR GERASIMOV	{"phone": "+70095359370"}
0005434550520	0E264A	0222 305818	SERGEY VOROBEV	{"phone": "+70067727402"}
0005434550521	80F569	2487 546100	SERGEY GAVRILOV	{"phone": "+70471442298"}
0005434550522	F559A0	3487 397999	ALEKSEY ABRAMOV	{"email": "abramova031960@postgrespro.ru", "phone": "+70397312803"}
0005434550636	957E71	9814 224760	VALENTINA KUZNECOVA	{"phone": "+70863562100"}
0005434550523	8344F0	7109 559644	VLADIMIR GUSEV	{"email": "v_gusev-01081962@postgrespro.ru", "phone": "+70959765524"}
0005434550524	7B6206	7722 331986	ROMAN MIRONOV	{"phone": "+70345687923"}
0005434550525	7B6206	7982 609021	NIKOLAY VASILEV	{"email": "vasilev-nikolay101980@postgrespro.ru", "phone": "+70639352696"}
0005434550526	F33B8C	7264 628259	LYUDMILA KUZMINA	{"email": "l_kuzmina.121976@postgrespro.ru", "phone": "+70670062358"}
0005434550527	9E608E	5036 394059	ALINA NAUMOVA	{"email": "naumovaa1970@postgrespro.ru", "phone": "+70947810711"}
0005434550528	19F814	3847 239764	VLADIMIR MAKSIMOV	{"email": "maksimov.v-041977@postgrespro.ru", "phone": "+70269546145"}
0005434550529	5F3765	9071 050965	MARIYA FILATOVA	{"email": "mariyafilatova_29061973@postgrespro.ru", "phone": "+70545512082"}
0005434550530	C99064	9686 046702	LYUBOV KOMAROVA	{"phone": "+70666331243"}
0005434550531	C99064	0767 875000	DARYA FADEEVA	{"phone": "+70475293315"}
0005434550532	4E0515	4161 408224	VALENTIN MELNIKOV	{"phone": "+70634051223"}
0005434550533	23C654	1417 141516	MARIYA TARASOVA	{"email": "tarasovam_1979@postgrespro.ru", "phone": "+70172453835"}
0005434550534	23C654	0614 678486	VLADIMIR KUZNECOV	{"phone": "+70204386935"}
0005434550535	DA60EE	8939 129026	YULIYA MATVEEVA	{"phone": "+70625301957"}
0005434550536	203900	7199 757210	IVAN GORBUNOV	{"email": "gorbunov.ivan-071981@postgrespro.ru", "phone": "+70670176073"}
0005434550537	3FC425	3892 112713	MIKHAIL MAKSIMOV	{"email": "maksimovm_26081964@postgrespro.ru", "phone": "+70639174729"}
0005434550538	3FC425	1820 138343	LYUBOV KOLESNIKOVA	{"email": "kolesnikova.lyubov-1973@postgrespro.ru", "phone": "+70410391787"}
0005434550539	3FC425	0674 476850	SERGEY MEDVEDEV	{"phone": "+70084829403"}
0005434550540	0E07AE	5032 323732	ELIZAVETA ANDREEVA	{"email": "elizaveta.andreeva071968@postgrespro.ru", "phone": "+70196976408"}
0005434550541	0E07AE	6904 947084	DMITRIY GERASIMOV	{"phone": "+70877044961"}
0005434550542	F88272	1766 631348	GALINA DAVYDOVA	{"phone": "+70128056373"}
0005434550543	3E8269	8697 398747	OLEG MEDVEDEV	{"phone": "+70752442900"}
0005434550544	1289EF	5438 566922	DMITRIY VASILEV	{"email": "dmitriy-vasilev.25071969@postgrespro.ru", "phone": "+70875096707"}
0005434550545	895C67	1415 274381	ANASTASIYA ZAKHAROVA	{"email": "a.zakharova_1963@postgrespro.ru", "phone": "+70406566910"}
0005434550546	D723D5	7560 522589	RAISA KALININA	{"email": "kalinina-raisa.111969@postgrespro.ru", "phone": "+70666567686"}
0005434550547	D92ED3	3247 967566	ALEKSEY TIMOFEEV	{"phone": "+70947297250"}
0005434550548	3718A1	5274 861120	EVGENIY SOLOVEV	{"phone": "+70752353272"}
0005434550549	AF3F51	0437 165252	LIDIYA RYABOVA	{"phone": "+70501534818"}
0005434550550	AF3F51	6955 456122	TATYANA IVANOVA	{"email": "tivanova.19111976@postgrespro.ru", "phone": "+70139155515"}
0005434550551	995C4C	8697 450233	DARYA KUZMINA	{"phone": "+70407576524"}
0005434550552	253559	7579 530930	VADIM KRASNOV	{"email": "krasnov.vadim_11041971@postgrespro.ru", "phone": "+70648214437"}
0005434550553	F86C07	3106 084808	YURIY SCHERBAKOV	{"email": "yuriy.scherbakov.1973@postgrespro.ru", "phone": "+70368323135"}
0005434550554	5D3116	3579 590741	EKATERINA EGOROVA	{"phone": "+70092583341"}
0005434550555	CE444B	6229 253682	TIMOFEY KONOVALOV	{"phone": "+70421093347"}
0005434550556	CE444B	6285 630780	IRINA NESTEROVA	{"email": "nesterova.i_091972@postgrespro.ru", "phone": "+70476904157"}
0005434550557	7F1725	4451 825473	DMITRIY KOROLEV	{"phone": "+70887463816"}
0005434550558	495D0F	9930 811225	IGOR SOROKIN	{"phone": "+70320302446"}
0005434550559	495D0F	8294 661288	NATALYA POPOVA	{"phone": "+70276108789"}
0005434550560	0297BD	6601 840757	NADEZHDA POPOVA	{"email": "popovanadezhda031964@postgrespro.ru", "phone": "+70393166360"}
0005434550561	4E4467	7816 968480	SERGEY SOKOLOV	{"phone": "+70580571561"}
0005434550562	4E4467	2106 955067	ANNA PETROVA	{"phone": "+70713686655"}
0005434550563	79DCA2	7317 649829	NATALYA MARTYNOVA	{"email": "natalya-martynova1982@postgrespro.ru", "phone": "+70262383295"}
0005434550564	79DCA2	2818 810494	LYUDMILA LOGINOVA	{"email": "loginova-lyudmila1975@postgrespro.ru", "phone": "+70332503256"}
0005434550565	79DCA2	5415 756283	EDUARD KRASNOV	{"phone": "+70023333357"}
0005434550566	79DCA2	7242 952604	ALEKSANDR MATVEEV	{"email": "matveevaleksandr111961@postgrespro.ru", "phone": "+70914232813"}
0005434550567	800B30	4403 268471	OLEG ANTONOV	{"phone": "+70936341886"}
0005434550568	800B30	7184 900727	LYUDMILA VOLKOVA	{"email": "l_volkova-1968@postgrespro.ru", "phone": "+70723855833"}
0005434550569	030D04	1604 128561	ELENA ZAYCEVA	{"phone": "+70267141025"}
0005434550570	162763	5838 167389	SALAVAT FILIPPOV	{"email": "salavatfilippov-1980@postgrespro.ru", "phone": "+70852132483"}
0005434550571	A81199	5996 373169	SVETLANA FILATOVA	{"phone": "+70011761199"}
0005434550572	A81199	9306 163480	SERGEY POPOV	{"email": "s.popov-051969@postgrespro.ru", "phone": "+70835163402"}
0005434550573	221326	1860 521796	ANTONINA MIRONOVA	{"phone": "+70396385300"}
0005434550574	465363	6365 434639	NADEZHDA ORLOVA	{"phone": "+70662321472"}
0005434550575	4211AD	1767 495658	YURIY YAKOVLEV	{"email": "yakovlev.yuriy.051973@postgrespro.ru", "phone": "+70956250611"}
0005434550576	B7AA3D	5061 468554	DENIS TARASOV	{"phone": "+70446221801"}
0005434550577	395F5F	4731 265600	MAKSIM IVANOV	{"email": "maksim.ivanov.28071963@postgrespro.ru", "phone": "+70839492608"}
0005434550578	395F5F	7009 164369	KARINA ALEKSANDROVA	{"phone": "+70544353665"}
0005434550579	13B1CB	7115 833987	ROMAN MAKAROV	{"email": "makarov.roman-1977@postgrespro.ru", "phone": "+70881798334"}
0005434550580	13B1CB	4114 817308	TATYANA VASILEVA	{"email": "t_vasileva-1977@postgrespro.ru", "phone": "+70382044364"}
0005434550581	E7DA97	0422 525955	DENIS KISELEV	{"email": "kiselev-d.081962@postgrespro.ru", "phone": "+70879669566"}
0005434550582	E33A6B	0377 447712	OLESYA DANILOVA	{"email": "danilovaolesya.20021971@postgrespro.ru", "phone": "+70545239001"}
0005434550583	2CE4A7	3939 069265	NADEZHDA VASILEVA	{"phone": "+70124760818"}
0005434550584	F73383	7784 914557	MARINA KUZNECOVA	{"phone": "+70575704192"}
0005434550585	5A2A43	1349 330039	VYACHESLAV ZAKHAROV	{"email": "v_zakharov-15071970@postgrespro.ru", "phone": "+70422086335"}
0005434550586	5E6404	3901 055423	DMITRIY SCHERBAKOV	{"email": "scherbakovd_1971@postgrespro.ru", "phone": "+70117855926"}
0005434550587	5E6404	3653 837342	DMITRIY KOROLEV	{"email": "dkorolev-28101968@postgrespro.ru", "phone": "+70700654999"}
0005434550588	2DE1B2	4002 810162	KSENIYA ALEKSEEVA	{"email": "alekseeva-kseniya.1967@postgrespro.ru", "phone": "+70422955428"}
0005434550589	2DE1B2	4769 786375	ELENA TIKHONOVA	{"email": "e-tikhonova-061970@postgrespro.ru", "phone": "+70425890248"}
0005434550590	3C9D1B	7291 280697	SVETLANA KRASNOVA	{"phone": "+70881361107"}
0005434550591	AC916A	8164 758042	OLGA GUSEVA	{"phone": "+70162672769"}
0005434550592	4D40A5	9370 626440	ROMAN ROMANOV	{"phone": "+70374425850"}
0005434550593	018F4D	8692 912714	VLADIMIR EGOROV	{"email": "egorovvladimir111970@postgrespro.ru", "phone": "+70867354942"}
0005434550594	35BBE6	5280 479393	NATALYA SAVELEVA	{"email": "natalya-saveleva-021973@postgrespro.ru", "phone": "+70863983334"}
0005434550595	206766	1043 257002	RAISA ZOTOVA	{"phone": "+70673313894"}
0005434550597	389C04	1116 536021	VALENTINA KOZLOVA	{"email": "kozlova-valentina.21111977@postgrespro.ru", "phone": "+70052862120"}
0005434550598	77F286	5512 954920	ALEKSANDR CHERNOV	{"phone": "+70922241241"}
0005434550599	4F21DE	4484 771694	ELENA KULIKOVA	{"email": "kulikova-elena1972@postgrespro.ru", "phone": "+70411735355"}
0005434550600	A91060	5909 233100	GALINA MALYSHEVA	{"phone": "+70547754331"}
0005434550601	A91060	4961 897636	DMITRIY ZHUKOV	{"phone": "+70791074176"}
0005434550602	7327F5	9246 267236	MARGARITA ZAYCEVA	{"phone": "+70903139475"}
0005434550603	8194CB	1612 209513	NIKOLAY KUZNECOV	{"phone": "+70542380982"}
0005434550604	A3474D	7887 044665	IVAN PETROV	{"phone": "+70039254478"}
0005434550605	000DBE	3667 786392	VALENTINA ANISIMOVA	{"email": "anisimova.v.16031966@postgrespro.ru", "phone": "+70656742431"}
0005434550606	000DBE	5856 298169	NADEZHDA GRISHINA	{"phone": "+70403680498"}
0005434550607	136027	3812 012732	MARINA MARTYNOVA	{"email": "martynova-m.15081960@postgrespro.ru", "phone": "+70675043316"}
0005434550608	BF3391	1127 409727	VERONIKA ISAEVA	{"email": "v.isaeva-1977@postgrespro.ru", "phone": "+70102159294"}
0005434550609	3647BD	2048 773834	OLGA BORISOVA	{"phone": "+70395482499"}
0005434550610	3647BD	6987 679638	YULIYA ANISIMOVA	{"email": "yuliya.anisimova_09031972@postgrespro.ru", "phone": "+70675667411"}
0005434550611	3647BD	5754 325362	LYUDMILA MOISEEVA	{"email": "moiseeva-lyudmila081976@postgrespro.ru", "phone": "+70129749610"}
0005434550612	8AD2D1	8931 547089	ROMAN ILIN	{"email": "ilin_roman_1985@postgrespro.ru", "phone": "+70848567080"}
0005434550613	8AD2D1	4431 744834	VIKTOR MELNIKOV	{"phone": "+70166422112"}
0005434550614	8AD2D1	7720 681907	MIKHAIL KUZNECOV	{"phone": "+70827675121"}
0005434550615	5D6E8A	0468 520343	OLGA BELOVA	{"email": "olga-belova-061958@postgrespro.ru", "phone": "+70594443184"}
0005434550616	7ABF4C	0381 052670	OLEG MAKAROV	{"email": "omakarov1982@postgrespro.ru", "phone": "+70408408689"}
0005434550617	8D8A10	9270 017996	OLEG MIRONOV	{"phone": "+70027406338"}
0005434550618	6A32C2	5813 812877	IGOR ISAEV	{"phone": "+70971709811"}
0005434550619	C8B3A4	8545 957984	ANNA NAUMOVA	{"email": "anna.naumova_1975@postgrespro.ru", "phone": "+70900716358"}
0005434550620	C8B3A4	7703 874082	MIKHAIL KULIKOV	{"phone": "+70245877035"}
0005434550621	82AC7D	3538 741269	VALENTINA ILINA	{"email": "valentinailina011979@postgrespro.ru", "phone": "+70668982427"}
0005434550622	82AC7D	5167 321756	ALLA ISAEVA	{"phone": "+70734132138"}
0005434550623	A2727C	5663 807555	OKSANA VLASOVA	{"phone": "+70648959209"}
0005434550624	A2727C	8430 564688	VERA NIKITINA	{"email": "nikitina_vera.23081974@postgrespro.ru", "phone": "+70808176235"}
0005434550625	2694B5	6114 409629	VYACHESLAV DAVYDOV	{"email": "davydovvyacheslav-03071966@postgrespro.ru", "phone": "+70124229322"}
0005434550626	2694B5	8235 884691	MARIYA EFREMOVA	{"phone": "+70043853128"}
0005434550627	D7926D	5265 277375	KIRILL ALEKSEEV	{"phone": "+70372447964"}
0005434550628	1053B0	7842 917650	VIKTOR PAVLOV	{"phone": "+70030197985"}
0005434550629	CDAB06	2363 711527	KIRILL VASILEV	{"email": "k.vasilev.1981@postgrespro.ru", "phone": "+70881777668"}
0005434550630	CDAB06	6263 980297	GALINA ZAKHAROVA	{"phone": "+70066412840"}
0005434550631	4FE392	3427 299755	EVGENIY ZHUKOV	{"email": "zhukov_e_18111981@postgrespro.ru", "phone": "+70587157825"}
0005434550632	4FE392	5383 321217	NATALYA TARASOVA	{"phone": "+70299153214"}
0005434550633	6BCDEF	6195 696544	AIDA KOROLEVA	{"phone": "+70994087312"}
0005434550634	E43796	1091 743475	MIKHAIL MIKHAYLOV	{"email": "mikhaylov.m-1970@postgrespro.ru", "phone": "+70023575601"}
0005434550635	788652	9635 085167	ANASTASIYA SAVELEVA	{"phone": "+70388171538"}
0005434550637	06FD60	6201 947570	SVETLANA KUZNECOVA	{"phone": "+70929785397"}
0005434550638	06FD60	5747 862042	VITALIY SEMENOV	{"email": "semenov-v.1980@postgrespro.ru", "phone": "+70896153195"}
0005434550639	3D9517	0376 575207	LINAR MAKAROV	{"email": "l-makarov061971@postgrespro.ru", "phone": "+70137312555"}
0005434550640	BA4D83	2768 130728	EVGENIY BORISOV	{"phone": "+70554409523"}
0005434550641	F9AF0C	0789 723767	ZINAIDA OVCHINNIKOVA	{"phone": "+70868308086"}
0005434550642	381760	6468 776982	RAVIL BORISOV	{"phone": "+70344884309"}
0005434550643	A93147	6926 442909	DMITRIY VOLKOV	{"email": "volkov_d07041977@postgrespro.ru", "phone": "+70979333401"}
0005434550644	555846	9475 770966	VALENTINA BORISOVA	{"phone": "+70022833001"}
0005434550645	451987	3286 940567	DENIS PETROV	{"email": "petrov_denis-071980@postgrespro.ru", "phone": "+70094425810"}
0005434550646	5A7BC7	8755 559255	ROMAN VASILEV	{"email": "vasilev_r_091978@postgrespro.ru", "phone": "+70278843201"}
0005434550647	5A7BC7	0223 645135	KIRILL IVANOV	{"phone": "+70732068278"}
0005434550648	5A7BC7	6149 284361	OKSANA NIKIFOROVA	{"email": "nikiforova.oksana-121983@postgrespro.ru", "phone": "+70755259450"}
0005434550649	3DC482	3928 484506	OLGA MOROZOVA	{"phone": "+70695536047"}
0005434550650	3DC482	8628 114758	ANATOLIY MAKAROV	{"email": "makarov.a_26031970@postgrespro.ru", "phone": "+70101525236"}
0005434550651	3F3859	2959 834494	GENNADIY KULIKOV	{"email": "kulikov.gennadiy_1971@postgrespro.ru", "phone": "+70836388573"}
0005434550652	E804BE	3492 952080	GALINA LAZAREVA	{"email": "g-lazareva31011976@postgrespro.ru", "phone": "+70087440156"}
0005434550653	E804BE	2621 629164	MARIYA MIRONOVA	{"email": "mariya.mironova.061983@postgrespro.ru", "phone": "+70129497964"}
0005434550654	E804BE	5074 925108	NATALYA ANDREEVA	{"phone": "+70076655400"}
0005434550655	F4C9D9	2861 296409	NADEZHDA FEDOROVA	{"phone": "+70869231837"}
0005434550656	9F4B4C	8691 185441	LYUBOV MIKHAYLOVA	{"phone": "+70157904453"}
0005434550657	9F4B4C	3058 718723	SEMEN TARASOV	{"email": "tarasovsemen.1982@postgrespro.ru", "phone": "+70325669810"}
0005434550658	2B11EC	9756 065946	ALINA SMIRNOVA	{"phone": "+70718153193"}
0005434550659	0BA95F	7115 483204	YURIY OSIPOV	{"email": "yuriyosipov_031980@postgrespro.ru", "phone": "+70827799142"}
0005434550660	5CCF67	5121 489715	YULIYA KONOVALOVA	{"phone": "+70735399580"}
0005434550661	E7FB7D	5766 946046	EKATERINA FADEEVA	{"email": "fadeeva_ekaterina_01091962@postgrespro.ru", "phone": "+70544771458"}
0005434550662	C04AA4	0287 366458	VALERIYA MOROZOVA	{"phone": "+70146400561"}
0005434550663	C04AA4	0603 141056	ALEKSANDR MIKHAYLOV	{"email": "a_mikhaylov_1974@postgrespro.ru", "phone": "+70812456529"}
0005434550664	76A4A3	8780 184011	LIDIYA ISAEVA	{"phone": "+70039061772"}
0005434550665	6CADF8	7984 249908	NIKOLAY KUZMIN	{"phone": "+70680480664"}
0005434550666	6CADF8	8921 194524	NINA MOISEEVA	{"email": "moiseeva.n_041958@postgrespro.ru", "phone": "+70966003921"}
0005434550667	6CADF8	3538 636733	ANDREY FEDOTOV	{"email": "a.fedotov_011969@postgrespro.ru", "phone": "+70971707189"}
0005434550668	8C5E43	1981 616640	SERGEY KUDRYASHOV	{"phone": "+70297446504"}
0005434550669	B30847	2568 942691	TATYANA BORISOVA	{"phone": "+70919064885"}
0005434550670	CCE8BA	1891 413282	ARTEM TIKHONOV	{"phone": "+70831012474"}
0005434550671	CCE8BA	6535 169036	EGOR POPOV	{"email": "epopov-1973@postgrespro.ru", "phone": "+70974134488"}
0005434550672	C3E88F	6789 603301	IRINA MIRONOVA	{"email": "mironova_irina_02121973@postgrespro.ru", "phone": "+70197757663"}
0005434550673	915474	7212 132326	NATALYA STEPANOVA	{"phone": "+70149033439"}
0005434550674	915474	0352 105690	YURIY PETROV	{"email": "yuriypetrov.071988@postgrespro.ru", "phone": "+70759116921"}
0005434550675	CDCB56	1792 349088	VLADIMIR ALEKSEEV	{"email": "alekseev_v_061969@postgrespro.ru", "phone": "+70123798516"}
0005434550676	CDCB56	1242 379802	MARIYA EGOROVA	{"email": "egorova.m_1965@postgrespro.ru", "phone": "+70011108584"}
0005434550677	CDCB56	8690 327173	VLADISLAV POPOV	{"email": "popovvladislav.31031960@postgrespro.ru", "phone": "+70808321042"}
0005434550678	F85B5E	1500 785707	YULIYA CHERNOVA	{"phone": "+70600199928"}
0005434550679	1B7E88	9524 485704	ALEKSANDR RODIONOV	{"phone": "+70724652866"}
0005434550680	E78935	3789 819117	VALENTINA NOVIKOVA	{"email": "novikova-valentina1974@postgrespro.ru", "phone": "+70853140860"}
0005434550681	F4AF80	0489 024189	TATYANA BORISOVA	{"email": "borisova.tatyana1974@postgrespro.ru", "phone": "+70498565355"}
0005434550682	15846E	9941 522724	OLEG SMIRNOV	{"phone": "+70141931607"}
0005434550683	15846E	8531 604398	NIKITA VASILEV	{"email": "n_vasilev14061972@postgrespro.ru", "phone": "+70905163085"}
0005434550684	E665BB	6805 132813	SERGEY ALEKSEEV	{"phone": "+70935484942"}
0005434550685	24E931	2594 135135	ELENA MASLOVA	{"email": "maslova_e.061976@postgrespro.ru", "phone": "+70278717243"}
0005434550686	956263	6216 500694	OLGA ALEKSEEVA	{"email": "o_alekseeva_1974@postgrespro.ru", "phone": "+70907500984"}
0005434550687	956263	7954 033579	ALEKSANDR KUZNECOV	{"email": "kuznecov_a.111958@postgrespro.ru", "phone": "+70772605320"}
0005434550688	CF8B84	5757 654589	ALEKSANDRA EGOROVA	{"email": "aleksandra_egorova_1975@postgrespro.ru", "phone": "+70031667715"}
0005434550689	690E6C	3125 413215	ANATOLIY SCHERBAKOV	{"email": "anatoliyscherbakov_1965@postgrespro.ru", "phone": "+70611733668"}
0005434550690	690E6C	6039 324391	RAVIL DENISOV	{"email": "ravildenisov.011978@postgrespro.ru", "phone": "+70740718838"}
0005434550691	3201C8	6327 315477	SERGEY BELOV	{"phone": "+70005031106"}
0005434550692	3201C8	3308 834278	VIKTOR ANDREEV	{"phone": "+70505812650"}
0005434550693	2CD432	1838 923785	ALEKSANDR GRIGOREV	{"phone": "+70030415893"}
0005434550694	899B47	6417 082527	EKATERINA SAVELEVA	{"email": "saveleva-e-13071970@postgrespro.ru", "phone": "+70248294285"}
0005434550695	1BC45F	5730 773736	SVETLANA SOROKINA	{"email": "svetlana.sorokina081980@postgrespro.ru", "phone": "+70545454442"}
0005434550696	1BC45F	0522 814294	PAVEL AFANASEV	{"email": "afanasev-pavel071979@postgrespro.ru", "phone": "+70175221694"}
0005434550697	E18DDC	7956 558338	TATYANA RODIONOVA	{"phone": "+70985308013"}
0005434550698	9037DA	5378 053069	ELENA VLASOVA	{"phone": "+70408218027"}
0005434550699	EDF10E	7857 674899	SERGEY SOLOVEV	{"phone": "+70221649783"}
0005434550700	EDF10E	9977 924180	ANDREY MELNIKOV	{"phone": "+70125691541"}
0005434550701	90D96E	0127 126864	LYUDMILA MARTYNOVA	{"email": "lyudmilamartynova14121974@postgrespro.ru", "phone": "+70589708331"}
0005434550702	90D96E	8491 579376	ILYA ABRAMOV	{"email": "abramovi-1962@postgrespro.ru", "phone": "+70110700396"}
0005434550703	EC3DB8	5620 438468	GALINA KRASNOVA	{"email": "galinakrasnova-091982@postgrespro.ru", "phone": "+70416301988"}
0005434550704	617930	2771 167036	ARINA MOISEEVA	{"email": "a.moiseeva.051982@postgrespro.ru", "phone": "+70311852353"}
0005434550705	617930	2725 974644	NIKOLAY STEPANOV	{"phone": "+70410793735"}
0005434550706	8E1DAB	5896 235830	EKATERINA CHERNOVA	{"phone": "+70189290885"}
0005434550707	A3D2F3	1480 437210	ALEKSANDR NOVIKOV	{"phone": "+70302934293"}
0005434550708	08B221	8017 776526	NATALYA EGOROVA	{"email": "n.egorova_091969@postgrespro.ru", "phone": "+70250878140"}
0005434550709	08B221	2604 675910	ANNA MARTYNOVA	{"email": "a-martynova-01071975@postgrespro.ru", "phone": "+70957127875"}
0005434550710	08B221	0340 462656	NIKOLAY KUZNECOV	{"email": "n-kuznecov12071974@postgrespro.ru", "phone": "+70669104311"}
0005434550711	414E02	4939 325834	ARTEM KOZLOV	{"phone": "+70061914697"}
0005434550712	B68093	2050 225918	OKSANA BOGDANOVA	{"email": "oksana-bogdanova-041978@postgrespro.ru", "phone": "+70761510100"}
0005434550713	B68093	6043 673530	MARIYA POTAPOVA	{"email": "mpotapova031976@postgrespro.ru", "phone": "+70347699713"}
0005434550714	C66FAE	8595 504200	OLGA BORISOVA	{"email": "borisovaolga.11041977@postgrespro.ru", "phone": "+70296209655"}
0005434550715	8A13E5	8954 963762	NADEZHDA FILATOVA	{"email": "filatova_nadezhda.1957@postgrespro.ru", "phone": "+70357949940"}
0005434550716	D082C8	2535 641821	LIDIYA FEDOROVA	{"email": "l.fedorova.011971@postgrespro.ru", "phone": "+70786083805"}
0005434550717	9606C3	4510 737727	ANTONINA MIRONOVA	{"phone": "+70261121767"}
0005434550718	1E16AC	5060 072071	VLADIMIR SAVELEV	{"phone": "+70438569399"}
0005434550719	9B7843	2880 164562	LARISA GORBUNOVA	{"phone": "+70621858198"}
0005434550720	9B7843	5846 130729	NATALYA OSIPOVA	{"phone": "+70670583397"}
0005434550721	A54AFF	9485 514554	ALEKSANDR ORLOV	{"email": "aorlov.02061960@postgrespro.ru", "phone": "+70003336771"}
0005434550722	A54AFF	9093 298753	NADEZHDA SERGEEVA	{"email": "n.sergeeva-101977@postgrespro.ru", "phone": "+70107604239"}
0005434550723	2716F1	4240 457561	ANTONINA BELYAEVA	{"phone": "+70502241704"}
0005434550724	2AA8C2	4030 265539	LYUDMILA POPOVA	{"email": "lyudmila-popova_13061970@postgrespro.ru", "phone": "+70227186261"}
0005434550725	921E46	7016 600851	VALENTINA DAVYDOVA	{"phone": "+70511757218"}
0005434550726	E6CAF0	4157 101551	IRINA PAVLOVA	{"email": "irina_pavlova021969@postgrespro.ru", "phone": "+70180322529"}
0005434550727	E6CAF0	7791 189637	ANDREY MOROZOV	{"email": "morozov.andrey_101974@postgrespro.ru", "phone": "+70872131800"}
0005434550728	1C2B0A	0291 329236	OLGA FROLOVA	{"email": "frolova_o.18021966@postgrespro.ru", "phone": "+70763668769"}
0005434550729	1C2B0A	9604 922605	IREK IVANOV	{"phone": "+70621561512"}
0005434550730	47D3CE	1555 211881	ILYAS TARASOV	{"email": "ilyas-tarasov1981@postgrespro.ru", "phone": "+70847558552"}
0005434550731	97F3A0	6161 499275	SVETLANA IVANOVA	{"email": "s-ivanova021985@postgrespro.ru", "phone": "+70347088467"}
0005434550732	75A134	9972 116907	ALEKSANDR VOROBEV	{"email": "avorobev.02031987@postgrespro.ru", "phone": "+70967773151"}
0005434550733	D6DC5E	9344 899426	TAGIR DENISOV	{"phone": "+70236268328"}
0005434550734	7F3DBD	2868 410451	SERGEY KAZAKOV	{"phone": "+70164453139"}
0005434550735	FD598F	0095 068264	TIMUR FOMIN	{"phone": "+70125147323"}
0005434550736	FD598F	7218 734391	MARINA AKIMOVA	{"phone": "+70795669306"}
0005434550737	7D63EF	4730 529597	SERGEY FEDOTOV	{"email": "fedotov_sergey.25051970@postgrespro.ru", "phone": "+70240093524"}
0005434550738	6BDE04	6812 799254	SANIYA SOKOLOVA	{"email": "saniya-sokolova.29081967@postgrespro.ru", "phone": "+70438426355"}
0005434550739	6BDE04	2353 990463	ZOYA KARPOVA	{"email": "karpova-zoya.061977@postgrespro.ru", "phone": "+70513437351"}
0005434550740	6BDE04	3698 080076	VASILIY ZAYCEV	{"email": "zaycev-vasiliy-1975@postgrespro.ru", "phone": "+70397105672"}
0005434550741	166FAA	9532 201452	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr-01041970@postgrespro.ru", "phone": "+70964498153"}
0005434550742	7860F7	7212 013294	VALENTINA VASILEVA	{"email": "vasileva-v_1972@postgrespro.ru", "phone": "+70902858370"}
0005434550743	7860F7	8400 588755	NIKOLAY IVANOV	{"phone": "+70274793676"}
0005434550744	95A129	3433 259240	SABINA MELNIKOVA	{"phone": "+70863853411"}
0005434550745	9C9873	6326 079349	ELENA NESTEROVA	{"email": "e.nesterova101980@postgrespro.ru", "phone": "+70980051499"}
0005434550746	2FAAB1	6245 457249	NIKOLAY NIKITIN	{"email": "nikitinn1963@postgrespro.ru", "phone": "+70898649919"}
0005434550747	2FAAB1	8187 954030	ALEKSANDR TARASOV	{"phone": "+70368419286"}
0005434550748	77C8D5	0086 620957	DMITRIY GUSEV	{"phone": "+70610611505"}
0005434550749	77C8D5	4416 428862	NATALYA DAVYDOVA	{"email": "natalya_davydova18091975@postgrespro.ru", "phone": "+70827522257"}
0005434550750	D88D3A	5548 057217	ANTONINA KUZNECOVA	{"phone": "+70772052880"}
0005434550751	DF12EA	2138 482137	NINA ARKHIPOVA	{"phone": "+70193483653"}
0005434550752	DF12EA	5476 310240	KIRILL ANDREEV	{"phone": "+70425597079"}
0005434550753	9C2962	5725 577871	LYUDMILA KISELEVA	{"phone": "+70023248334"}
0005434550754	E010A9	0200 725403	OLGA STEPANOVA	{"phone": "+70510161578"}
0005434550755	30AE88	1136 080736	DANILA NOVIKOV	{"phone": "+70535127448"}
0005434550756	D536EC	9643 126195	DMITRIY SIDOROV	{"phone": "+70308066672"}
0005434550757	B1C022	4419 762313	RAISA MIKHAYLOVA	{"phone": "+70676201224"}
0005434550758	7B49B0	1281 408113	LARISA GAVRILOVA	{"phone": "+70062394533"}
0005434550759	7B49B0	7455 172136	VLADIMIR FEDOROV	{"email": "fedorov-v.021970@postgrespro.ru", "phone": "+70697431099"}
0005434550760	F301EA	0011 481607	ANTONINA KUZNECOVA	{"email": "kuznecovaantonina.22061979@postgrespro.ru", "phone": "+70385021082"}
0005434550761	A21248	2322 643327	KLAVDIYA MIRONOVA	{"email": "mironova.k.29051972@postgrespro.ru", "phone": "+70898243593"}
0005434550762	A21248	6284 976725	LILIYA FILATOVA	{"phone": "+70975052973"}
0005434550763	4F4A3C	7012 943932	VIKTOR SERGEEV	{"phone": "+70457756274"}
0005434550764	56356C	4989 907694	ANNA NOVIKOVA	{"email": "a_novikova.23121962@postgrespro.ru", "phone": "+70841891894"}
0005434550765	56356C	6271 123189	ALEKSANDR VASILEV	{"email": "a.vasilev.101964@postgrespro.ru", "phone": "+70423859125"}
0005434550766	56356C	3108 886758	GALINA KISELEVA	{"email": "galina_kiseleva-26071974@postgrespro.ru", "phone": "+70560433248"}
0005434550767	5ED914	6181 365482	EGOR GRIGOREV	{"email": "grigorev-egor-1972@postgrespro.ru", "phone": "+70735433427"}
0005434550768	5ED914	2632 432345	SERGEY AFANASEV	{"email": "afanasevs_1968@postgrespro.ru", "phone": "+70124091691"}
0005434550769	4F3196	5252 922517	NADEZHDA IVANOVA	{"email": "ivanova-n-1972@postgrespro.ru", "phone": "+70301699585"}
0005434550770	4F3196	2492 395161	VITALIY VASILEV	{"phone": "+70133548914"}
0005434550771	4F3196	6896 287001	LYUDMILA EGOROVA	{"email": "lyudmila_egorova.30051974@postgrespro.ru", "phone": "+70211020557"}
0005434550772	A72ED5	8894 620943	NADEZHDA PETROVA	{"email": "petrova.n-111966@postgrespro.ru", "phone": "+70709252858"}
0005434550773	B7C37D	1835 905931	VALENTINA EFIMOVA	{"email": "efimovavalentina-08051965@postgrespro.ru", "phone": "+70219594771"}
0005434550774	B7C37D	0256 948575	VALENTINA ANISIMOVA	{"email": "vanisimova.061975@postgrespro.ru", "phone": "+70054450677"}
0005434550775	B7C37D	4761 949137	VASILIY SERGEEV	{"email": "vasiliysergeev1980@postgrespro.ru", "phone": "+70704462254"}
0005434550776	3A8FE8	5542 677188	LIDIYA KISELEVA	{"phone": "+70993859473"}
0005434550777	E941A9	7781 095863	DARYA YAKOVLEVA	{"email": "yakovleva_darya-081976@postgrespro.ru", "phone": "+70529937577"}
0005434550778	0F14B7	5603 495562	LYUDMILA LEBEDEVA	{"email": "lebedeva_lyudmila_1971@postgrespro.ru", "phone": "+70444461404"}
0005434550779	AEE010	1501 677247	KAMIL SCHERBAKOV	{"phone": "+70987996513"}
0005434550780	AEE010	2466 772757	VALERIY EGOROV	{"email": "valeriy_egorov_1967@postgrespro.ru", "phone": "+70325997827"}
0005434550781	8DD018	9361 630574	LIDIYA POPOVA	{"email": "l_popova-05101965@postgrespro.ru", "phone": "+70572984502"}
0005434550782	672B4F	1551 898832	BOGDAN NOVIKOV	{"email": "novikovbogdan-25061966@postgrespro.ru", "phone": "+70653612924"}
0005434550783	66DB75	5903 137197	ANASTASIYA ORLOVA	{"email": "a_orlova101973@postgrespro.ru", "phone": "+70209877518"}
0005434550784	BEFAAF	5015 514938	VLADIMIR SHEVCHENKO	{"email": "shevchenko.vladimir09051962@postgrespro.ru", "phone": "+70354046000"}
0005434550785	BEFAAF	0713 098811	MARGARITA FADEEVA	{"email": "fadeevamargarita1968@postgrespro.ru", "phone": "+70503099887"}
0005434550786	8FF1BC	1476 541927	VLADIMIR NIKOLAEV	{"phone": "+70041169841"}
0005434550787	3E4B4C	1580 914554	ANASTASIYA DAVYDOVA	{"phone": "+70692180177"}
0005434550788	3E4B4C	4902 404228	IGOR SIDOROV	{"phone": "+70080027952"}
0005434550789	3A2F1A	2313 972858	EVGENIYA POTAPOVA	{"phone": "+70822256013"}
0005434550790	3A2F1A	0375 589005	IGOR PAVLOV	{"email": "igor.pavlov071975@postgrespro.ru", "phone": "+70430234773"}
0005434550791	1F7255	8468 320284	YULIYA MIRONOVA	{"email": "ymironova-1970@postgrespro.ru", "phone": "+70236580225"}
0005434550792	595C7D	7638 631977	ANASTASIYA KULIKOVA	{"email": "akulikova121976@postgrespro.ru", "phone": "+70803426471"}
0005434550793	F0AF76	1484 626304	GALINA MARTYNOVA	{"email": "martynova-galina.051974@postgrespro.ru", "phone": "+70484607342"}
0005434550794	594623	5250 812093	MAKSIM FOMIN	{"email": "fomin-m-061976@postgrespro.ru", "phone": "+70041607065"}
0005434550795	594623	8529 104348	NIKOLAY DMITRIEV	{"email": "dmitrievn111980@postgrespro.ru", "phone": "+70951322212"}
0005434550796	4CD2D2	4156 327240	MIKHAIL KONOVALOV	{"email": "m-konovalov-06051967@postgrespro.ru", "phone": "+70804870893"}
0005434550797	4CD2D2	0513 390994	ARINA POPOVA	{"email": "arina_popova-091969@postgrespro.ru", "phone": "+70530292209"}
0005434550798	DA432D	0291 088065	ELMIRA DENISOVA	{"phone": "+70678427226"}
0005434550799	DA432D	3410 242875	NIKITA KARPOV	{"email": "nikita.karpov_051975@postgrespro.ru", "phone": "+70095095875"}
0005434550800	2F60B1	5375 884599	IGOR DENISOV	{"phone": "+70467453450"}
0005434550801	B506B6	6419 014783	VLADIMIR DENISOV	{"phone": "+70945245062"}
0005434550802	B177A0	9274 817262	ALEKSEY FEDOROV	{"email": "fedorov.aleksey.1981@postgrespro.ru", "phone": "+70643465568"}
0005434550803	B177A0	3752 646110	IRINA CHERNOVA	{"phone": "+70203164778"}
0005434550804	C4F2DC	1739 244496	ANNA MAKSIMOVA	{"phone": "+70623857503"}
0005434550805	7557FF	7038 840898	DMITRIY AFANASEV	{"email": "afanasev_dmitriy.07031966@postgrespro.ru", "phone": "+70610296077"}
0005434550806	D312EA	8985 581723	YURIY SIDOROV	{"phone": "+70401025474"}
0005434550807	27AD36	7446 443585	VLADIMIR VOLKOV	{"phone": "+70733889944"}
0005434550808	E928EB	8843 707289	SERGEY EGOROV	{"email": "egorov-s_1984@postgrespro.ru", "phone": "+70027553895"}
0005434550809	4B4650	1388 383663	NATALYA KULIKOVA	{"email": "kulikovan.1962@postgrespro.ru", "phone": "+70994822619"}
0005434550810	790141	4783 322953	RADIK SEMENOV	{"email": "semenov-radik-1974@postgrespro.ru", "phone": "+70369167218"}
0005434550811	790141	1512 705144	SVETLANA STEPANOVA	{"phone": "+70566795941"}
0005434550812	790141	7821 086557	EVGENIY SOLOVEV	{"email": "evgeniysolovev_13081980@postgrespro.ru", "phone": "+70477812795"}
0005434550813	D4152D	3241 983247	ALEKSEY YAKOVLEV	{"phone": "+70811722567"}
0005434550814	FD4677	0643 580592	MARIYA NAZAROVA	{"phone": "+70542768483"}
0005434550815	F04426	9475 067727	NIKOLAY POPOV	{"email": "popovn-021981@postgrespro.ru", "phone": "+70293895611"}
0005434550816	D36FA7	7827 539479	ALEKSANDR FOMIN	{"email": "fomin_a.031978@postgrespro.ru", "phone": "+70012007347"}
0005434550817	D36FA7	6827 607891	VIKTOR NOVIKOV	{"phone": "+70014106759"}
0005434550818	D36FA7	4272 545591	MAKSIM STEPANOV	{"phone": "+70005646915"}
0005434550819	1EA82C	7075 920016	VYACHESLAV NIKITIN	{"email": "nikitin.v_23031973@postgrespro.ru", "phone": "+70319499528"}
0005434550820	F3FE48	9212 496728	ANNA FILIPPOVA	{"phone": "+70509507190"}
0005434550821	F3FE48	1978 818344	ALEKSANDR MOISEEV	{"phone": "+70184797371"}
0005434550822	3A3494	5259 525223	VIKTOR SCHERBAKOV	{"phone": "+70627099460"}
0005434550823	72D15C	5204 350640	ARTUR SERGEEV	{"email": "sergeeva-18021977@postgrespro.ru", "phone": "+70425763488"}
0005434550824	CFA7B4	1230 911875	ANTON FEDOROV	{"phone": "+70858961899"}
0005434550825	CFA7B4	1852 649445	NATALIYA POLYAKOVA	{"phone": "+70071293286"}
0005434550826	126193	7194 735075	SERGEY KUDRYASHOV	{"phone": "+70824106224"}
0005434550827	215300	1879 599127	OLEG GORBUNOV	{"phone": "+70471966354"}
0005434550828	912161	7208 847916	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov_071970@postgrespro.ru", "phone": "+70668283610"}
0005434550829	71A890	8739 747006	VALERIY NIKOLAEV	{"phone": "+70889929287"}
0005434550830	71A890	2543 185157	MAKSIM ZAKHAROV	{"email": "zakharov_m.031974@postgrespro.ru", "phone": "+70630594058"}
0005434550831	13307F	0500 604381	VALENTINA NIKIFOROVA	{"email": "nikiforova.v.07101975@postgrespro.ru", "phone": "+70744144571"}
0005434550832	13307F	2525 540794	GALINA LAZAREVA	{"phone": "+70282822950"}
0005434550833	A849FE	7998 316217	SVETLANA KUZNECOVA	{"phone": "+70018111302"}
0005434550834	A849FE	1643 553301	SERGEY SMIRNOV	{"email": "smirnov_s.041960@postgrespro.ru", "phone": "+70776849564"}
0005434550835	C0E275	2124 837054	YULIYA KULIKOVA	{"email": "kulikova_y-20051976@postgrespro.ru", "phone": "+70033858035"}
0005434550836	901259	7664 799091	MARIYA ANISIMOVA	{"email": "anisimovam.05011975@postgrespro.ru", "phone": "+70600077485"}
0005434550837	901259	9377 361267	YURIY MEDVEDEV	{"phone": "+70681907375"}
0005434550838	19ACA1	1239 561029	TATYANA KOROLEVA	{"email": "koroleva_t_27061973@postgrespro.ru", "phone": "+70760062685"}
0005434550839	8085AD	1884 216289	NINA BORISOVA	{"phone": "+70063155586"}
0005434550840	7269C8	7325 479653	PAVEL ANDREEV	{"email": "andreevp_25041966@postgrespro.ru", "phone": "+70124454772"}
0005434550841	78D93C	6527 969400	DANIIL FOMIN	{"email": "fomin-d081963@postgrespro.ru", "phone": "+70262294313"}
0005434550842	AA1F67	1302 276274	DMITRIY STEPANOV	{"phone": "+70063414651"}
0005434550843	AA1F67	6698 432704	EVGENIY SERGEEV	{"phone": "+70242106236"}
0005434550844	90F6E7	0267 144668	EVGENIYA RYABOVA	{"phone": "+70607023823"}
0005434550845	90F6E7	9698 675443	ALEKSANDR FROLOV	{"phone": "+70540578639"}
0005434550846	A0ADDD	1578 613293	VALENTINA KUZNECOVA	{"phone": "+70949966587"}
0005434550847	39B050	4077 595417	LEONID MOROZOV	{"email": "lmorozov-10081975@postgrespro.ru", "phone": "+70566952681"}
0005434550848	69CE45	2983 720906	NINA MAKAROVA	{"email": "nina-makarova_1966@postgrespro.ru", "phone": "+70345078982"}
0005434550849	69CE45	8245 903261	NIKITA ZHURAVLEV	{"email": "n-zhuravlev-1963@postgrespro.ru", "phone": "+70497705927"}
0005434550850	4515B2	9773 746541	PAVEL MELNIKOV	{"email": "pavel-melnikov-1967@postgrespro.ru", "phone": "+70446270528"}
0005434550851	A72B0C	1558 390821	DIANA VOROBEVA	{"phone": "+70565756305"}
0005434550852	48C22D	5908 060609	OLGA ZAYCEVA	{"email": "olga-zayceva-1970@postgrespro.ru", "phone": "+70501259822"}
0005434550853	C0F4A7	9556 080094	ANASTASIYA VOLKOVA	{"email": "anastasiya.volkova081979@postgrespro.ru", "phone": "+70646881254"}
0005434550854	DF400F	9934 262545	TATYANA VASILEVA	{"phone": "+70674802153"}
0005434550855	A0B209	6368 552338	NADEZHDA KOROLEVA	{"phone": "+70308284367"}
0005434550856	0375FB	9218 026869	MAKSIM GUSEV	{"phone": "+70687056811"}
0005434550857	3A9E0F	9857 849356	LEONID VOLKOV	{"email": "l.volkov04111970@postgrespro.ru", "phone": "+70300817656"}
0005434550858	B7A511	0800 226977	ALEKSANDR VOLKOV	{"phone": "+70958985622"}
0005434550859	6D1504	1595 286379	ALEKSANDR ZHUKOV	{"email": "a-zhukov061969@postgrespro.ru", "phone": "+70452090793"}
0005434550860	ECFD48	1526 303225	NATALYA ZAKHAROVA	{"phone": "+70545510015"}
0005434550861	A9F822	6305 623359	TATYANA DAVYDOVA	{"phone": "+70017338267"}
0005434550862	A9F822	9627 607693	ALEKSANDR MIRONOV	{"email": "a-mironov_05051983@postgrespro.ru", "phone": "+70227807881"}
0005434550863	EF2558	8552 786061	SERGEY NIKITIN	{"email": "nikitin-s.101979@postgrespro.ru", "phone": "+70356938266"}
0005434550864	B8C3A2	3848 836253	ZAKHAR NIKITIN	{"email": "z_nikitin-28101963@postgrespro.ru", "phone": "+70872572436"}
0005434550865	F60683	5618 695479	ELENA VOLKOVA	{"phone": "+70057463483"}
0005434550866	E68C8C	1976 360900	NATALYA BOGDANOVA	{"email": "bogdanovanatalya.1963@postgrespro.ru", "phone": "+70752928725"}
0005434550867	400502	6858 534357	ARTEM KONOVALOV	{"phone": "+70175299873"}
0005434550868	4BB192	3546 301590	INESSA MEDVEDEVA	{"phone": "+70253863368"}
0005434550869	A51726	1650 635424	SVETLANA KAZAKOVA	{"email": "kazakova.s-1971@postgrespro.ru", "phone": "+70631760346"}
0005434550870	35E198	8825 239216	DANIIL MAKSIMOV	{"email": "dmaksimov.02111973@postgrespro.ru", "phone": "+70075640184"}
0005434550871	9ED135	9413 434431	DMITRIY SEMENOV	{"phone": "+70262464448"}
0005434550872	53940C	7253 534480	ANDREY IVANOV	{"email": "andrey.ivanov-16051978@postgrespro.ru", "phone": "+70880073362"}
0005434550873	9666A9	9961 398587	VADIM TARASOV	{"phone": "+70639770135"}
0005434550874	B3B5D4	3679 025317	VADIM KOZLOV	{"email": "vadimkozlov1980@postgrespro.ru", "phone": "+70068876684"}
0005434550875	B3B5D4	6550 330909	VLADIMIR ANTONOV	{"phone": "+70740931042"}
0005434550876	575A52	1845 288426	SVETLANA FILATOVA	{"phone": "+70404797915"}
0005434550877	01B1F0	2781 866604	TATYANA KISELEVA	{"phone": "+70707311500"}
0005434550878	634329	9790 441211	KLAVDIYA KUZNECOVA	{"email": "kuznecova_klavdiya.19121971@postgrespro.ru", "phone": "+70473490404"}
0005434550879	8F4049	0381 057206	VYACHESLAV IVANOV	{"email": "vivanov24071966@postgrespro.ru", "phone": "+70835082574"}
0005434550880	73961D	4725 731869	OLGA STEPANOVA	{"email": "stepanovao_1973@postgrespro.ru", "phone": "+70748516962"}
0005434550881	EEBBD8	9333 254117	EGOR GAVRILOV	{"phone": "+70623211506"}
0005434550882	22DD54	8711 571649	VIKTOR TIMOFEEV	{"phone": "+70906944949"}
0005434550883	22DD54	9892 158618	OLGA KONDRATEVA	{"email": "okondrateva_111971@postgrespro.ru", "phone": "+70016941572"}
0005434550884	E7E650	6954 854657	ANNA NAZAROVA	{"email": "a-nazarova111977@postgrespro.ru", "phone": "+70171856864"}
0005434550885	E7E650	8794 386404	TATYANA NESTEROVA	{"phone": "+70399983053"}
0005434550886	0E94C3	0911 153888	ALEKSEY ZAKHAROV	{"phone": "+70903332293"}
0005434550887	0E94C3	9452 115924	LIDIYA MARTYNOVA	{"email": "lmartynova.18041977@postgrespro.ru", "phone": "+70730372159"}
0005434550888	A47710	6074 038435	VSEVOLOD YAKOVLEV	{"email": "v.yakovlev-081964@postgrespro.ru", "phone": "+70074047411"}
0005434550889	B72780	4818 558163	YULIYA MAKSIMOVA	{"email": "yuliya-maksimova.1969@postgrespro.ru", "phone": "+70611282548"}
0005434550890	B51638	6455 565514	FELIKS VOROBEV	{"email": "vorobev_feliks.1969@postgrespro.ru", "phone": "+70950744958"}
0005434550891	E1F666	1097 577453	ANDREY IVANOV	{"email": "ivanov_a.29051980@postgrespro.ru", "phone": "+70091829248"}
0005434550892	680380	0999 863257	SERGEY RODIONOV	{"phone": "+70816582010"}
0005434550893	C4F6D3	7606 592846	VASILIY ROMANOV	{"email": "vasiliy-romanov-071976@postgrespro.ru", "phone": "+70483627299"}
0005434550894	4875E8	2507 418802	ANASTASIYA KUZMINA	{"phone": "+70726255231"}
0005434550895	4875E8	1012 571945	NINA AKIMOVA	{"phone": "+70070715118"}
0005434550896	A61C18	5946 276960	MIKHAIL STEPANOV	{"phone": "+70649412775"}
0005434550897	28FC0C	3060 205333	OLGA MAKAROVA	{"phone": "+70701095945"}
0005434550898	28FC0C	0069 330739	DMITRIY DENISOV	{"phone": "+70997311679"}
0005434550899	E8D903	9505 807826	ALEKSEY SMIRNOV	{"email": "asmirnov-091962@postgrespro.ru", "phone": "+70793045677"}
0005434550900	E8D903	9865 309222	ALEKSEY FEDOROV	{"phone": "+70382719054"}
0005434550901	E52526	6641 892811	IVAN FROLOV	{"email": "frolov-ivan071964@postgrespro.ru", "phone": "+70044906475"}
0005434550902	4329B4	0509 183988	NADEZHDA FEDOROVA	{"email": "nfedorova01091977@postgrespro.ru", "phone": "+70268524678"}
0005434550903	CEFD69	0003 479451	YULIYA TARASOVA	{"email": "tarasova.y_1967@postgrespro.ru", "phone": "+70814378006"}
0005434550904	BDBE45	8618 712709	TATYANA EFREMOVA	{"phone": "+70662132821"}
0005434550905	90A737	1260 034810	IGOR MOISEEV	{"email": "moiseev-i.28021968@postgrespro.ru", "phone": "+70850716245"}
0005434550906	CE3364	1293 279590	DARYA DENISOVA	{"email": "darya_denisova-14081974@postgrespro.ru", "phone": "+70257552141"}
0005434550907	847056	8320 210585	TAMARA ANDREEVA	{"email": "tamara-andreeva-1965@postgrespro.ru", "phone": "+70081399936"}
0005434550908	EEEAB7	4415 991327	EKATERINA ROMANOVA	{"email": "romanova-e11041982@postgrespro.ru", "phone": "+70867533349"}
0005434550909	EEEAB7	0173 674362	TATYANA IVANOVA	{"phone": "+70478094267"}
0005434550910	EEEAB7	2395 464113	SERGEY EGOROV	{"email": "egorov_sergey-061982@postgrespro.ru", "phone": "+70476262693"}
0005434550911	F2843B	3444 821116	ELENA NAZAROVA	{"phone": "+70646824407"}
0005434550912	F2843B	0789 357527	LYUBOV IVANOVA	{"email": "ivanova-lyubov1973@postgrespro.ru", "phone": "+70747259733"}
0005434550913	06251E	8145 919458	VIKTOR IVANOV	{"email": "v-ivanov.041980@postgrespro.ru", "phone": "+70617797274"}
0005434550914	96406E	1028 727461	VIKTOR DAVYDOV	{"email": "davydov_v_121976@postgrespro.ru", "phone": "+70642393839"}
0005434550915	41FB23	1088 006252	GALINA ABRAMOVA	{"phone": "+70192237075"}
0005434550916	B0AC46	0560 779461	NIKITA TIMOFEEV	{"email": "n.timofeev_20061982@postgrespro.ru", "phone": "+70092481221"}
0005434550917	91AD4D	9755 706915	SHAVKAT ISAEV	{"email": "shavkatisaev_101964@postgrespro.ru", "phone": "+70487259620"}
0005434550918	5D3D18	6906 341841	ANASTASIYA MAKSIMOVA	{"email": "maksimova-anastasiya22041960@postgrespro.ru", "phone": "+70285115960"}
0005434550919	5D3D18	7189 687636	DMITRIY IVANOV	{"email": "divanov_1983@postgrespro.ru", "phone": "+70711148644"}
0005434550920	FADE07	2025 280122	OKSANA VOLKOVA	{"email": "volkova.o1962@postgrespro.ru", "phone": "+70505341346"}
0005434550921	FADE07	3699 530291	SERGEY KULIKOV	{"email": "sergey_kulikov1971@postgrespro.ru", "phone": "+70536985534"}
0005434550922	FADE07	8119 628300	DANILA GUSEV	{"phone": "+70425910070"}
0005434550923	FADE07	8314 755883	DMITRIY KUZNECOV	{"phone": "+70444501687"}
0005434550924	F1F7D9	4141 028791	ALEKSANDR ZHUKOV	{"email": "zhukov.a_1977@postgrespro.ru", "phone": "+70459932087"}
0005434550925	5D2B8B	7966 825215	YURIY NIKITIN	{"phone": "+70979245295"}
0005434550926	744DD2	1480 481075	ANDREY FEDOTOV	{"email": "fedotova1972@postgrespro.ru", "phone": "+70961128136"}
0005434550927	06F83A	4745 950199	ANATOLIY SOKOLOV	{"email": "sokolov-a.041978@postgrespro.ru", "phone": "+70029915147"}
0005434550928	9137C7	9952 828594	OKSANA MOROZOVA	{"email": "morozova-o-1963@postgrespro.ru", "phone": "+70892969157"}
0005434550929	A7D7DD	0185 167305	OLGA ERMAKOVA	{"email": "olga.ermakova1974@postgrespro.ru", "phone": "+70698814960"}
0005434550930	BAE6B8	0006 353090	ANTON MOROZOV	{"phone": "+70350601594"}
0005434550931	BAE6B8	4515 320971	NIKOLAY PAVLOV	{"phone": "+70129677203"}
0005434550932	B3188B	6481 843024	VIKTOR MATVEEV	{"email": "matveevviktor1979@postgrespro.ru", "phone": "+70533039505"}
0005434550933	3ECFCD	0351 396472	SERGEY NAUMOV	{"email": "naumovsergey_17111972@postgrespro.ru", "phone": "+70711757411"}
0005434550934	C01886	5785 683133	MAKSIM GUSEV	{"phone": "+70038834382"}
0005434550935	BD549C	3276 916532	LYUBOV STEPANOVA	{"phone": "+70091701428"}
0005434550936	6F8979	5225 387246	DANIYA KARPOVA	{"phone": "+70548375778"}
0005434550937	6F8979	9594 435837	ANDREY GUSEV	{"email": "agusev28111964@postgrespro.ru", "phone": "+70701530610"}
0005434550938	45A1A8	0363 426755	ALEKSANDR BORISOV	{"email": "a-borisov-06081969@postgrespro.ru", "phone": "+70390619819"}
0005434550939	65E4FF	8100 837908	VITALIY BORISOV	{"phone": "+70879335720"}
0005434550940	6FBECA	4713 749530	ELENA TIMOFEEVA	{"phone": "+70988209142"}
0005434550941	6FBECA	5491 776277	ANTON ROMANOV	{"phone": "+70854276950"}
0005434550942	D6A597	2286 701718	TATYANA GUSEVA	{"email": "tguseva_12041975@postgrespro.ru", "phone": "+70337598664"}
0005434550943	D6A597	3133 287049	ANATOLIY SHEVCHENKO	{"email": "a.shevchenko-02071974@postgrespro.ru", "phone": "+70711836551"}
0005434550944	BA234C	4244 905500	IRINA FROLOVA	{"email": "frolova-irina30121965@postgrespro.ru", "phone": "+70958779923"}
0005434550945	FC3E88	6315 105059	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov.11101968@postgrespro.ru", "phone": "+70062849696"}
0005434550946	8DD20C	9997 451685	ANASTASIYA FILATOVA	{"email": "filatovaanastasiya_1965@postgrespro.ru", "phone": "+70023689059"}
0005434550947	BC6C7D	1623 386859	ANASTASIYA VASILEVA	{"email": "anastasiya.vasileva-111973@postgrespro.ru", "phone": "+70754703181"}
0005434550948	BE1971	1709 662615	ALEKSEY EGOROV	{"email": "aleksey.egorov_18091962@postgrespro.ru", "phone": "+70667432133"}
0005434550949	BE1971	9005 955908	LEONID YAKOVLEV	{"phone": "+70798469665"}
0005434550950	3A49A2	6966 698002	TATYANA MATVEEVA	{"phone": "+70153851317"}
0005434550951	D2DCE9	9542 942224	NIKOLAY FEDOTOV	{"email": "fedotov_n.061972@postgrespro.ru", "phone": "+70031150320"}
0005434550952	23AF91	7747 883985	ALEKSANDR FROLOV	{"phone": "+70794441815"}
0005434550953	23AF91	0997 748365	VLADIMIR ANDREEV	{"email": "vladimir-andreev1969@postgrespro.ru", "phone": "+70902798206"}
0005434550954	DAE478	4250 795580	MARIYA FEDOROVA	{"phone": "+70352284432"}
0005434550955	D3B1A0	8405 431758	NINA KOLESNIKOVA	{"phone": "+70381860094"}
0005434550956	4A023E	1814 661256	EVGENIY KUZNECOV	{"email": "evgeniy-kuznecov24071975@postgrespro.ru", "phone": "+70238904963"}
0005434550957	4A023E	3877 909948	OLGA VLASOVA	{"phone": "+70595042445"}
0005434550958	F0425F	0862 292093	YULIYA FROLOVA	{"phone": "+70685467971"}
0005434550959	F0425F	6775 480147	IRINA TIKHONOVA	{"email": "irina-tikhonova1971@postgrespro.ru", "phone": "+70155618498"}
0005434550960	C0ABE1	4371 427906	NATALYA YUDINA	{"email": "natalya_yudina-16011972@postgrespro.ru", "phone": "+70699241667"}
0005434550961	C0ABE1	2705 856967	DMITRIY MOROZOV	{"email": "morozovdmitriy_1966@postgrespro.ru", "phone": "+70177793321"}
0005434550962	AA4117	5802 763145	DINA SERGEEVA	{"email": "sergeevadina.28121968@postgrespro.ru", "phone": "+70327302961"}
0005434550963	D55C29	9202 842192	ALEKSANDR SHEVCHENKO	{"phone": "+70571792542"}
0005434550964	386024	9983 185562	VIKTOR IVANOV	{"email": "ivanovv_03061968@postgrespro.ru", "phone": "+70527753909"}
0005434550965	DC9328	7848 709425	NADEZHDA KOZLOVA	{"phone": "+70562915013"}
0005434550966	4C1EE8	2077 102724	VYACHESLAV VOLKOV	{"phone": "+70139465698"}
0005434550967	4C1EE8	7166 383089	DANILA ZAKHAROV	{"email": "zakharovdanila-01111974@postgrespro.ru", "phone": "+70429491320"}
0005434550968	CB9696	8101 147176	KONSTANTIN PAVLOV	{"phone": "+70338492982"}
0005434550969	93C8FC	4889 228949	VALENTINA VOROBEVA	{"email": "valentina.vorobeva-14081978@postgrespro.ru", "phone": "+70567130860"}
0005434550970	93C8FC	2177 176642	VERA KISELEVA	{"email": "kiseleva-v071975@postgrespro.ru", "phone": "+70465774866"}
0005434550971	9999FE	6031 600596	MARINA KONOVALOVA	{"phone": "+70808234667"}
0005434550972	9999FE	9516 860710	VERA SERGEEVA	{"phone": "+70487686522"}
0005434550973	F1F693	9436 589876	DARYA ZOTOVA	{"email": "daryazotova_021974@postgrespro.ru", "phone": "+70928212492"}
0005434550974	C0E7B7	1443 014255	IGOR EGOROV	{"email": "i-egorov091973@postgrespro.ru", "phone": "+70835803413"}
0005434550975	E2F358	3518 491791	VERA BELOVA	{"phone": "+70542270324"}
0005434550976	100092	2706 182289	LARISA KUZNECOVA	{"phone": "+70389193457"}
0005434550977	52BDE8	8769 636929	ALEKSEY ZHURAVLEV	{"phone": "+70273782972"}
0005434550978	52BDE8	1189 606110	ALEKSEY FROLOV	{"phone": "+70780394931"}
0005434550979	262498	6302 962153	IRINA PAVLOVA	{"phone": "+70239973858"}
0005434550980	9A587B	8843 365500	ANTON VASILEV	{"phone": "+70249551791"}
0005434550981	FC2E3B	8713 808960	ALEKSANDR TARASOV	{"email": "tarasov-a_08111958@postgrespro.ru", "phone": "+70700827521"}
0005434550982	4C0A99	8202 362425	TATYANA STEPANOVA	{"email": "tstepanova-03071979@postgrespro.ru", "phone": "+70746017579"}
0005434550983	4C0A99	4173 508635	NATALYA ABRAMOVA	{"phone": "+70635104055"}
0005434550984	FB4A4B	2529 489660	ANDREY MIKHAYLOV	{"phone": "+70282337022"}
0005434550985	FB4A4B	2040 324059	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov111977@postgrespro.ru", "phone": "+70604014886"}
0005434550986	FB4A4B	5218 219683	ARTEM KUZNECOV	{"email": "kuznecov.artem-26071972@postgrespro.ru", "phone": "+70622313201"}
0005434550987	89DAA3	5026 300238	VLADIMIR DENISOV	{"email": "denisov_v.081976@postgrespro.ru", "phone": "+70726912793"}
0005434550988	C711B4	8087 701073	KIRILL SEMENOV	{"phone": "+70956625106"}
0005434550989	FD8AFA	3193 629917	ANNA VASILEVA	{"email": "vasileva-a_031977@postgrespro.ru", "phone": "+70704483557"}
0005434550990	3E0216	5286 973041	VIKTORIYA ANTONOVA	{"email": "v-antonova_041967@postgrespro.ru", "phone": "+70913507830"}
0005434550991	3E0216	7165 670417	SERGEY KUZNECOV	{"email": "sergey.kuznecov-031974@postgrespro.ru", "phone": "+70371293634"}
0005434550992	3E0216	2418 921244	NATALYA ZHUKOVA	{"email": "natalya.zhukova-1971@postgrespro.ru", "phone": "+70633078740"}
0005434550993	66DC43	1475 205247	VALERIY CHERNOV	{"phone": "+70060831107"}
0005434550994	66DC43	5628 099020	ANATOLIY KISELEV	{"email": "anatoliy_kiselev-17071970@postgrespro.ru", "phone": "+70806713382"}
0005434550995	30FC37	5632 253932	ANASTASIYA FILIPPOVA	{"phone": "+70328249583"}
0005434550996	257681	3900 809644	YURIY IVANOV	{"email": "ivanov-y-1969@postgrespro.ru", "phone": "+70592070743"}
0005434550997	FEA00C	0688 764356	ANATOLIY NIKOLAEV	{"email": "a.nikolaev_121965@postgrespro.ru", "phone": "+70938469543"}
0005434550998	0E8209	5647 930246	DMITRIY NIKOLAEV	{"phone": "+70910248357"}
0005434550999	B46469	8078 162521	SERGEY ANTONOV	{"phone": "+70414124550"}
0005434551000	43B627	1915 302654	EVDOKIYA SIDOROVA	{"phone": "+70075154650"}
0005434551001	43B627	8525 899593	DANIIL KUZNECOV	{"email": "d-kuznecov.13041973@postgrespro.ru", "phone": "+70816686875"}
0005434551002	DF628E	6098 246968	ALEKSANDR DAVYDOV	{"phone": "+70136290871"}
0005434551003	AD2F73	6306 151789	LYUBOV NOVIKOVA	{"email": "lyubovnovikova.101980@postgrespro.ru", "phone": "+70367044815"}
0005434551004	CC44B1	3199 507894	OLGA ANISIMOVA	{"phone": "+70729967078"}
0005434551005	CC44B1	8280 826426	VYACHESLAV MELNIKOV	{"email": "melnikov.vyacheslav1979@postgrespro.ru", "phone": "+70205036829"}
0005434551006	D4DC96	7314 823710	OLGA PETROVA	{"phone": "+70712111377"}
0005434551007	D4DC96	1506 972295	SVETLANA ZAKHAROVA	{"phone": "+70082992003"}
0005434551008	954F32	4605 982764	NINA TROFIMOVA	{"email": "trofimovan.1958@postgrespro.ru", "phone": "+70969836430"}
0005434551009	1E8383	5732 414535	NATALYA KRASNOVA	{"phone": "+70965035226"}
0005434551010	A05C07	6504 192224	ANDREY MELNIKOV	{"phone": "+70091892638"}
0005434551011	850706	1056 091361	RUSLAN SHEVCHENKO	{"phone": "+70945849926"}
0005434551012	FCF6E0	4140 079796	TATYANA PETROVA	{"phone": "+70509137875"}
0005434551013	FCF6E0	2507 953536	EGOR SCHERBAKOV	{"email": "e_scherbakov_051970@postgrespro.ru", "phone": "+70302138349"}
0005434551014	08BFD9	6903 854943	NATALYA SIDOROVA	{"email": "sidorova-natalya101982@postgrespro.ru", "phone": "+70777277904"}
0005434551015	4B3E25	9642 248726	VLADIMIR NIKOLAEV	{"email": "nikolaev_vladimir.011965@postgrespro.ru", "phone": "+70990497466"}
0005434551016	4B3E25	2724 843622	IRINA KAZAKOVA	{"phone": "+70163643458"}
0005434551017	37596E	0963 362547	GEORGIY TIKHONOV	{"phone": "+70610117272"}
0005434551018	25E3A9	0927 263580	ANATOLIY SEMENOV	{"email": "anatoliysemenov.12091966@postgrespro.ru", "phone": "+70620532985"}
0005434551019	7CF80D	1311 498651	VLADISLAV SCHERBAKOV	{"email": "vladislav_scherbakov-1974@postgrespro.ru", "phone": "+70141560262"}
0005434551020	1F7ADF	8627 743365	PETR PAVLOV	{"email": "p.pavlov.091970@postgrespro.ru", "phone": "+70657843374"}
0005434551021	702399	9893 191143	ZOYA MIRONOVA	{"phone": "+70422346729"}
0005434551022	702399	9339 750808	IGOR KOZLOV	{"email": "kozlov_i.051976@postgrespro.ru", "phone": "+70942159740"}
0005434551023	E91A83	4853 887475	ALEKSEY SHEVCHENKO	{"email": "aleksey_shevchenko111969@postgrespro.ru", "phone": "+70627583409"}
0005434551024	A76FAC	6965 957833	DMITRIY KUZNECOV	{"email": "d_kuznecov_1964@postgrespro.ru", "phone": "+70095367635"}
0005434551025	9E7DB3	9956 984411	SVETLANA ZOTOVA	{"phone": "+70121687963"}
0005434551026	F80965	5593 535334	NATALYA SIDOROVA	{"email": "sidorova_natalya.15031961@postgrespro.ru", "phone": "+70666311781"}
0005434551027	7EC308	9577 169807	ANZHELIKA OSIPOVA	{"phone": "+70805868710"}
0005434551028	1E69DB	3577 694249	SOFIYA ISAEVA	{"phone": "+70583676609"}
0005434551029	7B75DC	1786 100630	ALBERT IVANOV	{"phone": "+70518112791"}
0005434551030	7B75DC	2281 741357	ANTON SCHERBAKOV	{"phone": "+70471180558"}
0005434551031	7B75DC	4586 788542	NATALYA ANDREEVA	{"email": "andreeva.n-031987@postgrespro.ru", "phone": "+70611551176"}
0005434551032	CD06FB	5462 630726	TAMARA VOROBEVA	{"email": "t-vorobeva_091979@postgrespro.ru", "phone": "+70571681927"}
0005434551033	B2061B	4954 399866	MARINA BORISOVA	{"email": "m-borisova_1973@postgrespro.ru", "phone": "+70337841627"}
0005434551034	BF2496	6253 084440	OLGA FILIPPOVA	{"email": "olga.filippova_061973@postgrespro.ru", "phone": "+70534105259"}
0005434551035	51C7CC	1885 913034	ANATOLIY EGOROV	{"email": "a_egorov_02071965@postgrespro.ru", "phone": "+70318930194"}
0005434551036	DC42F6	2298 108641	TATYANA IVANOVA	{"phone": "+70350214934"}
0005434551037	DC42F6	9288 686920	IRINA ALEKSEEVA	{"email": "alekseeva-irina-01071974@postgrespro.ru", "phone": "+70794466350"}
0005434551038	DC42F6	3361 568346	INNA KOROLEVA	{"email": "inna_koroleva_06101980@postgrespro.ru", "phone": "+70603611079"}
0005434551039	DA9CB3	5853 296270	ALEKSANDR SHEVCHENKO	{"phone": "+70367254842"}
0005434551040	9BA15B	9790 726172	TATYANA LAZAREVA	{"phone": "+70463322818"}
0005434551041	C11ACD	6957 329707	NIKOLAY POPOV	{"email": "nikolaypopov23021962@postgrespro.ru", "phone": "+70500289435"}
0005434551042	8DFB45	9253 017333	VIKTOR KOZLOV	{"email": "kozlov.viktor-021974@postgrespro.ru", "phone": "+70937335778"}
0005434551043	8DFB45	9414 229862	KLAVDIYA OVCHINNIKOVA	{"phone": "+70444981761"}
0005434551264	4C6D2E	9415 027012	ANNA ZAYCEVA	{"phone": "+70978052114"}
0005434551044	814CC4	4042 825039	ALEKSANDRA STEPANOVA	{"email": "stepanova.aleksandra21121969@postgrespro.ru", "phone": "+70891945118"}
0005434551045	80592F	6326 708935	NADEZHDA MAKAROVA	{"email": "nadezhda-makarova_111963@postgrespro.ru", "phone": "+70578681163"}
0005434551046	859D6C	9544 055027	NIKITA ZHURAVLEV	{"email": "n_zhuravlev_12091973@postgrespro.ru", "phone": "+70846121691"}
0005434551047	6C87D9	6963 946314	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda091974@postgrespro.ru", "phone": "+70940632522"}
0005434551048	2CC1BC	5830 872380	MIKHAIL IVANOV	{"email": "ivanov_mikhail1964@postgrespro.ru", "phone": "+70913034664"}
0005434551049	0347E9	2608 802782	OLGA LAZAREVA	{"email": "lazareva-o_23111974@postgrespro.ru", "phone": "+70107819179"}
0005434551050	99C3A7	3078 390096	DMITRIY DENISOV	{"email": "denisov.d-21111971@postgrespro.ru", "phone": "+70031913378"}
0005434551051	2FF8D2	8143 590934	SVETLANA KOMAROVA	{"email": "komarova-svetlana_081973@postgrespro.ru", "phone": "+70869560567"}
0005434551052	A38174	7749 750595	NADEZHDA ZAYCEVA	{"email": "zayceva_nadezhda_061976@postgrespro.ru", "phone": "+70444731214"}
0005434551053	20BE67	1627 345522	ALEKSEY GERASIMOV	{"email": "a.gerasimov-13071971@postgrespro.ru", "phone": "+70535504866"}
0005434551054	20BE67	2256 480324	ANASTASIYA SMIRNOVA	{"email": "anastasiyasmirnova.121972@postgrespro.ru", "phone": "+70708423655"}
0005434551055	BA0DD6	2932 658275	LYUDMILA MOROZOVA	{"email": "morozova-lyudmila-1959@postgrespro.ru", "phone": "+70490865205"}
0005434551056	BA0DD6	9711 696943	VIKTOR ZHURAVLEV	{"email": "v.zhuravlev.091983@postgrespro.ru", "phone": "+70472145300"}
0005434551057	BA0DD6	6632 324561	ANNA CHERNOVA	{"email": "chernova.anna081973@postgrespro.ru", "phone": "+70030200740"}
0005434551058	A91AD6	4471 925433	DMITRIY GRIGOREV	{"email": "grigorev-d041974@postgrespro.ru", "phone": "+70950867756"}
0005434551059	5599AE	3806 736519	SOFYA KOROLEVA	{"email": "s.koroleva-1971@postgrespro.ru", "phone": "+70071231675"}
0005434551060	D4FF64	1464 571075	VADIM SCHERBAKOV	{"email": "v-scherbakov.1984@postgrespro.ru", "phone": "+70120827802"}
0005434551061	160EA0	2791 965591	ANNA DENISOVA	{"phone": "+70518907660"}
0005434551062	160EA0	2943 686931	TATYANA BOGDANOVA	{"email": "tatyana-bogdanova18041973@postgrespro.ru", "phone": "+70600015397"}
0005434551063	957C12	8312 017490	ALEKSANDR PETROV	{"email": "petrov.aleksandr1964@postgrespro.ru", "phone": "+70844071152"}
0005434551064	957C12	3874 793420	NIKOLAY NIKOLAEV	{"email": "nikolaev-nikolay.30071961@postgrespro.ru", "phone": "+70516887269"}
0005434551065	7F6988	4553 695682	TATYANA MAKSIMOVA	{"phone": "+70687947732"}
0005434551066	14F1D3	3735 304546	ALEKSANDR KOZLOV	{"email": "kozlova.18061969@postgrespro.ru", "phone": "+70666999873"}
0005434551067	B000B6	5997 026742	ANDREY GERASIMOV	{"email": "gerasimova-07081961@postgrespro.ru", "phone": "+70413519605"}
0005434551068	B000B6	4776 639741	VALERIY DMITRIEV	{"phone": "+70436561539"}
0005434551069	C78A76	5241 433792	VASILIY NAUMOV	{"phone": "+70643998739"}
0005434551070	A8E5DC	4772 571897	DMITRIY VOLKOV	{"phone": "+70576292545"}
0005434551071	A8E5DC	4699 623618	VALENTINA EGOROVA	{"phone": "+70002403025"}
0005434551072	7D49FF	3474 473920	IRINA POPOVA	{"phone": "+70481963105"}
0005434551073	7FF592	2234 045798	TATYANA SERGEEVA	{"email": "sergeeva-tatyana091979@postgrespro.ru", "phone": "+70074501942"}
0005434551074	7FF592	2469 215715	GALINA CHERNOVA	{"email": "chernovagalina-08031962@postgrespro.ru", "phone": "+70307248326"}
0005434551075	8274DB	0489 716316	ALEKSANDR NIKITIN	{"phone": "+70490149105"}
0005434551076	5419ED	8907 271279	SERGEY KONOVALOV	{"phone": "+70698985706"}
0005434551077	E21214	3312 742292	OLGA KUZNECOVA	{"email": "o_kuznecova1972@postgrespro.ru", "phone": "+70975176023"}
0005434551078	C44E89	3604 161350	KLAVDIYA MIRONOVA	{"phone": "+70909053107"}
0005434551079	3E4143	4973 352866	MIKHAIL BORISOV	{"phone": "+70398759848"}
0005434551080	ABC673	9625 801821	ROMAN IVANOV	{"phone": "+70192577143"}
0005434551081	172C93	1092 388701	DIANA PAVLOVA	{"phone": "+70336830624"}
0005434551082	172C93	5686 984335	MIKHAIL NOVIKOV	{"email": "novikov_mikhail071977@postgrespro.ru", "phone": "+70303003643"}
0005434551083	EAB1F1	3280 997017	ALEVTINA MIKHAYLOVA	{"email": "a.mikhaylova-03041973@postgrespro.ru", "phone": "+70884053903"}
0005434551084	EAB1F1	7415 288770	TATYANA POLYAKOVA	{"email": "tatyana.polyakova-17101963@postgrespro.ru", "phone": "+70205724731"}
0005434551085	379345	5561 550209	VYACHESLAV MEDVEDEV	{"phone": "+70221863723"}
0005434551086	379345	3974 071205	NIKITA ABRAMOV	{"email": "abramov_nikita-1989@postgrespro.ru", "phone": "+70766049231"}
0005434551087	882B3A	0895 786020	NURIYA EFREMOVA	{"phone": "+70202856714"}
0005434551088	7BE0AC	9927 703306	VLADIMIR NOVIKOV	{"phone": "+70951467878"}
0005434551089	E3AB8E	8150 680353	NIKOLAY ALEKSEEV	{"email": "alekseev.n-1963@postgrespro.ru", "phone": "+70531693671"}
0005434551090	0E1993	5826 657290	MARINA CHERNOVA	{"email": "marina-chernova071969@postgrespro.ru", "phone": "+70885808284"}
0005434551091	56C413	2175 127639	SERGEY MOISEEV	{"email": "sergey-moiseev-03091969@postgrespro.ru", "phone": "+70313542996"}
0005434551092	56C413	5011 959025	ALSU MAKAROVA	{"email": "makarova_a31121967@postgrespro.ru", "phone": "+70431779585"}
0005434551093	3F586A	5458 070460	TATYANA KALININA	{"phone": "+70046114033"}
0005434551094	CE2C22	6922 167181	VIKTOR BELOV	{"email": "belov_viktor-1970@postgrespro.ru", "phone": "+70109717192"}
0005434551095	EEC69D	3988 055741	RAISA MIRONOVA	{"phone": "+70049542678"}
0005434551096	16CA34	2838 664800	ALEKSANDR ISAEV	{"email": "aleksandrisaev.1967@postgrespro.ru", "phone": "+70036160661"}
0005434551097	8E9A49	9999 496587	VYACHESLAV RODIONOV	{"email": "v_rodionov17031971@postgrespro.ru", "phone": "+70107987656"}
0005434551098	8E9A49	9187 152309	IVAN KRASNOV	{"email": "ivan-krasnov_1965@postgrespro.ru", "phone": "+70864461923"}
0005434551099	3F791E	9430 515307	YULIYA ILINA	{"phone": "+70973713831"}
0005434551100	6D35B0	6811 066200	NATALIYA NIKOLAEVA	{"phone": "+70624611190"}
0005434551101	9EFB71	8896 860579	VALENTINA ARKHIPOVA	{"phone": "+70580611399"}
0005434551102	14E23E	1739 255155	ALEKSEY EGOROV	{"phone": "+70317079841"}
0005434551103	EE36DE	7091 831434	SVETLANA RODIONOVA	{"email": "s-rodionova_061970@postgrespro.ru", "phone": "+70153263473"}
0005434551104	8D9211	4032 727697	ANNA IVANOVA	{"phone": "+70867823789"}
0005434551105	F7E7DC	3844 787086	YULIYA ORLOVA	{"email": "yuliyaorlova-12081979@postgrespro.ru", "phone": "+70448804251"}
0005434551106	F7E7DC	0619 283426	ELENA KUZNECOVA	{"phone": "+70825077601"}
0005434551107	62418D	0217 212052	OLEG STEPANOV	{"email": "o-stepanov_1974@postgrespro.ru", "phone": "+70915566563"}
0005434551108	79D7E2	7611 090922	NURLAN KUZNECOV	{"phone": "+70589526650"}
0005434551109	79D7E2	8260 049838	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana_1980@postgrespro.ru", "phone": "+70142007133"}
0005434551110	EEF650	5436 322771	DMITRIY KOZLOV	{"email": "kozlov-d.071981@postgrespro.ru", "phone": "+70235505727"}
0005434551111	EEF650	0433 285546	GENNADIY VASILEV	{"email": "g-vasilev17121969@postgrespro.ru", "phone": "+70453700840"}
0005434551112	9C29A9	6121 430652	LYUDMILA ARKHIPOVA	{"email": "arkhipoval_05051969@postgrespro.ru", "phone": "+70887802140"}
0005434551113	295F9C	3072 899309	EKATERINA KONDRATEVA	{"email": "kondratevaekaterina_1968@postgrespro.ru", "phone": "+70475412989"}
0005434551114	69CBFB	8891 189299	NATALYA FILIPPOVA	{"email": "n_filippova.091972@postgrespro.ru", "phone": "+70083860159"}
0005434551115	69CBFB	4039 549815	LYUBOV PAVLOVA	{"email": "pavlova.lyubov-061976@postgrespro.ru", "phone": "+70248290467"}
0005434551116	3D9846	9068 148378	NIKOLAY SIDOROV	{"phone": "+70257365638"}
0005434551117	2A5F91	1304 540891	SERGEY SEMENOV	{"phone": "+70320640598"}
0005434551118	E0E9E1	2174 324448	TATYANA NESTEROVA	{"phone": "+70095575371"}
0005434551119	29709C	8621 589204	VERA GUSEVA	{"phone": "+70532143646"}
0005434551120	29709C	4786 520392	VALENTINA DAVYDOVA	{"email": "valentinadavydova021970@postgrespro.ru", "phone": "+70731636624"}
0005434551121	68820C	7255 782914	OLGA SOLOVEVA	{"phone": "+70393887127"}
0005434551122	91342F	2599 963634	ALEKSANDR POPOV	{"email": "aleksandr.popov041968@postgrespro.ru", "phone": "+70766656202"}
0005434551123	91342F	4343 296858	LYUBOV GRISHINA	{"email": "grishina-lyubov.041966@postgrespro.ru", "phone": "+70022982940"}
0005434551124	366159	1632 958781	STANISLAV SOKOLOV	{"email": "stanislavsokolov_011980@postgrespro.ru", "phone": "+70698601284"}
0005434551125	48CC6F	8051 620623	OLGA TARASOVA	{"phone": "+70188435144"}
0005434551126	6362A3	7575 711065	IGOR BORISOV	{"email": "borisov-igor-03111979@postgrespro.ru", "phone": "+70211080121"}
0005434551127	6362A3	5311 261516	ANATOLIY MOROZOV	{"phone": "+70754260483"}
0005434551128	47DDEA	4708 223944	ANNA EFREMOVA	{"email": "efremova.a_20051974@postgrespro.ru", "phone": "+70523508279"}
0005434551129	238692	9184 086816	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov-071963@postgrespro.ru", "phone": "+70478152891"}
0005434551130	238692	4014 647405	EKATERINA RYABOVA	{"email": "ryabova-e.10011979@postgrespro.ru", "phone": "+70170130043"}
0005434551131	883BB6	4082 793013	KONSTANTIN ILIN	{"email": "ilin_konstantin-06041977@postgrespro.ru", "phone": "+70570588158"}
0005434551132	6C3509	3463 418843	NADEZHDA BORISOVA	{"email": "borisovanadezhda08021969@postgrespro.ru", "phone": "+70188367630"}
0005434551133	4F0DA4	2981 881764	INNA TARASOVA	{"email": "tarasova.inna_1977@postgrespro.ru", "phone": "+70194914010"}
0005434551134	4F0DA4	1843 290887	IGOR SEMENOV	{"phone": "+70386615014"}
0005434551135	25710E	1196 726036	ILYA SAVELEV	{"email": "savelevi-011969@postgrespro.ru", "phone": "+70599554198"}
0005434551136	25710E	6518 198947	VALERIY KARPOV	{"email": "karpovv_02081960@postgrespro.ru", "phone": "+70649812114"}
0005434551137	BCBB5A	0284 224667	MAKSIM KARPOV	{"email": "karpovm-021973@postgrespro.ru", "phone": "+70109378940"}
0005434551138	192E56	2143 145943	ELENA ZHURAVLEVA	{"email": "elena.zhuravleva.061982@postgrespro.ru", "phone": "+70495644477"}
0005434551139	FA0169	5018 146077	KRISTINA MELNIKOVA	{"phone": "+70112436099"}
0005434551140	6A620C	6783 515966	VALENTINA NIKOLAEVA	{"email": "valentinanikolaeva18111962@postgrespro.ru", "phone": "+70091335342"}
0005434551141	6A620C	3884 192628	STANISLAV PETROV	{"email": "stanislav.petrov.1980@postgrespro.ru", "phone": "+70043382351"}
0005434551142	6A620C	1015 931570	ALEKSEY SOKOLOV	{"email": "aleksey_sokolov_031978@postgrespro.ru", "phone": "+70807403770"}
0005434551143	8E6817	5965 270985	IVAN KONOVALOV	{"email": "konovalov.i-1983@postgrespro.ru", "phone": "+70884756779"}
0005434551144	4749F8	2123 154124	ROMAN MELNIKOV	{"email": "roman.melnikov.10011987@postgrespro.ru", "phone": "+70059901450"}
0005434551145	4749F8	3122 797697	VASILIY SOLOVEV	{"email": "solovev.vasiliy_07011969@postgrespro.ru", "phone": "+70128598000"}
0005434551146	990D78	0383 258058	SAMIRA MAKAROVA	{"email": "makarovas-1963@postgrespro.ru", "phone": "+70332161446"}
0005434551147	3243DA	6414 423216	ELENA VOLKOVA	{"email": "e.volkova_15101974@postgrespro.ru", "phone": "+70110569946"}
0005434551148	3243DA	8289 770980	LYUDMILA CHERNOVA	{"email": "chernova.lyudmila-10061961@postgrespro.ru", "phone": "+70445813512"}
0005434551149	DF7FF9	0913 933468	ALEVTINA STEPANOVA	{"email": "alevtina_stepanova_1979@postgrespro.ru", "phone": "+70077081833"}
0005434551150	DF7FF9	2620 182487	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir14061974@postgrespro.ru", "phone": "+70352090916"}
0005434551151	400818	3422 563393	ALEKSANDR FROLOV	{"phone": "+70479950945"}
0005434551152	400818	5575 512940	KIRILL EGOROV	{"email": "egorov-k.081966@postgrespro.ru", "phone": "+70839194891"}
0005434551153	99CD7D	3579 774027	MIKHAIL DENISOV	{"phone": "+70132655606"}
0005434551154	99CD7D	3325 211043	TAMARA MALYSHEVA	{"phone": "+70518701181"}
0005434551155	51A355	8697 745283	MARINA SERGEEVA	{"phone": "+70196216236"}
0005434551156	103E2F	8979 224501	MARIYA DENISOVA	{"phone": "+70103345769"}
0005434551157	058988	7552 406464	ALISA FEDOROVA	{"email": "a-fedorova1973@postgrespro.ru", "phone": "+70360565294"}
0005434551158	058988	0218 443962	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey_10111984@postgrespro.ru", "phone": "+70100384766"}
0005434551159	E19EE9	7504 455555	VALENTINA ROMANOVA	{"email": "romanovav021973@postgrespro.ru", "phone": "+70701208800"}
0005434551160	E92A11	4984 733472	ALEKSEY BELOV	{"phone": "+70718093115"}
0005434551161	6F514B	4090 654297	DANIIL SEMENOV	{"phone": "+70587094906"}
0005434551162	69A1CB	7057 605487	SERGEY PAVLOV	{"email": "sergey.pavlov_1979@postgrespro.ru", "phone": "+70115866410"}
0005434551163	9C04CF	1147 957020	GENNADIY PAVLOV	{"email": "gennadiy.pavlov_1970@postgrespro.ru", "phone": "+70153475049"}
0005434551164	9C04CF	8316 063870	GENNADIY GAVRILOV	{"email": "ggavrilov-1975@postgrespro.ru", "phone": "+70353316179"}
0005434551165	153B95	8652 936538	LIDIYA YAKOVLEVA	{"email": "lidiya.yakovleva.20101966@postgrespro.ru", "phone": "+70824654444"}
0005434551166	42F290	6534 573196	SVETLANA AFANASEVA	{"email": "s-afanaseva_09031965@postgrespro.ru", "phone": "+70740611841"}
0005434551167	FBA701	1120 183365	DMITRIY STEPANOV	{"phone": "+70314367952"}
0005434551168	F1374C	0832 790917	EKATERINA IVANOVA	{"phone": "+70296511007"}
0005434551169	F1374C	0127 222077	VARVARA ZOTOVA	{"email": "zotova-varvara_07071990@postgrespro.ru", "phone": "+70546491569"}
0005434551170	C23568	3106 444550	NIKOLAY PAVLOV	{"email": "pavlov_nikolay_061978@postgrespro.ru", "phone": "+70251920574"}
0005434551171	D08435	4844 180719	MARGARITA EGOROVA	{"email": "margarita-egorova_27101978@postgrespro.ru", "phone": "+70166490692"}
0005434551172	D08435	7272 033042	NADEZHDA MEDVEDEVA	{"phone": "+70347472360"}
0005434551173	43FF1E	1743 018967	TATYANA ARKHIPOVA	{"email": "t_arkhipova.041968@postgrespro.ru", "phone": "+70180583638"}
0005434551174	74A623	5692 151920	STANISLAV ALEKSEEV	{"email": "s_alekseev07071970@postgrespro.ru", "phone": "+70997213747"}
0005434551175	7DEBFA	0998 142131	MAKSIM SOLOVEV	{"email": "solovev_m_1975@postgrespro.ru", "phone": "+70965314554"}
0005434551176	E269F9	6466 166453	OLESYA POPOVA	{"phone": "+70591107519"}
0005434551177	9FD798	6429 191526	ALEKSEY MIKHAYLOV	{"email": "aleksey.mikhaylov-1963@postgrespro.ru", "phone": "+70286504682"}
0005434551178	FB1FD1	8534 598679	ALEKSANDR NIKOLAEV	{"phone": "+70679827665"}
0005434551179	FB1FD1	7596 362424	VITALIY MOISEEV	{"phone": "+70769863950"}
0005434551180	7E8A45	4740 928072	ANASTASIYA ROMANOVA	{"phone": "+70629379803"}
0005434551181	D71E10	1049 747209	NADEZHDA FILATOVA	{"email": "nadezhdafilatova29051979@postgrespro.ru", "phone": "+70891015110"}
0005434551182	D71E10	5640 667786	VLADIMIR NOVIKOV	{"phone": "+70201650804"}
0005434551183	5D36CB	4175 681406	ALEKSEY AFANASEV	{"email": "a-afanasev_04121982@postgrespro.ru", "phone": "+70523124307"}
0005434551184	262598	9570 896820	EKATERINA ANDREEVA	{"phone": "+70974830274"}
0005434551185	8810F1	0595 487854	DIANA ANDREEVA	{"phone": "+70973336251"}
0005434551186	8810F1	2738 956523	SVETLANA BORISOVA	{"email": "borisovas1978@postgrespro.ru", "phone": "+70112392056"}
0005434551187	67DACC	5962 110527	ELENA ANTONOVA	{"phone": "+70704469734"}
0005434551188	EC29BE	5921 295943	IVAN ROMANOV	{"phone": "+70927028091"}
0005434551189	F4ECD0	8657 738646	ANDREY MIRONOV	{"email": "andrey_mironov051974@postgrespro.ru", "phone": "+70521609357"}
0005434551190	F4ECD0	2265 478134	EKATERINA LUKYANOVA	{"phone": "+70618495428"}
0005434551191	C995BF	1064 017046	ANATOLIY KUZMIN	{"phone": "+70376844097"}
0005434551192	C995BF	9938 594052	MARINA MEDVEDEVA	{"email": "mmedvedeva_031973@postgrespro.ru", "phone": "+70201912642"}
0005434551193	7ED4EB	2250 067339	ALEKSANDR ZAKHAROV	{"phone": "+70097092183"}
0005434551194	7ED4EB	8400 283310	PRASKOVYA ANTONOVA	{"phone": "+70004463690"}
0005434551195	C2BA39	6441 701697	LYUDMILA POPOVA	{"email": "lyudmila.popova_091973@postgrespro.ru", "phone": "+70720859499"}
0005434551196	C0F59C	3105 490292	VADIM GUSEV	{"phone": "+70985897296"}
0005434551197	24E5B7	9058 067609	ANATOLIY MIRONOV	{"email": "a-mironov_16021973@postgrespro.ru", "phone": "+70156457224"}
0005434551198	76D41C	0368 579815	ANDREY POPOV	{"email": "andrey_popov-1973@postgrespro.ru", "phone": "+70305213260"}
0005434551199	890369	3139 070488	SVETLANA RODIONOVA	{"phone": "+70695989216"}
0005434551200	5A50CF	9657 602460	VALENTINA SMIRNOVA	{"email": "vsmirnova.051973@postgrespro.ru", "phone": "+70782469574"}
0005434551201	5D535D	4627 408809	FEDOR MAKAROV	{"phone": "+70097744020"}
0005434551202	A62519	7897 216278	VALENTINA MARTYNOVA	{"email": "martynova-valentina.021976@postgrespro.ru", "phone": "+70407016959"}
0005434551203	A2E9F9	6663 256378	NATALYA SOROKINA	{"email": "n.sorokina-1983@postgrespro.ru", "phone": "+70396230269"}
0005434551204	9FE417	8942 771895	PETR TIKHONOV	{"email": "tikhonovpetr.071980@postgrespro.ru", "phone": "+70288505396"}
0005434551205	576A91	5820 639154	ELENA ORLOVA	{"email": "orlovae.1973@postgrespro.ru", "phone": "+70860339667"}
0005434551206	576A91	4731 001576	GENNADIY IVANOV	{"email": "ivanov-gennadiy.1969@postgrespro.ru", "phone": "+70438174689"}
0005434551207	64178D	4683 010483	VALENTINA SOKOLOVA	{"phone": "+70830467311"}
0005434551208	8E26C5	7404 976136	ELENA NAZAROVA	{"email": "elena-nazarova-25091971@postgrespro.ru", "phone": "+70005665421"}
0005434551209	B4F8AD	1522 924411	ALEKSEY YAKOVLEV	{"phone": "+70327206358"}
0005434551210	E03CEF	3677 427754	ALEKSEY NAZAROV	{"phone": "+70900027172"}
0005434551211	93D352	5681 426213	PAVEL VOROBEV	{"email": "vorobev.p_081965@postgrespro.ru", "phone": "+70137174153"}
0005434551212	69E8DC	0134 904191	TATYANA ZOTOVA	{"email": "tzotova_21021982@postgrespro.ru", "phone": "+70903903679"}
0005434551213	A4CF4F	3435 129678	LYUDMILA NOVIKOVA	{"phone": "+70567014041"}
0005434551214	67EA7C	9381 184472	VASILIY DMITRIEV	{"email": "vasiliydmitriev.041977@postgrespro.ru", "phone": "+70988279699"}
0005434551215	12855D	4158 797138	NATALYA OVCHINNIKOVA	{"phone": "+70665123982"}
0005434551216	12855D	5295 785252	OLEG MIKHAYLOV	{"email": "omikhaylov.1976@postgrespro.ru", "phone": "+70601649606"}
0005434551217	96BF6F	6945 653269	NIKOLAY GAVRILOV	{"phone": "+70548831368"}
0005434551218	96BF6F	3160 465255	KSENIYA POLYAKOVA	{"phone": "+70842447549"}
0005434551219	8E587A	7224 788358	MIKHAIL VASILEV	{"email": "vasilev-mikhail.22101983@postgrespro.ru", "phone": "+70680131809"}
0005434551220	93382B	8651 237281	VALENTINA DENISOVA	{"phone": "+70034971366"}
0005434551221	D3F503	9384 656628	GALINA SCHERBAKOVA	{"phone": "+70644664041"}
0005434551222	640E4B	1291 007570	EVGENIY ORLOV	{"email": "evgeniy-orlov_011969@postgrespro.ru", "phone": "+70119938731"}
0005434551223	B7DA68	4672 905586	IRINA KUZNECOVA	{"email": "i.kuznecova_1976@postgrespro.ru", "phone": "+70692314369"}
0005434551224	0DA252	9198 734418	VASILIY KUZNECOV	{"email": "vkuznecov-04111967@postgrespro.ru", "phone": "+70603910264"}
0005434551225	0DA252	1238 414817	VLADIMIR PETROV	{"phone": "+70944667136"}
0005434551226	6DC989	1793 638843	PAVEL EGOROV	{"phone": "+70127852440"}
0005434551227	42A943	8870 522702	SERGEY GUSEV	{"email": "gusev.sergey111971@postgrespro.ru", "phone": "+70577999739"}
0005434551228	2FF7F0	8225 152498	AIDA ROMANOVA	{"phone": "+70368006489"}
0005434551229	6D42E2	5125 385858	SVETLANA STEPANOVA	{"phone": "+70116840775"}
0005434551230	B8B868	3594 745501	YURIY MIRONOV	{"email": "mironov_y-091980@postgrespro.ru", "phone": "+70284153088"}
0005434551231	21EF4D	2888 490098	MARGARITA OVCHINNIKOVA	{"email": "ovchinnikovamargarita-21061972@postgrespro.ru", "phone": "+70405708910"}
0005434551232	6248F5	0301 489717	GALINA MEDVEDEVA	{"phone": "+70679886749"}
0005434551233	C7869E	4776 018901	ALEKSANDRA KISELEVA	{"phone": "+70946963496"}
0005434551234	EE8333	5023 501310	EVGENIYA VLASOVA	{"email": "vlasova-e.1952@postgrespro.ru", "phone": "+70721781431"}
0005434551235	B4C872	7320 369978	VIKTOR BELOV	{"email": "vbelov041966@postgrespro.ru", "phone": "+70005351803"}
0005434551236	B4C872	4907 008797	RIMMA MATVEEVA	{"email": "r-matveeva-1970@postgrespro.ru", "phone": "+70507881217"}
0005434551237	EED8A9	1019 296050	ANASTASIYA MELNIKOVA	{"email": "melnikova-anastasiya_061981@postgrespro.ru", "phone": "+70564015217"}
0005434551238	EED8A9	7321 178295	VALENTINA KUZNECOVA	{"phone": "+70682426983"}
0005434551239	3AAB43	9481 717819	ALISA DENISOVA	{"email": "denisova-alisa_1980@postgrespro.ru", "phone": "+70151523856"}
0005434551240	3AAB43	9917 299423	TATYANA SCHERBAKOVA	{"phone": "+70353659164"}
0005434551241	CEF54C	5903 445986	LILIYA MAKSIMOVA	{"phone": "+70296711848"}
0005434551242	CEF54C	9115 830349	VADIM MATVEEV	{"phone": "+70095272085"}
0005434551243	CEF54C	5537 797815	IRINA AFANASEVA	{"phone": "+70316888253"}
0005434551244	5EC500	7820 155221	OLEG FILIPPOV	{"phone": "+70539215634"}
0005434551245	6F32AB	9332 130439	ELENA KALININA	{"phone": "+70048873348"}
0005434551246	6F32AB	3176 333222	VIKTOR SIDOROV	{"phone": "+70590773925"}
0005434551247	DAA89C	8890 451797	SVETLANA MOROZOVA	{"email": "svetlana_morozova_071971@postgrespro.ru", "phone": "+70224781741"}
0005434551248	49DB68	6105 729260	VIKTOR OSIPOV	{"phone": "+70827071880"}
0005434551249	49DB68	8516 578036	NADEZHDA SERGEEVA	{"email": "nadezhda-sergeeva-09091972@postgrespro.ru", "phone": "+70278082355"}
0005434551250	49DB68	9875 337490	TATYANA KUZMINA	{"phone": "+70755188884"}
0005434551251	E9B3B3	2140 270668	GEVORG PETROV	{"email": "g.petrov041973@postgrespro.ru", "phone": "+70961311950"}
0005434551252	E9B3B3	2673 239601	SERGEY KOZLOV	{"email": "sergey_kozlov-041972@postgrespro.ru", "phone": "+70172795813"}
0005434551253	830E85	4727 282310	EKATERINA SOKOLOVA	{"phone": "+70730718105"}
0005434551254	2A2B83	5131 505377	EKATERINA ABRAMOVA	{"email": "e-abramova-081973@postgrespro.ru", "phone": "+70222766512"}
0005434551255	232955	9690 210664	OLGA ZAYCEVA	{"email": "olga.zayceva.19011983@postgrespro.ru", "phone": "+70742190115"}
0005434551256	232955	0126 483673	ANDREY ANDREEV	{"phone": "+70978197716"}
0005434551257	232955	0654 779734	INNA IVANOVA	{"email": "i_ivanova-021966@postgrespro.ru", "phone": "+70535806712"}
0005434551258	232955	4722 545101	PETR GRIGOREV	{"phone": "+70903948992"}
0005434551259	3E4953	8611 220233	KIRILL KOZLOV	{"phone": "+70231905618"}
0005434551260	566760	5420 768420	SERGEY KUZNECOV	{"email": "sergey_kuznecov-06111974@postgrespro.ru", "phone": "+70035375483"}
0005434551261	4F1F4E	5754 502143	IVAN TARASOV	{"email": "tarasovi.1976@postgrespro.ru", "phone": "+70646560669"}
0005434551262	F6B8BB	0533 326742	GALINA SOKOLOVA	{"email": "sokolova.galina-16031960@postgrespro.ru", "phone": "+70263620550"}
0005434551263	EE8DDC	8164 434177	ALEKSANDRA GRISHINA	{"email": "grishina_a.061966@postgrespro.ru", "phone": "+70859053799"}
0005434551265	4C6D2E	4997 608863	YAN SEMENOV	{"email": "yansemenov.041980@postgrespro.ru", "phone": "+70134249103"}
0005434551266	4C6D2E	9702 543628	MAKSIM FEDOTOV	{"email": "fedotov_maksim.28111966@postgrespro.ru", "phone": "+70175291122"}
0005434551267	10F2E5	2058 244332	ALEKSANDR KOZLOV	{"email": "kozlova_101973@postgrespro.ru", "phone": "+70740506998"}
0005434551268	6D893F	8978 312263	LYUDMILA KONOVALOVA	{"phone": "+70440943240"}
0005434551269	71F330	4160 941624	NADEZHDA ZHURAVLEVA	{"phone": "+70283291528"}
0005434551270	78E2AB	7621 051173	ALEKSEY ORLOV	{"email": "orlova-091979@postgrespro.ru", "phone": "+70202518020"}
0005434551271	34342C	7465 725829	KARINA GAVRILOVA	{"phone": "+70493932025"}
0005434551272	B4A96B	0182 783807	OLEG KUZNECOV	{"email": "o.kuznecov-091969@postgrespro.ru", "phone": "+70066546745"}
0005434551273	B8656D	3339 511752	NATALYA FILIPPOVA	{"phone": "+70332701997"}
0005434551274	B8656D	7399 076405	ANATOLIY ANDREEV	{"phone": "+70233181154"}
0005434551275	B8656D	9196 271090	SVETLANA POPOVA	{"email": "popovas071975@postgrespro.ru", "phone": "+70668237532"}
0005434551276	854AF0	0228 009813	ZOYA NOVIKOVA	{"email": "z-novikova-1969@postgrespro.ru", "phone": "+70278155795"}
0005434551277	36872A	2345 672572	RAISA KUZNECOVA	{"email": "kuznecova.raisa-091979@postgrespro.ru", "phone": "+70971187997"}
0005434551278	36872A	8249 193880	VERONIKA NIKOLAEVA	{"phone": "+70141025279"}
0005434551279	3A047F	7847 700639	RITA ZAYCEVA	{"email": "r_zayceva_1986@postgrespro.ru", "phone": "+70731608434"}
0005434551280	0391DD	9319 229227	NIKOLAY ZHUKOV	{"phone": "+70037816919"}
0005434551281	0391DD	9160 099851	VIKTOR VLASOV	{"phone": "+70396813153"}
0005434551282	D87FC9	2352 415474	VLADIMIR POPOV	{"email": "popov-vladimir30121978@postgrespro.ru", "phone": "+70272909590"}
0005434551283	D87FC9	7623 084574	YURIY MIRONOV	{"email": "mironov_y.071972@postgrespro.ru", "phone": "+70406204309"}
0005434551284	C7A5F4	8334 217554	MIKHAIL SOLOVEV	{"email": "mikhail-solovev_1980@postgrespro.ru", "phone": "+70204947499"}
0005434551285	2F109F	2789 213996	ANNA SERGEEVA	{"email": "sergeeva.a.011967@postgrespro.ru", "phone": "+70459386273"}
0005434551286	C59265	0301 570304	ANASTASIYA KUZNECOVA	{"phone": "+70035645363"}
0005434551287	C59265	4527 489089	ALEKSEY ZAYCEV	{"email": "zaycev_aleksey-111973@postgrespro.ru", "phone": "+70317719722"}
0005434551288	22D92E	7310 360339	TIGRAN MATVEEV	{"phone": "+70971747244"}
0005434551289	6CB190	4745 859464	SVETLANA IVANOVA	{"phone": "+70351845608"}
0005434551290	6CB190	4573 083163	ANATOLIY TIKHONOV	{"phone": "+70489237124"}
0005434551291	46A636	6543 515026	LYUDMILA ROMANOVA	{"phone": "+70152755614"}
0005434551292	DD6AB4	2175 390541	ALINA SIDOROVA	{"phone": "+70995949323"}
0005434551293	170003	8659 560732	NATALYA SOROKINA	{"email": "sorokina.natalya_20061979@postgrespro.ru", "phone": "+70397409880"}
0005434551294	5148B7	3899 109946	LIDIYA TITOVA	{"phone": "+70764396272"}
0005434551295	69C850	8075 511792	NATALIYA MIRONOVA	{"email": "mironova-nataliya.091982@postgrespro.ru", "phone": "+70118617446"}
0005434551296	A2A2CB	4236 268147	GERMAN KUZNECOV	{"email": "germankuznecov-1968@postgrespro.ru", "phone": "+70956867441"}
0005434551297	A2A2CB	8064 439009	VLADIMIR MAKSIMOV	{"email": "vladimirmaksimov1973@postgrespro.ru", "phone": "+70795512649"}
0005434551298	EE59A6	3259 604838	ALEKSEY SCHERBAKOV	{"phone": "+70601338858"}
0005434551299	EE59A6	2365 102449	ANNA RYABOVA	{"email": "anna-ryabova.1975@postgrespro.ru", "phone": "+70177614122"}
0005434551300	77FCEA	3202 971307	VIKTORIYA DANILOVA	{"email": "v.danilova-13081981@postgrespro.ru", "phone": "+70059963057"}
0005434551301	D55D2B	3400 516279	NATALYA ZAYCEVA	{"phone": "+70279883447"}
0005434551302	D55D2B	5287 109358	IVAN CHERNOV	{"email": "ivan_chernov.111974@postgrespro.ru", "phone": "+70116538349"}
0005434551471	5FD9E5	6973 019766	SERGEY SMIRNOV	{"phone": "+70136582607"}
0005434551303	D234D6	7673 873783	LILIYA MIRONOVA	{"email": "mironova_liliya.01111970@postgrespro.ru", "phone": "+70887023627"}
0005434551304	3072BD	7738 731163	VLADIMIR GUSEV	{"phone": "+70917766911"}
0005434551305	3072BD	3697 216600	LIDIYA SOKOLOVA	{"phone": "+70340111987"}
0005434551306	88FEC2	3973 422898	ALEKSANDR VLASOV	{"phone": "+70737007373"}
0005434551307	88FEC2	0423 262720	NADEZHDA MARTYNOVA	{"email": "n.martynova.1974@postgrespro.ru", "phone": "+70875576204"}
0005434551308	C698DB	7671 591140	VALERIYA VOLKOVA	{"email": "volkova.valeriya-1981@postgrespro.ru", "phone": "+70460574321"}
0005434551309	38FA4A	9557 778790	ANDREY DMITRIEV	{"email": "dmitriev_a_121978@postgrespro.ru", "phone": "+70734583836"}
0005434551310	844C19	9865 374516	VLADIMIR KUZNECOV	{"email": "v.kuznecov10091975@postgrespro.ru", "phone": "+70602443297"}
0005434551311	692900	4652 483260	EKATERINA EFREMOVA	{"email": "efremova-e1973@postgrespro.ru", "phone": "+70522377622"}
0005434551312	5D2CE6	4343 296758	NATALIYA SERGEEVA	{"email": "sergeeva_n-18021980@postgrespro.ru", "phone": "+70459951002"}
0005434551313	5D2CE6	5009 778375	ANNA GAVRILOVA	{"email": "anna-gavrilova_1971@postgrespro.ru", "phone": "+70595292746"}
0005434551314	7275AE	3301 223296	IRINA ABRAMOVA	{"email": "i-abramova-01051970@postgrespro.ru", "phone": "+70781361105"}
0005434551315	5C6503	2398 149590	MARIYA KUZMINA	{"email": "mariya-kuzmina_111963@postgrespro.ru", "phone": "+70641853077"}
0005434551316	6843A5	2694 703819	ALFIYA YUDINA	{"email": "yudina.alfiya_031972@postgrespro.ru", "phone": "+70273789489"}
0005434551317	6843A5	5285 806334	MAKSIM DAVYDOV	{"phone": "+70845992130"}
0005434551318	83D63C	8662 759677	LYUBOV ALEKSEEVA	{"phone": "+70620585900"}
0005434551319	83D63C	4898 396379	ANVAR ORLOV	{"phone": "+70324654853"}
0005434551432	F6C862	3651 304593	NIKITA MELNIKOV	{"phone": "+70763934070"}
0005434551320	DD1BB3	7027 393677	MARIYA PETROVA	{"email": "mariya_petrova1975@postgrespro.ru", "phone": "+70071278000"}
0005434551321	4BF84F	9460 845822	ALEKSANDR KUZNECOV	{"phone": "+70757150585"}
0005434551322	4BF84F	1550 389271	ANNA SIDOROVA	{"phone": "+70499996382"}
0005434551323	BF0B8D	0667 222028	ANTONINA ISAEVA	{"phone": "+70034967109"}
0005434551324	64308B	8676 157743	VERA TIMOFEEVA	{"phone": "+70210475470"}
0005434551325	64308B	2318 167453	NATALYA ZAKHAROVA	{"email": "zakharova_n061964@postgrespro.ru", "phone": "+70099399266"}
0005434551326	1D46C0	6855 212094	VLADIMIR TARASOV	{"phone": "+70050515141"}
0005434551327	1D46C0	3399 085468	GALINA IVANOVA	{"phone": "+70998554433"}
0005434551328	02842C	9815 243130	IVAN TIKHONOV	{"phone": "+70807380756"}
0005434551329	02842C	0029 078011	ANNA KUZNECOVA	{"email": "kuznecova-a11031977@postgrespro.ru", "phone": "+70395938653"}
0005434551330	7AC280	9430 513484	ANTONINA ANDREEVA	{"phone": "+70933983456"}
0005434551331	CC2134	7395 889725	VASILIY SERGEEV	{"phone": "+70889193131"}
0005434551332	57802F	1713 739267	SVETLANA KOROLEVA	{"email": "korolevas.1982@postgrespro.ru", "phone": "+70859601228"}
0005434551333	7DA4FE	6649 592808	MAYYA SAVELEVA	{"email": "saveleva-m121974@postgrespro.ru", "phone": "+70043210765"}
0005434551334	3DFDFF	3093 183798	ANVAR TIKHONOV	{"email": "anvar_tikhonov.1972@postgrespro.ru", "phone": "+70018675800"}
0005434551335	3DFDFF	7192 542605	PAVEL DMITRIEV	{"email": "dmitriev_p051975@postgrespro.ru", "phone": "+70873248604"}
0005434551336	3DFDFF	6736 045059	ANASTASIYA SEMENOVA	{"phone": "+70734327113"}
0005434551337	59E579	6504 632615	EKATERINA MEDVEDEVA	{"email": "ekaterina.medvedeva1972@postgrespro.ru", "phone": "+70105558213"}
0005434551338	60F4E9	6672 504220	EVGENIY GAVRILOV	{"phone": "+70699379570"}
0005434551339	A5BCDF	9608 002692	ALEKSEY BELOV	{"email": "belov_aleksey-23051961@postgrespro.ru", "phone": "+70721255580"}
0005434551340	922492	0788 456552	NADEZHDA SOKOLOVA	{"phone": "+70552447928"}
0005434551341	922492	8367 126616	ALEKSANDR BORISOV	{"email": "borisovaleksandr.05111977@postgrespro.ru", "phone": "+70400930727"}
0005434551342	FCDC66	6466 674135	ILYAS ZHURAVLEV	{"phone": "+70203974259"}
0005434551343	891475	8357 597313	MARINA NIKITINA	{"phone": "+70866511109"}
0005434551344	0E6C6A	9786 481935	OLEG VLASOV	{"phone": "+70546266261"}
0005434551345	F7CA5E	2095 891136	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev-021984@postgrespro.ru", "phone": "+70064297855"}
0005434551346	0BF12B	0628 286389	ANDREY ROMANOV	{"email": "andrey_romanov.06091965@postgrespro.ru", "phone": "+70405341999"}
0005434551347	0BF12B	2985 832211	NADEZHDA FOMINA	{"email": "nadezhdafomina13081971@postgrespro.ru", "phone": "+70838725841"}
0005434551348	E5B249	8516 414252	ANATOLIY SERGEEV	{"phone": "+70054593060"}
0005434551349	545BC9	7751 338329	VIKTOR FILIPPOV	{"email": "filippovv021972@postgrespro.ru", "phone": "+70996726727"}
0005434551350	040B7F	1197 774666	MARIYA KUZNECOVA	{"email": "kuznecovam_031978@postgrespro.ru", "phone": "+70254174993"}
0005434551351	040B7F	9629 359677	MIKHAIL ILIN	{"phone": "+70021079846"}
0005434551352	693725	1995 395548	FANIYA VOLKOVA	{"phone": "+70272717789"}
0005434551353	693725	1470 705737	ALEKSANDR BELOV	{"phone": "+70717947259"}
0005434551354	D494A5	7143 879050	SVETLANA IVANOVA	{"email": "svetlanaivanova-1977@postgrespro.ru", "phone": "+70694587075"}
0005434551355	D494A5	0336 889028	EVGENIY POPOV	{"email": "e-popov.10101965@postgrespro.ru", "phone": "+70161451229"}
0005434551356	8F45AB	4239 053627	LYUDMILA IVANOVA	{"email": "ivanovalyudmila_06121969@postgrespro.ru", "phone": "+70332402023"}
0005434551357	8F45AB	3729 784527	VIKTOR GRIGOREV	{"phone": "+70756758967"}
0005434551358	D98521	1729 829347	LYUBOV POPOVA	{"email": "lyubovpopova.1965@postgrespro.ru", "phone": "+70485536350"}
0005434551359	D98521	3906 942180	NATALYA VASILEVA	{"phone": "+70716190790"}
0005434551360	7638AC	1317 357544	GALINA VOLKOVA	{"phone": "+70438034329"}
0005434551361	130AC5	2307 508441	NATALYA STEPANOVA	{"email": "stepanova-natalya_25111971@postgrespro.ru", "phone": "+70281153881"}
0005434551362	E89A67	9792 445160	ARTUR BORISOV	{"email": "borisov.a121976@postgrespro.ru", "phone": "+70291371496"}
0005434551363	E89A67	4722 667165	ALEKSANDR KAZAKOV	{"email": "kazakov_a-04021978@postgrespro.ru", "phone": "+70432639890"}
0005434551364	6CF3A3	2441 502785	TIMUR EGOROV	{"phone": "+70730332101"}
0005434551365	9842FC	9128 617305	MAKSIM KUZNECOV	{"phone": "+70261291058"}
0005434551366	9E3A73	9780 560794	TATYANA KOVALEVA	{"email": "kovaleva.tatyana.1980@postgrespro.ru", "phone": "+70892350653"}
0005434551367	52CEF0	4132 514150	YULIYA FOMINA	{"email": "yuliya-fomina_25111977@postgrespro.ru", "phone": "+70834980297"}
0005434551368	52CEF0	6223 591104	NATALYA VOROBEVA	{"phone": "+70616795694"}
0005434551369	F00AD0	0326 233233	NATALYA LAZAREVA	{"phone": "+70199057114"}
0005434551370	F00AD0	3522 625593	VLADIMIR ROMANOV	{"phone": "+70631327476"}
0005434551371	E18E86	6457 841723	VITALIY IVANOV	{"phone": "+70218386716"}
0005434551372	F92959	9682 755049	FEDOR SCHERBAKOV	{"phone": "+70722725923"}
0005434551373	F92959	0433 499436	AYRAT POPOV	{"phone": "+70146629377"}
0005434551374	AAB6A9	3078 080059	ALEKSANDRA DMITRIEVA	{"email": "dmitrieva.aleksandra_021966@postgrespro.ru", "phone": "+70434886206"}
0005434551375	AAB6A9	8665 391120	IRINA MOROZOVA	{"email": "i-morozova-1978@postgrespro.ru", "phone": "+70828957760"}
0005434551376	09A047	8554 346090	VLADIMIR KOZLOV	{"email": "v_kozlov.1975@postgrespro.ru", "phone": "+70010583222"}
0005434551377	8A76FB	3936 107797	NATALYA TROFIMOVA	{"email": "n_trofimova_1970@postgrespro.ru", "phone": "+70186511249"}
0005434551378	363E6A	0597 537375	ARKADIY KUDRYASHOV	{"phone": "+70680495235"}
0005434551379	363E6A	4048 291858	ELENA KARPOVA	{"email": "karpova_e111981@postgrespro.ru", "phone": "+70009587982"}
0005434551380	24CA6F	9536 750012	ARINA BORISOVA	{"phone": "+70845782545"}
0005434551381	716DA2	3283 415905	FILIPP IVANOV	{"email": "f_ivanov-17061981@postgrespro.ru", "phone": "+70058704301"}
0005434551382	716DA2	8987 051330	ELENA KOLESNIKOVA	{"email": "kolesnikova_e111980@postgrespro.ru", "phone": "+70777044626"}
0005434551383	394ECB	3952 374401	GALINA NAZAROVA	{"email": "galina-nazarova.24011977@postgrespro.ru", "phone": "+70046850766"}
0005434551384	ECACE1	2392 773467	ANASTASIYA MARTYNOVA	{"email": "martynovaanastasiya-10081964@postgrespro.ru", "phone": "+70993129977"}
0005434551385	224CB3	2538 415207	RAISA ERMAKOVA	{"email": "r_ermakova.17091963@postgrespro.ru", "phone": "+70000868919"}
0005434551386	E3280F	0086 700942	TATYANA KARPOVA	{"phone": "+70604465899"}
0005434551387	C64239	3382 909951	VLADIMIR ZAKHAROV	{"email": "v-zakharov_1963@postgrespro.ru", "phone": "+70830424441"}
0005434551388	C64239	2392 221807	ANASTASIYA LUKYANOVA	{"email": "anastasiya_lukyanova-10081955@postgrespro.ru", "phone": "+70744801432"}
0005434551389	C5C1B9	1508 120887	DENIS ZHUKOV	{"email": "denis-zhukov-1971@postgrespro.ru", "phone": "+70780905409"}
0005434551390	C5C1B9	2453 751092	EVGENIY FEDOTOV	{"email": "fedotove.20041971@postgrespro.ru", "phone": "+70297740082"}
0005434551391	C5C1B9	4596 336425	ELIZAVETA FOMINA	{"phone": "+70333221051"}
0005434551392	9FE961	7750 656758	ALISA MIRONOVA	{"email": "alisa_mironova_1971@postgrespro.ru", "phone": "+70844402951"}
0005434551393	F6DFEE	9228 269085	PAVEL MIKHAYLOV	{"email": "p-mikhaylov.1969@postgrespro.ru", "phone": "+70946161988"}
0005434551394	C93D4B	5781 884669	ANNA VOLKOVA	{"email": "avolkova1962@postgrespro.ru", "phone": "+70934853978"}
0005434551395	09D6B7	3551 794363	SVETLANA MOROZOVA	{"phone": "+70876620018"}
0005434551396	09D6B7	5682 630077	MIKHAIL SERGEEV	{"email": "sergeev-m021970@postgrespro.ru", "phone": "+70355219053"}
0005434551397	197609	7493 262678	TATYANA VLASOVA	{"phone": "+70979179310"}
0005434551398	197609	9821 144541	OLGA POPOVA	{"email": "olga.popova-1983@postgrespro.ru", "phone": "+70222742963"}
0005434551399	ACCE49	9357 175543	VLADIMIR TARASOV	{"phone": "+70145500838"}
0005434551400	5B3109	5505 374535	TATYANA KAZAKOVA	{"email": "tatyana_kazakova-121958@postgrespro.ru", "phone": "+70074612812"}
0005434551401	A4CBCB	5834 061311	LYUDMILA FILATOVA	{"phone": "+70368334346"}
0005434551402	C8B831	5309 156819	ELENA KONOVALOVA	{"phone": "+70711306491"}
0005434551403	4FE646	4381 956631	SERGEY IVANOV	{"phone": "+70214485673"}
0005434551404	C32EF6	6301 771631	LYUDMILA CHERNOVA	{"phone": "+70141502515"}
0005434551405	E8F042	8277 185038	SERGEY KONOVALOV	{"phone": "+70680565388"}
0005434551406	D6446B	0453 034659	KONSTANTIN NIKITIN	{"email": "nikitin.k.041963@postgrespro.ru", "phone": "+70838995745"}
0005434551407	D6446B	0715 014394	ALBINA PETROVA	{"email": "petrovaalbina-011976@postgrespro.ru", "phone": "+70277346558"}
0005434551408	879A26	9049 693954	NATALIYA EFREMOVA	{"phone": "+70649934130"}
0005434551409	0726C3	6474 864963	OLGA CHERNOVA	{"email": "chernova-o1963@postgrespro.ru", "phone": "+70959305892"}
0005434551410	E458C0	9848 297811	NATALYA EGOROVA	{"phone": "+70298562749"}
0005434551411	E458C0	7719 573550	LYUCIYA GAVRILOVA	{"email": "l-gavrilova_011972@postgrespro.ru", "phone": "+70506378553"}
0005434551412	E458C0	8626 031456	OLGA GAVRILOVA	{"phone": "+70597791428"}
0005434551413	37BFAF	8244 146797	IRINA NOVIKOVA	{"email": "i.novikova1974@postgrespro.ru", "phone": "+70946527077"}
0005434551414	CF5216	6315 470018	VITALIY GAVRILOV	{"email": "gavrilov-vitaliy-1966@postgrespro.ru", "phone": "+70148721510"}
0005434551415	CF5216	6341 484438	PELAGEYA MIRONOVA	{"phone": "+70828700180"}
0005434551416	106C55	0629 875067	NATALYA KRASNOVA	{"email": "n.krasnova.24081971@postgrespro.ru", "phone": "+70406868393"}
0005434551417	8EAD26	3138 382902	LYUDMILA MIRONOVA	{"phone": "+70510494199"}
0005434551418	8EAD26	4879 743303	ANDREY KRASNOV	{"email": "andreykrasnov1965@postgrespro.ru", "phone": "+70481608050"}
0005434551419	8EAD26	5906 612936	RAFAIL FEDOTOV	{"phone": "+70124777969"}
0005434551420	76ECBD	7738 465542	VLADIMIR MAKSIMOV	{"email": "maksimov.v-021990@postgrespro.ru", "phone": "+70300754766"}
0005434551421	0563E1	6663 217221	NINA SERGEEVA	{"email": "sergeeva-nina1969@postgrespro.ru", "phone": "+70182652666"}
0005434551422	DF2630	3488 838451	NIKOLAY GUSEV	{"phone": "+70069593641"}
0005434551423	8A8E76	7099 152092	ANATOLIY MARTYNOV	{"phone": "+70968603679"}
0005434551424	8A8E76	3658 974586	RADIK NOVIKOV	{"email": "novikov_r.12121967@postgrespro.ru", "phone": "+70971761910"}
0005434551425	01D822	8439 808930	MIKHAIL SOKOLOV	{"email": "sokolovm061974@postgrespro.ru", "phone": "+70943539713"}
0005434551426	262FD4	1488 194865	EKATERINA IVANOVA	{"phone": "+70824803864"}
0005434551427	D9CB34	2437 435858	TAMARA SOROKINA	{"phone": "+70913720103"}
0005434551428	D9CB34	9660 526252	MARIYA MARTYNOVA	{"phone": "+70914410511"}
0005434551429	56D26C	1913 896463	ALEKSANDR IVANOV	{"phone": "+70440780863"}
0005434551430	02ABB3	6091 002868	VLADIMIR MATVEEV	{"phone": "+70180376057"}
0005434551431	CFBB32	0381 066136	NATALYA LUKYANOVA	{"phone": "+70618028272"}
0005434551433	F6C862	3138 194537	NATALYA MATVEEVA	{"phone": "+70424031910"}
0005434551434	F6C862	1301 746948	ANDREY ILIN	{"email": "ilin_andrey.101969@postgrespro.ru", "phone": "+70701851576"}
0005434551435	2AC383	9304 395900	EVGENIY ZAYCEV	{"email": "zaycev-e.02011966@postgrespro.ru", "phone": "+70089532859"}
0005434551436	38E640	2968 166880	KONSTANTIN TIKHONOV	{"email": "k.tikhonov_11041986@postgrespro.ru", "phone": "+70880352113"}
0005434551437	38E640	6226 217434	VALERIY SMIRNOV	{"email": "valeriy-smirnov.29041975@postgrespro.ru", "phone": "+70284603738"}
0005434551438	1335FF	6551 666230	OLGA NOVIKOVA	{"phone": "+70367138173"}
0005434551439	1335FF	2580 581271	VITALIY BONDARENKO	{"email": "vitaliy-bondarenko-08041977@postgrespro.ru", "phone": "+70828336637"}
0005434551440	A9718C	1130 873581	ELENA ILINA	{"email": "ilina-elena1976@postgrespro.ru", "phone": "+70995286610"}
0005434551441	A9718C	0834 025190	ALBINA BELOVA	{"email": "albina_belova071961@postgrespro.ru", "phone": "+70937415342"}
0005434551442	E672F8	8388 339633	VASILIY KRASNOV	{"email": "krasnovv-23071965@postgrespro.ru", "phone": "+70222608799"}
0005434551443	34D5CC	3273 141070	MAKSIM MIKHAYLOV	{"phone": "+70053034070"}
0005434551444	40ECAA	1649 460750	KIRILL ANDREEV	{"email": "andreev.kirill121955@postgrespro.ru", "phone": "+70681218189"}
0005434551445	6F2301	1261 039909	ANDREY NIKITIN	{"phone": "+70518808295"}
0005434551446	6F2301	7836 855342	RAVIL VOROBEV	{"email": "rvorobev-25031982@postgrespro.ru", "phone": "+70876369246"}
0005434551447	49A387	4160 308738	ALEKSANDR MELNIKOV	{"phone": "+70717172992"}
0005434551448	4C2CBF	9029 200456	IVAN MAKAROV	{"email": "ivan-makarov.07061979@postgrespro.ru", "phone": "+70969791354"}
0005434551449	4C2CBF	4149 790957	OKSANA DAVYDOVA	{"phone": "+70329289603"}
0005434551450	CCA8A7	3840 637765	MIKHAIL GRIGOREV	{"phone": "+70776237440"}
0005434551451	CCA8A7	0001 280195	ALEKSANDR KUZMIN	{"email": "kuzmin.a091974@postgrespro.ru", "phone": "+70786010066"}
0005434551452	D8CDAD	0227 347433	ILNAR TARASOV	{"email": "ilnar-tarasov-05101981@postgrespro.ru", "phone": "+70293923955"}
0005434551453	D8CDAD	9398 813681	YURIY SOKOLOV	{"email": "yuriy-sokolov_021966@postgrespro.ru", "phone": "+70726827289"}
0005434551454	F8A067	4635 517378	LYUBOV MALYSHEVA	{"email": "malysheva-l011965@postgrespro.ru", "phone": "+70496593656"}
0005434551455	CFE896	0653 906176	DENIS GAVRILOV	{"phone": "+70531953451"}
0005434551456	34F966	0035 096013	ALEKSANDRA TARASOVA	{"phone": "+70433339533"}
0005434551457	A3245E	1499 170374	NIKOLAY SOKOLOV	{"email": "sokolov-nikolay02081976@postgrespro.ru", "phone": "+70792228199"}
0005434551458	F93011	3512 152400	VYACHESLAV POPOV	{"email": "vyacheslav.popov091980@postgrespro.ru", "phone": "+70818073851"}
0005434551459	F93011	8963 802691	SERGEY BELOV	{"email": "belov.s_19031975@postgrespro.ru", "phone": "+70804092408"}
0005434551460	3EF0EA	7282 950605	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov.1973@postgrespro.ru", "phone": "+70614389632"}
0005434551461	2406BA	2941 716095	ALLA MAKAROVA	{"email": "makarovaa-061975@postgrespro.ru", "phone": "+70818973610"}
0005434551462	F7BD80	9727 908243	VIKTORIYA BELOVA	{"email": "v.belova08021971@postgrespro.ru", "phone": "+70178284881"}
0005434551463	FA1EBE	7826 902620	GALINA MALYSHEVA	{"phone": "+70209334830"}
0005434551464	790351	9165 086447	ANNA BORISOVA	{"phone": "+70559278171"}
0005434551465	790351	0126 216119	ANNA KONDRATEVA	{"email": "kondrateva_a-101968@postgrespro.ru", "phone": "+70502464734"}
0005434551466	8BFB07	9400 662932	VITALIY FROLOV	{"phone": "+70659742734"}
0005434551467	C5D0E0	3612 552150	LYUDMILA GERASIMOVA	{"phone": "+70533082976"}
0005434551468	E8DA18	2421 580833	YULIYA ISAEVA	{"phone": "+70206199486"}
0005434551469	EF41BD	2196 458722	ANATOLIY GAVRILOV	{"phone": "+70510475507"}
0005434551470	EF41BD	9770 589350	PETR SMIRNOV	{"email": "p-smirnov_1967@postgrespro.ru", "phone": "+70226846281"}
0005434551472	5FD9E5	0310 771355	SERGEY PETROV	{"email": "petrov.s-061982@postgrespro.ru", "phone": "+70107375933"}
0005434551473	FC5B8F	0158 273518	EVGENIY PETROV	{"email": "petrov_evgeniy.121968@postgrespro.ru", "phone": "+70612165562"}
0005434551474	1C0427	6484 193645	ALEKSANDR KUZNECOV	{"email": "kuznecov-a08061971@postgrespro.ru", "phone": "+70449428593"}
0005434551475	F50208	4224 298630	SERGEY VASILEV	{"email": "s.vasilev-061975@postgrespro.ru", "phone": "+70877257767"}
0005434551476	21D512	6746 255605	TATYANA EGOROVA	{"email": "tegorova_04061976@postgrespro.ru", "phone": "+70059806345"}
0005434551477	21D512	3123 289014	MAKSIM NAUMOV	{"email": "naumov_maksim_081974@postgrespro.ru", "phone": "+70547782919"}
0005434551478	4AB017	7608 246405	SERGEY KOZLOV	{"email": "kozlov.sergey.1965@postgrespro.ru", "phone": "+70579169814"}
0005434551479	2B894F	9956 644758	TATYANA DANILOVA	{"email": "danilovatatyana.03101976@postgrespro.ru", "phone": "+70334784779"}
0005434551480	2B894F	5356 226436	ALEKSANDR FEDOROV	{"email": "fedorov.a_031978@postgrespro.ru", "phone": "+70465326784"}
0005434551481	E5F93F	4038 313673	OLGA POPOVA	{"phone": "+70311814835"}
0005434551482	74A592	0481 868146	ELENA VLASOVA	{"phone": "+70180925534"}
0005434551483	4E191C	4455 720272	NIKITA SERGEEV	{"phone": "+70369106959"}
0005434551484	AEEE6E	2813 105917	VLADIMIR RODIONOV	{"phone": "+70701036959"}
0005434551485	AEEE6E	2442 835257	NADEZHDA TIMOFEEVA	{"email": "n_timofeeva-18071970@postgrespro.ru", "phone": "+70786119389"}
0005434551486	F3E13E	2202 177599	SERGEY IVANOV	{"email": "ivanovs121963@postgrespro.ru", "phone": "+70405044264"}
0005434551487	CE4188	7500 658828	LIDIYA KUDRYASHOVA	{"phone": "+70410968795"}
0005434551488	CE4188	2374 059409	KIRILL ANTONOV	{"phone": "+70087539612"}
0005434551489	E44952	2012 197715	VIOLETTA SOKOLOVA	{"phone": "+70214257356"}
0005434551490	BF630D	5339 575641	RAMIL MAKAROV	{"phone": "+70647985500"}
0005434551491	BF630D	9025 728178	MARINA NAUMOVA	{"email": "naumova_marina-30071971@postgrespro.ru", "phone": "+70494210388"}
0005434551492	7C9289	2602 711303	ANDREY EGOROV	{"phone": "+70164715146"}
0005434551493	7C9289	9402 419976	IRINA POPOVA	{"email": "i_popova-28081971@postgrespro.ru", "phone": "+70341599291"}
0005434551494	C54F30	0407 538841	ALENA MAKSIMOVA	{"phone": "+70615126782"}
0005434551495	73B3C5	9055 700079	EVDOKIYA ZHURAVLEVA	{"email": "e_zhuravleva.1972@postgrespro.ru", "phone": "+70763838980"}
0005434551496	30A327	0139 208247	ALEKSEY MAKAROV	{"phone": "+70768095534"}
0005434551497	6606C4	1901 077760	DMITRIY BARANOV	{"email": "dmitriy_baranov-061962@postgrespro.ru", "phone": "+70661459952"}
0005434551498	6606C4	4225 637792	NINA KUZNECOVA	{"phone": "+70915393305"}
0005434551499	908F78	8645 429491	VERA ALEKSEEVA	{"phone": "+70478245325"}
0005434551500	A288BD	0175 377759	KONSTANTIN ISAEV	{"email": "isaev.k-1977@postgrespro.ru", "phone": "+70785705463"}
0005434551501	A288BD	7151 010510	NIKOLAY KRASNOV	{"phone": "+70969600905"}
0005434551502	314C0A	0025 078696	RAISA PETROVA	{"email": "petrova.raisa08031968@postgrespro.ru", "phone": "+70501492247"}
0005434551503	BBEC08	1782 845921	MARAT SOROKIN	{"email": "sorokinmarat.09121972@postgrespro.ru", "phone": "+70123198110"}
0005434551504	BBEC08	8762 210612	VERA FROLOVA	{"phone": "+70208041497"}
0005434551505	4DAD57	8662 837138	ALEKSANDR EGOROV	{"email": "a_egorov-1962@postgrespro.ru", "phone": "+70329260933"}
0005434551506	CAF7EF	8377 237993	NIKOLAY IVANOV	{"phone": "+70024529963"}
0005434551507	E4A594	7073 360936	RIMMA ZAKHAROVA	{"phone": "+70529889323"}
0005434551508	E4A594	5659 814674	NIKOLAY KISELEV	{"phone": "+70581618064"}
0005434551509	D7D065	0626 146373	GALINA VASILEVA	{"phone": "+70086625070"}
0005434551510	A06E60	1119 180002	TATYANA NESTEROVA	{"phone": "+70103236896"}
0005434551511	00F20D	1744 372501	ALEKSANDR IVANOV	{"phone": "+70598953925"}
0005434551512	F3CFBF	6671 211194	VASILIY ALEKSANDROV	{"phone": "+70077739802"}
0005434551513	E68D3B	2508 663288	TATYANA ANTONOVA	{"phone": "+70261396345"}
0005434551514	59766A	1147 485755	ALEKSANDR IVANOV	{"phone": "+70638765845"}
0005434551515	59766A	7023 513701	GENNADIY SOKOLOV	{"email": "sokolovg_091971@postgrespro.ru", "phone": "+70528806472"}
0005434551516	50685D	0635 956593	VIKTOR KUDRYASHOV	{"phone": "+70150120447"}
0005434551517	39A21B	4889 988552	ALEKSANDRA ISAEVA	{"email": "aisaeva_1976@postgrespro.ru", "phone": "+70490178154"}
0005434551518	E843B0	3655 207644	ANNA VASILEVA	{"phone": "+70200724982"}
0005434551519	EFDC31	4418 866718	TAMARA GERASIMOVA	{"phone": "+70780586709"}
0005434551520	400B5A	0435 946239	VIKTORIYA KOROLEVA	{"email": "viktoriya.koroleva_22031970@postgrespro.ru", "phone": "+70885758269"}
0005434551521	51C9A2	8733 638357	TATYANA SOKOLOVA	{"phone": "+70453532281"}
0005434551522	51C9A2	6537 353258	DMITRIY GORBUNOV	{"phone": "+70013317559"}
0005434551523	AA4118	7952 293195	ALISA NESTEROVA	{"phone": "+70558732336"}
0005434551524	A80CB1	2482 865103	SEMEN NIKITIN	{"email": "nikitin_s.10011967@postgrespro.ru", "phone": "+70239332409"}
0005434551525	FA75F1	6711 348677	ANDREY FEDOROV	{"phone": "+70167038545"}
0005434551526	FA75F1	2449 333452	DMITRIY BARANOV	{"phone": "+70450651896"}
0005434551527	9AE1AC	7351 557901	ZINAIDA VOLKOVA	{"email": "volkova_z.051975@postgrespro.ru", "phone": "+70988843738"}
0005434551528	9AE1AC	7939 222549	YURIY FOMIN	{"email": "y-fomin-02091971@postgrespro.ru", "phone": "+70130400295"}
0005434551529	D7AEC7	0909 934995	OLGA MOISEEVA	{"phone": "+70198116204"}
0005434551530	38018A	8978 489246	EVGENIY KONOVALOV	{"email": "konovalove1970@postgrespro.ru", "phone": "+70497840210"}
0005434551531	A38ADE	7638 064543	GALINA FROLOVA	{"phone": "+70630290671"}
0005434551532	A38ADE	6423 739954	GALIYA BELYAEVA	{"email": "g_belyaeva-29121958@postgrespro.ru", "phone": "+70488855447"}
0005434551533	185841	4543 058948	MAKSIM PAVLOV	{"email": "maksimpavlov_011959@postgrespro.ru", "phone": "+70336630182"}
0005434551534	29BC3F	9214 585611	SERGEY TIMOFEEV	{"phone": "+70943144969"}
0005434551535	29BC3F	7225 014484	VLADISLAV MOROZOV	{"phone": "+70416707691"}
0005434551713	D57215	0642 089668	LYUDMILA POLYAKOVA	{"phone": "+70328673472"}
0005434551536	439743	2337 348817	ALEKSANDR ANTONOV	{"email": "aleksandrantonov-13021973@postgrespro.ru", "phone": "+70984792554"}
0005434551537	B234C0	2855 922074	NADEZHDA VASILEVA	{"email": "n_vasileva-011977@postgrespro.ru", "phone": "+70251334520"}
0005434551538	B8255C	3237 930168	SERGEY MAKSIMOV	{"email": "sergeymaksimov.121971@postgrespro.ru", "phone": "+70956885537"}
0005434551539	87AA25	9964 200725	VIKTORIYA PAVLOVA	{"email": "pavlova.viktoriya1969@postgrespro.ru", "phone": "+70914633797"}
0005434551540	87AA25	2046 836206	LYUDMILA YAKOVLEVA	{"phone": "+70514959794"}
0005434551541	4A88CB	5122 075151	ALBINA OVCHINNIKOVA	{"email": "albina.ovchinnikova-24081963@postgrespro.ru", "phone": "+70032043804"}
0005434551542	4A88CB	1179 060346	ANDREY MELNIKOV	{"email": "melnikov-a.041967@postgrespro.ru", "phone": "+70845339705"}
0005434551543	3CF49D	8237 034556	ZINAIDA NOVIKOVA	{"phone": "+70521993559"}
0005434551544	23FD79	0061 147692	LILIYA VOLKOVA	{"email": "l.volkova_101974@postgrespro.ru", "phone": "+70453853061"}
0005434551545	8B889E	6203 485042	ANTON KARPOV	{"phone": "+70031660177"}
0005434551546	F772A8	4517 072807	MATVEY SOLOVEV	{"email": "solovev_matvey17121968@postgrespro.ru", "phone": "+70803035927"}
0005434551547	F772A8	5510 346766	VYACHESLAV KULIKOV	{"phone": "+70728821886"}
0005434551548	C53EF8	8735 080120	OKSANA VASILEVA	{"email": "vasilevaoksana-25051972@postgrespro.ru", "phone": "+70544821268"}
0005434551549	C53EF8	5604 834645	DIANA ZAKHAROVA	{"phone": "+70168658283"}
0005434551550	47824E	2946 150254	LEONID SCHERBAKOV	{"phone": "+70283004711"}
0005434551551	D8B25C	3065 776247	IGOR KUZNECOV	{"phone": "+70811714314"}
0005434551552	4D32B6	2664 550883	VLADIMIR YAKOVLEV	{"email": "v_yakovlev_101968@postgrespro.ru", "phone": "+70393079358"}
0005434551553	BC8F33	1832 755070	ALEKSANDR KOROLEV	{"phone": "+70827406510"}
0005434551554	BC8F33	0837 044314	IRINA FOMINA	{"phone": "+70612043816"}
0005434551555	BC8F33	8583 419455	MARIYA KUDRYASHOVA	{"phone": "+70731957182"}
0005434551556	08122D	3325 553471	LYUDMILA MOISEEVA	{"email": "lyudmila_moiseeva_041975@postgrespro.ru", "phone": "+70986324558"}
0005434551557	08122D	1519 000908	OLEG ROMANOV	{"email": "oleg_romanov.091963@postgrespro.ru", "phone": "+70864927331"}
0005434551558	2701DD	2434 295987	PAVEL NIKITIN	{"email": "nikitin-pavel-1970@postgrespro.ru", "phone": "+70962626196"}
0005434551559	40646B	6544 475927	ALEKSANDR STEPANOV	{"phone": "+70240620872"}
0005434551560	40646B	4584 274746	ARTEM MATVEEV	{"email": "artem-matveev-081972@postgrespro.ru", "phone": "+70669937973"}
0005434551561	D3AD5D	7132 921563	SVETLANA SEMENOVA	{"email": "semenova-svetlana-1976@postgrespro.ru", "phone": "+70264407388"}
0005434551562	D3AD5D	1836 892477	PAVEL STEPANOV	{"phone": "+70265342989"}
0005434551563	BBF68B	3067 827505	ELENA VASILEVA	{"phone": "+70111873045"}
0005434551564	879B9B	9069 066356	VLADIMIR DENISOV	{"email": "denisov.vladimir.14011970@postgrespro.ru", "phone": "+70591044866"}
0005434551565	8D6E85	0186 011378	LEONID RODIONOV	{"phone": "+70143999388"}
0005434551566	FA94C9	4617 732386	LIDIYA MATVEEVA	{"phone": "+70949996813"}
0005434551567	4652B3	2062 016249	SERGEY DMITRIEV	{"phone": "+70306412527"}
0005434551568	A9FEE7	7485 900470	DENIS TIKHONOV	{"phone": "+70883966427"}
0005434551569	A9FEE7	4209 497631	DMITRIY ANTONOV	{"phone": "+70035490024"}
0005434551570	3F4173	8496 209135	EDUARD KISELEV	{"email": "kiselev_e.031971@postgrespro.ru", "phone": "+70003807336"}
0005434551571	F4EE47	6408 273805	VALENTINA BELOVA	{"phone": "+70540166314"}
0005434551572	7FE08A	2068 060464	EKATERINA SEMENOVA	{"phone": "+70456781808"}
0005434551573	4FF095	7641 186533	ALEKSANDRA ISAEVA	{"phone": "+70522346897"}
0005434551574	4FF095	9624 796121	NIKOLAY KUZNECOV	{"email": "n-kuznecov_24071965@postgrespro.ru", "phone": "+70151943704"}
0005434551575	0C3569	3290 904169	NATALYA ZHUKOVA	{"phone": "+70772071708"}
0005434551576	0C3569	8123 314473	VALERIY FEDOROV	{"email": "v-fedorov.07081972@postgrespro.ru", "phone": "+70698728648"}
0005434551577	C46896	2630 484880	TATYANA MASLOVA	{"phone": "+70465450742"}
0005434551578	C46896	5943 723104	SERGEY KOROLEV	{"phone": "+70014591484"}
0005434551579	CA7A72	2009 931327	SHAMIL ANDREEV	{"phone": "+70217852787"}
0005434551580	CA7A72	6185 131018	ANDREY KARPOV	{"email": "karpov_andrey21021972@postgrespro.ru", "phone": "+70860563022"}
0005434551581	3475E2	6558 498995	EVGENIY VOROBEV	{"email": "e_vorobev.031980@postgrespro.ru", "phone": "+70807671780"}
0005434551582	DD22EC	7020 453156	ALEKSANDR STEPANOV	{"phone": "+70837636382"}
0005434551583	99D73C	4243 047927	ARSENIY POPOV	{"email": "popov-arseniy.1975@postgrespro.ru", "phone": "+70079988048"}
0005434551584	C5D4F4	3491 473347	SVETLANA ORLOVA	{"email": "orlovasvetlana.25091959@postgrespro.ru", "phone": "+70717777204"}
0005434551585	E5681A	0053 531055	FEDOR KUZNECOV	{"email": "fedorkuznecov.041970@postgrespro.ru", "phone": "+70975024821"}
0005434551586	512F7E	4528 105421	YURIY IVANOV	{"email": "ivanovy-021976@postgrespro.ru", "phone": "+70438349407"}
0005434551587	F73F59	2723 722841	MIKHAIL SEMENOV	{"email": "msemenov07061975@postgrespro.ru", "phone": "+70714280685"}
0005434551588	3DC4A2	4354 479805	NADEZHDA SOKOLOVA	{"email": "nadezhda-sokolova-28121960@postgrespro.ru", "phone": "+70028571157"}
0005434551589	3DC4A2	5792 094851	VITALIY MAKAROV	{"email": "makarov_vitaliy.05111974@postgrespro.ru", "phone": "+70134965076"}
0005434551590	B93BC6	4237 066303	EKATERINA POPOVA	{"phone": "+70277317510"}
0005434551591	20BE72	1691 669183	ALEKSANDR TIMOFEEV	{"email": "timofeev-aleksandr-111966@postgrespro.ru", "phone": "+70177981656"}
0005434551592	8B1DE8	8969 016894	NINA KUZNECOVA	{"phone": "+70004667300"}
0005434551593	8B1DE8	9839 716388	EVGENIYA LOGINOVA	{"email": "loginova.evgeniya_18021967@postgrespro.ru", "phone": "+70681324421"}
0005434551594	F99C27	6201 099062	ELMIRA KOLESNIKOVA	{"email": "kolesnikovaelmira071971@postgrespro.ru", "phone": "+70154750997"}
0005434551885	D0863C	9259 525845	SERGEY SERGEEV	{"phone": "+70201534033"}
0005434551595	F8ADEF	0507 077514	POLINA POPOVA	{"email": "ppopova10051976@postgrespro.ru", "phone": "+70098313586"}
0005434551596	EEA3B3	1530 407139	EKATERINA GRISHINA	{"phone": "+70905847752"}
0005434551597	1E51C3	1779 332902	FARIDA SAVELEVA	{"email": "saveleva.farida.1966@postgrespro.ru", "phone": "+70281096266"}
0005434551598	1E51C3	6993 299614	VLADIMIR STEPANOV	{"phone": "+70876568495"}
0005434551599	D4A488	8119 732948	FANIS FEDOROV	{"phone": "+70369743952"}
0005434551600	12C00B	4001 962987	ALSU ABRAMOVA	{"email": "alsuabramova.1973@postgrespro.ru", "phone": "+70220556600"}
0005434551601	C5EA8A	7907 832388	VLADISLAV IVANOV	{"phone": "+70091441182"}
0005434551602	C5EA8A	5694 287981	ANNA SAVELEVA	{"phone": "+70238561012"}
0005434551603	E1A5FE	2881 262511	KRISTINA KOVALEVA	{"email": "k.kovaleva11021979@postgrespro.ru", "phone": "+70274405137"}
0005434551604	E1A5FE	6579 967794	RAMIL DAVYDOV	{"email": "r.davydov071964@postgrespro.ru", "phone": "+70772838951"}
0005434551605	7CBAC8	8879 286094	ELENA NOVIKOVA	{"email": "enovikova.04041967@postgrespro.ru", "phone": "+70681768464"}
0005434551606	7CBAC8	9207 838114	VYACHESLAV POPOV	{"phone": "+70631099858"}
0005434551607	30E6B4	9739 669576	DMITRIY BARANOV	{"email": "d-baranov26071972@postgrespro.ru", "phone": "+70048493531"}
0005434551608	7E9488	5839 979828	OLGA AFANASEVA	{"email": "afanaseva-olga.1963@postgrespro.ru", "phone": "+70308685687"}
0005434551609	7E9488	3694 841288	VLADIMIR SIDOROV	{"email": "v-sidorov_031971@postgrespro.ru", "phone": "+70867890194"}
0005434551610	A4C207	7735 774641	MARINA TIMOFEEVA	{"email": "timofeeva_marina_1966@postgrespro.ru", "phone": "+70498253185"}
0005434551611	CD14AF	7123 837952	ALISA KUZMINA	{"phone": "+70829539212"}
0005434551612	CD14AF	3347 051559	ZOYA GRISHINA	{"phone": "+70738435788"}
0005434551613	996CCB	1474 400471	VASILIY KULIKOV	{"phone": "+70244934564"}
0005434551614	996CCB	0844 816750	INNA KOVALEVA	{"email": "kovaleva_inna.1976@postgrespro.ru", "phone": "+70109066657"}
0005434551615	996CCB	3720 612311	ANNA EGOROVA	{"email": "egorova-a-08051964@postgrespro.ru", "phone": "+70610211125"}
0005434551616	C7439B	5509 548694	IRINA MIKHAYLOVA	{"phone": "+70467721358"}
0005434551617	6FCB2F	1337 139733	MARINA KOROLEVA	{"phone": "+70695287558"}
0005434551618	6FCB2F	8624 474297	LYUBOV ERMAKOVA	{"email": "ermakova-lyubov1960@postgrespro.ru", "phone": "+70221441777"}
0005434551619	21AA03	2456 490002	MIKHAIL POPOV	{"email": "popov_m.121966@postgrespro.ru", "phone": "+70135473983"}
0005434551620	81729C	4241 807637	VIKTOR GUSEV	{"phone": "+70947268822"}
0005434551621	81729C	9130 102785	TATYANA ORLOVA	{"phone": "+70288152375"}
0005434551622	929134	3497 440719	EDUARD VOLKOV	{"email": "volkov.e011973@postgrespro.ru", "phone": "+70068458592"}
0005434551623	457B85	0977 134489	VYACHESLAV NIKITIN	{"phone": "+70830206825"}
0005434551624	EEC3BB	9449 367064	EVGENIYA VASILEVA	{"email": "evgeniya.vasileva_121983@postgrespro.ru", "phone": "+70640040382"}
0005434551625	51C37B	9874 386982	IGOR IVANOV	{"phone": "+70239195512"}
0005434551626	5FF002	3568 586645	TATYANA KUZMINA	{"email": "tatyana.kuzmina.121977@postgrespro.ru", "phone": "+70588136691"}
0005434551627	4283EB	9127 380165	INNA SOKOLOVA	{"phone": "+70400227819"}
0005434551628	C3B8B8	6863 529057	ANDREY DAVYDOV	{"phone": "+70134832276"}
0005434551629	C3B8B8	3490 545072	VALENTINA BORISOVA	{"email": "v_borisova_1977@postgrespro.ru", "phone": "+70994827615"}
0005434551630	F69B8D	8948 577950	EVGENIY ZAYCEV	{"email": "e-zaycev-1983@postgrespro.ru", "phone": "+70933640737"}
0005434551631	FEA23A	6392 524175	ALFIYA AKIMOVA	{"email": "akimova.a031972@postgrespro.ru", "phone": "+70603973549"}
0005434551632	06AFC7	0344 010475	IGOR BELOV	{"phone": "+70052139434"}
0005434551633	06AFC7	4080 918632	TATYANA MATVEEVA	{"phone": "+70803319636"}
0005434551634	A8944E	5844 324666	KONSTANTIN SOLOVEV	{"phone": "+70673455228"}
0005434551635	CE45AF	6497 214886	MIKHAIL DENISOV	{"email": "mdenisov-02111971@postgrespro.ru", "phone": "+70184922281"}
0005434551636	8A158E	8145 430393	IRINA ORLOVA	{"phone": "+70651707625"}
0005434551637	EC023D	5513 580294	MIKHAIL DENISOV	{"email": "denisovm25101973@postgrespro.ru", "phone": "+70851870977"}
0005434551638	EC023D	4984 018864	ELENA EGOROVA	{"email": "egorova_e-1978@postgrespro.ru", "phone": "+70721473929"}
0005434551639	8F979E	0758 944622	NATALYA ANTONOVA	{"phone": "+70323267629"}
0005434551640	8F979E	2479 069158	SERGEY SMIRNOV	{"email": "ssmirnov_08021973@postgrespro.ru", "phone": "+70727463424"}
0005434551641	75DBF9	8662 470715	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev_1976@postgrespro.ru", "phone": "+70331400052"}
0005434551642	75DBF9	8328 723458	VIKTOR BARANOV	{"email": "baranov-viktor1959@postgrespro.ru", "phone": "+70472289683"}
0005434551643	B12DA5	7306 716812	EVGENIY MIKHAYLOV	{"phone": "+70858843853"}
0005434551644	517914	7907 680346	ELENA YAKOVLEVA	{"email": "yakovleva.elena_07051969@postgrespro.ru", "phone": "+70884442599"}
0005434551645	517914	0196 768553	VARVARA OSIPOVA	{"email": "varvara.osipova-1972@postgrespro.ru", "phone": "+70176818618"}
0005434551646	E3D01F	9700 428825	OLGA VLASOVA	{"email": "vlasova.olga-1972@postgrespro.ru", "phone": "+70476351120"}
0005434551647	420692	4260 148005	VLADIMIR NIKOLAEV	{"phone": "+70129511806"}
0005434551648	0A0BD3	8751 014992	ALEKSEY DMITRIEV	{"email": "dmitriev.aleksey.21031972@postgrespro.ru", "phone": "+70370069741"}
0005434551649	0A0BD3	9637 933056	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr.02101972@postgrespro.ru", "phone": "+70788609344"}
0005434551650	3CD07B	0602 997528	LYUDMILA YUDINA	{"phone": "+70024364050"}
0005434551651	8303DA	0018 310258	OLEG KISELEV	{"phone": "+70654740051"}
0005434551652	946830	0134 624951	EKATERINA ERMAKOVA	{"email": "ekaterina-ermakova-1975@postgrespro.ru", "phone": "+70824255833"}
0005434551653	BC03AD	4416 180072	IGOR TIKHONOV	{"email": "i.tikhonov.15051963@postgrespro.ru", "phone": "+70529139003"}
0005434551886	7B1296	6043 983296	VLADIMIR ANDREEV	{"phone": "+70290791505"}
0005434551654	4BCE53	1204 281036	LYUBOV ROMANOVA	{"email": "lromanova081978@postgrespro.ru", "phone": "+70261792270"}
0005434551655	920439	4028 040896	VALENTINA MIRONOVA	{"email": "valentina-mironova-1966@postgrespro.ru", "phone": "+70592557982"}
0005434551656	B7B58C	0218 349288	NIKOLAY VASILEV	{"phone": "+70229201997"}
0005434551657	B0E1FB	0843 963886	IVAN KUZNECOV	{"email": "kuznecov_i021966@postgrespro.ru", "phone": "+70703616945"}
0005434551658	16B305	4987 171494	ULYANA KOMAROVA	{"phone": "+70634653730"}
0005434551659	7AE93D	7747 031422	LYUBOV SMIRNOVA	{"email": "l_smirnova.16071977@postgrespro.ru", "phone": "+70231893815"}
0005434551660	A8D4D2	9604 163236	ANASTASIYA ABRAMOVA	{"email": "abramovaa-07121977@postgrespro.ru", "phone": "+70861898091"}
0005434551661	C24EF3	1341 971523	LILIYA ANISIMOVA	{"email": "anisimova.l_061973@postgrespro.ru", "phone": "+70368969780"}
0005434551662	F22FBE	8690 841252	VARVARA BORISOVA	{"email": "varvara.borisova.041986@postgrespro.ru", "phone": "+70590189925"}
0005434551663	131E69	7775 627109	MARINA SEMENOVA	{"phone": "+70034738229"}
0005434551664	131E69	7883 461684	ALEKSEY ANDREEV	{"phone": "+70751311118"}
0005434551665	281FC7	6424 493776	VLADIMIR KUDRYASHOV	{"email": "kudryashov.v16121973@postgrespro.ru", "phone": "+70122551765"}
0005434551666	F5A6D6	4557 808008	EVGENIY BELOV	{"email": "ebelov-1972@postgrespro.ru", "phone": "+70882698523"}
0005434551667	F5A6D6	0388 357142	MAKSIM ALEKSEEV	{"phone": "+70839992111"}
0005434551668	F9F58A	6480 731159	OLGA AKIMOVA	{"phone": "+70273838896"}
0005434551669	34D1D8	3461 670873	ELENA KISELEVA	{"email": "elenakiseleva111981@postgrespro.ru", "phone": "+70640316078"}
0005434551670	34D1D8	7657 886590	GENNADIY SOKOLOV	{"phone": "+70503166044"}
0005434551671	C3A95A	8868 823398	NIKOLAY VOROBEV	{"email": "vorobev.n.101957@postgrespro.ru", "phone": "+70790561365"}
0005434551672	74B7B3	3913 428306	VLADIMIR KAZAKOV	{"phone": "+70766674613"}
0005434551673	59E6DB	8423 882822	TATYANA RYABOVA	{"phone": "+70822191522"}
0005434551674	54E1E7	0490 217430	VALERIY PAVLOV	{"email": "valeriypavlov-1968@postgrespro.ru", "phone": "+70243912324"}
0005434551675	54E1E7	7469 629853	ANATOLIY ROMANOV	{"phone": "+70482055292"}
0005434551676	61C782	6244 172009	GALINA FOMINA	{"email": "galina_fomina-1984@postgrespro.ru", "phone": "+70503057228"}
0005434551677	61C782	1741 009223	LYUBOV SEMENOVA	{"phone": "+70168195000"}
0005434551678	310D66	5825 998457	EKATERINA FILATOVA	{"email": "filatovae.26011972@postgrespro.ru", "phone": "+70592976468"}
0005434551679	310D66	6900 581557	VALENTINA AFANASEVA	{"email": "v_afanaseva_1965@postgrespro.ru", "phone": "+70789448704"}
0005434551680	33ED7B	7245 244086	VALENTINA FROLOVA	{"phone": "+70303271267"}
0005434551681	33ED7B	4037 254425	ALEKSANDR OSIPOV	{"phone": "+70780094910"}
0005434551682	2EC4D4	3747 927204	IVAN FEDOROV	{"email": "i-fedorov_27111973@postgrespro.ru", "phone": "+70809309608"}
0005434551683	2EC4D4	9303 661922	VITALIY NAZAROV	{"phone": "+70864599857"}
0005434551684	CBB6DC	7347 818229	VALENTINA BORISOVA	{"email": "borisova_v-22111976@postgrespro.ru", "phone": "+70124756201"}
0005434551685	CBB6DC	7032 003698	DARYA TARASOVA	{"phone": "+70387579672"}
0005434551686	49DE4A	1614 672142	SERGEY ANTONOV	{"phone": "+70971963028"}
0005434551687	7500FA	4892 314405	ANNA ANDREEVA	{"email": "andreeva-a28071970@postgrespro.ru", "phone": "+70763620214"}
0005434551688	174BEA	0997 948988	IRINA MEDVEDEVA	{"phone": "+70532026745"}
0005434551689	80D271	2815 017334	DMITRIY NIKOLAEV	{"email": "nikolaev_dmitriy.20031974@postgrespro.ru", "phone": "+70257598257"}
0005434551690	80D271	2596 978189	PELAGEYA GORBUNOVA	{"email": "gorbunova-p19031979@postgrespro.ru", "phone": "+70528459134"}
0005434551691	A24A9C	3170 598585	VLADIMIR NOVIKOV	{"email": "vladimirnovikov-15011961@postgrespro.ru", "phone": "+70310030846"}
0005434551692	A24A9C	8498 336023	ALEKSEY MAKAROV	{"phone": "+70819800371"}
0005434551693	97390C	6984 660828	OLGA KUZNECOVA	{"email": "okuznecova_1978@postgrespro.ru", "phone": "+70103884826"}
0005434551694	6B3409	7328 400009	ALEKSANDRA VOROBEVA	{"phone": "+70425671646"}
0005434551695	06F4F1	6107 955429	NINA SIDOROVA	{"phone": "+70798143469"}
0005434551696	1A740C	6977 031381	ALEKSANDRA KUZMINA	{"email": "aleksandrakuzmina-01011985@postgrespro.ru", "phone": "+70729626335"}
0005434551697	A79F54	0608 969945	ALISA ZAKHAROVA	{"email": "zakharova_alisa_06011966@postgrespro.ru", "phone": "+70706548429"}
0005434551698	CF12C8	0136 192245	ANDREY MOISEEV	{"email": "moiseev_a16111964@postgrespro.ru", "phone": "+70493060639"}
0005434551699	CF12C8	6544 067456	KSENIYA IVANOVA	{"email": "kivanova-081975@postgrespro.ru", "phone": "+70008799120"}
0005434551700	710973	1290 765712	BORIS ZAKHAROV	{"email": "boris.zakharov.071981@postgrespro.ru", "phone": "+70755949655"}
0005434551701	D553FD	2017 698997	YULIYA AFANASEVA	{"email": "afanaseva.y.1971@postgrespro.ru", "phone": "+70043917618"}
0005434551702	D553FD	6829 346146	VALENTINA BELYAEVA	{"email": "v.belyaeva09021960@postgrespro.ru", "phone": "+70215072791"}
0005434551703	BD92EE	9632 862061	ELENA CHERNOVA	{"email": "chernova_e.1984@postgrespro.ru", "phone": "+70669221342"}
0005434551704	BD92EE	8822 333782	DMITRIY DAVYDOV	{"email": "davydovd.1969@postgrespro.ru", "phone": "+70658450562"}
0005434551705	BD92EE	5245 491080	EVGENIY NIKITIN	{"phone": "+70521967597"}
0005434551706	732F6C	7616 936246	YANA POTAPOVA	{"phone": "+70094738219"}
0005434551707	442200	3292 128411	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov_1973@postgrespro.ru", "phone": "+70406695272"}
0005434551708	218797	6416 093769	LYUDMILA AKIMOVA	{"phone": "+70630374699"}
0005434551709	1FA9FE	2486 477593	VIKTOR BONDARENKO	{"email": "bondarenko.v1972@postgrespro.ru", "phone": "+70966095218"}
0005434551710	14144F	7586 396792	ALEKSANDR FROLOV	{"phone": "+70996031025"}
0005434551711	14144F	3060 945391	EKATERINA POLYAKOVA	{"email": "e-polyakova111981@postgrespro.ru", "phone": "+70332465703"}
0005434551712	14144F	3398 020377	VARVARA ANDREEVA	{"email": "andreeva_v-111969@postgrespro.ru", "phone": "+70278618012"}
0005434551714	0082F8	9154 258167	SNEZHANA FEDOROVA	{"email": "fedorova-snezhana011976@postgrespro.ru", "phone": "+70397912836"}
0005434551715	8F591A	0526 933695	VALERIY IVANOV	{"phone": "+70842337898"}
0005434551716	E17C0C	1288 316430	YULIYA FROLOVA	{"email": "frolova_yuliya30071975@postgrespro.ru", "phone": "+70520290692"}
0005434551717	E17C0C	9217 347899	RAISA RYABOVA	{"phone": "+70830022909"}
0005434551718	E17C0C	5191 629753	ALEKSANDR ZHURAVLEV	{"phone": "+70139912374"}
0005434551719	5F5E97	9189 238732	YULIYA OSIPOVA	{"phone": "+70357674966"}
0005434551720	DF2A84	2704 173067	ELENA ZHUKOVA	{"phone": "+70257080569"}
0005434551721	C30EC1	0371 892683	OKSANA YUDINA	{"email": "yudina.o-091970@postgrespro.ru", "phone": "+70373726144"}
0005434551722	C30EC1	8976 772183	ANNA KONDRATEVA	{"phone": "+70507240462"}
0005434551723	795364	9235 277474	IRINA NIKITINA	{"phone": "+70239095179"}
0005434551724	795364	5724 844864	VERA MOROZOVA	{"phone": "+70324557995"}
0005434551725	9713C1	3862 551978	ILYA BORISOV	{"phone": "+70657037066"}
0005434551726	8487A8	7288 123913	VIKTOR PAVLOV	{"phone": "+70207416408"}
0005434551727	8487A8	3524 258806	ARTUR SOROKIN	{"email": "sorokin_artur-071954@postgrespro.ru", "phone": "+70176426401"}
0005434551728	8487A8	4096 074011	NATALYA PETROVA	{"email": "petrovanatalya.121971@postgrespro.ru", "phone": "+70253071385"}
0005434551729	EF5380	2169 862216	NATALYA CHERNOVA	{"phone": "+70509445108"}
0005434551730	3A699D	0416 736190	OKSANA ANTONOVA	{"email": "antonova.oksana.081970@postgrespro.ru", "phone": "+70635480174"}
0005434551731	9FAD15	1766 684590	VLADIMIR SMIRNOV	{"phone": "+70688341791"}
0005434551732	9FAD15	4084 846154	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_1969@postgrespro.ru", "phone": "+70755942245"}
0005434551733	FE1393	5120 730341	ANASTASIYA EGOROVA	{"phone": "+70125971335"}
0005434551734	06199B	8773 739778	VALENTINA KALININA	{"phone": "+70911714034"}
0005434551735	6CB07B	1894 177937	MARIYA EGOROVA	{"email": "megorova-14101968@postgrespro.ru", "phone": "+70937965376"}
0005434551736	27FFF5	1991 034675	MARIYA ERMAKOVA	{"phone": "+70155179168"}
0005434551737	02B8C8	7780 395924	LIDIYA IVANOVA	{"phone": "+70202519047"}
0005434551738	02B8C8	2015 645687	ALBINA FADEEVA	{"email": "albina_fadeeva22081972@postgrespro.ru", "phone": "+70701171091"}
0005434551739	32E630	7638 695615	ZINAIDA KISELEVA	{"email": "z-kiseleva-1977@postgrespro.ru", "phone": "+70324497241"}
0005434551740	C46C07	5631 679206	NATALYA ILINA	{"email": "natalyailina_1967@postgrespro.ru", "phone": "+70475091491"}
0005434551741	541EAB	7636 364282	SVETLANA GAVRILOVA	{"phone": "+70600206448"}
0005434551742	30EAE9	0082 309014	EVGENIY FROLOV	{"email": "evgeniy-frolov-1980@postgrespro.ru", "phone": "+70910058635"}
0005434551743	EBD573	5818 329726	LYUDMILA KRASNOVA	{"email": "lyudmila-krasnova_1978@postgrespro.ru", "phone": "+70092061534"}
0005434551744	B4B2D8	4997 273565	VALENTINA YUDINA	{"email": "vyudina061978@postgrespro.ru", "phone": "+70485660500"}
0005434551745	A4C17F	6861 288578	KRISTINA KOZLOVA	{"email": "kkozlova081972@postgrespro.ru", "phone": "+70350462751"}
0005434551746	C99AA0	6049 569332	ZHANNA NIKIFOROVA	{"phone": "+70065425640"}
0005434551747	C99AA0	0683 517135	SERGEY MAKAROV	{"email": "makarov_s-18111972@postgrespro.ru", "phone": "+70487918248"}
0005434551748	3EE1A5	8281 043431	SVETLANA ANDREEVA	{"email": "svetlana-andreeva_20091960@postgrespro.ru", "phone": "+70507534037"}
0005434551749	5AAA45	2710 296226	VIKTOR ANTONOV	{"phone": "+70424329499"}
0005434551750	83FDA4	9417 375176	SVETLANA MOISEEVA	{"email": "moiseevas021977@postgrespro.ru", "phone": "+70921351709"}
0005434551914	DCE207	7548 851318	MAKSIM MELNIKOV	{"phone": "+70147740535"}
0005434551751	83FDA4	7538 097695	SERGEY OSIPOV	{"email": "s-osipov-28081979@postgrespro.ru", "phone": "+70195219796"}
0005434551752	83FDA4	5346 944370	YURIY KOROLEV	{"email": "yuriy_korolev_031965@postgrespro.ru", "phone": "+70094242079"}
0005434551753	BD3A32	4010 866666	TATYANA GERASIMOVA	{"email": "gerasimova.t-1963@postgrespro.ru", "phone": "+70847424887"}
0005434551754	0B6FDC	5977 040127	MARIYA SERGEEVA	{"email": "sergeeva-m23041972@postgrespro.ru", "phone": "+70911133843"}
0005434551755	DCA171	6860 911603	ALEKSANDRA NIKOLAEVA	{"phone": "+70006677829"}
0005434551756	DCA171	4155 821660	RAISA PAVLOVA	{"email": "pavlovar-12021979@postgrespro.ru", "phone": "+70336177466"}
0005434551757	2B0394	9183 261117	VALENTINA SERGEEVA	{"phone": "+70440025937"}
0005434551758	832E3A	9686 515924	OLGA VOLKOVA	{"phone": "+70446464790"}
0005434551759	4B72B7	4603 373855	OLESYA IVANOVA	{"phone": "+70638006077"}
0005434551760	4B72B7	2989 130072	ZINAIDA VOROBEVA	{"email": "z-vorobeva-1966@postgrespro.ru", "phone": "+70951103363"}
0005434551761	950CA8	1528 105420	NIKOLAY KAZAKOV	{"phone": "+70642725854"}
0005434551762	7C235C	2809 703797	TATYANA BOGDANOVA	{"phone": "+70409324138"}
0005434551763	CAEFF2	6349 232583	ANDREY KUZMIN	{"email": "a-kuzmin.19021972@postgrespro.ru", "phone": "+70135605592"}
0005434551764	CAEFF2	5118 295172	VASILIY SOROKIN	{"email": "v-sorokin31071977@postgrespro.ru", "phone": "+70278720893"}
0005434551765	21DC63	4389 898933	EVGENIY PETROV	{"email": "petrov_evgeniy.25031977@postgrespro.ru", "phone": "+70266664515"}
0005434551766	544522	8535 857886	ALEKSANDR ISAEV	{"phone": "+70158235558"}
0005434551767	6EBFDB	1069 642705	KLAVDIYA ZAKHAROVA	{"email": "zakharova.klavdiya.091971@postgrespro.ru", "phone": "+70970058764"}
0005434551768	79E0F7	5780 570886	TATYANA POPOVA	{"email": "popova-tatyana061974@postgrespro.ru", "phone": "+70700686646"}
0005434551769	C7B9F7	5371 998011	ALEKSEY PETROV	{"phone": "+70557981746"}
0005434551770	C7B9F7	0578 565553	ANDREY TIKHONOV	{"email": "tikhonov-andrey-26061967@postgrespro.ru", "phone": "+70494945596"}
0005434551771	A61593	4837 762339	SERGEY EGOROV	{"phone": "+70863919247"}
0005434551772	A61593	6103 878714	DANILA DAVYDOV	{"phone": "+70348978995"}
0005434551773	A61593	5511 862799	MARSEL KUZNECOV	{"email": "marsel_kuznecov041971@postgrespro.ru", "phone": "+70046464993"}
0005434551774	FCDFE6	6378 964015	PAVEL SEMENOV	{"email": "semenov.p-061994@postgrespro.ru", "phone": "+70498972579"}
0005434551775	B93498	9697 248918	ANTONINA KOROLEVA	{"phone": "+70774388844"}
0005434551776	2A9C0E	9198 071816	EVA ARKHIPOVA	{"email": "arkhipovaeva-01101958@postgrespro.ru", "phone": "+70059921288"}
0005434551777	2A9C0E	9113 141261	ANNA KUZNECOVA	{"email": "anna.kuznecova-1980@postgrespro.ru", "phone": "+70899688549"}
0005434551778	48E967	2941 048634	MAKSIM DMITRIEV	{"email": "dmitriev_m08091973@postgrespro.ru", "phone": "+70733796011"}
0005434551779	F40C92	0710 157905	NELLI NOVIKOVA	{"phone": "+70208333825"}
0005434551780	F40C92	8452 070450	INESSA POTAPOVA	{"email": "potapovai_19111973@postgrespro.ru", "phone": "+70694199943"}
0005434551781	C112E9	4314 436165	DMITRIY ANDREEV	{"email": "andreevdmitriy-031972@postgrespro.ru", "phone": "+70025131556"}
0005434551782	9EC3DF	1162 930731	VLADIMIR KUZMIN	{"email": "v_kuzmin-081972@postgrespro.ru", "phone": "+70084623090"}
0005434551783	487EF7	3351 757633	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov-02011971@postgrespro.ru", "phone": "+70320208916"}
0005434551784	487EF7	0161 914898	ALEKSANDR PAVLOV	{"phone": "+70314483112"}
0005434551785	5F21FA	8069 020122	ELIZAVETA IVANOVA	{"email": "ivanovaelizaveta-20111965@postgrespro.ru", "phone": "+70920525940"}
0005434551786	8D8733	2994 317228	ANATOLIY SCHERBAKOV	{"email": "scherbakov_anatoliy_1972@postgrespro.ru", "phone": "+70618421699"}
0005434551787	34A642	1975 594084	VLADISLAV SHEVCHENKO	{"phone": "+70780995751"}
0005434551788	4C9E14	3090 540664	EKATERINA STEPANOVA	{"phone": "+70819674407"}
0005434551789	8DDA4F	1014 271399	IRINA DMITRIEVA	{"email": "irina.dmitrieva.23041976@postgrespro.ru", "phone": "+70007794878"}
0005434551790	8DDA4F	1495 407468	LARISA NIKOLAEVA	{"phone": "+70377336907"}
0005434551791	8DDA4F	9110 755034	KLAVDIYA ANDREEVA	{"email": "klavdiya.andreeva01101964@postgrespro.ru", "phone": "+70564919194"}
0005434551792	1ABE59	7921 425746	VALENTINA CHERNOVA	{"email": "chernova.v28011972@postgrespro.ru", "phone": "+70177603644"}
0005434551793	C6988D	2011 097142	ZINAIDA KUZMINA	{"email": "zinaidakuzmina-1970@postgrespro.ru", "phone": "+70187283311"}
0005434551794	C6988D	6270 448343	VERA VASILEVA	{"phone": "+70654689668"}
0005434551795	3A1439	3995 329703	OLEG PAVLOV	{"email": "pavlov_oleg_1971@postgrespro.ru", "phone": "+70902963083"}
0005434551796	729DB9	0902 137101	ELENA KUZNECOVA	{"email": "e.kuznecova28101971@postgrespro.ru", "phone": "+70042065109"}
0005434551797	A879A7	8301 519580	LYUDMILA BELOVA	{"email": "lyudmilabelova1978@postgrespro.ru", "phone": "+70124665904"}
0005434551798	A879A7	2939 648585	ARMEN BARANOV	{"email": "baranov.a.03121967@postgrespro.ru", "phone": "+70550634447"}
0005434551799	40B075	6708 751917	ANNA BARANOVA	{"phone": "+70926563614"}
0005434551800	AA542C	6978 346429	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir09061976@postgrespro.ru", "phone": "+70747042423"}
0005434551801	AE8537	2910 736443	TATYANA SERGEEVA	{"email": "sergeeva-tatyana_111982@postgrespro.ru", "phone": "+70342126811"}
0005434551802	3C99F6	1168 688752	YULIYA KAZAKOVA	{"email": "kazakova_y021971@postgrespro.ru", "phone": "+70991282830"}
0005434551803	070914	7917 372536	SOFYA ZAYCEVA	{"email": "zayceva.s.19021963@postgrespro.ru", "phone": "+70084401212"}
0005434551804	070914	0413 196745	ALEKSEY POPOV	{"phone": "+70076925603"}
0005434551915	878691	8517 617080	ELENA KOMAROVA	{"phone": "+70024790590"}
0005434551805	62B2E4	2535 839996	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr_1976@postgrespro.ru", "phone": "+70408282784"}
0005434551806	BBD2FB	1398 391972	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova1978@postgrespro.ru", "phone": "+70015932073"}
0005434551807	BBD2FB	8735 021088	ANNA KUZMINA	{"email": "kuzminaanna08091985@postgrespro.ru", "phone": "+70647002822"}
0005434551808	BBD2FB	7095 012716	LYUBOV BORISOVA	{"phone": "+70186055779"}
0005434551809	877299	5361 887065	VYACHESLAV KUDRYASHOV	{"phone": "+70174086089"}
0005434551810	36D639	5010 638619	ALEKSEY SOROKIN	{"email": "sorokina_05071973@postgrespro.ru", "phone": "+70766724199"}
0005434551811	36D639	3492 947177	SERGEY SCHERBAKOV	{"email": "scherbakov_s-15091976@postgrespro.ru", "phone": "+70946218943"}
0005434551812	69B443	2847 767448	VASILIY FEDOROV	{"email": "fedorov_v.1973@postgrespro.ru", "phone": "+70260378669"}
0005434551813	BB4254	0087 579595	KIRA VOROBEVA	{"phone": "+70239751684"}
0005434551814	BB4254	2104 661468	KLAVDIYA KUZNECOVA	{"email": "kkuznecova31051967@postgrespro.ru", "phone": "+70048931874"}
0005434551815	3EA830	4583 699576	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail121978@postgrespro.ru", "phone": "+70316333170"}
0005434551816	8846E5	7800 150643	TATYANA MAKAROVA	{"phone": "+70949834723"}
0005434551817	8846E5	5794 250755	SERGEY ILIN	{"email": "silin1974@postgrespro.ru", "phone": "+70466579089"}
0005434551818	DF4FD5	7698 904845	EKATERINA EGOROVA	{"email": "egorova_ekaterina121968@postgrespro.ru", "phone": "+70014905868"}
0005434551819	DF4FD5	7009 263906	VERA ILINA	{"phone": "+70148835980"}
0005434551820	B0C4B8	6781 516303	ANNA NOVIKOVA	{"email": "anna-novikova021974@postgrespro.ru", "phone": "+70254988463"}
0005434551821	FF3A25	4244 240055	EKATERINA KRASNOVA	{"phone": "+70744677841"}
0005434551822	F3DA29	6650 907146	ANDREY STEPANOV	{"phone": "+70548401615"}
0005434551823	DC7CD0	2175 326322	ALEKSANDR KUZMIN	{"phone": "+70854802986"}
0005434551824	798FD8	1874 660201	VLADIMIR VOLKOV	{"email": "v.volkov1972@postgrespro.ru", "phone": "+70235293628"}
0005434551825	798FD8	7322 920320	LIDIYA ANDREEVA	{"email": "landreeva_28061965@postgrespro.ru", "phone": "+70231849210"}
0005434551826	798FD8	4613 207817	ZOYA ANTONOVA	{"phone": "+70678740650"}
0005434551827	DFFE77	5461 772655	LIDIYA MATVEEVA	{"email": "l.matveeva.1980@postgrespro.ru", "phone": "+70580876509"}
0005434551828	31E04F	0788 581919	VLADIMIR IVANOV	{"phone": "+70087984544"}
0005434551949	B7B6C1	6980 860152	LARISA VASILEVA	{"phone": "+70592466654"}
0005434551829	17A7EE	3586 266916	ALEKSANDR BONDARENKO	{"email": "bondarenko_aleksandr.1965@postgrespro.ru", "phone": "+70998306404"}
0005434551830	17A7EE	6835 372707	ALLA MEDVEDEVA	{"email": "medvedeva.a.31121976@postgrespro.ru", "phone": "+70601014654"}
0005434551831	7D97FA	5058 556109	OLGA NIKITINA	{"phone": "+70198338141"}
0005434551832	36409F	1180 018672	ALEKSANDR DENISOV	{"email": "denisovaleksandr.1967@postgrespro.ru", "phone": "+70589590770"}
0005434551833	03F361	1699 563758	VALENTINA DAVYDOVA	{"email": "valentina-davydova_121974@postgrespro.ru", "phone": "+70488831749"}
0005434551834	03F361	8674 097032	DMITRIY POPOV	{"phone": "+70971919716"}
0005434551835	AE0264	8390 810448	SERGEY ZHUKOV	{"email": "zhukovsergey.121977@postgrespro.ru", "phone": "+70322858953"}
0005434551836	DC62C6	2579 094525	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya-mikhaylova.21081976@postgrespro.ru", "phone": "+70189552116"}
0005434551837	1A73F1	2377 724743	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov_091966@postgrespro.ru", "phone": "+70386277027"}
0005434551838	1A73F1	6869 577847	EKATERINA TIMOFEEVA	{"email": "timofeeva_ekaterina-101967@postgrespro.ru", "phone": "+70083637620"}
0005434551839	EDA0BA	8090 462384	ALEKSANDR NIKOLAEV	{"email": "anikolaev.18121976@postgrespro.ru", "phone": "+70649863400"}
0005434551840	7B8EBE	8127 159331	ELIZAVETA ZHURAVLEVA	{"email": "elizavetazhuravleva-30101977@postgrespro.ru", "phone": "+70848564123"}
0005434551841	7B8EBE	2686 786332	ANTON PAVLOV	{"email": "pavlovanton-1992@postgrespro.ru", "phone": "+70739739592"}
0005434551842	778E4A	9730 554557	IRINA NIKOLAEVA	{"phone": "+70894843780"}
0005434551843	00F6A2	0496 427398	LYUBOV MAKAROVA	{"phone": "+70620985313"}
0005434551844	B658C2	0381 386046	VLADISLAV ALEKSEEV	{"email": "vladislavalekseev1958@postgrespro.ru", "phone": "+70514529282"}
0005434551845	5E9424	3290 760461	MARINA BORISOVA	{"email": "marina.borisova-1966@postgrespro.ru", "phone": "+70662230561"}
0005434551846	35F090	0188 728584	ELENA FEDOROVA	{"phone": "+70839255421"}
0005434551847	CB7C7D	5877 869027	VLADIMIR FILIPPOV	{"email": "filippov-vladimir1972@postgrespro.ru", "phone": "+70556334802"}
0005434551848	1535CB	9941 581740	DANIIL ZHUKOV	{"email": "zhukov.d-1970@postgrespro.ru", "phone": "+70944883007"}
0005434551849	1535CB	0393 409362	NIKOLAY ISAEV	{"email": "isaev.n_1983@postgrespro.ru", "phone": "+70432688654"}
0005434551850	1535CB	3386 936384	ANATOLIY VASILEV	{"email": "a_vasilev_021975@postgrespro.ru", "phone": "+70943532977"}
0005434551851	0F4A25	0174 535052	YULIYA SMIRNOVA	{"phone": "+70498205936"}
0005434551852	39FDB4	7150 741464	VLADIMIR IVANOV	{"email": "v-ivanov.051982@postgrespro.ru", "phone": "+70903418710"}
0005434551853	6DF780	3526 125330	ANNA BELOVA	{"email": "anna-belova_111979@postgrespro.ru", "phone": "+70100085347"}
0005434551854	C23DC0	7478 666263	OLEG SCHERBAKOV	{"email": "o-scherbakov_091979@postgrespro.ru", "phone": "+70568964673"}
0005434551855	C23DC0	5528 304848	ZLATA DENISOVA	{"email": "z-denisova-15021970@postgrespro.ru", "phone": "+70951297168"}
0005434551856	1B4500	5886 438988	DENIS KUZMIN	{"email": "d_kuzmin-1970@postgrespro.ru", "phone": "+70698283063"}
0005434551857	B607D4	5741 779786	SERGEY NAZAROV	{"email": "s_nazarov-1970@postgrespro.ru", "phone": "+70228386227"}
0005434551858	B607D4	3224 263556	ALEKSANDR SOKOLOV	{"phone": "+70676532946"}
0005434551859	A92CE1	3652 279819	LYUDMILA DAVYDOVA	{"email": "lyudmila_davydova.1970@postgrespro.ru", "phone": "+70832331714"}
0005434551860	89CB5D	6757 201417	VALENTINA KUZMINA	{"phone": "+70707203142"}
0005434551861	6FE3A2	3533 724456	IVAN TIKHONOV	{"email": "ivantikhonov_1972@postgrespro.ru", "phone": "+70313206188"}
0005434551862	6FE3A2	1269 851418	VLADIMIR NIKOLAEV	{"email": "nikolaevv101974@postgrespro.ru", "phone": "+70379204600"}
0005434551863	F1875C	5872 978207	NADEZHDA ZHUKOVA	{"email": "n.zhukova1959@postgrespro.ru", "phone": "+70627439711"}
0005434551864	7083DD	8518 284551	LYUDMILA POPOVA	{"phone": "+70159383594"}
0005434551865	7083DD	4865 392534	ELENA MIKHAYLOVA	{"phone": "+70106618775"}
0005434551866	1577AB	8059 334932	OLEG IVANOV	{"phone": "+70307986973"}
0005434551867	69431E	7028 271486	ANTONINA ANDREEVA	{"email": "andreeva_a-18101985@postgrespro.ru", "phone": "+70413802864"}
0005434551868	34ADE4	3596 263986	ELENA FOMINA	{"phone": "+70426708539"}
0005434551869	96F01A	1975 872998	VLADISLAV IVANOV	{"email": "vladislav.ivanov.081966@postgrespro.ru", "phone": "+70106595325"}
0005434551870	96F01A	3814 201569	VLADIMIR BELOV	{"email": "belovvladimir-03051972@postgrespro.ru", "phone": "+70851332612"}
0005434551871	7A78EA	7041 250142	VERA LOGINOVA	{"email": "vera.loginova28011967@postgrespro.ru", "phone": "+70054076762"}
0005434551872	CB64CE	2011 948402	OLGA MALYSHEVA	{"phone": "+70566941314"}
0005434551873	DD9105	9376 451042	MARIYA ARKHIPOVA	{"email": "arkhipova-m_17011972@postgrespro.ru", "phone": "+70379768316"}
0005434551874	14B97E	5808 937889	NIKOLAY NIKOLAEV	{"phone": "+70877557083"}
0005434551875	97313D	4823 335950	ELIZAVETA PETROVA	{"email": "petrova-e1960@postgrespro.ru", "phone": "+70276275670"}
0005434551932	635774	8252 889758	YURIY ZAKHAROV	{"phone": "+70365581642"}
0005434551876	97313D	9435 950321	ANASTASIYA VLASOVA	{"email": "anastasiyavlasova22031976@postgrespro.ru", "phone": "+70200159632"}
0005434551877	579F2C	9007 605275	SERGEY SERGEEV	{"phone": "+70603444204"}
0005434551878	191D6C	7221 341093	IVAN NAUMOV	{"email": "naumov_i.031973@postgrespro.ru", "phone": "+70953723901"}
0005434551879	191D6C	3352 535921	SERGEY MELNIKOV	{"phone": "+70978097281"}
0005434551880	D945F8	0411 089437	EKATERINA ALEKSEEVA	{"email": "ekaterina_alekseeva-10111973@postgrespro.ru", "phone": "+70070221138"}
0005434551881	2B3FDA	0315 003578	VALERIYA DANILOVA	{"email": "danilova.valeriya_1985@postgrespro.ru", "phone": "+70660870600"}
0005434551882	2B3FDA	4426 489508	SVETLANA FEDOROVA	{"phone": "+70161253551"}
0005434551883	61BE92	1067 201755	ALISA KUZMINA	{"email": "kuzminaalisa-10051978@postgrespro.ru", "phone": "+70004872041"}
0005434551884	323630	8122 912094	VALERIY ABRAMOV	{"phone": "+70720435399"}
0005434551887	7B1296	7128 327874	FAINA STEPANOVA	{"email": "stepanova_faina-06041985@postgrespro.ru", "phone": "+70517583223"}
0005434551888	097807	6113 703017	ARTEM ALEKSANDROV	{"email": "aaleksandrov.07031980@postgrespro.ru", "phone": "+70018910129"}
0005434551889	6B80E4	2210 658147	ANASTASIYA DMITRIEVA	{"phone": "+70949206079"}
0005434551890	D2DF54	0284 486926	GALINA OSIPOVA	{"email": "g.osipova_1970@postgrespro.ru", "phone": "+70679636667"}
0005434551891	4A2EF3	4419 454417	NINA KOMAROVA	{"phone": "+70176242124"}
0005434551892	4A2EF3	6596 659600	RAISA TITOVA	{"email": "titovar051977@postgrespro.ru", "phone": "+70182178641"}
0005434551893	F7ECD4	1436 592345	DANILA SMIRNOV	{"phone": "+70572835348"}
0005434551894	F7ECD4	0646 373960	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov1973@postgrespro.ru", "phone": "+70317467976"}
0005434551895	987C0B	4044 814234	SVETLANA GAVRILOVA	{"email": "svetlana_gavrilova-071978@postgrespro.ru", "phone": "+70132151389"}
0005434551896	945A97	7566 214547	MAKSIM TARASOV	{"phone": "+70264236127"}
0005434551897	945A97	8735 810434	ANNA KRASNOVA	{"email": "akrasnova.051969@postgrespro.ru", "phone": "+70614384237"}
0005434551898	542AC7	5027 965694	EVGENIY DENISOV	{"phone": "+70449538103"}
0005434551899	988703	8272 488629	NIKOLAY NAZAROV	{"phone": "+70249569140"}
0005434551900	CACF24	8558 422222	KIRILL POPOV	{"email": "popov.kirill_1976@postgrespro.ru", "phone": "+70063291995"}
0005434551901	78DB62	9766 107072	ALENA MOROZOVA	{"email": "morozovaalena.101983@postgrespro.ru", "phone": "+70370376837"}
0005434551902	78DB62	9803 704229	TIMUR STEPANOV	{"phone": "+70841216842"}
0005434551903	8D261C	4281 276210	LILIYA SERGEEVA	{"phone": "+70217705816"}
0005434551904	9AA1AB	8260 940329	NIKOLAY ROMANOV	{"email": "romanov_n_111964@postgrespro.ru", "phone": "+70102769646"}
0005434551905	9AA1AB	0018 402565	LILIYA MAKAROVA	{"email": "makarova.l-15021970@postgrespro.ru", "phone": "+70752371334"}
0005434551906	6C3D65	5730 544923	ALINA ORLOVA	{"email": "orlova.a.1970@postgrespro.ru", "phone": "+70712353417"}
0005434551907	957E2C	5074 194092	VALERIY ANDREEV	{"phone": "+70368280669"}
0005434551908	F61360	0595 306108	SERGEY TIKHONOV	{"email": "sergey_tikhonov.06111981@postgrespro.ru", "phone": "+70071546144"}
0005434551909	F61360	9560 487035	ALENA DANILOVA	{"email": "alena.danilova.111978@postgrespro.ru", "phone": "+70522854915"}
0005434551910	FF48D0	4145 639140	TATYANA ALEKSANDROVA	{"phone": "+70570549275"}
0005434551911	FF48D0	1050 693825	SERGEY ANDREEV	{"phone": "+70379835156"}
0005434551912	FF48D0	5574 563311	TAMARA BORISOVA	{"email": "t_borisova121963@postgrespro.ru", "phone": "+70079751508"}
0005434551913	6834D4	3032 852154	DENIS SCHERBAKOV	{"phone": "+70003919343"}
0005434551916	878691	1268 193898	OLEG GUSEV	{"email": "oleggusev-26121980@postgrespro.ru", "phone": "+70956351000"}
0005434551917	1DA6EB	6860 810209	ARSENIY GUSEV	{"email": "gusev-a-1978@postgrespro.ru", "phone": "+70397718504"}
0005434551918	1DA6EB	7878 117982	VENIAMIN MEDVEDEV	{"phone": "+70999887833"}
0005434551919	3B02C9	1827 913154	PAVEL SEMENOV	{"email": "semenov.pavel.121986@postgrespro.ru", "phone": "+70365638809"}
0005434551920	367DED	2124 120372	NIKITA DMITRIEV	{"phone": "+70406769630"}
0005434551921	D397A0	7047 479458	PETR GRIGOREV	{"email": "pgrigorev.041978@postgrespro.ru", "phone": "+70886138613"}
0005434551922	D7F6F6	0932 142181	NADEZHDA SCHERBAKOVA	{"email": "n_scherbakova.071984@postgrespro.ru", "phone": "+70184911798"}
0005434551923	8D3268	8291 712245	VLADIMIR KISELEV	{"phone": "+70006660021"}
0005434551924	F441BA	9227 824852	VLADISLAV PAVLOV	{"phone": "+70752350302"}
0005434551925	F441BA	7023 239454	ALEKSANDRA GRISHINA	{"phone": "+70867512898"}
0005434551926	42D309	7761 555324	KONSTANTIN ZHUKOV	{"email": "kzhukov-17051977@postgrespro.ru", "phone": "+70721544438"}
0005434551927	D187CE	3854 972775	VIKTOR ZAYCEV	{"phone": "+70226649792"}
0005434551928	E9506E	6582 037718	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr_07051975@postgrespro.ru", "phone": "+70880604531"}
0005434551929	E9506E	9817 540756	OLEG FEDOROV	{"email": "fedorov_o-1957@postgrespro.ru", "phone": "+70588378956"}
0005434551930	12AF9F	5248 746607	VALERIYA DMITRIEVA	{"email": "dmitrieva-valeriya23061969@postgrespro.ru", "phone": "+70089985951"}
0005434551931	FEA235	9739 993346	SVETLANA KUDRYASHOVA	{"email": "kudryashova-svetlana-041978@postgrespro.ru", "phone": "+70012754958"}
0005434551933	635774	1637 101796	NATALYA KISELEVA	{"phone": "+70716879747"}
0005434551934	1500D8	6039 047947	VASILIY ZHUKOV	{"email": "vasiliy-zhukov-21081962@postgrespro.ru", "phone": "+70465944588"}
0005434551935	1500D8	9535 767480	SVETLANA TIMOFEEVA	{"email": "timofeeva.svetlana13011981@postgrespro.ru", "phone": "+70399591264"}
0005434551936	76B72A	1898 026079	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr_041986@postgrespro.ru", "phone": "+70095989839"}
0005434551937	968395	4253 523486	ELENA DMITRIEVA	{"phone": "+70562778639"}
0005434551938	33FF02	8118 355623	SERGEY VOLKOV	{"email": "volkov-s.28021969@postgrespro.ru", "phone": "+70759986776"}
0005434551939	7C617F	6192 319862	ELENA YUDINA	{"phone": "+70043605906"}
0005434551940	7C617F	5494 519143	VYACHESLAV TIKHONOV	{"phone": "+70754920729"}
0005434551941	1B40F5	5763 275909	ARINA FEDOROVA	{"phone": "+70539117588"}
0005434551942	995018	5239 439236	ALLA BARANOVA	{"phone": "+70657131595"}
0005434551943	995018	0423 876010	IRINA VOLKOVA	{"email": "irina.volkova.31081969@postgrespro.ru", "phone": "+70600045651"}
0005434551944	995018	5802 451329	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova-18041972@postgrespro.ru", "phone": "+70248551343"}
0005434551945	598CE4	9732 918220	LYUBOV IVANOVA	{"phone": "+70879525466"}
0005434551946	598CE4	5040 504801	VIKTORIYA ARKHIPOVA	{"email": "viktoriyaarkhipova.1976@postgrespro.ru", "phone": "+70413774712"}
0005434551947	5F580C	8747 294749	ALIYA NAZAROVA	{"email": "anazarova121970@postgrespro.ru", "phone": "+70321386455"}
0005434551948	23DE30	5237 668339	EVGENIYA BELOVA	{"email": "belovaevgeniya.1974@postgrespro.ru", "phone": "+70911240109"}
0005434551950	E4C2B8	4442 709344	LYUBOV ALEKSANDROVA	{"phone": "+70177572516"}
0005434551951	81E9AC	2854 263934	EKATERINA AFANASEVA	{"phone": "+70217097296"}
0005434551952	81E9AC	8362 748294	LYUDMILA SOROKINA	{"phone": "+70051464354"}
0005434551953	B1A27A	0474 878762	SVETLANA FOMINA	{"phone": "+70201643582"}
0005434551954	B1A27A	6982 112996	MARIYA KRASNOVA	{"email": "krasnova-m.101964@postgrespro.ru", "phone": "+70928932966"}
0005434551955	B1A27A	0374 997385	EVGENIYA GAVRILOVA	{"phone": "+70656410766"}
0005434551956	B61B3A	9331 379990	ALEKSANDR ILIN	{"email": "a-ilin31121970@postgrespro.ru", "phone": "+70941543569"}
0005434551957	B61B3A	7439 414306	RUSLAN MOROZOV	{"email": "rmorozov-1972@postgrespro.ru", "phone": "+70417572184"}
0005434551958	DD6289	3155 520733	NIKOLAY BONDARENKO	{"phone": "+70547324011"}
0005434551959	3C751F	1224 663528	DMITRIY ANDREEV	{"phone": "+70905600124"}
0005434551960	3C751F	9539 365342	LYUDMILA MIRONOVA	{"email": "lyudmila-mironova_071967@postgrespro.ru", "phone": "+70035187002"}
0005434551961	AEA954	7226 537740	OLGA YAKOVLEVA	{"phone": "+70896726706"}
0005434551962	74C72D	1876 979229	ANDREY ZHUKOV	{"email": "a-zhukov.051969@postgrespro.ru", "phone": "+70544074727"}
0005434551963	74C72D	7514 351929	IGOR PETROV	{"phone": "+70833408241"}
0005434551964	D718CF	1090 321740	ALEKSEY ZAYCEV	{"phone": "+70216034925"}
0005434551965	D2DADC	8279 526074	EKATERINA MARTYNOVA	{"email": "martynovaekaterina.1972@postgrespro.ru", "phone": "+70149960376"}
0005434551966	F6AAE6	2908 206730	OLGA LEBEDEVA	{"email": "lebedeva-o-07101963@postgrespro.ru", "phone": "+70432849202"}
0005434551967	F6AAE6	5708 834111	MIKHAIL MOISEEV	{"phone": "+70942720691"}
0005434551968	D542C4	0299 588643	ALEKSANDR ISAEV	{"email": "isaev_aleksandr.12041978@postgrespro.ru", "phone": "+70371821714"}
0005434551969	D542C4	6274 022398	ALEKSANDR ANDREEV	{"email": "aleksandrandreev-02111979@postgrespro.ru", "phone": "+70072414446"}
0005434551970	43B747	5228 055465	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov_30111967@postgrespro.ru", "phone": "+70023127557"}
0005434551971	F84D22	2138 127468	YULIYA MARTYNOVA	{"phone": "+70440146633"}
0005434551972	F84D22	4577 631783	ALEKSANDR SIDOROV	{"phone": "+70298291696"}
0005434551973	8F4548	2608 984467	NIKOLAY MAKSIMOV	{"email": "n.maksimov.1976@postgrespro.ru", "phone": "+70284527838"}
0005434551974	8F4548	3272 663129	NINA SOLOVEVA	{"email": "nina_soloveva-121973@postgrespro.ru", "phone": "+70736291950"}
0005434551975	CAD8BC	1976 296859	ILYA NIKOLAEV	{"email": "ilya-nikolaev.1971@postgrespro.ru", "phone": "+70034764734"}
0005434551976	45DB1B	5007 125814	ROMAN MAKAROV	{"email": "makarov-r.121972@postgrespro.ru", "phone": "+70799157685"}
0005434551977	CC58F0	4923 288105	OLGA TITOVA	{"phone": "+70098958776"}
0005434551978	E095B7	3778 890199	ANATOLIY SAVELEV	{"email": "a-savelev22061978@postgrespro.ru", "phone": "+70019601904"}
0005434551979	54C139	3847 863723	KLAVDIYA NAZAROVA	{"phone": "+70844735035"}
0005434551980	F7E5AD	3679 872208	YURIY KRASNOV	{"email": "ykrasnov_09101979@postgrespro.ru", "phone": "+70274352145"}
0005434551981	AC530B	5129 693735	NADEZHDA ZOTOVA	{"email": "zotova-nadezhda-28031971@postgrespro.ru", "phone": "+70662975523"}
0005434551982	AD117E	6117 438758	IGOR MATVEEV	{"phone": "+70075873151"}
0005434551983	26E2ED	1775 303330	DARYA KUZNECOVA	{"email": "kuznecova_d041965@postgrespro.ru", "phone": "+70138077137"}
0005434551984	26E2ED	9613 371113	OLGA ALEKSANDROVA	{"email": "oaleksandrova_1974@postgrespro.ru", "phone": "+70603349168"}
0005434551985	F07ED1	2580 002993	TIMOFEY NAZAROV	{"phone": "+70821784062"}
0005434551986	F07ED1	9210 318275	ZHANNA FADEEVA	{"email": "fadeeva.z.1966@postgrespro.ru", "phone": "+70110291847"}
0005434551987	50F42C	3297 045502	VITALIY SOROKIN	{"email": "sorokinv_121974@postgrespro.ru", "phone": "+70866791744"}
0005434552044	B56E99	0661 096091	ALEKSANDR IVANOV	{"phone": "+70139595536"}
0005434551988	C63F69	8063 338250	ANNA NOVIKOVA	{"email": "anna-novikova_101972@postgrespro.ru", "phone": "+70414318540"}
0005434551989	3DC09C	1620 834107	EKATERINA DAVYDOVA	{"phone": "+70503644242"}
0005434551990	3DC09C	4932 007278	EVGENIY KOZLOV	{"phone": "+70910461033"}
0005434551991	21307B	3931 230619	ELENA SMIRNOVA	{"email": "e-smirnova101969@postgrespro.ru", "phone": "+70678736468"}
0005434551992	7EF04E	2770 116772	ALEKSANDR ZHUKOV	{"phone": "+70170973869"}
0005434551993	6A120D	4568 273473	ANDREY SOLOVEV	{"email": "a.solovev_121974@postgrespro.ru", "phone": "+70266779151"}
0005434551994	0777BF	4251 263537	ELENA NAUMOVA	{"email": "naumova_e_26031982@postgrespro.ru", "phone": "+70497668236"}
0005434551995	294285	1121 088252	ILYA DENISOV	{"phone": "+70634574333"}
0005434551996	294285	2840 950240	ILYA POPOV	{"email": "i_popov.061983@postgrespro.ru", "phone": "+70867724361"}
0005434551997	A5D891	0826 302696	YANA MOISEEVA	{"email": "y.moiseeva1981@postgrespro.ru", "phone": "+70716017302"}
0005434551998	A5D891	3130 513994	IRINA DENISOVA	{"email": "denisovairina_30081971@postgrespro.ru", "phone": "+70225252230"}
0005434551999	A5D891	4202 487541	NATALYA NIKOLAEVA	{"phone": "+70404886687"}
0005434552000	02184A	9790 070971	YURIY FROLOV	{"phone": "+70744488315"}
0005434552001	82CE3B	7620 032664	SERGEY PAVLOV	{"email": "s-pavlov1959@postgrespro.ru", "phone": "+70118489733"}
0005434552002	597FF4	6631 443299	VYACHESLAV BORISOV	{"phone": "+70715095253"}
0005434552003	03AC3C	6279 377817	ANNA KOZLOVA	{"phone": "+70561746223"}
0005434552004	03AC3C	4735 418087	NATALYA BORISOVA	{"phone": "+70988684334"}
0005434552005	A5CD55	5057 523543	VERA ARKHIPOVA	{"email": "arkhipova-v-081964@postgrespro.ru", "phone": "+70549668137"}
0005434552006	4FF07E	0393 267830	ALEKSANDR POPOV	{"phone": "+70944389357"}
0005434552007	6142C1	0107 901001	ANTONINA STEPANOVA	{"email": "stepanova-antonina04101970@postgrespro.ru", "phone": "+70868649309"}
0005434552008	6142C1	2336 655927	ANASTASIYA ISAEVA	{"email": "a.isaeva_031978@postgrespro.ru", "phone": "+70750652730"}
0005434552009	A4ED9A	2787 255631	EVGENIY GERASIMOV	{"phone": "+70806955021"}
0005434552010	E2DDE3	5540 438807	ALINA NAUMOVA	{"email": "naumova-a-01081965@postgrespro.ru", "phone": "+70163681737"}
0005434552011	053C84	6359 217633	ELENA MAKSIMOVA	{"email": "maksimovae.13081967@postgrespro.ru", "phone": "+70315796836"}
0005434552012	9875A2	8298 141025	EKATERINA MOISEEVA	{"phone": "+70466043314"}
0005434552013	9875A2	0666 357928	VALERIY NIKOLAEV	{"phone": "+70778155173"}
0005434552014	4527EA	8996 391362	LIDIYA ZHUKOVA	{"email": "lzhukova31071969@postgrespro.ru", "phone": "+70415888078"}
0005434552015	4527EA	8876 832478	VLADIMIR OSIPOV	{"email": "osipovv071980@postgrespro.ru", "phone": "+70972555588"}
0005434552016	9B1E7E	8909 599579	EVGENIYA GERASIMOVA	{"email": "evgeniya_gerasimova-1956@postgrespro.ru", "phone": "+70696032049"}
0005434552017	9B1E7E	8718 384380	NATALYA NIKIFOROVA	{"email": "nikiforova_natalya.1957@postgrespro.ru", "phone": "+70757037141"}
0005434552018	9B1E7E	1838 514392	MAKSIM ROMANOV	{"phone": "+70512418801"}
0005434552019	51637A	5597 175011	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey051976@postgrespro.ru", "phone": "+70671140211"}
0005434552020	D3F724	2890 787004	FAINA TIKHONOVA	{"phone": "+70870841523"}
0005434552021	665E86	8331 877608	RINAT ZAKHAROV	{"email": "r_zakharov-101963@postgrespro.ru", "phone": "+70906029030"}
0005434552022	665E86	9084 115735	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.18031975@postgrespro.ru", "phone": "+70979602943"}
0005434552023	AC7A1D	7320 683338	ALEKSANDR KISELEV	{"phone": "+70207638117"}
0005434552024	BB6F21	5283 643952	EKATERINA IVANOVA	{"email": "ivanova.e-26031971@postgrespro.ru", "phone": "+70785390635"}
0005434552025	BB6F21	5878 522534	MARIYA SOKOLOVA	{"phone": "+70301958318"}
0005434552026	B5B341	2008 654468	RAISA NESTEROVA	{"phone": "+70309403290"}
0005434552027	B5B341	9328 355795	ALEKSEY BARANOV	{"phone": "+70445147434"}
0005434552028	F7F4DE	9552 842740	ANASTASIYA KRASNOVA	{"email": "krasnova.anastasiya-101967@postgrespro.ru", "phone": "+70439959583"}
0005434552029	C26DB3	5163 419090	ALEKSANDR EGOROV	{"phone": "+70338615859"}
0005434552030	7F7347	4687 871370	LIDIYA MASLOVA	{"email": "l.maslova18111972@postgrespro.ru", "phone": "+70435563396"}
0005434552031	1A7DDD	7414 802487	ELVINA ZAKHAROVA	{"phone": "+70018880711"}
0005434552032	1A7DDD	5994 301620	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr-021977@postgrespro.ru", "phone": "+70995673168"}
0005434552033	87CB03	7608 899592	ALEKSANDRA TIKHONOVA	{"email": "tikhonova_aleksandra.21081968@postgrespro.ru", "phone": "+70470381383"}
0005434552034	CADA79	4183 984137	NATALYA PAVLOVA	{"email": "npavlova-21091968@postgrespro.ru", "phone": "+70387750172"}
0005434552035	36A095	4762 532516	OLGA MAKSIMOVA	{"phone": "+70773415276"}
0005434552036	36A095	4163 905532	NADEZHDA OSIPOVA	{"phone": "+70875883227"}
0005434552037	E5B4B9	9185 041501	SVETLANA ISAEVA	{"email": "isaeva-svetlana-02031979@postgrespro.ru", "phone": "+70229845078"}
0005434552038	2DC022	4934 074030	VLADIMIR MIRONOV	{"phone": "+70913173987"}
0005434552039	2DC022	3354 414899	ALEKSEY STEPANOV	{"phone": "+70148687509"}
0005434552040	2DC022	0821 941582	ELMIRA ERMAKOVA	{"email": "ermakova_elmira-1970@postgrespro.ru", "phone": "+70609280954"}
0005434552041	62C788	1148 408206	KIRILL ANDREEV	{"email": "kirillandreev.1967@postgrespro.ru", "phone": "+70554811196"}
0005434552042	8649B6	3880 403824	VERA FILIPPOVA	{"phone": "+70329037550"}
0005434552043	B56E99	3543 617602	SVETLANA SOROKINA	{"phone": "+70000725902"}
0005434552045	A53132	1186 171551	TATYANA KUZMINA	{"email": "tatyana_kuzmina_21051974@postgrespro.ru", "phone": "+70323340959"}
0005434552046	A53132	6645 018011	TATYANA DMITRIEVA	{"phone": "+70436406119"}
0005434552047	A53132	6396 035112	SVETLANA RODIONOVA	{"phone": "+70611830771"}
0005434552048	B18872	1695 114593	NINA BELOVA	{"phone": "+70439068648"}
0005434552049	930188	5216 985947	VLADIMIR SOROKIN	{"phone": "+70454321319"}
0005434552050	930188	1228 072133	ALEKSANDR BARANOV	{"email": "aleksandrbaranov-081977@postgrespro.ru", "phone": "+70945584019"}
0005434552051	284F24	0666 767513	ANTONINA IVANOVA	{"phone": "+70955261310"}
0005434552052	079549	6849 548698	LEONID KISELEV	{"email": "l_kiselev.1976@postgrespro.ru", "phone": "+70787640910"}
0005434552053	ECB09A	5831 163564	ANNA KULIKOVA	{"phone": "+70078330846"}
0005434552054	4F70DB	1067 600205	NIKOLAY PETROV	{"phone": "+70872174287"}
0005434552055	4F70DB	4293 997489	FATYMA KUZNECOVA	{"phone": "+70757741003"}
0005434552056	243E75	6091 445350	ANNA ERMAKOVA	{"phone": "+70335794241"}
0005434552057	243E75	7514 023679	NINA KRASNOVA	{"email": "n-krasnova_101975@postgrespro.ru", "phone": "+70637830991"}
0005434552058	3CEA2A	6911 642882	VALENTINA RODIONOVA	{"phone": "+70474537204"}
0005434552059	D5C94A	0590 181307	SVETLANA ZAYCEVA	{"email": "s_zayceva-051969@postgrespro.ru", "phone": "+70747526354"}
0005434552060	B91987	6839 654909	VALENTINA POPOVA	{"phone": "+70401470452"}
0005434552061	B91987	3950 657562	VALERIYA MALYSHEVA	{"phone": "+70236741953"}
0005434552062	7C61D5	5180 943339	REGINA ZAYCEVA	{"phone": "+70538816610"}
0005434552063	1EB37E	2258 497859	IVAN ALEKSANDROV	{"email": "ivanaleksandrov06051971@postgrespro.ru", "phone": "+70818258560"}
0005434552064	BC5430	4164 963146	TAMARA KOMAROVA	{"email": "komarova_t081971@postgrespro.ru", "phone": "+70812683277"}
0005434552065	11CEB2	9737 446749	OLGA OSIPOVA	{"phone": "+70960591661"}
0005434552066	11CEB2	4543 391251	LYUBOV KOLESNIKOVA	{"email": "lyubovkolesnikova.071976@postgrespro.ru", "phone": "+70377867451"}
0005434552067	705DED	6517 192902	EKATERINA IVANOVA	{"phone": "+70052568354"}
0005434552068	126F86	0714 045683	RINAT MOROZOV	{"email": "rinat.morozov_13121970@postgrespro.ru", "phone": "+70870817723"}
0005434552069	17D172	5970 463059	NINA AKIMOVA	{"phone": "+70477981108"}
0005434552070	17D172	3437 808309	TATYANA SOLOVEVA	{"phone": "+70200933313"}
0005434552071	18AEA8	4469 455982	ALEKSEY IVANOV	{"email": "a.ivanov-27021962@postgrespro.ru", "phone": "+70235453616"}
0005434552072	54D068	9677 002709	IGOR FEDOTOV	{"phone": "+70763666041"}
0005434552073	931945	5264 798365	VIKTORIYA KULIKOVA	{"phone": "+70064449928"}
0005434552074	931945	1968 562559	ALEKSANDR SOKOLOV	{"phone": "+70884353625"}
0005434552075	7B45DE	2304 134113	ALEKSEY ISAEV	{"email": "a.isaev_17071984@postgrespro.ru", "phone": "+70782931917"}
0005434552076	2F9F42	5986 964332	ANDREY MOROZOV	{"email": "morozov.andrey_071968@postgrespro.ru", "phone": "+70520535234"}
0005434552077	7C3849	5701 752066	NADEZHDA ISAEVA	{"phone": "+70522267469"}
0005434552078	7955B0	1083 528835	ALEKSANDR ALEKSANDROV	{"phone": "+70955110812"}
0005434552079	7955B0	6645 326769	ALEKSANDR NAUMOV	{"email": "a_naumov-091971@postgrespro.ru", "phone": "+70771451276"}
0005434552080	B62218	9744 130820	ALEKSANDR KOROLEV	{"phone": "+70079795687"}
0005434552081	B62218	2927 165891	TATYANA NAUMOVA	{"email": "t_naumova-111963@postgrespro.ru", "phone": "+70507431430"}
0005434552082	FEF512	5561 749734	SERGEY STEPANOV	{"email": "s.stepanov021969@postgrespro.ru", "phone": "+70594225414"}
0005434552083	519D51	8039 897925	ELENA FEDOROVA	{"email": "fedorovaelena_091973@postgrespro.ru", "phone": "+70822196464"}
0005434552084	675BCF	2874 761333	OLEG ALEKSEEV	{"phone": "+70268908025"}
0005434552141	0AC1D1	5321 667337	LYUBOV MOISEEVA	{"phone": "+70332068810"}
0005434552085	020766	0939 847200	KLAVDIYA KOLESNIKOVA	{"email": "klavdiya_kolesnikova_21091970@postgrespro.ru", "phone": "+70202119913"}
0005434552086	020766	4847 206382	ELENA DENISOVA	{"phone": "+70366094266"}
0005434552087	08B58A	4486 788248	ALEKSANDRA AFANASEVA	{"email": "afanaseva.a.051975@postgrespro.ru", "phone": "+70623337728"}
0005434552088	4CD21A	0764 201641	VLADIMIR MEDVEDEV	{"email": "v_medvedev.14091973@postgrespro.ru", "phone": "+70661642496"}
0005434552089	4CD21A	0599 789029	NADEZHDA FROLOVA	{"email": "n.frolova28121978@postgrespro.ru", "phone": "+70340606356"}
0005434552090	001273	9644 013492	MIKHAIL EGOROV	{"email": "mikhail-egorov_26091958@postgrespro.ru", "phone": "+70931071747"}
0005434552091	FDD278	9316 580277	ALEKSEY MAKAROV	{"phone": "+70520632319"}
0005434552092	FDD278	2103 241306	ANNA NESTEROVA	{"email": "a.nesterova1959@postgrespro.ru", "phone": "+70454385747"}
0005434552093	0914DE	9267 115211	VALENTINA IVANOVA	{"phone": "+70537860581"}
0005434552094	3F852E	6848 633918	GENNADIY MELNIKOV	{"email": "g.melnikov061974@postgrespro.ru", "phone": "+70396574859"}
0005434552095	74E770	9539 130458	VADIM ZAKHAROV	{"email": "vadim_zakharov.10021981@postgrespro.ru", "phone": "+70111304348"}
0005434552096	F77F94	2444 001606	EVGENIY NIKITIN	{"phone": "+70452382731"}
0005434552097	404CDE	0719 631133	VALENTINA KUZNECOVA	{"email": "kuznecova.v-081972@postgrespro.ru", "phone": "+70505712325"}
0005434552098	1DAE4C	2808 229801	ELENA FROLOVA	{"phone": "+70617350234"}
0005434552099	1DAE4C	5917 101885	NINA BELOVA	{"email": "belova.n021981@postgrespro.ru", "phone": "+70730568482"}
0005434552100	E46B4E	3384 243177	VALERIY KUZMIN	{"email": "kuzmin.valeriy_011973@postgrespro.ru", "phone": "+70847188237"}
0005434552101	DE9795	3753 689238	VLADIMIR KULIKOV	{"phone": "+70095091468"}
0005434552102	DE9795	6792 165444	LYUDMILA PAVLOVA	{"phone": "+70444377053"}
0005434552103	2EDE35	1128 564136	ALEKSEY GAVRILOV	{"phone": "+70177735663"}
0005434552104	5CCA4A	4321 679739	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir_07041972@postgrespro.ru", "phone": "+70308691132"}
0005434552105	CFFC89	8768 166000	OLEG MAKAROV	{"phone": "+70647009655"}
0005434552106	CFFC89	0528 288407	OKSANA PETROVA	{"phone": "+70304453222"}
0005434552107	6B426D	7079 522253	GALINA ILINA	{"phone": "+70124399203"}
0005434552108	BDB37A	1629 533735	TAMARA IVANOVA	{"email": "tamara.ivanova071959@postgrespro.ru", "phone": "+70121584719"}
0005434552109	843D2A	8503 172266	EVGENIYA MAKSIMOVA	{"phone": "+70892743026"}
0005434552110	4D2D3C	1767 875105	LADA NIKOLAEVA	{"phone": "+70454216045"}
0005434552111	4D2D3C	2498 673394	OLEG ALEKSEEV	{"email": "oalekseev.12091965@postgrespro.ru", "phone": "+70148428767"}
0005434552112	4D2D3C	9453 384561	GULFIYA MIKHAYLOVA	{"email": "g_mikhaylova-16111966@postgrespro.ru", "phone": "+70023172392"}
0005434552113	D93584	2957 494594	IGOR NAZAROV	{"email": "igor-nazarov_12071964@postgrespro.ru", "phone": "+70244607992"}
0005434552114	7BF746	7733 405752	ALEKSEY BELOV	{"phone": "+70467447642"}
0005434552115	6799F3	9788 125787	GALINA NIKITINA	{"email": "g.nikitina_07021962@postgrespro.ru", "phone": "+70630742429"}
0005434552116	3CDD76	4761 906243	LIDIYA BORISOVA	{"phone": "+70500625959"}
0005434552117	AA7B95	4219 218956	NADEZHDA MARTYNOVA	{"email": "martynovanadezhda_101969@postgrespro.ru", "phone": "+70837248476"}
0005434552118	AA7B95	6676 131728	DMITRIY ANTONOV	{"email": "d_antonov091974@postgrespro.ru", "phone": "+70092072135"}
0005434552119	AA7B95	5722 229961	ALEKSANDR VASILEV	{"phone": "+70807688919"}
0005434552120	C22DB5	5523 454727	NATALYA KUZNECOVA	{"phone": "+70036786118"}
0005434552121	BD702A	3391 072646	PAVEL SOKOLOV	{"email": "p-sokolov-071976@postgrespro.ru", "phone": "+70538722203"}
0005434552122	103CD9	4152 480669	OLEG ORLOV	{"email": "oleg_orlov.22111972@postgrespro.ru", "phone": "+70061829333"}
0005434552123	103CD9	9545 479777	ANDREY PETROV	{"phone": "+70829233397"}
0005434552124	CAAA29	7699 568255	KRISTINA GORBUNOVA	{"email": "gorbunova_k-061973@postgrespro.ru", "phone": "+70478670466"}
0005434552125	CAAA29	5686 300522	ELENA IVANOVA	{"phone": "+70418814874"}
0005434552126	7D42A3	0386 682289	KSENIYA PETROVA	{"email": "petrova.kseniya-081952@postgrespro.ru", "phone": "+70254717115"}
0005434552127	DCE278	0226 045492	TATYANA AKIMOVA	{"email": "akimova.t.01051971@postgrespro.ru", "phone": "+70060512684"}
0005434552128	BBE1A1	7424 702846	ELENA MASLOVA	{"phone": "+70759625083"}
0005434552129	D4CF46	5609 114789	DMITRIY VOLKOV	{"phone": "+70949549261"}
0005434552130	D4CF46	8354 226862	NIKOLAY AFANASEV	{"phone": "+70455847527"}
0005434552131	268C30	9985 901681	KIRILL EGOROV	{"email": "k.egorov051982@postgrespro.ru", "phone": "+70680069159"}
0005434552132	268C30	9315 104370	ALEKSANDR MELNIKOV	{"phone": "+70511683253"}
0005434552133	3595AE	7256 169389	ELIZAVETA SOROKINA	{"phone": "+70361501310"}
0005434552134	1802B9	3198 535884	MIKHAIL SEMENOV	{"phone": "+70350986713"}
0005434552135	1802B9	9989 989014	PAVEL PETROV	{"email": "petrov.p-24071965@postgrespro.ru", "phone": "+70982151435"}
0005434552136	A5CA69	3086 822158	YANA LUKYANOVA	{"phone": "+70088294584"}
0005434552137	84E8C5	0877 057191	YULIYA KUZMINA	{"phone": "+70242035108"}
0005434552138	24C4BF	9657 860044	ALEKSANDR TIMOFEEV	{"phone": "+70072828321"}
0005434552139	2C1579	2347 429244	NINEL KAZAKOVA	{"email": "ninel.kazakova07011960@postgrespro.ru", "phone": "+70153091469"}
0005434552140	2C1579	1756 170966	NINA LAZAREVA	{"phone": "+70131721660"}
0005434552142	0AC1D1	7156 093611	ELENA SOROKINA	{"phone": "+70056800192"}
0005434552143	9066DF	5011 552778	LILIYA ABRAMOVA	{"email": "l.abramova-1980@postgrespro.ru", "phone": "+70302978970"}
0005434552144	CFECEB	5013 746398	VIKTOR ILIN	{"email": "viktor_ilin.20011980@postgrespro.ru", "phone": "+70490341879"}
0005434552145	CFECEB	2679 912522	IVAN VOLKOV	{"phone": "+70159157496"}
0005434552146	D63D04	8437 097706	ELENA AFANASEVA	{"email": "afanaseva-e-17011974@postgrespro.ru", "phone": "+70775961896"}
0005434552147	12636D	0277 831294	ARTEM FEDOROV	{"phone": "+70110940392"}
0005434552148	12636D	3485 769397	ALEKSANDR SOROKIN	{"phone": "+70675530649"}
0005434552149	81C38F	5598 640107	REGINA MASLOVA	{"phone": "+70114673510"}
0005434552150	81C38F	2245 219698	ELENA MEDVEDEVA	{"phone": "+70121398256"}
0005434552151	E33FDF	7576 334489	GALINA MOISEEVA	{"email": "moiseeva_g-091967@postgrespro.ru", "phone": "+70982893043"}
0005434552152	055926	8803 529909	ANZHELIKA NOVIKOVA	{"email": "anzhelikanovikova.16021975@postgrespro.ru", "phone": "+70248425994"}
0005434552153	697363	0146 080117	IRINA FROLOVA	{"phone": "+70326417618"}
0005434552154	9874E1	0347 968934	KRISTINA IVANOVA	{"email": "k.ivanova_20101970@postgrespro.ru", "phone": "+70342053690"}
0005434552155	9874E1	3119 229625	EKATERINA SERGEEVA	{"email": "sergeevae_121974@postgrespro.ru", "phone": "+70506142015"}
0005434552156	5FBAE8	7178 011077	NATALYA ZAKHAROVA	{"phone": "+70162563666"}
0005434552157	5FBAE8	9226 969438	SERGEY ANTONOV	{"email": "antonovsergey_17081974@postgrespro.ru", "phone": "+70354652100"}
0005434552158	D1AFBA	3379 462742	KLAVDIYA BELOVA	{"email": "k_belova.13121972@postgrespro.ru", "phone": "+70267329972"}
0005434552159	835C2F	4980 998334	ALEKSANDR TIMOFEEV	{"phone": "+70072460630"}
0005434552160	D44DEE	2612 463227	RUSHANIYA DENISOVA	{"email": "rushaniya.denisova.101975@postgrespro.ru", "phone": "+70046671002"}
0005434552161	D44DEE	4298 113379	SERGEY GERASIMOV	{"phone": "+70459030436"}
0005434552162	8CA2D0	3380 376994	TATYANA MARTYNOVA	{"phone": "+70252359911"}
0005434552163	24628F	6176 232764	KONSTANTIN PETROV	{"email": "k.petrov.1961@postgrespro.ru", "phone": "+70709396725"}
0005434552164	19D393	4401 579786	OLGA DAVYDOVA	{"email": "davydovao071965@postgrespro.ru", "phone": "+70399121095"}
0005434552165	8C024C	7648 959864	SERGEY ZAYCEV	{"phone": "+70884681448"}
0005434552166	A0ED52	1948 423402	ARTEM KUZNECOV	{"email": "kuznecov_artem.1973@postgrespro.ru", "phone": "+70942088004"}
0005434552167	A0ED52	6353 817653	ELENA KOZLOVA	{"email": "elena_kozlova.07091973@postgrespro.ru", "phone": "+70288509245"}
0005434552168	7DB299	5150 413347	ALEKSANDR KRASNOV	{"email": "aleksandrkrasnov_1969@postgrespro.ru", "phone": "+70219115986"}
0005434552169	7DB299	1485 034005	ILYA MAKSIMOV	{"phone": "+70394818459"}
0005434552170	18B85F	8234 429454	ANDREY ZAYCEV	{"email": "zaycev.a071973@postgrespro.ru", "phone": "+70536283489"}
0005434552171	299080	4540 990090	ARSENIY SCHERBAKOV	{"email": "scherbakova_111956@postgrespro.ru", "phone": "+70377793600"}
0005434552172	1D907B	6019 600936	INNA BOGDANOVA	{"phone": "+70009063607"}
0005434552173	1D907B	2692 771473	MIKHAIL PETROV	{"email": "m.petrov1978@postgrespro.ru", "phone": "+70994996690"}
0005434552174	AA442F	7756 620373	DMITRIY SEMENOV	{"email": "dmitriy-semenov011962@postgrespro.ru", "phone": "+70717730614"}
0005434552175	53818D	1996 232032	SERGEY YAKOVLEV	{"email": "sergey_yakovlev.1970@postgrespro.ru", "phone": "+70270985097"}
0005434552176	8A4423	4865 483223	ALEKSEY VOLKOV	{"email": "volkov-aleksey121976@postgrespro.ru", "phone": "+70704218560"}
0005434552177	9AFE1E	3247 708553	VIKTORIYA BELYAEVA	{"email": "belyaevav_061966@postgrespro.ru", "phone": "+70354089494"}
0005434552178	E80257	9325 963198	MARINA ILINA	{"email": "ilina_marina_1976@postgrespro.ru", "phone": "+70928200761"}
0005434552179	D74331	5365 929422	SERGEY ZHURAVLEV	{"phone": "+70601940640"}
0005434552180	D74331	3530 187615	ANATOLIY MARTYNOV	{"phone": "+70739074997"}
0005434552181	D74331	0499 151003	SERGEY POPOV	{"email": "popov-sergey_051972@postgrespro.ru", "phone": "+70450230587"}
0005434552182	49ED58	9242 384994	LYUDMILA NAZAROVA	{"phone": "+70381714232"}
0005434552183	89CA3F	4310 107445	VERA MATVEEVA	{"email": "vera_matveeva021963@postgrespro.ru", "phone": "+70314699925"}
0005434552184	5B1FE9	0902 839388	ANASTASIYA FILIPPOVA	{"phone": "+70640714137"}
0005434552185	457BD8	7361 864262	EVGENIY FEDOROV	{"phone": "+70374830939"}
0005434552186	457BD8	2153 560346	MARIYA NIKOLAEVA	{"email": "nikolaeva_mariya_031978@postgrespro.ru", "phone": "+70849225796"}
0005434552187	457BD8	0398 542624	DARYA NESTEROVA	{"email": "nesterova-darya-061981@postgrespro.ru", "phone": "+70769939672"}
0005434552188	7D01F2	1684 428974	VLADISLAV VLASOV	{"email": "vladislav-vlasov_24111976@postgrespro.ru", "phone": "+70854789570"}
0005434552189	965124	6188 783636	SERGEY ALEKSANDROV	{"phone": "+70748705362"}
0005434552190	5F604F	1999 869935	VLADIMIR STEPANOV	{"email": "stepanov.v_15121963@postgrespro.ru", "phone": "+70950685261"}
0005434552191	22CB77	1428 235747	IVAN ZAKHAROV	{"email": "zakharov-ivan.1975@postgrespro.ru", "phone": "+70480881321"}
0005434552192	D41798	2418 022682	ALLA PETROVA	{"email": "alla-petrova_1964@postgrespro.ru", "phone": "+70303395243"}
0005434552193	D41798	8677 568385	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr-23071976@postgrespro.ru", "phone": "+70738704288"}
0005434552194	31E175	9806 343102	IGOR KUZNECOV	{"email": "kuznecov.igor.19081968@postgrespro.ru", "phone": "+70285559142"}
0005434552195	7B1C79	7416 158703	SVETLANA VASILEVA	{"email": "svetlana.vasileva_12021971@postgrespro.ru", "phone": "+70294491024"}
0005434552196	7B1C79	3469 726608	DMITRIY EGOROV	{"email": "egorov.dmitriy-1963@postgrespro.ru", "phone": "+70749042759"}
0005434552197	7FF9FE	8601 795162	EKATERINA TIKHONOVA	{"email": "tikhonova-e_1970@postgrespro.ru", "phone": "+70057854122"}
0005434552198	FFB93B	2422 167865	EKATERINA YAKOVLEVA	{"phone": "+70928555691"}
0005434552199	FFB93B	1729 090823	IGOR SMIRNOV	{"email": "smirnovi_041972@postgrespro.ru", "phone": "+70675077958"}
0005434552200	0DFDC1	5041 951068	VLADIMIR ANDREEV	{"phone": "+70934837892"}
0005434552201	F212CF	2876 108008	SVETLANA POTAPOVA	{"phone": "+70012176976"}
0005434552202	F212CF	4289 427416	POLINA MAKAROVA	{"email": "polinamakarova.1980@postgrespro.ru", "phone": "+70669012208"}
0005434552203	2F06AD	6619 439002	IVAN AFANASEV	{"email": "ivan_afanasev_12051972@postgrespro.ru", "phone": "+70108057747"}
0005434552204	283552	3599 939720	NIKOLAY BELOV	{"phone": "+70513089607"}
0005434552205	283552	7162 030729	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy-21031955@postgrespro.ru", "phone": "+70803027019"}
0005434552206	FD9A7E	9312 302583	SERGEY GORBUNOV	{"email": "gorbunov_sergey011973@postgrespro.ru", "phone": "+70844868629"}
0005434552207	FD9A7E	6949 882350	TAISIYA STEPANOVA	{"email": "t.stepanova.041961@postgrespro.ru", "phone": "+70478045464"}
0005434552208	77CFAF	5371 373312	IVAN GRIGOREV	{"phone": "+70373501103"}
0005434552209	76207F	4108 366465	SERGEY NOVIKOV	{"email": "s_novikov101972@postgrespro.ru", "phone": "+70196511468"}
0005434552210	F27BFF	4052 366484	OKSANA KOMAROVA	{"email": "oksana.komarova_1979@postgrespro.ru", "phone": "+70473702579"}
0005434552211	F27BFF	8855 388532	VERA ZHURAVLEVA	{"email": "vera.zhuravleva-04071978@postgrespro.ru", "phone": "+70974875980"}
0005434552212	59CB6D	6446 810883	ELENA ISAEVA	{"email": "e_isaeva_121982@postgrespro.ru", "phone": "+70403556281"}
0005434552213	6BA2D8	0865 124423	MARFA SOKOLOVA	{"email": "msokolova.11091970@postgrespro.ru", "phone": "+70239836005"}
0005434552214	F433A0	2982 876914	MIKHAIL KUZNECOV	{"email": "kuznecov.m.23031969@postgrespro.ru", "phone": "+70238658250"}
0005434552215	AEF1B6	1229 426112	NATALYA IVANOVA	{"phone": "+70058717373"}
0005434552216	D64C3C	7911 458992	NATALYA ABRAMOVA	{"phone": "+70517486280"}
0005434552217	D64C3C	2163 326836	VLADISLAV BELOV	{"email": "belov.v051971@postgrespro.ru", "phone": "+70260521068"}
0005434552218	D64C3C	6754 509295	KONSTANTIN KOROLEV	{"email": "korolev-k-05021969@postgrespro.ru", "phone": "+70764700757"}
0005434552219	13AFF4	2586 806845	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey11061976@postgrespro.ru", "phone": "+70569294911"}
0005434552220	1AEA22	5935 267555	TATYANA FILATOVA	{"phone": "+70597082754"}
0005434552221	CE2EE9	9632 572264	VLADIMIR MAKSIMOV	{"phone": "+70050250338"}
0005434552222	0FD62B	7779 453309	PETR KUZNECOV	{"email": "kuznecov-p.20061977@postgrespro.ru", "phone": "+70578096582"}
0005434552223	B1897E	1978 012210	GALINA KOZLOVA	{"phone": "+70304730116"}
0005434552224	B1897E	7811 676912	NINA MIKHAYLOVA	{"phone": "+70003500575"}
0005434552225	5CF412	1343 131352	EKATERINA BORISOVA	{"phone": "+70230100669"}
0005434552226	78CFD4	2471 468211	MARIYA VOLKOVA	{"email": "volkova-m_22061977@postgrespro.ru", "phone": "+70279043125"}
0005434552227	78CFD4	7006 582220	ANATOLIY NAZAROV	{"email": "anazarov_031983@postgrespro.ru", "phone": "+70261346860"}
0005434552228	E6DD1D	5556 121109	ARINA SERGEEVA	{"email": "arina-sergeeva.22111980@postgrespro.ru", "phone": "+70873426617"}
0005434552229	E6DD1D	6219 303607	TATYANA MIRONOVA	{"email": "mironova.t_031977@postgrespro.ru", "phone": "+70602192355"}
0005434552230	126315	9276 504490	IRINA ZAYCEVA	{"email": "zayceva-i_1977@postgrespro.ru", "phone": "+70945314132"}
0005434552231	02AD21	8646 623975	VLADIMIR STEPANOV	{"email": "stepanovvladimir_011980@postgrespro.ru", "phone": "+70004009840"}
0005434552232	80A131	0266 827737	TATYANA MIRONOVA	{"email": "mironova.t011966@postgrespro.ru", "phone": "+70909047930"}
0005434552233	197056	7906 280631	OLEG TARASOV	{"email": "tarasov.o_20081975@postgrespro.ru", "phone": "+70413359258"}
0005434552234	197056	4266 586336	TATYANA NAZAROVA	{"phone": "+70558647050"}
0005434552235	EB7FDC	8031 104889	ANTONINA LEBEDEVA	{"email": "alebedeva_24071968@postgrespro.ru", "phone": "+70330410377"}
0005434552236	D6E49A	9522 039523	VIKTOR TARASOV	{"email": "tarasov.v_10061964@postgrespro.ru", "phone": "+70971677043"}
0005434552237	9EABED	9994 465755	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana_05071962@postgrespro.ru", "phone": "+70662825910"}
0005434552238	FFA222	4419 459742	NINA ISAEVA	{"email": "nisaeva-1965@postgrespro.ru", "phone": "+70504330814"}
0005434552239	93AF25	4916 529180	ALEKSEY KISELEV	{"email": "aleksey-kiselev_11121977@postgrespro.ru", "phone": "+70523710430"}
0005434552240	93AF25	2259 861072	FARIT SEMENOV	{"email": "f_semenov1976@postgrespro.ru", "phone": "+70384612855"}
0005434552241	93AF25	4476 528106	ALEKSANDRA CHERNOVA	{"email": "chernova-a23051975@postgrespro.ru", "phone": "+70621066513"}
0005434552242	D3EB8F	9374 778437	VALENTINA OVCHINNIKOVA	{"phone": "+70749906208"}
0005434552243	507270	2293 898504	SVETLANA KUZNECOVA	{"phone": "+70328056777"}
0005434552244	507270	3138 737571	ALEKSANDR ROMANOV	{"phone": "+70476778531"}
0005434552245	ACA83C	8859 925812	IVAN MARTYNOV	{"email": "martynov.ivan-041963@postgrespro.ru", "phone": "+70545820646"}
0005434552246	4A6527	1066 087423	VALENTINA FEDOROVA	{"email": "fedorova.v_081974@postgrespro.ru", "phone": "+70403349923"}
0005434552247	8B9753	0916 945374	VLADIMIR ISAEV	{"phone": "+70216303700"}
0005434552248	CB5105	2986 090074	NATALYA NOVIKOVA	{"phone": "+70611869220"}
0005434552249	8EACAA	7442 555639	ALEKSANDR PETROV	{"phone": "+70355750916"}
0005434552250	CEBFC2	3559 255726	ANNA TIKHONOVA	{"email": "tikhonova-anna29111974@postgrespro.ru", "phone": "+70676271815"}
0005434552251	CEBFC2	6293 534239	NATALYA SOROKINA	{"email": "sorokina-natalya071970@postgrespro.ru", "phone": "+70940802765"}
0005434552252	E8821B	7866 399414	ALEKSANDR KOROLEV	{"phone": "+70046107916"}
0005434552253	E8821B	1649 410348	MAKSIM SOROKIN	{"phone": "+70962260049"}
0005434552254	2358EF	1514 217553	RUSLAN POPOV	{"email": "popovr.071974@postgrespro.ru", "phone": "+70776955019"}
0005434552255	2358EF	7678 933415	TATYANA TIKHONOVA	{"phone": "+70435939536"}
0005434552256	2358EF	2429 216405	RASHID VASILEV	{"email": "rashid.vasilev_05011969@postgrespro.ru", "phone": "+70321356766"}
0005434552257	F70F97	7235 248158	ANZHELA TROFIMOVA	{"email": "anzhelatrofimova_061977@postgrespro.ru", "phone": "+70951594498"}
0005434552258	B7733A	8069 303160	ANDREY MIKHAYLOV	{"phone": "+70058102081"}
0005434552259	B7733A	0270 973009	VYACHESLAV KARPOV	{"phone": "+70813108656"}
0005434552260	A89137	0182 921012	PAVEL YAKOVLEV	{"phone": "+70868458293"}
0005434552261	A89137	2504 157114	DMITRIY MELNIKOV	{"email": "dmitriy_melnikov.03111972@postgrespro.ru", "phone": "+70846363062"}
0005434552262	ECA7C5	1828 681500	ALEKSANDR MARTYNOV	{"email": "a-martynov-111979@postgrespro.ru", "phone": "+70725328622"}
0005434552263	ECA7C5	7155 420584	ALEKSANDR ALEKSANDROV	{"email": "aleksandr_aleksandrov101976@postgrespro.ru", "phone": "+70177679163"}
0005434552264	76AF2B	6685 883450	ANDREY VLASOV	{"email": "andrey.vlasov121974@postgrespro.ru", "phone": "+70702903895"}
0005434552265	DAA266	1383 371332	ALEKSEY DAVYDOV	{"email": "alekseydavydov-14111970@postgrespro.ru", "phone": "+70658605218"}
0005434552266	DAA266	2042 929334	TATYANA POPOVA	{"phone": "+70266673560"}
0005434552267	FB508B	9974 744083	SVETLANA DENISOVA	{"phone": "+70166932051"}
0005434552268	FB508B	5665 290841	EKATERINA VOLKOVA	{"email": "volkova_e-091968@postgrespro.ru", "phone": "+70525694932"}
0005434552269	3236BE	2458 807726	EKATERINA ZAKHAROVA	{"email": "e_zakharova-1968@postgrespro.ru", "phone": "+70766719487"}
0005434552270	D76B51	2335 456943	SVETLANA STEPANOVA	{"email": "stepanova_s_1972@postgrespro.ru", "phone": "+70892167584"}
0005434552271	D76B51	0963 614208	SERGEY YAKOVLEV	{"phone": "+70366055039"}
0005434552272	E88194	3547 226939	ANNA LAZAREVA	{"phone": "+70109785065"}
0005434552273	54F78D	1104 077239	EVGENIY CHERNOV	{"email": "chernov_e_1972@postgrespro.ru", "phone": "+70141772242"}
0005434552274	A37D61	4679 574476	YANA KOROLEVA	{"phone": "+70592952706"}
0005434552275	65BD80	5258 432692	SERGEY VLASOV	{"phone": "+70923865805"}
0005434552276	3E009D	6280 758119	SERGEY KARPOV	{"email": "s-karpov10031982@postgrespro.ru", "phone": "+70169028023"}
0005434552277	3E009D	9352 369497	DMITRIY ZHURAVLEV	{"email": "dmitriyzhuravlev.061964@postgrespro.ru", "phone": "+70233068497"}
0005434552278	76681E	1055 715169	ELENA BARANOVA	{"phone": "+70080607732"}
0005434552279	527634	7030 054568	ANATOLIY GUSEV	{"email": "a.gusev_101963@postgrespro.ru", "phone": "+70063808005"}
0005434552280	527634	3567 923984	NINA FILIPPOVA	{"phone": "+70724764451"}
0005434552281	EAD929	1221 868758	OKSANA FROLOVA	{"email": "frolova-o-27071976@postgrespro.ru", "phone": "+70598783870"}
0005434552282	059149	6154 585896	TATYANA KULIKOVA	{"phone": "+70245063138"}
0005434552283	ADB986	0822 990104	RUFINA ZAKHAROVA	{"email": "zakharovarufina.071968@postgrespro.ru", "phone": "+70262838770"}
0005434552284	C9819F	1168 635859	TATYANA VASILEVA	{"phone": "+70123859469"}
0005434552285	C9819F	5017 331457	EKATERINA SOLOVEVA	{"phone": "+70043472346"}
0005434552286	13C61C	2736 184359	MARIYA KUZNECOVA	{"email": "kuznecovam.091963@postgrespro.ru", "phone": "+70292193651"}
0005434552287	5DDB78	3029 935128	ALEKSEY EGOROV	{"email": "egorovaleksey111978@postgrespro.ru", "phone": "+70697739032"}
0005434552288	5DDB78	4451 804230	VALENTIN ROMANOV	{"email": "romanov_valentin_12061963@postgrespro.ru", "phone": "+70304498237"}
0005434552289	5DDB78	1767 414498	ROZALIYA MOROZOVA	{"email": "r.morozova1973@postgrespro.ru", "phone": "+70266601900"}
0005434552290	378048	9486 710859	ALEKSANDR SOROKIN	{"phone": "+70262239469"}
0005434552291	382902	9693 745205	VALENTINA KOZLOVA	{"email": "v-kozlova_011974@postgrespro.ru", "phone": "+70334084971"}
0005434552292	382902	6627 086407	IRINA KAZAKOVA	{"phone": "+70457071753"}
0005434552293	3F7D52	2314 750611	EKATERINA DAVYDOVA	{"phone": "+70604776424"}
0005434552294	DA9DC6	6789 970041	YULIYA KRASNOVA	{"email": "y.krasnova121968@postgrespro.ru", "phone": "+70366696369"}
0005434552295	435BD1	3388 542849	ANDREY FOMIN	{"phone": "+70343064643"}
0005434552296	68EADC	0044 109963	ZHANNA PETROVA	{"phone": "+70848098143"}
0005434552297	CC621F	9686 597869	EGOR NAZAROV	{"phone": "+70082651403"}
0005434552298	CC621F	9607 238084	EVGENIYA KAZAKOVA	{"email": "evgeniya-kazakova.101969@postgrespro.ru", "phone": "+70425238720"}
0005434552299	72C757	5669 411591	YULIYA ILINA	{"phone": "+70962424972"}
0005434552300	72C757	6142 567721	VLADIMIR ALEKSEEV	{"email": "alekseev-vladimir.1973@postgrespro.ru", "phone": "+70457385158"}
0005434552301	52654C	9948 381107	EVGENIY ROMANOV	{"phone": "+70051203628"}
0005434552302	52654C	3244 351366	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev_031976@postgrespro.ru", "phone": "+70425349063"}
0005434552303	4062E9	0590 026370	VLADIMIR DENISOV	{"phone": "+70218655738"}
0005434552304	B1FEEE	7675 181153	DMITRIY BELOV	{"email": "dbelov.101976@postgrespro.ru", "phone": "+70490124313"}
0005434552305	154F09	0133 151448	ANDREY MOROZOV	{"phone": "+70352539340"}
0005434552306	9443D2	4730 836986	VIKTOR DMITRIEV	{"email": "v.dmitriev.111967@postgrespro.ru", "phone": "+70291539324"}
0005434552307	B69D1D	8348 948586	VERONIKA SOLOVEVA	{"phone": "+70238384774"}
0005434552308	DADF52	2782 079895	SVETLANA IVANOVA	{"email": "ivanova_svetlana.011973@postgrespro.ru", "phone": "+70921028501"}
0005434552309	DADF52	1523 855762	NADEZHDA OVCHINNIKOVA	{"phone": "+70615147443"}
0005434552310	DADF52	2380 861832	NIKOLAY ZAYCEV	{"email": "zaycev_n_111973@postgrespro.ru", "phone": "+70880792455"}
0005434552311	EE34AF	8788 514098	DIANA FROLOVA	{"phone": "+70655945153"}
0005434552312	EE34AF	8652 795844	ULYANA IVANOVA	{"email": "uivanova.1977@postgrespro.ru", "phone": "+70715808910"}
0005434552313	FAA6C9	4755 515530	VIKTOR ZAKHAROV	{"phone": "+70471444842"}
0005434552314	FC2601	8926 219370	GRIGORIY KUZMIN	{"email": "kuzmin-grigoriy_15041976@postgrespro.ru", "phone": "+70169504173"}
0005434552315	FC2601	1441 280633	ANASTASIYA MIKHAYLOVA	{"email": "amikhaylova-1978@postgrespro.ru", "phone": "+70452613668"}
0005434552316	26694F	7186 992982	OLESYA ANTONOVA	{"email": "antonovaolesya.031977@postgrespro.ru", "phone": "+70980046042"}
0005434552317	26694F	5997 328383	IVAN FILIPPOV	{"email": "i.filippov16041965@postgrespro.ru", "phone": "+70188865178"}
0005434552318	FA9E3C	1250 679638	ELENA POLYAKOVA	{"email": "elena_polyakova_03121957@postgrespro.ru", "phone": "+70969099129"}
0005434552319	FA9E3C	5179 202831	TATYANA MARTYNOVA	{"phone": "+70035781263"}
0005434552320	74D8AB	6876 838076	EKATERINA FROLOVA	{"email": "e.frolova-23081980@postgrespro.ru", "phone": "+70926258053"}
0005434552321	503D28	0407 877510	VALENTIN SCHERBAKOV	{"phone": "+70682568216"}
0005434552322	4E4565	7955 629151	ANNA BELOVA	{"email": "belova-anna1989@postgrespro.ru", "phone": "+70620282408"}
0005434552323	66AACC	7008 040202	IRINA MEDVEDEVA	{"email": "i_medvedeva_081967@postgrespro.ru", "phone": "+70350537969"}
0005434552324	4570E6	9824 327143	VIKTORIYA KUZNECOVA	{"email": "kuznecova.v-1952@postgrespro.ru", "phone": "+70538276027"}
0005434552325	B077A9	3068 615536	EVGENIY GAVRILOV	{"phone": "+70919035017"}
0005434552326	F55E79	6055 278571	SERGEY FOMIN	{"email": "s.fomin.111980@postgrespro.ru", "phone": "+70275973846"}
0005434552327	F55E79	3192 681854	BORIS ANDREEV	{"email": "b.andreev15061967@postgrespro.ru", "phone": "+70045113848"}
0005434552328	F55E79	8315 379015	ANDREY GRIGOREV	{"email": "andrey-grigorev.09081965@postgrespro.ru", "phone": "+70778536912"}
0005434552329	38200E	9673 591797	YAROSLAV BELOV	{"email": "ybelov-1964@postgrespro.ru", "phone": "+70271122106"}
0005434552330	E5CF9C	3459 451833	GALINA IVANOVA	{"phone": "+70314566263"}
0005434552331	6F3A82	5405 167723	VALENTINA OSIPOVA	{"phone": "+70713044678"}
0005434552332	A3694C	1447 376311	NADEZHDA GRISHINA	{"email": "grishina-n_051971@postgrespro.ru", "phone": "+70338374747"}
0005434552333	A3694C	6659 298423	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov051975@postgrespro.ru", "phone": "+70942313426"}
0005434552334	1462B8	6516 523591	GALINA ALEKSEEVA	{"email": "galekseeva.1974@postgrespro.ru", "phone": "+70750580110"}
0005434552335	1462B8	0496 014133	YURIY POPOV	{"phone": "+70004671376"}
0005434552336	5AA9CB	9775 073937	MATVEY SOROKIN	{"email": "matvey-sorokin.071965@postgrespro.ru", "phone": "+70698442382"}
0005434552337	5AA9CB	6139 740145	EKATERINA KISELEVA	{"email": "ekiseleva-28111961@postgrespro.ru", "phone": "+70037429877"}
0005434552338	A25755	2115 432917	STANISLAV MIRONOV	{"phone": "+70457895569"}
0005434552339	E04F06	6729 317461	ILYA GUSEV	{"email": "gusev.i1963@postgrespro.ru", "phone": "+70044055262"}
0005434552340	7769F9	0907 424687	ANDREY IVANOV	{"email": "ivanov-andrey_1984@postgrespro.ru", "phone": "+70055447734"}
0005434552341	5E0D06	4514 154843	ELENA TIKHONOVA	{"phone": "+70808187925"}
0005434552342	5E0D06	6779 878525	VERA FADEEVA	{"email": "fadeevavera.121969@postgrespro.ru", "phone": "+70880433865"}
0005434552343	BFD0FB	8518 516262	YURIY BONDARENKO	{"phone": "+70039752861"}
0005434552344	E0F753	7209 511848	ALEKSEY MELNIKOV	{"phone": "+70178201483"}
0005434552345	E0F753	2430 779208	EKATERINA ISAEVA	{"email": "isaeva_e-021976@postgrespro.ru", "phone": "+70257050191"}
0005434552346	FEA76A	5235 026172	ALEKSANDRA NIKOLAEVA	{"email": "nikolaeva_aleksandra.071965@postgrespro.ru", "phone": "+70559755656"}
0005434552347	A6C38F	6393 666644	MARINA PAVLOVA	{"phone": "+70735742294"}
0005434552348	A6C38F	5028 303476	TATYANA KUZNECOVA	{"email": "tkuznecova011979@postgrespro.ru", "phone": "+70073805278"}
0005434552349	4CA49E	2418 214377	MIKHAIL FROLOV	{"email": "mikhail-frolov051975@postgrespro.ru", "phone": "+70184979983"}
0005434552350	261A22	7968 347622	OLGA MIRONOVA	{"email": "omironova_031980@postgrespro.ru", "phone": "+70693236042"}
0005434552351	261A22	5587 522381	VERA SAVELEVA	{"email": "verasaveleva_101986@postgrespro.ru", "phone": "+70695363599"}
0005434552352	E9DFB7	1463 709639	GULFIYA EGOROVA	{"phone": "+70917102609"}
0005434552353	A4AA0B	2155 405265	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir_021977@postgrespro.ru", "phone": "+70069837061"}
0005434552354	909CDC	1628 254537	NADEZHDA FILIPPOVA	{"phone": "+70195788214"}
0005434552355	909CDC	0605 762014	IVAN ALEKSANDROV	{"email": "ialeksandrov-06041975@postgrespro.ru", "phone": "+70544831226"}
0005434552356	B6A6A3	7235 631193	ALEKSANDR FOMIN	{"phone": "+70145459731"}
0005434552357	9CD0ED	2870 447683	ELENA VASILEVA	{"email": "vasileva.e-01021970@postgrespro.ru", "phone": "+70375465158"}
0005434552358	5EA327	7756 427669	ALEKSANDRA ZAKHAROVA	{"phone": "+70249468331"}
0005434552359	5EA327	6675 633059	VYACHESLAV ILIN	{"phone": "+70558573434"}
0005434552360	434E6A	9598 272884	OLGA ILINA	{"email": "ilinaolga_29051967@postgrespro.ru", "phone": "+70415894872"}
0005434552361	434E6A	2117 676077	VALERIY SCHERBAKOV	{"phone": "+70956956882"}
0005434552362	B4720E	8636 956239	NIKITA MAKAROV	{"phone": "+70637394729"}
0005434552363	4D1F21	2887 155337	TAMARA MIKHAYLOVA	{"email": "tamara.mikhaylova_031974@postgrespro.ru", "phone": "+70394806522"}
0005434552364	4D1F21	9212 672382	VLADIMIR KUZMIN	{"phone": "+70813138229"}
0005434552365	C9EF8E	6341 967566	GALINA ALEKSANDROVA	{"phone": "+70819599532"}
0005434552366	C9EF8E	2729 086405	ANDREY SIDOROV	{"email": "andrey-sidorov_02051979@postgrespro.ru", "phone": "+70587734268"}
0005434552367	E17AC1	0198 518252	YURIY VOLKOV	{"phone": "+70252538345"}
0005434552368	859157	6689 809147	ALEKSANDR KRASNOV	{"phone": "+70091950656"}
0005434552369	4FD368	1289 233983	MIKHAIL CHERNOV	{"email": "chernov-mikhail1966@postgrespro.ru", "phone": "+70378620360"}
0005434552370	4FD368	4021 269204	SERGEY SCHERBAKOV	{"phone": "+70411456952"}
0005434552371	E1A201	5655 558029	YULIYA BOGDANOVA	{"email": "y.bogdanova.27031969@postgrespro.ru", "phone": "+70015644919"}
0005434552372	E1A201	1355 961725	ANDREY VOLKOV	{"phone": "+70816261997"}
0005434552373	F29D8C	2957 676443	VLADIMIR GUSEV	{"email": "gusev_v_111971@postgrespro.ru", "phone": "+70119393231"}
0005434552374	6501F9	1250 618330	MIKHAIL POPOV	{"email": "popov_m.1966@postgrespro.ru", "phone": "+70664669069"}
0005434552375	6501F9	6320 499131	MARIYA ZAKHAROVA	{"phone": "+70901524830"}
0005434552376	D192D7	3496 824869	EKATERINA FROLOVA	{"email": "frolova.ekaterina121970@postgrespro.ru", "phone": "+70796270698"}
0005434552377	77DA20	2805 319044	RAFAIL GORBUNOV	{"phone": "+70111071164"}
0005434552378	FA92E2	7905 068717	VLADIMIR ANDREEV	{"email": "andreev_v101979@postgrespro.ru", "phone": "+70733455436"}
0005434552379	8B8D0A	4330 913354	ANASTASIYA EGOROVA	{"phone": "+70332665173"}
0005434552380	D5E64D	5726 954235	ALMIRA SAVELEVA	{"email": "savelevaalmira.1976@postgrespro.ru", "phone": "+70091284413"}
0005434552381	D5E64D	1393 486827	EVGENIY CHERNOV	{"phone": "+70315036190"}
0005434552382	76CF74	1367 101891	MIKHAIL VLASOV	{"email": "mikhailvlasov_12101972@postgrespro.ru", "phone": "+70758445980"}
0005434552383	A9868C	0084 161600	LYUBOV FILIPPOVA	{"phone": "+70679745016"}
0005434552384	F5CCE8	6837 329807	IVAN GUSEV	{"email": "gusevivan-01011975@postgrespro.ru", "phone": "+70596138359"}
0005434552385	E15306	2114 742830	NIKOLAY GERASIMOV	{"phone": "+70586549737"}
0005434552386	E15306	0033 652756	PETR KULIKOV	{"email": "kulikovp_20041974@postgrespro.ru", "phone": "+70327671210"}
0005434552387	C32532	1035 535076	VALERIY KAZAKOV	{"phone": "+70636990811"}
0005434552388	378381	9029 706710	ANNA PAVLOVA	{"phone": "+70982414873"}
0005434552389	378381	4225 764643	LARISA NIKITINA	{"phone": "+70000451847"}
0005434552390	09F4ED	4471 267330	KONSTANTIN NIKOLAEV	{"email": "nikolaev.k-031968@postgrespro.ru", "phone": "+70167765856"}
0005434552391	D2F27F	5788 889867	EVGENIYA SIDOROVA	{"email": "e_sidorova_09121976@postgrespro.ru", "phone": "+70724126212"}
0005434552392	2A6456	9574 235602	LIDIYA NESTEROVA	{"phone": "+70784714171"}
0005434552393	E7AF2A	7660 737457	SVETLANA POPOVA	{"phone": "+70409841563"}
0005434552394	BF8B37	2488 909172	ALEKSANDR KAZAKOV	{"email": "aleksandr_kazakov.14031970@postgrespro.ru", "phone": "+70221554789"}
0005434552395	176F1A	9794 957260	ALEKSANDR GUSEV	{"email": "gusev.aleksandr061972@postgrespro.ru", "phone": "+70032402849"}
0005434552396	474B31	8592 927548	NIKITA KUZNECOV	{"email": "nkuznecov.1966@postgrespro.ru", "phone": "+70084515460"}
0005434552397	474B31	3438 133767	FARID RODIONOV	{"phone": "+70150469470"}
0005434552398	E3DF0D	4205 909903	VALENTINA DANILOVA	{"email": "danilova.valentina_23101973@postgrespro.ru", "phone": "+70956988246"}
0005434552399	545D0C	5914 304423	YULIYA ZAYCEVA	{"email": "y_zayceva_101963@postgrespro.ru", "phone": "+70202476734"}
0005434552400	545D0C	8350 645215	OLGA KUDRYASHOVA	{"email": "kudryashova_olga_021981@postgrespro.ru", "phone": "+70228281952"}
0005434552401	545D0C	4773 454015	LYUDMILA KARPOVA	{"phone": "+70867715790"}
0005434552402	E3F388	9165 241291	MAKSIM MOISEEV	{"phone": "+70103677460"}
0005434552403	E3F388	0350 502786	EKATERINA BORISOVA	{"email": "borisova_ekaterina1972@postgrespro.ru", "phone": "+70759900565"}
0005434552404	A06820	8902 931116	TATYANA OSIPOVA	{"email": "t_osipova-1968@postgrespro.ru", "phone": "+70196781115"}
0005434552405	95647C	4945 608242	ULYANA IVANOVA	{"email": "u.ivanova_081973@postgrespro.ru", "phone": "+70070871863"}
0005434552406	95647C	9944 198498	LARISA MASLOVA	{"email": "maslovalarisa16091974@postgrespro.ru", "phone": "+70162633279"}
0005434552407	876F1B	2126 945270	ALEKSANDR NIKITIN	{"phone": "+70963921879"}
0005434552408	876F1B	8961 871370	VIKTOR ANDREEV	{"phone": "+70640659174"}
0005434552409	B7CB54	7081 892777	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev-16011961@postgrespro.ru", "phone": "+70227962124"}
0005434552410	B7CB54	3743 367555	MARIYA ABRAMOVA	{"email": "abramova.m.26121970@postgrespro.ru", "phone": "+70765215996"}
0005434552411	ED725F	7188 811063	YAROSLAV KUZNECOV	{"phone": "+70398662381"}
0005434552412	04A1F8	9090 781108	ALEKSEY ALEKSEEV	{"phone": "+70412165334"}
0005434552413	04A1F8	8679 725721	VLADIMIR IVANOV	{"email": "vivanov20031978@postgrespro.ru", "phone": "+70587134805"}
0005434552414	04A1F8	0200 515889	ANATOLIY ILIN	{"phone": "+70980357812"}
0005434552415	42C7BE	4536 687331	EKATERINA MAKSIMOVA	{"phone": "+70018592307"}
0005434552416	357ECE	5726 179089	VERA IVANOVA	{"phone": "+70228538419"}
0005434552417	357ECE	4214 929198	IGOR TARASOV	{"phone": "+70903046589"}
0005434552418	8A8B26	5193 138005	ZOYA SERGEEVA	{"email": "sergeevazoya.1973@postgrespro.ru", "phone": "+70681205934"}
0005434552419	1DAC89	8795 646939	NIKOLAY PETROV	{"email": "petrov-n_15031972@postgrespro.ru", "phone": "+70061850862"}
0005434552420	1DAC89	7794 830465	SERGEY BORISOV	{"email": "borisov-s.1982@postgrespro.ru", "phone": "+70315635916"}
0005434552421	CC0AF7	5609 904610	NATALYA KONOVALOVA	{"phone": "+70028770215"}
0005434552422	521D2D	4140 216453	ELENA PAVLOVA	{"email": "e-pavlova_25081970@postgrespro.ru", "phone": "+70565164706"}
0005434552423	521D2D	8363 923529	ELENA ANISIMOVA	{"email": "anisimovae.28011975@postgrespro.ru", "phone": "+70770331107"}
0005434552424	203CE5	2417 293709	MARINA FROLOVA	{"phone": "+70878937102"}
0005434552425	203CE5	6585 325295	DMITRIY AFANASEV	{"phone": "+70992577731"}
0005434552426	865A80	9742 784723	MARIYA ERMAKOVA	{"phone": "+70068101678"}
0005434552427	D23F82	2550 392967	OLGA KOROLEVA	{"phone": "+70157302325"}
0005434552428	6606C6	8851 268098	IDA NOVIKOVA	{"phone": "+70609987903"}
0005434552429	9619C9	4378 426165	TAMARA NOVIKOVA	{"phone": "+70453387450"}
0005434552430	46F55D	9912 858490	ANNA SOKOLOVA	{"email": "anna_sokolova.03011969@postgrespro.ru", "phone": "+70837727625"}
0005434552431	46F55D	3418 216347	PETR PETROV	{"phone": "+70877841248"}
0005434552432	E78C11	0140 288518	ZLATA ANTONOVA	{"email": "antonova.zlata1967@postgrespro.ru", "phone": "+70691260370"}
0005434552433	6E9386	2097 559022	EKATERINA RYABOVA	{"phone": "+70660838990"}
0005434552434	6E9386	0279 437856	SVETLANA KOMAROVA	{"email": "komarova.s_061975@postgrespro.ru", "phone": "+70148166487"}
0005434552545	A26E59	5458 000619	MIKHAIL KOZLOV	{"phone": "+70047187091"}
0005434552435	C0D46C	6793 538018	ANDREY NAUMOV	{"email": "naumov_andrey.09081975@postgrespro.ru", "phone": "+70456444442"}
0005434552436	C0D46C	3153 236900	ANNA ANTONOVA	{"email": "antonovaa031976@postgrespro.ru", "phone": "+70206722893"}
0005434552437	C0D46C	5240 307941	MARIYA VLASOVA	{"email": "vlasova.mariya061963@postgrespro.ru", "phone": "+70804431091"}
0005434552438	A617AB	3782 677820	LYUDMILA VLASOVA	{"email": "lyudmila.vlasova.081971@postgrespro.ru", "phone": "+70626603845"}
0005434552439	DE93CB	3971 481052	IVAN KUZNECOV	{"phone": "+70952300065"}
0005434552440	42F2B0	5860 092916	DAMIR FEDOROV	{"email": "damir-fedorov_1971@postgrespro.ru", "phone": "+70709211775"}
0005434552441	61E315	1026 601977	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev-25011972@postgrespro.ru", "phone": "+70931060067"}
0005434552442	B964F7	1064 386245	NATALYA NESTEROVA	{"phone": "+70805224116"}
0005434552443	4DFA99	8247 597200	SVETLANA TARASOVA	{"phone": "+70733295453"}
0005434552444	4DFA99	6888 675567	IRINA KOVALEVA	{"email": "kovalevai_1966@postgrespro.ru", "phone": "+70917217017"}
0005434552445	5C9FA9	3575 262112	MARIYA ANISIMOVA	{"email": "mariyaanisimova1982@postgrespro.ru", "phone": "+70921869116"}
0005434552446	F35441	6661 465471	DMITRIY KUZNECOV	{"phone": "+70498147038"}
0005434552447	2CE551	4953 430864	VYACHESLAV SERGEEV	{"phone": "+70243925314"}
0005434552448	2CE551	0639 557986	VLADIMIR NOVIKOV	{"email": "v.novikov_26061971@postgrespro.ru", "phone": "+70303417210"}
0005434552449	199E29	9987 696488	IGOR NIKOLAEV	{"email": "nikolaev-igor-021963@postgrespro.ru", "phone": "+70068918183"}
0005434552450	199E29	9120 316094	ALEKSANDR SERGEEV	{"phone": "+70252481913"}
0005434552451	D2B32F	3422 325910	DIANA ARKHIPOVA	{"phone": "+70397274829"}
0005434552452	D2B32F	7127 395773	VALERIYA SERGEEVA	{"phone": "+70026935741"}
0005434552453	C83967	6627 017930	DANIIL TIKHONOV	{"phone": "+70210145074"}
0005434552454	5CA1A4	0219 235575	RIMA ROMANOVA	{"phone": "+70193502156"}
0005434552455	5CA1A4	9772 883797	VIKTOR GORBUNOV	{"email": "viktor.gorbunov_091971@postgrespro.ru", "phone": "+70175180225"}
0005434552456	01DFEB	9692 187039	ELENA KUZNECOVA	{"phone": "+70493879433"}
0005434552457	EDDAC2	1121 270136	VLADIMIR FEDOROV	{"phone": "+70982754811"}
0005434552458	EDDAC2	2070 264520	LYUDMILA RODIONOVA	{"email": "l_rodionova17121976@postgrespro.ru", "phone": "+70745522020"}
0005434552459	DB0154	4588 507846	OLGA RODIONOVA	{"phone": "+70681746524"}
0005434552460	A4841B	3636 257276	NIKOLAY PAVLOV	{"email": "pavlovn02041973@postgrespro.ru", "phone": "+70019823145"}
0005434552461	A4841B	4889 729336	EKATERINA FEDOROVA	{"phone": "+70476124356"}
0005434552462	A4841B	4551 067722	ANDREY ABRAMOV	{"phone": "+70307989415"}
0005434552463	2887EA	8012 154813	GALINA FOMINA	{"email": "fomina-galina1963@postgrespro.ru", "phone": "+70165542364"}
0005434552464	624BEE	4598 175057	DARYA ISAEVA	{"email": "darya_isaeva1972@postgrespro.ru", "phone": "+70369112559"}
0005434552465	624BEE	6481 763614	ROMAN ORLOV	{"phone": "+70963496051"}
0005434552466	1F5061	0147 967319	ALENA OSIPOVA	{"phone": "+70909087770"}
0005434552467	A644E5	9868 876202	VALENTINA TARASOVA	{"email": "valentinatarasova.1985@postgrespro.ru", "phone": "+70574716720"}
0005434552468	A644E5	2941 122338	OLGA MAKAROVA	{"email": "makarova-o02091968@postgrespro.ru", "phone": "+70678749568"}
0005434552469	A644E5	0561 247276	MAKSIM VOROBEV	{"phone": "+70045120051"}
0005434552470	15516A	9970 578120	ALEKSANDR IVANOV	{"phone": "+70810194947"}
0005434552471	482FE7	9094 527053	LYUBOV NESTEROVA	{"phone": "+70241952356"}
0005434552472	482FE7	7579 514369	VALENTINA TARASOVA	{"email": "tarasovavalentina28111973@postgrespro.ru", "phone": "+70888096270"}
0005434552473	14C830	4495 587371	NATALYA MOISEEVA	{"email": "moiseevanatalya23021981@postgrespro.ru", "phone": "+70399551058"}
0005434552474	45B6A0	9090 392162	VALERIY IVANOV	{"phone": "+70564003984"}
0005434552475	4E9F97	7468 653854	SERGEY IVANOV	{"phone": "+70448853526"}
0005434552476	036659	5215 440996	ANDREY ALEKSANDROV	{"phone": "+70469472497"}
0005434552477	68B1E1	0644 912108	EVGENIYA STEPANOVA	{"email": "e_stepanova-061966@postgrespro.ru", "phone": "+70007494370"}
0005434552478	BD03FF	1758 654156	GEORGIY KARPOV	{"phone": "+70787774496"}
0005434552479	ABDF38	8586 397893	NATALYA MELNIKOVA	{"phone": "+70372511049"}
0005434552480	0A40CC	0849 683973	MARIYA MATVEEVA	{"phone": "+70328951361"}
0005434552481	A4B3BC	8654 534833	ANTONINA BELYAEVA	{"email": "belyaeva_a-24121975@postgrespro.ru", "phone": "+70350124929"}
0005434552482	A4B3BC	6722 438898	NIKITA ABRAMOV	{"phone": "+70257336597"}
0005434552483	A4B3BC	0048 549700	INNA VOLKOVA	{"email": "volkova-inna.011968@postgrespro.ru", "phone": "+70463705382"}
0005434552484	C7135E	6959 769913	ALEKSANDR DENISOV	{"email": "denisovaleksandr111975@postgrespro.ru", "phone": "+70032702062"}
0005434552485	E80F76	7550 485976	MAKSIM SOKOLOV	{"email": "sokolovmaksim_021969@postgrespro.ru", "phone": "+70807757489"}
0005434552486	E80F76	7053 681111	VLADIMIR SERGEEV	{"email": "sergeev-v-081982@postgrespro.ru", "phone": "+70597373102"}
0005434552487	559518	9018 385151	LARISA FILATOVA	{"phone": "+70630296473"}
0005434552488	DD9D14	5026 079320	OLGA FEDOROVA	{"email": "o-fedorova-011974@postgrespro.ru", "phone": "+70253525476"}
0005434552489	DD9D14	8837 229919	SVETLANA SERGEEVA	{"phone": "+70108562790"}
0005434552490	0D78CC	2618 694750	IVAN DENISOV	{"phone": "+70069036453"}
0005434552491	2E95CE	0489 262361	VALENTINA ZHUKOVA	{"email": "zhukova-v.101962@postgrespro.ru", "phone": "+70916464487"}
0005434552492	178FAE	2366 531955	TATYANA ZOTOVA	{"email": "zotova-t-1963@postgrespro.ru", "phone": "+70668627157"}
0005434552493	9BA273	9551 810263	MARIYA MATVEEVA	{"phone": "+70765112032"}
0005434552494	9BA273	8892 866415	LYUDMILA KOMAROVA	{"email": "komarova.lyudmila_101971@postgrespro.ru", "phone": "+70696262509"}
0005434552495	CAFCDE	3809 441678	ALEKSANDR ZAKHAROV	{"phone": "+70952833440"}
0005434552496	F6CB84	2562 542300	IRINA KOMAROVA	{"phone": "+70167961942"}
0005434552497	F6CB84	6279 996982	ANTON RODIONOV	{"email": "anton_rodionov.1965@postgrespro.ru", "phone": "+70551539932"}
0005434552498	137872	9397 213056	VIKTOR ANDREEV	{"phone": "+70811909468"}
0005434552499	6F919E	6395 258809	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov-101972@postgrespro.ru", "phone": "+70159721003"}
0005434552500	831325	0865 949496	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr-03111977@postgrespro.ru", "phone": "+70218430788"}
0005434552501	ECB3AF	7061 170870	KSENIYA MOROZOVA	{"email": "k.morozova.041975@postgrespro.ru", "phone": "+70533367383"}
0005434552502	17EDDC	7700 279600	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1964@postgrespro.ru", "phone": "+70191860470"}
0005434552503	0752C2	0783 855716	ELENA MOROZOVA	{"phone": "+70144497664"}
0005434552504	672EB1	8771 335776	PETR MAKAROV	{"email": "pmakarov_041968@postgrespro.ru", "phone": "+70722118756"}
0005434552505	672EB1	8755 451418	ANNA MATVEEVA	{"email": "a-matveeva-16071961@postgrespro.ru", "phone": "+70033985690"}
0005434552506	B2EA52	7375 284080	ALEKSANDR ZAYCEV	{"phone": "+70407005480"}
0005434552507	0BDDB5	3323 981066	VALERIY EGOROV	{"email": "egorov-valeriy1977@postgrespro.ru", "phone": "+70667390530"}
0005434552508	0BDDB5	1747 064429	TAMARA BARANOVA	{"email": "t_baranova_061969@postgrespro.ru", "phone": "+70538334685"}
0005434552509	3C382C	5893 151768	TAMARA PAVLOVA	{"email": "tpavlova-06021976@postgrespro.ru", "phone": "+70819430864"}
0005434552510	8BB1A3	5355 122407	IVAN MOROZOV	{"email": "ivan_morozov.31121969@postgrespro.ru", "phone": "+70949625689"}
0005434552511	B0DE71	1901 426199	ALINA EGOROVA	{"phone": "+70540551448"}
0005434552512	74FAE6	0498 476752	RAISA ANISIMOVA	{"email": "raisa-anisimova_1970@postgrespro.ru", "phone": "+70519008459"}
0005434552513	74FAE6	7019 850451	IVAN MELNIKOV	{"email": "imelnikov_04121982@postgrespro.ru", "phone": "+70456136688"}
0005434552514	8283BC	5982 329099	VALENTINA BORISOVA	{"phone": "+70272402625"}
0005434552515	8283BC	1854 216271	EVGENIY SEMENOV	{"email": "e-semenov.27051972@postgrespro.ru", "phone": "+70754398440"}
0005434552516	79C6FC	7053 359976	TATYANA IVANOVA	{"email": "ivanovat.14011971@postgrespro.ru", "phone": "+70661401497"}
0005434552517	79C6FC	8767 185019	ELENA MAKSIMOVA	{"email": "maksimova_e-13031974@postgrespro.ru", "phone": "+70996719704"}
0005434552518	E2EB59	7705 556184	IVAN FROLOV	{"email": "i.frolov-011970@postgrespro.ru", "phone": "+70850789825"}
0005434552519	E5D506	7814 361484	GALINA ZOTOVA	{"phone": "+70486295226"}
0005434552520	083939	3282 198154	YURIY BORISOV	{"email": "yuriy.borisov20101981@postgrespro.ru", "phone": "+70327286821"}
0005434552521	083939	8040 709833	PELAGEYA GAVRILOVA	{"phone": "+70081550908"}
0005434552522	A5717A	2915 847844	DIANA KUZNECOVA	{"email": "kuznecovad12071974@postgrespro.ru", "phone": "+70648110473"}
0005434552523	B1CE45	0037 144044	NATALYA BARANOVA	{"email": "n-baranova_06091985@postgrespro.ru", "phone": "+70439563269"}
0005434552524	F5DB94	5288 955695	YURIY TIKHONOV	{"email": "tikhonov_yuriy-061977@postgrespro.ru", "phone": "+70973858362"}
0005434552525	F5DB94	2078 259937	MARIYA ARKHIPOVA	{"email": "arkhipova-m_1974@postgrespro.ru", "phone": "+70365805449"}
0005434552526	0589EE	3838 610356	VALERIY IVANOV	{"email": "ivanov_valeriy01091965@postgrespro.ru", "phone": "+70083590730"}
0005434552527	D5C399	5749 274055	NATALIYA NIKOLAEVA	{"email": "nikolaeva_nataliya_1976@postgrespro.ru", "phone": "+70050358514"}
0005434552528	62E294	8343 580864	TATYANA MALYSHEVA	{"email": "t.malysheva_031971@postgrespro.ru", "phone": "+70321553941"}
0005434552529	B65619	9849 262073	GALINA MALYSHEVA	{"email": "malysheva.galina.101975@postgrespro.ru", "phone": "+70335194499"}
0005434552530	B0F6A1	6065 322588	RAISA ERMAKOVA	{"email": "ermakova.r_1968@postgrespro.ru", "phone": "+70380372399"}
0005434552531	008927	3759 142963	ALEKSEY ZHUKOV	{"email": "aleksey_zhukov-24011971@postgrespro.ru", "phone": "+70216729588"}
0005434552532	3C2F2C	1429 879697	ANATOLIY PAVLOV	{"email": "a-pavlov_091966@postgrespro.ru", "phone": "+70860044830"}
0005434552533	A6E880	6912 595227	MARINA TITOVA	{"email": "titova.m.20011973@postgrespro.ru", "phone": "+70215535442"}
0005434552534	A6E880	3721 520964	TATYANA MIRONOVA	{"phone": "+70441385664"}
0005434552535	7679A1	6191 643697	VLADIMIR DMITRIEV	{"phone": "+70097870731"}
0005434552536	7679A1	3267 181039	VALENTINA NAZAROVA	{"email": "nazarova.valentina13061972@postgrespro.ru", "phone": "+70145043879"}
0005434552537	514612	0869 423889	EVGENIY EGOROV	{"email": "evgeniy.egorov.121982@postgrespro.ru", "phone": "+70679790581"}
0005434552538	514612	5851 346961	EKATERINA EFIMOVA	{"phone": "+70026311704"}
0005434552539	514612	5739 068844	TATYANA SMIRNOVA	{"email": "smirnova.tatyana.1962@postgrespro.ru", "phone": "+70487539344"}
0005434552540	514612	3662 338805	ANDREY MOISEEV	{"phone": "+70845695672"}
0005434552541	141008	0095 931837	RADIK MOROZOV	{"phone": "+70502970574"}
0005434552542	AF3B9B	2347 559031	OLEG SOKOLOV	{"email": "sokolov.oleg.1964@postgrespro.ru", "phone": "+70287026905"}
0005434552543	5A812D	6256 454460	VIKTOR ABRAMOV	{"email": "abramov_viktor-1969@postgrespro.ru", "phone": "+70769555049"}
0005434552544	A26E59	4372 938009	KONSTANTIN TIMOFEEV	{"phone": "+70352984343"}
0005434552546	BAB927	9856 464319	LYUDMILA KUZNECOVA	{"email": "kuznecova-l-081961@postgrespro.ru", "phone": "+70107027816"}
0005434552547	172603	9665 138143	NATALYA IVANOVA	{"phone": "+70468043236"}
0005434552548	172603	8363 711838	BOGDAN GUSEV	{"email": "gusev.b-07091956@postgrespro.ru", "phone": "+70753429910"}
0005434552549	B49245	8461 584144	NATALYA VASILEVA	{"phone": "+70460515818"}
0005434552550	B49245	3397 026682	VLADIMIR FOMIN	{"email": "fomin-vladimir081967@postgrespro.ru", "phone": "+70420305798"}
0005434552551	D500E3	4676 383102	NATALYA BELOVA	{"email": "natalya-belova17011977@postgrespro.ru", "phone": "+70310885118"}
0005434552552	D500E3	8280 004107	NADEZHDA SEMENOVA	{"phone": "+70668699101"}
0005434552553	D500E3	9321 594598	KSENIYA GRISHINA	{"email": "grishina-k_08051977@postgrespro.ru", "phone": "+70063764239"}
0005434552554	BA6DF2	2127 506774	GEORGIY TARASOV	{"phone": "+70509441905"}
0005434552555	BA6DF2	5002 856198	SVETLANA CHERNOVA	{"email": "svetlana-chernova01021982@postgrespro.ru", "phone": "+70260809292"}
0005434552556	8CB6FA	9591 869491	KIRILL PETROV	{"phone": "+70489700321"}
0005434552557	CECFEA	5966 304602	VLADIMIR FOMIN	{"email": "fomin.v-051972@postgrespro.ru", "phone": "+70102677432"}
0005434552558	19B81D	5798 753868	NIKOLAY NAZAROV	{"email": "nikolay_nazarov07021968@postgrespro.ru", "phone": "+70865550802"}
0005434552559	97D6C8	4127 600507	KSENIYA ZOTOVA	{"email": "k_zotova.081982@postgrespro.ru", "phone": "+70627767715"}
0005434552560	97D6C8	0245 994663	MARIYA ZHUKOVA	{"email": "zhukovamariya25091977@postgrespro.ru", "phone": "+70951828014"}
0005434552561	B29944	9432 794000	OLGA FOMINA	{"phone": "+70852781113"}
0005434552562	B29944	5946 800268	FEDOR SAVELEV	{"email": "savelev_f1972@postgrespro.ru", "phone": "+70402318428"}
0005434552563	3E201E	6960 625046	VIKTOR IVANOV	{"email": "v_ivanov101967@postgrespro.ru", "phone": "+70542627671"}
0005434552564	9F693A	2147 027328	ALEKSEY ILIN	{"email": "ilin.a-23071971@postgrespro.ru", "phone": "+70277403674"}
0005434552565	9F693A	5409 604521	ANATOLIY SERGEEV	{"phone": "+70337933353"}
0005434552566	3667DC	6009 022961	VLADIMIR SHEVCHENKO	{"phone": "+70506640427"}
0005434552567	286153	0089 613960	KRISTINA AFANASEVA	{"email": "kristina-afanaseva1976@postgrespro.ru", "phone": "+70619828936"}
0005434552568	47E4DD	3088 288239	NADEZHDA KALININA	{"email": "kalininanadezhda-19121958@postgrespro.ru", "phone": "+70505463785"}
0005434552569	47E4DD	1005 449006	EKATERINA POLYAKOVA	{"email": "ekaterinapolyakova061973@postgrespro.ru", "phone": "+70441182919"}
0005434552570	832963	0922 552119	ELENA DENISOVA	{"phone": "+70244282935"}
0005434552571	F22828	0308 429204	ANATOLIY SCHERBAKOV	{"email": "anatoliy-scherbakov.091968@postgrespro.ru", "phone": "+70317745590"}
0005434552572	D27C59	5099 000727	VALENTINA GUSEVA	{"phone": "+70785958004"}
0005434552573	4565CD	9639 852274	KONSTANTIN EGOROV	{"email": "konstantin.egorov20111970@postgrespro.ru", "phone": "+70791642695"}
0005434552574	453AD7	2632 827619	YANA BELOVA	{"phone": "+70431046580"}
0005434552575	453AD7	9746 104079	KRISTINA GAVRILOVA	{"phone": "+70549352544"}
0005434552576	453AD7	8201 500813	DMITRIY PAVLOV	{"email": "d.pavlov_121966@postgrespro.ru", "phone": "+70465305993"}
0005434552577	CAEE13	2548 777225	ANASTASIYA MAKAROVA	{"phone": "+70383026286"}
0005434552578	89F93C	4907 696903	LYUDMILA GORBUNOVA	{"phone": "+70116840632"}
0005434552579	89F93C	4484 553497	RUSLAN BORISOV	{"phone": "+70143444297"}
0005434552580	D46B64	7765 263289	SVETLANA OSIPOVA	{"email": "osipova-s_1974@postgrespro.ru", "phone": "+70000973759"}
0005434552581	75AC91	5692 202069	MARGARITA KULIKOVA	{"phone": "+70364038068"}
0005434552582	0EDC1D	9672 096248	ALEKSEY POPOV	{"phone": "+70963517398"}
0005434552583	0EDC1D	2017 230387	ANTONINA KISELEVA	{"email": "akiseleva.29101968@postgrespro.ru", "phone": "+70034361592"}
0005434552584	0EDC1D	5603 743413	SVETLANA LEBEDEVA	{"email": "lebedevasvetlana.01051986@postgrespro.ru", "phone": "+70879463450"}
0005434552585	3D8EDF	5233 483565	NIKITA BARANOV	{"phone": "+70282477090"}
0005434552586	ACAD24	7191 633661	VERA BORISOVA	{"email": "borisovav-121971@postgrespro.ru", "phone": "+70274337546"}
0005434552587	9FCDB2	4563 688106	OLEG IVANOV	{"phone": "+70218619544"}
0005434552588	9FCDB2	9231 287416	VITALIY GORBUNOV	{"phone": "+70149478880"}
0005434552589	CEE59D	8028 708252	SVETLANA ANISIMOVA	{"email": "anisimova-s.1958@postgrespro.ru", "phone": "+70326573187"}
0005434552590	342618	4275 286725	LYUDMILA KAZAKOVA	{"phone": "+70570751839"}
0005434552591	C8C1FA	0953 504700	GALINA KUZMINA	{"email": "kuzmina_g101975@postgrespro.ru", "phone": "+70130748206"}
0005434552592	C8C1FA	7957 957172	TATYANA MALYSHEVA	{"email": "tmalysheva.18071975@postgrespro.ru", "phone": "+70790795800"}
0005434552593	205B92	0703 064021	ALEKSANDRA IVANOVA	{"phone": "+70963970099"}
0005434552594	A54ABB	0936 876024	ALEKSANDRA POTAPOVA	{"email": "potapovaa.071973@postgrespro.ru", "phone": "+70807709948"}
0005434552595	A54ABB	7949 871802	SERGEY ZAYCEV	{"phone": "+70871314568"}
0005434552596	C5A316	4851 869521	VENIAMIN SMIRNOV	{"phone": "+70091454019"}
0005434552597	C5A316	0222 736445	MILANA KUZNECOVA	{"phone": "+70219155598"}
0005434552598	FE6116	2532 126694	DINA ARKHIPOVA	{"email": "dinaarkhipova-11011963@postgrespro.ru", "phone": "+70181342023"}
0005434552599	FE6116	5789 733523	ELENA LUKYANOVA	{"email": "e_lukyanova_1960@postgrespro.ru", "phone": "+70322451986"}
0005434552600	04C546	6348 270624	ALEKSANDR SOROKIN	{"email": "asorokin.1971@postgrespro.ru", "phone": "+70011274396"}
0005434552601	B43220	1820 783144	KSENIYA KUZNECOVA	{"phone": "+70204974873"}
0005434552602	78D446	3555 830125	IRINA MAKAROVA	{"email": "irina.makarova_021969@postgrespro.ru", "phone": "+70872841977"}
0005434552603	78D446	1313 589319	VLADIMIR ALEKSANDROV	{"phone": "+70528606585"}
0005434552604	DF9F57	3645 790510	VLADIMIR MOROZOV	{"phone": "+70909498044"}
0005434552605	5B7094	4933 619599	SERGEY KUDRYASHOV	{"email": "kudryashov.sergey-14111960@postgrespro.ru", "phone": "+70502304088"}
0005434552606	5E11EF	8031 156426	ALEKSANDRA NIKIFOROVA	{"email": "a.nikiforova_041977@postgrespro.ru", "phone": "+70448412501"}
0005434552607	E6ECAF	3517 115059	IRINA FROLOVA	{"email": "i.frolova.1968@postgrespro.ru", "phone": "+70271750409"}
0005434552608	E6ECAF	1658 530459	IVAN ILIN	{"phone": "+70728576994"}
0005434552609	996941	8030 823058	ALEKSEY BONDARENKO	{"phone": "+70097503403"}
0005434552610	996941	3758 530818	SERGEY KOROLEV	{"email": "korolev.s051976@postgrespro.ru", "phone": "+70470485017"}
0005434552611	086CD1	8993 493464	PAVEL SAVELEV	{"phone": "+70371395574"}
0005434552612	086CD1	3455 110252	IRINA ISAEVA	{"email": "isaeva.i-08041985@postgrespro.ru", "phone": "+70228173788"}
0005434552613	523059	9735 918715	ALEKSANDR KULIKOV	{"phone": "+70989276514"}
0005434552614	2B0BD0	0807 630525	ALEVTINA KOZLOVA	{"email": "a.kozlova_101963@postgrespro.ru", "phone": "+70577172576"}
0005434552615	2B0BD0	9429 043530	DMITRIY MARTYNOV	{"phone": "+70066180415"}
0005434552616	0850B0	9964 692555	VIKTOR GUSEV	{"phone": "+70610736784"}
0005434552617	FACC15	9551 082335	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev111975@postgrespro.ru", "phone": "+70534903291"}
0005434552618	FACC15	7964 402637	EVGENIY MAKSIMOV	{"email": "e.maksimov-17101964@postgrespro.ru", "phone": "+70123560690"}
0005434552619	3D8816	4549 496268	SERGEY ANTONOV	{"email": "sergeyantonov_121966@postgrespro.ru", "phone": "+70759876348"}
0005434552620	5BE2FE	5590 714236	OLGA GRISHINA	{"phone": "+70746322996"}
0005434552621	5BE2FE	5404 883699	VALENTINA FADEEVA	{"phone": "+70211364153"}
0005434552622	5BE2FE	1052 815474	RUSTYAM SERGEEV	{"email": "rustyam.sergeev.1988@postgrespro.ru", "phone": "+70788636626"}
0005434552623	92FC35	3887 665794	LYUBOV KISELEVA	{"phone": "+70712503945"}
0005434552624	92FC35	5172 883384	MARIYA MOROZOVA	{"phone": "+70011446559"}
0005434552625	18DE18	8524 840149	VERA KUDRYASHOVA	{"email": "kudryashova-vera091970@postgrespro.ru", "phone": "+70768356897"}
0005434552626	037D49	5662 513634	IGOR SOKOLOV	{"email": "i-sokolov_081964@postgrespro.ru", "phone": "+70497152198"}
0005434552627	CA074C	2915 544291	SERGEY BELOV	{"email": "sergey_belov021969@postgrespro.ru", "phone": "+70696405329"}
0005434552628	1A2630	1495 485374	NADEZHDA KRASNOVA	{"email": "krasnova_n-08051960@postgrespro.ru", "phone": "+70919383653"}
0005434552629	887AC8	0775 503475	ALEKSANDR DENISOV	{"phone": "+70216481102"}
0005434552630	887AC8	4092 704867	RAFAEL MAKSIMOV	{"email": "r.maksimov_1968@postgrespro.ru", "phone": "+70278644051"}
0005434552631	887AC8	8698 256815	NIKOLAY KRASNOV	{"email": "krasnovnikolay30121970@postgrespro.ru", "phone": "+70500848078"}
0005434552632	8279C6	8386 798959	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova-1972@postgrespro.ru", "phone": "+70388381438"}
0005434552633	74E7DC	8558 247983	ELIZAVETA VOLKOVA	{"email": "elizaveta-volkova15061979@postgrespro.ru", "phone": "+70376729515"}
0005434552634	3DC2C9	6515 408623	OLGA PAVLOVA	{"email": "pavlovao-1977@postgrespro.ru", "phone": "+70866948360"}
0005434552635	8548F8	6250 626898	SOFYA KONOVALOVA	{"phone": "+70699468005"}
0005434552636	83436A	8590 924789	VALERIYA GUSEVA	{"email": "guseva.valeriya-091976@postgrespro.ru", "phone": "+70890010482"}
0005434552637	6C250A	5860 650799	DMITRIY MIKHAYLOV	{"email": "dmitriy-mikhaylov27031972@postgrespro.ru", "phone": "+70629438966"}
0005434552638	6C250A	9670 867580	ELENA SCHERBAKOVA	{"phone": "+70077453920"}
0005434552639	80DC2B	4678 257925	ALEKSANDR VASILEV	{"phone": "+70315746406"}
0005434552640	80DC2B	4416 354761	SVETLANA MAKSIMOVA	{"email": "svetlana_maksimova.1969@postgrespro.ru", "phone": "+70094798381"}
0005434552641	CBA879	3781 359767	VERA GUSEVA	{"email": "veraguseva031971@postgrespro.ru", "phone": "+70519879656"}
0005434552642	A4ACCD	4289 296000	KLAVDIYA KUZNECOVA	{"phone": "+70852267301"}
0005434552643	1E099D	2878 124881	KARINA KARPOVA	{"email": "karina.karpova_041964@postgrespro.ru", "phone": "+70670515543"}
0005434552644	83F870	3602 190016	ILYA ZHURAVLEV	{"phone": "+70770520806"}
0005434552645	412FB1	4743 075981	VALENTINA FOMINA	{"email": "fominav061976@postgrespro.ru", "phone": "+70985341104"}
0005434552646	412FB1	7345 351201	IGOR VOLKOV	{"phone": "+70529632076"}
0005434552647	598CFB	3626 799665	ANTONINA GAVRILOVA	{"email": "gavrilovaantonina-27101964@postgrespro.ru", "phone": "+70395270629"}
0005434552648	598CFB	5373 003004	AZAT MAKAROV	{"email": "makarova-1966@postgrespro.ru", "phone": "+70480074404"}
0005434552649	C8D3C1	5991 683926	IRINA OVCHINNIKOVA	{"email": "i.ovchinnikova-121963@postgrespro.ru", "phone": "+70320655035"}
0005434552650	D458E2	6158 408233	LIDIYA ALEKSEEVA	{"phone": "+70078500054"}
0005434552651	D458E2	3380 896769	TATYANA TITOVA	{"email": "titova-tatyana.011972@postgrespro.ru", "phone": "+70830356763"}
0005434552652	711C5C	7296 669242	GENNADIY ANTONOV	{"phone": "+70052812792"}
0005434552653	711C5C	4382 628767	ALEKSEY YAKOVLEV	{"email": "yakovlev-a-21021982@postgrespro.ru", "phone": "+70468011660"}
0005434552654	16E14A	1973 462129	TATYANA KARPOVA	{"phone": "+70530978323"}
0005434552655	6CBECE	4728 715699	OLEG FOMIN	{"phone": "+70949236327"}
0005434552656	4FA3A6	2736 981895	MARINA NIKOLAEVA	{"email": "m-nikolaeva_071979@postgrespro.ru", "phone": "+70187906204"}
0005434552657	4FA3A6	2627 349819	OLGA MOROZOVA	{"phone": "+70754345454"}
0005434552658	2C30A2	1995 734561	ALEKSANDR MARTYNOV	{"email": "martynovaleksandr_09101969@postgrespro.ru", "phone": "+70318205869"}
0005434552659	2C30A2	8755 807004	ALEKSANDR BONDARENKO	{"email": "aleksandr_bondarenko_1982@postgrespro.ru", "phone": "+70376928874"}
0005434552660	3DE26D	2528 038447	OLEG KRASNOV	{"email": "o_krasnov.051968@postgrespro.ru", "phone": "+70752560701"}
0005434552661	979A67	4443 219536	DENIS FROLOV	{"email": "frolovdenis-17041971@postgrespro.ru", "phone": "+70261280068"}
0005434552662	D8716A	5191 663977	ALENA ALEKSANDROVA	{"email": "alena.aleksandrova_12061974@postgrespro.ru", "phone": "+70419065548"}
0005434552663	D8716A	6587 506755	ALLA BELOVA	{"email": "abelova.1972@postgrespro.ru", "phone": "+70063581379"}
0005434552664	6AC1AE	3678 559433	VASILIY BELOV	{"phone": "+70046744134"}
0005434552665	6AC1AE	6531 370731	GENNADIY DAVYDOV	{"email": "davydovg1974@postgrespro.ru", "phone": "+70947367957"}
0005434552666	83B1B6	0509 108069	TATYANA MOROZOVA	{"phone": "+70331284005"}
0005434552667	4DCB73	9404 190227	ELENA BORISOVA	{"phone": "+70401928675"}
0005434552668	AFA383	9398 163438	TATYANA TARASOVA	{"email": "tatyana_tarasova21121969@postgrespro.ru", "phone": "+70971523348"}
0005434552669	0EE7A0	8910 230573	TATYANA DAVYDOVA	{"email": "davydovatatyana25111972@postgrespro.ru", "phone": "+70036512573"}
0005434552670	282ADE	5434 848349	RENAT BORISOV	{"email": "renat-borisov.02101982@postgrespro.ru", "phone": "+70910227012"}
0005434552671	192F5B	5385 568008	SVETLANA MATVEEVA	{"email": "matveeva-s_07021975@postgrespro.ru", "phone": "+70975755746"}
0005434552672	192F5B	4770 273195	ALEKSANDRA FEDOROVA	{"email": "aleksandrafedorova_1976@postgrespro.ru", "phone": "+70408055040"}
0005434552673	0F0FA8	4612 969680	TATYANA MAKAROVA	{"phone": "+70439749212"}
0005434552674	0F0FA8	8118 745979	TATYANA ANISIMOVA	{"phone": "+70365904761"}
0005434552675	830C1E	1600 654983	ALEKSANDR ANTONOV	{"phone": "+70361434218"}
0005434552676	830C1E	5370 844883	LARISA MELNIKOVA	{"email": "melnikova.l-28041978@postgrespro.ru", "phone": "+70306947590"}
0005434552677	6EBDE3	9536 543138	ARTEM TIMOFEEV	{"email": "timofeev_artem-24121969@postgrespro.ru", "phone": "+70129061335"}
0005434552678	6EBDE3	5198 956734	ANDREY ZAKHAROV	{"email": "zakharov-andrey111979@postgrespro.ru", "phone": "+70418817362"}
0005434552679	8B0F99	6878 007636	NATALYA VOLKOVA	{"phone": "+70059203510"}
0005434552680	8B0F99	9400 735365	ELENA SAVELEVA	{"phone": "+70881341743"}
0005434552681	4A2BA1	7508 911667	PAVEL ZHUKOV	{"email": "pavel_zhukov.1975@postgrespro.ru", "phone": "+70326176909"}
0005434552682	4A2BA1	3577 079381	VALENTINA SCHERBAKOVA	{"email": "v_scherbakova-26101976@postgrespro.ru", "phone": "+70917158305"}
0005434552683	4A2BA1	3139 715489	ARSENIY KUZMIN	{"email": "arseniy.kuzmin_1970@postgrespro.ru", "phone": "+70963633917"}
0005434552684	301DA1	9041 936459	TATYANA MARTYNOVA	{"email": "martynova-tatyana_05091974@postgrespro.ru", "phone": "+70578975617"}
0005434552685	301DA1	0826 710448	YURIY VOLKOV	{"email": "volkov.yuriy.1964@postgrespro.ru", "phone": "+70394544088"}
0005434552686	615459	7828 660746	YURIY PETROV	{"email": "petrov-y.081964@postgrespro.ru", "phone": "+70750435499"}
0005434552687	276C4A	7186 450083	VLADIMIR NAUMOV	{"phone": "+70288750270"}
0005434552688	5BF801	1128 382950	DMITRIY STEPANOV	{"phone": "+70492057428"}
0005434552689	5BF801	6705 960527	VLADIMIR SEMENOV	{"email": "vladimir.semenov1965@postgrespro.ru", "phone": "+70621801536"}
0005434552690	5BF801	1450 673485	PETR SOROKIN	{"email": "sorokinpetr051963@postgrespro.ru", "phone": "+70027507598"}
0005434552691	FAE4C0	9017 508750	VALENTINA FROLOVA	{"email": "valentina.frolova.1968@postgrespro.ru", "phone": "+70833472018"}
0005434552692	BDBB8F	0253 743228	IRINA ISAEVA	{"phone": "+70597025634"}
0005434552693	74CE15	3435 184225	ELENA TIKHONOVA	{"phone": "+70107024509"}
0005434552694	74CE15	3221 174091	ALEKSANDR ZAYCEV	{"phone": "+70081217466"}
0005434552695	90F4AA	7142 743598	EKATERINA KOMAROVA	{"phone": "+70710922490"}
0005434552696	7B9800	7453 564433	GALINA NIKITINA	{"phone": "+70540503159"}
0005434552697	5883DA	8213 411406	SERGEY ANTONOV	{"email": "sergey.antonov.1977@postgrespro.ru", "phone": "+70071562469"}
0005434552698	1E49E6	5094 838216	VERONIKA BOGDANOVA	{"phone": "+70480018181"}
0005434552699	5A9917	0402 402668	ALEKSANDR KUZNECOV	{"phone": "+70496473066"}
0005434552700	1BD784	3139 555304	PAVEL PETROV	{"email": "p_petrov-1971@postgrespro.ru", "phone": "+70235948729"}
0005434552701	788E68	3779 002152	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.07051969@postgrespro.ru", "phone": "+70321177178"}
0005434552702	788E68	6952 589098	NATALYA ANISIMOVA	{"phone": "+70270561391"}
0005434552703	61FA0A	8790 622188	TATYANA KUZMINA	{"email": "kuzminatatyana-041969@postgrespro.ru", "phone": "+70923620828"}
0005434552704	59C24E	7612 740327	NATALIYA KUZNECOVA	{"phone": "+70353421630"}
0005434552705	457272	6450 056967	LYUDMILA SOKOLOVA	{"email": "lyudmila_sokolova121963@postgrespro.ru", "phone": "+70822545903"}
0005434552706	217634	9525 951001	DENIS DAVYDOV	{"email": "davydov_denis.1967@postgrespro.ru", "phone": "+70497186821"}
0005434552707	D0E15B	4853 525227	IRINA GORBUNOVA	{"phone": "+70323124068"}
0005434552708	D0E15B	1938 416246	ARTUR KUZNECOV	{"email": "artur.kuznecov1970@postgrespro.ru", "phone": "+70046207656"}
0005434552709	3C0854	1562 424458	NADEZHDA MIRONOVA	{"email": "nadezhda-mironova-041980@postgrespro.ru", "phone": "+70995039245"}
0005434552710	DB9BBA	5235 187989	YULIYA ZOTOVA	{"phone": "+70065713349"}
0005434552711	330CAC	0639 685757	ALENA FEDOROVA	{"email": "fedorova-alena-1972@postgrespro.ru", "phone": "+70280698401"}
0005434552712	B09CF4	5829 020288	OLGA KOMAROVA	{"phone": "+70499068824"}
0005434552713	5D8093	3179 637840	TATYANA FEDOROVA	{"phone": "+70130563547"}
0005434552714	5D8093	5147 305774	EKATERINA FILATOVA	{"phone": "+70678190444"}
0005434552715	426E73	9670 638192	DENIS POPOV	{"email": "dpopov22031979@postgrespro.ru", "phone": "+70723558467"}
0005434552716	426E73	3654 601605	LYUBOV ALEKSANDROVA	{"phone": "+70126862460"}
0005434552717	426E73	8964 914865	DANA ZAYCEVA	{"email": "d-zayceva_25011975@postgrespro.ru", "phone": "+70203563884"}
0005434552718	5AD4AE	2749 304177	ANATOLIY MARTYNOV	{"email": "a.martynov-1979@postgrespro.ru", "phone": "+70821448505"}
0005434552719	5AD4AE	7461 776867	YULIYA GUSEVA	{"email": "yuliya-guseva-1972@postgrespro.ru", "phone": "+70885919316"}
0005434552720	A4136B	5509 700851	ANASTASIYA TIKHONOVA	{"phone": "+70422342173"}
0005434552721	C2E42A	5227 294419	VASILIY VLASOV	{"email": "vasiliy.vlasov_09031964@postgrespro.ru", "phone": "+70996442515"}
0005434552722	BD1194	1076 785259	OLGA BORISOVA	{"phone": "+70372731468"}
0005434552723	D2EF69	6631 770403	ELENA KULIKOVA	{"phone": "+70638451431"}
0005434552724	D2EF69	8643 259207	MARINA MOISEEVA	{"phone": "+70309524390"}
0005434552725	F177DA	4100 619162	RAMIL FEDOROV	{"phone": "+70921562070"}
0005434552726	2F7835	4246 061596	POLINA SERGEEVA	{"phone": "+70228094372"}
0005434552727	2F7835	7608 480907	ELENA ANTONOVA	{"email": "elenaantonova_23101984@postgrespro.ru", "phone": "+70407877593"}
0005434552728	042841	7506 912292	TATYANA FROLOVA	{"phone": "+70537010969"}
0005434552729	258786	3915 224386	SERGEY SAVELEV	{"email": "s.savelev1971@postgrespro.ru", "phone": "+70775472194"}
0005434552730	258786	5041 855315	SERGEY DMITRIEV	{"phone": "+70813975452"}
0005434552731	1B0709	4373 557777	TATYANA GERASIMOVA	{"phone": "+70903913131"}
0005434552732	11ED05	1833 497002	MARK NOVIKOV	{"email": "mark-novikov.14101975@postgrespro.ru", "phone": "+70239193000"}
0005434552733	11ED05	2954 085919	NIKOLAY POPOV	{"email": "popov_nikolay_1977@postgrespro.ru", "phone": "+70039041423"}
0005434552734	7D424D	6145 615244	VASILIY KUZMIN	{"email": "vasiliy-kuzmin_28071977@postgrespro.ru", "phone": "+70435093290"}
0005434552735	955966	0224 048441	ANDREY IVANOV	{"email": "andrey-ivanov.041965@postgrespro.ru", "phone": "+70508696475"}
0005434552736	8AA80E	1494 017212	ANTON FOMIN	{"phone": "+70875947820"}
0005434552737	8AA80E	6930 660104	YAROSLAV KRASNOV	{"phone": "+70147642729"}
0005434552738	8AA80E	1368 237045	SVETLANA LEBEDEVA	{"email": "svetlana_lebedeva15111981@postgrespro.ru", "phone": "+70593948812"}
0005434552739	7E4E02	5672 168283	LILIYA KOROLEVA	{"phone": "+70453952683"}
0005434552740	7E4E02	1354 800342	LYUDMILA IVANOVA	{"phone": "+70572433509"}
0005434552741	7E4E02	0208 905986	EKATERINA FEDOROVA	{"email": "efedorova.13081960@postgrespro.ru", "phone": "+70129778998"}
0005434552742	37BFE4	6477 083244	SVETLANA FOMINA	{"email": "s-fomina-121964@postgrespro.ru", "phone": "+70855835660"}
0005434552743	E78D69	7068 007768	NIKOLAY MIKHAYLOV	{"email": "mikhaylovn26091966@postgrespro.ru", "phone": "+70565088122"}
0005434552744	24E084	9176 384641	VYACHESLAV ZAKHAROV	{"email": "zakharov.vyacheslav-1982@postgrespro.ru", "phone": "+70239416976"}
0005434552745	6D3C1A	8952 295360	ELISEY TARASOV	{"email": "tarasov-e-031972@postgrespro.ru", "phone": "+70585702456"}
0005434552746	6D3C1A	9558 193578	TATYANA KOMAROVA	{"email": "tkomarova-101988@postgrespro.ru", "phone": "+70272068533"}
0005434552747	342B59	8258 995243	VASILIY KONOVALOV	{"email": "v_konovalov-1964@postgrespro.ru", "phone": "+70098514061"}
0005434552748	3EA815	2637 420839	ELENA MASLOVA	{"email": "maslovaelena1969@postgrespro.ru", "phone": "+70462077183"}
0005434552749	BFE7E8	8103 101656	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana_011972@postgrespro.ru", "phone": "+70278029718"}
0005434552750	E73D94	7667 541527	ARMEN ALEKSEEV	{"email": "armenalekseev_14011963@postgrespro.ru", "phone": "+70771895414"}
0005434552751	9B6D0E	1728 726111	YURIY FOMIN	{"phone": "+70442497121"}
0005434552752	44EABC	2141 942469	TIMUR ZAYCEV	{"email": "zaycev-t.04121976@postgrespro.ru", "phone": "+70106669245"}
0005434552753	5BE79F	6433 594326	ALEKSANDR ANTONOV	{"phone": "+70656176748"}
0005434552754	5A2387	7055 384775	BORIS STEPANOV	{"email": "stepanov-boris_18011977@postgrespro.ru", "phone": "+70867927663"}
0005434552755	5A2387	9092 287386	SERGEY IVANOV	{"email": "ivanovs31081959@postgrespro.ru", "phone": "+70876308062"}
0005434552756	1417A1	8688 126477	ALEKSEY ALEKSANDROV	{"email": "aleksandrov.a-011971@postgrespro.ru", "phone": "+70425459509"}
0005434552757	49005F	9383 901419	MIKHAIL STEPANOV	{"email": "stepanov-mikhail-30101981@postgrespro.ru", "phone": "+70613653045"}
0005434552758	49005F	2134 447191	ALEKSANDR NAZAROV	{"phone": "+70948620451"}
0005434552759	69B970	9361 706533	TATYANA DAVYDOVA	{"email": "davydova_tatyana-021977@postgrespro.ru", "phone": "+70059832167"}
0005434552760	6E0E6E	7868 368963	TATYANA LEBEDEVA	{"phone": "+70543680478"}
0005434552761	9C834C	7650 833631	NADEZHDA ANDREEVA	{"email": "nadezhda_andreeva1966@postgrespro.ru", "phone": "+70552708497"}
0005434552762	9C834C	3902 901056	LYUBOV NIKITINA	{"email": "nikitinalyubov-05081982@postgrespro.ru", "phone": "+70756333099"}
0005434552763	9C834C	3343 663818	NADEZHDA ARKHIPOVA	{"email": "arkhipova.n-16061979@postgrespro.ru", "phone": "+70899979230"}
0005434552764	8898AE	6923 639763	ANDREY SCHERBAKOV	{"phone": "+70243117350"}
0005434552765	13ECF2	2514 612730	PAVEL FROLOV	{"email": "frolov-p.1971@postgrespro.ru", "phone": "+70475757445"}
0005434552766	CACA47	4442 875640	ELIZAVETA MAKAROVA	{"email": "makarova_e.26031978@postgrespro.ru", "phone": "+70817475908"}
0005434552767	214FDB	0772 232441	VALENTINA ANDREEVA	{"email": "v-andreeva.091977@postgrespro.ru", "phone": "+70727648986"}
0005434552768	BDF4C2	7809 411343	LEONID POPOV	{"phone": "+70415356882"}
0005434552769	609C1E	4382 998568	LARISA POPOVA	{"email": "larisapopova_21031969@postgrespro.ru", "phone": "+70893937102"}
0005434552770	15A90C	0724 518437	LIDIYA IVANOVA	{"email": "ivanova-l-031972@postgrespro.ru", "phone": "+70855239392"}
0005434552771	9DEFA1	3116 767285	VLADIMIR MIKHAYLOV	{"phone": "+70869584086"}
0005434552772	9DEFA1	2973 296696	GALINA VOLKOVA	{"phone": "+70224751193"}
0005434552773	EFDCBF	2096 473031	ALEKSANDRA TARASOVA	{"phone": "+70146624690"}
0005434552774	EFDCBF	9708 284560	SVETLANA BORISOVA	{"phone": "+70839345469"}
0005434552775	20CD0B	2678 970392	ALBINA KOROLEVA	{"email": "korolevaa1973@postgrespro.ru", "phone": "+70690628114"}
0005434552776	02C537	7107 276694	ARTEM PETROV	{"phone": "+70349536888"}
0005434552777	02C537	6763 517436	ANDREY OSIPOV	{"email": "osipova-021972@postgrespro.ru", "phone": "+70546507038"}
0005434552778	526463	7105 944710	BORIS MIRONOV	{"email": "b-mironov011977@postgrespro.ru", "phone": "+70999775405"}
0005434552779	526463	8297 875271	DMITRIY ZAKHAROV	{"email": "dzakharov_18071965@postgrespro.ru", "phone": "+70352661875"}
0005434552780	526463	2495 585000	FEDOR KRASNOV	{"phone": "+70897894225"}
0005434552781	2E7270	1510 342563	EKATERINA EFREMOVA	{"email": "efremova-e.081981@postgrespro.ru", "phone": "+70504823306"}
0005434552782	2E7270	3155 666218	ELENA ZHURAVLEVA	{"email": "e.zhuravleva_081973@postgrespro.ru", "phone": "+70368527734"}
0005434552783	3F99A9	9453 132173	DMITRIY NIKITIN	{"email": "dmitriy.nikitin.081980@postgrespro.ru", "phone": "+70027598384"}
0005434552784	7351A5	1132 125652	SEMEN KONOVALOV	{"phone": "+70814228097"}
0005434552785	7351A5	6037 168839	NIKITA ROMANOV	{"email": "nikita-romanov_091977@postgrespro.ru", "phone": "+70408121915"}
0005434552786	988984	6738 935024	TATYANA PAVLOVA	{"phone": "+70512016981"}
0005434552787	988984	0680 174982	MAYYA ERMAKOVA	{"email": "ermakovamayya1963@postgrespro.ru", "phone": "+70371423919"}
0005434552788	617151	5213 542245	IGOR GRIGOREV	{"phone": "+70099357593"}
0005434552789	D16653	0135 571239	ELVIRA IVANOVA	{"email": "ivanova-elvira-081967@postgrespro.ru", "phone": "+70398583864"}
0005434552790	504225	7511 745860	NATALYA KARPOVA	{"email": "natalyakarpova.10091973@postgrespro.ru", "phone": "+70207254221"}
0005434552791	504225	9729 956128	NIKOLAY KUZNECOV	{"email": "n_kuznecov101980@postgrespro.ru", "phone": "+70845919543"}
0005434552792	8BD2ED	8858 705724	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev_26081976@postgrespro.ru", "phone": "+70951914112"}
0005434552793	8BD2ED	4820 005568	MARINA MAKAROVA	{"phone": "+70031764409"}
0005434552794	0D818C	6345 298047	DMITRIY ABRAMOV	{"phone": "+70574884765"}
0005434552795	0D818C	8002 342549	NIKOLAY KUZNECOV	{"email": "kuznecov.n-091968@postgrespro.ru", "phone": "+70601692192"}
0005434552796	E7ABFD	3274 357207	TATYANA IVANOVA	{"email": "tatyana.ivanova_1981@postgrespro.ru", "phone": "+70501500449"}
0005434552797	774A50	8708 239817	ANASTASIYA BORISOVA	{"phone": "+70430002943"}
0005434552798	774A50	9657 790608	NATALYA EFREMOVA	{"phone": "+70412652549"}
0005434552799	B79382	0762 816664	KIRILL VASILEV	{"email": "vasilev_k12021959@postgrespro.ru", "phone": "+70583846233"}
0005434552800	B79382	4770 936567	TIMUR SCHERBAKOV	{"phone": "+70670595579"}
0005434552801	4797AB	1433 630182	IRINA MALYSHEVA	{"email": "malysheva_irina.081967@postgrespro.ru", "phone": "+70810450637"}
0005434552802	9EF249	2587 756632	YAN MIKHAYLOV	{"email": "mikhaylov_yan-02091973@postgrespro.ru", "phone": "+70690871643"}
0005434552803	3C3921	5848 166133	DMITRIY ALEKSEEV	{"phone": "+70024387300"}
0005434552804	C2F18A	6036 741132	ANATOLIY NAZAROV	{"email": "nazarovanatoliy-1967@postgrespro.ru", "phone": "+70153050850"}
0005434552805	C9E1DC	6163 700547	IVAN FEDOROV	{"phone": "+70298310112"}
0005434552806	801B99	5749 171050	MARIYA MAKAROVA	{"phone": "+70175860349"}
0005434552807	8851FB	3400 401099	ALEKSANDR POPOV	{"email": "popovaleksandr.15101972@postgrespro.ru", "phone": "+70164033035"}
0005434552808	C2C891	7500 591305	GALINA KOLESNIKOVA	{"email": "kolesnikova.galina_031966@postgrespro.ru", "phone": "+70017927787"}
0005434552809	CB563E	7475 290712	DENIS PETROV	{"email": "dpetrov.021965@postgrespro.ru", "phone": "+70203219473"}
0005434552810	CB563E	8974 911270	SERGEY EGOROV	{"phone": "+70497755506"}
0005434552811	AA0A7C	7773 568893	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr.071972@postgrespro.ru", "phone": "+70248223987"}
0005434552812	DDC81A	5019 627548	BORIS KUZMIN	{"email": "kuzmin-boris_031971@postgrespro.ru", "phone": "+70829998837"}
0005434552813	AEE416	4869 774716	GALINA STEPANOVA	{"email": "stepanovag-05051971@postgrespro.ru", "phone": "+70998879584"}
0005434552814	DACC5D	6668 736409	ALEKSANDR SHEVCHENKO	{"phone": "+70332577103"}
0005434552815	394EAF	9158 524349	EKATERINA ERMAKOVA	{"email": "ekaterina.ermakova.1962@postgrespro.ru", "phone": "+70034936648"}
0005434552816	394EAF	5258 541819	MAKAR NAUMOV	{"email": "makar_naumov-07091969@postgrespro.ru", "phone": "+70694940913"}
0005434552817	394EAF	3943 943999	VALENTINA PETROVA	{"phone": "+70027830181"}
0005434552818	A44348	0441 846403	VLADIMIR VOLKOV	{"email": "volkov.v1991@postgrespro.ru", "phone": "+70990017244"}
0005434552819	A82A2A	8363 889031	ANDREY ORLOV	{"phone": "+70985755464"}
0005434552820	044BC0	7199 586418	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.061977@postgrespro.ru", "phone": "+70868153714"}
0005434552821	044BC0	9548 101083	TAMARA SOLOVEVA	{"email": "soloveva_tamara-03071966@postgrespro.ru", "phone": "+70512465019"}
0005434552822	528896	9995 054173	VIKTORIYA KAZAKOVA	{"email": "kazakovaviktoriya_061981@postgrespro.ru", "phone": "+70249278706"}
0005434552823	57DF6B	2023 264331	ELENA ANISIMOVA	{"email": "anisimova_elena-15041976@postgrespro.ru", "phone": "+70448314315"}
0005434552824	57DF6B	6678 624006	SVETLANA MOROZOVA	{"email": "morozova-s.091964@postgrespro.ru", "phone": "+70629317407"}
0005434552825	BB1B71	5116 930972	DARYA RODIONOVA	{"email": "drodionova_1975@postgrespro.ru", "phone": "+70054582282"}
0005434552826	9509F8	2956 556140	PAVEL SMIRNOV	{"phone": "+70579602694"}
0005434552827	9509F8	6666 552404	EGOR MAKAROV	{"email": "makarov_egor_17031972@postgrespro.ru", "phone": "+70322749572"}
0005434552828	FB84F1	4818 815914	VALENTINA KRASNOVA	{"phone": "+70173117026"}
0005434552829	FB84F1	1956 825985	MIKHAIL KUZNECOV	{"email": "kuznecov_m-25061964@postgrespro.ru", "phone": "+70849989576"}
0005434552830	FB84F1	4125 097350	OLGA SERGEEVA	{"email": "sergeeva_olga-1965@postgrespro.ru", "phone": "+70660792259"}
0005434552831	F6039C	5607 300096	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya.121977@postgrespro.ru", "phone": "+70185966522"}
0005434552832	F6039C	6707 599388	GRIGORIY MIKHAYLOV	{"email": "grigoriy-mikhaylov_121959@postgrespro.ru", "phone": "+70187433983"}
0005434552833	EB8F86	8154 110576	PAVEL SIDOROV	{"email": "sidorov_pavel_26011991@postgrespro.ru", "phone": "+70458403411"}
0005434552834	73A34A	4489 170894	IGOR VASILEV	{"email": "vasilev_igor-02021973@postgrespro.ru", "phone": "+70339835561"}
0005434552835	73A34A	0893 408954	LARISA RODIONOVA	{"email": "l.rodionova1979@postgrespro.ru", "phone": "+70596854244"}
0005434552836	B94AD2	6459 009087	VALERIY BORISOV	{"email": "borisov.valeriy.071978@postgrespro.ru", "phone": "+70567080916"}
0005434552837	00497A	7517 514192	VERA MALYSHEVA	{"phone": "+70428849029"}
0005434552838	CAE297	1382 971208	OLGA KOZLOVA	{"email": "o.kozlova-081973@postgrespro.ru", "phone": "+70266241534"}
0005434552839	CAE297	5638 374775	ANNA ISAEVA	{"phone": "+70307042968"}
0005434552840	160CA8	5072 592546	VLADIMIR SMIRNOV	{"email": "smirnov-vladimir09081969@postgrespro.ru", "phone": "+70809551816"}
0005434552841	93731D	8137 328119	NINA ZOTOVA	{"email": "n-zotova-061977@postgrespro.ru", "phone": "+70767611194"}
0005434552842	BEFA60	7091 244829	ALEKSEY ROMANOV	{"phone": "+70718772503"}
0005434552843	8207C4	6570 544807	ALEKSANDR GERASIMOV	{"phone": "+70434777024"}
0005434552844	9A6A34	8876 866368	EVGENIY MAKSIMOV	{"phone": "+70348165606"}
0005434552845	005769	9085 482113	ALEKSANDRA KALININA	{"phone": "+70779736345"}
0005434552846	005769	4984 302818	LYUBOV KONDRATEVA	{"email": "kondrateva-lyubov18041966@postgrespro.ru", "phone": "+70647938169"}
0005434552847	525FD7	8648 042515	ELENA NAZAROVA	{"email": "e-nazarova_081970@postgrespro.ru", "phone": "+70841639649"}
0005434552848	AA1EEC	4610 851759	VARVARA STEPANOVA	{"email": "varvara-stepanova_05011976@postgrespro.ru", "phone": "+70357033837"}
0005434552849	AA1EEC	9816 969965	INNA KUZNECOVA	{"phone": "+70549490835"}
0005434552850	FED6D0	0417 625808	STANISLAV IVANOV	{"phone": "+70954274017"}
0005434552851	F2DA6E	3833 127470	VLADIMIR PETROV	{"email": "petrovvladimir_061971@postgrespro.ru", "phone": "+70224786129"}
0005434552852	A0BE2F	1441 216159	VIKTOR KOZLOV	{"phone": "+70562929670"}
0005434552853	D2F9E2	8874 228391	VLADISLAV EGOROV	{"email": "vladislav_egorov_1976@postgrespro.ru", "phone": "+70599152559"}
0005434552854	0E11DB	1030 761441	RAISA ORLOVA	{"phone": "+70047154451"}
0005434552855	0E11DB	7186 707155	RAFIK ALEKSEEV	{"phone": "+70891517948"}
0005434552856	C9D9A3	9845 049014	ANASTASIYA BELOVA	{"email": "belovaa_021959@postgrespro.ru", "phone": "+70901805178"}
0005434552857	2D5420	9629 307434	VLADIMIR FROLOV	{"phone": "+70806529040"}
0005434552858	80D5F4	2096 387211	VITALIY POPOV	{"phone": "+70157447538"}
0005434552859	80D5F4	0152 043465	VALENTINA FOMINA	{"phone": "+70662907006"}
0005434552860	A3333B	1029 793799	KRISTINA SOROKINA	{"email": "kristinasorokina.24061979@postgrespro.ru", "phone": "+70598168210"}
0005434552861	A3333B	2261 667404	YURIY NOVIKOV	{"email": "ynovikov.24111976@postgrespro.ru", "phone": "+70378132933"}
0005434552862	588F7A	4283 121606	EKATERINA ALEKSEEVA	{"email": "ekaterina.alekseeva_081962@postgrespro.ru", "phone": "+70010853386"}
0005434552863	E1BD6C	1847 165918	VYACHESLAV SIDOROV	{"email": "sidorov.vyacheslav_1973@postgrespro.ru", "phone": "+70335306385"}
0005434552864	6E8D99	3681 778603	IRINA ORLOVA	{"phone": "+70325456581"}
0005434552865	6E8D99	3543 272624	PAVEL MOISEEV	{"email": "pavel-moiseev.111968@postgrespro.ru", "phone": "+70758114833"}
0005434552866	6401BF	5389 885328	ANATOLIY MAKAROV	{"phone": "+70595944437"}
0005434552867	4AC26A	5797 588924	MAYA EGOROVA	{"email": "egorova.maya1969@postgrespro.ru", "phone": "+70770533937"}
0005434552868	4AC26A	3301 417200	NADEZHDA KUZNECOVA	{"email": "kuznecova.n021972@postgrespro.ru", "phone": "+70541712932"}
0005434552869	CA8D6B	6059 654645	YULIYA SIDOROVA	{"email": "sidorova-y_26051993@postgrespro.ru", "phone": "+70071681253"}
0005434552870	309C6C	7630 664930	VIKTOR TIKHONOV	{"phone": "+70908328355"}
0005434552871	309C6C	6034 706693	VLADIMIR KISELEV	{"phone": "+70150102835"}
0005434552872	0659A9	6329 063589	EVGENIY ILIN	{"email": "ilin.e_091972@postgrespro.ru", "phone": "+70240234408"}
0005434552873	0659A9	5294 321593	YURIY AFANASEV	{"phone": "+70711998571"}
0005434552874	21FD86	6457 821517	ZHANNA POLYAKOVA	{"phone": "+70497949743"}
0005434552875	8855EE	0214 855403	OKSANA KISELEVA	{"email": "o_kiseleva.14081959@postgrespro.ru", "phone": "+70726119910"}
0005434552876	1F7AA3	4086 510839	ALEKSANDR SCHERBAKOV	{"phone": "+70329399400"}
0005434552877	8366D0	2819 937294	VLADISLAV ZAKHAROV	{"email": "v_zakharov.28071967@postgrespro.ru", "phone": "+70838409018"}
0005434552878	8366D0	3615 720299	OLGA LOGINOVA	{"phone": "+70868433770"}
0005434552879	D99618	5655 538440	SERGEY SERGEEV	{"phone": "+70743591378"}
0005434552880	CEF887	9739 145712	IRINA MATVEEVA	{"phone": "+70453288865"}
0005434552881	006151	8448 656045	OLGA TROFIMOVA	{"phone": "+70296996053"}
0005434552882	8AFA06	2730 593775	ANASTASIYA POPOVA	{"email": "popova_anastasiya-1975@postgrespro.ru", "phone": "+70021598823"}
0005434552883	955F53	9423 248619	MAKSIM KOZLOV	{"email": "m.kozlov101972@postgrespro.ru", "phone": "+70998459915"}
0005434552884	7BF1E0	0183 466678	ALEKSANDRA PAVLOVA	{"phone": "+70192945191"}
0005434552885	452B78	0742 527035	VLADIMIR NAZAROV	{"email": "nazarovv.011972@postgrespro.ru", "phone": "+70531616180"}
0005434552886	19FF9C	9702 792592	ANASTASIYA NAZAROVA	{"email": "nazarova-a_12031971@postgrespro.ru", "phone": "+70512111954"}
0005434552887	D805B5	5107 243742	EVGENIY TIKHONOV	{"phone": "+70160718408"}
0005434552888	A07A43	6170 204855	YULIYA MAKAROVA	{"email": "makarova_yuliya_1973@postgrespro.ru", "phone": "+70894164172"}
0005434552889	63284D	3501 672881	VERA KOZLOVA	{"email": "vera.kozlova.111970@postgrespro.ru", "phone": "+70949508970"}
0005434552890	EEC4BE	0295 677699	TAMARA ALEKSEEVA	{"email": "talekseeva_1969@postgrespro.ru", "phone": "+70061688591"}
0005434552891	EEC4BE	6609 004114	BORIS MOROZOV	{"email": "morozovb_101974@postgrespro.ru", "phone": "+70650475650"}
0005434552892	EEC4BE	3085 788648	OLGA LUKYANOVA	{"email": "o_lukyanova-021976@postgrespro.ru", "phone": "+70758876042"}
0005434552893	00E597	5208 339537	ROMAN MELNIKOV	{"email": "r.melnikov-011976@postgrespro.ru", "phone": "+70678334891"}
0005434552894	00E597	1675 502050	MARIYA MEDVEDEVA	{"phone": "+70193594384"}
0005434552895	8FC402	3330 313748	RUSLAN KUZNECOV	{"email": "kuznecov-ruslan-091974@postgrespro.ru", "phone": "+70344279511"}
0005434552896	B3E8F4	8258 064241	SERGEY DAVYDOV	{"phone": "+70012738132"}
0005434552897	B3E8F4	1224 901985	VALERIY KUDRYASHOV	{"phone": "+70941779601"}
0005434552898	B6D161	3688 161132	PETR SOLOVEV	{"phone": "+70825987643"}
0005434552899	05585C	6379 644101	EDUARD BELOV	{"email": "beloveduard041969@postgrespro.ru", "phone": "+70520159686"}
0005434552900	05585C	8111 958287	SERGEY SOROKIN	{"phone": "+70965251891"}
0005434552901	771565	3964 878753	EVGENIYA AFANASEVA	{"phone": "+70417045472"}
0005434552902	771565	6760 417172	OLEG SMIRNOV	{"email": "oleg.smirnov_1985@postgrespro.ru", "phone": "+70064834027"}
0005434552903	42748E	4312 558180	EVGENIY ANTONOV	{"email": "antonovevgeniy_021977@postgrespro.ru", "phone": "+70215005281"}
0005434552904	89686E	3784 726280	EKATERINA MAKAROVA	{"phone": "+70055555466"}
0005434552905	89686E	5930 600963	EVGENIY SOLOVEV	{"phone": "+70182596632"}
0005434552906	854B23	9402 868230	NATALYA KOZLOVA	{"phone": "+70011776077"}
0005434552907	854B23	0171 817077	ANASTASIYA VLASOVA	{"phone": "+70847784324"}
0005434552908	9BB443	9555 765359	TATYANA ROMANOVA	{"email": "tatyana_romanova_02031982@postgrespro.ru", "phone": "+70171511503"}
0005434552909	9BB443	5897 906768	VIKTOR TIKHONOV	{"email": "viktor.tikhonov-16051970@postgrespro.ru", "phone": "+70610174725"}
0005434552910	DA9D85	9598 801180	YULIYA ANISIMOVA	{"phone": "+70018105396"}
0005434552911	EAFE5D	9034 698724	IVAN PETROV	{"email": "petrov-i-14031974@postgrespro.ru", "phone": "+70100399257"}
0005434552912	4FCEE5	0462 000323	ALEKSANDR MOROZOV	{"phone": "+70734144926"}
0005434552913	4FCEE5	1918 641476	DANIIL PAVLOV	{"email": "pavlov-daniil.041975@postgrespro.ru", "phone": "+70887089382"}
0005434552914	4FCEE5	0737 077368	VIKTOR ALEKSANDROV	{"phone": "+70361276434"}
0005434552915	4FCEE5	3774 699112	PAVEL ABRAMOV	{"email": "pavelabramov.091972@postgrespro.ru", "phone": "+70888830747"}
0005434552916	3EBB28	3210 071617	DMITRIY SOROKIN	{"phone": "+70256343281"}
0005434552917	63374F	6392 994398	NINA YAKOVLEVA	{"email": "nina_yakovleva1970@postgrespro.ru", "phone": "+70139643309"}
0005434552918	128BCD	9792 384249	VERA SOROKINA	{"email": "v_sorokina26121966@postgrespro.ru", "phone": "+70434553151"}
0005434552919	0FC792	6489 301476	ZOYA NIKITINA	{"phone": "+70662340319"}
0005434554024	B347F4	6546 918963	LEONID KOROLEV	{"phone": "+70974877834"}
0005434554025	B7672B	2593 745451	GALINA BELYAEVA	{"email": "belyaeva-g_1967@postgrespro.ru", "phone": "+70893710065"}
0005434554026	5CA919	1378 071099	GALINA YUDINA	{"email": "yudina-galina.1962@postgrespro.ru", "phone": "+70912880629"}
0005434554027	5CA919	2628 119007	PAVEL SIDOROV	{"email": "pavel-sidorov_1969@postgrespro.ru", "phone": "+70275410569"}
0005434554028	9E71A6	1101 421513	DINA NIKOLAEVA	{"phone": "+70289489045"}
0005434554029	9E71A6	0435 918321	ANDREY YAKOVLEV	{"phone": "+70017534600"}
0005434554030	FDF64D	9199 332423	SERGEY KULIKOV	{"phone": "+70041275583"}
0005434554031	7D0FC3	9892 709518	EVGENIY SOLOVEV	{"email": "soloveve-101968@postgrespro.ru", "phone": "+70598118983"}
0005434554032	25FBED	1344 195376	MIKHAIL KRASNOV	{"email": "mikhail_krasnov091965@postgrespro.ru", "phone": "+70880135260"}
0005434554033	B7D95A	4353 020432	VALENTINA GORBUNOVA	{"email": "gorbunova.v_01101967@postgrespro.ru", "phone": "+70939799160"}
0005434554034	A34F8F	7200 579711	RENAT ZAYCEV	{"email": "renat-zaycev1969@postgrespro.ru", "phone": "+70521620459"}
0005434554035	2003C1	9027 664156	EGOR KUZNECOV	{"phone": "+70220559226"}
0005434554036	F09FE2	8744 980694	SERGEY VASILEV	{"email": "vasilev_sergey051983@postgrespro.ru", "phone": "+70453255487"}
0005434554037	F09FE2	7947 807459	ALEKSANDR SERGEEV	{"email": "aleksandr_sergeev.24091981@postgrespro.ru", "phone": "+70758770693"}
0005434554038	5331FA	5626 619502	ELENA ZAYCEVA	{"phone": "+70777944682"}
0005434554039	4EF637	2071 653752	NATALYA MAKSIMOVA	{"phone": "+70025773134"}
0005434554040	AF34BF	0965 131534	LYUDMILA LEBEDEVA	{"phone": "+70180266563"}
0005434554041	1D8B95	9192 610511	ELIZAVETA FILATOVA	{"email": "elizaveta_filatova.061974@postgrespro.ru", "phone": "+70049438359"}
0005434554042	77826C	1247 190740	ALEKSANDRA KUZMINA	{"phone": "+70780346617"}
0005434554043	77826C	7154 435196	MIKHAIL SIDOROV	{"phone": "+70961599231"}
0005434554044	6A7929	9674 449494	VALENTINA AKIMOVA	{"email": "akimovav-101976@postgrespro.ru", "phone": "+70835096916"}
0005434554045	A7CF1C	2434 031680	MIKHAIL MAKAROV	{"phone": "+70407986628"}
0005434554046	A7CF1C	9191 000478	NINA KRASNOVA	{"email": "krasnova_nina1979@postgrespro.ru", "phone": "+70723098513"}
0005434554047	4B751A	5451 050201	ANDREY BARANOV	{"phone": "+70183586077"}
0005434554048	8F377F	5174 229843	ANDREY MOISEEV	{"phone": "+70799690794"}
0005434554049	E6822E	1420 823013	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev-071975@postgrespro.ru", "phone": "+70534756739"}
0005434554050	B17A57	8052 087187	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov.1969@postgrespro.ru", "phone": "+70293263026"}
0005434554051	30C705	3268 232660	ANDREY SERGEEV	{"phone": "+70611761524"}
0005434554052	30C705	2346 275941	MATVEY KUZNECOV	{"phone": "+70945753651"}
0005434554053	4B140C	6161 802012	RAISA RYABOVA	{"email": "r-ryabova_06021973@postgrespro.ru", "phone": "+70603135920"}
0005434554054	4B140C	9259 139414	SERGEY SIDOROV	{"phone": "+70174878692"}
0005434554055	2E29A0	5436 741345	ZOYA KOROLEVA	{"email": "zoya.koroleva_02041983@postgrespro.ru", "phone": "+70504228154"}
0005434554056	2E29A0	0416 153133	EKATERINA SMIRNOVA	{"phone": "+70510664176"}
0005434554057	2E29A0	5539 118423	EKATERINA DMITRIEVA	{"email": "ekaterina-dmitrieva_05031971@postgrespro.ru", "phone": "+70993525761"}
0005434554058	7886E9	3534 904568	MIKHAIL ABRAMOV	{"phone": "+70869538003"}
0005434554059	47965B	8936 919711	PETR SERGEEV	{"email": "sergeev.p.021964@postgrespro.ru", "phone": "+70477111248"}
0005434554060	47965B	3507 735974	SERGEY MAKSIMOV	{"email": "s_maksimov.10061979@postgrespro.ru", "phone": "+70023818357"}
0005434554061	8ADF38	9422 378005	VLADIMIR GRIGOREV	{"email": "grigorev_v081970@postgrespro.ru", "phone": "+70482460209"}
0005434554062	8ADF38	1176 554800	VADIM SIDOROV	{"email": "v_sidorov.17081981@postgrespro.ru", "phone": "+70777429322"}
0005434554063	17A779	1337 047890	ALEKSANDR DMITRIEV	{"phone": "+70971078995"}
0005434554064	17A779	7016 018992	ALEKSANDRA POPOVA	{"email": "popova-aleksandra_03011968@postgrespro.ru", "phone": "+70060371103"}
0005434554065	7D5D52	5132 509353	ANASTASIYA MIRONOVA	{"email": "mironova_anastasiya-071970@postgrespro.ru", "phone": "+70704399622"}
0005434554066	715632	1270 300734	VLADIMIR BARANOV	{"email": "baranovvladimir.03121975@postgrespro.ru", "phone": "+70598685827"}
0005434554067	B1DA7D	6674 830184	ROMAN GRIGOREV	{"email": "grigorevr-10081970@postgrespro.ru", "phone": "+70318852837"}
0005434554068	38F247	5784 829134	DANILA MOROZOV	{"phone": "+70706849470"}
0005434554069	48E1EE	1258 195866	PETR KULIKOV	{"phone": "+70371869262"}
0005434554070	6149F1	0836 523018	TAISA FOMINA	{"email": "taisa.fomina-051974@postgrespro.ru", "phone": "+70640963941"}
0005434554071	E91F38	1302 191839	SERGEY NAUMOV	{"email": "naumovs.21031971@postgrespro.ru", "phone": "+70683477547"}
0005434554072	E91F38	0390 700104	LIDIYA KUZNECOVA	{"email": "kuznecova.lidiya-081970@postgrespro.ru", "phone": "+70619548258"}
0005434554073	E91F38	8531 374883	OLESYA TARASOVA	{"phone": "+70247958721"}
0005434554074	5DA430	3969 250616	LIDIYA BELYAEVA	{"phone": "+70305866099"}
0005434554075	02277D	3372 521664	SERGEY MARTYNOV	{"email": "sergeymartynov_05071972@postgrespro.ru", "phone": "+70472337299"}
0005434554076	40C2F0	7078 577391	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila.09031969@postgrespro.ru", "phone": "+70190991449"}
0005434554077	EB0B6E	6101 779592	MARGARITA KONOVALOVA	{"email": "konovalova.margarita26101968@postgrespro.ru", "phone": "+70445770417"}
0005434554078	EB0B6E	2278 905184	VITALIY ZHURAVLEV	{"email": "vitaliyzhuravlev-20031974@postgrespro.ru", "phone": "+70194167692"}
0005434554079	C0115E	6631 621806	SERGEY PETROV	{"email": "s-petrov-25091982@postgrespro.ru", "phone": "+70524315873"}
0005434554080	8BF249	2393 962931	IVAN FILIPPOV	{"email": "ifilippov01121970@postgrespro.ru", "phone": "+70966532774"}
0005434554081	D73DBD	5386 845674	SVETLANA ZOTOVA	{"phone": "+70182426169"}
0005434554082	9FE5DE	9965 217694	TATYANA PAVLOVA	{"phone": "+70662418584"}
0005434554083	5DD81D	9918 546465	LYUDMILA NAUMOVA	{"phone": "+70615124850"}
0005434554084	BC8D17	2820 284648	PETR SOLOVEV	{"email": "petr-solovev-111969@postgrespro.ru", "phone": "+70743314173"}
0005434554085	66C424	5555 689816	PAVEL MIRONOV	{"phone": "+70366132401"}
0005434554086	8563D6	1702 687747	ALEKSEY VASILEV	{"email": "vasilev_aleksey.1976@postgrespro.ru", "phone": "+70045465306"}
0005434554087	6F0062	2751 395285	GALINA FILATOVA	{"email": "filatova-galina22021964@postgrespro.ru", "phone": "+70699163578"}
0005434554088	5E3202	1479 778639	ALEKSEY NIKITIN	{"email": "a-nikitin_23021970@postgrespro.ru", "phone": "+70607399725"}
0005434554089	4CAA66	6205 517199	NATALYA BORISOVA	{"email": "borisova_natalya-061965@postgrespro.ru", "phone": "+70245065038"}
0005434554090	4CAA66	2658 485923	OLGA MIRONOVA	{"phone": "+70050150675"}
0005434554091	D4A289	7402 506617	ALEKSEY KUZNECOV	{"phone": "+70808522946"}
0005434554092	D4A289	5784 134081	PETR KUZNECOV	{"email": "kuznecov_petr-1969@postgrespro.ru", "phone": "+70778148600"}
0005434554093	5CF8BA	5555 342472	KRISTINA NIKOLAEVA	{"phone": "+70418688710"}
0005434554094	DF6349	4780 251817	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova-1976@postgrespro.ru", "phone": "+70301136331"}
0005434554095	DF6349	9113 209760	ALEKSEY TIKHONOV	{"email": "tikhonovaleksey_26031968@postgrespro.ru", "phone": "+70149696193"}
0005434554096	DF6349	3118 857899	OLGA LAZAREVA	{"phone": "+70371331585"}
0005434554097	34B231	4219 810910	ANTONINA KONOVALOVA	{"email": "a.konovalova-1966@postgrespro.ru", "phone": "+70256395998"}
0005434554098	9D2674	3946 805408	ANATOLIY MOROZOV	{"phone": "+70750359377"}
0005434554099	464854	1939 597417	ALEKSANDR SOLOVEV	{"email": "solovev_a-26091959@postgrespro.ru", "phone": "+70381032250"}
0005434554100	464854	8488 562205	ANDREY DENISOV	{"phone": "+70779926059"}
0005434554101	5248E2	3079 275475	TATYANA FILATOVA	{"email": "t-filatova061966@postgrespro.ru", "phone": "+70275349419"}
0005434554102	5248E2	8746 375319	OLGA POTAPOVA	{"phone": "+70761162254"}
0005434554103	9E81C5	0294 487260	ANTON VOLKOV	{"email": "volkov.anton_1974@postgrespro.ru", "phone": "+70077095056"}
0005434554104	9E81C5	4745 057334	VLADISLAV KAZAKOV	{"email": "kazakov.vladislav_26101978@postgrespro.ru", "phone": "+70950344224"}
0005434554105	1B1731	6475 087435	YULIYA KUZNECOVA	{"phone": "+70054474505"}
0005434554106	1B1731	5110 439972	YURIY MOROZOV	{"phone": "+70741117517"}
0005434554107	87EEB2	2714 154762	MARINA ILINA	{"email": "ilina.m.1956@postgrespro.ru", "phone": "+70179298778"}
0005434554108	9A0453	1980 291519	VLADIMIR KUZNECOV	{"phone": "+70590529315"}
0005434554109	9A0453	8664 246467	IVAN MELNIKOV	{"email": "i_melnikov051978@postgrespro.ru", "phone": "+70932762486"}
0005434554110	1FD3E8	7401 278397	MARGARITA VASILEVA	{"phone": "+70622152627"}
0005434554111	827AFF	5332 388372	RAISA STEPANOVA	{"email": "stepanova-r021979@postgrespro.ru", "phone": "+70144795728"}
0005434554112	827AFF	8795 803860	NADEZHDA PETROVA	{"email": "petrova-nadezhda06111972@postgrespro.ru", "phone": "+70107029734"}
0005434554113	8CB0E0	2032 275458	ANDREY PAVLOV	{"email": "a.pavlov.111976@postgrespro.ru", "phone": "+70171278458"}
0005434554114	43CA9E	1886 907807	RUSLAN TARASOV	{"email": "tarasov.ruslan.091980@postgrespro.ru", "phone": "+70339925316"}
0005434554115	32A77D	0622 456482	VERA YUDINA	{"email": "v.yudina081984@postgrespro.ru", "phone": "+70532703981"}
0005434554116	5A967B	5500 166181	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova_a20021968@postgrespro.ru", "phone": "+70274559213"}
0005434554117	717EE5	4871 505410	ALBINA LEBEDEVA	{"phone": "+70446061137"}
0005434554118	A2BFA8	7445 384618	ALEKSANDR MELNIKOV	{"email": "aleksandrmelnikov-011980@postgrespro.ru", "phone": "+70925967768"}
0005434554119	A2BFA8	7283 329360	MARINA SOLOVEVA	{"phone": "+70829464561"}
0005434554120	A2BFA8	4457 657857	ELENA BORISOVA	{"email": "borisovae.12101980@postgrespro.ru", "phone": "+70275007455"}
0005434554121	31955A	9794 402304	OLESYA TIMOFEEVA	{"phone": "+70453511996"}
0005434554122	1B8AC2	6755 011393	DMITRIY NAZAROV	{"phone": "+70665602665"}
0005434554123	1B8AC2	3299 598623	SERGEY KUZNECOV	{"phone": "+70611788988"}
0005434558158	CF3FD6	8757 494047	SVETLANA POPOVA	{"phone": "+70071766082"}
0005434558215	599F00	8446 086484	ANNA PAVLOVA	{"phone": "+70408825874"}
0005434558139	C058F9	4869 590774	VITALIY KUZNECOV	{"email": "vitaliy_kuznecov.1967@postgrespro.ru", "phone": "+70146932878"}
0005434558140	1837AE	4748 284615	VALENTINA MARTYNOVA	{"phone": "+70116708754"}
0005434558141	48FBED	8689 515574	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-1968@postgrespro.ru", "phone": "+70691013449"}
0005434558142	8B4834	9726 761108	VALERIY ZAYCEV	{"email": "zaycev.v-01091968@postgrespro.ru", "phone": "+70474895769"}
0005434558143	8B4834	7288 749357	ELENA NOVIKOVA	{"phone": "+70885692855"}
0005434558144	9552A3	8019 900880	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev1964@postgrespro.ru", "phone": "+70368187860"}
0005434558145	98A608	6082 031429	STANISLAV ANDREEV	{"email": "stanislavandreev_1968@postgrespro.ru", "phone": "+70404870508"}
0005434558146	C961AA	8274 144425	EVGENIY NAUMOV	{"phone": "+70348950093"}
0005434558147	25B3B0	3834 370216	ROMAN IVANOV	{"email": "ivanovr.23031970@postgrespro.ru", "phone": "+70701131636"}
0005434558148	25B3B0	1747 308604	VLADISLAV ISAEV	{"email": "vladislavisaev.1968@postgrespro.ru", "phone": "+70398527464"}
0005434558149	442893	4273 573602	VALENTINA GAVRILOVA	{"email": "valentina-gavrilova-051979@postgrespro.ru", "phone": "+70194423548"}
0005434558150	5B567D	4217 659945	TATYANA CHERNOVA	{"email": "tatyanachernova.1975@postgrespro.ru", "phone": "+70483486617"}
0005434558151	5B567D	3279 730035	OLEG PETROV	{"email": "petrov.oleg.07011968@postgrespro.ru", "phone": "+70305254243"}
0005434558152	9B25D3	6713 083460	IRINA KOMAROVA	{"email": "irina-komarova.23111978@postgrespro.ru", "phone": "+70420744750"}
0005434558153	DB4476	3902 455341	ALEKSANDR BORISOV	{"phone": "+70353106797"}
0005434558154	DB4476	9779 375481	NADEZHDA ILINA	{"email": "nadezhda.ilina-29011977@postgrespro.ru", "phone": "+70295319219"}
0005434558155	D7E96D	1656 561998	VLADIMIR FOMIN	{"email": "v_fomin_081975@postgrespro.ru", "phone": "+70906034280"}
0005434558156	31720C	7795 871714	OLESYA KULIKOVA	{"phone": "+70680901351"}
0005434558157	293569	3515 459706	YURIY ABRAMOV	{"phone": "+70917432544"}
0005434558159	CF3FD6	3567 393848	VALENTINA ZHUKOVA	{"email": "valentina-zhukova_011960@postgrespro.ru", "phone": "+70614248559"}
0005434558160	31B4CA	9128 819635	NAILYA SIDOROVA	{"email": "n-sidorova_051968@postgrespro.ru", "phone": "+70705792422"}
0005434558161	31B4CA	4575 170456	VLADIMIR TIMOFEEV	{"email": "timofeevvladimir.03011977@postgrespro.ru", "phone": "+70813849363"}
0005434558162	578CE5	4985 338779	VALERIY POPOV	{"phone": "+70420802323"}
0005434558163	03D82A	1822 738195	VITALIY PETROV	{"email": "v_petrov_14121973@postgrespro.ru", "phone": "+70197944730"}
0005434558164	0D346C	4828 986492	EKATERINA ALEKSEEVA	{"phone": "+70116778185"}
0005434558165	0D346C	9263 836203	ELENA SMIRNOVA	{"phone": "+70036787669"}
0005434558166	178F0F	3687 433920	ELENA NIKIFOROVA	{"phone": "+70953098442"}
0005434558167	178F0F	3072 703629	NINA BOGDANOVA	{"email": "nina-bogdanova-121979@postgrespro.ru", "phone": "+70808795951"}
0005434558168	C33587	2914 497709	LYUBOV IVANOVA	{"phone": "+70275775557"}
0005434558169	C33587	9946 089450	ALEKSEY PETROV	{"email": "petrov_aleksey.101974@postgrespro.ru", "phone": "+70681806688"}
0005434558170	A1F90A	2059 276462	ALEKSEY IVANOV	{"email": "ivanov_aleksey-071970@postgrespro.ru", "phone": "+70270862016"}
0005434558171	67A9ED	9324 858515	VALERIY SOLOVEV	{"phone": "+70335400154"}
0005434558172	8C9D56	8183 030928	VIKTOR ANDREEV	{"phone": "+70827806167"}
0005434558173	8C9D56	4847 156527	VYACHESLAV SMIRNOV	{"email": "smirnov.vyacheslav-17111971@postgrespro.ru", "phone": "+70657930889"}
0005434558174	B36DC7	0136 608922	YURIY SOROKIN	{"phone": "+70872926819"}
0005434558175	4C9BE6	0002 041723	OLGA BORISOVA	{"email": "borisova_o1969@postgrespro.ru", "phone": "+70354601186"}
0005434558176	DE0FDE	8782 045912	VALENTINA PETROVA	{"email": "valentina_petrova.13031982@postgrespro.ru", "phone": "+70181802786"}
0005434558177	DE0FDE	5045 657653	NIKITA MOISEEV	{"email": "moiseev-n_1981@postgrespro.ru", "phone": "+70655638444"}
0005434558178	F6EDB0	6169 931899	OLGA KRASNOVA	{"phone": "+70050160901"}
0005434558179	F6EDB0	9087 475239	NIKITA VOLKOV	{"phone": "+70512561648"}
0005434558180	C5086A	2412 762030	NINA KOZLOVA	{"phone": "+70620804316"}
0005434558181	C5086A	2542 741695	ALEKSEY VOROBEV	{"phone": "+70127479628"}
0005434558182	765820	4605 621307	VYACHESLAV GERASIMOV	{"email": "gerasimov.v.041970@postgrespro.ru", "phone": "+70718173522"}
0005434558183	ED7B6C	7453 778699	NINA FOMINA	{"phone": "+70099975258"}
0005434558184	D0F997	8551 853601	EGOR NOVIKOV	{"phone": "+70641165438"}
0005434558185	D0F997	1807 056976	TATYANA ZHURAVLEVA	{"phone": "+70023902752"}
0005434558186	969191	0387 751963	ALLA ALEKSANDROVA	{"email": "alla-aleksandrova.1977@postgrespro.ru", "phone": "+70068390272"}
0005434558187	BE91BA	7324 497490	ANASTASIYA BORISOVA	{"phone": "+70106396815"}
0005434558188	DDB65C	2258 509271	ALEKSANDR ISAEV	{"phone": "+70672189823"}
0005434558189	DDB65C	9092 476597	NATALYA DAVYDOVA	{"email": "davydova_natalya.01071987@postgrespro.ru", "phone": "+70000240447"}
0005434558190	1BED03	2256 573716	MARINA SIDOROVA	{"email": "marina.sidorova29101977@postgrespro.ru", "phone": "+70354925354"}
0005434558191	87953D	9426 957172	MAKSIM MELNIKOV	{"phone": "+70842563902"}
0005434558192	233910	6130 298971	TAMARA FEDOROVA	{"email": "tamara.fedorova.1974@postgrespro.ru", "phone": "+70905108234"}
0005434558193	35AC84	6549 909164	VALENTINA LAZAREVA	{"phone": "+70096107673"}
0005434558194	35AC84	9123 819295	DMITRIY FEDOROV	{"email": "fedorov_dmitriy1979@postgrespro.ru", "phone": "+70189338621"}
0005434558195	DD3C6F	3841 319598	ELDAR FROLOV	{"phone": "+70120759977"}
0005434558196	AB59B2	6965 541154	VLADIMIR KOZLOV	{"email": "kozlov_vladimir_31011973@postgrespro.ru", "phone": "+70727380897"}
0005434558197	85D3AB	9948 012364	VIKTOR NIKITIN	{"phone": "+70695939392"}
0005434558198	8C9399	7222 463044	ELENA ERMAKOVA	{"phone": "+70926519944"}
0005434558199	73CF7A	5796 956985	GENNADIY NAUMOV	{"email": "gennadiy-naumov15051977@postgrespro.ru", "phone": "+70431938574"}
0005434558200	82C30C	5956 010181	VALENTINA KOROLEVA	{"email": "valentina-koroleva_111980@postgrespro.ru", "phone": "+70818412815"}
0005434558201	BDCB6E	6021 421948	ANDREY OSIPOV	{"email": "osipovandrey071974@postgrespro.ru", "phone": "+70840115616"}
0005434558202	BDCB6E	5679 200618	TATYANA FROLOVA	{"email": "t.frolova.21091978@postgrespro.ru", "phone": "+70607876874"}
0005434558203	E20A6F	9486 361779	TATYANA KUZNECOVA	{"phone": "+70757989735"}
0005434558204	0B09E6	2448 696014	ALEKSANDR ABRAMOV	{"email": "abramovaleksandr_091979@postgrespro.ru", "phone": "+70961452633"}
0005434558205	C5586C	5675 411454	GALINA NOVIKOVA	{"phone": "+70044410459"}
0005434558206	682C56	1236 616949	ALEKSANDR MEDVEDEV	{"phone": "+70471887360"}
0005434558207	E7C3B5	0908 856845	INNA GAVRILOVA	{"phone": "+70296705708"}
0005434558208	E7C3B5	7805 287328	VERA KISELEVA	{"email": "vera-kiseleva-1971@postgrespro.ru", "phone": "+70628562180"}
0005434558209	376CF7	1414 638347	SERGEY SCHERBAKOV	{"email": "sscherbakov.041975@postgrespro.ru", "phone": "+70323508386"}
0005434558210	376CF7	6144 227534	LARISA ANDREEVA	{"phone": "+70448561072"}
0005434558211	972B7D	6178 904550	EVGENIY MAKSIMOV	{"email": "maksimov.e-071977@postgrespro.ru", "phone": "+70555986371"}
0005434558212	972B7D	2689 189371	OLGA NIKOLAEVA	{"phone": "+70335796992"}
0005434558213	972B7D	6851 036342	SVETLANA FOMINA	{"email": "fomina-s1971@postgrespro.ru", "phone": "+70369869096"}
0005434558214	599F00	5860 205104	ANASTASIYA ZAKHAROVA	{"email": "a_zakharova-1982@postgrespro.ru", "phone": "+70107703752"}
0005434558216	7D5B86	5263 050092	VIKTOR SMIRNOV	{"phone": "+70003650438"}
0005434558217	7D5B86	8961 317302	ALEKSANDR KAZAKOV	{"email": "a.kazakov.1968@postgrespro.ru", "phone": "+70143625080"}
0005434558218	7D5B86	2414 508722	ELENA BOGDANOVA	{"phone": "+70992876240"}
0005434558219	1E7B1A	7602 072867	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov_21111973@postgrespro.ru", "phone": "+70714886916"}
0005434558220	9B21B5	3608 535472	OLGA ILINA	{"email": "ilina_olga041976@postgrespro.ru", "phone": "+70369137481"}
0005434558221	9B21B5	0096 691205	EKATERINA YAKOVLEVA	{"email": "eyakovleva1962@postgrespro.ru", "phone": "+70932120091"}
0005434558222	9B21B5	9772 157715	LILIYA ARKHIPOVA	{"phone": "+70794873363"}
0005434558223	3D6B9D	7443 348118	EKATERINA RODIONOVA	{"phone": "+70826127467"}
0005434558224	AF6CAF	5976 025056	OKSANA TROFIMOVA	{"phone": "+70044951376"}
0005434558225	D245F8	3308 976256	ELENA BOGDANOVA	{"email": "elena_bogdanova-25051974@postgrespro.ru", "phone": "+70958688697"}
0005434558226	D245F8	7570 510606	NIKOLAY KONOVALOV	{"phone": "+70917036961"}
0005434558227	815B96	0993 608923	LYUDMILA ZHURAVLEVA	{"email": "l.zhuravleva_1971@postgrespro.ru", "phone": "+70275185238"}
0005434558228	815B96	3361 793700	ANASTASIYA GAVRILOVA	{"email": "anastasiya.gavrilova1969@postgrespro.ru", "phone": "+70888303898"}
0005434558229	A76A04	5376 885792	RAIL MARTYNOV	{"phone": "+70783007959"}
0005434558230	8795CF	2478 242873	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir_1974@postgrespro.ru", "phone": "+70921089489"}
0005434558231	8795CF	0516 993482	ALEKSANDR ABRAMOV	{"email": "a_abramov041972@postgrespro.ru", "phone": "+70690054068"}
0005434558232	FC038C	5283 439070	SVETLANA VLASOVA	{"phone": "+70449638430"}
0005434558233	525160	8030 690574	MAKSIM PAVLOV	{"email": "pavlov_maksim_09111975@postgrespro.ru", "phone": "+70420278395"}
0005434558234	5890CD	5217 005635	KSENIYA SEMENOVA	{"email": "k_semenova_071975@postgrespro.ru", "phone": "+70725146735"}
0005434558235	5890CD	5187 545994	OLEG SOKOLOV	{"phone": "+70747671571"}
0005434558236	49EA80	6331 241673	TATYANA BORISOVA	{"email": "tborisova.1982@postgrespro.ru", "phone": "+70875705325"}
0005434558237	49EA80	1068 069018	DMITRIY IVANOV	{"email": "dmitriy-ivanov041982@postgrespro.ru", "phone": "+70142503631"}
0005434558238	49EA80	8797 051584	ELDAR KRASNOV	{"phone": "+70418967991"}
0005434558239	073BC5	8970 569142	ELENA ILINA	{"email": "ilinae_09051974@postgrespro.ru", "phone": "+70061111529"}
0005434558240	DC3E26	0477 663337	ALEKSANDR KUZMIN	{"phone": "+70957548037"}
0005434558241	DC3E26	6237 907381	ARTEM VLASOV	{"email": "vlasov_a_18071972@postgrespro.ru", "phone": "+70808630536"}
0005434558242	32585F	3953 630415	MARIYA NIKOLAEVA	{"phone": "+70031625306"}
0005434558243	32585F	7287 459880	GALINA MIRONOVA	{"phone": "+70322955877"}
0005434558244	42BBB3	1301 529370	MARINA GRISHINA	{"email": "grishina.m-31051980@postgrespro.ru", "phone": "+70982043422"}
0005434558245	694C0E	1310 902457	FAINA TARASOVA	{"email": "tarasova.f.1984@postgrespro.ru", "phone": "+70412795056"}
0005434558246	E5C0D7	0539 571921	VYACHESLAV ZAYCEV	{"email": "v_zaycev-1969@postgrespro.ru", "phone": "+70764381041"}
0005434558247	B6DD60	4305 791111	IRINA TIMOFEEVA	{"phone": "+70660773396"}
0005434558248	29964B	5598 811197	SERGEY GAVRILOV	{"phone": "+70283993947"}
0005434558249	8DC3F7	0037 483720	ALEKSEY FEDOROV	{"email": "fedorov.a1964@postgrespro.ru", "phone": "+70362061195"}
0005434558250	8DC3F7	1726 456079	NELLI FOMINA	{"phone": "+70207780877"}
0005434558251	AEE36D	4226 445876	VLADIMIR NAUMOV	{"phone": "+70744823845"}
0005434558252	AEE36D	4572 997110	VALENTINA KUZMINA	{"phone": "+70937718486"}
0005434558253	AEE36D	7590 458747	EVGENIY KRASNOV	{"phone": "+70396964159"}
0005434558254	7A74C0	5215 673793	NATALYA OVCHINNIKOVA	{"phone": "+70492116948"}
0005434558255	7A74C0	5831 451599	GALINA NIKOLAEVA	{"email": "g.nikolaeva041973@postgrespro.ru", "phone": "+70995639513"}
0005434558256	893BC7	9716 134995	ALEKSEY FROLOV	{"email": "afrolov-1987@postgrespro.ru", "phone": "+70124970956"}
0005434558257	893BC7	4755 660901	VLADISLAV FEDOTOV	{"phone": "+70097569807"}
0005434558258	6BAF7A	2543 502914	ELENA KOVALEVA	{"email": "elena-kovaleva.031971@postgrespro.ru", "phone": "+70005246130"}
0005434558259	6BAF7A	8537 084646	FARIDA NIKITINA	{"email": "f_nikitina_1982@postgrespro.ru", "phone": "+70065520571"}
0005434558260	B205A0	6574 328091	ALEKSANDR VLASOV	{"email": "vlasov_a_1970@postgrespro.ru", "phone": "+70079232299"}
0005434558261	C4C123	3778 584969	ANNA EGOROVA	{"phone": "+70735938697"}
0005434558262	C4C123	8935 109720	ALEKSANDR IVANOV	{"phone": "+70978556476"}
0005434558263	302A27	9600 427783	ALEKSANDR BELOV	{"phone": "+70617087921"}
0005434558264	7E8634	6611 271987	TAISIYA FEDOROVA	{"phone": "+70077656302"}
0005434558265	07642B	7782 932800	ALEKSEY MAKAROV	{"email": "a-makarov031961@postgrespro.ru", "phone": "+70959331905"}
0005434558266	D96EC5	3703 241299	ALEKSANDR MOROZOV	{"phone": "+70966973837"}
0005434558267	D96EC5	3154 088318	MAKSIM AFANASEV	{"email": "maksim.afanasev-071963@postgrespro.ru", "phone": "+70382272951"}
0005434558268	9AADB2	3290 125912	VALERIY IVANOV	{"phone": "+70880671990"}
0005434558269	9AADB2	9115 862180	VARVARA SOROKINA	{"phone": "+70772842706"}
0005434558270	FC8932	4455 695851	EVGENIY ZAYCEV	{"email": "zaycev_evgeniy1979@postgrespro.ru", "phone": "+70328042271"}
0005434558271	FC8932	3345 553911	SERGEY YAKOVLEV	{"phone": "+70691364092"}
0005434558272	604172	8576 573263	NINA SAVELEVA	{"email": "n_saveleva1961@postgrespro.ru", "phone": "+70688372027"}
0005434558273	604172	4466 808030	KARINA NOVIKOVA	{"email": "novikova.karina.04061974@postgrespro.ru", "phone": "+70898463035"}
0005434558274	CD509B	9144 723307	ANDREY ALEKSANDROV	{"phone": "+70862490883"}
0005434558275	CD509B	1083 675008	VIKTOR KUZNECOV	{"email": "viktor-kuznecov.061972@postgrespro.ru", "phone": "+70314615128"}
0005434558276	CD509B	8714 442605	ALEKSANDR GAVRILOV	{"phone": "+70920653134"}
0005434558277	BDB631	1427 422206	SERGEY TIMOFEEV	{"email": "timofeev-sergey_1973@postgrespro.ru", "phone": "+70701693849"}
0005434558278	6E4950	1431 225352	ILDAR RODIONOV	{"phone": "+70350623348"}
0005434558279	693CDD	9028 527213	ALEKSANDRA SOROKINA	{"phone": "+70642116661"}
0005434558280	693CDD	3606 803003	ALEKSANDR ISAEV	{"email": "isaev.aleksandr16051978@postgrespro.ru", "phone": "+70380492612"}
0005434558281	7F5217	1811 106519	SVETLANA POPOVA	{"phone": "+70517369952"}
0005434558282	BCB1E8	0209 790959	YURIY KUZNECOV	{"phone": "+70147116971"}
0005434558283	09DE28	7651 072310	EVGENIY IVANOV	{"email": "ivanov_evgeniy_03101970@postgrespro.ru", "phone": "+70378309259"}
0005434558284	D08F67	8874 588140	OLGA VASILEVA	{"email": "o_vasileva.041975@postgrespro.ru", "phone": "+70672330445"}
0005434558285	2A254D	4151 448115	ALEKSEY ROMANOV	{"phone": "+70680889768"}
0005434558286	905165	3790 836940	VALERIY NIKITIN	{"email": "nikitin.valeriy1975@postgrespro.ru", "phone": "+70540294001"}
0005434558287	632530	8660 049244	GENNADIY ZAKHAROV	{"email": "g.zakharov.1974@postgrespro.ru", "phone": "+70342555368"}
0005434558288	632530	8946 514745	GENNADIY MAKAROV	{"email": "makarovg.1975@postgrespro.ru", "phone": "+70137667801"}
0005434558289	3350F9	1413 586637	GLEB PETROV	{"phone": "+70723939275"}
0005434558290	3350F9	3971 883900	ELIZAVETA PETROVA	{"phone": "+70353976883"}
0005434558291	6BD0D4	3062 102524	NATALIYA BELOVA	{"phone": "+70989213724"}
0005434558292	6BD0D4	7567 485550	VALERIYA KOROLEVA	{"email": "korolevavaleriya-061969@postgrespro.ru", "phone": "+70348358746"}
0005434558293	ACCD88	6345 171633	VALENTINA ALEKSEEVA	{"phone": "+70780213785"}
0005434558294	ACCD88	5792 346617	NINA ALEKSANDROVA	{"email": "aleksandrovanina1980@postgrespro.ru", "phone": "+70886978744"}
0005434558295	FB5837	6516 619994	LYUDMILA MAKAROVA	{"phone": "+70007219020"}
0005434558296	F68E6D	8983 101625	SERGEY YAKOVLEV	{"email": "sergey_yakovlev1979@postgrespro.ru", "phone": "+70849513334"}
0005434558297	A7D56F	6609 494356	ROZA KOVALEVA	{"phone": "+70228290128"}
0005434558298	EAECA0	3739 293108	VIKTORIYA POLYAKOVA	{"phone": "+70618782206"}
0005434558299	07909A	9160 706604	ALEKSEY GRIGOREV	{"email": "a_grigorev18021984@postgrespro.ru", "phone": "+70522918934"}
0005434558300	A0CD47	0747 945727	LYUDMILA CHERNOVA	{"email": "lchernova1967@postgrespro.ru", "phone": "+70841043475"}
0005434558301	B82785	3527 134981	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy_031983@postgrespro.ru", "phone": "+70211190311"}
0005434558302	B82785	3026 668273	EVGENIYA KOROLEVA	{"email": "korolevae-1970@postgrespro.ru", "phone": "+70352655012"}
0005434558303	4FFDA3	0470 316769	NINA PETROVA	{"email": "petrovanina-05061976@postgrespro.ru", "phone": "+70498065732"}
0005434558304	8B8C8B	3273 943767	GALINA ARKHIPOVA	{"email": "g_arkhipova-121975@postgrespro.ru", "phone": "+70649911916"}
0005434558305	8B8C8B	4678 165203	IRINA SERGEEVA	{"email": "irina.sergeeva1969@postgrespro.ru", "phone": "+70111523592"}
0005434558306	8B8C8B	0049 401893	DARYA KOMAROVA	{"phone": "+70078924271"}
0005434558307	690D85	2108 358477	ROMAN KUDRYASHOV	{"phone": "+70154690357"}
0005434558308	690D85	6715 669764	VLADIMIR SMIRNOV	{"phone": "+70529468428"}
0005434558309	770A5B	7357 347825	RINAT KARPOV	{"phone": "+70158939787"}
0005434558310	B11264	4342 521006	ANATOLIY SERGEEV	{"phone": "+70045149352"}
0005434558311	3B52D0	3606 410172	MIKHAIL KUZMIN	{"email": "mikhailkuzmin_071974@postgrespro.ru", "phone": "+70491142629"}
0005434558312	EFB3E3	3408 220412	SOFIYA KUZNECOVA	{"email": "s-kuznecova-1974@postgrespro.ru", "phone": "+70657466999"}
0005434558313	BC9CEA	1089 152884	ANTON MOROZOV	{"phone": "+70985264083"}
0005434558314	AD80A1	7317 636156	LIDIYA ROMANOVA	{"phone": "+70328451156"}
0005434558315	0A6060	1695 755782	ZAKHAR SIDOROV	{"phone": "+70448845711"}
0005434558316	CA5A99	9228 548363	YURIY DMITRIEV	{"phone": "+70434559136"}
0005434558317	CA5A99	3958 418048	SERGEY NOVIKOV	{"phone": "+70681913499"}
0005434558318	3EEF84	0193 806385	TATYANA KUDRYASHOVA	{"phone": "+70633980201"}
0005434558319	258F04	3307 703895	VERA VASILEVA	{"phone": "+70787371979"}
0005434558320	258F04	2499 464934	ALEKSANDR SCHERBAKOV	{"phone": "+70066210353"}
0005434558321	04D20E	6426 272803	PAVEL ZAKHAROV	{"email": "p-zakharov.091974@postgrespro.ru", "phone": "+70112990877"}
0005434558322	BEA00C	7644 748425	MARINA ROMANOVA	{"email": "romanovam18031976@postgrespro.ru", "phone": "+70123971886"}
0005434558323	45D8AF	1088 367742	VALENTINA ZAKHAROVA	{"email": "valentina-zakharova_111969@postgrespro.ru", "phone": "+70514031123"}
0005434558324	175560	0823 049859	SERGEY KUZMIN	{"phone": "+70289461564"}
0005434558325	54A0A0	9922 626982	NINA ISAEVA	{"phone": "+70413783277"}
0005434558326	DEBB2D	0280 365446	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr-03081977@postgrespro.ru", "phone": "+70997032586"}
0005434558327	DEBB2D	5840 913394	ALEKSANDR GERASIMOV	{"phone": "+70923477769"}
0005434558328	969470	6225 289787	DMITRIY KONOVALOV	{"email": "dmitriy-konovalov-1966@postgrespro.ru", "phone": "+70386473375"}
0005434558329	C1D410	5650 462826	VLADIMIR FROLOV	{"phone": "+70254490028"}
0005434558330	FA32CE	0343 704031	ELENA ANDREEVA	{"phone": "+70020007364"}
0005434558331	FA32CE	9200 475820	ELENA KONOVALOVA	{"email": "elena_konovalova_1975@postgrespro.ru", "phone": "+70355281081"}
0005434558332	9E4CF3	1314 480101	SERGEY VLASOV	{"email": "sergey_vlasov.101973@postgrespro.ru", "phone": "+70448434007"}
0005434558333	9E4CF3	7630 299535	ELENA PAVLOVA	{"phone": "+70163332193"}
0005434558334	C72581	6382 714403	GALINA GUSEVA	{"email": "galina_guseva-111969@postgrespro.ru", "phone": "+70031779496"}
0005434558335	AE0D72	9595 896196	BORIS TIMOFEEV	{"email": "timofeev.b02061970@postgrespro.ru", "phone": "+70043110113"}
0005434558336	AE0D72	6969 955253	ARTEM IVANOV	{"email": "ivanov.artem.041974@postgrespro.ru", "phone": "+70958749064"}
0005434558337	E29799	3176 191826	OLGA EFREMOVA	{"email": "o.efremova_081975@postgrespro.ru", "phone": "+70239123783"}
0005434558338	7AB98B	5246 643555	ANATOLIY STEPANOV	{"email": "stepanovanatoliy22041968@postgrespro.ru", "phone": "+70943459952"}
0005434558339	D259D9	3888 964389	VITALIY POPOV	{"email": "vitaliypopov_1982@postgrespro.ru", "phone": "+70490265101"}
0005434558340	CFF0DB	4636 700313	EVGENIYA KUZNECOVA	{"email": "evgeniya-kuznecova01111966@postgrespro.ru", "phone": "+70603538434"}
0005434558341	F43659	5414 463974	NADEZHDA YAKOVLEVA	{"phone": "+70079354716"}
0005434558342	23F8EB	9966 527765	NADEZHDA NIKOLAEVA	{"email": "nadezhda-nikolaeva.1962@postgrespro.ru", "phone": "+70567300155"}
0005434558343	0EE36C	5822 620433	YURIY SHEVCHENKO	{"phone": "+70106418594"}
0005434558344	D31370	4517 299033	ANASTASIYA GERASIMOVA	{"email": "gerasimova-anastasiya-1965@postgrespro.ru", "phone": "+70058875366"}
0005434558345	DCBAD6	4197 658524	ANASTASIYA ERMAKOVA	{"email": "ermakova-anastasiya-121977@postgrespro.ru", "phone": "+70834261651"}
0005434558346	1D5018	9680 299408	MIKHAIL ALEKSANDROV	{"email": "aleksandrovmikhail.111977@postgrespro.ru", "phone": "+70844906081"}
0005434558347	5631E4	5455 879719	NADEZHDA POLYAKOVA	{"email": "n_polyakova.14011977@postgrespro.ru", "phone": "+70452643226"}
0005434558348	5631E4	1655 299560	GALINA NIKITINA	{"email": "nikitina_galina_23051977@postgrespro.ru", "phone": "+70334653515"}
0005434558349	2D7664	9218 269082	VALENTINA LOGINOVA	{"email": "v.loginova20121980@postgrespro.ru", "phone": "+70342802208"}
0005434558350	CDAB0F	8347 875251	DMITRIY ALEKSEEV	{"phone": "+70117832579"}
0005434558351	F867AD	9342 082795	MARINA KOROLEVA	{"email": "m-koroleva_16031971@postgrespro.ru", "phone": "+70009414447"}
0005434558352	3563A5	9447 954320	IRINA AFANASEVA	{"email": "afanaseva.irina_1968@postgrespro.ru", "phone": "+70413266453"}
0005434558353	DAF25E	8971 149690	SERGEY PAVLOV	{"phone": "+70478012042"}
0005434558354	63A9F2	1695 154002	ARTEMIY KOZLOV	{"phone": "+70936784494"}
0005434558355	C88C5C	3165 436124	MIKHAIL ZAYCEV	{"email": "zaycevmikhail-091986@postgrespro.ru", "phone": "+70121692564"}
0005434558356	E7E21A	7839 072500	ANTON SMIRNOV	{"phone": "+70394870190"}
0005434558357	E7E21A	7381 236367	VALENTINA KOLESNIKOVA	{"phone": "+70542353664"}
0005434558358	E7E21A	7472 930759	ANDREY EGOROV	{"phone": "+70481046422"}
0005434558359	4CEA23	8421 149303	ROMAN KAZAKOV	{"email": "r-kazakov091980@postgrespro.ru", "phone": "+70365812497"}
0005434558360	4CEA23	6895 215290	ANDREY ILIN	{"email": "ilin_andrey_041954@postgrespro.ru", "phone": "+70368336396"}
0005434558361	4CEA23	5640 019275	VALERIY IVANOV	{"phone": "+70177325741"}
0005434558362	975DC3	0092 750583	SERGEY POPOV	{"phone": "+70057124339"}
0005434558363	1EC04D	0321 050316	ELINA ABRAMOVA	{"email": "abramova.elina_121979@postgrespro.ru", "phone": "+70525140771"}
0005434558364	1EC04D	0509 312114	STANISLAV SMIRNOV	{"email": "stanislav-smirnov.1970@postgrespro.ru", "phone": "+70713101741"}
0005434558365	D0C571	8799 604466	MARIYA EGOROVA	{"phone": "+70856078986"}
0005434558366	DD1277	7705 086298	ALEKSEY SMIRNOV	{"phone": "+70405369547"}
0005434558367	DD1277	0805 051212	VASILIY RODIONOV	{"phone": "+70931787517"}
0005434558368	8AD503	4753 373671	VLADIMIR MAKAROV	{"email": "makarov_vladimir.071966@postgrespro.ru", "phone": "+70495960663"}
0005434558369	582482	1240 037099	NATALYA IVANOVA	{"email": "ivanova.natalya_1968@postgrespro.ru", "phone": "+70478800402"}
0005434558370	582482	0391 653595	LYUBOV MAKSIMOVA	{"phone": "+70178546168"}
0005434558371	D45C87	7896 130439	MARIYA MAKAROVA	{"email": "m_makarova-1968@postgrespro.ru", "phone": "+70906188420"}
0005434558372	68E564	1421 941394	VLADIMIR DENISOV	{"phone": "+70634808069"}
0005434558373	68E564	1698 136492	DMITRIY KOZLOV	{"phone": "+70928639917"}
0005434558374	D9A6CF	7764 789266	OLGA BOGDANOVA	{"phone": "+70496249658"}
0005434558375	8019FD	5058 234360	RADIK FEDOTOV	{"email": "fedotov-radik-14041979@postgrespro.ru", "phone": "+70096627056"}
0005434558376	703746	1441 834964	IRINA ZOTOVA	{"phone": "+70767255702"}
0005434558377	526BBB	3563 379042	SOFYA POTAPOVA	{"email": "s-potapova011977@postgrespro.ru", "phone": "+70725105299"}
0005434558378	F1A994	4222 496246	TAMARA ROMANOVA	{"phone": "+70350388966"}
0005434558379	81F22C	2988 953280	IGOR POPOV	{"phone": "+70416716008"}
0005434558380	81F22C	7011 247005	EKATERINA FILIPPOVA	{"email": "filippova-e-1962@postgrespro.ru", "phone": "+70975309161"}
0005434558381	4305B5	0601 623703	IRINA ANDREEVA	{"email": "irinaandreeva_061969@postgrespro.ru", "phone": "+70673465506"}
0005434558382	69064B	5242 009613	TATYANA ISAEVA	{"email": "isaeva.t1975@postgrespro.ru", "phone": "+70786701974"}
0005434558383	69064B	9685 090610	TATYANA MARTYNOVA	{"email": "martynova_t_011968@postgrespro.ru", "phone": "+70757986137"}
0005434558384	B672CC	4208 241385	VIKTORIYA ANDREEVA	{"email": "andreevaviktoriya-11011977@postgrespro.ru", "phone": "+70960236393"}
0005434558385	102E27	5202 653260	VIKTOR YAKOVLEV	{"phone": "+70544833389"}
0005434558386	4BCDC8	9678 684965	SVETLANA SMIRNOVA	{"email": "smirnova-svetlana.021976@postgrespro.ru", "phone": "+70929457435"}
0005434558387	4BCDC8	3240 390764	VLADIMIR BONDARENKO	{"phone": "+70264388718"}
0005434558388	4BCDC8	9514 217737	ANASTASIYA NIKIFOROVA	{"phone": "+70221043907"}
0005434558389	310623	1470 235278	ALINA TARASOVA	{"phone": "+70749317988"}
0005434558390	310623	6968 140666	NIKITA KONOVALOV	{"email": "konovalov.nikita08051974@postgrespro.ru", "phone": "+70814714427"}
0005434558391	CDC8FA	1061 413008	TATYANA PETROVA	{"phone": "+70370494387"}
0005434558392	CDC8FA	8687 867866	VALENTINA KULIKOVA	{"email": "vkulikova18071970@postgrespro.ru", "phone": "+70172263344"}
0005434558393	4FB873	1694 677938	SVETLANA DAVYDOVA	{"phone": "+70517113256"}
0005434558394	C18E9F	6225 006699	ROMAN BELOV	{"phone": "+70887961131"}
0005434558395	F67E97	7323 124107	SERGEY MOISEEV	{"email": "moiseev_sergey-07111979@postgrespro.ru", "phone": "+70210144183"}
0005434558396	F35A62	2631 679337	ANNA LEBEDEVA	{"email": "anna_lebedeva.111977@postgrespro.ru", "phone": "+70975886324"}
0005434558397	F35A62	2683 535504	ALEKSANDR GAVRILOV	{"phone": "+70801304887"}
0005434558398	004C69	6488 078790	TATYANA POTAPOVA	{"phone": "+70753152118"}
0005434558399	A96212	3026 750917	KLAVDIYA MOROZOVA	{"email": "kmorozova041970@postgrespro.ru", "phone": "+70188513465"}
0005434558400	66D727	0645 316188	DANILA IVANOV	{"phone": "+70171932913"}
0005434558401	2DB271	2063 728062	OLGA TIMOFEEVA	{"phone": "+70306890466"}
0005434558402	7F2ACF	7538 326985	SERGEY BONDARENKO	{"phone": "+70544304645"}
0005434558403	3325FD	7303 691536	NATALIYA KAZAKOVA	{"phone": "+70522259737"}
0005434558404	3325FD	2053 732934	TATYANA OSIPOVA	{"email": "tatyana-osipova_1964@postgrespro.ru", "phone": "+70911605744"}
0005434558405	29349E	5706 312411	ALEKSANDR OSIPOV	{"phone": "+70892814066"}
0005434558406	0D66A1	7998 148488	ILYA VASILEV	{"phone": "+70674274274"}
0005434558407	03A530	2612 743263	SOFIYA OSIPOVA	{"email": "sofiya-osipova-1978@postgrespro.ru", "phone": "+70474060156"}
0005434558408	03A530	4977 979275	ARTUR BELOV	{"email": "arturbelov031968@postgrespro.ru", "phone": "+70478672167"}
0005434558409	449C5E	5713 888524	ELENA KOLESNIKOVA	{"phone": "+70623936915"}
0005434558410	DEEA01	8649 627178	EVGENIY VOLKOV	{"phone": "+70960333871"}
0005434558411	92CAE7	7338 531586	SERGEY BARANOV	{"phone": "+70031611930"}
0005434558412	9C4C69	6799 144858	SVETLANA VLASOVA	{"email": "svetlana.vlasova-20051968@postgrespro.ru", "phone": "+70573129179"}
0005434558413	25B6C1	0856 229622	ALEKSANDRA IVANOVA	{"phone": "+70255864399"}
0005434558414	C6F1CC	1690 278078	ALEKSANDR EGOROV	{"email": "egorovaleksandr_111964@postgrespro.ru", "phone": "+70864357437"}
0005434558415	D46E44	6996 859610	IGOR TIKHONOV	{"email": "tikhonovi_031965@postgrespro.ru", "phone": "+70707166286"}
0005434558416	632A0B	6871 395818	IVAN OSIPOV	{"email": "i-osipov.1968@postgrespro.ru", "phone": "+70275828620"}
0005434558417	5768C4	6840 480733	YURIY ZAKHAROV	{"phone": "+70491704354"}
0005434558418	5768C4	5631 392854	PETR FEDOTOV	{"email": "fedotov.p1976@postgrespro.ru", "phone": "+70557646825"}
0005434558419	CEA3F8	5689 676907	MAKSIM ORLOV	{"phone": "+70851401914"}
0005434558420	0FFBF1	3126 192831	MARIYA KOLESNIKOVA	{"email": "mariya_kolesnikova1972@postgrespro.ru", "phone": "+70162094729"}
0005434558421	ACA2BF	7896 318938	ELENA NIKOLAEVA	{"phone": "+70587800771"}
0005434558422	ACA2BF	7873 372229	ALEKSANDR SAVELEV	{"email": "savelevaleksandr.06081982@postgrespro.ru", "phone": "+70200358583"}
0005434558423	BFDAB0	8549 407740	BOGDAN ABRAMOV	{"email": "bogdanabramov111974@postgrespro.ru", "phone": "+70628522270"}
0005434558424	2AB948	7752 984247	ROMAN OSIPOV	{"phone": "+70779702555"}
0005434558425	34BC6D	4170 385441	GENNADIY ALEKSEEV	{"phone": "+70642405710"}
0005434558426	95F55D	9678 299809	LYUDMILA GORBUNOVA	{"email": "l-gorbunova-011966@postgrespro.ru", "phone": "+70777152777"}
0005434558427	95F55D	1152 218808	ANASTASIYA MAKAROVA	{"email": "makarova-a.1979@postgrespro.ru", "phone": "+70681342362"}
0005434558428	33DBB4	8299 639476	DMITRIY ZAYCEV	{"email": "d_zaycev.24091969@postgrespro.ru", "phone": "+70575660854"}
0005434558429	33DBB4	5660 992076	VIKTOR YAKOVLEV	{"phone": "+70872010653"}
0005434558430	5D5B0E	7397 241436	ANNA IVANOVA	{"email": "anna-ivanova.06081965@postgrespro.ru", "phone": "+70376866667"}
0005434558431	7C03E0	8270 888927	MARGARITA SEMENOVA	{"email": "msemenova-1976@postgrespro.ru", "phone": "+70903254159"}
0005434558432	150404	3658 825224	ANNA NIKITINA	{"phone": "+70088975107"}
0005434558433	150404	4112 772537	VIKTOR SAVELEV	{"email": "viktor_savelev1975@postgrespro.ru", "phone": "+70417131697"}
0005434558434	30EAFF	2941 195708	FAINA FILATOVA	{"phone": "+70084990953"}
0005434558435	30EAFF	4918 396532	ZHANNA IVANOVA	{"email": "zhanna.ivanova1969@postgrespro.ru", "phone": "+70200143594"}
0005434558497	90CC51	7618 104925	VALENTINA LAZAREVA	{"phone": "+70997265429"}
0005434558436	C3D365	2024 484349	NINA KOLESNIKOVA	{"email": "kolesnikovan-1976@postgrespro.ru", "phone": "+70367818375"}
0005434558437	D6355C	7059 573054	NINA ROMANOVA	{"phone": "+70086565878"}
0005434558438	00C57C	6780 149313	SERGEY GRIGOREV	{"phone": "+70989428290"}
0005434558439	00C57C	7735 317682	OLEG SCHERBAKOV	{"email": "scherbakov-oleg1981@postgrespro.ru", "phone": "+70563992455"}
0005434558440	47E618	2919 647089	ELENA KUZNECOVA	{"email": "kuznecovaelena011986@postgrespro.ru", "phone": "+70847735902"}
0005434558441	47E618	3892 957064	SVETLANA IVANOVA	{"phone": "+70182544348"}
0005434558442	817DAF	2763 533782	OLEG MELNIKOV	{"phone": "+70471997671"}
0005434558443	AA1297	6511 139592	VIKTOR FEDOTOV	{"phone": "+70540354831"}
0005434558444	AA1297	9838 271439	ANDREY ANDREEV	{"email": "a_andreev_1983@postgrespro.ru", "phone": "+70887433412"}
0005434558445	AA1297	9162 947109	SERGEY ALEKSEEV	{"email": "s_alekseev041972@postgrespro.ru", "phone": "+70060356626"}
0005434558446	53A0EC	3221 382112	ALEKSEY ROMANOV	{"phone": "+70395945278"}
0005434558447	A159C5	4386 023896	INESSA NOVIKOVA	{"email": "novikovainessa-05051968@postgrespro.ru", "phone": "+70489719779"}
0005434558448	F4DCB5	1439 065622	YANA KRASNOVA	{"phone": "+70487656861"}
0005434558449	04F1DC	5003 959007	DMITRIY OSIPOV	{"email": "osipov.d-091970@postgrespro.ru", "phone": "+70488790415"}
0005434558450	04F1DC	4530 107726	TAMARA KOROLEVA	{"phone": "+70677518672"}
0005434558451	04F1DC	5946 102389	YULIYA IVANOVA	{"phone": "+70699287753"}
0005434558452	92DB5C	2944 278817	YULIYA FROLOVA	{"email": "yuliyafrolova-1965@postgrespro.ru", "phone": "+70812505163"}
0005434558453	2B77D9	4342 263292	SERGEY FOMIN	{"email": "sergey.fomin121962@postgrespro.ru", "phone": "+70950734971"}
0005434558454	2B77D9	1192 684202	VLADISLAV MAKAROV	{"phone": "+70389832190"}
0005434558455	9D73C1	4916 635157	IGOR ANTONOV	{"email": "antonovigor.031977@postgrespro.ru", "phone": "+70917245329"}
0005434558456	9D73C1	0443 531042	VIKTOR NOVIKOV	{"email": "viktor_novikov_041971@postgrespro.ru", "phone": "+70872918302"}
0005434558457	8F5F7C	3568 531743	NIKOLAY FROLOV	{"email": "n_frolov1967@postgrespro.ru", "phone": "+70045681782"}
0005434558458	81E1A6	8693 945390	ANASTASIYA FOMINA	{"phone": "+70484432230"}
0005434558459	81E1A6	7504 330442	ANASTASIYA AKIMOVA	{"email": "a_akimova021969@postgrespro.ru", "phone": "+70690182710"}
0005434558460	007A31	4420 102265	OLESYA IVANOVA	{"email": "o_ivanova.26081967@postgrespro.ru", "phone": "+70919574833"}
0005434558461	F8FC64	8530 769207	EVGENIY ZAKHAROV	{"phone": "+70012426807"}
0005434558462	A3FE18	9291 096119	EKATERINA ALEKSEEVA	{"phone": "+70882975114"}
0005434558463	9302C4	6947 521264	LYUBOV ZOTOVA	{"email": "lyubov.zotova.1976@postgrespro.ru", "phone": "+70721258661"}
0005434558464	BE15D7	0236 297828	ELENA KUZNECOVA	{"phone": "+70038144570"}
0005434558465	BE15D7	2841 386702	ANDREY GUSEV	{"phone": "+70024661029"}
0005434558466	155074	3068 928205	LEONID FROLOV	{"email": "lfrolov_051955@postgrespro.ru", "phone": "+70713137957"}
0005434558467	FB4468	5096 625101	ANDREY ILIN	{"email": "andrey.ilin.1976@postgrespro.ru", "phone": "+70012210446"}
0005434558468	7BC9C3	8658 078027	TATYANA SIDOROVA	{"email": "sidorova_t-051979@postgrespro.ru", "phone": "+70777119327"}
0005434558469	FE917B	3284 467277	ILYA ZHUKOV	{"phone": "+70952069297"}
0005434558470	FE917B	4220 342670	ANNA GORBUNOVA	{"phone": "+70796531587"}
0005434558471	38919B	4916 708173	VLADIMIR ALEKSEEV	{"phone": "+70103924807"}
0005434558472	0F362C	5591 017246	VERA ILINA	{"phone": "+70761263033"}
0005434558473	26D713	4767 193920	LYUBOV KUDRYASHOVA	{"email": "kudryashovalyubov.25011976@postgrespro.ru", "phone": "+70767661764"}
0005434558474	748C0C	8430 146408	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr-1965@postgrespro.ru", "phone": "+70850462183"}
0005434558475	FDD8E5	8477 455076	SERGEY MEDVEDEV	{"email": "sergey-medvedev.061979@postgrespro.ru", "phone": "+70785657450"}
0005434558476	CADA8E	0728 334271	YAROSLAV KOROLEV	{"phone": "+70863573280"}
0005434558477	CADA8E	5530 702706	LEONID SMIRNOV	{"email": "l.smirnov_1973@postgrespro.ru", "phone": "+70559718723"}
0005434558478	CADA8E	6969 551060	VIKTORIYA FEDOROVA	{"email": "viktoriya_fedorova-08091972@postgrespro.ru", "phone": "+70387373405"}
0005434558479	E03572	3010 117395	ALEKSANDR ILIN	{"phone": "+70564900098"}
0005434558480	57C44B	2013 177388	TATYANA IVANOVA	{"email": "tivanova1972@postgrespro.ru", "phone": "+70543163336"}
0005434558481	B9A831	7662 756738	EKATERINA EGOROVA	{"phone": "+70423933367"}
0005434558482	03C3BF	0008 455032	YULIYA FILIPPOVA	{"phone": "+70133639173"}
0005434558483	77643D	2916 529994	RUSTAM ANTONOV	{"phone": "+70049812021"}
0005434558484	77643D	3799 412903	ROMAN ZHURAVLEV	{"email": "romanzhuravlev061968@postgrespro.ru", "phone": "+70351442451"}
0005434558485	B01C4E	7733 330470	TATYANA ALEKSEEVA	{"phone": "+70821628147"}
0005434558486	F79EFF	2653 965712	EKATERINA PETROVA	{"phone": "+70362714418"}
0005434558487	0117F5	2581 352173	VLADIMIR ANDREEV	{"phone": "+70825980411"}
0005434558488	8170DD	4834 167029	IVAN KULIKOV	{"phone": "+70392433620"}
0005434558489	5CF43A	1032 124974	ALEKSANDR ZAKHAROV	{"phone": "+70852627384"}
0005434558490	8FA454	8812 541050	ANTON GORBUNOV	{"email": "gorbunov.anton01091957@postgrespro.ru", "phone": "+70289850436"}
0005434558491	C987BB	1934 882285	NINA ZAKHAROVA	{"phone": "+70931760322"}
0005434558492	66C05B	8531 664142	ANDREY KUZMIN	{"email": "kuzmin.andrey_16061969@postgrespro.ru", "phone": "+70381118124"}
0005434558493	66C05B	3197 837709	VALENTINA ZAKHAROVA	{"phone": "+70991024599"}
0005434558494	A184BD	1849 524044	ANDREY SCHERBAKOV	{"email": "scherbakov_a021971@postgrespro.ru", "phone": "+70659012744"}
0005434558495	5A237A	5902 485166	ELENA MOROZOVA	{"phone": "+70165385251"}
0005434558496	5A237A	3518 335053	VALENTINA GAVRILOVA	{"email": "v_gavrilova.29011980@postgrespro.ru", "phone": "+70412482050"}
0005434558498	6CA6F4	2332 842201	ALLA SMIRNOVA	{"phone": "+70455264283"}
0005434558499	6CA6F4	5892 059059	ALEKSANDR MIKHAYLOV	{"phone": "+70343141523"}
0005434558500	4D133F	6221 354949	ANDREY SIDOROV	{"email": "sidorovandrey04021972@postgrespro.ru", "phone": "+70723330058"}
0005434558501	094AF9	6049 644916	TAISIYA ALEKSANDROVA	{"email": "aleksandrovat071963@postgrespro.ru", "phone": "+70336828248"}
0005434558502	094AF9	9764 668225	ANASTASIYA NOVIKOVA	{"email": "anastasiya.novikova-111976@postgrespro.ru", "phone": "+70830437760"}
0005434558503	094AF9	0768 658072	SERGEY DMITRIEV	{"phone": "+70051953383"}
0005434558504	51DD5E	1250 818952	VALENTINA KARPOVA	{"email": "karpova.valentina1973@postgrespro.ru", "phone": "+70326309589"}
0005434558505	51DD5E	9003 412297	ALEKSANDR TIMOFEEV	{"email": "a-timofeev_09021963@postgrespro.ru", "phone": "+70017628632"}
0005434558506	771D2E	8933 118426	ILYA SHEVCHENKO	{"phone": "+70462482607"}
0005434558507	A8A716	3270 004061	OLGA KOROLEVA	{"email": "o.koroleva-29091972@postgrespro.ru", "phone": "+70965519832"}
0005434558508	E2E443	1978 913523	IGOR MATVEEV	{"phone": "+70268745754"}
0005434558509	0F63E5	9370 035202	OKSANA ANTONOVA	{"phone": "+70668545120"}
0005434558510	2EAEB1	9119 801206	GALINA EFREMOVA	{"phone": "+70817086824"}
0005434558511	9BF6EB	4573 368253	SERGEY ROMANOV	{"email": "romanovs091968@postgrespro.ru", "phone": "+70171130984"}
0005434558512	9BF6EB	5478 750664	SERGEY ALEKSEEV	{"email": "sergey-alekseev.041982@postgrespro.ru", "phone": "+70501362979"}
0005434558513	9BF6EB	3409 683585	EDUARD GRIGOREV	{"phone": "+70222430576"}
0005434558514	71126A	5665 081099	NATALYA MASLOVA	{"email": "n-maslova-041972@postgrespro.ru", "phone": "+70276829806"}
0005434558515	1CFB30	0610 917353	SERGEY SMIRNOV	{"email": "ssmirnov.01021967@postgrespro.ru", "phone": "+70279609561"}
0005434558516	1FB86E	5688 983371	STANISLAV SOKOLOV	{"email": "stanislav.sokolov_081974@postgrespro.ru", "phone": "+70456621539"}
0005434558517	0C7CC8	5805 943406	IGOR BORISOV	{"phone": "+70903887454"}
0005434558518	0C7CC8	3203 077704	LYUDMILA ZOTOVA	{"email": "zotova_lyudmila.091975@postgrespro.ru", "phone": "+70305897199"}
0005434558519	2A8AA6	4045 179087	LYUDMILA TITOVA	{"phone": "+70231987058"}
0005434558520	C57F59	2523 900257	NIKOLAY TIMOFEEV	{"phone": "+70593724794"}
0005434558521	C57F59	8163 546431	NIKOLAY GORBUNOV	{"email": "gorbunov.nikolay-061977@postgrespro.ru", "phone": "+70194889873"}
0005434558522	4DE468	9955 859868	NATALYA PETROVA	{"phone": "+70948825098"}
0005434558523	68238D	5580 340691	PAVEL KAZAKOV	{"email": "kazakov.p_14081968@postgrespro.ru", "phone": "+70826406646"}
0005434558524	B77A14	2154 391018	EDUARD SOKOLOV	{"phone": "+70974818485"}
0005434558525	2D0399	6482 613247	VALERIYA LAZAREVA	{"email": "valeriya-lazareva-13021971@postgrespro.ru", "phone": "+70701455844"}
0005434558526	316B6D	9465 535601	ANASTASIYA VASILEVA	{"email": "vasilevaa091964@postgrespro.ru", "phone": "+70041598139"}
0005434558527	6BA7BC	2273 562321	TIMUR FEDOROV	{"email": "fedorov.timur_1980@postgrespro.ru", "phone": "+70137031399"}
0005434558528	2F38DD	3360 036686	SVETLANA NESTEROVA	{"phone": "+70097687066"}
0005434558529	47DF20	0941 919497	TATYANA MARTYNOVA	{"phone": "+70928513302"}
0005434558530	52E767	2471 577191	ALEKSANDR FEDOROV	{"phone": "+70316033428"}
0005434558531	E20594	6059 034751	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr.091980@postgrespro.ru", "phone": "+70733338067"}
0005434558532	C49515	6546 123527	YURIY NIKITIN	{"email": "nikitin.yuriy1959@postgrespro.ru", "phone": "+70850521309"}
0005434558533	38D9DA	4045 109906	EMIL NIKITIN	{"email": "nikitinemil_051971@postgrespro.ru", "phone": "+70841099790"}
0005434558534	735383	6566 583516	KLAVDIYA BELOVA	{"email": "klavdiyabelova_07121965@postgrespro.ru", "phone": "+70297850757"}
0005434558535	735383	1677 081808	PETR SCHERBAKOV	{"phone": "+70955580374"}
0005434558536	59B77D	8831 212524	ZINAIDA MOISEEVA	{"email": "zinaida.moiseeva011980@postgrespro.ru", "phone": "+70976895758"}
0005434558537	30F98D	9725 591307	DMITRIY SEMENOV	{"phone": "+70741450594"}
0005434558538	F7011D	9928 984510	YURIY ZAKHAROV	{"email": "y-zakharov-08021979@postgrespro.ru", "phone": "+70776754621"}
0005434558539	F7011D	5756 452723	NINA IVANOVA	{"phone": "+70683765986"}
0005434558540	523E29	6538 886781	FARIT BELOV	{"email": "farit_belov_1957@postgrespro.ru", "phone": "+70268757896"}
0005434558541	523E29	7700 154679	EVGENIY BORISOV	{"email": "evgeniy-borisov27061966@postgrespro.ru", "phone": "+70798929168"}
0005434558542	B5E6D2	9353 831407	ANDREY SCHERBAKOV	{"phone": "+70178225572"}
0005434558543	12AD32	9543 531038	VERA KOZLOVA	{"phone": "+70019578197"}
0005434558544	C68105	3273 444491	YULIYA DAVYDOVA	{"phone": "+70721308680"}
0005434558545	A3A807	6751 485546	LYUBOV PAVLOVA	{"email": "pavlova.l-27051961@postgrespro.ru", "phone": "+70555234362"}
0005434558546	48F335	6325 875550	ANASTASIYA GERASIMOVA	{"email": "anastasiya.gerasimova.071970@postgrespro.ru", "phone": "+70490367732"}
0005434558547	AC9C27	9367 861451	EKATERINA KAZAKOVA	{"phone": "+70180459879"}
0005434558548	726EBA	7741 358248	TATYANA TROFIMOVA	{"phone": "+70344282399"}
0005434558549	993223	8682 337180	OLEG MAKAROV	{"email": "makarov_oleg13021981@postgrespro.ru", "phone": "+70263728371"}
0005434558550	AB958B	5813 369779	MURAD GRIGOREV	{"email": "murad_grigorev.25021969@postgrespro.ru", "phone": "+70940016850"}
0005434558551	0487CA	9167 434989	ALEKSANDR SOROKIN	{"phone": "+70748277161"}
0005434558552	00D309	7250 359825	STANISLAV KAZAKOV	{"phone": "+70586741826"}
0005434558553	00D309	1678 789864	PELAGEYA VOLKOVA	{"phone": "+70934568271"}
0005434558554	B6024A	7806 297425	SERGEY KUZNECOV	{"email": "kuznecov-s.13021964@postgrespro.ru", "phone": "+70385731644"}
0005434558555	B6024A	6694 678771	ELENA MAKAROVA	{"email": "emakarova-06101976@postgrespro.ru", "phone": "+70940476370"}
0005434558556	B6024A	7288 635066	TAMARA KOZLOVA	{"email": "tamara.kozlova-29111970@postgrespro.ru", "phone": "+70387041942"}
0005434558557	48BFC3	1765 588466	ELENA KOVALEVA	{"phone": "+70918667607"}
0005434558558	48BFC3	3376 262730	VALENTINA POPOVA	{"email": "v-popova-1969@postgrespro.ru", "phone": "+70030273911"}
0005434558559	EBFFF7	5040 975639	YURIY KONOVALOV	{"email": "konovalov-y.26011979@postgrespro.ru", "phone": "+70939074118"}
0005434558560	29DC8B	6424 013275	OLEG FEDOROV	{"phone": "+70673691033"}
0005434558561	BCCEB6	0930 407631	TATYANA IVANOVA	{"phone": "+70564613388"}
0005434558562	D5A047	2141 367680	SERGEY KULIKOV	{"email": "sergeykulikov1964@postgrespro.ru", "phone": "+70674850424"}
0005434558563	D5A047	2799 226044	ANASTASIYA NAUMOVA	{"email": "naumova.anastasiya_19011966@postgrespro.ru", "phone": "+70943663466"}
0005434558564	DB2A4D	0428 076879	ANDREY NOVIKOV	{"email": "andrey.novikov.1979@postgrespro.ru", "phone": "+70862556654"}
0005434558565	DB2A4D	0462 787857	EKATERINA NIKITINA	{"phone": "+70504319422"}
0005434558566	E58CE7	1164 191876	ELIZAVETA TIKHONOVA	{"phone": "+70649063726"}
0005434558567	E58CE7	9055 596835	ALEKSEY VLASOV	{"email": "aleksey-vlasov-07101972@postgrespro.ru", "phone": "+70360547029"}
0005434558568	5FD48D	8471 797333	EVGENIY EGOROV	{"phone": "+70349193684"}
0005434558569	5FD48D	6925 229497	VALERIY FROLOV	{"email": "frolov.v-03051975@postgrespro.ru", "phone": "+70480485058"}
0005434558570	B7BBB8	3708 911616	ROMAN MIRONOV	{"phone": "+70226781498"}
0005434558571	DC70CB	5028 228247	ZARINA MASLOVA	{"email": "maslovaz-18041974@postgrespro.ru", "phone": "+70232701795"}
0005434558572	6D28B7	2525 697207	PAVEL TARASOV	{"email": "ptarasov_031979@postgrespro.ru", "phone": "+70736480955"}
0005434558573	6D28B7	4356 649588	OLGA KOLESNIKOVA	{"email": "o_kolesnikova1970@postgrespro.ru", "phone": "+70140970259"}
0005434558574	6D28B7	1585 920382	ANNA TARASOVA	{"email": "tarasova.a_061972@postgrespro.ru", "phone": "+70662566313"}
0005434558575	0994CA	5899 518406	OLGA KUZNECOVA	{"phone": "+70192793221"}
0005434558576	0994CA	0646 874394	RAILYA DENISOVA	{"phone": "+70362849022"}
0005434558577	CD35EB	5236 935487	VASILIY FEDOTOV	{"email": "v-fedotov_111975@postgrespro.ru", "phone": "+70411479817"}
0005434558578	E41468	1183 228387	VLADISLAV SERGEEV	{"email": "v-sergeev11081976@postgrespro.ru", "phone": "+70095555749"}
0005434558579	5F36EE	4686 046694	IRINA GAVRILOVA	{"email": "gavrilova_irina_101979@postgrespro.ru", "phone": "+70520806629"}
0005434558580	F3556E	1481 840972	DENIS POPOV	{"phone": "+70283692870"}
0005434558581	DDFCBD	2298 233469	NATALYA BORISOVA	{"phone": "+70151194743"}
0005434558582	0E1EF1	9665 424079	GEORGIY PETROV	{"phone": "+70877244039"}
0005434558583	0E1EF1	2723 063961	ALEKSEY YAKOVLEV	{"email": "yakovlev_aleksey_01071972@postgrespro.ru", "phone": "+70038581173"}
0005434558584	71314E	0762 231885	VLADIMIR ZAKHAROV	{"phone": "+70320187982"}
0005434558585	4105D1	9348 280509	NIKOLAY POPOV	{"email": "n-popov.21031977@postgrespro.ru", "phone": "+70421108284"}
0005434558586	C64A1D	2772 722883	TATYANA BARANOVA	{"phone": "+70499583086"}
0005434558587	C7046B	2898 147975	MARGARITA VASILEVA	{"email": "margaritavasileva16031976@postgrespro.ru", "phone": "+70030061546"}
0005434558588	0830D4	2708 228958	ROMAN FILIPPOV	{"email": "roman_filippov-071975@postgrespro.ru", "phone": "+70023550682"}
0005434558589	082709	2671 051466	VLADIMIR KONOVALOV	{"phone": "+70767920907"}
0005434558590	082709	0912 536780	LYUBOV PETROVA	{"email": "petrova.lyubov1968@postgrespro.ru", "phone": "+70209969090"}
0005434558591	657115	0134 734774	EKATERINA ALEKSANDROVA	{"phone": "+70473932728"}
0005434558592	8FF889	3578 899423	VALENTINA MOISEEVA	{"phone": "+70822168889"}
0005434558593	11AF00	4492 835843	MAKSIM STEPANOV	{"email": "m.stepanov.22101965@postgrespro.ru", "phone": "+70587989931"}
0005434558594	A3F03E	0157 849478	LARISA KOMAROVA	{"email": "komarova_l_08071976@postgrespro.ru", "phone": "+70640302705"}
0005434558595	1B0687	9968 772792	VALENTIN SAVELEV	{"phone": "+70326923895"}
0005434558596	1B0687	3433 707274	ELMIRA ARKHIPOVA	{"phone": "+70212520948"}
0005434558597	597570	8775 275768	VALERIY GERASIMOV	{"email": "valeriygerasimov.1962@postgrespro.ru", "phone": "+70285988486"}
0005434558598	645F9A	4917 283919	GENNADIY GRIGOREV	{"phone": "+70153105376"}
0005434558599	7F4F6D	5606 587367	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr25021976@postgrespro.ru", "phone": "+70082566238"}
0005434558600	96098B	1971 413850	EVGENIY PETROV	{"email": "evgeniypetrov_061973@postgrespro.ru", "phone": "+70927056444"}
0005434558601	96098B	6900 984047	ALEKSANDRA NIKOLAEVA	{"phone": "+70750238986"}
0005434558602	216A34	4980 673035	SERGEY ZAKHAROV	{"email": "s.zakharov20011962@postgrespro.ru", "phone": "+70987253680"}
0005434558603	B1C53C	5148 973980	MIKHAIL GORBUNOV	{"email": "gorbunov_mikhail.041966@postgrespro.ru", "phone": "+70841616654"}
0005434558604	945633	3973 440583	OLGA STEPANOVA	{"email": "stepanova-o.1973@postgrespro.ru", "phone": "+70948493007"}
0005434558605	945633	2322 334740	DANIIL KARPOV	{"email": "daniil_karpov-081975@postgrespro.ru", "phone": "+70819533459"}
0005434558606	8080F9	9319 623930	YURIY BARANOV	{"phone": "+70224215752"}
0005434558607	90ACD3	5494 632026	ANDREY KUZNECOV	{"email": "kuznecova_17111979@postgrespro.ru", "phone": "+70096981734"}
0005434558608	92AC11	8330 704527	MARINA ALEKSEEVA	{"email": "marina-alekseeva031976@postgrespro.ru", "phone": "+70147113565"}
0005434558609	5271F8	8881 375388	VLADIMIR KONOVALOV	{"phone": "+70573346540"}
0005434558610	F8E764	1571 932476	VADIM PAVLOV	{"email": "pavlov_vadim-061974@postgrespro.ru", "phone": "+70315828061"}
0005434558611	F8E764	3067 704819	ALEKSANDR SHEVCHENKO	{"phone": "+70837709044"}
0005434558612	1F15CC	7843 652439	MIKHAIL STEPANOV	{"email": "stepanovm.101976@postgrespro.ru", "phone": "+70847911982"}
0005434558613	9B8360	3563 877317	NIKOLAY KUZMIN	{"email": "n-kuzmin-04071975@postgrespro.ru", "phone": "+70340390315"}
0005434558614	9B8360	6134 126453	ROMAN ZAKHAROV	{"email": "roman-zakharov_011985@postgrespro.ru", "phone": "+70340257311"}
0005434558615	F3EDD5	9754 152746	ANTONINA KUZNECOVA	{"email": "kuznecova-a_1971@postgrespro.ru", "phone": "+70795640607"}
0005434558616	F3EDD5	1667 269233	DENIS SHEVCHENKO	{"email": "denisshevchenko121974@postgrespro.ru", "phone": "+70655949559"}
0005434558617	F3EDD5	8206 010687	NAILYA SCHERBAKOVA	{"phone": "+70038408303"}
0005434558618	ECF09A	2274 721705	VALENTIN IVANOV	{"email": "ivanov_v_02041974@postgrespro.ru", "phone": "+70589438518"}
0005434559105	5F698E	1049 093195	DANIIL SEMENOV	{"phone": "+70842981642"}
0005434559106	6288F3	9787 946606	KSENIYA KONOVALOVA	{"phone": "+70901423722"}
0005434559082	F3F4DC	9109 521485	SERGEY VOLKOV	{"email": "sergey_volkov.101982@postgrespro.ru", "phone": "+70150820536"}
0005434559083	36781B	5893 266919	GEORGIY KISELEV	{"email": "georgiy_kiselev1978@postgrespro.ru", "phone": "+70673135011"}
0005434559084	614ACA	9979 395901	DMITRIY POPOV	{"email": "dmitriy.popov_1964@postgrespro.ru", "phone": "+70487692764"}
0005434559085	414A29	7239 940453	YULIYA TIKHONOVA	{"phone": "+70350722080"}
0005434559086	414A29	2939 338286	GALINA SCHERBAKOVA	{"email": "scherbakova.galina.01081968@postgrespro.ru", "phone": "+70575388909"}
0005434559087	414A29	5071 346138	YULIYA BOGDANOVA	{"email": "y_bogdanova081971@postgrespro.ru", "phone": "+70210973213"}
0005434559088	04A4EF	2715 428440	ALEKSANDR ANDREEV	{"email": "andreevaleksandr011980@postgrespro.ru", "phone": "+70134853123"}
0005434559089	04A4EF	0291 428244	EDUARD KUZNECOV	{"email": "kuznecoveduard1987@postgrespro.ru", "phone": "+70922832136"}
0005434559090	BC7E6C	3825 103174	OLGA PETROVA	{"email": "petrovao1968@postgrespro.ru", "phone": "+70839781287"}
0005434559091	81C59C	0741 386192	GALINA KOZLOVA	{"phone": "+70355610292"}
0005434559092	369FF7	8379 870734	IGOR IVANOV	{"phone": "+70974216611"}
0005434559093	38E90D	3125 752618	ANTONINA FILIPPOVA	{"email": "antoninafilippova041968@postgrespro.ru", "phone": "+70882674825"}
0005434559094	38E90D	0063 624744	SERGEY KUZMIN	{"email": "s-kuzmin011981@postgrespro.ru", "phone": "+70638158436"}
0005434559095	FFC81E	6731 927266	VALERIY KUZNECOV	{"email": "valeriy.kuznecov-111974@postgrespro.ru", "phone": "+70766854371"}
0005434559096	9899B1	9499 123506	ALSU KUDRYASHOVA	{"email": "alsu.kudryashova.18111965@postgrespro.ru", "phone": "+70116669219"}
0005434559097	07F37C	3709 864315	ANNA ROMANOVA	{"email": "a.romanova.13111970@postgrespro.ru", "phone": "+70193035297"}
0005434559098	7C2423	7672 492271	NINA ANISIMOVA	{"phone": "+70545917133"}
0005434559099	7C2423	9434 770352	NATALYA FEDOROVA	{"email": "nfedorova16071962@postgrespro.ru", "phone": "+70498464157"}
0005434559100	58E9F4	7792 050521	SERGEY VOLKOV	{"email": "volkov.s_13121969@postgrespro.ru", "phone": "+70649128482"}
0005434559101	58E9F4	3653 890939	TATYANA YAKOVLEVA	{"email": "tatyana_yakovleva.1966@postgrespro.ru", "phone": "+70944607632"}
0005434559102	B2D021	1307 102613	ANDREY AFANASEV	{"email": "andrey_afanasev28081960@postgrespro.ru", "phone": "+70322020392"}
0005434559103	C9BF7E	6135 218800	DARYA TIMOFEEVA	{"phone": "+70851945782"}
0005434559104	8363A8	6156 960187	KLAVDIYA MASLOVA	{"phone": "+70747333374"}
0005434559107	B47EE4	4357 331817	OLGA NOVIKOVA	{"email": "olga.novikova1967@postgrespro.ru", "phone": "+70248942474"}
0005434559108	34DEDD	6485 861124	ALBINA KOROLEVA	{"phone": "+70790288298"}
0005434559109	34DEDD	9423 337594	SERGEY RODIONOV	{"email": "s-rodionov_06091969@postgrespro.ru", "phone": "+70711675196"}
0005434559110	4CBFE3	1211 329275	ALEKSEY MOISEEV	{"phone": "+70960741875"}
0005434559111	4CBFE3	0476 276308	MARIYA ZOTOVA	{"email": "zotova-mariya01041979@postgrespro.ru", "phone": "+70937587806"}
0005434559112	8B0C50	3053 993961	ZULFIYA AFANASEVA	{"email": "zulfiya_afanaseva1974@postgrespro.ru", "phone": "+70261814278"}
0005434559113	55BF1F	3426 980120	ANDREY BELOV	{"phone": "+70937590526"}
0005434559114	AD013A	3371 963413	TATYANA FOMINA	{"phone": "+70578871201"}
0005434559115	D26268	7156 879304	TATYANA DANILOVA	{"email": "tatyana-danilova-26051984@postgrespro.ru", "phone": "+70632751728"}
0005434559116	092E68	3049 984735	NATALYA IVANOVA	{"email": "ivanova_n_09041977@postgrespro.ru", "phone": "+70729095161"}
0005434559117	84B64C	8907 680851	VLADIMIR FEDOROV	{"phone": "+70964294842"}
0005434559118	84B64C	2129 388833	NINA LAZAREVA	{"phone": "+70329127970"}
0005434559119	9C3E3A	6601 274399	VIKTOR RODIONOV	{"email": "rodionovv-25111969@postgrespro.ru", "phone": "+70501575368"}
0005434559120	B31D2D	6841 517872	VERA CHERNOVA	{"email": "vera.chernova1969@postgrespro.ru", "phone": "+70497618097"}
0005434559121	86DAB0	9744 114309	NINA NIKOLAEVA	{"phone": "+70459586309"}
0005434559122	DE574A	1122 145701	ELENA DANILOVA	{"email": "elena.danilova_021977@postgrespro.ru", "phone": "+70952964661"}
0005434559123	DE574A	6474 586603	SVETLANA SAVELEVA	{"phone": "+70235537331"}
0005434559124	EEFB5F	4497 402404	MIKHAIL MEDVEDEV	{"phone": "+70205516442"}
0005434559125	3CC1C4	1482 680423	VLADIMIR SOROKIN	{"phone": "+70334672441"}
0005434559126	39D085	5184 077367	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya-1964@postgrespro.ru", "phone": "+70425479629"}
0005434559127	2F6C17	4653 725607	VLADIMIR RODIONOV	{"phone": "+70984507840"}
0005434559128	2F6C17	7402 956340	EVGENIY YAKOVLEV	{"email": "yakovlev.evgeniy_1970@postgrespro.ru", "phone": "+70996223619"}
0005434559129	8B52DA	7086 312176	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov20101969@postgrespro.ru", "phone": "+70201839015"}
0005434559130	69BD97	2529 036798	ALEKSEY FROLOV	{"phone": "+70296769971"}
0005434559131	A9481F	3459 616988	NADEZHDA SMIRNOVA	{"email": "n.smirnova.12121977@postgrespro.ru", "phone": "+70111063142"}
0005434559132	5B299F	6294 530942	ALEKSANDR ALEKSEEV	{"email": "alekseeva1976@postgrespro.ru", "phone": "+70669442043"}
0005434559133	5B299F	3594 283134	ALFIYA SCHERBAKOVA	{"email": "alfiya_scherbakova_081973@postgrespro.ru", "phone": "+70931607158"}
0005434559134	5B299F	1070 848124	NIKOLAY KOROLEV	{"phone": "+70213142267"}
0005434559135	FD4C09	4393 726181	DAMIR FEDOROV	{"phone": "+70539831247"}
0005434559136	B9DC58	2293 044743	ALEKSANDR ISAEV	{"email": "isaeva-13021961@postgrespro.ru", "phone": "+70505713077"}
0005434559137	B9DC58	4453 523986	EGOR OSIPOV	{"email": "osipov_egor_1959@postgrespro.ru", "phone": "+70907929400"}
0005434559138	DE11DF	1923 106950	NIKOLAY FEDOROV	{"phone": "+70871698834"}
0005434559139	DE11DF	7263 683815	YURIY SCHERBAKOV	{"email": "y.scherbakov.1978@postgrespro.ru", "phone": "+70887376727"}
0005434559140	4B1554	4219 734397	VALENTINA SMIRNOVA	{"email": "smirnova-v071960@postgrespro.ru", "phone": "+70114378678"}
0005434559141	E3E19E	3218 486560	ALEKSANDR FROLOV	{"phone": "+70627121299"}
0005434559142	E3E19E	8231 911080	ANASTASIYA AKIMOVA	{"email": "aakimova_11101965@postgrespro.ru", "phone": "+70158784703"}
0005434559143	1A63DA	6008 621775	YURIY IVANOV	{"phone": "+70901182007"}
0005434559144	B4A6F2	2933 461041	LARISA VASILEVA	{"phone": "+70363431029"}
0005434559145	A991E1	1216 666938	ZINAIDA DENISOVA	{"phone": "+70748898314"}
0005434559146	A991E1	9964 197207	GLEB PETROV	{"phone": "+70599541151"}
0005434559147	C66751	8525 208330	NATALYA TARASOVA	{"email": "tarasova_n-13101979@postgrespro.ru", "phone": "+70911529932"}
0005434559148	1404B1	5670 600549	LYUDMILA BOGDANOVA	{"phone": "+70976856831"}
0005434559149	9598B4	6787 298409	MIKHAIL DMITRIEV	{"phone": "+70268783709"}
0005434559150	9598B4	8018 328781	ARSENIY YAKOVLEV	{"email": "yakovlev-a061965@postgrespro.ru", "phone": "+70433913948"}
0005434559151	9598B4	5531 437347	YULIYA KOROLEVA	{"email": "korolevay.12121974@postgrespro.ru", "phone": "+70758344939"}
0005434559152	8DAEBC	3941 397563	DMITRIY SCHERBAKOV	{"phone": "+70244329012"}
0005434559153	8DAEBC	2620 669649	VIKTOR MAKAROV	{"phone": "+70315264555"}
0005434559154	00970E	7960 410303	VALERIY ISAEV	{"email": "isaev-valeriy.09021961@postgrespro.ru", "phone": "+70415275065"}
0005434559155	00970E	1599 019881	MIKHAIL ZHUKOV	{"phone": "+70466062131"}
0005434559156	00970E	7641 395843	ELENA GUSEVA	{"phone": "+70226326144"}
0005434559157	88B63E	2675 327559	GALINA SEMENOVA	{"email": "semenovagalina-1965@postgrespro.ru", "phone": "+70076178717"}
0005434559158	DB4058	0551 004116	MARIYA EGOROVA	{"phone": "+70379671211"}
0005434559159	DB2861	5853 278174	GALINA TARASOVA	{"email": "g.tarasova09061973@postgrespro.ru", "phone": "+70664451700"}
0005434559160	15476C	7166 030655	DAVID PETROV	{"email": "d-petrov_14061978@postgrespro.ru", "phone": "+70573092644"}
0005434559161	4AE1AB	1402 551160	MARIYA ROMANOVA	{"email": "m-romanova_101972@postgrespro.ru", "phone": "+70962666747"}
0005434559162	4AE1AB	6623 392205	PAVEL KAZAKOV	{"email": "kazakov_pavel_1978@postgrespro.ru", "phone": "+70678623929"}
0005434559163	4AE1AB	8560 427020	ANTON MIKHAYLOV	{"phone": "+70281246948"}
0005434559164	DC5A1F	1495 313248	ELENA EGOROVA	{"email": "egorova-elena-041984@postgrespro.ru", "phone": "+70524198384"}
0005434559165	D94011	0949 450323	VALENTINA POTAPOVA	{"email": "potapova.v-28041978@postgrespro.ru", "phone": "+70854594764"}
0005434559166	D9A95B	2488 418264	LYUDMILA EGOROVA	{"email": "egorova.l011971@postgrespro.ru", "phone": "+70260868055"}
0005434559167	7920BB	2061 004836	LEONID NIKOLAEV	{"email": "nikolaev.l-1969@postgrespro.ru", "phone": "+70909477606"}
0005434559168	7920BB	6320 248717	VALENTINA DENISOVA	{"phone": "+70990120541"}
0005434559169	C479B2	7194 234926	ANASTASIYA FROLOVA	{"phone": "+70431908110"}
0005434559170	239EE9	8388 760873	IRINA NAUMOVA	{"email": "i.naumova-1967@postgrespro.ru", "phone": "+70624968583"}
0005434559171	EBDD31	0338 872219	SVETLANA SOKOLOVA	{"phone": "+70684236158"}
0005434559172	A7FB51	0054 778476	IVAN DAVYDOV	{"email": "davydovi_041968@postgrespro.ru", "phone": "+70285632700"}
0005434559173	09D737	6910 978667	TATYANA ILINA	{"email": "ilina_tatyana_031967@postgrespro.ru", "phone": "+70714370145"}
0005434559174	D74B0D	5674 069595	VYACHESLAV KUDRYASHOV	{"email": "vyacheslav_kudryashov.1971@postgrespro.ru", "phone": "+70065874527"}
0005434559175	D74B0D	5360 428594	MARIYA ANISIMOVA	{"email": "anisimova.mariya-08071963@postgrespro.ru", "phone": "+70733108376"}
0005434559176	18BD0E	8091 200520	ANTON AFANASEV	{"phone": "+70632304020"}
0005434559177	DD239C	7600 090532	YULIYA ALEKSEEVA	{"email": "alekseeva.y1979@postgrespro.ru", "phone": "+70794865212"}
0005434559178	DD239C	2771 417700	ADELINA POTAPOVA	{"phone": "+70196406089"}
0005434559179	8331D6	7858 254392	NATALYA KULIKOVA	{"phone": "+70649435148"}
0005434559180	8331D6	2684 917062	MAKSIM MAKAROV	{"email": "makarovm.1966@postgrespro.ru", "phone": "+70667413979"}
0005434559181	17C4EF	4500 290511	MIKHAIL AFANASEV	{"email": "afanasev.m-21091974@postgrespro.ru", "phone": "+70819455759"}
0005434559182	7E64B1	0029 345471	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrova-aleksandra_08051979@postgrespro.ru", "phone": "+70079312692"}
0005434559183	7E64B1	0180 762904	KSENIYA OVCHINNIKOVA	{"email": "ovchinnikova-kseniya-1966@postgrespro.ru", "phone": "+70319994253"}
0005434559184	CBF196	1084 427075	GALINA NESTEROVA	{"email": "g-nesterova1976@postgrespro.ru", "phone": "+70426945483"}
0005434559185	6CF00B	1645 808563	RAFAEL OSIPOV	{"phone": "+70510494743"}
0005434559186	907B1C	0647 372134	ZULFIYA ILINA	{"email": "ilina-z1975@postgrespro.ru", "phone": "+70191945852"}
0005434559187	E9CF59	6018 988172	ANTONINA YAKOVLEVA	{"phone": "+70461801519"}
0005434559188	C33298	9793 795872	DIANA KUZNECOVA	{"email": "kuznecova_d-14061973@postgrespro.ru", "phone": "+70343702749"}
0005434559189	C33298	9563 446427	OLGA MOROZOVA	{"phone": "+70939883237"}
0005434559190	D1E5D4	2198 267630	LYUBOV RYABOVA	{"email": "lyubov-ryabova_1975@postgrespro.ru", "phone": "+70956091763"}
0005434559191	538D5F	9519 311852	LYUDMILA POTAPOVA	{"phone": "+70899816375"}
0005434559192	538D5F	7398 728128	NIKOLAY KUZMIN	{"email": "nikolaykuzmin-18041969@postgrespro.ru", "phone": "+70287800088"}
0005434559193	32F25C	6463 249245	YURIY ILIN	{"phone": "+70971157645"}
0005434559194	32F25C	6989 323498	ALEKSEY BELOV	{"email": "belov-aleksey05081968@postgrespro.ru", "phone": "+70493987783"}
0005434559195	32F25C	1126 527029	SVETLANA KUZNECOVA	{"email": "kuznecovasvetlana-08061985@postgrespro.ru", "phone": "+70961159003"}
0005434565677	6A6890	7593 713100	MAKSIM KAZAKOV	{"email": "kazakov.maksim-1971@postgrespro.ru", "phone": "+70458961427"}
0005434565678	3E9805	7092 052605	ALEKSANDR POPOV	{"email": "popov.a101960@postgrespro.ru", "phone": "+70404449751"}
0005434565679	3E9805	9000 585560	OKSANA MARTYNOVA	{"email": "martynova_o18051976@postgrespro.ru", "phone": "+70379941960"}
0005434565680	524E99	3519 979094	ELENA PETROVA	{"phone": "+70262956004"}
0005434565681	524E99	0237 834947	ANTONINA VLASOVA	{"phone": "+70351062648"}
0005434565682	7E03DD	3340 067589	OLESYA KOZLOVA	{"phone": "+70254937018"}
0005434565683	7EFE32	9932 186858	VLADISLAV TARASOV	{"email": "tarasov-vladislav1976@postgrespro.ru", "phone": "+70675261566"}
0005434565684	7EFE32	2572 315049	ANTON IVANOV	{"phone": "+70829556138"}
0005434565685	7EFE32	6209 471410	LIDIYA ZAYCEVA	{"email": "l-zayceva_09021976@postgrespro.ru", "phone": "+70771960861"}
0005434565686	C524B4	4567 155367	ELENA BARANOVA	{"email": "elena.baranova-081968@postgrespro.ru", "phone": "+70848505129"}
0005434565687	7DB61D	5657 828223	VLADIMIR BORISOV	{"phone": "+70828845300"}
0005434565688	7DB61D	7860 352882	LYUCIYA ZAYCEVA	{"phone": "+70337393961"}
0005434565689	466CE9	3193 156371	GALINA KARPOVA	{"email": "karpovagalina.1961@postgrespro.ru", "phone": "+70951161524"}
0005434565690	DC9368	0750 258128	VITALIY KARPOV	{"phone": "+70672496433"}
0005434565691	DC9368	4719 478204	MIKHAIL TIMOFEEV	{"email": "timofeev_mikhail.22051975@postgrespro.ru", "phone": "+70129335396"}
0005434565692	39FF22	7444 996182	ROMAN POPOV	{"email": "roman.popov.04061969@postgrespro.ru", "phone": "+70361880543"}
0005434565693	F8FA03	2278 318119	NINA KOZLOVA	{"phone": "+70641696830"}
0005434565694	1CFB8C	7454 458006	ANATOLIY NOVIKOV	{"phone": "+70717587307"}
0005434565695	2C418F	8622 324826	OLGA GRISHINA	{"phone": "+70350647785"}
0005434565696	D9D7D9	0602 155005	MAKSIM NIKOLAEV	{"email": "nikolaev_m_04041958@postgrespro.ru", "phone": "+70975755198"}
0005434565697	DC8571	7164 568381	VERA PETROVA	{"phone": "+70407269066"}
0005434565698	F33F31	9335 285221	VALENTINA ZAYCEVA	{"phone": "+70545314144"}
0005434565699	343062	7763 302126	ALEKSANDR KOZLOV	{"phone": "+70626955036"}
0005434565700	039151	4169 351432	IVAN VASILEV	{"phone": "+70271293781"}
0005434565701	039151	9670 465714	RODION BELOV	{"phone": "+70125198070"}
0005434565702	A3F694	5401 540655	ANDREY FEDOTOV	{"phone": "+70108122936"}
0005434565703	E2580E	6537 736323	GRIGORIY PAVLOV	{"email": "pavlovg1961@postgrespro.ru", "phone": "+70989930385"}
0005434565704	60DB8B	3244 638844	TATYANA SMIRNOVA	{"phone": "+70617364920"}
0005434565705	60DB8B	2143 573481	EKATERINA KOVALEVA	{"phone": "+70761229825"}
0005434565706	E36F9C	9536 304617	KIRILL MATVEEV	{"phone": "+70065948482"}
0005434565707	36E751	7402 468997	ANTONINA TROFIMOVA	{"email": "trofimova.a031966@postgrespro.ru", "phone": "+70148355999"}
0005434565708	304305	5237 165900	TATYANA ORLOVA	{"phone": "+70322072457"}
0005434565709	304305	5995 839322	NIKOLAY ZAYCEV	{"email": "zaycev-nikolay.121981@postgrespro.ru", "phone": "+70445047801"}
0005434565710	881BD4	5998 381079	SVETLANA VASILEVA	{"email": "svetlanavasileva.16051971@postgrespro.ru", "phone": "+70154747024"}
0005434565711	26CB17	2719 235123	TATYANA ANDREEVA	{"email": "andreeva_t.1976@postgrespro.ru", "phone": "+70634187538"}
0005434565712	1FD12D	2927 233561	TATYANA PETROVA	{"email": "tatyanapetrova_1972@postgrespro.ru", "phone": "+70755797439"}
0005434565713	1045E1	2040 969203	SERGEY NIKITIN	{"email": "sergey_nikitin-1959@postgrespro.ru", "phone": "+70865257888"}
0005434565714	1045E1	3396 914253	EKATERINA KULIKOVA	{"email": "e_kulikova09061966@postgrespro.ru", "phone": "+70903568277"}
0005434565715	11FD22	5289 609441	YURIY KUDRYASHOV	{"phone": "+70403391140"}
0005434565716	11FD22	8263 791154	TATYANA SAVELEVA	{"email": "savelevat-091979@postgrespro.ru", "phone": "+70784825628"}
0005434565717	11FD22	8594 572351	ALFIYA VOROBEVA	{"phone": "+70568439469"}
0005434565718	5456BB	9082 301936	VIKTOR POPOV	{"phone": "+70957642761"}
0005434565719	5456BB	9132 640581	LYUBOV KOROLEVA	{"email": "korolevalyubov-05111965@postgrespro.ru", "phone": "+70036800783"}
0005434565720	5EAB46	3674 941237	ROMAN ABRAMOV	{"email": "abramov.roman.091975@postgrespro.ru", "phone": "+70083775538"}
0005434565721	F03FAF	6128 592281	ANNA POPOVA	{"email": "popova.anna.081968@postgrespro.ru", "phone": "+70675748341"}
0005434565722	6811C8	0030 641560	ANASTASIYA ARKHIPOVA	{"phone": "+70757719392"}
0005434565723	582FB6	1078 605157	NATALYA KRASNOVA	{"email": "natalyakrasnova.1965@postgrespro.ru", "phone": "+70037422484"}
0005434565724	5F6A9E	0069 165069	YULIYA SOKOLOVA	{"phone": "+70107643221"}
0005434565725	5F6A9E	1698 942756	OLGA MALYSHEVA	{"email": "o_malysheva051978@postgrespro.ru", "phone": "+70450613073"}
0005434565726	75E515	8906 500266	ALEKSANDRA GORBUNOVA	{"email": "agorbunova.011980@postgrespro.ru", "phone": "+70374554268"}
0005434565727	D19E5C	1679 175644	PAVEL ZHUKOV	{"email": "zhukov-p.031972@postgrespro.ru", "phone": "+70007422356"}
0005434565728	72A22A	3465 204485	DMITRIY PETROV	{"email": "petrov.d1972@postgrespro.ru", "phone": "+70310115469"}
0005434565729	A7CF6F	9483 751306	OLGA MOISEEVA	{"phone": "+70588263830"}
0005434565730	C548E8	1628 952676	DARYA NAZAROVA	{"phone": "+70061444232"}
0005434565731	C548E8	2771 558136	ALEKSEY CHERNOV	{"phone": "+70368015157"}
0005434565732	C548E8	3696 334360	ANATOLIY FEDOROV	{"email": "fedorov_a_011968@postgrespro.ru", "phone": "+70333487638"}
0005434565733	C548E8	8247 400712	ALEKSANDR SHEVCHENKO	{"phone": "+70916331010"}
0005434565734	C8B8A9	1498 621323	ANDREY PAVLOV	{"email": "pavlova-01091989@postgrespro.ru", "phone": "+70272048245"}
0005434565735	B8996E	4452 780816	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr_25021972@postgrespro.ru", "phone": "+70646138581"}
0005434565793	6CCC97	2947 767962	POLINA MARTYNOVA	{"phone": "+70903022385"}
0005434565736	B8996E	4147 510830	YURIY KISELEV	{"email": "y_kiselev.1982@postgrespro.ru", "phone": "+70367519141"}
0005434565737	B41F4E	5511 560494	IRINA OSIPOVA	{"email": "irina-osipova.06071965@postgrespro.ru", "phone": "+70951994009"}
0005434565738	5D3380	8601 202491	ALEKSANDR MAKAROV	{"email": "makarov-a_1960@postgrespro.ru", "phone": "+70203404733"}
0005434565739	5D3380	5690 396599	ELENA KISELEVA	{"phone": "+70848316980"}
0005434565740	4B0CCE	7220 216673	NADEZHDA ZHUKOVA	{"email": "nadezhda_zhukova-26031983@postgrespro.ru", "phone": "+70526491320"}
0005434565741	4B0CCE	3776 136976	NADEZHDA NIKITINA	{"phone": "+70761473441"}
0005434565742	169A50	9525 097194	ANASTASIYA KRASNOVA	{"email": "a_krasnova-13031969@postgrespro.ru", "phone": "+70446644204"}
0005434565743	DB08A4	4031 536478	YURIY FROLOV	{"email": "frolov-y_1982@postgrespro.ru", "phone": "+70381482486"}
0005434565744	DB08A4	9646 049264	DMITRIY MAKSIMOV	{"phone": "+70090519355"}
0005434565745	69C763	0315 477480	OLEG PAVLOV	{"email": "pavlov-oleg031964@postgrespro.ru", "phone": "+70537636450"}
0005434565746	14B225	0381 044311	ROMAN VLASOV	{"phone": "+70377701556"}
0005434565747	14B225	4087 437785	VERA MARTYNOVA	{"email": "martynova-vera08011961@postgrespro.ru", "phone": "+70576543424"}
0005434565748	4E3DC9	0617 221396	GALINA NIKITINA	{"email": "galina.nikitina-1973@postgrespro.ru", "phone": "+70457466736"}
0005434565749	4E3DC9	0666 005150	GRIGORIY VASILEV	{"email": "grigoriyvasilev.24041978@postgrespro.ru", "phone": "+70030659241"}
0005434565750	4C01C9	5946 230000	NADEZHDA ZAKHAROVA	{"phone": "+70168819970"}
0005434565751	4C01C9	0205 316696	VIKTOR ROMANOV	{"email": "vromanov_051970@postgrespro.ru", "phone": "+70729292105"}
0005434565752	0FC285	4629 263483	MARIYA ZHURAVLEVA	{"email": "mariya_zhuravleva1973@postgrespro.ru", "phone": "+70161739070"}
0005434565753	8D48CD	2027 706296	ALEKSANDR ABRAMOV	{"email": "abramov.a-051975@postgrespro.ru", "phone": "+70350712631"}
0005434565754	4DCF91	4331 854621	NATALYA ALEKSANDROVA	{"phone": "+70399346969"}
0005434565755	A2916A	0233 707686	OLGA ERMAKOVA	{"phone": "+70438422088"}
0005434565756	335B13	6673 976799	IGOR SOROKIN	{"email": "sorokin_igor.081975@postgrespro.ru", "phone": "+70209939566"}
0005434565757	0490B3	0464 918084	VLADIMIR MEDVEDEV	{"email": "medvedevv-111968@postgrespro.ru", "phone": "+70866594467"}
0005434565758	0490B3	6097 823922	ANDREY KUZMIN	{"email": "andreykuzmin.1967@postgrespro.ru", "phone": "+70712724331"}
0005434565759	F886F1	9513 254626	IGOR TIMOFEEV	{"email": "igortimofeev-30031980@postgrespro.ru", "phone": "+70223567981"}
0005434565760	3537E8	7419 730078	EGOR POPOV	{"phone": "+70787304718"}
0005434565761	DC4325	5162 000688	VIKTOR GERASIMOV	{"email": "gerasimovviktor.25031969@postgrespro.ru", "phone": "+70960791640"}
0005434565762	19177E	1102 661731	ALISA KONOVALOVA	{"email": "alisakonovalova03051987@postgrespro.ru", "phone": "+70757919410"}
0005434565763	74C05D	2173 809743	ANATOLIY ABRAMOV	{"email": "anatoliyabramov_1974@postgrespro.ru", "phone": "+70242664665"}
0005434565764	34806C	7785 274416	AYRAT BONDARENKO	{"email": "bondarenkoa.01011974@postgrespro.ru", "phone": "+70641359893"}
0005434565765	D79A7D	9789 440094	NINA BOGDANOVA	{"email": "bogdanova.n1971@postgrespro.ru", "phone": "+70486817412"}
0005434565766	F5D5DF	8030 472816	VLADIMIR BORISOV	{"email": "borisov_vladimir-041984@postgrespro.ru", "phone": "+70694041647"}
0005434565767	F5D5DF	7202 657824	NIKOLAY SOLOVEV	{"email": "nikolay_solovev_071973@postgrespro.ru", "phone": "+70671461144"}
0005434565768	910D67	3102 710827	DARYA PETROVA	{"phone": "+70909484594"}
0005434565769	910D67	1002 117988	GALINA NAZAROVA	{"email": "g-nazarova-12081974@postgrespro.ru", "phone": "+70600602492"}
0005434565770	16D7FC	3989 898340	ELENA SCHERBAKOVA	{"email": "scherbakova_e.13041977@postgrespro.ru", "phone": "+70655949205"}
0005434565771	E19C71	2775 294634	ARTEM AFANASEV	{"email": "artem-afanasev-1969@postgrespro.ru", "phone": "+70198492011"}
0005434565772	BCB616	8328 689050	LYUDMILA KUZNECOVA	{"phone": "+70839473361"}
0005434565773	59E77B	9463 689268	PETR MOROZOV	{"email": "p.morozov-1982@postgrespro.ru", "phone": "+70478241052"}
0005434565774	59E77B	7896 939869	ELENA KUZNECOVA	{"phone": "+70258324891"}
0005434565775	F56655	0784 113823	ANDREY VLASOV	{"phone": "+70424086310"}
0005434565776	E9CB94	8877 525665	DMITRIY MOISEEV	{"email": "moiseev_d_19031970@postgrespro.ru", "phone": "+70481634377"}
0005434565777	0F8AEF	0421 099321	DIANA NOVIKOVA	{"email": "diana-novikova1968@postgrespro.ru", "phone": "+70692139252"}
0005434565778	A371CD	2268 141483	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev-23031978@postgrespro.ru", "phone": "+70278752751"}
0005434565779	A371CD	3579 793772	EKATERINA LUKYANOVA	{"email": "lukyanova.e.05031963@postgrespro.ru", "phone": "+70751687155"}
0005434565780	880378	4613 871653	NATALYA ZAYCEVA	{"email": "nzayceva_1965@postgrespro.ru", "phone": "+70640935745"}
0005434565781	880378	9806 534299	VALENTINA NIKOLAEVA	{"phone": "+70174789750"}
0005434565782	924D6C	6209 880507	ALIYA TROFIMOVA	{"email": "aliyatrofimova111971@postgrespro.ru", "phone": "+70401042965"}
0005434565783	6A76AF	6921 044097	ALEKSANDR IVANOV	{"phone": "+70239623491"}
0005434565784	6A76AF	3166 858876	MIKHAIL GUSEV	{"phone": "+70856663272"}
0005434565785	C1932A	3552 877958	OLEG KUZMIN	{"email": "olegkuzmin28101976@postgrespro.ru", "phone": "+70483521420"}
0005434565786	C1932A	4905 542123	DMITRIY MELNIKOV	{"phone": "+70867992115"}
0005434565787	C1932A	7384 940176	GRIGORIY KONOVALOV	{"email": "g-konovalov1979@postgrespro.ru", "phone": "+70985016533"}
0005434565788	967059	6831 635843	VALENTINA ALEKSANDROVA	{"email": "v.aleksandrova-1968@postgrespro.ru", "phone": "+70907002507"}
0005434565789	967059	9860 443848	TAMARA DAVYDOVA	{"email": "davydova_tamara081968@postgrespro.ru", "phone": "+70702645654"}
0005434565790	9FAA61	2786 665948	MATVEY ROMANOV	{"email": "m-romanov.1981@postgrespro.ru", "phone": "+70989674910"}
0005434565791	068C7D	6497 328500	DMITRIY TARASOV	{"phone": "+70343077852"}
0005434565792	068C7D	9909 991641	YURIY MATVEEV	{"email": "y_matveev.011964@postgrespro.ru", "phone": "+70274054158"}
0005434565913	7C0897	5416 535824	DMITRIY KONOVALOV	{"phone": "+70693544924"}
0005434565794	6CCC97	5948 584715	MARINA MAKSIMOVA	{"email": "m.maksimova-06061976@postgrespro.ru", "phone": "+70961842581"}
0005434565795	6CCC97	4601 119394	ALEKSANDR KOROLEV	{"email": "korolev.a.26101979@postgrespro.ru", "phone": "+70828265819"}
0005434565796	AF22CB	9807 048103	VALENTINA FILATOVA	{"email": "v_filatova021968@postgrespro.ru", "phone": "+70975105881"}
0005434565797	3CA346	8532 187678	IVAN FEDOTOV	{"phone": "+70722452937"}
0005434565798	AB0BBF	6705 606457	ALENA KOVALEVA	{"email": "a_kovaleva.101986@postgrespro.ru", "phone": "+70292967465"}
0005434565799	07EBB6	6310 389463	NATALYA MOISEEVA	{"phone": "+70363465081"}
0005434565800	F2C1E9	6982 140011	SERGEY OSIPOV	{"phone": "+70849435867"}
0005434565801	6220E5	5412 792003	ELENA FROLOVA	{"phone": "+70185217114"}
0005434565802	FF59C9	6840 039895	OLGA SEMENOVA	{"email": "semenova_o-1959@postgrespro.ru", "phone": "+70799374775"}
0005434565803	966B80	1522 961017	GENNADIY NIKITIN	{"phone": "+70167438963"}
0005434565804	0E8ADB	2108 801771	VERA KAZAKOVA	{"phone": "+70861027017"}
0005434565805	0E8ADB	9712 070386	ALEKSANDR MARTYNOV	{"phone": "+70045547779"}
0005434565806	0E8ADB	3695 920954	ANNA NOVIKOVA	{"phone": "+70766927754"}
0005434565807	0C117E	4371 284269	SERGEY FILIPPOV	{"email": "filippov_s_071972@postgrespro.ru", "phone": "+70077186351"}
0005434565808	0C117E	4515 497051	EKATERINA YUDINA	{"phone": "+70330492140"}
0005434565809	0C117E	2260 579276	NADEZHDA MARTYNOVA	{"email": "nmartynova-20121963@postgrespro.ru", "phone": "+70913001115"}
0005434565810	605168	1348 059094	ELENA GRISHINA	{"email": "elenagrishina.07081973@postgrespro.ru", "phone": "+70984505852"}
0005434565811	C8A19E	1345 996962	MIKHAIL ROMANOV	{"email": "romanov-mikhail01071971@postgrespro.ru", "phone": "+70346127287"}
0005434565812	A49FBA	8284 851604	OKSANA MIKHAYLOVA	{"email": "oksanamikhaylova_17021962@postgrespro.ru", "phone": "+70452023020"}
0005434565813	A49FBA	4035 964898	ANASTASIYA KOZLOVA	{"phone": "+70837435020"}
0005434565814	B6E411	9613 474308	VLADIMIR NAZAROV	{"email": "nazarovvladimir.1980@postgrespro.ru", "phone": "+70085628908"}
0005434565815	6FAFD3	4052 690900	IBRAGIM KARPOV	{"email": "i-karpov_071972@postgrespro.ru", "phone": "+70436419753"}
0005434565816	6FAFD3	7541 628340	DINA MEDVEDEVA	{"email": "medvedevadina1977@postgrespro.ru", "phone": "+70829952431"}
0005434565817	DD57E9	1122 548255	ALISHER YAKOVLEV	{"phone": "+70504140002"}
0005434565818	DD57E9	0576 956688	VALERIYA PAVLOVA	{"email": "pavlova-valeriya-18121979@postgrespro.ru", "phone": "+70697028907"}
0005434565819	04000A	2205 766421	YULIYA ZHURAVLEVA	{"phone": "+70903078504"}
0005434565820	04000A	1546 550517	VLADIMIR ZAKHAROV	{"phone": "+70343876004"}
0005434565821	8C5617	9834 678898	ALBINA MOISEEVA	{"phone": "+70944079152"}
0005434565822	8C5617	6928 726867	NADEZHDA VOROBEVA	{"email": "nadezhda.vorobeva_1962@postgrespro.ru", "phone": "+70503345195"}
0005434565823	17372E	4341 086684	RAIS MIRONOV	{"phone": "+70882278656"}
0005434565824	17372E	8925 251738	OLEG BELOV	{"email": "belovoleg.23121968@postgrespro.ru", "phone": "+70866141376"}
0005434565825	0FBA40	2494 405633	OLEG POPOV	{"phone": "+70778492965"}
0005434565826	9402EF	4430 123313	ANZHELIKA KISELEVA	{"email": "a.kiseleva15061970@postgrespro.ru", "phone": "+70268892182"}
0005434565827	B8E0BA	0522 834166	NATALYA SAVELEVA	{"email": "saveleva.natalya.1970@postgrespro.ru", "phone": "+70140288046"}
0005434565828	D57876	7497 116428	KSENIYA PAVLOVA	{"phone": "+70674484657"}
0005434565829	D4E175	8356 990081	SERGEY PAVLOV	{"phone": "+70807907230"}
0005434565830	D4E175	5732 216934	ARTEM IVANOV	{"phone": "+70991886627"}
0005434565831	2A08FD	9282 812537	ELENA DAVYDOVA	{"email": "davydova_elena_01051985@postgrespro.ru", "phone": "+70065613706"}
0005434565832	2A08FD	9860 644800	LYUBOV PAVLOVA	{"email": "pavlova.lyubov.03081972@postgrespro.ru", "phone": "+70015314278"}
0005434565833	408756	4244 238440	NIKOLAY FEDOROV	{"email": "nfedorov-1979@postgrespro.ru", "phone": "+70565705427"}
0005434565834	408756	0498 313977	ALEKSANDR ORLOV	{"phone": "+70795470143"}
0005434565835	C540D5	9851 784164	ALEKSANDR YAKOVLEV	{"phone": "+70215576344"}
0005434565836	1B200F	3952 838617	BOGDAN NIKITIN	{"email": "nikitin-b111973@postgrespro.ru", "phone": "+70982802499"}
0005434565837	1B200F	2020 632189	ANATOLIY KONOVALOV	{"email": "konovalova23031967@postgrespro.ru", "phone": "+70209669809"}
0005434565838	61E12D	2568 998885	SERGEY IVANOV	{"email": "ivanov_s_051975@postgrespro.ru", "phone": "+70607915757"}
0005434565839	6AE999	0164 729594	SERGEY DMITRIEV	{"email": "s-dmitriev-1969@postgrespro.ru", "phone": "+70766044348"}
0005434565840	DEF01A	1764 085793	ANNA FILIPPOVA	{"email": "filippova-anna-04101974@postgrespro.ru", "phone": "+70773154843"}
0005434565841	DEF01A	1812 604327	TATYANA CHERNOVA	{"phone": "+70587378815"}
0005434565842	D0B584	7795 519310	NATALYA GAVRILOVA	{"phone": "+70370790031"}
0005434565843	A8501B	2451 237026	IVAN TARASOV	{"email": "i_tarasov_01071964@postgrespro.ru", "phone": "+70461185894"}
0005434565844	7C32C9	5097 820799	SVETLANA YUDINA	{"email": "yudinas.11071970@postgrespro.ru", "phone": "+70802257079"}
0005434565845	909D10	3374 589298	YULIYA ANISIMOVA	{"email": "anisimovay_1972@postgrespro.ru", "phone": "+70386365088"}
0005434565846	186D9D	9891 716996	ALEKSANDR KOROLEV	{"phone": "+70520109781"}
0005434565847	B79B5C	8295 585579	MIKHAIL DENISOV	{"email": "denisovm.22121965@postgrespro.ru", "phone": "+70487071308"}
0005434565848	B79B5C	1826 050781	DARYA BELOVA	{"email": "belova-darya.04031973@postgrespro.ru", "phone": "+70349981446"}
0005434565849	816FC0	0813 988807	ALEKSANDR DAVYDOV	{"email": "a.davydov.1971@postgrespro.ru", "phone": "+70154454424"}
0005434565850	8D8897	6871 274703	SVETLANA FEDOROVA	{"phone": "+70308677218"}
0005434565851	8D8897	3245 847417	EVGENIY MIRONOV	{"email": "mironov.e051969@postgrespro.ru", "phone": "+70472749464"}
0005434565852	D80B86	8842 308528	DANIIL MIKHAYLOV	{"email": "daniilmikhaylov.28061976@postgrespro.ru", "phone": "+70002556210"}
0005434565853	D80B86	2986 832376	LYUDMILA KONDRATEVA	{"email": "lyudmila-kondrateva13071975@postgrespro.ru", "phone": "+70500361422"}
0005434565854	915BAF	3916 637980	OLGA KUDRYASHOVA	{"phone": "+70758570856"}
0005434565855	689535	8363 813440	KONSTANTIN MIRONOV	{"phone": "+70661601776"}
0005434565856	E7AABB	7560 455082	ANTON MEDVEDEV	{"phone": "+70648915222"}
0005434565857	15AFFE	7093 245169	ANTONINA OVCHINNIKOVA	{"phone": "+70076088371"}
0005434565858	56A1BA	7244 089459	ANNA IVANOVA	{"phone": "+70938301010"}
0005434565859	56A1BA	7353 876649	TAMARA MIRONOVA	{"email": "mironova.tamara.1975@postgrespro.ru", "phone": "+70939975831"}
0005434565860	136524	7789 257650	ZOYA KOZLOVA	{"phone": "+70891910858"}
0005434565861	0CE853	6787 636497	ANASTASIYA ZHUKOVA	{"email": "zhukova_a-091972@postgrespro.ru", "phone": "+70306346392"}
0005434565862	0CE853	1585 881605	MARIYA MASLOVA	{"email": "maslova.m.15081980@postgrespro.ru", "phone": "+70087739110"}
0005434565863	532AF7	6685 154567	VASILIY TIMOFEEV	{"phone": "+70239488165"}
0005434565864	BC5FF9	7470 808585	SVETLANA PAVLOVA	{"email": "spavlova.121975@postgrespro.ru", "phone": "+70680962634"}
0005434565865	1F8767	5560 213515	RIMMA EGOROVA	{"phone": "+70610663636"}
0005434565866	1F8767	6748 425009	DARYA SOKOLOVA	{"phone": "+70404969964"}
0005434565867	46837B	8158 464651	TAMARA POPOVA	{"email": "popova_tamara.011968@postgrespro.ru", "phone": "+70980869250"}
0005434565868	4DFB8E	3048 359562	VLADIMIR MAKAROV	{"email": "makarov.vladimir_021973@postgrespro.ru", "phone": "+70073396676"}
0005434565869	24AB16	3045 029249	ALEKSANDR BORISOV	{"phone": "+70290918649"}
0005434565870	24AB16	2256 872577	NINA DMITRIEVA	{"phone": "+70773735432"}
0005434565871	2BC7FD	2615 951460	SVETLANA KUZMINA	{"email": "kuzmina.svetlana-051969@postgrespro.ru", "phone": "+70469335185"}
0005434565872	D549CE	1945 781421	LIDIYA FROLOVA	{"phone": "+70315008200"}
0005434565873	69CFAB	1333 018013	ANNA KAZAKOVA	{"email": "kazakovaanna041968@postgrespro.ru", "phone": "+70305893359"}
0005434565874	69CFAB	1664 168145	NINA ZAKHAROVA	{"phone": "+70661797307"}
0005434565875	69CFAB	9057 052894	ALEKSANDR NIKITIN	{"phone": "+70463752875"}
0005434565876	48F5F3	6089 247563	NIKITA BONDARENKO	{"phone": "+70617570361"}
0005434565877	3DBD96	7738 852873	SERGEY MIKHAYLOV	{"email": "mikhaylov_s_1974@postgrespro.ru", "phone": "+70685014944"}
0005434565878	44ECFD	5087 440419	GENNADIY NIKOLAEV	{"email": "gnikolaev1969@postgrespro.ru", "phone": "+70838272523"}
0005434565879	6295B0	8921 048201	MARIYA BELYAEVA	{"email": "m-belyaeva111978@postgrespro.ru", "phone": "+70937308390"}
0005434565880	191E2F	4606 201155	ALEKSEY FROLOV	{"email": "frolov-a_03011975@postgrespro.ru", "phone": "+70695296260"}
0005434565881	3BFBF4	8727 689000	ALEKSANDR SHEVCHENKO	{"phone": "+70798448674"}
0005434565882	1EA989	5337 993020	ARTUR BONDARENKO	{"email": "abondarenko-1975@postgrespro.ru", "phone": "+70050522405"}
0005434565883	9C922B	4725 973881	KONSTANTIN POPOV	{"email": "konstantin-popov-101981@postgrespro.ru", "phone": "+70267991395"}
0005434565884	9C922B	3032 445824	VALENTIN GAVRILOV	{"phone": "+70911644988"}
0005434565885	8E6A65	7289 317274	VALENTINA ZAYCEVA	{"email": "zayceva-valentina_31031981@postgrespro.ru", "phone": "+70405308521"}
0005434565886	8E6A65	3643 323819	SULTAN GAVRILOV	{"email": "gavrilov_s1983@postgrespro.ru", "phone": "+70078002041"}
0005434565887	20C50F	7894 327281	GULNAZ ALEKSANDROVA	{"email": "aleksandrova.gulnaz031982@postgrespro.ru", "phone": "+70594155915"}
0005434565888	877688	7096 514278	SERGEY POPOV	{"phone": "+70148913734"}
0005434565889	D06A04	2586 537456	ANDREY ANDREEV	{"phone": "+70523509573"}
0005434565890	AABF37	3184 033867	VYACHESLAV BELOV	{"email": "vyacheslavbelov.1961@postgrespro.ru", "phone": "+70518954952"}
0005434565891	F0B6ED	0207 728271	VLADIMIR IVANOV	{"phone": "+70882040245"}
0005434565892	F34E87	9245 275878	MARIANNA KOZLOVA	{"email": "mkozlova14041979@postgrespro.ru", "phone": "+70495260288"}
0005434565893	B1B313	8984 232090	PETR DENISOV	{"email": "p_denisov.14091969@postgrespro.ru", "phone": "+70562212938"}
0005434565894	CE8A37	8998 014617	SERGEY FEDOROV	{"email": "s_fedorov.23021965@postgrespro.ru", "phone": "+70188108451"}
0005434565895	ED738B	0828 102043	MIKHAIL VASILEV	{"phone": "+70093597018"}
0005434565896	ED738B	4272 435572	ANZHELIKA GERASIMOVA	{"email": "gerasimova_anzhelika-031974@postgrespro.ru", "phone": "+70771450267"}
0005434565897	2138AE	4324 285993	ZOYA IVANOVA	{"phone": "+70439807532"}
0005434565898	2138AE	9404 762308	YURIY KOROLEV	{"email": "korolev_y.1963@postgrespro.ru", "phone": "+70617918620"}
0005434565899	9BACA7	1038 592818	SERGEY KUDRYASHOV	{"phone": "+70620050281"}
0005434565900	32D543	8453 664988	ANTON PAVLOV	{"email": "a-pavlov1962@postgrespro.ru", "phone": "+70093453387"}
0005434565901	D3FAA4	1985 941934	NINA FOMINA	{"phone": "+70941506786"}
0005434565902	D3FAA4	2943 207734	GALINA KOVALEVA	{"phone": "+70393699781"}
0005434565903	194E2F	0057 456912	NINA MASLOVA	{"phone": "+70411040493"}
0005434565904	938160	9199 606644	GALINA ANDREEVA	{"email": "galina-andreeva_081973@postgrespro.ru", "phone": "+70405858917"}
0005434565905	938160	7085 419072	ALEKSANDR BORISOV	{"email": "borisov_aleksandr-011969@postgrespro.ru", "phone": "+70286380722"}
0005434565906	2FFCA0	0633 433421	ALEKSANDRA SCHERBAKOVA	{"phone": "+70859650841"}
0005434565907	94BA7F	7738 834275	MARINA KUDRYASHOVA	{"phone": "+70126302250"}
0005434565908	5D8F60	5137 223242	ELIZAVETA ISAEVA	{"email": "elizaveta-isaeva021978@postgrespro.ru", "phone": "+70477525145"}
0005434565909	5D8F60	9616 965426	ALEKSANDR ZAKHAROV	{"phone": "+70331217063"}
0005434565910	9F8131	0644 164825	ANATOLIY PETROV	{"email": "apetrov.121967@postgrespro.ru", "phone": "+70887733155"}
0005434565911	7C0897	0092 722816	NADEZHDA MIKHAYLOVA	{"phone": "+70722923968"}
0005434565912	7C0897	0381 079094	NATALYA KONDRATEVA	{"email": "kondrateva.n121980@postgrespro.ru", "phone": "+70296026853"}
0005434565914	7C0897	9458 407727	OKSANA KUZNECOVA	{"phone": "+70473163142"}
0005434565915	9EC20E	9581 880929	VALENTINA DANILOVA	{"email": "danilova-valentina041977@postgrespro.ru", "phone": "+70232422049"}
0005434565916	A85C74	7240 191584	ROMAN SOKOLOV	{"phone": "+70246184088"}
0005434565917	AA68D9	9737 843570	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev-011973@postgrespro.ru", "phone": "+70601268577"}
0005434565918	AA68D9	2757 624684	ALEKSANDR TIMOFEEV	{"email": "aleksandr.timofeev-1965@postgrespro.ru", "phone": "+70003885031"}
0005434565919	074606	6884 872740	OLEG MOISEEV	{"phone": "+70514162113"}
0005434565920	074606	5194 605351	LYUDMILA KOVALEVA	{"phone": "+70325724404"}
0005434565921	B6C8F7	1395 255359	VLADIMIR SMIRNOV	{"email": "smirnovvladimir_15041971@postgrespro.ru", "phone": "+70132629851"}
0005434565922	C40FC3	7317 731662	ANASTASIYA ANTONOVA	{"phone": "+70431608106"}
0005434565923	98BD7A	7393 410885	YULIYA STEPANOVA	{"email": "stepanovay_1980@postgrespro.ru", "phone": "+70490140934"}
0005434565924	98BD7A	4991 402277	LARISA VASILEVA	{"email": "vasileva_larisa_021980@postgrespro.ru", "phone": "+70149565538"}
0005434565925	B05699	4696 791264	VYACHESLAV SCHERBAKOV	{"email": "v-scherbakov_081971@postgrespro.ru", "phone": "+70990326609"}
0005434565926	0312D2	8689 060848	ALEKSANDR VLASOV	{"email": "aleksandrvlasov-1982@postgrespro.ru", "phone": "+70494937207"}
0005434565927	0312D2	0799 468999	OLGA KARPOVA	{"phone": "+70468595404"}
0005434565928	0530BA	0027 704937	DANIIL MAKAROV	{"phone": "+70046889316"}
0005434565929	114BAA	9487 215824	ILONA ALEKSANDROVA	{"email": "aleksandrova-i-011979@postgrespro.ru", "phone": "+70894721837"}
0005434565930	15510E	2435 978685	ALEKSANDR VLASOV	{"email": "vlasov_a.1974@postgrespro.ru", "phone": "+70107542864"}
0005434565931	15510E	8424 426047	DMITRIY POPOV	{"email": "dmitriy.popov.081974@postgrespro.ru", "phone": "+70835145262"}
0005434565932	8D0A13	1561 688693	OKSANA NESTEROVA	{"phone": "+70894818043"}
0005434565933	ACDB69	8583 330203	DENIS PETROV	{"email": "petrov-denis-061963@postgrespro.ru", "phone": "+70713842886"}
0005434565934	5045FF	1456 836877	DMITRIY POPOV	{"email": "dmitriy.popov_081981@postgrespro.ru", "phone": "+70657588134"}
0005434565935	46E630	0787 755614	NADEZHDA SMIRNOVA	{"email": "smirnova-nadezhda-111963@postgrespro.ru", "phone": "+70772825423"}
0005434565936	1B4F50	1550 316865	OLEG KULIKOV	{"phone": "+70664765096"}
0005434565937	861597	4386 891855	KSENIYA STEPANOVA	{"phone": "+70609294869"}
0005434565938	4BBE25	2749 819128	IRINA KISELEVA	{"phone": "+70483386174"}
0005434565939	D7F7C3	5452 238367	DENIS DMITRIEV	{"email": "dmitriev-d_07061968@postgrespro.ru", "phone": "+70959142584"}
0005434565940	160E9C	9944 050458	EVGENIY POPOV	{"email": "popov-e1978@postgrespro.ru", "phone": "+70981591816"}
0005434565941	160E9C	7513 598411	NIKOLAY ZAKHAROV	{"phone": "+70056060778"}
0005434565942	5933A7	6443 630628	ANDREY IVANOV	{"email": "ivanov_a_02081983@postgrespro.ru", "phone": "+70091600741"}
0005434565943	5933A7	1279 216852	ELENA SIDOROVA	{"phone": "+70567167648"}
0005434565944	0D17AF	1930 562863	ALEKSEY MAKAROV	{"email": "makarova_23111970@postgrespro.ru", "phone": "+70815671220"}
0005434565945	056EAF	1619 519984	VLADIMIR NAZAROV	{"email": "vladimir.nazarov_01061989@postgrespro.ru", "phone": "+70393381837"}
0005434565946	A7540B	5262 181800	SERGEY MAKAROV	{"phone": "+70890597450"}
0005434565947	A7540B	5960 023943	SVETLANA KALININA	{"phone": "+70182844802"}
0005434565948	A7540B	2222 622361	ALEKSANDR ANDREEV	{"phone": "+70427775358"}
0005434565949	EE6775	4677 294456	ANASTASIYA VLASOVA	{"email": "a_vlasova_071980@postgrespro.ru", "phone": "+70419266949"}
0005434565950	EE6775	5159 105312	VLADIMIR KULIKOV	{"email": "kulikov.vladimir-06101967@postgrespro.ru", "phone": "+70161956538"}
0005434565951	123491	3233 293301	VLADIMIR DMITRIEV	{"email": "dmitriev.vladimir.28051971@postgrespro.ru", "phone": "+70821709933"}
0005434565952	123491	2969 323526	SVETLANA VOLKOVA	{"email": "volkova-s091957@postgrespro.ru", "phone": "+70399558804"}
0005434565953	6D51F7	0397 123715	KIRILL RODIONOV	{"email": "rodionov-k.01071980@postgrespro.ru", "phone": "+70112010248"}
0005434565954	6D51F7	3978 095340	TAMARA MAKSIMOVA	{"phone": "+70796751706"}
0005434565955	175C28	1919 440644	ILYA SCHERBAKOV	{"email": "ilya.scherbakov1975@postgrespro.ru", "phone": "+70338380703"}
0005434565956	312B32	3898 838083	VYACHESLAV ZHUKOV	{"phone": "+70393287025"}
0005434565957	312B32	9755 347924	VALENTINA VOLKOVA	{"email": "vvolkova.1974@postgrespro.ru", "phone": "+70292894425"}
0005434565958	075A12	5788 530009	OKSANA MOROZOVA	{"email": "o_morozova_18081975@postgrespro.ru", "phone": "+70406306885"}
0005434565959	E8DEC5	0530 498188	VIKTOR SIDOROV	{"phone": "+70433310827"}
0005434565960	E8DEC5	3886 708253	ANATOLIY PAVLOV	{"email": "anatoliypavlov.021976@postgrespro.ru", "phone": "+70170294525"}
0005434565961	8FED40	8060 711310	EVGENIY NIKOLAEV	{"email": "enikolaev_071973@postgrespro.ru", "phone": "+70218750518"}
0005434565962	AD6467	2591 132626	LYUBOV SIDOROVA	{"email": "lyubov-sidorova.041972@postgrespro.ru", "phone": "+70407482534"}
0005434565963	BBC8A3	6166 159148	MATVEY ZAKHAROV	{"email": "zakharov.matvey111976@postgrespro.ru", "phone": "+70400310256"}
0005434565964	BBC8A3	3353 249532	MIKHAIL GERASIMOV	{"phone": "+70297071564"}
0005434565965	83AB26	5602 292399	MARIYA DENISOVA	{"email": "mariyadenisova16111978@postgrespro.ru", "phone": "+70607838202"}
0005434565966	2BA6E1	6522 233487	MARINA PAVLOVA	{"email": "marinapavlova081974@postgrespro.ru", "phone": "+70682264863"}
0005434565967	2BA6E1	5229 158278	ELENA MOROZOVA	{"email": "elena_morozova-021979@postgrespro.ru", "phone": "+70595331481"}
0005434565968	C5261C	6075 493972	SERGEY TARASOV	{"phone": "+70845524188"}
0005434565969	51D506	6823 154422	IRINA BELOVA	{"email": "ibelova11081959@postgrespro.ru", "phone": "+70094723889"}
0005434565970	51D506	6126 983893	TAMARA MELNIKOVA	{"email": "melnikova-t1971@postgrespro.ru", "phone": "+70996577588"}
0005434565971	51D506	0194 890296	ROMAN NOVIKOV	{"phone": "+70202796535"}
0005434565972	938BA9	5702 551210	LYUBOV SCHERBAKOVA	{"email": "scherbakova_l_1970@postgrespro.ru", "phone": "+70091241451"}
0005434565973	41662A	2221 348020	IRINA FOMINA	{"email": "i-fomina-09111976@postgrespro.ru", "phone": "+70675346385"}
0005434565974	41662A	6977 584547	DMITRIY ROMANOV	{"email": "romanov-dmitriy-19101969@postgrespro.ru", "phone": "+70017137145"}
0005434565975	D015CF	9667 757987	SVETLANA KRASNOVA	{"email": "s-krasnova_1979@postgrespro.ru", "phone": "+70533887675"}
0005434565976	C0792B	4394 799787	VIKTOR VOLKOV	{"email": "volkov.v-14011968@postgrespro.ru", "phone": "+70105114476"}
0005434565977	C0792B	9671 236595	YURIY ROMANOV	{"email": "romanov_y_1978@postgrespro.ru", "phone": "+70260040561"}
0005434565978	6EBDFB	7443 873152	KIRILL GRIGOREV	{"email": "grigorevkirill1972@postgrespro.ru", "phone": "+70432355795"}
0005434565979	6EBDFB	3601 157513	LYUDMILA FILATOVA	{"phone": "+70395118247"}
0005434565980	780800	1855 181220	ELENA RYABOVA	{"email": "elenaryabova-27071969@postgrespro.ru", "phone": "+70945866866"}
0005434565981	780800	2667 732541	LYUDMILA KAZAKOVA	{"phone": "+70345344220"}
0005434565982	780800	7323 019223	VLADIMIR GORBUNOV	{"email": "v.gorbunov_061972@postgrespro.ru", "phone": "+70800303371"}
0005434565983	D44B5C	2442 258162	ANASTASIYA ZAKHAROVA	{"email": "a-zakharova.16061967@postgrespro.ru", "phone": "+70848807421"}
0005434565984	D44B5C	0951 477668	IRINA ARKHIPOVA	{"phone": "+70744599971"}
0005434565985	6C1EE5	6226 669868	EKATERINA ZHURAVLEVA	{"phone": "+70590160113"}
0005434565986	FB1C17	3675 738730	SVETLANA ANDREEVA	{"email": "andreeva-svetlana_081964@postgrespro.ru", "phone": "+70753715900"}
0005434565987	83A178	6441 840454	VLADIMIR TARASOV	{"phone": "+70397741022"}
0005434565988	F51937	6159 022117	EKATERINA ZOTOVA	{"email": "e_zotova-1982@postgrespro.ru", "phone": "+70719685450"}
0005434565989	F51937	5149 686306	TATYANA ALEKSEEVA	{"phone": "+70776348096"}
0005434565990	246A9F	3564 742838	LYUDMILA POPOVA	{"email": "lyudmila-popova_31051977@postgrespro.ru", "phone": "+70454173737"}
0005434565991	246A9F	6654 091722	GALINA LEBEDEVA	{"email": "lebedeva_g091973@postgrespro.ru", "phone": "+70779717973"}
0005434565992	E756B5	6469 906749	PETR GRIGOREV	{"phone": "+70556030436"}
0005434565993	E756B5	9098 543192	MIKHAIL NAZAROV	{"phone": "+70280146299"}
0005434565994	DA3629	2728 106629	VLADIMIR OSIPOV	{"phone": "+70530654084"}
0005434565995	DA3629	8312 420899	MIKHAIL GRIGOREV	{"email": "grigorev_mikhail_20121973@postgrespro.ru", "phone": "+70770028727"}
0005434565996	A27A7D	6321 414875	GALINA NIKOLAEVA	{"phone": "+70334710996"}
0005434565997	B5EB78	2758 633035	VIKTORIYA IVANOVA	{"phone": "+70651940983"}
0005434565998	B4D1D7	0734 561771	OLGA ZAKHAROVA	{"phone": "+70943734040"}
0005434565999	E4FD39	8377 987254	SERGEY MOISEEV	{"phone": "+70894683188"}
0005434566000	1589B2	9383 899795	LARISA VASILEVA	{"email": "larisa.vasileva1963@postgrespro.ru", "phone": "+70261268293"}
0005434566001	1589B2	9439 711928	OLGA LOGINOVA	{"email": "o.loginova.21101972@postgrespro.ru", "phone": "+70248872409"}
0005434566002	91390D	3379 439031	ELENA MAKSIMOVA	{"phone": "+70608211001"}
0005434566003	BD3C53	3878 273344	SERGEY KOROLEV	{"email": "sergey.korolev.011978@postgrespro.ru", "phone": "+70856855253"}
0005434566004	BD3C53	3991 608139	ALEKSANDR AFANASEV	{"phone": "+70139252173"}
0005434566005	BD3C53	6900 920604	VLADISLAV STEPANOV	{"phone": "+70763884490"}
0005434566006	5DFFB8	1168 262595	ALEKSANDR ANDREEV	{"phone": "+70033115923"}
0005434566007	6949C0	8864 091337	IRINA MEDVEDEVA	{"email": "medvedeva_i_1972@postgrespro.ru", "phone": "+70280464964"}
0005434566008	05B314	8349 479069	ELENA KUZNECOVA	{"email": "kuznecova.e01081970@postgrespro.ru", "phone": "+70734105729"}
0005434566009	05B314	3275 597888	VADIM VOROBEV	{"phone": "+70710176592"}
0005434566010	43B35D	8542 020845	VALERIY IVANOV	{"email": "ivanovv-091973@postgrespro.ru", "phone": "+70088013542"}
0005434566011	43B35D	7603 126341	PAVEL POPOV	{"email": "popov-pavel16071966@postgrespro.ru", "phone": "+70105513308"}
0005434566012	F6B01D	8101 310019	OLEG KUZMIN	{"email": "olegkuzmin-091976@postgrespro.ru", "phone": "+70697631544"}
0005434566013	B44E5A	2590 974709	ZINAIDA KUDRYASHOVA	{"phone": "+70719279497"}
0005434566014	46E278	7502 704796	ALEKSANDR SCHERBAKOV	{"phone": "+70946564998"}
0005434566015	ABD313	1489 759259	GALINA ROMANOVA	{"email": "romanova_galina-021968@postgrespro.ru", "phone": "+70880211967"}
0005434566016	A0487C	9423 858594	ARTUR SERGEEV	{"email": "sergeevartur_031977@postgrespro.ru", "phone": "+70261208638"}
0005434566017	D76BF8	2851 755101	RAISA NAZAROVA	{"phone": "+70473463548"}
0005434566018	D76BF8	6572 959534	SERGEY MIKHAYLOV	{"email": "mikhaylovs-081976@postgrespro.ru", "phone": "+70394552113"}
0005434566019	72E3F7	4442 904072	SERGEY EGOROV	{"phone": "+70453871406"}
0005434566020	69243C	3369 278819	DENIS ZHURAVLEV	{"email": "d_zhuravlev-24041970@postgrespro.ru", "phone": "+70454626794"}
0005434566021	30A599	8154 079372	STEPAN AFANASEV	{"phone": "+70434318394"}
0005434566022	30A599	8127 215744	SEMEN DENISOV	{"email": "semendenisov.11011971@postgrespro.ru", "phone": "+70280311465"}
0005434566023	FB640C	1439 783573	SERGEY KOZLOV	{"phone": "+70242969374"}
0005434566024	FB98DB	8295 797859	VLADISLAV MAKSIMOV	{"phone": "+70097945681"}
0005434566025	364E12	9656 922268	GRIGORIY MAKSIMOV	{"email": "maksimovg-011970@postgrespro.ru", "phone": "+70170229723"}
0005434566026	4F6B58	7795 229206	NADEZHDA MELNIKOVA	{"email": "melnikova.n.1966@postgrespro.ru", "phone": "+70447973787"}
0005434566027	9BFB24	6074 578088	EKATERINA ROMANOVA	{"phone": "+70274713996"}
0005434566028	9BFB24	8104 255678	VALERIY DAVYDOV	{"phone": "+70694736173"}
0005434566029	9BFB24	0153 599023	MARIYA POTAPOVA	{"email": "potapova_mariya1981@postgrespro.ru", "phone": "+70473529136"}
0005434566030	D0B9BA	7496 753237	ZINAIDA KISELEVA	{"email": "zinaida.kiseleva.1976@postgrespro.ru", "phone": "+70370792000"}
0005434566268	A1A20A	1889 711418	DMITRIY ILIN	{"phone": "+70464539452"}
0005434566031	961AD1	3630 085834	VLADISLAV SEMENOV	{"email": "vladislavsemenov_08011969@postgrespro.ru", "phone": "+70101884383"}
0005434566032	961AD1	5106 652956	SERGEY YAKOVLEV	{"phone": "+70902020323"}
0005434566033	490A0E	5452 071640	SVETLANA KISELEVA	{"email": "kiseleva_svetlana.041974@postgrespro.ru", "phone": "+70304451497"}
0005434566034	E867BA	2807 782040	TATYANA FILIPPOVA	{"phone": "+70355012647"}
0005434566035	90BC9D	8845 951760	NADEZHDA CHERNOVA	{"phone": "+70939570242"}
0005434566036	90BC9D	7657 283921	NATALYA ABRAMOVA	{"email": "abramova-natalya.051981@postgrespro.ru", "phone": "+70645355847"}
0005434566037	C7307F	8807 428526	VYACHESLAV MIKHAYLOV	{"phone": "+70377906369"}
0005434566038	2D26F2	5733 925939	MARINA GAVRILOVA	{"email": "mgavrilova_27051970@postgrespro.ru", "phone": "+70835969236"}
0005434566039	2D26F2	3012 785380	ALENA ANTONOVA	{"phone": "+70811773791"}
0005434566040	B43D6C	9471 690274	NATALYA ZAYCEVA	{"email": "zayceva-n_1974@postgrespro.ru", "phone": "+70502257529"}
0005434566041	21C9A1	4489 229931	EKATERINA TIKHONOVA	{"phone": "+70870758062"}
0005434566042	800B5D	9049 575550	ALEKSANDR VLASOV	{"email": "vlasova041974@postgrespro.ru", "phone": "+70991645642"}
0005434566043	4F15F6	9175 766528	OLEG YAKOVLEV	{"phone": "+70353531867"}
0005434566044	4F15F6	5115 540154	EKATERINA NOVIKOVA	{"phone": "+70403424100"}
0005434566045	E80BE3	2724 215252	OLEG ROMANOV	{"email": "o.romanov-30051973@postgrespro.ru", "phone": "+70437046685"}
0005434566046	E80BE3	6836 332971	VIKTOR MELNIKOV	{"email": "v-melnikov.13101969@postgrespro.ru", "phone": "+70179615633"}
0005434566047	E80BE3	5442 571647	TIMUR VASILEV	{"email": "timur-vasilev_061974@postgrespro.ru", "phone": "+70294851183"}
0005434566048	96DB78	7889 875869	NIKOLAY ZAKHAROV	{"phone": "+70198563375"}
0005434566049	96DB78	4948 929459	ARTUR KUDRYASHOV	{"phone": "+70202158233"}
0005434566050	5C14ED	5039 989213	SERGEY EGOROV	{"email": "sergey_egorov-101981@postgrespro.ru", "phone": "+70450104659"}
0005434566051	5C14ED	3328 740046	MIKHAIL KONOVALOV	{"phone": "+70733708781"}
0005434566052	F6ACE3	4479 535338	SERGEY SERGEEV	{"phone": "+70735730163"}
0005434566053	E0B27D	2893 129548	ANNA SEMENOVA	{"email": "semenova-anna.27101969@postgrespro.ru", "phone": "+70739079693"}
0005434566054	E0B27D	0882 811323	NATALYA ZHUKOVA	{"email": "n_zhukova.23101960@postgrespro.ru", "phone": "+70242809106"}
0005434566055	3ED204	6508 951689	POLINA NIKITINA	{"email": "polinanikitina_15031969@postgrespro.ru", "phone": "+70562690285"}
0005434566056	3ED204	5058 047716	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir1972@postgrespro.ru", "phone": "+70038631356"}
0005434566057	3ED204	1367 911673	MAKSIM MAKAROV	{"phone": "+70269272413"}
0005434566058	0F9AB5	9880 384671	IGOR ALEKSEEV	{"email": "alekseev-igor081977@postgrespro.ru", "phone": "+70638205375"}
0005434566059	0F9AB5	1577 833239	RAISA KRASNOVA	{"phone": "+70251172805"}
0005434566060	0F9AB5	0958 940039	ZINAIDA EFREMOVA	{"email": "efremova-zinaida-05081973@postgrespro.ru", "phone": "+70286943297"}
0005434566061	01A580	0641 880470	OLGA VASILEVA	{"phone": "+70449023132"}
0005434566062	3E1434	2261 088095	NIKOLAY SCHERBAKOV	{"phone": "+70080614718"}
0005434566063	B20EF5	4346 816377	ELENA NIKOLAEVA	{"phone": "+70857609341"}
0005434566064	E3CD0E	9328 002895	LARISA KALININA	{"phone": "+70936710911"}
0005434566065	A71F68	9036 879775	GEORGIY VASILEV	{"email": "g_vasilev.041966@postgrespro.ru", "phone": "+70651584585"}
0005434566066	6564F5	3973 749749	IRINA MOISEEVA	{"email": "irina_moiseeva1984@postgrespro.ru", "phone": "+70674170877"}
0005434566067	6564F5	6830 621598	MIKHAIL ZAYCEV	{"phone": "+70711102962"}
0005434566068	747FB2	2862 996770	ANNA SOKOLOVA	{"email": "sokolovaanna.101978@postgrespro.ru", "phone": "+70790125896"}
0005434566069	DCAEDC	9863 155861	OLGA NAZAROVA	{"email": "nazarovaolga1970@postgrespro.ru", "phone": "+70636963296"}
0005434566070	632779	4105 020890	LIDIYA KULIKOVA	{"email": "lidiya_kulikova_1983@postgrespro.ru", "phone": "+70730969631"}
0005434566071	A5A63A	2796 602835	ALEKSANDRA FILATOVA	{"email": "a_filatova-081969@postgrespro.ru", "phone": "+70182506037"}
0005434566072	A5A63A	7714 040765	ALEKSEY NIKOLAEV	{"phone": "+70941193890"}
0005434566073	4E7FB0	3311 927272	ANDREY VASILEV	{"phone": "+70433022151"}
0005434566074	2CAC7B	3573 598198	ALEKSEY VOLKOV	{"email": "volkov_a_20071973@postgrespro.ru", "phone": "+70168533328"}
0005434566075	1ADE2B	2677 721643	PAVEL ANDREEV	{"phone": "+70957743222"}
0005434566076	1ADE2B	1997 027735	MIKHAIL BARANOV	{"phone": "+70218924269"}
0005434566077	F595A9	6993 977584	TAMARA KOZLOVA	{"email": "tamarakozlova-011975@postgrespro.ru", "phone": "+70221770767"}
0005434566078	062632	8910 523609	DMITRIY ANDREEV	{"phone": "+70877397766"}
0005434566079	3816A4	3691 744274	ALEKSEY ORLOV	{"phone": "+70951771958"}
0005434566080	DAB11B	8152 623818	NINA ANDREEVA	{"phone": "+70861012433"}
0005434566081	E0C1CA	5645 017495	LYUDMILA LOGINOVA	{"phone": "+70844534801"}
0005434566082	3C6BFA	9610 065635	SEMEN KOZLOV	{"email": "kozlov.s1980@postgrespro.ru", "phone": "+70690147629"}
0005434566083	B68EF1	3808 755153	NATALYA DANILOVA	{"email": "n_danilova.091963@postgrespro.ru", "phone": "+70656067333"}
0005434566084	B68EF1	3606 445036	NIKOLAY TIKHONOV	{"email": "nikolay_tikhonov.1970@postgrespro.ru", "phone": "+70483508733"}
0005434566085	FBC759	6712 735428	VERA ARKHIPOVA	{"phone": "+70359570295"}
0005434566086	FBC759	4288 620613	NINA LUKYANOVA	{"phone": "+70925141202"}
0005434566087	DD1DCD	3539 964206	KIRILL NOVIKOV	{"phone": "+70932551996"}
0005434566088	C4D9C6	3383 599036	DAVID TARASOV	{"phone": "+70923830264"}
0005434566089	DFC3A3	8993 585023	IVAN GUSEV	{"email": "gusevivan.1969@postgrespro.ru", "phone": "+70418482464"}
0005434566090	0D7254	3824 212353	GRIGORIY BELOV	{"phone": "+70824647197"}
0005434566091	0D7254	7398 874174	GENNADIY ILIN	{"phone": "+70024904821"}
0005434566209	5122CA	1379 289512	ALEKSEY ROMANOV	{"phone": "+70678965926"}
0005434566092	0D7254	2693 854614	NADEZHDA SCHERBAKOVA	{"email": "scherbakova-nadezhda.031971@postgrespro.ru", "phone": "+70944694640"}
0005434566093	849E1E	0999 634475	SERGEY SMIRNOV	{"email": "sergey_smirnov011978@postgrespro.ru", "phone": "+70026787154"}
0005434566094	434521	3866 556874	ZINAIDA POPOVA	{"phone": "+70281116420"}
0005434566095	3CE618	2649 109514	DANIIL DENISOV	{"email": "denisov.daniil021962@postgrespro.ru", "phone": "+70438036206"}
0005434566096	38B95A	9802 261993	PAVEL KUZMIN	{"phone": "+70152008260"}
0005434566097	4EE168	9564 305586	TATYANA PAVLOVA	{"email": "t_pavlova-1968@postgrespro.ru", "phone": "+70866874429"}
0005434566098	673D7F	8451 549301	ALBINA NESTEROVA	{"email": "anesterova121963@postgrespro.ru", "phone": "+70568653277"}
0005434566099	673D7F	6974 996300	YULIYA KOMAROVA	{"email": "yuliya-komarova_1973@postgrespro.ru", "phone": "+70032509642"}
0005434566100	E0E6D3	4144 434898	TATYANA SIDOROVA	{"email": "sidorova-t30081965@postgrespro.ru", "phone": "+70585529507"}
0005434566101	79E66F	4867 253893	ALEKSANDR VOROBEV	{"phone": "+70559933006"}
0005434566102	57530F	8011 140599	ALLA NIKOLAEVA	{"email": "alla.nikolaeva-021967@postgrespro.ru", "phone": "+70594996273"}
0005434566103	4FCC84	9752 118109	TATYANA KONDRATEVA	{"email": "kondrateva_tatyana031979@postgrespro.ru", "phone": "+70885345353"}
0005434566104	5CEC03	2581 387092	DMITRIY BONDARENKO	{"email": "bondarenko-d-1975@postgrespro.ru", "phone": "+70294312058"}
0005434566105	5CEC03	9638 022150	ANNA ZAKHAROVA	{"phone": "+70934968654"}
0005434566106	E071A1	3070 925701	ANTONINA VOLKOVA	{"phone": "+70120353157"}
0005434566107	E071A1	5218 123496	SVETLANA ALEKSEEVA	{"email": "svetlana.alekseeva.121970@postgrespro.ru", "phone": "+70884958391"}
0005434566108	B417FE	6473 530772	NIKITA GUSEV	{"email": "n_gusev_1973@postgrespro.ru", "phone": "+70107691443"}
0005434566109	21DC37	3386 939866	VLADIMIR VASILEV	{"email": "vladimir.vasilev_081976@postgrespro.ru", "phone": "+70416651663"}
0005434566110	F64631	3632 383348	RAISA SOROKINA	{"email": "raisa_sorokina.061978@postgrespro.ru", "phone": "+70733060636"}
0005434566111	D7AC2B	5056 889065	SERGEY VASILEV	{"email": "svasilev-1965@postgrespro.ru", "phone": "+70553048482"}
0005434566112	0C987B	7681 163146	NATALYA DMITRIEVA	{"email": "natalyadmitrieva.26101977@postgrespro.ru", "phone": "+70795037809"}
0005434566113	0C987B	3712 286003	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov1962@postgrespro.ru", "phone": "+70785042267"}
0005434566114	1D3E39	3148 780015	YAROSLAV PAVLOV	{"email": "yaroslav.pavlov_121956@postgrespro.ru", "phone": "+70018665329"}
0005434566115	1D3E39	4311 998622	VALENTINA NAUMOVA	{"phone": "+70601025074"}
0005434566116	1D3E39	8596 841015	VIKTOR VASILEV	{"email": "vasilev-viktor_03061980@postgrespro.ru", "phone": "+70973037841"}
0005434566117	3BF61D	9059 347491	SERGEY MATVEEV	{"email": "smatveev_121971@postgrespro.ru", "phone": "+70209699048"}
0005434566118	244D46	9728 795601	ANNA STEPANOVA	{"phone": "+70935033526"}
0005434566119	6273D1	9698 465296	ANASTASIYA FILIPPOVA	{"email": "filippova_a_1972@postgrespro.ru", "phone": "+70621336956"}
0005434566120	6273D1	6042 403577	VASILIY FROLOV	{"email": "frolov-v021970@postgrespro.ru", "phone": "+70607747104"}
0005434566121	712401	7164 463729	NADEZHDA MOROZOVA	{"email": "nadezhda-morozova-25041968@postgrespro.ru", "phone": "+70410948110"}
0005434566122	388ECC	1741 506219	NATALIYA KULIKOVA	{"email": "kulikova-n-1966@postgrespro.ru", "phone": "+70907676159"}
0005434566123	388ECC	1113 512083	MARIYA TITOVA	{"email": "titova.mariya-01031970@postgrespro.ru", "phone": "+70799908585"}
0005434566124	BFAF20	5397 863635	LYUDMILA VOLKOVA	{"email": "l.volkova-18071965@postgrespro.ru", "phone": "+70684583099"}
0005434566125	542B04	3355 052973	ANATOLIY ZAKHAROV	{"phone": "+70595014733"}
0005434566126	E6D581	8721 232315	VASILIY KULIKOV	{"email": "kulikov-vasiliy-1963@postgrespro.ru", "phone": "+70465635857"}
0005434566127	5AF6E9	9657 841541	VARVARA KUZNECOVA	{"email": "varvara-kuznecova.1975@postgrespro.ru", "phone": "+70234314989"}
0005434566128	A436C7	0737 711078	ALEKSANDR SIDOROV	{"phone": "+70833536215"}
0005434566129	B92638	2980 045174	NADEZHDA FOMINA	{"phone": "+70847170034"}
0005434566130	B92638	5606 351134	RAISA POLYAKOVA	{"email": "polyakova-r_1964@postgrespro.ru", "phone": "+70029909198"}
0005434566131	CC3FC6	7062 504725	LARISA ALEKSANDROVA	{"email": "larisa.aleksandrova061960@postgrespro.ru", "phone": "+70165880130"}
0005434566132	C8A25F	7837 346998	ELENA KRASNOVA	{"email": "elena_krasnova-1971@postgrespro.ru", "phone": "+70234348529"}
0005434566133	C8A25F	9331 466803	MARIYA SAVELEVA	{"email": "saveleva.m.1962@postgrespro.ru", "phone": "+70767754384"}
0005434566134	FB9EBD	8990 709088	LYUBOV DMITRIEVA	{"email": "dmitrieva-lyubov.101975@postgrespro.ru", "phone": "+70925933302"}
0005434566135	FB9EBD	3157 754264	SVETLANA DENISOVA	{"phone": "+70824592988"}
0005434566136	1B23B0	5430 397269	NIKOLAY KUZNECOV	{"email": "n-kuznecov1966@postgrespro.ru", "phone": "+70908005104"}
0005434566137	35A437	2356 219585	PAVEL ALEKSEEV	{"email": "p.alekseev-061976@postgrespro.ru", "phone": "+70677583398"}
0005434566138	8FD7A5	7389 773254	ANATOLIY TIKHONOV	{"phone": "+70619462588"}
0005434566139	8FD7A5	2971 097881	ALENA TITOVA	{"phone": "+70568994238"}
0005434566140	A01775	6494 464950	DMITRIY FEDOTOV	{"phone": "+70339687186"}
0005434566141	239FF6	6591 721904	IVAN PETROV	{"email": "petrov_ivan-1967@postgrespro.ru", "phone": "+70761673343"}
0005434566142	2D0745	4059 011163	DMITRIY KARPOV	{"phone": "+70216898462"}
0005434566143	B9EEB2	0848 534717	INNA NIKOLAEVA	{"phone": "+70711706007"}
0005434566144	FF00CB	6066 317542	DMITRIY FEDOTOV	{"email": "d-fedotov-1963@postgrespro.ru", "phone": "+70998181977"}
0005434566145	2FCD7A	5446 597228	ALEKSEY GERASIMOV	{"phone": "+70301192470"}
0005434566146	2FCD7A	1476 739049	NADEZHDA ZAKHAROVA	{"email": "zakharova_n-1974@postgrespro.ru", "phone": "+70974100321"}
0005434566147	B80B6E	8752 582325	EKATERINA MEDVEDEVA	{"email": "ekaterinamedvedeva.16111968@postgrespro.ru", "phone": "+70370296958"}
0005434566148	75DF4F	1291 454010	VASILIY TIKHONOV	{"phone": "+70401314496"}
0005434566149	0883A3	1303 352698	MAKSIM KOROLEV	{"email": "maksim-korolev_1965@postgrespro.ru", "phone": "+70096318692"}
0005434566150	D419F3	6751 866937	LYUBOV ANTONOVA	{"phone": "+70195872832"}
0005434566151	1F02CC	8238 382605	ELENA FROLOVA	{"email": "e_frolova021969@postgrespro.ru", "phone": "+70750396766"}
0005434566152	1F02CC	6919 118153	MARINA MIRONOVA	{"email": "mironovam_011973@postgrespro.ru", "phone": "+70538287628"}
0005434566153	A86376	4744 738995	TAISIYA KRASNOVA	{"email": "taisiyakrasnova-23091963@postgrespro.ru", "phone": "+70918377881"}
0005434566154	208374	2444 231305	LYUDMILA KAZAKOVA	{"email": "kazakova_lyudmila.1966@postgrespro.ru", "phone": "+70530739353"}
0005434566155	651302	8849 078413	MARINA YUDINA	{"email": "yudina.m.26101973@postgrespro.ru", "phone": "+70602408461"}
0005434566156	B6CE9A	5364 000564	MIKHAIL KRASNOV	{"phone": "+70806910026"}
0005434566157	B6CE9A	6385 723862	ALEKSANDR KULIKOV	{"email": "kulikov_a_16031974@postgrespro.ru", "phone": "+70671140527"}
0005434566158	5D6A73	2396 465502	YURIY MELNIKOV	{"phone": "+70734959533"}
0005434566159	5D6A73	4459 789420	GRIGORIY GUSEV	{"phone": "+70074077781"}
0005434566160	74887B	7987 981138	ANASTASIYA MARTYNOVA	{"phone": "+70182768441"}
0005434566161	5B0F17	4615 604266	RUSTAM IVANOV	{"phone": "+70367834238"}
0005434566162	4A1C73	6379 243359	NAIL GRIGOREV	{"email": "grigorev-n_041965@postgrespro.ru", "phone": "+70791103958"}
0005434566163	65483E	0679 703549	EGOR MOROZOV	{"email": "e-morozov03081975@postgrespro.ru", "phone": "+70920890715"}
0005434566164	0B07FC	6798 518375	ZOYA ROMANOVA	{"email": "z_romanova-22061969@postgrespro.ru", "phone": "+70510024784"}
0005434566165	14315A	6143 178230	POLINA NAZAROVA	{"email": "polina_nazarova.08011975@postgrespro.ru", "phone": "+70110667833"}
0005434566166	14315A	2171 092330	YURIY KISELEV	{"phone": "+70419872022"}
0005434566167	6B7EE1	4100 424968	ANNA EFREMOVA	{"email": "a_efremova_29101971@postgrespro.ru", "phone": "+70017887976"}
0005434566168	AFAFE8	1645 160817	VITALIY KUZMIN	{"phone": "+70949586382"}
0005434566169	AFAFE8	4732 700993	IRINA KUZNECOVA	{"phone": "+70690809217"}
0005434566170	F58943	5958 772627	ILYA MOISEEV	{"phone": "+70051997176"}
0005434566171	4BD9B5	2516 901840	ANTON ORLOV	{"phone": "+70533258271"}
0005434566172	8B8ABE	7590 314805	MARIYA MASLOVA	{"email": "maslovam_041969@postgrespro.ru", "phone": "+70210662101"}
0005434566173	71CF07	9671 579122	ALEKSEY ZAKHAROV	{"phone": "+70001653903"}
0005434566174	71CF07	3769 265055	IGOR NAUMOV	{"email": "igornaumov121979@postgrespro.ru", "phone": "+70139392215"}
0005434566175	71CF07	4924 202687	MIKHAIL IVANOV	{"phone": "+70531777942"}
0005434566176	4B33AF	8986 019993	TAMARA KOZLOVA	{"phone": "+70363402291"}
0005434566177	F19261	8960 719730	PAVEL ANTONOV	{"email": "antonov.pavel07051975@postgrespro.ru", "phone": "+70127223830"}
0005434566178	1C8AB9	2709 192956	NINA ARKHIPOVA	{"email": "arkhipovanina_051979@postgrespro.ru", "phone": "+70157682050"}
0005434566179	1C8AB9	4706 794979	POLINA SMIRNOVA	{"email": "polina_smirnova1974@postgrespro.ru", "phone": "+70870417618"}
0005434566180	C86F7C	8373 007871	TATYANA MIKHAYLOVA	{"phone": "+70952505786"}
0005434566181	D3CCCF	0687 293733	TATYANA MAKSIMOVA	{"phone": "+70137088982"}
0005434566182	4FEB28	7426 689849	PAVEL IVANOV	{"email": "ivanov_p1987@postgrespro.ru", "phone": "+70624074350"}
0005434566183	4FEB28	0318 417513	DMITRIY FROLOV	{"email": "dfrolov_29101974@postgrespro.ru", "phone": "+70149952345"}
0005434566184	EBC323	0570 731104	NADEZHDA MIKHAYLOVA	{"phone": "+70980633406"}
0005434566185	ADA0DA	5033 787987	NATALYA VASILEVA	{"phone": "+70945559428"}
0005434566186	0D43EE	3416 538261	ALEKSANDR PAVLOV	{"phone": "+70177581131"}
0005434566187	A9D78C	9252 708593	SERGEY GAVRILOV	{"phone": "+70495915853"}
0005434566188	DFD76C	5790 394885	SVETLANA KRASNOVA	{"email": "krasnova-s_25121971@postgrespro.ru", "phone": "+70226273175"}
0005434566189	DFD76C	1096 403285	NINA NESTEROVA	{"email": "nesterova_nina.1987@postgrespro.ru", "phone": "+70690524752"}
0005434566190	3319B3	1719 699838	BORIS ILIN	{"email": "borisilin.031968@postgrespro.ru", "phone": "+70947476404"}
0005434566191	C62B9B	2214 872223	YURIY KULIKOV	{"phone": "+70764596422"}
0005434566192	C62B9B	3470 280926	ILDAR ZAYCEV	{"phone": "+70542533653"}
0005434566193	8785E9	5683 647423	OLGA POPOVA	{"email": "olga.popova_1977@postgrespro.ru", "phone": "+70276379236"}
0005434566194	8785E9	3724 027796	ALEKSEY IVANOV	{"email": "ivanovaleksey.18031973@postgrespro.ru", "phone": "+70185557833"}
0005434566195	8785E9	4006 581259	LIDIYA ANDREEVA	{"email": "lidiya-andreeva.15031965@postgrespro.ru", "phone": "+70015819112"}
0005434566196	8785E9	3010 722031	NATALYA MOROZOVA	{"email": "natalyamorozova16091985@postgrespro.ru", "phone": "+70349536356"}
0005434566197	AFE59D	0876 082178	LYUDMILA TARASOVA	{"email": "tarasova-l.03021969@postgrespro.ru", "phone": "+70859532606"}
0005434566198	D41F30	4139 458194	SERGEY MAKAROV	{"phone": "+70704417554"}
0005434566199	EF3786	5464 607882	LIDIYA ROMANOVA	{"email": "romanova_l-08091976@postgrespro.ru", "phone": "+70658235377"}
0005434566200	670F45	6082 643748	VERONIKA FROLOVA	{"phone": "+70841758789"}
0005434566201	221519	2252 850953	ELENA SEMENOVA	{"email": "semenova.e1971@postgrespro.ru", "phone": "+70747046424"}
0005434566202	DDBFC4	1391 286202	ANDREY SCHERBAKOV	{"email": "scherbakov-andrey_011979@postgrespro.ru", "phone": "+70559148216"}
0005434566203	DDBFC4	3463 969017	LYUDMILA ANTONOVA	{"email": "antonova_l-1974@postgrespro.ru", "phone": "+70947764299"}
0005434566204	DACB8C	4146 498803	IDA ANTONOVA	{"email": "i.antonova.19011974@postgrespro.ru", "phone": "+70355582510"}
0005434566205	D0A202	6560 711964	OLEG PETROV	{"email": "petrov_o_1963@postgrespro.ru", "phone": "+70362903975"}
0005434566206	D0A202	3278 377695	TATYANA ANDREEVA	{"email": "t.andreeva_111974@postgrespro.ru", "phone": "+70963037126"}
0005434566207	562E40	6452 996836	GALINA KOROLEVA	{"phone": "+70349757789"}
0005434566208	8AE91B	6268 244201	TATYANA PAVLOVA	{"phone": "+70786229433"}
0005434566210	5122CA	6154 819655	ALEKSEY STEPANOV	{"email": "a_stepanov-121968@postgrespro.ru", "phone": "+70170725397"}
0005434566211	5122CA	7872 763318	ELENA ZAYCEVA	{"phone": "+70893011217"}
0005434566212	627F37	7555 549364	VIKTOR VOLKOV	{"email": "viktor_volkov_101973@postgrespro.ru", "phone": "+70727808272"}
0005434566213	C71EF2	2045 296138	ARINA VASILEVA	{"phone": "+70973498700"}
0005434566214	723D1A	3886 503088	ANDREY KUZNECOV	{"phone": "+70589440392"}
0005434566215	04400E	5060 332787	OLGA VOLKOVA	{"phone": "+70742653862"}
0005434566216	99EB73	5838 663792	NINA VLASOVA	{"phone": "+70406632079"}
0005434566217	99EB73	3036 417817	VALENTINA SEMENOVA	{"email": "semenova-valentina-1961@postgrespro.ru", "phone": "+70961132932"}
0005434566218	F0260A	1915 779995	DMITRIY MAKAROV	{"phone": "+70722294924"}
0005434566219	B7E2A1	0724 818683	RIMMA PAVLOVA	{"email": "pavlova.rimma27111972@postgrespro.ru", "phone": "+70798355764"}
0005434566220	B7E2A1	8567 986767	ALEKSANDR TIMOFEEV	{"email": "a-timofeev_111976@postgrespro.ru", "phone": "+70253630838"}
0005434566221	BB5197	8894 860570	ANNA MALYSHEVA	{"email": "malysheva-a-101969@postgrespro.ru", "phone": "+70306021725"}
0005434566222	0FD317	9650 800920	ANASTASIYA IVANOVA	{"phone": "+70792536310"}
0005434566223	0FD317	1852 934635	VALERIY MAKSIMOV	{"email": "vmaksimov-1970@postgrespro.ru", "phone": "+70079682662"}
0005434566224	0FD317	3970 938770	OLGA KRASNOVA	{"phone": "+70131106664"}
0005434566225	9EFB58	6312 094107	NADEZHDA ILINA	{"email": "ilina-nadezhda-08121979@postgrespro.ru", "phone": "+70154000702"}
0005434566226	CDBF4D	4999 883419	DENIS RODIONOV	{"email": "rodionovd021963@postgrespro.ru", "phone": "+70943666418"}
0005434566227	4516E1	6962 007772	SERGEY MAKSIMOV	{"phone": "+70370211782"}
0005434566228	262E3D	3840 952182	YURIY VOLKOV	{"email": "volkovy051964@postgrespro.ru", "phone": "+70148775175"}
0005434566229	D95D21	2193 346467	IVAN KAZAKOV	{"email": "kazakov_ivan.1966@postgrespro.ru", "phone": "+70412030866"}
0005434566230	D416F1	1077 323986	ELENA ZHURAVLEVA	{"email": "e_zhuravleva-17031973@postgrespro.ru", "phone": "+70930247929"}
0005434566231	0B4AFC	0519 398178	SVETLANA BORISOVA	{"email": "borisova_s-091969@postgrespro.ru", "phone": "+70339280216"}
0005434566232	5DB284	9964 566584	DMITRIY SMIRNOV	{"email": "smirnovdmitriy-1968@postgrespro.ru", "phone": "+70587450063"}
0005434566233	1627D6	2929 039029	LEONID PETROV	{"email": "petrov.leonid_1983@postgrespro.ru", "phone": "+70591413576"}
0005434566234	04AE7D	6307 623939	YURIY ZAKHAROV	{"email": "zakharov.yuriy.021967@postgrespro.ru", "phone": "+70184699778"}
0005434566235	46CCCF	4963 249473	INNA FILIPPOVA	{"email": "innafilippova_011969@postgrespro.ru", "phone": "+70333779184"}
0005434566236	46CCCF	9847 107122	DENIS SIDOROV	{"email": "d.sidorov-081967@postgrespro.ru", "phone": "+70474454608"}
0005434566237	46CCCF	6646 619048	OLGA KAZAKOVA	{"phone": "+70463528813"}
0005434566238	ED0F62	1435 381711	ANTON PETROV	{"phone": "+70868149965"}
0005434566239	3ADF4A	3597 278558	IRINA DENISOVA	{"email": "denisova_irina061962@postgrespro.ru", "phone": "+70744461568"}
0005434566240	95FC0E	7666 266735	VIKTOR ZAYCEV	{"email": "zaycev-viktor101969@postgrespro.ru", "phone": "+70438344158"}
0005434566241	95FC0E	5211 821585	NADEZHDA SOLOVEVA	{"phone": "+70487903418"}
0005434566242	914693	5718 039212	ALEKSEY KARPOV	{"email": "aleksey-karpov-1967@postgrespro.ru", "phone": "+70506201745"}
0005434566243	914693	8183 665698	TATYANA GAVRILOVA	{"phone": "+70628486482"}
0005434566244	E352C6	2124 819035	MARIYA IVANOVA	{"phone": "+70227811069"}
0005434566245	E352C6	1733 503001	OLGA KISELEVA	{"email": "okiseleva.24081981@postgrespro.ru", "phone": "+70182640292"}
0005434566246	89B882	3165 118647	SALAVAT ISAEV	{"phone": "+70040774474"}
0005434566247	4E7D2C	4867 089343	EKATERINA GRISHINA	{"phone": "+70957875981"}
0005434566248	4E7D2C	7320 457144	RENAT KOZLOV	{"email": "renat_kozlov.1974@postgrespro.ru", "phone": "+70576549292"}
0005434566249	E92C1A	9302 849470	VIKTOR MIKHAYLOV	{"email": "v-mikhaylov1970@postgrespro.ru", "phone": "+70407995634"}
0005434566250	B0C400	3320 668542	IRINA NIKITINA	{"email": "nikitina.i.021975@postgrespro.ru", "phone": "+70643314000"}
0005434566251	B0C400	4119 709117	NINA ZAKHAROVA	{"email": "ninazakharova.08071968@postgrespro.ru", "phone": "+70815623222"}
0005434566252	B0C400	7196 587708	SERGEY MOISEEV	{"email": "s_moiseev.06091963@postgrespro.ru", "phone": "+70831688901"}
0005434566253	9CED50	1632 627771	YANA SOKOLOVA	{"email": "sokolovayana-071986@postgrespro.ru", "phone": "+70219129582"}
0005434566254	5FC79B	5653 949564	OLGA KULIKOVA	{"email": "kulikova-o_1965@postgrespro.ru", "phone": "+70226583779"}
0005434566255	5FC79B	7605 377894	EDUARD VASILEV	{"email": "e.vasilev.091976@postgrespro.ru", "phone": "+70212874294"}
0005434566256	ECEA1B	6890 758718	OLEG TIMOFEEV	{"email": "olegtimofeev28111971@postgrespro.ru", "phone": "+70195613386"}
0005434566257	01A464	5730 346467	ANNA MOROZOVA	{"email": "morozovaa.15071975@postgrespro.ru", "phone": "+70969003611"}
0005434566258	5D71A9	0560 945234	SVETLANA MELNIKOVA	{"email": "melnikova_svetlana.1975@postgrespro.ru", "phone": "+70906429690"}
0005434566259	5D71A9	3010 283039	KIRILL OSIPOV	{"phone": "+70710941740"}
0005434566260	C3DD89	5014 162001	EDUARD MOROZOV	{"phone": "+70770904794"}
0005434566261	C3DD89	4583 101300	DIANA ABRAMOVA	{"phone": "+70484060399"}
0005434566262	5107BC	0689 158636	VLADIMIR KOZLOV	{"phone": "+70710429208"}
0005434566263	5107BC	1052 608083	NADEZHDA AKIMOVA	{"phone": "+70525423342"}
0005434566264	47C482	1295 416690	SVETLANA TARASOVA	{"email": "svetlana_tarasova121972@postgrespro.ru", "phone": "+70677666333"}
0005434566265	47C482	0035 160022	NIKOLAY IVANOV	{"email": "ivanov-nikolay03111970@postgrespro.ru", "phone": "+70070115722"}
0005434566266	C6EB28	2507 945717	EVGENIYA DAVYDOVA	{"email": "evgeniyadavydova-31071967@postgrespro.ru", "phone": "+70818627403"}
0005434566267	8E7DCE	8675 880395	VALENTIN VASILEV	{"email": "valentin.vasilev-1964@postgrespro.ru", "phone": "+70871825192"}
0005434566269	A1A20A	1485 896116	VIKTORIYA KUZNECOVA	{"email": "viktoriya.kuznecova_041975@postgrespro.ru", "phone": "+70995325605"}
0005434566270	A1A20A	1629 924676	NATALYA NAZAROVA	{"phone": "+70597922628"}
0005434566271	4FB106	7893 418783	SALAVAT ROMANOV	{"email": "romanov_s1964@postgrespro.ru", "phone": "+70472094340"}
0005434566272	4FB106	1536 080596	ANNA KUZNECOVA	{"email": "kuznecova-anna_101976@postgrespro.ru", "phone": "+70621567186"}
0005434566273	C2CB36	8798 886317	VERA FILIPPOVA	{"email": "verafilippova.051957@postgrespro.ru", "phone": "+70680886702"}
0005434566274	7EEDFE	1638 508232	VALERIYA FADEEVA	{"phone": "+70532723869"}
0005434566275	D61653	4633 733598	DARYA KOLESNIKOVA	{"email": "d.kolesnikova-1957@postgrespro.ru", "phone": "+70277268055"}
0005434566276	1B5867	6190 625843	KRISTINA ANTONOVA	{"email": "k_antonova.031981@postgrespro.ru", "phone": "+70545158834"}
0005434566277	1B5867	1295 025436	ARTEM DMITRIEV	{"phone": "+70617066508"}
0005434566278	150AC2	7418 058713	NATALYA SOKOLOVA	{"email": "sokolova_natalya1968@postgrespro.ru", "phone": "+70558833679"}
0005434566279	150AC2	8255 934533	NINA BORISOVA	{"email": "nina_borisova031976@postgrespro.ru", "phone": "+70045533182"}
0005434566280	84A184	7809 244073	ALEKSANDR POPOV	{"email": "aleksandrpopov1974@postgrespro.ru", "phone": "+70505416921"}
0005434566281	6A9BD4	1276 208369	DENIS ROMANOV	{"phone": "+70383063481"}
0005434566282	6A9BD4	8748 260559	IVAN KOZLOV	{"email": "kozlov.i-05091967@postgrespro.ru", "phone": "+70361894892"}
0005434566283	EA0C83	1194 000491	ANDREY MARTYNOV	{"email": "martynov_a.1979@postgrespro.ru", "phone": "+70314402279"}
0005434566284	EA0C83	3628 677185	PRASKOVYA BOGDANOVA	{"email": "bogdanova.praskovya-071985@postgrespro.ru", "phone": "+70803992958"}
0005434566285	562A39	5979 902040	ALEKSANDR KOROLEV	{"email": "korolev-aleksandr.111964@postgrespro.ru", "phone": "+70782580507"}
0005434566286	A604C4	9844 699355	DARYA ZAYCEVA	{"phone": "+70330573331"}
0005434566287	5C6D7C	0496 950567	ALEVTINA DAVYDOVA	{"email": "a_davydova14091969@postgrespro.ru", "phone": "+70184964640"}
0005434566288	943B18	9547 811604	MARIYA TIKHONOVA	{"phone": "+70648264890"}
0005434566289	B49D3B	0823 057448	ANNA ZAKHAROVA	{"phone": "+70871688151"}
0005434566290	F15DC7	9283 859533	DMITRIY SAVELEV	{"email": "d-savelev.11021985@postgrespro.ru", "phone": "+70168244353"}
0005434566291	298628	4027 450505	ALLA SCHERBAKOVA	{"phone": "+70316328082"}
0005434566292	298628	6258 294145	MARINA VOROBEVA	{"email": "m-vorobeva031972@postgrespro.ru", "phone": "+70568998866"}
0005434566293	06D9B8	5504 765307	SVETLANA ZOTOVA	{"phone": "+70538417605"}
0005434566294	06D9B8	7905 232609	ALEKSEY BELOV	{"email": "belov_aleksey-28111977@postgrespro.ru", "phone": "+70850507683"}
0005434566295	B3C9BB	2235 849278	SVETLANA YAKOVLEVA	{"phone": "+70748196549"}
0005434566296	B3C9BB	4125 724562	TATYANA MOISEEVA	{"email": "tmoiseeva021969@postgrespro.ru", "phone": "+70195672531"}
0005434566297	046C94	1073 775489	SERGEY SERGEEV	{"email": "sergeev-s.14061976@postgrespro.ru", "phone": "+70342299693"}
0005434566298	4F003E	4830 383566	GENNADIY POPOV	{"phone": "+70974097506"}
0005434566299	4F003E	2664 185737	RUSLAN POPOV	{"email": "popov_ruslan1972@postgrespro.ru", "phone": "+70510729967"}
0005434566300	255378	1268 241965	EVGENIYA POPOVA	{"email": "e-popova_1976@postgrespro.ru", "phone": "+70329580094"}
0005434566301	082F0C	0856 625729	YURIY POPOV	{"email": "popovy.091979@postgrespro.ru", "phone": "+70697481166"}
0005434566302	082F0C	9004 736747	YURIY KUZNECOV	{"phone": "+70608019389"}
0005434566303	53D2DE	1905 225287	VASILIY MOROZOV	{"phone": "+70328864134"}
0005434566304	1510F2	8544 867872	ANNA POPOVA	{"email": "a.popova-101966@postgrespro.ru", "phone": "+70990177532"}
0005434566305	1510F2	4199 127888	ANATOLIY GUSEV	{"phone": "+70181736895"}
0005434566306	B0ED05	9894 108648	LIDIYA NIKITINA	{"phone": "+70902580240"}
0005434566307	B0ED05	5337 429883	VLADIMIR IVANOV	{"email": "ivanov.v_071974@postgrespro.ru", "phone": "+70873780249"}
0005434566308	B0ED05	3822 140715	ARINA POPOVA	{"phone": "+70812006014"}
0005434566309	BD9E75	2575 335686	DANIL MEDVEDEV	{"phone": "+70549686461"}
0005434566310	6BDBB6	4272 419184	VALENTINA FEDOROVA	{"phone": "+70044685343"}
0005434566311	6BDBB6	3433 198359	ALEKSANDR SHEVCHENKO	{"phone": "+70818038917"}
0005434566312	7D9245	6316 731563	TAMARA KULIKOVA	{"phone": "+70520196506"}
0005434573101	D084F7	7832 500623	ELENA SEMENOVA	{"email": "semenova.elena.101975@postgrespro.ru", "phone": "+70962814864"}
0005434573102	3D2717	5206 314628	ARTEM MIKHAYLOV	{"phone": "+70370189084"}
0005434573103	3D2717	7474 543405	MAKSIM OSIPOV	{"email": "osipov.maksim-29091969@postgrespro.ru", "phone": "+70215893153"}
0005434573104	3D2717	8525 581354	VLADIMIR MOISEEV	{"email": "moiseev.vladimir041964@postgrespro.ru", "phone": "+70938969782"}
0005434573105	9A673B	5617 049341	ANDREY SCHERBAKOV	{"phone": "+70271155059"}
0005434573106	FD9731	0948 944610	NINA LAZAREVA	{"phone": "+70093908654"}
0005434573107	5E9BDB	0213 382061	RAISA FROLOVA	{"phone": "+70196132775"}
0005434573108	8C25D4	4823 561084	ANDREY DENISOV	{"email": "andrey_denisov_1973@postgrespro.ru", "phone": "+70111433472"}
0005434573109	E333AA	8298 390869	EVGENIY DENISOV	{"email": "edenisov_1984@postgrespro.ru", "phone": "+70034625994"}
0005434573110	E333AA	8335 041686	SVETLANA ROMANOVA	{"email": "s.romanova_29061957@postgrespro.ru", "phone": "+70558173511"}
0005434573111	B6BE8B	2764 503394	LIDIYA NIKOLAEVA	{"phone": "+70673553473"}
0005434573112	3C6CFC	6300 438588	VYACHESLAV KUZNECOV	{"phone": "+70744231441"}
0005434573113	342050	5407 014413	OLGA NIKOLAEVA	{"phone": "+70968094532"}
0005434573114	342050	4324 914313	DMITRIY KUZNECOV	{"phone": "+70169114555"}
0005434573115	3F1EF3	9646 623464	ALINA DENISOVA	{"phone": "+70998814764"}
0005434573116	29DC1C	7062 954339	ALEKSANDR PETROV	{"phone": "+70419402689"}
0005434573117	5BF661	0915 173552	KRISTINA NESTEROVA	{"phone": "+70325718237"}
0005434573118	5BF661	8587 399858	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva_091979@postgrespro.ru", "phone": "+70078426206"}
0005434573119	FE0980	8683 577579	VLADIMIR NOVIKOV	{"phone": "+70009155193"}
0005434573120	F05E2B	3777 320747	GENNADIY SIDOROV	{"phone": "+70920640339"}
0005434573121	811129	0785 972679	KIRILL VOLKOV	{"email": "volkovk.1968@postgrespro.ru", "phone": "+70316663310"}
0005434573122	A5BF02	9544 906304	ZHANNA STEPANOVA	{"email": "z.stepanova_24021987@postgrespro.ru", "phone": "+70063997412"}
0005434573123	AFF767	9585 257800	ALENA ORLOVA	{"phone": "+70174706198"}
0005434573124	7B8F35	8610 549668	EKATERINA ZHURAVLEVA	{"email": "zhuravleva_ekaterina_16111987@postgrespro.ru", "phone": "+70125366575"}
0005434573125	7B8F35	9690 957093	VERA NIKOLAEVA	{"phone": "+70498380350"}
0005434573126	7B8F35	0611 098387	ELENA CHERNOVA	{"email": "elena-chernova-12101960@postgrespro.ru", "phone": "+70861884404"}
0005434573127	7EC010	0962 747143	NARIMAN EGOROV	{"email": "n-egorov.25121975@postgrespro.ru", "phone": "+70933497829"}
0005434573128	7EC010	2982 799304	NATALYA BARANOVA	{"email": "baranova.n091968@postgrespro.ru", "phone": "+70488321302"}
0005434573129	7EC010	4094 342169	MARIYA STEPANOVA	{"phone": "+70496976214"}
0005434573130	FAC4CE	4186 242579	DANIIL BARANOV	{"email": "d_baranov-22051967@postgrespro.ru", "phone": "+70943003897"}
0005434573131	3CB40C	6488 481327	TATYANA POPOVA	{"email": "popova-t_1964@postgrespro.ru", "phone": "+70337583683"}
0005434573132	3CB40C	2498 968548	DARYA KUZNECOVA	{"email": "kuznecova_darya_1967@postgrespro.ru", "phone": "+70541949264"}
0005434573133	1227DD	2705 250165	SERGEY SIDOROV	{"email": "s-sidorov31051981@postgrespro.ru", "phone": "+70602144167"}
0005434573134	1CD77F	8194 327408	NINA NOVIKOVA	{"email": "novikova.nina-27101984@postgrespro.ru", "phone": "+70070075065"}
0005434573135	7CE02B	5967 899424	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr061973@postgrespro.ru", "phone": "+70202138862"}
0005434573136	CB5506	9731 006480	ANNA MIKHAYLOVA	{"email": "mikhaylova_anna.1981@postgrespro.ru", "phone": "+70033529413"}
0005434573137	EED48C	0831 325073	KLAVDIYA VASILEVA	{"phone": "+70723334025"}
0005434573138	EED48C	9017 136956	VALERIY MIRONOV	{"phone": "+70493935896"}
0005434573139	620EE0	2266 636702	OLGA FROLOVA	{"phone": "+70008951510"}
0005434573140	5F0E77	4781 907627	RADIK NOVIKOV	{"phone": "+70534914575"}
0005434573141	4676FC	9481 155836	SAVELIY KISELEV	{"email": "saveliykiselev22031975@postgrespro.ru", "phone": "+70158806927"}
0005434573142	6A5D97	4860 184948	YURIY BELOV	{"email": "belov_y_071980@postgrespro.ru", "phone": "+70622070862"}
0005434573143	6A5D97	9896 271297	ALEKSANDR ZAKHAROV	{"email": "a_zakharov27081966@postgrespro.ru", "phone": "+70499032279"}
0005434573144	F4319B	0907 107666	DMITRIY VLASOV	{"email": "vlasovdmitriy-011975@postgrespro.ru", "phone": "+70502614898"}
0005434573145	F42876	1665 304422	TATYANA FEDOROVA	{"phone": "+70091191226"}
0005434573146	91E0FF	7570 392358	ROMAN SEMENOV	{"email": "semenov-r011982@postgrespro.ru", "phone": "+70622872337"}
0005434573147	73EA91	9493 995345	ALEKSANDR MOISEEV	{"phone": "+70082493385"}
0005434573148	73EA91	5464 385420	IGOR KUZNECOV	{"email": "kuznecov_igor-051956@postgrespro.ru", "phone": "+70090679694"}
0005434573149	0A3312	4084 462568	GALINA DMITRIEVA	{"email": "dmitrieva.g.111979@postgrespro.ru", "phone": "+70415481278"}
0005434573150	0A3312	3080 431612	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr091967@postgrespro.ru", "phone": "+70604897675"}
0005434573151	9C7B6B	8412 563320	VALERIY MAKSIMOV	{"phone": "+70157807169"}
0005434573152	DB18D3	9514 421423	DANIIL ZHURAVLEV	{"phone": "+70881265449"}
0005434573153	B96F5F	2111 505033	TATYANA MAKAROVA	{"phone": "+70423506665"}
0005434573154	B96F5F	9145 625754	VLADISLAV KAZAKOV	{"phone": "+70380106775"}
0005434573155	B96F5F	5851 789329	VASILIY KOROLEV	{"phone": "+70712140712"}
0005434573156	2C0F55	6878 366817	ARINA FOMINA	{"email": "afomina-071967@postgrespro.ru", "phone": "+70155013041"}
0005434573157	742674	8668 977003	ALEKSANDR NIKITIN	{"phone": "+70815028321"}
0005434573158	16D1FC	5951 749536	LYUBOV MAKSIMOVA	{"email": "maksimovalyubov1971@postgrespro.ru", "phone": "+70246977545"}
0005434573159	F7B812	9506 585346	VLADIMIR SOLOVEV	{"phone": "+70982707958"}
0005434573160	F7B812	7022 798611	IRINA BELOVA	{"phone": "+70626873853"}
0005434573161	F7B812	2711 521380	EVGENIY DENISOV	{"phone": "+70905108445"}
0005434573162	DD0339	4255 641926	ANDREY MIRONOV	{"phone": "+70960420877"}
0005434573163	B6380F	1230 156060	OLGA KONOVALOVA	{"email": "konovalovao1977@postgrespro.ru", "phone": "+70418942774"}
0005434573164	B6380F	2549 354894	NATALYA IVANOVA	{"phone": "+70847816910"}
0005434573165	536999	2923 266397	NAILYA KUZNECOVA	{"email": "nkuznecova_22091974@postgrespro.ru", "phone": "+70980938677"}
0005434573166	536999	7052 735317	VLADIMIR ANDREEV	{"email": "andreev_v.1963@postgrespro.ru", "phone": "+70455229023"}
0005434573167	B6F13E	8078 469814	VIKTOR BONDARENKO	{"email": "bondarenkoviktor1973@postgrespro.ru", "phone": "+70631783497"}
0005434573168	DF9080	1141 669926	NINA BELOVA	{"phone": "+70581432698"}
0005434573169	458076	0251 968355	VITALIY SIDOROV	{"email": "vitaliy-sidorov.1973@postgrespro.ru", "phone": "+70849238580"}
0005434573170	F39CFC	4143 109805	VLADIMIR KUZNECOV	{"phone": "+70570772565"}
0005434573171	878D4C	5704 448820	GALINA ZHUKOVA	{"phone": "+70452673648"}
0005434573172	878D4C	0394 008148	OLESYA ALEKSANDROVA	{"phone": "+70983155677"}
0005434573173	D4EF0C	8985 047631	ARTEM ZAKHAROV	{"email": "azakharov.021977@postgrespro.ru", "phone": "+70638103092"}
0005434573174	D4EF0C	4993 404387	NADEZHDA NESTEROVA	{"email": "n.nesterova-081971@postgrespro.ru", "phone": "+70364088484"}
0005434573175	190A5B	9580 981272	VLADISLAV KAZAKOV	{"phone": "+70837328281"}
0005434573176	1BF9F1	4524 898351	ALEKSEY TARASOV	{"phone": "+70797134941"}
0005434573177	05BF46	5372 417049	KIRILL BORISOV	{"email": "kborisov-1979@postgrespro.ru", "phone": "+70961251080"}
0005434573178	05BF46	7754 211264	IVAN DAVYDOV	{"phone": "+70226117965"}
0005434573179	5E88D2	1695 725376	MARIYA PETROVA	{"email": "mariya.petrova-031969@postgrespro.ru", "phone": "+70172449286"}
0005434573180	6589C6	9782 243217	ANATOLIY ROMANOV	{"phone": "+70658597052"}
0005434573181	11A9D5	6837 235590	KIRILL SMIRNOV	{"email": "smirnov.k_1977@postgrespro.ru", "phone": "+70202895680"}
0005434573182	11A9D5	9899 736879	YAKOV IVANOV	{"email": "ivanov_y071982@postgrespro.ru", "phone": "+70933321428"}
0005434573183	965200	3289 458111	VALENTINA NIKIFOROVA	{"phone": "+70779570165"}
0005434573184	785D4B	4046 566734	VALERIY PAVLOV	{"email": "v-pavlov-041976@postgrespro.ru", "phone": "+70738939856"}
0005434573185	785D4B	1692 757984	LYUBOV LEBEDEVA	{"email": "lebedeva-l-111979@postgrespro.ru", "phone": "+70421409048"}
0005434573186	E8CED0	7750 428327	OLGA ZHUKOVA	{"phone": "+70172357776"}
0005434573187	EF7ECE	4686 411172	NIKOLAY NAUMOV	{"email": "n_naumov.011964@postgrespro.ru", "phone": "+70029193399"}
0005434573188	E1515C	8791 188019	NIKOLAY MATVEEV	{"email": "nmatveev.20081967@postgrespro.ru", "phone": "+70931279960"}
0005434573189	E1515C	7955 797988	GENNADIY TARASOV	{"phone": "+70516886479"}
0005434573190	83C0A1	9235 608364	LARISA SCHERBAKOVA	{"phone": "+70438173411"}
0005434573191	83C0A1	0879 500732	VYACHESLAV KONOVALOV	{"phone": "+70550939288"}
0005434573192	83C0A1	4036 582119	SERGEY NIKITIN	{"email": "nikitin.s-071962@postgrespro.ru", "phone": "+70216307692"}
0005434573193	C909EF	8931 965361	GEORGIY VASILEV	{"email": "vasilev.georgiy_091968@postgrespro.ru", "phone": "+70320179538"}
0005434573194	B1A68A	1607 128335	OKSANA NAZAROVA	{"email": "o_nazarova.24041968@postgrespro.ru", "phone": "+70724571415"}
0005434573195	B1A68A	3375 185129	ELENA GAVRILOVA	{"phone": "+70292460684"}
0005434573196	F22090	2795 880760	FEDOR ROMANOV	{"email": "f-romanov-27051988@postgrespro.ru", "phone": "+70767976756"}
0005434573197	36189A	3709 890779	KLAVDIYA FILIPPOVA	{"phone": "+70575642453"}
0005434573198	367C61	9658 967114	OLGA MAKAROVA	{"phone": "+70385646958"}
0005434573199	963470	0264 546418	NATALYA MASLOVA	{"phone": "+70813050701"}
0005434573200	963470	7273 048758	VALENTINA KOLESNIKOVA	{"email": "v-kolesnikova-081962@postgrespro.ru", "phone": "+70673205733"}
0005434573201	257F06	2210 592593	VERA IVANOVA	{"phone": "+70380577350"}
0005434573202	257F06	9885 235607	VERA KUZNECOVA	{"email": "vkuznecova.05041971@postgrespro.ru", "phone": "+70017276379"}
0005434573203	B35131	0948 181243	MIKHAIL BARANOV	{"phone": "+70127771644"}
0005434573204	99B61C	8711 516117	TATYANA MELNIKOVA	{"phone": "+70561611033"}
0005434573205	0C1B9F	5354 284435	ANGELINA SERGEEVA	{"phone": "+70328735129"}
0005434573206	0C1B9F	2497 782536	MARGARITA NESTEROVA	{"email": "nesterova_margarita-1959@postgrespro.ru", "phone": "+70211798021"}
0005434573207	9A97F4	6535 183447	GALINA ZAYCEVA	{"email": "zayceva_galina_111956@postgrespro.ru", "phone": "+70520448821"}
0005434573208	267A36	0289 232794	DMITRIY VASILEV	{"email": "dvasilev.071978@postgrespro.ru", "phone": "+70988145152"}
0005434573209	267A36	7829 090627	YAROSLAV ANDREEV	{"email": "y.andreev.071974@postgrespro.ru", "phone": "+70435945486"}
0005434573210	2EFE2F	7789 646056	SAVELIY IVANOV	{"email": "ivanov_s1963@postgrespro.ru", "phone": "+70619992314"}
0005434573211	C6798B	6219 246551	VLADIMIR FEDOTOV	{"phone": "+70461821164"}
0005434573212	E9D135	5641 685588	ALEKSANDR SAVELEV	{"phone": "+70911104933"}
0005434573213	709E32	9327 362939	LIDIYA KUZNECOVA	{"phone": "+70356834253"}
0005434573214	709E32	1756 207384	PAVEL IVANOV	{"email": "pavel_ivanov_031973@postgrespro.ru", "phone": "+70587452432"}
0005434573215	94AA37	2446 867230	PETR KUZNECOV	{"phone": "+70746796735"}
0005434573216	30F1AD	9639 830171	VASILIY SMIRNOV	{"phone": "+70838268924"}
0005434573217	5662E2	7929 731097	ALEKSEY BELOV	{"phone": "+70220894614"}
0005434573218	25779D	9541 494299	ALEKSANDR BARANOV	{"phone": "+70502360666"}
0005434573219	25779D	2605 201925	VLADIMIR DENISOV	{"email": "denisov_vladimir011967@postgrespro.ru", "phone": "+70236041727"}
0005434573220	308F25	5964 205411	ALEKSEY GAVRILOV	{"email": "gavrilov.a-20051979@postgrespro.ru", "phone": "+70377366763"}
0005434573221	B62405	1885 065945	TATYANA ZAYCEVA	{"email": "zayceva.tatyana1962@postgrespro.ru", "phone": "+70801873025"}
0005434573222	736237	3813 398471	DMITRIY STEPANOV	{"phone": "+70809919187"}
0005434573223	613BA3	5362 488494	EDUARD VOLKOV	{"phone": "+70114671709"}
0005434573224	760F34	0986 293361	VYACHESLAV KAZAKOV	{"email": "vkazakov061975@postgrespro.ru", "phone": "+70999321379"}
0005434573225	610126	0356 628815	TATYANA POPOVA	{"phone": "+70166831313"}
0005434573226	295EE6	6421 581376	NATALYA MIKHAYLOVA	{"email": "mikhaylova_natalya.111970@postgrespro.ru", "phone": "+70641779013"}
0005434573227	8FFEC9	7817 193285	LYUDMILA VOLKOVA	{"phone": "+70104536377"}
0005434573228	8FFEC9	0290 659935	VALENTINA IVANOVA	{"phone": "+70312605796"}
0005434573229	D455CE	4671 939950	LIDIYA MAKAROVA	{"phone": "+70532557616"}
0005434573230	843D2E	4212 470948	VADIM GRIGOREV	{"email": "grigorevv_061975@postgrespro.ru", "phone": "+70059126527"}
0005434573231	843D2E	7874 751066	ALEKSEY MELNIKOV	{"phone": "+70869455448"}
0005434573232	7D37D7	3373 046734	NADEZHDA LEBEDEVA	{"phone": "+70447983474"}
0005434573233	24F66B	1427 805000	ALEKSANDR SERGEEV	{"phone": "+70457628376"}
0005434573234	976DBE	0498 566420	MARIYA ZOTOVA	{"email": "m.zotova_061962@postgrespro.ru", "phone": "+70774459725"}
0005434573235	976DBE	5410 619291	ALEKSANDR DENISOV	{"phone": "+70775324514"}
0005434573236	7A81DF	2948 116520	DARYA MAKAROVA	{"email": "makarova-darya_1978@postgrespro.ru", "phone": "+70802891096"}
0005434573237	D6528A	3189 969637	ELENA POPOVA	{"email": "elena-popova_1972@postgrespro.ru", "phone": "+70125625859"}
0005434573238	F84BBE	9571 615277	OLGA STEPANOVA	{"phone": "+70326678472"}
0005434573239	F84BBE	4412 213328	PETR BELOV	{"phone": "+70146698768"}
0005434573240	7F0D3E	0514 757126	SVETLANA GERASIMOVA	{"phone": "+70694449131"}
0005434573241	C3CA29	8693 784082	OLGA BARANOVA	{"email": "olgabaranova-04051979@postgrespro.ru", "phone": "+70821790956"}
0005434573242	BC9415	0234 205995	SVETLANA ROMANOVA	{"email": "romanova_svetlana1979@postgrespro.ru", "phone": "+70040799862"}
0005434573243	769EBB	8348 067267	RUSLAN BORISOV	{"email": "borisov.ruslan.021981@postgrespro.ru", "phone": "+70199414852"}
0005434573244	769EBB	5043 241987	EVGENIY YAKOVLEV	{"email": "evgeniyyakovlev-10061977@postgrespro.ru", "phone": "+70215882757"}
0005434573245	769EBB	4914 236742	MAKSIM NOVIKOV	{"email": "novikov-m-041975@postgrespro.ru", "phone": "+70405477278"}
0005434573246	1463CD	8037 943361	ELENA LEBEDEVA	{"phone": "+70431389452"}
0005434573247	1463CD	1277 645910	VYACHESLAV KUZMIN	{"phone": "+70896466538"}
0005434573248	93FE24	9445 454586	NATALIYA VOROBEVA	{"email": "vorobevan07101977@postgrespro.ru", "phone": "+70154951341"}
0005434573249	F151F4	5232 756905	IGOR GRIGOREV	{"email": "grigorev_igor03031969@postgrespro.ru", "phone": "+70062766219"}
0005434573250	9022A3	3647 062284	PETR MAKAROV	{"email": "petr_makarov.1977@postgrespro.ru", "phone": "+70113051673"}
0005434573251	7C91C2	6039 887769	TATYANA AFANASEVA	{"phone": "+70360533481"}
0005434573252	D1FC43	9344 988914	DMITRIY AFANASEV	{"phone": "+70254727469"}
0005434573253	356326	8437 921317	VLADISLAV ISAEV	{"phone": "+70694192707"}
0005434573254	356326	1007 408289	EKATERINA YUDINA	{"phone": "+70808457945"}
0005434573255	35958B	2639 949543	DMITRIY EGOROV	{"phone": "+70018633268"}
0005434573256	35958B	2945 799307	MIKHAIL PAVLOV	{"email": "pavlov-m_061972@postgrespro.ru", "phone": "+70314961627"}
0005434573257	35958B	7510 134531	NATALIYA MIRONOVA	{"email": "mironovanataliya28071977@postgrespro.ru", "phone": "+70180247318"}
0005434573258	816185	9164 264314	TATYANA KAZAKOVA	{"phone": "+70962532395"}
0005434573259	166274	5662 246175	DANIIL MAKAROV	{"email": "makarov-d-031970@postgrespro.ru", "phone": "+70076598142"}
0005434573260	166274	4575 315987	VASILIY ZAYCEV	{"phone": "+70894167856"}
0005434573261	640156	7967 884547	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin.28071984@postgrespro.ru", "phone": "+70014610146"}
0005434573262	8D7B81	4054 668250	NATALYA ZAKHAROVA	{"email": "natalyazakharova-07101971@postgrespro.ru", "phone": "+70752341999"}
0005434573263	6B3B4B	3206 601541	TATYANA PAVLOVA	{"email": "tpavlova-081969@postgrespro.ru", "phone": "+70809669863"}
0005434573264	69844D	5382 369364	VYACHESLAV MAKAROV	{"phone": "+70877118525"}
0005434573265	AEA687	5396 981095	TATYANA ZAYCEVA	{"phone": "+70120945812"}
0005434573266	71066B	8012 894966	MAKSIM KOROLEV	{"phone": "+70556605138"}
0005434573267	676259	3729 989949	VYACHESLAV BORISOV	{"phone": "+70451646209"}
0005434573268	FB017C	1689 945234	NAIL KARPOV	{"phone": "+70401592888"}
0005434573269	2A8FF8	0231 937514	DMITRIY ZHURAVLEV	{"email": "dmitriyzhuravlev_111967@postgrespro.ru", "phone": "+70474030879"}
0005434573270	1D404C	4623 127494	RUSTAM YAKOVLEV	{"phone": "+70058717544"}
0005434573271	30E7E8	9339 484514	VALENTINA KOROLEVA	{"phone": "+70672041268"}
0005434573272	EB0912	3438 195880	VIKTOR TARASOV	{"phone": "+70149139512"}
0005434573273	2EEABA	5675 184362	EVGENIY TIKHONOV	{"phone": "+70428208924"}
0005434573274	679A72	4035 267097	VALENTINA LAZAREVA	{"email": "valentina.lazareva-19121976@postgrespro.ru", "phone": "+70186815739"}
0005434573275	97DE6F	7034 285551	SVETLANA FEDOROVA	{"email": "fedorovas_091972@postgrespro.ru", "phone": "+70481097255"}
0005434573276	7BAB64	2659 878819	VALENTINA ZAYCEVA	{"email": "vzayceva.24111968@postgrespro.ru", "phone": "+70479420634"}
0005434573277	F23B44	0176 628158	LIDIYA PETROVA	{"email": "petrova-lidiya_04041967@postgrespro.ru", "phone": "+70928029958"}
0005434573278	09E817	4499 000669	TATYANA TARASOVA	{"email": "tarasova_t_01041963@postgrespro.ru", "phone": "+70734447826"}
0005434573279	09E817	8916 787706	FARID BARANOV	{"phone": "+70779380985"}
0005434573280	09E817	2939 685691	NATALYA DENISOVA	{"phone": "+70534653822"}
0005434573281	C1E63D	2618 078827	DENIS ANTONOV	{"email": "antonovd-1971@postgrespro.ru", "phone": "+70209109236"}
0005434573282	5BF58F	7882 563891	DENIS TIKHONOV	{"email": "tikhonov-d.15071965@postgrespro.ru", "phone": "+70322402893"}
0005434573283	462A22	0790 102743	DMITRIY KUDRYASHOV	{"phone": "+70598883106"}
0005434573284	51DE21	0112 517992	ALEKSEY NIKOLAEV	{"phone": "+70164538661"}
0005434573285	873ED8	2696 222931	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova.aleksandra-091978@postgrespro.ru", "phone": "+70437507948"}
0005434573286	DB7E00	4611 368352	EVGENIY ALEKSANDROV	{"email": "evgeniy.aleksandrov-041969@postgrespro.ru", "phone": "+70764264677"}
0005434573287	347C4F	4944 272421	SVETLANA MOROZOVA	{"email": "s-morozova07111968@postgrespro.ru", "phone": "+70001311807"}
0005434573288	BF5B8D	0630 870337	NATALYA FEDOROVA	{"email": "fedorova.n1966@postgrespro.ru", "phone": "+70405402147"}
0005434573289	B48010	1388 300699	EVGENIY MAKAROV	{"email": "e_makarov.06051971@postgrespro.ru", "phone": "+70940193368"}
0005434573290	2B1FE1	5950 557569	GEORGIY MEDVEDEV	{"email": "medvedev-g1971@postgrespro.ru", "phone": "+70781593215"}
0005434573291	2B1FE1	0769 825589	NATALYA IVANOVA	{"email": "ivanova-natalya.25081981@postgrespro.ru", "phone": "+70749727935"}
0005434573292	3B8FB0	7829 430284	SERGEY FEDOROV	{"email": "sergey-fedorov-19031967@postgrespro.ru", "phone": "+70836122003"}
0005434573293	803F23	0307 356927	NATALYA MASLOVA	{"email": "maslova.natalya_1968@postgrespro.ru", "phone": "+70275291744"}
0005434573294	2587FD	1522 194335	VITALIY ALEKSEEV	{"phone": "+70410677788"}
0005434573295	E97F75	2048 827016	ELIZAVETA KUZNECOVA	{"phone": "+70515164574"}
0005434573296	2ED6FB	3641 287522	VYACHESLAV BELOV	{"email": "belov.vyacheslav1982@postgrespro.ru", "phone": "+70181061773"}
0005434573297	D0DC9E	4413 657471	LEYLA IVANOVA	{"phone": "+70633340311"}
0005434573298	3F5962	1041 157510	MARIYA IVANOVA	{"phone": "+70328469941"}
0005434573299	3F5962	4659 168616	ELENA FEDOROVA	{"phone": "+70845372658"}
0005434573300	0C2E91	3743 174107	NIKOLAY SOLOVEV	{"email": "nikolay.solovev1972@postgrespro.ru", "phone": "+70732989339"}
0005434573301	0C2E91	7281 361547	LILIYA KOZLOVA	{"email": "kozlova-liliya-011966@postgrespro.ru", "phone": "+70723718369"}
0005434573302	DF5161	8366 281875	NINA STEPANOVA	{"email": "stepanova_n121981@postgrespro.ru", "phone": "+70328325086"}
0005434573303	DF5161	0090 284127	VITALIY FROLOV	{"email": "v_frolov_1966@postgrespro.ru", "phone": "+70559564938"}
0005434573304	053C61	3276 173941	EVGENIY SOKOLOV	{"email": "sokolov-evgeniy_1986@postgrespro.ru", "phone": "+70338574438"}
0005434573305	053C61	6801 998587	ARTEM DMITRIEV	{"phone": "+70682500885"}
0005434573306	053C61	1815 631269	TATYANA MIKHAYLOVA	{"email": "mikhaylova.t-31011978@postgrespro.ru", "phone": "+70136494287"}
0005434573307	B17DAD	7222 554151	NIKOLAY SOLOVEV	{"email": "solovev-n_121970@postgrespro.ru", "phone": "+70559110536"}
0005434573308	5E4DFF	7234 746657	DENIS SERGEEV	{"phone": "+70562165039"}
0005434573309	0EAD01	9248 895469	VASILIY GUSEV	{"phone": "+70026843304"}
0005434573310	EB02E5	7034 137537	SVETLANA EFREMOVA	{"email": "s.efremova_1972@postgrespro.ru", "phone": "+70646412423"}
0005434573311	6611DF	3684 323065	NADEZHDA PETROVA	{"phone": "+70458784938"}
0005434573312	8BB574	6900 428829	ANDREY VOROBEV	{"phone": "+70175389411"}
0005434573313	ED4492	9776 581406	ANATOLIY KISELEV	{"phone": "+70434499642"}
0005434573314	7E983C	0138 739995	GEORGIY KUZMIN	{"email": "g_kuzmin.011967@postgrespro.ru", "phone": "+70594437881"}
0005434573315	7E983C	3802 458385	NADEZHDA IVANOVA	{"email": "ivanova.nadezhda-27041975@postgrespro.ru", "phone": "+70242995054"}
0005434573316	84188A	2295 313550	VALERIY BORISOV	{"email": "valeriyborisov_071971@postgrespro.ru", "phone": "+70657342155"}
0005434573317	84188A	2767 300155	TATYANA ZAKHAROVA	{"email": "zakharova.tatyana17041978@postgrespro.ru", "phone": "+70988087910"}
0005434573318	A2E81E	8583 046111	YULIYA FILATOVA	{"phone": "+70810362057"}
0005434573319	1CBD68	5352 055725	SERGEY MEDVEDEV	{"phone": "+70814041727"}
0005434573320	473308	2444 571279	IRINA FOMINA	{"email": "ifomina_101982@postgrespro.ru", "phone": "+70863646133"}
0005434573321	473308	5086 033990	YURIY SOKOLOV	{"email": "sokolovyuriy-23061969@postgrespro.ru", "phone": "+70166674041"}
0005434573322	473308	5902 520271	MIKHAIL AFANASEV	{"email": "m_afanasev.1977@postgrespro.ru", "phone": "+70273129010"}
0005434573323	A12522	6012 076521	ELENA KUZNECOVA	{"email": "kuznecova.e_03081972@postgrespro.ru", "phone": "+70560520865"}
0005434573324	E96E75	5652 860635	ALEKSEY MOISEEV	{"phone": "+70973238683"}
0005434573325	CB37F2	0895 887162	EVGENIYA MOISEEVA	{"email": "evgeniya_moiseeva_06031973@postgrespro.ru", "phone": "+70952637920"}
0005434573326	CB37F2	7589 389865	ANDREY IVANOV	{"phone": "+70720892585"}
0005434573327	872A3A	3690 307716	YULIYA KARPOVA	{"phone": "+70809312170"}
0005434573328	D9870D	6366 124138	IRINA NAUMOVA	{"email": "naumova-irina-091975@postgrespro.ru", "phone": "+70218065653"}
0005434573329	C3F4AE	1147 423292	VASILIY NIKOLAEV	{"phone": "+70194106123"}
0005434573330	333C39	7666 839055	NATALYA SIDOROVA	{"email": "n.sidorova-19121972@postgrespro.ru", "phone": "+70039372795"}
0005434573331	8DA43B	7179 935762	ELENA FILIPPOVA	{"phone": "+70197572658"}
0005434573332	420935	6658 813590	ELIZAVETA VASILEVA	{"email": "vasileva-elizaveta-071980@postgrespro.ru", "phone": "+70265367917"}
0005434573333	CBA897	3646 599296	LYUBOV MAKSIMOVA	{"phone": "+70145966975"}
0005434573334	246017	7946 869714	GEORGIY NAZAROV	{"phone": "+70774524043"}
0005434573335	246017	5264 136006	MARINA KUZNECOVA	{"phone": "+70729404835"}
0005434573336	2D9EE6	8741 149316	VIKTOR GUSEV	{"email": "gusev.v.071980@postgrespro.ru", "phone": "+70368698496"}
0005434573337	2D9EE6	1202 163330	NADEZHDA SOROKINA	{"email": "sorokina-nadezhda.101971@postgrespro.ru", "phone": "+70023811569"}
0005434573338	5A53DF	5878 730396	ALEKSANDR DMITRIEV	{"email": "dmitrieva_04051956@postgrespro.ru", "phone": "+70859333141"}
0005434573339	093ADF	1518 080850	ALINA IVANOVA	{"email": "ivanova_alina.081966@postgrespro.ru", "phone": "+70582524649"}
0005434573340	86E80E	3772 594510	EVGENIY STEPANOV	{"phone": "+70591240401"}
0005434573341	86E80E	7374 967504	GALINA VOLKOVA	{"email": "volkova_g081965@postgrespro.ru", "phone": "+70761821013"}
0005434573342	3E00AC	4786 657552	LYUDMILA ROMANOVA	{"phone": "+70996941568"}
0005434573343	3E02E0	9607 709673	EKATERINA ZAKHAROVA	{"email": "ekaterina-zakharova-1974@postgrespro.ru", "phone": "+70702558897"}
0005434573344	DCD70B	6886 901745	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov_21041966@postgrespro.ru", "phone": "+70628997212"}
0005434573345	18691C	6223 723236	DMITRIY SHEVCHENKO	{"email": "d-shevchenko.23041967@postgrespro.ru", "phone": "+70643514820"}
0005434573346	18691C	8476 695839	YAKOV SOLOVEV	{"phone": "+70960124945"}
0005434573347	358CDF	9008 605129	VALERIYA MEDVEDEVA	{"phone": "+70884672731"}
0005434573348	E55B78	2945 224171	IVAN MOROZOV	{"email": "morozovi-031968@postgrespro.ru", "phone": "+70782169138"}
0005434573349	785BC4	2827 877975	ELENA KOLESNIKOVA	{"phone": "+70591695381"}
0005434573350	785BC4	7866 481584	VALERIY MIRONOV	{"phone": "+70771874147"}
0005434573351	03367A	2411 037995	SAMVEL PAVLOV	{"phone": "+70377794716"}
0005434573352	ACF4D1	2378 502836	OLEG SOKOLOV	{"email": "sokolov-o_1961@postgrespro.ru", "phone": "+70723912675"}
0005434573353	DF69B7	7999 636790	TAMARA KOZLOVA	{"email": "kozlova.t-1962@postgrespro.ru", "phone": "+70828326111"}
0005434573354	DF69B7	8987 827162	TATYANA GUSEVA	{"phone": "+70771735686"}
0005434573355	836719	4640 963044	ZINAIDA VASILEVA	{"phone": "+70526703050"}
0005434573356	836719	4609 352310	TATYANA FEDOROVA	{"email": "t_fedorova051974@postgrespro.ru", "phone": "+70302291291"}
0005434573357	9D1866	7429 474963	OKSANA CHERNOVA	{"email": "oksana.chernova_14081978@postgrespro.ru", "phone": "+70603395845"}
0005434573358	375B20	3584 346183	ANZHELIKA KOVALEVA	{"email": "a-kovaleva-1964@postgrespro.ru", "phone": "+70883512560"}
0005434573359	EA2175	3883 883878	RAFAIL POPOV	{"email": "popov-r_061965@postgrespro.ru", "phone": "+70017531588"}
0005434573360	F2236C	0036 438574	NATALYA SERGEEVA	{"email": "sergeevanatalya-14061962@postgrespro.ru", "phone": "+70731592743"}
0005434573361	A0371B	6892 458367	TATYANA KUZNECOVA	{"email": "t.kuznecova.1981@postgrespro.ru", "phone": "+70079686912"}
0005434573362	535C0E	4620 210227	VLADIMIR FEDOTOV	{"phone": "+70017408338"}
0005434573363	E0B64E	4174 253246	ILYA FILIPPOV	{"phone": "+70285759957"}
0005434573364	F776EF	5786 560178	IRINA NIKITINA	{"email": "nikitina-i_021969@postgrespro.ru", "phone": "+70509690754"}
0005434573365	884EAD	1043 235266	ALEKSEY MELNIKOV	{"email": "a_melnikov_011964@postgrespro.ru", "phone": "+70880264241"}
0005434573366	D7F7F1	1314 208017	LYUBOV CHERNOVA	{"email": "chernova_l.17051981@postgrespro.ru", "phone": "+70159226104"}
0005434573367	1EDF31	3432 840106	VALENTINA GAVRILOVA	{"email": "gavrilova-valentina.011978@postgrespro.ru", "phone": "+70736177399"}
0005434573368	0BABD1	1550 235264	VITALIY GRIGOREV	{"email": "grigorevv.081972@postgrespro.ru", "phone": "+70103836270"}
0005434573369	329BD2	0053 044078	YULIYA VOROBEVA	{"email": "y-vorobeva07061984@postgrespro.ru", "phone": "+70701138237"}
0005434573370	C7EFF8	8118 598240	NAIL ROMANOV	{"phone": "+70001926503"}
0005434573371	D57EA0	6686 807767	MAKSIM GORBUNOV	{"email": "m_gorbunov.101969@postgrespro.ru", "phone": "+70427415993"}
0005434573372	439857	6239 057205	ZOYA TIMOFEEVA	{"email": "timofeeva.z-1961@postgrespro.ru", "phone": "+70439066595"}
0005434573373	439857	6354 324213	VASILIY MEDVEDEV	{"email": "medvedev_v.09071975@postgrespro.ru", "phone": "+70580776992"}
0005434573374	36FB4D	9096 523005	TAMARA VOLKOVA	{"email": "volkovat24101970@postgrespro.ru", "phone": "+70513402298"}
0005434573375	456926	4063 237189	EVELINA ZAYCEVA	{"email": "zayceva.evelina.22101975@postgrespro.ru", "phone": "+70707688378"}
0005434573376	225078	0228 397301	ANATOLIY VASILEV	{"phone": "+70263919776"}
0005434573377	284785	2447 393327	ELENA ORLOVA	{"phone": "+70018625883"}
0005434573378	F23247	7218 489373	VIKTORIYA MELNIKOVA	{"phone": "+70259778724"}
0005434573379	826E7D	8975 049279	EKATERINA ANTONOVA	{"phone": "+70805128714"}
0005434573380	7AB6FE	6830 421711	ALEKSEY GORBUNOV	{"phone": "+70539290332"}
0005434573381	7AB6FE	2554 284224	VALENTIN GUSEV	{"email": "gusev-v_1976@postgrespro.ru", "phone": "+70563673569"}
0005434573382	2A33E9	8325 371536	YURIY NOVIKOV	{"email": "novikov-y-111972@postgrespro.ru", "phone": "+70698780121"}
0005434573383	2A33E9	0627 938452	DARYA ROMANOVA	{"phone": "+70688105467"}
0005434573384	D993AE	8205 460063	TAISIYA IVANOVA	{"phone": "+70089657788"}
0005434573385	D993AE	1094 518748	VALENTINA BORISOVA	{"email": "valentinaborisova-011970@postgrespro.ru", "phone": "+70273323035"}
0005434573386	525B57	7069 291055	ALEKSANDR FEDOROV	{"phone": "+70303038018"}
0005434573387	C01079	8027 927487	NIKITA SCHERBAKOV	{"phone": "+70222201717"}
0005434573388	DE23B1	5603 762823	ZINAIDA EGOROVA	{"phone": "+70332531166"}
0005434573389	6D81A7	4307 608487	YULIYA FILATOVA	{"email": "filatovayuliya_011970@postgrespro.ru", "phone": "+70906887938"}
0005434573390	CB2DF3	2464 692838	ILYA BARANOV	{"email": "ibaranov_1992@postgrespro.ru", "phone": "+70862023844"}
0005434573391	AA8042	5548 820164	IRINA KUZNECOVA	{"phone": "+70840786276"}
0005434573392	AA8042	2132 089967	NINA KONDRATEVA	{"phone": "+70003025125"}
0005434573393	11D288	5985 877763	ALEKSANDR ZAKHAROV	{"phone": "+70112607601"}
0005434573394	60C1F3	6897 409989	MARIYA VASILEVA	{"email": "vasileva-m-1973@postgrespro.ru", "phone": "+70501446328"}
0005434573395	A1DDFF	0915 790307	EVGENIY NIKOLAEV	{"email": "nikolaev-e1972@postgrespro.ru", "phone": "+70939481394"}
0005434573396	A1DDFF	9700 282565	ALEKSANDR MIRONOV	{"email": "aleksandr_mironov.031964@postgrespro.ru", "phone": "+70298846243"}
0005434573397	1EE488	0684 135502	TATYANA LUKYANOVA	{"email": "lukyanova_t-1967@postgrespro.ru", "phone": "+70238882681"}
0005434573398	2816A5	3118 742620	ALEKSANDRA GORBUNOVA	{"phone": "+70775595942"}
0005434573399	247864	7151 542117	ALEKSANDR BORISOV	{"email": "borisov_a13111972@postgrespro.ru", "phone": "+70090332300"}
0005434573400	247864	6029 233715	LYUDMILA FOMINA	{"email": "fomina.lyudmila021975@postgrespro.ru", "phone": "+70809551089"}
0005434573401	A5EE61	2338 088707	EKATERINA ROMANOVA	{"email": "ekaterina-romanova_22101972@postgrespro.ru", "phone": "+70072229507"}
0005434573402	80D90E	4507 021584	SERGEY IVANOV	{"email": "ivanov.s_011968@postgrespro.ru", "phone": "+70013916942"}
0005434573403	935FDF	4907 434671	NINA ZAYCEVA	{"phone": "+70622155212"}
0005434573404	C90A1D	2849 197281	ANDREY PETROV	{"email": "petrov-andrey_1977@postgrespro.ru", "phone": "+70746134061"}
0005434573405	E29B5B	9908 522095	ALLA KOROLEVA	{"phone": "+70416438815"}
0005434573406	353780	6326 607800	ELVIRA ZAYCEVA	{"phone": "+70848019954"}
0005434573407	353780	0415 896049	NATALYA SIDOROVA	{"email": "n_sidorova121979@postgrespro.ru", "phone": "+70645283086"}
0005434573408	14A609	7345 631282	NATALYA ZAYCEVA	{"phone": "+70303747867"}
0005434573409	14A609	4351 647041	TATYANA EFIMOVA	{"phone": "+70634785791"}
0005434573410	82108C	0057 187066	ANNA KOROLEVA	{"email": "a-koroleva-18011961@postgrespro.ru", "phone": "+70649849240"}
0005434573411	E5A16D	2866 137206	VLADIMIR STEPANOV	{"phone": "+70658648085"}
0005434573412	54EA73	7792 675325	LARISA RODIONOVA	{"email": "l.rodionova-02021977@postgrespro.ru", "phone": "+70314176782"}
0005434573413	54EA73	3974 216421	NATALYA ALEKSEEVA	{"email": "alekseeva-n_1967@postgrespro.ru", "phone": "+70564914924"}
0005434573414	54EA73	8394 140955	ALEKSANDR ISAEV	{"phone": "+70087374371"}
0005434573415	B1ACE7	3120 385100	ALEKSANDRA EFREMOVA	{"email": "efremova.aleksandra.23031971@postgrespro.ru", "phone": "+70236689019"}
0005434573416	934D83	9964 770794	VALERIY MEDVEDEV	{"email": "valeriy_medvedev-17101974@postgrespro.ru", "phone": "+70100973345"}
0005434573475	2F0C11	0290 810281	EVGENIYA KOZLOVA	{"phone": "+70137348662"}
0005434573417	A2E1BE	9804 912988	ANATOLIY MIKHAYLOV	{"email": "mikhaylovanatoliy_09011973@postgrespro.ru", "phone": "+70457023277"}
0005434573418	A2E1BE	6434 491340	SVETLANA VASILEVA	{"phone": "+70436799124"}
0005434573419	10573A	9390 150474	YURIY ROMANOV	{"email": "y_romanov_09071960@postgrespro.ru", "phone": "+70368710287"}
0005434573420	10573A	3085 674493	LYUDMILA DENISOVA	{"phone": "+70330782563"}
0005434573421	10573A	8859 122472	OLGA SOKOLOVA	{"email": "sokolova_olga01111980@postgrespro.ru", "phone": "+70283209646"}
0005434573422	01F646	8986 145691	ELENA FILIPPOVA	{"phone": "+70764987392"}
0005434573423	7E76C6	2665 322600	VALENTINA GRISHINA	{"email": "v_grishina1974@postgrespro.ru", "phone": "+70889305364"}
0005434573424	3493D1	5611 087122	LYUDMILA NOVIKOVA	{"email": "lnovikova06071971@postgrespro.ru", "phone": "+70845132633"}
0005434573425	3493D1	0337 901958	VERONIKA ANISIMOVA	{"email": "anisimova_v_22031967@postgrespro.ru", "phone": "+70639604759"}
0005434573426	06D05A	8351 927102	SERGEY ILIN	{"email": "sergeyilin_061977@postgrespro.ru", "phone": "+70366697374"}
0005434573427	06D05A	1752 345131	INNA LEBEDEVA	{"phone": "+70317210346"}
0005434573428	8AFD17	7511 660559	LYUBOV IVANOVA	{"email": "ivanova.lyubov22101968@postgrespro.ru", "phone": "+70919609640"}
0005434573429	8AFD17	5136 688902	VALENTINA GORBUNOVA	{"email": "v-gorbunova_081966@postgrespro.ru", "phone": "+70479577685"}
0005434573430	47E941	8287 415813	VLADIMIR ISAEV	{"email": "isaev.v_041973@postgrespro.ru", "phone": "+70624983144"}
0005434573431	47E941	4113 848269	ALEKSANDR BELOV	{"phone": "+70334566482"}
0005434573432	D30720	1913 000566	VERA KUZNECOVA	{"email": "vera.kuznecova1979@postgrespro.ru", "phone": "+70330430905"}
0005434573433	D30720	5563 909263	OLEG VASILEV	{"phone": "+70009831330"}
0005434573434	325223	3965 115671	LYUDMILA ANISIMOVA	{"phone": "+70175774954"}
0005434573435	9CE688	8546 585974	VITALIY BORISOV	{"email": "v_borisov_11021970@postgrespro.ru", "phone": "+70545184188"}
0005434573436	6C3551	7378 751727	IRINA GAVRILOVA	{"email": "gavrilova.irina.1974@postgrespro.ru", "phone": "+70650889584"}
0005434573437	D57A7D	4238 870646	ROZA PETROVA	{"email": "r_petrova.27041968@postgrespro.ru", "phone": "+70015941766"}
0005434573438	D57A7D	9769 880351	DMITRIY PETROV	{"email": "d.petrov_07051972@postgrespro.ru", "phone": "+70142654058"}
0005434573439	D57A7D	2226 840174	ANNA KOROLEVA	{"email": "a-koroleva-13021973@postgrespro.ru", "phone": "+70669609171"}
0005434573440	C5BFFC	5466 871149	MARIYA KISELEVA	{"email": "mkiseleva.041968@postgrespro.ru", "phone": "+70000791229"}
0005434573441	E3D031	4350 973067	ANTON NAZAROV	{"phone": "+70449276906"}
0005434573442	E3D031	1200 195719	MARGARITA ANDREEVA	{"email": "andreeva-margarita.031971@postgrespro.ru", "phone": "+70594777948"}
0005434573443	64463C	2688 809366	EVGENIYA ZOTOVA	{"phone": "+70367927789"}
0005434573444	64463C	4718 909704	ANASTASIYA MARTYNOVA	{"phone": "+70901233438"}
0005434573445	BE742D	4408 542546	MAKSIM MOROZOV	{"email": "mmorozov28111977@postgrespro.ru", "phone": "+70195518678"}
0005434573446	6C57C3	2803 211033	SEMEN TIMOFEEV	{"phone": "+70992566557"}
0005434573447	6C57C3	5256 728712	ALEKSANDR FEDOTOV	{"email": "a-fedotov1972@postgrespro.ru", "phone": "+70011748117"}
0005434573448	1576EA	4687 955279	LYUDMILA SOLOVEVA	{"email": "l.soloveva-091954@postgrespro.ru", "phone": "+70203435056"}
0005434573449	A31175	3723 824378	OLESYA LAZAREVA	{"phone": "+70291314529"}
0005434573450	8B3E1F	8058 636492	ANASTASIYA FOMINA	{"email": "anastasiyafomina.29041966@postgrespro.ru", "phone": "+70687405008"}
0005434573451	6A7932	9209 149203	OKSANA DENISOVA	{"phone": "+70323725154"}
0005434573452	5149A0	0060 733243	NATALYA PETROVA	{"phone": "+70256447818"}
0005434573453	6D807A	6388 730717	PETR MOISEEV	{"email": "moiseev.petr-22101978@postgrespro.ru", "phone": "+70924595217"}
0005434573454	2E057F	0872 717837	YULIYA MAKAROVA	{"phone": "+70701965943"}
0005434573455	2E057F	4966 169433	NIKOLAY TIKHONOV	{"email": "n.tikhonov1971@postgrespro.ru", "phone": "+70114655116"}
0005434573456	9F4038	2481 242823	GRIGORIY MAKAROV	{"phone": "+70355560532"}
0005434573457	9F4038	3330 654560	MIKHAIL ILIN	{"email": "mikhaililin_1979@postgrespro.ru", "phone": "+70950828744"}
0005434573458	89D6AD	0625 561496	VLADIMIR STEPANOV	{"phone": "+70947283121"}
0005434573459	44D9F1	0692 816227	GALINA NOVIKOVA	{"phone": "+70486089055"}
0005434573460	F95777	0075 929521	ELENA EGOROVA	{"email": "egorova_e.051974@postgrespro.ru", "phone": "+70981498495"}
0005434573461	F95777	9667 262748	ELVIRA KOZLOVA	{"email": "kozlova_e.101967@postgrespro.ru", "phone": "+70104261938"}
0005434573462	6A3A03	8840 553667	MIKHAIL ANDREEV	{"email": "mikhail-andreev_1963@postgrespro.ru", "phone": "+70544247378"}
0005434573463	392723	9097 080163	OLGA DAVYDOVA	{"email": "davydova-olga-11081979@postgrespro.ru", "phone": "+70119586436"}
0005434573464	E2B79F	4300 049165	ALEKSEY KOZLOV	{"email": "kozlovaleksey_18011966@postgrespro.ru", "phone": "+70350697461"}
0005434573465	B8FC01	3899 728262	ANDREY YAKOVLEV	{"email": "a_yakovlev13111968@postgrespro.ru", "phone": "+70058012448"}
0005434573466	83AF87	9513 160410	RUSTAM POPOV	{"phone": "+70308203707"}
0005434573467	83AF87	9155 595769	ELENA MARTYNOVA	{"phone": "+70822813546"}
0005434573468	29331C	1633 509370	OLGA LEBEDEVA	{"phone": "+70195614617"}
0005434573469	29331C	8469 926385	LEV TARASOV	{"phone": "+70794780208"}
0005434573470	6B0E02	0116 825294	EVELINA ERMAKOVA	{"phone": "+70913204081"}
0005434573471	6B0E02	7006 208131	EVGENIY SHEVCHENKO	{"email": "shevchenko-evgeniy021966@postgrespro.ru", "phone": "+70047256031"}
0005434573472	AA500E	6496 526501	NADEZHDA FEDOROVA	{"email": "fedorova-n-21011993@postgrespro.ru", "phone": "+70497602485"}
0005434573473	2F0C11	6745 970565	KAPITALINA MIKHAYLOVA	{"email": "k-mikhaylova18041976@postgrespro.ru", "phone": "+70542430908"}
0005434573590	3B2C05	3748 639236	NINA FOMINA	{"phone": "+70757338163"}
0005434573474	2F0C11	2037 246388	YURIY SMIRNOV	{"email": "smirnov_yuriy021969@postgrespro.ru", "phone": "+70561231431"}
0005434573476	2F0C11	1257 314505	ELENA KUZNECOVA	{"email": "kuznecova.elena-1967@postgrespro.ru", "phone": "+70507316220"}
0005434573477	8EEF71	0216 924692	ALEKSANDR VOROBEV	{"phone": "+70438285546"}
0005434573478	7B781B	0916 415017	NIKOLAY IVANOV	{"phone": "+70103925591"}
0005434573479	A6DA2F	3058 325651	ALEKSANDR YAKOVLEV	{"phone": "+70346500402"}
0005434573480	653DFD	9231 559795	NIKOLAY ISAEV	{"phone": "+70727220796"}
0005434573481	653DFD	3861 670543	ALEKSANDR IVANOV	{"email": "a-ivanov.25091971@postgrespro.ru", "phone": "+70570750508"}
0005434573482	653DFD	7369 926233	ANNA ZAYCEVA	{"email": "zayceva.anna_1980@postgrespro.ru", "phone": "+70012575362"}
0005434573483	84F2B5	0964 751562	ANNA GORBUNOVA	{"email": "annagorbunova.07051976@postgrespro.ru", "phone": "+70269215275"}
0005434573484	84F2B5	1818 451417	IRINA SCHERBAKOVA	{"phone": "+70533916670"}
0005434573485	84F2B5	1737 529551	ELMIRA AFANASEVA	{"email": "e_afanaseva1965@postgrespro.ru", "phone": "+70345823590"}
0005434573486	D9EC55	7308 110819	VALENTINA DAVYDOVA	{"email": "davydova.valentina.21091971@postgrespro.ru", "phone": "+70838316469"}
0005434573487	E3966B	6224 687614	LIDIYA LOGINOVA	{"phone": "+70516522238"}
0005434573488	3C6AB5	3408 597428	VLADIMIR IVANOV	{"phone": "+70517241626"}
0005434573489	B21027	1874 679878	LYUDMILA DENISOVA	{"email": "denisova.lyudmila01051978@postgrespro.ru", "phone": "+70805441424"}
0005434573490	F90DFB	9577 973725	VALERIY SMIRNOV	{"phone": "+70001150089"}
0005434573491	F90DFB	6661 064494	ZOYA ZOTOVA	{"phone": "+70524178988"}
0005434573492	B8BCF8	0028 924281	ALEKSANDR ZAYCEV	{"email": "zaycev_a19081971@postgrespro.ru", "phone": "+70756349175"}
0005434573493	B49909	8368 293780	VLADIMIR NOVIKOV	{"email": "novikovv.16091971@postgrespro.ru", "phone": "+70203902243"}
0005434573494	11A830	3795 667018	SERAFIMA MOROZOVA	{"email": "s-morozova.111976@postgrespro.ru", "phone": "+70667872863"}
0005434573495	11A830	5673 315300	ALEKSANDR MATVEEV	{"phone": "+70471245328"}
0005434573496	518595	6941 240950	TATYANA VASILEVA	{"email": "vasileva_t_14091964@postgrespro.ru", "phone": "+70111009811"}
0005434573497	AD4B63	5195 457481	INNA POTAPOVA	{"email": "inna-potapova_1965@postgrespro.ru", "phone": "+70532840192"}
0005434573498	AD4B63	3956 078355	ALEKSANDR MAKSIMOV	{"phone": "+70380870534"}
0005434573499	E212E1	9208 030157	NADEZHDA ABRAMOVA	{"email": "abramova-n1985@postgrespro.ru", "phone": "+70800744295"}
0005434573500	129194	6910 133384	NIKITA VOLKOV	{"email": "nikita.volkov_1969@postgrespro.ru", "phone": "+70837208070"}
0005434573501	9D45FF	1745 733775	LEV SHEVCHENKO	{"email": "l_shevchenko02031963@postgrespro.ru", "phone": "+70579570309"}
0005434573502	9D45FF	2837 753059	VIKTOR MEDVEDEV	{"email": "medvedev_v111977@postgrespro.ru", "phone": "+70641975573"}
0005434573503	C15302	1679 239480	NIKOLAY FEDOROV	{"email": "nikolayfedorov021972@postgrespro.ru", "phone": "+70478537896"}
0005434573504	D81135	5232 222624	VLADISLAV MOROZOV	{"email": "morozov_v.091962@postgrespro.ru", "phone": "+70281468863"}
0005434573505	F7A0B0	2336 952835	TATYANA KONOVALOVA	{"email": "tatyana.konovalova_071973@postgrespro.ru", "phone": "+70784337229"}
0005434573506	F7A0B0	6678 854567	RAMIL SIDOROV	{"phone": "+70333354908"}
0005434573507	B19942	7090 113389	LYUDMILA EFREMOVA	{"email": "lyudmilaefremova1973@postgrespro.ru", "phone": "+70957610896"}
0005434573508	D888C1	9573 583563	MIKHAIL NIKITIN	{"email": "mikhailnikitin031969@postgrespro.ru", "phone": "+70969700960"}
0005434573509	D888C1	3499 730622	MARINA SOROKINA	{"email": "marina.sorokina.1970@postgrespro.ru", "phone": "+70022811470"}
0005434573510	CFD060	4626 938581	ELENA MIRONOVA	{"phone": "+70988754248"}
0005434573511	CFD060	6058 158817	OLGA MELNIKOVA	{"email": "o_melnikova_05061964@postgrespro.ru", "phone": "+70147498697"}
0005434573512	CFD060	1056 357353	SERGEY SAVELEV	{"email": "ssavelev.1974@postgrespro.ru", "phone": "+70862463316"}
0005434573513	2BACD0	9467 296398	ALEKSANDR NIKOLAEV	{"phone": "+70119693300"}
0005434573514	53E71C	8106 329314	ZOYA KUZNECOVA	{"phone": "+70139281893"}
0005434573515	14201B	0337 669958	TATYANA ILINA	{"email": "ilina_t-1969@postgrespro.ru", "phone": "+70852723600"}
0005434573516	CE7736	4720 184928	MARIYA KISELEVA	{"email": "mariya.kiseleva_1979@postgrespro.ru", "phone": "+70246876793"}
0005434573517	8D0A99	5863 821491	MARTA GAVRILOVA	{"phone": "+70788603388"}
0005434573518	741C7E	8121 940228	VERA KUZNECOVA	{"phone": "+70905669692"}
0005434573519	741C7E	3677 832394	NIKOLAY DAVYDOV	{"phone": "+70670546056"}
0005434573520	725F93	2852 491779	VLADIMIR YAKOVLEV	{"email": "yakovlevv-081968@postgrespro.ru", "phone": "+70905450454"}
0005434573521	CD320E	0011 376354	OLESYA NIKOLAEVA	{"phone": "+70522957821"}
0005434573522	075409	3084 844086	VALENTINA MAKAROVA	{"email": "makarova.valentina031974@postgrespro.ru", "phone": "+70251612176"}
0005434573523	075409	6811 871602	ILYA PAVLOV	{"email": "pavlovilya05011988@postgrespro.ru", "phone": "+70514994433"}
0005434573524	547765	7716 020978	SERGEY NIKITIN	{"email": "nikitinsergey23071972@postgrespro.ru", "phone": "+70711161915"}
0005434573525	537949	6813 096008	NIKOLAY FOMIN	{"email": "nikolay.fomin.021969@postgrespro.ru", "phone": "+70411994802"}
0005434573526	3D1599	0417 338753	RINAT KUZNECOV	{"email": "kuznecov_rinat.1968@postgrespro.ru", "phone": "+70567704355"}
0005434573527	3D1599	4374 615326	LYUBOV FOMINA	{"phone": "+70540297285"}
0005434573528	4A8178	6394 140958	MARIYA OVCHINNIKOVA	{"email": "mariya-ovchinnikova-021972@postgrespro.ru", "phone": "+70375145206"}
0005434573529	25D233	7046 065155	ALEKSANDR KAZAKOV	{"email": "a.kazakov_121976@postgrespro.ru", "phone": "+70722777174"}
0005434573530	C04E5F	2730 803472	MAKSIM FILIPPOV	{"phone": "+70243367470"}
0005434573531	C04E5F	2841 594588	EVGENIY KUDRYASHOV	{"phone": "+70882722001"}
0005434573532	7DC4BA	9729 017747	EVGENIY TARASOV	{"email": "tarasov.evgeniy-1973@postgrespro.ru", "phone": "+70370600138"}
0005434573533	7DC4BA	0023 965117	VLADIMIR BELOV	{"phone": "+70953096628"}
0005434573534	7DC4BA	8987 510554	DMITRIY KAZAKOV	{"email": "kazakovd-051971@postgrespro.ru", "phone": "+70124518462"}
0005434573535	12A504	8809 523016	LYUDMILA ZOTOVA	{"email": "lyudmilazotova_121968@postgrespro.ru", "phone": "+70064342655"}
0005434573536	A7311A	8181 686508	TATYANA MATVEEVA	{"email": "t.matveeva_22101977@postgrespro.ru", "phone": "+70868615233"}
0005434573537	A7311A	3831 763287	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov011974@postgrespro.ru", "phone": "+70880409222"}
0005434573538	3FF870	3783 054415	NIKOLAY VASILEV	{"email": "nikolay_vasilev.1978@postgrespro.ru", "phone": "+70389557620"}
0005434573539	3FF870	8597 325636	DMITRIY POPOV	{"phone": "+70233961262"}
0005434573540	0AA5A2	6805 541711	VALENTINA YAKOVLEVA	{"email": "vyakovleva.1961@postgrespro.ru", "phone": "+70975684801"}
0005434573541	0C2C82	7956 945750	MAKSIM STEPANOV	{"phone": "+70275915773"}
0005434573542	BD3D9A	7225 409780	ANDREY SOROKIN	{"phone": "+70137650892"}
0005434573543	BD3D9A	8552 467071	ELENA POPOVA	{"email": "popovaelena-06121968@postgrespro.ru", "phone": "+70284507614"}
0005434573544	76C8E6	8805 299340	RAISA BORISOVA	{"phone": "+70699039652"}
0005434573545	24FCEE	2328 793728	OLESYA ZAKHAROVA	{"phone": "+70723492554"}
0005434573546	59F2A8	0831 833558	RAMIS NOVIKOV	{"phone": "+70078530558"}
0005434573547	59F2A8	4424 812026	NATALYA LUKYANOVA	{"email": "lukyanovan.04111976@postgrespro.ru", "phone": "+70346640287"}
0005434573548	2EEB6D	2787 413018	ALINA LAZAREVA	{"email": "lazareva.a.051966@postgrespro.ru", "phone": "+70579889039"}
0005434573549	2EEB6D	0692 894296	OLGA VLASOVA	{"email": "vlasovaolga-021967@postgrespro.ru", "phone": "+70162974561"}
0005434573550	86CD06	8542 420449	NINA MAKSIMOVA	{"email": "n.maksimova_03121970@postgrespro.ru", "phone": "+70097518148"}
0005434573551	86CD06	5997 845988	SERGEY KRASNOV	{"email": "krasnovsergey_27061976@postgrespro.ru", "phone": "+70770037945"}
0005434573552	500D2D	8008 947093	SERGEY MOISEEV	{"phone": "+70099360866"}
0005434573553	500D2D	1058 070597	EKATERINA MASLOVA	{"email": "maslova_ekaterina21101977@postgrespro.ru", "phone": "+70200560082"}
0005434573554	99AF57	5496 562204	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova-1965@postgrespro.ru", "phone": "+70912733025"}
0005434573555	131ADC	7656 221521	MARIYA KUZMINA	{"email": "m_kuzmina-05111977@postgrespro.ru", "phone": "+70117862206"}
0005434573556	2F3E09	1686 835833	ANNA MAKAROVA	{"phone": "+70284290329"}
0005434573557	CB1AAC	3142 746286	ARTEM ANDREEV	{"email": "andreev.a-081970@postgrespro.ru", "phone": "+70033052637"}
0005434573558	F46833	5773 968471	ALEKSANDR SCHERBAKOV	{"phone": "+70072221648"}
0005434573559	F46833	7412 612830	TATYANA KAZAKOVA	{"email": "kazakova-t_1978@postgrespro.ru", "phone": "+70776438573"}
0005434573560	224A2D	5028 802039	DENIS VASILEV	{"email": "denisvasilev.091959@postgrespro.ru", "phone": "+70075329391"}
0005434573561	BDE360	7869 138087	VIKTOR SHEVCHENKO	{"email": "v-shevchenko111975@postgrespro.ru", "phone": "+70392959889"}
0005434573562	BDE360	2889 619471	OLGA SMIRNOVA	{"phone": "+70119395281"}
0005434573563	BDE360	4660 441070	ANATOLIY KULIKOV	{"email": "anatoliykulikov-091966@postgrespro.ru", "phone": "+70465691747"}
0005434573564	B1E3A1	4471 249626	SERGEY KUZNECOV	{"phone": "+70978037271"}
0005434573565	BCE133	1669 963372	YURIY IVANOV	{"email": "ivanovy-1987@postgrespro.ru", "phone": "+70342234399"}
0005434573566	BCE133	0340 262012	NIKOLAY IVANOV	{"phone": "+70679488321"}
0005434573567	0EB4D1	1283 837994	ALEKSANDRA FEDOROVA	{"phone": "+70858728124"}
0005434573568	F59A3B	4459 471293	TATYANA MIRONOVA	{"phone": "+70601601057"}
0005434573569	F59A3B	1145 840106	TATYANA PAVLOVA	{"email": "tatyana_pavlova_12101961@postgrespro.ru", "phone": "+70040012832"}
0005434573570	76801D	5085 024856	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev.1978@postgrespro.ru", "phone": "+70539851051"}
0005434573571	F5FAFC	0786 435162	SOFYA SOLOVEVA	{"email": "solovevasofya.011990@postgrespro.ru", "phone": "+70442039568"}
0005434573572	413110	6009 143924	MARIYA ALEKSEEVA	{"email": "mariyaalekseeva.091968@postgrespro.ru", "phone": "+70631413782"}
0005434573573	BABD16	7857 430450	LYUDMILA ZAYCEVA	{"email": "zayceva.l.1967@postgrespro.ru", "phone": "+70350105508"}
0005434573574	6AF139	5647 212493	IGOR YAKOVLEV	{"phone": "+70619478175"}
0005434573575	804222	1529 934230	VALERIY BORISOV	{"email": "borisovv_08011971@postgrespro.ru", "phone": "+70824842290"}
0005434573576	804222	3315 831841	SERGEY MARTYNOV	{"phone": "+70408456517"}
0005434573577	40952E	4954 735379	VALERIY ZHURAVLEV	{"phone": "+70072754259"}
0005434573578	F55774	7009 392287	POLINA KALININA	{"email": "kalinina_polina1986@postgrespro.ru", "phone": "+70580050020"}
0005434573579	D77D1F	5982 668735	OKSANA NAZAROVA	{"email": "nazarovaoksana18081977@postgrespro.ru", "phone": "+70393635475"}
0005434573580	D77D1F	9938 846304	TATYANA IVANOVA	{"phone": "+70145372095"}
0005434573581	D77D1F	6475 105951	MARIYA KOZLOVA	{"email": "m.kozlova1975@postgrespro.ru", "phone": "+70084400883"}
0005434573582	B72F16	1699 840817	VLADIMIR ILIN	{"email": "vladimir-ilin.1973@postgrespro.ru", "phone": "+70726028563"}
0005434573583	94BE82	0490 502244	NIKOLAY NOVIKOV	{"phone": "+70468420238"}
0005434573584	8BE83F	7412 208939	PETR VLASOV	{"phone": "+70038787038"}
0005434573585	9FA6E8	2663 767811	VALERIY SIDOROV	{"email": "sidorov-valeriy1980@postgrespro.ru", "phone": "+70534027686"}
0005434573586	356C62	7649 629688	NATALYA KOROLEVA	{"email": "nkoroleva.29091972@postgrespro.ru", "phone": "+70910225790"}
0005434573587	7E83F3	7825 487384	VALENTINA TITOVA	{"email": "valentina-titova-1984@postgrespro.ru", "phone": "+70720322544"}
0005434573588	B60D26	5824 431861	MIKHAIL KUZNECOV	{"email": "kuznecov-m02011960@postgrespro.ru", "phone": "+70555027225"}
0005434573589	245768	7484 164482	LYUDMILA RYABOVA	{"phone": "+70121211566"}
0005434573591	E04C8F	3026 711676	ALEKSANDR FEDOROV	{"phone": "+70964159959"}
0005434573592	ABC6F5	1450 628127	GENNADIY FEDOTOV	{"email": "fedotov-g031972@postgrespro.ru", "phone": "+70873416421"}
0005434573593	E62423	3862 889136	VERA LAZAREVA	{"email": "vera_lazareva.13101971@postgrespro.ru", "phone": "+70206042650"}
0005434573594	E62423	6229 207854	TATYANA MEDVEDEVA	{"email": "medvedeva-t_121971@postgrespro.ru", "phone": "+70068790790"}
0005434573595	4793A8	5178 442596	DMITRIY POPOV	{"email": "dmitriy.popov24061962@postgrespro.ru", "phone": "+70058338918"}
0005434573596	1FF529	4454 492608	OLESYA SOLOVEVA	{"phone": "+70987329827"}
0005434573597	9D5B1D	1856 910074	EVGENIYA KOVALEVA	{"email": "kovaleva.evgeniya_021981@postgrespro.ru", "phone": "+70071033515"}
0005434573598	C4037E	7896 755248	IRINA NIKITINA	{"phone": "+70517847838"}
0005434573599	C4037E	4221 533268	YULIYA GRISHINA	{"email": "y_grishina1964@postgrespro.ru", "phone": "+70089523910"}
0005434573600	B3D867	2988 702166	EKATERINA ILINA	{"email": "ilina-ekaterina.31101961@postgrespro.ru", "phone": "+70350767801"}
0005434573601	8044E3	1960 770032	OLEG BORISOV	{"phone": "+70627542583"}
0005434573602	645163	3875 855867	MARINA MAKAROVA	{"phone": "+70404776190"}
0005434573603	645163	9012 734003	GENNADIY VLASOV	{"email": "vlasov-gennadiy1976@postgrespro.ru", "phone": "+70757596004"}
0005434573604	9CBF4A	6320 163192	VERA MATVEEVA	{"email": "v.matveeva091973@postgrespro.ru", "phone": "+70283446131"}
0005434573605	C629D1	9788 064064	ELENA RODIONOVA	{"phone": "+70997976824"}
0005434573606	B88EB4	4285 821036	LYUBOV FILATOVA	{"email": "l_filatova_1973@postgrespro.ru", "phone": "+70516177818"}
0005434573607	B88EB4	7940 240033	DMITRIY POPOV	{"phone": "+70998623577"}
0005434573608	AC3957	2379 639991	ANDREY ZHUKOV	{"phone": "+70624385500"}
0005434573609	AC3957	4280 369351	NATALYA IVANOVA	{"phone": "+70305663810"}
0005434573610	82C0CD	5099 954249	NINA POPOVA	{"phone": "+70733286518"}
0005434573611	8CC0CD	6643 670870	EVGENIY MAKSIMOV	{"email": "evgeniy.maksimov-1983@postgrespro.ru", "phone": "+70513209397"}
0005434573612	98CE5B	4670 060281	YULIYA FOMINA	{"email": "fomina_y.08101967@postgrespro.ru", "phone": "+70569982018"}
0005434573613	98CE5B	8375 775650	ALEKSANDR SIDOROV	{"phone": "+70114419777"}
0005434573614	1E457D	3733 897528	DMITRIY KONOVALOV	{"phone": "+70830110035"}
0005434573615	1E457D	3184 666861	KSENIYA NAZAROVA	{"email": "nazarova_k051971@postgrespro.ru", "phone": "+70865684090"}
0005434573616	17E38F	0001 953766	NATALYA ANDREEVA	{"phone": "+70193718053"}
0005434573617	17E38F	6524 098213	POLINA KOZLOVA	{"phone": "+70526692328"}
0005434573618	17E38F	7567 783775	TATYANA NIKITINA	{"phone": "+70979271781"}
0005434573619	579D20	1191 582076	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr.011956@postgrespro.ru", "phone": "+70956920742"}
0005434573620	579D20	2966 130952	ROMAN KONOVALOV	{"email": "roman-konovalov_29101973@postgrespro.ru", "phone": "+70112354504"}
0005434573621	579D20	8064 949172	TAMARA GERASIMOVA	{"phone": "+70026536385"}
0005434573622	AF7B98	5987 214162	EVGENIY KRASNOV	{"phone": "+70087830341"}
0005434573623	AF7B98	2678 332432	VERA DANILOVA	{"email": "danilovav-25101985@postgrespro.ru", "phone": "+70849780463"}
0005434573624	0B4B5E	6929 112609	NIKOLAY STEPANOV	{"email": "nikolay.stepanov_121963@postgrespro.ru", "phone": "+70140390052"}
0005434573625	0B4B5E	5549 003491	TATYANA DANILOVA	{"email": "danilova-tatyana091979@postgrespro.ru", "phone": "+70432205550"}
0005434573626	C58C2D	1179 635663	GALINA EFREMOVA	{"phone": "+70043219336"}
0005434573627	2A74D2	7062 536374	ALEKSEY ILIN	{"email": "ilinaleksey-101970@postgrespro.ru", "phone": "+70074581105"}
0005434573628	E962C4	7838 173603	ALEKSEY KUZNECOV	{"phone": "+70166967267"}
0005434573629	7B263A	8636 875217	ALEKSANDR MAKAROV	{"email": "amakarov-071975@postgrespro.ru", "phone": "+70962209225"}
0005434573630	1E3C58	4669 048060	NADEZHDA SMIRNOVA	{"email": "nadezhda_smirnova021970@postgrespro.ru", "phone": "+70122666214"}
0005434573631	1E3C58	9768 693781	ALEKSEY RODIONOV	{"phone": "+70745484083"}
0005434573632	3507D6	3550 780588	IVAN POPOV	{"email": "popovi.101969@postgrespro.ru", "phone": "+70468749295"}
0005434573633	0D47A8	3582 931242	DMITRIY AFANASEV	{"email": "dmitriy-afanasev-14081964@postgrespro.ru", "phone": "+70404441522"}
0005434573634	0D47A8	6508 735957	ELVIRA VOLKOVA	{"email": "volkova_elvira.041975@postgrespro.ru", "phone": "+70385279338"}
0005434573635	F68632	2771 756547	LYUBOV SAVELEVA	{"phone": "+70627164759"}
0005434573636	69FCE9	1831 439782	ALEKSANDR EGOROV	{"email": "aegorov081970@postgrespro.ru", "phone": "+70917524315"}
0005434573637	81A512	6568 408559	EKATERINA ORLOVA	{"email": "e_orlova-1962@postgrespro.ru", "phone": "+70066722347"}
0005434573638	81A512	8918 960377	OLEG SHEVCHENKO	{"email": "shevchenko_o-091978@postgrespro.ru", "phone": "+70772547103"}
0005434573639	384309	7503 752795	VIKTOR ALEKSANDROV	{"phone": "+70095841242"}
0005434573640	65458F	9397 978162	IGOR MIKHAYLOV	{"email": "i-mikhaylov-121975@postgrespro.ru", "phone": "+70832965432"}
0005434573641	65458F	8318 299753	NADEZHDA ZAKHAROVA	{"phone": "+70241955899"}
0005434573642	A15C25	9431 814336	SERGEY KUDRYASHOV	{"email": "sergeykudryashov.1969@postgrespro.ru", "phone": "+70831284789"}
0005434573643	A15C25	3469 601201	ALEKSEY ORLOV	{"email": "orlov.aleksey.19061971@postgrespro.ru", "phone": "+70100462266"}
0005434573644	5CF80F	4886 503303	SULTAN KAZAKOV	{"email": "s_kazakov.111978@postgrespro.ru", "phone": "+70568399380"}
0005434573645	5CF80F	8227 464851	OLGA VOLKOVA	{"email": "o_volkova_051976@postgrespro.ru", "phone": "+70119714852"}
0005434573646	E486FD	8464 046024	KLAVDIYA EFREMOVA	{"email": "k_efremova_10061962@postgrespro.ru", "phone": "+70556909001"}
0005434573647	831725	8684 340593	EVGENIY POPOV	{"email": "e_popov-27041965@postgrespro.ru", "phone": "+70516464838"}
0005434573648	4F6E2F	2600 504434	DMITRIY SERGEEV	{"phone": "+70651858446"}
0005434573649	E2BA36	8720 374088	PAVEL VASILEV	{"email": "p.vasilev.26111966@postgrespro.ru", "phone": "+70637920331"}
0005434573650	FCB094	3817 185251	SERGEY KUZNECOV	{"phone": "+70532720536"}
0005434573651	FCB094	9198 746574	MAKSIM GORBUNOV	{"phone": "+70951973107"}
0005434573652	D65EDA	1127 554829	ROMAN TIMOFEEV	{"email": "romantimofeev.22031971@postgrespro.ru", "phone": "+70474183152"}
0005434573653	D65EDA	5307 706888	SERGEY KISELEV	{"email": "s-kiselev25071973@postgrespro.ru", "phone": "+70042131402"}
0005434573654	4C756C	6356 622341	IRINA DANILOVA	{"email": "danilovai.1972@postgrespro.ru", "phone": "+70501472507"}
0005434573655	6C079C	8765 670963	ALEKSANDR BORISOV	{"email": "aleksandr.borisov_1984@postgrespro.ru", "phone": "+70149526419"}
0005434573656	6C079C	8569 110963	VIKTORIYA KUZMINA	{"phone": "+70477137316"}
0005434573657	29AA49	6236 641194	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir-11051978@postgrespro.ru", "phone": "+70718393657"}
0005434573658	29AA49	8504 425314	NIKOLAY PAVLOV	{"email": "pavlov.nikolay_1985@postgrespro.ru", "phone": "+70164123878"}
0005434573659	BFB4F9	5746 510750	MARIYA MOROZOVA	{"email": "mariyamorozova.02011975@postgrespro.ru", "phone": "+70882918717"}
0005434573660	BFB4F9	4861 230126	VALENTIN KARPOV	{"email": "valentin.karpov_101973@postgrespro.ru", "phone": "+70372753309"}
0005434573661	FA024A	9696 493331	IRINA NIKITINA	{"email": "inikitina.20021973@postgrespro.ru", "phone": "+70915612713"}
0005434573662	FA024A	0087 867854	IGOR KOZLOV	{"email": "igor.kozlov-1972@postgrespro.ru", "phone": "+70167964058"}
0005434573663	EB5BD4	6017 389334	VALENTIN ZHUKOV	{"phone": "+70310789176"}
0005434573664	EF62DF	4895 274610	VASILIY ORLOV	{"email": "vasiliy-orlov_021977@postgrespro.ru", "phone": "+70385026971"}
0005434573665	C5BABF	2721 616656	SERGEY ALEKSANDROV	{"email": "s-aleksandrov-121961@postgrespro.ru", "phone": "+70862721715"}
0005434573666	F5234C	1713 162563	ARSENIY SMIRNOV	{"email": "arseniy.smirnov19051970@postgrespro.ru", "phone": "+70674234824"}
0005434573667	F5234C	7056 596394	SERGEY BARANOV	{"phone": "+70211382667"}
0005434573668	0460B9	5395 572316	ALEKSANDR SOROKIN	{"email": "sorokina-23021981@postgrespro.ru", "phone": "+70905453825"}
0005434573669	55F826	1692 567891	NADEZHDA GERASIMOVA	{"phone": "+70473664652"}
0005434573670	FE28BE	8759 733334	OLGA PETROVA	{"phone": "+70233276482"}
0005434573671	FE28BE	8969 275229	NIKOLAY VOROBEV	{"email": "n.vorobev_071977@postgrespro.ru", "phone": "+70540207419"}
0005434573672	378C62	2688 146165	OLGA IVANOVA	{"phone": "+70961318488"}
0005434573673	DB1C9B	1190 622774	ANNA DAVYDOVA	{"email": "davydova-a.1972@postgrespro.ru", "phone": "+70383208689"}
0005434573674	FF5561	1160 935383	ANDREY MEDVEDEV	{"email": "medvedev.a.1976@postgrespro.ru", "phone": "+70805890728"}
0005434573675	674655	7667 885786	ANDREY SHEVCHENKO	{"phone": "+70016961881"}
0005434573676	674655	5300 111627	VIKTOR SEMENOV	{"email": "vsemenov_24011964@postgrespro.ru", "phone": "+70136703529"}
0005434573677	9CF60D	4561 620462	VLADIMIR MOROZOV	{"email": "morozov_vladimir1962@postgrespro.ru", "phone": "+70928488289"}
0005434573678	18D54E	8277 852525	VLADIMIR KOROLEV	{"email": "korolev_v-1972@postgrespro.ru", "phone": "+70328987946"}
0005434573679	347008	0644 681786	VERONIKA MAKSIMOVA	{"email": "maksimovaveronika.101966@postgrespro.ru", "phone": "+70255355026"}
0005434573680	347008	9544 437671	IGOR RODIONOV	{"phone": "+70421408204"}
0005434573681	347008	6596 240570	NATALYA LUKYANOVA	{"email": "lukyanova.natalya24101969@postgrespro.ru", "phone": "+70831892506"}
0005434573682	82636C	8766 272644	MIKHAIL ORLOV	{"email": "mikhail-orlov_1972@postgrespro.ru", "phone": "+70745977804"}
0005434573683	82636C	5360 684623	GALINA ORLOVA	{"email": "galina-orlova-031971@postgrespro.ru", "phone": "+70412999033"}
0005434573684	C925BA	2095 379217	EVGENIY KUZNECOV	{"phone": "+70464164181"}
0005434573685	C925BA	1770 972564	ANZHELIKA KUZMINA	{"phone": "+70745478166"}
0005434573686	A5A527	5619 463346	KAMILA OVCHINNIKOVA	{"email": "ovchinnikova-kamila091977@postgrespro.ru", "phone": "+70890408816"}
0005434573687	DF6D84	5470 854658	DENIS SOROKIN	{"phone": "+70135851063"}
0005434573688	6A9AD5	5126 765230	TAMARA TARASOVA	{"email": "t-tarasova.1984@postgrespro.ru", "phone": "+70697707831"}
0005434573689	20DE10	2208 216548	NINA FEDOROVA	{"phone": "+70503392857"}
0005434573690	B3D490	2423 815890	ALEKSANDRA MOISEEVA	{"email": "moiseeva-aleksandra.111976@postgrespro.ru", "phone": "+70513626731"}
0005434573691	37BA6C	8669 096503	NIKITA FEDOROV	{"email": "nfedorov_1984@postgrespro.ru", "phone": "+70912358830"}
0005434573692	7396C1	0693 630105	OLGA BORISOVA	{"phone": "+70383426046"}
0005434573693	55AFBC	4486 539948	VADIM FROLOV	{"phone": "+70932097895"}
0005434573694	E0FB2D	1588 415475	ALEKSANDR NOVIKOV	{"phone": "+70364304895"}
0005434573695	016ED0	1747 395531	VYACHESLAV ALEKSEEV	{"phone": "+70233632080"}
0005434573696	CD5C37	5415 833090	EVGENIYA TROFIMOVA	{"email": "evgeniya_trofimova-26111969@postgrespro.ru", "phone": "+70416359007"}
0005434573697	CD5C37	0957 393920	IGOR EGOROV	{"phone": "+70842202870"}
0005434573698	30A77C	3072 916401	EVGENIY BONDARENKO	{"email": "bondarenko-evgeniy-1985@postgrespro.ru", "phone": "+70917461959"}
0005434573699	C13922	2654 135283	ANDREY ANTONOV	{"email": "andrey-antonov-24041968@postgrespro.ru", "phone": "+70913636633"}
0005434573700	8A99F9	5983 734616	RAISA SERGEEVA	{"phone": "+70273667188"}
0005434573701	8A99F9	9267 762998	EVGENIY GERASIMOV	{"email": "egerasimov-06061966@postgrespro.ru", "phone": "+70178721898"}
0005434573702	0B6220	8436 211635	ELIZAVETA ANTONOVA	{"email": "elizaveta.antonova_1980@postgrespro.ru", "phone": "+70856307498"}
0005434573703	3F1C74	7383 544629	ANASTASIYA VASILEVA	{"email": "anastasiya-vasileva-29071968@postgrespro.ru", "phone": "+70615842037"}
0005434573704	0FD754	7956 064530	ZOYA MATVEEVA	{"phone": "+70866017840"}
0005434573705	0FD754	5960 970280	ELENA RYABOVA	{"email": "ryabovae.30091980@postgrespro.ru", "phone": "+70626447478"}
0005434573706	AB5482	1048 481369	ANASTASIYA TROFIMOVA	{"phone": "+70174499352"}
0005434573707	816FF2	7291 047399	ANASTASIYA ORLOVA	{"email": "orlova_anastasiya06081967@postgrespro.ru", "phone": "+70004460006"}
0005434573708	80752F	5821 548504	DMITRIY VASILEV	{"email": "d.vasilev101968@postgrespro.ru", "phone": "+70476155361"}
0005434573709	7FDB0F	2472 505725	KSENIYA SEMENOVA	{"phone": "+70771861453"}
0005434573710	F39B78	5229 181015	DMITRIY BORISOV	{"email": "d_borisov1981@postgrespro.ru", "phone": "+70544111274"}
0005434573711	D8E272	1176 414392	KLAVDIYA KUZNECOVA	{"email": "k-kuznecova.06101965@postgrespro.ru", "phone": "+70616070756"}
0005434573712	D8E272	1671 281848	SERGEY IVANOV	{"email": "ivanov_sergey.14081975@postgrespro.ru", "phone": "+70263613777"}
0005434573713	C5DE0D	6735 770144	IVAN SCHERBAKOV	{"phone": "+70650273843"}
0005434573714	E251B8	0525 223055	TATYANA ALEKSEEVA	{"phone": "+70361222130"}
0005434573715	D71631	0422 254238	ILDAR FEDOTOV	{"phone": "+70687138469"}
0005434573716	D71631	7796 463311	MAKSIM VOLKOV	{"phone": "+70387939896"}
0005434573717	AE8E3D	1658 977728	OLGA KOVALEVA	{"email": "olga-kovaleva1965@postgrespro.ru", "phone": "+70488091599"}
0005434573718	AE8E3D	4698 276351	VLADIMIR ANTONOV	{"email": "antonov.v.1971@postgrespro.ru", "phone": "+70651261919"}
0005434573719	AE8E3D	3559 496645	NADEZHDA DENISOVA	{"email": "denisova-n.031978@postgrespro.ru", "phone": "+70339173859"}
0005434573720	4CFF40	4824 593216	VLADIMIR KAZAKOV	{"phone": "+70124307326"}
0005434573721	5C85F7	8351 002638	VIKTOR OSIPOV	{"email": "osipov-viktor_08051957@postgrespro.ru", "phone": "+70457054813"}
0005434573722	ACBD01	4916 582393	EVDOKIYA KISELEVA	{"email": "kiseleva_evdokiya.011969@postgrespro.ru", "phone": "+70154209865"}
0005434573723	6C51A7	0883 445060	OLGA FOMINA	{"phone": "+70089058993"}
0005434573724	6C51A7	8652 873942	GERMAN EGOROV	{"phone": "+70504088921"}
0005434573725	6C51A7	3208 094722	EVGENIYA ILINA	{"phone": "+70430540435"}
0005434573726	EC8AEC	5642 473236	TATYANA POLYAKOVA	{"phone": "+70030765280"}
0005434573727	62F4EC	6929 812899	NIKOLAY PAVLOV	{"phone": "+70255208591"}
0005434573728	CA2ECD	8548 811219	YURIY GERASIMOV	{"phone": "+70777418841"}
0005434573729	8EADD9	5104 827876	MAKSIM KUZMIN	{"email": "kuzmin_maksim-1972@postgrespro.ru", "phone": "+70570051655"}
0005434573730	16E420	3792 209765	VALERIY NIKITIN	{"phone": "+70465834670"}
0005434573731	2F7E82	3631 932789	LILIYA IVANOVA	{"email": "ivanovaliliya111971@postgrespro.ru", "phone": "+70206154400"}
0005434573732	207B13	5403 402011	LYUDMILA GRISHINA	{"email": "lyudmilagrishina.25091976@postgrespro.ru", "phone": "+70805584857"}
0005434573733	2BE49F	7191 485169	SVETLANA STEPANOVA	{"email": "svetlanastepanova1977@postgrespro.ru", "phone": "+70976729995"}
0005434573734	C0E7DA	2864 956787	KLAVDIYA MAKAROVA	{"phone": "+70936685997"}
0005434573735	EC7D2E	8398 475222	ILYA VLASOV	{"phone": "+70812419397"}
0005434573736	FAFDD7	5313 323664	PETR CHERNOV	{"email": "chernov_petr.021962@postgrespro.ru", "phone": "+70522955345"}
0005434573737	094E8D	8925 284976	SERGEY VASILEV	{"phone": "+70772081580"}
0005434573738	05F68F	7652 570725	SERGEY SERGEEV	{"phone": "+70863773198"}
0005434573739	809885	1153 485916	VLADIMIR ANTONOV	{"email": "vladimir-antonov_27021975@postgrespro.ru", "phone": "+70093896913"}
0005434573740	809885	4804 662915	IVAN TARASOV	{"email": "i.tarasov.17121970@postgrespro.ru", "phone": "+70014443594"}
0005434573741	3EECC0	2253 731486	ALFIYA ZAKHAROVA	{"email": "azakharova_1973@postgrespro.ru", "phone": "+70611417938"}
0005434573742	F724A0	1795 762134	ROMAN ANDREEV	{"email": "roman_andreev-051979@postgrespro.ru", "phone": "+70281994084"}
0005434573743	ECC7FB	5841 751434	ALEKSEY DENISOV	{"email": "alekseydenisov031979@postgrespro.ru", "phone": "+70523050465"}
0005434573744	7C44B4	2469 208506	SVETLANA DAVYDOVA	{"email": "s.davydova091970@postgrespro.ru", "phone": "+70348834906"}
0005434573745	3635EF	6583 123381	VALERIY POPOV	{"email": "valeriypopov_121962@postgrespro.ru", "phone": "+70089667101"}
0005434573746	8B843D	7335 873920	IRINA PAVLOVA	{"email": "pavlova_i17031970@postgrespro.ru", "phone": "+70620206101"}
0005434573747	C04FC8	9408 570769	SVETLANA IVANOVA	{"email": "ivanova.svetlana-1965@postgrespro.ru", "phone": "+70917912081"}
0005434573748	89E04C	1294 136630	VASILIY KONOVALOV	{"phone": "+70900014656"}
0005434573749	89E04C	2649 177138	ANDREY ILIN	{"phone": "+70603843873"}
0005434573750	717680	9613 961212	ARTUR ALEKSEEV	{"phone": "+70332817187"}
0005434573751	717680	4099 179026	LARISA SAVELEVA	{"email": "l-saveleva.111966@postgrespro.ru", "phone": "+70213375418"}
0005434573752	BBEE3B	4885 390990	OLEG ANTONOV	{"phone": "+70841906888"}
0005434573753	30CE5E	8123 047500	TATYANA ZAYCEVA	{"phone": "+70700149825"}
0005434573754	80B3DD	3481 135645	OKSANA SIDOROVA	{"phone": "+70476915733"}
0005434573755	963ABB	7161 404079	LIDIYA NAZAROVA	{"phone": "+70911701952"}
0005434573756	963ABB	1281 307531	ALEKSEY ZHUKOV	{"phone": "+70494253699"}
0005434573757	60B6FD	3947 834287	VLADIMIR MOROZOV	{"email": "vladimirmorozov.061969@postgrespro.ru", "phone": "+70482372784"}
0005434573758	94D1EB	8465 548729	NATALYA STEPANOVA	{"email": "stepanova_n.031967@postgrespro.ru", "phone": "+70630350548"}
0005434573759	6E944B	7631 489226	NADEZHDA PETROVA	{"phone": "+70908165550"}
0005434573760	4C8E40	1022 280583	YULIYA DMITRIEVA	{"phone": "+70240560705"}
0005434573761	071FB1	8815 393782	ALEKSEY AFANASEV	{"email": "a.afanasev-071979@postgrespro.ru", "phone": "+70950462923"}
0005434573762	727406	3333 680822	NAIL KUZNECOV	{"email": "kuznecov.n-121972@postgrespro.ru", "phone": "+70231529681"}
0005434573763	727406	2948 352352	LYUBOV RODIONOVA	{"email": "rodionova-l-1974@postgrespro.ru", "phone": "+70473078466"}
0005434573764	15CFA7	9815 089382	NIKITA ZAKHAROV	{"email": "zakharovnikita-1964@postgrespro.ru", "phone": "+70754367085"}
0005434573765	15CFA7	2723 889541	EKATERINA KUZNECOVA	{"phone": "+70599682643"}
0005434573766	F0ECB0	0784 263869	MAKSIM ILIN	{"phone": "+70821767630"}
0005434573767	42CC2F	6761 394845	RINAT YAKOVLEV	{"phone": "+70788501285"}
0005434573768	7E7DA6	6057 720081	KONSTANTIN FROLOV	{"phone": "+70684624310"}
0005434573769	302AC8	8017 512214	EKATERINA NOVIKOVA	{"email": "e_novikova-13061972@postgrespro.ru", "phone": "+70433300442"}
0005434573770	302AC8	1791 575089	GEORGIY PAVLOV	{"phone": "+70782502480"}
0005434573771	1B5A0C	2525 570457	IVAN IVANOV	{"phone": "+70452983168"}
0005434573772	1B5A0C	1964 700473	IRINA YAKOVLEVA	{"phone": "+70726394381"}
0005434573773	1B5A0C	4280 700227	VIKTOR MATVEEV	{"email": "viktor_matveev.1972@postgrespro.ru", "phone": "+70523060168"}
0005434573774	AC8018	5613 421307	ANTON KUZNECOV	{"phone": "+70228838427"}
0005434573775	AC8018	1833 291176	EVGENIY PETROV	{"phone": "+70860599938"}
0005434573776	AC8018	6787 623635	ILYA KULIKOV	{"phone": "+70914255644"}
0005434573777	1E5F06	9781 079847	SERGEY NOVIKOV	{"email": "sergey_novikov17121963@postgrespro.ru", "phone": "+70494046319"}
0005434573778	2820E8	6601 816656	DMITRIY BELOV	{"email": "belov_d_041983@postgrespro.ru", "phone": "+70038728728"}
0005434573779	2820E8	1378 064129	DARYA MASLOVA	{"email": "d_maslova.03091972@postgrespro.ru", "phone": "+70822267662"}
0005434586179	4DAEA1	7905 315916	NIKOLAY SERGEEV	{"phone": "+70979983620"}
0005434586411	366266	1388 618093	RASHIT BARANOV	{"phone": "+70310869049"}
0005434586157	BA8E74	3045 343419	ALEKSANDR BELOV	{"phone": "+70390539722"}
0005434586158	26FDD9	7050 622886	YAN DAVYDOV	{"email": "davydov-y-17041975@postgrespro.ru", "phone": "+70662290032"}
0005434586159	2C9E9F	9031 250983	TAMARA DENISOVA	{"email": "tdenisova_041980@postgrespro.ru", "phone": "+70746466465"}
0005434586160	3FDC15	4432 149692	ANNA LEBEDEVA	{"phone": "+70441990883"}
0005434586161	AFD5DD	1869 131001	KIRILL ABRAMOV	{"email": "abramov.k.031977@postgrespro.ru", "phone": "+70905327404"}
0005434586162	AFD5DD	8583 826819	ALEKSEY BORISOV	{"email": "a_borisov_121970@postgrespro.ru", "phone": "+70763317131"}
0005434586163	208196	4327 216261	RAFAIL KRASNOV	{"email": "rafail_krasnov_091974@postgrespro.ru", "phone": "+70402036632"}
0005434586164	B44517	8048 669293	LARISA IVANOVA	{"email": "larisa.ivanova.071979@postgrespro.ru", "phone": "+70800882036"}
0005434586165	B44517	8939 397678	MARINA NIKITINA	{"email": "nikitina_marina_121966@postgrespro.ru", "phone": "+70467577555"}
0005434586166	057EC9	2596 002580	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_aleksey-1973@postgrespro.ru", "phone": "+70845092427"}
0005434586167	057EC9	4524 793504	DAMIR SCHERBAKOV	{"phone": "+70729360795"}
0005434586168	8C9407	7350 203971	ALEKSANDR TIMOFEEV	{"email": "timofeev-a.031973@postgrespro.ru", "phone": "+70616917765"}
0005434586169	EDD58A	8299 684671	VERA SOLOVEVA	{"phone": "+70716673996"}
0005434586170	EDD58A	5065 979587	OLEG GERASIMOV	{"email": "gerasimovoleg071984@postgrespro.ru", "phone": "+70157515462"}
0005434586171	A93474	2590 796180	NINA SAVELEVA	{"email": "nina.saveleva-021975@postgrespro.ru", "phone": "+70716665357"}
0005434586172	A93474	3029 316840	ALEKSANDR NOVIKOV	{"phone": "+70811459724"}
0005434586173	F642CE	7404 989123	ANNA VLASOVA	{"phone": "+70647767643"}
0005434586174	4BF1B4	0772 005863	YULIYA SMIRNOVA	{"email": "y-smirnova-081965@postgrespro.ru", "phone": "+70800133147"}
0005434586175	F7891E	5126 721231	DMITRIY SHEVCHENKO	{"phone": "+70593420598"}
0005434586176	F7891E	6013 423210	EVGENIY KAZAKOV	{"phone": "+70139493024"}
0005434586177	CE3B94	8496 050545	NADEZHDA ZHURAVLEVA	{"email": "zhuravleva.nadezhda13101974@postgrespro.ru", "phone": "+70697176676"}
0005434586178	4DAEA1	6948 006428	MAKSIM FILIPPOV	{"phone": "+70371594768"}
0005434586180	3E1D70	6135 409278	ELENA ARKHIPOVA	{"phone": "+70701496895"}
0005434586181	B967CE	7714 799765	VYACHESLAV FEDOROV	{"email": "vyacheslav-fedorov-21021985@postgrespro.ru", "phone": "+70106703199"}
0005434586182	8852EE	4317 062346	ZINAIDA KAZAKOVA	{"email": "kazakova.zinaida-1966@postgrespro.ru", "phone": "+70921914718"}
0005434586183	62C4BA	8646 812118	NATALIYA LAZAREVA	{"phone": "+70042603517"}
0005434586184	62C4BA	5106 900615	MAKSIM OSIPOV	{"phone": "+70407300758"}
0005434586185	6EBB7E	7527 862570	NIKOLAY DAVYDOV	{"phone": "+70968226604"}
0005434586186	117C9C	4628 389515	ELIZAVETA POPOVA	{"email": "e-popova-121969@postgrespro.ru", "phone": "+70102286744"}
0005434586187	6CCB1E	6843 453427	ALEKSANDRA NAZAROVA	{"email": "nazarova-aleksandra.12051963@postgrespro.ru", "phone": "+70591460889"}
0005434586188	6CCB1E	0906 763062	DENIS ALEKSEEV	{"phone": "+70457920508"}
0005434586189	4D12E3	0509 437785	RIMMA SOKOLOVA	{"phone": "+70647487429"}
0005434586190	6469DB	0835 214263	VLADIMIR KUZNECOV	{"phone": "+70320941791"}
0005434586191	BB4510	3704 712467	SARIYA ZAYCEVA	{"phone": "+70624556279"}
0005434586192	A2810D	0597 867817	ZOYA MATVEEVA	{"phone": "+70817456468"}
0005434586193	EA6F69	1877 244879	NINA AKIMOVA	{"email": "n_akimova031969@postgrespro.ru", "phone": "+70168059420"}
0005434586194	EA6F69	2036 489045	VERA KUZNECOVA	{"phone": "+70269018199"}
0005434586195	EA6F69	5128 171262	ANDREY MATVEEV	{"phone": "+70934385435"}
0005434586196	44EA31	1705 089676	VLADIMIR ROMANOV	{"phone": "+70743373921"}
0005434586197	4E3928	8800 881770	ANTONINA KOROLEVA	{"phone": "+70572191248"}
0005434586198	D19DE7	1748 405673	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev-1971@postgrespro.ru", "phone": "+70078083306"}
0005434586199	D19DE7	6329 823586	VALERIY MELNIKOV	{"email": "melnikov-valeriy-1970@postgrespro.ru", "phone": "+70736902952"}
0005434586200	CA5759	4739 563731	ELENA MALYSHEVA	{"email": "malysheva.e_081967@postgrespro.ru", "phone": "+70030799034"}
0005434586201	CA5759	0907 168167	STANISLAV ABRAMOV	{"phone": "+70267259826"}
0005434586202	E99615	3811 161189	VLADIMIR TARASOV	{"phone": "+70931081563"}
0005434586203	E99615	5938 497408	ELENA ANDREEVA	{"phone": "+70143804216"}
0005434586204	E99615	7926 662590	NATALYA NOVIKOVA	{"phone": "+70938793743"}
0005434586205	E99615	3617 262400	NINA BARANOVA	{"phone": "+70248525915"}
0005434586206	C2E0C5	9950 596967	LIDIYA ANTONOVA	{"phone": "+70609099681"}
0005434586207	9BCCEE	7865 478132	MARINA PETROVA	{"phone": "+70682649838"}
0005434586208	1BF3A3	8086 189526	YULIYA DENISOVA	{"phone": "+70887549666"}
0005434586209	05BAFE	6177 237389	NIKOLAY MARTYNOV	{"phone": "+70536568355"}
0005434586210	41C536	4620 290334	GALINA IVANOVA	{"email": "ivanovagalina-26031972@postgrespro.ru", "phone": "+70364299140"}
0005434586211	41C536	5523 571469	ARTEM VLASOV	{"phone": "+70944022966"}
0005434586212	36C05A	6453 589858	ILYA TIKHONOV	{"email": "ilya.tikhonov_1978@postgrespro.ru", "phone": "+70499270369"}
0005434586213	136672	1250 233627	YURIY MATVEEV	{"phone": "+70608988781"}
0005434586214	136672	8580 324327	SERGEY NIKOLAEV	{"email": "s-nikolaev.031974@postgrespro.ru", "phone": "+70603879903"}
0005434586215	799CFC	6876 327858	ANGELINA CHERNOVA	{"phone": "+70606629373"}
0005434586216	723850	9471 635204	YAROSLAV BARANOV	{"phone": "+70314553614"}
0005434586217	48AA7D	0530 818610	DMITRIY CHERNOV	{"phone": "+70216928747"}
0005434586218	643101	2404 687761	MARIYA OVCHINNIKOVA	{"email": "ovchinnikova_m-21041979@postgrespro.ru", "phone": "+70515955331"}
0005434586219	EAE428	7722 650846	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya11061974@postgrespro.ru", "phone": "+70799449445"}
0005434586220	2E532C	7006 012711	ALENA GERASIMOVA	{"phone": "+70097311076"}
0005434586221	01532F	7333 561189	VALENTINA KOZLOVA	{"email": "v.kozlova_1965@postgrespro.ru", "phone": "+70785411285"}
0005434586222	99BD70	8743 074376	MARIYA SCHERBAKOVA	{"phone": "+70824878741"}
0005434586223	BD2967	5678 789505	ELENA NESTEROVA	{"email": "elena.nesterova081969@postgrespro.ru", "phone": "+70772872731"}
0005434586224	D4AFF0	0913 249637	SERGEY KUZNECOV	{"phone": "+70075739519"}
0005434586225	D4AFF0	3207 646899	GENNADIY MEDVEDEV	{"phone": "+70274022498"}
0005434586226	CEBC34	7851 181984	EDUARD GERASIMOV	{"email": "gerasimove08011972@postgrespro.ru", "phone": "+70604293308"}
0005434586227	FEB7BB	2826 145416	ELENA MOISEEVA	{"phone": "+70502753918"}
0005434586228	D435A2	4876 752795	VLADIMIR KARPOV	{"phone": "+70182577484"}
0005434586229	D435A2	4907 182150	YURIY ALEKSEEV	{"phone": "+70274043758"}
0005434586230	B5C5BF	2207 733339	GALINA KUZNECOVA	{"phone": "+70451270749"}
0005434586231	6FD30D	1754 254008	DMITRIY POPOV	{"email": "popov-dmitriy-23061991@postgrespro.ru", "phone": "+70768015167"}
0005434586232	AFDE30	7456 359480	ALEKSANDR ANDREEV	{"email": "andreev_a.08091977@postgrespro.ru", "phone": "+70112128279"}
0005434586233	581FF3	0504 801652	ALEKSANDR GAVRILOV	{"phone": "+70626967234"}
0005434586234	0A435A	1196 159615	VIKTOR ROMANOV	{"email": "romanov-v-031969@postgrespro.ru", "phone": "+70329700451"}
0005434586235	85AB32	0878 074839	TATYANA GRISHINA	{"phone": "+70826980959"}
0005434586236	28B1CD	2474 008124	VALENTINA FROLOVA	{"email": "valentinafrolova-1967@postgrespro.ru", "phone": "+70436344212"}
0005434586237	28B1CD	3867 948258	NINA ORLOVA	{"phone": "+70871671457"}
0005434586238	3CFA7A	0511 059481	ALEKSANDR EGOROV	{"phone": "+70055409257"}
0005434586239	E8491A	7304 054948	ANATOLIY KOROLEV	{"email": "korolev.a-1978@postgrespro.ru", "phone": "+70026569659"}
0005434586240	E8491A	5252 279659	SVETLANA ILINA	{"phone": "+70668737991"}
0005434586241	99F5FF	5778 447568	YULIYA GUSEVA	{"phone": "+70826488068"}
0005434586242	ECD99D	6831 061977	ANDREY SCHERBAKOV	{"email": "andrey.scherbakov.21101962@postgrespro.ru", "phone": "+70055977490"}
0005434586243	644C15	4152 521312	EKATERINA SOROKINA	{"email": "esorokina-30031971@postgrespro.ru", "phone": "+70878960119"}
0005434586244	D8B2E4	2456 103666	VALERIY NIKITIN	{"phone": "+70209835097"}
0005434586245	17DFC6	6796 750358	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov.16081968@postgrespro.ru", "phone": "+70337739018"}
0005434586246	234C77	2110 691065	ALEKSANDR EGOROV	{"email": "aleksandr.egorov-05111974@postgrespro.ru", "phone": "+70714500761"}
0005434586247	234C77	1484 745094	EMMA KONOVALOVA	{"email": "emma-konovalova_26071965@postgrespro.ru", "phone": "+70063531884"}
0005434586248	1F4A25	8952 319566	NINA ILINA	{"phone": "+70101772971"}
0005434586249	1F4A25	6753 053537	VIKTOR GERASIMOV	{"phone": "+70777880515"}
0005434586250	1F4A25	6412 399601	VLADIMIR IVANOV	{"email": "vladimir_ivanov111969@postgrespro.ru", "phone": "+70950287676"}
0005434586251	1F4A25	6893 754335	ELENA POPOVA	{"email": "popova_e.02031977@postgrespro.ru", "phone": "+70961155375"}
0005434586252	C98A0F	5172 603423	NIKOLAY SOKOLOV	{"phone": "+70966320260"}
0005434586253	C98A0F	0086 054846	DMITRIY ORLOV	{"email": "dmitriyorlov-041976@postgrespro.ru", "phone": "+70130689661"}
0005434586254	AA5B09	0145 108528	GEORGIY SCHERBAKOV	{"phone": "+70475633454"}
0005434586255	F32CC7	6328 360525	IGOR MARTYNOV	{"phone": "+70263130796"}
0005434586256	19E98C	4085 736546	VLADIMIR SOKOLOV	{"email": "vsokolov_17021973@postgrespro.ru", "phone": "+70245266566"}
0005434586257	64A1C9	7442 225292	MARINA KONOVALOVA	{"email": "konovalova.m.1976@postgrespro.ru", "phone": "+70720360783"}
0005434586258	439700	2065 180797	LILIYA ANDREEVA	{"email": "liliya_andreeva_16121967@postgrespro.ru", "phone": "+70451219170"}
0005434586259	C0D949	5078 868376	ALEKSANDR MELNIKOV	{"phone": "+70127133548"}
0005434586260	C0D949	5629 921416	MARIYA SMIRNOVA	{"phone": "+70627573542"}
0005434586261	6A5BE7	5444 904669	ANNA MELNIKOVA	{"email": "anna_melnikova-25031978@postgrespro.ru", "phone": "+70132911168"}
0005434586262	16DE50	1264 686910	OLGA KONDRATEVA	{"phone": "+70271255959"}
0005434586263	056E57	6114 346429	NADEZHDA ZHURAVLEVA	{"phone": "+70347748935"}
0005434586264	CB6CFB	0170 197956	ALEKSEY TARASOV	{"email": "a-tarasov.1970@postgrespro.ru", "phone": "+70339941678"}
0005434586265	CB6CFB	2454 675005	IGOR KUZNECOV	{"phone": "+70211997596"}
0005434586266	8A2767	8497 336845	SOFYA KOROLEVA	{"phone": "+70732607788"}
0005434586267	FC32BE	8676 781694	ALEKSANDR PETROV	{"phone": "+70401664699"}
0005434586268	FC32BE	1726 523242	RAMIL SOKOLOV	{"email": "r_sokolov.06091975@postgrespro.ru", "phone": "+70882941257"}
0005434586269	7BBD83	9012 545248	YANA MIKHAYLOVA	{"email": "mikhaylova-yana19081977@postgrespro.ru", "phone": "+70670695553"}
0005434586270	148C95	8780 616115	LILIYA ROMANOVA	{"phone": "+70678931559"}
0005434586271	148C95	9713 047918	SERGEY MAKSIMOV	{"phone": "+70974882985"}
0005434586272	809E91	9275 625923	NINA FOMINA	{"phone": "+70841938181"}
0005434586273	809E91	4660 287639	MAKSIM ROMANOV	{"email": "maksim_romanov.27121975@postgrespro.ru", "phone": "+70400289763"}
0005434586274	809E91	2368 628605	RAISA KOVALEVA	{"phone": "+70447135725"}
0005434586275	3BC176	5550 304806	EKATERINA ANISIMOVA	{"email": "ekaterinaanisimova28041973@postgrespro.ru", "phone": "+70587015212"}
0005434586276	2076B4	4171 973886	LILIYA KOZLOVA	{"email": "liliya_kozlova.04111958@postgrespro.ru", "phone": "+70793597756"}
0005434586277	2076B4	0035 089378	ALEKSANDR GUSEV	{"phone": "+70279483003"}
0005434586278	ADF11A	1247 097818	EVGENIY KUDRYASHOV	{"phone": "+70306309986"}
0005434586279	C580C5	4053 673572	ANASTASIYA TIKHONOVA	{"email": "a-tikhonova04051974@postgrespro.ru", "phone": "+70748565814"}
0005434586280	E443FF	7471 309988	LYAYSAN MAKSIMOVA	{"email": "maksimovalyaysan1981@postgrespro.ru", "phone": "+70670071409"}
0005434586281	E443FF	0757 767314	LYUDMILA MAKAROVA	{"email": "lyudmila_makarova_1958@postgrespro.ru", "phone": "+70134633445"}
0005434586282	127C29	1259 820789	MARK PAVLOV	{"email": "pavlov-mark_06121973@postgrespro.ru", "phone": "+70687736001"}
0005434586283	48E2F4	9062 328681	ELENA MAKSIMOVA	{"email": "maksimovaelena.111975@postgrespro.ru", "phone": "+70250522071"}
0005434586284	48E2F4	7252 953639	OLGA KUZNECOVA	{"email": "olgakuznecova-01081963@postgrespro.ru", "phone": "+70825438360"}
0005434586285	1EF5AB	0428 051530	NIKOLAY IVANOV	{"phone": "+70148929030"}
0005434586286	15C3A9	5345 976073	LYUBOV ALEKSEEVA	{"email": "alekseevalyubov-07091955@postgrespro.ru", "phone": "+70965322571"}
0005434586287	15C3A9	9469 093630	BORIS PETROV	{"email": "borispetrov_1970@postgrespro.ru", "phone": "+70393722537"}
0005434586288	E9555E	1568 121269	ELIZAVETA NESTEROVA	{"email": "nesterova-e-111967@postgrespro.ru", "phone": "+70737073232"}
0005434586289	BA10D4	7225 015757	SERGEY KOZLOV	{"phone": "+70778299488"}
0005434586290	BA10D4	0422 259042	EVGENIY MAKAROV	{"phone": "+70077474631"}
0005434586291	801832	0945 003067	ALEKSANDR DAVYDOV	{"phone": "+70653482837"}
0005434586292	801832	0961 654236	ALBINA ZHUKOVA	{"phone": "+70938465658"}
0005434586293	0A2B5F	6502 080279	SVETLANA PETROVA	{"email": "petrova-s.17021980@postgrespro.ru", "phone": "+70037713369"}
0005434586294	9712A4	3735 107511	NADEZHDA GERASIMOVA	{"phone": "+70845768054"}
0005434586295	9712A4	7280 422693	DIANA NIKIFOROVA	{"phone": "+70512509689"}
0005434586296	9712A4	9393 972142	ANNA MOISEEVA	{"phone": "+70199760594"}
0005434586297	BFFDD2	1002 393669	ALEKSEY ZAYCEV	{"email": "a_zaycev20061982@postgrespro.ru", "phone": "+70025630844"}
0005434586298	2192FE	7871 605502	DMITRIY VOLKOV	{"email": "dmitriy-volkov20051979@postgrespro.ru", "phone": "+70231366696"}
0005434586299	2192FE	5714 215686	ANATOLIY MATVEEV	{"email": "matveevanatoliy_14051969@postgrespro.ru", "phone": "+70544939722"}
0005434586524	B7FEAB	2728 937446	ELENA POLYAKOVA	{"phone": "+70002423252"}
0005434586300	525090	2518 523466	IRINA OSIPOVA	{"email": "osipova.irina-23021975@postgrespro.ru", "phone": "+70085901479"}
0005434586301	2D75EE	6823 152660	GALINA NIKITINA	{"phone": "+70984969207"}
0005434586302	2D75EE	3587 535982	SOFYA BORISOVA	{"email": "borisovas1972@postgrespro.ru", "phone": "+70065315429"}
0005434586303	3776A7	6022 547731	IRINA EFREMOVA	{"email": "i_efremova_1978@postgrespro.ru", "phone": "+70431072804"}
0005434586304	E8ACBB	9099 778413	ALEKSANDR DAVYDOV	{"email": "a_davydov.1988@postgrespro.ru", "phone": "+70419967232"}
0005434586305	E8ACBB	2631 769442	IRINA TIMOFEEVA	{"phone": "+70160911618"}
0005434586306	72F409	5970 778640	ALEKSEY KUZMIN	{"email": "a.kuzmin121969@postgrespro.ru", "phone": "+70006833072"}
0005434586307	3E831A	6790 127370	NADEZHDA KAZAKOVA	{"phone": "+70355139369"}
0005434586308	5504D1	5132 767528	OLGA BARANOVA	{"email": "baranova_o.03081967@postgrespro.ru", "phone": "+70186212047"}
0005434586309	5F74BF	9592 275548	VALENTINA BORISOVA	{"email": "borisovavalentina_111975@postgrespro.ru", "phone": "+70085104990"}
0005434586310	2A9ABE	2105 660703	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_a.091978@postgrespro.ru", "phone": "+70141132932"}
0005434586311	1BF291	9707 234925	ARTEM BELOV	{"email": "belov_artem.1973@postgrespro.ru", "phone": "+70273321840"}
0005434586312	94D672	9908 183042	TATYANA VASILEVA	{"email": "vasileva.t-031974@postgrespro.ru", "phone": "+70970924702"}
0005434586313	ACCE28	2947 358384	SERGEY IVANOV	{"phone": "+70381250192"}
0005434586314	853314	5647 017134	KONSTANTIN FEDOROV	{"email": "konstantin.fedorov1966@postgrespro.ru", "phone": "+70631457374"}
0005434586315	891C51	5403 012402	EVGENIY ZAKHAROV	{"email": "zakharove.07071985@postgrespro.ru", "phone": "+70088234581"}
0005434586316	7954EA	9895 199185	KLAVDIYA ZAKHAROVA	{"phone": "+70637617424"}
0005434586317	7954EA	7506 204810	TATYANA BARANOVA	{"email": "tatyana.baranova-23091977@postgrespro.ru", "phone": "+70378151510"}
0005434586318	47A9D3	3300 589814	ALBINA BARANOVA	{"email": "baranova_a_23061973@postgrespro.ru", "phone": "+70740918606"}
0005434586319	8CE662	3953 873892	NIKOLAY ROMANOV	{"phone": "+70120214025"}
0005434586320	F270E3	7394 265368	NIKITA KUZMIN	{"phone": "+70215205425"}
0005434586321	F03E43	1805 335121	VASILIY NIKITIN	{"email": "nikitin_v-21081968@postgrespro.ru", "phone": "+70403637172"}
0005434586322	EC0359	2087 762872	SERGEY SEMENOV	{"email": "semenov.s-01011970@postgrespro.ru", "phone": "+70791446553"}
0005434586323	EC0359	2205 040845	POLINA PAVLOVA	{"email": "pavlova_polina-11031978@postgrespro.ru", "phone": "+70865578647"}
0005434586324	774B9B	7760 500913	ALEKSANDR FROLOV	{"phone": "+70296956498"}
0005434586325	562986	6324 947865	FATIMA YUDINA	{"email": "fyudina.1987@postgrespro.ru", "phone": "+70684666190"}
0005434586326	406E01	2754 906312	SERGEY SOKOLOV	{"email": "sokolovsergey.21121967@postgrespro.ru", "phone": "+70371996751"}
0005434586327	406E01	3355 894906	PETR TARASOV	{"phone": "+70287838130"}
0005434586328	EAAC3C	9939 640699	ALEKSANDR VLASOV	{"phone": "+70147228686"}
0005434586329	0BCA79	0058 054017	EKATERINA PETROVA	{"email": "ekaterina.petrova11091962@postgrespro.ru", "phone": "+70353174844"}
0005434586330	DC5262	5007 985166	ELENA TARASOVA	{"email": "e_tarasova03011979@postgrespro.ru", "phone": "+70346366448"}
0005434586331	DC5262	4979 678570	OLGA MAKSIMOVA	{"phone": "+70548486540"}
0005434586332	34E949	7025 188407	VLADIMIR KAZAKOV	{"email": "v_kazakov-101978@postgrespro.ru", "phone": "+70552759690"}
0005434586333	4983D6	0909 293330	EVGENIY ALEKSEEV	{"phone": "+70449957089"}
0005434586334	84A0AD	4073 788226	OLGA RODIONOVA	{"phone": "+70152547994"}
0005434586335	E8AF5C	7446 112177	GEORGIY KOROLEV	{"email": "g_korolev-1983@postgrespro.ru", "phone": "+70455477340"}
0005434586336	54B431	6353 575638	VALENTINA DAVYDOVA	{"email": "vdavydova_1959@postgrespro.ru", "phone": "+70329975689"}
0005434586337	1252BA	8552 534657	VLADIMIR NIKOLAEV	{"phone": "+70525386665"}
0005434586338	F37F40	7071 351614	VALENTINA SERGEEVA	{"email": "sergeeva-valentina1973@postgrespro.ru", "phone": "+70881801264"}
0005434586339	E3CD14	9366 049692	VALENTINA LUKYANOVA	{"email": "valentina-lukyanova09111960@postgrespro.ru", "phone": "+70307235731"}
0005434586340	E3CD14	5112 313900	ANNA GRISHINA	{"phone": "+70382417472"}
0005434586341	E3CD14	0812 527261	NADEZHDA CHERNOVA	{"phone": "+70512795003"}
0005434586342	8976B5	7078 262787	ALEKSANDR FROLOV	{"phone": "+70787801757"}
0005434586343	8976B5	8320 404385	MIKHAIL STEPANOV	{"email": "stepanov.m.091967@postgrespro.ru", "phone": "+70168698594"}
0005434586344	D0113D	3184 082859	RUFINA GAVRILOVA	{"email": "gavrilovar-23091973@postgrespro.ru", "phone": "+70448886535"}
0005434586345	D0113D	2581 385810	DENIS TARASOV	{"email": "denis.tarasov08091979@postgrespro.ru", "phone": "+70554141119"}
0005434586346	D65E20	0983 402194	PETR KISELEV	{"email": "p-kiselev.061976@postgrespro.ru", "phone": "+70085954870"}
0005434586347	157181	7873 857809	KRISTINA KONOVALOVA	{"phone": "+70596963967"}
0005434586348	157181	4853 687998	ANATOLIY GUSEV	{"email": "gusev.a_1966@postgrespro.ru", "phone": "+70922678110"}
0005434586349	0D4492	4051 145244	ANTON GORBUNOV	{"email": "a_gorbunov-1973@postgrespro.ru", "phone": "+70933965357"}
0005434586350	7AC129	8449 616103	DANIL ROMANOV	{"phone": "+70139744970"}
0005434586351	CC8308	6737 282834	ALEKSANDRA ZOTOVA	{"phone": "+70609633941"}
0005434586352	FA4A74	7074 709572	VARVARA LUKYANOVA	{"email": "varvara_lukyanova_081973@postgrespro.ru", "phone": "+70102939540"}
0005434586353	6D39D8	8356 722317	VERA MELNIKOVA	{"phone": "+70617325720"}
0005434586354	6D39D8	7176 202044	ALEKSANDR KAZAKOV	{"phone": "+70844408451"}
0005434586355	0EED8A	5780 066304	ANDREY MARTYNOV	{"email": "a.martynov1974@postgrespro.ru", "phone": "+70404459468"}
0005434586356	F0E491	3108 697279	DMITRIY POPOV	{"phone": "+70074002425"}
0005434586357	1E23AB	0483 055134	VALERIY ANDREEV	{"email": "valeriyandreev.121969@postgrespro.ru", "phone": "+70262422720"}
0005434586358	5C1DAB	7273 595329	LARISA FILATOVA	{"email": "larisa.filatova091974@postgrespro.ru", "phone": "+70689622634"}
0005434586359	97797B	1253 989349	RAISA MASLOVA	{"email": "r_maslova091966@postgrespro.ru", "phone": "+70520055576"}
0005434586360	BE6956	4473 971686	ALEKSANDR VASILEV	{"email": "a.vasilev.18021980@postgrespro.ru", "phone": "+70936318042"}
0005434586361	065C18	9295 759447	ELIZAVETA KAZAKOVA	{"email": "kazakova-e_29111978@postgrespro.ru", "phone": "+70349401390"}
0005434586362	065C18	2594 042333	ALLA SIDOROVA	{"phone": "+70834479863"}
0005434586363	065C18	7830 407647	ANTONINA KOROLEVA	{"email": "koroleva_antonina111969@postgrespro.ru", "phone": "+70322658553"}
0005434586364	9A1760	0301 562936	NATALYA ILINA	{"email": "n-ilina-05081978@postgrespro.ru", "phone": "+70484416783"}
0005434586365	2385B9	5665 043721	DMITRIY MAKSIMOV	{"phone": "+70269354159"}
0005434586366	ED93FB	1723 614573	MARIYA KONOVALOVA	{"email": "mariya.konovalova.02031965@postgrespro.ru", "phone": "+70166472238"}
0005434586367	ED93FB	0997 453435	ANNA MIRONOVA	{"email": "mironova-anna.051971@postgrespro.ru", "phone": "+70154363172"}
0005434586368	A110B8	5644 774836	ALEKSEY KUZNECOV	{"phone": "+70138544174"}
0005434586369	F96424	2303 619255	SERGEY ALEKSANDROV	{"phone": "+70183400539"}
0005434586370	F96424	0383 323514	SVETLANA MASLOVA	{"phone": "+70857259693"}
0005434586371	42380F	9675 419625	ALEKSANDR ZHUKOV	{"phone": "+70850323157"}
0005434586372	F91648	3231 119228	VLADISLAV IVANOV	{"phone": "+70883525844"}
0005434586373	96F8FE	4144 359152	OLEG ORLOV	{"phone": "+70233833862"}
0005434586374	96F8FE	5385 511684	ALEKSANDR BONDARENKO	{"phone": "+70708898235"}
0005434586375	3B0F6B	3310 904781	NIKOLAY KISELEV	{"phone": "+70939790994"}
0005434586376	DB59BF	9213 485403	NIKOLAY ALEKSEEV	{"phone": "+70078735737"}
0005434586377	5DD1E1	1067 153994	LYUBOV LEBEDEVA	{"email": "lyubov-lebedeva.21041989@postgrespro.ru", "phone": "+70610681204"}
0005434586378	B51028	1283 183786	NADEZHDA KUZNECOVA	{"phone": "+70205798706"}
0005434586379	21102C	0346 823543	MARIYA MOROZOVA	{"email": "morozova_mariya-25091976@postgrespro.ru", "phone": "+70322790715"}
0005434586380	A30B76	0042 364289	RAISA IVANOVA	{"phone": "+70903080462"}
0005434586381	A30B76	3222 746730	EVGENIY ANDREEV	{"email": "andreev.evgeniy.12121973@postgrespro.ru", "phone": "+70006487069"}
0005434586382	A30B76	4387 240648	OLGA RODIONOVA	{"phone": "+70262510118"}
0005434586383	668497	2529 837877	VIKTOR FOMIN	{"phone": "+70088342490"}
0005434586384	F00122	0506 109736	VALERIY PAVLOV	{"phone": "+70154056902"}
0005434586385	5EE2B5	5405 549712	ALINA KOZLOVA	{"email": "kozlova-a20111973@postgrespro.ru", "phone": "+70302863851"}
0005434586386	CDD598	5363 126873	TAMARA KOLESNIKOVA	{"phone": "+70311955133"}
0005434586387	CDD598	1922 609106	VALENTINA MASLOVA	{"phone": "+70818032584"}
0005434586388	AE7AA8	0661 379542	PAVEL SAVELEV	{"phone": "+70391729416"}
0005434586389	AE7AA8	8343 173542	GALINA FEDOROVA	{"email": "fedorova-galina_25061968@postgrespro.ru", "phone": "+70639461380"}
0005434586390	0FAFE6	2637 409993	VALENTINA IVANOVA	{"email": "ivanovavalentina_1980@postgrespro.ru", "phone": "+70214238085"}
0005434586391	3A13DF	6216 457220	EVGENIYA ILINA	{"email": "e.ilina-09041966@postgrespro.ru", "phone": "+70380231058"}
0005434586392	C24D6C	4399 764451	VALERIY MARTYNOV	{"phone": "+70506021611"}
0005434586393	C24D6C	1901 797807	VYACHESLAV KUDRYASHOV	{"phone": "+70347328485"}
0005434586394	CC3943	7488 299679	IVAN KOROLEV	{"phone": "+70282742445"}
0005434586395	4ED847	8245 368129	ALEKSEY GORBUNOV	{"phone": "+70071624011"}
0005434586396	1FED21	7923 988276	TATYANA DANILOVA	{"phone": "+70563914898"}
0005434586397	265456	8209 311101	YULIYA PAVLOVA	{"email": "y-pavlova121973@postgrespro.ru", "phone": "+70291935560"}
0005434586398	7CE8D6	5212 157060	ALEKSEY ANTONOV	{"email": "antonov_a1976@postgrespro.ru", "phone": "+70808831331"}
0005434586399	7CE8D6	1734 646104	LEONID IVANOV	{"phone": "+70823880883"}
0005434586400	7EFAC6	0707 581703	TAMARA TITOVA	{"phone": "+70941702994"}
0005434586401	468EC1	2661 864136	RASIM ALEKSEEV	{"email": "ralekseev.19111973@postgrespro.ru", "phone": "+70617515383"}
0005434586402	468EC1	0156 483295	OLGA FROLOVA	{"email": "frolova.olga.29111967@postgrespro.ru", "phone": "+70463036398"}
0005434586403	468EC1	3092 092034	VALENTINA ILINA	{"email": "ilina.v_15111974@postgrespro.ru", "phone": "+70800205664"}
0005434586404	F50DDC	8239 658036	KUZMA FROLOV	{"email": "kuzma.frolov_18061978@postgrespro.ru", "phone": "+70102464406"}
0005434586405	A62469	0133 158556	IRINA ARKHIPOVA	{"phone": "+70436425375"}
0005434586406	64B146	7144 645292	ELENA KUZMINA	{"email": "elena-kuzmina1972@postgrespro.ru", "phone": "+70005212440"}
0005434586407	E3EEAE	4242 707708	VALENTINA KOROLEVA	{"phone": "+70233163338"}
0005434586408	401E2C	3225 497990	VIKTOR KRASNOV	{"email": "krasnov_viktor_1972@postgrespro.ru", "phone": "+70112428231"}
0005434586409	401E2C	3063 430948	ALEKSANDR SERGEEV	{"email": "a-sergeev.07011962@postgrespro.ru", "phone": "+70060531430"}
0005434586410	401E2C	8317 224639	MIKHAIL FILIPPOV	{"email": "mikhail.filippov-111978@postgrespro.ru", "phone": "+70087725555"}
0005434586412	5AA602	0621 551604	NADEZHDA ZAKHAROVA	{"email": "zakharovanadezhda_16121969@postgrespro.ru", "phone": "+70715708687"}
0005434586413	5AA602	1601 678128	ANTON SCHERBAKOV	{"email": "scherbakov_anton.101969@postgrespro.ru", "phone": "+70924342335"}
0005434586414	5AA602	8106 752252	IVAN VOROBEV	{"phone": "+70691437891"}
0005434586415	07910D	9407 932485	GALINA KONOVALOVA	{"phone": "+70182274123"}
0005434586416	31C219	7838 134282	PAVEL DMITRIEV	{"email": "dmitriev_p-1978@postgrespro.ru", "phone": "+70528166017"}
0005434586417	01ADC4	1041 949458	POLINA DAVYDOVA	{"email": "davydovap-101979@postgrespro.ru", "phone": "+70574721842"}
0005434586418	01ADC4	6389 219787	TATYANA EGOROVA	{"email": "t_egorova-061986@postgrespro.ru", "phone": "+70435116393"}
0005434586419	E65858	8825 885017	VALENTINA TIKHONOVA	{"phone": "+70783009406"}
0005434586420	E65858	4833 060773	ALINA KUZNECOVA	{"email": "a_kuznecova_1975@postgrespro.ru", "phone": "+70025796435"}
0005434586421	CA7765	5421 489370	MAKSIM GUSEV	{"phone": "+70186534826"}
0005434586422	CA7765	3718 072785	SERGEY MEDVEDEV	{"phone": "+70933756144"}
0005434586423	E866C8	6542 727629	NATALYA GRISHINA	{"phone": "+70650988852"}
0005434586424	E866C8	4550 319320	ALEKSANDR EGOROV	{"phone": "+70770919690"}
0005434586425	170697	4826 378748	VIKTOR ZHUKOV	{"email": "zhukov-viktor111971@postgrespro.ru", "phone": "+70004499464"}
0005434586426	809BE5	9040 125547	IVAN BELOV	{"email": "belov.ivan-20091978@postgrespro.ru", "phone": "+70628021207"}
0005434586427	BAC1E6	9642 083545	LARISA YAKOVLEVA	{"phone": "+70602382966"}
0005434586428	BAC1E6	8741 367715	MARGARITA NAUMOVA	{"email": "naumova.margarita1963@postgrespro.ru", "phone": "+70788835671"}
0005434586429	D3A38D	0950 736003	GALINA AKIMOVA	{"phone": "+70240016765"}
0005434586430	699A34	4931 393949	LYUDMILA GORBUNOVA	{"phone": "+70080605634"}
0005434586431	14B27B	5406 482567	ANNA SIDOROVA	{"phone": "+70368433400"}
0005434586432	14B27B	9296 206757	IRINA POPOVA	{"email": "popova-i-31101974@postgrespro.ru", "phone": "+70119202589"}
0005434586433	8081BD	2975 667915	ELENA POLYAKOVA	{"email": "polyakovae_1955@postgrespro.ru", "phone": "+70615477889"}
0005434586434	AFF664	8423 129739	GALINA NIKITINA	{"phone": "+70312998384"}
0005434586435	AFF664	5869 161224	ILYA IVANOV	{"phone": "+70613153022"}
0005434586436	06D29E	1124 891499	TAMARA KOVALEVA	{"email": "kovaleva-tamara.071973@postgrespro.ru", "phone": "+70848042969"}
0005434586437	D457A3	1772 557917	ALEKSANDR BORISOV	{"phone": "+70853748973"}
0005434586438	C091E4	5568 961191	ALEKSEY FILIPPOV	{"email": "aleksey.filippov_1964@postgrespro.ru", "phone": "+70509886449"}
0005434586439	C091E4	4134 485237	VADIM SOLOVEV	{"email": "v-solovev.11121971@postgrespro.ru", "phone": "+70309817167"}
0005434586440	C57913	1469 712757	MARIYA FOMINA	{"phone": "+70632877590"}
0005434586441	2E002B	0748 844278	NIKOLAY SEMENOV	{"phone": "+70866829636"}
0005434586442	8A04DC	1384 338225	EVGENIYA AKIMOVA	{"email": "evgeniyaakimova-041974@postgrespro.ru", "phone": "+70955582528"}
0005434586443	DA16F4	2260 562641	NIKOLAY ZHUKOV	{"phone": "+70831818524"}
0005434586444	DCDC79	8203 748295	MARIYA FEDOROVA	{"email": "fedorova_mariya_18111981@postgrespro.ru", "phone": "+70656892751"}
0005434586445	7AFC47	7705 875555	YURIY ORLOV	{"email": "y-orlov.1965@postgrespro.ru", "phone": "+70761605014"}
0005434586446	7AFC47	6500 232031	VLADIMIR POPOV	{"phone": "+70586108599"}
0005434586447	D102F2	3744 209705	ZINAIDA MAKAROVA	{"email": "zmakarova_111987@postgrespro.ru", "phone": "+70118146430"}
0005434586448	98BDC8	3069 892644	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov.1974@postgrespro.ru", "phone": "+70998153411"}
0005434586449	98BDC8	3726 186051	YURIY NOVIKOV	{"phone": "+70816037294"}
0005434586450	F198C0	6213 385274	VALENTINA IVANOVA	{"email": "valentinaivanova1959@postgrespro.ru", "phone": "+70324374954"}
0005434586451	5EF320	9525 713412	VIKTOR MELNIKOV	{"phone": "+70154391436"}
0005434586452	E3E615	4501 404803	YULIYA NIKIFOROVA	{"email": "yuliya.nikiforova1978@postgrespro.ru", "phone": "+70151633462"}
0005434586453	0419CA	7785 469700	STANISLAV SIDOROV	{"email": "sidorov-stanislav.27041968@postgrespro.ru", "phone": "+70708976804"}
0005434586454	0419CA	2858 914557	ANNA FILATOVA	{"email": "filatova-a061968@postgrespro.ru", "phone": "+70466943433"}
0005434586455	9E1003	9360 666774	YULIYA DMITRIEVA	{"phone": "+70251476577"}
0005434586456	435783	1520 463574	ALEKSANDR FEDOROV	{"email": "fedorova.11071974@postgrespro.ru", "phone": "+70343241870"}
0005434586457	435783	4800 052908	ANASTASIYA FROLOVA	{"phone": "+70692594545"}
0005434586458	248106	4923 756179	SERGEY IVANOV	{"phone": "+70164435890"}
0005434586459	935168	3102 159141	DENIS SERGEEV	{"email": "d-sergeev101968@postgrespro.ru", "phone": "+70451063776"}
0005434586460	9D3CF7	8606 695533	EKATERINA IVANOVA	{"phone": "+70712693316"}
0005434586461	6963FF	5557 851512	IRINA ORLOVA	{"phone": "+70293147811"}
0005434586462	7A2DAC	0594 730514	ALEKSEY DMITRIEV	{"email": "dmitriev.a.1966@postgrespro.ru", "phone": "+70125422224"}
0005434586463	14BCBA	4270 988187	TATYANA SOLOVEVA	{"phone": "+70792687134"}
0005434586464	F1C219	2921 931562	TAMARA KOVALEVA	{"phone": "+70009408369"}
0005434586465	4B04B1	3825 416849	VALENTINA KOZLOVA	{"email": "kozlova-v091973@postgrespro.ru", "phone": "+70291640401"}
0005434586466	D54EC0	8900 900970	ILYA NIKITIN	{"email": "nikitin.i_1968@postgrespro.ru", "phone": "+70679216098"}
0005434586467	7A1882	2068 983215	GENNADIY DENISOV	{"email": "denisov-gennadiy.1965@postgrespro.ru", "phone": "+70367071593"}
0005434586468	7A1882	4646 819116	ALEKSANDR SMIRNOV	{"email": "a-smirnov-041985@postgrespro.ru", "phone": "+70817689889"}
0005434586469	FE332F	3724 028207	ELENA STEPANOVA	{"phone": "+70822922393"}
0005434586470	FE332F	2884 859243	ALEKSANDR SEMENOV	{"email": "semenovaleksandr.101978@postgrespro.ru", "phone": "+70359969050"}
0005434586471	211C2E	0317 730305	EVGENIY RODIONOV	{"phone": "+70069343506"}
0005434586472	D7EC26	9009 978625	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy_1964@postgrespro.ru", "phone": "+70214693262"}
0005434586473	D7EC26	4688 690573	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy.13111962@postgrespro.ru", "phone": "+70591469728"}
0005434586474	79065D	1390 938802	ALEKSANDR KOROLEV	{"email": "akorolev.121980@postgrespro.ru", "phone": "+70118822968"}
0005434586475	093C72	9481 226201	RAFAEL EGOROV	{"email": "rafaelegorov.1968@postgrespro.ru", "phone": "+70756220584"}
0005434586476	093C72	0111 030428	ALEKSEY ZHURAVLEV	{"email": "zhuravlev.aleksey-011976@postgrespro.ru", "phone": "+70898422997"}
0005434586477	A8D071	1944 091864	ANTONINA CHERNOVA	{"phone": "+70149784157"}
0005434586478	58B61D	5020 353124	EVGENIY KAZAKOV	{"phone": "+70626234367"}
0005434586479	58B61D	7114 376796	GALINA ISAEVA	{"email": "galinaisaeva081975@postgrespro.ru", "phone": "+70974333595"}
0005434586480	867A11	6083 998971	KONSTANTIN KAZAKOV	{"email": "konstantin.kazakov.10101974@postgrespro.ru", "phone": "+70166497544"}
0005434586481	2E5018	7095 005638	VIKTOR FILIPPOV	{"phone": "+70172051542"}
0005434586482	E936DC	4720 724751	NINA ABRAMOVA	{"phone": "+70364128644"}
0005434586483	045579	7607 172250	IGOR MAKSIMOV	{"phone": "+70191289978"}
0005434586484	045579	0898 695987	ANDREY PETROV	{"phone": "+70987655132"}
0005434586485	77CCA7	2703 609710	YURIY ALEKSEEV	{"phone": "+70039540337"}
0005434586486	F22BC8	5567 813459	ELENA VOROBEVA	{"email": "vorobeva-e1971@postgrespro.ru", "phone": "+70516601518"}
0005434586487	942C7A	1727 935010	IRINA IVANOVA	{"email": "ivanova_i-1965@postgrespro.ru", "phone": "+70318002232"}
0005434586488	983770	1516 704422	ALEKSEY SOKOLOV	{"email": "sokolov-a081970@postgrespro.ru", "phone": "+70142202337"}
0005434586489	1714D0	1039 575441	ZOYA GERASIMOVA	{"phone": "+70404199110"}
0005434586490	B18178	8746 661461	GALINA MEDVEDEVA	{"email": "g_medvedeva06021981@postgrespro.ru", "phone": "+70899344395"}
0005434586491	B18178	6215 057643	YULIYA IVANOVA	{"phone": "+70653451878"}
0005434586492	C63BE4	3295 545681	ZAKHAR TIMOFEEV	{"phone": "+70224155106"}
0005434586493	DD58F0	9145 464738	YURIY RODIONOV	{"phone": "+70608528027"}
0005434586494	DD58F0	0907 143868	ANDREY NIKOLAEV	{"phone": "+70522443731"}
0005434586495	671B10	5140 127743	IVAN RODIONOV	{"email": "i.rodionov_031963@postgrespro.ru", "phone": "+70796327383"}
0005434586496	C3ABDC	9521 006562	GALINA SOKOLOVA	{"email": "g_sokolova.23091978@postgrespro.ru", "phone": "+70440706552"}
0005434586497	C5EB38	3699 354614	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr121977@postgrespro.ru", "phone": "+70847714566"}
0005434586498	A8373D	6119 113152	ALEKSANDR ALEKSEEV	{"email": "aleksandr_alekseev_23031967@postgrespro.ru", "phone": "+70163946407"}
0005434586499	A8373D	1410 035193	OLEG MIRONOV	{"email": "mironovo021972@postgrespro.ru", "phone": "+70661851962"}
0005434586500	012EBE	8842 806612	MIKHAIL SOKOLOV	{"phone": "+70196017595"}
0005434586501	06CD08	6649 053289	GENNADIY ABRAMOV	{"phone": "+70128181901"}
0005434586502	06CD08	8952 091769	ALEKSANDR KISELEV	{"email": "kiseleva-041962@postgrespro.ru", "phone": "+70333342658"}
0005434586503	9E27F2	3146 097981	ALEKSANDR RODIONOV	{"email": "rodionovaleksandr-20111973@postgrespro.ru", "phone": "+70824948306"}
0005434586504	9E27F2	8659 084207	KONSTANTIN ZAYCEV	{"email": "zaycev-k-1972@postgrespro.ru", "phone": "+70184829275"}
0005434586505	386EC8	4476 681426	YAROSLAVA KUZNECOVA	{"email": "yaroslava.kuznecova1977@postgrespro.ru", "phone": "+70368351357"}
0005434586506	386EC8	7396 336499	TAMARA SERGEEVA	{"email": "sergeevat05011966@postgrespro.ru", "phone": "+70761512799"}
0005434586507	86ECED	0334 689644	ALEKSANDR KAZAKOV	{"phone": "+70753426252"}
0005434586508	D2486E	3455 563812	TATYANA VASILEVA	{"email": "tatyana.vasileva-111968@postgrespro.ru", "phone": "+70287114492"}
0005434586509	D2486E	1724 059682	VITALIY GUSEV	{"phone": "+70701554343"}
0005434586510	792846	8986 866334	ALEKSANDR KUZNECOV	{"phone": "+70980772354"}
0005434586511	792846	9536 913717	DMITRIY KISELEV	{"email": "kiselev-d_051961@postgrespro.ru", "phone": "+70257550074"}
0005434586512	60392B	3576 482073	ANNA KRASNOVA	{"phone": "+70541351271"}
0005434586513	D6393C	5976 413584	VLADIMIR IVANOV	{"phone": "+70207230482"}
0005434586514	69DF88	0063 586577	YURIY ILIN	{"phone": "+70129515631"}
0005434586515	7238BA	8767 402865	SERGEY NIKOLAEV	{"email": "nikolaev.sergey-021976@postgrespro.ru", "phone": "+70043837674"}
0005434586516	81BC7A	6722 295006	OLEG FOMIN	{"phone": "+70962208815"}
0005434586517	BAC8F7	5385 877710	IGOR KUZMIN	{"email": "kuzmin.igor_12121980@postgrespro.ru", "phone": "+70139329809"}
0005434586518	A872F1	5440 294793	ELENA LEBEDEVA	{"email": "elena_lebedeva.05111971@postgrespro.ru", "phone": "+70105321565"}
0005434586519	83DE05	0478 821894	VLADIMIR ISAEV	{"phone": "+70843323491"}
0005434586520	33E19A	2753 349569	LYUDMILA GORBUNOVA	{"phone": "+70072976106"}
0005434586521	AC380A	7184 057906	RAFAEL NIKOLAEV	{"phone": "+70267957868"}
0005434586522	21BDE2	2819 154211	GENNADIY KUZNECOV	{"email": "kuznecov_g_1978@postgrespro.ru", "phone": "+70100637161"}
0005434586523	21BDE2	4631 797771	VLADIMIR KUDRYASHOV	{"phone": "+70032726135"}
0005434586525	B7FEAB	1545 500230	VIKTOR SAVELEV	{"phone": "+70410408772"}
0005434586526	712E2F	0688 746863	NINA SEMENOVA	{"email": "ninasemenova-121961@postgrespro.ru", "phone": "+70285154458"}
0005434586527	62AA8E	4542 125186	VALENTINA TIKHONOVA	{"email": "v.tikhonova.091970@postgrespro.ru", "phone": "+70599845857"}
0005434586528	5FEAA0	4669 912827	NADEZHDA KUZNECOVA	{"phone": "+70847109836"}
0005434586529	ACA031	2299 450536	ALENA SMIRNOVA	{"phone": "+70316419347"}
0005434586530	7D9CD6	7117 407366	ALLA NESTEROVA	{"email": "alla_nesterova.02021974@postgrespro.ru", "phone": "+70877468439"}
0005434586531	1FCF83	0207 825326	ANDREY DAVYDOV	{"phone": "+70598865269"}
0005434586532	23432E	3072 273286	NATALYA MELNIKOVA	{"email": "melnikova.natalya-021974@postgrespro.ru", "phone": "+70566912677"}
0005434586533	23432E	9397 271185	MATVEY POPOV	{"email": "popov-matvey.28061962@postgrespro.ru", "phone": "+70449491690"}
0005434586534	80B036	6242 353880	VIKTOR IVANOV	{"phone": "+70465299060"}
0005434586535	80B036	0754 669837	DMITRIY ALEKSEEV	{"phone": "+70810912177"}
0005434586536	1C20AB	2967 346775	LILIYA ARKHIPOVA	{"phone": "+70474211165"}
0005434586537	117683	4902 805652	SERGEY KUZMIN	{"email": "s.kuzmin_15071977@postgrespro.ru", "phone": "+70200664575"}
0005434586538	18D9A8	6057 605242	MARIYA DAVYDOVA	{"email": "davydova_mariya.10041971@postgrespro.ru", "phone": "+70549045931"}
0005434586539	FDA29B	4549 214225	TATYANA VOROBEVA	{"email": "t-vorobeva_031972@postgrespro.ru", "phone": "+70721871514"}
0005434586540	1518EC	2424 297704	DIANA FEDOROVA	{"phone": "+70916859925"}
0005434586541	9CAC54	0526 697502	SERGEY KARPOV	{"phone": "+70308921418"}
0005434586542	524E97	9431 857333	VITALIY KISELEV	{"phone": "+70351222791"}
0005434586543	830653	2217 036455	LYUBOV BELOVA	{"phone": "+70792760467"}
0005434586544	830653	9240 722436	ALEKSEY TIMOFEEV	{"email": "timofeev.aleksey.12121983@postgrespro.ru", "phone": "+70660091096"}
0005434586545	830653	0377 536652	ADELINA ZAYCEVA	{"phone": "+70373601901"}
0005434586546	8A75AE	5480 170083	VLADIMIR MIRONOV	{"email": "v_mironov.111960@postgrespro.ru", "phone": "+70577299886"}
0005434586547	6C51D0	1396 036509	ILDAR ANTONOV	{"phone": "+70710731582"}
0005434586548	18B868	2836 161419	VALENTINA KUZNECOVA	{"email": "kuznecovavalentina-26121965@postgrespro.ru", "phone": "+70163330016"}
0005434586549	18B868	3270 828315	ALEKSEY GORBUNOV	{"email": "gorbunov_a.18061975@postgrespro.ru", "phone": "+70308734112"}
0005434586550	5D3BB2	6958 237145	EKATERINA KOROLEVA	{"email": "koroleva.e-111974@postgrespro.ru", "phone": "+70956459190"}
0005434586551	5D3BB2	5718 475358	ROMAN MOROZOV	{"phone": "+70144856774"}
0005434586552	C0253C	7022 446439	ANATOLIY RODIONOV	{"email": "rodionov_anatoliy_051958@postgrespro.ru", "phone": "+70444376796"}
0005434586553	BE7E6E	5329 936953	GALINA KOROLEVA	{"email": "galinakoroleva-1972@postgrespro.ru", "phone": "+70234772766"}
0005434586554	9E68BA	0866 716823	ANASTASIYA MIKHAYLOVA	{"phone": "+70791193467"}
0005434586555	6D8C84	5636 798205	EGOR STEPANOV	{"phone": "+70536487200"}
0005434586556	47B663	4824 464287	MIKHAIL IVANOV	{"email": "ivanov.m_26121980@postgrespro.ru", "phone": "+70364663541"}
0005434586557	47B663	5984 448850	SVETLANA GAVRILOVA	{"email": "gavrilovas.07061966@postgrespro.ru", "phone": "+70502069080"}
0005434586558	6D5BB8	6439 270459	ALEKSANDR MATVEEV	{"email": "aleksandr_matveev101980@postgrespro.ru", "phone": "+70783409151"}
0005434586559	E5CA0A	9970 030145	MARGARITA KOZLOVA	{"phone": "+70436097158"}
0005434586560	7BEED1	8267 629968	LIDIYA AKIMOVA	{"phone": "+70815468589"}
0005434586561	154833	4003 258266	NIKOLAY KUZMIN	{"phone": "+70670913432"}
0005434586562	265FE1	7616 384839	ZAKHAR MEDVEDEV	{"email": "medvedev.z10071971@postgrespro.ru", "phone": "+70384604681"}
0005434586563	8BFD48	7217 956228	ALEKSEY KRASNOV	{"email": "krasnova011960@postgrespro.ru", "phone": "+70097003134"}
0005434586564	8BFD48	2141 844154	ANDREY NIKOLAEV	{"email": "andrey_nikolaev.1965@postgrespro.ru", "phone": "+70089529883"}
0005434586565	8BFD48	7424 221836	GALINA LOGINOVA	{"email": "g-loginova.1973@postgrespro.ru", "phone": "+70507273011"}
0005434586566	72E1E0	0170 135154	KLAVDIYA ARKHIPOVA	{"email": "klavdiya-arkhipova.23081968@postgrespro.ru", "phone": "+70922085356"}
0005434586567	8580CD	8389 447656	MIKHAIL ZHUKOV	{"phone": "+70709359576"}
0005434586568	8580CD	5686 399581	SERGEY KARPOV	{"phone": "+70230281195"}
0005434586569	1746BB	2956 132362	IRINA FILIPPOVA	{"phone": "+70410046517"}
0005434586570	1746BB	7437 835671	VASILIY PAVLOV	{"phone": "+70999809893"}
0005434586571	31365A	2190 605974	ALEKSEY SAVELEV	{"phone": "+70039235214"}
0005434586572	31365A	8931 395101	ALEKSEY PETROV	{"phone": "+70091511257"}
0005434586573	39B2B8	2644 206841	ROMAN GORBUNOV	{"email": "gorbunov_r_10021966@postgrespro.ru", "phone": "+70461848969"}
0005434586574	185449	8975 430975	PELAGEYA GRISHINA	{"phone": "+70546899391"}
0005434586575	6F04A3	4506 000233	ILYA IVANOV	{"phone": "+70814756600"}
0005434586576	DC7CE0	9691 791489	VALENTINA KULIKOVA	{"phone": "+70095654823"}
0005434586577	D8959D	0686 814186	ELENA FEDOROVA	{"email": "fedorova.elena.1978@postgrespro.ru", "phone": "+70028170498"}
0005434586578	B9ECFA	8563 839849	DMITRIY ZAKHAROV	{"phone": "+70402936380"}
0005434586579	2F390C	9022 458012	ALEKSANDR IVANOV	{"email": "ivanovaleksandr13041965@postgrespro.ru", "phone": "+70822484715"}
0005434586580	D4F268	1900 957581	DMITRIY TIKHONOV	{"email": "tikhonov-d07041974@postgrespro.ru", "phone": "+70894668220"}
0005434586581	0B21AF	6536 105382	SERGEY ZHURAVLEV	{"phone": "+70015519112"}
0005434586582	0B21AF	4120 492565	VIKTOR MELNIKOV	{"phone": "+70882875830"}
0005434586583	3C8D19	9307 035241	TATYANA SAVELEVA	{"email": "tatyanasaveleva_111976@postgrespro.ru", "phone": "+70080758193"}
0005434586584	D7FCFC	4864 406913	YULIYA ORLOVA	{"phone": "+70489471064"}
0005434586585	040786	1782 010280	VALERIY KOZLOV	{"phone": "+70641292124"}
0005434586586	9ECA2B	0987 675081	NINA KUDRYASHOVA	{"phone": "+70088842333"}
0005434586587	F1FCF5	1412 176232	EVGENIY ANDREEV	{"email": "evgeniy_andreev-011974@postgrespro.ru", "phone": "+70710267076"}
0005434586588	F1FCF5	3858 810249	ANDREY KUZNECOV	{"email": "kuznecovandrey051977@postgrespro.ru", "phone": "+70677165826"}
0005434586589	196751	1383 928814	GALINA POTAPOVA	{"phone": "+70783544886"}
0005434586590	60E9C0	9911 602746	NINA SOROKINA	{"phone": "+70029464743"}
0005434586591	BD9F69	9991 494049	LIDIYA BELYAEVA	{"email": "belyaeva_l-1957@postgrespro.ru", "phone": "+70025757568"}
0005434586592	E45DCC	3115 528853	SERGEY VASILEV	{"email": "vasilev-s.09101966@postgrespro.ru", "phone": "+70933404385"}
0005434586593	BFC8A6	5009 222855	OLEG KUDRYASHOV	{"email": "kudryashov.oleg.1976@postgrespro.ru", "phone": "+70323358276"}
0005434586594	4B06CA	4161 208749	NADEZHDA GRISHINA	{"email": "nadezhda-grishina-1975@postgrespro.ru", "phone": "+70688103400"}
0005434586595	941EFC	5376 633773	ALEKSEY SMIRNOV	{"email": "smirnova_061979@postgrespro.ru", "phone": "+70938369283"}
0005434586596	941EFC	9850 338551	SERGEY MATVEEV	{"email": "s_matveev121976@postgrespro.ru", "phone": "+70925502887"}
0005434586597	95F364	6784 069144	VIKTOR VASILEV	{"phone": "+70534542897"}
0005434586598	9C3D73	8218 684662	TATYANA AKIMOVA	{"email": "t_akimova-28051973@postgrespro.ru", "phone": "+70926979395"}
0005434586599	9C3D73	5941 516216	PETR ALEKSANDROV	{"phone": "+70670063749"}
0005434586600	B44601	7057 171968	KIRILL MOROZOV	{"email": "kmorozov-12081967@postgrespro.ru", "phone": "+70071389090"}
0005434586601	D5C43E	2180 244714	VYACHESLAV KUZNECOV	{"email": "kuznecov-v-01051975@postgrespro.ru", "phone": "+70717607617"}
0005434586602	D5C43E	2137 045448	SEMEN ALEKSANDROV	{"phone": "+70331392354"}
0005434586603	F2F121	4851 267275	LUIZA KAZAKOVA	{"email": "kazakova.l-021984@postgrespro.ru", "phone": "+70293677828"}
0005434586604	F2F121	7689 212912	DARYA EGOROVA	{"email": "darya_egorova.03111974@postgrespro.ru", "phone": "+70587043785"}
0005434586605	901D34	7151 944630	ANNA SAVELEVA	{"phone": "+70458159425"}
0005434586606	51646D	3899 787592	NATALYA TITOVA	{"email": "ntitova-121973@postgrespro.ru", "phone": "+70291393854"}
0005434586607	28383E	8935 316220	VLADIMIR DENISOV	{"phone": "+70501357491"}
0005434586608	AA367C	7592 174507	VIKTORIYA DMITRIEVA	{"email": "viktoriya_dmitrieva_19031968@postgrespro.ru", "phone": "+70032261020"}
0005434586609	10CF3F	6353 262035	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov-1978@postgrespro.ru", "phone": "+70283854046"}
0005434586610	10CF3F	6004 420222	TATYANA GORBUNOVA	{"email": "gorbunova-t02121969@postgrespro.ru", "phone": "+70237027658"}
0005434586611	10CF3F	5386 648918	VITALIY MELNIKOV	{"email": "vitaliy.melnikov-15011984@postgrespro.ru", "phone": "+70884049328"}
0005434586612	1E2775	9712 754429	SVETLANA SIDOROVA	{"email": "svetlana-sidorova_1967@postgrespro.ru", "phone": "+70852922410"}
0005434586613	8214BB	7622 307753	DARYA KOROLEVA	{"email": "koroleva.darya_101981@postgrespro.ru", "phone": "+70761343573"}
0005434586614	6B1396	6013 948761	OLGA MATVEEVA	{"phone": "+70977168014"}
0005434586615	9D25E8	7175 117481	MARINA SOROKINA	{"email": "sorokina-marina.1977@postgrespro.ru", "phone": "+70819627717"}
0005434586616	9D25E8	2201 591872	RUSLAN KAZAKOV	{"phone": "+70285426546"}
0005434586617	66FF16	5914 371294	ANASTASIYA SCHERBAKOVA	{"phone": "+70777598290"}
0005434586618	47070A	0007 775812	VLADIMIR KOROLEV	{"email": "vkorolev.19071964@postgrespro.ru", "phone": "+70581096064"}
0005434586619	47070A	0476 427515	NINA PAVLOVA	{"phone": "+70953887525"}
0005434586620	7400F0	6675 829127	ALEKSANDR ROMANOV	{"phone": "+70134451428"}
0005434586621	1882BA	9660 433886	OLGA MARTYNOVA	{"phone": "+70551464151"}
0005434586622	1882BA	6864 303062	OKSANA ALEKSANDROVA	{"email": "oksanaaleksandrova021973@postgrespro.ru", "phone": "+70502908639"}
0005434586623	1C4C97	8033 420190	KIRILL IVANOV	{"phone": "+70234558036"}
0005434586624	DA99C5	7079 807411	OLESYA DMITRIEVA	{"email": "dmitrieva.o091971@postgrespro.ru", "phone": "+70542298943"}
0005434586625	420147	9498 589066	KUZMA VOLKOV	{"email": "k.volkov09041980@postgrespro.ru", "phone": "+70139718537"}
0005434586626	420147	3601 127471	ALEKSANDRA SIDOROVA	{"phone": "+70399734597"}
0005434586627	420147	1027 674442	GALINA ANISIMOVA	{"email": "anisimovag121971@postgrespro.ru", "phone": "+70956287947"}
0005434586628	0A9F16	6409 307485	RAUF DAVYDOV	{"email": "r_davydov24071978@postgrespro.ru", "phone": "+70751638053"}
0005434586629	1380D6	4087 968440	ALEKSANDR KOZLOV	{"phone": "+70868731619"}
0005434586630	E5DEA9	4673 916523	ANNA MAKAROVA	{"email": "annamakarova.031971@postgrespro.ru", "phone": "+70164751265"}
0005434586631	80386A	8328 931601	SERGEY KUZMIN	{"email": "sergeykuzmin.041982@postgrespro.ru", "phone": "+70167284290"}
0005434586632	AF8258	1893 168826	ARTEM VOLKOV	{"phone": "+70704018855"}
0005434586633	58DAF5	5934 614826	VYACHESLAV SOKOLOV	{"email": "sokolov_vyacheslav1966@postgrespro.ru", "phone": "+70965043448"}
0005434586634	98C728	9377 086389	VASILIY NIKOLAEV	{"email": "nikolaevv-09091977@postgrespro.ru", "phone": "+70273354314"}
0005434586635	98C728	3202 057050	PAVEL PAVLOV	{"phone": "+70462496463"}
0005434586636	C9AEF0	1704 873719	SERGEY NAZAROV	{"email": "nazarov_s.1969@postgrespro.ru", "phone": "+70365707789"}
0005434586637	A81BDF	2947 670924	TATYANA KOMAROVA	{"email": "tatyana_komarova081956@postgrespro.ru", "phone": "+70859506225"}
0005434586638	A81BDF	2918 923614	DENIS ANTONOV	{"phone": "+70084235720"}
0005434586639	248E2F	5722 046031	IRINA PAVLOVA	{"email": "i_pavlova.021983@postgrespro.ru", "phone": "+70697065505"}
0005434586640	C19873	8902 768658	EVGENIY ZAKHAROV	{"email": "ezakharov-1976@postgrespro.ru", "phone": "+70253315857"}
0005434586641	D0E85A	4310 297408	EVGENIY VOLKOV	{"email": "volkove1969@postgrespro.ru", "phone": "+70722400979"}
0005434586642	E816E5	6696 913152	LIDIYA FOMINA	{"phone": "+70025803760"}
0005434586643	6C54FD	8653 847627	ALEKSANDRA NIKOLAEVA	{"email": "aleksandranikolaeva_051964@postgrespro.ru", "phone": "+70976104213"}
0005434586644	24D7D0	7132 706230	SERGEY POPOV	{"email": "spopov061983@postgrespro.ru", "phone": "+70516240638"}
0005434586645	A1AFB1	8951 999970	SVETLANA YUDINA	{"phone": "+70845511304"}
0005434586646	B96C26	9342 202786	MARINA MALYSHEVA	{"email": "mmalysheva.1985@postgrespro.ru", "phone": "+70300915464"}
0005434586647	B3EE38	9820 901935	ALEKSEY POPOV	{"email": "a-popov.06051976@postgrespro.ru", "phone": "+70665503424"}
0005434586648	9D064E	5954 431129	NIKITA DMITRIEV	{"email": "nikitadmitriev.1984@postgrespro.ru", "phone": "+70821454685"}
0005434586649	F3D0DF	7332 263316	POLINA EGOROVA	{"phone": "+70021289614"}
0005434586650	484FC8	0687 206540	LARISA IVANOVA	{"phone": "+70473759747"}
0005434586651	484FC8	2061 644841	STEPAN BELOV	{"email": "belov_stepan.1974@postgrespro.ru", "phone": "+70435684731"}
0005434586652	18D8F5	4971 793266	IGOR KONOVALOV	{"phone": "+70814022253"}
0005434586653	18D8F5	7795 274295	YULIYA CHERNOVA	{"phone": "+70629489201"}
0005434586654	33AA5E	5142 670108	DARYA SMIRNOVA	{"phone": "+70350368095"}
0005434586655	B72085	0349 130414	EGOR KUZNECOV	{"phone": "+70679841580"}
0005434586656	C7B37D	2271 633380	ALEKSEY KUZNECOV	{"email": "kuznecov.a-111961@postgrespro.ru", "phone": "+70635011730"}
0005434586657	5CF47C	6701 235679	NATALYA SOKOLOVA	{"email": "sokolova.n_1962@postgrespro.ru", "phone": "+70431202151"}
0005434586658	67B7B8	0265 539671	ANTONINA NAZAROVA	{"email": "a_nazarova-041971@postgrespro.ru", "phone": "+70318592968"}
0005434586659	BE6105	0192 697978	MARIYA PETROVA	{"phone": "+70020166732"}
0005434586660	BE6105	7776 553942	EKATERINA IVANOVA	{"email": "ivanova-ekaterina_1964@postgrespro.ru", "phone": "+70190222494"}
0005434586661	AF54E9	5717 264342	ELENA DMITRIEVA	{"phone": "+70833729791"}
0005434586662	F0DCAC	3086 378140	YURIY IVANOV	{"email": "yuriy.ivanov_1965@postgrespro.ru", "phone": "+70227516631"}
0005434586663	F0DCAC	3261 730843	DMITRIY KUZMIN	{"email": "kuzmindmitriy-111968@postgrespro.ru", "phone": "+70392068231"}
0005434586664	524F39	0743 420476	NADEZHDA AFANASEVA	{"email": "afanaseva.n.30041982@postgrespro.ru", "phone": "+70116521994"}
0005434586665	91AF4C	8518 040377	SERGEY BONDARENKO	{"email": "sergey.bondarenko.1976@postgrespro.ru", "phone": "+70891450418"}
0005434586666	DB5D9A	9004 133196	NINA DAVYDOVA	{"email": "nina-davydova-031979@postgrespro.ru", "phone": "+70105267094"}
0005434586667	BB2FF7	4567 160160	EVGENIYA MATVEEVA	{"email": "matveevae_06031965@postgrespro.ru", "phone": "+70300923732"}
0005434586668	D1BFD0	7976 572025	NATALIYA ISAEVA	{"phone": "+70672586605"}
0005434586669	B215C7	0346 780347	ZHANNA DENISOVA	{"phone": "+70595550120"}
0005434586670	B9818F	8259 659386	VLADIMIR GAVRILOV	{"phone": "+70971949900"}
0005434586671	B9818F	7789 771099	SERGEY SIDOROV	{"phone": "+70975128195"}
0005434586672	0D437C	6721 767591	NATALYA MAKAROVA	{"email": "makarova_natalya.17031967@postgrespro.ru", "phone": "+70028368930"}
0005434586673	52D836	3262 124511	EVDOKIYA DAVYDOVA	{"email": "e.davydova021975@postgrespro.ru", "phone": "+70607677614"}
0005434586674	52D836	8232 936996	YULIYA IVANOVA	{"email": "ivanova.yuliya_14061976@postgrespro.ru", "phone": "+70264068886"}
0005434586675	B66AA7	3306 748473	EVA MOISEEVA	{"phone": "+70003541854"}
0005434586676	B66AA7	5695 287776	LIDIYA NESTEROVA	{"phone": "+70306815571"}
0005434586677	E277D1	5242 859349	VERA VLASOVA	{"phone": "+70838971387"}
0005434586678	2FE804	5239 976427	TAMARA TIKHONOVA	{"email": "tamara_tikhonova-1975@postgrespro.ru", "phone": "+70665408036"}
0005434586679	4A206D	4523 357555	ANASTASIYA FOMINA	{"phone": "+70063533056"}
0005434586680	4A206D	2618 082730	DENIS MOISEEV	{"email": "denis_moiseev-021968@postgrespro.ru", "phone": "+70647929694"}
0005434586681	59C8D0	3553 477320	GALINA KOVALEVA	{"email": "kovalevagalina-31081964@postgrespro.ru", "phone": "+70988997299"}
0005434586682	3E8860	9410 403053	OLGA NAUMOVA	{"phone": "+70145164859"}
0005434586683	9477B4	2823 462094	GALINA ZHUKOVA	{"email": "gzhukova041983@postgrespro.ru", "phone": "+70079650949"}
0005434586684	EE2502	5021 471998	EKATERINA ALEKSEEVA	{"email": "alekseeva.e1980@postgrespro.ru", "phone": "+70378105255"}
0005434586685	D75E14	1981 634646	POLINA ZHURAVLEVA	{"phone": "+70352207169"}
0005434586686	568778	2828 538561	VERA NIKOLAEVA	{"email": "vera-nikolaeva.021973@postgrespro.ru", "phone": "+70061038718"}
0005434586687	568778	2470 107085	TAMARA MIKHAYLOVA	{"phone": "+70010695332"}
0005434586688	1A9C5D	1421 251179	IRINA AKIMOVA	{"phone": "+70114719453"}
0005434586689	1A9C5D	5405 160445	MIKHAIL SHEVCHENKO	{"phone": "+70778599582"}
0005434586690	F1A51B	2895 499566	LARISA NESTEROVA	{"email": "nesterovalarisa-1975@postgrespro.ru", "phone": "+70284800584"}
0005434586691	D6EC88	1926 326210	DMITRIY ANDREEV	{"email": "andreev.d_071978@postgrespro.ru", "phone": "+70184690395"}
0005434586692	5048E3	7845 929866	ELIZAVETA NIKIFOROVA	{"email": "nikiforova-e08061980@postgrespro.ru", "phone": "+70991312123"}
0005434586693	3813AA	0690 606474	YURIY NIKOLAEV	{"phone": "+70366798837"}
0005434586694	3813AA	3163 433355	ANATOLIY SERGEEV	{"phone": "+70930846383"}
0005434586695	A54262	3397 037048	ALINA KOROLEVA	{"email": "koroleva-a_30121961@postgrespro.ru", "phone": "+70157638492"}
0005434586696	E6E797	4989 414374	VLADIMIR SOKOLOV	{"phone": "+70686807897"}
0005434586697	E6E797	8737 573565	IVAN ANDREEV	{"email": "andreev_ivan18061974@postgrespro.ru", "phone": "+70218015844"}
0005434586698	2D17C7	3682 431637	ELVIRA NOVIKOVA	{"email": "elviranovikova-1972@postgrespro.ru", "phone": "+70930155485"}
0005434586699	2D17C7	4990 996284	DARYA BORISOVA	{"email": "darya_borisova-01011968@postgrespro.ru", "phone": "+70124674458"}
0005434586700	442B89	3117 586526	EVGENIY MAKSIMOV	{"phone": "+70214821670"}
0005434586701	A0C71A	8562 739166	SERGEY NIKITIN	{"phone": "+70042292730"}
0005434586702	0D0667	1479 629855	LYUBOV ROMANOVA	{"phone": "+70983190606"}
0005434586703	D0D7C6	0297 746753	IRINA MAKSIMOVA	{"phone": "+70839924919"}
0005434586704	21F03B	2052 016271	VALENTINA DMITRIEVA	{"phone": "+70666009576"}
0005434586705	603256	9762 416568	KRISTINA SAVELEVA	{"email": "saveleva_k-101975@postgrespro.ru", "phone": "+70602869001"}
0005434586706	04B08E	7639 373318	LYUBOV FOMINA	{"phone": "+70934944194"}
0005434586707	8E49F4	4184 054187	MIKHAIL SCHERBAKOV	{"email": "mscherbakov1978@postgrespro.ru", "phone": "+70768787387"}
0005434586708	8E49F4	0251 600370	MIKHAIL SMIRNOV	{"email": "smirnov-mikhail1983@postgrespro.ru", "phone": "+70267939694"}
0005434586709	BFD83B	1214 159535	ELENA KONOVALOVA	{"email": "elenakonovalova.061970@postgrespro.ru", "phone": "+70082305165"}
0005434586710	BFD83B	5100 469978	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr.021970@postgrespro.ru", "phone": "+70870846006"}
0005434586711	BFD83B	1294 770800	ANASTASIYA IVANOVA	{"phone": "+70565425169"}
0005434586712	EF4B07	7439 678684	MARIYA TARASOVA	{"email": "mariya.tarasova.03111980@postgrespro.ru", "phone": "+70168357473"}
0005434586713	616573	4760 265671	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e.101969@postgrespro.ru", "phone": "+70935930097"}
0005434586714	2BA632	1355 161992	IVAN MAKSIMOV	{"email": "imaksimov031975@postgrespro.ru", "phone": "+70415863178"}
0005434586715	2BA632	5650 136729	MAKSIM MAKSIMOV	{"email": "maksimovm_28061961@postgrespro.ru", "phone": "+70128395557"}
0005434586716	2BA632	4820 126415	OLGA GAVRILOVA	{"email": "olga-gavrilova111975@postgrespro.ru", "phone": "+70860074382"}
0005434586717	862B8A	4166 267457	NATALYA KONDRATEVA	{"phone": "+70570681956"}
0005434586718	862B8A	2600 380593	IGOR DMITRIEV	{"phone": "+70376346637"}
0005434586719	283ABA	9314 638119	MARINA NAUMOVA	{"email": "m-naumova11041966@postgrespro.ru", "phone": "+70051217017"}
0005434586720	1A1651	6487 862542	ELIZAVETA NAZAROVA	{"phone": "+70365860085"}
0005434586721	1A1651	0261 101135	NIKOLAY KUZMIN	{"phone": "+70959081338"}
0005434586722	A0DA9D	9185 220237	EVGENIYA GRISHINA	{"email": "evgeniya_grishina-011980@postgrespro.ru", "phone": "+70965499166"}
0005434586723	A0DA9D	0125 673976	VALENTINA MASLOVA	{"email": "valentina.maslova.031971@postgrespro.ru", "phone": "+70764427782"}
0005434586724	04EA31	6079 963386	VIKTORIYA VOROBEVA	{"phone": "+70981235564"}
0005434586725	9A52CB	9540 585758	VLADIMIR SIDOROV	{"phone": "+70471890641"}
0005434586726	9A52CB	2845 911667	OLGA KUDRYASHOVA	{"phone": "+70664663241"}
0005434586727	E608FC	2878 053629	BORIS ILIN	{"email": "boris-ilin09081967@postgrespro.ru", "phone": "+70837054760"}
0005434586728	6B17C1	0973 381837	ELENA OVCHINNIKOVA	{"phone": "+70353142357"}
0005434586729	E9A7CD	3028 854393	VIKTOR IVANOV	{"email": "ivanov_v.1961@postgrespro.ru", "phone": "+70132296965"}
0005434586730	449D48	6779 116749	ALEKSANDR FEDOROV	{"email": "afedorov-1976@postgrespro.ru", "phone": "+70118935007"}
0005434586731	E0AF47	8332 165505	ALEKSANDR NIKITIN	{"phone": "+70860750615"}
0005434586732	6A494B	1826 834869	VALERIY GORBUNOV	{"email": "gorbunov.v.1972@postgrespro.ru", "phone": "+70210614122"}
0005434586733	E0CC2C	3836 359804	RAISA YAKOVLEVA	{"phone": "+70287990461"}
0005434586734	83EBAB	2795 270563	OLEG POPOV	{"phone": "+70980501948"}
0005434586735	83EBAB	4325 879561	ANNA NAZAROVA	{"email": "a.nazarova_1989@postgrespro.ru", "phone": "+70618046729"}
0005434586736	679710	7601 411023	LEONID MELNIKOV	{"email": "leonid-melnikov.11031971@postgrespro.ru", "phone": "+70616399063"}
0005434586737	679710	8988 178900	NIKOLAY MARTYNOV	{"phone": "+70610826293"}
0005434586738	5A751F	1627 967893	VERONIKA OVCHINNIKOVA	{"email": "ovchinnikova-v-1975@postgrespro.ru", "phone": "+70490630413"}
0005434586739	5A751F	5204 448623	NATALIYA POLYAKOVA	{"phone": "+70642774173"}
0005434586740	1B7042	6034 955559	NADEZHDA SOLOVEVA	{"phone": "+70563287167"}
0005434586741	1B7042	1485 242471	OLGA GORBUNOVA	{"email": "gorbunovao-1957@postgrespro.ru", "phone": "+70156408560"}
0005434586742	20BE31	0490 103485	ELENA IVANOVA	{"email": "e-ivanova-1976@postgrespro.ru", "phone": "+70094194636"}
0005434586743	20BE31	6374 239948	SVETLANA AKIMOVA	{"phone": "+70070724562"}
0005434586744	86DE13	1099 416329	IRINA MAKSIMOVA	{"phone": "+70229634125"}
0005434586745	868A78	2817 870770	OLGA MALYSHEVA	{"email": "malyshevaolga.1968@postgrespro.ru", "phone": "+70823216224"}
0005434586746	81D594	2070 005552	VERONIKA BELOVA	{"phone": "+70564511928"}
0005434586747	94B57B	6740 176202	NURIYA PAVLOVA	{"email": "pavlova.nuriya.1970@postgrespro.ru", "phone": "+70104455164"}
0005434586748	94B57B	7449 839584	OLESYA STEPANOVA	{"phone": "+70303460800"}
0005434586749	FE0A8A	5640 256316	ARTEM PETROV	{"email": "petrov.artem.1975@postgrespro.ru", "phone": "+70086873264"}
0005434586750	FE0A8A	7275 263752	EKATERINA BELOVA	{"phone": "+70213944835"}
0005434586751	A8E46A	4099 804899	MARIYA FROLOVA	{"phone": "+70246587513"}
0005434586752	5D918F	5567 560148	YURIY PETROV	{"email": "yuriy.petrov-21051964@postgrespro.ru", "phone": "+70530509468"}
0005434586753	877D6A	9650 233485	GENNADIY CHERNOV	{"phone": "+70888223440"}
0005434586754	AE74A4	6438 604111	YANA MEDVEDEVA	{"phone": "+70974656744"}
0005434586755	AE74A4	3951 115367	STANISLAV MOROZOV	{"email": "stanislavmorozov-08121982@postgrespro.ru", "phone": "+70157183294"}
0005434586756	01348C	7267 106470	ANATOLIY GAVRILOV	{"email": "gavrilov.a14051967@postgrespro.ru", "phone": "+70040792792"}
0005434586757	01348C	8325 718169	ANNA KUZMINA	{"email": "kuzmina.anna_041969@postgrespro.ru", "phone": "+70999233026"}
0005434586758	01348C	0605 734719	ELENA KUZNECOVA	{"phone": "+70556263137"}
0005434586759	9F5D74	5139 745865	OLGA KUZNECOVA	{"email": "kuznecovaolga.1967@postgrespro.ru", "phone": "+70466538901"}
0005434586760	9F5D74	3981 685421	ALEKSEY SEMENOV	{"phone": "+70622443002"}
0005434586761	47E5C5	5261 490367	VYACHESLAV KOZLOV	{"email": "vkozlov-1973@postgrespro.ru", "phone": "+70308235395"}
0005434586762	47E5C5	6793 988470	VERA RYABOVA	{"email": "ryabova-vera071967@postgrespro.ru", "phone": "+70740620812"}
0005434586763	C19C3E	6451 511595	ANDREY MEDVEDEV	{"email": "medvedev-andrey1967@postgrespro.ru", "phone": "+70451095222"}
0005434586764	C19C3E	2041 367800	ANVAR SHEVCHENKO	{"email": "shevchenkoanvar.18101979@postgrespro.ru", "phone": "+70687586674"}
0005434586765	F460F5	6509 571098	NIKOLAY ALEKSEEV	{"email": "nikolay.alekseev_1972@postgrespro.ru", "phone": "+70921287126"}
0005434586766	F2904B	8657 443572	ALENA ZOTOVA	{"phone": "+70238428300"}
0005434586767	3D66FB	2207 638988	IGOR KONOVALOV	{"phone": "+70863659144"}
0005434586768	BEC031	5777 193685	NATALYA MAKSIMOVA	{"phone": "+70940769951"}
0005434586769	B0034B	9741 805352	VLADIMIR ZAYCEV	{"email": "zaycev_vladimir071970@postgrespro.ru", "phone": "+70596432172"}
0005434586770	DDC8CC	7408 956366	TATYANA AFANASEVA	{"email": "afanaseva-tatyana.041973@postgrespro.ru", "phone": "+70821536516"}
0005434586771	DDC8CC	9759 535400	SERGEY PETROV	{"phone": "+70781077419"}
0005434586772	4801FA	2276 781801	SERGEY OSIPOV	{"phone": "+70622140045"}
0005434586773	4801FA	5755 801133	ALEKSANDR FOMIN	{"email": "aleksandr_fomin-011993@postgrespro.ru", "phone": "+70413291169"}
0005434586774	7EA1F1	5721 663969	EVGENIYA ROMANOVA	{"email": "romanova.e1970@postgrespro.ru", "phone": "+70258291879"}
0005434586775	7EA1F1	1058 926024	VALENTINA VOLKOVA	{"phone": "+70351752430"}
0005434586776	AC62F6	1757 433206	VENIAMIN PAVLOV	{"email": "veniamin-pavlov.081974@postgrespro.ru", "phone": "+70325294692"}
0005434586777	ED0B90	8395 485133	OKSANA KUZNECOVA	{"email": "oksana_kuznecova_06041972@postgrespro.ru", "phone": "+70322247251"}
0005434586778	F30D9C	6847 946963	EVGENIYA DMITRIEVA	{"phone": "+70701965342"}
0005434586779	CF02ED	5887 811070	YURIY NIKOLAEV	{"email": "nikolaevy_1978@postgrespro.ru", "phone": "+70651015948"}
0005434586780	D54E9A	7271 074414	ANNA ROMANOVA	{"email": "romanova_a031968@postgrespro.ru", "phone": "+70721603147"}
0005434586781	B13386	1092 332940	NIKOLAY NAUMOV	{"phone": "+70743039786"}
0005434586782	B13386	2247 439708	ELENA KUZMINA	{"phone": "+70749767566"}
0005434586783	D38AA8	2353 276718	VLADIMIR KAZAKOV	{"phone": "+70552867378"}
0005434586784	D38AA8	3447 348551	VLADIMIR NAUMOV	{"phone": "+70238747480"}
0005434586785	FE87DC	4279 999905	GALINA IVANOVA	{"email": "g-ivanova-07121961@postgrespro.ru", "phone": "+70298646075"}
0005434586786	ABB1DB	7121 887901	EVGENIY KUZNECOV	{"phone": "+70874793436"}
0005434586787	ABB1DB	5054 792889	YULIYA ALEKSANDROVA	{"phone": "+70473248133"}
0005434586788	ABB1DB	8670 066237	ALEKSANDR BARANOV	{"phone": "+70075165513"}
0005434586789	59DF16	3694 317867	SERGEY PETROV	{"email": "petrov-sergey.09091972@postgrespro.ru", "phone": "+70606832059"}
0005434586790	59DF16	4990 418253	ANDREY OSIPOV	{"email": "osipov_andrey041973@postgrespro.ru", "phone": "+70580637646"}
0005434586791	6BFC6E	1443 163213	DMITRIY BELOV	{"phone": "+70792368692"}
0005434586792	AAE516	0060 383256	ANNA GUSEVA	{"email": "guseva-a.1964@postgrespro.ru", "phone": "+70755837402"}
0005434586793	B3A349	6125 354824	ALEKSEY IVANOV	{"phone": "+70456772128"}
0005434586794	B3A349	5573 559490	GENNADIY KULIKOV	{"phone": "+70099335155"}
0005434586795	E5DC8E	6739 407735	TATYANA BORISOVA	{"email": "t-borisova_19101970@postgrespro.ru", "phone": "+70193684763"}
0005434586796	E5DC8E	9066 846643	MAKSIM SEMENOV	{"email": "semenov_m.121975@postgrespro.ru", "phone": "+70304316581"}
0005434586797	6C3A7F	0432 200247	EDUARD SMIRNOV	{"phone": "+70522626758"}
0005434586798	336161	6199 590003	OLESYA LEBEDEVA	{"email": "lebedeva_olesya-041963@postgrespro.ru", "phone": "+70598588976"}
0005434586799	513876	0011 015363	SERGEY GUSEV	{"email": "s.gusev.14081973@postgrespro.ru", "phone": "+70199174302"}
0005434586800	513876	3911 235312	ANTONINA SEMENOVA	{"email": "semenova.antonina.081965@postgrespro.ru", "phone": "+70018432975"}
0005434586801	C531F3	9113 970786	TAMARA PETROVA	{"phone": "+70982891328"}
0005434586802	C8F99D	3504 889975	ILYA SHEVCHENKO	{"email": "shevchenko.i-1970@postgrespro.ru", "phone": "+70732015379"}
0005434586803	C8F99D	5509 273063	TATYANA ZAKHAROVA	{"phone": "+70200044829"}
0005434586804	F0ACDE	4480 231052	MAKSIM AFANASEV	{"email": "mafanasev-18061973@postgrespro.ru", "phone": "+70548113960"}
0005434586805	2311B5	8609 413867	ANATOLIY KRASNOV	{"email": "anatoliy-krasnov021979@postgrespro.ru", "phone": "+70143902942"}
0005434586806	CEA9C7	6148 225577	SERGEY VASILEV	{"email": "vasilev.sergey-1987@postgrespro.ru", "phone": "+70329763507"}
0005434586807	CEA9C7	6721 339176	DARYA TROFIMOVA	{"phone": "+70075583770"}
0005434586866	F0BBD4	2372 639372	LYUDMILA VASILEVA	{"phone": "+70189562142"}
0005434586808	24A5E7	1958 878111	ALEKSANDR SAVELEV	{"email": "aleksandr.savelev.041965@postgrespro.ru", "phone": "+70188405607"}
0005434586809	24A5E7	0319 228623	ILDAR KOZLOV	{"email": "kozlov-i.05041974@postgrespro.ru", "phone": "+70224381781"}
0005434586810	58B8CF	5815 932132	RAISA BORISOVA	{"email": "raisaborisova-1969@postgrespro.ru", "phone": "+70213905333"}
0005434586811	ED01CD	7412 146612	ELENA GERASIMOVA	{"email": "elena_gerasimova_1967@postgrespro.ru", "phone": "+70111490694"}
0005434586812	ED01CD	6940 354107	VALERIYA GERASIMOVA	{"phone": "+70773267894"}
0005434586813	92C421	6080 162337	ARTEM KAZAKOV	{"phone": "+70825333441"}
0005434586814	92C421	1605 263420	NIKOLAY YAKOVLEV	{"phone": "+70989065122"}
0005434586815	3AC6A6	2547 046685	MIKHAIL BONDARENKO	{"email": "mikhail.bondarenko_111988@postgrespro.ru", "phone": "+70907084057"}
0005434586816	3AC6A6	0806 475574	SERGEY ORLOV	{"phone": "+70562884033"}
0005434586817	6EB95B	0355 497202	LYUBOV ALEKSEEVA	{"phone": "+70944742946"}
0005434586818	6EB95B	9370 855636	LARISA PETROVA	{"email": "petrova-l-1961@postgrespro.ru", "phone": "+70846540047"}
0005434586819	07C203	2976 915843	SERGEY KUZNECOV	{"email": "sergey.kuznecov.111975@postgrespro.ru", "phone": "+70300054453"}
0005434586820	07C203	3063 122768	NINA KOZLOVA	{"email": "ninakozlova1975@postgrespro.ru", "phone": "+70785588765"}
0005434586821	7A89C6	7348 352042	GALINA DANILOVA	{"email": "g_danilova.15111971@postgrespro.ru", "phone": "+70049474230"}
0005434586822	97FD50	5167 358004	VALENTINA ALEKSEEVA	{"email": "valentina.alekseeva.02021969@postgrespro.ru", "phone": "+70416792129"}
0005434586823	C344D3	1360 231900	OLGA FEDOROVA	{"phone": "+70519884372"}
0005434586824	C344D3	8027 932637	ALEKSANDR ZHURAVLEV	{"phone": "+70413637166"}
0005434586825	630DCF	2737 967073	LYUDMILA EGOROVA	{"phone": "+70085929385"}
0005434586826	14B379	8827 868401	LYUBOV MAKAROVA	{"email": "makarova-lyubov_021966@postgrespro.ru", "phone": "+70738719224"}
0005434586827	7BF8C7	8478 874645	IVAN ALEKSEEV	{"email": "ialekseev_06121963@postgrespro.ru", "phone": "+70547084552"}
0005434586828	2E1CE2	5148 771958	VLADIMIR STEPANOV	{"phone": "+70885188515"}
0005434586829	A7AA00	9671 197671	EGOR KAZAKOV	{"email": "egor_kazakov.18011963@postgrespro.ru", "phone": "+70367465346"}
0005434586830	A9C16E	2710 512557	ANVAR IVANOV	{"phone": "+70516991876"}
0005434586831	A9C16E	3338 297549	NADEZHDA BOGDANOVA	{"email": "nbogdanova.11101965@postgrespro.ru", "phone": "+70390476089"}
0005434586832	3FF738	5610 820382	ALEKSANDR ZAYCEV	{"phone": "+70231259519"}
0005434586833	70F2F7	2524 329654	SERGEY VASILEV	{"email": "s.vasilev-1964@postgrespro.ru", "phone": "+70327284258"}
0005434586834	85B75C	2741 163763	PAVEL RODIONOV	{"phone": "+70553783571"}
0005434586835	038AFF	5564 457613	LYUBOV DANILOVA	{"email": "l.danilova_051982@postgrespro.ru", "phone": "+70619057153"}
0005434586836	E6EA56	2949 539175	SERGEY VASILEV	{"phone": "+70851841921"}
0005434586837	0307B7	6523 680560	NIKOLAY KONOVALOV	{"phone": "+70204767013"}
0005434586838	0307B7	4936 651470	YURIY ZAKHAROV	{"email": "zakharov-yuriy_1976@postgrespro.ru", "phone": "+70539134576"}
0005434586839	0307B7	7961 222339	ALEKSANDR BONDARENKO	{"phone": "+70968377776"}
0005434586840	2B0FF7	3216 006279	EMIL MAKAROV	{"phone": "+70177760572"}
0005434586841	2B0FF7	5038 789974	VLADIMIR ALEKSANDROV	{"email": "vladimir_aleksandrov-011975@postgrespro.ru", "phone": "+70450845923"}
0005434586842	AEE97C	5253 477358	YURIY ANTONOV	{"email": "antonov_y-14061963@postgrespro.ru", "phone": "+70731852071"}
0005434586843	AEE97C	7778 738692	ALEKSANDRA ROMANOVA	{"email": "a-romanova1972@postgrespro.ru", "phone": "+70237146044"}
0005434586844	9DFAE4	0355 385824	IRINA PAVLOVA	{"email": "pavlova-irina.021975@postgrespro.ru", "phone": "+70863966361"}
0005434586845	18844E	4949 881604	MARINA VOLKOVA	{"phone": "+70105699319"}
0005434586846	C8518B	6428 457533	MARIYA IVANOVA	{"email": "ivanova-mariya05061971@postgrespro.ru", "phone": "+70600246151"}
0005434586847	8C209A	0246 521448	YURIY KUZNECOV	{"email": "yuriy.kuznecov28041973@postgrespro.ru", "phone": "+70952531362"}
0005434586848	395D49	4503 588159	ALEKSANDR IVANOV	{"email": "ivanova071972@postgrespro.ru", "phone": "+70705403563"}
0005434586849	395D49	3579 353855	LYUDMILA ZOTOVA	{"email": "zotoval091968@postgrespro.ru", "phone": "+70324983514"}
0005434586850	43DD5C	9204 790602	VLADIMIR FILIPPOV	{"phone": "+70212535794"}
0005434586851	09658E	7612 610918	NIKOLAY KISELEV	{"email": "nikolay.kiselev.22021968@postgrespro.ru", "phone": "+70500858563"}
0005434586852	09658E	7092 372032	MIKHAIL ALEKSANDROV	{"email": "m_aleksandrov_031977@postgrespro.ru", "phone": "+70702640249"}
0005434586853	39C82F	5088 919953	OLGA PETROVA	{"email": "o_petrova-1978@postgrespro.ru", "phone": "+70506329408"}
0005434586854	0F10D2	5551 502883	YULIYA NESTEROVA	{"email": "nesterova-y.1972@postgrespro.ru", "phone": "+70430904578"}
0005434586855	0F10D2	6178 368193	NIKOLAY SHEVCHENKO	{"phone": "+70675657924"}
0005434586856	669954	6934 510416	IRINA ALEKSANDROVA	{"email": "irina_aleksandrova.101968@postgrespro.ru", "phone": "+70418351128"}
0005434586857	8833E1	7261 585699	NIKITA ORLOV	{"phone": "+70822483796"}
0005434586858	8833E1	3067 977096	VITALIY BORISOV	{"email": "v.borisov.13081974@postgrespro.ru", "phone": "+70712639113"}
0005434586859	A421C2	5570 477717	MARINA IVANOVA	{"email": "marina.ivanova-1974@postgrespro.ru", "phone": "+70550694028"}
0005434586860	A421C2	0551 689118	KRISTINA NAZAROVA	{"phone": "+70823323661"}
0005434586861	1ACA1F	0787 237184	SERGEY ZAYCEV	{"phone": "+70168586147"}
0005434586862	5CB6E6	6671 867569	ANNA SOROKINA	{"email": "asorokina_061973@postgrespro.ru", "phone": "+70697119113"}
0005434586863	401517	0988 293672	ALEKSANDR KUZNECOV	{"email": "akuznecov-15051976@postgrespro.ru", "phone": "+70434795904"}
0005434586864	A05523	0055 808650	MADINA PETROVA	{"phone": "+70267569914"}
0005434586865	A05523	2467 866568	FAINA BELOVA	{"email": "fbelova20051973@postgrespro.ru", "phone": "+70753715246"}
0005434586867	353E07	1137 489920	MIKHAIL ALEKSANDROV	{"email": "mikhailaleksandrov1955@postgrespro.ru", "phone": "+70956356871"}
0005434586868	353E07	6660 975505	DMITRIY RODIONOV	{"phone": "+70109738255"}
0005434586869	353E07	4906 406418	ANDREY TIKHONOV	{"email": "atikhonov101981@postgrespro.ru", "phone": "+70693218323"}
0005434586870	2E1137	8814 280934	ARSENIY ZAYCEV	{"phone": "+70517982851"}
0005434586871	598408	5758 335764	IRINA KOROLEVA	{"email": "koroleva-i_05031958@postgrespro.ru", "phone": "+70532681432"}
0005434586872	CDA772	7493 974026	OLGA ZHURAVLEVA	{"phone": "+70173688869"}
0005434586873	CDA772	3567 634981	SERGEY KOZLOV	{"email": "sergey_kozlov1975@postgrespro.ru", "phone": "+70291441213"}
0005434586874	3FAE06	7943 552536	LYUDMILA NOVIKOVA	{"email": "novikova.lyudmila031973@postgrespro.ru", "phone": "+70187876047"}
0005434586875	3FAE06	8439 058908	VLADIMIR KISELEV	{"phone": "+70051228491"}
0005434586876	7CEFA1	8693 131350	GALINA VOROBEVA	{"phone": "+70785272505"}
0005434586877	7CEFA1	6704 973501	PAVEL MAKAROV	{"email": "makarov_p-1965@postgrespro.ru", "phone": "+70400507856"}
0005434586878	E221E4	9726 353393	ANTON VOLKOV	{"phone": "+70256748288"}
0005434586879	91D499	5825 773475	VITALIY ABRAMOV	{"phone": "+70907151672"}
0005434586880	220FB8	6840 838589	NADEZHDA ZAKHAROVA	{"phone": "+70671016694"}
0005434586881	C0DE7D	6932 535357	PETR YAKOVLEV	{"phone": "+70633835774"}
0005434586882	C0DE7D	6417 392679	VALENTINA MIRONOVA	{"email": "v-mironova.1976@postgrespro.ru", "phone": "+70148464277"}
0005434586883	227E4F	4996 587002	GALIYA MOISEEVA	{"email": "moiseevagaliya.13051963@postgrespro.ru", "phone": "+70778328577"}
0005434586884	227E4F	1051 136917	EVGENIY VOLKOV	{"phone": "+70461927124"}
0005434586885	1C1A9F	3250 318831	NATALYA DENISOVA	{"phone": "+70480209266"}
0005434586886	1C1A9F	1525 958495	KLAVDIYA NIKITINA	{"email": "nikitina.klavdiya_081972@postgrespro.ru", "phone": "+70068837137"}
0005434586887	1C1A9F	6753 877382	GALINA GUSEVA	{"email": "gusevag_011975@postgrespro.ru", "phone": "+70421725638"}
0005434586888	691CDD	5442 571927	NINA EGOROVA	{"email": "ninaegorova.29051982@postgrespro.ru", "phone": "+70994189852"}
0005434586889	691CDD	4018 353157	DANIIL DMITRIEV	{"email": "dmitrievd081973@postgrespro.ru", "phone": "+70804657311"}
0005434586890	99C1BE	1545 114224	VYACHESLAV MATVEEV	{"email": "matveev.v.1978@postgrespro.ru", "phone": "+70492092406"}
0005434586891	288F92	4354 951066	ANNA SEMENOVA	{"email": "a_semenova_22121981@postgrespro.ru", "phone": "+70024099701"}
0005434586892	288F92	1789 855394	NATALYA TITOVA	{"email": "titova_n-101979@postgrespro.ru", "phone": "+70612551659"}
0005434586893	3EEA9C	6623 253370	VIKTORIYA KUZMINA	{"phone": "+70556471455"}
0005434586894	8A6C1C	6773 480996	IRINA MAKAROVA	{"phone": "+70461487494"}
0005434586895	CB49CD	0419 882488	ROMAN NAZAROV	{"email": "nazarov.r.1960@postgrespro.ru", "phone": "+70275973049"}
0005434586896	4CF401	5626 099096	ELENA MAKAROVA	{"email": "e_makarova_061981@postgrespro.ru", "phone": "+70610330696"}
0005434586897	607541	7712 750079	ILYA MOISEEV	{"phone": "+70721995962"}
0005434586898	607541	1410 562348	LIDIYA NAUMOVA	{"phone": "+70405223407"}
0005434586899	79C78B	0385 650902	MARIYA MEDVEDEVA	{"phone": "+70230841275"}
0005434586900	8F16A4	6389 453050	MIKHAIL DENISOV	{"phone": "+70681778205"}
0005434586901	FA3469	3120 902802	ANATOLIY NIKOLAEV	{"email": "nikolaev_a.1990@postgrespro.ru", "phone": "+70495409701"}
0005434586902	FA3469	8664 915223	ELENA KAZAKOVA	{"email": "elena.kazakova091976@postgrespro.ru", "phone": "+70475137913"}
0005434586903	8EB72B	6842 731145	ALEKSEY KOZLOV	{"email": "kozlov.a.1971@postgrespro.ru", "phone": "+70160131908"}
0005434586904	C075D5	2259 713271	EKATERINA MATVEEVA	{"phone": "+70513707279"}
0005434586905	B9D941	9587 233020	YULIYA NIKITINA	{"phone": "+70613426654"}
0005434586906	E2B5E4	0566 143314	LYUDMILA ILINA	{"phone": "+70018403273"}
0005434586907	505C0A	2082 740112	VLADIMIR YAKOVLEV	{"email": "yakovlev-v-1982@postgrespro.ru", "phone": "+70372185425"}
0005434586908	481D55	6055 988276	OLGA LOGINOVA	{"phone": "+70539737539"}
0005434586909	37135E	1386 944722	YULIYA KUZNECOVA	{"email": "y.kuznecova-20011985@postgrespro.ru", "phone": "+70278072559"}
0005434586910	37135E	3021 961321	IRINA GAVRILOVA	{"email": "i-gavrilova24101974@postgrespro.ru", "phone": "+70840999007"}
0005434586911	D6EDCE	5782 606546	ARSENIY SEMENOV	{"phone": "+70463208662"}
0005434586912	71DE05	3225 128227	RODION KUZNECOV	{"email": "rkuznecov.1966@postgrespro.ru", "phone": "+70654534301"}
0005434586913	71DE05	6331 454763	ALBINA ZHURAVLEVA	{"email": "a_zhuravleva_121969@postgrespro.ru", "phone": "+70929780067"}
0005434586914	71DE05	6432 973290	ILYA FOMIN	{"email": "i.fomin081972@postgrespro.ru", "phone": "+70658457657"}
0005434586915	9A955D	7041 168406	ANGELINA RODIONOVA	{"phone": "+70147087512"}
0005434586916	17E1A9	3081 456436	NATALIYA POTAPOVA	{"phone": "+70268586449"}
0005434586917	17E1A9	7991 647832	KLAVDIYA ZAKHAROVA	{"phone": "+70090789344"}
0005434586918	0D8584	3900 384087	EVGENIY AFANASEV	{"phone": "+70272481409"}
0005434586919	0D8584	4743 302080	ALEKSANDR KULIKOV	{"phone": "+70203991823"}
0005434586920	04E50D	8495 111361	NIKOLAY KUZNECOV	{"phone": "+70626495524"}
0005434586921	CD7F11	4318 808453	VLADIMIR ZAYCEV	{"email": "vzaycev041985@postgrespro.ru", "phone": "+70326112314"}
0005434586922	2FD46F	5224 156788	NATALYA ZAKHAROVA	{"phone": "+70207898766"}
0005434586923	C9E55B	0715 144597	RUSLAN KUZNECOV	{"phone": "+70196041612"}
0005434586924	821719	8366 126088	LEV GUSEV	{"phone": "+70594810878"}
0005434586925	903CF8	6604 848526	IRINA VASILEVA	{"email": "i.vasileva02091973@postgrespro.ru", "phone": "+70328608171"}
0005434586926	4462F0	6267 146601	IVAN TIMOFEEV	{"phone": "+70667006533"}
0005434586927	0B18E1	2033 644128	NATALYA VASILEVA	{"email": "natalya_vasileva.101970@postgrespro.ru", "phone": "+70786807665"}
0005434586928	EB57E2	0308 289975	SERGEY KUZNECOV	{"phone": "+70667616557"}
0005434586929	318912	3321 933981	EKATERINA SIDOROVA	{"phone": "+70253717168"}
0005434586930	667022	7079 908247	DMITRIY KUZMIN	{"email": "dmitriykuzmin071975@postgrespro.ru", "phone": "+70693236975"}
0005434586931	50D3EB	7655 085543	SERGEY TIKHONOV	{"phone": "+70649702780"}
0005434586932	721466	5479 038473	NIKOLAY ABRAMOV	{"email": "n_abramov_061966@postgrespro.ru", "phone": "+70416229158"}
0005434586933	721466	2252 344958	VLADISLAV SEMENOV	{"email": "semenov.vladislav-19101975@postgrespro.ru", "phone": "+70390814835"}
0005434586934	FD25A9	9221 232458	ANTONINA GERASIMOVA	{"email": "gerasimova-a_30051975@postgrespro.ru", "phone": "+70686327257"}
0005434586935	3E3850	2840 433724	SERGEY MAKSIMOV	{"email": "s.maksimov_101979@postgrespro.ru", "phone": "+70514474744"}
0005434586936	7043DE	1575 752519	NIKOLAY KUZMIN	{"email": "nikolay-kuzmin-06051984@postgrespro.ru", "phone": "+70348427968"}
0005434586937	5F6E7C	4392 898774	TATYANA IVANOVA	{"email": "tivanova-111965@postgrespro.ru", "phone": "+70614849037"}
0005434586938	B8FC4B	8163 473950	SVETLANA ZAKHAROVA	{"email": "zakharova.svetlana071978@postgrespro.ru", "phone": "+70480371874"}
0005434586939	257EC2	1826 262550	SERGEY ANDREEV	{"phone": "+70203093136"}
0005434586940	257EC2	1178 057739	VIKTOR SMIRNOV	{"email": "v.smirnov-051972@postgrespro.ru", "phone": "+70698729685"}
0005434586941	257EC2	2577 866454	SERGEY MAKSIMOV	{"phone": "+70066383193"}
0005434586942	257EC2	4969 046724	VLADISLAV FILIPPOV	{"email": "vladislavfilippov.041975@postgrespro.ru", "phone": "+70251493741"}
0005434586943	9C2BCB	1179 277867	VALENTINA NIKIFOROVA	{"phone": "+70350451129"}
0005434586944	E88844	2780 763651	NIKOLAY KISELEV	{"phone": "+70986678745"}
0005434586945	E88844	8016 203790	DANIIL SCHERBAKOV	{"phone": "+70662825534"}
0005434586946	9FA93A	1476 989638	ALEKSANDR RODIONOV	{"phone": "+70872863296"}
0005434586947	9FA93A	7526 394684	EVGENIY BARANOV	{"phone": "+70115245557"}
0005434586948	E90C75	3923 168081	MARIYA ZOTOVA	{"email": "zotova_m13061971@postgrespro.ru", "phone": "+70362471167"}
0005434586949	475987	0735 459974	ALBERT BORISOV	{"email": "a.borisov.12011974@postgrespro.ru", "phone": "+70550641521"}
0005434586950	FD3C31	0218 579241	NINA SCHERBAKOVA	{"phone": "+70784465778"}
0005434586951	5B2DE9	5749 664829	ALEKSEY SIDOROV	{"email": "sidorov_aleksey-1975@postgrespro.ru", "phone": "+70592654018"}
0005434586952	7AA6FB	5317 670688	DARYA MAKSIMOVA	{"email": "maksimova.d_1975@postgrespro.ru", "phone": "+70333333923"}
0005434586953	7AA6FB	5107 596728	MIKHAIL GAVRILOV	{"email": "gavrilov.m.111976@postgrespro.ru", "phone": "+70020249984"}
0005434586954	606F47	3934 783500	YURIY SCHERBAKOV	{"email": "scherbakov-yuriy14061971@postgrespro.ru", "phone": "+70258191518"}
0005434586955	4FF3F2	4277 667965	VIKTOR OSIPOV	{"email": "viktorosipov-05061985@postgrespro.ru", "phone": "+70155227465"}
0005434586956	4FF3F2	9114 390788	EVGENIYA BORISOVA	{"email": "borisova_evgeniya.041981@postgrespro.ru", "phone": "+70826742585"}
0005434586957	6F22A2	2897 410890	DMITRIY ISAEV	{"email": "d.isaev-041973@postgrespro.ru", "phone": "+70507578451"}
0005434586958	413049	0221 039823	NINA SAVELEVA	{"email": "ninasaveleva.101980@postgrespro.ru", "phone": "+70122735822"}
0005434586959	413049	7732 960621	TATYANA TITOVA	{"email": "tatyana_titova24081978@postgrespro.ru", "phone": "+70674613664"}
0005434586960	413049	2001 212737	DENIS KUZNECOV	{"email": "denis.kuznecov_08041970@postgrespro.ru", "phone": "+70193819888"}
0005434586961	7EC75E	8305 286499	TAISIYA KISELEVA	{"email": "taisiyakiseleva-101978@postgrespro.ru", "phone": "+70517582771"}
0005434586962	883777	8964 370067	LILIYA YAKOVLEVA	{"phone": "+70163122197"}
0005434586963	883777	9478 003218	ALENA BELOVA	{"email": "belovaalena-121977@postgrespro.ru", "phone": "+70507412530"}
0005434586964	95A347	5394 528873	ALEKSANDR GUSEV	{"email": "a.gusev.111970@postgrespro.ru", "phone": "+70281846368"}
0005434586965	0D9C42	1623 784666	ANNA GORBUNOVA	{"email": "gorbunovaanna.1965@postgrespro.ru", "phone": "+70830332426"}
0005434586966	0D9C42	6860 280267	VALERIY KOROLEV	{"email": "korolev.valeriy.06011974@postgrespro.ru", "phone": "+70979176102"}
0005434586967	FF0BCD	3785 639861	DMITRIY MIKHAYLOV	{"phone": "+70607736792"}
0005434586968	FC9F81	4203 015601	VALENTINA DENISOVA	{"email": "valentina.denisova.1962@postgrespro.ru", "phone": "+70228291194"}
0005434586969	FC9F81	5933 831542	VLADIMIR PAVLOV	{"phone": "+70453844236"}
0005434586970	FC9F81	8704 186214	SVETLANA LOGINOVA	{"email": "loginovasvetlana_061965@postgrespro.ru", "phone": "+70769268172"}
0005434586971	C3CD90	9384 921274	MAKSIM TIKHONOV	{"phone": "+70087467830"}
0005434586972	BD5943	1448 940233	ALEKSANDR GUSEV	{"email": "gusev_aleksandr.14111974@postgrespro.ru", "phone": "+70759238498"}
0005434586973	BD5943	5669 821245	YULIYA LOGINOVA	{"email": "yloginova1970@postgrespro.ru", "phone": "+70189519176"}
0005434586974	031847	0678 484534	OLGA LUKYANOVA	{"email": "lukyanova.olga13121971@postgrespro.ru", "phone": "+70335743139"}
0005434586975	031847	2733 430377	NINA KOROLEVA	{"phone": "+70363770440"}
0005434586976	49253D	6571 586529	ELIZAVETA FADEEVA	{"phone": "+70515106410"}
0005434586977	002775	6965 088784	OLGA FOMINA	{"phone": "+70986912420"}
0005434586978	25ED6A	9435 658909	MARIYA YAKOVLEVA	{"email": "yakovleva_mariya.25121959@postgrespro.ru", "phone": "+70438733944"}
0005434586979	B7A5C9	8981 883883	EKATERINA PETROVA	{"email": "petrova_ekaterina-18121971@postgrespro.ru", "phone": "+70198477042"}
0005434586980	752076	7934 651212	DENIS MIKHAYLOV	{"phone": "+70612343623"}
0005434586981	752076	0013 058620	ELINA FOMINA	{"phone": "+70701458179"}
0005434586982	3287D1	6083 827477	SERGEY VLASOV	{"phone": "+70047989286"}
0005434586983	CB65C0	3635 083463	NATALIYA KUZMINA	{"phone": "+70699544404"}
0005434586984	769F96	8875 864341	ELENA EGOROVA	{"phone": "+70219102739"}
0005434586985	2A3CF5	2386 364744	VASILIY ANTONOV	{"email": "antonov.v1969@postgrespro.ru", "phone": "+70438822771"}
0005434586986	2A3CF5	8238 155398	EVGENIYA ROMANOVA	{"phone": "+70097554021"}
0005434586987	8A1DAC	5961 034838	EVGENIY GRIGOREV	{"phone": "+70396791448"}
0005434586988	0F3072	6070 872285	SERGEY KUZMIN	{"email": "kuzmin.s_13031976@postgrespro.ru", "phone": "+70779661317"}
0005434586989	A049AF	9317 768541	ANASTASIYA GUSEVA	{"phone": "+70539739264"}
0005434586990	04A410	6179 712016	LYUDMILA KISELEVA	{"phone": "+70873993660"}
0005434586991	3906A6	2833 989730	ELENA KOROLEVA	{"email": "elena.koroleva.13011970@postgrespro.ru", "phone": "+70011382818"}
0005434586992	2A7D1B	1430 878169	OLESYA VOLKOVA	{"email": "olesya-volkova07061959@postgrespro.ru", "phone": "+70477257058"}
0005434586993	7159DF	5024 593123	ANTON MIRONOV	{"email": "mironov-anton.27091963@postgrespro.ru", "phone": "+70301709054"}
0005434586994	7E0977	3706 295840	MARGARITA MIKHAYLOVA	{"email": "margaritamikhaylova_1968@postgrespro.ru", "phone": "+70155783340"}
0005434586995	669126	6230 255542	GALINA ILINA	{"email": "ilina.g011973@postgrespro.ru", "phone": "+70759419498"}
0005434586996	6C56DB	3646 703804	ANTON KOZLOV	{"phone": "+70333200406"}
0005434586997	25F3D0	0048 759400	MILANA KUZMINA	{"phone": "+70377127655"}
0005434586998	1AE95D	5790 249952	DIANA ANDREEVA	{"phone": "+70828636486"}
0005434586999	D8E3B4	5299 362291	NADEZHDA MOISEEVA	{"phone": "+70997585682"}
0005434587000	D8E3B4	9293 544898	ANDREY KISELEV	{"phone": "+70549430458"}
0005434587001	E8229F	9454 561958	LYUDMILA EFIMOVA	{"phone": "+70983830352"}
0005434587002	D08079	4830 415457	ALEKSEY VOLKOV	{"email": "aleksey-volkov.1974@postgrespro.ru", "phone": "+70886872854"}
0005434587003	CC347D	2142 940620	VLADIMIR STEPANOV	{"email": "stepanov-vladimir111973@postgrespro.ru", "phone": "+70859941827"}
0005434587004	2E8983	2069 790818	LYUDMILA KOZLOVA	{"phone": "+70740457517"}
0005434587005	98445B	7908 752259	SERGEY KUZNECOV	{"email": "sergey.kuznecov_1977@postgrespro.ru", "phone": "+70755054678"}
0005434587006	F55368	2199 591768	ALEKSEY NAZAROV	{"phone": "+70567062352"}
0005434587007	5B1B21	4229 267519	BORIS POPOV	{"email": "boris_popov_111973@postgrespro.ru", "phone": "+70478588448"}
0005434587008	52002D	7051 411589	ALEKSEY BELOV	{"phone": "+70633847998"}
0005434587009	6DEB3B	2966 458495	GALINA NIKOLAEVA	{"phone": "+70595539156"}
0005434587010	6DEB3B	0189 586276	LYUDMILA TIKHONOVA	{"phone": "+70571798115"}
0005434587011	3F004D	9088 803947	VALERIYA SMIRNOVA	{"email": "valeriya-smirnova_1965@postgrespro.ru", "phone": "+70822191294"}
0005434587012	3F004D	5447 322428	EVGENIY IVANOV	{"phone": "+70916619720"}
0005434587013	86A7CA	1951 625965	VIKTOR ALEKSANDROV	{"email": "aleksandrovviktor011982@postgrespro.ru", "phone": "+70879157593"}
0005434587014	86A7CA	2782 832118	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr1978@postgrespro.ru", "phone": "+70984967517"}
0005434587015	3D68BB	5332 625181	SVETLANA AKIMOVA	{"phone": "+70802321657"}
0005434587016	3D68BB	0517 618624	ALINA DANILOVA	{"phone": "+70574125622"}
0005434587017	EEB600	0320 038324	OLGA ALEKSANDROVA	{"email": "aleksandrova_o_051979@postgrespro.ru", "phone": "+70002714515"}
0005434587018	E65033	6060 140629	MATVEY DAVYDOV	{"email": "davydov-m_24121970@postgrespro.ru", "phone": "+70053354403"}
0005434587019	A3DC8B	8083 952736	RADIK ALEKSEEV	{"email": "alekseev_r_1966@postgrespro.ru", "phone": "+70920378740"}
0005434587020	A10E94	9252 307158	GALINA SOROKINA	{"phone": "+70707011496"}
0005434587021	95A343	6841 558921	PAVEL NAUMOV	{"email": "naumov-pavel24111974@postgrespro.ru", "phone": "+70908320285"}
0005434587022	AD3AD6	1201 961036	ELMIRA SOROKINA	{"email": "esorokina1967@postgrespro.ru", "phone": "+70637769277"}
0005434587023	AD3AD6	1396 796646	ANNA MATVEEVA	{"email": "matveevaa_1969@postgrespro.ru", "phone": "+70114252656"}
0005434587024	E5D9BA	5540 119966	VITALIY MIKHAYLOV	{"phone": "+70693527158"}
0005434587025	1575A8	4000 154306	VALENTINA VLASOVA	{"phone": "+70720358144"}
0005434587081	65DECD	3935 348917	VLADIMIR ROMANOV	{"phone": "+70699346416"}
0005434587026	B888B5	4984 966458	ANTONINA SOKOLOVA	{"email": "sokolova_antonina-1977@postgrespro.ru", "phone": "+70082613110"}
0005434587027	E359A3	0041 154678	EVGENIY PAVLOV	{"phone": "+70952474652"}
0005434587028	AEF11E	2772 415910	ZOYA VOLKOVA	{"phone": "+70443642699"}
0005434587029	AEF11E	6038 436256	NATALYA MAKAROVA	{"email": "makarova_n-1962@postgrespro.ru", "phone": "+70883841699"}
0005434587030	AAE93F	8072 223560	ILYA FROLOV	{"email": "frolov.i061963@postgrespro.ru", "phone": "+70850792951"}
0005434587031	AAE93F	7618 892699	VIKTORIYA KONOVALOVA	{"phone": "+70280989905"}
0005434587032	A23636	7487 549271	ELIZAVETA TIMOFEEVA	{"email": "timofeeva_elizaveta.15051978@postgrespro.ru", "phone": "+70876708302"}
0005434587033	A23636	2322 786844	IRINA FEDOROVA	{"phone": "+70394819484"}
0005434587034	6DA077	4154 547408	VALERIY IVANOV	{"phone": "+70323366984"}
0005434587035	AA3A5B	3821 981865	LIDIYA IVANOVA	{"phone": "+70046995559"}
0005434587036	AA3A5B	4959 950716	VYACHESLAV MOROZOV	{"email": "morozov.v081964@postgrespro.ru", "phone": "+70255273558"}
0005434587037	FC0A38	8469 020588	MAKSIM ZAYCEV	{"email": "maksim-zaycev_091986@postgrespro.ru", "phone": "+70045340473"}
0005434587038	A23B7C	9142 937157	MIKHAIL TARASOV	{"email": "m.tarasov-101972@postgrespro.ru", "phone": "+70446929813"}
0005434587039	B284EF	2952 378062	VERONIKA ANDREEVA	{"email": "andreeva.v-011977@postgrespro.ru", "phone": "+70531252432"}
0005434587040	B284EF	0746 862332	SERGEY VLASOV	{"phone": "+70217502239"}
0005434587041	B284EF	7895 530452	GALINA KUZMINA	{"phone": "+70766365272"}
0005434587042	98BA86	5734 212552	YURIY NIKITIN	{"email": "yuriynikitin1965@postgrespro.ru", "phone": "+70128275993"}
0005434587043	F2CB42	6973 779004	NIKOLAY SCHERBAKOV	{"email": "n-scherbakov.1979@postgrespro.ru", "phone": "+70060272798"}
0005434587044	B38A20	3451 726793	SERGEY SIDOROV	{"email": "sidorov-s03011964@postgrespro.ru", "phone": "+70159721220"}
0005434600643	DC7E1D	3497 074096	ALEKSANDR AFANASEV	{"phone": "+70378773714"}
0005434600603	19B077	5549 302312	VASILIY ZAYCEV	{"phone": "+70733024548"}
0005434587045	CBB925	2894 647788	ALEKSEY KONOVALOV	{"email": "konovalov-aleksey_1972@postgrespro.ru", "phone": "+70957680071"}
0005434587046	CBB925	3864 393132	KONSTANTIN ANTONOV	{"phone": "+70042965620"}
0005434587047	C06180	3469 308663	EKATERINA SMIRNOVA	{"phone": "+70423737699"}
0005434587048	7275D9	8885 503299	ALEKSANDR POPOV	{"phone": "+70389845800"}
0005434587049	BB3050	5421 763986	ALEKSANDR GAVRILOV	{"phone": "+70379502979"}
0005434587050	CDBC0D	2029 454865	MARIYA EGOROVA	{"phone": "+70100086536"}
0005434587051	CDBC0D	9472 371811	RUSLAN IVANOV	{"phone": "+70485039921"}
0005434587052	E0C5A4	4493 939622	MAKSIM KUZMIN	{"phone": "+70598973082"}
0005434587053	E0C5A4	8607 374017	GALINA TIKHONOVA	{"email": "tikhonova_g.23031978@postgrespro.ru", "phone": "+70058166445"}
0005434587054	E0C5A4	7911 082035	YURIY SAVELEV	{"email": "yuriy_savelev.101976@postgrespro.ru", "phone": "+70181725049"}
0005434587055	927ACC	2203 973980	SERGEY MAKSIMOV	{"email": "s.maksimov1969@postgrespro.ru", "phone": "+70029288886"}
0005434587056	062172	6662 403198	ALEKSANDR ROMANOV	{"email": "aromanov011971@postgrespro.ru", "phone": "+70787483402"}
0005434587057	FB47A2	4509 732426	ARTEM CHERNOV	{"email": "chernov.artem_021973@postgrespro.ru", "phone": "+70594584865"}
0005434587058	BB102C	5394 802297	ARTEM EGOROV	{"phone": "+70130205249"}
0005434587059	E1366A	2706 728722	ANNA NIKOLAEVA	{"phone": "+70064691960"}
0005434587060	6FE146	6385 240654	RAISA MASLOVA	{"email": "raisa.maslova29031969@postgrespro.ru", "phone": "+70730572935"}
0005434587061	6FE146	2945 787536	VERA MEDVEDEVA	{"phone": "+70553121826"}
0005434587062	3D6679	3287 958688	RISHAT ZHURAVLEV	{"email": "r-zhuravlev.1976@postgrespro.ru", "phone": "+70901811418"}
0005434587063	267EA3	5258 491390	KIRILL GRIGOREV	{"email": "grigorevk-031974@postgrespro.ru", "phone": "+70212654805"}
0005434587064	B3B7A3	1810 739162	PRASKOVYA IVANOVA	{"phone": "+70419390592"}
0005434587065	0DA32D	4078 350736	SERGEY GUSEV	{"email": "s_gusev-041978@postgrespro.ru", "phone": "+70116144638"}
0005434587066	0DA32D	4295 431286	VALERIY KUZMIN	{"email": "valeriykuzmin.14021985@postgrespro.ru", "phone": "+70535569512"}
0005434587067	B76DF0	5409 564645	MARIYA STEPANOVA	{"email": "m_stepanova-30061977@postgrespro.ru", "phone": "+70242535262"}
0005434587068	9651FB	9556 066284	ALEKSANDR DMITRIEV	{"email": "dmitrieva_17081974@postgrespro.ru", "phone": "+70635331565"}
0005434587069	9651FB	5123 335178	LILIYA ALEKSANDROVA	{"email": "aleksandrova.liliya-011972@postgrespro.ru", "phone": "+70793730830"}
0005434587070	5EF5B4	0440 614733	ANTONINA TARASOVA	{"email": "antonina_tarasova-15101961@postgrespro.ru", "phone": "+70658538192"}
0005434587071	D2701E	6166 034848	NIKOLAY GUSEV	{"email": "gusevnikolay.101969@postgrespro.ru", "phone": "+70091777747"}
0005434587072	59E4D9	9791 900893	LYUDMILA KOROLEVA	{"email": "lkoroleva.011975@postgrespro.ru", "phone": "+70986092272"}
0005434587073	59E4D9	1783 184807	OLGA TROFIMOVA	{"phone": "+70569377671"}
0005434587074	59E4D9	5424 648670	ANTON ZAKHAROV	{"email": "a_zakharov.091972@postgrespro.ru", "phone": "+70522123939"}
0005434587075	59E4D9	3505 058552	VIKTOR MARTYNOV	{"email": "vmartynov-091969@postgrespro.ru", "phone": "+70776381287"}
0005434587076	BAA958	5152 583203	KAROLINA GERASIMOVA	{"phone": "+70045226636"}
0005434587077	BAA958	4626 303562	NIKOLAY DAVYDOV	{"phone": "+70336841154"}
0005434587078	FA08DB	7606 739081	SERGEY VLASOV	{"phone": "+70321796818"}
0005434587079	FA08DB	6518 672067	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_v-26041969@postgrespro.ru", "phone": "+70158166869"}
0005434587080	08C1F8	3341 377986	VALENTINA ALEKSANDROVA	{"email": "aleksandrova-valentina1968@postgrespro.ru", "phone": "+70532064660"}
0005434587082	FB0034	7512 544662	NIKOLAY EGOROV	{"email": "egorov.nikolay.20021958@postgrespro.ru", "phone": "+70219492387"}
0005434587083	DD725D	8619 770228	OLGA KOLESNIKOVA	{"phone": "+70834189183"}
0005434587084	557685	1645 238621	VALERIY KUZNECOV	{"email": "vkuznecov-18041974@postgrespro.ru", "phone": "+70281790534"}
0005434587085	D3A974	9994 911339	STANISLAV OSIPOV	{"phone": "+70851375641"}
0005434587086	757D2C	6199 842622	NIKITA VOROBEV	{"phone": "+70898170020"}
0005434587087	114255	5046 061895	VALENTINA KUZMINA	{"phone": "+70266695714"}
0005434587088	A7CEA6	5661 341962	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova.l_15011976@postgrespro.ru", "phone": "+70312934758"}
0005434587089	E1AC02	3068 396768	EVGENIY MOISEEV	{"phone": "+70722710471"}
0005434587090	412E88	5892 828903	PETR OSIPOV	{"phone": "+70677856075"}
0005434587091	412E88	0656 140989	IGOR SOKOLOV	{"email": "sokolov.igor-091977@postgrespro.ru", "phone": "+70431001466"}
0005434587092	F73E25	7370 814953	VLADIMIR TARASOV	{"email": "v-tarasov-1968@postgrespro.ru", "phone": "+70281159852"}
0005434587093	F88026	9075 018199	ROZALIYA SEMENOVA	{"phone": "+70954460436"}
0005434587094	08C83D	5347 032224	TATYANA DENISOVA	{"email": "denisovat_1964@postgrespro.ru", "phone": "+70514369756"}
0005434587095	08C83D	0124 815760	ALEKSANDR KUDRYASHOV	{"email": "aleksandr-kudryashov_051957@postgrespro.ru", "phone": "+70004163630"}
0005434587096	52377F	8714 942973	ANTONINA ZAKHAROVA	{"phone": "+70757497009"}
0005434587097	0ADBF9	4282 649325	MARINA NIKOLAEVA	{"email": "nikolaeva-marina_1977@postgrespro.ru", "phone": "+70129592343"}
0005434587098	44C858	2683 843734	DIANA KUZNECOVA	{"email": "kuznecova.diana091976@postgrespro.ru", "phone": "+70527519877"}
0005434587099	607448	4911 371227	DMITRIY VASILEV	{"email": "vasilev-d03111970@postgrespro.ru", "phone": "+70460265801"}
0005434587100	2059FF	1846 193294	VALENTINA FOMINA	{"email": "valentina-fomina-1969@postgrespro.ru", "phone": "+70220187039"}
0005434587101	08C909	7462 346764	NATALYA KUZMINA	{"email": "kuzmina.natalya_1974@postgrespro.ru", "phone": "+70852414613"}
0005434587102	DD2671	6765 462320	VLADISLAV BORISOV	{"phone": "+70274028124"}
0005434587103	DD2671	7034 817341	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov1974@postgrespro.ru", "phone": "+70801856328"}
0005434587104	260497	3851 569867	VADIM CHERNOV	{"email": "chernov_vadim_1979@postgrespro.ru", "phone": "+70638317520"}
0005434587105	1C5646	1340 581559	KRISTINA GAVRILOVA	{"email": "k_gavrilova091967@postgrespro.ru", "phone": "+70618449406"}
0005434587106	1C5646	5450 577806	PAVEL IVANOV	{"email": "pivanov121981@postgrespro.ru", "phone": "+70566732372"}
0005434587107	339CAB	2482 960045	ANATOLIY OSIPOV	{"email": "osipov_a011989@postgrespro.ru", "phone": "+70820045242"}
0005434587108	DBBA8A	7252 456259	ALEKSEY SCHERBAKOV	{"email": "scherbakov_a01121978@postgrespro.ru", "phone": "+70912902203"}
0005434587109	DBBA8A	2283 464783	MAKSIM AFANASEV	{"email": "maksimafanasev_23051969@postgrespro.ru", "phone": "+70211881203"}
0005434587110	423226	1827 475962	MIKHAIL PETROV	{"email": "mikhailpetrov_01121975@postgrespro.ru", "phone": "+70753563487"}
0005434587111	423226	7073 459008	OLGA SOLOVEVA	{"phone": "+70310822409"}
0005434587112	C6BC34	3285 150173	GALINA MAKAROVA	{"phone": "+70253217614"}
0005434587113	2DCB54	2914 260614	VIKTOR TARASOV	{"email": "viktor_tarasov_101970@postgrespro.ru", "phone": "+70461590208"}
0005434587114	7EF3F6	3188 809219	MAKSIM KUZNECOV	{"phone": "+70720361211"}
0005434587115	CF5E5A	5499 601855	EVGENIY KISELEV	{"phone": "+70052157782"}
0005434587116	CD29E3	2190 642068	VITALIY ILIN	{"phone": "+70242770938"}
0005434587117	CD29E3	6663 200757	VLADIMIR FROLOV	{"phone": "+70885139115"}
0005434587118	CD29E3	1496 156952	LIDIYA KUZNECOVA	{"phone": "+70603599386"}
0005434587119	825770	5405 904042	ANDREY ROMANOV	{"email": "andrey.romanov_1972@postgrespro.ru", "phone": "+70620446496"}
0005434587120	291835	5512 321935	SERGEY OSIPOV	{"phone": "+70161925501"}
0005434587121	291835	3211 118711	ALENA FROLOVA	{"email": "alenafrolova.081980@postgrespro.ru", "phone": "+70541289890"}
0005434587122	A27FE2	7441 561110	ANATOLIY GUSEV	{"email": "a.gusev.10091974@postgrespro.ru", "phone": "+70009155179"}
0005434587123	2EECD3	3896 510118	TAMARA ALEKSANDROVA	{"email": "taleksandrova-1978@postgrespro.ru", "phone": "+70188206812"}
0005434587124	2EECD3	9882 036696	SVETLANA GORBUNOVA	{"email": "s.gorbunova-1976@postgrespro.ru", "phone": "+70284561733"}
0005434587125	25B649	9220 111377	IRINA TIKHONOVA	{"email": "irina-tikhonova27111967@postgrespro.ru", "phone": "+70170603476"}
0005434587126	458F65	6254 138222	MAKSIM ISAEV	{"email": "isaev_m_071976@postgrespro.ru", "phone": "+70156405885"}
0005434587127	458F65	6673 171743	FEDOR NIKITIN	{"email": "nikitinf-1969@postgrespro.ru", "phone": "+70242503489"}
0005434587128	5D05FC	8348 243465	ALLA LAZAREVA	{"phone": "+70612435535"}
0005434587129	5D05FC	9334 687026	ZINAIDA IVANOVA	{"email": "zinaida.ivanova_1974@postgrespro.ru", "phone": "+70848938514"}
0005434587130	8EF1D6	7812 518358	IRINA KUZNECOVA	{"email": "kuznecova-i071965@postgrespro.ru", "phone": "+70060267041"}
0005434587131	31DFCF	5161 355381	OLGA EGOROVA	{"phone": "+70387812455"}
0005434587132	F685CA	8182 544439	ANDREY KOROLEV	{"phone": "+70606395748"}
0005434587133	BC5866	1116 743765	TATYANA GERASIMOVA	{"email": "t-gerasimova1966@postgrespro.ru", "phone": "+70363290512"}
0005434587134	875D27	2400 074806	ANASTASIYA STEPANOVA	{"email": "anastasiya.stepanova1961@postgrespro.ru", "phone": "+70548526166"}
0005434587135	875D27	3598 963308	ALEKSANDR TIMOFEEV	{"phone": "+70853542857"}
0005434587136	A9362F	6276 358214	YURIY KULIKOV	{"email": "kulikovy.031978@postgrespro.ru", "phone": "+70133725986"}
0005434587137	C3595E	2180 433421	STANISLAV MEDVEDEV	{"phone": "+70888552923"}
0005434587138	B223DA	6458 990471	MARIYA RODIONOVA	{"phone": "+70290430041"}
0005434587139	2FCB66	3868 301875	ANDREY CHERNOV	{"phone": "+70678843105"}
0005434587140	B0B21D	2886 716562	INESSA KRASNOVA	{"email": "krasnova_inessa041969@postgrespro.ru", "phone": "+70499065641"}
0005434587141	B0B21D	7478 053450	VIKTOR FEDOROV	{"email": "fedorov.v-26011971@postgrespro.ru", "phone": "+70144861711"}
0005434587142	DD3B82	9132 095037	VALENTINA EFREMOVA	{"email": "valentinaefremova.081970@postgrespro.ru", "phone": "+70802236932"}
0005434587143	9DD877	2986 837911	NATALYA RODIONOVA	{"phone": "+70755662010"}
0005434587144	FFBFB9	2407 130905	ANASTASIYA KRASNOVA	{"phone": "+70904054814"}
0005434587145	FFBFB9	4562 202000	ANDREY IVANOV	{"phone": "+70451286448"}
0005434587146	174F75	0680 506358	NATALYA ZHURAVLEVA	{"email": "nzhuravleva.19051969@postgrespro.ru", "phone": "+70700965366"}
0005434587147	174F75	0672 891669	ZINAIDA ALEKSEEVA	{"phone": "+70761391335"}
0005434587148	552600	0675 042320	VALENTINA KOROLEVA	{"phone": "+70949724101"}
0005434587149	552600	9761 924971	VIKTOR KAZAKOV	{"phone": "+70968166128"}
0005434587150	819192	3177 271966	LEV MATVEEV	{"email": "lev-matveev-01071973@postgrespro.ru", "phone": "+70207991085"}
0005434587151	819192	2170 207882	MARINA YUDINA	{"phone": "+70299069910"}
0005434587152	5BC62C	1137 350091	LYUDMILA AKIMOVA	{"email": "akimoval1967@postgrespro.ru", "phone": "+70763861914"}
0005434587153	E1FEBF	5909 907282	OLGA ZAYCEVA	{"phone": "+70650844265"}
0005434587154	E1FEBF	5840 946833	OLGA TIKHONOVA	{"email": "o.tikhonova_1981@postgrespro.ru", "phone": "+70724289738"}
0005434587155	88F79A	7379 804764	MIKHAIL POPOV	{"phone": "+70228088327"}
0005434587156	88F79A	8928 982683	OKSANA NIKIFOROVA	{"email": "nikiforova.oksana1963@postgrespro.ru", "phone": "+70575643162"}
0005434587157	4C04A7	4542 828607	RAZIYA ILINA	{"phone": "+70136209340"}
0005434587158	6E1A51	2497 698420	VALENTIN VASILEV	{"phone": "+70339334832"}
0005434587159	57AF8E	8190 267802	VLADISLAV GAVRILOV	{"phone": "+70025000569"}
0005434587160	57AF8E	0704 905032	ELENA SOLOVEVA	{"email": "e.soloveva14021974@postgrespro.ru", "phone": "+70843623453"}
0005434587161	38AEBB	6871 326808	ALEKSANDR SOROKIN	{"phone": "+70076911077"}
0005434587162	6C899E	3238 425982	ALEKSANDR KISELEV	{"phone": "+70204467745"}
0005434587163	6C899E	9499 299452	DMITRIY MATVEEV	{"phone": "+70457558424"}
0005434587164	552DA1	7241 148978	SERGEY TIMOFEEV	{"phone": "+70469358965"}
0005434587165	26BA8B	7689 945461	NADEZHDA AFANASEVA	{"email": "n-afanaseva1972@postgrespro.ru", "phone": "+70626364545"}
0005434587166	7CB47A	3736 706020	DMITRIY SIDOROV	{"phone": "+70675857017"}
0005434587167	7CB47A	3075 854863	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva.091972@postgrespro.ru", "phone": "+70539807726"}
0005434587168	7E812E	2999 476085	NIKITA VASILEV	{"phone": "+70881094414"}
0005434587169	7E812E	2852 571946	EVGENIYA PAVLOVA	{"email": "e.pavlova-071971@postgrespro.ru", "phone": "+70374954246"}
0005434587170	D8FD54	8024 573384	VALENTINA POPOVA	{"phone": "+70466002292"}
0005434587171	D8FD54	0187 393673	IVAN STEPANOV	{"email": "stepanov_i.06071981@postgrespro.ru", "phone": "+70892826895"}
0005434587172	8F2777	5691 616934	MARIYA SOLOVEVA	{"phone": "+70350251635"}
0005434587173	DC301A	9697 994086	VERA SERGEEVA	{"email": "sergeeva.v_1975@postgrespro.ru", "phone": "+70285700109"}
0005434587174	DC301A	3788 811218	DENIS SEMENOV	{"email": "semenovdenis-121980@postgrespro.ru", "phone": "+70574178055"}
0005434587175	D078AF	8427 728445	KLAVDIYA ZAKHAROVA	{"phone": "+70730989608"}
0005434587176	6293A8	4332 484978	DARINA PAVLOVA	{"email": "pavlovadarina.19041967@postgrespro.ru", "phone": "+70567684414"}
0005434587177	954219	2186 588948	VALERIYA BELYAEVA	{"phone": "+70742797806"}
0005434587178	2D65E1	9407 956267	VALENTINA KONOVALOVA	{"email": "valentina-konovalova1968@postgrespro.ru", "phone": "+70186048363"}
0005434587179	2D65E1	7214 349797	SERGEY NIKITIN	{"phone": "+70269883970"}
0005434587180	6355AD	4986 289534	VLADIMIR NIKOLAEV	{"phone": "+70919160768"}
0005434587181	6355AD	1131 026827	KRISTINA DMITRIEVA	{"phone": "+70214924786"}
0005434587182	6355AD	0615 829545	ALEKSEY NIKOLAEV	{"email": "nikolaev-a-06081968@postgrespro.ru", "phone": "+70812917269"}
0005434587183	6355AD	9628 812585	VIKTOR KUZNECOV	{"email": "kuznecov-v.31031977@postgrespro.ru", "phone": "+70998871469"}
0005434587184	033390	1371 302061	ELIZAVETA MATVEEVA	{"email": "matveeva-e-041985@postgrespro.ru", "phone": "+70115562157"}
0005434587185	3614C4	5570 372985	NIKITA NIKOLAEV	{"phone": "+70761667964"}
0005434587186	0044ED	5283 527547	NIKOLAY KAZAKOV	{"phone": "+70226874271"}
0005434587187	40A4A1	5395 015916	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey_031965@postgrespro.ru", "phone": "+70650706359"}
0005434587188	40A4A1	4239 657048	LYUDMILA VOLKOVA	{"phone": "+70302131851"}
0005434587189	452E5F	5239 319583	ALEKSANDR ABRAMOV	{"email": "aabramov.18051976@postgrespro.ru", "phone": "+70620270719"}
0005434587190	452E5F	6657 561552	ALEKSEY ALEKSANDROV	{"email": "aaleksandrov14061975@postgrespro.ru", "phone": "+70533881708"}
0005434587191	E4E43A	4890 518336	VIKTOR SIDOROV	{"email": "sidorov-viktor_071954@postgrespro.ru", "phone": "+70687163428"}
0005434587192	E64322	3195 888823	DENIS BELOV	{"email": "belov.d-051973@postgrespro.ru", "phone": "+70717008365"}
0005434587193	3ABAA6	7383 264990	LYUBOV KONDRATEVA	{"email": "l.kondrateva_1973@postgrespro.ru", "phone": "+70770495868"}
0005434587194	685D2E	2786 773431	VALERIY ROMANOV	{"email": "romanovv_1987@postgrespro.ru", "phone": "+70450880373"}
0005434587195	F10E18	8390 813913	SVETLANA CHERNOVA	{"phone": "+70244420867"}
0005434587196	F10E18	0465 277119	SVETLANA NIKITINA	{"phone": "+70696841181"}
0005434587197	F10E18	1217 625064	ANNA ZAYCEVA	{"email": "anna.zayceva_1970@postgrespro.ru", "phone": "+70796846148"}
0005434587198	34E3CB	6020 616187	ANTON POPOV	{"email": "antonpopov.041965@postgrespro.ru", "phone": "+70945446679"}
0005434587199	EAF559	5452 614776	YURIY MAKAROV	{"email": "makarov-y-1973@postgrespro.ru", "phone": "+70492714945"}
0005434587200	7C1F76	2244 447289	PAVEL NIKITIN	{"email": "nikitin_p_1974@postgrespro.ru", "phone": "+70208796273"}
0005434587201	1B1879	2431 235916	NATALYA ABRAMOVA	{"phone": "+70706919055"}
0005434587202	47353C	9038 470488	SVETLANA NOVIKOVA	{"email": "novikova_s1974@postgrespro.ru", "phone": "+70863772560"}
0005434587203	B7890D	2513 946524	GULNARA DMITRIEVA	{"email": "gdmitrieva-1959@postgrespro.ru", "phone": "+70865653113"}
0005434587204	F789CB	1468 678324	IRINA ANDREEVA	{"email": "andreevairina021969@postgrespro.ru", "phone": "+70775201824"}
0005434587205	9F17F0	3408 718985	IVAN DMITRIEV	{"phone": "+70356666955"}
0005434587206	6AA4D8	0432 473385	ELENA PETROVA	{"email": "petrova_elena.061968@postgrespro.ru", "phone": "+70794121384"}
0005434587207	782DC4	8308 506880	ALEKSANDR MOROZOV	{"email": "morozov_a_26051959@postgrespro.ru", "phone": "+70481534248"}
0005434587208	8F0515	1949 415059	ZHANNA GERASIMOVA	{"email": "gerasimovazhanna.111966@postgrespro.ru", "phone": "+70343531532"}
0005434587209	99CBA8	7122 109924	VLADIMIR GERASIMOV	{"email": "gerasimov-v-101972@postgrespro.ru", "phone": "+70066066286"}
0005434587210	ED2969	4720 974786	NIKOLAY SCHERBAKOV	{"phone": "+70908761620"}
0005434587211	1F3DC4	2658 385113	LIDIYA MIRONOVA	{"phone": "+70172188156"}
0005434587212	4BE389	9010 388500	VIKTORIYA POTAPOVA	{"email": "potapova-v_15031975@postgrespro.ru", "phone": "+70963106552"}
0005434587213	9E0A69	2605 138765	RAISA ZAKHAROVA	{"phone": "+70675135250"}
0005434587214	1B82FE	8009 716680	KLARA BORISOVA	{"email": "klara.borisova1983@postgrespro.ru", "phone": "+70328889225"}
0005434587215	732E53	9535 882076	TAMARA SMIRNOVA	{"phone": "+70035993672"}
0005434587216	5AC152	9097 438323	TAMARA MAKAROVA	{"phone": "+70733283654"}
0005434587217	B379F6	9654 111760	ELENA TIMOFEEVA	{"email": "elena.timofeeva-02041975@postgrespro.ru", "phone": "+70042998498"}
0005434587218	B379F6	4169 512653	ANATOLIY GUSEV	{"phone": "+70098690284"}
0005434587219	51845D	9249 505927	ANTONINA ROMANOVA	{"phone": "+70130187179"}
0005434587220	51845D	5747 825874	SERGEY AFANASEV	{"phone": "+70605666651"}
0005434587221	07A14B	9684 501407	PAVEL BORISOV	{"email": "pavel.borisov-1970@postgrespro.ru", "phone": "+70254433134"}
0005434587222	4E012B	0281 219824	NIKITA BELOV	{"phone": "+70397733548"}
0005434587223	F49FED	8629 361628	YURIY PETROV	{"phone": "+70869345601"}
0005434600542	F375AA	9031 689664	ALEKSANDR MAKSIMOV	{"phone": "+70877038779"}
0005434587224	EB867B	7108 080793	VIKTOR DAVYDOV	{"email": "v_davydov.18091970@postgrespro.ru", "phone": "+70846267880"}
0005434587225	E49C93	1757 688526	ALEKSANDR KUZMIN	{"email": "kuzmin_a-27101969@postgrespro.ru", "phone": "+70794992472"}
0005434587226	31F0B7	0333 950864	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov031979@postgrespro.ru", "phone": "+70247802288"}
0005434587227	602B2E	6770 898716	ANNA NESTEROVA	{"email": "anna.nesterova05041970@postgrespro.ru", "phone": "+70723093187"}
0005434587228	602B2E	2048 599291	VYACHESLAV GAVRILOV	{"phone": "+70733269430"}
0005434587229	602B2E	1710 292540	YURIY SOKOLOV	{"phone": "+70397769817"}
0005434587230	E6E998	1714 490410	TATYANA MEDVEDEVA	{"email": "medvedevat-31121975@postgrespro.ru", "phone": "+70479927045"}
0005434587231	E6E998	9142 325650	TAMARA SOKOLOVA	{"email": "sokolova.t-091982@postgrespro.ru", "phone": "+70652351971"}
0005434587232	5D21C9	7447 769605	MARIYA SMIRNOVA	{"phone": "+70590553604"}
0005434587233	9D2CF5	5935 261691	YULIYA ERMAKOVA	{"email": "ermakova-y.011969@postgrespro.ru", "phone": "+70236727825"}
0005434587234	18230D	8853 262445	SERGEY GORBUNOV	{"email": "gorbunov.s-1963@postgrespro.ru", "phone": "+70206321577"}
0005434587235	595319	7015 515841	KLAVDIYA TARASOVA	{"email": "klavdiya_tarasova_1967@postgrespro.ru", "phone": "+70590852623"}
0005434587236	D2AA6D	9273 865721	VLADISLAV MAKSIMOV	{"email": "maksimov-vladislav_061978@postgrespro.ru", "phone": "+70983787158"}
0005434587237	B044A9	0482 537832	ELENA KUZNECOVA	{"phone": "+70834847680"}
0005434587238	B044A9	2092 377339	YURIY SOLOVEV	{"phone": "+70081713470"}
0005434587239	196314	9855 948351	LARISA ALEKSEEVA	{"phone": "+70536785152"}
0005434587240	196314	6489 597027	NATALYA POTAPOVA	{"email": "potapova_n.29011963@postgrespro.ru", "phone": "+70598302156"}
0005434587241	69430A	7128 034522	NATALIYA DAVYDOVA	{"phone": "+70421743275"}
0005434587242	4FAF47	6209 046781	DMITRIY VASILEV	{"email": "d_vasilev-07111958@postgrespro.ru", "phone": "+70937292490"}
0005434587243	4FAF47	8367 215862	OLESYA KUZNECOVA	{"email": "olesya_kuznecova.011964@postgrespro.ru", "phone": "+70091171711"}
0005434587244	7EFD42	7715 155977	SERGEY SOLOVEV	{"phone": "+70537572350"}
0005434587245	61C337	4102 408602	EVGENIYA ORLOVA	{"phone": "+70465413435"}
0005434587246	61C337	5992 169592	VLADIMIR SERGEEV	{"email": "vsergeev.051971@postgrespro.ru", "phone": "+70492498165"}
0005434587247	4A4EC4	0244 663300	VALERIY CHERNOV	{"phone": "+70258442136"}
0005434587248	4A4EC4	2420 663330	ANNA IVANOVA	{"email": "a_ivanova_101964@postgrespro.ru", "phone": "+70060066350"}
0005434587249	8AB41D	3837 468519	YURIY ALEKSEEV	{"phone": "+70447340140"}
0005434587250	C0C562	6489 822245	KIRILL STEPANOV	{"email": "k-stepanov-051973@postgrespro.ru", "phone": "+70581988574"}
0005434587251	174C44	4713 862715	ELENA MATVEEVA	{"phone": "+70904202021"}
0005434587252	7CF2F1	1658 546920	RADIK TIMOFEEV	{"phone": "+70906205505"}
0005434587253	7CF2F1	8880 857611	LARISA KONDRATEVA	{"phone": "+70497763724"}
0005434587254	DD5D12	9298 382862	SERGEY MAKSIMOV	{"email": "maksimovsergey111969@postgrespro.ru", "phone": "+70981628428"}
0005434587255	9E627C	4945 162285	VLADISLAV NIKITIN	{"phone": "+70309479635"}
0005434587256	9E627C	6186 546607	ZOYA ROMANOVA	{"email": "romanova_zoya-1962@postgrespro.ru", "phone": "+70162661110"}
0005434587257	35F64B	0591 604716	MILENA SMIRNOVA	{"email": "smirnova_milena.16011969@postgrespro.ru", "phone": "+70656288609"}
0005434587258	BB771E	0919 333956	EVGENIYA EGOROVA	{"email": "egorova.evgeniya-12091975@postgrespro.ru", "phone": "+70713528567"}
0005434587259	C50653	4311 840429	ELENA SEMENOVA	{"phone": "+70785425035"}
0005434587260	C50653	2598 438162	VALERIY ALEKSEEV	{"phone": "+70413837548"}
0005434587261	18DB8F	4024 685264	VLADISLAV SOKOLOV	{"phone": "+70824738086"}
0005434587262	18DB8F	5141 830472	VIKTOR IVANOV	{"phone": "+70392894353"}
0005434587263	DBF1B4	1389 988811	NADEZHDA SMIRNOVA	{"phone": "+70728521070"}
0005434587264	DC8F4C	7258 333580	GALINA SCHERBAKOVA	{"email": "scherbakova-galina.1964@postgrespro.ru", "phone": "+70934627250"}
0005434587265	DE8CFD	7548 934263	ALEKSEY MIRONOV	{"email": "a_mironov19081980@postgrespro.ru", "phone": "+70743808768"}
0005434587266	73C52F	4610 704450	ANATOLIY IVANOV	{"phone": "+70973386173"}
0005434587267	7EBCBC	9266 423061	OLGA VOROBEVA	{"phone": "+70810483427"}
0005434587268	E504A5	7630 643591	KARINA ANISIMOVA	{"email": "karina.anisimova_091962@postgrespro.ru", "phone": "+70975613522"}
0005434587269	35DB34	0721 512823	MAYYA EGOROVA	{"phone": "+70026396129"}
0005434587270	0C26F0	9118 447517	ANATOLIY NIKOLAEV	{"email": "a.nikolaev_1967@postgrespro.ru", "phone": "+70296826039"}
0005434587271	0C26F0	6768 276703	SVETLANA MIKHAYLOVA	{"phone": "+70450367618"}
0005434587272	D930AA	1944 644743	VLADIMIR PAVLOV	{"email": "pavlov_v-1973@postgrespro.ru", "phone": "+70893297800"}
0005434587273	6CA43A	4885 864740	LYUDMILA TIKHONOVA	{"email": "tikhonova.lyudmila101970@postgrespro.ru", "phone": "+70532234863"}
0005434587274	6CA43A	1243 885287	VLADIMIR CHERNOV	{"email": "chernov-vladimir-031978@postgrespro.ru", "phone": "+70259449771"}
0005434587275	50B2CC	9902 140271	VALENTINA FILATOVA	{"phone": "+70232396538"}
0005434587276	E4A486	6710 241165	ELENA BELYAEVA	{"email": "belyaeva-elena-091973@postgrespro.ru", "phone": "+70318425326"}
0005434587277	E4A486	7975 809510	NATALYA MOISEEVA	{"phone": "+70791322871"}
0005434587278	A66D9C	0279 238975	EGOR KAZAKOV	{"email": "egor.kazakov-1973@postgrespro.ru", "phone": "+70999629693"}
0005434587279	A66D9C	4121 073735	DARYA ALEKSEEVA	{"phone": "+70263794865"}
0005434587280	3E41D3	5669 566956	DARYA GERASIMOVA	{"email": "dgerasimova.101972@postgrespro.ru", "phone": "+70884685239"}
0005434587281	6DDADB	9932 125418	NIKITA ROMANOV	{"phone": "+70666561653"}
0005434587282	6DDADB	5800 931523	MARYAM DMITRIEVA	{"email": "maryam-dmitrieva_1973@postgrespro.ru", "phone": "+70543550970"}
0005434587283	6DDADB	4530 290965	GENNADIY ILIN	{"email": "ilin.gennadiy.1971@postgrespro.ru", "phone": "+70753208650"}
0005434587284	C21602	0129 510222	LYUBOV SERGEEVA	{"email": "lsergeeva.121978@postgrespro.ru", "phone": "+70939109614"}
0005434587285	8E23A4	8831 983607	TATYANA MELNIKOVA	{"phone": "+70537360506"}
0005434587286	779E62	6885 522672	ANDREY MOISEEV	{"phone": "+70056675668"}
0005434587287	779E62	3532 443628	MAKSIM IVANOV	{"email": "ivanov-maksim_1975@postgrespro.ru", "phone": "+70789757281"}
0005434587288	F65985	9329 210317	NINA PETROVA	{"phone": "+70238651930"}
0005434587289	85C281	2417 094548	IRINA KOZLOVA	{"email": "kozlova-i.051968@postgrespro.ru", "phone": "+70150183662"}
0005434587290	9689D0	0753 480312	RAFAEL SHEVCHENKO	{"email": "rafaelshevchenko.13121972@postgrespro.ru", "phone": "+70276070780"}
0005434587291	9689D0	7449 972263	ALEKSANDR STEPANOV	{"phone": "+70592189992"}
0005434587292	830C3D	3743 876673	ALEKSANDR TIKHONOV	{"phone": "+70737574570"}
0005434587293	6B4E5B	3607 764804	VITALIY IVANOV	{"phone": "+70861476163"}
0005434587294	6B4E5B	9079 956084	ANNA KUZNECOVA	{"email": "kuznecova_a_18091974@postgrespro.ru", "phone": "+70532556332"}
0005434587295	7A3C37	9802 436568	DMITRIY KUZNECOV	{"phone": "+70491357838"}
0005434587296	7A3C37	4029 158145	IGOR SCHERBAKOV	{"email": "igor_scherbakov03041980@postgrespro.ru", "phone": "+70841803698"}
0005434587297	B0BAEF	0080 797022	NIKOLAY SCHERBAKOV	{"phone": "+70252487521"}
0005434587298	5D2854	7216 380546	RENAT PETROV	{"phone": "+70200894000"}
0005434587299	5D2854	8464 557671	ANDREY MARTYNOV	{"email": "martynov_andrey-041981@postgrespro.ru", "phone": "+70072167762"}
0005434587300	D2A7AE	9914 599164	LYUBOV PETROVA	{"email": "lyubov.petrova.1976@postgrespro.ru", "phone": "+70875644520"}
0005434587301	46C665	5646 120697	ELENA KUZNECOVA	{"email": "e.kuznecova-05071969@postgrespro.ru", "phone": "+70063876363"}
0005434587302	335C8D	1632 883666	ANATOLIY NIKITIN	{"phone": "+70892794758"}
0005434587303	335C8D	0414 024926	ANATOLIY KOROLEV	{"email": "akorolev01061982@postgrespro.ru", "phone": "+70076727380"}
0005434587304	D8D343	1432 360707	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr.17111979@postgrespro.ru", "phone": "+70769376091"}
0005434587305	D8D343	7384 958571	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov.041979@postgrespro.ru", "phone": "+70918381910"}
0005434587306	C4AA8F	0558 183860	VALENTINA POLYAKOVA	{"email": "polyakova_valentina_20101982@postgrespro.ru", "phone": "+70045186834"}
0005434587307	45F02E	6686 144846	GALINA KUZMINA	{"phone": "+70283711621"}
0005434587308	BDEEC0	3553 102592	MAKSIM KULIKOV	{"email": "maksim-kulikov.101984@postgrespro.ru", "phone": "+70584774711"}
0005434587309	BDEEC0	2534 924131	SVETLANA NOVIKOVA	{"email": "novikova_svetlana.011964@postgrespro.ru", "phone": "+70211418208"}
0005434587310	70902D	4992 334752	ALEKSANDR FEDOTOV	{"email": "aleksandr-fedotov.1977@postgrespro.ru", "phone": "+70975769418"}
0005434587311	0D7F51	6061 733338	SVETLANA NIKITINA	{"phone": "+70309478222"}
0005434587312	B76672	4607 730937	OLGA DMITRIEVA	{"phone": "+70705126430"}
0005434587313	B76672	7143 720589	ALEKSEY KONOVALOV	{"email": "konovalov-aleksey_10101969@postgrespro.ru", "phone": "+70703787077"}
0005434587314	B76672	6969 055391	KSENIYA GUSEVA	{"email": "guseva-k.24071968@postgrespro.ru", "phone": "+70003806641"}
0005434587315	B76672	7588 702909	SEMEN DAVYDOV	{"email": "davydov.semen1971@postgrespro.ru", "phone": "+70987609027"}
0005434587316	5705F5	2160 992985	NIKITA ZAKHAROV	{"phone": "+70292096343"}
0005434587317	210E8F	4458 250645	EVGENIYA VOLKOVA	{"phone": "+70524194674"}
0005434587318	964912	8290 997724	MARIYA KUZNECOVA	{"email": "kuznecova-mariya.29061982@postgrespro.ru", "phone": "+70727693653"}
0005434587319	7E7F0E	1832 198530	NADEZHDA IVANOVA	{"phone": "+70414670279"}
0005434587320	30AA11	0448 824677	EKATERINA AFANASEVA	{"email": "afanasevaekaterina_1979@postgrespro.ru", "phone": "+70054238683"}
0005434587321	0738BD	2287 844503	MATVEY PAVLOV	{"email": "pavlov.matvey22081961@postgrespro.ru", "phone": "+70370592357"}
0005434587322	0738BD	4221 237742	DENIS MIKHAYLOV	{"email": "mikhaylovdenis1969@postgrespro.ru", "phone": "+70982953870"}
0005434587323	D22726	8982 445846	OLGA ZAKHAROVA	{"phone": "+70212276062"}
0005434587324	46C1BB	7975 600778	ANNA FILIPPOVA	{"email": "filippova_a_1970@postgrespro.ru", "phone": "+70507712536"}
0005434587325	F86C54	0002 523200	NATALYA POPOVA	{"email": "popova-n_111971@postgrespro.ru", "phone": "+70382456655"}
0005434587326	F86C54	7424 080088	TIMOFEY SHEVCHENKO	{"phone": "+70758442998"}
0005434587327	D62FC4	6415 263539	DENIS VASILEV	{"phone": "+70337399466"}
0005434587328	D62FC4	6204 514488	ALENA MALYSHEVA	{"phone": "+70065777639"}
0005434587329	3A4466	3234 840456	ANASTASIYA SOLOVEVA	{"email": "anastasiyasoloveva_1981@postgrespro.ru", "phone": "+70051397277"}
0005434587330	61850C	9587 510698	OLGA KUZNECOVA	{"email": "kuznecovaolga_1974@postgrespro.ru", "phone": "+70335140380"}
0005434587331	466B5F	5195 191739	OLGA NIKITINA	{"email": "olganikitina12011969@postgrespro.ru", "phone": "+70441544575"}
0005434587332	EE51FB	1663 308707	MARINA KUDRYASHOVA	{"phone": "+70729953652"}
0005434587333	A2A7DD	8217 955763	ALEKSEY IVANOV	{"email": "ivanov-a071971@postgrespro.ru", "phone": "+70270212739"}
0005434587334	B4F7F1	2796 374041	NATALYA ANISIMOVA	{"phone": "+70156087416"}
0005434587335	8E4B31	8146 826118	ANDREY ANTONOV	{"phone": "+70173991874"}
0005434587336	89A292	5338 257118	GALINA MASLOVA	{"phone": "+70606034672"}
0005434587337	479A3B	8099 449658	PAVEL DENISOV	{"phone": "+70515705347"}
0005434587338	D3AEC6	9444 481784	ALEKSANDR SHEVCHENKO	{"phone": "+70370900468"}
0005434587339	D3AEC6	0782 199393	VLADISLAV KARPOV	{"phone": "+70084916793"}
0005434587340	4D9F4A	0691 531733	VLADIMIR FEDOROV	{"phone": "+70546041783"}
0005434587341	0F7678	1650 924854	RAUF ALEKSANDROV	{"email": "rauf_aleksandrov-071978@postgrespro.ru", "phone": "+70983812666"}
0005434587342	A96AE2	6225 818629	LYUDMILA YAKOVLEVA	{"phone": "+70849141786"}
0005434587343	764EBC	9977 670938	LIDIYA MAKAROVA	{"phone": "+70827605300"}
0005434587344	8DCB4C	8610 744374	TALGAT FROLOV	{"email": "talgat-frolov_10081977@postgrespro.ru", "phone": "+70074105171"}
0005434587345	8DCB4C	2087 632758	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr_041970@postgrespro.ru", "phone": "+70878281396"}
0005434587346	8DCB4C	8097 831991	TATYANA FEDOROVA	{"email": "t.fedorova_051959@postgrespro.ru", "phone": "+70928453962"}
0005434587347	83CC9E	8914 745277	ALLA ALEKSANDROVA	{"email": "aaleksandrova23011966@postgrespro.ru", "phone": "+70913020371"}
0005434587348	869CAF	1761 990274	ALEKSANDR ILIN	{"email": "ilin-aleksandr-071982@postgrespro.ru", "phone": "+70189240567"}
0005434587349	869CAF	2226 858723	ANDREY KUZNECOV	{"phone": "+70965089417"}
0005434587350	F9F958	3459 228643	RUSLAN IVANOV	{"phone": "+70679369136"}
0005434587351	F9F958	8960 958067	SERGEY DMITRIEV	{"phone": "+70613183432"}
0005434587352	8F93BC	5549 402095	ELENA YUDINA	{"email": "eyudina13101975@postgrespro.ru", "phone": "+70178937552"}
0005434587353	A6492F	0238 657850	GENNADIY FEDOROV	{"phone": "+70798933523"}
0005434587354	2BF19D	6891 754767	LIDIYA ZHURAVLEVA	{"email": "lidiya-zhuravleva.011970@postgrespro.ru", "phone": "+70495374387"}
0005434587355	2BF19D	1926 926654	KAMILA SEMENOVA	{"email": "semenova_kamila.1979@postgrespro.ru", "phone": "+70068792038"}
0005434587356	2BF19D	0432 702610	TATYANA POPOVA	{"email": "t_popova-061971@postgrespro.ru", "phone": "+70603211152"}
0005434587357	3F9A3F	7514 594799	ROMAN MARTYNOV	{"phone": "+70345621188"}
0005434587358	3F9A3F	8553 998691	OLGA MEDVEDEVA	{"email": "medvedeva-o_1973@postgrespro.ru", "phone": "+70688978075"}
0005434587359	B34E22	8409 024881	ILYA PAVLOV	{"phone": "+70516544620"}
0005434587360	010986	1286 722800	MARIYA KUZNECOVA	{"phone": "+70611596778"}
0005434587361	010986	8840 313619	NATALYA RYABOVA	{"phone": "+70009910432"}
0005434587362	2B69F1	6681 345796	ANDREY STEPANOV	{"email": "andrey.stepanov.111973@postgrespro.ru", "phone": "+70514224870"}
0005434587363	672FC6	7463 847189	YURIY IVANOV	{"email": "yuriy-ivanov-1974@postgrespro.ru", "phone": "+70798963265"}
0005434600327	8DF8AC	3267 229370	ANDREY ORLOV	{"email": "andrey_orlov_1968@postgrespro.ru", "phone": "+70525355936"}
0005434600328	8DF8AC	8254 434058	SNEZHANA VASILEVA	{"phone": "+70565681861"}
0005434600329	9E9418	5331 983800	ELENA ILINA	{"email": "e_ilina101974@postgrespro.ru", "phone": "+70013777299"}
0005434600330	3AF099	7208 447351	AMIR ILIN	{"phone": "+70395399401"}
0005434600331	77BFF9	7739 704911	ANASTASIYA ILINA	{"email": "a_ilina1976@postgrespro.ru", "phone": "+70527425754"}
0005434600332	BE43AE	6130 622990	EKATERINA ABRAMOVA	{"phone": "+70944375927"}
0005434600333	AB3B46	4810 697888	NIKOLAY MELNIKOV	{"phone": "+70562498129"}
0005434600334	AB3B46	6516 112302	SVETLANA POPOVA	{"phone": "+70079210379"}
0005434600335	94185C	0363 993623	LYUDMILA SOKOLOVA	{"email": "lyudmila_sokolova_1964@postgrespro.ru", "phone": "+70385103419"}
0005434600336	646FEE	9803 915315	DANIIL NIKOLAEV	{"email": "nikolaev.d-041973@postgrespro.ru", "phone": "+70500328530"}
0005434600337	646FEE	9950 843590	YULIYA DAVYDOVA	{"phone": "+70807619061"}
0005434600338	52258B	8861 121270	PAVEL ZAKHAROV	{"email": "p_zakharov_091972@postgrespro.ru", "phone": "+70279090234"}
0005434600339	D53092	1465 499459	GALINA ANDREEVA	{"email": "g_andreeva061973@postgrespro.ru", "phone": "+70018379433"}
0005434600340	72A813	7526 830999	NIKOLAY FROLOV	{"email": "n_frolov-27121963@postgrespro.ru", "phone": "+70815430382"}
0005434600341	72A813	9226 008392	NADEZHDA FADEEVA	{"email": "fadeeva_nadezhda.011976@postgrespro.ru", "phone": "+70864463351"}
0005434600342	9E34F5	0832 316541	ALEKSANDR ALEKSEEV	{"email": "aleksandr_alekseev.071976@postgrespro.ru", "phone": "+70567856636"}
0005434600343	B0746A	2839 085305	DARYA ZAKHAROVA	{"email": "d_zakharova.101968@postgrespro.ru", "phone": "+70161149458"}
0005434600344	B0746A	1314 601129	ANTONINA KRASNOVA	{"email": "krasnova.a01011974@postgrespro.ru", "phone": "+70104832486"}
0005434600345	5A019B	7330 288982	DIANA EFIMOVA	{"email": "diana-efimova-23021974@postgrespro.ru", "phone": "+70243108572"}
0005434600346	7DCDE5	8697 145855	ALEKSANDR TARASOV	{"email": "aleksandr_tarasov-041984@postgrespro.ru", "phone": "+70010112805"}
0005434600347	7DCDE5	5716 539181	VIKTOR KONOVALOV	{"email": "konovalov.viktor-04121967@postgrespro.ru", "phone": "+70807547938"}
0005434600348	82155B	6010 444353	TATYANA SOROKINA	{"email": "sorokina-t1968@postgrespro.ru", "phone": "+70570118574"}
0005434600349	82155B	2245 262457	ANNA DMITRIEVA	{"email": "dmitrieva.anna03031976@postgrespro.ru", "phone": "+70693218535"}
0005434600350	781331	6482 956385	DANIL FROLOV	{"phone": "+70356240757"}
0005434600351	2AEE9C	3067 490493	ALEKSEY FEDOROV	{"phone": "+70161867001"}
0005434600352	F7C521	0561 540440	VALERIY SAVELEV	{"phone": "+70904660830"}
0005434600353	C6C25F	6310 713268	ALEKSEY ZAKHAROV	{"email": "aleksey.zakharov_21051983@postgrespro.ru", "phone": "+70547981283"}
0005434600354	E44043	1581 460883	OLGA SEMENOVA	{"phone": "+70784122898"}
0005434600355	D3A438	0796 081458	ANASTASIYA PETROVA	{"email": "a-petrova1970@postgrespro.ru", "phone": "+70495145785"}
0005434600356	E836D4	4939 358052	ALEKSEY MATVEEV	{"phone": "+70982329241"}
0005434600357	E836D4	9626 547551	NINA SOKOLOVA	{"phone": "+70288116054"}
0005434600358	037793	7483 021822	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-a_051970@postgrespro.ru", "phone": "+70978499770"}
0005434600359	037793	3764 292128	LEONID VOROBEV	{"email": "vorobevl.1977@postgrespro.ru", "phone": "+70803884919"}
0005434600360	3B1E91	6158 985913	PAVEL MIKHAYLOV	{"phone": "+70600382002"}
0005434600361	4CD3CD	0837 131962	ELENA IVANOVA	{"phone": "+70896370379"}
0005434600362	7AB73D	4246 434571	IGOR CHERNOV	{"email": "chernovi.041975@postgrespro.ru", "phone": "+70319784033"}
0005434600363	E87E3C	9678 069610	NIKOLAY SERGEEV	{"phone": "+70050963221"}
0005434600364	E87E3C	8393 090067	INNA YAKOVLEVA	{"email": "i_yakovleva.051970@postgrespro.ru", "phone": "+70608164414"}
0005434600365	E87E3C	8965 869877	RUSTAM KISELEV	{"email": "kiselev-r1967@postgrespro.ru", "phone": "+70309821911"}
0005434600366	C3F35C	2281 701387	OLGA STEPANOVA	{"email": "olga.stepanova.28071965@postgrespro.ru", "phone": "+70023761300"}
0005434600367	B6FD55	5671 951464	RODION BELOV	{"email": "belov-r031981@postgrespro.ru", "phone": "+70958560878"}
0005434600368	48FF66	8126 752348	DANILA DENISOV	{"email": "denisovd.101965@postgrespro.ru", "phone": "+70521092790"}
0005434600369	48FF66	5886 458054	YURIY FROLOV	{"email": "yuriyfrolov.051975@postgrespro.ru", "phone": "+70800400785"}
0005434600370	7133B3	6309 843355	VIKTOR PETROV	{"phone": "+70033054379"}
0005434600371	D01339	9110 886550	LYUBOV KARPOVA	{"email": "lyubov.karpova_02101979@postgrespro.ru", "phone": "+70943708658"}
0005434600372	30B44B	1694 873080	VENERA NIKOLAEVA	{"email": "v_nikolaeva.13071972@postgrespro.ru", "phone": "+70940984435"}
0005434600373	1530BB	1828 390686	ALENA NIKOLAEVA	{"email": "nikolaeva-a-1974@postgrespro.ru", "phone": "+70470934145"}
0005434600374	6EE576	7445 203563	NIKITA MAKAROV	{"phone": "+70613778468"}
0005434600375	01CAD6	3866 369250	ANASTASIYA ZHURAVLEVA	{"email": "anastasiya_zhuravleva-061964@postgrespro.ru", "phone": "+70556519547"}
0005434600376	045AF1	8609 474771	ANNA KUZNECOVA	{"phone": "+70969303230"}
0005434600377	045AF1	3909 047255	YURIY GORBUNOV	{"email": "yuriygorbunov-1974@postgrespro.ru", "phone": "+70941273145"}
0005434600378	045AF1	0799 593730	SERGEY KUZNECOV	{"email": "s_kuznecov.1973@postgrespro.ru", "phone": "+70102936653"}
0005434600379	045AF1	4059 743467	ANASTASIYA KOROLEVA	{"email": "koroleva.a081971@postgrespro.ru", "phone": "+70217981000"}
0005434600380	113C5B	2084 189209	ELENA ALEKSEEVA	{"email": "alekseeva_elena-19051974@postgrespro.ru", "phone": "+70359630358"}
0005434600381	6F344F	0411 446212	RUSLAN TIMOFEEV	{"email": "timofeev.r.22081973@postgrespro.ru", "phone": "+70525385430"}
0005434600382	9AF19F	5962 914341	VERA MOROZOVA	{"email": "v-morozova-1978@postgrespro.ru", "phone": "+70122416220"}
0005434600383	9AF19F	0793 064048	VLADIMIR SCHERBAKOV	{"email": "vscherbakov.031982@postgrespro.ru", "phone": "+70387678237"}
0005434600384	5832F2	1605 534551	TATYANA RODIONOVA	{"email": "tatyanarodionova_1972@postgrespro.ru", "phone": "+70445453446"}
0005434600385	5832F2	9364 019733	DMITRIY ISAEV	{"email": "dmitriy-isaev02011968@postgrespro.ru", "phone": "+70949903064"}
0005434600386	012382	7824 931267	ALEKSANDR VOROBEV	{"email": "a.vorobev_27051975@postgrespro.ru", "phone": "+70774168968"}
0005434600387	58EFC8	9102 519968	MARIYA POPOVA	{"phone": "+70585442230"}
0005434600388	58EFC8	4913 123237	OLGA BARANOVA	{"email": "baranovao28031975@postgrespro.ru", "phone": "+70595987557"}
0005434600389	0DFE03	8734 193309	VLADIMIR NOVIKOV	{"email": "novikov-v.061970@postgrespro.ru", "phone": "+70775013638"}
0005434600390	368694	0935 121625	ANASTASIYA MIRONOVA	{"email": "mironova-a1966@postgrespro.ru", "phone": "+70630108399"}
0005434600391	368694	8816 702273	MARIYA KONOVALOVA	{"email": "konovalova.m_011972@postgrespro.ru", "phone": "+70823719240"}
0005434600392	057CC2	2724 455764	MARAT KONOVALOV	{"phone": "+70366960960"}
0005434600393	3D712D	3732 298899	MIKHAIL KOZLOV	{"phone": "+70022876888"}
0005434600394	E09B23	3256 160322	GALINA EGOROVA	{"email": "egorovagalina-1960@postgrespro.ru", "phone": "+70816220160"}
0005434600395	E09B23	3320 046482	NIKOLAY KISELEV	{"phone": "+70370483528"}
0005434600396	EF911D	5017 904745	YURIY DAVYDOV	{"email": "ydavydov041977@postgrespro.ru", "phone": "+70652359917"}
0005434600397	89FEC7	3289 108385	SERGEY ROMANOV	{"email": "romanov_s-20121978@postgrespro.ru", "phone": "+70542286298"}
0005434600398	E5D243	6988 484464	VLADISLAV BELOV	{"email": "belov-vladislav-091982@postgrespro.ru", "phone": "+70988239224"}
0005434600399	2493A8	9025 559043	RAIS SMIRNOV	{"phone": "+70235649256"}
0005434600400	D2D4DA	9500 302733	SVETLANA IVANOVA	{"phone": "+70690935584"}
0005434600401	DD1594	5860 270089	OLESYA ANDREEVA	{"email": "olesyaandreeva.071985@postgrespro.ru", "phone": "+70816819582"}
0005434600402	DAF96B	6014 572114	SERGEY POPOV	{"email": "spopov-1979@postgrespro.ru", "phone": "+70600213548"}
0005434600403	D598AA	1390 474238	ARINA VASILEVA	{"phone": "+70726596197"}
0005434600404	D598AA	4046 883611	LYUBOV ZHUKOVA	{"phone": "+70375544845"}
0005434600405	373F1A	5804 170241	ELENA MASLOVA	{"email": "e_maslova-101989@postgrespro.ru", "phone": "+70156107855"}
0005434600406	6FEDF1	8000 360344	GALINA ANDREEVA	{"email": "andreeva_galina_1972@postgrespro.ru", "phone": "+70923742411"}
0005434600407	BE92A7	3137 748137	POLINA BORISOVA	{"phone": "+70162999202"}
0005434600408	BE92A7	1179 698337	VIKTOR ZAKHAROV	{"email": "zakharov.viktor-23091973@postgrespro.ru", "phone": "+70499985546"}
0005434600409	BE92A7	1982 028800	NINA PETROVA	{"email": "n-petrova-051964@postgrespro.ru", "phone": "+70716250924"}
0005434600410	7D768E	4265 051692	MARIYA SEMENOVA	{"email": "mariyasemenova.13061964@postgrespro.ru", "phone": "+70044649261"}
0005434600411	6C14FB	5662 682417	KIRILL KUZNECOV	{"email": "kuznecov.kirill.07121967@postgrespro.ru", "phone": "+70488528076"}
0005434600412	031E95	7380 234529	SERGEY KUZMIN	{"phone": "+70082957219"}
0005434600413	F1479B	3986 267939	VALERIY KONOVALOV	{"email": "konovalovvaleriy-1969@postgrespro.ru", "phone": "+70329547939"}
0005434600414	BED9DF	7837 010712	NADEZHDA NAUMOVA	{"phone": "+70385025243"}
0005434600415	A3EF68	4663 217462	NIKITA FILIPPOV	{"email": "nikitafilippov_1968@postgrespro.ru", "phone": "+70377420462"}
0005434600416	A3EF68	4391 770195	DMITRIY SIDOROV	{"phone": "+70420983453"}
0005434600417	1A79DD	2672 075436	YULIYA BOGDANOVA	{"phone": "+70408393380"}
0005434600418	4D0AC3	2116 966541	MARAT BORISOV	{"email": "m.borisov.1970@postgrespro.ru", "phone": "+70907918214"}
0005434600419	8740D5	1989 191192	ALEKSEY ZAKHAROV	{"phone": "+70027659732"}
0005434600420	C7E2BA	7763 913202	SVETLANA VASILEVA	{"email": "svetlana.vasileva-021975@postgrespro.ru", "phone": "+70123667474"}
0005434600421	F9B4E9	2370 005457	MAKSIM SOROKIN	{"phone": "+70172229838"}
0005434600422	1E6545	1258 204350	ELENA GORBUNOVA	{"email": "gorbunova_elena25071966@postgrespro.ru", "phone": "+70329498445"}
0005434600423	7A3A70	3079 756817	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_1967@postgrespro.ru", "phone": "+70248722663"}
0005434600424	C2DEEF	7363 216433	NIKOLAY MAKAROV	{"email": "n_makarov_14041976@postgrespro.ru", "phone": "+70909249805"}
0005434600425	C2DEEF	4252 884991	SERGEY MIKHAYLOV	{"phone": "+70834470460"}
0005434600426	AE01B9	0387 645134	NINA POLYAKOVA	{"email": "nina-polyakova_23041973@postgrespro.ru", "phone": "+70682110582"}
0005434600427	04D8E0	6883 952096	REGINA ZAKHAROVA	{"phone": "+70357701357"}
0005434600540	7481F6	4966 874900	TATYANA ZAKHAROVA	{"phone": "+70623101608"}
0005434600428	04D8E0	3093 612157	LIDIYA ZAKHAROVA	{"email": "lidiya_zakharova_1956@postgrespro.ru", "phone": "+70497009952"}
0005434600429	E08D67	8812 877030	LYUBOV KUZMINA	{"phone": "+70618692610"}
0005434600430	88AED5	5626 769941	IVAN FOMIN	{"phone": "+70285467056"}
0005434600431	21287B	5293 967835	ALEKSEY PETROV	{"email": "petrovaleksey_11041973@postgrespro.ru", "phone": "+70932285066"}
0005434600432	A3826D	0023 357942	MIKHAIL SEMENOV	{"email": "m-semenov1974@postgrespro.ru", "phone": "+70671707048"}
0005434600433	51FFA3	0856 083736	EVGENIY MAKAROV	{"phone": "+70554801724"}
0005434600434	412922	3347 669982	ANDREY NAZAROV	{"phone": "+70891419100"}
0005434600435	412922	3469 471094	DANIIL MOROZOV	{"phone": "+70342937838"}
0005434600436	79E258	0707 924062	DANIL IVANOV	{"email": "divanov_071975@postgrespro.ru", "phone": "+70471358902"}
0005434600437	79779A	2249 547424	ZINAIDA POLYAKOVA	{"email": "polyakova_z.17031960@postgrespro.ru", "phone": "+70849244240"}
0005434600438	CF2763	9419 141361	EVGENIYA SEMENOVA	{"phone": "+70076650777"}
0005434600439	4B90D9	0740 822765	VITALIY SCHERBAKOV	{"phone": "+70338061996"}
0005434600440	D57228	4992 755807	NATALIYA KUZNECOVA	{"email": "nataliyakuznecova1969@postgrespro.ru", "phone": "+70108993794"}
0005434600441	D57228	0338 489416	ANNA SEMENOVA	{"email": "semenovaa1969@postgrespro.ru", "phone": "+70430466474"}
0005434600442	D57228	7660 609798	ANGELINA VASILEVA	{"phone": "+70111793952"}
0005434600443	AA2979	6224 731363	ALEKSEY BARANOV	{"email": "aleksey_baranov.051965@postgrespro.ru", "phone": "+70927361345"}
0005434600444	73AE28	1876 987544	TATYANA POTAPOVA	{"email": "tatyana_potapova_30091962@postgrespro.ru", "phone": "+70121497311"}
0005434600445	219D25	4977 461444	NIKOLAY SEMENOV	{"phone": "+70835901675"}
0005434600446	D35465	4270 107862	LIDIYA NESTEROVA	{"phone": "+70695394319"}
0005434600447	239BD5	9698 795195	ALEKSEY KISELEV	{"phone": "+70920949095"}
0005434600448	77294F	7813 733547	MARINA MARTYNOVA	{"phone": "+70231732132"}
0005434600449	77294F	2572 370471	ILYA VOLKOV	{"phone": "+70948817737"}
0005434600450	6DE96F	1574 130529	MIKHAIL MIRONOV	{"email": "mikhail_mironov_31011978@postgrespro.ru", "phone": "+70734045523"}
0005434600451	033EEE	8373 834470	ALEKSANDR PETROV	{"phone": "+70956896231"}
0005434600452	A3619C	4901 881721	NATALIYA SMIRNOVA	{"email": "nataliya.smirnova.121981@postgrespro.ru", "phone": "+70475187955"}
0005434600453	870FD3	6115 705743	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr-101977@postgrespro.ru", "phone": "+70816660010"}
0005434600454	E67181	6426 116314	IGOR ZHURAVLEV	{"email": "zhuravlevi_061979@postgrespro.ru", "phone": "+70627969351"}
0005434600455	E67181	4946 279472	ANASTASIYA EGOROVA	{"email": "anastasiyaegorova05021989@postgrespro.ru", "phone": "+70662310029"}
0005434600456	44152C	8425 639156	ELENA FROLOVA	{"phone": "+70965626407"}
0005434600457	B7587D	3413 318878	EVGENIY KUZNECOV	{"email": "kuznecove.101961@postgrespro.ru", "phone": "+70495700500"}
0005434600458	116FC3	3197 500783	ELENA DANILOVA	{"email": "e.danilova.1972@postgrespro.ru", "phone": "+70337228971"}
0005434600459	7F27A5	5799 550017	IRINA KOMAROVA	{"phone": "+70201418496"}
0005434600460	7F27A5	6203 694581	MARINA FEDOROVA	{"phone": "+70204334563"}
0005434600461	7F7CE0	9938 931530	NATALIYA BELOVA	{"phone": "+70722056300"}
0005434600462	101314	1395 272849	ANDREY MIKHAYLOV	{"email": "a_mikhaylov-11101974@postgrespro.ru", "phone": "+70811518544"}
0005434600463	101314	9080 719004	NINA NESTEROVA	{"email": "n.nesterova-051978@postgrespro.ru", "phone": "+70510072441"}
0005434600464	CACD21	3738 360580	GALINA MALYSHEVA	{"phone": "+70461605569"}
0005434600465	7842F2	3012 460296	OLGA GUSEVA	{"phone": "+70748335975"}
0005434600466	EF3EE3	5955 472190	ALEKSANDR STEPANOV	{"email": "a.stepanov_101976@postgrespro.ru", "phone": "+70405275022"}
0005434600467	74CD3D	4606 607544	EVGENIY GAVRILOV	{"phone": "+70379026199"}
0005434600468	0A68C9	0825 327406	PETR PAVLOV	{"email": "petr.pavlov_23081965@postgrespro.ru", "phone": "+70392960282"}
0005434600469	0A68C9	9213 533697	VLADISLAV KOZLOV	{"email": "kozlov_v_01111968@postgrespro.ru", "phone": "+70028142839"}
0005434600470	2F18A8	0178 054195	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov_07121975@postgrespro.ru", "phone": "+70234923767"}
0005434600471	1970D2	5827 364368	EVGENIY SMIRNOV	{"phone": "+70097165555"}
0005434600472	4E4455	8772 410455	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_23101969@postgrespro.ru", "phone": "+70476521335"}
0005434600473	4E4455	6460 089509	LYUDMILA TARASOVA	{"phone": "+70351894195"}
0005434600474	4E2FE7	9115 633091	ELENA SIDOROVA	{"email": "sidorovaelena.031966@postgrespro.ru", "phone": "+70790017713"}
0005434600475	3C4A52	2363 963047	OLGA STEPANOVA	{"email": "stepanovaolga14031984@postgrespro.ru", "phone": "+70452969416"}
0005434600476	3B6D89	0456 799573	YURIY ANTONOV	{"phone": "+70823926859"}
0005434600477	A6916F	4139 854490	NIKOLAY MELNIKOV	{"phone": "+70808295295"}
0005434600478	A66179	8793 382030	IGOR ABRAMOV	{"email": "abramov-i.15091958@postgrespro.ru", "phone": "+70637475393"}
0005434600479	CFFA03	8020 144936	ANASTASIYA KOVALEVA	{"email": "anastasiya_kovaleva-1965@postgrespro.ru", "phone": "+70673454782"}
0005434600480	02BCA8	3185 622156	ANDREY KUZNECOV	{"phone": "+70714614946"}
0005434600481	2844F9	0566 593847	IVAN ALEKSANDROV	{"email": "aleksandrov_i071962@postgrespro.ru", "phone": "+70346115886"}
0005434600482	321D23	4174 174812	DMITRIY ZAKHAROV	{"email": "dmitriy.zakharov.03051969@postgrespro.ru", "phone": "+70235856101"}
0005434600483	7865D0	9733 184270	KONSTANTIN DAVYDOV	{"email": "davydov.k.091967@postgrespro.ru", "phone": "+70161987946"}
0005434600484	7865D0	8412 847364	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov30031969@postgrespro.ru", "phone": "+70421777975"}
0005434600485	910899	4676 259760	VIKTOR ABRAMOV	{"phone": "+70286818256"}
0005434600486	7F7E39	1732 057084	EKATERINA ZHURAVLEVA	{"email": "zhuravleva.e.031973@postgrespro.ru", "phone": "+70800846671"}
0005434600487	7F7E39	0407 496238	TATYANA YAKOVLEVA	{"email": "tyakovleva111966@postgrespro.ru", "phone": "+70228658364"}
0005434600488	575C54	5821 459177	DIANA ANTONOVA	{"email": "antonova_d.051974@postgrespro.ru", "phone": "+70288832145"}
0005434600489	898C86	7017 523939	ANDREY GERASIMOV	{"email": "gerasimovandrey20091963@postgrespro.ru", "phone": "+70376246088"}
0005434600490	898C86	2819 757701	MIKHAIL ZAKHAROV	{"email": "zakharov_mikhail-121983@postgrespro.ru", "phone": "+70810230226"}
0005434600491	CE986C	5268 225190	IRINA TROFIMOVA	{"phone": "+70873593011"}
0005434600492	CE986C	5453 869248	IGOR RODIONOV	{"phone": "+70042494269"}
0005434600493	CE986C	8494 894657	ALEKSEY VOROBEV	{"phone": "+70422666269"}
0005434600494	CF76BF	3633 553048	NATALYA TROFIMOVA	{"phone": "+70026503376"}
0005434600495	77EB3A	5805 686535	ELENA ABRAMOVA	{"phone": "+70149443813"}
0005434600496	D71B94	2097 057757	YURIY KUZNECOV	{"email": "kuznecov-y.1980@postgrespro.ru", "phone": "+70208927642"}
0005434600497	7594D1	2201 911649	VIKTOR GERASIMOV	{"phone": "+70878898762"}
0005434600498	9B4563	9942 510689	KIRILL ANDREEV	{"phone": "+70547791866"}
0005434600499	98530C	3739 702635	ALEKSANDR NIKOLAEV	{"phone": "+70350652881"}
0005434600500	98530C	0009 541564	ANDREY NAZAROV	{"email": "nazarov.andrey.1963@postgrespro.ru", "phone": "+70483826134"}
0005434600501	DCC383	0205 303444	LYUBOV STEPANOVA	{"email": "lyubov.stepanova_111970@postgrespro.ru", "phone": "+70231085661"}
0005434600502	B62E6B	0327 303992	ROMAN SOKOLOV	{"email": "sokolov.r-1964@postgrespro.ru", "phone": "+70181877995"}
0005434600503	D911E0	2696 713839	SVETLANA GRISHINA	{"phone": "+70699405995"}
0005434600504	3AEA7E	8646 769233	DENIS MAKAROV	{"email": "makarov-denis_061964@postgrespro.ru", "phone": "+70969970159"}
0005434600505	4FB386	0923 389255	ELENA VLASOVA	{"phone": "+70363203111"}
0005434600506	4FB386	9209 532023	LARISA KUZNECOVA	{"email": "kuznecova.larisa_14071972@postgrespro.ru", "phone": "+70530957084"}
0005434600507	AF5CFB	0437 972858	RASHID EGOROV	{"email": "r.egorov.1970@postgrespro.ru", "phone": "+70890476144"}
0005434600508	B45962	6248 375008	YANA PETROVA	{"phone": "+70057878021"}
0005434600509	370F5C	1847 986524	EKATERINA MIRONOVA	{"phone": "+70481967878"}
0005434600510	26B731	4275 621602	PAVEL MIKHAYLOV	{"email": "pmikhaylov_25091975@postgrespro.ru", "phone": "+70614985974"}
0005434600511	18C3F6	5430 720320	TATYANA RYABOVA	{"email": "tryabova_23081976@postgrespro.ru", "phone": "+70233445000"}
0005434600512	B5B7CF	0095 911882	EVGENIY SIDOROV	{"email": "evgeniy-sidorov-101978@postgrespro.ru", "phone": "+70481619582"}
0005434600513	45B9B4	3599 361999	MIKHAIL MARTYNOV	{"phone": "+70816695776"}
0005434600514	45B9B4	2940 073840	LYUCIYA ARKHIPOVA	{"email": "l-arkhipova.091967@postgrespro.ru", "phone": "+70176997384"}
0005434600515	494B71	9753 384450	SVETLANA KUZNECOVA	{"phone": "+70619740847"}
0005434600516	FC179B	6672 764523	LYUBOV MELNIKOVA	{"email": "melnikova.lyubov-1974@postgrespro.ru", "phone": "+70465406685"}
0005434600517	F96303	1434 228149	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov.11021973@postgrespro.ru", "phone": "+70040825617"}
0005434600518	B649D0	9581 664949	OKSANA KAZAKOVA	{"phone": "+70997078414"}
0005434600519	CEFB52	2495 996859	VALENTINA KAZAKOVA	{"phone": "+70422416010"}
0005434600520	CEFB52	6976 770015	ELENA MEDVEDEVA	{"email": "medvedevaelena_1978@postgrespro.ru", "phone": "+70771380967"}
0005434600521	D2BF3B	2904 393688	NATALIYA TIMOFEEVA	{"phone": "+70501523270"}
0005434600522	2AD2C4	7817 908717	EKATERINA CHERNOVA	{"email": "ekaterina-chernova031978@postgrespro.ru", "phone": "+70562430354"}
0005434600523	D03978	3308 643906	ALEKSEY MATVEEV	{"email": "a-matveev-15081952@postgrespro.ru", "phone": "+70489669207"}
0005434600524	8BAEFF	6090 331010	SERGEY MOROZOV	{"email": "morozov_s071978@postgrespro.ru", "phone": "+70186415600"}
0005434600525	199952	3105 690409	NINA SAVELEVA	{"phone": "+70359440083"}
0005434600526	251D1C	9793 910747	DMITRIY VASILEV	{"phone": "+70969295568"}
0005434600527	50AFD7	0418 597467	VERA KRASNOVA	{"phone": "+70135789593"}
0005434600528	BCBF68	8745 601381	ALEKSANDR KUZNECOV	{"phone": "+70293244088"}
0005434600529	1CD819	9465 015522	TATYANA TITOVA	{"email": "tatyanatitova-25011976@postgrespro.ru", "phone": "+70039504613"}
0005434600530	2875BE	3744 830451	IVAN POPOV	{"phone": "+70882126250"}
0005434600531	2875BE	1015 705172	ROMAN VOLKOV	{"email": "volkovroman-091973@postgrespro.ru", "phone": "+70516421510"}
0005434600532	2875BE	2688 999313	ANASTASIYA IVANOVA	{"email": "ivanova_a_071968@postgrespro.ru", "phone": "+70437887018"}
0005434600533	D9B3D3	6688 658518	RUSLAN FEDOTOV	{"email": "rfedotov1965@postgrespro.ru", "phone": "+70556293390"}
0005434600534	3AD066	4993 879796	PAVEL MOROZOV	{"phone": "+70617210228"}
0005434600535	D03B99	4364 150059	PETR MIKHAYLOV	{"email": "petr-mikhaylov101978@postgrespro.ru", "phone": "+70317637527"}
0005434600536	366301	6130 627939	ELENA GERASIMOVA	{"phone": "+70987487118"}
0005434600537	48B209	1659 077697	SERGEY BONDARENKO	{"phone": "+70475428802"}
0005434600538	29E94A	2505 841751	EVGENIYA DENISOVA	{"email": "denisova_e_1980@postgrespro.ru", "phone": "+70336548296"}
0005434600539	CB4DE5	6102 134732	KLAVDIYA KISELEVA	{"email": "kiseleva_k_25071965@postgrespro.ru", "phone": "+70384525866"}
0005434600541	F375AA	9932 778580	VIKTOR GAVRILOV	{"phone": "+70430141135"}
0005434600543	30DC08	4883 587371	IRINA NESTEROVA	{"email": "nesterova-irina091964@postgrespro.ru", "phone": "+70092955153"}
0005434600544	779EB4	8433 121888	ELENA NIKITINA	{"email": "nikitina_elena_21021969@postgrespro.ru", "phone": "+70522690791"}
0005434600545	779EB4	5971 553345	VLADIMIR MAKSIMOV	{"phone": "+70068862586"}
0005434600546	A0410E	5737 096887	NADEZHDA STEPANOVA	{"email": "nadezhda_stepanova011966@postgrespro.ru", "phone": "+70713401115"}
0005434600547	A0410E	9089 307717	ALEKSEY GUSEV	{"email": "gusev_aleksey.06081970@postgrespro.ru", "phone": "+70422522135"}
0005434600548	D0809A	5626 588744	NATALYA DMITRIEVA	{"phone": "+70343610993"}
0005434600549	D0809A	5655 238108	ALEKSANDR MAKAROV	{"email": "makarova.091964@postgrespro.ru", "phone": "+70956690438"}
0005434600550	444057	6034 425127	VALENTINA NIKOLAEVA	{"email": "nikolaeva_valentina-1973@postgrespro.ru", "phone": "+70957445361"}
0005434600551	03FDD3	2612 888537	EKATERINA PAVLOVA	{"email": "pavlova_e20041975@postgrespro.ru", "phone": "+70026497482"}
0005434600552	8BD551	4238 696215	TAMARA SMIRNOVA	{"phone": "+70112674669"}
0005434600553	38FC05	7685 182940	SERGEY ABRAMOV	{"phone": "+70310487997"}
0005434600554	FAE94F	2037 543627	IVAN CHERNOV	{"phone": "+70645981802"}
0005434600555	2C4B8C	9452 338826	ELENA NIKITINA	{"email": "e-nikitina09121981@postgrespro.ru", "phone": "+70910078151"}
0005434600556	2C4B8C	8786 467007	VALENTINA KRASNOVA	{"phone": "+70501578386"}
0005434600557	2C4B8C	0572 861497	LYUDMILA SERGEEVA	{"email": "l.sergeeva1966@postgrespro.ru", "phone": "+70693060968"}
0005434600558	26CE3F	2502 478558	DMITRIY IVANOV	{"email": "ivanov-d.041964@postgrespro.ru", "phone": "+70045898557"}
0005434600559	BA84D7	7819 283897	DENIS CHERNOV	{"phone": "+70229451220"}
0005434600560	BA84D7	7254 764550	ALEKSEY ZHUKOV	{"phone": "+70763562805"}
0005434600561	AF097A	2629 315990	NIKOLAY MOROZOV	{"email": "n.morozov-061968@postgrespro.ru", "phone": "+70861320200"}
0005434600562	717532	6153 112218	VIKTORIYA GORBUNOVA	{"email": "gorbunova_viktoriya.26021971@postgrespro.ru", "phone": "+70417899304"}
0005434600563	717532	5395 619914	EGOR OSIPOV	{"email": "osipov-egor-1966@postgrespro.ru", "phone": "+70359871760"}
0005434600564	4E3AA9	5942 933166	ALEKSEY PAVLOV	{"email": "a.pavlov1973@postgrespro.ru", "phone": "+70311043710"}
0005434600565	333E27	3713 585739	ALEKSANDRA SMIRNOVA	{"email": "smirnova.a-07031973@postgrespro.ru", "phone": "+70288123663"}
0005434600566	892D40	7757 081843	PETR VASILEV	{"phone": "+70867479545"}
0005434600567	892D40	3080 225285	EVGENIY POPOV	{"email": "popov.evgeniy.121972@postgrespro.ru", "phone": "+70923988847"}
0005434600568	F98592	7567 696600	VLADIMIR GRIGOREV	{"phone": "+70931400626"}
0005434600569	ACD98C	8201 630175	YULIYA MIKHAYLOVA	{"email": "yuliyamikhaylova-06021966@postgrespro.ru", "phone": "+70878059816"}
0005434600570	F6240A	1349 252921	ELENA BELOVA	{"phone": "+70389329505"}
0005434600571	E26551	4470 199179	EGOR PETROV	{"phone": "+70157229642"}
0005434600572	3F522A	3920 787492	DENIS IVANOV	{"phone": "+70680470827"}
0005434600573	C33209	8215 168656	GENNADIY BELOV	{"phone": "+70989428161"}
0005434600574	C33209	9362 913709	ANDREY GRIGOREV	{"email": "grigorev-andrey_11011969@postgrespro.ru", "phone": "+70675026940"}
0005434600575	FF5B00	2924 735972	ALEKSANDR KULIKOV	{"phone": "+70793952358"}
0005434600576	F25B15	6694 596303	ANNA TARASOVA	{"phone": "+70830160150"}
0005434600577	F25B15	0758 091302	OLGA NESTEROVA	{"email": "nesterova_o.24071962@postgrespro.ru", "phone": "+70250382710"}
0005434600578	F25B15	0089 426953	NINA DMITRIEVA	{"phone": "+70269347611"}
0005434600579	4298E4	1198 184089	EVGENIYA PAVLOVA	{"email": "pavlova_evgeniya-10081974@postgrespro.ru", "phone": "+70070888184"}
0005434600580	4298E4	4073 946695	VALERIYA NIKITINA	{"phone": "+70893005723"}
0005434600581	007DE7	8957 624553	SERGEY FROLOV	{"email": "sfrolov_01031975@postgrespro.ru", "phone": "+70153982465"}
0005434600582	B6B805	2843 102727	LYUDMILA DENISOVA	{"phone": "+70858190434"}
0005434600583	73BC6B	8809 523558	NATALIYA FROLOVA	{"phone": "+70127982245"}
0005434600584	A90D35	3794 481024	VIKTORIYA VOLKOVA	{"phone": "+70310858961"}
0005434600585	4D3E2A	2714 371152	NATALYA MATVEEVA	{"phone": "+70367052336"}
0005434600586	E843DB	2768 560647	SERGEY CHERNOV	{"phone": "+70670076173"}
0005434600587	A17976	3557 795617	IVAN ABRAMOV	{"email": "iabramov.1967@postgrespro.ru", "phone": "+70417258107"}
0005434600588	A17976	3443 848557	VALERIYA FOMINA	{"email": "fomina.v_071969@postgrespro.ru", "phone": "+70577968191"}
0005434600589	227E79	4684 398621	RAMIL VOLKOV	{"phone": "+70168148129"}
0005434600590	227E79	6893 267481	VIKTORIYA POLYAKOVA	{"email": "polyakova.viktoriya-11041978@postgrespro.ru", "phone": "+70475472660"}
0005434600591	8BA10C	7152 605928	NIKITA NOVIKOV	{"phone": "+70799348635"}
0005434600592	0FD394	7288 929317	ZHANNA BORISOVA	{"phone": "+70578117739"}
0005434600593	0FD394	4310 340974	MIKHAIL KARPOV	{"phone": "+70292282463"}
0005434600594	4232B2	4800 056495	ANDREY MAKAROV	{"phone": "+70652861543"}
0005434600595	BA5C74	9434 289739	GALINA KOMAROVA	{"email": "galina-komarova26021964@postgrespro.ru", "phone": "+70263667208"}
0005434600596	8BE1B4	7272 775680	DENIS STEPANOV	{"email": "denis-stepanov_1979@postgrespro.ru", "phone": "+70052752843"}
0005434600597	ECC333	0195 881307	ALEKSANDR STEPANOV	{"phone": "+70932553743"}
0005434600598	ECC333	5389 273806	TATYANA ZHURAVLEVA	{"email": "tatyana_zhuravleva_1963@postgrespro.ru", "phone": "+70728046495"}
0005434600599	ABB8EB	8326 260922	AZAT VASILEV	{"email": "a.vasilev-071966@postgrespro.ru", "phone": "+70609448115"}
0005434600600	ABB8EB	9464 367557	VYACHESLAV SEMENOV	{"email": "semenov.vyacheslav.04091974@postgrespro.ru", "phone": "+70033582897"}
0005434600601	FCF914	8306 858668	KIRA CHERNOVA	{"email": "k.chernova121983@postgrespro.ru", "phone": "+70978615175"}
0005434600602	FCF914	7867 469817	MARIYA KAZAKOVA	{"phone": "+70775454053"}
0005434600604	70725E	8686 371127	LYUBOV RODIONOVA	{"phone": "+70759486063"}
0005434600605	9B27B9	3511 157627	ANATOLIY PAVLOV	{"email": "a_pavlov_20101976@postgrespro.ru", "phone": "+70371855509"}
0005434600606	1C002A	6922 408090	FEDOR SERGEEV	{"email": "fedorsergeev_091968@postgrespro.ru", "phone": "+70274946092"}
0005434600607	1C002A	8581 041985	LYUDMILA BORISOVA	{"phone": "+70389027744"}
0005434600608	1C002A	6405 996822	TATYANA MELNIKOVA	{"email": "melnikova_t041969@postgrespro.ru", "phone": "+70439594980"}
0005434600609	FD563A	5125 424765	LYUBOV NESTEROVA	{"email": "lyubovnesterova.091975@postgrespro.ru", "phone": "+70220912094"}
0005434600610	E701AF	2745 095394	VALERIY KULIKOV	{"phone": "+70458199828"}
0005434600611	26E22F	0311 561682	KONSTANTIN AFANASEV	{"email": "afanasev.k.031967@postgrespro.ru", "phone": "+70139500188"}
0005434600612	26827C	3589 767415	MARIYA KOMAROVA	{"phone": "+70877768147"}
0005434600613	26827C	5482 301881	ALEKSANDR KULIKOV	{"email": "akulikov011975@postgrespro.ru", "phone": "+70794536259"}
0005434600614	26827C	6858 011897	VITALIY NIKOLAEV	{"email": "nikolaev_vitaliy081977@postgrespro.ru", "phone": "+70992587228"}
0005434600615	86FC1B	1317 742407	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov-1976@postgrespro.ru", "phone": "+70195450232"}
0005434600616	5DE950	6069 774015	ZHANNA SAVELEVA	{"phone": "+70080454798"}
0005434600617	DB9D04	2558 474892	RUSTAM ZAYCEV	{"email": "zaycev-rustam1972@postgrespro.ru", "phone": "+70598209880"}
0005434600618	77A793	1900 592746	ARTEM KARPOV	{"email": "karpov-artem_081987@postgrespro.ru", "phone": "+70255168659"}
0005434600619	D38E59	4580 707701	DMITRIY FROLOV	{"phone": "+70452173935"}
0005434600620	59A428	3469 573350	VLADIMIR RODIONOV	{"email": "rodionov.vladimir-1982@postgrespro.ru", "phone": "+70507012173"}
0005434600621	8ED08A	0580 564476	VENIAMIN NIKITIN	{"phone": "+70346696867"}
0005434600622	8ED08A	3910 403796	ANASTASIYA NOVIKOVA	{"email": "novikova_anastasiya1973@postgrespro.ru", "phone": "+70291149555"}
0005434600623	D5F6C3	4951 831622	DARYA NIKOLAEVA	{"phone": "+70107022853"}
0005434600624	F3FFE1	9999 688117	NATALIYA MOROZOVA	{"email": "nataliya-morozova.071961@postgrespro.ru", "phone": "+70539251965"}
0005434600625	F106CF	7344 806319	DARYA NAUMOVA	{"email": "darya_naumova1960@postgrespro.ru", "phone": "+70752093956"}
0005434600626	F506BC	2300 663321	VYACHESLAV KRASNOV	{"phone": "+70668390318"}
0005434600627	92E3EB	3918 046325	RAFAIL GORBUNOV	{"email": "gorbunov_rafail.051958@postgrespro.ru", "phone": "+70900752321"}
0005434600628	4C6E3E	0103 180206	VLADISLAV MAKAROV	{"email": "v_makarov_1965@postgrespro.ru", "phone": "+70260743114"}
0005434600629	951F70	1936 470638	DENIS BONDARENKO	{"phone": "+70071661388"}
0005434600630	DC7608	1005 141974	RIMMA MEDVEDEVA	{"email": "medvedeva-r-121965@postgrespro.ru", "phone": "+70620693713"}
0005434600631	4C46F2	9254 062543	ALEKSANDR BORISOV	{"phone": "+70947209910"}
0005434600632	4C46F2	9422 914175	PAVEL KULIKOV	{"phone": "+70845582009"}
0005434600633	110EE2	1685 890744	YURIY MELNIKOV	{"email": "melnikov_y.091971@postgrespro.ru", "phone": "+70590684304"}
0005434600634	010C35	0706 770210	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov_1971@postgrespro.ru", "phone": "+70982181212"}
0005434600635	B1DD81	9706 325113	OLEG POPOV	{"email": "o.popov.041980@postgrespro.ru", "phone": "+70159374387"}
0005434600636	B1DD81	2054 672397	ALEKSANDR IVANOV	{"phone": "+70609495969"}
0005434600637	B1DD81	8094 548953	VALENTINA GUSEVA	{"email": "v.guseva_16091977@postgrespro.ru", "phone": "+70864701873"}
0005434600638	57CA96	0784 436629	KLAVDIYA NIKIFOROVA	{"phone": "+70603546987"}
0005434600639	3C2490	7726 318745	ALEKSANDRA KUZMINA	{"phone": "+70989730924"}
0005434600640	388EFF	4372 753004	TATYANA FROLOVA	{"phone": "+70006873348"}
0005434600641	4551D7	8096 634064	ALEKSANDR BELOV	{"email": "belov-a_031971@postgrespro.ru", "phone": "+70555105426"}
0005434600642	7025A2	8815 298219	SERGEY MAKAROV	{"email": "s.makarov-121968@postgrespro.ru", "phone": "+70616053978"}
0005434600644	B9C1D9	6628 663655	VALENTIN IVANOV	{"phone": "+70028010796"}
0005434600645	D984C2	2406 833339	ANASTASIYA CHERNOVA	{"phone": "+70320528906"}
0005434600646	3B969D	0605 005114	ZINAIDA NESTEROVA	{"email": "nesterovazinaida_011973@postgrespro.ru", "phone": "+70655397634"}
0005434600647	063EA1	4495 609242	IGOR MATVEEV	{"phone": "+70328475439"}
0005434600648	87DF07	8536 201582	OLEG KUZMIN	{"phone": "+70017624730"}
0005434600649	87DF07	6685 019309	ILONA NESTEROVA	{"email": "nesterova.ilona-021968@postgrespro.ru", "phone": "+70166661206"}
0005434600650	9DA13F	0896 309383	VLADIMIR ZAKHAROV	{"phone": "+70540570251"}
0005434600651	4506CC	7915 993001	GALINA NAZAROVA	{"email": "nazarovagalina1966@postgrespro.ru", "phone": "+70570247616"}
0005434600652	507E4C	8478 811799	OLGA ZOTOVA	{"phone": "+70984666565"}
0005434600653	507E4C	0166 335386	NIKOLAY NAZAROV	{"phone": "+70311771551"}
0005434600654	C3C0E3	1991 714769	MARIYA SAVELEVA	{"email": "saveleva_m-081972@postgrespro.ru", "phone": "+70074173130"}
0005434600655	524AAC	4989 318243	VYACHESLAV VASILEV	{"phone": "+70879754655"}
0005434600656	817C77	5133 054341	NIKOLAY TIKHONOV	{"phone": "+70985906535"}
0005434600657	190F84	6711 780495	SEMEN VASILEV	{"phone": "+70191134681"}
0005434600658	253A3E	4469 515337	ELENA OSIPOVA	{"phone": "+70017919092"}
0005434600659	9DC80D	4269 302988	LYUBOV ZAKHAROVA	{"phone": "+70783434012"}
0005434600660	9DC80D	3365 047644	NIKITA AFANASEV	{"phone": "+70374063169"}
0005434600661	9DC80D	6673 213314	OLGA TIMOFEEVA	{"email": "o.timofeeva061981@postgrespro.ru", "phone": "+70102805925"}
0005434600662	C9CBB7	0156 346444	ALEKSANDR FROLOV	{"email": "afrolov.30061971@postgrespro.ru", "phone": "+70941375515"}
0005434600663	C9CBB7	9535 188364	INESSA ALEKSANDROVA	{"email": "ialeksandrova.04011974@postgrespro.ru", "phone": "+70743914321"}
0005434600664	B48A1D	4903 150152	DMITRIY POPOV	{"phone": "+70385221610"}
0005434600665	974FD1	8410 675332	GALINA ANISIMOVA	{"email": "ganisimova29061972@postgrespro.ru", "phone": "+70288807003"}
0005434600666	690958	1843 189733	ALEKSEY NOVIKOV	{"email": "aleksey.novikov_19041975@postgrespro.ru", "phone": "+70276399169"}
0005434600667	A87BE6	1647 955952	ANATOLIY VLASOV	{"phone": "+70172400183"}
0005434600668	340265	1629 779356	DANIL VLASOV	{"email": "vlasovd-24101975@postgrespro.ru", "phone": "+70072397235"}
0005434600669	79F073	1256 591132	VALENTINA KUZNECOVA	{"email": "kuznecova-valentina-1967@postgrespro.ru", "phone": "+70639934471"}
0005434600670	B83798	2756 126766	VITALIY TIMOFEEV	{"phone": "+70963023860"}
0005434600671	B83798	1192 782235	VLADIMIR MIRONOV	{"phone": "+70822317284"}
0005434600672	835F7F	6074 368573	TATYANA ZHUKOVA	{"phone": "+70383227937"}
0005434600673	D2A6E3	8755 703214	KRISTINA NIKITINA	{"phone": "+70232211176"}
0005434600674	9072CB	4912 210483	ILDAR DAVYDOV	{"phone": "+70309126398"}
0005434600675	6AD8B2	1288 837543	RITA ANDREEVA	{"email": "rita.andreeva031956@postgrespro.ru", "phone": "+70686210189"}
0005434600676	B707DC	2420 110754	SERGEY IVANOV	{"email": "ivanov_sergey.071981@postgrespro.ru", "phone": "+70596723834"}
0005434600677	B707DC	4937 890637	LYUBOV VASILEVA	{"email": "vasileva-lyubov_021970@postgrespro.ru", "phone": "+70760573973"}
0005434600678	D67ACB	6251 616565	SVETLANA YAKOVLEVA	{"phone": "+70899509791"}
0005434600679	D67ACB	6167 415431	NIKOLAY GAVRILOV	{"email": "ngavrilov_1966@postgrespro.ru", "phone": "+70546637843"}
0005434600680	18ADF7	3701 003968	YULIYA ILINA	{"email": "ilina_y-22071972@postgrespro.ru", "phone": "+70771039324"}
0005434600681	18ADF7	8743 631834	ROBERT KISELEV	{"email": "r-kiselev-02071969@postgrespro.ru", "phone": "+70015616102"}
0005434600682	51AA65	9393 650611	ALEKSEY KUZNECOV	{"phone": "+70831049317"}
0005434600683	878B6E	1421 330538	TIMOFEY ZHURAVLEV	{"phone": "+70762579392"}
0005434600684	878B6E	9411 404396	DIANA LAZAREVA	{"phone": "+70049551098"}
0005434600685	878B6E	6264 072965	ARKADIY IVANOV	{"email": "arkadiy_ivanov081973@postgrespro.ru", "phone": "+70089734654"}
0005434600686	E6BE66	2992 391854	RAFAIL AFANASEV	{"phone": "+70194418875"}
0005434600687	E6BE66	4657 008523	VIKTOR YAKOVLEV	{"email": "viktor_yakovlev.031984@postgrespro.ru", "phone": "+70034766984"}
0005434600688	FA53B5	1789 917284	OLGA MOROZOVA	{"phone": "+70027023488"}
0005434600689	423A4F	8401 538529	SVETLANA TARASOVA	{"email": "s_tarasova-18041969@postgrespro.ru", "phone": "+70649519094"}
0005434600690	56E556	8617 357689	LILIYA KRASNOVA	{"phone": "+70893253908"}
0005434600691	56E556	4171 718692	VLADIMIR KRASNOV	{"email": "vladimir.krasnov-31081968@postgrespro.ru", "phone": "+70561726956"}
0005434600692	DF41B6	8059 381788	RUSTAM KUZMIN	{"phone": "+70952668611"}
0005434600693	96E9F8	6988 786158	ALEKSANDR VLASOV	{"email": "vlasov-a-121983@postgrespro.ru", "phone": "+70612016507"}
0005434600694	96E9F8	2062 635519	OLEG MEDVEDEV	{"phone": "+70941174650"}
0005434600695	0B12F5	8544 532392	GALINA CHERNOVA	{"email": "g.chernova_25091967@postgrespro.ru", "phone": "+70691459478"}
0005434600696	0B12F5	0603 721185	YAROSLAV VOLKOV	{"email": "volkov-yaroslav051975@postgrespro.ru", "phone": "+70568176182"}
0005434600697	8D161D	9214 222903	ANASTASIYA GUSEVA	{"email": "guseva-a.13021971@postgrespro.ru", "phone": "+70172715376"}
0005434600698	8D161D	4722 522803	ALEKSANDR BORISOV	{"email": "aborisov_1966@postgrespro.ru", "phone": "+70465054023"}
0005434600699	514FFE	1751 952558	ANDREY POPOV	{"phone": "+70037628436"}
0005434600700	514FFE	6067 538324	YULIYA TITOVA	{"phone": "+70794358589"}
0005434600701	93C3FC	2242 260157	ALEKSEY ZAYCEV	{"email": "zaycev-a.1974@postgrespro.ru", "phone": "+70109730234"}
0005434600702	93C3FC	8163 605042	KSENIYA SEMENOVA	{"phone": "+70146158631"}
0005434600703	600C01	4371 460262	SERGEY MOROZOV	{"email": "sergeymorozov1980@postgrespro.ru", "phone": "+70936884731"}
0005434600704	600C01	3131 308482	VASILIY VLASOV	{"phone": "+70514330690"}
0005434600705	6D0C54	4025 520655	ELENA KUZNECOVA	{"email": "kuznecovae_23111970@postgrespro.ru", "phone": "+70583626435"}
0005434600706	6D0C54	8487 238579	MIKHAIL ROMANOV	{"email": "m-romanov.22071977@postgrespro.ru", "phone": "+70101252097"}
0005434600707	C5CEE9	1562 942811	NELLI FEDOROVA	{"email": "n-fedorova.1976@postgrespro.ru", "phone": "+70774332656"}
0005434600708	C5CEE9	7158 594543	FANIYA SOROKINA	{"email": "faniya_sorokina-18011963@postgrespro.ru", "phone": "+70741206563"}
0005434600709	458A1A	8331 583051	VLADIMIR DMITRIEV	{"phone": "+70425715475"}
0005434600710	01FA48	8613 941611	NINA FROLOVA	{"email": "frolova-nina021974@postgrespro.ru", "phone": "+70774908875"}
0005434600711	7C4CC8	1883 689618	ELENA NIKOLAEVA	{"phone": "+70892880842"}
0005434600712	7C4CC8	8961 491479	IVAN MOROZOV	{"phone": "+70177937797"}
0005434600713	D1AF42	8952 871438	YURIY GERASIMOV	{"phone": "+70249373708"}
0005434600714	91058D	9236 129759	MIKHAIL GRIGOREV	{"email": "grigorev_mikhail-05091979@postgrespro.ru", "phone": "+70046334618"}
0005434600715	7653B3	6704 682460	SVETLANA GORBUNOVA	{"email": "svetlana-gorbunova-1980@postgrespro.ru", "phone": "+70749293900"}
0005434600716	08838F	3232 713582	ANDREY SAVELEV	{"phone": "+70494948352"}
0005434600717	145B02	4789 169404	VERONIKA KOZLOVA	{"email": "v_kozlova.1970@postgrespro.ru", "phone": "+70905323005"}
0005434600718	145B02	6673 656307	ROZALIYA YAKOVLEVA	{"phone": "+70793469083"}
0005434600719	17C63C	3737 011772	ALEKSANDR MAKSIMOV	{"phone": "+70212220108"}
0005434600720	24EDC5	3511 085999	ANTONINA SAVELEVA	{"email": "saveleva-a_27011964@postgrespro.ru", "phone": "+70968126243"}
0005434600721	24EDC5	9866 610309	NATALYA NIKIFOROVA	{"email": "nikiforovanatalya-29121973@postgrespro.ru", "phone": "+70316613169"}
0005434600722	6C625E	6698 744568	NATALYA PAVLOVA	{"phone": "+70397465986"}
0005434600723	708384	4390 831853	OLGA NIKOLAEVA	{"phone": "+70705133644"}
0005434600724	F35180	7396 745385	YURIY NIKOLAEV	{"email": "y.nikolaev_01021966@postgrespro.ru", "phone": "+70856731867"}
0005434600725	79193B	9114 736409	YURIY MOISEEV	{"phone": "+70929177323"}
0005434600726	79193B	1178 352868	VALENTINA SERGEEVA	{"phone": "+70597119274"}
0005434600727	F0F79C	4021 343479	NATALYA FROLOVA	{"email": "natalya-frolova.1974@postgrespro.ru", "phone": "+70434598586"}
0005434600728	F0F79C	1284 468595	VALERIYA KUZNECOVA	{"phone": "+70015404392"}
0005434600729	F0F79C	5112 867146	ALEKSANDR ANTONOV	{"phone": "+70556906471"}
0005434600730	12EE45	6441 082221	DMITRIY STEPANOV	{"phone": "+70921112512"}
0005434600731	832714	9424 702728	VIKTOR OSIPOV	{"phone": "+70575357122"}
0005434600732	C0C598	6337 570062	EKATERINA ANDREEVA	{"email": "e.andreeva_041972@postgrespro.ru", "phone": "+70070002513"}
0005434600733	EBD235	5809 410982	OLGA EFREMOVA	{"phone": "+70872232704"}
0005434600734	81E3D5	9744 363510	NATALYA DAVYDOVA	{"email": "natalyadavydova-31031970@postgrespro.ru", "phone": "+70591522962"}
0005434600735	D2C3A4	0320 401701	ALINA ILINA	{"email": "alina-ilina_25031973@postgrespro.ru", "phone": "+70993545369"}
0005434600736	F2C581	2603 460226	OLGA DMITRIEVA	{"email": "dmitrieva_olga.1980@postgrespro.ru", "phone": "+70258641642"}
0005434600737	F2C581	1535 524775	RAISA SEMENOVA	{"email": "rsemenova_111977@postgrespro.ru", "phone": "+70491926430"}
0005434600738	982F5B	8147 883945	TATYANA KUZNECOVA	{"email": "tkuznecova1981@postgrespro.ru", "phone": "+70622424681"}
0005434600739	08ACB9	4239 444509	ELENA ZHURAVLEVA	{"phone": "+70293728320"}
0005434600740	08ACB9	1342 732612	NIKOLAY SHEVCHENKO	{"email": "nikolay.shevchenko1965@postgrespro.ru", "phone": "+70788227368"}
0005434600741	5461AF	0388 366795	GALINA GRISHINA	{"email": "galinagrishina03061960@postgrespro.ru", "phone": "+70131133063"}
0005434600742	1A92AA	5324 516493	IRINA KUZMINA	{"phone": "+70384475721"}
0005434600743	D179A3	7272 451954	ALEKSANDR RODIONOV	{"phone": "+70299966802"}
0005434600744	EE4406	0607 259260	PAVEL ORLOV	{"email": "pavel_orlov.02111965@postgrespro.ru", "phone": "+70210988026"}
0005434600745	7F8E43	9721 895267	KLAVDIYA EFIMOVA	{"email": "efimova-klavdiya-15031971@postgrespro.ru", "phone": "+70781021533"}
0005434600746	B17AC4	9884 862438	ARTEM PETROV	{"email": "artempetrov.06101979@postgrespro.ru", "phone": "+70804525209"}
0005434600747	63C131	5136 170247	IRINA TIKHONOVA	{"phone": "+70194516036"}
0005434600748	4545F6	8399 140462	VLADIMIR VOROBEV	{"email": "vvorobev-28111965@postgrespro.ru", "phone": "+70430942786"}
0005434600749	0F6764	3718 272389	KSENIYA BELYAEVA	{"phone": "+70153621049"}
0005434600750	0F6764	9621 019874	SERGEY GERASIMOV	{"phone": "+70777923106"}
0005434600751	4D9B2A	6780 351504	VYACHESLAV MATVEEV	{"phone": "+70301119816"}
0005434600752	4D9B2A	5964 403962	GENNADIY PAVLOV	{"phone": "+70932445367"}
0005434600753	FD4DF9	8443 560603	BORIS ZAKHAROV	{"email": "zakharov.boris_051967@postgrespro.ru", "phone": "+70330616119"}
0005434600754	A543BC	3939 511606	LYUBOV KUZNECOVA	{"phone": "+70852242999"}
0005434600755	FAAC7F	8937 953006	VLADIMIR VASILEV	{"phone": "+70406969049"}
0005434600756	E79292	7752 485477	ANDREY VASILEV	{"phone": "+70972668632"}
0005434600757	E79292	7643 508377	LYUBOV DENISOVA	{"email": "l_denisova.1976@postgrespro.ru", "phone": "+70112043179"}
0005434600758	11F858	5490 870064	ELENA ALEKSANDROVA	{"email": "elena-aleksandrova.081963@postgrespro.ru", "phone": "+70016220472"}
0005434600759	78E507	7403 809728	VLADISLAV ALEKSEEV	{"phone": "+70042882403"}
0005434600760	392F88	2233 246719	DMITRIY POPOV	{"phone": "+70036273712"}
0005434600761	1EB2B3	9749 789435	VIOLETTA KOVALEVA	{"email": "kovalevav-13071977@postgrespro.ru", "phone": "+70334310416"}
0005434600762	FEA5F2	6854 572250	RIMMA STEPANOVA	{"email": "rstepanova-17121964@postgrespro.ru", "phone": "+70065197606"}
0005434600763	8F178F	7722 212637	NADEZHDA FOMINA	{"email": "nadezhda-fomina-081979@postgrespro.ru", "phone": "+70237867279"}
0005434600764	F7FE3A	0703 540699	GALINA SIDOROVA	{"phone": "+70856768493"}
0005434600765	785A5F	2759 810915	ALEKSANDR IVANOV	{"phone": "+70702674388"}
0005434600766	6E6DDB	7803 456854	ANATOLIY KONOVALOV	{"phone": "+70077663534"}
0005434600767	1CEEBC	6956 352487	TATYANA TIMOFEEVA	{"phone": "+70100382939"}
0005434600768	4EFC2A	7178 201205	NATALYA PETROVA	{"email": "petrovanatalya1976@postgrespro.ru", "phone": "+70480812443"}
0005434600769	C0C778	2191 476659	NATALYA POPOVA	{"email": "popovanatalya-1964@postgrespro.ru", "phone": "+70052018823"}
0005434600770	C75D56	7944 762097	IRINA KUZMINA	{"phone": "+70041562655"}
0005434600771	C75D56	3641 085266	MARIYA SIDOROVA	{"phone": "+70844345883"}
0005434600772	27CF64	1920 798944	EKATERINA ALEKSEEVA	{"phone": "+70598769524"}
0005434600773	7C8F17	0682 437851	ANDREY KRASNOV	{"email": "krasnov-andrey111978@postgrespro.ru", "phone": "+70083623170"}
0005434600774	BD8148	3034 177273	SOFYA SEMENOVA	{"phone": "+70565101503"}
0005434600775	C8F43C	5497 062096	ALENA IVANOVA	{"email": "alena.ivanova28011965@postgrespro.ru", "phone": "+70750767718"}
0005434600776	F60347	4341 672441	ANASTASIYA VASILEVA	{"email": "a_vasileva17121971@postgrespro.ru", "phone": "+70161977718"}
0005434600777	460321	2928 059823	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev.1961@postgrespro.ru", "phone": "+70903404085"}
0005434600778	460321	6252 491573	VERA GORBUNOVA	{"email": "gorbunovavera-011980@postgrespro.ru", "phone": "+70054578166"}
0005434600779	8AB192	0200 655728	LYUBOV TROFIMOVA	{"email": "trofimova.l.02011977@postgrespro.ru", "phone": "+70500200899"}
0005434600780	8AB192	0297 673518	VIKTOR ZHURAVLEV	{"phone": "+70866099092"}
0005434600781	41FA52	4458 123926	LADA BORISOVA	{"email": "borisova-lada-30051984@postgrespro.ru", "phone": "+70043148554"}
0005434600782	6D78D0	2428 823760	IVAN GAVRILOV	{"email": "ivan-gavrilov-011975@postgrespro.ru", "phone": "+70084428965"}
0005434600783	6D78D0	3297 796866	VIKTOR MARTYNOV	{"email": "martynov.v-15111964@postgrespro.ru", "phone": "+70355475270"}
0005434600784	0AED5B	4655 999953	NIKOLAY STEPANOV	{"email": "nstepanov_31071968@postgrespro.ru", "phone": "+70059081649"}
0005434600785	0AED5B	0357 561593	SVETLANA NAZAROVA	{"phone": "+70315378665"}
0005434600786	7F6587	3547 623250	ELENA ROMANOVA	{"phone": "+70985327747"}
0005434600787	26B47D	7610 955633	EVGENIY VOROBEV	{"phone": "+70142160095"}
0005434600788	876113	3333 517435	GALINA VOLKOVA	{"email": "volkovagalina1961@postgrespro.ru", "phone": "+70676554012"}
0005434600789	67D3A4	4514 878985	MIKHAIL POPOV	{"email": "m_popov-1965@postgrespro.ru", "phone": "+70630253305"}
0005434600790	B5ADD3	4334 129969	ANNA VOLKOVA	{"email": "anna.volkova_20031975@postgrespro.ru", "phone": "+70792177597"}
0005434600791	5D74CA	4887 039330	KONSTANTIN BELOV	{"email": "k-belov1980@postgrespro.ru", "phone": "+70587823824"}
0005434600792	C38C9E	9348 641622	ELENA KUZMINA	{"email": "kuzmina_elena_051978@postgrespro.ru", "phone": "+70206947386"}
0005434600793	C38C9E	8769 610824	VASILIY ORLOV	{"phone": "+70128516335"}
0005434600794	C38C9E	2256 299311	SERGEY MOISEEV	{"email": "moiseev.s.1972@postgrespro.ru", "phone": "+70867128151"}
0005434600795	875216	8422 921894	ALEKSEY PETROV	{"phone": "+70262765094"}
0005434600796	BD39F1	9222 880522	NATALYA SERGEEVA	{"phone": "+70283519794"}
0005434600797	BD39F1	0157 705610	ANNA KUDRYASHOVA	{"phone": "+70558210048"}
0005434600798	D96138	5160 457442	MIKHAIL MIKHAYLOV	{"email": "mikhail.mikhaylov-1961@postgrespro.ru", "phone": "+70913004004"}
0005434600799	5D72CC	3023 811530	MARIYA ZOTOVA	{"phone": "+70764990535"}
0005434600800	8502A7	4046 427492	MIKHAIL KARPOV	{"phone": "+70780195401"}
0005434600801	764BE5	6514 066179	VIKTOR EGOROV	{"phone": "+70010750276"}
0005434600802	2EA35E	5626 836297	NATALYA ARKHIPOVA	{"phone": "+70535586162"}
0005434600803	6F39DD	7524 216610	IVAN ANDREEV	{"phone": "+70811993387"}
0005434600804	6F39DD	8054 425167	SAMVEL ANDREEV	{"phone": "+70770234414"}
0005434600805	4191DA	8927 933684	GALINA MASLOVA	{"email": "maslova-g-1975@postgrespro.ru", "phone": "+70561850441"}
0005434600806	C567F0	8932 646360	IGNAT PETROV	{"email": "petrov_ignat-1973@postgrespro.ru", "phone": "+70919724569"}
0005434600807	B07C13	3723 018906	YULIYA MARTYNOVA	{"phone": "+70129485262"}
0005434600808	B07C13	6842 630834	ANZHELA NIKITINA	{"email": "nikitina-anzhela1980@postgrespro.ru", "phone": "+70747383798"}
0005434600809	258513	3392 199371	VERA KUZNECOVA	{"email": "kuznecova_vera_071971@postgrespro.ru", "phone": "+70013694081"}
0005434600810	258513	5004 383241	NATALYA ANDREEVA	{"phone": "+70695395217"}
0005434600811	2B69CC	0171 582205	MIKHAIL NAZAROV	{"email": "nazarovmikhail-01111971@postgrespro.ru", "phone": "+70132079299"}
0005434600812	0D4B1A	4927 087278	ELENA ANDREEVA	{"email": "andreeva.e.27041967@postgrespro.ru", "phone": "+70075899584"}
0005434600813	595D24	5734 669439	NATALYA KOROLEVA	{"email": "nkoroleva1971@postgrespro.ru", "phone": "+70659231675"}
0005434600814	595D24	8077 811355	DENIS AFANASEV	{"phone": "+70313302642"}
0005434600815	EB0812	7315 582741	OLESYA NIKOLAEVA	{"email": "nikolaevaolesya_25021971@postgrespro.ru", "phone": "+70372082677"}
0005434600816	EB0812	6762 258207	VIKTOR ANTONOV	{"phone": "+70040470107"}
0005434600817	957325	7961 583852	VALERIY SCHERBAKOV	{"email": "v_scherbakov121972@postgrespro.ru", "phone": "+70005804123"}
0005434600818	957325	0651 812736	NADEZHDA ERMAKOVA	{"phone": "+70768629899"}
0005434600819	957325	5985 597587	ANATOLIY KAZAKOV	{"email": "kazakov-anatoliy.1982@postgrespro.ru", "phone": "+70966468158"}
0005434600820	E748A5	0384 255993	ALEKSEY MIKHAYLOV	{"phone": "+70239937162"}
0005434600821	34AEC4	0339 105975	MIKHAIL STEPANOV	{"email": "m-stepanov.061973@postgrespro.ru", "phone": "+70759863700"}
0005434600822	11B8A2	1472 095648	OLEG MELNIKOV	{"email": "o_melnikov091970@postgrespro.ru", "phone": "+70173364420"}
0005434600823	EC031C	2432 063399	LYUDMILA KUDRYASHOVA	{"phone": "+70105824811"}
0005434600824	EC031C	3221 440934	DENIS SHEVCHENKO	{"email": "d_shevchenko-031978@postgrespro.ru", "phone": "+70107370744"}
0005434600825	F19D4B	7801 895838	INNA ZHURAVLEVA	{"phone": "+70752047083"}
0005434600826	24042C	4024 762021	GALINA FADEEVA	{"email": "g-fadeeva-071979@postgrespro.ru", "phone": "+70995887319"}
0005434600827	430D23	3573 738983	STANISLAV TIMOFEEV	{"email": "timofeev-stanislav.25081982@postgrespro.ru", "phone": "+70365004189"}
0005434600828	430D23	9462 021769	YURIY KAZAKOV	{"email": "kazakov-yuriy-1967@postgrespro.ru", "phone": "+70614687872"}
0005434600829	6939B2	4541 106295	GENNADIY KUZNECOV	{"email": "kuznecov.g.25041971@postgrespro.ru", "phone": "+70745816178"}
0005434600830	BE8927	8732 099753	VLADIMIR OSIPOV	{"email": "osipov-vladimir-25021970@postgrespro.ru", "phone": "+70153633776"}
0005434600831	71DE59	4023 546073	MARGARITA NIKOLAEVA	{"email": "nikolaevam-041978@postgrespro.ru", "phone": "+70098541314"}
0005434600832	E838EF	7691 245173	VALENTINA STEPANOVA	{"phone": "+70866176478"}
0005434600833	E838EF	6883 350003	ALEKSANDR ROMANOV	{"email": "a-romanov-14021963@postgrespro.ru", "phone": "+70520855219"}
0005434600834	E838EF	3943 265559	SVETLANA VASILEVA	{"email": "svetlana-vasileva_011965@postgrespro.ru", "phone": "+70760595509"}
0005434600835	982B1A	9457 709055	ALENA SOROKINA	{"phone": "+70538394203"}
0005434600836	982B1A	4602 921853	VLADISLAV ANDREEV	{"phone": "+70041895784"}
0005434600837	6C2308	2129 720395	MARINA KONOVALOVA	{"phone": "+70347452826"}
0005434600838	6C2308	2787 496528	PETR DENISOV	{"phone": "+70556893816"}
0005434600839	91B276	5574 031843	EVGENIY MIRONOV	{"email": "emironov.16031985@postgrespro.ru", "phone": "+70575888734"}
0005434600840	91B276	0983 464229	IVAN PAVLOV	{"phone": "+70501316826"}
0005434600841	91B276	7061 208343	SERGEY SIDOROV	{"email": "sidorov.sergey-03081980@postgrespro.ru", "phone": "+70374771575"}
0005434600842	89C93F	5761 787089	ARTEM KOROLEV	{"email": "korolev-a13101965@postgrespro.ru", "phone": "+70978593830"}
0005434600843	F7971B	5618 739391	LYUBOV KOROLEVA	{"phone": "+70710654796"}
0005434600844	836805	4224 805807	PETR MELNIKOV	{"email": "melnikov_petr111981@postgrespro.ru", "phone": "+70915170079"}
0005434600845	836805	8360 118049	NATALYA PAVLOVA	{"phone": "+70876643810"}
0005434600846	C1C135	9180 763771	ELENA IVANOVA	{"email": "e.ivanova_031977@postgrespro.ru", "phone": "+70243982841"}
0005434600847	C1C135	4105 599381	ANASTASIYA BELOVA	{"email": "belova_anastasiya.1965@postgrespro.ru", "phone": "+70932765841"}
0005434600848	74123B	2609 858747	KONSTANTIN MAKAROV	{"email": "makarov.k.1977@postgrespro.ru", "phone": "+70943935937"}
0005434600849	85D960	4644 840933	SVETLANA VASILEVA	{"phone": "+70721085931"}
0005434600850	E99D00	3436 800690	NATALYA LAZAREVA	{"phone": "+70937409068"}
0005434600851	996B0A	6241 212289	ALEKSANDR SHEVCHENKO	{"phone": "+70125715259"}
0005434600852	0A7D4C	1849 642656	OLESYA OVCHINNIKOVA	{"email": "ovchinnikova_o.14051975@postgrespro.ru", "phone": "+70178390695"}
0005434600853	20DA6B	6230 492940	LYUBOV MELNIKOVA	{"email": "l.melnikova.07011985@postgrespro.ru", "phone": "+70951009208"}
0005434600854	66EE87	0842 679375	TAMARA MAKSIMOVA	{"email": "maksimova_tamara1967@postgrespro.ru", "phone": "+70994678141"}
0005434600855	F6B0BA	0610 982699	MIKHAIL SERGEEV	{"email": "sergeev-m-1978@postgrespro.ru", "phone": "+70980577479"}
0005434600856	22D670	4622 289198	IVAN IVANOV	{"phone": "+70204235017"}
0005434600857	D21301	0637 014248	SERGEY NAZAROV	{"phone": "+70127381654"}
0005434600858	D4E504	5338 268953	SVETLANA IVANOVA	{"email": "s.ivanova-28111977@postgrespro.ru", "phone": "+70053698214"}
0005434600859	D4E504	6604 843162	EKATERINA KOZLOVA	{"email": "kozlova_e.1962@postgrespro.ru", "phone": "+70390887252"}
0005434600860	2B78F0	1257 476358	ANTONINA PAVLOVA	{"phone": "+70607503738"}
0005434600861	2B78F0	6873 874784	DMITRIY STEPANOV	{"phone": "+70589958228"}
0005434600862	2B78F0	0197 015551	KONSTANTIN ZHUKOV	{"phone": "+70785419887"}
0005434600863	2B78F0	2148 898130	VLADIMIR MELNIKOV	{"email": "v.melnikov.1972@postgrespro.ru", "phone": "+70773914797"}
0005434600864	FFC5BA	8884 421323	IRINA MOROZOVA	{"email": "morozova-irina16071971@postgrespro.ru", "phone": "+70302148162"}
0005434600865	6F9B72	9411 686765	KSENIYA KUZNECOVA	{"email": "kuznecova.k061974@postgrespro.ru", "phone": "+70130490082"}
0005434600866	870374	4538 887862	ANDREY TIMOFEEV	{"email": "a_timofeev1977@postgrespro.ru", "phone": "+70884502752"}
0005434600867	870374	9331 894227	SERGEY GAVRILOV	{"phone": "+70917763228"}
0005434600868	232277	8272 739969	SERGEY ABRAMOV	{"phone": "+70704923431"}
0005434600869	0071AE	9833 337164	NATALIYA BELYAEVA	{"phone": "+70175830154"}
0005434600870	C2DF48	8416 763216	EVGENIY SCHERBAKOV	{"email": "scherbakov-evgeniy.28021969@postgrespro.ru", "phone": "+70834474840"}
0005434600871	71EA34	7641 515747	SERGEY SERGEEV	{"email": "sergeev.s-09111968@postgrespro.ru", "phone": "+70241608852"}
0005434600872	EBFA9A	4843 161541	TATYANA NIKIFOROVA	{"phone": "+70317831524"}
0005434600873	78F71D	2542 341735	GALINA GORBUNOVA	{"email": "g.gorbunova.30031973@postgrespro.ru", "phone": "+70476726014"}
0005434600874	78F71D	7816 070740	ALEKSANDR GUSEV	{"phone": "+70813077426"}
0005434600875	78F71D	8532 691979	VERA SIDOROVA	{"phone": "+70591289948"}
0005434600876	D6DC6A	0980 690896	ANNA TARASOVA	{"email": "atarasova081981@postgrespro.ru", "phone": "+70973560807"}
0005434600877	38A8D6	5672 824054	VITALIY ABRAMOV	{"email": "abramovvitaliy_101976@postgrespro.ru", "phone": "+70272777457"}
0005434600878	DD2683	5250 786880	OKSANA EGOROVA	{"phone": "+70843347967"}
0005434600879	DD2683	2831 223430	ALEKSANDR ZAKHAROV	{"phone": "+70348898848"}
0005434600880	1269A6	9966 829607	OLESYA GAVRILOVA	{"phone": "+70268110433"}
0005434600881	9C8EAF	0662 666131	ALEKSANDR GUSEV	{"phone": "+70124720558"}
0005434600882	9C8EAF	7634 654496	FEDOR ALEKSEEV	{"phone": "+70533600161"}
0005434600883	EB12E7	1549 086264	MARIYA AFANASEVA	{"phone": "+70835747767"}
0005434600884	73FC04	6182 308782	VIKTOR SHEVCHENKO	{"email": "shevchenko_v.031963@postgrespro.ru", "phone": "+70246349091"}
0005434600885	AFF670	2244 914967	VLADIMIR ISAEV	{"email": "visaev_1985@postgrespro.ru", "phone": "+70890610182"}
0005434600886	AFF670	5579 798258	SVETLANA POPOVA	{"phone": "+70179456489"}
0005434600887	AFF670	6378 412808	MAKSIM ZHURAVLEV	{"phone": "+70423966928"}
0005434600888	507B69	9687 113007	NELLI DANILOVA	{"email": "n_danilova_04081967@postgrespro.ru", "phone": "+70895807724"}
0005434600889	507B69	9559 558720	ROMAN PAVLOV	{"email": "pavlov-r10081970@postgrespro.ru", "phone": "+70750424266"}
0005434600890	F67C84	1357 893852	DENIS NOVIKOV	{"email": "novikov_denis_1961@postgrespro.ru", "phone": "+70921550365"}
0005434600891	7EA747	9750 322839	VLADISLAV KUZNECOV	{"phone": "+70369345826"}
0005434600892	D568B5	6439 583705	ELIZAVETA POLYAKOVA	{"email": "polyakova-elizaveta071969@postgrespro.ru", "phone": "+70871682146"}
0005434600893	4AEB37	6287 185781	TATYANA MAKAROVA	{"email": "makarovat-29031980@postgrespro.ru", "phone": "+70636450515"}
0005434600894	4AEB37	2522 041958	VALENTINA FADEEVA	{"phone": "+70396102287"}
0005434600895	D2681D	3312 205275	DENIS ROMANOV	{"email": "d-romanov_1977@postgrespro.ru", "phone": "+70101027451"}
0005434600896	D2681D	2803 932960	MIKHAIL NOVIKOV	{"phone": "+70847316229"}
0005434600897	9A7FB6	8926 219785	IVAN KOZLOV	{"phone": "+70119878633"}
0005434600898	9A7FB6	5461 770308	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr_25091972@postgrespro.ru", "phone": "+70369627833"}
0005434600899	51FCA3	6484 536172	OLGA MELNIKOVA	{"email": "olgamelnikova_101959@postgrespro.ru", "phone": "+70670272438"}
0005434600900	D2E7D2	3266 716451	TAMARA KOROLEVA	{"email": "korolevat_1970@postgrespro.ru", "phone": "+70176460478"}
0005434600901	F649AF	4707 839043	VLADISLAV NAZAROV	{"phone": "+70198445937"}
0005434600902	323C6A	0295 070658	MARINA SOKOLOVA	{"phone": "+70900846316"}
0005434600903	323C6A	5176 547554	SVETLANA KUZNECOVA	{"phone": "+70425874274"}
0005434601142	7CD744	6373 162117	VALENTINA IVANOVA	{"phone": "+70953220252"}
0005434600904	4BDA75	2425 951357	YANA KULIKOVA	{"email": "kulikova.y.071965@postgrespro.ru", "phone": "+70482881512"}
0005434600905	4BDA75	8758 652886	GALIYA FEDOROVA	{"phone": "+70644281443"}
0005434600906	4BDA75	8520 221931	MAKSIM FEDOROV	{"email": "maksim_fedorov-1973@postgrespro.ru", "phone": "+70188219562"}
0005434600907	D43E07	3373 999799	VLADIMIR KOZLOV	{"email": "vladimir_kozlov-1975@postgrespro.ru", "phone": "+70717420644"}
0005434600908	C9B0DE	4954 773959	TATYANA ISAEVA	{"email": "t-isaeva.1973@postgrespro.ru", "phone": "+70858509700"}
0005434600909	C9B0DE	7921 728192	NATALYA NIKOLAEVA	{"phone": "+70085722959"}
0005434600910	D76C33	4001 492561	LIDIYA KULIKOVA	{"email": "kulikova.lidiya22071966@postgrespro.ru", "phone": "+70213543118"}
0005434600911	967A28	1375 488414	TAMARA SERGEEVA	{"email": "sergeeva-tamara-1975@postgrespro.ru", "phone": "+70403342953"}
0005434600912	FC35D8	3213 274944	ALEKSEY ZAKHAROV	{"phone": "+70061273757"}
0005434600913	CAE39E	5028 331447	VIKTOR AFANASEV	{"email": "v_afanasev.091964@postgrespro.ru", "phone": "+70675331675"}
0005434600914	F7B49B	3506 586762	LYUDMILA NOVIKOVA	{"email": "novikova.l081957@postgrespro.ru", "phone": "+70752781317"}
0005434600915	388AAD	5950 184444	BORIS ABRAMOV	{"email": "abramov_boris.021971@postgrespro.ru", "phone": "+70246017553"}
0005434600916	9B1271	5111 881424	GENNADIY GRIGOREV	{"phone": "+70539811664"}
0005434600917	3C07B3	8033 406059	NINA LEBEDEVA	{"email": "lebedevan-1971@postgrespro.ru", "phone": "+70693517266"}
0005434600918	A24EA5	8836 964753	ELENA LEBEDEVA	{"email": "e-lebedeva_1970@postgrespro.ru", "phone": "+70059719486"}
0005434600919	A24EA5	3098 755772	GENNADIY KUZNECOV	{"email": "g-kuznecov29081966@postgrespro.ru", "phone": "+70959135714"}
0005434600920	6D203D	1732 311465	DARYA BARANOVA	{"phone": "+70423131798"}
0005434600921	809918	5393 886787	EVGENIY SCHERBAKOV	{"email": "scherbakov_e_051997@postgrespro.ru", "phone": "+70152887922"}
0005434600922	BF61CE	6848 113583	SVETLANA KONOVALOVA	{"email": "s.konovalova1973@postgrespro.ru", "phone": "+70905216167"}
0005434600923	B3285A	7488 031059	EVGENIYA NESTEROVA	{"email": "evgeniyanesterova-021974@postgrespro.ru", "phone": "+70619348376"}
0005434600924	F5D603	8405 421113	VALENTINA DENISOVA	{"phone": "+70160595099"}
0005434600925	E126FF	6822 967260	EKATERINA SERGEEVA	{"phone": "+70312394310"}
0005434600926	9F4928	1229 643963	IRINA FADEEVA	{"email": "fadeevairina-071984@postgrespro.ru", "phone": "+70882517464"}
0005434600927	9F4928	9757 987830	ANASTASIYA KUZNECOVA	{"phone": "+70607206144"}
0005434600928	0EF001	4112 003026	LIDIYA ISAEVA	{"email": "l_isaeva_23041989@postgrespro.ru", "phone": "+70819251104"}
0005434600929	5E4DF6	1443 767047	TATYANA KARPOVA	{"phone": "+70354243469"}
0005434600930	943585	9940 939163	NATALYA ROMANOVA	{"email": "n-romanova-08011971@postgrespro.ru", "phone": "+70662178478"}
0005434600931	662DF1	1754 254012	DMITRIY ZAKHAROV	{"phone": "+70828402334"}
0005434600932	662DF1	8036 276869	IVAN PAVLOV	{"email": "pavlov-ivan_27111977@postgrespro.ru", "phone": "+70336306058"}
0005434600933	9F20DA	2879 393825	STANISLAV BELOV	{"phone": "+70559156701"}
0005434600934	9F20DA	5698 019362	GALINA ILINA	{"email": "ilina_galina1981@postgrespro.ru", "phone": "+70342769794"}
0005434600935	3984B9	7139 674496	SVETLANA KUDRYASHOVA	{"phone": "+70733329813"}
0005434600936	3984B9	0003 467827	NINA NOVIKOVA	{"email": "ninanovikova_13071985@postgrespro.ru", "phone": "+70430022773"}
0005434600937	6323E1	4838 086429	ELENA ZAYCEVA	{"email": "zayceva-elena-11031981@postgrespro.ru", "phone": "+70829091988"}
0005434600938	1B08B7	9689 346264	ALEKSEY IVANOV	{"email": "aivanov-071982@postgrespro.ru", "phone": "+70341441052"}
0005434600939	1B08B7	9438 263638	NINA KALININA	{"email": "kalinina.nina_1957@postgrespro.ru", "phone": "+70772775390"}
0005434600940	4AA392	7096 659881	ANATOLIY SERGEEV	{"phone": "+70697513441"}
0005434600941	4AA392	8898 898343	VLADIMIR KOZLOV	{"email": "vkozlov.22041971@postgrespro.ru", "phone": "+70690094215"}
0005434600942	56D0A0	7631 767678	PAVEL POPOV	{"phone": "+70049700187"}
0005434600943	56D0A0	3810 113728	IRAIDA POLYAKOVA	{"phone": "+70223600124"}
0005434600944	85DC25	8396 328401	ANDREY IVANOV	{"phone": "+70383188385"}
0005434600945	85DC25	9650 056166	ANTON SAVELEV	{"phone": "+70689284826"}
0005434600946	978AC8	5210 764037	LYUDMILA TIKHONOVA	{"email": "lyudmila-tikhonova.1967@postgrespro.ru", "phone": "+70659231929"}
0005434600947	EF467C	9087 913092	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev_1969@postgrespro.ru", "phone": "+70201959055"}
0005434600948	9E6963	9600 761255	SERGEY SOLOVEV	{"email": "s-solovev.1970@postgrespro.ru", "phone": "+70244981549"}
0005434600949	2438C2	3281 095093	ANATOLIY AFANASEV	{"email": "afanasev_a-011968@postgrespro.ru", "phone": "+70507607952"}
0005434600950	B173D1	9310 671992	ALEKSANDR PETROV	{"email": "petrov-aleksandr-03121969@postgrespro.ru", "phone": "+70572003219"}
0005434600951	A15336	7280 226424	ALEKSANDR IVANOV	{"email": "aivanov-071972@postgrespro.ru", "phone": "+70894251078"}
0005434600952	1C0DE8	7173 248744	VASILIY POPOV	{"email": "popovv-22011973@postgrespro.ru", "phone": "+70293706995"}
0005434600953	1C0DE8	9684 476647	ALEKSEY MEDVEDEV	{"email": "medvedev.a-091965@postgrespro.ru", "phone": "+70025622624"}
0005434600954	92B25C	8090 498120	ALLA KARPOVA	{"email": "karpovaalla-111974@postgrespro.ru", "phone": "+70191756162"}
0005434600955	92B25C	9855 662961	ALEKSANDR YAKOVLEV	{"phone": "+70690003414"}
0005434600956	273763	0383 845924	IRINA ARKHIPOVA	{"phone": "+70380526097"}
0005434600957	33B844	3075 842094	ARINA DENISOVA	{"phone": "+70253893502"}
0005434600958	B4FF40	2839 753304	GALINA MEDVEDEVA	{"phone": "+70763098892"}
0005434600959	C80919	2867 837894	IVAN DENISOV	{"phone": "+70684592722"}
0005434600960	3BCCF4	2593 823703	SERGEY ANTONOV	{"phone": "+70181756121"}
0005434600961	3BCCF4	6892 146965	SERGEY KUZNECOV	{"email": "kuznecovsergey-12101976@postgrespro.ru", "phone": "+70171364929"}
0005434600962	3BCCF4	9784 901993	IRINA NIKOLAEVA	{"phone": "+70100093175"}
0005434600963	05ED9F	0774 166074	IRINA PETROVA	{"email": "irina-petrova081967@postgrespro.ru", "phone": "+70302239089"}
0005434600964	E63D7E	1387 439546	ALEKSANDR BELOV	{"phone": "+70623042257"}
0005434600965	E63D7E	4687 308851	VASILISA NIKOLAEVA	{"phone": "+70390784441"}
0005434600966	5F9D4E	1023 373711	VLADIMIR DMITRIEV	{"phone": "+70889819738"}
0005434600967	5F9D4E	5891 752613	ZOYA VLASOVA	{"phone": "+70617234509"}
0005434600968	08F55A	0234 384908	ANATOLIY VOLKOV	{"email": "volkova-1980@postgrespro.ru", "phone": "+70008634132"}
0005434600969	78A3C3	4696 842668	ANASTASIYA KISELEVA	{"phone": "+70555554403"}
0005434600970	5221FC	7480 748770	MAKSIM DENISOV	{"email": "denisov.maksim1958@postgrespro.ru", "phone": "+70829370734"}
0005434600971	82F4C8	6174 078947	ANGELINA BORISOVA	{"email": "a_borisova101979@postgrespro.ru", "phone": "+70883834000"}
0005434600972	11B552	0008 273911	LYUBOV SCHERBAKOVA	{"email": "scherbakova.l1974@postgrespro.ru", "phone": "+70940921346"}
0005434600973	11B552	9284 462860	GALINA ZAKHAROVA	{"email": "zakharova-galina-30051961@postgrespro.ru", "phone": "+70682598032"}
0005434600974	64ABC6	3918 990940	MAKSIM MAKSIMOV	{"email": "maksimov_m-1972@postgrespro.ru", "phone": "+70992982304"}
0005434600975	14A4DA	8267 377524	ANDREY SERGEEV	{"email": "asergeev021973@postgrespro.ru", "phone": "+70442382094"}
0005434600976	14A4DA	7801 634362	EVGENIY CHERNOV	{"email": "chernov_evgeniy1974@postgrespro.ru", "phone": "+70245391124"}
0005434600977	30EF02	4514 886841	ANNA LEBEDEVA	{"email": "a_lebedeva-1968@postgrespro.ru", "phone": "+70069615786"}
0005434600978	05A777	5536 122397	NIKITA MARTYNOV	{"phone": "+70344540011"}
0005434600979	722A55	7841 736512	ARTEM ABRAMOV	{"phone": "+70527312668"}
0005434600980	67223F	9951 372373	DANILA FILIPPOV	{"phone": "+70633665656"}
0005434600981	67223F	6973 389264	YURIY ROMANOV	{"phone": "+70300290046"}
0005434600982	67223F	3000 819397	VALENTINA MELNIKOVA	{"phone": "+70025274957"}
0005434600983	38101D	5078 360012	OLGA KUDRYASHOVA	{"phone": "+70728236638"}
0005434600984	0379D5	8970 901506	IGOR SOROKIN	{"phone": "+70780128745"}
0005434600985	0379D5	0999 917208	NATALYA MEDVEDEVA	{"phone": "+70640887225"}
0005434600986	0379D5	3599 513294	VALENTINA IVANOVA	{"phone": "+70222409110"}
0005434600987	1790FE	9633 494803	ANGELINA ARKHIPOVA	{"email": "angelina_arkhipova-1975@postgrespro.ru", "phone": "+70309717334"}
0005434601155	580A62	0705 996620	SVETLANA KUZNECOVA	{"phone": "+70058309428"}
0005434600988	3E2CA1	2894 579282	ANDREY NAUMOV	{"email": "a-naumov.1975@postgrespro.ru", "phone": "+70171579325"}
0005434600989	53F0CF	2625 619696	IVAN GORBUNOV	{"email": "gorbunov-ivan-17011968@postgrespro.ru", "phone": "+70657202761"}
0005434600990	8A1C27	5488 809706	ARSENIY DMITRIEV	{"phone": "+70522151587"}
0005434600991	F2B923	9645 518509	ANDREY NIKOLAEV	{"phone": "+70926850338"}
0005434600992	68BE56	7507 965818	VIKTOR EGOROV	{"email": "egorov.viktor_071970@postgrespro.ru", "phone": "+70037078577"}
0005434600993	2A8246	8595 843423	MIKHAIL GORBUNOV	{"email": "m.gorbunov_101973@postgrespro.ru", "phone": "+70090627588"}
0005434600994	B8DF08	4522 366791	YURIY CHERNOV	{"phone": "+70282254244"}
0005434600995	C5AB6A	4224 233619	LIDIYA CHERNOVA	{"phone": "+70239780818"}
0005434600996	31BA5C	9800 993069	ANDREY ISAEV	{"email": "aisaev-1976@postgrespro.ru", "phone": "+70481143242"}
0005434600997	E6033C	3227 129579	VALENTINA KOMAROVA	{"email": "v-komarova_1970@postgrespro.ru", "phone": "+70558099847"}
0005434600998	86AE25	7209 700657	VLADIMIR ANDREEV	{"email": "andreev_v-021980@postgrespro.ru", "phone": "+70947620445"}
0005434600999	D11CE6	4839 088739	DMITRIY SMIRNOV	{"phone": "+70761782495"}
0005434601000	84DCCB	3687 954140	SERGEY ZHURAVLEV	{"email": "s_zhuravlev30081971@postgrespro.ru", "phone": "+70124227410"}
0005434601001	E6F398	6691 874367	NIKITA NIKOLAEV	{"email": "n_nikolaev_021965@postgrespro.ru", "phone": "+70115447345"}
0005434601002	2C2CAF	5943 616041	ANNA BOGDANOVA	{"email": "bogdanova_a.061974@postgrespro.ru", "phone": "+70246357734"}
0005434601003	2C2CAF	2844 164950	DMITRIY ANDREEV	{"email": "d-andreev1986@postgrespro.ru", "phone": "+70497221187"}
0005434601004	353BD9	6015 459835	DANILA IVANOV	{"email": "ivanovdanila_1963@postgrespro.ru", "phone": "+70863319446"}
0005434601005	353BD9	5936 695470	VERA KRASNOVA	{"phone": "+70095869432"}
0005434601006	8CE0BC	8569 456334	TATYANA SCHERBAKOVA	{"email": "tatyana_scherbakova-23021973@postgrespro.ru", "phone": "+70993148832"}
0005434601007	F48556	0696 675177	DMITRIY CHERNOV	{"email": "chernov_d-1968@postgrespro.ru", "phone": "+70971920921"}
0005434601008	53B9F0	1922 066496	GALINA MOROZOVA	{"email": "morozova.g1972@postgrespro.ru", "phone": "+70804706884"}
0005434601009	FBB09B	7473 697517	GALINA SIDOROVA	{"phone": "+70626137736"}
0005434601010	1F0265	6946 490181	ANTONINA MAKAROVA	{"phone": "+70019527435"}
0005434601011	D8AD4F	0121 650051	VALENTINA ALEKSANDROVA	{"phone": "+70698555969"}
0005434601012	E0F842	4453 978797	OLEG NOVIKOV	{"phone": "+70932016910"}
0005434601013	B084DF	8942 993672	VLADIMIR OSIPOV	{"email": "osipovvladimir1967@postgrespro.ru", "phone": "+70844332977"}
0005434601014	5FBEBC	4855 978173	DIANA SIDOROVA	{"email": "d_sidorova_27061966@postgrespro.ru", "phone": "+70776296348"}
0005434601015	C97DF3	0507 441710	ALLA NAUMOVA	{"phone": "+70392890772"}
0005434601016	0EF9E5	1853 288142	YULIYA ZAYCEVA	{"phone": "+70842082844"}
0005434601017	AF8C3E	7000 916333	VITALIY SOLOVEV	{"email": "v_solovev25061973@postgrespro.ru", "phone": "+70996893326"}
0005434601018	AF8C3E	6802 231894	ALEKSANDR SOKOLOV	{"phone": "+70192021481"}
0005434601019	9E1FA4	4290 005604	MIKHAIL MIRONOV	{"email": "mikhailmironov_1955@postgrespro.ru", "phone": "+70081888961"}
0005434601020	39682E	1311 127018	NADEZHDA EFIMOVA	{"phone": "+70163709650"}
0005434601021	D0F665	6312 949913	VYACHESLAV NOVIKOV	{"email": "novikov_vyacheslav.10031971@postgrespro.ru", "phone": "+70155679933"}
0005434601022	9A0237	6162 168485	EKATERINA ILINA	{"email": "ilina.ekaterina_1977@postgrespro.ru", "phone": "+70795740878"}
0005434601023	819A51	2482 229427	RAISA SCHERBAKOVA	{"phone": "+70192181912"}
0005434601024	819A51	2710 133067	LYUDMILA GAVRILOVA	{"email": "lyudmila.gavrilova-06051967@postgrespro.ru", "phone": "+70766379728"}
0005434601025	819A51	7687 960915	VLADIMIR MEDVEDEV	{"phone": "+70713726747"}
0005434601026	577CF0	6548 260866	VASILIY TARASOV	{"phone": "+70219424532"}
0005434601027	FED23E	0926 987327	OKSANA GRISHINA	{"phone": "+70289611747"}
0005434601028	290203	5108 296293	OLGA KUDRYASHOVA	{"phone": "+70525376644"}
0005434601029	3F4482	5295 689690	SERGEY MIKHAYLOV	{"email": "sergeymikhaylov_121970@postgrespro.ru", "phone": "+70030921273"}
0005434601030	3F4482	8586 538071	DMITRIY BELOV	{"email": "d-belov-081972@postgrespro.ru", "phone": "+70158285848"}
0005434601031	C1A844	8376 718974	LYUDMILA SEMENOVA	{"email": "lyudmilasemenova_041974@postgrespro.ru", "phone": "+70069132263"}
0005434601032	C1A844	1383 325664	VLADISLAV KUZNECOV	{"email": "kuznecov-vladislav_1974@postgrespro.ru", "phone": "+70812372124"}
0005434601033	EB463E	3096 154605	OLEG MIKHAYLOV	{"email": "mikhaylov-o.1955@postgrespro.ru", "phone": "+70851789799"}
0005434601034	450CEA	6885 554739	NADEZHDA VASILEVA	{"email": "vasilevanadezhda.03101968@postgrespro.ru", "phone": "+70630433030"}
0005434601035	59AEEE	2037 894704	ANATOLIY GUSEV	{"phone": "+70905955534"}
0005434601036	8C56B8	8675 782668	NIKOLAY SHEVCHENKO	{"phone": "+70478479223"}
0005434601037	08E812	9149 524536	NADEZHDA IVANOVA	{"email": "n.ivanova061975@postgrespro.ru", "phone": "+70652695822"}
0005434601038	911A2F	7081 999770	STANISLAV TIKHONOV	{"phone": "+70027013713"}
0005434601039	FB7570	6734 817733	SVETLANA SCHERBAKOVA	{"email": "sscherbakova1977@postgrespro.ru", "phone": "+70484492838"}
0005434601040	25679E	3609 569555	ANATOLIY POPOV	{"email": "anatoliy_popov-1966@postgrespro.ru", "phone": "+70852945043"}
0005434601041	25679E	4254 989530	GALINA IVANOVA	{"email": "galina.ivanova-101974@postgrespro.ru", "phone": "+70311066131"}
0005434601042	25679E	9229 838069	KIRILL FROLOV	{"email": "frolovkirill_1975@postgrespro.ru", "phone": "+70479850940"}
0005434601043	F2040C	5696 616819	NATALYA DMITRIEVA	{"email": "n-dmitrieva25041965@postgrespro.ru", "phone": "+70191154653"}
0005434601044	9295A5	4093 129026	VIKTOR YAKOVLEV	{"phone": "+70209842197"}
0005434601045	F49D85	6464 148877	IGOR VASILEV	{"email": "vasilev.i-011977@postgrespro.ru", "phone": "+70685346761"}
0005434601046	85BF03	0588 822706	MARIYA SIDOROVA	{"phone": "+70391861941"}
0005434601047	AE33A2	3059 810552	SERGEY SAVELEV	{"email": "savelev_s1972@postgrespro.ru", "phone": "+70962299525"}
0005434601048	1BB286	0374 682403	ALENA GORBUNOVA	{"phone": "+70574096711"}
0005434601049	1BB286	1356 117995	IRINA PETROVA	{"phone": "+70596909544"}
0005434601050	4FD177	3884 419623	DMITRIY PETROV	{"phone": "+70337904554"}
0005434601051	4FD177	7924 616759	ANASTASIYA VOROBEVA	{"phone": "+70579738731"}
0005434601052	D2A263	5447 776397	ARMEN VASILEV	{"phone": "+70646115358"}
0005434601053	D2A263	5359 091616	SERGEY NIKOLAEV	{"phone": "+70702228364"}
0005434601054	9E47AF	4966 047364	PAVEL ZAYCEV	{"email": "zaycevp_28021971@postgrespro.ru", "phone": "+70258562713"}
0005434601055	9E47AF	4152 024944	VERONIKA MATVEEVA	{"email": "matveevav07071978@postgrespro.ru", "phone": "+70211784059"}
0005434601056	9E47AF	1054 428679	NINA MASLOVA	{"email": "maslovan_1978@postgrespro.ru", "phone": "+70959645238"}
0005434601057	9E47AF	2501 118555	LYUDMILA KUZNECOVA	{"email": "lyudmila-kuznecova_121971@postgrespro.ru", "phone": "+70422874448"}
0005434601058	40E266	2678 890138	DMITRIY KUZNECOV	{"phone": "+70171481922"}
0005434601059	ECEC84	7562 179154	NIKOLAY STEPANOV	{"phone": "+70997955991"}
0005434601060	1AEFDB	3535 197721	OLEG GERASIMOV	{"email": "gerasimovoleg.1955@postgrespro.ru", "phone": "+70778130444"}
0005434601061	8D4130	8439 326679	ANTON CHERNOV	{"phone": "+70574221434"}
0005434601062	C29B33	6672 408374	DENIS SOROKIN	{"phone": "+70630576531"}
0005434601063	690055	1091 639024	LARISA KONOVALOVA	{"email": "larisa-konovalova-09111975@postgrespro.ru", "phone": "+70616914214"}
0005434601064	690055	8520 538340	VIKTOR NIKITIN	{"phone": "+70033950711"}
0005434601065	690055	1092 996767	GALINA MIRONOVA	{"phone": "+70309953325"}
0005434601066	2414DB	1497 303401	LYUDMILA MAKAROVA	{"email": "makarova_l_1969@postgrespro.ru", "phone": "+70925391804"}
0005434601067	F3D153	9131 414754	VLADIMIR MAKSIMOV	{"phone": "+70918703014"}
0005434601068	3BDEC0	0493 371642	ALEKSANDRA KOVALEVA	{"phone": "+70831566327"}
0005434601069	3BDEC0	5881 142667	VALERIY NIKOLAEV	{"email": "nikolaev_v.27021976@postgrespro.ru", "phone": "+70424135023"}
0005434601070	D95EDB	2821 710694	DMITRIY NAUMOV	{"email": "d.naumov-1982@postgrespro.ru", "phone": "+70588974414"}
0005434601071	3294FE	8821 891544	ZINAIDA MOROZOVA	{"email": "zinaida-morozova_21021964@postgrespro.ru", "phone": "+70897540684"}
0005434601072	3294FE	9591 472698	KSENIYA ARKHIPOVA	{"email": "k_arkhipova-1969@postgrespro.ru", "phone": "+70197622263"}
0005434601073	3294FE	1241 589616	SERGEY MIRONOV	{"phone": "+70707162403"}
0005434601074	98896A	0103 815497	TAMARA CHERNOVA	{"phone": "+70638915576"}
0005434601075	98896A	8857 715088	ANATOLIY ALEKSEEV	{"phone": "+70510469671"}
0005434601076	98896A	3243 817492	LIDIYA KALININA	{"email": "lidiyakalinina_11071974@postgrespro.ru", "phone": "+70535504266"}
0005434601077	7FCDB4	4692 696209	ELENA KUZNECOVA	{"email": "elena-kuznecova-1968@postgrespro.ru", "phone": "+70644627724"}
0005434601078	2A3E9A	8338 420052	VIKTOR MARTYNOV	{"email": "martynovviktor-011981@postgrespro.ru", "phone": "+70298429297"}
0005434601079	4F08D6	3248 426490	DMITRIY MAKAROV	{"email": "dmakarov.30041973@postgrespro.ru", "phone": "+70952646158"}
0005434601080	7906E3	5779 209112	OLGA MOROZOVA	{"email": "o.morozova1979@postgrespro.ru", "phone": "+70371466455"}
0005434601081	D0FD36	1920 202386	ELENA POPOVA	{"email": "popova_e23081968@postgrespro.ru", "phone": "+70878388357"}
0005434601082	EBB955	9276 136898	RUSLAN KOZLOV	{"email": "r-kozlov_071984@postgrespro.ru", "phone": "+70554905031"}
0005434601083	B53A7F	2184 903769	EVGENIY DAVYDOV	{"phone": "+70714206587"}
0005434601084	B53A7F	2315 592632	LYUBOV MAKAROVA	{"email": "makarova.lyubov.031971@postgrespro.ru", "phone": "+70819303642"}
0005434601085	AB940C	9440 508024	DMITRIY OSIPOV	{"email": "d.osipov.1966@postgrespro.ru", "phone": "+70123993469"}
0005434601086	41675C	5232 918052	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov121973@postgrespro.ru", "phone": "+70687645529"}
0005434601087	0BE39B	6322 095589	ELENA MIKHAYLOVA	{"email": "e.mikhaylova-101972@postgrespro.ru", "phone": "+70889219529"}
0005434601088	0BE39B	8376 668007	ELENA KUZNECOVA	{"phone": "+70889722154"}
0005434601089	0BE39B	7678 167326	ILMIRA PAVLOVA	{"email": "pavlovai1969@postgrespro.ru", "phone": "+70521693679"}
0005434601090	5AAC97	4085 112426	VLADISLAV FILIPPOV	{"email": "filippov_vladislav.1962@postgrespro.ru", "phone": "+70864389803"}
0005434601091	8812B9	7317 360065	YURIY SERGEEV	{"phone": "+70599946431"}
0005434601092	8812B9	3626 509867	ALEKSANDR ANDREEV	{"phone": "+70877526212"}
0005434601093	8812B9	4859 031353	OLESYA MIRONOVA	{"phone": "+70704658401"}
0005434601094	1C04DB	7267 503438	ELENA FROLOVA	{"email": "e_frolova_1969@postgrespro.ru", "phone": "+70774765117"}
0005434601095	E776B2	0011 920478	BORIS IVANOV	{"phone": "+70265879281"}
0005434601096	E776B2	4049 938096	ALEKSANDR POPOV	{"email": "popov-a.081977@postgrespro.ru", "phone": "+70107201498"}
0005434601097	5A4783	0602 908594	NADEZHDA SEMENOVA	{"phone": "+70110438141"}
0005434601098	EE284E	2860 123246	NINA ORLOVA	{"email": "n.orlova.1972@postgrespro.ru", "phone": "+70220994050"}
0005434601099	EE284E	9453 736102	NAILYA EGOROVA	{"email": "nailya-egorova-1969@postgrespro.ru", "phone": "+70698440788"}
0005434601100	C1F79B	5292 165610	YURIY TARASOV	{"phone": "+70559905896"}
0005434601101	A0E606	1951 245517	ELENA ANTONOVA	{"phone": "+70407342643"}
0005434601102	6F50A8	0499 676507	SERGEY BARANOV	{"phone": "+70554286610"}
0005434601103	7683FA	4686 627442	SERGEY CHERNOV	{"phone": "+70094032258"}
0005434601104	2A089B	7549 506599	ALBERT MARTYNOV	{"email": "martynov-a23111983@postgrespro.ru", "phone": "+70314410566"}
0005434601105	19EBFD	2195 906178	ALEKSANDR GERASIMOV	{"phone": "+70192790552"}
0005434601106	19EBFD	7520 912296	ANTON FROLOV	{"phone": "+70108484353"}
0005434601107	19EBFD	1681 852134	ANNA FROLOVA	{"email": "anna_frolova_071976@postgrespro.ru", "phone": "+70019623401"}
0005434601108	75DFE5	2076 689361	ELENA BARANOVA	{"email": "e_baranova-011975@postgrespro.ru", "phone": "+70155789442"}
0005434601109	CFAD9F	8543 827655	SERGEY PETROV	{"phone": "+70658265017"}
0005434601110	F79B19	6429 217919	OKSANA SAVELEVA	{"phone": "+70199047086"}
0005434601111	ADA48F	8548 703863	ROZA ARKHIPOVA	{"phone": "+70118934190"}
0005434601112	5EED2F	8228 595613	YURIY IVANOV	{"phone": "+70741488685"}
0005434601113	5E6A96	5281 212085	TATYANA NOVIKOVA	{"phone": "+70561482629"}
0005434601114	5E6A96	0057 655076	NIKOLAY ZHUKOV	{"phone": "+70807894186"}
0005434601115	5D58A9	8536 498130	OLEG MOROZOV	{"email": "morozovoleg_1975@postgrespro.ru", "phone": "+70670811657"}
0005434601116	138F6F	8931 205692	VIKTORIYA EGOROVA	{"email": "egorova_v1947@postgrespro.ru", "phone": "+70465231991"}
0005434601117	138F6F	6569 318419	MARINA SOKOLOVA	{"email": "msokolova051963@postgrespro.ru", "phone": "+70263369875"}
0005434601118	A91AEC	2642 685618	MATVEY ABRAMOV	{"phone": "+70670694712"}
0005434601119	7E85E3	9520 622655	ALEKSANDR TIMOFEEV	{"email": "timofeev.aleksandr_011966@postgrespro.ru", "phone": "+70187524908"}
0005434601120	7E85E3	1632 592040	MARGARITA AKIMOVA	{"phone": "+70929650545"}
0005434601121	625375	1395 435368	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana.1968@postgrespro.ru", "phone": "+70824491628"}
0005434601122	625375	4274 486507	GALINA MAKAROVA	{"phone": "+70333480918"}
0005434601123	EB70F7	2680 547016	SVETLANA TROFIMOVA	{"phone": "+70441195359"}
0005434601124	EB70F7	4342 745928	LYUBOV NIKOLAEVA	{"email": "l_nikolaeva.1979@postgrespro.ru", "phone": "+70635284372"}
0005434601125	9171A8	0490 806007	DMITRIY FROLOV	{"email": "frolov.dmitriy091967@postgrespro.ru", "phone": "+70381506227"}
0005434601126	078C0E	1028 369592	IVAN YAKOVLEV	{"email": "yakovlevivan.071970@postgrespro.ru", "phone": "+70410761970"}
0005434601127	621692	8089 328844	YULIYA ANDREEVA	{"phone": "+70072152319"}
0005434601128	621692	2968 657713	NIKOLAY KRASNOV	{"email": "nikolay.krasnov08051980@postgrespro.ru", "phone": "+70985651472"}
0005434601129	5E77C0	6220 892210	ANNA DENISOVA	{"email": "a_denisova-011978@postgrespro.ru", "phone": "+70672760256"}
0005434601130	21DB35	9676 567619	VIKTOR GRIGOREV	{"phone": "+70169709781"}
0005434601131	21DB35	6548 969047	LIYA CHERNOVA	{"email": "chernova_liya_1982@postgrespro.ru", "phone": "+70019026813"}
0005434601132	834BFC	7304 064777	ALINA ANDREEVA	{"email": "a-andreeva-021964@postgrespro.ru", "phone": "+70491031608"}
0005434601133	76DC77	8925 346725	YULIYA ERMAKOVA	{"email": "yermakova1962@postgrespro.ru", "phone": "+70293512096"}
0005434601134	8D7B89	6925 942668	VIKTORIYA SOROKINA	{"email": "sorokina.viktoriya25011975@postgrespro.ru", "phone": "+70217062217"}
0005434601135	1D1FCC	5293 537645	IGOR MATVEEV	{"phone": "+70646153205"}
0005434601136	8EB0FE	2167 053258	IRINA EFREMOVA	{"email": "i_efremova_1970@postgrespro.ru", "phone": "+70461142660"}
0005434601137	8EB0FE	6894 854670	ALEKSANDR MIRONOV	{"phone": "+70675880366"}
0005434601138	8EB0FE	3591 954190	VASILIY GRIGOREV	{"email": "grigorev-v.19051981@postgrespro.ru", "phone": "+70940164341"}
0005434601139	331FF1	5781 681327	YULIYA BARANOVA	{"email": "baranovay_1963@postgrespro.ru", "phone": "+70791096071"}
0005434601140	6AE0D2	5713 907064	OLGA ALEKSEEVA	{"email": "alekseevaolga_1971@postgrespro.ru", "phone": "+70221887158"}
0005434601141	6AE0D2	1550 403218	OLGA OSIPOVA	{"phone": "+70324243838"}
0005434601143	6E1954	9975 035016	OLGA ORLOVA	{"email": "olga_orlova-16011968@postgrespro.ru", "phone": "+70898152299"}
0005434601144	6E1954	8359 334318	ANDREY SEMENOV	{"phone": "+70320953699"}
0005434601145	C115E4	8371 634692	NADEZHDA ILINA	{"email": "ilina_nadezhda_031972@postgrespro.ru", "phone": "+70296955986"}
0005434601146	C115E4	3538 724626	LYUDMILA IVANOVA	{"phone": "+70779938374"}
0005434601147	327068	6700 635390	ALEKSANDR TARASOV	{"email": "a_tarasov-15041970@postgrespro.ru", "phone": "+70497604998"}
0005434601148	3BA1C1	1699 906890	VALENTINA DANILOVA	{"email": "v_danilova-031973@postgrespro.ru", "phone": "+70663679016"}
0005434601149	445B5C	3039 553744	SERGEY SMIRNOV	{"email": "smirnovs_121975@postgrespro.ru", "phone": "+70355063942"}
0005434601150	885F63	4608 927020	ALEKSANDR NOVIKOV	{"email": "novikov-a-16041969@postgrespro.ru", "phone": "+70990585530"}
0005434601151	885F63	3419 508264	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr-041979@postgrespro.ru", "phone": "+70203112928"}
0005434601152	30D36E	7300 386100	TATYANA SEMENOVA	{"phone": "+70164485935"}
0005434601153	30D36E	4452 970134	TATYANA DAVYDOVA	{"phone": "+70134804561"}
0005434601154	0C68EB	8294 475470	GALINA MEDVEDEVA	{"phone": "+70939375844"}
0005434601156	CBE5FA	3547 140617	VLADISLAV KOROLEV	{"phone": "+70514873882"}
0005434601157	E8BB45	1347 804929	VLADIMIR GERASIMOV	{"phone": "+70646745645"}
0005434601158	E8BB45	6742 922894	OLEG VASILEV	{"phone": "+70853896081"}
0005434601159	C8984F	6697 491576	NATALYA KONOVALOVA	{"email": "konovalovanatalya_06011964@postgrespro.ru", "phone": "+70415578819"}
0005434601160	66CFB4	4505 426174	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_v1962@postgrespro.ru", "phone": "+70035799625"}
0005434601161	DAEEC3	1536 750429	VASILIY MIKHAYLOV	{"phone": "+70086854680"}
0005434601162	38D76C	9762 396262	VALENTIN MAKSIMOV	{"phone": "+70697143238"}
0005434601163	38D76C	6714 530726	RUMIYA PAVLOVA	{"email": "rumiyapavlova-03091976@postgrespro.ru", "phone": "+70283986458"}
0005434601164	AC6EB1	0645 534578	NINA VASILEVA	{"phone": "+70667627765"}
0005434601165	A3368B	0611 067758	OLEG FROLOV	{"email": "frolovoleg-21101963@postgrespro.ru", "phone": "+70039104713"}
0005434601166	A92469	6954 994254	GENNADIY VOROBEV	{"phone": "+70117034808"}
0005434601167	9A73A9	7543 763118	OLEG ANTONOV	{"email": "antonov_o-1974@postgrespro.ru", "phone": "+70139155559"}
0005434601168	0C8C27	1089 261263	DARYA BOGDANOVA	{"phone": "+70276703822"}
0005434601169	33ED7A	4295 860598	ILDAR DAVYDOV	{"email": "idavydov_26071973@postgrespro.ru", "phone": "+70955032842"}
0005434601170	07D906	8021 663207	ALEKSEY MAKAROV	{"email": "aleksey-makarov051971@postgrespro.ru", "phone": "+70320941038"}
0005434601171	3370BE	3109 559886	VALERIY KULIKOV	{"email": "kulikovv.28021970@postgrespro.ru", "phone": "+70812237925"}
0005434601172	3370BE	8145 779712	IVAN ANDREEV	{"phone": "+70584479351"}
0005434601173	911F83	6775 623059	ALEKSEY KRASNOV	{"email": "alekseykrasnov_121971@postgrespro.ru", "phone": "+70306978533"}
0005434601174	585F96	2624 092681	PAVEL PAVLOV	{"phone": "+70278585728"}
0005434601175	9E9E4D	7545 972808	YURIY SCHERBAKOV	{"email": "scherbakov_yuriy-071967@postgrespro.ru", "phone": "+70297777239"}
0005434601176	CA3732	3621 747059	TATYANA IVANOVA	{"phone": "+70206294828"}
0005434601177	A1AA81	6932 304936	NINA KULIKOVA	{"email": "n.kulikova091963@postgrespro.ru", "phone": "+70525117684"}
0005434601178	A1AA81	7668 002574	ANNA MELNIKOVA	{"email": "melnikova_a-1979@postgrespro.ru", "phone": "+70375000039"}
0005434601179	BD5527	6238 171642	ANNA POTAPOVA	{"email": "anna-potapova.1969@postgrespro.ru", "phone": "+70470622409"}
0005434601180	180D60	3086 850030	VIKTOR PAVLOV	{"phone": "+70088654477"}
0005434601181	180D60	5599 534648	NIKITA POPOV	{"phone": "+70456878047"}
0005434601182	EFE0E1	0223 725148	VERA NESTEROVA	{"email": "v-nesterova_25071982@postgrespro.ru", "phone": "+70651859171"}
0005434601183	EFE0E1	2169 842498	LYUCIYA PAVLOVA	{"phone": "+70061772075"}
0005434601184	EFE0E1	8443 582649	IRINA EGOROVA	{"phone": "+70293518394"}
0005434601185	BDB691	7986 328819	RUSTAM IVANOV	{"phone": "+70434517195"}
0005434601186	BDB691	2101 444453	MARINA KALININA	{"email": "kalinina.m-051962@postgrespro.ru", "phone": "+70223904030"}
0005434601187	BDB691	7869 077226	NIKITA NOVIKOV	{"email": "novikovn.04021966@postgrespro.ru", "phone": "+70242344237"}
0005434601188	D164D1	3916 115480	YURIY KUDRYASHOV	{"email": "kudryashov-yuriy16101964@postgrespro.ru", "phone": "+70907111401"}
0005434601189	545577	9548 693036	LYUDMILA KUZMINA	{"email": "lkuzmina.121974@postgrespro.ru", "phone": "+70908039080"}
0005434601190	545577	2822 053978	RUSLAN SERGEEV	{"email": "ruslansergeev.11071964@postgrespro.ru", "phone": "+70660212967"}
0005434601191	BA012F	4860 023066	MARIYA NIKITINA	{"phone": "+70064938550"}
0005434601192	5C0005	3296 273799	VLADIMIR VOROBEV	{"email": "vorobev_v-1962@postgrespro.ru", "phone": "+70610089607"}
0005434601193	5C0005	0688 940428	ALEKSANDR ROMANOV	{"phone": "+70914479912"}
0005434601194	61017F	7760 148405	RAISA ILINA	{"phone": "+70872103254"}
0005434601195	EA3431	7432 897052	OLGA OVCHINNIKOVA	{"phone": "+70764807438"}
0005434601196	EA3431	6654 811677	ALLA DANILOVA	{"phone": "+70740110926"}
0005434601197	9BE575	6594 378291	LYUDMILA ILINA	{"phone": "+70604368456"}
0005434601198	9BE575	1380 655186	VLADIMIR VOROBEV	{"email": "v_vorobev04121981@postgrespro.ru", "phone": "+70394876274"}
0005434601199	9BE575	1470 066608	NATALYA ZAYCEVA	{"email": "zayceva_natalya02021980@postgrespro.ru", "phone": "+70619443266"}
0005434601200	C892BC	0708 576219	ELENA ZAYCEVA	{"phone": "+70432908265"}
0005434601201	D972F6	3062 198985	ELENA ROMANOVA	{"email": "romanova_elena-1980@postgrespro.ru", "phone": "+70254656804"}
0005434601202	247F90	4552 836142	NIKITA MARTYNOV	{"phone": "+70547878184"}
0005434601203	247F90	4865 551335	PAVEL NIKITIN	{"email": "nikitinp-1974@postgrespro.ru", "phone": "+70867569707"}
0005434601204	B3A88C	8220 119500	ALENA ISAEVA	{"email": "isaeva_alena_071979@postgrespro.ru", "phone": "+70331663600"}
0005434601205	B3A88C	3975 699501	VASILIY VASILEV	{"email": "vasilevvasiliy.1977@postgrespro.ru", "phone": "+70687543883"}
0005434601206	5E48A8	1306 591421	NATALIYA KUZNECOVA	{"phone": "+70764917522"}
0005434601207	5E48A8	6736 160392	ANATOLIY KUZMIN	{"email": "a_kuzmin1957@postgrespro.ru", "phone": "+70220677094"}
0005434601208	32E70D	4731 816783	ALEVTINA SERGEEVA	{"email": "a.sergeeva-15121960@postgrespro.ru", "phone": "+70321009858"}
0005434601209	5EF30C	7936 790746	TATYANA FROLOVA	{"phone": "+70111830135"}
0005434601210	EFDE7C	4004 197319	ANTONINA KARPOVA	{"email": "antoninakarpova051972@postgrespro.ru", "phone": "+70730157335"}
0005434601211	9CBCD2	5162 583712	BORIS SERGEEV	{"phone": "+70855291741"}
0005434601212	54C78D	7257 975555	VENERA TARASOVA	{"email": "v.tarasova121968@postgrespro.ru", "phone": "+70742343005"}
0005434601213	7C965D	0570 217146	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana-09021960@postgrespro.ru", "phone": "+70654727363"}
0005434601214	88DEEB	3927 683249	NATALYA KAZAKOVA	{"email": "natalya_kazakova.1966@postgrespro.ru", "phone": "+70705238894"}
0005434601215	8AAADC	5777 589716	ANDREY RODIONOV	{"phone": "+70532109205"}
0005434601216	488621	0781 069217	OLGA TIKHONOVA	{"email": "tikhonova-o_081977@postgrespro.ru", "phone": "+70591140767"}
0005434601217	488621	0298 440608	NATALYA PAVLOVA	{"email": "pavlova_n.101970@postgrespro.ru", "phone": "+70868927260"}
0005434601218	3EDAE4	5574 225632	DENIS NAZAROV	{"email": "nazarov_d.23071977@postgrespro.ru", "phone": "+70148436048"}
0005434601219	3EDAE4	2920 156272	NINA KULIKOVA	{"phone": "+70123329089"}
0005434601220	3EDAE4	6245 048634	ANATOLIY KUDRYASHOV	{"phone": "+70304895391"}
0005434601221	65E30E	1427 187117	DMITRIY YAKOVLEV	{"phone": "+70490950286"}
0005434601222	65E30E	3007 916895	RIFAT SHEVCHENKO	{"email": "rshevchenko061968@postgrespro.ru", "phone": "+70142994465"}
0005434601223	6A5E36	9135 639840	IRINA VLASOVA	{"phone": "+70212534856"}
0005434601224	F6852E	2306 924235	EVGENIY BARANOV	{"email": "evgeniybaranov-111974@postgrespro.ru", "phone": "+70626971038"}
0005434601225	1216DF	6073 664479	ASKHAT KUZMIN	{"email": "askhat.kuzmin_13041971@postgrespro.ru", "phone": "+70022628334"}
0005434601226	EC602D	6903 756634	VITALIY ALEKSEEV	{"phone": "+70792292101"}
0005434601227	B15C3C	5115 103726	TAMARA ANTONOVA	{"email": "antonova-t.17021969@postgrespro.ru", "phone": "+70400927020"}
0005434601228	B15C3C	2713 062342	NIKITA IVANOV	{"email": "nikita.ivanov091974@postgrespro.ru", "phone": "+70197447725"}
0005434601229	FBBBA8	5423 502420	TAMARA MAKSIMOVA	{"phone": "+70387881406"}
0005434601230	4129D2	7236 042465	MARIYA YAKOVLEVA	{"phone": "+70085325170"}
0005434601231	4129D2	6327 254456	MIKHAIL ZHURAVLEV	{"phone": "+70646498946"}
0005434601232	4129D2	0934 683744	ALEKSANDR KRASNOV	{"email": "aleksandr_krasnov_1978@postgrespro.ru", "phone": "+70143163795"}
0005434601233	F4060F	4444 567076	MARINA KOVALEVA	{"phone": "+70778082920"}
0005434601234	744972	4940 279772	NIKITA MELNIKOV	{"email": "melnikov.n1975@postgrespro.ru", "phone": "+70578441675"}
0005434601235	7D1660	6418 609413	RITA SIDOROVA	{"phone": "+70556298682"}
0005434601236	7D1660	9947 629997	GERMAN EGOROV	{"phone": "+70169336155"}
0005434601237	5118CA	8163 316466	DMITRIY KUZNECOV	{"phone": "+70217062059"}
0005434601238	5118CA	5274 230126	ALEKSANDR POPOV	{"phone": "+70265608853"}
0005434601239	141367	9726 334512	SERGEY SOLOVEV	{"phone": "+70330326677"}
0005434601240	418076	4939 526557	VASILIY KOZLOV	{"email": "vkozlov.1972@postgrespro.ru", "phone": "+70714850265"}
0005434601241	4D144F	2400 255329	MARIYA ZHURAVLEVA	{"email": "zhuravlevamariya.091966@postgrespro.ru", "phone": "+70705195737"}
0005434601242	8104C6	4933 384762	OLGA EFREMOVA	{"phone": "+70895798565"}
0005434601243	4B97B0	2387 180596	MIKHAIL VOROBEV	{"email": "vorobev.m.041964@postgrespro.ru", "phone": "+70805328714"}
0005434601244	E95388	9761 768726	YURIY VOROBEV	{"email": "vorobev.yuriy.28061971@postgrespro.ru", "phone": "+70665485348"}
0005434601245	18C992	7604 015519	DANIIL GRIGOREV	{"email": "grigorev_daniil.1971@postgrespro.ru", "phone": "+70779115769"}
0005434601246	9B59FC	2892 034346	NADEZHDA YAKOVLEVA	{"phone": "+70614039228"}
0005434601247	723A85	2394 866511	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov1968@postgrespro.ru", "phone": "+70635328892"}
0005434601248	E5B8C3	1945 751879	KAPITALINA FOMINA	{"phone": "+70681945429"}
0005434601249	0FACC9	4347 280898	MARTA KULIKOVA	{"email": "kulikovam121975@postgrespro.ru", "phone": "+70419529668"}
0005434601250	C633CC	4262 021201	OLESYA MOISEEVA	{"email": "moiseeva_o051974@postgrespro.ru", "phone": "+70939251369"}
0005434601251	C633CC	4718 578648	VITALIY SAVELEV	{"phone": "+70636625562"}
0005434601252	C633CC	9598 212470	KSENIYA ZAKHAROVA	{"email": "zakharova-k-041972@postgrespro.ru", "phone": "+70005913810"}
0005434601253	C3F4FB	4724 720246	SVETLANA ROMANOVA	{"phone": "+70045396791"}
0005434601254	C3F4FB	9890 709340	ALINA POPOVA	{"email": "popova-alina031975@postgrespro.ru", "phone": "+70665270358"}
0005434601255	691603	8893 613106	MARINA SAVELEVA	{"phone": "+70143780165"}
0005434601256	CD2D19	9389 371800	TAISIYA TIKHONOVA	{"phone": "+70387509865"}
0005434601257	F71907	6821 673669	TATYANA TROFIMOVA	{"email": "trofimovat.20081969@postgrespro.ru", "phone": "+70107673618"}
0005434601258	CEA096	6553 910948	MARYAM KONOVALOVA	{"phone": "+70456769502"}
0005434601259	2F0CC8	5906 874524	ALEKSANDR STEPANOV	{"email": "a_stepanov_18011963@postgrespro.ru", "phone": "+70871519843"}
0005434601260	2F0CC8	4358 506808	LYUDMILA KAZAKOVA	{"phone": "+70129226461"}
0005434601261	06A42D	2354 252512	ELENA KARPOVA	{"phone": "+70583913222"}
0005434601262	06A42D	5562 707904	YURIY IVANOV	{"phone": "+70778343886"}
0005434601263	E2F950	7693 474617	NIKOLAY VASILEV	{"email": "nikolay-vasilev_081968@postgrespro.ru", "phone": "+70037838881"}
0005434601264	E2F950	4096 740091	ALEKSANDR GORBUNOV	{"phone": "+70228033688"}
0005434601265	F602AF	5098 075368	TATYANA KARPOVA	{"phone": "+70452588362"}
0005434601266	F602AF	1761 442125	VADIM MIKHAYLOV	{"phone": "+70982775540"}
0005434601267	0A651D	8454 449115	VIKTOR SOLOVEV	{"email": "solovevviktor.24121970@postgrespro.ru", "phone": "+70037171170"}
0005434601268	0A651D	8810 695686	SVETLANA ANDREEVA	{"email": "s.andreeva.081962@postgrespro.ru", "phone": "+70990642799"}
0005434601269	DD4686	4986 138889	TATYANA VOLKOVA	{"phone": "+70299846161"}
0005434601270	9218CD	1947 197943	ELENA ANTONOVA	{"email": "e_antonova_111967@postgrespro.ru", "phone": "+70111273910"}
0005434601271	681543	5246 386587	ALEKSEY FEDOTOV	{"email": "fedotov.aleksey_021965@postgrespro.ru", "phone": "+70246772584"}
0005434601272	BE2B85	2720 152885	SVETLANA KISELEVA	{"email": "kiseleva-s.071979@postgrespro.ru", "phone": "+70319114889"}
0005434601273	866F16	0361 219034	BOGDAN KAZAKOV	{"email": "b.kazakov-1974@postgrespro.ru", "phone": "+70692826352"}
0005434601274	0FAABC	6965 291550	SERGEY KOZLOV	{"email": "kozlov_s.13071959@postgrespro.ru", "phone": "+70011325037"}
0005434601275	221A09	2749 633111	OLGA IVANOVA	{"phone": "+70595371238"}
0005434601276	2DC7E6	5599 183979	LYUDMILA MOROZOVA	{"email": "morozova-l.101964@postgrespro.ru", "phone": "+70392123080"}
0005434601277	2DC7E6	7458 205635	VALENTINA PETROVA	{"email": "petrova.valentina-19121975@postgrespro.ru", "phone": "+70219864103"}
0005434601278	2DC7E6	7905 027766	TATYANA PETROVA	{"phone": "+70506788822"}
0005434601279	DF0449	9390 034243	NADEZHDA KUZNECOVA	{"phone": "+70286390067"}
0005434601280	4C75B2	8512 438785	VALENTINA KOROLEVA	{"phone": "+70757356074"}
0005434601281	4C75B2	7160 187284	ALEKSEY KUZMIN	{"email": "kuzmin-a.28041973@postgrespro.ru", "phone": "+70534892077"}
0005434601282	E6AE97	0823 871498	LYUDMILA MIKHAYLOVA	{"email": "l-mikhaylova.101970@postgrespro.ru", "phone": "+70804200536"}
0005434601283	4E3AB1	0896 591749	ALEKSANDR SIDOROV	{"phone": "+70508401240"}
0005434601284	4E3AB1	7772 932543	SERGEY PETROV	{"email": "s_petrov-1984@postgrespro.ru", "phone": "+70850583675"}
0005434601285	39A478	5798 480073	ELENA RODIONOVA	{"email": "rodionova.e1963@postgrespro.ru", "phone": "+70630978762"}
0005434601286	39A478	9761 629092	ARSENIY NOVIKOV	{"phone": "+70886687688"}
0005434601287	37912D	1469 086760	ELENA YAKOVLEVA	{"phone": "+70981801647"}
0005434601288	1C644E	5330 180857	DMITRIY IVANOV	{"phone": "+70041931067"}
0005434601289	C4294A	8744 397043	ANDREY GERASIMOV	{"email": "gerasimova121965@postgrespro.ru", "phone": "+70424718486"}
0005434601290	8034DD	8652 603646	ILDAR SEMENOV	{"email": "semenovildar_031968@postgrespro.ru", "phone": "+70746319105"}
0005434601291	24FE6A	0454 072213	ANATOLIY ROMANOV	{"email": "anatoliy-romanov1969@postgrespro.ru", "phone": "+70198130078"}
0005434601292	24FE6A	9839 647912	ELENA KOROLEVA	{"phone": "+70786264491"}
0005434601293	59F498	8253 697480	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay_101981@postgrespro.ru", "phone": "+70701958956"}
0005434601294	59F498	4270 999807	ALEKSEY ALEKSANDROV	{"email": "aleksandrov-a-1970@postgrespro.ru", "phone": "+70975905900"}
0005434601295	4F3923	8581 566989	NIKITA BORISOV	{"email": "n-borisov-011986@postgrespro.ru", "phone": "+70749095131"}
0005434601296	A0F59F	7464 507734	YANA TIMOFEEVA	{"phone": "+70080778180"}
0005434601297	BB281B	8446 704871	VERA MIKHAYLOVA	{"email": "mikhaylovavera1990@postgrespro.ru", "phone": "+70041962680"}
0005434601298	BB281B	9625 510816	LIDIYA MAKAROVA	{"email": "makarova-l_101961@postgrespro.ru", "phone": "+70434705568"}
0005434601299	942ABE	5542 873246	ANATOLIY VASILEV	{"phone": "+70932324870"}
0005434601300	0A13B9	2973 611736	NIKITA IVANOV	{"email": "ivanov-nikita1989@postgrespro.ru", "phone": "+70725442288"}
0005434601301	9D0EE7	1994 786592	MARIYA ZHUKOVA	{"email": "mariya-zhukova-1974@postgrespro.ru", "phone": "+70554576039"}
0005434601302	9D0EE7	3033 215694	ELENA BELOVA	{"phone": "+70648534891"}
0005434601303	A800B4	6699 207143	SVETLANA ARKHIPOVA	{"phone": "+70948733264"}
0005434601304	6A8066	9300 108155	KRISTINA DAVYDOVA	{"phone": "+70982684714"}
0005434601305	6A8066	1699 600792	DENIS KULIKOV	{"email": "kulikov_d-121964@postgrespro.ru", "phone": "+70299009520"}
0005434601306	BE1D5C	4862 110975	MARGARITA EFIMOVA	{"phone": "+70892360702"}
0005434601307	BE1D5C	6465 929820	ALEKSANDR GERASIMOV	{"phone": "+70161253037"}
0005434601308	BE1D5C	7171 779262	ALINA EGOROVA	{"phone": "+70406444099"}
0005434601309	1F8533	5624 012366	NATALYA AFANASEVA	{"phone": "+70526798085"}
0005434601310	9D7D38	7048 906745	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev_10121974@postgrespro.ru", "phone": "+70673834408"}
0005434601311	D34F1E	8953 018893	LARISA KUZNECOVA	{"email": "larisakuznecova1977@postgrespro.ru", "phone": "+70040187323"}
0005434601312	CFA563	8260 765122	RISHAT SEMENOV	{"phone": "+70998659979"}
0005434601313	CFA563	5599 182622	LYUBOV DENISOVA	{"email": "lyubovdenisova.1955@postgrespro.ru", "phone": "+70283983859"}
0005434601314	F78757	9531 154045	YURIY BORISOV	{"phone": "+70604181003"}
0005434601315	F78757	2322 563699	LYUDMILA POPOVA	{"email": "popova.lyudmila.121966@postgrespro.ru", "phone": "+70238777619"}
0005434601316	2EDAAB	4874 373144	MAKSIM ABRAMOV	{"phone": "+70585605708"}
0005434601317	2EDAAB	3784 206230	ELENA EGOROVA	{"phone": "+70281857061"}
0005434601318	2EDAAB	5454 867858	YURIY KISELEV	{"email": "y.kiselev.111964@postgrespro.ru", "phone": "+70831247652"}
0005434601319	1A9E54	3650 627128	KIRILL KONOVALOV	{"email": "konovalov.k.111970@postgrespro.ru", "phone": "+70495847860"}
0005434601320	096B62	4450 316470	SEMEN KULIKOV	{"email": "semen-kulikov-1980@postgrespro.ru", "phone": "+70778942292"}
0005434601321	096B62	9689 010876	TATYANA VOROBEVA	{"phone": "+70644729952"}
0005434601322	6002F1	6069 694142	YANA VOLKOVA	{"phone": "+70131738263"}
0005434601323	516735	1492 725898	ALEKSANDR IVANOV	{"phone": "+70442134379"}
0005434601324	516735	7696 230464	VLADIMIR SEMENOV	{"email": "semenov-vladimir.021965@postgrespro.ru", "phone": "+70137550212"}
0005434601325	BDDA8A	7181 652505	ANNA EGOROVA	{"email": "a-egorova1981@postgrespro.ru", "phone": "+70653210261"}
0005434601326	BDDA8A	1078 872812	VALENTINA KUDRYASHOVA	{"phone": "+70629400595"}
0005434601327	AE39D9	8663 226890	GENNADIY ILIN	{"email": "gilin_07111968@postgrespro.ru", "phone": "+70395078549"}
0005434601328	EF3BA1	4123 150811	OLGA YUDINA	{"email": "yudina_o_051986@postgrespro.ru", "phone": "+70758152114"}
0005434601329	EF3BA1	2426 097558	IVAN ANDREEV	{"phone": "+70238302236"}
0005434601330	1A5664	6824 365097	LARISA SOLOVEVA	{"phone": "+70878516305"}
0005434601331	1A5664	0479 552374	POLINA ZHUKOVA	{"phone": "+70056892717"}
0005434601332	B8B6DE	5465 833992	DMITRIY VOLKOV	{"phone": "+70598350569"}
0005434601333	923F0D	3255 137805	MARIYA OSIPOVA	{"phone": "+70454846052"}
0005434601334	2A862F	9850 384502	ALEKSEY GORBUNOV	{"phone": "+70090450135"}
0005434601335	D7F69F	2511 571044	NADEZHDA MIKHAYLOVA	{"phone": "+70323564758"}
0005434601336	8AF08A	3731 036458	MARINA KISELEVA	{"phone": "+70161912944"}
0005434601337	2344FD	8992 698754	NIKOLAY SIDOROV	{"email": "sidorovnikolay.021965@postgrespro.ru", "phone": "+70796675330"}
0005434601338	13DC16	8071 288536	KIRILL STEPANOV	{"email": "stepanov_kirill_05071969@postgrespro.ru", "phone": "+70095054093"}
0005434601339	13DC16	5757 332998	RAISA CHERNOVA	{"email": "chernovaraisa1968@postgrespro.ru", "phone": "+70144514483"}
0005434601340	367826	2633 460561	ANASTASIYA IVANOVA	{"phone": "+70582261320"}
0005434601341	34D019	0454 050799	ANDREY MIRONOV	{"phone": "+70600840559"}
0005434601342	34D019	3768 030577	ILYA ZAYCEV	{"email": "zaycev.ilya-101974@postgrespro.ru", "phone": "+70864201865"}
0005434601343	34D019	6448 487409	IRINA MAKSIMOVA	{"phone": "+70523694300"}
0005434601344	6B62D8	2403 912585	ELENA PAVLOVA	{"email": "pavlovae_1979@postgrespro.ru", "phone": "+70882973846"}
0005434601345	6EE15D	0137 417090	LIDIYA KISELEVA	{"email": "kiseleva_lidiya041972@postgrespro.ru", "phone": "+70926813398"}
0005434601346	C5E3DF	9416 101934	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr-071976@postgrespro.ru", "phone": "+70868080963"}
0005434601347	C5E3DF	6876 928894	VLADIMIR KUDRYASHOV	{"email": "kudryashov.v-081966@postgrespro.ru", "phone": "+70917284144"}
0005434601348	08B728	5526 396155	IGOR NIKOLAEV	{"phone": "+70451773084"}
0005434601349	08B728	9121 101298	ALEKSEY AFANASEV	{"email": "afanasev-a12091972@postgrespro.ru", "phone": "+70551095447"}
0005434601350	5ED342	2097 251415	DMITRIY NIKOLAEV	{"email": "d-nikolaev1976@postgrespro.ru", "phone": "+70073759351"}
0005434601351	500DDA	8316 143602	SANIYA PETROVA	{"phone": "+70129357372"}
0005434601352	78B5DB	9356 553527	MARINA IVANOVA	{"email": "marina-ivanova081978@postgrespro.ru", "phone": "+70791516478"}
0005434601353	19CD40	1704 035532	ELENA ZHURAVLEVA	{"phone": "+70200335657"}
0005434601354	516707	9635 192405	YANA NIKOLAEVA	{"email": "nikolaevay1969@postgrespro.ru", "phone": "+70258927245"}
0005434601355	516707	4898 870777	LYUBOV MEDVEDEVA	{"phone": "+70582431453"}
0005434601356	4CB797	5834 626345	ELENA POTAPOVA	{"email": "elena.potapova.091981@postgrespro.ru", "phone": "+70366379388"}
0005434601357	4CB797	0041 032995	PETR NAUMOV	{"email": "naumov-p30091969@postgrespro.ru", "phone": "+70741012803"}
0005434601358	0F9388	0340 252166	ALBERT DMITRIEV	{"phone": "+70663999567"}
0005434601359	0F9388	6204 122731	TATYANA OSIPOVA	{"phone": "+70119437097"}
0005434601360	EA66BE	1901 816231	ROMAN ANTONOV	{"phone": "+70338927805"}
0005434601361	EA66BE	2956 215337	DANILA SOLOVEV	{"email": "d.solovev.1967@postgrespro.ru", "phone": "+70181212687"}
0005434601362	76CD16	2885 724355	VALENTINA ANISIMOVA	{"email": "anisimova_v031975@postgrespro.ru", "phone": "+70314590932"}
0005434601363	76CD16	1242 704908	AYRAT POPOV	{"email": "ayratpopov-1966@postgrespro.ru", "phone": "+70813215623"}
0005434601364	0DC62E	6108 526611	NINA TIMOFEEVA	{"email": "timofeeva_nina.101970@postgrespro.ru", "phone": "+70237697891"}
0005434601365	1C8A32	3400 391686	SVETLANA TITOVA	{"email": "stitova1962@postgrespro.ru", "phone": "+70265212463"}
0005434601366	34C250	3228 173954	MARGARITA SIDOROVA	{"email": "margarita_sidorova.041973@postgrespro.ru", "phone": "+70563466597"}
0005434601367	2A0AFF	4681 937492	ANDREY KUZNECOV	{"email": "kuznecov-a15101964@postgrespro.ru", "phone": "+70598460875"}
0005434601368	C47242	3426 330797	VERA IVANOVA	{"email": "ivanova.vera_081964@postgrespro.ru", "phone": "+70008521265"}
0005434601369	980A90	3026 679696	ANDREY MIRONOV	{"email": "mironov-andrey_121974@postgrespro.ru", "phone": "+70440281334"}
0005434601370	B86598	9996 603081	VIKTOR SMIRNOV	{"email": "v.smirnov.011970@postgrespro.ru", "phone": "+70578622965"}
0005434601371	2A3E0E	6101 444367	EVGENIY KUZNECOV	{"phone": "+70728298979"}
0005434601372	C1E457	1238 210434	DMITRIY NIKITIN	{"phone": "+70543289476"}
0005434601373	C1E457	8325 012045	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana_20011964@postgrespro.ru", "phone": "+70871087758"}
0005434601374	64BCDE	6338 557025	VYACHESLAV TIMOFEEV	{"email": "timofeev-vyacheslav_08011973@postgrespro.ru", "phone": "+70951833900"}
0005434601375	966108	3932 471840	IRINA VOROBEVA	{"email": "vorobeva-i.28071970@postgrespro.ru", "phone": "+70205038340"}
0005434601376	7F352F	5641 589775	YULIYA SOKOLOVA	{"phone": "+70901088009"}
0005434601377	7F352F	6596 073931	NATALYA IVANOVA	{"email": "ivanova.n.091964@postgrespro.ru", "phone": "+70699029248"}
0005434601378	644277	3277 571267	EKATERINA KUZNECOVA	{"phone": "+70968441878"}
0005434601379	644277	3789 588019	EKATERINA CHERNOVA	{"phone": "+70596703891"}
0005434601380	245283	3995 470582	YULIYA TIKHONOVA	{"email": "yuliya.tikhonova-121980@postgrespro.ru", "phone": "+70909616811"}
0005434601381	245283	1430 996279	SERGEY NAUMOV	{"email": "sergey.naumov061978@postgrespro.ru", "phone": "+70652588516"}
0005434601382	1A97E3	7197 242347	VIKTORIYA ANDREEVA	{"email": "andreeva.viktoriya.1988@postgrespro.ru", "phone": "+70841142685"}
0005434601383	724F47	6536 759795	DANIIL DMITRIEV	{"email": "dmitriev_d_031981@postgrespro.ru", "phone": "+70617587226"}
0005434601384	724F47	9005 411538	ALEKSANDR KOZLOV	{"email": "kozlov.a22051967@postgrespro.ru", "phone": "+70698094628"}
0005434601385	2C2507	7029 637502	EVGENIY KUZNECOV	{"phone": "+70981570623"}
0005434601386	C65C38	4101 883122	NATALYA EGOROVA	{"email": "egorovanatalya.1967@postgrespro.ru", "phone": "+70943438954"}
0005434601387	9A0ECB	0552 530598	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr.1976@postgrespro.ru", "phone": "+70948611281"}
0005434601388	EB731C	6958 623832	SALAVAT PAVLOV	{"email": "salavatpavlov-16111976@postgrespro.ru", "phone": "+70314267042"}
0005434601389	8BA4CE	6544 108169	VIKTOR ZHURAVLEV	{"email": "zhuravlev.viktor-1973@postgrespro.ru", "phone": "+70705738145"}
0005434601390	EAA1CF	3429 569864	ANASTASIYA YAKOVLEVA	{"phone": "+70945139851"}
0005434601391	EAA1CF	2577 171572	LYUDMILA NIKITINA	{"phone": "+70006628686"}
0005434601392	DB85CE	5160 294887	TATYANA IVANOVA	{"email": "tatyana_ivanova_101965@postgrespro.ru", "phone": "+70473756729"}
0005434601393	F884A5	0250 208090	EVGENIY POPOV	{"phone": "+70853746339"}
0005434601394	F884A5	8747 393209	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr18031971@postgrespro.ru", "phone": "+70925007354"}
0005434601395	D5C6C3	2045 203052	VALERIY PETROV	{"phone": "+70569030986"}
0005434601396	F0CC71	4818 325958	KONSTANTIN ABRAMOV	{"phone": "+70738536135"}
0005434601397	F0CC71	5108 638479	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova-071973@postgrespro.ru", "phone": "+70796095213"}
0005434601398	F98297	1553 870022	VALENTINA EGOROVA	{"phone": "+70042358767"}
0005434601399	96E64C	6221 444578	GLEB IVANOV	{"phone": "+70445547548"}
0005434601400	23D6F5	9503 517133	ANTON MARTYNOV	{"phone": "+70090213690"}
0005434601401	23D6F5	7957 308225	TATYANA GUSEVA	{"phone": "+70110900912"}
0005434601402	700298	5050 275788	SERGEY FEDOROV	{"phone": "+70111121567"}
0005434601403	700298	0178 279650	VALERIYA ALEKSEEVA	{"email": "v_alekseeva12071975@postgrespro.ru", "phone": "+70081193860"}
0005434601404	2D2C16	6777 157234	SERGEY GORBUNOV	{"phone": "+70242600958"}
0005434601405	36E99E	8459 404766	NATALYA SIDOROVA	{"email": "sidorovanatalya_091982@postgrespro.ru", "phone": "+70324097451"}
0005434601406	36E99E	8205 887235	YULIYA KONOVALOVA	{"phone": "+70933394102"}
0005434601407	63A637	5606 758469	NATALYA VLASOVA	{"email": "n-vlasova051968@postgrespro.ru", "phone": "+70560842500"}
0005434601408	63A637	3866 990125	VLADIMIR KUDRYASHOV	{"email": "v-kudryashov_26101973@postgrespro.ru", "phone": "+70610341720"}
0005434601409	3AC53D	9455 835938	VLADIMIR ZAKHAROV	{"phone": "+70756723590"}
0005434601410	3AC53D	8100 073421	TAMARA LAZAREVA	{"phone": "+70032845677"}
0005434601411	14B72F	8887 775765	GALINA PETROVA	{"email": "petrova_galina_1968@postgrespro.ru", "phone": "+70345254636"}
0005434601412	14B72F	1589 981073	IRINA ZAKHAROVA	{"phone": "+70684531179"}
0005434601413	14B72F	1373 089665	ZINAIDA AKIMOVA	{"phone": "+70699659372"}
0005434601414	2E4C4B	9812 326129	ELENA MOISEEVA	{"phone": "+70320912781"}
0005434601415	A21D16	1022 043156	OLGA MIKHAYLOVA	{"phone": "+70885473884"}
0005434601416	A21D16	5305 779857	SERGEY SERGEEV	{"email": "sergeev_sergey-1973@postgrespro.ru", "phone": "+70645527598"}
0005434601417	A21D16	8603 965451	VASILIY MAKAROV	{"email": "vmakarov_1986@postgrespro.ru", "phone": "+70927743199"}
0005434601418	B76826	8638 386736	ALEKSANDRA MATVEEVA	{"email": "matveeva_a.011985@postgrespro.ru", "phone": "+70859058481"}
0005434601419	FCD412	9157 957231	TAISIYA LUKYANOVA	{"email": "t.lukyanova_19041974@postgrespro.ru", "phone": "+70090137349"}
0005434601420	61F35E	6242 704307	FARID VOLKOV	{"phone": "+70848695111"}
0005434601421	2D4623	6663 691164	SERGEY EGOROV	{"email": "s_egorov.1969@postgrespro.ru", "phone": "+70450629543"}
0005434601422	420320	4737 819918	TATYANA TITOVA	{"email": "t-titova111975@postgrespro.ru", "phone": "+70296920171"}
0005434601423	7D0BDE	0030 035919	ANDREY KUZNECOV	{"email": "andrey_kuznecov-111974@postgrespro.ru", "phone": "+70360353307"}
0005434601424	7D0BDE	1179 337712	YURIY YAKOVLEV	{"email": "yuriy-yakovlev_1973@postgrespro.ru", "phone": "+70867624396"}
0005434601425	157DA0	8458 415740	KSENIYA NIKOLAEVA	{"email": "kseniyanikolaeva041984@postgrespro.ru", "phone": "+70415522649"}
0005434601426	55898A	5810 881017	OLGA NIKOLAEVA	{"email": "nikolaevaolga_1983@postgrespro.ru", "phone": "+70767086004"}
0005434601427	1C44EF	6472 672146	MARINA MELNIKOVA	{"phone": "+70797685597"}
0005434601428	A45650	9434 963241	IRINA KISELEVA	{"email": "irina.kiseleva24121970@postgrespro.ru", "phone": "+70553575975"}
0005434601429	553362	0818 026684	ALEKSANDR GORBUNOV	{"email": "gorbunov.aleksandr.11031968@postgrespro.ru", "phone": "+70254819473"}
0005434601430	C7531F	8266 797937	RAVIL VASILEV	{"email": "vasilev.r.121976@postgrespro.ru", "phone": "+70009042092"}
0005434601431	C7531F	1229 407149	ALEKSANDRA KOROLEVA	{"phone": "+70003875337"}
0005434601432	C4BF06	2684 389219	SERGEY GRIGOREV	{"phone": "+70533936039"}
0005434601433	703DC0	1364 582724	MARINA LEBEDEVA	{"email": "lebedevam.03091967@postgrespro.ru", "phone": "+70925701851"}
0005434601434	C4892B	0639 345918	KSENIYA POPOVA	{"email": "popova.k_081978@postgrespro.ru", "phone": "+70698409336"}
0005434601435	609A4E	9097 436751	SERGEY SAVELEV	{"email": "savelev_sergey.1973@postgrespro.ru", "phone": "+70731579430"}
0005434601436	A3E8F2	1861 289675	ILYA MAKSIMOV	{"email": "maksimov-i08071967@postgrespro.ru", "phone": "+70204883097"}
0005434601437	615FF7	6570 161944	EKATERINA ANTONOVA	{"phone": "+70252382091"}
0005434601438	BEE7C1	2705 369906	ANNA GAVRILOVA	{"email": "agavrilova-121978@postgrespro.ru", "phone": "+70856682356"}
0005434601439	BEE7C1	8259 150254	ROMAN ISAEV	{"phone": "+70080461035"}
0005434601440	70E1C6	6183 631878	ALEKSANDR SERGEEV	{"phone": "+70463185100"}
0005434601441	61641A	5335 297249	ANATOLIY KOZLOV	{"email": "kozlov.a-1967@postgrespro.ru", "phone": "+70427380643"}
0005434601442	E78080	0537 143194	ELENA OVCHINNIKOVA	{"email": "ovchinnikova_elena-20071964@postgrespro.ru", "phone": "+70577064436"}
0005434601443	604991	8784 209734	KIRILL SHEVCHENKO	{"email": "shevchenkok_03081969@postgrespro.ru", "phone": "+70675625835"}
0005434601444	604991	1267 482123	OLEG NIKOLAEV	{"phone": "+70725132017"}
0005434601445	DC68FF	7540 288454	VALENTIN ALEKSANDROV	{"email": "valentinaleksandrov23051971@postgrespro.ru", "phone": "+70722491326"}
0005434601446	1A5193	1961 891607	VALENTINA PAVLOVA	{"phone": "+70133424608"}
0005434601447	0FCE8C	4825 800736	KAMIL DAVYDOV	{"email": "k_davydov011966@postgrespro.ru", "phone": "+70726145055"}
0005434601448	0FCE8C	7067 687616	SVETLANA ANTONOVA	{"email": "s_antonova_011961@postgrespro.ru", "phone": "+70254878617"}
0005434601449	0FCE8C	0982 591129	NIKITA CHERNOV	{"phone": "+70109265123"}
0005434601450	B2FE7C	1872 244511	ALEVTINA NESTEROVA	{"email": "nesterova.alevtina-1976@postgrespro.ru", "phone": "+70808445799"}
0005434601451	788B2F	1625 459142	ELENA BORISOVA	{"email": "e.borisova-23011980@postgrespro.ru", "phone": "+70725605524"}
0005434601452	08C1F4	0951 851071	SVETLANA SCHERBAKOVA	{"email": "sscherbakova-1979@postgrespro.ru", "phone": "+70665006951"}
0005434601453	5F6614	4844 735450	IVAN KUZNECOV	{"phone": "+70571568304"}
0005434601454	5F6614	3093 824209	TATYANA FILATOVA	{"phone": "+70343572740"}
0005434601455	8A3341	8739 544146	NIKOLAY FILIPPOV	{"email": "n-filippov1982@postgrespro.ru", "phone": "+70303162708"}
0005434601456	B07C66	6999 006563	MAKSIM KAZAKOV	{"phone": "+70644883705"}
0005434601457	B07C66	9250 329020	LEYLA NOVIKOVA	{"phone": "+70013512152"}
0005434601458	B07C66	3902 941574	NADEZHDA KAZAKOVA	{"email": "n-kazakova091969@postgrespro.ru", "phone": "+70698385319"}
0005434601459	E8A364	2812 927928	DMITRIY AFANASEV	{"email": "afanasev-d_1976@postgrespro.ru", "phone": "+70571514115"}
0005434601460	DCA1E5	4025 969725	DAMIR BELOV	{"email": "d-belov.10111963@postgrespro.ru", "phone": "+70574336131"}
0005434601461	178D98	8795 409245	TAMARA KUZNECOVA	{"email": "kuznecova_tamara_1970@postgrespro.ru", "phone": "+70245563953"}
0005434601462	A8F13B	1969 291840	LIDIYA ANDREEVA	{"email": "lidiya.andreeva041979@postgrespro.ru", "phone": "+70888933530"}
0005434601463	A8F13B	2181 437815	ALEKSANDR BORISOV	{"phone": "+70552097327"}
0005434601464	80EC2D	0679 635261	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr_02081972@postgrespro.ru", "phone": "+70205502352"}
0005434601465	645FA8	2259 264610	KIRA ZAKHAROVA	{"email": "zakharova.k_17071968@postgrespro.ru", "phone": "+70658990614"}
0005434601466	645FA8	7660 601555	VERA KUZNECOVA	{"phone": "+70071691425"}
0005434601467	645FA8	3699 773425	ANDREY SHEVCHENKO	{"email": "andreyshevchenko.071966@postgrespro.ru", "phone": "+70504875212"}
0005434601468	33F3BB	1948 177198	LYUBOV PETROVA	{"email": "petrova_lyubov111977@postgrespro.ru", "phone": "+70247918116"}
0005434601469	36312A	9317 556156	VALENTINA MAKSIMOVA	{"email": "maksimovavalentina-1979@postgrespro.ru", "phone": "+70182479136"}
0005434601470	0A3FA7	2698 831761	ANTONINA BELYAEVA	{"phone": "+70964149002"}
0005434601471	336E40	9295 375334	TATYANA MARTYNOVA	{"phone": "+70939928722"}
0005434601472	E6213E	2951 726354	ILYA MIKHAYLOV	{"phone": "+70548163952"}
0005434601473	6B213D	6856 503570	TAMARA ZHUKOVA	{"email": "t_zhukova_031966@postgrespro.ru", "phone": "+70232503345"}
0005434601474	E35403	1534 574503	VIKTOR VASILEV	{"phone": "+70836816393"}
0005434601475	CD42BB	9005 128872	NAIL VASILEV	{"phone": "+70981542174"}
0005434601476	CD42BB	5828 158241	SERGEY MAKAROV	{"email": "makarov.s.1975@postgrespro.ru", "phone": "+70773214529"}
0005434601477	8DA18D	4476 495974	OLEG ILIN	{"phone": "+70790751119"}
0005434601478	1DD920	9752 400839	RAISA ALEKSEEVA	{"phone": "+70703694400"}
0005434601479	38DDD9	0660 741662	IVAN FILIPPOV	{"email": "ivan-filippov_081976@postgrespro.ru", "phone": "+70406744194"}
0005434601480	38DDD9	0006 708326	MARGARITA YAKOVLEVA	{"email": "myakovleva.30061981@postgrespro.ru", "phone": "+70444037244"}
0005434601481	94CEF0	5285 392046	VLADIMIR VASILEV	{"email": "vladimir.vasilev31071975@postgrespro.ru", "phone": "+70321547558"}
0005434601482	94CEF0	5469 217927	NINA ZAKHAROVA	{"email": "zakharovanina.081964@postgrespro.ru", "phone": "+70614554961"}
0005434601483	94CEF0	5831 188455	TAMARA DMITRIEVA	{"email": "tdmitrieva1968@postgrespro.ru", "phone": "+70491836246"}
0005434601484	94CEF0	7595 766736	NATALYA KISELEVA	{"email": "natalya.kiseleva121969@postgrespro.ru", "phone": "+70676000629"}
0005434601485	DD7BA4	4336 928896	ANTON MIRONOV	{"phone": "+70792637473"}
0005434601486	6E7AEF	4271 781177	NIKITA VOROBEV	{"email": "n.vorobev091973@postgrespro.ru", "phone": "+70750616992"}
0005434601487	6E7AEF	9932 874347	OLEG FROLOV	{"email": "frolov_o.23101967@postgrespro.ru", "phone": "+70113012995"}
0005434601488	E685CE	9617 544292	SERGEY POPOV	{"phone": "+70115944083"}
0005434601489	2F11F9	3546 999442	IGOR POPOV	{"phone": "+70061755373"}
0005434601490	6A3656	6533 991290	ALEKSANDR IVANOV	{"phone": "+70263350483"}
0005434601491	C0D0BD	4517 678914	EGOR MAKAROV	{"email": "makarove.1975@postgrespro.ru", "phone": "+70712389554"}
0005434601492	3FA3F0	8398 331514	YULIYA FROLOVA	{"email": "frolova_yuliya31071968@postgrespro.ru", "phone": "+70523704410"}
0005434601493	946740	0895 921525	DMITRIY VASILEV	{"phone": "+70463436444"}
0005434601494	2E85DB	4161 867282	YULIYA KALININA	{"phone": "+70143997858"}
0005434601495	1342D8	6285 743364	SERGEY PAVLOV	{"email": "sergey_pavlov_24021988@postgrespro.ru", "phone": "+70014446791"}
0005434601496	A6095E	7500 947062	LYUDMILA ALEKSEEVA	{"phone": "+70545873343"}
0005434601497	A6095E	8732 423362	ELENA PAVLOVA	{"phone": "+70977447675"}
0005434601498	C31DC7	4557 848077	NIKITA NAUMOV	{"phone": "+70228941622"}
0005434601499	60EF0A	5062 597875	ALEKSANDRA MELNIKOVA	{"email": "a-melnikova24071981@postgrespro.ru", "phone": "+70590129389"}
0005434601500	60EF0A	3835 059734	SVETLANA PETROVA	{"phone": "+70433033414"}
0005434601501	3DDA43	1466 865726	OLGA KUDRYASHOVA	{"email": "kudryashova.olga-15061978@postgrespro.ru", "phone": "+70854997215"}
0005434601502	4318FF	5692 817453	LYUBOV BELYAEVA	{"phone": "+70751740884"}
0005434601503	14B2A1	5952 086202	OLGA MATVEEVA	{"email": "matveevao-101968@postgrespro.ru", "phone": "+70672468877"}
0005434601504	14B2A1	3828 774651	ALINA KOZLOVA	{"email": "kozlova-alina1978@postgrespro.ru", "phone": "+70325372617"}
0005434601505	568107	8612 710373	STANISLAV MIRONOV	{"phone": "+70615042338"}
0005434601506	568107	7910 487682	GALINA SERGEEVA	{"email": "galina-sergeeva_24061964@postgrespro.ru", "phone": "+70698873866"}
0005434601507	30EA72	3278 268352	ELENA ZHURAVLEVA	{"email": "zhuravleva_e.04031970@postgrespro.ru", "phone": "+70894764490"}
0005434601508	651789	2742 349799	VITALIY TARASOV	{"email": "vitaliytarasov_1954@postgrespro.ru", "phone": "+70559279204"}
0005434601509	651789	3584 761074	RAMILYA MAKAROVA	{"email": "makarovar_1966@postgrespro.ru", "phone": "+70439120002"}
0005434601510	2DEA5B	9199 259304	ANDREY IVANOV	{"email": "ivanov-andrey.1969@postgrespro.ru", "phone": "+70981189816"}
0005434601511	AE0DDE	3117 422140	NINA ILINA	{"email": "ilina_n111966@postgrespro.ru", "phone": "+70352208044"}
0005434601512	C0F105	4807 962747	VITALIY MAKAROV	{"phone": "+70733779850"}
0005434601513	6775B9	7949 817053	ALEKSANDR KULIKOV	{"phone": "+70361721050"}
0005434601514	32C7C6	0064 677399	SERGEY ABRAMOV	{"phone": "+70034815693"}
0005434601515	8AB239	0488 948580	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey021955@postgrespro.ru", "phone": "+70464437814"}
0005434601516	8AB239	4755 327657	ALEKSEY TIKHONOV	{"phone": "+70377344104"}
0005434601517	A04288	4788 779857	VALENTINA NIKIFOROVA	{"phone": "+70174800498"}
0005434601518	A04288	8763 648044	ILYA SAVELEV	{"email": "savelev-ilya_121979@postgrespro.ru", "phone": "+70046764644"}
0005434601519	E6E535	4663 715298	EVGENIYA ZOTOVA	{"email": "e_zotova-1985@postgrespro.ru", "phone": "+70629331934"}
0005434601520	E6E535	0090 986540	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr_1974@postgrespro.ru", "phone": "+70110334634"}
0005434601521	E6E535	0484 287160	ANDREY BONDARENKO	{"email": "abondarenko-15061974@postgrespro.ru", "phone": "+70821982022"}
0005434601522	F39A46	2764 252560	VALERIY VOROBEV	{"phone": "+70244903759"}
0005434601523	860E33	2373 670846	VIKTORIYA MATVEEVA	{"phone": "+70957552333"}
0005434601524	9B33F8	5714 235729	ANATOLIY KOZLOV	{"email": "kozlov.anatoliy_1970@postgrespro.ru", "phone": "+70431333933"}
0005434601525	9B33F8	8540 065129	VLADIMIR NIKOLAEV	{"phone": "+70047586124"}
0005434601526	9B33F8	0073 289849	ROMAN SERGEEV	{"phone": "+70159611347"}
0005434601527	42EDA1	1245 643313	ALEKSANDR NIKITIN	{"phone": "+70140271730"}
0005434601528	42EDA1	4180 734123	NIKOLAY GAVRILOV	{"phone": "+70716537898"}
0005434601529	1CB1F4	5683 007164	MARIYA ALEKSEEVA	{"email": "m.alekseeva.1963@postgrespro.ru", "phone": "+70997324666"}
0005434601530	1CB1F4	6757 417234	SERGEY IVANOV	{"email": "s_ivanov-02011965@postgrespro.ru", "phone": "+70164712512"}
0005434601531	27E57F	1436 986822	TATYANA KUDRYASHOVA	{"phone": "+70965200369"}
0005434601532	27E57F	3371 490654	ANDREY ABRAMOV	{"email": "andrey.abramov-1979@postgrespro.ru", "phone": "+70728117057"}
0005434601533	27E57F	1794 795662	NIKITA SOLOVEV	{"email": "solovev-nikita-1972@postgrespro.ru", "phone": "+70565546641"}
0005434601534	808C70	1209 993490	SVETLANA DMITRIEVA	{"phone": "+70880120131"}
0005434601535	808C70	4601 555288	YULIYA STEPANOVA	{"email": "y.stepanova.011974@postgrespro.ru", "phone": "+70045731145"}
0005434601536	C568C6	0715 920371	IRINA GUSEVA	{"phone": "+70458996616"}
0005434601537	C568C6	6088 418104	MARINA MELNIKOVA	{"phone": "+70849998331"}
0005434601538	78FA2B	8582 690175	VLADIMIR BORISOV	{"phone": "+70649748066"}
0005434601539	12AA12	2339 870150	ANATOLIY MEDVEDEV	{"email": "medvedev.anatoliy.051981@postgrespro.ru", "phone": "+70821910418"}
0005434601540	117766	2275 091632	LYUBOV ZAYCEVA	{"email": "zayceva.l-121976@postgrespro.ru", "phone": "+70110117806"}
0005434601541	CA17BD	9781 500737	ALENA KUZNECOVA	{"phone": "+70712577580"}
0005434601542	CA17BD	5359 617751	NATALYA NESTEROVA	{"email": "nesterovanatalya051960@postgrespro.ru", "phone": "+70031541586"}
0005434601543	D86E46	5346 287288	MAKSIM SERGEEV	{"phone": "+70906452182"}
0005434601544	D86E46	6344 891663	NINA ANTONOVA	{"email": "antonova_nina.17011975@postgrespro.ru", "phone": "+70750289499"}
0005434601545	74CBC3	1068 915093	MARIYA GAVRILOVA	{"email": "gavrilova.mariya-031977@postgrespro.ru", "phone": "+70155080816"}
0005434601546	95F9B9	1651 248903	YULIYA KUDRYASHOVA	{"email": "kudryashovayuliya1975@postgrespro.ru", "phone": "+70611237877"}
0005434601547	ED3825	4090 776396	VERA MOROZOVA	{"email": "veramorozova-17011982@postgrespro.ru", "phone": "+70951590444"}
0005434601548	04F254	5801 923260	YURIY NIKITIN	{"phone": "+70854977014"}
0005434601549	22061D	2772 858318	ALEKSEY STEPANOV	{"email": "aleksey_stepanov-1961@postgrespro.ru", "phone": "+70814849676"}
0005434601550	715670	9420 934285	VLADIMIR ALEKSANDROV	{"phone": "+70433812482"}
0005434601551	2D9632	1289 987973	EVGENIYA PAVLOVA	{"email": "pavlova-e091970@postgrespro.ru", "phone": "+70126744900"}
0005434601552	1DD7ED	7203 418994	ANDREY KUZNECOV	{"phone": "+70335382773"}
0005434601553	BC5AA8	7376 280517	TAMARA DENISOVA	{"email": "t_denisova_02051982@postgrespro.ru", "phone": "+70425969886"}
0005434601554	7FDF6F	8130 656190	ELENA KARPOVA	{"phone": "+70717719115"}
0005434601555	9C9A23	5411 115035	IGOR CHERNOV	{"email": "ichernov1972@postgrespro.ru", "phone": "+70882352977"}
0005434601556	9C9A23	3403 897175	LYUDMILA ANISIMOVA	{"email": "anisimova-lyudmila15121973@postgrespro.ru", "phone": "+70780752019"}
0005434601557	8FBA52	2951 663350	ANATOLIY SCHERBAKOV	{"email": "scherbakov_a30011969@postgrespro.ru", "phone": "+70122786372"}
0005434601558	224A3D	4140 258293	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov_1982@postgrespro.ru", "phone": "+70917800342"}
0005434601559	50435C	6800 298786	NIKITA OSIPOV	{"phone": "+70003224113"}
0005434601560	2250C7	7686 167896	LIDIYA VOLKOVA	{"email": "volkovalidiya.1967@postgrespro.ru", "phone": "+70821365937"}
0005434601561	2250C7	2708 539644	LYUBOV MALYSHEVA	{"phone": "+70132944301"}
0005434601562	2250C7	3045 761673	ANDREY MAKSIMOV	{"email": "amaksimov10031973@postgrespro.ru", "phone": "+70713173669"}
0005434601563	F1697F	1352 444988	KRISTINA NOVIKOVA	{"email": "kristina.novikova.16051975@postgrespro.ru", "phone": "+70312798756"}
0005434601564	F1697F	9662 940416	OLGA MIKHAYLOVA	{"phone": "+70635318636"}
0005434601565	1A5D23	2590 983469	VALERIY MAKAROV	{"phone": "+70641999488"}
0005434601566	1A5D23	3298 174614	RISHAT NIKOLAEV	{"email": "r.nikolaev-30011984@postgrespro.ru", "phone": "+70242209801"}
0005434601567	1A5D23	3896 927172	VALERIY DAVYDOV	{"email": "v_davydov101966@postgrespro.ru", "phone": "+70049842478"}
0005434601568	1A5D23	6286 931695	VIKTOR OSIPOV	{"phone": "+70607657771"}
0005434601569	138487	6110 304883	ALLA NESTEROVA	{"phone": "+70555103387"}
0005434601570	352D98	1388 398580	OKSANA NOVIKOVA	{"phone": "+70847926649"}
0005434601571	B1DCD3	7872 911891	TATYANA PAVLOVA	{"email": "tatyana-pavlova28021968@postgrespro.ru", "phone": "+70975678040"}
0005434601572	E97939	5780 296329	LIDIYA MOROZOVA	{"phone": "+70509438391"}
0005434601573	F2D969	8732 075060	LYUDMILA FADEEVA	{"email": "fadeevalyudmila-121969@postgrespro.ru", "phone": "+70161210737"}
0005434601574	24C81A	0099 961687	GALINA KRASNOVA	{"email": "galinakrasnova.1969@postgrespro.ru", "phone": "+70665662831"}
0005434601575	588D56	8329 457539	GENNADIY MOROZOV	{"email": "g.morozov.101965@postgrespro.ru", "phone": "+70956180556"}
0005434601576	C8E6D3	3828 418051	KRISTINA POLYAKOVA	{"email": "kristinapolyakova091967@postgrespro.ru", "phone": "+70200869325"}
0005434601577	96D439	5028 714370	MARIYA YUDINA	{"email": "yudinamariya-1972@postgrespro.ru", "phone": "+70734416541"}
0005434601578	3D369D	7694 874255	SVETLANA NIKITINA	{"email": "svetlana.nikitina.081972@postgrespro.ru", "phone": "+70499073658"}
0005434601579	641F99	7010 510887	YURIY VASILEV	{"phone": "+70519963390"}
0005434601580	BC7BB0	2748 389937	DMITRIY KOZLOV	{"phone": "+70482924395"}
0005434601581	5C4722	7323 769119	ANDREY DENISOV	{"email": "denisov_a_1988@postgrespro.ru", "phone": "+70700126943"}
0005434601582	0D0228	0723 594804	LINAR MIKHAYLOV	{"email": "mikhaylov_linar-1966@postgrespro.ru", "phone": "+70307898101"}
0005434601583	B68C15	4146 361169	OLGA MIKHAYLOVA	{"phone": "+70306014265"}
0005434601584	B68C15	6685 827096	LARISA STEPANOVA	{"email": "stepanova-l-21091961@postgrespro.ru", "phone": "+70239216495"}
0005434601585	FF27FB	0422 124342	ILYA MATVEEV	{"email": "matveev_ilya.1979@postgrespro.ru", "phone": "+70474862648"}
0005434601586	FF27FB	0764 921346	YURIY MEDVEDEV	{"phone": "+70257119775"}
0005434601587	2245B2	6395 339378	VALERIYA PETROVA	{"email": "vpetrova.1975@postgrespro.ru", "phone": "+70805947894"}
0005434601588	21E9A2	7463 595021	ANTONINA NIKOLAEVA	{"email": "anikolaeva061973@postgrespro.ru", "phone": "+70002736146"}
0005434601589	176473	9920 691207	NADEZHDA KULIKOVA	{"email": "nadezhda-kulikova-061974@postgrespro.ru", "phone": "+70052378899"}
0005434601590	6C386E	6102 424404	SERGEY FILIPPOV	{"phone": "+70678239127"}
0005434601591	6C386E	5810 184723	NATALYA GERASIMOVA	{"email": "natalya_gerasimova-16021961@postgrespro.ru", "phone": "+70038180179"}
0005434601592	148CD7	6237 245066	VLADIMIR PAVLOV	{"email": "v.pavlov.16121958@postgrespro.ru", "phone": "+70906475395"}
0005434601593	E43793	3538 106415	YULIYA BOGDANOVA	{"email": "bogdanova_y_25021976@postgrespro.ru", "phone": "+70859595692"}
0005434601594	E43793	3870 565403	NINA MOROZOVA	{"phone": "+70943577929"}
0005434601595	76B65C	0129 704720	NINA MAKAROVA	{"email": "makarova.n-101972@postgrespro.ru", "phone": "+70675381852"}
0005434601596	1ECA5B	8264 332831	ALEKSANDR DAVYDOV	{"email": "a.davydov101982@postgrespro.ru", "phone": "+70590702664"}
0005434601597	ED1EDD	6650 177468	MIKHAIL CHERNOV	{"email": "chernov.mikhail1967@postgrespro.ru", "phone": "+70623501440"}
0005434601598	220079	8973 116180	KRISTINA MELNIKOVA	{"email": "melnikova-kristina.24101964@postgrespro.ru", "phone": "+70109661160"}
0005434601599	220079	7285 901908	BORIS DAVYDOV	{"email": "davydovb-081968@postgrespro.ru", "phone": "+70237221935"}
0005434602858	79FB39	0990 556865	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr_1962@postgrespro.ru", "phone": "+70746448592"}
0005434602859	2D5A25	6655 328267	ALEKSEY POPOV	{"phone": "+70095701430"}
0005434602860	44EA77	6817 114815	BORIS MOROZOV	{"phone": "+70390357239"}
0005434602861	FF80F7	7425 595297	ANNA FROLOVA	{"phone": "+70147396153"}
0005434602862	FF80F7	6876 615666	LARISA KOROLEVA	{"email": "koroleva.l_081969@postgrespro.ru", "phone": "+70588921911"}
0005434602863	FF80F7	4113 187992	MARINA MAKAROVA	{"email": "marina.makarova_101973@postgrespro.ru", "phone": "+70456842632"}
0005434602864	93C3F8	6891 343538	NAILYA OVCHINNIKOVA	{"email": "ovchinnikova.n111975@postgrespro.ru", "phone": "+70367320354"}
0005434602865	B2707D	6437 045440	SERGEY BELOV	{"phone": "+70222952596"}
0005434602866	D65926	1955 473121	SERGEY MEDVEDEV	{"phone": "+70392979467"}
0005434602867	D65926	9074 961817	NATALYA ISAEVA	{"email": "isaeva-natalya26081974@postgrespro.ru", "phone": "+70544395591"}
0005434602868	01580E	8895 982603	VALERIY SOKOLOV	{"email": "sokolov_v-121980@postgrespro.ru", "phone": "+70685188923"}
0005434602869	01580E	8059 110863	ELENA BORISOVA	{"email": "elena.borisova.16051960@postgrespro.ru", "phone": "+70160908603"}
0005434602870	50566C	0870 030011	EDUARD SERGEEV	{"phone": "+70147570369"}
0005434602871	50566C	7158 242921	NADEZHDA POPOVA	{"email": "popova_nadezhda.12081980@postgrespro.ru", "phone": "+70049033442"}
0005434602872	E10FE5	1684 184805	ALLA IVANOVA	{"phone": "+70533061301"}
0005434602873	B96D1A	7479 262731	OLGA KOROLEVA	{"phone": "+70876250384"}
0005434602874	B96D1A	9533 668380	VALERIY NOVIKOV	{"email": "vnovikov_08071968@postgrespro.ru", "phone": "+70778028890"}
0005434602875	FEABFA	9712 756933	OLGA MIKHAYLOVA	{"email": "mikhaylovaolga.1965@postgrespro.ru", "phone": "+70625731640"}
0005434602876	FEABFA	9243 705124	SOFIYA FILATOVA	{"phone": "+70758365871"}
0005434602877	B9F078	5608 525711	IRINA ANISIMOVA	{"phone": "+70283227926"}
0005434602878	B9F078	5361 151129	VLADISLAV POPOV	{"phone": "+70125046753"}
0005434602879	07A725	1398 365058	GALINA GERASIMOVA	{"phone": "+70443846906"}
0005434602880	84D770	2972 922979	TATYANA IVANOVA	{"phone": "+70362737826"}
0005434602881	84D770	8126 386777	ROMAN KRASNOV	{"email": "r-krasnov.17051967@postgrespro.ru", "phone": "+70853184316"}
0005434602882	2827B1	8366 187654	PETR SIDOROV	{"email": "sidorov-petr1975@postgrespro.ru", "phone": "+70927989513"}
0005434602883	2827B1	0724 723130	SERGEY NIKOLAEV	{"phone": "+70916603908"}
0005434602884	CFEE8C	9778 150966	DENIS ZAKHAROV	{"phone": "+70312670884"}
0005434602885	EA358E	8135 073713	MARINA ALEKSANDROVA	{"email": "aleksandrova_m_22031965@postgrespro.ru", "phone": "+70011423249"}
0005434602886	93767E	6375 319165	GALINA NAZAROVA	{"email": "nazarovagalina.08101955@postgrespro.ru", "phone": "+70451838323"}
0005434602887	D4A1E3	4096 939247	OLEG ABRAMOV	{"phone": "+70123551547"}
0005434602888	C558B9	9139 519458	NINA POTAPOVA	{"email": "potapova-nina-12121983@postgrespro.ru", "phone": "+70110451251"}
0005434602889	36209D	9150 575243	RUSTEM IVANOV	{"email": "r_ivanov-05041971@postgrespro.ru", "phone": "+70711363162"}
0005434602890	9FF73E	7730 894291	DMITRIY ANDREEV	{"phone": "+70987436304"}
0005434602891	BD9D08	9426 457219	MARINA TIKHONOVA	{"phone": "+70526383393"}
0005434602892	9B9F48	4467 104015	SERGEY NIKOLAEV	{"phone": "+70260190786"}
0005434602893	31FAD1	7443 364174	ALEKSANDR KUDRYASHOV	{"phone": "+70599329460"}
0005434602894	5A5DB5	2309 442992	LYUDMILA VOLKOVA	{"phone": "+70795057820"}
0005434602895	EBAD23	6004 894331	POLINA ANTONOVA	{"email": "p_antonova_071980@postgrespro.ru", "phone": "+70285941466"}
0005434602896	BAF302	1151 740284	EVGENIY NOVIKOV	{"email": "evgeniy-novikov.19111969@postgrespro.ru", "phone": "+70966920862"}
0005434602897	C9744A	4901 795462	NIKOLAY MIKHAYLOV	{"phone": "+70112541975"}
0005434602898	C9744A	3896 631924	MARIYA IVANOVA	{"phone": "+70903094476"}
0005434602899	B48117	7260 682861	GUZEL NIKITINA	{"email": "guzel.nikitina.1966@postgrespro.ru", "phone": "+70309524469"}
0005434602900	B6C505	3461 278339	LYUDMILA KRASNOVA	{"email": "krasnova_l.25061977@postgrespro.ru", "phone": "+70965379779"}
0005434602901	B10920	5134 002987	ELENA SMIRNOVA	{"phone": "+70361112344"}
0005434602902	B10920	4688 621955	VLADIMIR SOROKIN	{"email": "sorokin-v.031974@postgrespro.ru", "phone": "+70082097280"}
0005434602903	EC678A	8632 278860	VASILISA DANILOVA	{"email": "danilova_vasilisa_1964@postgrespro.ru", "phone": "+70942510022"}
0005434602904	8AA450	6406 746832	ARTEM YAKOVLEV	{"email": "ayakovlev011948@postgrespro.ru", "phone": "+70273249039"}
0005434602905	D30C17	4883 276937	VADIM KISELEV	{"email": "kiselev.v-01091973@postgrespro.ru", "phone": "+70119881873"}
0005434602906	D30C17	5889 759088	NATALYA ZAKHAROVA	{"phone": "+70814571147"}
0005434602907	7A5011	4315 092113	NADEZHDA BOGDANOVA	{"phone": "+70223508575"}
0005434602908	7A5011	0341 793033	KLAVDIYA MIRONOVA	{"phone": "+70062651294"}
0005434602909	C04697	4521 046343	VLADIMIR IVANOV	{"phone": "+70455801132"}
0005434602910	EFBB37	9292 197309	YURIY ROMANOV	{"email": "romanovy_1980@postgrespro.ru", "phone": "+70767153106"}
0005434602911	E00CC6	9059 899479	ANNA FROLOVA	{"phone": "+70288189731"}
0005434602912	F36837	5325 100938	LYUBOV KULIKOVA	{"phone": "+70504589506"}
0005434602913	E5500C	3143 870086	NINA ILINA	{"email": "ilinanina-061965@postgrespro.ru", "phone": "+70904890860"}
0005434602914	76BCAD	6107 595028	NIKOLAY RODIONOV	{"email": "rodionov.n_12121975@postgrespro.ru", "phone": "+70130467133"}
0005434602915	9BD872	4148 162442	VLADISLAV ALEKSEEV	{"email": "v.alekseev_12031983@postgrespro.ru", "phone": "+70164898828"}
0005434602916	F316B3	8815 697801	VALERIY ZAKHAROV	{"phone": "+70085155226"}
0005434602917	EA6F31	6302 542874	PETR IVANOV	{"email": "ivanov.petr_01091983@postgrespro.ru", "phone": "+70868813452"}
0005434602918	3210F0	9758 038609	GALINA SOROKINA	{"email": "g-sorokina021985@postgrespro.ru", "phone": "+70205960614"}
0005434602919	3210F0	6621 470202	VLADIMIR BONDARENKO	{"phone": "+70414084789"}
0005434602920	38A0F7	3022 293281	DARYA GERASIMOVA	{"email": "d_gerasimova_1970@postgrespro.ru", "phone": "+70288171927"}
0005434602921	58F82A	2240 368694	SOFYA IVANOVA	{"email": "sofya-ivanova_1980@postgrespro.ru", "phone": "+70838812757"}
0005434602922	58F82A	4455 873750	OLGA FEDOROVA	{"email": "fedorova_o-20011970@postgrespro.ru", "phone": "+70571055895"}
0005434602923	C07B09	5851 204247	ELENA BORISOVA	{"email": "borisova_elena.14071969@postgrespro.ru", "phone": "+70987242113"}
0005434602924	C07B09	8944 006860	ANATOLIY EGOROV	{"email": "egorovanatoliy-031977@postgrespro.ru", "phone": "+70569677655"}
0005434602925	7A9C79	2325 688186	ALEKSANDRA TARASOVA	{"email": "a.tarasova_05081968@postgrespro.ru", "phone": "+70102532747"}
0005434602926	9CE3CC	9964 128118	KONSTANTIN DAVYDOV	{"phone": "+70724073648"}
0005434602927	A5BDF2	8522 396464	VLADIMIR POPOV	{"email": "vladimir-popov-011970@postgrespro.ru", "phone": "+70390627250"}
0005434602928	B45C6D	3850 501483	GYUZEL BARANOVA	{"phone": "+70555382851"}
0005434602929	1F1F26	5897 706649	VALENTINA KOROLEVA	{"phone": "+70772617723"}
0005434602930	1F1F26	4492 915243	LYUBOV MIRONOVA	{"phone": "+70324589740"}
0005434602931	1F1F26	7729 656124	YULIYA ZHURAVLEVA	{"phone": "+70279534473"}
0005434602932	6FBE81	4355 633597	EVGENIY MATVEEV	{"phone": "+70043232706"}
0005434602933	6FBE81	9628 071548	EKATERINA ANTONOVA	{"email": "e-antonova.18121977@postgrespro.ru", "phone": "+70628212031"}
0005434602934	E82001	1453 455618	TATYANA FROLOVA	{"email": "tatyana.frolova-1971@postgrespro.ru", "phone": "+70774313173"}
0005434602935	90B918	1565 243294	VLADIMIR BARANOV	{"phone": "+70507425446"}
0005434602936	B395E1	3827 074243	EKATERINA TIKHONOVA	{"phone": "+70348009417"}
0005434602937	75C90A	2933 659445	NATALYA BELOVA	{"email": "belova_natalya11071953@postgrespro.ru", "phone": "+70521007134"}
0005434602938	51F698	1274 202373	KRISTINA POPOVA	{"email": "popova_k.091982@postgrespro.ru", "phone": "+70922636309"}
0005434602939	51F698	6300 673887	PETR ZAYCEV	{"phone": "+70386745484"}
0005434602940	3274A2	9998 441486	TATYANA AFANASEVA	{"phone": "+70989473389"}
0005434602941	597E4E	5020 743343	BORIS ROMANOV	{"email": "bromanov_21101976@postgrespro.ru", "phone": "+70126502988"}
0005434602942	597E4E	4245 120883	ALEKSANDR BELOV	{"phone": "+70791976400"}
0005434602943	66C371	0847 566902	MIKHAIL SOLOVEV	{"email": "mikhail-solovev-011976@postgrespro.ru", "phone": "+70998099846"}
0005434602944	745A29	5645 621855	DARYA BOGDANOVA	{"phone": "+70988464320"}
0005434602945	96B580	2805 698638	PETR ZAKHAROV	{"email": "zakharov-petr.101972@postgrespro.ru", "phone": "+70657774198"}
0005434602946	F1FC8F	1451 194203	MIKHAIL PETROV	{"email": "petrovm-1971@postgrespro.ru", "phone": "+70024739811"}
0005434602947	99A6E4	6706 335606	FAINA MAKAROVA	{"phone": "+70056945204"}
0005434602948	F25504	9879 246798	NATALYA GORBUNOVA	{"phone": "+70628062400"}
0005434602949	1C0FC6	2243 271987	MARK MELNIKOV	{"phone": "+70190178573"}
0005434602950	1C0FC6	6323 890623	IVAN MAKSIMOV	{"phone": "+70490870991"}
0005434602951	FD8DDC	9409 379032	EKATERINA ROMANOVA	{"phone": "+70114733544"}
0005434602952	17A5A4	5826 182913	IRINA MATVEEVA	{"email": "irina_matveeva_1976@postgrespro.ru", "phone": "+70399021594"}
0005434602953	48CA60	0985 243983	RAMIL FEDOROV	{"email": "r.fedorov081984@postgrespro.ru", "phone": "+70301631814"}
0005434602954	95D876	1214 098779	LYUDMILA KAZAKOVA	{"email": "kazakova.lyudmila071974@postgrespro.ru", "phone": "+70949028695"}
0005434602955	95D876	4050 945974	YULIYA GRISHINA	{"email": "yuliya.grishina.021975@postgrespro.ru", "phone": "+70404923839"}
0005434602956	D70C65	7923 624877	YAKOV NOVIKOV	{"phone": "+70070860473"}
0005434602957	431ABC	4162 061986	NADEZHDA KONDRATEVA	{"email": "n_kondrateva-1971@postgrespro.ru", "phone": "+70906795878"}
0005434602958	503E10	3650 619620	MAKSIM FILIPPOV	{"phone": "+70073341164"}
0005434602959	503E10	0972 312392	OKSANA SERGEEVA	{"email": "sergeeva_o_1967@postgrespro.ru", "phone": "+70282874877"}
0005434602960	503E10	7325 769163	PELAGEYA NAZAROVA	{"email": "nazarova-pelageya-1972@postgrespro.ru", "phone": "+70123697155"}
0005434602961	AA5FB2	4161 627718	VIKTOR ZHURAVLEV	{"phone": "+70537970466"}
0005434602962	AA5FB2	1543 966696	SERGEY ABRAMOV	{"phone": "+70475723463"}
0005434602963	5AD41E	7009 772774	IVAN MAKAROV	{"phone": "+70714785550"}
0005434602964	5AD41E	1914 657172	ALEKSANDR SERGEEV	{"email": "asergeev-12101975@postgrespro.ru", "phone": "+70543402678"}
0005434602965	990234	1038 888884	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_031983@postgrespro.ru", "phone": "+70029781263"}
0005434602966	990234	5538 539452	MIKHAIL KISELEV	{"phone": "+70340062147"}
0005434602967	B74328	0115 066611	VERA IVANOVA	{"phone": "+70126704201"}
0005434602968	524373	5738 794357	SERGEY IVANOV	{"email": "sergeyivanov-1976@postgrespro.ru", "phone": "+70333911571"}
0005434602969	BC6B18	1319 788881	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.041974@postgrespro.ru", "phone": "+70634406504"}
0005434602970	CC1841	0444 637776	SVETLANA SERGEEVA	{"phone": "+70060390503"}
0005434602971	71C301	4343 525104	VERA MIRONOVA	{"email": "mironova.v24031979@postgrespro.ru", "phone": "+70522630429"}
0005434602972	04971B	7289 841415	NATALYA STEPANOVA	{"email": "natalya.stepanova_031968@postgrespro.ru", "phone": "+70804232137"}
0005434602973	CA55A2	4546 462899	TATYANA POPOVA	{"phone": "+70564281156"}
0005434602974	B7D55A	3304 033963	ALEKSANDR NIKOLAEV	{"email": "aleksandrnikolaev-1979@postgrespro.ru", "phone": "+70948223328"}
0005434602975	D3B212	2391 803856	OLGA STEPANOVA	{"phone": "+70377508345"}
0005434602976	D3B212	9644 036575	OLGA KONDRATEVA	{"email": "kondrateva_o.031973@postgrespro.ru", "phone": "+70215924962"}
0005434602977	B2A40C	9758 897549	IBRAGIM MEDVEDEV	{"phone": "+70223897237"}
0005434602978	55249F	6858 700248	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev.111969@postgrespro.ru", "phone": "+70672492521"}
0005434602979	CA6863	4967 875443	NATALYA ANDREEVA	{"phone": "+70019003905"}
0005434602980	CA6863	1377 632684	GALINA TROFIMOVA	{"email": "gtrofimova_1959@postgrespro.ru", "phone": "+70063537417"}
0005434602981	95A289	4005 024558	MARINA NOVIKOVA	{"email": "novikova.marina12041977@postgrespro.ru", "phone": "+70268349103"}
0005434602982	B4587D	2030 439259	SERGEY SERGEEV	{"email": "ssergeev_071976@postgrespro.ru", "phone": "+70159629194"}
0005434603019	97C5F0	3290 724840	LARISA GAVRILOVA	{"email": "gavrilova-larisa1969@postgrespro.ru", "phone": "+70634285411"}
0005434603020	FD038D	6237 288625	IRINA SOLOVEVA	{"email": "irina_soloveva.24061974@postgrespro.ru", "phone": "+70079110891"}
0005434603021	E8E9B2	7681 688499	EVGENIY SOLOVEV	{"email": "solovev_e.1969@postgrespro.ru", "phone": "+70278554022"}
0005434603022	E8E9B2	3455 094381	EKATERINA MASLOVA	{"email": "ekaterinamaslova091968@postgrespro.ru", "phone": "+70131060790"}
0005434603023	221CBB	2849 352799	SABINA SOROKINA	{"email": "sabina_sorokina-03061973@postgrespro.ru", "phone": "+70347867334"}
0005434603024	C5E4AC	4940 203279	YURIY MELNIKOV	{"email": "melnikov_yuriy.08051966@postgrespro.ru", "phone": "+70974360923"}
0005434603025	C5E4AC	3839 827938	NIKOLAY TIMOFEEV	{"email": "nikolay-timofeev.09071977@postgrespro.ru", "phone": "+70549457026"}
0005434603026	88E317	2575 542931	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov.061959@postgrespro.ru", "phone": "+70260731162"}
0005434603027	88E317	6711 816580	TATYANA NOVIKOVA	{"email": "novikovat_091961@postgrespro.ru", "phone": "+70908925847"}
0005434604892	AEDC19	6428 279839	NADEZHDA CHERNOVA	{"phone": "+70262501504"}
0005434604837	128BAE	9714 630753	LYUDMILA DENISOVA	{"email": "denisoval.08031965@postgrespro.ru", "phone": "+70266987372"}
0005434604838	2F689D	1832 328675	VALENTIN KUZNECOV	{"phone": "+70534784193"}
0005434604839	2F689D	0963 437633	VLADIMIR STEPANOV	{"email": "stepanov-v.121974@postgrespro.ru", "phone": "+70293911453"}
0005434604840	A2FA89	1197 559214	VLADIMIR MELNIKOV	{"phone": "+70938699824"}
0005434604841	4D6C06	0519 482383	NATALIYA ORLOVA	{"phone": "+70831449041"}
0005434604842	4D6C06	8396 924065	ANATOLIY AFANASEV	{"email": "afanasev_anatoliy-081968@postgrespro.ru", "phone": "+70580367878"}
0005434604843	56F449	7648 498542	IRINA POPOVA	{"email": "popova.i-07061976@postgrespro.ru", "phone": "+70359548210"}
0005434604844	56F449	8520 949424	IGOR IVANOV	{"phone": "+70682433219"}
0005434604845	4C31F5	4262 930041	MARINA ANDREEVA	{"email": "andreevamarina-071977@postgrespro.ru", "phone": "+70005372761"}
0005434604846	EB3B24	5551 706578	KONSTANTIN SMIRNOV	{"email": "smirnov-konstantin.1978@postgrespro.ru", "phone": "+70815488945"}
0005434604847	EB3B24	8607 866903	ALEKSEY ILIN	{"phone": "+70447066401"}
0005434604848	780E5A	4733 041568	KRISTINA FEDOROVA	{"email": "k_fedorova.1974@postgrespro.ru", "phone": "+70274696386"}
0005434604849	B11E6F	5850 970035	ANTON NIKITIN	{"email": "nikitin_anton_1968@postgrespro.ru", "phone": "+70293694124"}
0005434604850	B11E6F	0657 747060	ANTON FEDOTOV	{"email": "a-fedotov.30081977@postgrespro.ru", "phone": "+70136345720"}
0005434604851	7AC584	8189 122380	YURIY POPOV	{"phone": "+70715567075"}
0005434604852	7AC584	0868 532941	VALENTIN KUZNECOV	{"email": "kuznecov_v_031975@postgrespro.ru", "phone": "+70507709823"}
0005434604853	B97A8B	0465 201530	ANNA FROLOVA	{"email": "frolova-anna-1976@postgrespro.ru", "phone": "+70456244364"}
0005434604854	66CF5A	8010 146768	LYUBOV ZHUKOVA	{"email": "zhukova-l_11011964@postgrespro.ru", "phone": "+70244480220"}
0005434604855	66CF5A	5984 600164	ANATOLIY DMITRIEV	{"phone": "+70494442249"}
0005434604856	BA73E7	0228 014646	LYUDMILA ALEKSANDROVA	{"phone": "+70549827207"}
0005434604857	9301DC	2020 638118	LEONID OSIPOV	{"phone": "+70964918170"}
0005434604858	9301DC	1564 347282	NADEZHDA KUZMINA	{"email": "n-kuzmina.06051979@postgrespro.ru", "phone": "+70749245620"}
0005434604859	1DCA74	5498 524534	ARINA VLASOVA	{"email": "vlasova.arina-28051971@postgrespro.ru", "phone": "+70733642681"}
0005434604860	AE1E2C	0712 307229	SVETLANA NAUMOVA	{"email": "svetlana_naumova.12021980@postgrespro.ru", "phone": "+70154639882"}
0005434604861	92D551	8710 716965	YURIY SOROKIN	{"email": "sorokinyuriy-1979@postgrespro.ru", "phone": "+70161975288"}
0005434604862	92D551	8177 764861	VLADIMIR KAZAKOV	{"phone": "+70699213325"}
0005434604863	469155	1773 569460	VERA MOROZOVA	{"email": "morozova-v1977@postgrespro.ru", "phone": "+70693753389"}
0005434604864	F1FA5C	7966 502739	TATYANA GRISHINA	{"phone": "+70952997619"}
0005434604865	095A1B	2432 576440	ELENA ARKHIPOVA	{"phone": "+70002717277"}
0005434604866	A5FEFC	5230 848466	ALEKSANDR MIRONOV	{"phone": "+70898773664"}
0005434604867	A5FEFC	5086 459271	NINA DENISOVA	{"phone": "+70234383370"}
0005434604868	C4CB78	4653 549957	LYUBOV GAVRILOVA	{"email": "lyubov-gavrilova.1964@postgrespro.ru", "phone": "+70066693990"}
0005434604869	D546B7	9159 666337	EVGENIY SMIRNOV	{"email": "smirnov_evgeniy-121979@postgrespro.ru", "phone": "+70220757460"}
0005434604870	D546B7	9538 618506	MIKHAIL GORBUNOV	{"email": "gorbunov.m-13051967@postgrespro.ru", "phone": "+70155192196"}
0005434604871	4A95B8	4994 268050	ROMAN YAKOVLEV	{"email": "romanyakovlev_02011976@postgrespro.ru", "phone": "+70354081731"}
0005434604872	D34AC6	0193 851103	ELZA KULIKOVA	{"email": "kulikova-elza-27121965@postgrespro.ru", "phone": "+70789578769"}
0005434604873	D34AC6	6968 467494	EVGENIY KUZNECOV	{"phone": "+70961972337"}
0005434604874	D34AC6	7750 174107	ALEKSEY NIKOLAEV	{"phone": "+70326701079"}
0005434604875	0DD09B	0173 168253	IGOR PAVLOV	{"email": "igorpavlov.031981@postgrespro.ru", "phone": "+70472838753"}
0005434604876	E5D9B7	9952 344411	OLESYA KUZNECOVA	{"phone": "+70071984228"}
0005434604877	9C1B45	0792 239756	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a_1971@postgrespro.ru", "phone": "+70072740079"}
0005434604878	7F5BD4	6650 635588	SVETLANA SOROKINA	{"phone": "+70436410774"}
0005434604879	7F5BD4	7303 818424	SERGEY BORISOV	{"email": "s.borisov.071971@postgrespro.ru", "phone": "+70549155958"}
0005434604880	14BEB8	2973 501361	OLGA FEDOROVA	{"phone": "+70864952115"}
0005434604881	FCAB58	4796 512834	VALERIY KUZNECOV	{"email": "valeriy_kuznecov.19081978@postgrespro.ru", "phone": "+70590243943"}
0005434604882	F339EE	6102 002178	OLGA MELNIKOVA	{"email": "melnikova-o-081975@postgrespro.ru", "phone": "+70570027163"}
0005434604883	06D676	2365 165040	VITALIY KISELEV	{"email": "kiselevvitaliy_121970@postgrespro.ru", "phone": "+70688244259"}
0005434604884	06D676	4762 626828	NIKITA MELNIKOV	{"email": "n-melnikov-041968@postgrespro.ru", "phone": "+70768215294"}
0005434604885	06D676	3142 851414	NIKOLAY MEDVEDEV	{"email": "nikolay.medvedev_011974@postgrespro.ru", "phone": "+70518992682"}
0005434604886	DBE1EF	0607 980140	VERA SOLOVEVA	{"phone": "+70500705263"}
0005434604887	970A03	5016 828514	ALEKSEY SOLOVEV	{"phone": "+70131792901"}
0005434604888	EE154A	8904 238718	ALEKSANDR SAVELEV	{"phone": "+70637424582"}
0005434604889	0E6C4D	5334 840434	YULIYA SIDOROVA	{"email": "y_sidorova-1973@postgrespro.ru", "phone": "+70144525974"}
0005434604890	1CC533	0134 020733	MARINA YUDINA	{"email": "myudina_04031977@postgrespro.ru", "phone": "+70820687098"}
0005434604891	B2B7B1	8776 067062	VLADIMIR YAKOVLEV	{"email": "vyakovlev1982@postgrespro.ru", "phone": "+70539269403"}
0005434604893	4A6F01	9496 093273	TAMARA POPOVA	{"email": "popova_tamara-30041980@postgrespro.ru", "phone": "+70119939938"}
0005434604894	AF0AA8	7154 657493	VLADIMIR MELNIKOV	{"email": "v.melnikov_061967@postgrespro.ru", "phone": "+70436957450"}
0005434604895	5FC1A0	5523 105489	OLGA MELNIKOVA	{"phone": "+70159353102"}
0005434604896	5FC1A0	2634 908880	MAKSIM SOROKIN	{"email": "maksimsorokin1971@postgrespro.ru", "phone": "+70449682702"}
0005434604897	2150D5	9104 680119	ILYA BARANOV	{"phone": "+70124322558"}
0005434604898	89C36C	5977 906445	SERGEY SERGEEV	{"phone": "+70175298011"}
0005434604899	8A19B5	4058 793521	DARYA AFANASEVA	{"email": "afanasevad101968@postgrespro.ru", "phone": "+70873204380"}
0005434604900	85CE59	5721 236639	ANNA BORISOVA	{"email": "borisovaa_1970@postgrespro.ru", "phone": "+70672162748"}
0005434604901	7C44DA	4044 040810	ELENA FADEEVA	{"email": "elenafadeeva1975@postgrespro.ru", "phone": "+70637783341"}
0005434604902	7C44DA	8897 958344	IVAN SMIRNOV	{"phone": "+70380881961"}
0005434604903	338A81	8703 405947	MARIYA LOGINOVA	{"phone": "+70092194830"}
0005434604904	089742	6524 439608	TATYANA NIKITINA	{"phone": "+70288123162"}
0005434604905	1FDA42	2826 905428	PETR KUDRYASHOV	{"email": "petrkudryashov.30031974@postgrespro.ru", "phone": "+70844797842"}
0005434604906	8EACDD	5611 202871	ROMAN ORLOV	{"phone": "+70132659836"}
0005434604907	8EACDD	0443 441808	ELENA POPOVA	{"phone": "+70559601551"}
0005434604908	8EACDD	2672 956640	LARISA MARTYNOVA	{"email": "martynova-l_1965@postgrespro.ru", "phone": "+70139712424"}
0005434604909	B9913B	8583 327449	EKATERINA KAZAKOVA	{"email": "ekaterina.kazakova.12051973@postgrespro.ru", "phone": "+70215287402"}
0005434604910	BB8249	1617 540842	LYUBOV KRASNOVA	{"phone": "+70248254090"}
0005434604911	BB8249	7740 110956	DIANA PETROVA	{"phone": "+70856346764"}
0005434604912	BB8249	5730 129373	RAMIL STEPANOV	{"phone": "+70221940991"}
0005434604913	5049FE	4108 603729	OLGA ZAYCEVA	{"email": "olga_zayceva_20071975@postgrespro.ru", "phone": "+70440987266"}
0005434604914	5049FE	5859 107086	NADEZHDA ALEKSANDROVA	{"phone": "+70456224981"}
0005434604915	53F85A	6839 405615	SERGEY BELOV	{"email": "s-belov.041967@postgrespro.ru", "phone": "+70395391017"}
0005434604916	DC3FFD	9179 121124	ELENA ANDREEVA	{"email": "elena.andreeva.23031982@postgrespro.ru", "phone": "+70785371954"}
0005434604917	DC3FFD	9312 748107	YURIY ZAYCEV	{"phone": "+70351624027"}
0005434604918	DF7297	2561 351709	LARISA KONOVALOVA	{"email": "l-konovalova.041967@postgrespro.ru", "phone": "+70583054865"}
0005434604919	DF7297	9721 271140	GENNADIY SOKOLOV	{"phone": "+70740335271"}
0005434604920	A3C8A4	2113 753338	LYUDMILA IVANOVA	{"phone": "+70376785433"}
0005434604921	346AD6	5651 335730	DMITRIY EGOROV	{"email": "egorov_d.17121972@postgrespro.ru", "phone": "+70888107253"}
0005434604922	766EF2	9193 947866	IGOR VOROBEV	{"phone": "+70737028846"}
0005434604923	766EF2	8787 833566	NATALYA MALYSHEVA	{"email": "n-malysheva-021969@postgrespro.ru", "phone": "+70266844668"}
0005434604924	3E2333	3334 878940	PETR BORISOV	{"email": "borisov_petr121983@postgrespro.ru", "phone": "+70123448890"}
0005434604925	98B4C1	1605 974705	VERA OSIPOVA	{"phone": "+70095643788"}
0005434604926	98B4C1	1225 010466	VALENTINA TROFIMOVA	{"phone": "+70430995976"}
0005434604927	9C43D3	6284 642272	RUSLAN NAUMOV	{"phone": "+70266893904"}
0005434604928	9A7B62	3329 496737	GENNADIY SEMENOV	{"email": "g-semenov_17081965@postgrespro.ru", "phone": "+70333158112"}
0005434604929	9A7B62	4658 379850	SERGEY FILIPPOV	{"email": "sergey-filippov_051982@postgrespro.ru", "phone": "+70786501889"}
0005434604930	2D41C3	8348 864370	VIKTOR SIDOROV	{"email": "sidorov-v-1969@postgrespro.ru", "phone": "+70538339724"}
0005434604931	4ED511	1326 595753	ALEKSANDR CHERNOV	{"phone": "+70127529862"}
0005434604932	0CEED6	3655 322142	YURIY ZAKHAROV	{"email": "y_zakharov18101975@postgrespro.ru", "phone": "+70480004602"}
0005434604933	021378	2299 823545	NADEZHDA ANISIMOVA	{"phone": "+70079250631"}
0005434604934	021378	7869 564462	NATALYA ORLOVA	{"email": "natalya-orlova.031968@postgrespro.ru", "phone": "+70566425298"}
0005434604935	195322	6950 417509	DMITRIY MELNIKOV	{"email": "melnikov.dmitriy081987@postgrespro.ru", "phone": "+70595567318"}
0005434604936	0C6A38	6322 570182	VLADISLAV KARPOV	{"phone": "+70569642469"}
0005434604937	0C6A38	2132 701392	DENIS ROMANOV	{"phone": "+70237815896"}
0005434604938	0C6A38	3384 278105	ANATOLIY POPOV	{"phone": "+70169547140"}
0005434604939	DA9E59	3300 048184	ELENA ANDREEVA	{"email": "elena.andreeva_04041973@postgrespro.ru", "phone": "+70975422575"}
0005434604940	14A748	3434 091788	VLADIMIR KUZNECOV	{"phone": "+70295317060"}
0005434604941	14A748	7345 714856	DMITRIY ALEKSEEV	{"email": "alekseev_d-13021957@postgrespro.ru", "phone": "+70704413951"}
0005434604942	9B843A	2175 686075	MIKHAIL IVANOV	{"email": "ivanov.m.1975@postgrespro.ru", "phone": "+70769831522"}
0005434604943	9B843A	8093 606737	RIMMA KISELEVA	{"phone": "+70877678990"}
0005434604944	68D9ED	8880 531734	ROZA POPOVA	{"phone": "+70915223471"}
0005434604945	FAFE45	7501 042103	ALEKSEY VOROBEV	{"phone": "+70969616362"}
0005434604946	2ECD97	8563 468723	ELENA RODIONOVA	{"email": "elenarodionova.051973@postgrespro.ru", "phone": "+70986961648"}
0005434604947	12A6A9	0160 950773	VALERIY FILIPPOV	{"phone": "+70703587155"}
0005434604948	31A376	3361 802799	VALENTINA SAVELEVA	{"email": "saveleva_valentina_13071974@postgrespro.ru", "phone": "+70109933892"}
0005434604949	5171E6	4590 726361	NINA EFIMOVA	{"email": "efimova_nina-14021975@postgrespro.ru", "phone": "+70390925036"}
0005434604950	7CD308	2455 538523	NIKOLAY GAVRILOV	{"phone": "+70207792937"}
0005434604951	305382	7871 817435	ELENA KOZLOVA	{"phone": "+70815927423"}
0005434604952	6D7B67	2871 401735	ALEKSANDR SHEVCHENKO	{"phone": "+70686997537"}
0005434604953	98F7F2	9948 186658	TIMOFEY BELOV	{"phone": "+70602930910"}
0005434604954	0DAD2F	0586 937693	KLAVDIYA SOLOVEVA	{"phone": "+70889148643"}
0005434604955	0DAD2F	7318 542590	VIKTORIYA KALININA	{"phone": "+70258922782"}
0005434604956	0DAD2F	6787 999202	ALEKSEY TARASOV	{"phone": "+70003143169"}
0005434604957	DC2F10	1791 163120	MAKSIM MELNIKOV	{"phone": "+70382293473"}
0005434604958	DC2F10	0715 897807	VYACHESLAV ZAYCEV	{"email": "v-zaycev021977@postgrespro.ru", "phone": "+70600274690"}
0005434604959	7BE626	8989 251935	NADEZHDA DENISOVA	{"email": "denisovanadezhda-24071972@postgrespro.ru", "phone": "+70783664189"}
0005434604960	7BE626	9061 669180	TATYANA VASILEVA	{"phone": "+70595825865"}
0005434604961	7BE626	3480 825602	MIKHAIL MAKAROV	{"email": "makarov.mikhail-021972@postgrespro.ru", "phone": "+70373758427"}
0005434604962	FEFF6E	3114 616151	MAKSIM ANDREEV	{"email": "mandreev_09051975@postgrespro.ru", "phone": "+70709575496"}
0005434604963	304338	5322 242034	ELENA POPOVA	{"email": "e-popova041982@postgrespro.ru", "phone": "+70068168393"}
0005434604964	B11FCC	5017 231493	GALINA DENISOVA	{"email": "galina-denisova12041970@postgrespro.ru", "phone": "+70923228733"}
0005434604965	515315	8021 763104	VALENTINA MELNIKOVA	{"phone": "+70152877904"}
0005434604966	E2E294	6911 305595	NIKITA ALEKSANDROV	{"email": "n-aleksandrov19111980@postgrespro.ru", "phone": "+70763929082"}
0005434604967	8F4B2F	9002 631201	ROMAN SHEVCHENKO	{"email": "r.shevchenko_081975@postgrespro.ru", "phone": "+70075247007"}
0005434604968	915C78	5166 101485	OLGA LEBEDEVA	{"email": "olga.lebedeva101973@postgrespro.ru", "phone": "+70785118818"}
0005434604969	DFD5AA	7375 567827	VALERIY KISELEV	{"email": "kiselev_v_071966@postgrespro.ru", "phone": "+70664499812"}
0005434604970	DFD5AA	9415 805648	ZOYA KRASNOVA	{"phone": "+70288925920"}
0005434604971	DFD5AA	4188 376589	ALEKSANDR TARASOV	{"phone": "+70857515367"}
0005434604972	CE1951	3678 176163	VALERIY FEDOROV	{"phone": "+70667896269"}
0005434604973	73099A	1687 875368	ALEKSEY MIRONOV	{"email": "a-mironov1967@postgrespro.ru", "phone": "+70886362691"}
0005434604974	807FD0	1073 401883	ALEKSANDR ANDREEV	{"email": "aleksandrandreev17111979@postgrespro.ru", "phone": "+70785124910"}
0005434604975	67F3D8	9802 252654	NIKITA RODIONOV	{"phone": "+70143717367"}
0005434604976	B786ED	0364 202398	OLGA ZOTOVA	{"phone": "+70466105180"}
0005434604977	166B8A	7597 337936	ALEKSEY GERASIMOV	{"phone": "+70570732653"}
0005434604978	166B8A	7526 616886	LEONID TARASOV	{"phone": "+70632393421"}
0005434604979	E127DD	5878 935474	VLADIMIR IVANOV	{"email": "v.ivanov04081971@postgrespro.ru", "phone": "+70892447125"}
0005434604980	E127DD	8784 120541	VALENTINA BORISOVA	{"email": "valentina-borisova.051967@postgrespro.ru", "phone": "+70583012075"}
0005434604981	E127DD	4599 051744	ELENA LEBEDEVA	{"phone": "+70468167639"}
0005434604982	1FEDFA	1931 724610	IRINA EGOROVA	{"phone": "+70446275973"}
0005434604983	1FEDFA	1911 674842	VLADIMIR DENISOV	{"email": "denisov_vladimir_011968@postgrespro.ru", "phone": "+70040314171"}
0005434604984	22029E	6074 521113	PETR SERGEEV	{"email": "sergeev_p_011983@postgrespro.ru", "phone": "+70280604639"}
0005434604985	22029E	3281 628167	LYUBOV ORLOVA	{"phone": "+70433991631"}
0005434604986	335CD6	7608 119585	SERGEY GAVRILOV	{"email": "sgavrilov-15111979@postgrespro.ru", "phone": "+70585432785"}
0005434604987	335CD6	5293 583097	SERGEY KUDRYASHOV	{"phone": "+70575366021"}
0005434604988	64A9A4	8241 919023	SERGEY VOROBEV	{"phone": "+70370867838"}
0005434604989	64A9A4	1633 687956	OLESYA ISAEVA	{"phone": "+70854850683"}
0005434604990	BB03E4	4075 999507	MARINA POLYAKOVA	{"phone": "+70843466053"}
0005434604991	EB4B11	7774 435893	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr-111964@postgrespro.ru", "phone": "+70827709518"}
0005434604992	171EE0	0996 896855	GALINA ROMANOVA	{"email": "romanova_g.1969@postgrespro.ru", "phone": "+70899781604"}
0005434604993	59D4AF	5089 016330	MARIYA ILINA	{"phone": "+70613882678"}
0005434604994	EEAE8F	0348 492872	ALEKSANDR VLASOV	{"phone": "+70516702601"}
0005434604995	EEAE8F	8210 512598	ANNA NIKITINA	{"email": "nikitina-a-111981@postgrespro.ru", "phone": "+70002389295"}
0005434604996	7BE040	2208 747438	ALEKSANDR VOROBEV	{"email": "a_vorobev-21091969@postgrespro.ru", "phone": "+70608271228"}
0005434604997	05BAE1	0656 566323	MARIYA EGOROVA	{"email": "egorova.m-101967@postgrespro.ru", "phone": "+70745848907"}
0005434604998	0E855D	9507 197449	PAVEL SCHERBAKOV	{"email": "scherbakovp-11061966@postgrespro.ru", "phone": "+70416256816"}
0005434604999	0E855D	6045 257777	ALEKSANDR PAVLOV	{"phone": "+70290196888"}
0005434605000	33E737	4481 339219	VASILIY NIKITIN	{"email": "vasiliynikitin.061970@postgrespro.ru", "phone": "+70677208598"}
0005434605001	F5FBD5	7266 567088	SERGEY IVANOV	{"email": "ivanov.sergey.1965@postgrespro.ru", "phone": "+70841891306"}
0005434605002	F5FBD5	8747 186828	OLGA TIMOFEEVA	{"email": "o_timofeeva.1982@postgrespro.ru", "phone": "+70734966901"}
0005434605003	E24DF4	8150 752909	VIKTORIYA RODIONOVA	{"email": "rodionova.v-051969@postgrespro.ru", "phone": "+70649348546"}
0005434605004	43BDC4	8435 253289	NIKOLAY BORISOV	{"email": "borisov-n_16031956@postgrespro.ru", "phone": "+70415255000"}
0005434605005	43BDC4	0573 854188	ALEKSANDR ZHURAVLEV	{"phone": "+70036094656"}
0005434605006	43BDC4	2339 262460	ALINA GAVRILOVA	{"email": "agavrilova.15081969@postgrespro.ru", "phone": "+70346300381"}
0005434605007	7E06FE	8777 953736	VADIM IVANOV	{"email": "v_ivanov.23121982@postgrespro.ru", "phone": "+70166414941"}
0005434606759	C13539	8436 346032	EVDOKIYA KOROLEVA	{"email": "koroleva-e-031969@postgrespro.ru", "phone": "+70020279079"}
0005434606760	C13539	1754 197812	IVAN MEDVEDEV	{"phone": "+70996578101"}
0005434606761	EB0FB9	1629 424710	ELENA ARKHIPOVA	{"phone": "+70284139963"}
0005434606762	1EC979	4869 175146	MAKSIM EGOROV	{"email": "maksimegorov.1967@postgrespro.ru", "phone": "+70764926477"}
0005434606763	1EC979	8248 883315	IVAN ROMANOV	{"phone": "+70766291311"}
0005434606764	3ADFEA	0374 941852	RUSTAM MIKHAYLOV	{"phone": "+70435708327"}
0005434606765	3ADFEA	4669 455879	DMITRIY ALEKSANDROV	{"phone": "+70467202654"}
0005434606766	CFF176	5214 197480	VSEVOLOD KONOVALOV	{"email": "konovalov_v-121971@postgrespro.ru", "phone": "+70755650125"}
0005434606767	EA385D	9552 473483	SVETLANA MIRONOVA	{"phone": "+70757793689"}
0005434606768	C62F3D	8585 788578	ANNA ZAKHAROVA	{"email": "zakharovaanna_26021964@postgrespro.ru", "phone": "+70533944254"}
0005434606769	C62F3D	9588 270140	VALENTINA RODIONOVA	{"phone": "+70904853373"}
0005434606770	598CF4	6866 334391	ARTEM POPOV	{"phone": "+70180960630"}
0005434606771	0AC04F	1745 166736	VALENTINA TITOVA	{"email": "titova-v-23041965@postgrespro.ru", "phone": "+70366544883"}
0005434606772	3DC069	6242 387068	NADEZHDA SCHERBAKOVA	{"email": "scherbakovanadezhda_1966@postgrespro.ru", "phone": "+70608352182"}
0005434606773	938E92	2389 508346	ALENA ZAYCEVA	{"phone": "+70335196334"}
0005434606774	7B3079	1758 071091	EKATERINA MARTYNOVA	{"email": "martynova.ekaterina-1958@postgrespro.ru", "phone": "+70739610545"}
0005434606775	24D804	6189 846275	YURIY EGOROV	{"phone": "+70521599201"}
0005434606776	C68C32	9150 780596	MIKHAIL KUZMIN	{"email": "kuzmin_mikhail081970@postgrespro.ru", "phone": "+70519388786"}
0005434606777	7165A3	3490 947453	ILMIRA ANDREEVA	{"email": "andreeva-i-13021974@postgrespro.ru", "phone": "+70323136651"}
0005434606778	7165A3	3410 106125	LEONID OSIPOV	{"phone": "+70196099539"}
0005434606779	606EC8	2035 760486	PETR SOKOLOV	{"phone": "+70499329341"}
0005434606780	642D3E	2160 827409	VENERA FILIPPOVA	{"phone": "+70509877687"}
0005434606781	642D3E	6272 337308	MARIYA YAKOVLEVA	{"phone": "+70949190674"}
0005434606782	E4F686	5057 713970	OLEG NIKOLAEV	{"email": "o.nikolaev-09111972@postgrespro.ru", "phone": "+70775320085"}
0005434606783	2C8919	2779 584676	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova1967@postgrespro.ru", "phone": "+70246791192"}
0005434606784	C5A869	1244 366201	SVETLANA SOROKINA	{"email": "sorokina_svetlana.1964@postgrespro.ru", "phone": "+70864685947"}
0005434606785	C7A451	9271 915267	VLADISLAV GAVRILOV	{"email": "gavrilov.vladislav-1983@postgrespro.ru", "phone": "+70634180395"}
0005434606786	72D0FC	7447 571402	ALEKSANDR DAVYDOV	{"email": "aleksandr_davydov-1978@postgrespro.ru", "phone": "+70381216707"}
0005434606787	84477D	6736 363648	YURIY KULIKOV	{"email": "ykulikov-31071970@postgrespro.ru", "phone": "+70220187570"}
0005434606788	5EF98B	5013 847593	MATVEY KOZLOV	{"email": "kozlov.matvey_05061969@postgrespro.ru", "phone": "+70637609220"}
0005434606789	C0BB93	4441 118614	TAISIYA GORBUNOVA	{"phone": "+70443086172"}
0005434606790	1A98AE	0341 093410	NATALYA EGOROVA	{"email": "egorova_natalya01061968@postgrespro.ru", "phone": "+70201237916"}
0005434606791	B58CE7	1060 515662	TATYANA KOLESNIKOVA	{"email": "kolesnikova.t_10121986@postgrespro.ru", "phone": "+70385360859"}
0005434606792	8A0C0A	7706 957089	ALIYA MIKHAYLOVA	{"email": "mikhaylova.a_1970@postgrespro.ru", "phone": "+70922494330"}
0005434606793	2DB7BC	3756 056230	BOGDAN VASILEV	{"email": "b_vasilev-021973@postgrespro.ru", "phone": "+70954194345"}
0005434606794	5EC903	9482 165894	RUSTAM IVANOV	{"phone": "+70828219940"}
0005434606795	DC084C	9310 404714	VLADIMIR PETROV	{"email": "vladimirpetrov.071974@postgrespro.ru", "phone": "+70565788204"}
0005434606796	8855E0	2245 809522	ALEKSEY KOROLEV	{"email": "korolevaleksey1967@postgrespro.ru", "phone": "+70231405936"}
0005434606797	8855E0	2521 865871	EKATERINA NIKITINA	{"phone": "+70930431170"}
0005434606798	E8960F	6833 711533	LYUBOV ANTONOVA	{"email": "lyubovantonova_061968@postgrespro.ru", "phone": "+70005393234"}
0005434606799	E8960F	3234 227313	GALINA MAKSIMOVA	{"phone": "+70184152762"}
0005434606800	BC2BC5	4296 329953	ANATOLIY NIKOLAEV	{"phone": "+70619360147"}
0005434606801	BC2BC5	4238 857249	OLEG TIMOFEEV	{"phone": "+70236134435"}
0005434606802	964597	1021 626854	OLGA KOLESNIKOVA	{"email": "kolesnikova.olga.1968@postgrespro.ru", "phone": "+70370013229"}
0005434606803	C70530	3245 828635	MIKHAIL MOISEEV	{"phone": "+70207189314"}
0005434606804	C70530	1937 104260	VLADIMIR KUZNECOV	{"phone": "+70723946981"}
0005434606805	C70530	7660 538211	NINA ZOTOVA	{"email": "n.zotova_1974@postgrespro.ru", "phone": "+70269480886"}
0005434606806	717E01	2775 824727	VLADIMIR SOKOLOV	{"phone": "+70904450677"}
0005434606807	7ED6DE	8397 863623	ELENA KONOVALOVA	{"email": "konovalova-e_07111968@postgrespro.ru", "phone": "+70751413797"}
0005434606808	7ED6DE	5459 109463	ANNA TIKHONOVA	{"phone": "+70262370467"}
0005434606809	4681CF	8966 234217	DMITRIY IVANOV	{"phone": "+70859023568"}
0005434606810	9F588E	6965 599803	MIKHAIL MAKAROV	{"email": "m.makarov_121975@postgrespro.ru", "phone": "+70153880510"}
0005434606811	9F588E	6103 088965	IRINA ORLOVA	{"email": "orlova.irina-081981@postgrespro.ru", "phone": "+70251152831"}
0005434606812	94DAD4	3673 811723	OLGA IVANOVA	{"phone": "+70119754373"}
0005434606813	6312C3	0640 801356	IRINA NIKOLAEVA	{"phone": "+70562961214"}
0005434606814	C7DFCD	0867 457707	TATYANA LUKYANOVA	{"email": "lukyanova_t_071970@postgrespro.ru", "phone": "+70815672611"}
0005434606815	06CA28	5534 572053	ALEKSANDR NAZAROV	{"phone": "+70132046346"}
0005434606816	06CA28	9890 174619	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova-1974@postgrespro.ru", "phone": "+70107862412"}
0005434606817	2EE1AD	6375 354697	TATYANA TROFIMOVA	{"email": "t.trofimova_07121971@postgrespro.ru", "phone": "+70795641920"}
0005434606818	2EE1AD	2197 125238	VALENTINA KRASNOVA	{"phone": "+70138471913"}
0005434606819	A8511C	4462 225984	ALEKSANDR BORISOV	{"email": "aleksandr-borisov-23071974@postgrespro.ru", "phone": "+70669598552"}
0005434606820	A8511C	6941 616530	LIDIYA SIDOROVA	{"phone": "+70767554840"}
0005434606821	21AA01	5055 748850	ARTEM NOVIKOV	{"phone": "+70099170702"}
0005434606822	21AA01	2897 994539	MATVEY IVANOV	{"phone": "+70547441356"}
0005434606823	567138	4118 115455	VIKTORIYA KOZLOVA	{"phone": "+70149001446"}
0005434606824	C2EBEE	3144 733869	GENNADIY VASILEV	{"email": "gennadiy.vasilev.1980@postgrespro.ru", "phone": "+70537990454"}
0005434606825	297BD6	7092 773895	ANTON SERGEEV	{"email": "a-sergeev.111968@postgrespro.ru", "phone": "+70879615354"}
0005434606826	297BD6	2101 795389	ALEKSANDR ANTONOV	{"phone": "+70484473931"}
0005434606827	297BD6	4784 598792	ALEKSANDR MAKSIMOV	{"email": "a_maksimov_1970@postgrespro.ru", "phone": "+70931000712"}
0005434606828	B497EE	0522 071132	EVA LUKYANOVA	{"phone": "+70666599653"}
0005434606829	47C57B	0550 403152	NIKOLAY ORLOV	{"email": "orlovnikolay_1972@postgrespro.ru", "phone": "+70105921320"}
0005434606830	1FD5A8	2752 736138	SERGEY GAVRILOV	{"email": "gavrilov-sergey-1983@postgrespro.ru", "phone": "+70265808100"}
0005434606831	4C8F62	2435 898922	OLEG STEPANOV	{"phone": "+70844550041"}
0005434606832	EA8531	1247 354328	ALEKSANDR CHERNOV	{"email": "a-chernov_24101961@postgrespro.ru", "phone": "+70664831685"}
0005434606833	537BC3	5108 969545	VLADIMIR ALEKSEEV	{"email": "vladimir_alekseev21091972@postgrespro.ru", "phone": "+70221926047"}
0005434606834	DE1D0D	5443 366682	ANDREY SCHERBAKOV	{"email": "scherbakov.andrey.101973@postgrespro.ru", "phone": "+70242602226"}
0005434606835	AA992A	3508 794935	ANNA BELOVA	{"email": "belova.anna-1976@postgrespro.ru", "phone": "+70806751373"}
0005434606836	CDB7EA	5006 572686	OLESYA FROLOVA	{"email": "frolova_o-1978@postgrespro.ru", "phone": "+70183489073"}
0005434606837	E12D52	7098 100257	LYUDMILA FEDOROVA	{"phone": "+70608734933"}
0005434606838	C890D7	5044 748114	MARINA MELNIKOVA	{"email": "melnikova.m_24041972@postgrespro.ru", "phone": "+70969008526"}
0005434606839	FA026C	6106 238041	VALERIY SCHERBAKOV	{"email": "scherbakov.valeriy_011958@postgrespro.ru", "phone": "+70597286734"}
0005434606840	FA026C	3845 260271	VIKTORIYA FEDOROVA	{"phone": "+70327106375"}
0005434606841	FA026C	4998 991449	SVETLANA SMIRNOVA	{"email": "smirnovasvetlana011983@postgrespro.ru", "phone": "+70203654752"}
0005434606842	999B67	5390 296997	GENNADIY MAKAROV	{"email": "gennadiy_makarov.28061975@postgrespro.ru", "phone": "+70878644598"}
0005434606843	60B6DF	6326 363652	OLGA MIKHAYLOVA	{"email": "mikhaylova_o_07021968@postgrespro.ru", "phone": "+70633680354"}
0005434606844	60B6DF	5496 865523	TATYANA ANDREEVA	{"phone": "+70306218430"}
0005434606845	C4FE25	3165 854628	VASILIY KUZMIN	{"email": "vkuzmin17041975@postgrespro.ru", "phone": "+70489170061"}
0005434606846	1DA282	6467 305662	NIKOLAY KUZNECOV	{"email": "kuznecov-n-03101959@postgrespro.ru", "phone": "+70173592502"}
0005434606847	1DA282	9926 892802	DANIIL ALEKSANDROV	{"phone": "+70575900806"}
0005434606904	92404B	5014 257030	ALBERT NIKOLAEV	{"phone": "+70299069784"}
0005434606848	F54BC5	1920 659414	LIDIYA OVCHINNIKOVA	{"email": "ovchinnikova.lidiya.07011974@postgrespro.ru", "phone": "+70071419476"}
0005434606849	36C20B	6763 035485	EGOR BARANOV	{"email": "egorbaranov.1973@postgrespro.ru", "phone": "+70046976328"}
0005434606850	36C20B	9093 991098	NADEZHDA OVCHINNIKOVA	{"email": "n.ovchinnikova_101970@postgrespro.ru", "phone": "+70835726086"}
0005434606851	651C9F	8493 750929	ALEKSEY MEDVEDEV	{"email": "medvedev.a.081981@postgrespro.ru", "phone": "+70077405638"}
0005434606852	BF0989	8469 610970	PAVEL GUSEV	{"email": "gusev-p_041970@postgrespro.ru", "phone": "+70701161346"}
0005434606853	4FA180	9393 494282	MARIYA BARANOVA	{"email": "mariya_baranova_1968@postgrespro.ru", "phone": "+70646834414"}
0005434606854	4FA180	7150 501430	POLINA SOKOLOVA	{"email": "polina-sokolova_1970@postgrespro.ru", "phone": "+70658470191"}
0005434606855	E7162F	3501 118270	GEORGIY BORISOV	{"email": "borisovgeorgiy_1967@postgrespro.ru", "phone": "+70177196916"}
0005434606856	E35603	6017 533046	EVDOKIYA SMIRNOVA	{"phone": "+70817200562"}
0005434606857	E35603	8350 517142	IVAN SEMENOV	{"email": "semenov_i_08071985@postgrespro.ru", "phone": "+70853896944"}
0005434606858	661387	6678 106623	IVAN NIKITIN	{"email": "nikitini-22061966@postgrespro.ru", "phone": "+70356424595"}
0005434606859	15FDF9	3387 542061	KONSTANTIN KUZNECOV	{"phone": "+70709918670"}
0005434606860	01705D	7824 770791	MARIYA VASILEVA	{"phone": "+70021149436"}
0005434606861	01705D	9376 634741	ULYANA KARPOVA	{"email": "u.karpova_071970@postgrespro.ru", "phone": "+70644404872"}
0005434606862	01705D	9982 002179	ELENA PETROVA	{"phone": "+70627848558"}
0005434606863	7C9A35	9237 213197	IRINA SEMENOVA	{"phone": "+70030310578"}
0005434606864	6764E9	4489 597732	LYUDMILA SEMENOVA	{"email": "semenova-l-101975@postgrespro.ru", "phone": "+70471635212"}
0005434606865	6764E9	2181 174026	VALENTINA CHERNOVA	{"phone": "+70372378215"}
0005434606866	8F2B10	3417 827046	MARINA SCHERBAKOVA	{"phone": "+70338569679"}
0005434606867	1A8996	6121 876161	ANDREY POPOV	{"phone": "+70293955377"}
0005434606868	FED23A	8422 492290	ANATOLIY BORISOV	{"phone": "+70226031346"}
0005434606869	FED23A	0676 258417	KONSTANTIN MELNIKOV	{"email": "konstantinmelnikov22041962@postgrespro.ru", "phone": "+70674404864"}
0005434606870	EEA70A	6871 560475	ILYA MELNIKOV	{"phone": "+70958661646"}
0005434606871	094156	6401 372308	PETR MIKHAYLOV	{"phone": "+70834688777"}
0005434606872	F91D98	9558 338172	KSENIYA GERASIMOVA	{"phone": "+70385451265"}
0005434606873	D0133B	3049 418786	TAMARA MAKSIMOVA	{"email": "t_maksimova.05121974@postgrespro.ru", "phone": "+70732447089"}
0005434606874	402F44	7502 218991	SERGEY SERGEEV	{"phone": "+70918819817"}
0005434606875	402F44	1772 287918	GRIGORIY PETROV	{"email": "grigoriy_petrov.081966@postgrespro.ru", "phone": "+70843474250"}
0005434606876	EEAE99	7172 643129	OLGA ALEKSANDROVA	{"email": "olgaaleksandrova.01051975@postgrespro.ru", "phone": "+70760718269"}
0005434606877	EEAE99	7606 021122	NIKOLAY ANTONOV	{"email": "nikolay_antonov.071974@postgrespro.ru", "phone": "+70845130810"}
0005434606878	67B50B	3549 093577	ALEKSANDRA MEDVEDEVA	{"phone": "+70370378397"}
0005434606879	0B3AB3	7493 974500	NAILYA KAZAKOVA	{"email": "kazakovan.1975@postgrespro.ru", "phone": "+70021001707"}
0005434606880	490B66	5340 067992	NINA ANISIMOVA	{"email": "nina_anisimova-17081975@postgrespro.ru", "phone": "+70954723552"}
0005434606881	E22331	5754 084545	ALEKSEY CHERNOV	{"phone": "+70337211680"}
0005434606882	EFB7D3	9332 636184	DMITRIY ISAEV	{"email": "dmitriy-isaev.041979@postgrespro.ru", "phone": "+70356950716"}
0005434606883	6F8761	3190 463240	DMITRIY FEDOROV	{"phone": "+70985572959"}
0005434606884	6F8761	3276 239787	TATYANA GUSEVA	{"email": "t-guseva031978@postgrespro.ru", "phone": "+70606901693"}
0005434606885	6F8761	8591 783346	LEV MAKAROV	{"email": "lmakarov_11051963@postgrespro.ru", "phone": "+70226544405"}
0005434606886	6F8761	9605 671786	IVAN NIKITIN	{"phone": "+70842820101"}
0005434606887	AADC3A	9703 346748	NIKITA NIKOLAEV	{"phone": "+70690749089"}
0005434608284	7A2E9B	1842 012215	TAMARA PAVLOVA	{"phone": "+70660414897"}
0005434606888	AADC3A	9593 083438	GALINA FADEEVA	{"email": "fadeeva_g021970@postgrespro.ru", "phone": "+70083569396"}
0005434610219	CF82C6	1901 925488	VITALIY DAVYDOV	{"phone": "+70721978925"}
0005434606889	EC998C	8838 103273	MARIYA NIKITINA	{"email": "nikitina.m-16081969@postgrespro.ru", "phone": "+70352332201"}
0005434606890	B53DEE	0937 215278	OLEG NAUMOV	{"email": "naumov_oleg.101972@postgrespro.ru", "phone": "+70122984865"}
0005434606891	AA976D	9742 265059	OLGA VASILEVA	{"email": "vasileva-olga.1972@postgrespro.ru", "phone": "+70337138718"}
0005434606892	47E4EC	5522 658075	ANTON ZAKHAROV	{"email": "zakharov_anton_30081970@postgrespro.ru", "phone": "+70299411339"}
0005434606893	47E4EC	3298 589958	MARIYA KOZLOVA	{"phone": "+70026563733"}
0005434606894	08EC09	3923 903644	VIKTOR KOZLOV	{"phone": "+70135830473"}
0005434606895	0C3252	6683 699673	VLADIMIR MAKAROV	{"email": "makarov_vladimir_03021959@postgrespro.ru", "phone": "+70938472652"}
0005434606896	915793	6609 363995	KLAVDIYA NAUMOVA	{"email": "naumovak.18051972@postgrespro.ru", "phone": "+70577936693"}
0005434606897	107E74	3083 617864	ALEKSANDR NIKITIN	{"phone": "+70585627929"}
0005434606898	107E74	2205 482208	ANDREY ALEKSEEV	{"phone": "+70201839183"}
0005434606899	850599	1799 867397	SNEZHANA GORBUNOVA	{"email": "sgorbunova_30091968@postgrespro.ru", "phone": "+70032701011"}
0005434606900	B1FF24	2661 754805	OLGA FADEEVA	{"email": "fadeeva_o-021969@postgrespro.ru", "phone": "+70224895197"}
0005434606901	B1FF24	2593 485298	NIKOLAY ZHUKOV	{"email": "zhukov_nikolay021961@postgrespro.ru", "phone": "+70589415169"}
0005434606902	52F150	0799 788058	DMITRIY ZAKHAROV	{"phone": "+70765864876"}
0005434606903	1B691B	2731 578999	OLEG MIKHAYLOV	{"email": "olegmikhaylov-1975@postgrespro.ru", "phone": "+70460499811"}
0005434606905	041A89	9864 688137	ANASTASIYA NIKOLAEVA	{"phone": "+70140556722"}
0005434606906	D8C4B7	5748 192267	OLGA MOROZOVA	{"email": "olga_morozova-021964@postgrespro.ru", "phone": "+70070635141"}
0005434606907	D8C4B7	7255 183715	ALEKSANDR MOROZOV	{"email": "a.morozov.09071986@postgrespro.ru", "phone": "+70062251947"}
0005434606908	C77D21	0110 489160	ANNA KUZNECOVA	{"phone": "+70915849878"}
0005434606909	C77D21	6453 541509	NATALYA BARANOVA	{"email": "baranovanatalya071966@postgrespro.ru", "phone": "+70002081395"}
0005434606910	1C1991	2317 324305	IRINA KUDRYASHOVA	{"phone": "+70147204639"}
0005434606911	FD670B	7746 964482	ILYA ANDREEV	{"email": "andreevilya.121973@postgrespro.ru", "phone": "+70593511933"}
0005434606912	720D5F	4238 784717	ELENA VOLKOVA	{"phone": "+70650373375"}
0005434606913	720D5F	3860 474501	VALERIY SAVELEV	{"phone": "+70741941368"}
0005434606914	75FC87	8429 228105	ALEKSANDR AFANASEV	{"phone": "+70712624955"}
0005434606915	474DD5	2948 752138	SERGEY KONOVALOV	{"email": "konovalov-s_1959@postgrespro.ru", "phone": "+70325037687"}
0005434606916	35C073	4569 009377	ELENA MOISEEVA	{"email": "emoiseeva_02041973@postgrespro.ru", "phone": "+70256240549"}
0005434606917	C35885	6897 855869	ARINA NESTEROVA	{"phone": "+70564022841"}
0005434606918	C13A96	6706 262089	MARINA KOZLOVA	{"email": "kozlova-m1970@postgrespro.ru", "phone": "+70057912120"}
0005434606919	C13A96	1927 442379	VLADIMIR BONDARENKO	{"phone": "+70250469130"}
0005434606920	9FD74F	3936 119272	VALENTINA POTAPOVA	{"phone": "+70798003332"}
0005434606921	9FD74F	1546 019453	SERGEY DENISOV	{"email": "denisov_sergey_071975@postgrespro.ru", "phone": "+70961428635"}
0005434606922	FE7EF6	3073 667498	SERGEY MATVEEV	{"phone": "+70204611151"}
0005434606923	F85747	7585 050735	NATALYA ZAYCEVA	{"phone": "+70139888842"}
0005434606924	F85747	8384 491754	MAKSIM TIMOFEEV	{"phone": "+70939029130"}
0005434606925	9EFDA0	4921 594825	TATYANA KALININA	{"phone": "+70281867744"}
0005434606926	9EFDA0	8128 663605	SVETLANA EGOROVA	{"email": "egorova.s28091976@postgrespro.ru", "phone": "+70908489527"}
0005434606927	F0F6FD	2239 601337	NATALYA MASLOVA	{"email": "n-maslova.051967@postgrespro.ru", "phone": "+70481718973"}
0005434606928	E3CA5F	0125 133105	ANNA KOLESNIKOVA	{"phone": "+70324210336"}
0005434606929	0FCC72	7481 728145	ALEKSANDR KONOVALOV	{"email": "konovalov.aleksandr-031963@postgrespro.ru", "phone": "+70550389304"}
0005434606930	0FCC72	5383 357921	SVETLANA DANILOVA	{"email": "danilova-svetlana_19081976@postgrespro.ru", "phone": "+70938784102"}
0005434606931	739DE5	8862 541637	ANATOLIY VASILEV	{"email": "vasilev.a101974@postgrespro.ru", "phone": "+70799565432"}
0005434606932	AF8D65	5250 607843	GENNADIY STEPANOV	{"phone": "+70061504107"}
0005434606933	428124	6011 870367	GENNADIY ANDREEV	{"email": "gennadiy.andreev1961@postgrespro.ru", "phone": "+70338479001"}
0005434606934	FD75C4	0826 077424	NINA TIMOFEEVA	{"phone": "+70222498826"}
0005434606935	2E5193	0340 073042	DENIS NIKOLAEV	{"phone": "+70126703939"}
0005434606936	59094B	9432 190472	VALERIY GUSEV	{"phone": "+70988173972"}
0005434606937	59094B	7870 869295	ARTEM ALEKSEEV	{"email": "alekseeva-19111973@postgrespro.ru", "phone": "+70784713571"}
0005434606938	9494AC	4684 150496	YURIY SCHERBAKOV	{"phone": "+70412523575"}
0005434606939	53BEA3	4066 226743	SVETLANA AFANASEVA	{"email": "afanasevasvetlana-19111969@postgrespro.ru", "phone": "+70598396836"}
0005434608300	8D5A76	4759 129122	LYUDMILA NOVIKOVA	{"phone": "+70517089163"}
0005434608276	A1366E	3807 032644	LYUBOV KONOVALOVA	{"phone": "+70257570451"}
0005434608277	2BC886	1603 301900	NIKOLAY FILIPPOV	{"email": "filippov_n.17081971@postgrespro.ru", "phone": "+70331781569"}
0005434608278	3250A7	1676 034432	MARGARITA ABRAMOVA	{"phone": "+70381831028"}
0005434608279	3250A7	2050 487650	SERGEY KISELEV	{"email": "skiselev-10011973@postgrespro.ru", "phone": "+70568983926"}
0005434608280	999B2F	6366 923422	RAISA EFIMOVA	{"phone": "+70822708144"}
0005434608281	F055F2	5522 754510	KIRILL FILIPPOV	{"phone": "+70076386615"}
0005434608282	F055F2	4687 248859	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva05081971@postgrespro.ru", "phone": "+70296664457"}
0005434608283	7A2E9B	3872 029431	EKATERINA EFIMOVA	{"phone": "+70464514404"}
0005434608285	7A2E9B	0295 996157	VLADISLAV KUZMIN	{"phone": "+70179407371"}
0005434610220	5B31DF	2444 873678	NIKOLAY KUZNECOV	{"phone": "+70865715607"}
0005434608286	B07EC5	5806 310436	ALEKSANDRA SIDOROVA	{"email": "sidorova.a_061965@postgrespro.ru", "phone": "+70726572277"}
0005434608287	B07EC5	1915 081855	SVETLANA FROLOVA	{"phone": "+70523889483"}
0005434608288	DB330A	3411 561391	ALEKSANDR KONOVALOV	{"phone": "+70281035623"}
0005434608289	DB330A	1313 078258	NINA SOROKINA	{"email": "n-sorokina.021980@postgrespro.ru", "phone": "+70411614462"}
0005434608290	DB330A	4203 945134	VALERIY KOROLEV	{"phone": "+70442529942"}
0005434608291	DB330A	0807 676433	SABINA KOZLOVA	{"phone": "+70649109586"}
0005434608292	78FBA7	9526 704174	SERGEY ISAEV	{"email": "isaev.sergey10011984@postgrespro.ru", "phone": "+70251441616"}
0005434608293	78FBA7	9589 940276	LYUBOV FROLOVA	{"email": "frolova_lyubov-1972@postgrespro.ru", "phone": "+70660318877"}
0005434608294	236C03	8525 160911	ANNA NAUMOVA	{"email": "anna-naumova_1973@postgrespro.ru", "phone": "+70464760375"}
0005434608295	2F1A3A	5042 145078	TATYANA ALEKSEEVA	{"email": "talekseeva.1978@postgrespro.ru", "phone": "+70822893070"}
0005434608296	2F1A3A	6954 799133	YURIY KISELEV	{"phone": "+70575153101"}
0005434608297	C6C740	6292 798506	ELENA KOROLEVA	{"email": "ekoroleva_22051973@postgrespro.ru", "phone": "+70486032338"}
0005434608298	C6C740	1421 853357	ELENA PETROVA	{"email": "petrova.elena-1980@postgrespro.ru", "phone": "+70141436105"}
0005434608299	8D5A76	4299 273415	ANASTASIYA EGOROVA	{"email": "anastasiya-egorova_1973@postgrespro.ru", "phone": "+70649056880"}
0005434608301	655797	0586 003995	RASHIT ANTONOV	{"email": "r.antonov.1963@postgrespro.ru", "phone": "+70098454557"}
0005434608302	655797	3396 230181	EKATERINA VOLKOVA	{"email": "ekaterina_volkova_111970@postgrespro.ru", "phone": "+70608462256"}
0005434608303	7E4049	1022 215602	IVAN KONOVALOV	{"email": "konovalov-i-1975@postgrespro.ru", "phone": "+70155247084"}
0005434608304	DB296E	9884 619013	ANATOLIY SHEVCHENKO	{"email": "shevchenkoa_10081963@postgrespro.ru", "phone": "+70270135674"}
0005434608305	DB296E	5317 381026	VERA EFREMOVA	{"email": "efremova-vera_1972@postgrespro.ru", "phone": "+70274596010"}
0005434608306	C2AC56	9898 174644	LILIYA IVANOVA	{"phone": "+70184045721"}
0005434608307	C0C702	0464 939491	NINA MOROZOVA	{"email": "nina_morozova1982@postgrespro.ru", "phone": "+70934968143"}
0005434608308	E744B5	1480 375616	VYACHESLAV FEDOTOV	{"phone": "+70393400680"}
0005434608309	E744B5	7826 572937	ANDREY NIKITIN	{"email": "a-nikitin.1983@postgrespro.ru", "phone": "+70222673354"}
0005434608310	E744B5	6644 276712	VLADISLAV KONOVALOV	{"email": "v.konovalov.23051965@postgrespro.ru", "phone": "+70440865263"}
0005434608311	E744B5	2315 798846	TATYANA KUZNECOVA	{"phone": "+70011709318"}
0005434608312	314904	3986 237377	ALEKSEY GRIGOREV	{"email": "grigorev_a.021967@postgrespro.ru", "phone": "+70976103099"}
0005434608313	DB537B	7892 776660	SOFIYA ZAKHAROVA	{"phone": "+70814795638"}
0005434608314	A093EF	1947 518043	SVETLANA IVANOVA	{"email": "ivanova.s.021984@postgrespro.ru", "phone": "+70619533361"}
0005434608315	FB9238	2034 392751	NIKOLAY VOLKOV	{"phone": "+70604605408"}
0005434608316	84EE0F	0103 422016	TATYANA MASLOVA	{"email": "t_maslova-011966@postgrespro.ru", "phone": "+70226138522"}
0005434608317	08B75C	5437 908643	ALEKSANDR PETROV	{"email": "aleksandrpetrov_1976@postgrespro.ru", "phone": "+70142174874"}
0005434608318	F4E48B	7782 325140	NATALYA KOLESNIKOVA	{"email": "nkolesnikova.1971@postgrespro.ru", "phone": "+70310359325"}
0005434608319	1A0A85	5032 299825	LYUDMILA IVANOVA	{"email": "ivanova_l_111960@postgrespro.ru", "phone": "+70978239585"}
0005434608320	1DB1DB	2889 467754	ANATOLIY KRASNOV	{"email": "anatoliy-krasnov_17021974@postgrespro.ru", "phone": "+70163182892"}
0005434608321	A90F79	7106 949553	VALENTINA MAKAROVA	{"phone": "+70447249158"}
0005434608322	872B5A	5093 310398	LYUDMILA ANISIMOVA	{"email": "lanisimova-01021970@postgrespro.ru", "phone": "+70002672844"}
0005434608323	872B5A	8295 321890	SVETLANA EFIMOVA	{"phone": "+70431634465"}
0005434608324	36D576	5096 940676	ANDREY SOLOVEV	{"email": "solovev-andrey_1969@postgrespro.ru", "phone": "+70914670131"}
0005434608325	F8777D	0664 746571	DMITRIY FROLOV	{"phone": "+70649629823"}
0005434608326	F8777D	5362 003731	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr_071965@postgrespro.ru", "phone": "+70445286943"}
0005434608327	5EEF6C	7630 916955	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr1962@postgrespro.ru", "phone": "+70066221987"}
0005434608328	5EEF6C	1082 526932	SVETLANA ZAYCEVA	{"phone": "+70991629866"}
0005434608329	1C4211	8804 755421	NATALYA NESTEROVA	{"email": "nesterova_natalya.09071964@postgrespro.ru", "phone": "+70943924570"}
0005434608330	3198E1	9185 085597	YULIYA MATVEEVA	{"phone": "+70592562884"}
0005434608331	47B04F	7046 392010	MARIYA SOKOLOVA	{"phone": "+70308224646"}
0005434608332	64861A	9138 203772	NATALYA AKIMOVA	{"phone": "+70294664018"}
0005434608333	C5926E	9921 009829	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev-31051972@postgrespro.ru", "phone": "+70095400187"}
0005434608334	C1C33E	1423 556121	RAFAIL EGOROV	{"email": "egorov.rafail.1976@postgrespro.ru", "phone": "+70559001564"}
0005434608335	4D5330	2822 145201	OLGA MOROZOVA	{"email": "morozovao_1965@postgrespro.ru", "phone": "+70159315763"}
0005434608336	D53113	6068 495966	IVAN MOISEEV	{"email": "moiseev_i05111980@postgrespro.ru", "phone": "+70825702889"}
0005434608337	A208A4	2256 409006	VIKTOR ALEKSANDROV	{"email": "v-aleksandrov.1980@postgrespro.ru", "phone": "+70467865036"}
0005434608338	A208A4	1798 580114	KONSTANTIN NIKITIN	{"phone": "+70979691288"}
0005434608339	48FC76	4745 330076	TATYANA DENISOVA	{"email": "t.denisova_1962@postgrespro.ru", "phone": "+70797120964"}
0005434608340	DD85D9	8551 409683	NAZIYA NIKITINA	{"phone": "+70482205271"}
0005434608341	DD85D9	9998 897179	GALINA KUZNECOVA	{"email": "kuznecova.galina_1986@postgrespro.ru", "phone": "+70796331807"}
0005434608342	DD85D9	4759 090727	VIKTOR KAZAKOV	{"email": "viktorkazakov021969@postgrespro.ru", "phone": "+70022117786"}
0005434608403	A8EDA2	9820 314920	ALBINA IVANOVA	{"phone": "+70202916524"}
0005434610281	C0803E	7481 516628	DMITRIY YAKOVLEV	{"phone": "+70361957312"}
0005434608343	151800	7469 333448	ALINA POTAPOVA	{"email": "apotapova_041978@postgrespro.ru", "phone": "+70339308029"}
0005434608344	21C125	8635 311871	LYUBOV SERGEEVA	{"email": "l-sergeeva.1971@postgrespro.ru", "phone": "+70833851799"}
0005434608345	25863F	3714 796176	IVAN DENISOV	{"email": "denisov-i_1977@postgrespro.ru", "phone": "+70047453591"}
0005434608346	FAE2C2	4811 949169	RAILYA TIKHONOVA	{"phone": "+70484797609"}
0005434608347	FAE2C2	3998 731968	VYACHESLAV KAZAKOV	{"email": "vyacheslavkazakov.1970@postgrespro.ru", "phone": "+70987408349"}
0005434608348	FAE2C2	5043 147201	PAVEL IVANOV	{"email": "ivanov-p061982@postgrespro.ru", "phone": "+70979081835"}
0005434608349	0F1983	2187 534788	MAKSIM SOKOLOV	{"email": "maksim-sokolov.02071976@postgrespro.ru", "phone": "+70427497938"}
0005434608350	04F569	7189 184350	ANGELINA NIKOLAEVA	{"email": "angelinanikolaeva1970@postgrespro.ru", "phone": "+70549865706"}
0005434608351	3021DA	1293 813438	VERA SOROKINA	{"phone": "+70865092893"}
0005434608352	D3C061	7298 171357	OLGA GORBUNOVA	{"email": "olgagorbunova-1965@postgrespro.ru", "phone": "+70760190297"}
0005434608353	757C57	0302 559329	VLADIMIR MAKAROV	{"email": "makarov.v061978@postgrespro.ru", "phone": "+70445660167"}
0005434608354	757C57	6017 475880	OKSANA ZAYCEVA	{"phone": "+70740121682"}
0005434608355	757C57	6427 482907	VLADIMIR GUSEV	{"email": "v-gusev-121972@postgrespro.ru", "phone": "+70802339365"}
0005434608356	0CD562	6403 473136	VLADIMIR POPOV	{"phone": "+70156892752"}
0005434608357	38F53A	8415 529444	ALEKSEY TIMOFEEV	{"email": "timofeev.aleksey_1978@postgrespro.ru", "phone": "+70299858337"}
0005434608358	6AD042	7943 980338	SERGEY STEPANOV	{"email": "sergeystepanov-071966@postgrespro.ru", "phone": "+70297272713"}
0005434608359	6AD042	8784 858682	ALEKSANDR PETROV	{"phone": "+70012309947"}
0005434608360	07776D	1644 880176	GALINA KRASNOVA	{"phone": "+70372974425"}
0005434608361	7FE712	0641 799922	DMITRIY MEDVEDEV	{"phone": "+70208693533"}
0005434608362	BF4E03	3818 308631	ALEKSANDR MEDVEDEV	{"email": "medvedev-aleksandr-20041974@postgrespro.ru", "phone": "+70439232966"}
0005434608363	281AFD	8534 705772	ANDREY SMIRNOV	{"phone": "+70863690216"}
0005434608364	3E66CB	1640 819778	ALEKSANDR ANDREEV	{"phone": "+70890811384"}
0005434608365	3E66CB	9638 835475	PAVEL SERGEEV	{"phone": "+70037405656"}
0005434608366	1BF968	3760 975165	ELENA KISELEVA	{"email": "elena_kiseleva_08091983@postgrespro.ru", "phone": "+70068652347"}
0005434608367	82CC09	7535 769767	VLADIMIR MEDVEDEV	{"email": "medvedev_vladimir1975@postgrespro.ru", "phone": "+70162723395"}
0005434608368	9F2454	5690 903472	POLINA BORISOVA	{"phone": "+70522059254"}
0005434608369	7CB9D7	1162 193291	VLADISLAV KOZLOV	{"phone": "+70498119851"}
0005434608370	B9F8BE	9308 745883	KAMIL ZHURAVLEV	{"email": "k_zhuravlev.101984@postgrespro.ru", "phone": "+70443420342"}
0005434608371	744435	5055 941428	ALEKSEY KOROLEV	{"phone": "+70079834466"}
0005434608372	FCD048	9842 467434	ANATOLIY FROLOV	{"email": "frolov_anatoliy_1974@postgrespro.ru", "phone": "+70586740628"}
0005434608373	8BDF6F	5916 767612	YANA FOMINA	{"phone": "+70872396267"}
0005434608374	DA593C	6469 623879	GENNADIY SCHERBAKOV	{"phone": "+70948387714"}
0005434608375	38DE08	8798 121200	TATYANA NIKITINA	{"phone": "+70025899586"}
0005434608376	38DE08	1429 332914	ALEKSANDRA KOROLEVA	{"phone": "+70245224771"}
0005434608377	C6CD12	1578 959546	RAISA LOGINOVA	{"email": "r_loginova-061970@postgrespro.ru", "phone": "+70630171267"}
0005434608378	4E7064	2361 396619	SERGEY IVANOV	{"email": "ivanovs.17051967@postgrespro.ru", "phone": "+70031294423"}
0005434608379	DC34D0	4405 058163	POLINA DAVYDOVA	{"email": "davydova_polina.031971@postgrespro.ru", "phone": "+70103012927"}
0005434608380	873642	5044 159272	DMITRIY DAVYDOV	{"email": "davydov_dmitriy_17011977@postgrespro.ru", "phone": "+70926429976"}
0005434608381	873642	7274 609032	MARAT SMIRNOV	{"email": "marat.smirnov031965@postgrespro.ru", "phone": "+70125055782"}
0005434608382	EFF117	2603 359408	PAVEL RODIONOV	{"email": "rodionov-p1975@postgrespro.ru", "phone": "+70317929216"}
0005434608383	EFF117	0757 372521	VLADIMIR SERGEEV	{"phone": "+70648707788"}
0005434608384	EFF117	4884 186822	SVETLANA MATVEEVA	{"email": "smatveeva-10081977@postgrespro.ru", "phone": "+70516106659"}
0005434608385	272C6D	4546 193207	DMITRIY KUZNECOV	{"phone": "+70215320668"}
0005434608386	272C6D	1365 609075	GALINA MAKSIMOVA	{"phone": "+70290734085"}
0005434608387	A9E9B9	5371 142898	NIKOLAY KUZMIN	{"email": "kuzmin.n1983@postgrespro.ru", "phone": "+70273383282"}
0005434608388	A9E9B9	0950 407241	VALERIYA IVANOVA	{"email": "v-ivanova_08021978@postgrespro.ru", "phone": "+70192669217"}
0005434608389	A9E9B9	4026 636835	MARINA ARKHIPOVA	{"phone": "+70096009667"}
0005434608390	A9E9B9	6869 214393	ANATOLIY VOLKOV	{"phone": "+70852433209"}
0005434608391	297FCE	5238 494290	VLADIMIR PAVLOV	{"phone": "+70523107049"}
0005434608392	297FCE	9878 717045	NINA KOROLEVA	{"email": "koroleva_n-1963@postgrespro.ru", "phone": "+70978663660"}
0005434608393	8794AB	1276 362867	ELENA SOKOLOVA	{"phone": "+70057079816"}
0005434608394	8794AB	2076 672945	IRINA MOROZOVA	{"phone": "+70320422326"}
0005434608395	9F6D98	0316 352579	KONSTANTIN ANTONOV	{"email": "antonov_konstantin.09101975@postgrespro.ru", "phone": "+70754056396"}
0005434608396	9F6D98	1072 073893	YULIYA KOZLOVA	{"phone": "+70031315710"}
0005434608397	8EE3D5	9626 869336	NADEZHDA NIKOLAEVA	{"email": "nadezhdanikolaeva.071968@postgrespro.ru", "phone": "+70452917628"}
0005434608398	774AE9	2250 622921	ALEKSEY SIDOROV	{"phone": "+70267547340"}
0005434608399	363A3D	3385 639545	DMITRIY POPOV	{"email": "dpopov-071969@postgrespro.ru", "phone": "+70810263763"}
0005434608400	426723	8251 761851	NATALIYA POTAPOVA	{"email": "potapovan.011976@postgrespro.ru", "phone": "+70256821262"}
0005434608401	426723	6359 350786	TATYANA ALEKSEEVA	{"email": "alekseeva_tatyana1970@postgrespro.ru", "phone": "+70017671660"}
0005434608402	3F2B16	5610 683313	NIKITA PETROV	{"phone": "+70854544244"}
0005434608404	910242	6590 423840	LARISA NIKITINA	{"email": "nikitina_larisa-051978@postgrespro.ru", "phone": "+70413445187"}
0005434608405	795ADE	8694 480187	TATYANA SOKOLOVA	{"email": "tsokolova.01101972@postgrespro.ru", "phone": "+70274742195"}
0005434608406	795ADE	0008 659581	TAISIYA SERGEEVA	{"email": "sergeevat_10121970@postgrespro.ru", "phone": "+70005007704"}
0005434608407	4108E6	2982 432685	RAISA MAKSIMOVA	{"phone": "+70757402071"}
0005434610166	D17346	9292 647530	YURIY FOMIN	{"email": "fominyuriy22021970@postgrespro.ru", "phone": "+70464816024"}
0005434610167	D17346	3393 476220	NATALYA BORISOVA	{"phone": "+70924839835"}
0005434610168	BFF76A	7040 863016	IVAN BORISOV	{"email": "borisov.i16041960@postgrespro.ru", "phone": "+70954630581"}
0005434610169	C6982F	6251 321297	VLADIMIR VASILEV	{"email": "v.vasilev-13091982@postgrespro.ru", "phone": "+70612027669"}
0005434610170	C6982F	0397 330118	OLGA NAUMOVA	{"phone": "+70007884550"}
0005434610171	42909F	9305 840985	MARGARITA LUKYANOVA	{"email": "lukyanova_margarita-09121970@postgrespro.ru", "phone": "+70998428520"}
0005434610172	42909F	1011 500242	ANASTASIYA SERGEEVA	{"email": "anastasiyasergeeva_021977@postgrespro.ru", "phone": "+70368138391"}
0005434610173	163CE4	0992 207602	VALENTINA SCHERBAKOVA	{"email": "scherbakova_valentina_1985@postgrespro.ru", "phone": "+70277569190"}
0005434610174	163CE4	0055 226868	OLGA MARTYNOVA	{"email": "martynovaolga.1979@postgrespro.ru", "phone": "+70121834693"}
0005434610175	163CE4	3223 273116	PETR SERGEEV	{"email": "sergeev.p_29031973@postgrespro.ru", "phone": "+70174310701"}
0005434610176	5119B8	6280 137741	RUSTAM NAZAROV	{"email": "nazarovrustam_19031966@postgrespro.ru", "phone": "+70131783720"}
0005434610177	509AC0	0975 650323	ANDREY BORISOV	{"email": "borisov-andrey.051973@postgrespro.ru", "phone": "+70327417525"}
0005434610178	60E42E	2207 934806	GALINA FADEEVA	{"email": "fadeeva-g_1972@postgrespro.ru", "phone": "+70522511503"}
0005434610179	60E42E	7384 792510	OKSANA BELYAEVA	{"email": "o_belyaeva.02091968@postgrespro.ru", "phone": "+70773360708"}
0005434610180	A29FCA	9166 902051	MIKHAIL BORISOV	{"email": "mborisov.19121977@postgrespro.ru", "phone": "+70689675577"}
0005434610181	A29FCA	6855 524467	VITALIY TIKHONOV	{"email": "tikhonov_v.091976@postgrespro.ru", "phone": "+70780013748"}
0005434610182	8C0819	0384 321915	NIKOLAY KARPOV	{"email": "karpovnikolay-081975@postgrespro.ru", "phone": "+70403583151"}
0005434610183	8C0819	1467 867524	NATALYA NOVIKOVA	{"email": "natalya-novikova.041967@postgrespro.ru", "phone": "+70074864777"}
0005434610184	EDE730	4735 946136	IVAN ZAYCEV	{"phone": "+70146730644"}
0005434610185	59D005	2948 060381	GALINA IVANOVA	{"phone": "+70265974143"}
0005434610186	59D005	5107 659923	ALEKSEY IVANOV	{"phone": "+70511393455"}
0005434610187	59D005	1563 169957	ALEKSEY RODIONOV	{"phone": "+70635460254"}
0005434610188	A94227	2483 009587	LARISA CHERNOVA	{"phone": "+70525060981"}
0005434610189	A94227	8725 310668	YURIY IVANOV	{"email": "ivanovy.12061984@postgrespro.ru", "phone": "+70616012174"}
0005434610190	CC7788	8602 243891	IVAN FILIPPOV	{"phone": "+70730012758"}
0005434610191	57AA18	5302 265849	OLGA GRISHINA	{"email": "grishina.olga.021980@postgrespro.ru", "phone": "+70333557806"}
0005434610192	E4341E	4284 425891	KHALIDA MELNIKOVA	{"phone": "+70911450275"}
0005434610193	3E21D7	8500 045808	DMITRIY OSIPOV	{"email": "osipov.d_021966@postgrespro.ru", "phone": "+70824928246"}
0005434610194	E74600	1274 874967	SVETLANA FILATOVA	{"phone": "+70317646415"}
0005434610195	A15AFD	6891 680926	OLGA MALYSHEVA	{"email": "o_malysheva_1968@postgrespro.ru", "phone": "+70274141215"}
0005434610196	2398EF	7668 550337	LIDIYA VOLKOVA	{"email": "lidiya_volkova.1972@postgrespro.ru", "phone": "+70128459963"}
0005434610197	569BA2	5499 799522	LILIYA KUDRYASHOVA	{"phone": "+70113960768"}
0005434610198	CC9628	0487 534810	KONSTANTIN ANDREEV	{"phone": "+70752196952"}
0005434610199	EC7870	2156 497588	MIKHAIL SAVELEV	{"email": "m_savelev-29031981@postgrespro.ru", "phone": "+70757887273"}
0005434610200	2950F4	0459 946936	ANASTASIYA IVANOVA	{"email": "ivanova.a_041968@postgrespro.ru", "phone": "+70430056134"}
0005434610201	EA9487	9698 946070	DMITRIY MATVEEV	{"email": "d.matveev.041975@postgrespro.ru", "phone": "+70733592163"}
0005434610202	EA9487	4199 319635	EKATERINA KAZAKOVA	{"phone": "+70279354352"}
0005434610203	6E3F60	6463 350683	ALEKSANDR KUZNECOV	{"phone": "+70816533623"}
0005434610204	907AC1	4820 870369	VLADIMIR FEDOTOV	{"email": "v-fedotov_1961@postgrespro.ru", "phone": "+70475689291"}
0005434610205	907AC1	5665 822488	VALERIYA DMITRIEVA	{"email": "dmitrievavaleriya_1987@postgrespro.ru", "phone": "+70246872241"}
0005434610206	4A6778	3311 578730	ALENA ANDREEVA	{"phone": "+70096250856"}
0005434610207	4A6778	1848 198549	ELENA NIKIFOROVA	{"email": "nikiforova-elena.071980@postgrespro.ru", "phone": "+70835742172"}
0005434610208	5827D0	8137 957646	PAVEL VASILEV	{"phone": "+70888274874"}
0005434610209	C1654B	7932 517794	ALEKSANDR FROLOV	{"phone": "+70105032231"}
0005434610210	8171B2	9958 023412	ILSHAT NOVIKOV	{"phone": "+70646675125"}
0005434610211	4EAFA7	1468 261599	PETR KULIKOV	{"email": "kulikov-petr-16071977@postgrespro.ru", "phone": "+70440459638"}
0005434610212	4DD05D	2303 994614	SVETLANA ZAYCEVA	{"email": "zayceva-svetlana_021966@postgrespro.ru", "phone": "+70322662834"}
0005434610213	44981B	8775 028373	ALEKSEY NIKOLAEV	{"email": "nikolaev.aleksey061980@postgrespro.ru", "phone": "+70197274415"}
0005434610214	024A9F	7747 464457	VASILIY SOROKIN	{"email": "v.sorokin061972@postgrespro.ru", "phone": "+70236010040"}
0005434610215	024A9F	6860 232848	ALEKSANDR IVANOV	{"email": "ivanov-a08041965@postgrespro.ru", "phone": "+70350794737"}
0005434610216	9DD623	7833 371246	LYUDMILA NESTEROVA	{"phone": "+70597851814"}
0005434610217	5259E5	1998 575113	SERGEY IVANOV	{"email": "s.ivanov19011975@postgrespro.ru", "phone": "+70968162648"}
0005434610218	DC8989	1722 384795	NATALYA ALEKSANDROVA	{"email": "aleksandrova-natalya-1963@postgrespro.ru", "phone": "+70296743239"}
0005434610221	5D3A94	5365 254733	IRINA SIDOROVA	{"email": "irina-sidorova21101972@postgrespro.ru", "phone": "+70240350550"}
0005434610222	905A81	8284 313256	SVETLANA NAUMOVA	{"phone": "+70384172045"}
0005434610223	905A81	7463 883176	VALENTINA ARKHIPOVA	{"email": "arkhipova_v1968@postgrespro.ru", "phone": "+70327633213"}
0005434610224	BA2726	1747 111421	OLEG BELOV	{"email": "o-belov1969@postgrespro.ru", "phone": "+70966347189"}
0005434610225	BA2726	2443 855205	TATYANA KOROLEVA	{"phone": "+70847026643"}
0005434610226	2CED83	4147 791173	TATYANA MAKAROVA	{"email": "makarovatatyana29041969@postgrespro.ru", "phone": "+70089313088"}
0005434610227	2CED83	5513 229059	DENIS SIDOROV	{"phone": "+70141426293"}
0005434610228	B5AFAD	3587 598192	VLADIMIR KUZNECOV	{"phone": "+70807249416"}
0005434610229	81A2E9	4452 166141	NATALYA POPOVA	{"email": "natalya.popova-021966@postgrespro.ru", "phone": "+70020615838"}
0005434610230	81A2E9	9216 405230	MIKHAIL BONDARENKO	{"email": "m-bondarenko-16081982@postgrespro.ru", "phone": "+70683973491"}
0005434610231	15CBCD	2757 360545	RAISA ZOTOVA	{"email": "zotovaraisa_061979@postgrespro.ru", "phone": "+70156475494"}
0005434610232	34C9F4	3975 195276	EKATERINA TROFIMOVA	{"email": "ekaterina_trofimova-28091973@postgrespro.ru", "phone": "+70271859665"}
0005434610233	281444	2691 060314	VALERIY FEDOROV	{"email": "valeriy.fedorov-03021983@postgrespro.ru", "phone": "+70785229611"}
0005434610234	281444	9436 368276	IVAN NIKOLAEV	{"phone": "+70778189380"}
0005434610235	281444	9933 157435	OKSANA NOVIKOVA	{"email": "novikova-oksana-22041984@postgrespro.ru", "phone": "+70539203022"}
0005434610236	500547	7375 482728	VALERIY KONOVALOV	{"phone": "+70897918782"}
0005434610237	54232C	9828 121401	NADEZHDA FEDOROVA	{"email": "nfedorova1961@postgrespro.ru", "phone": "+70000883908"}
0005434610238	54232C	4660 387202	VALENTINA YAKOVLEVA	{"phone": "+70582205334"}
0005434610239	B92703	0213 628573	NINA ANDREEVA	{"email": "nandreeva091963@postgrespro.ru", "phone": "+70599522677"}
0005434610240	B92703	9640 468000	VARVARA ZAKHAROVA	{"phone": "+70220171921"}
0005434610241	31360C	7150 936199	ALEKSANDR DENISOV	{"phone": "+70556778764"}
0005434610242	96943D	7944 948616	EKATERINA GRISHINA	{"email": "egrishina1981@postgrespro.ru", "phone": "+70471473800"}
0005434610243	96943D	7050 531237	SERGEY BORISOV	{"phone": "+70563136272"}
0005434610244	F601D6	5530 181272	SERGEY MARTYNOV	{"email": "s_martynov28031977@postgrespro.ru", "phone": "+70083328801"}
0005434610245	F601D6	2072 000057	NATALYA TITOVA	{"email": "titova.n.20041971@postgrespro.ru", "phone": "+70176460770"}
0005434610246	7A67B8	8986 758617	TATYANA MELNIKOVA	{"phone": "+70200783585"}
0005434610247	309618	0395 888455	ALEKSEY IVANOV	{"phone": "+70524656121"}
0005434610248	309618	2111 406989	GALINA GRISHINA	{"email": "g-grishina-031969@postgrespro.ru", "phone": "+70697306284"}
0005434610249	A66623	0194 432630	TATYANA VOLKOVA	{"email": "volkova-t_031968@postgrespro.ru", "phone": "+70378779180"}
0005434610250	4B2C7A	7766 275884	OLGA PETROVA	{"email": "opetrova.1981@postgrespro.ru", "phone": "+70391357134"}
0005434610251	4B2C7A	3905 467928	RAVILYA DAVYDOVA	{"phone": "+70769460526"}
0005434610252	305ADF	7536 207528	DANIIL ZAKHAROV	{"email": "zakharovdaniil-21011979@postgrespro.ru", "phone": "+70937537750"}
0005434610253	F259E3	9594 807501	ANDREY SOROKIN	{"email": "a.sorokin_091983@postgrespro.ru", "phone": "+70476907828"}
0005434610254	F259E3	3585 915355	ZINAIDA SOKOLOVA	{"email": "z.sokolova1972@postgrespro.ru", "phone": "+70160953748"}
0005434610255	E2077A	5724 077879	IGOR SEMENOV	{"email": "semenov-igor.111974@postgrespro.ru", "phone": "+70372809309"}
0005434610256	E2077A	6115 872872	IRINA ROMANOVA	{"phone": "+70560122134"}
0005434610257	16C2DC	3389 624374	SERGEY MARTYNOV	{"phone": "+70855003805"}
0005434610258	DED75E	5398 991919	OLEG TIKHONOV	{"email": "tikhonov-o1966@postgrespro.ru", "phone": "+70688901782"}
0005434610259	DFBBAC	0782 780355	ALEKSEY ABRAMOV	{"phone": "+70762541459"}
0005434610260	8869BF	0794 280753	MIKHAIL ANDREEV	{"email": "andreev.mikhail_081991@postgrespro.ru", "phone": "+70934158926"}
0005434610261	8869BF	0332 158331	ROMAN KUZNECOV	{"phone": "+70374431258"}
0005434610262	5EBCF2	0963 510236	ALBINA TITOVA	{"phone": "+70224860314"}
0005434610263	5468D0	8912 815154	ALEKSANDR AFANASEV	{"phone": "+70224761370"}
0005434610264	C65E84	9474 259548	LYUDMILA TARASOVA	{"email": "ltarasova-111965@postgrespro.ru", "phone": "+70229318422"}
0005434610265	C65E84	8695 679427	EKATERINA BELOVA	{"email": "belova_e_10021972@postgrespro.ru", "phone": "+70005471002"}
0005434610266	2D9C8F	4110 486113	OLGA DAVYDOVA	{"email": "odavydova.1957@postgrespro.ru", "phone": "+70530780999"}
0005434610267	A1FF69	2820 225892	ANDREY ANDREEV	{"phone": "+70355876602"}
0005434610268	A1FF69	2331 923895	NATALYA MATVEEVA	{"phone": "+70883822402"}
0005434610269	782F8B	9389 858814	LILIYA KUZNECOVA	{"phone": "+70646245513"}
0005434610270	374F71	1751 764519	EVGENIY MIKHAYLOV	{"email": "mikhaylov-e101964@postgrespro.ru", "phone": "+70489023130"}
0005434610271	374F71	8890 298491	ALEKSANDR YAKOVLEV	{"email": "yakovleva021974@postgrespro.ru", "phone": "+70987027620"}
0005434610272	0F89B2	9531 579082	ALEKSEY MOISEEV	{"email": "moiseev-a.011969@postgrespro.ru", "phone": "+70401741335"}
0005434610273	85E34F	9142 807422	LYUDMILA ALEKSEEVA	{"phone": "+70984526447"}
0005434610274	593068	8940 622808	IRINA BARANOVA	{"phone": "+70574860973"}
0005434610275	AB27F7	3909 476324	YURIY SIDOROV	{"email": "sidorov_yuriy_15051975@postgrespro.ru", "phone": "+70181247670"}
0005434610276	44EF1D	2072 568727	NATALYA FEDOROVA	{"phone": "+70080040443"}
0005434610277	FCE033	2516 543087	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_23101975@postgrespro.ru", "phone": "+70414870111"}
0005434610278	94D746	5643 111854	DANILA SEMENOV	{"phone": "+70474979599"}
0005434610279	BE72A0	5553 535969	NINA NAUMOVA	{"email": "naumova-n29091962@postgrespro.ru", "phone": "+70604327801"}
0005434610280	C0803E	3003 840602	IRINA EFIMOVA	{"phone": "+70932037933"}
0005434610282	532643	6149 393860	NINA SERGEEVA	{"phone": "+70500714642"}
0005434610283	379B0E	1876 326596	DMITRIY TIKHONOV	{"phone": "+70039221361"}
0005434610284	379B0E	9972 470464	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr_031973@postgrespro.ru", "phone": "+70806817862"}
0005434610285	9C5AB2	1294 459174	MIKHAIL GERASIMOV	{"phone": "+70274968858"}
0005434610286	ABFC21	5366 571353	ANDREY ANTONOV	{"email": "a.antonov-1965@postgrespro.ru", "phone": "+70001584938"}
0005434610287	E18DB1	4229 678910	ALEKSANDR MEDVEDEV	{"email": "medvedev-a.071969@postgrespro.ru", "phone": "+70181317265"}
0005434610288	E18DB1	4815 807955	DMITRIY ILIN	{"phone": "+70276443895"}
0005434610289	066DB6	0710 674411	ALEKSANDR VASILEV	{"email": "vasilev_a_021967@postgrespro.ru", "phone": "+70953041227"}
0005434610290	8C23A8	1173 333551	TATYANA KONOVALOVA	{"email": "konovalova-t_081982@postgrespro.ru", "phone": "+70471003721"}
0005434610291	ECAAF7	8631 455302	MIKHAIL SERGEEV	{"email": "sergeev.mikhail1973@postgrespro.ru", "phone": "+70384039055"}
0005434610292	ECAAF7	3183 909871	LARISA IVANOVA	{"phone": "+70173420741"}
0005434610293	ECAAF7	2602 748493	VYACHESLAV PETROV	{"email": "petrovvyacheslav-28051978@postgrespro.ru", "phone": "+70348570854"}
0005434610294	0BF833	7923 724273	MARINA CHERNOVA	{"phone": "+70734077578"}
0005434610295	2FE673	3017 673881	ELENA IVANOVA	{"email": "e-ivanova_1969@postgrespro.ru", "phone": "+70786212344"}
0005434610296	2FE673	3265 317211	VASILIY MIKHAYLOV	{"email": "vasiliy-mikhaylov_21091972@postgrespro.ru", "phone": "+70908314665"}
0005434610297	563F55	5387 858729	VERA KOROLEVA	{"phone": "+70842156267"}
0005434610298	F74C95	9415 161807	NATALYA NIKITINA	{"phone": "+70573694621"}
0005434610299	A04F3A	6324 876721	ANATOLIY ALEKSEEV	{"phone": "+70491550238"}
0005434610300	2AA456	7420 334109	ULYANA MAKAROVA	{"email": "u_makarova-02071978@postgrespro.ru", "phone": "+70345912604"}
0005434610301	9E23B3	8121 864343	IGOR ILIN	{"phone": "+70260908597"}
0005434610302	A521E8	2762 599312	ALEKSANDR GRIGOREV	{"email": "grigorev-a-1975@postgrespro.ru", "phone": "+70476753486"}
0005434610303	19AE47	1963 501379	ALENA ZAKHAROVA	{"email": "alenazakharova021969@postgrespro.ru", "phone": "+70855060990"}
0005434610304	19AE47	6476 912213	ELENA ROMANOVA	{"phone": "+70896068326"}
0005434610305	5074A3	9158 326176	VERA TIKHONOVA	{"email": "v-tikhonova.031983@postgrespro.ru", "phone": "+70121576630"}
0005434610306	27974E	7755 130900	SVETLANA NIKITINA	{"phone": "+70095121752"}
0005434610307	4E2DB9	1914 611801	MARGARITA KUZNECOVA	{"email": "kuznecova.m.091960@postgrespro.ru", "phone": "+70320364781"}
0005434610308	AE9EDB	9572 612129	VLADIMIR SOKOLOV	{"email": "sokolovvladimir_1981@postgrespro.ru", "phone": "+70289921188"}
0005434610309	DACC10	0147 989504	DMITRIY IVANOV	{"email": "ivanov.d-1977@postgrespro.ru", "phone": "+70799566206"}
0005434610310	DACC10	7729 480644	RAISA VOLKOVA	{"phone": "+70524863405"}
0005434610311	0C9EB7	3924 503654	ALEKSEY ZAYCEV	{"phone": "+70643396062"}
0005434610312	0C9EB7	8818 809299	ANATOLIY GORBUNOV	{"phone": "+70497356818"}
0005434610313	611460	8746 128125	FARIT TARASOV	{"email": "f-tarasov_1973@postgrespro.ru", "phone": "+70355428588"}
0005434610314	D72F57	8088 516707	NIKOLAY YAKOVLEV	{"phone": "+70225722968"}
0005434610315	D72F57	4074 456265	EGOR TARASOV	{"email": "e.tarasov.1968@postgrespro.ru", "phone": "+70066979127"}
0005434610316	D3135C	4322 247426	VIKTOR EGOROV	{"email": "vegorov.21121966@postgrespro.ru", "phone": "+70824257168"}
0005434610317	3D1CE0	6566 285866	EKATERINA OSIPOVA	{"phone": "+70318121675"}
0005434610318	3D1CE0	9925 125959	MARIYA BOGDANOVA	{"email": "bogdanovamariya16081976@postgrespro.ru", "phone": "+70703671877"}
0005434610319	0F6275	0436 827675	SERGEY FEDOROV	{"phone": "+70468621268"}
0005434610320	89C2E6	8227 469967	ELIZAVETA GORBUNOVA	{"email": "elizaveta.gorbunova.1963@postgrespro.ru", "phone": "+70276283810"}
0005434610321	C75CE8	8926 038538	RODION SCHERBAKOV	{"email": "r-scherbakov_1966@postgrespro.ru", "phone": "+70415297164"}
0005434610322	0CC288	1820 186350	TATYANA ALEKSEEVA	{"phone": "+70201655780"}
0005434610323	0CC288	3472 083031	ALEKSEY KUZNECOV	{"phone": "+70557841929"}
0005434610324	02606F	8648 783281	NINA PETROVA	{"phone": "+70520692649"}
0005434610325	02606F	4696 043689	NINA GERASIMOVA	{"email": "gerasimova.nina.1975@postgrespro.ru", "phone": "+70866674505"}
0005434610326	D3E9BB	3949 083200	NATALYA POPOVA	{"email": "popova.natalya091982@postgrespro.ru", "phone": "+70182183342"}
0005434610327	D3E9BB	4673 187673	KONSTANTIN YAKOVLEV	{"email": "yakovlev_konstantin.1972@postgrespro.ru", "phone": "+70336136162"}
0005434610328	D3E9BB	5053 508651	ALINA VLASOVA	{"email": "vlasova-a_101967@postgrespro.ru", "phone": "+70113152500"}
0005434610329	511687	3821 736274	GENNADIY SEMENOV	{"email": "semenov.g1972@postgrespro.ru", "phone": "+70265483548"}
0005434610330	511687	4188 483644	EMIL RODIONOV	{"email": "rodionov_emil011975@postgrespro.ru", "phone": "+70971336691"}
0005434610331	3B621C	4746 296835	VALENTINA POPOVA	{"phone": "+70910126050"}
0005434610332	0DE709	1321 431740	ANATOLIY KOROLEV	{"phone": "+70742314631"}
0005434610333	0DE709	6306 642558	IRINA MAKAROVA	{"email": "irina-makarova-051974@postgrespro.ru", "phone": "+70024718591"}
0005434610334	636233	7339 595738	VALENTINA TARASOVA	{"phone": "+70049591485"}
0005434610335	6D8300	1780 225388	DAVID SEMENOV	{"email": "davidsemenov-22031962@postgrespro.ru", "phone": "+70842644002"}
0005434610336	25357C	3961 875994	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova011968@postgrespro.ru", "phone": "+70360182639"}
0005434610337	25357C	3673 718358	VLADIMIR SHEVCHENKO	{"email": "shevchenkov_1967@postgrespro.ru", "phone": "+70799424593"}
0005434610338	E29405	9659 755506	PETR BARANOV	{"email": "baranov-petr051977@postgrespro.ru", "phone": "+70695535464"}
0005434620222	454445	1476 508664	GULNARA NAUMOVA	{"phone": "+70030589693"}
0005434620223	0A9573	7609 563352	TATYANA KONOVALOVA	{"phone": "+70481375367"}
0005434620224	0A9573	1379 760036	SVETLANA RODIONOVA	{"phone": "+70373036642"}
0005434620225	510B32	3720 649176	SVETLANA MATVEEVA	{"phone": "+70507223981"}
0005434620226	510B32	1230 669040	ARSENIY IVANOV	{"phone": "+70905302047"}
0005434620227	40119E	5019 582868	IRINA LAZAREVA	{"phone": "+70440391733"}
0005434620228	40119E	4501 756247	VIKTORIYA FROLOVA	{"phone": "+70387125709"}
0005434620229	DB0833	0467 499912	VIKTORIYA YAKOVLEVA	{"email": "yakovleva_viktoriya-1974@postgrespro.ru", "phone": "+70371212730"}
0005434620230	DB0833	4012 439186	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr.011976@postgrespro.ru", "phone": "+70368465013"}
0005434620231	5A8B28	3998 385146	LYUDMILA PETROVA	{"email": "l.petrova1977@postgrespro.ru", "phone": "+70596175830"}
0005434620232	34AAF2	1701 061733	OKSANA FROLOVA	{"email": "o_frolova-24081978@postgrespro.ru", "phone": "+70006432158"}
0005434620233	34AAF2	0652 573704	YULIYA NIKITINA	{"email": "nikitina.yuliya101974@postgrespro.ru", "phone": "+70817864426"}
0005434620234	9F84A1	1023 963279	NADEZHDA ZOTOVA	{"email": "zotova-nadezhda-1975@postgrespro.ru", "phone": "+70132031767"}
0005434620235	9C940F	8905 637560	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr_091982@postgrespro.ru", "phone": "+70589967214"}
0005434620236	8C6FCC	5270 840048	VLADIMIR ILIN	{"phone": "+70739128978"}
0005434620237	C948A0	4306 636406	GENNADIY SOROKIN	{"email": "sorokin.gennadiy_1984@postgrespro.ru", "phone": "+70310170511"}
0005434620406	488E2E	4443 653806	VALERIY ZHURAVLEV	{"phone": "+70756778112"}
0005434620238	B090FA	3051 408101	ANASTASIYA NAZAROVA	{"email": "nazarova.anastasiya.041976@postgrespro.ru", "phone": "+70080428859"}
0005434620239	3C9990	1311 194145	TATYANA POTAPOVA	{"email": "potapovat_071974@postgrespro.ru", "phone": "+70762741364"}
0005434620240	3C9990	1568 428076	ALEKSEY ZHUKOV	{"email": "aleksey_zhukov_07051974@postgrespro.ru", "phone": "+70127995515"}
0005434620241	FA7341	3813 833625	VLADIMIR FOMIN	{"email": "vladimir-fomin_10061961@postgrespro.ru", "phone": "+70928827394"}
0005434620242	BD4B73	5022 586590	IGOR SERGEEV	{"phone": "+70945175011"}
0005434620243	C8C3E2	7160 430576	VLADIMIR IVANOV	{"email": "ivanovvladimir-1960@postgrespro.ru", "phone": "+70244036746"}
0005434620244	B6155C	5120 506887	VITALIY RODIONOV	{"email": "vitaliy_rodionov-1960@postgrespro.ru", "phone": "+70997368648"}
0005434620245	B6155C	7180 124656	MARINA VLASOVA	{"phone": "+70790413715"}
0005434620246	3FB00E	9431 771133	OLEG VOLKOV	{"phone": "+70669497991"}
0005434620247	6540BB	9391 932516	VALENTINA KOROLEVA	{"phone": "+70892909452"}
0005434620248	6540BB	6600 565055	ALEKSANDR FEDOROV	{"phone": "+70847707611"}
0005434620249	A4CA9E	3896 840195	NATALIYA MAKSIMOVA	{"email": "maksimova.n.06041978@postgrespro.ru", "phone": "+70898237981"}
0005434620250	1076EC	9094 612838	VLADISLAV FEDOROV	{"email": "vladislav.fedorov-061983@postgrespro.ru", "phone": "+70057559591"}
0005434620251	4430D1	4690 949421	MARIYA MIKHAYLOVA	{"phone": "+70554724951"}
0005434620252	4430D1	7519 617741	ALEKSANDR KARPOV	{"email": "karpov-aleksandr1962@postgrespro.ru", "phone": "+70071802929"}
0005434620253	8990AA	4822 888568	OLEG IVANOV	{"phone": "+70767369763"}
0005434620254	17C92C	6810 930520	ANDREY DMITRIEV	{"phone": "+70096604951"}
0005434620255	2A0BA5	2991 254089	VIKTOR FROLOV	{"phone": "+70148695017"}
0005434620256	D4ABD7	1754 428798	IGOR DENISOV	{"email": "igor.denisov031974@postgrespro.ru", "phone": "+70940954135"}
0005434620257	D4ABD7	3113 198799	VIKTOR MAKSIMOV	{"phone": "+70412606661"}
0005434620258	901E26	1484 128351	VLADIMIR ZAKHAROV	{"phone": "+70687313632"}
0005434620259	901E26	0644 815800	LARISA KOZLOVA	{"email": "l.kozlova-1968@postgrespro.ru", "phone": "+70666601436"}
0005434620260	B9B7F9	2250 176511	GUZEL IVANOVA	{"email": "guzelivanova1971@postgrespro.ru", "phone": "+70586558081"}
0005434620261	08052D	3269 154658	TATYANA STEPANOVA	{"email": "t-stepanova.1969@postgrespro.ru", "phone": "+70096134714"}
0005434620262	B5B4B9	7607 584042	LYUBOV ZOTOVA	{"email": "lyubovzotova15011971@postgrespro.ru", "phone": "+70359302591"}
0005434620263	75D374	7686 258630	ALEKSANDRA TIMOFEEVA	{"phone": "+70933566704"}
0005434620264	4FDBB7	9751 798601	DARYA MAKAROVA	{"phone": "+70423596944"}
0005434620265	7454E7	3723 717047	SERGEY NIKOLAEV	{"email": "sergeynikolaev111968@postgrespro.ru", "phone": "+70740360513"}
0005434620266	50B171	7293 920291	ANNA SERGEEVA	{"phone": "+70817237161"}
0005434620267	50B171	3026 683697	MARIYA NAUMOVA	{"phone": "+70046790305"}
0005434620268	08C070	8295 554823	IVAN SHEVCHENKO	{"phone": "+70956148546"}
0005434620269	08C070	8288 541387	VADIM POPOV	{"email": "popovvadim1971@postgrespro.ru", "phone": "+70568557684"}
0005434620270	17126D	0838 183619	PAVEL BORISOV	{"phone": "+70038333010"}
0005434620271	37583F	8833 490616	NATALYA KOZLOVA	{"phone": "+70652496282"}
0005434620272	9E0F67	4744 789821	GALINA SOROKINA	{"email": "galinasorokina-15071965@postgrespro.ru", "phone": "+70717961837"}
0005434620273	536CDA	2494 785399	YURIY VOROBEV	{"email": "vorobev_y15091969@postgrespro.ru", "phone": "+70441893120"}
0005434620274	260316	3247 252675	LYUDMILA BELOVA	{"email": "l-belova_111970@postgrespro.ru", "phone": "+70130487791"}
0005434620275	3ADE61	5843 045135	VLADIMIR EGOROV	{"email": "egorov.v.1973@postgrespro.ru", "phone": "+70070029059"}
0005434620276	3ADE61	4714 104462	IVAN KUDRYASHOV	{"email": "kudryashov_i1969@postgrespro.ru", "phone": "+70404136895"}
0005434620277	A4A227	9401 458015	SERGEY BARANOV	{"email": "s_baranov1981@postgrespro.ru", "phone": "+70768170413"}
0005434620278	D7EE27	8750 307291	OLGA VOLKOVA	{"phone": "+70492908925"}
0005434620279	45944F	6186 558178	MARIYA KOZLOVA	{"phone": "+70764348464"}
0005434620280	4F6982	2721 123778	IRINA VOLKOVA	{"phone": "+70862627269"}
0005434620281	4F6982	8139 326348	GENNADIY SOROKIN	{"phone": "+70040984405"}
0005434620282	DAB343	6727 759972	GALINA POTAPOVA	{"email": "potapova.g08051978@postgrespro.ru", "phone": "+70452343069"}
0005434620283	DAB343	6159 500193	VLADIMIR DMITRIEV	{"phone": "+70995602264"}
0005434620284	0F2F17	7537 395890	KONSTANTIN VLASOV	{"email": "konstantin_vlasov1967@postgrespro.ru", "phone": "+70281720375"}
0005434620285	D2C457	6851 698081	ELENA MAKAROVA	{"phone": "+70308734334"}
0005434620286	D2C457	1753 819417	OLGA ERMAKOVA	{"email": "o_ermakova_021968@postgrespro.ru", "phone": "+70687858672"}
0005434620287	D2C457	6532 371642	MARIYA MIKHAYLOVA	{"email": "mariya-mikhaylova.1958@postgrespro.ru", "phone": "+70004389127"}
0005434620288	D2C457	1030 892967	MIKHAIL KULIKOV	{"email": "kulikov.mikhail_1961@postgrespro.ru", "phone": "+70711198898"}
0005434620289	08C827	9413 531589	VITALIY SERGEEV	{"email": "sergeevv.051963@postgrespro.ru", "phone": "+70208842578"}
0005434620290	420484	2935 305359	ANASTASIYA KULIKOVA	{"email": "akulikova-1984@postgrespro.ru", "phone": "+70365226060"}
0005434620291	D20274	4597 966371	DARYA CHERNOVA	{"email": "chernova_d-111975@postgrespro.ru", "phone": "+70024534060"}
0005434620292	3AB409	4462 253250	IRINA LUKYANOVA	{"email": "lukyanova.irina_1971@postgrespro.ru", "phone": "+70569558030"}
0005434620293	7A1826	6026 762127	ZINAIDA FEDOROVA	{"email": "z.fedorova_1971@postgrespro.ru", "phone": "+70776231038"}
0005434620294	7A1826	6457 373956	NIKOLAY KUZMIN	{"email": "kuzminnikolay.1971@postgrespro.ru", "phone": "+70922334342"}
0005434620295	B61688	7531 643889	NINA KOVALEVA	{"phone": "+70042378450"}
0005434620296	FAF5C2	5797 315056	VIKTOR POPOV	{"email": "viktor.popov.031968@postgrespro.ru", "phone": "+70622819287"}
0005434620297	8A01AA	9637 571812	GULFIYA ANTONOVA	{"phone": "+70444205263"}
0005434620298	75C939	8507 534493	RAISA ZAYCEVA	{"phone": "+70936847886"}
0005434620299	D098EF	4354 255056	MARINA OSIPOVA	{"phone": "+70671504440"}
0005434620300	D098EF	9127 283186	ERIK SOKOLOV	{"email": "erik_sokolov081970@postgrespro.ru", "phone": "+70314485866"}
0005434620301	D098EF	1114 012948	NATALYA KUZNECOVA	{"email": "kuznecovanatalya-1978@postgrespro.ru", "phone": "+70555329214"}
0005434620302	851F63	0086 821164	TAMARA MELNIKOVA	{"phone": "+70906067500"}
0005434620303	851F63	0745 044976	SEMEN MAKSIMOV	{"phone": "+70094322443"}
0005434620304	851F63	7640 620192	YURIY NIKOLAEV	{"email": "yuriy-nikolaev_22021977@postgrespro.ru", "phone": "+70684982243"}
0005434620305	7EE330	6045 270570	ALEKSEY FEDOROV	{"email": "fedorov.aleksey-06041976@postgrespro.ru", "phone": "+70667757971"}
0005434620306	B86140	8829 335289	VALENTINA KUZNECOVA	{"phone": "+70476333392"}
0005434620307	B86140	4053 312590	GALINA LEBEDEVA	{"email": "g-lebedeva_1976@postgrespro.ru", "phone": "+70722482149"}
0005434620308	13086C	9285 189626	IVAN BELOV	{"email": "belov.ivan-13121965@postgrespro.ru", "phone": "+70553534034"}
0005434620309	13086C	0005 155781	VLADIMIR IVANOV	{"phone": "+70187231220"}
0005434620310	5E3126	6374 326937	OLGA KULIKOVA	{"email": "okulikova1966@postgrespro.ru", "phone": "+70523771744"}
0005434620311	5E3126	1814 128667	VIKTOR MATVEEV	{"email": "vmatveev-21091975@postgrespro.ru", "phone": "+70972305465"}
0005434620312	EA7BF9	9922 680888	ALEKSEY VASILEV	{"email": "a_vasilev-091981@postgrespro.ru", "phone": "+70656102402"}
0005434620313	CC27CC	1432 174894	ROMAN POPOV	{"email": "r_popov_23091968@postgrespro.ru", "phone": "+70991559911"}
0005434620314	C3F5E7	4625 557519	VYACHESLAV VASILEV	{"email": "v_vasilev.051974@postgrespro.ru", "phone": "+70569658681"}
0005434620315	C3F5E7	3399 035116	RAFAEL FOMIN	{"email": "rafael_fomin1963@postgrespro.ru", "phone": "+70890250785"}
0005434620316	A388B5	4558 052179	ANDREY SOKOLOV	{"phone": "+70581369573"}
0005434620317	11DCF9	8092 179560	ALEKSEY PAVLOV	{"phone": "+70209356566"}
0005434620318	7F1E0E	2332 580481	ALEKSANDR TARASOV	{"phone": "+70396054710"}
0005434620319	7F1E0E	6289 182443	ALEKSANDR ZAYCEV	{"email": "aleksandrzaycev_051963@postgrespro.ru", "phone": "+70986364214"}
0005434620320	D1CC5D	4332 084272	ALEKSEY VOROBEV	{"email": "vorobev.aleksey011975@postgrespro.ru", "phone": "+70128208119"}
0005434620321	D1CC5D	4302 288416	SVETLANA KOZLOVA	{"email": "kozlovasvetlana_03011977@postgrespro.ru", "phone": "+70656795974"}
0005434620322	7F23CF	3342 837364	NADEZHDA YAKOVLEVA	{"email": "n_yakovleva.1974@postgrespro.ru", "phone": "+70405727221"}
0005434620323	7F23CF	7052 773802	OLEG FEDOTOV	{"phone": "+70349941078"}
0005434620324	61849B	4225 994630	IVAN FEDOROV	{"phone": "+70830731219"}
0005434620325	61849B	8871 888161	ALEKSANDRA ZHURAVLEVA	{"phone": "+70744187609"}
0005434620326	CEFFC2	4185 048576	ALINA GORBUNOVA	{"email": "a.gorbunova-07111964@postgrespro.ru", "phone": "+70344782916"}
0005434620327	ACD989	8422 720632	VALENTINA MAKSIMOVA	{"email": "maksimova_valentina-061967@postgrespro.ru", "phone": "+70627008426"}
0005434620328	86AE70	0863 415597	SERGEY SOLOVEV	{"email": "solovevsergey.021965@postgrespro.ru", "phone": "+70162907673"}
0005434620329	02408F	4221 666360	TATYANA SAVELEVA	{"phone": "+70199137618"}
0005434620330	02408F	3440 412708	ALEKSANDR MELNIKOV	{"email": "a.melnikov-1979@postgrespro.ru", "phone": "+70376233167"}
0005434620331	076C80	7958 263093	SERGEY MAKSIMOV	{"email": "maksimovsergey.1971@postgrespro.ru", "phone": "+70780558095"}
0005434620332	35347D	6839 297643	DMITRIY ABRAMOV	{"email": "dmitriyabramov-1974@postgrespro.ru", "phone": "+70519663426"}
0005434620333	51610A	3741 705369	VLADIMIR ZHUKOV	{"email": "vzhukov.1975@postgrespro.ru", "phone": "+70705542153"}
0005434620334	51610A	6988 684909	STANISLAV ANDREEV	{"email": "andreev-s.091975@postgrespro.ru", "phone": "+70006033624"}
0005434620335	362BEB	3046 061325	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a_111968@postgrespro.ru", "phone": "+70685961603"}
0005434620336	4E4DE0	6969 036142	ALENA KULIKOVA	{"phone": "+70160560856"}
0005434620337	094DBC	5517 180735	GENNADIY MAKAROV	{"phone": "+70589674852"}
0005434620338	9317F6	1539 983990	EKATERINA KULIKOVA	{"phone": "+70523634061"}
0005434620339	9317F6	7468 120536	VALERIYA ROMANOVA	{"phone": "+70422878608"}
0005434620340	9317F6	5300 028725	ALEKSANDR SERGEEV	{"email": "sergeev.aleksandr_1975@postgrespro.ru", "phone": "+70474839168"}
0005434620341	96AD16	1173 869104	ALEKSEY ROMANOV	{"phone": "+70843386009"}
0005434620342	38EC90	7587 682485	EVGENIY ANTONOV	{"phone": "+70077590109"}
0005434620343	CFACA0	8299 953839	OLGA MARTYNOVA	{"email": "o-martynova_1971@postgrespro.ru", "phone": "+70806534169"}
0005434620344	262C96	3859 911003	KHALIDA EGOROVA	{"email": "egorovak_091973@postgrespro.ru", "phone": "+70497473657"}
0005434620345	262C96	7063 221918	SERGEY NIKOLAEV	{"email": "nikolaev-sergey-1975@postgrespro.ru", "phone": "+70496775408"}
0005434620346	B0ADDA	7045 690911	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana27061965@postgrespro.ru", "phone": "+70301899089"}
0005434620347	B0ADDA	2064 043422	DMITRIY ZAYCEV	{"phone": "+70330996098"}
0005434620348	287C79	6206 792654	RISHAT BORISOV	{"phone": "+70315024491"}
0005434620349	287C79	6243 256090	TAMARA KOZLOVA	{"phone": "+70488044843"}
0005434620350	FD9AC1	7212 243213	SERGEY FEDOROV	{"email": "fedorov.sergey_1965@postgrespro.ru", "phone": "+70031852746"}
0005434620351	588110	6263 907577	OLGA SAVELEVA	{"email": "savelevaolga15091983@postgrespro.ru", "phone": "+70112041966"}
0005434620352	9BF6C0	0451 057612	ANDREY EGOROV	{"email": "egorov_a121968@postgrespro.ru", "phone": "+70823064287"}
0005434620353	F3A4CF	0679 559328	IVAN ALEKSEEV	{"email": "alekseev-i-1972@postgrespro.ru", "phone": "+70618507408"}
0005434620354	DBA064	1477 615350	VALENTINA VASILEVA	{"phone": "+70930229789"}
0005434620355	AF50F7	2782 184912	NATALYA PAVLOVA	{"phone": "+70646916096"}
0005434620356	C1CB7A	6234 495287	ARTEM BONDARENKO	{"phone": "+70381103182"}
0005434620357	6CB18E	9003 207297	VALERIY GORBUNOV	{"phone": "+70695261847"}
0005434620358	1C577D	0615 338495	OLGA VASILEVA	{"phone": "+70031019035"}
0005434620359	324644	0856 363784	NADEZHDA SOROKINA	{"email": "sorokina-n1977@postgrespro.ru", "phone": "+70570543304"}
0005434620360	239EDD	3411 676588	MAKSIM SIDOROV	{"email": "m.sidorov-1983@postgrespro.ru", "phone": "+70796898498"}
0005434620361	239EDD	0840 551667	OLGA KUZMINA	{"phone": "+70539407288"}
0005434620362	5B89C8	3238 640372	ALEKSANDR IVANOV	{"email": "aleksandrivanov.25051982@postgrespro.ru", "phone": "+70125416795"}
0005434620363	5B89C8	0447 382007	ELENA KUZNECOVA	{"phone": "+70838589188"}
0005434620364	B04484	4994 634504	VALERIY MATVEEV	{"email": "valeriy.matveev.1960@postgrespro.ru", "phone": "+70999108550"}
0005434620365	F7BF26	0298 340207	OLGA POTAPOVA	{"email": "potapova.o_031964@postgrespro.ru", "phone": "+70371285196"}
0005434620366	F7BF26	1414 615854	VALENTINA TARASOVA	{"email": "tarasovav.1976@postgrespro.ru", "phone": "+70362583113"}
0005434620367	F7BF26	6567 836889	ROMAN KULIKOV	{"phone": "+70872114490"}
0005434620368	6CFEBE	7671 838982	SERGEY NAUMOV	{"phone": "+70333198174"}
0005434620369	6CFEBE	8485 070109	EVGENIY RODIONOV	{"phone": "+70884728266"}
0005434620370	21B2B5	1656 912793	LYUDMILA VOROBEVA	{"email": "lyudmila_vorobeva_14031972@postgrespro.ru", "phone": "+70487412541"}
0005434620371	5F8501	5205 329189	ALEKSEY FILIPPOV	{"phone": "+70514498194"}
0005434620372	4D7F21	7583 951082	DARYA LAZAREVA	{"phone": "+70566938243"}
0005434620373	2B33FA	5023 703737	ELVIRA NAUMOVA	{"email": "enaumova091984@postgrespro.ru", "phone": "+70019527413"}
0005434620374	18C8D3	4818 762836	OLGA KOMAROVA	{"phone": "+70472902170"}
0005434620375	B7D8E7	3999 507747	NADEZHDA MEDVEDEVA	{"email": "medvedeva.nadezhda_03101972@postgrespro.ru", "phone": "+70419346904"}
0005434620376	31D272	8577 830025	DAVID BELOV	{"phone": "+70578743416"}
0005434620377	F5C66A	4000 766148	MAKSIM KARPOV	{"phone": "+70530300083"}
0005434620378	302538	2104 342186	INNA ROMANOVA	{"email": "romanova.inna_1984@postgrespro.ru", "phone": "+70396329807"}
0005434620379	302538	7896 579057	DMITRIY CHERNOV	{"phone": "+70584683066"}
0005434620380	B0E383	0590 716466	DENIS PETROV	{"email": "petrov-denis-081966@postgrespro.ru", "phone": "+70319409958"}
0005434620381	7326BC	9538 615250	NADEZHDA KOROLEVA	{"email": "nadezhda-koroleva_011978@postgrespro.ru", "phone": "+70133062807"}
0005434620382	1A8D1A	1284 485406	MIKHAIL ANTONOV	{"phone": "+70465200514"}
0005434620383	1A8D1A	1027 093743	SVETLANA DAVYDOVA	{"phone": "+70611201574"}
0005434620384	DF97F3	2445 213179	IVAN VASILEV	{"email": "ivan-vasilev_1966@postgrespro.ru", "phone": "+70748356824"}
0005434620385	DF97F3	1162 265333	ALEKSEY IVANOV	{"email": "aivanov-30111982@postgrespro.ru", "phone": "+70049546831"}
0005434620386	75B036	4130 285362	ELIZAVETA ZAYCEVA	{"email": "ezayceva.31051964@postgrespro.ru", "phone": "+70049186356"}
0005434620387	FD2077	9236 397467	TATYANA IVANOVA	{"email": "ivanova_tatyana.1961@postgrespro.ru", "phone": "+70289998170"}
0005434620388	9D75A8	7484 857223	IGOR ZAKHAROV	{"phone": "+70443665432"}
0005434620389	9D75A8	2707 571355	NATALYA TITOVA	{"phone": "+70269887817"}
0005434620390	B4C8B7	4842 729727	DENIS KAZAKOV	{"email": "kazakov-denis.1975@postgrespro.ru", "phone": "+70079517492"}
0005434620391	6F1F23	5364 983741	NINA ISAEVA	{"email": "nisaeva.18081973@postgrespro.ru", "phone": "+70994864607"}
0005434620392	6F1F23	4108 931835	ELENA FILIPPOVA	{"email": "filippovaelena_1976@postgrespro.ru", "phone": "+70449684322"}
0005434620393	D90B7C	5680 555871	VLADIMIR ALEKSANDROV	{"email": "vladimir_aleksandrov_081979@postgrespro.ru", "phone": "+70017488915"}
0005434620394	40A234	3459 704357	DMITRIY DAVYDOV	{"email": "dmitriy-davydov_17031960@postgrespro.ru", "phone": "+70290752208"}
0005434620395	EE7D67	0128 652887	YULIYA ROMANOVA	{"phone": "+70981029711"}
0005434620396	EE7D67	4046 008183	NATALYA POTAPOVA	{"phone": "+70931951550"}
0005434620397	E6E824	4312 754602	DAMIR SEMENOV	{"phone": "+70884686859"}
0005434620398	E6E824	8493 326576	PAVEL NIKOLAEV	{"email": "nikolaev-p-1976@postgrespro.ru", "phone": "+70312677820"}
0005434620399	8D33D3	8769 800791	ALEKSEY MAKAROV	{"email": "makarov-aleksey121977@postgrespro.ru", "phone": "+70218224378"}
0005434620400	8D33D3	4639 414279	YURIY SAVELEV	{"phone": "+70567803348"}
0005434620401	810C37	8036 922208	ANDREY KUZNECOV	{"phone": "+70248908733"}
0005434620462	75A0A8	0154 907835	TATYANA MAKAROVA	{"phone": "+70045766572"}
0005434620402	291945	6264 625889	LYUDMILA KUZNECOVA	{"email": "lkuznecova-1971@postgrespro.ru", "phone": "+70291834651"}
0005434620403	D56AF3	8961 588823	SERGEY MAKAROV	{"email": "smakarov-12051974@postgrespro.ru", "phone": "+70822180148"}
0005434620404	BB96E5	0411 461525	ALEKSEY MAKAROV	{"email": "makarov-aleksey.1978@postgrespro.ru", "phone": "+70830139911"}
0005434620405	FFB8F9	8913 632961	VLADIMIR SMIRNOV	{"phone": "+70735729497"}
0005434620407	F33CA6	4808 159993	MARINA KUZNECOVA	{"email": "kuznecova_marina.071987@postgrespro.ru", "phone": "+70056401796"}
0005434620408	973C3E	1913 096138	ANDREY NIKOLAEV	{"email": "a_nikolaev.1985@postgrespro.ru", "phone": "+70442669755"}
0005434620409	973C3E	5378 683992	VERA SOROKINA	{"phone": "+70914936520"}
0005434620410	310CD0	9463 342369	NIKOLAY ILIN	{"email": "nilin-21121969@postgrespro.ru", "phone": "+70658834588"}
0005434620411	232F75	6916 017756	EKATERINA LEBEDEVA	{"email": "lebedeva_e091974@postgrespro.ru", "phone": "+70006214065"}
0005434620412	A408E0	5387 081339	SERGEY BORISOV	{"email": "borisov.sergey.091980@postgrespro.ru", "phone": "+70134828702"}
0005434620413	A408E0	9758 181625	DENIS KUZNECOV	{"email": "d-kuznecov.1970@postgrespro.ru", "phone": "+70269439846"}
0005434620414	3A20E8	5483 579779	IRINA DMITRIEVA	{"phone": "+70752124832"}
0005434620415	92F38D	6371 776761	ALEKSANDR SMIRNOV	{"phone": "+70130199861"}
0005434620416	2AE6A0	8152 479198	LYUDMILA KARPOVA	{"email": "l-karpova-1971@postgrespro.ru", "phone": "+70434797349"}
0005434620417	9CA9BB	6582 737566	DMITRIY SMIRNOV	{"phone": "+70055825420"}
0005434620418	54C834	5410 758490	TATYANA IVANOVA	{"email": "t.ivanova_031972@postgrespro.ru", "phone": "+70531668591"}
0005434620419	8EC374	3282 854330	VIKTOR NIKOLAEV	{"email": "v-nikolaev_25021971@postgrespro.ru", "phone": "+70195801363"}
0005434620420	8EC374	4011 341502	NIKITA ZAKHAROV	{"email": "n_zakharov081966@postgrespro.ru", "phone": "+70252243009"}
0005434620421	6CF663	3634 890694	VYACHESLAV KOZLOV	{"email": "vyacheslav-kozlov-07061964@postgrespro.ru", "phone": "+70564976874"}
0005434620422	2BF293	4637 765905	RAIS VOROBEV	{"phone": "+70362736861"}
0005434620423	2BF293	8668 035156	IGOR NIKITIN	{"email": "nikitin-igor-16101964@postgrespro.ru", "phone": "+70211089794"}
0005434620424	A69AD8	1042 427851	POLINA MALYSHEVA	{"email": "malysheva_p-21061974@postgrespro.ru", "phone": "+70895124459"}
0005434620425	A69AD8	9583 034269	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr-31071963@postgrespro.ru", "phone": "+70161769380"}
0005434620426	26EDC2	1946 565057	SVETLANA NIKITINA	{"phone": "+70466106072"}
0005434620427	C50823	1176 082730	ARTEM KUZNECOV	{"email": "a_kuznecov-1960@postgrespro.ru", "phone": "+70900871972"}
0005434620428	E713E7	1057 952833	EGOR POPOV	{"email": "egor_popov021975@postgrespro.ru", "phone": "+70387332553"}
0005434620429	C5AC26	2945 948404	ALEKSANDR KISELEV	{"phone": "+70900601491"}
0005434620430	796F9F	2832 509569	SVETLANA RYABOVA	{"email": "svetlanaryabova_23111967@postgrespro.ru", "phone": "+70580964634"}
0005434620431	788BDC	7953 105286	IGOR SOKOLOV	{"email": "igor_sokolov_05061971@postgrespro.ru", "phone": "+70283191276"}
0005434620432	788BDC	8513 571760	IRINA SERGEEVA	{"phone": "+70679005942"}
0005434620433	DF5B3A	4233 223008	PAVEL VLASOV	{"email": "pvlasov101988@postgrespro.ru", "phone": "+70907713425"}
0005434620434	B92143	1864 087356	NATALYA NIKOLAEVA	{"email": "nikolaeva-n.24011980@postgrespro.ru", "phone": "+70923517504"}
0005434620435	103BFD	8410 975382	ELENA MATVEEVA	{"email": "matveeva.e_30111968@postgrespro.ru", "phone": "+70494662318"}
0005434620436	103BFD	7137 893791	GALIYA VASILEVA	{"phone": "+70130674572"}
0005434620437	3C1BBC	2823 184455	PETR TARASOV	{"phone": "+70874196165"}
0005434620438	DFBE1D	2745 789719	VLADIMIR OSIPOV	{"email": "osipovv-011971@postgrespro.ru", "phone": "+70667044153"}
0005434620439	AD83B0	2055 070314	YURIY KUZNECOV	{"email": "kuznecov.y31081961@postgrespro.ru", "phone": "+70082779285"}
0005434620440	9EA7EE	1122 830179	IRINA TIKHONOVA	{"email": "i_tikhonova23051965@postgrespro.ru", "phone": "+70553130715"}
0005434620441	9EA7EE	1766 316207	VALENTINA PETROVA	{"email": "valentinapetrova10081976@postgrespro.ru", "phone": "+70118512929"}
0005434620442	54CABC	1742 914396	POLINA PAVLOVA	{"phone": "+70806985508"}
0005434620443	182E9D	7426 094499	ANTONINA ABRAMOVA	{"phone": "+70931178064"}
0005434620444	F7531B	4259 518375	SERGEY SIDOROV	{"email": "s_sidorov1973@postgrespro.ru", "phone": "+70654243910"}
0005434620445	31152C	7254 196540	ALINA MATVEEVA	{"phone": "+70874084827"}
0005434620446	46E93A	4309 354970	VLADIMIR AFANASEV	{"phone": "+70624431863"}
0005434620447	46E93A	6189 572108	LEV BORISOV	{"phone": "+70176887610"}
0005434620448	DA3B8E	4719 144187	NIKOLAY GAVRILOV	{"email": "n.gavrilov.101971@postgrespro.ru", "phone": "+70524704739"}
0005434620449	F2063D	7068 559517	EDUARD BARANOV	{"email": "e.baranov29011981@postgrespro.ru", "phone": "+70987620347"}
0005434620450	87D603	0639 105635	GRIGORIY POPOV	{"phone": "+70195528280"}
0005434620451	637081	5668 357152	ARINA LUKYANOVA	{"phone": "+70541081407"}
0005434620452	498120	3475 464425	MAKSIM POPOV	{"phone": "+70748188297"}
0005434620453	382E2E	9328 816269	EGOR DAVYDOV	{"phone": "+70753139384"}
0005434620454	2446ED	5592 407581	ALEKSEY NAZAROV	{"phone": "+70842438153"}
0005434620455	2446ED	2427 197183	NIKOLAY YAKOVLEV	{"email": "n_yakovlev_1976@postgrespro.ru", "phone": "+70844287946"}
0005434620456	84062C	4582 153119	EKATERINA EFIMOVA	{"email": "ekaterina-efimova-07011973@postgrespro.ru", "phone": "+70458936976"}
0005434620457	84062C	3220 130462	YULIYA MAKAROVA	{"email": "makarova-yuliya_1969@postgrespro.ru", "phone": "+70882330569"}
0005434620458	BE2ABE	3787 118097	VLADIMIR CHERNOV	{"phone": "+70652341629"}
0005434620459	7A45B4	7050 246330	NATALYA ANTONOVA	{"phone": "+70782467681"}
0005434620460	81599B	0726 321399	ALEKSANDR ABRAMOV	{"phone": "+70291355186"}
0005434620461	17549C	0840 386826	ALEKSANDR VASILEV	{"email": "vasilev.a-02101982@postgrespro.ru", "phone": "+70006319169"}
0005434620463	24178F	5916 698531	MAKSIM ZAYCEV	{"email": "zaycev.m.041983@postgrespro.ru", "phone": "+70177436165"}
0005434620464	E26435	4846 034070	ELENA PAVLOVA	{"phone": "+70611483397"}
0005434620465	E26435	1878 832785	VALERIY IVANOV	{"phone": "+70206614357"}
0005434620466	B0822C	9184 266526	IVAN ZAKHAROV	{"email": "zakharov.i051965@postgrespro.ru", "phone": "+70265068657"}
0005434620467	FD83CB	8657 805034	MAKSIM SMIRNOV	{"email": "smirnov_m-14041969@postgrespro.ru", "phone": "+70970097577"}
0005434620468	E16343	1582 399553	GEORGIY PETROV	{"email": "petrov_g26081977@postgrespro.ru", "phone": "+70449940147"}
0005434620469	DB6115	2000 826156	LYUDMILA MARTYNOVA	{"phone": "+70965420343"}
0005434620470	DB6115	9032 614340	LYAYSAN MEDVEDEVA	{"phone": "+70682598617"}
0005434620471	0FFE3D	4327 846233	TATYANA FILIPPOVA	{"phone": "+70112276782"}
0005434620472	B708E2	0929 102982	ALINA ZHUKOVA	{"email": "zhukovaa031991@postgrespro.ru", "phone": "+70753350981"}
0005434620473	EF2211	4278 067744	ANTON MELNIKOV	{"email": "melnikov_a.031979@postgrespro.ru", "phone": "+70614887791"}
0005434620474	0C8F40	1733 190311	IGOR VASILEV	{"email": "igor-vasilev-101966@postgrespro.ru", "phone": "+70090658168"}
0005434620475	0C8F40	7683 044028	TATYANA MEDVEDEVA	{"email": "medvedeva-t_1981@postgrespro.ru", "phone": "+70615480188"}
0005434620476	FAC892	2977 172589	NINA ZHURAVLEVA	{"email": "n.zhuravleva061982@postgrespro.ru", "phone": "+70995685188"}
0005434620477	1FC645	7577 369292	ALFIYA MOISEEVA	{"email": "alfiya_moiseeva061981@postgrespro.ru", "phone": "+70606642715"}
0005434620478	1FC645	1699 021070	DINARA SOKOLOVA	{"phone": "+70720261880"}
0005434620479	3B481C	3279 871203	VERA MEDVEDEVA	{"email": "medvedeva.vera-1983@postgrespro.ru", "phone": "+70666259692"}
0005434620480	3B481C	1236 027282	DMITRIY DMITRIEV	{"phone": "+70002240497"}
0005434620481	823274	6801 260246	GALINA ABRAMOVA	{"phone": "+70639758875"}
0005434620482	EBA44C	4228 104906	KSENIYA FADEEVA	{"phone": "+70991828619"}
0005434620483	DCCC9E	1074 915856	VALENTINA EFIMOVA	{"email": "v-efimova06021963@postgrespro.ru", "phone": "+70528556882"}
0005434620484	DCCC9E	0631 128132	GENNADIY PETROV	{"email": "gpetrov_011972@postgrespro.ru", "phone": "+70045104276"}
0005434620485	BB9941	6567 470880	VLADIMIR ANDREEV	{"phone": "+70478786368"}
0005434620486	4F3021	0864 730474	SERGEY NIKOLAEV	{"phone": "+70177406401"}
0005434620487	088B9E	1996 337158	ALEKSANDR GUSEV	{"email": "gusev-aleksandr1961@postgrespro.ru", "phone": "+70455842892"}
0005434620488	477FDF	5417 751881	KIRILL MOROZOV	{"email": "morozovkirill_10021966@postgrespro.ru", "phone": "+70990125639"}
0005434620489	3B6342	2595 318295	ANDREY SMIRNOV	{"email": "smirnova071956@postgrespro.ru", "phone": "+70110489619"}
0005434620490	5BA91D	6560 966277	NIKOLAY STEPANOV	{"phone": "+70426508103"}
0005434620491	5BA91D	1889 888835	VALENTINA DAVYDOVA	{"phone": "+70044483866"}
0005434620492	598DB2	5766 746259	MATVEY PAVLOV	{"phone": "+70239593112"}
0005434620493	C40FAE	8873 311668	ELENA YUDINA	{"email": "elenayudina-041974@postgrespro.ru", "phone": "+70062840471"}
0005434620494	C40FAE	7058 633425	YURIY GRIGOREV	{"email": "yuriy_grigorev-06061979@postgrespro.ru", "phone": "+70977958210"}
0005434620495	B3D814	4945 942652	MARIYA MOISEEVA	{"email": "moiseeva.m31011975@postgrespro.ru", "phone": "+70056498338"}
0005434620496	9CF773	2049 180535	GLEB SERGEEV	{"email": "sergeev-g_061970@postgrespro.ru", "phone": "+70327498273"}
0005434620497	9CF773	7053 686613	ELENA ANDREEVA	{"phone": "+70724045488"}
0005434620498	9CF773	7884 599855	TATYANA MARTYNOVA	{"email": "martynova.t101978@postgrespro.ru", "phone": "+70077890109"}
0005434620499	9F4031	0485 664519	LARISA FOMINA	{"phone": "+70589244724"}
0005434620500	360878	5220 680835	ANNA OVCHINNIKOVA	{"email": "ovchinnikova-a-011978@postgrespro.ru", "phone": "+70668092188"}
0005434620501	4D6E48	0704 479366	TATYANA GORBUNOVA	{"phone": "+70378414968"}
0005434620502	4D6E48	1227 064437	MIKHAIL ANDREEV	{"email": "m-andreev-091975@postgrespro.ru", "phone": "+70822715526"}
0005434620503	61EC1E	7994 793632	TATYANA KUZNECOVA	{"phone": "+70513545984"}
0005434620504	900DD0	7202 240389	VERA SERGEEVA	{"phone": "+70247088950"}
0005434620505	900DD0	8578 826288	MARIYA KOVALEVA	{"phone": "+70227750901"}
0005434620506	5C8058	5108 667691	IVAN KOROLEV	{"email": "ivan.korolev_10101974@postgrespro.ru", "phone": "+70869467993"}
0005434620507	029FAF	5910 510385	PAVEL ZAYCEV	{"email": "zaycev_p_1965@postgrespro.ru", "phone": "+70067377769"}
0005434620508	EBEE4B	2216 438447	VIKTOR GUSEV	{"email": "viktor-gusev_1971@postgrespro.ru", "phone": "+70923844113"}
0005434620509	EAF417	6186 775118	KIRILL ZHUKOV	{"email": "zhukov-k1966@postgrespro.ru", "phone": "+70467271946"}
0005434620510	F82E14	0608 401899	KONSTANTIN FEDOROV	{"phone": "+70343696473"}
0005434620511	EEF2F3	5250 369054	IRINA DAVYDOVA	{"email": "davydova_irina_1964@postgrespro.ru", "phone": "+70642887864"}
0005434620512	8D341D	2280 884084	GALINA BELOVA	{"phone": "+70915012408"}
0005434620513	499584	9841 557163	ELENA FEDOROVA	{"phone": "+70352628769"}
0005434620514	F84373	4021 806611	TATYANA CHERNOVA	{"phone": "+70656289891"}
0005434620515	F84373	2798 185833	ALEFTINA GUSEVA	{"phone": "+70532520120"}
0005434620516	DFD667	1124 217242	ALENA SIDOROVA	{"email": "a.sidorova.111977@postgrespro.ru", "phone": "+70271336498"}
0005434620517	BECB11	7736 350372	VALENTIN MAKSIMOV	{"email": "maksimov.valentin20071974@postgrespro.ru", "phone": "+70316005719"}
0005434620518	E9534C	2460 945270	TATYANA POTAPOVA	{"phone": "+70832692308"}
0005434620519	15966C	4365 942086	MIKHAIL MEDVEDEV	{"phone": "+70036793494"}
0005434620520	BF36D3	4944 890873	EKATERINA ALEKSEEVA	{"email": "alekseevae.1964@postgrespro.ru", "phone": "+70016762503"}
0005434620521	BF36D3	8833 551401	NADEZHDA NOVIKOVA	{"email": "novikova.nadezhda021984@postgrespro.ru", "phone": "+70612971007"}
0005434620522	BF36D3	5110 509143	ANATOLIY FEDOROV	{"email": "anatoliyfedorov1966@postgrespro.ru", "phone": "+70388867629"}
0005434620523	A887B9	5447 289559	MARIYA IVANOVA	{"email": "mivanova.19011972@postgrespro.ru", "phone": "+70544827169"}
0005434620524	8FA005	7223 669470	ALEKSANDR ZAKHAROV	{"phone": "+70152726177"}
0005434620525	8FA005	6689 422519	NINA ORLOVA	{"email": "nina-orlova.021969@postgrespro.ru", "phone": "+70174516747"}
0005434620526	7A57DE	4392 441174	DAVID IVANOV	{"email": "d-ivanov.061968@postgrespro.ru", "phone": "+70902097073"}
0005434620527	7A57DE	1003 282206	ANNA MIKHAYLOVA	{"phone": "+70617097927"}
0005434620528	7A57DE	2246 970296	YURIY ILIN	{"phone": "+70764854289"}
0005434620529	98A421	5932 369951	ALEKSANDRA MAKSIMOVA	{"email": "maksimovaa-1969@postgrespro.ru", "phone": "+70195344458"}
0005434620530	945005	3350 737358	TATYANA ZAKHAROVA	{"email": "zakharova_t-051970@postgrespro.ru", "phone": "+70416876953"}
0005434620531	0EEEC5	5110 281481	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-a-021986@postgrespro.ru", "phone": "+70425209251"}
0005434620532	A62378	5617 372482	ANNA VASILEVA	{"phone": "+70039295377"}
0005434620533	0A0550	8438 023751	DENIS POPOV	{"email": "denis.popov_05121978@postgrespro.ru", "phone": "+70881497920"}
0005434620534	19E83F	4560 505758	DANIIL KUZNECOV	{"phone": "+70632972308"}
0005434620535	19E83F	5061 838180	RUSTAM ALEKSANDROV	{"email": "aleksandrov_rustam_1976@postgrespro.ru", "phone": "+70906813882"}
0005434620536	1EBA77	1350 056779	ANNA MIKHAYLOVA	{"email": "mikhaylova.a041971@postgrespro.ru", "phone": "+70341315541"}
0005434620537	1EBA77	6528 845472	MARIYA IVANOVA	{"phone": "+70334761426"}
0005434620538	45FF9D	1648 059122	IRINA BELOVA	{"phone": "+70773439273"}
0005434620539	EBBB38	1482 770708	ALEKSANDR BELOV	{"email": "belov.a-031976@postgrespro.ru", "phone": "+70230193079"}
0005434620540	587BF1	0567 041234	STANISLAV EGOROV	{"email": "egorovs_23011960@postgrespro.ru", "phone": "+70006868592"}
0005434620541	A03A01	5239 890967	MARIYA TARASOVA	{"phone": "+70748135944"}
0005434620542	FFAD44	7810 131253	LYUDMILA ZAKHAROVA	{"phone": "+70439912813"}
0005434620543	90C934	9995 849183	DMITRIY MATVEEV	{"phone": "+70132174830"}
0005434620544	90C934	7964 401667	ELMIRA PETROVA	{"email": "petrova.e.1972@postgrespro.ru", "phone": "+70815641362"}
0005434620545	927C9F	8453 512202	ALEKSANDRA DANILOVA	{"phone": "+70330415219"}
0005434620546	ED1884	6117 459487	NINA CHERNOVA	{"phone": "+70554608510"}
0005434620547	9AC9B6	1531 370479	SERGEY GORBUNOV	{"email": "gorbunovsergey-031968@postgrespro.ru", "phone": "+70300054393"}
0005434620548	93D46B	9642 315734	IRINA POPOVA	{"email": "irina-popova071963@postgrespro.ru", "phone": "+70927061413"}
0005434620549	7E88B8	1452 023988	ANDREY SHEVCHENKO	{"email": "ashevchenko_09111963@postgrespro.ru", "phone": "+70878876049"}
0005434620550	7E88B8	6603 603905	KIRILL KUZNECOV	{"phone": "+70630622523"}
0005434620551	842E5F	6103 162209	NADEZHDA VLASOVA	{"phone": "+70573499348"}
0005434620552	842E5F	8826 902660	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr29071977@postgrespro.ru", "phone": "+70072262560"}
0005434620553	842E5F	1743 110022	NIKITA ANDREEV	{"email": "nikita-andreev.1968@postgrespro.ru", "phone": "+70824538444"}
0005434620554	B3DFFC	2565 602282	TAMARA KOROLEVA	{"email": "tamara-koroleva.1976@postgrespro.ru", "phone": "+70591659243"}
0005434620555	6B2813	0299 169256	VLADIMIR POPOV	{"phone": "+70139379959"}
0005434620556	6B2813	8717 548813	GENNADIY MIKHAYLOV	{"email": "mikhaylov-g-06011976@postgrespro.ru", "phone": "+70195866049"}
0005434620557	48D684	6060 696611	SERGEY VASILEV	{"email": "vasilev-sergey.21101985@postgrespro.ru", "phone": "+70775032814"}
0005434620558	52B0B0	6688 462836	VLADIMIR BONDARENKO	{"phone": "+70286335735"}
0005434620559	69BE4D	7213 549413	ANTON POPOV	{"phone": "+70865044995"}
0005434620560	8040CB	7492 279093	VLADISLAV FEDOTOV	{"email": "v.fedotov091976@postgrespro.ru", "phone": "+70467140457"}
0005434620561	8040CB	9143 122364	MIKHAIL SMIRNOV	{"email": "smirnov.m081972@postgrespro.ru", "phone": "+70519087245"}
0005434620562	C5E3D0	4744 719766	ELENA LAZAREVA	{"phone": "+70996395448"}
0005434620563	F94C84	5077 474200	TATYANA IVANOVA	{"email": "t.ivanova061979@postgrespro.ru", "phone": "+70566672282"}
0005434620564	E86691	9212 947822	VERONIKA KALININA	{"phone": "+70753636804"}
0005434620565	1BD514	4901 579130	NADEZHDA SAVELEVA	{"phone": "+70442154594"}
0005434620566	B1CC96	1659 872638	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov-031965@postgrespro.ru", "phone": "+70466166728"}
0005434620567	56927F	4382 723585	LYUBOV TITOVA	{"phone": "+70649150671"}
0005434620568	56927F	8954 648524	PAVEL NIKOLAEV	{"phone": "+70767564349"}
0005434620569	05BD38	8178 000558	IRINA IVANOVA	{"phone": "+70599706401"}
0005434620570	8B3DE4	7030 808523	ROZALIYA KOZLOVA	{"email": "rkozlova-121970@postgrespro.ru", "phone": "+70376507078"}
0005434620571	099948	1284 732637	ILYA MARTYNOV	{"phone": "+70377065637"}
0005434620572	9951B0	7652 998081	ELENA ABRAMOVA	{"email": "elena.abramova_1984@postgrespro.ru", "phone": "+70646605344"}
0005434620573	58D741	2723 276196	ARTEM POPOV	{"email": "popov-artem081978@postgrespro.ru", "phone": "+70645382779"}
0005434620574	58D741	1192 809694	ROMAN BELOV	{"phone": "+70048249716"}
0005434620575	0F30CB	9197 141150	OLESYA NOVIKOVA	{"phone": "+70368062062"}
0005434620576	0F30CB	8048 094537	LIDIYA VOROBEVA	{"email": "vorobeval_23061977@postgrespro.ru", "phone": "+70717536384"}
0005434620577	07596C	8134 643501	ANATOLIY MOROZOV	{"email": "a-morozov1974@postgrespro.ru", "phone": "+70025982674"}
0005434620578	07596C	3233 668982	TATYANA CHERNOVA	{"phone": "+70866715964"}
0005434620579	41F345	7108 086793	NIKOLAY EGOROV	{"phone": "+70422434948"}
0005434620580	5FFB96	3179 322949	LARISA SMIRNOVA	{"phone": "+70218467805"}
0005434620581	D39967	8485 660444	ROMAN MATVEEV	{"email": "matveev.roman_01101981@postgrespro.ru", "phone": "+70330459149"}
0005434620582	D39967	8114 363480	LARISA BORISOVA	{"email": "borisoval.03111978@postgrespro.ru", "phone": "+70116412959"}
0005434620583	3BF8D1	8146 145302	TATYANA ANDREEVA	{"email": "andreevatatyana021973@postgrespro.ru", "phone": "+70293336918"}
0005434620584	A95C49	6343 073449	ARTEM IVANOV	{"email": "artem_ivanov.1983@postgrespro.ru", "phone": "+70263559694"}
0005434620585	D6E2A7	7774 694051	LIDIYA MAKSIMOVA	{"phone": "+70876162638"}
0005434620586	579880	2374 031456	IGOR MELNIKOV	{"phone": "+70461035910"}
0005434620587	789042	0064 718226	SERGEY MIRONOV	{"email": "mironov.s-1988@postgrespro.ru", "phone": "+70423674793"}
0005434620588	789042	4378 136907	DENIS KISELEV	{"email": "denis_kiselev021970@postgrespro.ru", "phone": "+70610252243"}
0005434620589	3827DD	6101 304938	VIKTOR VOROBEV	{"email": "vorobev-viktor041975@postgrespro.ru", "phone": "+70299212943"}
0005434620590	3827DD	9830 648413	NIKOLAY KUZNECOV	{"email": "kuznecov.n-1965@postgrespro.ru", "phone": "+70212641253"}
0005434620591	1D7941	0159 211272	TATYANA NESTEROVA	{"phone": "+70651321253"}
0005434620592	450FC6	9191 005182	EKATERINA SERGEEVA	{"phone": "+70026986285"}
0005434620593	3DF136	7234 695112	OLEG VLASOV	{"phone": "+70619737716"}
0005434620594	318FED	0903 623714	OLGA KUZNECOVA	{"phone": "+70604844636"}
0005434620595	A48379	3023 276290	VIKTOR NIKITIN	{"email": "vnikitin.07091975@postgrespro.ru", "phone": "+70355368214"}
0005434620596	5C5231	8828 876415	VLADIMIR MAKAROV	{"email": "v.makarov_04051969@postgrespro.ru", "phone": "+70445541965"}
0005434620597	5C5231	4333 129598	ALEKSANDRA PETROVA	{"email": "aleksandrapetrova_121981@postgrespro.ru", "phone": "+70826242073"}
0005434620598	5C5231	6455 548957	MAKSIM SEMENOV	{"phone": "+70162442179"}
0005434620599	0F5C34	2884 874723	ANATOLIY BELOV	{"email": "belov-anatoliy_13061982@postgrespro.ru", "phone": "+70252949877"}
0005434620600	0F5C34	3922 782522	MIKHAIL TIMOFEEV	{"phone": "+70010434940"}
0005434620601	0F5C34	7954 158233	ALEKSEY NOVIKOV	{"phone": "+70177384392"}
0005434620602	EF12EE	0586 863870	LYUDMILA MEDVEDEVA	{"phone": "+70169631334"}
0005434620603	EF12EE	9024 114219	RASHID MAKAROV	{"email": "makarov.r.041977@postgrespro.ru", "phone": "+70720380722"}
0005434620604	EF12EE	4035 891858	LYUBOV PAVLOVA	{"email": "l-pavlova.24061975@postgrespro.ru", "phone": "+70607797265"}
0005434620605	B8A552	0540 164809	TAISIYA KUZNECOVA	{"phone": "+70349906868"}
0005434620606	B8A552	8359 680175	RUFIYA MIRONOVA	{"phone": "+70822083500"}
0005434620607	B8A552	9773 940639	ANDREY NAZAROV	{"phone": "+70653594596"}
0005434620608	B8A552	7558 768276	KIRILL MIKHAYLOV	{"phone": "+70661891942"}
0005434620609	D00C82	8909 769388	VLADIMIR KISELEV	{"phone": "+70955953423"}
0005434620610	916519	5976 324553	KLAVDIYA KULIKOVA	{"email": "kulikova_k1967@postgrespro.ru", "phone": "+70077147845"}
0005434620611	493B5D	9465 440520	ANDREY FOMIN	{"phone": "+70223073379"}
0005434620612	493B5D	7313 644493	VALENTINA MATVEEVA	{"email": "v.matveeva031974@postgrespro.ru", "phone": "+70505196087"}
0005434620613	676752	3021 474343	SERGEY TARASOV	{"email": "tarasov.sergey031962@postgrespro.ru", "phone": "+70636387720"}
0005434620614	21DFA4	2503 513666	NATALYA FROLOVA	{"phone": "+70783058779"}
0005434620615	21DFA4	8201 229483	SVETLANA EFREMOVA	{"phone": "+70846818248"}
0005434620616	76E30C	4569 638541	NIKOLAY MARTYNOV	{"phone": "+70491698513"}
0005434620617	76E30C	4105 993752	ANTON POPOV	{"email": "anton-popov_091970@postgrespro.ru", "phone": "+70044159513"}
0005434620618	7FD0C8	0414 173121	ANASTASIYA TARASOVA	{"email": "tarasova-a_22121971@postgrespro.ru", "phone": "+70388565492"}
0005434620619	070368	5357 727746	LYUBOV POLYAKOVA	{"email": "polyakova.lyubov-1969@postgrespro.ru", "phone": "+70314069782"}
0005434620620	485DC1	2482 054476	VIKTOR DMITRIEV	{"phone": "+70019038555"}
0005434620621	A8F2C4	5906 469923	MIKHAIL FROLOV	{"email": "mikhail_frolov-29071968@postgrespro.ru", "phone": "+70040787238"}
0005434620622	5D4C8D	5046 026751	LIDIYA TARASOVA	{"phone": "+70527701137"}
0005434620623	5D4C8D	2112 015636	POLINA AKIMOVA	{"phone": "+70279101406"}
0005434620624	859703	3223 733114	NADEZHDA BELOVA	{"email": "belova-nadezhda061969@postgrespro.ru", "phone": "+70881487033"}
0005434620625	9D62F9	7278 555755	EKATERINA ROMANOVA	{"email": "romanovaekaterina121972@postgrespro.ru", "phone": "+70364004784"}
0005434620626	9D62F9	4678 765853	DENIS KULIKOV	{"phone": "+70441433161"}
0005434620627	BD0DE0	8553 090291	ANTON KAZAKOV	{"email": "kazakov.a_21071975@postgrespro.ru", "phone": "+70402302787"}
0005434620628	DFEB16	9351 353401	ELENA BOGDANOVA	{"phone": "+70473416132"}
0005434620629	DFEB16	6031 762664	PAVEL DAVYDOV	{"phone": "+70906811814"}
0005434620630	DFEB16	0755 903502	OLEG PAVLOV	{"email": "pavlovoleg_1970@postgrespro.ru", "phone": "+70223162707"}
0005434620631	DFEB16	7811 899533	ELENA ANTONOVA	{"phone": "+70524338924"}
0005434620632	AAD81D	0389 941749	LARISA BORISOVA	{"phone": "+70128234785"}
0005434620633	624F9D	6503 746666	YURIY ISAEV	{"phone": "+70413485459"}
0005434620634	624F9D	7316 624793	ELENA ORLOVA	{"phone": "+70844510067"}
0005434620635	03CC60	1444 589380	VLADISLAV KULIKOV	{"email": "kulikov-vladislav-1967@postgrespro.ru", "phone": "+70552991640"}
0005434620636	03CC60	7363 500977	GEORGIY KULIKOV	{"phone": "+70156860670"}
0005434620637	12F0D4	0565 265132	VALENTINA IVANOVA	{"email": "ivanova-v061971@postgrespro.ru", "phone": "+70418387634"}
0005434620638	F8908F	5704 672293	EKATERINA KARPOVA	{"phone": "+70615312537"}
0005434620639	F8908F	1649 466159	MARIYA SAVELEVA	{"phone": "+70159739076"}
0005434620640	F94FE2	0746 534867	ELENA ZAKHAROVA	{"phone": "+70097025374"}
0005434620641	F94FE2	3239 789044	ANATOLIY EGOROV	{"phone": "+70210004794"}
0005434620642	1C5DD1	8991 271268	VLADIMIR KUZNECOV	{"email": "kuznecovv.121960@postgrespro.ru", "phone": "+70109083259"}
0005434620643	3D0129	5318 723618	LIDIYA ZHURAVLEVA	{"email": "l_zhuravleva1967@postgrespro.ru", "phone": "+70736956047"}
0005434620644	3D0129	9346 884489	ANNA ERMAKOVA	{"phone": "+70986217991"}
0005434620645	AC13D8	5919 957673	ALEKSEY PETROV	{"email": "petrov-aleksey.10041968@postgrespro.ru", "phone": "+70499373700"}
0005434620646	E4777D	6025 145779	OLESYA ABRAMOVA	{"phone": "+70088687975"}
0005434620647	6A4BA0	2951 633273	LYUDMILA TITOVA	{"phone": "+70898727082"}
0005434620648	6A4BA0	7741 698952	VLADIMIR BARANOV	{"email": "baranov_v_22061980@postgrespro.ru", "phone": "+70756057666"}
0005434620649	731308	7783 918902	DANILA KISELEV	{"phone": "+70900930777"}
0005434620650	FC64C9	5042 783088	VALENTINA MOROZOVA	{"email": "morozova-v-24121974@postgrespro.ru", "phone": "+70178389835"}
0005434620651	FC64C9	5506 183629	TATYANA DMITRIEVA	{"email": "t_dmitrieva091980@postgrespro.ru", "phone": "+70967386777"}
0005434620652	D5E962	8537 091310	VLADISLAV MARTYNOV	{"phone": "+70583520235"}
0005434620653	D5E962	9821 666214	VASILIY AFANASEV	{"email": "afanasevv1985@postgrespro.ru", "phone": "+70286065194"}
0005434620654	391489	5374 236053	VIKTOR GUSEV	{"email": "gusevviktor15121960@postgrespro.ru", "phone": "+70392894934"}
0005434620655	4E3704	7457 412336	OLGA LUKYANOVA	{"email": "lukyanovao.101978@postgrespro.ru", "phone": "+70431187556"}
0005434620656	4E3704	3882 308247	DANIYA ANISIMOVA	{"email": "anisimova-d-061974@postgrespro.ru", "phone": "+70774129972"}
0005434620657	521636	5741 024390	MARIYA FILIPPOVA	{"phone": "+70270258255"}
0005434620658	521636	5579 645401	NATALYA IVANOVA	{"phone": "+70150177139"}
0005434620659	B70B37	5849 571232	NAILYA FROLOVA	{"email": "n_frolova_1973@postgrespro.ru", "phone": "+70098974935"}
0005434620660	050161	6370 313727	GENNADIY MAKSIMOV	{"phone": "+70015748188"}
0005434620661	050161	5260 858585	ELIZAVETA POTAPOVA	{"email": "potapova_e-29061975@postgrespro.ru", "phone": "+70408255188"}
0005434620662	9B7490	9470 619565	ANNA NIKITINA	{"email": "anikitina-16071967@postgrespro.ru", "phone": "+70041619862"}
0005434620663	9B7490	4829 051140	IRINA SERGEEVA	{"phone": "+70520866522"}
0005434620664	3F7ECF	8237 918449	EGOR VLASOV	{"email": "vlasov_egor_1974@postgrespro.ru", "phone": "+70434557580"}
0005434620665	C87F08	0557 581329	NINA MELNIKOVA	{"phone": "+70167747956"}
0005434620666	E6788E	4591 387587	ILYA KOROLEV	{"email": "korolev_ilya.1983@postgrespro.ru", "phone": "+70485496118"}
0005434620667	073A43	0585 490000	ARTEM MIRONOV	{"email": "a.mironov-1963@postgrespro.ru", "phone": "+70277570890"}
0005434620668	073A43	1402 960595	TATYANA SOROKINA	{"email": "tsorokina-05111973@postgrespro.ru", "phone": "+70504773258"}
0005434620669	A585DE	0396 325560	EGOR GORBUNOV	{"email": "gorbunov_egor061975@postgrespro.ru", "phone": "+70263930687"}
0005434620670	2F116D	1884 757824	LILIYA KUZMINA	{"email": "l_kuzmina.1972@postgrespro.ru", "phone": "+70616218585"}
0005434620671	D37036	6709 871105	FARID GUSEV	{"phone": "+70832802453"}
0005434620672	98958A	1201 216490	STANISLAV OSIPOV	{"phone": "+70188697174"}
0005434620673	4AACCB	8105 668585	ILYA KARPOV	{"phone": "+70163336035"}
0005434620674	0D5290	9199 348553	DARYA YUDINA	{"email": "yudina.darya-071971@postgrespro.ru", "phone": "+70749187559"}
0005434620675	0D5290	4288 737528	NADEZHDA TIKHONOVA	{"email": "nadezhda_tikhonova.041961@postgrespro.ru", "phone": "+70140377550"}
0005434620676	A4A24A	4489 753427	YURIY ZAYCEV	{"email": "zaycev-yuriy_081972@postgrespro.ru", "phone": "+70832203169"}
0005434620677	A4A24A	3866 683500	SERGEY TIKHONOV	{"phone": "+70250265399"}
0005434620678	BA6B4A	7799 014585	ROMAN SOKOLOV	{"email": "sokolov_r-21021979@postgrespro.ru", "phone": "+70221997528"}
0005434620679	CC4D6A	0913 524009	TATYANA BOGDANOVA	{"email": "t-bogdanova.121957@postgrespro.ru", "phone": "+70675103340"}
0005434620680	800AF2	8302 925114	SERGEY FROLOV	{"phone": "+70140745283"}
0005434620681	5082A3	6749 949792	ANATOLIY IVANOV	{"email": "anatoliy.ivanov-25031974@postgrespro.ru", "phone": "+70538717067"}
0005434620682	09D258	2330 108187	ALBERT KOROLEV	{"email": "korolev.albert-121966@postgrespro.ru", "phone": "+70271858139"}
0005434620683	CEDFD3	3761 028220	RISHAT NIKOLAEV	{"email": "nikolaevrishat-1981@postgrespro.ru", "phone": "+70708584446"}
0005434620684	CAD43E	0792 579870	LUIZA MAKAROVA	{"email": "makarova.l.1969@postgrespro.ru", "phone": "+70342947704"}
0005434620685	CAD43E	7504 083231	ALEKSANDR PETROV	{"email": "a.petrov-021985@postgrespro.ru", "phone": "+70706375624"}
0005434620686	385F34	3920 896679	YURIY ORLOV	{"phone": "+70818179060"}
0005434620687	A47374	4998 420390	NATALYA NOVIKOVA	{"phone": "+70468533284"}
0005434620688	2C7A46	8224 497190	KRISTINA MOISEEVA	{"email": "moiseeva-k_041970@postgrespro.ru", "phone": "+70086858062"}
0005434620689	2C7A46	6187 766388	TATYANA BELOVA	{"phone": "+70467615782"}
0005434620690	D0DF4E	7753 637398	VALENTINA MIKHAYLOVA	{"phone": "+70211336954"}
0005434620691	D0DF4E	4106 155360	VLADLEN ZAKHAROV	{"email": "zakharov-vladlen_24091961@postgrespro.ru", "phone": "+70522543655"}
0005434620692	CCF059	3569 423505	VLADIMIR SHEVCHENKO	{"email": "shevchenkovladimir.111975@postgrespro.ru", "phone": "+70284315451"}
0005434620693	CCF059	3791 525257	SERGEY AFANASEV	{"phone": "+70202670802"}
0005434620694	E05703	6549 640085	VALERIY MAKAROV	{"email": "valeriy_makarov.17111957@postgrespro.ru", "phone": "+70499205925"}
0005434620695	E05703	7944 331305	SERGEY ANTONOV	{"email": "sergey_antonov.031974@postgrespro.ru", "phone": "+70801387337"}
0005434620696	E732B0	9983 552483	SVETLANA KOROLEVA	{"phone": "+70257008118"}
0005434620697	E1F102	7180 664495	MARINA NAZAROVA	{"phone": "+70063421525"}
0005434620698	E1F102	4482 701985	ELENA SEMENOVA	{"phone": "+70137886774"}
0005434620699	E1F102	9500 862459	ANNA KULIKOVA	{"email": "kulikova.a1967@postgrespro.ru", "phone": "+70175391527"}
0005434620700	4B5C44	2420 083184	NINA ZOTOVA	{"phone": "+70292640534"}
0005434620701	4B5C44	8223 214207	ALEKSEY GUSEV	{"phone": "+70811792487"}
0005434620702	48B971	6685 805839	LARISA TIMOFEEVA	{"phone": "+70474305212"}
0005434620703	48B971	6464 236040	OLGA MELNIKOVA	{"phone": "+70520730333"}
0005434620704	A43607	2173 109297	ALEKSANDR VASILEV	{"phone": "+70942556583"}
0005434620705	A43607	8329 549681	SERGEY KUZNECOV	{"email": "sergey.kuznecov-121972@postgrespro.ru", "phone": "+70758510405"}
0005434620706	4549E3	3852 169745	ANTONINA KOVALEVA	{"email": "kovaleva_a-101968@postgrespro.ru", "phone": "+70951592386"}
0005434620707	4549E3	9105 333176	VERA ANISIMOVA	{"email": "anisimova-vera_1979@postgrespro.ru", "phone": "+70923966186"}
0005434620708	36C710	6549 938240	NIKOLAY CHERNOV	{"email": "nchernov-24021975@postgrespro.ru", "phone": "+70660477281"}
0005434620709	36C710	3856 684252	LYUBOV RYABOVA	{"phone": "+70622630365"}
0005434620710	48727D	0262 126304	EKATERINA MIRONOVA	{"email": "ekaterina_mironova_25051984@postgrespro.ru", "phone": "+70610406093"}
0005434620711	3C1022	3417 360642	LYUBOV LEBEDEVA	{"email": "lebedeva_l_1975@postgrespro.ru", "phone": "+70136027769"}
0005434620712	2715A7	5267 244532	GLEB CHERNOV	{"email": "chernovg-071976@postgrespro.ru", "phone": "+70216604607"}
0005434620713	766634	5862 921355	ANNA IVANOVA	{"phone": "+70576550748"}
0005434620714	538713	0738 391391	VLADIMIR ORLOV	{"email": "orlov-v_021980@postgrespro.ru", "phone": "+70664848616"}
0005434620715	98D080	0520 498662	ALEKSANDR DMITRIEV	{"phone": "+70914761794"}
0005434620716	B76F6C	2848 882526	YAROSLAV EGOROV	{"phone": "+70807333875"}
0005434620717	234DE9	8455 198842	SHAVKAT ZAYCEV	{"email": "zaycev_shavkat081972@postgrespro.ru", "phone": "+70589809766"}
0005434620718	446BE0	5228 215055	OLGA DAVYDOVA	{"email": "davydova_olga-031973@postgrespro.ru", "phone": "+70509337978"}
0005434620719	11598A	8660 112298	ANASTASIYA FROLOVA	{"email": "frolovaa_081970@postgrespro.ru", "phone": "+70389477357"}
0005434620720	44AC2B	5718 279965	MARIYA KUZMINA	{"email": "kuzmina.mariya-24101973@postgrespro.ru", "phone": "+70854918319"}
0005434620721	895F37	5802 604640	LIDIYA ZAKHAROVA	{"email": "l_zakharova-091963@postgrespro.ru", "phone": "+70422455604"}
0005434620722	2B2E75	4112 891784	VLADIMIR POPOV	{"phone": "+70316072562"}
0005434620723	2B2E75	1311 768296	ALEKSANDR OSIPOV	{"phone": "+70704121549"}
0005434620724	038CB5	2037 082188	MIKHAIL MOROZOV	{"phone": "+70740760363"}
0005434620725	038CB5	6647 951463	LYUDMILA KAZAKOVA	{"phone": "+70894475539"}
0005434620726	9D4905	4571 710632	TIMOFEY CHERNOV	{"email": "chernov_t.23121971@postgrespro.ru", "phone": "+70517672469"}
0005434620727	3EE94C	2876 229702	ALEKSEY ANDREEV	{"email": "andreev_a061976@postgrespro.ru", "phone": "+70817196005"}
0005434620728	D197E3	7512 076778	ANATOLIY SOLOVEV	{"email": "anatoliy_solovev_11091975@postgrespro.ru", "phone": "+70348641712"}
0005434620729	D197E3	6887 302090	ANASTASIYA IVANOVA	{"phone": "+70012220111"}
0005434620730	6B2044	3377 452300	OLGA NIKOLAEVA	{"email": "olganikolaeva1963@postgrespro.ru", "phone": "+70877895235"}
0005434620731	6B5472	8613 615767	VLADIMIR NIKITIN	{"email": "nikitinv-1974@postgrespro.ru", "phone": "+70323803750"}
0005434620732	5BD418	4804 120753	VLADIMIR KUZMIN	{"phone": "+70786811342"}
0005434620733	569077	0190 618165	VLADIMIR FROLOV	{"email": "vladimir_frolov_10051967@postgrespro.ru", "phone": "+70806709975"}
0005434620734	F9B170	6613 094673	GALINA ZAKHAROVA	{"email": "zakharovag_101976@postgrespro.ru", "phone": "+70120942068"}
0005434620735	F9B170	9186 145248	GALINA RODIONOVA	{"email": "rodionova-galina_1967@postgrespro.ru", "phone": "+70124465205"}
0005434620736	7D6971	5779 082983	VLADIMIR CHERNOV	{"email": "chernov-vladimir13121973@postgrespro.ru", "phone": "+70428917254"}
0005434620737	7D6971	8631 944172	MAKSIM ANTONOV	{"phone": "+70024863452"}
0005434620738	7D6971	3945 249936	TATYANA DENISOVA	{"email": "denisovatatyana.1969@postgrespro.ru", "phone": "+70665131914"}
0005434620739	5B8EB5	7652 235856	ZLATA IVANOVA	{"phone": "+70458846582"}
0005434620740	07653B	5296 767571	ILDAR GERASIMOV	{"phone": "+70369730393"}
0005434620741	E88A9D	8046 111039	ALEKSEY TIKHONOV	{"email": "a-tikhonov08111970@postgrespro.ru", "phone": "+70358769157"}
0005434620742	E88A9D	2802 696700	DENIS POPOV	{"email": "popov.d_1972@postgrespro.ru", "phone": "+70724616474"}
0005434620743	E88A9D	4284 936242	DMITRIY KUZMIN	{"email": "d_kuzmin021975@postgrespro.ru", "phone": "+70636516959"}
0005434620744	701CB7	7550 398748	VLADIMIR SCHERBAKOV	{"phone": "+70400344619"}
0005434620745	11706F	8872 257315	ANATOLIY KUDRYASHOV	{"email": "anatoliykudryashov.111981@postgrespro.ru", "phone": "+70731385732"}
0005434620746	403E6B	1560 159453	VLADIMIR ZAKHAROV	{"email": "vzakharov-101967@postgrespro.ru", "phone": "+70216026422"}
0005434620747	FE19A0	8708 320456	IRAIDA FROLOVA	{"email": "iraidafrolova27091969@postgrespro.ru", "phone": "+70437717528"}
0005434620748	593742	5177 045290	TAMARA POPOVA	{"phone": "+70884883326"}
0005434620749	9DA11C	5629 611371	ALEKSANDRA KARPOVA	{"phone": "+70187394728"}
0005434620750	02FA8E	2624 500812	ANTON MIRONOV	{"phone": "+70577924158"}
0005434620751	D1A168	0144 407748	VITALIY ZAYCEV	{"phone": "+70891224396"}
0005434620752	D1A168	2876 219646	ELENA DENISOVA	{"email": "e_denisova.25011973@postgrespro.ru", "phone": "+70650572092"}
0005434620753	60700E	9472 274125	MARINA ROMANOVA	{"phone": "+70295060535"}
0005434620754	60700E	8542 456890	YURIY ROMANOV	{"phone": "+70021501504"}
0005434620755	2EAE28	8481 466065	SVETLANA ABRAMOVA	{"phone": "+70757559868"}
0005434620756	814DE4	3911 209886	MAGOMED PETROV	{"email": "m.petrov-16031973@postgrespro.ru", "phone": "+70263018120"}
0005434620757	F475C4	5920 432693	ZINAIDA DAVYDOVA	{"phone": "+70345685579"}
0005434620758	F475C4	1959 953358	NATALYA SERGEEVA	{"phone": "+70383026252"}
0005434620759	F475C4	1091 923034	YURIY YAKOVLEV	{"phone": "+70186026357"}
0005434620760	D52F33	9696 686753	DMITRIY OSIPOV	{"email": "osipov-dmitriy.121967@postgrespro.ru", "phone": "+70099500902"}
0005434620761	35E27E	7987 600398	IVAN ROMANOV	{"phone": "+70994969995"}
0005434620762	BF8336	2158 342518	ANTON FEDOROV	{"phone": "+70947828850"}
0005434620763	4DB8D2	3370 412952	VLADISLAV BONDARENKO	{"email": "vladislavbondarenko1966@postgrespro.ru", "phone": "+70785619404"}
0005434620764	0F5B6F	9576 967240	GALINA KOZLOVA	{"phone": "+70353336262"}
0005434620765	58D555	8977 470282	DMITRIY TIKHONOV	{"phone": "+70921824792"}
0005434620766	5049B2	3548 457065	VLADISLAV RODIONOV	{"phone": "+70664143901"}
0005434620767	BC5247	7966 494114	VALERIY ZAKHAROV	{"phone": "+70213227357"}
0005434620768	30A149	2413 765439	OLGA KARPOVA	{"phone": "+70512227803"}
0005434620769	935B10	5517 987180	SVETLANA AKIMOVA	{"email": "akimova.s-21041972@postgrespro.ru", "phone": "+70720529698"}
0005434620770	2E71F4	9624 738905	VALERIY FROLOV	{"phone": "+70690594998"}
0005434620771	4D9FB6	7217 542837	VERA KONDRATEVA	{"phone": "+70446043192"}
0005434620772	6D36C1	9799 284856	ANASTASIYA FILATOVA	{"email": "anastasiya_filatova.1981@postgrespro.ru", "phone": "+70193938061"}
0005434620773	6D36C1	8494 573745	ALBINA KAZAKOVA	{"phone": "+70552157676"}
0005434620774	8B09B7	6593 763543	MARIYA MELNIKOVA	{"email": "m.melnikova1976@postgrespro.ru", "phone": "+70443695649"}
0005434620775	8516D5	8936 987655	TATYANA STEPANOVA	{"email": "tatyana.stepanova071965@postgrespro.ru", "phone": "+70681066377"}
0005434620776	BA79C1	9997 365143	YULIANA FEDOROVA	{"phone": "+70704505366"}
0005434620777	835103	3048 524429	TATYANA PETROVA	{"email": "tatyana.petrova_1970@postgrespro.ru", "phone": "+70418098123"}
0005434620778	C1BC6D	3500 002541	OLGA FOMINA	{"phone": "+70379981638"}
0005434620779	47778C	7093 125154	FANIYA VOLKOVA	{"email": "faniya-volkova-1988@postgrespro.ru", "phone": "+70211854229"}
0005434620780	47778C	6644 772498	ANNA DANILOVA	{"email": "danilovaanna.1969@postgrespro.ru", "phone": "+70432575128"}
0005434620781	2B4641	1513 657235	LYUBOV FEDOROVA	{"phone": "+70229556446"}
0005434620782	FC3651	7515 181732	MARIYA GAVRILOVA	{"phone": "+70928264157"}
0005434620783	8511B5	2258 013219	IRINA TIKHONOVA	{"phone": "+70858164158"}
0005434620784	8511B5	1134 153978	EKATERINA STEPANOVA	{"email": "ekaterina.stepanova_1971@postgrespro.ru", "phone": "+70095771792"}
0005434620785	509FFC	0191 404452	IVAN EGOROV	{"email": "egorov.ivan_1969@postgrespro.ru", "phone": "+70392311666"}
0005434620786	509FFC	0382 192613	PAVEL PETROV	{"phone": "+70213937199"}
0005434620787	201912	5706 234852	ALEKSEY FOMIN	{"email": "fomin.aleksey-1977@postgrespro.ru", "phone": "+70694758610"}
0005434620788	201912	6448 388489	ANATOLIY MAKAROV	{"email": "amakarov15061959@postgrespro.ru", "phone": "+70750129330"}
0005434620789	5E33B0	2815 647687	YURIY PAVLOV	{"phone": "+70071612173"}
0005434620790	5E33B0	9088 673497	VERA GUSEVA	{"phone": "+70056130001"}
0005434620791	2A78AF	5088 208009	IGOR KUZNECOV	{"phone": "+70410113936"}
0005434620792	2A78AF	8232 832077	YULIYA NESTEROVA	{"email": "yuliyanesterova1973@postgrespro.ru", "phone": "+70436717021"}
0005434620793	B69FEA	3186 825721	VLADIMIR POPOV	{"phone": "+70008004573"}
0005434620794	C286F5	5484 223645	NATALYA ILINA	{"email": "n-ilina-011978@postgrespro.ru", "phone": "+70943535264"}
0005434620795	C286F5	7503 833310	ANASTASIYA ALEKSEEVA	{"email": "a_alekseeva09011976@postgrespro.ru", "phone": "+70251478940"}
0005434620796	5545E8	3580 908034	ALEKSANDR KUDRYASHOV	{"email": "kudryashovaleksandr-1975@postgrespro.ru", "phone": "+70359276468"}
0005434620797	526DBD	5555 244831	ARTEM ROMANOV	{"phone": "+70579559067"}
0005434620798	2F437F	4221 856098	VLADIMIR SIDOROV	{"phone": "+70701535985"}
0005434620799	C4917A	9687 519886	EVGENIY EGOROV	{"phone": "+70617222027"}
0005434620800	732CAC	8195 231085	ARTEM FEDOTOV	{"email": "a.fedotov-091979@postgrespro.ru", "phone": "+70070361709"}
0005434620801	732CAC	3452 250638	GULNARA SEMENOVA	{"phone": "+70450109999"}
0005434620802	94E9B3	5850 235668	OLESYA POTAPOVA	{"phone": "+70403928201"}
0005434620803	BBA58F	2885 998260	IVAN ALEKSEEV	{"email": "i-alekseev_08081980@postgrespro.ru", "phone": "+70480481646"}
0005434620804	BBA58F	6030 203380	TATYANA VOROBEVA	{"email": "vorobevatatyana.071966@postgrespro.ru", "phone": "+70050498426"}
0005434620805	BBA58F	3950 987025	OLGA SAVELEVA	{"phone": "+70693311271"}
0005434620806	BC3332	2536 540432	RUSTAM BONDARENKO	{"email": "bondarenkorustam20031981@postgrespro.ru", "phone": "+70116899187"}
0005434620807	3614E4	1694 403535	NADEZHDA SCHERBAKOVA	{"phone": "+70246207586"}
0005434620808	B3DD35	5320 834159	ALEKSANDR BARANOV	{"email": "baranov-a_26101964@postgrespro.ru", "phone": "+70131233396"}
0005434620809	B3DD35	7393 288063	ALEKSANDRA KOZLOVA	{"phone": "+70881434588"}
0005434620810	E1DE98	5923 131017	NIKOLAY SMIRNOV	{"email": "smirnov-n-111976@postgrespro.ru", "phone": "+70044754176"}
0005434620811	B3BEAE	5564 549484	ELENA ORLOVA	{"phone": "+70769667366"}
0005434620812	B3BEAE	4484 613863	TAMARA MEDVEDEVA	{"email": "medvedeva-tamara-24071981@postgrespro.ru", "phone": "+70674807282"}
0005434620813	788E15	9518 382897	VALENTINA MALYSHEVA	{"email": "malysheva_v_1972@postgrespro.ru", "phone": "+70089876642"}
0005434620814	F96FDA	1934 553293	SERGEY ROMANOV	{"phone": "+70403239585"}
0005434620815	4EB304	0965 941735	GALINA KAZAKOVA	{"phone": "+70610859722"}
0005434620816	D70AE3	3509 895266	EGOR ANTONOV	{"email": "egor-antonov_011971@postgrespro.ru", "phone": "+70590368107"}
0005434620817	220FC0	9687 463210	KONSTANTIN FILIPPOV	{"email": "k_filippov06121972@postgrespro.ru", "phone": "+70043147351"}
0005434620818	220FC0	6503 720274	ELENA SERGEEVA	{"phone": "+70236861518"}
0005434620819	90DEEB	9086 502821	SERGEY SEMENOV	{"email": "sergey_semenov1976@postgrespro.ru", "phone": "+70177324601"}
0005434620820	92E98C	2264 516458	ANNA POPOVA	{"email": "a-popova-06091969@postgrespro.ru", "phone": "+70173710119"}
0005434620821	D8D4D9	6988 230417	SVYATOSLAV IVANOV	{"email": "ivanov_s_1984@postgrespro.ru", "phone": "+70321918648"}
0005434620822	D8D4D9	4145 767826	VADIM SOLOVEV	{"email": "solovev.v.071978@postgrespro.ru", "phone": "+70543036399"}
0005434620823	D8D4D9	1540 953382	MARIYA KUZNECOVA	{"phone": "+70259146783"}
0005434620824	4E3693	6633 827421	ARMEN SHEVCHENKO	{"phone": "+70207076413"}
0005434620825	623047	7909 526672	LILIYA KUDRYASHOVA	{"email": "kudryashova.liliya-061971@postgrespro.ru", "phone": "+70957884451"}
0005434620826	CA96FE	9078 818353	NINA DAVYDOVA	{"phone": "+70212991876"}
0005434620827	B03C86	2179 991414	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova_021976@postgrespro.ru", "phone": "+70854245090"}
0005434620828	EA28A9	9230 275628	SOFIYA KULIKOVA	{"email": "sofiya-kulikova-1980@postgrespro.ru", "phone": "+70203589471"}
0005434620829	41CA9C	5055 402138	NADEZHDA EFIMOVA	{"email": "nadezhdaefimova_1971@postgrespro.ru", "phone": "+70182994433"}
0005434620830	4B3C57	5358 351227	VALENTINA NESTEROVA	{"email": "nesterova.valentina.15101963@postgrespro.ru", "phone": "+70429566043"}
0005434620831	EEFA78	6207 011878	YULIYA AFANASEVA	{"phone": "+70505601321"}
0005434620832	EEFA78	6196 740828	GALINA VASILEVA	{"phone": "+70566510644"}
0005434620833	B246FE	0758 244931	NATALYA NOVIKOVA	{"email": "novikova.natalya_07061972@postgrespro.ru", "phone": "+70185358321"}
0005434620834	0612A2	9566 701499	NINA SEMENOVA	{"phone": "+70251938276"}
0005434620835	B5DD5B	2829 975625	NADEZHDA EFREMOVA	{"email": "efremovan.121964@postgrespro.ru", "phone": "+70540169019"}
0005434620836	D64FBB	8778 907437	DARYA KULIKOVA	{"email": "d_kulikova_021973@postgrespro.ru", "phone": "+70104390070"}
0005434620837	200665	8734 967953	IRINA PETROVA	{"phone": "+70149470601"}
0005434620838	200665	7600 560337	VALENTINA TARASOVA	{"email": "tarasova-v-061971@postgrespro.ru", "phone": "+70159726993"}
0005434620839	C5A2C0	7987 551609	VLADIMIR BORISOV	{"phone": "+70606469381"}
0005434620840	C5A2C0	0019 497795	STANISLAV VOROBEV	{"phone": "+70983629646"}
0005434620841	A875EA	3470 028757	ALFIYA FILIPPOVA	{"email": "a.filippova.101977@postgrespro.ru", "phone": "+70510302828"}
0005434620842	5A0F7A	1297 894192	SERGEY VOLKOV	{"email": "sergey-volkov_1980@postgrespro.ru", "phone": "+70346281855"}
0005434620843	5A0F7A	4216 442114	ALEKSEY DMITRIEV	{"phone": "+70092069665"}
0005434620844	4FB6A9	8162 656692	ALEKSEY STEPANOV	{"email": "astepanov1986@postgrespro.ru", "phone": "+70837666442"}
0005434620845	A443F0	7485 793259	YAROSLAV OSIPOV	{"email": "osipov-y051969@postgrespro.ru", "phone": "+70156748897"}
0005434620846	AEB0F0	3297 860116	NINA MELNIKOVA	{"phone": "+70043020290"}
0005434620847	C6BD0E	2619 518756	OLGA LAZAREVA	{"phone": "+70116246863"}
0005434620848	AC2519	6754 828024	NINA VASILEVA	{"phone": "+70967918837"}
0005434620849	AC2519	3600 892779	NADEZHDA FROLOVA	{"phone": "+70675005372"}
0005434620850	BE3788	2861 474115	SERGEY TIKHONOV	{"email": "sergeytikhonov-041963@postgrespro.ru", "phone": "+70206142586"}
0005434620851	2A3C85	7176 790281	DMITRIY GUSEV	{"phone": "+70068726075"}
0005434620852	F810BC	5246 798296	ANZHELIKA ROMANOVA	{"phone": "+70447343918"}
0005434620853	F810BC	4157 257598	VYACHESLAV IVANOV	{"email": "ivanov_v-041972@postgrespro.ru", "phone": "+70121470051"}
0005434620854	05D6C0	2033 847506	KONSTANTIN SCHERBAKOV	{"email": "scherbakov_k09051973@postgrespro.ru", "phone": "+70760868022"}
0005434620855	05D6C0	8941 681570	VLADIMIR IVANOV	{"phone": "+70436659120"}
0005434620856	1C2656	4403 985492	PETR POPOV	{"email": "p_popov-13031984@postgrespro.ru", "phone": "+70025640468"}
0005434620857	53A958	6630 660159	YANA MOROZOVA	{"phone": "+70750431255"}
0005434620858	53A958	8253 336139	ANNA VOLKOVA	{"phone": "+70833162543"}
0005434620859	B2716A	0909 539271	ZINAIDA FOMINA	{"email": "fominaz-041965@postgrespro.ru", "phone": "+70746709312"}
0005434620860	B2716A	3125 272720	VSEVOLOD AFANASEV	{"email": "v_afanasev051965@postgrespro.ru", "phone": "+70796567274"}
0005434620861	3FFE5F	2855 854497	KONSTANTIN NIKOLAEV	{"phone": "+70472301564"}
0005434620862	2377E3	8294 510327	PAVEL SOLOVEV	{"phone": "+70854968351"}
0005434620863	08478C	4428 170504	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n_06081961@postgrespro.ru", "phone": "+70164473545"}
0005434620864	C3ACF7	7249 421046	ULYANA ILINA	{"phone": "+70388841165"}
0005434620865	DC73C0	5586 140101	NELLI KOROLEVA	{"phone": "+70949275865"}
0005434620866	DC73C0	3944 162907	IRINA OSIPOVA	{"email": "iosipova.09061968@postgrespro.ru", "phone": "+70432296126"}
0005434620867	38A0B0	9780 667551	ALEKSANDR ANDREEV	{"email": "aandreev1964@postgrespro.ru", "phone": "+70411654501"}
0005434620868	FBEE80	9709 930264	NAILYA MOROZOVA	{"email": "morozova.nailya071975@postgrespro.ru", "phone": "+70534804697"}
0005434620869	FBEE80	9544 308627	YURIY GORBUNOV	{"email": "yuriy-gorbunov05021981@postgrespro.ru", "phone": "+70114613609"}
0005434620870	612E99	8408 462048	ANNA PETROVA	{"email": "petrova.a-1971@postgrespro.ru", "phone": "+70814872897"}
0005434620871	612E99	5175 144332	VITALIY SCHERBAKOV	{"email": "scherbakov.v-1978@postgrespro.ru", "phone": "+70183458975"}
0005434620872	CFE266	7694 152393	SVETLANA MEDVEDEVA	{"email": "medvedevas031972@postgrespro.ru", "phone": "+70315376390"}
0005434620873	CFE266	1224 075167	TATYANA IVANOVA	{"phone": "+70424837900"}
0005434620874	8A8D61	2621 831942	SERGEY ALEKSEEV	{"email": "alekseevs.01121973@postgrespro.ru", "phone": "+70542594354"}
0005434620875	405C49	3226 340351	MARIYA BELOVA	{"email": "mariyabelova_15021969@postgrespro.ru", "phone": "+70264908760"}
0005434620876	018477	3733 803985	VIKTOR ZHUKOV	{"email": "zhukovviktor.061988@postgrespro.ru", "phone": "+70540680852"}
0005434620877	018477	4029 440058	MARIYA ARKHIPOVA	{"phone": "+70989095573"}
0005434620878	DCFC57	6334 002877	SAID BONDARENKO	{"phone": "+70889986719"}
0005434620879	DCFC57	9882 351566	MARIYA GAVRILOVA	{"phone": "+70941029833"}
0005434620880	CC2EFF	9004 737700	YULIYA IVANOVA	{"phone": "+70333744485"}
0005434620881	FFDECF	6457 012449	ALEKSANDR KUZNECOV	{"phone": "+70634408314"}
0005434620882	E85F62	2206 489170	MAKSIM ILIN	{"phone": "+70088255855"}
0005434620883	8D3134	4914 071907	TATYANA KONOVALOVA	{"phone": "+70178011155"}
0005434620884	8D3134	8336 494852	VIKTOR RODIONOV	{"phone": "+70148508339"}
0005434620885	EF84D1	2686 021146	ALMIRA MAKAROVA	{"phone": "+70859914199"}
0005434620886	EF84D1	9405 347896	ALEKSANDR SCHERBAKOV	{"phone": "+70098650331"}
0005434620887	DCBC6C	8844 911163	MAKSIM TARASOV	{"phone": "+70731890296"}
0005434620888	4D2649	3000 672392	DMITRIY KRASNOV	{"phone": "+70404740275"}
0005434620889	8FEC5E	2933 595439	SERGEY YAKOVLEV	{"email": "s.yakovlev061963@postgrespro.ru", "phone": "+70659781481"}
0005434620890	8FEC5E	5062 018719	OLGA BARANOVA	{"email": "olga.baranova_1975@postgrespro.ru", "phone": "+70500502075"}
0005434620891	8FEC5E	0673 248973	VITALIY BARANOV	{"email": "baranov-v_1968@postgrespro.ru", "phone": "+70958856859"}
0005434620892	8A2090	8208 464812	ALEKSANDR SEMENOV	{"phone": "+70954362817"}
0005434620893	B1190E	6020 499674	NIKOLAY DMITRIEV	{"email": "n_dmitriev101972@postgrespro.ru", "phone": "+70972842183"}
0005434620894	B1190E	0419 838066	GENNADIY BONDARENKO	{"email": "g-bondarenko_1975@postgrespro.ru", "phone": "+70087518281"}
0005434620895	036C56	0534 537825	MIKHAIL SEMENOV	{"phone": "+70934262304"}
0005434620896	036C56	1399 702533	TATYANA IVANOVA	{"email": "tatyana_ivanova_04031971@postgrespro.ru", "phone": "+70088511018"}
0005434620897	036C56	8722 221738	GALINA MOROZOVA	{"phone": "+70681995829"}
0005434620898	0D47D5	9244 386805	SVETLANA ROMANOVA	{"email": "svetlana.romanova.1970@postgrespro.ru", "phone": "+70002635332"}
0005434620899	0C2023	7184 000967	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin1965@postgrespro.ru", "phone": "+70584672128"}
0005434620900	0C2023	8878 251948	NIKOLAY ANTONOV	{"phone": "+70165927515"}
0005434620901	331CAC	8333 279302	SVYATOSLAV MIRONOV	{"email": "svyatoslav.mironov.1972@postgrespro.ru", "phone": "+70566037460"}
0005434620902	331CAC	2090 661278	DARYA NESTEROVA	{"email": "nesterova.d1981@postgrespro.ru", "phone": "+70720064517"}
0005434620903	D51B25	2007 681408	ELENA SOKOLOVA	{"email": "elenasokolova_121975@postgrespro.ru", "phone": "+70844391341"}
0005434620904	B28A2F	5381 365271	ANDREY ZAYCEV	{"email": "zaycev-andrey-081997@postgrespro.ru", "phone": "+70153185365"}
0005434620905	B28A2F	6803 507040	VALENTINA VASILEVA	{"phone": "+70904652350"}
0005434620906	C67F6B	1231 823390	ZHANNA ZAYCEVA	{"email": "z-zayceva.1963@postgrespro.ru", "phone": "+70453753025"}
0005434620907	A97A47	3369 941655	NADEZHDA SOROKINA	{"email": "n-sorokina-1973@postgrespro.ru", "phone": "+70066476326"}
0005434620908	A97A47	6244 155504	SVETLANA RODIONOVA	{"phone": "+70031424369"}
0005434620909	A97A47	6256 229501	ALLA BARANOVA	{"email": "baranova-a.061974@postgrespro.ru", "phone": "+70634870226"}
0005434620910	306910	9462 538376	ANNA ALEKSANDROVA	{"phone": "+70289587002"}
0005434620911	6F49B3	9279 484854	IRINA EGOROVA	{"phone": "+70280071630"}
0005434620912	6F49B3	5816 086220	ALEKSANDR TARASOV	{"phone": "+70208111159"}
0005434620913	CEDCC4	1893 437553	VALENTINA LOGINOVA	{"email": "loginova-v_1963@postgrespro.ru", "phone": "+70388983632"}
0005434620914	CEDCC4	5131 622875	MARIYA MATVEEVA	{"email": "m_matveeva17121982@postgrespro.ru", "phone": "+70810470304"}
0005434620915	A61A7E	0624 402622	NATALYA NOVIKOVA	{"email": "n_novikova.22121977@postgrespro.ru", "phone": "+70360055029"}
0005434620916	A61A7E	7764 283626	LYUDMILA FROLOVA	{"email": "frolovalyudmila.071972@postgrespro.ru", "phone": "+70773662440"}
0005434620917	2963C9	7219 759752	SVETLANA KUZMINA	{"phone": "+70690731677"}
0005434620918	2963C9	7725 211243	ALEKSANDRA NOVIKOVA	{"email": "novikova-aleksandra-061972@postgrespro.ru", "phone": "+70744441948"}
0005434620919	255074	7107 051171	ELENA NIKOLAEVA	{"email": "nikolaeva_elena-01111979@postgrespro.ru", "phone": "+70971218384"}
0005434620920	3E716B	4195 000018	ANDREY IVANOV	{"email": "aivanov031980@postgrespro.ru", "phone": "+70223347475"}
0005434620921	C19FB8	1329 985378	TATYANA KOMAROVA	{"email": "komarova-tatyana-071967@postgrespro.ru", "phone": "+70279202579"}
0005434620922	C19FB8	0570 722978	DENIS SCHERBAKOV	{"phone": "+70176729513"}
0005434620923	434ED7	9852 022529	OLEG MOISEEV	{"email": "moiseev.o-1967@postgrespro.ru", "phone": "+70018037557"}
0005434620924	E7A6DB	7685 990929	LYUDMILA KUZMINA	{"phone": "+70262427073"}
0005434620925	B1DD37	2706 242037	IRINA VLASOVA	{"phone": "+70214709961"}
0005434620926	BC8D21	5132 127691	TIMUR SIDOROV	{"phone": "+70086498756"}
0005434620927	BC8D21	2564 609241	OLGA KOMAROVA	{"email": "o_komarova_081965@postgrespro.ru", "phone": "+70841209061"}
0005434620928	BC8D21	6574 237626	ELENA ALEKSANDROVA	{"phone": "+70620857307"}
0005434620929	75BFA9	8988 392631	ALEKSEY BELOV	{"phone": "+70264519021"}
0005434620930	4D6EB0	7794 891070	ELIZAVETA ZAKHAROVA	{"email": "elizaveta-zakharova081978@postgrespro.ru", "phone": "+70537593741"}
0005434620931	4D6EB0	6479 452774	VIKTOR KULIKOV	{"email": "kulikov.viktor.12121969@postgrespro.ru", "phone": "+70666698109"}
0005434620932	4D6EB0	8425 964170	LYUDMILA FADEEVA	{"phone": "+70180798432"}
0005434620933	9EBC71	8895 465714	ALEKSANDR PAVLOV	{"phone": "+70948117738"}
0005434620934	393AA3	2987 146097	SERGEY ROMANOV	{"phone": "+70339610175"}
0005434620935	390CFE	8846 802568	VLADIMIR PAVLOV	{"phone": "+70959345063"}
0005434620936	7C72D5	7626 295764	ULYANA ORLOVA	{"email": "uorlova.17121967@postgrespro.ru", "phone": "+70999423711"}
0005434620937	0E26B4	7031 573899	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov.19121981@postgrespro.ru", "phone": "+70778656861"}
0005434620938	0E26B4	1416 115935	VIKTOR ISAEV	{"email": "v_isaev.1969@postgrespro.ru", "phone": "+70341179986"}
0005434620939	D9FF75	8783 965633	OLGA KUZNECOVA	{"phone": "+70008693342"}
0005434620940	D9FF75	6877 537701	IVAN TARASOV	{"phone": "+70654851644"}
0005434620941	114C67	6064 274385	LIYA MIKHAYLOVA	{"phone": "+70268690258"}
0005434620942	114C67	3072 707657	ANDREY MEDVEDEV	{"email": "a-medvedev.07031972@postgrespro.ru", "phone": "+70616403623"}
0005434620943	114C67	1925 273487	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-16051973@postgrespro.ru", "phone": "+70248415464"}
0005434620944	912CB0	1426 512180	KLAVDIYA ANTONOVA	{"email": "antonova.k121968@postgrespro.ru", "phone": "+70207407916"}
0005434620945	66CE8B	5668 810471	NIKOLAY VOLKOV	{"email": "volkov.nikolay_26021963@postgrespro.ru", "phone": "+70619176336"}
0005434620946	E870B3	4707 660829	MARIYA FROLOVA	{"phone": "+70517992813"}
0005434620947	FCE7A9	7387 711293	OLEG KUZNECOV	{"phone": "+70041495539"}
0005434620948	319DAA	7860 663504	RAFAEL SHEVCHENKO	{"phone": "+70934498391"}
0005434620949	A8A9CD	5989 389822	ELENA SEMENOVA	{"email": "elenasemenova061959@postgrespro.ru", "phone": "+70914087448"}
0005434620950	A8A9CD	6181 936333	GALINA SOROKINA	{"email": "sorokina_g.09071970@postgrespro.ru", "phone": "+70793697156"}
0005434620951	7150ED	1557 966026	TATYANA ANDREEVA	{"phone": "+70895713381"}
0005434620952	CFE9F4	9193 414592	VALERIYA SEMENOVA	{"phone": "+70949174565"}
0005434620953	163269	8699 185182	VADIM MEDVEDEV	{"phone": "+70211928421"}
0005434620954	163269	9016 619145	ALEKSANDR ILIN	{"phone": "+70468512427"}
0005434620955	32E332	1177 944671	LYUDMILA BARANOVA	{"email": "baranova_l-1975@postgrespro.ru", "phone": "+70025213933"}
0005434620956	9F5DB4	3363 317081	ANTON IVANOV	{"email": "ivanov-a-111977@postgrespro.ru", "phone": "+70616319202"}
0005434620957	382847	0475 801547	EKATERINA NAZAROVA	{"email": "ekaterina.nazarova-27071971@postgrespro.ru", "phone": "+70685095535"}
0005434620958	34A877	2224 147003	DENIS MIKHAYLOV	{"email": "mikhaylov-denis-21051968@postgrespro.ru", "phone": "+70818702001"}
0005434620959	DA2427	4961 907751	OLGA IVANOVA	{"email": "o.ivanova04111970@postgrespro.ru", "phone": "+70865347856"}
0005434620960	E9DDE0	4583 260659	IRINA SOROKINA	{"phone": "+70034812893"}
0005434620961	E9DDE0	8191 158278	GALINA GAVRILOVA	{"phone": "+70829808001"}
0005434620962	5E542A	8175 502539	VERA POPOVA	{"phone": "+70702522599"}
0005434620963	5E542A	5862 121340	DINA AFANASEVA	{"email": "afanaseva-d_27101965@postgrespro.ru", "phone": "+70494921819"}
0005434620964	49A354	8997 490607	ANDREY MIKHAYLOV	{"phone": "+70569303160"}
0005434620965	49A354	4350 488568	ALEKSANDRA NAUMOVA	{"email": "aleksandra.naumova-1977@postgrespro.ru", "phone": "+70477058419"}
0005434620966	768721	7679 599861	EGOR IVANOV	{"phone": "+70058528863"}
0005434620967	0303E3	9629 115903	ALEKSANDRA SERGEEVA	{"email": "a.sergeeva.121973@postgrespro.ru", "phone": "+70984175204"}
0005434620968	0303E3	6562 832200	LYUBOV SERGEEVA	{"email": "sergeeva-lyubov.12081978@postgrespro.ru", "phone": "+70167247213"}
0005434620969	E8E668	4488 268084	YURIY TIMOFEEV	{"phone": "+70304422810"}
0005434620970	75D01D	2309 295081	ANNA POPOVA	{"email": "a.popova.1969@postgrespro.ru", "phone": "+70236332112"}
0005434620971	443360	8343 369760	NIKOLAY DAVYDOV	{"email": "davydovn-30121976@postgrespro.ru", "phone": "+70333155945"}
0005434620972	C84BF0	5129 076579	EVGENIYA DANILOVA	{"phone": "+70084230979"}
0005434620973	829860	1116 977426	ALESYA ILINA	{"email": "ilina.alesya.1976@postgrespro.ru", "phone": "+70605932595"}
0005434620974	829860	3964 126701	MARAT GERASIMOV	{"email": "gerasimov_marat-21061974@postgrespro.ru", "phone": "+70905202535"}
0005434620975	FF330E	5887 438560	SERGEY IVANOV	{"email": "ivanovs-1955@postgrespro.ru", "phone": "+70324280762"}
0005434620976	09DD4D	5273 451310	VITALIY NAUMOV	{"phone": "+70051375835"}
0005434620977	09DD4D	3726 398044	SERGEY DMITRIEV	{"email": "s.dmitriev121965@postgrespro.ru", "phone": "+70512958287"}
0005434620978	9C0D65	2413 793629	ELIZAVETA GERASIMOVA	{"email": "gerasimova-e.24041977@postgrespro.ru", "phone": "+70944751287"}
0005434620979	D4595B	0287 341155	FANIS ANDREEV	{"email": "andreev_f.081980@postgrespro.ru", "phone": "+70965271610"}
0005434620980	48E7D4	5797 995016	MIKHAIL KOZLOV	{"email": "mkozlov_16071976@postgrespro.ru", "phone": "+70296842502"}
0005434620981	A3D899	6082 404280	MAKSIM ABRAMOV	{"phone": "+70473820794"}
0005434620982	89DBFF	7110 686245	TATYANA VASILEVA	{"email": "vasilevatatyana.1990@postgrespro.ru", "phone": "+70871274756"}
0005434620983	D50096	5316 703022	ALEKSANDR GRIGOREV	{"phone": "+70755163046"}
0005434621040	4EB3CC	8720 600297	VALENTINA MAKSIMOVA	{"phone": "+70614739846"}
0005434620984	D50096	6408 004983	ANASTASIYA ZAYCEVA	{"email": "zayceva_anastasiya-24031984@postgrespro.ru", "phone": "+70787246082"}
0005434620985	F2047B	2989 320128	NIKOLAY EGOROV	{"phone": "+70518483869"}
0005434620986	31D3BE	9563 381935	RIMMA VOLKOVA	{"phone": "+70138623242"}
0005434620987	31D3BE	0433 538330	ROMAN ISAEV	{"email": "isaev_roman-121976@postgrespro.ru", "phone": "+70706924306"}
0005434620988	31D3BE	0463 459014	VALENTINA IVANOVA	{"email": "vivanova-1968@postgrespro.ru", "phone": "+70192541929"}
0005434620989	AEA7B6	1956 345881	NADEZHDA ANTONOVA	{"email": "n.antonova.121973@postgrespro.ru", "phone": "+70301457754"}
0005434620990	D2BDD1	1372 770738	ALEKSEY PETROV	{"phone": "+70728869516"}
0005434620991	112752	6878 040763	DMITRIY MIRONOV	{"phone": "+70900845463"}
0005434620992	6252BD	6398 986586	ANATOLIY KUZMIN	{"phone": "+70354947086"}
0005434620993	6252BD	7965 413311	EKATERINA PETROVA	{"phone": "+70272080874"}
0005434620994	6252BD	0249 115930	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.27041979@postgrespro.ru", "phone": "+70586262372"}
0005434620995	6252BD	2815 385020	ZOYA BARANOVA	{"email": "baranova.zoya.1976@postgrespro.ru", "phone": "+70886722238"}
0005434620996	6252BD	4134 160030	DENIS VOLKOV	{"email": "volkovd19041972@postgrespro.ru", "phone": "+70029568812"}
0005434620997	B53054	0913 268304	ILDAR MOROZOV	{"email": "ildar_morozov_20091972@postgrespro.ru", "phone": "+70653264420"}
0005434620998	9F77E0	2179 662059	DENIS SCHERBAKOV	{"email": "d_scherbakov.1972@postgrespro.ru", "phone": "+70776713126"}
0005434620999	9F77E0	7252 307596	KONSTANTIN DMITRIEV	{"phone": "+70218030435"}
0005434621000	C35D20	5571 953128	NIKITA ZAYCEV	{"email": "nikita_zaycev-101979@postgrespro.ru", "phone": "+70137419233"}
0005434621001	C35D20	7689 831710	TATYANA NOVIKOVA	{"email": "tnovikova-09121983@postgrespro.ru", "phone": "+70434583576"}
0005434621002	F9A204	3086 816367	ELENA KOROLEVA	{"phone": "+70814366184"}
0005434621003	F9A204	6370 762277	MIKHAIL KUZMIN	{"email": "mikhailkuzmin_1972@postgrespro.ru", "phone": "+70135298084"}
0005434621004	A1FA43	1169 422548	TATYANA GERASIMOVA	{"email": "tatyana-gerasimova.121972@postgrespro.ru", "phone": "+70983218135"}
0005434621005	EDBC3F	9966 302369	VLADIMIR GRIGOREV	{"phone": "+70334178467"}
0005434621006	4A22D4	6739 142161	GALINA ILINA	{"phone": "+70033775432"}
0005434621007	4A22D4	0248 962631	LEONID NOVIKOV	{"phone": "+70290247007"}
0005434621008	D9F254	2532 772256	ILYA ZAKHAROV	{"phone": "+70775334296"}
0005434621009	D9F254	3086 054696	DANIL KUZNECOV	{"phone": "+70380856345"}
0005434621010	FD3B04	1451 931429	LIDIYA POLYAKOVA	{"phone": "+70906143009"}
0005434621011	B8F3E2	0425 720349	KIRILL SOROKIN	{"email": "k_sorokin10031974@postgrespro.ru", "phone": "+70469074961"}
0005434621012	8815EB	2754 206209	GENNADIY GAVRILOV	{"phone": "+70858722374"}
0005434621013	8815EB	3595 013277	EVGENIY MOISEEV	{"phone": "+70381315859"}
0005434621014	4F4A83	6876 830584	ELENA BARANOVA	{"email": "baranovae.11021975@postgrespro.ru", "phone": "+70857894689"}
0005434621015	4F4A83	0163 828690	IGOR POPOV	{"phone": "+70027096627"}
0005434621016	4F4A83	1997 904652	IRINA VLASOVA	{"email": "irina-vlasova_05021989@postgrespro.ru", "phone": "+70708166296"}
0005434621017	686A16	0583 443529	LYUBOV KALININA	{"email": "lyubov.kalinina071969@postgrespro.ru", "phone": "+70732647445"}
0005434621018	5DEED7	9296 205963	DANIL FEDOTOV	{"email": "danilfedotov.07021961@postgrespro.ru", "phone": "+70532498155"}
0005434621019	2F6D0D	6284 236969	GALINA KOROLEVA	{"phone": "+70173641138"}
0005434621020	BCB7DC	0625 567335	MARIYA KOMAROVA	{"email": "m.komarova_1977@postgrespro.ru", "phone": "+70543000806"}
0005434621021	5A2461	2204 723692	SVETLANA SOROKINA	{"phone": "+70368362475"}
0005434621022	4AF500	5125 597214	YULIYA ALEKSANDROVA	{"phone": "+70378939924"}
0005434621023	2AAA6A	2038 655520	ANDREY MOROZOV	{"phone": "+70619000636"}
0005434621024	2AAA6A	9323 642147	ANDREY ORLOV	{"phone": "+70429402560"}
0005434621025	99C245	5129 790216	RAISA NOVIKOVA	{"email": "raisa-novikova27041964@postgrespro.ru", "phone": "+70275748856"}
0005434621026	EE2095	0254 523709	DARYA ILINA	{"email": "ilina-d-1971@postgrespro.ru", "phone": "+70420859663"}
0005434621027	A1D08E	7135 349232	ALEKSANDR KUZNECOV	{"email": "akuznecov-27091971@postgrespro.ru", "phone": "+70175083874"}
0005434621028	A1D08E	0496 732723	YULIYA SOROKINA	{"phone": "+70583383304"}
0005434621029	36A4C7	6130 250573	STEPAN RODIONOV	{"phone": "+70532321874"}
0005434621030	36A4C7	9460 823863	LYUBOV LEBEDEVA	{"phone": "+70929757456"}
0005434621031	794D5D	8820 331032	TAGIR ALEKSEEV	{"email": "tagiralekseev_111968@postgrespro.ru", "phone": "+70285935177"}
0005434621032	D68FAE	5306 894841	ALENA SCHERBAKOVA	{"email": "scherbakova_a.051976@postgrespro.ru", "phone": "+70652597827"}
0005434621033	D68FAE	2273 237367	ALEKSANDR FROLOV	{"phone": "+70351798712"}
0005434621034	CAD420	5517 204726	TATYANA SIDOROVA	{"email": "tatyanasidorova_30101975@postgrespro.ru", "phone": "+70135292990"}
0005434621035	CAD420	3867 020974	PETR SEMENOV	{"phone": "+70203624618"}
0005434621036	CAD420	7907 252097	ALEKSANDR EGOROV	{"email": "egorov_aleksandr-011965@postgrespro.ru", "phone": "+70702464235"}
0005434621037	A6012F	6561 779667	ILYA SOROKIN	{"phone": "+70017628732"}
0005434621038	FA121F	6842 918359	MIKHAIL IVANOV	{"email": "mikhail-ivanov-01011963@postgrespro.ru", "phone": "+70672368096"}
0005434621039	4EB3CC	4556 083342	ANNA SEMENOVA	{"phone": "+70302822140"}
0005434621041	3598C7	8343 308007	LYUBOV DAVYDOVA	{"email": "ldavydova-1973@postgrespro.ru", "phone": "+70962459262"}
0005434621042	3598C7	6128 669300	DMITRIY MAKAROV	{"email": "dmitriy_makarov-1971@postgrespro.ru", "phone": "+70238747756"}
0005434621043	C10A61	9056 105201	DMITRIY BORISOV	{"phone": "+70275585624"}
0005434621044	0F4A85	5488 343908	LYUDMILA KOLESNIKOVA	{"email": "lyudmila.kolesnikova051981@postgrespro.ru", "phone": "+70369400406"}
0005434621045	5692A1	6373 223979	AYRAT FILIPPOV	{"phone": "+70434027766"}
0005434621046	63B784	2467 998916	IVAN SMIRNOV	{"email": "ismirnov.111967@postgrespro.ru", "phone": "+70838875860"}
0005434621047	7C7C24	1559 424528	IVAN ZHURAVLEV	{"phone": "+70082016680"}
0005434621048	7C7C24	5615 957716	ANDREY KAZAKOV	{"email": "kazakovandrey_071973@postgrespro.ru", "phone": "+70351179420"}
0005434621049	EE357B	6247 271712	ALEKSANDRA KRASNOVA	{"phone": "+70294418805"}
0005434621050	BE7645	8422 560049	ELENA VOLKOVA	{"email": "e.volkova-1974@postgrespro.ru", "phone": "+70694692270"}
0005434621051	CDEE17	0939 515185	ANTON EGOROV	{"phone": "+70075950502"}
0005434621052	0EC8F1	1271 354099	ALEKSEY YAKOVLEV	{"phone": "+70885020546"}
0005434621053	0EC8F1	2182 312122	DMITRIY ZAYCEV	{"email": "dmitriyzaycev-081965@postgrespro.ru", "phone": "+70304804476"}
0005434621054	958C81	0996 759285	VIKTOR ANDREEV	{"email": "vandreev-1988@postgrespro.ru", "phone": "+70788666115"}
0005434621055	958C81	4294 127417	TATYANA KUZNECOVA	{"email": "kuznecova_tatyana-021984@postgrespro.ru", "phone": "+70902884924"}
0005434621056	A87458	9605 645774	ALEKSANDR ORLOV	{"phone": "+70547246058"}
0005434621057	463E42	1763 506932	GALINA EGOROVA	{"email": "g.egorova.061965@postgrespro.ru", "phone": "+70120736337"}
0005434621058	668D41	6614 005707	GALINA FROLOVA	{"email": "frolova_g041973@postgrespro.ru", "phone": "+70914337037"}
0005434621059	9D506C	6312 281382	GALINA FILATOVA	{"email": "filatova_g061987@postgrespro.ru", "phone": "+70228095943"}
0005434621060	9D506C	8589 629760	GALINA PAVLOVA	{"phone": "+70642972504"}
0005434621061	49CB6A	6897 675743	OLEG SCHERBAKOV	{"phone": "+70554939891"}
0005434621062	A0BFCE	9454 193242	NADEZHDA KOROLEVA	{"phone": "+70629239944"}
0005434621063	A4EC44	0401 200047	VALENTINA MOROZOVA	{"phone": "+70344123413"}
0005434621064	A4EC44	5429 811040	SERGEY SOLOVEV	{"phone": "+70505807700"}
0005434621065	DC9B5D	6571 510753	ELENA POTAPOVA	{"phone": "+70404477469"}
0005434621066	DC9B5D	0173 502025	OLGA ORLOVA	{"email": "orlova_olga_011966@postgrespro.ru", "phone": "+70478740279"}
0005434621067	746B12	6030 101282	OLESYA MAKSIMOVA	{"phone": "+70890892541"}
0005434621068	746B12	6226 563143	YULIYA KOZLOVA	{"email": "ykozlova-071964@postgrespro.ru", "phone": "+70266506928"}
0005434621069	A73D0F	8747 061422	GENNADIY SEMENOV	{"email": "g-semenov.031971@postgrespro.ru", "phone": "+70625305196"}
0005434621070	6F1AC9	4172 163057	DAMIR SEMENOV	{"email": "semenov-damir-101978@postgrespro.ru", "phone": "+70543125246"}
0005434621071	E72478	4250 159087	OLEG PETROV	{"phone": "+70289521010"}
0005434621072	3F7184	4400 236836	ZHANNA KULIKOVA	{"email": "z.kulikova.101966@postgrespro.ru", "phone": "+70478061674"}
0005434621073	E1CBE7	7436 939011	EKATERINA KAZAKOVA	{"phone": "+70040189316"}
0005434621074	273DBD	5797 663028	SVETLANA MOISEEVA	{"phone": "+70583873141"}
0005434621075	E59FD9	0242 106172	ANASTASIYA KISELEVA	{"phone": "+70591692398"}
0005434621076	7C01C4	7917 041030	ANDREY KOZLOV	{"email": "a-kozlov.29111972@postgrespro.ru", "phone": "+70296409521"}
0005434621077	7C01C4	9391 527239	ALEKSEY PAVLOV	{"phone": "+70277108258"}
0005434621078	90323C	5055 976162	MARINA KARPOVA	{"phone": "+70095566803"}
0005434621079	90323C	0513 318030	ARTUR KULIKOV	{"email": "kulikov.artur_07101983@postgrespro.ru", "phone": "+70371652312"}
0005434621080	08F008	2591 341796	DMITRIY VLASOV	{"phone": "+70049198290"}
0005434621081	75CDBE	6856 757241	ALEKSANDR ANTONOV	{"phone": "+70962729909"}
0005434621082	7A9ED0	8799 128632	LARISA SIDOROVA	{"phone": "+70920965046"}
0005434621083	670F59	4331 551576	GALINA BELYAEVA	{"phone": "+70298825129"}
0005434621084	670F59	0820 982393	TAMARA AFANASEVA	{"email": "t_afanaseva25091971@postgrespro.ru", "phone": "+70639670023"}
0005434621085	670F59	5592 850673	ANDREY KUZNECOV	{"phone": "+70759645608"}
0005434621086	14AF86	4342 500761	SERGEY MEDVEDEV	{"email": "sergeymedvedev-16111979@postgrespro.ru", "phone": "+70171796009"}
0005434621087	5A5931	4030 756297	RITA KUZNECOVA	{"phone": "+70048321548"}
0005434621088	57E3F3	6501 460013	ELENA KISELEVA	{"email": "kiseleva.elena.1968@postgrespro.ru", "phone": "+70643399195"}
0005434621089	B5109C	3943 974371	ALEKSANDR KUDRYASHOV	{"phone": "+70512449474"}
0005434621090	63A636	2895 892164	VALENTINA VOLKOVA	{"phone": "+70500916555"}
0005434621091	63A636	3462 770571	YURIY ZHUKOV	{"email": "zhukov_y-27081971@postgrespro.ru", "phone": "+70638159202"}
0005434621092	45301E	7168 454492	MARIYA ARKHIPOVA	{"phone": "+70915700111"}
0005434621093	D40F58	4629 346845	RAISA OSIPOVA	{"phone": "+70851663512"}
0005434621094	D40F58	3304 191958	OLGA ABRAMOVA	{"phone": "+70675767302"}
0005434621095	D40F58	9027 039947	ANTONINA MAKAROVA	{"phone": "+70581152074"}
0005434621096	80D5BF	3296 949993	VIKTOR IVANOV	{"phone": "+70869755909"}
0005434621097	2E4E45	0711 913217	MADINA VASILEVA	{"email": "madinavasileva-111968@postgrespro.ru", "phone": "+70843454343"}
0005434621098	F0DD94	1743 084031	ANATOLIY MOISEEV	{"phone": "+70384277511"}
0005434621099	A2B075	4655 529644	YANA NOVIKOVA	{"email": "novikova_y051968@postgrespro.ru", "phone": "+70189786865"}
0005434621100	B4EA22	9881 898806	VALENTINA SOKOLOVA	{"phone": "+70478146147"}
0005434621101	8BFCC9	0158 719208	DMITRIY POPOV	{"phone": "+70108022766"}
0005434621102	8BFCC9	1398 212433	VIKTOR TARASOV	{"email": "v_tarasov16061979@postgrespro.ru", "phone": "+70500806943"}
0005434621103	2B2132	2246 291317	ALEKSANDR ZHURAVLEV	{"phone": "+70488091399"}
0005434621104	2B2132	1930 367817	SERGEY KUZMIN	{"phone": "+70282457284"}
0005434621105	2B2132	6845 722311	ANTONINA TIMOFEEVA	{"phone": "+70010200529"}
0005434621106	D7CF2D	3436 636433	MARIYA KULIKOVA	{"phone": "+70354205225"}
0005434621107	DCB1DA	0853 735373	ZINAIDA KUZMINA	{"phone": "+70343572622"}
0005434621108	6FCD21	7619 895012	VLADIMIR SOLOVEV	{"email": "solovev-vladimir.07031972@postgrespro.ru", "phone": "+70004522814"}
0005434621109	6FCD21	8329 041606	IVAN OSIPOV	{"phone": "+70938952587"}
0005434621110	6FCD21	1539 160863	GALINA FILATOVA	{"email": "filatova-g_1963@postgrespro.ru", "phone": "+70172474901"}
0005434621111	1720AD	1542 872027	RAMIS ANDREEV	{"email": "andreev-ramis.27091972@postgrespro.ru", "phone": "+70467129381"}
0005434621112	1720AD	8661 153978	NIKITA MOROZOV	{"email": "morozov_nikita021972@postgrespro.ru", "phone": "+70133642063"}
0005434621113	4C3D9D	5529 130715	ANNA ZAKHAROVA	{"phone": "+70979817064"}
0005434621114	4C3D9D	8150 705406	ALEKSANDR GORBUNOV	{"email": "aleksandrgorbunov.081962@postgrespro.ru", "phone": "+70819789377"}
0005434621115	6C86AD	3252 458453	DMITRIY SOROKIN	{"email": "dsorokin_011971@postgrespro.ru", "phone": "+70214334802"}
0005434621116	A2506E	8595 985214	BOGDAN MEDVEDEV	{"email": "b_medvedev.06091965@postgrespro.ru", "phone": "+70798502266"}
0005434621117	A2506E	9929 653560	IRINA BELOVA	{"email": "belova-i27101963@postgrespro.ru", "phone": "+70709981988"}
0005434621118	470067	6247 715759	DMITRIY KOZLOV	{"email": "kozlovd-1970@postgrespro.ru", "phone": "+70854162750"}
0005434621119	589F08	2256 759292	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr.011969@postgrespro.ru", "phone": "+70599700139"}
0005434621120	589F08	4430 882246	ELENA FROLOVA	{"email": "e-frolova.1972@postgrespro.ru", "phone": "+70485300616"}
0005434621121	A82DCB	3731 074498	NATALYA KULIKOVA	{"email": "natalya.kulikova.26121967@postgrespro.ru", "phone": "+70843961031"}
0005434621122	026467	7286 091578	VYACHESLAV SAVELEV	{"email": "savelevv031977@postgrespro.ru", "phone": "+70647857693"}
0005434621123	6DB7AD	9309 139902	KSENIYA BELOVA	{"phone": "+70760282927"}
0005434621124	993976	8820 547925	DMITRIY KISELEV	{"phone": "+70296953938"}
0005434621125	4A7125	3494 717574	VASILIY PAVLOV	{"email": "vasiliypavlov_111970@postgrespro.ru", "phone": "+70954547000"}
0005434621126	7923D2	8009 773622	DMITRIY DAVYDOV	{"email": "davydov.d_1977@postgrespro.ru", "phone": "+70205592054"}
0005434621127	755A29	1396 620755	TATYANA PAVLOVA	{"phone": "+70764823891"}
0005434621128	6226FA	4393 801050	VLADIMIR GRIGOREV	{"email": "vladimir.grigorev_18011968@postgrespro.ru", "phone": "+70241285721"}
0005434621129	EF5CA4	2342 137510	BORIS MELNIKOV	{"phone": "+70659603044"}
0005434621130	039662	9144 886527	MAKSIM MELNIKOV	{"email": "maksim_melnikov.051970@postgrespro.ru", "phone": "+70084907814"}
0005434621131	039662	9958 899650	LIDIYA MAKAROVA	{"phone": "+70429731539"}
0005434621132	95FF14	2330 815100	STEPAN IVANOV	{"email": "s_ivanov_15011978@postgrespro.ru", "phone": "+70976624639"}
0005434621133	95FF14	8244 356146	LIDIYA TARASOVA	{"phone": "+70463142094"}
0005434621134	6103DD	3642 765331	IVAN KRASNOV	{"email": "ivan_krasnov_061970@postgrespro.ru", "phone": "+70771916615"}
0005434621135	600773	6979 928615	NATALYA ZHURAVLEVA	{"phone": "+70613102969"}
0005434621136	600773	0785 855825	LYUBOV KUZMINA	{"email": "kuzmina_lyubov_13111973@postgrespro.ru", "phone": "+70095498819"}
0005434621137	F78318	0295 205221	ARTEM AFANASEV	{"email": "artemafanasev1965@postgrespro.ru", "phone": "+70965395857"}
0005434621138	C18F78	3150 156043	ALEVTINA ANDREEVA	{"email": "alevtina-andreeva.031969@postgrespro.ru", "phone": "+70071586670"}
0005434621139	C18F78	4929 218910	VALERIY GORBUNOV	{"phone": "+70063975802"}
0005434621140	406919	1238 384191	LYUBOV MASLOVA	{"email": "lyubov_maslova.09101977@postgrespro.ru", "phone": "+70617165467"}
0005434621141	406919	9141 261332	GALINA SOROKINA	{"phone": "+70737712446"}
0005434621142	ACFCA7	8466 486341	ALEKSEY ALEKSEEV	{"phone": "+70270910223"}
0005434621143	19504A	1887 904998	SNEZHANA MIRONOVA	{"phone": "+70953086015"}
0005434621144	BF3301	5172 280478	MAKSIM NIKOLAEV	{"phone": "+70360987514"}
0005434621145	D33527	2683 078176	ILYA MATVEEV	{"phone": "+70234675785"}
0005434621146	D33527	6920 016494	ALEKSEY KUZNECOV	{"phone": "+70658498765"}
0005434621147	E864CC	1616 962805	MARINA OSIPOVA	{"phone": "+70768212163"}
0005434621148	79A3C4	4584 992407	TATYANA ILINA	{"email": "t-ilina-071976@postgrespro.ru", "phone": "+70448531023"}
0005434621149	D80924	7836 990846	OLGA MAKSIMOVA	{"phone": "+70519737474"}
0005434621150	3A089B	0170 520750	DMITRIY ALEKSEEV	{"email": "alekseevd-02091979@postgrespro.ru", "phone": "+70138702741"}
0005434621151	3A089B	7819 470816	VLADIMIR DMITRIEV	{"phone": "+70070643352"}
0005434621152	7411B4	6923 005297	ANTONINA NIKITINA	{"phone": "+70480888060"}
0005434621153	BFFBEE	1848 683688	AYRAT EGOROV	{"phone": "+70618255612"}
0005434621154	BFFBEE	8190 247708	SVETLANA BARANOVA	{"phone": "+70113557544"}
0005434621155	BFFBEE	0897 732692	NATALYA KOLESNIKOVA	{"email": "kolesnikova-natalya30051978@postgrespro.ru", "phone": "+70708651775"}
0005434621156	0D41A0	7998 332551	TATYANA NIKITINA	{"phone": "+70972037561"}
0005434621157	EFA99B	6715 690999	LYUBOV ZAYCEVA	{"phone": "+70952279634"}
0005434621158	95411E	9604 528419	VLADIMIR MOROZOV	{"phone": "+70523019513"}
0005434621159	E63C25	5310 001975	SERGEY KRASNOV	{"phone": "+70818019845"}
0005434621160	E63C25	9029 861468	EVGENIY KISELEV	{"email": "kiselev.e_061973@postgrespro.ru", "phone": "+70972029528"}
0005434621161	9FF38E	0172 127708	DMITRIY NIKOLAEV	{"email": "nikolaevd-1964@postgrespro.ru", "phone": "+70374077454"}
0005434621162	0B9EC1	5384 313609	KSENIYA ABRAMOVA	{"phone": "+70411588906"}
0005434621163	7226DA	7182 873017	SVETLANA AKIMOVA	{"email": "svetlana.akimova20041974@postgrespro.ru", "phone": "+70123567346"}
0005434621164	DF6D8A	0153 207889	VALENTINA EGOROVA	{"email": "egorovavalentina.16081968@postgrespro.ru", "phone": "+70879438041"}
0005434621165	684799	4479 600950	NINA YAKOVLEVA	{"phone": "+70871287708"}
0005434621166	69BC23	0034 861344	EVGENIY KONOVALOV	{"email": "konovalov.evgeniy-17091971@postgrespro.ru", "phone": "+70026202809"}
0005434621167	0ED201	5530 558763	LIDIYA ANISIMOVA	{"email": "lidiyaanisimova-1970@postgrespro.ru", "phone": "+70046252663"}
0005434621168	0ED201	9266 579219	VALENTINA ARKHIPOVA	{"phone": "+70087511627"}
0005434621169	39D495	0357 073643	OLGA FROLOVA	{"email": "frolovao.05101965@postgrespro.ru", "phone": "+70960996628"}
0005434621170	8B081E	3198 711268	ZINAIDA MEDVEDEVA	{"email": "zinaida-medvedeva1962@postgrespro.ru", "phone": "+70246531855"}
0005434621171	8B081E	0688 419217	SERGEY IVANOV	{"phone": "+70388206591"}
0005434621172	7F984A	6381 606393	ALEKSANDR KOZLOV	{"phone": "+70270477520"}
0005434621173	7F984A	2681 050449	MAKSIM ANTONOV	{"phone": "+70937375265"}
0005434621174	D888E6	3011 277261	ALEKSANDR BARANOV	{"phone": "+70198337797"}
0005434621175	04AC07	6111 088218	VASILIY KUZMIN	{"email": "vasiliy.kuzmin.121968@postgrespro.ru", "phone": "+70234756152"}
0005434621176	BE0E0F	4789 921054	PAVEL BELOV	{"phone": "+70144106802"}
0005434621177	BE0E0F	4495 169139	OLGA GUSEVA	{"phone": "+70530849888"}
0005434621178	BE0E0F	1450 771083	VLADIMIR SOKOLOV	{"email": "v.sokolov-1981@postgrespro.ru", "phone": "+70166028970"}
0005434621179	1A18F2	8597 483038	SERGEY IVANOV	{"email": "sergey.ivanov.15061972@postgrespro.ru", "phone": "+70080314450"}
0005434621180	6061D5	0543 506954	DMITRIY GORBUNOV	{"phone": "+70437845163"}
0005434621181	9DDC8C	2106 435024	PAVEL KAZAKOV	{"phone": "+70953121755"}
0005434621182	649683	8506 700592	NATALYA MELNIKOVA	{"email": "melnikova_n.1969@postgrespro.ru", "phone": "+70264063122"}
0005434621183	649683	6890 716216	EKATERINA MOROZOVA	{"email": "emorozova1974@postgrespro.ru", "phone": "+70408471016"}
0005434625892	1ED174	7399 046990	LARISA ZHURAVLEVA	{"phone": "+70314586782"}
0005434625793	2DD8E9	5811 809194	ALEKSEY GERASIMOV	{"phone": "+70593960678"}
0005434625794	2DD8E9	1397 705199	MARINA MIRONOVA	{"email": "mironova.marina-18031975@postgrespro.ru", "phone": "+70525619494"}
0005434625795	C46DD8	3504 261033	ALEKSANDR BORISOV	{"email": "a-borisov_1966@postgrespro.ru", "phone": "+70057527409"}
0005434625796	0334FD	3437 327985	EGOR FROLOV	{"phone": "+70392596219"}
0005434625797	8AA1AF	9115 849816	ALEKSANDR ABRAMOV	{"email": "abramov.a-1960@postgrespro.ru", "phone": "+70083285224"}
0005434625798	8AA1AF	6167 342188	ANNA ANTONOVA	{"email": "antonova.a011966@postgrespro.ru", "phone": "+70501602344"}
0005434625799	131052	1442 282960	VALENTINA NIKOLAEVA	{"email": "nikolaevavalentina_021984@postgrespro.ru", "phone": "+70378082667"}
0005434625800	A0767A	5247 553042	VALENTINA KOROLEVA	{"email": "valentina-koroleva-1974@postgrespro.ru", "phone": "+70932471575"}
0005434625801	BDFA4D	6939 222107	EKATERINA MAKAROVA	{"email": "ekaterina-makarova-14041965@postgrespro.ru", "phone": "+70078696676"}
0005434625802	9527F7	5077 553923	SERGEY MOROZOV	{"phone": "+70226349659"}
0005434625803	C462E1	0689 124504	LIDIYA KUZMINA	{"phone": "+70474714106"}
0005434625804	29FE77	4760 606391	GALINA BOGDANOVA	{"phone": "+70460211017"}
0005434625805	451255	7288 386086	ALEKSANDR PAVLOV	{"email": "apavlov021970@postgrespro.ru", "phone": "+70439207386"}
0005434625806	6F9BE9	8107 505674	ALEKSANDR KAZAKOV	{"phone": "+70481643574"}
0005434625807	4A739E	4786 808503	ALEKSEY SOLOVEV	{"email": "solovev-a_23011969@postgrespro.ru", "phone": "+70885365919"}
0005434625808	4A739E	8937 741770	YURIY ANDREEV	{"phone": "+70939474878"}
0005434625809	E15AF2	4185 137537	YURIY PETROV	{"phone": "+70653686382"}
0005434625810	95A7C0	5562 735261	OLGA BORISOVA	{"email": "borisova_o09111969@postgrespro.ru", "phone": "+70991889466"}
0005434625811	75A6E8	5354 329482	VIKTORIYA RYABOVA	{"email": "viktoriya-ryabova_071971@postgrespro.ru", "phone": "+70448253671"}
0005434625812	004A87	8506 637804	MARINA POTAPOVA	{"phone": "+70478826378"}
0005434625813	756350	9733 736547	DIANA ANDREEVA	{"phone": "+70683696188"}
0005434625814	756350	2574 326591	TAMARA NESTEROVA	{"email": "tamara.nesterova_16071975@postgrespro.ru", "phone": "+70899046277"}
0005434625815	756350	5518 424996	NIKOLAY ALEKSEEV	{"phone": "+70261900952"}
0005434625816	611558	1155 604554	PAVEL VASILEV	{"phone": "+70450870807"}
0005434625817	8F598B	4399 658348	LYUDMILA EGOROVA	{"phone": "+70809314046"}
0005434625818	93A6ED	2421 874490	DENIS SCHERBAKOV	{"phone": "+70325226154"}
0005434625819	0E0762	5650 013505	ALENA OSIPOVA	{"phone": "+70896117859"}
0005434625820	0E0762	6712 214796	EVGENIY NAUMOV	{"email": "evgeniy-naumov-03121971@postgrespro.ru", "phone": "+70789813354"}
0005434625821	4A3885	0285 856881	OKSANA VASILEVA	{"phone": "+70372959209"}
0005434625822	4A3885	5666 366976	OLGA KOROLEVA	{"phone": "+70515722318"}
0005434625823	4A8175	3596 378094	DARYA KISELEVA	{"email": "dkiseleva_22041967@postgrespro.ru", "phone": "+70603181688"}
0005434625824	4A8175	5214 610522	SVETLANA ANISIMOVA	{"phone": "+70403425001"}
0005434625825	968E52	6428 979930	MIKHAIL SOKOLOV	{"email": "sokolov.mikhail_13051982@postgrespro.ru", "phone": "+70880246855"}
0005434625826	359487	2059 250219	EVGENIY SOROKIN	{"email": "sorokin_e17081963@postgrespro.ru", "phone": "+70157592796"}
0005434625827	988CAF	3839 395430	YULIYA KULIKOVA	{"email": "yuliya_kulikova1972@postgrespro.ru", "phone": "+70110290268"}
0005434625828	96B129	7630 044366	LYUBOV YAKOVLEVA	{"email": "lyubov_yakovleva-06041965@postgrespro.ru", "phone": "+70885602556"}
0005434625829	96B129	7953 167933	NATALYA KULIKOVA	{"email": "kulikova.n111968@postgrespro.ru", "phone": "+70121633825"}
0005434625830	96B129	5089 534962	NIKOLAY KUZMIN	{"email": "nikolay_kuzmin.27031968@postgrespro.ru", "phone": "+70672040573"}
0005434625831	FCB8A2	1955 057340	SERGEY FEDOROV	{"email": "fedorov-s.1970@postgrespro.ru", "phone": "+70986487289"}
0005434625832	FCB8A2	3999 313166	SVETLANA LAZAREVA	{"email": "lazarevasvetlana_09111972@postgrespro.ru", "phone": "+70803671430"}
0005434625833	8D8E08	0395 121198	LYUBOV GUSEVA	{"phone": "+70923426667"}
0005434625834	904641	4949 677782	MARIYA IVANOVA	{"phone": "+70567206816"}
0005434625835	904641	3306 490888	LEONID EGOROV	{"email": "leonid-egorov-20021968@postgrespro.ru", "phone": "+70678796252"}
0005434625836	7E1E7B	8901 191032	VYACHESLAV ALEKSEEV	{"email": "vyacheslav-alekseev_1969@postgrespro.ru", "phone": "+70097875980"}
0005434625837	7E1E7B	0146 041829	VYACHESLAV VLASOV	{"phone": "+70719743504"}
0005434625838	A53E67	1456 497791	ANTONINA FROLOVA	{"email": "afrolova121978@postgrespro.ru", "phone": "+70804709561"}
0005434625839	8F07F8	8339 886236	RUSTAM EGOROV	{"email": "egorov-rustam111973@postgrespro.ru", "phone": "+70975726104"}
0005434625840	4B853B	0709 788243	ANDREY ROMANOV	{"phone": "+70027392920"}
0005434625841	7D7DF5	3369 230502	NADEZHDA MEDVEDEVA	{"phone": "+70449758605"}
0005434625842	EAF629	9048 531617	ELENA KOROLEVA	{"phone": "+70936954869"}
0005434625843	594620	7024 439081	SVETLANA BORISOVA	{"phone": "+70990571664"}
0005434625844	D7FD1A	1932 365738	VALERIY MIRONOV	{"email": "mironovv041968@postgrespro.ru", "phone": "+70584382418"}
0005434625845	FC4674	4325 219450	VLADIMIR KOROLEV	{"phone": "+70876743257"}
0005434625846	22F781	0728 466568	OLGA SERGEEVA	{"phone": "+70789760987"}
0005434625847	8CC2FF	4066 748687	DMITRIY ANTONOV	{"email": "antonov-d_061974@postgrespro.ru", "phone": "+70252501431"}
0005434625848	8CC2FF	2518 849129	ZINAIDA KALININA	{"email": "zinaida-kalinina.1973@postgrespro.ru", "phone": "+70402966987"}
0005434625849	8B6AD8	2521 235882	MARIYA ANTONOVA	{"email": "mariya_antonova.1968@postgrespro.ru", "phone": "+70299850140"}
0005434625850	8B6AD8	4420 134467	LEONID MIKHAYLOV	{"phone": "+70003394337"}
0005434625851	5F936D	9392 691668	EVGENIYA ROMANOVA	{"email": "romanova.e.13021977@postgrespro.ru", "phone": "+70643423529"}
0005434625852	5F936D	9085 279504	NINA KUZMINA	{"email": "n-kuzmina.14111988@postgrespro.ru", "phone": "+70575088668"}
0005434625853	6E414B	5496 293769	IVAN GERASIMOV	{"email": "gerasimov-ivan16071982@postgrespro.ru", "phone": "+70350649436"}
0005434625854	BA11E9	5523 594583	ALEKSANDR SOLOVEV	{"phone": "+70685637230"}
0005434625855	236DAA	0629 205650	INNA NIKIFOROVA	{"email": "inikiforova_12111977@postgrespro.ru", "phone": "+70542698026"}
0005434625856	26D3CC	2554 990485	DENIS BORISOV	{"email": "d-borisov_19051965@postgrespro.ru", "phone": "+70022132902"}
0005434625857	24F545	3545 469854	VALENTINA FADEEVA	{"email": "fadeeva_valentina_21091971@postgrespro.ru", "phone": "+70402870754"}
0005434625858	C73976	1861 739593	VLADIMIR SOROKIN	{"phone": "+70970707490"}
0005434625859	C73976	3798 361425	SERGEY ORLOV	{"phone": "+70002312900"}
0005434625860	61C315	4962 851321	ELENA LAZAREVA	{"phone": "+70008324324"}
0005434625861	AA3C11	2102 544540	SERGEY SHEVCHENKO	{"phone": "+70357816888"}
0005434625862	AA3C11	0574 346194	TIMUR ZAKHAROV	{"phone": "+70960611564"}
0005434625863	AA3C11	9766 516833	ILYA SHEVCHENKO	{"email": "shevchenko-ilya_111969@postgrespro.ru", "phone": "+70022010549"}
0005434625864	AA4F18	0600 552298	NATALYA MASLOVA	{"email": "natalya_maslova.17111971@postgrespro.ru", "phone": "+70679021250"}
0005434625865	46D2C4	8027 155674	VITALIY GORBUNOV	{"email": "gorbunov.v.011973@postgrespro.ru", "phone": "+70102045450"}
0005434625866	8021FF	1310 763759	ARTEM ROMANOV	{"email": "romanov.a1964@postgrespro.ru", "phone": "+70802986093"}
0005434625867	8021FF	0305 575658	VALENTINA EGOROVA	{"email": "valentina_egorova_031973@postgrespro.ru", "phone": "+70778365728"}
0005434625868	E17D20	9252 294971	DMITRIY FROLOV	{"phone": "+70164158285"}
0005434625869	7B5544	4422 639685	VARVARA STEPANOVA	{"email": "v_stepanova1986@postgrespro.ru", "phone": "+70808833532"}
0005434625870	E0ED57	6034 689840	ANNA NIKITINA	{"email": "a.nikitina-1967@postgrespro.ru", "phone": "+70399275845"}
0005434625871	A6629C	4650 948297	ELENA EGOROVA	{"phone": "+70033623164"}
0005434625872	A5DB7B	1188 217400	VERA MALYSHEVA	{"email": "vera-malysheva_021976@postgrespro.ru", "phone": "+70982001919"}
0005434625873	E15986	0889 181336	SERGEY SCHERBAKOV	{"phone": "+70030654356"}
0005434625874	EFD6D0	7734 635042	VALENTINA OSIPOVA	{"email": "v-osipova121977@postgrespro.ru", "phone": "+70560688217"}
0005434625875	5A33C5	1539 952076	EVDOKIYA FILATOVA	{"email": "filatova-e_1964@postgrespro.ru", "phone": "+70881323583"}
0005434625876	9E84C8	9179 137480	TATYANA MEDVEDEVA	{"email": "tatyana-medvedeva_081979@postgrespro.ru", "phone": "+70087650833"}
0005434625877	9E84C8	3722 759897	OLGA SOLOVEVA	{"phone": "+70607078585"}
0005434625878	9E84C8	3613 896147	ALEKSEY STEPANOV	{"email": "a.stepanov_1963@postgrespro.ru", "phone": "+70882444075"}
0005434625879	9E84C8	6308 303371	ANTON BELOV	{"email": "belov_anton.051974@postgrespro.ru", "phone": "+70829135429"}
0005434625880	8AB0EA	8101 772004	ALEKSEY SERGEEV	{"phone": "+70415828164"}
0005434625881	D420A3	2123 099092	ANZHELIKA IVANOVA	{"email": "anzhelika.ivanova_05031974@postgrespro.ru", "phone": "+70577872138"}
0005434625882	81FF88	2499 566478	VENERA KAZAKOVA	{"email": "kazakova_v041974@postgrespro.ru", "phone": "+70801448317"}
0005434625883	81FF88	5067 356045	LYUBOV KUZMINA	{"phone": "+70149370348"}
0005434625884	EB32DB	4952 312859	IGOR ILIN	{"email": "i-ilin_24101965@postgrespro.ru", "phone": "+70179226260"}
0005434625885	0938EC	7168 589878	ALEKSANDRA CHERNOVA	{"email": "aleksandra_chernova-07101971@postgrespro.ru", "phone": "+70659919529"}
0005434625886	34E8AC	8266 190131	NIKITA POPOV	{"email": "popov_n121974@postgrespro.ru", "phone": "+70071672344"}
0005434625887	A7F9E1	1454 323079	VIKTOR NOVIKOV	{"phone": "+70822277308"}
0005434625888	CA90D9	7618 739002	LYUBOV MELNIKOVA	{"phone": "+70821161759"}
0005434625889	2322B6	0514 070592	DENIS DENISOV	{"email": "denisov_denis.11101973@postgrespro.ru", "phone": "+70517831567"}
0005434625890	2322B6	9797 896747	MARINA GRISHINA	{"phone": "+70788898818"}
0005434625891	20E9C3	7226 224500	PAVEL MELNIKOV	{"phone": "+70788352980"}
0005434625893	88C84A	3177 816971	SERGEY YAKOVLEV	{"email": "syakovlev.101971@postgrespro.ru", "phone": "+70836025089"}
0005434625894	02A985	8376 417825	VLADIMIR SERGEEV	{"email": "vsergeev05121971@postgrespro.ru", "phone": "+70002854947"}
0005434625895	9C6AA3	6274 627547	ANDREY FEDOTOV	{"email": "fedotov.a_27081969@postgrespro.ru", "phone": "+70304049408"}
0005434625896	9C6AA3	8362 883984	LARISA SIDOROVA	{"email": "larisasidorova.061980@postgrespro.ru", "phone": "+70042346592"}
0005434625897	DBE33B	1814 614920	STEPAN KOZLOV	{"phone": "+70983658319"}
0005434625898	DBE33B	9721 777447	VALENTINA MOROZOVA	{"email": "vmorozova.1967@postgrespro.ru", "phone": "+70222224327"}
0005434625899	760F24	4794 266930	OLGA GORBUNOVA	{"email": "ogorbunova.021974@postgrespro.ru", "phone": "+70498267040"}
0005434625900	8DF7AD	3893 723858	GALINA KOLESNIKOVA	{"email": "kolesnikovag.1979@postgrespro.ru", "phone": "+70758531120"}
0005434625901	8DF7AD	6061 941995	EKATERINA VOLKOVA	{"email": "e_volkova_13091961@postgrespro.ru", "phone": "+70469784994"}
0005434625902	211433	4997 611165	LYUDMILA MIKHAYLOVA	{"email": "mikhayloval.051970@postgrespro.ru", "phone": "+70223100019"}
0005434625903	211433	8014 985660	ANZHELIKA VOROBEVA	{"email": "anzhelika-vorobeva041987@postgrespro.ru", "phone": "+70192929249"}
0005434625904	1AA988	3990 322342	VIKTOR DENISOV	{"email": "vdenisov_07011973@postgrespro.ru", "phone": "+70947687192"}
0005434625905	0567A0	3880 299410	ANAIT KULIKOVA	{"email": "kulikova-anait.041973@postgrespro.ru", "phone": "+70318016437"}
0005434625906	F29F7B	3101 432628	OLGA GRISHINA	{"phone": "+70526713046"}
0005434625907	F29F7B	7373 936375	NINA GORBUNOVA	{"email": "ngorbunova071967@postgrespro.ru", "phone": "+70138640063"}
0005434625908	D5506B	3482 027656	VIKTORIYA NAZAROVA	{"phone": "+70874206969"}
0005434625909	A6A4E9	8043 921204	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir_111964@postgrespro.ru", "phone": "+70052122096"}
0005434625910	76DF82	6883 657913	SERGEY FILIPPOV	{"email": "filippov_sergey-121965@postgrespro.ru", "phone": "+70632314206"}
0005434625911	4D1415	4578 742939	ANDREY VOLKOV	{"phone": "+70565134830"}
0005434625912	4D1415	3245 758882	LARISA TARASOVA	{"email": "larisa.tarasova.25081979@postgrespro.ru", "phone": "+70998271972"}
0005434625913	B797B1	2167 282620	GALINA GERASIMOVA	{"email": "gerasimova_galina_1972@postgrespro.ru", "phone": "+70639667631"}
0005434625914	B797B1	0365 597691	ALEKSANDR KISELEV	{"phone": "+70278980799"}
0005434625915	EC7D5E	6763 135962	LYUDMILA ALEKSEEVA	{"phone": "+70095946477"}
0005434625916	0B19CE	5225 500300	SVETLANA KOVALEVA	{"phone": "+70907513588"}
0005434625917	0B19CE	1341 748635	SVETLANA BELOVA	{"email": "belovasvetlana_23061962@postgrespro.ru", "phone": "+70097477307"}
0005434625918	91A6D8	8656 846628	NATALYA STEPANOVA	{"email": "stepanova.n_1981@postgrespro.ru", "phone": "+70799467495"}
0005434625919	91A6D8	7344 902120	RUSTAM IVANOV	{"email": "rustam-ivanov-051988@postgrespro.ru", "phone": "+70471859674"}
0005434625920	B502CB	0814 799803	TATYANA ZHURAVLEVA	{"phone": "+70148166030"}
0005434625921	B502CB	7997 085579	INNA PETROVA	{"email": "i-petrova-01121975@postgrespro.ru", "phone": "+70356003820"}
0005434625922	0311B0	9071 963744	MADINA DMITRIEVA	{"phone": "+70762973333"}
0005434625923	013DD1	1145 210486	ANTONINA PETROVA	{"email": "antonina_petrova.081974@postgrespro.ru", "phone": "+70870566688"}
0005434625924	9591E4	6679 640865	SVETLANA SERGEEVA	{"phone": "+70170183292"}
0005434625925	9BA6DC	1565 970286	SERGEY GUSEV	{"phone": "+70917657693"}
0005434625926	8833C3	2485 325681	ALEKSANDR VASILEV	{"email": "vasilev_aleksandr-051981@postgrespro.ru", "phone": "+70725803817"}
0005434625927	AA41D7	9807 504713	TAMARA ANDREEVA	{"phone": "+70810258135"}
0005434625928	5B677A	5006 428584	IVAN TARASOV	{"phone": "+70527827742"}
0005434625929	29BB7C	9256 567317	MARIYA OSIPOVA	{"phone": "+70080843798"}
0005434625930	90CD2A	3685 768256	NATALYA FOMINA	{"phone": "+70786325289"}
0005434625931	585EC7	2259 444867	ALEKSANDR NAZAROV	{"phone": "+70944267231"}
0005434625932	7BBA9A	9556 954017	EKATERINA TIKHONOVA	{"phone": "+70897059328"}
0005434625933	722A05	9158 309467	ANATOLIY BORISOV	{"email": "borisov.anatoliy_1971@postgrespro.ru", "phone": "+70285433377"}
0005434625934	A3873E	9392 319667	KSENIYA IVANOVA	{"email": "ivanova-kseniya-1977@postgrespro.ru", "phone": "+70368843807"}
0005434625935	A3873E	8043 253104	SVETLANA ANDREEVA	{"phone": "+70014685271"}
0005434625936	DB5300	0294 992695	MARIYA ILINA	{"phone": "+70512708978"}
0005434625937	77AAF3	2944 068736	TATYANA NIKITINA	{"email": "nikitina.t.021981@postgrespro.ru", "phone": "+70946652673"}
0005434625938	77AAF3	3881 472155	BULAT SOLOVEV	{"phone": "+70103042831"}
0005434625939	24C34F	3131 951344	SERGEY MARTYNOV	{"phone": "+70884986600"}
0005434625940	3278D2	2769 949102	NIKOLAY FEDOROV	{"phone": "+70934482275"}
0005434625941	FF6F17	2928 581241	SERGEY VLASOV	{"email": "vlasov_sergey1970@postgrespro.ru", "phone": "+70718454911"}
0005434625942	C46AEF	0522 713523	FEDOR TARASOV	{"email": "tarasov-f30011983@postgrespro.ru", "phone": "+70098065383"}
0005434625943	C46AEF	1570 903347	INNA CHERNOVA	{"phone": "+70073766370"}
0005434625944	451F65	7595 497466	ELENA ALEKSANDROVA	{"email": "aleksandrova-elena-061974@postgrespro.ru", "phone": "+70827091125"}
0005434625945	F5A581	5516 901736	KIRA ROMANOVA	{"phone": "+70679752854"}
0005434625946	FAE2F5	8185 211676	ALEKSEY POPOV	{"email": "popov.aleksey_1986@postgrespro.ru", "phone": "+70958193688"}
0005434625947	C74E9C	2723 713178	PELAGEYA SOLOVEVA	{"phone": "+70023428434"}
0005434625948	C74E9C	4520 580476	ELENA MOROZOVA	{"email": "emorozova04011978@postgrespro.ru", "phone": "+70677741253"}
0005434625949	9BF9F2	8469 390366	MAYYA SEMENOVA	{"email": "mayyasemenova-1968@postgrespro.ru", "phone": "+70143518870"}
0005434625950	9BF9F2	7883 411387	VALENTINA KOMAROVA	{"email": "valentina_komarova-091970@postgrespro.ru", "phone": "+70954229280"}
0005434625951	0CDB8D	7447 313644	ANDREY DMITRIEV	{"phone": "+70467167879"}
0005434625952	91C2D7	3093 842781	NIKOLAY SERGEEV	{"email": "n-sergeev041976@postgrespro.ru", "phone": "+70828970048"}
0005434625953	91C2D7	9974 860580	LYUBOV NIKITINA	{"email": "lyubov-nikitina081961@postgrespro.ru", "phone": "+70750997919"}
0005434625954	91C2D7	5111 331475	VERA MAKAROVA	{"phone": "+70060343787"}
0005434625955	3AAFDF	0512 411795	DENIS ZAKHAROV	{"phone": "+70372189681"}
0005434625956	2219D0	6562 323724	ALEKSEY FEDOTOV	{"phone": "+70892333170"}
0005434625957	BCCA20	6530 870527	ELIZAVETA NOVIKOVA	{"email": "novikovaelizaveta_26121982@postgrespro.ru", "phone": "+70352379814"}
0005434625958	96A7F3	2833 251420	VALENTINA POLYAKOVA	{"phone": "+70574718073"}
0005434625959	B83114	7857 358893	TATYANA DMITRIEVA	{"email": "tatyana_dmitrieva111965@postgrespro.ru", "phone": "+70879320475"}
0005434625960	B83114	5180 904736	VALENTINA NIKOLAEVA	{"phone": "+70904507266"}
0005434625961	ECE9FD	8792 301136	ALEKSANDR ANDREEV	{"phone": "+70862286782"}
0005434625962	ECE9FD	2578 576534	ALINA DENISOVA	{"email": "denisova-a1973@postgrespro.ru", "phone": "+70235387197"}
0005434625963	677ED9	2514 552947	ANATOLIY SEMENOV	{"email": "semenov.anatoliy17061969@postgrespro.ru", "phone": "+70890428842"}
0005434625964	677ED9	3200 482178	NADEZHDA MOROZOVA	{"email": "morozova-nadezhda-011973@postgrespro.ru", "phone": "+70886958823"}
0005434625965	EC3D09	2182 859608	KONSTANTIN BORISOV	{"phone": "+70893907650"}
0005434625966	34E492	9470 800643	LYUBOV KRASNOVA	{"email": "krasnova.lyubov031979@postgrespro.ru", "phone": "+70452508433"}
0005434625967	34E492	6581 029700	IVAN PETROV	{"email": "ipetrov_1974@postgrespro.ru", "phone": "+70178031109"}
0005434625968	A25C8B	7798 220078	ALEKSANDR ZAYCEV	{"email": "zayceva.01041962@postgrespro.ru", "phone": "+70274030341"}
0005434625969	A25C8B	0167 286805	VLADIMIR KISELEV	{"phone": "+70629622034"}
0005434625970	DEE8A8	9511 857619	SVETLANA TROFIMOVA	{"email": "s.trofimova1979@postgrespro.ru", "phone": "+70325424927"}
0005434625971	8D2FD7	2939 954002	SERGEY SOROKIN	{"email": "sergeysorokin.021966@postgrespro.ru", "phone": "+70746096134"}
0005434625972	8D2FD7	4146 174956	TAMARA VASILEVA	{"email": "tamara.vasileva.1970@postgrespro.ru", "phone": "+70226160390"}
0005434625973	BBBEF2	6891 336079	VLADISLAV ALEKSANDROV	{"email": "aleksandrov_v.26101973@postgrespro.ru", "phone": "+70049172281"}
0005434625974	005684	3931 964816	SERGEY AFANASEV	{"phone": "+70492937924"}
0005434625975	005684	4701 081171	ILDUS MAKSIMOV	{"email": "ildus_maksimov_17111980@postgrespro.ru", "phone": "+70005442092"}
0005434625976	2537CD	8669 612791	LYUBOV VASILEVA	{"phone": "+70733619659"}
0005434625977	9996BD	1447 848558	YURIY KARPOV	{"email": "ykarpov_03041958@postgrespro.ru", "phone": "+70054004654"}
0005434625978	E5D08F	6545 549263	YURIY NOVIKOV	{"phone": "+70399773080"}
0005434625979	E5D08F	0036 470264	ANATOLIY POPOV	{"phone": "+70934791839"}
0005434625980	611797	5630 159349	NATALYA SERGEEVA	{"email": "natalya-sergeeva_05121968@postgrespro.ru", "phone": "+70227213707"}
0005434625981	341696	9882 996257	ARKADIY MIKHAYLOV	{"email": "mikhaylov.arkadiy_1985@postgrespro.ru", "phone": "+70097279220"}
0005434625982	1F6415	2715 507677	ELMIRA SIDOROVA	{"phone": "+70942682831"}
0005434625983	BE5FD3	8455 358596	DARYA VOLKOVA	{"email": "volkova-darya-28111972@postgrespro.ru", "phone": "+70549589527"}
0005434625984	739ED8	1028 813223	ANNA GAVRILOVA	{"email": "a-gavrilova121963@postgrespro.ru", "phone": "+70521800235"}
0005434625985	739ED8	6741 255770	NIKITA VOLKOV	{"email": "volkov.nikita.091966@postgrespro.ru", "phone": "+70417539560"}
0005434625986	7C93AC	4687 441592	NINA VLASOVA	{"phone": "+70339940846"}
0005434625987	3D98B3	4769 462236	VLADISLAV MARTYNOV	{"email": "martynov.v.1967@postgrespro.ru", "phone": "+70830940253"}
0005434625988	B9CBFD	6918 965719	ALEKSEY KUZNECOV	{"phone": "+70947522345"}
0005434625989	B9CBFD	3160 859912	YAN VLASOV	{"phone": "+70845891286"}
0005434625990	F983A0	3952 882635	ALEKSEY ZAYCEV	{"email": "zaycev_aleksey_031980@postgrespro.ru", "phone": "+70757620300"}
0005434625991	4A1FEF	8762 108843	ALEKSANDR VASILEV	{"email": "vasileva_121977@postgrespro.ru", "phone": "+70976696919"}
0005434625992	F24CC0	4041 233690	ARTEM SIDOROV	{"email": "a-sidorov101972@postgrespro.ru", "phone": "+70306314571"}
0005434625993	F24CC0	9761 671349	YURIY KRASNOV	{"phone": "+70794410694"}
0005434625994	6E323D	7889 354034	SERGEY FEDOTOV	{"email": "fedotovs051978@postgrespro.ru", "phone": "+70805640921"}
0005434625995	FF62CE	9717 038418	ANATOLIY MIKHAYLOV	{"email": "mikhaylov_anatoliy1977@postgrespro.ru", "phone": "+70093495171"}
0005434625996	FF62CE	1620 452395	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov-121980@postgrespro.ru", "phone": "+70665958123"}
0005434625997	A301FD	4262 955395	ALEKSANDR TARASOV	{"phone": "+70138630641"}
0005434625998	A301FD	8135 734749	VALENTINA ERMAKOVA	{"email": "ermakovavalentina-021967@postgrespro.ru", "phone": "+70134061816"}
0005434625999	A301FD	7654 424573	VALENTINA OSIPOVA	{"email": "vosipova_051973@postgrespro.ru", "phone": "+70630647371"}
0005434626000	205E5C	2277 079581	VLADIMIR SOKOLOV	{"email": "sokolov.vladimir_22111978@postgrespro.ru", "phone": "+70005730097"}
0005434626001	4AC8BC	7027 860060	ALEKSEY NOVIKOV	{"phone": "+70306695461"}
0005434626002	A4F92C	8666 298285	LILIYA ZOTOVA	{"email": "zotova_liliya-03101982@postgrespro.ru", "phone": "+70807251243"}
0005434626003	A4F92C	8584 746658	VYACHESLAV KARPOV	{"phone": "+70879515133"}
0005434626004	94B0FC	2822 272295	OLESYA PETROVA	{"phone": "+70823928799"}
0005434626005	69DED7	9019 789087	DARYA KONOVALOVA	{"phone": "+70976956498"}
0005434626006	364174	4596 814150	ROMAN SOROKIN	{"phone": "+70950577553"}
0005434626007	565356	7257 040389	MIKHAIL FILIPPOV	{"phone": "+70752824089"}
0005434626008	39F28A	3814 910038	YURIY KUZMIN	{"phone": "+70004537431"}
0005434626009	54DED3	7069 415892	YULIYA MIKHAYLOVA	{"email": "yuliyamikhaylova_101963@postgrespro.ru", "phone": "+70953360134"}
0005434626010	B22143	5909 469106	NADEZHDA GRISHINA	{"phone": "+70836707632"}
0005434626011	B22143	8498 294827	NIKOLAY TARASOV	{"email": "tarasov_nikolay.13031993@postgrespro.ru", "phone": "+70841573466"}
0005434626012	4096BF	2008 489358	ANASTASIYA EFIMOVA	{"phone": "+70201012728"}
0005434626013	4096BF	8880 659819	TATYANA KOZLOVA	{"email": "tatyana-kozlova.1971@postgrespro.ru", "phone": "+70279567414"}
0005434626014	376A42	4310 978110	ELENA KARPOVA	{"phone": "+70870121236"}
0005434626015	F9C8A0	3144 022725	EVGENIY SOLOVEV	{"email": "evgeniysolovev-15021972@postgrespro.ru", "phone": "+70067579029"}
0005434626016	F9C8A0	6392 513817	VALENTINA BORISOVA	{"email": "vborisova_1967@postgrespro.ru", "phone": "+70282119631"}
0005434626017	0EE01D	7254 468340	VERA IVANOVA	{"phone": "+70153561548"}
0005434626018	D1F736	4190 402967	RIMMA POPOVA	{"email": "rimma-popova.1978@postgrespro.ru", "phone": "+70123372271"}
0005434626019	D1F736	3034 688279	LUIZA KOMAROVA	{"phone": "+70721289604"}
0005434626020	1CAAE0	8478 120316	RAVIL KOZLOV	{"email": "kozlov_ravil-05091968@postgrespro.ru", "phone": "+70192434993"}
0005434626021	1BA4A8	3394 129503	IRINA PETROVA	{"email": "i_petrova-17051978@postgrespro.ru", "phone": "+70848271410"}
0005434626022	1BA4A8	5979 585130	TALGAT KAZAKOV	{"email": "kazakov.t_1974@postgrespro.ru", "phone": "+70732009286"}
0005434626023	4114DD	9351 561994	MIKHAIL PAVLOV	{"email": "mikhailpavlov.29051968@postgrespro.ru", "phone": "+70718005694"}
0005434626024	4114DD	5986 320333	YURIY NAUMOV	{"phone": "+70990778417"}
0005434626025	80975E	6647 901019	ANATOLIY MOROZOV	{"phone": "+70019503384"}
0005434626026	80975E	7159 174984	ANASTASIYA NESTEROVA	{"email": "anastasiyanesterova26011994@postgrespro.ru", "phone": "+70361909518"}
0005434626027	4ACE0A	8055 701930	ANATOLIY FEDOROV	{"email": "fedorov_anatoliy_1963@postgrespro.ru", "phone": "+70907721887"}
0005434626028	791341	2443 128961	VALENTINA RYABOVA	{"email": "vryabova-061966@postgrespro.ru", "phone": "+70411038419"}
0005434626029	791341	5306 675463	ANTONINA ANDREEVA	{"phone": "+70861249559"}
0005434626030	D1C73E	0136 384500	SERGEY MIRONOV	{"phone": "+70153370324"}
0005434626031	D1C73E	6210 503526	MIKHAIL KARPOV	{"email": "m_karpov_051971@postgrespro.ru", "phone": "+70560375377"}
0005434626032	0C80DF	7712 848242	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova-101969@postgrespro.ru", "phone": "+70481063936"}
0005434626033	F46CF7	8589 931953	LYUBOV NIKOLAEVA	{"email": "nikolaeva_l1968@postgrespro.ru", "phone": "+70319296411"}
0005434626034	F46CF7	2857 640181	STANISLAV MATVEEV	{"email": "matveevstanislav.1956@postgrespro.ru", "phone": "+70865776295"}
0005434626035	B9B5C4	9254 975836	NINA IVANOVA	{"phone": "+70117676899"}
0005434626036	B9B5C4	7158 158784	EVGENIY RODIONOV	{"phone": "+70253414819"}
0005434626037	F74FA0	4163 727832	KSENIYA STEPANOVA	{"email": "stepanova-k_041976@postgrespro.ru", "phone": "+70447255257"}
0005434626038	8D28E8	9690 476372	NINA MOROZOVA	{"email": "morozovan.09061970@postgrespro.ru", "phone": "+70868216341"}
0005434626039	08D30F	5905 997710	PETR MAKAROV	{"phone": "+70585946910"}
0005434626040	38058F	7516 837115	PELAGEYA IVANOVA	{"email": "ivanova.pelageya.20081967@postgrespro.ru", "phone": "+70665833149"}
0005434626041	EB3A55	0031 708317	ALEKSANDR KULIKOV	{"phone": "+70790743586"}
0005434626042	735AEC	6337 413103	MIKHAIL GORBUNOV	{"phone": "+70149624831"}
0005434626043	735AEC	3222 806154	DMITRIY MAKAROV	{"email": "dmitriy_makarov_13101974@postgrespro.ru", "phone": "+70625058440"}
0005434626044	735AEC	5019 795419	TATYANA LOGINOVA	{"email": "tatyana.loginova-051976@postgrespro.ru", "phone": "+70507970517"}
0005434626045	735AEC	2077 616375	LYUBOV BORISOVA	{"phone": "+70299801019"}
0005434626046	9D3A30	3318 859311	ILGIZ KAZAKOV	{"phone": "+70812298970"}
0005434626047	6E1FA2	2981 016064	EDUARD ZAKHAROV	{"email": "eduard_zakharov.1977@postgrespro.ru", "phone": "+70964284037"}
0005434626048	6E1FA2	8295 466183	TATYANA LEBEDEVA	{"phone": "+70824898433"}
0005434626049	64F996	5027 002560	VIKTOR SHEVCHENKO	{"email": "shevchenkov.1979@postgrespro.ru", "phone": "+70466486305"}
0005434626050	64F996	3244 522592	OKSANA RYABOVA	{"phone": "+70164392633"}
0005434626051	1FA14A	0962 150113	VALERIY PAVLOV	{"email": "v_pavlov-23121970@postgrespro.ru", "phone": "+70415574845"}
0005434626052	1FA14A	6841 994904	ANDREY KUZMIN	{"phone": "+70566108419"}
0005434626053	64D2CA	0317 632368	SOFIYA NIKITINA	{"email": "s.nikitina1967@postgrespro.ru", "phone": "+70716014546"}
0005434626054	64D2CA	3738 684778	MIKHAIL KOZLOV	{"phone": "+70980295008"}
0005434626055	64D2CA	1672 437928	SERGEY RODIONOV	{"email": "s-rodionov_111975@postgrespro.ru", "phone": "+70751199802"}
0005434626056	24957E	2055 357475	SVETLANA VASILEVA	{"email": "vasileva.svetlana.031971@postgrespro.ru", "phone": "+70435404289"}
0005434626057	24957E	4423 864216	VYACHESLAV SMIRNOV	{"phone": "+70391299930"}
0005434626058	E00BF3	8741 375895	NINA MAKSIMOVA	{"phone": "+70833243566"}
0005434626059	E00BF3	9813 213813	ANDREY DAVYDOV	{"phone": "+70876099673"}
0005434626060	7F83DC	3993 411305	ILYA ALEKSEEV	{"email": "alekseev-ilya_1980@postgrespro.ru", "phone": "+70816328771"}
0005434626061	E0A2F3	7003 468498	EGOR BONDARENKO	{"phone": "+70096333929"}
0005434626062	E4BBB9	7745 791644	IGOR FROLOV	{"email": "frolov-igor_1978@postgrespro.ru", "phone": "+70108375977"}
0005434626063	053F93	4507 316303	ELENA ABRAMOVA	{"phone": "+70196448218"}
0005434626064	FA03D1	6476 294356	MARIYA AFANASEVA	{"phone": "+70663075256"}
0005434626065	18F0A4	0877 829475	ANNA KONOVALOVA	{"email": "konovalova-a_101981@postgrespro.ru", "phone": "+70811743021"}
0005434626066	039041	2074 877321	VLADISLAV SAVELEV	{"email": "savelevvladislav_1979@postgrespro.ru", "phone": "+70662575547"}
0005434626067	1C28F5	3547 367482	VLADIMIR MATVEEV	{"phone": "+70275882715"}
0005434626068	B36358	2928 488826	ALBINA POLYAKOVA	{"email": "polyakova.albina.121984@postgrespro.ru", "phone": "+70299959763"}
0005434626069	305A22	8957 260170	ELENA POLYAKOVA	{"email": "polyakova_e.111965@postgrespro.ru", "phone": "+70078109608"}
0005434626070	7CF09B	7601 428910	GALINA ANDREEVA	{"email": "g-andreeva-1959@postgrespro.ru", "phone": "+70139230386"}
0005434626071	7CF09B	7617 942602	VLADIMIR KUZNECOV	{"phone": "+70048308721"}
0005434626072	37E181	1371 785576	MARINA TARASOVA	{"email": "tarasovamarina22071971@postgrespro.ru", "phone": "+70023427778"}
0005434626073	37E181	6700 923453	VASILIY POPOV	{"email": "popov_v-07021961@postgrespro.ru", "phone": "+70971900988"}
0005434626074	02D884	2872 353495	VIKTOR NIKOLAEV	{"phone": "+70445577342"}
0005434626075	02D884	0837 930780	EVGENIY KOROLEV	{"phone": "+70691989078"}
0005434626076	83A042	6510 213846	LIDIYA KUZMINA	{"phone": "+70581549682"}
0005434626077	83A042	9798 600421	LYUBOV NOVIKOVA	{"phone": "+70576358102"}
0005434626078	83A042	9381 323631	VALENTINA MOROZOVA	{"phone": "+70234179612"}
0005434626079	20F7CA	5543 826682	ELENA KULIKOVA	{"phone": "+70175196270"}
0005434626080	DE7675	4180 520344	GRIGORIY KOZLOV	{"email": "kozlov-grigoriy.071964@postgrespro.ru", "phone": "+70546532150"}
0005434626081	B008C3	0454 690681	KONSTANTIN KUZNECOV	{"email": "k_kuznecov1983@postgrespro.ru", "phone": "+70237794091"}
0005434626082	B008C3	8046 326982	ELENA TIMOFEEVA	{"email": "elena_timofeeva_1979@postgrespro.ru", "phone": "+70904169482"}
0005434626083	69569E	9480 355648	DMITRIY KONOVALOV	{"email": "dmitriy_konovalov-121972@postgrespro.ru", "phone": "+70646535213"}
0005434626084	29CCCD	1807 506730	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev_021969@postgrespro.ru", "phone": "+70867775245"}
0005434626085	FADF73	2977 548093	SERGEY KUZNECOV	{"email": "kuznecovsergey1973@postgrespro.ru", "phone": "+70448298265"}
0005434626086	56599B	4701 432970	MARINA ROMANOVA	{"phone": "+70251983910"}
0005434626087	B245B4	8604 222376	ANNA MELNIKOVA	{"phone": "+70421485643"}
0005434626088	2EE2A6	4116 677773	EKATERINA IVANOVA	{"email": "e.ivanova20011969@postgrespro.ru", "phone": "+70866558626"}
0005434626089	2EE2A6	8767 193495	IRINA KOROLEVA	{"phone": "+70629113871"}
0005434626090	2EE2A6	4200 939322	VITALIY POPOV	{"phone": "+70954522592"}
0005434626091	69B33D	5716 863130	VIKTOR FEDOROV	{"phone": "+70802871933"}
0005434626092	B8861B	2529 232028	SERGEY GRIGOREV	{"phone": "+70171777874"}
0005434626093	7CACB3	9845 740072	VITALIY MOISEEV	{"email": "moiseev_v_1980@postgrespro.ru", "phone": "+70426442415"}
0005434626094	390E71	8715 742902	NATALYA YAKOVLEVA	{"email": "yakovleva.natalya-13071972@postgrespro.ru", "phone": "+70757089801"}
0005434626095	CA1B6D	5290 271318	NADEZHDA MAKAROVA	{"email": "nadezhda_makarova1975@postgrespro.ru", "phone": "+70288564502"}
0005434626096	6F09FD	5003 471858	TAMARA KOZLOVA	{"email": "t.kozlova_07011976@postgrespro.ru", "phone": "+70600324741"}
0005434626097	292487	6490 128783	YURIY DAVYDOV	{"phone": "+70539976326"}
0005434626098	DD77EE	6071 536155	SERGEY FILIPPOV	{"phone": "+70748929538"}
0005434626099	DD77EE	8627 459332	IVAN BARANOV	{"email": "baranov.i-1981@postgrespro.ru", "phone": "+70531114146"}
0005434626100	DD77EE	2343 040759	ELENA MIRONOVA	{"email": "mironova-e081975@postgrespro.ru", "phone": "+70142352125"}
0005434626101	184733	8601 537702	KAMILA SMIRNOVA	{"phone": "+70499693173"}
0005434626102	1E48F4	3148 863746	TATYANA MELNIKOVA	{"phone": "+70523933231"}
0005434626103	1E48F4	5863 855178	RAVIL SCHERBAKOV	{"email": "scherbakovravil-031973@postgrespro.ru", "phone": "+70378093805"}
0005434626104	1E48F4	2023 201818	VADIM MEDVEDEV	{"email": "medvedev_vadim-1977@postgrespro.ru", "phone": "+70757659227"}
0005434626105	1E48F4	7286 245001	ALEKSANDR POPOV	{"phone": "+70653110376"}
0005434626106	59C160	0663 409148	SERGEY NAZAROV	{"phone": "+70671204457"}
0005434626107	CBB051	0931 841999	ANASTASIYA KOROLEVA	{"phone": "+70731828044"}
0005434626108	CBB051	4980 787166	VERA MARTYNOVA	{"phone": "+70059530776"}
0005434626109	D535A0	1075 045960	ANDREY IVANOV	{"phone": "+70972618451"}
0005434626110	08C048	8698 286589	VALERIY KUZMIN	{"phone": "+70190963880"}
0005434626111	BF0082	5368 245728	ANTONINA VASILEVA	{"email": "antonina.vasileva26021964@postgrespro.ru", "phone": "+70114201499"}
0005434626112	BF0082	6072 656832	ELENA FOMINA	{"email": "elena.fomina041972@postgrespro.ru", "phone": "+70281927208"}
0005434626113	EFB76D	1005 619515	OLESYA FILATOVA	{"phone": "+70564512662"}
0005434626114	EFB76D	9438 456596	ALEKSANDRA ZAYCEVA	{"email": "a_zayceva071975@postgrespro.ru", "phone": "+70360629254"}
0005434626115	CF04B9	3211 292645	ALEKSANDR KISELEV	{"phone": "+70161771286"}
0005434626116	CF04B9	9998 447199	ELENA MOROZOVA	{"phone": "+70861231377"}
0005434626117	5F68F4	5626 076180	DANIL SMIRNOV	{"phone": "+70682311906"}
0005434626118	D1A05E	1698 794152	DARYA IVANOVA	{"email": "darya-ivanova1973@postgrespro.ru", "phone": "+70474158035"}
0005434626119	3B6D8E	9831 033935	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey.1974@postgrespro.ru", "phone": "+70098974614"}
0005434626120	3B6D8E	1656 954383	VALERIY NIKOLAEV	{"email": "nikolaev.v_1973@postgrespro.ru", "phone": "+70788458194"}
0005434626121	DB4CBC	5427 866334	VERA MIKHAYLOVA	{"phone": "+70883907909"}
0005434626122	5D8A06	2419 721523	IRINA MOROZOVA	{"phone": "+70927801386"}
0005434626123	12FE5F	0071 475288	GALINA KALININA	{"email": "galina_kalinina.15101972@postgrespro.ru", "phone": "+70328453083"}
0005434626124	12FE5F	1668 780359	NIKOLAY SOKOLOV	{"phone": "+70037891996"}
0005434626125	D4390D	1714 406930	YANA KOMAROVA	{"email": "yana.komarova.021976@postgrespro.ru", "phone": "+70940986966"}
0005434626126	D4390D	4968 143324	ALEKSANDR SOKOLOV	{"phone": "+70621789273"}
0005434626127	F38070	2071 998803	OLEG ZHUKOV	{"phone": "+70987774495"}
0005434626128	809142	5833 077872	ALIYA KONOVALOVA	{"phone": "+70866260861"}
0005434626129	C6E064	8261 706561	DANIIL KUZMIN	{"email": "dkuzmin-061966@postgrespro.ru", "phone": "+70875990009"}
0005434626130	C6E064	4164 497588	ANTON DAVYDOV	{"email": "davydov-anton12071970@postgrespro.ru", "phone": "+70122940656"}
0005434626131	964DB7	8112 395087	YULIYA SEMENOVA	{"phone": "+70079858701"}
0005434626132	794283	6595 039191	VLADIMIR SOKOLOV	{"phone": "+70666911219"}
0005434626133	794283	6471 771990	YULIYA KOROLEVA	{"phone": "+70280861679"}
0005434626134	7E45E5	6011 998452	NADEZHDA MOISEEVA	{"phone": "+70252384687"}
0005434626135	7E45E5	7674 758144	NADEZHDA NIKOLAEVA	{"phone": "+70302639349"}
0005434626136	A9168A	3141 937688	VITALIY ALEKSEEV	{"phone": "+70058818943"}
0005434626137	2F5E47	4697 191957	NIKOLAY MELNIKOV	{"email": "n_melnikov-101960@postgrespro.ru", "phone": "+70172569746"}
0005434626138	A86330	2668 649028	NIKOLAY KISELEV	{"phone": "+70761894246"}
0005434626139	7B0976	2599 866222	IVAN BARANOV	{"email": "baranovivan121957@postgrespro.ru", "phone": "+70608874294"}
0005434626140	524D2D	6993 916888	ANATOLIY BELOV	{"email": "anatoliy-belov.101970@postgrespro.ru", "phone": "+70387783207"}
0005434626141	524D2D	6839 836251	ARINA SEMENOVA	{"phone": "+70576812157"}
0005434626142	559280	4882 913215	NINA ROMANOVA	{"phone": "+70172199081"}
0005434626143	559280	8986 426251	IRINA LEBEDEVA	{"email": "i_lebedeva1976@postgrespro.ru", "phone": "+70815572319"}
0005434626144	CE2E2F	4204 174160	MARIYA KOVALEVA	{"email": "m_kovaleva_1964@postgrespro.ru", "phone": "+70846351173"}
0005434626145	6CE647	5507 485483	NATALYA FILATOVA	{"email": "n.filatova.051980@postgrespro.ru", "phone": "+70756776764"}
0005434626146	D3DD2F	5878 383496	VLADIMIR CHERNOV	{"email": "v_chernov_02021969@postgrespro.ru", "phone": "+70028385842"}
0005434626147	D3DD2F	8829 273825	MARIYA BOGDANOVA	{"email": "mbogdanova1968@postgrespro.ru", "phone": "+70762098611"}
0005434626148	52C179	1771 027501	OLESYA MAKSIMOVA	{"phone": "+70811991057"}
0005434626149	09EDC4	2733 368955	NATALYA ROMANOVA	{"phone": "+70199512703"}
0005434626150	9C9557	8943 481625	DMITRIY SHEVCHENKO	{"phone": "+70368108942"}
0005434626151	9C9557	7466 361537	SERGEY NOVIKOV	{"email": "novikov-sergey-06071980@postgrespro.ru", "phone": "+70186489211"}
0005434626152	55CC15	2882 909354	IRINA NIKIFOROVA	{"phone": "+70911467480"}
0005434626153	6C0E20	1928 797497	IGOR SEMENOV	{"email": "semenov-igor.061976@postgrespro.ru", "phone": "+70050012107"}
0005434626214	D4A45B	9629 775434	TATYANA NIKOLAEVA	{"phone": "+70922634542"}
0005434626154	A8EB58	9691 265519	SERGEY KRASNOV	{"email": "sergey-krasnov.06121969@postgrespro.ru", "phone": "+70062504874"}
0005434626155	4B0B02	0613 238556	ZHANNA AFANASEVA	{"phone": "+70258933956"}
0005434626156	4671E6	4541 652993	VALERIY DMITRIEV	{"email": "dmitriev_v101977@postgrespro.ru", "phone": "+70406829636"}
0005434626157	189CE9	4974 314519	IRINA KISELEVA	{"email": "ikiseleva.04041975@postgrespro.ru", "phone": "+70857333776"}
0005434626158	189CE9	4922 237965	MARIYA NIKOLAEVA	{"email": "nikolaevam1974@postgrespro.ru", "phone": "+70780072329"}
0005434626159	D2D4F9	1651 728236	VYACHESLAV YAKOVLEV	{"email": "yakovlev-v1971@postgrespro.ru", "phone": "+70231640622"}
0005434626160	8E8680	3119 155908	DENIS KRASNOV	{"phone": "+70660350189"}
0005434626161	15FFB2	3632 287383	ALLA RYABOVA	{"phone": "+70859543928"}
0005434626162	15FFB2	0447 886315	TIGRAN OSIPOV	{"email": "tigran-osipov.1973@postgrespro.ru", "phone": "+70460557061"}
0005434626163	15FFB2	5332 962820	YURIY FILIPPOV	{"email": "y.filippov05081980@postgrespro.ru", "phone": "+70867051520"}
0005434626164	D8A4B6	5401 010365	SERGEY CHERNOV	{"email": "chernovs-17071962@postgrespro.ru", "phone": "+70963111115"}
0005434626165	D8A4B6	0029 033365	ELENA ORLOVA	{"email": "e_orlova_011976@postgrespro.ru", "phone": "+70507634072"}
0005434626166	5275D7	6536 075285	VIKTORIYA FOMINA	{"email": "v.fomina_22081969@postgrespro.ru", "phone": "+70531743313"}
0005434626167	F5D7FA	7980 276526	ALEKSANDR TIMOFEEV	{"phone": "+70274110510"}
0005434626168	BE8516	1228 688714	ALEVTINA FEDOROVA	{"phone": "+70637192628"}
0005434626169	2A6003	8298 226916	VALERIYA GERASIMOVA	{"phone": "+70289700965"}
0005434626170	1BB9EB	2171 441508	ARTEM MIKHAYLOV	{"phone": "+70803168037"}
0005434626171	1BB9EB	6532 353460	VLADIMIR KAZAKOV	{"email": "vladimir_kazakov_041978@postgrespro.ru", "phone": "+70069243330"}
0005434626172	4AA88C	1630 465928	NINA SERGEEVA	{"phone": "+70721942404"}
0005434626173	D01BC6	8412 759131	ALEKSANDR MOROZOV	{"email": "a.morozov1970@postgrespro.ru", "phone": "+70793058617"}
0005434626174	D01BC6	2204 745730	ANDREY EGOROV	{"email": "egorovandrey.29061973@postgrespro.ru", "phone": "+70311285394"}
0005434626175	245E2E	0588 761385	TATYANA SMIRNOVA	{"email": "tatyanasmirnova_011973@postgrespro.ru", "phone": "+70927895392"}
0005434626176	09C97F	8477 154677	LIDIYA KUZMINA	{"phone": "+70936239344"}
0005434626177	09C97F	8554 992116	ARTEM KARPOV	{"email": "karpov.artem-061967@postgrespro.ru", "phone": "+70784756338"}
0005434626178	09C97F	6723 745419	LYUDMILA YUDINA	{"phone": "+70895071818"}
0005434626179	832736	9080 615711	SERGEY DENISOV	{"phone": "+70766683544"}
0005434626180	4C0406	7289 876775	DMITRIY PETROV	{"phone": "+70244461152"}
0005434626181	4C0406	3926 085206	TATYANA MAKAROVA	{"phone": "+70418480622"}
0005434626182	6328CA	6809 126101	VLADIMIR NAUMOV	{"phone": "+70215066644"}
0005434626183	6328CA	5881 967053	ELENA LUKYANOVA	{"email": "lukyanovaelena_25041980@postgrespro.ru", "phone": "+70231605297"}
0005434626184	4270BC	4290 219118	ALINA NIKITINA	{"phone": "+70209166153"}
0005434626185	4270BC	6427 316142	VALENTINA TIKHONOVA	{"phone": "+70159070519"}
0005434626186	5D72B9	9386 287338	MAKSIM MOROZOV	{"email": "morozov_maksim_01061984@postgrespro.ru", "phone": "+70290381049"}
0005434626187	5D72B9	6720 933837	VLADIMIR FEDOROV	{"email": "fedorov-vladimir121967@postgrespro.ru", "phone": "+70690185468"}
0005434626188	E9CC31	4783 291627	YURIY SAVELEV	{"email": "yuriy_savelev1963@postgrespro.ru", "phone": "+70714010467"}
0005434626189	E9CC31	8715 977801	OLGA NESTEROVA	{"phone": "+70259261800"}
0005434626190	7B5B47	7011 954221	TATYANA IVANOVA	{"email": "t_ivanova.1977@postgrespro.ru", "phone": "+70551462059"}
0005434626191	7B5B47	8379 568988	EVGENIY KUDRYASHOV	{"phone": "+70387257514"}
0005434626192	7B5B47	7398 599341	ALEKSANDRA MARTYNOVA	{"phone": "+70452540045"}
0005434626193	44144F	5812 550700	DMITRIY KUZMIN	{"email": "kuzmind.101978@postgrespro.ru", "phone": "+70937552470"}
0005434626194	44144F	3787 436956	ALIYA MEDVEDEVA	{"email": "medvedeva-aliya-081960@postgrespro.ru", "phone": "+70930057357"}
0005434626195	83B51C	3708 988118	IVAN FEDOROV	{"email": "fedorov_ivan031985@postgrespro.ru", "phone": "+70403706260"}
0005434626196	83B51C	2665 878683	PETR ZAKHAROV	{"email": "petr-zakharov-24061961@postgrespro.ru", "phone": "+70605289252"}
0005434626197	EE8F86	5462 422134	ALEKSEY TARASOV	{"email": "aleksey.tarasov021982@postgrespro.ru", "phone": "+70756150087"}
0005434626198	FA368A	6134 083700	IGOR BELOV	{"email": "i-belov.1976@postgrespro.ru", "phone": "+70674114443"}
0005434626199	BA1166	5619 684417	DMITRIY SHEVCHENKO	{"phone": "+70601570686"}
0005434626200	E8CAD0	7051 784698	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr_101951@postgrespro.ru", "phone": "+70987586611"}
0005434626201	45B2EB	3447 179206	SERGEY ANDREEV	{"email": "s.andreev-1953@postgrespro.ru", "phone": "+70038093151"}
0005434626202	A23FE9	2649 878602	NATALYA DAVYDOVA	{"phone": "+70804747707"}
0005434626203	A23FE9	1728 101146	ALEKSANDRA STEPANOVA	{"phone": "+70447904007"}
0005434626204	A23FE9	0609 933764	DARYA GAVRILOVA	{"phone": "+70837533320"}
0005434626205	A23FE9	4329 691656	ROMAN KUZNECOV	{"phone": "+70429817221"}
0005434626206	663822	0299 086857	ALEKSANDR KUZNECOV	{"email": "a_kuznecov-121971@postgrespro.ru", "phone": "+70470630402"}
0005434626207	4A5862	8009 846340	MIKHAIL DAVYDOV	{"email": "davydovm-15091979@postgrespro.ru", "phone": "+70864180382"}
0005434626208	4A5862	1643 855807	OLEG ALEKSANDROV	{"phone": "+70883610252"}
0005434626209	A46F00	4797 258808	RUSHANIYA RYABOVA	{"phone": "+70572774594"}
0005434626210	57B3E6	6764 926964	IRINA IVANOVA	{"phone": "+70001475113"}
0005434626211	B22B76	0214 898219	IVAN BORISOV	{"email": "i_borisov-1963@postgrespro.ru", "phone": "+70733180694"}
0005434626212	B22B76	5300 743018	VLADIMIR OSIPOV	{"email": "osipov_vladimir-041959@postgrespro.ru", "phone": "+70586366980"}
0005434626213	07A258	5355 687413	ALENA DANILOVA	{"phone": "+70668872157"}
0005434626215	D4A45B	8554 413612	ALEKSANDR RODIONOV	{"email": "a.rodionov_041988@postgrespro.ru", "phone": "+70973993126"}
0005434626216	E7C57F	1311 088688	RUSLAN PETROV	{"phone": "+70738234666"}
0005434626217	941039	1139 164514	VLADISLAV KONOVALOV	{"phone": "+70755775619"}
0005434626218	941039	0899 206493	ROMAN SHEVCHENKO	{"phone": "+70093865622"}
0005434638945	239BF4	5359 771249	VALERIY ZAKHAROV	{"phone": "+70940716237"}
0005434626219	941039	8613 264137	ELENA NIKOLAEVA	{"email": "elena-nikolaeva-11081972@postgrespro.ru", "phone": "+70359288694"}
0005434626220	E0D655	0715 860680	MIKHAIL PETROV	{"email": "mpetrov-1967@postgrespro.ru", "phone": "+70729658087"}
0005434626221	4C0BE6	7631 339043	VALENTIN SOROKIN	{"phone": "+70629700397"}
0005434626222	4C0BE6	5809 785421	SHAMIL FILIPPOV	{"email": "filippov-s21111981@postgrespro.ru", "phone": "+70133258379"}
0005434626223	403FC4	8788 787608	EVDOKIYA MOROZOVA	{"phone": "+70093612239"}
0005434626224	214F9E	9570 021280	KRISTINA SMIRNOVA	{"phone": "+70364470980"}
0005434626225	214F9E	4525 321130	SERGEY KUZNECOV	{"email": "s-kuznecov.1969@postgrespro.ru", "phone": "+70573456978"}
0005434626226	F5B7B2	8253 465336	IVAN BELOV	{"phone": "+70011783151"}
0005434626227	F5B7B2	4044 638536	VYACHESLAV KUZNECOV	{"email": "kuznecovvyacheslav.031973@postgrespro.ru", "phone": "+70316526413"}
0005434626228	8B286E	0512 982063	EVGENIY FEDOROV	{"email": "fedorov_evgeniy31071969@postgrespro.ru", "phone": "+70524221988"}
0005434626229	8B286E	7551 016685	ANDREY RODIONOV	{"phone": "+70619024736"}
0005434626230	40822D	2039 754314	SVETLANA SOKOLOVA	{"phone": "+70257653720"}
0005434626231	40822D	0654 078791	SERGEY KONOVALOV	{"email": "konovalov_sergey-1970@postgrespro.ru", "phone": "+70171052878"}
0005434626232	86FEFC	2503 255095	LILIYA EFREMOVA	{"phone": "+70954180704"}
0005434626233	86FEFC	7599 796541	VIKTORIYA MAKAROVA	{"phone": "+70539460934"}
0005434626234	14E8E8	9696 953292	EGOR NIKITIN	{"phone": "+70966312949"}
0005434626235	71903A	0214 765664	YAROSLAV SEMENOV	{"email": "yaroslavsemenov_13011970@postgrespro.ru", "phone": "+70551280907"}
0005434626236	896FF4	7609 782130	TATYANA SEMENOVA	{"email": "semenovat.031974@postgrespro.ru", "phone": "+70155742016"}
0005434626237	5763BC	0852 852097	NATALYA KUZNECOVA	{"email": "kuznecova_n14081969@postgrespro.ru", "phone": "+70833494526"}
0005434626238	2134FB	6194 598274	NATALYA ZAKHAROVA	{"phone": "+70055477905"}
0005434626239	EC6E37	1808 784449	VASILIY TARASOV	{"email": "vasiliy.tarasov-06051963@postgrespro.ru", "phone": "+70823371035"}
0005434626240	EC6E37	5219 273422	SERGEY IVANOV	{"email": "ivanovs.27121970@postgrespro.ru", "phone": "+70658790771"}
0005434638914	BBB7EB	0198 253078	LYUDMILA SMIRNOVA	{"phone": "+70765336155"}
0005434638915	2F03EE	8379 613272	ALEKSEY NAZAROV	{"phone": "+70913381043"}
0005434638846	AD895C	0044 148712	ALEKSANDR FOMIN	{"phone": "+70705845593"}
0005434638847	AD895C	1688 256231	SERGEY DENISOV	{"phone": "+70783195417"}
0005434638848	F83D46	9312 579917	RUSLAN FEDOROV	{"phone": "+70860354450"}
0005434638849	F92342	8531 003163	YURIY ABRAMOV	{"phone": "+70991892492"}
0005434638850	7A9434	4125 002186	ANTONIDA BELYAEVA	{"phone": "+70838014642"}
0005434638851	CFA214	5456 637006	NADEZHDA TARASOVA	{"email": "ntarasova.23071970@postgrespro.ru", "phone": "+70703080122"}
0005434638852	AD9731	6977 235852	YURIY SMIRNOV	{"email": "smirnov-y.03121983@postgrespro.ru", "phone": "+70148846828"}
0005434638853	AD9731	9911 007555	DMITRIY KAZAKOV	{"phone": "+70111692731"}
0005434638854	59D048	1336 969736	ANASTASIYA ANDREEVA	{"email": "a-andreeva_1972@postgrespro.ru", "phone": "+70065653761"}
0005434638855	EF8D55	2979 278779	ANTONINA NESTEROVA	{"email": "antonina-nesterova_06081975@postgrespro.ru", "phone": "+70105705247"}
0005434638856	7AD3B3	6444 795740	OLGA IVANOVA	{"phone": "+70781904025"}
0005434638857	6AA00D	8911 712348	ALEKSEY FEDOROV	{"email": "fedorov.aleksey.30061959@postgrespro.ru", "phone": "+70150301054"}
0005434638858	6AA00D	4534 238696	IRINA ALEKSEEVA	{"email": "ialekseeva071980@postgrespro.ru", "phone": "+70249503694"}
0005434638859	97726A	1472 906406	NINA POLYAKOVA	{"phone": "+70016253290"}
0005434638860	E40D36	3372 442000	YULIYA FILIPPOVA	{"phone": "+70255956312"}
0005434638861	56DA5E	8771 710440	ALEKSANDR MOISEEV	{"phone": "+70814893541"}
0005434638862	494DFC	0351 821546	VALERIY ZHURAVLEV	{"email": "valeriy-zhuravlev_1977@postgrespro.ru", "phone": "+70485266101"}
0005434638863	90295D	7275 310480	LYUDMILA TITOVA	{"phone": "+70924345870"}
0005434638864	41B6DC	4744 612118	TATYANA SERGEEVA	{"email": "tsergeeva-1962@postgrespro.ru", "phone": "+70600047867"}
0005434638865	E78968	5972 151157	NINA GUSEVA	{"phone": "+70719768452"}
0005434638866	2E8DEA	5572 741632	OLEG TARASOV	{"phone": "+70661829384"}
0005434638867	D611EC	9547 725935	SVETLANA KUZNECOVA	{"phone": "+70530546239"}
0005434638868	D611EC	5244 672241	VLADISLAV NOVIKOV	{"phone": "+70078840872"}
0005434638869	D611EC	4348 964123	VIKTOR KUZMIN	{"phone": "+70810585110"}
0005434638870	2473CD	3775 581843	ALEKSEY STEPANOV	{"phone": "+70006903010"}
0005434638871	2473CD	0137 714736	ALIK TIKHONOV	{"email": "tikhonov-a-101976@postgrespro.ru", "phone": "+70675318901"}
0005434638872	63565E	8260 609412	VALENTINA BORISOVA	{"email": "v.borisova_30051960@postgrespro.ru", "phone": "+70655256654"}
0005434638873	63565E	8543 820825	YULIYA AFANASEVA	{"phone": "+70800516550"}
0005434638874	4FDC18	7904 310628	MATVEY MOISEEV	{"email": "moiseev_matvey101964@postgrespro.ru", "phone": "+70923749399"}
0005434638875	4FDC18	9690 858222	OLGA SERGEEVA	{"email": "sergeeva-olga_09101977@postgrespro.ru", "phone": "+70394366234"}
0005434638876	649A55	0291 447869	GENNADIY BORISOV	{"email": "borisov-g101970@postgrespro.ru", "phone": "+70651440938"}
0005434638877	153C77	0025 685904	EVGENIYA MELNIKOVA	{"email": "e.melnikova_1970@postgrespro.ru", "phone": "+70715838330"}
0005434638878	08BE0F	6636 397637	NIKITA SIDOROV	{"email": "sidorov-n_1969@postgrespro.ru", "phone": "+70368582065"}
0005434638879	FEE267	3126 620419	MARIYA FROLOVA	{"email": "frolova-mariya-1971@postgrespro.ru", "phone": "+70612924792"}
0005434638880	C8B7F3	5594 820698	ALEKSANDR KOROLEV	{"phone": "+70515852795"}
0005434638881	958C5C	1582 509975	NINA ZAYCEVA	{"email": "nina_zayceva.06111964@postgrespro.ru", "phone": "+70785056856"}
0005434638882	958C5C	2575 551441	TAMARA DMITRIEVA	{"phone": "+70896812933"}
0005434638883	35FC61	9564 135394	TATYANA MAKAROVA	{"email": "t-makarova.1985@postgrespro.ru", "phone": "+70890866338"}
0005434638884	35FC61	9620 265927	ELENA ZAYCEVA	{"phone": "+70820893234"}
0005434638885	0433C2	7784 840962	SVETLANA KUZMINA	{"email": "skuzmina_1967@postgrespro.ru", "phone": "+70651031455"}
0005434638886	0433C2	0059 460428	VLADIMIR MAKAROV	{"phone": "+70219246080"}
0005434638887	0433C2	7138 345900	EVGENIY NOVIKOV	{"email": "novikovevgeniy21031984@postgrespro.ru", "phone": "+70299713882"}
0005434638888	D8A77F	6521 225406	IREK SOKOLOV	{"phone": "+70447179920"}
0005434638889	AA7B32	1840 163338	ANNA PETROVA	{"email": "petrovaanna-021977@postgrespro.ru", "phone": "+70230991103"}
0005434638890	E225FF	9514 216025	ZAKHAR ALEKSANDROV	{"email": "aleksandrovzakhar.081978@postgrespro.ru", "phone": "+70648694168"}
0005434638891	1DDA30	2203 399913	NINA FILATOVA	{"phone": "+70217028372"}
0005434638892	1DDA30	7802 545959	VADIM NIKOLAEV	{"email": "vnikolaev-24031978@postgrespro.ru", "phone": "+70469348501"}
0005434638893	24683E	6608 762010	MARINA LAZAREVA	{"email": "lazarevamarina-1977@postgrespro.ru", "phone": "+70646519839"}
0005434638894	63FA50	6212 858755	TATYANA ROMANOVA	{"email": "tatyana-romanova.1998@postgrespro.ru", "phone": "+70074564894"}
0005434638895	7ED4BC	8784 298315	MAKSIM BONDARENKO	{"email": "mbondarenko.071969@postgrespro.ru", "phone": "+70430156585"}
0005434638896	7ED4BC	9725 421692	SERGEY ZHUKOV	{"email": "zhukov-s.061985@postgrespro.ru", "phone": "+70414723423"}
0005434638897	97EA51	0487 832244	ALEKSANDR TIMOFEEV	{"email": "aleksandr-timofeev.1984@postgrespro.ru", "phone": "+70953202889"}
0005434638898	EFE8E9	5256 522636	VALERIYA RYABOVA	{"phone": "+70555373608"}
0005434638899	BB841E	0335 185245	ILYA ALEKSANDROV	{"email": "aleksandrovi_18011969@postgrespro.ru", "phone": "+70862324703"}
0005434638900	BB841E	9461 799382	TATYANA GUSEVA	{"email": "guseva_tatyana_11101985@postgrespro.ru", "phone": "+70260023121"}
0005434638901	13FFD1	4252 994625	ANDREY SAVELEV	{"email": "andrey-savelev-051977@postgrespro.ru", "phone": "+70964294657"}
0005434638902	BD1B06	1139 721318	LYUDMILA POTAPOVA	{"phone": "+70778130310"}
0005434638903	FD8189	6558 891219	LYUBOV STEPANOVA	{"email": "stepanovalyubov_09041972@postgrespro.ru", "phone": "+70009569569"}
0005434638904	FD8189	5589 505741	ALEKSANDR DMITRIEV	{"phone": "+70123913078"}
0005434638905	F0F73B	1923 738612	VLADIMIR KUDRYASHOV	{"email": "v_kudryashov-18031974@postgrespro.ru", "phone": "+70364265144"}
0005434638906	E4B703	6136 046262	ANTONINA FEDOROVA	{"email": "fedorova.antonina29051969@postgrespro.ru", "phone": "+70337890836"}
0005434638907	A0C15E	9686 244605	TATYANA KARPOVA	{"phone": "+70451541368"}
0005434638908	8E5DA8	1877 280681	ELENA ZAKHAROVA	{"phone": "+70495122562"}
0005434638909	682EAF	3254 944127	ANASTASIYA DANILOVA	{"phone": "+70700855392"}
0005434638910	682EAF	6896 460346	IRINA BOGDANOVA	{"phone": "+70106589068"}
0005434638911	1431A4	7309 753310	DIANA ANTONOVA	{"email": "diana-antonova1969@postgrespro.ru", "phone": "+70692067777"}
0005434638912	1431A4	4364 289239	TATYANA ISAEVA	{"phone": "+70903782215"}
0005434638913	BBB7EB	1622 046111	VYACHESLAV VASILEV	{"email": "vasilev-vyacheslav-1974@postgrespro.ru", "phone": "+70628646176"}
0005434638916	3BD5BD	0322 596466	OLGA VLASOVA	{"phone": "+70445125134"}
0005434638917	3BD5BD	1671 201970	FATIMA FEDOROVA	{"email": "f-fedorova_1971@postgrespro.ru", "phone": "+70187696829"}
0005434638918	8155D5	0060 585442	RAISA TIMOFEEVA	{"email": "timofeeva.raisa15011964@postgrespro.ru", "phone": "+70296999116"}
0005434638919	CBA3A8	2360 942921	NINA KALININA	{"phone": "+70926325843"}
0005434638920	CB32EB	2072 327119	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr_091980@postgrespro.ru", "phone": "+70265292606"}
0005434638921	CB32EB	1579 128161	IGOR KRASNOV	{"phone": "+70971469936"}
0005434638922	348935	1128 362557	NADEZHDA IVANOVA	{"phone": "+70531612796"}
0005434638923	348935	7916 795808	VALERIY YAKOVLEV	{"email": "v_yakovlev10021965@postgrespro.ru", "phone": "+70588135280"}
0005434638924	793F4D	7604 770117	YURIY FILIPPOV	{"email": "filippov_yuriy.121970@postgrespro.ru", "phone": "+70777075268"}
0005434638925	CED402	8946 024074	ILYA ALEKSANDROV	{"email": "aleksandrov_i1975@postgrespro.ru", "phone": "+70237833634"}
0005434638926	147B09	0057 916161	EVGENIY MAKSIMOV	{"email": "emaksimov_31081969@postgrespro.ru", "phone": "+70153156983"}
0005434638927	B1534C	0811 556796	VIKTOR MAKSIMOV	{"email": "maksimovv.071979@postgrespro.ru", "phone": "+70667492691"}
0005434638928	405533	5230 965009	ALEKSANDR GERASIMOV	{"phone": "+70951358102"}
0005434638929	405533	1746 353927	ANDREY ALEKSANDROV	{"phone": "+70772876723"}
0005434638930	72C5F1	4123 801004	EVGENIY ROMANOV	{"email": "romanove20111970@postgrespro.ru", "phone": "+70322139234"}
0005434638931	A378A7	0389 015469	EKATERINA EGOROVA	{"email": "egorova.ekaterina25121973@postgrespro.ru", "phone": "+70120877824"}
0005434638932	C97AD3	5289 143561	LIDIYA GAVRILOVA	{"phone": "+70736386111"}
0005434638933	452B3F	1371 408878	LYUBOV MEDVEDEVA	{"email": "l.medvedeva-061972@postgrespro.ru", "phone": "+70333117053"}
0005434638934	139E9B	5659 478721	EKATERINA SCHERBAKOVA	{"phone": "+70166390422"}
0005434638935	139E9B	9706 174364	NIKOLAY FEDOROV	{"phone": "+70890415716"}
0005434638936	00D8D3	2698 870150	EDUARD ABRAMOV	{"phone": "+70329514135"}
0005434638937	38A445	3282 812636	VLADIMIR KUZMIN	{"phone": "+70249488344"}
0005434638938	38A445	7029 020714	VIKTORIYA SERGEEVA	{"phone": "+70051072387"}
0005434638939	3C214F	3274 134193	SERGEY DAVYDOV	{"email": "s.davydov-1972@postgrespro.ru", "phone": "+70861856217"}
0005434638940	C846F8	1925 552731	NIKOLAY IVANOV	{"phone": "+70891140348"}
0005434638941	67BBCE	2009 863877	MARIYA ABRAMOVA	{"phone": "+70481744210"}
0005434638942	307B26	8287 992490	NADEZHDA KOMAROVA	{"phone": "+70697065933"}
0005434638943	307B26	0365 114361	VLADIMIR KUZNECOV	{"phone": "+70926556756"}
0005434638944	239BF4	1698 000511	YULIYA IVANOVA	{"phone": "+70798733914"}
0005434638946	A23D50	1739 289910	LARISA MASLOVA	{"email": "maslova_l_20101965@postgrespro.ru", "phone": "+70082667854"}
0005434638947	1F0F4E	3434 770551	YURIY IVANOV	{"phone": "+70943921569"}
0005434638948	9E4BF7	6402 193211	EKATERINA ANTONOVA	{"email": "antonova-e-031965@postgrespro.ru", "phone": "+70767870025"}
0005434638949	D1C3D1	7943 760506	OLGA ABRAMOVA	{"phone": "+70794263909"}
0005434638950	28E48A	9982 947159	ANNA YAKOVLEVA	{"email": "a-yakovleva071968@postgrespro.ru", "phone": "+70446270957"}
0005434638951	28E48A	4425 667848	NADEZHDA ZAKHAROVA	{"email": "zakharova.n-1975@postgrespro.ru", "phone": "+70627456814"}
0005434638952	D4ECED	9025 848127	LYUDMILA ISAEVA	{"email": "isaeva-l101973@postgrespro.ru", "phone": "+70849946728"}
0005434638953	D4ECED	9198 803037	ALEKSANDR MATVEEV	{"email": "matveev.a13051960@postgrespro.ru", "phone": "+70365999059"}
0005434638954	FA87F8	5386 076170	PAVEL ALEKSEEV	{"phone": "+70171418821"}
0005434638955	B48708	0049 581641	RAFAIL KONOVALOV	{"email": "konovalov_rafail_011975@postgrespro.ru", "phone": "+70058261374"}
0005434638956	DE00CB	2126 363804	ANASTASIYA DANILOVA	{"email": "danilova_anastasiya03101976@postgrespro.ru", "phone": "+70463663385"}
0005434638957	3D832E	6118 249561	IVAN KOZLOV	{"phone": "+70244727716"}
0005434638958	3D832E	1640 063285	SERGEY ZAYCEV	{"email": "szaycev1977@postgrespro.ru", "phone": "+70744896174"}
0005434638959	3D832E	4233 030541	SVETLANA MIKHAYLOVA	{"email": "svetlana.mikhaylova081961@postgrespro.ru", "phone": "+70045099084"}
0005434638960	BC419E	2522 439121	EKATERINA MARTYNOVA	{"email": "martynova.e-081981@postgrespro.ru", "phone": "+70546448457"}
0005434638961	BC419E	2549 453325	OLGA YUDINA	{"phone": "+70177729186"}
0005434638962	9A5F8A	9108 057052	YAROSLAV MIRONOV	{"phone": "+70412560047"}
0005434638963	9A5F8A	6826 066973	ALISA BORISOVA	{"phone": "+70966701444"}
0005434638964	577F0E	6819 824117	GALINA SOKOLOVA	{"email": "g-sokolova.1982@postgrespro.ru", "phone": "+70848012134"}
0005434638965	F61FDB	5048 341790	VYACHESLAV ALEKSEEV	{"email": "v.alekseev-1983@postgrespro.ru", "phone": "+70670169879"}
0005434638966	F61FDB	8492 064905	ALEKSANDR FEDOTOV	{"email": "fedotov-a-15091982@postgrespro.ru", "phone": "+70646437912"}
0005434638967	AF5490	3237 595847	ALEKSANDR KRASNOV	{"phone": "+70095624953"}
0005434638968	D0E67F	3457 158214	YURIY TARASOV	{"email": "yuriytarasov031982@postgrespro.ru", "phone": "+70133090405"}
0005434638969	70F003	0125 104057	NATALYA ROMANOVA	{"phone": "+70503482468"}
0005434638970	142290	7935 516953	TATYANA ILINA	{"email": "tatyana.ilina1967@postgrespro.ru", "phone": "+70352837093"}
0005434638971	BA7FF3	7163 592358	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey26111972@postgrespro.ru", "phone": "+70901102280"}
0005434638972	F1A3F9	0838 945872	GENNADIY EGOROV	{"email": "g.egorov071967@postgrespro.ru", "phone": "+70155785834"}
0005434638973	F1A3F9	2034 822002	TAMARA AKIMOVA	{"email": "akimova.t.041975@postgrespro.ru", "phone": "+70101816854"}
0005434638974	F1A3F9	3369 913151	VALENTINA ANDREEVA	{"phone": "+70828764629"}
0005434638975	6DB10E	2086 865614	RUSTAM PAVLOV	{"email": "rpavlov.1968@postgrespro.ru", "phone": "+70698091405"}
0005434638976	848F86	4101 912853	IVAN MAKAROV	{"email": "makarov_i1969@postgrespro.ru", "phone": "+70884414737"}
0005434638977	B28DD5	7996 906121	IVAN IVANOV	{"email": "ivanov-ivan_1966@postgrespro.ru", "phone": "+70691063099"}
0005434638978	C790AB	4908 954961	SOFIYA AFANASEVA	{"email": "afanasevas.101973@postgrespro.ru", "phone": "+70212278682"}
0005434638979	ADE1E2	5714 767438	DANIIL FROLOV	{"email": "frolov-d.1982@postgrespro.ru", "phone": "+70613108166"}
0005434638980	D21181	2815 720684	ILYA MEDVEDEV	{"email": "ilya-medvedev_041968@postgrespro.ru", "phone": "+70788021231"}
0005434638981	A5A08C	9955 715532	ALEKSANDR KUZMIN	{"phone": "+70749358251"}
0005434638982	10AED6	3748 693719	ANTONINA VOLKOVA	{"phone": "+70575892180"}
0005434638983	19C880	0966 338370	ANTONINA KONOVALOVA	{"phone": "+70032228823"}
0005434638984	19C880	0961 395826	OLGA POLYAKOVA	{"email": "olga.polyakova.1973@postgrespro.ru", "phone": "+70549935330"}
0005434638985	66CE34	0963 668595	ANATOLIY VOLKOV	{"email": "a.volkov-1977@postgrespro.ru", "phone": "+70346794867"}
0005434638986	4EAACF	2248 548943	NATALYA ZHURAVLEVA	{"email": "natalya-zhuravleva17111975@postgrespro.ru", "phone": "+70453448145"}
0005434638987	4EAACF	5276 179386	IRINA ZAKHAROVA	{"email": "zakharova.i-081983@postgrespro.ru", "phone": "+70080238962"}
0005434638988	D83CD3	0256 089097	VLADIMIR SMIRNOV	{"phone": "+70862253592"}
0005434638989	D83CD3	1744 392331	YURIY VOLKOV	{"email": "yvolkov-061971@postgrespro.ru", "phone": "+70023742433"}
0005434638990	C6058E	3749 094036	EVGENIY NIKITIN	{"phone": "+70411628173"}
0005434638991	985ED7	3622 117478	YULIYA MAKAROVA	{"phone": "+70390520619"}
0005434638992	985ED7	8647 598774	NATALYA GAVRILOVA	{"email": "gavrilova-natalya-30041974@postgrespro.ru", "phone": "+70948598405"}
0005434638993	CDB5EC	0054 742122	VLADIMIR PETROV	{"phone": "+70623666346"}
0005434638994	7B8B21	5497 338305	DENIS KONOVALOV	{"phone": "+70869902117"}
0005434638995	B7D6DD	7872 051105	ALEKSEY PETROV	{"email": "aleksey_petrov-1969@postgrespro.ru", "phone": "+70265736175"}
0005434638996	B7D6DD	3179 546782	ANDREY IVANOV	{"phone": "+70771385156"}
0005434638997	F1CC35	4920 938778	LIDIYA ZHUKOVA	{"email": "zhukovalidiya.11021965@postgrespro.ru", "phone": "+70492576351"}
0005434638998	F1CC35	3427 011606	ALENA CHERNOVA	{"phone": "+70871289618"}
0005434638999	C161B3	0518 797092	ARINA SMIRNOVA	{"phone": "+70525178815"}
0005434639000	273882	2076 319978	BORIS KUZNECOV	{"email": "kuznecovboris-111971@postgrespro.ru", "phone": "+70368232842"}
0005434639001	273882	1634 395187	VIKTOR FROLOV	{"phone": "+70872497438"}
0005434639002	3D7353	2198 286276	ELENA PAVLOVA	{"phone": "+70468637128"}
0005434639003	FA009F	3019 558826	POLINA GRISHINA	{"phone": "+70646216037"}
0005434639004	31B595	6488 045468	OLGA ROMANOVA	{"phone": "+70631653620"}
0005434639062	71E805	4701 465001	VASILIY KUZMIN	{"phone": "+70845305000"}
0005434639005	DC733C	1572 633375	VLADIMIR MAKAROV	{"email": "makarov-vladimir-071972@postgrespro.ru", "phone": "+70569717635"}
0005434639006	F5C07E	1836 511571	ANATOLIY BORISOV	{"email": "a_borisov.051972@postgrespro.ru", "phone": "+70270021088"}
0005434639007	C6A56A	9353 405999	POLINA FEDOROVA	{"email": "fedorova_polina111960@postgrespro.ru", "phone": "+70706545274"}
0005434639008	20EDCF	8860 591502	ALEKSANDR NAUMOV	{"email": "naumov-a.05051978@postgrespro.ru", "phone": "+70448438605"}
0005434639009	3560F8	7946 422099	DENIS SHEVCHENKO	{"email": "shevchenkod1969@postgrespro.ru", "phone": "+70489579325"}
0005434639010	A794DD	4904 726875	ALEKSEY STEPANOV	{"phone": "+70841561725"}
0005434639011	E13F1E	9569 775357	RAMIL IVANOV	{"phone": "+70912370503"}
0005434639012	26D569	5087 933866	ELENA NIKITINA	{"email": "elena-nikitina.111984@postgrespro.ru", "phone": "+70819966957"}
0005434639013	E854A8	0329 862130	VIKTOR POPOV	{"email": "v.popov061974@postgrespro.ru", "phone": "+70328606479"}
0005434639014	E854A8	8407 624720	VIKTOR POPOV	{"email": "popovv.09021977@postgrespro.ru", "phone": "+70930103750"}
0005434639015	8A9340	7548 252186	ELENA MAKAROVA	{"phone": "+70349516778"}
0005434639016	15419E	1292 879602	LEONID SOLOVEV	{"email": "l-solovev031971@postgrespro.ru", "phone": "+70949074709"}
0005434639017	540F6C	9748 892393	NATALYA TIKHONOVA	{"phone": "+70408011446"}
0005434639018	53C284	8860 510161	DMITRIY SOKOLOV	{"phone": "+70611571708"}
0005434639019	67273F	1456 983203	ULYANA ABRAMOVA	{"email": "ulyana_abramova101974@postgrespro.ru", "phone": "+70560894147"}
0005434639020	20DEE2	5454 892218	VLADIMIR KRASNOV	{"email": "krasnov-v07011974@postgrespro.ru", "phone": "+70226522899"}
0005434639021	E2A82F	5388 998518	TATYANA BELOVA	{"phone": "+70293499940"}
0005434639022	984E27	8448 120502	DMITRIY PAVLOV	{"phone": "+70618715618"}
0005434639023	9E8FC1	4087 213943	DMITRIY NIKITIN	{"email": "dnikitin091970@postgrespro.ru", "phone": "+70815037278"}
0005434639024	E5034C	6474 111555	ALEKSANDR TARASOV	{"email": "aleksandrtarasov_041968@postgrespro.ru", "phone": "+70398961925"}
0005434639025	C5A3AB	1791 000356	NIKOLAY SMIRNOV	{"phone": "+70594669153"}
0005434639026	C5A3AB	6660 061178	OLESYA SOLOVEVA	{"email": "soloveva.olesya-091969@postgrespro.ru", "phone": "+70169022350"}
0005434639027	1D956C	9263 201585	ALINA ISAEVA	{"email": "alina.isaeva.16021982@postgrespro.ru", "phone": "+70521156722"}
0005434639028	DDCCC4	5800 916059	VERA YAKOVLEVA	{"email": "vyakovleva_28031978@postgrespro.ru", "phone": "+70069700172"}
0005434639029	1DB581	0519 840310	NATALYA PAVLOVA	{"email": "pavlova_natalya_1965@postgrespro.ru", "phone": "+70137190675"}
0005434639030	1DB581	6204 902040	STEPAN MOROZOV	{"email": "morozov-stepan.1978@postgrespro.ru", "phone": "+70886350981"}
0005434639031	1DB581	2244 706917	ANTON SOROKIN	{"phone": "+70652998980"}
0005434639032	0072A0	2639 213520	VIKTOR FEDOROV	{"email": "fedorovviktor_1969@postgrespro.ru", "phone": "+70290594362"}
0005434639033	3DE8BF	9983 289047	ALLA EGOROVA	{"email": "allaegorova-1975@postgrespro.ru", "phone": "+70788995907"}
0005434639034	275C9C	6390 547433	ASIYA GORBUNOVA	{"phone": "+70432868082"}
0005434639035	DAFAF3	3963 790184	VLADIMIR VOLKOV	{"email": "volkovvladimir101969@postgrespro.ru", "phone": "+70713519004"}
0005434639036	DAFAF3	0894 600161	ZINAIDA KUZNECOVA	{"phone": "+70225636126"}
0005434639037	872DD5	8775 972296	PETR ROMANOV	{"email": "p-romanov-31051983@postgrespro.ru", "phone": "+70128911900"}
0005434639038	71A65B	9667 294808	NATALYA MAKSIMOVA	{"phone": "+70916747878"}
0005434639039	26351B	6880 735263	TATYANA BELOVA	{"email": "tatyana.belova_12011973@postgrespro.ru", "phone": "+70158606945"}
0005434639040	26351B	3895 851456	ALINA ALEKSEEVA	{"email": "a-alekseeva04121979@postgrespro.ru", "phone": "+70401900307"}
0005434639041	A49ECE	9363 139719	VERA BARANOVA	{"phone": "+70159890337"}
0005434639042	A49ECE	8885 580306	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir.1970@postgrespro.ru", "phone": "+70969469839"}
0005434639043	A49ECE	5613 528133	VLADIMIR SIDOROV	{"email": "vsidorov-13111975@postgrespro.ru", "phone": "+70235404148"}
0005434639044	124D38	9488 562114	VLADISLAV KUDRYASHOV	{"email": "kudryashovv_18011979@postgrespro.ru", "phone": "+70671394636"}
0005434639045	EF3E6B	8523 494229	IRINA MATVEEVA	{"phone": "+70938976283"}
0005434639046	8C10CD	2032 842548	ANNA KUZNECOVA	{"email": "anna.kuznecova1971@postgrespro.ru", "phone": "+70929227870"}
0005434639047	8C10CD	5098 964525	NIKOLAY IVANOV	{"email": "ivanov-n061982@postgrespro.ru", "phone": "+70543701933"}
0005434639048	0976AD	0120 739141	NATALYA SEMENOVA	{"email": "semenova_n1970@postgrespro.ru", "phone": "+70229122462"}
0005434639049	098EF0	9277 944872	LILIYA ZOTOVA	{"phone": "+70041525897"}
0005434639050	707F57	5884 270755	TATYANA IVANOVA	{"email": "ivanova.tatyana_081982@postgrespro.ru", "phone": "+70898612895"}
0005434639051	440017	7944 669531	OLGA LAZAREVA	{"email": "o_lazareva16091973@postgrespro.ru", "phone": "+70585965883"}
0005434639052	A558B0	2609 571678	ANATOLIY DMITRIEV	{"email": "a-dmitriev-1972@postgrespro.ru", "phone": "+70982750960"}
0005434639053	06B762	7027 940539	IGOR RODIONOV	{"email": "igor_rodionov1983@postgrespro.ru", "phone": "+70149094182"}
0005434639054	06B762	9064 760191	TATYANA FEDOROVA	{"email": "fedorova.tatyana051976@postgrespro.ru", "phone": "+70499393492"}
0005434639055	7CD564	9965 293287	NATALYA FADEEVA	{"email": "fadeeva.n-25021978@postgrespro.ru", "phone": "+70599465659"}
0005434639056	7CD564	7247 794407	EKATERINA KOZLOVA	{"phone": "+70889964585"}
0005434639057	5148A2	5029 159867	SVETLANA MOROZOVA	{"email": "s.morozova.1960@postgrespro.ru", "phone": "+70675664908"}
0005434639058	1F008F	8629 026177	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr_03111978@postgrespro.ru", "phone": "+70763264857"}
0005434639059	901985	8891 196682	GERMAN ILIN	{"email": "ilin-g_101975@postgrespro.ru", "phone": "+70697060152"}
0005434639060	71E805	0257 432274	IVAN MOROZOV	{"phone": "+70561887104"}
0005434639061	71E805	0624 792905	IRINA FILIPPOVA	{"phone": "+70832463894"}
0005434639063	3E073F	4449 461436	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey_071971@postgrespro.ru", "phone": "+70389477405"}
0005434639064	7907D6	2677 191117	YURIY ISAEV	{"email": "yuriy-isaev081980@postgrespro.ru", "phone": "+70349344007"}
0005434639065	51F216	2753 224198	MAKSIM MIRONOV	{"phone": "+70862762775"}
0005434639066	FAD714	4017 886442	DARYA RYABOVA	{"email": "ryabova_darya_28111982@postgrespro.ru", "phone": "+70954210563"}
0005434639067	3D792F	9430 530444	SERGEY ROMANOV	{"email": "sergeyromanov_24011970@postgrespro.ru", "phone": "+70165877571"}
0005434639068	B1AE55	7642 421084	EMIL TIKHONOV	{"phone": "+70019718846"}
0005434639069	B1AE55	8591 238837	PAVEL MATVEEV	{"email": "matveevpavel_1984@postgrespro.ru", "phone": "+70358155113"}
0005434639070	EAA0F6	1662 498300	VALERIY ALEKSANDROV	{"email": "aleksandrovvaleriy15021977@postgrespro.ru", "phone": "+70539057493"}
0005434639071	11CC68	8223 988947	ANDREY KUDRYASHOV	{"phone": "+70129131970"}
0005434639072	7B1BD4	4174 243959	ALEKSEY PAVLOV	{"email": "a-pavlov_20111981@postgrespro.ru", "phone": "+70494125992"}
0005434639073	72B7AD	1699 684450	VIKTOR NAZAROV	{"email": "vnazarov22071974@postgrespro.ru", "phone": "+70732657705"}
0005434639074	B24838	6079 464672	NINA LAZAREVA	{"email": "lazareva_nina.23071963@postgrespro.ru", "phone": "+70049506739"}
0005434639075	B24838	4642 401705	ALBERT SAVELEV	{"email": "savelev_albert.1969@postgrespro.ru", "phone": "+70237718471"}
0005434639076	B24838	3216 857116	LIDIYA KISELEVA	{"phone": "+70243540209"}
0005434639077	640DC9	0107 184834	YURIY ILIN	{"email": "iliny.021976@postgrespro.ru", "phone": "+70397350433"}
0005434639078	640DC9	9117 028251	TAMARA IVANOVA	{"phone": "+70973474438"}
0005434639079	2CA202	3807 604361	MARIYA KUDRYASHOVA	{"phone": "+70821207868"}
0005434639080	2CA202	6021 665900	SVETLANA NESTEROVA	{"email": "nesterovas_111983@postgrespro.ru", "phone": "+70119229867"}
0005434639081	B4D24B	0973 952912	NINA NIKOLAEVA	{"email": "n-nikolaeva.041967@postgrespro.ru", "phone": "+70947465544"}
0005434639139	D7BABB	5405 960672	ALEKSANDR KONOVALOV	{"phone": "+70219170534"}
0005434639082	6D1B31	9523 172528	NADEZHDA ERMAKOVA	{"email": "ermakova-nadezhda26031962@postgrespro.ru", "phone": "+70575433751"}
0005434639083	8EB26C	8709 119293	OLESYA FILATOVA	{"email": "filatovaolesya-14101967@postgrespro.ru", "phone": "+70020563594"}
0005434639084	E96879	3012 951485	LIDIYA KOVALEVA	{"email": "kovaleva_l_121962@postgrespro.ru", "phone": "+70742612356"}
0005434639085	B55C85	6177 490523	NIKOLAY ZAKHAROV	{"phone": "+70799987734"}
0005434639086	9378CE	7795 157456	LYUDMILA OSIPOVA	{"email": "l_osipova.111978@postgrespro.ru", "phone": "+70208121372"}
0005434639087	9378CE	6604 049659	OLGA KOMAROVA	{"email": "komarova-o19071964@postgrespro.ru", "phone": "+70223988822"}
0005434639088	E9F743	2269 066008	IVAN ANTONOV	{"email": "antonov_ivan-30071974@postgrespro.ru", "phone": "+70286207869"}
0005434639089	2719F5	7334 875944	NATALYA ABRAMOVA	{"email": "natalya_abramova.1973@postgrespro.ru", "phone": "+70210269499"}
0005434639090	1C22B1	3634 380123	MIKHAIL MAKSIMOV	{"phone": "+70606626652"}
0005434639091	BFCC04	3559 746980	SERGEY NOVIKOV	{"phone": "+70410237497"}
0005434639092	738465	0247 807399	NINA TIKHONOVA	{"email": "n-tikhonova_091960@postgrespro.ru", "phone": "+70652035651"}
0005434639093	8EE642	6998 340465	FEDOR NOVIKOV	{"phone": "+70431812183"}
0005434639094	8EE642	0308 651790	ALEKSANDR TARASOV	{"phone": "+70443898434"}
0005434639095	FB5F93	1899 751833	IRINA OSIPOVA	{"phone": "+70579306752"}
0005434639096	FB5F93	2557 389266	NINA EFREMOVA	{"email": "nefremova.26041971@postgrespro.ru", "phone": "+70634515806"}
0005434639097	FB5F93	0084 679511	ALENA KUZNECOVA	{"phone": "+70679927332"}
0005434639098	611713	3151 743379	NIKOLAY NAUMOV	{"phone": "+70449416571"}
0005434639099	C5FBDA	6581 063226	ANDREY SEMENOV	{"phone": "+70324383750"}
0005434639100	8269CD	3340 546047	VLADIMIR TIKHONOV	{"email": "tikhonov.vladimir_28031969@postgrespro.ru", "phone": "+70534606165"}
0005434639101	8269CD	6195 923038	LEV SOLOVEV	{"phone": "+70158784119"}
0005434639102	65FD7B	4714 356131	NADEZHDA KUZNECOVA	{"phone": "+70897898860"}
0005434639103	65FD7B	3959 022052	ALEKSEY NIKOLAEV	{"phone": "+70307314167"}
0005434639104	C46382	7421 163797	IGOR KUZMIN	{"phone": "+70585088898"}
0005434639105	D23897	5241 133068	MILENA KOLESNIKOVA	{"phone": "+70004941136"}
0005434639106	D23897	6823 705669	ALEKSANDR KUZNECOV	{"phone": "+70302144677"}
0005434639107	D23897	9568 727811	OLGA ILINA	{"email": "ilinao.24011976@postgrespro.ru", "phone": "+70984301117"}
0005434639108	D23897	3393 403928	LYUDMILA BELYAEVA	{"email": "l-belyaeva21051971@postgrespro.ru", "phone": "+70845791367"}
0005434639109	2B627C	4382 961642	ARTEM NAUMOV	{"email": "naumova_071976@postgrespro.ru", "phone": "+70002312133"}
0005434639110	D792D0	1971 564189	IRINA KOZLOVA	{"phone": "+70070201443"}
0005434639111	D792D0	4618 451720	MARINA LEBEDEVA	{"email": "mlebedeva_04031976@postgrespro.ru", "phone": "+70448870491"}
0005434639112	2C8AD4	9907 245441	VLADISLAV SOLOVEV	{"phone": "+70757703636"}
0005434639113	2C8AD4	1524 064785	TATYANA MAKAROVA	{"phone": "+70788918777"}
0005434639114	68367C	8500 854469	OLGA KUZNECOVA	{"phone": "+70005235624"}
0005434639115	68367C	3460 636602	ANDREY ROMANOV	{"phone": "+70643463924"}
0005434639116	AE5F3D	2935 941183	VASILIY OSIPOV	{"phone": "+70780502854"}
0005434639117	AE5F3D	6639 433675	DMITRIY SHEVCHENKO	{"phone": "+70586255224"}
0005434639175	231F1B	9773 825661	VASILIY STEPANOV	{"phone": "+70990844719"}
0005434639118	4144B7	1448 798806	MIKHAIL EGOROV	{"email": "m-egorov.09101977@postgrespro.ru", "phone": "+70450887500"}
0005434639119	9F9B8A	6067 489069	NIKOLAY IVANOV	{"phone": "+70822370184"}
0005434639120	9F9B8A	8603 819846	ALEKSANDR SEMENOV	{"email": "a.semenov_31071962@postgrespro.ru", "phone": "+70674165923"}
0005434639121	481EAA	4768 694505	ANDREY BONDARENKO	{"phone": "+70006207512"}
0005434639122	55CA07	3373 058338	MARAT NAUMOV	{"email": "naumov_m.031983@postgrespro.ru", "phone": "+70181514204"}
0005434639123	55CA07	8254 685873	LIDIYA ZHURAVLEVA	{"phone": "+70569462216"}
0005434639124	6D6816	6854 178820	ALEKSEY FEDOROV	{"email": "a_fedorov.101969@postgrespro.ru", "phone": "+70172315370"}
0005434639125	2CE469	7897 435726	VLADIMIR GRIGOREV	{"phone": "+70148679015"}
0005434639126	C122C2	9020 247982	OLGA FROLOVA	{"email": "olga-frolova1973@postgrespro.ru", "phone": "+70014706642"}
0005434639127	4FCA2F	1433 474288	ALEKSANDR IVANOV	{"phone": "+70444013606"}
0005434639128	C3607E	6366 410606	LYUBOV NOVIKOVA	{"email": "novikova_l_071972@postgrespro.ru", "phone": "+70930818794"}
0005434639129	594DE8	6660 077972	ELENA BORISOVA	{"phone": "+70115937344"}
0005434639130	F2A29B	5000 921775	OLGA MELNIKOVA	{"email": "melnikova.o_1971@postgrespro.ru", "phone": "+70834622978"}
0005434639131	FE86B0	8828 417919	NINA LEBEDEVA	{"email": "lebedevanina1981@postgrespro.ru", "phone": "+70330690982"}
0005434639132	FE86B0	0175 868612	ELENA KALININA	{"email": "kalinina-e011982@postgrespro.ru", "phone": "+70397965409"}
0005434639133	F4D50F	7402 104533	KIRILL ILIN	{"email": "k.ilin-041974@postgrespro.ru", "phone": "+70990156080"}
0005434639134	90C269	1650 194312	OLGA KISELEVA	{"phone": "+70172385298"}
0005434639135	90C269	3746 395997	EKATERINA VOROBEVA	{"email": "ekaterina_vorobeva-03031990@postgrespro.ru", "phone": "+70388025941"}
0005434639136	A9D1F0	7416 200627	ELENA MELNIKOVA	{"phone": "+70962772878"}
0005434639137	A9D1F0	7807 953836	IRINA GAVRILOVA	{"phone": "+70701753937"}
0005434639138	A9D1F0	0920 923490	ANNA FROLOVA	{"phone": "+70000175074"}
0005434639140	D7BABB	0175 405254	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov.1980@postgrespro.ru", "phone": "+70745267089"}
0005434639141	A672A5	9691 405909	YURIY NAUMOV	{"email": "yuriynaumov.1969@postgrespro.ru", "phone": "+70141320087"}
0005434639142	8AF316	7020 368111	NATALYA NESTEROVA	{"email": "nesterovan_17121975@postgrespro.ru", "phone": "+70355322182"}
0005434639143	0D4881	4769 959160	MIKHAIL TIKHONOV	{"phone": "+70995961546"}
0005434639144	0D4881	1559 883671	KLAVDIYA FILIPPOVA	{"email": "klavdiya-filippova.071986@postgrespro.ru", "phone": "+70516627604"}
0005434639145	0D4881	8579 330345	ANNA VOROBEVA	{"phone": "+70371163819"}
0005434639146	CE7BF4	3034 110009	OLGA ERMAKOVA	{"email": "o_ermakova_15061966@postgrespro.ru", "phone": "+70941734104"}
0005434639147	01745B	6667 899246	TATYANA FEDOROVA	{"phone": "+70510347905"}
0005434639148	596B5B	7764 856865	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr051969@postgrespro.ru", "phone": "+70785914771"}
0005434639149	4DF828	2370 159493	SERGEY KOZLOV	{"email": "kozlov_s111969@postgrespro.ru", "phone": "+70044279499"}
0005434639150	572072	0793 224506	NIKOLAY SOKOLOV	{"phone": "+70444471222"}
0005434639151	3173A8	9930 555320	TAISIYA KOVALEVA	{"email": "kovalevataisiya_1975@postgrespro.ru", "phone": "+70019808810"}
0005434639152	397504	9899 863204	YANA TIKHONOVA	{"phone": "+70010826366"}
0005434639153	397504	5616 596924	LYUDMILA BELOVA	{"email": "l.belova1966@postgrespro.ru", "phone": "+70490533563"}
0005434639154	5D2162	3328 972801	VITALIY BELOV	{"email": "belov.vitaliy1974@postgrespro.ru", "phone": "+70538984499"}
0005434639155	5D2162	9530 707491	NATALYA ALEKSANDROVA	{"email": "aleksandrova_natalya-1967@postgrespro.ru", "phone": "+70099586655"}
0005434639156	2EBC0D	6253 144916	ELIZAVETA MAKAROVA	{"email": "makarova.e.14041963@postgrespro.ru", "phone": "+70151684135"}
0005434639157	C6C76F	2424 228490	ARINA KOROLEVA	{"email": "arina_koroleva.071972@postgrespro.ru", "phone": "+70187110337"}
0005434639158	C6C76F	3734 155141	SERGEY DAVYDOV	{"phone": "+70092212667"}
0005434639159	C6C76F	4459 369637	YULIYA KOZLOVA	{"email": "kozlovayuliya.1974@postgrespro.ru", "phone": "+70265120667"}
0005434639160	571385	2524 808964	NINA KONDRATEVA	{"email": "kondrateva.nina_04021978@postgrespro.ru", "phone": "+70966947126"}
0005434639161	571385	4405 513730	IRINA POPOVA	{"phone": "+70069443350"}
0005434639162	A607A2	8745 344008	IRINA KAZAKOVA	{"email": "kazakova.irina_25071977@postgrespro.ru", "phone": "+70329419657"}
0005434639163	CD49E9	1591 692512	IRINA OSIPOVA	{"phone": "+70769495321"}
0005434639164	CD49E9	9416 899152	OLGA VLASOVA	{"email": "vlasova-o-05101972@postgrespro.ru", "phone": "+70472333853"}
0005434639165	D0CE76	7902 861061	VALENTINA POLYAKOVA	{"phone": "+70389506572"}
0005434639166	EB13EE	5412 698515	VALENTINA FILATOVA	{"phone": "+70542881027"}
0005434639167	D3EBE7	8505 834180	NATALYA EFIMOVA	{"phone": "+70936539973"}
0005434639168	3FB0EE	0045 858612	NIKOLAY SCHERBAKOV	{"email": "scherbakov-nikolay.08121974@postgrespro.ru", "phone": "+70060493068"}
0005434639169	3FB0EE	5428 164311	ANDREY MIRONOV	{"phone": "+70784242755"}
0005434639170	55C2F3	2633 240830	YURIY KUZNECOV	{"phone": "+70296636380"}
0005434639171	3E412F	7661 219866	LIDIYA KOLESNIKOVA	{"email": "kolesnikova_lidiya-26041968@postgrespro.ru", "phone": "+70280409046"}
0005434639172	CA8EA3	8317 746793	YURIY MIRONOV	{"phone": "+70813373760"}
0005434639173	214456	6490 347573	SERGEY ILIN	{"phone": "+70172038373"}
0005434639174	231F1B	0006 857079	SERGEY GRIGOREV	{"phone": "+70986912264"}
0005434639176	FE7C08	3498 817813	YURIY SHEVCHENKO	{"email": "yuriy_shevchenko.121971@postgrespro.ru", "phone": "+70166573864"}
0005434639177	1D1A51	1776 191389	TATYANA PETROVA	{"phone": "+70555789565"}
0005434639178	1D1A51	2534 865570	ALLA VOLKOVA	{"email": "volkova.alla16041971@postgrespro.ru", "phone": "+70719347534"}
0005434639179	9FBF54	8288 300203	VLADIMIR STEPANOV	{"phone": "+70103759793"}
0005434639180	796CDE	2225 409189	ALEVTINA POLYAKOVA	{"email": "polyakova-a_071967@postgrespro.ru", "phone": "+70499325531"}
0005434639181	796CDE	6439 390536	EKATERINA BELOVA	{"phone": "+70011430901"}
0005434639182	A6AD79	1562 686334	ARTEM BORISOV	{"email": "a.borisov-20121984@postgrespro.ru", "phone": "+70753663510"}
0005434639183	11407E	4901 373898	NIKOLAY IVANOV	{"phone": "+70838905190"}
0005434639184	11407E	3751 321808	MARIYA KUZNECOVA	{"phone": "+70636682378"}
0005434639185	62B44E	6453 636766	SERGEY NIKOLAEV	{"email": "sergey-nikolaev_041971@postgrespro.ru", "phone": "+70596036435"}
0005434639186	62B44E	3086 290852	VALENTINA NIKITINA	{"phone": "+70626903264"}
0005434639187	62B44E	3590 042931	SVETLANA MIRONOVA	{"email": "mironova-svetlana-101978@postgrespro.ru", "phone": "+70284680153"}
0005434639188	0B03A7	9740 979395	SERGEY GAVRILOV	{"phone": "+70308790266"}
0005434639189	0B03A7	6246 487107	ALEKSEY POPOV	{"phone": "+70998284875"}
0005434639190	0B03A7	0566 135666	SERGEY MAKAROV	{"phone": "+70684315441"}
0005434639191	2883F4	3484 151527	SERGEY MIRONOV	{"email": "smironov.1969@postgrespro.ru", "phone": "+70648117567"}
0005434639192	A19330	4293 084984	ALENA ISAEVA	{"email": "isaevaalena-071966@postgrespro.ru", "phone": "+70273104551"}
0005434639193	969CD5	5854 682415	VASILIY KOZLOV	{"email": "vasiliy-kozlov-1969@postgrespro.ru", "phone": "+70339196942"}
0005434639194	969CD5	0429 515259	VLADIMIR NIKOLAEV	{"phone": "+70749216675"}
0005434639195	269B69	7158 199893	MARINA VOROBEVA	{"phone": "+70280966423"}
0005434639196	63E632	2444 313247	ALEKSEY GORBUNOV	{"email": "aleksey_gorbunov_14041981@postgrespro.ru", "phone": "+70015912498"}
0005434639197	49329C	9783 973167	NATALYA MELNIKOVA	{"phone": "+70961568009"}
0005434639198	49D444	7243 002189	GEORGIY NAZAROV	{"phone": "+70254744537"}
0005434639199	0FCE21	1261 230893	STANISLAV DMITRIEV	{"phone": "+70186225849"}
0005434639200	0FCE21	6814 440865	MARGARITA MOISEEVA	{"phone": "+70713674325"}
0005434639201	614AF0	5946 802673	IRINA BORISOVA	{"phone": "+70700840760"}
0005434639202	095F99	5358 558444	RAFAIL SOROKIN	{"phone": "+70508026157"}
0005434639203	02BE7D	5674 592624	SERGEY GERASIMOV	{"phone": "+70915254508"}
0005434639204	DB1A6C	8325 689300	LILIYA KALININA	{"phone": "+70207194244"}
0005434639205	DB1A6C	3628 885026	VLADIMIR PAVLOV	{"email": "v_pavlov.121979@postgrespro.ru", "phone": "+70312928257"}
0005434639206	AD86AF	4783 680610	KRISTINA GRISHINA	{"email": "grishina_kristina021985@postgrespro.ru", "phone": "+70555572049"}
0005434639207	0B8D7F	6483 041974	IVAN KAZAKOV	{"email": "ivan.kazakov_1988@postgrespro.ru", "phone": "+70677211433"}
0005434639208	0B8D7F	0038 007658	NATALYA ILINA	{"phone": "+70523473125"}
0005434639209	6D13A6	3967 810660	YURIY IVANOV	{"email": "ivanovy.21031971@postgrespro.ru", "phone": "+70453650690"}
0005434639210	6D13A6	6319 750969	ANATOLIY RODIONOV	{"email": "anatoliy_rodionov_091978@postgrespro.ru", "phone": "+70408342431"}
0005434639211	00ABE9	2780 593009	MARIYA DMITRIEVA	{"email": "dmitrieva-m28031968@postgrespro.ru", "phone": "+70549952631"}
0005434639212	CC3179	9849 727628	VALERIY MEDVEDEV	{"phone": "+70097754191"}
0005434639213	11DF72	5350 182425	LYUBOV NAZAROVA	{"phone": "+70999579910"}
0005434639214	57AC44	7002 264615	IRINA TITOVA	{"phone": "+70005021947"}
0005434639215	85F938	0808 932457	DMITRIY KAZAKOV	{"phone": "+70405988434"}
0005434639216	56C24B	4188 283221	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev21121971@postgrespro.ru", "phone": "+70725058985"}
0005434639217	56C24B	9999 891617	EKATERINA MOROZOVA	{"phone": "+70269694932"}
0005434639218	EC6B4A	4678 372871	NADEZHDA ZHURAVLEVA	{"phone": "+70608819925"}
0005434639219	EC0EB4	2177 655685	LILIYA VOROBEVA	{"email": "vorobeval1978@postgrespro.ru", "phone": "+70862732111"}
0005434639220	CC5EB1	1700 703112	ALEKSANDR MAKAROV	{"phone": "+70523207530"}
0005434639221	73D7D0	7797 848336	SERGEY SMIRNOV	{"email": "sergey-smirnov_10021975@postgrespro.ru", "phone": "+70485723541"}
0005434639222	73D7D0	7985 738085	ALEKSANDR PAVLOV	{"phone": "+70809092966"}
0005434639223	113E2E	2692 589017	OLGA KUZNECOVA	{"email": "olgakuznecova_13031968@postgrespro.ru", "phone": "+70952411155"}
0005434639224	113E2E	0035 187849	RAMILYA ARKHIPOVA	{"email": "arkhipova_r_051973@postgrespro.ru", "phone": "+70378461193"}
0005434639225	57F030	5288 848516	MARIYA KUZNECOVA	{"email": "mkuznecova-081979@postgrespro.ru", "phone": "+70738751141"}
0005434639226	57F030	0360 318245	SVETLANA MARTYNOVA	{"phone": "+70310872775"}
0005434639227	0C2E46	0083 417028	ALEVTINA KONDRATEVA	{"phone": "+70917115602"}
0005434639228	0C2E46	5349 570590	NINA EFREMOVA	{"phone": "+70010843918"}
0005434639229	79D806	8203 021318	ALEKSEY ANDREEV	{"email": "alekseyandreev_111969@postgrespro.ru", "phone": "+70980094745"}
0005434639230	E9E675	8491 993422	MARIYA ROMANOVA	{"email": "m_romanova_21071959@postgrespro.ru", "phone": "+70805360735"}
0005434639231	E9E675	2456 222204	ANNA TIMOFEEVA	{"email": "timofeeva-a_1962@postgrespro.ru", "phone": "+70518629373"}
0005434639288	B518E5	5819 705900	IVAN ILIN	{"phone": "+70518189540"}
0005434639232	A6D80D	2745 282399	KLAVDIYA GORBUNOVA	{"email": "klavdiya-gorbunova-19121963@postgrespro.ru", "phone": "+70271384253"}
0005434639233	1DA85C	4183 186088	ALEKSANDR NOVIKOV	{"email": "a_novikov.26011975@postgrespro.ru", "phone": "+70944781873"}
0005434639234	4C0602	6945 933475	NINA SIDOROVA	{"email": "nina-sidorova.1973@postgrespro.ru", "phone": "+70657226917"}
0005434639235	4C0602	2454 484688	IRINA MASLOVA	{"email": "maslovairina061967@postgrespro.ru", "phone": "+70780855778"}
0005434639236	B80CCF	3791 129320	EVGENIY NAZAROV	{"phone": "+70535299054"}
0005434639237	BDF062	9997 905448	DMITRIY FILIPPOV	{"phone": "+70849136477"}
0005434639238	A4C0BE	8864 713256	FLYURA NESTEROVA	{"phone": "+70367781748"}
0005434639418	139BE8	6615 838191	OLGA ANISIMOVA	{"phone": "+70681837930"}
0005434639239	01E480	0868 968515	KSENIYA KUZNECOVA	{"email": "kuznecova_k-121977@postgrespro.ru", "phone": "+70575580601"}
0005434639240	01E480	7361 783179	IRAIDA FROLOVA	{"email": "iraida-frolova1989@postgrespro.ru", "phone": "+70592214225"}
0005434639241	2DD678	9577 965556	SERGEY DMITRIEV	{"phone": "+70874222065"}
0005434639242	2DD678	5533 075524	VIKTORIYA PETROVA	{"email": "petrova-viktoriya-16111975@postgrespro.ru", "phone": "+70625454349"}
0005434639243	253BCD	2402 543599	SVETLANA KONDRATEVA	{"phone": "+70624973744"}
0005434639244	253BCD	6610 248835	DMITRIY TARASOV	{"email": "dmitriytarasov_1983@postgrespro.ru", "phone": "+70163750987"}
0005434639245	1933FB	9500 209579	VIKTOR ANTONOV	{"email": "antonov-viktor-1972@postgrespro.ru", "phone": "+70089039206"}
0005434639246	4AF00F	8226 846842	NIKITA NAZAROV	{"email": "n_nazarov-121982@postgrespro.ru", "phone": "+70183703365"}
0005434639247	4AF00F	6557 326437	GEORGIY NIKOLAEV	{"phone": "+70371582568"}
0005434639248	546B28	3557 373369	MARINA TARASOVA	{"email": "m.tarasova101976@postgrespro.ru", "phone": "+70577681214"}
0005434639249	0EAE68	9858 544536	VALERIY POPOV	{"phone": "+70793318196"}
0005434639250	D7BF8E	7772 836612	ANNA ILINA	{"phone": "+70337117660"}
0005434639251	FAA582	6218 625713	VIKTOR IVANOV	{"email": "ivanovviktor.1978@postgrespro.ru", "phone": "+70218678488"}
0005434639252	9777C3	7436 904113	EVGENIYA DENISOVA	{"phone": "+70863358100"}
0005434639253	9777C3	2638 507312	ALEKSANDR KARPOV	{"email": "a_karpov081973@postgrespro.ru", "phone": "+70845117416"}
0005434639254	B7A224	4273 279826	DMITRIY VOROBEV	{"phone": "+70737964515"}
0005434639255	68FA20	1787 876234	DMITRIY KISELEV	{"email": "kiselev_dmitriy-031964@postgrespro.ru", "phone": "+70801703443"}
0005434639256	479409	0451 624524	NATALYA TIKHONOVA	{"phone": "+70385503469"}
0005434639257	7529AC	4258 802583	VIKTOR PAVLOV	{"email": "v_pavlov30011978@postgrespro.ru", "phone": "+70590775456"}
0005434639258	8D2792	9931 379729	VERA GUSEVA	{"email": "vera-guseva.30091960@postgrespro.ru", "phone": "+70025793419"}
0005434639259	917842	8749 685794	NATALYA SEMENOVA	{"phone": "+70253859554"}
0005434639260	917842	0327 237508	ANNA MAKAROVA	{"phone": "+70844145886"}
0005434639261	51B9D1	4063 626563	ANASTASIYA FEDOROVA	{"email": "fedorova_anastasiya-061967@postgrespro.ru", "phone": "+70688180791"}
0005434639262	4B7063	4723 396004	LARISA MARTYNOVA	{"phone": "+70229859606"}
0005434639263	B3FDE8	7333 921598	ANATOLIY CHERNOV	{"email": "chernov.a-1963@postgrespro.ru", "phone": "+70628220000"}
0005434639264	D09249	3261 777264	ELENA NIKOLAEVA	{"phone": "+70732313272"}
0005434639265	1BF156	6371 864295	TATYANA KULIKOVA	{"email": "t-kulikova101973@postgrespro.ru", "phone": "+70943564092"}
0005434639266	FFB2FF	5713 341598	OLGA IVANOVA	{"phone": "+70251920079"}
0005434639267	9A0F2F	8619 206868	SVETLANA PAVLOVA	{"phone": "+70762357048"}
0005434639268	C8A4D5	5126 916333	ALEKSANDR MARTYNOV	{"email": "martynov.aleksandr111972@postgrespro.ru", "phone": "+70330110357"}
0005434639269	15CA6B	7515 483956	SERGEY TIMOFEEV	{"phone": "+70621652027"}
0005434639270	15CA6B	1306 516689	PAVEL EGOROV	{"email": "egorov-p_021967@postgrespro.ru", "phone": "+70503066794"}
0005434639271	7ED010	0681 205392	NATALIYA MAKSIMOVA	{"phone": "+70041876154"}
0005434639272	9F50CC	5522 931308	ALEKSANDR ABRAMOV	{"email": "a-abramov1966@postgrespro.ru", "phone": "+70135051207"}
0005434639273	9F50CC	0193 463120	ALEKSANDRA VASILEVA	{"email": "aleksandra.vasileva19041971@postgrespro.ru", "phone": "+70024451391"}
0005434639274	2047AA	1423 497134	DANILA KISELEV	{"phone": "+70486390908"}
0005434639275	2047AA	2742 723504	LIDIYA POPOVA	{"email": "lidiya.popova-27021971@postgrespro.ru", "phone": "+70602008338"}
0005434639276	6149C7	5834 802769	LEONID SIDOROV	{"email": "leonid.sidorov08081962@postgrespro.ru", "phone": "+70829134527"}
0005434639277	6149C7	6390 124849	VALENTINA POPOVA	{"phone": "+70650107380"}
0005434639278	683915	5316 182261	MARIYA MAKSIMOVA	{"email": "mariya_maksimova.25011964@postgrespro.ru", "phone": "+70673281451"}
0005434639279	F80D11	5358 091721	EVA DANILOVA	{"email": "evadanilova_061986@postgrespro.ru", "phone": "+70638387018"}
0005434639280	0B814D	3912 883501	ARSENIY SCHERBAKOV	{"phone": "+70357133693"}
0005434639281	0B814D	8587 718154	VIKTOR KOZLOV	{"phone": "+70227349878"}
0005434639282	796A5A	1941 762742	DMITRIY NAZAROV	{"email": "d-nazarov-071971@postgrespro.ru", "phone": "+70170680643"}
0005434639283	646E7C	1204 314912	ALENA NOVIKOVA	{"email": "novikova.alena1967@postgrespro.ru", "phone": "+70548100334"}
0005434639284	CDA1A0	8127 657170	TATYANA SMIRNOVA	{"phone": "+70150976805"}
0005434639285	CDA1A0	5987 137336	VALERIYA ILINA	{"phone": "+70513309172"}
0005434639286	7831E1	7316 614885	NADEZHDA POTAPOVA	{"email": "potapova-nadezhda_10041971@postgrespro.ru", "phone": "+70361897385"}
0005434639287	7831E1	3614 676525	ANATOLIY ISAEV	{"phone": "+70251977796"}
0005434639289	B518E5	1672 592194	NADEZHDA NIKITINA	{"phone": "+70743783182"}
0005434639290	07B4D9	7933 759773	VALERIYA SOROKINA	{"email": "v-sorokina26051974@postgrespro.ru", "phone": "+70393680262"}
0005434639291	07B4D9	2595 729483	SEMEN ZAKHAROV	{"email": "zakharov-semen.04011963@postgrespro.ru", "phone": "+70045083725"}
0005434639292	7F08F2	7560 017609	DMITRIY IVANOV	{"phone": "+70974210498"}
0005434639293	7F08F2	9418 545818	LIDIYA SEMENOVA	{"email": "semenova-lidiya22101967@postgrespro.ru", "phone": "+70561090980"}
0005434639294	52DB86	6340 314766	NATALYA NIKIFOROVA	{"phone": "+70708060875"}
0005434639295	F42031	5543 673309	ANATOLIY KRASNOV	{"phone": "+70387137143"}
0005434639296	65042C	3770 977113	VERA VOLKOVA	{"email": "volkova_v10071967@postgrespro.ru", "phone": "+70300750770"}
0005434639297	F681D2	2333 775161	NINA KUZNECOVA	{"phone": "+70920814831"}
0005434639298	4EA546	0711 335582	ALLA EGOROVA	{"email": "egorova_alla02091974@postgrespro.ru", "phone": "+70204519495"}
0005434639299	6BFA75	4836 686338	ALEKSEY VASILEV	{"email": "vasilev-a-071973@postgrespro.ru", "phone": "+70195347431"}
0005434639300	6BFA75	8922 326590	MIKHAIL KONOVALOV	{"email": "mikhailkonovalov-061993@postgrespro.ru", "phone": "+70493019556"}
0005434639301	AD48F5	5171 568958	VLADIMIR POPOV	{"phone": "+70502307404"}
0005434639302	683647	6344 567990	VLADIMIR VLASOV	{"phone": "+70269985096"}
0005434639303	5F2F83	7210 685663	IVAN GERASIMOV	{"email": "gerasimovi1973@postgrespro.ru", "phone": "+70886443312"}
0005434639304	08FECB	4589 428717	IVAN VOLKOV	{"phone": "+70292308135"}
0005434639305	08FECB	2484 732164	LYUBOV KONDRATEVA	{"email": "lyubov-kondrateva-22071963@postgrespro.ru", "phone": "+70167439427"}
0005434639306	C757C6	0848 932222	NADEZHDA MARTYNOVA	{"phone": "+70024062999"}
0005434639307	3E3473	7173 611398	ALEKSANDRA SERGEEVA	{"email": "a_sergeeva17101970@postgrespro.ru", "phone": "+70547181350"}
0005434639308	3E3473	0159 646059	NATALYA NOVIKOVA	{"email": "natalya_novikova07041974@postgrespro.ru", "phone": "+70421460570"}
0005434639309	A509AB	0705 203308	SERGEY KAZAKOV	{"phone": "+70484028110"}
0005434639310	315CE9	0129 500750	SVETLANA IVANOVA	{"phone": "+70858502962"}
0005434639311	315CE9	6128 082070	EKATERINA VOLKOVA	{"phone": "+70225996869"}
0005434639312	737E5A	1816 591836	NATALIYA RODIONOVA	{"phone": "+70291067358"}
0005434639313	33ED11	3742 014366	ANDREY MAKAROV	{"email": "makarov_andrey1981@postgrespro.ru", "phone": "+70585699880"}
0005434639314	08B936	3438 725511	SERGEY SOLOVEV	{"phone": "+70228704957"}
0005434639315	20A367	6268 897477	NATALYA ALEKSEEVA	{"email": "n-alekseeva.061978@postgrespro.ru", "phone": "+70163325079"}
0005434639316	20A367	6966 329222	EVGENIY NIKOLAEV	{"email": "nikolaev-evgeniy.1965@postgrespro.ru", "phone": "+70584390654"}
0005434639317	8CA6F8	7780 532218	MARINA ILINA	{"phone": "+70904893317"}
0005434639318	8CA6F8	3306 289805	VADIM POPOV	{"email": "popov_v1977@postgrespro.ru", "phone": "+70363746376"}
0005434639319	08E74B	3130 720355	GLEB IVANOV	{"phone": "+70273408612"}
0005434639320	59EF8E	2930 718084	ILYA ISAEV	{"phone": "+70810561754"}
0005434639321	64D708	9141 791773	ANDREY VLASOV	{"email": "andrey_vlasov-111984@postgrespro.ru", "phone": "+70589429444"}
0005434639322	C38DF1	5289 963217	ALEKSEY TIMOFEEV	{"email": "timofeev-a.28121978@postgrespro.ru", "phone": "+70184923267"}
0005434639323	C38DF1	1843 588351	SERGEY VOROBEV	{"phone": "+70674480536"}
0005434639324	ADC1A3	3675 330094	ANTON SCHERBAKOV	{"phone": "+70395364911"}
0005434639325	1811E5	2522 137943	ALEKSANDR CHERNOV	{"phone": "+70406219578"}
0005434639326	1811E5	6044 691415	TAMARA GRISHINA	{"email": "t_grishina_111972@postgrespro.ru", "phone": "+70509598305"}
0005434639327	A136A0	8747 104017	TATYANA KOROLEVA	{"phone": "+70383931591"}
0005434639328	A136A0	9356 817669	DMITRIY STEPANOV	{"phone": "+70553496593"}
0005434639329	1DF003	4788 713464	ALEKSEY MARTYNOV	{"phone": "+70145406328"}
0005434639330	0A8EAA	7491 049375	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova_l011977@postgrespro.ru", "phone": "+70724432548"}
0005434639331	678BB7	6196 702121	YULIYA POPOVA	{"phone": "+70689812196"}
0005434639332	678BB7	1162 187030	KSENIYA DENISOVA	{"email": "denisova.kseniya-1961@postgrespro.ru", "phone": "+70545149443"}
0005434639333	8789B2	8935 839694	OLGA TARASOVA	{"email": "otarasova091963@postgrespro.ru", "phone": "+70911899995"}
0005434639334	480459	7701 775289	EKATERINA ZAYCEVA	{"phone": "+70536226166"}
0005434639335	F4EFB4	1824 801784	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr.04031977@postgrespro.ru", "phone": "+70299810273"}
0005434639336	252BA4	6268 422943	SERGEY MIKHAYLOV	{"email": "mikhaylov_s.01041967@postgrespro.ru", "phone": "+70407747306"}
0005434639337	252BA4	5632 334444	DMITRIY ROMANOV	{"email": "dmitriyromanov071983@postgrespro.ru", "phone": "+70159178155"}
0005434639338	23C5AD	9852 994600	EVGENIY KISELEV	{"phone": "+70369611218"}
0005434639339	82676A	8710 865813	ELIZAVETA NESTEROVA	{"phone": "+70062558887"}
0005434639340	07BA15	0591 931725	SALAVAT KAZAKOV	{"phone": "+70514772971"}
0005434639341	F1D1F8	5316 363454	NADEZHDA ZHUKOVA	{"email": "nadezhda_zhukova07051966@postgrespro.ru", "phone": "+70158163685"}
0005434639342	94A109	5317 999454	LYUBOV YAKOVLEVA	{"phone": "+70080416370"}
0005434639343	08E5EB	7193 188392	EKATERINA PETROVA	{"phone": "+70656514140"}
0005434639344	08E5EB	2898 318884	ALEKSANDR FOMIN	{"email": "fomin_aleksandr.1977@postgrespro.ru", "phone": "+70688548359"}
0005434639678	1F1064	3082 968881	ANASTASIYA DAVYDOVA	{"phone": "+70603116114"}
0005434639345	08E5EB	6176 925588	VASILIY ZHURAVLEV	{"email": "zhuravlev_vasiliy-091965@postgrespro.ru", "phone": "+70026546781"}
0005434639346	0064DD	6840 088810	ARTEM ZAKHAROV	{"email": "zakharov.a-30081961@postgrespro.ru", "phone": "+70799223326"}
0005434639347	C8ECDA	6083 641359	SERGEY KUZNECOV	{"email": "kuznecov.sergey061972@postgrespro.ru", "phone": "+70028382931"}
0005434639348	19CB9E	9694 554515	LYUDMILA YUDINA	{"email": "l_yudina-1969@postgrespro.ru", "phone": "+70873413290"}
0005434639349	388D8F	8393 773393	ALEKSANDRA TROFIMOVA	{"email": "trofimova.aleksandra.23031976@postgrespro.ru", "phone": "+70162910525"}
0005434639350	388D8F	8232 938810	FEDOR CHERNOV	{"phone": "+70969488630"}
0005434639351	E3B2A3	2565 218135	ANNA MALYSHEVA	{"phone": "+70008889418"}
0005434639352	E3B2A3	8497 222548	YANA GRISHINA	{"email": "grishinayana-041963@postgrespro.ru", "phone": "+70377001160"}
0005434639353	523BD6	7304 013585	VLADIMIR KISELEV	{"phone": "+70942762232"}
0005434639354	4E1E76	6247 040872	VLADIMIR ZAYCEV	{"email": "zaycevvladimir.07031978@postgrespro.ru", "phone": "+70882229607"}
0005434639355	0F8EE6	7788 384753	IVAN ZAKHAROV	{"phone": "+70597099485"}
0005434639356	11CEF6	6108 560702	ALEKSEY TIKHONOV	{"email": "tikhonov.a-051967@postgrespro.ru", "phone": "+70053388312"}
0005434639357	DD8251	2732 635716	LARISA PAVLOVA	{"phone": "+70819673473"}
0005434639358	DD8251	1230 611789	YURIY OSIPOV	{"phone": "+70272600094"}
0005434639359	72B6E5	1247 811171	ANDREY MIRONOV	{"phone": "+70329137789"}
0005434639360	ACC905	3845 742859	OLEG ANTONOV	{"email": "antonov.o-1976@postgrespro.ru", "phone": "+70461517360"}
0005434639361	BB4EA3	7668 354645	VLADIMIR SAVELEV	{"email": "v.savelev.26021971@postgrespro.ru", "phone": "+70996694141"}
0005434639362	01535E	7391 092341	ROMAN EGOROV	{"phone": "+70369695944"}
0005434639363	01535E	5607 696364	VLADIMIR SEMENOV	{"email": "vladimir.semenov-25081973@postgrespro.ru", "phone": "+70505563160"}
0005434639364	01535E	4349 455593	GEORGIY FEDOTOV	{"email": "fedotovg-1966@postgrespro.ru", "phone": "+70831063707"}
0005434639365	3998A7	9382 548494	VIKTORIYA VOROBEVA	{"email": "vorobeva.viktoriya.31071954@postgrespro.ru", "phone": "+70987127776"}
0005434639366	3998A7	9581 493496	SVETLANA PAVLOVA	{"email": "pavlovas-18121975@postgrespro.ru", "phone": "+70055268503"}
0005434639367	D2F88D	4707 263312	IRINA POPOVA	{"phone": "+70856097478"}
0005434639368	8E153F	8465 117354	DARYA TIMOFEEVA	{"phone": "+70262872744"}
0005434639369	8E7914	8268 256310	MAKSIM ILIN	{"email": "ilin.m_13121974@postgrespro.ru", "phone": "+70561601059"}
0005434639370	54030C	1558 414469	NIKITA MARTYNOV	{"email": "martynovnikita-28021979@postgrespro.ru", "phone": "+70924556953"}
0005434639371	BF49F5	0436 021910	ROMAN PETROV	{"email": "petrov-r-31071981@postgrespro.ru", "phone": "+70197441220"}
0005434639372	BE832A	9296 841400	YURIY SIDOROV	{"email": "yuriy.sidorov_1976@postgrespro.ru", "phone": "+70136190171"}
0005434639373	1E2F57	4970 104736	EKATERINA OSIPOVA	{"email": "e-osipova_1969@postgrespro.ru", "phone": "+70105361575"}
0005434639374	1E2F57	4912 449937	MARINA VASILEVA	{"phone": "+70524741956"}
0005434639375	07C8C0	7469 692305	EKATERINA DMITRIEVA	{"email": "dmitrievae_1975@postgrespro.ru", "phone": "+70331081958"}
0005434639376	B63A77	3747 971868	VLADIMIR IVANOV	{"email": "vladimirivanov-10111976@postgrespro.ru", "phone": "+70964534528"}
0005434639377	537EDA	1558 012438	VIKTOR KOROLEV	{"phone": "+70460966124"}
0005434639378	537EDA	9878 637823	MIKHAIL OSIPOV	{"phone": "+70483853192"}
0005434639379	59C97C	4219 508705	VLADIMIR SCHERBAKOV	{"phone": "+70075575964"}
0005434639380	59C97C	2445 438695	ANDREY POPOV	{"phone": "+70945681746"}
0005434639381	59C97C	3010 734948	VLADIMIR BORISOV	{"email": "borisov.vladimir.22111970@postgrespro.ru", "phone": "+70347695020"}
0005434639382	2AA6C6	0970 184286	KSENIYA AFANASEVA	{"email": "afanaseva-k_29071961@postgrespro.ru", "phone": "+70885278060"}
0005434639383	BD32EF	2362 519407	ALEKSEY KUZMIN	{"phone": "+70505213926"}
0005434639384	BD32EF	1554 035844	MARAT NIKITIN	{"email": "m.nikitin-10081952@postgrespro.ru", "phone": "+70812815380"}
0005434639385	DCE763	7855 817883	DANIIL SCHERBAKOV	{"phone": "+70316205312"}
0005434639386	870447	2816 783574	ALEKSEY VASILEV	{"phone": "+70000832066"}
0005434639387	5AB0A0	1097 657701	ALEKSANDR ZAYCEV	{"email": "aleksandrzaycev1967@postgrespro.ru", "phone": "+70558796514"}
0005434639388	F65A4A	3200 830295	ANTON NIKITIN	{"email": "antonnikitin.1969@postgrespro.ru", "phone": "+70999913137"}
0005434639389	872BC8	2275 881301	ANDREY SERGEEV	{"email": "andrey-sergeev.25011967@postgrespro.ru", "phone": "+70746892809"}
0005434639390	872BC8	7562 224436	ALINA KOROLEVA	{"phone": "+70111281749"}
0005434639391	614DAE	8570 874381	TAMARA ISAEVA	{"phone": "+70301564793"}
0005434639392	DAFC2A	4897 881718	VIKTOR MAKAROV	{"phone": "+70908251606"}
0005434639393	DAFC2A	2806 397106	RIMMA TIMOFEEVA	{"email": "timofeevarimma021969@postgrespro.ru", "phone": "+70641758281"}
0005434639394	1A659D	7594 840514	VALENTINA SERGEEVA	{"email": "sergeeva_valentina031979@postgrespro.ru", "phone": "+70053087315"}
0005434639395	668C6F	1388 082485	ILYA IVANOV	{"phone": "+70808351550"}
0005434639396	E7CCF3	5337 073793	ANTON NIKOLAEV	{"phone": "+70920723638"}
0005434639397	736B8C	7136 621007	TATYANA IVANOVA	{"email": "ivanova_t_051980@postgrespro.ru", "phone": "+70965795857"}
0005434639398	5B5AAC	1474 725364	ALEKSEY PETROV	{"email": "petrov_aleksey-051970@postgrespro.ru", "phone": "+70782390047"}
0005434639399	5B5AAC	1535 533964	MIKHAIL ROMANOV	{"email": "romanov.mikhail_12071978@postgrespro.ru", "phone": "+70824263126"}
0005434639400	561009	3676 355537	EVGENIY STEPANOV	{"email": "stepanov.e_1972@postgrespro.ru", "phone": "+70946827473"}
0005434639401	561009	9528 077344	NIKITA ANTONOV	{"email": "nantonov_071968@postgrespro.ru", "phone": "+70033634728"}
0005434639402	934839	5730 811548	ANATOLIY PETROV	{"email": "petrov_anatoliy_111974@postgrespro.ru", "phone": "+70443355923"}
0005434639403	934839	3759 547462	TAMARA KOMAROVA	{"phone": "+70593058592"}
0005434639404	934839	4263 785284	DARYA MALYSHEVA	{"phone": "+70989316820"}
0005434639405	2BE184	8720 869532	ALEKSANDR SOLOVEV	{"phone": "+70340437235"}
0005434639406	2BE184	1233 401470	GALINA NIKOLAEVA	{"email": "nikolaeva.g.1982@postgrespro.ru", "phone": "+70022195604"}
0005434639407	2BE184	5399 151587	GALINA MATVEEVA	{"email": "matveeva-galina.03051979@postgrespro.ru", "phone": "+70499573135"}
0005434639408	FBE6FE	7464 848092	RUSLAN ZAYCEV	{"email": "zaycevr081991@postgrespro.ru", "phone": "+70721396912"}
0005434639409	0268FF	4686 272615	TATYANA TARASOVA	{"email": "tatyana-tarasova_1978@postgrespro.ru", "phone": "+70734613558"}
0005434639410	AF8B36	3093 636721	YURIY KUZNECOV	{"email": "y-kuznecov.091975@postgrespro.ru", "phone": "+70109949359"}
0005434639411	AF8B36	4862 565789	VIKTOR FROLOV	{"phone": "+70458180707"}
0005434639412	DE054B	2167 483579	VALENTINA MOROZOVA	{"email": "vmorozova-1969@postgrespro.ru", "phone": "+70523162621"}
0005434639413	DE054B	9211 619819	SERGEY ANTONOV	{"phone": "+70987015388"}
0005434639414	4DE6BA	8988 186773	VLADIMIR POPOV	{"email": "v.popov_1978@postgrespro.ru", "phone": "+70760964648"}
0005434639415	1BA5FC	3111 617306	NIKOLAY KUZNECOV	{"email": "kuznecov-n-1978@postgrespro.ru", "phone": "+70991175026"}
0005434639416	1BA5FC	5104 101905	LARISA AFANASEVA	{"phone": "+70251273603"}
0005434639417	8141FB	4978 600906	IVAN VASILEV	{"email": "i_vasilev_1962@postgrespro.ru", "phone": "+70674174851"}
0005434639419	C46874	4601 913687	VIKTOR SAVELEV	{"email": "v.savelev021966@postgrespro.ru", "phone": "+70307217785"}
0005434639420	C46874	2868 037070	TATYANA KONDRATEVA	{"email": "tatyana_kondrateva.031969@postgrespro.ru", "phone": "+70746284133"}
0005434639421	4DA410	2535 299274	DMITRIY ZAYCEV	{"email": "zaycev-d_061979@postgrespro.ru", "phone": "+70839191329"}
0005434639422	E5E0AD	5652 164118	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov.091971@postgrespro.ru", "phone": "+70874568895"}
0005434639423	9DBD8C	1753 583062	NADEZHDA MELNIKOVA	{"phone": "+70168261574"}
0005434639424	5BA760	3643 231540	MIKHAIL POPOV	{"phone": "+70663388746"}
0005434639425	AF740E	7837 300896	ARINA IVANOVA	{"phone": "+70668469603"}
0005434639426	AF740E	7246 265539	VIKTOR POPOV	{"email": "popov-viktor-031960@postgrespro.ru", "phone": "+70096832600"}
0005434639427	1E7234	4222 229438	ALEKSEY SHEVCHENKO	{"email": "aleksey.shevchenko071983@postgrespro.ru", "phone": "+70175910048"}
0005434639428	296180	5965 286921	IGOR POPOV	{"email": "popov.igor051974@postgrespro.ru", "phone": "+70564001088"}
0005434639429	9506A1	0155 525984	EVGENIY YAKOVLEV	{"email": "yakovlev.evgeniy.14081974@postgrespro.ru", "phone": "+70107094688"}
0005434639430	49905A	6807 039981	NIKOLAY GUSEV	{"email": "gusev.n-101974@postgrespro.ru", "phone": "+70442460870"}
0005434639431	900B54	9938 358299	OLEG GORBUNOV	{"phone": "+70344483164"}
0005434639432	D8B1EA	0270 711494	ILYA ROMANOV	{"email": "ilya.romanov111960@postgrespro.ru", "phone": "+70464801592"}
0005434639433	011877	4151 815752	LIDIYA GORBUNOVA	{"email": "gorbunova.lidiya_051980@postgrespro.ru", "phone": "+70457576972"}
0005434639434	011877	0682 923020	TAMARA KOROLEVA	{"phone": "+70763109546"}
0005434639435	7EE3DF	9562 658918	ELENA NIKOLAEVA	{"phone": "+70548578843"}
0005434639436	7EE3DF	7858 303731	VLADIMIR KUZNECOV	{"phone": "+70651407611"}
0005434639437	899259	5988 566688	ALENA VLASOVA	{"phone": "+70499122743"}
0005434639438	899259	5279 797686	DANILA MAKAROV	{"email": "d-makarov-1964@postgrespro.ru", "phone": "+70630413183"}
0005434639439	407735	3807 975181	DMITRIY GRIGOREV	{"email": "dmitriy_grigorev_03021965@postgrespro.ru", "phone": "+70687447012"}
0005434639440	407735	5202 272475	MIKHAIL CHERNOV	{"phone": "+70740922298"}
0005434639441	5FC6FB	1064 085931	TATYANA ANTONOVA	{"phone": "+70856755155"}
0005434639442	5FC6FB	8878 462836	ALLA ANDREEVA	{"phone": "+70919041723"}
0005434639443	97C97A	3554 037397	VALENTINA FADEEVA	{"email": "fadeeva_v111965@postgrespro.ru", "phone": "+70142810899"}
0005434639444	2FB834	1733 018506	TATYANA BORISOVA	{"email": "borisova-t1979@postgrespro.ru", "phone": "+70688323426"}
0005434639445	2FB834	4423 314360	KONSTANTIN ISAEV	{"email": "isaev-k_041976@postgrespro.ru", "phone": "+70663648682"}
0005434639446	FFDD4D	6415 903670	IVAN MOROZOV	{"phone": "+70973511490"}
0005434639447	FFDD4D	8434 712754	ANDREY TIMOFEEV	{"phone": "+70084284613"}
0005434639448	D26A27	6480 284987	MIKHAIL KUZMIN	{"email": "kuzmin-m_1971@postgrespro.ru", "phone": "+70676636328"}
0005434639449	060447	0506 441000	VALERIY NIKOLAEV	{"email": "nikolaev.v-26081970@postgrespro.ru", "phone": "+70838397083"}
0005434639450	43EF14	0561 956181	OLEG DMITRIEV	{"email": "odmitriev-1959@postgrespro.ru", "phone": "+70300181018"}
0005434639451	FE3F8E	5284 409376	KIRILL KUZMIN	{"email": "k-kuzmin.02111970@postgrespro.ru", "phone": "+70359694294"}
0005434639452	E1E688	5346 796856	NATALYA YAKOVLEVA	{"phone": "+70741015288"}
0005434639453	75892A	6345 920756	ALEKSEY SOROKIN	{"email": "sorokin-aleksey_1982@postgrespro.ru", "phone": "+70232963019"}
0005434639454	DE3D62	9216 837862	TATYANA KOVALEVA	{"phone": "+70323132045"}
0005434639455	DE3D62	7081 728238	RAISA TITOVA	{"email": "r_titova31051966@postgrespro.ru", "phone": "+70221164992"}
0005434639456	DE3D62	5708 555235	ELENA RODIONOVA	{"email": "rodionova-e.1973@postgrespro.ru", "phone": "+70240610935"}
0005434639457	B98102	9482 120877	DANIIL AFANASEV	{"phone": "+70778119212"}
0005434639458	B98102	2094 476818	TAMARA ZOTOVA	{"email": "tamara-zotova.1962@postgrespro.ru", "phone": "+70192589956"}
0005434639459	B98102	2116 999135	ARTEM AFANASEV	{"email": "afanasevartem.1959@postgrespro.ru", "phone": "+70343283916"}
0005434639460	F0FA52	2277 600627	ANNA IVANOVA	{"phone": "+70397360318"}
0005434639461	F34EF2	5284 089051	NIKOLAY BARANOV	{"phone": "+70209080358"}
0005434639462	F34EF2	2029 154244	TATYANA KRASNOVA	{"phone": "+70913918772"}
0005434639463	F34EF2	4870 659170	YULIYA SMIRNOVA	{"phone": "+70437690138"}
0005434639464	91AE98	6591 047557	GALINA SMIRNOVA	{"phone": "+70518373698"}
0005434639465	CD3F76	3511 919928	VLADIMIR SAVELEV	{"phone": "+70149931368"}
0005434639466	A462EA	4732 605013	LIDIYA NIKOLAEVA	{"phone": "+70238038686"}
0005434639467	125F79	6010 899134	VERA SIDOROVA	{"phone": "+70979621642"}
0005434639468	1FDE9B	0411 605616	ALENA YUDINA	{"phone": "+70253015178"}
0005434639469	1FDE9B	2921 891433	ANDREY SOKOLOV	{"phone": "+70418313965"}
0005434639470	1FDE9B	7085 625312	ELENA SMIRNOVA	{"phone": "+70029039536"}
0005434639471	C3D8C2	4773 150182	ANNA NESTEROVA	{"phone": "+70107915816"}
0005434639472	2B249D	7072 349053	VYACHESLAV PETROV	{"phone": "+70057210215"}
0005434639473	A482EF	9801 510833	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_g-1967@postgrespro.ru", "phone": "+70806387521"}
0005434639474	721760	3832 284816	TATYANA ANISIMOVA	{"email": "tatyana.anisimova04071963@postgrespro.ru", "phone": "+70716383413"}
0005434639531	9FF367	0128 356113	VALENTINA MIKHAYLOVA	{"phone": "+70735817603"}
0005434639475	721760	6435 627337	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov-051981@postgrespro.ru", "phone": "+70368920694"}
0005434639476	721760	4812 895209	MARIYA LAZAREVA	{"email": "mlazareva-1968@postgrespro.ru", "phone": "+70959592695"}
0005434639477	CE453F	1534 938915	DANIYA ALEKSANDROVA	{"phone": "+70293825624"}
0005434639478	CE453F	3970 410798	VYACHESLAV ZAKHAROV	{"email": "zakharov_v.121977@postgrespro.ru", "phone": "+70216154989"}
0005434639479	DD9836	0734 839730	OLGA RYABOVA	{"email": "olgaryabova1959@postgrespro.ru", "phone": "+70570168124"}
0005434639480	A7928B	3049 388290	LYUDMILA ROMANOVA	{"email": "lyudmila-romanova1970@postgrespro.ru", "phone": "+70997723193"}
0005434639481	A7928B	2323 206179	INGA LEBEDEVA	{"email": "lebedeva.i-111956@postgrespro.ru", "phone": "+70135973272"}
0005434639482	E2CFBD	9497 512061	IVAN MATVEEV	{"phone": "+70204138839"}
0005434639779	7BD802	8039 111666	VENIAMIN ANTONOV	{"phone": "+70408236249"}
0005434639483	F6A38B	0870 944575	NIKITA VOLKOV	{"email": "nikita.volkov1967@postgrespro.ru", "phone": "+70869982366"}
0005434639484	72FC30	1568 671967	EDUARD ANDREEV	{"email": "andreeveduard_1980@postgrespro.ru", "phone": "+70495914394"}
0005434639485	72FC30	7301 978064	IVAN KOZLOV	{"email": "ivan_kozlov-031975@postgrespro.ru", "phone": "+70965098920"}
0005434639486	5C96DF	7018 017280	VERA POTAPOVA	{"phone": "+70867966769"}
0005434639487	CD6E8A	8805 807462	NATALYA KUZNECOVA	{"email": "natalya_kuznecova-041975@postgrespro.ru", "phone": "+70845082178"}
0005434639488	CD6E8A	3315 109492	MARIYA ORLOVA	{"email": "orlovamariya_1959@postgrespro.ru", "phone": "+70980279786"}
0005434639489	B017B8	9636 416656	ALEKSEY BELOV	{"phone": "+70535306552"}
0005434639490	B017B8	6830 191706	MARINA DAVYDOVA	{"phone": "+70855891395"}
0005434639491	8C5626	8954 241627	LYUDMILA SMIRNOVA	{"email": "smirnova-l-24041960@postgrespro.ru", "phone": "+70256749566"}
0005434639492	18B0AC	1893 331618	SERGEY VASILEV	{"phone": "+70859313023"}
0005434639493	18B0AC	3021 435190	ALEKSANDR IVANOV	{"email": "ivanov-a_28121982@postgrespro.ru", "phone": "+70151866460"}
0005434639494	EB9919	9480 296995	ZOYA FILATOVA	{"email": "filatova-z.1974@postgrespro.ru", "phone": "+70448706470"}
0005434639495	EB9919	2249 154825	SOFIYA KOZLOVA	{"email": "kozlova.s091970@postgrespro.ru", "phone": "+70413642256"}
0005434639496	78BE56	5655 952185	OLEG KUZMIN	{"email": "oleg-kuzmin101968@postgrespro.ru", "phone": "+70007841661"}
0005434639497	66CCB0	8389 148685	EVDOKIYA OSIPOVA	{"phone": "+70924856234"}
0005434639498	4887BC	5029 330896	GALINA PETROVA	{"phone": "+70444806809"}
0005434639499	A829DC	1187 254312	VLADIMIR GORBUNOV	{"phone": "+70680520839"}
0005434639500	1D2776	6378 121906	VLADIMIR MEDVEDEV	{"phone": "+70286712281"}
0005434639501	C148C0	4838 295215	YURIY KUDRYASHOV	{"phone": "+70799331607"}
0005434639502	103003	3086 005132	ALEKSANDR KONOVALOV	{"email": "konovalov-a.04011977@postgrespro.ru", "phone": "+70885978497"}
0005434639503	69B4BB	2959 740577	VALENTINA POPOVA	{"email": "vpopova_031971@postgrespro.ru", "phone": "+70850070598"}
0005434639504	E4D3B8	5971 886281	TAMARA IVANOVA	{"email": "tamara.ivanova.02031963@postgrespro.ru", "phone": "+70571731134"}
0005434639505	E4D3B8	2148 110620	NIKITA GERASIMOV	{"email": "gerasimov.nikita.1978@postgrespro.ru", "phone": "+70810581172"}
0005434639506	E4D3B8	2762 877479	EKATERINA ANISIMOVA	{"phone": "+70280583851"}
0005434639507	D0C070	1939 535176	DENIS VOLKOV	{"email": "d-volkov-13111982@postgrespro.ru", "phone": "+70634147530"}
0005434639508	D0C070	2671 343860	VLADIMIR NAZAROV	{"email": "v_nazarov-111965@postgrespro.ru", "phone": "+70069633911"}
0005434639509	FEE07A	7674 737294	ALEKSANDR KAZAKOV	{"phone": "+70546196703"}
0005434639510	FEE07A	0775 835406	STEPAN NIKOLAEV	{"email": "s.nikolaev_1958@postgrespro.ru", "phone": "+70965287751"}
0005434639511	4FF215	9135 196421	ARTEM PAVLOV	{"email": "artem-pavlov-1977@postgrespro.ru", "phone": "+70366897405"}
0005434639512	4FF215	0018 449337	ALEKSANDR MELNIKOV	{"email": "amelnikov091979@postgrespro.ru", "phone": "+70379163184"}
0005434639513	4FF215	3027 664726	VLADIMIR FEDOROV	{"phone": "+70751264349"}
0005434639514	7C3574	8559 976955	IRINA PAVLOVA	{"email": "i_pavlova08011968@postgrespro.ru", "phone": "+70525800861"}
0005434639515	F5FF18	1070 082314	DMITRIY PAVLOV	{"phone": "+70417588959"}
0005434639516	F5FF18	0691 344517	ALEKSEY KISELEV	{"phone": "+70363044781"}
0005434639517	B1D8DC	6930 124558	GRIGORIY FEDOTOV	{"phone": "+70492714725"}
0005434639518	A6996C	1840 793706	VASILIY GERASIMOV	{"email": "gerasimov.v_111984@postgrespro.ru", "phone": "+70106125130"}
0005434639519	DAF66E	1650 671496	MARINA FADEEVA	{"phone": "+70649564092"}
0005434639520	5C2AE7	6682 421727	VIKTOR CHERNOV	{"phone": "+70456951000"}
0005434639521	92B1CF	3578 959896	OKSANA SOKOLOVA	{"phone": "+70956428163"}
0005434639522	6B02C8	6219 088036	VASILIY KUZNECOV	{"email": "vasiliy.kuznecov_1982@postgrespro.ru", "phone": "+70634331482"}
0005434639523	6B02C8	8541 664815	ALBINA ALEKSEEVA	{"phone": "+70063957100"}
0005434639524	223E06	4739 570356	OLGA MOISEEVA	{"email": "o.moiseeva_1966@postgrespro.ru", "phone": "+70615249409"}
0005434639525	3D3FA2	6412 881601	NATALYA CHERNOVA	{"email": "chernova_n.1983@postgrespro.ru", "phone": "+70277751790"}
0005434639526	3D3FA2	1129 088223	MARIYA MOISEEVA	{"phone": "+70897640105"}
0005434639527	3D3FA2	5572 453449	ALEKSANDR GORBUNOV	{"phone": "+70675319466"}
0005434639528	652907	3207 307202	ELIZAVETA KOZLOVA	{"email": "elizaveta_kozlova1971@postgrespro.ru", "phone": "+70604074562"}
0005434639529	A446A2	3095 791603	SERGEY KONOVALOV	{"email": "konovalovsergey-1981@postgrespro.ru", "phone": "+70887922519"}
0005434639530	97C945	1725 330758	IRINA ANDREEVA	{"phone": "+70012704940"}
0005434639532	8D1CE7	5015 275310	MARIYA KALININA	{"email": "kalinina-m_04091959@postgrespro.ru", "phone": "+70981775560"}
0005434639533	56C868	3640 461690	SERGEY IVANOV	{"phone": "+70255115168"}
0005434639534	56C868	8755 828753	VASILIY MAKSIMOV	{"phone": "+70795094515"}
0005434639535	38BDB5	3951 911618	VALERIY NIKOLAEV	{"phone": "+70503015597"}
0005434639536	38BDB5	3955 498921	MAKSIM TARASOV	{"phone": "+70296021563"}
0005434639537	A3613F	6817 713557	ALEKSEY VASILEV	{"email": "aleksey.vasilev21091971@postgrespro.ru", "phone": "+70215817181"}
0005434639538	98E3BC	5020 623379	EKATERINA NAUMOVA	{"phone": "+70233297784"}
0005434639539	98E3BC	1390 035632	ANNA KRASNOVA	{"email": "anna_krasnova_1969@postgrespro.ru", "phone": "+70182406733"}
0005434639540	99596F	9957 866619	IRINA ROMANOVA	{"email": "irina_romanova_19041966@postgrespro.ru", "phone": "+70655615942"}
0005434639541	1A0B52	3576 980929	ELIZAVETA AFANASEVA	{"email": "e-afanaseva-18091964@postgrespro.ru", "phone": "+70523142582"}
0005434639542	745CF8	5932 926817	AZAT NAZAROV	{"email": "a-nazarov_031970@postgrespro.ru", "phone": "+70820760955"}
0005434639543	745CF8	7800 917141	ALEKSANDR EGOROV	{"phone": "+70882925671"}
0005434639544	61F388	5251 433199	VALENTINA MALYSHEVA	{"email": "vmalysheva1964@postgrespro.ru", "phone": "+70471952271"}
0005434639545	FDC62C	7745 867303	VITALIY VASILEV	{"email": "vasilev_vitaliy011973@postgrespro.ru", "phone": "+70067975713"}
0005434639546	32275B	5130 724198	TATYANA EFIMOVA	{"phone": "+70505006008"}
0005434639547	0C5E4A	9966 646116	TATYANA ANDREEVA	{"email": "t_andreeva.061975@postgrespro.ru", "phone": "+70857967612"}
0005434639548	044B18	9806 799447	NATALYA EFREMOVA	{"email": "n.efremova-031987@postgrespro.ru", "phone": "+70711185410"}
0005434639549	D5479D	4984 868385	KRISTINA PAVLOVA	{"email": "kristina.pavlova-1983@postgrespro.ru", "phone": "+70841338244"}
0005434639550	D5479D	8911 574150	VYACHESLAV ORLOV	{"email": "vyacheslav-orlov_17011976@postgrespro.ru", "phone": "+70942825100"}
0005434639551	14E63E	0446 533166	LYUDMILA NESTEROVA	{"phone": "+70560726533"}
0005434639552	14E63E	7457 932221	ELENA KONOVALOVA	{"email": "konovalova-e_24071972@postgrespro.ru", "phone": "+70102299044"}
0005434639553	A7940F	5558 100027	VERA DANILOVA	{"email": "danilova.v21121975@postgrespro.ru", "phone": "+70670206129"}
0005434639554	2C6282	6768 429843	VIOLETTA ILINA	{"email": "ilina.v-01051961@postgrespro.ru", "phone": "+70681356565"}
0005434639555	1EE7DE	1826 214535	EVGENIY SIDOROV	{"email": "evgeniy.sidorov-01021970@postgrespro.ru", "phone": "+70432146925"}
0005434639556	ECD012	3194 083703	SERGEY DAVYDOV	{"email": "davydov_s.1968@postgrespro.ru", "phone": "+70061026215"}
0005434639557	509A65	7202 202592	SERGEY SOROKIN	{"phone": "+70013205251"}
0005434639558	B1D3A4	8100 290697	OLGA TARASOVA	{"email": "olga.tarasova.021968@postgrespro.ru", "phone": "+70432578725"}
0005434639559	9E19A3	3811 184107	ALEKSEY SOROKIN	{"email": "sorokin.aleksey021965@postgrespro.ru", "phone": "+70672090651"}
0005434639560	0CAFE4	2294 238899	VASILIY KUZNECOV	{"phone": "+70140859483"}
0005434639561	0CAFE4	0506 716009	MAKAR ANDREEV	{"email": "andreev_m-1979@postgrespro.ru", "phone": "+70991358613"}
0005434639562	3D01C1	3688 406336	SVETLANA VASILEVA	{"email": "svasileva.24111978@postgrespro.ru", "phone": "+70514795488"}
0005434639563	3D01C1	2698 005366	ELENA KUDRYASHOVA	{"email": "elena-kudryashova_16021973@postgrespro.ru", "phone": "+70958691093"}
0005434639564	6C75C6	6267 354308	GULNARA NAUMOVA	{"email": "gulnara.naumova-051974@postgrespro.ru", "phone": "+70985598584"}
0005434639565	C56464	0796 720694	ANNA MOISEEVA	{"email": "amoiseeva_1971@postgrespro.ru", "phone": "+70454896746"}
0005434639566	C56464	8041 201196	IRINA RODIONOVA	{"phone": "+70576363029"}
0005434639567	78C4E0	1327 350473	SERGEY MIKHAYLOV	{"email": "sergey.mikhaylov.061981@postgrespro.ru", "phone": "+70131684560"}
0005434639568	78C4E0	3520 186524	ANTON MOROZOV	{"phone": "+70945876989"}
0005434639569	FEC1AE	7800 244317	YURIY STEPANOV	{"email": "stepanovy071961@postgrespro.ru", "phone": "+70896514549"}
0005434639570	2D436C	7400 637631	ALEKSANDR TARASOV	{"email": "atarasov_121977@postgrespro.ru", "phone": "+70455296971"}
0005434639571	6CEDA5	4754 846716	MAKSIM EGOROV	{"email": "maksim-egorov_27051961@postgrespro.ru", "phone": "+70331363225"}
0005434639572	D4B9D8	1127 199702	TATYANA KOROLEVA	{"email": "t-koroleva_111970@postgrespro.ru", "phone": "+70373916053"}
0005434639573	AF0879	4095 986377	ANATOLIY SERGEEV	{"email": "asergeev_081978@postgrespro.ru", "phone": "+70908763778"}
0005434639574	AF0879	5510 718872	SVETLANA GRISHINA	{"phone": "+70600924563"}
0005434639575	4862D7	3857 925585	YULIYA IVANOVA	{"phone": "+70361537204"}
0005434639576	4862D7	6853 536785	YANINA LOGINOVA	{"phone": "+70643453941"}
0005434639577	A452AC	6311 592317	OLGA SOKOLOVA	{"email": "olga_sokolova_041983@postgrespro.ru", "phone": "+70111198355"}
0005434639578	B2C941	9733 695885	TATYANA EFIMOVA	{"email": "efimova-t1966@postgrespro.ru", "phone": "+70900043282"}
0005434639579	B2C941	8594 624436	ANNA SOLOVEVA	{"phone": "+70256142867"}
0005434639580	E2CA60	8825 463885	VASILIY POPOV	{"phone": "+70386455141"}
0005434639581	24B5DE	0891 538281	GALINA DMITRIEVA	{"phone": "+70331936196"}
0005434639582	24B5DE	4653 750987	DMITRIY VASILEV	{"phone": "+70898596511"}
0005434639583	8C094F	2107 526187	DANILA SERGEEV	{"phone": "+70644667861"}
0005434639584	3CDB22	8950 113728	OLGA KOROLEVA	{"email": "koroleva_olga_12111966@postgrespro.ru", "phone": "+70239190549"}
0005434639585	1CF458	7233 267001	ANTONINA FEDOROVA	{"email": "antonina.fedorova_1974@postgrespro.ru", "phone": "+70709643624"}
0005434639586	ADD892	2376 513232	MARIYA GAVRILOVA	{"email": "mariyagavrilova-25101976@postgrespro.ru", "phone": "+70618197309"}
0005434639587	F1E2B2	2995 716803	NATALYA ABRAMOVA	{"email": "abramova.natalya-1973@postgrespro.ru", "phone": "+70994683250"}
0005434639588	F1E2B2	9954 072812	ALEKSEY MATVEEV	{"email": "matveevaleksey.18051982@postgrespro.ru", "phone": "+70833367248"}
0005434639589	AAA256	4660 956703	ANATOLIY NIKOLAEV	{"phone": "+70227073239"}
0005434639590	AAA256	3454 421385	ANATOLIY FROLOV	{"email": "a-frolov-22031979@postgrespro.ru", "phone": "+70249172145"}
0005434639591	616FEA	2770 713963	MAKSIM SIDOROV	{"email": "sidorovmaksim.10081976@postgrespro.ru", "phone": "+70964318657"}
0005434639592	7D82B0	4855 935603	SVETLANA ARKHIPOVA	{"email": "svetlana.arkhipova-1973@postgrespro.ru", "phone": "+70180342075"}
0005434639593	4CE0D1	8974 793666	ALEKSANDR FOMIN	{"phone": "+70951667405"}
0005434639594	5302ED	3210 816746	ALEKSEY SOROKIN	{"phone": "+70557867094"}
0005434639595	994B6A	6963 474544	SERGEY KUZNECOV	{"phone": "+70227732391"}
0005434639596	DB9CC7	1290 092431	IVAN FILIPPOV	{"email": "i-filippov_27081963@postgrespro.ru", "phone": "+70893249170"}
0005434639597	5D1391	5493 080875	POLINA NIKITINA	{"email": "nikitina_polina.101976@postgrespro.ru", "phone": "+70146544431"}
0005434639598	121A41	3403 482423	ELENA TITOVA	{"email": "elenatitova.01041977@postgrespro.ru", "phone": "+70358300691"}
0005434639599	FC454C	8490 445652	ELIZAVETA LAZAREVA	{"email": "elizaveta.lazareva1967@postgrespro.ru", "phone": "+70893192939"}
0005434639600	310D65	0433 055925	SERGEY KISELEV	{"email": "kiselevs_031972@postgrespro.ru", "phone": "+70711852067"}
0005434639601	B063F9	1883 028152	VLADIMIR MAKAROV	{"email": "makarovv04111965@postgrespro.ru", "phone": "+70176582024"}
0005434639602	9086FB	5968 381667	SVETLANA TIKHONOVA	{"phone": "+70334002004"}
0005434639603	9086FB	7086 929096	ELENA KOMAROVA	{"phone": "+70944285183"}
0005434639604	9AFBEE	8940 824632	VLADIMIR VLASOV	{"email": "v-vlasov.02011968@postgrespro.ru", "phone": "+70953544920"}
0005434639605	9AFBEE	9288 360026	ALEKSEY ROMANOV	{"email": "aleksey.romanov-1965@postgrespro.ru", "phone": "+70349733090"}
0005434639606	1FAFE5	1023 469911	YURIY GUSEV	{"phone": "+70343723285"}
0005434639607	07B96C	6800 008783	TATYANA SMIRNOVA	{"phone": "+70649641039"}
0005434639608	922C1D	8891 909688	TAMARA DENISOVA	{"phone": "+70585029961"}
0005434639609	BB0EB9	2012 487589	VLADIMIR GORBUNOV	{"email": "gorbunovv_03101979@postgrespro.ru", "phone": "+70318485231"}
0005434639610	BB0EB9	8760 654086	IVAN SERGEEV	{"phone": "+70540423233"}
0005434639611	BB0EB9	3356 164889	IGOR MEDVEDEV	{"phone": "+70316799176"}
0005434639612	ED5BFD	7395 075332	OLGA IVANOVA	{"email": "ivanova.olga-22081957@postgrespro.ru", "phone": "+70084328727"}
0005434639613	ED5BFD	6632 412519	MARINA GORBUNOVA	{"phone": "+70597535527"}
0005434639614	11E657	5993 347051	ANTON KOZLOV	{"phone": "+70374338645"}
0005434639615	11E657	8109 645620	VALERIY MIKHAYLOV	{"email": "mikhaylov_valeriy1982@postgrespro.ru", "phone": "+70412617576"}
0005434639616	F26F9D	6283 552873	SERGEY CHERNOV	{"email": "sergey-chernov_1980@postgrespro.ru", "phone": "+70656117821"}
0005434639617	2128DD	6643 761166	MARINA KULIKOVA	{"phone": "+70957391155"}
0005434639618	A2E394	0189 751342	NADEZHDA SAVELEVA	{"phone": "+70822264767"}
0005434639619	A2E394	8923 692811	VADIM IVANOV	{"phone": "+70485295536"}
0005434639620	5EC60F	4920 629276	EVGENIY NIKOLAEV	{"phone": "+70964831506"}
0005434639621	BDFD56	6627 955304	ROMAN DENISOV	{"email": "denisov_roman.1977@postgrespro.ru", "phone": "+70930071189"}
0005434639622	BDFD56	0583 205787	MILENA FEDOROVA	{"phone": "+70641919682"}
0005434639623	2ECE94	8096 039551	VERA SEMENOVA	{"email": "semenovav.021967@postgrespro.ru", "phone": "+70451801126"}
0005434639624	2ECE94	0635 084196	VERA FILATOVA	{"email": "filatovav-091968@postgrespro.ru", "phone": "+70974279945"}
0005434639625	2ECE94	0501 713772	MARIYA VASILEVA	{"email": "vasilevam1967@postgrespro.ru", "phone": "+70900280320"}
0005434639626	2ECE94	6410 718251	MAKSIM KISELEV	{"phone": "+70653320802"}
0005434639627	BB2952	7373 181413	VALENTINA BOGDANOVA	{"phone": "+70071017565"}
0005434639628	630EA7	7589 816502	NIKOLAY EGOROV	{"email": "egorov.nikolay19051978@postgrespro.ru", "phone": "+70770717088"}
0005434639629	CE10E8	9473 044901	GALINA BELOVA	{"phone": "+70907183528"}
0005434639630	CE10E8	3891 937126	SERGEY KRASNOV	{"email": "krasnov_s-1970@postgrespro.ru", "phone": "+70234627208"}
0005434639631	CF926B	1525 027170	ALEKSANDR DENISOV	{"phone": "+70078562788"}
0005434639632	4AEAC3	4633 716117	NATALIYA TROFIMOVA	{"email": "trofimovan_1960@postgrespro.ru", "phone": "+70323911407"}
0005434639633	67883D	4537 708241	ELENA MIKHAYLOVA	{"email": "mikhaylovaelena.1969@postgrespro.ru", "phone": "+70163533916"}
0005434639634	67883D	1960 424411	LEONID PAVLOV	{"phone": "+70964164398"}
0005434639635	32FF27	6077 315983	LYUDMILA KOZLOVA	{"email": "kozlova_l1969@postgrespro.ru", "phone": "+70881276780"}
0005434639636	60D0BC	9931 086339	VLADIMIR POPOV	{"phone": "+70287484289"}
0005434639637	51396D	3693 925080	LYUDMILA SEMENOVA	{"phone": "+70145792752"}
0005434639638	ACCFD7	4946 445838	VIKTOR KOZLOV	{"phone": "+70268714782"}
0005434639639	596F20	9550 278353	VALENTINA MOISEEVA	{"email": "moiseeva.v.041967@postgrespro.ru", "phone": "+70280077853"}
0005434639640	596F20	5569 185117	EVGENIY MAKAROV	{"email": "emakarov.28081959@postgrespro.ru", "phone": "+70390622900"}
0005434639641	ED1C86	9177 598338	YULIYA MIKHAYLOVA	{"email": "mikhaylova.y22101970@postgrespro.ru", "phone": "+70503495696"}
0005434639642	ED1C86	9850 316783	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov_18031965@postgrespro.ru", "phone": "+70750164723"}
0005434639643	F87853	0094 628922	POLINA SERGEEVA	{"email": "polina_sergeeva_1966@postgrespro.ru", "phone": "+70716521275"}
0005434639644	1FC4D7	1702 425387	GALINA PAVLOVA	{"phone": "+70226228971"}
0005434639645	5517F8	9434 045200	DANIIL KUZNECOV	{"email": "kuznecov-d.081966@postgrespro.ru", "phone": "+70417582961"}
0005434639646	447293	7345 248717	ALEKSEY SERGEEV	{"email": "sergeev_aleksey_1963@postgrespro.ru", "phone": "+70823257994"}
0005434639647	447293	4497 386967	YURIY OSIPOV	{"email": "yuriy.osipov_1966@postgrespro.ru", "phone": "+70374174352"}
0005434639648	447293	1731 248086	ROMAN VASILEV	{"email": "r.vasilev-10051961@postgrespro.ru", "phone": "+70510026164"}
0005434639649	28FF47	1275 023802	TATYANA KUZMINA	{"email": "tkuzmina_1984@postgrespro.ru", "phone": "+70573186739"}
0005434639650	1F037A	4611 997570	VIKTOR BELOV	{"phone": "+70820276935"}
0005434639651	2F3AF9	3598 524677	ANNA FILATOVA	{"email": "filatova.a-07041970@postgrespro.ru", "phone": "+70358398533"}
0005434639652	2F3AF9	5100 238103	ALEKSEY KUZMIN	{"email": "a_kuzmin1988@postgrespro.ru", "phone": "+70211467093"}
0005434639653	76DF30	4890 666312	IRINA KAZAKOVA	{"email": "kazakova_irina-081975@postgrespro.ru", "phone": "+70564597910"}
0005434639654	76DF30	6399 568801	EVGENIYA MIRONOVA	{"phone": "+70054013815"}
0005434639655	F0C1F8	0709 884007	LYUDMILA KOMAROVA	{"phone": "+70844077111"}
0005434654179	2CAD01	2145 157714	MARIYA ANDREEVA	{"phone": "+70709927571"}
0005434639656	9D9786	9067 469182	ALEKSANDR BONDARENKO	{"email": "a.bondarenko-01041967@postgrespro.ru", "phone": "+70106657466"}
0005434639657	9D9786	6485 349108	ALEKSANDR ROMANOV	{"phone": "+70192477684"}
0005434639658	9D9786	5258 857726	VALENTINA OVCHINNIKOVA	{"email": "v-ovchinnikova06021964@postgrespro.ru", "phone": "+70312213593"}
0005434639659	82381D	0698 107696	NATALYA MALYSHEVA	{"phone": "+70551549908"}
0005434639660	82381D	8427 442193	VERA SERGEEVA	{"email": "vera_sergeeva.02061973@postgrespro.ru", "phone": "+70219509675"}
0005434639661	1DE5EC	7588 403396	ALEKSANDR FROLOV	{"email": "frolov.a.18051975@postgrespro.ru", "phone": "+70008984347"}
0005434639662	8BCB22	7787 861289	ANASTASIYA EGOROVA	{"email": "anastasiya.egorova-28101966@postgrespro.ru", "phone": "+70016247047"}
0005434639663	E1800B	3376 703408	ALMIRA MAKSIMOVA	{"email": "maksimova-a-041971@postgrespro.ru", "phone": "+70940115102"}
0005434639664	113D67	9134 567717	VLADIMIR GORBUNOV	{"email": "gorbunov.v091968@postgrespro.ru", "phone": "+70788167702"}
0005434639665	113D67	6330 661835	VERA POPOVA	{"phone": "+70246391820"}
0005434639666	167353	2621 720959	ANDREY BELOV	{"email": "a_belov30031970@postgrespro.ru", "phone": "+70435467875"}
0005434639667	167353	8758 881157	MARINA MAKAROVA	{"phone": "+70641880455"}
0005434639668	281E3E	8215 348469	NADEZHDA KOZLOVA	{"email": "kozlova_n.11011966@postgrespro.ru", "phone": "+70796003665"}
0005434639669	281E3E	5965 165846	TATYANA VOROBEVA	{"email": "tatyana_vorobeva051961@postgrespro.ru", "phone": "+70759042017"}
0005434639670	60662B	2076 432249	LEV NIKITIN	{"email": "lev-nikitin-01101963@postgrespro.ru", "phone": "+70618352602"}
0005434639671	E8A7FA	0712 871335	DMITRIY ISAEV	{"phone": "+70273529205"}
0005434639672	2CA7E1	8905 843920	SVETLANA FROLOVA	{"email": "sfrolova_111985@postgrespro.ru", "phone": "+70026266990"}
0005434639673	62E2D8	4208 761056	NIKOLAY AFANASEV	{"phone": "+70861124244"}
0005434639674	72C82B	2658 916540	IRINA PETROVA	{"email": "i-petrova.21031974@postgrespro.ru", "phone": "+70589604060"}
0005434639675	995E65	7959 406708	LILIYA NAUMOVA	{"email": "naumova-l-021973@postgrespro.ru", "phone": "+70187296729"}
0005434639676	5E65BB	1930 714677	VERA ISAEVA	{"phone": "+70035690969"}
0005434639677	9852C3	4577 893044	ELENA IVANOVA	{"phone": "+70811544337"}
0005434639679	7319CE	2373 094283	VLADIMIR SMIRNOV	{"phone": "+70908335907"}
0005434639680	7319CE	2975 017161	VITALIY SHEVCHENKO	{"email": "v.shevchenko-1976@postgrespro.ru", "phone": "+70550406609"}
0005434639681	20573F	5288 898570	NATALYA KOLESNIKOVA	{"email": "natalyakolesnikova_1967@postgrespro.ru", "phone": "+70275204114"}
0005434639682	AC0FF1	4987 561789	ALEKSANDRA FILIPPOVA	{"phone": "+70268293590"}
0005434639683	4512FF	9203 837986	NADEZHDA FROLOVA	{"phone": "+70499285295"}
0005434639684	7932D8	8101 716951	GALINA KOMAROVA	{"phone": "+70568101335"}
0005434639685	38ACF5	5170 430239	OLGA ROMANOVA	{"email": "o-romanova_26021981@postgrespro.ru", "phone": "+70930895536"}
0005434639686	3F690D	2829 202128	NADEZHDA BOGDANOVA	{"email": "bogdanova-nadezhda.22121966@postgrespro.ru", "phone": "+70955200948"}
0005434639687	F93AC6	7226 105893	NIKOLAY FROLOV	{"phone": "+70585928016"}
0005434639688	EA4433	6370 419911	ANTON KRASNOV	{"phone": "+70186799559"}
0005434639689	EA4433	3451 712307	LEONID ROMANOV	{"email": "l-romanov.1971@postgrespro.ru", "phone": "+70763844828"}
0005434639690	4E929C	8697 835193	MATVEY FOMIN	{"email": "fomin-m.16091972@postgrespro.ru", "phone": "+70192516250"}
0005434639691	2571C7	5304 564789	MARIYA SEMENOVA	{"email": "mariyasemenova_071973@postgrespro.ru", "phone": "+70009027927"}
0005434639692	2ABCD6	2016 882663	ALEKSEY MIRONOV	{"email": "mironov_a_1973@postgrespro.ru", "phone": "+70215682300"}
0005434639693	2ABCD6	2086 859915	NIKOLAY KRASNOV	{"email": "krasnovnikolay_1971@postgrespro.ru", "phone": "+70326727915"}
0005434639694	38E1FF	5648 837043	VERA KUZMINA	{"email": "kuzmina.vera-23081960@postgrespro.ru", "phone": "+70908526835"}
0005434639695	330494	1312 921642	OLESYA NESTEROVA	{"email": "nesterova.o_23071978@postgrespro.ru", "phone": "+70398218413"}
0005434639696	FA468C	4587 747495	ANDREY MAKAROV	{"email": "makarov-a.1975@postgrespro.ru", "phone": "+70909583795"}
0005434639697	8FA0DC	9500 528174	YAROSLAV IVANOV	{"phone": "+70578739023"}
0005434639698	CD99A8	0311 260462	LYUDMILA LAZAREVA	{"phone": "+70502947979"}
0005434639699	CD99A8	7366 063443	ALEKSEY ALEKSANDROV	{"email": "a.aleksandrov.11071966@postgrespro.ru", "phone": "+70808331442"}
0005434639700	24AB41	9206 955441	VITALIY BORISOV	{"email": "vborisov-021982@postgrespro.ru", "phone": "+70092579316"}
0005434639701	24AB41	4285 876613	ANATOLIY PETROV	{"email": "petrov_anatoliy_071972@postgrespro.ru", "phone": "+70585333754"}
0005434639702	4BE37E	0031 364614	VITALIY MOISEEV	{"email": "moiseev-vitaliy.1967@postgrespro.ru", "phone": "+70211493878"}
0005434639703	4DF4D1	4704 095881	ALEKSANDR KUZNECOV	{"phone": "+70664937482"}
0005434639704	588322	1120 746261	NADEZHDA GRISHINA	{"email": "grishina-nadezhda_081968@postgrespro.ru", "phone": "+70790042864"}
0005434639705	88CE51	7386 425087	OLGA MARTYNOVA	{"phone": "+70648872718"}
0005434639706	88CE51	1997 725086	POLINA MARTYNOVA	{"email": "martynova-polina021980@postgrespro.ru", "phone": "+70651725615"}
0005434639707	E67879	7340 738172	LARISA KOZLOVA	{"phone": "+70548451029"}
0005434639708	DB3EAB	9050 665431	NIKOLAY PAVLOV	{"phone": "+70373348658"}
0005434639709	4D7200	5675 874342	VYACHESLAV MOISEEV	{"email": "moiseevvyacheslav_08071971@postgrespro.ru", "phone": "+70266536275"}
0005434639710	A636EA	7231 068658	PAVEL FILIPPOV	{"email": "filippov.pavel_1979@postgrespro.ru", "phone": "+70482082268"}
0005434639711	A636EA	4809 052564	MARINA EGOROVA	{"email": "egorovamarina.1967@postgrespro.ru", "phone": "+70485987530"}
0005434639712	540D76	4154 593836	ALEKSANDR GERASIMOV	{"phone": "+70874211698"}
0005434639713	540D76	1045 481023	YURIY SERGEEV	{"email": "yuriy.sergeev_1971@postgrespro.ru", "phone": "+70041682094"}
0005434639714	161D08	3048 375116	VLADIMIR TARASOV	{"phone": "+70849108978"}
0005434639715	A0F364	9691 690911	ELENA ZAKHAROVA	{"email": "zakharova.e-24041984@postgrespro.ru", "phone": "+70752101709"}
0005434639716	9083CC	0086 105112	NINA IVANOVA	{"email": "n-ivanova_30091979@postgrespro.ru", "phone": "+70200492698"}
0005434639717	B730FE	3485 374964	SERGEY VLASOV	{"phone": "+70405968801"}
0005434639718	063BC1	6281 797027	ALINA GORBUNOVA	{"email": "gorbunova-a.081967@postgrespro.ru", "phone": "+70741235173"}
0005434639719	4753E7	9708 359297	MIKHAIL SERGEEV	{"email": "sergeev_mikhail30101975@postgrespro.ru", "phone": "+70765746446"}
0005434639720	2CFFD2	0773 967498	PETR KUZNECOV	{"email": "kuznecov-p_1976@postgrespro.ru", "phone": "+70338971673"}
0005434639721	94E954	9718 914220	MARIYA KULIKOVA	{"phone": "+70943406719"}
0005434639722	EE6DDF	3395 932117	OLGA YAKOVLEVA	{"phone": "+70017360194"}
0005434639723	D2DCD5	9397 787251	VALERIY VOROBEV	{"phone": "+70475802594"}
0005434639724	BED1A1	3630 646193	SVETLANA KONDRATEVA	{"email": "svetlana-kondrateva-16051972@postgrespro.ru", "phone": "+70676406458"}
0005434639725	7A706F	6322 807425	IRINA KOROLEVA	{"phone": "+70029682787"}
0005434639726	B0F2CC	5155 512392	SERGEY KARPOV	{"phone": "+70231299255"}
0005434639727	B0F2CC	3742 837648	ELENA EGOROVA	{"phone": "+70029639909"}
0005434639728	B0F2CC	8161 795623	ALEKSANDR VASILEV	{"email": "avasilev-121974@postgrespro.ru", "phone": "+70169418210"}
0005434639729	41555E	0234 216004	ELENA MASLOVA	{"email": "elenamaslova02031981@postgrespro.ru", "phone": "+70849254061"}
0005434639730	8BD464	8259 635120	DMITRIY KOROLEV	{"email": "d-korolev1977@postgrespro.ru", "phone": "+70607553309"}
0005434639731	285A64	1741 601901	ALEKSANDR GAVRILOV	{"email": "gavrilova-121973@postgrespro.ru", "phone": "+70578125162"}
0005434639732	637AFD	8520 761942	AMINA DENISOVA	{"email": "denisova_amina_051966@postgrespro.ru", "phone": "+70028424975"}
0005434639733	637AFD	0208 710521	YURIY ZAKHAROV	{"phone": "+70773427581"}
0005434639734	B89ABB	7067 666233	VASILIY VASILEV	{"email": "vasilev-v1965@postgrespro.ru", "phone": "+70901125179"}
0005434639735	1A246C	9393 293477	NIKOLAY MELNIKOV	{"phone": "+70474361246"}
0005434639736	59C7E5	2047 302500	PAVEL POPOV	{"phone": "+70425394195"}
0005434639737	D585F0	0084 753366	IRINA RYABOVA	{"phone": "+70810920433"}
0005434639738	61CED1	4446 822315	LILIYA KOLESNIKOVA	{"email": "liliyakolesnikova13071965@postgrespro.ru", "phone": "+70503389060"}
0005434639739	61CED1	0141 987455	ILYA IVANOV	{"email": "ivanov_ilya_15101972@postgrespro.ru", "phone": "+70750657855"}
0005434639740	BD59A7	2304 387072	VLADIMIR PETROV	{"phone": "+70942844025"}
0005434639741	5ED9F5	4556 737626	VLADISLAV DAVYDOV	{"phone": "+70751632708"}
0005434639742	5ED9F5	2794 968965	NINA OSIPOVA	{"email": "osipova-n-041974@postgrespro.ru", "phone": "+70145366940"}
0005434639743	AFD35B	0591 525804	VIKTOR KUZNECOV	{"phone": "+70699969028"}
0005434639744	AFD35B	5049 115324	ELENA TITOVA	{"phone": "+70693480012"}
0005434639745	D9625B	7125 071848	TATYANA AKIMOVA	{"email": "tatyana-akimova.1976@postgrespro.ru", "phone": "+70763475438"}
0005434639746	D9625B	6094 182553	VYACHESLAV VOLKOV	{"email": "v_volkov_021971@postgrespro.ru", "phone": "+70166317996"}
0005434639747	9AD0B5	4388 738404	ALEKSANDR ORLOV	{"phone": "+70027035276"}
0005434639748	C69307	5966 215456	NATALYA GERASIMOVA	{"email": "gerasimovan_1975@postgrespro.ru", "phone": "+70506886987"}
0005434639749	CA6C15	6387 771208	ANATOLIY MOROZOV	{"phone": "+70673229562"}
0005434639750	DB0297	4513 321917	VALERIYA ZHUKOVA	{"email": "zhukova.valeriya1966@postgrespro.ru", "phone": "+70095565514"}
0005434639751	DB0297	1269 200457	ALEKSANDR VLASOV	{"email": "vlasova101977@postgrespro.ru", "phone": "+70646639316"}
0005434639752	F82447	2350 839314	VADIM POPOV	{"email": "popovvadim-30081970@postgrespro.ru", "phone": "+70485820300"}
0005434639753	44828A	8050 447124	ANATOLIY NIKITIN	{"email": "anatoliy_nikitin_02081964@postgrespro.ru", "phone": "+70385243861"}
0005434639754	32B450	9112 522062	LYUDMILA ABRAMOVA	{"email": "l_abramova_26051975@postgrespro.ru", "phone": "+70280313649"}
0005434639755	F3B8ED	1196 044669	VASILIY MIKHAYLOV	{"email": "mikhaylov.vasiliy-15051965@postgrespro.ru", "phone": "+70236578318"}
0005434639756	FCB1AE	4923 505993	OLGA FILIPPOVA	{"email": "filippovao-25031981@postgrespro.ru", "phone": "+70591507723"}
0005434639757	53D311	5781 625900	DMITRIY VASILEV	{"phone": "+70690693113"}
0005434639758	676709	1303 221338	ELENA IVANOVA	{"phone": "+70725052402"}
0005434639759	6C4D98	5483 295973	MIKHAIL IVANOV	{"email": "ivanov_mikhail-011979@postgrespro.ru", "phone": "+70363339329"}
0005434639760	DC4525	3336 298675	OLGA GORBUNOVA	{"phone": "+70311054204"}
0005434639761	DC4525	2880 343652	OLGA ZHURAVLEVA	{"email": "o.zhuravleva.031970@postgrespro.ru", "phone": "+70646142904"}
0005434639762	DC4525	1507 670117	DMITRIY DAVYDOV	{"email": "davydov-d1976@postgrespro.ru", "phone": "+70461036834"}
0005434639763	7DFA2B	2106 237195	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a_051974@postgrespro.ru", "phone": "+70945767923"}
0005434639764	7DFA2B	6113 027121	EVGENIY SOROKIN	{"email": "e_sorokin121984@postgrespro.ru", "phone": "+70879910746"}
0005434639765	A0425C	9933 061799	IRINA KAZAKOVA	{"phone": "+70856043404"}
0005434639766	A0425C	7025 402946	IRINA NESTEROVA	{"phone": "+70891859448"}
0005434639767	A3A7D7	1656 198800	LYUBOV MELNIKOVA	{"email": "lyubov-melnikova.021975@postgrespro.ru", "phone": "+70690052453"}
0005434639768	CB65B5	5126 713807	NAILYA IVANOVA	{"email": "nailya.ivanova-1968@postgrespro.ru", "phone": "+70703960687"}
0005434639769	CB65B5	4471 758730	ANASTASIYA MAKSIMOVA	{"phone": "+70591064606"}
0005434639770	CB65B5	5217 429803	ALEKSANDR MELNIKOV	{"phone": "+70061926766"}
0005434639771	BC7844	4560 976035	VLADLEN VASILEV	{"phone": "+70716944159"}
0005434639772	BC7844	8251 064096	EKATERINA KUZMINA	{"email": "ekuzmina_101969@postgrespro.ru", "phone": "+70610874777"}
0005434639773	139272	7329 362506	ELENA FROLOVA	{"email": "elena-frolova03041962@postgrespro.ru", "phone": "+70515078229"}
0005434639774	2AE266	0617 270441	SVETLANA BOGDANOVA	{"email": "bogdanova-svetlana-04071968@postgrespro.ru", "phone": "+70829652152"}
0005434639775	09301C	2031 015654	STANISLAV MOROZOV	{"phone": "+70323799705"}
0005434639776	66FC62	5200 709531	NINA ROMANOVA	{"phone": "+70746348108"}
0005434639777	577C96	9620 019871	ALEKSEY KULIKOV	{"phone": "+70104799167"}
0005434639778	14F49D	7679 187014	NATALIYA VOROBEVA	{"email": "vorobeva.n_26091971@postgrespro.ru", "phone": "+70984805529"}
0005434639780	0AEE42	5337 050131	VERONIKA SOLOVEVA	{"phone": "+70774229229"}
0005434639781	0AEE42	8281 373790	SVETLANA DANILOVA	{"email": "sdanilova_1972@postgrespro.ru", "phone": "+70556186578"}
0005434639782	AEF45A	3334 266734	VIKTOR ZHUKOV	{"phone": "+70266123571"}
0005434639783	7B14FF	1220 749929	MARGARITA BELYAEVA	{"phone": "+70690281663"}
0005434639784	B76254	5653 193755	ELIZAVETA NIKITINA	{"email": "elizaveta-nikitina12071985@postgrespro.ru", "phone": "+70910687127"}
0005434639785	B76254	7985 798586	EGOR SEMENOV	{"email": "egor.semenov_27121972@postgrespro.ru", "phone": "+70686933015"}
0005434639786	47442F	5916 788418	SERGEY ZAYCEV	{"email": "sergey_zaycev041969@postgrespro.ru", "phone": "+70227959606"}
0005434639787	7E08BD	7372 335973	VLADIMIR KUZNECOV	{"phone": "+70535555502"}
0005434639788	2FDCE6	5918 325512	NINA KUZMINA	{"email": "nina.kuzmina-1962@postgrespro.ru", "phone": "+70800115813"}
0005434639789	D6EE1D	7652 679518	NATALYA TARASOVA	{"phone": "+70837954355"}
0005434639790	D6EE1D	7156 001043	NADEZHDA SIDOROVA	{"email": "nadezhda.sidorova-1964@postgrespro.ru", "phone": "+70556681985"}
0005434639791	3BDEBA	0357 339771	ANASTASIYA VOLKOVA	{"phone": "+70227012944"}
0005434639792	3BDEBA	0716 956205	LIDIYA PAVLOVA	{"phone": "+70840167112"}
0005434639793	34DEAB	3110 407942	MARINA TARASOVA	{"email": "tarasova.marina1981@postgrespro.ru", "phone": "+70267641835"}
0005434639794	34DEAB	2281 691529	SHAVKAT SCHERBAKOV	{"phone": "+70395518698"}
0005434639795	BA9448	1179 509744	MARINA VOLKOVA	{"email": "volkova-m1974@postgrespro.ru", "phone": "+70004651844"}
0005434639796	38DC9F	8220 511375	RUSLAN PAVLOV	{"email": "ruslanpavlov_1963@postgrespro.ru", "phone": "+70450129022"}
0005434639797	E49E1E	9245 876018	KIRILL BELOV	{"email": "belov-k_061980@postgrespro.ru", "phone": "+70751382267"}
0005434639798	7E437C	8394 910937	NINA EGOROVA	{"phone": "+70089369610"}
0005434639799	B848F9	6437 990374	LYUBOV NAZAROVA	{"phone": "+70019880009"}
0005434639800	787F59	4637 804156	ALEKSANDR SMIRNOV	{"email": "smirnova.1966@postgrespro.ru", "phone": "+70383788554"}
0005434639801	A76514	1704 422669	LYUBOV GRISHINA	{"email": "grishinal_061972@postgrespro.ru", "phone": "+70438834061"}
0005434639802	90A173	7204 206263	OLEG POPOV	{"email": "olegpopov-1972@postgrespro.ru", "phone": "+70098001110"}
0005434639803	84705F	7771 300830	TAMARA ALEKSEEVA	{"phone": "+70758049207"}
0005434639804	EEACE2	9258 229513	ANTONINA EGOROVA	{"email": "egorova.a1964@postgrespro.ru", "phone": "+70421365193"}
0005434639805	D1458C	3190 588524	SERGEY SOLOVEV	{"email": "sergey_solovev-1966@postgrespro.ru", "phone": "+70972129802"}
0005434639806	D1458C	2637 513215	ANASTASIYA KOVALEVA	{"email": "anastasiyakovaleva_21091984@postgrespro.ru", "phone": "+70312658641"}
0005434639807	87DDF3	6617 880648	VLADIMIR ALEKSEEV	{"email": "alekseevv_1975@postgrespro.ru", "phone": "+70517333054"}
0005434639808	87DDF3	1682 465895	ELENA IVANOVA	{"phone": "+70777983559"}
0005434639974	CC6976	2059 701872	TATYANA EFREMOVA	{"phone": "+70115592935"}
0005434639809	87DDF3	4567 263503	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy.081969@postgrespro.ru", "phone": "+70724767847"}
0005434639810	EEC76D	0200 483440	SERGEY VOROBEV	{"email": "vorobev-sergey1982@postgrespro.ru", "phone": "+70013024833"}
0005434639811	55CDA6	5074 149798	VADIM FROLOV	{"email": "frolovvadim.1965@postgrespro.ru", "phone": "+70950528594"}
0005434639812	D98826	7538 618769	IVAN NAZAROV	{"phone": "+70594480446"}
0005434639813	D98826	0448 632589	EVGENIY OSIPOV	{"email": "osipov_evgeniy121972@postgrespro.ru", "phone": "+70863879805"}
0005434639814	45C040	7702 083264	TATYANA EGOROVA	{"email": "t-egorova1975@postgrespro.ru", "phone": "+70331770843"}
0005434639815	45C040	2728 982062	EVGENIY PETROV	{"email": "petrov.evgeniy-22081981@postgrespro.ru", "phone": "+70934038304"}
0005434639816	E24FE4	2487 894349	ELIZAVETA KOLESNIKOVA	{"email": "kolesnikovae_101971@postgrespro.ru", "phone": "+70289425241"}
0005434639817	E24FE4	1977 912560	MIKHAIL TIKHONOV	{"email": "tikhonovm-1976@postgrespro.ru", "phone": "+70548031800"}
0005434639818	675F36	9655 318046	ANTONINA EGOROVA	{"phone": "+70081681383"}
0005434639819	675F36	4760 379471	SERGEY EGOROV	{"phone": "+70465093246"}
0005434639820	ED6419	2887 485283	ALEKSEY SERGEEV	{"email": "sergeev_aleksey.09021977@postgrespro.ru", "phone": "+70577233241"}
0005434639821	ED6419	5831 568998	ALINA POLYAKOVA	{"email": "a-polyakova_10021971@postgrespro.ru", "phone": "+70059206142"}
0005434639822	ED6419	8290 155181	VLADIMIR SCHERBAKOV	{"phone": "+70420056881"}
0005434639823	01524D	2526 681512	VLADIMIR FILIPPOV	{"email": "v_filippov.25081964@postgrespro.ru", "phone": "+70098394931"}
0005434639824	A53A86	0278 340558	EVGENIYA POPOVA	{"email": "epopova.021973@postgrespro.ru", "phone": "+70558800756"}
0005434639825	A53A86	0997 708802	ALIYA ALEKSANDROVA	{"phone": "+70451414612"}
0005434639826	A53A86	3421 250967	NADEZHDA KARPOVA	{"email": "nadezhda.karpova-16071976@postgrespro.ru", "phone": "+70996583931"}
0005434639827	3F6420	7660 961119	ALEKSANDR GORBUNOV	{"phone": "+70830371903"}
0005434639828	3F6420	0758 712652	NAILYA FEDOROVA	{"phone": "+70485117594"}
0005434639829	D3E085	6198 711465	ANDREY ILIN	{"phone": "+70563047836"}
0005434639830	F09725	0741 840662	IRINA YUDINA	{"email": "irina.yudina_09011980@postgrespro.ru", "phone": "+70427398940"}
0005434639831	4C4026	1617 064827	VITALIY ALEKSEEV	{"email": "vitaliy.alekseev-17061969@postgrespro.ru", "phone": "+70355291395"}
0005434639832	4C4026	7622 383158	NIKITA SERGEEV	{"email": "nsergeev_22121963@postgrespro.ru", "phone": "+70411632714"}
0005434639833	00A69C	9058 919657	EKATERINA KONOVALOVA	{"email": "e-konovalova.011967@postgrespro.ru", "phone": "+70758561480"}
0005434639834	00A69C	1387 883928	ANDREY NIKOLAEV	{"email": "nikolaev.a1984@postgrespro.ru", "phone": "+70713295518"}
0005434639835	5FEAB8	9544 941913	NIKOLAY MAKAROV	{"phone": "+70865665055"}
0005434639836	9527F9	0321 035851	ILYA MELNIKOV	{"phone": "+70287425942"}
0005434639837	32F18F	1179 199031	TAMARA NAUMOVA	{"email": "tamara_naumova.1964@postgrespro.ru", "phone": "+70917221412"}
0005434639838	32F18F	5148 319090	ALLA RYABOVA	{"phone": "+70379369135"}
0005434639839	D2FDE5	6616 957268	OLEG DAVYDOV	{"phone": "+70806688500"}
0005434639840	8B002C	6290 402676	ALEKSEY DAVYDOV	{"email": "aleksey-davydov1968@postgrespro.ru", "phone": "+70769637559"}
0005434639841	AB249F	1321 339062	ANNA DMITRIEVA	{"email": "anna-dmitrieva021965@postgrespro.ru", "phone": "+70673445889"}
0005434639842	7A06A3	2683 681991	YULIYA STEPANOVA	{"email": "y.stepanova_1973@postgrespro.ru", "phone": "+70481284527"}
0005434639843	ADA3A5	3287 813060	OLGA IVANOVA	{"email": "ivanova.olga061978@postgrespro.ru", "phone": "+70685123862"}
0005434639844	ADA3A5	2791 216258	LYUBOV TIMOFEEVA	{"email": "timofeeva.lyubov-111972@postgrespro.ru", "phone": "+70948511696"}
0005434639845	196AC3	3224 777608	IRINA NIKOLAEVA	{"phone": "+70443317803"}
0005434639846	196AC3	1804 974407	VLADIMIR ANTONOV	{"email": "antonov.v-27121966@postgrespro.ru", "phone": "+70697374860"}
0005434639847	FD9468	2347 084602	SERGEY KONOVALOV	{"phone": "+70612743614"}
0005434639848	F59970	2891 135132	ANASTASIYA DENISOVA	{"phone": "+70710732169"}
0005434639849	5D8A7E	5791 072662	NIKOLAY BARANOV	{"phone": "+70258002361"}
0005434639850	5D8A7E	6119 642508	SVETLANA MELNIKOVA	{"phone": "+70106198287"}
0005434639851	629E18	8560 968353	SERGEY BONDARENKO	{"phone": "+70831236738"}
0005434639852	629E18	0569 432545	LIDIYA FEDOROVA	{"email": "lidiya_fedorova-21041977@postgrespro.ru", "phone": "+70107224751"}
0005434639853	591B20	8788 920200	MIKHAIL ZAYCEV	{"email": "mzaycev_071976@postgrespro.ru", "phone": "+70111249194"}
0005434639854	591B20	2271 387027	IVAN CHERNOV	{"email": "i_chernov111970@postgrespro.ru", "phone": "+70381565421"}
0005434639855	24C156	2480 376583	LEONID GAVRILOV	{"email": "gavrilov_leonid_1971@postgrespro.ru", "phone": "+70620206907"}
0005434639856	EE724D	6033 486861	VALENTINA EFREMOVA	{"phone": "+70487347834"}
0005434639857	687206	3966 316807	OLGA VOLKOVA	{"phone": "+70290759911"}
0005434639858	8FF3B4	0576 048774	ELENA ORLOVA	{"email": "e-orlova.041974@postgrespro.ru", "phone": "+70897576901"}
0005434639859	D91D17	7193 700315	IGOR PETROV	{"phone": "+70925257221"}
0005434639860	D91D17	7447 831347	VALERIYA VASILEVA	{"email": "v_vasileva.091952@postgrespro.ru", "phone": "+70535429917"}
0005434639861	68E70A	6876 741910	MIKHAIL VOROBEV	{"email": "mikhail-vorobev.121979@postgrespro.ru", "phone": "+70895076968"}
0005434639862	68E70A	7603 078251	LIDIYA DANILOVA	{"email": "danilova.l.091975@postgrespro.ru", "phone": "+70338440191"}
0005434639863	7A306A	7229 471916	VLADIMIR KISELEV	{"phone": "+70786520272"}
0005434639864	3D80D4	4560 889257	ELENA KOROLEVA	{"phone": "+70420713644"}
0005434639865	3D80D4	8817 466319	NADEZHDA GERASIMOVA	{"email": "nadezhda-gerasimova.071973@postgrespro.ru", "phone": "+70906297671"}
0005434639866	6C7553	4745 236403	VIKTOR ROMANOV	{"email": "v-romanov.31031974@postgrespro.ru", "phone": "+70875548211"}
0005434639867	B32B09	5234 739521	ANATOLIY SCHERBAKOV	{"email": "scherbakov.a.11031967@postgrespro.ru", "phone": "+70422756212"}
0005434639868	B32B09	8144 211949	GULNARA ALEKSANDROVA	{"email": "aleksandrova_g.11081968@postgrespro.ru", "phone": "+70739198863"}
0005434639869	721DA4	4278 422214	ANVAR MEDVEDEV	{"email": "medvedev-a.1966@postgrespro.ru", "phone": "+70894435578"}
0005434639870	721DA4	7747 139130	LIDIYA PAVLOVA	{"email": "pavlova_l_1971@postgrespro.ru", "phone": "+70320448171"}
0005434639871	58782C	4520 938324	LYUDMILA EFREMOVA	{"email": "efremova-l011978@postgrespro.ru", "phone": "+70514414312"}
0005434639872	58782C	1453 704425	OLGA ANISIMOVA	{"email": "olga-anisimova1960@postgrespro.ru", "phone": "+70921904977"}
0005434639873	1A2F2E	1019 870032	ANTONINA SERGEEVA	{"email": "antonina.sergeeva_031972@postgrespro.ru", "phone": "+70417326409"}
0005434639874	95A667	3231 191285	NIKOLAY VLASOV	{"email": "vlasov.n-27121962@postgrespro.ru", "phone": "+70046032275"}
0005434639875	95A667	7356 890511	NATALYA TROFIMOVA	{"email": "n-trofimova_091967@postgrespro.ru", "phone": "+70781858423"}
0005434639876	047F74	6194 044859	NIKOLAY MARTYNOV	{"email": "martynov.nikolay-081984@postgrespro.ru", "phone": "+70727047407"}
0005434639877	EF7C9A	3066 238097	ANATOLIY ANTONOV	{"email": "anatoliy_antonov_1972@postgrespro.ru", "phone": "+70181340922"}
0005434639878	EF7C9A	8404 772051	GALINA KOZLOVA	{"phone": "+70872629896"}
0005434639879	EF7C9A	3886 285205	ALENA ANDREEVA	{"phone": "+70285480680"}
0005434639880	1DBC93	7590 017135	DMITRIY GUSEV	{"phone": "+70509059795"}
0005434639881	1DBC93	8364 629936	GALINA ARKHIPOVA	{"email": "arkhipova.g-11011975@postgrespro.ru", "phone": "+70434690492"}
0005434639882	88E104	3563 437778	VALENTINA MOROZOVA	{"phone": "+70164372139"}
0005434639883	BAC3C5	7324 294425	ALFIYA LOGINOVA	{"phone": "+70131463182"}
0005434639884	BAC3C5	0103 103506	POLINA SMIRNOVA	{"email": "polina.smirnova18081969@postgrespro.ru", "phone": "+70900865647"}
0005434639885	0B6C01	6048 677080	ROZA SOKOLOVA	{"email": "sokolova-roza-1969@postgrespro.ru", "phone": "+70963479391"}
0005434639886	0B6C01	6421 637204	KONSTANTIN ALEKSEEV	{"email": "k-alekseev_1976@postgrespro.ru", "phone": "+70591573447"}
0005434639887	C1BB70	8082 237682	PAVEL VLASOV	{"phone": "+70888925245"}
0005434639888	0ED0A2	7905 083820	SERGEY STEPANOV	{"email": "stepanov_sergey.021983@postgrespro.ru", "phone": "+70543266025"}
0005434639889	0ED0A2	5965 882491	EVGENIY KRASNOV	{"email": "evgeniy.krasnov-1974@postgrespro.ru", "phone": "+70750937091"}
0005434639890	8448A7	7816 218273	VALENTIN MOROZOV	{"email": "valentin.morozov-15111979@postgrespro.ru", "phone": "+70308977373"}
0005434639891	6E8145	7252 685371	ALEKSANDR FROLOV	{"phone": "+70087469647"}
0005434639892	5B1D32	5663 445533	ELENA KAZAKOVA	{"email": "kazakovaelena.071971@postgrespro.ru", "phone": "+70473886340"}
0005434639893	5B1D32	6395 676909	ALEKSANDR SERGEEV	{"email": "sergeev-a1967@postgrespro.ru", "phone": "+70894061061"}
0005434639894	298404	0162 605684	BORIS FROLOV	{"email": "bfrolov_22051969@postgrespro.ru", "phone": "+70035705033"}
0005434639895	41F27A	5470 670690	NINA LUKYANOVA	{"email": "lukyanova-n23051969@postgrespro.ru", "phone": "+70033598984"}
0005434639896	41F27A	3222 702180	ANNA MELNIKOVA	{"email": "melnikovaa28011971@postgrespro.ru", "phone": "+70793940524"}
0005434639897	E10F72	7098 581251	YURIY POPOV	{"phone": "+70484221757"}
0005434639898	E10F72	9756 553306	OLGA KRASNOVA	{"phone": "+70267612995"}
0005434639899	731F43	8990 767809	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey.1970@postgrespro.ru", "phone": "+70989061651"}
0005434639900	24AEDB	9438 841008	ELENA MIRONOVA	{"phone": "+70848681505"}
0005434639901	19BCCA	0130 437298	LYUBOV STEPANOVA	{"phone": "+70758868034"}
0005434639902	0493D8	7719 355630	ALEKSANDR SAVELEV	{"email": "savelev_a1968@postgrespro.ru", "phone": "+70068510543"}
0005434639903	F2E2D6	6577 094004	GALINA SEMENOVA	{"phone": "+70326865673"}
0005434639904	51C883	3840 376258	ANZHELIKA VOLKOVA	{"phone": "+70383705050"}
0005434639905	51C883	0197 875885	ALEKSEY VOROBEV	{"email": "aleksey-vorobev-1970@postgrespro.ru", "phone": "+70179243931"}
0005434639906	88B4A3	8782 141626	LYUBOV EGOROVA	{"email": "l_egorova_31121973@postgrespro.ru", "phone": "+70365778652"}
0005434639907	D8D8EC	9407 618084	VIKTOR ALEKSANDROV	{"email": "viktor_aleksandrov-22071976@postgrespro.ru", "phone": "+70614123644"}
0005434639908	0FC1EA	9670 122331	ARTEM KULIKOV	{"email": "kulikov.artem_101955@postgrespro.ru", "phone": "+70225865294"}
0005434639909	0FC1EA	4458 692379	YURIY SOROKIN	{"email": "sorokin-yuriy.13061972@postgrespro.ru", "phone": "+70570907328"}
0005434639910	55022F	1124 555590	DMITRIY ROMANOV	{"email": "romanov.d_1971@postgrespro.ru", "phone": "+70830390597"}
0005434639911	DD4F87	6445 341725	VALENTINA PAVLOVA	{"phone": "+70539993247"}
0005434639912	A8BADA	0663 608235	SERGEY FEDOTOV	{"email": "s-fedotov-1961@postgrespro.ru", "phone": "+70496808684"}
0005434639913	BEAD55	3819 261060	EKATERINA MOROZOVA	{"email": "e_morozova_101972@postgrespro.ru", "phone": "+70232191258"}
0005434639914	BCE96D	5468 293185	ILYA GORBUNOV	{"email": "i.gorbunov.25071976@postgrespro.ru", "phone": "+70818026230"}
0005434639915	BCE96D	0134 263647	VYACHESLAV MAKAROV	{"phone": "+70981880404"}
0005434639916	03090F	4531 392797	MARGARITA TIMOFEEVA	{"phone": "+70617362372"}
0005434639917	270385	2953 340160	PAVEL SOROKIN	{"email": "pavel_sorokin_17021979@postgrespro.ru", "phone": "+70668616968"}
0005434639918	CB622A	0157 159954	DMITRIY NOVIKOV	{"email": "d_novikov041968@postgrespro.ru", "phone": "+70091719088"}
0005434639919	D590DC	0837 928566	ANTON KUZMIN	{"email": "kuzmina_041976@postgrespro.ru", "phone": "+70184757600"}
0005434639920	239360	8046 224159	DMITRIY DENISOV	{"phone": "+70855810697"}
0005434639921	239360	7332 380386	ALEKSANDR KONOVALOV	{"phone": "+70291670078"}
0005434639922	239360	5803 135287	DMITRIY ZAKHAROV	{"email": "dmitriy-zakharov.23091978@postgrespro.ru", "phone": "+70792314803"}
0005434639923	7F6307	3545 838033	ALEKSANDR KONOVALOV	{"phone": "+70224036262"}
0005434639924	4A706B	6755 280081	OLEG SIDOROV	{"phone": "+70648649496"}
0005434639925	4A706B	9664 273982	GRIGORIY KISELEV	{"email": "kiselev-grigoriy.25011980@postgrespro.ru", "phone": "+70575767266"}
0005434639926	950027	5193 690175	IVAN TARASOV	{"phone": "+70140256973"}
0005434639927	4E77BD	6945 392890	SVETLANA ALEKSEEVA	{"email": "s.alekseeva_07011970@postgrespro.ru", "phone": "+70692105958"}
0005434639928	4E77BD	0919 767540	IVAN ALEKSEEV	{"email": "i_alekseev-27011978@postgrespro.ru", "phone": "+70004854853"}
0005434639929	859250	9507 243323	EVGENIY ANDREEV	{"phone": "+70542306388"}
0005434639930	A65F14	2555 487742	VALENTIN FEDOTOV	{"email": "v-fedotov_071968@postgrespro.ru", "phone": "+70837395256"}
0005434639931	769978	3952 704887	NINA KOROLEVA	{"phone": "+70777711991"}
0005434639932	873CDD	6495 748859	DANILA SOKOLOV	{"email": "sokolov.d-1967@postgrespro.ru", "phone": "+70153286995"}
0005434639933	873CDD	9959 003973	ALEKSANDR FROLOV	{"email": "frolov-a.19111970@postgrespro.ru", "phone": "+70835469402"}
0005434639934	CEE2DF	3067 880316	DMITRIY IVANOV	{"email": "ivanov-d1973@postgrespro.ru", "phone": "+70237876105"}
0005434639935	CEE2DF	3666 629206	SERGEY MIKHAYLOV	{"email": "smikhaylov.091974@postgrespro.ru", "phone": "+70832087539"}
0005434639936	AEA26D	8131 740724	NIKOLAY PETROV	{"phone": "+70247991324"}
0005434639937	61851B	2898 628254	IRINA POPOVA	{"phone": "+70998741070"}
0005434639938	61851B	8538 672688	ALEKSEY MOROZOV	{"email": "aleksey-morozov.101961@postgrespro.ru", "phone": "+70535283621"}
0005434639939	A4D76B	3977 970238	KSENIYA ARKHIPOVA	{"email": "arkhipova_k-051979@postgrespro.ru", "phone": "+70809937667"}
0005434639940	B54DD4	9926 515608	YAROSLAV MELNIKOV	{"phone": "+70665993674"}
0005434639941	23D606	7043 663613	NIKOLAY TARASOV	{"phone": "+70208925966"}
0005434639942	23D606	0996 007610	SVETLANA MIRONOVA	{"email": "svetlana_mironova-22041974@postgrespro.ru", "phone": "+70412548651"}
0005434639943	68BD28	1986 569091	LYUDMILA YAKOVLEVA	{"phone": "+70183997933"}
0005434639944	68BD28	2116 181249	NATALIYA LOGINOVA	{"email": "loginova_n1973@postgrespro.ru", "phone": "+70742225292"}
0005434639945	3E691B	2619 315565	VIKTOR KUZNECOV	{"email": "v.kuznecov-20021968@postgrespro.ru", "phone": "+70178169851"}
0005434639946	3E691B	4507 599748	IRINA KARPOVA	{"phone": "+70384005551"}
0005434639947	3E691B	7475 330171	MARIYA ANISIMOVA	{"email": "anisimovam.07091973@postgrespro.ru", "phone": "+70774202870"}
0005434639948	733C91	7912 741738	ELENA FROLOVA	{"phone": "+70393173372"}
0005434639949	733C91	4592 130403	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov_14111974@postgrespro.ru", "phone": "+70021329110"}
0005434639950	8ABFAF	8312 164607	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana-1964@postgrespro.ru", "phone": "+70039462817"}
0005434639951	FC423A	3275 516123	LIDIYA TARASOVA	{"phone": "+70935570640"}
0005434639952	8C1AB0	3853 059282	DMITRIY MIRONOV	{"phone": "+70762845103"}
0005434639953	40617B	1528 807962	ELINA ALEKSANDROVA	{"phone": "+70523298815"}
0005434639954	EDA40F	1039 956282	ALINA DENISOVA	{"email": "alina-denisova.121981@postgrespro.ru", "phone": "+70620636843"}
0005434639955	EDA40F	1954 235439	ANATOLIY RODIONOV	{"email": "rodionov_a-22031986@postgrespro.ru", "phone": "+70035947238"}
0005434639956	B8FDB4	8788 443006	ANDREY PAVLOV	{"email": "andrey.pavlov_1963@postgrespro.ru", "phone": "+70332012955"}
0005434639957	B8FDB4	1106 463036	VERA YAKOVLEVA	{"email": "v_yakovleva031975@postgrespro.ru", "phone": "+70263386434"}
0005434639958	643ED6	9101 902088	SVETLANA KUZMINA	{"phone": "+70020320746"}
0005434639959	F4DD4C	5850 613856	SOFYA DMITRIEVA	{"phone": "+70446106645"}
0005434639960	F89DAB	6318 785875	OLGA KUZNECOVA	{"email": "o-kuznecova-091971@postgrespro.ru", "phone": "+70261596746"}
0005434639961	F89DAB	3317 645439	EVGENIY NIKOLAEV	{"email": "evgeniy.nikolaev1966@postgrespro.ru", "phone": "+70031557919"}
0005434639962	1C0BB2	9066 853646	ALEKSANDR BONDARENKO	{"phone": "+70469300695"}
0005434639963	572B5E	4282 078756	VALENTINA PAVLOVA	{"phone": "+70877828072"}
0005434639964	572B5E	8553 095852	OLGA DENISOVA	{"phone": "+70879595565"}
0005434639965	CCAB9F	4055 570778	OLEG NOVIKOV	{"email": "novikov_o1967@postgrespro.ru", "phone": "+70722510023"}
0005434639966	6D0B88	0561 709741	VALERIY BORISOV	{"email": "borisov_valeriy.1964@postgrespro.ru", "phone": "+70423356640"}
0005434639967	C450EF	2777 722803	VLADIMIR FEDOTOV	{"phone": "+70315129933"}
0005434639968	F67667	5817 144442	SERGEY KUDRYASHOV	{"email": "kudryashov-sergey_011967@postgrespro.ru", "phone": "+70368178012"}
0005434639969	F67667	0396 308671	SERGEY KAZAKOV	{"email": "sergey-kazakov.1972@postgrespro.ru", "phone": "+70548181037"}
0005434639970	69DA8D	7236 371879	ALEKSANDR POPOV	{"email": "popovaleksandr.20091971@postgrespro.ru", "phone": "+70793505908"}
0005434639971	69DA8D	6844 520428	ILYA SCHERBAKOV	{"email": "scherbakov_i_051972@postgrespro.ru", "phone": "+70392643589"}
0005434639972	BA2E04	5903 627160	TAMARA IVANOVA	{"email": "tamara.ivanova20021986@postgrespro.ru", "phone": "+70562002303"}
0005434639973	CC6976	9152 669720	ANDREY STEPANOV	{"email": "stepanov_andrey1959@postgrespro.ru", "phone": "+70989641066"}
0005434639975	CC6976	9430 260798	IRINA MIRONOVA	{"phone": "+70334485682"}
0005434639976	28B9BA	6187 674950	VIKTOR POPOV	{"email": "viktor_popov01071969@postgrespro.ru", "phone": "+70460329456"}
0005434639977	28B9BA	2799 502709	POLINA FADEEVA	{"email": "p.fadeeva.1976@postgrespro.ru", "phone": "+70340066558"}
0005434639978	22B093	8492 878110	VALERIYA NIKOLAEVA	{"email": "valeriyanikolaeva041971@postgrespro.ru", "phone": "+70255830236"}
0005434639979	22B093	8803 520137	NINA SMIRNOVA	{"email": "smirnova_nina.22051971@postgrespro.ru", "phone": "+70803060381"}
0005434639980	6645B4	8428 535686	ELENA IVANOVA	{"phone": "+70549031330"}
0005434639981	DF2568	6113 658599	ALEKSANDR ZAYCEV	{"phone": "+70628919312"}
0005434639982	DF2568	8129 817938	ARTEM IVANOV	{"email": "a.ivanov081956@postgrespro.ru", "phone": "+70072673199"}
0005434639983	546381	0766 639986	IRINA NESTEROVA	{"phone": "+70022918212"}
0005434639984	E098EE	5199 214511	MARGARITA SCHERBAKOVA	{"phone": "+70401761368"}
0005434639985	7BC616	1257 150693	EVGENIY ISAEV	{"email": "isaev_e071975@postgrespro.ru", "phone": "+70111396506"}
0005434639986	7BC616	1899 573296	OLGA FADEEVA	{"phone": "+70322727242"}
0005434639987	F89E55	0792 180422	MAKSIM MARTYNOV	{"phone": "+70551786159"}
0005434639988	F89E55	0947 404907	VALERIY NAZAROV	{"phone": "+70797609442"}
0005434639989	A4023E	4408 252090	DANILA ISAEV	{"phone": "+70064045877"}
0005434639990	FDA6AD	7442 862996	LEONID SERGEEV	{"email": "sergeev-leonid_02031971@postgrespro.ru", "phone": "+70151711773"}
0005434639991	FDA6AD	4393 383403	ALEKSANDR KAZAKOV	{"email": "kazakova10091974@postgrespro.ru", "phone": "+70218662908"}
0005434639992	96DDB1	7968 577166	VIKTOR KUZNECOV	{"phone": "+70152512038"}
0005434639993	C91025	8205 726403	RAMAZAN KUZNECOV	{"phone": "+70379087397"}
0005434639994	96BE1E	8314 270994	DMITRIY NAUMOV	{"phone": "+70337959021"}
0005434639995	96BE1E	9724 102218	SVETLANA FROLOVA	{"email": "svetlana_frolova_23011969@postgrespro.ru", "phone": "+70308652949"}
0005434639996	62E059	3140 152780	ANDREY MEDVEDEV	{"email": "medvedevandrey-11021977@postgrespro.ru", "phone": "+70642557944"}
0005434639997	62E059	4542 663291	DMITRIY MIKHAYLOV	{"email": "mikhaylov-dmitriy-06091975@postgrespro.ru", "phone": "+70699385865"}
0005434639998	E486B6	5805 157371	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila_1978@postgrespro.ru", "phone": "+70288644396"}
0005434639999	9CBF37	1627 073571	IRINA ZHUKOVA	{"phone": "+70146986334"}
0005434640000	7C14D8	0063 818561	OLEG BELOV	{"phone": "+70393679263"}
0005434640001	D34E53	2844 721988	RINAT BELOV	{"phone": "+70634022753"}
0005434640002	86BE27	7976 866129	LYUDMILA ANISIMOVA	{"email": "l.anisimova-22061974@postgrespro.ru", "phone": "+70706998117"}
0005434640003	86BE27	3618 913205	VERA KUZNECOVA	{"email": "vera-kuznecova.051968@postgrespro.ru", "phone": "+70101601623"}
0005434640004	B44595	4403 609118	NIKOLAY ANDREEV	{"email": "nikolay_andreev.08031967@postgrespro.ru", "phone": "+70813871602"}
0005434640005	B44595	7735 976123	VIKTOR FEDOROV	{"email": "fedorovv-1971@postgrespro.ru", "phone": "+70616241487"}
0005434640006	12BEB2	9315 278130	ALBINA DENISOVA	{"email": "albina_denisova1971@postgrespro.ru", "phone": "+70838814304"}
0005434640007	E5E096	4018 243606	ANATOLIY KOZLOV	{"phone": "+70470179166"}
0005434640008	5A9814	4533 255198	ALEKSEY TARASOV	{"phone": "+70718057205"}
0005434640009	5A9814	5519 946201	SERGEY DAVYDOV	{"email": "davydov-s.1975@postgrespro.ru", "phone": "+70410699466"}
0005434640010	5A9814	9516 602957	ARTEM KUZNECOV	{"phone": "+70750335755"}
0005434640011	8EE000	7557 112906	VLADIMIR SERGEEV	{"email": "v-sergeev-121971@postgrespro.ru", "phone": "+70191231103"}
0005434640012	8EE000	5469 983876	LYUDMILA MATVEEVA	{"email": "matveeva-lyudmila_031980@postgrespro.ru", "phone": "+70050649779"}
0005434640013	ED65B8	1743 130351	VERA ARKHIPOVA	{"phone": "+70180590897"}
0005434640014	ED65B8	0550 423411	VLADISLAV IVANOV	{"email": "ivanov.v_30071971@postgrespro.ru", "phone": "+70354488623"}
0005434640015	ED65B8	0422 584090	VALENTINA PETROVA	{"email": "valentinapetrova.25111974@postgrespro.ru", "phone": "+70399206010"}
0005434640016	ED6B63	5111 172010	OKSANA SOKOLOVA	{"email": "sokolova_o1989@postgrespro.ru", "phone": "+70703031758"}
0005434640017	ED6B63	8393 790592	ELENA SCHERBAKOVA	{"email": "elenascherbakova_1967@postgrespro.ru", "phone": "+70169282121"}
0005434640018	B2A24C	1953 556243	ALINA KONDRATEVA	{"phone": "+70376452773"}
0005434640019	3C28AE	4168 217014	LEYLA MELNIKOVA	{"phone": "+70969860616"}
0005434640020	54D5C2	7621 218795	VIKTOR MATVEEV	{"email": "vmatveev.1977@postgrespro.ru", "phone": "+70918007164"}
0005434640021	AC99A3	6304 647163	IVAN MIKHAYLOV	{"email": "imikhaylov.1968@postgrespro.ru", "phone": "+70181950830"}
0005434640022	1DAA47	5910 157803	OLGA KOZLOVA	{"email": "kozlova-o_10091970@postgrespro.ru", "phone": "+70397848422"}
0005434640023	47759B	5451 664778	KSENIYA SAVELEVA	{"email": "saveleva.kseniya_071978@postgrespro.ru", "phone": "+70033583774"}
0005434640024	96D1C0	2259 664531	EVGENIY KARPOV	{"phone": "+70661212353"}
0005434640025	8947F7	2431 568498	YULIYA ARKHIPOVA	{"phone": "+70218288250"}
0005434640026	608F20	8113 843532	DMITRIY MAKAROV	{"email": "d.makarov-051975@postgrespro.ru", "phone": "+70382281892"}
0005434640027	07B4DD	4449 134456	IRINA KONDRATEVA	{"phone": "+70836232714"}
0005434640028	53C497	0350 227964	VLADIMIR KUZNECOV	{"email": "v_kuznecov.091974@postgrespro.ru", "phone": "+70703555911"}
0005434640029	06A630	2979 614575	ALENA MIKHAYLOVA	{"email": "mikhaylovaa-031968@postgrespro.ru", "phone": "+70593858551"}
0005434640030	D24813	5695 304650	IRINA STEPANOVA	{"email": "istepanova02021977@postgrespro.ru", "phone": "+70696427057"}
0005434640031	B2DC5D	2539 557610	ANDREY FROLOV	{"email": "a_frolov-31051978@postgrespro.ru", "phone": "+70338809665"}
0005434640032	B2DC5D	5310 501133	TATYANA MAKAROVA	{"email": "tatyana_makarova_14031974@postgrespro.ru", "phone": "+70936583920"}
0005434640033	8C8D93	4682 540468	YURIY MIKHAYLOV	{"email": "yuriy_mikhaylov1966@postgrespro.ru", "phone": "+70287971527"}
0005434640034	C23998	1223 365311	ANTON BELOV	{"email": "abelov121972@postgrespro.ru", "phone": "+70830952412"}
0005434640035	193D21	5860 860567	DMITRIY EGOROV	{"phone": "+70399120227"}
0005434640036	193D21	6328 990147	VIKTORIYA KUDRYASHOVA	{"email": "viktoriya.kudryashova121969@postgrespro.ru", "phone": "+70041134083"}
0005434640037	AF4CC9	4361 525485	MAKSIM ZHUKOV	{"phone": "+70723263536"}
0005434640038	5499C1	6668 077965	ALEKSANDR FEDOROV	{"phone": "+70960424604"}
0005434640039	B76A93	6961 296061	YURIY ANDREEV	{"phone": "+70996712565"}
0005434640040	EDF3E4	0689 754638	YULIYA ZAKHAROVA	{"email": "zakharova-y.101970@postgrespro.ru", "phone": "+70833224153"}
0005434640041	EDF3E4	0297 932464	NATALYA NIKITINA	{"email": "nikitina-natalya_1976@postgrespro.ru", "phone": "+70164492931"}
0005434640042	259914	0957 376823	YURIY TIKHONOV	{"email": "tikhonov.yuriy_1964@postgrespro.ru", "phone": "+70195404448"}
0005434640043	259914	6488 177153	IGOR VOLKOV	{"email": "ivolkov.061965@postgrespro.ru", "phone": "+70243537340"}
0005434640044	BF2953	4322 913291	ELENA MAKAROVA	{"email": "makarova_e-091971@postgrespro.ru", "phone": "+70811204657"}
0005434640045	BF2953	2326 534511	KSENIYA VASILEVA	{"phone": "+70884250049"}
0005434640046	8BE9A7	3202 829926	ELENA PETROVA	{"email": "e_petrova_1973@postgrespro.ru", "phone": "+70359695197"}
0005434640047	8BE9A7	9575 885449	ELENA KULIKOVA	{"email": "elena-kulikova-30081970@postgrespro.ru", "phone": "+70712754840"}
0005434640048	8BE9A7	2898 633017	OLGA GAVRILOVA	{"phone": "+70312161286"}
0005434640049	2F8301	6203 389371	DARYA FROLOVA	{"phone": "+70983571042"}
0005434640050	FBCDF8	7103 665112	VALENTINA KARPOVA	{"email": "karpova-v-05091961@postgrespro.ru", "phone": "+70250354601"}
0005434640051	76CBA6	7829 400162	OKSANA NAZAROVA	{"phone": "+70677286957"}
0005434640052	76CBA6	2661 635116	VIKTORIYA POPOVA	{"email": "popova_viktoriya-06011978@postgrespro.ru", "phone": "+70451718773"}
0005434640053	76CBA6	4026 278081	KONSTANTIN SERGEEV	{"email": "konstantinsergeev-011976@postgrespro.ru", "phone": "+70815407635"}
0005434640054	CD82C4	4155 141123	VERA VOLKOVA	{"phone": "+70235549458"}
0005434640055	CD82C4	6103 601740	OLGA DMITRIEVA	{"phone": "+70033941469"}
0005434640056	447A56	6500 789607	ELENA KUZNECOVA	{"phone": "+70434398200"}
0005434640057	D15CDF	0058 188678	ANDREY NAZAROV	{"phone": "+70778114498"}
0005434640058	D15CDF	9475 949627	EKATERINA SAVELEVA	{"email": "e_saveleva_23121969@postgrespro.ru", "phone": "+70741049158"}
0005434640059	10E79B	0565 425777	OLGA MEDVEDEVA	{"phone": "+70612755140"}
0005434640060	10E79B	9037 994830	VALENTINA TIKHONOVA	{"phone": "+70640849959"}
0005434640061	A42666	7474 369646	NATALYA FADEEVA	{"email": "n_fadeeva-08011959@postgrespro.ru", "phone": "+70073201732"}
0005434640062	A42666	1152 777138	VLADIMIR MELNIKOV	{"phone": "+70691901385"}
0005434640063	1B68B7	7291 677587	LYUBOV KUZNECOVA	{"phone": "+70598190796"}
0005434640064	EE4D17	7912 973595	ALEKSANDR TARASOV	{"email": "tarasov_a.1984@postgrespro.ru", "phone": "+70846303854"}
0005434640065	5F0315	3260 664434	NIKOLAY IVANOV	{"phone": "+70710395144"}
0005434640066	70C11C	8548 731905	ALIYA MAKSIMOVA	{"email": "maksimova_aliya-13071966@postgrespro.ru", "phone": "+70733105583"}
0005434640067	70C11C	2256 210096	ALEKSEY MIRONOV	{"email": "mironov_a.011970@postgrespro.ru", "phone": "+70547791549"}
0005434640068	AE6530	0092 283437	IVAN MOROZOV	{"email": "morozov_ivan.101974@postgrespro.ru", "phone": "+70421542715"}
0005434640069	B2E603	0527 763828	IDA ISAEVA	{"email": "i-isaeva-10081982@postgrespro.ru", "phone": "+70535479691"}
0005434640070	B2E603	6515 822587	ALEKSANDRA ANTONOVA	{"phone": "+70816920379"}
0005434640071	9377FE	7142 232852	KUZMA ISAEV	{"phone": "+70060133947"}
0005434640072	9377FE	4994 942043	IGOR ZAYCEV	{"phone": "+70480080573"}
0005434640073	4573BB	6925 216727	GEORGIY MAKAROV	{"email": "makarovg-1966@postgrespro.ru", "phone": "+70247260159"}
0005434640074	4573BB	6636 321930	VERA NOVIKOVA	{"email": "vera-novikova_22051968@postgrespro.ru", "phone": "+70788581999"}
0005434640075	6EDDEA	2007 600083	LYUBOV DAVYDOVA	{"phone": "+70331218283"}
0005434640076	6EDDEA	1091 210310	VERA KOZLOVA	{"email": "vera-kozlova03101969@postgrespro.ru", "phone": "+70029644325"}
0005434640077	B658FE	8798 626848	ZINAIDA DENISOVA	{"email": "denisova-zinaida21111979@postgrespro.ru", "phone": "+70506435249"}
0005434640078	99E18F	7691 771884	DMITRIY SERGEEV	{"email": "sergeevdmitriy1974@postgrespro.ru", "phone": "+70617247296"}
0005434640079	BEE5A3	7439 646813	ELENA ANISIMOVA	{"phone": "+70764092467"}
0005434640080	BEE5A3	0134 700887	IVAN CHERNOV	{"phone": "+70052448658"}
0005434640081	D42FDA	7109 524450	OLEG BARANOV	{"phone": "+70225096136"}
0005434640082	D42FDA	6033 333889	SVETLANA LAZAREVA	{"email": "svetlana-lazareva_1966@postgrespro.ru", "phone": "+70584522515"}
0005434640083	389017	4121 029077	ALEKSEY RODIONOV	{"phone": "+70442959282"}
0005434640084	389017	0675 187716	VIKTORIYA VOLKOVA	{"email": "volkova.v05071966@postgrespro.ru", "phone": "+70696706167"}
0005434640085	C96287	2473 955658	ALINA ZAKHAROVA	{"phone": "+70378431899"}
0005434640086	C96287	6818 647192	VLADIMIR YAKOVLEV	{"phone": "+70502555909"}
0005434640087	AF5987	3107 298622	ANNA BELOVA	{"phone": "+70497886935"}
0005434640088	AF5987	1820 254885	NINA FOMINA	{"email": "n-fomina_1977@postgrespro.ru", "phone": "+70008282064"}
0005434640089	F848FD	1042 213295	VYACHESLAV SEMENOV	{"email": "semenovv_1962@postgrespro.ru", "phone": "+70077533945"}
0005434640090	6F8EEF	7443 621823	ALEKSEY SHEVCHENKO	{"email": "ashevchenko-081967@postgrespro.ru", "phone": "+70434780733"}
0005434640091	9C9BC4	6499 716533	LYUDMILA BORISOVA	{"phone": "+70716307276"}
0005434640092	9C9BC4	0106 561486	NIKITA ABRAMOV	{"email": "abramov-n02091973@postgrespro.ru", "phone": "+70936791551"}
0005434640093	9C9BC4	3541 796534	ALEKSANDR STEPANOV	{"phone": "+70166971961"}
0005434640094	2722F3	5074 715511	TATYANA VOROBEVA	{"email": "vorobeva.t.061976@postgrespro.ru", "phone": "+70214673645"}
0005434640095	2722F3	3607 939317	TAISIYA FROLOVA	{"phone": "+70330172886"}
0005434640096	59F542	4212 436287	STEPAN YAKOVLEV	{"email": "yakovlev_s.091973@postgrespro.ru", "phone": "+70054244837"}
0005434640097	59F542	1077 131721	VITALIY MARTYNOV	{"email": "martynov-vitaliy_021973@postgrespro.ru", "phone": "+70402380987"}
0005434640098	D5CAD5	3286 695279	VIKTOR POPOV	{"phone": "+70275710317"}
0005434640099	8541BD	5572 066540	IRINA ABRAMOVA	{"phone": "+70041706115"}
0005434640100	B52219	4368 688753	VALERIY MAKSIMOV	{"email": "maksimovvaleriy_1971@postgrespro.ru", "phone": "+70198810144"}
0005434640101	B52219	8061 231173	ANDREY CHERNOV	{"phone": "+70095473843"}
0005434640102	8C3E2B	5174 660728	SVETLANA SAVELEVA	{"email": "saveleva_svetlana.21111973@postgrespro.ru", "phone": "+70954897761"}
0005434640103	8C3E2B	2430 399619	DARYA FROLOVA	{"email": "frolova_d.18111968@postgrespro.ru", "phone": "+70898448575"}
0005434640104	58B218	8550 858439	ANDREY MIRONOV	{"email": "mironovandrey_1965@postgrespro.ru", "phone": "+70345490263"}
0005434640105	A06168	7913 435492	SVETLANA KUZNECOVA	{"phone": "+70195859679"}
0005434640106	45117B	0168 732726	ILYA YAKOVLEV	{"email": "yakovlev-i.061980@postgrespro.ru", "phone": "+70361943684"}
0005434640107	B7C2B8	1450 390979	ALEKSANDR NAZAROV	{"phone": "+70444642065"}
0005434640108	B7C2B8	6358 951683	SVETLANA KAZAKOVA	{"phone": "+70251921508"}
0005434654160	03CC23	6135 479440	MAKSIM MOROZOV	{"phone": "+70825443352"}
0005434654161	03CC23	4495 827832	ELVIRA LOGINOVA	{"phone": "+70262421412"}
0005434654162	4F464A	4254 389926	EVGENIYA KOROLEVA	{"email": "evgeniyakoroleva.081967@postgrespro.ru", "phone": "+70391181777"}
0005434654163	2EEB45	4548 387928	OKSANA GUSEVA	{"email": "oguseva-071978@postgrespro.ru", "phone": "+70345130290"}
0005434654164	2EEB45	5426 752398	NIKOLAY YAKOVLEV	{"email": "nikolayyakovlev-081969@postgrespro.ru", "phone": "+70320769930"}
0005434654165	2EEB45	0138 876319	MARIYA ANTONOVA	{"email": "antonova.mariya1967@postgrespro.ru", "phone": "+70429237630"}
0005434654166	1F16FB	4146 386098	ELENA FOMINA	{"phone": "+70842045277"}
0005434654167	967558	2011 042568	ANASTASIYA NOVIKOVA	{"phone": "+70544464841"}
0005434654168	B91B27	9233 377570	ARTEM SOROKIN	{"email": "artem_sorokin_091966@postgrespro.ru", "phone": "+70509071099"}
0005434654169	286D92	0595 867332	ELENA YAKOVLEVA	{"email": "elena-yakovleva-24101973@postgrespro.ru", "phone": "+70425037748"}
0005434654170	286D92	1631 224762	SERGEY KONOVALOV	{"email": "s-konovalov021982@postgrespro.ru", "phone": "+70303522828"}
0005434654171	6A4048	8750 528922	ALEKSANDR SHEVCHENKO	{"email": "aleksandr_shevchenko-1963@postgrespro.ru", "phone": "+70690574707"}
0005434654172	CD9773	6693 041724	NIKOLAY SMIRNOV	{"email": "nikolay_smirnov.08091970@postgrespro.ru", "phone": "+70720507609"}
0005434654173	CD9773	1002 031511	VIKTORIYA LOGINOVA	{"phone": "+70159095932"}
0005434654174	DB944A	9906 881461	ANNA BELOVA	{"email": "anna_belova05111979@postgrespro.ru", "phone": "+70880198633"}
0005434654175	37BBC1	4306 306667	ANDREY TIKHONOV	{"email": "tikhonov-a-03021974@postgrespro.ru", "phone": "+70287739002"}
0005434654176	37BBC1	4499 408988	ANDREY YAKOVLEV	{"phone": "+70414479771"}
0005434654177	9062E0	5667 139292	SERGEY ANTONOV	{"phone": "+70596577184"}
0005434654178	2CAD01	1990 867573	OLEG ANDREEV	{"phone": "+70978140639"}
0005434654180	9AC739	7543 461201	EKATERINA AKIMOVA	{"email": "akimovaekaterina_06041963@postgrespro.ru", "phone": "+70890782639"}
0005434654181	9AC739	8499 766505	ALEKSANDR GUSEV	{"phone": "+70991913484"}
0005434654182	7EEA58	1782 079241	FANIS YAKOVLEV	{"phone": "+70610878789"}
0005434654183	5B03DD	6881 916698	DANIIL KOROLEV	{"phone": "+70330388715"}
0005434654184	5B03DD	8848 586219	VLADIMIR SOLOVEV	{"phone": "+70606922692"}
0005434654185	BC64CF	2086 678553	OLGA POLYAKOVA	{"email": "polyakovaolga.1991@postgrespro.ru", "phone": "+70504708951"}
0005434654186	CF777A	9101 649294	SERGEY VOLKOV	{"email": "svolkov16091973@postgrespro.ru", "phone": "+70814527776"}
0005434654187	CF777A	7955 768933	VERA MEDVEDEVA	{"email": "medvedeva_vera1976@postgrespro.ru", "phone": "+70948402452"}
0005434654188	47B00F	6437 388204	LIDIYA ROMANOVA	{"phone": "+70135533274"}
0005434654189	264198	2535 206451	NADEZHDA NESTEROVA	{"phone": "+70942664075"}
0005434654190	4E0E74	6198 241221	MARINA POPOVA	{"phone": "+70235924524"}
0005434654191	CA414D	9565 771990	NATALYA KULIKOVA	{"phone": "+70129117976"}
0005434654192	CA414D	9664 963288	DMITRIY MOROZOV	{"email": "dmorozov29121981@postgrespro.ru", "phone": "+70705694084"}
0005434654193	A03205	4943 513794	NINA KULIKOVA	{"email": "n-kulikova_041972@postgrespro.ru", "phone": "+70077562287"}
0005434654194	44E90B	4986 333335	VASILIY KUZNECOV	{"phone": "+70369847627"}
0005434654195	653519	5046 331768	VASILIY SOLOVEV	{"email": "vasiliysolovev061977@postgrespro.ru", "phone": "+70936963630"}
0005434654196	653519	7103 195254	NATALYA KONOVALOVA	{"email": "natalyakonovalova13091984@postgrespro.ru", "phone": "+70243082752"}
0005434654197	E5F3F8	4337 673402	OLEG NIKITIN	{"email": "nikitino_051969@postgrespro.ru", "phone": "+70385898010"}
0005434654198	8B008D	7337 043205	SERGEY YAKOVLEV	{"email": "yakovlevsergey29021964@postgrespro.ru", "phone": "+70331233612"}
0005434654199	9489B1	8416 269710	EKATERINA SCHERBAKOVA	{"phone": "+70838762433"}
0005434654200	9C3B62	7786 053812	OLGA KOLESNIKOVA	{"phone": "+70094667124"}
0005434654201	49C57B	0397 745033	TATYANA KRASNOVA	{"phone": "+70782544283"}
0005434654202	7D74D5	3260 537708	ANNA MASLOVA	{"email": "maslovaa061975@postgrespro.ru", "phone": "+70983697131"}
0005434654203	71288F	8367 658231	DENIS POPOV	{"email": "popov_denis1971@postgrespro.ru", "phone": "+70227252132"}
0005434654204	01E9BE	6181 292996	ALEKSANDR GAVRILOV	{"phone": "+70969768786"}
0005434654205	01E9BE	6572 834020	IRINA KUZNECOVA	{"phone": "+70995801057"}
0005434654206	01E9BE	4185 329455	ANATOLIY VOLKOV	{"phone": "+70074840093"}
0005434654207	016768	2790 686734	ELENA IVANOVA	{"email": "ivanovaelena081979@postgrespro.ru", "phone": "+70175154724"}
0005434654208	FCB5D0	8939 500565	SERGEY SOROKIN	{"email": "sorokin.sergey18021966@postgrespro.ru", "phone": "+70773775578"}
0005434654209	EEF02F	3678 311973	KSENIYA PAVLOVA	{"email": "pavlova-k10011973@postgrespro.ru", "phone": "+70033552431"}
0005434654210	CDD7E7	8149 108874	YULIYA GAVRILOVA	{"email": "gavrilovay03031977@postgrespro.ru", "phone": "+70652652402"}
0005434654211	CDD7E7	1535 458392	VALENTINA ZAKHAROVA	{"phone": "+70411247503"}
0005434654212	85BAA4	7427 460162	ALEKSEY KISELEV	{"email": "kiselev_a.1969@postgrespro.ru", "phone": "+70185862422"}
0005434654213	85BAA4	4769 017884	TATYANA KUZMINA	{"phone": "+70170554884"}
0005434654214	5DBFA9	6783 530261	SERGEY IVANOV	{"phone": "+70325389399"}
0005434654215	3A62AF	2020 522977	ANTONINA ABRAMOVA	{"email": "antonina_abramova1967@postgrespro.ru", "phone": "+70294448851"}
0005434654216	5CB292	5414 091222	IGOR MIRONOV	{"email": "igormironov.1982@postgrespro.ru", "phone": "+70169248647"}
0005434654217	5CB292	1135 748521	EVGENIYA STEPANOVA	{"email": "e_stepanova-121970@postgrespro.ru", "phone": "+70544846760"}
0005434654218	DFF92D	6450 995876	TATYANA KUZMINA	{"phone": "+70451303572"}
0005434654219	2F050C	1280 794441	NIKOLAY SMIRNOV	{"phone": "+70576901577"}
0005434654220	2F050C	6459 017049	ELENA BELYAEVA	{"phone": "+70373345664"}
0005434654221	4ABB62	3972 647401	NINA ZHUKOVA	{"phone": "+70009172871"}
0005434654222	807CDD	4141 222289	DARYA FROLOVA	{"phone": "+70098315789"}
0005434654223	6485CD	2637 702340	NIKOLAY KUZNECOV	{"phone": "+70050246577"}
0005434654224	6485CD	0809 373949	DMITRIY DENISOV	{"email": "ddenisov_03101973@postgrespro.ru", "phone": "+70460032940"}
0005434654225	D56C6C	2070 051325	MARINA SIDOROVA	{"phone": "+70123001531"}
0005434654226	8534B1	8952 683022	ALEKSANDRA DMITRIEVA	{"phone": "+70136125693"}
0005434654227	114833	3044 719662	ANASTASIYA YAKOVLEVA	{"phone": "+70845322361"}
0005434654228	114833	0602 398947	PAVEL SEMENOV	{"email": "semenovpavel.26071964@postgrespro.ru", "phone": "+70194106547"}
0005434654229	C28390	4419 957154	KIRILL MAKSIMOV	{"phone": "+70734650130"}
0005434654230	BC5CC0	7379 707827	VLADIMIR NAZAROV	{"email": "v_nazarov-021974@postgrespro.ru", "phone": "+70944250139"}
0005434654231	2B25FD	7595 104664	ANDREY EGOROV	{"email": "andrey-egorov_1974@postgrespro.ru", "phone": "+70220156482"}
0005434654232	35A85D	5052 355066	IVAN ANDREEV	{"phone": "+70335754668"}
0005434654233	EEB9F3	6193 967298	MAKSIM NOVIKOV	{"phone": "+70206260822"}
0005434654234	F09F18	8135 430273	KSENIYA GERASIMOVA	{"email": "kseniya.gerasimova_1980@postgrespro.ru", "phone": "+70197421024"}
0005434654235	6FE74B	0835 762158	EVGENIY PETROV	{"email": "petrov.evgeniy-1972@postgrespro.ru", "phone": "+70130810589"}
0005434654236	2F1F72	4744 917629	PELAGEYA KOROLEVA	{"email": "pelageya_koroleva-1979@postgrespro.ru", "phone": "+70798693011"}
0005434654237	2F1F72	6170 857655	ILYA ALEKSEEV	{"email": "alekseev.ilya.1967@postgrespro.ru", "phone": "+70773296511"}
0005434654238	EA3F78	6579 544787	DMITRIY EGOROV	{"email": "d-egorov-27081961@postgrespro.ru", "phone": "+70073976912"}
0005434654239	340123	6241 492129	DARYA ORLOVA	{"email": "d.orlova08101975@postgrespro.ru", "phone": "+70870311769"}
0005434654240	169C3A	9977 438840	NIKOLAY NIKITIN	{"email": "nikolay_nikitin-1964@postgrespro.ru", "phone": "+70787312142"}
0005434654241	169C3A	7446 531516	VLADIMIR VOLKOV	{"phone": "+70906744335"}
0005434654242	EB6D6A	0179 217520	IVAN MARTYNOV	{"email": "martynov-i.15071968@postgrespro.ru", "phone": "+70223849152"}
0005434654243	8590CD	4772 381335	KSENIYA KONDRATEVA	{"phone": "+70766414983"}
0005434654244	8590CD	0676 257984	TATYANA NIKOLAEVA	{"phone": "+70285688991"}
0005434654245	48E86F	3364 136445	IVAN VOLKOV	{"phone": "+70692073767"}
0005434654246	48E86F	5425 523919	TAMARA GRISHINA	{"email": "tamara_grishina.25091973@postgrespro.ru", "phone": "+70087634885"}
0005434654247	D2802B	2734 627581	NIKOLAY VASILEV	{"email": "n.vasilev_1966@postgrespro.ru", "phone": "+70903631161"}
0005434654248	D2802B	7896 233298	VLADIMIR ABRAMOV	{"phone": "+70272954462"}
0005434654249	F3972D	0398 301675	MAKSIM ROMANOV	{"phone": "+70495289767"}
0005434654250	F3972D	8001 815491	PETR ZAKHAROV	{"phone": "+70616370079"}
0005434654251	92BC28	4553 616235	EVGENIY KOROLEV	{"phone": "+70828241268"}
0005434654252	7D53F1	9240 801740	LYUBOV GUSEVA	{"email": "lyubov-guseva-05061981@postgrespro.ru", "phone": "+70768580786"}
0005434654253	7D53F1	5791 668992	OLGA KALININA	{"phone": "+70504167406"}
0005434654254	C2EB10	0670 299698	MIKHAIL MOROZOV	{"phone": "+70906410568"}
0005434654255	F25F43	0087 730056	INNA FOMINA	{"phone": "+70884531397"}
0005434654256	E63701	4805 275199	ANATOLIY SCHERBAKOV	{"email": "a.scherbakov-17061975@postgrespro.ru", "phone": "+70699062273"}
0005434654257	E63701	0114 387839	YURIY KOZLOV	{"phone": "+70183983059"}
0005434654258	A0564A	2150 255857	MAKSIM NAUMOV	{"email": "m.naumov_22081971@postgrespro.ru", "phone": "+70596544873"}
0005434654259	A0564A	5545 824879	VITALIY SCHERBAKOV	{"phone": "+70046388786"}
0005434654260	0FF36D	6729 929866	MAKSIM DMITRIEV	{"email": "mdmitriev02111968@postgrespro.ru", "phone": "+70997041839"}
0005434654261	E42BF0	4164 864202	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov.1962@postgrespro.ru", "phone": "+70952606134"}
0005434654262	C8D84E	4375 810621	VLADIMIR ANDREEV	{"email": "andreev-vladimir1985@postgrespro.ru", "phone": "+70137482124"}
0005434654263	C8D84E	9766 909469	ALEKSEY VOLKOV	{"email": "volkov-a.061987@postgrespro.ru", "phone": "+70496714161"}
0005434654264	C8D84E	3493 980568	ALEKSANDR NIKITIN	{"phone": "+70540577736"}
0005434654265	132830	9233 405188	VLADIMIR KISELEV	{"email": "kiselevvladimir.26061980@postgrespro.ru", "phone": "+70683048307"}
0005434654266	F4887F	6733 901779	ANNA SMIRNOVA	{"phone": "+70303391535"}
0005434654267	EAC0A0	5078 044869	DMITRIY GUSEV	{"email": "d.gusev1978@postgrespro.ru", "phone": "+70349586319"}
0005434654268	C6E5AA	9417 827012	VIKTOR MIRONOV	{"phone": "+70376135006"}
0005434654269	C6E5AA	2805 227068	LYUBOV ERMAKOVA	{"email": "ermakova_lyubov-101983@postgrespro.ru", "phone": "+70360994296"}
0005434654270	D4D296	6637 010477	YULIYA GORBUNOVA	{"email": "gorbunova-yuliya.1965@postgrespro.ru", "phone": "+70481760626"}
0005434654271	D4D296	2742 707706	SERGEY GERASIMOV	{"phone": "+70094916465"}
0005434654272	801E93	3917 153651	LYUDMILA BELYAEVA	{"email": "lbelyaeva021970@postgrespro.ru", "phone": "+70189412441"}
0005434654273	801E93	6713 317696	VIKTOR ROMANOV	{"phone": "+70827122638"}
0005434654274	1D3028	8649 483507	VLADIMIR KUZMIN	{"email": "vladimir_kuzmin_10091973@postgrespro.ru", "phone": "+70548800910"}
0005434654275	9505FB	2319 003981	OLGA NESTEROVA	{"email": "olga_nesterova.1968@postgrespro.ru", "phone": "+70560027502"}
0005434654276	BCB1B8	1721 774159	MARINA ABRAMOVA	{"email": "m.abramova1969@postgrespro.ru", "phone": "+70644493488"}
0005434654277	42F9E6	9065 860151	TATYANA PETROVA	{"email": "petrova.tatyana.031974@postgrespro.ru", "phone": "+70625338273"}
0005434654278	5B3F37	3462 892494	ALBINA PETROVA	{"email": "petrova-a-1971@postgrespro.ru", "phone": "+70727203547"}
0005434654279	5B3F37	2147 200250	TATYANA NIKITINA	{"email": "tatyananikitina.1968@postgrespro.ru", "phone": "+70295642897"}
0005434654280	5B3F37	1269 793340	VIKTOR OSIPOV	{"phone": "+70442319466"}
0005434654281	16B674	1146 593717	SERGEY OSIPOV	{"email": "osipov.sergey-16061967@postgrespro.ru", "phone": "+70203658174"}
0005434654282	8D19A7	3770 132973	OLEG SOLOVEV	{"email": "oleg_solovev041974@postgrespro.ru", "phone": "+70584640726"}
0005434654283	43850D	0152 072020	OKSANA GORBUNOVA	{"email": "oksana.gorbunova-04111976@postgrespro.ru", "phone": "+70773543565"}
0005434654284	E38DA0	2498 548701	LILIYA VASILEVA	{"email": "vasileva.liliya_16091972@postgrespro.ru", "phone": "+70210358868"}
0005434654285	E38DA0	9929 096008	NATALYA EGOROVA	{"email": "egorova.n.04081984@postgrespro.ru", "phone": "+70107526826"}
0005434654286	C98855	3584 950926	EMILIYA NIKOLAEVA	{"email": "nikolaeva_emiliya-06071969@postgrespro.ru", "phone": "+70382627609"}
0005434654287	534F39	7175 214389	RAISA NOVIKOVA	{"email": "raisa-novikova.07011966@postgrespro.ru", "phone": "+70231889397"}
0005434654288	EE3FCB	6463 110752	EVGENIY TARASOV	{"email": "tarasov.evgeniy.111967@postgrespro.ru", "phone": "+70759367199"}
0005434654289	127BE1	4038 531113	SVETLANA MARTYNOVA	{"email": "s.martynova.1974@postgrespro.ru", "phone": "+70424031808"}
0005434654290	4BCBF6	1084 107903	ZOYA KRASNOVA	{"phone": "+70559122098"}
0005434654291	24D5C7	2608 938897	YULIYA PAVLOVA	{"phone": "+70538135289"}
0005434654292	24D5C7	0874 860874	LEONID FROLOV	{"phone": "+70584918558"}
0005434654293	A49CBC	0880 248650	DMITRIY MATVEEV	{"phone": "+70141843525"}
0005434654294	A49CBC	5992 582742	OLGA KOZLOVA	{"email": "o_kozlova.121970@postgrespro.ru", "phone": "+70323573401"}
0005434654295	1D541C	3241 210000	VALERIYA RODIONOVA	{"phone": "+70504189400"}
0005434654296	550279	9973 984561	MARIYA SOKOLOVA	{"phone": "+70520648438"}
0005434654297	55E123	5301 945007	YULIYA MAKAROVA	{"email": "makarova.yuliya101967@postgrespro.ru", "phone": "+70543263009"}
0005434654298	55E123	5433 784619	STANISLAV SAVELEV	{"phone": "+70555934602"}
0005434654299	08906F	5959 378010	KRISTINA VLASOVA	{"email": "kristinavlasova111958@postgrespro.ru", "phone": "+70139225504"}
0005434654300	159C12	7421 446361	PAVEL SEMENOV	{"email": "pavel.semenov011971@postgrespro.ru", "phone": "+70930514812"}
0005434654301	4BA76A	4630 596485	SVETLANA IVANOVA	{"email": "ivanova-s_051987@postgrespro.ru", "phone": "+70679876342"}
0005434654302	745E7C	1906 682556	SVETLANA SCHERBAKOVA	{"email": "svetlana_scherbakova_041978@postgrespro.ru", "phone": "+70678597312"}
0005434654303	247481	7204 385515	ALEKSANDR ANDREEV	{"email": "a_andreev.08081963@postgrespro.ru", "phone": "+70926617205"}
0005434654304	9CAF17	9581 577392	DARYA AKIMOVA	{"phone": "+70389311206"}
0005434654305	C5054C	5866 590925	ANGELINA BELOVA	{"email": "angelinabelova_051979@postgrespro.ru", "phone": "+70647587528"}
0005434654306	DDA96B	4832 512249	VALERIY RODIONOV	{"email": "v-rodionov.111983@postgrespro.ru", "phone": "+70383994029"}
0005434654307	5B84F2	9294 846153	PAVEL ISAEV	{"phone": "+70259258816"}
0005434654308	19ABFD	5844 691811	ANGELINA MOISEEVA	{"phone": "+70927394201"}
0005434654309	9E0D71	4839 752911	ANTON ROMANOV	{"email": "romanov.a11051975@postgrespro.ru", "phone": "+70177490342"}
0005434654310	9E0D71	3218 094486	NATALIYA FEDOROVA	{"email": "nfedorova-011963@postgrespro.ru", "phone": "+70977444324"}
0005434654311	ED8103	1070 714986	DMITRIY YAKOVLEV	{"email": "yakovlev_d.1972@postgrespro.ru", "phone": "+70480190158"}
0005434654312	ED8103	6979 192677	NINA KUZNECOVA	{"email": "kuznecova_nina-1972@postgrespro.ru", "phone": "+70874266821"}
0005434654313	4D753D	5300 355276	ANDREY BORISOV	{"email": "andrey.borisov.1971@postgrespro.ru", "phone": "+70296108672"}
0005434654314	917F29	9613 109799	ELENA KONOVALOVA	{"phone": "+70970211884"}
0005434654315	A34384	4361 230789	ANDREY SOKOLOV	{"email": "a.sokolov-111972@postgrespro.ru", "phone": "+70510120211"}
0005434654316	A34384	9898 524663	ELENA IVANOVA	{"email": "ivanova_e_081977@postgrespro.ru", "phone": "+70569078658"}
0005434654317	F2516F	6559 733763	NINA POPOVA	{"phone": "+70684860495"}
0005434654318	F2516F	1633 119215	DARYA IVANOVA	{"email": "d.ivanova.1957@postgrespro.ru", "phone": "+70045394969"}
0005434654319	9A4FFD	3437 367683	SERGEY ANTONOV	{"phone": "+70213756371"}
0005434654320	60592F	1271 937488	ELENA VOLKOVA	{"email": "volkova.elena-14031970@postgrespro.ru", "phone": "+70861221024"}
0005434654321	E026C3	8041 754968	VYACHESLAV KAZAKOV	{"email": "kazakov-v_01041967@postgrespro.ru", "phone": "+70134966094"}
0005434654322	E026C3	8700 292319	OLGA SMIRNOVA	{"phone": "+70167260168"}
0005434654323	C70B9F	4461 675049	ANTON STEPANOV	{"email": "stepanov_a_1975@postgrespro.ru", "phone": "+70754281399"}
0005434654324	F8054B	2069 249655	VITALIY TARASOV	{"phone": "+70867635418"}
0005434654325	03DEE7	0941 662991	OLGA BORISOVA	{"phone": "+70010712279"}
0005434654326	DBFA3D	9024 630880	ROMAN ORLOV	{"phone": "+70399889729"}
0005434654327	AA5E37	1713 007994	DANA TIKHONOVA	{"email": "danatikhonova.101969@postgrespro.ru", "phone": "+70808692511"}
0005434654328	AA5E37	2405 753668	OLEG ZAKHAROV	{"phone": "+70090742572"}
0005434654329	87DD3F	9580 264770	LARISA VOLKOVA	{"phone": "+70847029683"}
0005434654330	3D8180	0367 227146	EVGENIY KARPOV	{"email": "karpove-041971@postgrespro.ru", "phone": "+70693335960"}
0005434654331	405C24	6810 385568	ALEKSEY ZAYCEV	{"phone": "+70130395519"}
0005434654332	405C24	5614 255981	IVAN SOKOLOV	{"email": "i.sokolov.041962@postgrespro.ru", "phone": "+70687873503"}
0005434654333	405C24	9560 325021	VLADIMIR MATVEEV	{"email": "matveevvladimir-16091975@postgrespro.ru", "phone": "+70442498219"}
0005434654334	5A3036	8390 135530	DARYA RYABOVA	{"email": "ryabova-d-1969@postgrespro.ru", "phone": "+70579286860"}
0005434654335	5A3036	9928 075458	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev-11071973@postgrespro.ru", "phone": "+70114028288"}
0005434654336	E37A45	8254 580174	ANASTASIYA ROMANOVA	{"email": "romanova.anastasiya.1961@postgrespro.ru", "phone": "+70392488244"}
0005434654337	984C58	1730 110648	ALEKSANDR ORLOV	{"phone": "+70389310135"}
0005434654338	984C58	4537 517068	YURIY FILIPPOV	{"email": "filippov-y021969@postgrespro.ru", "phone": "+70058201773"}
0005434654339	195DF3	5825 211755	KLAVDIYA SOKOLOVA	{"email": "sokolova_k.1964@postgrespro.ru", "phone": "+70233206809"}
0005434654340	2B7F35	8697 797348	ELENA YUDINA	{"email": "eyudina041971@postgrespro.ru", "phone": "+70349527393"}
0005434654341	8C4A9E	9159 662446	DIANA SOROKINA	{"phone": "+70073138979"}
0005434654342	F06A85	7834 831102	LYUBOV LAZAREVA	{"phone": "+70824365430"}
0005434654343	5DB6DF	9130 143966	SVETLANA IVANOVA	{"phone": "+70768025909"}
0005434654344	974F32	4151 361995	VYACHESLAV RODIONOV	{"phone": "+70443785852"}
0005434654345	6A64C3	7174 677038	ANDREY PETROV	{"email": "petrov_a_22011971@postgrespro.ru", "phone": "+70333631231"}
0005434654346	6A64C3	8992 994672	GRIGORIY NIKITIN	{"phone": "+70899336107"}
0005434654347	0EE59E	4115 179933	IGOR KAZAKOV	{"phone": "+70277025498"}
0005434654348	507B9B	1637 740572	RISHAT SAVELEV	{"email": "savelev_r.051973@postgrespro.ru", "phone": "+70849075443"}
0005434654349	AFB7C1	0664 579966	ALFIYA SERGEEVA	{"email": "a.sergeeva_111983@postgrespro.ru", "phone": "+70833266547"}
0005434654350	AFB7C1	0493 915075	VASILIY SHEVCHENKO	{"email": "shevchenko_vasiliy1973@postgrespro.ru", "phone": "+70751171111"}
0005434654351	369B27	8952 962962	TAMARA CHERNOVA	{"email": "chernova.t_021984@postgrespro.ru", "phone": "+70891217137"}
0005434654352	91C695	9117 525982	ALENA KOZLOVA	{"phone": "+70479060922"}
0005434654353	91C695	2369 448053	ARTUR VOLKOV	{"phone": "+70208942186"}
0005434654354	0E6712	6874 561172	SVETLANA MATVEEVA	{"phone": "+70002415475"}
0005434654355	0E6712	2335 041732	NADEZHDA BORISOVA	{"email": "borisovanadezhda.1965@postgrespro.ru", "phone": "+70223558665"}
0005434654356	BCC856	0411 980519	ALEKSANDRA FOMINA	{"email": "aleksandra_fomina-1975@postgrespro.ru", "phone": "+70675659287"}
0005434654357	BCC856	8624 735900	DMITRIY SOROKIN	{"phone": "+70508228571"}
0005434654358	BCC856	5379 489500	IVAN ABRAMOV	{"email": "abramovi.071970@postgrespro.ru", "phone": "+70147455998"}
0005434654359	DEB963	6891 795596	GALINA FADEEVA	{"email": "fadeeva_galina011977@postgrespro.ru", "phone": "+70284259534"}
0005434654360	A5F2B8	0760 637633	ANDREY ILIN	{"email": "ilin-a_18031961@postgrespro.ru", "phone": "+70097441637"}
0005434654361	C3FBB5	0179 987233	NATALYA SOROKINA	{"email": "natalya_sorokina07061971@postgrespro.ru", "phone": "+70290932147"}
0005434654362	22E57D	7584 164128	VALERIYA POLYAKOVA	{"email": "v_polyakova_111984@postgrespro.ru", "phone": "+70931955441"}
0005434654363	22E57D	4089 292458	KRISTINA GORBUNOVA	{"email": "kristina_gorbunova.1977@postgrespro.ru", "phone": "+70401548560"}
0005434654364	852870	5838 578131	VLADISLAV ANTONOV	{"phone": "+70889323401"}
0005434654365	1A9F83	8438 889698	SABINA BORISOVA	{"email": "borisovas.30101970@postgrespro.ru", "phone": "+70463289633"}
0005434654366	929B50	1437 055897	DMITRIY KONOVALOV	{"email": "konovalovd.1976@postgrespro.ru", "phone": "+70120235155"}
0005434654367	A1636A	4336 488942	NINA KRASNOVA	{"email": "nina_krasnova1961@postgrespro.ru", "phone": "+70191997906"}
0005434654368	4CBC07	0869 649318	TATYANA ARKHIPOVA	{"phone": "+70500589356"}
0005434654369	95B9BC	8462 736219	SERGEY KONOVALOV	{"email": "s-konovalov101967@postgrespro.ru", "phone": "+70439522060"}
0005434654370	7675BD	0529 047056	ELENA SOROKINA	{"phone": "+70799190516"}
0005434654371	6465C9	7116 828402	ELINA PETROVA	{"email": "petrovaelina_02051968@postgrespro.ru", "phone": "+70576311721"}
0005434654372	6465C9	4797 512246	KONSTANTIN NOVIKOV	{"email": "k.novikov03121967@postgrespro.ru", "phone": "+70912561767"}
0005434654373	53D02C	9313 695715	VIKTOR KONOVALOV	{"phone": "+70891582032"}
0005434654374	02D23D	8264 970089	ANDREY SERGEEV	{"email": "andrey_sergeev121957@postgrespro.ru", "phone": "+70494766166"}
0005434654375	02D23D	3978 173806	TATYANA PETROVA	{"phone": "+70918095401"}
0005434654376	2C60A7	5500 393512	NATALYA IVANOVA	{"phone": "+70827413585"}
0005434654377	A669A0	8053 714367	LYUDMILA CHERNOVA	{"phone": "+70081928244"}
0005434654378	795FD6	3916 698191	NATALYA KULIKOVA	{"phone": "+70875810407"}
0005434654379	795FD6	4116 326540	ALEKSANDR KULIKOV	{"email": "aleksandr_kulikov-061991@postgrespro.ru", "phone": "+70759837740"}
0005434654380	F61371	8244 717720	OLESYA NAZAROVA	{"email": "nazarova-o.25111968@postgrespro.ru", "phone": "+70243421212"}
0005434654381	F61371	5092 105854	MARIYA NAZAROVA	{"email": "nazarovamariya_1972@postgrespro.ru", "phone": "+70693390604"}
0005434654382	E77FB4	1630 569194	ALENA NIKOLAEVA	{"email": "a-nikolaeva18091967@postgrespro.ru", "phone": "+70743927544"}
0005434654383	D64263	9467 000352	VALERIY NIKITIN	{"phone": "+70490708055"}
0005434654384	204509	1905 793735	VLADIMIR CHERNOV	{"phone": "+70574832387"}
0005434654385	204509	4585 309245	KRISTINA DMITRIEVA	{"phone": "+70908416055"}
0005434654386	8EBA7D	7664 459654	SOFYA ANDREEVA	{"phone": "+70280374734"}
0005434654387	E0C80F	6073 565637	LIDIYA NIKOLAEVA	{"email": "lidiya_nikolaeva.16021972@postgrespro.ru", "phone": "+70935042143"}
0005434654388	34209C	7383 621490	DMITRIY BELOV	{"email": "dmitriy-belov1962@postgrespro.ru", "phone": "+70400946979"}
0005434654389	6B3C65	9181 019555	IGOR ANTONOV	{"phone": "+70412502935"}
0005434654390	630910	5729 715321	LILIYA KAZAKOVA	{"phone": "+70142770884"}
0005434654391	1AF733	2644 650340	IRINA GUSEVA	{"phone": "+70550147397"}
0005434654392	5396F4	4163 210334	OLGA IVANOVA	{"email": "ivanova_olga.1967@postgrespro.ru", "phone": "+70046505967"}
0005434654393	5396F4	4531 514684	PAVEL DENISOV	{"phone": "+70258423885"}
0005434654394	6C87E3	5843 955814	LEONID KUZNECOV	{"phone": "+70531367679"}
0005434654395	FC8AAC	0193 416917	SERGEY KULIKOV	{"email": "kulikov_s.101977@postgrespro.ru", "phone": "+70177633596"}
0005434654396	312CA3	4312 614611	YURIY FILIPPOV	{"phone": "+70055509812"}
0005434654397	8D9D27	6059 102940	ALEKSANDR ZHUKOV	{"phone": "+70125938048"}
0005434654398	0F28C1	1283 601440	TATYANA BORISOVA	{"email": "tatyana.borisova-1969@postgrespro.ru", "phone": "+70006475554"}
0005434654399	164073	2420 090723	VLADIMIR BARANOV	{"phone": "+70311610056"}
0005434654400	8DBBB0	6016 347622	ALEKSANDR KULIKOV	{"phone": "+70148771728"}
0005434654401	C939DE	5903 710731	NADEZHDA KUZNECOVA	{"phone": "+70672792089"}
0005434654402	96AA39	0324 498099	YULIYA VASILEVA	{"email": "vasilevay-13051974@postgrespro.ru", "phone": "+70256872832"}
0005434654403	4E7266	6948 964312	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr_03051980@postgrespro.ru", "phone": "+70502173813"}
0005434654404	EDE184	0140 332585	NATALYA AFANASEVA	{"email": "n-afanaseva.031973@postgrespro.ru", "phone": "+70300441318"}
0005434654405	DEF3D7	2379 346980	ELENA KONDRATEVA	{"email": "e.kondrateva-26081969@postgrespro.ru", "phone": "+70653863478"}
0005434654406	DEF3D7	2606 533557	NATALYA LEBEDEVA	{"phone": "+70510754644"}
0005434654407	31F127	2161 519036	ILYA ZHUKOV	{"phone": "+70203954327"}
0005434654408	F59D7C	5175 011082	YURIY SIDOROV	{"phone": "+70013582631"}
0005434654409	0BAE80	2084 072535	ALEKSANDR VLASOV	{"email": "vlasov_aleksandr-1977@postgrespro.ru", "phone": "+70814721865"}
0005434654410	AB9F2B	3716 913834	VALENTINA PETROVA	{"phone": "+70394140419"}
0005434654411	AB9F2B	1438 933550	ELENA MARTYNOVA	{"phone": "+70804921354"}
0005434654412	AB9F2B	3973 963795	GALINA ANDREEVA	{"email": "g-andreeva-091962@postgrespro.ru", "phone": "+70253225720"}
0005434654413	02F563	6249 445204	ELENA EGOROVA	{"email": "e.egorova_17101960@postgrespro.ru", "phone": "+70951204478"}
0005434654414	02F563	6809 488919	NINA KUZMINA	{"phone": "+70708523617"}
0005434654415	B53196	2005 000972	MAKSIM GAVRILOV	{"phone": "+70881796350"}
0005434654416	53E143	6474 522464	YULIYA NAUMOVA	{"email": "yuliyanaumova03041962@postgrespro.ru", "phone": "+70065207754"}
0005434654417	53E143	4413 168498	ARTEM BARANOV	{"phone": "+70921945240"}
0005434654418	938B35	4098 486727	NADEZHDA TITOVA	{"email": "titova-n.1965@postgrespro.ru", "phone": "+70347886490"}
0005434654419	938B35	5680 713928	STEPAN ILIN	{"phone": "+70627862574"}
0005434654420	938B35	2017 259686	SERGEY KOZLOV	{"email": "s.kozlov-051977@postgrespro.ru", "phone": "+70249136810"}
0005434654421	E73EB7	3605 691346	SERGEY KRASNOV	{"email": "krasnov_s1965@postgrespro.ru", "phone": "+70363731181"}
0005434654422	16885E	8385 903901	VLADIMIR VASILEV	{"email": "vasilevv011979@postgrespro.ru", "phone": "+70230283156"}
0005434654423	125E4E	7879 164959	MATVEY ORLOV	{"email": "orlovmatvey.051972@postgrespro.ru", "phone": "+70164230577"}
0005434654424	125E4E	7307 083084	KLAVDIYA BORISOVA	{"email": "borisova_klavdiya_24021960@postgrespro.ru", "phone": "+70243628395"}
0005434654425	BF082E	3904 277118	EKATERINA IVANOVA	{"phone": "+70486590811"}
0005434654426	C7EA53	6667 025411	NINA BELOVA	{"phone": "+70328504896"}
0005434654427	83C6B1	7714 308513	TATYANA MALYSHEVA	{"email": "t_malysheva_111959@postgrespro.ru", "phone": "+70406049676"}
0005434654428	21887A	8051 758157	KAMILLA DAVYDOVA	{"email": "davydova.k_1968@postgrespro.ru", "phone": "+70905494160"}
0005434654429	16D397	5558 576316	DMITRIY GAVRILOV	{"phone": "+70573805618"}
0005434654430	68D01A	9154 776141	VIKTOR ZAKHAROV	{"email": "viktor-zakharov29121964@postgrespro.ru", "phone": "+70321250043"}
0005434654431	303E3B	4640 300307	POLINA NOVIKOVA	{"email": "polina-novikova-15011965@postgrespro.ru", "phone": "+70326894129"}
0005434654432	8F7F7A	7222 261030	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov11041979@postgrespro.ru", "phone": "+70342215338"}
0005434654433	8F7F7A	0455 581150	VIKTOR NIKOLAEV	{"phone": "+70289795794"}
0005434654434	FCD44D	4855 654441	VALERIY MIKHAYLOV	{"phone": "+70058983250"}
0005434654435	FCD44D	7790 025342	ALEKSEY GRIGOREV	{"email": "a-grigorev_22021972@postgrespro.ru", "phone": "+70163862035"}
0005434654436	1F4AAF	9420 064812	SVETLANA NIKITINA	{"phone": "+70106435707"}
0005434654437	C5983F	1531 670530	ANVAR KOZLOV	{"email": "anvarkozlov-02051963@postgrespro.ru", "phone": "+70167211177"}
0005434654438	32CF4A	3109 631714	DENIS KISELEV	{"email": "denis-kiselev27051978@postgrespro.ru", "phone": "+70219235040"}
0005434654439	32CF4A	0674 624463	SVETLANA KULIKOVA	{"phone": "+70198547927"}
0005434654440	7F1708	0081 012722	VALENTINA ANDREEVA	{"email": "andreevavalentina-1961@postgrespro.ru", "phone": "+70805412562"}
0005434654441	40EA27	5573 798110	SVETLANA PAVLOVA	{"email": "spavlova-1960@postgrespro.ru", "phone": "+70401922609"}
0005434654442	7C0429	8806 827016	NIKITA MAKAROV	{"phone": "+70062182406"}
0005434654443	7C0429	2739 754402	VIKTOR TIKHONOV	{"phone": "+70587720462"}
0005434654444	7C0429	8192 085296	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov_23091981@postgrespro.ru", "phone": "+70060990767"}
0005434654445	7C0429	2276 839544	ANDREY NAUMOV	{"phone": "+70117724001"}
0005434654446	E63750	3340 231033	OLGA NESTEROVA	{"phone": "+70559747376"}
0005434654447	F442AF	9234 334577	DANIIL TARASOV	{"phone": "+70516934898"}
0005434654448	B46E91	3625 232110	DMITRIY MIKHAYLOV	{"email": "d_mikhaylov.1978@postgrespro.ru", "phone": "+70007514478"}
0005434654449	B46E91	8048 045540	EVGENIY SOROKIN	{"phone": "+70288153107"}
0005434654450	2F5CA9	4212 507366	IVAN KOZLOV	{"email": "kozlov_i-101969@postgrespro.ru", "phone": "+70914170912"}
0005434654451	2F5CA9	4998 023382	MARGARITA IVANOVA	{"phone": "+70517282808"}
0005434654452	DE90E9	3405 938715	PAVEL POPOV	{"email": "pavel-popov.10121964@postgrespro.ru", "phone": "+70436945794"}
0005434654453	DE90E9	5279 123829	OLEG FEDOTOV	{"phone": "+70100601985"}
0005434654454	3D787A	0221 878658	SVETLANA PETROVA	{"phone": "+70366351646"}
0005434654455	3D787A	2395 459646	RASHIT KISELEV	{"email": "kiselev_r_081968@postgrespro.ru", "phone": "+70353505582"}
0005434654456	656A6A	8366 637509	VALERIY FEDOROV	{"phone": "+70616318466"}
0005434654457	656A6A	0372 185531	VLADIMIR PETROV	{"email": "vladimir.petrov-10111974@postgrespro.ru", "phone": "+70405567829"}
0005434654458	110664	5578 630547	SERGEY MAKAROV	{"phone": "+70124365625"}
0005434654459	110664	8836 726911	EVELINA MAKAROVA	{"phone": "+70767625636"}
0005434654460	110664	8644 585592	NATALYA GAVRILOVA	{"email": "gavrilova_natalya_22071972@postgrespro.ru", "phone": "+70650510895"}
0005434654461	DE940F	4539 418093	ANTONINA MOISEEVA	{"phone": "+70984028971"}
0005434654462	DE940F	0426 796915	ANTONINA PETROVA	{"email": "antonina.petrova-18111979@postgrespro.ru", "phone": "+70719834466"}
0005434654463	2ED01E	1326 887149	VLADISLAV NOVIKOV	{"email": "v-novikov111968@postgrespro.ru", "phone": "+70708334024"}
0005434654464	75F2C6	3336 420855	RIMMA SAVELEVA	{"email": "r.saveleva.1973@postgrespro.ru", "phone": "+70377768417"}
0005434654465	75F2C6	3376 791044	ALSU TARASOVA	{"phone": "+70657443708"}
0005434654466	37D61F	0634 259514	SERGEY KUZNECOV	{"email": "kuznecov.s.111980@postgrespro.ru", "phone": "+70787256036"}
0005434654467	DC9F4F	1557 957971	VLADISLAV ZAKHAROV	{"email": "zakharov.vladislav-051963@postgrespro.ru", "phone": "+70852430029"}
0005434654468	787679	8443 317169	EVGENIY GERASIMOV	{"email": "gerasimov_e-091973@postgrespro.ru", "phone": "+70759504962"}
0005434654469	B08C6E	1711 175171	EVGENIY NOVIKOV	{"email": "novikovevgeniy111962@postgrespro.ru", "phone": "+70152034199"}
0005434654524	1481C3	9553 799268	LYUDMILA NAZAROVA	{"phone": "+70362744132"}
0005434654470	F63244	0810 986426	VLADIMIR VLASOV	{"email": "vlasov_vladimir1975@postgrespro.ru", "phone": "+70145363826"}
0005434654471	906532	4777 956683	NATALYA ISAEVA	{"email": "natalya_isaeva21041966@postgrespro.ru", "phone": "+70789611573"}
0005434654472	F95F2D	4154 461023	ELENA VASILEVA	{"email": "vasileva_e-071970@postgrespro.ru", "phone": "+70370330051"}
0005434654473	F95F2D	5158 426909	MARIYA MELNIKOVA	{"email": "melnikovamariya.081971@postgrespro.ru", "phone": "+70290663227"}
0005434654474	719EAF	6706 036977	TAMARA KULIKOVA	{"email": "tkulikova_26081966@postgrespro.ru", "phone": "+70792930424"}
0005434654475	4D74A2	8168 334492	FEDOR TARASOV	{"phone": "+70585934003"}
0005434654476	4D74A2	4412 643532	LYUDMILA FILIPPOVA	{"phone": "+70308013187"}
0005434654534	B37EA4	4899 678487	VALENTINA EGOROVA	{"phone": "+70262829020"}
0005434654477	4EB41C	5343 032237	LYUDMILA ANDREEVA	{"email": "andreeva.lyudmila_29111978@postgrespro.ru", "phone": "+70093144131"}
0005434654478	4EB41C	6123 282320	POLINA RYABOVA	{"email": "ryabova_polina051980@postgrespro.ru", "phone": "+70824994859"}
0005434654479	72EF95	7407 378780	LYUBOV GORBUNOVA	{"phone": "+70844665387"}
0005434654480	72EF95	8767 677463	EKATERINA NIKIFOROVA	{"email": "nikiforovaekaterina_20041972@postgrespro.ru", "phone": "+70199872544"}
0005434654481	D2DF7F	1521 725691	VERONIKA KOZLOVA	{"phone": "+70291572075"}
0005434654482	F12740	3699 510747	YULIYA BOGDANOVA	{"email": "y-bogdanova1971@postgrespro.ru", "phone": "+70524291048"}
0005434654483	F4C00B	9265 398657	ALEKSEY VASILEV	{"email": "aleksey.vasilev_1971@postgrespro.ru", "phone": "+70611719274"}
0005434654484	F4C00B	2879 828289	SVETLANA PAVLOVA	{"email": "pavlova-s_121981@postgrespro.ru", "phone": "+70452267569"}
0005434654485	20DBE4	5037 542616	ANATOLIY FILIPPOV	{"email": "filippov_anatoliy.25041971@postgrespro.ru", "phone": "+70610028785"}
0005434654486	8ABE53	7654 324496	ANASTASIYA BELOVA	{"email": "belova_a091984@postgrespro.ru", "phone": "+70038671236"}
0005434654487	8ABE53	9419 184526	VALENTINA KUZNECOVA	{"phone": "+70683813837"}
0005434654488	8ABE53	1671 439924	VYACHESLAV FILIPPOV	{"email": "filippovvyacheslav-09071977@postgrespro.ru", "phone": "+70264176087"}
0005434654489	533872	4123 814397	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.1980@postgrespro.ru", "phone": "+70469587199"}
0005434654490	4B4B96	3502 338038	ANDREY KUZNECOV	{"phone": "+70178420173"}
0005434654491	187316	4895 278644	SERGEY SIDOROV	{"email": "s_sidorov1963@postgrespro.ru", "phone": "+70552589724"}
0005434654492	CBFD63	0446 572643	ILONA TIKHONOVA	{"email": "tikhonova.ilona_031972@postgrespro.ru", "phone": "+70730365758"}
0005434654493	CBFD63	6331 130279	EKATERINA KONOVALOVA	{"phone": "+70640581667"}
0005434654494	B319FC	3582 693065	SERAFIMA RODIONOVA	{"email": "srodionova_19051971@postgrespro.ru", "phone": "+70639314643"}
0005434654495	3C6713	2890 993564	OLGA KOZLOVA	{"email": "kozlova-o.10091978@postgrespro.ru", "phone": "+70619497383"}
0005434654496	3C6713	0974 378594	MIKHAIL OSIPOV	{"email": "mosipov.031989@postgrespro.ru", "phone": "+70438035872"}
0005434654497	3C6713	0395 074755	PAVEL BARANOV	{"email": "baranov.pavel.031977@postgrespro.ru", "phone": "+70789027674"}
0005434654498	3C6713	8013 372900	VIKTOR IVANOV	{"email": "ivanov-v_29121961@postgrespro.ru", "phone": "+70279503028"}
0005434654499	A1D8E1	1052 814694	DMITRIY GERASIMOV	{"phone": "+70774090295"}
0005434654500	A1D8E1	3478 882964	EVGENIY EGOROV	{"phone": "+70015263685"}
0005434654501	A0EC74	4280 998566	KONSTANTIN ZAYCEV	{"email": "k.zaycev-1968@postgrespro.ru", "phone": "+70315177061"}
0005434654502	915DB8	5676 048586	VIKTOR ZHURAVLEV	{"phone": "+70144970534"}
0005434654503	DC1283	1018 571669	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey23101963@postgrespro.ru", "phone": "+70580564659"}
0005434654504	DC1283	7504 421692	VLADISLAV DENISOV	{"email": "vdenisov_071984@postgrespro.ru", "phone": "+70765679118"}
0005434654505	84AA81	2864 774838	DMITRIY VOLKOV	{"email": "volkov-dmitriy-081968@postgrespro.ru", "phone": "+70577188497"}
0005434654506	BA8C38	7572 294551	VLADIMIR FILIPPOV	{"email": "filippov-v_15031965@postgrespro.ru", "phone": "+70235150044"}
0005434654507	BA8C38	9441 568423	PETR AFANASEV	{"email": "pafanasev-22061971@postgrespro.ru", "phone": "+70287201439"}
0005434654508	D4293C	3114 468149	KRISTINA SEMENOVA	{"email": "k_semenova081978@postgrespro.ru", "phone": "+70713707765"}
0005434654509	D4293C	0314 502398	ANNA MATVEEVA	{"email": "matveeva_a1956@postgrespro.ru", "phone": "+70558066758"}
0005434654510	DFDBEE	5041 647814	VYACHESLAV VLASOV	{"phone": "+70330063601"}
0005434654511	07E8F7	0395 321935	SVETLANA VASILEVA	{"email": "vasileva-svetlana-03111964@postgrespro.ru", "phone": "+70986472675"}
0005434654512	95C583	4196 229156	NINA GORBUNOVA	{"email": "nina.gorbunova.01041984@postgrespro.ru", "phone": "+70683913120"}
0005434654513	DA2C82	5636 477315	IVAN POPOV	{"email": "i.popov.101977@postgrespro.ru", "phone": "+70434209811"}
0005434654514	DA2C82	9305 964875	EVGENIYA BELOVA	{"email": "evgeniya_belova26021966@postgrespro.ru", "phone": "+70548760674"}
0005434654515	C3EF9F	3309 281540	MIKHAIL POPOV	{"phone": "+70718828421"}
0005434654516	141C0D	7992 517967	SVETLANA FROLOVA	{"phone": "+70397026625"}
0005434654517	B7078C	5459 541545	VASILIY FEDOTOV	{"phone": "+70878862474"}
0005434654518	8E7ACA	7535 915578	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov.18031964@postgrespro.ru", "phone": "+70586404370"}
0005434654519	896833	9149 963396	PAVEL MOISEEV	{"phone": "+70073099447"}
0005434654520	896833	4192 539762	SERGEY ZAKHAROV	{"email": "sergey-zakharov041972@postgrespro.ru", "phone": "+70897528547"}
0005434654521	24E5D8	6784 349111	GALINA KULIKOVA	{"phone": "+70548416289"}
0005434654522	0F8EF7	5496 266165	GALINA GUSEVA	{"phone": "+70280941520"}
0005434654523	526940	1669 855643	VLADIMIR MOROZOV	{"email": "v-morozov011963@postgrespro.ru", "phone": "+70231384075"}
0005434654525	877AE9	5202 711673	ELENA KOROLEVA	{"email": "korolevaelena_1971@postgrespro.ru", "phone": "+70982790518"}
0005434654526	877AE9	7794 223478	PETR NIKITIN	{"email": "nikitin-petr14091976@postgrespro.ru", "phone": "+70980304834"}
0005434654527	EFA104	7828 352221	NATALYA ANTONOVA	{"email": "antonovanatalya.021971@postgrespro.ru", "phone": "+70837574011"}
0005434654528	8FCA99	9578 309503	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov101970@postgrespro.ru", "phone": "+70537810293"}
0005434654529	8FCA99	6977 777703	NINA KUZNECOVA	{"email": "kuznecova_nina-101974@postgrespro.ru", "phone": "+70992914012"}
0005434654530	489D36	5799 981465	YULIYA KUZNECOVA	{"email": "kuznecova-y-091958@postgrespro.ru", "phone": "+70389252837"}
0005434654531	11F15C	3688 579626	VADIM VOLKOV	{"email": "volkov.vadim_07021979@postgrespro.ru", "phone": "+70352926390"}
0005434654532	D4DDA9	0326 658112	EKATERINA RYABOVA	{"phone": "+70330876449"}
0005434654533	D4DDA9	6994 176458	IVAN ROMANOV	{"email": "romanov_i1971@postgrespro.ru", "phone": "+70451343000"}
0005434654535	B67F30	8183 930672	ANDREY SMIRNOV	{"phone": "+70425702449"}
0005434654536	B67F30	9513 746996	DMITRIY BARANOV	{"email": "baranov-dmitriy_1993@postgrespro.ru", "phone": "+70106889460"}
0005434654537	D4ECF4	9286 622513	OLEG KAZAKOV	{"email": "kazakovoleg061986@postgrespro.ru", "phone": "+70942212103"}
0005434654538	D4ECF4	9187 959144	VIKTOR GRIGOREV	{"phone": "+70006223104"}
0005434654539	4BAD24	5942 550679	SVETLANA VOLKOVA	{"email": "s.volkova-10091972@postgrespro.ru", "phone": "+70612729248"}
0005434654540	4BAD24	4786 320993	MARAT MAKAROV	{"phone": "+70390272212"}
0005434654541	A06C7C	7444 896392	GALINA VLASOVA	{"email": "galina.vlasova_1981@postgrespro.ru", "phone": "+70530784546"}
0005434654542	53CEFB	3227 249935	EVGENIY KUZNECOV	{"email": "kuznecov-e-09091973@postgrespro.ru", "phone": "+70680111310"}
0005434654543	53CEFB	2536 880293	MARIYA KOROLEVA	{"email": "m_koroleva.08071975@postgrespro.ru", "phone": "+70083288002"}
0005434654544	08A12B	3266 253317	TATYANA EFIMOVA	{"phone": "+70173100201"}
0005434654545	08A12B	8276 543707	TATYANA EFREMOVA	{"email": "tatyana_efremova.1974@postgrespro.ru", "phone": "+70542374391"}
0005434654546	2D541A	4224 262699	TATYANA KALININA	{"phone": "+70090183605"}
0005434654547	2D541A	0498 979421	OLGA ROMANOVA	{"email": "romanovaolga_111971@postgrespro.ru", "phone": "+70817992553"}
0005434654548	C48779	0120 955446	VLADIMIR NIKOLAEV	{"phone": "+70941677186"}
0005434654549	EDC830	0644 032380	POLINA FADEEVA	{"phone": "+70291930523"}
0005434654550	05C5B8	7595 717479	IRINA NIKOLAEVA	{"phone": "+70203378869"}
0005434654551	F84A5F	3438 945342	IRINA NESTEROVA	{"phone": "+70935952333"}
0005434654552	A390EB	7325 971275	VIKTOR ALEKSEEV	{"phone": "+70907957932"}
0005434654553	067637	0464 075001	IRINA ABRAMOVA	{"phone": "+70544074062"}
0005434654554	CDC467	1374 912573	NIKOLAY SAVELEV	{"email": "savelev_nikolay-031970@postgrespro.ru", "phone": "+70369975057"}
0005434654555	D12039	9106 373479	KIRILL EGOROV	{"email": "egorovkirill.1975@postgrespro.ru", "phone": "+70169742762"}
0005434654556	9A7DD8	4146 579825	ELENA KAZAKOVA	{"phone": "+70442793525"}
0005434654557	A21A2F	9927 179722	ALEKSANDR FOMIN	{"phone": "+70562428966"}
0005434654558	84F18B	6380 004801	SVETLANA FROLOVA	{"phone": "+70979326942"}
0005434654559	104586	3524 814242	SERGEY KARPOV	{"phone": "+70393219955"}
0005434654560	CBF5AC	4152 195061	NINA BOGDANOVA	{"email": "nina_bogdanova-081967@postgrespro.ru", "phone": "+70200379166"}
0005434654561	CBF5AC	2829 804413	ALEKSANDR ZHURAVLEV	{"phone": "+70825549946"}
0005434654562	43EA23	2554 673882	ALEKSEY MARTYNOV	{"email": "martynov.a22101982@postgrespro.ru", "phone": "+70652528100"}
0005434654563	9276B3	9070 322412	LYUDMILA KOZLOVA	{"phone": "+70718323282"}
0005434654564	9276B3	3820 171044	VLADIMIR SMIRNOV	{"phone": "+70155041719"}
0005434654565	04CCFE	6974 783989	MAKSIM VASILEV	{"email": "maksim_vasilev-021967@postgrespro.ru", "phone": "+70711195183"}
0005434654566	3347E0	3781 967628	VITALIY SCHERBAKOV	{"phone": "+70015464010"}
0005434654567	1A65C2	7180 797242	MIKHAIL GORBUNOV	{"phone": "+70960685666"}
0005434654568	44691C	1266 288010	VASILIY MAKSIMOV	{"email": "maksimovv24071979@postgrespro.ru", "phone": "+70646043870"}
0005434654569	44691C	6598 635541	ROMAN ALEKSEEV	{"email": "r-alekseev.27081972@postgrespro.ru", "phone": "+70832402014"}
0005434654570	B9B8A7	1159 324092	ALEKSEY SIDOROV	{"phone": "+70193603491"}
0005434654571	B9B8A7	1273 952510	MARIYA SIDOROVA	{"email": "mariya-sidorova_01121977@postgrespro.ru", "phone": "+70403993671"}
0005434654572	556D56	1889 318755	OKSANA KUZNECOVA	{"email": "kuznecovao.121966@postgrespro.ru", "phone": "+70414137825"}
0005434654573	277D44	6442 526027	EVGENIY GAVRILOV	{"phone": "+70399590562"}
0005434654574	1B9719	7972 148733	SEMEN SIDOROV	{"email": "sidorovs-1976@postgrespro.ru", "phone": "+70125621140"}
0005434654575	1B9719	1062 082199	OLGA ILINA	{"email": "o.ilina-061974@postgrespro.ru", "phone": "+70239775628"}
0005434654576	9789C2	8495 516312	YANA VLASOVA	{"phone": "+70712266927"}
0005434654577	F0E6B7	8283 221150	SERGEY SAVELEV	{"phone": "+70822263314"}
0005434654578	4592E1	0234 057615	YULIYA DENISOVA	{"phone": "+70577360555"}
0005434654579	4592E1	4652 157661	ARTEM KUZNECOV	{"phone": "+70780956673"}
0005434654580	7132A1	1404 920556	ALEKSANDR POPOV	{"email": "aleksandr_popov.051969@postgrespro.ru", "phone": "+70857487971"}
0005434654581	924482	4269 603888	SERGEY SAVELEV	{"phone": "+70048385995"}
0005434654582	90F6B8	6408 560622	OLGA DENISOVA	{"phone": "+70935672584"}
0005434654583	5E5470	2998 676639	SVETLANA FOMINA	{"email": "svetlana_fomina061970@postgrespro.ru", "phone": "+70263014574"}
0005434654584	5E5470	4656 808882	ARTEM ALEKSANDROV	{"email": "a-aleksandrov_1971@postgrespro.ru", "phone": "+70626116059"}
0005434654585	402455	2125 352856	VLADIMIR POPOV	{"phone": "+70050082967"}
0005434654586	402455	0905 759222	VASILIY FEDOROV	{"phone": "+70210778106"}
0005434654587	0EF13C	9377 397909	DMITRIY SAVELEV	{"email": "d_savelev-071966@postgrespro.ru", "phone": "+70376450677"}
0005434654588	240FF5	5499 853298	DMITRIY MIRONOV	{"phone": "+70342869732"}
0005434654589	6C312B	2156 872487	DENIS ZAKHAROV	{"phone": "+70944253992"}
0005434654590	6C312B	5539 507338	MAKSIM STEPANOV	{"email": "m_stepanov031973@postgrespro.ru", "phone": "+70005894346"}
0005434654591	C54087	1270 030759	YURIY SCHERBAKOV	{"phone": "+70396326895"}
0005434654592	8869C6	0821 522384	BORIS ALEKSANDROV	{"phone": "+70937492721"}
0005434654593	0179E3	5416 573960	VIKTOR FEDOROV	{"email": "viktor_fedorov_14041978@postgrespro.ru", "phone": "+70360676192"}
0005434654594	7EA23D	2658 298830	SERGEY ISAEV	{"phone": "+70214679464"}
0005434654595	7EA23D	4841 615404	IGOR IVANOV	{"phone": "+70998252789"}
0005434654596	800447	8086 159815	MIKHAIL ISAEV	{"email": "mikhailisaev_121966@postgrespro.ru", "phone": "+70407655746"}
0005434654597	800447	0804 551281	OLGA BORISOVA	{"email": "borisova.olga-1971@postgrespro.ru", "phone": "+70628617026"}
0005434654598	1296F6	5279 414339	YURIY MIRONOV	{"email": "yuriy-mironov.19011983@postgrespro.ru", "phone": "+70312904026"}
0005434654599	10F91C	5676 299267	ELENA TITOVA	{"phone": "+70119923219"}
0005434654600	9E2918	0659 839782	NIKOLAY ROMANOV	{"phone": "+70472122024"}
0005434654601	369F0B	9310 180416	ALEKSANDR SEMENOV	{"phone": "+70767972402"}
0005434654602	369F0B	0138 161053	ALEKSANDR POPOV	{"email": "popov-a-17091973@postgrespro.ru", "phone": "+70859569825"}
0005434654603	5D1C70	8264 081457	OLESYA MIKHAYLOVA	{"phone": "+70070450405"}
0005434654604	5D1C70	8736 617222	SERGEY POPOV	{"email": "spopov_061979@postgrespro.ru", "phone": "+70606781908"}
0005434654605	6DEDF5	8358 263045	DMITRIY IVANOV	{"phone": "+70989619280"}
0005434654606	6DEDF5	4192 185469	LIDIYA KAZAKOVA	{"email": "kazakova-lidiya1964@postgrespro.ru", "phone": "+70485728543"}
0005434654607	02E1D8	2496 771964	ANASTASIYA KARPOVA	{"email": "karpova.anastasiya_011976@postgrespro.ru", "phone": "+70070574348"}
0005434654608	02E1D8	4078 193983	OLGA EGOROVA	{"email": "egorova_o_1971@postgrespro.ru", "phone": "+70773193831"}
0005434654609	BA0466	2608 835854	RAMZIYA BARANOVA	{"email": "baranova-r_1968@postgrespro.ru", "phone": "+70580783497"}
0005434654610	C423E9	9611 944232	NINA ANDREEVA	{"phone": "+70438588546"}
0005434654611	5207C2	9435 526922	VITALIY KUZNECOV	{"phone": "+70325891431"}
0005434654612	D6E573	7613 109522	VERA NAUMOVA	{"email": "naumovavera.1976@postgrespro.ru", "phone": "+70115827760"}
0005434654613	D6E573	5923 149033	MARINA ZHUKOVA	{"phone": "+70552620835"}
0005434654614	6EDF6F	3914 582489	ELENA ABRAMOVA	{"email": "abramovaelena.121976@postgrespro.ru", "phone": "+70096308009"}
0005434654615	6EDF6F	3141 852701	MAKSIM ROMANOV	{"email": "maksim_romanov.1981@postgrespro.ru", "phone": "+70524416568"}
0005434654616	D4C284	8323 612982	MIKHAIL GERASIMOV	{"phone": "+70225607142"}
0005434654617	D4C284	9583 337522	VASILIY NAZAROV	{"email": "v_nazarov.1979@postgrespro.ru", "phone": "+70654834431"}
0005434654618	E26C60	9070 574077	ANGELINA ALEKSEEVA	{"email": "alekseevaangelina.061973@postgrespro.ru", "phone": "+70683080954"}
0005434654619	446D7A	1662 573895	TATYANA GERASIMOVA	{"email": "gerasimova_tatyana-29081969@postgrespro.ru", "phone": "+70295046810"}
0005434654620	446D7A	0644 101899	LIDIYA ZHUKOVA	{"phone": "+70774243999"}
0005434654621	446D7A	8584 492681	ZULFIYA MAKAROVA	{"phone": "+70030376002"}
0005434654622	78D464	2166 675051	OLGA MOISEEVA	{"phone": "+70986619136"}
0005434654623	ECA022	7176 126743	NATALYA RODIONOVA	{"phone": "+70551761490"}
0005434654624	216004	0396 559422	NATALYA VASILEVA	{"email": "vasilevan1962@postgrespro.ru", "phone": "+70777888295"}
0005434654625	7787E2	8879 702597	ALEKSANDR MOROZOV	{"email": "morozov_a-091965@postgrespro.ru", "phone": "+70252802664"}
0005434654626	872F1E	1229 470446	TAMARA MELNIKOVA	{"email": "melnikova-t.1972@postgrespro.ru", "phone": "+70173143771"}
0005434654627	7F117F	4726 720602	NATALYA ANDREEVA	{"email": "andreeva-natalya.081977@postgrespro.ru", "phone": "+70626554709"}
0005434654628	2EA1E8	0958 974191	GALINA VOLKOVA	{"phone": "+70857982275"}
0005434654629	C2AB6B	4762 705437	DAMIR IVANOV	{"phone": "+70351030214"}
0005434654630	C2AB6B	0433 952419	ALEKSEY SCHERBAKOV	{"phone": "+70314458911"}
0005434654631	D6D403	6117 937857	OLGA NIKOLAEVA	{"email": "onikolaeva_02011974@postgrespro.ru", "phone": "+70846798433"}
0005434654632	440AB9	1776 260369	DANIIL VASILEV	{"email": "daniilvasilev_081989@postgrespro.ru", "phone": "+70733522180"}
0005434654633	440AB9	9114 980059	EVGENIY IVANOV	{"email": "evgeniy-ivanov06061970@postgrespro.ru", "phone": "+70321422023"}
0005434654634	A40A73	2484 809705	NATALYA IVANOVA	{"phone": "+70739610627"}
0005434654635	D022F0	5292 934943	LYUBOV KULIKOVA	{"phone": "+70280666438"}
0005434654636	155BD8	8917 565643	IVAN VOROBEV	{"email": "i-vorobev_05021970@postgrespro.ru", "phone": "+70760434779"}
0005434654637	7165AB	4335 916542	ELENA ZOTOVA	{"phone": "+70447463555"}
0005434654638	7165AB	2778 642241	VALENTINA PAVLOVA	{"phone": "+70404991082"}
0005434654639	7165AB	2647 623054	VLADIMIR MOROZOV	{"email": "v-morozov1965@postgrespro.ru", "phone": "+70334417079"}
0005434654640	7165AB	2938 581479	ELENA KUZNECOVA	{"email": "kuznecova_elena1974@postgrespro.ru", "phone": "+70440454611"}
0005434654641	E8476E	2223 109970	VADIM TIKHONOV	{"email": "vtikhonov-081957@postgrespro.ru", "phone": "+70066916739"}
0005434654642	A303FF	7830 934454	ALEKSEY EGOROV	{"phone": "+70638469914"}
0005434654643	565E3E	6172 502848	LYUDMILA MAKAROVA	{"email": "makarova_lyudmila_1972@postgrespro.ru", "phone": "+70544320778"}
0005434654644	E738B4	7261 183210	GEORGIY SOROKIN	{"email": "sorokin_georgiy-1963@postgrespro.ru", "phone": "+70354720472"}
0005434654645	F08668	7164 756838	MARINA MEDVEDEVA	{"email": "mmedvedeva_05081966@postgrespro.ru", "phone": "+70138795285"}
0005434654646	F08668	6942 873278	GENNADIY AFANASEV	{"phone": "+70145749935"}
0005434654647	A4C9E6	4267 566813	SERGEY MOROZOV	{"email": "morozov-sergey_121970@postgrespro.ru", "phone": "+70311555613"}
0005434654648	6347A2	3841 735866	SVETLANA SOLOVEVA	{"email": "svetlanasoloveva1979@postgrespro.ru", "phone": "+70093394376"}
0005434654649	6347A2	1768 292047	NINA KONDRATEVA	{"phone": "+70867798800"}
0005434654650	6347A2	1369 701987	DINARA KRASNOVA	{"email": "d_krasnova-24101968@postgrespro.ru", "phone": "+70517738098"}
0005434654651	581D73	8229 329194	EKATERINA STEPANOVA	{"phone": "+70173914273"}
0005434654652	605F03	4897 031772	AZAT SOKOLOV	{"email": "azat-sokolov041973@postgrespro.ru", "phone": "+70976832819"}
0005434654653	605F03	5577 998680	NATALYA MARTYNOVA	{"phone": "+70581461153"}
0005434654654	6E1711	6955 523856	ANZHELIKA ANTONOVA	{"email": "antonova_anzhelika.031972@postgrespro.ru", "phone": "+70898914602"}
0005434654655	6E1711	5243 275008	OLEG NIKOLAEV	{"email": "oleg.nikolaev.14041973@postgrespro.ru", "phone": "+70083805551"}
0005434654656	6E1711	7743 908205	GALINA SCHERBAKOVA	{"email": "scherbakovag1972@postgrespro.ru", "phone": "+70993294430"}
0005434654657	B1E4A2	6066 873813	IVAN AFANASEV	{"email": "afanasevi_041981@postgrespro.ru", "phone": "+70345088002"}
0005434654658	B1E4A2	6263 246427	NATALYA ORLOVA	{"email": "natalya-orlova1974@postgrespro.ru", "phone": "+70477731113"}
0005434654659	210889	0317 060711	MARIYA NAZAROVA	{"email": "mariya.nazarova.111974@postgrespro.ru", "phone": "+70459451266"}
0005434654660	210889	6563 746241	MIKHAIL PETROV	{"email": "petrov.m.27031965@postgrespro.ru", "phone": "+70119200717"}
0005434654661	40712D	0596 857093	DARYA POTAPOVA	{"email": "darya.potapova_111973@postgrespro.ru", "phone": "+70827062552"}
0005434654662	40712D	8361 750145	YULIYA POPOVA	{"phone": "+70094993322"}
0005434654663	40712D	4628 675021	VADIM FROLOV	{"phone": "+70962444213"}
0005434654719	C4B854	9128 620180	PAVEL NIKITIN	{"phone": "+70381140839"}
0005434654664	10ACFE	3952 892533	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana-121966@postgrespro.ru", "phone": "+70420973976"}
0005434654665	825DFC	2250 084891	STEPAN IVANOV	{"email": "s-ivanov1984@postgrespro.ru", "phone": "+70620250603"}
0005434654666	FAA418	8372 204366	YULIYA ERMAKOVA	{"phone": "+70801508442"}
0005434654667	FAA418	4464 578536	VADIM MIKHAYLOV	{"phone": "+70594689998"}
0005434654668	29115A	6903 392506	NIKOLAY GORBUNOV	{"email": "gorbunov-nikolay28031971@postgrespro.ru", "phone": "+70251810973"}
0005434654669	DEDD2B	5061 541643	IGOR DAVYDOV	{"email": "davydov.i.071973@postgrespro.ru", "phone": "+70942697827"}
0005434654670	A879A5	7064 067056	DARYA NOVIKOVA	{"email": "d_novikova.1966@postgrespro.ru", "phone": "+70691410526"}
0005434654671	E22D74	7516 175348	EKATERINA MOISEEVA	{"phone": "+70310056730"}
0005434654672	EBB3E8	4702 807627	ANNA DANILOVA	{"email": "adanilova-081975@postgrespro.ru", "phone": "+70188334339"}
0005434654673	EBB3E8	6310 951722	KLAVDIYA KOVALEVA	{"email": "k-kovaleva-081969@postgrespro.ru", "phone": "+70741690165"}
0005434654674	7E9E2F	4645 290330	EVGENIY FROLOV	{"email": "evgeniy.frolov19111971@postgrespro.ru", "phone": "+70827231828"}
0005434654675	9218BA	7223 429426	NINA TITOVA	{"email": "titova.n-22031975@postgrespro.ru", "phone": "+70770914505"}
0005434654676	09E871	7755 536095	ALEKSANDR MAKAROV	{"phone": "+70498954699"}
0005434654677	09E871	7767 895154	ALENA KUZMINA	{"email": "kuzmina.a.081969@postgrespro.ru", "phone": "+70609741393"}
0005434654678	C815AC	0305 998796	NAIL NAZAROV	{"email": "nazarov-nail.031970@postgrespro.ru", "phone": "+70034765252"}
0005434654679	22AFFD	4014 212413	ELENA FROLOVA	{"phone": "+70696922353"}
0005434654680	22AFFD	9556 371351	VYACHESLAV CHERNOV	{"phone": "+70343390308"}
0005434654681	9BDA80	0945 264168	DMITRIY KUZNECOV	{"email": "d-kuznecov.051981@postgrespro.ru", "phone": "+70853687948"}
0005434654682	C9E0E1	9933 076701	ANDREY NOVIKOV	{"phone": "+70180754063"}
0005434654683	91D40C	0646 880774	IVAN EGOROV	{"email": "ivanegorov-16061971@postgrespro.ru", "phone": "+70057640642"}
0005434654684	D851D1	4851 636047	NATALYA NAUMOVA	{"email": "naumovanatalya021972@postgrespro.ru", "phone": "+70669648876"}
0005434654685	D851D1	6948 166640	SVETLANA POPOVA	{"phone": "+70107602566"}
0005434654686	D5C8AE	8013 757559	NATALYA GERASIMOVA	{"phone": "+70371636553"}
0005434654687	3BDE76	4994 771659	NINA DMITRIEVA	{"email": "n_dmitrieva-1971@postgrespro.ru", "phone": "+70870759066"}
0005434654688	3BDE76	9272 677073	EVGENIY NOVIKOV	{"email": "evgeniy_novikov.121978@postgrespro.ru", "phone": "+70518431277"}
0005434654689	E71C04	8102 153867	EKATERINA NIKIFOROVA	{"email": "e-nikiforova031966@postgrespro.ru", "phone": "+70089931644"}
0005434654690	09D701	8065 076146	SERGEY BONDARENKO	{"phone": "+70444636258"}
0005434654691	09D701	9237 875628	ANDREY ZHUKOV	{"email": "a-zhukov.061973@postgrespro.ru", "phone": "+70725667159"}
0005434654692	961EF8	1311 228074	VYACHESLAV KULIKOV	{"phone": "+70100688313"}
0005434654693	961EF8	0216 852263	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay-16011969@postgrespro.ru", "phone": "+70217301132"}
0005434654694	67962B	1144 436670	ELENA VOLKOVA	{"phone": "+70529690289"}
0005434654695	93511B	8057 442584	LYUDMILA VOLKOVA	{"email": "volkova_l101976@postgrespro.ru", "phone": "+70851524385"}
0005434654696	93511B	8460 789382	SVETLANA IVANOVA	{"phone": "+70531392449"}
0005434654697	400144	2938 639605	VALENTINA SMIRNOVA	{"email": "smirnovav_10091972@postgrespro.ru", "phone": "+70301654355"}
0005434654698	FD7F5A	3067 189755	NIKITA DMITRIEV	{"email": "dmitriev_nikita28121977@postgrespro.ru", "phone": "+70100475094"}
0005434654699	613A7F	6498 872579	ALEKSANDR CHERNOV	{"email": "chernovaleksandr-021976@postgrespro.ru", "phone": "+70572872886"}
0005434654700	892117	1852 135525	TATYANA KUDRYASHOVA	{"email": "tatyanakudryashova-031971@postgrespro.ru", "phone": "+70820521361"}
0005434654701	883BED	7595 989359	VLADIMIR PETROV	{"email": "petrovv1978@postgrespro.ru", "phone": "+70064113624"}
0005434654702	CB5CB3	9010 003839	BORIS SEMENOV	{"email": "b-semenov1964@postgrespro.ru", "phone": "+70762825220"}
0005434654703	614F4B	2930 405391	DMITRIY PETROV	{"phone": "+70646817545"}
0005434654704	614F4B	5445 551716	OLESYA ALEKSEEVA	{"phone": "+70840697181"}
0005434654705	F82602	2877 727022	VIKTORIYA GAVRILOVA	{"email": "viktoriya.gavrilova-091966@postgrespro.ru", "phone": "+70675226499"}
0005434654706	3D3133	6507 622861	NIKOLAY NOVIKOV	{"email": "n.novikov.26031976@postgrespro.ru", "phone": "+70547382140"}
0005434654707	6B65AC	8469 935386	ANNA AFANASEVA	{"email": "afanaseva.a-24061985@postgrespro.ru", "phone": "+70642062694"}
0005434654708	6B65AC	5741 214437	IGOR SEMENOV	{"email": "semenov.igor.19041964@postgrespro.ru", "phone": "+70192320843"}
0005434654709	DCB3E2	7702 971924	TATYANA OVCHINNIKOVA	{"phone": "+70804958110"}
0005434654710	003270	6595 601208	ANDREY MEDVEDEV	{"email": "medvedev.andrey031959@postgrespro.ru", "phone": "+70860295596"}
0005434654711	485117	5625 878041	VLADIMIR MOROZOV	{"email": "vladimir_morozov-1979@postgrespro.ru", "phone": "+70758027093"}
0005434654712	485117	8344 743295	ARTEM PAVLOV	{"phone": "+70081062846"}
0005434654834	F5A5B5	5227 810824	ANDREY KUZNECOV	{"phone": "+70699042536"}
0005434654713	68EF61	8707 078441	VLADIMIR MATVEEV	{"email": "matveev_vladimir1959@postgrespro.ru", "phone": "+70526463813"}
0005434654714	A54126	4163 974063	TAMARA NESTEROVA	{"email": "nesterova.t1976@postgrespro.ru", "phone": "+70037582728"}
0005434654715	405359	2183 736273	ELENA ERMAKOVA	{"email": "elena_ermakova21031970@postgrespro.ru", "phone": "+70597445288"}
0005434654716	D1C13E	3415 376130	OLGA SOLOVEVA	{"email": "olga_soloveva28111974@postgrespro.ru", "phone": "+70329069371"}
0005434654717	D1C13E	9662 473828	OLGA DANILOVA	{"email": "olga.danilova-12011963@postgrespro.ru", "phone": "+70254600419"}
0005434654718	C4B854	8864 986244	EKATERINA IVANOVA	{"phone": "+70648063151"}
0005434654720	0A3EC9	7737 193353	GALINA YAKOVLEVA	{"email": "yakovleva.g.1973@postgrespro.ru", "phone": "+70023352382"}
0005434654721	D636D3	6418 975307	RAISA KOROLEVA	{"email": "r.koroleva21061967@postgrespro.ru", "phone": "+70369888653"}
0005434654722	50D87C	1328 415748	ANTONINA SEMENOVA	{"phone": "+70642530006"}
0005434654723	781E4F	9733 520246	RIMMA BARANOVA	{"email": "baranovar_1963@postgrespro.ru", "phone": "+70280767505"}
0005434654724	88B713	6328 898535	DMITRIY MELNIKOV	{"email": "dmelnikov-13071982@postgrespro.ru", "phone": "+70775129768"}
0005434654725	88B713	5574 452854	EKATERINA DAVYDOVA	{"email": "davydovaekaterina.1968@postgrespro.ru", "phone": "+70477714893"}
0005434654726	4BD18E	8853 605418	VLADIMIR DAVYDOV	{"phone": "+70975715793"}
0005434654727	24548F	0172 243099	GALINA SOKOLOVA	{"email": "sokolova.galina_1994@postgrespro.ru", "phone": "+70960472091"}
0005434654728	EA5BDA	7125 242247	VLADIMIR IVANOV	{"phone": "+70738168951"}
0005434654729	BA77D4	8561 665871	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana1962@postgrespro.ru", "phone": "+70655920356"}
0005434654730	4EAB8D	9119 740096	FEDOR FEDOTOV	{"email": "fedotov_f1970@postgrespro.ru", "phone": "+70776717726"}
0005434654731	EC0EF1	2506 609861	SEMEN BORISOV	{"phone": "+70757149415"}
0005434654732	EC0EF1	5080 488143	SVETLANA BELOVA	{"phone": "+70884840484"}
0005434654733	EC0EF1	4787 940932	NADEZHDA TROFIMOVA	{"phone": "+70673367917"}
0005434654734	A84E2C	4945 971075	PAVEL PETROV	{"email": "petrovpavel.03011973@postgrespro.ru", "phone": "+70595380712"}
0005434654735	A84E2C	5850 626880	VALENTINA LUKYANOVA	{"phone": "+70629801222"}
0005434654736	E17C2F	4338 291751	SERGEY KRASNOV	{"email": "skrasnov-1978@postgrespro.ru", "phone": "+70414909529"}
0005434654737	BC02DF	0754 074612	SAMIR MELNIKOV	{"email": "s_melnikov.071973@postgrespro.ru", "phone": "+70711861077"}
0005434654738	894D70	3002 614852	SERGEY SOKOLOV	{"phone": "+70761695388"}
0005434654739	397CC5	2394 600180	POLINA KOLESNIKOVA	{"email": "kolesnikova.polina1971@postgrespro.ru", "phone": "+70662184527"}
0005434654740	150347	5997 721022	ANNA KRASNOVA	{"email": "anna.krasnova.041971@postgrespro.ru", "phone": "+70846131301"}
0005434654741	CC52B3	4214 954555	DMITRIY GERASIMOV	{"phone": "+70712667493"}
0005434654742	5723B9	5805 285656	NINA LOGINOVA	{"email": "nloginova1973@postgrespro.ru", "phone": "+70857129035"}
0005434654743	07B397	0068 622363	OLGA TIKHONOVA	{"phone": "+70414059326"}
0005434654744	9C4169	9860 126843	KRISTINA PETROVA	{"phone": "+70965184089"}
0005434654745	CD980A	2783 758051	PETR SIDOROV	{"phone": "+70461246388"}
0005434654746	CD980A	4479 569507	EVGENIY MATVEEV	{"email": "evgeniy-matveev04021982@postgrespro.ru", "phone": "+70526609165"}
0005434654747	2755F6	0209 893547	NATALYA VOLKOVA	{"phone": "+70090805371"}
0005434654748	35493A	2815 744829	OLGA POTAPOVA	{"phone": "+70849535180"}
0005434654749	35493A	3079 596190	ELENA ZAKHAROVA	{"email": "elena.zakharova-18051975@postgrespro.ru", "phone": "+70894924456"}
0005434654750	9ED01D	5849 912965	EKATERINA KARPOVA	{"email": "e-karpova-10051977@postgrespro.ru", "phone": "+70550223701"}
0005434654751	786E2D	8328 917824	MIKHAIL FILIPPOV	{"email": "filippovmikhail_091976@postgrespro.ru", "phone": "+70603339721"}
0005434654752	786E2D	0800 073739	ELENA MASLOVA	{"email": "emaslova_1970@postgrespro.ru", "phone": "+70484784022"}
0005434654753	FA9405	7834 362872	ANASTASIYA ILINA	{"email": "ilinaanastasiya_051973@postgrespro.ru", "phone": "+70520248193"}
0005434654754	9A95F3	0740 625718	NATALYA SOROKINA	{"phone": "+70542953839"}
0005434654755	4208F1	2714 084437	GALINA ZHUKOVA	{"email": "gzhukova_04011978@postgrespro.ru", "phone": "+70892564650"}
0005434654756	4208F1	9627 171992	DENIS GORBUNOV	{"email": "d-gorbunov-12081985@postgrespro.ru", "phone": "+70688082786"}
0005434654757	4208F1	9656 427685	IVAN MOROZOV	{"phone": "+70153160060"}
0005434654758	201A2B	8708 764568	MARINA SERGEEVA	{"phone": "+70999723092"}
0005434654759	44F76F	3381 567158	LILIYA NOVIKOVA	{"email": "novikova-l.011964@postgrespro.ru", "phone": "+70656820153"}
0005434654760	E7C08E	3052 998992	DANILA KOROLEV	{"phone": "+70987243200"}
0005434654761	C89441	9627 795464	NIKITA KRASNOV	{"phone": "+70118246977"}
0005434654762	F7E9D4	6438 146154	VALERIY ZAYCEV	{"phone": "+70416440978"}
0005434654763	097C7D	5661 202053	NINA ALEKSEEVA	{"email": "nina.alekseeva.14121977@postgrespro.ru", "phone": "+70215131143"}
0005434654764	A14B53	4037 994081	GEORGIY MAKSIMOV	{"email": "g-maksimov061963@postgrespro.ru", "phone": "+70146053980"}
0005434654765	E8E71B	4785 812723	YURIY GUSEV	{"email": "gusev_y-16011959@postgrespro.ru", "phone": "+70260344170"}
0005434654766	11D11D	7287 395115	DMITRIY ANDREEV	{"email": "andreev_d08011969@postgrespro.ru", "phone": "+70410104860"}
0005434654767	2C1AAB	6464 489882	ANTONINA EGOROVA	{"phone": "+70066952896"}
0005434654768	F7D102	2238 049666	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr_111966@postgrespro.ru", "phone": "+70318063637"}
0005434654769	AEEC87	0493 199513	VIKTOR CHERNOV	{"phone": "+70174508728"}
0005434654770	DCDA00	0540 224481	ANNA SMIRNOVA	{"email": "a_smirnova121978@postgrespro.ru", "phone": "+70497955726"}
0005434654771	F19B06	9780 901883	NADEZHDA GERASIMOVA	{"phone": "+70280706333"}
0005434654772	C76774	5348 062650	ANNA ISAEVA	{"email": "annaisaeva_22051974@postgrespro.ru", "phone": "+70693955713"}
0005434654773	C76774	0346 277874	VALERIYA PETROVA	{"email": "petrova-valeriya.021964@postgrespro.ru", "phone": "+70919351563"}
0005434654774	1552A8	6844 351017	TIMUR GORBUNOV	{"email": "gorbunovtimur.101979@postgrespro.ru", "phone": "+70817535634"}
0005434654775	1552A8	8950 924072	YURIY IVANOV	{"phone": "+70883865508"}
0005434654776	96CCA8	3487 235260	SVETLANA CHERNOVA	{"phone": "+70697274883"}
0005434654777	CFD66E	0380 724526	IGOR OSIPOV	{"phone": "+70359316524"}
0005434654778	7C800C	6599 990475	GALINA POPOVA	{"email": "gpopova.101984@postgrespro.ru", "phone": "+70643291719"}
0005434654779	F4FB9F	9314 250366	STEPAN SCHERBAKOV	{"phone": "+70140687706"}
0005434654780	6D4E16	5054 831007	YAKOV GUSEV	{"phone": "+70764365169"}
0005434654781	B67FDC	0913 581111	YANA DMITRIEVA	{"email": "y_dmitrieva30111971@postgrespro.ru", "phone": "+70965390785"}
0005434654782	B67FDC	6345 741533	SERGEY KULIKOV	{"phone": "+70791131524"}
0005434654783	B67FDC	9542 270143	IRINA PAVLOVA	{"phone": "+70800518088"}
0005434654784	F08A44	3265 853427	ARMAN OSIPOV	{"email": "a-osipov_061981@postgrespro.ru", "phone": "+70198511385"}
0005434654785	F08A44	6774 946964	OLGA ALEKSANDROVA	{"email": "aleksandrova.olga.1967@postgrespro.ru", "phone": "+70614067715"}
0005434654786	2A1843	8411 115104	VALENTINA IVANOVA	{"email": "ivanova.valentina_031981@postgrespro.ru", "phone": "+70789223906"}
0005434654787	2A1843	0768 502278	SERGEY SMIRNOV	{"phone": "+70824442673"}
0005434654788	602C40	5057 554680	OKSANA NAZAROVA	{"phone": "+70163708080"}
0005434654789	6F9552	9671 147655	MARINA FILIPPOVA	{"email": "filippova_marina.091978@postgrespro.ru", "phone": "+70799234921"}
0005434654790	3C6744	8508 420683	RUSLAN SMIRNOV	{"phone": "+70046406848"}
0005434654791	3004C2	3280 902434	VLADIMIR ALEKSEEV	{"email": "vladimiralekseev.021963@postgrespro.ru", "phone": "+70972071339"}
0005434654792	AF7620	7282 979298	ALEKSEY SAVELEV	{"phone": "+70177727864"}
0005434654793	579D95	9661 318377	DENIS NAZAROV	{"phone": "+70676662631"}
0005434654794	579D95	1837 158056	SERGEY GERASIMOV	{"phone": "+70793042394"}
0005434654795	C6A722	7381 615776	ANDREY IVANOV	{"phone": "+70887680879"}
0005434654796	3683C5	9526 192555	PETR GORBUNOV	{"email": "gorbunov_p_011965@postgrespro.ru", "phone": "+70228333996"}
0005434654797	3683C5	2171 171134	SERGEY KUZNECOV	{"phone": "+70479245991"}
0005434654798	69F34D	7001 811119	ELENA NIKITINA	{"email": "e-nikitina1968@postgrespro.ru", "phone": "+70035479643"}
0005434654799	36C536	6208 027651	NADEZHDA KOZLOVA	{"phone": "+70082702423"}
0005434654800	673F5B	3480 649781	MARAT YAKOVLEV	{"phone": "+70973517014"}
0005434654801	E51F2C	2757 465007	MARIYA FOMINA	{"email": "fominam22101979@postgrespro.ru", "phone": "+70231396078"}
0005434654802	74CF63	2352 764958	YULIYA IVANOVA	{"phone": "+70849237796"}
0005434654803	47A104	5077 076459	VALENTINA PETROVA	{"phone": "+70739236519"}
0005434654916	03AFAE	6295 498233	VLADIMIR SHEVCHENKO	{"phone": "+70752053240"}
0005434654804	47A104	8143 844248	YURIY KUZNECOV	{"email": "ykuznecov_051967@postgrespro.ru", "phone": "+70014464785"}
0005434654805	28336A	6758 690715	VIKTOR BORISOV	{"email": "borisov_viktor_091981@postgrespro.ru", "phone": "+70308344108"}
0005434654806	28336A	6612 608533	VASILIY KISELEV	{"phone": "+70792781259"}
0005434654807	9F89C7	4480 821053	OLGA KUZNECOVA	{"email": "o.kuznecova051978@postgrespro.ru", "phone": "+70154252817"}
0005434654808	05C392	2368 121870	LYUBOV IVANOVA	{"email": "ivanova_l.021970@postgrespro.ru", "phone": "+70902138358"}
0005434654809	7F90DC	9969 497357	NATALIYA CHERNOVA	{"email": "chernova_nataliya_051967@postgrespro.ru", "phone": "+70043110496"}
0005434654810	1E5977	5552 157417	SERGEY TIKHONOV	{"email": "sergey-tikhonov-29071977@postgrespro.ru", "phone": "+70927852256"}
0005434654811	4C8895	6482 585052	NADEZHDA FOMINA	{"phone": "+70584835512"}
0005434654812	DF9DF7	9959 775803	YULIYA POLYAKOVA	{"phone": "+70433338236"}
0005434654813	1C9D0E	0740 393857	SVETLANA MAKAROVA	{"email": "smakarova_1977@postgrespro.ru", "phone": "+70083784595"}
0005434654814	497EE2	4313 338881	DMITRIY FEDOTOV	{"email": "d_fedotov-1982@postgrespro.ru", "phone": "+70893762239"}
0005434654815	497EE2	3931 848530	VLADIMIR MARTYNOV	{"phone": "+70778440760"}
0005434654816	046C36	9394 230048	DENIS MOROZOV	{"phone": "+70648957882"}
0005434654817	F55399	2335 740906	ANATOLIY BELOV	{"phone": "+70649421008"}
0005434654818	7EFD07	6928 221652	NIKOLAY VASILEV	{"phone": "+70824372390"}
0005434654819	AFF962	4886 027740	MARIYA SOROKINA	{"email": "mariya_sorokina-011973@postgrespro.ru", "phone": "+70082256410"}
0005434654820	9E4A9F	7165 213508	NATALYA RYABOVA	{"email": "ryabovanatalya.22091970@postgrespro.ru", "phone": "+70366252158"}
0005434654821	9E4A9F	9459 097562	MARIYA POPOVA	{"phone": "+70640885939"}
0005434654822	1373EF	1514 077882	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov-16071980@postgrespro.ru", "phone": "+70450368788"}
0005434654823	F83F7A	1666 902518	KSENIYA NAZAROVA	{"phone": "+70810947567"}
0005434654824	413261	4165 464608	DMITRIY ABRAMOV	{"email": "dmitriy.abramov_1969@postgrespro.ru", "phone": "+70386711119"}
0005434654825	413261	8530 133541	OLGA ROMANOVA	{"email": "olgaromanova_1964@postgrespro.ru", "phone": "+70239497290"}
0005434654826	D905E8	7688 086152	NAILYA MAKSIMOVA	{"phone": "+70030405513"}
0005434654827	D905E8	7870 025321	VYACHESLAV KUZNECOV	{"phone": "+70892519025"}
0005434654828	D905E8	8119 660428	TATYANA SOLOVEVA	{"email": "soloveva.tatyana.14061975@postgrespro.ru", "phone": "+70466677805"}
0005434654829	3863B3	1213 229175	VASILIY GRIGOREV	{"phone": "+70971999043"}
0005434654830	E53E6C	3504 807712	SERGEY ALEKSEEV	{"phone": "+70145194642"}
0005434654831	C55C40	6575 237664	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr-1975@postgrespro.ru", "phone": "+70008285931"}
0005434654832	DC23A1	0203 270567	VERA FROLOVA	{"phone": "+70591907730"}
0005434654833	DC23A1	2734 641376	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev-021980@postgrespro.ru", "phone": "+70099068756"}
0005434654835	CF2818	0899 998989	ALEKSANDRA STEPANOVA	{"phone": "+70438257538"}
0005434654836	CF2818	3821 077209	ANDREY ANDREEV	{"email": "andreev.andrey12091969@postgrespro.ru", "phone": "+70441948652"}
0005434654837	FCDC84	9765 650298	ANASTASIYA CHERNOVA	{"phone": "+70256631401"}
0005434654838	AC38F2	1760 132737	VLADIMIR BARANOV	{"email": "baranov_vladimir-23061973@postgrespro.ru", "phone": "+70490539948"}
0005434654839	8A590F	3970 410660	OKSANA FEDOROVA	{"email": "fedorova-o.1972@postgrespro.ru", "phone": "+70351380650"}
0005434654840	8A590F	3896 666395	ELENA ABRAMOVA	{"email": "e-abramova.121971@postgrespro.ru", "phone": "+70493945296"}
0005434654841	BA4C31	4074 321307	MIKHAIL ANDREEV	{"phone": "+70104249288"}
0005434654842	BA4C31	7673 695901	VADIM DAVYDOV	{"email": "vadim_davydov_01111964@postgrespro.ru", "phone": "+70306185187"}
0005434654843	3B3E70	4625 725140	KONSTANTIN VLASOV	{"email": "k.vlasov-1975@postgrespro.ru", "phone": "+70172000115"}
0005434654844	3B3E70	0819 759359	IVAN BELOV	{"phone": "+70997281890"}
0005434654845	3B3E70	6142 516875	LARISA FILIPPOVA	{"email": "larisa-filippova1969@postgrespro.ru", "phone": "+70759464082"}
0005434654846	A9BBF5	3589 016049	DARINA KONDRATEVA	{"phone": "+70394726148"}
0005434654847	A9BBF5	9508 442947	OLGA BARANOVA	{"email": "baranovaolga051978@postgrespro.ru", "phone": "+70492752953"}
0005434654848	C0F1FF	2229 261465	DENIS ZAKHAROV	{"phone": "+70782807854"}
0005434654849	EE5DDE	8255 637774	DARYA VOLKOVA	{"phone": "+70360144372"}
0005434654850	EE5DDE	4811 183507	OLESYA FEDOROVA	{"phone": "+70609348426"}
0005434654851	25D00B	4715 908713	INGA ZHURAVLEVA	{"email": "zhuravleva_i.071967@postgrespro.ru", "phone": "+70756588496"}
0005434654852	25D00B	6806 957324	DENIS SMIRNOV	{"email": "smirnov_d_15011974@postgrespro.ru", "phone": "+70518368449"}
0005434654853	40DD5F	2146 458825	GEORGIY NOVIKOV	{"phone": "+70988287904"}
0005434654854	F0D895	4792 475941	OLGA PETROVA	{"email": "opetrova-121968@postgrespro.ru", "phone": "+70939484136"}
0005434654855	29AFD6	3646 262586	MARIANNA BELOVA	{"email": "m-belova_011971@postgrespro.ru", "phone": "+70049960732"}
0005434654856	3EF417	9307 622632	ZLATA KUZNECOVA	{"phone": "+70571811549"}
0005434654857	16AB1B	6493 485591	ALINA MIKHAYLOVA	{"email": "mikhaylovaalina_15111980@postgrespro.ru", "phone": "+70946255571"}
0005434654858	798912	2972 885504	TATYANA ISAEVA	{"email": "isaeva_tatyana.121977@postgrespro.ru", "phone": "+70943254758"}
0005434654974	6DC680	1755 645970	AMIR BELOV	{"phone": "+70552548398"}
0005434654859	5339E8	4364 370408	GALINA NIKOLAEVA	{"email": "nikolaeva.g-091978@postgrespro.ru", "phone": "+70725807356"}
0005434654860	B3D8A1	2906 398943	KSENIYA ANDREEVA	{"phone": "+70899945871"}
0005434654861	B3D8A1	3237 860654	MATVEY PETROV	{"email": "matveypetrov-041983@postgrespro.ru", "phone": "+70496433268"}
0005434654862	8C9F7D	4573 386307	SERGEY MIKHAYLOV	{"phone": "+70961363053"}
0005434654863	03954E	7611 766996	ANNA NIKITINA	{"email": "nikitina-anna1963@postgrespro.ru", "phone": "+70999443397"}
0005434654864	6CB2FD	3246 541465	ALEKSANDR CHERNOV	{"email": "a.chernov-1981@postgrespro.ru", "phone": "+70948280755"}
0005434654865	8B8724	8497 684975	PETR BARANOV	{"phone": "+70679113688"}
0005434654866	775E71	6812 823507	VITALIY KUZMIN	{"email": "kuzmin-vitaliy1968@postgrespro.ru", "phone": "+70932192178"}
0005434654867	967B45	8086 264033	RAZIYA FROLOVA	{"email": "frolova_r.071973@postgrespro.ru", "phone": "+70534722907"}
0005434654868	86322F	2921 338692	DMITRIY KARPOV	{"phone": "+70655636906"}
0005434654869	460B86	9364 776083	ANNA IVANOVA	{"phone": "+70463598366"}
0005434654870	460B86	5125 995349	YURIY SERGEEV	{"phone": "+70463602617"}
0005434654871	460B86	8128 599163	PAVEL KULIKOV	{"email": "p_kulikov.1978@postgrespro.ru", "phone": "+70096656640"}
0005434654872	8D3549	3724 013288	YULIYA PETROVA	{"phone": "+70659415625"}
0005434654873	8D3549	0865 454831	MIKHAIL SCHERBAKOV	{"email": "scherbakov.mikhail1964@postgrespro.ru", "phone": "+70691716127"}
0005434654874	8D3549	3364 447560	VITALIY ABRAMOV	{"phone": "+70262909621"}
0005434654875	EAE3F3	2285 651393	DMITRIY ZHUKOV	{"phone": "+70059876285"}
0005434654876	A1F1CE	3545 181900	VALERIY EGOROV	{"phone": "+70067803956"}
0005434654877	A1F1CE	6367 154726	ARTEM TIKHONOV	{"phone": "+70815094491"}
0005434654878	3F862F	0095 400016	ELENA KONDRATEVA	{"email": "elena.kondrateva21061986@postgrespro.ru", "phone": "+70179602045"}
0005434654879	C167C3	4376 400542	RUSLAN KULIKOV	{"phone": "+70846214308"}
0005434654880	C167C3	7756 391528	ANASTASIYA KONOVALOVA	{"email": "konovalova-anastasiya_021975@postgrespro.ru", "phone": "+70337190727"}
0005434654881	47EC4B	6484 223333	MARIYA ERMAKOVA	{"phone": "+70784267265"}
0005434654882	81EF43	1461 195357	ELENA GORBUNOVA	{"email": "gorbunova.e_091975@postgrespro.ru", "phone": "+70412267730"}
0005434654883	DF6FD5	8757 407763	PAVEL MAKAROV	{"email": "pavel.makarov_17121978@postgrespro.ru", "phone": "+70367981950"}
0005434654884	1031ED	1088 877076	SVETLANA MELNIKOVA	{"phone": "+70818617392"}
0005434654885	5CC29E	7751 831488	ANASTASIYA KOVALEVA	{"phone": "+70290441271"}
0005434654886	F64593	4283 733443	ANNA SOKOLOVA	{"phone": "+70818227099"}
0005434654887	39DD8A	8487 163173	NINA IVANOVA	{"email": "ivanova-n_071963@postgrespro.ru", "phone": "+70052827602"}
0005434654888	39DD8A	0216 872089	MARINA EGOROVA	{"email": "egorova-marina_1971@postgrespro.ru", "phone": "+70749781984"}
0005434654889	B35556	2517 526403	GRIGORIY IVANOV	{"phone": "+70671350787"}
0005434654890	352278	7338 062967	OLGA MOROZOVA	{"email": "o_morozova.29091982@postgrespro.ru", "phone": "+70643999318"}
0005434654891	7959DB	7597 482161	ANNA ALEKSANDROVA	{"phone": "+70791235467"}
0005434654892	7959DB	7231 902532	TATYANA ROMANOVA	{"phone": "+70633921042"}
0005434654893	D1E943	4178 079272	ILYA NIKITIN	{"phone": "+70367563066"}
0005434654894	F8EED3	9442 564437	YURIY ZAKHAROV	{"phone": "+70802620973"}
0005434654895	0A02BC	6657 313520	YURIY GUSEV	{"email": "gusevyuriy_02071981@postgrespro.ru", "phone": "+70591254791"}
0005434654896	C71ED9	1686 088472	MARAT MOROZOV	{"phone": "+70266112104"}
0005434654897	C71ED9	6690 547190	VLADISLAV MATVEEV	{"phone": "+70270791508"}
0005434654898	A443B9	6437 723927	SERGEY ZHUKOV	{"email": "zhukov_s1987@postgrespro.ru", "phone": "+70753949541"}
0005434654899	FC3B8D	9098 519238	IRAIDA VASILEVA	{"email": "vasileva-i-17061973@postgrespro.ru", "phone": "+70534698754"}
0005434654900	C52227	7721 308461	VALERIY DAVYDOV	{"email": "v-davydov1977@postgrespro.ru", "phone": "+70661331776"}
0005434654901	10C007	8986 947916	TATYANA KRASNOVA	{"phone": "+70034782311"}
0005434654902	4C6DA6	3537 683121	VASILIY EGOROV	{"email": "vasiliyegorov_081968@postgrespro.ru", "phone": "+70136612141"}
0005434654903	8CD0EC	0886 187611	ELENA NAUMOVA	{"phone": "+70750403682"}
0005434654904	8CD0EC	8974 864396	LYUDMILA FEDOROVA	{"phone": "+70063545944"}
0005434654905	E78C52	4520 172096	MARIYA KUZNECOVA	{"email": "kuznecova_mariya_031978@postgrespro.ru", "phone": "+70517675320"}
0005434654906	8532AC	8522 231091	ALEKSEY SOKOLOV	{"email": "a-sokolov23081979@postgrespro.ru", "phone": "+70337694857"}
0005434654907	12C048	8724 077965	DARYA LAZAREVA	{"phone": "+70945550350"}
0005434654908	183E13	6555 977439	RAFAEL VOLKOV	{"phone": "+70277089160"}
0005434654909	28631E	3319 668485	GYUZEL DENISOVA	{"email": "denisova_g.18101976@postgrespro.ru", "phone": "+70813425321"}
0005434654910	13472B	2551 159866	ELENA PETROVA	{"phone": "+70503651503"}
0005434654911	5F1D10	7220 700799	GALINA TIKHONOVA	{"email": "g.tikhonova1977@postgrespro.ru", "phone": "+70517860858"}
0005434654912	5F1D10	0077 655557	SERGEY FOMIN	{"phone": "+70379110669"}
0005434654913	E04690	7726 163642	MARIYA LUKYANOVA	{"email": "mariya.lukyanova-10101961@postgrespro.ru", "phone": "+70757111070"}
0005434654914	D31D9A	3158 246549	DMITRIY MELNIKOV	{"phone": "+70062884280"}
0005434654915	08454E	3238 800451	ARINA GRISHINA	{"email": "grishina_arina061978@postgrespro.ru", "phone": "+70482813973"}
0005434654917	F44683	7098 220831	VLADIMIR FROLOV	{"email": "frolov-v.1978@postgrespro.ru", "phone": "+70051151154"}
0005434654918	F44683	0215 268208	REGINA ZHUKOVA	{"phone": "+70061845920"}
0005434654919	93B213	0267 959148	FEDOR GRIGOREV	{"email": "grigorev.f_121974@postgrespro.ru", "phone": "+70328832551"}
0005434654920	5D55B5	0002 021015	FARIDA KUZNECOVA	{"phone": "+70753208642"}
0005434654921	5D55B5	6404 992204	ALEKSANDR SERGEEV	{"phone": "+70759085658"}
0005434654922	5C9AEE	8991 517770	NINA GRISHINA	{"phone": "+70856297702"}
0005434654923	36073B	3933 015376	VALERIYA OVCHINNIKOVA	{"phone": "+70018710768"}
0005434654924	36073B	1077 137381	IVAN SAVELEV	{"email": "ivansavelev.12121964@postgrespro.ru", "phone": "+70491876849"}
0005434654925	F164B3	2836 423634	PETR ANTONOV	{"phone": "+70031644931"}
0005434654926	F164B3	8174 687082	OLESYA FEDOROVA	{"phone": "+70576071987"}
0005434654927	92339F	8150 834918	EVGENIY NOVIKOV	{"email": "novikove_021970@postgrespro.ru", "phone": "+70932904343"}
0005434654928	F62E3A	0904 077159	ELENA IVANOVA	{"email": "elena-ivanova_1977@postgrespro.ru", "phone": "+70442594047"}
0005434654929	F0CF64	6616 592035	MIKHAIL MAKAROV	{"phone": "+70055676333"}
0005434654930	14B902	4301 963403	ALEKSEY ISAEV	{"email": "a.isaev.1965@postgrespro.ru", "phone": "+70871786905"}
0005434654931	AFC175	4791 003782	VADIM NAZAROV	{"phone": "+70337749852"}
0005434654932	AFC175	9443 783278	RAFAIL STEPANOV	{"email": "stepanov_r_121969@postgrespro.ru", "phone": "+70894944392"}
0005434654933	7FCE7A	9537 335058	NATALYA ALEKSEEVA	{"email": "n_alekseeva03031973@postgrespro.ru", "phone": "+70388532312"}
0005434654934	7FCE7A	7303 329262	VLADIMIR VOROBEV	{"phone": "+70386856061"}
0005434654935	DD9B25	8039 025495	LYUBOV IVANOVA	{"email": "ivanova_lyubov_12091979@postgrespro.ru", "phone": "+70740208600"}
0005434654936	7E35DE	8696 814825	NADEZHDA MIKHAYLOVA	{"phone": "+70084209342"}
0005434654937	AF91AB	9733 495765	SERGEY ZAYCEV	{"email": "zaycev.sergey_1968@postgrespro.ru", "phone": "+70377920847"}
0005434654938	C4280E	7864 955508	IVAN KAZAKOV	{"email": "i-kazakov25121976@postgrespro.ru", "phone": "+70318317225"}
0005434654939	F536B2	3945 432249	ANDREY YAKOVLEV	{"phone": "+70197114690"}
0005434654940	A3FC54	2001 625466	MARIYA MAKAROVA	{"email": "makarova-m-01011975@postgrespro.ru", "phone": "+70799389156"}
0005434654941	9B4362	2371 088124	IRINA NIKITINA	{"email": "nikitina_i_1972@postgrespro.ru", "phone": "+70653775790"}
0005434654942	46D3E6	2428 074413	EDUARD KRASNOV	{"phone": "+70878673608"}
0005434654943	745120	1226 500909	ELENA LEBEDEVA	{"phone": "+70302574089"}
0005434654944	745120	8204 372816	ELENA IVANOVA	{"email": "e.ivanova_121986@postgrespro.ru", "phone": "+70728874164"}
0005434654945	745120	9601 748585	DARINA MASLOVA	{"email": "darina_maslova.14091967@postgrespro.ru", "phone": "+70530539199"}
0005434654946	938331	2466 517642	DENIS KAZAKOV	{"phone": "+70699888344"}
0005434654947	BD83CF	0008 261113	VIKTOR POPOV	{"phone": "+70950229241"}
0005434654948	6DA675	3260 867628	ANASTASIYA MATVEEVA	{"phone": "+70390906842"}
0005434654949	8DF9B9	3073 077717	MARIYA OSIPOVA	{"email": "osipovam081975@postgrespro.ru", "phone": "+70019369497"}
0005434654950	D65996	4209 306456	IRINA IVANOVA	{"email": "ivanova_irina_04021977@postgrespro.ru", "phone": "+70062182227"}
0005434654951	8BB3F1	1569 576000	MARK AFANASEV	{"phone": "+70260425014"}
0005434654952	030366	0718 145099	NADEZHDA BARANOVA	{"phone": "+70092977122"}
0005434654953	030366	2500 789527	SERGEY SAVELEV	{"phone": "+70225509905"}
0005434654954	48E66E	0863 807490	PETR ABRAMOV	{"phone": "+70422688092"}
0005434654955	48E66E	1209 832177	NATALYA FADEEVA	{"phone": "+70617781785"}
0005434654956	685DC0	3631 419027	VLADIMIR ROMANOV	{"email": "vladimir.romanov19121971@postgrespro.ru", "phone": "+70330223382"}
0005434654957	F913A2	7115 131057	LIDIYA PETROVA	{"phone": "+70047924705"}
0005434654958	34C0E5	6046 169045	NINA EGOROVA	{"email": "egorova-n_1979@postgrespro.ru", "phone": "+70592434010"}
0005434654959	5E0562	2702 550633	RAISA MAKAROVA	{"email": "r_makarova_1970@postgrespro.ru", "phone": "+70511433586"}
0005434654960	810504	0719 419545	ALEKSANDR ZAKHAROV	{"phone": "+70815043085"}
0005434654961	810504	1669 966990	IRINA SOROKINA	{"email": "irina.sorokina121970@postgrespro.ru", "phone": "+70681840566"}
0005434654962	73CF07	7473 342229	ARTEM DAVYDOV	{"phone": "+70359117979"}
0005434654963	2BFCD6	6232 203819	IRINA CHERNOVA	{"email": "irina.chernova_071969@postgrespro.ru", "phone": "+70993026364"}
0005434654964	A6D0D1	3546 205354	OKSANA IVANOVA	{"phone": "+70296086258"}
0005434654965	41F632	3492 882146	SERGEY KAZAKOV	{"email": "kazakov_sergey_061967@postgrespro.ru", "phone": "+70574306293"}
0005434654966	853499	6656 349599	GALINA MASLOVA	{"phone": "+70999117865"}
0005434654967	853499	6527 838906	IVAN TARASOV	{"phone": "+70392567440"}
0005434654968	853499	7722 944722	VALERIY SEMENOV	{"email": "valeriysemenov02091966@postgrespro.ru", "phone": "+70322001954"}
0005434654969	399B3D	3949 454246	ELENA ARKHIPOVA	{"email": "arkhipova_elena-1975@postgrespro.ru", "phone": "+70614307850"}
0005434654970	9F6AA7	3124 371846	BORIS ZHUKOV	{"phone": "+70594270143"}
0005434654971	A02AC4	4191 318687	EKATERINA SCHERBAKOVA	{"email": "scherbakova-e_10111957@postgrespro.ru", "phone": "+70204371316"}
0005434654972	A02AC4	8245 751442	SVETLANA BELYAEVA	{"phone": "+70920588337"}
0005434654973	DFE39E	3117 117747	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr_14071967@postgrespro.ru", "phone": "+70861863525"}
0005434654975	661863	6567 004256	ANATOLIY OSIPOV	{"email": "osipova_1976@postgrespro.ru", "phone": "+70289800795"}
0005434654976	F6D8FD	4700 438388	GENNADIY FEDOROV	{"phone": "+70548562330"}
0005434654977	CEC3CB	5221 714998	OLESYA SOLOVEVA	{"email": "olesyasoloveva-021963@postgrespro.ru", "phone": "+70735178476"}
0005434654978	369942	4379 366466	TATYANA PETROVA	{"phone": "+70515949202"}
0005434654979	9B4B37	1792 138371	ALEKSEY NAZAROV	{"phone": "+70629255133"}
0005434654980	9B4B37	4016 743027	EVGENIY IVANOV	{"email": "e.ivanov-1981@postgrespro.ru", "phone": "+70363251664"}
0005434654981	64484E	1355 334791	ALEKSEY TIMOFEEV	{"email": "timofeev.a.25101980@postgrespro.ru", "phone": "+70821098438"}
0005434654982	5CCFF1	5259 771868	KRISTINA BARANOVA	{"phone": "+70375083832"}
0005434654983	480DFA	1553 924372	VASILIY BONDARENKO	{"email": "bondarenko.vasiliy-081971@postgrespro.ru", "phone": "+70967599362"}
0005434654984	480DFA	3155 539555	VALERIYA STEPANOVA	{"email": "valeriya_stepanova.25091953@postgrespro.ru", "phone": "+70132877351"}
0005434654985	9E9392	2114 104357	GRIGORIY NAZAROV	{"phone": "+70940509178"}
0005434654986	C80F5A	8317 180548	SERGEY VOLKOV	{"email": "volkovsergey25021967@postgrespro.ru", "phone": "+70518473968"}
0005434654987	C80F5A	6084 286416	SERGEY POPOV	{"email": "s-popov.1971@postgrespro.ru", "phone": "+70997835370"}
0005434654988	AE51CC	1324 109149	KONSTANTIN ROMANOV	{"phone": "+70096635880"}
0005434654989	B5F45D	0927 035355	VERA KULIKOVA	{"email": "vera_kulikova.1970@postgrespro.ru", "phone": "+70140530641"}
0005434654990	12AD72	7761 202863	GALINA FEDOROVA	{"phone": "+70612385801"}
0005434654991	A2271B	2505 010889	ANNA KUZNECOVA	{"phone": "+70607373173"}
0005434654992	9F14AA	7008 263845	ANTON ORLOV	{"phone": "+70948097418"}
0005434654993	1CCCDF	2017 693497	RIMMA IVANOVA	{"phone": "+70358398736"}
0005434654994	1CCCDF	7571 432536	YURIY NIKOLAEV	{"email": "nikolaev_yuriy_1967@postgrespro.ru", "phone": "+70547424462"}
0005434654995	E03920	4782 262205	GLEB ANTONOV	{"email": "g.antonov-1973@postgrespro.ru", "phone": "+70261634528"}
0005434654996	839483	3926 281552	YANA KUZNECOVA	{"email": "kuznecova_yana-02081977@postgrespro.ru", "phone": "+70238565724"}
0005434654997	839483	8109 389015	ANTONINA MIKHAYLOVA	{"email": "mikhaylova-a.1979@postgrespro.ru", "phone": "+70914829174"}
0005434654998	9A1C32	8568 067739	ALEKSEY KUDRYASHOV	{"email": "kudryashovaleksey.03041962@postgrespro.ru", "phone": "+70679388770"}
0005434654999	9A1C32	2889 914701	VALENTINA SEMENOVA	{"phone": "+70106331270"}
0005434655000	02AF77	1567 696229	ARKADIY BELOV	{"email": "arkadiy.belov-091970@postgrespro.ru", "phone": "+70697491316"}
0005434655001	02AF77	9773 770052	NATALIYA SCHERBAKOVA	{"phone": "+70966115603"}
0005434655002	52F1BD	3361 672412	DMITRIY ORLOV	{"phone": "+70873619063"}
0005434655003	5578D7	6176 061376	TATYANA ARKHIPOVA	{"phone": "+70560420476"}
0005434655004	E7AF5A	1312 619573	LILIYA YAKOVLEVA	{"phone": "+70640867246"}
0005434655005	FF986D	2246 344885	YURIY MAKAROV	{"phone": "+70003538098"}
0005434655006	9E9658	1229 076900	VALENTINA EFIMOVA	{"email": "efimovav-03061955@postgrespro.ru", "phone": "+70453351139"}
0005434655007	9E9658	3600 803751	ANASTASIYA KOVALEVA	{"email": "anastasiya.kovaleva.1976@postgrespro.ru", "phone": "+70882583348"}
0005434655008	1F139C	1688 495602	ANNA EGOROVA	{"email": "egorovaanna05121967@postgrespro.ru", "phone": "+70379687101"}
0005434655009	F835D9	2768 845226	OLGA TITOVA	{"phone": "+70487312160"}
0005434655010	E6A356	5834 796663	YANA YAKOVLEVA	{"phone": "+70502151990"}
0005434655011	7476C2	6416 606460	ANDREY BORISOV	{"phone": "+70731514978"}
0005434655012	7476C2	9928 379719	OLGA ALEKSANDROVA	{"phone": "+70103268701"}
0005434655013	7476C2	7069 338965	ELENA MIRONOVA	{"email": "mironova-elena.051963@postgrespro.ru", "phone": "+70753800861"}
0005434655014	6CEB69	8888 055878	IRINA OSIPOVA	{"phone": "+70971391493"}
0005434655015	6CEB69	5464 421596	YURIY SMIRNOV	{"phone": "+70927198982"}
0005434655016	C304DA	6851 912881	DANIIL SERGEEV	{"phone": "+70574493945"}
0005434655017	C304DA	4340 233147	EVELINA KONOVALOVA	{"email": "evelina.konovalova1967@postgrespro.ru", "phone": "+70259084482"}
0005434655018	40B2DD	6112 030338	IVAN CHERNOV	{"email": "i_chernov-30061970@postgrespro.ru", "phone": "+70213464848"}
0005434655019	510D4A	3336 732725	YURIY YAKOVLEV	{"phone": "+70297251125"}
0005434655020	8B226D	5180 260315	MARIYA FILIPPOVA	{"email": "filippovam.111970@postgrespro.ru", "phone": "+70514684412"}
0005434655021	01613F	4162 470868	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy091972@postgrespro.ru", "phone": "+70045417944"}
0005434655022	FAB18A	3788 148882	MAKSIM BONDARENKO	{"phone": "+70268736299"}
0005434655023	FAB18A	0905 595653	ALEKSANDRA DMITRIEVA	{"phone": "+70659101403"}
0005434655024	A8F913	2528 428306	NINA TIMOFEEVA	{"email": "nina-timofeeva_021965@postgrespro.ru", "phone": "+70230459710"}
0005434655025	985DB8	8050 034872	RAMILYA BELOVA	{"phone": "+70560818920"}
0005434655026	752CB0	2305 494895	IRINA SMIRNOVA	{"email": "smirnova_irina23081965@postgrespro.ru", "phone": "+70340976741"}
0005434655027	C3D467	7437 122219	MIKHAIL KUZMIN	{"email": "kuzmin_mikhail1968@postgrespro.ru", "phone": "+70910880913"}
0005434655028	C3D467	5675 836411	ARTEM MELNIKOV	{"email": "artem-melnikov.06111979@postgrespro.ru", "phone": "+70605889859"}
0005434655029	CAE2A8	3802 456231	ALEKSEY BELOV	{"email": "aleksey-belov_01021962@postgrespro.ru", "phone": "+70654514511"}
0005434655030	CAE2A8	5630 675020	OLGA KOVALEVA	{"email": "kovalevaolga121967@postgrespro.ru", "phone": "+70041889118"}
0005434655031	CAE2A8	7030 064298	NINA SCHERBAKOVA	{"email": "n_scherbakova.26101984@postgrespro.ru", "phone": "+70681211682"}
0005434655032	FCA58E	1063 738219	OLEG YAKOVLEV	{"phone": "+70699039957"}
0005434655033	239801	6879 723781	SERGEY AFANASEV	{"email": "afanasev-sergey-03111975@postgrespro.ru", "phone": "+70470345126"}
0005434655034	2C1233	2748 492267	YULIYA MAKAROVA	{"phone": "+70985920688"}
0005434655035	10032B	2579 253796	SERGEY KUZNECOV	{"email": "kuznecov-sergey.061967@postgrespro.ru", "phone": "+70306836065"}
0005434655036	68527D	2556 643460	VENIAMIN MIRONOV	{"email": "veniamin.mironov-1987@postgrespro.ru", "phone": "+70305074218"}
0005434655037	68527D	8109 117222	VITALIY NOVIKOV	{"email": "novikovv.1974@postgrespro.ru", "phone": "+70624913169"}
0005434655038	C79E67	8128 328992	YURIY ISAEV	{"email": "isaev.y-1978@postgrespro.ru", "phone": "+70437437043"}
0005434655039	9DC85E	1035 574144	LYUBOV ZOTOVA	{"email": "zotoval.071967@postgrespro.ru", "phone": "+70608481753"}
0005434655040	9DC85E	3486 958357	ANASTASIYA KONDRATEVA	{"phone": "+70072174185"}
0005434655041	D18EE5	0578 213691	YULIYA ROMANOVA	{"phone": "+70108677696"}
0005434655042	2A6CFC	5499 945967	KRISTINA PETROVA	{"phone": "+70105102293"}
0005434655043	409B62	3038 028686	ALENA SAVELEVA	{"phone": "+70364994952"}
0005434655044	016310	5746 820242	ALEKSANDRA KOROLEVA	{"email": "koroleva_a-031961@postgrespro.ru", "phone": "+70913167401"}
0005434655045	3FC181	1037 117591	TATYANA EGOROVA	{"phone": "+70960894339"}
0005434655046	8394DB	7705 447048	VLADIMIR SIDOROV	{"phone": "+70393198751"}
0005434655047	8394DB	7559 764969	ALEKSEY FOMIN	{"phone": "+70250954162"}
0005434655048	79E41F	2208 690741	ALEKSEY VLASOV	{"phone": "+70586571581"}
0005434655049	79E41F	2127 544273	RAISA MAKAROVA	{"email": "rmakarova-031983@postgrespro.ru", "phone": "+70776005339"}
0005434655050	8295B3	5057 013099	MAKSIM PAVLOV	{"phone": "+70881078673"}
0005434655051	4CF2ED	8960 418458	TATYANA ROMANOVA	{"email": "romanova-t.011975@postgrespro.ru", "phone": "+70521975023"}
0005434655052	C1874D	8947 761847	LYUDMILA DENISOVA	{"email": "lyudmila_denisova.111966@postgrespro.ru", "phone": "+70050509089"}
0005434655053	C1874D	5145 481762	ANDREY KULIKOV	{"email": "andrey_kulikov_1991@postgrespro.ru", "phone": "+70581155486"}
0005434655054	E71602	8168 917801	SVETLANA ANDREEVA	{"email": "andreevas1972@postgrespro.ru", "phone": "+70027513652"}
0005434655055	E71602	6379 056154	SVETLANA NAZAROVA	{"email": "nazarova_svetlana-10031975@postgrespro.ru", "phone": "+70542896273"}
0005434655056	B9BEB3	3745 318285	VLADIMIR FEDOROV	{"email": "fedorov-vladimir.1974@postgrespro.ru", "phone": "+70507719164"}
0005434655057	C1B857	8514 357304	YULIYA MELNIKOVA	{"email": "melnikova_yuliya16021987@postgrespro.ru", "phone": "+70719296633"}
0005434655058	362553	6261 855400	ANASTASIYA MATVEEVA	{"phone": "+70167894218"}
0005434655059	CD68F6	7252 141430	IVAN FILIPPOV	{"email": "i_filippov.19031963@postgrespro.ru", "phone": "+70576246073"}
0005434655060	CD68F6	0456 026916	STANISLAV VOROBEV	{"phone": "+70638885348"}
0005434655061	3FA477	2217 491756	TATYANA YUDINA	{"phone": "+70771424290"}
0005434655062	FA0091	2056 239919	TAMARA LEBEDEVA	{"email": "t_lebedeva05111973@postgrespro.ru", "phone": "+70539391770"}
0005434655063	7CE464	6623 852066	MILANA DMITRIEVA	{"email": "m.dmitrieva.101965@postgrespro.ru", "phone": "+70753866921"}
0005434655064	D2DB79	7144 603702	ALEKSANDRA VOLKOVA	{"phone": "+70398118796"}
0005434655065	D2DB79	6775 545501	DAMIR GRIGOREV	{"email": "d_grigorev1959@postgrespro.ru", "phone": "+70080303924"}
0005434655066	3ECB7C	6772 718126	ELENA KULIKOVA	{"phone": "+70940779687"}
0005434655067	C1A807	7696 739485	ANNA FROLOVA	{"phone": "+70500631606"}
0005434655068	C1A807	3737 159876	SERGEY SERGEEV	{"phone": "+70003140128"}
0005434655069	C1A807	0064 385508	SERGEY GORBUNOV	{"phone": "+70905370834"}
0005434655070	F48787	7094 783039	ANTON IVANOV	{"email": "antonivanov_041974@postgrespro.ru", "phone": "+70639355616"}
0005434655071	1F50C9	8967 598271	ANASTASIYA KOROLEVA	{"phone": "+70593240776"}
0005434655072	11A12E	1387 854225	EKATERINA BARANOVA	{"email": "baranova-e_02031973@postgrespro.ru", "phone": "+70141203024"}
0005434655073	11A12E	5108 290268	SVETLANA AKIMOVA	{"phone": "+70939972059"}
0005434655074	A1C8A4	5999 427767	LYUDMILA POTAPOVA	{"email": "l-potapova_12051976@postgrespro.ru", "phone": "+70227192569"}
0005434655075	528C49	3904 732330	VALERIY PETROV	{"email": "petrovv-17041981@postgrespro.ru", "phone": "+70301060422"}
0005434655076	E78CB3	0960 850064	LYUDMILA KONOVALOVA	{"email": "lyudmila-konovalova.1974@postgrespro.ru", "phone": "+70257978471"}
0005434655077	01247F	1814 653410	FEDOR NAZAROV	{"email": "fnazarov-07051971@postgrespro.ru", "phone": "+70854698020"}
0005434655251	7FB801	7045 082748	VERONIKA SCHERBAKOVA	{"phone": "+70392315429"}
0005434655078	DF2BE3	2193 608314	VIKTORIYA ALEKSANDROVA	{"email": "viktoriya.aleksandrova_051970@postgrespro.ru", "phone": "+70034331638"}
0005434655079	DF2BE3	5296 509965	ROZA VASILEVA	{"email": "r.vasileva-1971@postgrespro.ru", "phone": "+70552364274"}
0005434655080	69B799	6504 092211	IRINA LOGINOVA	{"email": "loginova.irina.1981@postgrespro.ru", "phone": "+70868921747"}
0005434655081	69B799	6041 528752	TATYANA AKIMOVA	{"phone": "+70444935155"}
0005434655082	963E66	2275 949994	LIDIYA DANILOVA	{"email": "ldanilova.1967@postgrespro.ru", "phone": "+70517318678"}
0005434655083	918CDE	3705 827710	ALENA EGOROVA	{"phone": "+70612393669"}
0005434655084	2765E0	2115 460394	ARTUR PAVLOV	{"email": "pavlova_12071961@postgrespro.ru", "phone": "+70171369033"}
0005434655085	2765E0	3664 425647	OLESYA KOVALEVA	{"email": "olesyakovaleva_02101982@postgrespro.ru", "phone": "+70057285073"}
0005434655086	34B9AD	8738 738520	OLGA PETROVA	{"email": "petrova.olga.1969@postgrespro.ru", "phone": "+70552828077"}
0005434655087	34B9AD	5240 285261	MARIYA ALEKSANDROVA	{"email": "mariya_aleksandrova_22041970@postgrespro.ru", "phone": "+70324256016"}
0005434655088	51CAD4	7450 272963	MIROSLAV MARTYNOV	{"email": "m_martynov-06011967@postgrespro.ru", "phone": "+70072204857"}
0005434655089	E907F8	7570 700676	IRINA OSIPOVA	{"email": "osipovairina1970@postgrespro.ru", "phone": "+70632056548"}
0005434655090	E907F8	9644 701216	PAVEL NIKOLAEV	{"email": "nikolaev.pavel1981@postgrespro.ru", "phone": "+70953648454"}
0005434655091	4B0DCA	4267 485980	ULYANA DANILOVA	{"email": "u_danilova1960@postgrespro.ru", "phone": "+70726911535"}
0005434655092	7A8838	0273 146584	VALENTINA STEPANOVA	{"email": "stepanova_v13031965@postgrespro.ru", "phone": "+70187024139"}
0005434655093	7A8838	3880 859480	ELIZAVETA VOLKOVA	{"email": "e_volkova-1971@postgrespro.ru", "phone": "+70468285975"}
0005434655094	D4E899	4748 519382	ANGELINA ABRAMOVA	{"email": "angelinaabramova-1963@postgrespro.ru", "phone": "+70111032222"}
0005434655095	D4E899	4809 475016	LIDIYA NOVIKOVA	{"email": "lidiyanovikova_041980@postgrespro.ru", "phone": "+70057037078"}
0005434655096	D4E899	0583 875386	ELENA BELOVA	{"phone": "+70103736444"}
0005434655097	86D611	0598 063716	GALINA PETROVA	{"phone": "+70830365225"}
0005434655098	86D611	1064 196401	ZINAIDA SOROKINA	{"email": "zinaida_sorokina-24111971@postgrespro.ru", "phone": "+70775051583"}
0005434655099	A8A2EC	5492 430052	ANNA KONDRATEVA	{"phone": "+70419181107"}
0005434655100	47F6DB	4497 985636	VIKTOR FILIPPOV	{"email": "viktorfilippov-24121970@postgrespro.ru", "phone": "+70921964956"}
0005434655101	47F6DB	3658 426067	IGOR AFANASEV	{"email": "i-afanasev1961@postgrespro.ru", "phone": "+70387944993"}
0005434655102	D1F68E	1024 321660	VALERIY POPOV	{"phone": "+70872965518"}
0005434655103	D1F68E	6940 715052	MARINA TARASOVA	{"phone": "+70997044511"}
0005434655104	1F03D1	1836 993480	VALERIY DMITRIEV	{"email": "v.dmitriev-1963@postgrespro.ru", "phone": "+70606374290"}
0005434655105	1F03D1	1631 493032	VALENTINA BOGDANOVA	{"email": "bogdanova_valentina-1972@postgrespro.ru", "phone": "+70782448930"}
0005434655106	9DB4BE	3974 689230	SERGEY OSIPOV	{"email": "osipov.sergey_031977@postgrespro.ru", "phone": "+70510554133"}
0005434655107	9DB4BE	0435 024624	VLADIMIR NOVIKOV	{"email": "v.novikov-06031981@postgrespro.ru", "phone": "+70089141948"}
0005434655108	A5A30A	2939 615374	PETR VOROBEV	{"email": "vorobev.petr.1969@postgrespro.ru", "phone": "+70216682761"}
0005434655109	3957D1	5999 566995	DAMIR KUZMIN	{"phone": "+70521288454"}
0005434655110	3957D1	3814 858457	ZINAIDA TITOVA	{"phone": "+70044446009"}
0005434655111	7A560A	6040 720845	ELENA ROMANOVA	{"email": "romanovaelena.1968@postgrespro.ru", "phone": "+70628136614"}
0005434655112	7A560A	3878 399885	TAMARA KUZNECOVA	{"email": "kuznecova_t_29041971@postgrespro.ru", "phone": "+70013250830"}
0005434655113	B8E321	8011 469953	ANNA KOMAROVA	{"phone": "+70154927144"}
0005434655114	555319	3703 442522	ALEKSANDR KAZAKOV	{"email": "kazakova_1966@postgrespro.ru", "phone": "+70119096556"}
0005434655115	C451A8	3849 764128	IVAN MELNIKOV	{"email": "ivan-melnikov_1979@postgrespro.ru", "phone": "+70390267977"}
0005434655116	C3F838	2643 463350	YURIY KAZAKOV	{"phone": "+70095880572"}
0005434655117	3677ED	7476 380348	SERGEY FEDOTOV	{"email": "s_fedotov-27111975@postgrespro.ru", "phone": "+70543891103"}
0005434655118	3677ED	5925 594316	NADEZHDA BARANOVA	{"email": "baranova.nadezhda.1972@postgrespro.ru", "phone": "+70850723220"}
0005434655119	911A59	0100 155678	NATALYA NOVIKOVA	{"phone": "+70403608618"}
0005434655120	911A59	9821 513522	NIKOLAY IVANOV	{"phone": "+70050555043"}
0005434655121	331170	6484 240298	VLADIMIR IVANOV	{"phone": "+70107260992"}
0005434655122	D335A3	7470 322167	MARINA SOROKINA	{"phone": "+70583421576"}
0005434655123	80B68C	2686 770408	SERGEY ALEKSANDROV	{"phone": "+70403773840"}
0005434655124	80B68C	9153 754744	ROMAN KUZMIN	{"phone": "+70423624263"}
0005434655125	AD58FE	0898 922744	SERGEY KONOVALOV	{"phone": "+70826555912"}
0005434655126	225FF8	3213 451166	MAKSIM GUSEV	{"email": "m.gusev-121969@postgrespro.ru", "phone": "+70712943384"}
0005434655127	225FF8	0805 027294	DARYA IVANOVA	{"email": "daryaivanova1977@postgrespro.ru", "phone": "+70327475448"}
0005434655128	61F2DC	0505 372758	ALEKSEY NIKOLAEV	{"email": "aleksey-nikolaev_09111977@postgrespro.ru", "phone": "+70054359696"}
0005434655129	61F2DC	3734 567093	BORIS FROLOV	{"email": "frolov-boris.1971@postgrespro.ru", "phone": "+70484278237"}
0005434655130	A16AEA	0805 554540	SERGEY STEPANOV	{"phone": "+70509064636"}
0005434655131	2FBCC4	3652 577495	VIKTOR IVANOV	{"phone": "+70019438135"}
0005434655132	2FBCC4	5769 636249	YURIY ZAKHAROV	{"email": "zakharov_yuriy_19071972@postgrespro.ru", "phone": "+70783939010"}
0005434655133	2B1F9A	7034 936765	ANDREY FOMIN	{"phone": "+70941136638"}
0005434655134	3D1AEF	0723 017971	TIMOFEY NIKITIN	{"email": "nikitin_t_1985@postgrespro.ru", "phone": "+70187500465"}
0005434655135	3D1AEF	4834 478591	ANNA KUZMINA	{"email": "anna-kuzmina25111979@postgrespro.ru", "phone": "+70891010306"}
0005434655136	3D1AEF	8179 341272	DMITRIY KARPOV	{"email": "d-karpov.061978@postgrespro.ru", "phone": "+70268188535"}
0005434655137	3D1AEF	8601 129990	IVAN SEMENOV	{"email": "ivan.semenov_1981@postgrespro.ru", "phone": "+70643185151"}
0005434655138	DCDC2B	7330 082918	OKSANA POPOVA	{"email": "oksanapopova041979@postgrespro.ru", "phone": "+70265124107"}
0005434655139	A49D46	8470 795214	ELENA NAZAROVA	{"phone": "+70935558784"}
0005434655140	A49D46	9858 859105	OLGA BORISOVA	{"phone": "+70664459277"}
0005434655141	80D11E	6391 716616	GALINA MOISEEVA	{"email": "moiseeva_g1962@postgrespro.ru", "phone": "+70052030718"}
0005434655142	D16CA6	8404 327795	SVETLANA MIRONOVA	{"email": "smironova-061962@postgrespro.ru", "phone": "+70843337781"}
0005434655143	D16CA6	2643 819131	EVGENIY SCHERBAKOV	{"phone": "+70185911461"}
0005434655144	663637	8700 752134	VLADIMIR ISAEV	{"email": "isaevvladimir041962@postgrespro.ru", "phone": "+70596259018"}
0005434655145	A5C125	7029 732865	VIKTOR GUSEV	{"email": "viktor_gusev-08051967@postgrespro.ru", "phone": "+70758264031"}
0005434655146	AF858B	9068 180346	DARYA MEDVEDEVA	{"email": "medvedeva_d.1975@postgrespro.ru", "phone": "+70318557025"}
0005434655147	AF858B	0385 473965	MILANA LEBEDEVA	{"phone": "+70777925905"}
0005434655148	CFA660	7644 309508	LYUBOV ZHUKOVA	{"email": "zhukova.lyubov-15101976@postgrespro.ru", "phone": "+70176149149"}
0005434655149	CFA660	6928 978280	ALLA SERGEEVA	{"phone": "+70765901324"}
0005434655150	551A3A	7714 340085	TAGIR ANTONOV	{"phone": "+70074492320"}
0005434655151	A8E9CE	1022 348987	DENIS MEDVEDEV	{"email": "denismedvedev_09081965@postgrespro.ru", "phone": "+70549893505"}
0005434655152	A8E9CE	0845 574077	ANTONINA MALYSHEVA	{"email": "malyshevaantonina1984@postgrespro.ru", "phone": "+70737030711"}
0005434655153	A7809A	9092 344214	SVETLANA POPOVA	{"email": "popovasvetlana.1975@postgrespro.ru", "phone": "+70242607038"}
0005434655154	F411E1	5459 185900	NINA ZAKHAROVA	{"email": "ninazakharova-051977@postgrespro.ru", "phone": "+70102079924"}
0005434655155	EEB9DD	1784 450698	VIKTOR POPOV	{"email": "viktorpopov_07121970@postgrespro.ru", "phone": "+70547509124"}
0005434655156	EEB9DD	8597 801136	SVETLANA SERGEEVA	{"phone": "+70257957064"}
0005434655157	42B7F1	9970 607890	GALINA MIRONOVA	{"email": "g.mironova121976@postgrespro.ru", "phone": "+70692525491"}
0005434655158	E47328	1867 691535	VIKTOR TARASOV	{"email": "tarasov-v.05061970@postgrespro.ru", "phone": "+70703602128"}
0005434655159	ECF3AF	1494 390946	IRAIDA MATVEEVA	{"phone": "+70812833582"}
0005434655160	ECF3AF	4063 448807	ALEKSANDR POPOV	{"email": "popov-a.101973@postgrespro.ru", "phone": "+70068428501"}
0005434655161	749DCA	1644 417213	YAROSLAV PETROV	{"phone": "+70268841965"}
0005434655162	CFFF84	8974 644305	LIDIYA RYABOVA	{"email": "l.ryabova-051980@postgrespro.ru", "phone": "+70233748739"}
0005434655163	CFFF84	7399 385616	TATYANA PETROVA	{"email": "t.petrova.29091967@postgrespro.ru", "phone": "+70429958598"}
0005434655164	2B7D29	8511 148561	LYUDMILA OSIPOVA	{"email": "lyudmila-osipova.25041967@postgrespro.ru", "phone": "+70257931150"}
0005434655165	756C8C	4308 230809	RAMIL DENISOV	{"email": "denisov_ramil_061979@postgrespro.ru", "phone": "+70494728854"}
0005434655166	756C8C	0134 129575	VLADIMIR AFANASEV	{"email": "vladimirafanasev.19021963@postgrespro.ru", "phone": "+70270302307"}
0005434655167	5373DB	8483 281177	IRINA KONOVALOVA	{"email": "konovalova.irina1966@postgrespro.ru", "phone": "+70851548744"}
0005434655168	D57AC5	6106 117029	NIKOLAY ROMANOV	{"email": "n_romanov.21111972@postgrespro.ru", "phone": "+70109556361"}
0005434655169	C51942	3750 842458	LYUDMILA AKIMOVA	{"phone": "+70454177997"}
0005434655170	9032F3	3553 588058	KONSTANTIN GAVRILOV	{"email": "gavrilov_konstantin_1958@postgrespro.ru", "phone": "+70637252561"}
0005434655171	9032F3	6706 728482	MARINA ANISIMOVA	{"phone": "+70636321015"}
0005434655172	E638CE	5990 426775	DMITRIY IVANOV	{"email": "divanov_26121967@postgrespro.ru", "phone": "+70708745841"}
0005434655173	D5E32F	4489 542709	NIKOLAY PAVLOV	{"email": "pavlov_nikolay_101969@postgrespro.ru", "phone": "+70917512035"}
0005434655174	CB4C5B	0325 139928	PAVEL KOROLEV	{"phone": "+70549817788"}
0005434655175	48FC0B	6105 639692	TATYANA MARTYNOVA	{"phone": "+70057072392"}
0005434655176	48FC0B	7245 040640	ELENA BELYAEVA	{"email": "e.belyaeva.25041965@postgrespro.ru", "phone": "+70530513507"}
0005434655177	1829C7	8696 606046	VARVARA DENISOVA	{"email": "v-denisova-22011971@postgrespro.ru", "phone": "+70433205054"}
0005434655178	1829C7	0178 672931	MIKHAIL IVANOV	{"email": "mikhailivanov08061970@postgrespro.ru", "phone": "+70949882283"}
0005434655179	1829C7	6216 637407	OLGA GERASIMOVA	{"email": "gerasimova.o-071983@postgrespro.ru", "phone": "+70762986116"}
0005434655180	BF0904	3516 724000	IVAN SMIRNOV	{"email": "ivan-smirnov.1978@postgrespro.ru", "phone": "+70694388950"}
0005434655181	BF0904	7645 421712	LYUDMILA KOVALEVA	{"email": "lkovaleva.06051966@postgrespro.ru", "phone": "+70511725414"}
0005434655182	C94399	1355 627334	ALEKSANDR KUZMIN	{"email": "a.kuzmin.12051970@postgrespro.ru", "phone": "+70276296856"}
0005434655183	C94399	9044 324729	NADEZHDA FROLOVA	{"email": "n_frolova.071971@postgrespro.ru", "phone": "+70569609040"}
0005434655184	9205C4	7544 712593	SERGEY ZHURAVLEV	{"email": "s_zhuravlev18101973@postgrespro.ru", "phone": "+70571138215"}
0005434655185	9205C4	6091 385943	ROMAN STEPANOV	{"phone": "+70487475976"}
0005434655186	8C6759	4451 647472	NINA ALEKSEEVA	{"email": "alekseeva_nina-031977@postgrespro.ru", "phone": "+70523409840"}
0005434655187	FD3926	9223 341629	OLGA MOROZOVA	{"email": "morozovao061968@postgrespro.ru", "phone": "+70695858295"}
0005434655188	84E1EE	3999 360738	NATALIYA MASLOVA	{"email": "n.maslova.27021964@postgrespro.ru", "phone": "+70916781542"}
0005434655189	D3BE59	6384 857865	VALENTINA RYABOVA	{"email": "ryabova-valentina_18061978@postgrespro.ru", "phone": "+70934202364"}
0005434655190	FF82B3	2398 141289	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr081974@postgrespro.ru", "phone": "+70813272394"}
0005434655191	A65EB9	3734 015512	SERGEY SIDOROV	{"email": "sergey-sidorov-031971@postgrespro.ru", "phone": "+70255009635"}
0005434655192	50E4A9	2941 465683	EKATERINA IVANOVA	{"email": "e.ivanova-1971@postgrespro.ru", "phone": "+70223008352"}
0005434655193	50E4A9	7064 473696	DENIS GERASIMOV	{"phone": "+70105046633"}
0005434655194	59F520	5858 978166	TAMARA DENISOVA	{"phone": "+70636264437"}
0005434655195	59F520	2949 165580	OLGA STEPANOVA	{"email": "stepanovao101964@postgrespro.ru", "phone": "+70857862594"}
0005434655196	033414	8333 107332	LYUDMILA FILIPPOVA	{"email": "filippova_l_091980@postgrespro.ru", "phone": "+70854873008"}
0005434655197	033414	1512 885570	ALEKSANDR MIRONOV	{"phone": "+70597711682"}
0005434655198	D8E210	0543 693008	KIRILL KARPOV	{"email": "karpov_kirill1989@postgrespro.ru", "phone": "+70350004373"}
0005434655199	82F9BE	2089 036070	ANTONINA ROMANOVA	{"email": "a_romanova-051984@postgrespro.ru", "phone": "+70117246448"}
0005434655200	6AB06F	3289 821508	SERGEY ILIN	{"email": "ilinsergey-21021958@postgrespro.ru", "phone": "+70762232301"}
0005434655201	6AB06F	6770 379850	YANA MIKHAYLOVA	{"email": "mikhaylova.y061976@postgrespro.ru", "phone": "+70733057412"}
0005434655202	A38AED	1021 149966	KLAVDIYA MEDVEDEVA	{"email": "medvedeva_klavdiya.1958@postgrespro.ru", "phone": "+70234583791"}
0005434655203	A38AED	9251 589798	ALINA NOVIKOVA	{"email": "alina_novikova.1967@postgrespro.ru", "phone": "+70918734966"}
0005434655204	7C7256	7984 605902	RAISA FOMINA	{"phone": "+70504312361"}
0005434655205	BF4FA4	6816 217183	EKATERINA GRISHINA	{"phone": "+70946088178"}
0005434655206	9A84C9	6132 916146	VITALIY VOLKOV	{"phone": "+70870310136"}
0005434655207	91F89B	7319 790206	EVGENIY MAKSIMOV	{"email": "e-maksimov07011979@postgrespro.ru", "phone": "+70990495938"}
0005434655208	2543B3	8050 408280	ANNA NIKITINA	{"phone": "+70798396512"}
0005434655209	2543B3	2981 189327	KRISTINA LAZAREVA	{"email": "lazareva-kristina-101980@postgrespro.ru", "phone": "+70534609168"}
0005434655210	F9B7C5	0945 607220	NATALYA VLASOVA	{"email": "n.vlasova-26081981@postgrespro.ru", "phone": "+70196448688"}
0005434655211	F9B7C5	2815 308634	ANNA KARPOVA	{"phone": "+70977156006"}
0005434655212	83C59F	4750 012613	TATYANA STEPANOVA	{"phone": "+70723771019"}
0005434655213	4E1F5F	4840 150324	OLGA FROLOVA	{"email": "frolova.olga061990@postgrespro.ru", "phone": "+70066380622"}
0005434655214	BBDEC4	4983 275665	NATALYA NAZAROVA	{"email": "nazarovanatalya_071973@postgrespro.ru", "phone": "+70608772769"}
0005434655215	7FBD7C	8543 322445	MIKHAIL MOROZOV	{"email": "morozov.m011982@postgrespro.ru", "phone": "+70339308499"}
0005434655216	E7444F	3530 021401	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov071977@postgrespro.ru", "phone": "+70525788594"}
0005434655217	C1162E	8384 297619	ALEKSEY SIDOROV	{"email": "sidorov_a_10041975@postgrespro.ru", "phone": "+70665413527"}
0005434655218	DCF1D2	2909 035258	ALEKSANDR ABRAMOV	{"email": "abramov.a.18111967@postgrespro.ru", "phone": "+70183524245"}
0005434655219	DCF1D2	7473 647429	ELENA MOISEEVA	{"phone": "+70805566948"}
0005434655220	6BDE87	8250 943711	YURIY ALEKSANDROV	{"phone": "+70340126178"}
0005434655221	02DB6F	1094 916340	IRINA CHERNOVA	{"phone": "+70805426093"}
0005434655222	069353	6657 004990	SERGEY MARTYNOV	{"phone": "+70155819271"}
0005434655223	442C03	9902 127927	VALENTINA PETROVA	{"phone": "+70007680843"}
0005434655224	BAC3DC	0041 047018	ALEKSANDR BARANOV	{"email": "baranovaleksandr.041976@postgrespro.ru", "phone": "+70340587589"}
0005434655225	BAC3DC	9600 574370	MAKSIM PETROV	{"email": "petrov.m09071979@postgrespro.ru", "phone": "+70511016528"}
0005434655226	733E59	9536 917126	DIANA PETROVA	{"phone": "+70220853242"}
0005434655227	733E59	9008 317801	ANATOLIY ALEKSEEV	{"email": "anatoliy_alekseev1965@postgrespro.ru", "phone": "+70421829659"}
0005434655228	9E22E8	5194 014304	ALEKSEY NIKITIN	{"email": "nikitin-a-10011976@postgrespro.ru", "phone": "+70716657383"}
0005434655229	9E22E8	6489 750554	LYUDMILA SEMENOVA	{"email": "lsemenova-02011976@postgrespro.ru", "phone": "+70267024288"}
0005434655230	70A193	1134 438624	SERGEY RODIONOV	{"phone": "+70173773225"}
0005434655231	70A193	4421 642758	DMITRIY POPOV	{"email": "d_popov1971@postgrespro.ru", "phone": "+70239225818"}
0005434655232	E90B46	2317 965687	VLADIMIR VASILEV	{"phone": "+70450146557"}
0005434655233	E90B46	6678 422162	NADEZHDA ZAYCEVA	{"email": "nadezhda-zayceva.041982@postgrespro.ru", "phone": "+70581026782"}
0005434655234	53B158	2508 521260	MARINA GRISHINA	{"email": "grishina.marina.081970@postgrespro.ru", "phone": "+70862179878"}
0005434655235	53B158	9172 782435	NIKITA FILIPPOV	{"phone": "+70129428098"}
0005434655236	53B158	1649 308121	NIKITA MAKSIMOV	{"phone": "+70093645187"}
0005434655237	4528FA	1410 706688	NIKOLAY GUSEV	{"email": "n.gusev_051977@postgrespro.ru", "phone": "+70046007519"}
0005434655238	4528FA	9449 311522	DMITRIY MAKAROV	{"phone": "+70565453609"}
0005434655239	1216C7	9949 447949	ANASTASIYA KUZMINA	{"email": "kuzmina.anastasiya.111977@postgrespro.ru", "phone": "+70730925343"}
0005434655240	1216C7	6994 997348	YULIYA NOVIKOVA	{"email": "novikovay1984@postgrespro.ru", "phone": "+70030761330"}
0005434655241	862E54	2436 978788	YANA TIMOFEEVA	{"phone": "+70988300147"}
0005434655242	862E54	7796 953903	ALEKSANDR TARASOV	{"email": "a-tarasov_21121972@postgrespro.ru", "phone": "+70339830928"}
0005434655243	E1AB68	8548 683998	SERGEY NIKITIN	{"phone": "+70706646743"}
0005434655244	6ECAE7	3716 882797	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a-10081976@postgrespro.ru", "phone": "+70926675376"}
0005434655245	080538	0953 534608	SVETLANA ALEKSANDROVA	{"phone": "+70924412762"}
0005434655246	BF52E4	4435 362720	ALEKSEY VOROBEV	{"phone": "+70764162805"}
0005434655247	FB043E	3971 458528	NINA FEDOROVA	{"email": "ninafedorova_1970@postgrespro.ru", "phone": "+70711502433"}
0005434655248	FB043E	7380 010445	VALENTINA NIKIFOROVA	{"phone": "+70765611468"}
0005434655249	58A743	8966 154875	DENIS SOKOLOV	{"email": "sokolov-d.091958@postgrespro.ru", "phone": "+70980233677"}
0005434655250	7FB801	3035 470807	EVGENIYA ERMAKOVA	{"phone": "+70097759629"}
0005434655252	4EEB6A	0835 611633	LEONID AFANASEV	{"email": "afanasevl-091979@postgrespro.ru", "phone": "+70986219667"}
0005434655253	7F7AF4	4550 202666	ALEKSEY KISELEV	{"email": "kiselev_aleksey081966@postgrespro.ru", "phone": "+70130688612"}
0005434655254	31DED7	3170 044118	VALERIY KUZMIN	{"phone": "+70963599334"}
0005434655255	31DED7	4215 063958	EKATERINA ROMANOVA	{"phone": "+70841126623"}
0005434655256	31DED7	6349 726106	GALINA KARPOVA	{"email": "g-karpova_1974@postgrespro.ru", "phone": "+70040139654"}
0005434655257	DE95C3	3843 029703	MARIYA POLYAKOVA	{"email": "polyakovamariya.23031973@postgrespro.ru", "phone": "+70922159986"}
0005434655258	AF1192	6382 321316	ANNA NOVIKOVA	{"phone": "+70685576254"}
0005434655259	1E491C	7464 654987	VLADIMIR SOKOLOV	{"phone": "+70183812327"}
0005434655260	CA9553	8232 430911	SERGEY ILIN	{"email": "ilin_sergey-20091975@postgrespro.ru", "phone": "+70486945890"}
0005434655261	37B3A6	6963 705525	TATYANA LOGINOVA	{"email": "tloginova.22021975@postgrespro.ru", "phone": "+70747023195"}
0005434655262	37B3A6	6977 484027	TATYANA SEMENOVA	{"phone": "+70217772799"}
0005434655263	057A4C	2748 235961	KSENIYA KAZAKOVA	{"email": "kseniya_kazakova1977@postgrespro.ru", "phone": "+70876378635"}
0005434655264	C9C7F5	5489 799533	NIKOLAY MATVEEV	{"phone": "+70338237760"}
0005434655265	5A9130	8092 066498	RUSTAM SOROKIN	{"email": "sorokin.rustam_1971@postgrespro.ru", "phone": "+70773284650"}
0005434655266	5A9130	1168 406021	MILANA EGOROVA	{"email": "m_egorova.121975@postgrespro.ru", "phone": "+70838967383"}
0005434655267	5A9130	5749 870619	VLADIMIR GAVRILOV	{"phone": "+70065384159"}
0005434655268	670574	4094 883117	VITALIY MIKHAYLOV	{"phone": "+70729606960"}
0005434655269	670574	4864 411682	NINA MIKHAYLOVA	{"email": "mikhaylova.n-29121968@postgrespro.ru", "phone": "+70868695340"}
0005434655270	5FEBCD	8064 592549	ALEKSANDR ROMANOV	{"phone": "+70995108555"}
0005434655271	05CF2D	5937 968700	VALENTINA SOLOVEVA	{"email": "v.soloveva.24081968@postgrespro.ru", "phone": "+70846514916"}
0005434655272	2D8A5F	8372 157659	OLGA ABRAMOVA	{"phone": "+70252270016"}
0005434655273	EE795A	7506 060317	VITALIY NIKOLAEV	{"email": "nikolaevv_13061977@postgrespro.ru", "phone": "+70939938129"}
0005434655274	60C580	4343 291683	ALEKSANDR SERGEEV	{"phone": "+70951802236"}
0005434655275	936DDA	7757 496800	SERGEY NOVIKOV	{"phone": "+70745514674"}
0005434655276	936DDA	8215 324115	EVGENIY VOROBEV	{"phone": "+70459305813"}
0005434655277	6D5EBE	1724 970973	ILYA IVANOV	{"email": "ivanov-ilya.051964@postgrespro.ru", "phone": "+70531516801"}
0005434655278	9C977C	6913 075711	ELENA MAKSIMOVA	{"email": "maksimova-e24041972@postgrespro.ru", "phone": "+70526666322"}
0005434655279	D36649	0571 185532	SERGEY BARANOV	{"email": "sergeybaranov13121978@postgrespro.ru", "phone": "+70740508606"}
0005434655280	D36649	8083 633958	ARTEM ANDREEV	{"email": "artem-andreev.061977@postgrespro.ru", "phone": "+70449387985"}
0005434655281	4BB349	0053 026399	DMITRIY KUZNECOV	{"email": "kuznecov.d-061974@postgrespro.ru", "phone": "+70963466877"}
0005434655282	4BB349	2404 994734	ALEKSANDR ISAEV	{"email": "isaevaleksandr-03111974@postgrespro.ru", "phone": "+70110097134"}
0005434655283	2ABF81	7062 691199	VLADIMIR TARASOV	{"email": "v.tarasov-1975@postgrespro.ru", "phone": "+70599525790"}
0005434655284	712116	1693 536521	TAISIYA GRISHINA	{"email": "t.grishina.14081967@postgrespro.ru", "phone": "+70291997259"}
0005434655285	D9CA6B	6613 158862	SERGEY SHEVCHENKO	{"email": "sergey.shevchenko041971@postgrespro.ru", "phone": "+70871612431"}
0005434655286	1EA224	9688 446210	ALEKSANDR AFANASEV	{"phone": "+70511093520"}
0005434655287	2D540D	3033 704438	LARISA KAZAKOVA	{"phone": "+70562007436"}
0005434655288	3A770A	1349 256794	ANASTASIYA NESTEROVA	{"phone": "+70705242335"}
0005434655289	3A770A	0735 429546	ZINAIDA KUZNECOVA	{"email": "zinaidakuznecova051966@postgrespro.ru", "phone": "+70466791658"}
0005434655290	6423D7	0783 367926	SOFYA KUZMINA	{"phone": "+70135536985"}
0005434655291	44C05B	9439 302208	TAMARA VOLKOVA	{"phone": "+70335224263"}
0005434655292	EF3393	1523 912007	VALENTINA BORISOVA	{"email": "borisova_valentina.031972@postgrespro.ru", "phone": "+70041150324"}
0005434655293	EE826D	3350 513562	PAVEL DMITRIEV	{"email": "paveldmitriev_051973@postgrespro.ru", "phone": "+70218085290"}
0005434655294	EE826D	2537 255811	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko_29101977@postgrespro.ru", "phone": "+70717824888"}
0005434655295	48209A	8810 651895	TATYANA KISELEVA	{"email": "tatyana.kiseleva22101966@postgrespro.ru", "phone": "+70862861183"}
0005434655296	6B4513	8080 669349	EKATERINA ERMAKOVA	{"phone": "+70412072352"}
0005434655297	6B4513	8426 045819	EKATERINA ROMANOVA	{"phone": "+70990497366"}
0005434655298	6B4513	2286 523560	EVGENIY MAKAROV	{"email": "evgeniy.makarov25061963@postgrespro.ru", "phone": "+70414820770"}
0005434655299	3E3A65	2101 973091	IVAN VOLKOV	{"email": "volkov.ivan_22121976@postgrespro.ru", "phone": "+70286484430"}
0005434655300	3E3A65	5608 207438	ALENA EFIMOVA	{"email": "efimova_alena.29081972@postgrespro.ru", "phone": "+70975665667"}
0005434655301	5FD360	2443 232841	SERGEY ABRAMOV	{"email": "sergey_abramov.111970@postgrespro.ru", "phone": "+70590315292"}
0005434655302	BDEE28	3893 324725	VLADISLAV FOMIN	{"phone": "+70237393577"}
0005434655303	7E842A	2992 583669	OLGA GAVRILOVA	{"phone": "+70649651663"}
0005434655304	A49712	3280 661653	SERGEY OSIPOV	{"email": "osipov_sergey_24011975@postgrespro.ru", "phone": "+70108749031"}
0005434655305	A49712	5410 598465	LARISA NIKITINA	{"email": "larisa-nikitina121972@postgrespro.ru", "phone": "+70283540376"}
0005434655306	396C85	8818 118787	NATALIYA DANILOVA	{"phone": "+70154882778"}
0005434655307	79F19F	3640 661027	ANDREY FROLOV	{"email": "a_frolov03101971@postgrespro.ru", "phone": "+70582624802"}
0005434655308	79F19F	4915 192225	NADEZHDA VOROBEVA	{"phone": "+70901795708"}
0005434655309	3690AB	7517 003750	ANDREY MELNIKOV	{"email": "andrey-melnikov_1979@postgrespro.ru", "phone": "+70162369262"}
0005434655310	3690AB	8820 328186	EVGENIYA BORISOVA	{"phone": "+70830933970"}
0005434655311	35FEAC	8705 856369	DANIL FROLOV	{"phone": "+70102100350"}
0005434655312	E26243	7671 261983	VLADIMIR IVANOV	{"phone": "+70063524865"}
0005434655313	C70354	2826 643134	MARIYA MARTYNOVA	{"email": "mariyamartynova-23011982@postgrespro.ru", "phone": "+70764270405"}
0005434655314	C70354	4018 146288	VERA KOLESNIKOVA	{"phone": "+70339900757"}
0005434655315	6EE81C	4756 956854	ALENA OSIPOVA	{"email": "osipova-a.1977@postgrespro.ru", "phone": "+70892852044"}
0005434655316	2D8322	0282 266012	OLGA KUZMINA	{"email": "kuzminao-011974@postgrespro.ru", "phone": "+70142819474"}
0005434655317	168110	4141 905837	MIKHAIL ZHURAVLEV	{"email": "zhuravlev_m-1965@postgrespro.ru", "phone": "+70433487966"}
0005434655318	9A6E56	7854 781686	GALINA ANTONOVA	{"email": "galina-antonova_071973@postgrespro.ru", "phone": "+70757518714"}
0005434655319	9A6E56	6694 378088	NIKOLAY SEMENOV	{"phone": "+70070916303"}
0005434655320	531133	3972 127924	VLADIMIR KOZLOV	{"email": "kozlov-vladimir-1972@postgrespro.ru", "phone": "+70627920143"}
0005434655321	8353D9	4967 215115	OLGA KOLESNIKOVA	{"phone": "+70494204583"}
0005434655322	9AA07F	0673 544963	ELENA STEPANOVA	{"phone": "+70571698917"}
0005434655323	BB07D8	5673 490908	ALEKSANDRA KULIKOVA	{"email": "a.kulikova.07011977@postgrespro.ru", "phone": "+70215927238"}
0005434655324	99C982	2074 369150	TAMARA ISAEVA	{"phone": "+70704746528"}
0005434655325	5F85A2	5414 057247	VYACHESLAV GORBUNOV	{"phone": "+70750255680"}
0005434655326	5F85A2	4682 545409	VIKTOR SEMENOV	{"email": "semenov.viktor_091964@postgrespro.ru", "phone": "+70778660915"}
0005434655327	053FC4	5941 128669	ELENA GRISHINA	{"email": "elenagrishina121972@postgrespro.ru", "phone": "+70532662751"}
0005434655328	314657	7428 440865	NATALYA VASILEVA	{"email": "vasileva_natalya.15101972@postgrespro.ru", "phone": "+70975509437"}
0005434655329	3A3EA1	4273 413404	ALEKSANDR ALEKSEEV	{"phone": "+70048404354"}
0005434655330	CE1AB1	9102 756053	NIKOLAY KUZMIN	{"phone": "+70775227179"}
0005434655331	75CC92	8642 297974	VLADIMIR ILIN	{"email": "vladimir.ilin_081970@postgrespro.ru", "phone": "+70256396361"}
0005434655332	75CC92	7647 892268	KIRA BELYAEVA	{"email": "belyaevakira.1966@postgrespro.ru", "phone": "+70196066866"}
0005434655333	CB25F9	2732 389661	IRINA FEDOROVA	{"email": "fedorova.irina06081966@postgrespro.ru", "phone": "+70529171990"}
0005434655334	CB25F9	4845 268075	TATYANA VASILEVA	{"email": "vasileva.t_22121972@postgrespro.ru", "phone": "+70501592504"}
0005434655335	66CA51	7853 829097	VITALIY DMITRIEV	{"email": "v_dmitriev-091960@postgrespro.ru", "phone": "+70615005325"}
0005434655336	C51528	8250 856978	VASILIY NOVIKOV	{"email": "novikov-vasiliy_071981@postgrespro.ru", "phone": "+70807530093"}
0005434655337	08916D	4069 432752	LYUBOV PETROVA	{"email": "petrova_lyubov.041979@postgrespro.ru", "phone": "+70649585692"}
0005434655338	08916D	6143 974340	SERGEY MAKAROV	{"phone": "+70146786973"}
0005434655339	0C020E	1197 879542	OLGA MAKSIMOVA	{"phone": "+70624953639"}
0005434655340	4D0578	2965 397745	ANDREY ORLOV	{"email": "orlov_andrey-1969@postgrespro.ru", "phone": "+70851295642"}
0005434655341	91FFBF	1983 779369	ELENA GAVRILOVA	{"email": "gavrilova.e_021971@postgrespro.ru", "phone": "+70930290814"}
0005434655342	F0C022	9317 880181	ELENA KUZNECOVA	{"email": "kuznecova.elena-08011972@postgrespro.ru", "phone": "+70657687131"}
0005434655343	F0C022	5919 440857	ALEKSANDR SERGEEV	{"phone": "+70248647753"}
0005434655344	16C752	3948 680044	ALINA PAVLOVA	{"phone": "+70387184721"}
0005434655345	ED2A4F	9992 770847	ALEKSANDRA MOISEEVA	{"phone": "+70883395162"}
0005434655346	A1B5DA	0424 332872	NATALIYA NESTEROVA	{"email": "n.nesterova1977@postgrespro.ru", "phone": "+70743985026"}
0005434655347	3DED93	3054 798517	DENIS IVANOV	{"email": "ivanov-d_1979@postgrespro.ru", "phone": "+70435878186"}
0005434655348	3DED93	3019 927752	ALEKSANDR POPOV	{"phone": "+70886390263"}
0005434655349	403250	2543 793056	YAROSLAV KUDRYASHOV	{"phone": "+70819025221"}
0005434655350	27A0AF	1297 273020	SVETLANA ALEKSEEVA	{"email": "salekseeva.081973@postgrespro.ru", "phone": "+70818940242"}
0005434655351	27A0AF	3706 931083	EGOR AFANASEV	{"email": "e_afanasev-1965@postgrespro.ru", "phone": "+70400752313"}
0005434655352	7E22FD	0626 384879	VIKTOR ISAEV	{"phone": "+70253313149"}
0005434655353	AF3E66	1254 244576	ROMAN SOLOVEV	{"email": "r_solovev_051968@postgrespro.ru", "phone": "+70453403401"}
0005434655354	117595	1923 515624	VALENTINA FROLOVA	{"email": "valentina.frolova_18071980@postgrespro.ru", "phone": "+70871083044"}
0005434655355	C48B90	6299 585982	KRISTINA VLASOVA	{"email": "kristina-vlasova_091976@postgrespro.ru", "phone": "+70465934603"}
0005434655356	C48B90	7977 772288	NINA MEDVEDEVA	{"email": "n-medvedeva_021969@postgrespro.ru", "phone": "+70156635563"}
0005434655357	C48B90	1884 857206	OLGA SOKOLOVA	{"phone": "+70014682389"}
0005434655358	A704E6	8293 550076	NATALYA GORBUNOVA	{"email": "n-gorbunova.031980@postgrespro.ru", "phone": "+70505284088"}
0005434655359	CA6E68	5230 946143	EKATERINA NIKITINA	{"email": "nikitina_ekaterina.1968@postgrespro.ru", "phone": "+70349071097"}
0005434655360	CA6E68	4943 505329	LYUDMILA VOROBEVA	{"email": "l.vorobeva.15061962@postgrespro.ru", "phone": "+70805655155"}
0005434655361	5F17B8	3730 491082	VLADIMIR YAKOVLEV	{"phone": "+70562602361"}
0005434655362	194A2A	9594 806116	VLADIMIR OSIPOV	{"email": "v.osipov.30091963@postgrespro.ru", "phone": "+70558033533"}
0005434655363	CD231E	2047 928380	DIANA FILATOVA	{"email": "filatovadiana-1977@postgrespro.ru", "phone": "+70271323787"}
0005434655364	CD231E	0815 624186	EVGENIYA MEDVEDEVA	{"email": "medvedevaevgeniya-1984@postgrespro.ru", "phone": "+70667370927"}
0005434655365	CD231E	7613 369911	LYUBOV FEDOROVA	{"phone": "+70166356720"}
0005434655366	CD231E	5187 300339	VALENTINA EFREMOVA	{"email": "v_efremova_1967@postgrespro.ru", "phone": "+70041420021"}
0005434655367	03DB4F	2639 402498	VLADIMIR VOLKOV	{"email": "vvolkov_1970@postgrespro.ru", "phone": "+70350329430"}
0005434655368	03DB4F	1877 464221	NIKOLAY MOISEEV	{"phone": "+70946963950"}
0005434655369	879DCB	4690 106870	ANDREY SHEVCHENKO	{"phone": "+70551885666"}
0005434655370	879DCB	9949 373504	VALERIY TIKHONOV	{"phone": "+70434153897"}
0005434655371	D20281	0290 983546	LYUBOV YAKOVLEVA	{"phone": "+70723610633"}
0005434655372	FA2907	7763 446701	VLADIMIR MIKHAYLOV	{"phone": "+70987489665"}
0005434655373	FA2907	1245 543049	LYUDMILA SMIRNOVA	{"phone": "+70535600473"}
0005434655374	305F29	9363 708339	SVETLANA CHERNOVA	{"phone": "+70674177170"}
0005434655375	305F29	8648 893243	KIRILL BONDARENKO	{"phone": "+70111140515"}
0005434655376	4B3B5D	2426 751416	ALEKSEY SMIRNOV	{"email": "smirnov_aleksey_24081969@postgrespro.ru", "phone": "+70622422862"}
0005434655377	4B3B5D	3443 014528	ALEKSANDR GRIGOREV	{"email": "aleksandr.grigorev.031988@postgrespro.ru", "phone": "+70900698903"}
0005434655378	2C7E2F	2686 611671	OLGA ISAEVA	{"phone": "+70360179956"}
0005434655379	DCE9B7	0159 199636	ELENA POTAPOVA	{"phone": "+70121340347"}
0005434655380	DCE9B7	9114 108867	DMITRIY BORISOV	{"phone": "+70070568967"}
0005434655381	AEB877	3640 884196	NIKOLAY NIKOLAEV	{"phone": "+70989392960"}
0005434655382	AEB877	1284 259278	VERONIKA IVANOVA	{"phone": "+70242090585"}
0005434655383	E5E3E3	9524 121245	IGOR PETROV	{"email": "igor.petrov_28101971@postgrespro.ru", "phone": "+70203939369"}
0005434655384	CF5C53	0058 036939	RUFIYA POPOVA	{"phone": "+70909120974"}
0005434655385	CF5C53	0582 724892	DMITRIY ANDREEV	{"email": "andreevd.101957@postgrespro.ru", "phone": "+70821522228"}
0005434655386	B3DDA4	5000 768200	ILYA SOKOLOV	{"email": "sokolovilya_1962@postgrespro.ru", "phone": "+70853228518"}
0005434655387	D32F44	3654 696744	LEONID KISELEV	{"phone": "+70639179941"}
0005434655388	D32F44	9511 901310	VIKTORIYA ANISIMOVA	{"email": "v_anisimova17101957@postgrespro.ru", "phone": "+70082136729"}
0005434655389	47B520	3625 971011	LARISA ANDREEVA	{"email": "andreeva-l-28091978@postgrespro.ru", "phone": "+70067798891"}
0005434655390	077D3B	0930 510290	VALENTINA MAKAROVA	{"email": "valentinamakarova.041983@postgrespro.ru", "phone": "+70558347110"}
0005434655391	077D3B	2020 371550	VERA GORBUNOVA	{"email": "vgorbunova-29051970@postgrespro.ru", "phone": "+70003689438"}
0005434655392	077D3B	8711 529448	ALEKSEY SOLOVEV	{"phone": "+70432699971"}
0005434655393	73B129	4506 879488	STANISLAV KONOVALOV	{"email": "stanislav-konovalov.24011970@postgrespro.ru", "phone": "+70621018174"}
0005434655394	CA82EC	2894 652797	SOFIYA TROFIMOVA	{"phone": "+70093166738"}
0005434655395	87986D	8988 907171	FEDOR PAVLOV	{"phone": "+70648110083"}
0005434655396	87986D	2866 450997	VIKTORIYA NESTEROVA	{"email": "nesterova_v-03081980@postgrespro.ru", "phone": "+70304680204"}
0005434655397	001233	0671 070346	ANNA IVANOVA	{"email": "ivanovaanna.27091973@postgrespro.ru", "phone": "+70261317823"}
0005434655398	FD28DD	3134 834841	TAMARA ZAKHAROVA	{"email": "tamara.zakharova_27101962@postgrespro.ru", "phone": "+70545808064"}
0005434655399	0B0996	6345 608590	EVGENIY SERGEEV	{"phone": "+70825951843"}
0005434655400	0B0996	6157 274178	ANDREY FILIPPOV	{"email": "filippov_andrey_1971@postgrespro.ru", "phone": "+70429466493"}
0005434655401	767A8F	2407 217100	LYUBOV KUZNECOVA	{"phone": "+70528978606"}
0005434655402	EE830B	9500 285755	NADEZHDA SERGEEVA	{"email": "nsergeeva.051977@postgrespro.ru", "phone": "+70490430950"}
0005434655403	AC4929	0449 488972	ANATOLIY FILIPPOV	{"email": "filippov_anatoliy-1967@postgrespro.ru", "phone": "+70158999707"}
0005434655404	4E4CA9	1669 098730	ANNA VASILEVA	{"phone": "+70381324903"}
0005434655405	4B08D5	8164 041510	VLADISLAV BORISOV	{"phone": "+70145068711"}
0005434655406	AECB1C	0404 801455	IGOR BELOV	{"phone": "+70765407241"}
0005434655407	AECB1C	9226 782812	VLADIMIR EGOROV	{"email": "egorov.vladimir1963@postgrespro.ru", "phone": "+70611270608"}
0005434655408	3495C8	8558 630057	VLADIMIR NOVIKOV	{"phone": "+70090988774"}
0005434655409	48EECD	4738 506193	MAKSIM GERASIMOV	{"phone": "+70769982284"}
0005434655410	2ECA1F	7607 407194	ROMAN POPOV	{"phone": "+70098051048"}
0005434655411	3F8745	2765 102062	OLEG MATVEEV	{"phone": "+70244216969"}
0005434655412	68990E	7674 123283	GALINA ANDREEVA	{"phone": "+70644109637"}
0005434655413	4CB77C	3791 704818	YULIYA CHERNOVA	{"email": "yuliyachernova-1978@postgrespro.ru", "phone": "+70944706596"}
0005434655414	4CB77C	0111 751914	SVETLANA SOROKINA	{"phone": "+70304061757"}
0005434655415	18B8EA	4330 485979	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy.23011970@postgrespro.ru", "phone": "+70914175412"}
0005434655416	5A9EC9	6966 655999	VALENTINA KUZNECOVA	{"phone": "+70607694795"}
0005434655417	5A9EC9	9130 587096	GALINA ANTONOVA	{"phone": "+70155345608"}
0005434655418	38EFAB	2971 799396	LIDIYA PETROVA	{"email": "lidiya.petrova_111977@postgrespro.ru", "phone": "+70319761283"}
0005434655419	38EFAB	7865 055181	VERA VASILEVA	{"phone": "+70468363046"}
0005434655420	54C084	6043 933863	DANIL KRASNOV	{"email": "danil_krasnov_1963@postgrespro.ru", "phone": "+70130258038"}
0005434655421	B1CA25	9907 049814	ALEKSANDR KUZMIN	{"email": "akuzmin-30051975@postgrespro.ru", "phone": "+70172586076"}
0005434655422	4FC2F6	5019 211440	POLINA OSIPOVA	{"email": "p.osipova_1964@postgrespro.ru", "phone": "+70602807656"}
0005434655423	4FC2F6	6593 874042	EKATERINA KULIKOVA	{"email": "ekaterina-kulikova-111981@postgrespro.ru", "phone": "+70886597604"}
0005434655424	7555D6	9228 789462	VLADIMIR STEPANOV	{"email": "stepanov-v.011973@postgrespro.ru", "phone": "+70283507392"}
0005434655425	7555D6	1548 368837	SVETLANA FILIPPOVA	{"email": "filippova_svetlana-19101960@postgrespro.ru", "phone": "+70820863225"}
0005434655426	9CEBF5	8842 786829	IGOR YAKOVLEV	{"phone": "+70464525385"}
0005434655427	542A2C	5649 274386	ALEKSEY IVANOV	{"phone": "+70167492655"}
0005434655428	542A2C	2785 540163	VLADISLAV MELNIKOV	{"email": "vladislav.melnikov_1974@postgrespro.ru", "phone": "+70797133546"}
0005434655429	1CF0BB	7927 271714	MIKHAIL BARANOV	{"email": "baranovm_041959@postgrespro.ru", "phone": "+70281450147"}
0005434655430	1CF0BB	8576 806930	POLINA GAVRILOVA	{"email": "gavrilova_polina.06041967@postgrespro.ru", "phone": "+70744223882"}
0005434655431	C70D2A	3196 535615	NIKITA MATVEEV	{"phone": "+70744929146"}
0005434655432	764ACD	5964 485641	NIKITA KARPOV	{"email": "karpov_n_1961@postgrespro.ru", "phone": "+70458840542"}
0005434655433	28DA62	1216 510784	ROMAN POPOV	{"email": "popov-roman.1980@postgrespro.ru", "phone": "+70338462599"}
0005434655434	28DA62	9229 574493	VASILIY DENISOV	{"phone": "+70548679493"}
0005434655435	8C1CB6	4380 713937	ROMAN ANDREEV	{"phone": "+70117309432"}
0005434655436	2BDE30	3913 478856	YURIY SERGEEV	{"email": "ysergeev011971@postgrespro.ru", "phone": "+70350892958"}
0005434655437	C89159	6559 156041	SERGEY FROLOV	{"phone": "+70609599696"}
0005434655438	C89159	0350 560108	SERGEY IVANOV	{"email": "ivanov-s.03031983@postgrespro.ru", "phone": "+70791792133"}
0005434655439	8F9AC4	4016 847627	IRINA SAVELEVA	{"phone": "+70025469909"}
0005434655440	0914C9	8773 338266	SVETLANA SOKOLOVA	{"email": "s-sokolova-121975@postgrespro.ru", "phone": "+70460769551"}
0005434655441	BC2611	1020 898934	IGOR ALEKSANDROV	{"phone": "+70356603132"}
0005434655442	B3A68F	8833 371215	VLADIMIR KUDRYASHOV	{"email": "v.kudryashov_11051977@postgrespro.ru", "phone": "+70038606734"}
0005434655443	C12066	9324 881873	MATVEY FEDOROV	{"email": "fedorovm-1965@postgrespro.ru", "phone": "+70807529411"}
0005434655444	C8A6C6	3940 222905	OLGA BELOVA	{"email": "belova_olga09091968@postgrespro.ru", "phone": "+70338630857"}
0005434655445	0EA98D	4006 297878	VLADIMIR STEPANOV	{"email": "stepanov_v-011953@postgrespro.ru", "phone": "+70365500275"}
0005434655446	26ECA9	4615 222450	SVETLANA SOKOLOVA	{"phone": "+70820223791"}
0005434655447	2D86CA	9699 573962	NADEZHDA VOROBEVA	{"email": "vorobeva.nadezhda.111965@postgrespro.ru", "phone": "+70823720081"}
0005434655448	2D86CA	8015 968470	ANNA KALININA	{"email": "kalinina.a071978@postgrespro.ru", "phone": "+70678623945"}
0005434655449	94945C	3640 753475	DINARA IVANOVA	{"phone": "+70788525129"}
0005434655450	2624CD	9134 730950	POLINA GUSEVA	{"email": "guseva.polina.071962@postgrespro.ru", "phone": "+70602417375"}
0005434655451	2624CD	5697 559037	EVGENIYA DENISOVA	{"email": "e-denisova-1959@postgrespro.ru", "phone": "+70565886201"}
0005434655452	A509EA	5485 543464	SERGEY PAVLOV	{"phone": "+70787996790"}
0005434655453	46AC57	6844 595862	GALINA ANTONOVA	{"phone": "+70056524498"}
0005434655454	4CCEF3	4365 104002	NIKOLAY MIKHAYLOV	{"email": "nikolay-mikhaylov1963@postgrespro.ru", "phone": "+70707708113"}
0005434655455	05FB34	2958 466746	ALEKSEY IVANOV	{"email": "ivanov.aleksey_031975@postgrespro.ru", "phone": "+70141944620"}
0005434655456	3477C6	1647 305623	EKATERINA GUSEVA	{"email": "guseva-e-26031960@postgrespro.ru", "phone": "+70861891219"}
0005434655457	3477C6	4340 708765	LYUBOV SOLOVEVA	{"email": "soloveva-l_30051971@postgrespro.ru", "phone": "+70415109136"}
0005434655458	3477C6	0687 439856	EGOR SEMENOV	{"phone": "+70142829385"}
0005434655459	F65758	3067 645910	SERGEY PETROV	{"email": "s.petrov_08111971@postgrespro.ru", "phone": "+70130806591"}
0005434655460	923251	3336 390995	RAFAIL KISELEV	{"phone": "+70629745992"}
0005434655461	BED9D3	9362 713062	OLEG CHERNOV	{"email": "oleg-chernov.021971@postgrespro.ru", "phone": "+70946331855"}
0005434655462	A3535C	1587 972296	OLGA STEPANOVA	{"email": "ostepanova_111963@postgrespro.ru", "phone": "+70234025297"}
0005434655463	DD26BC	2893 872325	ANGELINA SERGEEVA	{"email": "angelinasergeeva.011977@postgrespro.ru", "phone": "+70930218150"}
0005434655464	DD26BC	6462 817806	ILYA VOROBEV	{"phone": "+70654329139"}
0005434655465	65C287	2241 447509	NINA PETROVA	{"phone": "+70999753780"}
0005434655466	BDFDCF	2518 797349	NATALYA POPOVA	{"email": "popova-n.071968@postgrespro.ru", "phone": "+70953916442"}
0005434655467	CE1B18	0557 357272	EKATERINA SOROKINA	{"email": "ekaterina-sorokina-21101971@postgrespro.ru", "phone": "+70455065327"}
0005434655468	B1CA05	3573 816515	ANDREY IVANOV	{"phone": "+70565484993"}
0005434655469	B1CA05	8702 847665	EKATERINA FOMINA	{"phone": "+70585848074"}
0005434655470	64C928	2438 046241	VIKTOR BORISOV	{"phone": "+70095530132"}
0005434655471	1ECCA4	5192 116200	OLEG IVANOV	{"email": "ivanov-o_1974@postgrespro.ru", "phone": "+70759017261"}
0005434655472	256C38	7345 694190	YULIYA KRASNOVA	{"email": "ykrasnova_04111960@postgrespro.ru", "phone": "+70108513275"}
0005434655473	B65346	5851 706497	LYUBOV NIKITINA	{"email": "nikitina_lyubov_1964@postgrespro.ru", "phone": "+70181144043"}
0005434655474	2E7755	2296 316927	GALINA KONOVALOVA	{"email": "g-konovalova.1962@postgrespro.ru", "phone": "+70587212017"}
0005434655475	8AAAC1	5614 969824	DENIS NAZAROV	{"phone": "+70384450240"}
0005434655476	8AAAC1	7445 447176	ALEKSANDR NIKOLAEV	{"phone": "+70295684045"}
0005434655477	90523E	0603 529657	MAKSIM TIKHONOV	{"email": "tikhonovmaksim.081968@postgrespro.ru", "phone": "+70329554694"}
0005434655478	912EE0	7440 148265	MARIYA OSIPOVA	{"phone": "+70423764875"}
0005434655479	912EE0	9192 006576	ARTEM PETROV	{"phone": "+70093628736"}
0005434655480	CA3FB7	4315 731519	IGOR MAKAROV	{"email": "makarov-i011976@postgrespro.ru", "phone": "+70157411734"}
0005434655481	CA3FB7	5498 966336	ANDREY ZHUKOV	{"phone": "+70050685764"}
0005434655482	882689	4014 057815	MAKSIM KARPOV	{"email": "karpovm_11011965@postgrespro.ru", "phone": "+70386244196"}
0005434655483	882689	3098 554119	IRAIDA MOROZOVA	{"phone": "+70447539277"}
0005434655484	326227	9021 911226	ALEKSEY ALEKSEEV	{"phone": "+70843583521"}
0005434655485	326227	2686 961179	YURIY ROMANOV	{"email": "y_romanov-081976@postgrespro.ru", "phone": "+70011687148"}
0005434655486	7BF32B	8152 040547	IRINA KUZMINA	{"email": "kuzminairina1980@postgrespro.ru", "phone": "+70260501944"}
0005434655487	7BF32B	4331 948734	GALINA ZHUKOVA	{"phone": "+70686601187"}
0005434663429	EB15BE	2275 489961	LIDIYA ZOTOVA	{"phone": "+70926072272"}
0005434655488	E9D976	0388 433755	NATALYA MAKAROVA	{"email": "makarova_n_21091976@postgrespro.ru", "phone": "+70981383629"}
0005434655489	5EACA9	9722 517098	ALEKSEY FOMIN	{"phone": "+70415336848"}
0005434655490	5EACA9	3172 740731	NIKOLAY SHEVCHENKO	{"email": "shevchenko.nikolay_22071974@postgrespro.ru", "phone": "+70458209830"}
0005434655491	B14765	4773 209739	ANATOLIY NOVIKOV	{"email": "novikov.a-1980@postgrespro.ru", "phone": "+70590037396"}
0005434655492	B14765	3621 799107	OKSANA DENISOVA	{"email": "o.denisova-1971@postgrespro.ru", "phone": "+70487042769"}
0005434655493	EE1A57	6511 254188	ELIZAVETA MIKHAYLOVA	{"email": "mikhaylova_e_061972@postgrespro.ru", "phone": "+70777650808"}
0005434655494	498E3E	9357 325504	ALBINA ZHURAVLEVA	{"phone": "+70965527821"}
0005434655495	638727	2214 809261	LYUDMILA IVANOVA	{"email": "livanova02031974@postgrespro.ru", "phone": "+70588692736"}
0005434655496	52F4C4	1860 663529	LIDIYA POTAPOVA	{"email": "lidiyapotapova-1977@postgrespro.ru", "phone": "+70437296650"}
0005434655497	A10C2D	8355 440524	PAVEL FEDOTOV	{"phone": "+70395052448"}
0005434655498	A10C2D	4133 207707	DENIS TIMOFEEV	{"email": "d-timofeev_1958@postgrespro.ru", "phone": "+70760187392"}
0005434655499	FF888E	9848 410034	VLADIMIR ALEKSEEV	{"email": "vladimir-alekseev-1973@postgrespro.ru", "phone": "+70880709499"}
0005434655500	FF888E	0974 875492	EVGENIY PETROV	{"email": "petrov_evgeniy_1970@postgrespro.ru", "phone": "+70549431972"}
0005434655501	FF888E	2357 873544	EVGENIYA EGOROVA	{"phone": "+70511687567"}
0005434655502	24A2C2	0828 250191	IGOR IVANOV	{"phone": "+70372594722"}
0005434655503	24A2C2	3098 740978	SERGEY MAKAROV	{"email": "s.makarov30081974@postgrespro.ru", "phone": "+70558037294"}
0005434655504	F36159	4990 236852	RAISA KULIKOVA	{"email": "rkulikova-021959@postgrespro.ru", "phone": "+70419837635"}
0005434655505	F36159	0518 215320	VIKTORIYA RODIONOVA	{"phone": "+70907651402"}
0005434655506	084436	1819 621795	LYUDMILA SMIRNOVA	{"phone": "+70504541655"}
0005434655507	86CA03	8815 494847	DANILA ABRAMOV	{"email": "abramovd091967@postgrespro.ru", "phone": "+70935688116"}
0005434655508	9A513F	9514 680676	SERGEY POPOV	{"phone": "+70265049682"}
0005434655509	3C839F	8411 792469	SERGEY PAVLOV	{"email": "pavlov.s-1972@postgrespro.ru", "phone": "+70154648217"}
0005434655510	3C839F	2147 760427	NATALYA NAZAROVA	{"phone": "+70005496209"}
0005434655511	DB682D	8921 435358	EDUARD MOROZOV	{"email": "morozov-e_1978@postgrespro.ru", "phone": "+70927711868"}
0005434655512	4CFE5F	3809 343620	NATALYA MIKHAYLOVA	{"phone": "+70330368265"}
0005434655513	4CFE5F	3140 836946	VALENTINA SOLOVEVA	{"email": "soloveva-v_26051972@postgrespro.ru", "phone": "+70136158016"}
0005434655514	166911	2988 267638	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr.17041965@postgrespro.ru", "phone": "+70620712158"}
0005434655515	1F6310	8679 224864	NIKITA GAVRILOV	{"phone": "+70913324323"}
0005434655516	55493C	8975 297925	ANATOLIY MOISEEV	{"email": "a.moiseev-30081976@postgrespro.ru", "phone": "+70329677432"}
0005434655517	E06A88	7130 059216	PETR SAVELEV	{"email": "p.savelev05061971@postgrespro.ru", "phone": "+70382499807"}
0005434655518	E06A88	6086 448563	SERGEY STEPANOV	{"email": "stepanov_s_031960@postgrespro.ru", "phone": "+70551792126"}
0005434655519	599232	3405 534419	IVAN ORLOV	{"email": "orlov-i.19041974@postgrespro.ru", "phone": "+70828116072"}
0005434655520	038FE5	5597 828729	EVGENIY TARASOV	{"phone": "+70220917778"}
0005434655521	A23CBE	8318 600235	NADEZHDA PETROVA	{"phone": "+70970206123"}
0005434655522	A23CBE	4556 966635	ALEKSANDRA KUZNECOVA	{"phone": "+70120547827"}
0005434655523	A23CBE	6348 099789	LYUBOV DENISOVA	{"phone": "+70545876388"}
0005434655524	46D6BC	5919 507360	ANDREY SERGEEV	{"phone": "+70675551305"}
0005434655525	46D6BC	3827 377902	EVGENIY ANTONOV	{"email": "antonov.e_1980@postgrespro.ru", "phone": "+70749886283"}
0005434655526	46D6BC	3161 885209	POLINA MOROZOVA	{"email": "morozova_polina_1973@postgrespro.ru", "phone": "+70319283406"}
0005434655527	1F9983	1252 601589	VITALIY VLASOV	{"email": "vlasovvitaliy07011970@postgrespro.ru", "phone": "+70219809536"}
0005434655528	1F9983	8555 532333	ALENA POPOVA	{"phone": "+70214645497"}
0005434655529	E5626A	0337 142243	ANDREY YAKOVLEV	{"phone": "+70331115510"}
0005434655530	090D46	9493 581123	VERA KUZNECOVA	{"email": "kuznecova_vera1969@postgrespro.ru", "phone": "+70681976743"}
0005434655531	E54F92	4943 346624	NATALYA BELYAEVA	{"email": "belyaeva.natalya.11091972@postgrespro.ru", "phone": "+70512650417"}
0005434655532	8D2035	8844 866016	ALENA GERASIMOVA	{"email": "alenagerasimova1975@postgrespro.ru", "phone": "+70621015254"}
0005434655533	8D2035	1807 745500	ALEKSANDR ZAKHAROV	{"email": "zakharova-081969@postgrespro.ru", "phone": "+70904514489"}
0005434655534	8D2035	1381 791076	SERGEY SOLOVEV	{"phone": "+70905084738"}
0005434655535	441FFB	6890 747460	ANASTASIYA KONOVALOVA	{"email": "konovalova-a.23031961@postgrespro.ru", "phone": "+70102783040"}
0005434655536	441FFB	1502 683875	ANASTASIYA ZHUKOVA	{"email": "anastasiya-zhukova_1975@postgrespro.ru", "phone": "+70088596225"}
0005434655537	4FBA32	1192 675461	ALEKSANDR VASILEV	{"phone": "+70989954523"}
0005434655538	4FBA32	4730 898568	GULNARA PETROVA	{"email": "g_petrova.111971@postgrespro.ru", "phone": "+70801044031"}
0005434655539	CF7751	8299 246879	LYUBOV KULIKOVA	{"phone": "+70639914892"}
0005434655540	0172E4	1073 022898	VLADIMIR POPOV	{"email": "v.popov_14061977@postgrespro.ru", "phone": "+70621448711"}
0005434655541	288CB7	6226 587092	LYUBOV ALEKSANDROVA	{"phone": "+70186200402"}
0005434655542	288CB7	8780 644087	VIKTOR BARANOV	{"email": "viktor_baranov-111966@postgrespro.ru", "phone": "+70733782406"}
0005434656557	E3D611	6573 662068	MARIYA MATVEEVA	{"phone": "+70858539488"}
0005434656520	CC2719	5205 390376	LYUBOV SOKOLOVA	{"email": "sokolova.lyubov.061966@postgrespro.ru", "phone": "+70182534276"}
0005434656521	CC2719	7874 213397	SVETLANA ALEKSANDROVA	{"email": "s.aleksandrova-1981@postgrespro.ru", "phone": "+70488543905"}
0005434656522	A524E7	6408 428115	NINA VOROBEVA	{"phone": "+70906445367"}
0005434656523	ECA85E	0643 709816	ALEKSANDR MIRONOV	{"email": "mironov.a_08051973@postgrespro.ru", "phone": "+70452159723"}
0005434656524	E62136	6520 130391	VIKTOR SAVELEV	{"email": "viktor_savelev1978@postgrespro.ru", "phone": "+70748217037"}
0005434656525	C5651F	4392 454320	MARIYA DANILOVA	{"phone": "+70390335325"}
0005434656526	63FF54	8423 055532	ULYANA IVANOVA	{"email": "uivanova-27021973@postgrespro.ru", "phone": "+70355682866"}
0005434656527	F78BF5	8373 239105	ANDREY NAZAROV	{"email": "nazarov.a-021965@postgrespro.ru", "phone": "+70208076775"}
0005434656528	DCBCB8	5357 433527	ALIK SOROKIN	{"phone": "+70630939509"}
0005434656529	49EBD0	1011 928059	NADEZHDA YAKOVLEVA	{"email": "yakovleva.nadezhda-031970@postgrespro.ru", "phone": "+70480576104"}
0005434656530	36D445	9888 884269	ALEKSEY IVANOV	{"phone": "+70382873661"}
0005434656531	36D445	1584 361158	ALEKSEY VOLKOV	{"phone": "+70847808613"}
0005434656532	5A4252	5267 012079	EKATERINA KISELEVA	{"email": "ekaterina.kiseleva-1971@postgrespro.ru", "phone": "+70959815157"}
0005434656533	5A4252	2067 061166	VALERIY BONDARENKO	{"email": "valeriy-bondarenko_1971@postgrespro.ru", "phone": "+70417398420"}
0005434656534	9D01CE	7662 626887	ALEKSEY KOZLOV	{"email": "kozlov_aleksey_061976@postgrespro.ru", "phone": "+70106453652"}
0005434656535	9D01CE	9918 113521	VIKTOR GAVRILOV	{"phone": "+70909266068"}
0005434656536	9D01CE	4395 889186	ALEKSEY VLASOV	{"email": "a_vlasov.061974@postgrespro.ru", "phone": "+70161896741"}
0005434656537	9D01CE	4976 842712	LYUDMILA FEDOROVA	{"email": "lfedorova_041975@postgrespro.ru", "phone": "+70050808356"}
0005434656538	B939B7	0701 481091	ANATOLIY PETROV	{"email": "petrov_anatoliy.041971@postgrespro.ru", "phone": "+70045554300"}
0005434656539	B939B7	3131 046118	MAKSIM GRIGOREV	{"email": "grigorev_maksim1969@postgrespro.ru", "phone": "+70544197716"}
0005434656540	417EA9	8673 679155	VLADIMIR KULIKOV	{"email": "kulikov.v_1964@postgrespro.ru", "phone": "+70608241395"}
0005434656541	8AE4E2	5777 308365	DMITRIY KOROLEV	{"phone": "+70991736824"}
0005434656542	44A76C	5404 281339	OLGA NOVIKOVA	{"email": "o_novikova_011972@postgrespro.ru", "phone": "+70557271861"}
0005434656543	2D675B	5735 066490	IRINA VOLKOVA	{"phone": "+70303560921"}
0005434656544	5713E4	9431 728852	MARIYA GUSEVA	{"phone": "+70002028636"}
0005434656545	A98D44	2116 347090	RUSLAN ROMANOV	{"phone": "+70316843637"}
0005434656546	34FAF5	3537 739094	DENIS SAVELEV	{"email": "savelev-denis111977@postgrespro.ru", "phone": "+70423149066"}
0005434656547	DA7045	4683 968822	NADEZHDA FILATOVA	{"phone": "+70086417943"}
0005434656548	DA7045	7235 272945	PAVEL OSIPOV	{"phone": "+70917211852"}
0005434656549	D9464A	1824 858181	IRINA POLYAKOVA	{"email": "polyakova.i-1957@postgrespro.ru", "phone": "+70231396887"}
0005434656550	8F5088	0801 011431	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir031987@postgrespro.ru", "phone": "+70293385727"}
0005434656551	8F5088	4333 507945	NATALIYA ORLOVA	{"email": "norlova.03021967@postgrespro.ru", "phone": "+70323993381"}
0005434656552	36E016	3004 807853	ALEKSANDR IVANOV	{"phone": "+70721982516"}
0005434656553	36E016	2531 423845	OLEG ORLOV	{"email": "orlov_o-061977@postgrespro.ru", "phone": "+70135489928"}
0005434656554	36E016	9101 758006	NIKITA KUDRYASHOV	{"phone": "+70790093353"}
0005434656555	98FE01	2702 350688	IGOR IVANOV	{"email": "iivanov.071979@postgrespro.ru", "phone": "+70844583810"}
0005434656556	257F0F	0620 982310	DMITRIY MATVEEV	{"email": "d.matveev_051975@postgrespro.ru", "phone": "+70409675204"}
0005434656558	483144	8473 280656	DAMIR VOROBEV	{"phone": "+70108047242"}
0005434656559	18E0A6	3824 504474	TATYANA TIKHONOVA	{"phone": "+70961720030"}
0005434656560	8A1E2A	5370 521246	SERGEY KUZMIN	{"email": "kuzmin_s_091967@postgrespro.ru", "phone": "+70867270035"}
0005434656561	4E97D7	3127 903693	YURIY IVANOV	{"email": "ivanov-yuriy_041965@postgrespro.ru", "phone": "+70713037653"}
0005434656562	493AB4	1628 695635	OLESYA KRASNOVA	{"phone": "+70159780001"}
0005434656563	493AB4	7265 367760	TATYANA NIKIFOROVA	{"phone": "+70865958506"}
0005434656564	E6EEB1	8573 145582	NELYA IVANOVA	{"email": "ivanovan121975@postgrespro.ru", "phone": "+70687295707"}
0005434656565	3E3D40	0130 452300	ALEKSANDR SERGEEV	{"phone": "+70295513739"}
0005434656566	8B070E	7628 574786	NATALYA NIKITINA	{"phone": "+70184732270"}
0005434656567	8B070E	1037 445321	MARIYA KULIKOVA	{"phone": "+70048391966"}
0005434656568	8B070E	8328 992145	SVETLANA MEDVEDEVA	{"phone": "+70970082672"}
0005434656569	8498A1	2921 217410	MIKHAIL PAVLOV	{"email": "m_pavlov041967@postgrespro.ru", "phone": "+70456263565"}
0005434656570	8498A1	7585 374831	TATYANA OSIPOVA	{"phone": "+70958823425"}
0005434656571	4AF276	3883 839483	SERGEY TIKHONOV	{"phone": "+70062115261"}
0005434656572	7F1DCE	4773 936087	EKATERINA TARASOVA	{"email": "tarasova-e_04011978@postgrespro.ru", "phone": "+70472741633"}
0005434656573	9B1AB6	4403 493508	ARTEM SERGEEV	{"email": "sergeev.artem.19061976@postgrespro.ru", "phone": "+70148411383"}
0005434656574	9B1AB6	9966 123822	EVGENIY SCHERBAKOV	{"phone": "+70860293031"}
0005434656575	561350	4226 279455	TATYANA MARTYNOVA	{"email": "martynova-tatyana-121974@postgrespro.ru", "phone": "+70717497935"}
0005434656576	666119	5096 317202	MAKSIM KUZNECOV	{"phone": "+70259505117"}
0005434656577	666119	6527 537965	DMITRIY RODIONOV	{"phone": "+70351548783"}
0005434656578	670D10	6967 620988	VLADIMIR ZAYCEV	{"phone": "+70241489245"}
0005434656579	17CF48	8700 547218	ANDREY NOVIKOV	{"email": "novikovandrey-1974@postgrespro.ru", "phone": "+70730811434"}
0005434656580	8DD773	0433 155104	EKATERINA VOLKOVA	{"phone": "+70623643232"}
0005434656581	3EB4F5	3215 476337	ALEKSANDRA ERMAKOVA	{"phone": "+70698800513"}
0005434656582	3EB4F5	2418 389924	VLADIMIR SEMENOV	{"email": "semenov.v_1974@postgrespro.ru", "phone": "+70159282304"}
0005434656583	9DF224	8187 665527	NATALYA SIDOROVA	{"email": "sidorovanatalya-1978@postgrespro.ru", "phone": "+70640435756"}
0005434656584	18C956	2257 751131	ROMAN ZAKHAROV	{"email": "zakharovroman.15101971@postgrespro.ru", "phone": "+70534223166"}
0005434656585	C119CB	7581 204135	VASILIY VOLKOV	{"email": "v.volkov-111989@postgrespro.ru", "phone": "+70389132549"}
0005434656586	C119CB	7335 797959	VENIAMIN KRASNOV	{"email": "veniamin.krasnov.1966@postgrespro.ru", "phone": "+70575671829"}
0005434656587	C0FC89	4158 513848	ELENA ANTONOVA	{"phone": "+70752961181"}
0005434656588	4F6AFF	8469 192699	LYUDMILA KUZMINA	{"email": "l.kuzmina-061981@postgrespro.ru", "phone": "+70459877971"}
0005434656589	26DA93	1230 051167	NINA LEBEDEVA	{"phone": "+70545082684"}
0005434656590	26DA93	0220 502609	ALEKSANDR BELOV	{"phone": "+70783226086"}
0005434656591	0E8B1D	5253 526622	VLADIMIR FEDOROV	{"email": "fedorov-v_1980@postgrespro.ru", "phone": "+70392994029"}
0005434656592	6D4CF0	3340 374128	ELENA KAZAKOVA	{"phone": "+70916851196"}
0005434656593	D8DDFB	4369 831468	MIKHAIL OSIPOV	{"email": "mikhail.osipov_12091961@postgrespro.ru", "phone": "+70324073918"}
0005434656594	3CDECC	7970 523529	TATYANA MAKAROVA	{"email": "makarova_t.30011957@postgrespro.ru", "phone": "+70104432890"}
0005434656595	3CDECC	0829 501378	EVGENIY GAVRILOV	{"phone": "+70359691547"}
0005434656596	68DB06	6727 192111	OLGA NIKITINA	{"email": "nikitina.olga-081972@postgrespro.ru", "phone": "+70309607904"}
0005434656597	015C9A	2726 829336	LYUBOV POPOVA	{"email": "popova-l.1976@postgrespro.ru", "phone": "+70866041549"}
0005434656598	4B8AB4	2692 338314	VALENTINA EFIMOVA	{"email": "v-efimova.1973@postgrespro.ru", "phone": "+70264203180"}
0005434656599	3BC26A	1114 535346	ANNA TARASOVA	{"phone": "+70263980858"}
0005434656600	ACA9EE	8028 850105	NATALYA ERMAKOVA	{"phone": "+70548721663"}
0005434656601	ACA9EE	3885 584597	ALENA FILIPPOVA	{"email": "alena-filippova1968@postgrespro.ru", "phone": "+70574076750"}
0005434656602	8960BD	2259 039729	ALEKSANDR POPOV	{"email": "popov-aleksandr.031972@postgrespro.ru", "phone": "+70957092864"}
0005434656603	1D3E22	4937 396461	ARSENIY BARANOV	{"phone": "+70006172363"}
0005434656604	F01E82	6671 059427	ALEKSANDR GORBUNOV	{"phone": "+70327223615"}
0005434656605	A37AB5	6391 232262	NATALYA MASLOVA	{"phone": "+70850635653"}
0005434656606	1EEA6E	2681 193827	ALEKSANDR FROLOV	{"email": "frolov_a_04071967@postgrespro.ru", "phone": "+70020929234"}
0005434656607	A90D28	7812 884606	TATYANA FROLOVA	{"email": "frolova_t-071971@postgrespro.ru", "phone": "+70262056057"}
0005434656608	A90D28	9344 361368	EVGENIY MARTYNOV	{"phone": "+70219709905"}
0005434656609	A90D28	2356 687102	VALERIY FROLOV	{"email": "v_frolov-30091972@postgrespro.ru", "phone": "+70491105402"}
0005434656610	2909E0	1550 077561	ELENA SOKOLOVA	{"email": "sokolovae.011990@postgrespro.ru", "phone": "+70056245937"}
0005434656611	2909E0	3457 860733	SVETLANA MASLOVA	{"email": "maslovasvetlana_09071971@postgrespro.ru", "phone": "+70116507894"}
0005434656612	C10879	1359 899477	MAKSIM NAUMOV	{"phone": "+70881873417"}
0005434656613	BA8C23	2300 764639	VITALIY KONOVALOV	{"email": "konovalov_v.041973@postgrespro.ru", "phone": "+70602428075"}
0005434656614	BA8C23	8544 834449	ELENA IVANOVA	{"phone": "+70026372439"}
0005434656615	BA8C23	9395 270092	ANDREY MOROZOV	{"email": "morozovandrey-041974@postgrespro.ru", "phone": "+70012408520"}
0005434663165	3B73B1	4110 557375	KLAVDIYA SIDOROVA	{"email": "ksidorova21011975@postgrespro.ru", "phone": "+70668017286"}
0005434663166	DD399C	0551 601562	MARINA KOVALEVA	{"email": "m.kovaleva_15071967@postgrespro.ru", "phone": "+70932509724"}
0005434663167	B45968	9604 224237	OLGA GRISHINA	{"email": "olga-grishina-111966@postgrespro.ru", "phone": "+70815053916"}
0005434663168	B45968	9334 747606	ALEKSANDR SMIRNOV	{"phone": "+70698420326"}
0005434663169	5C2290	7207 715829	OLGA ROMANOVA	{"email": "oromanova12081970@postgrespro.ru", "phone": "+70453505960"}
0005434663170	5C2290	1333 681321	PAVEL KOZLOV	{"phone": "+70117127365"}
0005434663171	5C2290	2306 207318	VALENTINA FILATOVA	{"email": "filatova-v.03111972@postgrespro.ru", "phone": "+70907577598"}
0005434663172	B9394E	7078 327695	SERGEY KAZAKOV	{"email": "s.kazakov.061979@postgrespro.ru", "phone": "+70665773974"}
0005434663173	FC0F59	9498 853965	NIKOLAY SAVELEV	{"email": "savelev-nikolay011982@postgrespro.ru", "phone": "+70625641197"}
0005434663174	248359	9947 997282	ALEKSEY ANTONOV	{"email": "antonov.aleksey-1974@postgrespro.ru", "phone": "+70283894408"}
0005434663175	A53384	8372 702703	VLADIMIR GUSEV	{"phone": "+70754173837"}
0005434663176	A53384	3073 386533	NAILYA KUZMINA	{"email": "kuzmina_n_09121975@postgrespro.ru", "phone": "+70458617713"}
0005434663177	480647	6127 843018	OLGA IVANOVA	{"email": "ivanova.olga.091979@postgrespro.ru", "phone": "+70281508867"}
0005434663178	1804BB	9986 869075	SERGEY GUSEV	{"phone": "+70198044699"}
0005434663179	D3F93D	1584 453936	LYUDMILA GAVRILOVA	{"phone": "+70501800405"}
0005434663180	8BAE63	8367 260837	LILIYA SOROKINA	{"email": "sorokinal-071981@postgrespro.ru", "phone": "+70124974415"}
0005434663181	8BAE63	8071 194396	SERGEY VOROBEV	{"phone": "+70872245870"}
0005434663182	A0B17F	9627 750003	SAMIRA ZAKHAROVA	{"email": "zakharovasamira_07061987@postgrespro.ru", "phone": "+70164536492"}
0005434663183	408B01	9923 556344	DMITRIY ZHURAVLEV	{"phone": "+70314450398"}
0005434663184	408B01	4036 978459	ALEKSANDR KAZAKOV	{"phone": "+70871380742"}
0005434663185	1228F3	4753 018510	NIKITA PETROV	{"email": "nikita.petrov_021979@postgrespro.ru", "phone": "+70176686611"}
0005434663186	1228F3	3373 527976	VLADIMIR IVANOV	{"phone": "+70009586440"}
0005434663187	41BC23	5163 784598	SOFYA KONOVALOVA	{"email": "skonovalova.1978@postgrespro.ru", "phone": "+70183372249"}
0005434663188	85B909	8519 547007	ALEKSEY DENISOV	{"email": "denisov.aleksey.1968@postgrespro.ru", "phone": "+70864520643"}
0005434663189	F9BA57	2798 377801	MARGARITA KUZNECOVA	{"phone": "+70862979481"}
0005434663190	F9BA57	5057 273629	TATYANA MIKHAYLOVA	{"email": "tatyana.mikhaylova04051971@postgrespro.ru", "phone": "+70824310550"}
0005434663191	C3255B	1708 199755	TAISIYA SAVELEVA	{"email": "taisiyasaveleva1967@postgrespro.ru", "phone": "+70411708339"}
0005434663192	72457B	8921 682377	YULIYA GORBUNOVA	{"email": "gorbunova.yuliya16061967@postgrespro.ru", "phone": "+70574408687"}
0005434663193	483B82	2429 658969	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.t-031987@postgrespro.ru", "phone": "+70483779958"}
0005434663194	483B82	4068 667199	MARIYA IVANOVA	{"phone": "+70771642768"}
0005434663195	21C345	3566 021001	NIKITA DAVYDOV	{"phone": "+70871230717"}
0005434663196	21C345	0377 480482	IRINA BOGDANOVA	{"email": "i-bogdanova-021976@postgrespro.ru", "phone": "+70031293973"}
0005434663197	C213B4	2086 183228	VLADIMIR TIMOFEEV	{"phone": "+70382327816"}
0005434663198	73405B	5915 103258	ALEKSANDR ALEKSANDROV	{"email": "a.aleksandrov-031970@postgrespro.ru", "phone": "+70643669106"}
0005434663199	092802	5404 012975	VLADIMIR SEMENOV	{"phone": "+70983111737"}
0005434663200	2D34AF	7410 020552	NIKITA EGOROV	{"email": "nikita-egorov_051970@postgrespro.ru", "phone": "+70937643630"}
0005434663201	2D34AF	7039 824959	TAMARA MATVEEVA	{"email": "matveevatamara-12071955@postgrespro.ru", "phone": "+70206796856"}
0005434663202	DEF561	7541 587234	MARINA IVANOVA	{"email": "mivanova-26061968@postgrespro.ru", "phone": "+70842746487"}
0005434663203	DEF561	2755 168765	NADEZHDA SOROKINA	{"email": "sorokina_nadezhda.1970@postgrespro.ru", "phone": "+70466519300"}
0005434663204	DEF561	5682 173157	ALENA ORLOVA	{"phone": "+70419962794"}
0005434663205	3726AD	3216 277570	NATALYA TROFIMOVA	{"email": "trofimovanatalya_1971@postgrespro.ru", "phone": "+70120499292"}
0005434663206	E8C142	3780 624605	ALEKSANDR ANTONOV	{"phone": "+70190196014"}
0005434663207	118BFE	5496 028273	OKSANA LEBEDEVA	{"phone": "+70741032713"}
0005434663208	5A9987	1689 572563	SERGEY YAKOVLEV	{"phone": "+70427901356"}
0005434663209	1501FF	3776 492397	KIRILL MOROZOV	{"email": "morozov-k.1967@postgrespro.ru", "phone": "+70443016594"}
0005434663210	B51E71	9410 472453	ANATOLIY SIDOROV	{"email": "sidorova-28081973@postgrespro.ru", "phone": "+70688210282"}
0005434663211	0F3C54	1734 944134	NATALYA DMITRIEVA	{"phone": "+70723918456"}
0005434663212	2EA9FE	4051 167272	ARTEM ROMANOV	{"email": "artem-romanov.12061961@postgrespro.ru", "phone": "+70229242534"}
0005434663213	F364AC	6591 436801	ELENA ROMANOVA	{"phone": "+70173023191"}
0005434663214	E54FA1	9710 881550	MARIYA FROLOVA	{"phone": "+70292885551"}
0005434663215	5B0E0A	1469 757197	PAVEL SMIRNOV	{"email": "smirnov.p_1964@postgrespro.ru", "phone": "+70361443252"}
0005434663216	5F3C3E	0777 863082	NIKOLAY KOZLOV	{"phone": "+70751124394"}
0005434663217	FA3808	3287 178906	VLADIMIR SOLOVEV	{"phone": "+70496730997"}
0005434663218	FA3808	4669 430848	NINA DMITRIEVA	{"phone": "+70277336675"}
0005434663219	DE8369	6406 750873	ALEKSANDR KOZLOV	{"email": "a.kozlov.091975@postgrespro.ru", "phone": "+70059829944"}
0005434663220	746228	3400 249662	VIKTORIYA NESTEROVA	{"email": "viktoriyanesterova071975@postgrespro.ru", "phone": "+70953152145"}
0005434663221	746228	2881 397165	VLADIMIR KRASNOV	{"phone": "+70758207093"}
0005434663222	F5BC19	2136 943229	IRINA LOGINOVA	{"email": "loginova.i.061966@postgrespro.ru", "phone": "+70538863564"}
0005434663223	F5BC19	2203 605044	ALEKSEY PAVLOV	{"phone": "+70625274521"}
0005434663224	EBAB48	9570 987724	NATALYA ANDREEVA	{"phone": "+70688917128"}
0005434663225	78A0AD	3449 502770	ANNA ALEKSEEVA	{"email": "alekseevaanna-23011969@postgrespro.ru", "phone": "+70359232425"}
0005434663226	78A0AD	4364 161572	VALENTINA SMIRNOVA	{"email": "v.smirnova_041967@postgrespro.ru", "phone": "+70265235446"}
0005434663227	F67048	2738 676262	VYACHESLAV SEMENOV	{"email": "semenovvyacheslav.1982@postgrespro.ru", "phone": "+70566454237"}
0005434663228	1781E5	9356 682280	GALINA TIKHONOVA	{"phone": "+70249021144"}
0005434663229	6B8549	4646 523659	ALEKSANDR SCHERBAKOV	{"phone": "+70885874611"}
0005434663230	6B8549	2613 314137	VIKTOR SEMENOV	{"email": "semenov.v-30081970@postgrespro.ru", "phone": "+70069555099"}
0005434663231	186E98	6390 850906	RAISA BELOVA	{"email": "raisa-belova1972@postgrespro.ru", "phone": "+70086109077"}
0005434663232	186E98	8574 368116	ANNA PETROVA	{"email": "petrova.a1968@postgrespro.ru", "phone": "+70105839407"}
0005434663233	186E98	4746 475048	NINA NOVIKOVA	{"email": "novikova_nina-25111975@postgrespro.ru", "phone": "+70961064274"}
0005434663234	1B565E	2905 548376	DARYA POPOVA	{"email": "popova-d.1967@postgrespro.ru", "phone": "+70651066719"}
0005434663235	FE2E56	3639 081487	ANDREY KONOVALOV	{"phone": "+70605566643"}
0005434663236	C15297	7138 500946	PETR MELNIKOV	{"email": "p_melnikov-041973@postgrespro.ru", "phone": "+70572181823"}
0005434663237	3A778F	8706 465191	NATALYA MEDVEDEVA	{"email": "natalyamedvedeva121958@postgrespro.ru", "phone": "+70207841403"}
0005434663238	B9D7DA	4298 287264	ANNA LEBEDEVA	{"phone": "+70571060506"}
0005434663239	1C7E8C	1439 378165	SVETLANA BELYAEVA	{"email": "belyaeva.svetlana.091978@postgrespro.ru", "phone": "+70960687643"}
0005434663240	1C7E8C	2433 980463	VIKTOR FOMIN	{"email": "vfomin_23101980@postgrespro.ru", "phone": "+70872821020"}
0005434663241	79EBD8	9672 184891	ALEKSANDR POPOV	{"email": "popovaleksandr03061968@postgrespro.ru", "phone": "+70048818628"}
0005434663242	79EBD8	3356 059878	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir.1974@postgrespro.ru", "phone": "+70816486677"}
0005434663243	B424B6	3866 448879	ALEKSANDR SOROKIN	{"phone": "+70480140275"}
0005434663244	B424B6	3132 351640	VIKTOR KOZLOV	{"phone": "+70713893674"}
0005434663245	CB9A0F	7429 627168	ALEKSEY GRIGOREV	{"email": "a.grigorev_041986@postgrespro.ru", "phone": "+70448476231"}
0005434663246	CB9A0F	5229 719678	SERGEY TIMOFEEV	{"phone": "+70946475707"}
0005434663247	EC6D77	1020 114034	FEDOR DMITRIEV	{"email": "fdmitriev_28101970@postgrespro.ru", "phone": "+70888936835"}
0005434663248	B5EE5B	7311 590015	ARTEM TIKHONOV	{"email": "artem-tikhonov_011977@postgrespro.ru", "phone": "+70938791064"}
0005434663249	086DD7	1690 786942	NADEZHDA ISAEVA	{"email": "nadezhda_isaeva-1951@postgrespro.ru", "phone": "+70683342260"}
0005434663250	C774A2	2080 023962	RAFAEL ILIN	{"email": "rafael.ilin-1972@postgrespro.ru", "phone": "+70299644047"}
0005434663251	05BF63	8011 711027	GALINA DMITRIEVA	{"phone": "+70543092169"}
0005434663252	239458	7780 373074	EVGENIY KUZMIN	{"phone": "+70428597541"}
0005434663253	7EBAD5	5280 545250	IVAN VOROBEV	{"email": "vorobev-ivan011980@postgrespro.ru", "phone": "+70474964631"}
0005434663254	7F3F62	6189 972637	OLGA ARKHIPOVA	{"email": "olgaarkhipova.081964@postgrespro.ru", "phone": "+70286981846"}
0005434663255	7F3F62	1304 940312	OLGA FEDOROVA	{"phone": "+70413300723"}
0005434663256	9CA8F1	0606 379918	ARSENIY SAVELEV	{"email": "a-savelev.101967@postgrespro.ru", "phone": "+70311059318"}
0005434663257	7F24E5	4033 705424	ALEKSANDR NOVIKOV	{"email": "anovikov051974@postgrespro.ru", "phone": "+70071425763"}
0005434663258	2372BF	4429 484015	EKATERINA FOMINA	{"phone": "+70427986584"}
0005434663259	CE3CB1	5113 502058	EVGENIYA KOVALEVA	{"email": "evgeniya-kovaleva021971@postgrespro.ru", "phone": "+70653051040"}
0005434663260	64B939	1014 144743	NINA SEMENOVA	{"email": "semenova.n12081976@postgrespro.ru", "phone": "+70914498239"}
0005434663261	8B24AC	2110 934033	TAISIYA PETROVA	{"email": "petrova-t.20111960@postgrespro.ru", "phone": "+70427426141"}
0005434663262	EC71BF	7932 561070	GENNADIY TIKHONOV	{"email": "gennadiytikhonov25061965@postgrespro.ru", "phone": "+70451286581"}
0005434663263	4242B9	1978 710810	ROMAN BELOV	{"phone": "+70496111644"}
0005434663264	692A7A	9761 650778	DENIS RODIONOV	{"phone": "+70993578399"}
0005434663265	692A7A	6709 813302	RUSLAN SMIRNOV	{"email": "smirnovruslan.101959@postgrespro.ru", "phone": "+70978387981"}
0005434663266	742C04	5528 590989	IGOR KAZAKOV	{"email": "kazakovi-1980@postgrespro.ru", "phone": "+70057596370"}
0005434663267	742C04	4315 196628	ALESYA NOVIKOVA	{"email": "novikovaalesya.021969@postgrespro.ru", "phone": "+70906912831"}
0005434663268	90CE06	1830 077076	YULIYA SOROKINA	{"email": "yuliya-sorokina.1975@postgrespro.ru", "phone": "+70059426335"}
0005434663269	90CE06	0694 099320	OKSANA KONOVALOVA	{"phone": "+70661353727"}
0005434663270	871668	8117 469762	SVETLANA ISAEVA	{"email": "s_isaeva_1965@postgrespro.ru", "phone": "+70177348234"}
0005434663271	871668	7245 511634	ELENA KISELEVA	{"phone": "+70460616381"}
0005434663272	54F0C2	5164 956830	ELIZAVETA MEDVEDEVA	{"phone": "+70764847423"}
0005434663273	66D4DC	1257 112502	DMITRIY NIKITIN	{"email": "d_nikitin-22111975@postgrespro.ru", "phone": "+70040035166"}
0005434663274	66D4DC	9412 453999	RAVIL SEMENOV	{"phone": "+70021418523"}
0005434663275	66D4DC	3044 905243	VLADIMIR MATVEEV	{"email": "matveev_v021977@postgrespro.ru", "phone": "+70985244070"}
0005434663276	BA1BE3	5003 702903	EVELINA MELNIKOVA	{"email": "melnikova.evelina-1970@postgrespro.ru", "phone": "+70241615599"}
0005434663277	BA1BE3	2329 333683	ZINAIDA ZOTOVA	{"email": "zotova_zinaida_051980@postgrespro.ru", "phone": "+70301147912"}
0005434663278	D3C134	2163 618123	VLADIMIR SOKOLOV	{"email": "sokolov.v09011974@postgrespro.ru", "phone": "+70692544171"}
0005434663279	D3C134	9436 845001	ALEVTINA IVANOVA	{"phone": "+70752447901"}
0005434663280	5D9BDB	9168 518750	ANTON KUZNECOV	{"phone": "+70527753489"}
0005434663281	7C1A83	5480 125325	DMITRIY ZAKHAROV	{"phone": "+70333022840"}
0005434663282	0D85D6	3893 652840	GRIGORIY SHEVCHENKO	{"phone": "+70708340419"}
0005434663283	0D85D6	1469 001439	NADEZHDA KISELEVA	{"phone": "+70089542755"}
0005434663284	4EAF38	3456 070903	VIKTOR SOLOVEV	{"email": "solovev-viktor.031966@postgrespro.ru", "phone": "+70528470142"}
0005434663285	A94ED9	1127 577831	IRINA IVANOVA	{"phone": "+70576181342"}
0005434663286	A94ED9	1073 192611	YULIYA KONOVALOVA	{"phone": "+70146833288"}
0005434663287	A94ED9	2049 405169	LYUDMILA IVANOVA	{"phone": "+70818999266"}
0005434663288	08BE00	2974 537955	YURIY CHERNOV	{"email": "chernovy.091961@postgrespro.ru", "phone": "+70545780943"}
0005434663289	08BE00	5136 769898	KONSTANTIN ZHURAVLEV	{"email": "zhuravlevk111986@postgrespro.ru", "phone": "+70330645149"}
0005434663346	A9424D	9638 749233	YULIYA MARTYNOVA	{"phone": "+70180249372"}
0005434663290	6766CD	6231 138176	ELENA YUDINA	{"email": "e_yudina-031982@postgrespro.ru", "phone": "+70844417827"}
0005434663291	6766CD	2547 519652	DMITRIY CHERNOV	{"phone": "+70881245594"}
0005434663292	92DC65	8794 901620	OLGA IVANOVA	{"phone": "+70851785595"}
0005434663293	92DC65	3615 825281	ALEKSANDR VASILEV	{"email": "a_vasilev_011976@postgrespro.ru", "phone": "+70144667795"}
0005434663294	C5020A	9035 086691	VERA EFIMOVA	{"email": "vera-efimova021971@postgrespro.ru", "phone": "+70105939052"}
0005434663295	B1FD21	6419 804000	VALERIY MATVEEV	{"phone": "+70445313491"}
0005434663296	B1FD21	5484 575819	ALENA GERASIMOVA	{"email": "gerasimovaa.22051965@postgrespro.ru", "phone": "+70528416406"}
0005434663297	52C7C2	9759 607620	EVGENIY VOLKOV	{"phone": "+70014104275"}
0005434663298	52C7C2	1647 682235	NATALYA PAVLOVA	{"phone": "+70683861651"}
0005434663299	52C7C2	4654 251171	GULFIYA KOZLOVA	{"phone": "+70526455683"}
0005434663300	F5F520	3766 488429	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-121973@postgrespro.ru", "phone": "+70519820602"}
0005434663301	FE1C1E	0692 742938	NIKOLAY MAKAROV	{"phone": "+70361254694"}
0005434663302	19256B	5152 913138	ALEKSANDR NOVIKOV	{"phone": "+70947609744"}
0005434663303	03EEF2	9547 834115	DANILA BELOV	{"email": "d.belov.18071969@postgrespro.ru", "phone": "+70407267479"}
0005434663304	2EF8E0	2357 533129	KONSTANTIN POPOV	{"email": "popov-konstantin031973@postgrespro.ru", "phone": "+70019317652"}
0005434663305	2EF8E0	6143 097686	ALEKSEY PETROV	{"email": "aleksey-petrov06031962@postgrespro.ru", "phone": "+70140952529"}
0005434663306	2EF8E0	5187 776468	ALEKSEY KISELEV	{"phone": "+70383521663"}
0005434663307	11869E	7000 002474	NIKITA NIKITIN	{"email": "nikita.nikitin.021973@postgrespro.ru", "phone": "+70078212664"}
0005434663308	11869E	0427 804830	ALEKSANDR FEDOROV	{"phone": "+70907504133"}
0005434663609	2FB592	1510 864373	ALEFTINA RYABOVA	{"phone": "+70884301923"}
0005434663309	DCA1A5	4240 058237	VLADIMIR IVANOV	{"email": "ivanov.v061974@postgrespro.ru", "phone": "+70080963582"}
0005434663310	292B44	3315 945443	LARISA KRASNOVA	{"phone": "+70198416005"}
0005434663311	292B44	7131 324553	ELENA VLASOVA	{"phone": "+70260158786"}
0005434663312	079489	3083 375937	NINA SOROKINA	{"email": "sorokinan06021974@postgrespro.ru", "phone": "+70221212240"}
0005434663313	4A34F3	9375 718512	POLINA TITOVA	{"phone": "+70423328655"}
0005434663314	A63CB9	6373 969347	VASILIY ISAEV	{"email": "isaevv.021964@postgrespro.ru", "phone": "+70377164037"}
0005434663315	D1752C	6499 716153	LEONID SOROKIN	{"email": "sorokin_l121971@postgrespro.ru", "phone": "+70691950683"}
0005434663316	D1752C	8547 537191	ALEKSANDR PETROV	{"email": "petrova1969@postgrespro.ru", "phone": "+70595833265"}
0005434663317	E29EF1	0239 686546	NIKOLAY ZAKHAROV	{"email": "zakharov-n-25011967@postgrespro.ru", "phone": "+70033760903"}
0005434663318	E29EF1	2953 497133	VITALIY VOLKOV	{"email": "volkov.v04091962@postgrespro.ru", "phone": "+70648291053"}
0005434663319	FB6F04	9344 408734	SERGEY ABRAMOV	{"email": "abramovs1971@postgrespro.ru", "phone": "+70664864433"}
0005434663320	1C4104	7119 410588	DENIS ALEKSANDROV	{"phone": "+70198884392"}
0005434663321	59FA88	5393 830969	TATYANA KUZNECOVA	{"email": "kuznecovat_061974@postgrespro.ru", "phone": "+70267577542"}
0005434663322	2A01BB	8993 247186	EKATERINA KOMAROVA	{"phone": "+70536731296"}
0005434663323	2A01BB	9070 002907	VIKTOR MEDVEDEV	{"email": "v_medvedev.1988@postgrespro.ru", "phone": "+70467753740"}
0005434663324	14E921	7087 791427	IRINA KUZNECOVA	{"phone": "+70333259867"}
0005434663325	14E921	7795 068445	GALINA CHERNOVA	{"email": "g_chernova091972@postgrespro.ru", "phone": "+70560680462"}
0005434663326	14E921	0689 359577	EVDOKIYA POPOVA	{"email": "e-popova101972@postgrespro.ru", "phone": "+70880673456"}
0005434663327	BA3F1F	9854 716563	YULIYA POPOVA	{"phone": "+70131696717"}
0005434663328	BA3F1F	1043 196779	RUSTAM SOLOVEV	{"phone": "+70273945658"}
0005434663329	F71F22	0103 830446	ALEKSANDR GORBUNOV	{"email": "gorbunov.a.1980@postgrespro.ru", "phone": "+70349662070"}
0005434663330	F71F22	4473 239352	SOFYA KISELEVA	{"email": "kiseleva_s-1985@postgrespro.ru", "phone": "+70306066436"}
0005434663331	88B2BD	6352 268730	ALEKSANDR SMIRNOV	{"email": "smirnov.a14111963@postgrespro.ru", "phone": "+70253202184"}
0005434663332	88B2BD	4568 723315	ARSENIY VASILEV	{"phone": "+70273458678"}
0005434663333	BADC2F	5646 781540	ELIZAVETA SEMENOVA	{"phone": "+70805059555"}
0005434663334	00A970	0341 753587	SERGEY KRASNOV	{"phone": "+70953396956"}
0005434663335	00A970	1847 559788	DMITRIY BELOV	{"email": "belov-dmitriy101963@postgrespro.ru", "phone": "+70970649775"}
0005434663336	CC9D39	8641 594292	MARINA IVANOVA	{"email": "ivanovamarina-28091970@postgrespro.ru", "phone": "+70281468590"}
0005434663337	1E9478	6319 741960	ARINA MELNIKOVA	{"phone": "+70550477771"}
0005434663338	1AFF98	0948 974653	ZINAIDA ABRAMOVA	{"phone": "+70720187397"}
0005434663339	7C6581	4829 466624	ALEKSANDR VASILEV	{"email": "aleksandrvasilev1960@postgrespro.ru", "phone": "+70601578646"}
0005434663340	7C6581	9252 904618	ANNA KOZLOVA	{"email": "anna_kozlova051971@postgrespro.ru", "phone": "+70633289186"}
0005434663341	7C6581	5556 206075	VALERIY DMITRIEV	{"email": "valeriy.dmitriev-021971@postgrespro.ru", "phone": "+70729873594"}
0005434663342	26C827	9612 848263	YULIYA FEDOROVA	{"phone": "+70920212545"}
0005434663343	34B9E7	9044 036357	ALEKSANDR BELOV	{"email": "belova_1965@postgrespro.ru", "phone": "+70168336841"}
0005434663344	34B9E7	1197 788159	RAIS KUDRYASHOV	{"email": "r_kudryashov_12041977@postgrespro.ru", "phone": "+70653669746"}
0005434663345	8374CC	9630 031788	DENIS ZHURAVLEV	{"phone": "+70124230009"}
0005434663347	3E677D	5526 461425	NATALIYA ZAKHAROVA	{"phone": "+70909277789"}
0005434663348	3E677D	2870 761001	SERGEY KONOVALOV	{"phone": "+70308112443"}
0005434663349	7B5670	8347 831611	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a101971@postgrespro.ru", "phone": "+70743159827"}
0005434663350	8F43F6	7242 601989	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr1991@postgrespro.ru", "phone": "+70792534063"}
0005434663351	8F43F6	8584 588058	VALENTINA DENISOVA	{"email": "denisova_v.28031962@postgrespro.ru", "phone": "+70754953349"}
0005434663352	476DB3	8956 191923	ZINAIDA MIKHAYLOVA	{"email": "mikhaylova.z.1983@postgrespro.ru", "phone": "+70469549941"}
0005434663353	4E9DEC	8184 172294	IVAN ILIN	{"email": "ivan-ilin081974@postgrespro.ru", "phone": "+70311709668"}
0005434663354	4E9DEC	4843 493602	SERGEY ZAYCEV	{"email": "sergey_zaycev-1972@postgrespro.ru", "phone": "+70593538629"}
0005434663355	4E9DEC	8638 241173	ALINA ROMANOVA	{"email": "romanova_a-1981@postgrespro.ru", "phone": "+70424501636"}
0005434663356	C50ADD	0436 908844	IVAN KUZMIN	{"email": "i.kuzmin051975@postgrespro.ru", "phone": "+70420251472"}
0005434663357	CC16D8	7639 967746	ANGELINA GAVRILOVA	{"email": "a_gavrilova_1981@postgrespro.ru", "phone": "+70104981534"}
0005434663358	C7EB26	4702 090235	LYUDMILA ILINA	{"email": "l-ilina_021975@postgrespro.ru", "phone": "+70049755827"}
0005434663359	2E31B2	4532 726437	TATYANA DAVYDOVA	{"email": "tdavydova.071977@postgrespro.ru", "phone": "+70987470917"}
0005434663360	EA3F62	6022 770330	FAINA ALEKSEEVA	{"phone": "+70099194355"}
0005434663361	EA3F62	9293 661973	DANIIL KUZNECOV	{"email": "kuznecov_d041969@postgrespro.ru", "phone": "+70915914883"}
0005434663362	B44334	2064 896343	SVETLANA ALEKSEEVA	{"email": "svetlana.alekseeva_1966@postgrespro.ru", "phone": "+70966097021"}
0005434663363	B44334	3042 263740	SVETLANA STEPANOVA	{"phone": "+70150316577"}
0005434663364	F36A6D	9933 202443	RIMMA ORLOVA	{"phone": "+70580886837"}
0005434663365	F36A6D	9996 564485	SERGEY BORISOV	{"email": "borisovs.1971@postgrespro.ru", "phone": "+70509418818"}
0005434663366	F36A6D	5635 430548	EVGENIYA ERMAKOVA	{"phone": "+70356851076"}
0005434663367	6E52A9	6293 845420	SERGEY AFANASEV	{"phone": "+70894585965"}
0005434663368	C65721	5553 959483	VERA POPOVA	{"phone": "+70753138357"}
0005434663369	92A4E0	4503 207959	ARTUR MIKHAYLOV	{"email": "mikhaylov-a_091978@postgrespro.ru", "phone": "+70188177902"}
0005434663370	8FA898	5629 283190	TATYANA LEBEDEVA	{"email": "t.lebedeva.20101977@postgrespro.ru", "phone": "+70099531596"}
0005434663371	8FA898	1522 181215	LYUDMILA SMIRNOVA	{"email": "smirnoval28091979@postgrespro.ru", "phone": "+70086138232"}
0005434663372	D50523	4245 030567	SOFIYA ILINA	{"email": "sofiya.ilina.1971@postgrespro.ru", "phone": "+70307290620"}
0005434663373	EC7096	5835 208645	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr051980@postgrespro.ru", "phone": "+70241367475"}
0005434663374	EC7096	0167 859773	VYACHESLAV IVANOV	{"phone": "+70397286004"}
0005434663597	2B60A7	4555 252769	VLADIMIR ISAEV	{"phone": "+70914076866"}
0005434663375	EC7096	9261 225632	FAINA NIKITINA	{"email": "nikitina-f.12071968@postgrespro.ru", "phone": "+70084371673"}
0005434663376	0D2C03	6486 180457	ELENA SCHERBAKOVA	{"email": "elena_scherbakova20061978@postgrespro.ru", "phone": "+70458718709"}
0005434663377	0D2C03	8048 104764	ANDREY ROMANOV	{"phone": "+70085048263"}
0005434663378	CDCFB2	8339 022079	ALEKSANDR GAVRILOV	{"email": "gavrilov.a_041971@postgrespro.ru", "phone": "+70871095464"}
0005434663379	301A9D	0901 699982	ANTON SIDOROV	{"email": "sidorov_anton-25091977@postgrespro.ru", "phone": "+70128095114"}
0005434663380	301A9D	7112 582233	EKATERINA ROMANOVA	{"phone": "+70583423563"}
0005434663381	301A9D	8163 040427	OLGA MOISEEVA	{"phone": "+70413901266"}
0005434663382	D804CC	3660 254143	ANASTASIYA PAVLOVA	{"phone": "+70250129337"}
0005434663383	3E5D77	5809 796268	VALENTINA IVANOVA	{"email": "valentina-ivanova041972@postgrespro.ru", "phone": "+70364626974"}
0005434663384	E31309	7974 434767	NADEZHDA KONOVALOVA	{"phone": "+70577925423"}
0005434663385	84D00A	8717 145540	SERGEY BONDARENKO	{"email": "sbondarenko1964@postgrespro.ru", "phone": "+70148424991"}
0005434663386	20B673	7774 423444	OLEG TIKHONOV	{"phone": "+70047517808"}
0005434663387	34BAE6	0892 296035	DMITRIY TIMOFEEV	{"email": "dmitriy_timofeev041976@postgrespro.ru", "phone": "+70569208696"}
0005434663388	62BFEB	8677 063881	NATALYA KULIKOVA	{"phone": "+70077633132"}
0005434663389	C4B29D	7521 939988	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev1967@postgrespro.ru", "phone": "+70175623250"}
0005434663390	3C64B3	7724 844930	KONSTANTIN NAUMOV	{"phone": "+70972148130"}
0005434663391	25F9FA	6144 669917	VALENTINA RYABOVA	{"email": "ryabova-v.101974@postgrespro.ru", "phone": "+70919093486"}
0005434663392	25F9FA	3730 150836	YULIYA GRISHINA	{"phone": "+70572153196"}
0005434663393	8B34EB	0328 238457	PETR IVANOV	{"phone": "+70850298125"}
0005434663394	06C80E	2795 868305	ALEKSEY ZAKHAROV	{"phone": "+70514946410"}
0005434663395	FD2F71	6179 661735	RITA KULIKOVA	{"email": "kulikovarita_041973@postgrespro.ru", "phone": "+70285854777"}
0005434663396	3C0AEE	1745 149221	VLADIMIR BORISOV	{"phone": "+70656224200"}
0005434663397	2D3143	0789 619855	VIKTOR BELOV	{"email": "v.belov.17051978@postgrespro.ru", "phone": "+70951068011"}
0005434663398	1E609D	0246 065412	FEDOR MIRONOV	{"phone": "+70447351373"}
0005434663399	6AB9BD	5507 961844	TATYANA OSIPOVA	{"email": "tatyana-osipova.081975@postgrespro.ru", "phone": "+70341029852"}
0005434663400	CF0A4F	3074 392726	DMITRIY MAKAROV	{"phone": "+70659834027"}
0005434663401	06082A	8112 737513	ELENA NIKOLAEVA	{"phone": "+70262802402"}
0005434663402	3F2B88	1056 697777	SERGEY PETROV	{"phone": "+70205139564"}
0005434663403	C37834	3270 317131	EVGENIYA KUZNECOVA	{"email": "e-kuznecova.1978@postgrespro.ru", "phone": "+70304954027"}
0005434663404	7ABEB4	1757 881963	SERGEY PETROV	{"phone": "+70297492464"}
0005434663405	B35F58	0661 161606	ELIZAVETA KOZLOVA	{"phone": "+70834992191"}
0005434663406	E11E1D	8411 682289	DANIL KUZNECOV	{"email": "d.kuznecov_091969@postgrespro.ru", "phone": "+70282593968"}
0005434663407	B33A5C	4364 799432	GALINA SOKOLOVA	{"email": "sokolova_galina031969@postgrespro.ru", "phone": "+70304189332"}
0005434663408	675D96	8256 262398	VLADIMIR SHEVCHENKO	{"phone": "+70976110626"}
0005434663409	995237	7246 659212	OLGA RODIONOVA	{"email": "o-rodionova.22041975@postgrespro.ru", "phone": "+70533772820"}
0005434663410	1C004B	9793 428186	ELENA MOISEEVA	{"phone": "+70286344532"}
0005434663411	1C004B	2769 504321	ILYA DENISOV	{"phone": "+70256730912"}
0005434663412	E362E6	3155 585394	NIKOLAY NOVIKOV	{"phone": "+70820867320"}
0005434663413	7E22F5	8163 993572	DMITRIY TARASOV	{"email": "d.tarasov.111977@postgrespro.ru", "phone": "+70375825963"}
0005434663414	00D573	4043 356333	ROMAN ANDREEV	{"phone": "+70521842808"}
0005434663415	F09261	4750 937005	ELENA DAVYDOVA	{"phone": "+70767121570"}
0005434663416	F09261	5875 513784	NINA FOMINA	{"email": "fomina.nina17021981@postgrespro.ru", "phone": "+70071018463"}
0005434663417	5E3F1D	9122 106232	ANDREY MARTYNOV	{"email": "martynovandrey_111972@postgrespro.ru", "phone": "+70627444244"}
0005434663418	F20AEA	2853 460516	SOFYA VOLKOVA	{"email": "s.volkova-021970@postgrespro.ru", "phone": "+70496765659"}
0005434663419	72DEDB	0211 945927	VALERIY DENISOV	{"email": "denisovvaleriy1970@postgrespro.ru", "phone": "+70500016453"}
0005434663420	6A775D	1395 856118	ZINAIDA GERASIMOVA	{"phone": "+70830613487"}
0005434663421	2F6262	0843 685366	ANNA SMIRNOVA	{"phone": "+70699933928"}
0005434663422	2F6262	8256 885862	LYUDMILA KOVALEVA	{"email": "kovalevalyudmila28031979@postgrespro.ru", "phone": "+70784924998"}
0005434663423	2F6262	8031 192965	EGOR SEMENOV	{"email": "e_semenov.20121982@postgrespro.ru", "phone": "+70742033633"}
0005434663424	7C136F	2002 714923	YURIY MOROZOV	{"email": "morozov_y-101969@postgrespro.ru", "phone": "+70882487599"}
0005434663425	7C136F	7483 760334	RINAT NOVIKOV	{"phone": "+70028609350"}
0005434663426	7C136F	0492 923031	VIKTORIYA ZAYCEVA	{"phone": "+70219638549"}
0005434663427	8B8BAF	8776 282945	IVAN KOROLEV	{"email": "ivan_korolev_29031964@postgrespro.ru", "phone": "+70893298472"}
0005434663428	8B8BAF	6789 965965	ALEKSANDRA LAZAREVA	{"phone": "+70918985633"}
0005434663430	BC1818	2439 481622	ALEKSANDRA STEPANOVA	{"email": "aleksandra-stepanova27071969@postgrespro.ru", "phone": "+70528447597"}
0005434663431	99D06A	4398 333230	LYUDMILA ALEKSANDROVA	{"phone": "+70268148861"}
0005434663432	E95706	1265 140857	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir_1969@postgrespro.ru", "phone": "+70771595713"}
0005434663433	E2FE8D	5882 561695	RAISA ORLOVA	{"email": "orlova.raisa_051974@postgrespro.ru", "phone": "+70400775228"}
0005434663434	E2FE8D	7620 286182	VERA SOKOLOVA	{"phone": "+70150739519"}
0005434663435	A83912	0282 162407	MIKHAIL ZHUKOV	{"email": "zhukov.m1965@postgrespro.ru", "phone": "+70029761775"}
0005434663436	A83912	8764 526317	OLEG MOISEEV	{"email": "olegmoiseev-1962@postgrespro.ru", "phone": "+70119062911"}
0005434663437	25148B	8612 189630	YULIYA MAKAROVA	{"email": "yuliya-makarova.1972@postgrespro.ru", "phone": "+70163962950"}
0005434663438	25148B	4231 107138	RAISA YAKOVLEVA	{"email": "ryakovleva-101978@postgrespro.ru", "phone": "+70233136885"}
0005434663439	B135D3	1843 001389	LYUDMILA KOZLOVA	{"phone": "+70147087018"}
0005434663440	8B5ACC	5166 022783	OLGA ABRAMOVA	{"phone": "+70831158016"}
0005434663441	68FF9C	0041 773611	NINA BELYAEVA	{"phone": "+70949973289"}
0005434663442	7B6A80	1701 649753	VIKTORIYA BOGDANOVA	{"phone": "+70753895819"}
0005434663443	7B6A80	9223 432450	EVGENIY POPOV	{"email": "popov-e_011967@postgrespro.ru", "phone": "+70110620084"}
0005434663444	C0A207	2677 454017	EVA ARKHIPOVA	{"email": "arkhipovae_091978@postgrespro.ru", "phone": "+70280706566"}
0005434663445	E1C527	3361 537640	NADEZHDA PETROVA	{"phone": "+70443553560"}
0005434663446	F1C496	3764 807067	TATYANA FROLOVA	{"phone": "+70554677175"}
0005434663447	F1C496	1705 860221	ALEKSEY NOVIKOV	{"phone": "+70383639902"}
0005434663448	507AED	3650 713273	SERGEY ZAKHAROV	{"email": "zakharov-sergey111986@postgrespro.ru", "phone": "+70181825906"}
0005434663449	1DE3B3	7082 776925	EKATERINA TROFIMOVA	{"email": "ekaterinatrofimova_1971@postgrespro.ru", "phone": "+70230473757"}
0005434663450	1DE3B3	1980 530457	ANNA TITOVA	{"email": "anna.titova_1968@postgrespro.ru", "phone": "+70166986974"}
0005434663451	36D706	8121 443779	NIKOLAY SEMENOV	{"email": "n_semenov_011977@postgrespro.ru", "phone": "+70738927813"}
0005434663452	36D706	4488 124568	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr101973@postgrespro.ru", "phone": "+70920732899"}
0005434663453	E4E99F	1324 063931	EKATERINA SOLOVEVA	{"phone": "+70252303049"}
0005434663454	E4E99F	0892 843233	ANASTASIYA PAVLOVA	{"email": "a.pavlova.1969@postgrespro.ru", "phone": "+70939891104"}
0005434663455	4EAE93	7417 648886	VLADIMIR SOKOLOV	{"phone": "+70410196736"}
0005434663456	52F967	4451 362589	RUSLAN SIDOROV	{"phone": "+70379731893"}
0005434663457	3932F7	8038 339221	RINAT GRIGOREV	{"email": "grigorev-rinat-1973@postgrespro.ru", "phone": "+70199525105"}
0005434663458	3932F7	9097 794358	VIKTOR EGOROV	{"phone": "+70284478320"}
0005434663459	A4FF83	5861 673307	TATYANA NAZAROVA	{"phone": "+70448473353"}
0005434663460	794E0F	3350 240380	VERA MAKSIMOVA	{"email": "maksimova.v.1962@postgrespro.ru", "phone": "+70910455017"}
0005434663461	E8E067	9181 528574	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr_101980@postgrespro.ru", "phone": "+70348619187"}
0005434663462	E8E067	9071 901801	ALEVTINA PAVLOVA	{"email": "pavlova.alevtina28091967@postgrespro.ru", "phone": "+70569874154"}
0005434663463	B0476B	3843 630276	ANASTASIYA NAZAROVA	{"phone": "+70717532712"}
0005434663464	B0476B	6796 021760	OLGA ZOTOVA	{"email": "zotova-olga111986@postgrespro.ru", "phone": "+70895385672"}
0005434663465	0944C6	6636 219432	GALINA POLYAKOVA	{"email": "gpolyakova_121974@postgrespro.ru", "phone": "+70185176117"}
0005434663466	0944C6	1362 754410	VLADIMIR BONDARENKO	{"phone": "+70144266172"}
0005434663467	B97D0B	4375 321942	SOFIYA SCHERBAKOVA	{"phone": "+70801823129"}
0005434663468	B97D0B	8889 364240	MARIYA POPOVA	{"email": "mariya.popova111972@postgrespro.ru", "phone": "+70601503423"}
0005434663469	C2219D	2945 395226	ALEKSANDR ALEKSANDROV	{"phone": "+70223463796"}
0005434663470	0EF2AE	7696 468694	ALEKSANDR SIDOROV	{"phone": "+70436406248"}
0005434663471	81DC2E	4077 703587	MARIYA KRASNOVA	{"email": "krasnova_mariya-1977@postgrespro.ru", "phone": "+70166904212"}
0005434663472	1EB4F0	2194 941571	DMITRIY MARTYNOV	{"phone": "+70351841684"}
0005434663473	EB2B29	9179 417076	VIKTOR VASILEV	{"email": "v-vasilev-071979@postgrespro.ru", "phone": "+70032078513"}
0005434663474	4EAC6F	3143 492404	NIKOLAY KUZMIN	{"email": "nkuzmin14081979@postgrespro.ru", "phone": "+70550009913"}
0005434663475	43259A	0129 928052	NATALYA SEMENOVA	{"phone": "+70018370803"}
0005434663476	166485	3304 082471	PAVEL SOLOVEV	{"phone": "+70126851250"}
0005434663477	166485	2222 752920	TATYANA STEPANOVA	{"email": "tatyanastepanova-051981@postgrespro.ru", "phone": "+70968058167"}
0005434663478	824640	4333 177441	ALEKSEY SHEVCHENKO	{"email": "shevchenko_aleksey-28121973@postgrespro.ru", "phone": "+70135268489"}
0005434663479	824640	5932 753543	VIKTOR KOZLOV	{"phone": "+70534633987"}
0005434663480	B1E488	9270 912391	TATYANA SOROKINA	{"email": "tatyana_sorokina_1968@postgrespro.ru", "phone": "+70054197778"}
0005434663481	F5CB2F	8916 674143	ALEKSANDRA KULIKOVA	{"phone": "+70881237211"}
0005434663482	F5CB2F	6438 271094	LYUDMILA SERGEEVA	{"phone": "+70677035935"}
0005434663483	F5CB2F	0941 390135	SVETLANA SEMENOVA	{"email": "s-semenova.02031974@postgrespro.ru", "phone": "+70769470923"}
0005434663484	51DA4F	3348 957772	SVETLANA ANDREEVA	{"email": "andreeva-svetlana121972@postgrespro.ru", "phone": "+70301285066"}
0005434663485	51DA4F	7030 823871	GALINA MATVEEVA	{"email": "matveevag091973@postgrespro.ru", "phone": "+70147353187"}
0005434663486	72085C	8251 485995	EVGENIY MAKAROV	{"email": "makarovevgeniy.31011977@postgrespro.ru", "phone": "+70678798430"}
0005434663487	72085C	3044 400776	YULIYA CHERNOVA	{"email": "y.chernova1968@postgrespro.ru", "phone": "+70695337577"}
0005434663488	72085C	7392 369527	VIKTOR MAKAROV	{"email": "makarovviktor.1980@postgrespro.ru", "phone": "+70541816361"}
0005434663489	0BCF23	4934 689603	MIKHAIL IVANOV	{"email": "m-ivanov_05011973@postgrespro.ru", "phone": "+70381555710"}
0005434663490	964FB4	6295 511169	VYACHESLAV ZAKHAROV	{"phone": "+70279538441"}
0005434663491	887F50	1978 353058	OLEG SOLOVEV	{"phone": "+70857188536"}
0005434663492	1E56AE	1048 338826	ELENA NESTEROVA	{"email": "elena.nesterova-081967@postgrespro.ru", "phone": "+70641288134"}
0005434663493	55CC08	5206 375862	TATYANA KUZNECOVA	{"phone": "+70474923671"}
0005434663494	F75635	7926 211707	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.vladimir_031971@postgrespro.ru", "phone": "+70955148584"}
0005434663495	F75635	1813 425462	SOFYA SMIRNOVA	{"email": "s-smirnova_14041970@postgrespro.ru", "phone": "+70274354713"}
0005434663496	0A115F	4768 893938	VASILIY IVANOV	{"email": "ivanov.v-091970@postgrespro.ru", "phone": "+70102268937"}
0005434663497	0A115F	1777 825137	YURIY GUSEV	{"phone": "+70926056992"}
0005434663498	0A115F	0541 884071	TATYANA EGOROVA	{"email": "t.egorova22061975@postgrespro.ru", "phone": "+70400690708"}
0005434663499	EA5A34	6899 746388	LIDIYA ZAKHAROVA	{"phone": "+70236248313"}
0005434663500	EA5A34	5666 875146	TATYANA SOKOLOVA	{"email": "t-sokolova-16041979@postgrespro.ru", "phone": "+70044078925"}
0005434663501	EA5A34	5125 313642	GALINA LAZAREVA	{"phone": "+70477891110"}
0005434663502	B77D9E	2791 855569	ALEKSANDR VOLKOV	{"email": "volkovaleksandr-1974@postgrespro.ru", "phone": "+70983391792"}
0005434663503	223FEB	7592 784268	ELENA MOROZOVA	{"phone": "+70642017572"}
0005434663504	F0DE6C	9344 001023	TATYANA TROFIMOVA	{"phone": "+70288998028"}
0005434663505	F0DE6C	7087 727728	IVAN SAVELEV	{"phone": "+70522814925"}
0005434663506	219D41	2311 038745	VLADIMIR TIMOFEEV	{"email": "timofeev_v-1962@postgrespro.ru", "phone": "+70274302711"}
0005434663507	D91DAD	1812 050550	EVGENIYA PETROVA	{"email": "petrova-evgeniya1977@postgrespro.ru", "phone": "+70314601509"}
0005434663508	56EA22	9476 700923	LIDIYA YAKOVLEVA	{"phone": "+70465890559"}
0005434663509	56EA22	6489 164550	ANASTASIYA SMIRNOVA	{"email": "a_smirnova.1979@postgrespro.ru", "phone": "+70736633265"}
0005434663510	8084BC	9269 840381	LYUBOV LAZAREVA	{"phone": "+70401337647"}
0005434663511	7C83F5	1484 855446	YULIYA KOMAROVA	{"email": "komarova.yuliya.06101979@postgrespro.ru", "phone": "+70665542772"}
0005434663512	C4FED7	3545 128363	VLADIMIR IVANOV	{"phone": "+70938602852"}
0005434663513	06875C	8917 421901	ELENA ANTONOVA	{"email": "elena-antonova.101985@postgrespro.ru", "phone": "+70419639142"}
0005434663514	D34AE0	3076 938332	NATALYA YAKOVLEVA	{"email": "n.yakovleva121977@postgrespro.ru", "phone": "+70110443210"}
0005434663515	D34AE0	0327 448868	NURIYA MALYSHEVA	{"email": "nuriya-malysheva111977@postgrespro.ru", "phone": "+70554357706"}
0005434663516	D34AE0	0606 173249	ELENA TITOVA	{"email": "elena-titova121970@postgrespro.ru", "phone": "+70860204067"}
0005434663517	8468F5	1487 099473	VLADIMIR NAUMOV	{"phone": "+70791984462"}
0005434663518	FA5269	4849 983221	LYUBOV MATVEEVA	{"email": "lyubov_matveeva-24061971@postgrespro.ru", "phone": "+70024269958"}
0005434663519	030549	0018 890540	VLADIMIR STEPANOV	{"email": "stepanovvladimir_071971@postgrespro.ru", "phone": "+70996608174"}
0005434663520	D72593	3064 025816	VALENTINA MAKAROVA	{"email": "makarova.valentina.111981@postgrespro.ru", "phone": "+70547524487"}
0005434663521	4982B4	0966 019402	VALENTINA KRASNOVA	{"phone": "+70017370928"}
0005434663522	C11F5E	7098 323728	NATALIYA LAZAREVA	{"email": "nlazareva.051983@postgrespro.ru", "phone": "+70098814457"}
0005434663523	9AE02C	5979 288045	NIKOLAY POPOV	{"phone": "+70918510152"}
0005434663524	A3B86D	3586 271907	KLAVDIYA AFANASEVA	{"phone": "+70966582431"}
0005434663525	E5E42A	5547 668516	VASILIY KUZMIN	{"email": "vasiliy-kuzmin.1982@postgrespro.ru", "phone": "+70308547328"}
0005434663526	E54117	8245 194870	VALENTINA YAKOVLEVA	{"phone": "+70867858976"}
0005434663527	256E3C	3289 483874	YULIYA ARKHIPOVA	{"phone": "+70790875503"}
0005434663528	186BC8	7979 243812	TATYANA DAVYDOVA	{"email": "t-davydova1971@postgrespro.ru", "phone": "+70821784439"}
0005434663529	E8BAC7	0300 149478	VLADIMIR SIDOROV	{"email": "sidorov-vladimir.08041973@postgrespro.ru", "phone": "+70723615579"}
0005434663530	820ACF	7191 747532	VERA DENISOVA	{"email": "vera-denisova-21101970@postgrespro.ru", "phone": "+70941251157"}
0005434663531	445867	1561 248440	SERGEY EGOROV	{"phone": "+70215393580"}
0005434663532	1A6CB2	3710 524915	VLADIMIR SEMENOV	{"email": "semenov.v021970@postgrespro.ru", "phone": "+70059810039"}
0005434663533	542839	8269 019195	NIKOLAY PAVLOV	{"phone": "+70329007770"}
0005434663534	2FB0ED	8281 578286	NATALYA DAVYDOVA	{"email": "davydova.n_041962@postgrespro.ru", "phone": "+70946855168"}
0005434663535	B12848	1892 857302	STANISLAV SOROKIN	{"phone": "+70858651088"}
0005434663536	F294C3	4367 391476	OLGA BARANOVA	{"phone": "+70134570401"}
0005434663537	30A5AE	5534 766909	VLADIMIR POPOV	{"phone": "+70353438224"}
0005434663538	8D69F6	4169 879417	LYUBOV SIDOROVA	{"phone": "+70692115750"}
0005434663539	8D69F6	8739 415334	MIKHAIL CHERNOV	{"phone": "+70188846834"}
0005434663540	8D69F6	4553 210018	VADIM KUZMIN	{"phone": "+70906810503"}
0005434663541	4F730E	9630 030016	YURIY BARANOV	{"phone": "+70968823792"}
0005434663542	4F730E	6114 519426	MARIYA FROLOVA	{"email": "frolovam.091963@postgrespro.ru", "phone": "+70647556568"}
0005434663543	DCFE81	4831 686150	NIKOLAY BARANOV	{"email": "n_baranov_30101968@postgrespro.ru", "phone": "+70935637518"}
0005434663544	35B3AD	7116 294375	ALEKSANDR KUZNECOV	{"phone": "+70685347077"}
0005434663545	7CE2BA	2341 659721	NIKOLAY ROMANOV	{"phone": "+70571835666"}
0005434663546	7CE2BA	2394 130899	SERGEY MOROZOV	{"phone": "+70457386142"}
0005434663547	C7F37E	0643 942864	MARIYA ANDREEVA	{"email": "mariya-andreeva.111967@postgrespro.ru", "phone": "+70882882251"}
0005434663548	95AF9B	8409 481933	VALERIY MOROZOV	{"email": "v.morozov.04051971@postgrespro.ru", "phone": "+70671760407"}
0005434663549	C25EF1	2754 987735	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova-1957@postgrespro.ru", "phone": "+70924493014"}
0005434663550	6AFC90	7042 811113	ALFIYA NAZAROVA	{"phone": "+70977232326"}
0005434663551	939C6E	5623 360579	NINA TIMOFEEVA	{"phone": "+70206557207"}
0005434663552	939C6E	0370 177980	SERGEY ABRAMOV	{"email": "abramov_s071965@postgrespro.ru", "phone": "+70052713525"}
0005434663553	31A2EF	6856 786804	IRINA AFANASEVA	{"email": "afanaseva-irina_041974@postgrespro.ru", "phone": "+70643677489"}
0005434663554	15C2D1	0458 947307	MAKSIM KOZLOV	{"phone": "+70914122866"}
0005434663555	15C2D1	2735 419035	VALENTINA ANDREEVA	{"phone": "+70977072177"}
0005434663556	C6B28B	8458 024851	PAVEL VASILEV	{"email": "vasilev.p.061972@postgrespro.ru", "phone": "+70551206719"}
0005434663557	C6B28B	9144 331241	VERA ROMANOVA	{"phone": "+70076136143"}
0005434663558	29BFA6	7935 174852	TATYANA FROLOVA	{"email": "frolovatatyana-06101978@postgrespro.ru", "phone": "+70435462988"}
0005434663559	26D03A	2796 014608	TATYANA BELOVA	{"phone": "+70531849859"}
0005434663560	A09E7E	7260 525622	ELENA KAZAKOVA	{"email": "kazakova.elena1977@postgrespro.ru", "phone": "+70455656029"}
0005434663561	92FDE4	0764 084713	SERGEY TARASOV	{"email": "tarasov_s031962@postgrespro.ru", "phone": "+70613110982"}
0005434663562	ABF07F	3188 861569	NAIL NIKOLAEV	{"email": "nikolaevnail-101970@postgrespro.ru", "phone": "+70134542593"}
0005434663563	ABF07F	6559 187186	SERGEY SERGEEV	{"email": "sergeev_s-021973@postgrespro.ru", "phone": "+70939185000"}
0005434663564	BC80F2	6238 970561	DAVID SEMENOV	{"email": "semenov-d15101971@postgrespro.ru", "phone": "+70993471776"}
0005434663565	44A912	4547 229090	SVETLANA NESTEROVA	{"email": "nesterova-s06031981@postgrespro.ru", "phone": "+70602471909"}
0005434663566	44A912	3156 178141	LIDIYA KONOVALOVA	{"phone": "+70264903442"}
0005434663567	E5F541	6560 323260	NATALYA KOVALEVA	{"email": "kovaleva.natalya.061968@postgrespro.ru", "phone": "+70905837266"}
0005434663568	E5F541	3951 515622	KONSTANTIN STEPANOV	{"email": "stepanovkonstantin-28111968@postgrespro.ru", "phone": "+70221092996"}
0005434663569	E5F541	2704 922992	ELENA ROMANOVA	{"email": "elena.romanova.1965@postgrespro.ru", "phone": "+70268020849"}
0005434663570	B415D0	5961 742130	KIRILL SOKOLOV	{"email": "sokolov-k_011973@postgrespro.ru", "phone": "+70343574434"}
0005434663571	B415D0	9326 223488	EVGENIYA EFREMOVA	{"phone": "+70094629335"}
0005434663572	EE4593	6224 994328	VALENTINA MIRONOVA	{"email": "mironova_valentina_091987@postgrespro.ru", "phone": "+70504454468"}
0005434663573	EE4593	3457 863853	ELENA TIMOFEEVA	{"email": "e-timofeeva121967@postgrespro.ru", "phone": "+70852262952"}
0005434663574	F7A940	5162 467779	LIDIYA NAZAROVA	{"phone": "+70679363265"}
0005434663575	2A05D6	2391 400259	SVETLANA VOROBEVA	{"email": "s-vorobeva1971@postgrespro.ru", "phone": "+70178505307"}
0005434663576	B0ABAE	2929 348069	OLGA NOVIKOVA	{"phone": "+70413886945"}
0005434663577	B0ABAE	3067 968129	VALENTINA KALININA	{"phone": "+70728129883"}
0005434663578	53FA7B	2670 562027	ELENA DENISOVA	{"email": "e-denisova1976@postgrespro.ru", "phone": "+70550337824"}
0005434663579	53FA7B	6616 586445	VITALIY DMITRIEV	{"phone": "+70579920826"}
0005434663580	C7A7E9	4210 439257	DANIS GUSEV	{"email": "gusev_danis_061972@postgrespro.ru", "phone": "+70076933863"}
0005434663581	2CDFAF	4569 923646	ALEKSANDR OSIPOV	{"email": "a.osipov06101971@postgrespro.ru", "phone": "+70258505237"}
0005434663582	2CDFAF	6914 467476	NINA VOLKOVA	{"email": "volkovan.031984@postgrespro.ru", "phone": "+70054423455"}
0005434663583	6695E9	9241 718335	RAISA NAZAROVA	{"email": "raisa.nazarova-071961@postgrespro.ru", "phone": "+70505987559"}
0005434663584	6695E9	1378 813825	SVETLANA ROMANOVA	{"phone": "+70127777379"}
0005434663585	C34D4C	7751 204614	NINA IVANOVA	{"phone": "+70672430411"}
0005434663586	1F0871	8432 246148	IRINA NAZAROVA	{"email": "nazarova_i1971@postgrespro.ru", "phone": "+70090164888"}
0005434663587	831343	1903 860821	ROMAN ANDREEV	{"email": "andreev_r-081966@postgrespro.ru", "phone": "+70883553498"}
0005434663588	91C63B	5753 243680	VLADIMIR SERGEEV	{"phone": "+70408538616"}
0005434663589	0FD02A	3090 716410	ANASTASIYA FILATOVA	{"email": "filatova_a.06111978@postgrespro.ru", "phone": "+70979257530"}
0005434663590	4D4EDA	5728 677289	TATYANA NIKOLAEVA	{"phone": "+70118210348"}
0005434663591	E8FAB9	4557 855387	ANNA ISAEVA	{"email": "isaeva_a-031984@postgrespro.ru", "phone": "+70772157834"}
0005434663592	F6C8CE	0358 334605	KLARA YAKOVLEVA	{"phone": "+70122226363"}
0005434663593	2C8DC0	3829 679480	IVAN ZHURAVLEV	{"phone": "+70218457203"}
0005434663594	2C8DC0	1481 746535	VALENTIN KULIKOV	{"phone": "+70206906421"}
0005434663595	135B62	3345 688225	NATALIYA POTAPOVA	{"email": "potapovanataliya.1987@postgrespro.ru", "phone": "+70652860363"}
0005434663596	2B60A7	8504 759810	ANDREY DMITRIEV	{"email": "andrey_dmitriev_1968@postgrespro.ru", "phone": "+70172427112"}
0005434663598	9E7D07	9407 364986	MARIYA KOROLEVA	{"phone": "+70973830333"}
0005434663599	333A11	6901 989593	ANNA KONOVALOVA	{"email": "a_konovalova-19051965@postgrespro.ru", "phone": "+70275825860"}
0005434663600	D63AC3	5526 984353	YURIY OSIPOV	{"email": "y-osipov_1973@postgrespro.ru", "phone": "+70720955570"}
0005434663601	D63AC3	1511 605718	ALEKSANDR SERGEEV	{"phone": "+70912102866"}
0005434663602	5439F9	5047 676557	IGOR MATVEEV	{"phone": "+70706883397"}
0005434663603	DF227B	2140 664464	ELENA KISELEVA	{"phone": "+70349909140"}
0005434663604	808C8D	7224 949680	SERGEY BONDARENKO	{"phone": "+70749645295"}
0005434663605	70DB6A	6199 734233	OLEG VOLKOV	{"phone": "+70334829080"}
0005434663606	70DB6A	1287 259396	MIKHAIL MELNIKOV	{"email": "mikhail_melnikov_05031976@postgrespro.ru", "phone": "+70656609453"}
0005434663607	2FB592	4065 098950	YAROSLAVA BARANOVA	{"email": "baranovayaroslava-1956@postgrespro.ru", "phone": "+70446467479"}
0005434663608	2FB592	7623 832828	VALENTINA ANTONOVA	{"email": "antonova.valentina051962@postgrespro.ru", "phone": "+70928790293"}
0005434663610	2FB592	3659 373459	VALENTINA YAKOVLEVA	{"phone": "+70100326569"}
0005434663611	87B031	6853 526660	DMITRIY VLASOV	{"phone": "+70871924680"}
0005434663612	C42F47	8053 113989	ANTON DAVYDOV	{"email": "davydov-a1976@postgrespro.ru", "phone": "+70960509122"}
0005434663613	01F5AA	4241 919964	VALERIYA FILATOVA	{"email": "valeriya-filatova.16081985@postgrespro.ru", "phone": "+70259879478"}
0005434663614	2B2F9F	3774 849642	RASHID ILIN	{"phone": "+70049877293"}
0005434663615	BB746B	5971 714908	EVGENIY VASILEV	{"email": "vasilevevgeniy.031967@postgrespro.ru", "phone": "+70232845439"}
0005434663616	8B7CEE	1090 670492	SERGEY KUZNECOV	{"email": "s_kuznecov.20041975@postgrespro.ru", "phone": "+70009364234"}
0005434663617	E53EAA	9217 212818	SERGEY FROLOV	{"email": "frolov.s_08091978@postgrespro.ru", "phone": "+70610880162"}
0005434663618	E53EAA	4864 835035	MAKSIM NOVIKOV	{"phone": "+70723538667"}
0005434663619	8B4112	1894 072178	ANATOLIY BARANOV	{"email": "abaranov.031968@postgrespro.ru", "phone": "+70304473667"}
0005434663620	8B4112	5184 693743	ALEKSANDR EGOROV	{"email": "aleksandr.egorov_1965@postgrespro.ru", "phone": "+70916309847"}
0005434663621	744565	4765 142122	MARIYA TIKHONOVA	{"email": "tikhonova_mariya-061974@postgrespro.ru", "phone": "+70847985008"}
0005434663622	744565	5058 288880	ARTEM PAVLOV	{"phone": "+70307566667"}
0005434663623	CFA7DE	3148 493112	VALERIY MOROZOV	{"email": "v.morozov-06091973@postgrespro.ru", "phone": "+70087817633"}
0005434663624	99C4FF	7979 910413	KAPITALINA MELNIKOVA	{"phone": "+70096827037"}
0005434663625	99C4FF	5222 891123	YULIYA FOMINA	{"email": "fomina-y_25041968@postgrespro.ru", "phone": "+70907596583"}
0005434663626	F8BED7	5070 775707	LIDIYA GUSEVA	{"email": "lguseva-1972@postgrespro.ru", "phone": "+70576189420"}
0005434663627	F8BED7	5586 064856	MARIYA SEMENOVA	{"phone": "+70544782426"}
0005434663628	A741CA	4922 264844	GALINA ZAKHAROVA	{"email": "galina-zakharova-101971@postgrespro.ru", "phone": "+70821770741"}
0005434663629	A741CA	4072 102577	YURIY KUZNECOV	{"email": "kuznecov-yuriy.071971@postgrespro.ru", "phone": "+70540189277"}
0005434663630	D776C0	0544 223895	ALEKSEY KISELEV	{"phone": "+70105921796"}
0005434663631	D776C0	9149 308906	NATALYA MAKSIMOVA	{"phone": "+70375183109"}
0005434663632	EC38EA	6070 566741	TATYANA GUSEVA	{"email": "tatyanaguseva_27031973@postgrespro.ru", "phone": "+70613963761"}
0005434663633	454DBF	7062 629851	IRINA AFANASEVA	{"email": "i.afanaseva24041972@postgrespro.ru", "phone": "+70111071841"}
0005434663634	F2221B	2870 189221	GENNADIY IVANOV	{"phone": "+70402231905"}
0005434663635	F2221B	1976 287310	GRIGORIY ZAYCEV	{"email": "grigoriy.zaycev1973@postgrespro.ru", "phone": "+70964202518"}
0005434663636	C8EBBB	6244 807066	ALEKSEY KONOVALOV	{"phone": "+70965359887"}
0005434663637	22D0B5	4291 971075	SERGEY OSIPOV	{"phone": "+70310778335"}
0005434663638	019ECE	7876 221628	OLESYA FILIPPOVA	{"phone": "+70212735271"}
0005434663639	3E54EB	1124 437442	ALEKSEY VLASOV	{"phone": "+70559496541"}
0005434663640	673594	2552 898715	ANATOLIY SMIRNOV	{"phone": "+70743261494"}
0005434663641	20569E	2175 941693	NIKOLAY MEDVEDEV	{"email": "nikolay_medvedev.02091986@postgrespro.ru", "phone": "+70977679167"}
0005434663642	4AC967	9996 690498	VITALIY CHERNOV	{"phone": "+70906471785"}
0005434663643	4AC967	6914 671289	ELENA ABRAMOVA	{"phone": "+70912970902"}
0005434663644	CCEFBB	0967 061274	IGOR NIKITIN	{"email": "nikitin_i-111969@postgrespro.ru", "phone": "+70462916423"}
0005434663645	CCEFBB	2326 973359	LIDIYA GERASIMOVA	{"email": "lidiya_gerasimova1987@postgrespro.ru", "phone": "+70646834101"}
0005434663646	C9719D	7763 257056	VIKTOR CHERNOV	{"email": "viktor.chernov_1964@postgrespro.ru", "phone": "+70169724820"}
0005434663647	C9719D	9853 677386	TATYANA KOMAROVA	{"email": "komarovatatyana-1980@postgrespro.ru", "phone": "+70081921487"}
0005434663648	5A0D30	1304 382042	OLGA VASILEVA	{"phone": "+70346234098"}
0005434663649	256229	5608 089452	ANDREY FOMIN	{"phone": "+70692170563"}
0005434663650	AAD4C8	7929 279938	LYUDMILA ZAKHAROVA	{"email": "lyudmila-zakharova1963@postgrespro.ru", "phone": "+70092083538"}
0005434663651	AAD4C8	7903 526041	VERONIKA ANDREEVA	{"phone": "+70916100159"}
0005434663652	0145A0	6723 325686	LYUDMILA POTAPOVA	{"phone": "+70479325356"}
0005434663653	0145A0	2660 188983	ALEKSANDR KULIKOV	{"email": "a_kulikov121975@postgrespro.ru", "phone": "+70804348677"}
0005434663654	A71FAF	0762 378419	NIKITA SIDOROV	{"phone": "+70265148589"}
0005434663655	98730B	2803 491885	MIKHAIL FILIPPOV	{"phone": "+70172123658"}
0005434663656	082FAA	7162 182737	NATALIYA FROLOVA	{"email": "nataliyafrolova-12021973@postgrespro.ru", "phone": "+70059036645"}
0005434663657	EB5805	1866 146918	IGOR NIKOLAEV	{"phone": "+70812514620"}
0005434663658	EB5805	4054 778280	IVAN SHEVCHENKO	{"email": "shevchenko.i-19111973@postgrespro.ru", "phone": "+70676288386"}
0005434663659	9A27EB	6421 265203	NIKITA KISELEV	{"phone": "+70484801709"}
0005434663660	9A27EB	6513 394771	MARIYA KARPOVA	{"phone": "+70479775127"}
0005434663661	C95FB6	6844 509839	RAISA ZAKHAROVA	{"email": "zakharova.raisa.12111965@postgrespro.ru", "phone": "+70813314712"}
0005434663662	2963F7	2444 373063	VLADIMIR ISAEV	{"email": "isaev.vladimir.13121981@postgrespro.ru", "phone": "+70321968760"}
0005434663663	92CFD1	4446 848337	ELIZAVETA POTAPOVA	{"email": "potapovae-1971@postgrespro.ru", "phone": "+70169915987"}
0005434663664	719AC0	7411 282057	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev_111988@postgrespro.ru", "phone": "+70032158004"}
0005434663665	67DEBA	5865 342024	ALEKSANDR MIKHAYLOV	{"phone": "+70891633879"}
0005434663666	DEC1A3	6867 826516	EVGENIY EGOROV	{"email": "egorov.evgeniy-20111970@postgrespro.ru", "phone": "+70284020033"}
0005434663667	FC120D	6142 367869	MARINA ALEKSEEVA	{"email": "alekseeva-marina-1974@postgrespro.ru", "phone": "+70771269131"}
0005434663668	30DF4D	9845 725833	DENIS KOROLEV	{"email": "korolevd-091979@postgrespro.ru", "phone": "+70289410885"}
0005434665017	B80D20	3969 216760	VERA ZAKHAROVA	{"phone": "+70258384017"}
0005434663669	5CEBE2	1309 413722	ELENA ANDREEVA	{"email": "andreeva.elena-1970@postgrespro.ru", "phone": "+70384946261"}
0005434663670	5CEBE2	7849 131097	VYACHESLAV VASILEV	{"email": "v-vasilev_15011962@postgrespro.ru", "phone": "+70145846271"}
0005434663671	E98451	6041 203730	TATYANA ZOTOVA	{"phone": "+70073297592"}
0005434663672	AA0C44	0061 624991	ALEKSANDR ANTONOV	{"email": "aantonov_1974@postgrespro.ru", "phone": "+70633524267"}
0005434663673	AA0C44	4563 215421	VYACHESLAV GRIGOREV	{"phone": "+70909817876"}
0005434663674	AA0C44	7809 518887	ELIZAVETA MIRONOVA	{"phone": "+70990465202"}
0005434663675	B04877	6886 454534	ALEKSANDR SCHERBAKOV	{"phone": "+70552234782"}
0005434663676	DB0183	9417 224559	NIKITA NAZAROV	{"email": "nnazarov_101967@postgrespro.ru", "phone": "+70223715611"}
0005434663677	DB0183	8665 685358	ALEKSEY MATVEEV	{"email": "matveev_a10081975@postgrespro.ru", "phone": "+70239513094"}
0005434663678	CDEBA5	2068 225160	SERGEY ZAKHAROV	{"email": "zakharov-s.19031962@postgrespro.ru", "phone": "+70280558730"}
0005434663679	E5BEF9	2436 961562	ALSU YAKOVLEVA	{"email": "yakovleva.alsu_121980@postgrespro.ru", "phone": "+70168557675"}
0005434663680	E5BEF9	1822 073977	TATYANA TIMOFEEVA	{"phone": "+70209977800"}
0005434663681	8165D6	0591 129563	LYUBOV MAKAROVA	{"email": "lmakarova.031980@postgrespro.ru", "phone": "+70278720898"}
0005434663682	03A2EE	6605 350441	ALINA OSIPOVA	{"phone": "+70271343876"}
0005434663683	9FFDFF	9275 803133	STEPAN STEPANOV	{"email": "stepanov_stepan-1979@postgrespro.ru", "phone": "+70939471321"}
0005434663684	9FFDFF	7679 241422	DMITRIY ZHUKOV	{"email": "dmitriy-zhukov-071979@postgrespro.ru", "phone": "+70897615957"}
0005434663685	9FFDFF	4139 337108	KLAVDIYA VOROBEVA	{"email": "vorobeva.klavdiya1976@postgrespro.ru", "phone": "+70290460737"}
0005434663686	7D4F82	0174 296308	ALEKSANDR KOZLOV	{"email": "a.kozlov071970@postgrespro.ru", "phone": "+70476587109"}
0005434663687	7D4F82	8610 183012	OKSANA NAZAROVA	{"email": "nazarova.o_071974@postgrespro.ru", "phone": "+70186521258"}
0005434663688	C3E822	1968 859091	MARINA BELOVA	{"email": "belova_m09021969@postgrespro.ru", "phone": "+70848147786"}
0005434663689	17D922	4455 135077	ALEKSANDR EGOROV	{"email": "aleksandregorov011962@postgrespro.ru", "phone": "+70271414578"}
0005434663690	9B671B	7158 573311	LEONID MATVEEV	{"email": "matveev-leonid-101959@postgrespro.ru", "phone": "+70773247735"}
0005434663691	D50922	0893 951373	NATALYA LAZAREVA	{"phone": "+70240421812"}
0005434663692	B7E078	2927 440184	MIKHAIL GERASIMOV	{"phone": "+70251102751"}
0005434663693	0E6487	3833 185603	IRINA GUSEVA	{"email": "i.guseva101979@postgrespro.ru", "phone": "+70842307421"}
0005434663694	22B866	8751 039739	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov.25101975@postgrespro.ru", "phone": "+70741724151"}
0005434663695	C4A44B	9129 574726	EVGENIY VOROBEV	{"phone": "+70141928549"}
0005434663696	C4A44B	2314 306388	ALEKSANDR POPOV	{"email": "aleksandr.popov_071979@postgrespro.ru", "phone": "+70768847614"}
0005434663697	8034C3	0146 358468	LIDIYA MIRONOVA	{"phone": "+70445063916"}
0005434663698	8034C3	0116 520605	GRIGORIY SOLOVEV	{"phone": "+70641354779"}
0005434663699	8034C3	8976 621613	ALEKSANDR IVANOV	{"phone": "+70034613979"}
0005434663700	62A5AE	1656 283956	DANIIL BORISOV	{"phone": "+70265540528"}
0005434663701	303FEE	2772 208609	OKSANA LUKYANOVA	{"email": "lukyanova_oksana_051954@postgrespro.ru", "phone": "+70198891069"}
0005434663702	7B3978	4925 512120	NINA LUKYANOVA	{"email": "lukyanova.nina.1973@postgrespro.ru", "phone": "+70734970080"}
0005434663703	D0DCF0	0336 543998	ANTONINA NAUMOVA	{"phone": "+70264206964"}
0005434663704	739B69	0525 393122	MAYA BELOVA	{"email": "mayabelova-071964@postgrespro.ru", "phone": "+70185582466"}
0005434663705	1FE664	5562 203108	EKATERINA ABRAMOVA	{"email": "ekaterina.abramova_20111961@postgrespro.ru", "phone": "+70056113620"}
0005434663706	83D114	2511 741424	OKSANA MASLOVA	{"email": "oksanamaslova-21091969@postgrespro.ru", "phone": "+70612525063"}
0005434663707	83D114	9997 424720	ALEKSANDR FEDOTOV	{"phone": "+70187775952"}
0005434663708	83D114	0301 737478	NIKOLAY EGOROV	{"email": "egorovnikolay_1970@postgrespro.ru", "phone": "+70678658127"}
0005434663709	A323DF	5127 607971	ANATOLIY MOISEEV	{"email": "a.moiseev_081987@postgrespro.ru", "phone": "+70626920652"}
0005434663710	B7D583	6519 144001	OKSANA KOZLOVA	{"phone": "+70119188934"}
0005434663711	B7D583	3818 266389	MAKSIM MELNIKOV	{"email": "m-melnikov_1959@postgrespro.ru", "phone": "+70569553664"}
0005434663712	640A24	1528 839560	LEYLA KOMAROVA	{"phone": "+70515808795"}
0005434663713	8C4BE3	6113 031225	EVGENIY SOLOVEV	{"phone": "+70079936152"}
0005434663714	F20F07	0849 220571	VLADIMIR DENISOV	{"phone": "+70742646936"}
0005434663715	03F43F	3239 865154	IRINA VOROBEVA	{"email": "vorobeva-i_101970@postgrespro.ru", "phone": "+70914992672"}
0005434663716	5D5790	1351 659174	VERA MOROZOVA	{"phone": "+70851671145"}
0005434663717	5D5790	8561 829302	IRINA NOVIKOVA	{"email": "i_novikova.11041969@postgrespro.ru", "phone": "+70757589756"}
0005434663718	5D5790	8306 535681	SERGEY BONDARENKO	{"email": "s.bondarenko18041981@postgrespro.ru", "phone": "+70054900644"}
0005434663719	B05FC3	7084 934153	DIANA KUZNECOVA	{"phone": "+70078370696"}
0005434663720	B05FC3	2200 582361	DIANA MOROZOVA	{"email": "morozova.diana-031968@postgrespro.ru", "phone": "+70012569527"}
0005434663721	20B026	7408 069384	PAVEL BELOV	{"phone": "+70611659636"}
0005434663722	20B026	2568 156750	ANASTASIYA EFIMOVA	{"email": "efimova_anastasiya_071966@postgrespro.ru", "phone": "+70745438846"}
0005434663723	9EF59C	7441 299548	YURIY ZHURAVLEV	{"email": "y_zhuravlev_051975@postgrespro.ru", "phone": "+70139189612"}
0005434663724	A85D83	2963 704863	VERA GERASIMOVA	{"email": "gerasimovavera-16041981@postgrespro.ru", "phone": "+70539177349"}
0005434663725	731A34	1750 284945	MARGARITA SCHERBAKOVA	{"phone": "+70542430970"}
0005434663726	731A34	1019 094288	EVGENIYA MASLOVA	{"email": "e-maslova1962@postgrespro.ru", "phone": "+70719335332"}
0005434663727	21021F	0698 051288	ALEKSEY GUSEV	{"email": "gusev_a.16081968@postgrespro.ru", "phone": "+70639555823"}
0005434663728	21021F	3785 824140	KRISTINA SMIRNOVA	{"email": "k-smirnova_041965@postgrespro.ru", "phone": "+70685381290"}
0005434663729	2DE474	7861 791304	NATALYA LAZAREVA	{"email": "lazareva_n-16051979@postgrespro.ru", "phone": "+70481219640"}
0005434663730	2DE474	3485 364823	ELENA NIKOLAEVA	{"phone": "+70986139467"}
0005434663731	BFAA68	7232 086374	ZULFIYA ZAYCEVA	{"email": "z-zayceva-27061972@postgrespro.ru", "phone": "+70667575419"}
0005434663732	BFAA68	6786 820542	DARYA EFREMOVA	{"email": "d.efremova_1985@postgrespro.ru", "phone": "+70587367109"}
0005434663733	24BD53	2109 552424	ELENA FILIPPOVA	{"email": "filippova.elena_1976@postgrespro.ru", "phone": "+70825966632"}
0005434663734	123E6C	7325 223393	DMITRIY IVANOV	{"email": "d_ivanov29101969@postgrespro.ru", "phone": "+70542002644"}
0005434663735	14A679	9345 636746	ARTEM FILIPPOV	{"email": "afilippov-1981@postgrespro.ru", "phone": "+70420771215"}
0005434663736	14A679	2999 308393	SERGEY RODIONOV	{"email": "sergey-rodionov1977@postgrespro.ru", "phone": "+70573566440"}
0005434663737	3269C8	4727 080660	SERGEY DMITRIEV	{"phone": "+70142410530"}
0005434663738	3269C8	2858 151617	EGOR MELNIKOV	{"phone": "+70057004181"}
0005434663739	BC478C	9208 694495	GENNADIY SEMENOV	{"email": "semenov_gennadiy-1970@postgrespro.ru", "phone": "+70295150945"}
0005434663740	63FC5C	2406 996104	PAVEL SOLOVEV	{"phone": "+70425711590"}
0005434663741	63FC5C	6512 252907	NINEL BARANOVA	{"email": "ninel.baranova_101978@postgrespro.ru", "phone": "+70666428810"}
0005434663742	F4540F	8138 124129	ALEKSANDR PETROV	{"email": "petrov_aleksandr1974@postgrespro.ru", "phone": "+70393259514"}
0005434663743	F4540F	4515 446749	VASILIY PAVLOV	{"email": "v.pavlov18021965@postgrespro.ru", "phone": "+70799411084"}
0005434663744	470C2F	6735 318572	ALEKSEY TIKHONOV	{"phone": "+70501269793"}
0005434663745	14EA92	0735 946727	YURIY ABRAMOV	{"email": "abramov.yuriy101973@postgrespro.ru", "phone": "+70353615158"}
0005434663746	4F1EC1	7839 901853	ANNA SAVELEVA	{"phone": "+70274985834"}
0005434663747	34FB83	8967 411824	NATALYA FROLOVA	{"email": "natalya_frolova_30071973@postgrespro.ru", "phone": "+70600965119"}
0005434663748	43DE9A	1019 700002	POLINA ILINA	{"email": "polinailina.29051957@postgrespro.ru", "phone": "+70649180274"}
0005434663749	43DE9A	2669 904421	ANNA BOGDANOVA	{"phone": "+70001265023"}
0005434663750	588741	4194 461966	NATALYA GERASIMOVA	{"phone": "+70013559734"}
0005434663751	A6BF6E	7767 781893	TATYANA SEMENOVA	{"email": "semenova-t.1980@postgrespro.ru", "phone": "+70854227397"}
0005434663752	31AED9	9138 425068	MIKHAIL VASILEV	{"email": "m_vasilev12081958@postgrespro.ru", "phone": "+70123035395"}
0005434663753	99BA0A	0042 558095	NATALYA DANILOVA	{"phone": "+70905793384"}
0005434663754	70B7DF	1151 535620	VALENTIN IVANOV	{"email": "ivanov.v_1978@postgrespro.ru", "phone": "+70239580314"}
0005434663755	D47CF7	6755 603228	LARISA VASILEVA	{"email": "vasileva_larisa_1976@postgrespro.ru", "phone": "+70387074055"}
0005434663756	957A6D	7230 064893	VIKTOR SEMENOV	{"email": "v_semenov22021961@postgrespro.ru", "phone": "+70947518692"}
0005434663757	FCB68E	3414 002123	TATYANA FEDOROVA	{"phone": "+70323661398"}
0005434663758	8EDCE6	3840 163397	VADIM MAKAROV	{"email": "makarov-vadim-1954@postgrespro.ru", "phone": "+70390891497"}
0005434663759	8EDCE6	5446 071956	PAVEL GERASIMOV	{"email": "p.gerasimov-1987@postgrespro.ru", "phone": "+70066583907"}
0005434663760	739E95	9964 521124	NADEZHDA PAVLOVA	{"phone": "+70634631227"}
0005434663761	739E95	7355 308653	VALENTINA KOLESNIKOVA	{"phone": "+70560597747"}
0005434663762	739E95	7793 842827	EKATERINA ILINA	{"phone": "+70639782621"}
0005434663763	1C4A23	0651 923640	MARINA SOKOLOVA	{"phone": "+70929583048"}
0005434663764	7B3D4C	1561 383723	ELENA AKIMOVA	{"phone": "+70644733993"}
0005434663765	B1B1D3	7840 390364	ANNA SEMENOVA	{"phone": "+70611567394"}
0005434663766	9CEBBA	2920 003980	VLADIMIR MIRONOV	{"email": "mironov.v031969@postgrespro.ru", "phone": "+70528447194"}
0005434663767	9CEBBA	9146 646035	NIKOLAY DMITRIEV	{"phone": "+70848008285"}
0005434663768	E34252	2456 611068	ARTUR PAVLOV	{"phone": "+70042484452"}
0005434663769	E34252	6254 734381	ALEKSANDR SHEVCHENKO	{"email": "aleksandr.shevchenko_1966@postgrespro.ru", "phone": "+70345415229"}
0005434663770	B88C40	1937 247720	NINA ANDREEVA	{"phone": "+70445436275"}
0005434663771	61D633	7638 178829	ALEKSANDR MAKAROV	{"email": "makarov_a-07041967@postgrespro.ru", "phone": "+70037637247"}
0005434663772	5FB6D2	7698 722532	NIKOLAY MAKSIMOV	{"email": "maksimovn_011966@postgrespro.ru", "phone": "+70957069133"}
0005434663773	E3D84C	4459 780167	MARIYA NIKITINA	{"phone": "+70016355651"}
0005434663774	B3B9A0	4045 023801	ANATOLIY BORISOV	{"email": "borisov_anatoliy-1973@postgrespro.ru", "phone": "+70188471366"}
0005434663775	03E027	5048 694398	VLADIMIR VOLKOV	{"email": "v.volkov_101978@postgrespro.ru", "phone": "+70534725894"}
0005434663776	84CA36	3439 966549	ARTEM KULIKOV	{"phone": "+70446453453"}
0005434663777	941E21	3533 318802	RADIK ROMANOV	{"email": "romanov.r_22101968@postgrespro.ru", "phone": "+70606532976"}
0005434663778	941E21	2557 435048	DANILA BONDARENKO	{"email": "dbondarenko081977@postgrespro.ru", "phone": "+70836616421"}
0005434663779	941E21	9315 968403	SVETLANA MEDVEDEVA	{"email": "medvedeva_svetlana-111973@postgrespro.ru", "phone": "+70613200984"}
0005434663780	14A07A	3458 662507	VALERIYA NIKITINA	{"phone": "+70409529102"}
0005434663781	9CD63A	4048 158691	NATALYA GRISHINA	{"email": "grishina_n-24011966@postgrespro.ru", "phone": "+70116914053"}
0005434663782	17D580	3391 514154	SERGEY ANDREEV	{"email": "andreev_sergey051971@postgrespro.ru", "phone": "+70223011389"}
0005434663783	17D580	1049 384936	DAVID ANTONOV	{"phone": "+70981452942"}
0005434663784	FCC5C4	4183 356415	OKSANA NIKITINA	{"email": "nikitina.oksana.13031970@postgrespro.ru", "phone": "+70816030871"}
0005434663785	2C2295	5076 422286	ANNA MAKAROVA	{"phone": "+70602802012"}
0005434663786	DA9D25	8553 835448	SNEZHANA KOZLOVA	{"email": "s.kozlova111981@postgrespro.ru", "phone": "+70755374177"}
0005434663787	A45AE4	1337 707179	EVGENIY FEDOROV	{"phone": "+70696915613"}
0005434663788	A45AE4	4790 919712	VLADIMIR NAZAROV	{"email": "nazarov.v-1974@postgrespro.ru", "phone": "+70132551196"}
0005434663789	2F24D5	7993 211936	ANATOLIY ZHUKOV	{"phone": "+70529974161"}
0005434663790	D2086E	7191 139666	NATALYA POPOVA	{"email": "popovanatalya-011983@postgrespro.ru", "phone": "+70685441287"}
0005434663791	2D7DAA	3389 963665	MARIYA KUZNECOVA	{"email": "kuznecova-mariya_1967@postgrespro.ru", "phone": "+70855755186"}
0005434663792	2D7DAA	4491 304379	IRINA MATVEEVA	{"email": "i-matveeva.1970@postgrespro.ru", "phone": "+70623694143"}
0005434663793	B8E371	3015 249668	VIKTOR VOLKOV	{"email": "v.volkov-1960@postgrespro.ru", "phone": "+70913594196"}
0005434663794	B8E371	4575 434964	MIKHAIL BARANOV	{"email": "mikhail.baranov_1968@postgrespro.ru", "phone": "+70980673500"}
0005434663795	121657	1624 362995	EKATERINA SEMENOVA	{"email": "semenova-e-1985@postgrespro.ru", "phone": "+70064113030"}
0005434663796	D2DF1D	4341 449428	ALEKSANDR MIRONOV	{"phone": "+70999627816"}
0005434663797	539B59	6806 441576	FEDOR TARASOV	{"phone": "+70106224109"}
0005434663798	94ABDC	6264 442336	NIKOLAY MAKAROV	{"email": "makarov_n081973@postgrespro.ru", "phone": "+70191318537"}
0005434663799	94ABDC	6879 981038	IVAN DENISOV	{"phone": "+70082378794"}
0005434663800	854596	0318 595867	VLADIMIR ZAYCEV	{"email": "zaycev-v_091972@postgrespro.ru", "phone": "+70062350257"}
0005434663801	2614B7	4597 015248	MARIYA KONOVALOVA	{"phone": "+70770375396"}
0005434663802	2614B7	3314 782283	EVGENIY ABRAMOV	{"email": "abramov.evgeniy24081979@postgrespro.ru", "phone": "+70540569315"}
0005434663803	632F3F	8638 377749	DMITRIY BARANOV	{"phone": "+70340041327"}
0005434663804	B90C30	4464 489593	NIKITA POPOV	{"email": "popov_n-03031976@postgrespro.ru", "phone": "+70434803130"}
0005434663805	19493B	7035 943160	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_011980@postgrespro.ru", "phone": "+70203378265"}
0005434663806	F9FEC8	3387 835958	VITALIY ZHUKOV	{"phone": "+70250354466"}
0005434663807	BFF2C6	6800 979086	NATALYA OSIPOVA	{"email": "osipovan1967@postgrespro.ru", "phone": "+70647625852"}
0005434664968	12ACE7	8698 913263	NINA KUZNECOVA	{"phone": "+70519437878"}
0005434664919	78EEF0	3994 907156	ALEKSANDR ILIN	{"email": "aleksandrilin_051960@postgrespro.ru", "phone": "+70688618289"}
0005434664920	E0DC19	9141 443390	OLGA MAKSIMOVA	{"email": "olga-maksimova021959@postgrespro.ru", "phone": "+70400321788"}
0005434664921	708B78	6497 364824	EVGENIYA MOROZOVA	{"phone": "+70035889884"}
0005434664922	D1FBC3	8285 356464	ANTONINA GORBUNOVA	{"phone": "+70326614715"}
0005434664923	6C1374	9805 881910	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir.05121967@postgrespro.ru", "phone": "+70613398138"}
0005434664924	6C1374	3604 614063	GALINA TROFIMOVA	{"phone": "+70034505763"}
0005434664925	78678A	7505 009493	MARINA VASILEVA	{"phone": "+70803144096"}
0005434664926	0B34A2	3669 383237	ELENA VOROBEVA	{"email": "vorobeva.e-1989@postgrespro.ru", "phone": "+70553484740"}
0005434664927	0B34A2	8064 841701	DMITRIY NOVIKOV	{"email": "dmitriy_novikov.31081973@postgrespro.ru", "phone": "+70371906116"}
0005434664928	58A4FC	4737 813942	LIDIYA FILATOVA	{"phone": "+70448613834"}
0005434664929	58A4FC	1533 740185	MAYYA DENISOVA	{"email": "denisova.m_08061968@postgrespro.ru", "phone": "+70186843607"}
0005434664930	64D53D	2056 003541	NIKITA PETROV	{"email": "nikita_petrov111972@postgrespro.ru", "phone": "+70872648915"}
0005434664931	64D53D	8524 503316	VALENTIN ISAEV	{"email": "v-isaev-02051979@postgrespro.ru", "phone": "+70342935232"}
0005434664932	38CEA6	3311 547768	IGOR ILIN	{"phone": "+70835232950"}
0005434664933	A4E550	4862 341934	IGOR KUZNECOV	{"email": "i_kuznecov22041971@postgrespro.ru", "phone": "+70042080397"}
0005434664934	A4E550	5632 816867	NIKITA ANDREEV	{"phone": "+70295349328"}
0005434664935	76A804	1725 557177	GULSINA FILATOVA	{"email": "filatova_g-051987@postgrespro.ru", "phone": "+70341384543"}
0005434664936	9F0E67	8114 266302	SAMIRA SOKOLOVA	{"email": "sokolovasamira-1963@postgrespro.ru", "phone": "+70539797440"}
0005434664937	CC0FDB	0275 422083	NATALYA MAKAROVA	{"email": "makarovanatalya1980@postgrespro.ru", "phone": "+70241556779"}
0005434664938	CC0FDB	7012 088405	VYACHESLAV VOLKOV	{"phone": "+70278435091"}
0005434664939	BCEB6A	3686 423288	SERGEY SERGEEV	{"phone": "+70530054014"}
0005434664940	EDD687	3696 440340	ARTEM RODIONOV	{"phone": "+70615676882"}
0005434664941	551628	4785 747899	SERGEY TARASOV	{"email": "s_tarasov.071971@postgrespro.ru", "phone": "+70635100627"}
0005434664942	85C90A	9688 504667	YURIY SIDOROV	{"phone": "+70820044593"}
0005434664943	C3B5D6	6718 093849	MIKHAIL NOVIKOV	{"email": "m-novikov-29071970@postgrespro.ru", "phone": "+70295290007"}
0005434664944	0EC3A8	1092 307282	ELENA KOMAROVA	{"phone": "+70739933343"}
0005434664945	0EC3A8	7578 528903	MARIYA MIKHAYLOVA	{"email": "mmikhaylova021967@postgrespro.ru", "phone": "+70716682022"}
0005434664946	04290E	0447 300940	SERGEY MIKHAYLOV	{"phone": "+70131570924"}
0005434664947	04290E	7032 060261	YURIY IVANOV	{"phone": "+70391173212"}
0005434664948	04290E	7857 230228	ELVIRA NIKOLAEVA	{"email": "nikolaevae.21051982@postgrespro.ru", "phone": "+70179823427"}
0005434664949	0BA54D	3443 889629	DANIIL VASILEV	{"phone": "+70094492301"}
0005434664950	0BA54D	5120 111122	ZULFIYA FOMINA	{"phone": "+70912634322"}
0005434664951	1EC4E2	3423 712500	MARGARITA YAKOVLEVA	{"email": "margaritayakovleva.1971@postgrespro.ru", "phone": "+70947170927"}
0005434664952	637C38	3985 310439	NINA POLYAKOVA	{"phone": "+70268018823"}
0005434664953	D55DA9	6320 726447	DARYA FOMINA	{"email": "fomina-darya111974@postgrespro.ru", "phone": "+70425736569"}
0005434664954	2BF0EC	0647 394195	ELIZAVETA ZAKHAROVA	{"email": "elizaveta_zakharova1975@postgrespro.ru", "phone": "+70053022974"}
0005434665018	82F44F	6236 497856	TATYANA ALEKSEEVA	{"phone": "+70316415034"}
0005434664955	B298E7	5270 869666	LARISA EGOROVA	{"email": "egorova-larisa-071962@postgrespro.ru", "phone": "+70701068165"}
0005434664956	029AD5	5114 150717	ALEKSANDR SAVELEV	{"phone": "+70953472833"}
0005434664957	C56292	2833 016440	MIKHAIL SCHERBAKOV	{"email": "mscherbakov-011967@postgrespro.ru", "phone": "+70197612360"}
0005434664958	F80F25	5460 138962	MARIYA ALEKSEEVA	{"email": "alekseeva_m-121971@postgrespro.ru", "phone": "+70945582379"}
0005434664959	F80F25	7306 308340	GENNADIY IVANOV	{"email": "ivanov-g27081969@postgrespro.ru", "phone": "+70024111012"}
0005434664960	094793	9298 776187	GENNADIY DAVYDOV	{"email": "gennadiy-davydov_27101959@postgrespro.ru", "phone": "+70231643760"}
0005434664961	094793	0772 649470	NIKOLAY BORISOV	{"email": "nikolay-borisov.27101973@postgrespro.ru", "phone": "+70916800461"}
0005434664962	094793	7355 472579	IRINA CHERNOVA	{"email": "chernova.i031972@postgrespro.ru", "phone": "+70549057612"}
0005434664963	E7A92F	0164 199694	SVETLANA FOMINA	{"email": "fomina_s_1974@postgrespro.ru", "phone": "+70126376059"}
0005434664964	E7A92F	6979 010464	MARGARITA KARPOVA	{"phone": "+70328417812"}
0005434664965	521C2E	8499 891042	DMITRIY VLASOV	{"email": "vlasovd.061962@postgrespro.ru", "phone": "+70550727472"}
0005434664966	98AECB	1021 774138	PAVEL ANTONOV	{"phone": "+70358147827"}
0005434664967	38D2B9	4750 516710	ILYAS ZHUKOV	{"phone": "+70646339860"}
0005434664969	12ACE7	1070 147863	ANATOLIY MAKSIMOV	{"email": "a_maksimov_111971@postgrespro.ru", "phone": "+70047379039"}
0005434664970	12ACE7	0224 708252	RAISA KUZNECOVA	{"email": "kuznecova_r.1967@postgrespro.ru", "phone": "+70388090726"}
0005434664971	78D9C6	7474 273427	NADEZHDA SOKOLOVA	{"email": "sokolova_n071974@postgrespro.ru", "phone": "+70765518987"}
0005434664972	F8E1A1	9513 893130	VLADIMIR VOROBEV	{"phone": "+70627789643"}
0005434664973	29C415	5835 278857	IGOR TIMOFEEV	{"email": "igor.timofeev.1967@postgrespro.ru", "phone": "+70254704080"}
0005434664974	87AD56	9800 977757	SERGEY AFANASEV	{"email": "s.afanasev-1966@postgrespro.ru", "phone": "+70736365092"}
0005434664975	87AD56	6754 810648	VERA KULIKOVA	{"phone": "+70898729116"}
0005434664976	87DF53	7430 016250	ZAKHAR ILIN	{"email": "z_ilin_22021979@postgrespro.ru", "phone": "+70132311258"}
0005434664977	799D30	6563 766187	VALENTINA KISELEVA	{"phone": "+70361899161"}
0005434664978	799D30	1865 498687	ANDREY KOROLEV	{"phone": "+70175716433"}
0005434664979	3159B3	1549 207082	YURIY KISELEV	{"phone": "+70471519516"}
0005434664980	1A5C50	2249 905014	ANDREY BELOV	{"email": "abelov071979@postgrespro.ru", "phone": "+70812320964"}
0005434664981	1A5C50	8946 923526	GALINA GORBUNOVA	{"phone": "+70713569944"}
0005434664982	B089E2	7118 261828	ALEKSANDR SOKOLOV	{"phone": "+70351650962"}
0005434664983	94260A	5110 820489	RAISA NIKIFOROVA	{"phone": "+70192125149"}
0005434664984	94260A	0554 730243	PETR NAUMOV	{"email": "petr-naumov.13101971@postgrespro.ru", "phone": "+70582282633"}
0005434664985	D1539B	5759 187500	ROMAN TARASOV	{"email": "tarasov-r.30101981@postgrespro.ru", "phone": "+70972190017"}
0005434664986	D1539B	6973 104973	OLEG STEPANOV	{"email": "stepanov.o.29041980@postgrespro.ru", "phone": "+70607630351"}
0005434664987	7FDD6B	7097 210767	NINA NAZAROVA	{"phone": "+70480417374"}
0005434664988	7FDD6B	6073 241024	ELENA ISAEVA	{"email": "eisaeva.1972@postgrespro.ru", "phone": "+70598466671"}
0005434664989	E5DA9D	5081 254801	NAIL IVANOV	{"email": "nivanov.041972@postgrespro.ru", "phone": "+70991187800"}
0005434664990	5705B9	0261 993742	ANGELINA NESTEROVA	{"phone": "+70386752866"}
0005434664991	7703DC	0956 626155	SERGEY POPOV	{"email": "s_popov_29101972@postgrespro.ru", "phone": "+70719025071"}
0005434664992	F30F57	4110 793208	LYUDMILA ABRAMOVA	{"phone": "+70616691925"}
0005434664993	CA136F	0443 213492	EKATERINA ANISIMOVA	{"email": "e-anisimova.101973@postgrespro.ru", "phone": "+70151045421"}
0005434664994	4513B4	7628 115765	VLADIMIR KAZAKOV	{"email": "kazakov-v_071971@postgrespro.ru", "phone": "+70324324148"}
0005434664995	4513B4	1996 653078	VLADIMIR ORLOV	{"email": "orlov_vladimir_061973@postgrespro.ru", "phone": "+70609077817"}
0005434664996	7C7B32	4200 412234	OLGA GERASIMOVA	{"email": "o_gerasimova031970@postgrespro.ru", "phone": "+70926355802"}
0005434664997	5A535E	4245 418877	ALFIYA VOLKOVA	{"phone": "+70292479468"}
0005434664998	5A535E	5729 913025	ALEKSEY MIKHAYLOV	{"phone": "+70422059018"}
0005434664999	2CE0C6	3107 838077	RAISA SERGEEVA	{"phone": "+70195353937"}
0005434665000	2CE0C6	9443 956175	ARTEM ZAYCEV	{"email": "a.zaycev_041976@postgrespro.ru", "phone": "+70786697227"}
0005434665001	9ACEBD	6014 069773	SERGEY KRASNOV	{"phone": "+70825346227"}
0005434665002	9ACEBD	3348 294386	LYUDMILA ZOTOVA	{"phone": "+70750383920"}
0005434665003	87DEAB	6841 339912	VLADIMIR TIMOFEEV	{"phone": "+70800674220"}
0005434665004	42E6CE	4365 253880	VALENTINA PETROVA	{"email": "valentina.petrova.09081974@postgrespro.ru", "phone": "+70655574401"}
0005434665005	AC64B2	5702 347816	MARINA MIRONOVA	{"email": "m-mironova1959@postgrespro.ru", "phone": "+70391980728"}
0005434665006	AC64B2	0821 754002	OLEG POPOV	{"email": "opopov.01051979@postgrespro.ru", "phone": "+70249657077"}
0005434665007	8DB565	3849 832044	ANASTASIYA VOLKOVA	{"phone": "+70684033047"}
0005434665008	EEEC97	3727 797108	SVETLANA PETROVA	{"phone": "+70804996100"}
0005434665009	EEEC97	6238 530270	VALERIY EGOROV	{"email": "egorov.v_10061985@postgrespro.ru", "phone": "+70668882957"}
0005434665010	95434D	7299 475119	ALEKSANDR OSIPOV	{"phone": "+70016542314"}
0005434665011	CA871A	1203 514313	SAID ALEKSANDROV	{"phone": "+70712848586"}
0005434665012	F834AA	4428 961774	EVGENIY MOROZOV	{"phone": "+70141030584"}
0005434665013	B89C8D	5979 563021	ALEKSANDR ZHURAVLEV	{"phone": "+70197069556"}
0005434665014	89A1C0	6602 271011	TATYANA NAUMOVA	{"email": "naumovat05111980@postgrespro.ru", "phone": "+70610753504"}
0005434665015	33DC68	1823 804889	YURIY GERASIMOV	{"phone": "+70680117700"}
0005434665016	F41DBE	2357 346364	VITALIY GUSEV	{"phone": "+70205578711"}
0005434665019	3C40BC	1685 365783	ANDREY NIKITIN	{"email": "nikitin-andrey-19101965@postgrespro.ru", "phone": "+70127911062"}
0005434665020	3C40BC	3788 641239	ANASTASIYA MOROZOVA	{"phone": "+70017208892"}
0005434665021	91FFD7	8486 385174	NIKOLAY SCHERBAKOV	{"phone": "+70218044334"}
0005434665022	4B0364	5087 847032	SERGEY BONDARENKO	{"phone": "+70576474902"}
0005434665023	C13638	9116 287688	ALEFTINA ZHUKOVA	{"email": "aleftina.zhukova_11011963@postgrespro.ru", "phone": "+70064027430"}
0005434665024	131BD6	4009 750651	ELENA ZHUKOVA	{"email": "elena.zhukova.1989@postgrespro.ru", "phone": "+70227241920"}
0005434665025	131BD6	7439 609856	EKATERINA FOMINA	{"email": "fomina-e-071978@postgrespro.ru", "phone": "+70695594733"}
0005434665026	F2FC1E	9028 651146	ROMAN TARASOV	{"email": "tarasov.r-021966@postgrespro.ru", "phone": "+70327346792"}
0005434723310	5AFFE1	2601 557341	OLEG PAVLOV	{"email": "pavlovoleg19111978@postgrespro.ru", "phone": "+70173169613"}
0005434723311	7C638E	3300 594564	KONSTANTIN OSIPOV	{"phone": "+70335757863"}
0005434723312	7C638E	6805 556054	DMITRIY SERGEEV	{"email": "d-sergeev-121962@postgrespro.ru", "phone": "+70688468788"}
0005434723313	8E0316	8297 445928	VADIM PETROV	{"email": "v-petrov21121967@postgrespro.ru", "phone": "+70490054397"}
0005434723314	8E0316	5328 711972	NINA ROMANOVA	{"phone": "+70031577275"}
0005434723315	8E0316	3869 419638	RAISA IVANOVA	{"email": "raisa-ivanova041977@postgrespro.ru", "phone": "+70725006304"}
0005434723316	30661C	9620 987208	ANNA PETROVA	{"phone": "+70513953476"}
0005434723317	0C197C	9392 183752	KSENIYA FROLOVA	{"phone": "+70748900573"}
0005434723318	0C197C	6838 613747	ANTONINA CHERNOVA	{"email": "chernova-a_1972@postgrespro.ru", "phone": "+70248496913"}
0005434723319	89C015	7268 008638	ANASTASIYA DENISOVA	{"email": "adenisova-031964@postgrespro.ru", "phone": "+70274330777"}
0005434723320	688EF0	3711 401150	MARIYA YAKOVLEVA	{"phone": "+70718517457"}
0005434723321	688EF0	2632 753586	POLINA KOROLEVA	{"email": "p.koroleva1968@postgrespro.ru", "phone": "+70496786492"}
0005434723322	359225	9221 686599	SERGEY KULIKOV	{"phone": "+70169852282"}
0005434723323	359225	2035 898289	OKSANA MASLOVA	{"email": "maslova-o_12051966@postgrespro.ru", "phone": "+70534612457"}
0005434723324	8ECC82	6099 545203	IRINA ANDREEVA	{"email": "irina.andreeva-111982@postgrespro.ru", "phone": "+70225222549"}
0005434723325	120687	8326 897187	EKATERINA KUZNECOVA	{"email": "ekaterina-kuznecova.091986@postgrespro.ru", "phone": "+70946957774"}
0005434723326	D13A0F	9732 341400	ELENA GORBUNOVA	{"email": "e.gorbunova081965@postgrespro.ru", "phone": "+70655066722"}
0005434723327	D13A0F	0013 913120	ALEKSEY RODIONOV	{"email": "a-rodionov081979@postgrespro.ru", "phone": "+70335679318"}
0005434723328	ED97BE	4853 089496	VADIM IVANOV	{"email": "ivanov.v08021965@postgrespro.ru", "phone": "+70117848713"}
0005434723329	1FC429	0907 479742	GALINA NAZAROVA	{"phone": "+70479633557"}
0005434723330	1FC429	1234 507250	KSENIYA LOGINOVA	{"email": "k_loginova.1969@postgrespro.ru", "phone": "+70811792527"}
0005434723331	E899F5	9488 829164	RIMMA GRISHINA	{"phone": "+70450517383"}
0005434723332	E899F5	8745 853633	ANDREY KOZLOV	{"email": "andrey.kozlov071970@postgrespro.ru", "phone": "+70512154227"}
0005434723333	BE8491	9035 759495	ALEKSANDR ANDREEV	{"phone": "+70512011850"}
0005434723334	BE8491	3511 639072	RITA LOGINOVA	{"phone": "+70994854331"}
0005434723335	E265B9	9685 865116	IRINA POPOVA	{"email": "popova_irina1973@postgrespro.ru", "phone": "+70682337088"}
0005434723336	114AC8	8755 306699	ANTON PETROV	{"email": "petrov_a_02111990@postgrespro.ru", "phone": "+70822025114"}
0005434723337	E538B2	2361 629206	GALINA KISELEVA	{"email": "galina.kiseleva-081973@postgrespro.ru", "phone": "+70516026776"}
0005434723338	E538B2	3955 346594	DANIIL SAVELEV	{"email": "daniil-savelev.111978@postgrespro.ru", "phone": "+70479233344"}
0005434723339	4235D4	6192 296098	ANDREY IVANOV	{"email": "ivanov.andrey20041980@postgrespro.ru", "phone": "+70588276750"}
0005434723340	4235D4	7835 397917	ALISA MAKSIMOVA	{"email": "alisa.maksimova-1963@postgrespro.ru", "phone": "+70164449537"}
0005434723341	EA223C	8189 273938	MAKSIM IVANOV	{"email": "maksimivanov.1961@postgrespro.ru", "phone": "+70659460789"}
0005434723342	22ED2F	7240 181961	YURIY GUSEV	{"phone": "+70396450423"}
0005434723343	4A0200	2161 803997	ALEKSANDR DMITRIEV	{"phone": "+70538447995"}
0005434723344	C2EE36	3818 886877	KRISTINA GORBUNOVA	{"email": "gorbunova_k-011976@postgrespro.ru", "phone": "+70403707624"}
0005434723345	C2EE36	2007 686487	NIKOLAY EGOROV	{"phone": "+70811820373"}
0005434723346	85DAB0	4454 189641	SERGEY MARTYNOV	{"email": "sergey-martynov_1974@postgrespro.ru", "phone": "+70015816525"}
0005434723347	03C9EB	7789 193443	VALERIYA IVANOVA	{"phone": "+70596094062"}
0005434723348	7B400B	9076 443825	NATALYA ROMANOVA	{"phone": "+70513725494"}
0005434723349	999147	4872 731596	YURIY VOROBEV	{"email": "y-vorobev.021958@postgrespro.ru", "phone": "+70245844151"}
0005434723350	E51A49	6325 231847	IGOR MAKAROV	{"phone": "+70547473135"}
0005434723351	A6AA8E	4510 680790	ZINAIDA KUZNECOVA	{"phone": "+70448117667"}
0005434723352	28BFA0	8624 472626	EVGENIY PAVLOV	{"phone": "+70188812611"}
0005434723353	0DE3DB	9682 329582	ALEKSANDR IVANOV	{"phone": "+70191851386"}
0005434723354	C551D9	6065 687272	SERGEY SERGEEV	{"email": "sergeev_sergey.121966@postgrespro.ru", "phone": "+70519292044"}
0005434723355	5689EC	7035 917263	MAKSIM SIDOROV	{"email": "m-sidorov_24091980@postgrespro.ru", "phone": "+70733253629"}
0005434723356	5689EC	7211 845745	NIKOLAY NIKOLAEV	{"email": "nikolaev-nikolay-30061986@postgrespro.ru", "phone": "+70473913285"}
0005434723357	55BD7F	6012 417618	SERGEY KUZMIN	{"email": "sergey-kuzmin-1983@postgrespro.ru", "phone": "+70125575634"}
0005434723358	035E75	0941 062094	FEDOR MOROZOV	{"email": "morozov_f.25081967@postgrespro.ru", "phone": "+70345529403"}
0005434723359	8E54EB	2793 937665	RAVIL VOLKOV	{"phone": "+70331625818"}
0005434723535	9B559A	7759 077436	DARYA MIRONOVA	{"phone": "+70506385746"}
0005434723360	AD18F1	6653 485853	ELENA FEDOROVA	{"email": "elenafedorova.27091962@postgrespro.ru", "phone": "+70891809359"}
0005434723361	23C9EE	5993 802810	RITA FROLOVA	{"phone": "+70152536437"}
0005434723362	23C9EE	4276 486381	MARIYA EFIMOVA	{"phone": "+70034705833"}
0005434723363	F33F30	6952 612935	ALEKSEY MAKAROV	{"email": "alekseymakarov-13061981@postgrespro.ru", "phone": "+70800972093"}
0005434723364	D4D1BB	1266 837603	ALLA IVANOVA	{"email": "a_ivanova_121978@postgrespro.ru", "phone": "+70384157516"}
0005434723365	E2E3F8	8054 080524	GALINA LAZAREVA	{"email": "lazareva-galina.29051977@postgrespro.ru", "phone": "+70523053716"}
0005434723366	E2E3F8	7767 866257	ALLA KUZNECOVA	{"phone": "+70852227063"}
0005434723367	8C63EC	5928 175901	KAPITALINA BARANOVA	{"email": "kbaranova_111967@postgrespro.ru", "phone": "+70757498850"}
0005434723368	AA7FCA	2415 395605	YURIY KUZMIN	{"phone": "+70965872363"}
0005434723369	1DB454	4649 389607	ALEKSANDR ZHUKOV	{"phone": "+70336068038"}
0005434723370	E28177	0145 390269	ALEKSANDRA GAVRILOVA	{"email": "aleksandra-gavrilova_06071975@postgrespro.ru", "phone": "+70720448691"}
0005434723371	E28177	0161 600354	NATALYA ANDREEVA	{"email": "andreeva-natalya-1976@postgrespro.ru", "phone": "+70699629705"}
0005434723372	B8CE53	6225 199715	VLADIMIR GRIGOREV	{"phone": "+70567961131"}
0005434723373	F229E4	3779 147156	TATYANA SOROKINA	{"phone": "+70370027728"}
0005434723374	D17328	8844 552252	ALEKSANDRA VLASOVA	{"email": "a.vlasova_13091969@postgrespro.ru", "phone": "+70237886054"}
0005434723375	CB525A	8524 077581	KSENIYA PAVLOVA	{"email": "pavlovak20011973@postgrespro.ru", "phone": "+70481835354"}
0005434723376	CB525A	6322 777332	ZINAIDA EFIMOVA	{"phone": "+70840464463"}
0005434723377	CB525A	1792 507552	MIKHAIL PETROV	{"email": "petrov_m_1972@postgrespro.ru", "phone": "+70080400813"}
0005434723378	4C9114	7055 229977	LIDIYA DENISOVA	{"email": "denisova_l.1966@postgrespro.ru", "phone": "+70143767253"}
0005434723379	0832C0	3844 218899	DANIIL PETROV	{"email": "petrov_daniil1961@postgrespro.ru", "phone": "+70992814735"}
0005434723380	5C2F2A	6591 512134	ALEKSANDRA MEDVEDEVA	{"phone": "+70804118207"}
0005434723381	2AE9BB	0028 971487	SERGEY GERASIMOV	{"email": "gerasimov.sergey041970@postgrespro.ru", "phone": "+70010986982"}
0005434723382	2AE9BB	0423 664787	MARSEL ALEKSANDROV	{"phone": "+70409797076"}
0005434723383	BEB0DC	2476 799173	ALEKSANDR IVANOV	{"email": "aleksandrivanov.08081982@postgrespro.ru", "phone": "+70298660805"}
0005434723384	696722	2391 752738	EVGENIY NIKITIN	{"phone": "+70943346592"}
0005434723385	A80144	2906 227228	LYUBOV NIKOLAEVA	{"email": "nikolaeva-l-101977@postgrespro.ru", "phone": "+70576852441"}
0005434723386	A80144	7701 674415	ALINA KRASNOVA	{"email": "krasnova-a-1981@postgrespro.ru", "phone": "+70921796895"}
0005434723387	F6531C	9741 632670	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov-1974@postgrespro.ru", "phone": "+70343039022"}
0005434723388	FA7C0E	7734 608053	ANNA SOROKINA	{"email": "sorokina_a.23041965@postgrespro.ru", "phone": "+70834311607"}
0005434723389	FA7C0E	9605 781152	DMITRIY BORISOV	{"email": "borisov_d041989@postgrespro.ru", "phone": "+70809538925"}
0005434723390	12D843	8619 432495	MARINA KRASNOVA	{"email": "krasnovamarina-081973@postgrespro.ru", "phone": "+70651645148"}
0005434723391	7E281E	4476 930022	ELINA STEPANOVA	{"phone": "+70349891906"}
0005434723392	EA3852	6719 377185	NINA SAVELEVA	{"phone": "+70945403171"}
0005434723393	EA3852	8951 993517	DMITRIY GERASIMOV	{"phone": "+70543608536"}
0005434723394	A861F5	3832 676005	MATVEY DMITRIEV	{"email": "dmitriev.m.10031969@postgrespro.ru", "phone": "+70224058285"}
0005434723395	A861F5	4529 394670	VLADIMIR KISELEV	{"email": "vkiselev-011964@postgrespro.ru", "phone": "+70766129477"}
0005434723396	0564A9	6957 079186	OLGA VLASOVA	{"email": "vlasovaolga_13101973@postgrespro.ru", "phone": "+70690753085"}
0005434723397	C7F165	0434 506784	SERGEY STEPANOV	{"email": "s.stepanov.011966@postgrespro.ru", "phone": "+70283372148"}
0005434723398	9E1ABB	7962 943050	VYACHESLAV SEMENOV	{"email": "vyacheslav-semenov_10121959@postgrespro.ru", "phone": "+70990483177"}
0005434723399	971EF1	9458 665250	VIKTORIYA MAKSIMOVA	{"phone": "+70662483685"}
0005434723400	971EF1	9288 829395	VALERIY FROLOV	{"phone": "+70063025166"}
0005434723401	45838F	5514 849241	ZLATA IVANOVA	{"phone": "+70694689497"}
0005434723402	0C2F75	2696 350635	ALMIRA ZHURAVLEVA	{"phone": "+70132394026"}
0005434723403	0C2F75	2406 383545	IGOR ANTONOV	{"email": "antonov_igor_071969@postgrespro.ru", "phone": "+70082406170"}
0005434723404	CF649E	9113 388490	SOFYA NOVIKOVA	{"email": "sofyanovikova-1972@postgrespro.ru", "phone": "+70918457240"}
0005434723405	CF649E	6473 871273	ALEKSANDRA TIKHONOVA	{"email": "tikhonovaaleksandra.071974@postgrespro.ru", "phone": "+70633467819"}
0005434723406	277210	8810 124525	VADIM TIMOFEEV	{"phone": "+70210495227"}
0005434723407	152971	7802 052781	SERGEY KUZMIN	{"email": "kuzmin_s_21101973@postgrespro.ru", "phone": "+70833079766"}
0005434723408	80C448	0534 698619	ROZALIYA ZOTOVA	{"phone": "+70100196112"}
0005434723409	7DE60D	7719 483262	VIKTOR IVANOV	{"phone": "+70438305757"}
0005434723410	7DE60D	0136 984474	NATALYA FROLOVA	{"phone": "+70974929239"}
0005434723411	7DE60D	3521 712538	SERGEY MEDVEDEV	{"email": "medvedev.sergey12101970@postgrespro.ru", "phone": "+70747325293"}
0005434723412	F93529	5910 387892	ELIZAVETA SEMENOVA	{"phone": "+70664952391"}
0005434723413	D92478	3443 611911	SVETLANA NAZAROVA	{"email": "snazarova.081972@postgrespro.ru", "phone": "+70453383893"}
0005434723414	D92478	0471 299290	ALEKSEY ROMANOV	{"email": "romanov-a-1997@postgrespro.ru", "phone": "+70211095632"}
0005434723415	68A974	4890 404376	NINA BELOVA	{"email": "belova_nina_051973@postgrespro.ru", "phone": "+70193017954"}
0005434723416	5513F7	1760 980908	VALERIYA VASILEVA	{"phone": "+70461653393"}
0005434723417	7E9F76	8507 735496	YURIY DMITRIEV	{"phone": "+70198851337"}
0005434723418	A0E022	6230 474509	GALIYA ZAYCEVA	{"phone": "+70834938415"}
0005434723419	A0E022	4970 301146	LIDIYA FOMINA	{"email": "fomina_l_02031972@postgrespro.ru", "phone": "+70289854069"}
0005434723420	2AADB7	4672 660518	VLADIMIR DENISOV	{"email": "vladimir.denisov_071963@postgrespro.ru", "phone": "+70070245163"}
0005434723421	B7C8F5	0609 065510	EVDOKIYA ANDREEVA	{"email": "evdokiya-andreeva-071973@postgrespro.ru", "phone": "+70455637808"}
0005434723422	B7C8F5	7379 081881	NATALYA EFIMOVA	{"email": "efimova-natalya.031969@postgrespro.ru", "phone": "+70222528482"}
0005434723423	C1FBE2	3448 492232	OLGA MEDVEDEVA	{"email": "medvedeva-o22111975@postgrespro.ru", "phone": "+70948816835"}
0005434723424	C7A79D	1475 504547	MILENA ARKHIPOVA	{"email": "milena.arkhipova_051981@postgrespro.ru", "phone": "+70297602482"}
0005434723425	ABF8EE	9141 524139	GEORGIY TIMOFEEV	{"email": "georgiy-timofeev_021978@postgrespro.ru", "phone": "+70170255321"}
0005434723426	ABF8EE	2223 451190	SVETLANA DMITRIEVA	{"phone": "+70309974236"}
0005434723427	2AA4DB	3782 189788	YULIYA KOLESNIKOVA	{"phone": "+70280658518"}
0005434723428	2AA4DB	6396 102100	MARINA MAKAROVA	{"email": "makarova-marina-21021971@postgrespro.ru", "phone": "+70688775313"}
0005434723429	2AA4DB	0418 193786	EKATERINA ERMAKOVA	{"email": "ermakova_e.13021974@postgrespro.ru", "phone": "+70975005597"}
0005434723430	98E906	1995 575391	DARYA AFANASEVA	{"email": "afanasevadarya-05051968@postgrespro.ru", "phone": "+70939364667"}
0005434723484	57EC9E	7892 685022	VYACHESLAV ZAYCEV	{"phone": "+70117733363"}
0005434723431	427BA6	6551 523365	VALENTINA TIMOFEEVA	{"email": "timofeeva-valentina.091976@postgrespro.ru", "phone": "+70487404055"}
0005434723432	0B8D58	7446 836867	ALINA SEMENOVA	{"phone": "+70630695322"}
0005434723433	0B8D58	4508 589313	MARIYA KOZLOVA	{"phone": "+70138805656"}
0005434723434	E0355F	3258 736073	ALEKSANDRA SOROKINA	{"email": "sorokinaa_06011963@postgrespro.ru", "phone": "+70317919146"}
0005434723435	54E5E1	8422 929419	YULIYA KRASNOVA	{"phone": "+70671578379"}
0005434723436	65BC65	7236 658940	DANILA STEPANOV	{"email": "d_stepanov.02101973@postgrespro.ru", "phone": "+70276914340"}
0005434723437	B03680	8436 532561	SERGEY GAVRILOV	{"phone": "+70504610086"}
0005434723438	EA431F	2010 375534	EGOR VLASOV	{"email": "vlasov-e-011973@postgrespro.ru", "phone": "+70747545254"}
0005434723439	6A5948	8266 540395	LARISA BELOVA	{"email": "larisa.belova111967@postgrespro.ru", "phone": "+70992371209"}
0005434723440	F743CB	4780 909122	ELENA ANISIMOVA	{"phone": "+70061217151"}
0005434723441	A508B0	7242 390194	MIKHAIL VOLKOV	{"email": "volkovmikhail12011977@postgrespro.ru", "phone": "+70159871587"}
0005434723442	A508B0	5852 812890	TATYANA STEPANOVA	{"phone": "+70713138261"}
0005434723443	5D3F66	8572 657638	SVETLANA KAZAKOVA	{"email": "kazakova.svetlana-28051983@postgrespro.ru", "phone": "+70732354188"}
0005434723444	5D3F66	7589 998678	VALERIY PETROV	{"email": "petrov_valeriy061963@postgrespro.ru", "phone": "+70641772179"}
0005434723445	008417	6336 089581	ANTON DMITRIEV	{"email": "admitriev_071975@postgrespro.ru", "phone": "+70238974766"}
0005434723446	A15A58	0220 183981	VITALIY VASILEV	{"email": "vasilev_v.121973@postgrespro.ru", "phone": "+70428724698"}
0005434723447	A15A58	6252 363886	ELENA FROLOVA	{"email": "e_frolova08021968@postgrespro.ru", "phone": "+70731473535"}
0005434723448	E9B62E	2112 008670	NADEZHDA FOMINA	{"email": "fominanadezhda-04021964@postgrespro.ru", "phone": "+70988582095"}
0005434723449	C11E66	6921 064155	ROMAN ILIN	{"phone": "+70828130827"}
0005434723450	0EB385	1708 149183	NIKOLAY FOMIN	{"phone": "+70299912339"}
0005434723451	D67FE4	1070 712365	YULIYA ZAKHAROVA	{"email": "zakharova.yuliya_16081978@postgrespro.ru", "phone": "+70942843885"}
0005434723452	D8A867	1411 113810	VALENTINA ANISIMOVA	{"phone": "+70252784514"}
0005434723453	FB4494	7453 409545	VIKTOR NOVIKOV	{"phone": "+70126757528"}
0005434723454	9E7005	4616 024211	SVETLANA MALYSHEVA	{"email": "s_malysheva-1967@postgrespro.ru", "phone": "+70093985570"}
0005434723455	9E7005	7393 640064	ANATOLIY FILIPPOV	{"email": "filippov.anatoliy05051965@postgrespro.ru", "phone": "+70717227103"}
0005434723456	E079E6	7171 062502	VYACHESLAV KULIKOV	{"email": "vyacheslavkulikov-06021970@postgrespro.ru", "phone": "+70603966394"}
0005434723457	E079E6	6089 796167	GAGIK VASILEV	{"email": "vasilev.gagik-04061967@postgrespro.ru", "phone": "+70902964090"}
0005434723458	AC72CC	7214 066639	TATYANA IVANOVA	{"email": "ivanova_t-091961@postgrespro.ru", "phone": "+70871448466"}
0005434723514	18F23A	3066 768480	VLADIMIR MATVEEV	{"phone": "+70836212186"}
0005434723459	E1DC44	1073 217506	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-091971@postgrespro.ru", "phone": "+70256925286"}
0005434723460	E1DC44	7313 659141	MARIYA OVCHINNIKOVA	{"email": "ovchinnikovam_1965@postgrespro.ru", "phone": "+70030379761"}
0005434723461	F098F2	3913 598238	GLEB SEMENOV	{"email": "semenov_g03111981@postgrespro.ru", "phone": "+70036814722"}
0005434723462	F098F2	1271 133928	NIKOLAY ALEKSEEV	{"phone": "+70889669514"}
0005434723463	CEB8FA	8912 812115	ZLATA KONDRATEVA	{"email": "zlata-kondrateva.1979@postgrespro.ru", "phone": "+70275746716"}
0005434723464	ED2DD9	5666 780649	TATYANA SAVELEVA	{"email": "savelevatatyana_101958@postgrespro.ru", "phone": "+70888885181"}
0005434723465	DDB421	5894 089708	EVGENIY KOZLOV	{"phone": "+70474372473"}
0005434723466	4AD34E	4024 994249	ELENA FILIPPOVA	{"phone": "+70642532092"}
0005434723467	4AD34E	9176 332047	SERGEY NAUMOV	{"email": "s-naumov1972@postgrespro.ru", "phone": "+70883912308"}
0005434723468	2C5018	6376 088622	ANATOLIY GAVRILOV	{"email": "gavrilov_a.06091973@postgrespro.ru", "phone": "+70938392545"}
0005434723469	2C5018	0406 885402	NIKOLAY STEPANOV	{"email": "n-stepanov.13021978@postgrespro.ru", "phone": "+70965561882"}
0005434723470	2C5018	6679 406125	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov-28041971@postgrespro.ru", "phone": "+70769247860"}
0005434723471	2C5018	6998 487351	MIKHAIL SHEVCHENKO	{"phone": "+70444022295"}
0005434723472	3C2875	0990 849242	OLEG SMIRNOV	{"email": "smirnov.o-051971@postgrespro.ru", "phone": "+70324799463"}
0005434723473	EF3C5B	8136 330881	PETR TIKHONOV	{"email": "tikhonov.p-1981@postgrespro.ru", "phone": "+70536293479"}
0005434723474	A50DDC	8951 524934	IGNAT MOISEEV	{"email": "i-moiseev_081968@postgrespro.ru", "phone": "+70051000021"}
0005434723475	FCFD91	9296 167398	TATYANA SOKOLOVA	{"email": "t-sokolova_081978@postgrespro.ru", "phone": "+70107648228"}
0005434723476	FCFD91	4002 046182	RAISA GERASIMOVA	{"email": "gerasimova.raisa.01031981@postgrespro.ru", "phone": "+70152612709"}
0005434723477	27B612	3742 689412	EKATERINA ALEKSEEVA	{"phone": "+70756019882"}
0005434723478	83D3D2	6679 894930	NINA KISELEVA	{"phone": "+70781008419"}
0005434723479	83D3D2	8477 747040	LYUBOV SEMENOVA	{"email": "lyubov_semenova.041966@postgrespro.ru", "phone": "+70650541097"}
0005434723480	DEECD3	0623 122476	TATYANA ZAYCEVA	{"email": "tatyanazayceva.1970@postgrespro.ru", "phone": "+70753508192"}
0005434723481	DEECD3	4378 771157	ELIZAVETA VOROBEVA	{"email": "elizaveta-vorobeva.101989@postgrespro.ru", "phone": "+70928248570"}
0005434723482	E22A1C	5701 531287	VIKTOR AFANASEV	{"email": "afanasev.v1966@postgrespro.ru", "phone": "+70462584965"}
0005434723483	57EC9E	8266 015398	VARVARA TROFIMOVA	{"email": "v_trofimova-1981@postgrespro.ru", "phone": "+70579805393"}
0005434723485	AE8775	9705 354430	OLEG SHEVCHENKO	{"email": "oleg.shevchenko-13091974@postgrespro.ru", "phone": "+70162717334"}
0005434723486	AE8775	8161 632459	ZOYA TARASOVA	{"phone": "+70109985855"}
0005434723487	AE8775	9335 336786	ALEKSANDR MIKHAYLOV	{"phone": "+70198931457"}
0005434723488	3C07A7	9046 275758	MARINA ZAKHAROVA	{"email": "zakharova-m.051969@postgrespro.ru", "phone": "+70072875569"}
0005434723489	3C07A7	9743 699277	VIKTOR KOZLOV	{"email": "kozlovv_1976@postgrespro.ru", "phone": "+70800992572"}
0005434723490	B6786C	5150 603639	VLADIMIR SIDOROV	{"phone": "+70255553366"}
0005434723491	B6786C	6499 054422	LYUBOV LUKYANOVA	{"email": "lukyanova_l1979@postgrespro.ru", "phone": "+70272561534"}
0005434723492	5A380F	0848 521364	ANASTASIYA EGOROVA	{"email": "egorova.a011968@postgrespro.ru", "phone": "+70969281870"}
0005434723493	133FB4	2871 596730	MARAT ALEKSEEV	{"phone": "+70561272937"}
0005434723494	6AA60F	2890 584126	FEDOR PETROV	{"email": "f-petrov_13041967@postgrespro.ru", "phone": "+70752563258"}
0005434723495	7155BC	9991 528741	ELENA KUZNECOVA	{"phone": "+70994425255"}
0005434723496	EE33E3	4979 855239	EVGENIY ANTONOV	{"phone": "+70974389051"}
0005434723497	965361	0220 800928	ALEKSANDR MIRONOV	{"email": "aleksandrmironov121969@postgrespro.ru", "phone": "+70447202990"}
0005434723498	965361	2221 124174	NATALYA MOISEEVA	{"phone": "+70233994080"}
0005434723499	425BD0	0977 346904	KRISTINA KUZNECOVA	{"email": "kuznecova_kristina.121978@postgrespro.ru", "phone": "+70578929811"}
0005434723500	DED3CA	7905 813132	MARINA KUZMINA	{"phone": "+70381210209"}
0005434723501	6103C1	9992 228163	DARYA PAVLOVA	{"phone": "+70276380894"}
0005434723502	6103C1	2665 939053	VLADIMIR KOZLOV	{"phone": "+70343516374"}
0005434723503	B80717	6369 725239	DMITRIY ZAKHAROV	{"phone": "+70813958463"}
0005434723504	2C9A1C	9318 472653	SERGEY MAKSIMOV	{"phone": "+70471406643"}
0005434723505	4DD5A8	4782 746481	ALEKSEY ZHURAVLEV	{"email": "zhuravlev-aleksey_1984@postgrespro.ru", "phone": "+70470477146"}
0005434723506	4DD5A8	4370 389894	PRASKOVYA CHERNOVA	{"phone": "+70096490830"}
0005434723507	4DD5A8	1641 086667	ALEKSANDR MELNIKOV	{"email": "melnikov-aleksandr_05061969@postgrespro.ru", "phone": "+70966412546"}
0005434723508	F17ACB	7460 307137	VLADIMIR MAKAROV	{"phone": "+70243991730"}
0005434723509	DA9AE6	1149 802056	VALENTINA KOZLOVA	{"email": "kozlovav.20111960@postgrespro.ru", "phone": "+70203318586"}
0005434723510	DA9AE6	7732 724555	ELENA TIMOFEEVA	{"email": "timofeeva-elena.071964@postgrespro.ru", "phone": "+70804178387"}
0005434723511	3ED724	7866 591893	STANISLAV BELOV	{"email": "s.belov24071970@postgrespro.ru", "phone": "+70472999725"}
0005434723512	3ED724	6597 525983	RAFIK KUZNECOV	{"phone": "+70357963389"}
0005434723513	18F23A	2010 972720	ALEKSANDR ZHUKOV	{"email": "azhukov061966@postgrespro.ru", "phone": "+70515976593"}
0005434723515	F3BA52	7456 691828	ELENA MIKHAYLOVA	{"phone": "+70875347607"}
0005434723516	F3BA52	9418 787412	ROZA NESTEROVA	{"email": "r-nesterova101967@postgrespro.ru", "phone": "+70125557495"}
0005434723517	1D975A	2985 083010	RUSLAN MATVEEV	{"phone": "+70643544798"}
0005434723518	C2B79B	4064 154463	SERGEY GORBUNOV	{"email": "gorbunov.sergey_19041966@postgrespro.ru", "phone": "+70590416093"}
0005434723519	3CD329	2114 919034	OLGA PETROVA	{"email": "o_petrova-1971@postgrespro.ru", "phone": "+70832125581"}
0005434723520	7F33BD	1438 410057	NATALYA IVANOVA	{"phone": "+70421908106"}
0005434723521	7F33BD	2193 592890	ANASTASIYA DAVYDOVA	{"phone": "+70391418968"}
0005434723522	9FDA62	3467 750370	IRINA ANTONOVA	{"phone": "+70229404933"}
0005434723523	54E760	9720 799075	VALENTINA MELNIKOVA	{"phone": "+70418707755"}
0005434723524	425DAA	9947 866325	DMITRIY OSIPOV	{"phone": "+70868357781"}
0005434723525	425DAA	7004 158739	NATALYA ANDREEVA	{"email": "andreeva_natalya-22071974@postgrespro.ru", "phone": "+70819960882"}
0005434723526	425DAA	5793 546290	ANASTASIYA CHERNOVA	{"phone": "+70825475579"}
0005434723527	1ECB2C	8182 250442	ELIZAVETA POLYAKOVA	{"phone": "+70091672599"}
0005434723528	85BF4D	6756 085485	ARTEM RODIONOV	{"email": "artem.rodionov-071966@postgrespro.ru", "phone": "+70266551256"}
0005434723529	B38FCF	7828 799011	MARINA ALEKSEEVA	{"email": "alekseeva_m.06051972@postgrespro.ru", "phone": "+70686139863"}
0005434723530	B38FCF	5537 671012	SERGEY POPOV	{"email": "sergey.popov12081966@postgrespro.ru", "phone": "+70991362024"}
0005434723531	11473F	4377 768721	ANTONINA EGOROVA	{"email": "antonina_egorova1974@postgrespro.ru", "phone": "+70989024724"}
0005434723532	65ED3E	2111 694451	NATALYA OVCHINNIKOVA	{"phone": "+70147859392"}
0005434723533	D73B72	0636 919293	TAMARA CHERNOVA	{"email": "tamara_chernova.1970@postgrespro.ru", "phone": "+70541841906"}
0005434723534	D73B72	7707 217325	MARINA CHERNOVA	{"phone": "+70972222134"}
0005434723536	A80A9D	0747 011151	MAKSIM SMIRNOV	{"phone": "+70688224142"}
0005434723537	130E87	0448 063948	ALEKSANDRA RODIONOVA	{"email": "aleksandra.rodionova_1978@postgrespro.ru", "phone": "+70006253890"}
0005434723538	F466BF	6042 990487	MARINA VOLKOVA	{"phone": "+70910119537"}
0005434723539	56B819	8478 781162	ELENA DENISOVA	{"phone": "+70226111910"}
0005434723540	1B514B	0559 878837	ELENA KULIKOVA	{"email": "elena-kulikova-1961@postgrespro.ru", "phone": "+70451351712"}
0005434723541	D42F4D	1790 580099	LIDIYA NIKITINA	{"email": "l_nikitina1974@postgrespro.ru", "phone": "+70416236903"}
0005434723542	D42F4D	4059 156129	ILGIZ ABRAMOV	{"email": "ilgizabramov-1967@postgrespro.ru", "phone": "+70104622819"}
0005434723543	2936D1	2740 213657	ANNA SERGEEVA	{"email": "sergeevaa.21051972@postgrespro.ru", "phone": "+70039434094"}
0005434723544	2936D1	4168 776844	LYUDMILA VASILEVA	{"phone": "+70773273742"}
0005434723545	FCCE4F	5140 645939	ALEKSEY SERGEEV	{"phone": "+70377475467"}
0005434723546	FCCE4F	9081 408004	ANASTASIYA VLASOVA	{"email": "vlasova_a-07041965@postgrespro.ru", "phone": "+70432915906"}
0005434723547	6C6C96	9883 008035	SVETLANA ISAEVA	{"email": "isaeva_s041977@postgrespro.ru", "phone": "+70434264338"}
0005434723548	6C6C96	3059 124945	ANATOLIY MARTYNOV	{"email": "a-martynov_1966@postgrespro.ru", "phone": "+70218341259"}
0005434723549	D4C72C	1839 440474	ALLA SMIRNOVA	{"phone": "+70455320925"}
0005434723550	D4C72C	4719 549946	NADEZHDA VASILEVA	{"email": "vasilevan121982@postgrespro.ru", "phone": "+70623479068"}
0005434723551	BD544E	3235 077472	ALEKSANDR ABRAMOV	{"email": "aleksandrabramov1973@postgrespro.ru", "phone": "+70906068233"}
0005434723552	BD544E	0219 491870	OLGA NIKITINA	{"email": "nikitina-olga.1967@postgrespro.ru", "phone": "+70014575954"}
0005434723553	303881	9819 818260	IRINA PETROVA	{"email": "irinapetrova.011976@postgrespro.ru", "phone": "+70283834044"}
0005434723554	31C3C3	9579 424692	NIKOLAY SAVELEV	{"phone": "+70446916771"}
0005434723555	8EC407	0788 653680	NINA ANTONOVA	{"email": "antonova.nina_25081975@postgrespro.ru", "phone": "+70445495488"}
0005434723556	8EC407	5332 062041	YURIY VASILEV	{"phone": "+70874383978"}
0005434723557	1E7452	7996 006108	SVETLANA AFANASEVA	{"phone": "+70508228851"}
0005434723558	1E7452	0262 622009	ANDREY SCHERBAKOV	{"phone": "+70861955850"}
0005434723559	7794D1	0930 432234	TATYANA SERGEEVA	{"phone": "+70898097688"}
0005434723560	7794D1	7984 436236	ANTONINA KOZLOVA	{"phone": "+70170167099"}
0005434723561	7DAE1A	8386 569668	ALEKSANDR KISELEV	{"email": "kiseleva021974@postgrespro.ru", "phone": "+70149741907"}
0005434723562	2E0E2C	9376 815312	DMITRIY VOLKOV	{"email": "d-volkov-041985@postgrespro.ru", "phone": "+70029559983"}
0005434723563	45753E	9834 598492	ANASTASIYA IVANOVA	{"phone": "+70976283256"}
0005434723564	143202	6760 282107	ANATOLIY KARPOV	{"phone": "+70561403917"}
0005434723565	143202	4944 089492	VLADIMIR MATVEEV	{"email": "vladimirmatveev-081966@postgrespro.ru", "phone": "+70593220454"}
0005434723566	21477F	8651 090205	OLEG NIKOLAEV	{"email": "onikolaev_081970@postgrespro.ru", "phone": "+70359803995"}
0005434723567	DE4FCB	3223 822194	IRINA TROFIMOVA	{"phone": "+70322603926"}
0005434723568	2BD77B	9037 420028	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev-111979@postgrespro.ru", "phone": "+70832875740"}
0005434723569	29A623	1295 623366	MARIYA VASILEVA	{"phone": "+70309345486"}
0005434723570	44F6E6	4120 998387	LYUBOV FILATOVA	{"email": "filatova.l-051972@postgrespro.ru", "phone": "+70092018219"}
0005434723571	5CB88B	3321 977128	VLADIMIR VLASOV	{"phone": "+70672400396"}
0005434723572	5CB88B	0876 878538	OLEG POPOV	{"email": "popovo011968@postgrespro.ru", "phone": "+70538102847"}
0005434723573	DC1425	9084 405724	ANATOLIY GORBUNOV	{"phone": "+70786644809"}
0005434723574	DC1425	3374 319578	VALERIY SCHERBAKOV	{"email": "scherbakov_valeriy28121973@postgrespro.ru", "phone": "+70535729728"}
0005434723575	4999ED	8192 302699	VASILIY KOROLEV	{"phone": "+70682618319"}
0005434723576	4999ED	5792 466053	LUIZA ANTONOVA	{"phone": "+70770564594"}
0005434723577	1B9779	1815 619035	TATYANA AFANASEVA	{"email": "tafanaseva.1972@postgrespro.ru", "phone": "+70902148354"}
0005434723578	97CC6A	7023 015705	SOFIYA ALEKSEEVA	{"email": "s-alekseeva_1968@postgrespro.ru", "phone": "+70691707689"}
0005434723579	97CC6A	6079 766061	IRINA GUSEVA	{"email": "irina-guseva-17051969@postgrespro.ru", "phone": "+70585783234"}
0005434723580	97CC6A	7053 932767	VIKTOR ALEKSEEV	{"phone": "+70232012535"}
0005434723581	FF2E8B	3280 524690	KRISTINA PETROVA	{"phone": "+70268097321"}
0005434723582	83784D	5591 963418	MARINA VASILEVA	{"email": "vasilevamarina_1974@postgrespro.ru", "phone": "+70254783451"}
0005434723583	83784D	7851 374036	ANASTASIYA SERGEEVA	{"email": "sergeeva.anastasiya_1968@postgrespro.ru", "phone": "+70363132798"}
0005434723584	7C9410	5524 706330	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova.natalya1988@postgrespro.ru", "phone": "+70140638423"}
0005434723585	1E95AE	3052 339381	MIKHAIL KUZNECOV	{"phone": "+70882245008"}
0005434723586	4ADE8A	5250 212182	SVETLANA KONOVALOVA	{"phone": "+70147637993"}
0005434723587	52EECD	1210 172385	SERGEY MOROZOV	{"email": "morozov_s-1979@postgrespro.ru", "phone": "+70018743310"}
0005434723588	3BE7C3	9714 919020	ARTEM MAKAROV	{"phone": "+70571897107"}
0005434723589	3BE7C3	5189 536041	SERGEY GUSEV	{"email": "sergey_gusev-07091972@postgrespro.ru", "phone": "+70951056527"}
0005434723590	1C6DDA	5708 085783	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova_lyudmila.1965@postgrespro.ru", "phone": "+70108736908"}
0005434723591	9302BD	7368 446391	SERGEY FROLOV	{"email": "frolov.sergey_27111962@postgrespro.ru", "phone": "+70927905735"}
0005434723592	453F78	3099 268593	VERONIKA KRASNOVA	{"email": "krasnova.v_16101960@postgrespro.ru", "phone": "+70691884757"}
0005434723593	7C7A40	5470 237603	ANTON NIKOLAEV	{"email": "nikolaev-anton_1972@postgrespro.ru", "phone": "+70500914994"}
0005434723594	7C7A40	9471 835796	ALEKSANDR VOROBEV	{"email": "a-vorobev_101970@postgrespro.ru", "phone": "+70903889557"}
0005434723595	A87C53	9825 882275	KONSTANTIN GRIGOREV	{"phone": "+70553548255"}
0005434723596	A87C53	7064 073598	VLADIMIR NIKOLAEV	{"phone": "+70834043731"}
0005434723653	D91684	9659 536587	NIKITA VOLKOV	{"phone": "+70078021821"}
0005434723597	D03848	0097 008389	ANTONINA EFIMOVA	{"email": "efimovaantonina_051966@postgrespro.ru", "phone": "+70492735823"}
0005434723598	D03848	6412 555497	IRINA DENISOVA	{"email": "irina-denisova-1980@postgrespro.ru", "phone": "+70699901194"}
0005434723599	80C9CC	6848 571374	GALINA TIKHONOVA	{"phone": "+70561099884"}
0005434723600	80C9CC	7809 612294	NIKITA BONDARENKO	{"phone": "+70498703128"}
0005434723601	3F91C0	2525 451061	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr.121968@postgrespro.ru", "phone": "+70273549039"}
0005434723602	3F91C0	3380 509049	ALEKSEY ILIN	{"phone": "+70775012285"}
0005434723603	0BE977	9275 604000	ARTEM FEDOROV	{"email": "fedorov-artem-14101972@postgrespro.ru", "phone": "+70095632666"}
0005434723604	0BE977	7084 464178	TATYANA KUZNECOVA	{"phone": "+70800225140"}
0005434723605	0BE977	0670 370140	ALEKSANDR ZAKHAROV	{"phone": "+70755389728"}
0005434723606	5983A5	1367 452723	NATALIYA BELYAEVA	{"email": "belyaeva_n-021970@postgrespro.ru", "phone": "+70110463980"}
0005434723607	09432E	9657 973133	KIRILL MIKHAYLOV	{"email": "k.mikhaylov_28121967@postgrespro.ru", "phone": "+70223914672"}
0005434723608	09432E	7003 621514	VALENTINA SERGEEVA	{"email": "sergeeva-valentina_1970@postgrespro.ru", "phone": "+70488849075"}
0005434723609	3B69D3	3357 479718	ANDREY KUZNECOV	{"phone": "+70517858880"}
0005434723610	1B9770	6311 974961	MARIYA KUDRYASHOVA	{"email": "m.kudryashova.17021976@postgrespro.ru", "phone": "+70581121338"}
0005434723611	2D509A	3125 885133	PETR SOROKIN	{"phone": "+70967260993"}
0005434723612	719D45	1541 316661	MARIYA VASILEVA	{"email": "mvasileva17071976@postgrespro.ru", "phone": "+70832832892"}
0005434723613	331374	2605 011932	GALINA LAZAREVA	{"email": "galinalazareva021975@postgrespro.ru", "phone": "+70417195574"}
0005434723614	4B62AC	2074 292442	TATYANA POPOVA	{"email": "popova.t_23031967@postgrespro.ru", "phone": "+70137885438"}
0005434723615	AE0C87	9329 609246	DENIS ISAEV	{"phone": "+70631233095"}
0005434723616	2FFC32	4707 159889	ANDREY KONOVALOV	{"email": "konovalov-a-071958@postgrespro.ru", "phone": "+70863505711"}
0005434723617	2FFC32	2982 050073	EVGENIY MOISEEV	{"email": "moiseevevgeniy091980@postgrespro.ru", "phone": "+70871649300"}
0005434723618	C91C61	6601 063764	MARIYA MATVEEVA	{"email": "matveeva.m_101973@postgrespro.ru", "phone": "+70594744073"}
0005434723619	CD77CE	6171 069845	DMITRIY NAZAROV	{"email": "nazarov_d_081977@postgrespro.ru", "phone": "+70774795677"}
0005434723620	5B5AD4	7833 350922	OLGA MATVEEVA	{"phone": "+70694258884"}
0005434723621	5B5AD4	9507 035982	NATALYA LOGINOVA	{"email": "natalyaloginova.041969@postgrespro.ru", "phone": "+70314278403"}
0005434723622	A38FB6	9621 383866	LYUDMILA ALEKSANDROVA	{"phone": "+70000531894"}
0005434723623	DEF7A2	8924 901111	ROZA GORBUNOVA	{"phone": "+70804720312"}
0005434723624	DEF7A2	0554 232235	SERGEY GAVRILOV	{"phone": "+70722876507"}
0005434723625	02CD0E	8728 966221	VYACHESLAV PAVLOV	{"phone": "+70003042905"}
0005434723626	0A970B	7637 080851	ARTUR GORBUNOV	{"phone": "+70188724617"}
0005434723627	0E38A2	2214 954933	EVGENIYA VLASOVA	{"email": "vlasova_e.1961@postgrespro.ru", "phone": "+70684948241"}
0005434723628	8A7F26	4669 349534	NADEZHDA MEDVEDEVA	{"phone": "+70477379392"}
0005434723629	64EAF9	3417 715627	ANDREY ZHUKOV	{"email": "a-zhukov-1981@postgrespro.ru", "phone": "+70264619759"}
0005434723630	44AD6B	7181 184007	GALINA BARANOVA	{"email": "galina.baranova_1971@postgrespro.ru", "phone": "+70778340916"}
0005434723631	44AD6B	2142 433015	PRASKOVYA ZAYCEVA	{"email": "zayceva_p_09011976@postgrespro.ru", "phone": "+70036848954"}
0005434723632	27D80C	9691 822020	ELENA KUZNECOVA	{"email": "kuznecova-e04041991@postgrespro.ru", "phone": "+70355421966"}
0005434723633	27D80C	3245 956692	ANNA MAKAROVA	{"phone": "+70127270073"}
0005434723634	F193CF	6751 239836	MILANA TROFIMOVA	{"email": "m-trofimova_1980@postgrespro.ru", "phone": "+70877298505"}
0005434723635	F193CF	4867 103850	YULIYA NOVIKOVA	{"phone": "+70663212688"}
0005434723636	513418	3564 588444	ALEKSEY FOMIN	{"email": "fomin_aleksey.051978@postgrespro.ru", "phone": "+70358161667"}
0005434723637	0FA420	3417 978580	MARINA ALEKSANDROVA	{"email": "aleksandrova_marina_23051971@postgrespro.ru", "phone": "+70720488646"}
0005434723638	CA5C1B	3530 519929	PETR ALEKSEEV	{"email": "alekseevp-031971@postgrespro.ru", "phone": "+70165117402"}
0005434723639	2548C8	3621 178574	ANDREY KULIKOV	{"phone": "+70833024046"}
0005434723640	86BFD3	4376 638720	ANDREY NIKITIN	{"phone": "+70661627933"}
0005434723641	AA4AF8	3100 120139	ELENA NAZAROVA	{"email": "nazarova_e_121977@postgrespro.ru", "phone": "+70204989524"}
0005434723642	525ECC	3256 466028	ALEKSANDR SEMENOV	{"email": "semenova1991@postgrespro.ru", "phone": "+70868531491"}
0005434723643	249E23	0722 045072	TAMARA CHERNOVA	{"phone": "+70734829235"}
0005434723644	249E23	8752 553599	RAISA POPOVA	{"email": "rpopova.021980@postgrespro.ru", "phone": "+70838452186"}
0005434723645	F6D0A8	8986 869481	VYACHESLAV KONOVALOV	{"email": "v_konovalov_1988@postgrespro.ru", "phone": "+70662612614"}
0005434723646	4ACDBE	4270 769734	ALEKSANDR ROMANOV	{"phone": "+70897684235"}
0005434723647	4ACDBE	8137 406032	SERGEY MIRONOV	{"phone": "+70629840781"}
0005434723648	85A95B	5438 114041	ALEKSANDR KUZNECOV	{"phone": "+70084421533"}
0005434723649	9995A2	8327 761257	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov-011975@postgrespro.ru", "phone": "+70433837386"}
0005434723650	9995A2	4575 534996	ALEKSEY SOKOLOV	{"phone": "+70592454125"}
0005434723651	496AAC	4408 861409	ELENA ISAEVA	{"phone": "+70192608865"}
0005434723652	29068A	5612 614957	OLEG SCHERBAKOV	{"phone": "+70195737216"}
0005434723654	C7F35F	5832 129174	VALENTINA AFANASEVA	{"email": "afanasevavalentina.1975@postgrespro.ru", "phone": "+70689413441"}
0005434723655	54A721	2310 310780	ALEKSEY GERASIMOV	{"phone": "+70714075009"}
0005434723656	29248C	3626 169503	ELENA POPOVA	{"email": "elena_popova11121972@postgrespro.ru", "phone": "+70752187277"}
0005434723657	0D5978	5012 162534	SVETLANA ZHUKOVA	{"email": "zhukova-svetlana1983@postgrespro.ru", "phone": "+70851163463"}
0005434723658	446A3C	4691 794801	ARTUR NOVIKOV	{"email": "arturnovikov-031979@postgrespro.ru", "phone": "+70529275186"}
0005434723659	446A3C	2710 537601	NIKOLAY ZHUKOV	{"email": "nikolay_zhukov_23081974@postgrespro.ru", "phone": "+70801694660"}
0005434723660	349309	4651 496204	KONSTANTIN SMIRNOV	{"phone": "+70586087540"}
0005434723661	349309	4115 463992	NIKOLAY MEDVEDEV	{"phone": "+70770618469"}
0005434723662	DA637E	4930 514101	VLADIMIR PAVLOV	{"email": "pavlov.v1976@postgrespro.ru", "phone": "+70526144969"}
0005434723663	DA637E	1995 250823	SERGEY YAKOVLEV	{"email": "yakovlevs_03041965@postgrespro.ru", "phone": "+70189950995"}
0005434723664	DA637E	3140 011640	MARINA ZHURAVLEVA	{"phone": "+70912490110"}
0005434723665	72B030	7253 761867	LYUBOV BELYAEVA	{"phone": "+70231686504"}
0005434723666	9F12C4	0551 692984	KSENIYA FOMINA	{"email": "fomina.k-011967@postgrespro.ru", "phone": "+70940630326"}
0005434723667	014CC4	2232 817082	GALINA IVANOVA	{"email": "givanova081971@postgrespro.ru", "phone": "+70647299752"}
0005434723668	014CC4	3832 633260	TATYANA GAVRILOVA	{"phone": "+70579228067"}
0005434723669	2F8557	6029 078208	VITALIY BORISOV	{"email": "borisov_v-03071961@postgrespro.ru", "phone": "+70786232222"}
0005434723670	2F8557	8714 440636	ZHANNA MOROZOVA	{"email": "z.morozova_111977@postgrespro.ru", "phone": "+70190138777"}
0005434723671	2F8557	5220 664774	PAVEL KUZNECOV	{"phone": "+70935396169"}
0005434723672	F037F6	7781 050195	KIRILL ROMANOV	{"phone": "+70038663910"}
0005434723673	6ECF26	4730 927805	ARTEM KUZNECOV	{"email": "artemkuznecov09091986@postgrespro.ru", "phone": "+70508895814"}
0005434723674	A44CFA	2154 910931	LYUBOV EFREMOVA	{"email": "efremoval-27071975@postgrespro.ru", "phone": "+70936811656"}
0005434723675	7BAC3A	9176 455156	LYUBOV ERMAKOVA	{"email": "lyubov-ermakova.111981@postgrespro.ru", "phone": "+70988518942"}
0005434723676	0559C7	2237 967839	DMITRIY ALEKSEEV	{"email": "d-alekseev-061971@postgrespro.ru", "phone": "+70755463638"}
0005434723677	0559C7	3350 069668	NADEZHDA DAVYDOVA	{"email": "nadezhda_davydova.18091972@postgrespro.ru", "phone": "+70154188845"}
0005434723678	B86CBC	7422 314424	IRINA VOLKOVA	{"email": "volkova.i041977@postgrespro.ru", "phone": "+70858839552"}
0005434723679	1FFE20	1827 850672	DENIS ZHUKOV	{"email": "zhukov.d1977@postgrespro.ru", "phone": "+70975929346"}
0005434723680	1C8EE5	3153 539380	EVGENIYA KRASNOVA	{"phone": "+70790456532"}
0005434723681	1C8EE5	8414 757757	ELENA MAKAROVA	{"phone": "+70206507781"}
0005434723682	1C8EE5	5233 309606	NIKITA MAKAROV	{"phone": "+70303925820"}
0005434723683	37091D	6686 864596	VALENTINA KOVALEVA	{"email": "v.kovaleva1965@postgrespro.ru", "phone": "+70500412666"}
0005434723684	8E0D20	5256 220863	ALEKSEY TARASOV	{"phone": "+70632151846"}
0005434723685	E4B84F	1717 546254	ALEKSANDR VASILEV	{"phone": "+70082131385"}
0005434723686	912058	8590 412505	ALEKSANDR POPOV	{"email": "popov_aleksandr.23051965@postgrespro.ru", "phone": "+70256816690"}
0005434723687	5ABA0A	9356 130155	ANDREY MARTYNOV	{"phone": "+70293876191"}
0005434723688	BA139E	5727 987406	TAISIYA SOKOLOVA	{"email": "tsokolova21041966@postgrespro.ru", "phone": "+70070681861"}
0005434723689	E12C3E	9539 053811	SERGEY FILIPPOV	{"phone": "+70290335047"}
0005434723690	106862	7765 487966	ALEKSANDR MELNIKOV	{"email": "a_melnikov_1965@postgrespro.ru", "phone": "+70460555010"}
0005434723691	106862	9710 996097	TAMARA MOROZOVA	{"phone": "+70242337564"}
0005434723692	BBDD76	6874 750431	DARYA FOMINA	{"phone": "+70752283026"}
0005434723693	6239EE	2651 545412	TATYANA BORISOVA	{"phone": "+70333180278"}
0005434723694	AAFAA2	5945 182705	VIKTORIYA KOROLEVA	{"phone": "+70214492679"}
0005434723695	BDA668	9715 764930	SERGEY NIKOLAEV	{"email": "nikolaevsergey-011970@postgrespro.ru", "phone": "+70076291574"}
0005434723696	BDA668	2598 930535	LYUDMILA NESTEROVA	{"phone": "+70453794461"}
0005434723697	B0827E	8108 214951	ANTONINA AFANASEVA	{"phone": "+70489310895"}
0005434723698	1B6924	9843 406980	ANNA MASLOVA	{"phone": "+70816321569"}
0005434723699	0B5E6F	4177 240975	VALENTINA MIRONOVA	{"phone": "+70659963147"}
0005434723700	82D590	9714 564978	SERGEY NIKOLAEV	{"email": "sergeynikolaev-09111965@postgrespro.ru", "phone": "+70766957856"}
0005434723701	82D590	1889 197425	MARINA TIMOFEEVA	{"email": "timofeeva.marina.011979@postgrespro.ru", "phone": "+70928969721"}
0005434723702	028B50	2346 097492	VERONIKA BELOVA	{"phone": "+70128426076"}
0005434723703	A8BD24	9881 422013	ALEKSANDRA NIKITINA	{"phone": "+70206677492"}
0005434723704	A8BD24	1028 487321	EVGENIY NAUMOV	{"email": "naumovevgeniy-051968@postgrespro.ru", "phone": "+70391646983"}
0005434723705	A8BD24	2750 124460	VALENTINA TITOVA	{"phone": "+70441440209"}
0005434723706	AA2645	5890 659994	ALEKSANDR KONOVALOV	{"phone": "+70118490409"}
0005434723707	7AAA35	3979 450779	ALEKSEY ALEKSEEV	{"email": "alekseev_aleksey-1980@postgrespro.ru", "phone": "+70964576367"}
0005434723708	A85B36	1405 797114	ANDREY FEDOTOV	{"email": "andrey-fedotov.051966@postgrespro.ru", "phone": "+70025167706"}
0005434723709	494852	4409 779399	ANDREY BORISOV	{"phone": "+70499497720"}
0005434723710	62999C	1689 483078	GALINA SERGEEVA	{"email": "sergeevag111966@postgrespro.ru", "phone": "+70346564813"}
0005434723711	01273A	0959 476244	MARIYA MAKAROVA	{"email": "mariyamakarova_1966@postgrespro.ru", "phone": "+70737460238"}
0005434723712	A167BB	4506 650583	ALEKSANDR EGOROV	{"phone": "+70483331238"}
0005434723713	A167BB	7946 763671	LYUDMILA DANILOVA	{"email": "daniloval05101982@postgrespro.ru", "phone": "+70870114993"}
0005434723714	3BF6CB	9065 935725	VLADIMIR KONOVALOV	{"email": "vladimir.konovalov_081970@postgrespro.ru", "phone": "+70112108516"}
0005434723715	2F6889	9176 172714	ANASTASIYA MASLOVA	{"email": "anastasiya-maslova_29031981@postgrespro.ru", "phone": "+70959435553"}
0005434723716	3E8BED	2737 247896	EKATERINA ARKHIPOVA	{"email": "earkhipova-1978@postgrespro.ru", "phone": "+70346207397"}
0005434723717	3E8BED	7324 128728	MARIYA KOZLOVA	{"email": "mariyakozlova-1983@postgrespro.ru", "phone": "+70215383241"}
0005434723718	9F565E	2872 634950	NINA STEPANOVA	{"phone": "+70368154368"}
0005434723719	9F565E	0015 976478	MAKSIM ANTONOV	{"email": "maksim.antonov_02061983@postgrespro.ru", "phone": "+70185131080"}
0005434723720	B8DB34	1909 522569	VIKTOR VOLKOV	{"phone": "+70858057032"}
0005434723721	227C70	9313 099591	SERGEY SERGEEV	{"phone": "+70686271854"}
0005434723722	CC52A3	8920 740586	VLADISLAV STEPANOV	{"phone": "+70500214729"}
0005434723723	CC52A3	8101 013326	TATYANA VLASOVA	{"email": "t.vlasova.1965@postgrespro.ru", "phone": "+70841281554"}
0005434723724	E4050B	3412 692612	ELENA GAVRILOVA	{"email": "gavrilovae24061977@postgrespro.ru", "phone": "+70803741432"}
0005434723725	CE2BAE	5370 230994	RUSLAN ABRAMOV	{"phone": "+70593170779"}
0005434723726	FDCA17	4557 270160	EVGENIY ROMANOV	{"email": "e-romanov.1972@postgrespro.ru", "phone": "+70957137494"}
0005434723727	FDCA17	9682 937846	TATYANA AFANASEVA	{"email": "tatyana-afanaseva-22041975@postgrespro.ru", "phone": "+70169483773"}
0005434723728	FDCA17	4906 047103	SERGEY AFANASEV	{"email": "afanasevs-021971@postgrespro.ru", "phone": "+70532954501"}
0005434723729	FB1F6E	0852 617777	VERA PAVLOVA	{"phone": "+70083536516"}
0005434723730	271936	4745 693319	VALERIYA FEDOROVA	{"phone": "+70479380044"}
0005434723731	0B452E	8739 145919	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov1972@postgrespro.ru", "phone": "+70779651808"}
0005434723732	2BAE94	2606 208589	ALBINA AFANASEVA	{"email": "albinaafanaseva_101965@postgrespro.ru", "phone": "+70735435957"}
0005434723733	A182C6	6570 775732	ANDREY ISAEV	{"phone": "+70364437758"}
0005434723734	FA31B3	5928 384896	ANDREY TARASOV	{"phone": "+70284435349"}
0005434723735	797171	3061 715699	KSENIYA AFANASEVA	{"phone": "+70299075372"}
0005434723736	FB37CB	4471 002062	INGA TROFIMOVA	{"phone": "+70343840147"}
0005434723737	B924C6	1396 974890	MARIYA SMIRNOVA	{"phone": "+70461818046"}
0005434723738	B924C6	0433 337791	MARIYA AFANASEVA	{"email": "afanasevamariya-1966@postgrespro.ru", "phone": "+70188922243"}
0005434723739	B924C6	2913 321372	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov_021971@postgrespro.ru", "phone": "+70308347734"}
0005434723740	408644	9227 160542	ALEKSANDR TIMOFEEV	{"email": "timofeev.aleksandr1971@postgrespro.ru", "phone": "+70111573259"}
0005434723741	408644	0316 125617	VALENTINA LAZAREVA	{"phone": "+70830386763"}
0005434723742	A0BEC3	8018 688504	SOFIYA KOROLEVA	{"email": "korolevas-05041975@postgrespro.ru", "phone": "+70897636394"}
0005434723743	AD3904	3980 700484	ANATOLIY ZAKHAROV	{"email": "a.zakharov.28081971@postgrespro.ru", "phone": "+70682747901"}
0005434723744	4E7B1E	9429 543619	ALEKSANDR VLASOV	{"email": "a-vlasov.1972@postgrespro.ru", "phone": "+70648237822"}
0005434723745	9352B7	4256 670990	ANDREY PETROV	{"phone": "+70621581822"}
0005434723746	28FD0F	5622 923031	VERONIKA POPOVA	{"phone": "+70092147469"}
0005434723747	28FD0F	9951 559043	ANDREY TARASOV	{"email": "andrey_tarasov.1982@postgrespro.ru", "phone": "+70997594278"}
0005434723748	28FD0F	0744 294189	DIANA IVANOVA	{"email": "ivanovadiana_1965@postgrespro.ru", "phone": "+70371880605"}
0005434723749	C6395D	8423 380524	LYUDMILA FADEEVA	{"email": "fadeeva-l-28071965@postgrespro.ru", "phone": "+70385386735"}
0005434723750	C5AE65	9990 727635	ALEKSEY PAVLOV	{"phone": "+70650639878"}
0005434723751	43008B	9776 181244	EKATERINA DMITRIEVA	{"email": "ekaterina-dmitrieva11061975@postgrespro.ru", "phone": "+70172089105"}
0005434723752	1BDA43	2057 506135	VITALIY SIDOROV	{"email": "sidorovv-1973@postgrespro.ru", "phone": "+70698904356"}
0005434723753	AA08B9	2008 248978	VALENTINA KONDRATEVA	{"email": "kondratevav.20071976@postgrespro.ru", "phone": "+70497294185"}
0005434723754	0DA4F9	7851 856519	ULYANA MAKAROVA	{"phone": "+70657482210"}
0005434723755	0DA4F9	5968 839441	DMITRIY NIKOLAEV	{"phone": "+70558881865"}
0005434723756	0DA4F9	1250 852422	NATALYA ZAYCEVA	{"email": "zaycevanatalya08011971@postgrespro.ru", "phone": "+70155846644"}
0005434723757	E8084A	8168 756364	NIKOLAY KUZMIN	{"phone": "+70999684777"}
0005434723758	E8084A	4836 466126	ZINAIDA NAUMOVA	{"email": "zinaida-naumova-1972@postgrespro.ru", "phone": "+70097843032"}
0005434723759	79914C	2642 155765	NADEZHDA KRASNOVA	{"email": "nadezhdakrasnova_101972@postgrespro.ru", "phone": "+70412998161"}
0005434723760	7956C1	9162 121702	VERA ZAKHAROVA	{"email": "verazakharova-1984@postgrespro.ru", "phone": "+70498964833"}
0005434723761	A0E419	1606 778351	MARIYA SCHERBAKOVA	{"phone": "+70007404070"}
0005434723762	BA5750	9267 076155	ANDREY FROLOV	{"email": "frolov.andrey-05091980@postgrespro.ru", "phone": "+70226005676"}
0005434723763	081F7F	2139 084810	OLGA RYABOVA	{"phone": "+70305971678"}
0005434723764	081F7F	7643 417612	ANASTASIYA ZAKHAROVA	{"phone": "+70340222828"}
0005434723765	F79E5F	9731 992406	EKATERINA YAKOVLEVA	{"phone": "+70159674646"}
0005434723766	F79E5F	7152 522700	ANNA POLYAKOVA	{"phone": "+70308272782"}
0005434723767	421E72	8331 936903	ALEKSANDR ANTONOV	{"phone": "+70817200708"}
0005434723768	844E0A	4223 223456	VLADIMIR YAKOVLEV	{"email": "yakovlevv-111973@postgrespro.ru", "phone": "+70767291213"}
0005434723769	840081	5528 479819	VIKTORIYA DAVYDOVA	{"phone": "+70683283560"}
0005434723770	F2D204	8815 529673	ANNA POTAPOVA	{"email": "apotapova1969@postgrespro.ru", "phone": "+70809388811"}
0005434723771	8FCD39	3660 787805	LYUBOV NIKITINA	{"phone": "+70458423519"}
0005434723772	04DFF8	3877 209548	POLINA OVCHINNIKOVA	{"phone": "+70163781840"}
0005434723773	04DFF8	0196 232082	VALERIY ALEKSEEV	{"phone": "+70184871455"}
0005434723774	FEF3FF	4667 679784	LILIYA NIKITINA	{"phone": "+70284904182"}
0005434723775	739B7B	4178 745198	GALINA MOISEEVA	{"email": "moiseevag-13071972@postgrespro.ru", "phone": "+70850022865"}
0005434723776	DE4EAE	1772 511477	MIKHAIL KUZNECOV	{"phone": "+70068857833"}
0005434723777	836613	4762 727432	OLGA PAVLOVA	{"phone": "+70513167189"}
0005434723778	836613	5408 249660	ALEKSANDR ROMANOV	{"phone": "+70498665729"}
0005434723779	836613	8209 577981	YURIY KRASNOV	{"phone": "+70566632148"}
0005434723780	E5C566	2321 180590	STANISLAV POPOV	{"email": "popov_stanislav.041960@postgrespro.ru", "phone": "+70706120310"}
0005434723781	A62C52	3079 428078	DMITRIY KARPOV	{"email": "dmitriy_karpov1981@postgrespro.ru", "phone": "+70741268997"}
0005434723782	A62C52	7601 799974	DMITRIY MEDVEDEV	{"phone": "+70563424194"}
0005434723783	D1D4FF	3517 330076	MARIYA BELOVA	{"phone": "+70826421943"}
0005434723784	36E0E9	5000 256681	VALENTINA TARASOVA	{"email": "tarasova_valentina.1979@postgrespro.ru", "phone": "+70983447425"}
0005434723785	36E0E9	5607 072606	VYACHESLAV ANDREEV	{"email": "andreev-vyacheslav_16021961@postgrespro.ru", "phone": "+70438348313"}
0005434723786	36E0E9	2994 771653	ALEKSANDR BELOV	{"phone": "+70049709101"}
0005434723787	73F840	4612 987711	RADIK KOROLEV	{"email": "radik-korolev_101964@postgrespro.ru", "phone": "+70248783873"}
0005434723788	73F840	1004 848729	YULIYA GORBUNOVA	{"email": "y_gorbunova_16071975@postgrespro.ru", "phone": "+70870383152"}
0005434723789	73F840	0576 352984	PAVEL MATVEEV	{"email": "p.matveev_1974@postgrespro.ru", "phone": "+70895329342"}
0005434723790	D9DE85	8574 743356	ELENA NIKOLAEVA	{"phone": "+70647923045"}
0005434723791	867244	3131 932149	VLADIMIR ISAEV	{"email": "isaev.v_1987@postgrespro.ru", "phone": "+70203314955"}
0005434723792	867244	1071 178335	VLADIMIR BORISOV	{"email": "v.borisov-051981@postgrespro.ru", "phone": "+70952458819"}
0005434723793	6BDF2E	8414 085655	IRINA SAVELEVA	{"phone": "+70262865299"}
0005434723794	6BDF2E	0461 085634	LIDIYA BELYAEVA	{"email": "belyaevalidiya_051980@postgrespro.ru", "phone": "+70839723762"}
0005434723795	BF9F5F	7061 599541	ANASTASIYA VASILEVA	{"phone": "+70516861800"}
0005434723796	5FD264	4576 221136	MATVEY DAVYDOV	{"phone": "+70991480611"}
0005434723797	CE7499	3569 309580	DENIS PETROV	{"email": "d.petrov-17081969@postgrespro.ru", "phone": "+70386401292"}
0005434723798	EC09BF	9470 487594	ANDREY ALEKSEEV	{"email": "a_alekseev-1977@postgrespro.ru", "phone": "+70537967230"}
0005434723799	0D3272	1389 206307	ALEKSANDR SOROKIN	{"phone": "+70843825094"}
0005434723800	0D3272	2601 004403	TAMARA NIKOLAEVA	{"email": "t.nikolaeva1967@postgrespro.ru", "phone": "+70327281756"}
0005434723801	F58C2E	1025 190928	ALEKSANDR MAKAROV	{"phone": "+70213669203"}
0005434723802	E7710F	3255 690640	VLADIMIR GAVRILOV	{"phone": "+70432471765"}
0005434723803	858131	5658 650956	ANASTASIYA KONDRATEVA	{"email": "anastasiya_kondrateva1975@postgrespro.ru", "phone": "+70552035833"}
0005434723804	13C576	5582 048359	ALEKSANDR SIDOROV	{"phone": "+70305859634"}
0005434723805	BD9B72	1958 344840	VADIM MATVEEV	{"email": "v_matveev01051976@postgrespro.ru", "phone": "+70092724349"}
0005434723806	BD9B72	8165 672505	OLGA MIRONOVA	{"email": "mironova.o_1979@postgrespro.ru", "phone": "+70737380540"}
0005434723807	BD9B72	1004 881393	NIKITA ZAKHAROV	{"phone": "+70683034041"}
0005434723808	18BF25	2687 249764	NIKOLAY PETROV	{"email": "petrov_n1966@postgrespro.ru", "phone": "+70094834650"}
0005434723809	3DF253	4998 163672	VALENTIN EGOROV	{"email": "valentin_egorov1974@postgrespro.ru", "phone": "+70657436819"}
0005434723810	44FE22	3400 988605	MIKHAIL MAKAROV	{"email": "makarov-m-07101978@postgrespro.ru", "phone": "+70715416794"}
0005434723811	747296	4095 532855	ZHANNA STEPANOVA	{"email": "stepanova-z-01101977@postgrespro.ru", "phone": "+70037094900"}
0005434723812	747296	5111 689124	TAMARA IVANOVA	{"phone": "+70340050830"}
0005434723813	B0EDE1	5564 348546	SOFIYA ANTONOVA	{"email": "antonova.sofiya_11121965@postgrespro.ru", "phone": "+70682929507"}
0005434723814	B0EDE1	5997 226894	ARMAN KULIKOV	{"email": "a.kulikov121978@postgrespro.ru", "phone": "+70255010226"}
0005434723815	E2D143	6940 173108	DINA KULIKOVA	{"email": "kulikova_d-031970@postgrespro.ru", "phone": "+70617160530"}
0005434723816	3EBBFD	1634 958118	VLADIMIR KUZNECOV	{"email": "v.kuznecov-111970@postgrespro.ru", "phone": "+70103539147"}
0005434723817	81B653	0113 286630	PETR IVANOV	{"email": "petr_ivanov.1971@postgrespro.ru", "phone": "+70842191464"}
0005434723818	7A8981	9285 606861	ANTON DAVYDOV	{"phone": "+70666591910"}
0005434723819	7A8981	1248 473355	IRINA POTAPOVA	{"email": "i_potapova_111969@postgrespro.ru", "phone": "+70188764925"}
0005434723820	363246	5937 624323	RUSLAN KUZNECOV	{"email": "r.kuznecov-1969@postgrespro.ru", "phone": "+70964850370"}
0005434723821	363246	8645 643604	YURIY DMITRIEV	{"email": "dmitriev.y_1974@postgrespro.ru", "phone": "+70725987625"}
0005434723822	5F7C48	1453 800715	ANNA SERGEEVA	{"phone": "+70204854850"}
0005434723823	5F7C48	0711 838634	VLADIMIR MAKAROV	{"email": "makarov.vladimir1986@postgrespro.ru", "phone": "+70981576691"}
0005434723824	4A2C54	9214 143668	ALEKSANDR DAVYDOV	{"phone": "+70866789313"}
0005434723825	EBB0C7	1526 593013	ALEKSEY MEDVEDEV	{"phone": "+70792858622"}
0005434723826	D34220	8797 192911	OLGA SIDOROVA	{"email": "sidorovao_30091975@postgrespro.ru", "phone": "+70981026892"}
0005434723827	D34220	0143 457967	VLADIMIR GORBUNOV	{"email": "gorbunov_vladimir-19091964@postgrespro.ru", "phone": "+70304717056"}
0005434723828	416268	5990 153214	SERGEY SOKOLOV	{"email": "sergey-sokolov20121967@postgrespro.ru", "phone": "+70278490878"}
0005434723829	7FE25A	3009 354362	VALENTINA EGOROVA	{"email": "egorova.valentina1977@postgrespro.ru", "phone": "+70330636951"}
0005434723830	007E78	5815 757447	YURIY ANDREEV	{"phone": "+70157562812"}
0005434723831	7CB02E	8004 871613	GALINA ANDREEVA	{"phone": "+70814130923"}
0005434723832	55FCA8	2205 887799	ELENA MELNIKOVA	{"email": "e.melnikova_20071973@postgrespro.ru", "phone": "+70754980246"}
0005434723833	B1262B	1396 270859	VALENTIN ZAKHAROV	{"phone": "+70797307813"}
0005434723834	B1262B	1730 159943	ALEKSEY IVANOV	{"email": "aivanov_23111965@postgrespro.ru", "phone": "+70923280336"}
0005434723835	3B16B8	2173 475588	NINA LUKYANOVA	{"phone": "+70580005033"}
0005434723836	7E6DE4	7893 596550	ROMAN ORLOV	{"email": "orlov_roman1956@postgrespro.ru", "phone": "+70639374260"}
0005434723837	91C1B6	0422 257424	VERA EGOROVA	{"email": "vera.egorova-1970@postgrespro.ru", "phone": "+70782896221"}
0005434723838	B39C7A	2868 078221	MAKSIM ISAEV	{"email": "isaev.m1963@postgrespro.ru", "phone": "+70302183650"}
0005434723839	E1DF35	1891 608661	EGOR POPOV	{"email": "epopov29021964@postgrespro.ru", "phone": "+70569002637"}
0005434723840	7D8E47	8130 830080	EKATERINA SOROKINA	{"phone": "+70547870484"}
0005434723841	0A4479	2770 799043	EKATERINA GRISHINA	{"email": "ekaterina_grishina.101974@postgrespro.ru", "phone": "+70892489005"}
0005434723842	6B50CD	2693 231779	LILIYA KOZLOVA	{"phone": "+70634957256"}
0005434723843	CD0057	7711 349846	SERGEY SOKOLOV	{"phone": "+70551300661"}
0005434723844	B2C5DA	0987 946995	VIKTOR KRASNOV	{"phone": "+70306199001"}
0005434723845	7C2EAA	3233 385690	NADEZHDA KARPOVA	{"phone": "+70023460648"}
0005434723846	7EB5C5	9376 676515	PETR MIKHAYLOV	{"phone": "+70739240381"}
0005434723847	78DB6F	1636 562424	EVGENIYA DENISOVA	{"email": "evgeniya-denisova121968@postgrespro.ru", "phone": "+70464982876"}
0005434723848	91B148	8800 021876	VLADISLAV VASILEV	{"email": "vasilev-vladislav09031974@postgrespro.ru", "phone": "+70428299328"}
0005434723849	91B148	3677 182917	TATYANA VASILEVA	{"phone": "+70013989149"}
0005434723850	276588	4558 196678	ARTEM GORBUNOV	{"phone": "+70359476504"}
0005434723851	276588	9500 572846	ALEKSANDRA DENISOVA	{"phone": "+70141755384"}
0005434723852	48E701	2504 250350	VIKTOR KARPOV	{"phone": "+70288683790"}
0005434723853	B261E7	3365 859115	MARIYA GUSEVA	{"phone": "+70409623189"}
0005434723854	B261E7	5890 730454	ALLA KAZAKOVA	{"phone": "+70782386922"}
0005434723855	75EE0B	7306 177702	MIKHAIL MAKAROV	{"email": "makarov-m_1974@postgrespro.ru", "phone": "+70927230704"}
0005434723856	E6D938	9378 856196	OLGA KOZLOVA	{"email": "o-kozlova_12061980@postgrespro.ru", "phone": "+70625459326"}
0005434723857	E6D938	6415 321548	EVGENIY POPOV	{"email": "e-popov.031982@postgrespro.ru", "phone": "+70594786147"}
0005434723858	E9150C	6218 928699	EKATERINA OVCHINNIKOVA	{"phone": "+70991276545"}
0005434723859	EC3B2A	3859 623338	TATYANA EGOROVA	{"phone": "+70707161106"}
0005434723860	EC3B2A	6103 626305	VIKTOR PETROV	{"email": "petrov_v_13051979@postgrespro.ru", "phone": "+70360675228"}
0005434723861	CBD48F	3399 783860	YAN KAZAKOV	{"phone": "+70942443806"}
0005434723862	CBD48F	3537 622696	OLGA IVANOVA	{"email": "ivanova_olga.051975@postgrespro.ru", "phone": "+70557172754"}
0005434723863	F6E2D4	3925 631588	OLGA MAKSIMOVA	{"email": "olga.maksimova071972@postgrespro.ru", "phone": "+70381892129"}
0005434723864	F6E2D4	5584 035809	ALEKSANDR KUZNECOV	{"phone": "+70702936147"}
0005434723865	DC6BC8	9399 060858	IRINA GERASIMOVA	{"email": "gerasimova.i-21111980@postgrespro.ru", "phone": "+70697556726"}
0005434723866	107062	6791 804887	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov-1980@postgrespro.ru", "phone": "+70818441265"}
0005434723867	DD9005	8743 000447	IVAN BONDARENKO	{"phone": "+70061268767"}
0005434723868	E5B77D	1120 375961	ARTEM KOROLEV	{"phone": "+70715591399"}
0005434723869	E5B77D	5079 160708	SOFYA IVANOVA	{"email": "sofyaivanova.24111972@postgrespro.ru", "phone": "+70087045725"}
0005434723870	E5B77D	0535 418756	DENIS PAVLOV	{"email": "denispavlov.14091981@postgrespro.ru", "phone": "+70258917330"}
0005434723871	DC417A	6108 613518	ZINAIDA ILINA	{"email": "zinaida-ilina-031974@postgrespro.ru", "phone": "+70736757910"}
0005434723872	E8CC75	2799 620423	VYACHESLAV TARASOV	{"email": "vyacheslav.tarasov_1961@postgrespro.ru", "phone": "+70565562644"}
0005434723873	E8CC75	8275 619663	VALERIYA LEBEDEVA	{"phone": "+70887287856"}
0005434723874	265B0A	8857 436262	NIKITA MIKHAYLOV	{"email": "mikhaylov_nikita-1982@postgrespro.ru", "phone": "+70049713763"}
0005434723875	265B0A	8482 728404	SVETLANA KISELEVA	{"email": "skiseleva071971@postgrespro.ru", "phone": "+70513605645"}
0005434723876	66B4F1	1751 554289	SERGEY BELOV	{"email": "belov_sergey.081976@postgrespro.ru", "phone": "+70393180526"}
0005434723877	60EA72	1132 685195	SERGEY SOKOLOV	{"email": "sokolov_s-091978@postgrespro.ru", "phone": "+70479384262"}
0005434723878	EAD1D1	9346 375343	ARTEM FEDOROV	{"phone": "+70206435990"}
0005434723879	FC1A81	1755 782065	MARINA TIKHONOVA	{"phone": "+70783554763"}
0005434723880	FC1A81	6892 502769	NATALYA KUZNECOVA	{"email": "natalya.kuznecova.011978@postgrespro.ru", "phone": "+70991350032"}
0005434723881	C5D26A	8787 126728	VLADISLAV VOLKOV	{"email": "vladislav_volkov031966@postgrespro.ru", "phone": "+70988468868"}
0005434723882	FB0819	0553 585833	ALEKSANDR POPOV	{"email": "aleksandrpopov.021971@postgrespro.ru", "phone": "+70899299181"}
0005434723883	96271E	2711 537281	STANISLAV MIRONOV	{"email": "mironovstanislav-02011973@postgrespro.ru", "phone": "+70003809715"}
0005434723884	96271E	3864 266327	ANATOLIY POPOV	{"phone": "+70455333741"}
0005434723885	CE82A3	0923 720396	ELENA FADEEVA	{"email": "e_fadeeva-071972@postgrespro.ru", "phone": "+70332351797"}
0005434723886	CE82A3	9126 274121	RAISA GAVRILOVA	{"phone": "+70385902805"}
0005434723887	13747E	7304 335275	EVGENIY MAKAROV	{"phone": "+70257832139"}
0005434723888	3C3DF2	3238 144801	ANASTASIYA KUZNECOVA	{"phone": "+70989416333"}
0005434723889	3C3DF2	2088 762547	VALENTIN DAVYDOV	{"email": "valentin.davydov1984@postgrespro.ru", "phone": "+70030884923"}
0005434723890	03477D	4519 830909	ALFIYA IVANOVA	{"email": "aivanova_1961@postgrespro.ru", "phone": "+70778912496"}
0005434723891	03477D	4306 011677	LYUBOV FOMINA	{"phone": "+70803991555"}
0005434723892	AEC758	1493 717488	ALEKSANDR RODIONOV	{"email": "rodionov_aleksandr.011959@postgrespro.ru", "phone": "+70732791050"}
0005434723893	AEC758	2862 902063	LYUDMILA PAVLOVA	{"phone": "+70899532521"}
0005434723894	426935	8012 249352	EKATERINA ARKHIPOVA	{"phone": "+70975959824"}
0005434723895	5C5714	8861 696747	ALEKSEY FOMIN	{"email": "fomin-a1982@postgrespro.ru", "phone": "+70122504818"}
0005434723896	CDB670	7689 542072	EVGENIYA GORBUNOVA	{"email": "evgeniya.gorbunova.29121973@postgrespro.ru", "phone": "+70505038618"}
0005434723897	81FAD1	9450 620762	DENIS GAVRILOV	{"email": "gavrilov_denis1975@postgrespro.ru", "phone": "+70091358037"}
0005434723898	81FAD1	7011 248947	VASILIY KOROLEV	{"email": "v.korolev_051974@postgrespro.ru", "phone": "+70250421376"}
0005434723899	81FAD1	4243 503010	EKATERINA VLASOVA	{"phone": "+70555934853"}
0005434723900	FD8617	2491 185974	IVAN MIKHAYLOV	{"email": "ivan_mikhaylov-041979@postgrespro.ru", "phone": "+70432727201"}
0005434723901	7266EC	3370 022080	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov13051965@postgrespro.ru", "phone": "+70716331227"}
0005434723902	7266EC	8583 257834	OLGA ZAYCEVA	{"email": "ozayceva_08101963@postgrespro.ru", "phone": "+70002604891"}
0005434723903	EC3674	0602 733553	YANA GORBUNOVA	{"phone": "+70398090602"}
0005434723904	31E02D	5673 907827	ELENA TIKHONOVA	{"email": "elena.tikhonova-14111974@postgrespro.ru", "phone": "+70498674052"}
0005434723905	31E02D	8634 714433	PAVEL OSIPOV	{"phone": "+70618456095"}
0005434723906	AD3CF1	2036 993513	MAKSIM VASILEV	{"phone": "+70585463156"}
0005434723907	D17D16	3119 975074	KSENIYA GUSEVA	{"phone": "+70023331953"}
0005434723908	D17D16	4937 031819	IGOR STEPANOV	{"phone": "+70169426613"}
0005434723909	035516	2194 816257	ROMAN SMIRNOV	{"email": "roman_smirnov_1978@postgrespro.ru", "phone": "+70617695128"}
0005434723910	AEA7FC	3998 047309	ALEKSANDR TIMOFEEV	{"email": "aleksandrtimofeev_1965@postgrespro.ru", "phone": "+70284444305"}
0005434723911	AEA7FC	5677 697366	OKSANA SMIRNOVA	{"phone": "+70934624984"}
0005434723912	01CBB9	6648 883095	EVGENIY ABRAMOV	{"phone": "+70839968377"}
0005434723913	216373	9160 991562	DARYA SAVELEVA	{"email": "saveleva-d.1969@postgrespro.ru", "phone": "+70852323735"}
0005434723914	E6DAC0	1904 462649	TATYANA KUZNECOVA	{"phone": "+70915712205"}
0005434723915	660F45	2802 370172	LILIYA NESTEROVA	{"phone": "+70888332705"}
0005434723916	A801F2	9574 049076	LYUDMILA LEBEDEVA	{"phone": "+70717017083"}
0005434723917	13EFB3	6261 243133	MARIYA RYABOVA	{"email": "ryabovamariya_12051977@postgrespro.ru", "phone": "+70054899411"}
0005434723918	490B40	8819 566024	VALENTINA FOMINA	{"email": "vfomina10031981@postgrespro.ru", "phone": "+70350605181"}
0005434723919	271311	3003 810277	TATYANA MASLOVA	{"email": "maslova.tatyana.091980@postgrespro.ru", "phone": "+70855862451"}
0005434723920	271311	0116 535031	ALEKSANDRA GORBUNOVA	{"email": "agorbunova_13041967@postgrespro.ru", "phone": "+70010488694"}
0005434723921	271311	8697 097497	LYUBOV STEPANOVA	{"email": "l-stepanova.03011973@postgrespro.ru", "phone": "+70274237811"}
0005434723922	D3DA49	0286 247611	YANA POTAPOVA	{"email": "y.potapova061976@postgrespro.ru", "phone": "+70929735944"}
0005434723923	D3DA49	1913 157585	TAMARA KOROLEVA	{"email": "korolevatamara.01061969@postgrespro.ru", "phone": "+70581982268"}
0005434723924	28D8A9	0485 810120	RAISA SEMENOVA	{"email": "semenova-raisa_1969@postgrespro.ru", "phone": "+70052300383"}
0005434723925	28D8A9	5669 143211	ALEKSANDR OSIPOV	{"phone": "+70821640599"}
0005434723926	9B08B8	4288 459527	YURIY GRIGOREV	{"email": "grigorev-y_081979@postgrespro.ru", "phone": "+70655684933"}
0005434723927	166214	1011 948081	SERGEY GUSEV	{"email": "gusevsergey071951@postgrespro.ru", "phone": "+70324854489"}
0005434723928	380B0F	6350 704481	SVETLANA MALYSHEVA	{"phone": "+70273433251"}
0005434723929	380B0F	1590 793586	SVETLANA BARANOVA	{"phone": "+70804330462"}
0005434723930	FD8B2E	8360 868155	EVGENIY KARPOV	{"email": "e-karpov09011968@postgrespro.ru", "phone": "+70240523920"}
0005434723931	B58284	1395 916365	IVAN KOZLOV	{"email": "kozlov_i.24071963@postgrespro.ru", "phone": "+70606704043"}
0005434723932	0B1FD1	5377 542346	SERGEY CHERNOV	{"phone": "+70701326729"}
0005434723933	0B1FD1	5651 934341	LARISA TIMOFEEVA	{"phone": "+70150370958"}
0005434723934	F5EBA4	9204 804704	DMITRIY ANTONOV	{"phone": "+70283954552"}
0005434723935	A0EFD2	6922 514517	LYUBOV NAUMOVA	{"phone": "+70518871614"}
0005434723936	4244EE	5614 651134	ARTUR ZAYCEV	{"email": "a-zaycev_1968@postgrespro.ru", "phone": "+70082272372"}
0005434723937	71AB0C	2961 756487	ANDREY VASILEV	{"phone": "+70374376135"}
0005434723938	41E771	0745 161162	KIRILL KOZLOV	{"phone": "+70221210822"}
0005434723939	A83752	7849 814487	NATALIYA PETROVA	{"phone": "+70573642811"}
0005434723940	A83752	4789 323671	ALENA LOGINOVA	{"email": "aloginova-091965@postgrespro.ru", "phone": "+70025272989"}
0005434723941	A83752	5773 636913	ANASTASIYA ABRAMOVA	{"phone": "+70210120440"}
0005434723942	FEC4A9	4980 838703	DENIS TIMOFEEV	{"email": "denis.timofeev-1984@postgrespro.ru", "phone": "+70665312069"}
0005434723943	FEC4A9	3933 897268	RAMIL AFANASEV	{"phone": "+70863867433"}
0005434723944	544179	9695 520974	VYACHESLAV NIKOLAEV	{"phone": "+70987763822"}
0005434723945	7F1ECB	0557 079470	DARYA NIKIFOROVA	{"phone": "+70884614941"}
0005434723946	FD70B8	8043 190359	LYUDMILA PETROVA	{"phone": "+70399576605"}
0005434723947	FD70B8	5076 795289	NIKOLAY IVANOV	{"phone": "+70756443884"}
0005434723948	441E6F	0760 235577	SVETLANA ALEKSEEVA	{"phone": "+70176054148"}
0005434723949	CBC6DF	6161 778746	GALINA GORBUNOVA	{"email": "g_gorbunova_1961@postgrespro.ru", "phone": "+70094354222"}
0005434723950	7EF936	5209 292385	LIDIYA SEMENOVA	{"phone": "+70674624777"}
0005434723951	3DCB78	4355 593374	SERGEY DMITRIEV	{"email": "sergey-dmitriev081970@postgrespro.ru", "phone": "+70455352508"}
0005434723952	18F395	8139 063934	TATYANA BORISOVA	{"email": "tatyana.borisova.011972@postgrespro.ru", "phone": "+70746653540"}
0005434723953	18F395	6128 238242	TATYANA EFIMOVA	{"phone": "+70804215507"}
0005434723954	18F395	3288 374338	VLADISLAV FILIPPOV	{"email": "filippov-v18081967@postgrespro.ru", "phone": "+70674059975"}
0005434724247	4475F2	2273 733881	VLADIMIR GRIGOREV	{"phone": "+70942604275"}
0005434723955	3F71BE	2006 907429	GENNADIY DMITRIEV	{"email": "g_dmitriev.10091977@postgrespro.ru", "phone": "+70482913786"}
0005434723956	281FC9	1630 365329	ANATOLIY EGOROV	{"email": "anatoliy_egorov.02071980@postgrespro.ru", "phone": "+70207324641"}
0005434723957	79DD21	6113 139955	NIKOLAY KULIKOV	{"email": "nikolay.kulikov_15091967@postgrespro.ru", "phone": "+70931375966"}
0005434723958	9A582D	3994 184785	ANASTASIYA STEPANOVA	{"email": "stepanovaanastasiya12071981@postgrespro.ru", "phone": "+70026092010"}
0005434723959	BB4765	7259 800718	EGOR MIKHAYLOV	{"email": "mikhaylov-egor_091964@postgrespro.ru", "phone": "+70757325328"}
0005434723960	BB4765	8615 346849	VALERIY SMIRNOV	{"email": "smirnov.valeriy_01051977@postgrespro.ru", "phone": "+70377768393"}
0005434723961	3A46EB	7475 970201	IGOR MARTYNOV	{"phone": "+70240755564"}
0005434723962	78025A	5307 029068	PLATON MEDVEDEV	{"email": "medvedev-platon-051966@postgrespro.ru", "phone": "+70357712063"}
0005434723963	C1AA89	9675 290081	ANASTASIYA MIKHAYLOVA	{"phone": "+70270663108"}
0005434723964	1F611D	4762 252944	ELENA KALININA	{"email": "elena_kalinina-111978@postgrespro.ru", "phone": "+70555637624"}
0005434723965	0BE5C3	6243 194470	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov.29081977@postgrespro.ru", "phone": "+70813735126"}
0005434723966	1F3EA1	7658 306870	MIKHAIL GERASIMOV	{"email": "m.gerasimov-09101963@postgrespro.ru", "phone": "+70839949734"}
0005434723967	562A18	5178 867433	RASIM SHEVCHENKO	{"phone": "+70248256987"}
0005434723968	0CDBB2	7449 863892	DARYA GERASIMOVA	{"email": "gerasimovad.1975@postgrespro.ru", "phone": "+70660464872"}
0005434723969	0CDBB2	3407 959891	GENNADIY ILIN	{"phone": "+70817818035"}
0005434723970	E26773	9255 230202	RADIK SMIRNOV	{"email": "smirnov_r.1976@postgrespro.ru", "phone": "+70924108756"}
0005434723971	E26773	2131 957489	YULIYA VASILEVA	{"phone": "+70991525412"}
0005434723972	395B03	1367 512404	LYUDMILA LEBEDEVA	{"email": "lyudmila_lebedeva1964@postgrespro.ru", "phone": "+70102425956"}
0005434723973	395B03	3041 803750	MILENA ANDREEVA	{"email": "andreevamilena10011973@postgrespro.ru", "phone": "+70621760651"}
0005434723974	D774B6	5782 543125	TATYANA FOMINA	{"email": "fomina-t_1974@postgrespro.ru", "phone": "+70400480298"}
0005434723975	D774B6	0744 373905	VALENTINA PETROVA	{"email": "valentinapetrova_05021964@postgrespro.ru", "phone": "+70063768362"}
0005434723976	7A1602	1919 623630	ALEKSANDR SHEVCHENKO	{"phone": "+70043411765"}
0005434723977	F89010	1326 356098	ALEKSANDR KONOVALOV	{"phone": "+70045650285"}
0005434723978	BF4ADA	0474 290459	SERGEY ANDREEV	{"phone": "+70358594879"}
0005434723979	C09449	6690 760553	ANATOLIY MOISEEV	{"email": "anatoliy_moiseev1971@postgrespro.ru", "phone": "+70875807222"}
0005434723980	C09449	5649 183178	RUSLAN BELOV	{"email": "belovruslan.081978@postgrespro.ru", "phone": "+70388130998"}
0005434723981	14ADD1	5536 538510	ALEKSEY IVANOV	{"email": "ivanovaleksey-20071969@postgrespro.ru", "phone": "+70865617269"}
0005434723982	D3D88B	8429 326310	NADEZHDA KALININA	{"email": "nadezhdakalinina-121970@postgrespro.ru", "phone": "+70768199233"}
0005434723983	52E51E	4813 068108	ROMAN POPOV	{"email": "r.popov.1974@postgrespro.ru", "phone": "+70510537063"}
0005434723984	52E51E	4160 859136	OLEG MIKHAYLOV	{"phone": "+70011065655"}
0005434723985	5C86DF	7106 549898	TATYANA OSIPOVA	{"phone": "+70003159511"}
0005434723986	5C86DF	0873 316036	VALENTIN VLASOV	{"phone": "+70149153012"}
0005434723987	DD4374	8111 767973	KONSTANTIN MOROZOV	{"phone": "+70351623764"}
0005434723988	A8E1D7	8533 958923	ELENA GERASIMOVA	{"email": "elena_gerasimova-031971@postgrespro.ru", "phone": "+70456014397"}
0005434723989	46486F	4435 039061	SERGEY MAKSIMOV	{"email": "s.maksimov30091974@postgrespro.ru", "phone": "+70336106944"}
0005434723990	812722	5339 546066	ELVIRA POPOVA	{"phone": "+70695191357"}
0005434723991	A81F9B	6513 625021	VALENTIN SIDOROV	{"email": "sidorov_valentin-22091979@postgrespro.ru", "phone": "+70643677583"}
0005434723992	23D425	5019 899325	ILYAS FEDOTOV	{"phone": "+70135712269"}
0005434723993	5DC6F2	5987 148797	KONSTANTIN DAVYDOV	{"email": "davydov_konstantin_22101982@postgrespro.ru", "phone": "+70207678270"}
0005434723994	123031	7036 431736	ANNA BARANOVA	{"email": "baranova-anna-111975@postgrespro.ru", "phone": "+70838500702"}
0005434723995	E67E39	6328 448020	MAYYA VASILEVA	{"email": "vasileva.mayya-03021963@postgrespro.ru", "phone": "+70842303842"}
0005434723996	E67E39	0283 765254	DMITRIY MATVEEV	{"phone": "+70064560202"}
0005434723997	92C700	8616 309428	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov_23061970@postgrespro.ru", "phone": "+70443910038"}
0005434723998	B00137	4748 227350	IRINA PAVLOVA	{"phone": "+70045393051"}
0005434723999	B00137	5092 581058	NATALYA GRISHINA	{"phone": "+70852717393"}
0005434724000	2F2AE1	2771 509168	NIKITA FILIPPOV	{"phone": "+70822944643"}
0005434724001	2F2AE1	2934 482721	TATYANA SMIRNOVA	{"phone": "+70000172308"}
0005434724002	468C66	5038 168781	DENIS GRIGOREV	{"email": "denis_grigorev.11021979@postgrespro.ru", "phone": "+70651194892"}
0005434724003	06F652	6817 929221	MARINA SOKOLOVA	{"email": "sokolova-m.18041978@postgrespro.ru", "phone": "+70779176676"}
0005434724004	6F6ABD	0036 569385	NIKOLAY PETROV	{"phone": "+70063073997"}
0005434724005	7B4E61	6320 703907	IVAN ALEKSEEV	{"email": "i-alekseev_27011976@postgrespro.ru", "phone": "+70694910241"}
0005434724006	7B4E61	7066 595604	ANNA FADEEVA	{"email": "a.fadeeva.041960@postgrespro.ru", "phone": "+70766831807"}
0005434724007	6F490B	2198 662414	YANA FROLOVA	{"email": "yfrolova-19101971@postgrespro.ru", "phone": "+70037978786"}
0005434724008	14FBBD	6468 960065	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova_18011974@postgrespro.ru", "phone": "+70254874895"}
0005434724009	7EDC94	2373 876133	ALINA MAKSIMOVA	{"phone": "+70051088084"}
0005434724010	BC8ED1	2599 787637	GALINA GERASIMOVA	{"email": "g_gerasimova_19101967@postgrespro.ru", "phone": "+70702760302"}
0005434724011	AC4442	9659 634206	IVAN ROMANOV	{"email": "i_romanov1963@postgrespro.ru", "phone": "+70470620965"}
0005434724012	F9B4DA	2155 176282	TAGIR KUZNECOV	{"email": "kuznecovtagir_1973@postgrespro.ru", "phone": "+70917153137"}
0005434724013	6F2BE6	4363 882681	ANNA KONOVALOVA	{"phone": "+70919894106"}
0005434724014	6F2BE6	2456 503692	ELENA KUZNECOVA	{"email": "kuznecova_elena091975@postgrespro.ru", "phone": "+70887251446"}
0005434724015	AA93B4	1516 870391	ALEKSANDR KISELEV	{"email": "kiselev_a_1967@postgrespro.ru", "phone": "+70525304049"}
0005434724016	AC50CB	2482 141023	ALEKSANDR ZAYCEV	{"phone": "+70898642586"}
0005434724017	55FE3A	3786 807637	VALERIY TARASOV	{"email": "tarasov-v.091971@postgrespro.ru", "phone": "+70599676607"}
0005434724018	55FE3A	6280 562379	OLGA SERGEEVA	{"email": "sergeevao.30041985@postgrespro.ru", "phone": "+70037819460"}
0005434724019	50DEEF	0001 998571	OLGA KALININA	{"email": "okalinina_1959@postgrespro.ru", "phone": "+70614689241"}
0005434724020	50DEEF	6151 133894	VLADISLAV ZAKHAROV	{"email": "vladislav-zakharov-041978@postgrespro.ru", "phone": "+70502078599"}
0005434724021	916E9C	5959 167396	MARIYA KOVALEVA	{"email": "kovaleva_mariya1969@postgrespro.ru", "phone": "+70162261007"}
0005434724022	1E90B9	2059 981174	SERGEY IVANOV	{"phone": "+70363559323"}
0005434724023	881B52	6398 737366	LYUDMILA VOROBEVA	{"email": "lyudmila.vorobeva19041973@postgrespro.ru", "phone": "+70609329495"}
0005434724024	DFD53B	1730 788199	EGOR TIKHONOV	{"phone": "+70251175514"}
0005434724025	DFD53B	9105 793537	NATALYA KOROLEVA	{"phone": "+70409294950"}
0005434724026	2FCADD	5630 246092	YULIYA BARANOVA	{"email": "yuliya.baranova-1969@postgrespro.ru", "phone": "+70171477966"}
0005434724027	4798F0	8634 313291	LYUBOV DAVYDOVA	{"email": "davydova_lyubov021971@postgrespro.ru", "phone": "+70176686177"}
0005434724028	9A142A	5013 712699	GENNADIY KAZAKOV	{"email": "g_kazakov101980@postgrespro.ru", "phone": "+70143871594"}
0005434724029	F74980	2897 317625	SERGEY FEDOROV	{"email": "sergey_fedorov_1967@postgrespro.ru", "phone": "+70450504262"}
0005434724030	7D47E2	7272 487612	EVGENIY FILIPPOV	{"phone": "+70987008552"}
0005434724031	830970	3014 545516	ALEKSANDR FEDOTOV	{"email": "fedotov-aleksandr.11041973@postgrespro.ru", "phone": "+70578226343"}
0005434724032	830970	2943 146467	ILYA ISAEV	{"phone": "+70517972905"}
0005434724033	23821C	7469 387526	LYUBOV NOVIKOVA	{"email": "novikova_lyubov.091976@postgrespro.ru", "phone": "+70467221112"}
0005434724034	BA29FF	1927 679457	ALEKSANDR KISELEV	{"phone": "+70820685881"}
0005434724035	BA29FF	4723 459154	IRINA FOMINA	{"email": "fomina-i.071973@postgrespro.ru", "phone": "+70402890533"}
0005434724036	BA29FF	6821 295581	MARIYA ROMANOVA	{"phone": "+70788009808"}
0005434724037	5C7CDD	9958 154038	DANILA EGOROV	{"email": "egorov.d.021967@postgrespro.ru", "phone": "+70094438408"}
0005434724038	5C7CDD	3523 529370	IVAN ANDREEV	{"email": "i_andreev_021969@postgrespro.ru", "phone": "+70254797547"}
0005434724039	8E72E7	7039 237100	EVGENIY NOVIKOV	{"email": "evgeniy_novikov_31121975@postgrespro.ru", "phone": "+70135319665"}
0005434724040	319E24	0198 620622	LIDIYA MIRONOVA	{"email": "mironova.l.011980@postgrespro.ru", "phone": "+70556683816"}
0005434724041	F85C2E	7462 827966	ALEKSEY KISELEV	{"phone": "+70128715000"}
0005434724320	1A86C7	6353 734173	GENNADIY VASILEV	{"phone": "+70717703832"}
0005434724042	F85C2E	6222 469849	PAVEL TARASOV	{"email": "paveltarasov-091965@postgrespro.ru", "phone": "+70398646644"}
0005434724043	4D033A	9476 624878	SOFYA EGOROVA	{"email": "egorova-s121979@postgrespro.ru", "phone": "+70753043507"}
0005434724044	629E24	8477 125548	OLEG IVANOV	{"phone": "+70993559844"}
0005434724045	8AD29E	1597 398887	YULIYA TIKHONOVA	{"phone": "+70092060203"}
0005434724046	8AD29E	0670 058522	VIKTOR ZHUKOV	{"phone": "+70809847741"}
0005434724047	169FBD	6543 051145	KIRILL STEPANOV	{"phone": "+70665204683"}
0005434724048	169FBD	3401 389271	POLINA TIKHONOVA	{"phone": "+70875972840"}
0005434724049	F6633E	4015 546799	ILYA AFANASEV	{"phone": "+70661379936"}
0005434724050	A0DED8	1935 860031	NATALYA LUKYANOVA	{"email": "nlukyanova1963@postgrespro.ru", "phone": "+70934309024"}
0005434724051	A0DED8	5417 802606	GALINA FOMINA	{"phone": "+70584141848"}
0005434724052	C8746E	6152 315028	VLADIMIR SHEVCHENKO	{"phone": "+70908760937"}
0005434724053	C8746E	0548 590862	TATYANA ZOTOVA	{"email": "zotova.tatyana041969@postgrespro.ru", "phone": "+70264017590"}
0005434724054	95CEFB	6675 267399	MAKSIM BELOV	{"phone": "+70640288320"}
0005434724055	D15AEE	7329 390501	IVAN CHERNOV	{"email": "ichernov1985@postgrespro.ru", "phone": "+70301819839"}
0005434724056	D15AEE	4194 972536	ALEKSANDR KARPOV	{"email": "karpov-aleksandr_121964@postgrespro.ru", "phone": "+70504778068"}
0005434724057	46EE6A	5781 188671	DAMIR FOMIN	{"email": "damir_fomin-091975@postgrespro.ru", "phone": "+70057757771"}
0005434724058	E6AEF1	6268 274400	VADIM MEDVEDEV	{"email": "medvedevvadim_1976@postgrespro.ru", "phone": "+70856393306"}
0005434724059	7D5901	5129 595615	ANDREY ANDREEV	{"email": "andreev-a.021973@postgrespro.ru", "phone": "+70016303423"}
0005434724060	5EC871	6943 317272	SERGEY SCHERBAKOV	{"email": "s-scherbakov1969@postgrespro.ru", "phone": "+70697036988"}
0005434724061	5EC871	0927 283353	DMITRIY SOKOLOV	{"email": "sokolovdmitriy27051970@postgrespro.ru", "phone": "+70461460373"}
0005434724062	008CAC	7737 420531	ALEKSANDR BELOV	{"phone": "+70445932764"}
0005434724063	C9D9CA	5691 748078	ALEKSEY KUZNECOV	{"email": "alekseykuznecov28041977@postgrespro.ru", "phone": "+70255508591"}
0005434724064	78677F	1955 246454	VLADIMIR NIKOLAEV	{"phone": "+70652084365"}
0005434724065	78677F	3204 797446	VLADIMIR NIKITIN	{"phone": "+70865086066"}
0005434724066	146187	0730 109731	SERGEY ALEKSANDROV	{"email": "sergey-aleksandrov.15061967@postgrespro.ru", "phone": "+70341850206"}
0005434724067	146187	6261 386754	RAVIL PETROV	{"email": "r_petrov071974@postgrespro.ru", "phone": "+70788592871"}
0005434724068	E5568A	8600 959367	TATYANA SMIRNOVA	{"email": "smirnovatatyana_061966@postgrespro.ru", "phone": "+70640395739"}
0005434724069	C43F3B	9586 477691	VIKTOR ROMANOV	{"email": "romanovviktor_1963@postgrespro.ru", "phone": "+70751477521"}
0005434724070	C43F3B	3184 909453	OLEG KAZAKOV	{"email": "kazakovo27091964@postgrespro.ru", "phone": "+70881889485"}
0005434724071	B6EA63	2641 140656	ALEKSEY BONDARENKO	{"email": "a.bondarenko28051976@postgrespro.ru", "phone": "+70184624994"}
0005434724072	13F59D	8199 437302	NIKOLAY FROLOV	{"phone": "+70115497472"}
0005434724073	13F59D	5956 560849	ELENA TROFIMOVA	{"email": "trofimovae04111967@postgrespro.ru", "phone": "+70957202624"}
0005434724074	13F59D	5483 500499	VLADIMIR GAVRILOV	{"email": "gavrilov.v-02021968@postgrespro.ru", "phone": "+70745806394"}
0005434724075	CF1990	5966 692188	YULIYA VASILEVA	{"email": "y_vasileva101963@postgrespro.ru", "phone": "+70093328091"}
0005434724076	6B9381	4512 327703	PETR KUZNECOV	{"email": "petrkuznecov-1965@postgrespro.ru", "phone": "+70086978969"}
0005434724077	16CF34	6996 349378	ARTEM EGOROV	{"phone": "+70139848539"}
0005434724078	3755EC	8218 020878	EVGENIY NIKOLAEV	{"phone": "+70894242672"}
0005434724079	A813EA	2404 170311	ELIZAVETA TIMOFEEVA	{"email": "timofeevae_25111971@postgrespro.ru", "phone": "+70854915159"}
0005434724080	1C5337	6313 796472	IVAN FILIPPOV	{"email": "ivan_filippov_1979@postgrespro.ru", "phone": "+70222641558"}
0005434724081	FB20A2	8172 503779	IRINA AFANASEVA	{"email": "afanaseva_irina1979@postgrespro.ru", "phone": "+70265339847"}
0005434724082	FB20A2	6338 513908	ALEKSEY MIRONOV	{"email": "a.mironov.041983@postgrespro.ru", "phone": "+70889231270"}
0005434724083	04BAD5	4275 397769	OKSANA MAKAROVA	{"phone": "+70585077495"}
0005434724084	E87A1F	0022 282078	VYACHESLAV KRASNOV	{"email": "v-krasnov.1972@postgrespro.ru", "phone": "+70918594026"}
0005434724085	BCEB93	4375 152072	DARYA LAZAREVA	{"email": "darya_lazareva.08071989@postgrespro.ru", "phone": "+70255082060"}
0005434724086	BCEB93	3567 604778	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova.l07071965@postgrespro.ru", "phone": "+70863595758"}
0005434724087	6C672F	0859 863492	KSENIYA KUZNECOVA	{"phone": "+70776212629"}
0005434724088	7A8C86	7168 222083	VALERIY NOVIKOV	{"phone": "+70214306298"}
0005434724089	5C97D2	5503 362496	POLINA ROMANOVA	{"phone": "+70434209010"}
0005434724090	42B4A8	1581 749965	SERGEY ALEKSEEV	{"phone": "+70666048260"}
0005434724091	340E38	2233 089772	ARTEM EGOROV	{"phone": "+70374667218"}
0005434724092	CC5B88	9537 505059	NINA SOROKINA	{"phone": "+70450136514"}
0005434724093	BED38A	6490 480266	OLGA PETROVA	{"phone": "+70010018780"}
0005434724094	BED38A	7612 130093	SERGEY SMIRNOV	{"email": "s-smirnov1966@postgrespro.ru", "phone": "+70440808105"}
0005434724095	2DEF65	8626 364955	NATALYA NOVIKOVA	{"phone": "+70951028574"}
0005434724096	2DEF65	3328 827148	NIKOLAY CHERNOV	{"email": "chernov.n.1966@postgrespro.ru", "phone": "+70156496033"}
0005434724097	75564E	3948 652884	YURIY NIKITIN	{"email": "yuriy-nikitin_1980@postgrespro.ru", "phone": "+70028725854"}
0005434724098	6F0E6A	7174 496431	IVAN KARPOV	{"email": "ivan-karpov.1969@postgrespro.ru", "phone": "+70165851608"}
0005434724099	69AAC2	5185 166421	ALINA MIKHAYLOVA	{"email": "a.mikhaylova_1979@postgrespro.ru", "phone": "+70771597697"}
0005434724100	3D310A	1312 286617	VYACHESLAV ALEKSEEV	{"phone": "+70564570777"}
0005434724101	5B706A	2784 452245	EVGENIY ZHURAVLEV	{"email": "evgeniy.zhuravlev-06071964@postgrespro.ru", "phone": "+70277756999"}
0005434724102	E385CF	2332 566791	MIKHAIL BORISOV	{"phone": "+70109987566"}
0005434724103	A5B378	6635 993346	DMITRIY TARASOV	{"phone": "+70217391868"}
0005434724104	FA796C	5127 947013	SERGEY MATVEEV	{"phone": "+70780665987"}
0005434724105	8BAF00	7183 127053	NATALYA IVANOVA	{"email": "ivanova.n-081969@postgrespro.ru", "phone": "+70469852820"}
0005434724106	EE79EF	6606 717517	ALLA VOLKOVA	{"email": "allavolkova051980@postgrespro.ru", "phone": "+70750434074"}
0005434724107	C53B5E	8826 507439	SERGEY NIKOLAEV	{"phone": "+70525608526"}
0005434724108	0DEF24	9562 276782	ALEKSEY GAVRILOV	{"phone": "+70030200725"}
0005434724109	61AD6A	4280 313389	YULIYA SMIRNOVA	{"phone": "+70810480216"}
0005434724110	61AD6A	5800 190725	VLADIMIR MARTYNOV	{"phone": "+70302763242"}
0005434724111	F6F8F8	0441 374503	OLGA KONDRATEVA	{"phone": "+70418890161"}
0005434724112	DE5575	5515 369102	LIDIYA ANTONOVA	{"email": "antonova-lidiya_041970@postgrespro.ru", "phone": "+70941348679"}
0005434724113	B3914A	1795 553977	VITALIY MAKAROV	{"phone": "+70381009138"}
0005434724114	B3914A	1429 863568	NINA BARANOVA	{"email": "ninabaranova_1987@postgrespro.ru", "phone": "+70729589074"}
0005434724115	B3914A	3833 905840	MAKSIM KUDRYASHOV	{"email": "m_kudryashov101970@postgrespro.ru", "phone": "+70802230142"}
0005434724116	3D30BB	6705 051989	DENIS MOROZOV	{"email": "d_morozov.1973@postgrespro.ru", "phone": "+70909907722"}
0005434724117	905EF8	7731 440931	SVETLANA SIDOROVA	{"phone": "+70054886908"}
0005434724118	64517C	5440 659762	NATALYA VLASOVA	{"email": "n_vlasova_05101974@postgrespro.ru", "phone": "+70956356560"}
0005434724119	5D0F47	8013 888928	ELENA ALEKSEEVA	{"email": "elena-alekseeva_1980@postgrespro.ru", "phone": "+70830119312"}
0005434724120	D1BBBF	7177 597596	SERGEY ALEKSANDROV	{"email": "saleksandrov_1965@postgrespro.ru", "phone": "+70057844260"}
0005434724121	D1BBBF	1677 299174	SERGEY KOROLEV	{"email": "korolevsergey081972@postgrespro.ru", "phone": "+70496526282"}
0005434724122	D35359	2429 875422	GALINA FILIPPOVA	{"phone": "+70156947155"}
0005434724123	76A461	2418 812376	SVETLANA IVANOVA	{"phone": "+70923339519"}
0005434724124	2E75DE	2600 834818	ANDREY NIKITIN	{"email": "andrey.nikitin_081971@postgrespro.ru", "phone": "+70344289581"}
0005434724125	2E75DE	5321 484239	SERGEY AFANASEV	{"email": "s_afanasev_011973@postgrespro.ru", "phone": "+70672691713"}
0005434724126	B8C264	7037 594507	VLADIMIR KISELEV	{"phone": "+70951124609"}
0005434724127	D8B1C6	3648 760362	NADEZHDA AKIMOVA	{"email": "nadezhda-akimova.041974@postgrespro.ru", "phone": "+70221018213"}
0005434724128	D3D8D9	4538 104000	MIKHAIL MOISEEV	{"phone": "+70281866617"}
0005434724129	2D799D	8824 675953	YULIYA SERGEEVA	{"phone": "+70662653711"}
0005434724130	2D799D	0056 870022	VALERIY ALEKSEEV	{"email": "alekseevvaleriy_021974@postgrespro.ru", "phone": "+70567930862"}
0005434724131	E315FF	7449 724529	EKATERINA KONOVALOVA	{"email": "e-konovalova041973@postgrespro.ru", "phone": "+70065552078"}
0005434724132	D0EEB5	9059 533532	YURIY TIMOFEEV	{"email": "yuriy-timofeev_20121984@postgrespro.ru", "phone": "+70654763972"}
0005434724133	34528B	2081 652400	ZAKHAR CHERNOV	{"email": "zakhar-chernov051975@postgrespro.ru", "phone": "+70427738454"}
0005434724134	34528B	2757 769738	SERGEY EGOROV	{"email": "sergey_egorov.17091969@postgrespro.ru", "phone": "+70864932152"}
0005434724135	7359BE	2374 143515	DMITRIY MIKHAYLOV	{"email": "mikhaylov_dmitriy-1975@postgrespro.ru", "phone": "+70358102758"}
0005434724136	7359BE	6103 952929	ALENA ZAKHAROVA	{"email": "zakharova.a1970@postgrespro.ru", "phone": "+70924293881"}
0005434724137	6795FA	1284 113675	NADEZHDA GAVRILOVA	{"email": "gavrilova.nadezhda.1977@postgrespro.ru", "phone": "+70877957358"}
0005434724138	6795FA	4748 107781	OLGA NAZAROVA	{"phone": "+70714812094"}
0005434724139	666BE2	6894 009502	MIKHAIL GAVRILOV	{"phone": "+70697475986"}
0005434724140	B7B85B	6715 695372	IVAN PETROV	{"email": "petrov_ivan-29121968@postgrespro.ru", "phone": "+70649898538"}
0005434724141	B7B85B	3202 430766	VALENTINA POPOVA	{"phone": "+70450681645"}
0005434724142	73A9C5	2695 633509	ALEKSANDRA KOVALEVA	{"phone": "+70897478493"}
0005434724143	73A9C5	6964 063115	OLGA IVANOVA	{"phone": "+70316384470"}
0005434724144	CF0BCD	1467 780512	VALERIY ALEKSANDROV	{"phone": "+70468262791"}
0005434724145	60200F	3643 780310	TATYANA ALEKSEEVA	{"email": "talekseeva_04081959@postgrespro.ru", "phone": "+70518397134"}
0005434724146	9B67CA	4099 686846	ANASTASIYA OVCHINNIKOVA	{"phone": "+70147088818"}
0005434724147	955D69	2814 542156	DMITRIY KUZNECOV	{"phone": "+70163066548"}
0005434724148	F54263	7749 311881	ALEKSANDRA EGOROVA	{"phone": "+70567987831"}
0005434724149	58E44D	1560 997438	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov01081976@postgrespro.ru", "phone": "+70581072743"}
0005434724150	8D8AD5	8997 768232	ALENA ZAKHAROVA	{"phone": "+70670481189"}
0005434724151	5546F6	6746 117497	EKATERINA MIKHAYLOVA	{"phone": "+70600573892"}
0005434724152	1F53DE	6552 309606	ALEKSANDR SIDOROV	{"email": "a_sidorov.011974@postgrespro.ru", "phone": "+70188625356"}
0005434724153	90971F	9557 004705	ANNA SAVELEVA	{"phone": "+70941587786"}
0005434724154	90971F	4018 978603	ARINA SMIRNOVA	{"email": "smirnova.arina-021981@postgrespro.ru", "phone": "+70669356573"}
0005434724155	77F595	2615 989895	SVETLANA GAVRILOVA	{"email": "gavrilova-svetlana_121966@postgrespro.ru", "phone": "+70830676184"}
0005434724156	32D633	5217 719122	NINA GRISHINA	{"email": "grishina.n1979@postgrespro.ru", "phone": "+70001185311"}
0005434724157	32D633	4070 810956	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_aleksandr-23011970@postgrespro.ru", "phone": "+70989550216"}
0005434724158	32D633	2265 041108	LIDIYA ZOTOVA	{"phone": "+70513093226"}
0005434724159	CDF9C3	8350 316090	PELAGEYA PETROVA	{"email": "pelageyapetrova_011975@postgrespro.ru", "phone": "+70170436965"}
0005434724160	17C528	9117 665576	ANTONINA GUSEVA	{"email": "guseva_a-041972@postgrespro.ru", "phone": "+70353262992"}
0005434724161	9C67ED	4715 694360	ANATOLIY KOROLEV	{"email": "korolev.a.27071972@postgrespro.ru", "phone": "+70662242514"}
0005434724162	9C67ED	6958 275021	YULIYA KALININA	{"email": "kalinina.y20021962@postgrespro.ru", "phone": "+70723054165"}
0005434724163	9B73A8	9399 835244	FEDOR GAVRILOV	{"email": "fedor-gavrilov_121982@postgrespro.ru", "phone": "+70825494667"}
0005434724164	500D17	1455 715350	ALEKSANDR VASILEV	{"phone": "+70016556504"}
0005434724165	6492D2	6510 456432	OLEG KARPOV	{"phone": "+70852684816"}
0005434724166	168B4E	8038 000019	SERGEY ZHUKOV	{"email": "zhukovsergey.1973@postgrespro.ru", "phone": "+70643132233"}
0005434724167	168B4E	2087 667863	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov-07121968@postgrespro.ru", "phone": "+70015693838"}
0005434724168	168B4E	5748 226412	NIKOLAY NAZAROV	{"phone": "+70097221704"}
0005434724169	602074	5628 655760	VALERIY IVANOV	{"phone": "+70443832864"}
0005434724170	810E51	7528 731099	ALEKSANDR BORISOV	{"phone": "+70013077054"}
0005434724171	35DA4D	6032 888030	YURIY PETROV	{"phone": "+70315721468"}
0005434724172	2F47D9	0558 638678	MILENA STEPANOVA	{"email": "stepanova_m_021964@postgrespro.ru", "phone": "+70074695655"}
0005434724173	2F47D9	0215 437887	LYUDMILA KUDRYASHOVA	{"email": "lyudmila_kudryashova.13101979@postgrespro.ru", "phone": "+70631584327"}
0005434724174	076910	8856 581317	VERA KOLESNIKOVA	{"phone": "+70466278451"}
0005434724175	076910	7829 038674	ALLA KUZNECOVA	{"email": "a-kuznecova.021970@postgrespro.ru", "phone": "+70977696783"}
0005434724176	77ECF4	9401 370481	NINA MATVEEVA	{"email": "matveeva.n-091974@postgrespro.ru", "phone": "+70489291013"}
0005434724177	77ECF4	6309 668884	VASILIY KUZNECOV	{"email": "kuznecov_vasiliy_041968@postgrespro.ru", "phone": "+70181805335"}
0005434724178	969079	0112 953704	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-aleksandr30051980@postgrespro.ru", "phone": "+70014568773"}
0005434724179	948C7B	9661 960580	NATALYA KOZLOVA	{"email": "natalya.kozlova.041973@postgrespro.ru", "phone": "+70329599703"}
0005434724180	156CCA	5479 799041	SERGEY ORLOV	{"phone": "+70788509690"}
0005434724181	CDCABD	8826 163548	RAISA KOROLEVA	{"email": "koroleva-r-31101976@postgrespro.ru", "phone": "+70781119274"}
0005434724182	1B207D	3071 957108	ELENA MARTYNOVA	{"email": "e_martynova_22041977@postgrespro.ru", "phone": "+70250664862"}
0005434724183	0F84F5	6315 108412	SERGEY SIDOROV	{"email": "ssidorov-1980@postgrespro.ru", "phone": "+70226706969"}
0005434724184	0F84F5	8959 494996	DMITRIY MEDVEDEV	{"phone": "+70740236455"}
0005434724185	0F84F5	6090 442337	VERA KUZNECOVA	{"email": "kuznecova-v041985@postgrespro.ru", "phone": "+70815302265"}
0005434724186	D28F0C	6883 769924	TATYANA MIRONOVA	{"email": "t.mironova.1971@postgrespro.ru", "phone": "+70932749513"}
0005434724187	6B2133	4382 648414	TATYANA IVANOVA	{"phone": "+70006070003"}
0005434724188	6B2133	8468 867367	ALEKSEY PETROV	{"email": "petrov-aleksey.081972@postgrespro.ru", "phone": "+70378865962"}
0005434724189	6B2133	0250 784944	MARGARITA ZAKHAROVA	{"email": "zakharovam_061976@postgrespro.ru", "phone": "+70301649073"}
0005434724190	0896D8	8815 287281	ANATOLIY NAUMOV	{"email": "naumova-061958@postgrespro.ru", "phone": "+70462438247"}
0005434724191	84B229	0529 410705	ELIZAVETA ZHUKOVA	{"phone": "+70241990113"}
0005434724192	84B229	6419 117358	PAVEL KUDRYASHOV	{"email": "kudryashovp061964@postgrespro.ru", "phone": "+70537976578"}
0005434724193	357A2B	7698 809699	ILYA PAVLOV	{"phone": "+70725257151"}
0005434724194	AB8F70	3347 026826	NIKOLAY EGOROV	{"phone": "+70226495291"}
0005434724195	8E2988	4640 460167	LEV BORISOV	{"phone": "+70489082566"}
0005434724196	BF5FE3	0749 251390	KSENIYA NIKIFOROVA	{"email": "kseniya-nikiforova_12121974@postgrespro.ru", "phone": "+70198812584"}
0005434724197	BF5FE3	5815 256984	NELLI KOROLEVA	{"email": "n.koroleva.081972@postgrespro.ru", "phone": "+70304832358"}
0005434724198	7CFD4D	4244 581930	NINA DENISOVA	{"phone": "+70506633879"}
0005434724199	8289E3	8305 545055	FANIL EGOROV	{"phone": "+70180208799"}
0005434724200	8289E3	0739 531907	SERGEY MIRONOV	{"phone": "+70322615357"}
0005434724201	8A3024	0905 394660	ALEKSANDR SOROKIN	{"phone": "+70474032549"}
0005434724202	405B0B	0528 340459	ALEKSEY TIMOFEEV	{"email": "a-timofeev041963@postgrespro.ru", "phone": "+70508748894"}
0005434724203	B2E0F5	8335 912689	ALEKSANDR ZAKHAROV	{"phone": "+70094243311"}
0005434724204	B2E0F5	8163 124595	IVAN KOZLOV	{"email": "kozlov-ivan_08081974@postgrespro.ru", "phone": "+70412709440"}
0005434724205	071CC7	7058 386635	VALERIYA KUZMINA	{"email": "valeriya-kuzmina091969@postgrespro.ru", "phone": "+70558661757"}
0005434724206	099FED	7194 512841	VASILIY MAKAROV	{"phone": "+70872269400"}
0005434724207	099FED	2339 837781	ELENA POLYAKOVA	{"email": "polyakova.e_1973@postgrespro.ru", "phone": "+70121597009"}
0005434724208	099FED	3718 850754	VERA NAUMOVA	{"email": "naumova-v-1983@postgrespro.ru", "phone": "+70131789277"}
0005434724209	A5DD9A	2550 351543	EVGENIY MOROZOV	{"email": "morozov_evgeniy021973@postgrespro.ru", "phone": "+70256308291"}
0005434724210	A5DD9A	1626 952021	ALLA IVANOVA	{"phone": "+70582275583"}
0005434724211	1FAFDC	8614 724345	ELENA ABRAMOVA	{"email": "abramovaelena_1984@postgrespro.ru", "phone": "+70014620007"}
0005434724212	B88A4B	7490 711337	VERA SERGEEVA	{"phone": "+70727286308"}
0005434724213	F886C6	5305 093259	NIKOLAY NIKITIN	{"email": "nnikitin_111975@postgrespro.ru", "phone": "+70767868224"}
0005434724214	F886C6	1839 527822	MIKHAIL BELOV	{"email": "m-belov_1974@postgrespro.ru", "phone": "+70791018136"}
0005434724215	6A248A	0100 308160	ANNA TITOVA	{"email": "titova-anna091976@postgrespro.ru", "phone": "+70353315231"}
0005434724216	DD2E28	3170 789300	VITALIY EGOROV	{"email": "egorov-vitaliy_1968@postgrespro.ru", "phone": "+70934113091"}
0005434724217	DD2E28	8592 013463	SERGEY ZAYCEV	{"email": "sergey.zaycev1971@postgrespro.ru", "phone": "+70001872562"}
0005434724218	96D1A7	8191 866330	LIDIYA BARANOVA	{"email": "lidiya-baranova.01071979@postgrespro.ru", "phone": "+70794625247"}
0005434724219	786D49	0495 206789	YANA AFANASEVA	{"email": "yana-afanaseva05051975@postgrespro.ru", "phone": "+70958116091"}
0005434724220	167C82	2282 754427	PAVEL SEMENOV	{"email": "psemenov_041967@postgrespro.ru", "phone": "+70930781350"}
0005434724221	483CAD	2819 683058	ILMIR ALEKSANDROV	{"phone": "+70790550407"}
0005434724222	483CAD	5053 004763	MIKHAIL AFANASEV	{"phone": "+70231791179"}
0005434724223	8FA85D	8264 318266	EVGENIY MATVEEV	{"phone": "+70949123134"}
0005434724224	2E6FAA	0631 046212	ALEKSEY NAUMOV	{"phone": "+70764983702"}
0005434724225	2E6FAA	7984 318654	ANTON FEDOROV	{"email": "fedorov-a081970@postgrespro.ru", "phone": "+70814018248"}
0005434724226	730A58	0439 601863	GALINA LOGINOVA	{"phone": "+70913562619"}
0005434724227	888C61	6584 204733	VALENTINA ANTONOVA	{"email": "antonova.valentina_12121970@postgrespro.ru", "phone": "+70583326689"}
0005434724228	B8AB75	0521 917968	IVAN SHEVCHENKO	{"email": "ivan_shevchenko_051972@postgrespro.ru", "phone": "+70564620569"}
0005434724229	AD7888	2225 746814	ELIZAVETA TITOVA	{"phone": "+70608276644"}
0005434724230	E1E55E	3750 382214	KRISTINA ZAYCEVA	{"email": "kzayceva.23051960@postgrespro.ru", "phone": "+70468395502"}
0005434724231	850277	6732 636467	VLADIMIR VOROBEV	{"phone": "+70364599795"}
0005434724232	67A877	1955 699680	ELENA IVANOVA	{"phone": "+70341394045"}
0005434724233	84B004	4871 103453	ALENA DENISOVA	{"phone": "+70386633269"}
0005434724234	84B004	5783 364497	EVGENIYA POLYAKOVA	{"phone": "+70695545283"}
0005434724235	C00A86	1085 608056	IRINA IVANOVA	{"email": "ivanova_i-28121981@postgrespro.ru", "phone": "+70410091475"}
0005434724236	6F8C5F	3270 874460	ELENA IVANOVA	{"phone": "+70422493035"}
0005434724237	5717A9	9857 609428	YAN KUZNECOV	{"email": "kuznecov-yan111967@postgrespro.ru", "phone": "+70182313604"}
0005434724238	A6F3CD	1602 046186	SERGEY ANDREEV	{"email": "sergeyandreev-061969@postgrespro.ru", "phone": "+70798509179"}
0005434724239	CAD56B	9260 776401	EVGENIY POPOV	{"email": "evgeniy-popov_11121975@postgrespro.ru", "phone": "+70299882759"}
0005434724240	CAD56B	0003 469708	SERGEY DMITRIEV	{"phone": "+70994602582"}
0005434724241	DAEE7A	6693 439613	RAMIL TARASOV	{"email": "tarasov_r1967@postgrespro.ru", "phone": "+70765191381"}
0005434724242	93C63F	5480 167927	NATALYA NESTEROVA	{"phone": "+70654614287"}
0005434724243	232371	7581 852148	ALEKSANDR FROLOV	{"email": "aleksandrfrolov-14051972@postgrespro.ru", "phone": "+70864795338"}
0005434724244	A050B7	4014 614863	YURIY KUZNECOV	{"email": "yuriy_kuznecov.081964@postgrespro.ru", "phone": "+70061272875"}
0005434724245	8F2BDE	7889 564330	SERGEY MATVEEV	{"email": "matveevs.1974@postgrespro.ru", "phone": "+70519978129"}
0005434724246	4475F2	5221 286405	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev1975@postgrespro.ru", "phone": "+70880626945"}
0005434724248	38EAE8	3520 515134	VERA KOROLEVA	{"phone": "+70122421244"}
0005434724249	38EAE8	1329 843897	SOFYA PAVLOVA	{"email": "pavlova_s.22011966@postgrespro.ru", "phone": "+70393326917"}
0005434724250	CC95EB	2462 067154	ELENA TROFIMOVA	{"phone": "+70864015093"}
0005434724251	0029F9	7398 481389	ALEKSANDR MOROZOV	{"email": "a_morozov04061965@postgrespro.ru", "phone": "+70063690858"}
0005434724252	A5FE0B	9372 185872	SVETLANA IVANOVA	{"phone": "+70897924212"}
0005434724253	90CE35	3067 745284	EVGENIYA POLYAKOVA	{"email": "e-polyakova.1972@postgrespro.ru", "phone": "+70807881087"}
0005434724254	90CE35	9505 279054	ELENA RODIONOVA	{"phone": "+70302377483"}
0005434724255	90CE35	3416 489705	NADEZHDA TIMOFEEVA	{"email": "timofeevan1969@postgrespro.ru", "phone": "+70375533194"}
0005434724256	C73FAC	9236 969600	NIKITA NOVIKOV	{"phone": "+70893863649"}
0005434724257	A1702A	7714 975221	EGOR NOVIKOV	{"phone": "+70658626647"}
0005434724258	A1702A	6317 324386	VASILIY ZAKHAROV	{"phone": "+70223986357"}
0005434724259	A1702A	8378 735005	TATYANA ILINA	{"email": "t-ilina-1971@postgrespro.ru", "phone": "+70818908864"}
0005434724260	47AA0E	2811 057762	GALINA MASLOVA	{"phone": "+70654623486"}
0005434724261	47AA0E	3945 414896	SERGEY ROMANOV	{"phone": "+70522976738"}
0005434724262	ECB3B9	9437 566410	ELENA MASLOVA	{"email": "elena_maslova_1971@postgrespro.ru", "phone": "+70102155676"}
0005434724263	0EC1F7	9328 585381	NIKOLAY BARANOV	{"email": "baranov.nikolay-1976@postgrespro.ru", "phone": "+70002120497"}
0005434724264	8218AD	7512 144296	OLGA BELOVA	{"phone": "+70209416680"}
0005434724265	ACFDB6	9658 754016	YULIYA DAVYDOVA	{"email": "y-davydova_15101972@postgrespro.ru", "phone": "+70089584666"}
0005434724266	4C6D9A	2083 574163	VALENTINA ZAYCEVA	{"phone": "+70431642969"}
0005434724267	BF8BE8	9974 074133	NIKITA POPOV	{"email": "popov_n_02111976@postgrespro.ru", "phone": "+70116881418"}
0005434724268	768CBF	6016 053212	ELENA BOGDANOVA	{"phone": "+70884898310"}
0005434724269	768CBF	4521 680938	TATYANA IVANOVA	{"email": "tatyanaivanova-02071967@postgrespro.ru", "phone": "+70938695264"}
0005434724270	768CBF	4749 298680	EGOR FROLOV	{"phone": "+70148135243"}
0005434724271	6649F7	2965 351460	DARYA SOLOVEVA	{"phone": "+70904231607"}
0005434724272	51CA24	7664 077457	VALENTINA IVANOVA	{"email": "valentina_ivanova.011970@postgrespro.ru", "phone": "+70311178190"}
0005434724273	51CA24	8549 360286	SVETLANA STEPANOVA	{"phone": "+70143489861"}
0005434724274	F5261C	9099 636385	YULIYA NOVIKOVA	{"email": "y.novikova.091970@postgrespro.ru", "phone": "+70396887491"}
0005434724275	F5261C	8730 564759	NIKOLAY SOROKIN	{"email": "nikolay.sorokin_23051987@postgrespro.ru", "phone": "+70138706494"}
0005434724276	43F591	5720 874770	ANNA MAKAROVA	{"email": "makarova-a_121971@postgrespro.ru", "phone": "+70969319155"}
0005434724277	954F18	1172 061578	EDUARD GAVRILOV	{"email": "egavrilov_091978@postgrespro.ru", "phone": "+70182107707"}
0005434724278	954F18	6042 943692	ELENA STEPANOVA	{"email": "e_stepanova051975@postgrespro.ru", "phone": "+70378721485"}
0005434724279	104BE0	5291 486176	MARIYA GAVRILOVA	{"phone": "+70367750486"}
0005434724280	7D0C78	9252 924075	NATALYA KOZLOVA	{"phone": "+70433576198"}
0005434724281	2E8643	1925 385501	RAISA SOLOVEVA	{"phone": "+70883743321"}
0005434724282	2E8643	6493 159800	OLGA VASILEVA	{"email": "o-vasileva_30111984@postgrespro.ru", "phone": "+70632015287"}
0005434724283	EB83B5	5800 018158	ANDREY GORBUNOV	{"email": "gorbunov-andrey29111968@postgrespro.ru", "phone": "+70881797773"}
0005434724284	36D535	7565 099032	KIRILL NOVIKOV	{"email": "novikov_kirill_111976@postgrespro.ru", "phone": "+70447667781"}
0005434724285	BBB24F	7283 734214	VASILIY NOVIKOV	{"email": "novikov_vasiliy-051972@postgrespro.ru", "phone": "+70151466652"}
0005434724286	BBB24F	4788 518998	SERGEY DAVYDOV	{"email": "davydov-sergey061976@postgrespro.ru", "phone": "+70595996651"}
0005434724287	D6FF1F	7065 885139	ALEKSANDR MIKHAYLOV	{"phone": "+70331366149"}
0005434724288	BB7B10	5819 868304	DENIS ANDREEV	{"phone": "+70480875463"}
0005434724289	BB7B10	9844 668499	LARISA TIKHONOVA	{"email": "larisa-tikhonova-16101977@postgrespro.ru", "phone": "+70105789235"}
0005434724290	334E28	6922 363950	ARTUR VOROBEV	{"email": "artur_vorobev_17081977@postgrespro.ru", "phone": "+70806424532"}
0005434724291	59B423	9989 463369	OLGA KAZAKOVA	{"email": "okazakova_1973@postgrespro.ru", "phone": "+70479798168"}
0005434724292	CFD4DC	7407 205605	VIKTORIYA AKIMOVA	{"email": "v_akimova1963@postgrespro.ru", "phone": "+70510150357"}
0005434724293	4A32C3	1595 263118	EMIL MATVEEV	{"email": "e_matveev14061970@postgrespro.ru", "phone": "+70264989329"}
0005434724294	4A32C3	7598 160568	ALEKSANDR NOVIKOV	{"phone": "+70786926574"}
0005434724295	09975D	3639 463422	ILDAR TIKHONOV	{"email": "i_tikhonov-121983@postgrespro.ru", "phone": "+70288901880"}
0005434724296	ECC3C1	2090 042463	TATYANA ALEKSANDROVA	{"email": "tatyana.aleksandrova.071971@postgrespro.ru", "phone": "+70487043408"}
0005434724297	ECC3C1	9614 289461	YULIYA ANTONOVA	{"email": "yuliya-antonova.091983@postgrespro.ru", "phone": "+70137464541"}
0005434724298	69B966	0380 155009	ANDREY FILIPPOV	{"phone": "+70940485537"}
0005434724299	69B966	5105 337144	VLADISLAV MAKSIMOV	{"email": "maksimovv101971@postgrespro.ru", "phone": "+70092088588"}
0005434724300	DC5F65	9655 442516	YULIYA CHERNOVA	{"phone": "+70754948022"}
0005434724301	E7FD15	6002 088091	MARINA DENISOVA	{"phone": "+70198611452"}
0005434724302	BCC7A8	3856 751446	SERGEY ANTONOV	{"phone": "+70981695178"}
0005434724303	0F1C08	7745 804832	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr08031963@postgrespro.ru", "phone": "+70410484010"}
0005434724304	830F24	1223 246186	DARYA KOVALEVA	{"email": "daryakovaleva28101971@postgrespro.ru", "phone": "+70076676780"}
0005434724305	830F24	5858 836846	OLGA FEDOROVA	{"email": "o_fedorova.1979@postgrespro.ru", "phone": "+70408379887"}
0005434724306	B45F17	3973 674952	IVAN OSIPOV	{"email": "osipov.i-071973@postgrespro.ru", "phone": "+70587731297"}
0005434724307	DDB629	3356 739126	MIKHAIL SOKOLOV	{"phone": "+70158488483"}
0005434724308	DDB629	2031 429723	ALEKSANDRA PAVLOVA	{"phone": "+70724296578"}
0005434724309	4E561D	4284 736441	SHAVKAT KUZMIN	{"phone": "+70249049681"}
0005434724310	67D6AD	4241 250311	ELIZAVETA CHERNOVA	{"phone": "+70913247476"}
0005434724311	8122F9	3998 963632	DANILA IVANOV	{"email": "ivanovdanila12091977@postgrespro.ru", "phone": "+70122895426"}
0005434724312	BE940C	3516 264226	ANDREY MATVEEV	{"email": "andrey.matveev.1975@postgrespro.ru", "phone": "+70680070473"}
0005434724313	CE2BEA	9585 147235	ANASTASIYA VOROBEVA	{"phone": "+70248264363"}
0005434724314	B4C560	2965 471813	DMITRIY TIMOFEEV	{"email": "dmitriytimofeev_1982@postgrespro.ru", "phone": "+70559792955"}
0005434724315	E89131	0266 087006	ALEKSANDR KOZLOV	{"phone": "+70263388792"}
0005434724316	E89131	0849 455750	KLAVDIYA FILIPPOVA	{"email": "filippova.klavdiya_10121978@postgrespro.ru", "phone": "+70426699904"}
0005434724317	959C69	0758 696161	LYUBOV POLYAKOVA	{"email": "polyakoval_091963@postgrespro.ru", "phone": "+70911937211"}
0005434724318	1A86C7	6715 913789	KAMILA LEBEDEVA	{"email": "lebedevakamila16011964@postgrespro.ru", "phone": "+70690932476"}
0005434724319	1A86C7	2237 716190	YURIY TIMOFEEV	{"phone": "+70643947082"}
0005434724321	6A5B61	9473 906797	VIKTOR TIKHONOV	{"phone": "+70029464770"}
0005434724322	6A5B61	7668 864306	NATALYA RYABOVA	{"email": "n-ryabova_09101973@postgrespro.ru", "phone": "+70770421973"}
0005434724323	34BA46	7501 892171	EKATERINA KARPOVA	{"email": "karpova_e.1965@postgrespro.ru", "phone": "+70553605734"}
0005434724324	A2D6B8	4530 956131	MARIYA TIKHONOVA	{"email": "tikhonova_mariya-29061968@postgrespro.ru", "phone": "+70183489004"}
0005434724325	B260BD	6720 948543	ANATOLIY KULIKOV	{"phone": "+70199529685"}
0005434724326	B260BD	1310 452370	ANASTASIYA SIDOROVA	{"email": "sidorova.a_06021983@postgrespro.ru", "phone": "+70045516705"}
0005434724327	E5EDE3	2665 325810	POLINA VASILEVA	{"email": "vasileva.polina1967@postgrespro.ru", "phone": "+70011167500"}
0005434724328	B37653	7139 105178	LYUBOV KOLESNIKOVA	{"email": "kolesnikova-lyubov11071979@postgrespro.ru", "phone": "+70973994838"}
0005434724329	B37653	9655 993140	RENAT VASILEV	{"phone": "+70720419261"}
0005434724330	6EADCF	0265 844036	LYUDMILA ISAEVA	{"email": "lisaeva.1975@postgrespro.ru", "phone": "+70424533006"}
0005434724331	6EADCF	2128 649191	SERGEY SOROKIN	{"phone": "+70786558800"}
0005434724332	47E24D	5815 458662	SHAMIL MIRONOV	{"email": "shamil.mironov_20051976@postgrespro.ru", "phone": "+70093079615"}
0005434724333	34C3C1	2102 844759	YURIY TARASOV	{"phone": "+70339781743"}
0005434724334	34C3C1	1465 158788	LYUDMILA POLYAKOVA	{"email": "polyakova_lyudmila_21071957@postgrespro.ru", "phone": "+70782749067"}
0005434724335	D46311	0573 535993	NADEZHDA FROLOVA	{"email": "frolova_n.071959@postgrespro.ru", "phone": "+70559851404"}
0005434724336	80D376	3484 039264	DMITRIY KARPOV	{"email": "dkarpov1974@postgrespro.ru", "phone": "+70894017178"}
0005434724337	010C01	6778 200431	YULIYA ROMANOVA	{"email": "romanova-y.051971@postgrespro.ru", "phone": "+70149435828"}
0005434724338	71E8E4	7771 252154	SERGEY DAVYDOV	{"email": "davydov_s.1979@postgrespro.ru", "phone": "+70907321387"}
0005434724339	661C72	8669 136278	YURIY KUZNECOV	{"phone": "+70456224929"}
0005434724340	137485	5982 607209	SVETLANA EGOROVA	{"email": "segorova.041972@postgrespro.ru", "phone": "+70777631329"}
0005434724341	E52D88	2657 009184	VALERIY ANDREEV	{"phone": "+70244373523"}
0005434724342	0EBAB8	0995 707568	MAKSIM OSIPOV	{"phone": "+70878332507"}
0005434724343	3258AA	0304 491490	NINA MEDVEDEVA	{"email": "medvedeva.n-091965@postgrespro.ru", "phone": "+70728000321"}
0005434724344	C1AC31	5331 759777	TATYANA BOGDANOVA	{"email": "t_bogdanova-1964@postgrespro.ru", "phone": "+70355473268"}
0005434724345	2B3B8A	4142 893535	SVETLANA POPOVA	{"phone": "+70987436752"}
0005434724346	2B3B8A	5176 122102	DANIIL PETROV	{"email": "petrov.daniil-1973@postgrespro.ru", "phone": "+70825799403"}
0005434724347	D4B32F	7591 007791	GALINA MELNIKOVA	{"email": "melnikovagalina-011979@postgrespro.ru", "phone": "+70820522694"}
0005434724348	D4B32F	4176 463325	DIANA ZAKHAROVA	{"phone": "+70949018090"}
0005434724349	8AC662	1213 526404	VALENTINA ANTONOVA	{"phone": "+70968407258"}
0005434724350	65EECF	0635 552821	ALEKSANDR IVANOV	{"email": "a_ivanov17051975@postgrespro.ru", "phone": "+70664481648"}
0005434724351	65EECF	0052 547039	OLGA IVANOVA	{"phone": "+70173298275"}
0005434724352	65EECF	3205 243018	DMITRIY TIMOFEEV	{"email": "dmitriy-timofeev.1978@postgrespro.ru", "phone": "+70578028184"}
0005434724353	046674	8361 652453	ELENA KOZLOVA	{"email": "e-kozlova24101972@postgrespro.ru", "phone": "+70637136494"}
0005434724354	6DEC41	7750 237249	SERGEY IVANOV	{"email": "ivanovs.061985@postgrespro.ru", "phone": "+70914291117"}
0005434724355	9E7DF3	3950 881823	OLESYA NOVIKOVA	{"email": "o_novikova_1970@postgrespro.ru", "phone": "+70346454449"}
0005434724356	C0D468	6295 650439	DMITRIY DMITRIEV	{"phone": "+70974004517"}
0005434724357	89E47B	8664 123417	MARINA MASLOVA	{"phone": "+70389691186"}
0005434724358	307BF2	3335 638542	TATYANA MOROZOVA	{"phone": "+70942973542"}
0005434724359	7926F1	9859 046208	TATYANA EGOROVA	{"phone": "+70818937591"}
0005434724360	7926F1	8193 139005	GEORGIY KUZMIN	{"phone": "+70829412908"}
0005434724361	0AB663	9144 688269	VERONIKA ISAEVA	{"phone": "+70734110014"}
0005434724362	C79002	1344 238753	ALEKSANDRA SOLOVEVA	{"phone": "+70250847477"}
0005434724363	676D44	2723 961469	ANNA ABRAMOVA	{"phone": "+70143399451"}
0005434724364	676D44	7877 000859	ANTON DAVYDOV	{"phone": "+70089037037"}
0005434724365	676D44	8837 177647	MIKHAIL GRIGOREV	{"email": "mgrigorev.1969@postgrespro.ru", "phone": "+70925870341"}
0005434724366	C2E11A	1110 576456	MIKHAIL FEDOTOV	{"phone": "+70678128820"}
0005434724367	E48CAE	1215 721010	GENNADIY FEDOTOV	{"email": "fedotovgennadiy_041969@postgrespro.ru", "phone": "+70035863388"}
0005434724368	3745AB	5813 616653	OLGA KISELEVA	{"phone": "+70109746267"}
0005434724369	3745AB	0342 432951	SVETLANA VASILEVA	{"phone": "+70828290615"}
0005434724370	728072	7697 654733	IRINA BELOVA	{"email": "i.belova21091974@postgrespro.ru", "phone": "+70833022766"}
0005434724371	266501	6732 865292	ROMAN KUZNECOV	{"email": "rkuznecov.18021961@postgrespro.ru", "phone": "+70994117360"}
0005434724372	266501	1519 442007	MARINA PAVLOVA	{"email": "pavlova_m081974@postgrespro.ru", "phone": "+70671674586"}
0005434724373	266501	4737 532903	ALEKSANDR NIKITIN	{"phone": "+70295919094"}
0005434724374	49BE87	6749 667102	OLEG TIKHONOV	{"email": "otikhonov-101970@postgrespro.ru", "phone": "+70814708693"}
0005434724375	D0F0F9	9783 437621	ARSENIY MIRONOV	{"email": "arseniy-mironov_101976@postgrespro.ru", "phone": "+70550036095"}
0005434724376	D0F0F9	2367 486414	DARYA ANDREEVA	{"phone": "+70810665108"}
0005434724377	85FD9F	4636 343910	ALEKSANDR IVANOV	{"email": "a-ivanov-031970@postgrespro.ru", "phone": "+70483937240"}
0005434724378	85FD9F	8927 805213	ELENA FILIPPOVA	{"email": "e.filippova_16021980@postgrespro.ru", "phone": "+70334832575"}
0005434724379	406E94	6340 888918	INNA SOLOVEVA	{"email": "innasoloveva091975@postgrespro.ru", "phone": "+70425735321"}
0005434724380	6F7E35	3574 958447	ANATOLIY NOVIKOV	{"phone": "+70222827739"}
0005434724381	90AD05	9344 948289	OLESYA TARASOVA	{"email": "o-tarasova.1975@postgrespro.ru", "phone": "+70373524956"}
0005434724382	77AEB9	9533 358208	ANASTASIYA SOROKINA	{"phone": "+70396823845"}
0005434724383	314B31	7799 925408	GULIYA TIKHONOVA	{"email": "gtikhonova1969@postgrespro.ru", "phone": "+70575140396"}
0005434724384	A52DC3	1445 134369	ALEKSANDR RODIONOV	{"email": "rodionova_21121965@postgrespro.ru", "phone": "+70969051482"}
0005434724385	E879EC	1403 192904	ARINA NOVIKOVA	{"email": "novikova_a-111981@postgrespro.ru", "phone": "+70416445979"}
0005434724386	D0AC56	4786 033960	ALEKSANDR ROMANOV	{"email": "romanov-a.101980@postgrespro.ru", "phone": "+70889400063"}
0005434724387	D0AC56	1145 667811	SVETLANA POPOVA	{"phone": "+70098563211"}
0005434724388	4B6CFE	5782 557394	LYUDMILA SOKOLOVA	{"phone": "+70983392894"}
0005434724389	303EAE	5899 505404	MARIYA NIKOLAEVA	{"phone": "+70032011249"}
0005434724390	DB5FB6	1903 612628	ALINA NAZAROVA	{"email": "nazarovaa.10051963@postgrespro.ru", "phone": "+70162468036"}
0005434724391	DB5FB6	6281 315349	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaa1975@postgrespro.ru", "phone": "+70496638589"}
0005434724392	0FD114	1209 014473	OLESYA VASILEVA	{"phone": "+70822801144"}
0005434724393	0FD114	8109 173630	ARTEM MAKSIMOV	{"email": "artemmaksimov.031974@postgrespro.ru", "phone": "+70714090841"}
0005434724394	B262BA	5770 068692	VALERIY ZAKHAROV	{"email": "zakharovv-091959@postgrespro.ru", "phone": "+70761829645"}
0005434724395	B262BA	6212 366409	TAMARA LEBEDEVA	{"phone": "+70559935535"}
0005434724396	D5C9E4	9914 711820	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr101970@postgrespro.ru", "phone": "+70820807776"}
0005434724397	D5C9E4	4026 609582	ANNA GORBUNOVA	{"phone": "+70349850145"}
0005434724398	4A6C3E	7443 262246	OKSANA BELOVA	{"phone": "+70426677097"}
0005434724399	4A6C3E	2745 761612	IVAN EGOROV	{"email": "egorov.ivan021975@postgrespro.ru", "phone": "+70112499515"}
0005434724400	74AA7F	3849 727130	MARINA DANILOVA	{"email": "marina.danilova-031971@postgrespro.ru", "phone": "+70469532311"}
0005434724401	74AA7F	9626 419619	VYACHESLAV GERASIMOV	{"email": "vgerasimov-091964@postgrespro.ru", "phone": "+70765689864"}
0005434724402	0CD071	2839 344834	EKATERINA SIDOROVA	{"phone": "+70158690529"}
0005434724403	F10F5F	7170 055044	OLGA FEDOROVA	{"email": "fedorova.o_1973@postgrespro.ru", "phone": "+70533503073"}
0005434724404	EFF02E	5181 234900	DARYA KRASNOVA	{"phone": "+70035228014"}
0005434724405	EFF02E	6471 569538	NIKOLAY EGOROV	{"email": "egorovn.1964@postgrespro.ru", "phone": "+70931077679"}
0005434724406	06C879	9649 242232	GALINA POPOVA	{"phone": "+70710616383"}
0005434724407	3D619E	7864 809282	ANDREY ZHURAVLEV	{"phone": "+70013254195"}
0005434724408	02F589	0960 323484	EVGENIY BELOV	{"phone": "+70112428522"}
0005434724409	CA5001	3744 682105	NINA KOVALEVA	{"phone": "+70104264901"}
0005434724410	6A86D3	1597 804575	VALENTINA SAVELEVA	{"email": "valentinasaveleva.16111963@postgrespro.ru", "phone": "+70545349685"}
0005434724411	82050D	5309 528660	TATYANA POLYAKOVA	{"email": "polyakova-tatyana.101972@postgrespro.ru", "phone": "+70485079390"}
0005434724412	35D30C	9445 160252	ARTEM OSIPOV	{"email": "osipovartem1979@postgrespro.ru", "phone": "+70007809770"}
0005434724413	D83D67	0436 662098	ZHANNA BELOVA	{"phone": "+70135443184"}
0005434724414	B1AF0D	6702 433537	ANTONIDA KRASNOVA	{"email": "antonidakrasnova_28111984@postgrespro.ru", "phone": "+70026670575"}
0005434724415	B1AF0D	2929 188581	NINA ZHURAVLEVA	{"phone": "+70654637788"}
0005434724416	A1D48D	6544 945095	ELENA RODIONOVA	{"email": "e.rodionova_16041973@postgrespro.ru", "phone": "+70586142246"}
0005434724417	60231A	3126 032718	DMITRIY VASILEV	{"email": "vasilevdmitriy05051971@postgrespro.ru", "phone": "+70732812175"}
0005434724418	60231A	6608 324155	MARIYA ROMANOVA	{"phone": "+70026877158"}
0005434724419	42A1F8	4816 398595	SERGEY BARANOV	{"email": "s_baranov.1966@postgrespro.ru", "phone": "+70893766651"}
0005434724420	B31EC1	0075 153707	SERGEY OSIPOV	{"email": "osipovsergey101964@postgrespro.ru", "phone": "+70462157057"}
0005434724421	70A346	0842 103837	ALEKSANDR KUZMIN	{"phone": "+70094211022"}
0005434724422	70A346	6043 660435	YULIYA NAUMOVA	{"phone": "+70944347430"}
0005434724423	C3F64F	8516 968591	SVETLANA KUZMINA	{"email": "svetlanakuzmina-1965@postgrespro.ru", "phone": "+70092788200"}
0005434724424	1597F0	0279 429618	ARTEM FROLOV	{"phone": "+70286413595"}
0005434724425	1597F0	0612 645419	SVETLANA LOGINOVA	{"email": "s_loginova-1973@postgrespro.ru", "phone": "+70361904750"}
0005434724426	A5B099	0068 078140	YULIYA SOROKINA	{"phone": "+70188859775"}
0005434724783	45658B	0336 638092	LYUBOV POLYAKOVA	{"phone": "+70604076150"}
0005434724427	8B1B58	8251 607790	NIKOLAY EGOROV	{"email": "nikolay.egorov-21011976@postgrespro.ru", "phone": "+70361318617"}
0005434724428	10E272	6433 721159	MARIYA FILIPPOVA	{"email": "filippova_mariya_27121965@postgrespro.ru", "phone": "+70831924321"}
0005434724429	10E272	5683 573432	NIKOLAY MOROZOV	{"phone": "+70594919925"}
0005434724430	A264C9	6179 049330	RAISA SIDOROVA	{"email": "r-sidorova-091976@postgrespro.ru", "phone": "+70605325797"}
0005434724431	A264C9	5128 097929	DANILA MAKAROV	{"email": "makarov.danila-1976@postgrespro.ru", "phone": "+70390756522"}
0005434724432	EC37B6	6904 554739	ALEKSANDR FEDOROV	{"phone": "+70670301916"}
0005434724433	6BC6C6	7070 107685	SERGEY FEDOROV	{"email": "fedorov_sergey_24041976@postgrespro.ru", "phone": "+70233756972"}
0005434724434	0ED73D	1373 800156	SVETLANA LUKYANOVA	{"phone": "+70170710486"}
0005434724435	3669A3	7033 805399	LYUBOV PAVLOVA	{"email": "pavlova-l.041971@postgrespro.ru", "phone": "+70182282195"}
0005434724436	3669A3	9672 591047	SERGEY ABRAMOV	{"phone": "+70449815822"}
0005434724437	3669A3	6420 593385	ELENA FILIPPOVA	{"phone": "+70367733494"}
0005434724438	61286B	8224 134329	ALEKSANDR FROLOV	{"email": "frolovaleksandr-111956@postgrespro.ru", "phone": "+70402551407"}
0005434724439	D70565	1753 631944	IVAN GAVRILOV	{"phone": "+70174244643"}
0005434724440	D70565	3899 936482	MIKHAIL IVANOV	{"email": "m-ivanov.041978@postgrespro.ru", "phone": "+70680706305"}
0005434724441	F58290	1050 470032	TATYANA ROMANOVA	{"email": "romanova_tatyana051979@postgrespro.ru", "phone": "+70216830939"}
0005434724442	CD7733	2135 390371	EKATERINA LUKYANOVA	{"email": "lukyanovaekaterina_27081974@postgrespro.ru", "phone": "+70001672250"}
0005434724443	CD7733	4512 214858	ANASTASIYA POPOVA	{"email": "popovaanastasiya.091976@postgrespro.ru", "phone": "+70562770914"}
0005434724444	4E00D0	9356 133799	ROMAN ZAKHAROV	{"email": "roman.zakharov_17081959@postgrespro.ru", "phone": "+70212888481"}
0005434724445	2DBA18	8036 285548	VLADIMIR ZAYCEV	{"phone": "+70833276023"}
0005434724446	173332	1437 008542	ZOYA NAZAROVA	{"email": "nazarova-z-061962@postgrespro.ru", "phone": "+70171211355"}
0005434724447	9409C7	1212 491393	IVAN MIRONOV	{"phone": "+70963409480"}
0005434724448	24B0BB	9694 045060	TATYANA VASILEVA	{"phone": "+70513427474"}
0005434724449	9EBDA2	0697 120255	ANATOLIY KOROLEV	{"email": "anatoliykorolev021977@postgrespro.ru", "phone": "+70759919555"}
0005434724450	B20038	1623 858063	OLESYA VASILEVA	{"phone": "+70395589519"}
0005434724451	6B4AA7	6086 946584	ALEKSANDR ANTONOV	{"email": "aantonov-031971@postgrespro.ru", "phone": "+70410885311"}
0005434724452	389022	1811 381188	GUZEL SEMENOVA	{"phone": "+70150127631"}
0005434724453	389022	2373 431095	VITALIY VOROBEV	{"phone": "+70011251358"}
0005434724454	1F582B	6497 018186	NATALYA NIKOLAEVA	{"phone": "+70192885699"}
0005434724455	5A6BA3	8368 846563	SERGEY BELOV	{"email": "sergeybelov_1967@postgrespro.ru", "phone": "+70720301632"}
0005434724456	5A6BA3	7338 913504	VLADIMIR KUZMIN	{"phone": "+70420920925"}
0005434724457	DB12D6	4207 589875	RAISA FILATOVA	{"email": "raisa-filatova_1969@postgrespro.ru", "phone": "+70872373130"}
0005434724458	F0CBAC	7796 537497	MIKHAIL NAUMOV	{"phone": "+70843344801"}
0005434724459	F0CBAC	0085 904614	VLADIMIR PAVLOV	{"phone": "+70789670102"}
0005434724460	102633	9150 909580	MARINA BARANOVA	{"email": "baranova.m.1976@postgrespro.ru", "phone": "+70744486848"}
0005434724461	CED591	4761 816441	ELENA MOISEEVA	{"email": "moiseeva_elena-071975@postgrespro.ru", "phone": "+70147933079"}
0005434724462	F7ACAA	3264 943509	SERGEY PETROV	{"phone": "+70025664965"}
0005434724463	8AEC45	6783 502707	YANA KOMAROVA	{"phone": "+70122406019"}
0005434724464	8AEC45	9503 559516	ANNA SERGEEVA	{"phone": "+70050592842"}
0005434724465	C24952	3582 300274	YULIYA KAZAKOVA	{"email": "y-kazakova.05121984@postgrespro.ru", "phone": "+70827001196"}
0005434724466	F98A37	4773 104656	VLADISLAV BONDARENKO	{"phone": "+70641273159"}
0005434724467	2A4ADE	1085 408774	FEDOR VOLKOV	{"phone": "+70155743077"}
0005434724468	4F04AE	9076 087587	SERGEY ZAYCEV	{"phone": "+70314268222"}
0005434724469	CCDB82	1496 047632	ANASTASIYA ZHUKOVA	{"email": "anastasiyazhukova_1974@postgrespro.ru", "phone": "+70330449865"}
0005434724470	9E0C6F	5480 084168	LYUDMILA STEPANOVA	{"email": "l-stepanova_111971@postgrespro.ru", "phone": "+70551902195"}
0005434724471	FFCE62	3255 991538	ALEKSANDR SIDOROV	{"phone": "+70843591617"}
0005434724472	241550	4820 392021	TAMARA FOMINA	{"email": "fomina.t.021970@postgrespro.ru", "phone": "+70078809223"}
0005434724473	18EF2B	8056 211092	SVETLANA FEDOROVA	{"phone": "+70414118559"}
0005434724474	18EF2B	3485 305423	NIKOLAY MOISEEV	{"phone": "+70149103851"}
0005434724475	18EF2B	7144 114393	ELIZAVETA VOLKOVA	{"email": "elizaveta.volkova-28071964@postgrespro.ru", "phone": "+70503178099"}
0005434724476	E148B3	0823 483337	VALENTINA MAKSIMOVA	{"phone": "+70434747910"}
0005434724477	51E58A	7862 883535	SVETLANA OVCHINNIKOVA	{"phone": "+70760061143"}
0005434724478	BDDF20	4410 142961	PAVEL KARPOV	{"email": "p_karpov1974@postgrespro.ru", "phone": "+70024630542"}
0005434724479	339C70	4931 114741	DMITRIY SAVELEV	{"email": "savelevdmitriy02081980@postgrespro.ru", "phone": "+70841219288"}
0005434724480	BDE2BC	6302 402851	EVGENIY ISAEV	{"email": "isaev.e1984@postgrespro.ru", "phone": "+70965651494"}
0005434724481	BDE2BC	2626 200036	DMITRIY SHEVCHENKO	{"email": "shevchenko.d.081972@postgrespro.ru", "phone": "+70704577815"}
0005434724482	651E41	8345 792449	VALENTIN ABRAMOV	{"phone": "+70160729796"}
0005434724483	49236B	5763 816495	OLGA NIKIFOROVA	{"email": "o_nikiforova-02121966@postgrespro.ru", "phone": "+70307868315"}
0005434724484	E7685E	6679 599369	ELENA KUZNECOVA	{"email": "kuznecova-e061978@postgrespro.ru", "phone": "+70601084040"}
0005434724485	B94B22	9481 331922	OLGA KOVALEVA	{"phone": "+70934403323"}
0005434724486	E34940	5003 131417	RAISA ALEKSEEVA	{"email": "r_alekseeva_31071961@postgrespro.ru", "phone": "+70186832804"}
0005434724487	49863A	7182 970347	NIKITA PETROV	{"email": "petrovnikita.041976@postgrespro.ru", "phone": "+70820281985"}
0005434724488	92D091	9769 484001	MIKHAIL MEDVEDEV	{"email": "m_medvedev-1965@postgrespro.ru", "phone": "+70743225129"}
0005434724489	0C7F3A	0871 390296	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr-1967@postgrespro.ru", "phone": "+70355436046"}
0005434724490	93284D	7538 750994	NADEZHDA KULIKOVA	{"phone": "+70828604743"}
0005434724491	D98DDC	4222 989068	NINA MIRONOVA	{"phone": "+70686984649"}
0005434724492	6A952B	1161 463211	LYUDMILA ZAYCEVA	{"email": "l.zayceva.07081979@postgrespro.ru", "phone": "+70327107170"}
0005434724493	6A952B	2745 194874	OLGA BOGDANOVA	{"email": "bogdanovaolga101976@postgrespro.ru", "phone": "+70872281179"}
0005434724494	B52DED	9576 609619	EGOR GAVRILOV	{"email": "e_gavrilov.25021969@postgrespro.ru", "phone": "+70494460952"}
0005434724495	B52DED	1147 375143	ALEKSANDRA POPOVA	{"email": "aleksandrapopova_051982@postgrespro.ru", "phone": "+70685405917"}
0005434724496	9AADA3	1992 941387	SOFYA GUSEVA	{"email": "guseva_sofya_091978@postgrespro.ru", "phone": "+70860002486"}
0005434724497	372EC0	8226 819424	DMITRIY NAZAROV	{"phone": "+70517413739"}
0005434724498	372EC0	9335 610285	RUSLAN SOROKIN	{"email": "r-sorokin_14091977@postgrespro.ru", "phone": "+70357571484"}
0005434724499	319C1C	3011 709561	ANTONINA BELOVA	{"phone": "+70739285047"}
0005434724500	02BB79	3565 615656	LYUDMILA LOGINOVA	{"email": "l_loginova1968@postgrespro.ru", "phone": "+70021593735"}
0005434724501	D5E37F	8662 507812	VALENTINA FEDOROVA	{"phone": "+70472859562"}
0005434724502	D5E37F	1770 287848	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova14011968@postgrespro.ru", "phone": "+70994531291"}
0005434724503	1B4B68	0865 976577	NINA KOROLEVA	{"email": "koroleva-n1979@postgrespro.ru", "phone": "+70335336947"}
0005434724504	84734F	1135 911835	ANASTASIYA MAKAROVA	{"email": "anastasiya_makarova_1977@postgrespro.ru", "phone": "+70594282149"}
0005434724505	034E4A	6596 763965	ELENA NIKITINA	{"phone": "+70759997954"}
0005434724506	034E4A	7620 876606	VALENTINA LOGINOVA	{"phone": "+70566991935"}
0005434724507	034E4A	2277 210833	VLADIMIR TARASOV	{"email": "tarasov_vladimir_04041972@postgrespro.ru", "phone": "+70144591695"}
0005434724508	BFE7A5	9917 300634	VASILIY MOROZOV	{"email": "v_morozov-1971@postgrespro.ru", "phone": "+70047697012"}
0005434724509	719647	6847 830100	OLGA KARPOVA	{"email": "karpovaolga_31031966@postgrespro.ru", "phone": "+70609947540"}
0005434724510	719647	8340 642047	IGOR SCHERBAKOV	{"email": "scherbakov-i-101980@postgrespro.ru", "phone": "+70653685292"}
0005434724511	A9CE1E	7365 840643	VIKTOR NIKOLAEV	{"email": "nikolaev_v.1968@postgrespro.ru", "phone": "+70151054119"}
0005434724512	093B85	9620 913108	PETR KULIKOV	{"phone": "+70249904966"}
0005434724513	B2B4C9	2396 544796	RUSLAN ANDREEV	{"phone": "+70800456319"}
0005434724514	B2B4C9	1340 442640	TAMARA KARPOVA	{"email": "karpova_t_011979@postgrespro.ru", "phone": "+70140172726"}
0005434724515	B2B4C9	1733 937223	ALEKSEY VOLKOV	{"email": "aleksey-volkov_021971@postgrespro.ru", "phone": "+70023388590"}
0005434724516	62C214	7924 923953	VLADIMIR KOZLOV	{"email": "kozlov.v_08051958@postgrespro.ru", "phone": "+70788911826"}
0005434724517	27FC1B	7313 881040	ARTEM DMITRIEV	{"email": "admitriev.19041968@postgrespro.ru", "phone": "+70702658390"}
0005434724518	27FC1B	0212 002687	NATALYA KOVALEVA	{"email": "kovaleva-natalya-1972@postgrespro.ru", "phone": "+70215845269"}
0005434724519	B36F2F	2904 316036	TAMARA ERMAKOVA	{"email": "ermakova.tamara_121978@postgrespro.ru", "phone": "+70589929292"}
0005434724520	DE2B75	0442 724708	ALBERT BELOV	{"phone": "+70702507991"}
0005434724521	AB25C2	0867 486842	NIKOLAY KRASNOV	{"phone": "+70299734711"}
0005434724522	62FC5C	8891 790549	ANASTASIYA VOROBEVA	{"phone": "+70128954370"}
0005434724523	CE9F29	6873 501378	NIKOLAY DENISOV	{"email": "denisov_n_1977@postgrespro.ru", "phone": "+70453526668"}
0005434724524	CE9F29	3379 956073	ANDREY KISELEV	{"email": "kiseleva_1970@postgrespro.ru", "phone": "+70069771825"}
0005434724525	DC5872	1786 325693	ARTEM MARTYNOV	{"phone": "+70582983099"}
0005434724526	DC5872	4645 901581	ROMAN MAKAROV	{"phone": "+70688453174"}
0005434724527	8C4DBF	8923 436055	VYACHESLAV MIRONOV	{"phone": "+70152501450"}
0005434724528	8C4DBF	7213 985621	VIKTOR YAKOVLEV	{"email": "viktoryakovlev_12051968@postgrespro.ru", "phone": "+70800907369"}
0005434724529	F33409	3071 424699	RUSLAN KARPOV	{"email": "r.karpov1977@postgrespro.ru", "phone": "+70565544613"}
0005434724530	8C8FC1	0131 334348	VALENTINA POPOVA	{"phone": "+70615467250"}
0005434724531	ECB96C	7252 625298	RAISA MELNIKOVA	{"phone": "+70968511855"}
0005434724532	CBED79	3425 198848	VALERIY KOZLOV	{"phone": "+70184934467"}
0005434724533	AF6A50	3361 266351	SVETLANA TROFIMOVA	{"phone": "+70736989793"}
0005434724534	90EDD0	0174 146677	TATYANA GUSEVA	{"email": "t.guseva-081971@postgrespro.ru", "phone": "+70187030478"}
0005434724535	C8358A	5934 174237	ALEKSEY GERASIMOV	{"email": "a.gerasimov22021964@postgrespro.ru", "phone": "+70984768050"}
0005434724536	7031F1	0309 007650	IGOR ILIN	{"phone": "+70995044482"}
0005434724537	7031F1	0368 901537	LILIYA KALININA	{"email": "l.kalinina26101966@postgrespro.ru", "phone": "+70364937023"}
0005434724538	F096BC	7117 743698	ALEKSEY MIRONOV	{"phone": "+70146983178"}
0005434724539	1E7A2F	7201 985707	VLADISLAV MIKHAYLOV	{"phone": "+70954918199"}
0005434724540	7A200E	0990 706736	IVAN ABRAMOV	{"email": "abramovi-121975@postgrespro.ru", "phone": "+70641049872"}
0005434724541	7A200E	7128 042509	VALERIY STEPANOV	{"email": "valeriystepanov-051968@postgrespro.ru", "phone": "+70309025435"}
0005434724542	77A711	7702 368535	KSENIYA STEPANOVA	{"email": "stepanovakseniya.1973@postgrespro.ru", "phone": "+70268234550"}
0005434724543	D47511	0200 746688	MARIYA POLYAKOVA	{"email": "polyakovamariya-1973@postgrespro.ru", "phone": "+70038990905"}
0005434724544	D47511	4887 462827	ALLA ANDREEVA	{"phone": "+70566252644"}
0005434724545	B77D24	6768 361617	DMITRIY STEPANOV	{"phone": "+70467272481"}
0005434724546	1D6326	1635 605984	YURIY VOROBEV	{"email": "vorobev-yuriy.1974@postgrespro.ru", "phone": "+70515678492"}
0005434724547	1D6326	8863 119608	GALINA MOISEEVA	{"phone": "+70753589990"}
0005434724548	1D6326	8282 071741	VLADIMIR BORISOV	{"email": "borisov-v071970@postgrespro.ru", "phone": "+70463583033"}
0005434724549	39E943	9816 034943	ARTEM FEDOROV	{"phone": "+70140045238"}
0005434724550	FF20CE	5774 751339	VIKTORIYA TARASOVA	{"email": "tarasova_viktoriya.1975@postgrespro.ru", "phone": "+70490400232"}
0005434724551	FF20CE	1663 304556	ANDREY POPOV	{"phone": "+70685341215"}
0005434724552	F65E87	4141 197852	VYACHESLAV DAVYDOV	{"email": "vyacheslav.davydov-081973@postgrespro.ru", "phone": "+70068419639"}
0005434724553	7A6389	0346 361355	ALBINA MAKSIMOVA	{"phone": "+70447612260"}
0005434724554	7A6389	9935 408082	DENIS MOROZOV	{"email": "dmorozov.09011976@postgrespro.ru", "phone": "+70039690590"}
0005434724555	B422D0	1775 543214	ALEKSANDRA KUZMINA	{"email": "kuzmina_aleksandra_1983@postgrespro.ru", "phone": "+70786922192"}
0005434724556	B422D0	5943 998218	VIKTOR SEMENOV	{"email": "semenovviktor.26121981@postgrespro.ru", "phone": "+70175476303"}
0005434724557	D83A1B	4469 156219	NATALYA SMIRNOVA	{"email": "smirnova.n_14061973@postgrespro.ru", "phone": "+70975554958"}
0005434724558	AA3FB6	7612 857066	PAVEL SEMENOV	{"phone": "+70088800298"}
0005434724559	D5F1CD	3902 086899	YURIY FEDOROV	{"email": "yuriy_fedorov_01081972@postgrespro.ru", "phone": "+70337236081"}
0005434724560	18EC6C	5357 725607	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya-1966@postgrespro.ru", "phone": "+70198422737"}
0005434724561	18EC6C	7661 224778	RAISA LOGINOVA	{"phone": "+70835339564"}
0005434724562	376590	3445 039161	MARINA LEBEDEVA	{"phone": "+70868805140"}
0005434724563	4FAA90	7636 174116	OLGA KUZNECOVA	{"email": "o_kuznecova22021963@postgrespro.ru", "phone": "+70161277072"}
0005434724564	4FAA90	8738 056977	LYUDMILA BORISOVA	{"email": "borisovalyudmila-1970@postgrespro.ru", "phone": "+70900263252"}
0005434724565	611368	6833 912397	NINA SIDOROVA	{"phone": "+70146338521"}
0005434724566	611368	4612 382625	GALINA IVANOVA	{"phone": "+70104122687"}
0005434724567	A32EDD	0130 287507	ALEKSANDRA ZAYCEVA	{"email": "zayceva_aleksandra-101954@postgrespro.ru", "phone": "+70562195298"}
0005434724568	0B7601	3775 430370	NATALYA ISAEVA	{"phone": "+70017929154"}
0005434724569	C02571	7468 584444	NAILYA KULIKOVA	{"phone": "+70453869628"}
0005434724570	24D175	2759 837039	OLEG DENISOV	{"phone": "+70278242082"}
0005434724571	A91089	6485 165806	KRISTINA DANILOVA	{"email": "k.danilova_1977@postgrespro.ru", "phone": "+70915153476"}
0005434724572	172BB1	5011 691006	VLADIMIR AFANASEV	{"email": "afanasev-v-1970@postgrespro.ru", "phone": "+70862040825"}
0005434724573	C0A0E0	8429 420054	ALEKSEY SMIRNOV	{"email": "aleksey-smirnov.04011959@postgrespro.ru", "phone": "+70143492664"}
0005434724574	FB4852	0706 528126	ANDREY MAKAROV	{"email": "a_makarov.04011965@postgrespro.ru", "phone": "+70024279211"}
0005434724575	FB4852	3655 798602	OLGA TITOVA	{"phone": "+70950139873"}
0005434724576	41F705	7903 426468	MARIYA ROMANOVA	{"phone": "+70626463003"}
0005434724577	41F705	8478 503079	ALEKSEY IVANOV	{"email": "ivanov_a-041966@postgrespro.ru", "phone": "+70752782418"}
0005434724578	26CBD1	6198 235363	SERGEY DMITRIEV	{"email": "dmitriev-sergey.01061965@postgrespro.ru", "phone": "+70065726258"}
0005434724579	E70A0D	7682 567433	NIKOLAY SOKOLOV	{"phone": "+70714245460"}
0005434724580	E70A0D	5582 557008	PAVEL NIKOLAEV	{"phone": "+70169102686"}
0005434724581	B32C8F	1745 359770	RIMMA LUKYANOVA	{"phone": "+70593490515"}
0005434724582	FE1D99	8678 803973	VALERIY SAVELEV	{"phone": "+70493024446"}
0005434724583	6461AD	2390 554708	MARIYA KALININA	{"email": "kalininam.29081964@postgrespro.ru", "phone": "+70247674785"}
0005434724584	1A3BA3	9202 179864	YAROSLAV NOVIKOV	{"phone": "+70986843492"}
0005434724585	B0E620	2608 651181	STANISLAV SAVELEV	{"email": "savelev-s_091978@postgrespro.ru", "phone": "+70531266877"}
0005434724586	B276F5	2283 725190	MARIYA MIRONOVA	{"email": "mironovam051974@postgrespro.ru", "phone": "+70018175203"}
0005434724587	4D6DAE	1373 395723	ALEKSEY NAUMOV	{"phone": "+70132754054"}
0005434724588	707078	6845 546830	ALEKSANDRA FADEEVA	{"email": "fadeeva_aleksandra1953@postgrespro.ru", "phone": "+70054117436"}
0005434724589	707078	4401 172845	VALENTINA BORISOVA	{"phone": "+70166802907"}
0005434724590	69A5B0	5042 122103	GALINA KOLESNIKOVA	{"phone": "+70904625923"}
0005434724591	5CA8D5	5022 715164	ALEKSANDRA FROLOVA	{"phone": "+70567743065"}
0005434724592	CDE8B5	6316 811844	NATALYA FILIPPOVA	{"phone": "+70992586815"}
0005434724593	FE796F	1986 225174	FEDOR NIKITIN	{"email": "fedor-nikitin.111975@postgrespro.ru", "phone": "+70048105853"}
0005434724594	EEA6A7	3381 261884	SERGEY SIDOROV	{"email": "ssidorov26051965@postgrespro.ru", "phone": "+70801238617"}
0005434724595	5BB4C7	0772 751612	SERGEY ABRAMOV	{"email": "sabramov071970@postgrespro.ru", "phone": "+70559229626"}
0005434724596	5BB4C7	1261 839103	ANATOLIY MAKAROV	{"email": "anatoliymakarov_10031973@postgrespro.ru", "phone": "+70717310460"}
0005434724597	B877B2	4617 324305	ANNA KRASNOVA	{"email": "anna-krasnova.011979@postgrespro.ru", "phone": "+70106757248"}
0005434724598	B877B2	4021 724397	NATALYA VOROBEVA	{"phone": "+70951170333"}
0005434724599	3473D4	5064 258970	NINA TIKHONOVA	{"phone": "+70588867717"}
0005434724600	9EDE05	7579 557674	GALINA KISELEVA	{"phone": "+70162879963"}
0005434724601	902C4B	0561 799760	DENIS EGOROV	{"email": "d-egorov_01121969@postgrespro.ru", "phone": "+70342683198"}
0005434724602	902C4B	4752 098553	MATVEY VASILEV	{"email": "matveyvasilev1974@postgrespro.ru", "phone": "+70734243943"}
0005434724603	6629D1	7650 122495	NADEZHDA ANTONOVA	{"phone": "+70067890103"}
0005434724604	709A3F	7701 580489	TATYANA SMIRNOVA	{"phone": "+70886773846"}
0005434724605	6B369B	2681 895637	YANA TIKHONOVA	{"phone": "+70758611049"}
0005434724962	FF6014	5528 223817	VLADISLAV KULIKOV	{"phone": "+70647053591"}
0005434724606	5658C8	5951 529653	SVETLANA OSIPOVA	{"email": "sosipova-051974@postgrespro.ru", "phone": "+70944766714"}
0005434724607	D7D4A4	0674 162069	TATYANA IVANOVA	{"email": "ivanova.t091969@postgrespro.ru", "phone": "+70751577954"}
0005434724608	D89DAC	1385 914977	MIKHAIL NIKITIN	{"email": "nikitin-m_25051968@postgrespro.ru", "phone": "+70300433760"}
0005434724609	D89DAC	7609 748984	ELENA EGOROVA	{"phone": "+70318049457"}
0005434724610	EB3CB4	7419 402619	NATALYA ORLOVA	{"email": "n_orlova-12021973@postgrespro.ru", "phone": "+70795992889"}
0005434724611	D442C5	6658 185658	RUSTAM POPOV	{"email": "popov-rustam.011985@postgrespro.ru", "phone": "+70027905483"}
0005434724612	FD9311	2922 607130	VITALIY KUZMIN	{"phone": "+70860204046"}
0005434724613	FD9311	1548 240519	RAFAIL MOISEEV	{"phone": "+70613177030"}
0005434724614	A60F30	9595 338651	SVETLANA FILIPPOVA	{"phone": "+70842197241"}
0005434724615	FF9749	6867 383203	NATALYA STEPANOVA	{"email": "stepanova_natalya_091969@postgrespro.ru", "phone": "+70096496810"}
0005434724616	FF9749	2018 435298	SERGEY KUZNECOV	{"phone": "+70279090922"}
0005434724617	786ADC	0607 727296	DMITRIY FEDOROV	{"email": "fedorov.dmitriy_1976@postgrespro.ru", "phone": "+70328295433"}
0005434724618	786ADC	2895 270029	VLADISLAV MIKHAYLOV	{"email": "vladislavmikhaylov-081976@postgrespro.ru", "phone": "+70368683169"}
0005434724619	F71356	5269 944347	OLESYA BORISOVA	{"email": "borisova.olesya.04061970@postgrespro.ru", "phone": "+70884409463"}
0005434724620	0CC8A6	9631 496416	ALEKSANDR ORLOV	{"email": "orlov.aleksandr.1977@postgrespro.ru", "phone": "+70203317283"}
0005434724621	0CC8A6	1298 447345	YULIYA ROMANOVA	{"email": "yuliyaromanova30031965@postgrespro.ru", "phone": "+70922726151"}
0005434724622	115CDE	7707 976194	ANDREY DENISOV	{"email": "denisova.1962@postgrespro.ru", "phone": "+70017898392"}
0005434724623	115CDE	3071 372792	VALERIY TIMOFEEV	{"email": "valeriytimofeev-1983@postgrespro.ru", "phone": "+70242899387"}
0005434724624	A55674	7592 637857	OKSANA IVANOVA	{"email": "oksana-ivanova_1967@postgrespro.ru", "phone": "+70862497687"}
0005434724625	893A7E	0408 704654	SERGEY SIDOROV	{"email": "sidorov.s-1977@postgrespro.ru", "phone": "+70035935841"}
0005434724626	76C85A	6142 603576	ALEKSEY SERGEEV	{"phone": "+70599502950"}
0005434724627	562253	5173 780372	SERGEY KRASNOV	{"phone": "+70114274598"}
0005434724628	0FB440	3682 267190	VLADIMIR ZAYCEV	{"phone": "+70170343492"}
0005434724629	362C62	4193 020918	VALENTINA NIKOLAEVA	{"email": "vnikolaeva-23121968@postgrespro.ru", "phone": "+70183604558"}
0005434724630	DEC372	4862 954988	DMITRIY ANTONOV	{"phone": "+70434744354"}
0005434724631	551BFD	3066 439456	NATALYA MELNIKOVA	{"email": "melnikova-n1964@postgrespro.ru", "phone": "+70620474823"}
0005434724632	551BFD	4881 060078	NATALYA MAKAROVA	{"phone": "+70644378894"}
0005434724633	00C4FE	3531 504162	ALEKSANDR ALEKSEEV	{"email": "alekseev-a-081972@postgrespro.ru", "phone": "+70943641137"}
0005434724634	00C4FE	6736 638704	SVETLANA PAVLOVA	{"phone": "+70749683679"}
0005434724635	DBC39A	3231 784391	ALEKSANDR BARANOV	{"email": "baranov.a_1974@postgrespro.ru", "phone": "+70228146991"}
0005434724636	7F7956	5084 662648	SVETLANA DENISOVA	{"email": "denisova.svetlana_24121975@postgrespro.ru", "phone": "+70984385327"}
0005434724637	0D2808	6940 770826	MAKSIM CHERNOV	{"email": "chernov-m.1978@postgrespro.ru", "phone": "+70534940539"}
0005434724638	789A9A	3402 541740	LYUDMILA NIKITINA	{"email": "l.nikitina.16081970@postgrespro.ru", "phone": "+70460718877"}
0005434724639	58A96F	2951 829126	SERGEY EGOROV	{"phone": "+70133747334"}
0005434724640	F8FC7F	7850 758034	YULIYA GAVRILOVA	{"email": "yuliyagavrilova-071965@postgrespro.ru", "phone": "+70680625947"}
0005434724641	F8FC7F	9035 192014	SERGEY SEMENOV	{"phone": "+70816414305"}
0005434724642	31F695	5916 077348	SERGEY MAKSIMOV	{"email": "sergeymaksimov.1984@postgrespro.ru", "phone": "+70955681547"}
0005434724643	FA6E68	2304 809071	VIKTORIYA KAZAKOVA	{"email": "v_kazakova-051978@postgrespro.ru", "phone": "+70169772851"}
0005434724644	781783	5610 396523	TIMUR STEPANOV	{"phone": "+70630065520"}
0005434724645	2F0F9C	5877 240253	YULIYA KONOVALOVA	{"email": "yuliyakonovalova-30091978@postgrespro.ru", "phone": "+70827040383"}
0005434724646	66A917	5979 359223	RENAT ALEKSEEV	{"email": "r.alekseev_121962@postgrespro.ru", "phone": "+70715830945"}
0005434724647	66A917	1485 427466	ELENA MAKSIMOVA	{"email": "elena.maksimova-041973@postgrespro.ru", "phone": "+70837527179"}
0005434724648	66A917	0797 954010	VENERA KUZMINA	{"phone": "+70736403470"}
0005434724649	9F5B5A	5325 906423	TATYANA MIKHAYLOVA	{"email": "tatyana-mikhaylova_1981@postgrespro.ru", "phone": "+70477757238"}
0005434724650	A4EC85	2737 517917	DMITRIY ALEKSEEV	{"email": "alekseev_d_051968@postgrespro.ru", "phone": "+70873199902"}
0005434724651	2B14A1	6905 490427	GENNADIY POPOV	{"phone": "+70956965167"}
0005434724652	B2B167	6780 674420	ALEKSEY MAKSIMOV	{"email": "maksimov.aleksey_1974@postgrespro.ru", "phone": "+70832809140"}
0005434724653	086C71	4018 041042	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin.081978@postgrespro.ru", "phone": "+70465781984"}
0005434724654	086C71	4390 507532	DMITRIY KOROLEV	{"email": "d.korolev_011967@postgrespro.ru", "phone": "+70824363537"}
0005434724655	FB099C	6979 836713	ANDREY BONDARENKO	{"phone": "+70430324677"}
0005434724656	B7C868	6271 094373	TATYANA GRISHINA	{"email": "grishina-tatyana.1976@postgrespro.ru", "phone": "+70560811691"}
0005434724657	FBC062	1831 286955	ELENA ARKHIPOVA	{"email": "elena_arkhipova-1965@postgrespro.ru", "phone": "+70366208381"}
0005434724658	74FFD3	5616 499683	MAKSIM CHERNOV	{"phone": "+70879264286"}
0005434724659	74FFD3	4680 116211	VALERIY ROMANOV	{"phone": "+70055289344"}
0005434724660	CE65D1	7859 097625	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov_1969@postgrespro.ru", "phone": "+70604583613"}
0005434724661	C2B939	4184 314050	OLGA LOGINOVA	{"email": "ologinova111970@postgrespro.ru", "phone": "+70733366540"}
0005434724723	517846	9796 272215	LYUDMILA MAKAROVA	{"phone": "+70492111790"}
0005434725023	46274E	7185 068604	GALINA SOLOVEVA	{"phone": "+70784055138"}
0005434724662	C2B939	3746 425856	ANASTASIYA POPOVA	{"email": "a_popova02051965@postgrespro.ru", "phone": "+70630105312"}
0005434724663	EEEC7F	2944 212001	NIKITA KUZNECOV	{"phone": "+70799396732"}
0005434724664	EEEC7F	0143 053110	EVGENIYA IVANOVA	{"email": "ivanova.evgeniya_091970@postgrespro.ru", "phone": "+70909948000"}
0005434724665	3FC6DF	5686 099742	NIKITA DENISOV	{"email": "denisov.n-1961@postgrespro.ru", "phone": "+70340330764"}
0005434724666	05DD8C	6893 276952	NINA ROMANOVA	{"phone": "+70263748176"}
0005434724667	05DD8C	3634 935170	EKATERINA YAKOVLEVA	{"phone": "+70230252133"}
0005434724668	0420D2	2768 682342	YULIYA VOROBEVA	{"phone": "+70508967651"}
0005434724669	6A6162	9570 606485	IRINA ZAYCEVA	{"email": "zayceva.i111963@postgrespro.ru", "phone": "+70919093357"}
0005434724670	6A6162	9648 725364	ALEKSANDRA NIKITINA	{"phone": "+70450722944"}
0005434724671	4EA0FE	0261 279610	GALINA PETROVA	{"phone": "+70050072819"}
0005434724672	B58A6B	5012 143637	ANDREY EGOROV	{"phone": "+70749504206"}
0005434724673	B58A6B	3935 848082	ELENA AFANASEVA	{"phone": "+70883911937"}
0005434724674	618DC6	5122 482982	DENIS GRIGOREV	{"phone": "+70822838371"}
0005434724675	618DC6	9396 864437	ANNA KOZLOVA	{"phone": "+70400134689"}
0005434724676	2FAA8B	5413 994471	ALBERT MOROZOV	{"email": "a_morozov.25111971@postgrespro.ru", "phone": "+70791561303"}
0005434724677	2FAA8B	6830 970448	TATYANA BOGDANOVA	{"email": "tatyanabogdanova_031978@postgrespro.ru", "phone": "+70173934858"}
0005434724678	08FC1D	2576 458671	SVETLANA ANISIMOVA	{"phone": "+70914805945"}
0005434724679	08FC1D	5870 064269	ANNA FILATOVA	{"phone": "+70935632726"}
0005434724680	C1F972	1192 360122	MIKHAIL KISELEV	{"phone": "+70691373660"}
0005434724681	70BC50	2559 972227	VITALIY KOZLOV	{"email": "kozlov-vitaliy29051976@postgrespro.ru", "phone": "+70711492116"}
0005434724682	70BC50	2613 206654	VIKTOR FEDOTOV	{"email": "fedotov-v-04071984@postgrespro.ru", "phone": "+70312535828"}
0005434724683	A6310D	9906 384990	TATYANA ZAKHAROVA	{"phone": "+70127103109"}
0005434724740	57B474	2721 566477	ELENA KAZAKOVA	{"phone": "+70494083154"}
0005434724684	E8576A	0966 481098	YULIYA KUDRYASHOVA	{"email": "kudryashova.yuliya_1973@postgrespro.ru", "phone": "+70662906756"}
0005434724685	E8576A	0504 517222	ANDREY DENISOV	{"email": "denisov-andrey.1980@postgrespro.ru", "phone": "+70169490771"}
0005434724686	E774B9	8995 940027	PAVEL ANTONOV	{"email": "antonov_p_16111971@postgrespro.ru", "phone": "+70153820808"}
0005434724687	BCA1C8	2798 174652	ELIZAVETA ANDREEVA	{"email": "andreeva-elizaveta-061971@postgrespro.ru", "phone": "+70222246998"}
0005434724688	BCA1C8	1556 628958	NADEZHDA ISAEVA	{"phone": "+70934165997"}
0005434724689	971B0F	4044 196558	NIKOLAY GORBUNOV	{"phone": "+70278162200"}
0005434724690	FCFC2A	6485 071577	SERGEY KONOVALOV	{"phone": "+70732264150"}
0005434724691	8007A6	8708 707221	SVETLANA SOLOVEVA	{"phone": "+70578499588"}
0005434724692	C766D4	5767 494570	LEONID SEMENOV	{"email": "semenovleonid16101973@postgrespro.ru", "phone": "+70093599425"}
0005434724693	C766D4	1506 890513	GALINA ZAKHAROVA	{"email": "galina.zakharova-091981@postgrespro.ru", "phone": "+70730382592"}
0005434724694	8912A8	8115 630239	LILIYA ILINA	{"email": "liliyailina-031981@postgrespro.ru", "phone": "+70052136985"}
0005434724695	8912A8	7031 651103	ANATOLIY BORISOV	{"phone": "+70501267874"}
0005434724696	E95289	6690 950793	ELLA MATVEEVA	{"phone": "+70653397006"}
0005434724697	FFE5A9	4875 991612	ALEKSANDR FROLOV	{"phone": "+70383003105"}
0005434724698	73627C	9021 794336	PRASKOVYA VOLKOVA	{"phone": "+70095365741"}
0005434724699	4FDBDE	0121 051348	ANNA ARKHIPOVA	{"email": "arkhipova.a.1977@postgrespro.ru", "phone": "+70582072530"}
0005434724700	8EBE5F	4566 088081	YURIY MIRONOV	{"phone": "+70552600797"}
0005434724701	2E4F97	0452 546365	EKATERINA TARASOVA	{"email": "tarasova_e.041966@postgrespro.ru", "phone": "+70487293762"}
0005434724702	2E4F97	3403 879447	VIKTORIYA KULIKOVA	{"email": "viktoriya_kulikova.1977@postgrespro.ru", "phone": "+70363159934"}
0005434724703	022BA6	6238 347077	VYACHESLAV PETROV	{"email": "vyacheslav.petrov-23081970@postgrespro.ru", "phone": "+70307897135"}
0005434724704	022BA6	9338 762052	SVETLANA NOVIKOVA	{"email": "s_novikova081972@postgrespro.ru", "phone": "+70420591215"}
0005434724705	022BA6	1128 562054	SVETLANA AFANASEVA	{"phone": "+70939851940"}
0005434724706	F108B7	2204 132433	OLEG PAVLOV	{"email": "pavlov-o_121971@postgrespro.ru", "phone": "+70118128145"}
0005434724707	0E52CE	3206 458199	SERGEY KRASNOV	{"phone": "+70417636407"}
0005434724708	DF3334	4617 696304	VALENTINA KUZNECOVA	{"email": "valentinakuznecova041974@postgrespro.ru", "phone": "+70762054434"}
0005434724709	DE51AE	6128 594936	NADEZHDA ZOTOVA	{"phone": "+70819421048"}
0005434724710	3B512E	6359 822467	EVA MAKAROVA	{"phone": "+70864600130"}
0005434724711	5C8BBF	0548 669496	ANATOLIY SERGEEV	{"phone": "+70727520141"}
0005434724712	05029F	5699 817414	EKATERINA IVANOVA	{"phone": "+70001075737"}
0005434724713	05029F	8860 773739	ANZHELIKA GORBUNOVA	{"email": "gorbunova.anzhelika_1973@postgrespro.ru", "phone": "+70139109069"}
0005434724714	3ECDE2	5939 437208	DMITRIY YAKOVLEV	{"email": "yakovlev-dmitriy_101975@postgrespro.ru", "phone": "+70370205288"}
0005434724715	E7E733	6761 965232	ALEKSANDR SEMENOV	{"phone": "+70070415187"}
0005434724716	3F5E50	8673 193434	NADEZHDA ZOTOVA	{"email": "n.zotova.011978@postgrespro.ru", "phone": "+70430041349"}
0005434724717	58D3F8	3174 355109	NATALYA SOKOLOVA	{"phone": "+70704400649"}
0005434724718	03D13F	4752 631047	VALENTINA KULIKOVA	{"phone": "+70201684258"}
0005434724719	66DEC4	8329 892178	MIKHAIL KONOVALOV	{"phone": "+70237468813"}
0005434724720	E42F46	2986 014467	VERA PAVLOVA	{"phone": "+70699918324"}
0005434724721	E42F46	0244 655985	RENAT VASILEV	{"phone": "+70182284085"}
0005434724722	B799A3	4350 019765	GENNADIY KUZMIN	{"email": "kuzmin.gennadiy-051970@postgrespro.ru", "phone": "+70184554852"}
0005434724724	517846	3472 253268	OLGA ZOTOVA	{"email": "zotova_o-061970@postgrespro.ru", "phone": "+70324801686"}
0005434724725	C4BB35	7535 464902	YURIY FOMIN	{"phone": "+70586185915"}
0005434724726	FAD6A4	9979 620494	OLGA STEPANOVA	{"phone": "+70149436392"}
0005434724727	FAD6A4	9790 340246	SVETLANA OSIPOVA	{"phone": "+70791512071"}
0005434724728	FAD6A4	1019 676214	FEDOR FROLOV	{"phone": "+70568321464"}
0005434724729	36C20A	8364 669725	OLGA MAKAROVA	{"email": "olga_makarova-10051973@postgrespro.ru", "phone": "+70679670365"}
0005434724730	558C12	6453 185014	MAKSIM MIKHAYLOV	{"email": "mikhaylov-maksim1965@postgrespro.ru", "phone": "+70232566123"}
0005434724731	558C12	7246 215037	TATYANA SMIRNOVA	{"phone": "+70376366454"}
0005434724732	E8C8A8	0465 603101	ANTONINA KOZLOVA	{"email": "kozlova.antonina_1973@postgrespro.ru", "phone": "+70836040512"}
0005434724733	E8C8A8	8804 690451	ALEKSEY KUZNECOV	{"phone": "+70206902846"}
0005434724734	A30E45	6264 825501	LYUBOV MEDVEDEVA	{"email": "lyubov-medvedeva-111977@postgrespro.ru", "phone": "+70596748873"}
0005434724735	3F9FFF	9542 910148	SVETLANA GUSEVA	{"email": "guseva-svetlana19081966@postgrespro.ru", "phone": "+70132483420"}
0005434724736	EEBFCA	0353 354986	ANTON KISELEV	{"email": "a-kiselev04051965@postgrespro.ru", "phone": "+70457848812"}
0005434724737	EEBFCA	1205 232487	ELIZAVETA MOISEEVA	{"email": "moiseeva.elizaveta-1970@postgrespro.ru", "phone": "+70251263485"}
0005434724738	EEBFCA	7419 742922	OLGA ARKHIPOVA	{"email": "arkhipova.o-1969@postgrespro.ru", "phone": "+70776908470"}
0005434724739	57B474	6679 426454	ANNA PAVLOVA	{"phone": "+70384084831"}
0005434724741	E49D90	9035 967643	FEDOR BARANOV	{"phone": "+70946043861"}
0005434724742	F2BC05	1662 646020	INNA SMIRNOVA	{"email": "smirnova-inna_1973@postgrespro.ru", "phone": "+70974706085"}
0005434724743	206677	6457 066582	ALEKSANDR KRASNOV	{"phone": "+70132622305"}
0005434724744	206677	2276 372093	DMITRIY IVANOV	{"phone": "+70245668202"}
0005434724745	28AD0E	1893 024220	ROBERT KUZNECOV	{"email": "kuznecov.robert.1965@postgrespro.ru", "phone": "+70542572850"}
0005434724746	F87A06	3542 581473	OLEG KUDRYASHOV	{"email": "kudryashovo_081968@postgrespro.ru", "phone": "+70453146712"}
0005434724747	9D7EFB	8718 698530	EVGENIY ZAKHAROV	{"phone": "+70607599805"}
0005434724748	9D7EFB	1532 296263	YANA YAKOVLEVA	{"email": "yakovleva-y-03071972@postgrespro.ru", "phone": "+70482011704"}
0005434724749	B17F01	6809 563140	ALEKSEY SEMENOV	{"phone": "+70793203041"}
0005434724750	B17F01	0004 493007	VALERIY MAKAROV	{"email": "makarov-v.101953@postgrespro.ru", "phone": "+70243631995"}
0005434724751	93F15D	2059 308147	REGINA SAVELEVA	{"email": "saveleva.regina28011966@postgrespro.ru", "phone": "+70373508914"}
0005434724752	D97010	5860 368732	ALEKSEY ORLOV	{"phone": "+70906960155"}
0005434724753	5A4BE5	2663 069302	SERGEY GRIGOREV	{"phone": "+70728779584"}
0005434724754	450C43	8867 327102	ALEKSEY VOROBEV	{"phone": "+70660817381"}
0005434724755	7802B5	5505 847607	MARIYA PAVLOVA	{"phone": "+70264941785"}
0005434724756	AF2B06	1376 388759	NIKOLAY KONOVALOV	{"phone": "+70123867304"}
0005434724757	E91D6C	7770 858451	ALEKSANDR KUZMIN	{"email": "kuzmin-a-021960@postgrespro.ru", "phone": "+70976027043"}
0005434724758	4E4C82	8668 310567	NATALYA MOROZOVA	{"email": "morozova-natalya_091966@postgrespro.ru", "phone": "+70920506853"}
0005434724759	167197	8325 231796	VALERIYA MOROZOVA	{"email": "morozova.v_21031973@postgrespro.ru", "phone": "+70320492301"}
0005434724760	167197	0724 034306	VYACHESLAV SEMENOV	{"email": "semenov.vyacheslav_22011970@postgrespro.ru", "phone": "+70841700962"}
0005434724761	72865A	3662 432006	YULIYA KUDRYASHOVA	{"email": "y.kudryashova31121969@postgrespro.ru", "phone": "+70292110159"}
0005434724762	7D0545	8317 761283	VLADIMIR BORISOV	{"email": "borisovv-1976@postgrespro.ru", "phone": "+70685843878"}
0005434724763	6C6F58	1787 244391	DMITRIY IVANOV	{"phone": "+70878911498"}
0005434724764	AAF9D1	4925 852770	IVAN VLASOV	{"email": "vlasov.ivan1974@postgrespro.ru", "phone": "+70923711109"}
0005434724765	EE7FAD	4895 745314	OLGA MAKAROVA	{"email": "makarova-o.11011967@postgrespro.ru", "phone": "+70775839593"}
0005434724766	4EC237	3190 322038	VLADISLAV MELNIKOV	{"phone": "+70216674539"}
0005434724767	3AA918	8682 239351	ANTON ILIN	{"phone": "+70050668407"}
0005434724768	B7A999	6863 659664	DARYA ANDREEVA	{"email": "dandreeva-08111969@postgrespro.ru", "phone": "+70956308818"}
0005434724769	B7A999	4916 172078	NIKOLAY CHERNOV	{"phone": "+70365212479"}
0005434724770	A66BE8	4794 150077	ALEKSEY BELOV	{"phone": "+70654489965"}
0005434724771	B646EB	4634 540080	ELENA ANDREEVA	{"email": "andreeva-elena_1972@postgrespro.ru", "phone": "+70660276777"}
0005434724772	0572CB	0473 583209	VIKTOR MIKHAYLOV	{"email": "mikhaylovviktor.031966@postgrespro.ru", "phone": "+70101589186"}
0005434724773	0572CB	1630 871869	DMITRIY GUSEV	{"email": "gusev_d_1976@postgrespro.ru", "phone": "+70749775257"}
0005434724774	C16EF2	1759 115598	ZINAIDA TITOVA	{"email": "ztitova-29081979@postgrespro.ru", "phone": "+70062687668"}
0005434724775	C16EF2	6886 124528	NIKITA MOROZOV	{"email": "n_morozov1980@postgrespro.ru", "phone": "+70969596842"}
0005434724776	F02592	6105 308324	MARINA FOMINA	{"email": "fomina_marina-101979@postgrespro.ru", "phone": "+70133997830"}
0005434724777	4551E5	7391 162669	ALEKSANDR KOZLOV	{"email": "kozlov-a_09061966@postgrespro.ru", "phone": "+70479576575"}
0005434724778	4551E5	4652 493051	DMITRIY SCHERBAKOV	{"email": "d-scherbakov_22011970@postgrespro.ru", "phone": "+70887582686"}
0005434724779	415CDF	7536 660312	DMITRIY FOMIN	{"phone": "+70947103611"}
0005434724780	BCE106	4471 516853	LYUBOV MELNIKOVA	{"email": "melnikovalyubov041973@postgrespro.ru", "phone": "+70754255572"}
0005434724781	73E3F0	2027 281807	VYACHESLAV ROMANOV	{"email": "vyacheslav-romanov-14101974@postgrespro.ru", "phone": "+70090937126"}
0005434724782	9C93B7	2095 575880	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr-28101974@postgrespro.ru", "phone": "+70685270362"}
0005434724784	4399A8	7682 871708	ARTEM ILIN	{"email": "ilin.artem.1973@postgrespro.ru", "phone": "+70136639275"}
0005434724785	4C166E	0160 237152	YAROSLAV ORLOV	{"email": "orlov-yaroslav.1974@postgrespro.ru", "phone": "+70913390781"}
0005434724786	4C166E	6403 866911	SEMEN IVANOV	{"phone": "+70091934531"}
0005434724787	413506	5559 142088	VALENTINA MIRONOVA	{"phone": "+70044389171"}
0005434724788	BEE413	4648 910053	DMITRIY MAKSIMOV	{"phone": "+70437090536"}
0005434724789	BEE413	8683 451231	NIKOLAY GAVRILOV	{"email": "nikolay-gavrilov.07101976@postgrespro.ru", "phone": "+70066262356"}
0005434724790	8EF100	4316 696781	ALEKSANDRA IVANOVA	{"phone": "+70985539008"}
0005434724791	4951E5	4684 058621	ANATOLIY PAVLOV	{"email": "pavlov_anatoliy_03121969@postgrespro.ru", "phone": "+70802243949"}
0005434724792	4951E5	3291 998045	VLADISLAV KARPOV	{"phone": "+70995669074"}
0005434724793	D87C1F	8005 500386	ELENA VOLKOVA	{"phone": "+70871247425"}
0005434724794	DDF7C4	2931 790233	DANILA MIRONOV	{"phone": "+70041790280"}
0005434724795	5B0142	2174 556760	NADEZHDA SERGEEVA	{"phone": "+70224231729"}
0005434724796	E1E9A9	4663 422727	RAFIK TIKHONOV	{"phone": "+70629030398"}
0005434724797	B89766	2032 056421	VYACHESLAV MIRONOV	{"email": "vyacheslavmironov-22071981@postgrespro.ru", "phone": "+70584908432"}
0005434724798	32ED96	9453 623236	SERGEY ILIN	{"phone": "+70722143478"}
0005434724799	32ED96	8148 215535	ANATOLIY ANDREEV	{"email": "anatoliyandreev1974@postgrespro.ru", "phone": "+70425296359"}
0005434724800	32ED96	1527 862717	SERGEY KARPOV	{"email": "karpov.sergey_111976@postgrespro.ru", "phone": "+70531833691"}
0005434724801	32ED96	3612 944033	PAVEL SHEVCHENKO	{"phone": "+70111059554"}
0005434724802	72F5F7	0846 763250	RISHAT VOROBEV	{"phone": "+70695774108"}
0005434724803	C3EE0B	9736 677872	ANNA KOLESNIKOVA	{"email": "akolesnikova_101963@postgrespro.ru", "phone": "+70158845581"}
0005434724804	627682	3376 292919	ALEKSANDR ILIN	{"phone": "+70055991171"}
0005434724805	F12EEB	2597 526677	TATYANA MOROZOVA	{"email": "t_morozova.061969@postgrespro.ru", "phone": "+70362266930"}
0005434724806	DC9DC5	9564 355973	SAVELIY KAZAKOV	{"phone": "+70010716772"}
0005434724807	DC9DC5	1975 854672	IGOR GAVRILOV	{"email": "gavrilov.igor_07031976@postgrespro.ru", "phone": "+70477441281"}
0005434724808	F14A14	9739 801928	LARISA KUZNECOVA	{"email": "kuznecova.l-1978@postgrespro.ru", "phone": "+70449265851"}
0005434724809	689034	1537 269291	ALEKSANDR MAKSIMOV	{"phone": "+70381881886"}
0005434724810	689034	7125 088892	ALEKSANDR ABRAMOV	{"phone": "+70169218553"}
0005434724811	91F8DD	9066 503893	VASILIY FILIPPOV	{"phone": "+70352828495"}
0005434724812	FAC816	7908 667416	RENAT SIDOROV	{"email": "r.sidorov10011978@postgrespro.ru", "phone": "+70781815056"}
0005434724813	710672	2748 576507	SVETLANA TROFIMOVA	{"email": "trofimova.svetlana_061974@postgrespro.ru", "phone": "+70246244929"}
0005434724814	710672	2021 666694	KRISTINA BELOVA	{"phone": "+70429329999"}
0005434724815	104901	5435 519984	EKATERINA ARKHIPOVA	{"phone": "+70042701532"}
0005434724816	104901	2157 920777	TATYANA MEDVEDEVA	{"email": "medvedeva.tatyana.011970@postgrespro.ru", "phone": "+70714162451"}
0005434724817	D7CE88	4530 813266	NATALYA PETROVA	{"email": "petrova.natalya-29061971@postgrespro.ru", "phone": "+70290609244"}
0005434724818	D23E66	9591 715145	LIDIYA BORISOVA	{"email": "borisova_l1968@postgrespro.ru", "phone": "+70623387486"}
0005434724819	6E9EE5	5845 901000	IVAN FROLOV	{"phone": "+70226232907"}
0005434724820	FC4C5D	9478 108441	ALEKSANDRA ALEKSEEVA	{"phone": "+70148996855"}
0005434724821	EB2003	9599 708662	LYUBOV EFIMOVA	{"email": "efimova.lyubov_30111964@postgrespro.ru", "phone": "+70656326616"}
0005434724822	EB2003	7897 982014	ILYA SOKOLOV	{"phone": "+70530108100"}
0005434724823	AD8879	5121 251789	LYUBOV SOLOVEVA	{"email": "l_soloveva111972@postgrespro.ru", "phone": "+70796267620"}
0005434724824	6C829E	1450 081230	VALENTINA SIDOROVA	{"email": "sidorova_valentina061976@postgrespro.ru", "phone": "+70373573717"}
0005434724825	7F1E97	8023 481877	AYRAT MATVEEV	{"email": "amatveev1963@postgrespro.ru", "phone": "+70968248464"}
0005434724826	4AE06B	1391 959243	VERA ANTONOVA	{"phone": "+70348466439"}
0005434724827	1A90BE	2576 097488	ANASTASIYA VLASOVA	{"phone": "+70275734889"}
0005434724828	58D5BA	7603 768631	NATALYA GRISHINA	{"email": "n.grishina.081963@postgrespro.ru", "phone": "+70574308568"}
0005434724829	58D5BA	7701 508204	VITALIY KISELEV	{"phone": "+70267951281"}
0005434724830	55EB3F	8657 211316	KONSTANTIN SCHERBAKOV	{"email": "k_scherbakov-011976@postgrespro.ru", "phone": "+70053090766"}
0005434724831	0A8783	4313 996435	VALERIY GERASIMOV	{"email": "valeriygerasimov1971@postgrespro.ru", "phone": "+70782349205"}
0005434724832	0A8783	6374 061352	IRINA ABRAMOVA	{"phone": "+70197163885"}
0005434724833	BDA063	0069 051319	ROMAN PETROV	{"email": "petrovr_02111973@postgrespro.ru", "phone": "+70525488707"}
0005434724834	B2E6A8	1123 804026	NADEZHDA ILINA	{"email": "ilinan.05041975@postgrespro.ru", "phone": "+70475636426"}
0005434724835	30CDF8	2272 623769	ALEVTINA NESTEROVA	{"email": "a-nesterova27101970@postgrespro.ru", "phone": "+70690739838"}
0005434724836	198755	4802 667137	SOFYA POPOVA	{"phone": "+70555653447"}
0005434724837	D0BF3A	9082 925739	SEMEN GAVRILOV	{"email": "semen.gavrilov_021970@postgrespro.ru", "phone": "+70772385514"}
0005434724838	5F041F	7623 581724	MARIYA ZHUKOVA	{"phone": "+70473956808"}
0005434724839	5F041F	2995 230902	NATALIYA SEMENOVA	{"phone": "+70423985551"}
0005434724840	8E920C	5569 382322	MIKHAIL KUZNECOV	{"phone": "+70005443297"}
0005434724841	92FFAA	0395 261537	OLGA MIKHAYLOVA	{"email": "mikhaylova.o1978@postgrespro.ru", "phone": "+70493110141"}
0005434724842	785273	2349 653799	ALINA KARPOVA	{"email": "karpova.a_15021970@postgrespro.ru", "phone": "+70956842675"}
0005434724843	73FD94	6762 770312	NATALYA KOROLEVA	{"phone": "+70732738499"}
0005434724844	A0CC10	8663 073591	MARIYA VASILEVA	{"phone": "+70574310796"}
0005434724845	622190	3406 080834	MARINA NIKITINA	{"email": "marina-nikitina.10021963@postgrespro.ru", "phone": "+70394968743"}
0005434724846	622190	2627 685146	VLADIMIR IVANOV	{"email": "v.ivanov-011962@postgrespro.ru", "phone": "+70203631712"}
0005434724847	7AD77F	6765 140335	ALFIYA SOROKINA	{"email": "a.sorokina-1978@postgrespro.ru", "phone": "+70913891677"}
0005434724848	7AD77F	2703 129531	ANATOLIY MIKHAYLOV	{"email": "a-mikhaylov29041981@postgrespro.ru", "phone": "+70166626017"}
0005434724849	79B874	6673 953941	VYACHESLAV GUSEV	{"phone": "+70272265605"}
0005434724850	79B874	3338 075573	IRINA KUZNECOVA	{"phone": "+70271033385"}
0005434724851	821A60	8952 757763	EVGENIYA KONOVALOVA	{"email": "evgeniyakonovalova.25111979@postgrespro.ru", "phone": "+70967204948"}
0005434724852	748DEF	5420 808804	VALENTINA VLASOVA	{"phone": "+70541967936"}
0005434724853	748DEF	3986 640180	SERGEY MEDVEDEV	{"email": "sergey.medvedev.091978@postgrespro.ru", "phone": "+70477529859"}
0005434724854	3FF281	9182 713447	TATYANA GRISHINA	{"phone": "+70421437876"}
0005434724855	3FF281	5892 736002	ALEKSANDR NIKOLAEV	{"phone": "+70589539993"}
0005434724856	E51AC2	5737 030422	TAMARA PETROVA	{"phone": "+70679477759"}
0005434724857	E51AC2	1421 335972	SVETLANA IVANOVA	{"email": "ivanova_svetlana061973@postgrespro.ru", "phone": "+70411366798"}
0005434724858	E51AC2	0251 268543	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey_081974@postgrespro.ru", "phone": "+70695553445"}
0005434724859	DEAE3B	6866 684438	VLADIMIR VOROBEV	{"email": "v-vorobev13101972@postgrespro.ru", "phone": "+70575976776"}
0005434724860	0AB948	2564 350311	OLGA IVANOVA	{"email": "ivanova-olga-041974@postgrespro.ru", "phone": "+70768908666"}
0005434724861	0AB948	5367 268633	TATYANA KAZAKOVA	{"phone": "+70728879905"}
0005434724862	C7DCD0	3432 809368	ANNA ZAYCEVA	{"email": "a_zayceva_21071978@postgrespro.ru", "phone": "+70915255630"}
0005434724863	C7DCD0	5697 156198	OLESYA ALEKSEEVA	{"email": "olesya_alekseeva-1978@postgrespro.ru", "phone": "+70731509203"}
0005434724864	D50687	5050 029470	NINA IVANOVA	{"email": "ivanova-nina_1965@postgrespro.ru", "phone": "+70683784117"}
0005434724865	63E363	1235 834465	DMITRIY IVANOV	{"phone": "+70263758139"}
0005434724866	E0F2E3	9311 070518	KRISTINA MIRONOVA	{"email": "mironova_k_09011981@postgrespro.ru", "phone": "+70965475066"}
0005434724867	89809E	9448 743918	ALEKSANDR KRASNOV	{"email": "akrasnov051978@postgrespro.ru", "phone": "+70775474384"}
0005434724868	4B2B5E	2700 867934	NADEZHDA LOGINOVA	{"email": "nadezhda.loginova.011974@postgrespro.ru", "phone": "+70115604205"}
0005434724869	F946DB	8144 421536	ANNA MALYSHEVA	{"phone": "+70604568451"}
0005434724870	E1678D	4352 748570	EVGENIY KUDRYASHOV	{"email": "kudryashov_evgeniy_061970@postgrespro.ru", "phone": "+70705525672"}
0005434724871	E1678D	4382 607133	ALINA LUKYANOVA	{"phone": "+70543351459"}
0005434724872	64C259	7062 711713	MARINA FEDOROVA	{"phone": "+70080051791"}
0005434724873	CD53D6	0279 876379	POLINA BOGDANOVA	{"phone": "+70219431719"}
0005434724874	CD53D6	2898 802989	ALEKSANDR KUZMIN	{"phone": "+70953356337"}
0005434724875	E6B7FB	9001 725065	POLINA MARTYNOVA	{"email": "martynova.polina_21021976@postgrespro.ru", "phone": "+70178505456"}
0005434724876	3BDAB5	4090 025987	NIKOLAY ABRAMOV	{"email": "abramovnikolay-121969@postgrespro.ru", "phone": "+70404218303"}
0005434724877	F21331	8827 980425	NIKOLAY TIMOFEEV	{"phone": "+70088397336"}
0005434724878	89B535	3040 351599	NATALIYA KOZLOVA	{"email": "nkozlova.24081966@postgrespro.ru", "phone": "+70438142630"}
0005434724879	A8EB02	3458 441351	SERGEY BELOV	{"email": "belov_sergey-06121968@postgrespro.ru", "phone": "+70543728643"}
0005434724880	AC574C	6805 894448	SERGEY MAKAROV	{"email": "sergey-makarov.051974@postgrespro.ru", "phone": "+70592739448"}
0005434724881	29483C	5228 334848	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr011977@postgrespro.ru", "phone": "+70984795262"}
0005434724882	29483C	9993 228309	VLADIMIR VOLKOV	{"phone": "+70543371522"}
0005434724883	A08BCB	7206 687332	RIFAT NAZAROV	{"email": "nazarovr_1983@postgrespro.ru", "phone": "+70151726212"}
0005434724884	9FBD8D	6367 010133	SVETLANA MAKAROVA	{"email": "makarovas.16101963@postgrespro.ru", "phone": "+70283794162"}
0005434724885	96FEF0	4991 970884	VLADIMIR POPOV	{"email": "popov.v-03041974@postgrespro.ru", "phone": "+70574271134"}
0005434724886	6C86F7	2640 864404	NADEZHDA FEDOROVA	{"email": "fedorova_n-081972@postgrespro.ru", "phone": "+70326538748"}
0005434724887	EC0D91	1386 032717	NATALYA KUDRYASHOVA	{"phone": "+70102406977"}
0005434724888	E3C0F7	5877 670363	ELENA IVANOVA	{"email": "elenaivanova.031975@postgrespro.ru", "phone": "+70503984083"}
0005434724889	CA55B8	7447 400104	ALEKSEY ZHUKOV	{"phone": "+70260614954"}
0005434724890	44E30D	0301 864258	VIKTOR RODIONOV	{"phone": "+70897712548"}
0005434724891	44E30D	1506 794985	VASILIY SMIRNOV	{"email": "vsmirnov_011980@postgrespro.ru", "phone": "+70937759696"}
0005434724892	304D13	2911 212560	NINA ISAEVA	{"phone": "+70675538629"}
0005434724893	9F80D3	4253 052475	IVAN IVANOV	{"email": "ivan-ivanov-10031967@postgrespro.ru", "phone": "+70108560270"}
0005434724894	CEF8B2	8981 857238	SERGEY AFANASEV	{"email": "sergeyafanasev.05011970@postgrespro.ru", "phone": "+70300897040"}
0005434724895	B73FBD	7131 901877	MATVEY FEDOROV	{"email": "fedorov.matvey.26111974@postgrespro.ru", "phone": "+70911929519"}
0005434724896	40426F	1288 459176	DENIS ABRAMOV	{"email": "d_abramov_021961@postgrespro.ru", "phone": "+70071536129"}
0005434724897	ABA3E8	9672 159040	ALEKSEY NAUMOV	{"phone": "+70477976760"}
0005434724898	30B355	4208 996749	SERGEY ISAEV	{"phone": "+70728678365"}
0005434724899	30B355	9724 085512	OLGA BOGDANOVA	{"phone": "+70643229828"}
0005434724900	C81947	8318 727958	VERA STEPANOVA	{"phone": "+70082719144"}
0005434724901	F697BC	1268 332438	VALENTINA SIDOROVA	{"phone": "+70206741191"}
0005434724902	F697BC	5847 309922	NATALYA VLASOVA	{"email": "natalyavlasova-25121973@postgrespro.ru", "phone": "+70103976259"}
0005434724903	76CE88	7302 464684	ALEKSANDR KUDRYASHOV	{"email": "aleksandr_kudryashov.12111960@postgrespro.ru", "phone": "+70911930457"}
0005434724904	B066FB	4113 719705	ALEKSEY NAUMOV	{"email": "naumov-a14071973@postgrespro.ru", "phone": "+70138250749"}
0005434724905	AB169E	0901 940138	ELENA NOVIKOVA	{"email": "elenanovikova_091969@postgrespro.ru", "phone": "+70546452580"}
0005434724906	AB169E	9396 586653	VLADIMIR AFANASEV	{"email": "vladimir_afanasev-1960@postgrespro.ru", "phone": "+70451644796"}
0005434724907	A50193	7921 065577	OLGA NAUMOVA	{"email": "olganaumova15081968@postgrespro.ru", "phone": "+70973786783"}
0005434724908	36BF86	0324 230828	ANNA VASILEVA	{"email": "vasileva.anna1975@postgrespro.ru", "phone": "+70299800550"}
0005434724909	36BF86	1286 269813	DARYA SMIRNOVA	{"phone": "+70472334122"}
0005434724910	71DFD0	6016 103815	NADEZHDA MIRONOVA	{"email": "mironova_n-22011979@postgrespro.ru", "phone": "+70033406434"}
0005434724911	71DFD0	1269 834922	SVETLANA LEBEDEVA	{"phone": "+70505948960"}
0005434724912	AE29A9	8919 180870	ANATOLIY NAZAROV	{"email": "nazarov-anatoliy051970@postgrespro.ru", "phone": "+70694315302"}
0005434724913	AE29A9	0534 764658	ANDREY MIRONOV	{"email": "mironovandrey.16081971@postgrespro.ru", "phone": "+70549941712"}
0005434724914	B0CB98	8856 436261	VALERIYA ANISIMOVA	{"phone": "+70863518542"}
0005434724915	B0CB98	9820 824262	ELENA IVANOVA	{"phone": "+70774410546"}
0005434724916	CEF9B8	5613 640014	NATALYA IVANOVA	{"email": "ivanovan_081984@postgrespro.ru", "phone": "+70864596495"}
0005434724917	7B5E40	6422 196156	MARIYA SOLOVEVA	{"email": "msoloveva-1981@postgrespro.ru", "phone": "+70797364713"}
0005434724918	7B5E40	3661 799099	YULIYA PETROVA	{"email": "y-petrova.1966@postgrespro.ru", "phone": "+70232381891"}
0005434724919	7B5E40	0585 340795	IGOR MAKAROV	{"phone": "+70719638982"}
0005434724920	069D6C	0574 205529	NATALYA ROMANOVA	{"email": "romanova_natalya-1964@postgrespro.ru", "phone": "+70290805659"}
0005434724921	069D6C	7219 643177	VALENTINA SERGEEVA	{"phone": "+70668008959"}
0005434724922	B651D7	1066 886809	GALINA ROMANOVA	{"phone": "+70686685305"}
0005434724923	AB6725	9630 001482	SERGEY DMITRIEV	{"phone": "+70881449445"}
0005434724924	AB6725	9753 611717	ELENA NESTEROVA	{"phone": "+70885457091"}
0005434724925	DEA00B	7516 992935	ARTEM MAKAROV	{"phone": "+70503477175"}
0005434724926	93F8D3	8806 896461	ALINA ORLOVA	{"phone": "+70444525248"}
0005434724927	5F18DB	1441 388338	VYACHESLAV MOISEEV	{"phone": "+70194938398"}
0005434724928	179913	7281 766737	RAISA MOROZOVA	{"email": "rmorozova_1976@postgrespro.ru", "phone": "+70629450084"}
0005434724929	E47EE5	1414 612943	YULIYA MALYSHEVA	{"email": "malysheva.yuliya22041970@postgrespro.ru", "phone": "+70031431326"}
0005434724930	764C42	7988 884239	ALEKSANDRA PAVLOVA	{"phone": "+70158871421"}
0005434724931	9A8C69	0748 640257	ELENA PETROVA	{"email": "elena-petrova-31051974@postgrespro.ru", "phone": "+70293959084"}
0005434724932	C52164	4670 705253	LIDIYA SEMENOVA	{"email": "semenova_lidiya.071975@postgrespro.ru", "phone": "+70282933004"}
0005434724933	C52164	0896 892441	VIKTOR KUZMIN	{"phone": "+70818021313"}
0005434724934	C52164	7993 491582	NATALYA AFANASEVA	{"email": "natalya-afanaseva-10031968@postgrespro.ru", "phone": "+70401633771"}
0005434724935	0CE9B6	3146 004870	VALENTINA YAKOVLEVA	{"phone": "+70088573598"}
0005434724936	7F080A	7597 077456	DMITRIY IVANOV	{"email": "ivanov.dmitriy_011978@postgrespro.ru", "phone": "+70757205713"}
0005434724937	1D6ECE	3005 112384	TATYANA LEBEDEVA	{"email": "lebedeva_tatyana01081978@postgrespro.ru", "phone": "+70254630805"}
0005434724938	72A88A	6729 083778	OLGA SOROKINA	{"email": "sorokina.olga.09101982@postgrespro.ru", "phone": "+70966111228"}
0005434724939	72A88A	0007 468441	ANDREY ALEKSEEV	{"email": "andrey-alekseev_12081981@postgrespro.ru", "phone": "+70168496770"}
0005434724940	A53482	3598 445183	MARINA ISAEVA	{"phone": "+70910128695"}
0005434724941	1E6579	0763 720904	KONSTANTIN CHERNOV	{"email": "k_chernov_17091970@postgrespro.ru", "phone": "+70180975040"}
0005434724942	1E6579	7088 812827	ANASTASIYA GUSEVA	{"email": "anastasiya.guseva.101971@postgrespro.ru", "phone": "+70511539510"}
0005434724943	1E6579	6409 105801	NIKOLAY ALEKSEEV	{"phone": "+70028476495"}
0005434724944	1E6579	2432 854931	GALINA POPOVA	{"phone": "+70791478242"}
0005434724945	D9123F	9045 711911	MAKSIM MATVEEV	{"email": "matveev-m_1973@postgrespro.ru", "phone": "+70203323273"}
0005434724946	D9123F	7883 152142	ALEKSANDRA SMIRNOVA	{"email": "smirnovaa_08101977@postgrespro.ru", "phone": "+70861691921"}
0005434724947	F128B6	2697 250692	LARISA KUZNECOVA	{"phone": "+70344307927"}
0005434724948	C6A22B	9101 352852	VALERIY STEPANOV	{"phone": "+70596630669"}
0005434724949	3B9CDB	8009 417037	ALEKSANDR VASILEV	{"email": "vasilevaleksandr.011961@postgrespro.ru", "phone": "+70618458182"}
0005434724950	3B9CDB	5703 448897	NATALIYA DENISOVA	{"phone": "+70500833806"}
0005434724951	503842	5392 318262	KLAVDIYA KULIKOVA	{"email": "kulikova-klavdiya-22051966@postgrespro.ru", "phone": "+70642071542"}
0005434724952	0508E9	5072 045154	ALEKSANDR POPOV	{"email": "popova.03111972@postgrespro.ru", "phone": "+70869044763"}
0005434724953	D5971D	6758 270933	MIKHAIL KAZAKOV	{"phone": "+70179798955"}
0005434724954	D5971D	4022 048065	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr-10091978@postgrespro.ru", "phone": "+70139060080"}
0005434724955	4F515F	8346 038093	LYUBOV POLYAKOVA	{"phone": "+70074057571"}
0005434724956	4F515F	6967 753204	SERGEY CHERNOV	{"email": "chernovs.021970@postgrespro.ru", "phone": "+70194819351"}
0005434724957	A74E7E	8086 332981	TATYANA VLASOVA	{"phone": "+70103112256"}
0005434724958	A74E7E	6544 752808	VALENTINA MAKSIMOVA	{"email": "v_maksimova1973@postgrespro.ru", "phone": "+70929538033"}
0005434724959	A74E7E	5800 028886	VALENTIN BORISOV	{"phone": "+70532396743"}
0005434724960	A74E7E	8679 250933	IRINA DMITRIEVA	{"phone": "+70176063411"}
0005434724961	FF6014	8779 447544	TATYANA POPOVA	{"phone": "+70141021664"}
0005434724963	51147A	3805 198964	VITALIY KOZLOV	{"email": "vitaliy-kozlov18121976@postgrespro.ru", "phone": "+70334054685"}
0005434724964	62B7A0	8632 495244	NIKOLAY BORISOV	{"phone": "+70512209484"}
0005434724965	26C890	4574 698672	VALENTINA KOROLEVA	{"phone": "+70834675426"}
0005434724966	26C890	7367 597893	GALINA KARPOVA	{"phone": "+70763605575"}
0005434724967	4C9FA3	2249 168728	VLADIMIR KUDRYASHOV	{"phone": "+70302939232"}
0005434724968	3A60F9	5421 748457	ALEKSEY KARPOV	{"email": "aleksey_karpov_1966@postgrespro.ru", "phone": "+70295487980"}
0005434724969	4DD452	0759 027696	ARTEM VOLKOV	{"phone": "+70384511105"}
0005434724970	1CEB8E	8470 244903	VYACHESLAV SOROKIN	{"email": "sorokin-vyacheslav-1973@postgrespro.ru", "phone": "+70319228986"}
0005434724971	14389D	1762 809625	SVETLANA MASLOVA	{"phone": "+70852182781"}
0005434724972	5236C1	5539 673144	ALEKSANDR AFANASEV	{"email": "afanasev.a1970@postgrespro.ru", "phone": "+70140460414"}
0005434724973	33F192	9966 319453	BORIS GORBUNOV	{"phone": "+70055364007"}
0005434724974	AE5017	0893 399688	ALEKSANDR ZHURAVLEV	{"email": "zhuravleva1974@postgrespro.ru", "phone": "+70178399414"}
0005434724975	BA4D88	7090 310712	VLADIMIR BORISOV	{"phone": "+70770253873"}
0005434724976	303A6D	3694 794832	LIDIYA MARTYNOVA	{"email": "martynova-l.091972@postgrespro.ru", "phone": "+70954353184"}
0005434724977	303A6D	3813 624880	ELENA MIKHAYLOVA	{"phone": "+70975800388"}
0005434724978	91D695	5670 251580	IVAN MIRONOV	{"phone": "+70225077466"}
0005434724979	91D695	7816 439827	KLAVDIYA TROFIMOVA	{"email": "klavdiya-trofimova061975@postgrespro.ru", "phone": "+70778960670"}
0005434724980	F22BC4	2378 092424	YULIYA PETROVA	{"phone": "+70427834240"}
0005434724981	79F55B	7751 794886	ANTON SERGEEV	{"email": "sergeeva_1972@postgrespro.ru", "phone": "+70539247005"}
0005434724982	79F55B	2894 270001	ALLA PETROVA	{"email": "alla.petrova.30101972@postgrespro.ru", "phone": "+70361667377"}
0005434724983	1044C4	3397 251533	LYUDMILA DENISOVA	{"email": "denisova_lyudmila_08011965@postgrespro.ru", "phone": "+70193475736"}
0005434724984	55AFAE	1840 384236	ANDREY POPOV	{"phone": "+70798854707"}
0005434724985	9012D7	6468 793489	NATALYA OVCHINNIKOVA	{"phone": "+70240750596"}
0005434724986	3B9275	2616 506266	VALENTINA SEMENOVA	{"phone": "+70974914870"}
0005434724987	3B9275	3040 614518	ALEKSEY POPOV	{"email": "aleksey.popov-081980@postgrespro.ru", "phone": "+70659077384"}
0005434724988	3B9275	2088 081060	VLADIMIR ORLOV	{"phone": "+70032759679"}
0005434724989	10E405	8045 613389	NIKOLAY ALEKSANDROV	{"email": "aleksandrov-nikolay_07041968@postgrespro.ru", "phone": "+70694385308"}
0005434724990	8CE6ED	9354 927897	NIKOLAY FOMIN	{"phone": "+70835740081"}
0005434724991	4BBD26	4174 310031	GENNADIY SHEVCHENKO	{"phone": "+70747062762"}
0005434724992	4BBD26	5344 616527	VYACHESLAV FEDOROV	{"phone": "+70900151739"}
0005434724993	5C3E5F	4316 159840	LYUDMILA PAVLOVA	{"phone": "+70224056040"}
0005434724994	5C3E5F	2906 034031	VALENTINA ZAYCEVA	{"email": "valentinazayceva-07041979@postgrespro.ru", "phone": "+70614735857"}
0005434724995	54497D	1850 215967	ALEKSANDR KUDRYASHOV	{"phone": "+70177653438"}
0005434724996	54497D	9714 542830	YURIY NIKITIN	{"phone": "+70075133013"}
0005434724997	D0304B	7257 285215	SERGEY SAVELEV	{"email": "savelev_sergey-061973@postgrespro.ru", "phone": "+70495111590"}
0005434724998	D0304B	2452 466009	LYUDMILA SEMENOVA	{"email": "semenova-l.1978@postgrespro.ru", "phone": "+70726023298"}
0005434724999	4BAA21	3282 718908	NADEZHDA LOGINOVA	{"email": "loginova_nadezhda1986@postgrespro.ru", "phone": "+70731599765"}
0005434725000	4BAA21	2954 434104	VITALIY MOROZOV	{"email": "vitaliy-morozov-28041973@postgrespro.ru", "phone": "+70617708542"}
0005434725001	3BCCC6	7453 060975	EVGENIY MOROZOV	{"email": "morozov-e.081981@postgrespro.ru", "phone": "+70032621011"}
0005434725002	3BCCC6	4600 488056	DMITRIY MIRONOV	{"phone": "+70814181672"}
0005434725003	5AE879	3048 243346	IRINA RODIONOVA	{"email": "i-rodionova.071969@postgrespro.ru", "phone": "+70670827333"}
0005434725004	8E2E8C	0225 893220	NADEZHDA TIKHONOVA	{"phone": "+70521147688"}
0005434725005	0B7F50	0150 866655	ELENA FOMINA	{"phone": "+70620854411"}
0005434725006	0B7F50	9384 621103	SVETLANA NESTEROVA	{"email": "nesterova.svetlana051967@postgrespro.ru", "phone": "+70286066956"}
0005434725007	0B7F50	9903 539842	TATYANA FEDOROVA	{"phone": "+70123890832"}
0005434725008	FA3E5C	1999 125286	LYUBOV ERMAKOVA	{"phone": "+70124436484"}
0005434725009	B489EA	6784 566838	IGOR TIMOFEEV	{"email": "i-timofeev.041977@postgrespro.ru", "phone": "+70055267766"}
0005434725010	4B626E	7623 463579	RUSLAN NIKITIN	{"email": "ruslan_nikitin.1975@postgrespro.ru", "phone": "+70104467423"}
0005434725011	298B83	2843 453271	OLGA KOZLOVA	{"email": "kozlova_o.091972@postgrespro.ru", "phone": "+70965765780"}
0005434725012	30C5FF	7076 170285	TATYANA FILATOVA	{"email": "filatova_t1982@postgrespro.ru", "phone": "+70937316950"}
0005434725013	30C5FF	0813 044806	RAFAIL SOROKIN	{"email": "rafail-sorokin_1962@postgrespro.ru", "phone": "+70769746601"}
0005434725014	D73D7F	0274 816952	SERGEY MAKSIMOV	{"email": "sergey_maksimov-27031961@postgrespro.ru", "phone": "+70107766362"}
0005434725015	D73D7F	0364 047103	ALEKSANDR IVANOV	{"phone": "+70610352069"}
0005434725016	9948E6	5977 461000	KIRILL NIKOLAEV	{"phone": "+70161185000"}
0005434725017	9948E6	0839 047509	LIDIYA SOLOVEVA	{"email": "soloveva-lidiya-1968@postgrespro.ru", "phone": "+70278395996"}
0005434725018	EE2CF4	0833 929569	LYUBOV ERMAKOVA	{"phone": "+70111678378"}
0005434725019	EE2CF4	0442 691490	NADEZHDA SIDOROVA	{"email": "nadezhda.sidorova.30031967@postgrespro.ru", "phone": "+70648105059"}
0005434725020	E45EF4	4312 450259	ANATOLIY NAZAROV	{"email": "nazarova.111965@postgrespro.ru", "phone": "+70967311472"}
0005434725021	E45EF4	2882 732404	ILYA KULIKOV	{"email": "kulikov.i-08061977@postgrespro.ru", "phone": "+70764767018"}
0005434725022	B034E3	8051 295712	SERGEY VOROBEV	{"email": "svorobev.1977@postgrespro.ru", "phone": "+70032698055"}
0005434725024	46274E	9807 099127	YURIY SAVELEV	{"phone": "+70158687147"}
0005434725025	6A53BD	2867 958014	KAMIL YAKOVLEV	{"email": "k_yakovlev_1969@postgrespro.ru", "phone": "+70763257837"}
0005434725026	44179D	8088 104856	LARISA KRASNOVA	{"email": "krasnova.l-081968@postgrespro.ru", "phone": "+70167943710"}
0005434725027	44179D	4987 772599	ELENA DENISOVA	{"phone": "+70542117326"}
0005434725028	444EB3	7906 719215	LEONID NOVIKOV	{"phone": "+70281131122"}
0005434725029	444EB3	5173 999646	OLGA BELOVA	{"email": "o-belova.081976@postgrespro.ru", "phone": "+70630244137"}
0005434725030	A1782F	3072 885012	NIKOLAY KONOVALOV	{"phone": "+70961470484"}
0005434725031	8E967B	4174 003477	IRINA MAKAROVA	{"email": "makarova.i.031974@postgrespro.ru", "phone": "+70622412103"}
0005434725032	2A6B60	4788 880320	LYUDMILA SEMENOVA	{"phone": "+70611871152"}
0005434725033	85CB3B	7092 096990	OLGA RYABOVA	{"phone": "+70202127529"}
0005434725034	02E80A	1902 117425	EKATERINA LAZAREVA	{"phone": "+70931268263"}
0005434725035	02E80A	7427 159804	DMITRIY MAKAROV	{"phone": "+70001005359"}
0005434725036	02E80A	5018 639005	ALEKSANDR OSIPOV	{"email": "a-osipov.16071970@postgrespro.ru", "phone": "+70806927442"}
0005434725037	107AF2	5331 636914	MAKSIM POPOV	{"phone": "+70771744089"}
0005434725038	E32285	2935 943744	LYUBOV MATVEEVA	{"email": "matveeva-l101964@postgrespro.ru", "phone": "+70539492692"}
0005434725039	FEBB4A	2775 243174	LYUBOV POPOVA	{"email": "popova-l_1985@postgrespro.ru", "phone": "+70338842873"}
0005434725040	B38115	4578 470485	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.10011970@postgrespro.ru", "phone": "+70712789604"}
0005434725041	59849B	5471 764588	YURIY BORISOV	{"email": "borisov.yuriy04041968@postgrespro.ru", "phone": "+70487995243"}
0005434725042	7C7973	1886 706472	MARINA KUZMINA	{"email": "mkuzmina-1972@postgrespro.ru", "phone": "+70447975379"}
0005434725043	7C7973	5950 140803	ANZHELA EGOROVA	{"email": "a.egorova-1975@postgrespro.ru", "phone": "+70095846277"}
0005434725044	23AA5B	6247 094410	GALINA EGOROVA	{"phone": "+70900723367"}
0005434725045	DB45DC	2670 509433	YULIYA POPOVA	{"email": "yuliya_popova_31101981@postgrespro.ru", "phone": "+70217669352"}
0005434725046	6783AC	5714 480934	ELENA KUZNECOVA	{"phone": "+70650844007"}
0005434725047	1C28B9	4190 522931	SERGEY MEDVEDEV	{"phone": "+70015906586"}
0005434725048	764D7E	5869 435203	NIKITA PETROV	{"phone": "+70967135604"}
0005434725049	670236	5908 120139	ANDREY KUZNECOV	{"email": "andreykuznecov101972@postgrespro.ru", "phone": "+70015583060"}
0005434725050	17DA5B	1680 361775	LYUBOV KUZNECOVA	{"email": "l-kuznecova-1976@postgrespro.ru", "phone": "+70481451707"}
0005434725051	17DA5B	0961 116488	TATYANA OVCHINNIKOVA	{"phone": "+70283564467"}
0005434725052	5A1D98	3137 937449	VIKTOR KUZNECOV	{"email": "v-kuznecov_1973@postgrespro.ru", "phone": "+70826652525"}
0005434725053	69D31F	6799 625367	RAISA AFANASEVA	{"phone": "+70524829724"}
0005434725054	9AE794	5965 933304	IGOR FILIPPOV	{"phone": "+70458730562"}
0005434725055	3014B7	3273 039717	ALEKSANDR NIKITIN	{"email": "nikitin.aleksandr1984@postgrespro.ru", "phone": "+70692413395"}
0005434725056	472184	6946 245556	FARIDA NIKITINA	{"email": "nikitinafarida041974@postgrespro.ru", "phone": "+70736767597"}
0005434725057	4AF4B5	5791 842542	ANDREY ALEKSEEV	{"phone": "+70148945807"}
0005434725058	7105E8	9372 704416	TATYANA POPOVA	{"email": "t-popova_1980@postgrespro.ru", "phone": "+70030309003"}
0005434725059	8F321E	3922 873541	MARINA SIDOROVA	{"phone": "+70963007640"}
0005434725060	8F321E	6350 469484	ELENA SOKOLOVA	{"phone": "+70438517495"}
0005434725061	45C7B7	9442 512763	VALENTINA SOLOVEVA	{"phone": "+70011663521"}
0005434725062	45C7B7	3869 081455	MARIYA FILIPPOVA	{"email": "filippovamariya101970@postgrespro.ru", "phone": "+70064487166"}
0005434725063	C39A66	4905 916587	DMITRIY KONOVALOV	{"email": "konovalov-d.20121977@postgrespro.ru", "phone": "+70519712204"}
0005434725064	C9F451	9834 354505	PAVEL ALEKSEEV	{"phone": "+70963478531"}
0005434725065	515078	3927 969434	MARIYA SOKOLOVA	{"phone": "+70245833541"}
0005434725066	DD784E	3361 772177	KRISTINA KULIKOVA	{"email": "kristina.kulikova.051973@postgrespro.ru", "phone": "+70898720797"}
0005434725067	BAA612	8718 301721	RODION FEDOROV	{"email": "fedorov_r_031981@postgrespro.ru", "phone": "+70922131799"}
0005434725068	6A9EFC	5338 734763	VLADIMIR BORISOV	{"email": "borisovv-1971@postgrespro.ru", "phone": "+70396807062"}
0005434725069	6A9EFC	8467 574213	TATYANA FEDOROVA	{"phone": "+70709037732"}
0005434725070	90B117	4365 266907	YAKOV POPOV	{"email": "y-popov_12071970@postgrespro.ru", "phone": "+70266279604"}
0005434725071	6DEBBC	2178 387752	SERGEY KULIKOV	{"phone": "+70545231231"}
0005434725072	7193D2	6919 500314	ELIZAVETA ARKHIPOVA	{"email": "arkhipova.elizaveta111973@postgrespro.ru", "phone": "+70064432328"}
0005434725073	5CCCAD	9509 142728	ALEKSEY NIKITIN	{"email": "nikitin.aleksey18101965@postgrespro.ru", "phone": "+70234344985"}
0005434725074	5CCCAD	5247 861679	MILENA EFIMOVA	{"email": "m.efimova-1974@postgrespro.ru", "phone": "+70160861235"}
0005434725075	977E5A	5175 469684	MAKSIM BARANOV	{"email": "m.baranov-101976@postgrespro.ru", "phone": "+70515940592"}
0005434725076	76C480	5355 729993	MARIYA ILINA	{"email": "ilina_mariya101973@postgrespro.ru", "phone": "+70207675741"}
0005434725077	749E9E	6757 562690	NIKOLAY ALEKSANDROV	{"phone": "+70041861269"}
0005434725078	C0C56C	3138 731797	OLGA MAKAROVA	{"email": "olga_makarova-20061972@postgrespro.ru", "phone": "+70603251290"}
0005434725079	EFF877	4506 169465	ALEKSANDR ANDREEV	{"phone": "+70206746536"}
0005434725080	EFF877	1128 574487	NIKITA KOZLOV	{"phone": "+70186206876"}
0005434725081	9AF0B5	3753 518433	ALEKSEY ALEKSANDROV	{"phone": "+70853923849"}
0005434725082	757ADD	5272 644081	EVGENIY KAZAKOV	{"phone": "+70309744894"}
0005434725083	6824B7	9307 789451	VIKTOR KAZAKOV	{"email": "kazakov-viktor.17091973@postgrespro.ru", "phone": "+70336319255"}
0005434725084	152EA5	5477 002156	ANATOLIY DMITRIEV	{"phone": "+70371931173"}
0005434725085	152EA5	1205 913279	IVAN KUZNECOV	{"phone": "+70191745312"}
0005434725086	3BBD48	6067 902094	ANASTASIYA NIKIFOROVA	{"email": "nikiforova-a091972@postgrespro.ru", "phone": "+70955207354"}
0005434725087	12504E	2207 922270	VALERIY POPOV	{"phone": "+70232780709"}
0005434725088	12504E	2827 904510	PAVEL TIMOFEEV	{"email": "timofeevp.06061965@postgrespro.ru", "phone": "+70577662763"}
0005434725089	C55162	2588 522078	NIKOLAY TIKHONOV	{"email": "tikhonov_nikolay1973@postgrespro.ru", "phone": "+70004949285"}
0005434725090	C55162	6209 112386	VLADIMIR VASILEV	{"phone": "+70823206298"}
0005434725091	92089D	1665 537911	EKATERINA KOROLEVA	{"phone": "+70857319656"}
0005434725092	92089D	8211 910083	VLADIMIR KARPOV	{"email": "vladimir_karpov05071957@postgrespro.ru", "phone": "+70769453406"}
0005434725093	CCBF05	6675 140629	VALERIY GRIGOREV	{"email": "grigorev_valeriy121971@postgrespro.ru", "phone": "+70051767540"}
0005434725094	CCBF05	4219 964418	SVETLANA OSIPOVA	{"phone": "+70144615781"}
0005434725095	50810F	8743 474923	IRINA SMIRNOVA	{"email": "ismirnova_21111971@postgrespro.ru", "phone": "+70644311751"}
0005434725096	50810F	5508 183988	EVGENIYA PAVLOVA	{"email": "pavlova-evgeniya071971@postgrespro.ru", "phone": "+70702646573"}
0005434725097	B28CE6	6432 283777	MARIYA BOGDANOVA	{"phone": "+70474601503"}
0005434725098	3E9C87	9835 150170	OLGA POPOVA	{"email": "olga.popova-05021975@postgrespro.ru", "phone": "+70145020011"}
0005434725099	3E9C87	3066 056152	VLADIMIR KOZLOV	{"phone": "+70015696529"}
0005434725100	3E9C87	0842 528511	EGOR PAVLOV	{"email": "egorpavlov_12051981@postgrespro.ru", "phone": "+70182903271"}
0005434725101	5A1BD0	3822 407883	VALENTINA MIKHAYLOVA	{"email": "mikhaylova.valentina121970@postgrespro.ru", "phone": "+70623747167"}
0005434725102	5A1BD0	4356 729988	NATALYA PETROVA	{"email": "petrova_n16091969@postgrespro.ru", "phone": "+70598690203"}
0005434725103	5A1BD0	9693 120947	GALINA MELNIKOVA	{"email": "g_melnikova1973@postgrespro.ru", "phone": "+70729986236"}
0005434725104	BD34B2	5094 079781	SVETLANA VOLKOVA	{"email": "volkova_s1969@postgrespro.ru", "phone": "+70191236263"}
0005434725105	669F1C	1480 144318	ANTON MEDVEDEV	{"phone": "+70178905125"}
0005434725106	5E290B	6254 662485	EGOR KUZNECOV	{"phone": "+70884508650"}
0005434725107	5E290B	6076 363172	ALEKSANDR MOISEEV	{"phone": "+70681652672"}
0005434725108	22DBF3	6148 693442	VERA KALININA	{"email": "kalinina-vera-06101976@postgrespro.ru", "phone": "+70531242663"}
0005434725109	A079A7	2516 156978	LYUDMILA MELNIKOVA	{"phone": "+70995886387"}
0005434725110	603551	2847 065627	MARIYA ALEKSANDROVA	{"email": "aleksandrova-m1970@postgrespro.ru", "phone": "+70627432747"}
0005434725111	603551	6976 188613	ALEKSEY MAKAROV	{"phone": "+70180698476"}
0005434725112	41B717	4659 735282	ANNA FOMINA	{"phone": "+70391279647"}
0005434725113	E7254F	0307 665715	LEYLA GORBUNOVA	{"email": "leyla-gorbunova28111963@postgrespro.ru", "phone": "+70503316982"}
0005434725114	C12535	8057 238634	EKATERINA NOVIKOVA	{"email": "e-novikova.111968@postgrespro.ru", "phone": "+70037588196"}
0005434725115	5320CD	6803 193717	ANDREY TIKHONOV	{"email": "a_tikhonov.23051975@postgrespro.ru", "phone": "+70160843326"}
0005434725116	849D5A	7852 094779	OLGA DANILOVA	{"email": "o.danilova-23041982@postgrespro.ru", "phone": "+70452125217"}
0005434725117	849D5A	7061 078727	ANASTASIYA ANDREEVA	{"email": "anastasiya.andreeva-1980@postgrespro.ru", "phone": "+70551485506"}
0005434725118	CC4A28	6101 327581	ALEKSEY DMITRIEV	{"email": "a-dmitriev30111966@postgrespro.ru", "phone": "+70541726927"}
0005434725119	FD250F	8158 997872	VYACHESLAV BORISOV	{"email": "vborisov21081975@postgrespro.ru", "phone": "+70298587158"}
0005434725120	FD250F	0653 329362	VALENTINA MAKAROVA	{"email": "valentina_makarova031979@postgrespro.ru", "phone": "+70712965862"}
0005434725121	9F30ED	1623 258639	OLEG KRASNOV	{"email": "krasnov-o.1973@postgrespro.ru", "phone": "+70446223632"}
0005434725122	9F30ED	7949 446969	YULIYA ANTONOVA	{"email": "antonovay_20011962@postgrespro.ru", "phone": "+70381140932"}
0005434725123	4C764E	5168 316186	PAVEL PETROV	{"phone": "+70157204504"}
0005434725124	ADAFFE	8145 548564	ELENA KAZAKOVA	{"phone": "+70054072171"}
0005434725125	89C0E5	8697 091651	RAMIS MIRONOV	{"email": "mironov_r.25101974@postgrespro.ru", "phone": "+70528626529"}
0005434725126	89C0E5	3727 405738	DMITRIY BELOV	{"email": "belov.d_18081961@postgrespro.ru", "phone": "+70989049114"}
0005434725127	89C0E5	7736 718376	ANASTASIYA PETROVA	{"phone": "+70212623553"}
0005434725128	2BBA80	7502 904121	ANGELINA SAVELEVA	{"phone": "+70944478200"}
0005434725129	47D453	5289 002536	MARIYA MIKHAYLOVA	{"phone": "+70864212180"}
0005434725130	3E2667	1657 207251	EVGENIYA ILINA	{"phone": "+70769667575"}
0005434725131	F2C4C1	1045 338084	SERGEY GERASIMOV	{"phone": "+70116187706"}
0005434725132	9C188D	1569 877996	VLADIMIR ANDREEV	{"phone": "+70346321030"}
0005434725133	A4E934	3251 479603	VLADIMIR KAZAKOV	{"phone": "+70315226007"}
0005434725134	A8FE17	4909 286133	ANDREY MAKAROV	{"email": "a.makarov.071974@postgrespro.ru", "phone": "+70186853111"}
0005434725135	756DF6	0722 539639	OLGA MATVEEVA	{"email": "olgamatveeva-081970@postgrespro.ru", "phone": "+70186989728"}
0005434725136	102466	7737 061057	LYUBOV MIRONOVA	{"phone": "+70038593539"}
0005434725137	D68B88	1636 882452	KIRILL ZHUKOV	{"phone": "+70863356351"}
0005434725138	892463	4681 372356	EVGENIY NIKITIN	{"email": "nikitin.e-23051970@postgrespro.ru", "phone": "+70871424360"}
0005434725139	317941	9156 764347	GALIYA ROMANOVA	{"phone": "+70036065176"}
0005434725140	C32A2C	2149 180353	ARTEM BORISOV	{"email": "artem_borisov-26041981@postgrespro.ru", "phone": "+70571151135"}
0005434725141	C32A2C	6047 499249	VADIM SERGEEV	{"phone": "+70898237631"}
0005434725142	5B1C6E	5716 627384	ALEKSANDR ILIN	{"email": "a.ilin1967@postgrespro.ru", "phone": "+70965132002"}
0005434725143	5B1C6E	7577 480253	NATALYA VLASOVA	{"phone": "+70623047431"}
0005434725379	3D9584	1201 004367	VALERIY KOZLOV	{"phone": "+70869716604"}
0005434725144	533E53	1158 763028	ELENA VASILEVA	{"email": "vasileva-elena12111959@postgrespro.ru", "phone": "+70993003827"}
0005434725145	DCEA63	4287 416689	ELIZAVETA KONOVALOVA	{"phone": "+70390932927"}
0005434725146	474623	8918 898733	NINA YAKOVLEVA	{"email": "n_yakovleva-1977@postgrespro.ru", "phone": "+70647980760"}
0005434725147	179FF4	0282 923075	POLINA ABRAMOVA	{"phone": "+70730472468"}
0005434725148	179FF4	7708 432092	OLGA FROLOVA	{"email": "o_frolova041972@postgrespro.ru", "phone": "+70225503099"}
0005434725149	581700	5033 557914	RUSTAM MELNIKOV	{"email": "r_melnikov011970@postgrespro.ru", "phone": "+70630999013"}
0005434725150	653386	1396 847593	VERA GAVRILOVA	{"email": "vera_gavrilova_1964@postgrespro.ru", "phone": "+70663644395"}
0005434725151	E7C716	3296 741950	DMITRIY GRIGOREV	{"email": "dmitriy-grigorev-10091978@postgrespro.ru", "phone": "+70232698699"}
0005434725152	AE40B5	7982 158416	NIKOLAY DENISOV	{"email": "nikolay.denisov_12101969@postgrespro.ru", "phone": "+70013494050"}
0005434725153	D8577D	9778 851679	YULIYA BORISOVA	{"email": "borisovay-1968@postgrespro.ru", "phone": "+70526107533"}
0005434725154	D8577D	8464 166412	DANIIL SOKOLOV	{"phone": "+70361243695"}
0005434725155	08ED34	0145 426399	ARTEM STEPANOV	{"phone": "+70715377814"}
0005434725156	7BD8E9	7168 204110	ALEKSANDR KISELEV	{"phone": "+70419838594"}
0005434725157	7BD8E9	6730 903352	EVA TARASOVA	{"email": "evatarasova.1977@postgrespro.ru", "phone": "+70628741309"}
0005434725158	DB086A	6278 544854	RAISA AKIMOVA	{"phone": "+70405859177"}
0005434725159	51EA2D	7004 639512	EVGENIY VOLKOV	{"email": "e_volkov_21071965@postgrespro.ru", "phone": "+70604472523"}
0005434725160	51EA2D	9784 601985	SERGEY MIKHAYLOV	{"phone": "+70390451491"}
0005434725161	CB5EC9	6047 611210	ALEKSEY NOVIKOV	{"phone": "+70903591204"}
0005434725162	F76F49	7751 726530	SERAFIMA PAVLOVA	{"phone": "+70733515332"}
0005434725163	F76F49	2055 017340	LILIYA GRISHINA	{"phone": "+70035216243"}
0005434725164	2C86EC	1557 289930	ALEKSANDRA SEMENOVA	{"email": "aleksandra_semenova1963@postgrespro.ru", "phone": "+70681809745"}
0005434725165	4255B8	4931 795180	ZINAIDA FILIPPOVA	{"email": "z.filippova-22061992@postgrespro.ru", "phone": "+70273287180"}
0005434725166	1196CC	6005 645087	MIKHAIL NOVIKOV	{"phone": "+70022258807"}
0005434725167	3BD4CE	1061 762081	VALENTINA KUZNECOVA	{"phone": "+70308944864"}
0005434725168	3BD4CE	3691 932793	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr021967@postgrespro.ru", "phone": "+70889493899"}
0005434725169	5C14FE	0031 928109	YANA PETROVA	{"phone": "+70631984894"}
0005434725170	5C14FE	4510 018853	SERAFIM CHERNOV	{"email": "s.chernov-12011979@postgrespro.ru", "phone": "+70259670928"}
0005434725171	3263CA	1970 315342	POLINA ANISIMOVA	{"phone": "+70404852241"}
0005434725172	3263CA	3064 281059	MARINA ALEKSANDROVA	{"email": "aleksandrova_marina1968@postgrespro.ru", "phone": "+70281726860"}
0005434725173	253084	4807 581117	VLADIMIR VOROBEV	{"email": "v-vorobev19061959@postgrespro.ru", "phone": "+70092253500"}
0005434725174	57705B	6828 189123	SVYATOSLAV SIDOROV	{"email": "sidorov.svyatoslav_1973@postgrespro.ru", "phone": "+70883051039"}
0005434725175	72BE86	9958 579737	DMITRIY SEMENOV	{"phone": "+70097131858"}
0005434725176	50A030	1115 212087	ANTONINA KUZNECOVA	{"phone": "+70581975302"}
0005434725177	B56F03	2613 231300	VYACHESLAV GORBUNOV	{"email": "vyacheslav_gorbunov1963@postgrespro.ru", "phone": "+70111639183"}
0005434725178	B56F03	1741 810907	ELENA KOMAROVA	{"phone": "+70522955756"}
0005434725179	040139	7065 459962	VITALIY NIKITIN	{"phone": "+70938456411"}
0005434725180	040139	0649 226556	YURIY ANDREEV	{"email": "andreevy011990@postgrespro.ru", "phone": "+70706437978"}
0005434725181	1148D6	0231 808661	IGOR EGOROV	{"phone": "+70190353823"}
0005434725182	6F49AC	8141 487530	NARIMAN FILIPPOV	{"email": "filippov.nariman.06111976@postgrespro.ru", "phone": "+70758035626"}
0005434725183	6F49AC	6622 050133	ROMAN TIKHONOV	{"phone": "+70259800420"}
0005434725184	FAEC0C	9611 006448	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay-03121967@postgrespro.ru", "phone": "+70500988638"}
0005434725185	FAEC0C	1420 419535	PETR NIKITIN	{"email": "nikitin_petr_041991@postgrespro.ru", "phone": "+70853479421"}
0005434725186	A06AFA	6115 697110	NIKOLAY SIDOROV	{"email": "n.sidorov.21011966@postgrespro.ru", "phone": "+70731741614"}
0005434725187	26D89B	5295 408877	ALEKSANDR FOMIN	{"email": "a.fomin_12021971@postgrespro.ru", "phone": "+70268553475"}
0005434725188	537615	1062 008735	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov14091975@postgrespro.ru", "phone": "+70391958058"}
0005434725189	537615	2826 077453	IRINA GORBUNOVA	{"phone": "+70549163551"}
0005434725190	5DEA69	9675 143421	EKATERINA BORISOVA	{"email": "ekaterina_borisova_27061973@postgrespro.ru", "phone": "+70251687337"}
0005434725191	5B99F8	9514 972431	MARIYA NAZAROVA	{"phone": "+70605852041"}
0005434725192	3B0BCC	7355 694947	IRINA SOKOLOVA	{"email": "irina.sokolova_20031983@postgrespro.ru", "phone": "+70472188162"}
0005434725193	3B0BCC	6099 457165	OLEG KULIKOV	{"phone": "+70180604960"}
0005434725194	157917	5560 632921	INNA NIKIFOROVA	{"email": "nikiforova-inna21081966@postgrespro.ru", "phone": "+70484642191"}
0005434725195	1ECC15	8185 373957	SERGEY CHERNOV	{"email": "chernov.s.1974@postgrespro.ru", "phone": "+70054930225"}
0005434725196	EF093B	9028 793211	OKSANA ZHUKOVA	{"email": "zhukova_oksana.1970@postgrespro.ru", "phone": "+70667925361"}
0005434725197	D16337	3454 602674	GALINA IVANOVA	{"email": "ivanovagalina_08101963@postgrespro.ru", "phone": "+70924537337"}
0005434725198	907E81	1116 916229	ELENA GAVRILOVA	{"email": "gavrilovaelena.011976@postgrespro.ru", "phone": "+70968346664"}
0005434725199	907E81	7016 153135	NIKOLAY GAVRILOV	{"email": "n_gavrilov_30071971@postgrespro.ru", "phone": "+70805890660"}
0005434725260	DB89CD	0419 126152	SERGEY TIKHONOV	{"phone": "+70340360462"}
0005434725200	159460	9360 183160	ALEKSANDR MARTYNOV	{"email": "a.martynov-28051964@postgrespro.ru", "phone": "+70330106579"}
0005434725201	0911BF	4063 530924	ANDREY GAVRILOV	{"phone": "+70332749986"}
0005434725202	D4EC96	3854 289215	NATALYA ABRAMOVA	{"email": "natalyaabramova_1960@postgrespro.ru", "phone": "+70783992580"}
0005434725203	D4EC96	0842 488548	PAVEL FROLOV	{"email": "frolov-p121964@postgrespro.ru", "phone": "+70736068431"}
0005434725204	F80DC4	8506 542286	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov-1974@postgrespro.ru", "phone": "+70157696290"}
0005434725205	FE12E2	3751 095093	TATYANA MAKAROVA	{"email": "t-makarova1968@postgrespro.ru", "phone": "+70910410468"}
0005434725206	45F770	0821 125455	VIKTORIYA DENISOVA	{"phone": "+70060570085"}
0005434725207	E4F3BA	5933 337915	SVETLANA FEDOROVA	{"email": "svetlanafedorova_1976@postgrespro.ru", "phone": "+70459984240"}
0005434725208	C94619	0966 400345	ELENA MAKAROVA	{"phone": "+70861705295"}
0005434725209	B6638A	7136 467072	LYUBOV TARASOVA	{"phone": "+70834756230"}
0005434725210	EF4B23	7075 893888	GALINA ROMANOVA	{"phone": "+70976338283"}
0005434725211	EF4B23	6322 473748	VALENTINA ZHURAVLEVA	{"email": "valentina-zhuravleva-1978@postgrespro.ru", "phone": "+70238297187"}
0005434725212	31F183	4172 679588	IVAN EGOROV	{"phone": "+70986762372"}
0005434725213	31F183	9630 151364	ARTEM GRIGOREV	{"email": "agrigorev1973@postgrespro.ru", "phone": "+70913096585"}
0005434725214	31F183	5650 907107	SERGEY CHERNOV	{"email": "chernov_s.031980@postgrespro.ru", "phone": "+70983496738"}
0005434725215	8FF011	3784 151839	DMITRIY KARPOV	{"email": "karpov_d-021973@postgrespro.ru", "phone": "+70185589607"}
0005434725216	76BED7	0159 890292	ALEKSANDR BORISOV	{"phone": "+70329001300"}
0005434725217	C36750	8465 229512	GENNADIY MARTYNOV	{"phone": "+70273057915"}
0005434725218	C0B7A2	1631 235565	GENNADIY AFANASEV	{"email": "afanasev_gennadiy-121982@postgrespro.ru", "phone": "+70517085294"}
0005434725219	5BD7CA	4061 925189	GALINA MELNIKOVA	{"phone": "+70699436392"}
0005434725220	DB5297	4283 316308	GALINA POPOVA	{"email": "g.popova-031971@postgrespro.ru", "phone": "+70608336879"}
0005434725221	A9B4E6	2995 528765	VERONIKA STEPANOVA	{"email": "stepanova-veronika-1966@postgrespro.ru", "phone": "+70965045500"}
0005434725222	A9B4E6	4493 702116	VALERIY VLASOV	{"email": "vlasov-valeriy-1971@postgrespro.ru", "phone": "+70708107556"}
0005434725223	425C25	2401 454289	NATALYA MOROZOVA	{"email": "nmorozova-1960@postgrespro.ru", "phone": "+70157542606"}
0005434725224	4EF453	2278 937329	LYUBOV KAZAKOVA	{"email": "l.kazakova_081978@postgrespro.ru", "phone": "+70480510500"}
0005434725225	4EF453	8098 737463	ANTON SCHERBAKOV	{"phone": "+70493191681"}
0005434725226	43AF7F	7782 655342	LIDIYA MOROZOVA	{"phone": "+70307850015"}
0005434725227	AAF783	8844 351435	NADEZHDA EFIMOVA	{"phone": "+70931255795"}
0005434725228	F29D3A	2707 164703	EKATERINA NESTEROVA	{"email": "ekaterina_nesterova_1981@postgrespro.ru", "phone": "+70982797982"}
0005434725229	F8CD1E	6142 430451	SERGEY SMIRNOV	{"email": "smirnov.s.12121970@postgrespro.ru", "phone": "+70309304360"}
0005434725230	203B92	9583 712441	OLEG EGOROV	{"email": "o-egorov.031970@postgrespro.ru", "phone": "+70966018619"}
0005434725231	F5E874	1701 065331	VALENTINA MOROZOVA	{"email": "morozova-valentina-1962@postgrespro.ru", "phone": "+70253406688"}
0005434725232	9B40D3	5138 986539	ALENA PETROVA	{"email": "alena-petrova.091977@postgrespro.ru", "phone": "+70021139816"}
0005434725233	9B40D3	3615 750958	VALERIY MARTYNOV	{"email": "vmartynov011980@postgrespro.ru", "phone": "+70586306515"}
0005434725234	8CC056	6991 827987	LARISA ZAYCEVA	{"phone": "+70312571653"}
0005434725235	8CC056	0667 344149	VALERIYA VOLKOVA	{"email": "valeriya_volkova1972@postgrespro.ru", "phone": "+70501758463"}
0005434725236	8CC056	5124 293068	NINA EFIMOVA	{"email": "n-efimova.11091973@postgrespro.ru", "phone": "+70894436089"}
0005434725237	8700B7	6137 799485	VASILIY DENISOV	{"email": "denisovvasiliy_1963@postgrespro.ru", "phone": "+70737733605"}
0005434725238	8700B7	1425 579032	KIRILL MOISEEV	{"phone": "+70978046173"}
0005434725239	9B970C	7074 951429	DENIS IVANOV	{"phone": "+70176993752"}
0005434725240	1D54FA	8297 078595	YULIYA POTAPOVA	{"email": "yuliyapotapova18121963@postgrespro.ru", "phone": "+70837301370"}
0005434725241	1D54FA	8614 345840	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr_071972@postgrespro.ru", "phone": "+70438426159"}
0005434725242	D69C8E	5174 357793	IRINA MAKSIMOVA	{"phone": "+70174854039"}
0005434725243	D69C8E	7377 514643	KSENIYA EGOROVA	{"phone": "+70668872807"}
0005434725244	CB67E7	7556 670423	ALEKSEY KISELEV	{"phone": "+70194880160"}
0005434725245	20510C	3557 160371	DARYA VASILEVA	{"email": "vasileva_d_21081981@postgrespro.ru", "phone": "+70644251500"}
0005434725246	20510C	4163 512224	IVAN SOLOVEV	{"email": "ivan-solovev1981@postgrespro.ru", "phone": "+70840091538"}
0005434725247	14949E	8660 818576	ALEKSANDR DENISOV	{"phone": "+70466332894"}
0005434725248	4C67BA	6610 382660	EKATERINA KUDRYASHOVA	{"phone": "+70861965128"}
0005434725249	A24B21	4432 509785	RUSLAN ANDREEV	{"phone": "+70327461377"}
0005434725250	CA3A8E	9197 627575	ANASTASIYA VLASOVA	{"phone": "+70768762125"}
0005434725251	010937	9786 768730	ALEKSANDR KOZLOV	{"phone": "+70108188622"}
0005434725252	A31F3F	3338 604406	OKSANA SOROKINA	{"phone": "+70165664050"}
0005434725253	A31F3F	7150 578450	NATALYA ZAKHAROVA	{"phone": "+70655463391"}
0005434725254	205502	0626 211213	YULIYA RODIONOVA	{"email": "rodionova.y-22101965@postgrespro.ru", "phone": "+70234895748"}
0005434725255	5E558F	8803 068279	NIKOLAY BELOV	{"email": "belov-nikolay_051975@postgrespro.ru", "phone": "+70691141762"}
0005434725256	317175	7154 903673	ARTUR AFANASEV	{"phone": "+70843023141"}
0005434725257	AAB08B	7077 001864	SVETLANA PAVLOVA	{"email": "pavlovasvetlana_11121974@postgrespro.ru", "phone": "+70380182322"}
0005434725258	AAB08B	0401 395884	KLAVDIYA LAZAREVA	{"phone": "+70797459592"}
0005434725259	DB89CD	3084 960156	TATYANA LUKYANOVA	{"phone": "+70639551811"}
0005434725261	C69663	4957 495901	NAIL RODIONOV	{"email": "n.rodionov-1966@postgrespro.ru", "phone": "+70680776161"}
0005434725380	3D9584	3367 723225	ALEKSEY PETROV	{"phone": "+70461703787"}
0005434725262	9F1806	2206 891846	TATYANA SAVELEVA	{"email": "tatyanasaveleva.1966@postgrespro.ru", "phone": "+70546130896"}
0005434725263	346BF7	3713 614813	PAVEL FROLOV	{"email": "frolovpavel_1975@postgrespro.ru", "phone": "+70006356748"}
0005434725264	04F2DE	8315 586752	VIKTOR NIKOLAEV	{"email": "vnikolaev-1966@postgrespro.ru", "phone": "+70254392261"}
0005434725265	C75592	6675 866620	RAMZIYA RYABOVA	{"phone": "+70903771428"}
0005434725266	0B1632	0779 815806	MARIYA VLASOVA	{"phone": "+70822072359"}
0005434725267	0B1632	4172 557225	IRINA SERGEEVA	{"email": "sergeevai.06061976@postgrespro.ru", "phone": "+70333800011"}
0005434725268	238B1C	5457 977060	SVETLANA MAKSIMOVA	{"email": "maksimova_s_1974@postgrespro.ru", "phone": "+70922269079"}
0005434725269	3F4CDE	7742 751985	ALEKSANDR DMITRIEV	{"phone": "+70332253708"}
0005434725270	B4B1F4	3844 944574	NIKOLAY PAVLOV	{"email": "nikolaypavlov-071969@postgrespro.ru", "phone": "+70637113019"}
0005434725271	A9AEA6	8463 944956	YURIY ZHUKOV	{"phone": "+70262260871"}
0005434725272	708FE3	1790 833407	MADINA KALININA	{"phone": "+70127159392"}
0005434725273	708FE3	5671 139562	ANNA BARANOVA	{"email": "baranova.a-1975@postgrespro.ru", "phone": "+70281547270"}
0005434725274	7BA78E	9791 308964	MIKHAIL IVANOV	{"email": "mikhail-ivanov.29051975@postgrespro.ru", "phone": "+70277865537"}
0005434725275	7BA78E	8700 622640	DMITRIY VOLKOV	{"phone": "+70059210356"}
0005434725276	44C1F9	9910 899750	ANDREY ABRAMOV	{"phone": "+70909050542"}
0005434725277	44C1F9	9740 793691	TATYANA DAVYDOVA	{"phone": "+70046294296"}
0005434725278	1F9477	5639 503385	IGOR STEPANOV	{"email": "stepanov_igor-011965@postgrespro.ru", "phone": "+70633660941"}
0005434725279	2AFAD2	0012 156118	MIKHAIL KUZNECOV	{"email": "m-kuznecov-29091977@postgrespro.ru", "phone": "+70529389529"}
0005434725280	20BE8C	4112 110926	ELENA KALININA	{"email": "ekalinina13081971@postgrespro.ru", "phone": "+70639171491"}
0005434725281	F7A9E9	9693 067859	VALENTINA NIKOLAEVA	{"phone": "+70157304280"}
0005434725282	10C488	1564 791870	GALINA POTAPOVA	{"email": "galina_potapova.111970@postgrespro.ru", "phone": "+70770679596"}
0005434725283	10C488	8603 451572	NATALYA KOVALEVA	{"phone": "+70630056902"}
0005434725284	10C488	9068 776004	VALERIYA ZHUKOVA	{"email": "zhukova-valeriya.28111970@postgrespro.ru", "phone": "+70664470896"}
0005434725285	EE3A68	6377 820608	VLADIMIR KOZLOV	{"phone": "+70368091842"}
0005434725286	EE3A68	0183 389964	SERGEY EGOROV	{"phone": "+70416375410"}
0005434725287	997DE9	5446 791973	YURIY KONOVALOV	{"email": "konovalovy.1971@postgrespro.ru", "phone": "+70414708917"}
0005434725288	997DE9	1794 462201	YAROSLAV ZAKHAROV	{"email": "yaroslav.zakharov_1974@postgrespro.ru", "phone": "+70952652145"}
0005434725289	422C46	2305 465736	SERGEY DENISOV	{"email": "sdenisov.021976@postgrespro.ru", "phone": "+70984300447"}
0005434725290	422C46	7735 310149	GERMAN KRASNOV	{"phone": "+70182097141"}
0005434725291	3B3B87	4343 706929	ELENA TIKHONOVA	{"email": "tikhonova.elena-28071970@postgrespro.ru", "phone": "+70195493937"}
0005434725292	387E6C	8592 676958	GEORGIY SOROKIN	{"email": "sorokin.g_041968@postgrespro.ru", "phone": "+70752707486"}
0005434725293	83946E	0624 088013	OLGA YAKOVLEVA	{"email": "yakovleva.olga_051982@postgrespro.ru", "phone": "+70650587965"}
0005434725294	4A61A8	1938 282306	VIKTOR KUZNECOV	{"email": "kuznecov-viktor24011976@postgrespro.ru", "phone": "+70422739693"}
0005434725295	DCA967	6182 567163	VITALIY SERGEEV	{"phone": "+70508803980"}
0005434725296	DCA967	2744 915132	SERGEY YAKOVLEV	{"phone": "+70994452965"}
0005434725297	42A5CF	8920 470197	ROMAN PETROV	{"email": "petrovroman.1973@postgrespro.ru", "phone": "+70079966722"}
0005434725298	078FD9	9887 024716	TIMUR MEDVEDEV	{"phone": "+70599833826"}
0005434725299	FCE603	8881 851145	ANATOLIY SOKOLOV	{"email": "a-sokolov17011976@postgrespro.ru", "phone": "+70236290196"}
0005434725300	45ED81	1719 357068	ALEKSANDR OSIPOV	{"email": "a.osipov1966@postgrespro.ru", "phone": "+70820803408"}
0005434725301	45ED81	9935 394928	NIKOLAY KARPOV	{"phone": "+70584386741"}
0005434725302	1B9E9F	2595 938297	OKSANA NESTEROVA	{"phone": "+70760681608"}
0005434725303	1B9E9F	3189 639667	ANNA CHERNOVA	{"email": "chernova.anna10031987@postgrespro.ru", "phone": "+70366066072"}
0005434725304	36A78E	3920 985043	SERGEY GERASIMOV	{"email": "s_gerasimov.101973@postgrespro.ru", "phone": "+70622628663"}
0005434725305	51E2E8	3430 843068	VALERIY ANDREEV	{"phone": "+70527421866"}
0005434725306	51E2E8	3439 395360	VLADIMIR ZAYCEV	{"phone": "+70876298174"}
0005434725307	906758	7554 850956	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr-071958@postgrespro.ru", "phone": "+70275149979"}
0005434725308	ACFB1A	0656 155239	NIKOLAY SEMENOV	{"phone": "+70355869602"}
0005434725309	0D3188	4466 237261	ALEKSANDR YAKOVLEV	{"phone": "+70474925651"}
0005434725310	3131A5	2153 867723	NIKITA MIRONOV	{"phone": "+70296511518"}
0005434725311	73AFB1	4117 796120	IVAN ZAKHAROV	{"email": "zakharov.ivan031971@postgrespro.ru", "phone": "+70737829605"}
0005434725312	F1FC03	5015 295915	ALEKSANDRA ORLOVA	{"email": "aleksandraorlova_011972@postgrespro.ru", "phone": "+70932141221"}
0005434725313	7B289B	6937 106717	YULIYA PETROVA	{"phone": "+70167901340"}
0005434725314	7B289B	3201 854262	ANASTASIYA OSIPOVA	{"email": "anastasiya.osipova.21031973@postgrespro.ru", "phone": "+70432475024"}
0005434725315	932894	6370 940109	DMITRIY MELNIKOV	{"phone": "+70551683710"}
0005434725316	285510	2925 125325	LARISA LEBEDEVA	{"email": "lebedeva-larisa-22111976@postgrespro.ru", "phone": "+70873153945"}
0005434725317	285510	0907 877375	ANTONINA NIKOLAEVA	{"phone": "+70284543717"}
0005434725318	FA89DC	4806 121163	RAISA KISELEVA	{"phone": "+70787323980"}
0005434725319	4F9920	4547 232655	VALERIY ROMANOV	{"phone": "+70164596569"}
0005434725320	0DCE2E	4353 371205	TATYANA MOROZOVA	{"phone": "+70379112572"}
0005434725321	1F974A	2662 687183	KSENIYA BOGDANOVA	{"email": "bogdanova_kseniya-07011985@postgrespro.ru", "phone": "+70190248537"}
0005434725322	1F974A	7379 517058	IVAN CHERNOV	{"email": "i-chernov_071988@postgrespro.ru", "phone": "+70266396932"}
0005434725323	D0F5D9	5419 194799	ALEKSANDR SIDOROV	{"email": "sidorova081973@postgrespro.ru", "phone": "+70920856482"}
0005434725324	D0F5D9	1942 610934	ALEKSEY KRASNOV	{"phone": "+70101799579"}
0005434725325	AAC4D6	2744 488350	ANTONINA MARTYNOVA	{"email": "martynova_antonina1970@postgrespro.ru", "phone": "+70941425501"}
0005434725326	574CB6	2524 517603	NINA DMITRIEVA	{"email": "n.dmitrieva-1964@postgrespro.ru", "phone": "+70994357026"}
0005434725327	81D1CB	5630 001308	SERGEY ANTONOV	{"phone": "+70727867479"}
0005434725328	81D1CB	2110 656259	ALEKSANDR ABRAMOV	{"email": "a.abramov.05031968@postgrespro.ru", "phone": "+70539784618"}
0005434725329	425CD3	4404 575264	OLEG GRIGOREV	{"phone": "+70037527746"}
0005434725330	425CD3	3520 533250	NADEZHDA GERASIMOVA	{"phone": "+70653244368"}
0005434725331	63A049	3819 630478	OLGA FROLOVA	{"email": "olgafrolova.10041958@postgrespro.ru", "phone": "+70745070336"}
0005434725332	1BD453	2675 721503	DMITRIY IVANOV	{"phone": "+70344591020"}
0005434725333	1BD453	9811 820808	ELENA PETROVA	{"email": "petrova.elena-25101965@postgrespro.ru", "phone": "+70525401636"}
0005434725334	2EDE07	3876 594924	ARTEM IVANOV	{"email": "ivanov.artem.071976@postgrespro.ru", "phone": "+70843951659"}
0005434725335	B3D032	8888 023111	TATYANA MALYSHEVA	{"email": "malysheva.t-21121985@postgrespro.ru", "phone": "+70659253798"}
0005434725336	B3D032	9434 838218	LYUBOV SAVELEVA	{"email": "l_saveleva.071965@postgrespro.ru", "phone": "+70847548396"}
0005434725337	8DFE57	7126 076508	ARTEM KUZMIN	{"email": "a.kuzmin_1980@postgrespro.ru", "phone": "+70441261776"}
0005434725338	8DFE57	9563 401159	DANILA BONDARENKO	{"phone": "+70290269176"}
0005434725339	5F80BE	0848 534644	OLGA YUDINA	{"email": "olga.yudina111966@postgrespro.ru", "phone": "+70010423636"}
0005434725340	77F10E	1947 564510	GENNADIY KUZNECOV	{"email": "gennadiy-kuznecov-011971@postgrespro.ru", "phone": "+70029546866"}
0005434725341	BFC04B	9464 117041	ANNA IVANOVA	{"email": "annaivanova-16071977@postgrespro.ru", "phone": "+70712978855"}
0005434725342	BFC04B	3537 097107	VERA VOROBEVA	{"phone": "+70585620498"}
0005434725343	57F285	1216 745974	ALEKSANDR MATVEEV	{"email": "matveevaleksandr18081974@postgrespro.ru", "phone": "+70622108576"}
0005434725344	847C22	1187 275342	MARIYA KOLESNIKOVA	{"phone": "+70506723801"}
0005434725345	B4AC34	7778 451285	ANASTASIYA SERGEEVA	{"phone": "+70706320199"}
0005434725346	B5BC5A	9275 871631	SERGEY MELNIKOV	{"email": "melnikov-s.111977@postgrespro.ru", "phone": "+70187330074"}
0005434725347	4F8F21	8580 764506	VASILIY DENISOV	{"email": "denisov-vasiliy041967@postgrespro.ru", "phone": "+70103484938"}
0005434725348	A4E3A2	6850 086317	TAMARA NIKOLAEVA	{"email": "t_nikolaeva.16091977@postgrespro.ru", "phone": "+70052091624"}
0005434725349	A4E3A2	7261 761544	VALENTINA KONOVALOVA	{"phone": "+70908404120"}
0005434725350	BF324D	9933 906605	TAMARA KISELEVA	{"email": "tamara.kiseleva-071968@postgrespro.ru", "phone": "+70580914288"}
0005434725351	7CE2E5	1403 776289	ARTEM TIMOFEEV	{"email": "artem-timofeev_22041966@postgrespro.ru", "phone": "+70303460491"}
0005434725352	7A339C	4004 055608	NIKOLAY KRASNOV	{"email": "krasnov-nikolay.1967@postgrespro.ru", "phone": "+70062599863"}
0005434725353	7A339C	4307 572216	TATYANA FADEEVA	{"phone": "+70432482850"}
0005434725354	7A339C	3582 838711	IVAN FILIPPOV	{"email": "filippovivan.26021979@postgrespro.ru", "phone": "+70149511285"}
0005434725355	1D7DE8	0404 570352	VLADISLAV SAVELEV	{"phone": "+70173393915"}
0005434725356	1D7DE8	6646 255335	ANDREY ROMANOV	{"phone": "+70550647985"}
0005434725357	BAB6B2	1407 947494	LYUBOV SOLOVEVA	{"email": "soloveva_lyubov-26121971@postgrespro.ru", "phone": "+70060243474"}
0005434725358	BAB6B2	4085 900154	OLGA POPOVA	{"phone": "+70901184472"}
0005434725359	DB7019	3736 997487	ALEKSANDR GUSEV	{"email": "gusev.aleksandr_1977@postgrespro.ru", "phone": "+70908650788"}
0005434725360	DB7019	7542 562204	IGOR POPOV	{"email": "popov-igor.081971@postgrespro.ru", "phone": "+70326352266"}
0005434725361	DB7019	7137 276143	ALEKSANDR VASILEV	{"email": "a.vasilev_04121980@postgrespro.ru", "phone": "+70907958494"}
0005434725362	C4B359	0998 284117	VALERIY MELNIKOV	{"email": "valeriy.melnikov.03101961@postgrespro.ru", "phone": "+70526994557"}
0005434725363	C4B359	0428 526861	ALEKSEY GAVRILOV	{"email": "aleksey-gavrilov24061965@postgrespro.ru", "phone": "+70816122066"}
0005434725364	B9836C	9322 588952	IGOR STEPANOV	{"email": "stepanovi.121966@postgrespro.ru", "phone": "+70324121840"}
0005434725365	B9836C	7028 326516	ALEKSEY MAKAROV	{"phone": "+70226131640"}
0005434725366	724F66	1925 342011	VIKTOR PETROV	{"phone": "+70691280058"}
0005434725367	0DBC32	0813 761261	GALINA GRISHINA	{"email": "grishina_g.1971@postgrespro.ru", "phone": "+70358405398"}
0005434725368	0DBC32	2479 871971	NATALYA LEBEDEVA	{"email": "lebedevanatalya.09111972@postgrespro.ru", "phone": "+70290567716"}
0005434725369	486092	3812 424469	EVGENIYA DENISOVA	{"phone": "+70345428515"}
0005434725370	427377	9433 988507	REGINA RYABOVA	{"email": "ryabova-r091969@postgrespro.ru", "phone": "+70771471535"}
0005434725371	30AE85	1557 123935	NATALYA NIKOLAEVA	{"email": "n_nikolaeva_011983@postgrespro.ru", "phone": "+70583218069"}
0005434725372	3D1812	1275 656042	SVETLANA IVANOVA	{"email": "ivanova_svetlana-1985@postgrespro.ru", "phone": "+70376458283"}
0005434725373	101D2F	0275 134444	ELENA BORISOVA	{"email": "borisova_elena_1975@postgrespro.ru", "phone": "+70974656969"}
0005434725374	101D2F	1070 807219	LINAR BELOV	{"email": "belov-linar-111968@postgrespro.ru", "phone": "+70673776002"}
0005434725375	C77BD7	6611 426965	ELMIRA NAZAROVA	{"email": "nazarova.elmira1979@postgrespro.ru", "phone": "+70830682903"}
0005434725376	997778	2592 486002	ALEKSANDRA ILINA	{"phone": "+70453722387"}
0005434725377	79AFF6	2625 997215	FLYURA KUZMINA	{"email": "kuzmina-flyura-061968@postgrespro.ru", "phone": "+70623459861"}
0005434725378	5AF5BF	6598 849277	PAVEL PETROV	{"phone": "+70770888103"}
0005434725381	167F25	0531 151897	DANIL GERASIMOV	{"email": "danil_gerasimov.1978@postgrespro.ru", "phone": "+70797103790"}
0005434725382	167F25	1944 005438	KONSTANTIN ORLOV	{"phone": "+70374762249"}
0005434725383	7841CC	6311 823665	NATALYA ZAYCEVA	{"email": "natalya.zayceva-031963@postgrespro.ru", "phone": "+70614952971"}
0005434725384	7841CC	6696 733977	ALEVTINA NAZAROVA	{"email": "nazarova.alevtina_1969@postgrespro.ru", "phone": "+70638155159"}
0005434725385	647D48	9809 638863	OLGA DAVYDOVA	{"email": "o.davydova.071965@postgrespro.ru", "phone": "+70004765152"}
0005434725386	EDB83E	0819 318120	ALEKSEY MEDVEDEV	{"phone": "+70118387775"}
0005434725387	379132	6161 145266	IGOR TIKHONOV	{"phone": "+70166179502"}
0005434725388	379132	8141 406028	YULIYA KOZLOVA	{"phone": "+70984873494"}
0005434725389	85738D	7327 833962	OLEG STEPANOV	{"email": "stepanovo.18101967@postgrespro.ru", "phone": "+70845220472"}
0005434725390	FBE258	3766 609587	ALEKSEY BARANOV	{"email": "a.baranov-31011970@postgrespro.ru", "phone": "+70400525149"}
0005434725391	57B809	3565 935933	SERGEY ZAKHAROV	{"phone": "+70207108841"}
0005434725392	A56369	9059 823987	ANNA KUZNECOVA	{"phone": "+70216139572"}
0005434725393	A56369	5187 437670	SERGEY ALEKSEEV	{"email": "sergey-alekseev_121974@postgrespro.ru", "phone": "+70437315277"}
0005434725394	3B99CE	7942 558274	NADEZHDA TIKHONOVA	{"phone": "+70186657632"}
0005434725395	FA2323	6216 377810	OLEG FEDOROV	{"phone": "+70374013298"}
0005434725396	FA2323	0441 535853	NIKOLAY VOLKOV	{"phone": "+70136145645"}
0005434725397	C587D4	2493 364726	ANNA ZAYCEVA	{"email": "a-zayceva041966@postgrespro.ru", "phone": "+70577175574"}
0005434725398	C587D4	0320 996602	DMITRIY NAZAROV	{"phone": "+70030706769"}
0005434725399	E68344	8172 587134	NATALYA STEPANOVA	{"phone": "+70421283853"}
0005434725400	E68344	4952 022093	IRINA NAZAROVA	{"email": "i_nazarova_101974@postgrespro.ru", "phone": "+70654047610"}
0005434725401	6564BA	1926 331690	SVETLANA ANDREEVA	{"email": "s-andreeva.101967@postgrespro.ru", "phone": "+70203598852"}
0005434725402	A9C67F	7627 044576	GALINA KUZNECOVA	{"email": "g-kuznecova.021975@postgrespro.ru", "phone": "+70037330048"}
0005434725403	F46A6B	4517 720790	DMITRIY ORLOV	{"phone": "+70528025568"}
0005434725404	F46A6B	8975 502286	VIKTORIYA MAKSIMOVA	{"email": "vmaksimova.011973@postgrespro.ru", "phone": "+70484348214"}
0005434725405	51393D	0306 237761	ANDREY YAKOVLEV	{"email": "a-yakovlev.081982@postgrespro.ru", "phone": "+70143508014"}
0005434725406	51393D	5359 803142	GALINA EGOROVA	{"email": "galina_egorova-1969@postgrespro.ru", "phone": "+70902035929"}
0005434725407	7B965D	0394 939105	VASILIY KARPOV	{"email": "vkarpov-031950@postgrespro.ru", "phone": "+70628641651"}
0005434725408	7B965D	9334 059094	TAMARA KOVALEVA	{"phone": "+70618160564"}
0005434725409	3431AC	7437 111483	VLADISLAV CHERNOV	{"phone": "+70031056194"}
0005434725410	C55933	9895 553902	ANDREY GUSEV	{"phone": "+70120751017"}
0005434725411	C55933	7851 952537	BORIS KRASNOV	{"phone": "+70856945478"}
0005434725412	C23DFA	7834 797258	MARAT MATVEEV	{"phone": "+70647914981"}
0005434725413	C21A22	8465 146262	IVAN KARPOV	{"email": "ivan_karpov.021971@postgrespro.ru", "phone": "+70144446315"}
0005434725414	5C890A	1698 252195	ALEKSEY RODIONOV	{"email": "arodionov.1962@postgrespro.ru", "phone": "+70072586241"}
0005434725415	B568F5	0081 562488	PAVEL KUZNECOV	{"phone": "+70727237602"}
0005434725416	57A509	9761 468396	ANNA PETROVA	{"phone": "+70206179671"}
0005434725417	07B213	8562 172281	VASILIY ALEKSANDROV	{"phone": "+70166555516"}
0005434725418	07B213	3332 705709	ANATOLIY NIKITIN	{"phone": "+70691289908"}
0005434725419	AD679D	2051 821789	FEDOR MIKHAYLOV	{"phone": "+70842866505"}
0005434725420	760448	7651 399424	ALEKSANDR SCHERBAKOV	{"phone": "+70084477187"}
0005434725421	760448	9329 670135	VYACHESLAV TIKHONOV	{"phone": "+70599856094"}
0005434725422	760448	1799 197408	MARIYA RYABOVA	{"phone": "+70456493738"}
0005434725423	12D71F	5879 573777	MIKHAIL FOMIN	{"phone": "+70382094762"}
0005434725424	BD8C33	7307 586164	ALEKSANDR SCHERBAKOV	{"phone": "+70658719328"}
0005434725425	BD8C33	1032 575770	VITALIY POPOV	{"email": "popovvitaliy-1975@postgrespro.ru", "phone": "+70614098853"}
0005434725426	235B41	5222 988318	OLGA ZAYCEVA	{"email": "olga_zayceva.11101964@postgrespro.ru", "phone": "+70924910963"}
0005434725427	235B41	0940 166705	VARVARA NIKITINA	{"phone": "+70066705562"}
0005434725428	92275D	7618 108194	VADIM KOZLOV	{"phone": "+70645739581"}
0005434725429	092D74	7432 764473	SERGEY FEDOTOV	{"email": "fedotovs_09051983@postgrespro.ru", "phone": "+70032614094"}
0005434725430	31FE84	2148 590032	VLADIMIR VASILEV	{"email": "vasilev.v-051963@postgrespro.ru", "phone": "+70836577747"}
0005434725431	B855FC	4389 763083	ANATOLIY SMIRNOV	{"email": "smirnov-anatoliy1976@postgrespro.ru", "phone": "+70221464713"}
0005434725432	B855FC	2301 642048	SVETLANA MIKHAYLOVA	{"phone": "+70859290007"}
0005434725433	B855FC	3959 732544	SERGEY NIKOLAEV	{"email": "nikolaev_s-08101972@postgrespro.ru", "phone": "+70761869636"}
0005434725434	02271E	8302 106799	ANNA ERMAKOVA	{"email": "a_ermakova1964@postgrespro.ru", "phone": "+70904143067"}
0005434725435	7ABAE0	1605 757114	NIKOLAY IVANOV	{"email": "ivanov-nikolay1967@postgrespro.ru", "phone": "+70364160415"}
0005434725436	1ADCAF	7732 000447	VERA KOROLEVA	{"phone": "+70172108081"}
0005434725437	1ADCAF	3369 496260	TATYANA BOGDANOVA	{"email": "tatyana_bogdanova.01111976@postgrespro.ru", "phone": "+70889358560"}
0005434725438	1ADCAF	5297 924436	DARYA KUZMINA	{"phone": "+70770833938"}
0005434725439	0D766B	5659 198551	NIKOLAY ORLOV	{"phone": "+70915637707"}
0005434725557	19CE7B	3032 277194	VLADIMIR YAKOVLEV	{"phone": "+70344042170"}
0005434725440	CF0289	4416 042226	ANGELINA ZAYCEVA	{"email": "zayceva-a.1971@postgrespro.ru", "phone": "+70043847245"}
0005434725441	CF0289	4313 430875	VERA YAKOVLEVA	{"email": "v-yakovleva24081974@postgrespro.ru", "phone": "+70863916451"}
0005434725442	A69237	7997 687948	ALENA MOROZOVA	{"phone": "+70490095746"}
0005434725443	0DA422	5795 394962	ANDREY BORISOV	{"phone": "+70187773675"}
0005434725444	0DA422	8738 059478	IVAN KOROLEV	{"email": "ivan_korolev_1971@postgrespro.ru", "phone": "+70641179899"}
0005434725445	EF5399	2009 369987	OLGA KOMAROVA	{"phone": "+70594964258"}
0005434725446	918640	3325 852835	OLGA PETROVA	{"email": "o-petrova_30071962@postgrespro.ru", "phone": "+70695509679"}
0005434725447	918640	8141 778636	ANDREY KULIKOV	{"phone": "+70571507478"}
0005434725448	36453F	7835 206676	SEMEN GRIGOREV	{"email": "semengrigorev.021972@postgrespro.ru", "phone": "+70877576072"}
0005434725449	0B182B	2785 368995	SOFIYA KOZLOVA	{"email": "sofiya_kozlova1964@postgrespro.ru", "phone": "+70806024152"}
0005434725450	0B182B	1188 116070	NATALYA KOROLEVA	{"phone": "+70336707550"}
0005434725451	4AE87C	3465 903031	YAROSLAV FILIPPOV	{"email": "yaroslav.filippov.24051969@postgrespro.ru", "phone": "+70523060169"}
0005434725452	9280F5	7267 846260	NADEZHDA GORBUNOVA	{"phone": "+70742737247"}
0005434725453	04101A	0026 728244	GALINA KUZNECOVA	{"phone": "+70391532556"}
0005434725454	8BC4C3	6353 365846	NIKOLAY KISELEV	{"email": "kiselev.nikolay-1979@postgrespro.ru", "phone": "+70296460151"}
0005434725455	5E42F6	0990 453185	ANDREY PETROV	{"email": "petrov-a.051968@postgrespro.ru", "phone": "+70153033735"}
0005434725456	804D95	1506 388093	NIKOLAY SOROKIN	{"email": "sorokin_nikolay_1976@postgrespro.ru", "phone": "+70004452228"}
0005434725457	804D95	0584 958054	ILNUR FEDOTOV	{"phone": "+70119427419"}
0005434725458	804D95	1345 543838	VALERIYA DMITRIEVA	{"email": "valeriyadmitrieva_1981@postgrespro.ru", "phone": "+70047551809"}
0005434725459	DBC85B	1365 901943	ANTON BONDARENKO	{"email": "bondarenkoa_061970@postgrespro.ru", "phone": "+70878263836"}
0005434725460	DBC85B	6490 923087	RAISA TARASOVA	{"phone": "+70678915830"}
0005434725461	8D1503	5737 549329	YURIY DENISOV	{"phone": "+70643081961"}
0005434725462	8D1503	0662 182015	VALENTINA MELNIKOVA	{"email": "melnikova.valentina051972@postgrespro.ru", "phone": "+70576235374"}
0005434725463	0C49B2	0563 506664	VIKTOR ANDREEV	{"phone": "+70738335174"}
0005434725464	0C49B2	2130 015026	YAROSLAV MOROZOV	{"email": "morozovy_1970@postgrespro.ru", "phone": "+70877203206"}
0005434725465	0C49B2	8211 561755	GEORGIY NAUMOV	{"phone": "+70639454464"}
0005434725466	34B279	9605 236459	GALINA SEMENOVA	{"phone": "+70611058500"}
0005434725467	1DCDF2	7103 458219	SERGEY BONDARENKO	{"phone": "+70366565172"}
0005434725468	1DCDF2	1903 210251	TAISIYA RODIONOVA	{"email": "rodionova-t-021963@postgrespro.ru", "phone": "+70387236420"}
0005434725469	94D2D6	9086 551019	LYUBOV SEMENOVA	{"email": "lyubov.semenova_051977@postgrespro.ru", "phone": "+70650160203"}
0005434725470	94D2D6	0308 316519	NATALYA NIKOLAEVA	{"email": "nikolaeva-natalya.051975@postgrespro.ru", "phone": "+70039775703"}
0005434725471	0D9C6C	8688 554489	ALEKSANDR KULIKOV	{"phone": "+70668589950"}
0005434725472	0D9C6C	5873 160113	PETR KOROLEV	{"phone": "+70856995910"}
0005434725473	1AF231	4094 680398	NADEZHDA TARASOVA	{"email": "nadezhdatarasova-1966@postgrespro.ru", "phone": "+70092359953"}
0005434725474	40D951	6682 159582	DENIS SERGEEV	{"phone": "+70520426900"}
0005434725475	49D686	3635 850748	IVAN ISAEV	{"email": "isaev_ivan041969@postgrespro.ru", "phone": "+70388192864"}
0005434725476	52AA62	3416 875383	TATYANA ABRAMOVA	{"phone": "+70233678223"}
0005434725477	E355D8	5757 768708	ANDREY SERGEEV	{"phone": "+70863981908"}
0005434725478	2ED521	9529 381047	VALENTIN KUDRYASHOV	{"phone": "+70889829745"}
0005434725479	F1869D	6327 920819	ANZHELA ZHUKOVA	{"email": "zhukova-a.051967@postgrespro.ru", "phone": "+70572740224"}
0005434725480	F1869D	7214 237411	ALEKSEY SERGEEV	{"phone": "+70604407505"}
0005434725481	0E8ECD	7923 046469	NIKOLAY SOROKIN	{"email": "sorokin_n_111970@postgrespro.ru", "phone": "+70792607176"}
0005434725482	5749FC	6754 573107	TAMARA VASILEVA	{"phone": "+70773917954"}
0005434725483	1A1835	5434 612990	ALEKSANDR ANTONOV	{"phone": "+70076906636"}
0005434725484	1A1835	0842 501834	SERGEY BELOV	{"phone": "+70928984055"}
0005434725485	517EBB	8900 090676	TAKHIR SOKOLOV	{"phone": "+70417779794"}
0005434725486	51B68E	9865 495348	VIKTOR MAKSIMOV	{"email": "maksimov-v.041964@postgrespro.ru", "phone": "+70955773253"}
0005434725487	D84B36	6440 409626	POLINA GORBUNOVA	{"email": "polinagorbunova041974@postgrespro.ru", "phone": "+70877760242"}
0005434725488	82A794	0838 530598	NADEZHDA TARASOVA	{"email": "tarasovan071975@postgrespro.ru", "phone": "+70543936923"}
0005434725489	0CD6BB	8589 860700	DANIIL BARANOV	{"phone": "+70219745435"}
0005434725490	667ABC	0420 372651	RAISA NIKIFOROVA	{"email": "nikiforova-r13121984@postgrespro.ru", "phone": "+70121058523"}
0005434725491	667ABC	7208 008565	ALEKSANDRA KOZLOVA	{"phone": "+70210822567"}
0005434725492	7E9871	0889 752424	IRINA FADEEVA	{"email": "fadeeva.irina.101971@postgrespro.ru", "phone": "+70543016878"}
0005434725602	20DFC5	3517 417889	LYUDMILA RODIONOVA	{"phone": "+70015998843"}
0005434725493	7E9871	2540 948911	ALLA SAVELEVA	{"email": "saveleva_alla-1966@postgrespro.ru", "phone": "+70619237596"}
0005434725494	C6CA40	9093 024981	EKATERINA GRISHINA	{"email": "ekaterinagrishina_27041976@postgrespro.ru", "phone": "+70525701314"}
0005434725495	C6CA40	7647 985906	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov021968@postgrespro.ru", "phone": "+70791769286"}
0005434725496	7F5C8C	1761 939921	LYUDMILA GUSEVA	{"email": "lyudmila_guseva_27081970@postgrespro.ru", "phone": "+70312371952"}
0005434725497	7F5C8C	9212 636044	NATALYA IVANOVA	{"phone": "+70389873705"}
0005434725498	10B2FA	0246 539470	DENIS CHERNOV	{"email": "denischernov_16041976@postgrespro.ru", "phone": "+70145387940"}
0005434725499	10B2FA	4024 567428	MARGARITA FEDOROVA	{"email": "fedorova_margarita121977@postgrespro.ru", "phone": "+70575012448"}
0005434725500	10B2FA	6356 521762	ANNA AKIMOVA	{"email": "akimova.anna05081961@postgrespro.ru", "phone": "+70496827700"}
0005434725501	3694F2	3927 207957	VIKTORIYA MAKAROVA	{"email": "makarovav-17121965@postgrespro.ru", "phone": "+70807799922"}
0005434725502	3694F2	8717 523314	MAKSIM FOMIN	{"phone": "+70888547832"}
0005434725503	CB444F	0673 479753	ZULFIYA MEDVEDEVA	{"phone": "+70308973636"}
0005434725504	CB444F	4183 038260	LARISA NOVIKOVA	{"email": "larisa_novikova_06101970@postgrespro.ru", "phone": "+70090685238"}
0005434725505	96B664	2610 530979	TATYANA KARPOVA	{"email": "tatyana_karpova.01121970@postgrespro.ru", "phone": "+70241600838"}
0005434725506	334AAA	4492 953306	ALEKSEY TARASOV	{"email": "tarasov_aleksey-1977@postgrespro.ru", "phone": "+70538128391"}
0005434725507	334AAA	0746 014996	IVAN POPOV	{"email": "popov-ivan1978@postgrespro.ru", "phone": "+70418756437"}
0005434725508	7ED035	1764 996968	MARIYA GAVRILOVA	{"phone": "+70964333136"}
0005434725509	A8BA5C	3693 033498	RINAT VOLKOV	{"email": "volkov-rinat-061978@postgrespro.ru", "phone": "+70143092922"}
0005434725510	E9A78F	0516 534472	NINA NESTEROVA	{"email": "n_nesterova-1979@postgrespro.ru", "phone": "+70512328828"}
0005434725511	E9A78F	7161 872123	SERGEY OSIPOV	{"phone": "+70500204217"}
0005434725512	F2BD26	2163 006550	ARKADIY SIDOROV	{"email": "sidorov.arkadiy1976@postgrespro.ru", "phone": "+70964505870"}
0005434725513	99E329	7147 852774	NIKITA MIRONOV	{"phone": "+70065724449"}
0005434725514	BF37F5	3854 023423	OLGA KARPOVA	{"email": "karpovaolga_11111969@postgrespro.ru", "phone": "+70512753513"}
0005434725515	BF37F5	7940 146899	SERGEY IVANOV	{"email": "sivanov.27051962@postgrespro.ru", "phone": "+70587836967"}
0005434725516	219489	0556 011661	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova-09031979@postgrespro.ru", "phone": "+70011791518"}
0005434725517	A95F8C	3770 541014	NINA ANTONOVA	{"email": "nina_antonova_071969@postgrespro.ru", "phone": "+70470199224"}
0005434725518	72EA8E	9122 631189	EVGENIY ANDREEV	{"phone": "+70575375359"}
0005434725519	72EA8E	1013 470797	NADEZHDA SMIRNOVA	{"email": "n-smirnova-101960@postgrespro.ru", "phone": "+70209005802"}
0005434725520	ED3B9D	8745 696346	ELENA MELNIKOVA	{"phone": "+70054191919"}
0005434725521	ED3B9D	1106 115975	ANNA PETROVA	{"phone": "+70032859074"}
0005434725522	6AF4C0	7393 355628	ALEKSANDR EGOROV	{"email": "egorov_a-01111973@postgrespro.ru", "phone": "+70985740634"}
0005434725523	48FA09	7027 520231	LYUBOV KRASNOVA	{"email": "krasnova_l-20071967@postgrespro.ru", "phone": "+70039519172"}
0005434725524	FA1400	1281 518146	RUSLAN NOVIKOV	{"email": "r-novikov1968@postgrespro.ru", "phone": "+70770948409"}
0005434725525	DF2948	3596 292465	TATYANA TIKHONOVA	{"email": "t_tikhonova1972@postgrespro.ru", "phone": "+70580192348"}
0005434725526	DF2948	2820 881680	VALENTINA MARTYNOVA	{"email": "valentinamartynova.1973@postgrespro.ru", "phone": "+70755242525"}
0005434725527	832862	2544 369987	DMITRIY IVANOV	{"email": "ivanov_d-26111973@postgrespro.ru", "phone": "+70839900995"}
0005434725528	C214B1	6307 326680	EVGENIY KUZMIN	{"email": "evgeniy.kuzmin23101984@postgrespro.ru", "phone": "+70163195127"}
0005434725529	C214B1	9336 402107	LILIYA OSIPOVA	{"email": "l-osipova.031965@postgrespro.ru", "phone": "+70992742829"}
0005434725530	DD7CE1	2919 374305	NINA EGOROVA	{"email": "n_egorova29011978@postgrespro.ru", "phone": "+70829871135"}
0005434725531	6D81DD	2263 004396	PETR KARPOV	{"email": "p.karpov-27041964@postgrespro.ru", "phone": "+70111969357"}
0005434725532	6D81DD	5226 399708	VALENTINA BELOVA	{"email": "valentina_belova.011975@postgrespro.ru", "phone": "+70105884091"}
0005434725533	691C0D	4073 072988	ALEKSANDR KISELEV	{"phone": "+70840732638"}
0005434725534	691C0D	4433 995047	EVGENIY MIRONOV	{"phone": "+70718122384"}
0005434725535	0F53F6	4666 643540	EKATERINA ANTONOVA	{"email": "eantonova-08111965@postgrespro.ru", "phone": "+70129165588"}
0005434725536	168D1A	0111 345337	ALEKSANDR SERGEEV	{"phone": "+70357358760"}
0005434725537	168D1A	4991 515717	DMITRIY OSIPOV	{"phone": "+70412459394"}
0005434725538	B41794	8943 874455	MIROSLAV RODIONOV	{"email": "m_rodionov.10111971@postgrespro.ru", "phone": "+70887653050"}
0005434725539	E670FB	1908 569440	NIKOLAY MIKHAYLOV	{"phone": "+70166009306"}
0005434725540	300C3F	7153 024382	ANDREY VOLKOV	{"email": "volkov.a1954@postgrespro.ru", "phone": "+70925370907"}
0005434725541	3AE84A	6021 035474	NIKOLAY SOKOLOV	{"phone": "+70368608738"}
0005434725542	3AE84A	8346 664256	YULIYA ANDREEVA	{"phone": "+70138183867"}
0005434725543	5F6060	5278 638000	VASILIY NIKITIN	{"phone": "+70347444548"}
0005434725544	5F6060	9591 146392	LARISA AKIMOVA	{"email": "akimova_l_14071986@postgrespro.ru", "phone": "+70545997590"}
0005434725545	96CD59	9618 844735	IVAN DAVYDOV	{"phone": "+70929809004"}
0005434725546	BEBCA9	2653 411004	BORIS ZAKHAROV	{"email": "zakharov.boris.081977@postgrespro.ru", "phone": "+70356454526"}
0005434725603	20DFC5	6944 173692	IRINA NIKITINA	{"phone": "+70152235961"}
0005434725547	71DAA0	0886 694300	TATYANA KONOVALOVA	{"email": "konovalova-tatyana.21081974@postgrespro.ru", "phone": "+70155437544"}
0005434725548	71DAA0	7428 740172	ILYA ORLOV	{"phone": "+70475470513"}
0005434725549	C50546	2198 453559	BORIS YAKOVLEV	{"email": "b-yakovlev_13031964@postgrespro.ru", "phone": "+70012148124"}
0005434725550	C50546	5763 032218	DMITRIY ROMANOV	{"phone": "+70388396717"}
0005434725551	DBBBC9	1391 777633	ANNA NIKIFOROVA	{"email": "a_nikiforova_12041968@postgrespro.ru", "phone": "+70354490139"}
0005434725552	B0899B	5376 004956	OLGA PETROVA	{"email": "petrova-olga_1965@postgrespro.ru", "phone": "+70427552464"}
0005434725553	A34B58	9704 849006	ALEKSANDR SIDOROV	{"phone": "+70702758056"}
0005434725554	23E9A8	9367 921079	LYUBOV KUZMINA	{"phone": "+70648800908"}
0005434725555	23E9A8	9345 777800	YULIYA KOROLEVA	{"phone": "+70607515778"}
0005434725556	7E28D6	6560 637049	OLGA KONOVALOVA	{"phone": "+70665709156"}
0005434725558	B66D40	8705 399112	DINARA BELYAEVA	{"email": "d.belyaeva_1965@postgrespro.ru", "phone": "+70239614545"}
0005434725559	B66D40	8320 342533	FANIL KARPOV	{"email": "karpov.fanil.071976@postgrespro.ru", "phone": "+70916257517"}
0005434725560	EEC282	4838 374518	OKSANA FADEEVA	{"phone": "+70221115482"}
0005434725561	EEC282	9724 577724	OKSANA IVANOVA	{"email": "ivanovao.101964@postgrespro.ru", "phone": "+70500871301"}
0005434725562	0B4366	0465 094794	NADEZHDA SEMENOVA	{"email": "semenova_n051976@postgrespro.ru", "phone": "+70017048105"}
0005434725563	0B4366	2294 232910	ELENA FEDOROVA	{"email": "fedorova.e1967@postgrespro.ru", "phone": "+70829395043"}
0005434725564	51A904	8715 162405	VLADIMIR KOZLOV	{"email": "kozlov.vladimir-111975@postgrespro.ru", "phone": "+70237928357"}
0005434725565	EF4CDD	5873 063766	EVGENIY ZAKHAROV	{"phone": "+70776743884"}
0005434725566	4A63BE	0342 613250	LYUDMILA VLASOVA	{"phone": "+70830821107"}
0005434725567	3DAB0C	9917 098496	NATALYA KUZNECOVA	{"email": "kuznecova_natalya-1973@postgrespro.ru", "phone": "+70943244815"}
0005434725568	8A53B7	1848 238445	ANDREY RODIONOV	{"phone": "+70204060552"}
0005434725569	9C9482	1679 430703	ALEKSANDR VASILEV	{"email": "aleksandrvasilev.071970@postgrespro.ru", "phone": "+70439234817"}
0005434725570	22693B	4888 816899	ALENA SCHERBAKOVA	{"phone": "+70793373193"}
0005434725571	40D661	1906 763452	ANATOLIY SEMENOV	{"email": "asemenov_1957@postgrespro.ru", "phone": "+70745658020"}
0005434725572	935514	3079 524480	KSENIYA ALEKSANDROVA	{"phone": "+70132301010"}
0005434725573	4B3E4D	4599 376245	TIMOFEY SHEVCHENKO	{"phone": "+70556014822"}
0005434725574	7E4823	4974 567209	ALEKSANDR KUZNECOV	{"email": "akuznecov061978@postgrespro.ru", "phone": "+70571735202"}
0005434725575	63191C	3014 405232	ALEKSANDR KUZNECOV	{"email": "a-kuznecov1983@postgrespro.ru", "phone": "+70404565539"}
0005434725576	CE0DB9	2300 871020	TATYANA KALININA	{"email": "tatyana.kalinina.01081976@postgrespro.ru", "phone": "+70332060684"}
0005434725633	80236D	0229 924699	YANA RODIONOVA	{"phone": "+70327549558"}
0005434725577	51D7C6	1663 452946	SERGEY MAKAROV	{"email": "makarovs-011976@postgrespro.ru", "phone": "+70579451829"}
0005434725578	51D7C6	8577 751105	LYUDMILA VASILEVA	{"email": "l_vasileva.12041980@postgrespro.ru", "phone": "+70024140616"}
0005434725579	B4EBDC	4764 420044	STANISLAV FEDOTOV	{"phone": "+70462585472"}
0005434725580	B4EBDC	3116 008871	GALINA SMIRNOVA	{"email": "galina_smirnova.091977@postgrespro.ru", "phone": "+70137628831"}
0005434725581	ACAEB2	4578 837097	IRINA KOROLEVA	{"phone": "+70811874282"}
0005434725582	A580E1	6920 456573	ALESYA ORLOVA	{"email": "a_orlova1958@postgrespro.ru", "phone": "+70958157684"}
0005434725583	18B691	9792 350011	ANNA ZAKHAROVA	{"phone": "+70985246863"}
0005434725584	F8213B	3142 101242	NATALYA TROFIMOVA	{"phone": "+70035190973"}
0005434725585	CBA04A	1112 972477	VERA YAKOVLEVA	{"email": "vera-yakovleva03101971@postgrespro.ru", "phone": "+70787451300"}
0005434725586	098958	6860 563271	VLADIMIR ZAYCEV	{"email": "zaycev_vladimir.011974@postgrespro.ru", "phone": "+70181435781"}
0005434725587	016DCE	6588 383445	MAKSIM POPOV	{"email": "popov_maksim18011967@postgrespro.ru", "phone": "+70271422868"}
0005434725588	11157A	3520 845812	ALEKSANDR BORISOV	{"phone": "+70258459309"}
0005434725589	105820	5708 818284	TATYANA ORLOVA	{"email": "tatyanaorlova10021972@postgrespro.ru", "phone": "+70678780413"}
0005434725590	105820	7735 712273	VLADIMIR EGOROV	{"email": "vegorov_1959@postgrespro.ru", "phone": "+70025466187"}
0005434725591	4223B5	9861 220500	ELENA ZOTOVA	{"phone": "+70645955885"}
0005434725592	C8060F	5652 860851	ANTONINA KARPOVA	{"email": "karpova_antonina071978@postgrespro.ru", "phone": "+70340515411"}
0005434725593	19A561	5064 720370	VADIM MIRONOV	{"email": "v_mironov_1982@postgrespro.ru", "phone": "+70367306772"}
0005434725594	2D67E5	3936 558363	RUDOLF TIKHONOV	{"email": "r.tikhonov_1966@postgrespro.ru", "phone": "+70993492995"}
0005434725595	62E05C	3172 491859	DENIS MIKHAYLOV	{"phone": "+70986247982"}
0005434725596	62E05C	8309 070938	GENNADIY MOROZOV	{"email": "morozov_g-25121978@postgrespro.ru", "phone": "+70308731277"}
0005434725597	0690E6	1991 110008	ELENA LEBEDEVA	{"email": "lebedeva.e02071978@postgrespro.ru", "phone": "+70484728647"}
0005434725598	8D2A4A	5084 610961	OLGA ABRAMOVA	{"email": "o-abramova-05081962@postgrespro.ru", "phone": "+70547239829"}
0005434725599	0D852D	7527 453649	MARIYA MIKHAYLOVA	{"phone": "+70667776812"}
0005434725600	D63390	0266 106177	YULIYA NESTEROVA	{"email": "y_nesterova.1967@postgrespro.ru", "phone": "+70778541639"}
0005434725601	D63390	1811 062379	ROBERT FEDOTOV	{"email": "robertfedotov-1977@postgrespro.ru", "phone": "+70873838683"}
0005434725604	9D30C3	9895 539675	ELENA VOLKOVA	{"email": "e_volkova_1956@postgrespro.ru", "phone": "+70750631406"}
0005434725605	47BB1F	6844 242297	TATYANA ERMAKOVA	{"phone": "+70560317763"}
0005434725606	EB33D2	0446 836428	SVETLANA GRISHINA	{"email": "grishina-s1973@postgrespro.ru", "phone": "+70058890141"}
0005434725607	0C5708	1939 090356	MARIYA LEBEDEVA	{"email": "lebedeva_mariya-121966@postgrespro.ru", "phone": "+70067425559"}
0005434725608	2B30DB	3624 891858	VIKTOR MELNIKOV	{"phone": "+70845591552"}
0005434725609	42EC03	5745 424864	ALENA TARASOVA	{"email": "alena-tarasova.27061976@postgrespro.ru", "phone": "+70683668109"}
0005434725610	0BE489	6558 837450	ALEKSANDR PAVLOV	{"phone": "+70274304367"}
0005434725611	0BE489	9665 066987	EVGENIY BELOV	{"email": "belov.evgeniy.061960@postgrespro.ru", "phone": "+70991088258"}
0005434725612	0BE489	2806 969609	ALEKSANDR KOROLEV	{"email": "aleksandr-korolev-1961@postgrespro.ru", "phone": "+70191672322"}
0005434725613	0BE489	2042 208425	VLADIMIR VLASOV	{"phone": "+70947395533"}
0005434725614	ED06C0	2310 162053	TATYANA NIKIFOROVA	{"phone": "+70991486253"}
0005434725615	1BA16F	1885 556572	MIKHAIL VASILEV	{"email": "vasilev-mikhail-111977@postgrespro.ru", "phone": "+70265339647"}
0005434725616	1BA16F	7583 410400	ANDREY FROLOV	{"phone": "+70388554386"}
0005434725617	5CA4A0	8535 942383	AYRAT SERGEEV	{"phone": "+70422264718"}
0005434725618	3F3AD8	1594 686739	ELENA ANDREEVA	{"phone": "+70062186787"}
0005434725619	3F3AD8	4904 757811	ELVIRA FEDOROVA	{"email": "fedorova_elvira1977@postgrespro.ru", "phone": "+70994484597"}
0005434725620	9CF6CC	9032 688850	ALEKSEY KUZMIN	{"email": "a-kuzmin.091963@postgrespro.ru", "phone": "+70473794443"}
0005434725621	979330	8387 614134	LYUDMILA GUSEVA	{"email": "guseva-l-02081964@postgrespro.ru", "phone": "+70125408776"}
0005434725622	979330	8573 636585	LARISA OSIPOVA	{"phone": "+70737139536"}
0005434725623	979330	4585 078666	MARIYA KOVALEVA	{"phone": "+70597737749"}
0005434725624	E2238F	7669 005978	ALEKSEY PAVLOV	{"phone": "+70153851018"}
0005434725625	E2238F	3835 475093	INNA STEPANOVA	{"email": "stepanova.i30031970@postgrespro.ru", "phone": "+70618180164"}
0005434725626	4476DE	8104 141124	OLEG NIKITIN	{"phone": "+70281923074"}
0005434725627	4476DE	7373 751472	YULIYA GERASIMOVA	{"phone": "+70614422967"}
0005434725628	BC11BE	4392 556674	NATALYA ZAKHAROVA	{"email": "zakharovan_1973@postgrespro.ru", "phone": "+70795766832"}
0005434725629	BA049C	3270 122206	YURIY TIMOFEEV	{"email": "timofeev-yuriy-14121969@postgrespro.ru", "phone": "+70850907947"}
0005434725630	DF5988	1402 138082	VLADIMIR SERGEEV	{"email": "v-sergeev-051965@postgrespro.ru", "phone": "+70695984597"}
0005434725631	9F2708	9099 626538	LYUBOV NIKOLAEVA	{"phone": "+70292166195"}
0005434725632	80236D	3949 412660	LIDIYA NOVIKOVA	{"phone": "+70557754593"}
0005434725634	704D30	8825 541084	NIKOLAY BORISOV	{"email": "borisov-nikolay-05121974@postgrespro.ru", "phone": "+70639690320"}
0005434725635	704D30	3763 779859	OLGA ZHUKOVA	{"phone": "+70608263342"}
0005434725636	CBE65E	3390 948580	NIKOLAY TIMOFEEV	{"email": "nikolay.timofeev.1976@postgrespro.ru", "phone": "+70130500908"}
0005434725637	CFC46F	4760 520221	LIDIYA ALEKSEEVA	{"email": "alekseeva_lidiya16011973@postgrespro.ru", "phone": "+70253464620"}
0005434725638	CFC46F	9926 941173	ELENA LOGINOVA	{"email": "loginovae.1962@postgrespro.ru", "phone": "+70222127606"}
0005434725639	B8AB07	4098 133757	GALINA ARKHIPOVA	{"phone": "+70658728807"}
0005434725640	B8AB07	5710 983703	YANA STEPANOVA	{"phone": "+70819378855"}
0005434725641	3D81F6	7762 347528	MARIYA NAUMOVA	{"email": "m.naumova_101976@postgrespro.ru", "phone": "+70241801578"}
0005434725642	9A3F15	9674 735170	ALLA BELOVA	{"email": "belova_alla-081977@postgrespro.ru", "phone": "+70444593627"}
0005434725643	8F96D6	6051 659027	OLEG YAKOVLEV	{"phone": "+70885719392"}
0005434725644	EE3D45	4867 713257	ZOYA BELYAEVA	{"email": "z_belyaeva-23041965@postgrespro.ru", "phone": "+70667875759"}
0005434725645	EE3D45	0283 060738	ALEKSANDR MOROZOV	{"email": "a.morozov_1982@postgrespro.ru", "phone": "+70637088474"}
0005434725646	EE3D45	3753 916899	SVETLANA STEPANOVA	{"phone": "+70031759659"}
0005434725647	C166CF	5519 614274	NADEZHDA GRISHINA	{"phone": "+70798692594"}
0005434725648	C166CF	9766 392847	PAVEL KRASNOV	{"email": "pavel_krasnov.021970@postgrespro.ru", "phone": "+70148790629"}
0005434725649	4A15F3	5767 231369	MIKHAIL KULIKOV	{"phone": "+70059713639"}
0005434725650	BDBDC2	8914 660870	TAMARA MIKHAYLOVA	{"email": "tamara.mikhaylova.30051975@postgrespro.ru", "phone": "+70115380750"}
0005434725651	BDBDC2	0665 729054	EKATERINA STEPANOVA	{"phone": "+70875567214"}
0005434725652	8C16CF	5724 404411	ALEKSANDR SMIRNOV	{"phone": "+70745216646"}
0005434725653	043778	5922 623875	TATYANA KULIKOVA	{"phone": "+70122531437"}
0005434725654	CF05EF	1400 329938	ILYA MATVEEV	{"phone": "+70369733089"}
0005434725655	237F30	5311 278776	KRISTINA EFREMOVA	{"phone": "+70708815684"}
0005434725656	D15E00	2598 489078	ELENA EFREMOVA	{"email": "efremova.elena.10031975@postgrespro.ru", "phone": "+70890332912"}
0005434725657	2100E4	8912 128904	ALENA VASILEVA	{"email": "alena.vasileva24041972@postgrespro.ru", "phone": "+70106572491"}
0005434725658	146072	2389 433844	NINA MOISEEVA	{"email": "n_moiseeva-11011975@postgrespro.ru", "phone": "+70173531574"}
0005434725659	2781A5	2891 351289	ROMAN KOROLEV	{"phone": "+70550709975"}
0005434725660	773261	5798 800405	ALEKSEY OSIPOV	{"email": "osipov-a-081972@postgrespro.ru", "phone": "+70449107720"}
0005434725661	BD9C02	9807 971273	IVAN YAKOVLEV	{"email": "ivan-yakovlev.1976@postgrespro.ru", "phone": "+70905929426"}
0005434725662	958418	5988 112173	IRINA SEMENOVA	{"phone": "+70962306186"}
0005434725663	958418	4636 997962	NIKOLAY KUZNECOV	{"email": "nkuznecov1971@postgrespro.ru", "phone": "+70270546022"}
0005434725664	DFCEF9	9126 210749	ALEKSANDR SERGEEV	{"phone": "+70152137190"}
0005434725665	B36065	4433 210795	LIDIYA VLASOVA	{"phone": "+70335512734"}
0005434725666	B36065	3844 852033	OLGA DAVYDOVA	{"email": "olgadavydova-05111975@postgrespro.ru", "phone": "+70777332464"}
0005434725667	9D57F2	6094 956442	PAVEL DENISOV	{"phone": "+70869888723"}
0005434725668	9D57F2	9949 364246	OLEG SOROKIN	{"phone": "+70077193351"}
0005434725669	C2377D	8024 703594	OLGA IVANOVA	{"phone": "+70891195263"}
0005434725670	C2377D	3355 457272	MARIYA SAVELEVA	{"phone": "+70844438261"}
0005434725671	BE3E14	4097 197695	YURIY KUZMIN	{"phone": "+70205640228"}
0005434725672	4AC810	8746 849889	RUSTAM ISAEV	{"phone": "+70668547363"}
0005434725673	4EB3BC	5664 866883	VERA ZOTOVA	{"email": "vzotova-14071970@postgrespro.ru", "phone": "+70466256790"}
0005434725674	4EB3BC	2637 186686	ARTEM IVANOV	{"email": "artem_ivanov_1958@postgrespro.ru", "phone": "+70643007060"}
0005434725675	97B44E	1687 637543	NIKOLAY ALEKSEEV	{"phone": "+70071374864"}
0005434725676	97B44E	7173 176341	MARINA DAVYDOVA	{"phone": "+70182966868"}
0005434725677	DDF0EE	2269 437233	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov-06081973@postgrespro.ru", "phone": "+70186767505"}
0005434725678	DDF0EE	9402 231386	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin071966@postgrespro.ru", "phone": "+70750685206"}
0005434725679	DDF0EE	9546 143753	VALENTINA MEDVEDEVA	{"phone": "+70919279550"}
0005434725680	2978BE	1165 072147	VERA EFIMOVA	{"email": "efimova.v071974@postgrespro.ru", "phone": "+70496502405"}
0005434725681	B38450	3783 307492	VERA EFIMOVA	{"phone": "+70961719239"}
0005434725682	B38450	4096 554173	DMITRIY MIRONOV	{"phone": "+70202042034"}
0005434725683	48EA05	9433 333228	MARIYA POLYAKOVA	{"phone": "+70713267283"}
0005434725684	655DD3	2771 598370	ALEKSANDR IVANOV	{"phone": "+70683466181"}
0005434725685	4B7B8E	2047 325222	SERGEY STEPANOV	{"email": "sergey.stepanov_041977@postgrespro.ru", "phone": "+70812791279"}
0005434725686	52783A	3151 245561	ALEKSEY KULIKOV	{"email": "a_kulikov17041974@postgrespro.ru", "phone": "+70735775383"}
0005434725687	F3E2D0	2120 823973	VIKTOR KUZNECOV	{"phone": "+70613271482"}
0005434725688	F3E2D0	5903 305501	NATALYA PAVLOVA	{"email": "n_pavlova.03071969@postgrespro.ru", "phone": "+70720842396"}
0005434725689	F3E2D0	8788 475197	VYACHESLAV KONOVALOV	{"phone": "+70142424097"}
0005434725690	DD342F	5913 820430	NATALYA ALEKSANDROVA	{"phone": "+70772318759"}
0005434725691	A968AD	6376 448809	YURIY MAKAROV	{"phone": "+70701688452"}
0005434725692	FE55F4	7109 421292	ROMAN VOROBEV	{"email": "vorobev_roman121974@postgrespro.ru", "phone": "+70960672798"}
0005434725693	FE55F4	1769 854693	NATALYA LUKYANOVA	{"email": "lukyanova.n101970@postgrespro.ru", "phone": "+70008687534"}
0005434725694	004A02	8722 043187	IRINA SEMENOVA	{"email": "semenovairina_28091968@postgrespro.ru", "phone": "+70336285167"}
0005434725695	7FA0AB	6272 991852	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr-07061968@postgrespro.ru", "phone": "+70819884163"}
0005434725696	F10690	8834 780298	ALENA ZAKHAROVA	{"email": "a.zakharova18081976@postgrespro.ru", "phone": "+70730240121"}
0005434725697	56474C	2302 037887	MARIYA SOLOVEVA	{"phone": "+70192202871"}
0005434725698	56474C	3605 246370	EDGAR VASILEV	{"email": "vasilevedgar.101971@postgrespro.ru", "phone": "+70143491085"}
0005434725699	562676	0208 865796	KARINA SOKOLOVA	{"phone": "+70658850617"}
0005434725700	80575D	5393 603482	YURIY RODIONOV	{"email": "rodionovy_1981@postgrespro.ru", "phone": "+70897617737"}
0005434725701	80575D	8865 168961	KIRILL SOLOVEV	{"email": "solovev_k_1956@postgrespro.ru", "phone": "+70723302460"}
0005434725702	C81284	0152 392539	MIKHAIL GAVRILOV	{"email": "gavrilov_m-071978@postgrespro.ru", "phone": "+70853416969"}
0005434725703	2FB528	5556 356861	EVGENIY TARASOV	{"email": "tarasov-evgeniy.051977@postgrespro.ru", "phone": "+70974134770"}
0005434725704	68476D	0787 095937	IVAN KUZMIN	{"email": "kuzmin-ivan_1969@postgrespro.ru", "phone": "+70154349033"}
0005434725705	39B3D5	8298 077071	ALEKSANDRA KAZAKOVA	{"email": "aleksandra_kazakova_1976@postgrespro.ru", "phone": "+70522355725"}
0005434725706	C0E054	1503 137386	YULIYA KUZMINA	{"phone": "+70055417776"}
0005434725707	1657ED	2896 037747	NINA KULIKOVA	{"email": "n_kulikova.041965@postgrespro.ru", "phone": "+70900854519"}
0005434725708	91C40A	6884 009098	YULIYA GUSEVA	{"phone": "+70639701914"}
0005434725709	80E4AB	2055 967415	EVGENIY GERASIMOV	{"email": "gerasimove051961@postgrespro.ru", "phone": "+70549188698"}
0005434725710	89F7B7	4005 200948	ANASTASIYA KUDRYASHOVA	{"phone": "+70105745999"}
0005434725711	65E718	7379 358579	ALEKSANDR SAVELEV	{"email": "a.savelev29121964@postgrespro.ru", "phone": "+70431195743"}
0005434725712	755A38	0548 022233	NADEZHDA KUZNECOVA	{"email": "kuznecovan.101969@postgrespro.ru", "phone": "+70445654844"}
0005434725713	E3E5D2	8988 057008	OLGA NIKITINA	{"phone": "+70234286011"}
0005434725714	548475	3998 775883	ELENA KAZAKOVA	{"phone": "+70011746194"}
0005434725715	74EF7A	7093 037542	ANNA LUKYANOVA	{"phone": "+70069398231"}
0005434725716	74EF7A	6245 281288	VYACHESLAV SERGEEV	{"phone": "+70362066663"}
0005434725717	540A40	9526 506692	TATYANA NESTEROVA	{"phone": "+70233587764"}
0005434725718	B1755C	4559 152914	KONSTANTIN ZAKHAROV	{"email": "k-zakharov061967@postgrespro.ru", "phone": "+70812341179"}
0005434725719	62A999	6251 791617	TATYANA STEPANOVA	{"email": "tatyanastepanova04081976@postgrespro.ru", "phone": "+70610333531"}
0005434725720	546B0F	2408 422770	IRINA BELYAEVA	{"email": "belyaeva_i-05051967@postgrespro.ru", "phone": "+70241043694"}
0005434725721	D40973	8432 896425	ZINAIDA ARKHIPOVA	{"email": "arkhipovaz.061979@postgrespro.ru", "phone": "+70239117072"}
0005434725722	8B4005	8990 415465	VIKTORIYA KUZNECOVA	{"email": "kuznecova-viktoriya21111969@postgrespro.ru", "phone": "+70440727719"}
0005434725723	8B4005	8830 046731	SERGEY IVANOV	{"phone": "+70426655963"}
0005434725724	8B4005	9022 876218	VYACHESLAV NAZAROV	{"email": "v_nazarov-021966@postgrespro.ru", "phone": "+70802463432"}
0005434725725	DF94D6	0679 896027	IRINA RODIONOVA	{"email": "i-rodionova.101975@postgrespro.ru", "phone": "+70901688346"}
0005434725726	DF94D6	9027 206423	ALEKSEY BORISOV	{"email": "borisov.aleksey1971@postgrespro.ru", "phone": "+70305377168"}
0005434725727	DB39F7	5441 848886	EMIL DAVYDOV	{"email": "davydov-e.011973@postgrespro.ru", "phone": "+70789291108"}
0005434725728	1C6AA8	1784 225531	SERGEY STEPANOV	{"phone": "+70321863979"}
0005434725729	192D8D	3885 499398	VLADIMIR SMIRNOV	{"phone": "+70966551574"}
0005434725730	192D8D	7116 033389	VYACHESLAV ZHURAVLEV	{"email": "zhuravlevvyacheslav.1972@postgrespro.ru", "phone": "+70424421280"}
0005434725731	51ABFA	4063 980474	VIKTOR DENISOV	{"email": "viktor-denisov_111972@postgrespro.ru", "phone": "+70321912556"}
0005434725732	FB57F5	0571 785750	STANISLAV FEDOTOV	{"email": "sfedotov.1968@postgrespro.ru", "phone": "+70723068404"}
0005434725733	FB57F5	7284 237910	IRINA BELOVA	{"email": "belova-i_1965@postgrespro.ru", "phone": "+70839825888"}
0005434725734	77FE01	0739 130393	IRINA VLASOVA	{"phone": "+70707288578"}
0005434725735	E894DB	1005 811784	IRINA MAKSIMOVA	{"phone": "+70270593964"}
0005434725736	E894DB	5424 803689	VASILIY BORISOV	{"phone": "+70506021671"}
0005434725737	618B42	0349 130309	ANATOLIY POPOV	{"phone": "+70644710287"}
0005434725738	618B42	4728 897147	VLADIMIR BORISOV	{"email": "v.borisov.111976@postgrespro.ru", "phone": "+70008961934"}
0005434725739	618B42	7140 209504	LYUBOV MALYSHEVA	{"phone": "+70732708200"}
0005434725740	618B42	4392 349974	VITALIY DENISOV	{"phone": "+70458918594"}
0005434725741	8F907B	0450 601087	LYUBOV KOROLEVA	{"email": "l.koroleva02121974@postgrespro.ru", "phone": "+70236609903"}
0005434725742	4D0CCE	0534 367606	EKATERINA MELNIKOVA	{"email": "e.melnikova041990@postgrespro.ru", "phone": "+70703344157"}
0005434725743	76DC85	2854 900605	ILYA FEDOROV	{"email": "i-fedorov.19061968@postgrespro.ru", "phone": "+70854387768"}
0005434725744	36DBBF	4200 722373	ALEKSEY SCHERBAKOV	{"phone": "+70157756869"}
0005434725745	36DBBF	7690 639541	ANASTASIYA TROFIMOVA	{"email": "trofimova-a1964@postgrespro.ru", "phone": "+70200744522"}
0005434725746	36DBBF	5227 820616	YANA SEMENOVA	{"phone": "+70769192539"}
0005434725747	F8BAA3	8949 979479	ANDREY CHERNOV	{"phone": "+70977485517"}
0005434725748	F8BAA3	4991 840036	MARIYA NIKOLAEVA	{"phone": "+70632470209"}
0005434725749	BECA1B	9990 696057	EVGENIY MATVEEV	{"phone": "+70610637126"}
0005434725750	CD5EBA	4525 869911	ALEKSEY MELNIKOV	{"phone": "+70676167232"}
0005434725751	B0DF70	6158 344483	NINA VOLKOVA	{"email": "volkova_n_051967@postgrespro.ru", "phone": "+70249517609"}
0005434725752	57BAEA	4861 203713	KARINA ANDREEVA	{"email": "andreeva-k_081973@postgrespro.ru", "phone": "+70739745407"}
0005434725753	B9F3C2	1244 630202	MIKHAIL KOZLOV	{"email": "kozlov_m_1967@postgrespro.ru", "phone": "+70690503292"}
0005434725754	B76C2C	5508 277852	TATYANA CHERNOVA	{"email": "chernova-t-16111957@postgrespro.ru", "phone": "+70796963757"}
0005434725755	B76C2C	9105 126258	GENNADIY GUSEV	{"phone": "+70853435215"}
0005434725756	2FC286	0120 488965	YULIYA YUDINA	{"phone": "+70914181116"}
0005434725757	0DE525	9493 777050	MARIYA ZHURAVLEVA	{"phone": "+70861648277"}
0005434725758	5689C8	1091 331598	ELENA IVANOVA	{"email": "elena_ivanova-1983@postgrespro.ru", "phone": "+70777881589"}
0005434725759	9FF316	8006 397679	SVETLANA MARTYNOVA	{"email": "svetlana_martynova29071968@postgrespro.ru", "phone": "+70161823570"}
0005434725760	9FF316	5895 914723	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova-25051964@postgrespro.ru", "phone": "+70238863423"}
0005434725761	097F63	6211 394064	NINA DANILOVA	{"email": "n-danilova_1967@postgrespro.ru", "phone": "+70342603833"}
0005434725762	097F63	3785 405683	IDA DMITRIEVA	{"phone": "+70095924801"}
0005434725763	D9E0B4	9165 128817	SERGEY BELOV	{"email": "belov_sergey22041968@postgrespro.ru", "phone": "+70909872434"}
0005434725764	6C3F28	6041 991773	VIKTORIYA KONOVALOVA	{"phone": "+70789573101"}
0005434725765	584EBB	6328 137439	NINA SEMENOVA	{"phone": "+70682972141"}
0005434725766	F59CCC	6336 799467	TATYANA ZHURAVLEVA	{"phone": "+70086752393"}
0005434725767	85C8B6	9295 751594	DMITRIY KUZNECOV	{"phone": "+70792212415"}
0005434725768	85C8B6	3245 258429	EVGENIY FOMIN	{"email": "e_fomin-14011980@postgrespro.ru", "phone": "+70051750975"}
0005434725769	43D406	0980 561883	VENERA DAVYDOVA	{"email": "v_davydova_051979@postgrespro.ru", "phone": "+70628767650"}
0005434725770	318D81	0616 524586	EKATERINA MAKAROVA	{"email": "e_makarova.021974@postgrespro.ru", "phone": "+70205385471"}
0005434725771	318D81	9430 334149	EVGENIY SCHERBAKOV	{"email": "scherbakov-evgeniy_1981@postgrespro.ru", "phone": "+70231526760"}
0005434725772	318D81	7761 554303	ALEKSEY VOROBEV	{"phone": "+70499256682"}
0005434725884	9D5B22	1729 328978	DINARA KOVALEVA	{"phone": "+70088375235"}
0005434725773	318D81	0371 620775	TATYANA KOMAROVA	{"email": "komarova.tatyana-08071972@postgrespro.ru", "phone": "+70860178307"}
0005434725774	3E7F15	4434 712512	DMITRIY KUZMIN	{"phone": "+70103321883"}
0005434725775	625012	1705 786982	MIKHAIL SEMENOV	{"email": "mikhail-semenov-1965@postgrespro.ru", "phone": "+70430302657"}
0005434725776	2293E9	2721 618893	ZAKHAR ISAEV	{"phone": "+70287177190"}
0005434725777	93ECD1	1199 880789	VYACHESLAV KUZNECOV	{"email": "kuznecovv1964@postgrespro.ru", "phone": "+70093296627"}
0005434725778	93ECD1	2509 424017	KIRILL AFANASEV	{"phone": "+70258027182"}
0005434725779	712993	2715 819956	ANATOLIY IVANOV	{"email": "anatoliy.ivanov_25111964@postgrespro.ru", "phone": "+70870450934"}
0005434725780	C396C2	9789 158759	OLGA SIDOROVA	{"email": "olga-sidorova.1968@postgrespro.ru", "phone": "+70060927347"}
0005434725781	A8571E	9863 455742	NADEZHDA YUDINA	{"email": "yudina.nadezhda_071961@postgrespro.ru", "phone": "+70430361800"}
0005434725782	196EF1	8069 230186	OLGA ALEKSEEVA	{"phone": "+70876987608"}
0005434725783	196EF1	3988 719930	NIKOLAY DENISOV	{"email": "denisov-n.091964@postgrespro.ru", "phone": "+70481397669"}
0005434725784	196EF1	0499 970792	ANATOLIY AFANASEV	{"email": "afanasev_a.18091970@postgrespro.ru", "phone": "+70356016705"}
0005434725785	9BD9C3	7713 994120	IRINA FEDOROVA	{"email": "fedorova_i.091982@postgrespro.ru", "phone": "+70591556929"}
0005434725786	DB6A8B	0617 099427	VERA BELYAEVA	{"email": "v_belyaeva_17061975@postgrespro.ru", "phone": "+70623543060"}
0005434725787	9C5514	0728 929782	NATALYA TIMOFEEVA	{"phone": "+70336658287"}
0005434725788	9D7383	8608 022809	KLAVDIYA SIDOROVA	{"phone": "+70931509298"}
0005434725789	9D7383	5118 647815	IGOR KUZNECOV	{"phone": "+70671207893"}
0005434725790	3A99F7	7383 478394	MARIYA OVCHINNIKOVA	{"email": "mariya_ovchinnikova.1970@postgrespro.ru", "phone": "+70409208546"}
0005434725791	00B44B	5959 392633	VITALIY POPOV	{"phone": "+70271589170"}
0005434725792	833EF7	9216 434829	EVGENIY SIDOROV	{"phone": "+70515985875"}
0005434725793	DE446C	4842 659641	YULIYA SOKOLOVA	{"email": "yuliya.sokolova_15061976@postgrespro.ru", "phone": "+70535055771"}
0005434725794	DE446C	1043 798430	MARINA ZAKHAROVA	{"phone": "+70875726592"}
0005434725795	F54F2D	0326 370766	EVGENIY NIKOLAEV	{"email": "evgeniy_nikolaev_09061962@postgrespro.ru", "phone": "+70039421335"}
0005434725796	EB86C6	9706 621011	NADEZHDA NAZAROVA	{"email": "nazarova.n-061971@postgrespro.ru", "phone": "+70411593159"}
0005434725797	A36C13	1648 186838	YULIYA ALEKSANDROVA	{"email": "aleksandrova.yuliya.011967@postgrespro.ru", "phone": "+70350255003"}
0005434725798	C9566A	6336 931400	TATYANA KUDRYASHOVA	{"phone": "+70877997722"}
0005434725799	DF21E5	8391 350704	ANNA KUZNECOVA	{"email": "kuznecovaanna-1969@postgrespro.ru", "phone": "+70338873865"}
0005434725800	8F2DD6	6104 290234	ALEKSANDR ORLOV	{"phone": "+70909608594"}
0005434725801	8F2DD6	8437 131097	NINA MATVEEVA	{"phone": "+70187163759"}
0005434725802	29BEFF	7519 330511	YANA GERASIMOVA	{"email": "gerasimova.y111978@postgrespro.ru", "phone": "+70339872953"}
0005434725803	A4B951	8186 475086	RAFAEL KAZAKOV	{"phone": "+70161234305"}
0005434725804	F44F3B	0547 479170	MARIYA YUDINA	{"email": "yudina.mariya_1967@postgrespro.ru", "phone": "+70409789204"}
0005434725805	4A9CDD	0670 387648	IGOR BELOV	{"email": "belov.igor_051962@postgrespro.ru", "phone": "+70601883466"}
0005434725806	9A5AAE	3354 451524	TAISIYA KOROLEVA	{"email": "taisiyakoroleva10041974@postgrespro.ru", "phone": "+70394952357"}
0005434725807	24484D	7218 255471	VIKTOR ZAYCEV	{"email": "zaycevviktor.1971@postgrespro.ru", "phone": "+70181130518"}
0005434725808	565F7B	5168 383416	IVAN FEDOTOV	{"email": "ivan-fedotov.1959@postgrespro.ru", "phone": "+70048249826"}
0005434725809	565F7B	8409 746219	VALENTINA FROLOVA	{"email": "valentinafrolova24111964@postgrespro.ru", "phone": "+70029223946"}
0005434725810	565F7B	7298 445148	YURIY POPOV	{"phone": "+70925104864"}
0005434725811	0EBE48	8344 166014	TATYANA ANISIMOVA	{"phone": "+70434563282"}
0005434725812	8ABC42	7438 887021	TATYANA SAVELEVA	{"email": "saveleva_tatyana_1973@postgrespro.ru", "phone": "+70917892359"}
0005434725813	8ABC42	9545 321980	NADEZHDA PAVLOVA	{"email": "nadezhda_pavlova03051982@postgrespro.ru", "phone": "+70101177849"}
0005434725814	DBA67E	0488 930544	PAVEL KOROLEV	{"email": "korolev-p.081968@postgrespro.ru", "phone": "+70370255609"}
0005434725815	DBA67E	1571 115046	LEONID ZAKHAROV	{"email": "l.zakharov.03111977@postgrespro.ru", "phone": "+70030427523"}
0005434725816	60EB43	9754 468695	DANILA VLASOV	{"email": "danilavlasov.13021984@postgrespro.ru", "phone": "+70513297555"}
0005434725817	357CFB	1812 670779	RINAT ABRAMOV	{"email": "abramovr-1967@postgrespro.ru", "phone": "+70011564779"}
0005434725818	357CFB	5606 973746	YURIY ORLOV	{"email": "yuriyorlov-1971@postgrespro.ru", "phone": "+70274604469"}
0005434725819	24B84D	9731 276360	NIKOLAY KRASNOV	{"phone": "+70138239637"}
0005434725820	24B84D	6220 451453	ANDREY MOISEEV	{"email": "moiseev_andrey29101967@postgrespro.ru", "phone": "+70509391428"}
0005434725821	826771	4622 492914	PETR MATVEEV	{"email": "pmatveev1967@postgrespro.ru", "phone": "+70515358079"}
0005434725822	590E5D	5829 623076	VIKTOR STEPANOV	{"phone": "+70000091691"}
0005434725823	590E5D	4022 481751	ELENA ALEKSEEVA	{"email": "alekseeva-elena_061976@postgrespro.ru", "phone": "+70887767371"}
0005434725824	5CAD33	5996 974424	IRINA DENISOVA	{"email": "denisova_i_03091979@postgrespro.ru", "phone": "+70015016928"}
0005434725825	5CAD33	5276 019404	VIKTOR KUZNECOV	{"email": "kuznecov_viktor.081977@postgrespro.ru", "phone": "+70024358858"}
0005434725826	5CAD33	7592 596544	ALEKSEY SIDOROV	{"phone": "+70627081361"}
0005434725827	AE5CA5	6778 387406	ANASTASIYA KOVALEVA	{"email": "kovaleva-anastasiya1981@postgrespro.ru", "phone": "+70841448512"}
0005434725828	4F6865	0122 213021	EVGENIY ORLOV	{"email": "orlov-evgeniy1954@postgrespro.ru", "phone": "+70567460798"}
0005434725829	E11EFB	4372 434215	EDUARD MAKSIMOV	{"phone": "+70759194988"}
0005434725830	E11EFB	9396 081437	ANTON KISELEV	{"phone": "+70141554783"}
0005434725831	97ADC3	8632 125600	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr.08121972@postgrespro.ru", "phone": "+70690555242"}
0005434725832	CC5CF2	1723 570236	GENNADIY ORLOV	{"phone": "+70871596072"}
0005434725833	CC5CF2	9646 682719	IRINA PETROVA	{"phone": "+70813758649"}
0005434725834	286FD8	9135 702395	ELENA ILINA	{"email": "elena_ilina-1966@postgrespro.ru", "phone": "+70768321132"}
0005434725835	286FD8	1531 511678	EVGENIY KOZLOV	{"phone": "+70543438627"}
0005434725836	3310B3	1497 806678	ELENA GAVRILOVA	{"phone": "+70896679347"}
0005434725837	6B7F97	5057 087494	LARISA ILINA	{"phone": "+70003315407"}
0005434725838	1FDA41	2366 634667	VLADIMIR PETROV	{"phone": "+70483151605"}
0005434725839	817994	8646 705746	SVETLANA LAZAREVA	{"email": "svetlana.lazareva.22061968@postgrespro.ru", "phone": "+70556018336"}
0005434725840	7FC041	7691 791606	GALINA KULIKOVA	{"phone": "+70087665380"}
0005434725841	7FC041	1970 914927	ALEKSANDR POPOV	{"email": "aleksandr.popov041978@postgrespro.ru", "phone": "+70671616741"}
0005434725842	D61864	1180 724880	LYUDMILA SEMENOVA	{"email": "semenova_lyudmila_1958@postgrespro.ru", "phone": "+70246903973"}
0005434725843	D61864	0099 981854	YURIY VASILEV	{"phone": "+70781544144"}
0005434725844	C94147	7929 932580	ALEKSEY GRIGOREV	{"phone": "+70128139819"}
0005434725845	2A3126	8572 200334	SERGEY SERGEEV	{"phone": "+70599035986"}
0005434725846	2A3126	8439 233149	IRINA PAVLOVA	{"email": "pavlova-i.21051973@postgrespro.ru", "phone": "+70166651832"}
0005434725847	454686	9649 147535	ELENA POPOVA	{"email": "elenapopova_1961@postgrespro.ru", "phone": "+70364076249"}
0005434725848	454686	5190 727749	IRINA PAVLOVA	{"email": "irina_pavlova121969@postgrespro.ru", "phone": "+70888262466"}
0005434725849	255440	7649 588083	KIRILL STEPANOV	{"email": "stepanov_kirill_29111979@postgrespro.ru", "phone": "+70198822362"}
0005434725850	004B7B	7988 186528	NINA IVANOVA	{"phone": "+70224070843"}
0005434725851	004B7B	7239 351114	VLADIMIR MAKSIMOV	{"email": "maksimov.vladimir_11091977@postgrespro.ru", "phone": "+70687399760"}
0005434725852	A5A7E1	5375 722385	MIKHAIL FROLOV	{"email": "mikhail.frolov.1987@postgrespro.ru", "phone": "+70561670632"}
0005434725853	7B8087	9135 435572	LARISA BOGDANOVA	{"email": "lbogdanova15041967@postgrespro.ru", "phone": "+70719225770"}
0005434725854	5C7116	7415 654299	ELENA CHERNOVA	{"phone": "+70114423553"}
0005434725855	5C7116	8846 657301	ANASTASIYA FILIPPOVA	{"email": "filippovaanastasiya_28041968@postgrespro.ru", "phone": "+70246443190"}
0005434725856	05CCF8	7322 029818	LYUDMILA PAVLOVA	{"email": "lyudmila.pavlova08111969@postgrespro.ru", "phone": "+70450289480"}
0005434725857	177846	3518 064127	IVAN KUZMIN	{"email": "ikuzmin.1966@postgrespro.ru", "phone": "+70183029503"}
0005434725858	0DE7DA	7046 419688	IVAN SMIRNOV	{"email": "i_smirnov-06021978@postgrespro.ru", "phone": "+70688679413"}
0005434725859	0DE7DA	6007 690731	VERONIKA BELOVA	{"phone": "+70324303907"}
0005434725860	0DE7DA	5330 484623	ANATOLIY BONDARENKO	{"phone": "+70802393280"}
0005434725861	EBDDEA	6900 874331	VERA NIKIFOROVA	{"phone": "+70949679123"}
0005434725862	EBDDEA	7673 264800	MARINA FOMINA	{"email": "m.fomina-031970@postgrespro.ru", "phone": "+70666544155"}
0005434725863	2EA7CD	0774 647559	MILENA MAKAROVA	{"email": "m-makarova-12021974@postgrespro.ru", "phone": "+70304234084"}
0005434725864	B6148F	0848 825283	ANDREY YAKOVLEV	{"email": "a-yakovlev-1977@postgrespro.ru", "phone": "+70052581495"}
0005434725865	B6148F	7340 707712	VLADIMIR KRASNOV	{"email": "krasnov_vladimir1983@postgrespro.ru", "phone": "+70630636146"}
0005434725866	7942BE	4654 252725	YURIY GERASIMOV	{"phone": "+70165410855"}
0005434725867	7942BE	3924 080403	NADEZHDA FEDOROVA	{"email": "nadezhda-fedorova-061980@postgrespro.ru", "phone": "+70761904571"}
0005434725868	49B461	7119 237289	TATYANA KARPOVA	{"email": "karpova_t1974@postgrespro.ru", "phone": "+70037227452"}
0005434725869	49B461	3684 955061	VYACHESLAV MATVEEV	{"phone": "+70560774121"}
0005434725870	C8DE50	0450 659807	ALEKSEY ROMANOV	{"email": "aromanov_01021971@postgrespro.ru", "phone": "+70240707194"}
0005434725871	1FF712	5878 253586	SERGEY MAKAROV	{"phone": "+70326388020"}
0005434725872	1FF712	3967 111538	KSENIYA TIMOFEEVA	{"email": "timofeeva-kseniya.1968@postgrespro.ru", "phone": "+70047607410"}
0005434725873	7D5174	6940 037373	VALENTINA VASILEVA	{"phone": "+70015165012"}
0005434725874	7D5174	7697 126425	NIKOLAY DAVYDOV	{"phone": "+70014084530"}
0005434725875	9B2B61	8556 664066	LYUDMILA SOLOVEVA	{"email": "lyudmila_soloveva.1974@postgrespro.ru", "phone": "+70352463521"}
0005434725876	9B2B61	6210 718909	VALENTINA KULIKOVA	{"email": "kulikova_valentina.16111977@postgrespro.ru", "phone": "+70742112638"}
0005434725877	B91707	7992 958907	YULIYA KUDRYASHOVA	{"phone": "+70402499520"}
0005434725878	146734	9307 651563	NIKITA FOMIN	{"phone": "+70242979241"}
0005434725879	146734	7501 620226	EKATERINA ZHUKOVA	{"email": "e.zhukova.15111979@postgrespro.ru", "phone": "+70033556944"}
0005434725880	D11593	2903 468832	SVETLANA FADEEVA	{"email": "s_fadeeva_121979@postgrespro.ru", "phone": "+70285729851"}
0005434725881	D11593	2438 561067	FARID PETROV	{"phone": "+70810434225"}
0005434725882	12FEBF	2081 789987	IRINA SMIRNOVA	{"phone": "+70638118740"}
0005434725883	E370E7	9424 369568	MARIYA DENISOVA	{"phone": "+70891732366"}
0005434725885	A48A2D	5523 441413	TAMARA MOROZOVA	{"email": "tamara-morozova-29041972@postgrespro.ru", "phone": "+70239221378"}
0005434725886	CD80B3	5063 495494	ALEKSANDRA GUSEVA	{"email": "gusevaa.121979@postgrespro.ru", "phone": "+70297554185"}
0005434725887	28B366	8507 285128	VIKTOR KUZNECOV	{"phone": "+70737367919"}
0005434725888	5938E3	4829 729611	MAKSIM BELOV	{"phone": "+70236779956"}
0005434725889	A7C4EB	1243 469317	ZOYA ZOTOVA	{"phone": "+70820138524"}
0005434725890	A7C4EB	4571 160508	GUZEL DENISOVA	{"email": "guzeldenisova.1977@postgrespro.ru", "phone": "+70813613711"}
0005434725891	0D61B0	0781 085865	LYUDMILA IVANOVA	{"phone": "+70975743219"}
0005434725892	D7AECD	2028 514177	BORIS VASILEV	{"phone": "+70268370541"}
0005434725893	063046	3246 352989	RAISA DAVYDOVA	{"email": "davydova.r_19071969@postgrespro.ru", "phone": "+70048955162"}
0005434725894	063046	8810 932096	SERGEY SMIRNOV	{"email": "smirnov_s.09041969@postgrespro.ru", "phone": "+70069120928"}
0005434725895	253FBC	3300 084101	VIKTOR IVANOV	{"email": "ivanov_viktor-051979@postgrespro.ru", "phone": "+70768483733"}
0005434725896	4DB5EA	4223 815046	IGOR MOROZOV	{"phone": "+70613362806"}
0005434725897	4DB5EA	0880 799870	ALI SERGEEV	{"phone": "+70828833443"}
0005434725898	1D2712	9473 179808	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.121984@postgrespro.ru", "phone": "+70584637215"}
0005434725899	16C201	2128 331610	LYUDMILA ROMANOVA	{"email": "lyudmilaromanova.12111968@postgrespro.ru", "phone": "+70439069293"}
0005434725900	685C8D	9521 777701	FEDOR SEMENOV	{"phone": "+70160243311"}
0005434725901	2B5C42	9173 403129	YURIY KAZAKOV	{"email": "kazakov-y_051969@postgrespro.ru", "phone": "+70717216447"}
0005434725902	93D38B	1851 759060	MARIYA IVANOVA	{"phone": "+70066857912"}
0005434725903	64AE78	9428 642687	ELENA KARPOVA	{"email": "e-karpova1964@postgrespro.ru", "phone": "+70922690897"}
0005434725904	64AE78	6737 231519	VYACHESLAV FEDOROV	{"email": "vyacheslavfedorov-071967@postgrespro.ru", "phone": "+70542993494"}
0005434725905	1C039F	2373 329549	NATALYA IVANOVA	{"email": "natalya_ivanova-1959@postgrespro.ru", "phone": "+70387279971"}
0005434725906	BFC3D6	7887 280134	IVAN SOKOLOV	{"email": "i.sokolov1966@postgrespro.ru", "phone": "+70609613715"}
0005434725907	66AB54	6016 327126	KLAVDIYA VASILEVA	{"phone": "+70085160883"}
0005434725908	66AB54	0341 863574	NATALIYA NOVIKOVA	{"phone": "+70371514451"}
0005434725909	8BF488	3439 707413	VLADIMIR DAVYDOV	{"email": "vladimir-davydov-1976@postgrespro.ru", "phone": "+70648183963"}
0005434725910	CBC702	5308 424272	ALEKSANDR BORISOV	{"phone": "+70669546268"}
0005434725911	C9D80B	4568 971485	ANNA SMIRNOVA	{"phone": "+70038580056"}
0005434725912	C9D80B	4657 512217	ANTONINA KOROLEVA	{"phone": "+70153756980"}
0005434725913	AA980C	1178 502979	IVAN KUZMIN	{"email": "kuzmin.i1964@postgrespro.ru", "phone": "+70559570871"}
0005434725914	AB413E	7975 665735	NINA SEMENOVA	{"email": "n-semenova1975@postgrespro.ru", "phone": "+70344932857"}
0005434725915	95D09C	7635 172605	LYUBOV SEMENOVA	{"email": "lyubov_semenova.1970@postgrespro.ru", "phone": "+70059184555"}
0005434725916	E3F423	0999 964853	LARISA SOKOLOVA	{"phone": "+70165768308"}
0005434725917	E3F423	1219 759232	ELENA MOROZOVA	{"email": "morozova-e_061960@postgrespro.ru", "phone": "+70396708747"}
0005434725918	EAB819	6064 788468	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr.13121982@postgrespro.ru", "phone": "+70824664689"}
0005434725919	F8D3F6	9861 393041	ALEKSANDR TIMOFEEV	{"email": "a_timofeev101980@postgrespro.ru", "phone": "+70707445950"}
0005434725920	C71929	8155 750271	IVAN TIKHONOV	{"phone": "+70142357487"}
0005434725921	22C03F	4892 356456	VYACHESLAV SOKOLOV	{"phone": "+70584693271"}
0005434725922	7712D7	4393 346165	EKATERINA ILINA	{"phone": "+70878691598"}
0005434725923	B2E170	7498 295153	NATALYA YAKOVLEVA	{"email": "n.yakovleva-15091976@postgrespro.ru", "phone": "+70479577733"}
0005434725924	B2E170	7049 131569	SERGEY STEPANOV	{"email": "stepanov_sergey_20031979@postgrespro.ru", "phone": "+70983829760"}
0005434725925	E05E45	4935 154660	LYUDMILA KUZMINA	{"phone": "+70332515292"}
0005434725926	1DFF82	8463 748867	YURIY MAKAROV	{"email": "y-makarov121972@postgrespro.ru", "phone": "+70361391429"}
0005434725927	BADA50	7617 747162	VLADIMIR YAKOVLEV	{"phone": "+70494830852"}
0005434725928	A4FA80	8945 495548	IRINA YUDINA	{"phone": "+70748081395"}
0005434725929	A4FA80	3583 613172	SERGEY ZAYCEV	{"phone": "+70241963495"}
0005434725930	0AA3DF	8506 685492	OKSANA KUZNECOVA	{"phone": "+70802137985"}
0005434725931	060723	3085 520515	TAISIYA NIKOLAEVA	{"phone": "+70869820876"}
0005434725932	D74BD4	0324 899029	ALEKSANDR ANTONOV	{"email": "aantonov.1966@postgrespro.ru", "phone": "+70903322003"}
0005434725933	D74BD4	2186 555349	FAINA TIMOFEEVA	{"phone": "+70490743174"}
0005434725934	1247CA	7565 535904	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov.031973@postgrespro.ru", "phone": "+70117107363"}
0005434725935	0E0AF3	6357 443992	MATVEY NIKITIN	{"email": "m_nikitin_1978@postgrespro.ru", "phone": "+70291660045"}
0005434725936	0E0AF3	7251 573410	MARIYA KOMAROVA	{"email": "mkomarova27091963@postgrespro.ru", "phone": "+70817009271"}
0005434725937	747868	2621 481596	NATALYA AKIMOVA	{"phone": "+70840877801"}
0005434725938	9258C6	0794 922816	KRISTINA ARKHIPOVA	{"email": "k-arkhipova-1970@postgrespro.ru", "phone": "+70887801927"}
0005434725939	320D22	0605 048840	VALENTIN FEDOTOV	{"phone": "+70800787099"}
0005434725940	320D22	5773 262377	LYUDMILA ROMANOVA	{"email": "romanova_lyudmila_28021984@postgrespro.ru", "phone": "+70486315118"}
0005434725941	320D22	3320 180650	VLADIMIR ZAYCEV	{"phone": "+70108135714"}
0005434725942	15BA93	5124 791747	TAMARA TITOVA	{"phone": "+70446518673"}
0005434725943	FBEB32	1631 367133	VLADIMIR ALEKSEEV	{"email": "v.alekseev-031972@postgrespro.ru", "phone": "+70562786501"}
0005434725944	398D15	2399 718577	EKATERINA SOROKINA	{"email": "sorokina_ekaterina_1982@postgrespro.ru", "phone": "+70209463097"}
0005434725945	BB8ED3	2315 566927	ALEKSEY VOROBEV	{"phone": "+70495669188"}
0005434725946	BB8ED3	4108 689379	MARIYA AKIMOVA	{"phone": "+70500676601"}
0005434725947	4312DC	0097 232183	DENIS MOROZOV	{"phone": "+70532607639"}
0005434725948	C469F3	2715 504338	EGOR MOROZOV	{"email": "morozov-e.08061958@postgrespro.ru", "phone": "+70083552062"}
0005434725949	C469F3	1851 573421	MARIYA KUZNECOVA	{"phone": "+70951094866"}
0005434725950	AA3ED2	5486 948623	ALEKSANDR FILIPPOV	{"phone": "+70427766719"}
0005434725951	AA3ED2	4135 587292	ANNA DENISOVA	{"email": "denisova.a-101971@postgrespro.ru", "phone": "+70629629360"}
0005434725952	813CBE	4919 307198	MARIYA VOROBEVA	{"email": "vorobeva_mariya.1968@postgrespro.ru", "phone": "+70684617621"}
0005434725953	F59F70	1209 673953	PAVEL KOROLEV	{"phone": "+70269084681"}
0005434725954	E62CC6	1250 667756	ALEVTINA GAVRILOVA	{"phone": "+70334599715"}
0005434725955	7F5C5E	3984 986964	FATIMA STEPANOVA	{"phone": "+70858330722"}
0005434725956	251DFA	7457 198651	ANTONINA FILATOVA	{"email": "antonina_filatova1974@postgrespro.ru", "phone": "+70737113842"}
0005434725957	CD3579	6655 982047	EVGENIYA NIKOLAEVA	{"phone": "+70148534617"}
0005434725958	1F4EFE	0459 199244	IRINA LOGINOVA	{"email": "loginova.i_18101968@postgrespro.ru", "phone": "+70139789583"}
0005434725959	1F4EFE	3136 431968	ALEKSANDR KUDRYASHOV	{"email": "aleksandr-kudryashov071974@postgrespro.ru", "phone": "+70287358134"}
0005434725960	1720A4	7014 287627	NATALYA ANTONOVA	{"email": "n_antonova05101983@postgrespro.ru", "phone": "+70098456184"}
0005434725961	6B9CA1	2795 302825	ZOYA KUZMINA	{"email": "kuzmina.z_021971@postgrespro.ru", "phone": "+70278945918"}
0005434725962	5FDF15	6341 281510	SERGEY MOROZOV	{"email": "morozov-s-24101972@postgrespro.ru", "phone": "+70500252320"}
0005434725963	5FDF15	9453 536044	SERGEY MOISEEV	{"email": "s-moiseev-1967@postgrespro.ru", "phone": "+70251120267"}
0005434725964	F516CE	1340 428304	KLAVDIYA ZOTOVA	{"email": "zotova.klavdiya_21061981@postgrespro.ru", "phone": "+70796358438"}
0005434725965	E03589	3544 587526	SVETLANA NIKOLAEVA	{"phone": "+70176337987"}
0005434725966	C5086E	2277 687118	ALEKSANDR DENISOV	{"email": "aleksandr_denisov1965@postgrespro.ru", "phone": "+70050351575"}
0005434725967	E3CAA5	1686 950503	GALINA ZAYCEVA	{"email": "zaycevag_081975@postgrespro.ru", "phone": "+70039793335"}
0005434725968	114569	9470 329772	ALEKSEY SERGEEV	{"email": "a.sergeev.101987@postgrespro.ru", "phone": "+70109872189"}
0005434725969	195CD6	4606 719182	TATYANA NOVIKOVA	{"phone": "+70118924424"}
0005434725970	EC9DC4	5367 292798	ARSENIY PAVLOV	{"phone": "+70725439889"}
0005434725971	EC9DC4	9952 936080	DMITRIY KONOVALOV	{"phone": "+70551019126"}
0005434725972	8CCBF2	1374 958350	TIMOFEY ANTONOV	{"email": "antonov_timofey-21051981@postgrespro.ru", "phone": "+70815075328"}
0005434725973	8CCBF2	8887 300863	ALEKSANDR GAVRILOV	{"phone": "+70039503744"}
0005434725974	FCCCDA	7246 309951	TATYANA GORBUNOVA	{"phone": "+70383896538"}
0005434725975	FCCCDA	8655 450609	PAVEL BARANOV	{"email": "pavel_baranov071978@postgrespro.ru", "phone": "+70676630457"}
0005434725976	FCCCDA	8082 635634	ALEKSEY SIDOROV	{"phone": "+70197070343"}
0005434725977	E5A555	4579 441161	TATYANA ABRAMOVA	{"phone": "+70491016912"}
0005434726098	626501	2985 780596	ALEKSEY VASILEV	{"phone": "+70161538833"}
0005434725978	EDEB31	3369 475045	ANASTASIYA CHERNOVA	{"email": "achernova_1968@postgrespro.ru", "phone": "+70897830618"}
0005434725979	FA7028	6794 940154	ANATOLIY VOLKOV	{"phone": "+70614576038"}
0005434725980	FF6B9C	1055 137038	VIKTOR KISELEV	{"phone": "+70350824219"}
0005434725981	D6C46B	9364 212918	ELENA ALEKSANDROVA	{"email": "aleksandrova-elena-1984@postgrespro.ru", "phone": "+70259022121"}
0005434725982	D6C46B	7676 697470	NADEZHDA SOKOLOVA	{"phone": "+70758334350"}
0005434725983	CC85AA	2804 343105	DIANA MARTYNOVA	{"email": "martynovadiana.081986@postgrespro.ru", "phone": "+70846621203"}
0005434725984	CC85AA	8650 389634	BORIS SOLOVEV	{"phone": "+70035838183"}
0005434725985	CC85AA	8927 631792	ARTEM VASILEV	{"email": "vasilevartem_27031970@postgrespro.ru", "phone": "+70202130019"}
0005434725986	F6C6D6	2734 853776	TATYANA KONOVALOVA	{"email": "konovalova-tatyana_08091966@postgrespro.ru", "phone": "+70230253459"}
0005434725987	4A6EE8	0998 154891	MARIYA MAKAROVA	{"phone": "+70267884118"}
0005434725988	7B91B0	4981 148802	MAKSIM MIKHAYLOV	{"phone": "+70728530276"}
0005434725989	4ED04A	1261 664444	KONSTANTIN VOROBEV	{"email": "kvorobev.1983@postgrespro.ru", "phone": "+70954623885"}
0005434725990	4ED04A	4769 092026	PAVEL VOROBEV	{"email": "vorobev-p-11101972@postgrespro.ru", "phone": "+70196737553"}
0005434725991	7C6653	1270 698830	ANDREY BELOV	{"email": "a.belov.14111964@postgrespro.ru", "phone": "+70057160141"}
0005434725992	7C6653	5589 148847	ALEKSANDRA DMITRIEVA	{"phone": "+70127464628"}
0005434725993	69FDE5	2153 434586	MARINA BORISOVA	{"phone": "+70846931055"}
0005434725994	8BA7B7	1809 060874	VLADIMIR FOMIN	{"phone": "+70113280795"}
0005434725995	D41CEE	1055 135391	NATALYA KOROLEVA	{"phone": "+70579262053"}
0005434725996	1FCAF8	5967 829696	SERGEY KOROLEV	{"email": "sergeykorolev061973@postgrespro.ru", "phone": "+70540241815"}
0005434725997	460FAF	6117 456332	IRINA NIKOLAEVA	{"phone": "+70097781725"}
0005434725998	614DD3	8099 855086	GALINA MIRONOVA	{"phone": "+70007146880"}
0005434725999	614DD3	0601 757078	ANDREY GRIGOREV	{"phone": "+70246561721"}
0005434726000	23536C	5681 393873	RAISA POTAPOVA	{"email": "rpotapova_28051969@postgrespro.ru", "phone": "+70038119683"}
0005434726001	DBBCFD	9697 373694	NIKITA OSIPOV	{"email": "osipovnikita-021969@postgrespro.ru", "phone": "+70147486713"}
0005434726002	125BAD	0422 311665	LYUDMILA MIKHAYLOVA	{"phone": "+70961353351"}
0005434726003	660807	1530 713844	SERGEY KUZNECOV	{"email": "s.kuznecov27091973@postgrespro.ru", "phone": "+70315518740"}
0005434726004	660807	1004 303621	ALEKSANDR IVANOV	{"phone": "+70269294489"}
0005434726005	940816	5930 620781	DENIS SOLOVEV	{"phone": "+70465629415"}
0005434726006	940816	0786 138080	MAKSIM YAKOVLEV	{"phone": "+70268565906"}
0005434726007	314262	6283 490140	SERGEY KONOVALOV	{"email": "konovalov.sergey_1973@postgrespro.ru", "phone": "+70260941695"}
0005434726008	314262	9481 623070	ANTONINA NIKITINA	{"phone": "+70766436174"}
0005434726009	25F823	7812 456961	DAMIR FEDOROV	{"email": "fedorov_d_1973@postgrespro.ru", "phone": "+70509657845"}
0005434726010	60D8DB	5194 388056	SERGEY MAKSIMOV	{"email": "maksimov_sergey-071963@postgrespro.ru", "phone": "+70702747884"}
0005434726011	385836	5305 364570	NADEZHDA MIRONOVA	{"email": "mironova-n-14071968@postgrespro.ru", "phone": "+70642492611"}
0005434726012	3E3422	8424 490200	MARIYA FILIPPOVA	{"phone": "+70441034405"}
0005434726013	EE3117	9466 032109	MARIYA SOLOVEVA	{"email": "m.soloveva09091970@postgrespro.ru", "phone": "+70840657317"}
0005434726014	1B7306	6645 101011	ANDREY POPOV	{"email": "popovandrey-07021971@postgrespro.ru", "phone": "+70928781733"}
0005434726015	4025DD	9467 197050	RAMIL KOZLOV	{"phone": "+70589560144"}
0005434726016	4025DD	7748 454767	ANNA KARPOVA	{"phone": "+70886500089"}
0005434726017	E49F5B	0965 299033	RAFAIL ABRAMOV	{"email": "rafail.abramov_081979@postgrespro.ru", "phone": "+70494454178"}
0005434726018	DE8529	7682 618638	ALENA SOLOVEVA	{"phone": "+70395820323"}
0005434726019	019E9A	2182 483613	YAKOV KISELEV	{"email": "yakov_kiselev.071963@postgrespro.ru", "phone": "+70217807740"}
0005434726020	019E9A	9292 368806	OLGA MELNIKOVA	{"email": "o-melnikova_1973@postgrespro.ru", "phone": "+70094305981"}
0005434726021	44AA6B	1631 201431	ANDREY TARASOV	{"email": "andrey-tarasov-22121960@postgrespro.ru", "phone": "+70987776454"}
0005434726022	CB73C1	4371 979791	ANASTASIYA EFREMOVA	{"phone": "+70055013572"}
0005434726023	E26E4D	3942 815946	RITA EGOROVA	{"email": "rita-egorova09031975@postgrespro.ru", "phone": "+70437884960"}
0005434726024	AAE579	0530 612364	RAISA SERGEEVA	{"phone": "+70606864079"}
0005434726025	E5BA6F	2629 943640	IVAN KARPOV	{"email": "i-karpov-1969@postgrespro.ru", "phone": "+70860572153"}
0005434726026	55F7AA	2291 060620	ELDAR FEDOROV	{"email": "fedorov_eldar.1977@postgrespro.ru", "phone": "+70320700735"}
0005434726027	C698B1	1931 154234	VLADISLAV MOROZOV	{"phone": "+70960367884"}
0005434726028	1A2AA9	9249 352266	TATYANA POPOVA	{"email": "t_popova.081958@postgrespro.ru", "phone": "+70713099129"}
0005434726029	1A2AA9	0147 737916	ARTUR OSIPOV	{"email": "osipova.121965@postgrespro.ru", "phone": "+70151766763"}
0005434726030	49A253	0195 018664	MARINA KUZMINA	{"email": "kuzmina-m1964@postgrespro.ru", "phone": "+70090460747"}
0005434726031	DC23D1	0122 796321	MARINA ZAKHAROVA	{"phone": "+70784789498"}
0005434726032	6C7210	1980 948733	VLADIMIR DENISOV	{"email": "denisovvladimir-011976@postgrespro.ru", "phone": "+70768156179"}
0005434726033	6C7210	6304 911625	NATALYA NOVIKOVA	{"phone": "+70112802190"}
0005434726034	E77CFD	0591 130695	VALENTINA PAVLOVA	{"email": "pavlova.v.1974@postgrespro.ru", "phone": "+70185691142"}
0005434726035	6CAF65	2575 723204	ALEKSANDR SHEVCHENKO	{"phone": "+70445865411"}
0005434726036	3FB506	8151 536206	MARIYA FEDOROVA	{"phone": "+70964594318"}
0005434726037	8F4DD4	6605 548041	VALERIYA GRISHINA	{"email": "grishina_valeriya.1968@postgrespro.ru", "phone": "+70373531664"}
0005434726038	729E41	8540 719239	ANASTASIYA FEDOROVA	{"email": "anastasiya.fedorova.101962@postgrespro.ru", "phone": "+70505863101"}
0005434726039	729E41	7204 295862	IRINA KISELEVA	{"phone": "+70630280656"}
0005434726040	7FF37F	4998 300657	TATYANA SOROKINA	{"email": "t_sorokina-1972@postgrespro.ru", "phone": "+70011062653"}
0005434726041	7FF37F	0255 909010	TATYANA VOLKOVA	{"email": "tatyanavolkova-08051981@postgrespro.ru", "phone": "+70431011242"}
0005434726042	BD3F0F	0954 050965	NIKOLAY IVANOV	{"phone": "+70556754028"}
0005434726043	DC0C0E	6469 519776	ALEKSEY ISAEV	{"email": "isaevaleksey1975@postgrespro.ru", "phone": "+70300229691"}
0005434726044	7B567C	9984 209620	MARIYA KUZNECOVA	{"email": "kuznecovamariya-1971@postgrespro.ru", "phone": "+70249428348"}
0005434726045	7B567C	4535 815333	ALBERT YAKOVLEV	{"phone": "+70163479690"}
0005434726046	C3C794	5319 092662	YURIY KUZMIN	{"phone": "+70682893758"}
0005434726047	896E57	3107 709401	YURIY NOVIKOV	{"email": "yuriy.novikov_1972@postgrespro.ru", "phone": "+70424738042"}
0005434726048	731248	3420 044819	POLINA ANISIMOVA	{"email": "polina.anisimova.18081979@postgrespro.ru", "phone": "+70225579435"}
0005434726049	F93A3A	1621 567994	ALEKSEY NAZAROV	{"phone": "+70010237937"}
0005434726050	F93A3A	7144 217232	EVGENIY SOKOLOV	{"email": "sokolov_e-1969@postgrespro.ru", "phone": "+70656548015"}
0005434726051	4CE92C	4209 759078	EVGENIYA ALEKSANDROVA	{"phone": "+70192116597"}
0005434726052	B404C6	7615 830202	ALEKSEY RODIONOV	{"phone": "+70171782146"}
0005434726053	B404C6	5898 089580	KONSTANTIN PAVLOV	{"phone": "+70444530778"}
0005434726054	8DBA0B	2197 685447	IRINA FILIPPOVA	{"phone": "+70320754805"}
0005434726055	97438B	3141 383193	ELENA DAVYDOVA	{"phone": "+70496694254"}
0005434726056	97438B	6294 278360	ALEKSANDR MATVEEV	{"email": "a-matveev-24031981@postgrespro.ru", "phone": "+70684434379"}
0005434726057	95E6C9	9946 342199	EKATERINA ROMANOVA	{"email": "romanova.e_01061962@postgrespro.ru", "phone": "+70022886111"}
0005434726058	FE9C07	3739 056931	YULIYA POPOVA	{"email": "popova-y-1970@postgrespro.ru", "phone": "+70420822283"}
0005434726059	FE9C07	7443 968999	NATALYA FILIPPOVA	{"email": "natalya-filippova.1971@postgrespro.ru", "phone": "+70977976907"}
0005434726060	FEE70F	9239 157473	DANIIL MAKAROV	{"phone": "+70794789300"}
0005434726061	FEE70F	3235 524066	OLGA SIDOROVA	{"phone": "+70061140588"}
0005434726062	FEE70F	4222 337047	EKATERINA ZHURAVLEVA	{"email": "ekaterinazhuravleva.111974@postgrespro.ru", "phone": "+70017454166"}
0005434726063	FEE70F	0776 577516	RAFAIL NIKOLAEV	{"email": "nikolaev.rafail1967@postgrespro.ru", "phone": "+70051310355"}
0005434726064	FD5091	9779 460124	ANNA POLYAKOVA	{"phone": "+70404470651"}
0005434726065	598722	5130 850306	MAKSIM KULIKOV	{"email": "kulikov-maksim13121974@postgrespro.ru", "phone": "+70865507902"}
0005434726066	7677C0	6978 453846	RAISA TROFIMOVA	{"email": "r-trofimova-26111971@postgrespro.ru", "phone": "+70389768665"}
0005434726067	7677C0	4092 458980	ANATOLIY MAKAROV	{"email": "makarova031973@postgrespro.ru", "phone": "+70942637166"}
0005434726068	7677C0	1307 524860	VALENTINA GAVRILOVA	{"email": "valentina-gavrilova-051978@postgrespro.ru", "phone": "+70662700553"}
0005434726069	0F27DA	4383 342066	SERGEY ANTONOV	{"email": "sergey_antonov121972@postgrespro.ru", "phone": "+70666094083"}
0005434726070	572E3C	7062 485446	TATYANA VLASOVA	{"phone": "+70006266573"}
0005434726071	907810	7721 619952	ANASTASIYA EGOROVA	{"phone": "+70680828099"}
0005434726072	907810	5974 885800	EKATERINA ZAKHAROVA	{"phone": "+70521431570"}
0005434726073	14FB09	8630 705221	VIKTORIYA VASILEVA	{"email": "vasilevav.1979@postgrespro.ru", "phone": "+70798759757"}
0005434726074	F30211	5293 654152	SERGEY FOMIN	{"phone": "+70363911470"}
0005434726075	F30211	2343 655569	TATYANA ARKHIPOVA	{"email": "arkhipova.t-101973@postgrespro.ru", "phone": "+70345429282"}
0005434726076	FA854A	9574 538130	ALEKSEY DMITRIEV	{"email": "admitriev28061974@postgrespro.ru", "phone": "+70558089757"}
0005434726077	76155B	4494 917462	YAKOV IVANOV	{"phone": "+70291409755"}
0005434726078	2155E8	9295 978680	DENIS BONDARENKO	{"phone": "+70028151030"}
0005434726079	EB860B	8279 538425	IRINA KOZLOVA	{"phone": "+70806041878"}
0005434726080	4BF29F	5048 392001	VALERIY MIRONOV	{"email": "valeriy-mironov.01011980@postgrespro.ru", "phone": "+70946621568"}
0005434726081	4BF29F	3682 679190	NURIYA RODIONOVA	{"phone": "+70426185219"}
0005434726082	4BF29F	3582 417797	ALEKSANDR FEDOTOV	{"phone": "+70478150157"}
0005434726083	DB331B	7501 401363	VITALIY NIKOLAEV	{"phone": "+70428468763"}
0005434726084	74D6EF	1867 407451	DMITRIY SOROKIN	{"phone": "+70139802136"}
0005434726085	12E522	1709 127386	SVETLANA SMIRNOVA	{"email": "svetlana-smirnova1981@postgrespro.ru", "phone": "+70940550815"}
0005434726086	12E522	1230 820397	ALEKSANDR SOLOVEV	{"email": "a-solovev.07041976@postgrespro.ru", "phone": "+70293098808"}
0005434726087	39F01E	2417 570961	VLADISLAV FOMIN	{"phone": "+70401113147"}
0005434726088	F74E65	8197 461509	GALINA VASILEVA	{"email": "vasileva.galina-051974@postgrespro.ru", "phone": "+70414179607"}
0005434726089	80DA37	1644 709083	OLGA IVANOVA	{"email": "ivanovao_091974@postgrespro.ru", "phone": "+70525120053"}
0005434726090	80DA37	7608 686455	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr_081979@postgrespro.ru", "phone": "+70863907524"}
0005434726091	784039	8906 980883	ALEKSEY DAVYDOV	{"phone": "+70812069211"}
0005434726092	857F5B	8420 841818	SERGEY MAKAROV	{"email": "makarov.sergey.111976@postgrespro.ru", "phone": "+70498295145"}
0005434726093	B5E19A	8585 988807	EVDOKIYA BOGDANOVA	{"email": "bogdanova_e04121972@postgrespro.ru", "phone": "+70618873279"}
0005434726094	B5E19A	5145 680821	ALEKSEY KUZMIN	{"email": "kuzmina_28021976@postgrespro.ru", "phone": "+70832113827"}
0005434726095	36ED34	4322 449625	ALEKSEY NAZAROV	{"phone": "+70745531639"}
0005434726096	07C9E1	7879 133397	ALEKSANDR ALEKSANDROV	{"phone": "+70449615748"}
0005434726097	07C9E1	4449 244479	ANATOLIY MOROZOV	{"phone": "+70453935195"}
0005434726099	DFAA45	9624 221223	EKATERINA EGOROVA	{"email": "egorova.ekaterina.071961@postgrespro.ru", "phone": "+70422963140"}
0005434726100	DFAA45	2687 013690	EKATERINA KOLESNIKOVA	{"phone": "+70407798032"}
0005434726101	906553	3369 580203	IVAN KUZNECOV	{"phone": "+70128489653"}
0005434726102	23823D	9246 297517	VADIM AFANASEV	{"email": "afanasevvadim_17061969@postgrespro.ru", "phone": "+70947387429"}
0005434726103	23823D	0975 063052	KIRILL SMIRNOV	{"phone": "+70107922995"}
0005434726104	7F91E2	9067 433064	VIKTOR KUZNECOV	{"email": "vkuznecov.071975@postgrespro.ru", "phone": "+70697168091"}
0005434726105	0DEC73	1865 309952	ALLA YUDINA	{"email": "a-yudina_031969@postgrespro.ru", "phone": "+70620244053"}
0005434726106	BF59FC	2875 238245	DMITRIY VASILEV	{"email": "vasilev.d_1972@postgrespro.ru", "phone": "+70595220261"}
0005434726107	BB4158	7018 326405	VALENTINA GUSEVA	{"email": "valentina.guseva-1972@postgrespro.ru", "phone": "+70199349466"}
0005434726108	3A5D15	9062 984838	VADIM BORISOV	{"phone": "+70254170220"}
0005434726109	BCDF3D	7166 199119	ELENA IVANOVA	{"email": "elena_ivanova_061963@postgrespro.ru", "phone": "+70800561887"}
0005434726110	BCDF3D	0348 208141	OLEG FEDOROV	{"phone": "+70305900950"}
0005434726111	E9CFFF	9575 529293	IVAN POPOV	{"phone": "+70812313560"}
0005434726112	75B141	1175 815580	NATALYA SMIRNOVA	{"phone": "+70348852502"}
0005434726113	DCB2E6	3322 239522	IGOR NIKOLAEV	{"email": "nikolaev_i-1974@postgrespro.ru", "phone": "+70206158993"}
0005434726114	DCB2E6	6947 020644	SVETLANA PETROVA	{"phone": "+70270372442"}
0005434726115	C719FF	1323 347341	IRINA NIKOLAEVA	{"email": "i_nikolaeva-16061970@postgrespro.ru", "phone": "+70602654474"}
0005434726116	182EA1	8526 996066	YULIYA TIMOFEEVA	{"phone": "+70906487173"}
0005434726117	D85BA2	4292 965458	NINA VLASOVA	{"email": "ninavlasova-26041977@postgrespro.ru", "phone": "+70770353804"}
0005434726118	8C75DF	1126 522539	ANTON MOROZOV	{"email": "morozov-anton021976@postgrespro.ru", "phone": "+70184886554"}
0005434726119	8C75DF	3704 411987	DENIS FILIPPOV	{"phone": "+70980278365"}
0005434726120	4D28C8	6724 867879	EKATERINA YAKOVLEVA	{"email": "yakovleva.ekaterina.14061968@postgrespro.ru", "phone": "+70160795877"}
0005434726121	D18996	6563 580611	GALINA KULIKOVA	{"email": "g.kulikova-21021964@postgrespro.ru", "phone": "+70243241814"}
0005434726122	3A5217	8030 284968	ANASTASIYA FROLOVA	{"phone": "+70615854268"}
0005434726123	A856E9	0033 046560	OLGA DMITRIEVA	{"phone": "+70680647315"}
0005434726124	27E39E	8237 047267	ELVIRA VASILEVA	{"phone": "+70327430305"}
0005434726125	27E39E	4290 188317	ALEKSANDR VASILEV	{"phone": "+70385708706"}
0005434726126	C72B5D	0433 870511	NATALYA IVANOVA	{"email": "natalyaivanova_1965@postgrespro.ru", "phone": "+70177745811"}
0005434726127	63EF37	6350 276301	EVGENIY NAZAROV	{"email": "evgeniy.nazarov.081973@postgrespro.ru", "phone": "+70429659942"}
0005434726128	63EF37	7484 154828	VERA DENISOVA	{"phone": "+70935373324"}
0005434726129	C0731F	6528 424162	NIKOLAY BONDARENKO	{"phone": "+70975212075"}
0005434726130	932CD9	9481 145741	NINA KUZNECOVA	{"phone": "+70796316344"}
0005434726131	82D795	1084 286205	ANTON SERGEEV	{"phone": "+70530969380"}
0005434726132	82D795	2594 442979	EVGENIY ANDREEV	{"email": "andreevevgeniy-1955@postgrespro.ru", "phone": "+70795182712"}
0005434726133	3182F7	3104 775158	GALINA KUZNECOVA	{"email": "kuznecova_galina1972@postgrespro.ru", "phone": "+70182019988"}
0005434726134	3182F7	9385 459646	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov_1975@postgrespro.ru", "phone": "+70044998124"}
0005434726135	2C299E	3582 799747	SERGEY ROMANOV	{"phone": "+70261793262"}
0005434726136	5F246A	4376 522105	VLADIMIR IVANOV	{"email": "v-ivanov121972@postgrespro.ru", "phone": "+70586194571"}
0005434726137	5F246A	0113 251150	OLEG KUDRYASHOV	{"email": "o_kudryashov-101966@postgrespro.ru", "phone": "+70665339703"}
0005434726138	1F1E9D	2562 835854	VIKTOR KRASNOV	{"phone": "+70338066267"}
0005434726139	08DB89	4082 043031	ANASTASIYA SMIRNOVA	{"phone": "+70504079365"}
0005434726140	99FA55	8838 265202	EKATERINA VLASOVA	{"email": "ekaterina.vlasova.14121982@postgrespro.ru", "phone": "+70878543252"}
0005434726141	10D8DE	4811 306657	ANATOLIY GUSEV	{"email": "a-gusev.09021980@postgrespro.ru", "phone": "+70136019003"}
0005434726142	7FAD86	4049 320490	VIKTOR SHEVCHENKO	{"email": "vshevchenko.1966@postgrespro.ru", "phone": "+70643900893"}
0005434726143	7FAD86	7385 161704	ANNA AFANASEVA	{"phone": "+70523343814"}
0005434726144	F94962	8983 305173	OLGA SCHERBAKOVA	{"phone": "+70919693979"}
0005434726145	E216B6	9190 625571	YULIYA VOROBEVA	{"email": "vorobeva-yuliya.16021968@postgrespro.ru", "phone": "+70546970173"}
0005434726146	3C4938	1726 292641	SERGEY VOLKOV	{"phone": "+70883791148"}
0005434726147	B46C35	8051 949461	LIDIYA YAKOVLEVA	{"phone": "+70555411898"}
0005434726148	B46C35	8695 313988	REGINA ZAKHAROVA	{"phone": "+70957840890"}
0005434726149	C9A6C8	1810 253802	KIRILL PETROV	{"email": "petrovk_1981@postgrespro.ru", "phone": "+70043087234"}
0005434726150	C9A6C8	0045 548675	VIKTOR PETROV	{"email": "vpetrov31071969@postgrespro.ru", "phone": "+70421400184"}
0005434726151	C9A6C8	5821 894392	YURIY GUSEV	{"phone": "+70715308663"}
0005434726152	0ADF4F	8915 134951	YULIYA NESTEROVA	{"email": "nesterova.y041971@postgrespro.ru", "phone": "+70209662039"}
0005434726153	6254BA	4909 263992	VLADIMIR KAZAKOV	{"phone": "+70435898100"}
0005434726154	096A10	0313 339648	ANATOLIY BORISOV	{"email": "anatoliyborisov-11091971@postgrespro.ru", "phone": "+70156077435"}
0005434726155	096A10	0951 515755	ALEKSANDR ORLOV	{"email": "orlov-aleksandr_29121982@postgrespro.ru", "phone": "+70287646773"}
0005434726156	C9DDEB	6087 870547	ALEKSANDR KUZMIN	{"phone": "+70919495185"}
0005434726157	C9DDEB	9392 613041	LYUBOV NESTEROVA	{"phone": "+70516282200"}
0005434726158	C9DDEB	4824 819222	SERGEY PETROV	{"email": "sergey-petrov.081976@postgrespro.ru", "phone": "+70026982406"}
0005434726159	9794D0	3363 032365	OLGA POLYAKOVA	{"email": "olga.polyakova-1990@postgrespro.ru", "phone": "+70612188618"}
0005434726160	9794D0	6593 716782	RAMILYA KUZNECOVA	{"email": "rkuznecova_1979@postgrespro.ru", "phone": "+70230376758"}
0005434726161	016C15	2014 521866	OLGA IVANOVA	{"phone": "+70184517893"}
0005434726162	BABD73	5807 552664	TATYANA DAVYDOVA	{"email": "davydova_tatyana.051959@postgrespro.ru", "phone": "+70192894945"}
0005434726163	BABD73	7454 879860	YURIY ROMANOV	{"phone": "+70810532106"}
0005434726164	4CC12E	6200 863379	ELENA SOROKINA	{"phone": "+70826935192"}
0005434726165	4CC12E	4008 581137	NIKOLAY FEDOROV	{"email": "fedorov.n_1970@postgrespro.ru", "phone": "+70242256067"}
0005434726166	F0350E	6529 540751	YULIYA SOROKINA	{"email": "yuliyasorokina-1966@postgrespro.ru", "phone": "+70191149241"}
0005434726167	17C977	1457 299404	ALEKSANDR SERGEEV	{"phone": "+70873088147"}
0005434726168	77957B	6729 501218	SERGEY CHERNOV	{"email": "sergeychernov_1974@postgrespro.ru", "phone": "+70384043650"}
0005434726169	77957B	6404 327529	TATYANA ANDREEVA	{"email": "tatyana_andreeva101972@postgrespro.ru", "phone": "+70015584941"}
0005434726170	187B1A	1847 928629	TAMARA NIKITINA	{"phone": "+70879526391"}
0005434726171	DE4EDF	5048 677009	ANVAR TARASOV	{"email": "tarasov.a1977@postgrespro.ru", "phone": "+70566838696"}
0005434726172	378345	4482 681307	ANDREY MEDVEDEV	{"email": "andrey-medvedev031974@postgrespro.ru", "phone": "+70213717295"}
0005434726173	378345	7448 596219	VIKTOR SCHERBAKOV	{"email": "scherbakovv-091981@postgrespro.ru", "phone": "+70090864812"}
0005434726174	9B2B5E	5401 234797	TIMOFEY ISAEV	{"email": "isaev_t_25061956@postgrespro.ru", "phone": "+70782610310"}
0005434726175	AB2968	3711 936105	NATALYA VOLKOVA	{"phone": "+70175359835"}
0005434726176	AB2968	4446 185503	GENNADIY BORISOV	{"phone": "+70923850913"}
0005434726177	A504A6	5990 478213	PELAGEYA NOVIKOVA	{"email": "pelageya_novikova1969@postgrespro.ru", "phone": "+70917291855"}
0005434726178	33187E	6916 946174	VLADIMIR SMIRNOV	{"email": "v.smirnov26031978@postgrespro.ru", "phone": "+70063623896"}
0005434726179	97772C	2490 405857	RUSHANIYA YAKOVLEVA	{"email": "yakovleva_r_08081966@postgrespro.ru", "phone": "+70809183794"}
0005434726180	1F143E	8525 535796	YULIYA MIRONOVA	{"email": "yuliya_mironova-1958@postgrespro.ru", "phone": "+70844393570"}
0005434726181	71687C	2097 922650	EKATERINA VLASOVA	{"email": "e_vlasova.021982@postgrespro.ru", "phone": "+70673031293"}
0005434726182	7459DB	0755 677744	LIDIYA FEDOROVA	{"phone": "+70821629654"}
0005434726183	7459DB	7905 418004	ALEKSEY SOROKIN	{"phone": "+70260295480"}
0005434726184	7459DB	6452 935527	PAVEL NAUMOV	{"phone": "+70538979810"}
0005434726185	510123	5610 442101	ANDREY DMITRIEV	{"email": "a_dmitriev_1970@postgrespro.ru", "phone": "+70363951920"}
0005434726186	979784	6180 004778	YURIY ZAYCEV	{"email": "zaycev-yuriy.13061978@postgrespro.ru", "phone": "+70175600634"}
0005434726187	990D5D	4778 516759	ALEKSANDR BARANOV	{"email": "a_baranov-051982@postgrespro.ru", "phone": "+70953119818"}
0005434726188	E8EC6B	1080 310670	ALEKSANDR POPOV	{"phone": "+70251032727"}
0005434726189	E8D17B	2206 378563	VADIM GUSEV	{"email": "gusev-vadim1986@postgrespro.ru", "phone": "+70296866867"}
0005434726190	EB6718	1490 459854	LYUDMILA DANILOVA	{"email": "lyudmila.danilova081973@postgrespro.ru", "phone": "+70562855945"}
0005434726191	EB6718	8269 785844	SVETLANA LUKYANOVA	{"phone": "+70569997722"}
0005434726192	7DC270	5492 782043	GALINA SOKOLOVA	{"phone": "+70645642284"}
0005434726193	4FFA73	7216 362063	ELENA SEMENOVA	{"phone": "+70941722323"}
0005434726194	404C88	9861 511133	ARTEM IVANOV	{"email": "a_ivanov_09091979@postgrespro.ru", "phone": "+70688061555"}
0005434726195	33B670	3660 700216	EVDOKIYA KONDRATEVA	{"email": "kondrateva.e-22031975@postgrespro.ru", "phone": "+70298358910"}
0005434726196	EABBA6	8888 264707	MARTA FADEEVA	{"email": "fadeeva.marta1962@postgrespro.ru", "phone": "+70276885969"}
0005434726197	6AC100	8081 858423	TATYANA IVANOVA	{"phone": "+70492564056"}
0005434726198	6AC100	7595 906153	YURIY POPOV	{"email": "y.popov.061964@postgrespro.ru", "phone": "+70619525878"}
0005434726199	6AC100	7773 482898	VYACHESLAV PAVLOV	{"email": "vyacheslav_pavlov-15031969@postgrespro.ru", "phone": "+70517763015"}
0005434726200	5AC2B5	6741 299420	VERA EGOROVA	{"email": "vegorova12061977@postgrespro.ru", "phone": "+70112565571"}
0005434726201	815802	2144 179415	MARIYA FROLOVA	{"phone": "+70913653761"}
0005434726202	9F66F3	5332 192610	LYUBOV FILIPPOVA	{"phone": "+70987073533"}
0005434726203	93F2C0	0620 183050	ANTON NAZAROV	{"phone": "+70359132031"}
0005434726204	93F2C0	4076 038930	ANFISA KARPOVA	{"email": "karpova-anfisa1978@postgrespro.ru", "phone": "+70632289106"}
0005434726205	2D7A6B	1127 519107	SERGEY KARPOV	{"email": "karpov.s1961@postgrespro.ru", "phone": "+70910724396"}
0005434726206	2D7A6B	1458 011043	OLESYA POPOVA	{"email": "olesya_popova_061973@postgrespro.ru", "phone": "+70607519209"}
0005434726207	054E88	5429 047988	VLADIMIR SMIRNOV	{"email": "smirnovv03041974@postgrespro.ru", "phone": "+70893522191"}
0005434726208	98BC4B	3156 759775	ALEKSANDR MIKHAYLOV	{"phone": "+70548172051"}
0005434726209	6E8972	7775 814328	SERGEY FROLOV	{"email": "frolovs_091959@postgrespro.ru", "phone": "+70155065717"}
0005434726210	6E8972	1448 392113	VIKTOR SERGEEV	{"email": "viktor_sergeev1965@postgrespro.ru", "phone": "+70642906039"}
0005434726211	AC8EA9	5978 489729	ANASTASIYA BELYAEVA	{"email": "abelyaeva1970@postgrespro.ru", "phone": "+70715621381"}
0005434726212	6D78E0	9681 224166	YURIY SMIRNOV	{"email": "yuriy.smirnov.071972@postgrespro.ru", "phone": "+70071336889"}
0005434726213	6A0234	0461 966024	LARISA DAVYDOVA	{"email": "l-davydova-011961@postgrespro.ru", "phone": "+70369469907"}
0005434726214	6A0234	9816 241908	SERGEY VASILEV	{"phone": "+70278897864"}
0005434726215	32620D	7558 360598	TATYANA NIKITINA	{"email": "nikitina_tatyana_1967@postgrespro.ru", "phone": "+70081167753"}
0005434726216	F4F529	5756 574176	VALENTIN AFANASEV	{"email": "afanasev.valentin.1962@postgrespro.ru", "phone": "+70974041034"}
0005434726217	F4F529	9955 961559	PAVEL PETROV	{"phone": "+70203752759"}
0005434726218	AC6C62	1962 719587	IRINA MIRONOVA	{"email": "i-mironova.17051969@postgrespro.ru", "phone": "+70153808530"}
0005434726219	914138	7327 736987	VIKTORIYA NIKOLAEVA	{"email": "nikolaevav1981@postgrespro.ru", "phone": "+70204296675"}
0005434726220	6C7614	9805 789565	VERA SOKOLOVA	{"phone": "+70594567016"}
0005434726221	587E5F	6102 265476	MAKSIM SAVELEV	{"email": "savelev.maksim1983@postgrespro.ru", "phone": "+70144684007"}
0005434726222	587E5F	3355 164683	ELENA VOROBEVA	{"email": "vorobeva-e081982@postgrespro.ru", "phone": "+70057598482"}
0005434726223	0263F9	9751 894286	ALEKSANDR MOROZOV	{"phone": "+70215583225"}
0005434726224	D5141C	7618 307492	IRINA EGOROVA	{"email": "i_egorova1978@postgrespro.ru", "phone": "+70928168246"}
0005434726225	D04D19	3464 625055	LYUBOV VOLKOVA	{"phone": "+70870982495"}
0005434726226	3C6590	1436 572073	ANDREY CHERNOV	{"phone": "+70737446595"}
0005434726227	3C6590	4343 199599	SERGEY VASILEV	{"email": "vasilev_sergey.1985@postgrespro.ru", "phone": "+70628766782"}
0005434726228	7C3B04	7430 771227	ZINAIDA KUZMINA	{"email": "zinaida.kuzmina1967@postgrespro.ru", "phone": "+70037701573"}
0005434726229	C9E596	0414 704831	VALENTINA KOLESNIKOVA	{"phone": "+70273779828"}
0005434726230	351122	1965 041925	VALENTINA DENISOVA	{"phone": "+70848568724"}
0005434726231	351122	0424 572728	MAKSIM ABRAMOV	{"email": "abramov.maksim.071974@postgrespro.ru", "phone": "+70244402179"}
0005434726232	8B2441	7078 991510	LEONID EGOROV	{"email": "leonid.egorov-1976@postgrespro.ru", "phone": "+70911124584"}
0005434726233	46D35E	7897 622120	VALERIY SCHERBAKOV	{"phone": "+70491664512"}
0005434726234	88F047	1173 994878	RIMMA YAKOVLEVA	{"email": "yakovlevar-061970@postgrespro.ru", "phone": "+70122974272"}
0005434726235	453ACA	6987 583591	YURIY AFANASEV	{"phone": "+70947906704"}
0005434726236	26E5A8	1547 766432	ANNA BORISOVA	{"email": "borisovaa031965@postgrespro.ru", "phone": "+70661093761"}
0005434726237	2F94C3	3120 432237	MAKSIM ILIN	{"phone": "+70697634057"}
0005434726238	5372BE	0380 502235	LARISA KUZNECOVA	{"phone": "+70179810673"}
0005434726239	CD9D92	8276 275831	ALEKSANDR KUZNECOV	{"phone": "+70805643840"}
0005434726240	CD9D92	2562 694362	EKATERINA MIRONOVA	{"phone": "+70381981905"}
0005434726241	F53A54	4368 000554	EKATERINA FILIPPOVA	{"email": "ekaterina-filippova.061980@postgrespro.ru", "phone": "+70966833539"}
0005434726242	222356	3403 297490	EVGENIY ZAKHAROV	{"email": "evgeniy.zakharov17091973@postgrespro.ru", "phone": "+70806057054"}
0005434726243	222356	1367 413635	MAKSIM VLASOV	{"email": "vlasov.m_011974@postgrespro.ru", "phone": "+70228007990"}
0005434726244	1AA37C	8714 356380	ANASTASIYA ZHUKOVA	{"email": "a.zhukova.1972@postgrespro.ru", "phone": "+70012186433"}
0005434726245	1AA37C	6146 510600	IRINA NIKOLAEVA	{"phone": "+70378817908"}
0005434726246	D0C01B	6163 309053	VALENTINA PETROVA	{"email": "petrova_v_29101969@postgrespro.ru", "phone": "+70124668556"}
0005434726247	0B61E9	4482 418518	GALINA KOZLOVA	{"phone": "+70608780318"}
0005434726248	0B61E9	1304 052845	DMITRIY OSIPOV	{"email": "osipov.dmitriy1979@postgrespro.ru", "phone": "+70156903405"}
0005434726249	E7FC7A	2275 121317	EDUARD TIKHONOV	{"phone": "+70676770304"}
0005434726250	DA3C9D	7671 666401	OKSANA EFIMOVA	{"phone": "+70533926553"}
0005434726251	DA3C9D	3194 970684	SVETLANA MOROZOVA	{"email": "svetlanamorozova-1959@postgrespro.ru", "phone": "+70661619055"}
0005434726252	9C2E56	6369 861967	ANDREY FOMIN	{"phone": "+70730601300"}
0005434726253	B8ADF9	3280 254873	YURIY SCHERBAKOV	{"phone": "+70140651757"}
0005434726254	29538E	5892 357335	VLADIMIR VOROBEV	{"email": "vorobev.vladimir1969@postgrespro.ru", "phone": "+70297405002"}
0005434726255	29538E	3669 439609	VALERIY GRIGOREV	{"phone": "+70374356584"}
0005434726256	29538E	3853 124674	EVGENIY MEDVEDEV	{"phone": "+70224342217"}
0005434726257	BD9291	3179 444204	NIKITA KOZLOV	{"email": "kozlovnikita-1988@postgrespro.ru", "phone": "+70333807202"}
0005434726258	BD9291	4208 821853	VALENTINA MOISEEVA	{"phone": "+70983586983"}
0005434726259	EA4FA3	5870 504224	TATYANA BOGDANOVA	{"email": "t-bogdanova1979@postgrespro.ru", "phone": "+70545807717"}
0005434726260	C47C62	3353 712390	ALEKSANDR SERGEEV	{"email": "sergeev_a-061968@postgrespro.ru", "phone": "+70482959118"}
0005434726261	F8A5A0	0758 323635	DMITRIY SOKOLOV	{"email": "sokolov-dmitriy061974@postgrespro.ru", "phone": "+70731781374"}
0005434726262	F8A5A0	0445 448713	VIKTOR NIKOLAEV	{"email": "nikolaevviktor041973@postgrespro.ru", "phone": "+70119870997"}
0005434726263	EBF04D	5681 057908	EKATERINA GUSEVA	{"email": "gusevae_1973@postgrespro.ru", "phone": "+70982265282"}
0005434726264	CB587A	0568 580483	KONSTANTIN KARPOV	{"email": "konstantin.karpov_11031977@postgrespro.ru", "phone": "+70532590756"}
0005434726265	CB587A	7957 846328	KIRILL SERGEEV	{"phone": "+70271178257"}
0005434726266	2DD530	4371 852945	MARIYA VASILEVA	{"phone": "+70061836683"}
0005434726267	2DD530	6271 993619	ANDREY IVANOV	{"email": "ivanova.101970@postgrespro.ru", "phone": "+70293200664"}
0005434726268	01A375	8631 172557	ALEKSANDR SEMENOV	{"phone": "+70072667274"}
0005434726269	04FB29	4800 950090	ZINAIDA BELYAEVA	{"phone": "+70366739308"}
0005434726270	D60C23	8822 590162	GEORGIY VOROBEV	{"email": "vorobev_g.051969@postgrespro.ru", "phone": "+70038301890"}
0005434726271	D60C23	0386 783577	AZAT EGOROV	{"email": "a-egorov1964@postgrespro.ru", "phone": "+70757510569"}
0005434726272	2BAB52	6804 363170	NADEZHDA FILATOVA	{"email": "filatovanadezhda-27081974@postgrespro.ru", "phone": "+70728297175"}
0005434726273	71D17C	0817 964592	YANA KUZNECOVA	{"email": "y-kuznecova.111970@postgrespro.ru", "phone": "+70384872657"}
0005434726274	4629B7	2944 072078	LYUDMILA ISAEVA	{"phone": "+70316499976"}
0005434726275	7806E8	4656 607484	TATYANA FADEEVA	{"email": "t-fadeeva_1973@postgrespro.ru", "phone": "+70129070307"}
0005434726276	7806E8	1859 373812	OLGA MIKHAYLOVA	{"email": "mikhaylovao-081970@postgrespro.ru", "phone": "+70091401521"}
0005434726574	44290C	4919 297255	YULIYA SOKOLOVA	{"phone": "+70275700490"}
0005434726277	D4B9D0	5754 353234	VYACHESLAV SMIRNOV	{"email": "v_smirnov031969@postgrespro.ru", "phone": "+70884150672"}
0005434726278	D4B9D0	0997 884158	SOFIYA KUZNECOVA	{"email": "sofiya-kuznecova1981@postgrespro.ru", "phone": "+70691585574"}
0005434726279	6EAFAA	0605 304435	NATALYA MIKHAYLOVA	{"email": "natalya_mikhaylova_041974@postgrespro.ru", "phone": "+70726565439"}
0005434726280	6EAFAA	0716 351458	EVGENIY FOMIN	{"email": "evgeniy_fomin_1967@postgrespro.ru", "phone": "+70816511029"}
0005434726281	9496F0	2389 951515	TAMARA KUZNECOVA	{"email": "t.kuznecova_1970@postgrespro.ru", "phone": "+70943360425"}
0005434726282	9496F0	3709 928719	VYACHESLAV VOLKOV	{"email": "vvolkov_1965@postgrespro.ru", "phone": "+70851196279"}
0005434726283	F32113	0946 244335	OLGA ANDREEVA	{"email": "oandreeva_111983@postgrespro.ru", "phone": "+70007662854"}
0005434726284	937286	6154 188025	LIDIYA ANTONOVA	{"phone": "+70811696197"}
0005434726285	937286	4735 857084	NIKOLAY STEPANOV	{"email": "n-stepanov-1976@postgrespro.ru", "phone": "+70097550056"}
0005434726286	937286	3757 711856	TAMARA ARKHIPOVA	{"phone": "+70213825833"}
0005434726287	56A700	5233 764987	GALINA KAZAKOVA	{"email": "kazakova_g_27111969@postgrespro.ru", "phone": "+70144624692"}
0005434726288	07AD28	2636 158742	NIKOLAY VASILEV	{"phone": "+70130233677"}
0005434726289	9D21D5	4139 278650	ALEKSEY BARANOV	{"phone": "+70892479631"}
0005434726290	943BDA	1694 777319	EKATERINA NAZAROVA	{"email": "e.nazarova_041969@postgrespro.ru", "phone": "+70054023359"}
0005434726291	943BDA	6454 439766	LILIYA SMIRNOVA	{"phone": "+70192077504"}
0005434726292	30FBE0	1862 323962	LYUBOV ROMANOVA	{"email": "l_romanova041983@postgrespro.ru", "phone": "+70805457823"}
0005434726293	30FBE0	2015 098832	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova_anastasiya.14051959@postgrespro.ru", "phone": "+70601632495"}
0005434726294	15FA40	6875 026341	VLADIMIR MIRONOV	{"phone": "+70429336727"}
0005434726295	A487BC	6527 697718	VALENTINA ZHURAVLEVA	{"email": "zhuravlevavalentina.08051975@postgrespro.ru", "phone": "+70551769228"}
0005434726296	09A41F	2692 860386	ELENA BORISOVA	{"phone": "+70989682549"}
0005434726297	4DC3BD	7167 346862	IGOR KRASNOV	{"email": "igor-krasnov_051977@postgrespro.ru", "phone": "+70175014592"}
0005434726298	E79D0E	1624 820014	MAKSIM KONOVALOV	{"phone": "+70118153892"}
0005434726299	B7574E	0426 252824	SERGEY VOLKOV	{"email": "svolkov1985@postgrespro.ru", "phone": "+70944956094"}
0005434726300	3EB7E1	4577 469914	EVGENIY DAVYDOV	{"email": "e-davydov1966@postgrespro.ru", "phone": "+70940272348"}
0005434726301	3EB7E1	3486 257968	IRINA PAVLOVA	{"phone": "+70215994595"}
0005434726302	C541FF	4742 138302	VLADIMIR KUZNECOV	{"email": "v-kuznecov-26081961@postgrespro.ru", "phone": "+70762710856"}
0005434726303	15A186	7445 045640	IRINA FADEEVA	{"phone": "+70191701133"}
0005434726304	709CF8	4401 022788	ILYA OSIPOV	{"email": "iosipov-1981@postgrespro.ru", "phone": "+70440180834"}
0005434726305	46D562	3417 013206	ALEKSANDR GAVRILOV	{"phone": "+70822151547"}
0005434726306	C722BC	6457 091068	ELIZAVETA SCHERBAKOVA	{"email": "scherbakova_elizaveta-22061972@postgrespro.ru", "phone": "+70445175473"}
0005434726307	C4864A	1170 781914	ANNA SMIRNOVA	{"email": "a_smirnova04031981@postgrespro.ru", "phone": "+70267793802"}
0005434726308	C4864A	8322 725461	ALEKSANDR KULIKOV	{"email": "kulikov-aleksandr_23111956@postgrespro.ru", "phone": "+70073386189"}
0005434726309	F51375	0779 031808	OLGA ORLOVA	{"email": "orlova_olga-1955@postgrespro.ru", "phone": "+70911324871"}
0005434726310	91ADCE	7796 223654	LYUDMILA RYABOVA	{"phone": "+70794021922"}
0005434726311	006837	5836 296448	OLGA KUZMINA	{"phone": "+70990023376"}
0005434726312	8EAC31	9094 465203	DMITRIY MATVEEV	{"email": "matveev-d-1959@postgrespro.ru", "phone": "+70351542575"}
0005434726313	8EAC31	1367 866960	VALENTIN KUZNECOV	{"email": "valentin.kuznecov-121971@postgrespro.ru", "phone": "+70646698284"}
0005434726314	B5D946	9368 618847	VALERIY KOZLOV	{"phone": "+70707278140"}
0005434726315	B5D946	7451 896460	VIKTOR FEDOTOV	{"email": "fedotov-v.071973@postgrespro.ru", "phone": "+70208413568"}
0005434726316	649A5F	2688 966039	GALINA POLYAKOVA	{"email": "g-polyakova-1971@postgrespro.ru", "phone": "+70430667551"}
0005434726317	649A5F	5792 154129	TAMARA MOROZOVA	{"email": "tamara_morozova-19071956@postgrespro.ru", "phone": "+70404816742"}
0005434726318	5F2584	9833 741596	MARIYA POPOVA	{"email": "popovam081973@postgrespro.ru", "phone": "+70470190805"}
0005434726319	5F2584	7220 324314	MARINA SOLOVEVA	{"phone": "+70747507804"}
0005434726320	CDDB0F	9239 197402	NADEZHDA ABRAMOVA	{"email": "nadezhda_abramova_051976@postgrespro.ru", "phone": "+70287818345"}
0005434726321	CDDB0F	1307 647185	SERGEY OSIPOV	{"email": "osipov_sergey_1973@postgrespro.ru", "phone": "+70326361067"}
0005434726322	B39D95	4487 162976	VIKTOR SOROKIN	{"email": "v-sorokin_1980@postgrespro.ru", "phone": "+70987544189"}
0005434726323	8D2358	1592 863629	SVETLANA SERGEEVA	{"email": "svetlana.sergeeva.11051965@postgrespro.ru", "phone": "+70579154314"}
0005434726324	8D2358	3638 126316	ALEKSEY MIKHAYLOV	{"phone": "+70580750143"}
0005434726325	89A6BC	9362 974684	YURIY KUZNECOV	{"email": "y-kuznecov031982@postgrespro.ru", "phone": "+70940390619"}
0005434726326	89A6BC	2955 909043	EVGENIY MAKAROV	{"email": "makarov_evgeniy_081971@postgrespro.ru", "phone": "+70077939983"}
0005434726327	610EC6	1175 720086	PETR ALEKSANDROV	{"phone": "+70781016002"}
0005434726328	1C88EB	8256 351214	VIOLETTA MEDVEDEVA	{"email": "medvedeva_violetta_1966@postgrespro.ru", "phone": "+70480239325"}
0005434726329	0A2C5D	4440 460013	EGOR GORBUNOV	{"email": "e-gorbunov021982@postgrespro.ru", "phone": "+70389821868"}
0005434726330	0A2C5D	3008 005478	SERGEY GUSEV	{"email": "gusev_sergey041982@postgrespro.ru", "phone": "+70173553988"}
0005434726331	22AF4E	0112 146504	IRINA ERMAKOVA	{"email": "irina-ermakova_1972@postgrespro.ru", "phone": "+70700589052"}
0005434726332	D3B2E4	2889 136391	IVAN KUZNECOV	{"phone": "+70835938398"}
0005434726333	D3B2E4	9154 872672	ALEKSANDR VOROBEV	{"email": "a_vorobev051974@postgrespro.ru", "phone": "+70843771008"}
0005434726334	D3B2E4	6266 112794	TATYANA KOZLOVA	{"email": "tatyanakozlova_1966@postgrespro.ru", "phone": "+70519219676"}
0005434726335	301657	9516 354491	VLADIMIR ALEKSANDROV	{"email": "vladimir-aleksandrov1975@postgrespro.ru", "phone": "+70277089413"}
0005434726336	301657	3313 148794	SERGEY OSIPOV	{"email": "s.osipov.1973@postgrespro.ru", "phone": "+70523901697"}
0005434726337	FB1BB2	8067 475156	ALISA AKIMOVA	{"phone": "+70523244827"}
0005434726338	5CB91C	2283 489324	IRINA SEMENOVA	{"phone": "+70754328015"}
0005434726339	5CB91C	0721 412227	ALEKSANDR KOROLEV	{"email": "a_korolev_041965@postgrespro.ru", "phone": "+70195114225"}
0005434726340	5B057D	0349 876305	YURIY VOLKOV	{"email": "volkov.yuriy-1974@postgrespro.ru", "phone": "+70619590693"}
0005434726341	E49595	1890 367728	ZHANNA NIKITINA	{"email": "nikitina-zhanna1984@postgrespro.ru", "phone": "+70292537605"}
0005434726342	87FAE9	1041 382671	VLADIMIR SHEVCHENKO	{"phone": "+70343978748"}
0005434726343	02DB7D	0042 167876	VLADIMIR MAKSIMOV	{"phone": "+70031506278"}
0005434726344	79A54E	4801 356831	OLGA EGOROVA	{"phone": "+70123201298"}
0005434726345	D6BC3D	3789 259287	EKATERINA IVANOVA	{"email": "ivanovae_021964@postgrespro.ru", "phone": "+70158258461"}
0005434726346	DB1591	2257 596155	ALEKSEY SEMENOV	{"email": "a-semenov16011971@postgrespro.ru", "phone": "+70134152801"}
0005434726347	48C970	4494 058819	MARINA PAVLOVA	{"phone": "+70130669617"}
0005434726348	48C970	5132 108124	NADEZHDA KOZLOVA	{"phone": "+70504945001"}
0005434726349	BEC891	1036 988835	ELENA IVANOVA	{"email": "ivanova.e1981@postgrespro.ru", "phone": "+70291343722"}
0005434726350	862726	2054 313815	YULIYA KOMAROVA	{"email": "komarova.y17101980@postgrespro.ru", "phone": "+70095839551"}
0005434726351	5FE38E	2528 884238	ALEKSANDR ABRAMOV	{"email": "abramovaleksandr-091972@postgrespro.ru", "phone": "+70100741945"}
0005434726352	5FE38E	0863 852314	MARINA VOLKOVA	{"phone": "+70835339068"}
0005434726353	4F6548	8867 116006	OLGA POPOVA	{"phone": "+70147978426"}
0005434726354	12818D	0619 749136	ANATOLIY ZHUKOV	{"phone": "+70385496378"}
0005434726355	12818D	8667 457879	YULIYA KOMAROVA	{"phone": "+70924595054"}
0005434726356	7FEBEE	7529 753448	ALENA FEDOROVA	{"phone": "+70980375721"}
0005434726357	529FA8	0873 796117	KONSTANTIN MEDVEDEV	{"phone": "+70730680413"}
0005434726358	2E0026	5767 862906	TAMARA POLYAKOVA	{"phone": "+70501519881"}
0005434726359	0B4B6C	7886 763753	ALEKSEY TIMOFEEV	{"phone": "+70574629235"}
0005434726360	0B4B6C	5656 768409	VALERIY SOKOLOV	{"phone": "+70680957338"}
0005434726361	0E4105	4765 778076	TAMARA AFANASEVA	{"email": "afanaseva_tamara_07031974@postgrespro.ru", "phone": "+70207776962"}
0005434726362	AEAD5C	0962 996115	ANNA MOROZOVA	{"email": "anna-morozova-071961@postgrespro.ru", "phone": "+70468993520"}
0005434726363	BD42A2	4477 285977	MARINA STEPANOVA	{"phone": "+70805362851"}
0005434726364	B2A216	5274 750812	NATALYA SIDOROVA	{"phone": "+70725051345"}
0005434726365	B2A216	7974 511377	ALEKSANDR ALEKSEEV	{"phone": "+70113354590"}
0005434726366	76301F	7176 065247	NIKOLAY FROLOV	{"email": "nikolay.frolov_14111963@postgrespro.ru", "phone": "+70919830851"}
0005434726367	698EAE	1250 733736	OLGA KUZNECOVA	{"email": "kuznecova-olga.1974@postgrespro.ru", "phone": "+70770553550"}
0005434726368	698EAE	2516 891085	ALEKSEY ABRAMOV	{"email": "abramov-aleksey-1982@postgrespro.ru", "phone": "+70176465471"}
0005434726369	698EAE	7997 477590	ELENA MOROZOVA	{"phone": "+70356585184"}
0005434726370	C43C93	2147 150337	VASILISA ALEKSEEVA	{"phone": "+70601266619"}
0005434726371	9D2B45	6027 543642	ALEKSEY KISELEV	{"phone": "+70211351383"}
0005434726372	9D2B45	6015 381891	ANDREY MAKAROV	{"email": "makarov.a08121963@postgrespro.ru", "phone": "+70239486518"}
0005434726373	E6FE50	3311 564805	VASILIY BONDARENKO	{"email": "vasiliy.bondarenko-29101975@postgrespro.ru", "phone": "+70424873113"}
0005434726374	A36BC8	4302 856758	VERA SEMENOVA	{"phone": "+70854849389"}
0005434726375	A36BC8	1927 991842	NATALYA ANDREEVA	{"phone": "+70509108496"}
0005434726376	BB7A45	6514 794311	VALENTINA KOLESNIKOVA	{"phone": "+70000209969"}
0005434726377	D1D459	9160 800458	VALERIY YAKOVLEV	{"email": "yakovlev.v07061969@postgrespro.ru", "phone": "+70372332356"}
0005434726378	0F2A0A	0563 625582	RAFAIL MOISEEV	{"email": "r_moiseev.04091973@postgrespro.ru", "phone": "+70601743255"}
0005434726379	32CD7B	5357 713871	IGOR FILIPPOV	{"email": "filippov.i_041972@postgrespro.ru", "phone": "+70724175134"}
0005434726380	987084	0151 223944	EKATERINA ZAKHAROVA	{"phone": "+70160872453"}
0005434726381	3911BD	4838 191616	ANDREY SCHERBAKOV	{"phone": "+70266562776"}
0005434726382	3911BD	2264 313642	ALEKSANDR ILIN	{"email": "ailin081959@postgrespro.ru", "phone": "+70124741785"}
0005434726383	609B16	3350 972738	ALEKSANDR KARPOV	{"email": "aleksandr-karpov_1954@postgrespro.ru", "phone": "+70319613193"}
0005434726384	56B678	5246 894407	TATYANA LEBEDEVA	{"email": "lebedeva-tatyana-1971@postgrespro.ru", "phone": "+70801709685"}
0005434726385	56B678	0839 682504	LYUDMILA POTAPOVA	{"email": "potapova_lyudmila06031971@postgrespro.ru", "phone": "+70238928634"}
0005434726386	E8DA81	4367 913300	ANTON ALEKSEEV	{"phone": "+70686850648"}
0005434726387	E8DA81	8751 850812	KLARA EFIMOVA	{"email": "k-efimova.1969@postgrespro.ru", "phone": "+70575022872"}
0005434726388	E8DA81	2214 399858	MAKSIM KOZLOV	{"email": "kozlov_maksim-24021974@postgrespro.ru", "phone": "+70480343795"}
0005434726389	8C04A1	6526 451982	VERA BORISOVA	{"phone": "+70383858943"}
0005434726390	3C0F4E	8029 098770	ZINAIDA FILIPPOVA	{"phone": "+70319646090"}
0005434726391	59C6D2	5781 811285	VIKTOR DENISOV	{"phone": "+70293851027"}
0005434726392	3020BA	0404 672268	ELENA SOROKINA	{"email": "sorokina_e-21121981@postgrespro.ru", "phone": "+70515701344"}
0005434726393	28CAB0	4079 977001	RUSLAN BARANOV	{"phone": "+70129539971"}
0005434726394	A36423	2859 814017	IVAN ALEKSANDROV	{"phone": "+70686447430"}
0005434726395	82E192	5493 587676	ELENA TROFIMOVA	{"email": "e.trofimova-1966@postgrespro.ru", "phone": "+70725179489"}
0005434726396	13C836	3053 291039	NIKOLAY SOLOVEV	{"email": "solovevn.021975@postgrespro.ru", "phone": "+70435264229"}
0005434726517	2153EF	2398 279031	SEMEN NIKOLAEV	{"phone": "+70197852246"}
0005434726397	13C836	9777 670395	VERA FILIPPOVA	{"email": "filippovavera_041974@postgrespro.ru", "phone": "+70120203303"}
0005434726398	FA1216	8259 267306	VIKTOR MAKSIMOV	{"email": "maksimov-viktor1967@postgrespro.ru", "phone": "+70969383722"}
0005434726399	A9EA6F	8509 304830	RUSLAN ZAKHAROV	{"email": "rzakharov_27101977@postgrespro.ru", "phone": "+70322338205"}
0005434726400	A9EA6F	9334 575317	GALINA IVANOVA	{"phone": "+70745851267"}
0005434726401	A9EA6F	2702 694101	VALERIY ANDREEV	{"phone": "+70823612822"}
0005434726402	789A19	8014 446270	ALEKSANDR ILIN	{"phone": "+70614107153"}
0005434726403	2480BD	3530 803313	FEDOR SEMENOV	{"email": "semenov-f-01121968@postgrespro.ru", "phone": "+70868283161"}
0005434726404	2480BD	2518 876919	VLADIMIR GRIGOREV	{"email": "vladimirgrigorev_1980@postgrespro.ru", "phone": "+70168616775"}
0005434726405	2480BD	9158 200948	EKATERINA FADEEVA	{"phone": "+70843477717"}
0005434726406	AE622D	6526 145932	VERONIKA POLYAKOVA	{"phone": "+70455684852"}
0005434726407	AE622D	6809 228619	ALINA MARTYNOVA	{"email": "martynova-a.1966@postgrespro.ru", "phone": "+70007129588"}
0005434726408	FB84EB	1515 925887	DANIIL NIKOLAEV	{"phone": "+70804236918"}
0005434726409	FB84EB	8377 590375	ELENA NAZAROVA	{"email": "nazarova-e_12121978@postgrespro.ru", "phone": "+70398035938"}
0005434726410	91DA86	1373 312292	TATYANA KALININA	{"phone": "+70566225290"}
0005434726411	91DA86	6518 256661	SOFIYA FROLOVA	{"phone": "+70731325500"}
0005434726412	C07913	8345 540574	YULIYA FILATOVA	{"phone": "+70710457348"}
0005434726413	868E02	7833 804797	ROMAN KOROLEV	{"phone": "+70667514853"}
0005434726414	868E02	5620 092787	ALEKSANDRA GERASIMOVA	{"phone": "+70569109240"}
0005434726415	E3B735	4727 595837	VLADIMIR KUZNECOV	{"phone": "+70806151245"}
0005434726416	87614F	7025 776041	SERGEY POPOV	{"phone": "+70716128455"}
0005434726417	C97C7D	1503 840000	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey-02031976@postgrespro.ru", "phone": "+70472663692"}
0005434726418	C97C7D	2683 130421	ALLA MAKSIMOVA	{"email": "amaksimova101973@postgrespro.ru", "phone": "+70230557449"}
0005434726419	D03B42	0781 605708	ANASTASIYA NIKOLAEVA	{"email": "anastasiya_nikolaeva.1977@postgrespro.ru", "phone": "+70458840595"}
0005434726420	26A044	6275 929704	VLADISLAV NIKOLAEV	{"email": "vladislav.nikolaev_071970@postgrespro.ru", "phone": "+70099416290"}
0005434726421	35E03F	3346 261023	DMITRIY FILIPPOV	{"email": "dmitriy_filippov.041972@postgrespro.ru", "phone": "+70283518963"}
0005434726422	35E03F	2950 420433	MARGARITA KOROLEVA	{"email": "koroleva.margarita.11101968@postgrespro.ru", "phone": "+70792043317"}
0005434726423	DD57BC	8376 123934	ELENA DAVYDOVA	{"phone": "+70781679782"}
0005434726424	6BF0A3	4047 573902	ALEKSANDR AFANASEV	{"phone": "+70520628167"}
0005434726425	849F05	5438 473728	ULYANA KOZLOVA	{"phone": "+70508339790"}
0005434726426	C61CF0	1129 142559	PAVEL IVANOV	{"phone": "+70711293251"}
0005434726427	7A5762	2024 798156	VIKTOR FROLOV	{"phone": "+70629055732"}
0005434726428	7A5762	1553 499041	MAKSIM SMIRNOV	{"phone": "+70559002809"}
0005434726429	7A5762	7260 946057	VALERIY MIKHAYLOV	{"phone": "+70830820172"}
0005434726430	CC231B	6284 156852	TATYANA FROLOVA	{"email": "frolova.tatyana.081965@postgrespro.ru", "phone": "+70955621496"}
0005434726431	1A9EED	3641 471247	VALERIY SCHERBAKOV	{"phone": "+70621930043"}
0005434726432	F415DB	4723 193870	ALEKSEY GAVRILOV	{"email": "aleksey_gavrilov_1964@postgrespro.ru", "phone": "+70860563222"}
0005434726433	58E8B5	1950 785699	VALENTINA FROLOVA	{"phone": "+70221082272"}
0005434726434	0756C1	4911 803017	VLADIMIR MAKSIMOV	{"phone": "+70812222153"}
0005434726435	C6763F	7153 481768	TATYANA ZHUKOVA	{"phone": "+70359756761"}
0005434726436	FAC154	0190 105072	ANASTASIYA PETROVA	{"email": "petrova-a.10091970@postgrespro.ru", "phone": "+70906319052"}
0005434726437	77D3C1	8153 235064	DMITRIY BELOV	{"email": "dmitriy.belov.1974@postgrespro.ru", "phone": "+70992744897"}
0005434726438	240B4D	4852 633317	PETR DAVYDOV	{"email": "petr_davydov1970@postgrespro.ru", "phone": "+70211703447"}
0005434726439	826BC2	2497 752697	ANTONINA TITOVA	{"phone": "+70530339939"}
0005434726440	862AB2	8937 477407	SVETLANA NIKITINA	{"email": "nikitinasvetlana.121988@postgrespro.ru", "phone": "+70300818660"}
0005434726441	168686	4242 850328	EGOR PETROV	{"email": "egorpetrov.1969@postgrespro.ru", "phone": "+70811363753"}
0005434726554	EA61D2	8828 225763	ZINAIDA EFREMOVA	{"phone": "+70758556713"}
0005434726442	A9BEC2	1392 552686	VYACHESLAV SCHERBAKOV	{"phone": "+70656059337"}
0005434726443	A9BEC2	7181 255509	MAKSIM BARANOV	{"phone": "+70654643697"}
0005434726444	8E2A4E	8908 336305	VENIAMIN KUZNECOV	{"phone": "+70102098771"}
0005434726445	8E2A4E	3841 886493	VLADIMIR KOZLOV	{"email": "kozlovvladimir.1975@postgrespro.ru", "phone": "+70744175344"}
0005434726446	025C11	2719 729120	OLGA BARANOVA	{"email": "baranova.olga.04091971@postgrespro.ru", "phone": "+70004636024"}
0005434726447	025C11	0387 815839	ALEKSEY FEDOROV	{"email": "afedorov.051967@postgrespro.ru", "phone": "+70434776949"}
0005434726448	A6EA26	7577 128526	ELENA KUZMINA	{"email": "ekuzmina1983@postgrespro.ru", "phone": "+70260812772"}
0005434726449	245603	2003 051889	VASILIY GORBUNOV	{"phone": "+70858356812"}
0005434726450	063431	6275 233073	ELENA ALEKSEEVA	{"email": "alekseeva_elena_12011978@postgrespro.ru", "phone": "+70059443082"}
0005434726451	BD42A9	8864 962953	OLGA SIDOROVA	{"phone": "+70168159691"}
0005434726452	E56445	3850 727143	ALEKSANDR FILIPPOV	{"email": "filippov_aleksandr_031963@postgrespro.ru", "phone": "+70785903360"}
0005434726453	EDBF48	2875 828952	DARYA FILATOVA	{"email": "filatovadarya.06051977@postgrespro.ru", "phone": "+70018118946"}
0005434726454	9D699B	5045 813191	ALENA POPOVA	{"email": "popova_alena1977@postgrespro.ru", "phone": "+70429367966"}
0005434726455	B0FD50	0172 702474	ELENA MOISEEVA	{"email": "moiseeva.e_20011978@postgrespro.ru", "phone": "+70419464372"}
0005434726456	2FE752	9240 381969	DMITRIY IVANOV	{"phone": "+70870367835"}
0005434726457	B091C8	3392 122837	OLGA GUSEVA	{"email": "o.guseva.071979@postgrespro.ru", "phone": "+70825850229"}
0005434726458	B091C8	6983 178940	ELENA VASILEVA	{"phone": "+70214395627"}
0005434726459	E1E747	5427 216260	GALINA MAKSIMOVA	{"phone": "+70931978190"}
0005434726460	E1E747	3778 946935	ALINA NIKOLAEVA	{"phone": "+70705969541"}
0005434726461	7F5895	5348 251160	VIKTOR KAZAKOV	{"phone": "+70202187911"}
0005434726462	A69C6F	4873 740615	YAKOV ABRAMOV	{"phone": "+70715722260"}
0005434726463	1797B8	0831 969351	ALEKSEY CHERNOV	{"email": "chernov.a041970@postgrespro.ru", "phone": "+70594088696"}
0005434726464	23F5BF	4740 782647	YULIYA KUDRYASHOVA	{"phone": "+70269778957"}
0005434726465	23F5BF	4681 075733	INNA ANDREEVA	{"phone": "+70588595069"}
0005434726466	7FC308	7631 190213	LARISA EFIMOVA	{"email": "lefimova03051978@postgrespro.ru", "phone": "+70047288208"}
0005434726467	7FC308	2397 335228	ALEKSANDR NAUMOV	{"email": "a-naumov.1977@postgrespro.ru", "phone": "+70095323258"}
0005434726468	E6B849	5824 893316	ARTEM DMITRIEV	{"email": "dmitrieva_041974@postgrespro.ru", "phone": "+70310018700"}
0005434726469	E6B849	9993 907233	ALEKSEY BORISOV	{"email": "a.borisov_1958@postgrespro.ru", "phone": "+70299484683"}
0005434726470	AB443B	5687 976372	ALISA NIKITINA	{"email": "nikitina.alisa-04091981@postgrespro.ru", "phone": "+70326316033"}
0005434726471	FE159C	1923 728985	ALEKSANDR GORBUNOV	{"phone": "+70779551068"}
0005434726472	ACB416	2988 210550	SERGEY KUZNECOV	{"email": "s.kuznecov.01041972@postgrespro.ru", "phone": "+70885420010"}
0005434726473	ACB416	9206 679632	OLGA IVANOVA	{"phone": "+70486462971"}
0005434726474	15B67C	6820 767292	DMITRIY SHEVCHENKO	{"email": "dmitriy-shevchenko_1978@postgrespro.ru", "phone": "+70464915417"}
0005434726475	15B67C	2149 667718	IRINA MOISEEVA	{"phone": "+70467213856"}
0005434726476	A2F6DA	0896 146780	ZOYA EGOROVA	{"email": "z-egorova_17121971@postgrespro.ru", "phone": "+70619008687"}
0005434726477	A2F6DA	1677 666370	TATYANA NIKITINA	{"phone": "+70406841505"}
0005434726478	E5DDF3	9546 913818	MARIYA SEMENOVA	{"email": "m_semenova-08061974@postgrespro.ru", "phone": "+70677681721"}
0005434726479	46281C	2051 796823	ALEKSANDRA KONDRATEVA	{"phone": "+70679689413"}
0005434726480	6F477F	0143 803629	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev.061976@postgrespro.ru", "phone": "+70000307033"}
0005434726481	3DB4ED	9671 555171	OLGA ROMANOVA	{"email": "romanova-o_091981@postgrespro.ru", "phone": "+70531127152"}
0005434726482	03717E	4677 113903	KLAVDIYA STEPANOVA	{"email": "stepanova.k_02071982@postgrespro.ru", "phone": "+70401407864"}
0005434726483	03717E	5961 050380	SERGEY BORISOV	{"email": "s-borisov_22021963@postgrespro.ru", "phone": "+70296011382"}
0005434726484	03717E	7658 587081	VYACHESLAV STEPANOV	{"phone": "+70667633892"}
0005434726485	EC4253	8517 697874	VALERIY KOROLEV	{"email": "korolev.valeriy_021978@postgrespro.ru", "phone": "+70960824171"}
0005434726486	94806D	6534 654544	NIKOLAY OSIPOV	{"phone": "+70132855010"}
0005434726487	F71C7B	0674 096899	ALBINA PETROVA	{"email": "petrova-a_081970@postgrespro.ru", "phone": "+70335700866"}
0005434726488	741883	6505 051510	OKSANA YAKOVLEVA	{"email": "yakovlevao_071964@postgrespro.ru", "phone": "+70766525903"}
0005434726489	509E06	8224 467818	DARYA SOROKINA	{"phone": "+70402022719"}
0005434726490	ECB2DA	7552 705561	EKATERINA IVANOVA	{"phone": "+70591879557"}
0005434726491	12DCFE	1557 000570	ELENA NAZAROVA	{"email": "nazarovae.31121981@postgrespro.ru", "phone": "+70382298948"}
0005434726492	27552E	1915 516493	YULIYA BORISOVA	{"phone": "+70545367312"}
0005434726493	2A2300	4708 830515	SERGEY ALEKSEEV	{"email": "alekseev.s1964@postgrespro.ru", "phone": "+70308928936"}
0005434726494	2A2300	7158 734629	ALEKSANDR POPOV	{"phone": "+70410401710"}
0005434726495	62FAB7	0681 915563	DMITRIY EGOROV	{"phone": "+70079882971"}
0005434726496	62FAB7	0397 255613	DANILA SCHERBAKOV	{"phone": "+70977858672"}
0005434726497	1499F6	1634 906946	SVETLANA FILATOVA	{"phone": "+70191367596"}
0005434726498	1499F6	9212 015809	ANNA POPOVA	{"email": "anna_popova01121972@postgrespro.ru", "phone": "+70946052173"}
0005434726499	E12324	8606 117219	SERGEY FROLOV	{"phone": "+70849958633"}
0005434726500	788EB7	2490 472450	VALENTINA FROLOVA	{"phone": "+70538771352"}
0005434726501	42B64E	5238 185737	VALERIY ZHUKOV	{"email": "v-zhukov_031977@postgrespro.ru", "phone": "+70471188221"}
0005434726502	42B64E	0470 262306	TATYANA AFANASEVA	{"email": "afanaseva-t_1973@postgrespro.ru", "phone": "+70531684711"}
0005434726503	0A4539	2459 775592	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov_1974@postgrespro.ru", "phone": "+70852111508"}
0005434726504	0A4539	2651 934825	EVDOKIYA TROFIMOVA	{"phone": "+70221127045"}
0005434726505	B435C8	7422 587820	VALERIY PETROV	{"email": "valeriy-petrov.021985@postgrespro.ru", "phone": "+70374356413"}
0005434726506	B435C8	1344 911442	KSENIYA MALYSHEVA	{"phone": "+70902382069"}
0005434726507	864A1D	0952 204458	TAMARA KUZNECOVA	{"email": "t.kuznecova_27061971@postgrespro.ru", "phone": "+70510699422"}
0005434726508	864A1D	6092 691605	VLADISLAV GORBUNOV	{"email": "v_gorbunov.26011967@postgrespro.ru", "phone": "+70242514104"}
0005434726509	339FE9	4137 736681	EVGENIY TIKHONOV	{"email": "e-tikhonov.24121968@postgrespro.ru", "phone": "+70640495630"}
0005434726510	FD0F7B	7310 567475	SERGEY CHERNOV	{"phone": "+70951266035"}
0005434726511	BCE482	1178 618242	OLGA MASLOVA	{"phone": "+70939661188"}
0005434726512	94022D	7110 639284	SERGEY IVANOV	{"email": "ivanov_s-24031971@postgrespro.ru", "phone": "+70807345210"}
0005434726513	1D18F6	5908 886057	ALEKSANDR TIKHONOV	{"email": "tikhonova.1981@postgrespro.ru", "phone": "+70461503010"}
0005434726514	1D18F6	5475 085497	SERGEY OSIPOV	{"email": "sergey-osipov-111966@postgrespro.ru", "phone": "+70443129727"}
0005434726515	3863AD	7302 427612	YURIY ALEKSANDROV	{"email": "aleksandrov_y04011954@postgrespro.ru", "phone": "+70614677926"}
0005434726516	078920	9804 194995	IRINA STEPANOVA	{"phone": "+70641080531"}
0005434726518	E816D3	2317 242154	EGOR SOROKIN	{"email": "sorokin_e-1958@postgrespro.ru", "phone": "+70689878593"}
0005434726519	1F767E	6801 952150	ALEKSANDR FEDOROV	{"phone": "+70196001353"}
0005434726520	C60EE7	0230 592546	OLGA PETROVA	{"email": "olga-petrova_17061979@postgrespro.ru", "phone": "+70086865409"}
0005434726521	E3CB9D	4624 442669	LIDIYA CHERNOVA	{"phone": "+70821025783"}
0005434726522	5AA9D8	4503 344495	OLGA SOROKINA	{"phone": "+70449373197"}
0005434726523	5AA9D8	2279 619067	NADEZHDA FILATOVA	{"email": "nadezhda-filatova-1976@postgrespro.ru", "phone": "+70243257241"}
0005434726524	0FE728	4220 598739	NIKOLAY SERGEEV	{"phone": "+70019185749"}
0005434726525	0FE728	6957 453935	VALERIY FOMIN	{"email": "fomin-valeriy_28021970@postgrespro.ru", "phone": "+70079989137"}
0005434726526	5C1E8F	0508 268873	ALEKSANDR NOVIKOV	{"phone": "+70383317184"}
0005434726527	931838	7766 113226	PAVEL DMITRIEV	{"phone": "+70929873922"}
0005434726528	5C3B27	6845 193182	NIKITA IVANOV	{"email": "ivanovn.25021968@postgrespro.ru", "phone": "+70675243609"}
0005434726529	40CA98	1757 836628	YULIYA PETROVA	{"email": "petrova-yuliya.1969@postgrespro.ru", "phone": "+70442680588"}
0005434726530	40CA98	4783 268244	VLADIMIR KUZNECOV	{"email": "kuznecovv.111972@postgrespro.ru", "phone": "+70584247009"}
0005434726531	AC636B	8466 744171	ANDREY GUSEV	{"phone": "+70549552709"}
0005434726532	E073EA	9170 041436	OLGA BOGDANOVA	{"email": "o-bogdanova.1969@postgrespro.ru", "phone": "+70084526295"}
0005434726533	684F3E	0485 410713	KLAVDIYA DAVYDOVA	{"email": "davydova.k.071975@postgrespro.ru", "phone": "+70120099926"}
0005434726534	684F3E	1854 856406	IRINA ZAKHAROVA	{"phone": "+70337028690"}
0005434726535	139BA7	9975 094609	MAKSIM KUZNECOV	{"email": "m-kuznecov-18041979@postgrespro.ru", "phone": "+70683685834"}
0005434726536	0E0730	9169 615161	MARIYA PETROVA	{"phone": "+70474619549"}
0005434726537	0E0730	0293 109441	EKATERINA KALININA	{"email": "ekalinina22061981@postgrespro.ru", "phone": "+70018758661"}
0005434726538	1D1EBA	9461 246964	LYUDMILA ERMAKOVA	{"phone": "+70630128739"}
0005434726539	1D1EBA	3908 245025	MARIYA KOROLEVA	{"email": "koroleva-m.011982@postgrespro.ru", "phone": "+70134780083"}
0005434726540	05B298	9285 804879	SERGEY PAVLOV	{"phone": "+70647731863"}
0005434726541	CB966C	0133 247551	ELENA NIKITINA	{"email": "e_nikitina_1980@postgrespro.ru", "phone": "+70129987289"}
0005434726542	F4F540	6606 133247	REGINA ANDREEVA	{"email": "regina_andreeva.05041969@postgrespro.ru", "phone": "+70361908281"}
0005434726543	F4F540	2582 715028	NINA ALEKSANDROVA	{"phone": "+70705797131"}
0005434726544	38C902	0975 875380	TATYANA PAVLOVA	{"phone": "+70835288598"}
0005434726545	38C902	1521 569623	VIKTOR DAVYDOV	{"email": "v.davydov.06031967@postgrespro.ru", "phone": "+70779925174"}
0005434726546	6E714E	2580 755852	VASILIY ISAEV	{"phone": "+70541232569"}
0005434726547	14F2F5	5966 087903	NATALIYA OVCHINNIKOVA	{"phone": "+70719176358"}
0005434726548	14F2F5	7248 089086	TATYANA IVANOVA	{"email": "ivanova-tatyana.11071975@postgrespro.ru", "phone": "+70957259092"}
0005434726549	BA5933	9289 172789	KSENIYA KUZMINA	{"email": "kseniyakuzmina.1972@postgrespro.ru", "phone": "+70707705141"}
0005434726550	BA5933	0892 654090	ALEKSANDR POPOV	{"phone": "+70846256988"}
0005434726551	8929FB	8183 691383	RAVIL BONDARENKO	{"email": "ravilbondarenko.031978@postgrespro.ru", "phone": "+70927571649"}
0005434726552	8929FB	5384 159716	NATALYA MIKHAYLOVA	{"phone": "+70245739361"}
0005434726553	EA61D2	7237 197054	NATALYA NIKITINA	{"phone": "+70085261041"}
0005434726555	B3B568	6249 802683	VLADIMIR MOISEEV	{"phone": "+70260424233"}
0005434726556	B3B568	3993 725443	KIRILL GERASIMOV	{"email": "kirill_gerasimov-121959@postgrespro.ru", "phone": "+70278590993"}
0005434726557	048718	8301 134214	VIKTOR SOLOVEV	{"email": "solovevviktor.1969@postgrespro.ru", "phone": "+70081260982"}
0005434726558	C7CCF6	5202 527093	ALEKSANDR BORISOV	{"phone": "+70121906827"}
0005434726559	C7CCF6	3339 362153	NIKOLAY GAVRILOV	{"email": "nikolaygavrilov-091986@postgrespro.ru", "phone": "+70237035251"}
0005434726560	BE4F14	0856 208339	NELLYA KUZNECOVA	{"phone": "+70016677606"}
0005434726561	428EAC	3068 145292	LYUDMILA PETROVA	{"email": "l_petrova1985@postgrespro.ru", "phone": "+70419177871"}
0005434726562	535311	6193 547074	LARISA SOROKINA	{"email": "lsorokina_111982@postgrespro.ru", "phone": "+70447093403"}
0005434726563	9031F2	7479 108786	DMITRIY ZAKHAROV	{"email": "d_zakharov-011965@postgrespro.ru", "phone": "+70800354260"}
0005434726564	645CEB	3820 124085	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov.061972@postgrespro.ru", "phone": "+70502432301"}
0005434726565	645CEB	7088 217865	AYRAT SMIRNOV	{"email": "ayratsmirnov_1978@postgrespro.ru", "phone": "+70468275754"}
0005434726566	645CEB	7072 592303	PAVEL ROMANOV	{"email": "p.romanov-1981@postgrespro.ru", "phone": "+70806718338"}
0005434726567	1251F5	1002 865034	TATYANA MAKAROVA	{"email": "t_makarova1978@postgrespro.ru", "phone": "+70926871613"}
0005434726568	DA87A0	4027 997373	OLEG ANDREEV	{"phone": "+70291462399"}
0005434726569	CEE4FB	5910 862431	IVAN MATVEEV	{"email": "i_matveev021984@postgrespro.ru", "phone": "+70767290697"}
0005434726570	07DDA1	4899 459503	TATYANA YUDINA	{"email": "yudina_t.1968@postgrespro.ru", "phone": "+70757850474"}
0005434726571	1480AF	9494 922523	SVETLANA DANILOVA	{"phone": "+70334612924"}
0005434726572	1480AF	1941 894916	KARINA IVANOVA	{"email": "kivanova1975@postgrespro.ru", "phone": "+70770227368"}
0005434726573	62277D	9262 594368	DMITRIY AFANASEV	{"email": "afanasev.d-1966@postgrespro.ru", "phone": "+70377565115"}
0005434726575	56135B	2534 077778	ARTEM SOLOVEV	{"email": "solovev.artem_031984@postgrespro.ru", "phone": "+70501028766"}
0005434726576	56135B	3306 042901	ANDREY SOROKIN	{"phone": "+70799679626"}
0005434726577	47225D	7197 273095	IVAN FEDOROV	{"email": "ivanfedorov_10071976@postgrespro.ru", "phone": "+70725589825"}
0005434726578	87B971	6933 938779	VERONIKA PETROVA	{"email": "vpetrova_1968@postgrespro.ru", "phone": "+70346286068"}
0005434726579	0EF3DF	4349 425035	ANASTASIYA VASILEVA	{"phone": "+70701427445"}
0005434726580	1A258B	6945 342756	POLINA BARANOVA	{"email": "polina_baranova_051979@postgrespro.ru", "phone": "+70047630218"}
0005434726581	839EFE	4709 222435	NATALYA TITOVA	{"email": "n-titova-08041980@postgrespro.ru", "phone": "+70133194246"}
0005434726582	47C09B	9335 433760	YURIY ISAEV	{"phone": "+70735228790"}
0005434726583	1923E7	8021 547418	ARTEM KULIKOV	{"email": "kulikovartem1975@postgrespro.ru", "phone": "+70189027649"}
0005434726584	1B7382	4385 721420	NIKOLAY ANTONOV	{"phone": "+70189466545"}
0005434726585	9B598E	9226 375232	EVGENIY PETROV	{"email": "petrov.evgeniy.021974@postgrespro.ru", "phone": "+70813166720"}
0005434726586	87AC21	7799 521759	GENNADIY SHEVCHENKO	{"email": "g-shevchenko.061975@postgrespro.ru", "phone": "+70699976690"}
0005434726587	78A763	1031 703557	ALEKSANDR KOZLOV	{"email": "aleksandrkozlov14021965@postgrespro.ru", "phone": "+70787970729"}
0005434726588	D26849	5294 766551	DMITRIY ZAYCEV	{"email": "zaycev_d011974@postgrespro.ru", "phone": "+70983271503"}
0005434726589	D26849	5800 731299	SERGEY KOZLOV	{"phone": "+70626463882"}
0005434726590	A3DB75	8295 117100	EKATERINA YAKOVLEVA	{"phone": "+70273327938"}
0005434726591	DCEFE4	8331 697356	ELENA VASILEVA	{"email": "vasileva_elena-061979@postgrespro.ru", "phone": "+70140708659"}
0005434726592	3737F1	0266 830705	MADINA FEDOROVA	{"phone": "+70537672508"}
0005434726593	A445B5	3273 850658	VALERIY AFANASEV	{"email": "valeriy_afanasev_02031975@postgrespro.ru", "phone": "+70557379948"}
0005434726594	A445B5	6355 098847	RAISA MOROZOVA	{"email": "morozova-raisa_051977@postgrespro.ru", "phone": "+70916346410"}
0005434726595	30E870	9562 125532	DENIS AFANASEV	{"phone": "+70798144981"}
0005434726596	73B97A	8158 720493	PAVEL KAZAKOV	{"email": "pavel_kazakov-06071968@postgrespro.ru", "phone": "+70358325384"}
0005434726597	DE0DDE	5896 409282	VALENTINA SMIRNOVA	{"phone": "+70834048116"}
0005434726598	CE633E	6561 803351	VALENTINA ABRAMOVA	{"email": "valentina-abramova_30091963@postgrespro.ru", "phone": "+70143492218"}
0005434726599	CE633E	2154 764151	ARTEM CHERNOV	{"phone": "+70016036145"}
0005434726600	B4201B	9259 388107	PAVEL KOROLEV	{"phone": "+70057624254"}
0005434726601	5E5B48	8803 740381	ALEKSANDR SCHERBAKOV	{"phone": "+70863756674"}
0005434726602	5E5B48	0874 737861	OLGA DAVYDOVA	{"email": "olga_davydova.03011988@postgrespro.ru", "phone": "+70528351895"}
0005434726603	0A885F	8611 019842	ELMIRA NIKOLAEVA	{"email": "e_nikolaeva-051971@postgrespro.ru", "phone": "+70313160531"}
0005434726604	0A885F	7070 443216	VIKTOR MAKAROV	{"email": "viktor-makarov1978@postgrespro.ru", "phone": "+70350378743"}
0005434726605	AB4C98	7314 449476	ROMAN ANTONOV	{"phone": "+70584914860"}
0005434726606	AB4C98	2135 892498	LYUDMILA GRISHINA	{"phone": "+70020328535"}
0005434726607	595955	6605 495869	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir091965@postgrespro.ru", "phone": "+70360987738"}
0005434726608	595955	3939 338475	MIKHAIL ZAKHAROV	{"email": "zakharov_m.29081978@postgrespro.ru", "phone": "+70178514899"}
0005434726609	14BCD3	4191 886918	SVETLANA POPOVA	{"email": "svetlanapopova_1965@postgrespro.ru", "phone": "+70523648999"}
0005434726610	4B6889	3958 878039	IGOR ALEKSEEV	{"phone": "+70484963777"}
0005434726611	4B6889	8412 454104	VIOLETTA MEDVEDEVA	{"email": "medvedevavioletta-1976@postgrespro.ru", "phone": "+70020451846"}
0005434726612	8ACE23	1078 905135	GALINA TITOVA	{"phone": "+70251317425"}
0005434726613	ACAA68	5721 168621	RAMIL ABRAMOV	{"phone": "+70783159317"}
0005434726614	5E0EA0	6297 257373	SVETLANA MIKHAYLOVA	{"email": "s-mikhaylova_091986@postgrespro.ru", "phone": "+70144579319"}
0005434726615	5E0EA0	5404 894712	GALINA TIMOFEEVA	{"email": "galinatimofeeva.021968@postgrespro.ru", "phone": "+70942960744"}
0005434726616	7538A6	3831 314707	ANASTASIYA POPOVA	{"email": "a.popova.13091980@postgrespro.ru", "phone": "+70685448731"}
0005434726617	060BF9	2476 361816	ILYA KAZAKOV	{"phone": "+70017405402"}
0005434726618	170055	4321 085447	VLADIMIR TIMOFEEV	{"email": "v-timofeev_26091971@postgrespro.ru", "phone": "+70168071428"}
0005434726619	170055	6343 834642	NADEZHDA KARPOVA	{"phone": "+70114724305"}
0005434726620	E99C9E	9281 266293	TATYANA GRISHINA	{"phone": "+70238895961"}
0005434726621	E99C9E	6551 776244	DMITRIY TIMOFEEV	{"phone": "+70450974494"}
0005434726622	E99C9E	1468 598042	GALINA POPOVA	{"email": "g_popova_03041970@postgrespro.ru", "phone": "+70638620545"}
0005434726623	84FC18	4778 373966	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr.25101975@postgrespro.ru", "phone": "+70279461254"}
0005434726624	61A129	3887 912550	MIKHAIL ZAYCEV	{"phone": "+70760915757"}
0005434726625	603E28	2923 387319	LYUBOV KUZNECOVA	{"email": "l.kuznecova_05061973@postgrespro.ru", "phone": "+70710433747"}
0005434726626	6261CC	2066 129929	ROMAN KRASNOV	{"email": "krasnovroman_08121975@postgrespro.ru", "phone": "+70294138853"}
0005434726627	6261CC	9341 340582	OLGA MAKAROVA	{"email": "o-makarova-041983@postgrespro.ru", "phone": "+70045418985"}
0005434726628	23C760	6023 758680	NATALYA OSIPOVA	{"email": "natalya-osipova-27011983@postgrespro.ru", "phone": "+70880105389"}
0005434726629	23C760	7985 667339	VERA FILIPPOVA	{"phone": "+70732226279"}
0005434726630	632ED3	0666 672099	ALEKSANDR PETROV	{"email": "petrov-aleksandr1962@postgrespro.ru", "phone": "+70194007017"}
0005434726631	219A85	3549 604939	OLGA KUZNECOVA	{"phone": "+70402226448"}
0005434726632	774954	2707 748481	DMITRIY NAUMOV	{"phone": "+70840659295"}
0005434726633	68B86E	9090 499350	ANDREY SEMENOV	{"email": "andrey_semenov071982@postgrespro.ru", "phone": "+70177902861"}
0005434726634	A271A2	6359 308542	ELENA MAKAROVA	{"email": "elena-makarova-091959@postgrespro.ru", "phone": "+70331769800"}
0005434726635	99E0E9	4142 367980	OKSANA VASILEVA	{"phone": "+70797926906"}
0005434726636	EBCE2A	5145 068959	ELENA OSIPOVA	{"email": "osipova_elena.01041982@postgrespro.ru", "phone": "+70798105845"}
0005434726637	AD4955	1917 693980	NATALYA NIKOLAEVA	{"email": "nikolaevanatalya-1970@postgrespro.ru", "phone": "+70641358865"}
0005434726638	7EE6DE	5686 007941	MARIYA ANDREEVA	{"phone": "+70493901916"}
0005434726639	59A761	0667 978345	ROMAN NAZAROV	{"email": "roman-nazarov_021970@postgrespro.ru", "phone": "+70584119823"}
0005434726640	1D7DF7	4656 685881	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov_1964@postgrespro.ru", "phone": "+70663609231"}
0005434726641	1D7DF7	0687 182178	ELENA IVANOVA	{"phone": "+70862299458"}
0005434726642	746304	5212 314327	MARINA NESTEROVA	{"email": "m_nesterova-1979@postgrespro.ru", "phone": "+70525222112"}
0005434726643	C3EFC0	3437 430064	NINA DAVYDOVA	{"email": "n.davydova_23041987@postgrespro.ru", "phone": "+70204584796"}
0005434726644	C2D866	0399 167601	OLGA YAKOVLEVA	{"email": "olga-yakovleva_1977@postgrespro.ru", "phone": "+70643894646"}
0005434726645	C2D866	3303 567919	MARAT MAKAROV	{"phone": "+70222641070"}
0005434726646	662648	7863 801968	MARIYA ALEKSEEVA	{"phone": "+70331643740"}
0005434726647	3A63A4	1492 598942	VADIM ORLOV	{"phone": "+70102213057"}
0005434726648	3A63A4	1317 989033	NADEZHDA MELNIKOVA	{"phone": "+70297593410"}
0005434726649	3A63A4	2056 408093	OLGA KULIKOVA	{"email": "olgakulikova-1975@postgrespro.ru", "phone": "+70376235145"}
0005434726650	229032	3175 173628	ANNA IVANOVA	{"email": "anna.ivanova101971@postgrespro.ru", "phone": "+70140712992"}
0005434726651	9BCD89	7020 898581	KIRILL MAKAROV	{"phone": "+70627926890"}
0005434726652	465AB4	8488 736743	OLGA VOLKOVA	{"email": "o_volkova.061965@postgrespro.ru", "phone": "+70419758410"}
0005434726653	52107E	0381 645573	DMITRIY ROMANOV	{"phone": "+70945379781"}
0005434726654	1E8F8F	4346 973320	GALINA BOGDANOVA	{"phone": "+70532695464"}
0005434726655	1CDB10	7474 845782	SOFIYA KOVALEVA	{"email": "sofiya_kovaleva.081970@postgrespro.ru", "phone": "+70224101435"}
0005434726656	64A666	1130 210272	VALERIYA ZAKHAROVA	{"email": "zakharova_v.08091977@postgrespro.ru", "phone": "+70740268286"}
0005434726657	64A666	4021 984753	SOFYA IVANOVA	{"phone": "+70233177542"}
0005434726658	BA8E30	8070 675073	ELENA ALEKSEEVA	{"phone": "+70610035803"}
0005434726659	92CB5E	3684 695185	VALENTINA NOVIKOVA	{"email": "valentinanovikova_26081972@postgrespro.ru", "phone": "+70780448085"}
0005434726660	DC096E	7775 362782	SOFYA KAZAKOVA	{"email": "kazakova_sofya_121963@postgrespro.ru", "phone": "+70275101326"}
0005434726661	B6051B	6496 059334	SVETLANA SOKOLOVA	{"phone": "+70694917295"}
0005434726662	C02164	7645 804815	VALENTIN FILIPPOV	{"email": "v-filippov-101966@postgrespro.ru", "phone": "+70697949274"}
0005434726663	F7A08B	5335 991945	YAROSLAV ZAKHAROV	{"phone": "+70381328440"}
0005434726664	B189BF	7962 958048	SNEZHANA ZOTOVA	{"email": "s.zotova-1965@postgrespro.ru", "phone": "+70163616083"}
0005434726665	C50042	6168 162503	MARIYA DENISOVA	{"email": "m_denisova.051973@postgrespro.ru", "phone": "+70331497007"}
0005434726666	C50042	8445 835440	VITALIY CHERNOV	{"phone": "+70033884585"}
0005434726667	49D1FD	2496 490170	TAMARA POLYAKOVA	{"email": "tamarapolyakova1969@postgrespro.ru", "phone": "+70425365295"}
0005434726668	49D1FD	1948 337948	MAKSIM ANDREEV	{"phone": "+70405290250"}
0005434726669	1AC959	6490 677796	ANNA LEBEDEVA	{"phone": "+70484929582"}
0005434726670	84A442	4172 741650	INGA SOROKINA	{"email": "ingasorokina.051962@postgrespro.ru", "phone": "+70448173829"}
0005434726671	84A442	2074 356490	MARINA EGOROVA	{"email": "egorova_marina1978@postgrespro.ru", "phone": "+70210082309"}
0005434726672	6A88E2	6749 635548	STANISLAV MAKAROV	{"phone": "+70215454250"}
0005434726673	6A88E2	6201 248265	VYACHESLAV ZHURAVLEV	{"email": "vzhuravlev-24111981@postgrespro.ru", "phone": "+70784405631"}
0005434726674	291693	9856 813748	OLEG MEDVEDEV	{"phone": "+70181251581"}
0005434726675	284E8A	7076 913280	VIKTOR BORISOV	{"email": "v_borisov.031975@postgrespro.ru", "phone": "+70054255771"}
0005434726676	443A86	4895 774497	ALEKSANDR MIRONOV	{"email": "mironov.aleksandr_12081975@postgrespro.ru", "phone": "+70780829669"}
0005434726677	E926D2	1492 462823	VYACHESLAV NAZAROV	{"phone": "+70291395774"}
0005434726678	E176F0	1574 706810	VIKTOR ZHURAVLEV	{"email": "zhuravlev-viktor_20081986@postgrespro.ru", "phone": "+70067430985"}
0005434726679	E176F0	7359 584925	EVGENIY GERASIMOV	{"email": "evgeniy-gerasimov.041970@postgrespro.ru", "phone": "+70021431170"}
0005434726680	11CE11	6874 028184	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay.01061968@postgrespro.ru", "phone": "+70877481974"}
0005434726681	8C09DC	3545 222530	MARGARITA LEBEDEVA	{"phone": "+70481323175"}
0005434726682	F2AE66	1699 677958	ANATOLIY ANDREEV	{"email": "andreev.anatoliy_1969@postgrespro.ru", "phone": "+70935704878"}
0005434726683	9404EF	8694 404742	ALEKSANDR ANDREEV	{"phone": "+70054592417"}
0005434726684	484037	1654 995091	KSENIYA SOROKINA	{"phone": "+70821141755"}
0005434726685	36CF66	0384 044612	ANASTASIYA PETROVA	{"email": "anastasiya_petrova_10031967@postgrespro.ru", "phone": "+70918778172"}
0005434726686	36CF66	7128 933880	ANNA TARASOVA	{"email": "tarasovaanna.051964@postgrespro.ru", "phone": "+70841071146"}
0005434726687	6DFCD7	1911 812968	EVGENIY KULIKOV	{"phone": "+70774526447"}
0005434726688	D08153	1785 100495	YULIYA EFIMOVA	{"email": "efimovayuliya15111975@postgrespro.ru", "phone": "+70930412798"}
0005434726689	D08153	0713 257590	MAKSIM MATVEEV	{"phone": "+70395526413"}
0005434726690	D08153	8706 267615	ANDREY VASILEV	{"phone": "+70030524500"}
0005434726691	935A04	2508 714556	KLAVDIYA GERASIMOVA	{"email": "k.gerasimova.13091969@postgrespro.ru", "phone": "+70048111898"}
0005434726692	A6F3A1	4556 210113	ANTON YAKOVLEV	{"phone": "+70665497946"}
0005434726693	A6F3A1	7185 105007	ELIZAVETA YAKOVLEVA	{"phone": "+70621189946"}
0005434726694	A6F3A1	2738 342710	ANNA NESTEROVA	{"email": "a.nesterova.27021964@postgrespro.ru", "phone": "+70175661497"}
0005434726695	7B9C2E	9134 812983	VASILIY MAKSIMOV	{"phone": "+70697912785"}
0005434726696	343DF7	3799 210335	VLADISLAV BONDARENKO	{"email": "v_bondarenko-1984@postgrespro.ru", "phone": "+70800345806"}
0005434726757	BA1F08	5879 611193	MIKHAIL VASILEV	{"phone": "+70028561277"}
0005434726697	343DF7	3759 240481	ZOYA ALEKSANDROVA	{"email": "aleksandrova_z_1965@postgrespro.ru", "phone": "+70711325449"}
0005434726698	343DF7	8043 300145	ARTEM SEMENOV	{"email": "semenov_a-071962@postgrespro.ru", "phone": "+70920471316"}
0005434726699	A91105	0348 604642	SERGEY POPOV	{"phone": "+70225884296"}
0005434726700	A91105	4557 316458	NIKOLAY VASILEV	{"phone": "+70513530872"}
0005434726701	C53AA1	3970 544117	YAKOV ALEKSEEV	{"phone": "+70894052817"}
0005434726702	454FB7	8916 206471	DMITRIY GORBUNOV	{"phone": "+70376533397"}
0005434726703	454FB7	3302 731138	NATALYA ROMANOVA	{"phone": "+70700337765"}
0005434726704	5B0A4C	7704 117223	VLADIMIR SCHERBAKOV	{"phone": "+70056924553"}
0005434726705	DC5106	4607 035469	DAMIR MAKSIMOV	{"email": "maksimov-d_05101978@postgrespro.ru", "phone": "+70061390951"}
0005434726706	E2EB30	5253 885227	TATYANA GUSEVA	{"phone": "+70912208224"}
0005434726707	E2EB30	7813 761483	ELIZAVETA MOROZOVA	{"email": "morozovae_01081969@postgrespro.ru", "phone": "+70460278707"}
0005434726708	BFBAFC	2231 645103	LIDIYA GERASIMOVA	{"email": "lidiya-gerasimova.25011970@postgrespro.ru", "phone": "+70427063932"}
0005434726709	BFBAFC	3407 617008	ELENA ZAYCEVA	{"email": "zayceva-elena.041985@postgrespro.ru", "phone": "+70526819852"}
0005434726710	ECA16F	9495 878099	MARIYA SOLOVEVA	{"email": "m.soloveva_1975@postgrespro.ru", "phone": "+70650319947"}
0005434726711	D56503	7369 072739	KRISTINA RYABOVA	{"email": "ryabovak-1963@postgrespro.ru", "phone": "+70736629787"}
0005434726712	E2E994	5557 020213	VLADIMIR ZAYCEV	{"phone": "+70074215045"}
0005434726713	E2E994	3486 477559	LYUDMILA LAZAREVA	{"phone": "+70321935621"}
0005434726714	693439	9180 301940	KONSTANTIN GUSEV	{"email": "gusev-k_1968@postgrespro.ru", "phone": "+70274800231"}
0005434726715	2FAC42	9398 492654	GENNADIY ANDREEV	{"email": "andreev_g1975@postgrespro.ru", "phone": "+70204500508"}
0005434726716	C18105	7448 628793	VERA NAZAROVA	{"email": "vera_nazarova_13061969@postgrespro.ru", "phone": "+70892117848"}
0005434726717	680AA0	4368 098957	ALEFTINA POPOVA	{"email": "aleftina-popova_1966@postgrespro.ru", "phone": "+70075284166"}
0005434726718	45EF44	6713 473292	SVETLANA FILIPPOVA	{"email": "filippovasvetlana_22081970@postgrespro.ru", "phone": "+70726077142"}
0005434726719	45EF44	2816 602159	SVETLANA SMIRNOVA	{"email": "s.smirnova081978@postgrespro.ru", "phone": "+70167655154"}
0005434726720	5EDB51	4871 458588	RAMZIYA MAKAROVA	{"email": "r_makarova_04121965@postgrespro.ru", "phone": "+70787343234"}
0005434726721	F19C5F	4959 313364	TATYANA FROLOVA	{"email": "frolova_t051980@postgrespro.ru", "phone": "+70031548824"}
0005434726722	E9C994	3760 056155	STANISLAV STEPANOV	{"email": "stanislav-stepanov-10111959@postgrespro.ru", "phone": "+70568821384"}
0005434726723	43DB92	3425 571797	SVETLANA MARTYNOVA	{"email": "svetlana.martynova_121976@postgrespro.ru", "phone": "+70077485135"}
0005434726724	4DED6D	0003 594102	MIKHAIL ANTONOV	{"email": "antonov.m1985@postgrespro.ru", "phone": "+70817790038"}
0005434726725	4DED6D	2877 828119	LYUDMILA MARTYNOVA	{"email": "martynovalyudmila-1972@postgrespro.ru", "phone": "+70896334248"}
0005434726726	B793E6	2163 447758	ULYANA MAKSIMOVA	{"email": "maksimova_u_021971@postgrespro.ru", "phone": "+70448666899"}
0005434726727	B793E6	0186 887009	TATYANA VOROBEVA	{"email": "t-vorobeva.1981@postgrespro.ru", "phone": "+70598318913"}
0005434726728	A42BF4	9427 964313	ALEKSANDRA OVCHINNIKOVA	{"email": "aovchinnikova_1964@postgrespro.ru", "phone": "+70747192443"}
0005434726729	A42BF4	1467 057030	RUSTAM KULIKOV	{"email": "rustam-kulikov_111972@postgrespro.ru", "phone": "+70036506202"}
0005434726730	833419	2902 453267	ELINA CHERNOVA	{"email": "e_chernova-111982@postgrespro.ru", "phone": "+70517765671"}
0005434726731	833419	8739 464596	DIANA DANILOVA	{"phone": "+70311204325"}
0005434726732	B4D67F	6284 703847	SERGEY ILIN	{"phone": "+70265358416"}
0005434726733	31F96E	5244 671469	EKATERINA STEPANOVA	{"phone": "+70089469613"}
0005434726734	31F96E	3029 748134	PETR FOMIN	{"phone": "+70874691487"}
0005434726735	EB44A0	5134 162947	MARINA IVANOVA	{"phone": "+70536086423"}
0005434726736	662876	7990 718867	IVAN VASILEV	{"email": "vasilev.i-1966@postgrespro.ru", "phone": "+70195007720"}
0005434726737	1AE153	7107 626656	VALENTINA SIDOROVA	{"phone": "+70422386292"}
0005434726738	365FC7	6864 025769	RAISA AFANASEVA	{"phone": "+70492797966"}
0005434726739	365FC7	8063 644403	MARINA KUZNECOVA	{"phone": "+70376156324"}
0005434726740	F8B84A	0964 609111	LIDIYA PAVLOVA	{"phone": "+70897342627"}
0005434726741	9D01E2	7792 532625	SERGEY SOROKIN	{"phone": "+70843596799"}
0005434726742	BA750E	0246 351047	NIKOLAY OSIPOV	{"phone": "+70540490818"}
0005434726743	7D8346	2230 747413	ALEKSANDR SOKOLOV	{"phone": "+70658146111"}
0005434726744	B102DC	6421 999871	DANIIL GORBUNOV	{"email": "d.gorbunov091971@postgrespro.ru", "phone": "+70229521228"}
0005434726745	FD4DD8	7049 690837	TATYANA NAZAROVA	{"phone": "+70895585757"}
0005434726746	73930F	5108 434429	ANASTASIYA BELYAEVA	{"email": "anastasiya_belyaeva_1970@postgrespro.ru", "phone": "+70710006905"}
0005434726747	73930F	2740 492123	YANA AKIMOVA	{"phone": "+70280645397"}
0005434726748	2ACAF2	1184 511672	TAISIYA BORISOVA	{"phone": "+70423770161"}
0005434726749	780FB9	8281 714270	ROMAN GORBUNOV	{"email": "r.gorbunov1976@postgrespro.ru", "phone": "+70258346786"}
0005434726750	780FB9	6404 123675	ANATOLIY AFANASEV	{"phone": "+70740971365"}
0005434726751	FB5216	9182 845100	ELIZAVETA MOROZOVA	{"email": "morozova_e11051966@postgrespro.ru", "phone": "+70569905405"}
0005434726752	F130D9	8603 298759	SERGEY VOLKOV	{"email": "sergeyvolkov.26041975@postgrespro.ru", "phone": "+70637385354"}
0005434726753	F130D9	7925 860232	PRASKOVYA NIKIFOROVA	{"phone": "+70182778332"}
0005434726754	26AD72	6941 590068	EKATERINA RYABOVA	{"phone": "+70852115925"}
0005434726755	26AD72	5903 183253	SERGEY GERASIMOV	{"email": "gerasimov_s.13011978@postgrespro.ru", "phone": "+70407396925"}
0005434726756	EE5004	5456 088026	OLEG SCHERBAKOV	{"email": "scherbakovo-03021967@postgrespro.ru", "phone": "+70033334070"}
0005434726758	1BAC55	6187 848898	ILYA KARPOV	{"email": "karpovilya.21111978@postgrespro.ru", "phone": "+70272931579"}
0005434726759	1BAC55	7870 341092	ALEKSANDR PAVLOV	{"phone": "+70524184945"}
0005434726760	00FD6A	2961 332753	GENNADIY IVANOV	{"email": "ivanovg-121979@postgrespro.ru", "phone": "+70765962254"}
0005434726761	00FD6A	1514 460209	MATVEY ANDREEV	{"email": "andreev_matvey1968@postgrespro.ru", "phone": "+70675914809"}
0005434726762	60F359	9239 921665	ALEKSEY KUZNECOV	{"phone": "+70467888632"}
0005434726763	1240D3	6372 714149	NINA CHERNOVA	{"phone": "+70983415567"}
0005434726764	BE1556	7233 164256	ANDREY BELOV	{"phone": "+70648890536"}
0005434726765	DCA63F	4034 796595	GENNADIY CHERNOV	{"email": "chernovgennadiy_1979@postgrespro.ru", "phone": "+70291455422"}
0005434726766	7F6100	2665 414999	ANDREY RODIONOV	{"phone": "+70520422306"}
0005434726767	EAC5F2	2405 814842	MIKHAIL AFANASEV	{"email": "afanasevmikhail_1975@postgrespro.ru", "phone": "+70307328055"}
0005434726768	A3D17E	2792 418880	ZINAIDA KOMAROVA	{"phone": "+70002079665"}
0005434726769	A3D17E	1344 661795	DMITRIY MATVEEV	{"email": "dmitriy_matveev-121973@postgrespro.ru", "phone": "+70934427413"}
0005434726770	633B0F	8791 529871	ANTON VOLKOV	{"email": "avolkov_1973@postgrespro.ru", "phone": "+70516368188"}
0005434726771	633B0F	3006 572659	OKSANA PAVLOVA	{"email": "pavlovaoksana.011973@postgrespro.ru", "phone": "+70431748355"}
0005434726772	8D3DE6	4553 583791	SERGEY PAVLOV	{"phone": "+70703304135"}
0005434726773	8D3DE6	9273 666553	YURIY KUZMIN	{"phone": "+70807380898"}
0005434726774	FF5976	6240 128007	VALENTINA SEMENOVA	{"phone": "+70425794700"}
0005434726775	CF60CD	0232 770009	NADEZHDA ABRAMOVA	{"phone": "+70969196071"}
0005434726776	DE97D4	2272 138834	RUSTAM OSIPOV	{"email": "osipovrustam1977@postgrespro.ru", "phone": "+70589917677"}
0005434726777	8DC855	0569 216904	NATALYA MAKAROVA	{"phone": "+70835806332"}
0005434726778	8DC855	3848 431437	IVAN KUZNECOV	{"phone": "+70593621173"}
0005434726779	FE1C39	7241 282709	FARIDA TIMOFEEVA	{"phone": "+70963882002"}
0005434726780	EB2036	5743 306188	OLGA IVANOVA	{"email": "o.ivanova.1977@postgrespro.ru", "phone": "+70246751014"}
0005434726781	A739D9	5775 289718	ANASTASIYA MELNIKOVA	{"phone": "+70881919871"}
0005434726782	A739D9	7173 529996	MIKHAIL ALEKSEEV	{"phone": "+70161734016"}
0005434726783	64263F	4143 885581	MARIYA MAKAROVA	{"email": "makarova.mariya-1984@postgrespro.ru", "phone": "+70776516960"}
0005434726784	64263F	8726 311470	YURIY ANTONOV	{"phone": "+70770695578"}
0005434726785	8B2E40	3197 291740	OLEG POPOV	{"email": "popovo04041974@postgrespro.ru", "phone": "+70409828987"}
0005434726786	5681E2	9528 496674	NINA EFIMOVA	{"phone": "+70185354290"}
0005434726787	5681E2	1402 195963	ALBINA NIKOLAEVA	{"email": "nikolaeva_albina-031974@postgrespro.ru", "phone": "+70296959853"}
0005434726788	5681E2	5137 496703	DANIYA ABRAMOVA	{"phone": "+70960995347"}
0005434726789	BF20CB	0596 287747	SERGEY POPOV	{"email": "s.popov.1975@postgrespro.ru", "phone": "+70095581071"}
0005434726790	BF20CB	9187 660815	ANVAR KUZNECOV	{"email": "akuznecov-08011979@postgrespro.ru", "phone": "+70563424831"}
0005434726791	645E0B	8919 853982	NIKITA FILIPPOV	{"phone": "+70792953421"}
0005434726792	7B466D	4578 113421	MARIYA IVANOVA	{"email": "ivanova-mariya1982@postgrespro.ru", "phone": "+70576995605"}
0005434726793	F9F36E	9003 687946	NATALYA KRASNOVA	{"phone": "+70811811832"}
0005434726794	E3A985	3730 649679	VADIM FILIPPOV	{"phone": "+70266782753"}
0005434726795	E3A985	0092 753723	SERGEY FILIPPOV	{"email": "sergey-filippov1977@postgrespro.ru", "phone": "+70692418912"}
0005434726796	0EC16F	3768 690725	NIKOLAY PETROV	{"phone": "+70018884496"}
0005434726797	9C37CC	2814 159345	ALEKSANDR BELOV	{"phone": "+70829615644"}
0005434726798	D515F8	9069 523640	YANA YAKOVLEVA	{"phone": "+70074245479"}
0005434726799	D515F8	0979 804808	SVETLANA VOROBEVA	{"phone": "+70857357809"}
0005434726800	661155	3924 026835	GALINA ZHURAVLEVA	{"phone": "+70369202839"}
0005434726801	661155	0423 145898	GEORGIY SIDOROV	{"phone": "+70969815457"}
0005434726802	457E4B	7700 416215	NADEZHDA ZAYCEVA	{"email": "zayceva.nadezhda_051961@postgrespro.ru", "phone": "+70008643057"}
0005434726803	564CD9	2830 659094	DANIIL KULIKOV	{"email": "daniilkulikov.25021984@postgrespro.ru", "phone": "+70676232903"}
0005434726804	F82481	4076 701721	ANASTASIYA DENISOVA	{"phone": "+70934205602"}
0005434726805	F82481	2126 130933	LIDIYA MAKSIMOVA	{"email": "l-maksimova-28011966@postgrespro.ru", "phone": "+70529805370"}
0005434726806	F82481	7557 424739	LARISA MIKHAYLOVA	{"phone": "+70074413644"}
0005434726807	9AA2CA	1687 597562	SVETLANA MASLOVA	{"phone": "+70113845459"}
0005434726808	9AA2CA	0649 474351	SERGEY KONOVALOV	{"email": "konovalov.s.071963@postgrespro.ru", "phone": "+70763496891"}
0005434726809	6A4E1E	6146 650170	VLADIMIR KONOVALOV	{"email": "v-konovalov_071978@postgrespro.ru", "phone": "+70371044497"}
0005434726810	4AD6E2	6656 183800	SERGEY PAVLOV	{"phone": "+70783386301"}
0005434726811	4AD6E2	1434 799274	VASILIY SOLOVEV	{"email": "vasiliy-solovev-1971@postgrespro.ru", "phone": "+70186425825"}
0005434726812	860A8F	9657 655843	ALEKSANDR FEDOROV	{"phone": "+70036393745"}
0005434726813	860A8F	8553 803474	MIKHAIL FEDOROV	{"email": "fedorovmikhail-1971@postgrespro.ru", "phone": "+70871942532"}
0005434726814	7188B6	1883 336255	NINA LUKYANOVA	{"phone": "+70578645329"}
0005434726992	00BC7A	7294 683702	IVAN DAVYDOV	{"phone": "+70804063650"}
0005434726815	7188B6	4649 631714	NATALYA ERMAKOVA	{"email": "ermakovan-1972@postgrespro.ru", "phone": "+70845601199"}
0005434726816	ED5ED6	6158 008696	LEONID ISAEV	{"phone": "+70863471804"}
0005434726817	8527A3	7855 654199	OKSANA EFREMOVA	{"phone": "+70626452755"}
0005434726818	8527A3	1480 945584	LYUBOV MOISEEVA	{"phone": "+70635573339"}
0005434726819	87CFF3	2509 930879	NIKOLAY SEMENOV	{"email": "semenov_nikolay.071979@postgrespro.ru", "phone": "+70736009119"}
0005434726820	49B872	3902 982136	DARYA SMIRNOVA	{"phone": "+70424637086"}
0005434726821	49B872	3482 180125	ANDREY SAVELEV	{"email": "savelevandrey.1973@postgrespro.ru", "phone": "+70459155171"}
0005434726822	49B872	6356 579330	EVGENIY KUDRYASHOV	{"phone": "+70506775940"}
0005434726823	49B872	1900 607165	NATALYA IVANOVA	{"phone": "+70011185061"}
0005434726824	E99870	1562 409599	ALEKSEY VOROBEV	{"email": "vorobev-aleksey_1971@postgrespro.ru", "phone": "+70218507706"}
0005434726825	E99870	8986 863761	DMITRIY BONDARENKO	{"email": "bondarenko-d.051968@postgrespro.ru", "phone": "+70870151193"}
0005434726826	CCB66F	0949 419160	AMIR ORLOV	{"phone": "+70952407112"}
0005434726827	CCB66F	7189 252514	ELIZAVETA ANISIMOVA	{"phone": "+70130474526"}
0005434726828	115B05	8857 279935	VLADIMIR ISAEV	{"phone": "+70843931518"}
0005434726829	A5FB03	7101 214930	VALENTINA DMITRIEVA	{"phone": "+70127194643"}
0005434726830	D7FDCD	8375 241488	IRINA ZAYCEVA	{"phone": "+70313826183"}
0005434726831	26917C	7455 781457	VALERIY FEDOTOV	{"email": "valeriy-fedotov.03021974@postgrespro.ru", "phone": "+70075044031"}
0005434726832	6FCFA5	6080 676536	ANATOLIY SOKOLOV	{"email": "asokolov_061985@postgrespro.ru", "phone": "+70686414546"}
0005434726833	148454	0015 909747	VERA ANTONOVA	{"email": "antonova.v.05111966@postgrespro.ru", "phone": "+70163702381"}
0005434726834	148454	6600 447226	INNA TITOVA	{"email": "innatitova-18101967@postgrespro.ru", "phone": "+70837719245"}
0005434726835	8DF949	1642 362397	VERA KISELEVA	{"email": "kiseleva_v.1979@postgrespro.ru", "phone": "+70390187599"}
0005434726836	306650	9693 182675	OLGA NIKIFOROVA	{"phone": "+70901830354"}
0005434726837	C5DA18	0978 746285	MIKHAIL FROLOV	{"phone": "+70507511976"}
0005434726838	680312	0987 794442	GALINA ANTONOVA	{"email": "galinaantonova-041976@postgrespro.ru", "phone": "+70620355874"}
0005434726839	370D59	6555 711291	YULIYA GAVRILOVA	{"phone": "+70070394546"}
0005434726840	370D59	1018 362431	YULIYA KUZNECOVA	{"email": "ykuznecova-051970@postgrespro.ru", "phone": "+70298589054"}
0005434726841	470083	8453 621424	ALEKSEY VOLKOV	{"email": "a-volkov.071971@postgrespro.ru", "phone": "+70601046652"}
0005434726842	9E20C9	3580 690765	VASILIY SOROKIN	{"phone": "+70585623297"}
0005434726843	9E20C9	3799 193953	ALEKSEY KUZMIN	{"phone": "+70484520554"}
0005434726844	983D85	0145 787289	ALEKSANDR SAVELEV	{"phone": "+70375007812"}
0005434726845	04FA52	6942 277763	DMITRIY KUDRYASHOV	{"email": "d-kudryashov-04011968@postgrespro.ru", "phone": "+70359801113"}
0005434726846	04FA52	7326 900622	VALERIY SEMENOV	{"email": "vsemenov_031969@postgrespro.ru", "phone": "+70700548000"}
0005434726847	A8E38D	3068 238996	NINA GAVRILOVA	{"email": "ninagavrilova_07041974@postgrespro.ru", "phone": "+70366752328"}
0005434726848	A8E38D	9546 647988	MARINA NIKIFOROVA	{"email": "nikiforova-m.01041969@postgrespro.ru", "phone": "+70435710831"}
0005434726849	28E9B4	5558 008581	ANDREY KULIKOV	{"email": "andrey-kulikov.1973@postgrespro.ru", "phone": "+70438713427"}
0005434726850	57D9C7	1454 695276	DENIS SOKOLOV	{"email": "sokolov-denis.19071962@postgrespro.ru", "phone": "+70362169605"}
0005434726851	CDFD25	0221 169069	ELENA TIMOFEEVA	{"phone": "+70613572579"}
0005434726852	EEC903	4240 475678	VALENTINA KOROLEVA	{"email": "valentina_koroleva_031971@postgrespro.ru", "phone": "+70679753253"}
0005434726853	EEC903	4198 749186	ANNA EGOROVA	{"email": "a_egorova-16091984@postgrespro.ru", "phone": "+70456831371"}
0005434726854	012C57	9894 603108	EVGENIY NAUMOV	{"email": "e_naumov.091976@postgrespro.ru", "phone": "+70172240293"}
0005434726855	BCC0EC	5561 337539	EVGENIYA VASILEVA	{"email": "evgeniya_vasileva-22061969@postgrespro.ru", "phone": "+70916432877"}
0005434726856	AB0E89	2121 766110	VALENTIN IVANOV	{"phone": "+70772873476"}
0005434726857	CECED0	0085 370943	ILNUR ORLOV	{"email": "orlov_ilnur_051967@postgrespro.ru", "phone": "+70728935076"}
0005434726858	A6B3EC	2947 200472	VLADISLAV SIDOROV	{"phone": "+70911566775"}
0005434726859	1ED9D7	5128 272796	ROZA TARASOVA	{"phone": "+70737286410"}
0005434726860	5064CC	1348 700189	DMITRIY DAVYDOV	{"phone": "+70099583154"}
0005434726861	412EC5	7510 780874	MIKHAIL MIKHAYLOV	{"email": "mikhailmikhaylov.011973@postgrespro.ru", "phone": "+70483710675"}
0005434726862	82669D	4094 016236	NIKOLAY OSIPOV	{"phone": "+70372850139"}
0005434726863	C2E39E	2345 036266	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr.1975@postgrespro.ru", "phone": "+70065688001"}
0005434726864	B1D8B4	0548 663914	IRINA NIKIFOROVA	{"email": "i_nikiforova-23111973@postgrespro.ru", "phone": "+70760548760"}
0005434726865	B1D8B4	6154 449587	MAKSIM TIMOFEEV	{"email": "timofeev_maksim.051979@postgrespro.ru", "phone": "+70147447052"}
0005434726866	4283C3	3522 393894	GALINA ORLOVA	{"email": "orlova-galina_111981@postgrespro.ru", "phone": "+70333945225"}
0005434726867	997DCE	3854 065159	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir_041970@postgrespro.ru", "phone": "+70353870750"}
0005434726868	C47012	2431 106993	NATALYA OSIPOVA	{"email": "natalya-osipova.25061980@postgrespro.ru", "phone": "+70174127679"}
0005434726869	C47012	2873 258419	NATALYA DANILOVA	{"email": "danilova.natalya-1975@postgrespro.ru", "phone": "+70009824058"}
0005434726870	132D08	0804 563085	VLADIMIR BORISOV	{"email": "vladimirborisov121962@postgrespro.ru", "phone": "+70319687491"}
0005434726871	95B089	3906 255125	ILYA VLASOV	{"phone": "+70694836309"}
0005434726872	95B089	6689 033870	IVAN MAKAROV	{"phone": "+70362593092"}
0005434726873	3D0874	6318 861399	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana_111958@postgrespro.ru", "phone": "+70332815933"}
0005434726874	E355BA	6594 212850	ALEKSANDR GERASIMOV	{"email": "gerasimov_aleksandr_21111984@postgrespro.ru", "phone": "+70702714576"}
0005434726875	23ABCD	8322 317702	NIKOLAY NOVIKOV	{"email": "n.novikov_05031972@postgrespro.ru", "phone": "+70689988954"}
0005434726876	C0A9F2	4336 931633	DARYA KOLESNIKOVA	{"phone": "+70279568293"}
0005434726877	C0A9F2	2416 049749	MAKSIM ROMANOV	{"email": "romanov.maksim1976@postgrespro.ru", "phone": "+70490889276"}
0005434726878	C0A9F2	7791 992610	GEORGIY ZAYCEV	{"phone": "+70831424045"}
0005434726879	8A2500	5997 470466	ELENA DENISOVA	{"email": "denisovae061971@postgrespro.ru", "phone": "+70806543729"}
0005434726880	F2D335	4100 144368	ANDREY ROMANOV	{"email": "aromanov_061978@postgrespro.ru", "phone": "+70000901009"}
0005434726881	F2D335	1491 153892	ANTON IVANOV	{"phone": "+70181812131"}
0005434726882	04A008	0123 065698	LARISA OVCHINNIKOVA	{"phone": "+70139907022"}
0005434726883	04A008	7710 115076	KARIM KISELEV	{"email": "kiselevkarim_051964@postgrespro.ru", "phone": "+70504047898"}
0005434726884	6B3226	9015 424356	ALEKSEY ANDREEV	{"email": "andreev_a.121971@postgrespro.ru", "phone": "+70252941923"}
0005434726885	79F37A	9873 678888	ALEKSEY ROMANOV	{"phone": "+70902155878"}
0005434726886	79F37A	3197 719705	SERGEY NIKOLAEV	{"email": "snikolaev021974@postgrespro.ru", "phone": "+70744020852"}
0005434726887	216436	2300 077147	ANDREY ZAYCEV	{"phone": "+70492889348"}
0005434726888	216436	1117 976168	VLADIMIR GORBUNOV	{"phone": "+70237327769"}
0005434726889	6CA384	2935 580579	GALINA SAVELEVA	{"phone": "+70170624887"}
0005434726890	0F1FFA	7051 624357	TATYANA FEDOROVA	{"email": "tatyana_fedorova.071976@postgrespro.ru", "phone": "+70422213281"}
0005434726891	685094	3218 346931	NIKOLAY SMIRNOV	{"email": "smirnovnikolay.021969@postgrespro.ru", "phone": "+70008562344"}
0005434726892	BEA181	0714 326304	VYACHESLAV VASILEV	{"phone": "+70627266320"}
0005434726893	BEA181	3181 289000	ROMAN MEDVEDEV	{"phone": "+70583575626"}
0005434726894	B6147D	0968 139175	ALEKSANDR MOROZOV	{"phone": "+70275193031"}
0005434726895	61E523	0798 056432	SERGEY NIKOLAEV	{"email": "nikolaev-sergey.08071974@postgrespro.ru", "phone": "+70708773192"}
0005434726896	61E523	9647 709272	VLADISLAV STEPANOV	{"email": "stepanov.v.081974@postgrespro.ru", "phone": "+70070387301"}
0005434726897	2B96E5	4055 093532	LILIYA NAZAROVA	{"email": "liliyanazarova.041967@postgrespro.ru", "phone": "+70018264144"}
0005434726898	B2B6BE	8377 123959	ELENA KOVALEVA	{"email": "e_kovaleva.1972@postgrespro.ru", "phone": "+70188500897"}
0005434726899	18FA7A	3217 558772	EVGENIY GRIGOREV	{"phone": "+70679426333"}
0005434726900	CD29BD	6868 897991	ROMAN FROLOV	{"phone": "+70754285777"}
0005434726901	E7B935	7891 970385	IRINA BARANOVA	{"email": "irina_baranova081953@postgrespro.ru", "phone": "+70684794861"}
0005434726902	653F3B	9510 205326	RAISA SOKOLOVA	{"email": "raisasokolova_031974@postgrespro.ru", "phone": "+70427891105"}
0005434726903	54E474	2145 929998	SERGEY ANDREEV	{"email": "sergeyandreev.041975@postgrespro.ru", "phone": "+70145667481"}
0005434726904	077E02	1601 411003	YURIY DAVYDOV	{"email": "yuriydavydov.1973@postgrespro.ru", "phone": "+70469146285"}
0005434726905	077E02	9373 396921	SVETLANA VLASOVA	{"phone": "+70942470344"}
0005434726906	077E02	5299 202565	ANATOLIY KARPOV	{"email": "karpov.a-041970@postgrespro.ru", "phone": "+70287778745"}
0005434726907	2EB5B0	7292 892232	GENNADIY MARTYNOV	{"email": "martynov_g-1979@postgrespro.ru", "phone": "+70602416395"}
0005434726908	8D85AC	3404 348937	ARTEM DMITRIEV	{"email": "dmitriev.artem27071965@postgrespro.ru", "phone": "+70021862829"}
0005434726909	B2F8B6	4853 751572	NATALYA SOROKINA	{"phone": "+70565015481"}
0005434726910	57EA9F	0085 577336	YULIYA LUKYANOVA	{"email": "ylukyanova_1966@postgrespro.ru", "phone": "+70758489237"}
0005434726911	909A12	4719 121046	IVAN CHERNOV	{"email": "ichernov051984@postgrespro.ru", "phone": "+70801739110"}
0005434726912	4E605D	4739 190084	ELENA PETROVA	{"email": "petrova.elena.1970@postgrespro.ru", "phone": "+70099201979"}
0005434726913	E16B21	6587 558917	MARIYA BELOVA	{"phone": "+70610513564"}
0005434726914	326A95	0754 776323	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir_071971@postgrespro.ru", "phone": "+70535465411"}
0005434726915	326A95	2899 989493	VLADIMIR NOVIKOV	{"email": "novikov.vladimir_091970@postgrespro.ru", "phone": "+70558807303"}
0005434726916	CA82E3	1472 175460	VERA SOKOLOVA	{"phone": "+70108271924"}
0005434726917	2D9EA2	1173 064896	TATYANA SOROKINA	{"email": "sorokina_t091969@postgrespro.ru", "phone": "+70536905274"}
0005434726918	2D9EA2	1023 536211	MARINA ISAEVA	{"email": "misaeva_1964@postgrespro.ru", "phone": "+70369541103"}
0005434726919	60E687	1303 670138	PETR DENISOV	{"phone": "+70556844249"}
0005434726920	60E687	0922 177264	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova-1966@postgrespro.ru", "phone": "+70967735517"}
0005434726921	6CD13F	4796 489109	VALERIY FEDOTOV	{"email": "valeriy.fedotov_121970@postgrespro.ru", "phone": "+70520585960"}
0005434726922	B614C1	8169 702558	ANATOLIY NAZAROV	{"email": "anatoliy_nazarov.10011974@postgrespro.ru", "phone": "+70154860808"}
0005434726923	B4BAC8	8830 563493	TAMARA KUZNECOVA	{"phone": "+70524912494"}
0005434726924	28B216	6861 020638	MARIYA ABRAMOVA	{"phone": "+70041995367"}
0005434726925	28B216	6645 454617	TATYANA MAKAROVA	{"email": "makarova-tatyana031975@postgrespro.ru", "phone": "+70612392480"}
0005434726926	300E0E	7493 575640	SERGEY NOVIKOV	{"email": "sergey_novikov1975@postgrespro.ru", "phone": "+70889068784"}
0005434726927	6911A2	1499 785542	NIKOLAY MELNIKOV	{"email": "melnikov-nikolay06021973@postgrespro.ru", "phone": "+70608167577"}
0005434726928	8BDAA5	0475 089004	NINA OSIPOVA	{"phone": "+70162251486"}
0005434726929	8BDAA5	8287 460223	IVAN MATVEEV	{"email": "i_matveev_13111975@postgrespro.ru", "phone": "+70983240431"}
0005434726930	A2ABA1	0040 914340	MARIYA GORBUNOVA	{"phone": "+70655333451"}
0005434726931	B7F3CC	3588 762177	ANNA KOLESNIKOVA	{"email": "anna.kolesnikova1984@postgrespro.ru", "phone": "+70792821098"}
0005434726932	B7F3CC	0736 806784	NIKOLAY SMIRNOV	{"email": "smirnov-nikolay-061977@postgrespro.ru", "phone": "+70533096476"}
0005434726933	FACCFF	7811 980384	SVETLANA ANTONOVA	{"phone": "+70624884586"}
0005434726934	AECF61	8974 027460	VIKTOR PETROV	{"email": "v-petrov-101964@postgrespro.ru", "phone": "+70204664905"}
0005434726935	610DE8	6153 674112	SERGEY STEPANOV	{"email": "stepanov-s1959@postgrespro.ru", "phone": "+70212682015"}
0005434726936	79DE6F	9362 491387	NIKOLAY POPOV	{"email": "popov-n12111963@postgrespro.ru", "phone": "+70355770638"}
0005434726937	79DE6F	5976 330240	MARIYA POPOVA	{"email": "popova-mariya_1969@postgrespro.ru", "phone": "+70361899923"}
0005434726938	628E39	2203 027257	NINA MIKHAYLOVA	{"phone": "+70098328414"}
0005434726939	C76918	1024 648468	ZINAIDA KULIKOVA	{"phone": "+70540978170"}
0005434726940	C76918	9469 650091	VADIM MIRONOV	{"phone": "+70686094251"}
0005434726941	201FB1	8828 436697	DENIS SIDOROV	{"phone": "+70905772721"}
0005434726942	201FB1	6787 585293	RAFAEL PAVLOV	{"phone": "+70960479845"}
0005434726943	EB68F9	4387 923675	GENNADIY EGOROV	{"email": "gennadiy_egorov-02061975@postgrespro.ru", "phone": "+70131591158"}
0005434726944	141825	3188 921521	OKSANA NESTEROVA	{"email": "nesterova-o.26041974@postgrespro.ru", "phone": "+70986268071"}
0005434726945	33F732	0307 798190	DMITRIY MAKAROV	{"email": "makarovdmitriy.051982@postgrespro.ru", "phone": "+70357556160"}
0005434726946	F74A24	7228 398953	MAKSIM ORLOV	{"phone": "+70083408772"}
0005434726947	5B060F	0073 184579	TAISIYA SAVELEVA	{"email": "saveleva-t.121972@postgrespro.ru", "phone": "+70611880107"}
0005434726948	5B060F	8143 554099	ALEKSEY IVANOV	{"email": "ivanovaleksey011970@postgrespro.ru", "phone": "+70649340553"}
0005434726949	80F0EC	5658 032552	EKATERINA SIDOROVA	{"email": "esidorova1966@postgrespro.ru", "phone": "+70463917466"}
0005434726950	042813	6399 614877	VYACHESLAV VOLKOV	{"email": "volkovv_22021977@postgrespro.ru", "phone": "+70380195564"}
0005434726951	7AFA1B	6284 852119	LEONID VOROBEV	{"email": "leonid-vorobev-081972@postgrespro.ru", "phone": "+70285533586"}
0005434726952	92493E	3728 897990	GEORGIY KAZAKOV	{"email": "g_kazakov1971@postgrespro.ru", "phone": "+70254598663"}
0005434726953	92493E	5726 728799	AYRAT VOLKOV	{"phone": "+70146545735"}
0005434726954	92493E	7429 260818	ANDREY BORISOV	{"email": "andrey_borisov-1968@postgrespro.ru", "phone": "+70901001697"}
0005434726955	F9D8EF	2945 557394	EKATERINA PAVLOVA	{"email": "e_pavlova.04061984@postgrespro.ru", "phone": "+70962823440"}
0005434726956	CBA028	3040 328951	LYUBOV ANISIMOVA	{"email": "anisimova-l021975@postgrespro.ru", "phone": "+70697053127"}
0005434726957	11E1F5	9123 641896	KSENIYA PETROVA	{"phone": "+70944862288"}
0005434726958	EB4A4D	1208 086101	KSENIYA ANDREEVA	{"email": "k.andreeva-061976@postgrespro.ru", "phone": "+70654263717"}
0005434726959	63A212	4529 860811	OLGA PAVLOVA	{"email": "pavlova-olga031976@postgrespro.ru", "phone": "+70477382106"}
0005434726960	63A212	3683 398721	ALEKSANDR KUZNECOV	{"email": "kuznecov.a-09091974@postgrespro.ru", "phone": "+70276278618"}
0005434726961	137BE6	4155 243440	VLADIMIR KOZLOV	{"phone": "+70870431963"}
0005434726962	137BE6	0665 464428	GALINA EFREMOVA	{"email": "efremova.galina.1972@postgrespro.ru", "phone": "+70202304967"}
0005434726963	21CE88	8631 729062	VIKTORIYA AKIMOVA	{"phone": "+70941390713"}
0005434726964	871472	6206 129556	GALINA TIKHONOVA	{"phone": "+70896485808"}
0005434726965	871472	1068 467052	NIKOLAY SCHERBAKOV	{"phone": "+70297817421"}
0005434726966	F94F26	8219 411917	ANTON POPOV	{"email": "anton-popov_18021970@postgrespro.ru", "phone": "+70261762936"}
0005434726967	1D0D73	8901 540301	VLADIMIR YAKOVLEV	{"email": "vladimir_yakovlev08031979@postgrespro.ru", "phone": "+70729122573"}
0005434726968	C1A360	3905 412403	NIKOLAY MOROZOV	{"phone": "+70338272795"}
0005434726969	C1A360	7039 838852	ALEKSEY ROMANOV	{"email": "romanov.aleksey.1969@postgrespro.ru", "phone": "+70894310620"}
0005434726970	84763A	8219 293013	ALEKSANDR ZAYCEV	{"phone": "+70397700991"}
0005434726971	5C04BB	1788 273328	ELENA LOGINOVA	{"phone": "+70668925572"}
0005434726972	5C04BB	5716 399215	NINA EFREMOVA	{"email": "efremova-nina_1978@postgrespro.ru", "phone": "+70255880003"}
0005434726973	4E2B35	6526 801547	NINA KONDRATEVA	{"email": "kondrateva_n-06101975@postgrespro.ru", "phone": "+70549871361"}
0005434726974	4E2B35	6784 489718	ANATOLIY ORLOV	{"phone": "+70916440626"}
0005434726975	F4BB57	4927 258276	SERGEY TIMOFEEV	{"email": "sergey_timofeev_1954@postgrespro.ru", "phone": "+70239280399"}
0005434726976	F4BB57	9535 197175	EKATERINA MELNIKOVA	{"email": "e.melnikova01121960@postgrespro.ru", "phone": "+70103875093"}
0005434726977	AB6353	8350 077042	YURIY POPOV	{"email": "ypopov-29031973@postgrespro.ru", "phone": "+70586967660"}
0005434726978	AB6353	1946 634692	TATYANA SEMENOVA	{"phone": "+70680545338"}
0005434726979	A0D2EB	9721 839014	VERA VASILEVA	{"phone": "+70282546080"}
0005434726980	BA8736	0572 234803	SVETLANA ANTONOVA	{"phone": "+70360245150"}
0005434726981	AA2CC0	4351 959476	VLADIMIR EGOROV	{"phone": "+70709414876"}
0005434726982	058443	2124 708989	EVGENIY DAVYDOV	{"phone": "+70995126957"}
0005434726983	058443	7264 742150	ALINA MIRONOVA	{"email": "mironova-alina.1962@postgrespro.ru", "phone": "+70131934493"}
0005434726984	88214D	8391 549215	LYUDMILA SMIRNOVA	{"email": "lyudmila-smirnova_1976@postgrespro.ru", "phone": "+70812136874"}
0005434726985	F99E87	3905 591035	VALENTINA LAZAREVA	{"phone": "+70868956162"}
0005434726986	10F7CC	9008 118319	ELENA ZOTOVA	{"email": "zotova-elena_14031976@postgrespro.ru", "phone": "+70740039551"}
0005434726987	DC080E	1909 643682	NATALYA KOVALEVA	{"phone": "+70274439074"}
0005434726988	DC080E	1222 061822	NATALYA ANISIMOVA	{"email": "anisimovanatalya1966@postgrespro.ru", "phone": "+70743605572"}
0005434726989	DC080E	9815 358516	ANDREY GUSEV	{"phone": "+70330896379"}
0005434726990	9B8C5C	4691 880512	ANNA ROMANOVA	{"phone": "+70786319850"}
0005434726991	72787E	3639 174424	INNA ZHURAVLEVA	{"phone": "+70243403244"}
0005434726993	00BC7A	1618 980325	DMITRIY ZAYCEV	{"email": "dzaycev_1959@postgrespro.ru", "phone": "+70514127996"}
0005434726994	634BFB	4255 100579	ELENA GUSEVA	{"email": "guseva_e-09091970@postgrespro.ru", "phone": "+70380411181"}
0005434726995	94CE57	9289 287279	NIKITA SIDOROV	{"email": "nsidorov-081976@postgrespro.ru", "phone": "+70127220292"}
0005434726996	15038C	9812 831876	GALINA KUZNECOVA	{"email": "kuznecova.galina_1964@postgrespro.ru", "phone": "+70400200839"}
0005434726997	15038C	6426 483987	ANTONINA POPOVA	{"email": "a.popova-121979@postgrespro.ru", "phone": "+70553445007"}
0005434726998	5EC400	9217 193287	ALEKSANDRA PETROVA	{"email": "petrovaaleksandra-1971@postgrespro.ru", "phone": "+70216705507"}
0005434726999	4AB2E1	2596 233004	IGOR POPOV	{"email": "popov-igor-1969@postgrespro.ru", "phone": "+70598789254"}
0005434727000	7F7ED4	5319 521621	ANDREY MAKAROV	{"phone": "+70597776038"}
0005434727001	1432F4	7741 247870	ANDREY NAZAROV	{"email": "andrey-nazarov_1978@postgrespro.ru", "phone": "+70332411119"}
0005434727002	1432F4	9445 204010	FEDOR DAVYDOV	{"email": "fdavydov-11061966@postgrespro.ru", "phone": "+70347760766"}
0005434727003	7FBEF5	1168 159873	BORIS PETROV	{"email": "petrovboris_1972@postgrespro.ru", "phone": "+70384309880"}
0005434727004	B77493	5092 237518	OLEG ANDREEV	{"email": "oleg.andreev101974@postgrespro.ru", "phone": "+70296733778"}
0005434727005	B77493	8647 452481	OLGA BORISOVA	{"email": "o.borisova_15041976@postgrespro.ru", "phone": "+70779497139"}
0005434727006	B77493	9512 105674	VYACHESLAV VOLKOV	{"email": "volkov.v_071973@postgrespro.ru", "phone": "+70228086397"}
0005434727007	A76530	3031 991622	RIMMA KOROLEVA	{"email": "koroleva.rimma.27061967@postgrespro.ru", "phone": "+70128372601"}
0005434727008	A76530	7863 261691	ALEKSEY IVANOV	{"phone": "+70319359254"}
0005434727009	1C8946	2567 285231	ALEKSANDR ANDREEV	{"email": "a-andreev061981@postgrespro.ru", "phone": "+70866778281"}
0005434727010	D792F2	9050 845780	NATALYA KARPOVA	{"phone": "+70249497886"}
0005434727011	D792F2	5904 395576	NIKOLAY ANTONOV	{"phone": "+70631493233"}
0005434727012	D792F2	9561 104168	ANDREY ALEKSEEV	{"email": "alekseevandrey-1966@postgrespro.ru", "phone": "+70521935409"}
0005434727013	82F833	6839 970263	MAKSIM ZAYCEV	{"email": "zaycev.maksim-1972@postgrespro.ru", "phone": "+70372359492"}
0005434727014	543026	5741 902803	VLADIMIR MELNIKOV	{"phone": "+70797600394"}
0005434727015	543026	9256 762531	IGOR ROMANOV	{"phone": "+70230359380"}
0005434727016	B2FD3D	2408 989120	EVDOKIYA DENISOVA	{"phone": "+70981210204"}
0005434727017	B3178F	8127 270172	OLGA RYABOVA	{"email": "ryabova.olga-18061972@postgrespro.ru", "phone": "+70696581157"}
0005434727018	8B5F64	9292 965290	KSENIYA DAVYDOVA	{"email": "davydovak121954@postgrespro.ru", "phone": "+70583447802"}
0005434727019	EC27F4	4986 056929	ELMIRA ZAKHAROVA	{"email": "zakharova.elmira.1982@postgrespro.ru", "phone": "+70247361135"}
0005434727020	BFBE77	0849 627041	EVGENIY NIKITIN	{"email": "nikitine-1970@postgrespro.ru", "phone": "+70679417298"}
0005434727021	BFBE77	1804 052044	RIMMA POLYAKOVA	{"email": "polyakova.r-22051972@postgrespro.ru", "phone": "+70060706234"}
0005434727022	64767E	9850 059201	ISLAM KAZAKOV	{"phone": "+70580925467"}
0005434727023	3E5E1F	7399 420881	IGOR SMIRNOV	{"email": "smirnov_i101968@postgrespro.ru", "phone": "+70303216994"}
0005434727024	D856A2	2158 210177	SVETLANA BELOVA	{"email": "s-belova1966@postgrespro.ru", "phone": "+70560858568"}
0005434727025	D856A2	0819 571876	DMITRIY CHERNOV	{"email": "chernov.dmitriy.13031965@postgrespro.ru", "phone": "+70134278073"}
0005434727026	69A7F6	6344 585998	NADEZHDA ZAKHAROVA	{"email": "zakharova-n.15051990@postgrespro.ru", "phone": "+70400079377"}
0005434727027	CC58BD	6130 049983	OLGA NESTEROVA	{"email": "nesterova_olga-1974@postgrespro.ru", "phone": "+70969971866"}
0005434727028	CC58BD	0927 823341	GALINA FADEEVA	{"phone": "+70180315385"}
0005434727029	3EFAC6	5709 200672	MARINA TROFIMOVA	{"phone": "+70714499509"}
0005434727030	CA2DF5	8770 981970	YULIYA DANILOVA	{"phone": "+70871146066"}
0005434727031	CA2DF5	9699 375126	TATYANA KUZNECOVA	{"phone": "+70281360528"}
0005434727032	CA2DF5	8244 845464	OLGA KONOVALOVA	{"email": "olgakonovalova.19011974@postgrespro.ru", "phone": "+70275862510"}
0005434727033	2BB4E6	6112 830148	KARINA GERASIMOVA	{"phone": "+70636490128"}
0005434727034	2BB4E6	5222 963277	VIKTOR SOKOLOV	{"email": "sokolov-v_1961@postgrespro.ru", "phone": "+70691071532"}
0005434727035	CAFBCA	2042 780060	ALEKSANDR DAVYDOV	{"email": "a.davydov-1967@postgrespro.ru", "phone": "+70185395285"}
0005434727036	CAFBCA	9249 103322	YURIY FEDOROV	{"email": "y_fedorov091979@postgrespro.ru", "phone": "+70801732892"}
0005434727037	EDCDE3	4194 893167	ALENA PETROVA	{"email": "a-petrova041962@postgrespro.ru", "phone": "+70284659920"}
0005434727038	F905D3	8573 108852	VLADIMIR KUZMIN	{"email": "vladimir-kuzmin.031979@postgrespro.ru", "phone": "+70185670089"}
0005434727039	F905D3	8175 914197	ARTEM KAZAKOV	{"email": "kazakov-a-1970@postgrespro.ru", "phone": "+70495327230"}
0005434727040	F905D3	8382 065378	ALEKSANDR ABRAMOV	{"email": "abramov.a.27031962@postgrespro.ru", "phone": "+70200921673"}
0005434727041	89789B	7405 380682	VALENTINA MOISEEVA	{"phone": "+70562610330"}
0005434727042	CE8F9B	6597 565149	NIKITA MEDVEDEV	{"email": "nmedvedev_031971@postgrespro.ru", "phone": "+70045418606"}
0005434727043	BEC4FD	1433 811556	MIKHAIL FOMIN	{"phone": "+70596403312"}
0005434727044	129796	2240 555755	LEONID NIKOLAEV	{"email": "nikolaev.leonid-1966@postgrespro.ru", "phone": "+70842581654"}
0005434727045	129796	0153 364353	ALEKSANDR ANDREEV	{"email": "andreevaleksandr.31121967@postgrespro.ru", "phone": "+70777373258"}
0005434727046	074693	0435 130018	ELENA KOZLOVA	{"phone": "+70907564603"}
0005434727047	23CC66	5140 006413	VIKTOR ALEKSEEV	{"phone": "+70079564412"}
0005434727048	23CC66	8088 884620	ELENA DMITRIEVA	{"phone": "+70107259323"}
0005434727049	266006	0711 954059	PAVEL KUZNECOV	{"email": "kuznecovpavel-091979@postgrespro.ru", "phone": "+70643315424"}
0005434727050	5FF346	1572 865579	ARTEM PETROV	{"email": "petrovartem_051979@postgrespro.ru", "phone": "+70729341922"}
0005434727051	241C5F	5543 906407	ANATOLIY AFANASEV	{"email": "afanasev.a.061971@postgrespro.ru", "phone": "+70830458538"}
0005434727052	AD8755	3247 026235	KRISTINA FILIPPOVA	{"email": "kristina.filippova-011975@postgrespro.ru", "phone": "+70202961256"}
0005434727053	AA1145	7940 541441	ANNA MAKAROVA	{"phone": "+70540640971"}
0005434727114	0C9DD0	2044 198841	VASILIY KUZNECOV	{"phone": "+70936860862"}
0005434727054	AA1145	9401 477895	ELENA BARANOVA	{"email": "e_baranova-071961@postgrespro.ru", "phone": "+70201380653"}
0005434727055	3257DA	2338 869872	OLGA NESTEROVA	{"phone": "+70371316378"}
0005434727056	201AF1	3573 340710	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-06041966@postgrespro.ru", "phone": "+70151950560"}
0005434727057	B0902B	5416 061488	ALEKSEY OSIPOV	{"email": "osipov.aleksey-1964@postgrespro.ru", "phone": "+70820748192"}
0005434727058	B0902B	7251 960636	YULIYA KARPOVA	{"email": "karpova.yuliya_1966@postgrespro.ru", "phone": "+70936007524"}
0005434727059	3D2DB4	7822 807442	KONSTANTIN VOLKOV	{"phone": "+70866896163"}
0005434727060	655545	7354 364423	NATALYA KOROLEVA	{"phone": "+70131960705"}
0005434727061	655545	9604 848551	NADEZHDA KUZMINA	{"email": "n-kuzmina.011969@postgrespro.ru", "phone": "+70766092862"}
0005434727062	B702FD	3854 942681	VARVARA AFANASEVA	{"phone": "+70478185788"}
0005434727063	7B8604	5354 046238	YURIY NAZAROV	{"email": "yuriy_nazarov.05041966@postgrespro.ru", "phone": "+70958144844"}
0005434727064	DC21A8	9937 098423	SVETLANA FEDOROVA	{"email": "s_fedorova-17021974@postgrespro.ru", "phone": "+70798878792"}
0005434727065	1C941B	7365 574104	GENNADIY KUZNECOV	{"phone": "+70031678483"}
0005434727066	1C941B	7264 860282	VLADIMIR ANDREEV	{"phone": "+70766461630"}
0005434727067	B94DE5	5330 960001	VALENTINA KUZNECOVA	{"phone": "+70741867530"}
0005434727068	B94DE5	3635 680717	KONSTANTIN TIKHONOV	{"phone": "+70839688590"}
0005434727069	E998E1	6333 732117	OLGA VOLKOVA	{"phone": "+70145559184"}
0005434727070	6885BD	7940 636396	GULSHAT EGOROVA	{"phone": "+70525355145"}
0005434727071	6885BD	6684 731534	ANTONINA NOVIKOVA	{"phone": "+70992231759"}
0005434727072	962670	0985 303240	NINA KISELEVA	{"email": "kiseleva.nina_1969@postgrespro.ru", "phone": "+70700861129"}
0005434727073	615532	0002 604542	VLADIMIR ANDREEV	{"email": "andreev-vladimir061962@postgrespro.ru", "phone": "+70280465434"}
0005434727074	4661D1	5146 022398	ALEKSANDR YAKOVLEV	{"phone": "+70926663503"}
0005434727075	4661D1	0434 593253	SERGEY GRIGOREV	{"email": "s-grigorev_011967@postgrespro.ru", "phone": "+70785003638"}
0005434727076	8C66CC	6796 976561	YANA BORISOVA	{"email": "y-borisova.18121977@postgrespro.ru", "phone": "+70419119076"}
0005434727077	3C2A28	5009 894332	LYUBOV PETROVA	{"phone": "+70604039198"}
0005434727078	3C2A28	9440 075442	SERGEY VASILEV	{"email": "svasilev-061969@postgrespro.ru", "phone": "+70379592248"}
0005434727079	86B6B6	8993 872461	KSENIYA VOLKOVA	{"email": "volkova-kseniya-1975@postgrespro.ru", "phone": "+70773096256"}
0005434727080	7D2DF7	5229 389746	GENNADIY SERGEEV	{"phone": "+70445931814"}
0005434727081	7D2DF7	2426 773553	DARYA IVANOVA	{"email": "d_ivanova.26121976@postgrespro.ru", "phone": "+70285115339"}
0005434727082	26B2F1	3061 815992	VALENTINA PAVLOVA	{"email": "pavlovav02011978@postgrespro.ru", "phone": "+70222898642"}
0005434727083	F7BF5D	1784 515088	EKATERINA GRISHINA	{"email": "grishina_ekaterina_21071974@postgrespro.ru", "phone": "+70961714860"}
0005434727084	49A487	9458 108273	SERGEY GAVRILOV	{"phone": "+70626863657"}
0005434727085	49A487	1812 023983	NATALYA LEBEDEVA	{"phone": "+70859625853"}
0005434727086	D23E85	6186 919459	GALINA NIKIFOROVA	{"email": "nikiforova-galina_121972@postgrespro.ru", "phone": "+70064547623"}
0005434727087	721E67	7597 834249	IRINA MOROZOVA	{"email": "morozova-i09041971@postgrespro.ru", "phone": "+70465652451"}
0005434727088	80918C	1955 954247	ANDREY KUZMIN	{"email": "a-kuzmin.061981@postgrespro.ru", "phone": "+70477626502"}
0005434727089	40919A	6199 629597	ALEKSANDR KUZNECOV	{"phone": "+70298833955"}
0005434727090	B0403B	5861 299939	ARTEM PAVLOV	{"email": "artem_pavlov-031978@postgrespro.ru", "phone": "+70361767490"}
0005434727091	EEB285	7809 705610	IRINA NIKITINA	{"phone": "+70778327246"}
0005434727092	EEB285	7354 550379	OLEG FROLOV	{"email": "oleg.frolov1977@postgrespro.ru", "phone": "+70666649339"}
0005434727093	D8F020	9340 127473	IGOR PETROV	{"email": "igor_petrov1962@postgrespro.ru", "phone": "+70715847411"}
0005434727094	D8F020	1103 981970	YURIY NAZAROV	{"phone": "+70241344357"}
0005434727095	8F8ABB	2156 966450	SERGEY POPOV	{"email": "sergey_popov_051972@postgrespro.ru", "phone": "+70078051653"}
0005434727096	8F8ABB	4774 470072	ANTON NAUMOV	{"email": "naumov_anton_1970@postgrespro.ru", "phone": "+70027742946"}
0005434727097	E9D32A	5196 800158	ILYA VOLKOV	{"email": "volkov.i101973@postgrespro.ru", "phone": "+70582777703"}
0005434727098	276E0A	0695 194674	OLGA SOKOLOVA	{"phone": "+70173158571"}
0005434727099	2DF17A	9297 836514	OKSANA FROLOVA	{"phone": "+70129231218"}
0005434727100	2DF17A	0828 574954	NINA GUSEVA	{"phone": "+70905965135"}
0005434727101	62E82E	5603 501623	ALEKSEY VOROBEV	{"phone": "+70438947823"}
0005434727102	62E82E	3165 947588	SVETLANA GUSEVA	{"phone": "+70018346564"}
0005434727103	154B64	2034 505917	ALINA SOKOLOVA	{"email": "sokolova_alina-1986@postgrespro.ru", "phone": "+70420403313"}
0005434727104	154B64	3790 819371	OLGA KARPOVA	{"phone": "+70533144772"}
0005434727105	2A9B15	0451 546819	EVGENIY POPOV	{"email": "popov_evgeniy_1982@postgrespro.ru", "phone": "+70935602242"}
0005434727106	9E9C58	8401 128937	VITALIY KRASNOV	{"phone": "+70814586465"}
0005434727107	9E9C58	5506 612285	VIKTOR MARTYNOV	{"email": "martynov_viktor_27021970@postgrespro.ru", "phone": "+70692814796"}
0005434727108	51F4D4	7646 153945	VALENTINA PETROVA	{"email": "petrova.v17051971@postgrespro.ru", "phone": "+70162351866"}
0005434727109	E097E7	3502 821790	YULIYA MALYSHEVA	{"email": "malysheva.yuliya.091983@postgrespro.ru", "phone": "+70270720044"}
0005434727110	C3309B	8233 274825	EVGENIY MIKHAYLOV	{"phone": "+70516940763"}
0005434727111	680835	8316 167135	GENNADIY KONOVALOV	{"phone": "+70919773725"}
0005434727112	B3ABB7	1927 448243	DARYA ALEKSANDROVA	{"email": "d.aleksandrova_1968@postgrespro.ru", "phone": "+70108222379"}
0005434727113	880D12	9620 419630	IVAN FEDOROV	{"phone": "+70607215575"}
0005434727115	0C9DD0	8175 781166	VLADIMIR KISELEV	{"phone": "+70448348116"}
0005434727116	CADA2F	5799 946224	TATYANA KOROLEVA	{"email": "koroleva-t1979@postgrespro.ru", "phone": "+70619072154"}
0005434727117	9EC8C9	0070 587149	ANDREY PAVLOV	{"phone": "+70978042328"}
0005434727118	9EC8C9	2054 195937	DINA NIKOLAEVA	{"email": "nikolaevadina1961@postgrespro.ru", "phone": "+70002831472"}
0005434727119	FFA2CB	1556 171700	ALEVTINA KOROLEVA	{"phone": "+70588375936"}
0005434727120	48F461	7630 195894	TATYANA MOROZOVA	{"phone": "+70781972372"}
0005434727121	52415F	2033 929577	VLADIMIR DMITRIEV	{"email": "dmitrievvladimir_1971@postgrespro.ru", "phone": "+70763415472"}
0005434727122	637A31	0667 422340	VLADIMIR POPOV	{"phone": "+70217555974"}
0005434727123	637A31	6000 678982	ANDREY OSIPOV	{"phone": "+70161370365"}
0005434727124	D74638	3163 267121	VALENTINA GRISHINA	{"phone": "+70280035320"}
0005434727125	61A487	7227 903387	TATYANA GERASIMOVA	{"phone": "+70160494977"}
0005434727126	9BBA55	9242 128370	LYUDMILA POPOVA	{"email": "popovalyudmila-031974@postgrespro.ru", "phone": "+70684676431"}
0005434727127	978027	6411 444560	YANA SERGEEVA	{"phone": "+70145098682"}
0005434727128	554222	4252 419437	EVGENIY ORLOV	{"phone": "+70419573920"}
0005434727129	554222	7341 167582	PAVEL GRIGOREV	{"email": "grigorev_p1985@postgrespro.ru", "phone": "+70704012925"}
0005434727130	539AF2	3446 502003	LYUDMILA NESTEROVA	{"email": "l-nesterova-03101980@postgrespro.ru", "phone": "+70922646970"}
0005434727131	A5115C	9008 402388	DARYA ANTONOVA	{"email": "antonova_d-13031965@postgrespro.ru", "phone": "+70669535129"}
0005434727132	A5115C	6265 773721	VALENTINA KOROLEVA	{"phone": "+70426609789"}
0005434727133	9DAD9F	2999 860267	RAISA EFIMOVA	{"email": "refimova31011976@postgrespro.ru", "phone": "+70424706968"}
0005434727134	B0EF44	9235 631713	EVGENIY VLASOV	{"phone": "+70380483762"}
0005434727135	C6197D	0484 693541	ELENA EGOROVA	{"phone": "+70613449393"}
0005434727136	C6197D	5033 410618	NADEZHDA IVANOVA	{"phone": "+70732273805"}
0005434727137	C6197D	8108 267793	VERA ANDREEVA	{"phone": "+70346753976"}
0005434727138	843443	8101 250800	ANZHELIKA DMITRIEVA	{"phone": "+70206577319"}
0005434727139	843443	0341 943864	LYUBOV SEMENOVA	{"phone": "+70440990444"}
0005434727140	C084B6	3488 290491	VLADISLAV SMIRNOV	{"email": "vladislavsmirnov071979@postgrespro.ru", "phone": "+70475144225"}
0005434727141	C2607D	8557 409869	DMITRIY CHERNOV	{"email": "chernovd051963@postgrespro.ru", "phone": "+70949626142"}
0005434727142	71E033	3429 194682	IRINA EGOROVA	{"email": "irinaegorova.1970@postgrespro.ru", "phone": "+70841325063"}
0005434727143	DAB97D	8346 433298	OLGA VASILEVA	{"phone": "+70577836123"}
0005434727144	2A3B75	4507 010584	MARIYA KOZLOVA	{"email": "kozlova.m_1966@postgrespro.ru", "phone": "+70835230656"}
0005434727145	2A3B75	4693 876813	DAMIR GERASIMOV	{"phone": "+70772897491"}
0005434727146	DCAF11	9834 150279	VLADISLAV PETROV	{"phone": "+70103375013"}
0005434727147	F79A2E	1280 906585	DMITRIY SOROKIN	{"email": "sorokin_dmitriy28021974@postgrespro.ru", "phone": "+70859323343"}
0005434727148	2C83FB	0701 803379	KLAVDIYA MAKAROVA	{"email": "makarova_klavdiya-1964@postgrespro.ru", "phone": "+70910386846"}
0005434727149	532C91	3369 422897	PAVEL OSIPOV	{"email": "osipov_pavel101968@postgrespro.ru", "phone": "+70291383697"}
0005434727150	532C91	6182 013497	SERGEY PAVLOV	{"phone": "+70868990684"}
0005434727151	9055FA	8755 824632	ALEKSANDR MIKHAYLOV	{"phone": "+70427568203"}
0005434727152	90A20F	3499 573630	NATALYA PETROVA	{"phone": "+70861548118"}
0005434727153	B8335B	2853 124227	MARAT ABRAMOV	{"email": "marat.abramov1966@postgrespro.ru", "phone": "+70816822790"}
0005434727154	FCF4E2	1350 332060	OLGA OVCHINNIKOVA	{"phone": "+70163381945"}
0005434727155	F31B7D	7103 450581	MAKSIM STEPANOV	{"email": "stepanov-maksim1966@postgrespro.ru", "phone": "+70172738974"}
0005434727156	F31B7D	2105 655456	ANTON TIKHONOV	{"email": "tikhonova01061958@postgrespro.ru", "phone": "+70571711214"}
0005434727157	C70E45	5551 591646	IRINA MEDVEDEVA	{"email": "medvedeva-i-1962@postgrespro.ru", "phone": "+70888288504"}
0005434727158	C70E45	1753 556727	SERGEY KUDRYASHOV	{"phone": "+70344415184"}
0005434727159	3E6DE5	6910 960290	ILYA SEMENOV	{"email": "semenov.i-111979@postgrespro.ru", "phone": "+70720640801"}
0005434727160	3E6DE5	0455 881961	ELENA NESTEROVA	{"phone": "+70878810475"}
0005434727161	F64237	7629 654713	ANDREY ROMANOV	{"phone": "+70884715473"}
0005434727162	1EB976	8457 431989	LYUDMILA GAVRILOVA	{"phone": "+70990842854"}
0005434727163	683E4B	8158 839565	ALEKSANDR KUZNECOV	{"email": "kuznecova_011971@postgrespro.ru", "phone": "+70619733157"}
0005434727164	C03AC1	7535 881429	LYUDMILA BORISOVA	{"phone": "+70153137737"}
0005434727165	C03AC1	9568 719622	EKATERINA ABRAMOVA	{"phone": "+70673765546"}
0005434727166	C03AC1	8182 648376	GALINA KUZNECOVA	{"email": "galina.kuznecova.07041963@postgrespro.ru", "phone": "+70071510331"}
0005434727167	3B9F86	3018 846273	NADEZHDA SEMENOVA	{"email": "semenova-n-1964@postgrespro.ru", "phone": "+70516502663"}
0005434727168	042572	2536 044254	VITALIY NIKITIN	{"email": "nikitin.vitaliy11091982@postgrespro.ru", "phone": "+70060473023"}
0005434727169	A14EBD	7240 273420	ELENA OVCHINNIKOVA	{"phone": "+70973919274"}
0005434727170	AC5BDE	2863 651708	TATYANA KARPOVA	{"phone": "+70605941321"}
0005434727171	050505	9675 495359	FAINA ZOTOVA	{"email": "faina-zotova_1968@postgrespro.ru", "phone": "+70850969516"}
0005434727172	9BF5DE	8322 812891	NINA YAKOVLEVA	{"phone": "+70439204805"}
0005434727173	E62B76	7089 562858	LYUBOV NIKITINA	{"email": "lyubov-nikitina_1974@postgrespro.ru", "phone": "+70457636122"}
0005434727174	0EBBE7	2991 610146	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr061976@postgrespro.ru", "phone": "+70093211169"}
0005434727175	83F71F	7471 225813	RINAT IVANOV	{"phone": "+70515128013"}
0005434727176	83F71F	4249 598577	YURIY ZHUKOV	{"email": "zhukov-y.061967@postgrespro.ru", "phone": "+70981687372"}
0005434727177	A1E333	5372 085734	VLADIMIR POPOV	{"email": "popovvladimir-111979@postgrespro.ru", "phone": "+70247871223"}
0005434727178	A1E333	2881 392698	ALBERT BONDARENKO	{"email": "a.bondarenko_1985@postgrespro.ru", "phone": "+70960226227"}
0005434727179	CDF0B0	7155 424568	MAKSIM KUZNECOV	{"email": "m.kuznecov.1984@postgrespro.ru", "phone": "+70885989248"}
0005434727180	CDF0B0	4137 256511	ALEKSANDR DMITRIEV	{"email": "dmitriev_aleksandr.05041971@postgrespro.ru", "phone": "+70969435075"}
0005434727181	CDF0B0	9147 369049	VLADISLAV KULIKOV	{"email": "vkulikov_081969@postgrespro.ru", "phone": "+70650624327"}
0005434727182	D7F687	9215 004306	EKATERINA IVANOVA	{"phone": "+70594631346"}
0005434727183	5DAA63	3458 731386	OKSANA VOROBEVA	{"email": "ovorobeva.08021979@postgrespro.ru", "phone": "+70004366396"}
0005434727184	04632B	0646 730625	ANDREY SCHERBAKOV	{"email": "a.scherbakov-1967@postgrespro.ru", "phone": "+70532392067"}
0005434727185	04632B	0657 514407	VALENTINA ABRAMOVA	{"phone": "+70900967660"}
0005434727186	FA99F1	9432 572751	VIKTORIYA SAVELEVA	{"email": "v_saveleva-1969@postgrespro.ru", "phone": "+70518880222"}
0005434727187	A73855	3581 332375	VLADIMIR TIMOFEEV	{"phone": "+70861612616"}
0005434727188	6FE7A1	9380 102072	VALENTINA SMIRNOVA	{"email": "valentina.smirnova_1967@postgrespro.ru", "phone": "+70762088174"}
0005434727189	6FE7A1	4432 146930	SERGEY ILIN	{"phone": "+70503415718"}
0005434727190	7235E5	5806 220468	OLGA SAVELEVA	{"email": "saveleva.olga091963@postgrespro.ru", "phone": "+70215241430"}
0005434727191	7235E5	2003 710256	NIKITA KOZLOV	{"phone": "+70889265686"}
0005434727192	7235E5	3730 576102	TATYANA KOROLEVA	{"email": "koroleva.tatyana.03041965@postgrespro.ru", "phone": "+70274469134"}
0005434727193	A403C3	4537 788172	ANDREY POPOV	{"email": "popov-andrey-121976@postgrespro.ru", "phone": "+70084807653"}
0005434727194	A403C3	3916 331890	EVGENIY KUZNECOV	{"phone": "+70958257749"}
0005434727195	5A9349	9796 193507	NINA SAVELEVA	{"phone": "+70195579115"}
0005434727196	5A9349	0128 129354	VERA CHERNOVA	{"email": "v-chernova.19041974@postgrespro.ru", "phone": "+70749148529"}
0005434727197	5A9349	4889 021384	ARTUR GORBUNOV	{"phone": "+70464196785"}
0005434727198	C102A8	0720 179664	TATYANA ANDREEVA	{"email": "t-andreeva-031968@postgrespro.ru", "phone": "+70600292556"}
0005434727199	1CFBA6	4510 056823	SERGEY SEMENOV	{"email": "sergeysemenov-1972@postgrespro.ru", "phone": "+70902249802"}
0005434727200	1CFBA6	7467 384513	YURIY BONDARENKO	{"phone": "+70196583378"}
0005434727201	14A972	6321 307155	MARIYA SEMENOVA	{"email": "mariya.semenova-081969@postgrespro.ru", "phone": "+70534859357"}
0005434727202	59F867	2393 944364	VLADISLAV SEMENOV	{"email": "semenovv121969@postgrespro.ru", "phone": "+70820567023"}
0005434727203	59F867	9429 594229	ELIZAVETA FILIPPOVA	{"email": "filippova.e-27121969@postgrespro.ru", "phone": "+70967078492"}
0005434727204	4CADBA	3296 527731	PRASKOVYA VOROBEVA	{"email": "pvorobeva.1969@postgrespro.ru", "phone": "+70272754182"}
0005434727205	F5AA48	4156 939341	ALEKSANDR BARANOV	{"email": "aleksandr.baranov.18101975@postgrespro.ru", "phone": "+70489695183"}
0005434727206	8BE41C	2520 512541	GALINA FROLOVA	{"phone": "+70339594768"}
0005434727207	CBD513	1750 581730	VIKTOR TIMOFEEV	{"phone": "+70687433035"}
0005434727208	3DCA77	7585 097112	NIKOLAY NAUMOV	{"phone": "+70418659637"}
0005434727209	0C29CC	9309 529323	SERGEY IVANOV	{"email": "s-ivanov.1973@postgrespro.ru", "phone": "+70271899815"}
0005434727210	29679D	0068 553653	DARYA KUZNECOVA	{"phone": "+70885176361"}
0005434727211	29679D	3048 520542	IVAN DAVYDOV	{"phone": "+70996015232"}
0005434727212	FB780E	1027 692882	ELENA POPOVA	{"email": "popova_elena-041968@postgrespro.ru", "phone": "+70432388002"}
0005434727213	8C5CB5	9457 343707	DMITRIY ALEKSEEV	{"email": "dalekseev-04091958@postgrespro.ru", "phone": "+70963390093"}
0005434727214	6B66BD	3335 162627	VITALIY STEPANOV	{"phone": "+70983369670"}
0005434727215	7CF8AC	5173 942700	ALEKSANDR ALEKSEEV	{"email": "alekseev_a1976@postgrespro.ru", "phone": "+70374123118"}
0005434727216	249FCB	1113 241664	NATALYA VASILEVA	{"email": "vasileva.n.041973@postgrespro.ru", "phone": "+70605171464"}
0005434727217	93FA41	9613 517343	LYUDMILA TITOVA	{"email": "lyudmila.titova1965@postgrespro.ru", "phone": "+70470733575"}
0005434727218	4107B7	5946 480847	IGOR SHEVCHENKO	{"email": "igor_shevchenko.101970@postgrespro.ru", "phone": "+70908250549"}
0005434727219	4107B7	8662 558902	ALINA IVANOVA	{"phone": "+70662577451"}
0005434727220	4107B7	4729 461653	IRINA IVANOVA	{"phone": "+70091603794"}
0005434727221	9E1DA1	4264 363678	ANDREY ISAEV	{"phone": "+70492414841"}
0005434727222	22D057	2263 628101	SERGEY DMITRIEV	{"phone": "+70279634525"}
0005434727223	F9CA7B	6802 337848	LYUBOV DANILOVA	{"email": "l-danilova.18021974@postgrespro.ru", "phone": "+70578371423"}
0005434727615	BE2C4D	9812 429583	VADIM SIDOROV	{"phone": "+70818961690"}
0005434727224	CEE1DE	8804 343998	MIKHAIL SIDOROV	{"email": "sidorov.mikhail1968@postgrespro.ru", "phone": "+70382509744"}
0005434727225	CEC203	0820 273509	ANTONINA RODIONOVA	{"email": "rodionovaantonina.1970@postgrespro.ru", "phone": "+70597994741"}
0005434727226	5EBBA5	5586 563031	VALENTINA LEBEDEVA	{"email": "lebedevavalentina_101983@postgrespro.ru", "phone": "+70456449778"}
0005434727227	AA218D	5177 096632	NINA NOVIKOVA	{"phone": "+70665951877"}
0005434727228	CF81D7	1923 789713	AYRAT YAKOVLEV	{"phone": "+70572334912"}
0005434727229	C5C753	9548 322245	VALENTINA NAZAROVA	{"email": "nazarova-valentina_1970@postgrespro.ru", "phone": "+70881685371"}
0005434727230	C5C753	1014 277396	POLINA POPOVA	{"email": "popova_p-111954@postgrespro.ru", "phone": "+70534068100"}
0005434727231	FDB8C2	4814 472700	DMITRIY KULIKOV	{"email": "dmitriy_kulikov.091967@postgrespro.ru", "phone": "+70514994071"}
0005434727232	CCC6FB	0843 559109	EGOR PAVLOV	{"email": "egor_pavlov.071961@postgrespro.ru", "phone": "+70122219719"}
0005434727233	F3662E	7715 789790	SVETLANA EGOROVA	{"phone": "+70565179758"}
0005434727234	21FEE6	4949 642496	VYACHESLAV DAVYDOV	{"email": "davydov_vyacheslav20121966@postgrespro.ru", "phone": "+70830160201"}
0005434727235	0B3D15	3178 899856	ANNA IVANOVA	{"phone": "+70817073023"}
0005434727236	6674C9	4214 802926	ALEKSANDR GAVRILOV	{"phone": "+70246364274"}
0005434727237	C15370	4760 671518	SOFYA EFREMOVA	{"email": "efremova_sofya1982@postgrespro.ru", "phone": "+70007928467"}
0005434727238	C15370	7678 336383	OLEG VASILEV	{"email": "oleg_vasilev1972@postgrespro.ru", "phone": "+70082626007"}
0005434727239	E019BE	1701 328418	VITALIY DAVYDOV	{"phone": "+70852346420"}
0005434727240	FBEA58	3982 696281	LYUDMILA MASLOVA	{"phone": "+70841736773"}
0005434727241	FBEA58	2054 908181	ANTON MAKAROV	{"email": "a_makarov121953@postgrespro.ru", "phone": "+70354727036"}
0005434727242	FBEA58	0484 815096	VLADIMIR KUZNECOV	{"email": "v.kuznecov081979@postgrespro.ru", "phone": "+70676066523"}
0005434727243	3DC1A8	4469 221396	SVETLANA BELOVA	{"email": "belova_s-1968@postgrespro.ru", "phone": "+70808934236"}
0005434727244	83EBE6	2328 293467	GENNADIY ANTONOV	{"email": "gennadiy.antonov.30121969@postgrespro.ru", "phone": "+70132695569"}
0005434727245	83EBE6	6482 378738	YULIYA SMIRNOVA	{"email": "smirnova-yuliya.1971@postgrespro.ru", "phone": "+70931770416"}
0005434727246	C1EE3C	0698 772466	LYUDMILA SEMENOVA	{"email": "lyudmilasemenova051974@postgrespro.ru", "phone": "+70536847588"}
0005434727247	0C3710	9197 381789	NIKITA NIKOLAEV	{"phone": "+70731325625"}
0005434727248	AC94E0	2808 595118	MARIYA BORISOVA	{"phone": "+70475954285"}
0005434727249	5C8556	9203 483441	VLADIMIR MIKHAYLOV	{"phone": "+70574026578"}
0005434727250	72C756	5774 055121	ZULFIYA LAZAREVA	{"email": "zulfiya_lazareva.22111981@postgrespro.ru", "phone": "+70549512023"}
0005434727251	15B223	8268 620076	VIKTORIYA SCHERBAKOVA	{"email": "scherbakova.v.1979@postgrespro.ru", "phone": "+70218030083"}
0005434727252	15B223	5379 985652	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev.121968@postgrespro.ru", "phone": "+70842642841"}
0005434727253	39E120	2730 247050	LYUDMILA OSIPOVA	{"phone": "+70427851342"}
0005434727254	0D1DF5	0473 843507	NINA RYABOVA	{"phone": "+70292631774"}
0005434727255	A75F04	8204 510306	NADEZHDA ALEKSEEVA	{"email": "alekseevan-1978@postgrespro.ru", "phone": "+70699937681"}
0005434727256	A75F04	6189 884078	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko041972@postgrespro.ru", "phone": "+70832296735"}
0005434727257	78F34B	2792 813012	VALERIY SEMENOV	{"phone": "+70661865981"}
0005434727258	C45E62	2923 075697	IRINA GUSEVA	{"email": "irina_guseva.1958@postgrespro.ru", "phone": "+70934732694"}
0005434727259	C45E62	5393 407304	MAKSIM MATVEEV	{"email": "matveev_m.011978@postgrespro.ru", "phone": "+70630351823"}
0005434727260	C467C9	9433 375786	ARTUR MELNIKOV	{"email": "melnikovartur-01021970@postgrespro.ru", "phone": "+70080049566"}
0005434727261	AE5976	9564 080771	ELENA POPOVA	{"email": "elenapopova-111973@postgrespro.ru", "phone": "+70545531530"}
0005434727262	4974EE	2882 036106	ALEKSANDR GORBUNOV	{"phone": "+70090625377"}
0005434727263	D47DF4	2794 651554	POLINA FROLOVA	{"phone": "+70284961874"}
0005434727264	D47DF4	0804 571585	PETR GUSEV	{"email": "gusev_petr28041974@postgrespro.ru", "phone": "+70928141788"}
0005434727265	AE6D48	2820 641011	OLEG VLASOV	{"phone": "+70916756757"}
0005434727266	23E501	0779 092429	NATALYA TIMOFEEVA	{"phone": "+70270773329"}
0005434727267	784BEF	7556 146047	ANNA ISAEVA	{"email": "isaeva_a-101960@postgrespro.ru", "phone": "+70543479009"}
0005434727268	478F11	9122 382900	ANTONINA FROLOVA	{"email": "frolovaantonina04011973@postgrespro.ru", "phone": "+70268342560"}
0005434727269	81A176	6502 861396	ALEKSANDR KRASNOV	{"phone": "+70104614022"}
0005434727270	81A176	9934 430050	EKATERINA YUDINA	{"email": "ekaterina_yudina_1975@postgrespro.ru", "phone": "+70087525091"}
0005434727271	BD3A9C	9506 933386	YURIY SOLOVEV	{"email": "yuriy-solovev_1961@postgrespro.ru", "phone": "+70633203463"}
0005434727272	D8DD88	9267 699676	ALEKSEY SOKOLOV	{"phone": "+70727157110"}
0005434727273	4E663A	1216 593057	SVETLANA KUZNECOVA	{"phone": "+70754291030"}
0005434727274	28FEDD	5402 224116	IRINA YAKOVLEVA	{"phone": "+70749524758"}
0005434727275	28FEDD	6185 496187	NADEZHDA POPOVA	{"phone": "+70063714986"}
0005434727276	28FEDD	3664 129323	OLESYA MOISEEVA	{"phone": "+70900309073"}
0005434727277	135819	2520 513322	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr-10021966@postgrespro.ru", "phone": "+70885360947"}
0005434727278	3EF900	1998 291056	VERA POTAPOVA	{"phone": "+70979738042"}
0005434727279	3EF900	6124 321666	NATALYA AFANASEVA	{"phone": "+70382497305"}
0005434727280	E8EF47	5839 194966	ALEKSANDR VOLKOV	{"email": "volkova24041984@postgrespro.ru", "phone": "+70263396995"}
0005434727281	F11AFD	3977 963083	VLADLEN GERASIMOV	{"phone": "+70844116640"}
0005434727282	F11AFD	8805 463291	MARINA STEPANOVA	{"email": "stepanovamarina1978@postgrespro.ru", "phone": "+70689761116"}
0005434727283	56E1D8	5383 965598	MARIYA NOVIKOVA	{"email": "novikovamariya.03011968@postgrespro.ru", "phone": "+70204081222"}
0005434727284	38F8A9	1727 676840	NADEZHDA LAZAREVA	{"phone": "+70791271302"}
0005434727285	38F8A9	1627 663523	DARYA DMITRIEVA	{"email": "daryadmitrieva_1976@postgrespro.ru", "phone": "+70241635646"}
0005434727286	11CBC1	0672 545834	IVAN GERASIMOV	{"phone": "+70424205732"}
0005434727287	BEAAD4	2986 903300	MIKHAIL MARTYNOV	{"phone": "+70584779105"}
0005434727288	98134C	6799 835264	ALEKSANDR PAVLOV	{"phone": "+70657184268"}
0005434727289	98134C	2546 389704	NATALIYA EGOROVA	{"phone": "+70325824446"}
0005434727290	B7BE69	6009 295527	EKATERINA BORISOVA	{"phone": "+70567879600"}
0005434727291	4798FD	6808 246568	LYUDMILA ZAKHAROVA	{"phone": "+70192386814"}
0005434727292	A4F953	0749 625458	ALEKSANDR KUZMIN	{"phone": "+70491926755"}
0005434727293	9D76FC	3731 726097	NATALYA ZAYCEVA	{"email": "zayceva.natalya_23031973@postgrespro.ru", "phone": "+70123867888"}
0005434727294	18556B	2153 939841	ANASTASIYA PAVLOVA	{"phone": "+70024991675"}
0005434727295	18556B	1583 370761	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov_29101972@postgrespro.ru", "phone": "+70947039974"}
0005434727296	E65DD0	0557 000780	MIKHAIL NAZAROV	{"phone": "+70721750397"}
0005434727297	D96E3F	4027 136487	LILIYA IVANOVA	{"email": "liliya-ivanova081968@postgrespro.ru", "phone": "+70500242814"}
0005434727298	31DAC6	1883 976281	ZINAIDA FROLOVA	{"phone": "+70528646132"}
0005434727299	5FD47C	0640 586153	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_121971@postgrespro.ru", "phone": "+70620031672"}
0005434727300	9A30DD	1543 928557	KSENIYA TITOVA	{"phone": "+70441230685"}
0005434727301	9A30DD	4634 344401	ALBINA KRASNOVA	{"email": "krasnova_albina051960@postgrespro.ru", "phone": "+70744338012"}
0005434727302	69DA72	4363 071709	EVGENIY STEPANOV	{"phone": "+70992528529"}
0005434727303	3516FE	9001 000155	DMITRIY NAZAROV	{"email": "d.nazarov-31051976@postgrespro.ru", "phone": "+70844911393"}
0005434727304	F7E186	2230 150111	VALENTINA STEPANOVA	{"phone": "+70616139841"}
0005434727305	F7E186	3676 177379	OLGA ANDREEVA	{"phone": "+70733756418"}
0005434727306	AB7A2D	2042 064287	ANASTASIYA TIKHONOVA	{"phone": "+70964157321"}
0005434727307	AB7A2D	8838 266829	ARTUR ANDREEV	{"phone": "+70122930913"}
0005434727308	AB7A2D	1535 078857	ANTONINA IVANOVA	{"phone": "+70855907726"}
0005434727309	38E38E	3328 064295	NIKOLAY ABRAMOV	{"email": "nikolay_abramov_1961@postgrespro.ru", "phone": "+70288446174"}
0005434727310	38E38E	3458 113255	VLADIMIR RODIONOV	{"email": "rodionov.vladimir-1968@postgrespro.ru", "phone": "+70622359724"}
0005434727311	28F27A	1916 951409	YULIYA SAVELEVA	{"email": "y_saveleva1983@postgrespro.ru", "phone": "+70616551291"}
0005434727312	5A79CD	3756 119915	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko_21031975@postgrespro.ru", "phone": "+70775972946"}
0005434727313	5A79CD	4085 163055	DANILA NIKOLAEV	{"email": "danila-nikolaev_1974@postgrespro.ru", "phone": "+70977027957"}
0005434727314	54C5A0	9868 243401	OLEG TARASOV	{"phone": "+70861059957"}
0005434727315	4D2C2F	3466 209754	VALERIY IVANOV	{"email": "v_ivanov.071972@postgrespro.ru", "phone": "+70581146775"}
0005434727316	4D2C2F	9023 715852	EKATERINA KALININA	{"phone": "+70608719152"}
0005434727317	A532EF	5331 404845	ALEKSANDR FOMIN	{"email": "fominaleksandr.30111962@postgrespro.ru", "phone": "+70190513522"}
0005434727318	A532EF	9294 051660	ANTONINA LEBEDEVA	{"email": "lebedeva_antonina_031969@postgrespro.ru", "phone": "+70191203707"}
0005434727319	8D8668	6667 998202	NIKITA ALEKSANDROV	{"email": "aleksandrov.nikita_05031973@postgrespro.ru", "phone": "+70848429338"}
0005434727320	0B0555	9956 778709	ALEKSANDR MAKAROV	{"email": "a.makarov-08121966@postgrespro.ru", "phone": "+70841154939"}
0005434727321	3740C9	4808 554227	ALEKSANDR FROLOV	{"phone": "+70887618156"}
0005434727322	CC648D	2821 133761	LARISA NOVIKOVA	{"email": "larisanovikova.14121974@postgrespro.ru", "phone": "+70498303652"}
0005434727323	CC648D	5946 349102	NATALYA KOLESNIKOVA	{"email": "n.kolesnikova23101967@postgrespro.ru", "phone": "+70541303851"}
0005434727324	9B4E5F	6657 990924	LYUDMILA BELOVA	{"phone": "+70238489667"}
0005434727325	FD4FF6	3646 836195	ANDREY ZAKHAROV	{"email": "zakharov_a-051965@postgrespro.ru", "phone": "+70707405189"}
0005434727326	362688	2498 823788	NINA NIKITINA	{"phone": "+70298674191"}
0005434727327	160456	8386 371185	TATYANA ZHUKOVA	{"email": "t-zhukova-091981@postgrespro.ru", "phone": "+70548507710"}
0005434727328	082FBE	2227 823995	TATYANA ANDREEVA	{"phone": "+70142227473"}
0005434727329	082FBE	2779 966278	RAISA BOGDANOVA	{"phone": "+70822918085"}
0005434727330	AC4E3A	6222 047624	YULIYA MAKAROVA	{"phone": "+70659602873"}
0005434727331	8D47B6	4365 024777	VALERIYA ALEKSEEVA	{"phone": "+70513422617"}
0005434727332	7A9871	1572 167328	NIKOLAY SAVELEV	{"phone": "+70919611236"}
0005434727333	7A9871	9680 719615	ANDREY POPOV	{"phone": "+70841811417"}
0005434727334	FC9B5E	5378 773688	ANDREY SAVELEV	{"email": "savelev_a08091959@postgrespro.ru", "phone": "+70330884519"}
0005434727335	FC9B5E	0558 871585	IVAN SOKOLOV	{"email": "ivan.sokolov25081967@postgrespro.ru", "phone": "+70953168027"}
0005434727336	340244	3252 910164	PETR NOVIKOV	{"email": "novikov.p1982@postgrespro.ru", "phone": "+70796911072"}
0005434727337	8901A7	2540 430915	YURIY KUZNECOV	{"email": "yuriy.kuznecov-1960@postgrespro.ru", "phone": "+70374147625"}
0005434727338	8901A7	0992 249000	TATYANA TIKHONOVA	{"email": "tikhonova-tatyana.1976@postgrespro.ru", "phone": "+70927617244"}
0005434727339	B433A2	6770 131512	ALEKSANDR KONOVALOV	{"phone": "+70873653054"}
0005434727340	B9A9BE	3104 507706	DMITRIY TIKHONOV	{"email": "dmitriytikhonov-031974@postgrespro.ru", "phone": "+70099940819"}
0005434727341	7B01FB	2780 269994	ROMAN DMITRIEV	{"phone": "+70904490684"}
0005434727342	54484A	1521 524457	TATYANA NAZAROVA	{"phone": "+70178016138"}
0005434727343	93F2EC	2561 453579	MAKAR GRIGOREV	{"phone": "+70653834811"}
0005434727344	93F2EC	5427 533645	RUSLAN ABRAMOV	{"email": "ruslanabramov_22011980@postgrespro.ru", "phone": "+70403951231"}
0005434727345	644263	5018 068333	NINA MAKSIMOVA	{"email": "maksimova.n.1975@postgrespro.ru", "phone": "+70168733350"}
0005434727346	A42E55	2176 356606	FANIL ZAKHAROV	{"email": "zakharov-fanil-1975@postgrespro.ru", "phone": "+70814104014"}
0005434727347	266473	9249 574196	SERGEY MAKAROV	{"email": "makarov.s-23111967@postgrespro.ru", "phone": "+70683358986"}
0005434727348	F84A05	6098 599461	ARTEM ZAKHAROV	{"email": "artem_zakharov.031975@postgrespro.ru", "phone": "+70498155919"}
0005434727468	9B0DD3	8232 078908	SERGEY SOLOVEV	{"phone": "+70801817008"}
0005434727349	F84A05	0553 481852	ELENA ORLOVA	{"email": "elena.orlova.02011981@postgrespro.ru", "phone": "+70127660466"}
0005434727350	8DF7EA	8373 273240	DAVID PETROV	{"phone": "+70272131301"}
0005434727351	8DF7EA	5031 796703	SEMEN ABRAMOV	{"email": "semen-abramov.031974@postgrespro.ru", "phone": "+70490880166"}
0005434727352	A783BB	5949 087057	ARTEM SERGEEV	{"email": "sergeev_a_031968@postgrespro.ru", "phone": "+70209175415"}
0005434727353	A783BB	0182 641549	SERGEY AFANASEV	{"phone": "+70673431744"}
0005434727354	A783BB	6238 553252	OLESYA KAZAKOVA	{"email": "kazakovao_10011965@postgrespro.ru", "phone": "+70636793580"}
0005434727355	349724	8923 447402	TATYANA KUZNECOVA	{"phone": "+70071094931"}
0005434727356	781408	9991 620367	DMITRIY KULIKOV	{"phone": "+70992643135"}
0005434727357	C528CD	1327 570223	MAKSIM IVANOV	{"email": "maksimivanov061968@postgrespro.ru", "phone": "+70783394437"}
0005434727358	C528CD	9530 961252	ZHANNA KUZNECOVA	{"email": "kuznecova-z.121958@postgrespro.ru", "phone": "+70693758572"}
0005434727359	CEFBFD	8936 895361	LYUBOV TROFIMOVA	{"phone": "+70693975021"}
0005434727360	033EF4	7203 234806	GALINA SAVELEVA	{"email": "gsaveleva-18091973@postgrespro.ru", "phone": "+70164695001"}
0005434727361	082A3E	9793 143519	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov27121977@postgrespro.ru", "phone": "+70019293259"}
0005434727362	4B95C2	7894 711162	KONSTANTIN NOVIKOV	{"email": "knovikov-1973@postgrespro.ru", "phone": "+70188641191"}
0005434727363	2731CB	4460 016424	YURIY KRASNOV	{"email": "krasnov_yuriy-1968@postgrespro.ru", "phone": "+70744615316"}
0005434727364	2731CB	8315 477044	ALINA IVANOVA	{"phone": "+70683199011"}
0005434727365	D0F65A	0984 346573	EVGENIY PAVLOV	{"phone": "+70539175382"}
0005434727366	9F4963	7933 628715	SERGEY RODIONOV	{"phone": "+70301338259"}
0005434727367	D54183	5010 779288	NIKOLAY MATVEEV	{"phone": "+70943585809"}
0005434727368	C9B95A	6127 944842	ELIZAVETA ROMANOVA	{"email": "elizaveta.romanova-1969@postgrespro.ru", "phone": "+70847084318"}
0005434727369	FBC340	2535 036720	YURIY ROMANOV	{"phone": "+70854638458"}
0005434727370	449347	2457 037874	NADEZHDA MALYSHEVA	{"email": "nadezhda_malysheva_1970@postgrespro.ru", "phone": "+70344816186"}
0005434727371	650B70	4495 525095	SERGEY OSIPOV	{"phone": "+70711381917"}
0005434727372	26C8FF	9551 688032	TAMARA KAZAKOVA	{"phone": "+70498977476"}
0005434727373	26C8FF	7191 427880	VASILIY KARPOV	{"phone": "+70152250863"}
0005434727374	17CCB0	9962 243040	ELENA PAVLOVA	{"phone": "+70796351849"}
0005434727375	17CCB0	4585 913408	ALEKSEY SERGEEV	{"email": "sergeev.a30121972@postgrespro.ru", "phone": "+70952005080"}
0005434727376	4B80D0	2606 057125	SVETLANA LEBEDEVA	{"phone": "+70660892388"}
0005434727377	78D999	4361 929560	NATALYA FROLOVA	{"phone": "+70363443273"}
0005434727378	D501C0	8232 363950	ANNA MARTYNOVA	{"email": "a-martynova.1963@postgrespro.ru", "phone": "+70154444619"}
0005434727379	D501C0	3175 468602	ARTEM GERASIMOV	{"email": "artemgerasimov-1972@postgrespro.ru", "phone": "+70378797569"}
0005434727380	657B7F	0927 170374	LYUDMILA MIKHAYLOVA	{"email": "mikhaylova_l-13111966@postgrespro.ru", "phone": "+70347005910"}
0005434727381	657B7F	0095 207709	SERGEY ZHURAVLEV	{"phone": "+70892296429"}
0005434727382	D46E36	8676 457592	ALEKSEY NIKOLAEV	{"email": "anikolaev-1988@postgrespro.ru", "phone": "+70300503534"}
0005434727383	D1DC7C	6917 045572	VITALIY EGOROV	{"email": "egorov.v-061969@postgrespro.ru", "phone": "+70355548360"}
0005434727384	D1DC7C	2945 013699	OLGA RODIONOVA	{"email": "rodionova.olga-081973@postgrespro.ru", "phone": "+70141755737"}
0005434727385	8A9E4D	3288 762657	ZINAIDA VOLKOVA	{"email": "volkova-zinaida_121974@postgrespro.ru", "phone": "+70075261099"}
0005434727386	0832D4	7635 477829	RUSTAM MIKHAYLOV	{"phone": "+70181982176"}
0005434727387	4C48E1	1061 152623	SERGEY NOVIKOV	{"phone": "+70882475930"}
0005434727388	823FD1	5704 020666	NIKITA IVANOV	{"email": "n.ivanov30051972@postgrespro.ru", "phone": "+70519475206"}
0005434727389	F59EB0	6227 511509	KIRILL KOZLOV	{"email": "kirill-kozlov.29031974@postgrespro.ru", "phone": "+70958754035"}
0005434727390	1A101A	7613 979636	RUSLAN ANDREEV	{"phone": "+70656884241"}
0005434727391	1A101A	0389 293358	PETR STEPANOV	{"phone": "+70700783006"}
0005434727392	7EB04C	3773 751223	NINA ANDREEVA	{"email": "n.andreeva_02081973@postgrespro.ru", "phone": "+70843201076"}
0005434727393	006E64	2362 962620	OLEG KISELEV	{"phone": "+70367682798"}
0005434727394	F4405E	3485 896830	RAISA IVANOVA	{"email": "rivanova_25111968@postgrespro.ru", "phone": "+70145197713"}
0005434727395	286392	4959 796404	OLGA ALEKSANDROVA	{"email": "olga-aleksandrova091978@postgrespro.ru", "phone": "+70836368342"}
0005434727396	045056	7717 960687	GRIGORIY GAVRILOV	{"phone": "+70612278731"}
0005434727397	B78FEB	7894 785740	DARYA ORLOVA	{"phone": "+70988949002"}
0005434727398	B78FEB	3226 883019	NINA NIKITINA	{"email": "nina.nikitina.1965@postgrespro.ru", "phone": "+70805238695"}
0005434727399	9D7504	9489 398160	OLGA ROMANOVA	{"phone": "+70109809998"}
0005434727400	033192	1220 352284	KAPITALINA AFANASEVA	{"email": "kapitalinaafanaseva-101966@postgrespro.ru", "phone": "+70826897815"}
0005434727401	033192	0616 496448	IGOR ZHUKOV	{"email": "zhukov.igor.1970@postgrespro.ru", "phone": "+70092981656"}
0005434727402	F65316	6542 349710	ALEKSEY STEPANOV	{"phone": "+70227349583"}
0005434727403	F65316	5677 441780	EGOR SHEVCHENKO	{"email": "shevchenko.e-1974@postgrespro.ru", "phone": "+70446135514"}
0005434727404	7FD71F	3801 630867	VIKTOR VASILEV	{"email": "viktor.vasilev_121975@postgrespro.ru", "phone": "+70765546679"}
0005434727405	DE3448	6214 649501	ILYA KUZNECOV	{"email": "kuznecov-ilya-30051962@postgrespro.ru", "phone": "+70101198941"}
0005434727406	DE3448	2736 651522	ELENA RODIONOVA	{"phone": "+70791999456"}
0005434727407	5FF37A	9031 295664	MIKHAIL EGOROV	{"email": "egorov-mikhail-071969@postgrespro.ru", "phone": "+70173956693"}
0005434727408	5FF37A	6124 981454	DENIS PAVLOV	{"phone": "+70785000321"}
0005434727409	55AD84	2260 128394	RUSLAN RODIONOV	{"email": "ruslan-rodionov.021971@postgrespro.ru", "phone": "+70141989504"}
0005434727410	0FE47A	0943 172753	ALEKSEY VASILEV	{"email": "aleksey.vasilev_041960@postgrespro.ru", "phone": "+70355935953"}
0005434727411	C9D22E	3690 019441	IRINA SOLOVEVA	{"phone": "+70368760646"}
0005434727412	518B8A	5820 008015	VASILIY VLASOV	{"phone": "+70295173507"}
0005434727413	CC41A9	3253 577481	VIKTOR ALEKSEEV	{"phone": "+70221094631"}
0005434727414	A8D14A	6536 186179	EVGENIY KOZLOV	{"email": "kozlov.evgeniy.07121976@postgrespro.ru", "phone": "+70819073741"}
0005434727415	A8D14A	0372 747902	ALEKSEY SMIRNOV	{"email": "a_smirnov.22021984@postgrespro.ru", "phone": "+70901332561"}
0005434727416	A8D14A	7260 105155	SERGEY PAVLOV	{"email": "pavlov.s08121978@postgrespro.ru", "phone": "+70456288037"}
0005434727417	F86E0B	6247 391784	MIKHAIL SOKOLOV	{"email": "mikhailsokolov_1968@postgrespro.ru", "phone": "+70353588586"}
0005434727418	510DEC	7066 693911	VERA EFIMOVA	{"phone": "+70967472392"}
0005434727419	46B7C2	7740 214069	ILYA IVANOV	{"email": "iivanov02111969@postgrespro.ru", "phone": "+70520029348"}
0005434727420	A5B1DA	4602 950474	IGNAT SAVELEV	{"email": "savelev_ignat_041977@postgrespro.ru", "phone": "+70806228150"}
0005434727421	27FC47	9651 728327	ILYAS IVANOV	{"email": "ilyasivanov-071981@postgrespro.ru", "phone": "+70955547392"}
0005434727422	27FC47	7925 701707	LARISA BOGDANOVA	{"phone": "+70240285886"}
0005434727423	2BB0F7	9203 212885	ANNA MAKAROVA	{"phone": "+70254685904"}
0005434727424	C266F0	8464 029155	OKSANA SOKOLOVA	{"phone": "+70145812504"}
0005434727425	C186EE	0111 065623	EMIL ZHUKOV	{"email": "ezhukov.02011983@postgrespro.ru", "phone": "+70682595091"}
0005434727426	C186EE	7083 181322	YULIYA MELNIKOVA	{"phone": "+70609884665"}
0005434727427	C186EE	3012 012814	SERGEY ISAEV	{"email": "isaevsergey.041964@postgrespro.ru", "phone": "+70031321281"}
0005434727428	1B91A2	3484 965191	PETR KUZNECOV	{"email": "p_kuznecov_21031973@postgrespro.ru", "phone": "+70603571854"}
0005434727429	C103F3	3037 274525	IVAN ISAEV	{"email": "i.isaev1959@postgrespro.ru", "phone": "+70974515466"}
0005434727430	1212B1	5293 347483	IRINA BOGDANOVA	{"phone": "+70992698844"}
0005434727431	EC519F	2369 353790	GAGIK PETROV	{"phone": "+70545692178"}
0005434727432	EC519F	2911 067282	SVETLANA SOKOLOVA	{"phone": "+70901679837"}
0005434727433	5C5C46	9310 759022	NINA SERGEEVA	{"phone": "+70224687312"}
0005434727434	5C5C46	6034 191711	TATYANA KALININA	{"email": "kalinina-tatyana1978@postgrespro.ru", "phone": "+70955133715"}
0005434727435	C84B08	9949 573091	TAISIYA IVANOVA	{"email": "ivanova_t.081973@postgrespro.ru", "phone": "+70514940586"}
0005434727436	AF8A88	2330 230439	IGOR VOLKOV	{"email": "igorvolkov-1971@postgrespro.ru", "phone": "+70622789606"}
0005434727437	FB1D94	6715 762462	SERGEY MATVEEV	{"phone": "+70763796958"}
0005434727438	9F3783	7589 910105	YAROSLAV KUDRYASHOV	{"email": "kudryashovy-21071986@postgrespro.ru", "phone": "+70313165116"}
0005434727439	17E351	1969 205101	MIKHAIL ZHUKOV	{"email": "zhukov_mikhail.1981@postgrespro.ru", "phone": "+70438447500"}
0005434727440	F81670	0655 918348	NATALYA SMIRNOVA	{"email": "smirnova.natalya1958@postgrespro.ru", "phone": "+70151141178"}
0005434727441	F81670	5532 031018	SANIYA SAVELEVA	{"phone": "+70322241868"}
0005434727442	603E65	9576 074887	DENIS KOROLEV	{"phone": "+70324145454"}
0005434727443	603E65	4726 998084	ALLA ZAKHAROVA	{"email": "azakharova-30121973@postgrespro.ru", "phone": "+70886573410"}
0005434727444	DA507E	4390 413469	NATALYA GAVRILOVA	{"email": "gavrilovan_1982@postgrespro.ru", "phone": "+70763293516"}
0005434727445	DA507E	3826 274021	ARTUR VOLKOV	{"email": "volkov_artur31071974@postgrespro.ru", "phone": "+70809602673"}
0005434727446	F62AE6	6540 776260	TATYANA AFANASEVA	{"phone": "+70337626474"}
0005434727447	8B3DFE	5629 684208	DENIS KUZNECOV	{"email": "dkuznecov17071975@postgrespro.ru", "phone": "+70728278670"}
0005434727448	AF692F	8320 269342	ALEKSEY KRASNOV	{"email": "a-krasnov-1972@postgrespro.ru", "phone": "+70255180611"}
0005434727449	AF692F	1322 255620	VALERIY KRASNOV	{"email": "krasnov_valeriy-1973@postgrespro.ru", "phone": "+70690955082"}
0005434727450	F4B2B6	0684 432175	LYUDMILA SEMENOVA	{"email": "semenova.lyudmila-091975@postgrespro.ru", "phone": "+70923975550"}
0005434727451	E70628	7649 398315	ALEKSEY SOROKIN	{"email": "sorokin_a-30041976@postgrespro.ru", "phone": "+70618570462"}
0005434727452	E70628	7414 103419	ELENA SAVELEVA	{"email": "esaveleva.12011965@postgrespro.ru", "phone": "+70038086960"}
0005434727453	247DFB	6633 927190	DMITRIY PAVLOV	{"phone": "+70162463135"}
0005434727454	247DFB	5382 232743	MARINA ANDREEVA	{"phone": "+70998157377"}
0005434727455	C2ABC9	1495 701081	DMITRIY DAVYDOV	{"email": "davydov-d-011972@postgrespro.ru", "phone": "+70759194631"}
0005434727456	DFE73A	9640 632615	KIRILL ANDREEV	{"phone": "+70326830411"}
0005434727457	806640	7679 501085	EVGENIY SHEVCHENKO	{"email": "shevchenko_evgeniy-061978@postgrespro.ru", "phone": "+70120453228"}
0005434727458	806640	5296 803636	VALENTINA KULIKOVA	{"email": "valentina-kulikova.051976@postgrespro.ru", "phone": "+70074188696"}
0005434727459	ADC7A5	6319 665802	SERGEY MIKHAYLOV	{"phone": "+70899973258"}
0005434727460	ADC7A5	5508 060272	ELENA NOVIKOVA	{"phone": "+70782366558"}
0005434727461	E2DDDC	9169 198802	KIRILL KUZMIN	{"email": "kkuzmin-111971@postgrespro.ru", "phone": "+70705137428"}
0005434727462	545147	5515 490345	SERGEY FEDOROV	{"phone": "+70860312040"}
0005434727463	9E6721	4688 952375	VLADIMIR IVANOV	{"email": "vladimirivanov-23061968@postgrespro.ru", "phone": "+70011586664"}
0005434727464	9E6721	7955 177371	ALEKSEY NIKITIN	{"phone": "+70660994693"}
0005434727465	DCC05C	5782 706270	TATYANA BELOVA	{"email": "tatyana_belova25121976@postgrespro.ru", "phone": "+70827559320"}
0005434727466	B6FCD6	3228 000398	NATALYA ISAEVA	{"email": "isaeva.n23021973@postgrespro.ru", "phone": "+70181147746"}
0005434727467	9B0DD3	4601 384008	NADEZHDA SMIRNOVA	{"phone": "+70860009613"}
0005434727469	26698D	0547 872237	NATALYA ABRAMOVA	{"email": "natalya.abramova-101974@postgrespro.ru", "phone": "+70036984870"}
0005434727470	589AFA	6139 357691	VALENTINA SIDOROVA	{"phone": "+70759276245"}
0005434727471	994A4F	6425 702782	YURIY VOROBEV	{"phone": "+70334130178"}
0005434727472	E0DAF8	5262 546810	YURIY AFANASEV	{"email": "afanasev-yuriy1964@postgrespro.ru", "phone": "+70360246081"}
0005434727473	E0DAF8	9857 239826	VLADIMIR SIDOROV	{"email": "vsidorov-15091967@postgrespro.ru", "phone": "+70997272136"}
0005434727474	E0DAF8	9749 632441	DANIIL KUZNECOV	{"phone": "+70104716276"}
0005434727475	178966	1056 940648	VITALIY FILIPPOV	{"email": "vitaliy_filippov1974@postgrespro.ru", "phone": "+70420633247"}
0005434727476	12B34B	0295 726639	LYUBOV POPOVA	{"email": "popova-l051963@postgrespro.ru", "phone": "+70253159866"}
0005434727477	6EAD67	9295 843806	VASILIY IVANOV	{"phone": "+70783722401"}
0005434727478	6EAD67	3705 898244	KSENIYA ABRAMOVA	{"phone": "+70740863328"}
0005434727479	99875D	6249 637817	IGOR PETROV	{"email": "i_petrov.09051988@postgrespro.ru", "phone": "+70059853370"}
0005434727480	31D6E6	4877 936819	ANASTASIYA MATVEEVA	{"phone": "+70605063049"}
0005434727481	A58A86	9246 186381	SNEZHANA SOKOLOVA	{"email": "sokolova-snezhana11121980@postgrespro.ru", "phone": "+70307939745"}
0005434727482	A58A86	5043 694487	VALERIY ORLOV	{"phone": "+70388401477"}
0005434727483	E6695D	7824 291905	ALEKSANDRA SMIRNOVA	{"phone": "+70694188965"}
0005434727484	CACA99	0098 651363	IVAN ZHURAVLEV	{"phone": "+70729199743"}
0005434727485	CACA99	6346 464937	MAKSIM EGOROV	{"email": "maksim_egorov-011971@postgrespro.ru", "phone": "+70967500431"}
0005434727486	60556D	6634 797329	ZINAIDA ILINA	{"email": "z.ilina.1968@postgrespro.ru", "phone": "+70887420156"}
0005434727487	60556D	3376 015555	ALEKSANDR MIKHAYLOV	{"phone": "+70388947563"}
0005434727488	95AC29	7158 736787	IVAN SERGEEV	{"email": "sergeev_i111977@postgrespro.ru", "phone": "+70577921131"}
0005434727489	98C928	9645 228712	OLESYA KALININA	{"phone": "+70646984080"}
0005434727490	1BD887	6308 549504	EVGENIYA RYABOVA	{"email": "e.ryabova-031968@postgrespro.ru", "phone": "+70757524484"}
0005434727491	1BD887	4617 070624	ARINA SAVELEVA	{"phone": "+70044893628"}
0005434727492	A476EF	5259 167651	ALEKSANDR FILIPPOV	{"email": "filippov-a11091980@postgrespro.ru", "phone": "+70112740009"}
0005434727493	77DCF8	5377 519162	ANASTASIYA KONOVALOVA	{"phone": "+70485284966"}
0005434727494	16A071	6945 118659	VALENTIN ZAYCEV	{"email": "zaycevv.061977@postgrespro.ru", "phone": "+70086376494"}
0005434727495	812475	2972 869257	ELENA VOROBEVA	{"phone": "+70457844515"}
0005434727496	5EF6D4	2860 411920	GENNADIY MAKAROV	{"email": "g.makarov-091971@postgrespro.ru", "phone": "+70599897999"}
0005434727497	F39E36	2344 857040	DANIIL KAZAKOV	{"phone": "+70471878503"}
0005434727498	F39E36	5109 031418	SERGEY POPOV	{"phone": "+70047386894"}
0005434727499	C84C37	3573 845254	OLEG SOLOVEV	{"phone": "+70523458894"}
0005434727500	A01558	4572 492784	IRINA MAKSIMOVA	{"phone": "+70332939467"}
0005434727501	555345	3949 436551	ANDREY MIRONOV	{"phone": "+70410818956"}
0005434727502	082C4B	9653 824027	ANASTASIYA NOVIKOVA	{"phone": "+70469271636"}
0005434727503	AFF46F	5306 605813	VITALIY MAKAROV	{"email": "vitaliy-makarov_1973@postgrespro.ru", "phone": "+70280375121"}
0005434727671	F72931	0761 760251	ELENA GUSEVA	{"phone": "+70094157899"}
0005434727504	A7DFC0	0817 219097	SERGEY FEDOROV	{"email": "sergeyfedorov081970@postgrespro.ru", "phone": "+70294527066"}
0005434727505	1C14DF	3969 785134	GALINA KOROLEVA	{"email": "koroleva.galina021972@postgrespro.ru", "phone": "+70259169892"}
0005434727506	1C14DF	0752 955290	VALENTINA NOVIKOVA	{"email": "novikova.v.1960@postgrespro.ru", "phone": "+70870402864"}
0005434727507	7E9E6F	2744 938677	MARIYA KOROLEVA	{"phone": "+70548557474"}
0005434727508	7E9E6F	0657 856243	PAVEL GUSEV	{"email": "p_gusev.16031976@postgrespro.ru", "phone": "+70591456415"}
0005434727509	7E9E6F	8637 781679	MIKHAIL SHEVCHENKO	{"phone": "+70596632951"}
0005434727510	CE0B68	3083 288775	EKATERINA ALEKSANDROVA	{"email": "e_aleksandrova_28111982@postgrespro.ru", "phone": "+70762927740"}
0005434727511	AC42C6	3594 703748	LYUDMILA ANISIMOVA	{"phone": "+70157496809"}
0005434727512	EFD7F7	4082 242375	MAKSIM BARANOV	{"phone": "+70125835828"}
0005434727513	EFD7F7	1789 681751	TATYANA ORLOVA	{"phone": "+70955636032"}
0005434727514	2B3861	2556 803429	NIKOLAY NOVIKOV	{"email": "nnovikov-09041976@postgrespro.ru", "phone": "+70600152908"}
0005434727515	135161	7010 321302	ANNA FROLOVA	{"email": "anna-frolova121975@postgrespro.ru", "phone": "+70029111060"}
0005434727516	3F3AE2	7033 623746	ALEKSEY KUZMIN	{"phone": "+70363190449"}
0005434727517	5C6247	8783 591928	STANISLAV ZAKHAROV	{"email": "zakharovstanislav1966@postgrespro.ru", "phone": "+70565539635"}
0005434727518	3B5213	0775 680544	ANASTASIYA YUDINA	{"email": "anastasiya_yudina18081970@postgrespro.ru", "phone": "+70862666061"}
0005434727519	E25692	3598 427529	NIKOLAY SEMENOV	{"email": "nikolay-semenov_1955@postgrespro.ru", "phone": "+70335597763"}
0005434727520	E25692	9172 958915	TATYANA TIMOFEEVA	{"email": "timofeeva-tatyana12041962@postgrespro.ru", "phone": "+70919604987"}
0005434727521	E25692	6151 887983	GALINA MARTYNOVA	{"phone": "+70720032153"}
0005434727522	6F6563	0495 604594	ALEKSANDRA ARKHIPOVA	{"email": "arkhipovaaleksandra.081971@postgrespro.ru", "phone": "+70455020677"}
0005434727523	6F6563	4588 021947	YURIY PAVLOV	{"email": "yuriy_pavlov_1956@postgrespro.ru", "phone": "+70836565698"}
0005434727524	2EE46F	1274 147326	KHALIDA NOVIKOVA	{"phone": "+70094542519"}
0005434727525	2EE46F	3636 469992	ALEKSANDR YAKOVLEV	{"phone": "+70489135888"}
0005434727526	0F19B4	9633 715096	GALINA AFANASEVA	{"phone": "+70441000850"}
0005434727527	0F19B4	7928 651997	NIKOLAY FILIPPOV	{"email": "nikolayfilippov-29091970@postgrespro.ru", "phone": "+70527773434"}
0005434727528	74C1BB	9209 786388	SVETLANA OSIPOVA	{"email": "svetlana-osipova1962@postgrespro.ru", "phone": "+70680219497"}
0005434727529	3C2EFF	0964 389185	ANASTASIYA KOMAROVA	{"phone": "+70956000594"}
0005434727530	3C2EFF	3976 615997	YURIY MOROZOV	{"phone": "+70135195242"}
0005434727531	2D7FED	1464 556491	ANATOLIY MATVEEV	{"phone": "+70320376344"}
0005434727532	2D7FED	3211 550442	LYUDMILA FROLOVA	{"email": "lfrolova.041968@postgrespro.ru", "phone": "+70455202885"}
0005434727533	2D7FED	1441 207328	LYUBOV MOROZOVA	{"phone": "+70033412509"}
0005434727590	C8CA88	2271 155339	SVETLANA SIDOROVA	{"phone": "+70396981371"}
0005434727534	1A581F	3759 256349	ANNA NIKOLAEVA	{"email": "a_nikolaeva.21081970@postgrespro.ru", "phone": "+70539713755"}
0005434727535	1A581F	2673 723370	VALENTINA KUZNECOVA	{"phone": "+70228951835"}
0005434727536	776D91	8641 131180	DENIS FILIPPOV	{"phone": "+70314739863"}
0005434727537	776D91	3650 234777	OLGA SOLOVEVA	{"phone": "+70204445540"}
0005434727538	D2AA1E	4564 496321	ZARINA ILINA	{"email": "ilinaz_1979@postgrespro.ru", "phone": "+70732564041"}
0005434727539	4891D2	9001 821762	ANDREY FROLOV	{"phone": "+70418422323"}
0005434727540	F3D52D	4480 934409	EKATERINA ZHUKOVA	{"email": "zhukova.ekaterina_14071973@postgrespro.ru", "phone": "+70916188678"}
0005434727541	F3D52D	7047 322136	SERGEY POPOV	{"email": "sergey_popov-20051973@postgrespro.ru", "phone": "+70413900279"}
0005434727542	F3D52D	5016 306783	DMITRIY PETROV	{"phone": "+70855432092"}
0005434727543	B68EFC	5206 950764	MARYAM MELNIKOVA	{"email": "maryam_melnikova02011983@postgrespro.ru", "phone": "+70327494460"}
0005434727544	027E6F	0951 579731	VALENTINA KUZMINA	{"phone": "+70982318724"}
0005434727545	F99EF2	6322 509066	SERGEY FEDOROV	{"phone": "+70940274600"}
0005434727546	F99EF2	5776 343611	TATYANA ILINA	{"email": "ilinat-20061981@postgrespro.ru", "phone": "+70659160356"}
0005434727547	C3D8CD	9462 927122	VLADIMIR KARPOV	{"email": "karpovvladimir.30071971@postgrespro.ru", "phone": "+70315178879"}
0005434727548	C3D8CD	6230 655908	MIKHAIL GUSEV	{"phone": "+70810356144"}
0005434727549	755589	7231 538814	KONSTANTIN SCHERBAKOV	{"email": "scherbakovk.07051967@postgrespro.ru", "phone": "+70704796956"}
0005434727550	755589	6534 176496	ANTONINA KALININA	{"email": "kalinina_a30011973@postgrespro.ru", "phone": "+70282215826"}
0005434727551	E5E9AF	5720 657829	NIKOLAY ORLOV	{"email": "orlovn1969@postgrespro.ru", "phone": "+70933480200"}
0005434727552	E5E9AF	3197 948804	TATYANA LUKYANOVA	{"email": "lukyanovatatyana-1973@postgrespro.ru", "phone": "+70265893763"}
0005434727553	EA1365	1083 065019	MARINA YAKOVLEVA	{"email": "myakovleva_091972@postgrespro.ru", "phone": "+70870826980"}
0005434727554	EA1365	8708 092765	ELENA MOISEEVA	{"phone": "+70012361662"}
0005434727555	541BD4	9244 212144	NADEZHDA ZHURAVLEVA	{"phone": "+70788959837"}
0005434727556	541BD4	1198 390887	LYUDMILA TIMOFEEVA	{"phone": "+70924876076"}
0005434727557	AA52A3	1650 812234	VIKTOR KUZNECOV	{"phone": "+70945297399"}
0005434727558	D9A345	4823 899906	VALERIY MIKHAYLOV	{"phone": "+70971585721"}
0005434727559	D9A345	3722 731172	GULNARA MAKAROVA	{"email": "makarova-g-021969@postgrespro.ru", "phone": "+70619662228"}
0005434727560	7BFD47	4824 161675	MIKHAIL FILIPPOV	{"email": "filippovmikhail-1966@postgrespro.ru", "phone": "+70428031782"}
0005434727561	14F58C	0637 528201	DMITRIY CHERNOV	{"phone": "+70259934975"}
0005434727562	054D69	9101 708702	ALEKSANDR NIKOLAEV	{"phone": "+70534075927"}
0005434727563	054D69	9087 612499	INNA SMIRNOVA	{"email": "inna_smirnova061979@postgrespro.ru", "phone": "+70294593533"}
0005434727564	054D69	3020 531875	ALEKSANDR IVANOV	{"phone": "+70804837786"}
0005434727565	C35CE9	8165 320701	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov-011966@postgrespro.ru", "phone": "+70290078908"}
0005434727566	2DFCDA	7886 174077	GALINA FOMINA	{"email": "galina_fomina.08021967@postgrespro.ru", "phone": "+70654533453"}
0005434727567	2DFCDA	0848 163920	RINAT ALEKSANDROV	{"email": "aleksandrov.r_1975@postgrespro.ru", "phone": "+70343509126"}
0005434727568	E389F5	0740 482726	IRINA NOVIKOVA	{"phone": "+70693014172"}
0005434727569	E389F5	4285 530700	DARYA MATVEEVA	{"email": "matveeva.d_19061991@postgrespro.ru", "phone": "+70954969386"}
0005434727570	5A4990	4950 318880	SERGEY SOKOLOV	{"email": "s-sokolov071962@postgrespro.ru", "phone": "+70963937161"}
0005434727571	201534	9883 636849	LYUBOV DAVYDOVA	{"email": "davydova-lyubov-121979@postgrespro.ru", "phone": "+70759200195"}
0005434727572	201534	4528 745953	IRINA FOMINA	{"phone": "+70737088166"}
0005434727573	02A6DF	0379 370754	DENIS IVANOV	{"phone": "+70141236406"}
0005434727574	4DA583	4452 637857	ANNA ANDREEVA	{"email": "anna_andreeva_1970@postgrespro.ru", "phone": "+70230879611"}
0005434727575	DFA92E	0274 210602	EVDOKIYA KOZLOVA	{"phone": "+70337090736"}
0005434727576	E2CABA	0790 619953	ANDREY SERGEEV	{"phone": "+70859857211"}
0005434727577	7B94B7	2646 345026	DMITRIY KUZNECOV	{"email": "dmitriykuznecov-031971@postgrespro.ru", "phone": "+70768775005"}
0005434727578	2F5810	1779 256454	LARISA KOVALEVA	{"phone": "+70533190532"}
0005434727579	E4EE99	7951 960232	SERGEY ANDREEV	{"email": "sergey.andreev061975@postgrespro.ru", "phone": "+70109939218"}
0005434727580	A9953C	5302 851821	VIKTOR ANTONOV	{"email": "viktor_antonov051964@postgrespro.ru", "phone": "+70677872155"}
0005434727581	A9953C	1771 000778	EKATERINA LEBEDEVA	{"email": "lebedeva_ekaterina071971@postgrespro.ru", "phone": "+70402758483"}
0005434727582	CD3A6A	9707 592516	VALENTINA MATVEEVA	{"phone": "+70207631461"}
0005434727583	E72364	2099 740481	MIKHAIL PAVLOV	{"email": "mpavlov_24021975@postgrespro.ru", "phone": "+70466651882"}
0005434727584	E72364	8240 277539	ANASTASIYA EFIMOVA	{"phone": "+70967680586"}
0005434727585	0D2B81	4486 785999	ALEKSEY SCHERBAKOV	{"phone": "+70800209087"}
0005434727586	01706D	7604 724893	NINA IVANOVA	{"phone": "+70976737042"}
0005434727587	B87A4A	6323 382011	VALENTINA VASILEVA	{"phone": "+70557269277"}
0005434727588	B87A4A	0102 016263	NIKOLAY SEMENOV	{"phone": "+70761467531"}
0005434727589	C8CA88	3441 435472	POLINA ANDREEVA	{"email": "andreevap_14061959@postgrespro.ru", "phone": "+70985048070"}
0005434727591	6B44F6	7857 255240	IRINA FEDOROVA	{"email": "fedorova_irina_1975@postgrespro.ru", "phone": "+70489129486"}
0005434727592	5D38F2	6330 462432	ANDREY ANDREEV	{"email": "andreev.andrey101974@postgrespro.ru", "phone": "+70371041170"}
0005434727593	049FA5	3519 606043	NINA MAKSIMOVA	{"email": "n.maksimova_30081966@postgrespro.ru", "phone": "+70829519695"}
0005434727594	049FA5	8770 360472	RAMIL KOZLOV	{"email": "ramilkozlov16041976@postgrespro.ru", "phone": "+70724209661"}
0005434727595	9AC8C2	6215 527956	ALEKSANDR SMIRNOV	{"email": "a-smirnov-1968@postgrespro.ru", "phone": "+70177612475"}
0005434727596	9AC8C2	6152 214163	IVAN SAVELEV	{"email": "ivan.savelev.1997@postgrespro.ru", "phone": "+70331496858"}
0005434727597	8F32DB	7043 630319	VALENTINA KUZNECOVA	{"phone": "+70009195694"}
0005434727598	8F32DB	2408 141631	MARINA AKIMOVA	{"phone": "+70577705423"}
0005434727599	8F32DB	6067 906054	KARINA ROMANOVA	{"email": "karina_romanova_16031977@postgrespro.ru", "phone": "+70855491077"}
0005434727600	502F2E	1784 246322	MIKHAIL VOLKOV	{"email": "volkovm071976@postgrespro.ru", "phone": "+70025127106"}
0005434727601	0F7BA4	5484 743803	ALENA IVANOVA	{"email": "ivanova_alena-11021976@postgrespro.ru", "phone": "+70130068611"}
0005434727602	0F7BA4	8243 552267	RINAT KULIKOV	{"email": "rinat-kulikov.1963@postgrespro.ru", "phone": "+70370804994"}
0005434727603	05F2F9	2640 835573	LYUDMILA ALEKSANDROVA	{"phone": "+70286972990"}
0005434727604	05F2F9	1798 145443	EDGAR KRASNOV	{"email": "krasnov.edgar041992@postgrespro.ru", "phone": "+70494840566"}
0005434727605	EEB047	3827 523247	BORIS GUSEV	{"email": "b_gusev011980@postgrespro.ru", "phone": "+70232153683"}
0005434727606	7B9971	5674 310825	SERGEY BARANOV	{"email": "baranov.s.22051971@postgrespro.ru", "phone": "+70133310915"}
0005434727607	082AC2	9940 768992	TATYANA VOLKOVA	{"email": "tatyana-volkova.111976@postgrespro.ru", "phone": "+70381993320"}
0005434727608	BD9895	3275 044885	NINEL IVANOVA	{"phone": "+70471313937"}
0005434727609	B15F09	5637 469122	NATALYA MAKAROVA	{"email": "natalya_makarova1978@postgrespro.ru", "phone": "+70368671225"}
0005434727610	AD5BB5	5051 740209	TAMARA SAVELEVA	{"phone": "+70344647153"}
0005434727611	10D306	4162 283311	SERGEY KONOVALOV	{"email": "s.konovalov.1967@postgrespro.ru", "phone": "+70036333402"}
0005434727612	E4C77B	6492 628061	ANTON ALEKSEEV	{"phone": "+70599145200"}
0005434727613	E4C77B	7655 467098	ELENA FROLOVA	{"email": "frolova.e23081972@postgrespro.ru", "phone": "+70831946132"}
0005434727614	D931F8	3751 408143	TATYANA VOLKOVA	{"email": "volkova_t-1974@postgrespro.ru", "phone": "+70495258192"}
0005434727616	BE2C4D	9078 625288	NINA KAZAKOVA	{"email": "nkazakova_111977@postgrespro.ru", "phone": "+70092301447"}
0005434727617	0D9F41	7324 843557	PAVEL NIKITIN	{"email": "p_nikitin-1981@postgrespro.ru", "phone": "+70329020664"}
0005434727618	DEEC97	8934 110580	DMITRIY BORISOV	{"phone": "+70207077639"}
0005434727619	7932D1	5490 755715	MARGARITA KOROLEVA	{"email": "margarita-koroleva.01111988@postgrespro.ru", "phone": "+70106930630"}
0005434727620	7932D1	8559 561691	OLGA KUZNECOVA	{"email": "olga-kuznecova.1977@postgrespro.ru", "phone": "+70455517825"}
0005434727621	988FC1	9989 922519	SERGEY ZHURAVLEV	{"email": "zhuravlev_sergey.091977@postgrespro.ru", "phone": "+70039657581"}
0005434727622	3BEF08	9686 637457	MAKSIM ANTONOV	{"email": "antonov-m_041969@postgrespro.ru", "phone": "+70788072381"}
0005434727623	4DDE01	8429 733725	ANDREY PETROV	{"phone": "+70736239757"}
0005434727624	4DDE01	2364 319967	ANATOLIY BORISOV	{"phone": "+70504931497"}
0005434727625	D0A740	7310 382620	DMITRIY ANDREEV	{"phone": "+70024754027"}
0005434727626	DBB038	2878 063890	NATALYA STEPANOVA	{"email": "n.stepanova-051968@postgrespro.ru", "phone": "+70225287512"}
0005434727627	DAA3F4	7375 185647	YURIY FROLOV	{"phone": "+70521424473"}
0005434727628	DAA3F4	6727 930607	VIKTORIYA SOROKINA	{"phone": "+70583926718"}
0005434727629	1EC300	0167 566885	DMITRIY KISELEV	{"email": "d-kiselev.051967@postgrespro.ru", "phone": "+70974587131"}
0005434727630	1EC300	8091 455308	TATYANA SOKOLOVA	{"phone": "+70214402156"}
0005434727631	1EC300	1243 942514	ANGELINA IVANOVA	{"email": "ivanova-angelina011970@postgrespro.ru", "phone": "+70224122745"}
0005434727632	CDEB43	8556 066628	LYUBOV MAKSIMOVA	{"phone": "+70615855151"}
0005434727633	CDEB43	7796 677734	VASILIY ANDREEV	{"email": "vandreev.1977@postgrespro.ru", "phone": "+70636658517"}
0005434727634	DA3ACE	1330 561839	ALEKSEY ROMANOV	{"phone": "+70254552138"}
0005434727635	DA3ACE	5261 938761	NADEZHDA RODIONOVA	{"email": "rodionova-nadezhda_11041967@postgrespro.ru", "phone": "+70948857789"}
0005434727636	DA3ACE	8891 773735	SVETLANA STEPANOVA	{"phone": "+70009003861"}
0005434727637	DED0F7	7679 256188	MARIYA SOROKINA	{"phone": "+70851715524"}
0005434727638	A646B0	7202 452658	ANNA LUKYANOVA	{"phone": "+70638015833"}
0005434727639	077F70	6643 941110	GALINA BARANOVA	{"email": "galina-baranova-1965@postgrespro.ru", "phone": "+70912053277"}
0005434727640	077F70	1621 651147	LYUDMILA NAZAROVA	{"phone": "+70847088690"}
0005434727641	7AAE8E	4495 674444	GALINA KUDRYASHOVA	{"email": "kudryashova_galina-1973@postgrespro.ru", "phone": "+70533422330"}
0005434727642	7AAE8E	0416 670809	ANNA EFREMOVA	{"phone": "+70358753891"}
0005434727643	728A72	6674 981196	VALENTINA BOGDANOVA	{"phone": "+70573426241"}
0005434727644	5B0C29	2213 306172	ALEKSANDRA PETROVA	{"phone": "+70774363310"}
0005434727645	5B0C29	3958 681445	NATALYA FROLOVA	{"email": "frolova-natalya-1970@postgrespro.ru", "phone": "+70248455886"}
0005434727701	130E42	3434 157119	NIKOLAY SHEVCHENKO	{"phone": "+70524858740"}
0005434727646	6AF48C	8127 097989	NADEZHDA MELNIKOVA	{"email": "melnikova_nadezhda_1978@postgrespro.ru", "phone": "+70907563511"}
0005434727647	6AF48C	6011 797102	VASILIY POPOV	{"email": "v-popov-01081984@postgrespro.ru", "phone": "+70386691244"}
0005434727648	295ED7	2337 648331	ALEKSANDR VLASOV	{"phone": "+70628002480"}
0005434727649	AA5750	1011 733903	VERA GORBUNOVA	{"email": "vera.gorbunova25041969@postgrespro.ru", "phone": "+70198406373"}
0005434727650	3033A8	4573 258096	VASILIY MELNIKOV	{"email": "v_melnikov_061977@postgrespro.ru", "phone": "+70121369504"}
0005434727889	4CDC69	3447 464643	VALENTINA ERMAKOVA	{"phone": "+70911233045"}
0005434727651	57DDE7	1607 848794	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev_02011970@postgrespro.ru", "phone": "+70730422580"}
0005434727652	57DDE7	4583 968912	GALINA AFANASEVA	{"email": "afanaseva.galina.1961@postgrespro.ru", "phone": "+70517538365"}
0005434727653	E85593	5835 189871	IRINA MOROZOVA	{"email": "irina_morozova-1970@postgrespro.ru", "phone": "+70128232337"}
0005434727654	E85593	7377 010514	IRINA ANDREEVA	{"email": "i_andreeva.23021971@postgrespro.ru", "phone": "+70991311865"}
0005434727655	0FE154	6878 938034	NIKITA MAKAROV	{"phone": "+70353286505"}
0005434727656	2D6000	6262 251393	ALLA KISELEVA	{"phone": "+70004440507"}
0005434727657	2D6000	7747 570715	ALINA ALEKSANDROVA	{"email": "alinaaleksandrova.1967@postgrespro.ru", "phone": "+70590969994"}
0005434727658	F980C5	4603 130407	NATALYA MATVEEVA	{"phone": "+70736096616"}
0005434727659	4EFE56	6384 511287	NINA VOROBEVA	{"phone": "+70268505625"}
0005434727660	32E07A	5399 451644	LYUBOV TIKHONOVA	{"email": "tikhonova.l-1969@postgrespro.ru", "phone": "+70082566762"}
0005434727661	DD4D5B	0795 354287	EKATERINA NIKOLAEVA	{"phone": "+70508680894"}
0005434727662	DD4D5B	5618 147458	SVETLANA KAZAKOVA	{"email": "kazakova_svetlana13081972@postgrespro.ru", "phone": "+70073777618"}
0005434727663	75FC49	2112 378937	EKATERINA BORISOVA	{"email": "e-borisova_24061958@postgrespro.ru", "phone": "+70513233836"}
0005434727664	CA0BE0	8542 747653	ALBINA MAKAROVA	{"email": "albinamakarova1979@postgrespro.ru", "phone": "+70518149993"}
0005434727665	FD0D67	9025 448041	ALI ROMANOV	{"phone": "+70235233894"}
0005434727666	04EF3C	2377 448639	VYACHESLAV POPOV	{"phone": "+70079918541"}
0005434727667	E0BB01	5424 980118	ANDREY NAUMOV	{"phone": "+70966476969"}
0005434727668	D7F408	1936 734224	LARISA TIKHONOVA	{"email": "tikhonoval_111966@postgrespro.ru", "phone": "+70432408544"}
0005434727669	D7F408	5439 345359	YURIY OSIPOV	{"phone": "+70358313402"}
0005434727670	5DE4A9	7965 411016	YANA ORLOVA	{"email": "orlova_yana_081970@postgrespro.ru", "phone": "+70288788308"}
0005434727672	2C62E0	7776 199445	AZAT MELNIKOV	{"email": "amelnikov_031973@postgrespro.ru", "phone": "+70145780268"}
0005434727673	2C62E0	1339 624574	FANIS MELNIKOV	{"email": "f-melnikov_20111954@postgrespro.ru", "phone": "+70315140509"}
0005434727674	B7179C	6751 841250	YURIY ORLOV	{"email": "orlovy.1978@postgrespro.ru", "phone": "+70066191004"}
0005434727675	323FE8	0953 448614	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov.011979@postgrespro.ru", "phone": "+70312477135"}
0005434727676	323FE8	1686 419554	NIKOLAY NOVIKOV	{"email": "nikolay_novikov-011972@postgrespro.ru", "phone": "+70747334554"}
0005434727677	36ED11	6553 929909	VALERIYA TIKHONOVA	{"email": "valeriyatikhonova-09101978@postgrespro.ru", "phone": "+70834295211"}
0005434727678	36ED11	5934 571462	YAROSLAV MAKAROV	{"email": "makarovy_1968@postgrespro.ru", "phone": "+70408127583"}
0005434727679	2A5E17	4651 386275	TATYANA NIKIFOROVA	{"email": "nikiforova.tatyana1980@postgrespro.ru", "phone": "+70737739849"}
0005434727680	63B651	4953 676566	NATALYA NIKITINA	{"email": "n-nikitina.1977@postgrespro.ru", "phone": "+70081773659"}
0005434727681	63B651	1317 921182	NINA KOROLEVA	{"phone": "+70452070619"}
0005434727682	12AFDB	0719 763294	ALEKSANDR BELOV	{"email": "belov_aleksandr_06011977@postgrespro.ru", "phone": "+70548998825"}
0005434727683	F5DEDA	1280 287615	ELENA KUZMINA	{"email": "e_kuzmina-11081991@postgrespro.ru", "phone": "+70860607296"}
0005434727684	F5DEDA	3319 458962	SERGEY DENISOV	{"email": "sergeydenisov-051979@postgrespro.ru", "phone": "+70383846032"}
0005434727685	4DE38F	7644 783479	IVAN GUSEV	{"email": "i-gusev1981@postgrespro.ru", "phone": "+70039642613"}
0005434727686	4DE38F	6057 437024	VASILIY NIKITIN	{"email": "v-nikitin26101955@postgrespro.ru", "phone": "+70224222800"}
0005434727687	4DE38F	6809 534399	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina.14101961@postgrespro.ru", "phone": "+70766109416"}
0005434727688	E645E5	0209 224591	TATYANA SOKOLOVA	{"email": "tatyana_sokolova111984@postgrespro.ru", "phone": "+70612084368"}
0005434727689	E645E5	3722 298078	VALERIY SEMENOV	{"email": "semenov.v-101976@postgrespro.ru", "phone": "+70611482979"}
0005434727690	3391EF	0229 065581	YULIYA NIKOLAEVA	{"phone": "+70049892114"}
0005434727691	D77B9B	0646 413692	GENNADIY MAKAROV	{"phone": "+70511010097"}
0005434727692	662D52	0160 909469	ILYA ILIN	{"phone": "+70319648901"}
0005434727693	915D47	6201 241374	MARIYA FEDOROVA	{"email": "m.fedorova.1975@postgrespro.ru", "phone": "+70216284107"}
0005434727694	208711	6940 331910	ALINA STEPANOVA	{"phone": "+70709622677"}
0005434727695	88212D	7605 443117	ALEKSEY MATVEEV	{"phone": "+70811035351"}
0005434727696	88212D	6334 597104	GRIGORIY POPOV	{"email": "g_popov-081969@postgrespro.ru", "phone": "+70472799976"}
0005434727697	88212D	3020 052214	DMITRIY KONOVALOV	{"email": "konovalov-dmitriy111953@postgrespro.ru", "phone": "+70507360042"}
0005434727698	C071D9	9911 901364	NADEZHDA KUZMINA	{"email": "nkuzmina041971@postgrespro.ru", "phone": "+70268975756"}
0005434727699	E2A183	1186 602112	KIRILL KONOVALOV	{"email": "kkonovalov.031979@postgrespro.ru", "phone": "+70066148210"}
0005434727700	0FFF8B	7506 596737	ROMAN IVANOV	{"phone": "+70275273270"}
0005434727702	130E42	2854 573202	SVETLANA EGOROVA	{"email": "s-egorova-19081970@postgrespro.ru", "phone": "+70091425329"}
0005434727703	2E30B8	5621 357566	GULIYA KUZNECOVA	{"phone": "+70751620259"}
0005434727704	7220F0	1559 662759	ELENA LEBEDEVA	{"email": "lebedevaelena_1968@postgrespro.ru", "phone": "+70484629330"}
0005434727705	7220F0	1093 385986	VIKTOR BORISOV	{"email": "borisov_v-011988@postgrespro.ru", "phone": "+70969712085"}
0005434727706	483BD6	1100 498016	VALENTINA KUZNECOVA	{"phone": "+70879930220"}
0005434727707	20A0E3	0216 300921	STANISLAV SCHERBAKOV	{"phone": "+70327484557"}
0005434727708	01D00C	9353 929986	EVGENIY ANTONOV	{"phone": "+70510569001"}
0005434727709	01D00C	9868 487852	ELENA IVANOVA	{"email": "eivanova_071968@postgrespro.ru", "phone": "+70377508443"}
0005434728008	013104	9442 822615	ANNA MOISEEVA	{"phone": "+70920261104"}
0005434727710	0A3EEB	9020 336252	NIKOLAY FEDOROV	{"email": "fedorovnikolay-10121978@postgrespro.ru", "phone": "+70420876799"}
0005434727711	0A3EEB	5373 996631	VALENTINA KOZLOVA	{"phone": "+70001380792"}
0005434727712	2EC88E	4760 748585	YULIYA TIMOFEEVA	{"phone": "+70170509912"}
0005434727713	2EC88E	3691 157945	GAGIK SIDOROV	{"email": "gagik-sidorov-051973@postgrespro.ru", "phone": "+70453203955"}
0005434727714	B1359D	3344 369524	NATALYA NESTEROVA	{"email": "n-nesterova1973@postgrespro.ru", "phone": "+70015955957"}
0005434727715	CED5EB	3869 355908	MARIYA MALYSHEVA	{"phone": "+70980488241"}
0005434727716	02ED31	5270 038616	ALEKSANDR VOLKOV	{"phone": "+70863362141"}
0005434727717	02ED31	8218 563029	VALENTIN MAKAROV	{"email": "makarov-v_1968@postgrespro.ru", "phone": "+70261499390"}
0005434727718	529863	4707 096252	NINA KRASNOVA	{"email": "krasnovan-121975@postgrespro.ru", "phone": "+70749890135"}
0005434727719	FD9F8D	9739 585840	SVETLANA FADEEVA	{"email": "s_fadeeva.1982@postgrespro.ru", "phone": "+70129997178"}
0005434727720	79DCC6	9944 737316	VYACHESLAV GORBUNOV	{"phone": "+70655291284"}
0005434727721	D35E62	7732 355117	ELENA MALYSHEVA	{"email": "malysheva-e.1971@postgrespro.ru", "phone": "+70992921610"}
0005434727722	A0FABA	4446 091230	NATALYA KUDRYASHOVA	{"email": "kudryashova-n.1978@postgrespro.ru", "phone": "+70806375794"}
0005434727723	A0FABA	8132 942826	ANASTASIYA NIKOLAEVA	{"phone": "+70118993273"}
0005434727724	96C0A6	4720 463010	EKATERINA STEPANOVA	{"email": "estepanova_1966@postgrespro.ru", "phone": "+70826310452"}
0005434727725	9F5EAD	3783 250336	ALEKSANDR CHERNOV	{"phone": "+70430388744"}
0005434727726	2DA29F	6558 000336	TATYANA LAZAREVA	{"phone": "+70924447274"}
0005434727727	1717AD	0615 027533	ALEKSANDR TARASOV	{"phone": "+70967002814"}
0005434727728	1717AD	3107 595139	SHAVKAT NAUMOV	{"email": "naumov-s.1968@postgrespro.ru", "phone": "+70228047850"}
0005434727729	021AEF	3041 432749	EDUARD DMITRIEV	{"phone": "+70040476931"}
0005434727730	EE7EEC	0794 522082	LYUDMILA OVCHINNIKOVA	{"email": "lyudmila.ovchinnikova_29121973@postgrespro.ru", "phone": "+70514352346"}
0005434727731	1B662F	8223 166189	TATYANA GUSEVA	{"phone": "+70142780323"}
0005434727732	1B662F	1955 758374	VLADIMIR SEMENOV	{"email": "vladimir_semenov18011973@postgrespro.ru", "phone": "+70673125648"}
0005434727733	9DABD3	9964 762294	DMITRIY STEPANOV	{"email": "stepanov.dmitriy_111963@postgrespro.ru", "phone": "+70662093524"}
0005434727734	83AD94	6382 244273	LYUBOV AFANASEVA	{"phone": "+70040263168"}
0005434727735	DE13C5	3819 683603	KRISTINA DANILOVA	{"phone": "+70059243309"}
0005434727736	4D6458	0181 406802	RAFAEL RODIONOV	{"phone": "+70944170005"}
0005434727737	4EFD8A	5242 114553	YULIYA ANTONOVA	{"email": "antonova_y.07021979@postgrespro.ru", "phone": "+70474337135"}
0005434727738	1314F2	8161 967256	VALERIY MELNIKOV	{"email": "v-melnikov-13021971@postgrespro.ru", "phone": "+70204164728"}
0005434727739	1314F2	8556 492306	GALINA GORBUNOVA	{"email": "galina_gorbunova_05061961@postgrespro.ru", "phone": "+70961168240"}
0005434727740	FEC1CA	1127 615150	RAISA ROMANOVA	{"phone": "+70794039104"}
0005434727741	307401	5144 073544	NADEZHDA OSIPOVA	{"phone": "+70609144772"}
0005434727742	36C392	3351 722007	VLADIMIR ALEKSEEV	{"phone": "+70903255882"}
0005434727743	36C392	8714 763353	ILYA MELNIKOV	{"phone": "+70659981620"}
0005434727744	F66B53	6626 142647	ANNA SMIRNOVA	{"phone": "+70621299997"}
0005434727745	A94DE7	1966 114168	ELENA VASILEVA	{"email": "e.vasileva-23021972@postgrespro.ru", "phone": "+70777926122"}
0005434727746	C0659E	5282 948126	LILIYA MOISEEVA	{"email": "l_moiseeva.1975@postgrespro.ru", "phone": "+70793649290"}
0005434727747	C0659E	8387 865585	YURIY MOISEEV	{"email": "yuriy-moiseev_021963@postgrespro.ru", "phone": "+70662491475"}
0005434727748	C0659E	8747 667367	ALEKSEY SOROKIN	{"email": "a-sorokin.1970@postgrespro.ru", "phone": "+70135180310"}
0005434727749	C0659E	7960 445449	ALEKSANDR ORLOV	{"email": "aleksandr_orlov-03051967@postgrespro.ru", "phone": "+70092776564"}
0005434727750	B28122	9735 728843	EVGENIYA KALININA	{"email": "kalinina.e.05091974@postgrespro.ru", "phone": "+70689524202"}
0005434727751	EDFBA8	1835 167886	TATYANA PETROVA	{"email": "petrova_tatyana.031973@postgrespro.ru", "phone": "+70370626854"}
0005434727752	EDFBA8	8497 045776	ANASTASIYA PETROVA	{"email": "petrovaanastasiya-1979@postgrespro.ru", "phone": "+70070986812"}
0005434727753	451A52	6081 869117	NIKOLAY ALEKSEEV	{"email": "alekseevn-011971@postgrespro.ru", "phone": "+70680171248"}
0005434727754	253315	3091 324829	MAKSIM KISELEV	{"email": "kiselev-maksim.061971@postgrespro.ru", "phone": "+70474367467"}
0005434727755	CDC69C	4842 989005	ALEKSANDR MELNIKOV	{"phone": "+70386480540"}
0005434727756	DFC98A	5097 428329	IGOR MOROZOV	{"phone": "+70856330980"}
0005434727757	DFC98A	6206 400130	ELENA KOLESNIKOVA	{"phone": "+70143015762"}
0005434727758	68E7C9	6052 612101	ELENA ALEKSEEVA	{"email": "alekseeva-elena.091969@postgrespro.ru", "phone": "+70093937559"}
0005434727759	C4C53B	6814 006780	RAMAZAN STEPANOV	{"phone": "+70774391430"}
0005434727760	9A406B	7852 588859	YURIY NOVIKOV	{"email": "novikov-yuriy-1979@postgrespro.ru", "phone": "+70149106375"}
0005434727761	8012C5	0712 214214	NIKOLAY SHEVCHENKO	{"email": "nikolayshevchenko-1977@postgrespro.ru", "phone": "+70336581874"}
0005434727762	43B619	6312 484266	VALERIYA KUZMINA	{"email": "kuzminav081979@postgrespro.ru", "phone": "+70692577185"}
0005434727763	8D1B4B	2514 820642	ALEKSEY MIKHAYLOV	{"email": "alekseymikhaylov-1970@postgrespro.ru", "phone": "+70740573691"}
0005434727764	348BD8	8481 552873	ANASTASIYA SOROKINA	{"phone": "+70921122274"}
0005434727765	0F6DAC	6117 984708	LARISA STEPANOVA	{"email": "larisa_stepanova.14011976@postgrespro.ru", "phone": "+70370513023"}
0005434727766	5E7F43	8619 248498	LYUBOV VOROBEVA	{"phone": "+70046269669"}
0005434727767	E58F49	7272 231147	VERA FROLOVA	{"email": "vera_frolova.1962@postgrespro.ru", "phone": "+70749951186"}
0005434727768	75D804	0408 978129	OLGA STEPANOVA	{"phone": "+70879668052"}
0005434727769	5211D8	4441 149337	PAVEL GUSEV	{"email": "gusev-pavel_011965@postgrespro.ru", "phone": "+70997424140"}
0005434727770	5211D8	2244 508295	MIKHAIL FOMIN	{"email": "fominm_12041980@postgrespro.ru", "phone": "+70534057278"}
0005434727771	8CE470	7658 313807	OLGA FROLOVA	{"email": "frolova.o-31051982@postgrespro.ru", "phone": "+70417368251"}
0005434727772	1351E7	6166 704549	DMITRIY ZHUKOV	{"phone": "+70968268014"}
0005434727773	1351E7	9247 834957	TATYANA FADEEVA	{"email": "t_fadeeva_12081979@postgrespro.ru", "phone": "+70102104145"}
0005434727774	1351E7	6349 866103	NINA MASLOVA	{"email": "maslova_nina1970@postgrespro.ru", "phone": "+70308725739"}
0005434727775	042D9D	6792 947397	NIKITA MELNIKOV	{"email": "melnikov.nikita-02051966@postgrespro.ru", "phone": "+70023101545"}
0005434727776	0571D1	1275 957729	LYUDMILA SCHERBAKOVA	{"email": "scherbakova.l.011982@postgrespro.ru", "phone": "+70328520774"}
0005434727777	0571D1	1986 719769	YAKOV PETROV	{"phone": "+70040521469"}
0005434727778	3C0458	0097 337441	VALENTINA FILIPPOVA	{"phone": "+70080112004"}
0005434727779	5A9105	9717 053857	MARIYA MALYSHEVA	{"email": "malysheva_m-1963@postgrespro.ru", "phone": "+70991332722"}
0005434727780	5A9105	1776 695734	LIDIYA BELYAEVA	{"email": "belyaeva.l.23021981@postgrespro.ru", "phone": "+70419159022"}
0005434727781	5A9105	2228 619966	VYACHESLAV BARANOV	{"phone": "+70642907198"}
0005434727782	85C143	5669 021706	ALEKSEY ZAKHAROV	{"phone": "+70630126666"}
0005434727783	603EAB	9100 569402	OLGA KOVALEVA	{"email": "kovaleva-o.30031979@postgrespro.ru", "phone": "+70894706643"}
0005434727784	94EE87	0944 974324	VIKTOR TARASOV	{"phone": "+70154789708"}
0005434727785	94EE87	5602 499453	LYUDMILA STEPANOVA	{"email": "stepanova.l.101973@postgrespro.ru", "phone": "+70027047684"}
0005434727786	0CE58F	2522 294020	VIKTOR NIKOLAEV	{"phone": "+70903758469"}
0005434727787	0CE58F	9228 239276	SERGEY SOKOLOV	{"phone": "+70049828708"}
0005434727788	1B972A	3854 515898	POLINA ANDREEVA	{"email": "p-andreeva-051972@postgrespro.ru", "phone": "+70872760587"}
0005434727789	66519D	1821 669201	ANDREY EGOROV	{"email": "egorov-a1966@postgrespro.ru", "phone": "+70162872678"}
0005434727790	BE534F	0865 151049	VALERIY ILIN	{"email": "v.ilin1979@postgrespro.ru", "phone": "+70590040805"}
0005434727791	BE534F	5396 547909	ANGELINA EGOROVA	{"phone": "+70437524986"}
0005434727792	AFC1D5	9604 482363	ALEKSEY MEDVEDEV	{"phone": "+70876978934"}
0005434727793	BB0EA7	6788 772835	YULIYA KARPOVA	{"email": "y_karpova_29031979@postgrespro.ru", "phone": "+70677215487"}
0005434727794	36B00B	1872 385773	OKSANA IVANOVA	{"phone": "+70847287297"}
0005434727795	DB8800	8142 282417	VERA MOROZOVA	{"email": "vera-morozova-09081973@postgrespro.ru", "phone": "+70205844074"}
0005434727796	5062B3	1950 781251	ALINA KUZNECOVA	{"email": "kuznecova-alina.10061971@postgrespro.ru", "phone": "+70816272365"}
0005434727797	5062B3	9909 148037	SERGEY MOROZOV	{"email": "s.morozov051972@postgrespro.ru", "phone": "+70196732841"}
0005434727798	8F66FB	8328 625891	LARISA MOISEEVA	{"email": "larisamoiseeva.20101977@postgrespro.ru", "phone": "+70430443276"}
0005434727799	F4570D	8146 112963	SVETLANA LUKYANOVA	{"phone": "+70129035359"}
0005434727800	F11C35	8075 563662	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev-1978@postgrespro.ru", "phone": "+70097907449"}
0005434727801	F11C35	6184 401584	DMITRIY SOKOLOV	{"email": "sokolov-d.1974@postgrespro.ru", "phone": "+70497400519"}
0005434727802	1294E9	3488 977976	OLGA FOMINA	{"phone": "+70988478298"}
0005434727803	750DB0	2614 347874	YURIY BORISOV	{"email": "yuriyborisov_031975@postgrespro.ru", "phone": "+70852765959"}
0005434727804	052609	7022 340090	EKATERINA KOROLEVA	{"email": "koroleva_ekaterina_1969@postgrespro.ru", "phone": "+70363477558"}
0005434727805	052609	1692 872638	SERGEY ISAEV	{"email": "sergey.isaev-091977@postgrespro.ru", "phone": "+70906057056"}
0005434727806	8389C4	8834 133375	VALENTINA BELOVA	{"phone": "+70431110363"}
0005434727807	944049	1800 655017	VIKTORIYA ISAEVA	{"email": "v-isaeva1978@postgrespro.ru", "phone": "+70097641254"}
0005434727808	272D28	6408 141925	YULIYA SOKOLOVA	{"email": "yuliya_sokolova.021972@postgrespro.ru", "phone": "+70067643848"}
0005434727809	272D28	1782 190631	YURIY ANTONOV	{"email": "antonov.y.04021967@postgrespro.ru", "phone": "+70015617152"}
0005434727810	910859	1156 543574	ANTONINA KOROLEVA	{"email": "antoninakoroleva_07041964@postgrespro.ru", "phone": "+70902806433"}
0005434727811	65C890	3555 576806	MIKHAIL EGOROV	{"email": "egorov-mikhail.1984@postgrespro.ru", "phone": "+70394493193"}
0005434727812	65C890	0592 748555	ANNA VOLKOVA	{"phone": "+70634341710"}
0005434727813	E3ACEF	9595 462398	YURIY FROLOV	{"email": "frolov-yuriy_1976@postgrespro.ru", "phone": "+70471794027"}
0005434727814	E3ACEF	5940 394144	SERGEY TIMOFEEV	{"phone": "+70111193753"}
0005434727815	8B1520	1531 760528	NADEZHDA VOLKOVA	{"phone": "+70069138613"}
0005434727816	C0678E	5618 256288	VLADIMIR MOROZOV	{"phone": "+70184970192"}
0005434727817	C0678E	2859 321323	ALEKSANDR POPOV	{"phone": "+70296195634"}
0005434727818	2ED198	0339 766161	DMITRIY GAVRILOV	{"email": "gavrilov.dmitriy.26111974@postgrespro.ru", "phone": "+70520231349"}
0005434727819	F70E9F	4873 716170	RAUZA BOGDANOVA	{"phone": "+70818520676"}
0005434727820	F28968	4286 912133	SVETLANA ABRAMOVA	{"phone": "+70144045495"}
0005434727821	C9FE8A	6730 436034	SVETLANA MOISEEVA	{"email": "moiseeva-s071978@postgrespro.ru", "phone": "+70654902597"}
0005434727822	F2F8A3	2728 590996	VERA ALEKSANDROVA	{"email": "aleksandrova_vera14031961@postgrespro.ru", "phone": "+70157015014"}
0005434727823	552BA8	9150 966970	ELENA GORBUNOVA	{"email": "e.gorbunova121984@postgrespro.ru", "phone": "+70295418856"}
0005434727824	552BA8	0018 529394	VIKTORIYA TIKHONOVA	{"phone": "+70144806650"}
0005434727825	42ADC6	0395 255648	YULIYA TIMOFEEVA	{"phone": "+70834737889"}
0005434727826	A89A3B	1760 802542	ANDREY VASILEV	{"email": "a-vasilev_041974@postgrespro.ru", "phone": "+70400122905"}
0005434728132	322452	6176 714072	NADEZHDA MIKHAYLOVA	{"phone": "+70287049861"}
0005434727827	A89C13	2133 938066	NIKOLAY ANDREEV	{"email": "andreev.n.1972@postgrespro.ru", "phone": "+70894711406"}
0005434727828	2D8182	9938 625372	ARKADIY VOROBEV	{"phone": "+70662372143"}
0005434727829	08557B	9613 694755	SERGEY SCHERBAKOV	{"phone": "+70225605272"}
0005434727830	C1F5D3	0672 590231	IVAN KULIKOV	{"email": "ivan.kulikov111971@postgrespro.ru", "phone": "+70474977832"}
0005434727831	E46DB6	4296 452189	ALEKSEY BONDARENKO	{"email": "aleksey-bondarenko-021972@postgrespro.ru", "phone": "+70861786791"}
0005434727832	E46DB6	2698 178451	LEONID SEMENOV	{"phone": "+70115599760"}
0005434727833	EFF3BD	0535 739262	OLGA FOMINA	{"phone": "+70626514433"}
0005434727834	12016B	1152 018899	VITALIY BORISOV	{"email": "borisovvitaliy1964@postgrespro.ru", "phone": "+70647919633"}
0005434727835	9221A5	8510 671046	ELENA KISELEVA	{"phone": "+70275876196"}
0005434727836	9221A5	2041 576146	OKSANA NIKIFOROVA	{"phone": "+70604789053"}
0005434727837	D06DF7	0543 843814	ALEKSANDR VOROBEV	{"phone": "+70624493213"}
0005434727838	DFED78	0188 563625	ANDREY TIKHONOV	{"email": "tikhonov-andrey-23021978@postgrespro.ru", "phone": "+70134206301"}
0005434727839	DFED78	4006 294520	DANIL ANTONOV	{"phone": "+70055527995"}
0005434727840	881A63	4027 188405	ANNA AFANASEVA	{"phone": "+70647401602"}
0005434727841	881A63	5307 204572	VLADIMIR PETROV	{"email": "petrov_v-13071969@postgrespro.ru", "phone": "+70340840695"}
0005434727842	80CA0C	3024 353679	NATALYA KUZNECOVA	{"email": "kuznecova.natalya.20101963@postgrespro.ru", "phone": "+70326588186"}
0005434727843	80CA0C	6344 921077	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov_1972@postgrespro.ru", "phone": "+70393229878"}
0005434727844	A37AB9	9325 225151	SERGEY GUSEV	{"email": "sergeygusev_091971@postgrespro.ru", "phone": "+70921407565"}
0005434727845	6EFB88	6205 849630	ROMAN MAKSIMOV	{"email": "maksimovroman_1971@postgrespro.ru", "phone": "+70215755042"}
0005434727846	6EFB88	8383 646260	EKATERINA BORISOVA	{"email": "borisovae-041979@postgrespro.ru", "phone": "+70714009606"}
0005434727847	6EFB88	2643 084414	EVA ROMANOVA	{"phone": "+70462428762"}
0005434727848	2C4F6F	3372 425628	TATYANA ILINA	{"email": "t.ilina_14091965@postgrespro.ru", "phone": "+70984689138"}
0005434727849	2C4F6F	8440 223610	ANASTASIYA NIKOLAEVA	{"phone": "+70535770653"}
0005434727850	DBECD3	1757 677723	LYUBOV MARTYNOVA	{"email": "martynoval.1964@postgrespro.ru", "phone": "+70208099939"}
0005434727851	1488AA	5001 216982	DENIS BARANOV	{"phone": "+70402922161"}
0005434727852	5787F2	6931 674043	DMITRIY SIDOROV	{"phone": "+70994113597"}
0005434727853	5787F2	2191 057269	BOGDAN ABRAMOV	{"phone": "+70795614878"}
0005434727854	5787F2	2269 346383	OLGA NESTEROVA	{"email": "nesterova_o_1980@postgrespro.ru", "phone": "+70228978202"}
0005434727855	5063C7	9131 794284	NATALIYA VASILEVA	{"phone": "+70529020127"}
0005434727856	5063C7	4701 281259	VADIM FROLOV	{"email": "frolov-vadim-03051972@postgrespro.ru", "phone": "+70102765321"}
0005434727857	7C66EC	2604 599648	DMITRIY SMIRNOV	{"phone": "+70372348843"}
0005434727858	156DD3	9297 751555	KARINA POPOVA	{"email": "karina.popova-06101984@postgrespro.ru", "phone": "+70995261044"}
0005434727859	7081FC	6014 746542	PAVEL PAVLOV	{"phone": "+70917250946"}
0005434727860	7081FC	8444 286530	EVGENIY VOLKOV	{"phone": "+70986771511"}
0005434727861	BB6B2A	8906 834488	SVETLANA KALININA	{"email": "s_kalinina-051964@postgrespro.ru", "phone": "+70902534858"}
0005434727862	BB6B2A	9211 185639	GALINA VOROBEVA	{"phone": "+70462261870"}
0005434727863	1E8A52	4811 818149	IGOR EGOROV	{"email": "egorov_igor_1971@postgrespro.ru", "phone": "+70785817065"}
0005434727864	1E8A52	3156 345730	KRISTINA LEBEDEVA	{"email": "klebedeva-1970@postgrespro.ru", "phone": "+70004179604"}
0005434727865	FBD831	1262 296585	TATYANA DENISOVA	{"phone": "+70817776059"}
0005434727866	40F729	7617 453115	TATYANA RYABOVA	{"phone": "+70045268096"}
0005434727867	03A604	6064 607668	KIRILL IVANOV	{"phone": "+70614161411"}
0005434727868	DD0C61	1092 775557	IRINA MIRONOVA	{"email": "i_mironova.061972@postgrespro.ru", "phone": "+70742759105"}
0005434727869	EC1635	4653 839662	EVGENIY ILIN	{"email": "ilin_evgeniy_1959@postgrespro.ru", "phone": "+70853378780"}
0005434727870	EC1635	1585 229397	ALINA VOROBEVA	{"phone": "+70642429460"}
0005434727871	142D27	8956 831987	NINA KRASNOVA	{"phone": "+70997986244"}
0005434727872	142D27	1871 137789	LYUDMILA DENISOVA	{"email": "lyudmila_denisova.121978@postgrespro.ru", "phone": "+70492603006"}
0005434727873	45E09C	5495 143856	VALERIY NIKOLAEV	{"email": "v-nikolaev.051965@postgrespro.ru", "phone": "+70243746418"}
0005434727874	8AF521	7650 664283	GENNADIY VOROBEV	{"phone": "+70385410722"}
0005434727875	5EC753	8293 490344	VALENTIN ALEKSEEV	{"email": "valentinalekseev-1982@postgrespro.ru", "phone": "+70673526193"}
0005434727876	C11F10	1429 040712	VLADIMIR SOLOVEV	{"phone": "+70298340220"}
0005434727877	145232	2629 657915	PETR BARANOV	{"phone": "+70705965529"}
0005434727878	145232	5592 903859	GALINA NIKOLAEVA	{"phone": "+70792116523"}
0005434727879	0B72B0	8550 949919	ARTEM MARTYNOV	{"phone": "+70805369694"}
0005434727880	2B7633	0859 350537	EKATERINA MIRONOVA	{"phone": "+70082047615"}
0005434727881	B726B8	9956 573164	OLGA KOZLOVA	{"phone": "+70016463410"}
0005434727882	B726B8	7968 646337	VALENTIN KONOVALOV	{"email": "valentin.konovalov_1978@postgrespro.ru", "phone": "+70799146954"}
0005434727883	6A89BF	9657 320733	NATALYA NIKOLAEVA	{"phone": "+70125699057"}
0005434727884	DA23D7	9225 388775	VALENTINA PETROVA	{"phone": "+70610824484"}
0005434727885	DA23D7	3820 171239	TATYANA EGOROVA	{"email": "egorova_t.1982@postgrespro.ru", "phone": "+70963538578"}
0005434727886	799C3F	4901 699814	TATYANA TIMOFEEVA	{"phone": "+70637200339"}
0005434727887	799C3F	8871 842800	IGOR MOROZOV	{"email": "morozovigor_08101970@postgrespro.ru", "phone": "+70735029841"}
0005434727888	4CDC69	0797 695134	VLADIMIR GAVRILOV	{"phone": "+70487611356"}
0005434727890	275DC2	8576 265274	ALEKSANDR MOISEEV	{"email": "a_moiseev_1975@postgrespro.ru", "phone": "+70426526070"}
0005434727891	275DC2	1944 530968	GALINA VASILEVA	{"email": "vasilevag.26031974@postgrespro.ru", "phone": "+70078459422"}
0005434727892	76A1A8	2092 018108	INNA SIDOROVA	{"phone": "+70165143551"}
0005434727893	76A1A8	3850 586960	ILYA KOZLOV	{"email": "i.kozlov_1975@postgrespro.ru", "phone": "+70715447741"}
0005434727894	4DB6B5	7206 742363	VIKTOR FROLOV	{"email": "frolovviktor_08081976@postgrespro.ru", "phone": "+70186305398"}
0005434727895	BFE6EB	3661 311896	ANTONINA NIKOLAEVA	{"email": "nikolaeva-antonina-1971@postgrespro.ru", "phone": "+70929338854"}
0005434727896	BFE6EB	8946 198282	SERGEY ABRAMOV	{"email": "sergey-abramov_16061978@postgrespro.ru", "phone": "+70470585454"}
0005434727897	74B4E5	3117 260148	NATALYA KONOVALOVA	{"phone": "+70897408874"}
0005434727898	74B4E5	3124 408897	TATYANA MAKSIMOVA	{"phone": "+70147830793"}
0005434727899	74B4E5	4839 340245	ELIZAVETA IVANOVA	{"email": "elizaveta-ivanova.101978@postgrespro.ru", "phone": "+70899243962"}
0005434727900	C6A595	3041 213654	ILYA ISAEV	{"phone": "+70817893478"}
0005434727901	E3E030	0708 232980	STEPAN SEMENOV	{"phone": "+70774271829"}
0005434727902	EA282F	8783 509424	EVGENIY MELNIKOV	{"email": "melnikove_021968@postgrespro.ru", "phone": "+70101910155"}
0005434727903	805D46	1416 876896	AYRAT KOZLOV	{"email": "a.kozlov.04121976@postgrespro.ru", "phone": "+70367698327"}
0005434727904	E330E5	9945 990864	YURIY CHERNOV	{"email": "yuriy-chernov1975@postgrespro.ru", "phone": "+70773529764"}
0005434727905	D64D24	3627 887232	GALINA DAVYDOVA	{"email": "gdavydova-01021966@postgrespro.ru", "phone": "+70067845265"}
0005434727906	5F9651	0630 272367	OLGA OVCHINNIKOVA	{"email": "o-ovchinnikova.21091970@postgrespro.ru", "phone": "+70738482610"}
0005434727907	3F273F	1115 543113	MARIYA KARPOVA	{"phone": "+70849528368"}
0005434727908	CF1D73	4669 299228	VLADIMIR FEDOROV	{"phone": "+70221519044"}
0005434727909	FE1EC4	8405 143252	NATALYA IVANOVA	{"phone": "+70727904656"}
0005434727910	050B4B	5917 817539	NADEZHDA FOMINA	{"email": "fominanadezhda.1968@postgrespro.ru", "phone": "+70604041886"}
0005434727911	44EA4A	0404 604669	VERONIKA ZHURAVLEVA	{"email": "veronika.zhuravleva_121970@postgrespro.ru", "phone": "+70632353832"}
0005434727912	44EA4A	7845 320627	RAFAIL IVANOV	{"phone": "+70056085583"}
0005434727913	8882A5	6268 043755	VIKTOR NOVIKOV	{"phone": "+70817798854"}
0005434727914	80A159	6407 914723	NATALYA POPOVA	{"email": "popova_natalya_121968@postgrespro.ru", "phone": "+70469183787"}
0005434727915	AB0F84	2320 557251	LYUBOV VASILEVA	{"phone": "+70668758496"}
0005434727916	09086F	4969 598230	ANASTASIYA KAZAKOVA	{"phone": "+70572712031"}
0005434727917	B60856	5705 827043	ULYANA IVANOVA	{"phone": "+70239039978"}
0005434727918	F2164B	6062 060415	ANATOLIY ANDREEV	{"phone": "+70820587246"}
0005434727919	F2164B	3065 390329	VIKTOR PETROV	{"email": "petrovviktor_05061980@postgrespro.ru", "phone": "+70326125639"}
0005434727920	F2164B	4508 573801	ALEVTINA NOVIKOVA	{"phone": "+70517993698"}
0005434727921	F2164B	5724 272509	LYUBOV NESTEROVA	{"email": "lnesterova-12081964@postgrespro.ru", "phone": "+70546052716"}
0005434727922	3D208B	0630 416393	ANTONINA GUSEVA	{"phone": "+70298993928"}
0005434727923	BBF573	1116 606830	ALEKSEY SERGEEV	{"email": "sergeev-a_12111964@postgrespro.ru", "phone": "+70008697814"}
0005434727924	A8379D	6282 952869	SERGEY ILIN	{"email": "sergey-ilin_11081965@postgrespro.ru", "phone": "+70052119699"}
0005434727925	D1782D	3976 908594	MAKSIM SOKOLOV	{"email": "m.sokolov-081972@postgrespro.ru", "phone": "+70920880540"}
0005434727926	D1782D	3439 860485	ANATOLIY TARASOV	{"phone": "+70883275641"}
0005434727927	A8EBFE	5645 849895	ROMAN SIDOROV	{"email": "sidorov_roman041971@postgrespro.ru", "phone": "+70309324222"}
0005434727928	D288D9	5357 616073	OLEG YAKOVLEV	{"phone": "+70777905191"}
0005434727929	D288D9	8900 221127	ANNA BORISOVA	{"email": "annaborisova-071975@postgrespro.ru", "phone": "+70704198543"}
0005434727930	D288D9	7560 247930	ANZHELA KAZAKOVA	{"email": "a_kazakova-03051957@postgrespro.ru", "phone": "+70826026361"}
0005434727931	61325A	2286 559740	SERGEY PAVLOV	{"phone": "+70665592327"}
0005434727932	56A193	9268 391289	ANASTASIYA MAKAROVA	{"phone": "+70976940007"}
0005434727933	9D38BC	4374 248707	ALEKSANDR KUZMIN	{"phone": "+70549035304"}
0005434727934	015C61	4437 595062	ANNA MAKAROVA	{"phone": "+70817426903"}
0005434727935	306C7D	2597 051056	LIDIYA MELNIKOVA	{"email": "l-melnikova_11071976@postgrespro.ru", "phone": "+70122886281"}
0005434727936	D786B1	5457 047009	TATYANA ABRAMOVA	{"email": "abramova-t_19051963@postgrespro.ru", "phone": "+70796638989"}
0005434727937	B47F85	3045 443460	SERGEY MARTYNOV	{"email": "sergey-martynov09011963@postgrespro.ru", "phone": "+70189797575"}
0005434727938	B47F85	3313 133510	ELIZAVETA MEDVEDEVA	{"phone": "+70957143452"}
0005434727939	A8C3FE	5300 733281	IRINA NIKITINA	{"phone": "+70712677093"}
0005434727940	A8C3FE	8340 866976	EVGENIY FEDOTOV	{"email": "evgeniyfedotov.07051968@postgrespro.ru", "phone": "+70111519462"}
0005434727941	CC2BC6	6019 748952	MAKSIM NOVIKOV	{"phone": "+70735537945"}
0005434727942	CC2BC6	2374 817552	NATALYA BARANOVA	{"email": "natalyabaranova-1976@postgrespro.ru", "phone": "+70923163772"}
0005434727943	194A87	1340 960918	MURAT VOLKOV	{"email": "volkov-murat.17081965@postgrespro.ru", "phone": "+70370356131"}
0005434727944	194A87	6833 344367	DMITRIY MIRONOV	{"email": "mironov_d.1957@postgrespro.ru", "phone": "+70105478268"}
0005434727945	FACD25	8523 812667	ANDREY PAVLOV	{"email": "andreypavlov.091972@postgrespro.ru", "phone": "+70679676995"}
0005434727946	FACD25	5255 389385	TATYANA IVANOVA	{"email": "t.ivanova09071970@postgrespro.ru", "phone": "+70700760900"}
0005434727947	0D0FA5	7589 784751	ANATOLIY OSIPOV	{"phone": "+70444516770"}
0005434727948	8E130A	8099 941943	ALEKSANDRA MAKAROVA	{"email": "makarova-a-051965@postgrespro.ru", "phone": "+70911531864"}
0005434727949	7FFE5F	8512 545819	OLEG STEPANOV	{"email": "stepanovoleg-15051971@postgrespro.ru", "phone": "+70871012281"}
0005434727950	D46167	1686 957122	OLGA TITOVA	{"phone": "+70147779067"}
0005434727951	C2712F	5098 436057	KLAVDIYA EGOROVA	{"phone": "+70736184862"}
0005434727952	C2712F	2791 628391	EVGENIY KONOVALOV	{"phone": "+70854856922"}
0005434727953	9ADC62	7248 245971	EKATERINA LEBEDEVA	{"phone": "+70992076041"}
0005434727954	9ADC62	7342 072766	NINA ZAYCEVA	{"email": "ninazayceva_1970@postgrespro.ru", "phone": "+70754208382"}
0005434727955	A02CE6	3611 351816	LYUBOV MATVEEVA	{"phone": "+70300603644"}
0005434727956	A51A42	6683 669738	VYACHESLAV MIKHAYLOV	{"email": "v_mikhaylov.041976@postgrespro.ru", "phone": "+70341543207"}
0005434727957	EC804D	4456 679772	GALINA VOROBEVA	{"email": "vorobeva.galina_021963@postgrespro.ru", "phone": "+70319418200"}
0005434727958	EC804D	1436 695435	OLEG KOROLEV	{"email": "korolev_oleg101964@postgrespro.ru", "phone": "+70193843545"}
0005434727959	800D94	2955 851726	ALEKSANDR KRASNOV	{"phone": "+70592165460"}
0005434727960	800D94	1038 849260	FARIDA PETROVA	{"email": "f.petrova1967@postgrespro.ru", "phone": "+70461763313"}
0005434727961	56FBAB	1809 816253	VALERIY KONOVALOV	{"phone": "+70512870927"}
0005434727962	56FBAB	2989 270790	DENIS KOROLEV	{"email": "denis_korolev051968@postgrespro.ru", "phone": "+70143640263"}
0005434727963	2A15A7	3165 182757	SOFIYA NIKIFOROVA	{"email": "s_nikiforova-061962@postgrespro.ru", "phone": "+70528391989"}
0005434727964	2A15A7	7762 081025	RUSLAN ANTONOV	{"phone": "+70782581276"}
0005434727965	E1E426	7118 186208	SVETLANA SOKOLOVA	{"email": "sokolovasvetlana_101976@postgrespro.ru", "phone": "+70845890099"}
0005434727966	5A3A66	5509 729380	NIKITA DMITRIEV	{"email": "dmitrievnikita111971@postgrespro.ru", "phone": "+70105816251"}
0005434727967	5A3A66	7824 848853	YURIY MIKHAYLOV	{"phone": "+70191941811"}
0005434727968	06CC2E	2434 054144	YULIYA LOGINOVA	{"email": "loginova-yuliya-071974@postgrespro.ru", "phone": "+70659767501"}
0005434727969	06CC2E	2779 297910	NIKITA EGOROV	{"phone": "+70708115872"}
0005434727970	06CC2E	9594 239378	IVAN ROMANOV	{"phone": "+70194314441"}
0005434727971	02B828	1489 300903	VALENTINA EGOROVA	{"phone": "+70823149858"}
0005434727972	02B828	2556 646319	SERGEY KUZNECOV	{"email": "kuznecov_s-1978@postgrespro.ru", "phone": "+70631367142"}
0005434727973	D676D4	8218 731451	EVGENIY PAVLOV	{"email": "pavlove-02021966@postgrespro.ru", "phone": "+70426874813"}
0005434727974	4AAEB5	8564 329510	RAISA KUZMINA	{"email": "kuzmina_raisa_11091961@postgrespro.ru", "phone": "+70078349772"}
0005434727975	4AAEB5	1833 069826	GALINA ANTONOVA	{"email": "antonova_galina.051980@postgrespro.ru", "phone": "+70240513552"}
0005434727976	AFE79D	7713 954032	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya061977@postgrespro.ru", "phone": "+70093923046"}
0005434727977	A8609A	6039 540758	ANATOLIY NOVIKOV	{"phone": "+70356531421"}
0005434727978	A8609A	2640 336451	VALENTINA NAZAROVA	{"phone": "+70959311158"}
0005434727979	AE9E34	8074 750920	ALEKSANDR TARASOV	{"email": "tarasov.a091969@postgrespro.ru", "phone": "+70362242802"}
0005434727980	AE9E34	6368 935872	EVGENIY CHERNOV	{"email": "chernov.evgeniy111974@postgrespro.ru", "phone": "+70499306124"}
0005434727981	876F8E	8225 860448	YURIY MIKHAYLOV	{"email": "mikhaylov.y-1976@postgrespro.ru", "phone": "+70058456260"}
0005434727982	876F8E	0863 212740	RAISA TIMOFEEVA	{"phone": "+70576924066"}
0005434727983	841A03	4277 418718	OLEG EGOROV	{"email": "o-egorov.111971@postgrespro.ru", "phone": "+70751765452"}
0005434727984	F7FEC1	4174 168386	IVAN PAVLOV	{"email": "ipavlov-05071968@postgrespro.ru", "phone": "+70078373360"}
0005434727985	E13EF7	9183 560886	ELENA MOROZOVA	{"email": "elena-morozova091967@postgrespro.ru", "phone": "+70136329130"}
0005434727986	91A1FA	4290 792093	VLADIMIR MIKHAYLOV	{"phone": "+70378380674"}
0005434727987	021B9E	4301 039563	ILYA FEDOTOV	{"phone": "+70705492315"}
0005434727988	A54765	3205 636323	SOFYA MOROZOVA	{"email": "morozova-sofya_04031977@postgrespro.ru", "phone": "+70116670662"}
0005434727989	450D2D	8571 854117	TATYANA MIRONOVA	{"email": "tatyana_mironova_1973@postgrespro.ru", "phone": "+70104151710"}
0005434727990	93DD56	2413 828043	NIKOLAY ROMANOV	{"email": "nikolay-romanov_19021973@postgrespro.ru", "phone": "+70507599125"}
0005434727991	F982C9	2015 414118	ZOYA SAVELEVA	{"email": "zoya.saveleva_1975@postgrespro.ru", "phone": "+70809581038"}
0005434727992	E721E0	4742 960131	NIKITA STEPANOV	{"email": "stepanovn031971@postgrespro.ru", "phone": "+70564519952"}
0005434727993	1EAF63	6357 788364	EVGENIYA NIKITINA	{"phone": "+70589980467"}
0005434727994	D2DF88	0550 944532	DMITRIY POPOV	{"email": "dmitriy-popov-22031970@postgrespro.ru", "phone": "+70142643784"}
0005434727995	D2DF88	7782 551452	VALENTINA BARANOVA	{"phone": "+70315299278"}
0005434727996	3E23C7	4783 115616	LEONID KUZNECOV	{"phone": "+70135675731"}
0005434727997	4A20AF	7091 862011	NINA BARANOVA	{"phone": "+70931510125"}
0005434727998	792E98	4892 540250	VIKTOR IVANOV	{"email": "v.ivanov111967@postgrespro.ru", "phone": "+70768066340"}
0005434727999	E4B21E	8967 344738	LIDIYA SMIRNOVA	{"email": "smirnova.l-071969@postgrespro.ru", "phone": "+70632461964"}
0005434728000	79C7FF	0820 677983	VLADIMIR BARANOV	{"phone": "+70189983151"}
0005434728001	934418	9405 586492	ALEKSANDR MOISEEV	{"phone": "+70242339902"}
0005434728002	A9E603	9494 765947	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_a041973@postgrespro.ru", "phone": "+70974930102"}
0005434728003	ECE49C	2102 463481	NIKOLAY POPOV	{"email": "nikolay-popov041966@postgrespro.ru", "phone": "+70853330388"}
0005434728004	DB3094	7986 475925	MARIYA GERASIMOVA	{"email": "gerasimova-mariya1961@postgrespro.ru", "phone": "+70525565918"}
0005434728005	DB3094	8589 448430	NINA NAZAROVA	{"email": "nazarovan031975@postgrespro.ru", "phone": "+70233238679"}
0005434728006	9D878A	7660 359641	EVGENIYA MOISEEVA	{"phone": "+70567114613"}
0005434728007	B756C7	4223 171046	NIKITA KUZNECOV	{"phone": "+70645365149"}
0005434728009	D73940	9985 894232	VLADIMIR FROLOV	{"email": "vfrolov20011977@postgrespro.ru", "phone": "+70705512984"}
0005434728010	CE1EC9	3576 433443	RAISA AFANASEVA	{"phone": "+70219394695"}
0005434728011	747249	2595 304912	ANNA NESTEROVA	{"email": "nesterova_anna_08051970@postgrespro.ru", "phone": "+70300874448"}
0005434728012	747249	8433 628376	EKATERINA MIKHAYLOVA	{"email": "mikhaylova_ekaterina091968@postgrespro.ru", "phone": "+70309293146"}
0005434728013	747249	3693 025066	OLESYA ARKHIPOVA	{"phone": "+70153733494"}
0005434728014	550EB2	3920 945539	TAMARA YAKOVLEVA	{"phone": "+70808817470"}
0005434728015	2F6164	8606 017462	ELENA VASILEVA	{"email": "vasileva.elena_28091976@postgrespro.ru", "phone": "+70446683468"}
0005434728016	2F6164	1053 877249	OLESYA SERGEEVA	{"email": "olesya_sergeeva.051980@postgrespro.ru", "phone": "+70704941092"}
0005434728017	CE7711	6063 605741	OLEG KUZNECOV	{"phone": "+70747876067"}
0005434728018	721E51	1296 254707	NIKITA SOROKIN	{"email": "nikita_sorokin_25031975@postgrespro.ru", "phone": "+70819532391"}
0005434728019	721E51	3861 510390	KONSTANTIN SOLOVEV	{"phone": "+70570138253"}
0005434728020	2E612D	8569 882864	TATYANA MIKHAYLOVA	{"phone": "+70387335216"}
0005434728021	D273D5	6896 609894	SERGEY EGOROV	{"phone": "+70764366845"}
0005434728022	90B6F2	2862 211969	ALEKSEY ABRAMOV	{"phone": "+70822915118"}
0005434728023	90B6F2	6770 649694	LYUDMILA KOZLOVA	{"phone": "+70094228262"}
0005434728024	DC5040	8352 324275	EKATERINA KARPOVA	{"phone": "+70541777229"}
0005434728025	75FE71	1448 189486	OKSANA POPOVA	{"phone": "+70385228674"}
0005434728026	75FE71	0968 449051	ALEKSANDR SMIRNOV	{"phone": "+70779933939"}
0005434728027	3ED7E5	8043 159641	NADEZHDA NOVIKOVA	{"phone": "+70329852276"}
0005434728028	3ED7E5	8834 494201	TAMARA KOROLEVA	{"phone": "+70346649956"}
0005434728029	422F52	9133 733505	IVAN POPOV	{"phone": "+70632013097"}
0005434728030	422F52	4877 220054	NIKOLAY SOROKIN	{"phone": "+70419798806"}
0005434728031	A64611	3438 507507	ANTONINA NIKITINA	{"phone": "+70625632394"}
0005434728032	E1AB28	4721 594393	ANDREY POPOV	{"phone": "+70532399508"}
0005434728033	E4B41E	5104 595825	NIKOLAY GAVRILOV	{"phone": "+70380660601"}
0005434728034	E4B41E	2987 447847	GALINA LEBEDEVA	{"phone": "+70286009901"}
0005434728035	531A6B	8162 467758	SERGEY KUZMIN	{"phone": "+70378477564"}
0005434728036	9097AB	0302 767959	VLADISLAV DENISOV	{"email": "denisov.vladislav.021975@postgrespro.ru", "phone": "+70026812225"}
0005434728037	B3D431	2220 613244	RAMIL KUDRYASHOV	{"email": "kudryashov-r_1971@postgrespro.ru", "phone": "+70836268561"}
0005434728038	9795BC	5027 969021	EVGENIY ZAKHAROV	{"phone": "+70935659135"}
0005434728039	FD4BDE	2687 925519	NATALYA MELNIKOVA	{"email": "natalya-melnikova091975@postgrespro.ru", "phone": "+70338349700"}
0005434728040	F3F43F	7849 315762	DARYA KUDRYASHOVA	{"phone": "+70818347011"}
0005434728041	54667A	3818 467811	VALENTIN AFANASEV	{"email": "afanasev-valentin121965@postgrespro.ru", "phone": "+70274278205"}
0005434728042	54667A	0364 470926	YULIYA KARPOVA	{"email": "karpovay.14101962@postgrespro.ru", "phone": "+70635269428"}
0005434728043	64D0D5	1582 338904	NINA LEBEDEVA	{"phone": "+70536596585"}
0005434728044	64D0D5	4214 439829	SERGEY NOVIKOV	{"phone": "+70058479432"}
0005434728045	64D0D5	3954 998022	NIKOLAY NOVIKOV	{"phone": "+70070350722"}
0005434728046	9A3AD4	1410 842441	DARYA DAVYDOVA	{"phone": "+70687935142"}
0005434728047	8D1072	9527 166569	VALENTINA YAKOVLEVA	{"email": "vyakovleva.1976@postgrespro.ru", "phone": "+70921762374"}
0005434728048	B3DD5B	3386 208586	ANZHELA SERGEEVA	{"phone": "+70415189870"}
0005434728049	B3DD5B	2945 473169	ANASTASIYA DENISOVA	{"phone": "+70964745555"}
0005434728050	5FC874	0306 514982	VYACHESLAV BELOV	{"phone": "+70507989361"}
0005434728051	934DEF	7840 743398	VLADISLAV ROMANOV	{"phone": "+70085148691"}
0005434728052	305E69	6765 967520	IRINA BARANOVA	{"email": "baranova.i_19091970@postgrespro.ru", "phone": "+70569593963"}
0005434728053	305E69	7501 641860	SERGEY MIKHAYLOV	{"email": "sergey-mikhaylov1976@postgrespro.ru", "phone": "+70073839448"}
0005434728054	88F07A	8590 591764	SERGEY POPOV	{"email": "popov-sergey24091966@postgrespro.ru", "phone": "+70914306247"}
0005434728055	753264	7815 179443	VIKTOR DMITRIEV	{"phone": "+70425965883"}
0005434728056	6154E1	8496 144090	IVAN FEDOROV	{"email": "fedorovi-011967@postgrespro.ru", "phone": "+70431878001"}
0005434728057	BA130D	3002 843569	DMITRIY KOZLOV	{"phone": "+70444364209"}
0005434728058	AB6D02	5312 571406	EVGENIY RODIONOV	{"email": "evgeniy-rodionov1975@postgrespro.ru", "phone": "+70381650970"}
0005434728059	6C7497	6266 764364	VLADIMIR MATVEEV	{"email": "vladimir_matveev26091978@postgrespro.ru", "phone": "+70325787216"}
0005434728060	E03184	0171 405290	RUZALIYA ILINA	{"phone": "+70395413435"}
0005434728061	E03184	8120 068031	VLADIMIR ALEKSEEV	{"phone": "+70337293402"}
0005434728062	F14085	7903 760431	GALINA GRISHINA	{"email": "g_grishina_1962@postgrespro.ru", "phone": "+70980895063"}
0005434728063	384D6E	6561 390997	SVETLANA MIRONOVA	{"phone": "+70433495534"}
0005434728064	6BB600	6220 352353	MAKSIM KUDRYASHOV	{"phone": "+70194559668"}
0005434728121	65E7B8	1784 653232	PAVEL SCHERBAKOV	{"phone": "+70992883608"}
0005434728065	6BB600	2992 554199	ELENA ALEKSEEVA	{"email": "alekseeva.e021979@postgrespro.ru", "phone": "+70871432056"}
0005434728066	3705AA	7318 131900	ALEKSANDR VOLKOV	{"phone": "+70338125953"}
0005434728067	A67D32	8190 260479	MAKSIM SMIRNOV	{"phone": "+70050681031"}
0005434728068	0181D0	4644 488931	VALENTINA ROMANOVA	{"phone": "+70941073776"}
0005434728069	112340	7568 348683	ANTONINA NOVIKOVA	{"email": "antonina.novikova-1973@postgrespro.ru", "phone": "+70189523604"}
0005434728070	C2DF32	6160 812320	VALENTIN ZHURAVLEV	{"phone": "+70835722373"}
0005434728071	C2DF32	9076 170790	ANTON SERGEEV	{"email": "anton.sergeev-1966@postgrespro.ru", "phone": "+70489245449"}
0005434728072	C2DF32	9093 290435	ANDREY KARPOV	{"email": "karpov.andrey_1965@postgrespro.ru", "phone": "+70717128233"}
0005434728073	0DEA52	2187 184150	ALEKSANDRA YUDINA	{"email": "a-yudina.12011968@postgrespro.ru", "phone": "+70171685958"}
0005434728074	592977	4596 608306	VLADIMIR NIKOLAEV	{"phone": "+70694644309"}
0005434728075	592977	9267 639667	VALERIYA KOROLEVA	{"phone": "+70388194518"}
0005434728076	26FF23	3855 234312	VERA NOVIKOVA	{"email": "novikova_vera_1957@postgrespro.ru", "phone": "+70942388773"}
0005434728077	637864	6590 861186	MARINA DENISOVA	{"email": "denisovam-101968@postgrespro.ru", "phone": "+70496390770"}
0005434728078	319C06	3396 968033	YURIY RODIONOV	{"email": "yrodionov.031978@postgrespro.ru", "phone": "+70584344325"}
0005434728079	2C210E	4001 762093	DENIS SEMENOV	{"phone": "+70107577005"}
0005434728080	2C210E	6075 125307	TAISIYA SEMENOVA	{"email": "semenova_taisiya.011970@postgrespro.ru", "phone": "+70165713900"}
0005434728081	A346CD	0185 560093	SVETLANA SOKOLOVA	{"phone": "+70997803568"}
0005434728082	A346CD	6931 465379	ANASTASIYA SOKOLOVA	{"email": "sokolova_a25031967@postgrespro.ru", "phone": "+70668228255"}
0005434728083	C7F8F6	2081 250392	NIKOLAY FOMIN	{"email": "fomin-n-1971@postgrespro.ru", "phone": "+70694422437"}
0005434728084	7CA704	4526 862763	EVGENIY FROLOV	{"email": "e-frolov061976@postgrespro.ru", "phone": "+70053241245"}
0005434728085	75D301	2981 838192	IVAN VLASOV	{"email": "i-vlasov-03091970@postgrespro.ru", "phone": "+70496994343"}
0005434728086	CA7B64	1778 333116	RAMIL KULIKOV	{"phone": "+70175019336"}
0005434728087	CA7B64	1558 022298	ANNA KOMAROVA	{"email": "komarova-a051976@postgrespro.ru", "phone": "+70434480705"}
0005434728088	0A8C21	4542 370992	ELENA MARTYNOVA	{"email": "martynovae-18031967@postgrespro.ru", "phone": "+70512964510"}
0005434728089	0891F4	9169 130919	ANATOLIY MELNIKOV	{"phone": "+70978405131"}
0005434728090	CCB661	6568 947201	LYUBOV TROFIMOVA	{"phone": "+70743160819"}
0005434728091	4EA3F8	3843 680507	VERA EGOROVA	{"phone": "+70830701070"}
0005434728092	8B5F51	1482 753610	LARISA KOROLEVA	{"email": "l-koroleva.1948@postgrespro.ru", "phone": "+70330912821"}
0005434728093	8B5F51	3284 630144	GALINA ANTONOVA	{"email": "antonova-galina.111973@postgrespro.ru", "phone": "+70564637643"}
0005434728094	3EF7BB	6414 176276	IVAN PETROV	{"phone": "+70705809360"}
0005434728095	3EF7BB	1943 405068	SERGEY SERGEEV	{"email": "sergeev_s1979@postgrespro.ru", "phone": "+70900689676"}
0005434728096	3BEEC0	5203 724941	EVGENIY IVANOV	{"phone": "+70116007235"}
0005434728097	B500AD	9982 598073	DANIL NIKITIN	{"phone": "+70694467003"}
0005434728098	B500AD	6460 213580	VALENTINA PETROVA	{"phone": "+70954148116"}
0005434728099	481099	2515 032291	EGOR STEPANOV	{"email": "stepanov_e051964@postgrespro.ru", "phone": "+70512393500"}
0005434728100	304729	3087 614678	EVGENIYA SIDOROVA	{"phone": "+70705185490"}
0005434728101	2D12DE	7727 457470	NIKOLAY STEPANOV	{"email": "stepanov-nikolay25111977@postgrespro.ru", "phone": "+70801877918"}
0005434728102	2B1399	7922 899011	EKATERINA SOKOLOVA	{"phone": "+70346842290"}
0005434728103	8EE2BC	5758 910946	NATALYA POPOVA	{"email": "natalya_popova-19071966@postgrespro.ru", "phone": "+70264703171"}
0005434728104	00C097	0303 395744	MIKHAIL MIRONOV	{"email": "mironov_mikhail041979@postgrespro.ru", "phone": "+70033306436"}
0005434728105	E23FBC	9865 356680	ALEKSANDR SIDOROV	{"phone": "+70781535847"}
0005434728106	694E61	7791 116348	ALEKSANDR ROMANOV	{"phone": "+70444413925"}
0005434728107	694E61	2285 934925	YAKOV PAVLOV	{"email": "yakov_pavlov-1971@postgrespro.ru", "phone": "+70295343513"}
0005434728108	D24501	7252 625982	EVGENIY ANDREEV	{"phone": "+70042834344"}
0005434728109	4D7B75	7296 548994	ILDAR NOVIKOV	{"email": "novikovi.29101959@postgrespro.ru", "phone": "+70992549231"}
0005434728110	4D7B75	6673 048774	ANDREY GERASIMOV	{"phone": "+70120320004"}
0005434728111	43962A	1221 422020	EGOR VOLKOV	{"phone": "+70572865803"}
0005434728112	CCD430	8117 690746	ANATOLIY IVANOV	{"email": "anatoliy-ivanov_091982@postgrespro.ru", "phone": "+70879405770"}
0005434728113	E5ED19	4170 946177	VYACHESLAV ILIN	{"email": "ilinvyacheslav-1973@postgrespro.ru", "phone": "+70096973377"}
0005434728114	E5ED19	2752 148246	ASIYA ABRAMOVA	{"email": "asiyaabramova.021972@postgrespro.ru", "phone": "+70338945473"}
0005434728115	E5ED19	0482 907607	LYUDMILA KOROLEVA	{"phone": "+70496406273"}
0005434728116	BDAD39	2284 424397	TATYANA ORLOVA	{"email": "orlovat1958@postgrespro.ru", "phone": "+70054052163"}
0005434728117	1ACEB3	2802 698324	IVAN GRIGOREV	{"email": "ivan_grigorev.1964@postgrespro.ru", "phone": "+70534449337"}
0005434728118	3600F7	8104 347508	MIKHAIL TARASOV	{"email": "mikhail_tarasov1962@postgrespro.ru", "phone": "+70916644954"}
0005434728119	437CFA	3587 441229	VALERIYA SERGEEVA	{"phone": "+70453973159"}
0005434728120	57F74A	6178 766941	NIKOLAY GORBUNOV	{"email": "nikolay-gorbunov_1974@postgrespro.ru", "phone": "+70257823525"}
0005434728122	65E7B8	2037 541969	MARIYA MELNIKOVA	{"phone": "+70253120819"}
0005434728123	65E7B8	9780 052001	VIKTORIYA KOLESNIKOVA	{"email": "viktoriya.kolesnikova-121963@postgrespro.ru", "phone": "+70010873979"}
0005434728124	65E7B8	8878 246849	GALINA VASILEVA	{"email": "vasileva.g_1981@postgrespro.ru", "phone": "+70061898178"}
0005434728125	CD592E	9292 343078	RAUZA ZAKHAROVA	{"email": "rzakharova.07051975@postgrespro.ru", "phone": "+70360208187"}
0005434728126	41FC52	5062 534755	BOGDAN KONOVALOV	{"phone": "+70749229992"}
0005434728127	795D06	6136 335357	IRINA RODIONOVA	{"phone": "+70315007787"}
0005434728128	795D06	1039 995207	NIKOLAY VOROBEV	{"email": "n-vorobev_27071978@postgrespro.ru", "phone": "+70056000694"}
0005434728129	D47F15	1159 774278	LEONID KARPOV	{"phone": "+70461095532"}
0005434728130	B4C52C	8323 256376	TATYANA GORBUNOVA	{"phone": "+70699348906"}
0005434728131	3E9C58	8560 752244	ELIZAVETA MATVEEVA	{"email": "elizaveta-matveeva_051971@postgrespro.ru", "phone": "+70954705954"}
0005434728133	28D6DF	7890 285336	PETR FEDOROV	{"phone": "+70973493541"}
0005434728134	79300A	2485 086727	TAMARA MEDVEDEVA	{"email": "t.medvedeva-05071974@postgrespro.ru", "phone": "+70523771996"}
0005434728135	79300A	4268 959533	YAROSLAV PETROV	{"email": "petrov-yaroslav-1975@postgrespro.ru", "phone": "+70296207489"}
0005434728136	7BFC3C	5697 857236	VALENTINA MAKAROVA	{"phone": "+70102917088"}
0005434728137	7BFC3C	2403 242234	DMITRIY KUZNECOV	{"email": "d.kuznecov-18071979@postgrespro.ru", "phone": "+70624929784"}
0005434728138	D1CF9A	8266 027700	DANIYA SCHERBAKOVA	{"phone": "+70173112239"}
0005434728139	5689E1	2563 830998	SERGEY MARTYNOV	{"email": "martynovs.1959@postgrespro.ru", "phone": "+70583784241"}
0005434728140	5689E1	0253 660611	ALEKSANDR BORISOV	{"email": "aleksandrborisov071965@postgrespro.ru", "phone": "+70592043953"}
0005434728141	151F8F	6457 205756	ALEKSANDR ABRAMOV	{"email": "a.abramov1970@postgrespro.ru", "phone": "+70945051611"}
0005434728142	CFF63F	7889 163468	ELENA KUZNECOVA	{"phone": "+70621698383"}
0005434728143	BBFA09	5341 573788	ANDREY TIMOFEEV	{"email": "andrey_timofeev_051974@postgrespro.ru", "phone": "+70925304168"}
0005434728144	3A3DF1	2132 586514	SERGEY POPOV	{"phone": "+70187127352"}
0005434728145	75AAF5	4909 709641	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-24081962@postgrespro.ru", "phone": "+70046077769"}
0005434728146	AA90DA	1879 433803	SERGEY IVANOV	{"email": "sergey.ivanov_1969@postgrespro.ru", "phone": "+70455049432"}
0005434728147	EC6D44	0562 286480	NADEZHDA ILINA	{"email": "nilina.08111966@postgrespro.ru", "phone": "+70794875695"}
0005434728148	C906B2	7783 948435	VLADIMIR GUSEV	{"phone": "+70762273510"}
0005434728149	C906B2	8581 896719	RAISA KISELEVA	{"email": "kiselevaraisa21061964@postgrespro.ru", "phone": "+70478706754"}
0005434728150	8092D8	9921 430313	SERGEY ROMANOV	{"phone": "+70648753430"}
0005434728151	393040	1916 816510	GLEB SHEVCHENKO	{"phone": "+70531776713"}
0005434728152	35F158	8849 356681	ANASTASIYA LAZAREVA	{"email": "anastasiya-lazareva.1965@postgrespro.ru", "phone": "+70557262219"}
0005434728153	B50D19	1238 748676	ALEKSEY ZAYCEV	{"phone": "+70570547768"}
0005434728154	B50D19	3139 295445	LARISA KRASNOVA	{"email": "larisa.krasnova17011977@postgrespro.ru", "phone": "+70939536138"}
0005434728155	B50D19	3694 816240	ANDREY EGOROV	{"phone": "+70761715155"}
0005434728156	895CDC	0979 900978	OKSANA VASILEVA	{"phone": "+70476255537"}
0005434728157	895CDC	2193 331972	STANISLAV DMITRIEV	{"phone": "+70508342546"}
0005434728158	F8301F	9717 282864	EVGENIYA SEMENOVA	{"email": "semenova_e_12091977@postgrespro.ru", "phone": "+70919478448"}
0005434728159	A55525	0906 697190	NATALYA VASILEVA	{"phone": "+70838466870"}
0005434728160	3E5339	7482 734036	ALEKSEY ALEKSEEV	{"email": "alekseeva1961@postgrespro.ru", "phone": "+70610432085"}
0005434728161	3E5339	2646 251971	NATALYA VLASOVA	{"phone": "+70974655530"}
0005434728162	E629CD	9897 823616	LARISA KOZLOVA	{"phone": "+70047144439"}
0005434728163	8B9148	8241 867406	ALEKSANDRA NESTEROVA	{"email": "aleksandra_nesterova-1966@postgrespro.ru", "phone": "+70688215539"}
0005434728164	C75F1A	4060 410899	SVETLANA GAVRILOVA	{"phone": "+70308240110"}
0005434728165	C75F1A	9804 902209	EVGENIYA BORISOVA	{"email": "evgeniya-borisova.1967@postgrespro.ru", "phone": "+70726470824"}
0005434728166	C52650	3751 947928	ANDREY KUZMIN	{"phone": "+70636333591"}
0005434728167	89458D	2104 436257	SERGEY FEDOTOV	{"phone": "+70720899347"}
0005434728168	89458D	3623 924881	ILYA AFANASEV	{"phone": "+70443990571"}
0005434728169	CEB02F	0707 573247	MARINA FILATOVA	{"email": "filatova_m.1977@postgrespro.ru", "phone": "+70637016465"}
0005434728170	A8E014	5531 351114	ANATOLIY VLASOV	{"email": "vlasov_anatoliy-18081969@postgrespro.ru", "phone": "+70632467839"}
0005434728171	70CB8D	7973 405121	DARYA AKIMOVA	{"email": "dakimova.081969@postgrespro.ru", "phone": "+70338923262"}
0005434728172	70CB8D	6679 191026	ALEKSANDR ANTONOV	{"email": "aleksandrantonov091969@postgrespro.ru", "phone": "+70635659877"}
0005434728173	65625B	2030 310568	VALERIY PAVLOV	{"phone": "+70452131649"}
0005434728174	65625B	7332 540998	PETR PAVLOV	{"phone": "+70433444907"}
0005434728175	54D5FB	1520 232633	ELENA ROMANOVA	{"email": "romanova-elena.01101970@postgrespro.ru", "phone": "+70275216823"}
0005434728176	54D5FB	0903 866093	VALENTIN VASILEV	{"phone": "+70106262947"}
0005434728177	B7D698	3295 836049	GALINA ZAKHAROVA	{"phone": "+70430853931"}
0005434728178	B7D698	9973 780616	TATYANA NIKITINA	{"email": "tatyana_nikitina_1975@postgrespro.ru", "phone": "+70338680509"}
0005434728179	4D6413	9967 645503	YURIY KAZAKOV	{"phone": "+70806054317"}
0005434728180	4D6413	8483 431111	ANNA PAVLOVA	{"email": "a_pavlova.031962@postgrespro.ru", "phone": "+70653831791"}
0005434728181	6333AA	5323 575816	MARIYA BELOVA	{"phone": "+70932107948"}
0005434728182	6333AA	7218 419973	IRINA SIDOROVA	{"phone": "+70101902388"}
0005434728183	2E4335	4732 858937	ANASTASIYA ANTONOVA	{"email": "anastasiya_antonova.13011972@postgrespro.ru", "phone": "+70437893946"}
0005434728184	D31411	2682 168050	VLADIMIR VOLKOV	{"email": "v.volkov30091966@postgrespro.ru", "phone": "+70043787853"}
0005434728185	D31411	3179 840002	DENIS BELOV	{"email": "belovd.1977@postgrespro.ru", "phone": "+70327340464"}
0005434728186	3A196A	9040 949976	ALEKSANDR ANDREEV	{"email": "andreev-a_09121962@postgrespro.ru", "phone": "+70911604301"}
0005434728187	7AD1FD	1037 628146	NADEZHDA LEBEDEVA	{"phone": "+70854706773"}
0005434728188	712DF2	0218 675531	EVGENIY KARPOV	{"phone": "+70694326479"}
0005434728249	5C0F2F	7812 143707	MARGARITA BORISOVA	{"phone": "+70060118473"}
0005434728189	F9BC3C	9816 969752	LIDIYA NIKOLAEVA	{"email": "nikolaeva.l.02101967@postgrespro.ru", "phone": "+70084501410"}
0005434728190	C52C31	4375 676728	TAMARA ISAEVA	{"email": "isaeva.t_1988@postgrespro.ru", "phone": "+70130690742"}
0005434728191	C52C31	4962 044327	ZOYA YUDINA	{"phone": "+70061909769"}
0005434728192	8B8D29	9472 263162	VIKTOR MAKSIMOV	{"email": "maksimov.v-1971@postgrespro.ru", "phone": "+70766726102"}
0005434728193	00FB9A	3849 480730	VIKTOR GUSEV	{"email": "v_gusev-24061980@postgrespro.ru", "phone": "+70437463131"}
0005434728194	BB9223	5154 640232	IRINA SCHERBAKOVA	{"email": "i-scherbakova1986@postgrespro.ru", "phone": "+70696085417"}
0005434728195	BB9223	2832 509972	NIKITA EGOROV	{"phone": "+70705872342"}
0005434728196	0AA27E	3875 635024	VLADIMIR VOLKOV	{"phone": "+70387975064"}
0005434728197	C3D087	0651 061420	OLGA MALYSHEVA	{"email": "olga.malysheva.101973@postgrespro.ru", "phone": "+70783231198"}
0005434728198	48F4E4	0447 834212	MIKHAIL SMIRNOV	{"phone": "+70937027711"}
0005434728199	48F4E4	0024 896839	NATALIYA PAVLOVA	{"phone": "+70761544952"}
0005434728200	52CD80	1221 911257	VYACHESLAV STEPANOV	{"email": "v_stepanov1977@postgrespro.ru", "phone": "+70726516122"}
0005434728201	52CD80	9490 520018	NADEZHDA KOZLOVA	{"email": "nadezhda_kozlova.071971@postgrespro.ru", "phone": "+70667168955"}
0005434728202	5A263C	3397 502896	SERGEY KUZMIN	{"email": "sergeykuzmin_1970@postgrespro.ru", "phone": "+70385385440"}
0005434728203	5A263C	5144 530922	NIKITA EGOROV	{"phone": "+70588683396"}
0005434728204	5A263C	2578 802595	VIKTOR NAZAROV	{"phone": "+70112330867"}
0005434728205	77EEC4	6967 684723	OKSANA ORLOVA	{"email": "orlova-oksana_1969@postgrespro.ru", "phone": "+70913785207"}
0005434728206	77EEC4	9995 195067	ANTONINA ANTONOVA	{"email": "antoninaantonova-1970@postgrespro.ru", "phone": "+70749444924"}
0005434728207	1A7D12	0500 037089	SERGEY IVANOV	{"phone": "+70560018245"}
0005434728208	7710E0	9068 606380	VASILIY KUZMIN	{"email": "kuzminv.071969@postgrespro.ru", "phone": "+70116401544"}
0005434728209	7710E0	0724 524613	PAVEL KOZLOV	{"phone": "+70647816138"}
0005434728210	7710E0	2177 513541	RUSLAN ZHURAVLEV	{"email": "zhuravlev.r-01111969@postgrespro.ru", "phone": "+70980201417"}
0005434728211	9D26D0	3416 360248	ALEKSANDR SERGEEV	{"phone": "+70679417907"}
0005434728212	27EA62	6188 322708	EVGENIYA BELOVA	{"phone": "+70662558205"}
0005434728213	B94D90	4480 617494	TATYANA EGOROVA	{"email": "tegorova1979@postgrespro.ru", "phone": "+70688607679"}
0005434728214	D730AD	5594 023103	ARTEM NOVIKOV	{"email": "a.novikov.18061972@postgrespro.ru", "phone": "+70013572665"}
0005434728215	A88520	2731 592709	LYUDMILA KAZAKOVA	{"phone": "+70142514838"}
0005434728216	B79925	4089 528790	NIKOLAY ISAEV	{"phone": "+70974378666"}
0005434728217	13EFE3	8920 173871	LIDIYA NESTEROVA	{"phone": "+70161161962"}
0005434728218	13EFE3	2323 978230	VLADIMIR FROLOV	{"email": "frolovv-09121974@postgrespro.ru", "phone": "+70100305763"}
0005434728219	C0B0AC	0171 958505	VLADIMIR POPOV	{"phone": "+70069651118"}
0005434728220	A703B7	0915 505818	ANTON SCHERBAKOV	{"phone": "+70272750920"}
0005434728221	A703B7	6811 128960	ANDREY KAZAKOV	{"phone": "+70543666009"}
0005434728222	A703B7	3550 580778	NADEZHDA YUDINA	{"email": "n_yudina.081961@postgrespro.ru", "phone": "+70275874742"}
0005434728223	A703B7	5663 825261	RAFAIL BARANOV	{"email": "baranov.rafail_021967@postgrespro.ru", "phone": "+70103108663"}
0005434728224	45E039	6756 341889	ANDREY ORLOV	{"email": "orlovandrey-1968@postgrespro.ru", "phone": "+70129274577"}
0005434728225	243834	7788 038729	VALERIY KUZNECOV	{"email": "v.kuznecov_20091959@postgrespro.ru", "phone": "+70159487276"}
0005434728226	4D3FF2	5498 114733	ALEKSEY GERASIMOV	{"email": "aleksey_gerasimov_12021982@postgrespro.ru", "phone": "+70663723452"}
0005434728227	D2B764	2693 852433	LYUDMILA ZHURAVLEVA	{"phone": "+70983212530"}
0005434728228	E38812	9642 013263	MARINA VASILEVA	{"email": "marina-vasileva1974@postgrespro.ru", "phone": "+70279409010"}
0005434728229	E38812	8926 904801	OLGA CHERNOVA	{"email": "chernovaolga28011981@postgrespro.ru", "phone": "+70638247681"}
0005434728230	AB6423	4344 387061	SERGEY NIKOLAEV	{"phone": "+70370126522"}
0005434728231	8336C8	5559 580941	VALERIY ZAYCEV	{"phone": "+70171883074"}
0005434728232	34967C	8464 379262	ANNA KONOVALOVA	{"phone": "+70585308487"}
0005434728233	34967C	8828 994931	MARINA ANTONOVA	{"email": "antonova.m_1979@postgrespro.ru", "phone": "+70267771126"}
0005434728234	19E967	9912 579016	NATALYA FILIPPOVA	{"email": "n.filippova.23101983@postgrespro.ru", "phone": "+70199329525"}
0005434728235	774D43	4320 139150	EKATERINA MAKSIMOVA	{"email": "maksimova.ekaterina28041966@postgrespro.ru", "phone": "+70133903190"}
0005434728236	5242E9	6249 160879	LEONID KUZMIN	{"phone": "+70162885709"}
0005434728237	4937BF	5506 226179	VYACHESLAV SOLOVEV	{"phone": "+70786625916"}
0005434728238	2CEEA1	0665 093553	YURIY KOROLEV	{"email": "yuriy-korolev_071968@postgrespro.ru", "phone": "+70215660791"}
0005434728239	F05CEE	9110 624014	PAVEL NIKITIN	{"phone": "+70589014630"}
0005434728240	FD3077	4165 503428	VALERIY BONDARENKO	{"email": "bondarenkov_1981@postgrespro.ru", "phone": "+70573044442"}
0005434728241	FD3077	5514 555707	TIMUR VOROBEV	{"email": "timur.vorobev.121975@postgrespro.ru", "phone": "+70006599784"}
0005434728242	EBBF90	4141 682080	ANNA EFIMOVA	{"phone": "+70042530500"}
0005434728243	C0BE81	6856 425359	NIKOLAY ANDREEV	{"phone": "+70262214008"}
0005434728244	C0BE81	1433 104493	VERONIKA KUDRYASHOVA	{"email": "kudryashova_v-1987@postgrespro.ru", "phone": "+70055354465"}
0005434728245	8B8AA5	0527 491464	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova-23041976@postgrespro.ru", "phone": "+70770802577"}
0005434728246	8B8AA5	6241 955118	MIKHAIL BARANOV	{"phone": "+70814973553"}
0005434728247	E23F88	9060 082693	VERA KUZNECOVA	{"email": "kuznecova_v.091972@postgrespro.ru", "phone": "+70786548308"}
0005434728248	38E48E	6384 299231	VERA LAZAREVA	{"email": "lazareva.v.27011974@postgrespro.ru", "phone": "+70219732865"}
0005434728250	623CFD	0713 752976	ALEKSANDR GERASIMOV	{"email": "a-gerasimov.021967@postgrespro.ru", "phone": "+70550936979"}
0005434728251	D8DE42	6891 715005	ELENA VOLKOVA	{"email": "volkovaelena.1964@postgrespro.ru", "phone": "+70300401660"}
0005434728494	F170F6	3072 595706	NADEZHDA MARTYNOVA	{"phone": "+70562527202"}
0005434728252	D0505D	8854 499626	ELENA KOZLOVA	{"email": "kozlova_e-1966@postgrespro.ru", "phone": "+70424349387"}
0005434728253	C7FEDC	7092 177237	DMITRIY SMIRNOV	{"email": "dmitriy_smirnov-011974@postgrespro.ru", "phone": "+70489022586"}
0005434728254	C7FEDC	3811 217640	EVGENIY KUZNECOV	{"phone": "+70339813478"}
0005434728255	0310B2	9090 626975	SVETLANA FILATOVA	{"phone": "+70911346182"}
0005434728256	0310B2	8572 654516	PAVEL MAKSIMOV	{"email": "pavel_maksimov.1964@postgrespro.ru", "phone": "+70251424681"}
0005434728257	F4DD50	1731 243186	EVGENIY SMIRNOV	{"phone": "+70991167736"}
0005434728258	F4DD50	9019 343887	NIKITA KOZLOV	{"phone": "+70707871202"}
0005434728259	27EF35	7745 768229	YULIYA MIKHAYLOVA	{"phone": "+70235926874"}
0005434728260	9B63FE	5235 260993	ELENA MEDVEDEVA	{"phone": "+70420933331"}
0005434728261	464D8E	2834 463888	YURIY KUZNECOV	{"email": "yuriy.kuznecov-121972@postgrespro.ru", "phone": "+70383722312"}
0005434728262	EC9369	4206 712022	BOGDAN VLASOV	{"phone": "+70402736538"}
0005434728263	EC9369	6296 282875	LARISA KULIKOVA	{"email": "kulikova.l-19091958@postgrespro.ru", "phone": "+70689080204"}
0005434728264	EC9369	2376 515907	ALEKSANDR MAKAROV	{"email": "a_makarov_011963@postgrespro.ru", "phone": "+70871954296"}
0005434728265	1995F7	6287 795129	ALEKSANDR VOLKOV	{"email": "volkov.a1961@postgrespro.ru", "phone": "+70166658169"}
0005434728266	95343E	9602 435444	OLGA MAKSIMOVA	{"email": "o_maksimova_1970@postgrespro.ru", "phone": "+70200583646"}
0005434728267	95343E	2436 237488	MIKHAIL NAZAROV	{"email": "nazarov_m21111966@postgrespro.ru", "phone": "+70280735759"}
0005434728268	E033A4	6556 594721	ELENA SOKOLOVA	{"email": "elenasokolova.081972@postgrespro.ru", "phone": "+70631273328"}
0005434728269	E033A4	5591 965270	VALENTINA DAVYDOVA	{"email": "valentina-davydova1962@postgrespro.ru", "phone": "+70720518759"}
0005434728270	57FFEE	4407 427860	TATYANA MATVEEVA	{"email": "matveeva_t30031973@postgrespro.ru", "phone": "+70775881417"}
0005434728271	57FFEE	6091 750327	LYUBOV MIKHAYLOVA	{"email": "mikhaylova_l-1973@postgrespro.ru", "phone": "+70469182293"}
0005434728272	68C2A6	9556 386591	VLADIMIR ZAYCEV	{"phone": "+70201811094"}
0005434728273	B2DEC7	6166 745612	VYACHESLAV KUZMIN	{"phone": "+70331785274"}
0005434728274	F305D3	8551 049884	OLGA KUZNECOVA	{"email": "olga.kuznecova121986@postgrespro.ru", "phone": "+70010520217"}
0005434728275	C1C21A	7683 273503	OLGA FROLOVA	{"email": "olga-frolova-04111985@postgrespro.ru", "phone": "+70583435907"}
0005434728276	B1F910	2616 374235	SERGEY KISELEV	{"phone": "+70518344458"}
0005434728277	958049	0700 083005	MARIYA BARANOVA	{"email": "baranova-mariya-07041981@postgrespro.ru", "phone": "+70369768495"}
0005434728278	B8F4E2	0745 943103	NATALYA SCHERBAKOVA	{"email": "natalya.scherbakova-1966@postgrespro.ru", "phone": "+70733612242"}
0005434728279	6E403F	6127 269674	ANDREY ZAYCEV	{"phone": "+70706501624"}
0005434728280	51A420	9051 706612	NATALYA DENISOVA	{"email": "natalyadenisova.1968@postgrespro.ru", "phone": "+70342692416"}
0005434728281	F5DA0B	1136 686665	NIKITA ZAYCEV	{"phone": "+70159335558"}
0005434728282	F5DA0B	5415 562461	SERGEY SEMENOV	{"email": "semenov-s.101973@postgrespro.ru", "phone": "+70019537529"}
0005434728283	868D94	0814 205487	DAMIR PETROV	{"email": "petrov_damir1969@postgrespro.ru", "phone": "+70670302924"}
0005434728284	DD0649	1916 057838	SERGEY CHERNOV	{"phone": "+70148335443"}
0005434728285	08571F	4685 946963	YURIY EGOROV	{"phone": "+70913695629"}
0005434728286	08571F	1814 695792	TATYANA EFREMOVA	{"email": "efremovat-091968@postgrespro.ru", "phone": "+70120762300"}
0005434728287	B73955	8994 671677	ANTON ANTONOV	{"phone": "+70870371664"}
0005434728288	7019D6	2245 006108	NATALYA LOGINOVA	{"phone": "+70318836287"}
0005434728289	DB5823	2138 163931	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr-21091961@postgrespro.ru", "phone": "+70407271989"}
0005434728290	C55640	5174 571780	IRINA FEDOROVA	{"email": "fedorova_irina061974@postgrespro.ru", "phone": "+70349594157"}
0005434728291	C55640	3517 473104	MARGARITA IVANOVA	{"email": "ivanovam1976@postgrespro.ru", "phone": "+70729785617"}
0005434728292	DFCEDC	7429 984132	VALENTINA ANDREEVA	{"email": "valentina-andreeva_11091973@postgrespro.ru", "phone": "+70466120701"}
0005434728293	3D9A44	9921 384440	EGOR MATVEEV	{"email": "matveev_egor_1985@postgrespro.ru", "phone": "+70450604744"}
0005434728294	28D4D9	2196 064187	NINA ZHURAVLEVA	{"email": "zhuravleva-nina_011965@postgrespro.ru", "phone": "+70872089793"}
0005434728295	8E813D	8160 287771	ALEKSEY YAKOVLEV	{"phone": "+70647196277"}
0005434728296	79F3DE	6452 578938	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr-16101974@postgrespro.ru", "phone": "+70342328413"}
0005434728297	47C725	9803 182038	ALEKSANDR GAVRILOV	{"email": "a-gavrilov121965@postgrespro.ru", "phone": "+70755283865"}
0005434728298	E77C53	3599 781482	VALERIYA VOLKOVA	{"email": "v-volkova-031974@postgrespro.ru", "phone": "+70677608515"}
0005434728299	8DC0DB	8070 214643	BOGDAN GUSEV	{"phone": "+70237859069"}
0005434728300	B3FF82	5586 248437	ANTONINA MAKAROVA	{"email": "makarova-antonina-081963@postgrespro.ru", "phone": "+70489960767"}
0005434728301	B3FF82	7872 554928	ALEKSEY NOVIKOV	{"email": "novikov_aleksey101972@postgrespro.ru", "phone": "+70769671682"}
0005434728302	B3FF82	2951 261077	SERGEY MOISEEV	{"email": "s.moiseev_21011975@postgrespro.ru", "phone": "+70903659285"}
0005434728303	80B959	6923 562355	EGOR VLASOV	{"phone": "+70789077703"}
0005434728304	E2EB2C	0601 429061	ALEKSEY SOROKIN	{"phone": "+70526299902"}
0005434728305	66DD3E	3708 505369	ANATOLIY MIKHAYLOV	{"phone": "+70505605729"}
0005434728306	87E637	1011 393538	IGOR SAVELEV	{"email": "i_savelev091977@postgrespro.ru", "phone": "+70701124457"}
0005434728307	FA31EE	6925 619415	EGOR FOMIN	{"phone": "+70057154772"}
0005434728308	FA31EE	5652 473395	ELENA DMITRIEVA	{"phone": "+70070264245"}
0005434728309	7FBE0C	3378 729878	IVAN DMITRIEV	{"phone": "+70177704017"}
0005434728310	7FBE0C	0650 478804	ALEKSANDR NAZAROV	{"phone": "+70395937726"}
0005434728311	75E15B	0088 091914	DARYA IVANOVA	{"email": "ivanova.darya-06091977@postgrespro.ru", "phone": "+70523383657"}
0005434728312	D95F0E	6965 085309	DMITRIY KRASNOV	{"phone": "+70403447572"}
0005434728313	6F09DA	0250 693904	NIKITA KUZNECOV	{"phone": "+70630870677"}
0005434728314	ECB477	1266 061762	EKATERINA FROLOVA	{"email": "frolova-ekaterina_1978@postgrespro.ru", "phone": "+70983896043"}
0005434728315	ED3813	0623 841410	ELENA PAVLOVA	{"email": "elenapavlova-1969@postgrespro.ru", "phone": "+70887358317"}
0005434728316	ED3813	0642 743480	ANDREY SMIRNOV	{"email": "smirnov-andrey101976@postgrespro.ru", "phone": "+70615746374"}
0005434728317	E4909D	3300 096910	TAMARA SOROKINA	{"email": "sorokina.t03051969@postgrespro.ru", "phone": "+70031634903"}
0005434728318	E4909D	9960 845359	ANDREY GAVRILOV	{"phone": "+70206592209"}
0005434728319	8F716E	5454 742388	ELENA ZHUKOVA	{"phone": "+70140919096"}
0005434728320	8F716E	5281 211061	SVETLANA ANDREEVA	{"phone": "+70465851920"}
0005434728321	8F716E	3855 214910	NIKITA VOLKOV	{"email": "nikita_volkov031967@postgrespro.ru", "phone": "+70214116418"}
0005434728322	20950B	2006 015268	YURIY ZHURAVLEV	{"phone": "+70791733307"}
0005434728323	7A35EC	2695 553732	VLADIMIR SCHERBAKOV	{"email": "v-scherbakov_021973@postgrespro.ru", "phone": "+70827691338"}
0005434728324	44B750	6790 910061	TATYANA DAVYDOVA	{"phone": "+70891470876"}
0005434728325	48875A	9184 078610	KONSTANTIN ORLOV	{"phone": "+70302147550"}
0005434728326	48875A	1333 694046	ANASTASIYA ZHUKOVA	{"phone": "+70101383213"}
0005434728327	266ACA	3242 610565	IRINA NESTEROVA	{"phone": "+70935684931"}
0005434728328	AA9DD4	6226 883147	SERGEY OSIPOV	{"phone": "+70961745546"}
0005434728329	AA9DD4	9051 722587	ALEKSANDRA ANDREEVA	{"phone": "+70583760603"}
0005434728330	AA9DD4	0030 014144	MIKHAIL DMITRIEV	{"email": "mdmitriev.30081967@postgrespro.ru", "phone": "+70537748999"}
0005434728331	33C4E9	6727 857764	IVAN DMITRIEV	{"email": "ivandmitriev-1970@postgrespro.ru", "phone": "+70097459323"}
0005434728332	B2DE9B	6179 627310	LIDIYA ZAKHAROVA	{"email": "zakharova_l_08071975@postgrespro.ru", "phone": "+70628538214"}
0005434728333	3DE6B0	0949 927680	OLEG TIKHONOV	{"email": "tikhonov.oleg1960@postgrespro.ru", "phone": "+70254345664"}
0005434728334	6654C7	0110 948887	VARVARA GRISHINA	{"email": "v-grishina1969@postgrespro.ru", "phone": "+70336822880"}
0005434728335	4A6C71	0210 816926	GALINA ZAYCEVA	{"phone": "+70728705133"}
0005434728336	7B9B95	5738 357920	VALERIY ANDREEV	{"email": "andreev_v.13091965@postgrespro.ru", "phone": "+70871947880"}
0005434728337	5A0655	4986 160983	NADEZHDA SCHERBAKOVA	{"phone": "+70782055663"}
0005434728338	5A0655	7881 681802	YURIY ANTONOV	{"phone": "+70942645403"}
0005434728339	F49412	4154 350031	ROMAN ISAEV	{"email": "isaev.roman.04021971@postgrespro.ru", "phone": "+70728190992"}
0005434728340	F49412	0682 715306	TATYANA ZAYCEVA	{"email": "t.zayceva29061979@postgrespro.ru", "phone": "+70296889239"}
0005434728341	17B69F	2448 062652	VYACHESLAV FROLOV	{"phone": "+70111684028"}
0005434728342	17B69F	8467 767374	ANNA GRISHINA	{"phone": "+70698348307"}
0005434728343	89BC2E	5275 262125	NATALYA CHERNOVA	{"phone": "+70533735259"}
0005434728344	AD6882	6318 106497	GALINA DMITRIEVA	{"email": "dmitrievag.22071973@postgrespro.ru", "phone": "+70867469262"}
0005434728345	AE3993	5532 433508	ALEKSANDR NAZAROV	{"email": "a.nazarov_051969@postgrespro.ru", "phone": "+70374654556"}
0005434728346	8ACF19	6936 485942	NATALYA KUZNECOVA	{"email": "natalya_kuznecova-1982@postgrespro.ru", "phone": "+70856570118"}
0005434728347	8ACF19	8310 970897	MAYYA PAVLOVA	{"email": "pavlova-mayya071972@postgrespro.ru", "phone": "+70331510171"}
0005434728348	A29B3B	7418 487489	VLADIMIR KONOVALOV	{"phone": "+70149790310"}
0005434728349	A29B3B	0186 519095	TATYANA IVANOVA	{"phone": "+70660261368"}
0005434728350	CC5B72	8742 211539	TATYANA KAZAKOVA	{"phone": "+70870858007"}
0005434728351	B3CD56	9463 908328	ALEKSANDR IVANOV	{"phone": "+70161322750"}
0005434728352	A397BF	2540 138381	YULIYA KARPOVA	{"phone": "+70110387490"}
0005434728353	14AC0E	3629 199029	ALEKSANDR GUSEV	{"phone": "+70328130953"}
0005434728354	E47E39	5000 145862	ANASTASIYA KISELEVA	{"phone": "+70195849718"}
0005434728355	511901	7014 243149	DENIS BORISOV	{"email": "denisborisov.19031972@postgrespro.ru", "phone": "+70983707589"}
0005434728356	1FC8AB	0759 865737	MIKHAIL KUZMIN	{"phone": "+70639695796"}
0005434728357	A17DE5	4967 227445	ALEKSANDR KISELEV	{"phone": "+70460636082"}
0005434728358	812BC6	3147 011795	SERGEY BELOV	{"phone": "+70191203033"}
0005434728359	BA78DB	5331 546903	ALEKSEY SERGEEV	{"email": "sergeev-a.27031971@postgrespro.ru", "phone": "+70473527214"}
0005434728360	BA78DB	5788 204447	BULAT ABRAMOV	{"phone": "+70191323481"}
0005434728361	950645	4073 217703	ANASTASIYA VASILEVA	{"phone": "+70677613320"}
0005434728362	E76AAD	1712 453309	VALENTINA ZAYCEVA	{"phone": "+70147500868"}
0005434728363	E76AAD	5081 159139	ILDAR PAVLOV	{"phone": "+70844655542"}
0005434728364	031446	7693 762158	IRINA MAKSIMOVA	{"email": "irina_maksimova-1976@postgrespro.ru", "phone": "+70556578439"}
0005434728365	F54CC1	2898 781129	ALEKSANDR VOROBEV	{"phone": "+70965942383"}
0005434728366	F54CC1	8840 076011	IVAN GERASIMOV	{"email": "ivangerasimov1959@postgrespro.ru", "phone": "+70637569493"}
0005434728367	9930F4	9041 882217	INESSA CHERNOVA	{"email": "inessa_chernova_1971@postgrespro.ru", "phone": "+70155220937"}
0005434728368	8E6062	3715 004920	VALENTIN FEDOROV	{"email": "fedorov.v_18021978@postgrespro.ru", "phone": "+70127463674"}
0005434728369	BAE746	2785 630318	ELENA SMIRNOVA	{"email": "elena-smirnova.091975@postgrespro.ru", "phone": "+70720780546"}
0005434728370	1100CE	8348 028132	LYUCIYA EFIMOVA	{"phone": "+70016742157"}
0005434728371	9EF60A	5377 136147	MARINA PETROVA	{"email": "petrova-m-1964@postgrespro.ru", "phone": "+70176029671"}
0005434728372	735449	3675 654788	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr18101964@postgrespro.ru", "phone": "+70181194879"}
0005434728373	C4E2A5	7774 327458	FEDOR MATVEEV	{"email": "matveev.fedor_1969@postgrespro.ru", "phone": "+70782533725"}
0005434728374	9EE334	8548 460271	ANASTASIYA MOROZOVA	{"email": "anastasiya_morozova17071975@postgrespro.ru", "phone": "+70096025827"}
0005434728375	FA6C70	1223 274750	SOFYA IVANOVA	{"email": "ivanova_sofya061980@postgrespro.ru", "phone": "+70634810480"}
0005434728376	77CD87	7956 035277	EVGENIY PAVLOV	{"phone": "+70127927112"}
0005434728377	77CD87	4776 171133	MARINA ALEKSANDROVA	{"email": "m.aleksandrova_23041960@postgrespro.ru", "phone": "+70861754401"}
0005434728378	EE7DF3	2002 771668	EDUARD VOROBEV	{"email": "evorobev.121971@postgrespro.ru", "phone": "+70100059739"}
0005434728379	797F2A	9000 900952	ANASTASIYA FROLOVA	{"phone": "+70422791122"}
0005434728380	C3968D	9764 857858	ELENA KUZNECOVA	{"email": "elena_kuznecova.061973@postgrespro.ru", "phone": "+70324745949"}
0005434728381	1B7A9C	6299 727480	IVAN VOROBEV	{"phone": "+70564861266"}
0005434728382	72CCBD	4214 878878	DARYA RYABOVA	{"phone": "+70624215284"}
0005434728383	9E67CD	0273 912733	MAKSIM SCHERBAKOV	{"phone": "+70355753828"}
0005434728384	8F0A9B	6895 820480	IRINA KUZNECOVA	{"email": "i_kuznecova-20091974@postgrespro.ru", "phone": "+70922967186"}
0005434728385	8F0A9B	0545 775747	NIKOLAY KUZMIN	{"email": "n_kuzmin13121978@postgrespro.ru", "phone": "+70714749567"}
0005434728386	3FD0F8	0099 609593	ILYA VOLKOV	{"email": "volkov-i_16031975@postgrespro.ru", "phone": "+70921145162"}
0005434728387	0A3D12	0329 406055	RINAT NOVIKOV	{"phone": "+70357685967"}
0005434728388	0A3D12	7045 869470	GALINA SERGEEVA	{"email": "galina-sergeeva_22081981@postgrespro.ru", "phone": "+70913679731"}
0005434728389	57284F	5499 846799	EVGENIY BORISOV	{"phone": "+70190966258"}
0005434728390	6C3C94	7268 989269	GALINA NIKOLAEVA	{"email": "nikolaevag1980@postgrespro.ru", "phone": "+70622985323"}
0005434728391	37E5EB	1433 671956	VALERIY MIKHAYLOV	{"email": "valeriy-mikhaylov.051976@postgrespro.ru", "phone": "+70824690387"}
0005434728392	333FB4	0106 416639	OLGA KONDRATEVA	{"email": "kondrateva_o-121963@postgrespro.ru", "phone": "+70415576501"}
0005434728393	E5E011	4548 360532	ALEKSANDR IVANOV	{"email": "a-ivanov-031971@postgrespro.ru", "phone": "+70217838690"}
0005434728394	A3E98F	5834 724083	NADEZHDA SMIRNOVA	{"phone": "+70189954498"}
0005434728395	A3E98F	7913 831416	ELENA EFREMOVA	{"email": "e_efremova.1970@postgrespro.ru", "phone": "+70371106864"}
0005434728396	A559D9	6189 681810	EKATERINA VLASOVA	{"email": "e_vlasova.051962@postgrespro.ru", "phone": "+70659169019"}
0005434728397	5B553A	2221 437847	VIKTOR ZHUKOV	{"email": "zhukov-v.021979@postgrespro.ru", "phone": "+70648931519"}
0005434728398	5F3ED3	2718 540969	MAKSIM KAZAKOV	{"email": "mkazakov.091981@postgrespro.ru", "phone": "+70920015940"}
0005434728399	5F3ED3	5090 405565	NATALYA ALEKSEEVA	{"phone": "+70184252889"}
0005434728400	573541	7389 438770	SERGEY MAKAROV	{"phone": "+70800400249"}
0005434728401	573541	8075 624775	LYUBOV PETROVA	{"email": "petrova_l_1973@postgrespro.ru", "phone": "+70079908213"}
0005434728402	F875CD	4214 379948	ROMAN ILIN	{"phone": "+70834221422"}
0005434728403	05728B	9859 112667	PRASKOVYA NOVIKOVA	{"phone": "+70721297775"}
0005434728404	05728B	5772 514330	SVETLANA NIKOLAEVA	{"phone": "+70453568809"}
0005434728405	569DD4	0483 487382	VLADIMIR NIKOLAEV	{"phone": "+70300950839"}
0005434728406	AE53A5	9862 447120	ANTONINA AKIMOVA	{"phone": "+70257096213"}
0005434728407	AE53A5	9575 354974	RAVIL ZAKHAROV	{"email": "ravil-zakharov_021983@postgrespro.ru", "phone": "+70161289126"}
0005434728408	83103B	5645 967310	MATVEY KAZAKOV	{"email": "matvey_kazakov.22021970@postgrespro.ru", "phone": "+70862091535"}
0005434728409	F3531E	6332 938914	RASIM GUSEV	{"email": "rasim_gusev061971@postgrespro.ru", "phone": "+70809698962"}
0005434728410	9CECC3	8456 289337	ARTEM PETROV	{"phone": "+70828048564"}
0005434728411	17A503	9105 362332	IRINA ZOTOVA	{"phone": "+70399446526"}
0005434728412	FB3A10	6170 409979	DENIS MIRONOV	{"phone": "+70868781935"}
0005434728413	1BC9C6	1320 892108	EKATERINA ZAKHAROVA	{"phone": "+70813506815"}
0005434728414	E0A5A1	0524 603014	ALEKSEY ZHUKOV	{"phone": "+70691094836"}
0005434728415	A7225F	5855 831548	ANDREY MOROZOV	{"email": "andreymorozov_02041978@postgrespro.ru", "phone": "+70214395388"}
0005434728416	191A92	5082 048209	OLGA MALYSHEVA	{"email": "o-malysheva-1977@postgrespro.ru", "phone": "+70461830034"}
0005434728417	D5AC4A	3171 089070	OLEG PETROV	{"phone": "+70505467389"}
0005434728418	D5AC4A	9789 113528	NAIL PAVLOV	{"email": "n_pavlov_18071972@postgrespro.ru", "phone": "+70797520010"}
0005434728419	7DF18A	1375 506036	SVETLANA ZAKHAROVA	{"phone": "+70701720326"}
0005434728420	7DF18A	5411 265757	MARINA AKIMOVA	{"phone": "+70424990386"}
0005434728421	CD298A	7562 668204	MARINA NESTEROVA	{"phone": "+70883702293"}
0005434728422	CD298A	2120 070851	VALENTINA LOGINOVA	{"phone": "+70934579308"}
0005434728423	04ECCF	9587 527781	ELENA ALEKSEEVA	{"email": "alekseeva-e-041978@postgrespro.ru", "phone": "+70464544593"}
0005434728424	04ECCF	6055 050871	NIKOLAY SMIRNOV	{"phone": "+70596881740"}
0005434728425	49D9B7	0605 580495	VLADIMIR IVANOV	{"phone": "+70381808171"}
0005434728426	49D9B7	2773 926780	DMITRIY SERGEEV	{"phone": "+70299156343"}
0005434728427	69590C	5618 424363	MARIYA VASILEVA	{"phone": "+70811782107"}
0005434728428	69590C	0439 292805	VERONIKA PAVLOVA	{"email": "vpavlova31071982@postgrespro.ru", "phone": "+70234625772"}
0005434728429	9C116D	0492 437817	KONSTANTIN GRIGOREV	{"email": "kgrigorev.1988@postgrespro.ru", "phone": "+70250171932"}
0005434728430	9C116D	6236 402559	MARIYA DAVYDOVA	{"phone": "+70436255395"}
0005434728431	22E60E	6003 976331	LIDIYA YAKOVLEVA	{"phone": "+70302276419"}
0005434728432	A875CB	3406 008596	ELENA NIKITINA	{"phone": "+70963536329"}
0005434728433	A875CB	3364 470543	YULIYA KUZMINA	{"email": "y_kuzmina-1976@postgrespro.ru", "phone": "+70848304947"}
0005434728434	35720C	0625 604033	ALEKSEY FOMIN	{"email": "fomin.aleksey.1967@postgrespro.ru", "phone": "+70930859495"}
0005434728435	35720C	0270 654296	ALEKSANDR NOVIKOV	{"email": "a_novikov-26111967@postgrespro.ru", "phone": "+70422378711"}
0005434728436	E1F293	0251 237386	RUSLAN KUZNECOV	{"email": "ruslankuznecov041973@postgrespro.ru", "phone": "+70170444762"}
0005434728437	E1F293	4701 290936	VALERIY GRIGOREV	{"phone": "+70268013527"}
0005434728438	E1F293	2637 977552	NINA KONDRATEVA	{"email": "nina-kondrateva-1962@postgrespro.ru", "phone": "+70988776469"}
0005434728439	B92F2D	0123 248855	NATALYA SMIRNOVA	{"email": "smirnova_natalya.30061970@postgrespro.ru", "phone": "+70440100489"}
0005434728440	4B3766	6386 629943	NADEZHDA SOKOLOVA	{"phone": "+70568808222"}
0005434728441	4B3766	0308 384928	ANATOLIY ILIN	{"phone": "+70147027456"}
0005434728442	743180	2911 813387	ARTEM ZHURAVLEV	{"phone": "+70211413149"}
0005434728443	743180	2904 241944	MIKHAIL BORISOV	{"email": "borisov.m_12041968@postgrespro.ru", "phone": "+70580816066"}
0005434728444	601CD2	9196 173535	SVETLANA SEMENOVA	{"phone": "+70522298349"}
0005434728445	8C5BFD	2985 584322	OLEG GERASIMOV	{"phone": "+70881828381"}
0005434728446	ECD374	3202 044315	DENIS OSIPOV	{"email": "d-osipov1961@postgrespro.ru", "phone": "+70176172462"}
0005434728447	6C4F1E	9080 614303	VLADIMIR SIDOROV	{"phone": "+70008073431"}
0005434728448	487E27	6155 657662	TATYANA KISELEVA	{"email": "kiseleva-t-02111975@postgrespro.ru", "phone": "+70246608174"}
0005434728449	487E27	1830 049730	NATALYA GORBUNOVA	{"phone": "+70523250519"}
0005434728450	10886E	4554 422810	IVAN VASILEV	{"phone": "+70760770593"}
0005434728451	EF2272	9398 087624	VITALIY SEMENOV	{"phone": "+70298131218"}
0005434728452	1E2DEB	6792 543656	ANNA MOROZOVA	{"phone": "+70404762655"}
0005434728453	1E2DEB	4997 311701	GALINA GORBUNOVA	{"email": "gorbunova.galina1980@postgrespro.ru", "phone": "+70853980517"}
0005434728454	9DE761	0010 698876	ELENA SOROKINA	{"phone": "+70283883460"}
0005434728455	9DE761	6574 942208	ANASTASIYA SERGEEVA	{"email": "sergeevaanastasiya.1980@postgrespro.ru", "phone": "+70925350017"}
0005434728456	D58AF5	5077 291941	MARINA SOROKINA	{"phone": "+70703882948"}
0005434728457	68C351	4520 126306	NATALYA KALININA	{"email": "kalinina-natalya.16081976@postgrespro.ru", "phone": "+70471859739"}
0005434728458	80E7D6	8119 635972	IVAN KRASNOV	{"email": "krasnovi-03031970@postgrespro.ru", "phone": "+70348037240"}
0005434728459	B5DD68	8626 556013	NADEZHDA SEMENOVA	{"phone": "+70402260754"}
0005434728460	7060AC	1008 612284	NIKOLAY TARASOV	{"email": "tarasov_nikolay-18011964@postgrespro.ru", "phone": "+70977504805"}
0005434728461	7060AC	1326 897156	PAVEL DENISOV	{"email": "denisov_pavel.14091965@postgrespro.ru", "phone": "+70485990518"}
0005434728462	499C05	4756 113109	ANNA PAVLOVA	{"phone": "+70946166486"}
0005434728463	499C05	8082 599361	GUZEL NAZAROVA	{"email": "nazarova_guzel.01031969@postgrespro.ru", "phone": "+70165455132"}
0005434728464	DE312F	9650 192931	VERONIKA OVCHINNIKOVA	{"phone": "+70992094169"}
0005434728465	DE312F	3359 602202	VERA SCHERBAKOVA	{"email": "v-scherbakova-1974@postgrespro.ru", "phone": "+70367359545"}
0005434728466	BD6A2F	2412 247622	ALEKSANDRA NAZAROVA	{"phone": "+70774843073"}
0005434728467	03DC32	5768 839165	PAVEL DENISOV	{"phone": "+70491081653"}
0005434728468	D5D990	5707 214018	ZINAIDA SEMENOVA	{"email": "semenovazinaida-09121972@postgrespro.ru", "phone": "+70900272509"}
0005434728469	192086	2948 627536	ANNA RYABOVA	{"phone": "+70858544691"}
0005434728470	B64D0E	1667 802723	LIDIYA KUZNECOVA	{"email": "kuznecova-lidiya-21121979@postgrespro.ru", "phone": "+70651386346"}
0005434728471	B64D0E	6400 365529	PAVEL RODIONOV	{"email": "rodionov-p.1953@postgrespro.ru", "phone": "+70315751290"}
0005434728472	D6FBF1	3285 143851	KONSTANTIN ZAYCEV	{"email": "zaycev-konstantin-021971@postgrespro.ru", "phone": "+70833136602"}
0005434728473	D6FBF1	4970 726052	ANATOLIY VLASOV	{"email": "avlasov.1972@postgrespro.ru", "phone": "+70290467271"}
0005434728474	9E7200	2328 713202	LYUDMILA BELYAEVA	{"email": "belyaevalyudmila-17011974@postgrespro.ru", "phone": "+70428955507"}
0005434728475	9E7200	9728 292405	RINAT KUZNECOV	{"phone": "+70793534388"}
0005434728476	CEF5F0	2491 945257	ALEKSEY IVANOV	{"phone": "+70837254120"}
0005434728477	E40682	6272 022831	LYUDMILA FADEEVA	{"phone": "+70122795702"}
0005434728478	E40682	7721 911200	KRISTINA KAZAKOVA	{"phone": "+70939330778"}
0005434728479	059C10	8349 923713	ALEKSEY ZHUKOV	{"phone": "+70675464352"}
0005434728480	16DBCD	1122 578419	IGOR ZAKHAROV	{"phone": "+70954384593"}
0005434728481	655158	1232 012817	DMITRIY FOMIN	{"email": "fomin_dmitriy.06091968@postgrespro.ru", "phone": "+70245555108"}
0005434728482	655158	8841 482840	OLGA NOVIKOVA	{"phone": "+70619638015"}
0005434728483	938582	0648 000848	SERGEY NAUMOV	{"phone": "+70174340944"}
0005434728484	C2C739	7509 698664	ARINA FROLOVA	{"email": "frolova-arina02021975@postgrespro.ru", "phone": "+70119655334"}
0005434728485	A11794	5020 372291	TIMOFEY SMIRNOV	{"email": "timofey_smirnov.02031971@postgrespro.ru", "phone": "+70357640862"}
0005434728486	C87A41	2571 600332	VLADIMIR NOVIKOV	{"email": "novikov-vladimir.1970@postgrespro.ru", "phone": "+70635483125"}
0005434728487	FA44A8	1372 620167	ALEKSANDR GERASIMOV	{"email": "aleksandr-gerasimov.111970@postgrespro.ru", "phone": "+70189247142"}
0005434728488	FA44A8	3913 024152	VALENTINA MATVEEVA	{"phone": "+70627262583"}
0005434728489	E43A8C	3610 319390	ANNA NESTEROVA	{"email": "nesterova.a06061966@postgrespro.ru", "phone": "+70397223787"}
0005434728490	E43A8C	4879 754543	MARIYA AKIMOVA	{"email": "akimova-m-27101965@postgrespro.ru", "phone": "+70733107726"}
0005434728491	E43A8C	2918 264823	VLADISLAV KRASNOV	{"email": "vladislav.krasnov21121969@postgrespro.ru", "phone": "+70070325067"}
0005434728492	E750C5	0130 614260	ELENA BORISOVA	{"phone": "+70126509221"}
0005434728493	72E3BA	7399 475627	ALISA KOZLOVA	{"email": "kozlovaalisa_17091972@postgrespro.ru", "phone": "+70714996768"}
0005434728495	EE58CF	1919 145133	LARISA LUKYANOVA	{"email": "larisalukyanova-23051964@postgrespro.ru", "phone": "+70355849645"}
0005434728496	EE58CF	2333 395475	POLINA KOZLOVA	{"email": "p_kozlova-011968@postgrespro.ru", "phone": "+70204725729"}
0005434728497	4E3BE5	2980 069543	ALEKSEY VOLKOV	{"email": "volkov.aleksey.1963@postgrespro.ru", "phone": "+70870474880"}
0005434728498	A33684	3322 218699	VERA PAVLOVA	{"email": "vera-pavlova-041977@postgrespro.ru", "phone": "+70984974342"}
0005434728499	A33684	1018 858703	DAMIR SCHERBAKOV	{"phone": "+70569205558"}
0005434728500	42BAD4	6768 410656	SERGEY TARASOV	{"phone": "+70550707594"}
0005434728501	AFAB50	9708 481022	TATYANA STEPANOVA	{"email": "tstepanova041973@postgrespro.ru", "phone": "+70113436252"}
0005434728502	315488	4610 622817	VYACHESLAV POPOV	{"email": "popovv_081969@postgrespro.ru", "phone": "+70556892694"}
0005434728503	315488	3289 468130	VASILIY VASILEV	{"phone": "+70272413625"}
0005434728504	1D498C	9007 789422	EKATERINA EGOROVA	{"phone": "+70114332184"}
0005434728505	1A8578	6432 332909	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.a-051981@postgrespro.ru", "phone": "+70791437209"}
0005434728506	1A8578	4954 896987	IRINA ISAEVA	{"phone": "+70705281427"}
0005434728507	2BE6AB	3093 105989	ILYA SOLOVEV	{"email": "solovev-ilya_08111956@postgrespro.ru", "phone": "+70146262471"}
0005434728508	2BE6AB	6973 959563	ALEKSANDR TIMOFEEV	{"phone": "+70683557885"}
0005434728509	DC7EFA	9179 044710	ALEKSANDR VOLKOV	{"phone": "+70007713591"}
0005434728510	DC7EFA	0187 114549	TATYANA SEMENOVA	{"email": "t_semenova_1967@postgrespro.ru", "phone": "+70767145125"}
0005434728511	0E4098	9286 870579	ALEKSEY SMIRNOV	{"email": "asmirnov-101980@postgrespro.ru", "phone": "+70086895375"}
0005434728512	26E170	7862 102611	LYUBOV OVCHINNIKOVA	{"email": "l_ovchinnikova1967@postgrespro.ru", "phone": "+70081324145"}
0005434728513	3083C5	5874 620839	LYUDMILA PETROVA	{"phone": "+70696380804"}
0005434728571	AE7B60	1998 834955	VALENTIN TIMOFEEV	{"phone": "+70668605271"}
0005434728514	8207E6	9408 585812	IRINA EGOROVA	{"email": "egorovai091971@postgrespro.ru", "phone": "+70300252719"}
0005434728515	8207E6	6633 181505	RAFIS SOKOLOV	{"email": "rafis-sokolov_1963@postgrespro.ru", "phone": "+70169204120"}
0005434728516	2DB826	1022 535006	KLIM ALEKSANDROV	{"email": "aleksandrov-klim-031978@postgrespro.ru", "phone": "+70593110906"}
0005434728517	2DB826	7096 495946	ELENA KOZLOVA	{"phone": "+70830939357"}
0005434728518	2DB826	6026 405722	TAMARA MOISEEVA	{"email": "t_moiseeva.1976@postgrespro.ru", "phone": "+70649005352"}
0005434728519	CB65A9	0693 766788	IRINA VLASOVA	{"email": "irina_vlasova.1972@postgrespro.ru", "phone": "+70420160147"}
0005434728520	CB65A9	5150 834773	LYUBOV ZOTOVA	{"phone": "+70939610863"}
0005434728521	10EFB7	8359 983407	ALISA GRISHINA	{"phone": "+70691321917"}
0005434728522	9E3BC5	4797 022507	NATALYA PETROVA	{"phone": "+70928401605"}
0005434728523	B9979E	4945 246714	DENIS ZAYCEV	{"phone": "+70731903480"}
0005434728524	B9979E	9202 290494	TATYANA MALYSHEVA	{"phone": "+70235045413"}
0005434728525	1ACB04	9079 956999	ANDREY SMIRNOV	{"email": "smirnov-andrey_1968@postgrespro.ru", "phone": "+70787161853"}
0005434728526	1ACB04	3380 675873	ALEKSANDR ZAKHAROV	{"phone": "+70751702709"}
0005434728527	39C583	6709 252239	ALEKSANDR KUZNECOV	{"phone": "+70347116975"}
0005434728528	37182C	4749 611093	KONSTANTIN DMITRIEV	{"phone": "+70152643992"}
0005434728529	80C2EA	7298 506267	ILYA SCHERBAKOV	{"phone": "+70045363041"}
0005434728530	80C2EA	7654 016734	FEDOR SIDOROV	{"phone": "+70347508153"}
0005434728531	36DF5D	5844 711273	ALEKSANDR KULIKOV	{"phone": "+70231144820"}
0005434728532	36DF5D	8107 807902	ANASTASIYA ISAEVA	{"email": "isaeva.anastasiya_1975@postgrespro.ru", "phone": "+70074478008"}
0005434728533	96FCFF	6943 363825	ANATOLIY SIDOROV	{"email": "a-sidorov-121971@postgrespro.ru", "phone": "+70525854628"}
0005434728534	35D1F0	9758 472666	ANASTASIYA NAZAROVA	{"email": "nazarova.anastasiya.1970@postgrespro.ru", "phone": "+70664858785"}
0005434728535	35D1F0	6764 858085	VLADLEN ORLOV	{"email": "v-orlov121973@postgrespro.ru", "phone": "+70165274188"}
0005434728536	8A553A	1561 100862	ILYA SMIRNOV	{"phone": "+70128522688"}
0005434728537	1F1465	7729 103910	IRINA FADEEVA	{"phone": "+70459164853"}
0005434728538	2CB521	6391 469282	MARINA ANDREEVA	{"phone": "+70998299736"}
0005434728539	05F89A	2920 000297	ANDREY SAVELEV	{"phone": "+70677280191"}
0005434728540	2C0C1B	8776 691155	ANATOLIY KOZLOV	{"phone": "+70771796117"}
0005434728541	4ECCFB	7386 939834	LYUBOV ZHUKOVA	{"email": "l-zhukova.031973@postgrespro.ru", "phone": "+70309835983"}
0005434728542	FA6097	0174 527594	LYUBOV ALEKSEEVA	{"phone": "+70752177266"}
0005434728543	FA6097	1689 091151	SERGEY ZAKHAROV	{"email": "sergey_zakharov-121973@postgrespro.ru", "phone": "+70822957021"}
0005434728544	E6BE0A	0426 529243	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir071972@postgrespro.ru", "phone": "+70911824090"}
0005434728545	267E19	0437 977685	IVAN NIKOLAEV	{"phone": "+70802416080"}
0005434728546	267E19	6626 427538	EVGENIYA KOLESNIKOVA	{"phone": "+70794946801"}
0005434728547	4CBCC9	4218 820938	YULIYA VASILEVA	{"phone": "+70356453918"}
0005434728548	4CBCC9	9362 684189	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila021971@postgrespro.ru", "phone": "+70356160795"}
0005434728549	FA2AB0	6243 292509	EVGENIYA SOLOVEVA	{"phone": "+70416058689"}
0005434728550	FA2AB0	5609 988336	YURIY IVANOV	{"email": "yuriyivanov.28041976@postgrespro.ru", "phone": "+70025837982"}
0005434728551	D9AEBC	5984 628760	EGOR MATVEEV	{"email": "egor-matveev071975@postgrespro.ru", "phone": "+70023618420"}
0005434728552	A1AEB3	1471 428017	MIKHAIL IVANOV	{"phone": "+70503686934"}
0005434728553	A1AEB3	7670 745295	EKATERINA MIKHAYLOVA	{"phone": "+70563162131"}
0005434728554	A1AEB3	8400 935312	RUSLAN GRIGOREV	{"email": "r.grigorev.1978@postgrespro.ru", "phone": "+70553709539"}
0005434728555	F6B610	1910 029481	IGOR SEMENOV	{"email": "semenov-i.19031969@postgrespro.ru", "phone": "+70579043337"}
0005434728556	6703CE	2175 757476	TIGRAN VASILEV	{"phone": "+70915654196"}
0005434728557	E438C1	2673 091295	VIKTORIYA POPOVA	{"phone": "+70503796590"}
0005434728558	E438C1	6686 628513	ALEKSANDR SCHERBAKOV	{"phone": "+70286829616"}
0005434728559	C1BC8B	9860 792843	ARTEM GRIGOREV	{"phone": "+70294643265"}
0005434728560	E8F339	6740 759283	ALEKSANDR ROMANOV	{"phone": "+70062596960"}
0005434728561	A6BB77	0278 264080	LEV TIKHONOV	{"email": "levtikhonov-02071977@postgrespro.ru", "phone": "+70593262025"}
0005434728562	4BC5E8	5416 221707	SERGEY NOVIKOV	{"email": "novikov.sergey_061974@postgrespro.ru", "phone": "+70635309960"}
0005434728563	4BC5E8	4893 553768	VARVARA KARPOVA	{"email": "varvara-karpova.1973@postgrespro.ru", "phone": "+70590860183"}
0005434728564	42C78C	8195 885564	DMITRIY GORBUNOV	{"email": "dgorbunov_081971@postgrespro.ru", "phone": "+70342773294"}
0005434728565	42C78C	6223 131913	ELENA BELOVA	{"phone": "+70645029253"}
0005434728566	42C78C	7902 984936	VLADIMIR TIKHONOV	{"phone": "+70198453822"}
0005434728567	42C78C	9013 654836	ALEKSANDR KISELEV	{"phone": "+70263111347"}
0005434728568	388D15	6926 713179	DANIIL FOMIN	{"phone": "+70097484599"}
0005434728569	388D15	7832 306421	GALINA KUZNECOVA	{"phone": "+70518161128"}
0005434728570	C41999	5948 245572	EVA MEDVEDEVA	{"email": "eva.medvedeva-1974@postgrespro.ru", "phone": "+70342880862"}
0005434728572	AE7B60	0428 233251	ELENA SERGEEVA	{"email": "sergeevae-071964@postgrespro.ru", "phone": "+70101879102"}
0005434728573	9DB687	1342 586187	NIKOLAY PAVLOV	{"phone": "+70790942220"}
0005434728574	7069FD	4412 854482	LYUBOV BELYAEVA	{"email": "lyubov.belyaeva081970@postgrespro.ru", "phone": "+70555013219"}
0005434728575	7069FD	9820 349026	OLEG TARASOV	{"phone": "+70597770206"}
0005434728576	1084E3	9879 818269	ALEKSANDR ANDREEV	{"phone": "+70750980734"}
0005434728577	1084E3	1827 995465	VIKTOR AFANASEV	{"email": "v.afanasev-29081980@postgrespro.ru", "phone": "+70386182289"}
0005434728578	6F336B	4320 950485	ELENA ABRAMOVA	{"phone": "+70966807027"}
0005434728579	EA17AA	1662 277052	SERGEY NOVIKOV	{"phone": "+70092420687"}
0005434728580	111EEF	3714 610849	NIKITA SEMENOV	{"email": "semenovnikita.071972@postgrespro.ru", "phone": "+70521394427"}
0005434728581	215715	2878 330289	DMITRIY YAKOVLEV	{"email": "yakovlev-d_03011988@postgrespro.ru", "phone": "+70784982718"}
0005434728582	215715	1767 720016	IGOR SOLOVEV	{"email": "igor_solovev.1968@postgrespro.ru", "phone": "+70348416220"}
0005434728583	94C214	4038 852472	OLGA PETROVA	{"email": "o-petrova1956@postgrespro.ru", "phone": "+70566321371"}
0005434728584	0CDDEA	5270 994667	FARID PAVLOV	{"phone": "+70541903823"}
0005434728585	D2B955	6209 165262	VITALIY KISELEV	{"email": "kiselev_vitaliy.1979@postgrespro.ru", "phone": "+70318660327"}
0005434728586	72330D	1127 877825	DMITRIY SERGEEV	{"email": "dmitriy-sergeev.31101968@postgrespro.ru", "phone": "+70684346152"}
0005434728587	EA78D4	5674 368318	SERGEY KUZNECOV	{"email": "sergey.kuznecov_111973@postgrespro.ru", "phone": "+70827075955"}
0005434728588	D5E629	8712 762377	SVETLANA MALYSHEVA	{"email": "malysheva.s_081966@postgrespro.ru", "phone": "+70161068036"}
0005434728589	4CED50	8972 486611	MIKHAIL MAKSIMOV	{"email": "maksimov-m1978@postgrespro.ru", "phone": "+70186629881"}
0005434728590	3594F1	2790 986590	ELENA ANTONOVA	{"email": "antonova_elena.1966@postgrespro.ru", "phone": "+70726466787"}
0005434728591	983EBC	9904 689232	TATYANA AFANASEVA	{"phone": "+70791289233"}
0005434728592	B9588D	6153 012962	OLGA KOMAROVA	{"email": "olga_komarova-1972@postgrespro.ru", "phone": "+70606415367"}
0005434728593	209F5C	2965 736432	ANDREY OSIPOV	{"email": "a.osipov-22051981@postgrespro.ru", "phone": "+70237718443"}
0005434728594	7F8C28	9576 144842	DMITRIY KULIKOV	{"phone": "+70522374811"}
0005434728595	7F8C28	8162 251375	NIKOLAY BORISOV	{"email": "n.borisov.121975@postgrespro.ru", "phone": "+70710621964"}
0005434728596	0B57E6	2129 487130	ALEKSANDR SEMENOV	{"phone": "+70974438611"}
0005434728597	564285	4224 555545	EKATERINA GRISHINA	{"phone": "+70569722106"}
0005434728598	BFA66A	0069 749494	ALEKSANDR SIDOROV	{"email": "sidorova_31011976@postgrespro.ru", "phone": "+70331168860"}
0005434728599	576CE4	4611 703933	VALENTINA MAKSIMOVA	{"phone": "+70382771679"}
0005434728600	111A2F	0942 062623	ILDAR ZAKHAROV	{"phone": "+70361235937"}
0005434728601	9C5B39	0301 548931	GALINA NAUMOVA	{"phone": "+70778515984"}
0005434728602	463D02	3231 560991	VALENTIN MOROZOV	{"email": "morozov-valentin.03081980@postgrespro.ru", "phone": "+70288732926"}
0005434728603	99EEDE	4163 566007	NADEZHDA MIKHAYLOVA	{"phone": "+70715870493"}
0005434728604	8AD7B3	4381 293494	DANIL SAVELEV	{"email": "danilsavelev_1973@postgrespro.ru", "phone": "+70708815964"}
0005434728605	49BB01	9306 477546	FANIYA MIRONOVA	{"email": "mironovafaniya071980@postgrespro.ru", "phone": "+70831098334"}
0005434728606	49BB01	6463 781107	ALEKSANDR KAZAKOV	{"email": "kazakov.aleksandr1974@postgrespro.ru", "phone": "+70794305706"}
0005434728607	49BB01	0289 992717	ROMAN POPOV	{"email": "roman_popov.081971@postgrespro.ru", "phone": "+70060151838"}
0005434728608	D002C5	4603 288829	ALENA KALININA	{"phone": "+70649444181"}
0005434728609	D002C5	1053 713658	YURIY KUZNECOV	{"email": "ykuznecov121973@postgrespro.ru", "phone": "+70790604065"}
0005434728610	75DB4F	2029 344390	ELENA MELNIKOVA	{"phone": "+70399065002"}
0005434728611	772547	9307 379698	LADA MAKSIMOVA	{"phone": "+70458995367"}
0005434728612	1ED56F	8545 218886	PETR GRIGOREV	{"email": "grigorevp-041973@postgrespro.ru", "phone": "+70217462301"}
0005434728613	8C8C0C	3898 719669	VALENTINA KONOVALOVA	{"email": "v_konovalova-25051976@postgrespro.ru", "phone": "+70271322137"}
0005434728614	69D1EC	2877 838895	SEMEN ALEKSEEV	{"email": "alekseev_semen29091971@postgrespro.ru", "phone": "+70982790983"}
0005434728615	69D1EC	5723 309022	LEV DENISOV	{"phone": "+70913148727"}
0005434728616	69D1EC	6459 514525	IGOR MIKHAYLOV	{"email": "mikhaylov_igor.071966@postgrespro.ru", "phone": "+70970820523"}
0005434728617	BCD7B7	7280 286441	DARYA TIMOFEEVA	{"email": "timofeeva-darya_1973@postgrespro.ru", "phone": "+70975635787"}
0005434728618	BCD7B7	1781 756567	SVETLANA SCHERBAKOVA	{"email": "s-scherbakova.111982@postgrespro.ru", "phone": "+70957582373"}
0005434728619	41AD0F	0117 042647	OLESYA ILINA	{"email": "ilinao_1961@postgrespro.ru", "phone": "+70310882950"}
0005434728620	9FD7B0	9528 992417	ANTON SAVELEV	{"email": "anton_savelev1977@postgrespro.ru", "phone": "+70811204853"}
0005434728621	9FD7B0	4012 239790	ALEKSANDR KULIKOV	{"email": "kulikova-1966@postgrespro.ru", "phone": "+70222261001"}
0005434728622	072E5A	1167 234852	YULIYA NAZAROVA	{"email": "nazarovayuliya_021966@postgrespro.ru", "phone": "+70920093991"}
0005434728623	C94AFF	7945 595058	ANGELINA KUZNECOVA	{"email": "a-kuznecova_061978@postgrespro.ru", "phone": "+70398510596"}
0005434728624	AC4F7D	6251 637621	DMITRIY FEDOROV	{"phone": "+70525509935"}
0005434728625	AC4F7D	5169 796974	KONSTANTIN PAVLOV	{"phone": "+70678187995"}
0005434728626	AC4F7D	5361 280190	DENIS KOZLOV	{"phone": "+70637935947"}
0005434728627	8D09D6	1591 819084	ANASTASIYA NAZAROVA	{"email": "nazarova-anastasiya21071980@postgrespro.ru", "phone": "+70030399873"}
0005434728628	8D09D6	5410 037680	IRINA MEDVEDEVA	{"email": "medvedeva_i.101968@postgrespro.ru", "phone": "+70254265949"}
0005434728629	8D09D6	1647 258260	NIKOLAY ZHURAVLEV	{"email": "zhuravlev.n-1971@postgrespro.ru", "phone": "+70097107715"}
0005434728630	D694B1	8536 706484	MIKHAIL YAKOVLEV	{"phone": "+70166997944"}
0005434728631	9C5BEE	6618 465683	DARYA KUZNECOVA	{"email": "kuznecovad-22041969@postgrespro.ru", "phone": "+70884455377"}
0005434728632	9C5BEE	6431 514187	YURIY POPOV	{"email": "popov-y1970@postgrespro.ru", "phone": "+70638723578"}
0005434728633	669DE6	5316 041064	ALEVTINA FADEEVA	{"email": "fadeevaalevtina20081965@postgrespro.ru", "phone": "+70379568627"}
0005434728634	669DE6	2104 259942	ANATOLIY FILIPPOV	{"email": "a-filippov_1986@postgrespro.ru", "phone": "+70610189792"}
0005434728635	669DE6	3336 707692	SNEZHANA KONOVALOVA	{"phone": "+70174054052"}
0005434728636	C240A0	7031 772144	VALENTINA PAVLOVA	{"phone": "+70055538876"}
0005434728637	C1895B	3328 233233	YURIY KOZLOV	{"phone": "+70977045048"}
0005434728638	EEC544	2070 181567	ELEONORA ANTONOVA	{"phone": "+70733513550"}
0005434728639	EEC544	2809 344482	IVAN SOROKIN	{"phone": "+70401234251"}
0005434728640	829686	4991 531467	LIDIYA KOZLOVA	{"phone": "+70192977854"}
0005434728641	45DB7B	5414 560562	KIRILL FOMIN	{"phone": "+70358674428"}
0005434728642	45DB7B	6736 294497	VIKTOR NOVIKOV	{"email": "viktor-novikov-061968@postgrespro.ru", "phone": "+70019050259"}
0005434728643	E2664C	1570 966147	SERGEY IVANOV	{"phone": "+70116489904"}
0005434728644	F8A944	0102 202502	ALEKSANDR PETROV	{"phone": "+70695376371"}
0005434728645	BB8040	4749 744744	VITALIY SIDOROV	{"phone": "+70190724058"}
0005434728646	BB8040	5872 921928	OLEG KUZNECOV	{"phone": "+70764507674"}
0005434728647	3D9541	6953 627110	RAIS KOROLEV	{"phone": "+70617151419"}
0005434728648	3D9541	4940 119117	IRINA GORBUNOVA	{"email": "i.gorbunova_10071974@postgrespro.ru", "phone": "+70648680530"}
0005434728649	7ACA46	5571 820289	VITALIY GORBUNOV	{"email": "vitaliy.gorbunov.1977@postgrespro.ru", "phone": "+70085987692"}
0005434728650	148EFA	6871 167580	YULIYA NIKOLAEVA	{"email": "nikolaeva_yuliya.1966@postgrespro.ru", "phone": "+70670268034"}
0005434728651	148EFA	4766 801372	ALEKSANDR PETROV	{"phone": "+70249894312"}
0005434728652	8DB166	0555 889029	IGOR SMIRNOV	{"email": "igorsmirnov-121970@postgrespro.ru", "phone": "+70065630535"}
0005434728653	C69CE0	3960 406447	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov_29111963@postgrespro.ru", "phone": "+70529388628"}
0005434728654	683FB8	3163 128257	NADEZHDA SMIRNOVA	{"phone": "+70074971334"}
0005434728655	683FB8	6900 719549	ALEKSANDR DENISOV	{"phone": "+70833498825"}
0005434728656	F558E6	5376 438984	MARIYA SERGEEVA	{"email": "sergeeva-m-081963@postgrespro.ru", "phone": "+70459618683"}
0005434728657	D2A133	3248 212628	NIKOLAY BONDARENKO	{"phone": "+70252217551"}
0005434728658	D2A133	0189 132853	MIKHAIL SEMENOV	{"email": "semenov.mikhail-1964@postgrespro.ru", "phone": "+70866340997"}
0005434728659	77E7B4	6240 197098	ALEKSANDR FROLOV	{"phone": "+70332810666"}
0005434728660	8B86F1	2806 482007	MAKSIM ZAKHAROV	{"email": "maksim.zakharov-24021973@postgrespro.ru", "phone": "+70718791915"}
0005434728661	5B610D	5556 748298	EKATERINA NOVIKOVA	{"phone": "+70114532866"}
0005434728662	B43611	1739 090707	VLADIMIR ZHUKOV	{"phone": "+70439582588"}
0005434728663	E50615	3215 959343	ELENA LAZAREVA	{"phone": "+70788018699"}
0005434728664	E50615	2036 989477	ARTEM BELOV	{"email": "belov-a-041984@postgrespro.ru", "phone": "+70208018551"}
0005434728665	E12BD2	1428 580182	SVETLANA PAVLOVA	{"phone": "+70298801011"}
0005434728666	E12BD2	6694 623000	NIKOLAY ILIN	{"email": "ilinnikolay1972@postgrespro.ru", "phone": "+70872798582"}
0005434728667	81D8AD	4514 686498	ANATOLIY MIKHAYLOV	{"email": "mikhaylov_anatoliy.071969@postgrespro.ru", "phone": "+70197750930"}
0005434728668	A78660	7354 921789	VLADIMIR BELOV	{"phone": "+70256395054"}
0005434728669	9F2F99	2791 692846	MARIYA KONOVALOVA	{"phone": "+70905559476"}
0005434728670	4EE1CE	0902 117195	ILYA FROLOV	{"phone": "+70555373305"}
0005434728671	4EE1CE	2193 361665	MARINA ORLOVA	{"phone": "+70090762140"}
0005434728672	1B7E1D	0475 430760	NIKOLAY KAZAKOV	{"email": "kazakovn.1972@postgrespro.ru", "phone": "+70489199323"}
0005434728673	CDD602	1328 138521	GENNADIY TIMOFEEV	{"email": "g-timofeev_1983@postgrespro.ru", "phone": "+70065182316"}
0005434728674	3D0E3A	2795 470846	ANDREY TIKHONOV	{"email": "tikhonov.a-1970@postgrespro.ru", "phone": "+70313542230"}
0005434728675	883F49	4471 497230	MIKHAIL IVANOV	{"email": "ivanov.m.07011970@postgrespro.ru", "phone": "+70499301009"}
0005434728676	883F49	4262 034758	EVGENIY ROMANOV	{"phone": "+70337378149"}
0005434728677	991A8C	0421 359501	NIKOLAY NIKITIN	{"email": "n.nikitin-081980@postgrespro.ru", "phone": "+70384376165"}
0005434728678	991A8C	8612 928552	MIKHAIL FILIPPOV	{"phone": "+70349744816"}
0005434728679	7A25F8	4798 259365	YULIYA SEMENOVA	{"phone": "+70659417029"}
0005434728680	060DD9	1210 153696	SERGEY GUSEV	{"email": "sgusev-1972@postgrespro.ru", "phone": "+70492774170"}
0005434728681	EFA588	3132 634817	IGOR IVANOV	{"phone": "+70289191006"}
0005434728682	6CDB79	8485 266394	MARIYA DENISOVA	{"email": "mariyadenisova-081969@postgrespro.ru", "phone": "+70575089210"}
0005434728683	F523FE	1017 433521	MARIYA OVCHINNIKOVA	{"email": "mariya-ovchinnikova_1970@postgrespro.ru", "phone": "+70460645053"}
0005434728684	399191	5854 037279	SERGEY ALEKSANDROV	{"phone": "+70184308315"}
0005434728685	6C5AFA	7889 841363	MARIYA KULIKOVA	{"phone": "+70370609430"}
0005434728686	14D2DC	4561 419350	ALEKSANDR ANDREEV	{"phone": "+70110226369"}
0005434728687	9DF90B	3125 542942	MIKHAIL PETROV	{"email": "petrovm10061971@postgrespro.ru", "phone": "+70956408979"}
0005434728688	9DF90B	0584 271634	ALEKSEY FROLOV	{"email": "frolov-aleksey_1963@postgrespro.ru", "phone": "+70871840357"}
0005434728689	9DF90B	8440 606398	KRISTINA SOKOLOVA	{"phone": "+70752036475"}
0005434728690	927B5B	0133 283494	VALENTINA VLASOVA	{"phone": "+70646171466"}
0005434728691	D47B5A	3954 027283	ILYA YAKOVLEV	{"email": "yakovlevi.081979@postgrespro.ru", "phone": "+70916382480"}
0005434728692	13A81F	6261 473401	TATYANA ABRAMOVA	{"phone": "+70358122834"}
0005434728693	13A81F	7432 450748	ELENA KULIKOVA	{"phone": "+70681223334"}
0005434728694	4453E1	0755 169173	ANDREY DMITRIEV	{"phone": "+70672420570"}
0005434728695	4453E1	0145 890945	ALEKSANDR GERASIMOV	{"email": "a_gerasimov-09111981@postgrespro.ru", "phone": "+70262708890"}
0005434728696	D80912	2895 116223	RUDOLF KUZNECOV	{"email": "kuznecovr.24031979@postgrespro.ru", "phone": "+70161776869"}
0005434728697	E2F6AA	8448 443925	KLAVDIYA CHERNOVA	{"phone": "+70423916725"}
0005434728698	E2F6AA	2905 662384	NINA NIKOLAEVA	{"email": "nnikolaeva_19051976@postgrespro.ru", "phone": "+70817146776"}
0005434728699	B1B015	6021 927142	DMITRIY KUZNECOV	{"phone": "+70708231868"}
0005434728700	B1B015	0614 654960	DMITRIY NIKITIN	{"email": "dmitriy.nikitin.1972@postgrespro.ru", "phone": "+70837094591"}
0005434728701	6AF672	6689 792960	ALEKSANDR SOLOVEV	{"phone": "+70846898850"}
0005434728702	3C40EF	5922 474024	NADEZHDA CHERNOVA	{"phone": "+70677839021"}
0005434728703	3C40EF	9098 824173	ALEKSANDRA KUZNECOVA	{"email": "kuznecovaa19031972@postgrespro.ru", "phone": "+70630400192"}
0005434728704	0F12E8	7617 184997	GALINA KISELEVA	{"email": "g-kiseleva051977@postgrespro.ru", "phone": "+70861346895"}
0005434728705	9CE3CB	4316 516284	SERGEY DMITRIEV	{"email": "dmitriev-s1971@postgrespro.ru", "phone": "+70605264325"}
0005434728706	5FA441	6537 013594	MIKHAIL SIDOROV	{"phone": "+70253194237"}
0005434728707	2B98A8	3995 337652	MARIYA ISAEVA	{"email": "mariya-isaeva.01051967@postgrespro.ru", "phone": "+70693604552"}
0005434728708	1F9B06	9714 241009	LIDIYA AKIMOVA	{"email": "lidiya_akimova_1983@postgrespro.ru", "phone": "+70352832336"}
0005434728709	CD51EA	3268 524477	ALEKSANDR IVANOV	{"phone": "+70126172395"}
0005434728710	CD51EA	7302 403604	MAKSIM ALEKSEEV	{"email": "m.alekseev1975@postgrespro.ru", "phone": "+70354717380"}
0005434728711	6754ED	8062 852763	OLGA KRASNOVA	{"email": "krasnova_olga20021967@postgrespro.ru", "phone": "+70994121680"}
0005434728712	6754ED	4926 086504	VLADIMIR MARTYNOV	{"email": "vladimir_martynov-1975@postgrespro.ru", "phone": "+70351640925"}
0005434728713	0562E2	4038 232960	SERGEY IVANOV	{"phone": "+70428205968"}
0005434728714	B428D1	7784 970965	ALEKSEY RODIONOV	{"phone": "+70155945831"}
0005434728715	38BA2E	3253 458346	PAVEL ANTONOV	{"phone": "+70135661354"}
0005434728716	38BA2E	1762 694189	NADEZHDA MAKSIMOVA	{"email": "maksimova_nadezhda28051974@postgrespro.ru", "phone": "+70681007579"}
0005434728717	03CBDC	5536 235150	RAISA GORBUNOVA	{"phone": "+70666167952"}
0005434728718	6FFDD2	1489 932909	ANTONINA FILIPPOVA	{"email": "a_filippova.02101973@postgrespro.ru", "phone": "+70836563914"}
0005434728719	6FFDD2	2659 285490	FARIDA SOKOLOVA	{"phone": "+70664385522"}
0005434728720	70ABE2	2081 206957	GALINA BARANOVA	{"phone": "+70808241951"}
0005434728721	B47082	6567 228635	SERGEY IVANOV	{"phone": "+70536605893"}
0005434728722	EB4AEF	8404 385852	ALEKSEY OSIPOV	{"email": "osipov_a.09011975@postgrespro.ru", "phone": "+70113806531"}
0005434728723	100340	8851 092654	VERA ZAKHAROVA	{"email": "zakharovav031974@postgrespro.ru", "phone": "+70399737562"}
0005434728724	6094AF	8528 480358	TAMARA OSIPOVA	{"phone": "+70633975424"}
0005434728725	530ACA	7889 550800	IVAN MEDVEDEV	{"email": "i.medvedev_21041979@postgrespro.ru", "phone": "+70195099851"}
0005434728726	4D860E	6515 751831	RADIK PETROV	{"email": "petrov-radik.13071956@postgrespro.ru", "phone": "+70517867291"}
0005434728727	DCED6C	6649 233741	OLEG ZHUKOV	{"phone": "+70411240136"}
0005434728728	80E0FB	6349 547923	IRINA SOKOLOVA	{"phone": "+70653092388"}
0005434728729	0CD859	2999 838729	YURIY ILIN	{"phone": "+70969480395"}
0005434728730	D3FCD3	4829 888215	SVETLANA KOROLEVA	{"phone": "+70221225311"}
0005434728731	D3FCD3	4553 617029	ANNA NAUMOVA	{"phone": "+70981778622"}
0005434728732	81A964	4728 548408	SERGEY ZAYCEV	{"phone": "+70248197229"}
0005434728733	9480CB	1705 524117	VLADIMIR MOISEEV	{"email": "moiseev-v_061978@postgrespro.ru", "phone": "+70049985565"}
0005434728734	0D09F2	5437 116204	TATYANA TARASOVA	{"email": "t.tarasova-14081970@postgrespro.ru", "phone": "+70192648082"}
0005434728735	E94E36	8437 868387	VYACHESLAV KULIKOV	{"email": "v-kulikov17041970@postgrespro.ru", "phone": "+70984757451"}
0005434728736	10D221	9137 034160	LEV VASILEV	{"email": "vasilev.l01121965@postgrespro.ru", "phone": "+70661538354"}
0005434728737	10D221	4959 987898	PAVEL FROLOV	{"email": "p_frolov051977@postgrespro.ru", "phone": "+70981294525"}
0005434728738	10D221	4948 753089	EVGENIY TIKHONOV	{"phone": "+70832214223"}
0005434728739	ECD34F	5171 916803	TAMARA VASILEVA	{"email": "tvasileva-051972@postgrespro.ru", "phone": "+70402399974"}
0005434728740	988A7B	2292 473498	GERMAN KUZNECOV	{"phone": "+70470295948"}
0005434728741	988A7B	2742 261435	MARAT SCHERBAKOV	{"email": "mscherbakov-011975@postgrespro.ru", "phone": "+70056514865"}
0005434728742	988A7B	7715 762450	YULIYA MOROZOVA	{"email": "yuliya_morozova-1975@postgrespro.ru", "phone": "+70831639906"}
0005434728743	988A7B	5057 204125	VIKTOR VOROBEV	{"email": "vorobev.viktor-1959@postgrespro.ru", "phone": "+70277698279"}
0005434728744	1CA4EE	4340 432314	KONSTANTIN SMIRNOV	{"email": "smirnovk-1982@postgrespro.ru", "phone": "+70789192095"}
0005434728745	0F612A	0978 159336	ANNA MAKAROVA	{"email": "makarova.a.20121961@postgrespro.ru", "phone": "+70240388274"}
0005434728746	0F612A	0018 061286	SERGEY BARANOV	{"email": "s-baranov_101969@postgrespro.ru", "phone": "+70626348182"}
0005434728747	ACB4B1	6860 081436	ALBINA MIKHAYLOVA	{"email": "a.mikhaylova-1971@postgrespro.ru", "phone": "+70983131758"}
0005434728748	ACB4B1	5736 096508	TAMARA KUZNECOVA	{"email": "kuznecova_tamara101972@postgrespro.ru", "phone": "+70099150691"}
0005434728749	D3650C	2341 091614	DAVID KUZNECOV	{"email": "dkuznecov_031968@postgrespro.ru", "phone": "+70400117757"}
0005434728750	847BA9	4512 469091	ALEKSEY ALEKSEEV	{"phone": "+70898255273"}
0005434728751	D09B2F	2187 143178	ALEKSANDR MIRONOV	{"phone": "+70388293383"}
0005434728752	90E198	9967 494685	ALEKSANDR ALEKSANDROV	{"phone": "+70636045457"}
0005434728753	339D36	8157 801974	NATALYA SAVELEVA	{"email": "savelevanatalya-031973@postgrespro.ru", "phone": "+70872327018"}
0005434728754	89E284	0247 259890	OKSANA SERGEEVA	{"phone": "+70611075491"}
0005434728755	1D6E32	1285 183715	TATYANA SAVELEVA	{"email": "savelevatatyana-19091975@postgrespro.ru", "phone": "+70830525120"}
0005434728756	4AB05F	1920 379899	VIKTORIYA KUZNECOVA	{"phone": "+70722757461"}
0005434728757	5450FD	6118 432200	YULIYA TARASOVA	{"phone": "+70040442074"}
0005434728758	7AE78F	4703 377528	SANIYA ILINA	{"email": "s.ilina_1975@postgrespro.ru", "phone": "+70457616961"}
0005434728759	7AE78F	6164 902469	MARGARITA CHERNOVA	{"phone": "+70856185308"}
0005434728760	0BD5F8	1958 600833	YAROSLAV VOLKOV	{"phone": "+70228285655"}
0005434728761	8A79DC	2240 045606	OKSANA YAKOVLEVA	{"email": "o.yakovleva_09121975@postgrespro.ru", "phone": "+70634253164"}
0005434728762	7D0B9D	6477 369412	GALINA KISELEVA	{"email": "kiseleva.g-031981@postgrespro.ru", "phone": "+70596590743"}
0005434728763	4C4435	4697 133709	ANNA LOGINOVA	{"phone": "+70901639767"}
0005434728764	6063DF	5993 337959	PETR ANTONOV	{"email": "antonov_petr.14061971@postgrespro.ru", "phone": "+70058306653"}
0005434728765	6063DF	5088 882729	EKATERINA SAVELEVA	{"phone": "+70413913674"}
0005434728766	C5AA66	2531 008568	EVGENIY YAKOVLEV	{"email": "yakovlev_e.26121973@postgrespro.ru", "phone": "+70406009401"}
0005434728767	C5AA66	8489 516767	FEDOR SOLOVEV	{"email": "fsolovev_1975@postgrespro.ru", "phone": "+70141721418"}
0005434728768	8B07FF	5655 754460	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila_01071974@postgrespro.ru", "phone": "+70509710789"}
0005434728769	62DC85	8133 803990	KONSTANTIN STEPANOV	{"email": "k_stepanov_10121980@postgrespro.ru", "phone": "+70952915259"}
0005434728770	A2C547	6156 651635	GALINA MIKHAYLOVA	{"phone": "+70081307518"}
0005434728771	A658B0	0972 530855	LYUDMILA BELOVA	{"phone": "+70611090615"}
0005434728772	2E8190	2876 090156	EVGENIY GORBUNOV	{"email": "evgeniy-gorbunov-111971@postgrespro.ru", "phone": "+70350189636"}
0005434728773	42003F	0032 628899	ELENA ZAKHAROVA	{"phone": "+70284697775"}
0005434728774	8A26C5	2587 928802	GALINA VOLKOVA	{"phone": "+70383749669"}
0005434728775	746AAE	0117 091264	SERGEY DAVYDOV	{"phone": "+70478243815"}
0005434728776	3BF644	6942 979588	SVETLANA KARPOVA	{"email": "s.karpova_17061976@postgrespro.ru", "phone": "+70979685034"}
0005434728777	F3DC09	4451 402773	SERGEY ISAEV	{"email": "sergeyisaev_1967@postgrespro.ru", "phone": "+70454196250"}
0005434728778	64AAE1	6182 197548	ARTEM RODIONOV	{"email": "rodionov_artem.1976@postgrespro.ru", "phone": "+70359577419"}
0005434728779	64AAE1	0436 436655	IRINA KOLESNIKOVA	{"phone": "+70354693223"}
0005434728780	F6BF42	1215 813356	ILYA PETROV	{"phone": "+70719600918"}
0005434728781	7A66D7	5091 006290	SERGEY GERASIMOV	{"phone": "+70329311289"}
0005434728782	7A66D7	8996 558698	MIKHAIL BELOV	{"email": "belov.m_14011971@postgrespro.ru", "phone": "+70264775747"}
0005434728783	AAB6FD	9035 959249	OLGA OSIPOVA	{"phone": "+70449107676"}
0005434728784	AAB6FD	3977 660442	DMITRIY GORBUNOV	{"email": "d-gorbunov-11011969@postgrespro.ru", "phone": "+70868879428"}
0005434728785	AAB6FD	7139 736547	LILIYA RYABOVA	{"phone": "+70618301207"}
0005434728786	36CE2D	4240 100019	LEONID SHEVCHENKO	{"email": "shevchenko_leonid.27061977@postgrespro.ru", "phone": "+70371981886"}
0005434728787	36CE2D	8446 477469	SERGEY ANDREEV	{"phone": "+70031170409"}
0005434728788	E905E1	0053 301317	GALINA EGOROVA	{"email": "egorova-g_01071973@postgrespro.ru", "phone": "+70727998033"}
0005434728789	E905E1	4584 104235	YULIYA FEDOROVA	{"email": "fedorovay_091975@postgrespro.ru", "phone": "+70379198996"}
0005434728790	F3CC0A	9102 151724	MARINA ALEKSEEVA	{"phone": "+70263481533"}
0005434728791	8C3A95	7500 741990	LYUBOV LUKYANOVA	{"phone": "+70340945766"}
0005434728792	584A6D	1654 763352	OLGA LEBEDEVA	{"phone": "+70334173068"}
0005434728793	0B76E2	8909 464445	ALEKSEY ANDREEV	{"email": "alekseyandreev_091969@postgrespro.ru", "phone": "+70976292463"}
0005434728794	13F48F	2480 942011	EGOR OSIPOV	{"phone": "+70725077531"}
0005434728795	13F48F	5983 510179	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko_011980@postgrespro.ru", "phone": "+70880054011"}
0005434728796	E0BD8B	6545 956427	KLAVDIYA FEDOROVA	{"phone": "+70347910002"}
0005434728797	674CA5	8696 852875	VASILIY IVANOV	{"email": "ivanov_vasiliy-021974@postgrespro.ru", "phone": "+70738712489"}
0005434728798	B9BA00	0323 773923	LYUBOV FROLOVA	{"email": "froloval111971@postgrespro.ru", "phone": "+70157777358"}
0005434728799	B9BA00	3864 821790	MARIYA ROMANOVA	{"email": "romanovamariya_1973@postgrespro.ru", "phone": "+70306158246"}
0005434728800	B9BA00	4587 086321	YULIYA ROMANOVA	{"phone": "+70044185157"}
0005434728801	140603	6131 403130	LIDIYA STEPANOVA	{"email": "l_stepanova-121978@postgrespro.ru", "phone": "+70051314657"}
0005434728802	140603	8463 175326	OLEG KULIKOV	{"phone": "+70900007110"}
0005434728803	140603	3055 531792	ALEKSANDR KRASNOV	{"email": "aleksandrkrasnov_08051982@postgrespro.ru", "phone": "+70239540064"}
0005434728804	DD1F88	1585 141392	GENNADIY ZAKHAROV	{"email": "gzakharov_061990@postgrespro.ru", "phone": "+70822220588"}
0005434728805	DD1F88	1466 706242	OLESYA MOROZOVA	{"email": "morozova.o_041978@postgrespro.ru", "phone": "+70116982150"}
0005434728806	DD1F88	9053 145312	OLGA SMIRNOVA	{"email": "o.smirnova_20081960@postgrespro.ru", "phone": "+70159565994"}
0005434728807	F3EC31	1974 521899	VLADIMIR SOROKIN	{"email": "v_sorokin021973@postgrespro.ru", "phone": "+70378710641"}
0005434728808	F3EC31	4515 157654	SVETLANA MALYSHEVA	{"phone": "+70523205110"}
0005434728809	F3EC31	2940 433385	ANNA KALININA	{"email": "kalinina-a-051986@postgrespro.ru", "phone": "+70867039358"}
0005434728810	EEDF2D	5423 428222	MARIYA KONDRATEVA	{"email": "mariya-kondrateva.1968@postgrespro.ru", "phone": "+70106407743"}
0005434728811	F44B1F	5817 751308	GENNADIY MEDVEDEV	{"phone": "+70685163254"}
0005434728812	E25784	8625 430034	NIKOLAY FOMIN	{"email": "nikolayfomin-1972@postgrespro.ru", "phone": "+70029865934"}
0005434728813	E25784	6462 902848	MARINA KOROLEVA	{"email": "koroleva-marina1976@postgrespro.ru", "phone": "+70925282970"}
0005434728814	E25784	2135 590276	YURIY GRIGOREV	{"email": "grigorev-yuriy.12101960@postgrespro.ru", "phone": "+70724912514"}
0005434728815	0E9737	7233 886782	VALERIY ZAKHAROV	{"phone": "+70130299207"}
0005434728816	6FE6EB	5651 979722	IRINA AKIMOVA	{"email": "akimova-i20061962@postgrespro.ru", "phone": "+70751831069"}
0005434728817	6FE6EB	2828 578350	GENNADIY POPOV	{"phone": "+70758231203"}
0005434728818	C385B4	2555 096295	KIRILL NIKITIN	{"email": "nikitin_kirill-1966@postgrespro.ru", "phone": "+70993383340"}
0005434728819	B6B3AA	6996 994044	VITALIY ZAKHAROV	{"email": "v-zakharov.1960@postgrespro.ru", "phone": "+70131764764"}
0005434728820	F52E43	6700 497774	AMIR FILIPPOV	{"email": "a-filippov-10101968@postgrespro.ru", "phone": "+70240200464"}
0005434728821	F52E43	5045 661673	EVGENIYA AFANASEVA	{"phone": "+70963235701"}
0005434728822	98A8CD	3364 031746	OLESYA LUKYANOVA	{"phone": "+70392851493"}
0005434728823	98A8CD	7081 219595	MARINA VOLKOVA	{"phone": "+70440992564"}
0005434728824	F1F7F3	6172 867108	VLADIMIR NOVIKOV	{"phone": "+70750149044"}
0005434728825	F1F7F3	0945 224903	NATALIYA AFANASEVA	{"email": "afanaseva.n_071974@postgrespro.ru", "phone": "+70784996891"}
0005434728826	E016DF	7747 844127	ELENA KONDRATEVA	{"email": "e-kondrateva_101972@postgrespro.ru", "phone": "+70297726396"}
0005434728827	819478	1013 944575	TIGRAN NIKITIN	{"phone": "+70857888705"}
0005434728828	F48563	7006 491958	DMITRIY KOZLOV	{"phone": "+70476843521"}
0005434728829	8DDC61	0029 764699	KLIM SCHERBAKOV	{"phone": "+70283978165"}
0005434728830	840B6F	0865 754319	GLEB SHEVCHENKO	{"phone": "+70741458973"}
0005434728831	80134F	5149 564994	YULIYA EGOROVA	{"phone": "+70868496422"}
0005434728832	B40A3B	4380 667514	IGOR SOLOVEV	{"phone": "+70666069071"}
0005434728833	B40A3B	3009 892022	OLEG MEDVEDEV	{"email": "oleg.medvedev1973@postgrespro.ru", "phone": "+70800761638"}
0005434728834	A41F72	6913 903355	ANATOLIY STEPANOV	{"email": "stepanov.anatoliy.27021966@postgrespro.ru", "phone": "+70298844525"}
0005434728835	040162	9652 802039	OLGA MAKAROVA	{"email": "makarova.o-1973@postgrespro.ru", "phone": "+70506526367"}
0005434728836	040162	9857 605326	MARINA ANISIMOVA	{"phone": "+70916228957"}
0005434728837	FEA3E3	0598 675610	ZUKHRA TARASOVA	{"email": "tarasova_zukhra14071965@postgrespro.ru", "phone": "+70321864002"}
0005434728838	68EEDF	2035 362686	BORIS PETROV	{"phone": "+70263616767"}
0005434728839	F172C1	5419 724271	MAKSIM ALEKSEEV	{"email": "m_alekseev_091977@postgrespro.ru", "phone": "+70214468694"}
0005434728840	C2FC09	1803 906416	DMITRIY SMIRNOV	{"phone": "+70355353644"}
0005434728841	C2FC09	8789 154488	DENIS ZAYCEV	{"phone": "+70270859564"}
0005434728842	C0538D	8808 114157	ALEKSANDR ORLOV	{"email": "orlov-aleksandr_05071965@postgrespro.ru", "phone": "+70666884686"}
0005434728843	C0538D	6932 519682	VLADIMIR ZAYCEV	{"phone": "+70528137473"}
0005434728844	981E9A	4809 416627	DMITRIY SIDOROV	{"phone": "+70314833683"}
0005434728845	981E9A	1728 352943	GALINA PETROVA	{"phone": "+70005182822"}
0005434728846	981E9A	2803 740490	IGOR SEMENOV	{"phone": "+70660105082"}
0005434728847	B1784A	7577 126356	OLGA FOMINA	{"phone": "+70983387913"}
0005434728848	B1784A	7413 741978	TATYANA VOROBEVA	{"email": "tatyana.vorobeva.1975@postgrespro.ru", "phone": "+70641394636"}
0005434728849	249F6B	6882 456848	ELENA EGOROVA	{"phone": "+70114004636"}
0005434728850	249F6B	2363 282097	EVGENIY ABRAMOV	{"phone": "+70896632262"}
0005434728851	E86CBC	7443 909551	LIDIYA TROFIMOVA	{"email": "trofimoval.1976@postgrespro.ru", "phone": "+70645557353"}
0005434728852	7E70AA	6471 105234	OLGA KRASNOVA	{"email": "krasnova-olga-1970@postgrespro.ru", "phone": "+70598539407"}
0005434728853	668E81	3920 052328	ANASTASIYA ZAKHAROVA	{"email": "zakharova_a_31051972@postgrespro.ru", "phone": "+70300602654"}
0005434728854	47DD70	6167 723715	TAISIYA TARASOVA	{"email": "t.tarasova-06031982@postgrespro.ru", "phone": "+70337331801"}
0005434728855	A0F91D	5615 581481	VLADISLAV SOROKIN	{"email": "sorokin.vladislav1980@postgrespro.ru", "phone": "+70615611208"}
0005434728856	4FA015	5296 204452	ANASTASIYA SEMENOVA	{"email": "a_semenova-1971@postgrespro.ru", "phone": "+70587519392"}
0005434728857	31895F	0460 988820	ALEKSANDR CHERNOV	{"phone": "+70425528892"}
0005434728858	0CDE06	1355 836557	BORIS YAKOVLEV	{"phone": "+70760340769"}
0005434728859	638979	4488 930875	NINA FEDOROVA	{"phone": "+70676414546"}
0005434728860	638979	8148 471717	DANILA KONOVALOV	{"phone": "+70425110568"}
0005434728861	AB8CC1	4171 428642	EVGENIY TARASOV	{"phone": "+70293079597"}
0005434728862	69837D	6820 088513	ILYA NIKOLAEV	{"phone": "+70466462880"}
0005434728863	AB8244	7746 576211	ELENA PETROVA	{"email": "petrova.elena1972@postgrespro.ru", "phone": "+70022123532"}
0005434728864	814506	1432 441178	ALEKSANDR SMIRNOV	{"phone": "+70797044773"}
0005434728865	814506	5557 733412	ALEKSANDRA NAUMOVA	{"email": "aleksandra-naumova-13011986@postgrespro.ru", "phone": "+70657157045"}
0005434728866	4788CB	6584 848595	NINA SEMENOVA	{"email": "semenova.nina-1963@postgrespro.ru", "phone": "+70253438240"}
0005434728867	4788CB	6894 042603	NATALYA IVANOVA	{"phone": "+70484313247"}
0005434728868	CBC25B	0472 487569	ROMAN NIKOLAEV	{"email": "nikolaevr.091982@postgrespro.ru", "phone": "+70266362571"}
0005434728869	CBC25B	9069 012752	LIDIYA KOVALEVA	{"email": "lidiya_kovaleva1965@postgrespro.ru", "phone": "+70036533119"}
0005434728870	2E5C5F	8332 508539	TATYANA AFANASEVA	{"email": "tatyana.afanaseva.04041966@postgrespro.ru", "phone": "+70923979017"}
0005434728871	2E5C5F	7584 030959	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr1976@postgrespro.ru", "phone": "+70842539031"}
0005434728872	CBEEB0	2219 785840	MARAT ZAKHAROV	{"email": "marat-zakharov-1971@postgrespro.ru", "phone": "+70959853957"}
0005434728873	CBEEB0	4170 327035	ALEKSANDR KOROLEV	{"phone": "+70568444456"}
0005434728874	A5A00C	0007 369556	MAKSIM VLASOV	{"phone": "+70742423713"}
0005434728875	A5A00C	5721 019152	ANZHELIKA ZOTOVA	{"phone": "+70784065236"}
0005434728876	CF05AF	1478 473072	EVGENIY KRASNOV	{"email": "e.krasnov_061971@postgrespro.ru", "phone": "+70051216639"}
0005434728877	49B6CF	0523 848592	SVETLANA FROLOVA	{"email": "frolova_s_16061973@postgrespro.ru", "phone": "+70555255460"}
0005434728878	F5D517	4480 412195	VIKTOR ILIN	{"phone": "+70265731431"}
0005434728879	F5D517	8655 143847	SVETLANA KOLESNIKOVA	{"phone": "+70419510988"}
0005434728880	ABDF3D	0887 644430	TATYANA KOROLEVA	{"email": "t.koroleva.11021973@postgrespro.ru", "phone": "+70999423122"}
0005434728881	1C6AD9	5239 912477	ELINA AFANASEVA	{"email": "afanaseva_e1969@postgrespro.ru", "phone": "+70554192841"}
0005434728882	FD487C	6558 304385	TATYANA TITOVA	{"phone": "+70026320841"}
0005434728883	3B8F49	9758 877083	ROMAN EGOROV	{"phone": "+70823496528"}
0005434728884	6BA131	2489 504890	SERGEY TIKHONOV	{"phone": "+70177078079"}
0005434728885	6BA131	0038 183357	ALEKSANDR DAVYDOV	{"phone": "+70529723047"}
0005434728886	1FAF3F	9089 066122	ALBINA MELNIKOVA	{"phone": "+70098990553"}
0005434728887	2736B7	9050 804031	INNA LAZAREVA	{"email": "lazareva_inna_1981@postgrespro.ru", "phone": "+70552638593"}
0005434728888	259EC7	1731 097786	EVGENIY EGOROV	{"email": "egorove_1969@postgrespro.ru", "phone": "+70798796900"}
0005434728889	2ECBD4	1936 044736	OLGA GUSEVA	{"phone": "+70277261484"}
0005434728890	C26E04	2876 816136	LYUBOV SMIRNOVA	{"email": "smirnova_lyubov11011975@postgrespro.ru", "phone": "+70018675874"}
0005434728891	C26E04	4263 303225	VIKTORIYA SOROKINA	{"email": "sorokina_viktoriya_031975@postgrespro.ru", "phone": "+70298309791"}
0005434728892	C26E04	0164 868449	DANILA MEDVEDEV	{"phone": "+70580996836"}
0005434728893	FCE542	1196 989654	MIKHAIL MEDVEDEV	{"phone": "+70624011763"}
0005434728894	FCE542	1631 469581	KRISTINA ZAYCEVA	{"email": "zayceva.k-1967@postgrespro.ru", "phone": "+70099536588"}
0005434728895	FCE542	0644 259255	DARYA ALEKSEEVA	{"email": "alekseeva.darya.24071981@postgrespro.ru", "phone": "+70101607707"}
0005434728896	C19934	0740 144951	GALINA SOKOLOVA	{"email": "sokolovagalina-1975@postgrespro.ru", "phone": "+70188050423"}
0005434728897	9BDD3D	2265 441835	YURIY SCHERBAKOV	{"email": "scherbakovyuriy-08061973@postgrespro.ru", "phone": "+70375914243"}
0005434728898	9BDD3D	8745 888046	YANA FROLOVA	{"phone": "+70291730051"}
0005434728899	808281	0016 748841	DMITRIY SIDOROV	{"email": "sidorovdmitriy.1981@postgrespro.ru", "phone": "+70683764702"}
0005434728900	E76368	5411 120207	DANILA IVANOV	{"email": "ivanov-danila-22101977@postgrespro.ru", "phone": "+70625790529"}
0005434728901	61365E	9237 923378	KLAVDIYA DENISOVA	{"email": "denisovak_121975@postgrespro.ru", "phone": "+70928101601"}
0005434728902	ECDD9F	6400 168045	VYACHESLAV SCHERBAKOV	{"phone": "+70629334618"}
0005434728903	ECDD9F	5160 179250	ELIZAVETA ZAYCEVA	{"phone": "+70774230354"}
0005434728904	170334	5408 453596	TATYANA KONDRATEVA	{"email": "kondrateva-tatyana_031993@postgrespro.ru", "phone": "+70916647068"}
0005434728905	170334	3683 738214	ANTONINA POPOVA	{"email": "popova_antonina_1972@postgrespro.ru", "phone": "+70265334348"}
0005434728906	7FA282	1835 357439	LEV SIDOROV	{"email": "sidorovlev_061967@postgrespro.ru", "phone": "+70819551191"}
0005434728907	7FA282	5600 052684	SERGEY FEDOTOV	{"phone": "+70681505864"}
0005434728908	C7FDD8	0051 884495	YULIYA OSIPOVA	{"email": "y.osipova-1965@postgrespro.ru", "phone": "+70090637577"}
0005434728909	DC4011	4760 664944	SERGEY BORISOV	{"phone": "+70915167540"}
0005434728910	DC4011	4069 839135	MATVEY OSIPOV	{"email": "mosipov11031974@postgrespro.ru", "phone": "+70433254222"}
0005434728911	4FD761	5457 492583	ALEKSANDR BONDARENKO	{"phone": "+70573951519"}
0005434728912	419795	4170 709671	ALEKSEY KARPOV	{"phone": "+70161894016"}
0005434728913	42B962	9184 068519	VITALIY IVANOV	{"phone": "+70291063767"}
0005434728914	492621	3193 516893	VIKTOR ZAKHAROV	{"phone": "+70270640591"}
0005434728915	492621	1481 402960	VLADIMIR DENISOV	{"phone": "+70152068937"}
0005434728916	71A615	7514 186973	MARINA SAVELEVA	{"phone": "+70932857971"}
0005434728917	C43ED0	0551 230384	MARINA ABRAMOVA	{"email": "marinaabramova.07051973@postgrespro.ru", "phone": "+70956084685"}
0005434728918	C43ED0	6877 597653	ZOYA ABRAMOVA	{"email": "abramova.zoya_27101971@postgrespro.ru", "phone": "+70393759198"}
0005434728919	F2FD30	7827 571210	ALEVTINA SIDOROVA	{"phone": "+70001222605"}
0005434728920	F2FD30	5193 426556	ALEKSANDRA KAZAKOVA	{"phone": "+70093815961"}
0005434728921	F2FD30	9416 629193	GALINA TIMOFEEVA	{"phone": "+70906135700"}
0005434728922	F75D27	9663 519949	ELENA GUSEVA	{"email": "e_guseva011967@postgrespro.ru", "phone": "+70557140021"}
0005434728923	F75D27	6994 329249	MARIYA BELYAEVA	{"phone": "+70179689066"}
0005434728924	D966C3	6653 300600	LEONID ABRAMOV	{"email": "leonid-abramov-1970@postgrespro.ru", "phone": "+70874703903"}
0005434728925	D966C3	1507 611138	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov_071968@postgrespro.ru", "phone": "+70545312362"}
0005434728926	D966C3	5023 330292	IGOR STEPANOV	{"email": "i-stepanov_29031970@postgrespro.ru", "phone": "+70213856811"}
0005434728927	D6C6D7	7356 076631	SERGEY KUZNECOV	{"email": "kuznecov-s.23011961@postgrespro.ru", "phone": "+70980448715"}
0005434728928	0FA88B	9017 546341	DMITRIY FEDOTOV	{"email": "fedotov_dmitriy.031979@postgrespro.ru", "phone": "+70930246214"}
0005434728929	5B8517	5623 839108	VITALIY MOROZOV	{"phone": "+70792113423"}
0005434728930	425241	7639 016578	SVETLANA SOLOVEVA	{"email": "s-soloveva-031973@postgrespro.ru", "phone": "+70419314466"}
0005434728931	32260A	3811 817016	IRINA TIKHONOVA	{"email": "tikhonova-i011977@postgrespro.ru", "phone": "+70108509260"}
0005434728932	F5B730	1869 636446	ULYANA BOGDANOVA	{"phone": "+70098167364"}
0005434728933	9661F8	1622 087785	GALINA MIRONOVA	{"phone": "+70680070829"}
0005434728934	9661F8	1191 668459	EVGENIY TARASOV	{"email": "evgeniytarasov_27061973@postgrespro.ru", "phone": "+70219819886"}
0005434728935	F30EEE	0090 258626	VASILIY DAVYDOV	{"phone": "+70765697096"}
0005434728936	38EAB5	5871 909679	NATALYA RYABOVA	{"phone": "+70523659468"}
0005434728937	61342B	9540 998934	LYUBOV PETROVA	{"email": "petrova-l_1973@postgrespro.ru", "phone": "+70072111314"}
0005434728938	61342B	7126 435452	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr.021969@postgrespro.ru", "phone": "+70003036063"}
0005434728939	56565D	4962 760925	VYACHESLAV GORBUNOV	{"email": "v_gorbunov-22051962@postgrespro.ru", "phone": "+70803768946"}
0005434728940	D54582	5031 381855	OLGA BARANOVA	{"phone": "+70668375239"}
0005434728941	A0C7C2	4205 007268	SOFYA ANTONOVA	{"email": "antonova_sofya.27071968@postgrespro.ru", "phone": "+70101437795"}
0005434728942	A0C7C2	3249 118447	VADIM ORLOV	{"email": "orlov.vadim-1961@postgrespro.ru", "phone": "+70033866954"}
0005434728943	CFFB14	8744 236139	LYUDMILA FROLOVA	{"email": "lyudmila.frolova.061979@postgrespro.ru", "phone": "+70816750785"}
0005434728944	F25B38	8549 133484	ANDREY MELNIKOV	{"email": "andrey_melnikov_091972@postgrespro.ru", "phone": "+70806324416"}
0005434728945	F25B38	7149 931603	GUZEL NIKIFOROVA	{"phone": "+70058399963"}
0005434728946	A46C47	7277 879133	ELENA GUSEVA	{"email": "elenaguseva1973@postgrespro.ru", "phone": "+70169652807"}
0005434728947	F326E7	7382 491276	EKATERINA ZHUKOVA	{"email": "zhukova-ekaterina.1967@postgrespro.ru", "phone": "+70161913781"}
0005434728948	F6F087	7494 848687	PETR KOZLOV	{"phone": "+70123117088"}
0005434728949	88FDB0	2239 178866	VIKTOR ORLOV	{"phone": "+70694497724"}
0005434728950	88FDB0	3833 396109	LARISA EGOROVA	{"email": "egorova_l.101971@postgrespro.ru", "phone": "+70340070430"}
0005434728951	1FE0F2	6081 059033	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev.091978@postgrespro.ru", "phone": "+70182349306"}
0005434728952	D623DD	6714 179341	EVGENIY KUZNECOV	{"phone": "+70187193906"}
0005434728953	D623DD	1776 807769	SERGEY ANTONOV	{"email": "antonov.sergey_01051971@postgrespro.ru", "phone": "+70615467706"}
0005434728954	CBB58D	3745 260925	ILYA NAUMOV	{"email": "ilya_naumov-081976@postgrespro.ru", "phone": "+70743483784"}
0005434728955	CBB58D	6277 586284	KIRILL ALEKSANDROV	{"email": "aleksandrov.k_091972@postgrespro.ru", "phone": "+70407524266"}
0005434728956	00176F	0768 996899	MIKHAIL ANDREEV	{"phone": "+70621831672"}
0005434728957	899B64	5685 514468	ANDREY ILIN	{"email": "andrey_ilin-06121972@postgrespro.ru", "phone": "+70528385679"}
0005434728958	899B64	9084 919439	NATALYA KONOVALOVA	{"email": "konovalova_n_1977@postgrespro.ru", "phone": "+70304447485"}
0005434728959	A7B367	1050 766197	ANATOLIY ABRAMOV	{"phone": "+70199253979"}
0005434728960	8B5584	0724 083353	NATALYA ROMANOVA	{"email": "romanova-natalya.1979@postgrespro.ru", "phone": "+70870885801"}
0005434728961	F0514E	3895 258933	DENIS MOROZOV	{"phone": "+70397561929"}
0005434728962	8DB79D	6384 885169	VALENTINA DANILOVA	{"email": "danilovavalentina_23071979@postgrespro.ru", "phone": "+70528388344"}
0005434728963	8DB79D	1973 398482	ELENA MOISEEVA	{"email": "moiseeva.elena-1969@postgrespro.ru", "phone": "+70540930931"}
0005434728964	BF22B4	5483 367341	OLEG MOROZOV	{"email": "morozov.o-101975@postgrespro.ru", "phone": "+70728608776"}
0005434728965	76195D	5140 356173	ANDREY ANTONOV	{"phone": "+70151227490"}
0005434728966	76195D	5002 867568	TATYANA SIDOROVA	{"email": "sidorovat.061973@postgrespro.ru", "phone": "+70362131593"}
0005434728967	461B51	3851 719007	NIKOLAY MAKAROV	{"email": "nikolay.makarov.05031974@postgrespro.ru", "phone": "+70760069392"}
0005434728968	461B51	3473 545147	ANNA KUDRYASHOVA	{"email": "anna_kudryashova-031973@postgrespro.ru", "phone": "+70049020225"}
0005434728969	E34F74	1401 715438	TATYANA KUDRYASHOVA	{"email": "kudryashovatatyana_071970@postgrespro.ru", "phone": "+70337580181"}
0005434728970	E34F74	1035 500810	DIANA BARANOVA	{"phone": "+70151270601"}
0005434728971	3B7ED3	1828 401070	OKSANA KUZMINA	{"email": "oksana-kuzmina1975@postgrespro.ru", "phone": "+70935689119"}
0005434728972	334B55	2741 829229	PETR FEDOROV	{"email": "p-fedorov_23071980@postgrespro.ru", "phone": "+70817401810"}
0005434728973	334B55	2604 778376	RAMIL KUZMIN	{"phone": "+70599885538"}
0005434728974	A15038	7313 536006	KRISTINA SIDOROVA	{"phone": "+70569375266"}
0005434728975	D7F254	1579 600654	DMITRIY MATVEEV	{"phone": "+70650943609"}
0005434728976	9B8266	2594 077974	ANNA ISAEVA	{"email": "a.isaeva_14101976@postgrespro.ru", "phone": "+70811204666"}
0005434728977	2192D8	2197 896201	VASILIY MAKAROV	{"phone": "+70066195303"}
0005434728978	BA6E16	3703 132156	LYUDMILA NAUMOVA	{"email": "naumova.l_26101980@postgrespro.ru", "phone": "+70001943197"}
0005434728979	010D69	6573 946760	ALEKSEY KULIKOV	{"phone": "+70962753828"}
0005434728980	010D69	4576 740691	VALENTINA PETROVA	{"email": "petrovav_15041982@postgrespro.ru", "phone": "+70401457644"}
0005434728981	010D69	0677 783773	MIKHAIL SIDOROV	{"email": "sidorov_mikhail_1976@postgrespro.ru", "phone": "+70851904642"}
0005434728982	47408C	4724 080712	ALEKSANDR ILIN	{"phone": "+70623259968"}
0005434728983	1AB758	1282 798236	ALEKSEY SMIRNOV	{"email": "smirnovaleksey-1965@postgrespro.ru", "phone": "+70285212663"}
0005434728984	BE2634	9085 378196	EKATERINA ZAKHAROVA	{"email": "e.zakharova-101985@postgrespro.ru", "phone": "+70713106122"}
0005434728985	26FCA9	5893 897922	MARIYA IVANOVA	{"phone": "+70718745132"}
0005434728986	E3E5D6	9297 467352	SERGEY DENISOV	{"phone": "+70628917043"}
0005434728987	76B08F	6739 100300	ARTEM IVANOV	{"email": "ivanova_03071978@postgrespro.ru", "phone": "+70647679743"}
0005434728988	0CA4A5	5903 571994	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov_vyacheslav-1974@postgrespro.ru", "phone": "+70622142737"}
0005434728989	0CA4A5	3786 728232	VIKTORIYA STEPANOVA	{"email": "stepanova_viktoriya_1979@postgrespro.ru", "phone": "+70308746736"}
0005434728990	D1319B	2490 990130	OLGA KARPOVA	{"email": "karpova_olga.101973@postgrespro.ru", "phone": "+70799096929"}
0005434728991	D1319B	9109 741051	GENNADIY SOLOVEV	{"phone": "+70365259672"}
0005434728992	3BF905	7816 805525	SERGEY SHEVCHENKO	{"phone": "+70584561370"}
0005434728993	3BF905	8535 933875	FEDOR BELOV	{"email": "belovf-28121974@postgrespro.ru", "phone": "+70245312565"}
0005434728994	E0DA9D	9892 971320	EVGENIY MEDVEDEV	{"email": "medvedeve_14041965@postgrespro.ru", "phone": "+70825291892"}
0005434728995	9820A5	5408 329594	MARGARITA EFREMOVA	{"phone": "+70473518682"}
0005434728996	E597AB	3686 621728	SERGEY ANDREEV	{"email": "sandreev_071984@postgrespro.ru", "phone": "+70891487961"}
0005434728997	5B7909	7698 427384	ELIZAVETA SMIRNOVA	{"phone": "+70512598885"}
0005434728998	F177FF	3910 186165	ELENA KUZNECOVA	{"email": "ekuznecova_12041972@postgrespro.ru", "phone": "+70963949030"}
0005434728999	B071E6	9731 042738	IVAN EGOROV	{"email": "egorov-ivan051967@postgrespro.ru", "phone": "+70286628056"}
0005434729000	154E1D	7587 492678	ELENA CHERNOVA	{"phone": "+70582657848"}
0005434729001	44D786	0695 830754	ELVIRA PETROVA	{"email": "elvira-petrova.041967@postgrespro.ru", "phone": "+70966095171"}
0005434729002	44D786	5670 638520	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_g-27041973@postgrespro.ru", "phone": "+70563683775"}
0005434729003	0A7AF8	6021 773281	LYUBOV ANDREEVA	{"email": "lyubov.andreeva031974@postgrespro.ru", "phone": "+70610623709"}
0005434729004	24EA8D	1184 166831	ANTON NIKOLAEV	{"phone": "+70597219309"}
0005434729005	42FDD7	7922 211504	EKATERINA PETROVA	{"email": "petrova_ekaterina.1963@postgrespro.ru", "phone": "+70717993520"}
0005434729006	42FDD7	0759 908951	MARIYA KUZNECOVA	{"email": "kuznecova_m_081974@postgrespro.ru", "phone": "+70384666531"}
0005434729007	42FDD7	9924 457665	VLADIMIR SAVELEV	{"phone": "+70664802243"}
0005434729008	36A18B	9934 456232	VALERIY KOROLEV	{"phone": "+70115404725"}
0005434729009	2C5704	7755 933023	ARTEM ZAKHAROV	{"email": "zakharovartem22041959@postgrespro.ru", "phone": "+70255851623"}
0005434729010	2C5704	3110 885685	TATYANA PAVLOVA	{"email": "pavlova.t-05101971@postgrespro.ru", "phone": "+70739808466"}
0005434729011	01FEB3	6924 143681	GALINA KOMAROVA	{"email": "galinakomarova.101963@postgrespro.ru", "phone": "+70786696140"}
0005434729012	48F596	0174 664755	YAKOV VLASOV	{"email": "vlasov-yakov_021960@postgrespro.ru", "phone": "+70753405222"}
0005434729013	6B9BAC	8580 548613	DMITRIY FOMIN	{"email": "fomin.dmitriy-061972@postgrespro.ru", "phone": "+70854213709"}
0005434729014	ABA22A	0400 650184	DANILA MOROZOV	{"phone": "+70638419746"}
0005434729015	747036	9925 256982	ELENA KAZAKOVA	{"phone": "+70414694010"}
0005434729016	56FEA5	5975 686206	STANISLAV RODIONOV	{"phone": "+70576191409"}
0005434729017	56FEA5	4701 367586	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva111975@postgrespro.ru", "phone": "+70860071417"}
0005434729018	D8A736	2674 896632	PRASKOVYA KARPOVA	{"email": "p.karpova.1981@postgrespro.ru", "phone": "+70235645531"}
0005434729019	D8A736	2091 637513	LARISA BARANOVA	{"phone": "+70160884864"}
0005434729020	AF143B	3757 896073	NIKITA ILIN	{"phone": "+70771377201"}
0005434729021	AF143B	5016 673253	SERGEY FEDOTOV	{"email": "sergey.fedotov_051964@postgrespro.ru", "phone": "+70392413308"}
0005434729022	8E7FA5	0879 563937	OLGA NIKOLAEVA	{"phone": "+70656022459"}
0005434729023	8E7FA5	3653 860861	VLADIMIR GRIGOREV	{"phone": "+70123963401"}
0005434729024	FDA0AB	8125 161434	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr_05081972@postgrespro.ru", "phone": "+70715563704"}
0005434729025	EB4E9B	6767 021988	GALINA FOMINA	{"phone": "+70070611409"}
0005434729026	6CC6C9	5639 192803	ANNA STEPANOVA	{"phone": "+70260269066"}
0005434729027	C609AD	0478 374847	ALEKSEY KUZNECOV	{"phone": "+70714284629"}
0005434729028	C609AD	7487 878892	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov-1976@postgrespro.ru", "phone": "+70735443584"}
0005434729029	A445A5	7028 493433	LYUBOV IVANOVA	{"email": "l.ivanova-1970@postgrespro.ru", "phone": "+70062717971"}
0005434729030	91272F	0429 137867	KONSTANTIN ISAEV	{"phone": "+70348889558"}
0005434729031	91272F	7560 861262	SERGEY ANTONOV	{"phone": "+70872465988"}
0005434729032	659D73	7921 787567	PAVEL SOKOLOV	{"email": "p_sokolov16121975@postgrespro.ru", "phone": "+70353920525"}
0005434729033	659D73	7825 458784	TATYANA PETROVA	{"email": "petrova_tatyana_1964@postgrespro.ru", "phone": "+70214060835"}
0005434729034	344DD1	9956 442508	SHAMIL GERASIMOV	{"email": "gerasimovshamil031974@postgrespro.ru", "phone": "+70258191543"}
0005434729035	344DD1	3239 425708	ALEKSEY MAKAROV	{"email": "aleksey_makarov.1978@postgrespro.ru", "phone": "+70264671668"}
0005434729036	C88571	3196 199906	ALEKSANDR DAVYDOV	{"email": "davydov_aleksandr-011966@postgrespro.ru", "phone": "+70227509936"}
0005434729037	C88571	6714 887380	ALENA RODIONOVA	{"phone": "+70774741935"}
0005434729038	B04FD3	7516 546242	NADEZHDA KONOVALOVA	{"email": "konovalovanadezhda_101973@postgrespro.ru", "phone": "+70766208041"}
0005434729039	677B68	8120 753015	IGOR ZAKHAROV	{"email": "i.zakharov_121972@postgrespro.ru", "phone": "+70446124739"}
0005434729040	589196	3563 697905	TATYANA NIKOLAEVA	{"phone": "+70077496117"}
0005434729041	B7C3FD	3558 704074	VSEVOLOD POPOV	{"email": "v_popov-16111973@postgrespro.ru", "phone": "+70098524746"}
0005434729042	B7C3FD	6761 362821	YURIY SMIRNOV	{"phone": "+70559246422"}
0005434729043	698633	6393 848994	VLADIMIR FEDOROV	{"phone": "+70935336351"}
0005434729044	698633	9520 499923	NATALIYA GAVRILOVA	{"email": "gavrilova_n011984@postgrespro.ru", "phone": "+70798786903"}
0005434729045	0F0114	4246 728063	TAISIYA MIRONOVA	{"phone": "+70197036107"}
0005434729046	DF4B75	4787 869873	YURIY SMIRNOV	{"email": "smirnov_yuriy_23091966@postgrespro.ru", "phone": "+70997921930"}
0005434729047	770493	6724 605756	NADEZHDA ZAYCEVA	{"phone": "+70118706800"}
0005434729048	770493	7825 829080	ALEKSEY KRASNOV	{"phone": "+70145538832"}
0005434729049	2985E5	2742 613041	LIDIYA VLASOVA	{"phone": "+70610703049"}
0005434729050	10E025	6500 563555	VERA VOLKOVA	{"phone": "+70894160677"}
0005434729051	10E025	7134 791682	GENNADIY SHEVCHENKO	{"phone": "+70487576921"}
0005434729052	C5721D	5137 806218	VLADISLAV ANDREEV	{"email": "v-andreev1970@postgrespro.ru", "phone": "+70914744119"}
0005434729053	3F9932	1730 317498	KSENIYA FILIPPOVA	{"phone": "+70529384989"}
0005434729054	82C5D9	9245 033814	VYACHESLAV NIKOLAEV	{"email": "vyacheslav_nikolaev.061979@postgrespro.ru", "phone": "+70299180128"}
0005434729055	72F5B4	4870 019367	IGOR ISAEV	{"email": "igorisaev_061971@postgrespro.ru", "phone": "+70972867856"}
0005434729056	72F5B4	5514 931058	ANASTASIYA FEDOROVA	{"phone": "+70007153882"}
0005434729057	72F5B4	8211 598288	GUZEL NOVIKOVA	{"email": "novikova-guzel.081978@postgrespro.ru", "phone": "+70000331412"}
0005434729058	E1911B	4454 499241	FANIL TIMOFEEV	{"phone": "+70862612954"}
0005434731142	413BDC	5452 695145	DMITRIY GRIGOREV	{"phone": "+70240021528"}
0005434731117	3EE7B6	5428 482707	ANASTASIYA FOMINA	{"phone": "+70703399004"}
0005434731096	EE314F	7347 185711	DMITRIY SCHERBAKOV	{"phone": "+70583576046"}
0005434731097	8363E5	8601 220722	ANDREY PETROV	{"phone": "+70876099593"}
0005434731098	CA287C	2219 512763	LYUDMILA POTAPOVA	{"phone": "+70148749532"}
0005434731099	EDD84C	2732 001441	NIKOLAY BARANOV	{"email": "baranov-n_17031971@postgrespro.ru", "phone": "+70243969191"}
0005434731100	0DF3E5	1114 808963	EVGENIY PAVLOV	{"phone": "+70485019771"}
0005434731101	F30420	3288 106507	TATYANA FADEEVA	{"email": "tatyana-fadeeva.091963@postgrespro.ru", "phone": "+70700542962"}
0005434731102	F30420	6985 106174	SVETLANA LEBEDEVA	{"phone": "+70605167395"}
0005434731103	2B016A	3027 341344	MIKHAIL RODIONOV	{"phone": "+70299187097"}
0005434731104	15FEF1	7222 681753	ALEKSEY KOROLEV	{"phone": "+70260467780"}
0005434731105	C4D9D8	8513 665492	DMITRIY NIKOLAEV	{"phone": "+70033032556"}
0005434731106	5AA051	8133 201704	ROMAN YAKOVLEV	{"phone": "+70150716353"}
0005434731107	4EB1E4	1681 769434	MARIYA EFIMOVA	{"phone": "+70966486165"}
0005434731108	B7F583	9244 508364	TATYANA PETROVA	{"phone": "+70997552698"}
0005434731109	71F088	8164 029414	TAMARA VLASOVA	{"phone": "+70672919234"}
0005434731110	71F088	5880 590556	ARSENIY GUSEV	{"email": "agusev-101980@postgrespro.ru", "phone": "+70300782767"}
0005434731111	A84435	9928 205433	NADEZHDA YAKOVLEVA	{"email": "nadezhdayakovleva1973@postgrespro.ru", "phone": "+70736509587"}
0005434731112	C91C23	6089 882959	MARINA BELOVA	{"phone": "+70296256913"}
0005434731113	393951	5453 463921	TATYANA OVCHINNIKOVA	{"phone": "+70044119252"}
0005434731114	37C421	4330 187045	NADEZHDA FOMINA	{"phone": "+70286598362"}
0005434731115	37C421	3808 620961	MIKHAIL SOKOLOV	{"email": "sokolovm051970@postgrespro.ru", "phone": "+70400615949"}
0005434731116	7AE0FA	6474 870877	IRINA SOROKINA	{"phone": "+70461535357"}
0005434731118	1C9157	4214 831385	ALEKSANDRA NOVIKOVA	{"phone": "+70300634226"}
0005434731119	2C637C	0532 815622	VITALIY KARPOV	{"phone": "+70668135421"}
0005434731120	698826	7390 137163	SERGEY MOROZOV	{"email": "morozovsergey-07101970@postgrespro.ru", "phone": "+70246035792"}
0005434731121	D446F4	0477 091677	VLADIMIR FROLOV	{"phone": "+70298203580"}
0005434731122	5DACE7	4515 423914	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov101972@postgrespro.ru", "phone": "+70726878557"}
0005434731123	6798EA	0157 567822	TATYANA GRISHINA	{"phone": "+70397476952"}
0005434731124	6798EA	7149 630331	GALINA SERGEEVA	{"email": "sergeevagalina121975@postgrespro.ru", "phone": "+70465620474"}
0005434731125	62EC63	3947 890805	MARIYA MEDVEDEVA	{"phone": "+70604897606"}
0005434731126	093CC6	0653 591873	LYUDMILA PAVLOVA	{"phone": "+70545054123"}
0005434731127	6F9EAF	6436 685835	MIKHAIL KUZMIN	{"email": "m-kuzmin-1965@postgrespro.ru", "phone": "+70326680594"}
0005434731128	0C3E81	5726 463903	VLADIMIR GORBUNOV	{"phone": "+70233252157"}
0005434731129	60DFE3	6634 221217	EKATERINA SOKOLOVA	{"email": "e.sokolova-1980@postgrespro.ru", "phone": "+70522203488"}
0005434731130	B5BDD4	5832 918877	EVGENIY SAVELEV	{"phone": "+70169138460"}
0005434731131	B0D06B	6284 304712	NADEZHDA ALEKSEEVA	{"email": "n.alekseeva.061967@postgrespro.ru", "phone": "+70908690674"}
0005434731132	BA4B85	6522 749008	ANDREY GAVRILOV	{"email": "andreygavrilov.121972@postgrespro.ru", "phone": "+70840130878"}
0005434731133	7F33E6	6012 233033	ANTON ANDREEV	{"email": "andreev-a021971@postgrespro.ru", "phone": "+70600658666"}
0005434731134	7F33E6	3725 394682	ANNA FILIPPOVA	{"email": "filippova_anna1976@postgrespro.ru", "phone": "+70933515057"}
0005434731135	A61FCD	5009 345698	ANATOLIY TIMOFEEV	{"email": "anatoliy-timofeev.111976@postgrespro.ru", "phone": "+70143692544"}
0005434731136	A61FCD	7907 967820	DMITRIY DMITRIEV	{"phone": "+70190040593"}
0005434731137	DDB829	2447 248340	REGINA ZAKHAROVA	{"email": "r_zakharova1975@postgrespro.ru", "phone": "+70218099679"}
0005434731138	F63202	7949 254415	YULIYA ABRAMOVA	{"phone": "+70415493721"}
0005434731139	C95527	4506 808776	TATYANA KAZAKOVA	{"phone": "+70393165705"}
0005434731140	15A8E8	0194 413817	ANNA ZHUKOVA	{"phone": "+70111502394"}
0005434731141	CBB9AD	2383 055860	ALEKSEY KUZMIN	{"phone": "+70261329811"}
0005434731143	D9F216	7539 914222	IRINA FILATOVA	{"email": "filatovai_081959@postgrespro.ru", "phone": "+70593565879"}
0005434731144	D9F216	0680 867028	OLGA EGOROVA	{"email": "o_egorova_121975@postgrespro.ru", "phone": "+70860795725"}
0005434731145	1056D5	3026 489878	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir_11121960@postgrespro.ru", "phone": "+70733756643"}
0005434731146	6DA6E8	6726 448485	ALEKSANDR MIKHAYLOV	{"phone": "+70388602475"}
0005434731147	7F91BE	2344 529502	OLGA KUZNECOVA	{"phone": "+70914167579"}
0005434731148	A5774B	7163 752952	YURIY NIKOLAEV	{"phone": "+70850731269"}
0005434731149	A5774B	3431 219127	SERGEY CHERNOV	{"email": "sergey-chernov28021973@postgrespro.ru", "phone": "+70542189470"}
0005434731150	A5774B	1865 521115	GEORGIY KUZNECOV	{"email": "kuznecovgeorgiy_1968@postgrespro.ru", "phone": "+70952556440"}
0005434731151	D556DD	7422 664845	DANIIL ZAYCEV	{"email": "d-zaycev-19081972@postgrespro.ru", "phone": "+70994476566"}
0005434731152	C519C1	4350 208889	LIDIYA MATVEEVA	{"phone": "+70824542407"}
0005434731153	FCC764	0688 789089	MILANA KUZNECOVA	{"email": "milanakuznecova.121980@postgrespro.ru", "phone": "+70268117888"}
0005434731154	910131	7204 051367	ANASTASIYA KAZAKOVA	{"email": "kazakova.a-1974@postgrespro.ru", "phone": "+70748624109"}
0005434731155	F56308	5872 464129	MARIYA VOLKOVA	{"email": "volkova.m1982@postgrespro.ru", "phone": "+70398536680"}
0005434731156	9242E9	1535 177965	LYUBOV VLASOVA	{"phone": "+70450976440"}
0005434731157	B24FB9	7824 547431	VALENTINA LOGINOVA	{"email": "loginova-valentina.011985@postgrespro.ru", "phone": "+70110616658"}
0005434731158	191F54	3004 446245	LIDIYA TIKHONOVA	{"email": "l.tikhonova15061983@postgrespro.ru", "phone": "+70402839534"}
0005434731159	191F54	3015 296156	ELENA SOLOVEVA	{"email": "solovevaelena061972@postgrespro.ru", "phone": "+70510284001"}
0005434731160	78D644	2033 253136	IGOR POPOV	{"email": "i_popov.1969@postgrespro.ru", "phone": "+70957156130"}
0005434731161	635D7D	3990 607575	GALINA KISELEVA	{"email": "galina.kiseleva-1971@postgrespro.ru", "phone": "+70301342810"}
0005434731162	635D7D	4475 734561	SERGEY ANDREEV	{"email": "andreev.s-29041969@postgrespro.ru", "phone": "+70537770209"}
0005434731163	F273FB	5771 378378	EVGENIY NAZAROV	{"phone": "+70978369567"}
0005434731164	F273FB	2657 627001	VERA ZAKHAROVA	{"phone": "+70015757098"}
0005434731165	F273FB	7295 617662	NIKITA SCHERBAKOV	{"phone": "+70460820911"}
0005434731166	C88287	5840 359124	TATYANA MOISEEVA	{"phone": "+70915718027"}
0005434731167	225CF3	0042 847190	VLADIMIR DAVYDOV	{"phone": "+70440497608"}
0005434731168	225CF3	1406 860331	LYUDMILA NAZAROVA	{"email": "lnazarova-10011979@postgrespro.ru", "phone": "+70312767423"}
0005434731169	D8C4A7	8779 950995	TATYANA AKIMOVA	{"email": "t.akimova.1970@postgrespro.ru", "phone": "+70578458393"}
0005434731170	8DA536	2916 836507	ANASTASIYA TITOVA	{"phone": "+70697095071"}
0005434731171	FDB5A2	9326 572046	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr.1970@postgrespro.ru", "phone": "+70363384416"}
0005434731172	FDB5A2	1521 289731	VLADISLAV NIKOLAEV	{"phone": "+70273426918"}
0005434731173	B8C278	2997 983343	FEDOR KUZNECOV	{"phone": "+70648545489"}
0005434731174	5B85DE	9065 550154	RAIS BELOV	{"phone": "+70711143407"}
0005434731175	0E891F	9219 717398	DARYA FEDOROVA	{"email": "fedorova_darya_03021960@postgrespro.ru", "phone": "+70674068582"}
0005434731176	0E891F	1292 126378	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr.30101979@postgrespro.ru", "phone": "+70318109066"}
0005434731177	49858E	6505 306091	MIKHAIL VOROBEV	{"email": "vorobev-mikhail1980@postgrespro.ru", "phone": "+70381241009"}
0005434731178	49858E	0697 837195	SVETLANA KUZNECOVA	{"email": "svetlanakuznecova20081970@postgrespro.ru", "phone": "+70008260676"}
0005434731179	A445F4	7509 300056	ALINA MAKSIMOVA	{"email": "amaksimova_1983@postgrespro.ru", "phone": "+70457841906"}
0005434731180	C7D9F6	9611 482727	NATALYA KUDRYASHOVA	{"email": "natalya_kudryashova-031981@postgrespro.ru", "phone": "+70417878173"}
0005434731181	8CF4EC	0798 962022	DMITRIY MAKSIMOV	{"email": "maksimov.dmitriy1968@postgrespro.ru", "phone": "+70210871837"}
0005434731182	8CF4EC	2539 631264	IVAN MELNIKOV	{"phone": "+70678430545"}
0005434731183	8CF4EC	4368 194571	PAVEL GUSEV	{"phone": "+70425780965"}
0005434731184	4092C7	8900 802438	NATALYA KISELEVA	{"email": "n.kiseleva.1980@postgrespro.ru", "phone": "+70685956118"}
0005434731185	FEE118	2712 100479	MAKSIM IVANOV	{"email": "maksim-ivanov.26011972@postgrespro.ru", "phone": "+70820843433"}
0005434731186	4A2601	8335 379278	EKATERINA KALININA	{"email": "kalinina_e.19051960@postgrespro.ru", "phone": "+70673705873"}
0005434731187	A45E87	2711 989090	ALEKSANDR FOMIN	{"email": "fominaleksandr_091975@postgrespro.ru", "phone": "+70717196422"}
0005434731188	A45E87	4549 109107	SVETLANA FADEEVA	{"email": "fadeeva-s.081975@postgrespro.ru", "phone": "+70273875249"}
0005434731189	56F56D	3758 777675	ELENA SERGEEVA	{"email": "e.sergeeva-061974@postgrespro.ru", "phone": "+70506050188"}
0005434731190	3E3775	2778 195576	ANDREY PETROV	{"phone": "+70748470194"}
0005434731191	9D7F39	9825 227981	MIKHAIL CHERNOV	{"email": "mikhail-chernov.07071971@postgrespro.ru", "phone": "+70621176783"}
0005434731192	BD2CDA	7708 000123	IVAN TIMOFEEV	{"email": "timofeev_i.051972@postgrespro.ru", "phone": "+70153139878"}
0005434731193	BD2CDA	2527 232670	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr121976@postgrespro.ru", "phone": "+70255745186"}
0005434731194	F6E0FA	4161 489644	MIKHAIL RODIONOV	{"email": "rodionovmikhail.041962@postgrespro.ru", "phone": "+70716139629"}
0005434731195	7CE19D	4450 188947	ARTEM KISELEV	{"email": "a_kiselev-02081961@postgrespro.ru", "phone": "+70384915830"}
0005434731196	7CE19D	6496 381664	NINA GRISHINA	{"email": "nina_grishina.1975@postgrespro.ru", "phone": "+70768703068"}
0005434731197	BC80CE	7706 608064	IGOR ROMANOV	{"phone": "+70377598635"}
0005434731198	010998	0877 551452	PAVEL FROLOV	{"email": "frolov-p1962@postgrespro.ru", "phone": "+70394305531"}
0005434731199	4452C0	0892 519560	YURIY KOZLOV	{"phone": "+70933611648"}
0005434731200	9B438D	1513 254571	ANZHELIKA VASILEVA	{"phone": "+70629972667"}
0005434731201	C30F2F	1366 447980	VLADIMIR MAKSIMOV	{"phone": "+70143598034"}
0005434731202	C30F2F	1342 427232	ARTEM KOZLOV	{"phone": "+70331764066"}
0005434731203	10662A	3205 011877	NIKITA ILIN	{"email": "ilin-n_091968@postgrespro.ru", "phone": "+70868262582"}
0005434731204	4FE410	5293 188740	SERGEY VOROBEV	{"email": "sergeyvorobev-03011977@postgrespro.ru", "phone": "+70623559478"}
0005434731205	4FE410	3340 874075	NINA TARASOVA	{"email": "tarasova.n-20021960@postgrespro.ru", "phone": "+70553135893"}
0005434731206	9DB7FA	7773 791668	DINARA GORBUNOVA	{"phone": "+70266517103"}
0005434731207	8CD98E	8335 551455	KRISTINA BELOVA	{"phone": "+70326095620"}
0005434731208	CF4452	5624 620873	IRINA IVANOVA	{"email": "ivanova.i_27071977@postgrespro.ru", "phone": "+70700901378"}
0005434731209	CDD5F1	2026 497939	IVAN SCHERBAKOV	{"phone": "+70967997471"}
0005434731210	CDD5F1	3480 756454	SERGEY SMIRNOV	{"phone": "+70772509543"}
0005434731211	3DA5B8	9329 427733	VALERIY ZHUKOV	{"email": "zhukovv-041969@postgrespro.ru", "phone": "+70488556751"}
0005434731212	3DA5B8	4040 355937	YULIYA NAZAROVA	{"email": "y.nazarova091978@postgrespro.ru", "phone": "+70680454100"}
0005434731213	8768B7	0961 130493	RASIM SMIRNOV	{"email": "rsmirnov1973@postgrespro.ru", "phone": "+70369452327"}
0005434731214	0301AB	0909 061798	LYUBOV MOROZOVA	{"email": "l_morozova.1968@postgrespro.ru", "phone": "+70237500055"}
0005434731215	257C1E	9398 455966	SERGEY PAVLOV	{"phone": "+70499582870"}
0005434731216	965C45	0539 656862	DMITRIY KUDRYASHOV	{"email": "kudryashovd011976@postgrespro.ru", "phone": "+70464411545"}
0005434731217	965C45	0569 689286	ALEKSANDR NIKITIN	{"phone": "+70131484492"}
0005434731218	603976	1490 396653	TATYANA ROMANOVA	{"email": "t_romanova_01121967@postgrespro.ru", "phone": "+70959461939"}
0005434731219	065951	0120 085393	GALINA KUZNECOVA	{"phone": "+70397662009"}
0005434731220	DF9EC3	8572 474648	ALEKSEY POPOV	{"email": "a_popov.121980@postgrespro.ru", "phone": "+70780154875"}
0005434731221	DF9EC3	5530 559929	NATALYA KUZNECOVA	{"email": "kuznecova-natalya121967@postgrespro.ru", "phone": "+70600493205"}
0005434731222	17CD10	1051 121271	SVETLANA FEDOROVA	{"phone": "+70155726767"}
0005434731223	17CD10	3126 033678	NATALIYA LOGINOVA	{"email": "loginova.nataliya.24011970@postgrespro.ru", "phone": "+70772901395"}
0005434731224	52FAE2	1970 793515	LYUBOV NOVIKOVA	{"email": "novikova_l.1984@postgrespro.ru", "phone": "+70685058377"}
0005434731225	549CB7	1974 182875	YURIY SERGEEV	{"email": "yuriysergeev071974@postgrespro.ru", "phone": "+70057168494"}
0005434731226	98BE26	2484 595918	ALEKSANDR NIKOLAEV	{"phone": "+70396005424"}
0005434731227	BA049F	4472 568536	ALEKSANDR KUZNECOV	{"phone": "+70591478757"}
0005434731228	7B418C	7656 428222	SERGEY NIKITIN	{"phone": "+70564894811"}
0005434731229	F45104	1976 250476	ELENA SOKOLOVA	{"phone": "+70851436035"}
0005434731230	F45104	3328 775353	VERA ANDREEVA	{"email": "andreevav-1974@postgrespro.ru", "phone": "+70157359105"}
0005434731231	6D0FAB	7504 156474	LYUBOV SIDOROVA	{"phone": "+70905019255"}
0005434731232	6D0FAB	4206 465586	ANATOLIY BARANOV	{"email": "anatoliy_baranov-20081977@postgrespro.ru", "phone": "+70691417576"}
0005434731233	6D0FAB	1513 828365	ALEKSEY GERASIMOV	{"email": "gerasimovaleksey_1972@postgrespro.ru", "phone": "+70771478111"}
0005434731234	6D0FAB	1193 722608	SOFIYA IVANOVA	{"email": "sofiya.ivanova_1970@postgrespro.ru", "phone": "+70307510379"}
0005434731235	CC37D3	9185 545299	SERGEY BARANOV	{"email": "baranov.s1980@postgrespro.ru", "phone": "+70030325036"}
0005434731236	6B53C8	7826 110929	VALENTINA MASLOVA	{"phone": "+70898601673"}
0005434731237	ED4050	6704 630146	ELENA KOZLOVA	{"email": "kozlova.elena061977@postgrespro.ru", "phone": "+70537938408"}
0005434731238	8315D6	1348 563472	ANVAR DMITRIEV	{"email": "anvar_dmitriev-1968@postgrespro.ru", "phone": "+70501573957"}
0005434731239	D06515	4633 083542	LILIYA EGOROVA	{"email": "egorova-liliya_08101971@postgrespro.ru", "phone": "+70257938647"}
0005434731240	D06515	0261 616741	TATYANA DMITRIEVA	{"email": "dmitrievat_08101966@postgrespro.ru", "phone": "+70560963914"}
0005434731241	B1D816	8493 434068	TATYANA MASLOVA	{"phone": "+70972112768"}
0005434731242	A4BE25	6191 557830	PAVEL BORISOV	{"email": "pborisov.061968@postgrespro.ru", "phone": "+70158499828"}
0005434731243	A4BE25	4713 625230	LIYA ANTONOVA	{"phone": "+70410658519"}
0005434731244	8EF585	6306 384735	EVGENIY NAUMOV	{"phone": "+70823939996"}
0005434731245	E7CE21	7662 061853	OLGA RODIONOVA	{"email": "orodionova-091969@postgrespro.ru", "phone": "+70113009047"}
0005434731246	E7CE21	3581 151017	VALERIY KUDRYASHOV	{"email": "kudryashov-valeriy051964@postgrespro.ru", "phone": "+70476319922"}
0005434731247	CDE60E	8343 883686	ALEKSANDR ZAYCEV	{"email": "a.zaycev_041970@postgrespro.ru", "phone": "+70110015492"}
0005434731248	CDE60E	6870 236909	VALENTINA BELOVA	{"email": "belova_valentina.121969@postgrespro.ru", "phone": "+70061091002"}
0005434731249	FB6F33	8990 536224	VALENTINA TITOVA	{"phone": "+70475599181"}
0005434731250	FB6F33	6839 863728	LYUDMILA NOVIKOVA	{"email": "l_novikova-1984@postgrespro.ru", "phone": "+70432993768"}
0005434731251	698295	4119 031188	FAINA YAKOVLEVA	{"phone": "+70495947647"}
0005434731252	698295	4519 043258	SERGEY SEMENOV	{"email": "s.semenov.041964@postgrespro.ru", "phone": "+70171785237"}
0005434731253	23CDE1	2479 670892	POLINA SMIRNOVA	{"phone": "+70644530017"}
0005434731254	3FF86F	3429 195551	ELIZAVETA LAZAREVA	{"phone": "+70454968296"}
0005434731255	3FF86F	3862 171517	ANDREY ANTONOV	{"phone": "+70782348658"}
0005434731256	9F3ACE	7945 963112	DMITRIY TIKHONOV	{"email": "tikhonovdmitriy-1973@postgrespro.ru", "phone": "+70712622845"}
0005434731257	C3B15C	3865 324057	GALINA KOMAROVA	{"phone": "+70767499858"}
0005434731258	4F3DFF	4767 326235	ILYA GUSEV	{"phone": "+70367067259"}
0005434731259	177E93	7284 614754	DMITRIY KUDRYASHOV	{"email": "kudryashov_dmitriy.1962@postgrespro.ru", "phone": "+70518953303"}
0005434731260	EE1E9F	2197 160562	NINA POTAPOVA	{"phone": "+70612790026"}
0005434731261	D782F0	8897 079606	TATYANA ZAKHAROVA	{"email": "zakharova-t_1970@postgrespro.ru", "phone": "+70497937823"}
0005434731262	FF5A05	4794 387159	TATYANA BARANOVA	{"phone": "+70165833309"}
0005434731263	7B1066	7029 061730	RUSLAN FEDOROV	{"phone": "+70650041613"}
0005434731264	7B1066	5647 035612	VIKTOR KUZNECOV	{"phone": "+70766293020"}
0005434731265	9C9C27	6451 597849	EKATERINA ALEKSANDROVA	{"email": "ekaterinaaleksandrova_1977@postgrespro.ru", "phone": "+70859708925"}
0005434731266	EEBE14	4727 401927	VALERIY ZHUKOV	{"phone": "+70886713572"}
0005434731267	EEBE14	2971 379723	ALEKSANDR GERASIMOV	{"phone": "+70102546906"}
0005434731268	3E2A6E	6954 684150	NIKITA ZAKHAROV	{"phone": "+70637312458"}
0005434731269	3E2A6E	3986 752487	IRINA FROLOVA	{"phone": "+70275370215"}
0005434731270	3AA083	3697 613427	YULIYA POTAPOVA	{"email": "yuliya_potapova.121978@postgrespro.ru", "phone": "+70314965274"}
0005434731271	53E285	6739 503773	ANNA GUSEVA	{"email": "guseva_a_1984@postgrespro.ru", "phone": "+70962360323"}
0005434731272	81C74A	1785 650836	STANISLAV SCHERBAKOV	{"email": "scherbakovstanislav.061971@postgrespro.ru", "phone": "+70489732594"}
0005434731273	4970A2	8379 885352	VALERIY ANTONOV	{"phone": "+70440158113"}
0005434731274	73E70E	7890 899611	VALENTIN KRASNOV	{"email": "krasnov.valentin081958@postgrespro.ru", "phone": "+70921713820"}
0005434731275	7C25C8	6599 579936	YURIY KUZNECOV	{"phone": "+70646246712"}
0005434731276	3DD73B	4416 905795	NADEZHDA SERGEEVA	{"phone": "+70006052912"}
0005434731277	3DD73B	8428 206103	ANTON POPOV	{"email": "popova.28031960@postgrespro.ru", "phone": "+70566393437"}
0005434731278	CA38BB	5337 803106	SVETLANA NOVIKOVA	{"phone": "+70841566462"}
0005434731279	CA38BB	9188 142700	LIDIYA MEDVEDEVA	{"email": "l_medvedeva-1974@postgrespro.ru", "phone": "+70298834216"}
0005434731280	C72D7C	8102 804666	YULIYA MIRONOVA	{"email": "mironovay1969@postgrespro.ru", "phone": "+70527523353"}
0005434731281	C72D7C	7436 389084	ELVIRA FOMINA	{"phone": "+70107632308"}
0005434731282	C72D7C	9021 037581	YULIYA EGOROVA	{"email": "egorova-yuliya12061966@postgrespro.ru", "phone": "+70637193607"}
0005434731283	89B36E	3399 356166	SOFYA NIKITINA	{"phone": "+70999320116"}
0005434731284	D4952A	0179 977847	GERMAN FROLOV	{"email": "frolov-g-02091977@postgrespro.ru", "phone": "+70140600513"}
0005434731285	D4952A	6626 057486	IRINA CHERNOVA	{"email": "i.chernova_1981@postgrespro.ru", "phone": "+70377508541"}
0005434731286	1CF1E2	4323 158027	IVAN DAVYDOV	{"email": "i_davydov_061972@postgrespro.ru", "phone": "+70145569401"}
0005434731287	F0452B	5574 632632	ZINAIDA SEMENOVA	{"phone": "+70975435015"}
0005434731288	C1755A	1558 585609	IVAN PAVLOV	{"email": "ipavlov-01041956@postgrespro.ru", "phone": "+70079732271"}
0005434731289	46D093	0859 903017	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1973@postgrespro.ru", "phone": "+70505803612"}
0005434731290	627724	1385 702681	ALEKSANDR ISAEV	{"phone": "+70549692143"}
0005434731291	5A0344	2765 943310	NINA MARTYNOVA	{"email": "nina-martynova.061975@postgrespro.ru", "phone": "+70169421443"}
0005434731292	6D0075	3998 461919	NINA MIKHAYLOVA	{"phone": "+70723446640"}
0005434731293	60757E	9423 039694	SVETLANA KUZMINA	{"phone": "+70752272550"}
0005434732918	464BA4	4265 148576	TAISIYA SIDOROVA	{"email": "taisiya.sidorova_101968@postgrespro.ru", "phone": "+70660701425"}
0005434732919	464BA4	0385 049728	OLGA PAVLOVA	{"phone": "+70413396192"}
0005434732920	272E20	4035 176785	GALINA KUZNECOVA	{"phone": "+70971308554"}
0005434732921	7CFE9A	7072 800068	MAKSIM KUZMIN	{"email": "maksim-kuzmin_061971@postgrespro.ru", "phone": "+70649859564"}
0005434732922	A6D3B7	5578 606345	ZHANNA POPOVA	{"phone": "+70663567630"}
0005434732923	A841FC	3433 341999	ALEKSANDR IVANOV	{"email": "ivanova.021972@postgrespro.ru", "phone": "+70351938702"}
0005434732924	A841FC	9588 494897	VALERIY POPOV	{"phone": "+70080618420"}
0005434732925	A841FC	0306 744038	SERGEY ZHURAVLEV	{"phone": "+70783188614"}
0005434732926	818622	8500 796848	NATALYA POTAPOVA	{"email": "potapova_n21041966@postgrespro.ru", "phone": "+70003173848"}
0005434732927	818622	9150 046618	ELENA DAVYDOVA	{"phone": "+70273712488"}
0005434732928	B9B9B8	0726 773887	VLADISLAV MAKSIMOV	{"email": "v-maksimov_25091963@postgrespro.ru", "phone": "+70651821165"}
0005434732929	25493C	1284 085607	KLAVDIYA ZHURAVLEVA	{"phone": "+70602398343"}
0005434732930	516C1B	1102 960923	NIKOLAY SOLOVEV	{"email": "solovev-nikolay_051960@postgrespro.ru", "phone": "+70381772681"}
0005434732931	516C1B	0528 384630	SVETLANA SOKOLOVA	{"email": "sokolova.svetlana.071965@postgrespro.ru", "phone": "+70372113912"}
0005434732932	516C1B	7686 227482	IRINA SOROKINA	{"email": "irina-sorokina1981@postgrespro.ru", "phone": "+70110471958"}
0005434732933	3FF564	8033 609772	MARIYA KAZAKOVA	{"email": "kazakovamariya1964@postgrespro.ru", "phone": "+70266314706"}
0005434732934	BD706D	7155 925078	TATYANA SOKOLOVA	{"phone": "+70299977709"}
0005434732935	02DF12	5910 104594	ALEKSEY NAUMOV	{"phone": "+70687768414"}
0005434732936	29FCAE	7068 520922	SERGEY MELNIKOV	{"email": "melnikovsergey.1966@postgrespro.ru", "phone": "+70571308291"}
0005434732937	457728	9323 851292	ALEKSEY KISELEV	{"email": "kiselev-aleksey091970@postgrespro.ru", "phone": "+70833332933"}
0005434732938	457728	8277 462601	ALEKSANDRA MATVEEVA	{"email": "aleksandra_matveeva_101974@postgrespro.ru", "phone": "+70389762007"}
0005434732939	A97088	7869 625043	VALENTINA KUZNECOVA	{"email": "kuznecovav_1967@postgrespro.ru", "phone": "+70606556151"}
0005434732940	A40285	9425 648964	VLADIMIR IVANOV	{"phone": "+70821811322"}
0005434732941	BD769A	4523 028060	OLESYA KOROLEVA	{"email": "olesya-koroleva-12031961@postgrespro.ru", "phone": "+70756209673"}
0005434732942	FF5B8D	9953 302754	EKATERINA ORLOVA	{"email": "eorlova-071973@postgrespro.ru", "phone": "+70780188174"}
0005434732943	0E3AD7	0317 222247	STANISLAV STEPANOV	{"email": "stepanov-s-29101969@postgrespro.ru", "phone": "+70584387402"}
0005434732944	0E3AD7	8661 704051	LIDIYA PETROVA	{"phone": "+70581181337"}
0005434732945	469E72	5042 110458	KIRILL KULIKOV	{"email": "kirillkulikov_1974@postgrespro.ru", "phone": "+70556057938"}
0005434732946	E487EB	9066 168533	YULIYA IVANOVA	{"email": "ivanova-yuliya051973@postgrespro.ru", "phone": "+70896695068"}
0005434732947	AE9D11	6110 886172	ARTEM SOROKIN	{"phone": "+70187467024"}
0005434732948	890BAC	9837 458623	LARISA SOKOLOVA	{"phone": "+70466331740"}
0005434732949	890BAC	8538 894184	DMITRIY MATVEEV	{"email": "d.matveev-02081974@postgrespro.ru", "phone": "+70447253710"}
0005434732950	484F85	9789 782320	ALEKSANDR KUZNECOV	{"phone": "+70703023995"}
0005434732951	9F936F	0673 383823	LYUDMILA BORISOVA	{"email": "lyudmila_borisova_111975@postgrespro.ru", "phone": "+70692188271"}
0005434732952	32CDBA	3487 422676	ANATOLIY GUSEV	{"phone": "+70607671473"}
0005434732953	DDFE4E	1562 761905	TAMARA PETROVA	{"phone": "+70598634057"}
0005434732954	99B7B9	6619 071322	ALEKSANDR ZAKHAROV	{"email": "zakharova19031962@postgrespro.ru", "phone": "+70491695584"}
0005434732955	124466	0876 550742	VYACHESLAV KUZNECOV	{"phone": "+70485993400"}
0005434732956	9A3431	9405 197476	VLADISLAV MARTYNOV	{"email": "vladislav.martynov081969@postgrespro.ru", "phone": "+70368211103"}
0005434732957	0C8FFB	2891 657688	ELENA IVANOVA	{"email": "ivanova_e21111978@postgrespro.ru", "phone": "+70706563391"}
0005434732958	0C8FFB	3082 825973	ALEKSANDR ZHUKOV	{"phone": "+70508578305"}
0005434732959	4E3BB8	2750 764470	YULIYA CHERNOVA	{"email": "y_chernova-021973@postgrespro.ru", "phone": "+70103819926"}
0005434732960	4E3BB8	2434 307864	OLGA AFANASEVA	{"phone": "+70195293514"}
0005434732961	D30118	8043 767141	FEDOR ANTONOV	{"phone": "+70192593854"}
0005434732962	D30118	6529 646698	OLGA IVANOVA	{"phone": "+70044170330"}
0005434732963	E00B4E	5987 155105	ANATOLIY GORBUNOV	{"phone": "+70116463650"}
0005434732964	1D8DC2	3563 035861	ALEKSANDR ORLOV	{"email": "aorlov_19051971@postgrespro.ru", "phone": "+70231913254"}
0005434732965	1D8DC2	2193 550464	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev06071976@postgrespro.ru", "phone": "+70317411786"}
0005434732966	CE6B64	5968 627440	SERGEY SCHERBAKOV	{"phone": "+70384954835"}
0005434732967	51FCD7	5112 565175	ZINAIDA TIKHONOVA	{"email": "z-tikhonova.1965@postgrespro.ru", "phone": "+70066910510"}
0005434732968	ED687C	8837 717577	TATYANA FROLOVA	{"email": "frolovatatyana.23111968@postgrespro.ru", "phone": "+70828897200"}
0005434732969	41EDD7	3898 056252	ANDREY ZAKHAROV	{"phone": "+70621069082"}
0005434732970	467340	3361 750288	ALEKSEY FILIPPOV	{"email": "a_filippov-1973@postgrespro.ru", "phone": "+70027294787"}
0005434732971	786AEB	4494 803955	MARGARITA ROMANOVA	{"email": "romanova-m_31051975@postgrespro.ru", "phone": "+70872970624"}
0005434732972	669D2F	3761 388129	OLEG STEPANOV	{"phone": "+70053555974"}
0005434732973	13526D	6990 519609	IGOR MIKHAYLOV	{"email": "mikhaylov.i_25091974@postgrespro.ru", "phone": "+70834144930"}
0005434732974	52219D	8681 154365	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-1969@postgrespro.ru", "phone": "+70763177650"}
0005434732975	DCAA11	3002 685550	ELENA GERASIMOVA	{"email": "gerasimovaelena08101967@postgrespro.ru", "phone": "+70711752331"}
0005434732976	DCAA11	9861 041739	VIKTOR SMIRNOV	{"email": "vsmirnov021961@postgrespro.ru", "phone": "+70172642424"}
0005434732977	3EB75A	0798 160390	ALEVTINA TIMOFEEVA	{"email": "timofeeva-a_1970@postgrespro.ru", "phone": "+70372580352"}
0005434732978	5B6D24	6577 311968	ALEKSEY PAVLOV	{"email": "pavlov_a_01031985@postgrespro.ru", "phone": "+70121064188"}
0005434732979	5B6D24	0773 309324	NATALYA NIKOLAEVA	{"phone": "+70221514084"}
0005434732980	8B76B5	5940 404374	NINA EGOROVA	{"email": "egorovanina_29091978@postgrespro.ru", "phone": "+70691653800"}
0005434732981	E9990F	3143 397014	VALERIY SERGEEV	{"email": "sergeevvaleriy-13061973@postgrespro.ru", "phone": "+70310385894"}
0005434732982	5A6A76	2445 578073	ANNA EFIMOVA	{"email": "efimova.anna.1973@postgrespro.ru", "phone": "+70982300579"}
0005434732983	06CFB7	1370 509961	ALEKSEY RODIONOV	{"email": "aleksey_rodionov_021971@postgrespro.ru", "phone": "+70190289801"}
0005434732984	9CB4DB	6966 750722	VLADIMIR MOROZOV	{"phone": "+70589089544"}
0005434732985	2497FF	0837 921260	NATALYA CHERNOVA	{"email": "nchernova22051975@postgrespro.ru", "phone": "+70499422928"}
0005434732986	4942BD	4213 956865	SVETLANA NOVIKOVA	{"email": "svetlana-novikova1963@postgrespro.ru", "phone": "+70246719461"}
0005434732987	66754D	7685 435605	VITALIY ZAKHAROV	{"phone": "+70357269721"}
0005434732988	9B8549	8060 695821	YURIY NIKOLAEV	{"email": "ynikolaev.12041963@postgrespro.ru", "phone": "+70584642574"}
0005434732989	9B8549	5117 729387	EGOR SOKOLOV	{"phone": "+70958895685"}
0005434732990	4DC44F	6798 118490	DANIIL SIDOROV	{"email": "sidorov-daniil23111961@postgrespro.ru", "phone": "+70497671935"}
0005434732991	768C39	6788 788866	VALENTINA ANTONOVA	{"email": "antonova.v_061974@postgrespro.ru", "phone": "+70238525860"}
0005434732992	768C39	4507 127435	ALEVTINA ABRAMOVA	{"email": "abramova_a.101969@postgrespro.ru", "phone": "+70897475085"}
0005434732993	6CF7CE	9177 275986	LYUDMILA KOVALEVA	{"phone": "+70292403368"}
0005434732994	A55742	9656 236414	KLAVDIYA KOVALEVA	{"phone": "+70116783295"}
0005434732995	A55742	0829 069354	VALENTINA SCHERBAKOVA	{"phone": "+70669022291"}
0005434732996	E7AC8B	9304 392133	OKSANA ROMANOVA	{"phone": "+70475375026"}
0005434732997	1F87D4	8558 051336	IVAN MATVEEV	{"phone": "+70085424442"}
0005434732998	1F87D4	0003 247999	STANISLAV ORLOV	{"phone": "+70167613408"}
0005434732999	1F87D4	8153 579937	VLADIMIR GUSEV	{"email": "gusev-v01081981@postgrespro.ru", "phone": "+70642744508"}
0005434733000	DB91F5	0709 581689	VLADIMIR VOLKOV	{"email": "volkovvladimir.1970@postgrespro.ru", "phone": "+70673519737"}
0005434733001	A0B526	6983 127473	TATYANA GORBUNOVA	{"email": "gorbunova-tatyana_1963@postgrespro.ru", "phone": "+70316482106"}
0005434733002	A0B526	0778 803671	ANASTASIYA FROLOVA	{"email": "frolova.a-021986@postgrespro.ru", "phone": "+70730687701"}
0005434733003	6B18E2	4202 888290	IVAN SEMENOV	{"phone": "+70187383109"}
0005434733004	DCCC88	3106 974157	VLADIMIR FILIPPOV	{"phone": "+70962976481"}
0005434733005	F2F7AC	3735 625408	IVAN FROLOV	{"phone": "+70488093509"}
0005434733006	918B1A	4696 231504	ALEKSANDR ROMANOV	{"phone": "+70363392007"}
0005434733007	918B1A	4048 497653	GRIGORIY MIRONOV	{"phone": "+70797751822"}
0005434733008	C50ACF	1169 959666	ANTON SOKOLOV	{"email": "sokolovanton041985@postgrespro.ru", "phone": "+70755323646"}
0005434733009	DB2EC0	3398 854479	ELENA MEDVEDEVA	{"email": "medvedeva.elena.011978@postgrespro.ru", "phone": "+70037095524"}
0005434733010	DB2EC0	3234 759578	ULYANA KOZLOVA	{"email": "ulyana_kozlova111962@postgrespro.ru", "phone": "+70648113872"}
0005434733011	DB2EC0	3875 964490	RAISA BELOVA	{"phone": "+70175388215"}
0005434733012	473883	9694 499666	ALEKSANDR ILIN	{"phone": "+70687834457"}
0005434733013	473883	9397 248666	TATYANA FEDOROVA	{"email": "tfedorova.091960@postgrespro.ru", "phone": "+70713545303"}
0005434733014	123C62	5642 015800	DENIS TARASOV	{"email": "tarasov.d-051973@postgrespro.ru", "phone": "+70386162323"}
0005434733015	123C62	9410 043087	MARIYA ZAYCEVA	{"email": "zayceva-m.1973@postgrespro.ru", "phone": "+70103190523"}
0005434733016	9C503C	5643 754647	ARSEN KUZNECOV	{"email": "kuznecova_26071969@postgrespro.ru", "phone": "+70193935561"}
0005434733017	9C503C	2102 664226	OLGA YAKOVLEVA	{"email": "yakovlevao-121978@postgrespro.ru", "phone": "+70860028068"}
0005434733018	9C503C	0410 196893	VALENTINA RODIONOVA	{"phone": "+70528568448"}
0005434733019	A4FD9B	5863 516019	ELENA SMIRNOVA	{"email": "esmirnova_05051964@postgrespro.ru", "phone": "+70992902250"}
0005434733020	A4FD9B	7655 963671	PAVEL ZAKHAROV	{"phone": "+70505357031"}
0005434733021	DF6150	8661 620985	ALEKSEY IVANOV	{"phone": "+70878548787"}
0005434733022	DF6150	4014 979529	LIDIYA SEMENOVA	{"email": "lidiya.semenova_1980@postgrespro.ru", "phone": "+70091256818"}
0005434733023	983EC0	0856 226827	ELENA ERMAKOVA	{"phone": "+70540640920"}
0005434733024	983EC0	9285 832892	ALEKSANDR VOLKOV	{"email": "volkovaleksandr-071967@postgrespro.ru", "phone": "+70461001178"}
0005434733025	D239B3	8062 637894	ANASTASIYA KOZLOVA	{"email": "a-kozlova07101976@postgrespro.ru", "phone": "+70580231827"}
0005434733026	7CFC2B	8814 591088	DAMIR KOROLEV	{"email": "korolev-d_31081971@postgrespro.ru", "phone": "+70664519866"}
0005434733027	CD2C6D	6825 905207	ANTONINA ROMANOVA	{"email": "romanovaa_1980@postgrespro.ru", "phone": "+70983944364"}
0005434733028	CAF8EF	8880 328777	ALEKSEY MAKSIMOV	{"email": "maksimov-aleksey-1980@postgrespro.ru", "phone": "+70345736417"}
0005434733029	23A44C	5650 494228	GALINA BOGDANOVA	{"email": "g_bogdanova-121972@postgrespro.ru", "phone": "+70816051939"}
0005434733030	9ACC4E	4752 552980	ALENA PETROVA	{"phone": "+70664940136"}
0005434733031	9ACC4E	2833 444875	OLGA STEPANOVA	{"phone": "+70279722462"}
0005434733032	F5619E	0496 943848	ANASTASIYA KONOVALOVA	{"phone": "+70208136599"}
0005434733033	F5619E	5298 544212	NATALIYA IVANOVA	{"phone": "+70726358593"}
0005434733034	139950	8320 826420	VLADIMIR MAKAROV	{"email": "v.makarov091972@postgrespro.ru", "phone": "+70540619026"}
0005434733035	D65817	3592 230515	ALEKSANDR MOISEEV	{"email": "a-moiseev_19111963@postgrespro.ru", "phone": "+70002013156"}
0005434733036	B31D25	1847 202226	ANDREY ZHURAVLEV	{"email": "andrey_zhuravlev031974@postgrespro.ru", "phone": "+70371145457"}
0005434733037	664CE9	2444 222176	ALEKSEY SOLOVEV	{"email": "a-solovev-27031976@postgrespro.ru", "phone": "+70867006534"}
0005434733038	F1C663	9806 066914	ALEKSANDR MAKAROV	{"email": "makarov.a.1971@postgrespro.ru", "phone": "+70882598967"}
0005434733039	84ADF6	4515 559945	MAKSIM PETROV	{"email": "petrovm_21121972@postgrespro.ru", "phone": "+70679612736"}
0005434733040	A68746	3426 831188	SVETLANA ZAYCEVA	{"email": "svetlana_zayceva_021965@postgrespro.ru", "phone": "+70556282930"}
0005434733041	A68746	8034 647775	LYUBOV ZAKHAROVA	{"email": "zakharova.lyubov-051979@postgrespro.ru", "phone": "+70190208298"}
0005434733042	56C181	2899 602925	MIKHAIL BORISOV	{"email": "borisov-mikhail-091980@postgrespro.ru", "phone": "+70269885751"}
0005434733043	E4DA4D	0122 421617	ANDREY IVANOV	{"email": "andrey.ivanov.09081961@postgrespro.ru", "phone": "+70617744025"}
0005434733044	6AF924	8880 925778	VLADIMIR POPOV	{"email": "popov-vladimir011978@postgrespro.ru", "phone": "+70630406596"}
0005434733045	6AF924	9791 121616	GALINA MOISEEVA	{"email": "galinamoiseeva-121982@postgrespro.ru", "phone": "+70102389654"}
0005434733046	0CCEA8	2724 077003	NADEZHDA ZHURAVLEVA	{"email": "n-zhuravleva1981@postgrespro.ru", "phone": "+70180804077"}
0005434733047	D0A05F	2473 836754	ALEKSANDR ZHURAVLEV	{"phone": "+70179464638"}
0005434733048	D0A05F	2026 377908	VLADIMIR SEMENOV	{"email": "semenov_vladimir.031965@postgrespro.ru", "phone": "+70140789788"}
0005434733049	D0A05F	6316 291829	ALEKSANDRA ALEKSEEVA	{"phone": "+70350285237"}
0005434733050	DEF653	7563 350668	VERA IVANOVA	{"email": "veraivanova.041971@postgrespro.ru", "phone": "+70599848412"}
0005434733051	DEF653	8437 458040	VALENTINA ZAYCEVA	{"email": "vzayceva07051966@postgrespro.ru", "phone": "+70847637590"}
0005434733052	B29CFA	1261 216420	NATALYA VOLKOVA	{"email": "volkovan021966@postgrespro.ru", "phone": "+70085751387"}
0005434733053	B29CFA	9423 492259	EVGENIY CHERNOV	{"email": "chernov.e_12051974@postgrespro.ru", "phone": "+70373835060"}
0005434733054	EE092F	5448 062265	LILIYA VASILEVA	{"email": "lvasileva.1983@postgrespro.ru", "phone": "+70335357046"}
0005434733055	632A66	1062 248748	NATALIYA AFANASEVA	{"email": "afanaseva_nataliya_121963@postgrespro.ru", "phone": "+70310406869"}
0005434733056	632A66	0436 982565	NATALYA KALININA	{"phone": "+70287504119"}
0005434733057	262785	4600 986667	ANNA ORLOVA	{"phone": "+70667194394"}
0005434733058	89F5C4	9717 970683	ALEKSANDRA KOLESNIKOVA	{"email": "a_kolesnikova.1969@postgrespro.ru", "phone": "+70565948081"}
0005434733059	89F5C4	2974 811498	ZOYA KOVALEVA	{"phone": "+70576959735"}
0005434733060	60952F	5521 260714	STEPAN BELOV	{"email": "sbelov-031977@postgrespro.ru", "phone": "+70975568010"}
0005434733061	60952F	3435 291463	YURIY SAVELEV	{"email": "y_savelev_011986@postgrespro.ru", "phone": "+70025492618"}
0005434733062	486720	9778 160508	ANNA GORBUNOVA	{"email": "gorbunova_anna-101975@postgrespro.ru", "phone": "+70604945001"}
0005434733063	486720	7390 436424	ALEKSANDR FOMIN	{"email": "a_fomin_1963@postgrespro.ru", "phone": "+70099150334"}
0005434733064	486720	3185 440692	ELENA EGOROVA	{"phone": "+70465050364"}
0005434733065	C2F0DF	1778 997827	NIKOLAY CHERNOV	{"phone": "+70100359129"}
0005434733066	C2F0DF	4350 118438	DANIIL ZAYCEV	{"email": "zaycevdaniil-121969@postgrespro.ru", "phone": "+70044963410"}
0005434733067	CDA1DE	3053 474401	SVETLANA MASLOVA	{"email": "s_maslova-121968@postgrespro.ru", "phone": "+70937567405"}
0005434733068	7C28F9	9336 628229	GENNADIY DENISOV	{"email": "gdenisov.1969@postgrespro.ru", "phone": "+70192618842"}
0005434733069	E0C104	5106 873030	PAVEL NIKOLAEV	{"email": "nikolaev_pavel1973@postgrespro.ru", "phone": "+70562106721"}
0005434733070	E0C104	2228 322638	VIKTOR IVANOV	{"phone": "+70386968669"}
0005434733071	95F90F	2662 469585	OLGA LAZAREVA	{"email": "olga-lazareva_04101969@postgrespro.ru", "phone": "+70958590197"}
0005434733072	95F90F	6359 533268	ILYA VLASOV	{"email": "vlasov-i-25031974@postgrespro.ru", "phone": "+70571410697"}
0005434733073	6CC381	1518 204336	ANNA NIKITINA	{"email": "nikitina_anna121974@postgrespro.ru", "phone": "+70068030331"}
0005434733074	959136	9984 645938	DMITRIY MAKAROV	{"email": "makarov_dmitriy011983@postgrespro.ru", "phone": "+70002061769"}
0005434733075	373D5C	0624 194072	RIMMA ALEKSANDROVA	{"phone": "+70041321429"}
0005434733076	26CE27	1507 348736	ARTEM CHERNOV	{"phone": "+70470472986"}
0005434733077	C8FBEB	9161 620110	GALINA BELOVA	{"email": "belova.g.1972@postgrespro.ru", "phone": "+70981224473"}
0005434733078	C8FBEB	0857 082285	ANNA ZAKHAROVA	{"email": "zakharova_a.1967@postgrespro.ru", "phone": "+70593978515"}
0005434733079	063359	1844 428413	NATALYA MELNIKOVA	{"phone": "+70456988896"}
0005434733080	B82153	1536 043087	EVGENIYA MIKHAYLOVA	{"phone": "+70194028388"}
0005434733081	3B35AD	8064 795170	GEORGIY SERGEEV	{"phone": "+70217779425"}
0005434733082	160739	7084 455770	PAVEL ALEKSEEV	{"phone": "+70986257384"}
0005434733083	160739	4923 702514	NATALYA ZHURAVLEVA	{"phone": "+70382248098"}
0005434733084	B12DEA	6568 231668	LYUBOV MALYSHEVA	{"email": "malysheva_lyubov-111989@postgrespro.ru", "phone": "+70874530325"}
0005434733085	60E6D6	3623 833662	ANDREY IVANOV	{"email": "andreyivanov.20071970@postgrespro.ru", "phone": "+70608227341"}
0005434735788	8032A1	8356 245923	ALEFTINA SIDOROVA	{"phone": "+70002949704"}
0005434735597	46621B	4345 427472	LYUDMILA MAKSIMOVA	{"phone": "+70407456869"}
0005434735598	B2F7B4	0579 460880	VERA SCHERBAKOVA	{"phone": "+70197484392"}
0005434735599	B2F7B4	1810 216773	SERGEY ABRAMOV	{"email": "abramov-s071987@postgrespro.ru", "phone": "+70246021707"}
0005434735600	B09471	4666 228008	LIDIYA KAZAKOVA	{"email": "lkazakova101977@postgrespro.ru", "phone": "+70934826317"}
0005434735601	409907	9369 349641	YURIY FILIPPOV	{"email": "filippov-y.26071975@postgrespro.ru", "phone": "+70167401758"}
0005434735602	BFC0DC	6673 304664	VERA NESTEROVA	{"phone": "+70832275781"}
0005434735603	EDFDC3	3057 667724	ALEKSANDR PAVLOV	{"email": "a.pavlov19071963@postgrespro.ru", "phone": "+70767328634"}
0005434735604	897FAD	0019 877787	SVETLANA KOVALEVA	{"email": "s.kovaleva061969@postgrespro.ru", "phone": "+70458522522"}
0005434735605	897FAD	0202 159079	SVETLANA VLASOVA	{"email": "svetlana-vlasova.25101967@postgrespro.ru", "phone": "+70854771316"}
0005434735606	422329	6779 644835	ILYA ZAKHAROV	{"email": "ilya_zakharov-1972@postgrespro.ru", "phone": "+70646519452"}
0005434735607	EBC468	2083 297802	IGOR ANDREEV	{"phone": "+70271664311"}
0005434735608	023CBC	8855 014986	MARINA SMIRNOVA	{"email": "marina-smirnova071978@postgrespro.ru", "phone": "+70505013611"}
0005434735609	BF283D	4282 809974	LILIYA TIKHONOVA	{"phone": "+70813890901"}
0005434735610	BF283D	9283 319153	VALERIY TARASOV	{"email": "vtarasov-041969@postgrespro.ru", "phone": "+70197209386"}
0005434735611	BF283D	8791 930927	MARIYA STEPANOVA	{"email": "stepanova_m_01091976@postgrespro.ru", "phone": "+70794777198"}
0005434735612	BF283D	9615 961897	ANDREY VOROBEV	{"email": "avorobev-1973@postgrespro.ru", "phone": "+70037546856"}
0005434735613	D521DD	9528 504567	NATALIYA KONDRATEVA	{"phone": "+70900355179"}
0005434735614	0758A6	7470 147602	ALEKSANDRA MARTYNOVA	{"phone": "+70909123095"}
0005434735615	CFBE4B	6993 761771	ANDREY ZHURAVLEV	{"phone": "+70554705878"}
0005434735616	CFBE4B	4425 401792	TATYANA TIKHONOVA	{"phone": "+70448550841"}
0005434735617	CFBE4B	2817 787579	VLADIMIR MIRONOV	{"phone": "+70047044375"}
0005434735618	ABDE0C	3354 786507	KIRILL MAKAROV	{"phone": "+70086866024"}
0005434735619	ABDE0C	1181 548708	ALEKSANDR KONOVALOV	{"phone": "+70104131511"}
0005434735620	0CACD2	8138 571385	OLEG ZHUKOV	{"email": "zhukovo-061965@postgrespro.ru", "phone": "+70283723786"}
0005434735621	B59179	8125 768388	NIKOLAY SOROKIN	{"phone": "+70061868520"}
0005434735622	B59179	0032 844684	YULIYA STEPANOVA	{"email": "stepanova-y1980@postgrespro.ru", "phone": "+70732994132"}
0005434735623	749EAB	9486 166682	ALEKSANDR MAKSIMOV	{"email": "maksimov.aleksandr.051973@postgrespro.ru", "phone": "+70665147940"}
0005434735624	C71512	5293 922982	IRINA KARPOVA	{"phone": "+70913854748"}
0005434735625	ED46BC	8190 164895	PAVEL ZAKHAROV	{"phone": "+70212383215"}
0005434735626	8C800C	4885 031386	VITALIY GERASIMOV	{"phone": "+70975836096"}
0005434735627	925DAE	1224 076527	LYUDMILA BARANOVA	{"email": "lyudmila.baranova_061962@postgrespro.ru", "phone": "+70840986250"}
0005434735628	925DAE	2588 171706	OLGA MARTYNOVA	{"phone": "+70175133133"}
0005434735629	D0FFAB	4595 599540	TATYANA NESTEROVA	{"email": "t_nesterova.17101977@postgrespro.ru", "phone": "+70132888617"}
0005434735630	0978AD	5319 009642	IRINA FILIPPOVA	{"phone": "+70664039604"}
0005434735631	C43E3A	5039 856044	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr_07081965@postgrespro.ru", "phone": "+70524440349"}
0005434735632	C43E3A	7861 050283	EKATERINA ZAYCEVA	{"email": "zayceva_e.13101966@postgrespro.ru", "phone": "+70566711276"}
0005434735633	CBAB23	9272 769533	VLADIMIR CHERNOV	{"phone": "+70263268455"}
0005434735634	CBAB23	3986 811953	NONNA SOROKINA	{"email": "sorokina.nonna.011966@postgrespro.ru", "phone": "+70775437759"}
0005434735635	CBAB23	6118 771538	SERGEY PAVLOV	{"phone": "+70287774935"}
0005434735636	39CE04	0709 566621	ALEKSANDRA GERASIMOVA	{"email": "gerasimova-aleksandra.1969@postgrespro.ru", "phone": "+70028623220"}
0005434735637	39CE04	6910 983935	GUZEL EGOROVA	{"email": "g_egorova_14071965@postgrespro.ru", "phone": "+70178122071"}
0005434735638	39CE04	4524 026153	ANDREY MIKHAYLOV	{"email": "mikhaylov.a.08021966@postgrespro.ru", "phone": "+70956133256"}
0005434735639	E9F44D	8046 363465	YURIY IVANOV	{"email": "y-ivanov1973@postgrespro.ru", "phone": "+70676515140"}
0005434735640	E9F44D	5518 710495	IVAN KUZNECOV	{"phone": "+70253768980"}
0005434735641	B0085C	3490 327451	ANNA KONOVALOVA	{"email": "anna-konovalova-26091966@postgrespro.ru", "phone": "+70476270695"}
0005434735642	CC1C8C	1764 206953	GALINA EGOROVA	{"email": "g.egorova_1972@postgrespro.ru", "phone": "+70533915507"}
0005434735643	CC1C8C	5451 329029	ALEKSANDR POPOV	{"email": "popovaleksandr.28061980@postgrespro.ru", "phone": "+70983839921"}
0005434735699	EE84E0	2505 319374	GALINA TARASOVA	{"phone": "+70717657614"}
0005434735644	313339	8241 872505	VASILIY DENISOV	{"email": "v-denisov.111973@postgrespro.ru", "phone": "+70698089559"}
0005434735645	C57E6D	5648 421521	TATYANA ZHURAVLEVA	{"phone": "+70715161592"}
0005434735646	C57E6D	4773 820298	RUSTAM GERASIMOV	{"email": "gerasimov-rustam-031977@postgrespro.ru", "phone": "+70389195418"}
0005434735647	173472	6953 856154	KLAVDIYA MAKSIMOVA	{"email": "k_maksimova.22081976@postgrespro.ru", "phone": "+70531827866"}
0005434735648	173472	6280 318497	OLEG PAVLOV	{"email": "pavlov-o.101968@postgrespro.ru", "phone": "+70708053151"}
0005434735649	30077B	0497 748657	GALINA LAZAREVA	{"phone": "+70593118872"}
0005434735650	59792E	6775 254112	DMITRIY KONOVALOV	{"email": "dmitriy-konovalov15051967@postgrespro.ru", "phone": "+70477243222"}
0005434735651	59792E	6035 776401	MARINA KUZNECOVA	{"phone": "+70365200032"}
0005434735652	0DB964	5385 430810	OLGA POLYAKOVA	{"email": "polyakovao.1972@postgrespro.ru", "phone": "+70694629305"}
0005434735653	D5C25F	9931 397968	YULIYA MIKHAYLOVA	{"phone": "+70454702917"}
0005434735654	FE9A91	6455 102213	NIKOLAY EGOROV	{"email": "egorov-nikolay.1973@postgrespro.ru", "phone": "+70980980840"}
0005434735655	FE9A91	5104 941604	PAVEL PAVLOV	{"phone": "+70863903903"}
0005434735656	317496	7990 694484	ALENA SEMENOVA	{"email": "alenasemenova.101960@postgrespro.ru", "phone": "+70086669378"}
0005434735657	37AE7A	4932 767019	NADEZHDA NAZAROVA	{"email": "nazarova_n1977@postgrespro.ru", "phone": "+70855467571"}
0005434735658	B8032C	7944 574202	ARTEM ZHURAVLEV	{"email": "zhuravlev_artem111965@postgrespro.ru", "phone": "+70773257568"}
0005434735659	B8032C	5192 526055	VERA SMIRNOVA	{"email": "v_smirnova29061973@postgrespro.ru", "phone": "+70707872468"}
0005434735660	05A6CA	9098 232542	VERA SEMENOVA	{"email": "vera-semenova-061969@postgrespro.ru", "phone": "+70063226060"}
0005434735661	48A4A3	5481 586029	KONSTANTIN FEDOTOV	{"email": "konstantin-fedotov-071977@postgrespro.ru", "phone": "+70496628923"}
0005434735662	48A4A3	6249 079013	VALENTINA GERASIMOVA	{"email": "gerasimova_valentina.28021969@postgrespro.ru", "phone": "+70168106057"}
0005434735663	164825	3380 571061	NATALYA NIKITINA	{"email": "nnikitina04071978@postgrespro.ru", "phone": "+70023105189"}
0005434735664	164825	3704 576156	ROMAN GORBUNOV	{"phone": "+70538108703"}
0005434735665	164825	1872 802289	ANDREY DAVYDOV	{"phone": "+70125660617"}
0005434735666	315724	0057 903678	YULIYA ORLOVA	{"email": "yorlova121971@postgrespro.ru", "phone": "+70027800023"}
0005434735667	C82247	0768 835088	IGOR PAVLOV	{"email": "ipavlov1982@postgrespro.ru", "phone": "+70232008044"}
0005434735668	C82247	3087 207499	GRIGORIY ZAYCEV	{"phone": "+70201012702"}
0005434735669	06C5EC	7557 929602	VLADIMIR DENISOV	{"email": "vladimir-denisov1983@postgrespro.ru", "phone": "+70115492364"}
0005434735670	06C5EC	0646 664662	VARVARA SMIRNOVA	{"email": "smirnova-v_17071967@postgrespro.ru", "phone": "+70451582368"}
0005434735671	88D9FD	2484 268289	LYUDMILA KOZLOVA	{"email": "kozlova_l_1963@postgrespro.ru", "phone": "+70682744883"}
0005434735672	FE8911	2255 687764	ANNA MAKSIMOVA	{"phone": "+70621287962"}
0005434735673	E06585	1758 131468	PAVEL NIKITIN	{"email": "p-nikitin.011976@postgrespro.ru", "phone": "+70255894873"}
0005434735674	AB7656	4102 328063	NATALYA VASILEVA	{"email": "natalya_vasileva081981@postgrespro.ru", "phone": "+70881535218"}
0005434735675	AB7656	0487 621712	YURIY BELOV	{"phone": "+70447360845"}
0005434735676	C0CD3B	4215 070501	NATALYA NOVIKOVA	{"email": "natalya_novikova-1973@postgrespro.ru", "phone": "+70190949664"}
0005434735677	C0CD3B	3427 751457	ELENA FROLOVA	{"phone": "+70889222576"}
0005434735678	E53F91	9663 443551	NINA VASILEVA	{"phone": "+70026689569"}
0005434735679	AB9140	8935 838789	VIKTORIYA DAVYDOVA	{"email": "davydova_v-25081972@postgrespro.ru", "phone": "+70568736498"}
0005434735680	588E57	5765 472078	OLGA ALEKSEEVA	{"phone": "+70025111621"}
0005434735681	9D054E	0717 189937	NATALYA VASILEVA	{"phone": "+70719145737"}
0005434735682	B52EDA	5397 779244	TATYANA PAVLOVA	{"phone": "+70878722641"}
0005434735683	22F48C	4995 454587	NATALIYA IVANOVA	{"email": "ivanovanataliya.1976@postgrespro.ru", "phone": "+70871866292"}
0005434735684	2E2813	2050 478688	LEONID BONDARENKO	{"email": "bondarenko_leonid-1969@postgrespro.ru", "phone": "+70160335923"}
0005434735685	2E2813	0023 750404	VASILIY NOVIKOV	{"email": "vnovikov_17111971@postgrespro.ru", "phone": "+70097689265"}
0005434735686	2E2813	0761 038421	NATALYA SOKOLOVA	{"email": "sokolova-n-071967@postgrespro.ru", "phone": "+70039984359"}
0005434735687	F50D81	8854 532754	VYACHESLAV BONDARENKO	{"phone": "+70533930643"}
0005434735688	1B93B7	7041 963761	POLINA ZHUKOVA	{"phone": "+70958165399"}
0005434735689	1B93B7	9512 311677	VALERIY SOLOVEV	{"email": "solovev.valeriy-1966@postgrespro.ru", "phone": "+70668093943"}
0005434735690	E503EF	8263 589115	LARISA MATVEEVA	{"email": "l_matveeva.111972@postgrespro.ru", "phone": "+70546296409"}
0005434735691	35458A	2876 505405	SERGEY CHERNOV	{"email": "s.chernov_041979@postgrespro.ru", "phone": "+70554715550"}
0005434735692	35458A	0804 930671	ALEKSANDR NAZAROV	{"phone": "+70104488370"}
0005434735693	2D0D6D	4558 402837	BORIS STEPANOV	{"email": "boris.stepanov.111979@postgrespro.ru", "phone": "+70926127624"}
0005434735694	C9149A	3572 054174	YURIY GAVRILOV	{"phone": "+70609166020"}
0005434735695	C9149A	4000 464881	NATALYA KUZNECOVA	{"phone": "+70063901427"}
0005434735696	C9149A	7491 129993	ANZHELA TARASOVA	{"phone": "+70672398835"}
0005434735697	9C2B0A	9804 341256	DMITRIY ZHURAVLEV	{"phone": "+70026939016"}
0005434735698	09D65F	9497 160944	ANTONINA DENISOVA	{"phone": "+70000970533"}
0005434735700	24D48A	5356 375182	DMITRIY TARASOV	{"email": "dmitriytarasov031973@postgrespro.ru", "phone": "+70150985379"}
0005434735701	24D48A	6244 332936	YURIY SOKOLOV	{"phone": "+70168950923"}
0005434735702	E67614	3831 064223	YULIYA KISELEVA	{"phone": "+70186640939"}
0005434735703	AAE844	5898 666627	VERA SOROKINA	{"email": "sorokinavera_1987@postgrespro.ru", "phone": "+70023803640"}
0005434735704	93828D	0187 667737	VLADISLAV IVANOV	{"email": "vladislavivanov_1982@postgrespro.ru", "phone": "+70373083193"}
0005434735705	93828D	1851 831239	LIDIYA KUZMINA	{"phone": "+70778577645"}
0005434735706	93828D	8619 952429	ALEKSANDR NOVIKOV	{"phone": "+70933496116"}
0005434735707	9991B6	6538 934331	ALEKSANDR ZHUKOV	{"email": "zhukova-101989@postgrespro.ru", "phone": "+70795555746"}
0005434735708	9991B6	7156 139010	EVGENIY FILIPPOV	{"phone": "+70176573987"}
0005434735709	C11FF5	3662 875766	KIRILL FEDOTOV	{"email": "fedotov_kirill_1988@postgrespro.ru", "phone": "+70006871376"}
0005434735710	C11FF5	8617 100202	LYUBOV KOROLEVA	{"phone": "+70257010928"}
0005434735711	F51442	4854 500632	ALEKSANDR ANTONOV	{"phone": "+70511821427"}
0005434735712	B0462D	0492 757895	ELENA KONOVALOVA	{"email": "konovalova-elena101970@postgrespro.ru", "phone": "+70603559712"}
0005434735713	B0462D	6326 455305	NIKOLAY NAZAROV	{"email": "nazarovn_1972@postgrespro.ru", "phone": "+70961817926"}
0005434735714	9179F7	8003 808952	GALINA GERASIMOVA	{"phone": "+70682665498"}
0005434735715	70909A	1661 216193	ANTONINA FEDOROVA	{"phone": "+70659973356"}
0005434735716	70909A	6072 710968	DENIS STEPANOV	{"phone": "+70521954455"}
0005434735717	EC30B2	1508 796863	NIKOLAY PETROV	{"phone": "+70993360900"}
0005434735718	903886	6657 227416	SVETLANA STEPANOVA	{"email": "stepanova.svetlana-05011978@postgrespro.ru", "phone": "+70063787293"}
0005434735719	40B74A	6830 121419	SERAFIMA TIKHONOVA	{"phone": "+70434793561"}
0005434735720	B7D089	3686 041836	SVETLANA POPOVA	{"email": "s_popova12121979@postgrespro.ru", "phone": "+70600617734"}
0005434735721	B7D089	5629 227167	YURIY IVANOV	{"phone": "+70105949355"}
0005434735722	B93A5D	5476 812784	OLEG SIDOROV	{"phone": "+70701241323"}
0005434735723	1188D1	5859 533414	TAMARA GAVRILOVA	{"email": "tamaragavrilova_20081969@postgrespro.ru", "phone": "+70574851194"}
0005434735724	1188D1	6088 309882	DENIS MELNIKOV	{"phone": "+70645398760"}
0005434735725	0189E9	9053 684353	ALEKSANDR ILIN	{"phone": "+70192935765"}
0005434735726	D45803	4683 392470	TATYANA VOLKOVA	{"email": "t.volkova-051973@postgrespro.ru", "phone": "+70159482209"}
0005434735727	97B4AF	6044 683131	ELIZAVETA MATVEEVA	{"phone": "+70773717280"}
0005434735728	97B4AF	0301 368859	EKATERINA EFIMOVA	{"phone": "+70906588448"}
0005434735729	238A2B	5128 966747	ALEKSEY MIRONOV	{"phone": "+70372183636"}
0005434735730	238A2B	7658 971846	VALERIYA GUSEVA	{"email": "gusevav16101973@postgrespro.ru", "phone": "+70368947032"}
0005434735731	5F5E89	3154 582793	SERGEY AFANASEV	{"email": "afanasevsergey.1967@postgrespro.ru", "phone": "+70673732859"}
0005434735732	2BD612	8726 310091	ZOYA IVANOVA	{"phone": "+70544718096"}
0005434735733	2BD612	9326 482135	PETR ALEKSANDROV	{"phone": "+70869318595"}
0005434735734	2BD612	6988 551848	NINA MOROZOVA	{"email": "n_morozova.1961@postgrespro.ru", "phone": "+70221462165"}
0005434735735	0F0ABD	7638 519106	ALISA FEDOROVA	{"phone": "+70614996647"}
0005434735736	63D606	0168 442255	VLADIMIR MAKAROV	{"email": "vladimir.makarov121967@postgrespro.ru", "phone": "+70329306147"}
0005434735737	63D606	1792 699265	GRIGORIY MAKAROV	{"phone": "+70522574641"}
0005434735738	1E5BF4	2185 037955	ANDREY VASILEV	{"phone": "+70454208219"}
0005434735739	1E5BF4	3044 692310	EVGENIY VASILEV	{"email": "evgeniy.vasilev-1975@postgrespro.ru", "phone": "+70470725674"}
0005434735740	371DD0	8070 890866	DMITRIY GRIGOREV	{"phone": "+70054060700"}
0005434735741	DE6AC8	2884 069117	IVAN SAVELEV	{"phone": "+70265572624"}
0005434735742	B3C189	0709 780462	OLESYA EGOROVA	{"phone": "+70741482880"}
0005434735743	B3C189	4580 309409	VALENTINA MELNIKOVA	{"phone": "+70445313476"}
0005434735744	F1CBA2	5423 829235	VALENTINA OSIPOVA	{"phone": "+70740463750"}
0005434735745	DFF9E9	0233 359552	DARYA BELOVA	{"email": "darya-belova-1977@postgrespro.ru", "phone": "+70846895590"}
0005434735746	DFF9E9	9685 756581	ALEKSEY AFANASEV	{"email": "afanasev_a.09021976@postgrespro.ru", "phone": "+70711700003"}
0005434735747	DFF9E9	8227 589418	KSENIYA KUDRYASHOVA	{"phone": "+70560255911"}
0005434735748	681944	6542 648998	VALENTINA ALEKSEEVA	{"email": "alekseeva_v.1970@postgrespro.ru", "phone": "+70692182426"}
0005434735749	8C8AF9	8902 448647	GALINA KUZMINA	{"phone": "+70316681789"}
0005434735750	8C8AF9	5559 776689	VYACHESLAV ZAKHAROV	{"phone": "+70166128814"}
0005434735751	402F7F	1574 433599	ALEKSEY KRASNOV	{"email": "krasnov.aleksey1973@postgrespro.ru", "phone": "+70317742343"}
0005434735752	3078C6	2688 852047	VLADIMIR IVANOV	{"email": "ivanov-v.10091970@postgrespro.ru", "phone": "+70026816640"}
0005434735753	B43045	6151 458770	ANNA NESTEROVA	{"email": "anna_nesterova-17081971@postgrespro.ru", "phone": "+70886877561"}
0005434735754	6F334A	9083 930232	ALEKSANDRA MASLOVA	{"email": "maslova-a-1973@postgrespro.ru", "phone": "+70945389134"}
0005434735755	F8A0E9	7892 363431	SOFYA KOLESNIKOVA	{"email": "kolesnikovas_021968@postgrespro.ru", "phone": "+70631990682"}
0005434735756	835973	9588 359810	NADEZHDA KRASNOVA	{"phone": "+70073462323"}
0005434735757	835973	5904 597416	ALEKSEY PETROV	{"phone": "+70441605819"}
0005434735758	835973	2364 344399	LYUDMILA SOKOLOVA	{"email": "sokolova-l-27081969@postgrespro.ru", "phone": "+70888337991"}
0005434735759	84EAF1	0909 676924	PAVEL FEDOTOV	{"phone": "+70686736631"}
0005434735760	6082CD	9598 221558	ANDREY VOLKOV	{"phone": "+70773210804"}
0005434735761	6082CD	3110 980349	VLADIMIR NAZAROV	{"phone": "+70089392649"}
0005434735762	872A39	2629 308916	LARISA SOROKINA	{"phone": "+70219196169"}
0005434735763	138AF8	1713 404791	KONSTANTIN VASILEV	{"email": "kvasilev24011977@postgrespro.ru", "phone": "+70449102231"}
0005434735764	7C4336	6383 745157	VALENTIN ANTONOV	{"phone": "+70826996543"}
0005434735765	DA9ABB	2532 913520	VALENTINA EFIMOVA	{"email": "efimova_valentina_1978@postgrespro.ru", "phone": "+70506335323"}
0005434735766	DA9ABB	7662 989046	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva.14041965@postgrespro.ru", "phone": "+70562824311"}
0005434735767	3EA352	3690 141650	DENIS ANDREEV	{"email": "andreev-denis.061974@postgrespro.ru", "phone": "+70887673076"}
0005434735768	3EA352	7955 731350	ANNA YAKOVLEVA	{"email": "annayakovleva_021966@postgrespro.ru", "phone": "+70961085405"}
0005434735769	D07708	1361 658193	YULIYA IVANOVA	{"phone": "+70977425498"}
0005434735770	D07708	9566 352808	SNEZHANA KAZAKOVA	{"phone": "+70833353385"}
0005434735771	265923	8085 854859	ZINAIDA RYABOVA	{"phone": "+70228877910"}
0005434735772	4A7812	6089 424355	TATYANA VASILEVA	{"email": "tatyana.vasileva.14031988@postgrespro.ru", "phone": "+70289474282"}
0005434735773	AEDBC6	8403 686041	RAISA ROMANOVA	{"email": "r-romanova.1970@postgrespro.ru", "phone": "+70652616119"}
0005434735774	728DAD	4982 806966	VALENTINA TARASOVA	{"phone": "+70982239635"}
0005434735775	728DAD	5047 595020	OLGA SOLOVEVA	{"phone": "+70755249227"}
0005434735776	753B26	5344 079608	ELENA MOROZOVA	{"phone": "+70641588066"}
0005434735777	88CC56	2487 973564	LILIYA MAKSIMOVA	{"phone": "+70256203434"}
0005434735778	D95792	3859 743691	ANNA KOZLOVA	{"phone": "+70530434118"}
0005434735779	D95792	7895 212543	ALEKSANDR MOROZOV	{"phone": "+70924894611"}
0005434735780	63168A	4623 985080	SVETLANA MIRONOVA	{"email": "mironova_svetlana21031961@postgrespro.ru", "phone": "+70849378834"}
0005434735781	63168A	6096 904775	NATALYA DENISOVA	{"email": "natalya.denisova_061973@postgrespro.ru", "phone": "+70130018871"}
0005434735782	5E9DF4	9837 231653	NATALYA YUDINA	{"email": "yudina.n.041975@postgrespro.ru", "phone": "+70766273959"}
0005434735783	488F2D	5942 853246	ANATOLIY MIKHAYLOV	{"phone": "+70245393162"}
0005434735784	3722C1	6387 595804	TATYANA MEDVEDEVA	{"phone": "+70315493381"}
0005434735785	3722C1	3269 174037	NIKOLAY MIKHAYLOV	{"phone": "+70568853805"}
0005434735786	406E3F	2445 865397	ARSENIY MOROZOV	{"phone": "+70272852358"}
0005434735787	8032A1	9633 232298	TATYANA KAZAKOVA	{"email": "kazakovatatyana-051976@postgrespro.ru", "phone": "+70592773649"}
0005434735789	64AB73	1113 047246	ALEKSANDR PETROV	{"email": "aleksandr.petrov-1959@postgrespro.ru", "phone": "+70179541780"}
0005434735790	8C83B8	6000 747893	NATALYA SOKOLOVA	{"email": "natalyasokolova-081969@postgrespro.ru", "phone": "+70453417405"}
0005434735791	893FAD	0690 304709	NIKOLAY BELOV	{"email": "n-belov-20051971@postgrespro.ru", "phone": "+70181711024"}
0005434735792	47B703	6912 049289	ALEKSANDR KOZLOV	{"email": "akozlov.1974@postgrespro.ru", "phone": "+70898299910"}
0005434735793	47B703	9302 754120	ANZHELA ANDREEVA	{"email": "andreeva-anzhela-1976@postgrespro.ru", "phone": "+70682218419"}
0005434735794	CC60A0	3963 998794	GENNADIY SERGEEV	{"phone": "+70301108340"}
0005434735795	77157D	4715 669362	MIKHAIL DENISOV	{"email": "mikhail.denisov.1965@postgrespro.ru", "phone": "+70916782537"}
0005434735796	511580	0394 359477	ANNA EGOROVA	{"email": "egorovaanna_121968@postgrespro.ru", "phone": "+70790386146"}
0005434735797	511580	0837 962908	LYUBOV TIKHONOVA	{"email": "tikhonoval_111976@postgrespro.ru", "phone": "+70492580454"}
0005434735798	DB5BF1	1420 076119	VALENTINA ANISIMOVA	{"phone": "+70035433278"}
0005434735799	0C9748	4937 478901	SERGEY ALEKSEEV	{"email": "salekseev15101973@postgrespro.ru", "phone": "+70423532687"}
0005434735800	B72FEB	5841 675933	IVAN IVANOV	{"email": "i.ivanov_1979@postgrespro.ru", "phone": "+70469529486"}
0005434735801	273AFA	6785 164369	ILDAR MOROZOV	{"phone": "+70209450131"}
0005434735802	5A2E67	4173 937162	RAISA DMITRIEVA	{"email": "dmitrieva-raisa1969@postgrespro.ru", "phone": "+70356669118"}
0005434735803	644AFD	5536 427354	SERGEY ILIN	{"email": "ilins-101969@postgrespro.ru", "phone": "+70924112334"}
0005434735804	644AFD	4202 729546	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey_1978@postgrespro.ru", "phone": "+70310412718"}
0005434735805	DD4E0F	1802 390025	RINAT NIKOLAEV	{"email": "r.nikolaev-08061973@postgrespro.ru", "phone": "+70936113341"}
0005434735806	DD4E0F	4995 830032	EGOR SEMENOV	{"phone": "+70855395889"}
0005434735807	33DF55	3205 305561	LYUDMILA MIRONOVA	{"phone": "+70782999538"}
0005434735808	4BBF4C	4206 656082	DENIS FROLOV	{"phone": "+70840665124"}
0005434735809	F7F514	6810 403590	LYUBOV LUKYANOVA	{"phone": "+70902046507"}
0005434735810	263BFA	1942 977294	TATYANA MAKAROVA	{"email": "tatyanamakarova_111958@postgrespro.ru", "phone": "+70612791656"}
0005434735811	438D7C	3778 608109	LYUBOV ERMAKOVA	{"phone": "+70464832043"}
0005434735812	41C835	3777 863752	DMITRIY GUSEV	{"phone": "+70540850794"}
0005434735813	34555B	9548 195456	IRINA MAKAROVA	{"email": "makarova.irina1975@postgrespro.ru", "phone": "+70402816763"}
0005434735814	1B8749	0392 276793	VLADISLAV YAKOVLEV	{"email": "vladislavyakovlev121971@postgrespro.ru", "phone": "+70009648508"}
0005434735815	1B8749	4480 229692	LIDIYA KOLESNIKOVA	{"email": "l.kolesnikova_101976@postgrespro.ru", "phone": "+70277237707"}
0005434735816	1B8749	6315 429063	VALERIY BORISOV	{"email": "v_borisov.1974@postgrespro.ru", "phone": "+70383846783"}
0005434735817	9DEA6F	4096 826832	GALINA ROMANOVA	{"phone": "+70378932890"}
0005434735818	9DEA6F	4279 885623	ALEKSANDR KUZNECOV	{"email": "akuznecov-27011964@postgrespro.ru", "phone": "+70915540382"}
0005434735819	AF7B5A	1522 434395	TATYANA BELOVA	{"email": "belova.tatyana_051972@postgrespro.ru", "phone": "+70741916427"}
0005434735820	AF7B5A	7615 549777	LYUDMILA VASILEVA	{"email": "lvasileva.16091973@postgrespro.ru", "phone": "+70619897980"}
0005434735821	35E066	2394 740734	NIKOLAY PAVLOV	{"phone": "+70178331688"}
0005434735822	8DE4CA	6427 482120	MARINA MAKAROVA	{"phone": "+70933161292"}
0005434735823	783209	3485 944727	ANASTASIYA BARANOVA	{"email": "baranovaa-031971@postgrespro.ru", "phone": "+70884206109"}
0005434735824	91C1D9	7939 646567	NADEZHDA KOZLOVA	{"email": "kozlova.nadezhda-23091974@postgrespro.ru", "phone": "+70322128460"}
0005434735825	463686	8393 962488	NINA KAZAKOVA	{"email": "nkazakova.1966@postgrespro.ru", "phone": "+70613551374"}
0005434735826	EAFFC6	7798 178599	VALENTIN SERGEEV	{"email": "valentin.sergeev_111967@postgrespro.ru", "phone": "+70384410981"}
0005434735827	BFCD83	2523 427100	KRISTINA PETROVA	{"email": "petrova-k_08061983@postgrespro.ru", "phone": "+70587538848"}
0005434735828	BFCD83	1938 939633	ANTON NIKOLAEV	{"phone": "+70155438536"}
0005434735829	08EF3C	8632 916700	ALEKSANDR DENISOV	{"email": "denisovaleksandr-051976@postgrespro.ru", "phone": "+70746757321"}
0005434735830	08EF3C	8077 664090	ALEKSANDR ISAEV	{"email": "aisaev1983@postgrespro.ru", "phone": "+70075574359"}
0005434735831	41DE8D	6598 318474	LYUDMILA IVANOVA	{"phone": "+70453067210"}
0005434735832	70DDEF	6566 256759	ILDAR ORLOV	{"phone": "+70653311336"}
0005434735833	6190E4	8160 859974	DMITRIY IVANOV	{"email": "d-ivanov23111975@postgrespro.ru", "phone": "+70591917657"}
0005434735834	6190E4	4543 659957	DMITRIY DAVYDOV	{"phone": "+70931015972"}
0005434735835	27A89E	9042 686309	RAISA CHERNOVA	{"phone": "+70800261328"}
0005434735836	1798F9	9886 777457	ALEKSEY SHEVCHENKO	{"email": "aleksey-shevchenko-19071977@postgrespro.ru", "phone": "+70792920951"}
0005434735837	1798F9	0107 095973	NATALYA ROMANOVA	{"email": "natalya_romanova.041977@postgrespro.ru", "phone": "+70613264558"}
0005434735838	5328FE	3922 005994	MATVEY RODIONOV	{"phone": "+70018570470"}
0005434735839	12E931	5272 219281	OKSANA ANTONOVA	{"email": "antonovaoksana.27061967@postgrespro.ru", "phone": "+70745629640"}
0005434735840	12E931	6949 289857	VLADIMIR KRASNOV	{"phone": "+70419668184"}
0005434735841	A76F81	7103 205653	ANNA OSIPOVA	{"email": "aosipova_16061977@postgrespro.ru", "phone": "+70708983008"}
0005434735842	A76F81	2397 303989	GALINA DAVYDOVA	{"email": "galinadavydova-1973@postgrespro.ru", "phone": "+70994689418"}
0005434735843	BD9C21	5391 165299	VLADIMIR STEPANOV	{"email": "stepanov.vladimir-091975@postgrespro.ru", "phone": "+70455072575"}
0005434735844	BD9C21	8590 067308	MARIYA GUSEVA	{"phone": "+70825745503"}
0005434755720	DBE6EE	4360 254397	VALERIY VOROBEV	{"phone": "+70367535152"}
0005434755703	F931C1	2229 170404	EVGENIY FROLOV	{"phone": "+70887399058"}
0005434755704	F931C1	8956 853617	GULSHAT ANTONOVA	{"email": "g_antonova_25041968@postgrespro.ru", "phone": "+70504393637"}
0005434755705	49C8C5	3378 162516	VERA ANDREEVA	{"email": "andreevavera05081967@postgrespro.ru", "phone": "+70646187542"}
0005434755706	49C8C5	3303 199802	TAMARA STEPANOVA	{"email": "stepanova.tamara1975@postgrespro.ru", "phone": "+70203418305"}
0005434755707	326BCE	7144 723822	MAKAR ZAKHAROV	{"email": "zakharov-makar-081963@postgrespro.ru", "phone": "+70530634461"}
0005434755708	480A74	9279 168836	ALEKSANDR ANDREEV	{"email": "andreeva.20031967@postgrespro.ru", "phone": "+70003199009"}
0005434755709	560EAE	9139 218443	ANDREY VASILEV	{"email": "a_vasilev111974@postgrespro.ru", "phone": "+70501107837"}
0005434755710	A91941	3842 909011	NADEZHDA ARKHIPOVA	{"email": "arkhipova_n_121976@postgrespro.ru", "phone": "+70984521657"}
0005434755711	5233DF	2320 261603	ANTONINA FILATOVA	{"phone": "+70347265909"}
0005434755712	5233DF	6839 346644	ANTONINA SOLOVEVA	{"email": "a-soloveva.111970@postgrespro.ru", "phone": "+70284759397"}
0005434755713	759D30	0788 641086	ALEKSEY VASILEV	{"email": "avasilev-24051973@postgrespro.ru", "phone": "+70512066283"}
0005434755714	759D30	9450 319121	EKATERINA DMITRIEVA	{"phone": "+70637627921"}
0005434755715	33A168	5219 275529	VLADIMIR KISELEV	{"email": "vladimir-kiselev-18111974@postgrespro.ru", "phone": "+70298150570"}
0005434755716	33A168	2591 646197	ZOYA KOMAROVA	{"phone": "+70243743488"}
0005434755717	FC453A	0557 567433	NIKOLAY NIKITIN	{"email": "n.nikitin.071976@postgrespro.ru", "phone": "+70720753979"}
0005434755718	E6B103	8880 681304	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr_24101969@postgrespro.ru", "phone": "+70371995434"}
0005434755719	F812F4	6372 514345	KONSTANTIN SERGEEV	{"email": "konstantin_sergeev-1953@postgrespro.ru", "phone": "+70458748254"}
0005434755721	DBE6EE	2042 800401	ANASTASIYA GAVRILOVA	{"phone": "+70949422292"}
0005434755722	2458A3	5558 713672	ANATOLIY KOZLOV	{"email": "a.kozlov-031965@postgrespro.ru", "phone": "+70408842056"}
0005434755723	6F0CE3	1675 961349	VALENTINA SMIRNOVA	{"phone": "+70640957380"}
0005434755724	338A6B	5715 219410	BORIS ISAEV	{"phone": "+70338707706"}
0005434755725	E4D7C8	1712 660177	MIKHAIL MIKHAYLOV	{"phone": "+70429873946"}
0005434755726	B2A923	7572 146904	TATYANA KOZLOVA	{"email": "t.kozlova1973@postgrespro.ru", "phone": "+70101126801"}
0005434755727	C7A9BE	3595 876317	YULIYA MAKSIMOVA	{"phone": "+70882411476"}
0005434755728	6897A1	2812 660032	VLADISLAV ISAEV	{"email": "vladislav-isaev_101982@postgrespro.ru", "phone": "+70549660155"}
0005434755729	1243E5	8297 493080	ALEKSEY NAZAROV	{"phone": "+70041001603"}
0005434755730	1243E5	4175 008227	VADIM KONOVALOV	{"phone": "+70401441789"}
0005434755731	0CDB46	0980 649811	OLGA LEBEDEVA	{"phone": "+70002993951"}
0005434755732	1F6A75	9417 488466	VERA ZAKHAROVA	{"phone": "+70653436396"}
0005434755733	8987DA	5219 894563	SVETLANA KONOVALOVA	{"phone": "+70470937919"}
0005434755734	1ECC2E	7698 367935	ELENA POLYAKOVA	{"email": "polyakova.e.28051970@postgrespro.ru", "phone": "+70659712957"}
0005434755735	1ECC2E	0859 355330	SERGEY DMITRIEV	{"email": "dmitriev_sergey121972@postgrespro.ru", "phone": "+70970671626"}
0005434755736	95F3AD	7838 719869	PAVEL PAVLOV	{"email": "pavlov-p.19071968@postgrespro.ru", "phone": "+70959339322"}
0005434755737	495EF9	7532 590674	OLGA ROMANOVA	{"email": "romanova.o1966@postgrespro.ru", "phone": "+70508163708"}
0005434755738	3F1589	8722 587767	ANDREY KUZNECOV	{"email": "andrey_kuznecov-22021968@postgrespro.ru", "phone": "+70805424700"}
0005434755739	504713	8228 848507	ANASTASIYA EFREMOVA	{"phone": "+70099168824"}
0005434755740	719A0A	5416 321439	ALIYA MAKAROVA	{"phone": "+70338060121"}
0005434755741	719A0A	4587 106093	MAKSIM VOLKOV	{"phone": "+70205264024"}
0005434755742	3DD561	7405 576345	MIKHAIL ZAKHAROV	{"email": "zakharov_m-061967@postgrespro.ru", "phone": "+70755347543"}
0005434755743	013796	3029 759819	TATYANA NESTEROVA	{"email": "nesterova_t-1971@postgrespro.ru", "phone": "+70814330377"}
0005434755744	3882A3	9680 862645	VYACHESLAV DMITRIEV	{"phone": "+70470450510"}
0005434755745	3882A3	7563 852888	PETR EGOROV	{"phone": "+70675737278"}
0005434755746	9A99E8	6467 184719	TATYANA BOGDANOVA	{"email": "bogdanovatatyana.18091969@postgrespro.ru", "phone": "+70112863655"}
0005434755747	4C2900	8303 127461	ELIZAVETA MAKSIMOVA	{"email": "maksimova_elizaveta121977@postgrespro.ru", "phone": "+70307143281"}
0005434755748	A27B22	8403 630090	ALEKSANDR NOVIKOV	{"phone": "+70981019361"}
0005434755749	063CC3	7982 356788	ARTEM KUZNECOV	{"email": "artem-kuznecov_29041967@postgrespro.ru", "phone": "+70723727917"}
0005434755750	6E2B4B	4486 738350	DMITRIY KOROLEV	{"email": "dmitriy_korolev-03091968@postgrespro.ru", "phone": "+70722562928"}
0005434755751	60D508	8781 557997	VASILIY SOROKIN	{"email": "sorokinv-1970@postgrespro.ru", "phone": "+70759868147"}
0005434755752	85FCE2	4103 541941	VYACHESLAV MEDVEDEV	{"email": "medvedev-vyacheslav1982@postgrespro.ru", "phone": "+70090170803"}
0005434755753	85FCE2	9866 909139	VLADIMIR IVANOV	{"email": "ivanovvladimir23081967@postgrespro.ru", "phone": "+70035288929"}
0005434755754	ACA9CC	1507 940289	SVETLANA KUDRYASHOVA	{"phone": "+70527804600"}
0005434755755	E64B8F	4902 056388	LARISA SMIRNOVA	{"phone": "+70531735874"}
0005434755756	A51479	9594 443086	NINA IVANOVA	{"phone": "+70558069737"}
0005434755757	A51479	6665 349086	KSENIYA MAKAROVA	{"email": "makarova-k30071960@postgrespro.ru", "phone": "+70197131090"}
0005434755758	A8D98D	6353 060516	ALEKSANDR ALEKSANDROV	{"phone": "+70259250935"}
0005434755759	2B7D91	8299 900176	ELENA KOLESNIKOVA	{"phone": "+70555881752"}
0005434755760	2B7D91	3065 366996	ARINA MIKHAYLOVA	{"phone": "+70088576861"}
0005434755761	58719F	4578 437045	ALEKSANDR DMITRIEV	{"phone": "+70556237775"}
0005434755762	FB0981	5921 972787	BORIS KUDRYASHOV	{"email": "boriskudryashov-07011973@postgrespro.ru", "phone": "+70146498055"}
0005434755763	FB0981	7086 048511	NIKOLAY SERGEEV	{"email": "n.sergeev1972@postgrespro.ru", "phone": "+70425679001"}
0005434755764	04E435	0583 763151	OLGA TIKHONOVA	{"email": "tikhonova_olga_30081973@postgrespro.ru", "phone": "+70170046995"}
0005434755765	8FDCC0	8875 185934	MAKSIM KULIKOV	{"phone": "+70477768729"}
0005434755766	6C9CA4	1657 631541	GALINA PAVLOVA	{"email": "g_pavlova-021959@postgrespro.ru", "phone": "+70465063606"}
0005434755767	D82826	2182 789413	VALERIYA SIDOROVA	{"phone": "+70877530861"}
0005434755768	CC1B24	7445 137584	IVAN NAZAROV	{"email": "i.nazarov-03091970@postgrespro.ru", "phone": "+70718693366"}
0005434755769	A6C013	2141 764447	VALENTINA IVANOVA	{"email": "ivanova-v.17011967@postgrespro.ru", "phone": "+70600911627"}
0005434755770	A6C013	8198 894730	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_041978@postgrespro.ru", "phone": "+70156695288"}
0005434755771	105C12	5128 788969	NIKOLAY YAKOVLEV	{"email": "yakovlevnikolay.081975@postgrespro.ru", "phone": "+70572809538"}
0005434755772	F9187A	8602 194820	ILNUR IVANOV	{"email": "i.ivanov.031965@postgrespro.ru", "phone": "+70388404808"}
0005434755773	CB1ED7	5822 252363	ANDREY EGOROV	{"email": "egorov.a-111973@postgrespro.ru", "phone": "+70200820063"}
0005434755774	E659F9	6165 698254	ALEKSANDR KOZLOV	{"phone": "+70833583397"}
0005434755775	E659F9	9535 682221	OKSANA STEPANOVA	{"phone": "+70883301495"}
0005434755776	CE08D1	0899 785801	SERGEY OSIPOV	{"email": "s-osipov081973@postgrespro.ru", "phone": "+70723337173"}
0005434755777	CE08D1	2452 918583	NINA EFREMOVA	{"email": "efremova-n101969@postgrespro.ru", "phone": "+70246255130"}
0005434755778	CE08D1	7935 248921	ALEKSEY BELOV	{"phone": "+70154151266"}
0005434755779	03D9C4	9539 549875	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr09051971@postgrespro.ru", "phone": "+70358516905"}
0005434755780	03D9C4	0390 768024	OLEG ANTONOV	{"email": "antonov.oleg_051977@postgrespro.ru", "phone": "+70012318820"}
0005434755781	758501	4604 939976	YULIYA ALEKSEEVA	{"email": "alekseeva.y1967@postgrespro.ru", "phone": "+70987488954"}
0005434755782	5BC7DA	2679 405922	OLEG TIMOFEEV	{"email": "o.timofeev.1970@postgrespro.ru", "phone": "+70363513452"}
0005434755783	7FBD2A	1963 938599	VIKTOR NAZAROV	{"email": "v-nazarov-1953@postgrespro.ru", "phone": "+70474784879"}
0005434755784	6FC8D3	0942 450039	YULIYA MOROZOVA	{"email": "yuliya.morozova-1968@postgrespro.ru", "phone": "+70187438341"}
0005434755785	6FC8D3	4530 853582	LILIYA IVANOVA	{"phone": "+70655994188"}
0005434755786	B7B0F5	3459 848029	EVGENIYA KUZNECOVA	{"email": "evgeniyakuznecova_101962@postgrespro.ru", "phone": "+70706224351"}
0005434755787	31FAE2	1393 919993	KRISTINA DAVYDOVA	{"email": "kristina_davydova_111971@postgrespro.ru", "phone": "+70321132727"}
0005434755788	130316	7170 295196	DARYA FEDOROVA	{"phone": "+70262517634"}
0005434755789	130316	0921 646165	SERGEY KUZNECOV	{"email": "kuznecovsergey-1967@postgrespro.ru", "phone": "+70160347871"}
0005434755790	F261C1	4257 338566	MAYYA KOVALEVA	{"phone": "+70347474575"}
0005434755791	2052EE	0967 989824	STANISLAV SCHERBAKOV	{"phone": "+70892569401"}
0005434755792	524AF6	1763 587084	ALEKSEY IVANOV	{"email": "ivanov-aleksey091977@postgrespro.ru", "phone": "+70464608302"}
0005434755793	A41AF4	4993 708642	EVGENIY VOLKOV	{"phone": "+70605170240"}
0005434755794	A41AF4	9660 077973	VALENTINA KUZNECOVA	{"phone": "+70712675723"}
0005434755795	D7C5F6	2010 432124	ANDREY VASILEV	{"email": "vasilev.andrey-041969@postgrespro.ru", "phone": "+70020327881"}
0005434755796	D7C5F6	5777 648323	YURIY MAKAROV	{"email": "makarov-y_091964@postgrespro.ru", "phone": "+70384365196"}
0005434755797	5E2565	0275 880492	VIKTOR MIKHAYLOV	{"email": "vmikhaylov051956@postgrespro.ru", "phone": "+70907138317"}
0005434755798	2F05E4	3864 315861	NATALYA MOROZOVA	{"email": "morozova.n.1961@postgrespro.ru", "phone": "+70913912530"}
0005434755799	C2064B	8574 940453	ELENA VOROBEVA	{"email": "vorobeva-e-101983@postgrespro.ru", "phone": "+70272858089"}
0005434755800	E4CBD4	9788 399124	OLGA RYABOVA	{"phone": "+70638917009"}
0005434755801	A3197E	2658 811280	VLADIMIR MIRONOV	{"email": "mironov.vladimir.1960@postgrespro.ru", "phone": "+70429765384"}
0005434755802	6C7296	1752 882315	ANNA ABRAMOVA	{"email": "abramova.a_27081971@postgrespro.ru", "phone": "+70838525374"}
0005434755803	6C7296	2556 047782	EKATERINA MEDVEDEVA	{"email": "medvedevae_101983@postgrespro.ru", "phone": "+70789113386"}
0005434755804	C8D8AB	2132 219489	VLADIMIR MIRONOV	{"phone": "+70046260088"}
0005434755805	C8D8AB	8177 872196	MARIYA MEDVEDEVA	{"email": "medvedeva_mariya-12041972@postgrespro.ru", "phone": "+70453064069"}
0005434755806	2DCBED	3947 851685	NATALYA MELNIKOVA	{"email": "melnikova.n-04061966@postgrespro.ru", "phone": "+70134475631"}
0005434755807	2DCBED	5677 502269	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova-24091967@postgrespro.ru", "phone": "+70681986755"}
0005434755808	4A9178	7554 774626	ALEKSEY KRASNOV	{"email": "a.krasnov.111975@postgrespro.ru", "phone": "+70378661615"}
0005434755809	DB7E3D	3178 260766	IVAN PAVLOV	{"email": "pavlov-i041970@postgrespro.ru", "phone": "+70189991280"}
0005434755810	DB7E3D	8369 724780	ANTONINA ARKHIPOVA	{"phone": "+70009765385"}
0005434755811	0152FF	1988 077810	SERGEY KARPOV	{"phone": "+70080362375"}
0005434755812	1FCEE3	5142 249052	MARINA NAZAROVA	{"phone": "+70822493141"}
0005434755813	4CE7A5	7992 334771	OLGA OVCHINNIKOVA	{"email": "ovchinnikova-olga-041966@postgrespro.ru", "phone": "+70356998218"}
0005434755814	4CE7A5	6516 978812	VLADIMIR VLASOV	{"phone": "+70720006192"}
0005434755815	2F548F	8843 481823	NIKOLAY ZAYCEV	{"email": "zaycev-nikolay061972@postgrespro.ru", "phone": "+70787204872"}
0005434755816	2F548F	6097 792015	ALEKSANDRA TROFIMOVA	{"email": "trofimova_aleksandra_021969@postgrespro.ru", "phone": "+70886867588"}
0005434755817	98C9D8	3438 050410	YURIY FEDOROV	{"phone": "+70162584641"}
0005434755818	75BF10	3249 222235	ANNA STEPANOVA	{"phone": "+70773844233"}
0005434755819	989659	4242 215693	TATYANA PETROVA	{"email": "t.petrova22071974@postgrespro.ru", "phone": "+70776827197"}
0005434755820	989659	3082 795406	RUSTAM ALEKSEEV	{"phone": "+70417180217"}
0005434755821	FB3FBE	5635 986910	GALINA KOZLOVA	{"email": "kozlova.g-08101972@postgrespro.ru", "phone": "+70305435007"}
0005434755822	70965A	1368 745383	ANDREY VOLKOV	{"email": "andrey.volkov_09101970@postgrespro.ru", "phone": "+70020951806"}
0005434755823	70965A	5091 516703	VALERIYA FROLOVA	{"email": "frolova.v-121984@postgrespro.ru", "phone": "+70440862346"}
0005434755824	997F69	3774 229318	MAKAR FROLOV	{"phone": "+70821528190"}
0005434755825	997F69	2322 942917	DMITRIY KOZLOV	{"email": "kozlov-dmitriy06071975@postgrespro.ru", "phone": "+70853611790"}
0005434755826	3C6F3A	1534 226459	ALEKSANDR VLASOV	{"email": "vlasovaleksandr21051973@postgrespro.ru", "phone": "+70596983865"}
0005434755827	3C6F3A	8486 108957	IRINA MIRONOVA	{"email": "i-mironova_051969@postgrespro.ru", "phone": "+70875117605"}
0005434755828	3C6F3A	1117 389321	VALENTINA KAZAKOVA	{"email": "valentina.kazakova1976@postgrespro.ru", "phone": "+70233204755"}
0005434755829	101B0D	4732 279130	ARSEN IVANOV	{"phone": "+70438897343"}
0005434755830	076B22	4421 087263	ALLA MOISEEVA	{"email": "moiseevaa_1974@postgrespro.ru", "phone": "+70765077751"}
0005434755831	076B22	9874 608340	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr_1967@postgrespro.ru", "phone": "+70719128395"}
0005434755832	94729F	5157 219886	NIKOLAY NAUMOV	{"phone": "+70774258607"}
0005434755833	0D814C	1923 637891	YULIYA ZAYCEVA	{"email": "zayceva.yuliya_19121969@postgrespro.ru", "phone": "+70930356769"}
0005434755834	0D814C	8773 189548	FAINA DANILOVA	{"email": "danilovaf_101965@postgrespro.ru", "phone": "+70186070149"}
0005434755835	0BA5D5	5338 253954	LARISA PETROVA	{"email": "larisa.petrova-041979@postgrespro.ru", "phone": "+70264267171"}
0005434755836	8B68F4	4385 260564	ALBINA KUDRYASHOVA	{"phone": "+70554544065"}
0005434755837	A01AE0	6484 853183	TATYANA POTAPOVA	{"phone": "+70593761568"}
0005434755838	F036E9	4865 565139	YULIYA ILINA	{"email": "y-ilina011966@postgrespro.ru", "phone": "+70388211596"}
0005434755839	F036E9	7918 180114	SERGEY ROMANOV	{"email": "s_romanov-31031972@postgrespro.ru", "phone": "+70845819481"}
0005434755840	A24961	3088 572942	ALEKSANDR SOKOLOV	{"phone": "+70083055950"}
0005434755841	B9D8EE	5158 034396	ALEKSANDR SAVELEV	{"email": "savelev.a_1973@postgrespro.ru", "phone": "+70287539934"}
0005434755842	B9D8EE	4358 113725	NIKOLAY TIKHONOV	{"phone": "+70471014840"}
0005434755843	B9C98D	7711 287940	NIKITA ZAKHAROV	{"email": "nikitazakharov.1959@postgrespro.ru", "phone": "+70090040023"}
0005434755844	9A6AB0	7249 903490	VASILIY BARANOV	{"phone": "+70561122347"}
0005434755845	C93838	4952 673295	SERGEY KONOVALOV	{"email": "konovalov.sergey_031965@postgrespro.ru", "phone": "+70901841834"}
0005434755846	C93838	1115 522396	ILNAR SEMENOV	{"phone": "+70742167143"}
0005434755847	F93D74	3265 886074	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.21021983@postgrespro.ru", "phone": "+70187460672"}
0005434755848	F93D74	1128 130798	LYUDMILA ANTONOVA	{"email": "l-antonova051969@postgrespro.ru", "phone": "+70272422614"}
0005434755849	4C2C29	8474 799058	LYUDMILA ANISIMOVA	{"email": "lyudmila-anisimova091985@postgrespro.ru", "phone": "+70477401899"}
0005434755850	4C2C29	2003 486974	STANISLAV KUZNECOV	{"phone": "+70373708883"}
0005434755851	C89A38	5312 268000	ELENA SAVELEVA	{"email": "saveleva_elena1964@postgrespro.ru", "phone": "+70788731496"}
0005434755852	8D2AB4	5531 278855	NIKITA MEDVEDEV	{"email": "n.medvedev.011963@postgrespro.ru", "phone": "+70400786199"}
0005434755853	E52752	9543 383248	IVAN ALEKSANDROV	{"phone": "+70852104385"}
0005434755854	E52752	4223 686622	LYUDMILA ANTONOVA	{"phone": "+70753431364"}
0005434755855	E52752	0194 347607	VADIM MIRONOV	{"phone": "+70806418809"}
0005434755856	FC6B82	0326 551726	NIKOLAY ZAKHAROV	{"email": "n-zakharov-04031978@postgrespro.ru", "phone": "+70595137867"}
0005434755857	FC6B82	2629 003604	SERGEY MATVEEV	{"email": "matveev.s_1976@postgrespro.ru", "phone": "+70374088785"}
0005434755858	EB39BE	9839 403060	DANIL MELNIKOV	{"email": "d_melnikov_1970@postgrespro.ru", "phone": "+70376485641"}
0005434755859	BD20C5	4434 571363	NADEZHDA KALININA	{"phone": "+70308177124"}
0005434755860	329D9B	7503 128323	VLADIMIR MOROZOV	{"phone": "+70653291541"}
0005434755861	8D4577	7873 661087	MARIYA IVANOVA	{"phone": "+70017328996"}
0005434755862	8D4577	4514 874707	GALINA DMITRIEVA	{"email": "galina-dmitrieva.29111967@postgrespro.ru", "phone": "+70674306610"}
0005434755863	8CD2B7	0633 616554	SERGEY BELOV	{"phone": "+70629703346"}
0005434755864	8CD2B7	5465 887811	NADEZHDA KUZNECOVA	{"phone": "+70415448239"}
0005434755865	069B1B	0425 335144	SERGEY MAKAROV	{"email": "makarovs071973@postgrespro.ru", "phone": "+70262005145"}
0005434755866	6C2DA1	9582 741490	MAKSIM SIDOROV	{"phone": "+70807494089"}
0005434755867	E95AC3	3003 350781	SVETLANA ZHUKOVA	{"email": "svetlanazhukova_11101974@postgrespro.ru", "phone": "+70398151452"}
0005434755868	60FA2C	8757 276449	SERGEY NAUMOV	{"phone": "+70618309897"}
0005434755869	E1056C	1102 160768	MAKSIM ZAKHAROV	{"email": "zakharovm.051979@postgrespro.ru", "phone": "+70108529911"}
0005434755870	A18A95	1952 238958	SERGEY KARPOV	{"email": "sergey.karpov-1967@postgrespro.ru", "phone": "+70484014776"}
0005434755871	999DAB	6737 146372	LARISA NIKOLAEVA	{"email": "nikolaeva.l1971@postgrespro.ru", "phone": "+70033380723"}
0005434755872	999DAB	9192 311162	EKATERINA YAKOVLEVA	{"email": "yakovleva_ekaterina.1967@postgrespro.ru", "phone": "+70119746157"}
0005434755873	092AB9	1828 558821	ANASTASIYA ZAKHAROVA	{"email": "zakharova-a-1977@postgrespro.ru", "phone": "+70884532474"}
0005434755874	D90F06	1651 543838	LYUBOV MARTYNOVA	{"email": "martynova.lyubov1980@postgrespro.ru", "phone": "+70624832635"}
0005434755875	D90F06	5226 695301	ALEKSANDR KARPOV	{"phone": "+70518518912"}
0005434755876	B6CD25	8137 770536	OKSANA POTAPOVA	{"phone": "+70665627892"}
0005434755877	614C85	9971 740099	NIKITA NOVIKOV	{"phone": "+70685166837"}
0005434755878	183C74	6156 648528	SVETLANA POPOVA	{"phone": "+70232413480"}
0005434755879	4C56B4	9246 695869	VLADISLAV POPOV	{"email": "popov-v.26121971@postgrespro.ru", "phone": "+70301001546"}
0005434755880	4C56B4	0076 386422	IRINA VLASOVA	{"phone": "+70460430559"}
0005434755881	0F5F0A	1012 326093	DMITRIY IVANOV	{"email": "d-ivanov.051971@postgrespro.ru", "phone": "+70792198121"}
0005434755882	71AF10	3224 333892	ALEKSEY KUZMIN	{"email": "kuzmin.a021982@postgrespro.ru", "phone": "+70279628674"}
0005434755883	6764C3	7002 284387	ELENA DAVYDOVA	{"email": "davydova_e-1961@postgrespro.ru", "phone": "+70186692549"}
0005434755884	81646F	5119 891409	TATYANA NESTEROVA	{"email": "nesterova-tatyana-091975@postgrespro.ru", "phone": "+70272981934"}
0005434755885	B67103	1542 036321	ELENA VASILEVA	{"email": "e_vasileva1985@postgrespro.ru", "phone": "+70045770520"}
0005434755886	5B4ADB	2794 195541	KONSTANTIN IVANOV	{"email": "k.ivanov-01111967@postgrespro.ru", "phone": "+70684109547"}
0005434755887	82A337	5675 716520	ALEKSEY IVANOV	{"phone": "+70567679103"}
0005434755888	443D9E	8949 571592	EKATERINA MAKAROVA	{"phone": "+70063130882"}
0005434755889	443D9E	9581 022780	PETR NAZAROV	{"email": "nazarov.petr1968@postgrespro.ru", "phone": "+70163447394"}
0005434755890	CA2980	4508 001321	NIKOLAY IVANOV	{"email": "nikolayivanov.22121966@postgrespro.ru", "phone": "+70111397771"}
0005434755891	CA2980	2689 335175	YURIY GAVRILOV	{"phone": "+70274415288"}
0005434755892	9A52A6	4115 215382	VALENTINA NIKITINA	{"phone": "+70286247129"}
0005434755893	1BA5C0	2248 424659	OLGA ABRAMOVA	{"email": "olga.abramova-29011971@postgrespro.ru", "phone": "+70645952173"}
0005434755894	1BA5C0	8058 722480	VLADIMIR SCHERBAKOV	{"phone": "+70048492124"}
0005434755895	1BA5C0	3456 000744	VALENTINA YAKOVLEVA	{"email": "yakovleva_v.1966@postgrespro.ru", "phone": "+70671739510"}
0005434755896	1BA5C0	8133 243958	MAKSIM FEDOTOV	{"phone": "+70188812357"}
0005434755897	B529B1	2128 297113	VLADIMIR CHERNOV	{"email": "vladimir_chernov.15111979@postgrespro.ru", "phone": "+70781369154"}
0005434755898	B529B1	8008 763882	DARYA GRISHINA	{"email": "d.grishina_051975@postgrespro.ru", "phone": "+70984071156"}
0005434755899	4E71F0	2314 940843	VIKTORIYA AKIMOVA	{"email": "akimovav061970@postgrespro.ru", "phone": "+70729932847"}
0005434755900	8805BD	5980 305808	POLINA EGOROVA	{"email": "egorova_p_101981@postgrespro.ru", "phone": "+70559475056"}
0005434755901	390843	6661 997696	SERGEY VOLKOV	{"email": "sergeyvolkov_041981@postgrespro.ru", "phone": "+70700426830"}
0005434755902	60EF8C	2847 762205	DMITRIY ANDREEV	{"phone": "+70823872478"}
0005434755903	6C49D8	4229 684655	OLEG SEMENOV	{"email": "o.semenov.081963@postgrespro.ru", "phone": "+70683719412"}
0005434755904	89AFDF	7436 231631	ELIZAVETA KOVALEVA	{"email": "ekovaleva-121971@postgrespro.ru", "phone": "+70496864838"}
0005434755905	6A23AF	5017 995411	VALENTINA MAKAROVA	{"phone": "+70601787962"}
0005434755906	6A23AF	0615 464015	ALEKSANDR DAVYDOV	{"email": "a_davydov_1984@postgrespro.ru", "phone": "+70724276122"}
0005434755907	1877A8	0894 908595	VYACHESLAV PETROV	{"email": "vyacheslavpetrov.03051971@postgrespro.ru", "phone": "+70756475570"}
0005434755908	1877A8	0824 233724	ALENA MIRONOVA	{"email": "a-mironova12021979@postgrespro.ru", "phone": "+70057195924"}
0005434755909	8866BE	7680 914056	ALEKSANDR GAVRILOV	{"email": "agavrilov-011966@postgrespro.ru", "phone": "+70328837112"}
0005434755910	8866BE	9526 523856	VLADIMIR GRIGOREV	{"phone": "+70448319842"}
0005434755911	15D0E8	0646 210088	NADEZHDA KUZMINA	{"email": "nadezhda-kuzmina-1965@postgrespro.ru", "phone": "+70292597151"}
0005434755912	05BA5A	4392 961517	NATALYA KOROLEVA	{"phone": "+70001912241"}
0005434755913	B412A6	0602 888426	DMITRIY KUZNECOV	{"phone": "+70861351393"}
0005434755914	7E4491	9283 055138	SERGEY DMITRIEV	{"phone": "+70001629026"}
0005434755915	7E4491	4752 408858	MIKHAIL GORBUNOV	{"phone": "+70964627820"}
0005434755916	5FEB84	8410 814354	ARTEM MOROZOV	{"email": "artem-morozov_1973@postgrespro.ru", "phone": "+70751001586"}
0005434755917	726D6E	7799 464433	YURIY KULIKOV	{"phone": "+70858701547"}
0005434755918	726D6E	9240 039713	EVGENIY VASILEV	{"email": "vasilev_evgeniy-1963@postgrespro.ru", "phone": "+70219796447"}
0005434755919	A7FBFE	3986 247417	NINA LUKYANOVA	{"phone": "+70640406338"}
0005434755920	90700C	9977 516359	EKATERINA MELNIKOVA	{"email": "melnikova-ekaterina_03121972@postgrespro.ru", "phone": "+70725547081"}
0005434755921	90700C	3905 895739	VLADISLAV POPOV	{"phone": "+70753737797"}
0005434755922	622133	4959 928131	TATYANA EFREMOVA	{"phone": "+70363667634"}
0005434755923	3F3757	5089 926043	OLEG AFANASEV	{"email": "oleg_afanasev.21011974@postgrespro.ru", "phone": "+70531086607"}
0005434755924	5D69B1	8162 741172	LARISA PAVLOVA	{"phone": "+70734980360"}
0005434755925	E697C9	4323 483126	PAVEL GORBUNOV	{"phone": "+70718893367"}
0005434755926	E697C9	7322 850588	NATALIYA KUZNECOVA	{"phone": "+70002763721"}
0005434755927	DEB1A3	7968 396631	ALEKSEY MAKSIMOV	{"email": "alekseymaksimov_071964@postgrespro.ru", "phone": "+70584556741"}
0005434755928	DEB1A3	6639 314612	PETR STEPANOV	{"phone": "+70978045551"}
0005434755929	1A26EF	2401 275380	MARINA NESTEROVA	{"email": "nesterova-marina23041958@postgrespro.ru", "phone": "+70546148591"}
0005434755930	4ED61F	6110 436695	IVAN NAZAROV	{"phone": "+70681426560"}
0005434755931	4ED61F	0515 305725	ELENA FROLOVA	{"email": "elena.frolova121974@postgrespro.ru", "phone": "+70065288616"}
0005434755932	4EE79D	3356 068628	DMITRIY FILIPPOV	{"phone": "+70235923252"}
0005434755933	4EE79D	5763 335974	NINA SERGEEVA	{"phone": "+70605538021"}
0005434755934	4EE79D	0793 906345	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr-13051970@postgrespro.ru", "phone": "+70774512849"}
0005434755935	C3674B	9323 149127	NINA DENISOVA	{"email": "nina.denisova-061966@postgrespro.ru", "phone": "+70956332025"}
0005434755936	C3674B	6880 173454	KSENIYA SOLOVEVA	{"email": "k-soloveva-06061966@postgrespro.ru", "phone": "+70099613712"}
0005434755937	A98A77	1844 485968	ALEKSANDR TIMOFEEV	{"phone": "+70409163656"}
0005434755938	FCEAE9	5677 163983	BOGDAN TARASOV	{"email": "bogdantarasov.15061987@postgrespro.ru", "phone": "+70925158376"}
0005434755939	FCEAE9	1217 688863	ALEKSEY SOLOVEV	{"phone": "+70921668622"}
0005434755940	D60EE5	7005 229256	MARINA CHERNOVA	{"phone": "+70562832790"}
0005434755941	D60EE5	1724 227540	NIKOLAY KULIKOV	{"phone": "+70441817891"}
0005434755942	D52427	1592 896140	DMITRIY IVANOV	{"phone": "+70775329231"}
0005434755943	B032FA	6780 586344	YULIYA GUSEVA	{"email": "guseva-y_1979@postgrespro.ru", "phone": "+70889453050"}
0005434755944	B032FA	4138 763256	DANILA EGOROV	{"email": "danila.egorov_081972@postgrespro.ru", "phone": "+70778180876"}
0005434755945	E24EE1	9514 729923	ALEKSANDR MIRONOV	{"phone": "+70556145896"}
0005434755946	E24EE1	5365 218305	TATYANA KUZMINA	{"email": "kuzminatatyana22111974@postgrespro.ru", "phone": "+70714521675"}
0005434755947	26DF71	5285 664689	ANNA POPOVA	{"phone": "+70710730248"}
0005434755948	26DF71	6860 113079	ANDREY GRIGOREV	{"email": "grigorev.a-051972@postgrespro.ru", "phone": "+70572970966"}
0005434755949	86971D	9370 122709	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.20021969@postgrespro.ru", "phone": "+70778395251"}
0005434755950	86971D	2392 417195	SVETLANA KOZLOVA	{"email": "svetlana.kozlova_1974@postgrespro.ru", "phone": "+70919305289"}
0005434755951	5EAB6A	2368 175695	VALERIY SERGEEV	{"phone": "+70773947885"}
0005434755952	CA4D83	5639 184515	ROMAN ROMANOV	{"phone": "+70057857958"}
0005434755953	CA4D83	1021 733430	ALEKSANDRA YAKOVLEVA	{"phone": "+70264311807"}
0005434755954	511775	5571 152001	SERGEY ZAYCEV	{"email": "zaycev_sergey_03041985@postgrespro.ru", "phone": "+70069725699"}
0005434755955	782B46	4478 721134	SERGEY MATVEEV	{"phone": "+70208886640"}
0005434755956	782B46	1464 096624	ALEKSANDR SHEVCHENKO	{"email": "a.shevchenko.121978@postgrespro.ru", "phone": "+70270922150"}
0005434755957	89C87E	1198 906848	MARAT SMIRNOV	{"phone": "+70189530892"}
0005434755958	70351D	4835 277427	VLADIMIR FILIPPOV	{"email": "v.filippov-1974@postgrespro.ru", "phone": "+70188964133"}
0005434755959	C70706	2774 186855	EKATERINA GRISHINA	{"email": "ekaterinagrishina031975@postgrespro.ru", "phone": "+70284606212"}
0005434755960	C70706	8283 962293	IRINA POPOVA	{"phone": "+70478372071"}
0005434755961	646EBB	6142 223142	SVETLANA KOVALEVA	{"email": "svetlana_kovaleva_1976@postgrespro.ru", "phone": "+70121507432"}
0005434755962	646EBB	7171 694006	DENIS MIKHAYLOV	{"phone": "+70550088465"}
0005434755963	3EA62B	2741 633443	YURIY VLASOV	{"email": "vlasovyuriy-27011983@postgrespro.ru", "phone": "+70619519638"}
0005434755964	510BB1	1638 785553	MARIYA ZAKHAROVA	{"phone": "+70172760334"}
0005434755965	596327	2046 709070	YURIY TIMOFEEV	{"phone": "+70201194628"}
0005434755966	F9DC62	7219 018817	DMITRIY IVANOV	{"phone": "+70200166656"}
0005434755967	845CC9	1600 883500	IRINA KONOVALOVA	{"email": "konovalova_i.1989@postgrespro.ru", "phone": "+70358247929"}
0005434755968	845CC9	6878 626318	VALENTINA OVCHINNIKOVA	{"phone": "+70663136616"}
0005434755969	BE4511	2514 103340	VLADIMIR SCHERBAKOV	{"phone": "+70025609701"}
0005434755970	BE4511	7626 673147	NATALYA FOMINA	{"email": "n_fomina_111979@postgrespro.ru", "phone": "+70622839568"}
0005434755971	A33DB7	3759 982564	IGOR FEDOTOV	{"phone": "+70440144539"}
0005434755972	A33DB7	5686 582302	SVETLANA POTAPOVA	{"email": "potapova.svetlana_20061963@postgrespro.ru", "phone": "+70533089887"}
0005434755973	DC27FD	6727 227189	IGOR MIRONOV	{"email": "mironov.igor_20041979@postgrespro.ru", "phone": "+70192464983"}
0005434755974	0446D9	8715 121705	VLADIMIR GORBUNOV	{"email": "gorbunov_v.27061970@postgrespro.ru", "phone": "+70023645409"}
0005434755975	8470B4	2534 469655	NATALYA EFREMOVA	{"email": "efremova-n-091969@postgrespro.ru", "phone": "+70790008857"}
0005434755976	03BC62	7319 725323	GALINA ALEKSEEVA	{"email": "g_alekseeva.121974@postgrespro.ru", "phone": "+70455110616"}
0005434755977	03BC62	6267 699271	OKSANA GRISHINA	{"email": "grishina-oksana-1969@postgrespro.ru", "phone": "+70474887179"}
0005434755978	3041B0	8812 322138	IVAN MIRONOV	{"email": "ivan-mironov1987@postgrespro.ru", "phone": "+70598805471"}
0005434755979	3041B0	9715 624968	IVAN CHERNOV	{"email": "chernovivan_1981@postgrespro.ru", "phone": "+70998816912"}
0005434755980	CC6DC9	0875 771141	YURIY GERASIMOV	{"phone": "+70880780368"}
0005434755981	CC6DC9	5088 276833	ALEKSANDR KONOVALOV	{"email": "konovalov-a-27071967@postgrespro.ru", "phone": "+70439048806"}
0005434755982	53A846	8851 796988	BORIS DMITRIEV	{"email": "boris_dmitriev_1971@postgrespro.ru", "phone": "+70596171191"}
0005434755983	E515CF	0309 762831	VLADIMIR NIKOLAEV	{"email": "nikolaev_vladimir_1964@postgrespro.ru", "phone": "+70442902842"}
0005434755984	B3B6D6	2291 909961	IVAN FEDOROV	{"email": "fedorov.ivan-17021977@postgrespro.ru", "phone": "+70020092719"}
0005434755985	4A4164	6061 340096	SERGEY KULIKOV	{"phone": "+70302586672"}
0005434756041	B83188	1218 671810	MIKHAIL KOZLOV	{"phone": "+70398150964"}
0005434755986	1211B0	2078 281477	ZINAIDA IVANOVA	{"email": "ivanova-z081965@postgrespro.ru", "phone": "+70371715707"}
0005434755987	3806DC	0286 302578	DENIS KUDRYASHOV	{"email": "denis.kudryashov-1970@postgrespro.ru", "phone": "+70415954016"}
0005434755988	4B1C65	5905 883724	ANNA MIKHAYLOVA	{"phone": "+70724904097"}
0005434755989	08EEC1	4764 851770	GULNARA DANILOVA	{"email": "gulnaradanilova.101970@postgrespro.ru", "phone": "+70848497039"}
0005434755990	860D10	3059 143350	ROMAN MAKAROV	{"email": "makarov.r.20121978@postgrespro.ru", "phone": "+70695221957"}
0005434755991	860D10	4768 247116	DARYA NOVIKOVA	{"email": "novikovadarya_1979@postgrespro.ru", "phone": "+70987287664"}
0005434755992	6A5AEF	7064 554575	ANATOLIY SERGEEV	{"phone": "+70516940512"}
0005434755993	46A2CE	5443 414818	MARINA ANDREEVA	{"phone": "+70283660727"}
0005434755994	273F02	4587 261801	IRINA MIKHAYLOVA	{"email": "mikhaylova.irina_1965@postgrespro.ru", "phone": "+70140034938"}
0005434755995	92D4AC	4269 701337	ANATOLIY TIKHONOV	{"email": "tikhonov-a-15101967@postgrespro.ru", "phone": "+70519666963"}
0005434755996	D7EA46	5543 899053	DMITRIY NOVIKOV	{"email": "novikov_d.011969@postgrespro.ru", "phone": "+70447809890"}
0005434755997	D7EA46	0742 261551	ANDREY DAVYDOV	{"email": "davydov_a29031970@postgrespro.ru", "phone": "+70950136087"}
0005434755998	05BB0E	4506 355755	IRINA LEBEDEVA	{"phone": "+70492842719"}
0005434755999	05BB0E	1951 315293	VIKTOR KONOVALOV	{"email": "viktor-konovalov.071972@postgrespro.ru", "phone": "+70864281965"}
0005434756000	A40438	8181 821925	VLADIMIR SHEVCHENKO	{"phone": "+70612920368"}
0005434756001	528534	3610 673831	YULIYA MATVEEVA	{"email": "matveevay.101965@postgrespro.ru", "phone": "+70876172916"}
0005434756002	AC4EFB	6697 518592	IRINA VLASOVA	{"phone": "+70678018617"}
0005434756003	EE86A6	2239 816591	DMITRIY KUZNECOV	{"email": "kuznecov-d25031965@postgrespro.ru", "phone": "+70677296348"}
0005434756004	9299BA	1739 159909	ANATOLIY ILIN	{"email": "ilin-anatoliy_1960@postgrespro.ru", "phone": "+70745754346"}
0005434756005	9299BA	2950 655073	LYUDMILA MELNIKOVA	{"phone": "+70432158052"}
0005434756006	9299BA	5953 976493	KIRILL BARANOV	{"email": "baranovkirill.18041970@postgrespro.ru", "phone": "+70089745368"}
0005434756007	D534E1	6192 543224	DENIS SMIRNOV	{"email": "smirnov_denis_041970@postgrespro.ru", "phone": "+70069038094"}
0005434756008	E8A35E	9903 497727	IVAN MARTYNOV	{"phone": "+70904943991"}
0005434756009	C7F499	0600 786140	VERA TARASOVA	{"email": "tarasova-vera.081977@postgrespro.ru", "phone": "+70074828261"}
0005434756010	C7F499	9092 815022	VALENTINA ERMAKOVA	{"email": "v-ermakova_1980@postgrespro.ru", "phone": "+70994366560"}
0005434756011	77F7B9	8666 773796	KONSTANTIN ALEKSANDROV	{"phone": "+70041995553"}
0005434756012	D0E98E	2363 871050	MARGARITA MIRONOVA	{"email": "mironova_m.1969@postgrespro.ru", "phone": "+70844760387"}
0005434756013	B80D62	6897 446521	GENNADIY SMIRNOV	{"email": "gennadiy-smirnov_1971@postgrespro.ru", "phone": "+70888513663"}
0005434756014	22AE48	1493 410530	ZINAIDA MEDVEDEVA	{"email": "zinaida-medvedeva08081982@postgrespro.ru", "phone": "+70934011934"}
0005434756015	E927E6	6067 078380	NATALYA ZAKHAROVA	{"email": "zakharovan-07021970@postgrespro.ru", "phone": "+70597656107"}
0005434756016	4F1D99	7127 767682	DANIIL GAVRILOV	{"email": "d_gavrilov-081974@postgrespro.ru", "phone": "+70518082669"}
0005434756017	4F1D99	1430 932374	VITALIY NOVIKOV	{"phone": "+70923151363"}
0005434756018	E4073B	3363 455456	ILYA KUZMIN	{"email": "ilya_kuzmin.101982@postgrespro.ru", "phone": "+70576047275"}
0005434756019	E4073B	1560 733249	VLADIMIR VASILEV	{"email": "v_vasilev-111964@postgrespro.ru", "phone": "+70150281951"}
0005434756020	A696E1	8496 716715	NAIL GAVRILOV	{"phone": "+70386165147"}
0005434756021	A696E1	7558 421255	VERONIKA SOKOLOVA	{"email": "v-sokolova-1966@postgrespro.ru", "phone": "+70773271534"}
0005434756022	40E13A	3601 242487	ALEKSANDR KULIKOV	{"email": "aleksandr-kulikov.09021961@postgrespro.ru", "phone": "+70543448850"}
0005434756023	D59F2F	4186 995718	VALENTIN ORLOV	{"email": "orlov-v.03111958@postgrespro.ru", "phone": "+70238841103"}
0005434756024	411164	2651 510623	KONSTANTIN POPOV	{"phone": "+70156908379"}
0005434756025	411164	5843 536710	NIKOLAY SERGEEV	{"email": "sergeevnikolay.01031978@postgrespro.ru", "phone": "+70897178557"}
0005434756026	411164	1909 584119	ELENA MOISEEVA	{"email": "elena.moiseeva18021970@postgrespro.ru", "phone": "+70740785005"}
0005434756027	EB6925	3889 515535	ANASTASIYA STEPANOVA	{"phone": "+70932981162"}
0005434756028	1B2A6E	8821 760660	ALEKSANDR GORBUNOV	{"phone": "+70389465634"}
0005434756029	D10BAF	7708 071343	KRISTINA GUSEVA	{"phone": "+70820552078"}
0005434756030	50946F	8789 436754	NINA KOROLEVA	{"email": "korolevanina-1958@postgrespro.ru", "phone": "+70608551021"}
0005434756031	EF0702	6175 907237	DMITRIY EGOROV	{"email": "dmitriy.egorov.091978@postgrespro.ru", "phone": "+70850076476"}
0005434756032	EF0702	4337 199290	ALEKSANDR MIRONOV	{"phone": "+70159668845"}
0005434756033	6EE69E	9718 314882	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov26101980@postgrespro.ru", "phone": "+70524148583"}
0005434756034	C5B3D1	1166 842411	NATALIYA BARANOVA	{"phone": "+70817911881"}
0005434756035	C5B3D1	1522 385510	OKSANA BOGDANOVA	{"phone": "+70455035653"}
0005434756036	E6E24F	9765 565399	ARTEM NIKOLAEV	{"email": "artem.nikolaev.061978@postgrespro.ru", "phone": "+70756129557"}
0005434756037	DA6168	9917 774041	LARISA MIRONOVA	{"email": "larisamironova1968@postgrespro.ru", "phone": "+70626834231"}
0005434756038	209D83	1772 529938	VLADIMIR STEPANOV	{"phone": "+70413690666"}
0005434756039	209D83	6636 012233	GALINA KRASNOVA	{"phone": "+70520635307"}
0005434756040	25ABED	0032 069540	ANASTASIYA NIKITINA	{"email": "nikitina.a-1970@postgrespro.ru", "phone": "+70144919014"}
0005434756042	6ED8F1	2120 637822	ANTONINA MOISEEVA	{"email": "moiseevaa-20101981@postgrespro.ru", "phone": "+70175659413"}
0005434756043	6ED8F1	8472 415510	YURIY DMITRIEV	{"email": "dmitriev.yuriy-1967@postgrespro.ru", "phone": "+70630420421"}
0005434756044	EBA4B9	4012 859231	ANNA ANDREEVA	{"phone": "+70877291525"}
0005434756045	EBA4B9	0345 198522	ARKADIY ZHURAVLEV	{"email": "zhuravlev.arkadiy-1974@postgrespro.ru", "phone": "+70484930611"}
0005434756046	EBA4B9	6194 189902	ANDREY TIMOFEEV	{"phone": "+70878841438"}
0005434756047	87F8E8	2594 248304	NATALYA POPOVA	{"email": "natalyapopova17071983@postgrespro.ru", "phone": "+70749668385"}
0005434756048	230CE9	5305 108461	ROZALIYA KUZNECOVA	{"email": "kuznecova.r03061983@postgrespro.ru", "phone": "+70077959790"}
0005434756049	6218D4	9395 862306	SERGEY KUZMIN	{"phone": "+70861175053"}
0005434756050	6218D4	3214 902159	ANDREY ZAKHAROV	{"email": "zakharov.a11041966@postgrespro.ru", "phone": "+70773576536"}
0005434756051	F5C1F5	6096 614982	SERGEY SOKOLOV	{"phone": "+70676801328"}
0005434756052	57880E	2380 048023	GERMAN PETROV	{"phone": "+70728011622"}
0005434756053	5AAB04	3542 576637	VLADIMIR VLASOV	{"phone": "+70766070889"}
0005434756054	3C42BF	9984 045690	VALERIY KULIKOV	{"phone": "+70430517667"}
0005434756055	E34920	9882 068959	MIKHAIL FOMIN	{"email": "mikhail-fomin_011965@postgrespro.ru", "phone": "+70831657544"}
0005434756056	E34920	2117 304068	RUMIYA KUZMINA	{"email": "rkuzmina_29051981@postgrespro.ru", "phone": "+70364171727"}
0005434756057	E34920	6743 117695	YURIY SOROKIN	{"email": "yuriy.sorokin-1969@postgrespro.ru", "phone": "+70122934837"}
0005434756058	D3C975	5398 238941	ANNA FILATOVA	{"email": "filatova-anna_21091964@postgrespro.ru", "phone": "+70028913306"}
0005434756059	B8D7C9	4466 550045	IRINA TIMOFEEVA	{"email": "i-timofeeva05081968@postgrespro.ru", "phone": "+70877930803"}
0005434756060	B8D7C9	4818 944311	DANILA VOROBEV	{"email": "danilavorobev30101978@postgrespro.ru", "phone": "+70746250537"}
0005434756061	B8D7C9	6885 082500	MARINA IVANOVA	{"email": "m-ivanova_081983@postgrespro.ru", "phone": "+70237793610"}
0005434756062	FE6C43	7801 839588	LIDIYA NAZAROVA	{"phone": "+70952756532"}
0005434756063	FE6C43	7629 648250	OKSANA BORISOVA	{"email": "oksanaborisova1966@postgrespro.ru", "phone": "+70220351299"}
0005434756064	67C3E4	8607 658299	ANASTASIYA NIKOLAEVA	{"email": "anastasiya-nikolaeva.24081962@postgrespro.ru", "phone": "+70640992260"}
0005434756065	F589CF	7778 366441	OLEG NIKOLAEV	{"phone": "+70605658059"}
0005434756066	73C813	5265 442203	LIDIYA YAKOVLEVA	{"phone": "+70061097883"}
0005434756067	2E066D	3614 724687	NIKITA NIKOLAEV	{"email": "n.nikolaev.1975@postgrespro.ru", "phone": "+70035904639"}
0005434756068	C3A2F0	7852 053016	VLADIMIR KUZMIN	{"phone": "+70959340815"}
0005434756069	C7AABE	6462 486439	OLGA MELNIKOVA	{"phone": "+70871692601"}
0005434756070	839845	0731 980105	VLADIMIR VOROBEV	{"email": "vorobevv-041966@postgrespro.ru", "phone": "+70725700455"}
0005434756071	2596D3	1139 293690	GRIGORIY IVANOV	{"phone": "+70943839174"}
0005434756072	34331A	1695 712609	LIDIYA SERGEEVA	{"phone": "+70757108816"}
0005434756073	76030A	3956 927676	EKATERINA KAZAKOVA	{"phone": "+70317337588"}
0005434756074	014778	6882 772241	SERGEY KRASNOV	{"phone": "+70657939754"}
0005434756075	046807	7493 941450	ALEKSANDR SOLOVEV	{"email": "solovev-a_12051971@postgrespro.ru", "phone": "+70470718743"}
0005434756076	046807	0036 748036	NADEZHDA NAUMOVA	{"email": "n-naumova021976@postgrespro.ru", "phone": "+70440898682"}
0005434756077	755CB7	1112 408328	VLADIMIR SOLOVEV	{"email": "v.solovev-1964@postgrespro.ru", "phone": "+70652161872"}
0005434756078	755CB7	7890 332569	GALINA BORISOVA	{"phone": "+70320875709"}
0005434756079	755CB7	1525 232118	VARVARA TITOVA	{"email": "titova-varvara.04101975@postgrespro.ru", "phone": "+70600254696"}
0005434756080	8CFC11	7398 257087	VASILIY MELNIKOV	{"phone": "+70076903696"}
0005434756081	8CFC11	0487 529319	LARISA POPOVA	{"email": "popova_larisa_061963@postgrespro.ru", "phone": "+70257654680"}
0005434756082	45A02F	5301 681853	DMITRIY NAZAROV	{"phone": "+70990785286"}
0005434756083	45A02F	3406 224644	YULIYA MAKSIMOVA	{"phone": "+70692512048"}
0005434756084	45A02F	9974 122419	DMITRIY ANDREEV	{"email": "andreevdmitriy-071982@postgrespro.ru", "phone": "+70530302344"}
0005434756085	71150B	7024 974443	DENIS ILIN	{"phone": "+70535078954"}
0005434756086	5F26A9	3615 993325	IGOR ANDREEV	{"email": "igor_andreev_03101980@postgrespro.ru", "phone": "+70252421305"}
0005434756087	9EB671	1695 432915	ANDREY POPOV	{"phone": "+70101042713"}
0005434756088	0262D6	4648 179436	NIKOLAY ZHURAVLEV	{"phone": "+70289159501"}
0005434756089	402360	4218 151102	LYUDMILA KRASNOVA	{"email": "krasnova_lyudmila_101977@postgrespro.ru", "phone": "+70259581146"}
0005434756090	622079	0166 335663	LARISA SAVELEVA	{"phone": "+70208405011"}
0005434756091	1181CB	8979 529710	VALENTINA MIKHAYLOVA	{"email": "v.mikhaylova.071972@postgrespro.ru", "phone": "+70571736103"}
0005434756092	1181CB	2352 712927	VLADIMIR NAUMOV	{"phone": "+70368093262"}
0005434756093	F42848	2488 474837	PETR SOROKIN	{"email": "sorokin-petr1982@postgrespro.ru", "phone": "+70821566431"}
0005434756094	F42848	4253 802781	DIANA ROMANOVA	{"phone": "+70797799011"}
0005434756095	445CAF	3150 251945	DENIS ZHUKOV	{"phone": "+70586007741"}
0005434756096	24B3A3	9294 894980	ARTUR NOVIKOV	{"email": "novikova1972@postgrespro.ru", "phone": "+70634925867"}
0005434756097	E4A915	3520 642584	NIKITA KULIKOV	{"phone": "+70784422966"}
0005434756098	372940	5661 953903	NATALYA DAVYDOVA	{"email": "natalya-davydova_1974@postgrespro.ru", "phone": "+70046021747"}
0005434756099	CE7752	6332 750703	NATALYA FILATOVA	{"phone": "+70115533910"}
0005434756100	B9F979	5461 892348	ELENA ANDREEVA	{"phone": "+70401884619"}
0005434756101	BC99D1	6334 264328	OLGA ZAYCEVA	{"email": "zayceva_olga051972@postgrespro.ru", "phone": "+70779855092"}
0005434756102	BC99D1	0388 099906	VALENTINA MOROZOVA	{"email": "valentina-morozova-1974@postgrespro.ru", "phone": "+70929496979"}
0005434756103	39E24F	3047 073501	MIKHAIL KULIKOV	{"phone": "+70442331234"}
0005434756104	76CDB7	0615 054030	ANASTASIYA ZHUKOVA	{"email": "zhukova.a1969@postgrespro.ru", "phone": "+70663829361"}
0005434756105	E83A55	4928 845166	ALEKSANDR IVANOV	{"phone": "+70982251111"}
0005434756106	0828C1	4691 432699	RUSLAN KAZAKOV	{"phone": "+70410823751"}
0005434756107	530E1F	1278 071218	VLADIMIR MEDVEDEV	{"email": "medvedevv.1969@postgrespro.ru", "phone": "+70996011238"}
0005434756108	B7A01B	9089 771193	LYUDMILA NOVIKOVA	{"phone": "+70853842506"}
0005434756109	3F67B6	7098 926232	VLADIMIR FEDOROV	{"email": "vfedorov-28111968@postgrespro.ru", "phone": "+70064753245"}
0005434756110	3F67B6	7640 116828	ANATOLIY IVANOV	{"email": "ivanov_anatoliy011968@postgrespro.ru", "phone": "+70934819174"}
0005434756111	3F67B6	7764 251956	VIKTOR MAKSIMOV	{"phone": "+70545861595"}
0005434756112	1C783E	2917 405560	ELENA AKIMOVA	{"phone": "+70422459895"}
0005434756113	B402AF	4358 622951	GULNARA FILIPPOVA	{"email": "filippova.gulnara_1975@postgrespro.ru", "phone": "+70184289556"}
0005434756114	0F0096	0154 614517	VALERIY POPOV	{"phone": "+70184195425"}
0005434756115	E7B82E	7845 373058	ANATOLIY DENISOV	{"email": "denisovanatoliy06041977@postgrespro.ru", "phone": "+70246828300"}
0005434756116	980090	5470 544975	VIKTOR ZHURAVLEV	{"email": "zhuravlev.viktor1969@postgrespro.ru", "phone": "+70526830937"}
0005434756117	02051D	6622 624364	ANDREY RODIONOV	{"email": "a_rodionov-051971@postgrespro.ru", "phone": "+70478029733"}
0005434756118	CDEC35	5964 106106	TATYANA PETROVA	{"email": "tatyana-petrova_10061961@postgrespro.ru", "phone": "+70554757833"}
0005434756119	EF3E3F	8313 090342	MAKSIM IVANOV	{"email": "ivanov.m-021963@postgrespro.ru", "phone": "+70588445688"}
0005434756120	96D6AF	2348 859859	ALEKSANDR TIKHONOV	{"email": "aleksandr_tikhonov031986@postgrespro.ru", "phone": "+70859555521"}
0005434756121	96D6AF	2237 717687	SERGEY DAVYDOV	{"phone": "+70884212731"}
0005434756122	96D6AF	7103 219837	ELENA IVANOVA	{"phone": "+70463875344"}
0005434756123	51DEBE	2883 292476	TAMARA KUZNECOVA	{"phone": "+70917475683"}
0005434756124	B3CF92	4186 830405	VALENTINA IVANOVA	{"phone": "+70606441883"}
0005434756125	95A98C	5621 173096	VIKTORIYA NESTEROVA	{"email": "viktoriya.nesterova-1963@postgrespro.ru", "phone": "+70466711342"}
0005434756126	95A98C	3010 458419	ANNA ROMANOVA	{"phone": "+70815287975"}
0005434756127	C7C81A	1144 952844	DIANA SIDOROVA	{"phone": "+70777527869"}
0005434756128	2FC5D2	6048 412332	VIKTOR VOROBEV	{"phone": "+70947176297"}
0005434756129	2FC5D2	5392 866951	NIKOLAY OSIPOV	{"phone": "+70046125182"}
0005434756130	1E2651	9165 968449	YURIY IVANOV	{"email": "ivanov.y06121972@postgrespro.ru", "phone": "+70325835437"}
0005434756131	EB5B3C	2458 182884	ANDREY SHEVCHENKO	{"phone": "+70597219420"}
0005434756132	CFF47C	2804 061676	ILYA ORLOV	{"phone": "+70481096299"}
0005434756133	39718E	9365 488726	NATALIYA KOROLEVA	{"email": "nataliyakoroleva071970@postgrespro.ru", "phone": "+70742545497"}
0005434756134	E89E88	7151 682487	ALEKSANDR STEPANOV	{"email": "aleksandr_stepanov081971@postgrespro.ru", "phone": "+70102442723"}
0005434756135	F87A08	2927 603037	TATYANA KRASNOVA	{"phone": "+70547023965"}
0005434756136	668B90	7080 547460	ANATOLIY ALEKSEEV	{"email": "anatoliy-alekseev081963@postgrespro.ru", "phone": "+70552526262"}
0005434756137	86D6D3	0274 846248	MARIYA FEDOROVA	{"phone": "+70765023268"}
0005434756138	D6AA19	3773 500664	VALENTINA IVANOVA	{"email": "ivanovavalentina.05111982@postgrespro.ru", "phone": "+70745001985"}
0005434756139	CD55CA	5328 865245	ARTEM SEMENOV	{"phone": "+70368807971"}
0005434756140	CD55CA	2003 620992	NATALYA ILINA	{"phone": "+70127702599"}
0005434756141	CD55CA	9992 690360	VALENTINA MIKHAYLOVA	{"email": "mikhaylova.v1974@postgrespro.ru", "phone": "+70693564635"}
0005434756142	5DB907	1143 161851	VIKTOR PAVLOV	{"phone": "+70798723823"}
0005434756143	5DB907	4101 632627	NATALYA PETROVA	{"phone": "+70564675320"}
0005434756144	F75D5B	4475 785054	EVGENIYA VASILEVA	{"email": "evgeniya-vasileva_15021961@postgrespro.ru", "phone": "+70783837018"}
0005434756145	F75D5B	6434 812311	MAKSIM PETROV	{"phone": "+70907711213"}
0005434756146	B3D6DC	3313 320799	OLEG GUSEV	{"phone": "+70299125553"}
0005434756147	B84666	5567 665909	IRINA MAKAROVA	{"email": "irina_makarova_17041957@postgrespro.ru", "phone": "+70820368598"}
0005434756148	5C8C41	5091 867723	OLGA NESTEROVA	{"phone": "+70598037230"}
0005434756149	F39815	0465 410783	ANNA KULIKOVA	{"phone": "+70520068122"}
0005434756150	F39815	2821 191088	SERGEY MAKAROV	{"email": "s.makarov27071966@postgrespro.ru", "phone": "+70636079092"}
0005434756151	5AF093	9755 615349	OLGA ILINA	{"email": "olga-ilina.21121975@postgrespro.ru", "phone": "+70212761467"}
0005434756152	EC7A2C	9940 913797	ELENA SEMENOVA	{"email": "semenova_e.1984@postgrespro.ru", "phone": "+70802051506"}
0005434756153	F823C6	5513 540405	LYUDMILA KUZNECOVA	{"email": "lkuznecova_051972@postgrespro.ru", "phone": "+70735344402"}
0005434756154	438906	1487 895253	OLGA KUZNECOVA	{"email": "kuznecova.o.091975@postgrespro.ru", "phone": "+70906530950"}
0005434756155	438906	9739 357848	VIKTOR DENISOV	{"email": "v_denisov-111981@postgrespro.ru", "phone": "+70802413981"}
0005434756156	438906	9811 642406	ANDREY ILIN	{"phone": "+70494640605"}
0005434756157	C75788	9985 828960	ALEKSANDR BONDARENKO	{"email": "bondarenkoaleksandr_18041976@postgrespro.ru", "phone": "+70950133738"}
0005434756158	68A288	2068 644131	EDUARD ANDREEV	{"phone": "+70095363884"}
0005434756159	68A288	1232 730202	VIKTOR KOZLOV	{"phone": "+70920639796"}
0005434756160	AC07B9	0899 146390	ANDREY SMIRNOV	{"email": "smirnovandrey-15111972@postgrespro.ru", "phone": "+70153241246"}
0005434756161	BECAA5	0556 042567	MARIYA KUDRYASHOVA	{"phone": "+70973669725"}
0005434756162	4A0927	7022 649044	YURIY VLASOV	{"email": "vlasovyuriy-24071978@postgrespro.ru", "phone": "+70979921385"}
0005434756163	5C3D43	8427 996531	YULIYA SCHERBAKOVA	{"phone": "+70868430958"}
0005434756164	5C3D43	3126 080642	ALEKSEY VASILEV	{"email": "vasilevaleksey1966@postgrespro.ru", "phone": "+70944314374"}
0005434756165	0A047B	5511 814464	VIKTOR NIKOLAEV	{"email": "nikolaev_v_03041968@postgrespro.ru", "phone": "+70529751619"}
0005434756166	0A047B	6942 445509	SERGEY POPOV	{"phone": "+70391821903"}
0005434756167	026E5C	7337 668927	RAISA ANDREEVA	{"email": "raisa.andreeva1972@postgrespro.ru", "phone": "+70117223267"}
0005434756168	F274B7	0240 536920	DMITRIY SAVELEV	{"email": "d.savelev-1981@postgrespro.ru", "phone": "+70541804934"}
0005434756169	057793	1942 508910	VARVARA ZOTOVA	{"email": "zotova_v-04011981@postgrespro.ru", "phone": "+70035938254"}
0005434756170	F8801B	9436 634354	EKATERINA EFREMOVA	{"phone": "+70705517325"}
0005434756171	A1BE90	9941 274008	ALEKSEY FEDOROV	{"phone": "+70910413682"}
0005434756172	FE46E5	5664 071714	VIKTOR KOZLOV	{"phone": "+70451983361"}
0005434756173	2141FF	5763 349066	LYUDMILA KUZNECOVA	{"phone": "+70555025014"}
0005434756174	0A550F	1973 922332	NIKITA KUZNECOV	{"email": "kuznecov.nikita-121958@postgrespro.ru", "phone": "+70822041263"}
0005434756175	1D1602	0806 830822	TATYANA ZAKHAROVA	{"phone": "+70824888124"}
0005434756176	1D1602	3959 673623	DMITRIY FOMIN	{"email": "d-fomin1962@postgrespro.ru", "phone": "+70754086230"}
0005434756177	D643B4	8091 307704	SERGEY MAKAROV	{"phone": "+70461983669"}
0005434756178	348A10	5218 195860	OKSANA PETROVA	{"email": "oksana.petrova-101972@postgrespro.ru", "phone": "+70009797037"}
0005434756179	AD8423	9721 465276	IRINA FADEEVA	{"phone": "+70593445404"}
0005434756180	F2B813	9181 917025	RAISA CHERNOVA	{"email": "raisa.chernova.1967@postgrespro.ru", "phone": "+70500486585"}
0005434756181	F2B813	7472 001448	ANATOLIY YAKOVLEV	{"email": "yakovlev.a-16071968@postgrespro.ru", "phone": "+70906791428"}
0005434756182	02081E	2200 826008	MARIYA BOGDANOVA	{"email": "bogdanovam.31101968@postgrespro.ru", "phone": "+70901070382"}
0005434756183	448920	8668 418656	NATALYA MARTYNOVA	{"phone": "+70676949755"}
0005434756184	8E7F97	0373 688577	OLGA MASLOVA	{"phone": "+70353523417"}
0005434756185	8E7F97	7224 038144	INNA KUZNECOVA	{"phone": "+70060354774"}
0005434756186	336314	3701 289234	ALEKSEY KUZNECOV	{"email": "kuznecova.101980@postgrespro.ru", "phone": "+70595602767"}
0005434756187	9BE190	1109 021438	GALINA OVCHINNIKOVA	{"email": "ovchinnikova.galina1976@postgrespro.ru", "phone": "+70297044642"}
0005434756188	9BE190	5815 161709	OLEG KUDRYASHOV	{"phone": "+70539680278"}
0005434756189	5C75EC	0607 661223	KRISTINA MALYSHEVA	{"phone": "+70303587000"}
0005434756190	F85DDE	5099 789421	MARIYA FROLOVA	{"email": "mariya-frolova-06051971@postgrespro.ru", "phone": "+70442966062"}
0005434756191	F85DDE	4778 745480	EVGENIY ANTONOV	{"email": "e_antonov.071977@postgrespro.ru", "phone": "+70088922615"}
0005434756192	0FF58B	2110 435200	ANNA POPOVA	{"email": "popova_anna111982@postgrespro.ru", "phone": "+70929615467"}
0005434756193	DBE207	2064 932796	SVETLANA GAVRILOVA	{"email": "gavrilova-s1972@postgrespro.ru", "phone": "+70457835473"}
0005434756194	E7E938	2219 862644	RUSLAN KONOVALOV	{"phone": "+70650432244"}
0005434756195	552A1D	5374 688403	YURIY NIKOLAEV	{"email": "nikolaev.y_101969@postgrespro.ru", "phone": "+70653988417"}
0005434756196	552A1D	0814 282541	ALEKSEY MAKAROV	{"email": "makarova111974@postgrespro.ru", "phone": "+70417286161"}
0005434756197	22A3FB	7258 324987	NATALYA MIKHAYLOVA	{"phone": "+70918570549"}
0005434756198	7D96F6	4099 850903	ANTONINA ABRAMOVA	{"phone": "+70569517885"}
0005434756199	7D96F6	8610 650623	TATYANA POPOVA	{"phone": "+70149343909"}
0005434756200	072496	3750 176648	VIKTOR FEDOTOV	{"email": "vfedotov.24011968@postgrespro.ru", "phone": "+70205317360"}
0005434756201	3641D0	8268 374417	DMITRIY ILIN	{"email": "d.ilin1970@postgrespro.ru", "phone": "+70040737374"}
0005434756202	B11DC6	3105 870799	OLGA VOLKOVA	{"email": "volkova_o10041965@postgrespro.ru", "phone": "+70490625715"}
0005434756203	3083DE	4657 151276	NATALYA GUSEVA	{"email": "guseva-n28041962@postgrespro.ru", "phone": "+70328288592"}
0005434756204	3083DE	4414 844754	MAKSIM DAVYDOV	{"email": "davydov.m061979@postgrespro.ru", "phone": "+70538565184"}
0005434756205	AEE957	1350 780636	SERGEY KRASNOV	{"phone": "+70312087998"}
0005434756206	D78A8A	3901 501126	ELVIRA VASILEVA	{"phone": "+70749513724"}
0005434756207	D78A8A	4371 249224	VIKTORIYA MAKAROVA	{"phone": "+70898910345"}
0005434756208	F1AA02	2252 492091	EKATERINA TITOVA	{"email": "titovae21051983@postgrespro.ru", "phone": "+70358150062"}
0005434756209	B012FA	1195 322761	VLADISLAV BARANOV	{"phone": "+70159423846"}
0005434756210	60FBCF	9770 329264	MARIYA NOVIKOVA	{"email": "mariyanovikova-121979@postgrespro.ru", "phone": "+70516164383"}
0005434756211	E31879	1863 739734	SERGEY TIMOFEEV	{"email": "stimofeev-1967@postgrespro.ru", "phone": "+70799314982"}
0005434756212	0571D0	4121 102519	VIKTOR EGOROV	{"email": "egorovv.1966@postgrespro.ru", "phone": "+70120157324"}
0005434756213	0571D0	7239 279914	VALENTINA KOZLOVA	{"email": "v_kozlova.1966@postgrespro.ru", "phone": "+70095318186"}
0005434756214	1B2E87	8301 920428	DMITRIY PAVLOV	{"phone": "+70507313043"}
0005434756215	56CEF3	8002 338126	NADEZHDA PAVLOVA	{"phone": "+70275556204"}
0005434756216	56CEF3	5006 257524	IGOR MOROZOV	{"email": "morozov.igor_31051967@postgrespro.ru", "phone": "+70090917449"}
0005434756217	11A714	4952 187999	ANNA YUDINA	{"phone": "+70339343675"}
0005434756218	EB0B30	2563 989518	ALEKSANDR KOROLEV	{"email": "korolev.a1962@postgrespro.ru", "phone": "+70896925797"}
0005434756219	EB0B30	0594 107074	KSENIYA BELOVA	{"phone": "+70053373325"}
0005434756220	44FB3C	7350 156915	SERGEY NIKOLAEV	{"phone": "+70994275048"}
0005434756221	1AB0E3	7987 358864	GALINA POPOVA	{"email": "galina_popova-25031980@postgrespro.ru", "phone": "+70228314216"}
0005434756222	1AB0E3	4228 960287	ALEKSANDR AFANASEV	{"email": "afanaseva-031975@postgrespro.ru", "phone": "+70308164617"}
0005434756223	1AB0E3	8518 514416	DENIS KRASNOV	{"email": "deniskrasnov-1967@postgrespro.ru", "phone": "+70568845759"}
0005434756224	BEFD00	3763 330541	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev-091970@postgrespro.ru", "phone": "+70240913670"}
0005434756225	BEFD00	5985 591926	ALLA KUZMINA	{"phone": "+70746586452"}
0005434756226	2817DE	6577 313342	ALEKSANDR SAVELEV	{"email": "savelevaleksandr-031970@postgrespro.ru", "phone": "+70734130481"}
0005434756227	E2EB0D	4193 536015	VLADIMIR KUZNECOV	{"phone": "+70100681687"}
0005434756228	45475C	9095 970303	ALEKSEY MAKAROV	{"email": "makarov.a.01091969@postgrespro.ru", "phone": "+70993796462"}
0005434756229	45475C	2428 087496	MIKHAIL MAKSIMOV	{"phone": "+70458826596"}
0005434756230	45475C	0065 700656	DMITRIY ANDREEV	{"email": "andreev_d.16061971@postgrespro.ru", "phone": "+70877510982"}
0005434756231	B2A3CC	4964 965370	ELENA SERGEEVA	{"phone": "+70399194342"}
0005434756232	29080D	7046 626078	IRAIDA TARASOVA	{"email": "iraida.tarasova.041979@postgrespro.ru", "phone": "+70912370141"}
0005434756233	E8D96F	9903 939125	ALEKSANDR RODIONOV	{"phone": "+70561149482"}
0005434756234	F537F9	9742 229332	VERA KUZNECOVA	{"email": "kuznecova-vera_1970@postgrespro.ru", "phone": "+70715546965"}
0005434756235	ECFAE6	7121 227860	VLADIMIR SEMENOV	{"phone": "+70127027890"}
0005434756236	D0768C	0018 836595	OLGA PAVLOVA	{"email": "olga.pavlova_26081981@postgrespro.ru", "phone": "+70547320473"}
0005434756237	88F696	5325 622092	TAISIYA FROLOVA	{"phone": "+70868992867"}
0005434756238	88F696	2537 713359	NINA KUZMINA	{"email": "n-kuzmina.1970@postgrespro.ru", "phone": "+70983345093"}
0005434756239	9DC7E9	2387 225821	LIDIYA TIMOFEEVA	{"email": "lidiyatimofeeva-10051969@postgrespro.ru", "phone": "+70494981029"}
0005434756240	11207E	2263 466156	NINA MAKAROVA	{"email": "n.makarova.22061963@postgrespro.ru", "phone": "+70214584528"}
0005434756241	4F864F	8296 023157	ANDREY FILIPPOV	{"phone": "+70780808046"}
0005434756242	2EEDD6	7450 557273	ELIZAVETA AFANASEVA	{"email": "e.afanaseva_021974@postgrespro.ru", "phone": "+70054861145"}
0005434756243	4478C6	2853 629000	VIKTOR KONOVALOV	{"phone": "+70997285222"}
0005434756244	4478C6	5977 766756	NADEZHDA KRASNOVA	{"email": "krasnova-nadezhda.061977@postgrespro.ru", "phone": "+70706355857"}
0005434756245	006C55	7734 857380	YULIYA ZHUKOVA	{"phone": "+70591804952"}
0005434756246	1515F5	2062 654506	SERGEY SEMENOV	{"email": "semenovs1964@postgrespro.ru", "phone": "+70212114672"}
0005434756247	1515F5	4285 142987	ALENA LOGINOVA	{"email": "loginova-a19111976@postgrespro.ru", "phone": "+70873186177"}
0005434756248	86D13C	4615 359405	IRINA SEMENOVA	{"phone": "+70448793443"}
0005434756249	86D13C	4328 504350	ELENA DENISOVA	{"phone": "+70307341389"}
0005434756250	B6B6A3	4361 886599	ELENA YAKOVLEVA	{"email": "yakovleva-elena_20101968@postgrespro.ru", "phone": "+70115109005"}
0005434756251	B6B6A3	9341 442667	ALENA MAKAROVA	{"email": "a-makarova-081982@postgrespro.ru", "phone": "+70078668501"}
0005434756252	B6B6A3	7979 588681	ANDREY GORBUNOV	{"phone": "+70156933894"}
0005434756253	B6B6A3	0678 205432	TATYANA BELOVA	{"email": "belova-tatyana-04051964@postgrespro.ru", "phone": "+70856694892"}
0005434756254	196A6A	8887 959909	VALENTINA MATVEEVA	{"email": "matveevavalentina_1974@postgrespro.ru", "phone": "+70673622299"}
0005434756255	196A6A	6005 321206	FEDOR DMITRIEV	{"email": "dmitriev_fedor1986@postgrespro.ru", "phone": "+70491469152"}
0005434756256	1B08AA	1751 060474	ZINAIDA SOROKINA	{"email": "z_sorokina-1979@postgrespro.ru", "phone": "+70306811052"}
0005434756257	1B08AA	7545 571327	LYUDMILA VASILEVA	{"phone": "+70566667262"}
0005434756258	B30871	1253 067760	NADEZHDA GORBUNOVA	{"phone": "+70722346565"}
0005434756259	571CA7	3425 197850	ELENA KRASNOVA	{"phone": "+70862308913"}
0005434756260	571CA7	4549 505122	ALEKSANDRA MAKAROVA	{"phone": "+70830142907"}
0005434756261	0F827C	3530 436346	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov011978@postgrespro.ru", "phone": "+70030290927"}
0005434756262	B719F2	9033 356452	ALEKSANDR ROMANOV	{"phone": "+70193669589"}
0005434756263	508201	2539 811795	ARTEM KUZMIN	{"email": "kuzmin-a-051986@postgrespro.ru", "phone": "+70017247920"}
0005434756264	E3E3FE	2672 770015	TIMOFEY SEMENOV	{"email": "t_semenov031979@postgrespro.ru", "phone": "+70189182482"}
0005434756321	0FF7B4	2570 600501	TAMARA ANDREEVA	{"phone": "+70385921030"}
0005434756265	91F71B	9929 205133	VIKTOR BELOV	{"email": "v-belov.1973@postgrespro.ru", "phone": "+70351332036"}
0005434756266	9354F3	3863 208742	NATALIYA BELOVA	{"email": "n.belova1969@postgrespro.ru", "phone": "+70240610240"}
0005434756267	BE91F2	0928 678864	VERA KUZNECOVA	{"phone": "+70686618905"}
0005434756268	BE91F2	4825 875790	IRINA AFANASEVA	{"phone": "+70331237980"}
0005434756269	BE91F2	0744 138890	SERGEY DMITRIEV	{"phone": "+70100946141"}
0005434756270	7BFF1E	7357 685109	EKATERINA MASLOVA	{"phone": "+70815818692"}
0005434756271	98D0F8	8107 349745	VALERIY KUZMIN	{"email": "kuzminv.10111973@postgrespro.ru", "phone": "+70867026058"}
0005434756272	0090A5	3787 868415	IGOR NAUMOV	{"email": "igor-naumov-08031959@postgrespro.ru", "phone": "+70718438280"}
0005434756273	0090A5	5396 910032	ELENA ZAKHAROVA	{"email": "e_zakharova-071975@postgrespro.ru", "phone": "+70097927716"}
0005434756274	A6C35A	6042 716838	OKSANA ROMANOVA	{"email": "romanova_o_1965@postgrespro.ru", "phone": "+70549281647"}
0005434756275	487DEC	6681 682332	NIKOLAY PAVLOV	{"phone": "+70886416007"}
0005434756276	FA0CDF	9582 398998	LILIYA KUZMINA	{"phone": "+70702321827"}
0005434756277	995B0D	8979 708094	EVGENIYA IVANOVA	{"phone": "+70688983435"}
0005434756278	B5FF4A	5977 913046	NADEZHDA KUZNECOVA	{"phone": "+70243275416"}
0005434756279	8989D2	6591 028110	NATALYA GORBUNOVA	{"email": "gorbunova.n09111977@postgrespro.ru", "phone": "+70065000957"}
0005434756280	8989D2	5950 140107	VLADIMIR ILIN	{"email": "ilin-vladimir.1979@postgrespro.ru", "phone": "+70703891400"}
0005434756281	39A4D6	8774 688657	EVGENIY DAVYDOV	{"phone": "+70025959480"}
0005434756282	63DA21	6703 638461	NIKOLAY SCHERBAKOV	{"email": "scherbakovnikolay1966@postgrespro.ru", "phone": "+70635691502"}
0005434756283	63DA21	4911 663977	DARYA SEMENOVA	{"phone": "+70031290277"}
0005434756284	14D304	4804 511006	NIKOLAY VASILEV	{"phone": "+70153434543"}
0005434756285	14D304	5845 349302	IGOR VASILEV	{"phone": "+70061876203"}
0005434756286	3018FE	6041 424859	TATYANA OSIPOVA	{"phone": "+70939862666"}
0005434756287	370E68	0579 175175	STANISLAV VOLKOV	{"phone": "+70692478120"}
0005434756288	370E68	5057 440399	LIDIYA GAVRILOVA	{"email": "gavriloval-18071974@postgrespro.ru", "phone": "+70853787071"}
0005434756289	4494DC	3948 378463	RAFAEL KAZAKOV	{"phone": "+70525406156"}
0005434756290	F214F8	2513 657799	ANTON GAVRILOV	{"email": "gavrilovanton1978@postgrespro.ru", "phone": "+70645611330"}
0005434756291	680595	8625 661381	ALEKSANDR KUZNECOV	{"phone": "+70783630607"}
0005434756292	A129AA	6387 451997	DMITRIY SERGEEV	{"phone": "+70567202856"}
0005434756293	7F2C43	7830 219005	IGOR MOROZOV	{"phone": "+70265836414"}
0005434756294	F3C5CD	5632 261783	NIKOLAY POPOV	{"phone": "+70865183964"}
0005434756295	A34461	2177 953196	LIDIYA ANDREEVA	{"email": "lidiya_andreeva_02081977@postgrespro.ru", "phone": "+70069544528"}
0005434756296	90B72F	6621 385706	NINA DENISOVA	{"phone": "+70881929016"}
0005434756297	2C7A48	7116 446804	KLAVDIYA YAKOVLEVA	{"phone": "+70108775367"}
0005434756298	2C7A48	8675 969331	SVETLANA DMITRIEVA	{"email": "dmitrieva.s031967@postgrespro.ru", "phone": "+70980062563"}
0005434756299	4A987F	4290 537025	MARIYA NESTEROVA	{"email": "m.nesterova-1970@postgrespro.ru", "phone": "+70161685248"}
0005434756300	EC00C8	8348 930791	VIKTOR ZAKHAROV	{"email": "viktor-zakharov-1971@postgrespro.ru", "phone": "+70065036487"}
0005434756301	B61BAC	0147 830470	MARIYA ZAKHAROVA	{"email": "zakharova-mariya.27041964@postgrespro.ru", "phone": "+70407492619"}
0005434756302	A46D5A	8684 227762	DMITRIY MIRONOV	{"phone": "+70396712473"}
0005434756303	1C4B23	6723 791165	NINA KRASNOVA	{"phone": "+70567300445"}
0005434756304	1C4B23	7979 269885	ANNA KONDRATEVA	{"phone": "+70348438418"}
0005434756305	5CB720	5593 411535	NATALYA MAKAROVA	{"email": "makarova.natalya101969@postgrespro.ru", "phone": "+70541861741"}
0005434756306	5CB720	8396 322916	NIKOLAY STEPANOV	{"email": "stepanovn071974@postgrespro.ru", "phone": "+70261667857"}
0005434756307	2A6D05	8688 665466	ALISA NIKITINA	{"email": "nikitinaa1976@postgrespro.ru", "phone": "+70105929145"}
0005434756308	2A6D05	5239 318839	GALINA BARANOVA	{"email": "galina_baranova26111967@postgrespro.ru", "phone": "+70614601623"}
0005434756309	CA6195	1192 381661	ANDREY BELOV	{"phone": "+70374243750"}
0005434756310	CA6195	0581 790794	MATVEY BONDARENKO	{"email": "bondarenko_m-1977@postgrespro.ru", "phone": "+70330370501"}
0005434756311	5ED248	4523 109884	IVAN RODIONOV	{"phone": "+70322969062"}
0005434756312	5ED248	0350 129114	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.061964@postgrespro.ru", "phone": "+70005190468"}
0005434756313	1EB718	7033 008943	VIKTORIYA KONOVALOVA	{"email": "viktoriya.konovalova_19081975@postgrespro.ru", "phone": "+70713092018"}
0005434756314	7E13FB	3060 499110	IRINA NESTEROVA	{"phone": "+70646996879"}
0005434756315	7E13FB	9926 636997	ALEKSANDR GERASIMOV	{"phone": "+70341691217"}
0005434756316	E38C4C	2193 112133	EDUARD KAZAKOV	{"email": "eduard-kazakov_051964@postgrespro.ru", "phone": "+70448869217"}
0005434756317	E38C4C	7678 442905	OLGA NOVIKOVA	{"email": "o-novikova031981@postgrespro.ru", "phone": "+70943326107"}
0005434756318	E38C4C	0543 484708	ALINA KUZNECOVA	{"email": "alina-kuznecova-1974@postgrespro.ru", "phone": "+70293552675"}
0005434756319	8C168D	8831 818498	ELENA MAKSIMOVA	{"phone": "+70547015899"}
0005434756320	0FF7B4	5726 389364	DANIIL ALEKSANDROV	{"email": "d.aleksandrov.041969@postgrespro.ru", "phone": "+70978818736"}
0005434756322	3DE7C6	2251 544850	MARIYA IVANOVA	{"email": "mivanova-1965@postgrespro.ru", "phone": "+70902555360"}
0005434756323	4B6BF5	3853 783969	DMITRIY KUZNECOV	{"phone": "+70777180644"}
0005434756324	80E4BE	6782 883325	RUSLAN ORLOV	{"phone": "+70913418693"}
0005434756325	80E4BE	7937 668496	LIDIYA BELOVA	{"email": "lidiya.belova-011980@postgrespro.ru", "phone": "+70282263040"}
0005434756326	ACBBF9	8437 652177	LYUDMILA FROLOVA	{"phone": "+70553237145"}
0005434756327	ACBBF9	5575 641982	NADEZHDA ZHUKOVA	{"email": "n_zhukova_07041972@postgrespro.ru", "phone": "+70232199353"}
0005434756328	6426CC	5964 380991	KSENIYA FILIPPOVA	{"email": "kseniya_filippova_091966@postgrespro.ru", "phone": "+70225647857"}
0005434756329	BD8778	0053 739725	SERGEY KOZLOV	{"email": "kozlov_sergey.091984@postgrespro.ru", "phone": "+70180413634"}
0005434756330	8624CB	6317 082014	ANASTASIYA MALYSHEVA	{"phone": "+70486415974"}
0005434756331	E18208	6802 717569	EVGENIY MAKAROV	{"email": "evgeniy-makarov.081977@postgrespro.ru", "phone": "+70934635359"}
0005434756332	F13A1D	6237 510032	ALEKSANDR KISELEV	{"phone": "+70449648078"}
0005434756333	F13A1D	0804 517269	PAVEL PETROV	{"email": "petrov_pavel17071969@postgrespro.ru", "phone": "+70942458723"}
0005434756334	9DC073	6638 853852	TATYANA TIMOFEEVA	{"phone": "+70406038475"}
0005434756335	9DC073	8435 194337	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva_081978@postgrespro.ru", "phone": "+70407766346"}
0005434756336	F3DA77	2120 578409	YURIY SOROKIN	{"email": "sorokinyuriy_03051963@postgrespro.ru", "phone": "+70132478167"}
0005434756337	A3B035	3080 391899	OLGA BELOVA	{"email": "olga.belova-08061971@postgrespro.ru", "phone": "+70542609362"}
0005434756338	4EEA75	8420 208402	ELENA SOROKINA	{"email": "sorokina_e-111972@postgrespro.ru", "phone": "+70990304455"}
0005434756339	4EEA75	7217 278503	IRINA FILIPPOVA	{"phone": "+70971968064"}
0005434756340	DD7C59	8335 913816	DIANA KUZMINA	{"email": "diana.kuzmina1962@postgrespro.ru", "phone": "+70413360854"}
0005434756341	987855	8443 735653	MIKHAIL VOROBEV	{"email": "mikhailvorobev-09111973@postgrespro.ru", "phone": "+70298833904"}
0005434756342	987855	6214 850309	MARIYA VLASOVA	{"phone": "+70010098078"}
0005434756343	4370BB	4284 129243	ALEKSANDR IVANOV	{"email": "ivanov-a-30031974@postgrespro.ru", "phone": "+70886452608"}
0005434756344	4370BB	4809 794760	LYUBOV MAKAROVA	{"email": "lyubov-makarova011985@postgrespro.ru", "phone": "+70506688950"}
0005434756345	70FA70	8459 770088	LYUBOV BARANOVA	{"phone": "+70342495465"}
0005434756346	22CC2E	4982 936714	NINA POPOVA	{"phone": "+70638490134"}
0005434756347	61C9B7	6570 107856	SERGEY VOROBEV	{"phone": "+70573598018"}
0005434756348	29E180	8568 485170	EVGENIY KARPOV	{"phone": "+70409121541"}
0005434756349	E35FFB	2972 278513	VLADISLAV POPOV	{"email": "v.popov24041968@postgrespro.ru", "phone": "+70833884459"}
0005434756350	E35FFB	5457 022636	ELENA AFANASEVA	{"email": "afanasevaelena011982@postgrespro.ru", "phone": "+70381600414"}
0005434756351	E35FFB	3533 528297	VALENTINA KUZNECOVA	{"email": "v-kuznecova101977@postgrespro.ru", "phone": "+70235981937"}
0005434756352	5C2380	5085 763913	YULIYA FADEEVA	{"email": "fadeeva-y.1966@postgrespro.ru", "phone": "+70150040228"}
0005434756353	5C2380	1954 270815	ANDREY SOROKIN	{"email": "a.sorokin_031983@postgrespro.ru", "phone": "+70872153267"}
0005434756354	BD0669	4445 918707	ZINAIDA NIKOLAEVA	{"phone": "+70645849590"}
0005434756355	7AE50F	9555 995334	OLGA MOROZOVA	{"email": "morozova.olga.091969@postgrespro.ru", "phone": "+70797170758"}
0005434756356	7AE50F	7414 932244	VERA CHERNOVA	{"phone": "+70124729451"}
0005434756357	602360	0634 934147	IRINA DANILOVA	{"email": "danilova_i.06071976@postgrespro.ru", "phone": "+70199519305"}
0005434756358	602360	8642 560588	EKATERINA KUZNECOVA	{"email": "kuznecova_ekaterina_071976@postgrespro.ru", "phone": "+70486361259"}
0005434756359	ECE60D	1130 275937	ANDREY KOROLEV	{"phone": "+70217655752"}
0005434756360	5F4CC3	4246 422858	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy05061962@postgrespro.ru", "phone": "+70127706688"}
0005434756361	3C2F52	3642 757133	DARYA PAVLOVA	{"email": "pavlova.d1957@postgrespro.ru", "phone": "+70767875385"}
0005434756362	AA6C74	8861 551600	ANASTASIYA POTAPOVA	{"email": "potapova_anastasiya-051970@postgrespro.ru", "phone": "+70125382016"}
0005434756363	EC7C8F	4552 213444	ZARINA ABRAMOVA	{"email": "zabramova_081965@postgrespro.ru", "phone": "+70579819888"}
0005434756364	C11D9C	0622 960258	NIKITA SAVELEV	{"email": "n.savelev1961@postgrespro.ru", "phone": "+70881292934"}
0005434756365	6E250F	1395 827779	OLGA GRISHINA	{"phone": "+70374231684"}
0005434756366	FE8AC6	0328 904496	ELENA SEMENOVA	{"email": "semenova_elena.16081976@postgrespro.ru", "phone": "+70185531390"}
0005434756367	416784	7234 747063	PAVEL ROMANOV	{"phone": "+70700871595"}
0005434756368	416784	2843 855947	ALEKSANDR TARASOV	{"email": "a.tarasov.081972@postgrespro.ru", "phone": "+70053486895"}
0005434756369	416784	9525 669102	TATYANA STEPANOVA	{"phone": "+70096075876"}
0005434756370	B0D7C4	2943 126652	TATYANA ISAEVA	{"phone": "+70173337068"}
0005434756371	6F2944	9262 651270	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr_02021971@postgrespro.ru", "phone": "+70218040373"}
0005434756372	CF9B0A	5957 830529	ANNA BARANOVA	{"phone": "+70775485612"}
0005434756373	A16287	3179 863880	ANTON VLASOV	{"phone": "+70188458491"}
0005434756374	936291	6046 911315	PAVEL ANDREEV	{"email": "andreevp_1982@postgrespro.ru", "phone": "+70013225228"}
0005434756375	936291	5248 906085	BORIS SIDOROV	{"phone": "+70049679636"}
0005434756376	B6C430	0323 406296	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_17111975@postgrespro.ru", "phone": "+70783347526"}
0005434756377	097DF7	4179 305840	IOSIF ANDREEV	{"phone": "+70785073373"}
0005434756378	F8E5B2	3529 683133	MIKHAIL KONOVALOV	{"phone": "+70701192885"}
0005434756379	F8E5B2	3048 988836	MARINA MAKAROVA	{"email": "marina_makarova.1968@postgrespro.ru", "phone": "+70041012307"}
0005434756380	AF93D4	8872 385168	NADEZHDA BELOVA	{"phone": "+70813697986"}
0005434756381	7BEADE	2469 478981	VIKTOR KOZLOV	{"phone": "+70048101262"}
0005434756382	554316	5187 909288	ALEKSEY KARPOV	{"phone": "+70210038237"}
0005434756383	554316	3135 401904	SERGEY ISAEV	{"phone": "+70316568402"}
0005434756384	96A4FC	5489 657316	DMITRIY YAKOVLEV	{"phone": "+70127762569"}
0005434756385	30A639	3172 410165	VALENTINA CHERNOVA	{"phone": "+70297740845"}
0005434756386	504622	0492 323176	VALENTINA MIKHAYLOVA	{"email": "v.mikhaylova-021974@postgrespro.ru", "phone": "+70710749069"}
0005434756387	504622	2295 319676	IGOR MATVEEV	{"email": "matveev.igor041975@postgrespro.ru", "phone": "+70930670364"}
0005434756388	011056	5502 058018	ELENA OSIPOVA	{"phone": "+70006077485"}
0005434756389	6A9F85	1274 763363	ALEKSANDR KUZNECOV	{"email": "a.kuznecov-081975@postgrespro.ru", "phone": "+70002436355"}
0005434756390	A3B6ED	1670 018472	ARSENIY NAZAROV	{"phone": "+70658672251"}
0005434756391	BEBF92	3683 197985	EVGENIYA FADEEVA	{"phone": "+70296322792"}
0005434756392	F3D5DB	6630 022384	IVAN IVANOV	{"phone": "+70397305640"}
0005434756393	BCE029	3793 218992	IGOR SIDOROV	{"phone": "+70059682415"}
0005434756394	F7C628	7666 193677	ALEKSEY MELNIKOV	{"email": "melnikov.a_08071963@postgrespro.ru", "phone": "+70992721306"}
0005434756395	F7C628	8788 057649	SERGEY SOROKIN	{"email": "sorokin-s-1971@postgrespro.ru", "phone": "+70837819519"}
0005434756396	545301	5270 232808	EKATERINA KALININA	{"phone": "+70306496609"}
0005434756397	D0BFC1	0460 570689	GERMAN GERASIMOV	{"phone": "+70785300371"}
0005434756398	0976B0	0039 240390	ASIYA FILATOVA	{"email": "filatova.asiya_091980@postgrespro.ru", "phone": "+70939958420"}
0005434756399	0976B0	4321 123558	KONSTANTIN NAUMOV	{"email": "naumov-k.05081963@postgrespro.ru", "phone": "+70141905783"}
0005434756400	66C8EC	8076 948255	ANDREY PAVLOV	{"phone": "+70945179373"}
0005434756401	058C4B	5498 997117	ALISA VOLKOVA	{"phone": "+70326701201"}
0005434756402	E7FE08	1815 980341	TATYANA ZHUKOVA	{"phone": "+70226329844"}
0005434756403	003E84	2411 727115	EKATERINA FROLOVA	{"phone": "+70914311685"}
0005434756404	003E84	6126 727571	NINA ALEKSEEVA	{"email": "ninaalekseeva.041974@postgrespro.ru", "phone": "+70910021315"}
0005434756405	C1AE93	3602 808579	VIKTOR MAKAROV	{"phone": "+70086160589"}
0005434756406	8DEA13	3435 692870	ELIZAVETA YUDINA	{"email": "e-yudina1971@postgrespro.ru", "phone": "+70458519494"}
0005434756407	9FACC7	5663 975667	NADEZHDA KOROLEVA	{"phone": "+70036168570"}
0005434756408	07E047	9193 539482	VLADIMIR MAKAROV	{"email": "makarov.vladimir1964@postgrespro.ru", "phone": "+70275915066"}
0005434756409	07E047	7158 138437	ELIZAVETA ROMANOVA	{"phone": "+70525302627"}
0005434756410	07E047	2820 927975	VLADIMIR KUDRYASHOV	{"email": "v-kudryashov111972@postgrespro.ru", "phone": "+70336220833"}
0005434756411	4ED3F9	4059 542793	ALLA KOZLOVA	{"email": "a-kozlova-1967@postgrespro.ru", "phone": "+70449364151"}
0005434756412	4ED3F9	5370 414285	NINA ALEKSEEVA	{"email": "alekseeva_n061974@postgrespro.ru", "phone": "+70877537089"}
0005434756413	CBD3E4	7460 885696	NIKOLAY GERASIMOV	{"email": "nikolay-gerasimov-13091968@postgrespro.ru", "phone": "+70770806972"}
0005434756414	19E6E5	7052 680020	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov.061984@postgrespro.ru", "phone": "+70146004166"}
0005434756415	0220A4	9544 712873	LIDIYA LUKYANOVA	{"email": "lidiya_lukyanova_08071971@postgrespro.ru", "phone": "+70184842629"}
0005434756416	FC38FA	3848 238669	VASILIY RODIONOV	{"email": "rodionovvasiliy-16081973@postgrespro.ru", "phone": "+70332822263"}
0005434756417	17FF80	6347 102840	ANASTASIYA POPOVA	{"phone": "+70643691665"}
0005434756418	EC9C70	9770 288179	RUSLAN MOROZOV	{"email": "ruslan_morozov.101968@postgrespro.ru", "phone": "+70187685323"}
0005434756419	EC9C70	5537 337771	ELENA NIKOLAEVA	{"email": "nikolaeva.elena-06011989@postgrespro.ru", "phone": "+70181599196"}
0005434756420	8AC124	6051 809593	EVDOKIYA ZAKHAROVA	{"phone": "+70832490114"}
0005434756421	8AC124	9365 276315	ALIYA SIDOROVA	{"phone": "+70930600111"}
0005434756422	603359	8958 854581	NIKOLAY KOZLOV	{"email": "nikolaykozlov.25121976@postgrespro.ru", "phone": "+70776275542"}
0005434756423	867173	8052 237990	VLADIMIR SEMENOV	{"email": "vsemenov.20101968@postgrespro.ru", "phone": "+70689699867"}
0005434756424	65E6C0	0666 143379	AYRAT KISELEV	{"phone": "+70239218952"}
0005434756425	2EBDA6	0991 807497	SERGEY FILIPPOV	{"email": "filippov.s-101982@postgrespro.ru", "phone": "+70044744124"}
0005434756426	2EBDA6	7729 453152	GENNADIY NIKOLAEV	{"email": "gennadiy_nikolaev-1969@postgrespro.ru", "phone": "+70248239523"}
0005434756427	2EBDA6	0738 056281	IRINA ZHUKOVA	{"email": "irina.zhukova10121977@postgrespro.ru", "phone": "+70897579514"}
0005434756428	3E1EB9	4976 059189	VLADIMIR SMIRNOV	{"email": "vsmirnov_25031961@postgrespro.ru", "phone": "+70280083214"}
0005434756429	3E1EB9	4952 546980	TATYANA MOROZOVA	{"phone": "+70478575215"}
0005434756430	7CAFB4	8556 943454	KLAVDIYA KULIKOVA	{"phone": "+70400906706"}
0005434756431	048BD6	0429 309073	SHAMIL GORBUNOV	{"email": "gorbunovshamil.061971@postgrespro.ru", "phone": "+70325836669"}
0005434756432	B2F1E4	4892 961397	NIKOLAY KONOVALOV	{"email": "konovalov-nikolay_1968@postgrespro.ru", "phone": "+70599763478"}
0005434756433	B532D2	5542 226042	OLGA RODIONOVA	{"email": "rodionovaolga1977@postgrespro.ru", "phone": "+70888704441"}
0005434756434	C03963	4558 538984	YANA MIRONOVA	{"email": "mironovayana-1971@postgrespro.ru", "phone": "+70435885800"}
0005434756435	AF4F6D	3670 500309	VLADIMIR SOKOLOV	{"email": "vladimir.sokolov-121974@postgrespro.ru", "phone": "+70946748006"}
0005434756436	75178C	9327 991580	NATALYA SAVELEVA	{"email": "nsaveleva-101980@postgrespro.ru", "phone": "+70532508882"}
0005434756437	A0F8F5	5869 476129	LINAR POPOV	{"email": "linar.popov-021952@postgrespro.ru", "phone": "+70109523277"}
0005434756438	0A2C90	4557 665782	ANNA MOISEEVA	{"email": "moiseeva-a.1978@postgrespro.ru", "phone": "+70730757265"}
0005434756439	B3FCB3	8106 763930	RADIK ILIN	{"email": "radik-ilin021973@postgrespro.ru", "phone": "+70024844266"}
0005434756440	29EFC0	1434 770094	TATYANA PETROVA	{"email": "petrova.tatyana-061970@postgrespro.ru", "phone": "+70690281143"}
0005434756441	29EFC0	6171 590449	SVETLANA SERGEEVA	{"email": "s_sergeeva_1965@postgrespro.ru", "phone": "+70697327887"}
0005434756442	8B5F0C	1677 788523	ALEKSANDR BELOV	{"phone": "+70690019057"}
0005434756443	D3D3D5	5659 788882	ANATOLIY EGOROV	{"email": "a.egorov_1972@postgrespro.ru", "phone": "+70538085144"}
0005434756444	D3D3D5	3242 080079	SERGEY SOLOVEV	{"email": "solovev_s031972@postgrespro.ru", "phone": "+70455424089"}
0005434756445	D3D3D5	0592 290722	ANATOLIY GAVRILOV	{"email": "a-gavrilov-1982@postgrespro.ru", "phone": "+70729339950"}
0005434756446	43F384	9015 199813	GRIGORIY KAZAKOV	{"email": "kazakovg081983@postgrespro.ru", "phone": "+70875331318"}
0005434756447	5276F2	1265 083354	SERGEY SAVELEV	{"phone": "+70026027221"}
0005434756448	621CC3	4126 317453	VALENTINA ABRAMOVA	{"phone": "+70955961258"}
0005434756449	3363FB	5574 574076	ANDREY FROLOV	{"phone": "+70649452433"}
0005434756450	3363FB	4548 267241	EVGENIY DAVYDOV	{"email": "davydov-e031972@postgrespro.ru", "phone": "+70376734096"}
0005434756451	D6B93F	0740 172016	LIDIYA PAVLOVA	{"email": "pavlova-lidiya_23071977@postgrespro.ru", "phone": "+70502654120"}
0005434756452	D6B93F	8377 569546	MIKHAIL ISAEV	{"email": "isaev-m.25071967@postgrespro.ru", "phone": "+70118076080"}
0005434756453	C9670F	4294 724757	NIKITA ISAEV	{"email": "isaev_nikita.25031975@postgrespro.ru", "phone": "+70657104609"}
0005434756454	C9670F	9276 313348	OLGA POLYAKOVA	{"email": "polyakova.olga_101971@postgrespro.ru", "phone": "+70479579560"}
0005434756455	491154	0660 439337	RAMIL FROLOV	{"email": "frolov-ramil.1966@postgrespro.ru", "phone": "+70733030007"}
0005434756456	5DFC03	5338 074374	ELVIRA PAVLOVA	{"email": "epavlova02111973@postgrespro.ru", "phone": "+70860626704"}
0005434756457	5DFC03	5727 411020	VLADIMIR ABRAMOV	{"email": "v.abramov1963@postgrespro.ru", "phone": "+70344758357"}
0005434756458	FDC665	1201 981004	IRINA YUDINA	{"email": "irina_yudina.04041963@postgrespro.ru", "phone": "+70161821218"}
0005434756459	23FB29	9232 746685	ANASTASIYA TARASOVA	{"phone": "+70839912102"}
0005434756460	EBEEDA	7723 261955	OLGA FILATOVA	{"phone": "+70219513089"}
0005434756461	52B373	3586 666013	OLGA MOISEEVA	{"phone": "+70494414921"}
0005434756462	ED0AB4	1955 576593	VLADIMIR RODIONOV	{"phone": "+70376586948"}
0005434756463	8CD703	0930 377508	IRINA EGOROVA	{"phone": "+70254276944"}
0005434756464	F6534C	7451 232410	VIKTOR KRASNOV	{"phone": "+70870151067"}
0005434756465	2F2FA3	4364 156376	VLADISLAV KOZLOV	{"phone": "+70965463831"}
0005434756466	2F2FA3	8413 152861	LYUDMILA DMITRIEVA	{"email": "l_dmitrieva_041966@postgrespro.ru", "phone": "+70776621625"}
0005434756467	7B456D	0807 710240	MAKSIM POPOV	{"phone": "+70932092954"}
0005434756468	7B456D	2490 357212	VALENTINA LOGINOVA	{"phone": "+70014880236"}
0005434756469	A0699E	0975 510364	EVGENIY GUSEV	{"phone": "+70858727472"}
0005434756470	513C80	7383 852641	ALEKSEY ZAYCEV	{"email": "aleksey.zaycev_021970@postgrespro.ru", "phone": "+70776434975"}
0005434756471	F558F6	7344 494189	VLADIMIR NIKITIN	{"phone": "+70775065753"}
0005434756472	1BA692	6118 569493	IVAN POPOV	{"email": "popov.ivan-1970@postgrespro.ru", "phone": "+70042907566"}
0005434756473	1BA692	1175 954410	ALEKSEY TIKHONOV	{"phone": "+70443073203"}
0005434756474	9CDB2E	3773 070561	TATYANA KUZNECOVA	{"email": "kuznecovat_061977@postgrespro.ru", "phone": "+70168238348"}
0005434756475	556930	6660 310739	ALEKSANDR SOLOVEV	{"phone": "+70654096041"}
0005434756476	725D6C	7006 677045	MIKHAIL ANDREEV	{"phone": "+70725164499"}
0005434756477	8E82B0	4532 377025	ANATOLIY VOLKOV	{"email": "volkov_anatoliy091972@postgrespro.ru", "phone": "+70438224305"}
0005434756478	0B13D8	9414 362864	DAMIR PAVLOV	{"phone": "+70644598863"}
0005434756479	343F2B	8224 878718	YULIYA ANDREEVA	{"phone": "+70129046540"}
0005434756480	343F2B	6189 201941	TATYANA ROMANOVA	{"phone": "+70670974622"}
0005434756481	598645	6356 801174	SOFYA NESTEROVA	{"phone": "+70857406801"}
0005434756482	B62A73	7655 785270	TATYANA PAVLOVA	{"phone": "+70961128743"}
0005434756483	B62A73	0564 663769	MARTA PAVLOVA	{"email": "marta_pavlova_26121974@postgrespro.ru", "phone": "+70426233383"}
0005434756484	B62A73	5474 710664	VALENTINA SIDOROVA	{"email": "sidorova_v.08011976@postgrespro.ru", "phone": "+70849524906"}
0005434756485	E5E88E	5891 620676	MAKSIM IVANOV	{"email": "ivanov.maksim_1963@postgrespro.ru", "phone": "+70567848979"}
0005434756486	BF69F6	6903 282310	ALLA MOROZOVA	{"email": "alla_morozova_1982@postgrespro.ru", "phone": "+70739438056"}
0005434756487	BF69F6	4808 111127	VALERIY KUZMIN	{"email": "kuzminvaleriy_061972@postgrespro.ru", "phone": "+70529396294"}
0005434756488	2E2312	8490 256914	ALEKSEY POPOV	{"email": "a.popov-04021983@postgrespro.ru", "phone": "+70564607790"}
0005434756489	C597B6	6149 682214	SERGEY SMIRNOV	{"email": "s_smirnov20121970@postgrespro.ru", "phone": "+70203583902"}
0005434756490	C597B6	2807 263804	NIKOLAY PAVLOV	{"email": "pavlov-n_091971@postgrespro.ru", "phone": "+70412368654"}
0005434756491	BEFA95	1848 991679	GERMAN ZAKHAROV	{"phone": "+70372316984"}
0005434756492	0F358C	8072 733190	NIKOLAY VOLKOV	{"phone": "+70224885516"}
0005434756493	0F358C	1790 245731	ELENA TIKHONOVA	{"email": "tikhonovaelena-011984@postgrespro.ru", "phone": "+70889319503"}
0005434756494	0F358C	8174 472157	GALINA SERGEEVA	{"email": "sergeeva-galina_041976@postgrespro.ru", "phone": "+70942973770"}
0005434756495	E9A919	8052 167795	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr_26111964@postgrespro.ru", "phone": "+70988769529"}
0005434756496	A9D6C4	4769 157386	ALEKSEY MATVEEV	{"email": "a.matveev-04061964@postgrespro.ru", "phone": "+70336733533"}
0005434756497	A9D6C4	3106 669784	SERGEY DENISOV	{"phone": "+70868362797"}
0005434756498	A1DB3D	7476 911190	NATALYA KONDRATEVA	{"email": "nkondrateva_05051980@postgrespro.ru", "phone": "+70734724533"}
0005434756499	9C948E	5260 543677	NIKOLAY SMIRNOV	{"email": "nikolay-smirnov-1975@postgrespro.ru", "phone": "+70116750671"}
0005434756500	38B91A	3743 382601	VIKTOR POPOV	{"email": "popov-viktor-121968@postgrespro.ru", "phone": "+70632527401"}
0005434756501	38B91A	1732 982441	ILYAS SOKOLOV	{"phone": "+70451353735"}
0005434756502	9CE4E6	8299 435133	ALEKSANDR MOROZOV	{"phone": "+70822482900"}
0005434756503	7CED88	2562 738098	MARGARITA ILINA	{"phone": "+70182930970"}
0005434756504	7CED88	2603 935575	ANASTASIYA FILATOVA	{"email": "filatova-a041975@postgrespro.ru", "phone": "+70768607433"}
0005434756505	A43309	5672 251666	ANDREY BELOV	{"email": "belov.andrey_011974@postgrespro.ru", "phone": "+70796105503"}
0005434756506	A43309	2719 242549	VLADIMIR FILIPPOV	{"phone": "+70390196557"}
0005434756507	C7E997	8986 519460	VALENTINA MATVEEVA	{"phone": "+70054543417"}
0005434756508	C7E997	2570 147217	VYACHESLAV KUZNECOV	{"email": "vyacheslav.kuznecov-1971@postgrespro.ru", "phone": "+70018404698"}
0005434756509	545AC7	8509 087720	VIKTORIYA KOROLEVA	{"phone": "+70756446233"}
0005434756510	6FCB3A	7524 582721	SEMEN BORISOV	{"email": "borisov_s.17071976@postgrespro.ru", "phone": "+70075688938"}
0005434756511	3FB34B	3946 841641	NADEZHDA KUZNECOVA	{"email": "kuznecova_n091974@postgrespro.ru", "phone": "+70516777667"}
0005434756512	3FB34B	3951 251936	ALEKSEY ZAKHAROV	{"email": "azakharov_30011967@postgrespro.ru", "phone": "+70498075750"}
0005434756513	0EDC2F	2766 045586	PETR NIKITIN	{"email": "nikitin-p1972@postgrespro.ru", "phone": "+70656713638"}
0005434756514	0EDC2F	1450 393162	GALINA FOMINA	{"email": "g_fomina.071956@postgrespro.ru", "phone": "+70991337924"}
0005434756515	C85BF0	0789 698082	ALEKSANDR OSIPOV	{"email": "osipov_a061983@postgrespro.ru", "phone": "+70425918714"}
0005434756516	75A26C	2733 657981	FANIYA LUKYANOVA	{"phone": "+70510127330"}
0005434756517	75A26C	9648 539295	TATYANA KUZMINA	{"email": "tatyana_kuzmina-04031964@postgrespro.ru", "phone": "+70712413962"}
0005434756518	4BE634	2533 267119	SERGEY NIKOLAEV	{"email": "s-nikolaev.16021982@postgrespro.ru", "phone": "+70096919329"}
0005434756519	4BE634	5629 310881	ILYA ILIN	{"email": "ilin.i.071969@postgrespro.ru", "phone": "+70349107139"}
0005434756520	09AB67	4721 179428	MARIYA VOLKOVA	{"email": "volkova.mariya_1975@postgrespro.ru", "phone": "+70926855236"}
0005434756521	09AB67	1937 142216	ELENA NAUMOVA	{"email": "e-naumova-021971@postgrespro.ru", "phone": "+70455780935"}
0005434756522	15722B	0230 973398	ANDREY GORBUNOV	{"email": "a.gorbunov24061968@postgrespro.ru", "phone": "+70071325940"}
0005434756523	DDE2B0	7449 909131	ALEKSANDRA SOKOLOVA	{"phone": "+70924630073"}
0005434756524	77F5DC	2169 550149	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko-091967@postgrespro.ru", "phone": "+70412481873"}
0005434756525	77F5DC	6635 409569	DMITRIY NIKOLAEV	{"email": "d-nikolaev-07091975@postgrespro.ru", "phone": "+70942071780"}
0005434756526	89345B	3661 009847	VYACHESLAV BONDARENKO	{"phone": "+70797252571"}
0005434756527	59F862	7883 730687	ZOYA VOROBEVA	{"email": "vorobeva.zoya-051963@postgrespro.ru", "phone": "+70055631602"}
0005434756528	379266	4683 730231	VYACHESLAV KRASNOV	{"email": "krasnov_v.08071967@postgrespro.ru", "phone": "+70077511442"}
0005434756529	5F271E	2555 908712	DENIS KUZMIN	{"phone": "+70123096602"}
0005434756530	5F271E	4032 477026	VLADIMIR FROLOV	{"email": "frolov-vladimir.1967@postgrespro.ru", "phone": "+70801248942"}
0005434756531	F9C461	3083 075493	EMIL VOLKOV	{"phone": "+70340792642"}
0005434756532	F9C461	4773 180333	SVETLANA NIKITINA	{"email": "svetlana-nikitina.30011963@postgrespro.ru", "phone": "+70544031646"}
0005434756533	E251A3	4601 958782	ANNA MAKSIMOVA	{"phone": "+70243360568"}
0005434756534	E251A3	5240 054347	SERGEY ABRAMOV	{"email": "sabramov101967@postgrespro.ru", "phone": "+70945201900"}
0005434756535	9D2F00	5157 132413	EKATERINA MATVEEVA	{"phone": "+70657416647"}
0005434756536	93CA13	8306 866489	TAMARA KUZNECOVA	{"email": "t.kuznecova-011971@postgrespro.ru", "phone": "+70590367018"}
0005434756537	93CA13	4407 224843	ANDREY KOZLOV	{"phone": "+70488688948"}
0005434756538	0F22CF	3805 712870	TATYANA AKIMOVA	{"email": "tatyanaakimova.06061978@postgrespro.ru", "phone": "+70752775062"}
0005434756539	BC7C80	5041 598729	VALENTINA FADEEVA	{"phone": "+70610019354"}
0005434756540	316CF0	7999 154194	VALENTINA MATVEEVA	{"email": "matveeva_valentina-011970@postgrespro.ru", "phone": "+70813007885"}
0005434756541	316CF0	5436 513324	POLINA ANISIMOVA	{"email": "panisimova.061967@postgrespro.ru", "phone": "+70062762999"}
0005434756542	CAB92B	8150 872789	MIKHAIL POPOV	{"email": "popov_m121970@postgrespro.ru", "phone": "+70966944006"}
0005434756543	E99C73	0595 370314	RAVIL YAKOVLEV	{"email": "ryakovlev.19041966@postgrespro.ru", "phone": "+70240418971"}
0005434756544	E99C73	2478 118720	TATYANA KONOVALOVA	{"email": "tatyana-konovalova_011976@postgrespro.ru", "phone": "+70907594675"}
0005434756545	8C61A5	7473 627522	ALEKSANDR DAVYDOV	{"phone": "+70580202825"}
0005434756546	8C61A5	2600 786986	VLADIMIR VASILEV	{"email": "vasilevv-121980@postgrespro.ru", "phone": "+70587830269"}
0005434756547	CC9FE1	1742 581789	ALEKSANDR SOLOVEV	{"phone": "+70045103720"}
0005434756548	C31B83	0295 526806	VERA KOZLOVA	{"phone": "+70701448550"}
0005434756549	AC6CBB	6541 387968	IVAN SEMENOV	{"email": "semenov.ivan_061965@postgrespro.ru", "phone": "+70588982104"}
0005434756550	AC6CBB	9221 389314	EKATERINA GUSEVA	{"phone": "+70485378903"}
0005434756551	9C83FA	3827 975171	ALEKSANDR CHERNOV	{"phone": "+70325074488"}
0005434756552	936907	0707 358720	SERGEY ROMANOV	{"phone": "+70805688186"}
0005434756553	0367C2	1237 778386	NINA ZAYCEVA	{"email": "nina_zayceva031958@postgrespro.ru", "phone": "+70859479488"}
0005434756554	0367C2	6408 963685	TAMARA VOROBEVA	{"email": "tamara.vorobeva.1976@postgrespro.ru", "phone": "+70138982130"}
0005434756555	84F868	8118 911457	ANNA VASILEVA	{"phone": "+70783930263"}
0005434756556	84F868	9449 955187	ANDREY ALEKSEEV	{"phone": "+70714545029"}
0005434756557	AEE9C0	8212 674620	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-aleksandr_16071971@postgrespro.ru", "phone": "+70361871793"}
0005434756558	F37CC0	2956 831555	ANDREY VASILEV	{"email": "a_vasilev-16041968@postgrespro.ru", "phone": "+70857049708"}
0005434756559	F37CC0	2622 469379	GRIGORIY ALEKSANDROV	{"phone": "+70644496423"}
0005434756560	20E243	4975 841896	DMITRIY SERGEEV	{"email": "d_sergeev011976@postgrespro.ru", "phone": "+70163621079"}
0005434756561	C57737	3547 163580	MARIYA RODIONOVA	{"email": "m-rodionova_071964@postgrespro.ru", "phone": "+70570576875"}
0005434756562	C57737	4101 756027	ANDREY MOISEEV	{"phone": "+70257495391"}
0005434756563	6ED561	2120 880326	TATYANA MOROZOVA	{"phone": "+70808385247"}
0005434756564	59FCC2	4266 230843	SERGEY FEDOROV	{"email": "fedorov_sergey-121973@postgrespro.ru", "phone": "+70642455999"}
0005434756565	AED5B2	5185 157640	OLGA KAZAKOVA	{"email": "kazakovaolga-19081968@postgrespro.ru", "phone": "+70871538017"}
0005434756566	AED5B2	9931 340859	ELENA SMIRNOVA	{"phone": "+70915330761"}
0005434756567	735AFC	5395 533134	OKSANA KUZMINA	{"phone": "+70115210084"}
0005434756568	0B36EB	7808 366797	VLADIMIR KRASNOV	{"email": "vladimir_krasnov_1967@postgrespro.ru", "phone": "+70517415929"}
0005434756569	0B36EB	6824 422196	IGOR TARASOV	{"phone": "+70960260255"}
0005434756570	0B36EB	1218 731887	ALEKSANDR KARPOV	{"phone": "+70186292171"}
0005434756571	D8F09B	2836 320139	VIKTORIYA NOVIKOVA	{"email": "novikova.v.15091969@postgrespro.ru", "phone": "+70299255744"}
0005434756572	463E15	7138 270912	ELENA NESTEROVA	{"phone": "+70483020172"}
0005434756573	E834A4	4341 463546	ALEKSANDR FOMIN	{"email": "aleksandr.fomin041972@postgrespro.ru", "phone": "+70293378387"}
0005434756574	E834A4	7388 367957	ALEKSEY IVANOV	{"phone": "+70149245540"}
0005434756575	92F80D	5317 657106	MARIYA SOLOVEVA	{"email": "solovevam_04101966@postgrespro.ru", "phone": "+70317577408"}
0005434756576	92F80D	5012 315086	ARTEM SEMENOV	{"phone": "+70941722274"}
0005434756577	1CB6AA	7792 622482	EKATERINA FILIPPOVA	{"email": "e.filippova.1960@postgrespro.ru", "phone": "+70867422029"}
0005434756578	DD45D0	1225 177495	SERGEY MAKAROV	{"email": "sergey.makarov.13051977@postgrespro.ru", "phone": "+70416654483"}
0005434756579	476461	6792 381300	YULIYA KUZNECOVA	{"phone": "+70602499234"}
0005434756580	E2A209	1175 665226	VALENTINA RODIONOVA	{"email": "valentina.rodionova_29011976@postgrespro.ru", "phone": "+70793815353"}
0005434756581	A6E112	8032 748933	VALENTINA KAZAKOVA	{"phone": "+70818906496"}
0005434756582	A3CED1	6038 153512	ALEKSANDR TARASOV	{"email": "tarasov_a_08031969@postgrespro.ru", "phone": "+70696123486"}
0005434756583	1F7C0D	4727 859288	ANNA NAUMOVA	{"email": "anna_naumova101975@postgrespro.ru", "phone": "+70471621533"}
0005434756584	7F0192	0132 642327	VITALIY MAKAROV	{"phone": "+70288334966"}
0005434756585	7F0192	4253 561768	ANDREY POPOV	{"phone": "+70419630600"}
0005434756586	7F0192	5935 366969	EKATERINA POPOVA	{"phone": "+70613931310"}
0005434756587	CFF27E	9675 991620	GALINA AFANASEVA	{"email": "afanaseva.galina.1978@postgrespro.ru", "phone": "+70306346281"}
0005434756588	CFF27E	7754 583711	ANDREY GUSEV	{"email": "gusev-andrey_021967@postgrespro.ru", "phone": "+70658652726"}
0005434756589	9FD4AD	2400 277873	TATYANA RODIONOVA	{"phone": "+70689030927"}
0005434756590	F2D92F	1202 483183	ALEKSANDR NOVIKOV	{"email": "aleksandr.novikov-121967@postgrespro.ru", "phone": "+70205754864"}
0005434756591	06788B	4477 291444	SVETLANA BOGDANOVA	{"email": "bogdanova_svetlana-1975@postgrespro.ru", "phone": "+70039604040"}
0005434756592	D19873	4494 425240	VLADIMIR YAKOVLEV	{"phone": "+70370888112"}
0005434756593	16E709	4185 105936	RAZIYA KONOVALOVA	{"email": "konovalovar071977@postgrespro.ru", "phone": "+70141767901"}
0005434756594	F7F423	7826 175582	ANNA ERMAKOVA	{"email": "a_ermakova26051970@postgrespro.ru", "phone": "+70740553109"}
0005434756595	F7F423	6692 704718	VITALIY SOKOLOV	{"phone": "+70283745676"}
0005434756596	0B3900	4630 330453	NATALYA POPOVA	{"phone": "+70197503330"}
0005434756597	AD0002	8779 590663	ALEKSANDRA SCHERBAKOVA	{"phone": "+70741445523"}
0005434756598	AD0002	9981 754066	MIKHAIL FEDOROV	{"phone": "+70087373073"}
0005434756599	AD0002	6000 252007	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr071970@postgrespro.ru", "phone": "+70781101051"}
0005434756600	9B2E67	8994 859497	IRINA TARASOVA	{"email": "tarasova_i051986@postgrespro.ru", "phone": "+70261924129"}
0005434756601	86E4C6	0251 195965	NIKOLAY POPOV	{"phone": "+70594685639"}
0005434756602	9189CF	1439 638839	TATYANA KARPOVA	{"email": "tkarpova.051964@postgrespro.ru", "phone": "+70477544055"}
0005434756603	9189CF	5923 154415	DMITRIY MIKHAYLOV	{"email": "mikhaylovd-091964@postgrespro.ru", "phone": "+70404428957"}
0005434756604	34A476	7363 375379	NATALYA IVANOVA	{"email": "n-ivanova_01071982@postgrespro.ru", "phone": "+70232533985"}
0005434756605	72AD06	3367 586255	NAIL ZAKHAROV	{"email": "zakharov_n1974@postgrespro.ru", "phone": "+70831597326"}
0005434756606	B10CC8	7255 165439	LEONID MIKHAYLOV	{"email": "leonid-mikhaylov_091981@postgrespro.ru", "phone": "+70149828270"}
0005434756607	52330E	2262 785225	VYACHESLAV SCHERBAKOV	{"phone": "+70441352385"}
0005434756608	7C8C06	9673 957898	VLADIMIR PETROV	{"email": "v.petrov_05071972@postgrespro.ru", "phone": "+70375541305"}
0005434756609	023140	9928 675118	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin_08081971@postgrespro.ru", "phone": "+70606005706"}
0005434756610	F0C85D	7477 582315	NADEZHDA BOGDANOVA	{"phone": "+70605192573"}
0005434756611	7C878C	0662 183393	ZULFIYA ZHURAVLEVA	{"phone": "+70339328502"}
0005434756612	7C878C	6253 286548	ANDREY MATVEEV	{"email": "a-matveev-1966@postgrespro.ru", "phone": "+70529492804"}
0005434756613	FDE269	1351 380244	VITALIY KUZNECOV	{"email": "kuznecovvitaliy-101980@postgrespro.ru", "phone": "+70175871863"}
0005434756614	AFDBD1	5041 988972	SOFYA SIDOROVA	{"email": "sidorova_sofya-22031972@postgrespro.ru", "phone": "+70366166363"}
0005434756615	0296E7	4100 981995	VYACHESLAV ZAKHAROV	{"phone": "+70844810035"}
0005434756616	0296E7	0352 325899	YURIY KUZNECOV	{"email": "y-kuznecov121977@postgrespro.ru", "phone": "+70776571979"}
0005434756617	3429EA	5579 013706	MARGARITA NAUMOVA	{"phone": "+70035893063"}
0005434756618	3429EA	9163 155735	ZINAIDA NAUMOVA	{"phone": "+70491096145"}
0005434756619	3429EA	9519 809062	EDUARD FOMIN	{"email": "eduard_fomin04011969@postgrespro.ru", "phone": "+70356966084"}
0005434756620	78C3E7	8352 784932	NINA OSIPOVA	{"email": "nina.osipova_111963@postgrespro.ru", "phone": "+70750473141"}
0005434756621	3DB1EF	4261 337895	NATALYA ALEKSEEVA	{"email": "n.alekseeva-09021966@postgrespro.ru", "phone": "+70907540747"}
0005434756622	3DB1EF	1702 892358	VIKTOR FOMIN	{"phone": "+70607176511"}
0005434756623	3DB1EF	3260 503553	VLADIMIR ANTONOV	{"email": "antonovv_18081978@postgrespro.ru", "phone": "+70743920255"}
0005434756624	026789	7123 349197	NIKOLAY KISELEV	{"phone": "+70155003742"}
0005434756625	026789	7930 280522	NINA ZAYCEVA	{"phone": "+70339809749"}
0005434756626	122C45	0333 821359	ANNA BELOVA	{"email": "belovaa_1968@postgrespro.ru", "phone": "+70962010008"}
0005434756627	122C45	5324 376296	SVETLANA ARKHIPOVA	{"phone": "+70787205955"}
0005434756628	9141DA	9174 897858	ALEKSANDRA KONOVALOVA	{"email": "konovalovaaleksandra_1969@postgrespro.ru", "phone": "+70364172571"}
0005434756629	9141DA	3361 840325	VLADIMIR MOROZOV	{"email": "v.morozov05011967@postgrespro.ru", "phone": "+70573566982"}
0005434756630	CEB3CC	1296 473409	EVGENIYA KUZMINA	{"phone": "+70555486566"}
0005434756631	C40186	4541 914494	SVETLANA STEPANOVA	{"phone": "+70263554018"}
0005434756632	65910C	8222 961191	ANNA MAKAROVA	{"phone": "+70953310274"}
0005434756633	81C19A	1662 360601	TATYANA ROMANOVA	{"email": "romanova.tatyana_011976@postgrespro.ru", "phone": "+70911073926"}
0005434756634	6497B6	5347 727761	VLADIMIR SOLOVEV	{"email": "solovev_vladimir-1981@postgrespro.ru", "phone": "+70402550435"}
0005434756635	E2DFCC	6000 639752	NIKOLAY SOKOLOV	{"email": "sokolov-n_14081965@postgrespro.ru", "phone": "+70475814214"}
0005434756636	E2DFCC	7328 092989	VALENTINA EFREMOVA	{"phone": "+70302781646"}
0005434756637	5E0570	1830 962553	SEMEN SIDOROV	{"email": "ssidorov-20091966@postgrespro.ru", "phone": "+70468400732"}
0005434756638	5E0570	6731 641993	ELIZAVETA MALYSHEVA	{"email": "malysheva.elizaveta_10091978@postgrespro.ru", "phone": "+70598790472"}
0005434756639	5E0570	7259 950777	LYUDMILA MAKAROVA	{"email": "makarova-lyudmila051983@postgrespro.ru", "phone": "+70760310285"}
0005434756640	7453DF	9167 020606	SERGEY GUSEV	{"email": "s_gusev-031969@postgrespro.ru", "phone": "+70395526877"}
0005434756641	78D87D	8705 113128	LYUBOV POPOVA	{"email": "popova.lyubov-1965@postgrespro.ru", "phone": "+70110802827"}
0005434756642	104A51	2484 880877	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr1955@postgrespro.ru", "phone": "+70963739634"}
0005434756643	FF27DF	0242 585280	ALEKSANDR KUZNECOV	{"phone": "+70710513082"}
0005434756644	36CFB9	9949 531674	DENIS MATVEEV	{"email": "d-matveev-1979@postgrespro.ru", "phone": "+70847136785"}
0005434756645	36CFB9	1293 557290	NATALYA DENISOVA	{"phone": "+70766171643"}
0005434756646	B4C6F8	0283 598411	BORIS MAKAROV	{"phone": "+70762417767"}
0005434756647	B4C6F8	4681 965370	RAISA IVANOVA	{"phone": "+70908926793"}
0005434756648	CBCF4D	8145 919341	TATYANA LAZAREVA	{"email": "lazareva.t-071962@postgrespro.ru", "phone": "+70787267121"}
0005434756649	5C6D2C	7674 043121	NADEZHDA AFANASEVA	{"email": "nadezhdaafanaseva_21031976@postgrespro.ru", "phone": "+70836487870"}
0005434756650	5C6D2C	7439 345702	OLGA TITOVA	{"email": "titova_o_011972@postgrespro.ru", "phone": "+70536154856"}
0005434756651	737F0D	0877 495436	TATYANA MAKSIMOVA	{"email": "t-maksimova-101966@postgrespro.ru", "phone": "+70727808735"}
0005434756652	737F0D	8900 233089	ANNA DENISOVA	{"email": "denisova-anna27041961@postgrespro.ru", "phone": "+70692571699"}
0005434756653	59C202	8966 933503	VERA KULIKOVA	{"email": "v-kulikova-1969@postgrespro.ru", "phone": "+70103928890"}
0005434756654	4BE656	8415 829302	LYUBOV ZAYCEVA	{"phone": "+70930516661"}
0005434756655	475AB2	3737 752586	TATYANA BORISOVA	{"email": "borisovat111967@postgrespro.ru", "phone": "+70428619360"}
0005434756656	C4F1C8	4498 274880	ELENA KONOVALOVA	{"phone": "+70871754006"}
0005434756657	C86F71	4719 910618	SERGEY SOLOVEV	{"email": "solovev-sergey1969@postgrespro.ru", "phone": "+70860024900"}
0005434756658	C86F71	3833 174991	VLADIMIR CHERNOV	{"email": "chernov_vladimir_121964@postgrespro.ru", "phone": "+70792429323"}
0005434756659	A0CF71	4439 535509	NIKOLAY ZAYCEV	{"phone": "+70531273043"}
0005434756660	A8CCA1	0100 159945	SERGEY YAKOVLEV	{"email": "s.yakovlev14101990@postgrespro.ru", "phone": "+70168148912"}
0005434756661	A8CCA1	1865 949946	IGOR SIDOROV	{"email": "sidorov.igor.26021976@postgrespro.ru", "phone": "+70419351267"}
0005434756662	D21924	6227 851339	OLGA SEMENOVA	{"phone": "+70840306410"}
0005434756663	AA5A1D	6430 034243	TATYANA LEBEDEVA	{"phone": "+70279107138"}
0005434756664	D9BE69	8865 477350	LYUBOV KULIKOVA	{"email": "lyubov-kulikova1970@postgrespro.ru", "phone": "+70750679163"}
0005434756665	598A83	3604 726509	MARIYA KONDRATEVA	{"phone": "+70577871536"}
0005434756666	598A83	4882 086096	GENNADIY SOLOVEV	{"email": "solovev-g.30121973@postgrespro.ru", "phone": "+70913770612"}
0005434756667	C69982	1802 565353	ILYA NAUMOV	{"phone": "+70171805065"}
0005434756728	DBAE17	0589 169149	SERGEY IVANOV	{"phone": "+70343705384"}
0005434756668	CA3300	8761 027706	ANDREY MAKAROV	{"email": "andrey.makarov-07031970@postgrespro.ru", "phone": "+70341336101"}
0005434756669	CA3300	7485 017395	ARTEM SCHERBAKOV	{"phone": "+70192691170"}
0005434756670	48DB6C	9040 005711	ALEKSANDR SEMENOV	{"phone": "+70431407497"}
0005434756671	E8DFE2	3227 910826	NIKOLAY DAVYDOV	{"phone": "+70185667848"}
0005434756672	CDE836	8756 074624	LARISA SOKOLOVA	{"email": "lsokolova-041967@postgrespro.ru", "phone": "+70324295735"}
0005434756673	B8DD1A	7812 452510	VYACHESLAV YAKOVLEV	{"email": "yakovlev.v_30011975@postgrespro.ru", "phone": "+70610793126"}
0005434756674	B8DD1A	7641 582992	YULIYA POPOVA	{"email": "yuliya-popova_1983@postgrespro.ru", "phone": "+70947358375"}
0005434756675	CCB2B1	1605 394629	LYUBOV NAZAROVA	{"email": "l.nazarova.1974@postgrespro.ru", "phone": "+70095242408"}
0005434756676	73F80E	9284 991110	ALEKSANDR TIKHONOV	{"phone": "+70267404059"}
0005434756677	184F54	0925 327334	ILYA ANDREEV	{"email": "i.andreev_1982@postgrespro.ru", "phone": "+70805634939"}
0005434756678	184F54	7760 478029	ALEKSANDR DAVYDOV	{"phone": "+70959556610"}
0005434756679	BDDC8F	1588 604130	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov-22021971@postgrespro.ru", "phone": "+70876842939"}
0005434756680	29C97C	0641 774502	VIKTOR MEDVEDEV	{"email": "viktor_medvedev_18011974@postgrespro.ru", "phone": "+70403148825"}
0005434756681	E0463C	6981 747983	NIKOLAY ORLOV	{"email": "orlovn-02011980@postgrespro.ru", "phone": "+70258419796"}
0005434756682	1C4C54	8207 946837	ANNA YUDINA	{"email": "yudina.anna.021981@postgrespro.ru", "phone": "+70686037961"}
0005434756683	74E79B	2905 184512	NATALYA ILINA	{"email": "n-ilina.051974@postgrespro.ru", "phone": "+70480348991"}
0005434756684	74E79B	3297 799231	ANDREY VOLKOV	{"phone": "+70972615558"}
0005434756685	CFFBA7	9521 538265	ALEKSANDR MELNIKOV	{"phone": "+70504279204"}
0005434756686	CFFBA7	8807 561369	ALEKSEY BORISOV	{"phone": "+70370034554"}
0005434756687	A025F3	5703 883864	ALEKSEY FEDOROV	{"phone": "+70719306569"}
0005434756688	A025F3	7968 173160	OLGA KARPOVA	{"phone": "+70451901884"}
0005434756689	A025F3	0263 921418	ALEKSEY ZHUKOV	{"email": "alekseyzhukov111976@postgrespro.ru", "phone": "+70190206005"}
0005434756690	52688C	5245 323970	ALEKSANDRA ABRAMOVA	{"email": "aleksandra.abramova.1977@postgrespro.ru", "phone": "+70527298564"}
0005434756691	52688C	0933 095420	ANTONINA SOLOVEVA	{"phone": "+70889577859"}
0005434756692	76A639	0023 404563	LYUBOV BELOVA	{"email": "l-belova.1977@postgrespro.ru", "phone": "+70103104893"}
0005434756693	DAA9A7	6838 230562	VYACHESLAV MIRONOV	{"phone": "+70984875328"}
0005434756694	11BAE5	6159 547303	RODION KISELEV	{"email": "rodion.kiselev.071970@postgrespro.ru", "phone": "+70247929324"}
0005434756695	11BAE5	5965 991743	MAKSIM KAZAKOV	{"email": "mkazakov-031973@postgrespro.ru", "phone": "+70245739574"}
0005434756696	022B50	4586 219605	EVGENIY KRASNOV	{"phone": "+70169938555"}
0005434756697	F1AAC4	8608 408590	TATYANA PETROVA	{"email": "petrovatatyana1962@postgrespro.ru", "phone": "+70438402761"}
0005434756698	25977F	5755 920952	TATYANA LOGINOVA	{"email": "t-loginova.12081984@postgrespro.ru", "phone": "+70614761857"}
0005434756699	25977F	8158 395215	VIKTOR IVANOV	{"email": "ivanov_viktor101974@postgrespro.ru", "phone": "+70539471171"}
0005434756700	A40C3C	1996 434617	ELENA FOMINA	{"email": "fomina-e1976@postgrespro.ru", "phone": "+70822853932"}
0005434756701	EC9D6E	0474 517756	KSENIYA EFIMOVA	{"phone": "+70240798086"}
0005434756702	544B5F	2053 027197	VALERIY MAKSIMOV	{"phone": "+70696313211"}
0005434756703	544B5F	2703 746961	DANIIL SOKOLOV	{"email": "daniil_sokolov.011970@postgrespro.ru", "phone": "+70333561559"}
0005434756704	6DB8DD	8896 231073	VIKTOR KUZMIN	{"email": "kuzminviktor051981@postgrespro.ru", "phone": "+70201530885"}
0005434756705	ECB88D	3028 291076	MARIYA IVANOVA	{"email": "mariya-ivanova.041978@postgrespro.ru", "phone": "+70215598896"}
0005434756706	68DCE8	9789 442203	EVGENIY ZAKHAROV	{"email": "zakharov-evgeniy-111972@postgrespro.ru", "phone": "+70557572658"}
0005434756707	069A7F	0698 438357	GALINA TARASOVA	{"phone": "+70138346481"}
0005434756708	2221AA	9666 427205	ASIYA KAZAKOVA	{"phone": "+70608909060"}
0005434756709	518315	0888 017624	ALEKSEY IVANOV	{"phone": "+70701584950"}
0005434756710	C1FFA9	7438 134541	ANNA GERASIMOVA	{"email": "gerasimova_anna.22111970@postgrespro.ru", "phone": "+70005966795"}
0005434756711	C1FFA9	6163 916463	NIKITA KISELEV	{"email": "kiselev_n-16041982@postgrespro.ru", "phone": "+70039260808"}
0005434756712	E1FE86	8414 861635	EVGENIY VOROBEV	{"email": "evgeniyvorobev.051978@postgrespro.ru", "phone": "+70115355053"}
0005434756713	8DF0A5	4758 537378	DMITRIY NOVIKOV	{"phone": "+70926584307"}
0005434756714	211847	5688 654213	ELENA PAVLOVA	{"email": "pavlova_e1975@postgrespro.ru", "phone": "+70842636206"}
0005434756715	211847	4050 018204	MARINA MASLOVA	{"email": "marina_maslova_111974@postgrespro.ru", "phone": "+70303799335"}
0005434756716	D9FFC1	9366 510014	NINA MEDVEDEVA	{"email": "medvedevanina-091976@postgrespro.ru", "phone": "+70710459795"}
0005434756717	D9FFC1	0475 558849	ANNA ERMAKOVA	{"phone": "+70559224841"}
0005434756718	D9FFC1	5667 188605	OLGA BELYAEVA	{"phone": "+70903091510"}
0005434756719	A3C797	1760 206390	YURIY ZAKHAROV	{"phone": "+70379872220"}
0005434756720	156CDB	4878 764509	ALEKSANDR KUZNECOV	{"phone": "+70889750176"}
0005434756721	156CDB	2732 263665	VIKTOR BARANOV	{"email": "viktor.baranov.1982@postgrespro.ru", "phone": "+70230815431"}
0005434756722	3FF54F	2339 690426	MARIYA MATVEEVA	{"phone": "+70765658156"}
0005434756723	3FF54F	0695 215743	ELIZAVETA MAKAROVA	{"phone": "+70295958930"}
0005434756724	CCAB9C	0581 693991	SERGEY ZAKHAROV	{"phone": "+70510531561"}
0005434756725	4E32EA	5294 826963	VLADIMIR VASILEV	{"phone": "+70370069986"}
0005434756726	E2B572	5502 093223	MARIYA ABRAMOVA	{"email": "mariya.abramova.1966@postgrespro.ru", "phone": "+70986683051"}
0005434756727	8F1815	3736 842417	IVAN NIKITIN	{"email": "nikitin.i-061981@postgrespro.ru", "phone": "+70002403114"}
0005434756729	DBAE17	6286 244036	ANNA MIRONOVA	{"phone": "+70317414830"}
0005434756730	AE2D3B	4617 469487	MARIYA BELYAEVA	{"email": "belyaevamariya_041987@postgrespro.ru", "phone": "+70029834337"}
0005434756731	588146	1545 603795	MARIYA MOROZOVA	{"email": "morozova.mariya-1967@postgrespro.ru", "phone": "+70519322681"}
0005434756732	F658E8	0932 965111	NATALYA ZOTOVA	{"phone": "+70508059246"}
0005434756733	111483	2925 152053	OKSANA FROLOVA	{"email": "frolova-oksana_1971@postgrespro.ru", "phone": "+70007653340"}
0005434756734	788897	6167 774840	ELENA ZOTOVA	{"phone": "+70362879663"}
0005434756735	788897	7497 377605	SERGEY VOROBEV	{"email": "vorobev_s061983@postgrespro.ru", "phone": "+70144930679"}
0005434756736	3D8A27	8109 673602	ALINA IVANOVA	{"phone": "+70478675814"}
0005434756737	92BEB1	1639 576831	TAISIYA TITOVA	{"phone": "+70083313441"}
0005434756738	D24562	6491 121848	ALEKSANDR EGOROV	{"phone": "+70324609945"}
0005434756739	D24562	8324 853010	IRINA PETROVA	{"email": "petrovai_28041974@postgrespro.ru", "phone": "+70814420372"}
0005434756740	283F56	6006 720209	OLGA ORLOVA	{"phone": "+70163898337"}
0005434756741	C0434D	2683 586726	DANIL ISAEV	{"phone": "+70448336793"}
0005434756742	E5107A	9205 114981	ROSTISLAV KONOVALOV	{"email": "konovalovrostislav.041977@postgrespro.ru", "phone": "+70443824838"}
0005434756743	EAF982	0817 849946	MAKSIM TIMOFEEV	{"phone": "+70681284812"}
0005434756744	EAF982	3111 820090	ANASTASIYA ORLOVA	{"email": "a-orlova_01091978@postgrespro.ru", "phone": "+70563252841"}
0005434756745	419783	1007 719122	MARINA OSIPOVA	{"phone": "+70083719456"}
0005434756746	189DC3	3698 580968	GENNADIY GAVRILOV	{"phone": "+70421285626"}
0005434756747	2A2AB4	7040 514239	ALEKSANDR IVANOV	{"phone": "+70626731483"}
0005434756748	A1AD9B	9080 399284	PAVEL ALEKSEEV	{"email": "alekseev_pavel_021967@postgrespro.ru", "phone": "+70293638080"}
0005434756749	B3BA3A	6329 253487	DANIIL SOKOLOV	{"email": "daniil-sokolov071981@postgrespro.ru", "phone": "+70407743744"}
0005434756750	ECCC7D	0617 039655	DMITRIY MOROZOV	{"email": "d.morozov_03011969@postgrespro.ru", "phone": "+70139353702"}
0005434756751	ECCC7D	2457 188706	EKATERINA OSIPOVA	{"phone": "+70558819524"}
0005434756752	3E543E	1360 808899	EKATERINA TROFIMOVA	{"phone": "+70871995109"}
0005434756753	B8450D	6181 400468	OLGA EFREMOVA	{"email": "efremova.o.1977@postgrespro.ru", "phone": "+70030050932"}
0005434756754	B8450D	1874 545906	LYUDMILA ROMANOVA	{"email": "lromanova_041982@postgrespro.ru", "phone": "+70547805245"}
0005434756755	B0AD33	4896 781729	DMITRIY BARANOV	{"phone": "+70712335544"}
0005434756756	B0AD33	8248 564529	EKATERINA KARPOVA	{"phone": "+70435961538"}
0005434756757	9E6F11	3338 037479	ALEKSEY STEPANOV	{"email": "stepanov-a09111975@postgrespro.ru", "phone": "+70570849765"}
0005434756758	2FE530	7979 141342	LYUBOV GUSEVA	{"email": "guseva-l.1973@postgrespro.ru", "phone": "+70827275785"}
0005434756759	B6338A	4751 873813	ELENA MAKSIMOVA	{"email": "maksimova_elena1970@postgrespro.ru", "phone": "+70142296668"}
0005434756760	D96EC0	8391 837725	IGOR MOROZOV	{"email": "morozov_i-31101964@postgrespro.ru", "phone": "+70631130846"}
0005434756761	79F308	9203 359190	ANASTASIYA ROMANOVA	{"phone": "+70885362775"}
0005434756762	19B57C	7284 512141	IRINA PAVLOVA	{"phone": "+70605855170"}
0005434756763	BE3B9E	6214 131280	ALEKSANDRA IVANOVA	{"phone": "+70146781283"}
0005434756764	01F8B5	4030 634811	IRINA VASILEVA	{"email": "vasileva-irina.041973@postgrespro.ru", "phone": "+70715349834"}
0005434756765	01F8B5	6495 129306	LILIYA VOROBEVA	{"email": "vorobeval101963@postgrespro.ru", "phone": "+70141359552"}
0005434756766	69D0E9	9296 035533	VLADIMIR MAKSIMOV	{"email": "vladimirmaksimov_121969@postgrespro.ru", "phone": "+70141573288"}
0005434756767	9D43E2	6303 306777	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr.111974@postgrespro.ru", "phone": "+70026290057"}
0005434756768	312374	1197 492530	YULIYA FADEEVA	{"phone": "+70523180896"}
0005434756769	9AD470	0477 415622	ANTON KUZMIN	{"email": "kuzmin_anton-101982@postgrespro.ru", "phone": "+70527606957"}
0005434756770	9AD470	8396 442386	OLGA PETROVA	{"email": "petrova-olga041970@postgrespro.ru", "phone": "+70079327293"}
0005434756771	3A5C41	4976 547076	DMITRIY ANDREEV	{"phone": "+70491592226"}
0005434756772	3A5C41	8352 223742	MARIYA ISAEVA	{"phone": "+70759328240"}
0005434756773	6E6FF6	7082 665109	ANDREY NIKOLAEV	{"email": "nikolaev.andrey1972@postgrespro.ru", "phone": "+70024956573"}
0005434756774	6E6FF6	1231 221969	ELENA MARTYNOVA	{"email": "martynova_elena-121987@postgrespro.ru", "phone": "+70386607772"}
0005434756775	C1467E	5197 241406	SERGEY SMIRNOV	{"phone": "+70779770762"}
0005434756887	512BD2	6413 929351	ANATOLIY MOISEEV	{"phone": "+70119776407"}
0005434756776	C1467E	7556 751248	NADEZHDA KISELEVA	{"email": "kiseleva-nadezhda10121979@postgrespro.ru", "phone": "+70096389989"}
0005434756777	3EFD49	9925 711261	YULIYA BOGDANOVA	{"phone": "+70031926667"}
0005434756778	4C3704	5404 183874	NINA ILINA	{"email": "ilina_n-061976@postgrespro.ru", "phone": "+70548329367"}
0005434756779	D33FAC	8901 916378	ALEKSANDR SOROKIN	{"email": "aleksandrsorokin-1971@postgrespro.ru", "phone": "+70744340515"}
0005434756780	208D86	5517 132751	ANNA KUZMINA	{"phone": "+70590568815"}
0005434756781	208D86	1011 650532	SVETLANA KOROLEVA	{"phone": "+70792046429"}
0005434756782	D55B24	2188 252373	YURIY KRASNOV	{"email": "krasnov.yuriy_25051973@postgrespro.ru", "phone": "+70065749268"}
0005434756783	D55B24	3890 664600	POLINA KUZNECOVA	{"email": "kuznecova-polina-1970@postgrespro.ru", "phone": "+70472889323"}
0005434756784	90CFF5	2741 134179	SERGEY FEDOTOV	{"phone": "+70510276076"}
0005434756785	90CFF5	5500 501904	VALENTINA GRISHINA	{"email": "v-grishina_031984@postgrespro.ru", "phone": "+70830463746"}
0005434756786	90CFF5	1709 886558	OLGA GRISHINA	{"email": "grishina_olga1969@postgrespro.ru", "phone": "+70527950452"}
0005434756787	D7986E	6348 470418	DANILA ROMANOV	{"phone": "+70862182031"}
0005434756788	B07CBB	4584 492615	LYUDMILA SOKOLOVA	{"email": "lyudmila-sokolova-011971@postgrespro.ru", "phone": "+70339623454"}
0005434756789	B07CBB	1786 190081	ALEKSEY SERGEEV	{"phone": "+70564915608"}
0005434756790	9DFE6E	5555 899410	ANATOLIY ZAYCEV	{"phone": "+70595819600"}
0005434756791	3DC0AB	3893 964883	GALINA FROLOVA	{"email": "galina-frolova_1953@postgrespro.ru", "phone": "+70598731241"}
0005434756792	3DC0AB	3709 154486	ROMAN IVANOV	{"email": "romanivanov_051972@postgrespro.ru", "phone": "+70629791842"}
0005434756793	77556A	7682 408235	NADEZHDA SEMENOVA	{"email": "semenovanadezhda041975@postgrespro.ru", "phone": "+70368172628"}
0005434756794	BC4B1E	0752 543395	ANASTASIYA AKIMOVA	{"phone": "+70170356836"}
0005434756795	277DF9	8058 262588	RUSLAN MIKHAYLOV	{"email": "mikhaylov.ruslan_1962@postgrespro.ru", "phone": "+70778156027"}
0005434756796	6DA53E	7795 078020	VLADISLAV MAKAROV	{"phone": "+70890160395"}
0005434756797	56688D	2901 551762	TATYANA KOZLOVA	{"phone": "+70655955273"}
0005434756798	56688D	2126 828892	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov.1977@postgrespro.ru", "phone": "+70763014804"}
0005434756799	8D0C01	4015 617227	ALEKSANDR MEDVEDEV	{"phone": "+70157668051"}
0005434756800	D9B1F5	1438 546921	EKATERINA NIKOLAEVA	{"phone": "+70023720873"}
0005434756801	BDFEBD	6836 288345	TATYANA LUKYANOVA	{"phone": "+70041900449"}
0005434756802	BDFEBD	0579 998645	KLAVDIYA VLASOVA	{"phone": "+70592839270"}
0005434756803	20035A	0518 134267	TAISIYA NIKITINA	{"email": "nikitinataisiya.20121973@postgrespro.ru", "phone": "+70991110028"}
0005434756804	6E4F44	2150 815504	VLADIMIR PAVLOV	{"phone": "+70361984862"}
0005434756805	6E4F44	6053 681523	ANDREY ANTONOV	{"email": "andreyantonov.011968@postgrespro.ru", "phone": "+70513396768"}
0005434756806	E35592	4618 473258	VLADISLAV KUZNECOV	{"email": "kuznecov_vladislav_1968@postgrespro.ru", "phone": "+70472873115"}
0005434756807	E35592	9020 087404	ANTONINA MELNIKOVA	{"phone": "+70487350618"}
0005434756808	CF9348	1623 564987	OLGA KUZMINA	{"phone": "+70890672844"}
0005434756809	951EA5	3577 899336	ANDREY SIDOROV	{"phone": "+70618361308"}
0005434756810	CFF46D	6563 887402	ALEKSANDR SERGEEV	{"phone": "+70477909615"}
0005434756811	D46ED6	8212 556812	MIKHAIL MAKSIMOV	{"phone": "+70994773686"}
0005434756812	9AA504	0476 452889	MARINA FROLOVA	{"phone": "+70368458053"}
0005434756813	C8EA2C	7068 915708	VALENTINA NIKITINA	{"email": "valentina.nikitina.20101979@postgrespro.ru", "phone": "+70938489699"}
0005434756814	C8EA2C	2926 041812	SALAVAT POPOV	{"phone": "+70694507519"}
0005434756815	C8EA2C	7255 560652	GENNADIY IVANOV	{"phone": "+70882639881"}
0005434756816	1747EA	0576 127863	ANASTASIYA KUZMINA	{"email": "kuzmina_anastasiya051973@postgrespro.ru", "phone": "+70903139262"}
0005434756817	1747EA	6684 829434	VLADIMIR NIKITIN	{"email": "nikitin-vladimir.21071978@postgrespro.ru", "phone": "+70963909090"}
0005434756818	C6D862	6953 310226	ILYA TARASOV	{"email": "tarasov.i_1967@postgrespro.ru", "phone": "+70250956009"}
0005434756819	C6D862	8588 879532	VADIM MELNIKOV	{"email": "vadimmelnikov121976@postgrespro.ru", "phone": "+70210991599"}
0005434756820	F1ADD0	6835 981408	MIKHAIL MIKHAYLOV	{"email": "m_mikhaylov_30041966@postgrespro.ru", "phone": "+70287059275"}
0005434756821	DFE76E	4330 685670	LEONID NOVIKOV	{"phone": "+70759505779"}
0005434756822	E664E9	6928 726067	ALEKSANDR VOROBEV	{"phone": "+70138216498"}
0005434756823	6612BC	2743 191709	ANASTASIYA GAVRILOVA	{"email": "anastasiyagavrilova-01081973@postgrespro.ru", "phone": "+70271419235"}
0005434756824	F1FC4A	9269 161046	LADA ZOTOVA	{"phone": "+70461476873"}
0005434756825	A21C70	5905 996786	DMITRIY DMITRIEV	{"phone": "+70118743872"}
0005434756826	1DD1BC	2044 255139	LIDIYA IVANOVA	{"phone": "+70351706788"}
0005434756827	1DD1BC	1130 471350	EKATERINA KUZNECOVA	{"email": "kuznecova-e091968@postgrespro.ru", "phone": "+70594248230"}
0005434756828	26E97F	9804 041210	LYUDMILA ANDREEVA	{"phone": "+70909783563"}
0005434756829	F011E6	0708 084926	ALEKSANDR ROMANOV	{"phone": "+70133522946"}
0005434756830	F011E6	5186 530713	TATYANA VASILEVA	{"email": "vasileva.tatyana.24111972@postgrespro.ru", "phone": "+70175381500"}
0005434756831	08F38B	0789 824398	VALENTINA FROLOVA	{"phone": "+70758821762"}
0005434756832	C5612A	1567 333318	PRASKOVYA NOVIKOVA	{"email": "novikova-p071970@postgrespro.ru", "phone": "+70815546672"}
0005434756833	695F40	8409 019858	SVETLANA FADEEVA	{"email": "s.fadeeva101970@postgrespro.ru", "phone": "+70134097359"}
0005434756834	666038	4071 580448	MARIYA OVCHINNIKOVA	{"email": "mariya-ovchinnikova_1975@postgrespro.ru", "phone": "+70747503600"}
0005434756835	666038	2812 203739	ELENA VASILEVA	{"email": "elenavasileva.1970@postgrespro.ru", "phone": "+70360629089"}
0005434756836	9D0FCF	5989 596002	ANASTASIYA ZAKHAROVA	{"email": "azakharova_1977@postgrespro.ru", "phone": "+70181527391"}
0005434756837	CD03D5	0395 099566	SERGEY IVANOV	{"email": "s.ivanov_03031970@postgrespro.ru", "phone": "+70812021585"}
0005434756838	5520F4	6912 163756	ELENA MIKHAYLOVA	{"email": "mikhaylova.e071963@postgrespro.ru", "phone": "+70214691965"}
0005434756839	5520F4	4357 519791	ILYA FEDOTOV	{"email": "fedotov_ilya.19091974@postgrespro.ru", "phone": "+70103211885"}
0005434756840	B1CF4C	3202 095748	YURIY VASILEV	{"email": "yuriy-vasilev22011978@postgrespro.ru", "phone": "+70407040768"}
0005434756841	30ECB1	5690 758648	ELENA RODIONOVA	{"phone": "+70329907147"}
0005434756842	3B2A47	2002 694876	ALINA SCHERBAKOVA	{"phone": "+70931629329"}
0005434756843	3B2A47	9587 071966	YULIYA LAZAREVA	{"phone": "+70220004687"}
0005434756844	F9BE73	8770 013274	VALENTINA MAKAROVA	{"phone": "+70440537782"}
0005434756845	495EE7	4452 285357	NIKOLAY GUSEV	{"phone": "+70086083937"}
0005434756846	EF7CEB	7088 556568	NINA BORISOVA	{"email": "nina_borisova_05111974@postgrespro.ru", "phone": "+70596715885"}
0005434756847	249419	6507 414283	VIKTOR SOROKIN	{"email": "viktorsorokin-1972@postgrespro.ru", "phone": "+70588979999"}
0005434756848	4AE82F	5948 538559	ELENA POPOVA	{"phone": "+70824883103"}
0005434756849	4AE82F	9219 519979	INNA KRASNOVA	{"phone": "+70747189841"}
0005434756850	164DBF	0172 888277	ANGELINA YAKOVLEVA	{"phone": "+70700085034"}
0005434756851	7F56E2	7549 378683	ALEKSANDR ABRAMOV	{"email": "abramova.09071967@postgrespro.ru", "phone": "+70787531091"}
0005434756852	43F5DB	2036 878525	ARKADIY RODIONOV	{"email": "rodionov-a071973@postgrespro.ru", "phone": "+70754582721"}
0005434756853	9011A7	2171 868314	VLADIMIR BELOV	{"email": "vladimir-belov-03011976@postgrespro.ru", "phone": "+70115734117"}
0005434756854	B44739	7915 383154	TATYANA ABRAMOVA	{"phone": "+70177445273"}
0005434756855	8B3594	3840 522346	OLGA ZAKHAROVA	{"email": "ozakharova_1973@postgrespro.ru", "phone": "+70677963913"}
0005434756856	8B3594	9904 186179	VALENTINA RODIONOVA	{"phone": "+70399306536"}
0005434756857	45B408	1751 645881	NATALYA KONOVALOVA	{"email": "natalya.konovalova.031971@postgrespro.ru", "phone": "+70264945033"}
0005434756858	F412EF	7514 311109	ALEKSANDR KUDRYASHOV	{"phone": "+70069563126"}
0005434756859	F412EF	7339 427255	ALEKSANDR POPOV	{"email": "popov-aleksandr1976@postgrespro.ru", "phone": "+70044143284"}
0005434756860	D95CE3	3829 128586	YULIYA RYABOVA	{"phone": "+70315081334"}
0005434756861	D95CE3	8064 247470	ALINA TARASOVA	{"phone": "+70718166777"}
0005434756862	D95CE3	3256 225097	NINA FROLOVA	{"phone": "+70906839141"}
0005434756863	A0B423	9242 264181	ALEKSANDR ANTONOV	{"email": "aantonov.021966@postgrespro.ru", "phone": "+70882890174"}
0005434756864	A0B423	9404 638111	ALEKSANDR STEPANOV	{"email": "stepanova_31011967@postgrespro.ru", "phone": "+70416442055"}
0005434756865	48AE4E	9405 147788	EVGENIY STEPANOV	{"email": "e.stepanov.1981@postgrespro.ru", "phone": "+70224210139"}
0005434756866	48AE4E	6524 143625	ALEKSEY NAUMOV	{"email": "anaumov.1977@postgrespro.ru", "phone": "+70201245507"}
0005434756867	83FD5F	2093 067070	ELENA KOZLOVA	{"phone": "+70121008973"}
0005434756868	F286F1	4803 444307	VITALIY DMITRIEV	{"email": "dmitrievvitaliy1967@postgrespro.ru", "phone": "+70883417846"}
0005434756869	589E80	6776 870110	ARTEM YAKOVLEV	{"email": "yakovlev.a_1962@postgrespro.ru", "phone": "+70393161965"}
0005434756870	589E80	1389 363893	ALEKSANDRA SEMENOVA	{"email": "aleksandrasemenova.1974@postgrespro.ru", "phone": "+70881525416"}
0005434756871	1E9145	8783 993599	DMITRIY SERGEEV	{"phone": "+70310289579"}
0005434756872	9937CB	1765 502234	TATYANA PETROVA	{"email": "tpetrova_09101963@postgrespro.ru", "phone": "+70704483894"}
0005434756873	AD9427	8396 087072	LYUDMILA MOISEEVA	{"email": "moiseeva.l.11051974@postgrespro.ru", "phone": "+70524287803"}
0005434756874	C68AC1	0712 489945	MARINA NOVIKOVA	{"email": "novikova_marina.1978@postgrespro.ru", "phone": "+70310380715"}
0005434756875	C68AC1	6181 960835	VITALIY FOMIN	{"email": "vitaliy_fomin22091978@postgrespro.ru", "phone": "+70127506137"}
0005434756876	C68AC1	6702 954823	OKSANA FEDOROVA	{"phone": "+70885575256"}
0005434756877	39D1BC	6344 294128	GALINA TIKHONOVA	{"email": "galina-tikhonova-031982@postgrespro.ru", "phone": "+70105269582"}
0005434756878	CAD100	1104 307752	FAINA VASILEVA	{"email": "vasileva.f-1965@postgrespro.ru", "phone": "+70672962324"}
0005434756879	CAD100	7204 623766	ALEKSANDR SAVELEV	{"phone": "+70980546088"}
0005434756880	41E374	2573 912734	TATYANA ZHURAVLEVA	{"email": "zhuravlevatatyana21111970@postgrespro.ru", "phone": "+70534159737"}
0005434756881	F6FC5F	1993 643143	MATVEY FEDOROV	{"email": "matvey-fedorov071972@postgrespro.ru", "phone": "+70065548383"}
0005434756882	F58205	8754 754006	ELIZAVETA FILIPPOVA	{"email": "elizaveta.filippova.1978@postgrespro.ru", "phone": "+70497054427"}
0005434756883	B77428	6194 830342	TATYANA ARKHIPOVA	{"phone": "+70630392306"}
0005434756884	B77428	8185 836132	SVETLANA FOMINA	{"phone": "+70575916224"}
0005434756885	B77428	9643 290892	ALENA FADEEVA	{"phone": "+70084805841"}
0005434756886	512BD2	4093 241993	LEONID MIRONOV	{"phone": "+70627207339"}
0005434756888	23124F	8414 197672	OLGA KOROLEVA	{"phone": "+70239527203"}
0005434756889	AFCE94	0841 416549	ALEKSANDR MIRONOV	{"email": "mironovaleksandr.1979@postgrespro.ru", "phone": "+70005774042"}
0005434756890	20D3AD	6571 852771	SERGEY NAZAROV	{"phone": "+70702787758"}
0005434756891	AA27C2	9877 788705	LYUDMILA IVANOVA	{"email": "ivanovalyudmila.24011980@postgrespro.ru", "phone": "+70219209150"}
0005434756892	730319	6771 278873	ALEKSANDR MARTYNOV	{"phone": "+70421844312"}
0005434756893	F8C345	2061 755328	LYUDMILA MIKHAYLOVA	{"phone": "+70778110441"}
0005434756894	702B92	8223 887255	ANASTASIYA VOLKOVA	{"email": "anastasiya.volkova-1962@postgrespro.ru", "phone": "+70052128429"}
0005434756895	52C34F	3395 325654	IRINA KOZLOVA	{"phone": "+70670948301"}
0005434756896	002752	4031 563403	VALERIY IVANOV	{"email": "vivanov.011980@postgrespro.ru", "phone": "+70795153487"}
0005434756897	002752	0006 065884	ZOYA FOMINA	{"email": "fomina_z_121959@postgrespro.ru", "phone": "+70284148825"}
0005434756898	71AC04	9624 048719	ALEKSEY DMITRIEV	{"email": "aleksey_dmitriev_051980@postgrespro.ru", "phone": "+70471160124"}
0005434756899	ED5C72	6647 190359	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr.071985@postgrespro.ru", "phone": "+70099330362"}
0005434756900	ED5C72	8749 575418	EVGENIYA NAZAROVA	{"phone": "+70069158994"}
0005434756901	1E58DE	9382 966168	LIDIYA ZAKHAROVA	{"email": "lzakharova-041973@postgrespro.ru", "phone": "+70039182906"}
0005434756902	1E58DE	0233 129827	DMITRIY BELOV	{"phone": "+70117021371"}
0005434756903	1E58DE	9256 408442	IVAN SEMENOV	{"email": "semenov-i.121976@postgrespro.ru", "phone": "+70304266308"}
0005434756904	31E4BC	8626 963266	ELENA CHERNOVA	{"phone": "+70391797088"}
0005434756905	FCE3A3	4014 204085	OLEG GERASIMOV	{"email": "gerasimovoleg-09051968@postgrespro.ru", "phone": "+70408950628"}
0005434756906	023552	3981 171970	NATALIYA MELNIKOVA	{"email": "melnikova.nataliya_041990@postgrespro.ru", "phone": "+70764045922"}
0005434756907	023552	4210 711370	NATALYA LEBEDEVA	{"phone": "+70392126674"}
0005434756908	145244	1080 908066	OLGA KUZNECOVA	{"phone": "+70342146919"}
0005434756909	145244	1028 245250	NATALYA ISAEVA	{"email": "n_isaeva_101975@postgrespro.ru", "phone": "+70713025585"}
0005434756910	5B032E	3110 736700	TIMUR VASILEV	{"phone": "+70259868665"}
0005434756911	9021CD	2932 194841	YULIYA IVANOVA	{"email": "ivanova.y_1983@postgrespro.ru", "phone": "+70038826823"}
0005434756912	2919FE	8152 541306	ALESYA NIKITINA	{"email": "a_nikitina_23121979@postgrespro.ru", "phone": "+70666534777"}
0005434756913	FD6037	4938 893760	ANDREY NIKITIN	{"email": "nikitin.andrey09021975@postgrespro.ru", "phone": "+70606274383"}
0005434756914	FD6037	4755 541696	ELENA NIKOLAEVA	{"email": "elena.nikolaeva.041973@postgrespro.ru", "phone": "+70725719566"}
0005434756915	985DAC	7297 013530	DMITRIY ALEKSEEV	{"email": "d_alekseev.121975@postgrespro.ru", "phone": "+70554502512"}
0005434756916	985DAC	8630 027185	NIKITA SMIRNOV	{"phone": "+70580867937"}
0005434756917	A75669	2990 577330	MARINA SMIRNOVA	{"email": "smirnovamarina-081977@postgrespro.ru", "phone": "+70128703289"}
0005434756918	A75669	0377 058760	SERGEY ROMANOV	{"email": "sromanov17011974@postgrespro.ru", "phone": "+70388325539"}
0005434756919	732EF1	8307 673438	EKATERINA SCHERBAKOVA	{"phone": "+70077986704"}
0005434756920	732EF1	2625 792198	MIKHAIL BELOV	{"email": "mikhail_belov-07081973@postgrespro.ru", "phone": "+70212709531"}
0005434756921	732EF1	0190 187578	VASILISA MAKAROVA	{"phone": "+70987796602"}
0005434756922	40B4CC	1349 756143	ZOYA KUZNECOVA	{"email": "kuznecovaz.101964@postgrespro.ru", "phone": "+70186975995"}
0005434756923	40B4CC	3513 254733	VLADIMIR BARANOV	{"phone": "+70131439688"}
0005434756924	40B4CC	6877 306634	VASILIY YAKOVLEV	{"email": "v-yakovlev-101981@postgrespro.ru", "phone": "+70225355444"}
0005434756925	6CA347	1507 590042	ELENA BARANOVA	{"email": "baranovae.05011977@postgrespro.ru", "phone": "+70999502646"}
0005434756926	3DD5F6	6306 336995	TATYANA AKIMOVA	{"email": "t_akimova-1973@postgrespro.ru", "phone": "+70642279657"}
0005434756927	3DD5F6	9122 417299	ANNA KUZNECOVA	{"email": "kuznecova.a23011967@postgrespro.ru", "phone": "+70265022779"}
0005434756928	2C360F	8050 799369	SNEZHANA ZAYCEVA	{"email": "zaycevas.071964@postgrespro.ru", "phone": "+70166754511"}
0005434756929	59374D	2760 090257	IRINA NOVIKOVA	{"phone": "+70437560473"}
0005434756930	59374D	5743 082352	YULIYA TIKHONOVA	{"phone": "+70409590644"}
0005434756931	24D098	7544 126261	NADEZHDA MALYSHEVA	{"phone": "+70471166245"}
0005434756932	24D098	7074 489997	EVGENIY KUZNECOV	{"phone": "+70219625759"}
0005434756933	746E20	6352 364807	IRINA NIKITINA	{"email": "nikitina.i-1964@postgrespro.ru", "phone": "+70790718116"}
0005434757322	C8CE5E	7426 740887	MARINA TIKHONOVA	{"phone": "+70403888845"}
0005434756934	D1D4BD	3908 753880	ALBINA ANISIMOVA	{"email": "albina-anisimova.1966@postgrespro.ru", "phone": "+70165769051"}
0005434756935	3DEE6B	0707 063386	VIKTOR IVANOV	{"email": "ivanovviktor_041976@postgrespro.ru", "phone": "+70422937045"}
0005434756936	9D843E	4360 436505	SERGEY MAKAROV	{"email": "makarovs.24031981@postgrespro.ru", "phone": "+70040434980"}
0005434756937	197268	5201 232063	TATYANA KARPOVA	{"phone": "+70164030322"}
0005434756938	A333B0	7200 837525	ANDREY KUZNECOV	{"email": "kuznecov-andrey1968@postgrespro.ru", "phone": "+70891537708"}
0005434756939	A333B0	8821 089409	GALINA GRISHINA	{"email": "grishinag081966@postgrespro.ru", "phone": "+70928583466"}
0005434756940	8D07BA	3642 566415	OLGA NAZAROVA	{"email": "nazarova_o_1967@postgrespro.ru", "phone": "+70535905647"}
0005434756941	5840AA	6820 836532	ELENA SOROKINA	{"phone": "+70007803396"}
0005434756942	BBF459	2259 934076	IGOR KAZAKOV	{"phone": "+70407086269"}
0005434756943	BBF459	1130 960907	ALEKSANDR ALEKSEEV	{"phone": "+70451711424"}
0005434756944	D3E196	9456 477788	VALERIY ZHUKOV	{"email": "zhukov.valeriy26091978@postgrespro.ru", "phone": "+70580535403"}
0005434756945	D3E196	8714 605489	ALEKSANDR ORLOV	{"email": "aleksandr_orlov_1976@postgrespro.ru", "phone": "+70498676879"}
0005434756946	EF23EB	4423 674072	VLADIMIR KUZMIN	{"email": "vladimir.kuzmin-031966@postgrespro.ru", "phone": "+70470593157"}
0005434756947	C2CCAC	8371 186918	TATYANA IVANOVA	{"phone": "+70314899222"}
0005434756948	7FE07F	0092 149150	VLADIMIR VOLKOV	{"email": "volkov-vladimir-1964@postgrespro.ru", "phone": "+70475209453"}
0005434756949	B848C2	8002 571401	NATALYA KOZLOVA	{"email": "n.kozlova13011967@postgrespro.ru", "phone": "+70342232708"}
0005434756950	B6EBD5	4194 239163	DMITRIY POPOV	{"email": "d.popov.24061964@postgrespro.ru", "phone": "+70220792949"}
0005434756951	168DB4	3998 220637	DENIS MATVEEV	{"email": "denis_matveev.1964@postgrespro.ru", "phone": "+70426004341"}
0005434756952	168DB4	8039 035521	DMITRIY VOLKOV	{"phone": "+70618660315"}
0005434756953	CBA42E	1607 881378	VALERIYA MOROZOVA	{"phone": "+70282929118"}
0005434756954	FE55AA	2443 738685	YULIYA POTAPOVA	{"email": "potapova-y-1974@postgrespro.ru", "phone": "+70629691389"}
0005434756955	FE55AA	9983 211673	ULYANA MAKAROVA	{"email": "u-makarova1975@postgrespro.ru", "phone": "+70187641362"}
0005434756956	FE55AA	6217 783445	ELIZAVETA SERGEEVA	{"email": "sergeeva-e-14011974@postgrespro.ru", "phone": "+70537951859"}
0005434756957	941431	7664 150390	LYUDMILA TROFIMOVA	{"email": "trofimoval031974@postgrespro.ru", "phone": "+70157468489"}
0005434756958	DF7B1D	6539 343799	DARYA PAVLOVA	{"email": "darya-pavlova_1973@postgrespro.ru", "phone": "+70727914493"}
0005434756959	5E6D70	7607 982105	ELENA KOMAROVA	{"email": "komarova-elena1965@postgrespro.ru", "phone": "+70210630135"}
0005434756960	56D15E	0393 648598	TATYANA RODIONOVA	{"email": "rodionova.t11091969@postgrespro.ru", "phone": "+70996826145"}
0005434756961	AD6868	4760 245726	NATALIYA KAZAKOVA	{"email": "kazakova.n-15101964@postgrespro.ru", "phone": "+70483713811"}
0005434756962	0883B6	3262 418279	LYUDMILA MIKHAYLOVA	{"phone": "+70375625420"}
0005434756963	0883B6	3875 540018	ZULFIYA MAKAROVA	{"phone": "+70069737840"}
0005434756964	312F8B	2357 836909	PAVEL ABRAMOV	{"phone": "+70859660910"}
0005434756965	FA832E	3992 411154	EKATERINA ZAKHAROVA	{"email": "zakharovae.1961@postgrespro.ru", "phone": "+70088810993"}
0005434756966	FA832E	2919 399454	DMITRIY ABRAMOV	{"phone": "+70894056400"}
0005434756967	3C71F8	3595 847628	VLADIMIR ORLOV	{"email": "v-orlov091975@postgrespro.ru", "phone": "+70401695296"}
0005434756968	3C71F8	5909 671857	EVGENIYA VASILEVA	{"phone": "+70904015443"}
0005434756969	1009D2	5108 314441	STANISLAV VOLKOV	{"email": "volkovstanislav04011966@postgrespro.ru", "phone": "+70227428827"}
0005434756970	42BE87	9411 536033	ALEKSANDRA SMIRNOVA	{"phone": "+70673805940"}
0005434756971	42BE87	1347 495552	MAKSIM IVANOV	{"email": "maksim.ivanov_061972@postgrespro.ru", "phone": "+70527615059"}
0005434756972	5E0D0E	2953 044110	VLADIMIR DMITRIEV	{"email": "dmitriev-v-1979@postgrespro.ru", "phone": "+70576746289"}
0005434756973	40DD1F	5881 303144	MAKSIM ORLOV	{"email": "maksim_orlov_13101964@postgrespro.ru", "phone": "+70444987478"}
0005434756974	40DD1F	6710 017789	ALINA NOVIKOVA	{"phone": "+70074282611"}
0005434756975	F8D679	5247 496303	GALINA KUZNECOVA	{"email": "kuznecova.galina.20111961@postgrespro.ru", "phone": "+70810185633"}
0005434756976	EC2084	9029 194323	ELENA PAVLOVA	{"phone": "+70796736632"}
0005434756977	37A3CE	6282 189856	RAISA MEDVEDEVA	{"phone": "+70715882109"}
0005434756978	1CE746	4402 510121	OLESYA ANTONOVA	{"email": "antonova_o-091974@postgrespro.ru", "phone": "+70627281583"}
0005434756979	9AFAC4	0930 383695	VIKTORIYA EGOROVA	{"phone": "+70147334097"}
0005434756980	450388	2896 996404	RADMIR GORBUNOV	{"email": "gorbunov.radmir-051976@postgrespro.ru", "phone": "+70755896302"}
0005434756981	D9274F	3834 883731	SERGEY NIKOLAEV	{"phone": "+70541094608"}
0005434756982	567E18	5155 503378	VERA KAZAKOVA	{"phone": "+70986804369"}
0005434756983	0A6A2A	8751 402668	ALLA RODIONOVA	{"email": "rodionova.a-041978@postgrespro.ru", "phone": "+70978806462"}
0005434756984	0A6A2A	0233 351100	MARINA LOGINOVA	{"phone": "+70677572611"}
0005434756985	252223	2827 052252	NATALYA MATVEEVA	{"phone": "+70170303745"}
0005434756986	252223	9505 223847	MIKHAIL MATVEEV	{"email": "mikhailmatveev_06111973@postgrespro.ru", "phone": "+70790241359"}
0005434756987	252223	5262 980570	VLADIMIR SOKOLOV	{"phone": "+70902963762"}
0005434756988	61649D	7279 277634	MAKSIM KUZNECOV	{"email": "maksim_kuznecov.091971@postgrespro.ru", "phone": "+70255445792"}
0005434756989	B34578	8906 500780	VIKTORIYA IVANOVA	{"email": "viktoriya_ivanova.1969@postgrespro.ru", "phone": "+70206996374"}
0005434756990	1B468F	1364 354056	ALEKSANDR MIKHAYLOV	{"phone": "+70622351773"}
0005434756991	19F7BB	1470 621217	LARISA KOZLOVA	{"email": "kozlova-larisa-1971@postgrespro.ru", "phone": "+70182989917"}
0005434756992	4C5FFB	1477 285919	VIKTOR POPOV	{"email": "popov-v-09031977@postgrespro.ru", "phone": "+70586723631"}
0005434756993	4C5FFB	0372 508854	ALEKSANDR ANDREEV	{"email": "a_andreev111983@postgrespro.ru", "phone": "+70360862637"}
0005434756994	A1CC06	3509 632653	VLADIMIR SMIRNOV	{"email": "v-smirnov1957@postgrespro.ru", "phone": "+70483520200"}
0005434756995	527D1F	2585 989871	EKATERINA SMIRNOVA	{"email": "smirnova.ekaterina.051972@postgrespro.ru", "phone": "+70285315453"}
0005434756996	05B624	0475 625461	VIKTOR SOLOVEV	{"email": "viktor_solovev111972@postgrespro.ru", "phone": "+70251358752"}
0005434756997	22ED87	7064 731990	GALINA KUZMINA	{"email": "kuzmina_g_051976@postgrespro.ru", "phone": "+70658980273"}
0005434756998	69BA91	3915 354395	KLAVDIYA SCHERBAKOVA	{"email": "scherbakova-k051969@postgrespro.ru", "phone": "+70303798932"}
0005434756999	69BA91	0210 806331	SVETLANA VLASOVA	{"phone": "+70003912909"}
0005434757000	25F343	8097 246060	ALENA NIKITINA	{"email": "alena_nikitina-1975@postgrespro.ru", "phone": "+70994184005"}
0005434757001	FAB2FD	2166 871401	ELENA ZAYCEVA	{"email": "e_zayceva_07111990@postgrespro.ru", "phone": "+70768783360"}
0005434757002	FAB2FD	6800 353848	SERGEY KONOVALOV	{"email": "konovalov_sergey-19041968@postgrespro.ru", "phone": "+70547980750"}
0005434757003	31C1D9	6492 612759	ALEKSEY SEMENOV	{"phone": "+70394541926"}
0005434757004	AA496D	7526 748337	ZINAIDA MIKHAYLOVA	{"phone": "+70887421127"}
0005434757005	AA496D	1897 073852	SVETLANA MIKHAYLOVA	{"email": "s.mikhaylova.091972@postgrespro.ru", "phone": "+70390997420"}
0005434757006	AA496D	8684 144897	SERGEY NIKOLAEV	{"phone": "+70940781873"}
0005434757007	CBF1BC	0729 885002	VASILIY KOZLOV	{"email": "vkozlov071970@postgrespro.ru", "phone": "+70532804694"}
0005434757008	49CB5B	1873 466042	ALEKSANDR ILIN	{"phone": "+70715993942"}
0005434757009	F37A21	1141 498754	VIKTOR VASILEV	{"email": "viktor-vasilev.13121968@postgrespro.ru", "phone": "+70714978748"}
0005434757010	C28CC8	2085 615953	LYUDMILA ANISIMOVA	{"phone": "+70033695485"}
0005434757011	8DF961	1324 179195	ALEKSEY EGOROV	{"email": "aleksey-egorov.30091971@postgrespro.ru", "phone": "+70499829548"}
0005434757012	10645B	3027 458836	ALEKSANDR MAKAROV	{"email": "a.makarov-1982@postgrespro.ru", "phone": "+70251434007"}
0005434757013	D9DB67	8452 374433	LYUBOV PAVLOVA	{"phone": "+70248595155"}
0005434757014	D9DB67	9387 299990	OLEG NAZAROV	{"email": "nazarov.oleg.071967@postgrespro.ru", "phone": "+70333567230"}
0005434757015	D9DB67	2660 070097	ILYA BONDARENKO	{"email": "bondarenko-i.04071968@postgrespro.ru", "phone": "+70626125577"}
0005434757016	609D00	4451 302517	YURIY SHEVCHENKO	{"phone": "+70994296624"}
0005434757017	7AD91F	1615 698141	SERGEY ALEKSEEV	{"email": "s_alekseev-121966@postgrespro.ru", "phone": "+70089551186"}
0005434757254	A0413C	6933 933862	VADIM SMIRNOV	{"phone": "+70989724294"}
0005434757018	4A17B1	7625 350319	GALINA ISAEVA	{"email": "isaevagalina-091967@postgrespro.ru", "phone": "+70202782189"}
0005434757019	E845F8	5357 518190	GENNADIY ROMANOV	{"phone": "+70353016220"}
0005434757020	E845F8	0651 795488	EVGENIYA KRASNOVA	{"email": "krasnova_e1979@postgrespro.ru", "phone": "+70525839359"}
0005434757021	9940B4	4302 047738	VIKTOR POPOV	{"email": "popovviktor-20031975@postgrespro.ru", "phone": "+70040326440"}
0005434757022	9940B4	3510 428631	ANATOLIY EGOROV	{"phone": "+70287341532"}
0005434757023	D8DBA1	6533 832954	VASILIY ORLOV	{"email": "vorlov_13121983@postgrespro.ru", "phone": "+70081873630"}
0005434757024	48F45C	6469 069396	ANATOLIY STEPANOV	{"phone": "+70567281833"}
0005434757025	68E0A3	1507 764560	VLADIMIR KOZLOV	{"email": "v_kozlov.041967@postgrespro.ru", "phone": "+70208924879"}
0005434757026	37D923	6386 146776	VLADIMIR BELOV	{"email": "vbelov_031978@postgrespro.ru", "phone": "+70492586131"}
0005434757027	F6DBE6	0587 082073	LYUBOV KOLESNIKOVA	{"phone": "+70935697072"}
0005434757028	F6DBE6	6999 434596	LYUDMILA ZHURAVLEVA	{"email": "l.zhuravleva-121968@postgrespro.ru", "phone": "+70866082642"}
0005434757029	F6DBE6	3999 720613	NIKOLAY FEDOTOV	{"email": "fedotov_n-1981@postgrespro.ru", "phone": "+70571777770"}
0005434757030	626E5A	0285 997239	GALINA KAZAKOVA	{"phone": "+70294981660"}
0005434757031	626E5A	0512 727290	IBRAGIM IVANOV	{"phone": "+70932880142"}
0005434757032	B827DD	6670 410377	IRINA LOGINOVA	{"phone": "+70677833907"}
0005434757033	B827DD	7696 286122	ALEKSANDR SEMENOV	{"phone": "+70359629348"}
0005434757034	C2B3B0	8106 605201	ELENA FADEEVA	{"phone": "+70649425994"}
0005434757035	C2B3B0	2257 424903	ANNA NIKOLAEVA	{"phone": "+70192036890"}
0005434757036	70B55D	9195 967032	YURIY FROLOV	{"phone": "+70612428072"}
0005434757037	75F5CC	0752 320117	LEONTIY IVANOV	{"email": "leontiyivanov-1972@postgrespro.ru", "phone": "+70570250861"}
0005434757038	55392B	4293 271838	TATYANA KUZNECOVA	{"phone": "+70636301472"}
0005434757039	55392B	4083 513574	OLGA ALEKSANDROVA	{"phone": "+70539085203"}
0005434757040	7D2DDF	1483 516050	MIKHAIL ANTONOV	{"email": "mikhailantonov22051973@postgrespro.ru", "phone": "+70456586985"}
0005434757041	7D2DDF	5417 841834	MARINA SAVELEVA	{"phone": "+70620012995"}
0005434757042	093697	9877 609521	NIKITA PETROV	{"phone": "+70665773721"}
0005434757043	887634	3613 312491	EVGENIY MIKHAYLOV	{"email": "e.mikhaylov_021969@postgrespro.ru", "phone": "+70366312854"}
0005434757044	AE6A9D	0499 246174	ANATOLIY VASILEV	{"phone": "+70351432195"}
0005434757045	AE6A9D	1845 076731	IRINA FEDOROVA	{"email": "i_fedorova.1975@postgrespro.ru", "phone": "+70493295929"}
0005434757046	1E663E	5788 152350	VALENTINA BELOVA	{"email": "valentinabelova_26031983@postgrespro.ru", "phone": "+70183074606"}
0005434757047	1E663E	0763 803687	GEORGIY NIKOLAEV	{"email": "g_nikolaev_1976@postgrespro.ru", "phone": "+70615657363"}
0005434757048	3E1E4C	0810 659535	ALEKSEY KOZLOV	{"email": "aleksey-kozlov_041966@postgrespro.ru", "phone": "+70088684363"}
0005434757049	01485F	6818 551278	YULIYA VASILEVA	{"email": "y-vasileva.1964@postgrespro.ru", "phone": "+70904713198"}
0005434757050	8F5020	0920 841802	SERGEY DENISOV	{"phone": "+70828954314"}
0005434757051	1111D9	9005 901238	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-valentina-1976@postgrespro.ru", "phone": "+70553706427"}
0005434757052	294823	9219 211553	VIKTOR SERGEEV	{"phone": "+70255555811"}
0005434757053	3810C5	2409 227456	NADEZHDA VASILEVA	{"email": "vasileva_n-25071969@postgrespro.ru", "phone": "+70936184754"}
0005434757054	1F010E	7845 851405	SVETLANA KONDRATEVA	{"phone": "+70851971097"}
0005434757055	AEB965	3545 902836	TAMARA AFANASEVA	{"email": "afanaseva-tamara1977@postgrespro.ru", "phone": "+70636310883"}
0005434757056	AEB965	9398 719778	ANNA KARPOVA	{"email": "a.karpova.24121971@postgrespro.ru", "phone": "+70690377529"}
0005434757057	D1EA79	7630 497659	VLADIMIR ALEKSEEV	{"email": "alekseev-v-051973@postgrespro.ru", "phone": "+70658443969"}
0005434757058	D1EA79	1376 894595	EVGENIY ANTONOV	{"email": "antonov-e_071980@postgrespro.ru", "phone": "+70994915564"}
0005434757059	C9F9AD	2482 976767	MAKSIM OSIPOV	{"phone": "+70210045647"}
0005434757060	3E801F	5155 449108	LYUBOV KOZLOVA	{"phone": "+70486918860"}
0005434757061	3E801F	2143 484063	LYUBOV KUZMINA	{"phone": "+70988411147"}
0005434757062	F3A863	3539 289614	DENIS DAVYDOV	{"phone": "+70785033325"}
0005434757063	F3A863	2952 593376	MAKSIM VASILEV	{"phone": "+70348741533"}
0005434757064	A93442	5332 806222	DANILA KUZMIN	{"email": "kuzmind.25021972@postgrespro.ru", "phone": "+70590695465"}
0005434757065	21A484	1859 365787	NADEZHDA EGOROVA	{"email": "nadezhda-egorova.1971@postgrespro.ru", "phone": "+70700120199"}
0005434757066	12CD56	2250 862941	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr30031967@postgrespro.ru", "phone": "+70325230106"}
0005434757067	12CD56	0505 135030	LIDIYA NIKIFOROVA	{"phone": "+70940231246"}
0005434757068	1CF79A	5647 050930	IRINA MIRONOVA	{"phone": "+70417183217"}
0005434757069	1CF79A	0747 488399	TATYANA RODIONOVA	{"phone": "+70507240673"}
0005434757070	DB0F8F	7260 899216	VLADIMIR MOROZOV	{"email": "v-morozov1974@postgrespro.ru", "phone": "+70847270745"}
0005434757071	DB0F8F	3827 516614	VLADIMIR KRASNOV	{"email": "vladimir_krasnov-121977@postgrespro.ru", "phone": "+70024782635"}
0005434757072	DB0F8F	5628 960121	NADEZHDA CHERNOVA	{"phone": "+70436679028"}
0005434757073	22E5A2	6116 357216	DMITRIY MAKAROV	{"email": "d-makarov_04011979@postgrespro.ru", "phone": "+70041481802"}
0005434757074	1C70C0	9864 485910	KONSTANTIN ALEKSEEV	{"email": "kalekseev17061973@postgrespro.ru", "phone": "+70905499911"}
0005434757075	1814BF	9555 342216	LYUBOV ALEKSANDROVA	{"email": "l-aleksandrova_011979@postgrespro.ru", "phone": "+70550863806"}
0005434757076	1814BF	9363 735887	NATALIYA MEDVEDEVA	{"phone": "+70681433299"}
0005434757077	1814BF	1197 847307	TATYANA SCHERBAKOVA	{"email": "tatyanascherbakova-1976@postgrespro.ru", "phone": "+70292981195"}
0005434757078	8D784B	5809 010406	VALERIYA MIRONOVA	{"email": "v_mironova14041976@postgrespro.ru", "phone": "+70118526682"}
0005434757079	5504C1	2592 203083	IGOR IVANOV	{"email": "ivanovigor1970@postgrespro.ru", "phone": "+70086046619"}
0005434757080	5504C1	8235 397709	KRISTINA IVANOVA	{"phone": "+70812585278"}
0005434757081	45CD73	6722 603357	GALINA STEPANOVA	{"email": "gstepanova101976@postgrespro.ru", "phone": "+70775948449"}
0005434757082	5A59C2	3669 980141	RASHIT SIDOROV	{"email": "sidorov.rashit_071966@postgrespro.ru", "phone": "+70659757877"}
0005434757083	5A59C2	1080 597567	VALENTINA YAKOVLEVA	{"email": "v-yakovleva.1968@postgrespro.ru", "phone": "+70925273909"}
0005434757084	077736	0185 594474	ALEKSEY SOLOVEV	{"email": "aleksey_solovev-111969@postgrespro.ru", "phone": "+70470920424"}
0005434757085	077736	7911 023416	TATYANA LAZAREVA	{"phone": "+70891023758"}
0005434757086	0328DD	0828 970277	EGOR KAZAKOV	{"email": "e-kazakov_1974@postgrespro.ru", "phone": "+70936263394"}
0005434757087	0328DD	0672 561093	NIKOLAY GUSEV	{"phone": "+70537737431"}
0005434757088	2872E1	6755 852071	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_nikolay1969@postgrespro.ru", "phone": "+70882772640"}
0005434757089	2872E1	9996 818107	MAYYA AFANASEVA	{"email": "mafanaseva.17021967@postgrespro.ru", "phone": "+70546754185"}
0005434757090	4B739A	1186 477858	KLAVDIYA ZAKHAROVA	{"phone": "+70800078277"}
0005434757091	04283B	4346 805393	ANDREY KOZLOV	{"phone": "+70343342941"}
0005434757092	04283B	0508 027407	VALENTINA KOLESNIKOVA	{"phone": "+70255358752"}
0005434757093	3EB570	5152 197281	LARISA NIKIFOROVA	{"email": "l.nikiforova021973@postgrespro.ru", "phone": "+70333490164"}
0005434757094	3EB570	5868 562315	ALINA EGOROVA	{"email": "egorova_alina_061970@postgrespro.ru", "phone": "+70391729830"}
0005434757095	B39F02	2896 426227	ALEKSANDR KUZNECOV	{"phone": "+70913240666"}
0005434757096	7EE956	9581 712856	LYUDMILA PETROVA	{"phone": "+70663419629"}
0005434757097	A52F9B	2851 527615	VALERIY SMIRNOV	{"email": "smirnov_valeriy-1962@postgrespro.ru", "phone": "+70074921498"}
0005434757098	8F55E7	4678 300955	LUIZA MAKAROVA	{"phone": "+70404362667"}
0005434757099	7BD6D6	0064 903119	ELENA POPOVA	{"email": "popova.e_15091978@postgrespro.ru", "phone": "+70415942170"}
0005434757100	D934FF	4026 352982	VYACHESLAV TARASOV	{"email": "tarasov_v-1973@postgrespro.ru", "phone": "+70454435454"}
0005434757101	D934FF	2676 854333	MIKHAIL SMIRNOV	{"phone": "+70848604748"}
0005434757102	CFA85D	9975 425277	TATYANA ZOTOVA	{"email": "zotova.t.1978@postgrespro.ru", "phone": "+70725505420"}
0005434757103	44C9FC	3145 604113	VERA MELNIKOVA	{"phone": "+70687076579"}
0005434757104	44C9FC	3525 802002	NATALYA KULIKOVA	{"email": "kulikova.natalya1980@postgrespro.ru", "phone": "+70692614019"}
0005434757105	494EF9	2753 223791	MARIYA ZAYCEVA	{"phone": "+70511569644"}
0005434757106	494EF9	1798 117441	MARINA KULIKOVA	{"phone": "+70716376786"}
0005434757107	99515B	1355 116817	NADEZHDA KISELEVA	{"phone": "+70938303169"}
0005434757108	99515B	8361 512093	IVAN SMIRNOV	{"phone": "+70239336183"}
0005434757109	8CB3B1	3605 116780	VLADIMIR VOLKOV	{"email": "volkovv11051977@postgrespro.ru", "phone": "+70934820306"}
0005434757110	8CB3B1	1302 479084	ANDREY SAVELEV	{"email": "savelev_a-23041965@postgrespro.ru", "phone": "+70648201528"}
0005434757111	FA99ED	4377 704752	NATALYA MAKAROVA	{"phone": "+70635002039"}
0005434757112	248C04	7468 701091	LARISA FROLOVA	{"email": "larisa.frolova_22041984@postgrespro.ru", "phone": "+70509308661"}
0005434757113	4A9157	7693 704700	ANDREY SCHERBAKOV	{"email": "ascherbakov18011971@postgrespro.ru", "phone": "+70370255411"}
0005434757114	4A9157	6787 318309	ANDREY VASILEV	{"email": "vasilev-a091965@postgrespro.ru", "phone": "+70261522078"}
0005434757115	4B0B11	7028 508577	PELAGEYA IVANOVA	{"phone": "+70068145045"}
0005434757116	97668F	6068 366700	DARYA KONDRATEVA	{"phone": "+70519488876"}
0005434757117	F631D5	5860 241905	SERGEY VASILEV	{"phone": "+70694850792"}
0005434757118	F631D5	6481 813283	OLGA LUKYANOVA	{"email": "olga-lukyanova.20071965@postgrespro.ru", "phone": "+70085514385"}
0005434757119	360B8E	6916 514894	VALERIYA TROFIMOVA	{"email": "valeriya_trofimova_041972@postgrespro.ru", "phone": "+70029609145"}
0005434757120	360B8E	3192 042461	NATALYA TARASOVA	{"phone": "+70994469986"}
0005434757121	9C2EAB	0702 811171	VIKTORIYA SOKOLOVA	{"email": "sokolova-v091970@postgrespro.ru", "phone": "+70592831804"}
0005434757122	5E82FC	2762 137592	EKATERINA PAVLOVA	{"phone": "+70691518130"}
0005434757123	5E82FC	8179 124107	IRINA SOKOLOVA	{"phone": "+70528079892"}
0005434757124	235A7B	0287 407960	EKATERINA ZHUKOVA	{"email": "zhukova.e-1977@postgrespro.ru", "phone": "+70058637075"}
0005434757125	16CD94	7376 646756	LYUBOV FEDOROVA	{"phone": "+70477651067"}
0005434757126	3B5466	4875 860307	ZINAIDA ORLOVA	{"email": "orlova-z-021977@postgrespro.ru", "phone": "+70642635465"}
0005434757127	3B5466	9388 371024	NIKOLAY BARANOV	{"email": "baranov-nikolay_1962@postgrespro.ru", "phone": "+70030834041"}
0005434757128	57C33F	0832 439651	ALEKSANDR PAVLOV	{"phone": "+70955557756"}
0005434757129	155712	4821 477165	EKATERINA IVANOVA	{"email": "eivanova.121981@postgrespro.ru", "phone": "+70648795274"}
0005434757130	BB9171	0508 871326	VYACHESLAV DMITRIEV	{"email": "dmitrievvyacheslav.1979@postgrespro.ru", "phone": "+70219536256"}
0005434757131	8F7D21	9860 673636	SVETLANA DAVYDOVA	{"phone": "+70793355148"}
0005434757132	F61108	4796 526082	MIKHAIL NIKITIN	{"email": "mnikitin.091965@postgrespro.ru", "phone": "+70665114506"}
0005434757133	F61108	3663 030441	IVAN NAZAROV	{"email": "nazarov-i.081968@postgrespro.ru", "phone": "+70745781945"}
0005434757134	90E2BB	8717 982468	VLADIMIR KAZAKOV	{"email": "kazakov_v29051969@postgrespro.ru", "phone": "+70504137608"}
0005434757135	90E2BB	3649 008083	MARINA ABRAMOVA	{"email": "abramova_m-121972@postgrespro.ru", "phone": "+70726934026"}
0005434757136	D8019B	0685 764829	GALINA FADEEVA	{"email": "galina-fadeeva.031980@postgrespro.ru", "phone": "+70825041988"}
0005434757137	D8019B	1001 592761	GENNADIY OSIPOV	{"email": "gennadiy-osipov.101974@postgrespro.ru", "phone": "+70229441861"}
0005434757138	47E0AD	4213 209091	IRINA POPOVA	{"email": "popovai.01021968@postgrespro.ru", "phone": "+70144796091"}
0005434757139	9F04E7	7654 355296	DANILA ZAKHAROV	{"email": "zakharov.danila.29011975@postgrespro.ru", "phone": "+70253149210"}
0005434757140	FAA539	6753 631086	ANTONINA LAZAREVA	{"email": "a-lazareva1972@postgrespro.ru", "phone": "+70203567996"}
0005434757141	1EDB86	4068 524403	VLADIMIR ORLOV	{"phone": "+70750015945"}
0005434757142	D6F02F	0809 652604	GULIYA DENISOVA	{"email": "denisova-g-30081966@postgrespro.ru", "phone": "+70361666662"}
0005434757143	D6F02F	6876 578212	NADEZHDA NIKITINA	{"phone": "+70643325267"}
0005434757144	358203	5059 643535	MIKHAIL SOROKIN	{"email": "sorokin.mikhail_03111965@postgrespro.ru", "phone": "+70107896151"}
0005434757145	F5DF2F	5354 508128	ANTON RODIONOV	{"email": "rodionov.anton.14011965@postgrespro.ru", "phone": "+70824617447"}
0005434757146	F5DF2F	6264 404088	IRINA IVANOVA	{"phone": "+70251688223"}
0005434757147	802D14	0289 792943	MAKSIM MAKAROV	{"phone": "+70693055571"}
0005434757148	B0455E	1431 810168	ANDREY SAVELEV	{"email": "a-savelev_23031968@postgrespro.ru", "phone": "+70832733825"}
0005434757149	3F209F	7882 400175	EVGENIY CHERNOV	{"email": "chernov-e021977@postgrespro.ru", "phone": "+70372342662"}
0005434757150	1C2087	5010 809950	ALFIYA VASILEVA	{"email": "vasileva_a.12031961@postgrespro.ru", "phone": "+70172184371"}
0005434757151	34E995	0298 331098	MATVEY MELNIKOV	{"phone": "+70844180575"}
0005434757152	34E995	3549 031699	DMITRIY VLASOV	{"email": "d.vlasov-1976@postgrespro.ru", "phone": "+70538006252"}
0005434757153	9806BA	4763 804909	TAMARA POPOVA	{"email": "tpopova06111970@postgrespro.ru", "phone": "+70843194468"}
0005434757154	E2A4DA	8268 563060	NADEZHDA ERMAKOVA	{"email": "ermakova.n-1960@postgrespro.ru", "phone": "+70209656046"}
0005434757155	FD973B	4728 130436	DARYA STEPANOVA	{"email": "darya_stepanova.031974@postgrespro.ru", "phone": "+70747266471"}
0005434757156	FD973B	9510 098205	VERONIKA VOROBEVA	{"email": "vorobeva.veronika.1966@postgrespro.ru", "phone": "+70109065477"}
0005434757157	77B8B0	7113 005479	ANDREY IVANOV	{"phone": "+70533281563"}
0005434757158	58F895	4188 224667	IRAIDA SOLOVEVA	{"phone": "+70080924489"}
0005434757159	49BD8C	9418 428374	VALENTINA GORBUNOVA	{"email": "v.gorbunova.1971@postgrespro.ru", "phone": "+70429986060"}
0005434757160	2B3D39	5203 334382	OLGA GUSEVA	{"phone": "+70942232741"}
0005434757161	2B3D39	9739 605540	KSENIYA MIKHAYLOVA	{"phone": "+70529848248"}
0005434757162	654DF2	0355 288863	OLEG BELOV	{"phone": "+70143266288"}
0005434757163	72A912	4749 472674	NIKOLAY GAVRILOV	{"phone": "+70956263057"}
0005434757164	35FD07	2243 137424	MILANA NOVIKOVA	{"email": "novikova.m.19121967@postgrespro.ru", "phone": "+70390068498"}
0005434757165	301C67	6197 981763	DARYA KUZNECOVA	{"email": "kuznecova.darya-1977@postgrespro.ru", "phone": "+70738117468"}
0005434757166	301C67	6309 128970	ELENA NOVIKOVA	{"phone": "+70902731569"}
0005434757167	64E2DF	8353 631565	NATALYA BELYAEVA	{"phone": "+70318505859"}
0005434757168	64E2DF	8001 912385	ANATOLIY TIKHONOV	{"phone": "+70676400244"}
0005434757169	59C083	3134 943259	SOFIYA NESTEROVA	{"phone": "+70536930183"}
0005434757170	59C083	1802 458625	VLADIMIR NOVIKOV	{"phone": "+70356209533"}
0005434757171	6DC375	9580 275870	SERGEY MOISEEV	{"email": "smoiseev.04041980@postgrespro.ru", "phone": "+70426854639"}
0005434757172	5A9057	3072 705860	NINA OVCHINNIKOVA	{"phone": "+70191523892"}
0005434757173	0716DD	4633 939186	ALEKSANDR ROMANOV	{"email": "romanov.a.121969@postgrespro.ru", "phone": "+70897431369"}
0005434757174	7F0E0B	3889 040930	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov-1986@postgrespro.ru", "phone": "+70964069374"}
0005434757175	7F0E0B	7355 281422	ELENA IVANOVA	{"phone": "+70817919702"}
0005434757176	305082	0461 699858	MAKSIM KONOVALOV	{"email": "konovalov_maksim-14071971@postgrespro.ru", "phone": "+70865178427"}
0005434757177	305082	4258 499381	NATALYA VOROBEVA	{"phone": "+70251526718"}
0005434757178	81F161	0291 202715	PETR NIKITIN	{"phone": "+70570616871"}
0005434757179	E599EE	4336 253914	OLEG SEMENOV	{"email": "oleg-semenov071974@postgrespro.ru", "phone": "+70393115652"}
0005434757180	6214CC	2721 545649	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov_1976@postgrespro.ru", "phone": "+70708179708"}
0005434757181	609571	7319 752754	SERGEY MIKHAYLOV	{"phone": "+70035114559"}
0005434757182	1EF0FC	6101 150985	YURIY FILIPPOV	{"phone": "+70602893289"}
0005434757183	1EF0FC	9837 132357	YULIYA SOROKINA	{"phone": "+70745691692"}
0005434757184	608F49	6048 775735	SVETLANA BELOVA	{"phone": "+70399458986"}
0005434757185	9BFAC5	9214 586417	DMITRIY FROLOV	{"phone": "+70208759519"}
0005434757186	585AC5	1702 327156	NATALYA RODIONOVA	{"email": "rodionova.natalya-091982@postgrespro.ru", "phone": "+70597097632"}
0005434757187	3977E7	1856 797375	KONSTANTIN PAVLOV	{"phone": "+70075945683"}
0005434757188	7721F4	7444 998349	VALENTINA SOROKINA	{"phone": "+70544012202"}
0005434757189	FFD8A6	9056 895855	ANDREY SEMENOV	{"email": "semenovandrey031964@postgrespro.ru", "phone": "+70719080471"}
0005434757190	FFD8A6	2013 317844	KIRILL MELNIKOV	{"phone": "+70722100998"}
0005434757191	446282	2140 266616	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir_18081956@postgrespro.ru", "phone": "+70347141200"}
0005434757192	851705	3289 432578	NATALYA KOVALEVA	{"email": "n-kovaleva051962@postgrespro.ru", "phone": "+70110041289"}
0005434757193	15DBF5	1650 708462	VLADIMIR RODIONOV	{"email": "vladimirrodionov09081964@postgrespro.ru", "phone": "+70972938113"}
0005434757194	10789F	7481 953708	VERA ZHURAVLEVA	{"phone": "+70217954770"}
0005434757195	06B1DB	0377 477359	VALENTINA KOVALEVA	{"email": "valentinakovaleva071978@postgrespro.ru", "phone": "+70848376765"}
0005434757196	8121EA	9756 888588	NIKOLAY SOROKIN	{"phone": "+70605136565"}
0005434757197	E2A0A1	4638 058468	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a1960@postgrespro.ru", "phone": "+70955664767"}
0005434757198	E936A4	3391 482165	EKATERINA MATVEEVA	{"email": "matveeva.ekaterina.20021966@postgrespro.ru", "phone": "+70833707062"}
0005434757199	2475DE	9656 850709	KONSTANTIN POPOV	{"email": "konstantinpopov05021970@postgrespro.ru", "phone": "+70556043280"}
0005434757200	2475DE	6037 807407	YANA FILATOVA	{"phone": "+70794379515"}
0005434757318	1F2D32	6479 598562	NATALYA ZAYCEVA	{"phone": "+70234786246"}
0005434757201	B5D3CE	6356 100888	IRINA NIKITINA	{"email": "i_nikitina_081978@postgrespro.ru", "phone": "+70117388457"}
0005434757202	808B4C	9193 853055	EKATERINA FEDOROVA	{"email": "e-fedorova.17011971@postgrespro.ru", "phone": "+70432935373"}
0005434757203	361101	7301 106210	ILYA IVANOV	{"email": "ivanov.ilya_1962@postgrespro.ru", "phone": "+70473146891"}
0005434757204	6E64AB	5727 094268	SEMEN GUSEV	{"phone": "+70174931556"}
0005434757205	669038	1117 230865	VLADIMIR KOZLOV	{"email": "kozlov-v-16121982@postgrespro.ru", "phone": "+70449024118"}
0005434757206	C303DC	5284 587993	DMITRIY MELNIKOV	{"phone": "+70301521252"}
0005434757207	C303DC	8001 823549	LYUDMILA KOROLEVA	{"email": "koroleva-l-061971@postgrespro.ru", "phone": "+70923363052"}
0005434757208	C303DC	6108 536523	OLGA IVANOVA	{"phone": "+70063624456"}
0005434757209	5DD934	4545 545730	SOFYA FADEEVA	{"email": "s_fadeeva.1966@postgrespro.ru", "phone": "+70415112318"}
0005434757210	ACF8F3	6139 913256	LYUDMILA KOZLOVA	{"email": "lyudmilakozlova-1973@postgrespro.ru", "phone": "+70917243283"}
0005434757211	3E1186	7483 339475	ELENA KUZNECOVA	{"email": "elenakuznecova_1962@postgrespro.ru", "phone": "+70879558831"}
0005434757212	3E1186	2114 915650	ANASTASIYA ORLOVA	{"phone": "+70120161373"}
0005434757213	71010A	2876 056098	EVGENIY DMITRIEV	{"email": "dmitriev.e_1977@postgrespro.ru", "phone": "+70128739580"}
0005434757214	B5C304	8325 851010	LYUDMILA KRASNOVA	{"phone": "+70559588693"}
0005434757215	647890	5076 058346	OLGA MAKAROVA	{"email": "olga.makarova-06101976@postgrespro.ru", "phone": "+70009024259"}
0005434757216	CB6EB6	4329 603525	KAMILLA SOKOLOVA	{"email": "sokolova-kamilla-1971@postgrespro.ru", "phone": "+70759702315"}
0005434757217	CB6EB6	5351 012296	ELIZAVETA FEDOROVA	{"email": "e.fedorova.1968@postgrespro.ru", "phone": "+70501755796"}
0005434757218	4E230E	3517 321462	MARINA VOROBEVA	{"email": "vorobeva_marina111982@postgrespro.ru", "phone": "+70880776287"}
0005434757219	4E230E	0933 498042	ALLA POPOVA	{"email": "popova_alla-081978@postgrespro.ru", "phone": "+70966004000"}
0005434757331	2CF040	2868 205243	ALBERT ISAEV	{"phone": "+70219588481"}
0005434757220	2D52C9	9521 704676	VLADIMIR MAKAROV	{"email": "makarovvladimir-101965@postgrespro.ru", "phone": "+70356710438"}
0005434757221	2D52C9	1126 100544	GENNADIY FEDOROV	{"email": "gennadiyfedorov_1975@postgrespro.ru", "phone": "+70483166729"}
0005434757222	CE9BE5	4252 417172	YURIY VOLKOV	{"phone": "+70424440351"}
0005434757223	CE9BE5	9860 736923	ALLA ABRAMOVA	{"phone": "+70844003367"}
0005434757224	5CA27F	8020 652233	ALEKSEY ILIN	{"phone": "+70585083107"}
0005434757225	5CA27F	2055 418092	ANNA ANDREEVA	{"email": "anna.andreeva_021966@postgrespro.ru", "phone": "+70999514640"}
0005434757226	F79624	1518 010804	SVETLANA POPOVA	{"email": "svetlana.popova-061969@postgrespro.ru", "phone": "+70073025708"}
0005434757227	DA9A24	5306 483908	ALEKSEY ROMANOV	{"phone": "+70276938109"}
0005434757228	B8A7ED	6272 000848	VYACHESLAV NOVIKOV	{"phone": "+70692246266"}
0005434757229	BABFD1	9700 185216	VITALIY ALEKSEEV	{"phone": "+70134804952"}
0005434757230	1D1022	5403 475046	VALENTINA OSIPOVA	{"email": "osipova.valentina.26031980@postgrespro.ru", "phone": "+70195264757"}
0005434757231	1D1022	7057 728660	ANNA OSIPOVA	{"email": "anna-osipova-01051972@postgrespro.ru", "phone": "+70183861629"}
0005434757232	657BE3	7456 751638	VLADIMIR AFANASEV	{"phone": "+70219580091"}
0005434757233	A315A2	4437 244940	IGOR NIKITIN	{"email": "nikitini1963@postgrespro.ru", "phone": "+70074671213"}
0005434757234	A315A2	8413 670634	VITALIY ALEKSANDROV	{"phone": "+70459640184"}
0005434757235	6E06EE	1068 938206	VITALIY EGOROV	{"phone": "+70321369186"}
0005434757236	6E06EE	9203 049677	LYUDMILA ORLOVA	{"email": "l.orlova_021976@postgrespro.ru", "phone": "+70889595132"}
0005434757237	9DB3CF	2589 205190	YULIYA ZAKHAROVA	{"email": "zakharova-yuliya011971@postgrespro.ru", "phone": "+70271916290"}
0005434757238	9DB3CF	2689 072846	VITALIY KRASNOV	{"email": "krasnov_vitaliy_11121970@postgrespro.ru", "phone": "+70151169336"}
0005434757239	689DF5	3354 726485	VLADIMIR EGOROV	{"email": "vladimiregorov21091971@postgrespro.ru", "phone": "+70168506523"}
0005434757240	689DF5	0662 211071	RAFAIL BELOV	{"email": "belov-r.121966@postgrespro.ru", "phone": "+70680865685"}
0005434757241	DEF7B3	4074 100875	LUIZA NIKITINA	{"email": "nikitina-l.01011974@postgrespro.ru", "phone": "+70083522438"}
0005434757242	DEF7B3	4244 875571	SVETLANA LEBEDEVA	{"email": "lebedeva.svetlana_27071971@postgrespro.ru", "phone": "+70577586837"}
0005434757243	81F04E	2661 047918	VERONIKA KOROLEVA	{"phone": "+70192395492"}
0005434757244	239179	4377 638297	ANTONINA PAVLOVA	{"email": "a.pavlova_031977@postgrespro.ru", "phone": "+70874364626"}
0005434757245	757F14	3168 626745	TATYANA ZHUKOVA	{"phone": "+70562279611"}
0005434757246	757F14	9849 804893	MIKHAIL NOVIKOV	{"phone": "+70363380244"}
0005434757247	615A51	9707 691206	ALEKSANDR IVANOV	{"phone": "+70446233310"}
0005434757248	615A51	0453 356246	NIKITA ALEKSEEV	{"email": "nikita_alekseev1966@postgrespro.ru", "phone": "+70895337658"}
0005434757249	2CBFC9	7073 865477	TATYANA ALEKSANDROVA	{"phone": "+70249482776"}
0005434757250	9F5E0C	6918 896078	IVAN GUSEV	{"email": "gusev.ivan15011967@postgrespro.ru", "phone": "+70269968218"}
0005434757251	604855	2445 782790	ALEKSANDR POPOV	{"phone": "+70518012924"}
0005434757252	604855	9808 577815	GENNADIY PETROV	{"email": "gennadiy_petrov27011968@postgrespro.ru", "phone": "+70616125410"}
0005434757253	A0413C	3078 829700	NIKOLAY SCHERBAKOV	{"email": "scherbakov_nikolay_09011968@postgrespro.ru", "phone": "+70044794914"}
0005434757255	8770F5	7347 472430	ELENA ZAYCEVA	{"email": "zayceva-elena.14021968@postgrespro.ru", "phone": "+70946817083"}
0005434757256	8770F5	5900 674641	TATYANA KUZNECOVA	{"email": "kuznecova_t-051977@postgrespro.ru", "phone": "+70945462287"}
0005434757257	11EB05	4488 025105	DMITRIY SEMENOV	{"email": "d_semenov27051980@postgrespro.ru", "phone": "+70295532366"}
0005434757258	CA1D46	7210 934320	VLADIMIR MOISEEV	{"email": "moiseevv-121981@postgrespro.ru", "phone": "+70263887936"}
0005434757259	EC5648	9976 129301	ARTEM IVANOV	{"email": "ivanovartem-14101971@postgrespro.ru", "phone": "+70106913027"}
0005434757260	E593A2	4676 846310	GALIYA KOZLOVA	{"email": "galiya.kozlova041982@postgrespro.ru", "phone": "+70295100246"}
0005434757261	E593A2	6081 987988	LEONID NAUMOV	{"email": "l.naumov.111971@postgrespro.ru", "phone": "+70329581825"}
0005434757262	DD4973	7733 200526	EVGENIY KONOVALOV	{"email": "konovalov.e_061985@postgrespro.ru", "phone": "+70738209720"}
0005434757263	DD4973	9636 953682	NINA EFREMOVA	{"email": "nefremova_071982@postgrespro.ru", "phone": "+70347719407"}
0005434757264	C24D9B	4043 019194	EVGENIY ROMANOV	{"email": "romanove-061971@postgrespro.ru", "phone": "+70242749713"}
0005434757265	4AE470	7908 827664	ANATOLIY ZAKHAROV	{"email": "zakharova-19041981@postgrespro.ru", "phone": "+70369018040"}
0005434757266	4AE470	3374 830930	OLGA KOZLOVA	{"phone": "+70719108376"}
0005434757267	C69F16	4339 427619	PAVEL NOVIKOV	{"email": "novikov_pavel1968@postgrespro.ru", "phone": "+70827133762"}
0005434757268	4885F3	9009 248361	IRINA KOVALEVA	{"email": "kovalevairina-02091974@postgrespro.ru", "phone": "+70000919913"}
0005434757269	4885F3	8761 810400	IVAN KOROLEV	{"email": "ivankorolev_1966@postgrespro.ru", "phone": "+70372470570"}
0005434757270	4885F3	3942 484769	OLGA NAUMOVA	{"phone": "+70557593740"}
0005434757271	68260C	1952 529090	ALENA ANDREEVA	{"phone": "+70369709689"}
0005434757272	549F01	3907 363225	VALERIYA GUSEVA	{"phone": "+70235865249"}
0005434757273	549F01	7117 355359	NIKOLAY KUZNECOV	{"email": "nkuznecov1975@postgrespro.ru", "phone": "+70962102892"}
0005434757274	B3D9B0	9487 340423	ALEKSANDR ALEKSEEV	{"email": "alekseeva-04081975@postgrespro.ru", "phone": "+70184280564"}
0005434757275	64DBED	5215 353906	VIKTOR SOROKIN	{"email": "viktorsorokin-27091970@postgrespro.ru", "phone": "+70513008181"}
0005434757276	DF551D	0119 417012	YULIYA FADEEVA	{"email": "fadeeva.yuliya-091979@postgrespro.ru", "phone": "+70382013898"}
0005434757277	9BF805	6882 982063	RAFAIL TARASOV	{"email": "tarasovrafail-1967@postgrespro.ru", "phone": "+70465288249"}
0005434757278	4FFE9D	5498 368525	EKATERINA KUDRYASHOVA	{"phone": "+70545128924"}
0005434757279	CFB65D	4578 676159	YULIYA IVANOVA	{"phone": "+70147610756"}
0005434757280	CFB65D	2741 062552	EKATERINA IVANOVA	{"phone": "+70115480692"}
0005434757281	2C2718	6527 095029	ALEKSANDR MOROZOV	{"phone": "+70310852235"}
0005434757282	2C2718	0558 165853	ALEKSEY DAVYDOV	{"email": "davydov_a_1980@postgrespro.ru", "phone": "+70711519416"}
0005434757283	E97B43	0406 113450	ANDREY PETROV	{"phone": "+70160547248"}
0005434757284	9954F2	7873 133576	ALEKSEY ORLOV	{"phone": "+70756544093"}
0005434757285	6AA991	3969 830235	EVGENIY PAVLOV	{"email": "evgeniypavlov09121965@postgrespro.ru", "phone": "+70126101034"}
0005434757286	6AA991	3324 826706	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov081982@postgrespro.ru", "phone": "+70300313349"}
0005434757287	D02DA7	2936 104674	PAVEL KUZMIN	{"phone": "+70704191884"}
0005434757288	D02DA7	7121 489445	MAKSIM SIDOROV	{"email": "m_sidorov1965@postgrespro.ru", "phone": "+70612405231"}
0005434757289	ECBCB6	7715 819685	VERA NOVIKOVA	{"phone": "+70910566783"}
0005434757290	13FAC5	0007 863406	VLADIMIR FROLOV	{"email": "frolovvladimir.06091986@postgrespro.ru", "phone": "+70012794067"}
0005434757291	6E602E	2674 581475	GENNADIY MAKAROV	{"email": "g-makarov091970@postgrespro.ru", "phone": "+70371352822"}
0005434757292	6E602E	1413 477465	DMITRIY MAKAROV	{"email": "makarov.d22061971@postgrespro.ru", "phone": "+70476281196"}
0005434757293	AE275D	0443 240709	SVETLANA PETROVA	{"phone": "+70970673191"}
0005434757294	AE275D	8987 308272	TATYANA KOZLOVA	{"email": "kozlova-t_1968@postgrespro.ru", "phone": "+70468157605"}
0005434757295	010140	0283 603729	ANNA FOMINA	{"email": "fomina-a07011974@postgrespro.ru", "phone": "+70494410494"}
0005434757296	010140	7631 677976	VALENTINA FILIPPOVA	{"email": "v-filippova1957@postgrespro.ru", "phone": "+70256293999"}
0005434757297	906913	1668 359493	IGOR SERGEEV	{"email": "sergeev-i_1965@postgrespro.ru", "phone": "+70233398761"}
0005434757298	736BAD	8666 609823	NATALIYA SOLOVEVA	{"phone": "+70844093106"}
0005434757299	17080D	0400 887257	EVGENIY IVANOV	{"phone": "+70095221631"}
0005434757300	0619A5	0330 709880	NATALYA OSIPOVA	{"phone": "+70455138578"}
0005434757301	0619A5	9981 685839	SERGEY MIKHAYLOV	{"email": "s-mikhaylov-031970@postgrespro.ru", "phone": "+70816720343"}
0005434757302	43FE0B	0077 020875	NADEZHDA MAKAROVA	{"email": "makarova.n-081980@postgrespro.ru", "phone": "+70840516571"}
0005434757303	318F4E	4492 199859	ALEKSANDR KOZLOV	{"phone": "+70208121807"}
0005434757304	318F4E	1928 945738	ELIZAVETA MARTYNOVA	{"phone": "+70935794763"}
0005434757305	6C82B8	0801 640712	ALLA DMITRIEVA	{"email": "dmitrievaalla.1977@postgrespro.ru", "phone": "+70640457891"}
0005434757306	6C82B8	1500 269329	ELIZAVETA KUZNECOVA	{"phone": "+70327538354"}
0005434757307	BA5D26	1619 999615	IGOR PETROV	{"email": "ipetrov_1972@postgrespro.ru", "phone": "+70768987599"}
0005434757308	E219CE	3115 197376	SVETLANA KUDRYASHOVA	{"phone": "+70240834026"}
0005434757309	E219CE	9032 615051	SERGEY ROMANOV	{"email": "romanov-s.111970@postgrespro.ru", "phone": "+70737086502"}
0005434757310	F265F5	8284 580079	ANASTASIYA ROMANOVA	{"phone": "+70101475012"}
0005434757311	F265F5	8484 359884	EVGENIYA KUZNECOVA	{"phone": "+70748982885"}
0005434757312	39087D	6589 365723	MIKHAIL ALEKSEEV	{"phone": "+70952783699"}
0005434757313	146E99	1837 605215	NATALYA KOLESNIKOVA	{"email": "natalya-kolesnikova-041957@postgrespro.ru", "phone": "+70270442236"}
0005434757314	146E99	4379 396183	SERGEY IVANOV	{"phone": "+70856851152"}
0005434757315	AFE212	1669 875892	SVETLANA NIKOLAEVA	{"phone": "+70524909181"}
0005434757316	AFE212	3678 265262	ANNA SMIRNOVA	{"email": "anna_smirnova14101974@postgrespro.ru", "phone": "+70680656525"}
0005434757317	1F2D32	7443 923695	MARINA ROMANOVA	{"email": "m-romanova-1982@postgrespro.ru", "phone": "+70910490801"}
0005434757319	1F2D32	0557 337309	MARGARITA ANDREEVA	{"phone": "+70060042269"}
0005434757320	CFC8E4	6216 353934	EKATERINA NESTEROVA	{"phone": "+70120545788"}
0005434757321	C8CE5E	2479 853570	MIKHAIL STEPANOV	{"phone": "+70100826522"}
0005434757323	601763	7343 446746	IRINA KOZLOVA	{"phone": "+70604645502"}
0005434757324	80BF93	0410 124393	VLADIMIR FOMIN	{"email": "fominv-01071981@postgrespro.ru", "phone": "+70830502636"}
0005434757325	2AC9E8	6881 047289	YURIY SIDOROV	{"email": "yuriy.sidorov_1981@postgrespro.ru", "phone": "+70790997581"}
0005434757326	2AC9E8	2179 405763	LIDIYA KOLESNIKOVA	{"email": "l_kolesnikova_09061968@postgrespro.ru", "phone": "+70361445494"}
0005434757327	A9B12D	7119 302270	YULIYA ALEKSEEVA	{"email": "yalekseeva28031961@postgrespro.ru", "phone": "+70611858702"}
0005434757328	A9B12D	7451 743696	ZINAIDA SOKOLOVA	{"email": "zinaida_sokolova_121975@postgrespro.ru", "phone": "+70525271539"}
0005434757329	BBF8EE	2955 337252	EGOR IVANOV	{"phone": "+70108346719"}
0005434757330	BBF8EE	3707 946128	ALEVTINA MOISEEVA	{"email": "moiseeva_alevtina_03011979@postgrespro.ru", "phone": "+70344264882"}
0005434757332	2CF040	8464 071544	DMITRIY SOROKIN	{"phone": "+70648315817"}
0005434757333	AEF3BB	9980 478997	EKATERINA KUZMINA	{"phone": "+70931891329"}
0005434757334	AEF3BB	7290 763971	SERGEY ZAYCEV	{"phone": "+70701023596"}
0005434757335	AEF3BB	6190 016705	SERGEY KOZLOV	{"email": "kozlov-s-051972@postgrespro.ru", "phone": "+70174514905"}
0005434757336	8403F4	6435 925967	ALEKSANDRA ABRAMOVA	{"email": "a-abramova.10041975@postgrespro.ru", "phone": "+70189159369"}
0005434757337	8403F4	3842 961589	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov_07101977@postgrespro.ru", "phone": "+70348973309"}
0005434757338	D58E79	6083 632407	ALEKSANDR SMIRNOV	{"email": "a_smirnov_121976@postgrespro.ru", "phone": "+70905325279"}
0005434757339	C303D3	4856 062359	IRINA NAZAROVA	{"email": "irina_nazarova-17091980@postgrespro.ru", "phone": "+70140397068"}
0005434757340	2033B6	6399 651865	TATYANA EFREMOVA	{"email": "tefremova_24011961@postgrespro.ru", "phone": "+70955915378"}
0005434757341	D94673	9131 877450	IRINA MIKHAYLOVA	{"phone": "+70096131168"}
0005434757342	D94673	7880 554934	ARTEM ZAKHAROV	{"phone": "+70962498918"}
0005434757343	60E70D	4699 507203	ALEKSEY ZAKHAROV	{"phone": "+70626591669"}
0005434757344	27B6AB	5058 579013	VASILIY FROLOV	{"phone": "+70561863905"}
0005434757345	CD2DB0	6839 096865	IGOR ZHURAVLEV	{"phone": "+70201136144"}
0005434757346	FA3A57	2261 186530	ELENA KUZMINA	{"phone": "+70903709143"}
0005434757347	56E4EC	0824 996882	MIKHAIL POPOV	{"phone": "+70285320387"}
0005434757348	C4C631	1268 350796	NINA ARKHIPOVA	{"phone": "+70250141340"}
0005434757349	BEE105	1847 130833	ELVIRA DAVYDOVA	{"email": "elvira_davydova_101957@postgrespro.ru", "phone": "+70674499718"}
0005434757350	BEE105	8367 505950	ROZA ZAYCEVA	{"email": "zaycevaroza_1967@postgrespro.ru", "phone": "+70491156823"}
0005434757351	281C86	0619 928429	ALEVTINA ALEKSEEVA	{"email": "alekseevaa.071978@postgrespro.ru", "phone": "+70747391671"}
0005434757352	876EA4	6862 692157	DARYA CHERNOVA	{"email": "chernova.darya1971@postgrespro.ru", "phone": "+70857402359"}
0005434757353	876EA4	6754 364174	ROMAN KUZNECOV	{"email": "roman_kuznecov.1979@postgrespro.ru", "phone": "+70309325475"}
0005434757354	B1A49D	2841 384542	YULIYA DENISOVA	{"phone": "+70692472869"}
0005434757355	B1A49D	3812 646226	EVGENIY SIDOROV	{"email": "sidorov-e-031979@postgrespro.ru", "phone": "+70954650840"}
0005434757356	DD6373	9120 825058	SVETLANA ALEKSEEVA	{"phone": "+70698188332"}
0005434757357	AFB071	2212 216504	VALENTINA PETROVA	{"phone": "+70392702825"}
0005434757358	AFB071	7671 514084	VALERIYA NIKOLAEVA	{"email": "nikolaeva_valeriya_09111970@postgrespro.ru", "phone": "+70924327035"}
0005434757359	D88E78	2113 152651	EKATERINA ROMANOVA	{"email": "ekaterinaromanova02031974@postgrespro.ru", "phone": "+70699483688"}
0005434757360	83861A	6223 525073	ARSENIY FOMIN	{"email": "fominarseniy.081971@postgrespro.ru", "phone": "+70759685803"}
0005434757361	74E366	0331 532804	ANDREY BARANOV	{"email": "abaranov28091968@postgrespro.ru", "phone": "+70322881076"}
0005434757362	D8AD29	4569 878891	SVETLANA MIRONOVA	{"phone": "+70254543528"}
0005434757363	7FCD64	0866 615732	MAKSIM SOKOLOV	{"email": "sokolov-m-01121961@postgrespro.ru", "phone": "+70539881214"}
0005434757364	7FCD64	2601 986296	EKATERINA MELNIKOVA	{"email": "e-melnikova_08081977@postgrespro.ru", "phone": "+70495537355"}
0005434757365	6E9177	6210 346461	EVGENIY FROLOV	{"email": "e_frolov_011973@postgrespro.ru", "phone": "+70250856321"}
0005434757366	6E9177	3079 166705	NATALYA SMIRNOVA	{"email": "n_smirnova.14071969@postgrespro.ru", "phone": "+70902690633"}
0005434757367	EFA63C	0636 107209	SERGEY IVANOV	{"phone": "+70481079854"}
0005434757368	045E57	0781 055193	VALERIYA NIKOLAEVA	{"email": "valeriya.nikolaeva.25031974@postgrespro.ru", "phone": "+70718359060"}
0005434757369	5D088B	4892 438031	OLGA ARKHIPOVA	{"email": "o.arkhipova-02061982@postgrespro.ru", "phone": "+70589115323"}
0005434757370	5D088B	2472 958171	EKATERINA TIKHONOVA	{"email": "tikhonovae-1968@postgrespro.ru", "phone": "+70882099789"}
0005434757371	5CE6CA	6034 744514	LYUBOV ROMANOVA	{"phone": "+70259498417"}
0005434757372	FA8DD2	0389 412747	LARISA MOROZOVA	{"phone": "+70345528971"}
0005434757373	63EA3D	0414 752709	SVETLANA SCHERBAKOVA	{"email": "scherbakova-svetlana.071963@postgrespro.ru", "phone": "+70525519696"}
0005434757374	8E64C8	4665 586619	VALERIY ZHURAVLEV	{"phone": "+70031161143"}
0005434757375	9B2AB8	4644 176292	VYACHESLAV YAKOVLEV	{"phone": "+70428550573"}
0005434757376	DECAF2	1807 557779	MARIYA SMIRNOVA	{"phone": "+70110152407"}
0005434757377	DECAF2	4605 618269	IRINA ZAYCEVA	{"phone": "+70988210420"}
0005434757378	E9E832	1159 722091	STEPAN KUZNECOV	{"phone": "+70585200600"}
0005434757379	323FC8	6796 747055	ANTON BONDARENKO	{"phone": "+70573387712"}
0005434757380	6FDC75	7838 486898	NADEZHDA KUZNECOVA	{"email": "kuznecova_nadezhda_1964@postgrespro.ru", "phone": "+70024158025"}
0005434757381	6FDC75	1642 372389	IRINA EFREMOVA	{"phone": "+70252071615"}
0005434757382	9BF08F	5271 784399	SERGEY ORLOV	{"email": "orlovs24101970@postgrespro.ru", "phone": "+70822785776"}
0005434757383	9BF08F	6228 489871	DANILA MARTYNOV	{"email": "d.martynov-121964@postgrespro.ru", "phone": "+70247815529"}
0005434757384	927B26	4082 784338	TATYANA KOVALEVA	{"email": "t_kovaleva1974@postgrespro.ru", "phone": "+70257644930"}
0005434757385	927B26	2843 871300	GALINA ANTONOVA	{"phone": "+70248576522"}
0005434757386	1A21F5	5897 365519	LYUBOV ORLOVA	{"email": "orlova-lyubov.041978@postgrespro.ru", "phone": "+70207768315"}
0005434757387	1A21F5	7624 070112	ALENA SAVELEVA	{"phone": "+70830461785"}
0005434757388	67A49D	6902 953727	EVGENIY FOMIN	{"phone": "+70862675283"}
0005434757389	7C0693	1426 606947	LYUDMILA YAKOVLEVA	{"email": "yakovleval_1957@postgrespro.ru", "phone": "+70122930371"}
0005434757390	DBD39F	9114 015538	VALERIY MIKHAYLOV	{"email": "valeriymikhaylov26071978@postgrespro.ru", "phone": "+70496356009"}
0005434757391	DBD39F	2114 062650	ANNA SOKOLOVA	{"phone": "+70646521192"}
0005434757392	DBD39F	3026 001395	NIKOLAY KUZNECOV	{"email": "n_kuznecov_10081978@postgrespro.ru", "phone": "+70404785647"}
0005434757393	73BB8D	9527 634193	NIKITA ANDREEV	{"phone": "+70578588610"}
0005434757394	A1D062	2693 891938	ILYA KAZAKOV	{"email": "kazakov-ilya-10041965@postgrespro.ru", "phone": "+70901318107"}
0005434757395	A1D062	1712 235316	GALINA SOKOLOVA	{"phone": "+70373648960"}
0005434757396	4A994E	5977 492863	VALENTINA SOLOVEVA	{"phone": "+70566550459"}
0005434757397	C032B0	5963 522455	OKSANA TARASOVA	{"email": "o.tarasova_1974@postgrespro.ru", "phone": "+70050672748"}
0005434757398	08B5FC	6069 842571	OLGA ZAKHAROVA	{"email": "olga-zakharova-1974@postgrespro.ru", "phone": "+70599819272"}
0005434757399	0C3F16	3940 722157	ALEKSEY ILIN	{"email": "ilinaleksey.14021971@postgrespro.ru", "phone": "+70127717519"}
0005434757400	7B87BC	5098 341805	MAKSIM ZAYCEV	{"phone": "+70739589012"}
0005434757401	3E83F9	2607 132165	DMITRIY ALEKSEEV	{"email": "dmitriy-alekseev.1971@postgrespro.ru", "phone": "+70802551033"}
0005434757402	3E83F9	7270 795366	ALEKSANDR MIRONOV	{"phone": "+70268383240"}
0005434757403	34C71D	4677 233159	YURIY MIRONOV	{"phone": "+70517292779"}
0005434757404	34C71D	6268 171103	FATIMA GERASIMOVA	{"phone": "+70691048820"}
0005434757405	D30B25	7211 138768	TATYANA NIKIFOROVA	{"email": "tnikiforova.05101970@postgrespro.ru", "phone": "+70835542763"}
0005434757406	D30B25	9265 545956	DENIS KUZNECOV	{"phone": "+70244305278"}
0005434757407	0C43C9	3516 455969	ALBINA KISELEVA	{"email": "kiseleva_albina_071961@postgrespro.ru", "phone": "+70421075292"}
0005434757408	5F88F5	4782 325270	SERGEY NOVIKOV	{"phone": "+70772748821"}
0005434757409	B3C4B1	0316 877730	VLADIMIR NIKITIN	{"email": "vnikitin_091951@postgrespro.ru", "phone": "+70771081398"}
0005434757410	CF99F3	0008 571041	ZOYA KONOVALOVA	{"phone": "+70036888989"}
0005434757411	CE3277	1736 911374	RAFAEL SMIRNOV	{"email": "r_smirnov021967@postgrespro.ru", "phone": "+70215405584"}
0005434757412	968D36	0187 759322	VIKTORIYA IVANOVA	{"email": "ivanova-viktoriya-02111967@postgrespro.ru", "phone": "+70279528485"}
0005434757413	DB4F94	5174 567625	DANILA IVANOV	{"phone": "+70392979543"}
0005434757414	9645E1	4720 828373	ROMAN ISAEV	{"phone": "+70450277870"}
0005434757415	9645E1	6615 995744	NINA VASILEVA	{"email": "vasileva.nina_091967@postgrespro.ru", "phone": "+70248518643"}
0005434757416	F012BA	6627 229762	SERGEY CHERNOV	{"email": "s.chernov.1965@postgrespro.ru", "phone": "+70067607567"}
0005434757417	F012BA	3679 698861	ILDUS DAVYDOV	{"email": "davydov.ildus_111980@postgrespro.ru", "phone": "+70456707346"}
0005434757418	68E593	2967 887306	VYACHESLAV ALEKSEEV	{"email": "alekseev_v-1989@postgrespro.ru", "phone": "+70223604132"}
0005434757419	F7400C	3716 370769	LEV MOROZOV	{"phone": "+70004898720"}
0005434757420	CCFF1E	1050 768818	SVETLANA MAKAROVA	{"phone": "+70402216700"}
0005434757421	CCFF1E	0854 264975	LYUDMILA SERGEEVA	{"email": "sergeeva-l.30031974@postgrespro.ru", "phone": "+70570781432"}
0005434757422	CCFF1E	0160 038688	ALLA VASILEVA	{"phone": "+70921155682"}
0005434757423	59870F	5749 567520	FATYMA LEBEDEVA	{"phone": "+70549939224"}
0005434757424	052047	3716 062406	IGOR OSIPOV	{"phone": "+70354331207"}
0005434757425	AF76E8	0866 157511	VALENTINA YUDINA	{"phone": "+70357401214"}
0005434757426	AF76E8	2892 196196	VLADIMIR VOLKOV	{"email": "v.volkov-11021982@postgrespro.ru", "phone": "+70633245234"}
0005434757427	87265F	0354 637168	MARINA POPOVA	{"phone": "+70391847081"}
0005434757428	DBB809	5557 777778	OLEG KUZNECOV	{"phone": "+70450531123"}
0005434757429	F20BD7	4850 815715	ANDREY FOMIN	{"phone": "+70607798489"}
0005434757430	08493C	5672 021122	MARAT POPOV	{"email": "m.popov_031969@postgrespro.ru", "phone": "+70850587265"}
0005434757431	8FDC8F	6747 474128	ALEKSANDR BARANOV	{"email": "baranovaleksandr1959@postgrespro.ru", "phone": "+70287089734"}
0005434757432	8FDC8F	0383 279057	DMITRIY IVANOV	{"phone": "+70714844099"}
0005434757433	648E44	2407 364105	NATALYA PETROVA	{"email": "n.petrova-1963@postgrespro.ru", "phone": "+70403833338"}
0005434757434	648E44	8551 658949	EKATERINA KUZNECOVA	{"email": "e.kuznecova021957@postgrespro.ru", "phone": "+70863443555"}
0005434757435	648E44	9702 613693	ALEKSEY NIKITIN	{"email": "nikitina_1962@postgrespro.ru", "phone": "+70299308657"}
0005434757436	576CAE	3465 789544	IRINA ROMANOVA	{"phone": "+70815063787"}
0005434757437	576CAE	4168 246266	LYUBOV DANILOVA	{"email": "lyubov_danilova1973@postgrespro.ru", "phone": "+70331487476"}
0005434757438	576CAE	6430 861909	NATALYA IVANOVA	{"email": "natalya_ivanova-17041969@postgrespro.ru", "phone": "+70172525507"}
0005434757439	AF118A	7645 827301	NADEZHDA MOROZOVA	{"phone": "+70282803697"}
0005434757440	AF118A	9922 757821	ANDREY TIKHONOV	{"email": "tikhonov.andrey-081973@postgrespro.ru", "phone": "+70898148785"}
0005434757441	FF93F1	9567 427507	NIKOLAY POPOV	{"email": "popov_nikolay1971@postgrespro.ru", "phone": "+70664930815"}
0005434757442	FF93F1	8729 138430	GALINA FROLOVA	{"phone": "+70175081345"}
0005434757443	405E8A	8413 149563	OLGA LEBEDEVA	{"email": "lebedeva.o011975@postgrespro.ru", "phone": "+70242215288"}
0005434757444	793299	8659 976477	MARGARITA FILATOVA	{"phone": "+70569199348"}
0005434757445	793299	3174 379035	NINA VLASOVA	{"email": "ninavlasova1980@postgrespro.ru", "phone": "+70299755061"}
0005434757446	BDFF9D	5638 882757	VYACHESLAV ZAKHAROV	{"phone": "+70831622511"}
0005434757447	17B425	5700 793743	LYUDMILA GORBUNOVA	{"phone": "+70731538741"}
0005434757448	17B425	0945 457993	VLADISLAV MELNIKOV	{"phone": "+70417071652"}
0005434757449	60CF05	1815 123603	YAKOV MAKSIMOV	{"phone": "+70855936536"}
0005434757450	56D668	8425 619052	RAMIL MOISEEV	{"phone": "+70996178283"}
0005434757451	B10B45	0945 437793	ANATOLIY FROLOV	{"email": "anatoliy_frolov.26081956@postgrespro.ru", "phone": "+70355004134"}
0005434757452	B10B45	4636 390005	LIDIYA TIMOFEEVA	{"phone": "+70549344977"}
0005434757453	B7B7C0	2226 724551	MAKSIM KUDRYASHOV	{"phone": "+70072896311"}
0005434757454	B7B7C0	1599 391456	TATYANA YAKOVLEVA	{"email": "yakovlevatatyana031974@postgrespro.ru", "phone": "+70564335663"}
0005434757455	B7B7C0	4188 342918	DENIS TIMOFEEV	{"phone": "+70747623563"}
0005434757456	FE3E0F	2237 298333	IRINA LUKYANOVA	{"email": "lukyanova-i-23111969@postgrespro.ru", "phone": "+70105048403"}
0005434757457	070E6D	4719 357940	KIRILL ZAKHAROV	{"phone": "+70599194853"}
0005434757458	3F81FC	8616 456030	ALEKSANDR NAZAROV	{"phone": "+70043476107"}
0005434757459	A94768	8732 972534	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-121960@postgrespro.ru", "phone": "+70718487893"}
0005434757460	4AFFAB	3371 243824	ANDREY ANTONOV	{"phone": "+70805012148"}
0005434757461	266DB0	3374 421589	IRINA ZOTOVA	{"phone": "+70561761066"}
0005434757462	0070DF	8571 809417	ROMAN ZHUKOV	{"phone": "+70327878897"}
0005434757463	0070DF	2800 879019	ELENA VOLKOVA	{"email": "elena-volkova-1972@postgrespro.ru", "phone": "+70546983214"}
0005434757464	6EA9FC	9841 076672	EVGENIY EGOROV	{"email": "e.egorov28021975@postgrespro.ru", "phone": "+70965322222"}
0005434757465	384DED	5448 671036	IRINA STEPANOVA	{"email": "stepanovairina.061973@postgrespro.ru", "phone": "+70729388468"}
0005434757466	802DFB	8512 157334	OLGA GAVRILOVA	{"email": "olgagavrilova13051976@postgrespro.ru", "phone": "+70177941020"}
0005434757467	8D4083	8605 258720	TATYANA POPOVA	{"phone": "+70716964605"}
0005434757468	046279	4862 332365	OKSANA KUZMINA	{"email": "kuzmina-o_111971@postgrespro.ru", "phone": "+70962430570"}
0005434757469	73E715	4475 936420	VIKTOR CHERNOV	{"email": "chernov-v101968@postgrespro.ru", "phone": "+70015642345"}
0005434757470	73E715	8919 978968	DMITRIY SERGEEV	{"email": "sergeev_dmitriy121976@postgrespro.ru", "phone": "+70901082323"}
0005434757471	8C29CE	7331 055565	SVETLANA BOGDANOVA	{"phone": "+70607054172"}
0005434757472	0B8A8C	0742 868271	SERGEY NAZAROV	{"email": "nazarov.sergey-121969@postgrespro.ru", "phone": "+70305278764"}
0005434757473	EF4451	2954 039603	OLGA SOKOLOVA	{"email": "sokolova.o-08031980@postgrespro.ru", "phone": "+70879719513"}
0005434757474	621DCA	7231 908192	VLADIMIR VASILEV	{"phone": "+70478583573"}
0005434757475	621DCA	4232 407378	GALINA ZAYCEVA	{"email": "zayceva_g_20101981@postgrespro.ru", "phone": "+70808591088"}
0005434757476	B4D24E	9920 374928	MARINA ILINA	{"email": "milina-1970@postgrespro.ru", "phone": "+70426580560"}
0005434757477	B4D24E	5536 081093	EKATERINA ROMANOVA	{"email": "romanova-ekaterina.041978@postgrespro.ru", "phone": "+70652807033"}
0005434757478	DF2351	5792 500056	NADEZHDA POPOVA	{"phone": "+70508689230"}
0005434757479	33BCB9	1414 665268	SERGEY BORISOV	{"phone": "+70979301665"}
0005434757480	4EC7DE	5553 596901	VALENTIN SOROKIN	{"email": "sorokin.valentin1973@postgrespro.ru", "phone": "+70145011358"}
0005434757481	D81E59	9943 931368	PETR SMIRNOV	{"email": "p_smirnov_1967@postgrespro.ru", "phone": "+70012432069"}
0005434757482	64B26A	8326 844137	PAVEL FILIPPOV	{"email": "pavel.filippov08031969@postgrespro.ru", "phone": "+70284275341"}
0005434757483	52FC95	7635 383781	VIKTOR SIDOROV	{"phone": "+70385321225"}
0005434757484	52FC95	0618 719151	ELENA ZAKHAROVA	{"phone": "+70934965480"}
0005434757485	52FC95	8466 914203	LARISA PAVLOVA	{"email": "pavlova.larisa1982@postgrespro.ru", "phone": "+70236542553"}
0005434757486	FCFE14	5159 285300	TAMARA FEDOROVA	{"phone": "+70446439737"}
0005434757487	3F8162	9663 155928	NATALYA MOROZOVA	{"phone": "+70309974039"}
0005434757488	3F8162	5455 189980	VALENTINA POPOVA	{"phone": "+70902300906"}
0005434757489	333511	9273 163028	TATYANA MEDVEDEVA	{"phone": "+70644130411"}
0005434757490	9F7624	9641 752156	NATALYA IVANOVA	{"phone": "+70781040474"}
0005434757491	A1A0DC	3427 723529	MARINA POTAPOVA	{"phone": "+70172416072"}
0005434757492	698274	6698 647171	MARIYA SCHERBAKOVA	{"phone": "+70712449965"}
0005434757493	745D86	0555 514403	IVAN KUZNECOV	{"email": "i-kuznecov_1973@postgrespro.ru", "phone": "+70551995412"}
0005434757494	745D86	2060 694891	PETR IVANOV	{"phone": "+70028705779"}
0005434757495	8B7DE3	6763 676107	ILYA CHERNOV	{"email": "i_chernov.29071962@postgrespro.ru", "phone": "+70627478707"}
0005434757496	8B7DE3	5323 573518	VERA BOGDANOVA	{"email": "v-bogdanova_1963@postgrespro.ru", "phone": "+70800067366"}
0005434757497	AF26B9	2588 509688	ANTONINA TARASOVA	{"phone": "+70838354443"}
0005434757498	AF26B9	4796 398608	YURIY BARANOV	{"phone": "+70074998947"}
0005434757499	A7A065	3760 984651	ROMAN KOZLOV	{"phone": "+70956747097"}
0005434757500	BD231B	5807 457396	AYRAT NIKOLAEV	{"email": "nikolaev-a_031970@postgrespro.ru", "phone": "+70198592988"}
0005434757501	11B55E	2709 560014	GEORGIY KARPOV	{"email": "karpov.g.051975@postgrespro.ru", "phone": "+70767255739"}
0005434757502	5BF544	2991 348090	NATALYA ZAKHAROVA	{"email": "zakharova-n_1969@postgrespro.ru", "phone": "+70973577897"}
0005434757503	CF6BA7	0355 160811	VLADIMIR CHERNOV	{"email": "vladimir_chernov_081965@postgrespro.ru", "phone": "+70250517685"}
0005434757504	267F1D	2200 482235	VALENTINA PAVLOVA	{"email": "v_pavlova-10071968@postgrespro.ru", "phone": "+70187173499"}
0005434757505	ABFD3F	2622 732019	ELENA MOISEEVA	{"phone": "+70691542125"}
0005434757506	4DE3E0	4229 096955	ELENA FOMINA	{"phone": "+70755054526"}
0005434757507	17DDC5	5222 946744	VIKTOR SEMENOV	{"phone": "+70021752776"}
0005434757508	17DDC5	6777 688269	ANNA KUZNECOVA	{"phone": "+70377933005"}
0005434757509	17DDC5	7529 512838	DMITRIY EGOROV	{"email": "d_egorov.1975@postgrespro.ru", "phone": "+70008783292"}
0005434757510	90FB13	6371 224053	MIKHAIL ABRAMOV	{"phone": "+70433861343"}
0005434757511	90FB13	9706 047941	ALBINA GORBUNOVA	{"phone": "+70325724713"}
0005434757512	AE6614	2565 852524	ANNA CHERNOVA	{"phone": "+70682948856"}
0005434757513	AE6614	2924 769936	OLGA IVANOVA	{"phone": "+70399341541"}
0005434757514	EBF516	9256 388879	TATYANA KOLESNIKOVA	{"email": "kolesnikova.t_29111963@postgrespro.ru", "phone": "+70331068067"}
0005434757515	479F83	1528 951074	VALENTINA EGOROVA	{"phone": "+70782260157"}
0005434757516	479F83	7119 466703	TATYANA VOLKOVA	{"phone": "+70302757205"}
0005434757517	7820A6	5694 169118	ALEKSANDR ZAKHAROV	{"phone": "+70958201745"}
0005434757518	9BA25A	9547 582455	ALENA TROFIMOVA	{"email": "trofimova_alena_16061967@postgrespro.ru", "phone": "+70483022746"}
0005434757519	115B76	5698 485904	IGOR MATVEEV	{"phone": "+70481408377"}
0005434757520	115B76	8289 713990	ALEKSANDR NIKITIN	{"phone": "+70452992107"}
0005434757521	A3BDF1	3955 007398	VLADIMIR KOZLOV	{"email": "kozlov-v.101971@postgrespro.ru", "phone": "+70170833344"}
0005434757522	ACD085	4354 677676	OLGA KOROLEVA	{"phone": "+70289964426"}
0005434757523	ACD085	4545 772327	ANDREY SOROKIN	{"phone": "+70926417322"}
0005434757524	8A623B	7006 854327	VADIM IVANOV	{"phone": "+70557547586"}
0005434757525	E07B0A	3137 650900	DMITRIY FROLOV	{"email": "d-frolov-26091969@postgrespro.ru", "phone": "+70640529056"}
0005434757526	87A8CB	0038 271375	LIDIYA VASILEVA	{"email": "l.vasileva.17011976@postgrespro.ru", "phone": "+70302823235"}
0005434757527	87A8CB	5344 886645	NIKOLAY PETROV	{"email": "n.petrov_041973@postgrespro.ru", "phone": "+70909952772"}
0005434757528	DD8FF5	8073 548029	LYUDMILA BELOVA	{"phone": "+70715480259"}
0005434757529	DD8FF5	9664 012589	RAFAIL GORBUNOV	{"email": "r-gorbunov071975@postgrespro.ru", "phone": "+70128717216"}
0005434757530	D72DF8	4788 242335	MARGARITA KUZNECOVA	{"phone": "+70705382499"}
0005434757531	AD3712	2880 367755	OLGA AFANASEVA	{"email": "afanaseva-olga1971@postgrespro.ru", "phone": "+70357176080"}
0005434757532	AD3712	8543 910730	TAISIYA NAUMOVA	{"phone": "+70370204568"}
0005434757533	AD3712	9936 085905	KONSTANTIN KUZNECOV	{"email": "kuznecovk.021978@postgrespro.ru", "phone": "+70859754231"}
0005434757534	AD3712	7248 255021	ILYA MOISEEV	{"email": "imoiseev_111973@postgrespro.ru", "phone": "+70990215820"}
0005434757535	2FD7EB	0989 766888	NIKOLAY NAUMOV	{"phone": "+70946487265"}
0005434757536	A2AC12	5412 470476	MAKSIM TIKHONOV	{"phone": "+70420724969"}
0005434757537	1E9CF7	7953 485503	IRINA MALYSHEVA	{"phone": "+70947979090"}
0005434757538	3BA981	4873 690329	ANDREY VASILEV	{"phone": "+70595348596"}
0005434757539	BA5A49	6517 490686	RASHIT ROMANOV	{"phone": "+70944389870"}
0005434757540	AABF2C	5215 968286	PRASKOVYA FROLOVA	{"email": "p.frolova-061971@postgrespro.ru", "phone": "+70179835342"}
0005434757541	301C1C	0369 620854	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr23061965@postgrespro.ru", "phone": "+70014300172"}
0005434757542	489BE0	0042 359763	ELENA KONDRATEVA	{"phone": "+70830748840"}
0005434757543	9D8174	9474 518824	VADIM ZAKHAROV	{"email": "vadim_zakharov17061975@postgrespro.ru", "phone": "+70806171526"}
0005434757544	76682C	1360 684302	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr_1964@postgrespro.ru", "phone": "+70687368980"}
0005434757545	76682C	3588 808471	SERGEY IVANOV	{"phone": "+70135442531"}
0005434757546	CFCA70	8322 060760	MARIYA NAUMOVA	{"phone": "+70967152825"}
0005434757547	A2A352	6702 815153	IGOR MATVEEV	{"email": "matveev_igor-21121969@postgrespro.ru", "phone": "+70874572462"}
0005434757548	795E25	6453 099386	OLGA MALYSHEVA	{"email": "olga.malysheva-18091970@postgrespro.ru", "phone": "+70950461885"}
0005434757549	795E25	2312 469114	VALENTINA NIKIFOROVA	{"phone": "+70928632678"}
0005434757550	082DA0	5792 165209	TATYANA NOVIKOVA	{"phone": "+70110345395"}
0005434757551	656D5A	7813 255022	GALINA RODIONOVA	{"phone": "+70295316943"}
0005434757552	12AEA0	5231 946580	ALINA RYABOVA	{"phone": "+70133649874"}
0005434757553	E3F012	5308 468274	VYACHESLAV MIRONOV	{"email": "mironov_vyacheslav_1974@postgrespro.ru", "phone": "+70788743309"}
0005434757554	967C38	0149 452002	SERGEY STEPANOV	{"email": "s-stepanov-121969@postgrespro.ru", "phone": "+70920060441"}
0005434757555	F7F5C9	7549 124043	SERGEY EGOROV	{"phone": "+70310048927"}
0005434757556	0BFC72	6476 287190	OKSANA VOLKOVA	{"phone": "+70631124271"}
0005434757557	62E62A	6566 027101	MARIYA ANISIMOVA	{"email": "mariya.anisimova.1958@postgrespro.ru", "phone": "+70618055527"}
0005434757558	62E62A	7498 215967	OLGA TARASOVA	{"email": "o_tarasova.19121973@postgrespro.ru", "phone": "+70439832889"}
0005434757559	97BC4A	0366 299594	LIDIYA EFREMOVA	{"email": "efremova.l02071973@postgrespro.ru", "phone": "+70929690042"}
0005434757560	97BC4A	5182 319271	ZINAIDA BELOVA	{"phone": "+70565994067"}
0005434757561	97BC4A	4821 319905	TIMOFEY BARANOV	{"phone": "+70192563104"}
0005434757562	128A36	3144 284365	EVGENIY NOVIKOV	{"phone": "+70508809037"}
0005434757563	2982DC	9541 116849	ANASTASIYA KOROLEVA	{"phone": "+70599748051"}
0005434757564	1EA6BF	5583 042950	NADEZHDA GERASIMOVA	{"email": "n.gerasimova1972@postgrespro.ru", "phone": "+70566447664"}
0005434757565	1EA6BF	8305 002245	MARINA GORBUNOVA	{"phone": "+70643986679"}
0005434757566	5F797C	2301 178902	VLADISLAV SMIRNOV	{"email": "vladislavsmirnov19101979@postgrespro.ru", "phone": "+70138190965"}
0005434757567	59B2EE	2948 453997	SERGEY STEPANOV	{"phone": "+70052619179"}
0005434757568	578269	9352 572438	DENIS SERGEEV	{"email": "dsergeev25071964@postgrespro.ru", "phone": "+70999792604"}
0005434757569	01596C	4084 097716	VLADIMIR KISELEV	{"phone": "+70375139036"}
0005434757570	39CCA6	0583 602941	MAKSIM NIKITIN	{"email": "m.nikitin.09021977@postgrespro.ru", "phone": "+70706475636"}
0005434757571	39CCA6	1975 369218	LEONTIY KUDRYASHOV	{"email": "kudryashovl-1975@postgrespro.ru", "phone": "+70767629652"}
0005434757572	FA56E5	8758 662707	ALEKSANDR GRIGOREV	{"phone": "+70606991457"}
0005434757573	8622FB	0115 956167	NIKOLAY VASILEV	{"phone": "+70076909151"}
0005434757574	8BF4A2	4480 684593	TATYANA NOVIKOVA	{"email": "t-novikova.011965@postgrespro.ru", "phone": "+70840081666"}
0005434757575	8BF4A2	8640 081051	ANATOLIY GERASIMOV	{"phone": "+70232873335"}
0005434757576	1A71C4	3198 136907	DARYA ZOTOVA	{"email": "zotova_darya.14091972@postgrespro.ru", "phone": "+70047127808"}
0005434757577	1A71C4	7040 578966	NINA ISAEVA	{"email": "isaeva-n31011976@postgrespro.ru", "phone": "+70625545694"}
0005434757578	652E95	0878 985309	STANISLAV KUZNECOV	{"email": "skuznecov-24071970@postgrespro.ru", "phone": "+70294154340"}
0005434757579	F17A7D	2796 737319	VALENTINA BORISOVA	{"email": "valentina.borisova-021970@postgrespro.ru", "phone": "+70794528548"}
0005434757580	4D9076	0154 605165	EKATERINA ABRAMOVA	{"phone": "+70855653068"}
0005434757581	D33591	2816 343274	MAYYA EGOROVA	{"email": "m-egorova.081977@postgrespro.ru", "phone": "+70068279815"}
0005434757582	D6F405	6513 967057	LYUDMILA GERASIMOVA	{"email": "gerasimova-l-1971@postgrespro.ru", "phone": "+70479566022"}
0005434757583	29F866	6439 612769	NIKOLAY PAVLOV	{"email": "npavlov-1960@postgrespro.ru", "phone": "+70337409204"}
0005434757584	83EB05	7986 779425	MARIYA EGOROVA	{"email": "egorova.mariya.1962@postgrespro.ru", "phone": "+70322523915"}
0005434757585	693A5C	4842 618284	SERGEY MAKAROV	{"phone": "+70534801574"}
0005434757586	67BE74	4418 615945	NATALYA BELYAEVA	{"email": "belyaeva_natalya.07121977@postgrespro.ru", "phone": "+70240815043"}
0005434757587	4EB78C	2663 428572	ANATOLIY VOLKOV	{"email": "a_volkov-07011969@postgrespro.ru", "phone": "+70634252455"}
0005434757588	847084	2314 251094	SERGEY MEDVEDEV	{"email": "s_medvedev-051973@postgrespro.ru", "phone": "+70801091053"}
0005434757589	75DEFD	8496 276666	ELENA GORBUNOVA	{"email": "e-gorbunova-1970@postgrespro.ru", "phone": "+70015365739"}
0005434757590	FAAA95	2899 977074	LYUDMILA NIKIFOROVA	{"email": "nikiforova.lyudmila_081975@postgrespro.ru", "phone": "+70257824393"}
0005434757591	E8A7BC	9824 425239	ALEKSANDR MOROZOV	{"phone": "+70468386392"}
0005434757592	A1BDAE	0913 229090	MIKHAIL MAKAROV	{"email": "mikhail-makarov1969@postgrespro.ru", "phone": "+70088345537"}
0005434757593	A1BDAE	3410 044765	ANASTASIYA MIKHAYLOVA	{"phone": "+70129741160"}
0005434757594	5C2DAA	8597 144947	VLADIMIR YAKOVLEV	{"phone": "+70285539250"}
0005434757595	5C2DAA	7866 808489	FEDOR MIRONOV	{"email": "fedor.mironov.1977@postgrespro.ru", "phone": "+70352479202"}
0005434757596	F1C972	0122 510362	MARIYA ALEKSANDROVA	{"email": "mariya.aleksandrova.06021981@postgrespro.ru", "phone": "+70085083570"}
0005434757597	F1C972	2342 504608	ANNA GORBUNOVA	{"phone": "+70393258747"}
0005434757598	F4BDE6	9814 076200	ELIZAVETA NAZAROVA	{"phone": "+70022436835"}
0005434757599	F4BDE6	0407 058252	DARYA STEPANOVA	{"phone": "+70128207157"}
0005434757600	D418E0	1465 443187	EVGENIY STEPANOV	{"email": "evgeniy_stepanov_041971@postgrespro.ru", "phone": "+70097625218"}
0005434757601	D418E0	5921 994366	ALEKSEY MELNIKOV	{"phone": "+70173855285"}
0005434757602	A6CF47	6521 423060	SERGEY ZHURAVLEV	{"email": "sergey_zhuravlev_1981@postgrespro.ru", "phone": "+70786517319"}
0005434757603	A6CF47	8514 034015	KLAVDIYA KUZMINA	{"phone": "+70116812287"}
0005434757604	A6CF47	2234 739459	ALEKSANDR GERASIMOV	{"email": "agerasimov1967@postgrespro.ru", "phone": "+70205644939"}
0005434757605	16CD95	1260 693868	LEV ANDREEV	{"email": "landreev061974@postgrespro.ru", "phone": "+70256846650"}
0005434757606	7F9D31	4893 475874	IRINA POPOVA	{"email": "popovairina.1972@postgrespro.ru", "phone": "+70258782365"}
0005434757607	7F9D31	5998 095353	MARIYA POPOVA	{"email": "popova_m.051979@postgrespro.ru", "phone": "+70968510224"}
0005434757608	F041FA	3405 046876	ARTEM BELOV	{"email": "belova27081974@postgrespro.ru", "phone": "+70554993239"}
0005434757609	FB654C	5232 723414	ELENA BOGDANOVA	{"email": "ebogdanova_1970@postgrespro.ru", "phone": "+70818547816"}
0005434757610	CAC7DE	2393 373251	SVETLANA MAKSIMOVA	{"email": "maksimova-s-081974@postgrespro.ru", "phone": "+70276957469"}
0005434757611	61F26F	3208 642800	SERGEY MELNIKOV	{"phone": "+70116425131"}
0005434757612	CD152A	7946 177659	ALEKSANDR ILIN	{"phone": "+70855732155"}
0005434757613	F80188	3793 298199	YURIY ZAKHAROV	{"email": "zakharov_y.031970@postgrespro.ru", "phone": "+70693351733"}
0005434757614	EDC3A1	7795 424364	YULIYA KAZAKOVA	{"email": "kazakova.y051963@postgrespro.ru", "phone": "+70541809520"}
0005434757615	771DB2	9216 001688	VLADIMIR FEDOROV	{"email": "vladimir_fedorov-011979@postgrespro.ru", "phone": "+70941225607"}
0005434757616	9D49DA	3124 313188	IRINA MAKAROVA	{"email": "makarovairina_071980@postgrespro.ru", "phone": "+70224530590"}
0005434757617	9D49DA	8387 396447	GENNADIY VOLKOV	{"phone": "+70471664502"}
0005434757618	F8C6C9	5431 472443	KONSTANTIN SAVELEV	{"email": "k.savelev.081966@postgrespro.ru", "phone": "+70424043357"}
0005434757619	AF4B72	3699 757966	ANDREY DMITRIEV	{"phone": "+70901606203"}
0005434757620	CBC976	6592 479159	ALEKSANDR FROLOV	{"email": "frolov-aleksandr.1974@postgrespro.ru", "phone": "+70715907317"}
0005434757621	5F60F0	9151 073983	VALENTINA CHERNOVA	{"email": "chernova_v011966@postgrespro.ru", "phone": "+70088441811"}
0005434757622	06B3BC	2835 259775	YURIY KUZMIN	{"phone": "+70601970031"}
0005434757623	A7881A	1379 924815	ALEKSANDR TARASOV	{"phone": "+70340397814"}
0005434757624	208F30	8852 602126	KSENIYA KUZNECOVA	{"phone": "+70839216652"}
0005434757625	676C09	6007 870410	LYUDMILA ZAYCEVA	{"phone": "+70752427879"}
0005434757626	F6FC70	6622 956481	PETR ANDREEV	{"phone": "+70822902815"}
0005434757627	DB3467	2637 486414	NIKOLAY TIKHONOV	{"email": "tikhonov-n_081978@postgrespro.ru", "phone": "+70604882738"}
0005434757628	DB3467	4830 399468	EKATERINA ABRAMOVA	{"phone": "+70662794269"}
0005434757629	CE6AA4	2180 564969	PELAGEYA MELNIKOVA	{"email": "pmelnikova_21111964@postgrespro.ru", "phone": "+70227016302"}
0005434757630	CE6AA4	7106 313466	YAROSLAV SHEVCHENKO	{"email": "shevchenko-y-101974@postgrespro.ru", "phone": "+70037333752"}
0005434757631	819653	4631 347923	NINEL PETROVA	{"phone": "+70042186351"}
0005434757632	819653	8503 049812	PAVEL KOZLOV	{"email": "pkozlov.1975@postgrespro.ru", "phone": "+70909132107"}
0005434757633	DDBD4A	5991 967341	GALINA POPOVA	{"phone": "+70620533178"}
0005434757634	8C3617	4975 919240	TATYANA KOROLEVA	{"email": "korolevatatyana-051973@postgrespro.ru", "phone": "+70192522609"}
0005434757635	8C3617	8347 761217	NIKOLAY ZAYCEV	{"phone": "+70439032666"}
0005434757636	CEF9A3	3648 899594	MAKSIM KAZAKOV	{"phone": "+70628550915"}
0005434757637	13A6C0	8394 040251	ANTONINA TITOVA	{"email": "titova.antonina081977@postgrespro.ru", "phone": "+70595027157"}
0005434757638	0C039E	9270 093762	SVETLANA DENISOVA	{"email": "s_denisova-12041977@postgrespro.ru", "phone": "+70524627759"}
0005434757639	0C039E	0950 573291	ANDREY MIKHAYLOV	{"phone": "+70731563099"}
0005434757640	074065	4119 730359	GEORGIY FROLOV	{"phone": "+70729443694"}
0005434757641	3488E3	0655 607516	ELENA SAVELEVA	{"phone": "+70931603348"}
0005434757642	581F6C	8138 861530	ANASTASIYA SERGEEVA	{"email": "a.sergeeva.091979@postgrespro.ru", "phone": "+70761373705"}
0005434757643	581F6C	3005 034647	MAKSIM MIRONOV	{"email": "mironov.maksim121972@postgrespro.ru", "phone": "+70876984277"}
0005434757644	CFC31B	4887 231042	ALEKSANDR CHERNOV	{"email": "chernov_a-1974@postgrespro.ru", "phone": "+70647014464"}
0005434757645	B33A92	6590 431334	MAKSIM IVANOV	{"phone": "+70132324762"}
0005434757646	B33A92	0105 899809	OLGA SAVELEVA	{"email": "osaveleva.121983@postgrespro.ru", "phone": "+70117262975"}
0005434757647	1AEC9F	2198 934577	MIKHAIL FEDOROV	{"phone": "+70178062696"}
0005434757648	1AEC9F	8360 770435	OLGA ANTONOVA	{"email": "antonovaolga_13121969@postgrespro.ru", "phone": "+70662624429"}
0005434757649	95E938	7682 771688	TATYANA SERGEEVA	{"email": "sergeevat_041978@postgrespro.ru", "phone": "+70101134872"}
0005434757650	94CC43	8834 276914	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov-011970@postgrespro.ru", "phone": "+70445866428"}
0005434757651	94CC43	2442 124815	TATYANA OSIPOVA	{"email": "tatyana.osipova_22061969@postgrespro.ru", "phone": "+70567610839"}
0005434757652	38E55C	7292 878113	KONSTANTIN NAZAROV	{"phone": "+70520293438"}
0005434757653	65A07A	4137 928121	ANNA ZAKHAROVA	{"phone": "+70160044280"}
0005434757654	B82F38	3387 516025	NURIYA NIKOLAEVA	{"email": "nikolaeva_n-011975@postgrespro.ru", "phone": "+70500364289"}
0005434757655	B82F38	8781 900543	VIKTOR SOKOLOV	{"phone": "+70726584164"}
0005434757656	762A78	0661 880617	ALINA IVANOVA	{"phone": "+70446744156"}
0005434757657	762A78	8695 198167	GENNADIY POPOV	{"email": "gennadiy.popov-26031962@postgrespro.ru", "phone": "+70707032702"}
0005434757658	C65ACE	1474 106930	KONSTANTIN ALEKSANDROV	{"phone": "+70918701526"}
0005434757659	06CC3D	3078 717306	YULIYA BELYAEVA	{"phone": "+70811149731"}
0005434757660	5E93BB	2775 786139	MARIYA EFREMOVA	{"email": "mariya.efremova-1959@postgrespro.ru", "phone": "+70606511799"}
0005434757661	3FE2EB	3616 455180	TATYANA IVANOVA	{"email": "tatyanaivanova-19081962@postgrespro.ru", "phone": "+70363736302"}
0005434757662	3FE2EB	5561 287869	IRINA PETROVA	{"phone": "+70012545104"}
0005434757663	EBF54E	5498 293240	ELENA ALEKSEEVA	{"email": "elena.alekseeva_28011971@postgrespro.ru", "phone": "+70310768111"}
0005434757664	AA9936	1618 651876	NADEZHDA YAKOVLEVA	{"phone": "+70744378306"}
0005434757665	AA9936	3521 458756	MIKHAIL VLASOV	{"email": "vlasov-m_1980@postgrespro.ru", "phone": "+70443636774"}
0005434757666	2FAC1F	7975 080299	SERGEY MIRONOV	{"email": "s-mironov.041964@postgrespro.ru", "phone": "+70562790363"}
0005434757667	BA58D3	3347 097578	YURIY DAVYDOV	{"email": "ydavydov-09051969@postgrespro.ru", "phone": "+70327630167"}
0005434757668	B309A4	7108 707274	YURIY TIMOFEEV	{"phone": "+70027110890"}
0005434757669	B309A4	3236 727287	GALINA IVANOVA	{"email": "givanova-1959@postgrespro.ru", "phone": "+70969953544"}
0005434757670	14F112	1956 185541	ALEKSANDRA MARTYNOVA	{"phone": "+70396617070"}
0005434757671	14F112	0433 696418	ALEKSANDR POPOV	{"phone": "+70215363176"}
0005434757672	D37478	3657 016949	EKATERINA KOZLOVA	{"phone": "+70236557089"}
0005434757673	D37478	4389 215414	ARSENIY KISELEV	{"email": "kiselev.a.1968@postgrespro.ru", "phone": "+70001717113"}
0005434757674	A6564D	2087 360220	MARIYA IVANOVA	{"email": "mivanova_091976@postgrespro.ru", "phone": "+70703613179"}
0005434757675	96556C	6912 072086	VLADIMIR CHERNOV	{"phone": "+70052172270"}
0005434757676	F0639C	7999 804666	ALEKSANDR AFANASEV	{"email": "aleksandrafanasev.061976@postgrespro.ru", "phone": "+70582130957"}
0005434757677	F0639C	9955 490313	ALEVTINA VOLKOVA	{"phone": "+70791273288"}
0005434757678	F0639C	5252 514304	ZOYA MATVEEVA	{"phone": "+70716839253"}
0005434757679	CA462E	4670 203079	YURIY KONOVALOV	{"email": "y-konovalov_20121978@postgrespro.ru", "phone": "+70863462349"}
0005434757680	B2F504	2466 276574	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov-24041961@postgrespro.ru", "phone": "+70781437179"}
0005434757681	C4308E	2132 519169	IVAN MAKAROV	{"email": "i-makarov-26091971@postgrespro.ru", "phone": "+70052832328"}
0005434757682	3D52F3	0229 106108	ALEKSANDR PETROV	{"phone": "+70856858822"}
0005434757683	70C1CF	0328 015571	MIKHAIL FEDOROV	{"phone": "+70142479568"}
0005434757684	B5C3B0	9905 142443	VLADIMIR AFANASEV	{"phone": "+70656735268"}
0005434757685	B5C3B0	4481 964154	YURIY MOROZOV	{"phone": "+70506869445"}
0005434757686	EF0768	3313 454925	GALINA TARASOVA	{"phone": "+70658410495"}
0005434757687	B12220	1724 274522	VADIM FEDOROV	{"email": "fedorov-v1977@postgrespro.ru", "phone": "+70781639889"}
0005434757688	B12220	6977 709167	VIKTOR MIRONOV	{"email": "vmironov121966@postgrespro.ru", "phone": "+70253612027"}
0005434757689	1892EA	3159 787476	IVAN MEDVEDEV	{"email": "ivan.medvedev_121970@postgrespro.ru", "phone": "+70611967214"}
0005434757690	84ECD5	2797 025867	VYACHESLAV POPOV	{"email": "vyacheslav_popov.1964@postgrespro.ru", "phone": "+70325537956"}
0005434757691	57C8F3	6290 025014	SEMEN DENISOV	{"phone": "+70706748044"}
0005434757692	C8746D	0930 997007	EVGENIY KUZMIN	{"phone": "+70032308792"}
0005434757693	C8746D	0649 447775	VERA KOROLEVA	{"phone": "+70349938011"}
0005434757694	0AD779	2472 254099	NATALIYA CHERNOVA	{"phone": "+70628656833"}
0005434757695	0AD779	1182 882576	GALINA MAKAROVA	{"email": "g.makarova-20091980@postgrespro.ru", "phone": "+70786724522"}
0005434757696	5AA1DD	0405 543091	ANASTASIYA NAZAROVA	{"phone": "+70350101586"}
0005434757697	9F3F5A	7766 018086	OLGA GORBUNOVA	{"email": "o_gorbunova_13061964@postgrespro.ru", "phone": "+70925696820"}
0005434757698	8A049D	2440 949159	EVGENIY KOROLEV	{"phone": "+70768889979"}
0005434757699	8A049D	0107 508997	NATALYA ZAKHAROVA	{"phone": "+70474255512"}
0005434757700	8A049D	2579 941645	NIKITA NAZAROV	{"email": "n.nazarov-1972@postgrespro.ru", "phone": "+70068736660"}
0005434757701	7D933F	5510 532035	VIKTOR GAVRILOV	{"phone": "+70222670298"}
0005434757702	7D933F	9497 646317	ANATOLIY SIDOROV	{"email": "sidorov_a_21031968@postgrespro.ru", "phone": "+70798374069"}
0005434757703	6AD601	4408 097384	IRINA KUDRYASHOVA	{"phone": "+70179146279"}
0005434757704	6AD601	8603 261445	ARTEM VASILEV	{"phone": "+70756369665"}
0005434757705	CBCD2B	4072 846528	IGOR MOROZOV	{"phone": "+70927275769"}
0005434757706	688A12	0015 570824	ILYA BARANOV	{"phone": "+70133728177"}
0005434757707	CC2DCD	1434 502026	LEONID SOROKIN	{"email": "sorokin-leonid-1972@postgrespro.ru", "phone": "+70648441720"}
0005434757708	CC2DCD	3627 758715	NADEZHDA MAKAROVA	{"email": "nadezhda.makarova18081968@postgrespro.ru", "phone": "+70340128483"}
0005434757709	92A9A3	9995 639226	NATALYA KOLESNIKOVA	{"email": "kolesnikova-n25071967@postgrespro.ru", "phone": "+70310748390"}
0005434757710	92A9A3	5575 464527	ELIZAVETA KUZMINA	{"phone": "+70683239391"}
0005434757711	0AABEC	6752 974757	NAILYA ANTONOVA	{"phone": "+70599989981"}
0005434757712	12099E	8839 197067	SERGEY KUZNECOV	{"phone": "+70280970338"}
0005434758852	118AD9	3294 593751	TATYANA MARTYNOVA	{"email": "tatyanamartynova25051971@postgrespro.ru", "phone": "+70932917104"}
0005434758853	411E4B	3447 562828	OLGA MAKSIMOVA	{"email": "maksimova.o.1978@postgrespro.ru", "phone": "+70062650606"}
0005434758854	411E4B	3539 338607	VYACHESLAV ISAEV	{"phone": "+70554078995"}
0005434758855	6578CA	5328 382678	OLGA OSIPOVA	{"email": "osipova_o03091967@postgrespro.ru", "phone": "+70862597795"}
0005434758856	6578CA	0864 561253	VLADIMIR GAVRILOV	{"phone": "+70597882137"}
0005434758857	B69669	5482 726593	GALINA FILIPPOVA	{"email": "galina-filippova_12061973@postgrespro.ru", "phone": "+70720538355"}
0005434758858	B69669	8916 162432	LYUBOV ZOTOVA	{"phone": "+70919358627"}
0005434758859	A2B516	1175 669889	VALENTINA TARASOVA	{"phone": "+70212514481"}
0005434758860	A2B516	6434 143191	TAMARA NESTEROVA	{"phone": "+70792549925"}
0005434758861	A2B516	6674 797316	DARYA IVANOVA	{"phone": "+70547896532"}
0005434758862	D1171F	5924 986484	IRINA GORBUNOVA	{"phone": "+70766524530"}
0005434758863	D1171F	1602 843289	SERGEY MARTYNOV	{"phone": "+70894666995"}
0005434758864	316041	2079 208251	ARMEN ANTONOV	{"email": "antonov-armen.021970@postgrespro.ru", "phone": "+70545633358"}
0005434758865	316041	1715 957635	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay.071969@postgrespro.ru", "phone": "+70323176565"}
0005434758866	85CD21	5559 481335	DMITRIY IVANOV	{"email": "ivanovd-1970@postgrespro.ru", "phone": "+70271589238"}
0005434758867	E50D31	6615 843935	VYACHESLAV TIKHONOV	{"phone": "+70676144010"}
0005434758868	C628E2	3593 968204	ANASTASIYA VOROBEVA	{"phone": "+70114749567"}
0005434758869	5D7E03	2973 623755	ELENA FROLOVA	{"email": "frolova-elena-02111970@postgrespro.ru", "phone": "+70618246274"}
0005434758870	5D7E03	7644 079029	OLGA VLASOVA	{"phone": "+70719599068"}
0005434758871	5D7E03	3524 569096	ELENA FROLOVA	{"email": "efrolova.1964@postgrespro.ru", "phone": "+70161899320"}
0005434758872	77F6FD	9466 552559	VYACHESLAV MAKAROV	{"email": "vyacheslav-makarov.22041976@postgrespro.ru", "phone": "+70620664692"}
0005434758873	205363	3435 279346	ZOYA KUZNECOVA	{"phone": "+70146046893"}
0005434758874	26FFA5	6604 376495	SERGEY MIKHAYLOV	{"email": "sergey-mikhaylov-121977@postgrespro.ru", "phone": "+70424502766"}
0005434758875	A722EE	3032 859618	NATALYA BARANOVA	{"phone": "+70908904049"}
0005434758876	A722EE	3145 640523	MARIYA MAKAROVA	{"email": "makarova-mariya.011977@postgrespro.ru", "phone": "+70192018082"}
0005434758877	CB9182	0673 055847	MIKHAIL ABRAMOV	{"email": "m-abramov_1965@postgrespro.ru", "phone": "+70859392072"}
0005434758878	3136B7	1052 982176	YURIY MELNIKOV	{"phone": "+70117887584"}
0005434758879	B15B6D	9378 107895	RUSLAN SOKOLOV	{"phone": "+70848253874"}
0005434758880	1C9836	1272 360595	ALEKSEY VLASOV	{"email": "aleksey-vlasov.121958@postgrespro.ru", "phone": "+70094311821"}
0005434758881	125C35	8865 617881	EVGENIYA FILIPPOVA	{"phone": "+70699340826"}
0005434758882	CC53BD	7419 289294	IGOR SERGEEV	{"phone": "+70551947365"}
0005434758883	B7B380	7953 117776	ALEKSEY DENISOV	{"phone": "+70693070466"}
0005434758884	E1FF33	6416 558052	ALEKSEY FEDOTOV	{"email": "a-fedotov-20071967@postgrespro.ru", "phone": "+70506153419"}
0005434758885	0B90E6	4683 725639	IRINA VOLKOVA	{"email": "volkovairina_1969@postgrespro.ru", "phone": "+70284049156"}
0005434758886	CC4CE6	8006 131182	ANDREY VOROBEV	{"phone": "+70132123302"}
0005434758887	EC7117	3784 672901	VITALIY KUZNECOV	{"email": "v_kuznecov_121969@postgrespro.ru", "phone": "+70385034382"}
0005434758888	E45FCB	2974 517991	ELENA MELNIKOVA	{"email": "melnikovaelena_1971@postgrespro.ru", "phone": "+70994314628"}
0005434758889	3C06C9	3038 559488	EKATERINA SEMENOVA	{"email": "semenova-ekaterina.061988@postgrespro.ru", "phone": "+70188961650"}
0005434758890	3C06C9	0229 596924	IVAN MIKHAYLOV	{"phone": "+70294154095"}
0005434758891	3C06C9	2741 853800	YULIYA ANDREEVA	{"phone": "+70056017335"}
0005434758892	259948	6653 395695	VALENTINA NOVIKOVA	{"phone": "+70052673821"}
0005434758893	259948	0297 246767	ALEKSANDR DENISOV	{"email": "aleksandr_denisov1976@postgrespro.ru", "phone": "+70319869368"}
0005434758894	935876	2027 335672	ANDREY BELOV	{"phone": "+70709333346"}
0005434758895	C3FA92	3373 952361	TATYANA KONOVALOVA	{"email": "konovalova.tatyana.081965@postgrespro.ru", "phone": "+70518479730"}
0005434758896	555591	9000 042207	MIKHAIL NIKITIN	{"email": "m.nikitin18061978@postgrespro.ru", "phone": "+70492571838"}
0005434758897	555591	8341 798777	NATALIYA IVANOVA	{"phone": "+70466777072"}
0005434758898	555591	0946 654784	VALENTINA MIKHAYLOVA	{"email": "mikhaylovavalentina1969@postgrespro.ru", "phone": "+70045541970"}
0005434758899	6F5DC7	9119 506552	ELENA SMIRNOVA	{"phone": "+70520135045"}
0005434758900	A49528	7397 856260	ANTONINA FOMINA	{"email": "fomina_antonina.1981@postgrespro.ru", "phone": "+70398319858"}
0005434758901	A49528	0139 515982	TAMARA KALININA	{"email": "tkalinina-1984@postgrespro.ru", "phone": "+70031178895"}
0005434758902	9BCD03	3451 962544	LIDIYA KUZNECOVA	{"email": "kuznecova_l_091972@postgrespro.ru", "phone": "+70059142771"}
0005434758903	9BCD03	7512 151233	ROMAN KUZMIN	{"email": "romankuzmin021978@postgrespro.ru", "phone": "+70472190152"}
0005434758904	9BCD03	3120 206968	OLGA SAVELEVA	{"phone": "+70141700788"}
0005434758905	7E476C	3175 339258	OLEG VLASOV	{"phone": "+70640464851"}
0005434758906	2CD1B7	4623 999831	VYACHESLAV DAVYDOV	{"phone": "+70089440754"}
0005434758907	F069BA	5834 799911	DANIIL DAVYDOV	{"phone": "+70804147710"}
0005434758908	169D69	0220 360151	SERGEY KUZMIN	{"phone": "+70841688962"}
0005434758909	7AC4A3	1190 757515	EKATERINA POLYAKOVA	{"email": "e.polyakova.25081980@postgrespro.ru", "phone": "+70949486179"}
0005434758910	BE0282	3919 244812	YURIY KAZAKOV	{"email": "kazakovyuriy_1965@postgrespro.ru", "phone": "+70441838846"}
0005434758911	CEDC91	0648 011070	NIKOLAY VOLKOV	{"phone": "+70613462799"}
0005434758912	F80AD9	6526 021648	ZOYA BARANOVA	{"phone": "+70834553374"}
0005434758913	F80AD9	9458 568699	ELENA FADEEVA	{"email": "fadeeva.e.1962@postgrespro.ru", "phone": "+70925038124"}
0005434758914	FAD546	6395 295541	KSENIYA IVANOVA	{"phone": "+70276314971"}
0005434758915	63D3BB	7838 648457	ANNA ALEKSEEVA	{"email": "alekseeva-a.1978@postgrespro.ru", "phone": "+70419529758"}
0005434758916	BA9456	1179 725513	EGOR KUZNECOV	{"phone": "+70735584199"}
0005434758917	B281C6	4234 093579	LARISA PETROVA	{"email": "petrova_larisa-11061968@postgrespro.ru", "phone": "+70486292751"}
0005434758918	3739D1	0528 893321	IVAN FOMIN	{"phone": "+70934683104"}
0005434758919	3079CF	0904 624528	TATYANA PAVLOVA	{"phone": "+70721091895"}
0005434758920	C90B91	6619 305913	VLADIMIR YAKOVLEV	{"email": "yakovlevvladimir_1977@postgrespro.ru", "phone": "+70564666226"}
0005434758921	C90B91	6101 686042	NIKITA SOKOLOV	{"phone": "+70323568820"}
0005434758922	19DDD6	0810 719854	LYUDMILA KALININA	{"phone": "+70032823698"}
0005434758923	19DDD6	4514 403933	ANTON MIKHAYLOV	{"phone": "+70254316761"}
0005434758924	F2F3B9	5859 492451	TATYANA KARPOVA	{"phone": "+70882803828"}
0005434758925	7F2FF9	1282 861070	ANATOLIY OSIPOV	{"email": "a-osipov.031969@postgrespro.ru", "phone": "+70804889960"}
0005434758926	8E7346	7423 933282	RINAT MAKAROV	{"email": "makarov-rinat.24121974@postgrespro.ru", "phone": "+70652881550"}
0005434758927	F9CECD	3977 166062	ANDREY ALEKSEEV	{"phone": "+70177064596"}
0005434758928	B44679	3967 257252	ANASTASIYA POPOVA	{"email": "apopova_21021972@postgrespro.ru", "phone": "+70554486246"}
0005434758929	3CCAE1	1603 700391	YURIY DENISOV	{"email": "denisov.yuriy.16021965@postgrespro.ru", "phone": "+70016380230"}
0005434758930	3CCAE1	7308 684175	POLINA MEDVEDEVA	{"phone": "+70287036146"}
0005434758931	CB20E0	7678 175775	ELIZAVETA ALEKSEEVA	{"phone": "+70478106988"}
0005434758932	FD341C	4517 134870	ANDREY BARANOV	{"email": "andreybaranov_091977@postgrespro.ru", "phone": "+70984312281"}
0005434758933	FD341C	4785 842429	ALEKSEY KRASNOV	{"phone": "+70384219208"}
0005434758934	FD341C	5413 381837	OLGA MIRONOVA	{"phone": "+70433188600"}
0005434758935	29626F	3425 467632	VERONIKA TARASOVA	{"phone": "+70028181965"}
0005434758936	A9FCE7	2899 389069	SERGEY MAKAROV	{"phone": "+70911970806"}
0005434758937	A9FCE7	1039 526545	OLGA FROLOVA	{"email": "ofrolova1969@postgrespro.ru", "phone": "+70643922738"}
0005434758938	763BAC	2738 345899	NATALIYA DMITRIEVA	{"email": "dmitrieva_n_04031985@postgrespro.ru", "phone": "+70477641871"}
0005434758939	2A421F	8789 228818	GALINA LOGINOVA	{"phone": "+70131095308"}
0005434758940	24A6BC	0678 141715	EVDOKIYA GERASIMOVA	{"email": "e.gerasimova.021975@postgrespro.ru", "phone": "+70865435418"}
0005434758941	DD2AFD	7292 820256	SERGEY KISELEV	{"phone": "+70703886560"}
0005434758942	477AAE	4955 998517	MARINA NOVIKOVA	{"email": "marina-novikova.021981@postgrespro.ru", "phone": "+70456286017"}
0005434758943	477AAE	0729 703948	MARIYA KOROLEVA	{"email": "koroleva-mariya_1972@postgrespro.ru", "phone": "+70318037232"}
0005434758944	682E77	6863 112281	NIKITA EGOROV	{"phone": "+70678453914"}
0005434758945	F93930	5779 284796	SERGEY MAKAROV	{"email": "sergey_makarov_041978@postgrespro.ru", "phone": "+70759046577"}
0005434758946	F93930	1762 488386	ARSEN IVANOV	{"phone": "+70699898793"}
0005434758947	F93930	4167 707123	ALINA ZAYCEVA	{"phone": "+70830810811"}
0005434758948	DC6DE8	7627 252599	VALERIYA SOROKINA	{"phone": "+70707609137"}
0005434758949	DC6DE8	3211 091964	TATYANA EGOROVA	{"email": "egorova-tatyana1962@postgrespro.ru", "phone": "+70421626028"}
0005434758950	DC6DE8	5044 950380	RADIK NIKOLAEV	{"email": "radik-nikolaev03121970@postgrespro.ru", "phone": "+70187393564"}
0005434758951	894348	4890 158036	VLADIMIR NIKITIN	{"email": "vladimir.nikitin22021975@postgrespro.ru", "phone": "+70557577570"}
0005434758952	ED58D5	5942 170702	ANNA STEPANOVA	{"phone": "+70205169086"}
0005434758953	B6E4F3	5452 692204	VLADIMIR VOROBEV	{"phone": "+70906515190"}
0005434758954	B6E4F3	8734 759440	GALINA TIKHONOVA	{"phone": "+70004291663"}
0005434758955	5E4D43	5618 238514	IRINA GUSEVA	{"email": "iguseva_26091964@postgrespro.ru", "phone": "+70582633190"}
0005434758956	5B1C40	2616 109401	ALFIYA NOVIKOVA	{"email": "novikovaa_24111964@postgrespro.ru", "phone": "+70702154046"}
0005434758957	5B1C40	4734 062454	MARIYA MOISEEVA	{"email": "m_moiseeva.1967@postgrespro.ru", "phone": "+70501826383"}
0005434758958	DF9213	5926 043379	EKATERINA KONOVALOVA	{"email": "e-konovalova.1967@postgrespro.ru", "phone": "+70782060282"}
0005434758959	FB172F	0987 495139	OLEG POPOV	{"phone": "+70028285638"}
0005434758960	FB172F	2125 479426	VLADIMIR PETROV	{"phone": "+70328427559"}
0005434758961	970AC1	0387 164069	ROMAN KRASNOV	{"phone": "+70869963913"}
0005434758962	970AC1	5391 126353	LILIYA KUZMINA	{"email": "liliya-kuzmina_01091984@postgrespro.ru", "phone": "+70021422969"}
0005434758963	3927A0	1339 182440	ELENA VASILEVA	{"phone": "+70635192887"}
0005434758964	3927A0	5949 600615	YURIY KISELEV	{"email": "ykiselev_1975@postgrespro.ru", "phone": "+70487863364"}
0005434760153	7E5628	6917 621894	MURAT EGOROV	{"email": "murat_egorov24111982@postgrespro.ru", "phone": "+70826448435"}
0005434760154	B08644	8214 060692	GEORGIY SMIRNOV	{"email": "gsmirnov_01041965@postgrespro.ru", "phone": "+70861688432"}
0005434760155	B08644	8954 523706	VIKTOR GUSEV	{"email": "viktor-gusev1960@postgrespro.ru", "phone": "+70472010068"}
0005434760156	AD2B69	4198 336170	VLADIMIR GAVRILOV	{"email": "v_gavrilov-031975@postgrespro.ru", "phone": "+70516463707"}
0005434760157	6CDC29	1744 245259	DARYA IVANOVA	{"email": "ivanova-d_1961@postgrespro.ru", "phone": "+70347249035"}
0005434760158	A0588A	9388 065823	MARINA OSIPOVA	{"phone": "+70987570712"}
0005434760159	BEB2CF	2044 380072	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev-091973@postgrespro.ru", "phone": "+70332048625"}
0005434760160	25A651	2287 146510	SERGEY POPOV	{"email": "s_popov.06021970@postgrespro.ru", "phone": "+70671851532"}
0005434760161	BA3424	0356 807405	DMITRIY BORISOV	{"phone": "+70928247017"}
0005434760162	BA3424	4843 854106	ALEKSEY BORISOV	{"phone": "+70956436313"}
0005434760163	608A65	0653 545047	OLGA MALYSHEVA	{"email": "o.malysheva_1976@postgrespro.ru", "phone": "+70540848924"}
0005434760164	608A65	4598 469786	VALENTINA SOLOVEVA	{"email": "valentina-soloveva-1967@postgrespro.ru", "phone": "+70693810943"}
0005434760165	608A65	5887 947171	NADEZHDA LOGINOVA	{"phone": "+70204959088"}
0005434760166	2C0015	4686 487522	YURIY VOLKOV	{"email": "volkov.y.18111968@postgrespro.ru", "phone": "+70245425376"}
0005434760167	2C0015	1750 075965	ANATOLIY SMIRNOV	{"phone": "+70957692312"}
0005434760168	6A946F	2345 797446	SERGEY GRIGOREV	{"phone": "+70980257898"}
0005434760169	529484	4764 974208	NADEZHDA NAZAROVA	{"phone": "+70272721496"}
0005434760170	529484	2794 695098	VITALIY SIDOROV	{"email": "vitaliy_sidorov071960@postgrespro.ru", "phone": "+70521795763"}
0005434760171	3629D0	0032 277360	RASUL IVANOV	{"phone": "+70249550343"}
0005434760172	32BC88	6247 688343	ALISHER ZAYCEV	{"phone": "+70845555962"}
0005434760173	095B0D	8173 753058	IVAN POPOV	{"email": "popov_ivan.1966@postgrespro.ru", "phone": "+70218937050"}
0005434760174	08E339	3518 503164	RAISA SEMENOVA	{"phone": "+70857299171"}
0005434760175	08E339	2468 034553	EKATERINA NIKIFOROVA	{"email": "e.nikiforova-1969@postgrespro.ru", "phone": "+70076336388"}
0005434760176	3879DD	4749 876993	DMITRIY ZHURAVLEV	{"phone": "+70373651282"}
0005434760177	1F6E42	5122 507148	OLGA ZHUKOVA	{"email": "ozhukova-041974@postgrespro.ru", "phone": "+70474811270"}
0005434760178	1F6E42	2478 847524	VALENTINA POPOVA	{"phone": "+70321622515"}
0005434760179	1F6E42	3253 664343	OLGA AKIMOVA	{"phone": "+70261947396"}
0005434760180	1390B2	4012 523685	DANIIL STEPANOV	{"phone": "+70057655707"}
0005434760181	40F8A8	8920 709157	MIKHAIL ANDREEV	{"phone": "+70467720950"}
0005434760182	CACF6D	1206 264697	SERGEY KUZNECOV	{"email": "kuznecovs_04111974@postgrespro.ru", "phone": "+70931184895"}
0005434760183	A4B791	2677 652397	ALEKSANDR KONOVALOV	{"email": "konovalov_a06071966@postgrespro.ru", "phone": "+70111267219"}
0005434760184	391154	0082 332642	OLGA MOROZOVA	{"email": "morozova_o02071967@postgrespro.ru", "phone": "+70549495753"}
0005434760185	0DA5E2	0654 432303	ALEKSANDR KARPOV	{"email": "akarpov1967@postgrespro.ru", "phone": "+70314796648"}
0005434760186	0DA5E2	2062 100439	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov_08091976@postgrespro.ru", "phone": "+70840491209"}
0005434760187	0DA5E2	2740 246927	DANILA KULIKOV	{"phone": "+70999092177"}
0005434760188	A09656	3287 963301	NATALYA GUSEVA	{"phone": "+70622892268"}
0005434760189	15EA20	7726 852533	LARISA LAZAREVA	{"email": "lazareva_larisa-051971@postgrespro.ru", "phone": "+70156112532"}
0005434760190	15EA20	2254 608858	PETR NAZAROV	{"email": "nazarov-p.1967@postgrespro.ru", "phone": "+70214361908"}
0005434760191	599B2F	8965 949497	ANATOLIY MOISEEV	{"email": "a-moiseev-13091964@postgrespro.ru", "phone": "+70151604722"}
0005434760192	C18317	9399 689682	LILIYA ANTONOVA	{"phone": "+70463399455"}
0005434760193	25B565	5947 790016	NIKITA GERASIMOV	{"email": "gerasimov.n06071974@postgrespro.ru", "phone": "+70747434004"}
0005434760194	D31D1C	1111 799876	GENNADIY IVANOV	{"email": "gennadiy_ivanov_031984@postgrespro.ru", "phone": "+70292272183"}
0005434760195	AC5AA5	2317 555692	MIKHAIL SOKOLOV	{"email": "sokolovm1963@postgrespro.ru", "phone": "+70961877914"}
0005434760196	AC5AA5	7444 951991	ELENA KUZNECOVA	{"phone": "+70260154830"}
0005434760197	5AA429	3604 641162	GENNADIY POPOV	{"email": "g.popov071976@postgrespro.ru", "phone": "+70159749012"}
0005434760198	5FFEA5	5452 826101	DAMIR PETROV	{"phone": "+70799591454"}
0005434760199	5FFEA5	3717 211979	VITALIY SOLOVEV	{"phone": "+70347185690"}
0005434760200	BC9C28	8788 341766	NIKOLAY KUDRYASHOV	{"phone": "+70851989835"}
0005434760201	BC9C28	1460 357467	SERGEY FOMIN	{"email": "s.fomin_091971@postgrespro.ru", "phone": "+70816464107"}
0005434760202	9772AF	8107 654198	ALEKSANDR NAZAROV	{"email": "nazarov_a10111971@postgrespro.ru", "phone": "+70732599435"}
0005434760203	9772AF	9198 547768	KSENIYA MELNIKOVA	{"phone": "+70073233828"}
0005434760204	D76E91	6743 901531	OLGA BORISOVA	{"email": "olgaborisova1970@postgrespro.ru", "phone": "+70456488773"}
0005434760205	2DA2E1	8846 021694	VITALIY SERGEEV	{"email": "sergeev_vitaliy_12021975@postgrespro.ru", "phone": "+70103039359"}
0005434760206	586E80	5083 717809	MARINA SEMENOVA	{"phone": "+70672720840"}
0005434760207	617A05	2906 603857	SERGEY SCHERBAKOV	{"email": "sergey_scherbakov-041972@postgrespro.ru", "phone": "+70044007984"}
0005434760208	617A05	4060 835797	TATYANA MALYSHEVA	{"phone": "+70032370943"}
0005434760209	A1BC2D	6437 553587	VLADIMIR TARASOV	{"email": "tarasov.v_1978@postgrespro.ru", "phone": "+70898671080"}
0005434760210	1EBEC6	4419 539883	PETR SOLOVEV	{"phone": "+70394694099"}
0005434760211	91E460	7596 199209	ALEKSANDR ANTONOV	{"phone": "+70565945110"}
0005434760212	B1F530	2439 114417	NATALYA MIKHAYLOVA	{"email": "mikhaylovanatalya.1967@postgrespro.ru", "phone": "+70984906539"}
0005434760213	3AFF07	6466 449211	LYUDMILA MALYSHEVA	{"email": "lmalysheva-1969@postgrespro.ru", "phone": "+70790669378"}
0005434760214	3AFF07	3241 725491	ALEKSANDR KISELEV	{"email": "akiselev-14021973@postgrespro.ru", "phone": "+70232036424"}
0005434760215	70B3C2	5860 524873	YULIYA KUDRYASHOVA	{"phone": "+70540209065"}
0005434760216	70B3C2	2947 615494	SERGEY KARPOV	{"email": "karpov_s1965@postgrespro.ru", "phone": "+70861341709"}
0005434760217	81BF2C	2167 775400	VALENTINA VASILEVA	{"phone": "+70300323431"}
0005434760218	81BF2C	9445 415118	TATYANA ZAKHAROVA	{"phone": "+70515440319"}
0005434760219	01EDF6	6425 331817	ANDREY PAVLOV	{"email": "pavlov.andrey_011980@postgrespro.ru", "phone": "+70758918595"}
0005434760220	B1BFC3	9231 949602	NURLAN IVANOV	{"email": "nivanov_071976@postgrespro.ru", "phone": "+70104285306"}
0005434760221	2ABFA2	8201 674831	ANNA POPOVA	{"phone": "+70032872580"}
0005434760222	385715	2599 139714	ANTONINA FEDOROVA	{"phone": "+70348136004"}
0005434760223	385715	0911 536286	ZINAIDA LAZAREVA	{"phone": "+70186339542"}
0005434760224	DF5828	9256 614435	ALEKSEY GAVRILOV	{"email": "a-gavrilov.061969@postgrespro.ru", "phone": "+70995496954"}
0005434760225	2B437B	4421 881289	ROZA ISAEVA	{"email": "risaeva.1971@postgrespro.ru", "phone": "+70682973176"}
0005434760226	119F71	6241 367393	ELENA OVCHINNIKOVA	{"email": "elena-ovchinnikova121971@postgrespro.ru", "phone": "+70448923324"}
0005434760227	5B7B57	8477 030375	EVGENIYA SIDOROVA	{"phone": "+70588730002"}
0005434760228	5B7B57	9947 890328	OLEG STEPANOV	{"phone": "+70695319203"}
0005434760229	CAB37D	2088 282859	SVETLANA BORISOVA	{"phone": "+70825242018"}
0005434760230	A574C8	0965 675602	NATALYA KARPOVA	{"phone": "+70823911760"}
0005434760231	B282EC	8778 172739	ANDREY TIKHONOV	{"phone": "+70172769277"}
0005434760232	68EAB1	4594 407762	GALINA KUZNECOVA	{"email": "g_kuznecova10021977@postgrespro.ru", "phone": "+70194559635"}
0005434760233	46D8B2	0240 041443	ALLA KONDRATEVA	{"phone": "+70519446351"}
0005434760234	95916B	6340 465809	ARTEM DMITRIEV	{"email": "artem.dmitriev-031963@postgrespro.ru", "phone": "+70965546179"}
0005434760235	95916B	1327 762845	PETR KOZLOV	{"phone": "+70671482189"}
0005434760236	972B0F	5371 508062	KSENIYA GAVRILOVA	{"email": "k.gavrilova_02051969@postgrespro.ru", "phone": "+70705480217"}
0005434760237	C92C60	7000 217911	IRINA SIDOROVA	{"phone": "+70436477088"}
0005434760238	A475A2	6825 675524	SOFYA TARASOVA	{"phone": "+70352768845"}
0005434760239	250FAF	9100 837949	TATYANA KONOVALOVA	{"email": "t-konovalova1971@postgrespro.ru", "phone": "+70709086370"}
0005434760240	D9021C	2692 503332	PETR MATVEEV	{"phone": "+70992389917"}
0005434760241	4A579A	4428 626875	ANNA KAZAKOVA	{"email": "kazakovaanna.1969@postgrespro.ru", "phone": "+70480257707"}
0005434760242	4A579A	6037 952113	MARIYA ILINA	{"phone": "+70772480232"}
0005434760243	4A579A	2995 352426	MIKHAIL SEMENOV	{"email": "mikhail_semenov.19111964@postgrespro.ru", "phone": "+70937118673"}
0005434760244	7CCB89	2459 598803	MARINA FEDOROVA	{"phone": "+70154954646"}
0005434760245	7CCB89	5453 340311	VERA AFANASEVA	{"phone": "+70591388137"}
0005434760246	8A7BBE	4240 310772	GALINA FEDOROVA	{"phone": "+70489377778"}
0005434760247	23318E	1393 383284	RUSLAN ALEKSEEV	{"email": "r-alekseev-031967@postgrespro.ru", "phone": "+70283637715"}
0005434760248	23318E	3060 562156	ARTUR KUZMIN	{"email": "kuzmin.artur111975@postgrespro.ru", "phone": "+70933595122"}
0005434760249	A95A81	8143 870021	SOFYA BELYAEVA	{"phone": "+70516004684"}
0005434760250	A95A81	7897 815998	VLADIMIR YAKOVLEV	{"phone": "+70507215723"}
0005434760251	BADDA0	5412 704562	NATALYA MELNIKOVA	{"email": "melnikova_natalya_101978@postgrespro.ru", "phone": "+70294176089"}
0005434760252	AA74E0	8500 596167	NADEZHDA MIRONOVA	{"phone": "+70775718009"}
0005434760253	AA74E0	9819 635196	ALBINA POPOVA	{"email": "popova_albina05101971@postgrespro.ru", "phone": "+70367063024"}
0005434760254	8FDBCF	4436 377275	VERA EGOROVA	{"phone": "+70039165487"}
0005434760255	8FDBCF	8593 370564	VLADIMIR NIKOLAEV	{"email": "v-nikolaev-28101968@postgrespro.ru", "phone": "+70280631485"}
0005434760256	4DEDB6	1136 225855	DARYA GUSEVA	{"phone": "+70930086223"}
0005434760257	4DEDB6	7933 501668	YULIYA FEDOROVA	{"email": "yuliya.fedorova-1965@postgrespro.ru", "phone": "+70573146129"}
0005434760258	9DE7E2	2571 569578	KIRILL KUZNECOV	{"email": "kuznecov_k.05071980@postgrespro.ru", "phone": "+70264726402"}
0005434760259	0F03E3	3955 420461	DENIS ALEKSANDROV	{"email": "aleksandrov-d-1958@postgrespro.ru", "phone": "+70628250986"}
0005434760260	A29968	5533 768682	VLADISLAV ALEKSANDROV	{"phone": "+70514439127"}
0005434760261	A29968	3107 957148	DARYA MASLOVA	{"phone": "+70872421981"}
0005434760262	6BFCDC	8587 446920	DENIS ROMANOV	{"email": "romanov-denis-1973@postgrespro.ru", "phone": "+70496300553"}
0005434760263	8C9ADC	9402 504980	YULIYA ARKHIPOVA	{"phone": "+70264433292"}
0005434760264	15D3A4	9208 932486	DENIS BORISOV	{"email": "dborisov_1986@postgrespro.ru", "phone": "+70350959206"}
0005434760265	15D3A4	8019 807507	IRINA POPOVA	{"phone": "+70790147736"}
0005434760266	D656F9	9495 487096	SERGEY ROMANOV	{"email": "sromanov_1975@postgrespro.ru", "phone": "+70597037909"}
0005434760267	098308	2710 693152	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov-1971@postgrespro.ru", "phone": "+70382574486"}
0005434821311	DA91D1	7451 974999	YURIY KUZNECOV	{"phone": "+70567560316"}
0005434821312	DA91D1	6318 639314	ALEKSANDR MOROZOV	{"phone": "+70000074409"}
0005434821313	2C61CE	8822 422824	LYUBOV MAKSIMOVA	{"phone": "+70175071880"}
0005434821314	CB0CBE	9439 134668	TATYANA IVANOVA	{"email": "ivanova_t_081969@postgrespro.ru", "phone": "+70877361778"}
0005434821315	E6D0F7	5005 078272	KIRILL ALEKSANDROV	{"phone": "+70430160591"}
0005434821316	E6D0F7	4675 422241	OLGA ABRAMOVA	{"email": "olgaabramova.1984@postgrespro.ru", "phone": "+70215679213"}
0005434821317	8C76B1	3891 340160	DMITRIY KULIKOV	{"phone": "+70436964609"}
0005434821318	7650B2	8610 511984	ARTEM FEDOTOV	{"email": "fedotov.artem_14021965@postgrespro.ru", "phone": "+70172590673"}
0005434821319	0F230D	3103 981561	OLGA EFREMOVA	{"email": "olgaefremova.071981@postgrespro.ru", "phone": "+70040346902"}
0005434821320	4438C0	9753 854717	GENNADIY VOLKOV	{"phone": "+70993917883"}
0005434821321	4438C0	4802 284547	OLEG STEPANOV	{"phone": "+70109327921"}
0005434821322	597D56	7298 819407	VLADIMIR KRASNOV	{"phone": "+70474274290"}
0005434821323	6E91F8	6687 606352	YURIY GUSEV	{"phone": "+70634559656"}
0005434821324	6E91F8	3287 716699	MIKHAIL DMITRIEV	{"email": "mikhail-dmitriev-1968@postgrespro.ru", "phone": "+70235595678"}
0005434821325	9CC6B8	1629 558472	ELENA BORISOVA	{"phone": "+70287904490"}
0005434821326	036756	2555 477720	ELENA SEMENOVA	{"email": "semenovae_081975@postgrespro.ru", "phone": "+70085239716"}
0005434821327	B5A1A3	5188 462785	NIKOLAY KRASNOV	{"phone": "+70241137948"}
0005434821328	B5A1A3	9308 329736	RAISA TROFIMOVA	{"email": "trofimova-raisa_10031959@postgrespro.ru", "phone": "+70522292283"}
0005434821329	80EF47	0576 199691	ANNA KONOVALOVA	{"email": "konovalovaanna1974@postgrespro.ru", "phone": "+70893592668"}
0005434821330	8EC66D	3717 252445	OLESYA LUKYANOVA	{"email": "o.lukyanova_17071983@postgrespro.ru", "phone": "+70326439377"}
0005434821331	8EC66D	1089 542880	ALEKSANDR POPOV	{"email": "popov-aleksandr.061968@postgrespro.ru", "phone": "+70930459611"}
0005434821332	3DA7EB	9877 289670	PETR SIDOROV	{"email": "sidorovp_22101972@postgrespro.ru", "phone": "+70367115071"}
0005434821333	3DA7EB	7251 534366	ALEKSEY BONDARENKO	{"email": "bondarenko-a101968@postgrespro.ru", "phone": "+70155361185"}
0005434821334	3DA7EB	7238 653520	NINA KOMAROVA	{"email": "komarova-nina1965@postgrespro.ru", "phone": "+70668226602"}
0005434821335	AF2DB5	9293 754689	SERGEY DMITRIEV	{"email": "s_dmitriev_031973@postgrespro.ru", "phone": "+70020037893"}
0005434821336	7B63E4	6921 177907	OLGA VASILEVA	{"email": "vasileva_o.11061968@postgrespro.ru", "phone": "+70455229840"}
0005434821337	661D9C	5819 665276	KRISTINA ZAYCEVA	{"email": "zaycevak.1986@postgrespro.ru", "phone": "+70731693719"}
0005434821338	661D9C	2952 053152	MARIYA MIRONOVA	{"email": "m.mironova.28121973@postgrespro.ru", "phone": "+70487764401"}
0005434821339	CD3CFE	1267 351219	ILYA KUDRYASHOV	{"email": "kudryashovi.031975@postgrespro.ru", "phone": "+70451198152"}
0005434821340	F7A401	3118 380322	VIKTOR ALEKSEEV	{"email": "alekseevv081971@postgrespro.ru", "phone": "+70089827058"}
0005434821341	B1876D	3962 145748	NATALYA LOGINOVA	{"email": "loginova_natalya-091973@postgrespro.ru", "phone": "+70209013904"}
0005434821342	C83D6B	1178 217920	OLGA MOROZOVA	{"email": "morozovao1964@postgrespro.ru", "phone": "+70181815390"}
0005434821343	095A6A	4018 796920	TATYANA ANTONOVA	{"phone": "+70401809906"}
0005434821344	FCFAA3	7702 720301	OLEG BONDARENKO	{"email": "o.bondarenko15021992@postgrespro.ru", "phone": "+70526749256"}
0005434821345	8AC998	9237 206210	ELENA LAZAREVA	{"email": "lazareva-e-25061981@postgrespro.ru", "phone": "+70857921885"}
0005434821346	8AC998	7836 351334	ZOYA ZOTOVA	{"email": "zotova-zoya-1963@postgrespro.ru", "phone": "+70586247218"}
0005434821347	9CFACF	6202 846882	MIKHAIL ZAKHAROV	{"phone": "+70923033732"}
0005434821348	B9B4FB	8651 983596	LYUBOV AKIMOVA	{"email": "akimova.l17071977@postgrespro.ru", "phone": "+70526253852"}
0005434821349	B9B4FB	7667 902752	ALEKSANDRA GAVRILOVA	{"email": "aleksandra_gavrilova-05101972@postgrespro.ru", "phone": "+70079851167"}
0005434821350	5DBB4F	9622 764720	ELENA IVANOVA	{"email": "ivanova_e1979@postgrespro.ru", "phone": "+70206155034"}
0005434821351	181423	3905 041338	MIKHAIL MIRONOV	{"phone": "+70343614076"}
0005434821352	134BA4	2225 093597	VIKTOR BELOV	{"email": "viktorbelov1961@postgrespro.ru", "phone": "+70124645802"}
0005434821353	576400	1109 685870	ANATOLIY SEMENOV	{"phone": "+70327498146"}
0005434821354	A64B46	0903 034749	PETR MAKAROV	{"phone": "+70946211274"}
0005434821355	9B6DBC	2041 478478	VALENTINA GORBUNOVA	{"phone": "+70476861558"}
0005434821356	FDDBDF	5074 883209	OLEG KAZAKOV	{"email": "kazakovo_081978@postgrespro.ru", "phone": "+70574797669"}
0005434821357	6517DC	2430 650248	YURIY SIDOROV	{"email": "y-sidorov111978@postgrespro.ru", "phone": "+70226458101"}
0005434821358	DAC071	6268 541289	VASILIY MOROZOV	{"phone": "+70843971267"}
0005434821359	716123	3313 828956	PAVEL MAKAROV	{"phone": "+70311575190"}
0005434821360	4D41A0	4950 328394	ZOYA TROFIMOVA	{"phone": "+70887035366"}
0005434821361	4D41A0	7719 088378	SERGEY DAVYDOV	{"phone": "+70466770804"}
0005434821362	5D51D1	9462 590955	ELVIRA KOZLOVA	{"email": "elvira_kozlova-1964@postgrespro.ru", "phone": "+70253755667"}
0005434821363	1478F2	6806 675092	NATALYA CHERNOVA	{"phone": "+70926508195"}
0005434821364	C7817C	7256 783177	OLGA KARPOVA	{"phone": "+70382872110"}
0005434821365	C7817C	2018 202873	MIKHAIL FROLOV	{"phone": "+70927866903"}
0005434821366	79759C	8418 391003	TATYANA KOLESNIKOVA	{"phone": "+70906330237"}
0005434821367	79759C	4434 763027	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-101968@postgrespro.ru", "phone": "+70721495835"}
0005434821368	79759C	6389 802250	SVETLANA MOROZOVA	{"email": "morozova_s1971@postgrespro.ru", "phone": "+70168803081"}
0005434821369	7636F0	1805 401847	TATYANA ISAEVA	{"phone": "+70008312661"}
0005434821370	DFF03F	1836 845526	ALEKSEY MELNIKOV	{"email": "aleksey-melnikov.071971@postgrespro.ru", "phone": "+70119216764"}
0005434821371	CDEEBE	1610 500547	GALINA BARANOVA	{"email": "baranova-galina-101977@postgrespro.ru", "phone": "+70228629378"}
0005434821372	5868AB	9881 691805	KSENIYA POPOVA	{"phone": "+70202696908"}
0005434821373	214588	9261 138968	DENIS KRASNOV	{"phone": "+70936521292"}
0005434821374	214588	9137 610130	IRINA ORLOVA	{"email": "orlova.i08121968@postgrespro.ru", "phone": "+70059269164"}
0005434821375	6BFA01	6318 025391	OLGA GORBUNOVA	{"email": "gorbunova_olga-1975@postgrespro.ru", "phone": "+70476244756"}
0005434821376	EFF56B	4586 433484	SVETLANA ZAKHAROVA	{"phone": "+70236082804"}
0005434821377	350308	0832 459280	YULIYA ZHURAVLEVA	{"phone": "+70036876072"}
0005434821378	AA9432	8914 256829	MARIYA ERMAKOVA	{"email": "m-ermakova.071985@postgrespro.ru", "phone": "+70151312602"}
0005434821379	E4554A	8940 034388	NIKOLAY ZAYCEV	{"phone": "+70739688802"}
0005434821380	E4554A	6183 386108	VIKTORIYA NAZAROVA	{"email": "vnazarova.121972@postgrespro.ru", "phone": "+70199182558"}
0005434821381	F3956A	0242 771988	ANNA KUZNECOVA	{"phone": "+70817085340"}
0005434821382	C0CEB4	6091 689578	NADEZHDA DENISOVA	{"email": "n-denisova.05031974@postgrespro.ru", "phone": "+70665682997"}
0005434821383	C0CEB4	0213 065342	SERGEY KUZNECOV	{"email": "sergey.kuznecov-1972@postgrespro.ru", "phone": "+70600399149"}
0005434821384	693247	1132 557674	DENIS KARPOV	{"email": "karpov-d-15111974@postgrespro.ru", "phone": "+70538694657"}
0005434821385	693247	1243 528046	GALINA YAKOVLEVA	{"email": "gyakovleva.1984@postgrespro.ru", "phone": "+70993076386"}
0005434821386	7AB130	1791 265064	OLGA MATVEEVA	{"email": "matveeva-o-25041976@postgrespro.ru", "phone": "+70153819295"}
0005434821387	E15A0E	4894 914113	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.1974@postgrespro.ru", "phone": "+70301092389"}
0005434821388	49E76B	6854 383119	EKATERINA KAZAKOVA	{"email": "kazakovae.25031980@postgrespro.ru", "phone": "+70446658437"}
0005434821389	49E76B	0804 206140	GRIGORIY IVANOV	{"phone": "+70713822347"}
0005434821390	BED436	9981 541184	VALENTINA FROLOVA	{"email": "frolova-valentina1959@postgrespro.ru", "phone": "+70479146088"}
0005434821391	BED436	2381 744706	LYUDMILA SCHERBAKOVA	{"email": "scherbakova_lyudmila-1976@postgrespro.ru", "phone": "+70986371309"}
0005434821392	F75257	5513 934800	IRINA FEDOROVA	{"phone": "+70931392921"}
0005434821393	780B6A	1889 237530	EMIL BELOV	{"phone": "+70038668216"}
0005434821394	780B6A	4330 872176	IRINA IVANOVA	{"phone": "+70778882199"}
0005434821395	780B6A	1790 747720	ALEKSEY VOROBEV	{"phone": "+70062653999"}
0005434821396	D5CB8C	6834 522617	TATYANA ILINA	{"email": "t-ilina.1973@postgrespro.ru", "phone": "+70101785835"}
0005434821397	ED37F0	7232 418392	LYUBOV KAZAKOVA	{"phone": "+70494416925"}
0005434821398	49C104	6685 092149	GALINA NIKITINA	{"email": "galinanikitina_24011982@postgrespro.ru", "phone": "+70648771952"}
0005434821399	49C104	1448 757253	SERGEY BORISOV	{"email": "sergey-borisov.06041969@postgrespro.ru", "phone": "+70312987216"}
0005434821400	D53284	0205 832476	SERGEY KUZNECOV	{"phone": "+70854835836"}
0005434821401	D53284	8514 512962	YURIY ANTONOV	{"email": "y_antonov-1976@postgrespro.ru", "phone": "+70560501014"}
0005434821402	5C9A4E	5448 806091	OKSANA ALEKSANDROVA	{"email": "oksana-aleksandrova.02071962@postgrespro.ru", "phone": "+70833795132"}
0005434821403	5C9A4E	8223 096866	SERGEY SEMENOV	{"email": "s-semenov-13011975@postgrespro.ru", "phone": "+70243678820"}
0005434821404	9E37A8	8641 274759	NATALYA DAVYDOVA	{"email": "davydova.n_1971@postgrespro.ru", "phone": "+70726266962"}
0005434821405	1911D6	9196 126711	ANATOLIY NOVIKOV	{"email": "novikova_011976@postgrespro.ru", "phone": "+70306499522"}
0005434821406	1911D6	2255 459645	ALBINA SOKOLOVA	{"email": "a-sokolova.24111967@postgrespro.ru", "phone": "+70597999108"}
0005434821407	FF0058	3806 472267	MARIYA FROLOVA	{"email": "frolova.m_23021970@postgrespro.ru", "phone": "+70559013023"}
0005434821408	1A40A9	9457 024407	EVGENIYA DAVYDOVA	{"email": "davydovae.03091966@postgrespro.ru", "phone": "+70944119453"}
0005434821409	868A64	7451 438207	SERGEY GUSEV	{"phone": "+70412553697"}
0005434821410	868A64	0188 089350	VLADIMIR ZHURAVLEV	{"phone": "+70933879604"}
0005434821411	543C45	9106 874581	MIKHAIL SCHERBAKOV	{"phone": "+70059147037"}
0005434821412	543C45	1488 372305	MARINA MAKAROVA	{"phone": "+70627417152"}
0005434821413	9C56FE	5785 675368	ANATOLIY SAVELEV	{"phone": "+70653308754"}
0005434821414	68FEE4	5455 433477	KRISTINA FEDOROVA	{"email": "k.fedorova-051970@postgrespro.ru", "phone": "+70521958110"}
0005434821415	7A0409	0543 114111	VIKTOR BORISOV	{"email": "vborisov_011982@postgrespro.ru", "phone": "+70920376127"}
0005434821416	1ACFD6	2210 251060	ROMAN KOZLOV	{"phone": "+70187262476"}
0005434821417	294BA7	4540 133974	EVDOKIYA AFANASEVA	{"email": "afanaseva.e-031969@postgrespro.ru", "phone": "+70603941109"}
0005434821418	7A05ED	8754 461411	DMITRIY KUZMIN	{"phone": "+70734142716"}
0005434821419	7A05ED	4076 571318	NINA SEMENOVA	{"phone": "+70177893085"}
0005434821420	5D6FB3	0508 088248	MARIYA KAZAKOVA	{"email": "m.kazakova.101972@postgrespro.ru", "phone": "+70537706218"}
0005434821421	EAD361	1738 238956	ELENA SEMENOVA	{"phone": "+70120414575"}
0005434821422	FF8822	4621 901103	YULIYA IVANOVA	{"phone": "+70549300022"}
0005434821423	FF8822	9712 279356	ELENA YAKOVLEVA	{"phone": "+70939842514"}
0005434821424	FF4C8D	2753 919952	EVGENIY GRIGOREV	{"email": "grigorev-evgeniy-1972@postgrespro.ru", "phone": "+70746659494"}
0005434821425	069070	9554 047891	NATALYA NAZAROVA	{"email": "natalya-nazarova.121988@postgrespro.ru", "phone": "+70746485967"}
0005434821426	715A88	7014 089929	STANISLAV TIMOFEEV	{"email": "stimofeev021981@postgrespro.ru", "phone": "+70818414196"}
0005434821427	2AFED9	6552 053852	VLADISLAV KUDRYASHOV	{"email": "kudryashovvladislav-28011972@postgrespro.ru", "phone": "+70099186706"}
0005434821428	2AFED9	6960 648091	ANNA SOKOLOVA	{"phone": "+70882110607"}
0005434821429	5FEFFA	4319 987352	VIKTOR KONOVALOV	{"email": "viktorkonovalov1964@postgrespro.ru", "phone": "+70980993152"}
0005434821430	5FEFFA	2685 664584	VLADIMIR CHERNOV	{"email": "v.chernov19031974@postgrespro.ru", "phone": "+70612343061"}
0005434821431	5FEFFA	7631 203064	VIKTOR BORISOV	{"email": "borisovviktor.1971@postgrespro.ru", "phone": "+70774978344"}
0005434821432	93048D	9887 882709	IRINA SMIRNOVA	{"email": "i-smirnova-1982@postgrespro.ru", "phone": "+70612915849"}
0005434821433	F14B7C	1906 960282	KIRILL IVANOV	{"phone": "+70478954541"}
0005434821434	F14B7C	7633 817441	GALINA BELYAEVA	{"email": "belyaeva_galina.1970@postgrespro.ru", "phone": "+70067522991"}
0005434821435	27AFAF	4419 663968	MARINA KARPOVA	{"phone": "+70688033143"}
0005434821436	27AFAF	1874 756066	DMITRIY RODIONOV	{"phone": "+70683645333"}
0005434821437	27AFAF	1079 981572	BORIS ORLOV	{"phone": "+70443475982"}
0005434821438	9D9435	5588 427939	SERGEY PETROV	{"phone": "+70492939772"}
0005434821439	69D392	7024 687989	NATALYA KUZNECOVA	{"phone": "+70709846870"}
0005434821440	EB04E9	8661 509863	NATALIYA YAKOVLEVA	{"phone": "+70406007640"}
0005434821441	5E9DF6	2824 244222	ALEKSANDR IVANOV	{"phone": "+70684015882"}
0005434821442	5E9DF6	2589 165918	VALENTINA MOROZOVA	{"email": "morozova_valentina.06091960@postgrespro.ru", "phone": "+70749872636"}
0005434821443	C1DD2A	0760 081680	OLEG DMITRIEV	{"email": "olegdmitriev041978@postgrespro.ru", "phone": "+70683289763"}
0005434821444	7E8071	7130 031078	NURIYA FROLOVA	{"email": "frolovanuriya.091965@postgrespro.ru", "phone": "+70777707718"}
0005434821445	53FECA	7042 184651	NINA NOVIKOVA	{"email": "novikovan.1978@postgrespro.ru", "phone": "+70575326541"}
0005434821446	634574	4531 501364	SERGEY YAKOVLEV	{"phone": "+70565558861"}
0005434821447	4F51B4	2366 408959	LYUBOV ORLOVA	{"email": "lyubov.orlova1973@postgrespro.ru", "phone": "+70164331265"}
0005434821448	835102	3503 866026	VLADIMIR SOROKIN	{"phone": "+70445317727"}
0005434821449	835102	8931 020593	SVETLANA FROLOVA	{"email": "svetlana-frolova_1964@postgrespro.ru", "phone": "+70580144351"}
0005434821450	835102	1579 506203	SERGEY ANTONOV	{"email": "santonov-29111967@postgrespro.ru", "phone": "+70996465802"}
0005434821451	835102	1186 851973	EKATERINA ZOTOVA	{"phone": "+70950835650"}
0005434821452	B2E258	8896 955425	EKATERINA MAKSIMOVA	{"email": "ekaterinamaksimova-24051974@postgrespro.ru", "phone": "+70341535852"}
0005434821453	AB2961	1207 659400	NADEZHDA ZHUKOVA	{"email": "zhukova.n_051974@postgrespro.ru", "phone": "+70555503304"}
0005434821454	819B45	3801 391046	ANDREY POPOV	{"email": "popovandrey_101975@postgrespro.ru", "phone": "+70932123534"}
0005434821455	819B45	7903 486940	ZOYA SOLOVEVA	{"email": "soloveva-zoya.06021965@postgrespro.ru", "phone": "+70366579321"}
0005434821456	819B45	4360 370709	TATYANA KARPOVA	{"email": "karpova-tatyana1961@postgrespro.ru", "phone": "+70999199365"}
0005434821457	690F03	4386 227730	ELENA VOLKOVA	{"email": "volkova.e021977@postgrespro.ru", "phone": "+70432700681"}
0005434821458	690F03	6688 372098	EDUARD NIKOLAEV	{"email": "nikolaeve_061971@postgrespro.ru", "phone": "+70930622757"}
0005434821459	9242D3	9790 708196	ELENA KUZMINA	{"email": "elena.kuzmina_101975@postgrespro.ru", "phone": "+70263651924"}
0005434821460	9B8EC9	3826 389073	PAVEL KULIKOV	{"phone": "+70722280123"}
0005434821461	B26D9F	1728 663331	NATALIYA KISELEVA	{"email": "kiseleva_n1972@postgrespro.ru", "phone": "+70178871578"}
0005434821462	AE34D9	1003 287953	VERA PAVLOVA	{"phone": "+70318835385"}
0005434821463	AE34D9	7661 367393	NATALYA KULIKOVA	{"email": "natalya.kulikova-021974@postgrespro.ru", "phone": "+70006191225"}
0005434821464	66D28C	6461 884429	IRINA YUDINA	{"phone": "+70774312045"}
0005434821465	49B7C1	4972 197729	DMITRIY SOKOLOV	{"email": "sokolovdmitriy.071962@postgrespro.ru", "phone": "+70790190341"}
0005434821466	49B7C1	0169 338808	LIDIYA KOROLEVA	{"email": "koroleva-lidiya-1961@postgrespro.ru", "phone": "+70284540404"}
0005434821467	9756CF	7941 922636	NATALYA SOROKINA	{"email": "sorokina_n-051969@postgrespro.ru", "phone": "+70103051382"}
0005434821468	5977AC	3841 678012	SERGEY MOISEEV	{"email": "moiseev.s-051962@postgrespro.ru", "phone": "+70448382402"}
0005434821469	A230D7	9558 427083	SERGEY TIMOFEEV	{"phone": "+70226625830"}
0005434821470	D6B609	6977 887861	ELENA KUZNECOVA	{"phone": "+70893644555"}
0005434821471	D6B609	8063 780147	KLAVDIYA KOMAROVA	{"phone": "+70314961760"}
0005434821472	6C4C22	5830 270148	OLGA POPOVA	{"email": "olga-popova_08091971@postgrespro.ru", "phone": "+70310706254"}
0005434821473	6C4C22	5810 066357	IVAN GAVRILOV	{"phone": "+70041676461"}
0005434821474	48D184	2089 420171	ANATOLIY KOROLEV	{"email": "koroleva_1976@postgrespro.ru", "phone": "+70133188414"}
0005434821475	CFCDEA	6669 026144	TAISIYA SOLOVEVA	{"phone": "+70779435841"}
0005434821476	E394F9	0592 915830	NADEZHDA POPOVA	{"phone": "+70595859183"}
0005434821477	2AD9E7	0407 590776	GENNADIY KRASNOV	{"phone": "+70632185672"}
0005434821478	4C4FCB	8118 829955	VLADIMIR KOZLOV	{"email": "v-kozlov-061960@postgrespro.ru", "phone": "+70844651859"}
0005434821479	4C4FCB	2086 616523	ANATOLIY VLASOV	{"phone": "+70698879178"}
0005434821480	7B210F	8522 034277	LYUDMILA ZAKHAROVA	{"email": "zakharova_lyudmila_061976@postgrespro.ru", "phone": "+70131157868"}
0005434821481	7B210F	7019 798981	VALENTIN SOKOLOV	{"email": "sokolov.valentin27101972@postgrespro.ru", "phone": "+70904572691"}
0005434821482	7448A5	2359 057748	ELIZAVETA POLYAKOVA	{"email": "e.polyakova1968@postgrespro.ru", "phone": "+70203097672"}
0005434821483	D14372	7735 203384	ANNA GAVRILOVA	{"phone": "+70504228778"}
0005434821484	D14372	6378 181715	ANATOLIY ALEKSANDROV	{"phone": "+70822485106"}
0005434821485	9B0B89	1406 300589	ALEKSANDR NAZAROV	{"phone": "+70071439174"}
0005434821486	00F553	1751 971227	VYACHESLAV NIKOLAEV	{"phone": "+70198023158"}
0005434821487	B26616	1122 676467	VALERIYA POPOVA	{"email": "v-popova_091996@postgrespro.ru", "phone": "+70257571239"}
0005434821488	B26616	6721 772972	IGOR DAVYDOV	{"email": "davydov-igor051955@postgrespro.ru", "phone": "+70022075461"}
0005434821489	B26616	3983 497891	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova-1971@postgrespro.ru", "phone": "+70382425454"}
0005434821490	2E0BCC	5446 349909	DMITRIY KARPOV	{"email": "d.karpov-041971@postgrespro.ru", "phone": "+70400143947"}
0005434821491	3A4F4D	5000 031020	DMITRIY MIKHAYLOV	{"phone": "+70035299263"}
0005434821492	9E4CCF	0122 666827	ALISHER MELNIKOV	{"phone": "+70310232104"}
0005434821493	D16CB9	0478 771203	ANDREY SIDOROV	{"phone": "+70167720563"}
0005434821494	B43AF2	8389 779184	RUSLAN KOROLEV	{"phone": "+70780852732"}
0005434821495	2B3AD2	0241 624936	TATYANA KOROLEVA	{"email": "korolevatatyana-061960@postgrespro.ru", "phone": "+70219618731"}
0005434821496	B0DEEC	3532 225393	IRINA CHERNOVA	{"phone": "+70148102208"}
0005434821497	6C7EF3	7417 172227	IGOR EGOROV	{"phone": "+70814989371"}
0005434821498	2032C4	4805 328747	SVETLANA ZAYCEVA	{"email": "zayceva-svetlana061984@postgrespro.ru", "phone": "+70752854724"}
0005434821499	F58478	1296 560439	TAMARA NIKOLAEVA	{"phone": "+70784117809"}
0005434821500	FF941F	7439 266543	IRINA DENISOVA	{"phone": "+70933670044"}
0005434821501	21CC5E	0239 349450	NATALYA SAVELEVA	{"phone": "+70992334529"}
0005434821502	21CC5E	9666 230817	EKATERINA SIDOROVA	{"phone": "+70102733422"}
0005434821503	4BF768	1829 500609	ELENA NIKOLAEVA	{"email": "nikolaeva_e-1968@postgrespro.ru", "phone": "+70758435241"}
0005434821504	9E6B58	2280 836555	VIKTOR KUZNECOV	{"email": "v.kuznecov-061967@postgrespro.ru", "phone": "+70558496564"}
0005434821505	1FFE33	1945 319952	IRINA KOROLEVA	{"email": "koroleva.irina-29061975@postgrespro.ru", "phone": "+70134099145"}
0005434821506	1FFE33	2566 963452	ARTEM OSIPOV	{"email": "osipov-artem_041983@postgrespro.ru", "phone": "+70737937699"}
0005434821507	1FFE33	7113 480643	RINAT MAKSIMOV	{"email": "maksimov.rinat-1973@postgrespro.ru", "phone": "+70281948096"}
0005434821508	9C2687	7635 789529	ALISA IVANOVA	{"email": "ivanova_a051981@postgrespro.ru", "phone": "+70537856317"}
0005434821509	D99BCC	9512 248157	ELENA SMIRNOVA	{"email": "smirnova.e_061984@postgrespro.ru", "phone": "+70532125709"}
0005434821510	D99BCC	6561 693542	SERGEY MAKAROV	{"phone": "+70933552511"}
0005434821511	D99BCC	7479 350580	ALEKSANDR MOISEEV	{"email": "moiseev.aleksandr_1980@postgrespro.ru", "phone": "+70118919843"}
0005434821512	22AC6D	2950 195279	RAISA OSIPOVA	{"phone": "+70238990994"}
0005434821513	22AC6D	9062 749464	OLGA NIKOLAEVA	{"email": "olganikolaeva_1976@postgrespro.ru", "phone": "+70222271033"}
0005434821514	5CCE21	4787 695150	ANDREY VOROBEV	{"phone": "+70790596263"}
0005434821515	55293E	7148 569301	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir.071983@postgrespro.ru", "phone": "+70346181952"}
0005434821516	B57B2B	8849 017669	ANATOLIY STEPANOV	{"email": "a_stepanov.14011974@postgrespro.ru", "phone": "+70420546600"}
0005434821517	88BC3F	6990 133616	ANDREY ALEKSANDROV	{"email": "aleksandrov-andrey.041971@postgrespro.ru", "phone": "+70419164773"}
0005434821518	9A85D5	7104 671651	ZUKHRA PETROVA	{"email": "petrova-zukhra.1976@postgrespro.ru", "phone": "+70971315347"}
0005434821519	3B4CB7	2951 884973	NATALYA BORISOVA	{"email": "borisova.n081976@postgrespro.ru", "phone": "+70700240630"}
0005434821520	3B4CB7	9450 725822	LARISA NIKOLAEVA	{"email": "nikolaeva.l121976@postgrespro.ru", "phone": "+70011980608"}
0005434821521	FB1D48	6307 645975	VALENTIN NIKITIN	{"email": "nikitin_v_121980@postgrespro.ru", "phone": "+70358135443"}
0005434821522	FB1D48	2892 130264	OLGA BELYAEVA	{"email": "belyaeva_o_081973@postgrespro.ru", "phone": "+70188567235"}
0005434821523	D62314	5743 562767	ALEKSANDRA ANDREEVA	{"email": "aandreeva_1965@postgrespro.ru", "phone": "+70936221355"}
0005434821524	0085DF	1769 139850	YAROSLAV KULIKOV	{"phone": "+70852537854"}
0005434821525	0085DF	7023 042766	TAMARA RYABOVA	{"email": "tamara_ryabova.14021963@postgrespro.ru", "phone": "+70719048615"}
0005434821526	BA0BB3	5451 112034	RAISA MALYSHEVA	{"phone": "+70358993948"}
0005434821527	5B43AD	1565 564536	LEONID BELOV	{"email": "belov.l.02051964@postgrespro.ru", "phone": "+70529937166"}
0005434821528	FA3AF5	5786 000001	ARTEM TIMOFEEV	{"email": "a-timofeev071965@postgrespro.ru", "phone": "+70881364089"}
0005434821529	57AEC7	3618 508454	VERONIKA EGOROVA	{"phone": "+70546970029"}
0005434821530	57AEC7	9164 933493	TATYANA VOLKOVA	{"phone": "+70358620247"}
0005434821531	9F1F4A	0152 528164	ALEKSANDR GUSEV	{"email": "aleksandr-gusev.061965@postgrespro.ru", "phone": "+70153563785"}
0005434821532	55A734	8704 270384	ANATOLIY PETROV	{"phone": "+70497268450"}
0005434821533	CB62A7	5546 256236	MARIYA MOISEEVA	{"phone": "+70394191557"}
0005434821534	0324D7	8344 297059	SERGEY KUZNECOV	{"phone": "+70941222606"}
0005434821535	0324D7	4809 442583	GENNADIY NIKOLAEV	{"phone": "+70577110126"}
0005434821536	B0D8C8	1886 930570	MARIYA ANDREEVA	{"email": "mariya_andreeva_061961@postgrespro.ru", "phone": "+70379704418"}
0005434821537	B0D8C8	7512 629436	ANATOLIY OSIPOV	{"phone": "+70956780062"}
0005434821538	62949E	8192 759300	ALEKSANDR STEPANOV	{"phone": "+70595489405"}
0005434821539	C5EC6F	8300 958249	NATALYA ARKHIPOVA	{"phone": "+70322749887"}
0005434821540	C5EC6F	6111 697758	ROMAN KUZNECOV	{"phone": "+70941323519"}
0005434821541	B3F57B	7383 426811	EGOR FOMIN	{"phone": "+70607105919"}
0005434821542	C1DA47	0678 500868	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_14111960@postgrespro.ru", "phone": "+70672862105"}
0005434821543	C1DA47	8970 980406	LIDIYA ROMANOVA	{"email": "romanova_lidiya.1978@postgrespro.ru", "phone": "+70018271146"}
0005434821544	EBA592	9039 182978	SERGEY OSIPOV	{"email": "s_osipov-081969@postgrespro.ru", "phone": "+70938909261"}
0005434821545	7FAB58	2235 753053	KIRILL VOROBEV	{"phone": "+70800334643"}
0005434821546	2A0111	2695 287033	SERGEY ALEKSEEV	{"phone": "+70638566575"}
0005434821547	44FB3B	3644 413977	ANDREY OSIPOV	{"email": "osipovandrey041971@postgrespro.ru", "phone": "+70964245651"}
0005434821548	44FB3B	9755 091140	TAISIYA MELNIKOVA	{"email": "t.melnikova-081983@postgrespro.ru", "phone": "+70148997252"}
0005434821549	69197E	4562 011437	OLGA KALININA	{"phone": "+70648007421"}
0005434821550	A85740	8559 090750	NINA LOGINOVA	{"phone": "+70063379542"}
0005434821551	05E45B	0541 634673	ANASTASIYA ABRAMOVA	{"email": "abramova_anastasiya.1973@postgrespro.ru", "phone": "+70059096780"}
0005434821552	05E45B	0018 817136	DMITRIY IVANOV	{"email": "d-ivanov.20041976@postgrespro.ru", "phone": "+70744869850"}
0005434821553	F47669	7368 321302	EVGENIY RODIONOV	{"email": "rodionov_evgeniy28041981@postgrespro.ru", "phone": "+70625917266"}
0005434821554	E57225	4585 730201	ELENA MIKHAYLOVA	{"phone": "+70768824957"}
0005434821555	49D07A	8030 871638	IGOR NIKOLAEV	{"email": "igor-nikolaev-08111971@postgrespro.ru", "phone": "+70155214799"}
0005434821556	73DAAA	0712 177643	ALEKSANDR SAVELEV	{"email": "savelev_a-05061977@postgrespro.ru", "phone": "+70532213323"}
0005434821557	90258D	2109 235891	SERGEY KRASNOV	{"phone": "+70738689657"}
0005434821558	8BC917	2870 293704	VADIM TIKHONOV	{"phone": "+70107697493"}
0005434821559	2B4E24	2004 096063	EKATERINA GAVRILOVA	{"email": "gavrilova_e.1956@postgrespro.ru", "phone": "+70112210919"}
0005434821560	2B4E24	9724 152839	ANDREY VASILEV	{"phone": "+70804124243"}
0005434821561	BDF738	4478 492846	RAMIL KUZNECOV	{"email": "r_kuznecov.10091979@postgrespro.ru", "phone": "+70175317310"}
0005434821562	BDF738	8831 636858	MARINA MAKAROVA	{"email": "makarova-m.091964@postgrespro.ru", "phone": "+70893898400"}
0005434821563	F17478	3772 672622	TATYANA MAKAROVA	{"email": "makarova.t041968@postgrespro.ru", "phone": "+70024297421"}
0005434821564	075070	3546 024220	VASILIY FROLOV	{"email": "frolov_vasiliy.101972@postgrespro.ru", "phone": "+70582416036"}
0005434821565	6DD6F6	6778 162197	EGOR KUDRYASHOV	{"email": "kudryashove-1972@postgrespro.ru", "phone": "+70064997667"}
0005434821566	6DD6F6	0394 480518	DARYA SEMENOVA	{"email": "darya.semenova.091977@postgrespro.ru", "phone": "+70128309316"}
0005434821567	052D81	0547 696220	VALENTINA SIDOROVA	{"email": "v.sidorova031973@postgrespro.ru", "phone": "+70018225388"}
0005434821568	91440C	7423 106186	NATALYA ALEKSANDROVA	{"email": "natalya_aleksandrova.09081970@postgrespro.ru", "phone": "+70258113444"}
0005434821569	9D2C59	0331 270873	IRINA FOMINA	{"phone": "+70287145116"}
0005434821570	9D2C59	9304 802852	ALEKSANDRA KOZLOVA	{"email": "kozlova-a.27041967@postgrespro.ru", "phone": "+70382461397"}
0005434821571	4E17FF	2050 464768	VLADIMIR ISAEV	{"phone": "+70194582828"}
0005434821572	4E17FF	2477 398125	OLEG SAVELEV	{"email": "savelev_oleg.17121966@postgrespro.ru", "phone": "+70565383564"}
0005434821573	625FFA	6931 970727	BOGDAN SOROKIN	{"email": "bsorokin_101969@postgrespro.ru", "phone": "+70512073562"}
0005434821574	ADF6F8	0791 609576	VERA DENISOVA	{"phone": "+70368691138"}
0005434821575	ADF6F8	7563 425814	ARTEM ISAEV	{"email": "aisaev.02071970@postgrespro.ru", "phone": "+70654364747"}
0005434821576	ADF6F8	0805 622367	EVGENIY PETROV	{"email": "e_petrov_041980@postgrespro.ru", "phone": "+70452860816"}
0005434821577	2479F9	9250 532327	ALEKSEY SOKOLOV	{"email": "aleksey_sokolov_22101980@postgrespro.ru", "phone": "+70773524172"}
0005434821578	3FD1A7	9905 810014	VYACHESLAV MOROZOV	{"phone": "+70727575074"}
0005434821579	C038DE	3842 568961	VIOLETTA KOVALEVA	{"phone": "+70957551959"}
0005434821580	D571CD	6652 297611	VLADIMIR PETROV	{"email": "petrov.vladimir.071961@postgrespro.ru", "phone": "+70581947308"}
0005434821581	7788D6	2165 727568	KIRILL KOZLOV	{"email": "kozlov-k031980@postgrespro.ru", "phone": "+70367106483"}
0005434821582	E9B48C	5978 141769	VLADIMIR OSIPOV	{"email": "vladimirosipov121973@postgrespro.ru", "phone": "+70473327627"}
0005434821862	E7E2A0	7723 156135	OLGA NOVIKOVA	{"phone": "+70341384593"}
0005434821583	D6BF46	2951 766361	VLADIMIR ROMANOV	{"email": "v-romanov-01021965@postgrespro.ru", "phone": "+70541267737"}
0005434821584	D6BF46	0115 200080	OLGA VASILEVA	{"email": "olga_vasileva.021959@postgrespro.ru", "phone": "+70564533579"}
0005434821585	75B9E3	4258 277510	IRINA SERGEEVA	{"email": "irinasergeeva.081980@postgrespro.ru", "phone": "+70429602286"}
0005434821586	75B9E3	0270 471007	SERGEY ZAKHAROV	{"phone": "+70148859139"}
0005434821587	BFC3D1	8462 555338	IGOR MATVEEV	{"phone": "+70896101617"}
0005434821588	B7A261	7438 617672	ELENA MOROZOVA	{"phone": "+70367491963"}
0005434821589	935DBD	2523 165318	VIKTOR MELNIKOV	{"email": "viktor.melnikov.091982@postgrespro.ru", "phone": "+70069453856"}
0005434821590	7E1B42	6485 144245	ANTON SIDOROV	{"email": "sidorov.anton041981@postgrespro.ru", "phone": "+70806856383"}
0005434821591	7DB7B2	1992 291105	VALERIY GAVRILOV	{"email": "gavrilov.v.04121972@postgrespro.ru", "phone": "+70034469734"}
0005434821592	41D78C	5908 412214	ALENA PETROVA	{"email": "a-petrova_07041980@postgrespro.ru", "phone": "+70769550526"}
0005434821593	EA8CD1	6230 760118	ALEKSANDR FILIPPOV	{"email": "filippova-101966@postgrespro.ru", "phone": "+70141345158"}
0005434821594	3FB7A2	9329 075704	ALEKSANDRA YAKOVLEVA	{"email": "yakovleva-a_091983@postgrespro.ru", "phone": "+70978610871"}
0005434821595	3FB7A2	5038 481279	NELLI MOROZOVA	{"phone": "+70416539417"}
0005434821596	3724F7	7402 925792	STANISLAV MELNIKOV	{"email": "s_melnikov1966@postgrespro.ru", "phone": "+70401146411"}
0005434821597	88B5E6	7155 883805	DARYA POLYAKOVA	{"phone": "+70609512353"}
0005434821598	C0365C	8860 418354	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr-111962@postgrespro.ru", "phone": "+70771858670"}
0005434821599	8C7F4A	5703 455970	NIKOLAY TIKHONOV	{"phone": "+70194979716"}
0005434821600	7CE768	2419 319690	ANATOLIY KUZNECOV	{"phone": "+70688648192"}
0005434821601	A303DF	1715 058744	MARINA ROMANOVA	{"phone": "+70360810118"}
0005434821602	AE350E	6647 402961	IGOR IVANOV	{"email": "ivanovi_021958@postgrespro.ru", "phone": "+70340713332"}
0005434821603	3E09A2	7061 756468	VIKTOR DAVYDOV	{"email": "viktordavydov_1968@postgrespro.ru", "phone": "+70067837835"}
0005434821604	3E09A2	1122 916459	MARIYA KUZMINA	{"phone": "+70142475626"}
0005434821605	5A9EB0	0148 792694	NAILYA NAUMOVA	{"email": "naumova_nailya.04021964@postgrespro.ru", "phone": "+70016544545"}
0005434821606	5A9EB0	7235 370538	VYACHESLAV KAZAKOV	{"email": "v-kazakov.13111970@postgrespro.ru", "phone": "+70299138923"}
0005434821607	DBD004	7015 967197	IGOR MOISEEV	{"email": "moiseev.igor.11021980@postgrespro.ru", "phone": "+70953309370"}
0005434821608	39336D	8497 334841	ALENA KAZAKOVA	{"email": "alena_kazakova051961@postgrespro.ru", "phone": "+70826504137"}
0005434821609	39336D	0210 845033	DANIIL SHEVCHENKO	{"phone": "+70482264468"}
0005434821610	9B7E51	3248 419407	VLADIMIR FROLOV	{"phone": "+70960268185"}
0005434821611	9B7E51	3403 682468	ANDREY ROMANOV	{"phone": "+70229865145"}
0005434821612	9B7E51	7836 995989	IVAN NOVIKOV	{"email": "novikov.i.28041979@postgrespro.ru", "phone": "+70979193831"}
0005434821613	CC58B1	8998 337578	MIKHAIL SMIRNOV	{"email": "smirnov_mikhail_1959@postgrespro.ru", "phone": "+70350171756"}
0005434821614	A36954	3735 370272	DMITRIY DAVYDOV	{"phone": "+70523816096"}
0005434821615	A36954	5125 913047	TATYANA STEPANOVA	{"phone": "+70151723986"}
0005434821616	47D064	3233 256468	DANILA NIKITIN	{"email": "nikitin_danila_1974@postgrespro.ru", "phone": "+70986690919"}
0005434821617	94131E	2967 531880	DANIL GORBUNOV	{"email": "gorbunov_d111981@postgrespro.ru", "phone": "+70392379068"}
0005434821618	9565BF	8729 127035	YURIY FEDOROV	{"email": "yuriy.fedorov1975@postgrespro.ru", "phone": "+70427876097"}
0005434821619	D3A470	2797 600493	ALEKSANDRA SMIRNOVA	{"email": "smirnovaaleksandra.011972@postgrespro.ru", "phone": "+70395676964"}
0005434821620	C65547	4048 399615	STANISLAV IVANOV	{"phone": "+70339196512"}
0005434821621	F2D827	2186 697666	NIKOLAY STEPANOV	{"email": "n.stepanov_111976@postgrespro.ru", "phone": "+70410557758"}
0005434821622	EF4EF1	7231 221220	GENNADIY MAKAROV	{"email": "makarovgennadiy071973@postgrespro.ru", "phone": "+70544355994"}
0005434821623	D73CFE	3337 209839	NADEZHDA MEDVEDEVA	{"email": "n_medvedeva-1971@postgrespro.ru", "phone": "+70998541091"}
0005434821624	D73CFE	8920 764379	ALLA FILIPPOVA	{"email": "filippova_a-011979@postgrespro.ru", "phone": "+70046367627"}
0005434821625	F11EEE	9240 798281	SVETLANA MALYSHEVA	{"email": "s-malysheva_22041977@postgrespro.ru", "phone": "+70467102776"}
0005434821626	27F935	8618 004365	VLADIMIR AFANASEV	{"email": "afanasev-vladimir_1975@postgrespro.ru", "phone": "+70118193505"}
0005434821627	2B3361	9465 919925	SERGEY VOROBEV	{"email": "sergey.vorobev1969@postgrespro.ru", "phone": "+70992721133"}
0005434821628	E8859E	1625 763443	ANNA KONDRATEVA	{"email": "kondrateva_a-1964@postgrespro.ru", "phone": "+70475886482"}
0005434821629	A3094C	4781 087089	MAKSIM ANDREEV	{"phone": "+70002186365"}
0005434821630	A3094C	0515 512296	TATYANA SMIRNOVA	{"email": "smirnova_tatyana-1971@postgrespro.ru", "phone": "+70469278663"}
0005434821631	262D93	6965 726920	TAMARA EGOROVA	{"email": "egorovat_1976@postgrespro.ru", "phone": "+70125724579"}
0005434821632	C020F5	6401 918348	ALEVTINA KUZMINA	{"email": "kuzmina.alevtina_091967@postgrespro.ru", "phone": "+70865324239"}
0005434821633	E6E013	1065 788158	TAMARA NIKITINA	{"email": "nikitina-tamara_15111971@postgrespro.ru", "phone": "+70062164048"}
0005434821634	66A8DE	6836 373215	EKATERINA SERGEEVA	{"email": "e_sergeeva04021983@postgrespro.ru", "phone": "+70215019259"}
0005434821635	66A8DE	8523 381286	EVGENIY SCHERBAKOV	{"email": "scherbakov-evgeniy011985@postgrespro.ru", "phone": "+70016562909"}
0005434821636	0AFF7A	7775 420568	TATYANA ISAEVA	{"email": "tatyana_isaeva051990@postgrespro.ru", "phone": "+70731925610"}
0005434821637	0AFF7A	4713 470618	NIKOLAY PAVLOV	{"email": "n-pavlov1977@postgrespro.ru", "phone": "+70616924241"}
0005434821638	0AFF7A	1761 175349	POLINA SMIRNOVA	{"email": "p-smirnova.02031971@postgrespro.ru", "phone": "+70609251553"}
0005434821639	C2E4CC	2485 868717	ELENA VOLKOVA	{"phone": "+70793851084"}
0005434821640	C2E4CC	2908 929700	TAMARA ISAEVA	{"email": "tamara_isaeva_1971@postgrespro.ru", "phone": "+70511511402"}
0005434821641	A8ED28	0436 784222	EKATERINA MAKAROVA	{"email": "ekaterina-makarova-18121971@postgrespro.ru", "phone": "+70685928297"}
0005434821642	D22463	6750 345971	VIKTOR ZAYCEV	{"phone": "+70050055873"}
0005434821643	37923F	3528 776960	ILYA MAKAROV	{"phone": "+70894467844"}
0005434821644	C6B312	7227 251610	SVETLANA KUZNECOVA	{"phone": "+70759571193"}
0005434821645	C6B312	6670 327729	LILIYA LAZAREVA	{"email": "lazareva_liliya-041959@postgrespro.ru", "phone": "+70125162743"}
0005434821646	9BD882	0398 933304	OLGA MEDVEDEVA	{"phone": "+70977757892"}
0005434821647	6FDC3D	7003 916684	LYUDMILA CHERNOVA	{"phone": "+70407411587"}
0005434821648	BB0180	8733 998899	ANTONINA OVCHINNIKOVA	{"phone": "+70567537607"}
0005434821649	50EFD2	9547 496976	VALENTINA NESTEROVA	{"email": "v-nesterova_1984@postgrespro.ru", "phone": "+70457352743"}
0005434821650	50EFD2	0948 750928	LYUBOV YUDINA	{"phone": "+70483817669"}
0005434821651	9A0518	6602 764711	ELMIRA GAVRILOVA	{"phone": "+70585355022"}
0005434821652	B54668	5072 781359	NATALYA KUZMINA	{"email": "natalya-kuzmina.27091970@postgrespro.ru", "phone": "+70692473030"}
0005434821653	B54668	4564 795747	NATALYA KAZAKOVA	{"phone": "+70471164132"}
0005434821654	72CE60	0148 336534	SVETLANA GAVRILOVA	{"phone": "+70084104977"}
0005434821655	F75378	1893 824495	SVETLANA TITOVA	{"phone": "+70570939275"}
0005434821656	037B6A	2472 975367	EVGENIY KOZLOV	{"phone": "+70689842335"}
0005434821657	037B6A	1027 018927	LYUBOV MATVEEVA	{"phone": "+70702671740"}
0005434821658	037B6A	8398 062010	MAKSIM MARTYNOV	{"email": "m-martynov-101971@postgrespro.ru", "phone": "+70805421827"}
0005434821659	7263F6	7333 955125	MARIYA MAKSIMOVA	{"phone": "+70585336778"}
0005434821660	AEE4FD	8289 134653	ROMAN CHERNOV	{"email": "r.chernov_02061981@postgrespro.ru", "phone": "+70118936554"}
0005434821661	9367C7	3815 740214	SERGEY KOZLOV	{"email": "kozlov_s-18041972@postgrespro.ru", "phone": "+70291877515"}
0005434821662	9367C7	0218 961174	ARTUR ZHURAVLEV	{"phone": "+70131882641"}
0005434821663	9367C7	6406 184680	EKATERINA BARANOVA	{"email": "baranova.e1976@postgrespro.ru", "phone": "+70350453109"}
0005434821664	9367C7	4711 866586	DMITRIY ZAYCEV	{"email": "dzaycev_1966@postgrespro.ru", "phone": "+70210070011"}
0005434821665	4C05A8	8770 134391	ELENA EGOROVA	{"email": "egorova-e.02071969@postgrespro.ru", "phone": "+70492369380"}
0005434821666	4C05A8	4295 088780	OLGA GORBUNOVA	{"email": "o-gorbunova26121977@postgrespro.ru", "phone": "+70610359423"}
0005434821667	AF7C05	4784 362734	PETR VOROBEV	{"phone": "+70486473191"}
0005434821668	C38C06	8883 809540	NATALYA FADEEVA	{"email": "n_fadeeva_15121978@postgrespro.ru", "phone": "+70719332783"}
0005434821669	FC1E41	3724 167125	MARIYA TITOVA	{"email": "titova.mariya.1981@postgrespro.ru", "phone": "+70514598207"}
0005434821670	2AEEA1	7305 152894	YULIYA SEMENOVA	{"email": "semenova.yuliya091977@postgrespro.ru", "phone": "+70261004776"}
0005434821671	CCDA99	0394 838054	VARVARA ZAYCEVA	{"email": "zayceva_v-031980@postgrespro.ru", "phone": "+70465704891"}
0005434821672	ED6D61	4425 064720	ANDREY TIKHONOV	{"email": "a_tikhonov22051988@postgrespro.ru", "phone": "+70338519390"}
0005434821673	ED6D61	4262 908278	ANATOLIY MIKHAYLOV	{"email": "anatoliy-mikhaylov-01071967@postgrespro.ru", "phone": "+70174380970"}
0005434821674	B1464F	6172 787729	MAKSIM MEDVEDEV	{"phone": "+70099123065"}
0005434821675	37AF46	1015 406079	IVAN KUZNECOV	{"email": "ivan_kuznecov_1971@postgrespro.ru", "phone": "+70960006478"}
0005434821676	37AF46	4486 510319	SVETLANA GERASIMOVA	{"email": "gerasimova-svetlana.1960@postgrespro.ru", "phone": "+70769807724"}
0005434821677	CC5330	9175 759063	ANDREY POPOV	{"email": "a.popov111974@postgrespro.ru", "phone": "+70655389267"}
0005434821678	BD198A	0452 843907	ANASTASIYA ARKHIPOVA	{"email": "arkhipova_a_1982@postgrespro.ru", "phone": "+70391708888"}
0005434821679	56067E	7472 994753	ANASTASIYA MOISEEVA	{"phone": "+70070696390"}
0005434821680	56067E	3660 765240	KIRILL IVANOV	{"phone": "+70670779156"}
0005434821681	3D166E	4456 625367	YURIY KUDRYASHOV	{"phone": "+70338601895"}
0005434821682	3D166E	7925 088749	ALEKSANDRA FROLOVA	{"email": "frolovaaleksandra_21081961@postgrespro.ru", "phone": "+70343389039"}
0005434821683	EB95DA	8194 131665	RENAT BORISOV	{"phone": "+70474582009"}
0005434821684	DFBAFE	6325 126651	VERA KISELEVA	{"email": "kiseleva_v_06041959@postgrespro.ru", "phone": "+70404233870"}
0005434821685	A75CA9	1313 151656	NIKOLAY KULIKOV	{"phone": "+70011254031"}
0005434821686	A75CA9	2279 242571	KONSTANTIN MIKHAYLOV	{"phone": "+70115672078"}
0005434821687	A75CA9	4614 370320	EKATERINA BORISOVA	{"email": "borisovaekaterina_121970@postgrespro.ru", "phone": "+70824825344"}
0005434821688	219BE9	5323 538859	VLADIMIR ANTONOV	{"email": "antonov.v-20121973@postgrespro.ru", "phone": "+70973330094"}
0005434821689	FEA706	2148 160905	VLADIMIR RODIONOV	{"phone": "+70248696198"}
0005434821690	855D71	8834 375599	ILYA MATVEEV	{"phone": "+70547121721"}
0005434821691	651CC2	7571 104187	SERGEY PETROV	{"phone": "+70346070842"}
0005434821692	709054	9863 497828	SVETLANA POLYAKOVA	{"phone": "+70289386856"}
0005434821693	23EB43	0504 256540	ANTONINA FOMINA	{"email": "fomina-antonina-011964@postgrespro.ru", "phone": "+70377666269"}
0005434821694	E87851	1001 722056	KIRILL ANDREEV	{"phone": "+70539465819"}
0005434821695	E87851	6419 869821	NIKITA SOROKIN	{"phone": "+70678483757"}
0005434821696	B4E317	8139 444445	TATYANA BELOVA	{"email": "tatyanabelova27091979@postgrespro.ru", "phone": "+70054655654"}
0005434821697	B4E317	6916 209529	ANDREY SOKOLOV	{"email": "asokolov28101980@postgrespro.ru", "phone": "+70701345321"}
0005434821698	73E5B3	8828 207389	IVAN ANTONOV	{"email": "antonovi-031974@postgrespro.ru", "phone": "+70394785188"}
0005434821699	4FA07E	3109 271670	NAILYA NESTEROVA	{"email": "nesterova_n021975@postgrespro.ru", "phone": "+70577509303"}
0005434821700	44B204	1071 549158	TAMARA PETROVA	{"email": "petrova-t.121974@postgrespro.ru", "phone": "+70621602619"}
0005434821701	3BA11C	5179 010568	YULIYA RODIONOVA	{"email": "rodionova-y-091978@postgrespro.ru", "phone": "+70056875591"}
0005434821702	3BA11C	0466 979594	YURIY PETROV	{"email": "petrov-y021973@postgrespro.ru", "phone": "+70871096197"}
0005434821703	3BA11C	7774 740422	VADIM BARANOV	{"phone": "+70221752240"}
0005434821704	3D90F0	4278 447348	RAISA NIKOLAEVA	{"phone": "+70475329291"}
0005434821705	84A8D7	8048 343950	NATALYA ORLOVA	{"phone": "+70033557825"}
0005434821706	90299C	2828 667850	MARIYA DENISOVA	{"email": "denisovam021973@postgrespro.ru", "phone": "+70483854186"}
0005434821707	E77BC2	9848 371941	ANTONINA FEDOROVA	{"email": "fedorova-antonina-01011974@postgrespro.ru", "phone": "+70562515948"}
0005434821708	6515B1	2994 024293	VLADIMIR FEDOROV	{"email": "fedorov-vladimir03081960@postgrespro.ru", "phone": "+70850940118"}
0005434821709	CCEFE3	4356 902700	ZHANNA NESTEROVA	{"phone": "+70916223255"}
0005434821710	CCEFE3	1209 239796	EKATERINA ZHUKOVA	{"email": "e-zhukova21021970@postgrespro.ru", "phone": "+70141213284"}
0005434821711	3BB27A	5228 829275	ELENA SOKOLOVA	{"email": "elena_sokolova-041973@postgrespro.ru", "phone": "+70200704508"}
0005434821712	6B7477	6567 476839	ELENA BELOVA	{"email": "belova-e.24061970@postgrespro.ru", "phone": "+70350346027"}
0005434821713	C1DBE1	8254 937480	VYACHESLAV NIKOLAEV	{"phone": "+70415104991"}
0005434821714	C1DBE1	8951 961287	OLGA PAVLOVA	{"phone": "+70873527042"}
0005434821715	23A4A1	4161 330710	TAISIYA KOZLOVA	{"email": "kozlova.t-10091971@postgrespro.ru", "phone": "+70551648115"}
0005434821716	075B6B	7626 292377	GALINA MAKAROVA	{"phone": "+70437996890"}
0005434821717	318DC8	7052 743251	MAKSIM FEDOROV	{"phone": "+70946329625"}
0005434821718	318DC8	7885 782847	ALEKSANDR KARPOV	{"phone": "+70999656979"}
0005434821719	152E22	5155 921659	TATYANA KUZMINA	{"phone": "+70154290192"}
0005434821720	152E22	0267 232166	SERGEY DMITRIEV	{"phone": "+70527677513"}
0005434821721	04AE35	0515 528050	ALEKSEY BARANOV	{"phone": "+70737212059"}
0005434821722	04AE35	8742 814826	FARIT NAZAROV	{"phone": "+70291784928"}
0005434821723	04AE35	5874 557713	EKATERINA NIKOLAEVA	{"email": "nikolaeva-e-121969@postgrespro.ru", "phone": "+70530313813"}
0005434821724	AA4535	4870 301192	EKATERINA NIKIFOROVA	{"email": "e-nikiforova_101970@postgrespro.ru", "phone": "+70712575463"}
0005434821725	AA4535	9379 823580	SVETLANA PETROVA	{"email": "s_petrova.111975@postgrespro.ru", "phone": "+70232237019"}
0005434821726	2709F6	7797 722337	DARYA NAZAROVA	{"email": "d-nazarova-06051971@postgrespro.ru", "phone": "+70239731571"}
0005434821727	7F4EFE	9843 707642	ALEKSEY SEMENOV	{"email": "aleksey-semenov-23101976@postgrespro.ru", "phone": "+70769428828"}
0005434821728	7F4EFE	5855 797345	MARIYA ALEKSEEVA	{"email": "m_alekseeva.071972@postgrespro.ru", "phone": "+70018134619"}
0005434821729	79A4FE	9010 129503	ROMAN IVANOV	{"phone": "+70449448987"}
0005434821730	79A4FE	9003 815009	SERGEY BARANOV	{"email": "s-baranov111983@postgrespro.ru", "phone": "+70228904722"}
0005434821731	ACA5B9	0769 841011	MARINA KOZLOVA	{"phone": "+70165372459"}
0005434821732	ABD9EA	9202 538332	ALEKSANDR ANTONOV	{"email": "a-antonov-081973@postgrespro.ru", "phone": "+70923475286"}
0005434821733	ED5AE8	5912 041054	NIKOLAY GAVRILOV	{"phone": "+70241021741"}
0005434821734	9047AD	1569 803234	OLGA MARTYNOVA	{"email": "martynova_o_23041953@postgrespro.ru", "phone": "+70395062141"}
0005434821735	9047AD	9751 952400	IGOR FROLOV	{"phone": "+70985741185"}
0005434821736	9047AD	3598 721955	NATALYA SOLOVEVA	{"phone": "+70619437736"}
0005434821737	33E880	6403 688332	SVETLANA POPOVA	{"email": "popova_svetlana-02111975@postgrespro.ru", "phone": "+70722083502"}
0005434821738	33E880	1446 897803	YULIYA KUZNECOVA	{"phone": "+70556027210"}
0005434821739	6126F8	3457 445345	VALENTINA ZHURAVLEVA	{"email": "zhuravleva-valentina-06051968@postgrespro.ru", "phone": "+70152932123"}
0005434821740	6126F8	6901 218759	KLARA MATVEEVA	{"phone": "+70273289774"}
0005434821741	B0F990	4962 523092	ALEKSEY NIKOLAEV	{"email": "nikolaev.a13061967@postgrespro.ru", "phone": "+70290725673"}
0005434821742	6F53F0	0383 591904	SVETLANA KOVALEVA	{"phone": "+70309703850"}
0005434821743	B8F0BF	0435 198869	RAISA ABRAMOVA	{"email": "raisa-abramova_01071969@postgrespro.ru", "phone": "+70449797285"}
0005434821744	9B7115	5358 393634	NATALYA ZAKHAROVA	{"phone": "+70268284288"}
0005434821745	25D71E	8216 681165	VIKTOR KOZLOV	{"phone": "+70598089847"}
0005434821746	4C28AA	7147 660503	GUZEL RYABOVA	{"email": "guzel.ryabova-1981@postgrespro.ru", "phone": "+70655087521"}
0005434821747	0AC6B4	7984 848404	SERGEY GERASIMOV	{"email": "gerasimovs021954@postgrespro.ru", "phone": "+70036502909"}
0005434821748	9D2385	4717 869075	KRISTINA KUZNECOVA	{"phone": "+70157910436"}
0005434821749	9D2385	1892 541939	VYACHESLAV VOLKOV	{"email": "volkov-vyacheslav_1981@postgrespro.ru", "phone": "+70997310643"}
0005434821750	D63174	2188 232093	LYUBOV MEDVEDEVA	{"phone": "+70121720680"}
0005434821751	4CDABD	6333 508315	IRINA SCHERBAKOVA	{"phone": "+70559051004"}
0005434821752	4CDABD	6272 780197	EVGENIY MOISEEV	{"phone": "+70539298344"}
0005434821753	7390D5	7050 332147	ARTUR MELNIKOV	{"phone": "+70022896278"}
0005434821754	9CB197	4942 229667	LYUBOV IVANOVA	{"phone": "+70039803319"}
0005434821755	9CB197	7284 972824	VLADIMIR SMIRNOV	{"email": "vsmirnov.25011973@postgrespro.ru", "phone": "+70479168053"}
0005434821756	0A5665	6880 596235	ANNA FOMINA	{"phone": "+70616643060"}
0005434821757	6EBD04	1327 774998	ALEKSANDR BARANOV	{"phone": "+70088636873"}
0005434821758	C4EF2D	0414 062642	EVGENIY AFANASEV	{"phone": "+70286041279"}
0005434821759	C4EF2D	2700 028564	VLADIMIR SMIRNOV	{"email": "v-smirnov.22101966@postgrespro.ru", "phone": "+70334272444"}
0005434821760	C4EF2D	5403 671499	VASILIY CHERNOV	{"phone": "+70523179249"}
0005434821761	C1B91F	2361 211637	MARINA NIKOLAEVA	{"email": "marina.nikolaeva_121979@postgrespro.ru", "phone": "+70946749853"}
0005434821762	1B56E1	1907 908134	VIKTOR IVANOV	{"email": "ivanovviktor_25011978@postgrespro.ru", "phone": "+70985628768"}
0005434821763	ADA81B	3544 979299	DARYA IVANOVA	{"email": "divanova1967@postgrespro.ru", "phone": "+70379483003"}
0005434821764	7CBDCA	2996 582542	EMILIYA KAZAKOVA	{"email": "emiliyakazakova-091970@postgrespro.ru", "phone": "+70413743914"}
0005434821765	C3B940	2181 657902	SVETLANA ZHUKOVA	{"phone": "+70300881819"}
0005434821766	0A342E	7635 220809	SVETLANA SIDOROVA	{"email": "svetlana.sidorova30041973@postgrespro.ru", "phone": "+70915433652"}
0005434821767	220408	4334 888210	VIKTOR ANTONOV	{"phone": "+70558664745"}
0005434821768	220408	8593 770430	ALEKSANDR VASILEV	{"email": "aleksandrvasilev-30011961@postgrespro.ru", "phone": "+70735929772"}
0005434821769	35AEE1	8449 526420	IGOR VASILEV	{"phone": "+70742452355"}
0005434821770	9C6223	1645 866200	ALEKSEY IVANOV	{"email": "aleksey-ivanov.011973@postgrespro.ru", "phone": "+70194005993"}
0005434821771	484058	7111 660959	TATYANA KULIKOVA	{"email": "kulikova-t-06011972@postgrespro.ru", "phone": "+70814938958"}
0005434821772	3FB95E	0056 997590	SERGEY IVANOV	{"phone": "+70391896774"}
0005434821773	3FB95E	4440 875215	LIDIYA NOVIKOVA	{"phone": "+70387206626"}
0005434821833	45B943	2407 014631	TATYANA KOZLOVA	{"phone": "+70780980280"}
0005434821774	263593	7416 430355	GALINA MAKAROVA	{"email": "makarova-g14061979@postgrespro.ru", "phone": "+70093806856"}
0005434821775	E1EF1E	6093 147272	ROZALIYA ILINA	{"email": "ilina-r011976@postgrespro.ru", "phone": "+70723102225"}
0005434821776	E1EF1E	7749 151198	VLADISLAV DMITRIEV	{"email": "vladislav-dmitriev.081981@postgrespro.ru", "phone": "+70402700995"}
0005434821777	71F901	5629 900255	VALERIY GAVRILOV	{"phone": "+70291005951"}
0005434821778	71F901	5960 702251	EVGENIY PAVLOV	{"phone": "+70183279826"}
0005434821779	0100D1	9828 131519	VLADIMIR KONOVALOV	{"phone": "+70463878701"}
0005434821780	0100D1	6283 784444	VALENTIN ZAYCEV	{"email": "zaycev_v.041969@postgrespro.ru", "phone": "+70223995663"}
0005434821781	01664C	6470 119448	SERGEY ALEKSEEV	{"email": "s_alekseev_25011973@postgrespro.ru", "phone": "+70358334962"}
0005434821782	01664C	6639 028536	NIKOLAY ABRAMOV	{"phone": "+70409027815"}
0005434821783	CAEF06	4883 925613	ROMAN STEPANOV	{"email": "stepanov-r.031965@postgrespro.ru", "phone": "+70390390227"}
0005434821784	6F678D	3008 795527	NATALYA NOVIKOVA	{"email": "novikova_natalya011971@postgrespro.ru", "phone": "+70536909861"}
0005434821785	6F678D	8979 172449	YURIY IVANOV	{"email": "yivanov.1959@postgrespro.ru", "phone": "+70789548419"}
0005434821786	F2B6FE	6553 379585	ALEKSEY MAKAROV	{"email": "alekseymakarov.1969@postgrespro.ru", "phone": "+70280250200"}
0005434821787	1D6904	0568 254667	ALEKSANDR DAVYDOV	{"phone": "+70054464876"}
0005434821788	40E79E	1082 243577	IVAN BARANOV	{"phone": "+70587215603"}
0005434821789	04ACC0	2558 229830	MIKHAIL PETROV	{"phone": "+70121323495"}
0005434821790	B5132D	7302 188371	SERGEY GORBUNOV	{"phone": "+70139197017"}
0005434821791	D1D24B	1787 725092	SERGEY BELOV	{"phone": "+70614464985"}
0005434821792	D1D24B	6510 200762	ELENA YAKOVLEVA	{"phone": "+70940045055"}
0005434821793	471B44	0644 556120	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko1966@postgrespro.ru", "phone": "+70820906994"}
0005434821794	471B44	1763 729383	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr-1967@postgrespro.ru", "phone": "+70682190067"}
0005434821795	471B44	5993 366681	ELENA TARASOVA	{"email": "tarasova-elena-28051969@postgrespro.ru", "phone": "+70307062286"}
0005434821796	5AF4B8	0999 057475	YURIY PETROV	{"email": "petrov.yuriy-101972@postgrespro.ru", "phone": "+70881644353"}
0005434821797	00CAF0	2279 755878	DMITRIY SIDOROV	{"email": "sidorovdmitriy-26011960@postgrespro.ru", "phone": "+70159029843"}
0005434821798	00CAF0	5793 738578	EMIL ANTONOV	{"email": "emil.antonov28081975@postgrespro.ru", "phone": "+70639010919"}
0005434821799	0CCB6B	9882 631966	MIKHAIL BARANOV	{"phone": "+70406140476"}
0005434821800	81A3A3	4922 577626	ALINA MELNIKOVA	{"phone": "+70813860540"}
0005434821801	81A3A3	8927 976673	EKATERINA KUZNECOVA	{"phone": "+70269595666"}
0005434821802	BCF84F	0521 227664	LYUDMILA KAZAKOVA	{"phone": "+70855589142"}
0005434821803	37A749	6294 741946	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov01061968@postgrespro.ru", "phone": "+70332274569"}
0005434821804	0BDC3D	4066 013200	VASILIY MATVEEV	{"email": "v-matveev-1970@postgrespro.ru", "phone": "+70193154596"}
0005434821805	0BDC3D	9659 404699	MARIYA KOLESNIKOVA	{"email": "mariyakolesnikova-041979@postgrespro.ru", "phone": "+70092080843"}
0005434821806	04A1E0	9080 680376	ANGELINA SOROKINA	{"phone": "+70272706448"}
0005434821807	04A1E0	3289 587071	GALINA EFREMOVA	{"email": "galina.efremova_22111985@postgrespro.ru", "phone": "+70540754908"}
0005434821808	D9D016	9350 646191	ZAKHAR NIKITIN	{"email": "nikitin_zakhar.26071988@postgrespro.ru", "phone": "+70554661811"}
0005434821809	08BEEB	5318 257290	OLEG BELOV	{"email": "belov.oleg.1971@postgrespro.ru", "phone": "+70928879539"}
0005434821810	2BFCE3	2199 872426	GULNAZ SMIRNOVA	{"phone": "+70935632089"}
0005434821811	DBEEB9	6690 648836	LYUDMILA ZAKHAROVA	{"email": "zakharovalyudmila_16121972@postgrespro.ru", "phone": "+70726665109"}
0005434821812	DBEEB9	7693 395167	VLADIMIR SEMENOV	{"email": "semenov-v-19051968@postgrespro.ru", "phone": "+70641299395"}
0005434821813	DDE076	0497 622101	VLADISLAV OSIPOV	{"email": "vladislavosipov-111973@postgrespro.ru", "phone": "+70618443619"}
0005434821814	90007C	9757 940237	ANASTASIYA ZAKHAROVA	{"phone": "+70170370516"}
0005434821815	90007C	4859 370154	TATYANA NIKOLAEVA	{"email": "nikolaeva_t-101971@postgrespro.ru", "phone": "+70423227160"}
0005434821816	762378	0725 427720	TATYANA ERMAKOVA	{"email": "tatyanaermakova101973@postgrespro.ru", "phone": "+70014180255"}
0005434821817	762378	1235 741064	DMITRIY NIKOLAEV	{"email": "nikolaev_dmitriy10021982@postgrespro.ru", "phone": "+70241122491"}
0005434821818	FDB451	4174 409375	PAVEL SERGEEV	{"phone": "+70518783585"}
0005434821819	FDB451	5100 967454	NELLI ZHUKOVA	{"email": "zhukovanelli_1974@postgrespro.ru", "phone": "+70857841355"}
0005434821820	1AC3D9	8180 522542	LYUDMILA ARKHIPOVA	{"phone": "+70924179428"}
0005434821821	7D6247	7938 222146	VLADIMIR NAZAROV	{"phone": "+70995025973"}
0005434821822	D85497	0113 240143	LYUDMILA LOGINOVA	{"email": "loginoval1958@postgrespro.ru", "phone": "+70228218920"}
0005434821823	D85497	2192 459470	NATALYA KARPOVA	{"email": "karpova-n_1968@postgrespro.ru", "phone": "+70952482980"}
0005434821824	D85497	4885 744074	VIKTOR ROMANOV	{"phone": "+70776521064"}
0005434821825	DB39F3	8806 415279	NAILYA ZHURAVLEVA	{"phone": "+70268081044"}
0005434821826	416579	8244 002657	IGOR ZAKHAROV	{"email": "i.zakharov-12011969@postgrespro.ru", "phone": "+70897672426"}
0005434821827	F9034C	4685 853626	ALEKSANDR FOMIN	{"phone": "+70367165919"}
0005434821828	F9034C	9016 036230	ANDREY ZAYCEV	{"phone": "+70176866287"}
0005434821829	327823	3395 808984	DMITRIY POPOV	{"email": "popov-d20011976@postgrespro.ru", "phone": "+70367871016"}
0005434821830	1D5F61	4782 433521	TATYANA GERASIMOVA	{"phone": "+70744715953"}
0005434821831	1D5F61	2914 356831	NINA KARPOVA	{"email": "ninakarpova_041976@postgrespro.ru", "phone": "+70663890161"}
0005434821832	9F01EB	1466 797642	ALEKSANDR GERASIMOV	{"phone": "+70491624171"}
0005434821834	C0AD55	0590 367653	GALINA YAKOVLEVA	{"email": "gyakovleva-1973@postgrespro.ru", "phone": "+70834249461"}
0005434821835	C0AD55	1970 305568	LYUDMILA POPOVA	{"phone": "+70961736115"}
0005434821836	4FD1A1	4916 927962	VASILISA PAVLOVA	{"phone": "+70411445455"}
0005434821837	21E097	1910 912062	YURIY VLASOV	{"phone": "+70355937824"}
0005434821838	21E097	5139 927560	MIKHAIL GAVRILOV	{"email": "gavrilov-m.1985@postgrespro.ru", "phone": "+70695537681"}
0005434821839	9AD18B	2650 885903	TATYANA TITOVA	{"phone": "+70938376898"}
0005434821840	9AD18B	2403 128709	ANDREY MEDVEDEV	{"email": "medvedevandrey-20011962@postgrespro.ru", "phone": "+70417474893"}
0005434821841	9AD18B	8958 012106	VIKTOR GRIGOREV	{"email": "grigorevviktor_101971@postgrespro.ru", "phone": "+70815073867"}
0005434821842	A5C817	9233 473531	LYUDMILA NESTEROVA	{"email": "l_nesterova.1979@postgrespro.ru", "phone": "+70239643496"}
0005434821843	48D2D3	1613 732522	RAMIL ZAKHAROV	{"phone": "+70559983726"}
0005434821844	E00831	4137 619356	MAKSIM SOKOLOV	{"phone": "+70143193233"}
0005434821845	6CCA38	0683 228494	NADEZHDA SIDOROVA	{"phone": "+70017487511"}
0005434821846	603D47	3116 871957	MIKHAIL KULIKOV	{"email": "mikhail.kulikov_1974@postgrespro.ru", "phone": "+70710030649"}
0005434821847	A61449	4077 099515	TATYANA EGOROVA	{"phone": "+70764982294"}
0005434821848	C3CA5D	2911 916584	OKSANA ZAKHAROVA	{"phone": "+70601332105"}
0005434821849	1559FB	4326 429279	YAKOV DAVYDOV	{"email": "davydov_yakov.081980@postgrespro.ru", "phone": "+70390800006"}
0005434821850	D43AF1	8600 096737	FAIL ZAKHAROV	{"email": "f_zakharov1974@postgrespro.ru", "phone": "+70756876305"}
0005434821851	6A99EB	3964 651573	DMITRIY KULIKOV	{"phone": "+70210214002"}
0005434821852	834C19	6176 430591	MARIYA SMIRNOVA	{"phone": "+70786653006"}
0005434821853	8B4321	9856 359274	LIDIYA VLASOVA	{"phone": "+70290091231"}
0005434821854	1BF91A	3176 368284	DMITRIY BORISOV	{"email": "borisov-dmitriy-041970@postgrespro.ru", "phone": "+70910010397"}
0005434821855	D2E57E	7286 289149	ALEKSANDR ANTONOV	{"phone": "+70003058174"}
0005434821856	D2E57E	3241 123671	VLADIMIR PETROV	{"phone": "+70220274562"}
0005434821857	46B11A	2695 395462	IRINA POPOVA	{"phone": "+70012613849"}
0005434821858	2F0EA6	5028 387849	IRINA LEBEDEVA	{"phone": "+70783919099"}
0005434821859	85502E	6966 528430	NIKOLAY ROMANOV	{"phone": "+70899788839"}
0005434821860	4CA3D9	5542 610993	ILYA KOROLEV	{"phone": "+70074607460"}
0005434821861	B8D8FB	2720 888146	TATYANA MAKAROVA	{"email": "makarova_tatyana02051962@postgrespro.ru", "phone": "+70754809841"}
0005434821863	6877D3	9359 860322	YURIY VASILEV	{"email": "vasilev_yuriy07031968@postgrespro.ru", "phone": "+70492498820"}
0005434821864	D05FB2	7871 099299	ELENA PETROVA	{"email": "elena_petrova.01091983@postgrespro.ru", "phone": "+70917731628"}
0005434821865	D05FB2	8509 606297	ALEKSANDR NIKITIN	{"phone": "+70673868185"}
0005434821866	001ED4	2282 636990	VLADIMIR SIDOROV	{"email": "v_sidorov.011974@postgrespro.ru", "phone": "+70377556294"}
0005434821867	FCE836	6277 524338	NATALYA TARASOVA	{"phone": "+70699199365"}
0005434821868	FA93C0	2274 312970	DIANA SEMENOVA	{"email": "semenova.diana1978@postgrespro.ru", "phone": "+70441589180"}
0005434821869	B6A601	6104 858064	ANNA KOZLOVA	{"phone": "+70346275302"}
0005434821870	B6A601	7946 842798	OLEG VOLKOV	{"email": "o_volkov29111968@postgrespro.ru", "phone": "+70045432420"}
0005434821871	FB32A9	7205 484235	ALEKSANDR FOMIN	{"phone": "+70699115112"}
0005434821872	8B3B70	9683 316132	IRINA NOVIKOVA	{"phone": "+70605179396"}
0005434821873	8B3B70	9649 289005	EKATERINA ARKHIPOVA	{"phone": "+70478050802"}
0005434821874	144E4B	8843 016188	ANNA IVANOVA	{"phone": "+70292012881"}
0005434821875	144E4B	5529 373578	DENIS TIMOFEEV	{"email": "denistimofeev.111975@postgrespro.ru", "phone": "+70408586120"}
0005434821876	8FBA05	3930 329403	TATYANA MAKAROVA	{"phone": "+70350926472"}
0005434821877	BBEC7B	6127 803798	TAMARA KOROLEVA	{"phone": "+70760600796"}
0005434821878	8A1516	9848 111146	NIKOLAY MELNIKOV	{"phone": "+70729316163"}
0005434821879	B5D4C6	9359 770668	EKATERINA SOKOLOVA	{"phone": "+70388724449"}
0005434821880	19B89E	7477 272070	VIKTOR KUZNECOV	{"phone": "+70801178226"}
0005434821881	19B89E	9461 448395	LYUDMILA EGOROVA	{"phone": "+70165588776"}
0005434821882	A83E42	3966 324198	EVGENIY ZAYCEV	{"email": "ezaycev15071974@postgrespro.ru", "phone": "+70389214751"}
0005434821883	98C2B1	8000 921142	LYUDMILA ROMANOVA	{"phone": "+70686634847"}
0005434821884	6CA388	5812 109868	ANDREY ALEKSEEV	{"email": "aalekseev1969@postgrespro.ru", "phone": "+70328305138"}
0005434821885	FBD389	3928 371957	OLGA IVANOVA	{"phone": "+70276618322"}
0005434821886	AFD727	1845 356277	BORIS NIKITIN	{"email": "b_nikitin_121964@postgrespro.ru", "phone": "+70249284679"}
0005434821887	C87EA8	5262 619995	IVAN VLASOV	{"email": "ivan_vlasov-1961@postgrespro.ru", "phone": "+70240849076"}
0005434821888	8D4117	0333 511864	VITALIY RODIONOV	{"email": "v_rodionov-20031978@postgrespro.ru", "phone": "+70324764640"}
0005434821889	1F5B64	0011 411346	OLEG POPOV	{"phone": "+70885847618"}
0005434821890	3EFE37	5165 263526	VIKTOR SOROKIN	{"email": "sorokin.v-121968@postgrespro.ru", "phone": "+70538086899"}
0005434821891	6D2129	4000 250135	BOGDAN POPOV	{"phone": "+70493989274"}
0005434821892	6D2129	5660 407823	LIDIYA DENISOVA	{"email": "denisova-l1974@postgrespro.ru", "phone": "+70526243935"}
0005434821893	0AE096	3075 265873	SERGEY PAVLOV	{"phone": "+70867613992"}
0005434821894	4783CF	8471 419748	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva-01121976@postgrespro.ru", "phone": "+70792394178"}
0005434821895	4783CF	1194 755439	SVETLANA LEBEDEVA	{"email": "lebedevasvetlana-1970@postgrespro.ru", "phone": "+70925551027"}
0005434821896	7D7456	7258 058833	SERGEY CHERNOV	{"phone": "+70216056772"}
0005434821897	7D7456	9293 477077	IVAN SIDOROV	{"phone": "+70038857906"}
0005434821898	36DD56	7784 708306	ALEKSANDRA TIMOFEEVA	{"phone": "+70531923982"}
0005434821899	6311E5	4567 434341	LYUDMILA PAVLOVA	{"email": "lyudmila-pavlova_1980@postgrespro.ru", "phone": "+70707682483"}
0005434821900	6311E5	9637 964339	MARIYA MELNIKOVA	{"email": "melnikova_m-1971@postgrespro.ru", "phone": "+70837307901"}
0005434821901	6311E5	9802 716967	ZOYA DENISOVA	{"phone": "+70885586512"}
0005434821902	7F4EBB	7025 389199	BORIS ANDREEV	{"email": "b.andreev_1974@postgrespro.ru", "phone": "+70428319172"}
0005434821903	B3FDCA	2974 012063	NINA TIKHONOVA	{"phone": "+70450126308"}
0005434821904	B3FDCA	7592 665401	YURIY SCHERBAKOV	{"email": "scherbakov_yuriy1964@postgrespro.ru", "phone": "+70273200272"}
0005434821905	4A2EFF	2933 474085	DARYA IVANOVA	{"phone": "+70462689502"}
0005434821906	4A2EFF	9875 315198	KSENIYA STEPANOVA	{"email": "stepanova-k1980@postgrespro.ru", "phone": "+70465669444"}
0005434821907	C77D96	7280 272092	YURIY MELNIKOV	{"phone": "+70274787197"}
0005434821908	C77D96	9234 620110	ALEKSANDR BELOV	{"email": "a.belov-051975@postgrespro.ru", "phone": "+70056113128"}
0005434821909	371606	3700 725870	SERGEY POPOV	{"email": "popov.s.10051974@postgrespro.ru", "phone": "+70255197025"}
0005434821910	B2354D	8550 999412	STANISLAV MATVEEV	{"phone": "+70353316241"}
0005434821911	78817B	4572 593581	POLINA FROLOVA	{"email": "polina-frolova-1970@postgrespro.ru", "phone": "+70795185695"}
0005434821912	904967	3344 541213	VIKTOR VOROBEV	{"email": "v-vorobev.031979@postgrespro.ru", "phone": "+70362648449"}
0005434821913	E8BFD5	7434 967509	OLEG AFANASEV	{"email": "afanasev.oleg_111973@postgrespro.ru", "phone": "+70511423862"}
0005434821914	B45A2E	4009 888825	EKATERINA KUDRYASHOVA	{"email": "kudryashova-e.12051971@postgrespro.ru", "phone": "+70558553212"}
0005434821915	B45A2E	1964 427273	ELENA RYABOVA	{"email": "elenaryabova-1970@postgrespro.ru", "phone": "+70683834440"}
0005434821916	ECE157	3716 971594	NATALYA YAKOVLEVA	{"email": "yakovleva_n.14111966@postgrespro.ru", "phone": "+70573378827"}
0005434821917	24DA79	9119 596300	GALINA NAZAROVA	{"email": "nazarovagalina.1977@postgrespro.ru", "phone": "+70393070345"}
0005434821918	24DA79	0845 768907	VIKTOR NIKOLAEV	{"email": "viktor.nikolaev_1969@postgrespro.ru", "phone": "+70390830656"}
0005434821919	EEA466	1873 193970	GERMAN PETROV	{"phone": "+70284305894"}
0005434821920	EEA466	7844 659410	IVAN ABRAMOV	{"email": "abramov.i061974@postgrespro.ru", "phone": "+70912950894"}
0005434821921	EEA466	6861 285436	ALLA SERGEEVA	{"phone": "+70408498577"}
0005434821922	4708B3	1133 860290	NATALYA BORISOVA	{"email": "borisova_natalya.1983@postgrespro.ru", "phone": "+70587322627"}
0005434821923	E579D2	6568 060423	ZOYA MELNIKOVA	{"email": "melnikovaz-09021986@postgrespro.ru", "phone": "+70402517110"}
0005434821924	59368F	4793 819584	NATALYA SMIRNOVA	{"phone": "+70703977194"}
0005434821925	C6A27E	8909 849379	IVAN ILIN	{"phone": "+70414771110"}
0005434821926	C6A27E	0613 431633	VALENTIN KULIKOV	{"email": "kulikov_v1970@postgrespro.ru", "phone": "+70486149355"}
0005434821927	10D538	6855 214562	NADEZHDA FILIPPOVA	{"email": "filippova-nadezhda_111986@postgrespro.ru", "phone": "+70315685675"}
0005434821928	1ABC22	8085 333373	ALFIYA KONOVALOVA	{"email": "alfiya_konovalova_31011970@postgrespro.ru", "phone": "+70071094167"}
0005434821929	1E41EC	8915 526211	SEMEN SMIRNOV	{"phone": "+70527466344"}
0005434821930	1E41EC	9433 488078	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr02121978@postgrespro.ru", "phone": "+70027332407"}
0005434821931	BF5F1E	4604 928993	ELENA AKIMOVA	{"email": "akimovaelena.1972@postgrespro.ru", "phone": "+70964942796"}
0005434821932	297B1A	2831 983848	ALEKSEY NOVIKOV	{"email": "novikov.aleksey-15101967@postgrespro.ru", "phone": "+70047525738"}
0005434821933	297B1A	9388 502184	OLGA PETROVA	{"phone": "+70511222999"}
0005434821934	05968E	5112 908045	RAVIL ZAYCEV	{"email": "ravil-zaycev.121968@postgrespro.ru", "phone": "+70663218299"}
0005434821935	430BF8	5498 780509	ALEKSANDR KOZLOV	{"phone": "+70722568494"}
0005434821936	7E9392	2876 299601	ANASTASIYA SEMENOVA	{"email": "semenova_a.1969@postgrespro.ru", "phone": "+70388874163"}
0005434821937	7537A0	6419 406955	NADEZHDA NESTEROVA	{"email": "nadezhdanesterova-081970@postgrespro.ru", "phone": "+70105229473"}
0005434821938	7537A0	8404 711808	GALINA RODIONOVA	{"email": "rodionova.galina_1970@postgrespro.ru", "phone": "+70737786598"}
0005434821939	75B296	3095 788931	SERGEY POPOV	{"email": "sergey-popov-031989@postgrespro.ru", "phone": "+70064800395"}
0005434821940	75B296	7387 765856	ANATOLIY IVANOV	{"email": "a-ivanov011976@postgrespro.ru", "phone": "+70921407935"}
0005434821941	60790D	6275 457228	NADEZHDA ALEKSEEVA	{"email": "alekseeva_n1964@postgrespro.ru", "phone": "+70158744297"}
0005434821942	E88F70	1956 075349	MIKHAIL FILIPPOV	{"phone": "+70485408164"}
0005434821943	215827	8318 926442	ALEVTINA TIKHONOVA	{"email": "a_tikhonova.11081970@postgrespro.ru", "phone": "+70313261704"}
0005434821944	215827	7623 622305	KLAVDIYA MARTYNOVA	{"phone": "+70069557795"}
0005434821945	E115BB	6864 586571	VYACHESLAV FOMIN	{"email": "fomin_v-13071975@postgrespro.ru", "phone": "+70378929019"}
0005434821946	B8C0D9	9076 165953	SERGEY KOZLOV	{"email": "sergey.kozlov.07061969@postgrespro.ru", "phone": "+70972988696"}
0005434821947	2F3526	1743 175205	TAMARA SOROKINA	{"email": "t-sorokina1971@postgrespro.ru", "phone": "+70219692684"}
0005434821948	5A98ED	2746 822008	SVETLANA ZOTOVA	{"email": "zotovasvetlana26031971@postgrespro.ru", "phone": "+70456194638"}
0005434821949	5A98ED	9412 219047	LYUDMILA ANDREEVA	{"phone": "+70157291596"}
0005434821950	5A98ED	9513 133602	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy-11011971@postgrespro.ru", "phone": "+70975679205"}
0005434821951	5A98ED	3191 315362	ALINA ANDREEVA	{"email": "alina_andreeva.051973@postgrespro.ru", "phone": "+70121010442"}
0005434821952	773949	6307 669274	SERGEY SCHERBAKOV	{"email": "s.scherbakov_1982@postgrespro.ru", "phone": "+70718600860"}
0005434821953	4117FE	6632 082673	YULIYA SAVELEVA	{"email": "saveleva_y.27031974@postgrespro.ru", "phone": "+70426881042"}
0005434821954	E7D349	1117 393748	PAVEL DENISOV	{"email": "denisovp101973@postgrespro.ru", "phone": "+70409233225"}
0005434821955	D0FA3C	5632 209555	NATALIYA VASILEVA	{"phone": "+70545878668"}
0005434821956	EA8B8F	8979 332684	ALINA BOGDANOVA	{"email": "alina.bogdanova-031980@postgrespro.ru", "phone": "+70793660434"}
0005434821957	EA8B8F	7042 281489	ELVIRA LAZAREVA	{"email": "elvira.lazareva-081967@postgrespro.ru", "phone": "+70088946397"}
0005434821958	EA8B8F	9816 454184	NINA ALEKSEEVA	{"email": "alekseeva.nina-1978@postgrespro.ru", "phone": "+70552451084"}
0005434821959	5F9D9E	5917 442209	EVGENIY MOROZOV	{"phone": "+70736256167"}
0005434821960	5F9D9E	6434 155083	PAVEL ISAEV	{"phone": "+70776052487"}
0005434821961	5F9D9E	1031 206880	ELENA MAKAROVA	{"email": "e_makarova25081976@postgrespro.ru", "phone": "+70961910860"}
0005434821962	661348	3654 631459	RUSLAN KISELEV	{"phone": "+70577563346"}
0005434821963	BAF8C3	4093 633967	KIRILL GERASIMOV	{"email": "kirill_gerasimov-071980@postgrespro.ru", "phone": "+70002402668"}
0005434821964	0C720D	6691 385725	VLADIMIR ORLOV	{"phone": "+70629526680"}
0005434821965	0C720D	7944 839827	LARISA SERGEEVA	{"phone": "+70630495597"}
0005434821966	C7C633	8846 614326	EKATERINA KRASNOVA	{"phone": "+70040947202"}
0005434821967	E83DA5	1459 411907	MARGARITA ANDREEVA	{"email": "andreeva-margarita-1966@postgrespro.ru", "phone": "+70097758474"}
0005434821968	605DF4	0497 938628	ANASTASIYA KALININA	{"email": "anastasiya_kalinina.20061988@postgrespro.ru", "phone": "+70531055703"}
0005434821969	605DF4	2637 636447	VITALIY SOKOLOV	{"phone": "+70493279378"}
0005434821970	7A27FB	3870 274908	NIKOLAY TARASOV	{"email": "tarasov_nikolay.091960@postgrespro.ru", "phone": "+70990122276"}
0005434821971	7A27FB	7066 061292	SERGEY ILIN	{"email": "ilin.sergey.121968@postgrespro.ru", "phone": "+70339207872"}
0005434821972	3E2FCC	4623 146917	NATALYA ILINA	{"phone": "+70757603315"}
0005434821973	FDB94E	3859 319413	MARIYA MELNIKOVA	{"phone": "+70993219008"}
0005434821974	72EACD	6791 454238	MIKHAIL AFANASEV	{"email": "m_afanasev_27041963@postgrespro.ru", "phone": "+70269445981"}
0005434821975	419DDE	7057 338789	ALEKSEY GUSEV	{"phone": "+70305757122"}
0005434821976	B8F99F	6782 855030	IRINA SERGEEVA	{"phone": "+70149567321"}
0005434821977	FED104	4013 467138	MARIYA CHERNOVA	{"email": "m.chernova-02081964@postgrespro.ru", "phone": "+70530560180"}
0005434821978	49D154	2749 344225	GALINA NOVIKOVA	{"phone": "+70691258848"}
0005434821979	49D154	4996 818035	IRINA POPOVA	{"phone": "+70240131560"}
0005434821980	6ACE01	9266 071476	ANNA MOISEEVA	{"email": "moiseeva.anna_04061972@postgrespro.ru", "phone": "+70179138446"}
0005434821981	DECAA8	3653 696071	OLGA FOMINA	{"email": "ofomina-26061978@postgrespro.ru", "phone": "+70570616265"}
0005434821982	F1CB05	7956 109449	PAVEL PETROV	{"phone": "+70184539910"}
0005434821983	F1CB05	3618 558913	VERA KOROLEVA	{"phone": "+70258497636"}
0005434821984	39457B	7681 177983	ARTUR ZAKHAROV	{"phone": "+70453569105"}
0005434821985	6DF7B4	1794 162924	EKATERINA FROLOVA	{"email": "efrolova.05021978@postgrespro.ru", "phone": "+70366840454"}
0005434821986	0D1ED9	7175 093192	ANDREY ROMANOV	{"phone": "+70352799871"}
0005434821987	4A2CFA	1706 335905	IGOR VOLKOV	{"email": "volkovigor1969@postgrespro.ru", "phone": "+70858401779"}
0005434821988	EF86AD	5801 888235	IRINA SIDOROVA	{"phone": "+70218824849"}
0005434821989	34956F	8795 794781	SERGEY FILIPPOV	{"email": "filippovs071981@postgrespro.ru", "phone": "+70084288478"}
0005434821990	B8FE60	5269 944160	ALEKSANDR NIKOLAEV	{"phone": "+70557700053"}
0005434821991	EA9742	2885 517046	IRINA YUDINA	{"email": "i-yudina1981@postgrespro.ru", "phone": "+70778261727"}
0005434821992	81C90C	5503 710107	NINA MAKAROVA	{"phone": "+70023906737"}
0005434821993	C92A26	3649 872443	OLGA MOISEEVA	{"email": "o.moiseeva.111981@postgrespro.ru", "phone": "+70559053240"}
0005434821994	D25E27	9305 218058	ARTEM ZAKHAROV	{"phone": "+70171192260"}
0005434821995	74C79D	2145 428436	MAKSIM KUZNECOV	{"email": "mkuznecov091967@postgrespro.ru", "phone": "+70316573284"}
0005434821996	43583A	2235 445976	MAKSIM POPOV	{"email": "popovm-27071972@postgrespro.ru", "phone": "+70674481380"}
0005434821997	43583A	8076 249731	LYUBOV TIMOFEEVA	{"email": "timofeeva-l1967@postgrespro.ru", "phone": "+70036816827"}
0005434821998	3B4D58	4231 773866	MIKHAIL IVANOV	{"email": "mivanov.1972@postgrespro.ru", "phone": "+70551169351"}
0005434821999	0CB6A7	3519 549902	BORIS SMIRNOV	{"email": "b_smirnov_1956@postgrespro.ru", "phone": "+70741359152"}
0005434822000	0CB6A7	0541 539843	NATALIYA KUZNECOVA	{"email": "nkuznecova_31051969@postgrespro.ru", "phone": "+70117086137"}
0005434822001	515CD2	8299 495537	ELENA IVANOVA	{"phone": "+70443542737"}
0005434822002	772794	8700 389637	EKATERINA GRISHINA	{"phone": "+70336016450"}
0005434822003	772794	6245 225717	NIKOLAY PAVLOV	{"email": "n_pavlov05061959@postgrespro.ru", "phone": "+70357651961"}
0005434822004	B26040	5389 316526	VALENTINA BELOVA	{"email": "belova.v-1975@postgrespro.ru", "phone": "+70910706121"}
0005434822005	5C7265	3461 478845	SOFYA ZAYCEVA	{"phone": "+70854453444"}
0005434822006	F8FBF3	6624 107765	SVETLANA NOVIKOVA	{"phone": "+70096139774"}
0005434822007	4BF694	9945 124694	VALENTINA FOMINA	{"phone": "+70964377589"}
0005434822008	4BF694	4176 629461	VIKTOR KUZNECOV	{"phone": "+70958585203"}
0005434822009	502529	2695 340976	RIMMA GRISHINA	{"email": "grishina_r.101974@postgrespro.ru", "phone": "+70997251325"}
0005434822010	502529	7533 781504	DANIIL SMIRNOV	{"email": "smirnov-daniil.011975@postgrespro.ru", "phone": "+70260382446"}
0005434822011	5B967D	3381 867248	NINA ALEKSEEVA	{"phone": "+70594636798"}
0005434822012	3EEF0C	4334 122936	ALEKSANDR EGOROV	{"email": "egorov.aleksandr.051969@postgrespro.ru", "phone": "+70270207189"}
0005434822013	D2C47A	1829 936152	SERGEY KULIKOV	{"phone": "+70131591503"}
0005434822014	D2C47A	8945 491192	POLINA VOLKOVA	{"email": "polina-volkova.051978@postgrespro.ru", "phone": "+70365800870"}
0005434822015	E037C1	3717 370505	VALENTINA SERGEEVA	{"email": "v-sergeeva-02111978@postgrespro.ru", "phone": "+70709514675"}
0005434822016	5EBF4F	9429 597931	ALEKSEY MIRONOV	{"email": "aleksey-mironov_1977@postgrespro.ru", "phone": "+70700589966"}
0005434822017	1E51C6	9441 739734	FEDOR IVANOV	{"phone": "+70367820082"}
0005434822018	1E51C6	5140 024510	NIKOLAY MAKSIMOV	{"email": "n-maksimov-06041974@postgrespro.ru", "phone": "+70090005343"}
0005434822019	1E51C6	8577 266513	ANNA ALEKSEEVA	{"email": "alekseeva-a.11121969@postgrespro.ru", "phone": "+70550926078"}
0005434822020	7FAB9C	1598 613236	VLADIMIR KOROLEV	{"email": "vladimir_korolev_041970@postgrespro.ru", "phone": "+70098536320"}
0005434822021	7FAB9C	8668 969096	ALEKSEY KARPOV	{"email": "karpova-111980@postgrespro.ru", "phone": "+70596461689"}
0005434822022	9973C5	1632 283284	OKSANA SIDOROVA	{"email": "sidorova_o_1972@postgrespro.ru", "phone": "+70978514262"}
0005434822023	3E1E7C	9415 913899	LYUBOV MELNIKOVA	{"email": "melnikova-lyubov.30111986@postgrespro.ru", "phone": "+70141178280"}
0005434822024	2216B0	9706 561774	ALLA MAKAROVA	{"email": "a_makarova.021981@postgrespro.ru", "phone": "+70528787601"}
0005434822025	460919	7060 791176	KSENIYA SOROKINA	{"phone": "+70843196204"}
0005434822026	9D69B8	1743 523593	MARINA ILINA	{"phone": "+70285800248"}
0005434822027	9D69B8	5729 780576	LEV NIKITIN	{"email": "nikitin-l-04111976@postgrespro.ru", "phone": "+70355139686"}
0005434822028	062F0C	2085 804553	ANNA VASILEVA	{"email": "anna.vasileva-091975@postgrespro.ru", "phone": "+70355291546"}
0005434822029	957CCF	1567 613850	TATYANA KONOVALOVA	{"email": "t_konovalova-1972@postgrespro.ru", "phone": "+70595646289"}
0005434822030	957CCF	2177 299998	LYUDMILA ROMANOVA	{"phone": "+70099198578"}
0005434822031	8D210F	7421 946961	VLADIMIR NIKOLAEV	{"phone": "+70578304541"}
0005434822032	A842A5	9411 578799	DINA LOGINOVA	{"email": "dloginova.1974@postgrespro.ru", "phone": "+70892081495"}
0005434822033	A842A5	4220 830341	ELENA RYABOVA	{"phone": "+70275891756"}
0005434822034	548351	4518 634756	ELENA SAVELEVA	{"phone": "+70592214072"}
0005434822035	1536C4	9062 385037	NADEZHDA ZOTOVA	{"email": "n-zotova-011968@postgrespro.ru", "phone": "+70145536064"}
0005434822036	898248	4937 527234	OLGA BELYAEVA	{"phone": "+70350333008"}
0005434822037	898248	0306 777943	PAVEL PETROV	{"phone": "+70223947809"}
0005434822038	898248	9606 343170	TATYANA NAZAROVA	{"phone": "+70083944883"}
0005434822039	81C759	7713 424060	SERGEY KUZNECOV	{"email": "sergey.kuznecov101963@postgrespro.ru", "phone": "+70308026812"}
0005434822040	EE9F3F	6920 515534	ANTON ANDREEV	{"email": "a-andreev.11021970@postgrespro.ru", "phone": "+70992590186"}
0005434822041	7D9E7F	0039 927065	ALFIYA ZAYCEVA	{"phone": "+70958197600"}
0005434822042	7D9E7F	9209 671994	NIKOLAY NIKITIN	{"email": "nikolay.nikitin-26081980@postgrespro.ru", "phone": "+70815129233"}
0005434822043	AD9EB8	2095 107340	ALEKSANDR KUZNECOV	{"phone": "+70950764837"}
0005434822044	0692EB	3127 567785	VLADIMIR IVANOV	{"phone": "+70829780323"}
0005434822045	0692EB	7216 752380	OLGA MASLOVA	{"phone": "+70814912133"}
0005434822046	4BF8EF	1945 684906	SEMEN OSIPOV	{"email": "osipov_s22051972@postgrespro.ru", "phone": "+70621858321"}
0005434822047	11389E	6892 307943	VLADIMIR IVANOV	{"phone": "+70552382322"}
0005434822048	11389E	3802 936348	ALENA GAVRILOVA	{"phone": "+70536675090"}
0005434822049	3D56B9	0849 636389	ALEKSEY BONDARENKO	{"email": "bondarenko-aleksey.1965@postgrespro.ru", "phone": "+70646564608"}
0005434822050	CD6C58	6164 936389	VLADIMIR GUSEV	{"email": "gusev-vladimir-1971@postgrespro.ru", "phone": "+70603448444"}
0005434822051	CD6C58	2351 738796	IVAN ROMANOV	{"email": "romanovi_1982@postgrespro.ru", "phone": "+70650789520"}
0005434822052	87512C	6761 709069	GEORGIY FILIPPOV	{"email": "filippovgeorgiy-1974@postgrespro.ru", "phone": "+70096771367"}
0005434822053	4F99C1	3013 656875	AMIR AFANASEV	{"phone": "+70426740368"}
0005434822054	2BF5B5	1698 480323	VASILIY MIKHAYLOV	{"email": "vasiliy-mikhaylov.011978@postgrespro.ru", "phone": "+70668233158"}
0005434822055	849FD2	4813 730694	VASILIY KUZMIN	{"phone": "+70887570522"}
0005434822056	849FD2	8854 696142	GULIYA NIKOLAEVA	{"phone": "+70860216210"}
0005434822057	849FD2	4187 596842	IRINA ZAKHAROVA	{"email": "zakharova.i-01111964@postgrespro.ru", "phone": "+70011478407"}
0005434822058	DD28F3	3983 044778	SERGEY GAVRILOV	{"email": "gavrilov_sergey071973@postgrespro.ru", "phone": "+70595494253"}
0005434822059	278835	3644 235052	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr-101977@postgrespro.ru", "phone": "+70810123423"}
0005434822060	2F2636	1249 723058	ALEKSANDRA CHERNOVA	{"email": "aleksandra.chernova-02111975@postgrespro.ru", "phone": "+70328654953"}
0005434822061	889A5D	1329 174709	ANATOLIY BONDARENKO	{"email": "bondarenko.anatoliy051969@postgrespro.ru", "phone": "+70812110434"}
0005434822062	889A5D	7319 660051	YAN MAKAROV	{"phone": "+70533486719"}
0005434822063	889A5D	7229 620047	NINA SOROKINA	{"phone": "+70028856222"}
0005434822064	487C14	4693 319397	TATYANA SOKOLOVA	{"phone": "+70937184983"}
0005434822065	55ED25	6373 050059	IRINA VLASOVA	{"email": "vlasova.i1976@postgrespro.ru", "phone": "+70311935473"}
0005434822123	4B304F	7733 382133	MAKSIM GUSEV	{"phone": "+70938179602"}
0005434822066	6CB57C	7882 811070	ANNA KOROLEVA	{"email": "koroleva.a1960@postgrespro.ru", "phone": "+70313543136"}
0005434822067	8F42B2	4137 258742	LYUBOV DANILOVA	{"email": "lyubov_danilova_111977@postgrespro.ru", "phone": "+70626761356"}
0005434822068	A0584F	1134 563410	GALINA ANDREEVA	{"email": "galinaandreeva_081982@postgrespro.ru", "phone": "+70779311684"}
0005434822069	A0584F	4339 014985	ELENA SMIRNOVA	{"phone": "+70605127998"}
0005434822070	E5FA5F	9909 836044	ANDREY NIKOLAEV	{"email": "a.nikolaev-02041977@postgrespro.ru", "phone": "+70411507802"}
0005434822071	E5FA5F	2007 331832	ELENA SEMENOVA	{"email": "semenovaelena_30121970@postgrespro.ru", "phone": "+70954852520"}
0005434822072	9801FB	2819 964034	ANASTASIYA KOVALEVA	{"email": "a_kovaleva-1972@postgrespro.ru", "phone": "+70978192052"}
0005434822073	5B0076	5851 887134	ANDREY RODIONOV	{"email": "rodionov_a1975@postgrespro.ru", "phone": "+70685231421"}
0005434822074	5B0076	9036 387193	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.14071962@postgrespro.ru", "phone": "+70732039902"}
0005434822075	6BEB0D	6542 045208	DENIS SEMENOV	{"email": "semenov_d.021981@postgrespro.ru", "phone": "+70198443648"}
0005434822076	695611	6549 379192	GRIGORIY NAZAROV	{"email": "grigoriy_nazarov-1972@postgrespro.ru", "phone": "+70478144847"}
0005434822077	70021B	1943 685826	PETR KUZMIN	{"phone": "+70859582489"}
0005434822078	70021B	2667 682554	MIKHAIL EGOROV	{"email": "egorov_m-091977@postgrespro.ru", "phone": "+70869122326"}
0005434822079	6E29D7	1485 114013	ANATOLIY ZHUKOV	{"phone": "+70307155785"}
0005434822080	B8A9E0	0952 343199	ALEKSANDR GRIGOREV	{"email": "aleksandr-grigorev_121976@postgrespro.ru", "phone": "+70436988525"}
0005434822081	2CD286	3466 511811	POLINA LAZAREVA	{"email": "polina.lazareva101975@postgrespro.ru", "phone": "+70398634758"}
0005434822082	AAC933	9706 702880	LARISA NOVIKOVA	{"phone": "+70733210182"}
0005434822083	9F563A	1495 856879	ANTON KUDRYASHOV	{"email": "kudryashov-a_111968@postgrespro.ru", "phone": "+70652534909"}
0005434822084	9F563A	5479 846581	NATALYA NIKOLAEVA	{"email": "nikolaevan.27041968@postgrespro.ru", "phone": "+70524438627"}
0005434822141	86596E	3170 681023	NADEZHDA IVANOVA	{"phone": "+70078826693"}
0005434822085	78972F	4652 246533	VLADIMIR VOLKOV	{"email": "volkov_vladimir.081974@postgrespro.ru", "phone": "+70859364265"}
0005434822086	B4F410	3836 836744	SVETLANA MAKSIMOVA	{"phone": "+70549594689"}
0005434822087	B4F410	6605 101733	ALEKSANDR KUZNECOV	{"email": "kuznecov.a-16081978@postgrespro.ru", "phone": "+70450804038"}
0005434822088	741013	2711 877879	SVETLANA NIKITINA	{"email": "svetlana-nikitina.051976@postgrespro.ru", "phone": "+70758789859"}
0005434822089	165B0C	2216 262707	ALEKSEY SHEVCHENKO	{"email": "a-shevchenko-1970@postgrespro.ru", "phone": "+70601826893"}
0005434822090	165B0C	8307 055193	ANNA KUZNECOVA	{"email": "akuznecova091964@postgrespro.ru", "phone": "+70782604483"}
0005434822091	A641C1	9509 403258	NINA ANDREEVA	{"phone": "+70180652244"}
0005434822092	B39423	5776 568375	YURIY TIKHONOV	{"phone": "+70469160781"}
0005434822093	B39423	1722 381709	MAKSIM OSIPOV	{"phone": "+70827785767"}
0005434822094	C103B8	6551 051368	EVGENIY GAVRILOV	{"phone": "+70725006719"}
0005434822095	BBE645	0558 552389	EKATERINA MIRONOVA	{"phone": "+70120555111"}
0005434822096	C59211	4442 467800	SERGEY SCHERBAKOV	{"phone": "+70729881465"}
0005434822097	F36C9C	0723 035793	OLEG MARTYNOV	{"email": "o_martynov041962@postgrespro.ru", "phone": "+70299952444"}
0005434822098	727E95	9160 851627	ZINAIDA LAZAREVA	{"email": "zlazareva_1982@postgrespro.ru", "phone": "+70862267759"}
0005434822099	D40911	7679 422130	GALINA FROLOVA	{"phone": "+70297011233"}
0005434822100	CB6DEF	4784 130993	EMIL KULIKOV	{"phone": "+70930675103"}
0005434822101	16343C	0640 610000	VALERIY YAKOVLEV	{"email": "yakovlev.valeriy_24031959@postgrespro.ru", "phone": "+70656865248"}
0005434822102	16343C	3991 343468	IVAN NAUMOV	{"phone": "+70658020982"}
0005434822103	450002	4601 603169	ILYA ANTONOV	{"phone": "+70828970715"}
0005434822104	450002	7732 177313	ALEKSANDR MAKAROV	{"email": "a.makarov.1978@postgrespro.ru", "phone": "+70254514229"}
0005434822105	15AF85	9916 288227	SERGEY EGOROV	{"email": "sergey-egorov.091972@postgrespro.ru", "phone": "+70877367221"}
0005434822106	15AF85	6262 577879	ALEKSEY TIMOFEEV	{"email": "timofeev-a.041974@postgrespro.ru", "phone": "+70354020146"}
0005434822107	6D444E	0177 019897	VLADIMIR VASILEV	{"email": "v_vasilev_011969@postgrespro.ru", "phone": "+70389045926"}
0005434822108	2F9F99	0015 877067	SVETLANA GORBUNOVA	{"phone": "+70783110534"}
0005434822109	2F9F99	9954 631959	TIMUR FEDOTOV	{"email": "timur_fedotov_1975@postgrespro.ru", "phone": "+70992415947"}
0005434822110	2F9F99	6511 622726	EKATERINA DMITRIEVA	{"email": "dmitrievaekaterina-081966@postgrespro.ru", "phone": "+70013573522"}
0005434822111	F014D4	9835 005869	PAVEL KUZNECOV	{"email": "kuznecov-p-16091964@postgrespro.ru", "phone": "+70791540389"}
0005434822112	D090EC	4671 555433	VERA ZOTOVA	{"phone": "+70903142802"}
0005434822113	D090EC	0346 058665	ANNA SMIRNOVA	{"phone": "+70104382748"}
0005434822114	D090EC	6094 344151	LYUBOV STEPANOVA	{"email": "stepanova_lyubov081966@postgrespro.ru", "phone": "+70050379356"}
0005434822115	D090EC	0089 275061	OLGA ROMANOVA	{"email": "romanovao-051957@postgrespro.ru", "phone": "+70104793227"}
0005434822116	8BC01B	3253 688740	NATALIYA IVANOVA	{"email": "ivanova.nataliya.1962@postgrespro.ru", "phone": "+70377654348"}
0005434822117	128818	6299 805344	LYUDMILA VASILEVA	{"phone": "+70425871977"}
0005434822118	EB5111	8860 627759	ANATOLIY ANDREEV	{"email": "a.andreev.17071966@postgrespro.ru", "phone": "+70647386745"}
0005434822119	3517EA	0406 049687	OLEG MATVEEV	{"email": "omatveev_1966@postgrespro.ru", "phone": "+70904262657"}
0005434822120	FDB7A3	6231 219306	DARYA IVANOVA	{"phone": "+70101405678"}
0005434822121	D639AA	4502 635430	GALINA POLYAKOVA	{"email": "g_polyakova021970@postgrespro.ru", "phone": "+70454993967"}
0005434822122	D639AA	4400 466247	RAISA BELYAEVA	{"email": "belyaevaraisa1974@postgrespro.ru", "phone": "+70097256795"}
0005434822124	E87C18	6007 847883	GALINA KUDRYASHOVA	{"email": "kudryashova-galina-121978@postgrespro.ru", "phone": "+70715493401"}
0005434822125	E87C18	2608 593118	ANDREY FROLOV	{"email": "andreyfrolov.14081979@postgrespro.ru", "phone": "+70784900500"}
0005434822126	6AA67F	6580 902256	DARYA ZOTOVA	{"email": "d_zotova.12011980@postgrespro.ru", "phone": "+70309693855"}
0005434822127	6AA67F	4087 180032	NATALIYA POPOVA	{"email": "n.popova1973@postgrespro.ru", "phone": "+70919359248"}
0005434822128	1DD632	2717 272447	VADIM KRASNOV	{"email": "v_krasnov_15011970@postgrespro.ru", "phone": "+70614285658"}
0005434822129	E009F8	1117 234831	ALEKSANDR MATVEEV	{"email": "matveev-a28011969@postgrespro.ru", "phone": "+70828632593"}
0005434822130	12E4B6	2117 047549	TAMARA VOLKOVA	{"phone": "+70779012997"}
0005434822131	12E4B6	0064 328306	YURIY IVANOV	{"email": "y_ivanov_21071961@postgrespro.ru", "phone": "+70421183494"}
0005434822132	DD4BD9	5557 696343	PAVEL KOZLOV	{"email": "kozlov_p-10071961@postgrespro.ru", "phone": "+70790691018"}
0005434822133	61FD94	9148 628501	ANASTASIYA FROLOVA	{"phone": "+70474717095"}
0005434822134	86B391	2079 601739	POLINA PETROVA	{"email": "polina.petrova1969@postgrespro.ru", "phone": "+70097735427"}
0005434822135	A78B62	9330 345569	ALEKSEY ZAYCEV	{"phone": "+70618339065"}
0005434822136	0F2A27	6130 855667	VLADIMIR MELNIKOV	{"phone": "+70951685555"}
0005434822137	8AE486	5951 353752	MIKHAIL SCHERBAKOV	{"email": "mikhail.scherbakov031967@postgrespro.ru", "phone": "+70265746601"}
0005434822138	66EC00	8933 311154	IGOR SOLOVEV	{"phone": "+70049303046"}
0005434822139	66EC00	7893 321769	ILNAR DENISOV	{"email": "denisov-ilnar.16101969@postgrespro.ru", "phone": "+70336035563"}
0005434822140	86596E	1809 911842	VLADIMIR ORLOV	{"phone": "+70036518171"}
0005434822142	82DC78	2176 840304	VLADISLAV KUDRYASHOV	{"email": "kudryashov.v-051971@postgrespro.ru", "phone": "+70884567853"}
0005434822143	C55555	7580 518426	LIDIYA DENISOVA	{"phone": "+70445859022"}
0005434822144	C55555	8705 304771	MARIYA ROMANOVA	{"phone": "+70303660537"}
0005434822145	57ECA1	2173 152660	VALENTINA DENISOVA	{"email": "valentinadenisova-09061972@postgrespro.ru", "phone": "+70031782438"}
0005434822146	F4B2E3	9512 330657	NINA PETROVA	{"email": "petrova_n.091973@postgrespro.ru", "phone": "+70053795270"}
0005434822147	1ACF37	3619 133937	GENNADIY MAKAROV	{"email": "makarov.g_101970@postgrespro.ru", "phone": "+70280825983"}
0005434822148	F067E5	7778 708770	EKATERINA LUKYANOVA	{"phone": "+70371363001"}
0005434822149	9415D1	4065 574509	KSENIYA IVANOVA	{"email": "ivanova.k1964@postgrespro.ru", "phone": "+70071837135"}
0005434822150	830760	6495 953762	SERGEY KOROLEV	{"email": "korolev-sergey_071975@postgrespro.ru", "phone": "+70812555121"}
0005434822151	8E10FF	8343 217037	DMITRIY KUDRYASHOV	{"phone": "+70813235161"}
0005434822152	8E10FF	8728 454069	EDUARD FEDOTOV	{"email": "eduard.fedotov_1973@postgrespro.ru", "phone": "+70290695297"}
0005434822153	70E573	0953 667940	MAKSIM KONOVALOV	{"phone": "+70456813980"}
0005434822154	70E573	3499 555863	DARYA RYABOVA	{"phone": "+70482820936"}
0005434822155	70E573	8339 141852	ELENA ZHUKOVA	{"email": "zhukovaelena111977@postgrespro.ru", "phone": "+70047971607"}
0005434822156	ABD4E6	9536 480071	GALIYA KULIKOVA	{"email": "gkulikova1963@postgrespro.ru", "phone": "+70323842409"}
0005434822157	2FA8E2	8274 063270	RAFAIL FILIPPOV	{"phone": "+70823979961"}
0005434822158	89813F	9324 772439	YULIYA ALEKSEEVA	{"email": "alekseeva.yuliya1982@postgrespro.ru", "phone": "+70387879339"}
0005434822159	89813F	7563 364325	PAVEL KUZNECOV	{"phone": "+70966202441"}
0005434822160	624642	7463 940849	NATALYA NESTEROVA	{"phone": "+70582797197"}
0005434822161	B0E9B3	0621 330038	TAMARA ANISIMOVA	{"email": "tamara_anisimova-1967@postgrespro.ru", "phone": "+70196986775"}
0005434822162	B0E9B3	2683 442751	NATALYA NIKITINA	{"phone": "+70169854225"}
0005434822163	A65D36	7698 070344	ANNA CHERNOVA	{"email": "chernovaanna08101973@postgrespro.ru", "phone": "+70376397096"}
0005434822164	A6C16D	1051 492029	ALEKSANDR FROLOV	{"email": "aleksandr.frolov1969@postgrespro.ru", "phone": "+70123219057"}
0005434822165	A6C16D	4419 550889	ELENA SEMENOVA	{"email": "semenovae.1969@postgrespro.ru", "phone": "+70782996127"}
0005434822166	4C171D	0979 230511	SVETLANA VOLKOVA	{"phone": "+70128335298"}
0005434822167	4C171D	3357 288912	OLEG KARPOV	{"email": "o_karpov-031967@postgrespro.ru", "phone": "+70071761554"}
0005434822168	6339C7	9082 316852	KONSTANTIN GERASIMOV	{"email": "konstantin_gerasimov.12071977@postgrespro.ru", "phone": "+70546287028"}
0005434822169	6339C7	4153 251851	EDUARD ZHURAVLEV	{"email": "eduard-zhuravlev1991@postgrespro.ru", "phone": "+70144091745"}
0005434822170	156ADF	1474 630702	EVGENIY SIDOROV	{"phone": "+70720795746"}
0005434822171	B2B2FC	4878 420657	SERGEY DENISOV	{"email": "denisovsergey091974@postgrespro.ru", "phone": "+70448876844"}
0005434822172	B2B2FC	9985 422816	NAILYA NOVIKOVA	{"phone": "+70908952852"}
0005434822173	B4E577	1484 721206	NIKOLAY KOZLOV	{"phone": "+70915662684"}
0005434822174	F37F39	1593 671369	ANGELINA SOROKINA	{"email": "sorokina-a_011975@postgrespro.ru", "phone": "+70306904485"}
0005434822175	F37F39	0362 704490	ALEKSANDR DAVYDOV	{"email": "aleksandr-davydov-1961@postgrespro.ru", "phone": "+70924761776"}
0005434822176	5F783B	3674 927946	SERGEY KUZMIN	{"email": "kuzmin.s1963@postgrespro.ru", "phone": "+70200279316"}
0005434822177	74AFE1	2397 943109	OKSANA BELOVA	{"phone": "+70552807018"}
0005434822178	E5C65F	3967 187253	RAISA ERMAKOVA	{"phone": "+70252247063"}
0005434822179	E5C65F	2415 125319	ALEKSANDR MIRONOV	{"email": "mironova_10021964@postgrespro.ru", "phone": "+70510607982"}
0005434822180	FB46CD	9212 578404	ALEKSEY MIKHAYLOV	{"phone": "+70520202524"}
0005434822181	3E2909	6431 743739	IRINA BORISOVA	{"email": "borisova-i_1976@postgrespro.ru", "phone": "+70373691427"}
0005434822182	83AB23	8775 475965	LYUDMILA NESTEROVA	{"phone": "+70885670008"}
0005434822183	83AB23	2305 395751	ANNA SIDOROVA	{"phone": "+70695350746"}
0005434822184	83AB23	5882 110418	YURIY NIKOLAEV	{"phone": "+70635004886"}
0005434822185	A48913	7121 409099	IGOR VOROBEV	{"email": "igorvorobev_1964@postgrespro.ru", "phone": "+70311952461"}
0005434822186	D9E96C	3298 582610	ANDREY KUZMIN	{"email": "kuzmin_a.12031977@postgrespro.ru", "phone": "+70083300019"}
0005434822187	72D633	6288 456229	IGOR MAKAROV	{"phone": "+70309021586"}
0005434822188	0B1855	9217 086176	ANTONINA SOROKINA	{"email": "sorokina-antonina-1974@postgrespro.ru", "phone": "+70753006740"}
0005434822189	4DF09C	5044 342897	FEDOR SAVELEV	{"email": "savelev_fedor_09061962@postgrespro.ru", "phone": "+70479231791"}
0005434822190	2AA45B	3435 998105	PAVEL KONOVALOV	{"phone": "+70112010831"}
0005434822191	2AA45B	6017 941719	ILYA ZAYCEV	{"phone": "+70740122973"}
0005434822192	2AA45B	2881 401057	VLADIMIR VASILEV	{"phone": "+70804348174"}
0005434822193	5C73A8	3281 643964	ANZHELIKA ABRAMOVA	{"email": "abramova-a11101985@postgrespro.ru", "phone": "+70603902824"}
0005434822194	80125E	8486 737726	ALEKSANDRA AKIMOVA	{"phone": "+70881026322"}
0005434822195	80125E	8618 854380	ANASTASIYA NIKOLAEVA	{"phone": "+70528076760"}
0005434822196	3BB827	8980 395843	ANNA NAUMOVA	{"phone": "+70639578444"}
0005434822197	3A48A0	5454 445688	SERGEY NAZAROV	{"email": "s.nazarov-091958@postgrespro.ru", "phone": "+70597189560"}
0005434822198	3A48A0	3239 407763	ANTON SHEVCHENKO	{"phone": "+70354117630"}
0005434822199	3A48A0	6075 310362	VALERIY DENISOV	{"email": "denisovvaleriy.1972@postgrespro.ru", "phone": "+70817659315"}
0005434822200	7E3E33	1272 564657	NATALIYA KUZMINA	{"phone": "+70245132430"}
0005434822201	7E3E33	0505 961549	VLADISLAV KUDRYASHOV	{"phone": "+70057740138"}
0005434822202	856EF4	6141 682456	ALEKSEY DMITRIEV	{"phone": "+70125080472"}
0005434822203	7FBCD6	5767 450037	PAVEL ZAYCEV	{"email": "pavel.zaycev_041963@postgrespro.ru", "phone": "+70412084162"}
0005434822204	D6EF34	5844 767633	DMITRIY ABRAMOV	{"email": "abramov-dmitriy031978@postgrespro.ru", "phone": "+70892567593"}
0005434822205	AC740B	7786 032748	VIKTOR ILIN	{"email": "v.ilin.14051979@postgrespro.ru", "phone": "+70860766391"}
0005434822206	9E5F75	1423 972056	IVAN DAVYDOV	{"email": "davydov_i-021961@postgrespro.ru", "phone": "+70010035103"}
0005434822207	9E5F75	5053 751296	VALENTINA OSIPOVA	{"phone": "+70165239084"}
0005434822208	010CE0	0322 164233	VYACHESLAV NAUMOV	{"phone": "+70166801426"}
0005434822209	5808C8	1477 099703	NIKOLAY SCHERBAKOV	{"email": "scherbakov-n121978@postgrespro.ru", "phone": "+70352865895"}
0005434822210	7EAFDC	6620 871392	DMITRIY BORISOV	{"email": "dmitriy-borisov10111969@postgrespro.ru", "phone": "+70724223648"}
0005434822211	2444C9	1146 590687	ALEKSANDR SOKOLOV	{"email": "a_sokolov-03111969@postgrespro.ru", "phone": "+70322734162"}
0005434822212	773380	4553 511084	TATYANA KALININA	{"email": "tatyana_kalinina-1973@postgrespro.ru", "phone": "+70846702402"}
0005434822213	2AC61B	5387 644182	TATYANA ZHUKOVA	{"email": "zhukova-tatyana-1972@postgrespro.ru", "phone": "+70523157350"}
0005434822214	6E50D8	9766 417610	ANNA DMITRIEVA	{"email": "annadmitrieva_1982@postgrespro.ru", "phone": "+70879778755"}
0005434822215	1C11C7	4462 194616	VLADIMIR EGOROV	{"phone": "+70283128369"}
0005434822216	36F9C1	3958 036045	STANISLAV SIDOROV	{"email": "stanislavsidorov-1972@postgrespro.ru", "phone": "+70055617114"}
0005434822217	36F9C1	6169 551292	GALINA ABRAMOVA	{"email": "gabramova16021973@postgrespro.ru", "phone": "+70234339118"}
0005434822218	08447F	0031 025674	NINA MAKSIMOVA	{"email": "n.maksimova-1986@postgrespro.ru", "phone": "+70625093415"}
0005434822219	966AAD	0919 514682	ALEKSEY BORISOV	{"phone": "+70899543064"}
0005434822220	5E93FE	5373 151135	OLGA MARTYNOVA	{"email": "martynova_olga_07121977@postgrespro.ru", "phone": "+70047572245"}
0005434822221	5E93FE	5265 874354	OLGA NIKOLAEVA	{"email": "onikolaeva.02041958@postgrespro.ru", "phone": "+70214273008"}
0005434822222	B91FAA	4238 745659	MAKSIM ABRAMOV	{"email": "abramov_maksim-29011974@postgrespro.ru", "phone": "+70538953436"}
0005434822223	DD7B47	9429 622814	LYUDMILA YAKOVLEVA	{"phone": "+70097857417"}
0005434822224	D72BEF	3216 344813	VALENTIN BARANOV	{"email": "valentin_baranov-041983@postgrespro.ru", "phone": "+70562736466"}
0005434822225	C17C10	8920 103312	DARYA ZHURAVLEVA	{"phone": "+70816362485"}
0005434822226	B86C21	9260 277900	MAKSIM ZAKHAROV	{"email": "zakharov.maksim23021968@postgrespro.ru", "phone": "+70656186563"}
0005434822227	59980F	6060 452955	VLADISLAV EGOROV	{"email": "egorov_v.24121964@postgrespro.ru", "phone": "+70814083019"}
0005434822228	473EE6	6736 422114	IRINA SERGEEVA	{"email": "sergeeva_i.1971@postgrespro.ru", "phone": "+70574036484"}
0005434822229	473EE6	4758 770998	VALENTINA MALYSHEVA	{"email": "malysheva_valentina.051970@postgrespro.ru", "phone": "+70165703409"}
0005434822230	98A2C1	6350 027430	NATALYA LEBEDEVA	{"phone": "+70624520345"}
0005434822231	483A9B	0102 368518	ELENA SCHERBAKOVA	{"email": "e_scherbakova_1964@postgrespro.ru", "phone": "+70303002873"}
0005434822232	F4BB98	2512 867779	MARGARITA NOVIKOVA	{"email": "margarita_novikova081970@postgrespro.ru", "phone": "+70642269128"}
0005434822233	F4BB98	5679 848590	IGOR ABRAMOV	{"phone": "+70836286473"}
0005434822234	A4C7C1	0919 936654	NINA IVANOVA	{"phone": "+70315669721"}
0005434822235	C97831	7513 092965	MARINA SERGEEVA	{"email": "sergeeva_marina_1973@postgrespro.ru", "phone": "+70577815793"}
0005434822236	AE5DBB	2333 823871	IRINA KUZNECOVA	{"phone": "+70794974581"}
0005434822237	42C08F	9543 919409	VALENTINA FEDOROVA	{"email": "valentinafedorova.061967@postgrespro.ru", "phone": "+70268235939"}
0005434822238	2BD086	7829 023569	IRINA KOVALEVA	{"phone": "+70050398133"}
0005434822239	2D3231	7875 876655	ARTEM CHERNOV	{"phone": "+70797667025"}
0005434822240	033083	7341 219579	YULIYA ARKHIPOVA	{"email": "arkhipova.y.1992@postgrespro.ru", "phone": "+70721080624"}
0005434822241	5F5C8B	9688 587878	ELENA KUZMINA	{"phone": "+70932053347"}
0005434822242	2D3CF8	4057 051553	LARISA ALEKSANDROVA	{"email": "aleksandrova.larisa_1969@postgrespro.ru", "phone": "+70726502515"}
0005434822243	2D3CF8	0203 550752	SVETLANA ABRAMOVA	{"email": "s.abramova-06101977@postgrespro.ru", "phone": "+70448334641"}
0005434822244	32B0BB	0288 124674	GALINA KONOVALOVA	{"email": "konovalovagalina.1970@postgrespro.ru", "phone": "+70713412800"}
0005434822245	436476	3834 852607	ANDREY NOVIKOV	{"email": "novikov-andrey.1972@postgrespro.ru", "phone": "+70830065682"}
0005434822246	0D9533	4770 839390	LYUDMILA KUDRYASHOVA	{"email": "lyudmila.kudryashova1970@postgrespro.ru", "phone": "+70812895823"}
0005434822247	0D9533	7822 864040	VYACHESLAV KOZLOV	{"phone": "+70481377337"}
0005434822248	222182	0651 761701	OLGA MIRONOVA	{"phone": "+70622928788"}
0005434822249	222182	1521 905606	VLADIMIR ZHUKOV	{"email": "zhukov-vladimir.19061979@postgrespro.ru", "phone": "+70837770853"}
0005434822250	222182	6475 298000	GULFIYA ZHUKOVA	{"email": "zhukova_gulfiya08101970@postgrespro.ru", "phone": "+70185908859"}
0005434822251	F6B22D	1080 185226	VLADIMIR FILIPPOV	{"email": "v_filippov101973@postgrespro.ru", "phone": "+70036243186"}
0005434822252	F6B22D	2724 406564	ANNA SAVELEVA	{"email": "savelevaa_1960@postgrespro.ru", "phone": "+70666821735"}
0005434822253	B64ADF	1585 354245	RAISA ZAYCEVA	{"email": "zaycevaraisa.1966@postgrespro.ru", "phone": "+70655660377"}
0005434822254	B64ADF	6592 984692	ANNA SCHERBAKOVA	{"phone": "+70097844023"}
0005434822255	D76853	1086 641083	ALEKSANDR AFANASEV	{"phone": "+70546295903"}
0005434822256	D76853	6308 757403	OLGA SERGEEVA	{"email": "o-sergeeva081973@postgrespro.ru", "phone": "+70646097958"}
0005434822257	4BCE80	4329 584438	EKATERINA IVANOVA	{"phone": "+70954076464"}
0005434822258	FC8C0C	0620 221854	VLADIMIR SEMENOV	{"email": "semenov_vladimir27011965@postgrespro.ru", "phone": "+70824493267"}
0005434822259	7D9405	7762 194602	YURIY SEMENOV	{"phone": "+70973137996"}
0005434822260	4420E5	8634 579247	VIKTORIYA MOROZOVA	{"email": "v_morozova-1980@postgrespro.ru", "phone": "+70588575346"}
0005434822261	4420E5	5942 662234	ALEKSANDRA SMIRNOVA	{"email": "smirnovaaleksandra15111980@postgrespro.ru", "phone": "+70111688808"}
0005434822262	4420E5	9715 590554	ALEKSANDR ZHUKOV	{"phone": "+70725670415"}
0005434822263	503BE2	3150 673155	NIKOLAY POPOV	{"email": "popov.nikolay1970@postgrespro.ru", "phone": "+70170200446"}
0005434822264	E08787	3917 142600	ELENA EGOROVA	{"email": "elena-egorova-061961@postgrespro.ru", "phone": "+70176424789"}
0005434822265	9A16DA	7331 158886	IRINA KUZNECOVA	{"phone": "+70697412924"}
0005434822266	9A16DA	1776 618540	TAMARA FOMINA	{"phone": "+70562057005"}
0005434822267	F5656D	0219 051533	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr.091977@postgrespro.ru", "phone": "+70664494573"}
0005434822268	BDCB32	4316 921884	GALINA TIMOFEEVA	{"phone": "+70580439736"}
0005434822269	7F1573	4960 945802	VALENTINA ANISIMOVA	{"email": "anisimova_valentina16051976@postgrespro.ru", "phone": "+70015219423"}
0005434822270	2A2BAD	9415 595516	TAMARA IVANOVA	{"email": "ivanova.tamara-15091968@postgrespro.ru", "phone": "+70275081416"}
0005434822271	2A2BAD	6773 243633	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev-03111982@postgrespro.ru", "phone": "+70589301653"}
0005434822272	AA22CD	9552 519468	GALINA KRASNOVA	{"email": "galina.krasnova_071973@postgrespro.ru", "phone": "+70418175457"}
0005434822273	F68D13	3763 727537	DMITRIY NAZAROV	{"phone": "+70052022270"}
0005434822274	B04906	8745 690703	GEORGIY ALEKSEEV	{"phone": "+70455679387"}
0005434822275	B04906	3486 246209	ALEKSANDRA FEDOROVA	{"email": "aleksandra_fedorova-02121963@postgrespro.ru", "phone": "+70623777518"}
0005434822276	D506E4	1192 971111	ALEKSEY IVANOV	{"email": "ivanov.a_121976@postgrespro.ru", "phone": "+70168128295"}
0005434822277	D506E4	4741 199661	IRINA AKIMOVA	{"email": "iakimova071972@postgrespro.ru", "phone": "+70853017864"}
0005434822278	136C12	6803 105442	IRINA VASILEVA	{"email": "vasileva-irina-1980@postgrespro.ru", "phone": "+70988308251"}
0005434822279	916B40	6557 705554	LYUDMILA KOROLEVA	{"email": "koroleva-l1974@postgrespro.ru", "phone": "+70234139158"}
0005434822280	D5E868	0998 082854	ALEKSANDR ABRAMOV	{"phone": "+70409524477"}
0005434822281	9AE184	0303 703990	EGOR MELNIKOV	{"phone": "+70352549315"}
0005434822282	9AE184	2084 181916	VARVARA MELNIKOVA	{"email": "varvara.melnikova.1968@postgrespro.ru", "phone": "+70782435061"}
0005434822283	4A5D58	2058 524013	ELIZAVETA EFIMOVA	{"email": "e_efimova101966@postgrespro.ru", "phone": "+70859955168"}
0005434822284	9916C1	4490 709699	RAMIL GERASIMOV	{"email": "rgerasimov081972@postgrespro.ru", "phone": "+70508383026"}
0005434822285	9A2551	4350 208447	OLGA PETROVA	{"email": "petrova-o_021979@postgrespro.ru", "phone": "+70090552694"}
0005434822286	9A2551	0358 342663	NATALYA AFANASEVA	{"phone": "+70322343277"}
0005434822287	A57E40	9950 710478	KONSTANTIN KUZNECOV	{"email": "kuznecov.konstantin_28121972@postgrespro.ru", "phone": "+70619186841"}
0005434822288	A57E40	3620 510434	ALEKSANDR ALEKSEEV	{"email": "a.alekseev-081964@postgrespro.ru", "phone": "+70025635691"}
0005434822289	69AE4F	3436 186667	ALENA GORBUNOVA	{"phone": "+70197650871"}
0005434822290	69AE4F	0838 881717	TATYANA KRASNOVA	{"email": "krasnova-t-1968@postgrespro.ru", "phone": "+70294870680"}
0005434822291	06B668	6726 682185	TATYANA GUSEVA	{"email": "guseva.tatyana121972@postgrespro.ru", "phone": "+70424297528"}
0005434822292	06B668	9753 670804	ZOYA MIRONOVA	{"phone": "+70583925041"}
0005434822293	E9EB90	9463 852001	EKATERINA ISAEVA	{"phone": "+70608640434"}
0005434822294	E9EB90	8348 189063	ANFISA KUZNECOVA	{"phone": "+70841118372"}
0005434822295	19595D	5056 569704	ALFIYA POTAPOVA	{"phone": "+70596354287"}
0005434822296	F14601	3606 819451	ALEKSANDR SOKOLOV	{"phone": "+70875627337"}
0005434822297	097680	2871 489501	MIKHAIL MATVEEV	{"phone": "+70652936586"}
0005434822298	95C782	0687 112980	TATYANA KRASNOVA	{"email": "krasnovat_1966@postgrespro.ru", "phone": "+70605407904"}
0005434822299	42416A	8267 525930	TATYANA STEPANOVA	{"phone": "+70831750176"}
0005434822300	9BD97F	5045 616691	ROZA PETROVA	{"email": "rpetrova06071978@postgrespro.ru", "phone": "+70074882040"}
0005434822301	9BD97F	6151 635502	VALENTINA VOLKOVA	{"phone": "+70464168022"}
0005434822302	6F105B	5851 664328	LIDIYA NESTEROVA	{"email": "nesterova-l.081967@postgrespro.ru", "phone": "+70539917545"}
0005434822303	36C513	4801 414427	ALEFTINA POTAPOVA	{"email": "a_potapova-1977@postgrespro.ru", "phone": "+70939286705"}
0005434822304	555085	3326 539877	ANDREY TIKHONOV	{"phone": "+70951205893"}
0005434822305	555085	6137 966179	ALEKSANDR NAUMOV	{"email": "naumov_aleksandr-111964@postgrespro.ru", "phone": "+70880059201"}
0005434822306	38A2FE	4308 781269	YULIYA OSIPOVA	{"email": "yuliya.osipova1982@postgrespro.ru", "phone": "+70667098615"}
0005434822307	307936	3296 553312	ALEKSANDR DAVYDOV	{"email": "davydovaleksandr_091970@postgrespro.ru", "phone": "+70348434924"}
0005434822308	DD3007	9363 785623	NINA IVANOVA	{"email": "ivanova_n24051975@postgrespro.ru", "phone": "+70214961800"}
0005434822309	DD3007	2644 470319	DMITRIY MAKSIMOV	{"email": "maksimov.d.011975@postgrespro.ru", "phone": "+70447952725"}
0005434822310	425067	5753 064709	ANNA MIKHAYLOVA	{"email": "mikhaylova_anna-1984@postgrespro.ru", "phone": "+70184568122"}
0005434822311	0D745A	8618 284094	LYUDMILA GUSEVA	{"email": "lyudmila.guseva_121977@postgrespro.ru", "phone": "+70138342569"}
0005434822312	41415A	3344 168053	VADIM PETROV	{"email": "petrov_vadim.1970@postgrespro.ru", "phone": "+70593183780"}
0005434822313	41415A	0284 928960	OLEG SAVELEV	{"email": "olegsavelev-1975@postgrespro.ru", "phone": "+70064754242"}
0005434822314	E99482	5530 482995	NADEZHDA ZHURAVLEVA	{"phone": "+70140292148"}
0005434822315	17457D	5791 697824	DMITRIY VOROBEV	{"email": "d_vorobev.22091970@postgrespro.ru", "phone": "+70502768903"}
0005434822316	DD43AF	7433 219561	VASILIY KONOVALOV	{"phone": "+70028231502"}
0005434822317	D02D52	9700 810164	PETR KUZMIN	{"email": "kuzmin-p-19081964@postgrespro.ru", "phone": "+70236544149"}
0005434822318	D02D52	6946 452446	VERA VASILEVA	{"email": "vasilevavera-121983@postgrespro.ru", "phone": "+70703175518"}
0005434822319	539C2E	3533 959757	PAVEL SOKOLOV	{"email": "pavel.sokolov1977@postgrespro.ru", "phone": "+70886060333"}
0005434822320	539C2E	6358 229879	GALINA NESTEROVA	{"email": "nesterova.galina1979@postgrespro.ru", "phone": "+70693274469"}
0005434822321	825883	6044 271761	ANASTASIYA MIKHAYLOVA	{"email": "anastasiyamikhaylova_101975@postgrespro.ru", "phone": "+70077491211"}
0005434822322	20F10C	0803 279796	ANFISA SMIRNOVA	{"phone": "+70647069938"}
0005434822323	6BF32D	3933 282051	ALEKSANDR IVANOV	{"email": "a.ivanov19051972@postgrespro.ru", "phone": "+70634491425"}
0005434822324	362A4B	1360 316718	VALENTINA FILATOVA	{"phone": "+70562069645"}
0005434822325	48C419	3490 644163	NATALYA ALEKSANDROVA	{"phone": "+70775755388"}
0005434822326	437FC2	4500 328723	VALENTINA MELNIKOVA	{"phone": "+70528824588"}
0005434822327	437FC2	0424 546927	TATYANA EGOROVA	{"phone": "+70415428760"}
0005434822328	761DC7	4384 297342	ANNA KOZLOVA	{"phone": "+70748643785"}
0005434822329	E113B3	1561 639676	PAVEL ZAKHAROV	{"email": "pavel-zakharov1966@postgrespro.ru", "phone": "+70837335439"}
0005434822330	E113B3	0402 446395	NIKOLAY MARTYNOV	{"phone": "+70279068947"}
0005434822331	DC2C67	7875 448598	ALEKSANDRA MIRONOVA	{"phone": "+70499927906"}
0005434822332	C05FE6	8504 526359	NATALYA POPOVA	{"phone": "+70270161461"}
0005434822333	EFF4EE	7994 296392	ARTEM KAZAKOV	{"email": "kazakov-artem_1980@postgrespro.ru", "phone": "+70872761131"}
0005434822334	EFF4EE	9408 670145	SERGEY BORISOV	{"email": "borisovs17011988@postgrespro.ru", "phone": "+70657329637"}
0005434822335	7A6F26	9221 609031	RAISA NOVIKOVA	{"email": "r-novikova_041973@postgrespro.ru", "phone": "+70490023920"}
0005434822336	7A6F26	6590 624521	GALINA POPOVA	{"phone": "+70682790388"}
0005434822337	308BA0	0688 253401	ALEKSEY MAKAROV	{"phone": "+70629247925"}
0005434822338	459FE2	2663 393536	EVDOKIYA NIKITINA	{"phone": "+70025389810"}
0005434822339	C04009	7229 134333	VYACHESLAV RODIONOV	{"email": "vyacheslav_rodionov031968@postgrespro.ru", "phone": "+70189664604"}
0005434822340	C04009	8347 694498	ALEKSANDR MAKSIMOV	{"phone": "+70429578665"}
0005434822341	418D12	3496 587669	SVYATOSLAV TARASOV	{"phone": "+70862070491"}
0005434822342	F9406B	4117 222151	NATALYA AKIMOVA	{"email": "natalya_akimova27111967@postgrespro.ru", "phone": "+70748741589"}
0005434822343	F9406B	5839 081173	IGOR IVANOV	{"phone": "+70736621463"}
0005434822344	C813D0	4186 736970	YURIY MIRONOV	{"phone": "+70172059017"}
0005434822345	C813D0	1756 460492	NATALYA MIKHAYLOVA	{"email": "mikhaylova-natalya-091964@postgrespro.ru", "phone": "+70149295800"}
0005434822346	C813D0	5420 889100	LARISA MALYSHEVA	{"phone": "+70521378119"}
0005434822347	D977BB	5383 826304	OLESYA MOROZOVA	{"phone": "+70183315694"}
0005434822348	B56B99	9138 406011	ANATOLIY POPOV	{"email": "popovanatoliy.19031969@postgrespro.ru", "phone": "+70069036535"}
0005434822349	89F0B0	1936 482941	MARIYA MAKAROVA	{"email": "makarova-mariya-07031971@postgrespro.ru", "phone": "+70433328890"}
0005434822350	89F0B0	2379 325768	RAISA ABRAMOVA	{"email": "abramovar-031981@postgrespro.ru", "phone": "+70412596569"}
0005434822351	E4E881	5740 055652	VIKTOR VOROBEV	{"email": "v-vorobev_1971@postgrespro.ru", "phone": "+70869470130"}
0005434822352	E4E881	5109 974714	INNA SCHERBAKOVA	{"email": "scherbakova.i-1974@postgrespro.ru", "phone": "+70734955205"}
0005434822353	1B87A9	4567 697438	PAVEL SOROKIN	{"email": "sorokin_p_1970@postgrespro.ru", "phone": "+70121479029"}
0005434822354	CFEF10	1512 331407	RINAT BORISOV	{"phone": "+70827947775"}
0005434822355	7206F2	8985 607844	MARIYA ALEKSEEVA	{"phone": "+70094900393"}
0005434822356	1A420C	9343 542967	DARYA KUZNECOVA	{"phone": "+70024432640"}
0005434822357	A9846F	2638 720906	ZINAIDA POPOVA	{"phone": "+70953132528"}
0005434822358	860872	2007 099825	SERGEY MOROZOV	{"phone": "+70209739447"}
0005434822359	A4EA73	8395 531966	VADIM DMITRIEV	{"phone": "+70591532308"}
0005434822360	9A9A71	5136 004611	STANISLAV GERASIMOV	{"email": "gerasimov_stanislav_11121975@postgrespro.ru", "phone": "+70740462630"}
0005434822361	0E404B	8353 854494	VLADIMIR KUZMIN	{"email": "vladimirkuzmin_20111976@postgrespro.ru", "phone": "+70205957144"}
0005434822362	0E404B	1505 736483	YULIYA ZOTOVA	{"email": "y-zotova_03051972@postgrespro.ru", "phone": "+70221191398"}
0005434822363	7C41B5	2416 466497	RAISA VOROBEVA	{"phone": "+70740376935"}
0005434822364	7C41B5	2890 454279	IRINA PETROVA	{"email": "i_petrova.091976@postgrespro.ru", "phone": "+70357003570"}
0005434822365	682F7A	1639 828839	VALERIYA IVANOVA	{"email": "v.ivanova.01011980@postgrespro.ru", "phone": "+70676326153"}
0005434822366	C83F6F	8648 581199	EKATERINA KOLESNIKOVA	{"email": "kolesnikova_ekaterina-17031967@postgrespro.ru", "phone": "+70298325585"}
0005434822367	226661	3952 102379	ALEKSEY SEMENOV	{"email": "aleksey-semenov14111966@postgrespro.ru", "phone": "+70934032346"}
0005434822368	4775E4	5598 962007	VITALIY ANDREEV	{"email": "andreev.v1973@postgrespro.ru", "phone": "+70095215302"}
0005434822369	4775E4	6076 512327	DMITRIY SOROKIN	{"phone": "+70289988641"}
0005434822370	6FA582	3961 303979	SVETLANA KOLESNIKOVA	{"email": "svetlana_kolesnikova-05021973@postgrespro.ru", "phone": "+70576401536"}
0005434822371	16D3D0	2927 478574	IRINA FROLOVA	{"phone": "+70604879742"}
0005434822372	16D3D0	3742 756966	LIDIYA STEPANOVA	{"email": "lidiya-stepanova.1963@postgrespro.ru", "phone": "+70596513486"}
0005434822373	FF9EFD	1569 035581	NIKITA NOVIKOV	{"phone": "+70549296144"}
0005434822374	2508C8	5370 093078	YULIYA DANILOVA	{"phone": "+70426655487"}
0005434822375	2508C8	2336 236611	ANASTASIYA DAVYDOVA	{"phone": "+70169483601"}
0005434822376	252E4A	4611 163081	MARIYA BELOVA	{"email": "m.belova_1965@postgrespro.ru", "phone": "+70001329638"}
0005434822377	252E4A	6906 126986	DANIL AFANASEV	{"phone": "+70112386759"}
0005434822378	C88DAB	8572 398281	ANATOLIY ZAYCEV	{"email": "zaycev_a29041982@postgrespro.ru", "phone": "+70940908691"}
0005434822379	C88DAB	3676 417734	ALEKSANDRA SOLOVEVA	{"email": "aleksandra_soloveva_1979@postgrespro.ru", "phone": "+70557866636"}
0005434822380	065BA5	9509 338455	OLEG MAKAROV	{"email": "oleg_makarov_1981@postgrespro.ru", "phone": "+70482817357"}
0005434822381	065BA5	4741 716012	EMMA ROMANOVA	{"phone": "+70345770881"}
0005434822382	5F05CE	4515 902483	ROMAN BONDARENKO	{"email": "roman-bondarenko_25081976@postgrespro.ru", "phone": "+70041377062"}
0005434822383	5F05CE	1674 018354	DENIS MEDVEDEV	{"email": "dmedvedev_071977@postgrespro.ru", "phone": "+70333726859"}
0005434822384	5F05CE	5898 759185	MARINA ILINA	{"phone": "+70303748915"}
0005434822385	A0C6A4	4033 528103	ZINAIDA PETROVA	{"email": "zpetrova.031965@postgrespro.ru", "phone": "+70618507497"}
0005434822386	A0C6A4	4703 363688	GALINA BARANOVA	{"email": "baranova-g-1973@postgrespro.ru", "phone": "+70173873226"}
0005434822387	A0C6A4	7378 231991	VIKTOR PETROV	{"email": "petrov_viktor-061974@postgrespro.ru", "phone": "+70821140640"}
0005434822388	00737B	5728 644284	VLADIMIR FOMIN	{"email": "fomin.vladimir-25111964@postgrespro.ru", "phone": "+70179217294"}
0005434822389	533DCA	3761 424769	IGOR KONOVALOV	{"phone": "+70681389829"}
0005434822390	BC7E0A	1531 630688	ANNA ALEKSEEVA	{"email": "a-alekseeva121979@postgrespro.ru", "phone": "+70668979254"}
0005434822391	BC7E0A	3504 894466	NATALYA SOROKINA	{"email": "n.sorokina.111972@postgrespro.ru", "phone": "+70091975265"}
0005434822392	5C34CF	4242 045555	ELIZAVETA NAZAROVA	{"phone": "+70898344407"}
0005434822393	E7EA36	4995 734342	GALINA ORLOVA	{"email": "galina_orlova.121969@postgrespro.ru", "phone": "+70714918681"}
0005434822394	D61DAC	0492 592418	IRINA LOGINOVA	{"email": "i_loginova.09061979@postgrespro.ru", "phone": "+70316720623"}
0005434822395	D61DAC	2005 709696	IVAN MOROZOV	{"email": "ivan.morozov-27021979@postgrespro.ru", "phone": "+70211337013"}
0005434822396	13F92F	3359 386896	VALENTINA STEPANOVA	{"email": "vstepanova_1974@postgrespro.ru", "phone": "+70330361547"}
0005434822397	C6BD2B	5556 941713	LYUDMILA GORBUNOVA	{"phone": "+70747685281"}
0005434822398	C6BD2B	4562 815718	LILIYA ILINA	{"phone": "+70525409855"}
0005434822399	6BB7EE	5027 044287	NINA DENISOVA	{"email": "nina.denisova061971@postgrespro.ru", "phone": "+70936376961"}
0005434822400	C225FE	6244 771924	EKATERINA NESTEROVA	{"phone": "+70499075834"}
0005434822401	C225FE	1034 801706	OLGA MIKHAYLOVA	{"phone": "+70261376423"}
0005434822402	04F1AD	2666 047399	OKSANA ANDREEVA	{"phone": "+70807469165"}
0005434822403	A46322	3275 094902	SVETLANA SIDOROVA	{"email": "sidorova-s_30121961@postgrespro.ru", "phone": "+70063096887"}
0005434822404	244FD0	0953 818408	NIKOLAY EGOROV	{"email": "egorov_nikolay.021974@postgrespro.ru", "phone": "+70704000599"}
0005434822405	244FD0	6312 612398	GENNADIY ILIN	{"email": "ilin_gennadiy1989@postgrespro.ru", "phone": "+70282885174"}
0005434822406	D98288	5625 831680	ALEKSEY MATVEEV	{"email": "matveev.aleksey-05021970@postgrespro.ru", "phone": "+70703274229"}
0005434822407	7466EB	8128 113616	IVAN VASILEV	{"phone": "+70563528338"}
0005434822408	19853C	8955 672042	VIKTOR FOMIN	{"phone": "+70493381783"}
0005434822409	223571	9484 842785	OLEG KUZNECOV	{"email": "olegkuznecov-14011982@postgrespro.ru", "phone": "+70701278511"}
0005434822410	223571	4991 527236	ZINAIDA IVANOVA	{"phone": "+70331252118"}
0005434822411	64A163	8627 388836	ELENA MIKHAYLOVA	{"email": "mikhaylova-e-25101970@postgrespro.ru", "phone": "+70527461352"}
0005434822412	64A163	2393 973229	VITALIY ALEKSANDROV	{"email": "v-aleksandrov_1980@postgrespro.ru", "phone": "+70972712491"}
0005434822413	DD8B4E	1987 016202	VIKTORIYA NIKOLAEVA	{"phone": "+70930695113"}
0005434822414	D75874	7317 686645	VITALIY IVANOV	{"email": "vitaliy_ivanov_1975@postgrespro.ru", "phone": "+70945340392"}
0005434822415	D75874	6801 604256	NATALYA KULIKOVA	{"email": "kulikova_n-061991@postgrespro.ru", "phone": "+70413448759"}
0005434822416	2819CE	7510 501888	RUSLAN KISELEV	{"phone": "+70770624790"}
0005434822417	03DC24	7706 157579	LYUDMILA KOROLEVA	{"email": "l-koroleva_1976@postgrespro.ru", "phone": "+70041940936"}
0005434822418	03DC24	1072 229543	ALEKSANDRA IVANOVA	{"email": "a-ivanova_1974@postgrespro.ru", "phone": "+70010494584"}
0005434822419	03DC24	5374 215362	TATYANA KONOVALOVA	{"phone": "+70237607923"}
0005434822420	A52831	2792 897399	LILIYA KOMAROVA	{"phone": "+70901497555"}
0005434822421	26B6B9	0930 867190	POLINA NESTEROVA	{"email": "p.nesterova1965@postgrespro.ru", "phone": "+70374697433"}
0005434822422	5CBD9F	7492 314068	NATALYA FILIPPOVA	{"phone": "+70905637756"}
0005434822423	5CBD9F	1241 388457	RAVIL BONDARENKO	{"email": "bondarenko_ravil.17101972@postgrespro.ru", "phone": "+70993678408"}
0005434822424	55C794	9614 050024	ROMAN FEDOROV	{"email": "fedorov-roman.031980@postgrespro.ru", "phone": "+70680317293"}
0005434822425	7515AD	2825 848807	ELENA KUZNECOVA	{"email": "kuznecova.elena.21091979@postgrespro.ru", "phone": "+70337315075"}
0005434822426	7515AD	2353 898341	KIRILL PAVLOV	{"phone": "+70949479863"}
0005434822427	7515AD	2590 181375	MARINA SERGEEVA	{"phone": "+70282918225"}
0005434822428	8CB2E7	6793 388966	VYACHESLAV DENISOV	{"phone": "+70172301681"}
0005434822429	CB1C36	1308 739292	LYUBOV ZHURAVLEVA	{"email": "l.zhuravleva_071966@postgrespro.ru", "phone": "+70415905861"}
0005434822430	CB1C36	0164 658819	SOFIYA BORISOVA	{"phone": "+70215690281"}
0005434822431	09C0F1	2300 655110	MARIYA VASILEVA	{"email": "m.vasileva-1970@postgrespro.ru", "phone": "+70420428493"}
0005434822432	09C0F1	9771 429233	VALENTINA MOROZOVA	{"email": "morozova-v_25111965@postgrespro.ru", "phone": "+70233380769"}
0005434822433	ABBC32	5696 747782	SERGEY ZAYCEV	{"phone": "+70512760655"}
0005434822434	35901B	2842 254113	NATALYA DENISOVA	{"phone": "+70518253723"}
0005434822435	35901B	6188 438426	ZLATA POPOVA	{"phone": "+70139908417"}
0005434822436	BC4FD9	3469 768235	STANISLAV NIKITIN	{"email": "nikitin-stanislav-13061973@postgrespro.ru", "phone": "+70836640343"}
0005434822437	C8FC5D	2936 654778	VALENTINA ARKHIPOVA	{"email": "v.arkhipova.041968@postgrespro.ru", "phone": "+70163596107"}
0005434822438	FEF494	1553 254422	GALINA MIRONOVA	{"phone": "+70904780562"}
0005434822439	FEF494	2743 123834	VLADIMIR MELNIKOV	{"phone": "+70012068969"}
0005434822440	6CF700	7341 057995	GALINA KUZNECOVA	{"phone": "+70688410042"}
0005434822441	FFDECD	2570 714017	ALEKSANDRA VOLKOVA	{"phone": "+70551766755"}
0005434822442	FFDECD	5192 341184	VITALIY KULIKOV	{"email": "v-kulikov_121956@postgrespro.ru", "phone": "+70062501099"}
0005434822443	B97C28	6488 887213	LYUBOV TARASOVA	{"email": "l.tarasova.23101983@postgrespro.ru", "phone": "+70813058370"}
0005434822444	8C4488	6733 550104	VLADIMIR YAKOVLEV	{"phone": "+70038505890"}
0005434822445	49FF84	1474 973596	LARISA AFANASEVA	{"email": "afanaseva-larisa_22021971@postgrespro.ru", "phone": "+70667445079"}
0005434822446	3ECAC7	3897 117563	SVETLANA KOROLEVA	{"email": "koroleva_s_26061968@postgrespro.ru", "phone": "+70261173670"}
0005434822447	9542A1	3473 363523	DANIIL MAKAROV	{"email": "makarov.daniil.1971@postgrespro.ru", "phone": "+70069269731"}
0005434822448	9542A1	6297 719711	FAINA NIKITINA	{"phone": "+70548731165"}
0005434822449	484A9F	5938 351702	MARINA ANDREEVA	{"phone": "+70830446930"}
0005434822450	484A9F	6251 637529	NATALYA VOLKOVA	{"email": "volkovan_24061967@postgrespro.ru", "phone": "+70517958068"}
0005434822451	3C4008	3074 509923	ROMAN GRIGOREV	{"email": "roman.grigorev.11051970@postgrespro.ru", "phone": "+70215490116"}
0005434822452	3C0CD3	3019 870085	ALEKSANDR BORISOV	{"email": "a.borisov.121967@postgrespro.ru", "phone": "+70725171530"}
0005434822453	3C0CD3	0072 660711	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov_28071968@postgrespro.ru", "phone": "+70968451051"}
0005434822454	3C0CD3	4028 217845	ANASTASIYA STEPANOVA	{"phone": "+70327136221"}
0005434822455	1FDB3D	8990 005224	IRINA KUZNECOVA	{"email": "irina.kuznecova-101967@postgrespro.ru", "phone": "+70169895378"}
0005434822456	1FDB3D	8764 207925	ALEKSEY NOVIKOV	{"phone": "+70960628550"}
0005434822457	A728A1	2999 822208	ALEKSEY DAVYDOV	{"phone": "+70692725517"}
0005434822458	42B68F	6347 415460	GLEB IVANOV	{"email": "gleb-ivanov_1977@postgrespro.ru", "phone": "+70798279270"}
0005434822459	46D2B4	9928 866460	MARIYA NOVIKOVA	{"email": "novikova-m.081965@postgrespro.ru", "phone": "+70164174169"}
0005434822460	46D2B4	8403 024098	GALINA KOMAROVA	{"email": "komarova.g031978@postgrespro.ru", "phone": "+70384084670"}
0005434822461	5C58CD	5994 193987	ANATOLIY FOMIN	{"email": "anatoliy.fomin-24021968@postgrespro.ru", "phone": "+70205557844"}
0005434822462	45AAE4	1672 047432	VALENTINA ANDREEVA	{"email": "andreeva-valentina.011974@postgrespro.ru", "phone": "+70201515800"}
0005434822463	A17220	0160 811955	OLEG ZAKHAROV	{"email": "zakharov.o09121983@postgrespro.ru", "phone": "+70389361619"}
0005434822464	E2FF4A	2514 251078	ALEKSEY GERASIMOV	{"email": "gerasimov_a1965@postgrespro.ru", "phone": "+70078660950"}
0005434822465	E2FF4A	8598 646188	GALINA YUDINA	{"phone": "+70986401234"}
0005434822466	175ADC	0834 219843	NATALYA VOROBEVA	{"email": "natalya.vorobeva.061971@postgrespro.ru", "phone": "+70017404089"}
0005434822467	3D5DB8	8102 714516	SVETLANA NESTEROVA	{"email": "nesterova.s011983@postgrespro.ru", "phone": "+70667525869"}
0005434822468	AC2C83	9210 602179	VIKTORIYA BORISOVA	{"email": "borisovav.1962@postgrespro.ru", "phone": "+70782915764"}
0005434822469	3B8B1F	3022 252949	OKSANA SIDOROVA	{"email": "oksana-sidorova-1972@postgrespro.ru", "phone": "+70449071805"}
0005434822470	3B8B1F	7375 677809	NINA ILINA	{"phone": "+70752577601"}
0005434822471	3B8B1F	4992 301577	ANATOLIY KONOVALOV	{"email": "anatoliy_konovalov.011966@postgrespro.ru", "phone": "+70756578163"}
0005434822472	84C176	1210 737276	NADEZHDA MIKHAYLOVA	{"phone": "+70294822462"}
0005434822473	84C176	4802 897633	ARTEM BELOV	{"email": "belovartem01121966@postgrespro.ru", "phone": "+70987677192"}
0005434822474	81614A	8969 247349	PAVEL SMIRNOV	{"email": "p-smirnov-1982@postgrespro.ru", "phone": "+70193376215"}
0005434822475	81614A	0527 684548	ANATOLIY GORBUNOV	{"phone": "+70203893827"}
0005434822476	9B6A3F	3062 442628	RAMIL BORISOV	{"email": "borisov-ramil-15041983@postgrespro.ru", "phone": "+70889760110"}
0005434822477	2B5336	4935 421624	SVETLANA BELYAEVA	{"email": "svetlana_belyaeva121973@postgrespro.ru", "phone": "+70134492047"}
0005434822478	4D1C16	4367 977748	IVAN IVANOV	{"email": "iivanov.021973@postgrespro.ru", "phone": "+70727294781"}
0005434822479	4D1C16	5275 121286	BORIS ALEKSANDROV	{"phone": "+70622338108"}
0005434822480	230AA6	2805 570994	ANNA BOGDANOVA	{"phone": "+70822807973"}
0005434822481	230AA6	8418 726507	SVETLANA ZHUKOVA	{"email": "zhukova.s_1976@postgrespro.ru", "phone": "+70147849338"}
0005434822482	8899F9	7093 517527	OLGA KRASNOVA	{"email": "krasnova_o101961@postgrespro.ru", "phone": "+70236760710"}
0005434822483	8899F9	4489 153275	IRINA KUZMINA	{"phone": "+70034234259"}
0005434822484	4CE054	9914 791762	OLEG ALEKSANDROV	{"phone": "+70720646127"}
0005434822485	181ADE	3385 376683	VADIM NOVIKOV	{"phone": "+70835427409"}
0005434822486	181ADE	2591 542777	ALINA ZAKHAROVA	{"email": "zakharova-a.1978@postgrespro.ru", "phone": "+70091621105"}
0005434822487	87AFE5	2921 758147	POLINA KOLESNIKOVA	{"phone": "+70217369552"}
0005434822488	E6A2AA	0700 972423	VITALIY KUZNECOV	{"phone": "+70136029462"}
0005434822489	C9C2BC	8863 229249	LYUDMILA KARPOVA	{"phone": "+70062167993"}
0005434822490	E12191	4311 918898	SERGEY SMIRNOV	{"email": "smirnov.sergey1971@postgrespro.ru", "phone": "+70341658887"}
0005434822491	E12191	3164 434766	EVGENIY SEMENOV	{"phone": "+70217645239"}
0005434822492	893C76	0599 124152	EKATERINA SOKOLOVA	{"phone": "+70512123271"}
0005434822493	513B40	2575 478008	ZINAIDA VOROBEVA	{"phone": "+70256917761"}
0005434822494	A28BB1	5957 780556	ARTEM ZAKHAROV	{"phone": "+70464547308"}
0005434822495	A28BB1	0274 869443	EKATERINA NIKOLAEVA	{"email": "e_nikolaeva-14051983@postgrespro.ru", "phone": "+70809952055"}
0005434822496	C34ACA	7407 233674	GALINA ANTONOVA	{"email": "galina-antonova091975@postgrespro.ru", "phone": "+70403118920"}
0005434822497	A6E487	9745 844699	ALEKSEY RODIONOV	{"email": "rodionov-aleksey1979@postgrespro.ru", "phone": "+70727129817"}
0005434822498	3F3B9F	7299 877716	ALEKSANDR ANTONOV	{"phone": "+70133089296"}
0005434822499	60ACF7	4537 353966	RIMMA GRISHINA	{"phone": "+70629328999"}
0005434822500	1D2D8A	3564 349918	ANNA POPOVA	{"phone": "+70151102564"}
0005434822501	B21790	3755 402827	ANASTASIYA MALYSHEVA	{"email": "malyshevaanastasiya_101970@postgrespro.ru", "phone": "+70675408232"}
0005434822502	489E39	3472 854015	DANIIL ABRAMOV	{"phone": "+70526625553"}
0005434822503	F05EAA	5219 014574	GALINA KOROLEVA	{"email": "koroleva.g081980@postgrespro.ru", "phone": "+70753916082"}
0005434822504	9217DD	0864 874629	ARTEM ISAEV	{"email": "aisaev101964@postgrespro.ru", "phone": "+70978965097"}
0005434822505	13484D	6998 716955	VLADIMIR ANDREEV	{"email": "andreev_v.1978@postgrespro.ru", "phone": "+70621241143"}
0005434822506	13484D	8973 209613	VSEVOLOD SAVELEV	{"email": "vsevolod.savelev_17081972@postgrespro.ru", "phone": "+70956850152"}
0005434822507	3A7FA1	3753 680351	LYUDMILA SCHERBAKOVA	{"phone": "+70981990025"}
0005434822508	885BAA	8582 879548	VALERIY MARTYNOV	{"email": "martynov.v_1971@postgrespro.ru", "phone": "+70314018631"}
0005434822509	EA1958	7559 863043	MAKSIM MAKSIMOV	{"email": "maksimov_maksim_30111971@postgrespro.ru", "phone": "+70619946559"}
0005434822510	A1962F	4185 661790	IGOR MARTYNOV	{"email": "martynov_i-011972@postgrespro.ru", "phone": "+70806324425"}
0005434822511	734414	9607 536733	ELENA IVANOVA	{"phone": "+70785358628"}
0005434822512	CEB068	5633 552827	VERA POPOVA	{"phone": "+70769757388"}
0005434822513	CEB068	7337 784035	ALEKSANDR MARTYNOV	{"phone": "+70438411796"}
0005434822514	016CDA	6349 324380	ELENA ANISIMOVA	{"phone": "+70366695558"}
0005434822515	419A06	5956 411349	IRINA LOGINOVA	{"email": "i_loginova_27031968@postgrespro.ru", "phone": "+70122400163"}
0005434822516	F57D46	2138 662807	VALENTINA PAVLOVA	{"email": "pavlova_valentina081958@postgrespro.ru", "phone": "+70998322451"}
0005434822517	F57D46	0692 356038	OLGA SERGEEVA	{"phone": "+70534158930"}
0005434822518	AF1750	2869 146417	ELIZAVETA EGOROVA	{"phone": "+70047221515"}
0005434822519	A29031	6715 255873	LYUBOV SEMENOVA	{"phone": "+70758894123"}
0005434822520	00D00E	2695 543324	ANDREY VASILEV	{"email": "vasilev.a-02071969@postgrespro.ru", "phone": "+70471229263"}
0005434822521	9FE702	1526 777524	MARIYA ALEKSANDROVA	{"phone": "+70103362574"}
0005434822522	9BABEF	7782 748703	ARTEM BORISOV	{"phone": "+70477225981"}
0005434822523	A65BD4	3789 167316	ELENA KOROLEVA	{"phone": "+70323986042"}
0005434822524	B00671	3790 501323	OLGA LOGINOVA	{"email": "o.loginova1974@postgrespro.ru", "phone": "+70349521854"}
0005434822525	401C31	7114 798239	VIKTORIYA VOROBEVA	{"phone": "+70395722589"}
0005434822526	817B2D	7619 907221	MARINA VOROBEVA	{"phone": "+70402923944"}
0005434822527	9A8674	2303 099020	TAMARA TIKHONOVA	{"email": "tikhonova.tamara.091972@postgrespro.ru", "phone": "+70925053458"}
0005434822528	A0075D	7986 795108	ZINAIDA FILIPPOVA	{"email": "filippova-zinaida-051973@postgrespro.ru", "phone": "+70412209725"}
0005434822641	7A5754	5818 747031	ALEKSANDR SOROKIN	{"phone": "+70976380817"}
0005434822529	A0075D	7123 256169	ANATOLIY GERASIMOV	{"email": "anatoliy_gerasimov.08091967@postgrespro.ru", "phone": "+70023265472"}
0005434822530	E4F2AE	6773 931986	VLADISLAV BELOV	{"phone": "+70135851335"}
0005434822531	2BDD30	0695 847694	SERGEY VLASOV	{"email": "vlasov.s-30091976@postgrespro.ru", "phone": "+70222133809"}
0005434822532	C44588	0887 212205	VASILIY EGOROV	{"email": "egorov-vasiliy_1985@postgrespro.ru", "phone": "+70533721006"}
0005434822533	C44588	5783 506310	NADEZHDA KOROLEVA	{"email": "nadezhdakoroleva_061972@postgrespro.ru", "phone": "+70436752880"}
0005434822534	C44588	1356 352388	LYUBOV ANDREEVA	{"email": "l.andreeva_041967@postgrespro.ru", "phone": "+70268904795"}
0005434822535	54B588	4442 589886	MARK SEMENOV	{"phone": "+70014630537"}
0005434822536	54B588	2431 164084	EVGENIY PETROV	{"phone": "+70409917786"}
0005434822537	94FF4E	7911 625232	ARTEM IVANOV	{"phone": "+70506845593"}
0005434822538	54FBF1	8732 869036	ELENA MEDVEDEVA	{"email": "medvedeva.e_011963@postgrespro.ru", "phone": "+70893255012"}
0005434822539	68B0E9	4258 000622	NATALYA FILATOVA	{"phone": "+70399232594"}
0005434822540	68B0E9	4029 691081	ILYA VLASOV	{"email": "i-vlasov041965@postgrespro.ru", "phone": "+70253097735"}
0005434822541	68B0E9	7363 363976	NINA VOLKOVA	{"email": "volkovanina03111973@postgrespro.ru", "phone": "+70220121298"}
0005434822542	9CE5D1	2018 797468	VALENTINA MAKAROVA	{"email": "makarova.v_1982@postgrespro.ru", "phone": "+70399832104"}
0005434822543	9CE5D1	1965 766716	NATALYA NESTEROVA	{"email": "n_nesterova_03051974@postgrespro.ru", "phone": "+70030326036"}
0005434822544	9CE5D1	3659 994174	EKATERINA CHERNOVA	{"email": "chernovaekaterina.06111974@postgrespro.ru", "phone": "+70317064392"}
0005434822545	437349	4932 283232	MARGARITA CHERNOVA	{"phone": "+70378303948"}
0005434822546	437349	3917 089047	DMITRIY FEDOTOV	{"phone": "+70093166635"}
0005434822547	E2898B	1223 064762	ALINA ABRAMOVA	{"phone": "+70152838141"}
0005434822548	5C9287	1109 478252	ZINAIDA MEDVEDEVA	{"email": "zinaida.medvedeva-1980@postgrespro.ru", "phone": "+70985366356"}
0005434822549	1C69A5	8564 351815	ALEKSEY SOROKIN	{"phone": "+70929362551"}
0005434822550	AA5025	4201 023253	SERGEY KONOVALOV	{"email": "sergey.konovalov.09081966@postgrespro.ru", "phone": "+70742275630"}
0005434822551	AA5025	9065 987647	NADEZHDA IVANOVA	{"phone": "+70059350573"}
0005434822552	61516F	2313 547396	VLADIMIR ANTONOV	{"email": "antonov_v10071966@postgrespro.ru", "phone": "+70293320441"}
0005434822553	61516F	2853 992275	OLESYA SAVELEVA	{"phone": "+70081628071"}
0005434822554	87996E	8959 420300	GALINA SAVELEVA	{"email": "gsaveleva-16011969@postgrespro.ru", "phone": "+70348536098"}
0005434822555	87996E	3548 939873	ALEKSANDR VOROBEV	{"phone": "+70580892911"}
0005434822556	38BB42	3592 431450	IRINA GERASIMOVA	{"email": "i.gerasimova_091971@postgrespro.ru", "phone": "+70418771035"}
0005434822557	8DCA87	7434 132272	NIKOLAY KONOVALOV	{"phone": "+70469957072"}
0005434822558	9EB5E3	5274 189022	ARTEM MAKAROV	{"email": "makarovartem-01091979@postgrespro.ru", "phone": "+70884105605"}
0005434822559	9EB5E3	5482 546652	ANDREY ANTONOV	{"email": "antonova_091965@postgrespro.ru", "phone": "+70563249008"}
0005434822560	74CEC2	5560 357272	ELMIRA EFREMOVA	{"phone": "+70094449515"}
0005434822561	74CEC2	5783 100273	NIKOLAY FROLOV	{"email": "frolovnikolay1973@postgrespro.ru", "phone": "+70529981420"}
0005434822562	C29F14	4231 571128	ALEKSEY TARASOV	{"phone": "+70569566234"}
0005434822563	C29F14	3512 608815	VLADIMIR ZAKHAROV	{"phone": "+70614339446"}
0005434822564	C29F14	3090 361940	VALERIYA BELYAEVA	{"phone": "+70543339390"}
0005434822565	C29F14	2409 861825	ANDREY SMIRNOV	{"phone": "+70809847083"}
0005434822566	042618	5124 243814	LIDIYA EFIMOVA	{"email": "lefimova08081987@postgrespro.ru", "phone": "+70899178999"}
0005434822567	042618	5490 163342	VALERIYA MAKSIMOVA	{"email": "maksimovavaleriya_03011975@postgrespro.ru", "phone": "+70312958598"}
0005434822568	5FBF50	0529 697029	VALENTINA KUDRYASHOVA	{"phone": "+70186572720"}
0005434822569	5FBF50	8338 559712	VYACHESLAV NIKOLAEV	{"email": "v.nikolaev-101965@postgrespro.ru", "phone": "+70411026878"}
0005434822570	5FBF50	3320 945493	ANTONINA TARASOVA	{"phone": "+70839100975"}
0005434822571	7DCC32	0488 829519	ANNA EGOROVA	{"phone": "+70230997929"}
0005434822572	7DCC32	6721 232460	GALINA SEMENOVA	{"email": "semenovag-07081978@postgrespro.ru", "phone": "+70719123738"}
0005434822573	7DCC32	6286 737522	DMITRIY SOROKIN	{"email": "dsorokin.13091986@postgrespro.ru", "phone": "+70400854958"}
0005434822574	54BF21	8550 513206	MARIYA KUZNECOVA	{"phone": "+70843141594"}
0005434822575	4FFC24	4871 703387	YULIYA KUZNECOVA	{"email": "kuznecova.y18041966@postgrespro.ru", "phone": "+70976615201"}
0005434822576	ECB2B7	3735 823901	DMITRIY KOZLOV	{"email": "dmitriy-kozlov.1971@postgrespro.ru", "phone": "+70886579875"}
0005434822577	0312E5	0624 588352	ANTON KAZAKOV	{"email": "kazakovanton-1974@postgrespro.ru", "phone": "+70306539745"}
0005434822578	A1AAFA	1099 751025	ALEKSANDR NAZAROV	{"email": "nazarov_a_1981@postgrespro.ru", "phone": "+70377797070"}
0005434822579	A1AAFA	6749 481034	RAISA KONDRATEVA	{"email": "kondrateva_r1967@postgrespro.ru", "phone": "+70415096424"}
0005434822580	D01DFF	5704 066827	ANDREY EGOROV	{"email": "andrey-egorov1975@postgrespro.ru", "phone": "+70959551336"}
0005434822581	095E5D	7216 847115	ELENA LEBEDEVA	{"phone": "+70172960182"}
0005434822582	095E5D	6223 604398	OLGA FROLOVA	{"phone": "+70098479520"}
0005434822583	3983F9	3039 231808	TATYANA FEDOROVA	{"phone": "+70081574389"}
0005434822584	5CE2CA	2232 558478	VLADIMIR KUZNECOV	{"phone": "+70839246586"}
0005434822585	5CE2CA	1336 523137	IRINA NAZAROVA	{"email": "nazarovairina23011979@postgrespro.ru", "phone": "+70092857958"}
0005434822586	D0CE79	9805 199626	NINA KARPOVA	{"email": "n_karpova101954@postgrespro.ru", "phone": "+70270784242"}
0005434822587	93A89D	7220 258500	YULIYA BARANOVA	{"email": "baranovay.061963@postgrespro.ru", "phone": "+70555158537"}
0005434822588	93A89D	3113 227720	YULIYA POTAPOVA	{"email": "yuliya_potapova_20091965@postgrespro.ru", "phone": "+70313694028"}
0005434822589	B1DAD8	9084 575740	SERGEY DMITRIEV	{"phone": "+70853956073"}
0005434822590	390D07	6578 609332	NIKOLAY PAVLOV	{"email": "pavlov.nikolay021967@postgrespro.ru", "phone": "+70378137014"}
0005434822591	390D07	9831 058972	VLADIMIR IVANOV	{"email": "vladimir-ivanov.101963@postgrespro.ru", "phone": "+70403602210"}
0005434822592	852305	8700 166413	SERGEY SCHERBAKOV	{"email": "scherbakovsergey.10031978@postgrespro.ru", "phone": "+70502159767"}
0005434822593	852305	4373 448033	NIKITA VASILEV	{"email": "vasilevn1978@postgrespro.ru", "phone": "+70161235073"}
0005434822594	414072	3123 494888	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev_111972@postgrespro.ru", "phone": "+70859129603"}
0005434822595	414072	3568 415046	TATYANA RYABOVA	{"phone": "+70898187974"}
0005434822596	179BF2	0326 849559	KONSTANTIN VOLKOV	{"phone": "+70350572386"}
0005434822597	2C0719	6264 806012	LIDIYA MATVEEVA	{"phone": "+70036723209"}
0005434822598	2C0719	1951 563402	NIKOLAY MELNIKOV	{"phone": "+70207927368"}
0005434822599	377D3C	3593 903546	YURIY GAVRILOV	{"email": "yuriygavrilov_121973@postgrespro.ru", "phone": "+70586678589"}
0005434822600	377D3C	4396 608954	VLADIMIR BONDARENKO	{"phone": "+70902761110"}
0005434822601	14DA1D	8070 042554	LYUDMILA FOMINA	{"phone": "+70794044832"}
0005434822602	14DA1D	9977 238167	MIKHAIL EGOROV	{"phone": "+70470510488"}
0005434822603	ABC96C	6783 717429	OLEG KARPOV	{"email": "karpov.o.05011985@postgrespro.ru", "phone": "+70797717672"}
0005434822604	B38E08	1155 292441	TATYANA KUZMINA	{"email": "t.kuzmina.1972@postgrespro.ru", "phone": "+70394157732"}
0005434822605	428857	6653 912751	OKSANA KUZNECOVA	{"email": "kuznecovaoksana1970@postgrespro.ru", "phone": "+70229136841"}
0005434822606	F030C7	1987 064775	NIKOLAY POPOV	{"email": "n.popov041973@postgrespro.ru", "phone": "+70197871015"}
0005434822607	107D1A	3257 687829	VALENTINA KAZAKOVA	{"email": "kazakovav.091971@postgrespro.ru", "phone": "+70273881686"}
0005434822608	107D1A	9247 090533	ILMIR MAKAROV	{"email": "makarov-ilmir_051974@postgrespro.ru", "phone": "+70392042057"}
0005434822609	DB48CD	5886 899883	ZULFIYA PETROVA	{"phone": "+70413573293"}
0005434822610	DB48CD	5948 789906	EKATERINA SOROKINA	{"email": "e_sorokina-061971@postgrespro.ru", "phone": "+70920996702"}
0005434822611	D78172	9750 470610	SVETLANA KOROLEVA	{"email": "svetlanakoroleva.19081969@postgrespro.ru", "phone": "+70443318738"}
0005434822612	2C56AF	6230 456624	YULIYA NAZAROVA	{"email": "nazarovayuliya-1967@postgrespro.ru", "phone": "+70863119469"}
0005434822613	2C56AF	5015 385071	NIKOLAY TIMOFEEV	{"phone": "+70026422755"}
0005434822614	57B267	6005 533771	ANTON AFANASEV	{"phone": "+70014382482"}
0005434822615	57B267	9658 233049	ANVAR ABRAMOV	{"email": "abramov.a27071971@postgrespro.ru", "phone": "+70018308827"}
0005434822616	6945EC	1445 358218	VALERIY SOLOVEV	{"phone": "+70377681288"}
0005434822617	4D2413	0592 428948	TATYANA PETROVA	{"email": "tatyana_petrova31081976@postgrespro.ru", "phone": "+70678763337"}
0005434822618	651F0E	1087 562461	OLGA VASILEVA	{"email": "o.vasileva-1974@postgrespro.ru", "phone": "+70522949198"}
0005434822619	651F0E	2842 801092	VERA PAVLOVA	{"email": "pavlova_vera.04011978@postgrespro.ru", "phone": "+70913588653"}
0005434822620	8C989F	3545 187099	ALLA MASLOVA	{"phone": "+70076163547"}
0005434822621	8AE235	1975 701577	VLADIMIR POPOV	{"phone": "+70901096065"}
0005434822622	8AE235	0047 169042	ILMIR KUZNECOV	{"phone": "+70090980476"}
0005434822623	D04BEB	2949 735177	VALERIY ANTONOV	{"email": "valeriy_antonov_021977@postgrespro.ru", "phone": "+70774380748"}
0005434822624	DE4A5A	7095 288350	LYUDMILA VOROBEVA	{"phone": "+70553307542"}
0005434822625	EFD34F	9042 041848	IRINA DENISOVA	{"email": "denisova_i_18081965@postgrespro.ru", "phone": "+70140187051"}
0005434822626	EFD34F	7016 234559	YULIYA SOLOVEVA	{"email": "y.soloveva-03071973@postgrespro.ru", "phone": "+70901196368"}
0005434822627	EFD34F	1306 905890	NATALYA POTAPOVA	{"phone": "+70009173026"}
0005434822628	173F48	8215 617589	VALERIY VASILEV	{"email": "vasilev_valeriy_071971@postgrespro.ru", "phone": "+70331050290"}
0005434822629	173F48	2809 342614	ARINA KOROLEVA	{"phone": "+70210753780"}
0005434822630	95A4B2	9739 831301	SOFIYA KOROLEVA	{"email": "koroleva_sofiya_14061976@postgrespro.ru", "phone": "+70358825193"}
0005434822631	95A4B2	4975 907707	NIKITA YAKOVLEV	{"phone": "+70543003134"}
0005434822632	95A4B2	4490 982276	EVGENIY YAKOVLEV	{"phone": "+70737656371"}
0005434822633	711D0F	5958 354746	VLADIMIR ISAEV	{"email": "isaev.vladimir101973@postgrespro.ru", "phone": "+70652782730"}
0005434822634	8BDB2E	8736 775521	ALEKSANDRA ROMANOVA	{"phone": "+70928342545"}
0005434822635	E69FE4	8273 689774	VALENTINA MIRONOVA	{"email": "valentinamironova_02051961@postgrespro.ru", "phone": "+70985570729"}
0005434822636	A0387A	5165 572549	SVETLANA SCHERBAKOVA	{"phone": "+70881201198"}
0005434822637	A0387A	5002 811970	VLADIMIR NIKOLAEV	{"email": "nikolaev.v.121984@postgrespro.ru", "phone": "+70328932643"}
0005434822638	6CC2E3	9158 906503	MARGARITA BARANOVA	{"phone": "+70652168802"}
0005434822639	6CC2E3	2160 406388	EGOR PETROV	{"phone": "+70518719360"}
0005434822640	1F53A7	7487 832253	IRINA ZAKHAROVA	{"email": "i_zakharova111974@postgrespro.ru", "phone": "+70823038060"}
0005434822642	32A31A	9468 435051	ALEKSEY BORISOV	{"phone": "+70007189589"}
0005434822643	B5D6F2	0830 862972	EVGENIY ORLOV	{"email": "evgeniy_orlov-30111968@postgrespro.ru", "phone": "+70228888727"}
0005434822644	DBC55B	2569 713228	TATYANA IVANOVA	{"email": "t-ivanova1974@postgrespro.ru", "phone": "+70074735049"}
0005434822645	94D1DC	8587 836047	MIKHAIL MAKAROV	{"phone": "+70837648901"}
0005434822646	94D1DC	8869 430548	VIKTOR MARTYNOV	{"email": "martynov-v061985@postgrespro.ru", "phone": "+70273801619"}
0005434822647	1E07CB	8140 834292	SERGEY DAVYDOV	{"email": "davydov_s_20051969@postgrespro.ru", "phone": "+70246046726"}
0005434822648	1E07CB	7421 506091	GENNADIY MIRONOV	{"phone": "+70614955499"}
0005434822649	BA3016	6417 047018	RUSTYAM EGOROV	{"email": "rustyam_egorov1966@postgrespro.ru", "phone": "+70117947207"}
0005434822650	887C5A	9845 260683	LIDIYA ANDREEVA	{"phone": "+70899118395"}
0005434822651	60C0C9	3967 894472	ANASTASIYA GUSEVA	{"email": "a_guseva_091967@postgrespro.ru", "phone": "+70091751217"}
0005434822652	60C0C9	4580 908477	VALENTINA KOROLEVA	{"email": "koroleva.valentina-19121974@postgrespro.ru", "phone": "+70875548068"}
0005434822653	882D15	2697 862365	LYUBOV AKIMOVA	{"phone": "+70464352924"}
0005434822654	882D15	9426 789018	ALEKSANDR PETROV	{"email": "petrov_a_23101964@postgrespro.ru", "phone": "+70415257207"}
0005434822655	21F454	8742 518239	NINA NESTEROVA	{"phone": "+70447824827"}
0005434822656	E13B4D	6950 779101	ALEKSANDR EGOROV	{"email": "a.egorov_13111967@postgrespro.ru", "phone": "+70907574672"}
0005434822657	14C4B1	5125 934335	ILYA SOLOVEV	{"email": "isolovev.09111980@postgrespro.ru", "phone": "+70745772328"}
0005434822658	14C4B1	0522 804058	SERGEY GUSEV	{"email": "gusev-s_1976@postgrespro.ru", "phone": "+70635092693"}
0005434822659	481619	2452 189394	DMITRIY KRASNOV	{"email": "krasnov-d31121970@postgrespro.ru", "phone": "+70161184409"}
0005434822660	CDA856	1706 957804	ALEKSEY BORISOV	{"phone": "+70903251832"}
0005434822661	CDA856	3072 396627	PAVEL MOROZOV	{"email": "morozov_p1968@postgrespro.ru", "phone": "+70088714009"}
0005434822662	33F4F1	1852 035640	GENNADIY SOKOLOV	{"phone": "+70378495078"}
0005434822663	33F4F1	2394 967925	NIKOLAY ZHUKOV	{"phone": "+70445338504"}
0005434822664	5E6E44	5127 787921	VALENTINA NIKITINA	{"email": "nikitinav_11041969@postgrespro.ru", "phone": "+70099506941"}
0005434822665	5E6E44	8877 548386	ELENA MAKSIMOVA	{"phone": "+70010381896"}
0005434822666	D15F85	7808 139927	ELENA MASLOVA	{"email": "maslova_elena-061969@postgrespro.ru", "phone": "+70463595006"}
0005434822667	8C886C	9378 801805	VALENTINA PETROVA	{"email": "petrova_valentina_23041967@postgrespro.ru", "phone": "+70917723709"}
0005434822668	7B8F28	6927 617463	VIKTOR SOLOVEV	{"phone": "+70372548737"}
0005434822669	7B8F28	3842 872365	DANIL ANTONOV	{"email": "danil_antonov-20121965@postgrespro.ru", "phone": "+70404338588"}
0005434822670	C194EE	7714 738718	TATYANA VASILEVA	{"phone": "+70817143829"}
0005434822671	BE6EA0	9060 048085	EKATERINA MOROZOVA	{"phone": "+70380366783"}
0005434822672	800EC0	1082 677162	ALEKSEY ILIN	{"email": "aleksey-ilin031965@postgrespro.ru", "phone": "+70719900107"}
0005434822673	6476C2	6447 250123	VALERIY NIKITIN	{"email": "nikitin-valeriy_1977@postgrespro.ru", "phone": "+70347660918"}
0005434822674	86B6FD	6059 129087	SVETLANA MIKHAYLOVA	{"email": "svetlanamikhaylova_1958@postgrespro.ru", "phone": "+70473901499"}
0005434822675	86B6FD	2185 298004	EVGENIYA ILINA	{"phone": "+70655343504"}
0005434822676	A57BCE	5754 894619	GALINA MAKAROVA	{"email": "galina.makarova.021971@postgrespro.ru", "phone": "+70259022649"}
0005434822677	E29BD4	1555 754549	ZOYA IVANOVA	{"email": "ivanova.zoya.1978@postgrespro.ru", "phone": "+70301476677"}
0005434822678	962D8B	3673 759470	ANASTASIYA DMITRIEVA	{"email": "anastasiya.dmitrieva.1974@postgrespro.ru", "phone": "+70186638504"}
0005434822679	E95B6B	6714 528771	MARINA NAZAROVA	{"phone": "+70376295552"}
0005434822680	DC1176	5237 665221	LYUDMILA ROMANOVA	{"phone": "+70367006115"}
0005434822681	FF89D7	3661 356847	OLEG RODIONOV	{"email": "rodionov.oleg-03081971@postgrespro.ru", "phone": "+70333950887"}
0005434822682	08DF8F	0265 578523	SERGEY BELOV	{"phone": "+70881926834"}
0005434822683	08DF8F	4472 678825	OLGA BELYAEVA	{"phone": "+70076185953"}
0005434822684	9F1B7A	1342 665941	ELENA KISELEVA	{"phone": "+70847064141"}
0005434822685	5ADE70	9221 050509	ANASTASIYA BORISOVA	{"email": "borisova_a071972@postgrespro.ru", "phone": "+70205055022"}
0005434822686	B59714	2396 459818	NATALYA DANILOVA	{"phone": "+70184836279"}
0005434822687	1562E7	6269 400401	ALEKSEY AFANASEV	{"phone": "+70691782175"}
0005434822688	2BD5F1	9859 731153	VALENTINA GAVRILOVA	{"email": "gavrilova_v.19041964@postgrespro.ru", "phone": "+70107728593"}
0005434822689	747522	7691 160704	LYUBOV KISELEVA	{"email": "lkiseleva_1979@postgrespro.ru", "phone": "+70605867108"}
0005434822690	226F21	1253 623495	ELENA GUSEVA	{"email": "elena_guseva.1973@postgrespro.ru", "phone": "+70258835888"}
0005434822691	226F21	1261 831220	ANDREY IVANOV	{"phone": "+70543254982"}
0005434822692	1B2739	7269 821643	SVETLANA EGOROVA	{"email": "svetlanaegorova_1963@postgrespro.ru", "phone": "+70421713423"}
0005434822693	A85B14	1824 453497	ELIZAVETA NOVIKOVA	{"email": "novikova_e021985@postgrespro.ru", "phone": "+70481346013"}
0005434822694	A85B14	6258 368327	ALEKSANDR BELOV	{"email": "belov_a111975@postgrespro.ru", "phone": "+70643745414"}
0005434822695	2A1C30	9488 915919	VALENTINA KUDRYASHOVA	{"phone": "+70964894403"}
0005434822696	713B5C	6298 720977	ALEKSANDR SOKOLOV	{"phone": "+70629374579"}
0005434822697	771320	1731 261663	DMITRIY KISELEV	{"phone": "+70871376406"}
0005434822698	771320	3751 785518	ALEKSANDR PETROV	{"phone": "+70839522169"}
0005434822699	2DA273	2718 275069	ELENA ABRAMOVA	{"email": "abramova-elena081963@postgrespro.ru", "phone": "+70645096722"}
0005434822700	4C8509	3072 391463	ALEKSANDR SHEVCHENKO	{"phone": "+70698116634"}
0005434822701	DE99E2	3894 774006	ANDREY NAUMOV	{"email": "naumov-andrey101977@postgrespro.ru", "phone": "+70618870331"}
0005434822702	B0F5D7	7448 701000	EKATERINA POPOVA	{"email": "popova-ekaterina22041987@postgrespro.ru", "phone": "+70391986135"}
0005434822703	B0F5D7	0958 410199	ANTONINA NIKITINA	{"phone": "+70129450895"}
0005434822704	D3757D	7611 927236	IRINA SCHERBAKOVA	{"email": "irina-scherbakova.061973@postgrespro.ru", "phone": "+70998975527"}
0005434822705	53FFAE	1743 232045	IVAN ALEKSANDROV	{"phone": "+70823661013"}
0005434822706	53FFAE	2894 131042	OKSANA NAZAROVA	{"email": "o.nazarova-011969@postgrespro.ru", "phone": "+70201435806"}
0005434822707	F141AE	7877 994775	NIKOLAY MIRONOV	{"phone": "+70913586582"}
0005434822708	F141AE	4078 780681	NINA KUDRYASHOVA	{"email": "nina.kudryashova081970@postgrespro.ru", "phone": "+70570563623"}
0005434822709	1BB69D	4406 448318	VYACHESLAV GUSEV	{"phone": "+70936214626"}
0005434822710	1BB69D	5285 234730	ANDREY KAZAKOV	{"email": "andrey_kazakov_1964@postgrespro.ru", "phone": "+70827491156"}
0005434822711	1BB69D	7062 605011	FILIPP GRIGOREV	{"phone": "+70688955525"}
0005434822712	BC61A3	8232 711218	VALENTIN GRIGOREV	{"phone": "+70357497606"}
0005434822713	BC61A3	9719 198615	VLADIMIR POPOV	{"email": "popov-vladimir_031972@postgrespro.ru", "phone": "+70610486237"}
0005434822714	47BC30	3163 586851	VALENTINA PETROVA	{"email": "petrova_valentina021985@postgrespro.ru", "phone": "+70595562652"}
0005434822715	47BC30	7708 763438	VLADIMIR VOLKOV	{"email": "volkovvladimir081981@postgrespro.ru", "phone": "+70794050257"}
0005434822716	40B112	8352 079179	ALEKSANDR GUSEV	{"email": "guseva_1966@postgrespro.ru", "phone": "+70764891963"}
0005434822717	943A9D	0975 423981	EVGENIY KUZMIN	{"email": "kuzminevgeniy12071967@postgrespro.ru", "phone": "+70653457809"}
0005434822718	547A05	2817 494346	IRINA KOZLOVA	{"email": "irinakozlova.1972@postgrespro.ru", "phone": "+70654315270"}
0005434822719	ADEEE5	9371 597416	STEPAN MIKHAYLOV	{"email": "s_mikhaylov-121970@postgrespro.ru", "phone": "+70497095458"}
0005434822720	ADEEE5	3115 309788	ALEVTINA NIKOLAEVA	{"email": "alevtina_nikolaeva.1979@postgrespro.ru", "phone": "+70793500983"}
0005434822721	855DE2	1178 468843	ALEKSEY SIDOROV	{"email": "a.sidorov-031983@postgrespro.ru", "phone": "+70336461688"}
0005434822722	93E028	4834 479286	IRINA KUDRYASHOVA	{"email": "irinakudryashova1975@postgrespro.ru", "phone": "+70164551098"}
0005434822723	93E028	7445 656802	ANASTASIYA AKIMOVA	{"phone": "+70537394304"}
0005434822724	C8A3A3	9274 165825	MARK MAKAROV	{"phone": "+70813152111"}
0005434822725	4D5277	0074 595533	ILYA ANDREEV	{"email": "ilya.andreev-111963@postgrespro.ru", "phone": "+70594001852"}
0005434822726	FBEB5D	7034 745443	EVGENIY SMIRNOV	{"email": "evgeniy-smirnov-27051974@postgrespro.ru", "phone": "+70881531212"}
0005434822727	FBEB5D	4738 186252	ILSHAT PETROV	{"email": "ilshat.petrov.12091970@postgrespro.ru", "phone": "+70000211064"}
0005434822728	EC201D	6788 742811	SERGEY KUZNECOV	{"email": "sergey-kuznecov071976@postgrespro.ru", "phone": "+70775329466"}
0005434822729	054FDE	3983 977546	ANDREY DAVYDOV	{"phone": "+70505731538"}
0005434822730	6FED46	3565 240581	ALEKSEY KRASNOV	{"phone": "+70618820117"}
0005434822731	DA8FCC	6348 337659	TATYANA SMIRNOVA	{"phone": "+70793205561"}
0005434822732	C9EDBC	4341 545360	DMITRIY MAKAROV	{"email": "makarov-dmitriy1969@postgrespro.ru", "phone": "+70141088194"}
0005434822733	C9EDBC	0730 354532	ALEKSEY RODIONOV	{"email": "rodionova-1981@postgrespro.ru", "phone": "+70599288424"}
0005434822734	5EFAE8	2617 769287	GENNADIY VOLKOV	{"email": "volkov-g091978@postgrespro.ru", "phone": "+70686532211"}
0005434822735	B2077B	3005 370374	EKATERINA KISELEVA	{"email": "ekaterina_kiseleva-061971@postgrespro.ru", "phone": "+70290881013"}
0005434822736	8B80BB	3184 111026	TATYANA STEPANOVA	{"email": "stepanova-t_011970@postgrespro.ru", "phone": "+70846580462"}
0005434822737	8B80BB	2229 808174	ELENA KUDRYASHOVA	{"email": "elenakudryashova121977@postgrespro.ru", "phone": "+70502176278"}
0005434822738	87AE50	1318 351403	ALFIYA OSIPOVA	{"email": "osipova-a.30051970@postgrespro.ru", "phone": "+70038978750"}
0005434822739	12F366	7725 251779	OLEG NOVIKOV	{"email": "novikov.o-121980@postgrespro.ru", "phone": "+70028355070"}
0005434822740	3C22C2	5744 119323	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir25041964@postgrespro.ru", "phone": "+70987996579"}
0005434822741	CC006F	6819 548124	NATALYA ZAKHAROVA	{"email": "n_zakharova.1967@postgrespro.ru", "phone": "+70778407178"}
0005434822742	CC006F	7682 500360	ANNA IVANOVA	{"phone": "+70925261553"}
0005434822743	DCB330	9290 130610	MARIYA TIKHONOVA	{"email": "tikhonova-mariya-1967@postgrespro.ru", "phone": "+70905050159"}
0005434822744	F9FB4F	7880 233415	ALEKSANDRA ZAYCEVA	{"phone": "+70982850278"}
0005434822745	C66DBA	7433 319290	ANNA SERGEEVA	{"phone": "+70994441799"}
0005434822746	3904AC	3158 720355	OLGA PAVLOVA	{"phone": "+70260107842"}
0005434822747	10A03D	3009 629741	ALEKSEY KARPOV	{"email": "karpovaleksey.14071961@postgrespro.ru", "phone": "+70804731370"}
0005434822748	10A03D	0999 883318	LARISA TITOVA	{"phone": "+70527661175"}
0005434822749	C3DA0E	9530 411990	VASILIY MAKAROV	{"phone": "+70893730910"}
0005434822750	28608E	9015 802283	VLADIMIR KOZLOV	{"phone": "+70825157182"}
0005434822751	E42880	5032 329824	VLADIMIR FEDOROV	{"email": "vfedorov-1978@postgrespro.ru", "phone": "+70718817841"}
0005434822752	E42880	8174 328623	LYUDMILA ANTONOVA	{"phone": "+70480767844"}
0005434822753	F517B9	0547 012592	EKATERINA KUZNECOVA	{"email": "kuznecova.ekaterina16081969@postgrespro.ru", "phone": "+70062655227"}
0005434822754	12645D	8283 126460	ELENA KOROLEVA	{"email": "korolevaelena12091975@postgrespro.ru", "phone": "+70863706166"}
0005434822755	8CFF84	5072 104962	EVGENIYA SOLOVEVA	{"email": "evgeniyasoloveva.13091960@postgrespro.ru", "phone": "+70052524414"}
0005434822756	3016C6	5069 969502	TIMUR VLASOV	{"phone": "+70149177396"}
0005434822757	24473B	1765 679349	IVAN DENISOV	{"email": "idenisov07021961@postgrespro.ru", "phone": "+70582466311"}
0005434822758	24473B	2169 360033	ALEKSANDR IVANOV	{"email": "a-ivanov08011970@postgrespro.ru", "phone": "+70579778758"}
0005434822759	9C6E9B	9458 376729	NIKOLAY MOROZOV	{"email": "nikolay_morozov-091976@postgrespro.ru", "phone": "+70202328261"}
0005434822760	9C6E9B	9231 381423	SOFYA KUZNECOVA	{"email": "kuznecovas041983@postgrespro.ru", "phone": "+70166622199"}
0005434822761	061E96	3355 689127	ANDREY IVANOV	{"email": "ivanov.a24021971@postgrespro.ru", "phone": "+70775234708"}
0005434822762	91D13B	7928 332337	LYUDMILA ZAKHAROVA	{"email": "lzakharova071967@postgrespro.ru", "phone": "+70595819655"}
0005434822763	BEF387	1341 744528	SERGEY GORBUNOV	{"email": "gorbunov.sergey-091975@postgrespro.ru", "phone": "+70937675712"}
0005434822764	9E4B9C	2593 988657	PAVEL FILIPPOV	{"email": "pavel_filippov_03081972@postgrespro.ru", "phone": "+70889794601"}
0005434822765	CAE261	9295 233567	ARTEM KOROLEV	{"email": "korolevartem081975@postgrespro.ru", "phone": "+70091778798"}
0005434822766	CAE261	0678 412304	EVGENIY BARANOV	{"phone": "+70154389731"}
0005434822767	69ADCA	2804 754737	LYUBOV POPOVA	{"email": "lyubov.popova-081961@postgrespro.ru", "phone": "+70939938890"}
0005434822768	37D128	1625 149524	ALEKSANDR KAZAKOV	{"phone": "+70326652054"}
0005434822769	37D128	1921 356165	IGOR VOLKOV	{"phone": "+70089624124"}
0005434822770	2686A8	9034 962878	ANASTASIYA YUDINA	{"phone": "+70558405327"}
0005434822771	C3956A	9763 076805	MARIYA EGOROVA	{"email": "egorova.mariya.25011980@postgrespro.ru", "phone": "+70867693806"}
0005434822772	0428DD	4909 542017	NINA KUZNECOVA	{"email": "kuznecova.n101956@postgrespro.ru", "phone": "+70705124602"}
0005434822773	82338A	8863 401977	ALEKSEY PAVLOV	{"phone": "+70387085746"}
0005434822774	61F185	1718 574073	NIKOLAY MELNIKOV	{"email": "nikolay-melnikov-031968@postgrespro.ru", "phone": "+70066065335"}
0005434822775	36695F	4678 743284	DARYA FADEEVA	{"email": "fadeeva_d23101982@postgrespro.ru", "phone": "+70030598862"}
0005434822776	36695F	2272 023532	LYUBOV SERGEEVA	{"email": "sergeeval.09031967@postgrespro.ru", "phone": "+70925209358"}
0005434822777	97803F	6947 133759	ALEKSANDRA KUZNECOVA	{"email": "aleksandra_kuznecova1984@postgrespro.ru", "phone": "+70187311105"}
0005434822778	8F7EF4	8861 162402	EVGENIYA KOROLEVA	{"email": "koroleva.e08021966@postgrespro.ru", "phone": "+70931107081"}
0005434822779	A19010	0352 596499	OLGA PETROVA	{"phone": "+70995570142"}
0005434822780	8895E4	6398 968721	KIRILL MOROZOV	{"phone": "+70855012956"}
0005434822781	246FAD	3982 333804	ROMAN PAVLOV	{"phone": "+70331758754"}
0005434822782	62FF85	7813 998566	VIKTOR MOISEEV	{"email": "moiseev_v.23111974@postgrespro.ru", "phone": "+70194883783"}
0005434822783	62FF85	5329 413627	GALINA KOROLEVA	{"email": "korolevag-05041970@postgrespro.ru", "phone": "+70601415534"}
0005434822784	FC7883	7385 768045	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov-21071964@postgrespro.ru", "phone": "+70981901962"}
0005434822785	1EEBC3	1113 313777	ELENA IVANOVA	{"phone": "+70784910311"}
0005434822786	415C02	5623 578522	ANATOLIY PAVLOV	{"email": "pavlov-a.14041975@postgrespro.ru", "phone": "+70647996494"}
0005434822787	44006E	3255 616265	REGINA IVANOVA	{"phone": "+70184299619"}
0005434822788	44006E	7334 431598	ANATOLIY MOROZOV	{"phone": "+70719921407"}
0005434822789	44006E	2160 974631	OLESYA SERGEEVA	{"phone": "+70989263929"}
0005434822790	43B46B	6224 689728	OLGA LAZAREVA	{"email": "o-lazareva1972@postgrespro.ru", "phone": "+70360412966"}
0005434822791	EAAAD5	9710 954710	EKATERINA PETROVA	{"email": "epetrova_1964@postgrespro.ru", "phone": "+70760505059"}
0005434822792	EAAAD5	2834 882251	TATYANA SOLOVEVA	{"phone": "+70253076024"}
0005434822793	012E64	9131 482176	DENIS KUZNECOV	{"phone": "+70523106033"}
0005434822794	32319C	4032 077454	VALERIY FILIPPOV	{"email": "valeriy-filippov-061966@postgrespro.ru", "phone": "+70137603131"}
0005434822795	DFE4B4	2437 930915	VLADIMIR IVANOV	{"email": "ivanov-vladimir011969@postgrespro.ru", "phone": "+70984969224"}
0005434822796	AC93F3	8065 514846	VASILIY ANDREEV	{"email": "andreev.v.24121967@postgrespro.ru", "phone": "+70516674835"}
0005434822797	F419B6	1746 477354	EVGENIYA NIKITINA	{"phone": "+70231796911"}
0005434822798	E2AA81	6560 085855	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov051977@postgrespro.ru", "phone": "+70336338745"}
0005434822799	E2AA81	8960 191428	VLADIMIR KUZNECOV	{"phone": "+70940174373"}
0005434822800	914AAA	9340 453255	VALENTINA PETROVA	{"email": "petrova.valentina-23121977@postgrespro.ru", "phone": "+70499474331"}
0005434822801	914AAA	4187 568601	MARIYA MIKHAYLOVA	{"phone": "+70614980637"}
0005434822802	9B5695	7868 958390	NIKOLAY SOLOVEV	{"email": "solovevnikolay19041973@postgrespro.ru", "phone": "+70050325015"}
0005434822803	0F92A1	6097 802947	NIKOLAY MAKAROV	{"email": "nmakarov_1977@postgrespro.ru", "phone": "+70571153726"}
0005434822804	0F92A1	7884 272908	ALEKSANDRA SMIRNOVA	{"phone": "+70483239617"}
0005434822805	3E1B56	0688 601064	VERA GUSEVA	{"phone": "+70060752538"}
0005434822806	C4F35F	3932 732159	EVGENIY IVANOV	{"phone": "+70537941506"}
0005434822807	C4F35F	9612 125197	SERGEY FROLOV	{"email": "sergey_frolov121974@postgrespro.ru", "phone": "+70333096139"}
0005434822808	6802F3	2579 378242	TIMUR ALEKSANDROV	{"email": "t_aleksandrov1972@postgrespro.ru", "phone": "+70549811596"}
0005434822809	6802F3	1393 612715	LYUBOV EGOROVA	{"email": "lyubov-egorova.1977@postgrespro.ru", "phone": "+70656999353"}
0005434822810	4122F1	3303 095420	SERGEY TIKHONOV	{"phone": "+70833857763"}
0005434822811	6B9410	9686 335792	ANTON IVANOV	{"email": "antonivanov_071967@postgrespro.ru", "phone": "+70329446726"}
0005434822812	34251D	3494 946868	EKATERINA KUZNECOVA	{"email": "ekuznecova_18061970@postgrespro.ru", "phone": "+70613241584"}
0005434822813	34251D	4349 218695	NIKOLAY NAZAROV	{"phone": "+70214813162"}
0005434822814	E1600F	2757 317551	EKATERINA TIMOFEEVA	{"email": "timofeevae-1977@postgrespro.ru", "phone": "+70052222450"}
0005434822815	F20788	6046 538439	NIKITA SOKOLOV	{"email": "sokolovnikita_1972@postgrespro.ru", "phone": "+70639188591"}
0005434822816	F20788	2355 449857	MARIYA KOMAROVA	{"email": "m-komarova1974@postgrespro.ru", "phone": "+70176311632"}
0005434822817	0F6843	6146 155330	YURIY ALEKSANDROV	{"phone": "+70550781504"}
0005434822818	A5F194	3216 153043	OLEG ANDREEV	{"phone": "+70133517045"}
0005434822819	A5F194	3105 943302	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr.26121973@postgrespro.ru", "phone": "+70667843246"}
0005434822820	0ACEDB	3226 223865	IRINA FADEEVA	{"phone": "+70600438792"}
0005434822821	657331	9052 229092	ANATOLIY SIDOROV	{"email": "asidorov_1966@postgrespro.ru", "phone": "+70253377311"}
0005434822822	657331	5937 634890	ANDREY BORISOV	{"phone": "+70156257870"}
0005434822823	16417F	8285 453084	NELLI DMITRIEVA	{"email": "nellidmitrieva.09051967@postgrespro.ru", "phone": "+70720638941"}
0005434822824	16417F	3270 428570	DANIL SOLOVEV	{"email": "danil-solovev-1974@postgrespro.ru", "phone": "+70666210412"}
0005434822825	3AD1F3	6411 776762	ELENA MARTYNOVA	{"email": "elena_martynova101966@postgrespro.ru", "phone": "+70327572445"}
0005434822826	76D1E6	2086 441184	SERGEY KOZLOV	{"phone": "+70252063017"}
0005434822827	F13FA4	8243 311113	ROBERT MIRONOV	{"email": "r-mironov-1971@postgrespro.ru", "phone": "+70044825673"}
0005434822828	F13FA4	3974 206750	DMITRIY GORBUNOV	{"phone": "+70564657172"}
0005434822829	4A9680	1560 533057	ANATOLIY POPOV	{"email": "anatoliypopov.02041962@postgrespro.ru", "phone": "+70741824655"}
0005434822830	56DE2C	0092 925234	VASILIY NAUMOV	{"phone": "+70945345691"}
0005434822831	8C33F2	1665 520586	ALEKSEY MOROZOV	{"phone": "+70968687201"}
0005434822832	31D58C	3832 322609	LARISA SEMENOVA	{"phone": "+70637478845"}
0005434822833	31D58C	2159 461791	NATALYA NIKITINA	{"email": "nikitina-n1981@postgrespro.ru", "phone": "+70457508410"}
0005434822834	9786E4	7585 007657	PRASKOVYA MIRONOVA	{"email": "pmironova.1958@postgrespro.ru", "phone": "+70571103375"}
0005434822835	F8FCE7	7748 283986	GALINA KONDRATEVA	{"email": "g_kondrateva_1983@postgrespro.ru", "phone": "+70060753527"}
0005434822836	BC6014	6370 872233	TIMUR ZAYCEV	{"phone": "+70116251678"}
0005434822837	AAE1C1	5980 634839	EVDOKIYA KONOVALOVA	{"email": "konovalovaevdokiya-12031978@postgrespro.ru", "phone": "+70242440566"}
0005434822838	B03D4D	9587 927581	VLADIMIR MELNIKOV	{"phone": "+70305114388"}
0005434822839	B0E985	3473 103453	LILIYA POPOVA	{"phone": "+70820998675"}
0005434822840	5EB37B	6893 218758	MARINA IVANOVA	{"email": "ivanova-marina_1964@postgrespro.ru", "phone": "+70279461805"}
0005434822841	E2049D	5928 739341	DMITRIY NOVIKOV	{"email": "novikov_d-1961@postgrespro.ru", "phone": "+70541036228"}
0005434822842	CDE69C	8500 694414	ELENA PETROVA	{"phone": "+70001777455"}
0005434822843	CDE69C	3161 546389	YULIYA ROMANOVA	{"phone": "+70560436525"}
0005434822844	CDE69C	3972 317452	MIKHAIL ZAKHAROV	{"phone": "+70999669572"}
0005434822845	C7DE6B	7824 284446	VYACHESLAV BARANOV	{"phone": "+70881543307"}
0005434822846	03FB19	4902 437224	SERGEY KUZNECOV	{"phone": "+70771614847"}
0005434822847	03FB19	5116 277507	ANASTASIYA LAZAREVA	{"email": "lazarevaanastasiya.25101976@postgrespro.ru", "phone": "+70458153867"}
0005434822848	D1CE2F	5823 215741	OLGA BARANOVA	{"email": "baranova-olga.05041980@postgrespro.ru", "phone": "+70489863380"}
0005434822849	D1CE2F	8345 336947	VIKTOR MARTYNOV	{"email": "martynov_v07041965@postgrespro.ru", "phone": "+70829691822"}
0005434822850	D1CE2F	5472 392879	DAMIR SERGEEV	{"email": "damirsergeev.05021981@postgrespro.ru", "phone": "+70815272983"}
0005434822851	F20C66	8758 390111	VLADIMIR POPOV	{"phone": "+70556187993"}
0005434822852	0B8139	9971 069710	VYACHESLAV KUZNECOV	{"email": "vyacheslavkuznecov.1983@postgrespro.ru", "phone": "+70509091434"}
0005434822853	05CDF0	9576 668652	TATYANA KOLESNIKOVA	{"email": "t_kolesnikova_051967@postgrespro.ru", "phone": "+70765036503"}
0005434822854	05CDF0	3565 665119	OLEG NAZAROV	{"phone": "+70668437459"}
0005434822855	FBD7B9	1876 622848	ANNA DANILOVA	{"email": "a.danilova1978@postgrespro.ru", "phone": "+70458937879"}
0005434822856	117D32	0885 282230	EVGENIY NIKOLAEV	{"email": "e-nikolaev05121983@postgrespro.ru", "phone": "+70832500062"}
0005434822857	117D32	3112 451781	VADIM KUZMIN	{"phone": "+70793120629"}
0005434822858	89BA1E	5728 431082	ALEKSANDR ANDREEV	{"phone": "+70187074707"}
0005434822859	89BA1E	7048 950054	VIKTOR KUZNECOV	{"email": "kuznecovv.081975@postgrespro.ru", "phone": "+70572089220"}
0005434822860	EEF405	2604 612867	SERGEY KRASNOV	{"email": "sergey-krasnov_1970@postgrespro.ru", "phone": "+70875214078"}
0005434822861	EEF405	0541 868440	VALENTINA POLYAKOVA	{"email": "v_polyakova.071967@postgrespro.ru", "phone": "+70018563239"}
0005434822862	8806EB	9251 716819	EKATERINA MATVEEVA	{"email": "matveeva-ekaterina121973@postgrespro.ru", "phone": "+70017626442"}
0005434822976	6C1FD4	0125 540348	NIKOLAY IVANOV	{"phone": "+70684078539"}
0005434822863	BC69FB	2858 921488	RUSTAM YAKOVLEV	{"email": "rustam.yakovlev.101975@postgrespro.ru", "phone": "+70860689920"}
0005434822864	BC69FB	4827 884767	ANDREY VOLKOV	{"email": "volkov.a-1967@postgrespro.ru", "phone": "+70955780487"}
0005434822865	6B03E5	8162 548658	VITALIY NIKOLAEV	{"phone": "+70260934016"}
0005434822866	64A87F	8423 888558	SERGEY GUSEV	{"phone": "+70164707788"}
0005434822867	BAA737	2925 457868	SVETLANA ZAYCEVA	{"email": "zayceva_s.031960@postgrespro.ru", "phone": "+70318604967"}
0005434822868	D2B51D	1099 790773	NELLI VLASOVA	{"email": "nelli.vlasova-1964@postgrespro.ru", "phone": "+70519811109"}
0005434822869	BD2615	0949 967971	ALEKSANDR FROLOV	{"phone": "+70622866134"}
0005434822870	F6E121	8640 862876	TATYANA MARTYNOVA	{"phone": "+70550423644"}
0005434822871	617D68	8525 852384	VIKTORIYA ZAKHAROVA	{"email": "zakharova-v021975@postgrespro.ru", "phone": "+70792417415"}
0005434822872	C96E67	2368 942020	VIKTORIYA ORLOVA	{"email": "viktoriyaorlova.121977@postgrespro.ru", "phone": "+70752134522"}
0005434822873	B81339	8517 911209	ELIZAVETA ALEKSEEVA	{"phone": "+70059746317"}
0005434822874	B81339	8170 916724	POLINA PETROVA	{"email": "petrova_polina-071969@postgrespro.ru", "phone": "+70690800477"}
0005434822875	852C1F	3888 589862	ELENA IVANOVA	{"email": "e-ivanova_011973@postgrespro.ru", "phone": "+70379157948"}
0005434822876	987EE9	9564 867145	ANDREY SOLOVEV	{"phone": "+70583730163"}
0005434822877	1D78FC	5430 450808	VITALIY FROLOV	{"email": "frolovv-011969@postgrespro.ru", "phone": "+70466499004"}
0005434822878	E12DEC	8509 543801	SERGEY SOROKIN	{"email": "sorokin-s-19041965@postgrespro.ru", "phone": "+70044704331"}
0005434822879	1C94AE	6437 377742	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev.081972@postgrespro.ru", "phone": "+70355389123"}
0005434822880	1C94AE	5967 568328	IRINA RYABOVA	{"email": "iryabova_1967@postgrespro.ru", "phone": "+70545252768"}
0005434822881	1C94AE	6080 415462	MIKHAIL KARPOV	{"email": "mikhail.karpov-1964@postgrespro.ru", "phone": "+70777950849"}
0005434822882	ACE765	5181 880800	EKATERINA IVANOVA	{"email": "ivanova-ekaterina-101972@postgrespro.ru", "phone": "+70280273029"}
0005434822883	ACE765	1665 068061	TATYANA KISELEVA	{"email": "kiselevat-1964@postgrespro.ru", "phone": "+70457681053"}
0005434822884	4B246A	4287 657588	ANNA KULIKOVA	{"email": "a.kulikova_17111976@postgrespro.ru", "phone": "+70138182293"}
0005434822885	7D139F	5382 953361	SOFYA OSIPOVA	{"phone": "+70762586952"}
0005434822886	835C51	8728 417960	ELMIRA FOMINA	{"email": "fominaelmira_29061964@postgrespro.ru", "phone": "+70011865242"}
0005434822887	F8F334	3216 465879	LYUBOV MATVEEVA	{"phone": "+70460848797"}
0005434822888	EB7A6C	2247 134171	MARINA MARTYNOVA	{"phone": "+70035423560"}
0005434822889	B96662	4153 078352	MIKHAIL SERGEEV	{"email": "m.sergeev_1972@postgrespro.ru", "phone": "+70091273117"}
0005434822890	F00AF9	9111 715424	OLGA NIKITINA	{"phone": "+70276343338"}
0005434822891	59C1C0	3246 602681	LEONID PETROV	{"phone": "+70038582023"}
0005434822892	59C1C0	0498 702832	TATYANA GERASIMOVA	{"email": "gerasimova.t.081977@postgrespro.ru", "phone": "+70681787111"}
0005434822893	F0D3CF	2710 433291	KONSTANTIN KUZNECOV	{"email": "kuznecov.konstantin_011975@postgrespro.ru", "phone": "+70546476484"}
0005434822894	F0D3CF	0840 442461	MARIYA PETROVA	{"phone": "+70392645797"}
0005434822895	FABD4F	6425 428807	SERGEY SOROKIN	{"email": "sorokinsergey.071965@postgrespro.ru", "phone": "+70486588964"}
0005434822896	AC470E	7499 184539	KSENIYA BOGDANOVA	{"email": "kbogdanova-1969@postgrespro.ru", "phone": "+70272675274"}
0005434822897	D94A6E	3527 480843	SERGEY KUZNECOV	{"email": "kuznecov-s-041973@postgrespro.ru", "phone": "+70275219173"}
0005434822898	E6E19A	4170 687714	YULIYA NIKIFOROVA	{"email": "nikiforovay-1978@postgrespro.ru", "phone": "+70241333890"}
0005434822899	5752DE	9311 183648	GALINA DMITRIEVA	{"email": "g-dmitrieva-26101960@postgrespro.ru", "phone": "+70928547255"}
0005434822900	179026	8532 880361	VALENTINA KUZMINA	{"phone": "+70469739328"}
0005434822901	179026	6254 254539	GALINA IVANOVA	{"phone": "+70231178222"}
0005434822902	E7CD5F	0847 807378	MARK MIRONOV	{"phone": "+70865893102"}
0005434822903	266BE3	7941 448881	ALEKSANDR PAVLOV	{"phone": "+70594085916"}
0005434822904	8128B3	7849 086127	VALENTINA STEPANOVA	{"phone": "+70469666879"}
0005434822905	6C6F9A	7967 855975	LILIYA MOISEEVA	{"phone": "+70779814638"}
0005434822906	71CD1C	7311 495927	NIKITA ILIN	{"email": "ilinn_12021973@postgrespro.ru", "phone": "+70708023631"}
0005434822907	2B68FA	3970 421264	OLGA ISAEVA	{"phone": "+70212730924"}
0005434822908	2B68FA	7558 600155	ANTON NOVIKOV	{"phone": "+70270489668"}
0005434822909	485AEB	8371 879148	NATALYA KOROLEVA	{"email": "koroleva.natalya_061972@postgrespro.ru", "phone": "+70191093948"}
0005434822910	348412	0483 218338	SVETLANA MAKAROVA	{"email": "s.makarova-111974@postgrespro.ru", "phone": "+70666130501"}
0005434822911	554E95	7941 698929	NINA KOMAROVA	{"phone": "+70175276710"}
0005434822912	B48071	4752 844993	GALINA ANDREEVA	{"email": "gandreeva04121972@postgrespro.ru", "phone": "+70960914533"}
0005434822913	39875E	4653 226785	YURIY GORBUNOV	{"phone": "+70938274648"}
0005434822914	29F310	1922 623927	VASILIY ORLOV	{"email": "orlov-vasiliy-121971@postgrespro.ru", "phone": "+70168803504"}
0005434822915	CB55ED	9670 155758	LYUBOV ANTONOVA	{"phone": "+70313050218"}
0005434822916	CB55ED	7152 703185	ALEKSEY KULIKOV	{"email": "kulikov-aleksey121970@postgrespro.ru", "phone": "+70892003156"}
0005434822917	7AB7F3	9086 836635	EKATERINA GUSEVA	{"phone": "+70518561065"}
0005434822918	7AB7F3	3987 921670	VALERIY KRASNOV	{"email": "valeriy_krasnov.101965@postgrespro.ru", "phone": "+70306320605"}
0005434822919	8F8070	2093 954291	YULIYA RODIONOVA	{"email": "rodionova-y111981@postgrespro.ru", "phone": "+70872491936"}
0005434822920	C6E5B4	9194 162955	LIDIYA VLASOVA	{"email": "vlasova-l081973@postgrespro.ru", "phone": "+70766130435"}
0005434822921	5E98E0	4868 009632	DENIS VOROBEV	{"email": "vorobev.d081970@postgrespro.ru", "phone": "+70801389821"}
0005434822922	FAD2F4	5271 238703	LIDIYA POPOVA	{"phone": "+70310783656"}
0005434822923	23B30D	5520 444524	NADEZHDA VLASOVA	{"email": "n.vlasova-30081978@postgrespro.ru", "phone": "+70209783607"}
0005434822924	DAFDE4	5155 477372	VIKTOR GERASIMOV	{"phone": "+70565471917"}
0005434822925	7CFA87	4813 966904	OLGA MALYSHEVA	{"phone": "+70619543728"}
0005434822926	521D1F	5496 926747	MARINA NOVIKOVA	{"phone": "+70130142498"}
0005434822927	C8A2DD	3868 857772	IRINA ZAKHAROVA	{"email": "zakharova-irina07061977@postgrespro.ru", "phone": "+70342224053"}
0005434822928	C8A2DD	1189 982491	DARYA KUZNECOVA	{"phone": "+70620230837"}
0005434822929	C8A2DD	3720 299866	TAMARA YUDINA	{"email": "yudina-t_07101975@postgrespro.ru", "phone": "+70159873064"}
0005434822930	20AF93	1884 479834	VASILIY KISELEV	{"phone": "+70230434058"}
0005434822931	20AF93	2059 025258	DARYA FADEEVA	{"phone": "+70669897421"}
0005434822932	0025F1	1263 779194	GALINA DAVYDOVA	{"phone": "+70918373469"}
0005434822933	375C3A	6640 686168	MARIYA NOVIKOVA	{"phone": "+70498162088"}
0005434822934	5FB007	9676 338611	EKATERINA KUZNECOVA	{"email": "kuznecovaekaterina-111984@postgrespro.ru", "phone": "+70066896494"}
0005434822935	51A2A1	6274 782606	GALINA KOVALEVA	{"phone": "+70962605836"}
0005434822936	3BABD0	9609 104003	KIRILL CHERNOV	{"phone": "+70162055078"}
0005434822937	1F6E7B	8598 721630	ANDREY AFANASEV	{"phone": "+70201628958"}
0005434822938	17A292	9143 168533	FLYURA SERGEEVA	{"email": "sergeeva_f-31121974@postgrespro.ru", "phone": "+70549775140"}
0005434822939	17A292	0601 694453	PAVEL IVANOV	{"email": "ivanov_pavel-24121972@postgrespro.ru", "phone": "+70089275208"}
0005434822940	B1C329	7547 206656	NIKOLAY KOZLOV	{"phone": "+70292060674"}
0005434822941	2F8E48	6530 293145	MAKSIM SEMENOV	{"phone": "+70476696625"}
0005434822942	BF438C	9791 079838	ALEKSEY ALEKSANDROV	{"phone": "+70399855460"}
0005434822943	89C659	2044 427324	ARTEM IVANOV	{"email": "ivanov-artem_16031982@postgrespro.ru", "phone": "+70675346828"}
0005434822944	89C659	5826 786231	NIKITA GERASIMOV	{"phone": "+70918500908"}
0005434822945	ABE9E0	5950 561959	DMITRIY KONOVALOV	{"phone": "+70662415798"}
0005434822946	E63560	6040 546937	NATALYA STEPANOVA	{"email": "stepanovan.1968@postgrespro.ru", "phone": "+70753768169"}
0005434822947	E63560	8006 007072	ALEKSEY KOROLEV	{"email": "a_korolev1988@postgrespro.ru", "phone": "+70742502285"}
0005434822948	E63560	8791 954167	YULIYA IVANOVA	{"phone": "+70851826213"}
0005434822949	084C50	1389 491968	VIKTOR YAKOVLEV	{"phone": "+70320856612"}
0005434822950	4AA606	8610 635707	VYACHESLAV FILIPPOV	{"email": "filippovv15061971@postgrespro.ru", "phone": "+70447848585"}
0005434822951	4AA606	7817 909528	VALENTINA YAKOVLEVA	{"phone": "+70084762945"}
0005434822952	4AA606	0421 358047	ALEKSANDR ANDREEV	{"phone": "+70027532469"}
0005434822953	D03696	3357 457130	IGOR FEDOROV	{"phone": "+70451986058"}
0005434822954	1FF84B	4044 871580	DENIS SAVELEV	{"email": "savelev_denis.1966@postgrespro.ru", "phone": "+70632576101"}
0005434822955	1FF84B	6817 827476	NIKITA KAZAKOV	{"phone": "+70200325736"}
0005434822956	30310F	4761 310056	ALEKSANDR SCHERBAKOV	{"phone": "+70587146597"}
0005434822957	69D918	0254 042902	IGOR SOLOVEV	{"phone": "+70838452732"}
0005434822958	9749CB	5140 695482	STEPAN SERGEEV	{"phone": "+70762185765"}
0005434822959	3785D5	6157 505931	IVAN TARASOV	{"phone": "+70423537696"}
0005434822960	3785D5	4953 652692	RASHIT STEPANOV	{"email": "rstepanov_15101975@postgrespro.ru", "phone": "+70628582107"}
0005434822961	751BC9	4501 190619	VARVARA LOGINOVA	{"email": "loginova.varvara.06061973@postgrespro.ru", "phone": "+70431575273"}
0005434822962	AD35B4	5159 605113	IRINA SERGEEVA	{"phone": "+70103028438"}
0005434822963	AD35B4	2275 926685	ANATOLIY PETROV	{"email": "petrov_a.021969@postgrespro.ru", "phone": "+70779364063"}
0005434822964	AC71C2	4070 298966	VERA FROLOVA	{"email": "frolova.v071976@postgrespro.ru", "phone": "+70647563066"}
0005434822965	AC71C2	2003 555185	NIKOLAY GUSEV	{"email": "nikolay-gusev-26011964@postgrespro.ru", "phone": "+70568839212"}
0005434822966	47E7E0	3375 204628	NADEZHDA ZAYCEVA	{"email": "n_zayceva-1968@postgrespro.ru", "phone": "+70790648583"}
0005434822967	47E7E0	9885 555660	PRASKOVYA ZOTOVA	{"phone": "+70355980097"}
0005434822968	CDF617	5152 350307	ASKHAT GRIGOREV	{"phone": "+70284306993"}
0005434822969	91FAB0	8722 760818	VASILIY BELOV	{"email": "belov_v02061976@postgrespro.ru", "phone": "+70318470186"}
0005434822970	BC5C14	7026 153278	VLADLEN FOMIN	{"phone": "+70804342017"}
0005434822971	C4B822	9206 952278	LARISA SERGEEVA	{"email": "sergeeva_l18051967@postgrespro.ru", "phone": "+70498710156"}
0005434822972	C4B822	7764 417604	IRINA NIKOLAEVA	{"phone": "+70896581211"}
0005434822973	E22EAF	6750 591951	IRINA KONOVALOVA	{"phone": "+70384656504"}
0005434822974	18A91D	8593 697901	DENIS TIMOFEEV	{"email": "timofeev.d_26061982@postgrespro.ru", "phone": "+70750170489"}
0005434822975	18A91D	3686 587301	PAVEL MEDVEDEV	{"email": "medvedev_pavel.101973@postgrespro.ru", "phone": "+70492533382"}
0005434822977	6C1FD4	6946 615114	IVAN IVANOV	{"phone": "+70789324599"}
0005434822978	6C1FD4	6655 780583	VIKTORIYA ROMANOVA	{"email": "romanova_v.1967@postgrespro.ru", "phone": "+70399537203"}
0005434822979	0FF533	2291 646444	VADIM ORLOV	{"phone": "+70038511193"}
0005434822980	0FF533	1534 900247	ELENA YUDINA	{"email": "elena-yudina.091969@postgrespro.ru", "phone": "+70427306597"}
0005434822981	A5FB7C	0667 743725	VASILIY ANTONOV	{"email": "antonov-v-101984@postgrespro.ru", "phone": "+70474989368"}
0005434822982	A5FB7C	0588 643138	DARYA DENISOVA	{"email": "denisova.darya-22041969@postgrespro.ru", "phone": "+70561485297"}
0005434822983	C51B0B	3597 918772	ELENA PAVLOVA	{"email": "pavlovaelena_30091970@postgrespro.ru", "phone": "+70853918109"}
0005434822984	951377	9358 760098	VIKTORIYA ORLOVA	{"email": "orlovav.101966@postgrespro.ru", "phone": "+70342659985"}
0005434822985	1E155E	7666 301830	ALEKSANDR VASILEV	{"phone": "+70162960669"}
0005434822986	1E155E	5632 120025	KONSTANTIN VASILEV	{"email": "vasilev-konstantin1969@postgrespro.ru", "phone": "+70928076395"}
0005434822987	636093	8437 719566	NIKOLAY POPOV	{"email": "nikolay_popov-25051973@postgrespro.ru", "phone": "+70874148836"}
0005434822988	636093	5123 639091	DANIIL DMITRIEV	{"email": "dmitriev-daniil_1971@postgrespro.ru", "phone": "+70626679211"}
0005434822989	A3ED03	0416 850708	EKATERINA NOVIKOVA	{"email": "novikova-e-081966@postgrespro.ru", "phone": "+70003744219"}
0005434822990	39CDF3	5455 851631	YAROSLAV PETROV	{"email": "yaroslav.petrov_1970@postgrespro.ru", "phone": "+70336912980"}
0005434822991	FE0A09	8889 685541	GALINA YAKOVLEVA	{"phone": "+70646241052"}
0005434822992	1168C1	5871 890980	LYUDMILA NIKOLAEVA	{"phone": "+70948136594"}
0005434822993	5ADBD0	9106 152705	RAFAIL ALEKSANDROV	{"email": "aleksandrov-r051971@postgrespro.ru", "phone": "+70900795626"}
0005434822994	5ADBD0	5961 851967	SERGEY GORBUNOV	{"email": "s_gorbunov.1961@postgrespro.ru", "phone": "+70388627070"}
0005434822995	8C931E	5521 909772	ALEKSEY MELNIKOV	{"email": "melnikov-a-15031979@postgrespro.ru", "phone": "+70995946909"}
0005434822996	D9B12C	8558 651712	SVETLANA TROFIMOVA	{"email": "svetlana.trofimova.24071980@postgrespro.ru", "phone": "+70222956052"}
0005434822997	B27951	1647 046002	DMITRIY KONOVALOV	{"email": "konovalov.dmitriy1969@postgrespro.ru", "phone": "+70291906714"}
0005434822998	524C71	4236 938030	VLADIMIR SEMENOV	{"email": "vladimirsemenov021964@postgrespro.ru", "phone": "+70236464067"}
0005434822999	D388C0	3751 843961	POLINA ABRAMOVA	{"email": "abramova_polina-1968@postgrespro.ru", "phone": "+70633123875"}
0005434823000	6184B9	2320 468680	MARINA ZAYCEVA	{"email": "marina.zayceva1969@postgrespro.ru", "phone": "+70045588061"}
0005434823001	3025A3	5197 845009	YULIYA MOISEEVA	{"phone": "+70460290470"}
0005434823002	C31745	7186 073088	KONSTANTIN DMITRIEV	{"phone": "+70484166604"}
0005434823003	B211DE	0023 824272	VLADIMIR ZAKHAROV	{"phone": "+70719128076"}
0005434823004	3CB681	5699 638431	PAVEL MEDVEDEV	{"phone": "+70639639389"}
0005434823005	0D51E6	0264 521989	KLAVDIYA SMIRNOVA	{"phone": "+70215918921"}
0005434823006	DE725F	4217 025570	SVETLANA KOROLEVA	{"email": "svetlana_koroleva-1977@postgrespro.ru", "phone": "+70065724612"}
0005434823007	DE725F	7859 504474	SERGEY NIKOLAEV	{"email": "s.nikolaev1985@postgrespro.ru", "phone": "+70365405222"}
0005434823008	DB9858	6480 382069	AZAT ALEKSANDROV	{"phone": "+70960816599"}
0005434823009	349BB0	6705 012563	ANDREY NOVIKOV	{"email": "novikovandrey1984@postgrespro.ru", "phone": "+70308324841"}
0005434823010	349BB0	6703 443046	KIRILL KRASNOV	{"phone": "+70849182272"}
0005434823011	4C09DA	4411 411992	VADIM MAKAROV	{"phone": "+70856959849"}
0005434823012	4C09DA	8668 137120	SVETLANA ZHUKOVA	{"phone": "+70004678915"}
0005434823013	D65E32	0157 586527	ALENA IVANOVA	{"phone": "+70195556341"}
0005434823014	D65E32	1670 694268	OLGA MAKAROVA	{"phone": "+70618441289"}
0005434823015	D65E32	3740 168014	VIKTOR VOROBEV	{"email": "viktorvorobev1965@postgrespro.ru", "phone": "+70393853919"}
0005434823016	DF46C8	4238 739204	POLINA ZAYCEVA	{"phone": "+70843432830"}
0005434823017	DF6B84	1680 283627	OLGA KONOVALOVA	{"phone": "+70894765304"}
0005434823018	BE1ED9	4275 144065	TATYANA NOVIKOVA	{"email": "novikova.t_03031964@postgrespro.ru", "phone": "+70707576901"}
0005434823019	1ED7E5	3709 928132	GALINA YAKOVLEVA	{"phone": "+70546489277"}
0005434823020	1ED7E5	6018 113291	ANTONINA SERGEEVA	{"email": "sergeeva.a.011964@postgrespro.ru", "phone": "+70484956909"}
0005434823021	1ED7E5	8868 414418	ANTONINA RODIONOVA	{"email": "rodionovaantonina1962@postgrespro.ru", "phone": "+70896432800"}
0005434823022	317583	5006 500838	ZHANNA EFREMOVA	{"email": "zhanna-efremova-1978@postgrespro.ru", "phone": "+70895444792"}
0005434823023	317583	9831 010295	OLEG FILIPPOV	{"email": "olegfilippov-121974@postgrespro.ru", "phone": "+70122327196"}
0005434823024	61491E	8418 265082	DMITRIY MAKSIMOV	{"email": "d.maksimov.28081969@postgrespro.ru", "phone": "+70765117241"}
0005434823025	61491E	5784 449399	LILIYA SAVELEVA	{"email": "lsaveleva10111966@postgrespro.ru", "phone": "+70462468605"}
0005434823026	DD3079	1476 299488	ANNA FEDOROVA	{"email": "anna-fedorova_041973@postgrespro.ru", "phone": "+70452975529"}
0005434823027	DD3079	6475 430386	NIKOLAY OSIPOV	{"email": "n-osipov.1972@postgrespro.ru", "phone": "+70851307342"}
0005434823028	DD3079	3120 120801	TAMARA KOMAROVA	{"phone": "+70977416002"}
0005434823029	E96D00	6056 992197	MARINA KUZNECOVA	{"email": "kuznecova_marina1977@postgrespro.ru", "phone": "+70598436564"}
0005434823030	1CC42B	9286 748472	ALLA MIKHAYLOVA	{"phone": "+70734333642"}
0005434823031	1CC42B	3381 122461	ALEKSEY KUZNECOV	{"email": "kuznecov_a-27081975@postgrespro.ru", "phone": "+70805514929"}
0005434823032	C66EDB	4588 142934	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila-26091970@postgrespro.ru", "phone": "+70893361271"}
0005434823033	FC7CB6	9651 959367	VLADIMIR ANTONOV	{"phone": "+70626077959"}
0005434823034	FC7CB6	7450 496225	MARIYA FILATOVA	{"phone": "+70150150655"}
0005434823035	C68296	4064 203154	KONSTANTIN ZAYCEV	{"email": "konstantin-zaycev1971@postgrespro.ru", "phone": "+70332453134"}
0005434823036	E6AC8F	7996 660637	GALINA LEBEDEVA	{"phone": "+70530569772"}
0005434823037	E6AC8F	2303 619797	VALERIY BARANOV	{"phone": "+70092893369"}
0005434823038	E6AC8F	7758 580079	VLADIMIR SCHERBAKOV	{"phone": "+70307329459"}
0005434823039	F12662	6106 339669	SVETLANA KUZNECOVA	{"phone": "+70134975962"}
0005434823040	F12662	8108 779454	TATYANA ABRAMOVA	{"email": "tatyana_abramova-24121959@postgrespro.ru", "phone": "+70756125524"}
0005434823041	A334E6	6064 091266	VLADIMIR POPOV	{"email": "popov.vladimir20031980@postgrespro.ru", "phone": "+70148660570"}
0005434823042	9508A3	0472 153449	NATALIYA ZHUKOVA	{"email": "nataliya.zhukova-13051972@postgrespro.ru", "phone": "+70719692336"}
0005434823043	7B084D	4589 884603	ZINAIDA KISELEVA	{"email": "zinaida_kiseleva.061965@postgrespro.ru", "phone": "+70887684466"}
0005434823044	7B084D	3639 363121	ANATOLIY KISELEV	{"phone": "+70824338000"}
0005434823045	0E7798	6088 411169	VIKTOR NAZAROV	{"email": "nazarov.viktor_1962@postgrespro.ru", "phone": "+70045149605"}
0005434823046	631B38	4397 473223	RUSLAN KUZNECOV	{"phone": "+70612311114"}
0005434823047	631B38	8595 187036	ANFISA STEPANOVA	{"phone": "+70372796206"}
0005434823048	631B38	5118 976289	ELENA MIKHAYLOVA	{"email": "elena_mikhaylova.1985@postgrespro.ru", "phone": "+70692925737"}
0005434823049	4F141A	8420 497320	MIKHAIL ALEKSEEV	{"email": "alekseev.mikhail.081964@postgrespro.ru", "phone": "+70441108681"}
0005434823050	627580	8820 438373	NINA SOROKINA	{"email": "sorokina-n.091964@postgrespro.ru", "phone": "+70921591774"}
0005434823051	A99F3D	0977 881185	ILDAR IVANOV	{"email": "iivanov-24081969@postgrespro.ru", "phone": "+70034915524"}
0005434823052	4E86CB	5605 569972	TAISA FILATOVA	{"phone": "+70439030024"}
0005434823053	2BC83E	4531 345760	ALEKSANDR OSIPOV	{"phone": "+70354764523"}
0005434823054	C17DC2	2938 543568	ELENA STEPANOVA	{"email": "stepanovaelena.13101973@postgrespro.ru", "phone": "+70787898896"}
0005434823055	20F396	5705 059135	ANDREY DAVYDOV	{"phone": "+70221208469"}
0005434823056	48682C	3095 873579	LEONID DAVYDOV	{"phone": "+70204859112"}
0005434823057	48682C	6437 786888	VLADIMIR ABRAMOV	{"email": "vabramov-1983@postgrespro.ru", "phone": "+70796963193"}
0005434823058	2E9E83	8142 153395	VIKTOR TARASOV	{"phone": "+70380853178"}
0005434823059	DE446D	4016 748267	VIKTOR GRIGOREV	{"email": "grigorev-viktor1965@postgrespro.ru", "phone": "+70935993090"}
0005434823060	467B5C	0070 895896	ZOYA SOKOLOVA	{"phone": "+70925188188"}
0005434823061	46290A	7995 950727	VIKTORIYA MAKSIMOVA	{"email": "maksimova.v.081978@postgrespro.ru", "phone": "+70293946189"}
0005434823062	1960BE	9035 788021	EKATERINA SEMENOVA	{"email": "semenova.ekaterina_1960@postgrespro.ru", "phone": "+70185085293"}
0005434823063	1960BE	8098 678586	ULYANA PAVLOVA	{"phone": "+70788527118"}
0005434823064	F09D58	0543 845537	MARINA ARKHIPOVA	{"email": "m.arkhipova_19051968@postgrespro.ru", "phone": "+70424952777"}
0005434823065	F09D58	9733 782175	VLADIMIR PETROV	{"email": "vladimirpetrov-081977@postgrespro.ru", "phone": "+70920603990"}
0005434823066	837356	8088 734691	VYACHESLAV PETROV	{"phone": "+70551144251"}
0005434823067	08D028	6288 691441	ALEKSANDR SERGEEV	{"email": "sergeev.aleksandr-1986@postgrespro.ru", "phone": "+70718766932"}
0005434823068	69B6EF	7089 799670	VALENTINA ABRAMOVA	{"phone": "+70009994752"}
0005434823069	9D75A4	4566 666591	YULIYA BELYAEVA	{"phone": "+70134643453"}
0005434823070	9D75A4	4195 274716	IRINA OVCHINNIKOVA	{"email": "ovchinnikova-i-1962@postgrespro.ru", "phone": "+70941530803"}
0005434823071	805C1F	8010 031754	VIKTORIYA ILINA	{"phone": "+70627934469"}
0005434823072	805C1F	0262 296870	MATVEY DAVYDOV	{"email": "davydov-matvey.011968@postgrespro.ru", "phone": "+70223510671"}
0005434823073	148C8E	2697 041417	VIKTOR SCHERBAKOV	{"email": "scherbakov_viktor_031971@postgrespro.ru", "phone": "+70598237133"}
0005434823074	2C75BC	3151 478873	EKATERINA KUZNECOVA	{"phone": "+70457049540"}
0005434823075	86473F	8473 675065	ZLATA KOROLEVA	{"email": "koroleva.zlata-071976@postgrespro.ru", "phone": "+70619703058"}
0005434823076	86473F	7283 123532	KSENIYA RODIONOVA	{"email": "kseniya.rodionova1983@postgrespro.ru", "phone": "+70152626519"}
0005434823077	B85CD9	1454 437973	ELENA NESTEROVA	{"phone": "+70595197134"}
0005434823078	B95335	8229 405746	LIDIYA KARPOVA	{"email": "l.karpova.01121973@postgrespro.ru", "phone": "+70147670523"}
0005434823079	0FF617	8793 992409	ROMAN IVANOV	{"email": "ivanov_r.03061964@postgrespro.ru", "phone": "+70814178913"}
0005434823080	0FF617	6723 851965	ALEKSANDR NIKITIN	{"email": "a_nikitin.1965@postgrespro.ru", "phone": "+70288829626"}
0005434823081	0FF617	1702 274001	RUSLAN MATVEEV	{"email": "ruslan-matveev_31121965@postgrespro.ru", "phone": "+70269969351"}
0005434823082	D5C5B0	1398 335922	MARIYA SCHERBAKOVA	{"email": "mariya_scherbakova1976@postgrespro.ru", "phone": "+70668910468"}
0005434823083	D5C5B0	5156 209097	VLADIMIR SIDOROV	{"email": "sidorov_v-1970@postgrespro.ru", "phone": "+70030648226"}
0005434823084	4085B8	1198 394081	ANATOLIY GRIGOREV	{"email": "anatoliygrigorev_1969@postgrespro.ru", "phone": "+70250572192"}
0005434823085	588C5B	9625 321623	LYUDMILA PETROVA	{"phone": "+70805972360"}
0005434823086	BFDF14	7592 995036	LYUBOV KUDRYASHOVA	{"phone": "+70996960228"}
0005434823087	9C4551	1174 158553	EVGENIY IVANOV	{"phone": "+70277369772"}
0005434823088	9C4551	5734 396292	RUSLAN GAVRILOV	{"email": "gavrilov_r-05081968@postgrespro.ru", "phone": "+70580759733"}
0005434823089	D65A10	7964 605183	VIKTOR KUZMIN	{"email": "v.kuzmin-02011967@postgrespro.ru", "phone": "+70966706103"}
0005434823090	98E372	2899 307237	YULIYA LEBEDEVA	{"phone": "+70739646630"}
0005434823091	03CAE3	7557 510753	ANASTASIYA RYABOVA	{"phone": "+70798392207"}
0005434823092	03CAE3	9552 191833	OKSANA EFIMOVA	{"email": "oksana.efimova18111971@postgrespro.ru", "phone": "+70240080794"}
0005434823093	59A922	5695 683436	VASILIY ISAEV	{"phone": "+70623549303"}
0005434823094	0E8B38	1242 214232	VLADIMIR PETROV	{"phone": "+70138052512"}
0005434823095	0E8B38	2256 841122	NATALYA TITOVA	{"phone": "+70637636117"}
0005434823096	F49FB9	6670 459046	SERGEY IVANOV	{"email": "sergey.ivanov-1965@postgrespro.ru", "phone": "+70304567173"}
0005434823097	F49FB9	5483 289760	GALINA MOROZOVA	{"email": "morozova.g_1967@postgrespro.ru", "phone": "+70278040334"}
0005434823098	40D7AA	7045 447537	GALINA RODIONOVA	{"phone": "+70582852620"}
0005434823099	8F0955	0192 741294	TAISIYA NAZAROVA	{"phone": "+70495607272"}
0005434823100	8F0955	8178 725335	VERA GERASIMOVA	{"phone": "+70446126397"}
0005434823101	8F0955	2634 491044	ROMAN IVANOV	{"phone": "+70787632891"}
0005434823102	4B6942	9663 842069	PRASKOVYA TIKHONOVA	{"email": "tikhonovapraskovya_1968@postgrespro.ru", "phone": "+70825311467"}
0005434823103	54A816	7096 650189	ANATOLIY TIKHONOV	{"email": "tikhonova_101978@postgrespro.ru", "phone": "+70104612719"}
0005434823104	7FC997	1734 618224	ELENA MIKHAYLOVA	{"email": "mikhaylova_e111985@postgrespro.ru", "phone": "+70657351280"}
0005434823105	4AA272	7708 233449	IRINA ABRAMOVA	{"email": "abramovai_12081964@postgrespro.ru", "phone": "+70823380971"}
0005434823106	5FD617	0034 246372	SVETLANA LEBEDEVA	{"email": "s_lebedeva_20061967@postgrespro.ru", "phone": "+70071573274"}
0005434823107	5FD617	1767 779563	ELENA KUZNECOVA	{"email": "e.kuznecova1971@postgrespro.ru", "phone": "+70496768334"}
0005434823108	6778DF	6078 970216	KIRILL MIRONOV	{"email": "kirill-mironov.1965@postgrespro.ru", "phone": "+70081353684"}
0005434823109	59FE75	5902 339200	ZINAIDA NIKOLAEVA	{"email": "zinaida_nikolaeva-1966@postgrespro.ru", "phone": "+70963434905"}
0005434823110	59FE75	4552 949160	SERGEY CHERNOV	{"email": "chernovs_1962@postgrespro.ru", "phone": "+70844156063"}
0005434823111	4E7B6C	4735 505823	NATALYA KOVALEVA	{"phone": "+70917775315"}
0005434823112	B6AB22	2577 138139	LYUBOV ILINA	{"email": "lyubov.ilina-28021976@postgrespro.ru", "phone": "+70650607734"}
0005434823113	97D40A	4961 059230	DENIS SMIRNOV	{"email": "denis-smirnov_28061965@postgrespro.ru", "phone": "+70923585385"}
0005434823114	D722A1	5798 088078	NATALYA YAKOVLEVA	{"email": "yakovlevanatalya-1988@postgrespro.ru", "phone": "+70834541814"}
0005434823115	D722A1	4194 105820	VALERIY SCHERBAKOV	{"phone": "+70603063512"}
0005434823116	D722A1	9364 655564	YURIY SEMENOV	{"email": "semenov_yuriy1980@postgrespro.ru", "phone": "+70270246634"}
0005434823117	FB55E1	6646 034096	VARVARA PAVLOVA	{"email": "pavlova_varvara_1976@postgrespro.ru", "phone": "+70104694884"}
0005434823118	4C9043	3366 835461	ANASTASIYA MATVEEVA	{"phone": "+70896922372"}
0005434823119	4C9043	8458 743071	MIKHAIL ILIN	{"email": "mikhaililin_19091965@postgrespro.ru", "phone": "+70403146606"}
0005434823120	2952FA	0768 406493	SERGEY VOROBEV	{"phone": "+70273605728"}
0005434823121	C9B14A	4319 651352	VALENTINA LUKYANOVA	{"phone": "+70818880217"}
0005434823122	F8A983	6520 859899	DMITRIY EGOROV	{"email": "dmitriy-egorov.06011985@postgrespro.ru", "phone": "+70013072791"}
0005434823123	F8A983	0532 998746	DANILA NIKOLAEV	{"email": "d-nikolaev-1968@postgrespro.ru", "phone": "+70524726207"}
0005434823124	26E18F	2956 980894	MATVEY IVANOV	{"email": "ivanov_m041991@postgrespro.ru", "phone": "+70320794506"}
0005434823125	CC72B2	1577 500614	NIKOLAY KOROLEV	{"email": "korolevn.1987@postgrespro.ru", "phone": "+70307232064"}
0005434823126	039574	1828 795386	POLINA LEBEDEVA	{"phone": "+70270839830"}
0005434823127	039574	9683 239978	IRINA ORLOVA	{"email": "i-orlova1978@postgrespro.ru", "phone": "+70084980122"}
0005434823128	039574	9968 079895	ALEKSANDR ALEKSANDROV	{"phone": "+70789565335"}
0005434823129	577042	5299 208167	YULIYA TIMOFEEVA	{"email": "timofeeva-yuliya061959@postgrespro.ru", "phone": "+70753139798"}
0005434823130	577042	3609 330219	VERA DMITRIEVA	{"phone": "+70241123910"}
0005434823131	1E0655	9279 486673	IVAN ALEKSEEV	{"phone": "+70336037559"}
0005434823132	2DB2B6	6416 387491	VITALIY VASILEV	{"phone": "+70857043074"}
0005434823133	4BB1DA	8068 620173	LEV CHERNOV	{"email": "chernovl_1974@postgrespro.ru", "phone": "+70723970846"}
0005434823134	EBD7C3	0639 276048	YANA ZAKHAROVA	{"email": "y.zakharova.08101972@postgrespro.ru", "phone": "+70436670677"}
0005434823135	667498	7530 557825	OLGA KOROLEVA	{"email": "o-koroleva_19101962@postgrespro.ru", "phone": "+70755656699"}
0005434823136	667498	1025 863546	EGOR DENISOV	{"email": "denisov-e30011979@postgrespro.ru", "phone": "+70795540660"}
0005434823137	600958	1740 813865	ARTUR NIKITIN	{"phone": "+70068205319"}
0005434823138	600958	2198 391718	KRISTINA MAKAROVA	{"phone": "+70438490793"}
0005434823139	7445B5	6866 103993	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov25111975@postgrespro.ru", "phone": "+70353859106"}
0005434823140	1063D2	9779 814766	ANTON ZAKHAROV	{"phone": "+70932377718"}
0005434823141	C46DF0	4478 307643	NATALYA ROMANOVA	{"email": "n.romanova_13021975@postgrespro.ru", "phone": "+70253251688"}
0005434823142	FB995A	2362 330736	NIKOLAY SEMENOV	{"phone": "+70674425997"}
0005434823143	856665	1126 579176	RUSTAM ALEKSANDROV	{"email": "rustam.aleksandrov_1975@postgrespro.ru", "phone": "+70518785487"}
0005434823144	094F14	3002 042257	NINA ZAKHAROVA	{"phone": "+70191541425"}
0005434823145	094F14	4205 394002	OLGA KISELEVA	{"phone": "+70317083029"}
0005434823146	87BF72	5596 776748	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr-1980@postgrespro.ru", "phone": "+70639794313"}
0005434823147	740A36	1431 927285	ALLA ZAKHAROVA	{"phone": "+70873448392"}
0005434823148	270AA5	1438 944684	ALEKSANDR FROLOV	{"email": "frolov-aleksandr1962@postgrespro.ru", "phone": "+70132317220"}
0005434823149	606622	9338 532502	TATYANA NAUMOVA	{"phone": "+70372718799"}
0005434823150	08B63B	5776 830071	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr121967@postgrespro.ru", "phone": "+70914370929"}
0005434823151	4F4138	4812 123900	TATYANA EGOROVA	{"email": "tatyana-egorova011979@postgrespro.ru", "phone": "+70858490879"}
0005434823152	4F4138	8999 675229	MAKSIM KUZNECOV	{"phone": "+70075702882"}
0005434823153	E8C857	2888 165518	LYUDMILA KOLESNIKOVA	{"phone": "+70330467853"}
0005434823154	73D146	9269 842213	OLGA MOROZOVA	{"email": "morozovao-011979@postgrespro.ru", "phone": "+70572718908"}
0005434823155	73D146	2108 146882	VLADIMIR STEPANOV	{"email": "v.stepanov.16091975@postgrespro.ru", "phone": "+70982630326"}
0005434823156	483283	5816 378241	NATALYA MOROZOVA	{"email": "nmorozova_07051974@postgrespro.ru", "phone": "+70327016681"}
0005434823157	6A4DF9	0862 519164	GENNADIY ZAKHAROV	{"email": "gennadiy_zakharov.29041964@postgrespro.ru", "phone": "+70301978823"}
0005434823158	6A4DF9	9494 192875	MARAT GAVRILOV	{"phone": "+70613938931"}
0005434823159	BC5E35	1115 977033	VALERIY KARPOV	{"phone": "+70319091012"}
0005434823160	5803E6	1438 288905	NIKOLAY MOROZOV	{"phone": "+70584480962"}
0005434823161	297116	9647 687986	SERGEY SEMENOV	{"phone": "+70918141359"}
0005434823162	297116	5344 891557	MAKSIM NOVIKOV	{"phone": "+70764655935"}
0005434823163	297116	3301 267654	GALINA MAKAROVA	{"email": "galina_makarova-081971@postgrespro.ru", "phone": "+70122056155"}
0005434823164	297116	1560 913359	ANATOLIY POPOV	{"phone": "+70056771845"}
0005434823165	1FAE22	6920 668002	ALEKSANDR KARPOV	{"email": "aleksandrkarpov_22111970@postgrespro.ru", "phone": "+70783187329"}
0005434823166	1FAE22	8661 231173	LYUBOV OSIPOVA	{"phone": "+70319074065"}
0005434823167	16E12D	3487 128058	ANDREY RODIONOV	{"email": "andrey_rodionov_1974@postgrespro.ru", "phone": "+70550713245"}
0005434823168	2040C7	4458 459064	MIKHAIL DMITRIEV	{"email": "dmitrievmikhail-061970@postgrespro.ru", "phone": "+70360347315"}
0005434823169	5EE67A	7247 231340	SERGEY PAVLOV	{"email": "s-pavlov041965@postgrespro.ru", "phone": "+70942619163"}
0005434823170	F7EB6C	4887 100747	ANTONINA KUZMINA	{"phone": "+70811414419"}
0005434823171	42B3EB	1590 137218	ELENA OSIPOVA	{"email": "e.osipova-1966@postgrespro.ru", "phone": "+70163902171"}
0005434823172	8254A4	2412 851425	NIKOLAY MARTYNOV	{"phone": "+70141107505"}
0005434823173	8254A4	7311 852639	LIDIYA ZAKHAROVA	{"phone": "+70375680412"}
0005434823174	CC9F3F	6760 260864	MAKSIM IVANOV	{"email": "ivanov.m09081979@postgrespro.ru", "phone": "+70948545888"}
0005434823175	A4EB92	8974 271720	LARISA SIDOROVA	{"email": "sidorova_larisa.121973@postgrespro.ru", "phone": "+70246115262"}
0005434823176	A4EB92	7992 169969	DANILA KUZNECOV	{"email": "danila-kuznecov.13041959@postgrespro.ru", "phone": "+70490350469"}
0005434823177	BEB613	3172 573464	LYUBOV BORISOVA	{"phone": "+70676059621"}
0005434823178	1A7E63	3624 538727	ALEKSEY KOZLOV	{"phone": "+70029492892"}
0005434823179	1A7E63	2376 594655	DANIL SAVELEV	{"phone": "+70114628604"}
0005434823180	1A7E63	8570 139692	VIKTORIYA NOVIKOVA	{"email": "novikova-v.071983@postgrespro.ru", "phone": "+70830816430"}
0005434823181	3C8641	0100 318951	NIKITA STEPANOV	{"phone": "+70694076258"}
0005434823182	248996	3317 759706	MIKHAIL TIMOFEEV	{"email": "timofeev-m_13111977@postgrespro.ru", "phone": "+70500433312"}
0005434823183	248996	9475 143725	ALEKSANDR NIKOLAEV	{"phone": "+70505062462"}
0005434823184	C8F430	8068 983799	SERGEY MIRONOV	{"phone": "+70957331095"}
0005434823185	2BAF3C	0715 316216	BORIS ABRAMOV	{"email": "abramovboris_20041957@postgrespro.ru", "phone": "+70584263697"}
0005434823186	644C6C	1915 102247	GALINA NIKIFOROVA	{"phone": "+70589777524"}
0005434823187	0E3E97	3540 753571	MAKSIM SOLOVEV	{"phone": "+70752099976"}
0005434823188	601522	6167 029116	ALEKSEY BORISOV	{"email": "a-borisov-021992@postgrespro.ru", "phone": "+70091550946"}
0005434823189	601522	6330 618598	IRINA ZAYCEVA	{"phone": "+70092248214"}
0005434823190	26A84D	4701 835908	AYRAT VLASOV	{"email": "avlasov.051969@postgrespro.ru", "phone": "+70106447268"}
0005434823191	7BA77E	6082 297166	YURIY VLASOV	{"phone": "+70999614991"}
0005434823192	7BA77E	3881 237448	SERGEY NAUMOV	{"email": "s.naumov-1987@postgrespro.ru", "phone": "+70444912521"}
0005434823193	7BA77E	0995 735023	TATYANA PAVLOVA	{"email": "t.pavlova.011972@postgrespro.ru", "phone": "+70060261538"}
0005434823194	980175	3374 815896	TATYANA ZAKHAROVA	{"phone": "+70424030901"}
0005434823195	CB9DC3	4387 263385	MAKAR ILIN	{"phone": "+70155129327"}
0005434823196	821C5C	7953 502789	ANATOLIY KARPOV	{"email": "karpov_anatoliy-111970@postgrespro.ru", "phone": "+70036272503"}
0005434823197	821C5C	8155 589040	NIKOLAY CHERNOV	{"email": "chernov.n_1972@postgrespro.ru", "phone": "+70605316879"}
0005434823198	567F05	8971 203706	TAISIYA ZHUKOVA	{"phone": "+70401211526"}
0005434823199	AD9673	9255 762669	OLGA ALEKSANDROVA	{"phone": "+70791979741"}
0005434823200	AFE562	7052 015293	ANTONINA KUZNECOVA	{"email": "antonina_kuznecova.30071973@postgrespro.ru", "phone": "+70953615205"}
0005434823201	87345E	6897 637509	ALEKSANDR BORISOV	{"email": "borisov-aleksandr_1962@postgrespro.ru", "phone": "+70403457043"}
0005434823202	9B0DC3	6540 805831	EVGENIY FROLOV	{"email": "e.frolov.16111975@postgrespro.ru", "phone": "+70862319644"}
0005434823203	6CB597	6369 643997	ALEKSEY GRIGOREV	{"email": "a-grigorev-02031970@postgrespro.ru", "phone": "+70761561449"}
0005434823204	6CB597	1210 722687	IRINA MAKAROVA	{"phone": "+70106205177"}
0005434823205	6CB597	1441 025765	SVETLANA POTAPOVA	{"email": "potapova-svetlana.051972@postgrespro.ru", "phone": "+70207798879"}
0005434823206	C253FB	7651 091591	ELENA NAZAROVA	{"phone": "+70793709855"}
0005434823207	C253FB	3438 367522	VLADIMIR POPOV	{"email": "vladimirpopov121964@postgrespro.ru", "phone": "+70287918059"}
0005434823208	5281E4	7389 220436	ILYA MIRONOV	{"email": "mironov_ilya-121975@postgrespro.ru", "phone": "+70459919190"}
0005434823209	5281E4	5957 283954	ELENA IVANOVA	{"email": "ivanovaelena_18011975@postgrespro.ru", "phone": "+70681949067"}
0005434823210	0A75D9	1780 705057	NATALYA FROLOVA	{"phone": "+70050624503"}
0005434823211	F875A7	2755 385989	RAIL ALEKSANDROV	{"email": "aleksandrov-rail.051973@postgrespro.ru", "phone": "+70797048887"}
0005434823212	CA554B	3760 334591	ALEKSANDR MIKHAYLOV	{"phone": "+70601634523"}
0005434823213	CA554B	4520 151036	ALEKSEY YAKOVLEV	{"phone": "+70074906274"}
0005434823214	CA554B	2986 163267	KONSTANTIN BORISOV	{"phone": "+70628139894"}
0005434823215	7E5E1B	3761 563921	NINA LOGINOVA	{"email": "loginova_nina-22071969@postgrespro.ru", "phone": "+70348516623"}
0005434823216	401751	0729 797899	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-15071970@postgrespro.ru", "phone": "+70134237996"}
0005434823217	A9468C	5113 383319	MARINA KUZNECOVA	{"email": "kuznecova-m_07051970@postgrespro.ru", "phone": "+70097120796"}
0005434823218	02F36E	5761 281429	VASILISA ROMANOVA	{"phone": "+70180783312"}
0005434823219	02F36E	7731 253054	VITALIY DENISOV	{"email": "vitaliydenisov-03081990@postgrespro.ru", "phone": "+70304650464"}
0005434823220	4F1781	3107 951432	NATALIYA ROMANOVA	{"phone": "+70567572855"}
0005434823221	4F1781	1683 722402	LYUDMILA PAVLOVA	{"phone": "+70259979221"}
0005434823222	7882E2	5325 347749	EVGENIYA DANILOVA	{"phone": "+70349454861"}
0005434823223	7882E2	3529 907043	MIKHAIL KAZAKOV	{"email": "mikhail.kazakov20071966@postgrespro.ru", "phone": "+70772282411"}
0005434823224	5FB493	8833 445542	NIKOLAY MOROZOV	{"email": "morozov_nikolay_031968@postgrespro.ru", "phone": "+70229109073"}
0005434823225	5FB493	5806 429116	TATYANA NIKITINA	{"email": "nikitinat-1969@postgrespro.ru", "phone": "+70333491518"}
0005434823226	DF8D44	2397 639080	ANASTASIYA ABRAMOVA	{"phone": "+70756275496"}
0005434823227	DF8D44	4544 828562	ALLA SIDOROVA	{"phone": "+70717378131"}
0005434823228	9F7092	2714 602675	SVETLANA SOKOLOVA	{"phone": "+70366141606"}
0005434823229	938A11	0959 648065	OLESYA DMITRIEVA	{"phone": "+70408675726"}
0005434823230	4D8FB1	9735 980468	GENNADIY VOROBEV	{"phone": "+70529375266"}
0005434823231	4D8FB1	4313 802830	VLADIMIR PAVLOV	{"email": "vpavlov-03021975@postgrespro.ru", "phone": "+70531523128"}
0005434823232	4D8FB1	1135 316934	VALERIY IVANOV	{"email": "valeriyivanov-20101979@postgrespro.ru", "phone": "+70345525124"}
0005434823233	AC27BB	9736 180499	IVAN ZAKHAROV	{"phone": "+70749419200"}
0005434823234	BE312E	2570 405068	EVGENIY KUZNECOV	{"email": "kuznecov.evgeniy_02011967@postgrespro.ru", "phone": "+70568353619"}
0005434823235	BE312E	0456 662782	DENIS MARTYNOV	{"email": "d_martynov_091970@postgrespro.ru", "phone": "+70737307770"}
0005434823236	72E047	4035 171284	LYUDMILA IVANOVA	{"phone": "+70957993331"}
0005434823237	72E047	8536 471944	RIMMA FILATOVA	{"email": "filatova_r31081964@postgrespro.ru", "phone": "+70740789817"}
0005434823238	E41F06	6723 952074	ANATOLIY ZHURAVLEV	{"phone": "+70955185368"}
0005434823239	E41F06	7219 071668	VIKTOR SOROKIN	{"phone": "+70588720287"}
0005434823240	E41F06	9632 663841	ELENA KOVALEVA	{"email": "e-kovaleva.1965@postgrespro.ru", "phone": "+70145945613"}
0005434823241	E8C420	5813 310551	VALERIY IVANOV	{"phone": "+70438869267"}
0005434823242	E8C420	4007 366760	NINA ALEKSANDROVA	{"email": "aleksandrova.nina-1985@postgrespro.ru", "phone": "+70157506685"}
0005434823243	E7D43D	0972 372155	MIKHAIL NIKOLAEV	{"email": "nikolaev-mikhail-1977@postgrespro.ru", "phone": "+70434598228"}
0005434823244	E7D43D	3083 193448	DMITRIY KUZNECOV	{"phone": "+70540297595"}
0005434823245	A24672	2341 659508	TATYANA SEMENOVA	{"email": "tsemenova_30121965@postgrespro.ru", "phone": "+70919596010"}
0005434823246	B5A0D1	3868 647866	ALEKSEY MIKHAYLOV	{"phone": "+70850653839"}
0005434823247	B5A0D1	8227 342390	DMITRIY TARASOV	{"phone": "+70284551357"}
0005434823248	959231	6751 566122	OLGA POPOVA	{"phone": "+70805499142"}
0005434823249	959231	9057 329375	KARINA ZAKHAROVA	{"email": "zakharova-karina.18051979@postgrespro.ru", "phone": "+70949050789"}
0005434823250	A23F5F	2111 603639	ALEKSANDR KUZNECOV	{"phone": "+70195762071"}
0005434823251	A23F5F	1126 411406	VLADIMIR IVANOV	{"phone": "+70063302985"}
0005434823252	74DDDD	3411 585139	OLGA NIKITINA	{"email": "nikitina_olga-121979@postgrespro.ru", "phone": "+70834587757"}
0005434823253	7B7A8F	5904 661560	LYUDMILA MARTYNOVA	{"email": "martynova.l.11101968@postgrespro.ru", "phone": "+70676858173"}
0005434823254	1CD130	9436 517465	EKATERINA DAVYDOVA	{"phone": "+70173285923"}
0005434823255	1CD130	1220 548839	EGOR ALEKSEEV	{"email": "egor-alekseev_26031965@postgrespro.ru", "phone": "+70304646342"}
0005434823256	FBBC9C	7093 243638	VALENTINA DANILOVA	{"phone": "+70752496723"}
0005434823257	CC988A	0334 636082	ALEKSANDR POPOV	{"email": "a-popov-22081978@postgrespro.ru", "phone": "+70095821136"}
0005434823258	E04B5E	1745 370611	LYUDMILA POPOVA	{"email": "popova-l_02011980@postgrespro.ru", "phone": "+70663162942"}
0005434823259	E04B5E	0350 258460	ALEKSEY GUSEV	{"email": "aleksey-gusev-15101973@postgrespro.ru", "phone": "+70821926109"}
0005434823260	E04B5E	3660 737655	VLADIMIR MOISEEV	{"email": "moiseev-v_22101966@postgrespro.ru", "phone": "+70564624909"}
0005434823261	F6F6C9	6285 933151	NATALYA KISELEVA	{"email": "kiseleva.natalya-1976@postgrespro.ru", "phone": "+70228349609"}
0005434823262	E891F3	9566 327538	LYUDMILA DANILOVA	{"email": "danilova.lyudmila041977@postgrespro.ru", "phone": "+70499119525"}
0005434823263	E891F3	3349 713778	SERGEY SOROKIN	{"phone": "+70080960699"}
0005434823264	CA099E	3175 154342	KLAVDIYA VOLKOVA	{"phone": "+70931623677"}
0005434823265	A96D18	5829 724520	YAROSLAV OSIPOV	{"phone": "+70555786091"}
0005434823266	43E39B	2386 423961	NATALYA NAZAROVA	{"phone": "+70391180393"}
0005434823267	E0ED13	6164 754363	VLADIMIR BELOV	{"email": "belov.vladimir-29011976@postgrespro.ru", "phone": "+70437149284"}
0005434823268	A02145	9752 352740	ALEKSANDR ALEKSEEV	{"email": "a.alekseev_1968@postgrespro.ru", "phone": "+70052522880"}
0005434823269	A02145	7336 565605	VIKTORIYA TITOVA	{"email": "titova.v-051961@postgrespro.ru", "phone": "+70946450520"}
0005434823270	A02145	1909 418442	MARAT KUZNECOV	{"email": "kuznecov_marat-1970@postgrespro.ru", "phone": "+70441185444"}
0005434823271	328B5D	7760 648776	SERGEY VLASOV	{"phone": "+70918344656"}
0005434823272	8E3ED6	8042 242896	LYUDMILA EGOROVA	{"email": "egorova.l.1975@postgrespro.ru", "phone": "+70339932713"}
0005434823273	49DEB9	1418 593401	NIKOLAY KONOVALOV	{"phone": "+70465769879"}
0005434823274	BC32BC	1035 227431	YULIYA DENISOVA	{"email": "y-denisova_1968@postgrespro.ru", "phone": "+70396153064"}
0005434823275	35C945	2194 833309	VASILIY VOROBEV	{"phone": "+70467568713"}
0005434823276	55BD04	5785 549497	VIKTORIYA DAVYDOVA	{"phone": "+70511618420"}
0005434823277	3BDA0B	9006 226364	RIMMA KALININA	{"email": "kalinina.rimma.10051976@postgrespro.ru", "phone": "+70210423724"}
0005434823278	359EF1	8545 123872	MIKHAIL CHERNOV	{"email": "chernov.m091963@postgrespro.ru", "phone": "+70830469970"}
0005434823279	CB06E4	7542 448272	RAFAIL VOLKOV	{"email": "volkovr_051967@postgrespro.ru", "phone": "+70542295806"}
0005434823280	626ECC	3595 910428	YURIY KULIKOV	{"phone": "+70053180374"}
0005434823281	EEC607	8094 790010	ANZHELA GRISHINA	{"phone": "+70278132012"}
0005434823282	C06226	5428 879207	TAMARA KOZLOVA	{"email": "tamarakozlova_021990@postgrespro.ru", "phone": "+70509168760"}
0005434823283	684757	2715 756163	DIANA ERMAKOVA	{"phone": "+70676981101"}
0005434823284	684757	1585 425954	ARTEM ZAKHAROV	{"email": "artemzakharov.01061971@postgrespro.ru", "phone": "+70377638045"}
0005434823285	C6E57C	0582 410286	KONSTANTIN TARASOV	{"phone": "+70711641026"}
0005434823286	C6E57C	0680 874992	SERGEY KUZMIN	{"email": "sergeykuzmin-12071980@postgrespro.ru", "phone": "+70116663038"}
0005434823287	0CC49F	6408 916300	ANTONINA DAVYDOVA	{"email": "davydova.antonina041971@postgrespro.ru", "phone": "+70282479163"}
0005434823288	B5E2C4	4107 948217	OLGA MOROZOVA	{"email": "olgamorozova_23101975@postgrespro.ru", "phone": "+70889668167"}
0005434823289	85CADC	7323 241291	ANAIT DAVYDOVA	{"phone": "+70602844961"}
0005434823290	30AEAD	2516 052974	NIKOLAY KAZAKOV	{"email": "kazakovnikolay-101971@postgrespro.ru", "phone": "+70866578134"}
0005434823291	5CBF81	9088 309508	VERONIKA MIKHAYLOVA	{"email": "veronika.mikhaylova.01031982@postgrespro.ru", "phone": "+70197048101"}
0005434823292	1C65C1	5736 023197	DANIYA POPOVA	{"email": "popova.daniya08031983@postgrespro.ru", "phone": "+70778874343"}
0005434823293	D6DD1D	0180 492914	IRINA NOVIKOVA	{"email": "irina.novikova_051969@postgrespro.ru", "phone": "+70583773012"}
0005434823294	D6DD1D	9653 877306	YURIY PETROV	{"phone": "+70854040035"}
0005434823295	2C3BC4	0882 384611	NADEZHDA KISELEVA	{"email": "kiseleva-n101969@postgrespro.ru", "phone": "+70113898486"}
0005434823296	FDBBC8	5678 002692	LYUBOV ALEKSANDROVA	{"email": "aleksandrova_lyubov.30061957@postgrespro.ru", "phone": "+70169391689"}
0005434823297	FDBBC8	7561 501950	VALERIYA KISELEVA	{"phone": "+70412281531"}
0005434823298	19D544	8211 145416	DENIS KUZNECOV	{"phone": "+70040643458"}
0005434823299	6583FD	1766 576054	IRINA GAVRILOVA	{"email": "igavrilova121971@postgrespro.ru", "phone": "+70760985542"}
0005434823300	FAD8E0	0869 198615	MARIYA VASILEVA	{"phone": "+70613950454"}
0005434823301	B21183	6981 511366	SERGEY TARASOV	{"phone": "+70149390285"}
0005434823302	E5BD6D	5171 654094	ILYA MAKAROV	{"phone": "+70201054858"}
0005434823303	8B6061	4461 390282	VERA RYABOVA	{"email": "vryabova.1965@postgrespro.ru", "phone": "+70309183650"}
0005434823304	8B6061	6441 610305	NATALYA FILIPPOVA	{"phone": "+70754986032"}
0005434823305	FB7660	7220 878263	NATALYA GORBUNOVA	{"phone": "+70822428676"}
0005434823306	FB7660	2403 638077	VLADIMIR YAKOVLEV	{"email": "v_yakovlev_1974@postgrespro.ru", "phone": "+70361137234"}
0005434823307	6DE590	1662 213594	YULIYA NIKIFOROVA	{"phone": "+70861413795"}
0005434823308	6DE590	2434 678304	LIDIYA POPOVA	{"phone": "+70749505439"}
0005434823309	985631	5315 970684	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov-1975@postgrespro.ru", "phone": "+70671093072"}
0005434823310	258582	4727 399618	ANASTASIYA KRASNOVA	{"phone": "+70200057675"}
0005434823311	741E60	8580 796004	GALINA NIKOLAEVA	{"phone": "+70973023004"}
0005434823312	DA72F2	1614 315803	EVDOKIYA MAKSIMOVA	{"email": "maksimovae-14101976@postgrespro.ru", "phone": "+70102613401"}
0005434823313	DA72F2	2677 573002	VLADIMIR ZHURAVLEV	{"email": "v-zhuravlev-1972@postgrespro.ru", "phone": "+70301337694"}
0005434823314	9AAF1F	8076 420551	DMITRIY NOVIKOV	{"email": "novikov.dmitriy_081969@postgrespro.ru", "phone": "+70257031751"}
0005434823315	622CF2	4085 335599	ANDREY GUSEV	{"phone": "+70068681206"}
0005434823316	CBB40E	8488 147803	DENIS MIRONOV	{"phone": "+70335299038"}
0005434823317	CBB40E	5194 438254	NIKITA ZAKHAROV	{"phone": "+70856292296"}
0005434823318	7EA5D6	4389 108986	IRINA CHERNOVA	{"email": "chernova.i.061959@postgrespro.ru", "phone": "+70707432964"}
0005434823319	11B4C5	3176 582695	RAISA POTAPOVA	{"email": "potapova-raisa_06051967@postgrespro.ru", "phone": "+70750283373"}
0005434823320	11B4C5	2178 361399	DENIS FILIPPOV	{"phone": "+70073338654"}
0005434823321	11B4C5	3905 185756	IVAN FROLOV	{"email": "frolovi-09031967@postgrespro.ru", "phone": "+70155410963"}
0005434823322	D545CE	1671 312773	NIKOLAY KUZNECOV	{"phone": "+70950120051"}
0005434823323	307E79	3291 521892	EVGENIY ISAEV	{"email": "isaev.e_021990@postgrespro.ru", "phone": "+70981758958"}
0005434823324	4FB82F	2901 618529	EVGENIY SMIRNOV	{"email": "smirnovevgeniy-021976@postgrespro.ru", "phone": "+70749496089"}
0005434823325	4FB82F	3767 593253	VENERA BARANOVA	{"phone": "+70260229541"}
0005434823326	8C0EED	6552 942920	YURIY KUZMIN	{"email": "kuzmin-y.041979@postgrespro.ru", "phone": "+70110977195"}
0005434823327	FBB276	9304 848322	SERGEY ABRAMOV	{"phone": "+70753289098"}
0005434823328	FBB276	8138 864306	EKATERINA BORISOVA	{"email": "ekaterinaborisova_1976@postgrespro.ru", "phone": "+70934511719"}
0005434823329	5912F3	9799 780541	VITALIY BONDARENKO	{"email": "vitaliy-bondarenko031966@postgrespro.ru", "phone": "+70904311107"}
0005434823330	D88578	2710 016756	LYUBOV NIKOLAEVA	{"email": "nikolaeva_lyubov.1968@postgrespro.ru", "phone": "+70203052479"}
0005434823331	D88578	5532 267028	IRINA FILATOVA	{"email": "irina_filatova-20081968@postgrespro.ru", "phone": "+70285751009"}
0005434823332	13829C	0708 100651	NATALYA ANDREEVA	{"phone": "+70829773323"}
0005434823333	096F22	1179 556980	ILYA NAZAROV	{"phone": "+70433629374"}
0005434823334	096F22	3626 132017	RAMIL KUZNECOV	{"phone": "+70439409484"}
0005434823335	096F22	0719 963912	EVGENIY IVANOV	{"email": "e_ivanov_1978@postgrespro.ru", "phone": "+70965984485"}
0005434823336	46CA98	0220 600148	NATALYA PETROVA	{"phone": "+70684858499"}
0005434823337	A553E7	3080 686090	LIDIYA KOLESNIKOVA	{"email": "kolesnikova_lidiya.1976@postgrespro.ru", "phone": "+70690824551"}
0005434823338	A553E7	0037 801128	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova.a1973@postgrespro.ru", "phone": "+70769468754"}
0005434823339	59E7F2	2983 593233	OKSANA LEBEDEVA	{"email": "oksana.lebedeva1973@postgrespro.ru", "phone": "+70289291900"}
0005434823340	59E7F2	3831 605386	ALEKSANDR DENISOV	{"email": "denisov-aleksandr_101972@postgrespro.ru", "phone": "+70607567274"}
0005434823341	84459E	9963 159605	OLGA FILATOVA	{"phone": "+70887763361"}
0005434823342	078F57	7961 876748	ELIZAVETA NIKIFOROVA	{"email": "nikiforova-elizaveta-11061963@postgrespro.ru", "phone": "+70497747004"}
0005434823343	A46872	2984 073232	SVETLANA ANDREEVA	{"email": "andreeva.svetlana03041964@postgrespro.ru", "phone": "+70802829012"}
0005434823344	A46872	5863 007379	ELENA NIKOLAEVA	{"email": "e.nikolaeva-07011967@postgrespro.ru", "phone": "+70213713318"}
0005434823345	A46872	9249 373924	RAMIL VASILEV	{"phone": "+70223464883"}
0005434823346	6F4A90	9992 637425	RAVILYA FILATOVA	{"phone": "+70821796953"}
0005434823347	CCBA02	0577 517138	GALINA MARTYNOVA	{"email": "galinamartynova-081969@postgrespro.ru", "phone": "+70758662873"}
0005434823348	CCBA02	1228 147486	VERA NIKOLAEVA	{"email": "nikolaeva_vera011967@postgrespro.ru", "phone": "+70961765155"}
0005434823349	E85ED7	0992 082468	PETR GRIGOREV	{"phone": "+70029130182"}
0005434823350	D350DE	0396 264432	ANGELINA SOROKINA	{"phone": "+70074392667"}
0005434823351	295DE1	3455 454092	ALEKSANDR DAVYDOV	{"phone": "+70092286971"}
0005434823352	295DE1	2754 418796	NATALYA KOROLEVA	{"email": "n.koroleva1975@postgrespro.ru", "phone": "+70318154043"}
0005434823353	152AD8	4949 128193	ELENA ZHUKOVA	{"phone": "+70227579218"}
0005434823354	152AD8	8814 529908	GENNADIY SMIRNOV	{"email": "smirnov.g.1975@postgrespro.ru", "phone": "+70441689791"}
0005434823355	73EAA5	6912 433532	VERA KOZLOVA	{"email": "verakozlova-1969@postgrespro.ru", "phone": "+70167952691"}
0005434823356	C93CFB	1354 137052	ALSU SOKOLOVA	{"phone": "+70179179641"}
0005434823357	CC66D8	8032 317675	ALEKSANDR SOROKIN	{"phone": "+70520637672"}
0005434823358	A41EBE	6495 384851	DMITRIY BELOV	{"phone": "+70587621924"}
0005434823359	B9053E	7077 242683	ANASTASIYA CHERNOVA	{"email": "chernovaanastasiya-28061976@postgrespro.ru", "phone": "+70085528323"}
0005434823360	B9053E	0544 781464	STANISLAV MOISEEV	{"phone": "+70126940322"}
0005434823361	B48A98	1487 361776	ZINAIDA SMIRNOVA	{"phone": "+70199738377"}
0005434823362	B48A98	6090 272828	IVAN KUZMIN	{"email": "ivan_kuzmin.08031961@postgrespro.ru", "phone": "+70480470419"}
0005434823363	13173C	6050 737406	VERONIKA ZHURAVLEVA	{"email": "v-zhuravleva.29051980@postgrespro.ru", "phone": "+70665921472"}
0005434823364	881FCD	7031 035138	MATVEY BORISOV	{"email": "matveyborisov-27041968@postgrespro.ru", "phone": "+70425450697"}
0005434823365	C7D642	8005 385887	EKATERINA ARKHIPOVA	{"phone": "+70630986835"}
0005434823422	253E9B	8797 486167	MAKSIM FROLOV	{"phone": "+70124776671"}
0005434823366	FFFEF3	2963 853619	BOGDAN GRIGOREV	{"email": "b_grigorev_1969@postgrespro.ru", "phone": "+70197755605"}
0005434823367	D66C37	4841 445989	ANNA FADEEVA	{"phone": "+70407760405"}
0005434823368	D66C37	5774 796289	LYUBOV DMITRIEVA	{"email": "dmitrievalyubov.29051970@postgrespro.ru", "phone": "+70820846229"}
0005434823369	D66C37	6501 362441	MARINA ALEKSEEVA	{"email": "alekseeva.marina_081974@postgrespro.ru", "phone": "+70910440538"}
0005434823370	4FE2BF	1999 333621	TATYANA POTAPOVA	{"phone": "+70758025261"}
0005434823371	DD200A	1997 844305	GENNADIY GAVRILOV	{"email": "gennadiy.gavrilov.21041975@postgrespro.ru", "phone": "+70443111276"}
0005434823372	10520A	1816 398990	ANDREY ANTONOV	{"phone": "+70101930637"}
0005434823373	57E982	6329 161983	VIKTOR SOKOLOV	{"phone": "+70568164249"}
0005434823374	328BA2	3493 329344	TATYANA MAKAROVA	{"phone": "+70206751068"}
0005434823375	4DD4F7	7263 872105	ALEKSANDR ILIN	{"email": "aleksandr-ilin_01091970@postgrespro.ru", "phone": "+70701391195"}
0005434823376	4DD4F7	9714 622428	VLADIMIR PETROV	{"phone": "+70171224940"}
0005434823377	6B4093	7132 706687	SVETLANA SMIRNOVA	{"phone": "+70372198014"}
0005434823378	FF464F	9711 687890	GALINA DANILOVA	{"email": "danilova_g-09041976@postgrespro.ru", "phone": "+70680505871"}
0005434823379	C41FC0	4760 378148	DARYA ANDREEVA	{"phone": "+70624104758"}
0005434823380	726EC1	2321 244014	GALINA KUZNECOVA	{"email": "kuznecova.g_1967@postgrespro.ru", "phone": "+70924157561"}
0005434823381	726EC1	6155 276860	POLINA MOISEEVA	{"email": "moiseeva_p.1964@postgrespro.ru", "phone": "+70807710790"}
0005434823382	726EC1	0040 167537	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikova-a_111961@postgrespro.ru", "phone": "+70068700856"}
0005434823383	D25465	4711 200664	LYUDMILA BORISOVA	{"email": "l_borisova.101981@postgrespro.ru", "phone": "+70583562670"}
0005434823384	13DCF2	3317 418722	VIKTORIYA DMITRIEVA	{"phone": "+70412688844"}
0005434823385	B47941	4034 140618	YANA PAVLOVA	{"email": "pavlova.yana_24061983@postgrespro.ru", "phone": "+70766197659"}
0005434823386	5C6351	1748 563058	ELMIRA IVANOVA	{"email": "e_ivanova-1981@postgrespro.ru", "phone": "+70103795187"}
0005434823387	5C6351	1148 414284	DANIIL IVANOV	{"email": "d.ivanov-1974@postgrespro.ru", "phone": "+70235078176"}
0005434823388	7BB120	7192 024094	MIKHAIL FILIPPOV	{"phone": "+70845390133"}
0005434823389	7BB120	5617 137568	ALEKSEY TIKHONOV	{"phone": "+70519785021"}
0005434823390	4D7B4B	7366 388252	NIKOLAY EGOROV	{"email": "egorov.n081968@postgrespro.ru", "phone": "+70204912604"}
0005434823391	540B1E	0688 845133	DMITRIY NIKITIN	{"phone": "+70841299023"}
0005434823392	8D06B7	8776 508126	ALEKSANDR SOROKIN	{"email": "aleksandr.sorokin051965@postgrespro.ru", "phone": "+70915144699"}
0005434823393	BB951E	5567 821516	YURIY IVANOV	{"phone": "+70073696536"}
0005434823394	70A45C	6219 379232	ALEKSANDR STEPANOV	{"phone": "+70878068514"}
0005434823395	14DB6F	3306 041081	VERA POPOVA	{"email": "vpopova_071978@postgrespro.ru", "phone": "+70949580575"}
0005434823396	4F0A0C	5038 990728	ALEKSEY GUSEV	{"email": "gusev.a-051974@postgrespro.ru", "phone": "+70478170025"}
0005434823397	4F0A0C	1653 761173	EVGENIY GERASIMOV	{"phone": "+70434954801"}
0005434823398	18B7CB	0264 236146	YULIYA PETROVA	{"email": "petrova_y-031978@postgrespro.ru", "phone": "+70430978305"}
0005434823399	18B7CB	6296 325063	NURLAN VOLKOV	{"phone": "+70813214399"}
0005434823400	BF3319	4235 767719	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr_1981@postgrespro.ru", "phone": "+70863520484"}
0005434823401	BF3319	3418 584301	IVAN TIKHONOV	{"phone": "+70860046495"}
0005434823402	3E0FFC	0533 421991	ANNA RYABOVA	{"email": "ryabova.a1968@postgrespro.ru", "phone": "+70909073715"}
0005434823403	3E0FFC	1295 635724	TATYANA ROMANOVA	{"email": "t_romanova_1974@postgrespro.ru", "phone": "+70298481238"}
0005434823404	72A9FE	4357 899610	LYUDMILA KOMAROVA	{"phone": "+70086110823"}
0005434823405	347324	9796 620174	NATALYA KOMAROVA	{"email": "komarova_n.111975@postgrespro.ru", "phone": "+70266138420"}
0005434823406	347324	0075 347865	ANATOLIY POPOV	{"phone": "+70169124291"}
0005434823407	058432	3987 008468	NINA ABRAMOVA	{"phone": "+70781756606"}
0005434823408	297AB0	8048 519711	ANATOLIY PETROV	{"email": "a.petrov_17081977@postgrespro.ru", "phone": "+70110680484"}
0005434823409	889025	8350 502237	ALEKSEY OSIPOV	{"phone": "+70427419819"}
0005434823410	92FF42	5664 878130	LYUDMILA ORLOVA	{"email": "orlova_lyudmila-051957@postgrespro.ru", "phone": "+70319792219"}
0005434823411	C37259	5542 134989	KLAVDIYA ANTONOVA	{"email": "antonova.k_1972@postgrespro.ru", "phone": "+70188402071"}
0005434823412	C37259	5052 209939	ELENA NAZAROVA	{"phone": "+70641961398"}
0005434823413	94227E	7552 045157	ANDREY FROLOV	{"email": "andrey_frolov_1977@postgrespro.ru", "phone": "+70547261315"}
0005434823414	94227E	8377 830326	IRINA KUZNECOVA	{"phone": "+70300060938"}
0005434823415	7DBFB6	5270 453167	VALENTIN KISELEV	{"email": "kiselev.v-111974@postgrespro.ru", "phone": "+70521756985"}
0005434823416	1DB427	1216 542279	MIKHAIL BORISOV	{"email": "borisov_m-23051973@postgrespro.ru", "phone": "+70190390155"}
0005434823417	F95F9F	2383 751367	VIKTORIYA ARKHIPOVA	{"phone": "+70227393583"}
0005434823418	6D9388	0714 346150	IGOR MAKAROV	{"phone": "+70309856670"}
0005434823419	2C8775	1033 065164	NINA SMIRNOVA	{"phone": "+70111371892"}
0005434823420	852B36	3607 031980	ZHANNA KISELEVA	{"email": "z.kiseleva_29041970@postgrespro.ru", "phone": "+70122488835"}
0005434823421	253E9B	4048 455509	GALINA KOROLEVA	{"email": "koroleva_galina28111974@postgrespro.ru", "phone": "+70262311892"}
0005434823423	EF65D0	0447 689333	TATYANA KALININA	{"email": "kalinina-t.051964@postgrespro.ru", "phone": "+70535359688"}
0005434823424	E8840C	7959 366973	ALEKSANDR AFANASEV	{"phone": "+70608831289"}
0005434823425	E8840C	3022 581591	VYACHESLAV IVANOV	{"phone": "+70226250543"}
0005434823426	3C801F	7569 689028	YULIYA SEMENOVA	{"email": "semenova_yuliya121973@postgrespro.ru", "phone": "+70307827112"}
0005434823427	B32A99	6107 501607	ANDREY BONDARENKO	{"email": "a-bondarenko_06081960@postgrespro.ru", "phone": "+70780006180"}
0005434823428	DBC6F2	3850 977879	SVETLANA SOKOLOVA	{"phone": "+70220026292"}
0005434823429	092B74	8858 158319	KLAVDIYA MATVEEVA	{"email": "klavdiya-matveeva_26031971@postgrespro.ru", "phone": "+70036797187"}
0005434823430	534882	3711 076747	ANAIT STEPANOVA	{"email": "stepanova-anait071981@postgrespro.ru", "phone": "+70474189597"}
0005434823431	534882	3286 171263	RUSTAM STEPANOV	{"phone": "+70280914435"}
0005434823432	7BCBFB	3770 627027	NATALYA SCHERBAKOVA	{"phone": "+70374608252"}
0005434823433	74FDF5	6399 137686	IVAN MATVEEV	{"phone": "+70517949391"}
0005434823434	74FDF5	5093 293200	RAFAEL FILIPPOV	{"phone": "+70043601007"}
0005434823435	C2F16C	3161 845367	SERGEY KUZMIN	{"email": "s.kuzmin-03101961@postgrespro.ru", "phone": "+70381955072"}
0005434823436	C2F16C	3678 235394	LIDIYA GAVRILOVA	{"phone": "+70287045903"}
0005434823437	FFEB98	8840 176658	ANTONINA CHERNOVA	{"email": "a-chernova.29061984@postgrespro.ru", "phone": "+70257822710"}
0005434823438	FFEB98	1387 759773	SVETLANA PETROVA	{"phone": "+70371700701"}
0005434823439	B4FCB2	5574 028914	OLGA MEDVEDEVA	{"phone": "+70935275481"}
0005434823440	B4FCB2	0197 921903	FARID BELOV	{"email": "belov_f_28021966@postgrespro.ru", "phone": "+70125866456"}
0005434823441	DCAE00	7377 530882	SERGEY KUZMIN	{"email": "kuzmin_sergey071967@postgrespro.ru", "phone": "+70332784087"}
0005434823442	8143C3	9429 779203	VITALIY MARTYNOV	{"email": "v.martynov.1973@postgrespro.ru", "phone": "+70302529362"}
0005434823443	3924D9	2859 451045	OLGA SMIRNOVA	{"phone": "+70356038999"}
0005434823444	CE903F	3444 613519	OKSANA ILINA	{"email": "oksana_ilina.121962@postgrespro.ru", "phone": "+70890166383"}
0005434823445	6DC45D	2146 578674	ANASTASIYA KOZLOVA	{"email": "anastasiya-kozlova_1971@postgrespro.ru", "phone": "+70505904434"}
0005434823446	6DC45D	2639 252851	ELENA RODIONOVA	{"phone": "+70907715021"}
0005434823447	474AB7	1420 255820	KLARA POPOVA	{"email": "klara-popova_1972@postgrespro.ru", "phone": "+70991984620"}
0005434823448	7C848F	3812 110289	VALENTINA KONOVALOVA	{"phone": "+70654055734"}
0005434823449	7C848F	8899 738414	ELENA ISAEVA	{"email": "isaevae.091969@postgrespro.ru", "phone": "+70434063468"}
0005434823450	19DC5A	1659 364748	MIKHAIL MOISEEV	{"phone": "+70091106482"}
0005434823451	DFC495	1446 572843	ELENA FILATOVA	{"phone": "+70525518661"}
0005434823452	DFC495	4840 895112	VYACHESLAV NIKOLAEV	{"phone": "+70271230175"}
0005434823453	DFC495	6907 188346	VITALIY ROMANOV	{"email": "v_romanov24091984@postgrespro.ru", "phone": "+70023243448"}
0005434823454	D6FBF9	8708 500640	TATYANA PAVLOVA	{"email": "pavlova_tatyana29101981@postgrespro.ru", "phone": "+70643916317"}
0005434823455	38E54A	1329 074040	SERGEY PAVLOV	{"email": "pavlov-sergey_041974@postgrespro.ru", "phone": "+70389020482"}
0005434823456	C626DC	8303 422423	ANNA ABRAMOVA	{"phone": "+70723884211"}
0005434823457	77C277	4606 927688	SVETLANA EFIMOVA	{"phone": "+70024974501"}
0005434823458	77C277	3131 336937	ALINA ZAKHAROVA	{"phone": "+70975026258"}
0005434823459	82C1C7	7577 060229	EVDOKIYA TIMOFEEVA	{"phone": "+70810719564"}
0005434823460	3E936E	1047 177645	LYUBOV CHERNOVA	{"phone": "+70159986829"}
0005434823461	A80424	3226 437407	VALENTINA ABRAMOVA	{"email": "abramova_v_051978@postgrespro.ru", "phone": "+70769011622"}
0005434823462	A80424	6975 147317	ALEKSANDR MIKHAYLOV	{"phone": "+70917669784"}
0005434823463	A62575	5009 015629	YULIYA DAVYDOVA	{"email": "davydova.yuliya1968@postgrespro.ru", "phone": "+70586120846"}
0005434823464	8FCC41	1533 410682	NINA SOKOLOVA	{"phone": "+70701895292"}
0005434823465	3AD4DB	7803 121830	MIKHAIL MELNIKOV	{"email": "melnikov_m.25071969@postgrespro.ru", "phone": "+70987067515"}
0005434823466	3AD4DB	5483 778650	VYACHESLAV NIKOLAEV	{"email": "vyacheslavnikolaev07121973@postgrespro.ru", "phone": "+70721343698"}
0005434823467	23608C	1863 470697	VALENTINA DAVYDOVA	{"email": "v_davydova-061976@postgrespro.ru", "phone": "+70697255417"}
0005434823468	23608C	4378 395940	NATALYA GERASIMOVA	{"email": "gerasimovan_16091971@postgrespro.ru", "phone": "+70845086817"}
0005434823469	23608C	1949 546664	SERGEY MELNIKOV	{"email": "sergeymelnikov25021976@postgrespro.ru", "phone": "+70365655597"}
0005434823470	841F8D	6145 452004	GEORGIY AFANASEV	{"phone": "+70165123154"}
0005434823471	91B30F	7529 607872	TATYANA VASILEVA	{"email": "tatyanavasileva_11061964@postgrespro.ru", "phone": "+70138769135"}
0005434823472	D951FD	7707 971184	LYUBOV KULIKOVA	{"email": "kulikovalyubov041967@postgrespro.ru", "phone": "+70311356565"}
0005434823473	D951FD	4353 870185	ALEKSEY ZAKHAROV	{"email": "zakharov-aleksey.1976@postgrespro.ru", "phone": "+70634379349"}
0005434823474	5EE269	8114 960527	DMITRIY VASILEV	{"email": "dvasilev1970@postgrespro.ru", "phone": "+70754080756"}
0005434823475	8DEE99	4654 917184	VIKTOR FEDOTOV	{"phone": "+70481501492"}
0005434823476	EBF84B	2078 603911	ELENA CHERNOVA	{"phone": "+70765392308"}
0005434823477	E72968	8976 898391	RAMILYA KOROLEVA	{"email": "koroleva.ramilya-1976@postgrespro.ru", "phone": "+70930146746"}
0005434823478	E72968	2877 345719	YURIY KUZNECOV	{"phone": "+70101378804"}
0005434823479	E72968	6955 491208	ALEKSANDR SMIRNOV	{"phone": "+70121414093"}
0005434823480	73CD55	8966 560102	YURIY FROLOV	{"phone": "+70527789913"}
0005434823481	F57DBF	9645 885835	ANDREY FEDOROV	{"email": "fedorov-a-29111972@postgrespro.ru", "phone": "+70828721939"}
0005434823482	626781	7960 567517	VLADISLAV OSIPOV	{"phone": "+70598844967"}
0005434823483	455BD4	1650 057229	LIDIYA SERGEEVA	{"email": "sergeeval.011973@postgrespro.ru", "phone": "+70379513265"}
0005434823484	455BD4	5255 152657	TATYANA ALEKSEEVA	{"email": "t-alekseeva091972@postgrespro.ru", "phone": "+70634138980"}
0005434823485	40604C	4267 226142	TATYANA OSIPOVA	{"phone": "+70063643036"}
0005434823486	4CBC33	5806 322769	YULIYA ANDREEVA	{"email": "andreeva.y-04031970@postgrespro.ru", "phone": "+70065089851"}
0005434823487	4CBC33	5309 577942	ALEKSANDR DAVYDOV	{"phone": "+70177620924"}
0005434823488	7B88D1	7662 633543	EVGENIY DMITRIEV	{"phone": "+70878428632"}
0005434823489	BA1DF0	1203 297849	SVETLANA TIKHONOVA	{"email": "tikhonova-s_06011966@postgrespro.ru", "phone": "+70185772796"}
0005434823846	9EF99A	7538 914981	ANDREY OSIPOV	{"phone": "+70097842701"}
0005434823490	BA1DF0	2806 961795	RUSLAN OSIPOV	{"email": "osipov.ruslan-031970@postgrespro.ru", "phone": "+70115121627"}
0005434823491	D3B903	4220 748696	OLGA SERGEEVA	{"phone": "+70598736053"}
0005434823492	570873	5131 558001	ARTEM IVANOV	{"phone": "+70979284317"}
0005434823493	570873	2417 620092	SERGEY ZHUKOV	{"email": "zhukov_sergey-041976@postgrespro.ru", "phone": "+70513890097"}
0005434823494	E030A3	6631 306934	RAISA KAZAKOVA	{"email": "r_kazakova1982@postgrespro.ru", "phone": "+70337220136"}
0005434823495	8BE0D1	4179 292992	ANDREY TIMOFEEV	{"phone": "+70050875517"}
0005434823496	52EA2C	3453 400893	ANDREY SOKOLOV	{"email": "andrey.sokolov_06051967@postgrespro.ru", "phone": "+70139774358"}
0005434823497	52EA2C	8480 538531	SERGEY BORISOV	{"email": "sergeyborisov.101969@postgrespro.ru", "phone": "+70607990449"}
0005434823498	2EA545	9441 791206	VLADIMIR IVANOV	{"email": "ivanovvladimir.1969@postgrespro.ru", "phone": "+70449338781"}
0005434823499	5C3C24	2883 501715	ALEKSANDR SOKOLOV	{"phone": "+70655738800"}
0005434823500	C57ECE	0486 535408	VADIM SMIRNOV	{"phone": "+70582943162"}
0005434823501	236CA3	3073 512276	MARGARITA MATVEEVA	{"phone": "+70537337245"}
0005434823502	236CA3	5152 485793	ELIZAVETA ZAKHAROVA	{"phone": "+70902988614"}
0005434823503	D19BE2	7749 063814	ANDREY KUDRYASHOV	{"email": "kudryashov.andrey-12061973@postgrespro.ru", "phone": "+70705386949"}
0005434823504	A32FCA	1411 827448	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov-12091971@postgrespro.ru", "phone": "+70621963220"}
0005434823505	FAFBCF	1795 012587	TATYANA MIKHAYLOVA	{"phone": "+70236508490"}
0005434823506	FAFBCF	2421 779277	ANNA NAZAROVA	{"phone": "+70239909984"}
0005434823507	2C147F	9638 912052	MATVEY VOROBEV	{"phone": "+70240443619"}
0005434823508	2C147F	7704 424322	IVAN BONDARENKO	{"phone": "+70246507644"}
0005434823509	8B7638	7453 544738	ALEKSEY NIKOLAEV	{"email": "nikolaev_aleksey-1983@postgrespro.ru", "phone": "+70309277858"}
0005434823510	8B7638	6228 717503	IGOR NAZAROV	{"email": "nazarov-i.071974@postgrespro.ru", "phone": "+70114925265"}
0005434823511	527FC8	6170 111496	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr1977@postgrespro.ru", "phone": "+70363002329"}
0005434823512	527FC8	5973 433713	ANASTASIYA ZOTOVA	{"phone": "+70815224602"}
0005434823513	527FC8	6872 200607	ELVIRA ROMANOVA	{"email": "e_romanova-031962@postgrespro.ru", "phone": "+70582791146"}
0005434823514	618296	5473 399873	VALENTINA SMIRNOVA	{"phone": "+70035696421"}
0005434823515	618296	8119 509762	VLADIMIR NIKOLAEV	{"phone": "+70829431079"}
0005434823516	A00BE6	5670 977531	VALERIY ROMANOV	{"phone": "+70299448253"}
0005434823517	D9C4B9	6257 647151	GALINA KARPOVA	{"phone": "+70661892454"}
0005434823518	BF2797	8320 655575	EKATERINA MAKAROVA	{"email": "ekaterina.makarova_1979@postgrespro.ru", "phone": "+70843015499"}
0005434823519	BF2797	5618 525150	ALENA KONOVALOVA	{"phone": "+70420336233"}
0005434823520	D77F76	9890 797241	IVAN VASILEV	{"email": "i-vasilev1974@postgrespro.ru", "phone": "+70702499853"}
0005434823521	35341A	5663 216912	OLGA BOGDANOVA	{"email": "o.bogdanova-081972@postgrespro.ru", "phone": "+70154337984"}
0005434823522	35341A	9526 192059	NATALIYA BORISOVA	{"phone": "+70208628082"}
0005434823523	35341A	8543 640391	SVETLANA VOLKOVA	{"email": "volkova.s-02051971@postgrespro.ru", "phone": "+70595598279"}
0005434823524	16A4BA	3215 188093	GLEB TIMOFEEV	{"phone": "+70823363103"}
0005434823525	CB3AED	6532 316641	TATYANA ZAYCEVA	{"email": "tatyana_zayceva-23071958@postgrespro.ru", "phone": "+70016605555"}
0005434823526	CB3AED	4348 025121	RAISA PETROVA	{"email": "petrova.r-1985@postgrespro.ru", "phone": "+70366222804"}
0005434823527	062C1B	4504 666778	OLGA KOZLOVA	{"phone": "+70018674547"}
0005434823528	45C3A5	7007 004711	VALENTINA VOROBEVA	{"phone": "+70651118390"}
0005434823529	DFFC3E	2482 598032	ALBERT DMITRIEV	{"phone": "+70595066187"}
0005434823530	C7888D	8131 348643	SVETLANA KUZNECOVA	{"phone": "+70897314704"}
0005434823531	13F2BC	7524 356914	SERGEY NIKOLAEV	{"phone": "+70055872536"}
0005434823532	13F2BC	4779 033324	ANNA MAKAROVA	{"phone": "+70737696573"}
0005434823533	6B6299	3884 904863	VIKTOR SOLOVEV	{"phone": "+70503309578"}
0005434823534	A36C65	8771 923775	EKATERINA VLASOVA	{"phone": "+70175544673"}
0005434823535	A36C65	1263 213377	MARINA SIDOROVA	{"phone": "+70073964151"}
0005434823536	7E67E8	2057 986395	ALEKSANDR STEPANOV	{"phone": "+70583033108"}
0005434823537	7E67E8	2224 870154	VASILIY MEDVEDEV	{"phone": "+70821749450"}
0005434823538	B5D600	1753 128373	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila_1978@postgrespro.ru", "phone": "+70006331655"}
0005434823539	84B3C1	8707 675984	TATYANA SOROKINA	{"phone": "+70776560733"}
0005434823540	7CB58D	3309 586771	NINA ANDREEVA	{"email": "andreeva_nina_25011972@postgrespro.ru", "phone": "+70809136398"}
0005434823541	7CB58D	2074 068623	DMITRIY FILIPPOV	{"email": "dmitriyfilippov_1967@postgrespro.ru", "phone": "+70392547002"}
0005434823542	8089CC	5430 091501	NIKOLAY ROMANOV	{"phone": "+70325641655"}
0005434823543	12E367	0766 603668	ALEKSANDRA ABRAMOVA	{"email": "abramova.a27081974@postgrespro.ru", "phone": "+70989157350"}
0005434823544	12E367	5785 308956	GENNADIY ILIN	{"email": "g_ilin1973@postgrespro.ru", "phone": "+70569471722"}
0005434823545	A5B91B	2339 341582	ILYA KULIKOV	{"email": "i-kulikov03021977@postgrespro.ru", "phone": "+70261815481"}
0005434823546	4354F2	6202 137308	EKATERINA STEPANOVA	{"phone": "+70550443335"}
0005434823547	DD424F	0493 651861	VALERIY IVANOV	{"email": "v-ivanov.1962@postgrespro.ru", "phone": "+70721438233"}
0005434823548	DD424F	6078 798618	GALINA MATVEEVA	{"phone": "+70808374046"}
0005434823549	333074	0887 211745	IRINA BOGDANOVA	{"email": "bogdanova_irina26101979@postgrespro.ru", "phone": "+70690199029"}
0005434823550	F5B0BF	5420 394347	ANTON MIRONOV	{"phone": "+70941678173"}
0005434823551	4719C6	5200 196872	YURIY IVANOV	{"email": "y.ivanov-24021979@postgrespro.ru", "phone": "+70830658949"}
0005434823552	D96659	2374 748635	OLEG SOKOLOV	{"email": "oleg.sokolov-101960@postgrespro.ru", "phone": "+70211694773"}
0005434823553	240462	5297 804970	ELENA DMITRIEVA	{"email": "dmitrieva-e-1971@postgrespro.ru", "phone": "+70287597527"}
0005434823554	240462	5325 182144	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr16081976@postgrespro.ru", "phone": "+70841314284"}
0005434823555	33528C	6803 615564	OLEG PETROV	{"phone": "+70658755242"}
0005434823674	4441BC	3855 140020	ALINA VOLKOVA	{"phone": "+70077163294"}
0005434823556	08836F	9786 131748	NINA TIKHONOVA	{"email": "tikhonova.nina_19121976@postgrespro.ru", "phone": "+70458609588"}
0005434823557	A5D7EC	4131 724482	VIKTOR ZAKHAROV	{"phone": "+70823845434"}
0005434823558	EBCB71	4616 838894	ALEKSANDR IVANOV	{"phone": "+70721463850"}
0005434823559	0B20EC	4036 103798	OLGA GORBUNOVA	{"email": "olga.gorbunova.061977@postgrespro.ru", "phone": "+70216148580"}
0005434823560	08EFD1	3427 948657	NIKOLAY IVANOV	{"email": "ivanov_n_1975@postgrespro.ru", "phone": "+70349514596"}
0005434823561	DB06B3	1441 640456	VADIM ZAYCEV	{"phone": "+70233485166"}
0005434823562	DB06B3	8483 017997	EKATERINA ALEKSEEVA	{"phone": "+70407310339"}
0005434823563	5552F3	9874 332615	ALENA MATVEEVA	{"phone": "+70264920828"}
0005434823564	5552F3	4806 645870	IGOR VLASOV	{"phone": "+70505521722"}
0005434823565	86CB96	5341 306292	RUZALIYA YAKOVLEVA	{"email": "ruzaliyayakovleva-24101973@postgrespro.ru", "phone": "+70918584625"}
0005434823566	86CB96	0114 383251	MARIYA ROMANOVA	{"email": "mromanova-13071966@postgrespro.ru", "phone": "+70255764622"}
0005434823567	5B37B7	0214 957594	DMITRIY KOROLEV	{"email": "korolev.d-121977@postgrespro.ru", "phone": "+70425178156"}
0005434823568	71B1FD	9930 956244	GALINA KAZAKOVA	{"email": "g-kazakova1970@postgrespro.ru", "phone": "+70948945210"}
0005434823569	535DC4	3427 613514	OLGA EGOROVA	{"phone": "+70592692562"}
0005434823570	535DC4	6177 384843	GALINA SEMENOVA	{"phone": "+70130358605"}
0005434823571	BFCA5F	8057 993151	RENAT GORBUNOV	{"email": "renat-gorbunov_1972@postgrespro.ru", "phone": "+70850986511"}
0005434823572	BAAEE5	4890 126280	ELEONORA KOROLEVA	{"email": "eleonora-koroleva_091970@postgrespro.ru", "phone": "+70098227138"}
0005434823573	F101E5	3769 155493	MARIYA ORLOVA	{"email": "orlovam061973@postgrespro.ru", "phone": "+70224947946"}
0005434823574	208D6B	5476 094727	TAMARA FROLOVA	{"email": "frolova.tamara_1971@postgrespro.ru", "phone": "+70603657817"}
0005434823575	42C281	0606 333470	ALEKSANDR SERGEEV	{"phone": "+70951315068"}
0005434823576	441882	9196 452213	ANTONINA LEBEDEVA	{"phone": "+70190429519"}
0005434823577	C2E504	1212 473724	ILYA MEDVEDEV	{"phone": "+70171804722"}
0005434823578	0E8FA9	1896 234994	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a_121960@postgrespro.ru", "phone": "+70179111598"}
0005434823579	0E8FA9	4059 164661	MARIYA SAVELEVA	{"phone": "+70482426635"}
0005434823580	F9BC94	9650 867292	NIKOLAY PAVLOV	{"phone": "+70259731246"}
0005434823581	4E5444	2279 281752	ROMAN NOVIKOV	{"email": "novikov.roman.13101970@postgrespro.ru", "phone": "+70382997912"}
0005434823582	4E5444	3779 247234	MIKHAIL BONDARENKO	{"phone": "+70272626329"}
0005434823583	61D73E	0975 153270	TAMARA KOMAROVA	{"email": "komarovat_1980@postgrespro.ru", "phone": "+70465634585"}
0005434823584	61D73E	2733 080698	NADEZHDA ANDREEVA	{"email": "andreeva.nadezhda051966@postgrespro.ru", "phone": "+70485556625"}
0005434823585	01E477	3620 609871	NATALYA MOISEEVA	{"email": "n.moiseeva.051972@postgrespro.ru", "phone": "+70868886835"}
0005434823586	5714B9	7401 167204	SERGEY BORISOV	{"phone": "+70161552029"}
0005434823587	5714B9	6727 636071	SVETLANA POPOVA	{"email": "svetlana.popova_1969@postgrespro.ru", "phone": "+70334741192"}
0005434823588	EC53B0	0403 532666	BORIS MAKAROV	{"email": "makarovboris1967@postgrespro.ru", "phone": "+70922130124"}
0005434823589	7C9B86	7062 897336	VALERIYA ZHURAVLEVA	{"phone": "+70224493215"}
0005434823590	7C9B86	9159 034817	SVETLANA NIKOLAEVA	{"phone": "+70164647303"}
0005434823591	4DB3D2	2150 481715	VITALIY KOZLOV	{"email": "kozlov.v031966@postgrespro.ru", "phone": "+70614739231"}
0005434823592	6FD744	7851 701993	ALEKSANDR BORISOV	{"email": "borisova.05011963@postgrespro.ru", "phone": "+70675094538"}
0005434823593	E88411	3428 969654	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr19101966@postgrespro.ru", "phone": "+70756037070"}
0005434823594	E88411	2700 835387	NATALYA ANDREEVA	{"phone": "+70054473110"}
0005434823595	21B427	5968 902646	ALENA KUZNECOVA	{"email": "a_kuznecova14051962@postgrespro.ru", "phone": "+70922152102"}
0005434823596	537EC6	2633 439107	VALENTINA GORBUNOVA	{"email": "gorbunova-valentina30041971@postgrespro.ru", "phone": "+70046209883"}
0005434823597	46BE35	1400 308890	SHAVKAT KUZNECOV	{"email": "shavkat_kuznecov.061978@postgrespro.ru", "phone": "+70719274023"}
0005434823598	CF861F	4091 694464	NINA KOZLOVA	{"email": "kozlova_n1983@postgrespro.ru", "phone": "+70435094363"}
0005434823599	CF861F	5440 381357	ALEKSEY GRIGOREV	{"email": "grigoreva-021965@postgrespro.ru", "phone": "+70558500459"}
0005434823600	38BA86	0335 901471	NATALIYA FOMINA	{"phone": "+70955673821"}
0005434823601	F8EB43	6250 243140	VLADIMIR RODIONOV	{"email": "vladimir.rodionov121968@postgrespro.ru", "phone": "+70615494554"}
0005434823602	F8EB43	6644 096188	ALEKSANDR ILIN	{"email": "aleksandrilin.25111968@postgrespro.ru", "phone": "+70096572831"}
0005434823603	DDE724	3788 973237	OLEG BORISOV	{"email": "o.borisov-101987@postgrespro.ru", "phone": "+70926401051"}
0005434823604	E1B129	6505 084508	TATYANA MAKAROVA	{"phone": "+70363920268"}
0005434823605	E1B129	7249 573744	VYACHESLAV EGOROV	{"email": "v.egorov1964@postgrespro.ru", "phone": "+70939498670"}
0005434823606	97485E	2837 025113	VASILIY SCHERBAKOV	{"phone": "+70755890484"}
0005434823607	3AB23F	5217 908237	SERGEY CHERNOV	{"email": "chernov-sergey-1965@postgrespro.ru", "phone": "+70318603532"}
0005434823608	3AB23F	6089 971785	VALENTINA MAKSIMOVA	{"email": "v_maksimova.011976@postgrespro.ru", "phone": "+70396330397"}
0005434823609	3FBB50	8031 143803	MARIANNA KUZNECOVA	{"phone": "+70623235065"}
0005434823610	3FBB50	2591 684782	YURIY SOKOLOV	{"email": "sokolov-y25041969@postgrespro.ru", "phone": "+70247543258"}
0005434823611	5FDECD	3604 689108	ALFIYA MOROZOVA	{"email": "amorozova27061981@postgrespro.ru", "phone": "+70369909658"}
0005434823612	313E66	4004 388238	LIDIYA KUZMINA	{"email": "kuzmina-l_1969@postgrespro.ru", "phone": "+70235663825"}
0005434823613	722F1C	6238 050176	ALEKSANDR FROLOV	{"email": "frolov_aleksandr08081974@postgrespro.ru", "phone": "+70682812225"}
0005434823614	55361B	8560 106883	VALERIY GORBUNOV	{"email": "gorbunov.v.041981@postgrespro.ru", "phone": "+70706074089"}
0005434823615	55361B	5533 300466	IRINA ANTONOVA	{"phone": "+70333035661"}
0005434823616	55361B	4466 163068	DMITRIY ALEKSANDROV	{"phone": "+70876187636"}
0005434823617	F78CEC	9081 695356	ALISA ABRAMOVA	{"email": "alisa-abramova_1971@postgrespro.ru", "phone": "+70235556024"}
0005434823618	038D46	9125 338013	PAVEL VOLKOV	{"phone": "+70443952483"}
0005434823619	038D46	5403 727353	TATYANA MIRONOVA	{"email": "mironova_t.1973@postgrespro.ru", "phone": "+70393992881"}
0005434823620	0B5353	7664 908506	YURIY CHERNOV	{"email": "chernovyuriy.1974@postgrespro.ru", "phone": "+70182175781"}
0005434823621	EDDABE	1936 278437	MARIYA KOZLOVA	{"phone": "+70739821248"}
0005434823622	EDDABE	6327 788937	ALENA MAKAROVA	{"email": "amakarova_03011974@postgrespro.ru", "phone": "+70022239477"}
0005434823623	4A28E9	0519 764496	DMITRIY AFANASEV	{"email": "afanasevdmitriy.091969@postgrespro.ru", "phone": "+70518148900"}
0005434823624	4A28E9	2438 676192	NADEZHDA KONDRATEVA	{"email": "kondrateva-nadezhda_061976@postgrespro.ru", "phone": "+70044617303"}
0005434823625	647E4C	0998 310719	ELENA ABRAMOVA	{"email": "abramovaelena_19071979@postgrespro.ru", "phone": "+70909826353"}
0005434823626	17B2DE	2585 943619	VALENTINA ZAYCEVA	{"email": "valentina-zayceva.1970@postgrespro.ru", "phone": "+70699985964"}
0005434823627	22B29C	6538 160498	NADEZHDA SAVELEVA	{"phone": "+70335366761"}
0005434823628	22B29C	5189 643838	KONSTANTIN SEMENOV	{"email": "konstantinsemenov.1966@postgrespro.ru", "phone": "+70063725798"}
0005434823629	6ED7F3	1069 428366	YURIY SMIRNOV	{"phone": "+70075644556"}
0005434823630	6ED7F3	5953 713970	NIKOLAY BELOV	{"phone": "+70941996823"}
0005434823631	23099B	2225 554162	SERGEY SOLOVEV	{"phone": "+70227561575"}
0005434823632	77B5AB	7823 685067	DARYA ABRAMOVA	{"email": "abramova_darya_041973@postgrespro.ru", "phone": "+70922513236"}
0005434823633	7167C5	9369 252605	ELENA PETROVA	{"email": "petrova.elena111971@postgrespro.ru", "phone": "+70508322190"}
0005434823634	7167C5	3891 373089	LIDIYA KUDRYASHOVA	{"email": "lidiya-kudryashova_061960@postgrespro.ru", "phone": "+70592349889"}
0005434823635	A42471	1048 709707	NADEZHDA PAVLOVA	{"phone": "+70073754931"}
0005434823636	BA4ADF	2284 582628	DMITRIY POPOV	{"email": "popov.dmitriy.23011958@postgrespro.ru", "phone": "+70448755292"}
0005434823637	68C11F	3400 343351	ALEKSEY IVANOV	{"phone": "+70102333231"}
0005434823638	68C11F	2286 959528	VERA FILATOVA	{"phone": "+70408810713"}
0005434823639	CB4B52	9587 679301	YULIYA IVANOVA	{"email": "y-ivanova.1970@postgrespro.ru", "phone": "+70838390794"}
0005434823640	CB4B52	7659 428822	MIKHAIL KAZAKOV	{"phone": "+70386538402"}
0005434823641	CB4B52	6405 182122	OLEG ABRAMOV	{"phone": "+70197038685"}
0005434823642	7CECEC	1533 477320	SVETLANA RODIONOVA	{"phone": "+70008338100"}
0005434823643	62695C	1698 828355	ARTUR GUSEV	{"email": "gusev_artur.14101976@postgrespro.ru", "phone": "+70990217381"}
0005434823644	62695C	1332 163957	YULIYA SERGEEVA	{"email": "sergeeva_y-1979@postgrespro.ru", "phone": "+70205402556"}
0005434823645	635727	3330 711168	NIKOLAY VOLKOV	{"email": "nikolay.volkov-19121971@postgrespro.ru", "phone": "+70529557984"}
0005434823646	635727	2079 474786	VLADIMIR BORISOV	{"phone": "+70349573021"}
0005434823647	AE2F21	2949 282740	MAKSIM FROLOV	{"email": "frolovm.05021974@postgrespro.ru", "phone": "+70560269139"}
0005434823648	F6F33F	3970 661307	SERGEY KUZNECOV	{"email": "s-kuznecov_25121969@postgrespro.ru", "phone": "+70540631458"}
0005434823649	F6F33F	0334 105581	VYACHESLAV GUSEV	{"phone": "+70345631712"}
0005434823650	67595C	0547 825563	MARINA BARANOVA	{"phone": "+70909104272"}
0005434823651	62F343	2898 192207	SOFYA KAZAKOVA	{"email": "kazakova.sofya.12121973@postgrespro.ru", "phone": "+70471938317"}
0005434823652	62F343	9211 547310	DENIS POPOV	{"phone": "+70227477991"}
0005434823653	62F343	3850 913373	NADEZHDA ORLOVA	{"phone": "+70495481654"}
0005434823654	B56C91	3979 385827	EKATERINA KUZNECOVA	{"phone": "+70154478301"}
0005434823655	48DC7C	9551 746076	VALENTIN OSIPOV	{"email": "osipov.valentin_03061964@postgrespro.ru", "phone": "+70670314442"}
0005434823656	AE59A4	5341 632447	TATYANA FADEEVA	{"email": "fadeevatatyana.22071971@postgrespro.ru", "phone": "+70231071325"}
0005434823657	4B9072	2742 455307	RAVIL ALEKSEEV	{"phone": "+70124449292"}
0005434823658	061983	6670 699030	NATALIYA FADEEVA	{"email": "nataliya_fadeeva-22101975@postgrespro.ru", "phone": "+70408989812"}
0005434823659	933CCA	4119 319396	KLAVDIYA ALEKSEEVA	{"phone": "+70342145446"}
0005434823660	3AD59D	8299 060827	SERGEY SMIRNOV	{"email": "ssmirnov-16071973@postgrespro.ru", "phone": "+70971330958"}
0005434823661	C97604	7963 598256	ELENA OSIPOVA	{"phone": "+70342864898"}
0005434823662	C97604	2554 969822	POLINA FILATOVA	{"email": "polina-filatova-04121967@postgrespro.ru", "phone": "+70131244672"}
0005434823663	11CE69	0578 956578	ANTON KUZNECOV	{"phone": "+70824217451"}
0005434823664	11CE69	1962 292365	OLEG POPOV	{"email": "o-popov.27061979@postgrespro.ru", "phone": "+70825745257"}
0005434823665	A25428	5799 210124	TATYANA VOROBEVA	{"phone": "+70383375446"}
0005434823666	A25428	2944 801362	ANDREY IVANOV	{"email": "ivanovandrey_1969@postgrespro.ru", "phone": "+70210973419"}
0005434823667	FBD551	6472 852175	LYUDMILA MEDVEDEVA	{"phone": "+70755982642"}
0005434823668	706053	4819 301721	DMITRIY NAZAROV	{"email": "nazarov-d.17121984@postgrespro.ru", "phone": "+70371203524"}
0005434823669	706053	0622 212931	GENNADIY KAZAKOV	{"email": "gkazakov_1972@postgrespro.ru", "phone": "+70869349980"}
0005434823670	55C2F2	7640 978934	ANNA MIKHAYLOVA	{"phone": "+70499015032"}
0005434823671	55C2F2	1872 991527	VITALIY AFANASEV	{"email": "afanasev.v.101985@postgrespro.ru", "phone": "+70044358890"}
0005434823672	5BB4A4	9685 900453	EVGENIYA KUZNECOVA	{"phone": "+70848300395"}
0005434823673	5BB4A4	8305 180238	YULIYA KONOVALOVA	{"phone": "+70458231316"}
0005434823675	9DC7E4	9216 171213	VASILIY MARTYNOV	{"email": "martynovv.1977@postgrespro.ru", "phone": "+70812427640"}
0005434823676	C5D43B	8218 503951	ZOYA ZAYCEVA	{"email": "z_zayceva.111981@postgrespro.ru", "phone": "+70285908149"}
0005434823677	C5D43B	8405 831080	VITALIY MIKHAYLOV	{"phone": "+70900512867"}
0005434823678	5CE11F	3713 590466	ALEKSANDR VASILEV	{"email": "vasilev-aleksandr121976@postgrespro.ru", "phone": "+70529809560"}
0005434823679	5CE11F	3169 288866	IRINA FADEEVA	{"phone": "+70695616885"}
0005434823680	EBA20D	7515 297783	MARIYA EGOROVA	{"email": "m_egorova.091977@postgrespro.ru", "phone": "+70452379510"}
0005434823681	EBA20D	7373 139246	GALINA MAKAROVA	{"email": "makarova.galina-09021968@postgrespro.ru", "phone": "+70775736215"}
0005434823682	B0227C	3359 825133	MARIYA AKIMOVA	{"email": "akimova-mariya_1969@postgrespro.ru", "phone": "+70070344149"}
0005434823683	B0227C	8843 503082	MAKAR KRASNOV	{"email": "m.krasnov081966@postgrespro.ru", "phone": "+70767877154"}
0005434823684	F6AA4D	0237 168539	ARTUR SAVELEV	{"phone": "+70834055686"}
0005434823685	FDC0C6	8077 973169	ALEKSANDR EGOROV	{"email": "aegorov-1982@postgrespro.ru", "phone": "+70668275360"}
0005434823686	FDC0C6	2813 950546	SERGEY KOROLEV	{"email": "skorolev1977@postgrespro.ru", "phone": "+70148575476"}
0005434823687	C6C738	8699 724855	NATALYA LOGINOVA	{"phone": "+70914714247"}
0005434823688	20D54D	1225 219621	LYUDMILA ZAKHAROVA	{"phone": "+70299811861"}
0005434823689	520DFB	1056 984562	ANDREY KULIKOV	{"email": "andrey_kulikov_041972@postgrespro.ru", "phone": "+70650400485"}
0005434823690	520DFB	1486 852525	LYUDMILA EGOROVA	{"phone": "+70550044085"}
0005434823691	7B6C0E	7312 136956	RUSLAN MIRONOV	{"email": "r.mironov-1968@postgrespro.ru", "phone": "+70413928497"}
0005434823692	7B6C0E	8896 382532	VIKTOR FILIPPOV	{"email": "v-filippov_011971@postgrespro.ru", "phone": "+70373349372"}
0005434823693	7B6C0E	0297 829722	ALEKSANDR IVANOV	{"email": "ivanova_1987@postgrespro.ru", "phone": "+70049349439"}
0005434823694	16C66E	2916 666137	KLAVDIYA TIKHONOVA	{"email": "tikhonova_klavdiya.071962@postgrespro.ru", "phone": "+70176056975"}
0005434823695	16C66E	6020 254886	OKSANA KUDRYASHOVA	{"email": "kudryashova.o_1959@postgrespro.ru", "phone": "+70946809904"}
0005434823696	616E6E	0860 009866	SERGEY SIDOROV	{"phone": "+70833572780"}
0005434823697	91842F	6657 299259	KRISTINA GRISHINA	{"phone": "+70161817584"}
0005434823698	2C65C6	3988 683243	ANASTASIYA ANTONOVA	{"phone": "+70568500304"}
0005434823699	2C65C6	3831 977293	ALBINA ERMAKOVA	{"email": "ermakovaa.1974@postgrespro.ru", "phone": "+70899026404"}
0005434823700	A806A9	3903 530151	SERGEY MEDVEDEV	{"phone": "+70426617704"}
0005434823701	BA195B	7062 689745	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov-081965@postgrespro.ru", "phone": "+70780118789"}
0005434823702	BA195B	5860 354870	ILYA ISAEV	{"phone": "+70693396947"}
0005434823703	BA195B	7734 620957	NIKITA FILIPPOV	{"phone": "+70909875076"}
0005434823704	5DCC84	7000 035746	VYACHESLAV ORLOV	{"phone": "+70389782158"}
0005434823705	5DCC84	9093 256928	VLADISLAV SERGEEV	{"phone": "+70678614103"}
0005434823706	88EE78	5708 742511	DENIS ROMANOV	{"phone": "+70961600762"}
0005434823707	88EE78	6038 986963	ANNA NOVIKOVA	{"phone": "+70289101940"}
0005434823708	8A2B9D	3743 569411	ELENA POLYAKOVA	{"phone": "+70358030226"}
0005434823709	99718E	9165 640089	OLEG MATVEEV	{"email": "o.matveev08071969@postgrespro.ru", "phone": "+70859016363"}
0005434823710	99718E	8634 918183	OLGA KAZAKOVA	{"phone": "+70421560279"}
0005434823711	C7B521	4334 219668	VYACHESLAV RODIONOV	{"phone": "+70049940995"}
0005434823712	0E25A6	2568 438520	NATALYA VOROBEVA	{"email": "natalyavorobeva_031977@postgrespro.ru", "phone": "+70327568839"}
0005434823713	AEA18D	3503 998259	NIKOLAY IVANOV	{"phone": "+70155333185"}
0005434823714	AEA18D	3997 168938	SERGEY ABRAMOV	{"phone": "+70672215676"}
0005434823715	AEA18D	9247 439501	ANATOLIY KOZLOV	{"phone": "+70478771826"}
0005434823716	DB4A8C	4815 550283	ELENA DAVYDOVA	{"email": "e.davydova031983@postgrespro.ru", "phone": "+70722843961"}
0005434823717	B14691	0124 638712	OLGA IVANOVA	{"email": "o_ivanova_081983@postgrespro.ru", "phone": "+70706076687"}
0005434823718	B14691	3655 228719	OLGA ZAKHAROVA	{"phone": "+70856060835"}
0005434823719	9421F6	2035 531171	LYUBOV MIRONOVA	{"email": "mironova-l1968@postgrespro.ru", "phone": "+70923155684"}
0005434823720	F3A9C2	7361 713149	YURIY DAVYDOV	{"email": "ydavydov081976@postgrespro.ru", "phone": "+70400603478"}
0005434823721	C2EE74	7553 773200	OLGA MAKSIMOVA	{"email": "olga_maksimova-07031970@postgrespro.ru", "phone": "+70567639611"}
0005434823722	C2EE74	5602 183513	TAISIYA ANTONOVA	{"email": "antonova_taisiya_24121961@postgrespro.ru", "phone": "+70444962025"}
0005434823723	AB634E	3939 993383	NIKOLAY FROLOV	{"email": "nikolayfrolov-1967@postgrespro.ru", "phone": "+70232208580"}
0005434823724	AB634E	8780 584553	VLADIMIR KUZMIN	{"phone": "+70373589263"}
0005434823725	A449EF	5902 292084	OLEG KUZNECOV	{"email": "o-kuznecov-081968@postgrespro.ru", "phone": "+70661378236"}
0005434823726	AA8A74	8391 569785	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov.1980@postgrespro.ru", "phone": "+70690196138"}
0005434823727	E28603	5272 421900	ALEKSANDR TARASOV	{"phone": "+70835602147"}
0005434823728	0DED84	4392 044924	ELENA KUZMINA	{"email": "elena-kuzmina.1974@postgrespro.ru", "phone": "+70458137779"}
0005434823729	A88C84	3777 268991	EVGENIY CHERNOV	{"email": "e_chernov27011971@postgrespro.ru", "phone": "+70874413718"}
0005434823730	A88C84	0556 129144	ALEKSANDR VOROBEV	{"email": "vorobeva031962@postgrespro.ru", "phone": "+70684191158"}
0005434823731	6DEB55	6441 176842	MARIYA BARANOVA	{"phone": "+70794753920"}
0005434823732	539841	2337 211545	DMITRIY POPOV	{"email": "d.popov-10061977@postgrespro.ru", "phone": "+70235399909"}
0005434823733	5DA70C	3801 803015	VLADIMIR VOLKOV	{"email": "vladimirvolkov-121965@postgrespro.ru", "phone": "+70485035410"}
0005434823734	FEA8A0	2963 032619	SERGEY NIKOLAEV	{"email": "s.nikolaev.1967@postgrespro.ru", "phone": "+70790997115"}
0005434823735	FEA8A0	3581 237447	OLGA PAVLOVA	{"email": "olga.pavlova_03011964@postgrespro.ru", "phone": "+70853456021"}
0005434823736	39C93E	3109 244532	NADEZHDA LEBEDEVA	{"phone": "+70942222662"}
0005434823737	BA1FB2	8920 933868	SERGEY KOZLOV	{"phone": "+70800782578"}
0005434823738	535CDB	5946 896540	NADEZHDA MELNIKOVA	{"phone": "+70841851112"}
0005434823739	C99178	2810 615246	NATALIYA NIKIFOROVA	{"phone": "+70364682155"}
0005434823740	9FC195	1149 943760	DANIIL MATVEEV	{"phone": "+70009950122"}
0005434823741	9FC195	8490 003452	ALEKSANDR BORISOV	{"email": "a.borisov04021984@postgrespro.ru", "phone": "+70407838437"}
0005434823742	0899D7	0559 590744	DANILA SMIRNOV	{"email": "danila_smirnov-061972@postgrespro.ru", "phone": "+70664144673"}
0005434823743	8C984F	9768 280695	BORIS SAVELEV	{"email": "boris_savelev_121972@postgrespro.ru", "phone": "+70435094030"}
0005434823744	8C984F	7320 342101	KONSTANTIN KULIKOV	{"email": "kkulikov_01121967@postgrespro.ru", "phone": "+70288097082"}
0005434823745	85A4CE	6260 359013	VERA POLYAKOVA	{"email": "polyakova_vera_1985@postgrespro.ru", "phone": "+70387320581"}
0005434823746	ECDA20	0525 750453	GENNADIY SIDOROV	{"email": "gennadiy-sidorov.28101962@postgrespro.ru", "phone": "+70731508586"}
0005434823747	30A4AF	3587 404069	BORIS KUZNECOV	{"email": "bkuznecov1963@postgrespro.ru", "phone": "+70235396646"}
0005434823748	68D0A1	6809 940735	ELENA NAZAROVA	{"phone": "+70886335934"}
0005434823749	331959	4766 376593	VALENTINA KONOVALOVA	{"email": "v.konovalova_121976@postgrespro.ru", "phone": "+70748247039"}
0005434823750	B87DDF	1417 944919	SERGEY ZAKHAROV	{"email": "sergeyzakharov_111979@postgrespro.ru", "phone": "+70578056530"}
0005434823751	E63430	9420 923099	TATYANA POLYAKOVA	{"phone": "+70447181318"}
0005434823752	BE6EF6	8798 138502	SVETLANA TROFIMOVA	{"email": "trofimova_svetlana-09121970@postgrespro.ru", "phone": "+70304520747"}
0005434823753	F2FEE4	7383 017496	IVAN EGOROV	{"phone": "+70091432831"}
0005434823754	42454A	8249 113916	ALEKSANDR SIDOROV	{"phone": "+70669298623"}
0005434823755	42454A	5007 502963	ELENA LAZAREVA	{"email": "lazareva_e-1963@postgrespro.ru", "phone": "+70926146494"}
0005434823756	74B446	4772 175661	GALINA NIKOLAEVA	{"email": "nikolaeva-g.11121973@postgrespro.ru", "phone": "+70241530044"}
0005434823757	2AFF97	2751 047198	YULIYA VOLKOVA	{"email": "volkova.y1967@postgrespro.ru", "phone": "+70988815861"}
0005434823758	0B046E	7224 338064	ALEVTINA CHERNOVA	{"email": "chernova_a031971@postgrespro.ru", "phone": "+70863145736"}
0005434823759	E98A13	0890 559723	IGOR GERASIMOV	{"email": "gerasimov_igor.17011969@postgrespro.ru", "phone": "+70283039507"}
0005434823760	E98A13	3229 883360	VALENTIN NAUMOV	{"email": "valentin.naumov1967@postgrespro.ru", "phone": "+70169688860"}
0005434823761	8666C1	8719 348737	ANASTASIYA CHERNOVA	{"phone": "+70256959535"}
0005434823762	718C39	6265 490138	OLESYA ROMANOVA	{"email": "romanova_o_1962@postgrespro.ru", "phone": "+70891752407"}
0005434823763	97D367	3048 395727	NATALYA MASLOVA	{"email": "natalyamaslova_1975@postgrespro.ru", "phone": "+70346941989"}
0005434823764	2633F8	6874 539147	EVGENIYA LAZAREVA	{"email": "lazareva-e.101967@postgrespro.ru", "phone": "+70258167304"}
0005434823765	E8A087	7303 945425	OKSANA ABRAMOVA	{"email": "abramovaoksana.1963@postgrespro.ru", "phone": "+70835447242"}
0005434823766	E8A087	9001 987653	VIKTORIYA FADEEVA	{"email": "viktoriyafadeeva.1967@postgrespro.ru", "phone": "+70304668599"}
0005434823767	E8A087	0786 143364	ANNA KUDRYASHOVA	{"phone": "+70722552426"}
0005434823768	5F14E6	6471 007400	GALINA KRASNOVA	{"phone": "+70927325640"}
0005434823769	F6F36A	7359 358402	AMIR ALEKSEEV	{"phone": "+70069613372"}
0005434823770	11C8AA	3959 317307	VIKTOR SERGEEV	{"email": "viktorsergeev_101973@postgrespro.ru", "phone": "+70011570077"}
0005434823771	A376CE	3061 703634	DMITRIY GORBUNOV	{"email": "dmitriy_gorbunov-13081976@postgrespro.ru", "phone": "+70155517826"}
0005434823772	0BFAA1	6068 561197	ALSU VLASOVA	{"email": "avlasova.1967@postgrespro.ru", "phone": "+70374331190"}
0005434823773	F2B046	4616 411395	SERGEY POPOV	{"email": "sergey_popov_041973@postgrespro.ru", "phone": "+70109773739"}
0005434823774	F2B046	6447 666698	VASILIY IVANOV	{"email": "vasiliy-ivanov_041958@postgrespro.ru", "phone": "+70446235953"}
0005434823775	83B5ED	4519 273130	ZULFIYA VOLKOVA	{"phone": "+70151098203"}
0005434823776	83B5ED	5415 232460	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr061980@postgrespro.ru", "phone": "+70245639360"}
0005434823777	83B5ED	2133 989323	EKATERINA PAVLOVA	{"phone": "+70510648185"}
0005434823778	83F881	8866 640131	YULIYA IVANOVA	{"phone": "+70500534590"}
0005434823779	03B73D	8529 558435	PAVEL KUZMIN	{"email": "kuzmin.pavel.1985@postgrespro.ru", "phone": "+70207286222"}
0005434823780	F33C02	9378 645996	ANTONINA ANTONOVA	{"email": "antonova-antonina01071970@postgrespro.ru", "phone": "+70234260061"}
0005434823781	F33C02	4397 824608	NIKOLAY PETROV	{"phone": "+70265247075"}
0005434823782	4FCA4B	4414 653423	NATALYA MOISEEVA	{"phone": "+70222851756"}
0005434823783	1E1A26	4419 198032	OKSANA ORLOVA	{"email": "oksana-orlova13041979@postgrespro.ru", "phone": "+70940375979"}
0005434823784	1E1A26	2420 788265	SVETLANA FILIPPOVA	{"phone": "+70577064793"}
0005434823785	D72157	5596 334086	VLADIMIR KULIKOV	{"email": "vkulikov1979@postgrespro.ru", "phone": "+70038903308"}
0005434823786	3D4A17	6925 775376	VLADIMIR SOROKIN	{"phone": "+70315685524"}
0005434823787	2ABB2B	3711 495311	ANATOLIY SHEVCHENKO	{"email": "shevchenkoanatoliy-021979@postgrespro.ru", "phone": "+70909181310"}
0005434823788	E4FB2D	7546 415647	IVAN BELOV	{"email": "i_belov011972@postgrespro.ru", "phone": "+70531871617"}
0005434823789	EA70D1	4140 375766	VLADIMIR SOKOLOV	{"email": "v.sokolov.1968@postgrespro.ru", "phone": "+70006585067"}
0005434823790	4C13E6	1394 586315	GALINA FROLOVA	{"phone": "+70643686100"}
0005434823791	EF9AAD	6220 189144	VALERIY MAKAROV	{"email": "valeriy_makarov_051965@postgrespro.ru", "phone": "+70692474673"}
0005434823792	F96090	8633 819734	RAILYA STEPANOVA	{"email": "stepanova.r1981@postgrespro.ru", "phone": "+70361610297"}
0005434823793	145096	2325 640844	LYUBOV IVANOVA	{"email": "ivanova-lyubov_04111960@postgrespro.ru", "phone": "+70010570809"}
0005434823794	145096	9693 009646	OLGA SEMENOVA	{"email": "semenova_o1988@postgrespro.ru", "phone": "+70142228094"}
0005434823795	7528AF	3673 330767	ELENA FROLOVA	{"phone": "+70081419677"}
0005434823796	7528AF	5772 351963	NIKOLAY VOLKOV	{"phone": "+70541200742"}
0005434823797	4296E7	9536 196342	OLGA ARKHIPOVA	{"phone": "+70873509878"}
0005434823798	8BD706	1720 712876	NIKOLAY TIMOFEEV	{"email": "n_timofeev-1975@postgrespro.ru", "phone": "+70347291978"}
0005434823799	127D2F	1814 526542	VALENTINA MATVEEVA	{"email": "matveeva.valentina.061980@postgrespro.ru", "phone": "+70178204535"}
0005434823800	BBEEC7	4992 117133	VALENTINA BORISOVA	{"email": "borisovav-111964@postgrespro.ru", "phone": "+70118250778"}
0005434823801	BBEEC7	4297 026522	KLAVDIYA RYABOVA	{"phone": "+70589011838"}
0005434823802	E92B01	6018 918548	NINA DAVYDOVA	{"email": "nina.davydova18111977@postgrespro.ru", "phone": "+70091572589"}
0005434823803	BB310D	4441 506546	MAKSIM ROMANOV	{"phone": "+70446707440"}
0005434823804	20B033	2052 319848	ALEKSANDR BONDARENKO	{"phone": "+70998540303"}
0005434823805	6E6197	3156 818126	VERA ABRAMOVA	{"email": "vabramova.051971@postgrespro.ru", "phone": "+70120122480"}
0005434823806	6E6197	9244 162020	EVGENIY ZAKHAROV	{"phone": "+70460200779"}
0005434823807	61FF1C	2361 218546	OLESYA KUZNECOVA	{"email": "okuznecova.041977@postgrespro.ru", "phone": "+70885786532"}
0005434823808	61FF1C	8525 884993	KONSTANTIN ILIN	{"email": "ilink_031969@postgrespro.ru", "phone": "+70058110352"}
0005434823809	6DA54E	3079 285881	RIMMA FROLOVA	{"email": "r_frolova_1973@postgrespro.ru", "phone": "+70049495760"}
0005434823810	6DA54E	2300 914852	SERGEY TIKHONOV	{"phone": "+70647071312"}
0005434823811	E47E53	0033 746121	ELENA KUZNECOVA	{"phone": "+70010020921"}
0005434823812	FFA653	3801 281289	OLGA EGOROVA	{"phone": "+70591490685"}
0005434823813	245EB4	6667 816527	FILIPP NIKOLAEV	{"email": "filippnikolaev1968@postgrespro.ru", "phone": "+70232448310"}
0005434823814	245EB4	4432 858678	RADIK SERGEEV	{"phone": "+70030969320"}
0005434823815	31E83C	9231 838669	VASILIY POPOV	{"phone": "+70087970032"}
0005434823816	31E83C	8136 442649	MARAT FROLOV	{"email": "marat.frolov-011965@postgrespro.ru", "phone": "+70482968532"}
0005434823817	31E83C	1601 718279	YURIY KARPOV	{"email": "karpov.y_101982@postgrespro.ru", "phone": "+70923981898"}
0005434823818	2B1572	4346 308264	ALEKSANDR TARASOV	{"email": "tarasovaleksandr.23031972@postgrespro.ru", "phone": "+70952390746"}
0005434823819	2B1572	4081 160810	LILIYA ROMANOVA	{"email": "l_romanova14061968@postgrespro.ru", "phone": "+70832804249"}
0005434823820	EE72E5	6336 987683	LIDIYA GUSEVA	{"phone": "+70552709145"}
0005434823821	EE72E5	9239 672497	KLAVDIYA TIMOFEEVA	{"phone": "+70231751495"}
0005434823822	9E7613	3229 638621	SVYATOSLAV SMIRNOV	{"phone": "+70851822311"}
0005434823823	9E7613	6212 619272	VLADIMIR FROLOV	{"email": "frolov.v12111977@postgrespro.ru", "phone": "+70044032339"}
0005434823824	6602B8	3771 987444	ROMAN KAZAKOV	{"phone": "+70317571982"}
0005434823825	811FA8	3057 469664	EKATERINA KARPOVA	{"email": "e.karpova_1972@postgrespro.ru", "phone": "+70708792788"}
0005434823826	C9B6D6	7812 960982	LYUBOV NIKIFOROVA	{"phone": "+70152312804"}
0005434823827	AC5076	5734 033032	ANNA ALEKSANDROVA	{"email": "anna.aleksandrova.021974@postgrespro.ru", "phone": "+70780729587"}
0005434823828	AC5076	8267 869999	PETR NIKITIN	{"email": "nikitinp-05121969@postgrespro.ru", "phone": "+70847920472"}
0005434823829	555B6B	7662 947998	ANNA MOROZOVA	{"email": "a_morozova.1978@postgrespro.ru", "phone": "+70371014842"}
0005434823830	64A81E	1279 596774	NIKOLAY KONOVALOV	{"email": "nikolay_konovalov19111968@postgrespro.ru", "phone": "+70454792866"}
0005434823831	5659D3	0397 197463	GEORGIY KUZNECOV	{"email": "kuznecov-g-20101970@postgrespro.ru", "phone": "+70434467274"}
0005434823832	396176	1245 202007	ALEKSANDR STEPANOV	{"phone": "+70074357720"}
0005434823833	115EA0	9138 442685	YURIY SOROKIN	{"email": "sorokin.y.02111968@postgrespro.ru", "phone": "+70742424870"}
0005434823834	65687B	7692 985062	ALEKSANDR KOZLOV	{"phone": "+70162681799"}
0005434823835	65687B	6193 710903	EVGENIY KONOVALOV	{"phone": "+70710095278"}
0005434823836	53DC64	7722 799972	LEV POPOV	{"email": "popovl-091974@postgrespro.ru", "phone": "+70038889415"}
0005434823837	D8F95C	8252 112074	NATALIYA ANDREEVA	{"email": "nandreeva031972@postgrespro.ru", "phone": "+70435729434"}
0005434823838	E5E480	1465 535262	ALEKSANDR TIKHONOV	{"phone": "+70756621356"}
0005434823839	9E7CFF	6958 664861	RUMIYA BELOVA	{"email": "belova_rumiya_11041977@postgrespro.ru", "phone": "+70892125059"}
0005434823840	7C898B	4093 976283	VALERIYA AKIMOVA	{"email": "valeriya.akimova-1980@postgrespro.ru", "phone": "+70111087065"}
0005434823841	807EF9	8479 890984	TATYANA NESTEROVA	{"email": "t.nesterova1975@postgrespro.ru", "phone": "+70246471941"}
0005434823842	9DA59D	2838 453045	ELENA MATVEEVA	{"email": "matveeva.e_14041965@postgrespro.ru", "phone": "+70453059185"}
0005434823843	CF7047	9334 792506	VERA SOROKINA	{"phone": "+70142089169"}
0005434823844	9EF99A	8212 507048	NAILYA KISELEVA	{"email": "kiseleva_nailya041977@postgrespro.ru", "phone": "+70203521839"}
0005434823845	9EF99A	9803 768191	DMITRIY GRIGOREV	{"email": "d_grigorev-21091982@postgrespro.ru", "phone": "+70512710701"}
0005434823847	6EA796	2455 899950	ALBERT ROMANOV	{"email": "albert.romanov-28041988@postgrespro.ru", "phone": "+70399713792"}
0005434823848	3C9321	9006 528416	VIKTORIYA DENISOVA	{"email": "viktoriya_denisova.14021969@postgrespro.ru", "phone": "+70804832738"}
0005434823849	3C9321	4579 549282	RAUF SOKOLOV	{"phone": "+70303957018"}
0005434823850	E38DC1	5207 987167	ALEKSANDR CHERNOV	{"email": "a-chernov.1972@postgrespro.ru", "phone": "+70893542006"}
0005434823851	9BDB91	7695 202779	ALEKSANDR ILIN	{"email": "ilin.a091968@postgrespro.ru", "phone": "+70471012876"}
0005434823852	9BDB91	0453 090414	EKATERINA ROMANOVA	{"phone": "+70563960870"}
0005434823853	E778C3	3868 428064	IRINA POLYAKOVA	{"email": "polyakova.irina29071978@postgrespro.ru", "phone": "+70487550307"}
0005434823854	1F0C71	2187 752854	IVAN NAZAROV	{"phone": "+70662132068"}
0005434823855	1F0C71	5676 668827	TATYANA KAZAKOVA	{"phone": "+70495594947"}
0005434823856	1F0C71	4901 490874	GEORGIY MIKHAYLOV	{"phone": "+70677844360"}
0005434823857	1F0C71	0415 669179	VIKTORIYA EGOROVA	{"email": "v_egorova-05041976@postgrespro.ru", "phone": "+70458805607"}
0005434823858	74F9AA	1963 260725	TATYANA NIKIFOROVA	{"email": "nikiforova-tatyana_061976@postgrespro.ru", "phone": "+70296238949"}
0005434823859	C5DA7C	9614 706731	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-v081978@postgrespro.ru", "phone": "+70661974773"}
0005434823860	C5DA7C	4802 943768	GEORGIY MAKAROV	{"email": "gmakarov111974@postgrespro.ru", "phone": "+70743737198"}
0005434823861	B6D5E4	3521 910285	SERGEY MEDVEDEV	{"email": "medvedev.s.30051967@postgrespro.ru", "phone": "+70944993721"}
0005434823862	B6D5E4	0922 312385	ALEKSEY VOLKOV	{"phone": "+70834668618"}
0005434823863	8EDE3D	5590 002805	VERA TIMOFEEVA	{"email": "veratimofeeva031967@postgrespro.ru", "phone": "+70132944932"}
0005434823864	0737FD	5936 398719	EKATERINA KUZNECOVA	{"phone": "+70425169643"}
0005434823865	0737FD	0338 250486	ANATOLIY ALEKSEEV	{"phone": "+70111312425"}
0005434823866	8DE2AA	3397 479629	VLADIMIR TARASOV	{"phone": "+70854580051"}
0005434823867	93F4C9	3368 350895	ANDREY PAVLOV	{"email": "andrey.pavlov.121958@postgrespro.ru", "phone": "+70759918082"}
0005434823868	DCAE84	0263 350192	RAISA MIKHAYLOVA	{"phone": "+70623838124"}
0005434823869	DCAE84	9951 918173	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir061972@postgrespro.ru", "phone": "+70109559369"}
0005434823870	D6B78C	3926 955898	EVGENIY KUDRYASHOV	{"phone": "+70756929597"}
0005434823871	D6B78C	2287 816555	ANATOLIY MELNIKOV	{"email": "a_melnikov.051981@postgrespro.ru", "phone": "+70139895930"}
0005434823872	518FF9	5210 992610	EGOR GAVRILOV	{"email": "e_gavrilov_04031973@postgrespro.ru", "phone": "+70937050069"}
0005434823873	DFBC56	7243 815907	ANATOLIY TIMOFEEV	{"email": "timofeev.a.06101980@postgrespro.ru", "phone": "+70580286777"}
0005434823874	54910B	1091 257378	ALEKSEY STEPANOV	{"email": "a.stepanov_101973@postgrespro.ru", "phone": "+70486559741"}
0005434823875	EFCB9A	0403 397281	MARINA BELYAEVA	{"phone": "+70087829454"}
0005434823876	62A218	5816 640257	DMITRIY KUZNECOV	{"phone": "+70798260176"}
0005434823877	2B46D7	2289 367056	MARINA VOROBEVA	{"email": "vorobeva-m.1980@postgrespro.ru", "phone": "+70781378526"}
0005434823878	0EFA52	4542 393839	LARISA SOLOVEVA	{"phone": "+70738815514"}
0005434823879	771C04	9529 094166	TATYANA EGOROVA	{"email": "t.egorova-101973@postgrespro.ru", "phone": "+70881917001"}
0005434823880	724799	6394 651395	MARIYA SEMENOVA	{"phone": "+70547752322"}
0005434823881	30708A	6872 802261	ANATOLIY VOLKOV	{"email": "anatoliy.volkov_18041973@postgrespro.ru", "phone": "+70977076774"}
0005434823882	86FE4D	1363 492616	VLADIMIR NOVIKOV	{"phone": "+70690314916"}
0005434823883	86FE4D	3432 406110	ELENA KOMAROVA	{"email": "elena_komarova1970@postgrespro.ru", "phone": "+70628052738"}
0005434823884	9370F1	5334 649353	DINARA FROLOVA	{"email": "dinara_frolova23061958@postgrespro.ru", "phone": "+70096798867"}
0005434823885	A31F62	4017 610215	RAFAIL IVANOV	{"email": "ivanovr1968@postgrespro.ru", "phone": "+70423532433"}
0005434823886	C101E3	6066 423954	OLGA POPOVA	{"email": "popova.o.021972@postgrespro.ru", "phone": "+70899235746"}
0005434823887	059B1E	2112 904533	NIKOLAY MAKAROV	{"email": "makarov_n.1981@postgrespro.ru", "phone": "+70500913843"}
0005434823888	56CF4A	3354 082298	VALERIY ANTONOV	{"phone": "+70472556201"}
0005434823889	DE128C	7603 308357	VASILIY POPOV	{"email": "vasiliypopov.031977@postgrespro.ru", "phone": "+70803231263"}
0005434823890	261E6C	0747 820368	OLGA SOKOLOVA	{"email": "olga.sokolova081973@postgrespro.ru", "phone": "+70562468515"}
0005434823891	4DD0A2	5117 089117	GRIGORIY PETROV	{"email": "g.petrov17041965@postgrespro.ru", "phone": "+70270751750"}
0005434823892	D65F99	1286 930458	POLINA MAKAROVA	{"phone": "+70857089268"}
0005434823893	B60A87	4412 167261	RAISA MATVEEVA	{"phone": "+70199595590"}
0005434823894	B6EAA1	3391 224411	OLGA BELOVA	{"phone": "+70271877930"}
0005434823895	573381	0220 042965	NATALYA MATVEEVA	{"email": "matveevan19041986@postgrespro.ru", "phone": "+70916575760"}
0005434823896	2D8DE9	3907 071429	IVAN KUZNECOV	{"phone": "+70957598069"}
0005434823897	89D3F7	7412 812374	VASILIY ROMANOV	{"email": "romanovvasiliy1972@postgrespro.ru", "phone": "+70778096184"}
0005434823898	69148C	9865 394426	EVGENIY KISELEV	{"phone": "+70475165655"}
0005434823899	69148C	5120 341784	LIDIYA RODIONOVA	{"phone": "+70761017305"}
0005434823900	69148C	2137 190310	ALEKSANDR VLASOV	{"phone": "+70422022563"}
0005434823901	0106D9	9683 937738	MARGARITA NIKIFOROVA	{"phone": "+70580503808"}
0005434823902	0106D9	4705 042867	ANNA KOVALEVA	{"email": "kovaleva.a_1957@postgrespro.ru", "phone": "+70160508247"}
0005434823903	851114	7961 254764	LYUDMILA SMIRNOVA	{"email": "lsmirnova.1968@postgrespro.ru", "phone": "+70061593630"}
0005434823904	BD63EF	6815 738772	KLAVDIYA FEDOROVA	{"phone": "+70262913009"}
0005434823905	74F7F0	8881 575960	LYUBOV IVANOVA	{"email": "lyubovivanova051965@postgrespro.ru", "phone": "+70228674638"}
0005434823906	2509E1	1558 654182	ROMAN SCHERBAKOV	{"email": "scherbakov_roman.01041968@postgrespro.ru", "phone": "+70512508437"}
0005434823907	DFF606	7491 825053	FEDOR PETROV	{"email": "petrovf-101972@postgrespro.ru", "phone": "+70933054591"}
0005434823908	DFF606	0714 373219	POLINA NIKOLAEVA	{"phone": "+70216607554"}
0005434823909	7A2294	1500 852002	LILIYA NOVIKOVA	{"email": "novikovaliliya.081981@postgrespro.ru", "phone": "+70891305890"}
0005434823910	FA86F8	4709 203445	ALEKSANDR ILIN	{"phone": "+70381169520"}
0005434823911	28DD1A	8514 495246	MIKHAIL ANDREEV	{"email": "andreev_mikhail.021972@postgrespro.ru", "phone": "+70866839185"}
0005434823971	D67AF0	9278 958108	ELIZAVETA VOLKOVA	{"phone": "+70039966705"}
0005434823912	E0922D	0113 165407	OLGA AKIMOVA	{"email": "akimovao-07041977@postgrespro.ru", "phone": "+70429107329"}
0005434823913	E0922D	0693 605232	MILANA VOROBEVA	{"email": "milanavorobeva_1964@postgrespro.ru", "phone": "+70759004032"}
0005434823914	258FC2	0574 589255	ELIZAVETA NAUMOVA	{"email": "elizaveta.naumova_22011975@postgrespro.ru", "phone": "+70575985102"}
0005434823915	258FC2	4493 577846	VARVARA ZAKHAROVA	{"email": "varvara-zakharova_121973@postgrespro.ru", "phone": "+70181262375"}
0005434823916	5030B9	3093 386770	VALENTIN DAVYDOV	{"phone": "+70468749894"}
0005434823917	DCAA87	8478 185547	EKATERINA KOZLOVA	{"email": "ekaterina_kozlova-25091986@postgrespro.ru", "phone": "+70347629555"}
0005434823918	8EF65C	1021 487380	VLADIMIR IVANOV	{"phone": "+70106515915"}
0005434823919	447648	7566 273318	GALINA KAZAKOVA	{"email": "kazakova.g11121966@postgrespro.ru", "phone": "+70514099788"}
0005434823920	318FDD	4994 165434	MAKSIM TARASOV	{"phone": "+70513527993"}
0005434823921	318FDD	3969 011538	NATALYA VOLKOVA	{"email": "natalya_volkova111967@postgrespro.ru", "phone": "+70598127321"}
0005434823922	3BD286	8804 270441	LYUDMILA MEDVEDEVA	{"email": "medvedeval_1977@postgrespro.ru", "phone": "+70534395997"}
0005434823923	242DAD	3525 402891	GULNARA DENISOVA	{"phone": "+70006374262"}
0005434823924	242DAD	5712 414874	ALEKSANDRA ISAEVA	{"email": "a.isaeva1974@postgrespro.ru", "phone": "+70120869530"}
0005434823925	ED2080	5280 183508	IRAIDA VOLKOVA	{"phone": "+70956474590"}
0005434823926	506C57	8021 392089	ANASTASIYA SOROKINA	{"email": "asorokina.051970@postgrespro.ru", "phone": "+70970961134"}
0005434823927	506C57	2340 112748	ROMAN GRIGOREV	{"email": "grigorev_roman-1971@postgrespro.ru", "phone": "+70100655974"}
0005434823928	9E463A	1330 486587	DINA MOROZOVA	{"email": "d.morozova.041976@postgrespro.ru", "phone": "+70118356667"}
0005434823929	E9A872	6922 391098	VERA ZAYCEVA	{"phone": "+70285259444"}
0005434823930	8452CC	3485 689871	ZARINA ZAYCEVA	{"email": "zayceva-zarina.1971@postgrespro.ru", "phone": "+70664533987"}
0005434823931	8452CC	9348 498266	NATALYA DMITRIEVA	{"email": "dmitrieva.natalya.05121963@postgrespro.ru", "phone": "+70278554044"}
0005434823932	59D2F0	4325 250180	ALEKSANDRA IVANOVA	{"phone": "+70909383360"}
0005434823933	59D2F0	4377 967936	OKSANA MELNIKOVA	{"phone": "+70734770143"}
0005434823934	5A0362	5283 948252	OLGA MOROZOVA	{"phone": "+70273491356"}
0005434823935	D3CE11	3623 934248	YAN YAKOVLEV	{"email": "yakovlev.yan_1979@postgrespro.ru", "phone": "+70509254178"}
0005434823936	6C8247	2504 113981	OLGA KAZAKOVA	{"email": "kazakova-olga-1962@postgrespro.ru", "phone": "+70379729169"}
0005434823937	6CA79E	1137 471973	NATALYA NESTEROVA	{"phone": "+70291358637"}
0005434823938	6CA79E	4809 996276	SVETLANA FEDOROVA	{"phone": "+70588382124"}
0005434823939	48078E	0015 312662	SVETLANA ZAKHAROVA	{"email": "zakharovasvetlana-041964@postgrespro.ru", "phone": "+70968980894"}
0005434823940	48F67D	3869 119809	EKATERINA DENISOVA	{"email": "denisova-e.1966@postgrespro.ru", "phone": "+70630851446"}
0005434823941	6C3A10	8812 442325	ELIZAVETA LAZAREVA	{"email": "lazarevaelizaveta_15081974@postgrespro.ru", "phone": "+70428552718"}
0005434823942	6C3A10	3420 655161	DMITRIY KONOVALOV	{"phone": "+70262680701"}
0005434823943	F9FED9	0556 410842	VLADIMIR ISAEV	{"email": "isaev-vladimir_16111968@postgrespro.ru", "phone": "+70239261393"}
0005434823944	4399B9	0613 475816	MAKSIM KRASNOV	{"email": "m-krasnov-12041978@postgrespro.ru", "phone": "+70759841312"}
0005434823945	4399B9	7617 876944	VITALIY ZAKHAROV	{"email": "zakharov-v-1967@postgrespro.ru", "phone": "+70824680907"}
0005434823946	9CDBB4	0912 448051	ANDREY FEDOROV	{"phone": "+70836306301"}
0005434823947	3EF3EE	7063 297833	ALEKSEY PETROV	{"phone": "+70825289147"}
0005434823948	4977AE	8732 468514	SVETLANA MAKAROVA	{"phone": "+70979781481"}
0005434823949	4977AE	6017 387373	MAKSIM MEDVEDEV	{"email": "m_medvedev-101970@postgrespro.ru", "phone": "+70434390285"}
0005434823950	074C32	8344 664167	YANA SERGEEVA	{"email": "y.sergeeva_011967@postgrespro.ru", "phone": "+70506834000"}
0005434823951	01B06B	1145 183080	ANASTASIYA NIKITINA	{"phone": "+70588597502"}
0005434823952	283100	0043 152894	ELENA MIKHAYLOVA	{"email": "elena-mikhaylova-1964@postgrespro.ru", "phone": "+70932915753"}
0005434823953	2F8A17	8818 817504	SERGEY PAVLOV	{"email": "sergey.pavlov_1969@postgrespro.ru", "phone": "+70145027462"}
0005434823954	59F49C	1887 308635	ELENA ROMANOVA	{"phone": "+70989771726"}
0005434823955	59F49C	8532 638535	ANTONINA SAVELEVA	{"phone": "+70753634999"}
0005434823956	59F49C	6118 768006	NADEZHDA ZAYCEVA	{"phone": "+70606528641"}
0005434823957	C0F6F8	3780 491561	MARINA MALYSHEVA	{"email": "malysheva_marina_1975@postgrespro.ru", "phone": "+70045231260"}
0005434823958	5A12F5	9987 931943	SVETLANA KOZLOVA	{"phone": "+70568097105"}
0005434823959	5A12F5	3888 125110	ILYA MAKSIMOV	{"phone": "+70058386401"}
0005434823960	02C53A	4467 778809	SERGEY BORISOV	{"phone": "+70624895665"}
0005434823961	89C6B7	8007 143596	ELIZAVETA IVANOVA	{"email": "e.ivanova27071972@postgrespro.ru", "phone": "+70147371607"}
0005434823962	89C6B7	6768 399616	GALINA MARTYNOVA	{"phone": "+70952593306"}
0005434823963	89C6B7	8091 971147	IGOR BORISOV	{"phone": "+70301243009"}
0005434823964	89C6B7	5704 237482	NINA NIKITINA	{"phone": "+70112255922"}
0005434823965	E35577	9558 274473	ROZA KOZLOVA	{"email": "kozlova.roza29061954@postgrespro.ru", "phone": "+70880921454"}
0005434823966	B9DD69	9508 963851	GULNARA MIRONOVA	{"email": "gulnara-mironova.021968@postgrespro.ru", "phone": "+70281515410"}
0005434823967	704260	2792 306061	VIKTOR FOMIN	{"email": "viktorfomin_081978@postgrespro.ru", "phone": "+70353992546"}
0005434823968	229AE7	5177 315473	VLADIMIR MIRONOV	{"phone": "+70360532530"}
0005434823969	8C5286	8279 150616	TALGAT KULIKOV	{"email": "kulikov-talgat_1969@postgrespro.ru", "phone": "+70965717432"}
0005434823970	E7E9E6	1760 888746	ELENA NIKOLAEVA	{"email": "nikolaeva-e061981@postgrespro.ru", "phone": "+70832772094"}
0005434823972	650018	1321 607173	EKATERINA LAZAREVA	{"phone": "+70530777893"}
0005434823973	0DA2D3	5946 694516	SOFIYA ALEKSEEVA	{"phone": "+70236365347"}
0005434823974	0DA2D3	1532 882216	ROMAN SAVELEV	{"phone": "+70651134852"}
0005434823975	DD3A34	1528 029441	EVGENIY ALEKSEEV	{"phone": "+70046682191"}
0005434823976	DC764E	9928 937181	ALEKSANDR KAZAKOV	{"phone": "+70341641801"}
0005434823977	3835A5	6446 366011	POLINA BELOVA	{"email": "polina.belova.05021974@postgrespro.ru", "phone": "+70218059312"}
0005434823978	D662E3	4443 252826	ANATOLIY MEDVEDEV	{"email": "medvedev-a121972@postgrespro.ru", "phone": "+70529890920"}
0005434823979	D8F86D	5353 921075	ANASTASIYA BOGDANOVA	{"email": "anastasiyabogdanova-1967@postgrespro.ru", "phone": "+70230539781"}
0005434823980	D8F86D	1659 155620	ANNA PETROVA	{"phone": "+70239615209"}
0005434823981	2CED85	1312 262269	VYACHESLAV MATVEEV	{"email": "v-matveev051976@postgrespro.ru", "phone": "+70831721253"}
0005434823982	AAA93D	9503 139895	ROZA MELNIKOVA	{"phone": "+70884222385"}
0005434823983	AAA93D	0848 945627	NIKOLAY EGOROV	{"email": "n-egorov.041968@postgrespro.ru", "phone": "+70772189891"}
0005434823984	CA3EB0	1498 755444	VERA ALEKSANDROVA	{"email": "v_aleksandrova_111977@postgrespro.ru", "phone": "+70338483269"}
0005434823985	CA3EB0	9209 532194	EKATERINA IVANOVA	{"phone": "+70475674784"}
0005434823986	D290EA	8780 148903	KIRILL MIKHAYLOV	{"phone": "+70884160050"}
0005434823987	63D5E3	2576 795293	EVGENIY MIKHAYLOV	{"phone": "+70191872609"}
0005434823988	63D5E3	0643 753511	NADEZHDA BELOVA	{"phone": "+70923582220"}
0005434823989	DB3590	9692 197550	ANDREY NOVIKOV	{"email": "andrey-novikov-16111976@postgrespro.ru", "phone": "+70314620062"}
0005434823990	D8F738	2721 876783	VLADIMIR AFANASEV	{"email": "vladimir-afanasev_08071975@postgrespro.ru", "phone": "+70512177479"}
0005434823991	7F54B0	5413 337908	VIKTOR FEDOROV	{"email": "v_fedorov.10081971@postgrespro.ru", "phone": "+70422168173"}
0005434823992	2ED96B	8245 477787	MAKSIM MARTYNOV	{"email": "martynovmaksim.12101969@postgrespro.ru", "phone": "+70461571188"}
0005434823993	6D9E99	6037 526072	TATYANA VOROBEVA	{"email": "vorobevatatyana-1975@postgrespro.ru", "phone": "+70984086545"}
0005434823994	218EE3	9260 522672	VERA ILINA	{"phone": "+70491282913"}
0005434823995	D98EAB	4737 147344	ALEKSEY SOKOLOV	{"email": "aleksey.sokolov_11071981@postgrespro.ru", "phone": "+70760877921"}
0005434823996	5A5A5C	8470 817663	SVETLANA DENISOVA	{"email": "svetlana_denisova-1971@postgrespro.ru", "phone": "+70360279403"}
0005434823997	4C2A3B	2668 397526	OLGA POLYAKOVA	{"phone": "+70323448223"}
0005434823998	4C2A3B	8227 230359	VALERIY NAZAROV	{"email": "nazarovvaleriy.16041980@postgrespro.ru", "phone": "+70209125892"}
0005434823999	C1D1C1	4631 396280	MARIYA KUDRYASHOVA	{"email": "m-kudryashova-30061979@postgrespro.ru", "phone": "+70057011331"}
0005434824000	9F57A4	4637 501072	DENIS ZAKHAROV	{"phone": "+70740094123"}
0005434824001	4AB67B	5354 249512	VLADIMIR CHERNOV	{"phone": "+70548867326"}
0005434824002	4AB67B	0025 035053	LYUDMILA BARANOVA	{"phone": "+70060348110"}
0005434824003	BE6045	6314 869520	SERGEY FEDOROV	{"email": "fedorov-sergey031967@postgrespro.ru", "phone": "+70405772296"}
0005434824004	64FEE3	3580 913022	ANASTASIYA LUKYANOVA	{"email": "lukyanova.a_26031978@postgrespro.ru", "phone": "+70703331593"}
0005434824005	872452	2883 640979	TAISIYA KUZMINA	{"phone": "+70004935248"}
0005434824006	E11697	2503 899101	VALENTINA KOROLEVA	{"email": "v_koroleva.081970@postgrespro.ru", "phone": "+70546146070"}
0005434824007	1E5A76	7545 897668	NATALIYA VASILEVA	{"email": "n_vasileva_1982@postgrespro.ru", "phone": "+70516659328"}
0005434824008	1E5A76	4840 174770	ALEKSEY MAKAROV	{"email": "a-makarov-09041964@postgrespro.ru", "phone": "+70922369764"}
0005434824009	33451F	9135 254369	VLADIMIR GAVRILOV	{"email": "vladimir.gavrilov-081965@postgrespro.ru", "phone": "+70492574765"}
0005434824010	DC5542	8403 325964	TATYANA ISAEVA	{"email": "t-isaeva_081968@postgrespro.ru", "phone": "+70584487410"}
0005434824011	7DD220	2542 800680	EVGENIY ALEKSEEV	{"phone": "+70732131852"}
0005434824012	7DD220	6866 319419	IGOR MIKHAYLOV	{"email": "imikhaylov_08061976@postgrespro.ru", "phone": "+70867881237"}
0005434824013	2ACE6F	4592 260094	SALAVAT VOLKOV	{"phone": "+70045505277"}
0005434824014	C6D0D6	9070 645022	NIKOLAY SOLOVEV	{"phone": "+70852578533"}
0005434824015	C6D0D6	1796 919221	ALEKSEY MIRONOV	{"phone": "+70056640117"}
0005434824016	DADA8E	7271 772253	IRAIDA DMITRIEVA	{"phone": "+70964974772"}
0005434824017	42F473	8074 630836	ALENA KOLESNIKOVA	{"email": "kolesnikova.a101967@postgrespro.ru", "phone": "+70680614958"}
0005434824018	C2ACA4	1466 725611	ALEKSANDR ANDREEV	{"email": "aleksandr-andreev_04051961@postgrespro.ru", "phone": "+70302867191"}
0005434824019	7F47E5	6715 740850	ILNAR NIKITIN	{"email": "ilnar_nikitin.01031971@postgrespro.ru", "phone": "+70936946558"}
0005434824020	FD7B8A	4272 367263	ANFISA LUKYANOVA	{"phone": "+70223230752"}
0005434824021	FD7B8A	9113 857476	NATALYA IVANOVA	{"phone": "+70163875238"}
0005434824022	FD7B8A	1513 571290	MARIYA YUDINA	{"email": "yudina.mariya-05021975@postgrespro.ru", "phone": "+70402689375"}
0005434824023	D1CCA6	4863 620422	OLEG GUSEV	{"email": "oleg_gusev22081955@postgrespro.ru", "phone": "+70466535993"}
0005434824024	D1CCA6	8789 020168	ALEKSANDR NIKITIN	{"phone": "+70862964084"}
0005434824025	D1CCA6	2122 609782	DMITRIY SMIRNOV	{"phone": "+70719761900"}
0005434824026	D1CCA6	4793 211145	ALEKSANDR KUZMIN	{"phone": "+70394421211"}
0005434824027	653C6D	2815 334353	ALEKSANDR IVANOV	{"email": "a.ivanov061973@postgrespro.ru", "phone": "+70458125722"}
0005434824028	FDDE3B	8171 308219	OLGA KONOVALOVA	{"phone": "+70822399402"}
0005434824029	444895	1846 806507	YURIY DAVYDOV	{"email": "yuriy-davydov_22041971@postgrespro.ru", "phone": "+70529357109"}
0005434824030	3D9D71	1502 398855	VIOLETTA AFANASEVA	{"email": "v-afanaseva-14091961@postgrespro.ru", "phone": "+70154074195"}
0005434824031	3D9D71	4609 677062	VASILIY NAZAROV	{"email": "nazarov-vasiliy.071981@postgrespro.ru", "phone": "+70725455485"}
0005434824032	DB00F7	3013 153550	VALERIY PETROV	{"email": "petrov-valeriy.19091976@postgrespro.ru", "phone": "+70005360498"}
0005434824033	7D2B8D	5462 662175	LEONID KUDRYASHOV	{"phone": "+70208108753"}
0005434824034	9F0DFA	2471 024428	ALEKSANDR TARASOV	{"phone": "+70340434661"}
0005434824035	EB15DB	7932 676403	MIKHAIL MATVEEV	{"email": "mikhailmatveev.1965@postgrespro.ru", "phone": "+70899684672"}
0005434824036	EB15DB	0724 088856	DMITRIY POPOV	{"email": "popov-d-08051976@postgrespro.ru", "phone": "+70239642011"}
0005434824037	160F12	2573 458118	LYUBOV VLASOVA	{"email": "vlasoval_10031976@postgrespro.ru", "phone": "+70662543712"}
0005434824038	4652A2	3605 037008	NINA GUSEVA	{"email": "guseva.nina_1978@postgrespro.ru", "phone": "+70967134139"}
0005434824039	4652A2	3115 592814	ELIZAVETA MASLOVA	{"phone": "+70338379542"}
0005434824040	1E18EC	6646 897727	GUZEL MAKAROVA	{"email": "makarovaguzel.13081970@postgrespro.ru", "phone": "+70847466600"}
0005434824041	1E18EC	9767 670686	ALEKSEY STEPANOV	{"email": "aleksey-stepanov09091966@postgrespro.ru", "phone": "+70837637879"}
0005434824042	8C5C0E	9794 539245	GALINA SOLOVEVA	{"email": "galina-soloveva.1991@postgrespro.ru", "phone": "+70815188728"}
0005434824043	04CAE4	4690 092387	YANA ROMANOVA	{"email": "romanova_yana.03061974@postgrespro.ru", "phone": "+70074148887"}
0005434824044	04CAE4	2178 760918	ANASTASIYA NIKITINA	{"phone": "+70843769030"}
0005434824045	B9B31F	5437 489907	RENAT ANTONOV	{"email": "antonov_r-121967@postgrespro.ru", "phone": "+70370494738"}
0005434824046	B9B31F	1785 651613	ANTON KULIKOV	{"email": "kulikov-anton-1974@postgrespro.ru", "phone": "+70323177264"}
0005434824047	E8B5E6	9214 490590	MAKSIM MAKAROV	{"email": "maksimmakarov-041976@postgrespro.ru", "phone": "+70947313724"}
0005434824048	B05854	0400 144452	MARIYA VOROBEVA	{"phone": "+70427769558"}
0005434824049	BB78BC	0089 425603	VLADIMIR BORISOV	{"phone": "+70553285398"}
0005434824050	3A7F57	0450 933694	ALEKSANDR ANTONOV	{"phone": "+70497520920"}
0005434824051	3A7F57	6784 226440	NIKOLAY ALEKSEEV	{"email": "alekseev-n-1970@postgrespro.ru", "phone": "+70596981456"}
0005434824052	B61D52	2808 677150	NIKOLAY KULIKOV	{"phone": "+70264069395"}
0005434824053	7B8D62	1650 354065	TIMUR SOROKIN	{"phone": "+70828686707"}
0005434824054	82BFA8	5174 112318	BORIS KUZNECOV	{"phone": "+70621376193"}
0005434824055	82BFA8	9662 453731	ANASTASIYA VLASOVA	{"phone": "+70556964967"}
0005434824056	8E8CC5	2121 638427	ANATOLIY TIKHONOV	{"email": "tikhonov_anatoliy_021977@postgrespro.ru", "phone": "+70472237965"}
0005434824057	F14501	1230 387091	GEORGIY ORLOV	{"email": "georgiy-orlov.1982@postgrespro.ru", "phone": "+70241718148"}
0005434824058	F14501	6944 237526	ALEKSANDR MELNIKOV	{"email": "a-melnikov.101968@postgrespro.ru", "phone": "+70024533717"}
0005434824059	AA3035	6878 473475	TATYANA YAKOVLEVA	{"email": "yakovleva-t011975@postgrespro.ru", "phone": "+70351783663"}
0005434824060	4210B0	0060 496000	MARIYA SIDOROVA	{"email": "mariyasidorova.031977@postgrespro.ru", "phone": "+70806028732"}
0005434824061	4210B0	1005 565972	DMITRIY FROLOV	{"phone": "+70002956032"}
0005434824062	CA112B	5425 255547	DARYA KUZNECOVA	{"phone": "+70705812166"}
0005434824063	CA112B	0505 298078	ALEKSANDR KAZAKOV	{"email": "kazakova-13021971@postgrespro.ru", "phone": "+70647367774"}
0005434824064	CA112B	9997 360567	OLGA SMIRNOVA	{"email": "smirnova.o.02031983@postgrespro.ru", "phone": "+70399942136"}
0005434824065	4B1A63	7876 529861	LYUDMILA MIRONOVA	{"email": "lyudmila.mironova.1973@postgrespro.ru", "phone": "+70776241379"}
0005434824066	3D68D6	3260 740444	ANATOLIY FILIPPOV	{"email": "anatoliy.filippov.1970@postgrespro.ru", "phone": "+70748023380"}
0005434824067	04EE02	4495 949289	DMITRIY POPOV	{"phone": "+70384049356"}
0005434824068	11F80E	7578 556959	ARTEM KAZAKOV	{"email": "kazakova.16071974@postgrespro.ru", "phone": "+70222342103"}
0005434824069	31898F	0522 835976	IGOR POPOV	{"phone": "+70074495457"}
0005434824070	6592C3	6792 794373	ROZA KRASNOVA	{"email": "roza_krasnova1979@postgrespro.ru", "phone": "+70448112652"}
0005434824071	7A5E58	3370 411982	DMITRIY ABRAMOV	{"email": "abramovdmitriy101973@postgrespro.ru", "phone": "+70965282890"}
0005434824072	7A5E58	8076 852208	ANASTASIYA KOMAROVA	{"email": "anastasiya-komarova-22111970@postgrespro.ru", "phone": "+70810894134"}
0005434824073	B855B0	5100 041552	ANDREY ORLOV	{"email": "andreyorlov041988@postgrespro.ru", "phone": "+70469063295"}
0005434824074	41AA54	2269 057562	YAROSLAV MAKAROV	{"phone": "+70610701737"}
0005434824075	41AA54	4012 759531	MARIYA KUZNECOVA	{"email": "kuznecova-mariya.1962@postgrespro.ru", "phone": "+70856903626"}
0005434824076	311586	6495 287764	ARINA ZAYCEVA	{"email": "a.zayceva-111968@postgrespro.ru", "phone": "+70428324948"}
0005434824077	311586	4204 562819	VALENTINA FROLOVA	{"phone": "+70166186665"}
0005434824078	DE153D	6466 893460	NATALYA LOGINOVA	{"email": "loginova_natalya.081968@postgrespro.ru", "phone": "+70539388574"}
0005434824079	6AE7F0	0376 147242	MARINA ISAEVA	{"email": "marina.isaeva-1980@postgrespro.ru", "phone": "+70415522111"}
0005434824080	D08DD1	6772 949118	IGOR KOZLOV	{"email": "ikozlov.02121972@postgrespro.ru", "phone": "+70939711545"}
0005434824081	D08DD1	8385 088125	MARIYA NESTEROVA	{"phone": "+70523067833"}
0005434824082	4924D7	2130 161292	VADIM GUSEV	{"phone": "+70199084545"}
0005434824083	4924D7	1166 880496	ALEKSANDR DENISOV	{"phone": "+70170369687"}
0005434824084	1A98E4	9475 331097	SERGEY KARPOV	{"email": "karpovs_091970@postgrespro.ru", "phone": "+70054044094"}
0005434824085	1A98E4	3140 974020	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoaleksandr.121972@postgrespro.ru", "phone": "+70934227868"}
0005434824086	1D4E84	8553 195255	GUZEL ILINA	{"phone": "+70240785484"}
0005434824087	1D4E84	8145 817536	MARIYA RODIONOVA	{"phone": "+70832071035"}
0005434824088	CE03BD	5823 549080	PETR MELNIKOV	{"email": "melnikovp03081975@postgrespro.ru", "phone": "+70617641826"}
0005434824089	CE03BD	2296 680799	MARINA MIKHAYLOVA	{"phone": "+70433505775"}
0005434824090	C0EEF3	7254 487088	GALINA FILIPPOVA	{"phone": "+70752394598"}
0005434824091	9F434D	3703 824041	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n1980@postgrespro.ru", "phone": "+70979867596"}
0005434824092	9F434D	1142 624000	VENERA NOVIKOVA	{"phone": "+70624789712"}
0005434824093	069BF5	9685 892535	VERA VASILEVA	{"email": "v_vasileva1962@postgrespro.ru", "phone": "+70734851775"}
0005434824094	069BF5	7709 960138	EVDOKIYA EGOROVA	{"email": "e.egorova_081976@postgrespro.ru", "phone": "+70528776407"}
0005434824095	37A812	8500 424887	SERGEY MIRONOV	{"phone": "+70455863995"}
0005434824096	37D0D3	3559 486946	LYUBOV ERMAKOVA	{"phone": "+70042524398"}
0005434824097	37D0D3	5537 513841	TATYANA IVANOVA	{"phone": "+70113495161"}
0005434824098	F52F79	4544 140369	OLEG MAKAROV	{"phone": "+70298009933"}
0005434824099	F52F79	8133 175983	VYACHESLAV ILIN	{"phone": "+70856519882"}
0005434824100	9C0EAD	9998 003515	VLADIMIR CHERNOV	{"email": "vchernov_1976@postgrespro.ru", "phone": "+70143538836"}
0005434824101	EFB5F9	2502 539630	ELENA OVCHINNIKOVA	{"phone": "+70696965591"}
0005434824102	EFB5F9	4933 789155	MARGARITA MIRONOVA	{"phone": "+70671073006"}
0005434824103	C2ABD8	9866 626692	GALINA ANTONOVA	{"phone": "+70350011690"}
0005434824104	C2ABD8	7632 151142	VLADIMIR SCHERBAKOV	{"email": "v-scherbakov25021980@postgrespro.ru", "phone": "+70904833911"}
0005434824105	F2487B	4100 825294	OLESYA ANDREEVA	{"email": "andreeva_olesya-1967@postgrespro.ru", "phone": "+70321246315"}
0005434824106	F2487B	9006 840355	LYUBOV SMIRNOVA	{"phone": "+70811172701"}
0005434824107	012237	4024 377206	LYUDMILA MASLOVA	{"email": "maslova_l-18121974@postgrespro.ru", "phone": "+70305402439"}
0005434824108	F8C9F0	8630 219930	LYUBOV KOMAROVA	{"email": "lyubov_komarova_1972@postgrespro.ru", "phone": "+70886461801"}
0005434824109	24DF13	7105 912208	PAVEL ALEKSEEV	{"email": "pavelalekseev-20081978@postgrespro.ru", "phone": "+70219326752"}
0005434824110	5BC07E	7737 916459	ALEKSANDR KOROLEV	{"email": "aleksandrkorolev.071968@postgrespro.ru", "phone": "+70879703809"}
0005434824111	DF9E31	4251 262443	TATYANA MIRONOVA	{"phone": "+70551927001"}
0005434824112	DF9E31	3947 297387	IGOR YAKOVLEV	{"phone": "+70139742198"}
0005434824113	948F09	8315 439011	MIKHAIL KAZAKOV	{"email": "mikhailkazakov-1970@postgrespro.ru", "phone": "+70560621351"}
0005434824114	948F09	3401 622545	OLGA ERMAKOVA	{"phone": "+70196575432"}
0005434824115	699666	8354 520393	ZINAIDA VOROBEVA	{"phone": "+70169376595"}
0005434824116	699666	9329 395013	DANIIL DMITRIEV	{"email": "d-dmitriev.1973@postgrespro.ru", "phone": "+70392896206"}
0005434824117	699666	8299 022524	ANNA NIKOLAEVA	{"phone": "+70938314669"}
0005434824118	959004	7710 338680	RINAT DAVYDOV	{"phone": "+70044532683"}
0005434824119	8DB68D	3356 463343	OLGA GRISHINA	{"phone": "+70273068364"}
0005434824120	8DB68D	3183 583319	SVETLANA ZOTOVA	{"phone": "+70396834193"}
0005434824121	75509B	7988 209038	LIDIYA SAVELEVA	{"phone": "+70433605246"}
0005434824122	4C84DF	5085 200378	YURIY GERASIMOV	{"phone": "+70867393263"}
0005434824123	9AFC9B	3110 040995	ANDREY ANDREEV	{"phone": "+70429029603"}
0005434824124	32C6AC	7468 640271	ALEKSANDR ALEKSEEV	{"phone": "+70947438803"}
0005434824125	32C6AC	7853 464618	ALINA EGOROVA	{"phone": "+70413370158"}
0005434824126	8C48B9	6635 572363	OLGA NOVIKOVA	{"phone": "+70301533005"}
0005434824127	8C48B9	7342 370679	VYACHESLAV ORLOV	{"phone": "+70440481311"}
0005434824128	E39319	1679 052752	IGOR MOROZOV	{"phone": "+70231114494"}
0005434824129	F560F2	3287 974384	TATYANA SMIRNOVA	{"email": "t.smirnova12051954@postgrespro.ru", "phone": "+70226558675"}
0005434824130	F560F2	6822 150447	TATYANA GUSEVA	{"email": "guseva-t.24121980@postgrespro.ru", "phone": "+70254325327"}
0005434824131	97EF9B	5715 978430	ANTON POPOV	{"email": "popov-anton-1971@postgrespro.ru", "phone": "+70643858822"}
0005434824132	97EF9B	0321 609762	VALENTINA MAKAROVA	{"email": "makarova_v-071980@postgrespro.ru", "phone": "+70854182641"}
0005434824133	65B4B1	3813 486313	ILYA OSIPOV	{"email": "i_osipov121974@postgrespro.ru", "phone": "+70127680832"}
0005434824134	65B4B1	3768 210427	LYUBOV KUZNECOVA	{"email": "kuznecova.l_1974@postgrespro.ru", "phone": "+70172199283"}
0005434824135	13906D	7567 012638	RENAT VOROBEV	{"email": "vorobev-r12021982@postgrespro.ru", "phone": "+70548688262"}
0005434824136	C119B4	7375 690638	VYACHESLAV ZHUKOV	{"email": "zhukov.v1973@postgrespro.ru", "phone": "+70384846724"}
0005434824137	2A118B	1957 758834	EVGENIYA NESTEROVA	{"email": "evgeniya_nesterova1969@postgrespro.ru", "phone": "+70019476479"}
0005434824138	DA57DE	1132 465874	STANISLAV YAKOVLEV	{"phone": "+70448307212"}
0005434824139	EA857E	8055 789627	ALEKSANDR ISAEV	{"phone": "+70648438349"}
0005434824140	787789	4263 874538	VERA MAKSIMOVA	{"phone": "+70839431654"}
0005434824141	28CE30	0997 118109	LYUBOV TIKHONOVA	{"email": "lyubovtikhonova.1960@postgrespro.ru", "phone": "+70814084385"}
0005434824142	28CE30	0251 644448	DENIS ANDREEV	{"phone": "+70206044947"}
0005434824143	A48200	9405 019733	OLGA SOROKINA	{"phone": "+70602144322"}
0005434824144	A48200	9444 514388	TAMARA POTAPOVA	{"email": "potapovat.121967@postgrespro.ru", "phone": "+70428690552"}
0005434824145	551624	5840 207090	KSENIYA YAKOVLEVA	{"phone": "+70891462220"}
0005434824146	2600A5	7501 065599	DENIS BELOV	{"phone": "+70953984200"}
0005434824147	4FFBAC	4886 783255	OLGA EGOROVA	{"phone": "+70932771536"}
0005434824148	E3AB13	3428 770218	SERGEY VLASOV	{"phone": "+70754547878"}
0005434824149	FBD26F	6545 958105	ALEKSANDR KONOVALOV	{"email": "konovalov-a1969@postgrespro.ru", "phone": "+70209508712"}
0005434824150	A515CD	7718 753089	OLEG ZAYCEV	{"email": "oleg-zaycev_1972@postgrespro.ru", "phone": "+70146960953"}
0005434824151	84A228	3559 188775	YULIYA TIKHONOVA	{"email": "yuliya-tikhonova_1978@postgrespro.ru", "phone": "+70536028095"}
0005434824152	84A228	2836 536185	VERA SOROKINA	{"phone": "+70764364689"}
0005434824153	6F5559	1042 252483	SERGEY KUZMIN	{"email": "skuzmin.061977@postgrespro.ru", "phone": "+70975228474"}
0005434824154	C7A520	8855 361622	GENNADIY FROLOV	{"phone": "+70127958278"}
0005434824155	878EE0	1059 410010	VLADIMIR BORISOV	{"phone": "+70716072769"}
0005434824156	2C8B77	4235 440397	ELENA FEDOROVA	{"phone": "+70914139698"}
0005434824157	7A1729	5372 039206	DAMIR NIKOLAEV	{"email": "nikolaev-damir-091975@postgrespro.ru", "phone": "+70151707142"}
0005434824158	DD0E69	6555 357980	IVAN ABRAMOV	{"phone": "+70352267304"}
0005434824159	AD06EB	2400 341603	ALEKSEY VOLKOV	{"email": "volkov.a.051971@postgrespro.ru", "phone": "+70821149992"}
0005434824160	88C277	2652 423806	LIDIYA ZAKHAROVA	{"phone": "+70151923499"}
0005434824161	EEF686	0876 902255	DMITRIY DAVYDOV	{"phone": "+70181686718"}
0005434824162	0FCAE3	5481 785914	OLGA ROMANOVA	{"phone": "+70643645756"}
0005434824163	EB47B6	6535 467774	ALEKSANDR GRIGOREV	{"phone": "+70911708873"}
0005434824164	7FCC8D	4601 448125	ZOYA SIDOROVA	{"email": "z_sidorova-23031961@postgrespro.ru", "phone": "+70451923833"}
0005434824165	7FC53C	2321 116376	ALEKSANDR MEDVEDEV	{"phone": "+70380578432"}
0005434824166	7FC53C	8776 083410	VALERIYA ANTONOVA	{"email": "antonova.valeriya-15091975@postgrespro.ru", "phone": "+70798484110"}
0005434824167	983FB5	7873 980531	MAKSIM ANDREEV	{"email": "andreev_m-03081975@postgrespro.ru", "phone": "+70747493070"}
0005434824168	4C9364	3041 504915	TAMARA ANDREEVA	{"phone": "+70357187335"}
0005434824169	E8C3D7	0794 930431	ELVIRA FOMINA	{"email": "e_fomina-051975@postgrespro.ru", "phone": "+70334424689"}
0005434824170	CE6FBF	9150 065979	LIDIYA ZHURAVLEVA	{"email": "lidiya-zhuravleva15031968@postgrespro.ru", "phone": "+70657249095"}
0005434824171	CE6FBF	7211 580796	LIDIYA KOZLOVA	{"phone": "+70773962914"}
0005434824172	155BCF	8698 381468	SEMEN NOVIKOV	{"phone": "+70141610972"}
0005434824173	76E1D4	9625 242462	DMITRIY IVANOV	{"phone": "+70313297371"}
0005434824174	76E1D4	9313 636542	LYUDMILA BELOVA	{"phone": "+70913519840"}
0005434824175	76E1D4	9644 683674	NINA EFIMOVA	{"phone": "+70087652493"}
0005434824176	887296	8090 517434	VIKTOR KUZMIN	{"email": "viktorkuzmin-1965@postgrespro.ru", "phone": "+70947373036"}
0005434824177	887296	7502 969827	PAVEL SOKOLOV	{"phone": "+70483660077"}
0005434824178	576AC3	7476 047992	VLADIMIR ANDREEV	{"email": "andreev_vladimir_1984@postgrespro.ru", "phone": "+70340689735"}
0005434824179	341F05	7241 048371	NATALYA AFANASEVA	{"email": "afanaseva_n_23021969@postgrespro.ru", "phone": "+70181418330"}
0005434824180	266E40	6570 034610	GENNADIY MIKHAYLOV	{"email": "g_mikhaylov.111975@postgrespro.ru", "phone": "+70285640344"}
0005434824181	066A5E	1114 724267	YURIY IVANOV	{"email": "ivanov.yuriy-28081983@postgrespro.ru", "phone": "+70006715180"}
0005434824182	066A5E	0950 940838	ALEKSANDR FROLOV	{"phone": "+70331956572"}
0005434824183	F8C495	2158 015269	YURIY ALEKSEEV	{"phone": "+70904763603"}
0005434824184	A94E36	2488 966915	RUSTAM KUZNECOV	{"phone": "+70807573370"}
0005434824185	A94E36	8973 845117	ALEKSANDR IVANOV	{"phone": "+70360236507"}
0005434824186	204E02	6645 907321	SERGEY ZAYCEV	{"email": "zaycev_s-25061965@postgrespro.ru", "phone": "+70713637120"}
0005434824187	F22A9B	7176 583378	ALEKSANDR KUZMIN	{"phone": "+70683465468"}
0005434824188	F22A9B	5647 699778	ARTUR GERASIMOV	{"email": "gerasimova_021976@postgrespro.ru", "phone": "+70037888946"}
0005434824189	9F4D62	2496 663808	MARIYA NAZAROVA	{"email": "mnazarova-03051964@postgrespro.ru", "phone": "+70949961647"}
0005434824190	EA52AE	7602 501518	ANNA MASLOVA	{"phone": "+70800835398"}
0005434824191	5E2217	2752 064875	YAROSLAV KUZMIN	{"phone": "+70534816483"}
0005434824192	5E2217	9196 369383	OKSANA ALEKSANDROVA	{"email": "aleksandrova_oksana-1973@postgrespro.ru", "phone": "+70435656712"}
0005434824193	62A0DC	1670 927715	ZINAIDA ANISIMOVA	{"phone": "+70238746143"}
0005434824194	62A0DC	7195 051263	ALBINA OSIPOVA	{"email": "albinaosipova_02061976@postgrespro.ru", "phone": "+70791575048"}
0005434824195	ED1EAA	5531 598913	SERGEY FROLOV	{"email": "sfrolov_1963@postgrespro.ru", "phone": "+70401457275"}
0005434824196	ED1EAA	6978 160403	FEDOR ALEKSEEV	{"email": "alekseevfedor_19081974@postgrespro.ru", "phone": "+70448726148"}
0005434824197	A17E76	9066 457142	NINA ANDREEVA	{"phone": "+70908620506"}
0005434824198	A17E76	4000 026926	ANASTASIYA POPOVA	{"email": "popovaa.071971@postgrespro.ru", "phone": "+70060086148"}
0005434824199	787E6D	9649 849995	ELENA TARASOVA	{"phone": "+70081570590"}
0005434824200	787E6D	6451 392447	DMITRIY ROMANOV	{"email": "romanov-dmitriy_20061973@postgrespro.ru", "phone": "+70385597155"}
0005434824201	787E6D	7243 617731	NINA ZAKHAROVA	{"email": "n-zakharova-011974@postgrespro.ru", "phone": "+70106524727"}
0005434824202	58E0B5	6491 927601	IGOR BARANOV	{"email": "i_baranov.031966@postgrespro.ru", "phone": "+70287084483"}
0005434824203	C5247D	1683 073808	MAKSIM SIDOROV	{"email": "sidorovmaksim-05041974@postgrespro.ru", "phone": "+70344552408"}
0005434824204	973D8B	9729 983460	NADEZHDA YUDINA	{"email": "yudina_nadezhda-1983@postgrespro.ru", "phone": "+70880968853"}
0005434824205	FF605A	2432 465819	VLADIMIR ISAEV	{"phone": "+70399467824"}
0005434824624	D37006	2715 113936	LARISA GAVRILOVA	{"phone": "+70845882510"}
0005434824206	15492F	9497 381522	ALLA MARTYNOVA	{"email": "martynova-a.30121983@postgrespro.ru", "phone": "+70204543219"}
0005434824207	15492F	0855 197054	TATYANA ZAKHAROVA	{"phone": "+70739077021"}
0005434824208	15492F	4550 711129	YULIYA TARASOVA	{"email": "tarasova.yuliya-26111982@postgrespro.ru", "phone": "+70328342563"}
0005434824209	1C673C	4844 774530	LYUBOV NIKOLAEVA	{"email": "nikolaeva_lyubov.011972@postgrespro.ru", "phone": "+70435422699"}
0005434824210	03793B	9102 981635	VERA OVCHINNIKOVA	{"phone": "+70526269946"}
0005434824211	27E686	8083 571468	YULIYA PAVLOVA	{"phone": "+70538218665"}
0005434824212	67EC31	2879 638046	DANIIL KOZLOV	{"phone": "+70224309944"}
0005434824213	00D2C8	5203 075740	GALINA BELOVA	{"email": "belova_galina-09081957@postgrespro.ru", "phone": "+70735255224"}
0005434824214	00D2C8	5086 765309	EKATERINA MEDVEDEVA	{"email": "e.medvedeva_051973@postgrespro.ru", "phone": "+70332864099"}
0005434824215	213AEC	8838 460592	RUSLAN PAVLOV	{"phone": "+70286361415"}
0005434824216	213AEC	9478 229909	RAISA GUSEVA	{"email": "guseva-r.031967@postgrespro.ru", "phone": "+70996947997"}
0005434824217	8E3DDB	9149 848688	DMITRIY VASILEV	{"phone": "+70082019437"}
0005434824218	46ABE6	6122 931905	DMITRIY MIKHAYLOV	{"email": "dmikhaylov1983@postgrespro.ru", "phone": "+70548799426"}
0005434824219	46ABE6	6617 284784	FEDOR TIKHONOV	{"email": "fedortikhonov-081967@postgrespro.ru", "phone": "+70569279127"}
0005434824220	B8FB9C	1831 594638	PAVEL MARTYNOV	{"phone": "+70622282451"}
0005434824221	B8FB9C	7113 774549	TATYANA CHERNOVA	{"email": "chernova-tatyana_041971@postgrespro.ru", "phone": "+70129581270"}
0005434824222	134520	2461 601486	TAMARA IVANOVA	{"email": "t_ivanova-071982@postgrespro.ru", "phone": "+70581342905"}
0005434824223	134520	1104 653878	ALEKSANDR FILIPPOV	{"email": "filippov_aleksandr101982@postgrespro.ru", "phone": "+70616843384"}
0005434824224	134520	9992 557254	TAMARA VASILEVA	{"phone": "+70318601136"}
0005434824225	CB0CAD	1221 598426	MARGARITA POPOVA	{"phone": "+70945115100"}
0005434824226	531531	4879 365353	LYUDMILA VASILEVA	{"phone": "+70900151472"}
0005434824227	BC56FC	3485 756711	ANNA KOZLOVA	{"phone": "+70295274551"}
0005434824228	66466A	5414 387490	VERA KUZNECOVA	{"email": "v-kuznecova-031975@postgrespro.ru", "phone": "+70904163692"}
0005434824229	66466A	7308 420148	EVGENIY GAVRILOV	{"email": "e-gavrilov_1983@postgrespro.ru", "phone": "+70982041071"}
0005434824230	552B90	9614 959339	TATYANA DENISOVA	{"email": "denisova-tatyana.08081968@postgrespro.ru", "phone": "+70418379391"}
0005434824231	552B90	4816 435573	ANGELINA ISAEVA	{"email": "angelinaisaeva_1971@postgrespro.ru", "phone": "+70700619577"}
0005434824232	539C01	7900 585750	POLINA KUZNECOVA	{"phone": "+70625621926"}
0005434824233	9B68FE	4370 032238	NATALYA BORISOVA	{"email": "natalya.borisova_1967@postgrespro.ru", "phone": "+70570438747"}
0005434824234	15C693	9011 037746	OLGA MAKAROVA	{"email": "makarova.o1974@postgrespro.ru", "phone": "+70955314472"}
0005434824235	15C693	5001 806741	ALEKSANDR BELOV	{"email": "a_belov_031981@postgrespro.ru", "phone": "+70365748329"}
0005434824236	955D13	8617 912958	IRINA ABRAMOVA	{"email": "abramova-i_1986@postgrespro.ru", "phone": "+70016054032"}
0005434824237	EFDF2E	1063 025067	ANTONINA BELOVA	{"email": "belova-antonina_02111966@postgrespro.ru", "phone": "+70525920402"}
0005434824238	EFDF2E	8262 109509	VLADIMIR AFANASEV	{"email": "v-afanasev081984@postgrespro.ru", "phone": "+70247772082"}
0005434824239	EFDF2E	1419 594947	ALEKSANDR NOVIKOV	{"phone": "+70484599004"}
0005434824240	2BF86F	9398 497607	NINA KISELEVA	{"email": "nkiseleva-061972@postgrespro.ru", "phone": "+70580984805"}
0005434824241	43D3EE	5585 881320	VLADIMIR GRIGOREV	{"phone": "+70926540067"}
0005434824242	43D3EE	2732 664652	DARYA KUZNECOVA	{"phone": "+70537910249"}
0005434824243	1D019B	4877 855380	MARIYA MOROZOVA	{"phone": "+70217395069"}
0005434824244	1D019B	6284 972302	OLGA IVANOVA	{"phone": "+70417686903"}
0005434824245	55EDBE	1220 258084	ALEKSANDRA ABRAMOVA	{"email": "abramova-a-19081967@postgrespro.ru", "phone": "+70988000938"}
0005434824246	0DD8BB	9805 124714	TATYANA KOZLOVA	{"email": "kozlovat_051972@postgrespro.ru", "phone": "+70942823396"}
0005434824247	0DD8BB	8084 331970	ELENA SIDOROVA	{"phone": "+70860445667"}
0005434824248	5D5899	4330 874913	KSENIYA MIRONOVA	{"email": "mironovak.071965@postgrespro.ru", "phone": "+70083968953"}
0005434824249	AEB04F	8488 261813	ANNA MEDVEDEVA	{"phone": "+70191043177"}
0005434824250	5E5F22	5025 632501	VIKTORIYA FILIPPOVA	{"email": "v.filippova-011984@postgrespro.ru", "phone": "+70489132079"}
0005434824251	08D130	8086 007939	DENIS MAKSIMOV	{"email": "denis.maksimov-061969@postgrespro.ru", "phone": "+70726481375"}
0005434824252	970B71	7665 879606	ALEKSANDR FEDOROV	{"phone": "+70437935131"}
0005434824253	F8023E	6248 104862	EKATERINA VOLKOVA	{"phone": "+70194858357"}
0005434824254	CF0B5F	5570 439340	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov27031977@postgrespro.ru", "phone": "+70066578597"}
0005434824255	0073D3	1539 393916	KIRILL BORISOV	{"phone": "+70763300708"}
0005434824256	0073D3	7444 092548	ALLA FADEEVA	{"email": "a-fadeeva-041982@postgrespro.ru", "phone": "+70531576800"}
0005434824257	870714	9449 134434	ALISA SMIRNOVA	{"email": "a-smirnova_1975@postgrespro.ru", "phone": "+70148046439"}
0005434824258	0E80FF	5164 251891	EVGENIYA KOROLEVA	{"email": "e-koroleva031972@postgrespro.ru", "phone": "+70507230004"}
0005434824259	0E80FF	8578 516748	GENNADIY SCHERBAKOV	{"phone": "+70573614540"}
0005434824315	DA0528	4135 326381	TATYANA OVCHINNIKOVA	{"phone": "+70268448646"}
0005434824260	0E80FF	1602 117571	ARINA PETROVA	{"email": "arinapetrova_19021975@postgrespro.ru", "phone": "+70697813979"}
0005434824261	C58BB8	7739 044342	DANIIL SEMENOV	{"email": "d.semenov.041968@postgrespro.ru", "phone": "+70220257231"}
0005434824262	C58BB8	3405 319706	EKATERINA MELNIKOVA	{"email": "melnikovaekaterina18051964@postgrespro.ru", "phone": "+70151931879"}
0005434824263	27B881	6405 567848	ANNA ALEKSEEVA	{"phone": "+70797682822"}
0005434824264	B9858A	5656 824283	EKATERINA EFIMOVA	{"email": "ekaterina_efimova28071969@postgrespro.ru", "phone": "+70565785271"}
0005434824265	4ACA80	8337 636521	TAMARA NIKIFOROVA	{"email": "nikiforovat011978@postgrespro.ru", "phone": "+70868997716"}
0005434824266	499599	5671 247501	EKATERINA MAKSIMOVA	{"email": "e_maksimova_19051979@postgrespro.ru", "phone": "+70265555422"}
0005434824267	A7EB60	7493 308735	VLADIMIR ZHUKOV	{"phone": "+70765832654"}
0005434824268	A7EB60	7796 667511	NIKOLAY SIDOROV	{"email": "n-sidorov23031971@postgrespro.ru", "phone": "+70111003509"}
0005434824269	70CE1D	7282 313624	STEPAN IVANOV	{"email": "ivanov-stepan_1969@postgrespro.ru", "phone": "+70731684431"}
0005434824270	BD8605	5153 668399	SERGEY SOKOLOV	{"phone": "+70175058529"}
0005434824271	B66C4E	0758 597340	NATALYA SAVELEVA	{"email": "saveleva_n-091970@postgrespro.ru", "phone": "+70427644535"}
0005434824272	30D8B9	3443 020675	ALEKSEY SOROKIN	{"email": "sorokin_aleksey_1969@postgrespro.ru", "phone": "+70532034502"}
0005434824273	9ED95C	3385 415504	ALEKSANDR ROMANOV	{"phone": "+70334134085"}
0005434824274	462A92	3507 766800	NATALIYA SERGEEVA	{"phone": "+70269812184"}
0005434824275	DF5262	0173 699918	ALEKSANDR IVANOV	{"email": "aivanov.04101974@postgrespro.ru", "phone": "+70079839131"}
0005434824276	DF5262	3724 864638	ALEKSEY TARASOV	{"email": "tarasov.a.1971@postgrespro.ru", "phone": "+70847866661"}
0005434824277	DF5262	0738 134210	NIKOLAY ALEKSEEV	{"email": "alekseev_nikolay-24091976@postgrespro.ru", "phone": "+70249178152"}
0005434824278	6A2DB6	1136 796860	MARINA AFANASEVA	{"email": "afanaseva-m_17041968@postgrespro.ru", "phone": "+70421809953"}
0005434824279	EF3AE6	5767 470042	IVAN BORISOV	{"phone": "+70396639635"}
0005434824280	417B12	2705 099263	ELENA SERGEEVA	{"email": "e-sergeeva15081982@postgrespro.ru", "phone": "+70063624694"}
0005434824281	99BC14	0876 248726	GALINA BELYAEVA	{"email": "belyaeva.galina.061977@postgrespro.ru", "phone": "+70393295025"}
0005434824282	99BC14	8421 276024	SVETLANA DAVYDOVA	{"email": "svetlana_davydova_061979@postgrespro.ru", "phone": "+70007574169"}
0005434824283	3BFD02	2878 076268	VLADIMIR KUZNECOV	{"email": "kuznecov-v.07041971@postgrespro.ru", "phone": "+70981826508"}
0005434824284	3BFD02	6921 355236	MILANA NIKOLAEVA	{"phone": "+70975712630"}
0005434824285	508CB9	2379 456162	PAVEL KOROLEV	{"email": "korolev_pavel_1972@postgrespro.ru", "phone": "+70025713796"}
0005434824286	93B970	1417 621835	SOFYA ZOTOVA	{"phone": "+70802093595"}
0005434824287	93B970	7638 437766	ALEKSEY MIKHAYLOV	{"phone": "+70590250306"}
0005434824288	CE36CC	4511 553836	ANTON POPOV	{"phone": "+70492242153"}
0005434824289	CE36CC	5848 599812	NADEZHDA KONOVALOVA	{"phone": "+70452388681"}
0005434824290	CE36CC	0377 529323	LIDIYA KOMAROVA	{"phone": "+70769041066"}
0005434824291	AC52F9	8425 174304	VITALIY FEDOROV	{"phone": "+70727163060"}
0005434824292	CC803A	0236 514673	DMITRIY KOZLOV	{"phone": "+70920808679"}
0005434824293	CC803A	4962 043947	RINAT MIKHAYLOV	{"phone": "+70008244510"}
0005434824294	4CE88F	3327 269416	NIKOLAY FEDOROV	{"email": "nikolay.fedorov_19091977@postgrespro.ru", "phone": "+70423657147"}
0005434824295	4CE88F	8855 920964	SVETLANA SOKOLOVA	{"email": "sokolovas071986@postgrespro.ru", "phone": "+70925819501"}
0005434824296	0491A7	8204 310602	GALINA FILIPPOVA	{"email": "filippova.galina.11061962@postgrespro.ru", "phone": "+70970547037"}
0005434824297	EB50BB	2031 645428	TAMARA NOVIKOVA	{"phone": "+70752072484"}
0005434824298	EB50BB	3657 811198	ELENA VOROBEVA	{"phone": "+70753640671"}
0005434824299	6AA8B9	0355 718291	ANDREY KUDRYASHOV	{"phone": "+70796606936"}
0005434824300	6AA8B9	3868 347170	VIKTOR ALEKSEEV	{"email": "alekseev-v.08011979@postgrespro.ru", "phone": "+70226508317"}
0005434824301	C77DB3	5280 447246	YURIY DMITRIEV	{"phone": "+70901627651"}
0005434824302	85A067	2997 810612	LYUDMILA KUZNECOVA	{"phone": "+70238815149"}
0005434824303	11322B	8261 493970	LARISA VOROBEVA	{"email": "vorobeva.l_1975@postgrespro.ru", "phone": "+70769256761"}
0005434824304	C000E7	4889 429777	DARYA RODIONOVA	{"email": "rodionova-d_1958@postgrespro.ru", "phone": "+70017837969"}
0005434824305	C000E7	7462 714973	ALEKSEY ZAKHAROV	{"email": "zakharova_041976@postgrespro.ru", "phone": "+70884517541"}
0005434824306	6F5A75	5914 328039	ALEKSANDR PAVLOV	{"email": "a_pavlov14091970@postgrespro.ru", "phone": "+70839417412"}
0005434824307	EC3FFC	5651 895746	MIKHAIL NAUMOV	{"email": "naumov.m-20101968@postgrespro.ru", "phone": "+70301183323"}
0005434824308	0C1654	8870 483435	ANATOLIY ALEKSANDROV	{"email": "anatoliy.aleksandrov-25121976@postgrespro.ru", "phone": "+70368959396"}
0005434824309	282F4C	8086 862574	TATYANA ROMANOVA	{"email": "romanova.t.1969@postgrespro.ru", "phone": "+70292419913"}
0005434824310	55B3AE	6250 389351	ROMAN SHEVCHENKO	{"phone": "+70480710961"}
0005434824311	C92B40	5649 717874	PETR FROLOV	{"email": "frolov-p111975@postgrespro.ru", "phone": "+70024388853"}
0005434824312	99CDE9	5283 995567	DINA SMIRNOVA	{"phone": "+70411393617"}
0005434824313	99CDE9	0652 645819	VERA VASILEVA	{"email": "vera-vasileva_07051971@postgrespro.ru", "phone": "+70853415145"}
0005434824314	EBCBEE	8258 512948	VASILIY NAUMOV	{"email": "naumovvasiliy_1964@postgrespro.ru", "phone": "+70291020198"}
0005434824316	A1E37C	3390 473093	OLGA ISAEVA	{"email": "isaeva-olga.14091979@postgrespro.ru", "phone": "+70555083439"}
0005434824317	A1E37C	6361 521414	VERA PAVLOVA	{"email": "vera.pavlova.02031976@postgrespro.ru", "phone": "+70128881404"}
0005434824318	5E5D37	3766 741430	YULIYA VASILEVA	{"phone": "+70409362525"}
0005434824319	807D1C	0146 668018	NELLI ALEKSANDROVA	{"email": "n-aleksandrova.1969@postgrespro.ru", "phone": "+70460448994"}
0005434824320	807D1C	3685 333954	OLGA FOMINA	{"email": "fomina-o011969@postgrespro.ru", "phone": "+70200468385"}
0005434824321	04E5EE	8419 843995	ALEKSANDR EGOROV	{"phone": "+70824139572"}
0005434824322	04E5EE	3325 785436	EVGENIYA ANTONOVA	{"phone": "+70442888821"}
0005434824625	A17B3B	5333 154052	OLGA ZOTOVA	{"phone": "+70804668151"}
0005434824323	81781D	0043 043699	SERGEY DMITRIEV	{"email": "sergey-dmitriev-051973@postgrespro.ru", "phone": "+70561711701"}
0005434824324	9E1774	4597 487343	ASKAR ABRAMOV	{"email": "askar.abramov_031977@postgrespro.ru", "phone": "+70982293201"}
0005434824325	AA8FA4	6834 122109	LYAYSAN MIKHAYLOVA	{"phone": "+70170095164"}
0005434824326	AC4CF3	7227 343447	VALENTINA ABRAMOVA	{"phone": "+70750176415"}
0005434824327	4D48D2	4439 834699	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr.1972@postgrespro.ru", "phone": "+70633841126"}
0005434824328	4D48D2	8686 489670	NATALYA KUDRYASHOVA	{"email": "n.kudryashova_1966@postgrespro.ru", "phone": "+70151411277"}
0005434824329	4AED53	8559 460462	OLGA KONDRATEVA	{"email": "kondrateva-o29111977@postgrespro.ru", "phone": "+70462985817"}
0005434824330	FBBA31	5059 310511	TATYANA TITOVA	{"email": "titova.t041978@postgrespro.ru", "phone": "+70418183294"}
0005434824331	FBBA31	7302 385854	SERGEY YAKOVLEV	{"phone": "+70523041562"}
0005434824332	367674	6551 977074	ANNA SEMENOVA	{"phone": "+70703352099"}
0005434824333	72732E	2520 418064	KSENIYA BORISOVA	{"phone": "+70808957691"}
0005434824334	EED92C	3288 556737	ELENA ERMAKOVA	{"email": "e-ermakova.1961@postgrespro.ru", "phone": "+70824133536"}
0005434824335	8C05EA	1548 080565	YULIYA SAVELEVA	{"email": "saveleva-y_14041959@postgrespro.ru", "phone": "+70180941569"}
0005434824336	5D9252	2024 779932	EMMA ZOTOVA	{"email": "zotova-e_051984@postgrespro.ru", "phone": "+70678170951"}
0005434824337	5D9252	0476 108236	ALEKSEY KUZNECOV	{"phone": "+70959081151"}
0005434824338	C23FFE	7373 325529	KSENIYA KUZMINA	{"email": "kuzmina.kseniya.13061974@postgrespro.ru", "phone": "+70213004013"}
0005434824339	C23FFE	0729 118282	VIKTOR TIKHONOV	{"email": "vtikhonov_101968@postgrespro.ru", "phone": "+70161295962"}
0005434824340	BBC822	8510 314836	YULIYA NAZAROVA	{"phone": "+70331317002"}
0005434824341	BBC822	7556 923222	IVAN GRIGOREV	{"email": "igrigorev-1970@postgrespro.ru", "phone": "+70570374508"}
0005434824342	136574	3407 841308	TIMOFEY TIMOFEEV	{"email": "timofeev.t_011967@postgrespro.ru", "phone": "+70807211395"}
0005434824343	136574	3700 767433	VLADIMIR NAZAROV	{"phone": "+70565538083"}
0005434824344	B1FCED	6206 598513	LYUBOV CHERNOVA	{"email": "chernovalyubov.01031967@postgrespro.ru", "phone": "+70562904662"}
0005434824345	34C819	5109 146642	DMITRIY FROLOV	{"phone": "+70611744906"}
0005434824346	0A49C4	0374 141604	TATYANA ROMANOVA	{"email": "tatyana.romanova-101974@postgrespro.ru", "phone": "+70563727660"}
0005434824347	0A49C4	0815 903663	PAVEL MELNIKOV	{"phone": "+70268053108"}
0005434824348	B17446	7002 761990	VITALIY DAVYDOV	{"phone": "+70287551505"}
0005434824349	E557F7	2331 570870	NADEZHDA OSIPOVA	{"phone": "+70037596829"}
0005434824350	1D1306	1360 094272	ALEKSANDR ILIN	{"phone": "+70011645588"}
0005434824351	D434FE	3341 555616	ALINA ZAYCEVA	{"phone": "+70854137124"}
0005434824352	CD5C03	7519 323320	TATYANA NESTEROVA	{"email": "tatyananesterova_031973@postgrespro.ru", "phone": "+70142088597"}
0005434824353	95DE7F	9579 899560	NIKOLAY ZAKHAROV	{"phone": "+70321604628"}
0005434824354	992FAB	0280 617724	ANNA RYABOVA	{"email": "anna.ryabova-1962@postgrespro.ru", "phone": "+70439029727"}
0005434824355	992FAB	3979 675229	ANDREY ALEKSANDROV	{"email": "aleksandrov-a-04041965@postgrespro.ru", "phone": "+70513942012"}
0005434824356	E47D38	8739 731062	IGOR KONOVALOV	{"phone": "+70683517008"}
0005434824357	5176A1	4365 436694	ANASTASIYA ABRAMOVA	{"email": "a_abramova.18091959@postgrespro.ru", "phone": "+70597137932"}
0005434824358	D0FAF6	5599 363972	VALENTINA MOROZOVA	{"phone": "+70580226241"}
0005434824359	89CF7B	8804 658254	ALEKSEY KOZLOV	{"phone": "+70289336708"}
0005434824360	BE4482	6459 017044	IRINA ROMANOVA	{"phone": "+70341605526"}
0005434824361	8EAAEC	8184 581878	MARIYA KOZLOVA	{"phone": "+70021705182"}
0005434824362	6E235C	0217 247491	SERGEY BARANOV	{"email": "baranov.sergey1979@postgrespro.ru", "phone": "+70361492093"}
0005434824363	6E235C	8328 618713	ANASTASIYA KOZLOVA	{"email": "kozlova.anastasiya071962@postgrespro.ru", "phone": "+70336781957"}
0005434824364	5D32DA	6235 730370	ANDREY MELNIKOV	{"phone": "+70709257670"}
0005434824365	AB9AE9	3000 999901	VIKTOR ZAYCEV	{"phone": "+70732559194"}
0005434824366	AB9AE9	5964 047277	ELENA KUZNECOVA	{"phone": "+70605499316"}
0005434824367	25C588	8784 678593	GRIGORIY MEDVEDEV	{"phone": "+70507066089"}
0005434824368	19095D	8946 381469	ELENA SEMENOVA	{"phone": "+70045512997"}
0005434824369	F8EB64	9716 192081	EVGENIY MIRONOV	{"email": "mironovevgeniy.1963@postgrespro.ru", "phone": "+70755673298"}
0005434824370	F8EB64	7292 973853	ALEKSEY KUZMIN	{"email": "aleksey-kuzmin_1970@postgrespro.ru", "phone": "+70425088496"}
0005434824371	93BB22	3262 624844	ALEKSANDR VLASOV	{"email": "a.vlasov.101965@postgrespro.ru", "phone": "+70479199204"}
0005434824372	DBAB44	5639 696383	ALEKSANDR MIKHAYLOV	{"email": "a.mikhaylov-071981@postgrespro.ru", "phone": "+70296621623"}
0005434824373	DBAB44	6141 691262	OLEG ANDREEV	{"email": "andreevoleg-16011979@postgrespro.ru", "phone": "+70080799851"}
0005434824374	AB1CA0	3847 528135	LEV MELNIKOV	{"phone": "+70304649931"}
0005434824375	6EB6D6	9295 949082	OLEG MAKAROV	{"phone": "+70147052141"}
0005434824376	6EB6D6	6631 726304	ALEKSANDRA FROLOVA	{"phone": "+70849683145"}
0005434824377	4E702E	6998 073814	ALBINA ZHURAVLEVA	{"email": "albinazhuravleva.1974@postgrespro.ru", "phone": "+70683774114"}
0005434824378	4E702E	0234 731960	ALIYA NESTEROVA	{"phone": "+70767670737"}
0005434824379	E44CD0	0892 413142	ALEKSANDR DMITRIEV	{"phone": "+70031831923"}
0005434824380	44A055	4191 089880	VALENTINA KAZAKOVA	{"email": "kazakova-v_18031980@postgrespro.ru", "phone": "+70258215824"}
0005434824381	6CEBF7	3701 656422	ARINA GORBUNOVA	{"email": "arinagorbunova081966@postgrespro.ru", "phone": "+70250388537"}
0005434824382	6CEBF7	8583 869279	NATALIYA NIKIFOROVA	{"phone": "+70454186153"}
0005434824687	DE44AD	2709 314747	ELENA BELOVA	{"phone": "+70117040901"}
0005434824383	C74924	6590 510141	LYUDMILA IVANOVA	{"email": "lyudmila-ivanova-1970@postgrespro.ru", "phone": "+70432097327"}
0005434824384	6D1BE0	7179 109039	ELENA MAKSIMOVA	{"email": "e-maksimova1975@postgrespro.ru", "phone": "+70076904715"}
0005434824385	498244	0805 413088	SERGEY MAKAROV	{"email": "smakarov.051979@postgrespro.ru", "phone": "+70753017042"}
0005434824386	498244	6560 108274	VLADISLAV IVANOV	{"email": "ivanov-v-12121956@postgrespro.ru", "phone": "+70392469012"}
0005434824387	62591C	7260 731418	VALENTIN YAKOVLEV	{"phone": "+70658645173"}
0005434824388	19B5B9	8614 666216	RUSLAN KOZLOV	{"phone": "+70711172418"}
0005434824389	19B5B9	0278 804796	YURIY ISAEV	{"phone": "+70889905427"}
0005434824390	81E7F4	1234 475170	TAMARA ALEKSANDROVA	{"phone": "+70749349479"}
0005434824391	81E7F4	2465 402620	VLADISLAV ZHURAVLEV	{"phone": "+70548893217"}
0005434824392	B4ED50	7031 804831	YAROSLAV VOLKOV	{"phone": "+70779567484"}
0005434824393	3D148E	5277 292285	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov061963@postgrespro.ru", "phone": "+70165451896"}
0005434824394	3D148E	5444 504762	RAFAIL VASILEV	{"email": "r-vasilev041979@postgrespro.ru", "phone": "+70699664432"}
0005434824395	F66B49	6583 573695	KLAVDIYA KOZLOVA	{"email": "kozlovak_091982@postgrespro.ru", "phone": "+70410836269"}
0005434824396	F66B49	8521 629702	MIKHAIL TIKHONOV	{"phone": "+70909937128"}
0005434824397	F66B49	1344 965838	KSENIYA EFREMOVA	{"email": "k-efremova1986@postgrespro.ru", "phone": "+70175560994"}
0005434824398	086CF8	2862 328451	IVAN TARASOV	{"phone": "+70337570387"}
0005434824399	D2BA5A	3380 352961	KSENIYA GRISHINA	{"email": "k_grishina.091970@postgrespro.ru", "phone": "+70342579949"}
0005434824400	3E1886	3749 666621	SEMEN KUZNECOV	{"phone": "+70788215846"}
0005434824401	6CBF66	6678 872250	ILDAR ILIN	{"phone": "+70599617770"}
0005434824402	31E378	0594 232107	ZINAIDA CHERNOVA	{"phone": "+70830595703"}
0005434824403	31E378	1344 623472	ALEKSANDRA MATVEEVA	{"email": "matveeva-aleksandra.30011981@postgrespro.ru", "phone": "+70240497891"}
0005434824404	6A1401	0428 939331	SVETLANA EGOROVA	{"email": "s.egorova_04111981@postgrespro.ru", "phone": "+70535426810"}
0005434824405	EFFB9C	7575 707191	KAMILLA BORISOVA	{"phone": "+70572597365"}
0005434824406	289AAC	3785 085613	EVGENIYA GORBUNOVA	{"phone": "+70692393652"}
0005434824407	4BC975	5342 341319	NIKITA MAKAROV	{"email": "makarov-n1978@postgrespro.ru", "phone": "+70339731304"}
0005434824408	941BA9	7770 344031	ALEKSANDR ALEKSANDROV	{"phone": "+70103810249"}
0005434824409	941BA9	0017 067043	YURIY EGOROV	{"email": "y_egorov-25041971@postgrespro.ru", "phone": "+70200451008"}
0005434824410	047139	0575 607821	EKATERINA SOLOVEVA	{"email": "soloveva.e-01021969@postgrespro.ru", "phone": "+70693776062"}
0005434824411	A242B3	3084 153262	NADEZHDA ALEKSANDROVA	{"phone": "+70156411389"}
0005434824412	BFEB5C	0737 140349	ANASTASIYA ANDREEVA	{"email": "andreeva-anastasiya081964@postgrespro.ru", "phone": "+70887327337"}
0005434824413	167D84	2083 567420	IRINA KRASNOVA	{"email": "ikrasnova1988@postgrespro.ru", "phone": "+70211233531"}
0005434824414	361365	6116 838687	ANTONINA VASILEVA	{"phone": "+70761005622"}
0005434824415	34FE19	0401 674902	NADEZHDA NAZAROVA	{"email": "n-nazarova_1968@postgrespro.ru", "phone": "+70513862610"}
0005434824416	29D359	3985 045948	ELENA POPOVA	{"email": "elena_popova091973@postgrespro.ru", "phone": "+70048235688"}
0005434824417	29D359	6517 601408	MARINA IVANOVA	{"email": "m-ivanova_111979@postgrespro.ru", "phone": "+70563713892"}
0005434824418	4FC9D3	2581 260577	MARIYA LEBEDEVA	{"phone": "+70229963068"}
0005434824419	8676D5	2398 070543	SVETLANA VOLKOVA	{"email": "s.volkova.1975@postgrespro.ru", "phone": "+70895223032"}
0005434824420	F2CA0F	5668 875658	ANDREY DMITRIEV	{"phone": "+70472522998"}
0005434824421	3396EE	7579 282945	NAIL KAZAKOV	{"phone": "+70121061405"}
0005434824422	E2FFE2	8808 425435	NATALYA RODIONOVA	{"phone": "+70209967130"}
0005434824423	E2FFE2	4690 177763	IRINA SOROKINA	{"phone": "+70322393337"}
0005434824424	6EB808	4272 986320	ELENA LUKYANOVA	{"phone": "+70166803888"}
0005434824425	7E960F	9591 862508	OLGA BELOVA	{"phone": "+70997300814"}
0005434824426	7E960F	0465 024282	EVGENIY PAVLOV	{"phone": "+70558534079"}
0005434824427	06F3BC	2684 413213	ILYA GUSEV	{"phone": "+70196268002"}
0005434824428	0B9F42	2738 655962	ALINA TIKHONOVA	{"email": "alina.tikhonova1979@postgrespro.ru", "phone": "+70800946285"}
0005434824429	5BFC51	4475 299181	TATYANA AFANASEVA	{"phone": "+70780105731"}
0005434824430	B89267	3188 145719	ALEKSANDR POPOV	{"email": "aleksandr_popov-09121977@postgrespro.ru", "phone": "+70065997834"}
0005434824431	2E8FFC	8906 598751	NADEZHDA FEDOROVA	{"phone": "+70403695790"}
0005434824432	D21A92	1766 382526	IRINA ROMANOVA	{"phone": "+70543949918"}
0005434824433	81C796	5497 557946	ANATOLIY MIKHAYLOV	{"email": "mikhaylov-anatoliy.041971@postgrespro.ru", "phone": "+70721308024"}
0005434824434	A01A43	7750 408078	YAROSLAV TARASOV	{"email": "tarasov-y_011976@postgrespro.ru", "phone": "+70072844763"}
0005434824435	FD082E	2496 930146	ALEKSEY BONDARENKO	{"phone": "+70384588451"}
0005434824436	B42B64	2702 075636	ALEKSANDR CHERNOV	{"phone": "+70321082470"}
0005434824437	B42B64	5100 754024	NADEZHDA SIDOROVA	{"email": "nsidorova_04071972@postgrespro.ru", "phone": "+70408946596"}
0005434824438	B42B64	0433 782858	IRINA KUZNECOVA	{"email": "i.kuznecova09011970@postgrespro.ru", "phone": "+70519756558"}
0005434824439	626F53	7438 555493	VYACHESLAV ZHUKOV	{"phone": "+70335528038"}
0005434824440	6FF719	5831 477541	ALEKSEY KUZNECOV	{"phone": "+70547308148"}
0005434824441	6FF719	4167 345823	GALINA MOROZOVA	{"phone": "+70468096951"}
0005434824442	7B89E1	9735 687745	OLEG ANTONOV	{"phone": "+70946774547"}
0005434824443	76401A	8723 988395	NADEZHDA LUKYANOVA	{"email": "lukyanova.nadezhda_28121970@postgrespro.ru", "phone": "+70409769817"}
0005434824444	B893EF	0741 364358	VADIM KUZNECOV	{"phone": "+70536350075"}
0005434824445	E13E26	4395 359981	YURIY IVANOV	{"email": "ivanovyuriy.16091980@postgrespro.ru", "phone": "+70893633090"}
0005434824446	0CB669	3220 425111	VIKTORIYA KUZMINA	{"phone": "+70459192254"}
0005434824447	0CB669	3159 626416	IRINA ZAKHAROVA	{"phone": "+70633222564"}
0005434824448	0CB669	1007 091120	YURIY STEPANOV	{"phone": "+70332519044"}
0005434824449	CA0696	2751 655708	VALERIY VASILEV	{"email": "valeriy.vasilev-1963@postgrespro.ru", "phone": "+70607034340"}
0005434824450	7A75A5	6545 525114	EVGENIY MATVEEV	{"email": "evgeniy-matveev011971@postgrespro.ru", "phone": "+70871132386"}
0005434824451	7A75A5	3345 362754	VLADIMIR SMIRNOV	{"email": "vsmirnov.07111963@postgrespro.ru", "phone": "+70380590373"}
0005434824452	C176EE	6651 209984	OLGA SIDOROVA	{"phone": "+70557224384"}
0005434824453	0269DE	5778 846665	NIKOLAY SOROKIN	{"phone": "+70165915103"}
0005434824454	0269DE	2876 573491	MARIYA SOROKINA	{"email": "m.sorokina.061972@postgrespro.ru", "phone": "+70722670989"}
0005434824455	0269DE	9507 931280	ANASTASIYA ORLOVA	{"phone": "+70422939916"}
0005434824456	F1B926	3571 127603	ELENA ANDREEVA	{"phone": "+70533520908"}
0005434824457	4B2198	1277 708655	ANDREY ROMANOV	{"email": "aromanov_1974@postgrespro.ru", "phone": "+70255338558"}
0005434824458	4B2198	9270 172371	SEMEN NAUMOV	{"email": "semen.naumov-1975@postgrespro.ru", "phone": "+70403695801"}
0005434824459	7D3666	9763 307291	RADIK ABRAMOV	{"email": "abramov.radik28081969@postgrespro.ru", "phone": "+70261601218"}
0005434824460	7D3666	1857 450354	VLADIMIR PAVLOV	{"email": "pavlov.vladimir.05031970@postgrespro.ru", "phone": "+70521972528"}
0005434824461	188A46	7696 340921	NATALYA ALEKSEEVA	{"phone": "+70360418117"}
0005434824462	7BFD59	1158 440273	DANILA KAZAKOV	{"phone": "+70929790597"}
0005434824463	7BFD59	2889 915027	POLINA ZHURAVLEVA	{"email": "polina-zhuravleva.04061970@postgrespro.ru", "phone": "+70332306144"}
0005434824464	5192FB	2663 517046	LARISA FOMINA	{"phone": "+70535911894"}
0005434824465	4F2953	5906 967351	NIKOLAY GAVRILOV	{"phone": "+70750840623"}
0005434824466	0395CA	7448 477552	VALERIYA DANILOVA	{"email": "valeriya.danilova-23031972@postgrespro.ru", "phone": "+70781849433"}
0005434824467	2D4D4E	7395 087339	ALBERT KARPOV	{"email": "karpov_albert_021970@postgrespro.ru", "phone": "+70836796956"}
0005434824468	851614	7723 101263	ALEKSANDR MAKSIMOV	{"email": "maksimov_aleksandr_1978@postgrespro.ru", "phone": "+70806741298"}
0005434824469	EB53D1	5098 504027	ELENA TROFIMOVA	{"phone": "+70886285494"}
0005434824470	2AEDA4	2681 149804	MARIYA TIKHONOVA	{"phone": "+70948597482"}
0005434824471	204923	7782 721950	ANNA KOLESNIKOVA	{"phone": "+70649258272"}
0005434824472	8E9268	7855 511926	OLGA GRISHINA	{"phone": "+70007426663"}
0005434824473	5F3249	7532 234340	ANDREY PETROV	{"email": "petrova.1981@postgrespro.ru", "phone": "+70965205757"}
0005434824474	33EA6D	4841 975126	ALEKSANDR GAVRILOV	{"email": "gavrilov-aleksandr-1962@postgrespro.ru", "phone": "+70974764270"}
0005434824475	480B70	8660 452486	SERGEY TIKHONOV	{"phone": "+70698465602"}
0005434824476	480B70	4971 455749	ANDREY IVANOV	{"email": "ivanov-andrey_1976@postgrespro.ru", "phone": "+70538092701"}
0005434824477	576024	0659 676567	SVETLANA ORLOVA	{"phone": "+70870202579"}
0005434824478	7664FF	9189 365727	PAVEL ZAKHAROV	{"email": "zakharov-pavel.25041970@postgrespro.ru", "phone": "+70828138166"}
0005434824479	D25B4A	6362 591563	LYUDMILA ALEKSEEVA	{"phone": "+70524421094"}
0005434824480	9451B0	0941 241633	TAMARA MEDVEDEVA	{"phone": "+70321122037"}
0005434824481	9451B0	6540 517455	SVETLANA NAZAROVA	{"phone": "+70737322785"}
0005434824482	C6239D	3615 838854	LYUDMILA ANDREEVA	{"phone": "+70722074340"}
0005434824483	205A0B	8976 618592	IRINA SERGEEVA	{"email": "sergeeva_irina.1974@postgrespro.ru", "phone": "+70147390344"}
0005434824484	205A0B	9512 450833	YURIY GRIGOREV	{"phone": "+70242353272"}
0005434824541	22F906	2414 475307	IRINA ZHURAVLEVA	{"phone": "+70993380388"}
0005434824485	205A0B	3643 345254	EGOR AFANASEV	{"email": "egor_afanasev.031976@postgrespro.ru", "phone": "+70607794435"}
0005434824486	6566C3	1527 137952	ALEKSANDR KUZMIN	{"phone": "+70906046508"}
0005434824487	B0DD8B	0028 717705	TATYANA MAKAROVA	{"phone": "+70499463252"}
0005434824488	57DAFB	0438 013696	MIKHAIL SCHERBAKOV	{"phone": "+70481670860"}
0005434824489	57DAFB	7660 733735	ALEKSEY KOROLEV	{"phone": "+70586121308"}
0005434824490	51506B	0531 721486	ALEKSANDR ZHUKOV	{"phone": "+70714070394"}
0005434824491	51506B	1301 315474	EKATERINA KUZNECOVA	{"phone": "+70279841854"}
0005434824492	51506B	7683 887376	YULIYA TIMOFEEVA	{"email": "timofeeva.yuliya15011969@postgrespro.ru", "phone": "+70761344338"}
0005434824493	95EBA3	0739 365324	ILMIRA EFREMOVA	{"email": "i_efremova-091970@postgrespro.ru", "phone": "+70135681552"}
0005434824494	A5391C	6591 398107	RAFAEL NAZAROV	{"email": "nazarov_r-1970@postgrespro.ru", "phone": "+70744450656"}
0005434824495	DC30B6	6977 952436	SERGEY VASILEV	{"phone": "+70198414599"}
0005434824496	A71B3C	6631 340211	IVAN FROLOV	{"email": "frolov_i29051971@postgrespro.ru", "phone": "+70891102666"}
0005434824497	048292	1760 487947	NATALYA OSIPOVA	{"phone": "+70536325847"}
0005434824498	048292	7790 756119	ANASTASIYA MAKAROVA	{"email": "anastasiyamakarova-06031974@postgrespro.ru", "phone": "+70640295812"}
0005434824499	A80BFB	6727 512933	ALEKSANDR MOISEEV	{"phone": "+70179548387"}
0005434824500	7AF317	8846 136889	MARINA BELOVA	{"email": "belova_m_06121975@postgrespro.ru", "phone": "+70904313599"}
0005434824501	051805	9833 688691	LYUBOV KOZLOVA	{"email": "kozlova-l-051972@postgrespro.ru", "phone": "+70016239848"}
0005434824502	051805	6116 847389	SVETLANA NESTEROVA	{"email": "nesterova.svetlana.121982@postgrespro.ru", "phone": "+70965929162"}
0005434824503	EDC2B6	8265 602877	NIKITA GERASIMOV	{"email": "nikita-gerasimov.12081977@postgrespro.ru", "phone": "+70612173677"}
0005434824504	1AFBD8	5950 979731	MARIYA TROFIMOVA	{"phone": "+70365380181"}
0005434824505	1AFBD8	5698 000779	OLGA KUZMINA	{"email": "o.kuzmina.06051970@postgrespro.ru", "phone": "+70168888422"}
0005434824506	0156A1	2473 947134	YULIYA KUZMINA	{"phone": "+70357460240"}
0005434824507	BAFDD6	9982 435338	GALINA ZOTOVA	{"phone": "+70868027049"}
0005434824508	BAFDD6	5962 879377	NIKOLAY NIKITIN	{"phone": "+70845023731"}
0005434824509	786AFA	5284 542164	NADEZHDA ZAYCEVA	{"email": "zayceva_n12091967@postgrespro.ru", "phone": "+70816870150"}
0005434824510	786AFA	3942 003361	ANDREY IVANOV	{"email": "ivanov.andrey-23051976@postgrespro.ru", "phone": "+70199847632"}
0005434824511	64E91E	4907 682579	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr_26081971@postgrespro.ru", "phone": "+70774974320"}
0005434824512	D7FBD9	6286 012758	ANNA SEMENOVA	{"email": "anna.semenova25121961@postgrespro.ru", "phone": "+70682570427"}
0005434824513	D7FBD9	9352 245044	IRINA MAKSIMOVA	{"phone": "+70754493695"}
0005434824514	E924B6	0013 965013	DANIIL FILIPPOV	{"email": "filippov_daniil101967@postgrespro.ru", "phone": "+70887918137"}
0005434824515	E924B6	6905 706966	ANNA LAZAREVA	{"phone": "+70683494702"}
0005434824516	5FB08A	5906 336375	DMITRIY CHERNOV	{"phone": "+70004175288"}
0005434824517	8D5904	5734 572790	SVETLANA LUKYANOVA	{"phone": "+70912874827"}
0005434824518	F0D8A4	4084 992527	ALEKSEY MOROZOV	{"email": "morozov.a.091972@postgrespro.ru", "phone": "+70964179364"}
0005434824519	138776	2534 061202	SVETLANA POPOVA	{"email": "popova.s-101980@postgrespro.ru", "phone": "+70790686925"}
0005434824520	D2963E	1878 800831	NIKOLAY VOLKOV	{"email": "volkov_n_09021968@postgrespro.ru", "phone": "+70195436810"}
0005434824521	AA2875	5792 489090	SERGEY NIKITIN	{"email": "nikitin-s08071969@postgrespro.ru", "phone": "+70422628587"}
0005434824522	8028F5	1742 030572	MARIYA FEDOROVA	{"phone": "+70847917944"}
0005434824523	8028F5	5830 722957	TATYANA LOGINOVA	{"phone": "+70076079278"}
0005434824524	0674CC	2699 699980	VLADIMIR FROLOV	{"email": "frolov-v.121977@postgrespro.ru", "phone": "+70968936319"}
0005434824525	0674CC	9474 131003	LYUBOV SERGEEVA	{"email": "lsergeeva.16111966@postgrespro.ru", "phone": "+70646403142"}
0005434824526	137211	1263 002603	ALEKSEY YAKOVLEV	{"email": "aleksey_yakovlev.111975@postgrespro.ru", "phone": "+70419834602"}
0005434824527	9BD1EC	8628 336256	SVETLANA FROLOVA	{"email": "s-frolova1973@postgrespro.ru", "phone": "+70706596237"}
0005434824528	9BD1EC	7630 304379	VIKTOR KOZLOV	{"phone": "+70179178874"}
0005434824529	9BD1EC	2175 243295	OLGA KOVALEVA	{"email": "kovaleva-o1972@postgrespro.ru", "phone": "+70188934079"}
0005434824530	E2DC42	9347 906788	VADIM MAKAROV	{"phone": "+70151069827"}
0005434824531	E2DC42	4764 910161	YURIY TARASOV	{"phone": "+70448862740"}
0005434824532	8716CC	2803 488541	SERGEY FILIPPOV	{"email": "filippov_sergey-021985@postgrespro.ru", "phone": "+70227712214"}
0005434824533	3C27B9	5694 771263	VASILIY CHERNOV	{"phone": "+70249790070"}
0005434824534	3C27B9	2179 684697	NADEZHDA FILATOVA	{"email": "n-filatova.031979@postgrespro.ru", "phone": "+70060393379"}
0005434824535	BFF8C5	3958 968871	NIKOLAY PAVLOV	{"phone": "+70320066777"}
0005434824536	BFF8C5	2031 049550	NINA IVANOVA	{"phone": "+70704085018"}
0005434824537	BFF8C5	7092 376492	EVGENIY EGOROV	{"email": "egorov.evgeniy-1977@postgrespro.ru", "phone": "+70741002811"}
0005434824538	79C764	8722 403645	LYUDMILA GORBUNOVA	{"email": "lyudmilagorbunova_011972@postgrespro.ru", "phone": "+70417974100"}
0005434824539	156CCB	1278 518109	NINA SMIRNOVA	{"email": "nsmirnova-1965@postgrespro.ru", "phone": "+70581808678"}
0005434824540	156CCB	6097 828972	DMITRIY PAVLOV	{"phone": "+70950430032"}
0005434824542	BDB121	8908 095552	IVAN MELNIKOV	{"email": "i_melnikov_06011976@postgrespro.ru", "phone": "+70834173088"}
0005434824543	CD2342	0500 637482	SERGEY SCHERBAKOV	{"phone": "+70290811589"}
0005434824544	988499	7147 276993	MARIYA MAKSIMOVA	{"phone": "+70431645517"}
0005434824545	14C4E3	1107 866762	ARINA BARANOVA	{"email": "baranova-arina.1965@postgrespro.ru", "phone": "+70955896362"}
0005434824546	14C4E3	6442 170234	VASILIY SAVELEV	{"email": "savelevv.051970@postgrespro.ru", "phone": "+70857905591"}
0005434824547	C575CF	6415 304235	KIRILL SCHERBAKOV	{"email": "scherbakov.kirill1976@postgrespro.ru", "phone": "+70190956754"}
0005434824548	D9EAB1	5750 593663	TATYANA TIKHONOVA	{"phone": "+70215941663"}
0005434824549	D9EAB1	4024 503603	EVDOKIYA ZHUKOVA	{"phone": "+70450552823"}
0005434824550	986782	8822 678734	MIKHAIL KUZNECOV	{"phone": "+70480270396"}
0005434824551	63C947	2811 651557	TATYANA ROMANOVA	{"phone": "+70975745099"}
0005434824552	F32F82	0796 124567	NIKOLAY ROMANOV	{"email": "nikolay.romanov.1974@postgrespro.ru", "phone": "+70870834104"}
0005434824553	F32F82	5569 654735	RUSLAN BARANOV	{"email": "baranov-r.1977@postgrespro.ru", "phone": "+70277083991"}
0005434824554	165E84	7059 061807	OLGA NOVIKOVA	{"phone": "+70987346361"}
0005434824555	165E84	4903 541995	OLEG NAZAROV	{"email": "oleg-nazarov1974@postgrespro.ru", "phone": "+70693984909"}
0005434824556	A4AC57	8456 788258	VIKTORIYA PETROVA	{"email": "viktoriyapetrova_12041965@postgrespro.ru", "phone": "+70382491204"}
0005434824557	E03AB1	1894 056563	OKSANA KOZLOVA	{"email": "o.kozlova.1970@postgrespro.ru", "phone": "+70569384984"}
0005434824558	8EB6FD	8072 261267	ELENA NIKIFOROVA	{"email": "e.nikiforova02091975@postgrespro.ru", "phone": "+70413637812"}
0005434824559	1B5EE8	0146 916437	TATYANA VOROBEVA	{"email": "vorobeva_t_011975@postgrespro.ru", "phone": "+70626813180"}
0005434824560	F89266	2375 641647	SERGEY MAKAROV	{"phone": "+70832455755"}
0005434824561	6B6C8D	3640 811422	NATALYA NIKIFOROVA	{"phone": "+70675650205"}
0005434824562	639D65	0308 284021	VALENTINA SAVELEVA	{"email": "valentina_saveleva-071965@postgrespro.ru", "phone": "+70825419707"}
0005434824563	A08250	1345 849252	ANDREY VASILEV	{"email": "andrey-vasilev1973@postgrespro.ru", "phone": "+70373351280"}
0005434824564	09C3B9	5592 055039	OLESYA ISAEVA	{"email": "isaevao-1980@postgrespro.ru", "phone": "+70581432918"}
0005434824565	66C58F	0874 830104	ZINAIDA SOLOVEVA	{"email": "soloveva_z-1968@postgrespro.ru", "phone": "+70723003739"}
0005434824566	66C58F	9599 004695	MARINA NIKOLAEVA	{"email": "nikolaeva.marina.101956@postgrespro.ru", "phone": "+70449235746"}
0005434824567	8521EB	2427 036564	NADEZHDA KAZAKOVA	{"phone": "+70565348873"}
0005434824568	9D0CC2	6833 604048	NINA SAVELEVA	{"email": "n.saveleva-1966@postgrespro.ru", "phone": "+70786425841"}
0005434824569	042903	0671 388369	NATALYA KONOVALOVA	{"email": "nkonovalova.06061953@postgrespro.ru", "phone": "+70120162903"}
0005434824570	042903	5851 064183	LARISA KUZNECOVA	{"email": "kuznecova.larisa_1978@postgrespro.ru", "phone": "+70380122572"}
0005434824571	102C04	9233 508340	VALENTINA IVANOVA	{"email": "ivanova-valentina11111984@postgrespro.ru", "phone": "+70502457851"}
0005434824572	102C04	4051 319345	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-e.021966@postgrespro.ru", "phone": "+70066835855"}
0005434824573	102C04	7217 322364	KLAVDIYA LEBEDEVA	{"email": "klavdiya.lebedeva.14071974@postgrespro.ru", "phone": "+70350494979"}
0005434824574	FE8EAF	3203 152234	GALINA FEDOROVA	{"email": "g-fedorova101970@postgrespro.ru", "phone": "+70746882572"}
0005434824575	6AAA73	3288 076269	ZOYA MEDVEDEVA	{"email": "zoya_medvedeva_021978@postgrespro.ru", "phone": "+70354558061"}
0005434824576	E865B0	7430 784882	VLADIMIR SCHERBAKOV	{"phone": "+70465356783"}
0005434824577	E865B0	3692 046722	ANASTASIYA LEBEDEVA	{"phone": "+70903950680"}
0005434824578	E3E5DD	9254 269698	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr28121966@postgrespro.ru", "phone": "+70732661536"}
0005434824579	E3E5DD	9130 430538	SVETLANA BORISOVA	{"phone": "+70964392752"}
0005434824580	B812D1	1243 261626	VALENTINA NAUMOVA	{"phone": "+70786853745"}
0005434824581	B812D1	2544 375239	SERGEY PAVLOV	{"email": "pavlov_s031975@postgrespro.ru", "phone": "+70637426385"}
0005434824582	705DB1	4041 761910	IRINA PETROVA	{"email": "ipetrova_1985@postgrespro.ru", "phone": "+70378931018"}
0005434824583	705DB1	6603 056109	IVAN POPOV	{"phone": "+70800494323"}
0005434824584	6AD67D	8629 730183	VALENTINA FADEEVA	{"phone": "+70685413826"}
0005434824585	6AD67D	4172 028733	ELIZAVETA VASILEVA	{"email": "elizaveta.vasileva-061968@postgrespro.ru", "phone": "+70717239935"}
0005434824586	F9913E	2999 718031	ALIYA EFIMOVA	{"phone": "+70643918776"}
0005434824587	F16D0B	2446 948543	DENIS VLASOV	{"email": "vlasov_d-17101970@postgrespro.ru", "phone": "+70850180185"}
0005434824588	F16D0B	9985 838943	NATALYA IVANOVA	{"phone": "+70621624334"}
0005434824589	67B8F0	0112 740899	SVETLANA ANDREEVA	{"email": "s_andreeva-1970@postgrespro.ru", "phone": "+70603734339"}
0005434824590	EA9718	3682 449674	VITALIY MIRONOV	{"email": "mironov.v1985@postgrespro.ru", "phone": "+70613913825"}
0005434824591	7A7CF4	6223 464468	PAVEL MIKHAYLOV	{"email": "p.mikhaylov.121974@postgrespro.ru", "phone": "+70475134980"}
0005434824592	F621BC	0475 330756	YAROSLAV BORISOV	{"email": "borisov_y.1965@postgrespro.ru", "phone": "+70966784592"}
0005434824593	F621BC	5456 391967	ELENA KALININA	{"phone": "+70764095978"}
0005434824594	DFEC57	6395 233017	NATALYA LEBEDEVA	{"phone": "+70648527463"}
0005434824595	E1B10F	3010 787254	OLEG ZAYCEV	{"phone": "+70729878762"}
0005434824596	E1B10F	2337 194241	DMITRIY VASILEV	{"email": "d-vasilev.1956@postgrespro.ru", "phone": "+70321540854"}
0005434824597	4F4FB0	9590 229235	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr-021972@postgrespro.ru", "phone": "+70705399048"}
0005434824598	4F4FB0	4591 505367	OLEG ABRAMOV	{"phone": "+70115738628"}
0005434824599	4F4FB0	5783 174492	DAMIR MAKAROV	{"email": "makarov-damir-111974@postgrespro.ru", "phone": "+70636588769"}
0005434824600	256B7E	6022 739406	ALEKSEY KONOVALOV	{"phone": "+70476487969"}
0005434824601	256B7E	6596 634084	ANTONINA ORLOVA	{"phone": "+70949411709"}
0005434824602	6C41C8	8846 825843	RUSLAN NAZAROV	{"phone": "+70269207994"}
0005434824603	6C41C8	5034 886930	ELENA PAVLOVA	{"phone": "+70283846660"}
0005434824604	6C41C8	2225 274077	ANNA MEDVEDEVA	{"email": "amedvedeva041970@postgrespro.ru", "phone": "+70614732171"}
0005434824605	E4D94F	1015 124276	ALEKSEY KUZNECOV	{"phone": "+70100840894"}
0005434824606	96C0E1	2577 640264	EKATERINA FROLOVA	{"email": "e.frolova_25111968@postgrespro.ru", "phone": "+70358255685"}
0005434824607	EE97F0	7371 966727	MIKHAIL TIMOFEEV	{"phone": "+70032884848"}
0005434824608	9F86AB	4840 219372	SERGEY FEDOTOV	{"email": "sergey.fedotov031976@postgrespro.ru", "phone": "+70921943669"}
0005434824609	9F86AB	2503 070095	IRINA NIKIFOROVA	{"phone": "+70152001063"}
0005434824610	A43366	1351 838708	AZAT KARPOV	{"email": "karpova_14101974@postgrespro.ru", "phone": "+70328420925"}
0005434824611	A43366	5174 859756	EDUARD KULIKOV	{"phone": "+70770350796"}
0005434824612	A43366	1808 491675	VLADIMIR ALEKSANDROV	{"email": "aleksandrov_vladimir_19101968@postgrespro.ru", "phone": "+70550875858"}
0005434824613	20D103	0392 958178	NINA MARTYNOVA	{"email": "n_martynova1967@postgrespro.ru", "phone": "+70390092894"}
0005434824614	20D103	3214 868442	VLADIMIR GRIGOREV	{"phone": "+70682984770"}
0005434824615	20D103	0417 677407	VALERIY SOROKIN	{"phone": "+70269885388"}
0005434824616	976945	7705 655849	ALEKSANDRA KALININA	{"email": "kalinina.a.08021972@postgrespro.ru", "phone": "+70536263588"}
0005434824617	8F27FC	6460 919921	YURIY ZAYCEV	{"phone": "+70319180902"}
0005434824618	6C016A	9336 193489	EVGENIYA PAVLOVA	{"email": "pavlova.e021979@postgrespro.ru", "phone": "+70734151002"}
0005434824619	5162DB	3993 270008	YANA PETROVA	{"email": "petrova.y.12091974@postgrespro.ru", "phone": "+70746220953"}
0005434824620	E1F540	8321 345752	ELENA FEDOROVA	{"email": "fedorova-e_121980@postgrespro.ru", "phone": "+70668281111"}
0005434824621	7118F3	5471 521292	SVETLANA POPOVA	{"email": "svetlana-popova_071983@postgrespro.ru", "phone": "+70124577688"}
0005434824622	DA2C83	0980 828601	TATYANA ZHUKOVA	{"phone": "+70996163825"}
0005434824623	4B8467	7840 099028	INNA MALYSHEVA	{"email": "malysheva.i21071968@postgrespro.ru", "phone": "+70172938392"}
0005434824626	19DD90	0732 196582	VALERIY YAKOVLEV	{"email": "yakovlev.v_1974@postgrespro.ru", "phone": "+70256255880"}
0005434824627	19DD90	8410 789106	VLADIMIR FROLOV	{"email": "frolovv_1972@postgrespro.ru", "phone": "+70376863646"}
0005434824628	398B1F	9670 819343	ALEKSANDR NAZAROV	{"phone": "+70024199079"}
0005434824629	DF19AD	5802 444368	MIKHAIL IVANOV	{"email": "ivanov-mikhail-07061977@postgrespro.ru", "phone": "+70443838728"}
0005434824630	F6F2BF	2723 728858	EKATERINA MIRONOVA	{"email": "e_mironova_061969@postgrespro.ru", "phone": "+70901814630"}
0005434824631	9C3E29	1084 336079	DMITRIY VOLKOV	{"email": "d.volkov101971@postgrespro.ru", "phone": "+70750585783"}
0005434824632	9C3E29	0025 751699	ALEKSANDR ZAKHAROV	{"email": "a.zakharov091972@postgrespro.ru", "phone": "+70478489282"}
0005434824633	39FE94	9600 287908	SVETLANA PETROVA	{"phone": "+70174386521"}
0005434824634	D21AFB	5008 503470	TATYANA NESTEROVA	{"email": "tatyana_nesterova.081978@postgrespro.ru", "phone": "+70518582028"}
0005434824635	D2CCC7	2568 832860	LYUDMILA IVANOVA	{"phone": "+70374763760"}
0005434824636	D2CCC7	5606 813630	EGOR MAKSIMOV	{"phone": "+70375815132"}
0005434824637	2724C3	8155 859266	OKSANA EGOROVA	{"phone": "+70205601064"}
0005434824638	275037	1310 515599	VALENTINA SERGEEVA	{"phone": "+70251385361"}
0005434824639	66FC5B	5819 403558	YULIYA ZAKHAROVA	{"phone": "+70079189384"}
0005434824640	3F7425	6018 477709	VALERIY SCHERBAKOV	{"phone": "+70382647750"}
0005434824641	3F7425	5537 999056	VIKTOR ABRAMOV	{"email": "abramov.v_24081960@postgrespro.ru", "phone": "+70324723831"}
0005434824642	6C9B07	4166 935403	ZINAIDA NESTEROVA	{"phone": "+70409866832"}
0005434824643	8CF6FA	9336 991916	ARTUR EGOROV	{"email": "egorov.a.1960@postgrespro.ru", "phone": "+70184327837"}
0005434824644	8CF6FA	3535 852236	VASILIY FOMIN	{"phone": "+70673574065"}
0005434824645	8C80B2	8076 824148	ALEKSEY ANDREEV	{"email": "andreevaleksey081972@postgrespro.ru", "phone": "+70023388096"}
0005434824646	8C80B2	0449 793628	KONSTANTIN DENISOV	{"email": "denisov-k_28101972@postgrespro.ru", "phone": "+70892537756"}
0005434824647	595B57	9715 131598	MAKSIM FROLOV	{"phone": "+70323703299"}
0005434824648	C8E030	1265 613053	TIGRAN NOVIKOV	{"email": "novikov-t1973@postgrespro.ru", "phone": "+70908361172"}
0005434824649	C8E030	3571 675116	NIKOLAY YAKOVLEV	{"phone": "+70082952137"}
0005434824650	55135F	1755 680060	NINA YUDINA	{"phone": "+70062962963"}
0005434824651	55135F	2674 924736	MAKSIM SOKOLOV	{"phone": "+70272049488"}
0005434824652	3B9A0A	8756 944852	RAFAEL MAKAROV	{"phone": "+70980301320"}
0005434824653	3B9A0A	9899 434182	ALEKSEY KRASNOV	{"email": "krasnov.a.26111974@postgrespro.ru", "phone": "+70158879474"}
0005434824654	480277	3327 233864	OLGA GERASIMOVA	{"phone": "+70378265125"}
0005434824655	62932C	4353 013123	VIKTOR SAVELEV	{"phone": "+70151871639"}
0005434824656	62932C	5517 411774	ALEKSEY NIKITIN	{"email": "a-nikitin111974@postgrespro.ru", "phone": "+70429166073"}
0005434824657	62932C	6442 832483	ELIZAVETA BELOVA	{"phone": "+70075378785"}
0005434824658	295189	3761 804526	IGOR SEMENOV	{"phone": "+70261011357"}
0005434824659	CF0D84	9952 421225	SERGEY KOROLEV	{"email": "s.korolev28121981@postgrespro.ru", "phone": "+70355106981"}
0005434824660	7AB7ED	3224 344180	VALENTIN SCHERBAKOV	{"phone": "+70248779587"}
0005434824661	80A685	5731 319291	NATALYA BORISOVA	{"phone": "+70155955512"}
0005434824662	993C82	6878 426523	ANZHELIKA RYABOVA	{"phone": "+70278646324"}
0005434824663	2A9ADD	9340 860871	KIRILL MIKHAYLOV	{"email": "mikhaylov.kirill111976@postgrespro.ru", "phone": "+70604582267"}
0005434824664	2A9ADD	1038 018822	ELENA STEPANOVA	{"phone": "+70722861729"}
0005434824665	14A0A6	0693 544752	OLGA FROLOVA	{"phone": "+70819199301"}
0005434824666	0B59D7	9447 458075	ANDREY NAUMOV	{"phone": "+70099021975"}
0005434824667	7A1417	1830 941021	KSENIYA KOLESNIKOVA	{"phone": "+70602830056"}
0005434824668	7A1417	4988 256056	RAISA KUZNECOVA	{"email": "kuznecovar-081975@postgrespro.ru", "phone": "+70202711811"}
0005434824669	7A1417	0826 062067	LYUBOV MIKHAYLOVA	{"email": "lmikhaylova_031979@postgrespro.ru", "phone": "+70738502331"}
0005434824670	2C8CD7	4869 312518	SVETLANA ZHURAVLEVA	{"email": "svetlana-zhuravleva.021976@postgrespro.ru", "phone": "+70382027755"}
0005434824671	8F253E	2551 485246	VLADIMIR SAVELEV	{"email": "savelev-vladimir_041981@postgrespro.ru", "phone": "+70458474139"}
0005434824672	748D2B	2390 046882	SERGEY KUZNECOV	{"email": "kuznecov_sergey.07061972@postgrespro.ru", "phone": "+70192961718"}
0005434824673	748D2B	8839 393087	MARINA KULIKOVA	{"email": "kulikova-marina-1972@postgrespro.ru", "phone": "+70295808028"}
0005434824674	4BFA5E	9130 060884	IGOR FEDOROV	{"phone": "+70825153020"}
0005434824675	04F7AD	4160 263077	POLINA OSIPOVA	{"email": "posipova_1974@postgrespro.ru", "phone": "+70812779566"}
0005434824676	E476A7	4172 118534	ALEKSEY NIKITIN	{"email": "a.nikitin-20021971@postgrespro.ru", "phone": "+70220653552"}
0005434824677	E476A7	8368 026654	MARIYA MELNIKOVA	{"email": "m_melnikova.1984@postgrespro.ru", "phone": "+70614013562"}
0005434824678	D0D82A	1156 947060	TIMUR MOISEEV	{"email": "moiseevtimur-021955@postgrespro.ru", "phone": "+70522767283"}
0005434824679	D72C32	8603 737543	NINA FILIPPOVA	{"phone": "+70900848179"}
0005434824680	F0CFF0	1184 413189	VLADIMIR EGOROV	{"email": "egorovv.06081969@postgrespro.ru", "phone": "+70499322473"}
0005434824681	A8E661	0423 889311	SOFIYA LUKYANOVA	{"phone": "+70805204263"}
0005434824682	737EB0	4465 588938	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov-03061972@postgrespro.ru", "phone": "+70657605590"}
0005434824683	737EB0	3726 505442	YURIY KRASNOV	{"email": "yuriy-krasnov_071973@postgrespro.ru", "phone": "+70368185532"}
0005434824684	A0F37A	4250 924992	NINA ZAKHAROVA	{"email": "zakharova-nina-1974@postgrespro.ru", "phone": "+70049133624"}
0005434824685	A0F37A	7021 261734	ALEKSEY SAVELEV	{"email": "alekseysavelev1977@postgrespro.ru", "phone": "+70631078724"}
0005434824686	38FB82	7151 806715	NIKOLAY VOLKOV	{"phone": "+70834405104"}
0005434824688	B5B559	8443 665838	VALERIY ABRAMOV	{"phone": "+70376544397"}
0005434824689	B5B559	5277 829510	GALINA FADEEVA	{"phone": "+70114503732"}
0005434824690	A38680	9696 175281	OLGA ZHUKOVA	{"email": "ozhukova_1964@postgrespro.ru", "phone": "+70909473423"}
0005434824691	DD4A02	3812 095801	ANATOLIY IVANOV	{"phone": "+70690976381"}
0005434824692	6BCBE1	4212 790165	TATYANA NIKIFOROVA	{"email": "nikiforovat_1965@postgrespro.ru", "phone": "+70425404437"}
0005434824693	A263A5	1814 945923	OLGA MAKAROVA	{"email": "makarova_o_20021974@postgrespro.ru", "phone": "+70354040439"}
0005434824694	6A40DD	5293 409654	VLADIMIR IVANOV	{"phone": "+70981918384"}
0005434824695	A4C3D2	6536 607865	EVGENIY EGOROV	{"email": "egorove1970@postgrespro.ru", "phone": "+70729701834"}
0005434824696	B8B3C4	1201 437864	IRINA SAVELEVA	{"email": "savelevairina.1977@postgrespro.ru", "phone": "+70446038901"}
0005434824697	DBD1EC	4870 531593	OLGA YAKOVLEVA	{"email": "olga-yakovleva22081968@postgrespro.ru", "phone": "+70875733944"}
0005434824698	A248A9	2642 655078	LYUBOV SERGEEVA	{"email": "sergeeva-l.1968@postgrespro.ru", "phone": "+70538080524"}
0005434824699	A248A9	3817 235493	ZINAIDA SEMENOVA	{"phone": "+70740400157"}
0005434824700	696878	1442 787138	ANNA LUKYANOVA	{"phone": "+70604363870"}
0005434824701	696878	9442 062594	ARTUR IVANOV	{"phone": "+70849255781"}
0005434824702	244448	3441 931113	MIKHAIL KRASNOV	{"email": "krasnov.mikhail_101970@postgrespro.ru", "phone": "+70541854462"}
0005434824703	244448	7878 863143	VALENTINA DMITRIEVA	{"email": "dmitrievav-011976@postgrespro.ru", "phone": "+70255593684"}
0005434824704	FE64E9	5369 565496	FEDOR KAZAKOV	{"email": "fedor_kazakov.1972@postgrespro.ru", "phone": "+70226283901"}
0005434824705	C66E70	3535 490123	LYUDMILA KOZLOVA	{"phone": "+70708050824"}
0005434824706	C66E70	9529 230205	PETR MAKAROV	{"email": "petr_makarov-01081960@postgrespro.ru", "phone": "+70870732837"}
0005434824707	A72323	8213 987849	ELENA ISAEVA	{"phone": "+70191356941"}
0005434824708	E1F8FE	8592 547432	VERA AFANASEVA	{"email": "v_afanaseva.11101976@postgrespro.ru", "phone": "+70586754426"}
0005434824709	5FC9BC	6027 302589	ELVIRA TIKHONOVA	{"email": "e-tikhonova-051969@postgrespro.ru", "phone": "+70144009366"}
0005434824710	18098E	2963 008080	DMITRIY FEDOROV	{"email": "dmitriy-fedorov1974@postgrespro.ru", "phone": "+70141851033"}
0005434824711	18098E	6924 705769	ARTEM GORBUNOV	{"phone": "+70103870481"}
0005434824712	88EEB3	3041 231392	IRINA BORISOVA	{"email": "irina_borisova-071986@postgrespro.ru", "phone": "+70614954884"}
0005434824713	88EEB3	4341 211507	SERGEY SAVELEV	{"email": "savelev-sergey.1974@postgrespro.ru", "phone": "+70925157263"}
0005434824714	88EEB3	5627 158984	OLEG TIMOFEEV	{"email": "otimofeev071981@postgrespro.ru", "phone": "+70508205932"}
0005434824715	D46D53	3847 838282	EKATERINA VASILEVA	{"phone": "+70948326075"}
0005434824716	D46D53	5217 773150	MIKHAIL SAVELEV	{"phone": "+70733105027"}
0005434824717	57106A	4604 902289	ANATOLIY NOVIKOV	{"email": "anatoliy-novikov-111967@postgrespro.ru", "phone": "+70528076095"}
0005434824718	8D2283	2678 808354	VALENTINA ZOTOVA	{"phone": "+70878190115"}
0005434824719	22DE1D	6555 370910	ALEKSANDR KULIKOV	{"email": "kulikova041976@postgrespro.ru", "phone": "+70393222602"}
0005434824720	40BDB5	5475 025519	IVAN GUSEV	{"email": "i_gusev_1972@postgrespro.ru", "phone": "+70897721575"}
0005434824721	40BDB5	6803 229375	ELIZAVETA KOROLEVA	{"email": "koroleva.e_22101975@postgrespro.ru", "phone": "+70575685793"}
0005434824722	3201EF	0342 894685	LARISA ALEKSANDROVA	{"email": "l-aleksandrova1963@postgrespro.ru", "phone": "+70341276855"}
0005434824723	F29623	2107 883480	ANVAR STEPANOV	{"phone": "+70205881918"}
0005434824724	4A5E83	0153 431427	TATYANA BOGDANOVA	{"email": "bogdanova_tatyana.16041976@postgrespro.ru", "phone": "+70366302914"}
0005434824725	4A5E83	1965 531892	RAISA FROLOVA	{"phone": "+70689583416"}
0005434824726	61C32C	1889 062064	VALERIY GERASIMOV	{"email": "gerasimov_valeriy_081966@postgrespro.ru", "phone": "+70886350248"}
0005434824727	61C32C	7907 978659	VIKTOR RODIONOV	{"email": "rodionov_viktor-1967@postgrespro.ru", "phone": "+70022502066"}
0005434824728	61C32C	6275 526353	EVGENIY SERGEEV	{"email": "sergeev.evgeniy1974@postgrespro.ru", "phone": "+70527234533"}
0005434824729	F7DB35	4987 947476	VALENTINA RODIONOVA	{"phone": "+70157457088"}
0005434824730	F7DB35	0039 078628	VITALIY ILIN	{"email": "ilin.vitaliy-13101965@postgrespro.ru", "phone": "+70185656997"}
0005434824731	0DDF34	6881 310985	MARIYA KUZNECOVA	{"phone": "+70254963489"}
0005434824732	0DDF34	6117 013100	SVETLANA VOROBEVA	{"phone": "+70683675351"}
0005434824733	513B1E	7833 369131	PAVEL MIKHAYLOV	{"phone": "+70231012867"}
0005434824734	2F3F41	0273 778832	IRINA KUZMINA	{"email": "kuzmina-i.28121959@postgrespro.ru", "phone": "+70553350573"}
0005434824735	2F3F41	6257 995229	ALEKSEY NIKITIN	{"phone": "+70368773076"}
0005434824736	239EF8	0610 784631	TATYANA SOKOLOVA	{"phone": "+70726807155"}
0005434824737	3B478B	8668 641587	VLADIMIR BONDARENKO	{"email": "vladimir-bondarenko-01031965@postgrespro.ru", "phone": "+70932999095"}
0005434824738	3B478B	7005 717991	ELMIRA DMITRIEVA	{"phone": "+70462522254"}
0005434824739	A73013	5682 918788	MAKSIM GRIGOREV	{"email": "grigorev-m-1973@postgrespro.ru", "phone": "+70251419050"}
0005434824740	6AB071	4428 960702	ALEKSANDRA IVANOVA	{"phone": "+70656769167"}
0005434824741	8E9208	5823 145378	DMITRIY SHEVCHENKO	{"phone": "+70219137299"}
0005434824742	8E9208	1734 613471	YULIYA GAVRILOVA	{"phone": "+70360658560"}
0005434824743	255556	0097 896012	ELENA ABRAMOVA	{"email": "abramova-e.02031972@postgrespro.ru", "phone": "+70455466613"}
0005434824744	94D3FF	4597 028086	IRINA MASLOVA	{"phone": "+70604613886"}
0005434824745	F84E2B	0786 007849	ALEKSANDR NAUMOV	{"email": "aleksandr-naumov_1974@postgrespro.ru", "phone": "+70526217530"}
0005434824746	216E49	7568 908697	EKATERINA ZAKHAROVA	{"email": "ekaterina_zakharova_11021968@postgrespro.ru", "phone": "+70575685706"}
0005434824747	EB3B9A	6300 026740	IVAN NAUMOV	{"phone": "+70949510751"}
0005434824748	EB3B9A	2725 851242	VLADIMIR KOZLOV	{"email": "kozlov-vladimir031972@postgrespro.ru", "phone": "+70009398186"}
0005434824749	EB3B9A	6910 761080	YURIY ABRAMOV	{"phone": "+70754285690"}
0005434824750	C820D8	7413 701016	MARIYA BELOVA	{"email": "belova_m-05051981@postgrespro.ru", "phone": "+70840209700"}
0005434824751	635FAD	4361 288740	SVETLANA ROMANOVA	{"phone": "+70596280034"}
0005434824752	635FAD	1937 325480	ANATOLIY EGOROV	{"phone": "+70920349958"}
0005434824753	E2D471	5764 192761	YURIY MAKAROV	{"email": "makarov.yuriy.031974@postgrespro.ru", "phone": "+70459863117"}
0005434824754	E2D471	2247 423508	EVGENIY FOMIN	{"phone": "+70872331041"}
0005434824755	BCC8E8	8381 953988	GENNADIY SMIRNOV	{"phone": "+70299505092"}
0005434824756	D6E7C1	0509 585568	TAMARA SOKOLOVA	{"email": "sokolova.t091975@postgrespro.ru", "phone": "+70184187977"}
0005434824757	D6E7C1	5925 731920	RUMIYA RODIONOVA	{"phone": "+70070524131"}
0005434824758	D6E7C1	3918 052868	ZOYA IVANOVA	{"phone": "+70648080246"}
0005434824759	329232	1740 712783	VITALIY GRIGOREV	{"phone": "+70508490917"}
0005434824760	B31EE5	1004 989435	VALENTINA ZAKHAROVA	{"email": "valentina-zakharova24081967@postgrespro.ru", "phone": "+70960003310"}
0005434824761	B31EE5	8426 631080	NATALIYA ALEKSEEVA	{"email": "nataliyaalekseeva-1970@postgrespro.ru", "phone": "+70409777821"}
0005434824762	DE578B	7426 984277	MARIYA MOROZOVA	{"phone": "+70885383160"}
0005434824763	DE578B	2977 222151	SERGEY SAVELEV	{"email": "savelev-sergey.1973@postgrespro.ru", "phone": "+70867591524"}
0005434824764	DE578B	4917 541447	SERGEY POPOV	{"email": "s.popov.1966@postgrespro.ru", "phone": "+70799102550"}
0005434824765	37F7F5	3676 768894	SERGEY BELOV	{"phone": "+70147633161"}
0005434824766	B1D863	9485 509245	LYUDMILA FADEEVA	{"email": "fadeeva.l-041972@postgrespro.ru", "phone": "+70593449552"}
0005434824767	B1D863	7132 918394	LYUDMILA CHERNOVA	{"phone": "+70150170156"}
0005434824768	072909	2020 409484	VIKTOR NIKITIN	{"email": "nikitin.v.011974@postgrespro.ru", "phone": "+70065918379"}
0005434824769	072909	9786 737753	EKATERINA ABRAMOVA	{"email": "abramovaekaterina041957@postgrespro.ru", "phone": "+70428792770"}
0005434824770	AC7AA0	8412 196046	MARINA RODIONOVA	{"email": "rodionova_m_081979@postgrespro.ru", "phone": "+70994064493"}
0005434824771	AC7AA0	1953 673504	NATALYA GAVRILOVA	{"phone": "+70692470386"}
0005434824772	9B838C	2667 473921	SVETLANA POPOVA	{"phone": "+70220760951"}
0005434824773	9B838C	4776 793131	EKATERINA BORISOVA	{"phone": "+70178587032"}
0005434824774	9B838C	5244 516850	GALINA PAVLOVA	{"phone": "+70538218822"}
0005434824775	9B838C	1594 731986	VITALIY BARANOV	{"email": "v_baranov04041968@postgrespro.ru", "phone": "+70464515527"}
0005434824776	B55E64	3521 469150	ANTONINA FROLOVA	{"email": "a.frolova18111972@postgrespro.ru", "phone": "+70615055302"}
0005434824777	C302A3	4211 770994	IVAN SAVELEV	{"email": "i-savelev111972@postgrespro.ru", "phone": "+70363430590"}
0005434824778	32772E	1354 182044	NIKOLAY BORISOV	{"email": "borisov_n07041970@postgrespro.ru", "phone": "+70140142101"}
0005434824779	32772E	5946 330451	DMITRIY GAVRILOV	{"phone": "+70909846699"}
0005434824780	7F4B55	8810 478358	SVETLANA EGOROVA	{"email": "egorovas_1959@postgrespro.ru", "phone": "+70836359630"}
0005434824781	00C679	5135 944378	IGOR SMIRNOV	{"email": "smirnov.igor_02081972@postgrespro.ru", "phone": "+70223020473"}
0005434824782	00C679	8736 145353	DIANA SOLOVEVA	{"email": "soloveva-diana1969@postgrespro.ru", "phone": "+70269217137"}
0005434824783	3B9051	6033 380121	YULIYA GERASIMOVA	{"phone": "+70865958271"}
0005434824784	A2FF37	0430 009345	NADEZHDA TARASOVA	{"phone": "+70570910959"}
0005434824785	A2FF37	1116 518049	ALENA KAZAKOVA	{"phone": "+70493259802"}
0005434824786	A2FF37	3107 698651	NIKOLAY VOLKOV	{"email": "volkov_n17071963@postgrespro.ru", "phone": "+70095404773"}
0005434824787	DD8B18	5074 374997	DANIIL NAUMOV	{"phone": "+70045248731"}
0005434824788	8B09AF	0742 337895	YULIYA IVANOVA	{"phone": "+70790861732"}
0005434824789	D9219B	8951 315426	TATYANA AFANASEVA	{"phone": "+70496484805"}
0005434824790	D9219B	7783 829217	ANASTASIYA SCHERBAKOVA	{"email": "a.scherbakova1979@postgrespro.ru", "phone": "+70324527570"}
0005434824791	09E906	9321 956858	EVDOKIYA NIKITINA	{"email": "nikitinaevdokiya061976@postgrespro.ru", "phone": "+70708385216"}
0005434824792	09E906	5172 944238	ROMAN SCHERBAKOV	{"phone": "+70165063197"}
0005434824793	E2967F	2331 728430	LYUBOV PETROVA	{"phone": "+70413489738"}
0005434824794	E2967F	8438 570188	OLGA GUSEVA	{"phone": "+70080954686"}
0005434824795	0D24A4	1361 489622	VIKTOR FROLOV	{"email": "v.frolov17091986@postgrespro.ru", "phone": "+70976871066"}
0005434824796	0DD9BE	2440 208911	EGOR PAVLOV	{"phone": "+70950278622"}
0005434824797	52B503	3117 117326	YURIY MAKAROV	{"phone": "+70200909387"}
0005434824798	3DD9BA	4139 921000	VERONIKA ZAYCEVA	{"email": "veronikazayceva.1963@postgrespro.ru", "phone": "+70935493377"}
0005434824799	54F147	6082 786896	OLEG KULIKOV	{"email": "kulikov.o.071954@postgrespro.ru", "phone": "+70829784957"}
0005434824800	4FAF57	3551 196637	NINA SEMENOVA	{"email": "semenovan.1959@postgrespro.ru", "phone": "+70783935962"}
0005434824801	7CE9BB	2703 973301	FLYURA ORLOVA	{"email": "flyura.orlova_101976@postgrespro.ru", "phone": "+70368356527"}
0005434824802	ECDC6B	3031 123866	ALEKSANDR POPOV	{"email": "popov_a_11091976@postgrespro.ru", "phone": "+70767186153"}
0005434824803	ECDC6B	6412 060138	SVETLANA SEMENOVA	{"email": "semenova.s_081971@postgrespro.ru", "phone": "+70780861228"}
0005434824804	01B650	2698 733376	ALEKSEY NOVIKOV	{"phone": "+70434737789"}
0005434824805	6FF6FD	8869 331933	ELENA BELYAEVA	{"phone": "+70835711259"}
0005434824806	6FF6FD	9730 945319	MARINA NESTEROVA	{"email": "nesterova-m_1971@postgrespro.ru", "phone": "+70435977053"}
0005434824807	18CCF4	0824 751998	ALEKSANDR ANDREEV	{"phone": "+70461018009"}
0005434824808	A7FFFF	0882 221512	SERGEY NIKOLAEV	{"phone": "+70032466008"}
0005434824809	D7D1A0	8093 709901	ANTON VOROBEV	{"email": "vorobev_a1973@postgrespro.ru", "phone": "+70312620829"}
0005434824810	D325C1	3766 611906	VALERIY SOROKIN	{"email": "sorokin-valeriy091961@postgrespro.ru", "phone": "+70852963816"}
0005434824811	D325C1	9645 723554	ALEKSANDR KONOVALOV	{"email": "a-konovalov1986@postgrespro.ru", "phone": "+70818032531"}
0005434824812	90BBD3	0484 294289	LYUDMILA SMIRNOVA	{"email": "smirnova.l.06021969@postgrespro.ru", "phone": "+70914232717"}
0005434824813	D17CC9	4913 381662	IRINA ROMANOVA	{"email": "irina_romanova.02101970@postgrespro.ru", "phone": "+70414884718"}
0005434824814	D17CC9	0098 677793	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.n031975@postgrespro.ru", "phone": "+70625649281"}
0005434824815	41D6C6	3895 275603	TATYANA MAKAROVA	{"email": "makarova-t06101965@postgrespro.ru", "phone": "+70032305340"}
0005434824816	1F5C4F	6406 125800	ELENA FEDOROVA	{"phone": "+70126732254"}
0005434824817	F45617	8353 491110	VALENTINA VASILEVA	{"email": "valentinavasileva.04111975@postgrespro.ru", "phone": "+70216034731"}
0005434824818	657622	8479 562015	ALEKSANDR GUSEV	{"email": "aleksandrgusev1986@postgrespro.ru", "phone": "+70217508490"}
0005434824819	FFFCCC	7930 809322	VENERA MARTYNOVA	{"email": "venera_martynova.1980@postgrespro.ru", "phone": "+70972575913"}
0005434824820	FFFCCC	9088 140735	NATALYA GRISHINA	{"email": "grishina_n.1986@postgrespro.ru", "phone": "+70290236273"}
0005434824821	24ECC3	0617 196623	EVGENIYA SEMENOVA	{"phone": "+70401590628"}
0005434824822	24ECC3	9779 175727	KONSTANTIN ISAEV	{"email": "isaevkonstantin_071966@postgrespro.ru", "phone": "+70011590261"}
0005434824823	462D75	5848 285968	VASILIY MATVEEV	{"phone": "+70120721636"}
0005434824824	4257B6	8933 201309	MAKSIM NIKOLAEV	{"phone": "+70031171417"}
0005434824825	17D5E0	3143 626718	ANASTASIYA AKIMOVA	{"email": "anastasiya_akimova21111973@postgrespro.ru", "phone": "+70760322887"}
0005434824826	17D5E0	1839 989011	ARSEN ZAKHAROV	{"phone": "+70239572679"}
0005434824827	C31BB1	1417 535811	VALERIY NIKOLAEV	{"email": "nikolaev.v_11041968@postgrespro.ru", "phone": "+70435506784"}
0005434824828	E519D0	4118 472623	NIKITA DMITRIEV	{"email": "dmitrievnikita-081964@postgrespro.ru", "phone": "+70641908065"}
0005434824829	2732B8	4695 281759	LARISA POPOVA	{"phone": "+70146718534"}
0005434824830	A87B6E	4570 087358	VALENTINA BOGDANOVA	{"phone": "+70182476803"}
0005434824831	A87B6E	2268 514591	GEORGIY MAKAROV	{"email": "g.makarov_1976@postgrespro.ru", "phone": "+70554900344"}
0005434824832	E99A2C	6864 954316	ELENA KUZNECOVA	{"phone": "+70789581406"}
0005434824833	349B7E	1134 097732	MAKSIM SOLOVEV	{"phone": "+70222609460"}
0005434824834	AF0758	7951 288804	YULIYA ANISIMOVA	{"email": "yuliya.anisimova_011977@postgrespro.ru", "phone": "+70244123763"}
0005434824835	AF0758	9609 665424	ELENA FROLOVA	{"phone": "+70409629368"}
0005434824836	E6441A	2788 345379	EDUARD CHERNOV	{"email": "chernov-eduard_021975@postgrespro.ru", "phone": "+70054838947"}
0005434824837	990801	2059 460284	NIKOLAY GUSEV	{"phone": "+70727132871"}
0005434824838	0E4DC0	9968 346883	ALEKSANDRA POPOVA	{"email": "popovaaleksandra-031964@postgrespro.ru", "phone": "+70860824945"}
0005434824839	0E4DC0	8911 046279	NATALYA DANILOVA	{"phone": "+70765442275"}
0005434824840	18FE70	6664 634408	ALEKSEY ANTONOV	{"email": "aantonov09031981@postgrespro.ru", "phone": "+70155054270"}
0005434824841	18FE70	8030 349300	EKATERINA LUKYANOVA	{"email": "e_lukyanova-1967@postgrespro.ru", "phone": "+70339265587"}
0005434824842	66C3D0	0827 520240	OLGA ILINA	{"phone": "+70744996679"}
0005434824843	35C9D3	8463 888413	IVAN MIRONOV	{"email": "mironov_i_121966@postgrespro.ru", "phone": "+70748951484"}
0005434824844	35C9D3	6589 395863	SERGEY MIRONOV	{"phone": "+70152642074"}
0005434824845	BD19F2	1952 407370	ALEKSEY SEMENOV	{"email": "a-semenov.101973@postgrespro.ru", "phone": "+70033685928"}
0005434824846	A61223	8050 478416	ILYA MOROZOV	{"email": "ilya-morozov-101981@postgrespro.ru", "phone": "+70375955858"}
0005434824847	A61223	5836 044532	SERGEY ROMANOV	{"email": "romanov_s.19041967@postgrespro.ru", "phone": "+70721041611"}
0005434824848	399F6E	5376 490896	ALEKSEY KUZNECOV	{"email": "akuznecov_1975@postgrespro.ru", "phone": "+70681043883"}
0005434824849	61F6B8	0791 603726	MARINA IVANOVA	{"email": "ivanova_m_1971@postgrespro.ru", "phone": "+70020486452"}
0005434824850	61F6B8	7421 803088	LYUDMILA FEDOROVA	{"phone": "+70262353306"}
0005434824851	F6A98B	8864 045730	ANDREY SEMENOV	{"phone": "+70602662017"}
0005434824852	9439B4	5547 768755	ALEKSANDR SMIRNOV	{"phone": "+70731505170"}
0005434824853	B654F2	5274 851121	ANDREY VOLKOV	{"email": "andrey.volkov-1982@postgrespro.ru", "phone": "+70123185011"}
0005434824854	B654F2	0583 854313	ANGELINA POLYAKOVA	{"phone": "+70187151104"}
0005434824855	F0E565	0037 445652	OKSANA DENISOVA	{"email": "denisova-oksana_1977@postgrespro.ru", "phone": "+70551815581"}
0005434824856	86805F	4896 084210	ALEKSANDR GRIGOREV	{"phone": "+70964252871"}
0005434824857	D7F1BB	5323 879812	IRINA FILATOVA	{"phone": "+70668745247"}
0005434824858	D7F1BB	0646 873768	STEPAN PAVLOV	{"phone": "+70451333711"}
0005434824859	7290B2	2584 084239	GENNADIY STEPANOV	{"email": "stepanovgennadiy13011963@postgrespro.ru", "phone": "+70817194255"}
0005434824860	9486EA	2491 405493	ELENA SEMENOVA	{"phone": "+70277069162"}
0005434824861	C5D368	2694 512347	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_071971@postgrespro.ru", "phone": "+70866197315"}
0005434824862	C5D368	9196 624997	NINA TROFIMOVA	{"email": "n-trofimova_25021966@postgrespro.ru", "phone": "+70402837178"}
0005434824863	8594D5	5970 882232	MAKSIM IVANOV	{"email": "ivanov-maksim-21011979@postgrespro.ru", "phone": "+70612209319"}
0005434824864	7828B0	7275 210099	IGOR RODIONOV	{"phone": "+70022443106"}
0005434824865	8D3F83	1184 992779	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr21121966@postgrespro.ru", "phone": "+70014886774"}
0005434824866	B16753	4686 196079	IRINA VOLKOVA	{"phone": "+70459712549"}
0005434824867	BD0DA3	5332 427956	VYACHESLAV DENISOV	{"email": "denisov-vyacheslav-121976@postgrespro.ru", "phone": "+70509235841"}
0005434824868	BD0DA3	3993 821237	NADEZHDA EGOROVA	{"email": "egorova.nadezhda_121969@postgrespro.ru", "phone": "+70642795593"}
0005434824869	4A4182	6668 288488	VADIM VOROBEV	{"email": "vorobev_vadim-1980@postgrespro.ru", "phone": "+70436611301"}
0005434824870	4A4182	5104 314243	NATALYA ABRAMOVA	{"email": "abramova-natalya_29121973@postgrespro.ru", "phone": "+70047037535"}
0005434824871	287655	6094 218191	VLADIMIR KULIKOV	{"email": "kulikov_vladimir_1973@postgrespro.ru", "phone": "+70264463521"}
0005434824930	561FDE	3270 194112	GALINA MATVEEVA	{"phone": "+70306234487"}
0005434824872	4F0618	2778 476999	ALEKSANDR ROMANOV	{"email": "aleksandr.romanov.06081969@postgrespro.ru", "phone": "+70969376264"}
0005434824873	709CA3	1798 111927	NATALYA SOKOLOVA	{"email": "n_sokolova_1969@postgrespro.ru", "phone": "+70000523102"}
0005434824874	06712F	5811 907649	ILGIZ KUZNECOV	{"email": "kuznecov_ilgiz11021983@postgrespro.ru", "phone": "+70878947257"}
0005434824875	20883C	5384 690886	VASILIY CHERNOV	{"email": "chernov.vasiliy1970@postgrespro.ru", "phone": "+70512740954"}
0005434824876	20883C	6971 076070	YURIY EGOROV	{"email": "egorov.yuriy.02061965@postgrespro.ru", "phone": "+70493507659"}
0005434824877	2468C3	4372 820111	EGOR KOROLEV	{"email": "koroleve07041968@postgrespro.ru", "phone": "+70286343244"}
0005434824878	A51DC7	6822 065201	VIKTOR FILIPPOV	{"email": "filippovv-041966@postgrespro.ru", "phone": "+70360034106"}
0005434824879	8E00D3	7590 910477	YURIY KUZNECOV	{"email": "kuznecovyuriy_23101982@postgrespro.ru", "phone": "+70589261899"}
0005434824880	E22BB8	2500 356444	ELENA NESTEROVA	{"phone": "+70276133446"}
0005434824881	4EE9CC	6128 950136	DARINA KUZNECOVA	{"email": "kuznecova-darina_19121979@postgrespro.ru", "phone": "+70993469088"}
0005434824882	4EE9CC	8554 286125	DARYA NIKIFOROVA	{"phone": "+70018573380"}
0005434824883	775533	9046 969066	ALEKSANDR PETROV	{"email": "petrov.aleksandr_1968@postgrespro.ru", "phone": "+70011272838"}
0005434824884	6D61EF	6186 270294	VARVARA KOROLEVA	{"phone": "+70233054132"}
0005434824885	6D61EF	4565 086732	VASILIY ISAEV	{"phone": "+70166662492"}
0005434824886	41D835	6511 952414	ARTEM KARPOV	{"email": "artem_karpov061974@postgrespro.ru", "phone": "+70874962625"}
0005434824887	1635C4	8568 849835	IVAN ANDREEV	{"phone": "+70248886735"}
0005434824888	1635C4	0665 560681	NIKITA SAVELEV	{"email": "n.savelev-091966@postgrespro.ru", "phone": "+70062732373"}
0005434824889	6FEF83	9869 228980	NATALYA KOVALEVA	{"phone": "+70376729934"}
0005434824890	6FEF83	3735 826989	TAISIYA MATVEEVA	{"email": "matveeva-taisiya071970@postgrespro.ru", "phone": "+70552775394"}
0005434824891	46A935	8120 927943	ALENA ERMAKOVA	{"email": "ermakovaalena.29091985@postgrespro.ru", "phone": "+70792854214"}
0005434824892	4DFD69	3209 097127	EKATERINA LOGINOVA	{"phone": "+70720430972"}
0005434824893	9AA1F4	7661 480787	RENAT ZHUKOV	{"phone": "+70089742680"}
0005434824894	1DA9A5	1214 969804	MARIYA MOISEEVA	{"phone": "+70070909005"}
0005434824895	1DA9A5	6418 722897	NINA SOKOLOVA	{"phone": "+70401842017"}
0005434824896	DBBCB4	3900 188915	ALINA KAZAKOVA	{"email": "a_kazakova.08081984@postgrespro.ru", "phone": "+70422153610"}
0005434824897	DBBCB4	0834 440139	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav-20051978@postgrespro.ru", "phone": "+70083491105"}
0005434824898	47CA38	1846 758788	ANDREY IVANOV	{"phone": "+70360108213"}
0005434824899	826150	2075 450701	OLGA BARANOVA	{"email": "baranovaolga-18041968@postgrespro.ru", "phone": "+70770368598"}
0005434824900	4074CC	1071 332391	VIKTOR ABRAMOV	{"email": "viktor-abramov_051970@postgrespro.ru", "phone": "+70377678404"}
0005434824901	6B0A4B	0342 145730	VLADIMIR IVANOV	{"phone": "+70935201070"}
0005434824902	D19BE3	5397 289987	MATVEY MIKHAYLOV	{"email": "mikhaylovmatvey_1975@postgrespro.ru", "phone": "+70475612001"}
0005434824903	46BB55	8595 394987	ZINAIDA POTAPOVA	{"email": "potapovazinaida-24011979@postgrespro.ru", "phone": "+70398978908"}
0005434824904	EE02E7	6190 480712	ALEKSANDR ILIN	{"phone": "+70424413749"}
0005434824905	EE02E7	0239 421053	VERA DAVYDOVA	{"email": "davydova-v.04061977@postgrespro.ru", "phone": "+70169934051"}
0005434824906	94E955	5259 219485	INNA PETROVA	{"email": "inna.petrova.27061975@postgrespro.ru", "phone": "+70735243286"}
0005434824907	2E8003	3086 154045	ANNA SCHERBAKOVA	{"email": "anna-scherbakova_1973@postgrespro.ru", "phone": "+70153523664"}
0005434824908	EFBC15	8596 262727	ALEKSANDR FILIPPOV	{"phone": "+70737054471"}
0005434824909	E316DC	2802 473612	MARIYA NESTEROVA	{"email": "mnesterova.061961@postgrespro.ru", "phone": "+70446964304"}
0005434824910	E7AA0F	3659 397482	LYUBOV POTAPOVA	{"email": "l.potapova-061966@postgrespro.ru", "phone": "+70560122871"}
0005434824911	E7AA0F	9778 707743	NIKOLAY SOROKIN	{"phone": "+70479364925"}
0005434824912	394B00	7961 470808	ANASTASIYA MAKSIMOVA	{"email": "a_maksimova17091967@postgrespro.ru", "phone": "+70357144378"}
0005434824913	752040	1372 077612	VIKTORIYA EFIMOVA	{"email": "v-efimova_1962@postgrespro.ru", "phone": "+70296849934"}
0005434824914	752040	3441 788147	MATVEY FROLOV	{"email": "matvey-frolov-17051977@postgrespro.ru", "phone": "+70994210602"}
0005434824915	156A0B	0151 074221	VALERIY ILIN	{"email": "v-ilin_1980@postgrespro.ru", "phone": "+70936621648"}
0005434824916	1224A6	8679 539510	VALENTIN NAZAROV	{"phone": "+70191031367"}
0005434824917	0E9544	5905 727758	EKATERINA OSIPOVA	{"email": "osipova-e-23021976@postgrespro.ru", "phone": "+70877550785"}
0005434824918	285A44	4868 756102	VLADIMIR DAVYDOV	{"email": "davydov-vladimir-1979@postgrespro.ru", "phone": "+70303552818"}
0005434824919	285A44	5688 748053	ALEKSEY VASILEV	{"email": "a.vasilev-1966@postgrespro.ru", "phone": "+70623175552"}
0005434824920	285A44	5721 734031	ANATOLIY KISELEV	{"phone": "+70247017398"}
0005434824921	C59297	7744 337797	VIKTORIYA SEMENOVA	{"email": "viktoriya_semenova081963@postgrespro.ru", "phone": "+70464687533"}
0005434824922	16D6FE	8177 169391	ELENA GUSEVA	{"phone": "+70293919077"}
0005434824923	5A7B5E	9425 279898	TATYANA FROLOVA	{"phone": "+70470258178"}
0005434824924	31A92E	8541 507390	DMITRIY SMIRNOV	{"email": "d.smirnov.24121975@postgrespro.ru", "phone": "+70791203677"}
0005434824925	CA2547	1217 785984	TATYANA YAKOVLEVA	{"phone": "+70634599970"}
0005434824926	61C840	5948 750466	NATALYA DENISOVA	{"email": "natalya.denisova22011977@postgrespro.ru", "phone": "+70922051545"}
0005434824927	61C840	7654 048594	DMITRIY SCHERBAKOV	{"phone": "+70530718570"}
0005434824928	B3C255	8154 294325	GALINA KONDRATEVA	{"email": "galinakondrateva-1975@postgrespro.ru", "phone": "+70750591880"}
0005434824929	561FDE	9845 963565	NIKOLAY VLASOV	{"email": "nikolay-vlasov_31101978@postgrespro.ru", "phone": "+70177167965"}
0005434824931	75A364	2839 089191	ALEKSANDR FEDOROV	{"phone": "+70954951447"}
0005434824932	75A364	0196 150453	LYUBOV SIDOROVA	{"phone": "+70893141521"}
0005434824933	EE8750	6601 518810	SERGEY MELNIKOV	{"email": "smelnikov.1968@postgrespro.ru", "phone": "+70161440245"}
0005434824934	D573A2	3817 714744	VASILIY FEDOTOV	{"email": "v.fedotov_071964@postgrespro.ru", "phone": "+70163994711"}
0005434824935	528A9B	8182 509857	ALBINA GERASIMOVA	{"phone": "+70207308403"}
0005434824936	8382CE	5387 876662	TAMARA ZHUKOVA	{"phone": "+70851933108"}
0005434824937	8382CE	5483 051874	LARISA KUZNECOVA	{"phone": "+70806748741"}
0005434824938	76B5A7	8297 819972	TATYANA GAVRILOVA	{"phone": "+70088010577"}
0005434824939	128274	6608 649691	RADIK MELNIKOV	{"phone": "+70118864267"}
0005434824940	128274	9499 773580	ALEKSANDR POPOV	{"phone": "+70495243079"}
0005434824941	128274	7819 212308	TATYANA LEBEDEVA	{"email": "t-lebedeva-03061974@postgrespro.ru", "phone": "+70027595911"}
0005434824942	D883D7	4608 348463	TATYANA DAVYDOVA	{"phone": "+70457689969"}
0005434824943	D883D7	3901 134302	VALENTINA KOROLEVA	{"email": "koroleva-valentina-081981@postgrespro.ru", "phone": "+70379591224"}
0005434824944	D8F1EB	4325 528587	ALEKSEY IVANOV	{"email": "alekseyivanov031976@postgrespro.ru", "phone": "+70752034417"}
0005434824945	A8095F	1465 744107	VITALIY FOMIN	{"phone": "+70356001854"}
0005434824946	3A7826	2516 727663	NADEZHDA FEDOROVA	{"phone": "+70916977506"}
0005434824947	6DC787	8074 933480	NIKOLAY MARTYNOV	{"email": "martynov.n.17091974@postgrespro.ru", "phone": "+70284474288"}
0005434824948	6DC787	0690 805940	VYACHESLAV VOLKOV	{"email": "v-volkov_1978@postgrespro.ru", "phone": "+70331899567"}
0005434824949	AED461	2972 762065	VALERIY VASILEV	{"phone": "+70956503259"}
0005434824950	AED461	0006 962124	NATALYA KONDRATEVA	{"phone": "+70369483428"}
0005434824951	2FBA66	8277 403411	NATALYA ANISIMOVA	{"phone": "+70074901247"}
0005434824952	2FBA66	1665 770088	GENNADIY SIDOROV	{"phone": "+70471726052"}
0005434824953	60ACE6	4327 585701	LYUBOV OSIPOVA	{"phone": "+70333553876"}
0005434824954	60ACE6	9417 652872	SERGEY RODIONOV	{"phone": "+70508006456"}
0005434824955	60ACE6	0861 260823	OLEG FILIPPOV	{"email": "ofilippov-22071974@postgrespro.ru", "phone": "+70662670678"}
0005434824956	60ACE6	6650 694053	ANATOLIY ZAKHAROV	{"phone": "+70592590855"}
0005434824957	B1F906	0189 740988	ALEKSANDRA PAVLOVA	{"email": "pavlova_aleksandra_1980@postgrespro.ru", "phone": "+70844291237"}
0005434824958	B1F906	4031 866710	MARIYA GERASIMOVA	{"phone": "+70298920572"}
0005434824959	85ED80	3522 580141	ALEKSANDR MEDVEDEV	{"phone": "+70152260406"}
0005434824960	43B464	5731 714606	GENNADIY ISAEV	{"email": "gisaev19021963@postgrespro.ru", "phone": "+70685757760"}
0005434824961	2B7D5B	4921 339442	BORIS MIKHAYLOV	{"email": "borismikhaylov091977@postgrespro.ru", "phone": "+70186368764"}
0005434824962	2B7D5B	5386 707290	TATYANA EGOROVA	{"phone": "+70695397553"}
0005434824963	300009	6780 918058	NATALYA GAVRILOVA	{"phone": "+70196237351"}
0005434824964	E70E8A	1333 530878	VALENTINA MAKSIMOVA	{"phone": "+70154819524"}
0005434824965	E70E8A	5400 619633	IRINA EGOROVA	{"email": "irina.egorova.09121968@postgrespro.ru", "phone": "+70831962106"}
0005434824966	FE05A7	7491 272511	ALEKSANDR FEDOROV	{"email": "fedorova_28061969@postgrespro.ru", "phone": "+70744141461"}
0005434824967	0C4F34	1921 319399	VLADIMIR GORBUNOV	{"email": "vladimir_gorbunov-1981@postgrespro.ru", "phone": "+70368745167"}
0005434824968	8791E3	8222 084333	GRIGORIY OSIPOV	{"email": "g-osipov_12111976@postgrespro.ru", "phone": "+70338244758"}
0005434824969	417A30	0253 905846	OLGA BORISOVA	{"phone": "+70140136255"}
0005434824970	E230F0	7508 616061	GLEB BORISOV	{"phone": "+70207634533"}
0005434824971	34BFCE	2453 822667	IRINA KISELEVA	{"email": "irina.kiseleva.1964@postgrespro.ru", "phone": "+70043737036"}
0005434824972	3B1CF6	5973 887168	GALINA SIDOROVA	{"email": "sidorova.galina_1976@postgrespro.ru", "phone": "+70213444379"}
0005434824973	97412A	5088 237308	ALEKSANDR KUZMIN	{"phone": "+70252223402"}
0005434824974	886269	8365 197826	FEDOR AFANASEV	{"email": "afanasev.f1968@postgrespro.ru", "phone": "+70641248963"}
0005434824975	A1E139	4855 944159	GRIGORIY SOROKIN	{"phone": "+70259682460"}
0005434824976	4ADAA1	3507 615290	IRINA GAVRILOVA	{"phone": "+70025885013"}
0005434824977	D6D26E	2527 366792	IVAN BELOV	{"phone": "+70135924171"}
0005434824978	CFF56E	2868 221695	GUZEL GAVRILOVA	{"email": "g_gavrilova17061961@postgrespro.ru", "phone": "+70732823439"}
0005434824979	BB23F4	8799 627566	LYUBOV NOVIKOVA	{"email": "novikova.l.05061963@postgrespro.ru", "phone": "+70839197399"}
0005434824980	BB23F4	3057 971464	NINA KONDRATEVA	{"phone": "+70682130361"}
0005434824981	377CA7	4702 114744	VIKTORIYA DMITRIEVA	{"email": "v_dmitrieva071972@postgrespro.ru", "phone": "+70942058491"}
0005434824982	149F21	8971 837387	VALENTINA PETROVA	{"email": "petrova-valentina.021971@postgrespro.ru", "phone": "+70479745591"}
0005434824983	149F21	1760 914936	YURIY IVANOV	{"phone": "+70444088862"}
0005434824984	932D45	2833 394307	RAISA IVANOVA	{"email": "ivanova_raisa.13081975@postgrespro.ru", "phone": "+70059989332"}
0005434824985	932D45	9839 697924	NATALYA KARPOVA	{"phone": "+70719139349"}
0005434824986	AFB7D4	0628 784478	VADIM SCHERBAKOV	{"email": "scherbakov-vadim_111966@postgrespro.ru", "phone": "+70318571227"}
0005434824987	AFB7D4	7440 354994	ANDREY FEDOTOV	{"email": "fedotov_a28031981@postgrespro.ru", "phone": "+70448064790"}
0005434824988	4F11CB	7436 450741	ALEKSEY MOROZOV	{"email": "morozov.aleksey_09011982@postgrespro.ru", "phone": "+70617864615"}
0005434824989	4F11CB	5159 328777	DMITRIY KOROLEV	{"phone": "+70533497338"}
0005434824990	594920	6803 723787	NATALYA KUZNECOVA	{"phone": "+70015963699"}
0005434824991	693CDB	1018 122562	VYACHESLAV ZAYCEV	{"email": "v_zaycev_1977@postgrespro.ru", "phone": "+70349239468"}
0005434824992	D46E87	4300 873359	MIKHAIL BORISOV	{"phone": "+70928261947"}
0005434824993	D46E87	2397 251090	PRASKOVYA PETROVA	{"phone": "+70325690206"}
0005434824994	1055EC	9041 430902	MARAT KUDRYASHOV	{"email": "marat-kudryashov.1959@postgrespro.ru", "phone": "+70903732920"}
0005434824995	475170	7568 570717	GALINA KUZMINA	{"email": "kuzminag.1976@postgrespro.ru", "phone": "+70676551809"}
0005434824996	7C33C3	7304 541730	DMITRIY ANTONOV	{"email": "antonovdmitriy_051967@postgrespro.ru", "phone": "+70256423722"}
0005434824997	55ACC6	8048 102462	VERA ZHURAVLEVA	{"phone": "+70120606792"}
0005434824998	55ACC6	3457 131815	NATALYA ZAKHAROVA	{"phone": "+70300258478"}
0005434824999	914147	6820 833607	EKATERINA POPOVA	{"phone": "+70401997134"}
0005434825000	914147	7811 921767	ALEKSANDR VOLKOV	{"email": "volkov-a-101968@postgrespro.ru", "phone": "+70110974408"}
0005434825001	D10CAC	3773 267201	SVETLANA IVANOVA	{"email": "svetlana_ivanova011975@postgrespro.ru", "phone": "+70984770688"}
0005434825002	D10CAC	4087 779103	GALINA MIRONOVA	{"phone": "+70574217824"}
0005434825003	06F537	4078 981315	ALEKSANDRA ROMANOVA	{"phone": "+70996221442"}
0005434825004	06F537	6608 050828	SERGEY SMIRNOV	{"email": "s_smirnov-05111971@postgrespro.ru", "phone": "+70540151260"}
0005434825005	57721A	3202 763384	NATALYA EFREMOVA	{"email": "natalya-efremova.27021981@postgrespro.ru", "phone": "+70627140642"}
0005434825006	4625CD	6927 669256	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova-1978@postgrespro.ru", "phone": "+70164278422"}
0005434825007	4625CD	6952 368763	YURIY KUZNECOV	{"email": "y_kuznecov.011981@postgrespro.ru", "phone": "+70387919297"}
0005434825008	51EAA7	8709 619083	LIDIYA MELNIKOVA	{"phone": "+70947861061"}
0005434825009	D4EA02	3475 067633	EKATERINA KISELEVA	{"email": "kiseleva-e-021964@postgrespro.ru", "phone": "+70859516559"}
0005434825010	3FD74B	6683 648287	TATYANA VOROBEVA	{"email": "vorobeva.tatyana-1967@postgrespro.ru", "phone": "+70600612307"}
0005434825011	5D6DE8	3538 938605	NINA KULIKOVA	{"phone": "+70593250353"}
0005434825012	C83E80	0675 329434	ALEKSANDR KRASNOV	{"email": "aleksandr_krasnov031957@postgrespro.ru", "phone": "+70234304939"}
0005434825013	C83E80	3535 612123	DARINA ILINA	{"phone": "+70394462825"}
0005434825014	B9C0F7	6213 617618	MARGARITA LUKYANOVA	{"email": "m.lukyanova-18041972@postgrespro.ru", "phone": "+70636083868"}
0005434825015	D642DC	9126 865740	OLGA MELNIKOVA	{"phone": "+70697140413"}
0005434825016	DD0C1C	0735 348582	SVETLANA VASILEVA	{"email": "vasileva_s_1974@postgrespro.ru", "phone": "+70104713555"}
0005434825017	B91785	2109 753102	SVETLANA ANDREEVA	{"email": "andreeva.svetlana_1967@postgrespro.ru", "phone": "+70640936021"}
0005434825018	2FE2CA	0357 818026	MIKHAIL KUZMIN	{"email": "mikhail.kuzmin-15091970@postgrespro.ru", "phone": "+70235111858"}
0005434825019	621261	0804 922995	EVGENIY KRASNOV	{"phone": "+70474946017"}
0005434825020	621261	2367 836417	SERGEY EGOROV	{"email": "sergeyegorov_081976@postgrespro.ru", "phone": "+70145843710"}
0005434825021	F36A74	4619 335367	ANATOLIY MIRONOV	{"email": "mironov_a.14091967@postgrespro.ru", "phone": "+70608349496"}
0005434825022	BA7FD4	0190 005995	DMITRIY DENISOV	{"email": "dmitriy.denisov-091973@postgrespro.ru", "phone": "+70767468130"}
0005434825023	96ABE1	3490 096169	ELENA YAKOVLEVA	{"email": "yakovleva_e-031977@postgrespro.ru", "phone": "+70634819757"}
0005434825024	86E7F1	9732 780391	MARINA KARPOVA	{"email": "marina.karpova.23021965@postgrespro.ru", "phone": "+70761099907"}
0005434825025	9F5440	7175 090685	LYUBOV ZHURAVLEVA	{"email": "zhuravleva-lyubov_27091965@postgrespro.ru", "phone": "+70749988959"}
0005434825026	A39905	9888 240552	TATYANA VASILEVA	{"email": "tvasileva-1972@postgrespro.ru", "phone": "+70267568709"}
0005434825027	A39905	4366 124372	EKATERINA MAKSIMOVA	{"email": "ekaterinamaksimova_1958@postgrespro.ru", "phone": "+70402282881"}
0005434825028	14BBDE	9112 232412	MARIYA TIMOFEEVA	{"phone": "+70248551169"}
0005434825029	CD893D	3849 872747	DMITRIY KULIKOV	{"phone": "+70708656233"}
0005434825030	B7856D	0632 034394	DENIS OSIPOV	{"email": "denis.osipov_081969@postgrespro.ru", "phone": "+70897911708"}
0005434825031	B7856D	0679 012586	EKATERINA FROLOVA	{"email": "frolova_e091978@postgrespro.ru", "phone": "+70119540844"}
0005434825032	B7856D	6382 333554	MAKSIM VASILEV	{"phone": "+70272585918"}
0005434825033	C7E21F	9765 067629	MAKSIM CHERNOV	{"phone": "+70049536746"}
0005434825034	9D1ACA	9142 400423	NATALYA BARANOVA	{"phone": "+70971550923"}
0005434825035	9D1ACA	7966 992815	VALERIY ALEKSEEV	{"phone": "+70356379387"}
0005434825036	7AEF2A	4626 071847	MAKSIM KONOVALOV	{"phone": "+70091322421"}
0005434825037	3D8D5C	1893 069425	ELENA SERGEEVA	{"phone": "+70712456572"}
0005434825038	3D8D5C	3846 253300	YULIYA FILATOVA	{"phone": "+70157299899"}
0005434825039	0C2013	3479 638072	MAKSIM RODIONOV	{"email": "maksim_rodionov.1968@postgrespro.ru", "phone": "+70440716687"}
0005434825040	36A66C	2329 908876	IVAN MAKAROV	{"email": "imakarov-1964@postgrespro.ru", "phone": "+70788947526"}
0005434825041	461103	5129 544307	NINA VASILEVA	{"email": "nina_vasileva-23051974@postgrespro.ru", "phone": "+70408152319"}
0005434825042	47B35A	3258 565768	OKSANA KOROLEVA	{"email": "oksana.koroleva_1973@postgrespro.ru", "phone": "+70272940838"}
0005434825043	F97057	4047 400923	EVGENIY MAKAROV	{"email": "evgeniymakarov_1969@postgrespro.ru", "phone": "+70350402734"}
0005434825044	D3396C	9646 623018	ALEKSANDR SMIRNOV	{"email": "asmirnov_021981@postgrespro.ru", "phone": "+70292265021"}
0005434825045	E7CA3F	0089 621878	MARGARITA IVANOVA	{"email": "ivanovamargarita.101973@postgrespro.ru", "phone": "+70214636055"}
0005434825046	713EA6	9721 914042	KRISTINA SMIRNOVA	{"phone": "+70944347002"}
0005434825047	713EA6	9432 675008	VALENTINA EGOROVA	{"email": "egorovavalentina_07101960@postgrespro.ru", "phone": "+70700880459"}
0005434825048	31F5ED	0108 607785	LYUDMILA VASILEVA	{"email": "l-vasileva.16071981@postgrespro.ru", "phone": "+70868320469"}
0005434825049	31F5ED	1542 384875	MIKHAIL SCHERBAKOV	{"email": "mikhail.scherbakov-081980@postgrespro.ru", "phone": "+70441433371"}
0005434825050	58199A	4732 617633	MIKHAIL STEPANOV	{"phone": "+70603051554"}
0005434825051	61E6AB	9014 445137	TATYANA MELNIKOVA	{"email": "melnikova-tatyana_09031972@postgrespro.ru", "phone": "+70831219415"}
0005434825052	4D5B10	0559 859903	ASIYA IVANOVA	{"email": "asiya.ivanova.1977@postgrespro.ru", "phone": "+70123952312"}
0005434825053	4D5B10	4971 615440	LYUDMILA KONOVALOVA	{"email": "l-konovalova-29111975@postgrespro.ru", "phone": "+70713866707"}
0005434825054	4B38CE	0399 535195	DARYA NESTEROVA	{"email": "nesterova_d_1970@postgrespro.ru", "phone": "+70693105185"}
0005434825055	413385	0678 502820	TATYANA ILINA	{"phone": "+70674754872"}
0005434825056	181A5C	2650 870272	LYUBOV LEBEDEVA	{"email": "lebedeva.lyubov.1977@postgrespro.ru", "phone": "+70566425850"}
0005434825057	181A5C	3211 800391	ANATOLIY ROMANOV	{"email": "a-romanov.21121961@postgrespro.ru", "phone": "+70519966281"}
0005434825058	181A5C	7106 388250	ANATOLIY VASILEV	{"email": "anatoliyvasilev_101967@postgrespro.ru", "phone": "+70496722297"}
0005434825059	9AB69D	4776 176328	KSENIYA NIKITINA	{"email": "k.nikitina081973@postgrespro.ru", "phone": "+70204981270"}
0005434825060	9AB69D	3335 315610	ALEKSEY KUZNECOV	{"email": "a.kuznecov.11011973@postgrespro.ru", "phone": "+70194315232"}
0005434825061	D1718A	2778 558653	NINA KOROLEVA	{"phone": "+70945723800"}
0005434825062	8CB7F2	5916 910900	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr011968@postgrespro.ru", "phone": "+70571209216"}
0005434825063	F50EF6	9746 996156	ANDREY SERGEEV	{"email": "a_sergeev05091964@postgrespro.ru", "phone": "+70677439167"}
0005434825064	425A58	0473 695584	ANDREY KUZNECOV	{"email": "kuznecov-a-20061966@postgrespro.ru", "phone": "+70101630602"}
0005434825065	FD9074	0059 571755	ZLATA ALEKSANDROVA	{"email": "aleksandrova_z.031976@postgrespro.ru", "phone": "+70596947489"}
0005434825066	DA49AB	6867 485504	DANILA ZAYCEV	{"email": "dzaycev-03101974@postgrespro.ru", "phone": "+70431894273"}
0005434825067	FBEEC1	8866 781425	VYACHESLAV SAVELEV	{"email": "vyacheslavsavelev071964@postgrespro.ru", "phone": "+70778937581"}
0005434825068	34E3B2	6309 123582	ANATOLIY DENISOV	{"email": "denisov_anatoliy.1958@postgrespro.ru", "phone": "+70438243204"}
0005434825069	8F8FD6	8564 808245	DMITRIY IVANOV	{"phone": "+70923761552"}
0005434825070	8F8FD6	9564 036146	SVETLANA SOKOLOVA	{"email": "sokolova_svetlana.06071975@postgrespro.ru", "phone": "+70125628465"}
0005434825071	D558CA	6086 769826	LYUBOV KUZNECOVA	{"email": "kuznecova-lyubov_101967@postgrespro.ru", "phone": "+70044495126"}
0005434825072	873D4E	0008 442256	ALEKSEY DENISOV	{"email": "adenisov-06091978@postgrespro.ru", "phone": "+70488550111"}
0005434825073	873D4E	2515 668436	LYUBOV DAVYDOVA	{"phone": "+70619654445"}
0005434825074	015952	4105 152084	MIKHAIL SMIRNOV	{"phone": "+70713280018"}
0005434825075	B339DF	8260 965607	NATALIYA ANISIMOVA	{"phone": "+70095208637"}
0005434825076	40B041	7021 656174	VLADIMIR ANDREEV	{"email": "andreev.vladimir.011970@postgrespro.ru", "phone": "+70404195221"}
0005434825077	F0FEDD	2151 151349	NADEZHDA ROMANOVA	{"email": "n_romanova_16111971@postgrespro.ru", "phone": "+70325358262"}
0005434825078	85DF79	2795 275267	LIDIYA NIKITINA	{"phone": "+70095590940"}
0005434825079	85DF79	9461 971590	ALEKSEY OSIPOV	{"phone": "+70748742059"}
0005434825080	568B13	2320 232277	SERGEY NAZAROV	{"email": "nazarov.s1968@postgrespro.ru", "phone": "+70355522827"}
0005434825081	0C074D	3261 171769	PETR FOMIN	{"email": "pfomin-1966@postgrespro.ru", "phone": "+70494774898"}
0005434825082	2D2FC0	7291 869632	VIKTORIYA NESTEROVA	{"email": "nesterova_viktoriya081972@postgrespro.ru", "phone": "+70635566547"}
0005434825083	2D2FC0	6079 938381	ANNA KOVALEVA	{"email": "a-kovaleva.1967@postgrespro.ru", "phone": "+70610314205"}
0005434825084	2D2FC0	9372 581331	NIKITA TARASOV	{"email": "nikita_tarasov011978@postgrespro.ru", "phone": "+70858436991"}
0005434825085	BF4F35	7459 292315	OLEG VOLKOV	{"phone": "+70689434455"}
0005434825086	BF4F35	2961 442615	ALEKSANDR BARANOV	{"phone": "+70065841430"}
0005434825087	6F1323	4713 079898	OLGA ZOTOVA	{"email": "olga-zotova-011965@postgrespro.ru", "phone": "+70502532319"}
0005434825088	6F1323	1296 566268	IGOR SCHERBAKOV	{"email": "scherbakov.i041976@postgrespro.ru", "phone": "+70678731694"}
0005434825089	0B2480	7620 028106	OLGA TARASOVA	{"email": "tarasova.olga-1970@postgrespro.ru", "phone": "+70553201944"}
0005434825090	DE7548	0445 328809	TATYANA BOGDANOVA	{"email": "bogdanova.tatyana21071968@postgrespro.ru", "phone": "+70196417931"}
0005434825091	DE7548	1356 990697	MAKSIM PAVLOV	{"email": "pavlov-m_051976@postgrespro.ru", "phone": "+70229148427"}
0005434825092	A31E72	5263 400222	NATALYA MAKAROVA	{"phone": "+70359954072"}
0005434825093	389E66	4149 656858	ANDREY ANTONOV	{"email": "antonovandrey_15101975@postgrespro.ru", "phone": "+70934781310"}
0005434825094	389E66	3931 306202	IGOR MELNIKOV	{"email": "melnikov.i.05011978@postgrespro.ru", "phone": "+70129649769"}
0005434825095	389E66	5874 123500	TATYANA ZOTOVA	{"phone": "+70708904882"}
0005434825319	C82337	7930 470475	TATYANA RYABOVA	{"phone": "+70490734899"}
0005434825096	F10885	6215 099823	ELIZAVETA KUZMINA	{"email": "kuzminae.021969@postgrespro.ru", "phone": "+70308687633"}
0005434825097	2C0B4F	6975 215731	DENIS NIKOLAEV	{"email": "nikolaev.denis_101961@postgrespro.ru", "phone": "+70105408414"}
0005434825098	2C0B4F	9772 450708	NADEZHDA VASILEVA	{"email": "vasileva_n-081968@postgrespro.ru", "phone": "+70270681796"}
0005434825099	754EEA	7093 607388	TATYANA BOGDANOVA	{"phone": "+70900854028"}
0005434825100	5CF9C5	5050 776459	MARINA MASLOVA	{"email": "maslova-marina_13061982@postgrespro.ru", "phone": "+70897326808"}
0005434825101	C962B6	6280 856964	ANDREY VOLKOV	{"phone": "+70777646028"}
0005434825102	E2CC04	5935 822927	NADEZHDA ALEKSANDROVA	{"phone": "+70767617017"}
0005434825103	95B29F	6356 143503	MARINA PETROVA	{"email": "petrova_marina.071979@postgrespro.ru", "phone": "+70197829146"}
0005434825104	B6FB98	3978 858806	IRINA IVANOVA	{"email": "iivanova.08011973@postgrespro.ru", "phone": "+70590903550"}
0005434825105	FA95F8	5919 723323	ELENA ILINA	{"phone": "+70895426873"}
0005434825164	22513D	1535 475523	ANNA FEDOROVA	{"phone": "+70167318986"}
0005434825106	EE1C39	9432 389338	OLGA LEBEDEVA	{"email": "olgalebedeva_20071973@postgrespro.ru", "phone": "+70950174777"}
0005434825107	B4DA50	5454 183098	VERA VLASOVA	{"email": "vlasova.vera01101970@postgrespro.ru", "phone": "+70073037417"}
0005434825108	97F890	0233 527121	RUSLAN FROLOV	{"email": "r.frolov.03051965@postgrespro.ru", "phone": "+70850605730"}
0005434825109	04DE10	5736 482788	ANNA ZAYCEVA	{"phone": "+70407252815"}
0005434825110	BD8B90	3026 109201	ANTON FOMIN	{"phone": "+70479947119"}
0005434825111	BD8B90	9954 579203	MARINA LUKYANOVA	{"email": "lukyanova-marina031969@postgrespro.ru", "phone": "+70666128079"}
0005434825112	0E2BB1	5436 300602	LYUDMILA ALEKSANDROVA	{"email": "lyudmilaaleksandrova_06021976@postgrespro.ru", "phone": "+70507062732"}
0005434825113	0E2BB1	3416 154733	DIANA FROLOVA	{"phone": "+70157482096"}
0005434825114	F78F57	4538 451560	ALLA STEPANOVA	{"email": "stepanova-alla.1977@postgrespro.ru", "phone": "+70420676110"}
0005434825115	C2120D	4168 938891	ALFIYA KONDRATEVA	{"phone": "+70927561365"}
0005434825116	C2120D	5536 030909	YURIY GAVRILOV	{"phone": "+70911881838"}
0005434825117	38C0F4	8643 285352	IRINA PETROVA	{"email": "irina_petrova_021974@postgrespro.ru", "phone": "+70963978921"}
0005434825118	00FE5B	1198 700913	TAISIYA KONDRATEVA	{"email": "t_kondrateva.01041981@postgrespro.ru", "phone": "+70112341197"}
0005434825119	00FE5B	2309 866739	LYUDMILA EGOROVA	{"email": "l.egorova1973@postgrespro.ru", "phone": "+70005069693"}
0005434825120	00FE5B	5339 377334	SOFIYA GERASIMOVA	{"email": "sofiya_gerasimova.051975@postgrespro.ru", "phone": "+70251772059"}
0005434825121	3D46F9	4064 893281	ARTEM POPOV	{"email": "artem-popov-1970@postgrespro.ru", "phone": "+70662384262"}
0005434825122	A6E79C	4887 368289	YURIY KULIKOV	{"email": "kulikovy_27111965@postgrespro.ru", "phone": "+70837434418"}
0005434825123	68C7B2	4718 451816	YULIYA ZHURAVLEVA	{"email": "zhuravleva.y.06071976@postgrespro.ru", "phone": "+70040389115"}
0005434825124	D4C2D8	1533 163776	LYUDMILA TIKHONOVA	{"email": "tikhonova-lyudmila.101977@postgrespro.ru", "phone": "+70674078547"}
0005434825125	35808C	1077 092895	MARINA MALYSHEVA	{"email": "malyshevam-071985@postgrespro.ru", "phone": "+70623795638"}
0005434825126	EECB86	7984 551961	IRINA FEDOROVA	{"email": "irina_fedorova011967@postgrespro.ru", "phone": "+70778311143"}
0005434825127	75F1B1	9145 834580	ALEKSEY KOROLEV	{"phone": "+70491673699"}
0005434825128	AE128B	6113 156366	FEDOR KOZLOV	{"phone": "+70358528467"}
0005434825129	F132C1	3115 971162	TATYANA MOISEEVA	{"phone": "+70499092217"}
0005434825130	F132C1	8221 287962	IRINA POTAPOVA	{"email": "i.potapova-17091966@postgrespro.ru", "phone": "+70184415001"}
0005434825131	F132C1	6809 981349	MAKSIM MIRONOV	{"email": "mironov-m-1966@postgrespro.ru", "phone": "+70012720356"}
0005434825132	3DDDEA	4050 601163	EVGENIY BONDARENKO	{"phone": "+70433659891"}
0005434825133	3DDDEA	9675 687618	ALENA SEMENOVA	{"email": "semenova_alena-1976@postgrespro.ru", "phone": "+70175487689"}
0005434825134	3BC33D	2503 797529	MARIYA GAVRILOVA	{"phone": "+70800389499"}
0005434825135	3BC33D	9589 231239	VLADIMIR ZAKHAROV	{"phone": "+70212457495"}
0005434825136	B67B9B	7908 042436	ALEKSEY ORLOV	{"phone": "+70850663514"}
0005434825137	7B7E45	0658 391498	ALEKSANDR FEDOTOV	{"email": "fedotov_a_20101976@postgrespro.ru", "phone": "+70147582950"}
0005434825138	74D7F5	4479 122944	ANDREY SOLOVEV	{"email": "solovev.andrey.1966@postgrespro.ru", "phone": "+70173456995"}
0005434825139	74D7F5	5157 535550	ALFIYA SMIRNOVA	{"phone": "+70461891085"}
0005434825140	1E752C	5927 648312	OLGA VOLKOVA	{"email": "volkovaolga-091967@postgrespro.ru", "phone": "+70874860795"}
0005434825141	E72B71	7576 395733	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov_1977@postgrespro.ru", "phone": "+70958579343"}
0005434825142	B8732F	4497 959304	RISHAT IVANOV	{"email": "r_ivanov-031990@postgrespro.ru", "phone": "+70368862833"}
0005434825143	B8732F	9160 015330	LARISA MASLOVA	{"email": "maslova_l111973@postgrespro.ru", "phone": "+70251872381"}
0005434825144	0E586B	4941 076959	MIKHAIL NIKITIN	{"email": "mikhail_nikitin051979@postgrespro.ru", "phone": "+70628011044"}
0005434825145	69FFB0	6073 697427	RAMIS MIKHAYLOV	{"phone": "+70119315524"}
0005434825146	325E51	4297 870905	ALEKSEY IVANOV	{"email": "a-ivanov071970@postgrespro.ru", "phone": "+70263626570"}
0005434825147	5C085E	5156 099524	NINA TIMOFEEVA	{"email": "timofeeva.n011957@postgrespro.ru", "phone": "+70714011652"}
0005434825148	7A9870	4162 832322	FANIYA KONDRATEVA	{"phone": "+70160060096"}
0005434825149	F9DCF3	3477 749549	NIKOLAY MATVEEV	{"email": "matveev_nikolay.02031986@postgrespro.ru", "phone": "+70440723642"}
0005434825150	F9DCF3	2678 676501	ANNA ALEKSEEVA	{"email": "alekseeva_a_1965@postgrespro.ru", "phone": "+70572979197"}
0005434825151	6191F3	6473 232581	ANATOLIY ROMANOV	{"email": "anatoliyromanov1975@postgrespro.ru", "phone": "+70888462081"}
0005434825152	D1CB32	0082 682035	IVAN MOROZOV	{"email": "i_morozov.071979@postgrespro.ru", "phone": "+70410073064"}
0005434825153	32F839	5585 804914	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr101970@postgrespro.ru", "phone": "+70157969638"}
0005434825154	32F839	3122 561980	SERGEY IVANOV	{"phone": "+70585069992"}
0005434825155	6192ED	5332 785955	PETR IVANOV	{"phone": "+70989523593"}
0005434825156	6192ED	2988 158769	VALERIY CHERNOV	{"phone": "+70178741730"}
0005434825157	6192ED	4142 174233	GALINA DMITRIEVA	{"email": "gdmitrieva.1975@postgrespro.ru", "phone": "+70936652688"}
0005434825158	4D8E7F	9720 493630	ALEKSANDR MAKAROV	{"email": "makarova_19091966@postgrespro.ru", "phone": "+70596894977"}
0005434825159	CD0CCD	1701 854896	BORIS SOROKIN	{"phone": "+70440310558"}
0005434825160	765ACB	1571 239374	KSENIYA GRISHINA	{"phone": "+70369463912"}
0005434825161	765ACB	4203 528143	ELENA STEPANOVA	{"email": "stepanovae_11071976@postgrespro.ru", "phone": "+70708613995"}
0005434825162	258825	1925 516012	ALEKSANDR MOISEEV	{"email": "a.moiseev1962@postgrespro.ru", "phone": "+70331246178"}
0005434825163	793BBC	1336 420907	OLGA ISAEVA	{"email": "o.isaeva-051983@postgrespro.ru", "phone": "+70005209986"}
0005434825165	1A5D6C	4940 860081	ALEKSANDR SOKOLOV	{"email": "sokolov_a-13031970@postgrespro.ru", "phone": "+70332196530"}
0005434825166	1A5D6C	2934 994297	ELENA NIKOLAEVA	{"email": "enikolaeva061975@postgrespro.ru", "phone": "+70910623024"}
0005434825167	6C751F	7929 112963	DANIIL KOROLEV	{"phone": "+70641813388"}
0005434825168	2502C9	2600 733312	MARIYA KOROLEVA	{"phone": "+70917618681"}
0005434825169	E16D49	5883 787194	IVAN MOISEEV	{"phone": "+70256799195"}
0005434825170	162B4D	8286 631720	NIKITA STEPANOV	{"email": "stepanov.n-1975@postgrespro.ru", "phone": "+70838546555"}
0005434825171	B4B54F	4333 259500	NIKOLAY OSIPOV	{"phone": "+70599814418"}
0005434825172	B4B54F	8407 192492	ALBINA GERASIMOVA	{"phone": "+70515374383"}
0005434825173	91063C	2378 613733	IGOR BORISOV	{"phone": "+70568079862"}
0005434825174	83DD13	6531 079138	LIDIYA STEPANOVA	{"phone": "+70649078551"}
0005434825175	2A1A02	8460 912308	ALEKSANDR STEPANOV	{"email": "stepanov.a-041969@postgrespro.ru", "phone": "+70168211416"}
0005434825176	2A1A02	4892 375022	ALEKSANDR MATVEEV	{"phone": "+70702390323"}
0005434825177	0F4870	2231 155944	ANDREY BARANOV	{"phone": "+70522447861"}
0005434825178	05234C	7475 981544	VALENTINA SOLOVEVA	{"phone": "+70356001581"}
0005434825179	1BEC9A	6544 581759	VIKTOR ANTONOV	{"email": "v_antonov_041987@postgrespro.ru", "phone": "+70092182642"}
0005434825180	1BEC9A	5084 059719	ALEKSANDR FOMIN	{"phone": "+70018057459"}
0005434825181	1BEC9A	8123 187760	EKATERINA KULIKOVA	{"phone": "+70263171091"}
0005434825182	A785B2	8408 265128	ELENA PAVLOVA	{"email": "elenapavlova.18051976@postgrespro.ru", "phone": "+70644213438"}
0005434825183	703665	6608 362969	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov.10041975@postgrespro.ru", "phone": "+70233902119"}
0005434825184	13263A	9912 325734	ALEKSANDR VOLKOV	{"email": "volkov_a.091962@postgrespro.ru", "phone": "+70408030143"}
0005434825185	C5EFCA	5098 796982	MIKHAIL NAZAROV	{"email": "mikhail_nazarov_121975@postgrespro.ru", "phone": "+70163330409"}
0005434825186	3712C3	1844 669474	VALERIY MAKAROV	{"phone": "+70483650877"}
0005434825187	3712C3	3662 558802	ELENA CHERNOVA	{"email": "chernova_elena-02011969@postgrespro.ru", "phone": "+70759375648"}
0005434825188	3712C3	6434 533678	OLGA NESTEROVA	{"phone": "+70854667197"}
0005434825189	BB53ED	7145 722167	SVETLANA ROMANOVA	{"email": "svetlana-romanova1971@postgrespro.ru", "phone": "+70531494412"}
0005434825190	02E180	1458 696703	PAVEL ILIN	{"phone": "+70514196813"}
0005434825191	A6EC31	5289 509043	MIKHAIL VASILEV	{"phone": "+70826587826"}
0005434825192	71D7B0	1690 430843	ALEKSEY SIDOROV	{"phone": "+70396701563"}
0005434825193	32C40D	8942 568292	NADEZHDA OSIPOVA	{"phone": "+70429567843"}
0005434825194	32C40D	2928 364807	ALEKSANDR FROLOV	{"phone": "+70838000830"}
0005434825195	32C40D	4188 215042	ANATOLIY NIKOLAEV	{"email": "nikolaev-a121961@postgrespro.ru", "phone": "+70047912549"}
0005434825196	C88B18	7084 908229	NATALYA NAZAROVA	{"email": "n.nazarova.28071975@postgrespro.ru", "phone": "+70919517429"}
0005434825197	70E50E	3093 319561	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l02041980@postgrespro.ru", "phone": "+70906160504"}
0005434825198	D2158C	5700 493127	DARYA NOVIKOVA	{"email": "darya-novikova20041966@postgrespro.ru", "phone": "+70781696077"}
0005434825199	6E18FB	4497 418204	GRIGORIY ZAKHAROV	{"email": "zakharovg-1965@postgrespro.ru", "phone": "+70109837092"}
0005434825200	6E18FB	3887 918920	DMITRIY AFANASEV	{"email": "dmitriy_afanasev.13021978@postgrespro.ru", "phone": "+70344036160"}
0005434825201	FE38F5	2860 190329	VLADIMIR KRASNOV	{"phone": "+70749028956"}
0005434825202	EB7654	4055 896992	IRINA MAKSIMOVA	{"phone": "+70160153790"}
0005434825203	DA9535	5818 667078	RAMILYA KOLESNIKOVA	{"email": "kolesnikova_ramilya-24071976@postgrespro.ru", "phone": "+70934800177"}
0005434825204	62CDCB	5342 159212	ANDREY SCHERBAKOV	{"phone": "+70881656407"}
0005434825205	122044	0194 633282	NINA EFREMOVA	{"phone": "+70465067962"}
0005434825206	EC119F	5724 643426	ALEKSANDRA MAKSIMOVA	{"phone": "+70972558763"}
0005434825543	0D0646	9587 453095	VALENTINA NAUMOVA	{"phone": "+70548875141"}
0005434825207	FDF42E	2584 107211	EKATERINA ANISIMOVA	{"email": "e-anisimova-111969@postgrespro.ru", "phone": "+70280424530"}
0005434825208	8A1E92	1234 467414	IVAN POPOV	{"phone": "+70359241237"}
0005434825209	2B508B	3005 116553	ALINA BELYAEVA	{"phone": "+70995814450"}
0005434825210	F8162E	4535 549594	IRINA TARASOVA	{"email": "irina.tarasova-091973@postgrespro.ru", "phone": "+70152422619"}
0005434825211	F8162E	0559 143900	VIKTOR POPOV	{"email": "v.popov_071975@postgrespro.ru", "phone": "+70059437596"}
0005434825212	F8162E	0700 893522	VLADIMIR GORBUNOV	{"phone": "+70511176250"}
0005434825213	F8162E	6368 681310	SERGEY KUZMIN	{"phone": "+70628720928"}
0005434825214	7414E6	9048 807313	GALINA YUDINA	{"email": "yudinag-091990@postgrespro.ru", "phone": "+70300881353"}
0005434825215	7414E6	8705 771076	SERGEY SCHERBAKOV	{"phone": "+70075191209"}
0005434825216	7414E6	6116 190196	VLADIMIR IVANOV	{"phone": "+70142190759"}
0005434825217	42A2A5	4827 229058	VALENTINA EFREMOVA	{"email": "valentina_efremova29071969@postgrespro.ru", "phone": "+70882423669"}
0005434825218	FB6FC4	6077 995304	NATALYA BARANOVA	{"phone": "+70165222973"}
0005434825219	FB6FC4	4250 354991	RAISA ABRAMOVA	{"phone": "+70029016932"}
0005434825220	BA50F4	1597 774082	ALEKSANDR MELNIKOV	{"email": "melnikov-a-1979@postgrespro.ru", "phone": "+70913871797"}
0005434825221	BA50F4	9951 766125	ALEKSANDR VASILEV	{"email": "a.vasilev-04041979@postgrespro.ru", "phone": "+70265646894"}
0005434825222	891303	4890 010332	LARISA ANISIMOVA	{"email": "larisaanisimova.071982@postgrespro.ru", "phone": "+70851490965"}
0005434825223	AE90A0	0869 066043	GRIGORIY KULIKOV	{"email": "grigoriy.kulikov-1970@postgrespro.ru", "phone": "+70290769268"}
0005434825224	07ED4A	2659 367170	NADEZHDA SCHERBAKOVA	{"phone": "+70449277936"}
0005434825225	14286E	6166 418588	LIDIYA BELOVA	{"phone": "+70090435904"}
0005434825226	14286E	4043 206602	ALLA VOROBEVA	{"email": "allavorobeva1974@postgrespro.ru", "phone": "+70142478848"}
0005434825227	2014B3	5812 329328	MARGARITA ISAEVA	{"email": "isaeva-margarita-02091971@postgrespro.ru", "phone": "+70286546268"}
0005434825228	2014B3	1091 354669	ALEKSEY POPOV	{"phone": "+70761380531"}
0005434825229	48F5A2	4356 616323	LYUDMILA ABRAMOVA	{"phone": "+70348688059"}
0005434825230	48F5A2	4109 472735	ELENA ARKHIPOVA	{"email": "e-arkhipova.071981@postgrespro.ru", "phone": "+70047571397"}
0005434825231	860F8F	4068 411054	VALERIY KAZAKOV	{"email": "vkazakov_021982@postgrespro.ru", "phone": "+70098569286"}
0005434825232	11A242	3032 808796	YURIY BONDARENKO	{"phone": "+70684560938"}
0005434825233	18A6EE	3960 507211	NADEZHDA KUDRYASHOVA	{"phone": "+70606617147"}
0005434825234	F5627B	5022 403304	IRINA NOVIKOVA	{"phone": "+70471851205"}
0005434825235	7993B7	8265 134785	IRINA TITOVA	{"phone": "+70759756152"}
0005434825236	1C30E0	4113 177735	KSENIYA STEPANOVA	{"phone": "+70572115239"}
0005434825237	1C30E0	0698 766398	ILYA BORISOV	{"phone": "+70946932103"}
0005434825238	1C30E0	9472 963543	IVAN PAVLOV	{"phone": "+70892423172"}
0005434825239	013A3A	8679 714899	YURIY BORISOV	{"email": "yuriy_borisov.121960@postgrespro.ru", "phone": "+70300448354"}
0005434825240	7F789F	9662 320555	ANASTASIYA SIDOROVA	{"phone": "+70503272090"}
0005434825241	7F789F	1454 318554	MARIYA NIKITINA	{"phone": "+70662250359"}
0005434825242	603135	9114 570242	ANASTASIYA GRISHINA	{"email": "a_grishina101969@postgrespro.ru", "phone": "+70899988105"}
0005434825243	603135	9675 598004	RUSLAN KRASNOV	{"phone": "+70377870365"}
0005434825244	603135	8957 364446	NINA KISELEVA	{"phone": "+70536297204"}
0005434825245	56ECE7	9540 631773	ELVIRA FOMINA	{"email": "fomina_elvira091986@postgrespro.ru", "phone": "+70106354239"}
0005434825246	9530E0	4214 432855	ELENA ORLOVA	{"email": "e_orlova031976@postgrespro.ru", "phone": "+70312197821"}
0005434825247	6276FE	1476 475968	ELENA STEPANOVA	{"email": "elena-stepanova071977@postgrespro.ru", "phone": "+70814370697"}
0005434825248	BC37C7	8272 610073	VLADISLAV MAKAROV	{"email": "makarov-v1974@postgrespro.ru", "phone": "+70289654339"}
0005434825249	27AEB9	0568 240360	ALENA NOVIKOVA	{"email": "alena.novikova-01041970@postgrespro.ru", "phone": "+70099678315"}
0005434825250	649EB3	1675 206587	SERGEY GERASIMOV	{"phone": "+70371453441"}
0005434825251	839339	8531 013280	ROZA KUDRYASHOVA	{"phone": "+70599302886"}
0005434825252	28BC68	3249 380473	ANNA SAVELEVA	{"email": "a-saveleva021984@postgrespro.ru", "phone": "+70493476482"}
0005434825253	217A68	8925 607663	AZAT ZAYCEV	{"email": "zaycev-a.30081968@postgrespro.ru", "phone": "+70408411576"}
0005434825254	2D92D9	3485 976454	SERGEY OSIPOV	{"email": "sergey.osipov.011964@postgrespro.ru", "phone": "+70475063625"}
0005434825255	0B14CD	9957 039977	RUSLAN BONDARENKO	{"phone": "+70829435982"}
0005434825256	0B14CD	0113 100870	VITALIY FEDOTOV	{"email": "v_fedotov.05011960@postgrespro.ru", "phone": "+70264660727"}
0005434825257	B9ADEB	7158 826736	LYUDMILA FEDOROVA	{"email": "fedorova.l.18071974@postgrespro.ru", "phone": "+70197900424"}
0005434825258	2403D2	8829 197569	ANGELINA VOLKOVA	{"phone": "+70870861250"}
0005434825259	2403D2	7803 340670	MADINA LEBEDEVA	{"phone": "+70711904346"}
0005434825260	EEBA95	7128 564057	EKATERINA MAKAROVA	{"phone": "+70863293694"}
0005434825261	00B74D	3734 283726	OLEG MATVEEV	{"email": "o-matveev30091982@postgrespro.ru", "phone": "+70772139624"}
0005434825262	669F19	4396 553259	VASILIY IVANOV	{"phone": "+70664821839"}
0005434825263	DE6582	4544 223738	VLADIMIR MEDVEDEV	{"phone": "+70533510513"}
0005434825264	97DA36	8434 260161	SULTAN GORBUNOV	{"email": "gorbunov-sultan101964@postgrespro.ru", "phone": "+70574022014"}
0005434825265	97DA36	3762 363468	ARTEM ROMANOV	{"email": "artem-romanov16121977@postgrespro.ru", "phone": "+70201569613"}
0005434825266	869785	1362 867139	RAISA VASILEVA	{"phone": "+70850428303"}
0005434825267	869785	4419 209424	NIKOLAY FROLOV	{"phone": "+70265740961"}
0005434825268	D2D1D9	5291 047455	NIKOLAY BONDARENKO	{"email": "bondarenko-n_03071971@postgrespro.ru", "phone": "+70595746313"}
0005434825269	D2D1D9	8075 128763	ELENA FILATOVA	{"email": "elena_filatova_1969@postgrespro.ru", "phone": "+70497647500"}
0005434825270	44AF04	4059 628351	MIKHAIL ZAKHAROV	{"email": "m-zakharov.1965@postgrespro.ru", "phone": "+70090396173"}
0005434825271	A4A093	7816 997663	POLINA SERGEEVA	{"phone": "+70969516999"}
0005434825272	488904	3384 531452	ALEKSANDR POPOV	{"email": "aleksandrpopov.111970@postgrespro.ru", "phone": "+70709187057"}
0005434825273	48247E	1528 930949	TAMARA IVANOVA	{"email": "ivanovat_031970@postgrespro.ru", "phone": "+70723037313"}
0005434825274	48247E	7978 369938	ALEKSANDRA VASILEVA	{"email": "vasileva.aleksandra-081971@postgrespro.ru", "phone": "+70039635258"}
0005434825275	48247E	1578 409591	IRINA PAVLOVA	{"phone": "+70254101591"}
0005434825276	7E458F	7425 265610	LYAYSAN SEMENOVA	{"phone": "+70137382766"}
0005434825277	1B653A	1572 268505	ANASTASIYA MAKAROVA	{"email": "makarovaa051965@postgrespro.ru", "phone": "+70696282688"}
0005434825278	83D51C	6315 941935	ALEKSANDR FROLOV	{"phone": "+70322245071"}
0005434825279	A3E174	2943 231877	VARVARA SOKOLOVA	{"phone": "+70609494983"}
0005434825280	A3E174	8346 780837	ALEKSEY GUSEV	{"email": "gusev_aleksey-21101978@postgrespro.ru", "phone": "+70199658979"}
0005434825281	A3E174	8108 501024	TARAS NAZAROV	{"phone": "+70316017601"}
0005434825282	CFF92C	4615 659296	ALEKSEY FILIPPOV	{"email": "filippov_aleksey-1978@postgrespro.ru", "phone": "+70712649084"}
0005434825283	0513DA	9093 492323	SERGEY MIKHAYLOV	{"phone": "+70893244797"}
0005434825284	0513DA	4741 510099	VIKTOR SEMENOV	{"phone": "+70248515596"}
0005434825285	C5BC4B	1450 801816	TATYANA KONOVALOVA	{"phone": "+70626169258"}
0005434825286	C5BC4B	3694 168942	EVGENIY MOISEEV	{"email": "evgeniy.moiseev1977@postgrespro.ru", "phone": "+70254331474"}
0005434825287	C5BC4B	2635 308885	IGOR EGOROV	{"email": "i_egorov1965@postgrespro.ru", "phone": "+70254432201"}
0005434825288	B2B5D6	4180 315860	ANDREY IVANOV	{"email": "ivanov-a.16031980@postgrespro.ru", "phone": "+70948236543"}
0005434825289	F2348C	1803 436633	ALEKSANDR MAKAROV	{"email": "aleksandr_makarov011970@postgrespro.ru", "phone": "+70002281629"}
0005434825290	438F42	8425 826350	VLADIMIR SOROKIN	{"email": "sorokin.vladimir.28021966@postgrespro.ru", "phone": "+70007633833"}
0005434825291	438F42	6180 393449	ALEKSANDR KOZLOV	{"phone": "+70015711144"}
0005434825292	1DDA12	8747 089560	RUSTAM ZHUKOV	{"phone": "+70240571442"}
0005434825293	1DDA12	9538 255397	GENNADIY MAKAROV	{"phone": "+70438258270"}
0005434825294	7B7107	7929 371203	ANDREY AFANASEV	{"email": "andreyafanasev-1974@postgrespro.ru", "phone": "+70755853862"}
0005434825295	1ADCEA	8968 303032	VYACHESLAV ALEKSEEV	{"email": "alekseevv121976@postgrespro.ru", "phone": "+70725156288"}
0005434825296	1ADCEA	9273 312181	OLGA FOMINA	{"phone": "+70515948120"}
0005434825297	7C2D81	9619 980340	YURIY BORISOV	{"email": "borisov_yuriy.071967@postgrespro.ru", "phone": "+70433240883"}
0005434825298	7C2D81	4644 474092	DIANA NOVIKOVA	{"phone": "+70133798057"}
0005434825299	6ED83E	2068 189597	TATYANA FROLOVA	{"phone": "+70539638896"}
0005434825300	6ED83E	8340 901223	MARIYA FEDOROVA	{"phone": "+70259316107"}
0005434825301	ABD278	8725 382313	ANTONINA KULIKOVA	{"email": "a_kulikova-18011978@postgrespro.ru", "phone": "+70486794606"}
0005434825302	382D62	4559 320207	ALEKSEY KRASNOV	{"email": "krasnov_a_031975@postgrespro.ru", "phone": "+70942256603"}
0005434825303	664ED1	7271 144542	KONSTANTIN TIKHONOV	{"email": "k-tikhonov23121963@postgrespro.ru", "phone": "+70400158757"}
0005434825304	27A1EA	6991 122249	VERA KONOVALOVA	{"email": "v_konovalova-29121976@postgrespro.ru", "phone": "+70317468425"}
0005434825305	53CFC4	6587 550837	TATYANA MIKHAYLOVA	{"email": "mikhaylovat021972@postgrespro.ru", "phone": "+70823945496"}
0005434825306	A680BE	8442 285871	TATYANA AKIMOVA	{"email": "tatyana_akimova-13091964@postgrespro.ru", "phone": "+70582520549"}
0005434825307	BA7211	5758 059421	VALERIYA BORISOVA	{"email": "vborisova21011977@postgrespro.ru", "phone": "+70610667877"}
0005434825308	BA7211	9875 698577	GALINA GORBUNOVA	{"email": "gorbunovagalina.121978@postgrespro.ru", "phone": "+70463114988"}
0005434825309	5DA54D	7655 312843	KSENIYA BORISOVA	{"email": "kseniya.borisova_12021978@postgrespro.ru", "phone": "+70737909065"}
0005434825310	C5CB34	0838 762904	SVETLANA VOLKOVA	{"phone": "+70771481413"}
0005434825311	622477	7691 308161	DARYA MARTYNOVA	{"phone": "+70273570118"}
0005434825312	622477	0158 931092	LARISA KOROLEVA	{"email": "l.koroleva.121966@postgrespro.ru", "phone": "+70178859504"}
0005434825313	CB1FA2	1822 597700	LARISA POTAPOVA	{"email": "potapova.larisa.021962@postgrespro.ru", "phone": "+70200478465"}
0005434825314	CB1FA2	7273 600399	ANNA ZAKHAROVA	{"email": "anna-zakharova-1972@postgrespro.ru", "phone": "+70586959352"}
0005434825315	1E5606	7430 052078	ALEKSEY KUZMIN	{"phone": "+70869134869"}
0005434825316	79765E	1708 792125	SVETLANA MELNIKOVA	{"phone": "+70568887110"}
0005434825317	5590AE	8039 880833	VALENTINA IVANOVA	{"email": "ivanovavalentina26011961@postgrespro.ru", "phone": "+70736990402"}
0005434825318	3D37CD	6741 870151	VALERIY IVANOV	{"phone": "+70307590076"}
0005434825320	7B05D5	4439 872642	VIKTOR CHERNOV	{"email": "viktor.chernov.1965@postgrespro.ru", "phone": "+70920168634"}
0005434825321	00EF5F	3789 311225	VLADIMIR FILIPPOV	{"email": "filippov-vladimir.051959@postgrespro.ru", "phone": "+70193591368"}
0005434825322	6D48D7	2537 475073	ALEKSANDR VOROBEV	{"email": "vorobeva_081984@postgrespro.ru", "phone": "+70038138843"}
0005434825323	07C351	8854 096466	ANASTASIYA NAZAROVA	{"email": "nazarovaa13051972@postgrespro.ru", "phone": "+70715977600"}
0005434825324	53FE39	5294 962034	ANNA KUZMINA	{"email": "a.kuzmina1969@postgrespro.ru", "phone": "+70705693531"}
0005434825325	493D07	9011 082172	PAVEL PAVLOV	{"email": "pavlovpavel1958@postgrespro.ru", "phone": "+70171751414"}
0005434825326	F0004F	3256 936586	LYUDMILA KOROLEVA	{"email": "koroleva-l.22031966@postgrespro.ru", "phone": "+70890770484"}
0005434825327	B44788	0122 232782	NIKOLAY ZAKHAROV	{"email": "nikolayzakharov_14031976@postgrespro.ru", "phone": "+70338524319"}
0005434825328	95AEF6	8665 191330	SERGEY EGOROV	{"email": "sergey_egorov111974@postgrespro.ru", "phone": "+70867299314"}
0005434825329	3E7BF9	7267 122970	LYUBOV VASILEVA	{"email": "vasilevalyubov-061975@postgrespro.ru", "phone": "+70116973283"}
0005434825330	339B0F	4744 832929	TATYANA MOROZOVA	{"email": "tatyanamorozova_041972@postgrespro.ru", "phone": "+70968070102"}
0005434825331	05BCD1	5411 699361	NADEZHDA MAKAROVA	{"email": "nadezhda_makarova06031983@postgrespro.ru", "phone": "+70173715478"}
0005434825332	2249E5	0909 739285	GALINA TIMOFEEVA	{"phone": "+70196031726"}
0005434825333	8960A1	3032 998677	ALEKSEY MAKAROV	{"email": "makarov-aleksey1975@postgrespro.ru", "phone": "+70117494514"}
0005434825334	2D4089	0603 781469	ALEKSANDR BELOV	{"email": "belov.a1974@postgrespro.ru", "phone": "+70691547758"}
0005434825335	2D4089	3703 533561	VLADISLAV ZAKHAROV	{"email": "vladislavzakharov071971@postgrespro.ru", "phone": "+70918516985"}
0005434825336	D38763	1624 223814	MIKHAIL NAUMOV	{"phone": "+70161522100"}
0005434825337	D38763	1187 346392	ALEKSEY KUZNECOV	{"email": "akuznecov05051972@postgrespro.ru", "phone": "+70516972892"}
0005434825338	282A46	8856 464243	NATALYA STEPANOVA	{"phone": "+70539380775"}
0005434825339	9628DB	0938 119859	LYUBOV FILATOVA	{"email": "l-filatova1965@postgrespro.ru", "phone": "+70409526648"}
0005434825340	196744	3756 877294	LIDIYA ZAKHAROVA	{"email": "lzakharova-07051972@postgrespro.ru", "phone": "+70939787472"}
0005434825341	5B0E40	7220 156527	IGOR SEMENOV	{"email": "semenov-i051974@postgrespro.ru", "phone": "+70067216960"}
0005434825342	7E4E6C	9568 949329	GRIGORIY IVANOV	{"email": "ivanovg071976@postgrespro.ru", "phone": "+70570196339"}
0005434825343	723CF9	8618 686080	VALENTINA BORISOVA	{"phone": "+70844824448"}
0005434825344	04C545	2047 780533	OLGA FILATOVA	{"email": "filatova_olga1968@postgrespro.ru", "phone": "+70805638553"}
0005434825345	04C545	2361 028041	NADEZHDA SOROKINA	{"email": "n-sorokina011977@postgrespro.ru", "phone": "+70904333465"}
0005434825346	EEC41E	6989 913608	ELENA POPOVA	{"phone": "+70770951939"}
0005434825347	C620B1	3189 924443	TATYANA VASILEVA	{"email": "vasileva-t.021977@postgrespro.ru", "phone": "+70330959522"}
0005434825348	90D798	3301 184358	VALERIYA FEDOROVA	{"phone": "+70272121641"}
0005434825349	3DF859	3802 228054	VLADIMIR SCHERBAKOV	{"phone": "+70308574120"}
0005434825350	1E54E4	2976 678612	NATALYA BORISOVA	{"phone": "+70392499790"}
0005434825351	1E54E4	6283 337385	NIKOLAY NAZAROV	{"phone": "+70809719013"}
0005434825352	67B5D8	8416 215841	ELENA ALEKSEEVA	{"phone": "+70352547881"}
0005434825353	3FE3B3	1431 464248	SVETLANA MAKAROVA	{"email": "svetlana.makarova-22011980@postgrespro.ru", "phone": "+70161172765"}
0005434825354	3FE3B3	6661 326603	GULNARA KOROLEVA	{"email": "gulnarakoroleva-02041978@postgrespro.ru", "phone": "+70828547059"}
0005434825355	CF1526	1901 039678	OLGA OVCHINNIKOVA	{"email": "oovchinnikova.23081971@postgrespro.ru", "phone": "+70890039344"}
0005434825356	FA5A61	2646 913658	KONSTANTIN OSIPOV	{"email": "konstantin_osipov14031977@postgrespro.ru", "phone": "+70249744792"}
0005434825357	5072B0	6015 871319	SERGEY BORISOV	{"phone": "+70914835349"}
0005434825358	C98984	9142 408434	NATALYA MIKHAYLOVA	{"email": "mikhaylova.n_07111972@postgrespro.ru", "phone": "+70497831148"}
0005434825359	C1F1FD	4504 270815	MARINA NOVIKOVA	{"phone": "+70612535966"}
0005434825360	B4D5DA	8446 440581	OLEG KUZNECOV	{"phone": "+70031250135"}
0005434825361	28C8A5	5432 073958	GALINA KUZNECOVA	{"email": "galina.kuznecova.27011969@postgrespro.ru", "phone": "+70238740604"}
0005434825362	CA5172	6118 912205	KARINA ABRAMOVA	{"email": "karina-abramova-1976@postgrespro.ru", "phone": "+70375844191"}
0005434825363	74BB3B	6526 930152	ANNA VOLKOVA	{"email": "volkova.a.08031981@postgrespro.ru", "phone": "+70387710631"}
0005434825364	96B4B9	0678 597098	ANNA TIMOFEEVA	{"phone": "+70671506100"}
0005434825365	7F756F	2114 218936	GENNADIY ZAKHAROV	{"phone": "+70449980238"}
0005434825366	EC58A5	3052 490672	ALEKSANDR NIKITIN	{"phone": "+70458561232"}
0005434825367	EC58A5	3218 493343	VALENTINA MATVEEVA	{"phone": "+70844459484"}
0005434825368	FFFEA6	0691 393819	EVGENIY VASILEV	{"email": "vasileve.1982@postgrespro.ru", "phone": "+70747549921"}
0005434825369	184402	6087 556683	YULIYA ANDREEVA	{"email": "yuliya-andreeva_11021969@postgrespro.ru", "phone": "+70116850384"}
0005434825370	F676A4	7561 299171	TATYANA POPOVA	{"phone": "+70559574031"}
0005434825371	1C66D5	8559 624700	RAISA DAVYDOVA	{"phone": "+70865602980"}
0005434825372	13C7F4	8400 137612	LYUDMILA ABRAMOVA	{"email": "l_abramova-011973@postgrespro.ru", "phone": "+70312735785"}
0005434825373	794AC8	8212 380763	ARTEM MELNIKOV	{"phone": "+70036917941"}
0005434825374	1C60B7	0997 353515	NATALIYA VASILEVA	{"email": "nataliyavasileva.051961@postgrespro.ru", "phone": "+70126986078"}
0005434825375	453CB4	2638 812601	DMITRIY BARANOV	{"email": "baranov.d1966@postgrespro.ru", "phone": "+70181181152"}
0005434825376	A816EA	7176 437020	ANASTASIYA TITOVA	{"email": "titova_anastasiya_1978@postgrespro.ru", "phone": "+70335291864"}
0005434825377	A816EA	8520 657372	SVETLANA NIKIFOROVA	{"email": "s_nikiforova.1978@postgrespro.ru", "phone": "+70299705043"}
0005434825378	50BF7F	1751 475427	ALENA MOROZOVA	{"email": "alena.morozova_07121963@postgrespro.ru", "phone": "+70598664427"}
0005434825379	9FED42	8183 702118	EKATERINA POLYAKOVA	{"phone": "+70991994382"}
0005434825380	ABECE1	0185 613056	PETR YAKOVLEV	{"phone": "+70748873664"}
0005434825381	ABECE1	6192 119023	ANNA ANDREEVA	{"email": "andreeva.a-081966@postgrespro.ru", "phone": "+70308849483"}
0005434825382	8B6E5D	0456 394792	LIDIYA NIKITINA	{"phone": "+70790613503"}
0005434825383	ADDA30	1979 270592	EKATERINA SMIRNOVA	{"email": "e_smirnova-101971@postgrespro.ru", "phone": "+70169839780"}
0005434825384	E5814C	2046 792999	OLGA DANILOVA	{"email": "odanilova31121973@postgrespro.ru", "phone": "+70463675492"}
0005434825385	1D2550	8792 078650	KARINA MAKAROVA	{"phone": "+70882109116"}
0005434825386	1D2550	8424 087121	VALENTINA ALEKSEEVA	{"email": "alekseeva.valentina111991@postgrespro.ru", "phone": "+70752593749"}
0005434825387	485F12	9252 392732	ELENA VASILEVA	{"phone": "+70490450757"}
0005434825388	D80EFF	4912 515320	IVAN STEPANOV	{"phone": "+70426736958"}
0005434825389	1B60FA	3444 408357	OLGA TIKHONOVA	{"phone": "+70489861373"}
0005434825390	78B16D	3446 240602	VYACHESLAV KISELEV	{"email": "v.kiselev1975@postgrespro.ru", "phone": "+70962341348"}
0005434825391	1A2285	8022 057910	VLADIMIR IVANOV	{"phone": "+70640910377"}
0005434825392	C67AC6	9740 477062	SERGEY BORISOV	{"email": "borisovsergey_011969@postgrespro.ru", "phone": "+70264426991"}
0005434825393	C67AC6	0680 068610	OLGA SERGEEVA	{"email": "sergeevao-25071972@postgrespro.ru", "phone": "+70488285703"}
0005434825394	683864	9427 816095	ALEKSANDRA ANTONOVA	{"email": "antonova.aleksandra-061970@postgrespro.ru", "phone": "+70845361116"}
0005434825395	19F824	9565 312623	VITALIY POPOV	{"phone": "+70598410642"}
0005434825396	19F824	1051 631676	MIKHAIL KONOVALOV	{"email": "konovalov-mikhail.031976@postgrespro.ru", "phone": "+70099347659"}
0005434825397	FD5AD1	4127 371329	KIRILL FOMIN	{"phone": "+70456668432"}
0005434825398	5BA03F	5641 925680	VLADIMIR ZHURAVLEV	{"phone": "+70666279372"}
0005434825399	6F5655	8974 479730	YULIYA KUZNECOVA	{"email": "y_kuznecova071977@postgrespro.ru", "phone": "+70006079587"}
0005434825400	6F5655	0823 223357	LARISA SMIRNOVA	{"email": "lsmirnova_18031967@postgrespro.ru", "phone": "+70644848870"}
0005434825401	9D9A99	2590 691916	ALEKSANDR STEPANOV	{"phone": "+70799913966"}
0005434825402	08D05F	3145 150650	VALENTINA POPOVA	{"phone": "+70765555913"}
0005434825403	08D05F	1388 719050	LYUDMILA KOROLEVA	{"email": "lyudmila-koroleva.1965@postgrespro.ru", "phone": "+70904689662"}
0005434825404	76D64A	1658 985194	LYUDMILA GORBUNOVA	{"phone": "+70056084285"}
0005434825405	953EF5	5200 345124	VIKTOR MIRONOV	{"phone": "+70327795681"}
0005434825406	64440C	5330 006492	SVYATOSLAV IVANOV	{"phone": "+70904356414"}
0005434825407	64440C	2618 418511	ALEKSANDR STEPANOV	{"phone": "+70259905936"}
0005434825408	013C53	4275 164421	ZINAIDA MIKHAYLOVA	{"phone": "+70644863049"}
0005434825409	013C53	5052 588566	LYUDMILA MALYSHEVA	{"email": "l-malysheva.091971@postgrespro.ru", "phone": "+70054781454"}
0005434825410	9D0F3E	6409 656395	EKATERINA ANTONOVA	{"phone": "+70381313058"}
0005434825411	9D0F3E	5127 695565	ALEKSEY MELNIKOV	{"email": "aleksey-melnikov.121967@postgrespro.ru", "phone": "+70614797719"}
0005434825412	45B427	0054 636719	ANDREY KUZNECOV	{"phone": "+70238222892"}
0005434825413	EFC33D	9746 522076	POLINA NIKITINA	{"phone": "+70744363259"}
0005434825414	A04DDC	5803 206549	ALEKSANDR ZAKHAROV	{"phone": "+70685347979"}
0005434825415	A04DDC	6293 643767	VLADIMIR PAVLOV	{"phone": "+70639688476"}
0005434825416	061430	7340 271752	ANATOLIY MAKSIMOV	{"email": "a_maksimov_01121973@postgrespro.ru", "phone": "+70291359067"}
0005434825417	DA36EE	6235 536580	RAISA TIKHONOVA	{"phone": "+70821212495"}
0005434825418	152B19	9689 055967	SEMEN PAVLOV	{"phone": "+70430059866"}
0005434825419	152B19	3363 985585	NAIL FEDOROV	{"phone": "+70198873633"}
0005434825420	DD8357	5571 787496	ALI MARTYNOV	{"email": "martynov.a.1970@postgrespro.ru", "phone": "+70926361220"}
0005434825421	5BEE91	7868 081427	ANNA KOZLOVA	{"phone": "+70450685920"}
0005434825422	5935DE	6176 662434	DIANA KAZAKOVA	{"email": "kazakova-diana-021981@postgrespro.ru", "phone": "+70856871285"}
0005434825423	787AFA	9975 144968	EVGENIY CHERNOV	{"email": "e_chernov_1967@postgrespro.ru", "phone": "+70046618900"}
0005434825424	8A872F	0126 136684	NATALYA AFANASEVA	{"email": "natalyaafanaseva-21011965@postgrespro.ru", "phone": "+70516283451"}
0005434825425	4F13C2	6419 372816	DENIS IVANOV	{"phone": "+70372964365"}
0005434825426	4F13C2	9718 826851	YANA FROLOVA	{"phone": "+70726252779"}
0005434825427	1F7A8E	2574 200413	LIDIYA DAVYDOVA	{"phone": "+70310225416"}
0005434825428	504074	8729 454586	VIKTOR SOROKIN	{"email": "sorokin.viktor-1971@postgrespro.ru", "phone": "+70011434997"}
0005434825429	8369A3	3639 111479	LYUBOV KUDRYASHOVA	{"email": "kudryashoval_011976@postgrespro.ru", "phone": "+70644294367"}
0005434825430	71F2D4	6479 017200	MARIYA MAKAROVA	{"phone": "+70796556686"}
0005434825431	71F2D4	3430 045049	ANASTASIYA DMITRIEVA	{"email": "admitrieva-081965@postgrespro.ru", "phone": "+70597386077"}
0005434825432	76EFC1	1830 771938	ALEKSANDR ILIN	{"email": "ilin.aleksandr_051974@postgrespro.ru", "phone": "+70475263947"}
0005434825433	C3D52D	2238 337304	RUSLAN MATVEEV	{"email": "ruslan-matveev-111974@postgrespro.ru", "phone": "+70244575504"}
0005434825434	0A55C8	6916 172936	VLADIMIR FEDOROV	{"email": "v-fedorov-11081983@postgrespro.ru", "phone": "+70609008765"}
0005434825435	221318	5918 915154	EVGENIY KONOVALOV	{"email": "ekonovalov081984@postgrespro.ru", "phone": "+70977634348"}
0005434825436	C64155	7688 551719	MARIYA VASILEVA	{"email": "vasileva-mariya_1958@postgrespro.ru", "phone": "+70862095316"}
0005434825437	22D703	8693 339666	EVDOKIYA ZOTOVA	{"email": "zotova_e-071975@postgrespro.ru", "phone": "+70740427463"}
0005434825438	085C36	5368 299429	ALEKSEY ILIN	{"phone": "+70535651735"}
0005434825439	93F789	6663 605125	ANDREY NIKITIN	{"email": "anikitin_08111977@postgrespro.ru", "phone": "+70490549282"}
0005434825440	93F789	0235 170147	ALSU FROLOVA	{"phone": "+70055740272"}
0005434825441	BFCC15	8693 818812	NIKOLAY PAVLOV	{"email": "pavlov.n-1979@postgrespro.ru", "phone": "+70151828834"}
0005434825442	718B75	4770 786523	VASILIY GORBUNOV	{"phone": "+70299828830"}
0005434825443	4EA35D	6593 077240	TAISIYA IVANOVA	{"email": "ivanova_t.081974@postgrespro.ru", "phone": "+70266382735"}
0005434825444	4EA35D	4543 469435	MARINA NESTEROVA	{"email": "marina.nesterova28031964@postgrespro.ru", "phone": "+70188478139"}
0005434825445	FEDDE2	7769 007482	NATALYA LUKYANOVA	{"email": "natalya-lukyanova_1965@postgrespro.ru", "phone": "+70340452736"}
0005434825446	48EFB8	4949 008227	LILIYA MIKHAYLOVA	{"email": "lmikhaylova21121979@postgrespro.ru", "phone": "+70553072258"}
0005434825447	854D02	1742 869670	ARTEM ZHURAVLEV	{"email": "artem_zhuravlev121976@postgrespro.ru", "phone": "+70095915402"}
0005434825448	D1169D	4823 071561	VYACHESLAV MATVEEV	{"email": "vyacheslav.matveev111975@postgrespro.ru", "phone": "+70578552574"}
0005434825449	D1169D	5652 735779	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr041974@postgrespro.ru", "phone": "+70282332820"}
0005434825450	3D73A0	4705 993438	IGOR SEMENOV	{"phone": "+70685695765"}
0005434825451	D1FDC8	6286 189382	YULIYA KISELEVA	{"phone": "+70501526416"}
0005434825452	B9CACF	8766 574668	LIDIYA LEBEDEVA	{"phone": "+70925018522"}
0005434825453	03B437	2829 525925	IRINA KUZMINA	{"phone": "+70053480202"}
0005434825454	CC0FE4	8262 545660	ARTEM SMIRNOV	{"phone": "+70917409754"}
0005434825455	3D32DF	7340 737296	DMITRIY KOROLEV	{"phone": "+70124956626"}
0005434825456	3D32DF	6162 691077	OLGA BELYAEVA	{"email": "belyaeva-o_1967@postgrespro.ru", "phone": "+70341332816"}
0005434825457	E7E2DF	9047 711630	SARIYA VLASOVA	{"email": "vlasova_s_061981@postgrespro.ru", "phone": "+70556263900"}
0005434825458	9A51A4	7808 534190	GALINA BELYAEVA	{"phone": "+70562311065"}
0005434825459	9A51A4	8754 855256	DANIIL MAKAROV	{"email": "makarov.daniil.17021975@postgrespro.ru", "phone": "+70564171496"}
0005434825460	9A51A4	8829 728983	ALEKSEY ABRAMOV	{"email": "abramov_aleksey1974@postgrespro.ru", "phone": "+70631421554"}
0005434825461	7C5E1A	4678 449614	NIKOLAY MOISEEV	{"email": "nikolay.moiseev.01101965@postgrespro.ru", "phone": "+70572443059"}
0005434825462	A29B8B	0964 100281	ALEKSANDR KUZNECOV	{"phone": "+70215583592"}
0005434825463	7C7281	4070 026524	TIMOFEY BELOV	{"email": "t.belov.01121983@postgrespro.ru", "phone": "+70320316187"}
0005434825464	94B3E0	7262 156446	ELENA DAVYDOVA	{"phone": "+70209300249"}
0005434825465	19C3D2	6883 492056	NATALYA OSIPOVA	{"email": "nosipova-031974@postgrespro.ru", "phone": "+70695817451"}
0005434825466	19C3D2	3006 496776	LIDIYA KUZNECOVA	{"email": "kuznecova_lidiya.011967@postgrespro.ru", "phone": "+70493681603"}
0005434825467	19C3D2	1105 757894	OLGA AKIMOVA	{"phone": "+70312040064"}
0005434825468	F4DF68	4537 376204	MAKSIM NIKOLAEV	{"email": "mnikolaev10101978@postgrespro.ru", "phone": "+70161307464"}
0005434825469	B9ADF4	1975 178985	MARINA SERGEEVA	{"phone": "+70705164294"}
0005434825470	ABB0F7	5029 969213	ANATOLIY GAVRILOV	{"phone": "+70074547933"}
0005434825471	1A30F4	9470 400582	ALEKSEY SIDOROV	{"phone": "+70570206722"}
0005434825472	1A30F4	0500 676956	ALEKSANDR ZAYCEV	{"email": "aleksandr.zaycev_06081980@postgrespro.ru", "phone": "+70476130976"}
0005434825473	1A30F4	0171 606966	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila-25101979@postgrespro.ru", "phone": "+70651456163"}
0005434825474	A6A5A7	5415 045059	IGOR SERGEEV	{"email": "i_sergeev_01051973@postgrespro.ru", "phone": "+70767266182"}
0005434825475	DD1B4E	1110 920323	SERGEY IVANOV	{"phone": "+70905428417"}
0005434825476	00240A	8105 926409	ANATOLIY POPOV	{"email": "anatoliypopov-07031978@postgrespro.ru", "phone": "+70956700943"}
0005434825477	0D07F4	7538 955274	ALEKSANDR MAKAROV	{"phone": "+70988351804"}
0005434825478	0D07F4	1203 084195	MIKHAIL VOLKOV	{"email": "mikhail-volkov091977@postgrespro.ru", "phone": "+70160486271"}
0005434825479	C9E03C	6231 427461	ILDAR FROLOV	{"phone": "+70599166703"}
0005434825480	2450B0	9898 462447	NIKOLAY ZAKHAROV	{"email": "n-zakharov.1971@postgrespro.ru", "phone": "+70413682610"}
0005434825481	10C617	4740 037517	LYUDMILA MAKSIMOVA	{"email": "l.maksimova.031972@postgrespro.ru", "phone": "+70374777435"}
0005434825482	0AB0BB	3220 037560	VERONIKA KUZNECOVA	{"phone": "+70044917364"}
0005434825483	D8D37F	7193 760913	OLGA TIMOFEEVA	{"phone": "+70328459273"}
0005434825484	D8D37F	0729 944153	SVETLANA FOMINA	{"phone": "+70881605531"}
0005434825485	2376C7	2524 795021	MARINA LEBEDEVA	{"phone": "+70846577677"}
0005434825486	2376C7	8883 430194	MIKHAIL SOLOVEV	{"email": "mikhail-solovev.05041972@postgrespro.ru", "phone": "+70717679543"}
0005434825487	162E2E	3633 128583	ROMAN SAVELEV	{"email": "rsavelev.101977@postgrespro.ru", "phone": "+70775610550"}
0005434825488	250C29	4075 913264	ANDREY FROLOV	{"phone": "+70022920562"}
0005434825489	7D9922	6382 205561	SVETLANA VOROBEVA	{"phone": "+70698064289"}
0005434825490	FBC02A	6068 847492	NADEZHDA VOLKOVA	{"email": "volkovan11071979@postgrespro.ru", "phone": "+70089979238"}
0005434825491	EBDCB5	6631 291899	VLADIMIR IVANOV	{"phone": "+70481755738"}
0005434825492	D08A6C	2674 621888	SERGEY ZAKHAROV	{"phone": "+70849674274"}
0005434825493	D08A6C	7825 320629	VALENTINA MAKAROVA	{"phone": "+70475826841"}
0005434825494	E309EA	8832 129420	LYUBOV SOROKINA	{"email": "sorokina-l.021977@postgrespro.ru", "phone": "+70310280371"}
0005434825495	E309EA	3943 692055	YURIY BORISOV	{"phone": "+70805044998"}
0005434825496	0E76E6	7834 266363	ANATOLIY MELNIKOV	{"phone": "+70239941169"}
0005434825497	0E76E6	7923 033241	GALINA ISAEVA	{"email": "isaeva_galina-041967@postgrespro.ru", "phone": "+70554002540"}
0005434825498	3567D1	8744 207834	VLADIMIR FROLOV	{"email": "vladimirfrolov1969@postgrespro.ru", "phone": "+70212337006"}
0005434825499	3BF06A	8091 064441	DARYA LEBEDEVA	{"email": "d-lebedeva1972@postgrespro.ru", "phone": "+70523164533"}
0005434825500	3BF06A	5113 896145	GENNADIY DAVYDOV	{"phone": "+70812323367"}
0005434825501	E7232E	5861 210407	VENIAMIN ISAEV	{"email": "isaevv.051969@postgrespro.ru", "phone": "+70718825353"}
0005434825502	02B9F4	0618 372541	NADEZHDA MELNIKOVA	{"phone": "+70764233845"}
0005434825503	B04FCA	0990 815932	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_a03051977@postgrespro.ru", "phone": "+70037590361"}
0005434825504	E2896E	9641 661961	DARYA ALEKSANDROVA	{"email": "daleksandrova021977@postgrespro.ru", "phone": "+70284818662"}
0005434825505	F92324	7268 166070	SERGEY IVANOV	{"email": "sergey-ivanov1984@postgrespro.ru", "phone": "+70068898925"}
0005434825506	F9B4AF	7379 153243	YURIY KONOVALOV	{"email": "konovalov-yuriy_25021965@postgrespro.ru", "phone": "+70187443423"}
0005434825507	2164DA	7410 993503	GALINA PAVLOVA	{"email": "pavlova_g_1979@postgrespro.ru", "phone": "+70266960895"}
0005434825508	B8E751	8743 700278	VIKTOR ZHURAVLEV	{"phone": "+70966933063"}
0005434825509	1B1E89	3651 103487	EGOR DAVYDOV	{"phone": "+70807598978"}
0005434825510	C5D935	8760 239743	TATYANA KOROLEVA	{"email": "tatyana-koroleva07041966@postgrespro.ru", "phone": "+70944042046"}
0005434825511	04DC3B	3129 386994	VALENTINA KUZNECOVA	{"phone": "+70850421995"}
0005434825512	47CE3D	6652 394327	RAMIL MAKSIMOV	{"email": "r-maksimov-111961@postgrespro.ru", "phone": "+70302650936"}
0005434825513	7241E3	1226 977075	ALEKSEY MIRONOV	{"phone": "+70027226608"}
0005434825514	EE03CA	0223 453546	IGOR IVANOV	{"phone": "+70152457132"}
0005434825515	548949	0526 872101	VIKTOR MEDVEDEV	{"phone": "+70291365604"}
0005434825516	548949	7011 810401	LIDIYA IVANOVA	{"email": "lidiya-ivanova_051965@postgrespro.ru", "phone": "+70683411300"}
0005434825517	FEF313	9788 050655	DMITRIY MAKAROV	{"phone": "+70108916587"}
0005434825518	FEF313	4801 717834	ROMAN KISELEV	{"phone": "+70397189511"}
0005434825519	FE73C4	1912 301540	NATALIYA LEBEDEVA	{"email": "nataliya-lebedeva1984@postgrespro.ru", "phone": "+70694409160"}
0005434825520	FE73C4	5315 318894	TATYANA MARTYNOVA	{"email": "martynova-tatyana28021966@postgrespro.ru", "phone": "+70780610973"}
0005434825521	8C485A	2847 240683	VALERIY VASILEV	{"email": "valeriyvasilev_1971@postgrespro.ru", "phone": "+70040617817"}
0005434825522	42A532	0205 631520	RUSLAN IVANOV	{"phone": "+70098941371"}
0005434825523	1CE386	2860 184316	GENNADIY NIKITIN	{"phone": "+70352134875"}
0005434825524	5CF15B	2069 253699	IVAN MELNIKOV	{"email": "melnikov.i-071971@postgrespro.ru", "phone": "+70003883003"}
0005434825525	C0D8D5	9956 131473	YURIY FEDOROV	{"email": "yuriy-fedorov-27101975@postgrespro.ru", "phone": "+70207232842"}
0005434825526	C0D8D5	6312 756396	ANDREY STEPANOV	{"phone": "+70275592897"}
0005434825527	CF2EE1	3839 048666	VALENTINA SERGEEVA	{"email": "valentina_sergeeva.061968@postgrespro.ru", "phone": "+70059363288"}
0005434825528	00D2FF	9954 787952	RUSLAN NIKITIN	{"phone": "+70974921134"}
0005434825529	CF9CA6	0165 514055	VASILIY PAVLOV	{"email": "vasiliy_pavlov_24071979@postgrespro.ru", "phone": "+70070025110"}
0005434825530	B08A5C	0963 335483	TAMARA VASILEVA	{"phone": "+70795015035"}
0005434825531	4393A1	1568 817974	SVETLANA AKIMOVA	{"email": "akimova-s-041972@postgrespro.ru", "phone": "+70183364516"}
0005434825532	73F988	1188 856923	MURAT ANDREEV	{"phone": "+70597406559"}
0005434825533	73F988	4880 386461	KONSTANTIN EGOROV	{"email": "konstantin_egorov.1970@postgrespro.ru", "phone": "+70292564534"}
0005434825534	BAD9F5	3854 909544	ANDREY DAVYDOV	{"phone": "+70175481212"}
0005434825535	B792CE	3869 311206	SERGEY POPOV	{"email": "popov-s07071972@postgrespro.ru", "phone": "+70920803405"}
0005434825536	721784	4471 972248	VIKTOR SCHERBAKOV	{"phone": "+70060550409"}
0005434825537	E61180	1295 480023	VALENTINA KONDRATEVA	{"phone": "+70844029686"}
0005434825538	252EBA	2693 943630	SERGEY FROLOV	{"email": "frolov.sergey19031972@postgrespro.ru", "phone": "+70576095305"}
0005434825539	DAE5E2	8320 388203	SERGEY KAZAKOV	{"email": "sergey_kazakov.031984@postgrespro.ru", "phone": "+70160132837"}
0005434825540	69BF74	3187 183710	IRINA GERASIMOVA	{"phone": "+70297354074"}
0005434825541	C3D47A	7920 009433	NATALYA PETROVA	{"email": "n.petrova1975@postgrespro.ru", "phone": "+70655713105"}
0005434825542	C3D47A	7425 021369	MARINA GUSEVA	{"phone": "+70554741158"}
0005434825544	D5C3DF	8975 474133	VASILIY MOISEEV	{"email": "v.moiseev.111967@postgrespro.ru", "phone": "+70393836291"}
0005434825545	DC4468	7479 895417	ELIZAVETA VOROBEVA	{"phone": "+70390602477"}
0005434825546	8782F7	1383 782422	SERGEY PETROV	{"phone": "+70223827333"}
0005434825547	F27F52	1576 769332	TAISIYA SERGEEVA	{"email": "sergeevataisiya_1974@postgrespro.ru", "phone": "+70222884996"}
0005434825548	D8DBDB	0301 492410	MARINA SOROKINA	{"phone": "+70802359241"}
0005434825549	D8DBDB	3370 333550	RUSLAN GAVRILOV	{"phone": "+70681459128"}
0005434825550	8353A6	0066 881419	EKATERINA BORISOVA	{"email": "ekaterina_borisova101964@postgrespro.ru", "phone": "+70927178296"}
0005434825551	2CBECF	3067 420114	TATYANA RODIONOVA	{"phone": "+70914498282"}
0005434825552	93871D	9259 231721	ALEKSANDR DENISOV	{"phone": "+70085201451"}
0005434825553	EE6ADD	9362 709024	NIKOLAY SOLOVEV	{"email": "solovev_n.18091980@postgrespro.ru", "phone": "+70053423323"}
0005434825554	EE6ADD	2759 306534	EKATERINA NESTEROVA	{"email": "e-nesterova081955@postgrespro.ru", "phone": "+70590643277"}
0005434825555	68B474	0111 888131	SERGEY KRASNOV	{"email": "sergeykrasnov_011962@postgrespro.ru", "phone": "+70257628555"}
0005434825556	3AA1AF	7932 135369	LYUDMILA GRISHINA	{"email": "l_grishina.26051972@postgrespro.ru", "phone": "+70500524146"}
0005434825557	3AA1AF	9623 154444	RUSLAN BONDARENKO	{"email": "bondarenko.r_1975@postgrespro.ru", "phone": "+70917270961"}
0005434825558	3AA1AF	7793 620587	VLADIMIR VOLKOV	{"phone": "+70693527450"}
0005434825559	D855AB	7920 106358	TATYANA VASILEVA	{"phone": "+70371059529"}
0005434825560	C0F41F	7092 340129	ROMAN SHEVCHENKO	{"email": "romanshevchenko-011980@postgrespro.ru", "phone": "+70541028856"}
0005434825561	9F5BFD	0681 597286	MARINA ISAEVA	{"email": "isaevamarina.111971@postgrespro.ru", "phone": "+70494458659"}
0005434825562	9F5BFD	8105 713930	RODION MOROZOV	{"phone": "+70005622870"}
0005434825563	A09983	5502 556313	VITALIY MEDVEDEV	{"email": "vmedvedev-101968@postgrespro.ru", "phone": "+70445788037"}
0005434825564	A09983	7033 254197	VIOLETTA ROMANOVA	{"phone": "+70548922893"}
0005434825565	1F6F82	9189 886453	ANTON KUZMIN	{"phone": "+70737633767"}
0005434825566	1F6F82	1575 456105	IVAN KONOVALOV	{"email": "konovalovivan1973@postgrespro.ru", "phone": "+70817810392"}
0005434825567	A7CBB5	9520 151722	VIKTOR PETROV	{"email": "vpetrov31101974@postgrespro.ru", "phone": "+70547809181"}
0005434825568	A7CBB5	2593 629347	SVETLANA DAVYDOVA	{"phone": "+70474963175"}
0005434825569	D0837A	3731 302767	IVAN MAKAROV	{"phone": "+70410670921"}
0005434825570	105540	4641 417254	DANIIL POPOV	{"email": "daniil.popov031983@postgrespro.ru", "phone": "+70648154274"}
0005434825571	105540	2290 205605	SERGEY FOMIN	{"email": "s_fomin.18051972@postgrespro.ru", "phone": "+70425408257"}
0005434825572	777CFF	4612 268352	FEDOR MOISEEV	{"phone": "+70535427963"}
0005434825573	FD46AF	3354 015948	OLEG POPOV	{"email": "oleg.popov-27081982@postgrespro.ru", "phone": "+70475200104"}
0005434825574	FD46AF	3433 092698	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr031982@postgrespro.ru", "phone": "+70046270329"}
0005434825575	38222E	2137 634240	VALENTINA LAZAREVA	{"email": "lazarevavalentina30101974@postgrespro.ru", "phone": "+70880738519"}
0005434825576	B63523	9961 462546	VADIM POPOV	{"email": "vadim.popov-1958@postgrespro.ru", "phone": "+70304710330"}
0005434825577	23EC55	8296 141405	ALEKSEY NIKOLAEV	{"phone": "+70925907802"}
0005434825578	D8E810	3944 137127	GENNADIY ALEKSEEV	{"phone": "+70460845183"}
0005434825579	D8E810	7931 352546	VYACHESLAV POPOV	{"email": "popov-v081972@postgrespro.ru", "phone": "+70048440450"}
0005434825580	2571B4	3040 474189	GENNADIY BARANOV	{"email": "g.baranov041961@postgrespro.ru", "phone": "+70939093798"}
0005434825581	2571B4	6769 339701	OLGA AFANASEVA	{"phone": "+70306435790"}
0005434825582	2571B4	8386 031766	VLADIMIR GERASIMOV	{"phone": "+70437574859"}
0005434825583	444012	7071 498460	VYACHESLAV SEMENOV	{"email": "semenov-vyacheslav_1976@postgrespro.ru", "phone": "+70214754825"}
0005434825584	444012	0517 395453	ALEKSANDR FEDOROV	{"phone": "+70631730014"}
0005434825585	7A6D30	7992 259234	NATALIYA MIRONOVA	{"phone": "+70497716250"}
0005434825586	B7595A	0312 370223	VYACHESLAV NAZAROV	{"phone": "+70728072689"}
0005434825587	1AEDCD	6650 825734	LILIYA NESTEROVA	{"phone": "+70322789401"}
0005434825588	FF9D30	5752 828607	VALENTINA RYABOVA	{"email": "ryabova-v-061966@postgrespro.ru", "phone": "+70529497976"}
0005434825589	FF9D30	8267 415704	DMITRIY MOROZOV	{"email": "dmitriy.morozov_011976@postgrespro.ru", "phone": "+70338006428"}
0005434825590	8E0555	6376 220780	ALEKSEY PAVLOV	{"email": "a_pavlov_19071975@postgrespro.ru", "phone": "+70812788009"}
0005434825591	5194FE	1065 276725	IVAN DENISOV	{"email": "denisov_ivan1975@postgrespro.ru", "phone": "+70706239894"}
0005434825592	12BD71	8011 740134	DMITRIY MEDVEDEV	{"email": "d-medvedev.07041971@postgrespro.ru", "phone": "+70498830289"}
0005434825593	12BD71	1400 246412	NIKITA SIDOROV	{"phone": "+70139130593"}
0005434825594	D2ACB3	7596 667020	VLADIMIR MEDVEDEV	{"phone": "+70516625552"}
0005434825595	010C37	9488 804870	VALENTIN KAZAKOV	{"email": "valentin_kazakov121971@postgrespro.ru", "phone": "+70547954389"}
0005434825596	DD41DF	2075 040975	VALERIY BELOV	{"email": "belov-valeriy_1971@postgrespro.ru", "phone": "+70899665146"}
0005434825597	B67508	2642 381836	ALEKSANDR BELOV	{"email": "belov-aleksandr.01051987@postgrespro.ru", "phone": "+70359273203"}
0005434825598	B67508	8685 132129	ANDREY ZAKHAROV	{"phone": "+70647656162"}
0005434825599	457E41	8834 034380	RUSLAN POPOV	{"email": "popov-ruslan-1961@postgrespro.ru", "phone": "+70576677626"}
0005434825600	8992BC	4410 294199	VLADIMIR PETROV	{"phone": "+70464672243"}
0005434825601	5C97F8	9443 435631	OLGA EGOROVA	{"phone": "+70535011399"}
0005434825602	5C97F8	9094 476966	GALINA KOVALEVA	{"email": "galina.kovaleva_1977@postgrespro.ru", "phone": "+70400309984"}
0005434825603	5C97F8	1037 703218	IRINA CHERNOVA	{"email": "chernovai_1956@postgrespro.ru", "phone": "+70205008721"}
0005434825604	822AA0	1131 734702	SVETLANA PETROVA	{"email": "petrova_svetlana-1973@postgrespro.ru", "phone": "+70777669485"}
0005434825605	B8B810	7465 697029	OLGA RODIONOVA	{"phone": "+70590227672"}
0005434825606	659D9A	0830 694157	DENIS ORLOV	{"phone": "+70399373094"}
0005434825607	659D9A	0231 378541	DANIYA KUZNECOVA	{"email": "kuznecovad_081980@postgrespro.ru", "phone": "+70683272445"}
0005434825608	659D9A	2581 970371	MAKSIM KOZLOV	{"phone": "+70030203053"}
0005434825609	2915EE	3124 396651	KSENIYA NOVIKOVA	{"phone": "+70061308035"}
0005434825610	E3E0B7	4254 191299	LEONID EGOROV	{"email": "egorov.l_30041976@postgrespro.ru", "phone": "+70590819216"}
0005434825611	044397	2790 655436	SERGEY MAKAROV	{"phone": "+70609044791"}
0005434825612	C5356A	9995 100154	LYUBOV PETROVA	{"email": "petrova-l30031973@postgrespro.ru", "phone": "+70301211920"}
0005434825613	E5A039	0862 715716	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov-15091971@postgrespro.ru", "phone": "+70858736596"}
0005434825614	E25D2A	5120 176515	ANATOLIY IVANOV	{"phone": "+70222946965"}
0005434825615	E25D2A	7460 676868	OLGA SMIRNOVA	{"email": "smirnova_o1975@postgrespro.ru", "phone": "+70548551229"}
0005434825616	E25D2A	9356 104253	NIKOLAY ZAKHAROV	{"phone": "+70191416022"}
0005434825617	595E59	5380 097336	IVAN SOROKIN	{"email": "sorokin-ivan15061970@postgrespro.ru", "phone": "+70031888094"}
0005434825618	272FFB	2456 173748	RUSTAM NAZAROV	{"phone": "+70369223996"}
0005434825619	FEA674	7952 103065	RUDOLF MELNIKOV	{"phone": "+70259052202"}
0005434825620	FEA674	8740 466224	SERGEY GRIGOREV	{"phone": "+70551251875"}
0005434825621	E7CED1	2779 538427	GLEB KAZAKOV	{"email": "kazakov_g-02091973@postgrespro.ru", "phone": "+70294131971"}
0005434825622	E7CED1	0544 341826	GENNADIY POPOV	{"email": "gennadiy-popov_071965@postgrespro.ru", "phone": "+70835143164"}
0005434825623	E02E60	8102 302584	YURIY DMITRIEV	{"phone": "+70027720699"}
0005434825624	E02E60	5183 056873	MAKSIM MOROZOV	{"email": "morozov.maksim071973@postgrespro.ru", "phone": "+70537705743"}
0005434825625	94C5CB	2953 170593	MARINA KUZNECOVA	{"phone": "+70509628246"}
0005434825626	46F1F8	6463 444535	EKATERINA ANTONOVA	{"email": "e.antonova.1963@postgrespro.ru", "phone": "+70528996897"}
0005434825627	1ACEC0	5737 302402	VIKTOR EGOROV	{"email": "egorovv.121984@postgrespro.ru", "phone": "+70163597920"}
0005434825628	1ACEC0	9054 313849	LIDIYA EFREMOVA	{"email": "lidiya_efremova-1968@postgrespro.ru", "phone": "+70668305158"}
0005434825629	575D99	0484 205596	VITALIY KUZMIN	{"email": "vitaliy_kuzmin-091977@postgrespro.ru", "phone": "+70633904536"}
0005434825630	575D99	6124 946374	GALINA VOLKOVA	{"phone": "+70043085528"}
0005434825631	E11A91	4548 656321	POLINA ISAEVA	{"phone": "+70814353166"}
0005434825632	E11A91	2149 238972	EVGENIYA MIRONOVA	{"email": "mironova-e_16031966@postgrespro.ru", "phone": "+70749269706"}
0005434825633	894B08	8701 568695	ROMAN SEMENOV	{"phone": "+70280695333"}
0005434825634	1E13C9	3323 355932	DMITRIY MOISEEV	{"phone": "+70307429542"}
0005434825635	9426BE	5305 393251	TIMOFEY IVANOV	{"phone": "+70573986018"}
0005434825636	2EDEEA	1774 297180	NATALYA KALININA	{"phone": "+70909944563"}
0005434825637	2EDEEA	4999 402797	VIKTOR SMIRNOV	{"email": "smirnovviktor-121958@postgrespro.ru", "phone": "+70304547331"}
0005434825638	EB7AAA	4551 584871	TATYANA ORLOVA	{"phone": "+70246939433"}
0005434825639	EB7AAA	1327 061355	IRINA KOZLOVA	{"phone": "+70114423905"}
0005434825640	6FA2C5	1764 295982	ALEKSEY VASILEV	{"email": "vasilev_aleksey-041973@postgrespro.ru", "phone": "+70502234633"}
0005434825641	B4FD39	9767 596507	OLGA MATVEEVA	{"email": "matveeva_olga121959@postgrespro.ru", "phone": "+70802961753"}
0005434825642	58AFBC	7554 866095	DMITRIY ZAYCEV	{"email": "dmitriy-zaycev_04011959@postgrespro.ru", "phone": "+70681137049"}
0005434825643	246987	5569 421169	ELENA ALEKSANDROVA	{"email": "elena.aleksandrova_1971@postgrespro.ru", "phone": "+70447337922"}
0005434825644	A8BE9A	9908 307525	NADEZHDA VASILEVA	{"phone": "+70551270882"}
0005434825645	050415	8383 518691	ARTEM POPOV	{"phone": "+70253779234"}
0005434825646	050415	4774 305557	ELENA LOGINOVA	{"phone": "+70089619664"}
0005434825647	6ED8BF	1853 114992	DMITRIY PETROV	{"email": "petrov_dmitriy_111969@postgrespro.ru", "phone": "+70126175093"}
0005434825648	6ED8BF	1278 051858	DMITRIY ZAKHAROV	{"phone": "+70491165138"}
0005434825649	3C8D50	2833 128301	MARINA BOGDANOVA	{"phone": "+70115166742"}
0005434825650	6E9FF7	7162 709731	GALINA SERGEEVA	{"phone": "+70183007104"}
0005434825651	6E9FF7	0629 484373	SERGEY KUZNECOV	{"email": "kuznecov-sergey_121970@postgrespro.ru", "phone": "+70353736662"}
0005434825652	48599D	0987 409847	ALEKSANDR BORISOV	{"email": "borisov_a_111974@postgrespro.ru", "phone": "+70222571887"}
0005434825653	73A09D	2946 969839	GALINA KOROLEVA	{"email": "koroleva_galina.071974@postgrespro.ru", "phone": "+70495530333"}
0005434825654	73A09D	5826 862583	VASILIY IVANOV	{"email": "ivanov_vasiliy_1971@postgrespro.ru", "phone": "+70670227660"}
0005434825655	200090	1639 724662	ELENA SIDOROVA	{"email": "elena.sidorova-031978@postgrespro.ru", "phone": "+70214477424"}
0005434825656	ADCE5A	8730 991683	TATYANA ERMAKOVA	{"phone": "+70678305782"}
0005434825657	0809E4	6753 334299	NINA BELYAEVA	{"email": "belyaeva.nina.1978@postgrespro.ru", "phone": "+70090546412"}
0005434825658	A3CB9C	8549 775683	IGOR POPOV	{"email": "igorpopov.1965@postgrespro.ru", "phone": "+70745069933"}
0005434825659	A3CB9C	8478 340359	ALEKSANDRA YAKOVLEVA	{"email": "yakovlevaa_111963@postgrespro.ru", "phone": "+70409475648"}
0005434825660	FC8320	6787 236471	OKSANA BOGDANOVA	{"email": "oksanabogdanova-051974@postgrespro.ru", "phone": "+70389883357"}
0005434825661	DCD6A8	4375 726624	GALINA MIRONOVA	{"phone": "+70870437022"}
0005434825662	DCD6A8	6486 487995	KSENIYA SEMENOVA	{"email": "semenova-kseniya-101971@postgrespro.ru", "phone": "+70028444300"}
0005434825663	1D05B3	2149 230898	DMITRIY FILIPPOV	{"email": "filippov_dmitriy-1972@postgrespro.ru", "phone": "+70181065015"}
0005434825664	52C866	3406 104017	ROMAN SIDOROV	{"phone": "+70232722136"}
0005434825665	B09611	2089 980970	RAISA SOLOVEVA	{"phone": "+70436000620"}
0005434825666	B09611	0140 025342	VALENTINA KULIKOVA	{"phone": "+70867015760"}
0005434825667	A8C3AF	8258 501965	YURIY NOVIKOV	{"phone": "+70167206325"}
0005434825668	023410	1433 481526	LYUBOV DENISOVA	{"phone": "+70277924174"}
0005434825669	D8F7DC	4882 354646	NIKOLAY KOZLOV	{"phone": "+70345500896"}
0005434825670	B02738	3009 322155	ALEKSANDR ROMANOV	{"email": "aleksandrromanov-06121972@postgrespro.ru", "phone": "+70490604335"}
0005434825671	B02738	9410 358626	ANDREY POPOV	{"email": "andrey.popov1977@postgrespro.ru", "phone": "+70419507670"}
0005434825672	E5062F	4332 029439	SVETLANA KISELEVA	{"phone": "+70721982675"}
0005434825673	A3EF09	7481 509771	ELENA GAVRILOVA	{"email": "e-gavrilova_07011975@postgrespro.ru", "phone": "+70863475211"}
0005434825674	A3EF09	0207 186734	ALEKSEY NOVIKOV	{"email": "novikova031964@postgrespro.ru", "phone": "+70034659511"}
0005434825675	A3EF09	0701 163213	ELENA FROLOVA	{"email": "elena-frolova041975@postgrespro.ru", "phone": "+70417674988"}
0005434825676	1C77BE	6996 761104	LIDIYA YAKOVLEVA	{"phone": "+70593284035"}
0005434825677	85388C	9152 094152	ANDREY NAUMOV	{"phone": "+70376591855"}
0005434825678	7CE981	0704 492595	TATYANA BOGDANOVA	{"phone": "+70061641526"}
0005434825679	05DC6E	8892 340587	GALINA MELNIKOVA	{"email": "melnikova_galina.1974@postgrespro.ru", "phone": "+70642114283"}
0005434825680	3CC989	7901 485733	KIRA NOVIKOVA	{"email": "novikova.kira-20041972@postgrespro.ru", "phone": "+70247116997"}
0005434825681	71EB61	3539 744731	GALINA LUKYANOVA	{"phone": "+70852586058"}
0005434825682	C8F7E3	0479 243636	IVAN SIDOROV	{"email": "i-sidorov_081976@postgrespro.ru", "phone": "+70065399705"}
0005434825683	022CEC	1541 481219	SERGEY PETROV	{"email": "sergey.petrov-19031970@postgrespro.ru", "phone": "+70127184357"}
0005434825684	262644	1130 623507	VALERIY FEDOROV	{"email": "v-fedorov-03021972@postgrespro.ru", "phone": "+70340571881"}
0005434825685	597FBC	7668 691585	ANATOLIY MOISEEV	{"phone": "+70535206273"}
0005434825686	921397	7678 751447	GLEB TARASOV	{"email": "glebtarasov-22051969@postgrespro.ru", "phone": "+70138176093"}
0005434825687	921397	0966 806653	ALEKSEY MOROZOV	{"email": "amorozov.021977@postgrespro.ru", "phone": "+70753658906"}
0005434825688	5D0167	2899 005197	VLADIMIR MELNIKOV	{"email": "melnikov.vladimir-091984@postgrespro.ru", "phone": "+70239230193"}
0005434825689	2B3DE8	6841 271003	ALEVTINA GAVRILOVA	{"email": "alevtina_gavrilova.1983@postgrespro.ru", "phone": "+70178250601"}
0005434825690	2B3DE8	9379 698291	SERGEY MARTYNOV	{"phone": "+70400990848"}
0005434825691	C1951C	9774 582094	PETR TARASOV	{"email": "tarasov.p.101978@postgrespro.ru", "phone": "+70116456788"}
0005434825692	A06F01	9721 359214	VALERIY NIKOLAEV	{"email": "valeriy_nikolaev_101979@postgrespro.ru", "phone": "+70423834750"}
0005434825693	0FB3CC	0761 047247	ALEKSANDR SOKOLOV	{"email": "sokolova1968@postgrespro.ru", "phone": "+70339752370"}
0005434825694	0FB3CC	5581 757435	LYUDMILA BARANOVA	{"phone": "+70515403025"}
0005434825695	6FC064	9333 679132	NATALYA SIDOROVA	{"phone": "+70994062250"}
0005434825696	412AC2	6459 901090	EKATERINA ARKHIPOVA	{"email": "e-arkhipova.28041963@postgrespro.ru", "phone": "+70653361419"}
0005434825697	71869E	9002 807810	ALEKSEY EGOROV	{"email": "egorov-aleksey_1979@postgrespro.ru", "phone": "+70350547717"}
0005434825698	71869E	6509 197898	PRASKOVYA GAVRILOVA	{"email": "gavrilova.p_1973@postgrespro.ru", "phone": "+70556860343"}
0005434825699	AA3CAE	7738 866853	NADEZHDA KUZMINA	{"phone": "+70967771866"}
0005434825700	CFE3BD	5125 350864	OLGA BORISOVA	{"email": "olga.borisova1973@postgrespro.ru", "phone": "+70855294638"}
0005434825701	A23B41	1345 993653	KONSTANTIN SHEVCHENKO	{"email": "kshevchenko_19061970@postgrespro.ru", "phone": "+70827390311"}
0005434825702	C9C0E7	6500 358269	ELENA POLYAKOVA	{"phone": "+70847660261"}
0005434825703	4BC717	9891 819185	NINA STEPANOVA	{"email": "nina_stepanova-1970@postgrespro.ru", "phone": "+70123050941"}
0005434825704	F55D8A	9970 570280	PAVEL NIKOLAEV	{"phone": "+70428112976"}
0005434825705	7BAE9E	9598 619982	NATALYA VOLKOVA	{"email": "volkova_n.01011966@postgrespro.ru", "phone": "+70609829001"}
0005434825706	7BAE9E	1366 441613	YULIYA TITOVA	{"email": "titova.y1978@postgrespro.ru", "phone": "+70847438290"}
0005434825707	7BAE9E	2115 004689	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov_14041973@postgrespro.ru", "phone": "+70262005920"}
0005434825708	C596F7	1728 491609	TIMUR ILIN	{"phone": "+70609206686"}
0005434825709	3970D4	0113 428000	NATALYA ALEKSANDROVA	{"email": "natalya-aleksandrova-22031976@postgrespro.ru", "phone": "+70844217778"}
0005434825710	3970D4	1783 343741	ALEFTINA MAKAROVA	{"email": "a-makarova121984@postgrespro.ru", "phone": "+70626354171"}
0005434825711	3970D4	6135 207833	ROMAN SAVELEV	{"phone": "+70190198849"}
0005434825712	B4C131	9141 586776	TATYANA SOROKINA	{"phone": "+70552453311"}
0005434825713	B4C131	5039 202541	ALEKSANDR NOVIKOV	{"email": "a.novikov-091963@postgrespro.ru", "phone": "+70594812641"}
0005434825714	5BDCB2	6714 295177	NATALYA NIKITINA	{"phone": "+70709052849"}
0005434825715	5BDCB2	9775 803187	EVGENIYA TROFIMOVA	{"phone": "+70250903900"}
0005434825716	3D8627	1392 406402	DMITRIY KONOVALOV	{"email": "konovalov.dmitriy-091979@postgrespro.ru", "phone": "+70051971645"}
0005434825717	066F91	8019 725054	ALEKSANDR FEDOROV	{"email": "fedorov_a05111969@postgrespro.ru", "phone": "+70729999122"}
0005434825718	066F91	4841 295291	ALEKSANDR IVANOV	{"email": "ivanovaleksandr_1964@postgrespro.ru", "phone": "+70702914974"}
0005434825719	29CAE4	3604 056975	MIKHAIL BORISOV	{"email": "mikhail.borisov111977@postgrespro.ru", "phone": "+70003292154"}
0005434825720	0A6F41	5200 252040	SERGEY GRIGOREV	{"email": "s.grigorev-061974@postgrespro.ru", "phone": "+70765117546"}
0005434825721	E8B308	2591 115590	ZOYA POPOVA	{"email": "zpopova_091969@postgrespro.ru", "phone": "+70751059019"}
0005434825722	5458FC	7396 974322	ANASTASIYA KARPOVA	{"email": "karpova_anastasiya_121956@postgrespro.ru", "phone": "+70451773164"}
0005434825723	5458FC	7105 354157	GALINA SOKOLOVA	{"email": "galina.sokolova.1972@postgrespro.ru", "phone": "+70093987274"}
0005434825724	AFF993	6592 434831	LIDIYA DAVYDOVA	{"email": "lidiya.davydova.021973@postgrespro.ru", "phone": "+70697736903"}
0005434825725	AFF993	0591 946282	ANATOLIY BORISOV	{"email": "borisov-a-051979@postgrespro.ru", "phone": "+70234939145"}
0005434825726	AFF993	9122 488735	ELENA LUKYANOVA	{"phone": "+70825791376"}
0005434825727	AFF993	7844 938385	SERGEY VOLKOV	{"email": "volkov.sergey021964@postgrespro.ru", "phone": "+70993486642"}
0005434825728	AA4792	9531 698644	OLGA LOGINOVA	{"phone": "+70204429418"}
0005434825729	CAD36B	3886 334166	OLGA AFANASEVA	{"email": "o-afanaseva.1958@postgrespro.ru", "phone": "+70572913330"}
0005434825730	B90658	0984 283000	ZHANNA ZHURAVLEVA	{"phone": "+70244362580"}
0005434825731	B90658	6851 944777	TATYANA PAVLOVA	{"phone": "+70624506788"}
0005434825732	3D948F	3087 602006	SVETLANA ALEKSEEVA	{"email": "alekseeva.s-1974@postgrespro.ru", "phone": "+70349535329"}
0005434825733	1A4A54	4362 552475	OLESYA MAKSIMOVA	{"phone": "+70704593404"}
0005434825734	BBBE98	2626 753547	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-15021973@postgrespro.ru", "phone": "+70159204424"}
0005434825735	BBBE98	0512 282236	RAMIL IVANOV	{"phone": "+70396007428"}
0005434825736	BBBE98	6054 145574	NADEZHDA FOMINA	{"email": "fomina_nadezhda_1961@postgrespro.ru", "phone": "+70393630405"}
0005434825737	B47023	9311 713961	YANA BELOVA	{"email": "belova_yana_1969@postgrespro.ru", "phone": "+70110687273"}
0005434825738	B47023	6923 941979	SERGEY ILIN	{"phone": "+70332634254"}
0005434825739	22403A	0065 034202	KRISTINA KRASNOVA	{"phone": "+70967267208"}
0005434825740	22403A	4136 209331	YURIY MAKAROV	{"email": "makarov-yuriy1962@postgrespro.ru", "phone": "+70016870098"}
0005434825741	E27C5B	1002 637251	BORIS ORLOV	{"email": "orlov_boris_111980@postgrespro.ru", "phone": "+70608262697"}
0005434825742	3D0F3D	8862 090135	VALENTINA PETROVA	{"phone": "+70076063714"}
0005434825743	DE1565	3933 310950	VIKTORIYA FROLOVA	{"email": "v_frolova_1960@postgrespro.ru", "phone": "+70671656339"}
0005434825744	DE1565	1498 041712	TAMARA SAVELEVA	{"phone": "+70988425815"}
0005434825745	9FE0DC	6486 826177	TATYANA MOISEEVA	{"phone": "+70531379158"}
0005434825746	4ABDD7	7282 867108	VLADIMIR PAVLOV	{"email": "pavlovv-1976@postgrespro.ru", "phone": "+70772581784"}
0005434825747	4411E1	7589 561342	ANDREY FROLOV	{"phone": "+70346232311"}
0005434825748	4411E1	4239 553982	DMITRIY KUZNECOV	{"phone": "+70049953424"}
0005434825749	7F48DD	8059 945816	TATYANA LAZAREVA	{"phone": "+70872460355"}
0005434825750	FB4824	5631 857029	NADEZHDA KUZNECOVA	{"email": "kuznecova-n-061969@postgrespro.ru", "phone": "+70097847244"}
0005434825751	FB4824	7496 229928	NATALYA KAZAKOVA	{"email": "kazakova-natalya-1969@postgrespro.ru", "phone": "+70200232866"}
0005434825752	87F7AB	5113 022509	MAKSIM BORISOV	{"phone": "+70679168362"}
0005434825753	87F7AB	6091 149305	VLADIMIR ZAKHAROV	{"email": "zakharovv081964@postgrespro.ru", "phone": "+70722195967"}
0005434825754	E6F226	5116 942708	VLADIMIR KUZNECOV	{"email": "v_kuznecov_061973@postgrespro.ru", "phone": "+70052146832"}
0005434825755	E6F226	0149 538000	YULIYA KOZLOVA	{"phone": "+70921184605"}
0005434825756	0F8F69	6508 609858	ALLA KOZLOVA	{"email": "alla_kozlova-29081982@postgrespro.ru", "phone": "+70018495574"}
0005434825757	2135BE	9757 969045	ELENA KUZNECOVA	{"email": "e-kuznecova.19101975@postgrespro.ru", "phone": "+70864446778"}
0005434825758	2135BE	1700 049936	ANATOLIY KULIKOV	{"email": "anatoliy.kulikov.21091979@postgrespro.ru", "phone": "+70393989488"}
0005434825759	2135BE	3293 316272	DANIYA KOROLEVA	{"phone": "+70489949108"}
0005434825760	33600A	8755 098354	NIKOLAY SOKOLOV	{"phone": "+70772693776"}
0005434825761	67FADC	7743 148721	PAVEL BARANOV	{"phone": "+70379529175"}
0005434825762	529680	2207 411700	ALEKSANDR AFANASEV	{"email": "a-afanasev-1974@postgrespro.ru", "phone": "+70084135080"}
0005434825763	551657	3327 873185	NIKOLAY KUZNECOV	{"phone": "+70927722699"}
0005434825764	551657	9037 784586	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva_1966@postgrespro.ru", "phone": "+70379141067"}
0005434825765	BB3F36	0673 999355	ALEKSANDR ZAKHAROV	{"phone": "+70363922218"}
0005434825766	BB3F36	2056 442156	ALEKSANDR ZAKHAROV	{"email": "a.zakharov-15081972@postgrespro.ru", "phone": "+70527135078"}
0005434825767	BB3F36	0382 378801	MARINA IVANOVA	{"phone": "+70377286775"}
0005434825768	4C3583	7900 696870	ANZHELIKA ALEKSANDROVA	{"phone": "+70988813365"}
0005434825769	D8F1E2	1338 599013	NATALYA RODIONOVA	{"email": "natalyarodionova1976@postgrespro.ru", "phone": "+70585079760"}
0005434825770	22BC76	7721 764015	VALENTINA SAVELEVA	{"email": "v-saveleva-1971@postgrespro.ru", "phone": "+70673889630"}
0005434825771	521488	3734 138976	YURIY MAKAROV	{"email": "yuriy_makarov-1976@postgrespro.ru", "phone": "+70000629045"}
0005434825772	16DB1E	5024 072442	NIKOLAY ZHUKOV	{"phone": "+70303207243"}
0005434825773	16DB1E	0398 203458	ALEKSANDR TIMOFEEV	{"email": "a.timofeev031968@postgrespro.ru", "phone": "+70148523563"}
0005434825774	55E242	5095 385658	TAMARA MOISEEVA	{"email": "moiseeva-t.14071977@postgrespro.ru", "phone": "+70064011244"}
0005434825775	16533C	4584 653505	VLADIMIR NIKITIN	{"email": "vladimir-nikitin.16061967@postgrespro.ru", "phone": "+70618969858"}
0005434825776	1EE93C	7503 405190	EVGENIY TIKHONOV	{"email": "e_tikhonov-29081973@postgrespro.ru", "phone": "+70895911529"}
0005434825777	66FE2D	5957 346655	ELENA KUZNECOVA	{"phone": "+70243594866"}
0005434825778	D9A6E7	9479 605345	OLGA GORBUNOVA	{"phone": "+70255417432"}
0005434825779	F06AD0	5054 505536	VIKTOR NAUMOV	{"email": "naumov_viktor1973@postgrespro.ru", "phone": "+70829630970"}
0005434825780	F06AD0	3527 299232	MARIYA LOGINOVA	{"email": "m.loginova011975@postgrespro.ru", "phone": "+70100074833"}
0005434825781	5688BC	7404 031501	ALEKSEY KOZLOV	{"phone": "+70525142941"}
0005434825782	5688BC	2707 582949	VIKTOR ROMANOV	{"email": "viktor.romanov_051969@postgrespro.ru", "phone": "+70524783741"}
0005434825783	5002C5	3736 940047	ANTONINA PAVLOVA	{"email": "pavlovaantonina-06101980@postgrespro.ru", "phone": "+70197454047"}
0005434825784	5002C5	0063 489424	VALENTINA GAVRILOVA	{"email": "gavrilova.valentina22101969@postgrespro.ru", "phone": "+70420656206"}
0005434825785	00E71B	8903 980138	NATALYA KUZNECOVA	{"email": "kuznecova-natalya_25071974@postgrespro.ru", "phone": "+70201580940"}
0005434825786	122E19	4518 920146	OLGA KUZNECOVA	{"phone": "+70198260372"}
0005434825787	C1FA88	1672 051285	GALINA KAZAKOVA	{"phone": "+70595449001"}
0005434825788	F44B06	1214 804348	RIMA ZHURAVLEVA	{"phone": "+70032917456"}
0005434825789	00A36E	9510 415966	GALINA FILATOVA	{"phone": "+70968076407"}
0005434825790	D61E45	4500 399521	VADIM POPOV	{"email": "vadim_popov-1976@postgrespro.ru", "phone": "+70237188518"}
0005434825791	61B41E	4155 282175	VALERIY ZHUKOV	{"phone": "+70288726396"}
0005434825792	B5DEC5	9476 840783	EKATERINA STEPANOVA	{"phone": "+70022621688"}
0005434825793	7403D1	9896 901206	VERA OSIPOVA	{"phone": "+70870821459"}
0005434825794	61CF88	4138 180668	OLEG ALEKSEEV	{"phone": "+70766121814"}
0005434825795	D59CC6	0665 862762	NATALYA KARPOVA	{"email": "karpovan02101973@postgrespro.ru", "phone": "+70477506040"}
0005434825796	2E2AA8	4484 448686	OLEG BONDARENKO	{"email": "bondarenko.o-11081973@postgrespro.ru", "phone": "+70909921265"}
0005434825797	2E2AA8	1586 010851	VIKTORIYA SCHERBAKOVA	{"email": "v-scherbakova.30061975@postgrespro.ru", "phone": "+70391793528"}
0005434825798	29B536	7567 830608	OKSANA IVANOVA	{"email": "o.ivanova1965@postgrespro.ru", "phone": "+70171934294"}
0005434825799	29B536	5847 464844	SOFYA CHERNOVA	{"phone": "+70432481997"}
0005434825800	54EFF6	0444 589287	ALEKSANDR POPOV	{"email": "popov_a031971@postgrespro.ru", "phone": "+70351046697"}
0005434825801	54EFF6	6068 604790	RAMILYA KRASNOVA	{"email": "krasnova-r16051982@postgrespro.ru", "phone": "+70348502631"}
0005434825802	781515	7422 168245	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov_16111978@postgrespro.ru", "phone": "+70403375759"}
0005434825803	1DE824	2687 047439	LYUDMILA BELYAEVA	{"email": "lbelyaeva.17081974@postgrespro.ru", "phone": "+70005031258"}
0005434825804	1DE824	9988 944031	ALLA KUZNECOVA	{"phone": "+70897929274"}
0005434825805	96CB55	3924 263600	LYUDMILA SAVELEVA	{"phone": "+70578370435"}
0005434825806	96CB55	8908 792022	VALENTINA DANILOVA	{"email": "valentinadanilova_18021977@postgrespro.ru", "phone": "+70826370299"}
0005434825807	8A3D51	3023 444257	ARTEM ANDREEV	{"phone": "+70093175780"}
0005434825808	D337C3	6347 256458	ALEKSEY PETROV	{"phone": "+70039660556"}
0005434825809	D337C3	7080 323458	VADIM NAZAROV	{"phone": "+70510771285"}
0005434825810	A0072F	4288 148349	DMITRIY GUSEV	{"phone": "+70134607925"}
0005434825811	07A08B	9341 688911	TAISIYA STEPANOVA	{"phone": "+70548819865"}
0005434825812	07A08B	8120 383992	KONSTANTIN VASILEV	{"email": "vasilev.k_091968@postgrespro.ru", "phone": "+70309584711"}
0005434825813	A91760	8200 180665	RUSLAN EGOROV	{"email": "ruslan-egorov_1958@postgrespro.ru", "phone": "+70892354017"}
0005434825814	A91760	5762 215358	NIKOLAY FEDOROV	{"email": "fedorov.nikolay.23091960@postgrespro.ru", "phone": "+70409567525"}
0005434825815	20DFE6	0498 486491	VLADIMIR PAVLOV	{"email": "v-pavlov051979@postgrespro.ru", "phone": "+70666366467"}
0005434825816	20DFE6	8589 057957	VIKTOR POPOV	{"email": "viktor_popov.19101969@postgrespro.ru", "phone": "+70489073343"}
0005434825877	84A297	4939 241874	OLGA PETROVA	{"phone": "+70821064732"}
0005434825817	95FD52	5745 237143	TATYANA KUZNECOVA	{"email": "kuznecova.t-1966@postgrespro.ru", "phone": "+70186164954"}
0005434825818	95FD52	2936 194354	LIDIYA VOROBEVA	{"email": "lidiya-vorobeva.111978@postgrespro.ru", "phone": "+70338029841"}
0005434825819	03D427	9050 207506	ANDREY GORBUNOV	{"phone": "+70637545258"}
0005434825820	9A33F4	8584 799464	VLADIMIR ALEKSEEV	{"phone": "+70412180000"}
0005434825821	9A33F4	7720 640140	VIKTOR SOROKIN	{"phone": "+70140434439"}
0005434825822	56A60E	1756 551354	ANATOLIY IVANOV	{"phone": "+70553042181"}
0005434825823	E39DED	1546 787816	LIDIYA KUZNECOVA	{"email": "kuznecovalidiya.111972@postgrespro.ru", "phone": "+70927189948"}
0005434825824	B58DBC	5729 058093	ELENA SOLOVEVA	{"email": "e.soloveva.24061956@postgrespro.ru", "phone": "+70250036664"}
0005434825825	21021B	5167 412323	ANASTASIYA SEMENOVA	{"email": "semenovaa.031965@postgrespro.ru", "phone": "+70253408950"}
0005434825826	596B4A	8755 067448	IVAN PAVLOV	{"email": "pavlovi_1993@postgrespro.ru", "phone": "+70669845503"}
0005434825827	B50DF9	6534 674898	ANNA SOLOVEVA	{"phone": "+70540488034"}
0005434825828	98FB22	3669 159594	MAKSIM EGOROV	{"email": "maksim-egorov-01101958@postgrespro.ru", "phone": "+70495238719"}
0005434825829	E6187B	0940 886317	ALEKSANDR DENISOV	{"phone": "+70210034556"}
0005434825830	E6187B	6772 492903	IGOR NIKOLAEV	{"phone": "+70304764023"}
0005434825831	32680C	3222 318421	ALIYA ZOTOVA	{"email": "a.zotova.1963@postgrespro.ru", "phone": "+70857311416"}
0005434825832	32680C	1419 162078	RAISA POPOVA	{"phone": "+70220174392"}
0005434825833	72044B	5163 303610	ANDREY IVANOV	{"phone": "+70111582425"}
0005434825834	82A934	4641 194390	ALEKSANDR CHERNOV	{"phone": "+70084665780"}
0005434825835	4A4993	5228 550936	VALENTINA TARASOVA	{"email": "vtarasova.14071962@postgrespro.ru", "phone": "+70409611763"}
0005434825836	DF3D47	6412 725294	LYUBOV ROMANOVA	{"phone": "+70242874349"}
0005434825837	09027C	5893 379519	EVGENIY VASILEV	{"email": "evasilev-24061957@postgrespro.ru", "phone": "+70870215467"}
0005434825838	7A38BE	8984 289124	ANASTASIYA EGOROVA	{"email": "anastasiya-egorova_1976@postgrespro.ru", "phone": "+70205657628"}
0005434825839	7A38BE	9021 886685	ALENA MAKAROVA	{"phone": "+70290236946"}
0005434825840	7A38BE	3785 492543	LIDIYA POTAPOVA	{"email": "potapovalidiya_05011969@postgrespro.ru", "phone": "+70067302381"}
0005434825841	7C3FE8	2765 229868	SERGEY KUZNECOV	{"email": "sergey-kuznecov051973@postgrespro.ru", "phone": "+70784187932"}
0005434825842	7C3FE8	4362 340555	VYACHESLAV MOROZOV	{"email": "morozov_vyacheslav_011979@postgrespro.ru", "phone": "+70963661557"}
0005434825843	25A9CC	1706 551398	ALEVTINA SMIRNOVA	{"email": "alevtinasmirnova.091969@postgrespro.ru", "phone": "+70278489941"}
0005434825844	25A9CC	9936 301954	OLGA NOVIKOVA	{"email": "novikova.olga-18121969@postgrespro.ru", "phone": "+70868331513"}
0005434825845	25A9CC	8725 003778	SVETLANA KONDRATEVA	{"email": "kondrateva.s.1972@postgrespro.ru", "phone": "+70839802200"}
0005434825846	089D51	2818 021774	ZINAIDA ILINA	{"email": "ilina-zinaida-1958@postgrespro.ru", "phone": "+70020334306"}
0005434825847	A984FA	2219 136183	NINA SOLOVEVA	{"phone": "+70262964162"}
0005434825848	460050	2227 517735	TATYANA MIKHAYLOVA	{"email": "t_mikhaylova_1965@postgrespro.ru", "phone": "+70110017063"}
0005434825849	460050	1181 965916	VALENTINA ZAYCEVA	{"phone": "+70721359275"}
0005434825850	D23AE6	4533 238894	ANDREY MIRONOV	{"phone": "+70193352950"}
0005434825851	5872E1	4196 702985	LIDIYA VASILEVA	{"phone": "+70509926425"}
0005434825852	08F295	1208 730251	ALEKSANDR MEDVEDEV	{"email": "amedvedev-12121964@postgrespro.ru", "phone": "+70130544361"}
0005434825853	3F0EFE	5891 290403	IRINA ZHUKOVA	{"email": "zhukova_i-1969@postgrespro.ru", "phone": "+70419910243"}
0005434825854	3F0EFE	8729 401980	NADEZHDA NIKOLAEVA	{"email": "nikolaeva-nadezhda_27011965@postgrespro.ru", "phone": "+70285614881"}
0005434825855	509A7C	2657 494689	VLADIMIR GUSEV	{"phone": "+70902166353"}
0005434825856	9B0113	4861 040515	TATYANA SOKOLOVA	{"phone": "+70913864460"}
0005434825857	F8E53D	4759 587769	KSENIYA FROLOVA	{"email": "frolova-k-1962@postgrespro.ru", "phone": "+70674647345"}
0005434825858	F8E53D	6108 662765	SERGEY BORISOV	{"phone": "+70050678448"}
0005434825859	6933F2	5439 450528	GALINA MALYSHEVA	{"email": "malyshevagalina1979@postgrespro.ru", "phone": "+70860959362"}
0005434825860	6933F2	5987 167183	VALENTINA DENISOVA	{"email": "denisova.v-09081969@postgrespro.ru", "phone": "+70094058839"}
0005434825861	056E93	6163 111866	ANDREY ZHURAVLEV	{"phone": "+70334350730"}
0005434825862	056E93	3645 636450	OKSANA ZHUKOVA	{"email": "zhukova_o.061956@postgrespro.ru", "phone": "+70237844136"}
0005434825863	7EAD15	9535 400164	ELENA KISELEVA	{"email": "kiseleva-elena19101982@postgrespro.ru", "phone": "+70514146011"}
0005434825864	D773A6	4336 796532	VADIM EGOROV	{"email": "egorov.v-051968@postgrespro.ru", "phone": "+70414926145"}
0005434825865	D773A6	9627 900715	SERGEY PETROV	{"email": "petrov_sergey061963@postgrespro.ru", "phone": "+70168361471"}
0005434825866	74DF2A	8842 254866	ALEKSEY BARANOV	{"email": "a_baranov.04031964@postgrespro.ru", "phone": "+70231566809"}
0005434825867	74DF2A	9039 290153	RAMILYA MALYSHEVA	{"phone": "+70321798673"}
0005434825868	78302A	4058 345839	IRINA NESTEROVA	{"email": "i_nesterova28111979@postgrespro.ru", "phone": "+70187582779"}
0005434825869	AE8E44	9131 027744	SHAMIL MIKHAYLOV	{"phone": "+70840951142"}
0005434825870	9E18EA	9543 721532	OLGA DENISOVA	{"phone": "+70375794028"}
0005434825871	9E18EA	7322 006822	OKSANA PETROVA	{"phone": "+70973755147"}
0005434825872	9E18EA	2811 231901	DMITRIY RODIONOV	{"phone": "+70077162211"}
0005434825873	210B7B	2853 004829	LYUDMILA MELNIKOVA	{"phone": "+70785282146"}
0005434825874	E59DB2	1809 716051	EKATERINA NESTEROVA	{"email": "nesterova_ekaterina.081977@postgrespro.ru", "phone": "+70752264298"}
0005434825875	AD0939	8548 486001	VLADIMIR BORISOV	{"phone": "+70288080965"}
0005434825876	84A297	4684 432703	ALEKSEY GUSEV	{"phone": "+70053002360"}
0005434825878	1F862D	9634 677101	SOFIYA TIMOFEEVA	{"phone": "+70823446204"}
0005434825879	1F862D	0999 841747	DARYA SEMENOVA	{"email": "semenova-d22091973@postgrespro.ru", "phone": "+70373089904"}
0005434825880	1F862D	3570 060315	MARINA IVANOVA	{"email": "ivanova_marina_23031991@postgrespro.ru", "phone": "+70904888240"}
0005434825881	2E5F8C	3857 555146	SERGEY ALEKSANDROV	{"phone": "+70451991461"}
0005434825882	D48304	2160 091783	OLGA MAKAROVA	{"phone": "+70102474017"}
0005434825883	8267F6	4370 654746	DARYA KUZNECOVA	{"phone": "+70091514567"}
0005434825884	2DA015	3204 943524	OLEG SEMENOV	{"email": "oleg-semenov11071975@postgrespro.ru", "phone": "+70907207726"}
0005434825885	CEDA5B	7826 913841	RAFAIL FILIPPOV	{"phone": "+70707150896"}
0005434825886	42242D	6061 494923	TATYANA BORISOVA	{"phone": "+70777391763"}
0005434825887	A69D75	0421 206438	RASHIT GAVRILOV	{"email": "rashit_gavrilov.1980@postgrespro.ru", "phone": "+70963202499"}
0005434825888	146F26	1310 564485	ARTEM KOROLEV	{"phone": "+70866867692"}
0005434825889	6D8F64	7388 546986	ALEKSANDR VOLKOV	{"email": "a_volkov-01061972@postgrespro.ru", "phone": "+70297595653"}
0005434825890	3E255B	4775 008369	NATALYA IVANOVA	{"email": "ivanova-n-30041966@postgrespro.ru", "phone": "+70148603111"}
0005434825891	3E255B	3254 063723	NIKITA SERGEEV	{"email": "sergeev-nikita_1966@postgrespro.ru", "phone": "+70325104670"}
0005434825892	0AB918	8532 212348	ANNA ZAKHAROVA	{"phone": "+70100123617"}
0005434825893	F0DA75	4741 614928	NATALIYA ALEKSANDROVA	{"email": "aleksandrova-n1964@postgrespro.ru", "phone": "+70047607269"}
0005434825894	907485	3722 981106	IVAN SIDOROV	{"phone": "+70764214390"}
0005434825895	64D3C4	0973 709685	ANNA KOMAROVA	{"email": "komarova-a.1969@postgrespro.ru", "phone": "+70721455013"}
0005434825896	81E537	1257 610750	NINA KUZMINA	{"email": "n.kuzmina22121977@postgrespro.ru", "phone": "+70091301337"}
0005434825897	81E537	7733 437957	VALERIYA NOVIKOVA	{"email": "valeriya-novikova1972@postgrespro.ru", "phone": "+70348440793"}
0005434825898	A0F628	8489 355410	ALEKSANDR MAKAROV	{"phone": "+70474353508"}
0005434825899	A52ADE	0341 740459	NATALYA SOROKINA	{"phone": "+70185497106"}
0005434825900	88CDE6	9555 771104	ELENA KOZLOVA	{"phone": "+70329680208"}
0005434825901	62AB07	1784 105116	GEORGIY ZAKHAROV	{"phone": "+70059255903"}
0005434825902	62AB07	5795 738239	VALENTINA KALININA	{"phone": "+70709313349"}
0005434825903	7DE351	4285 077722	ANNA SERGEEVA	{"email": "sergeevaa_10061976@postgrespro.ru", "phone": "+70344654101"}
0005434825904	F921C8	9242 138912	EVGENIY MATVEEV	{"email": "e_matveev_1969@postgrespro.ru", "phone": "+70106386169"}
0005434825905	33B3AA	2204 125712	ELENA SMIRNOVA	{"email": "smirnovae-1969@postgrespro.ru", "phone": "+70692644374"}
0005434825906	F4E3EF	6108 920756	YULIYA MAKAROVA	{"email": "yuliya-makarova1979@postgrespro.ru", "phone": "+70832382696"}
0005434825907	8E6DE8	0824 021050	ALEKSANDR MATVEEV	{"email": "a-matveev_14021978@postgrespro.ru", "phone": "+70988831469"}
0005434825908	A07B8A	9414 711204	ANTONINA BORISOVA	{"email": "a-borisova-101968@postgrespro.ru", "phone": "+70100556703"}
0005434825909	A07B8A	4549 886317	GALINA KRASNOVA	{"email": "krasnova-g-1965@postgrespro.ru", "phone": "+70357049684"}
0005434825910	5B8921	7388 713387	VLADISLAV FEDOTOV	{"phone": "+70731159308"}
0005434825911	EBD98E	4110 495895	PETR IVANOV	{"email": "ivanov_petr.26111968@postgrespro.ru", "phone": "+70025967064"}
0005434825912	2C5E1E	2115 629324	LYUBOV MEDVEDEVA	{"email": "l_medvedeva.1969@postgrespro.ru", "phone": "+70948346697"}
0005434825913	9F1227	0105 716649	ROMAN SIDOROV	{"email": "rsidorov-17081970@postgrespro.ru", "phone": "+70495988109"}
0005434825914	9F1227	6561 060646	MARIYA ERMAKOVA	{"email": "m.ermakova.22051979@postgrespro.ru", "phone": "+70058041929"}
0005434825915	9F2FED	3042 604640	ELENA MELNIKOVA	{"email": "elena_melnikova_061961@postgrespro.ru", "phone": "+70005227887"}
0005434825916	5C8870	0741 490787	SVETLANA RYABOVA	{"email": "ryabova_s-111978@postgrespro.ru", "phone": "+70388909416"}
0005434825917	C122B8	5473 455482	RAFAIL KUZNECOV	{"phone": "+70073209672"}
0005434825918	C122B8	2758 186723	ANASTASIYA BARANOVA	{"phone": "+70692892934"}
0005434825919	CE029C	8030 682203	DMITRIY TIKHONOV	{"email": "dmitriy.tikhonov-28101973@postgrespro.ru", "phone": "+70743006188"}
0005434825920	CE029C	3622 651079	NADEZHDA LEBEDEVA	{"phone": "+70341334856"}
0005434825921	CE029C	5415 097398	SERGEY ZAYCEV	{"email": "zaycev_s_12021973@postgrespro.ru", "phone": "+70139567938"}
0005434825922	D21498	7263 727657	IRINA SERGEEVA	{"phone": "+70320687677"}
0005434825923	C3C19C	0696 995577	VYACHESLAV VOLKOV	{"phone": "+70178661050"}
0005434825924	385B07	0736 129171	KONSTANTIN GRIGOREV	{"email": "k_grigorev1981@postgrespro.ru", "phone": "+70240333789"}
0005434825925	2D49F3	8776 767283	DMITRIY PAVLOV	{"email": "dpavlov-23101978@postgrespro.ru", "phone": "+70125543344"}
0005434825926	A3CCEC	4514 369990	SOFYA KAZAKOVA	{"email": "sofya_kazakova111970@postgrespro.ru", "phone": "+70293367019"}
0005434825927	AC804B	4693 487231	VIKTOR POPOV	{"phone": "+70606226995"}
0005434825928	AC804B	0304 337155	ALFIYA SMIRNOVA	{"email": "a.smirnova-30111985@postgrespro.ru", "phone": "+70264769390"}
0005434825929	F529C7	7894 503199	ALEKSEY SOKOLOV	{"phone": "+70695887810"}
0005434825930	AB699E	6874 431203	VLADISLAV NIKITIN	{"email": "nikitin.vladislav_1983@postgrespro.ru", "phone": "+70094997855"}
0005434825931	AB699E	9001 649139	VIKTOR ZAKHAROV	{"phone": "+70678686093"}
0005434825932	AB699E	9648 960008	KSENIYA PAVLOVA	{"phone": "+70258829037"}
0005434825933	99D927	1909 130069	DENIS SOKOLOV	{"email": "sokolov.d1967@postgrespro.ru", "phone": "+70106971587"}
0005434825934	99D927	5716 828536	OLGA DANILOVA	{"phone": "+70662091217"}
0005434825935	1B1BFD	0985 883815	YULIYA NIKIFOROVA	{"email": "y.nikiforova.21111962@postgrespro.ru", "phone": "+70329534444"}
0005434825936	1B1BFD	4812 153301	VLADISLAV POPOV	{"email": "popov_vladislav_1975@postgrespro.ru", "phone": "+70060916655"}
0005434825937	A8E1F9	0413 863314	VLADIMIR BARANOV	{"phone": "+70761061274"}
0005434825938	693C66	3971 148912	YANA KARPOVA	{"email": "karpova-yana1970@postgrespro.ru", "phone": "+70249394228"}
0005434825939	6FFB96	8089 397095	DMITRIY TIMOFEEV	{"email": "timofeevdmitriy05061971@postgrespro.ru", "phone": "+70303466391"}
0005434825940	5B0CAA	0501 923241	SEMEN POPOV	{"phone": "+70924584067"}
0005434825941	5B0CAA	6745 899571	FANIYA RYABOVA	{"phone": "+70866244618"}
0005434825942	F14644	5345 412344	VLADIMIR ZHUKOV	{"phone": "+70524547735"}
0005434825943	F14644	2370 757369	ALLA GAVRILOVA	{"phone": "+70811459789"}
0005434825944	FFA800	8743 399055	VALERIY IVANOV	{"email": "ivanov-valeriy-1967@postgrespro.ru", "phone": "+70460444823"}
0005434825945	3EF4ED	5409 595993	SERGEY MEDVEDEV	{"phone": "+70240345913"}
0005434825946	6FD265	7781 243518	ZOYA TIKHONOVA	{"phone": "+70269436539"}
0005434825947	A7EE3E	9072 036928	ALEKSANDR MOROZOV	{"email": "a.morozov-1963@postgrespro.ru", "phone": "+70530864185"}
0005434825948	BDE2D9	2773 400595	ANATOLIY FOMIN	{"email": "anatoliyfomin.04111978@postgrespro.ru", "phone": "+70236732858"}
0005434825949	297D36	2609 638700	TATYANA NESTEROVA	{"phone": "+70734747198"}
0005434825950	589635	4020 568324	SERGEY KARPOV	{"email": "karpov.s1979@postgrespro.ru", "phone": "+70731511778"}
0005434825951	E54DED	3006 818967	ALEKSEY MARTYNOV	{"email": "a.martynov1981@postgrespro.ru", "phone": "+70788457505"}
0005434825952	EFAE9B	4247 943521	ALEKSANDRA ISAEVA	{"email": "aleksandra-isaeva_031972@postgrespro.ru", "phone": "+70540086319"}
0005434825953	EFAE9B	7543 261998	YURIY POPOV	{"email": "popov-y081966@postgrespro.ru", "phone": "+70962520215"}
0005434825954	4740E4	8430 560466	PAVEL ZAKHAROV	{"email": "p_zakharov_1981@postgrespro.ru", "phone": "+70138222420"}
0005434825955	85FC36	1065 582031	NIKOLAY VASILEV	{"phone": "+70826017697"}
0005434825956	D32D08	4762 936239	VLADIMIR POPOV	{"phone": "+70076094941"}
0005434825957	A7B0D5	1657 775308	PETR FROLOV	{"phone": "+70475736566"}
0005434825958	647FEF	7108 727912	SERGEY ZHUKOV	{"email": "sergey_zhukov-031962@postgrespro.ru", "phone": "+70626399503"}
0005434825959	E31DAE	2578 916768	VALENTINA NESTEROVA	{"phone": "+70200409495"}
0005434825960	9949E2	6390 911096	STEPAN ISAEV	{"email": "stepan-isaev_041977@postgrespro.ru", "phone": "+70149491553"}
0005434825961	2FD151	4587 184190	TATYANA MOISEEVA	{"phone": "+70872183536"}
0005434825962	1EFD49	7002 952508	ALEKSANDR KRASNOV	{"email": "krasnova_101971@postgrespro.ru", "phone": "+70187926859"}
0005434825963	4E60FE	0628 409389	VLADIMIR ANTONOV	{"email": "antonov_v-121973@postgrespro.ru", "phone": "+70027152714"}
0005434825964	DB3B88	4866 924192	NATALYA KUZNECOVA	{"email": "natalya.kuznecova-031978@postgrespro.ru", "phone": "+70960529921"}
0005434825965	2DCA32	5210 243178	ALEKSANDR ZHUKOV	{"email": "zhukovaleksandr05071966@postgrespro.ru", "phone": "+70539606058"}
0005434825966	2DCA32	5825 553876	SERGEY BORISOV	{"phone": "+70783453707"}
0005434825967	89FB8C	4513 088993	KONSTANTIN NOVIKOV	{"email": "konstantinnovikov19061973@postgrespro.ru", "phone": "+70979701827"}
0005434825968	4CFFB0	0069 163151	OLGA MATVEEVA	{"email": "olga_matveeva_03061979@postgrespro.ru", "phone": "+70437702096"}
0005434825969	5D36A4	4559 580148	VIKTOR CHERNOV	{"email": "chernov-v.1972@postgrespro.ru", "phone": "+70124710188"}
0005434825970	A8CD6D	2281 670826	ANNA FILIPPOVA	{"email": "a-filippova091970@postgrespro.ru", "phone": "+70669438584"}
0005434825971	715997	8394 963048	ANATOLIY KONOVALOV	{"phone": "+70408645370"}
0005434825972	715997	6606 603182	ANTON MEDVEDEV	{"email": "medvedev_a.21111963@postgrespro.ru", "phone": "+70145133533"}
0005434825973	715997	4516 890070	VLADIMIR ILIN	{"phone": "+70956910217"}
0005434825974	11AD82	3892 338260	EVGENIY KONOVALOV	{"email": "konovalov.evgeniy.1986@postgrespro.ru", "phone": "+70793819329"}
0005434825975	829D24	2803 126128	GRIGORIY SIDOROV	{"phone": "+70602664222"}
0005434825976	829D24	2673 789400	TIMUR IVANOV	{"phone": "+70827640508"}
0005434825977	3DA456	4042 296773	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov051986@postgrespro.ru", "phone": "+70234508130"}
0005434825978	3DA456	2256 639982	ARTEM SHEVCHENKO	{"phone": "+70918490359"}
0005434825979	3506AB	9035 757971	TATYANA IVANOVA	{"phone": "+70836769550"}
0005434825980	201659	0621 357621	RAILYA SERGEEVA	{"phone": "+70744564708"}
0005434825981	B7F0C2	7913 422443	GENNADIY MEDVEDEV	{"phone": "+70524447214"}
0005434825982	CB17D0	7462 006360	ANNA MALYSHEVA	{"phone": "+70103485417"}
0005434825983	64A6CC	8210 984083	ELENA KOROLEVA	{"phone": "+70926211802"}
0005434825984	B31F38	4153 947407	VALENTINA GRISHINA	{"phone": "+70853700262"}
0005434825985	B31F38	4259 951886	VASILIY SEMENOV	{"phone": "+70593817829"}
0005434825986	4EE41F	3823 618162	ALEKSANDR VLASOV	{"email": "vlasov_a_041967@postgrespro.ru", "phone": "+70559026028"}
0005434825987	83E981	5575 060957	SEMEN ALEKSEEV	{"email": "s_alekseev-021964@postgrespro.ru", "phone": "+70479867347"}
0005434825988	0B2995	8754 440455	SERGEY IVANOV	{"phone": "+70054233477"}
0005434825989	0B2995	0348 171247	ALEVTINA MELNIKOVA	{"email": "alevtina-melnikova-1953@postgrespro.ru", "phone": "+70186079098"}
0005434825990	0B2995	1295 770902	OKSANA SCHERBAKOVA	{"email": "scherbakovao.041974@postgrespro.ru", "phone": "+70336615042"}
0005434825991	34748F	0837 823729	NATALYA PETROVA	{"phone": "+70658013421"}
0005434825992	34748F	8232 269310	ANDREY ALEKSEEV	{"phone": "+70999653813"}
0005434825993	DA15C9	9340 863742	LYUDMILA ABRAMOVA	{"email": "abramova_l1965@postgrespro.ru", "phone": "+70882113866"}
0005434825994	DA15C9	7692 247692	ELENA NESTEROVA	{"phone": "+70705292431"}
0005434825995	DA15C9	3554 765916	ALEKSANDR MEDVEDEV	{"email": "a_medvedev.011965@postgrespro.ru", "phone": "+70398032190"}
0005434825996	8A6FE2	5150 392653	EVGENIYA PAVLOVA	{"phone": "+70991745651"}
0005434825997	8A6FE2	4170 909675	MIKHAIL TIKHONOV	{"phone": "+70111941871"}
0005434825998	FC997A	7171 889522	ALEKSANDR KARPOV	{"email": "karpov.a-121966@postgrespro.ru", "phone": "+70306071029"}
0005434825999	1AADD8	1390 900223	ELENA LOGINOVA	{"phone": "+70315716905"}
0005434826000	EC8D99	2290 293372	ELENA POPOVA	{"email": "elena-popova.22011966@postgrespro.ru", "phone": "+70354676958"}
0005434826001	DF7601	5437 713549	VALENTINA PETROVA	{"phone": "+70460990017"}
0005434826002	CFCC5F	9404 808756	ALEKSEY KUZNECOV	{"phone": "+70582085433"}
0005434826003	CFCC5F	4103 549906	TATYANA GUSEVA	{"email": "t-guseva.23081964@postgrespro.ru", "phone": "+70069629057"}
0005434826004	CFCC5F	4019 056444	TATYANA NIKITINA	{"email": "tnikitina.10031965@postgrespro.ru", "phone": "+70135501472"}
0005434826005	ECE4AC	2297 758581	ANDREY ABRAMOV	{"phone": "+70346288529"}
0005434826006	292C13	0579 605557	MARINA KUZNECOVA	{"email": "kuznecovamarina.08051966@postgrespro.ru", "phone": "+70503520118"}
0005434826007	292C13	7699 605461	ALEKSANDR MELNIKOV	{"email": "a.melnikov.1972@postgrespro.ru", "phone": "+70650847089"}
0005434826008	CBB88D	4132 618782	POLINA NIKITINA	{"email": "polina_nikitina_041976@postgrespro.ru", "phone": "+70718835976"}
0005434826009	CBB88D	3142 916975	LYUBOV YUDINA	{"phone": "+70206487845"}
0005434826010	608DB2	0999 162453	VALENTINA VOROBEVA	{"phone": "+70274296449"}
0005434826011	6F69FF	1967 689281	YULIYA KUZNECOVA	{"email": "kuznecova.yuliya_1976@postgrespro.ru", "phone": "+70049996161"}
0005434826012	40DD72	5792 236306	OLGA MELNIKOVA	{"phone": "+70105184705"}
0005434826013	40DD72	1505 817600	EVGENIY KOZLOV	{"phone": "+70865920385"}
0005434826014	2A8C14	4778 410470	OLGA DANILOVA	{"email": "o_danilova.081972@postgrespro.ru", "phone": "+70269421025"}
0005434826015	2A8C14	2144 006241	VYACHESLAV MEDVEDEV	{"email": "vyacheslav_medvedev1971@postgrespro.ru", "phone": "+70329977510"}
0005434826016	AF1062	0993 400238	STANISLAV KOROLEV	{"email": "stanislav.korolev1976@postgrespro.ru", "phone": "+70923591866"}
0005434826017	8D4CF6	5989 623798	GALINA SOKOLOVA	{"phone": "+70409614728"}
0005434826018	8E29CB	1359 213505	VIKTOR SOLOVEV	{"phone": "+70052222742"}
0005434826019	8E29CB	3598 055028	VASILIY ALEKSANDROV	{"phone": "+70995070694"}
0005434826020	123070	3435 888489	VASILIY VOLKOV	{"email": "vasiliyvolkov-1978@postgrespro.ru", "phone": "+70928638926"}
0005434826021	123070	2154 387955	DMITRIY KUZNECOV	{"email": "dmitriy-kuznecov_1966@postgrespro.ru", "phone": "+70301584489"}
0005434826022	5128D8	8175 544368	ARTEM KUZNECOV	{"email": "a.kuznecov.1985@postgrespro.ru", "phone": "+70545801801"}
0005434826023	FDB5E6	0294 762555	LEV MAKAROV	{"email": "makarov_lev081975@postgrespro.ru", "phone": "+70543418345"}
0005434826024	EB66CE	7208 288918	ANDREY SHEVCHENKO	{"email": "shevchenko_a_031977@postgrespro.ru", "phone": "+70471059888"}
0005434826025	72B087	9480 777670	NIKITA NIKITIN	{"email": "nikita-nikitin_1973@postgrespro.ru", "phone": "+70747566647"}
0005434826026	09461E	7161 111483	DIANA ALEKSEEVA	{"phone": "+70395520508"}
0005434826027	09461E	4701 168824	SERGEY POPOV	{"email": "popov_sergey041973@postgrespro.ru", "phone": "+70294515898"}
0005434826028	C9286E	9024 248863	ALEKSANDR MAKAROV	{"email": "makarovaleksandr1990@postgrespro.ru", "phone": "+70994796762"}
0005434826029	47254D	8854 495003	GALINA KRASNOVA	{"email": "krasnova_g_1966@postgrespro.ru", "phone": "+70029170044"}
0005434826030	CFAF03	3224 058609	LYUBOV ZAKHAROVA	{"email": "zakharoval1973@postgrespro.ru", "phone": "+70153497420"}
0005434826031	60F5A8	4908 714467	OLESYA CHERNOVA	{"phone": "+70821384356"}
0005434826032	332C7E	1267 099196	MARIYA KARPOVA	{"phone": "+70802771032"}
0005434826033	BCD731	8852 814264	PAVEL KULIKOV	{"email": "kulikovpavel_1965@postgrespro.ru", "phone": "+70571746908"}
0005434826034	D522DC	8849 893640	KSENIYA NOVIKOVA	{"email": "kseniyanovikova.091969@postgrespro.ru", "phone": "+70687598483"}
0005434826035	97D892	6733 248281	ANTONINA ANTONOVA	{"email": "antonova.a-021974@postgrespro.ru", "phone": "+70367981752"}
0005434826036	B1227C	5967 432311	ANATOLIY ZAKHAROV	{"email": "zakharovanatoliy02041975@postgrespro.ru", "phone": "+70540766609"}
0005434826037	B1227C	1188 429646	EKATERINA VASILEVA	{"email": "vasilevaekaterina_071986@postgrespro.ru", "phone": "+70811584335"}
0005434826038	D648A6	3365 278277	PAVEL ALEKSEEV	{"email": "alekseevpavel.1963@postgrespro.ru", "phone": "+70297360431"}
0005434826039	00B36C	6256 503438	PAVEL NAZAROV	{"email": "p.nazarov05021968@postgrespro.ru", "phone": "+70883516696"}
0005434826040	DF9B9E	4604 870567	MAKSIM VOLKOV	{"phone": "+70536511362"}
0005434826041	948731	0012 538088	SERGEY DMITRIEV	{"phone": "+70610512788"}
0005434826042	FA8467	8853 907865	GEORGIY KUZNECOV	{"email": "kuznecov-georgiy1982@postgrespro.ru", "phone": "+70022661882"}
0005434826043	5BD6F8	2539 917366	SVETLANA KRASNOVA	{"email": "krasnova-s-041977@postgrespro.ru", "phone": "+70513880623"}
0005434826044	F827FA	6720 023166	SVETLANA VOLKOVA	{"phone": "+70268086975"}
0005434826045	F827FA	5989 794526	ALEKSANDR POPOV	{"email": "popov_a011971@postgrespro.ru", "phone": "+70352739710"}
0005434826046	4F95C9	1469 168316	MARINA MAKSIMOVA	{"phone": "+70386859298"}
0005434826047	AF0F4B	6174 091638	VALERIY MARTYNOV	{"phone": "+70296556370"}
0005434826048	AF0F4B	4894 782522	MARIYA MIRONOVA	{"phone": "+70781246492"}
0005434826049	59CBD1	3235 018730	EKATERINA KISELEVA	{"phone": "+70174550603"}
0005434826050	E019CA	4561 182723	ANDREY EGOROV	{"phone": "+70568703054"}
0005434826051	9FC950	6311 126522	MARIYA ZAKHAROVA	{"phone": "+70500852394"}
0005434826052	9D1ACE	1783 752578	OLGA DENISOVA	{"email": "denisova.o_041976@postgrespro.ru", "phone": "+70332889371"}
0005434826053	E4CC78	2816 824149	VALERIY KUZMIN	{"phone": "+70977521669"}
0005434826054	E4CC78	5272 836251	ALEKSANDRA MATVEEVA	{"phone": "+70526693856"}
0005434826055	D95B38	4756 052057	DENIS KUZNECOV	{"email": "denis.kuznecov1987@postgrespro.ru", "phone": "+70650007048"}
0005434826056	FC523C	6531 401580	VLADISLAV SAVELEV	{"email": "savelev_vladislav17031977@postgrespro.ru", "phone": "+70015408414"}
0005434826057	FC523C	5223 430998	SERGEY MELNIKOV	{"email": "melnikov_sergey_1974@postgrespro.ru", "phone": "+70803273140"}
0005434826058	83D9A9	3424 052713	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir-16051967@postgrespro.ru", "phone": "+70244352878"}
0005434826059	A121C8	1323 346510	DARYA SEMENOVA	{"email": "semenova_darya_1971@postgrespro.ru", "phone": "+70820583321"}
0005434826060	FEED34	9563 876821	MAKSIM SIDOROV	{"phone": "+70536041711"}
0005434826061	FEED34	1196 075682	OKSANA KOLESNIKOVA	{"email": "kolesnikova-oksana-101971@postgrespro.ru", "phone": "+70726779232"}
0005434826062	9D2B5F	3726 425468	GALINA KAZAKOVA	{"email": "kazakova_g1975@postgrespro.ru", "phone": "+70542224786"}
0005434826063	9D2B5F	5524 835162	SERGEY SERGEEV	{"email": "sergeysergeev27121975@postgrespro.ru", "phone": "+70777640643"}
0005434826064	1D81AA	1705 608770	VYACHESLAV NIKOLAEV	{"email": "vyacheslav-nikolaev.081967@postgrespro.ru", "phone": "+70726770328"}
0005434826065	F34609	9387 102737	LYUDMILA ANISIMOVA	{"email": "anisimova.l_11041968@postgrespro.ru", "phone": "+70091196069"}
0005434826066	F34609	6377 158396	ELIZAVETA KUZNECOVA	{"email": "elizaveta-kuznecova_1971@postgrespro.ru", "phone": "+70989026348"}
0005434826067	E38F08	0895 736130	ALEKSANDR IVANOV	{"email": "aleksandrivanov31051967@postgrespro.ru", "phone": "+70790715303"}
0005434826068	4F3360	3702 455233	EVGENIY MELNIKOV	{"phone": "+70265740124"}
0005434826069	B34000	9659 331135	LYUBOV KARPOVA	{"email": "karpova-l-03041985@postgrespro.ru", "phone": "+70154382840"}
0005434826070	B34000	1243 571270	VITALIY MIKHAYLOV	{"email": "v_mikhaylov12101964@postgrespro.ru", "phone": "+70099825295"}
0005434826071	B34000	8400 308401	ELENA KULIKOVA	{"email": "kulikova_elena.18101955@postgrespro.ru", "phone": "+70340544674"}
0005434826072	42C1C7	7850 950340	TATYANA SEMENOVA	{"email": "semenova-t-051972@postgrespro.ru", "phone": "+70820890078"}
0005434826073	42C1C7	5063 617902	YULIYA ILINA	{"email": "ilinayuliya091970@postgrespro.ru", "phone": "+70777371896"}
0005434826074	E9A3A0	3868 597604	ALEKSEY DENISOV	{"phone": "+70935034502"}
0005434826075	7D4C8C	8762 287561	LYUBOV DAVYDOVA	{"email": "l_davydova-1973@postgrespro.ru", "phone": "+70837345903"}
0005434826076	7C0494	4753 038088	MARIYA VASILEVA	{"email": "mariya_vasileva-12091970@postgrespro.ru", "phone": "+70185186322"}
0005434826077	7C0494	4274 130227	ANDREY KUZMIN	{"email": "andrey-kuzmin.111972@postgrespro.ru", "phone": "+70253969236"}
0005434826078	FE4224	4552 233317	VIKTOR KUZNECOV	{"phone": "+70756870785"}
0005434826079	FE4224	7782 046070	IVAN NAZAROV	{"phone": "+70277126550"}
0005434826080	4BC9CF	1739 833718	ALEKSANDR YAKOVLEV	{"email": "aleksandr-yakovlev.1977@postgrespro.ru", "phone": "+70358384490"}
0005434826081	4BC9CF	6062 608134	GALINA FILIPPOVA	{"email": "g-filippova.26081978@postgrespro.ru", "phone": "+70903266390"}
0005434826082	5FE2EE	6058 945284	IRINA VOLKOVA	{"phone": "+70038320892"}
0005434826083	5FE2EE	0013 567219	BORIS MIRONOV	{"phone": "+70102815431"}
0005434826084	5FE2EE	0521 606773	DANILA AFANASEV	{"email": "afanasev-d-27101962@postgrespro.ru", "phone": "+70675594563"}
0005434826085	AF2972	7196 612055	YANA BELOVA	{"phone": "+70737040978"}
0005434826086	AF2972	5032 682574	TAMARA KAZAKOVA	{"email": "kazakova.tamara_1980@postgrespro.ru", "phone": "+70450711250"}
0005434826087	D7D768	7427 389154	GENNADIY NAUMOV	{"phone": "+70687548116"}
0005434826088	D7D768	5511 064914	EDUARD GUSEV	{"email": "gusev_eduard.071979@postgrespro.ru", "phone": "+70643584975"}
0005434826089	D7D768	6049 674233	IGOR KUZNECOV	{"phone": "+70089575355"}
0005434826090	BBC94A	9408 970900	MAKSIM NIKOLAEV	{"email": "m_nikolaev1976@postgrespro.ru", "phone": "+70407116496"}
0005434826091	E4D968	4928 882892	NINA ANDREEVA	{"email": "andreeva_nina.14011970@postgrespro.ru", "phone": "+70886952878"}
0005434826092	E4D968	7011 695142	SOFYA IVANOVA	{"email": "ivanova_s1951@postgrespro.ru", "phone": "+70754995589"}
0005434826093	938AD6	7455 330371	ELINA YUDINA	{"email": "yudinae-18081976@postgrespro.ru", "phone": "+70839121490"}
0005434826094	16DB6E	4797 085856	ANASTASIYA IVANOVA	{"phone": "+70381740385"}
0005434826095	16DB6E	8441 840619	NINA NIKOLAEVA	{"email": "n-nikolaeva-05061967@postgrespro.ru", "phone": "+70795385185"}
0005434826096	16DB6E	1523 954573	VIKTORIYA FROLOVA	{"phone": "+70976079810"}
0005434826097	3FB5BB	4426 240890	IRINA IVANOVA	{"phone": "+70428509897"}
0005434826098	23049C	5138 711196	YAROSLAV SCHERBAKOV	{"phone": "+70394162244"}
0005434826099	23049C	9224 863519	MARINA SOROKINA	{"phone": "+70423273319"}
0005434826100	660FE6	9139 548463	ALLA STEPANOVA	{"phone": "+70905385537"}
0005434826101	7A7E01	5148 454352	SERGEY RODIONOV	{"phone": "+70942327289"}
0005434826102	3D7AB9	7824 248889	ALEKSANDR POPOV	{"email": "a_popov1969@postgrespro.ru", "phone": "+70849061844"}
0005434826103	92C254	9957 689303	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov021957@postgrespro.ru", "phone": "+70458895904"}
0005434826104	92C254	2387 935000	OLGA IVANOVA	{"phone": "+70916105998"}
0005434826105	8821F8	8919 578406	VALENTINA KUZMINA	{"phone": "+70965163309"}
0005434826106	E5F01B	3575 020805	TATYANA FROLOVA	{"email": "frolova.tatyana.011970@postgrespro.ru", "phone": "+70603930221"}
0005434826107	B19D5E	2154 889504	LYUBOV BORISOVA	{"email": "lborisova_23031978@postgrespro.ru", "phone": "+70993163799"}
0005434826108	27BCE5	2718 367779	ADELINA FOMINA	{"phone": "+70193899944"}
0005434826109	27BCE5	7628 570756	VYACHESLAV OSIPOV	{"email": "osipov-v-091972@postgrespro.ru", "phone": "+70875799814"}
0005434826110	0DC777	5694 691676	INNA SIDOROVA	{"email": "sidorovai-26051971@postgrespro.ru", "phone": "+70342560036"}
0005434826111	6C357B	6755 563685	TAMARA AKIMOVA	{"email": "t_akimova061977@postgrespro.ru", "phone": "+70801490596"}
0005434826112	C87B92	3633 648172	SERGEY ZHUKOV	{"email": "zhukov-s10051972@postgrespro.ru", "phone": "+70071937070"}
0005434826113	827385	4124 910883	LARISA ALEKSANDROVA	{"phone": "+70230354951"}
0005434826114	039A02	9081 380003	GALINA MAKAROVA	{"phone": "+70854534006"}
0005434826115	44AA48	8315 054661	YULIYA LAZAREVA	{"phone": "+70712252909"}
0005434826116	84D7B4	6254 504602	MARINA MIRONOVA	{"phone": "+70349371113"}
0005434826117	8100BA	3124 877139	SVETLANA ORLOVA	{"email": "orlova_s.26021972@postgrespro.ru", "phone": "+70410144436"}
0005434826118	88B2A6	6159 377316	VLADISLAV ALEKSEEV	{"email": "alekseevv_1977@postgrespro.ru", "phone": "+70944772718"}
0005434826119	88B2A6	2655 235469	ALEKSANDR TARASOV	{"phone": "+70732206930"}
0005434826120	88B2A6	3992 050798	ALEKSANDR AFANASEV	{"email": "aafanasev_1974@postgrespro.ru", "phone": "+70517013326"}
0005434826121	E3044B	3455 224669	ALEKSANDR DAVYDOV	{"email": "a.davydov_07021971@postgrespro.ru", "phone": "+70505779914"}
0005434826122	0EEC70	8984 931062	ANASTASIYA LAZAREVA	{"email": "a-lazareva-011974@postgrespro.ru", "phone": "+70539324936"}
0005434826123	0EEC70	8624 664385	ALEKSANDR GORBUNOV	{"email": "gorbunov-aleksandr081980@postgrespro.ru", "phone": "+70314457592"}
0005434826124	7E10A1	0238 742387	EGOR ORLOV	{"email": "orlov.e.25061961@postgrespro.ru", "phone": "+70846545992"}
0005434826125	ADDF48	8189 136149	NINA TIMOFEEVA	{"email": "n_timofeeva-12041976@postgrespro.ru", "phone": "+70463282864"}
0005434826126	D64559	8481 939604	VIKTOR RODIONOV	{"phone": "+70355226381"}
0005434826127	D64559	0610 290324	NAZIYA KARPOVA	{"email": "naziyakarpova_21111975@postgrespro.ru", "phone": "+70271826806"}
0005434826128	CD8126	1287 929404	ANATOLIY MAKAROV	{"phone": "+70237939002"}
0005434826129	CD8126	5557 532187	GRIGORIY AFANASEV	{"email": "g.afanasev.031967@postgrespro.ru", "phone": "+70342205229"}
0005434826130	2E5FF6	3440 394592	YAKOV ORLOV	{"phone": "+70746836313"}
0005434826131	A03DCC	6566 060354	PETR ROMANOV	{"email": "romanov-petr_05051969@postgrespro.ru", "phone": "+70839720151"}
0005434826132	A03DCC	5866 389233	VALENTINA SIDOROVA	{"email": "valentinasidorova-29111965@postgrespro.ru", "phone": "+70295936561"}
0005434826133	D7A63C	3333 514703	ELENA KOROLEVA	{"email": "elena-koroleva031979@postgrespro.ru", "phone": "+70857454778"}
0005434826134	D7A63C	4899 138187	RINAT PETROV	{"phone": "+70553554288"}
0005434826135	AED5C2	9534 706147	LYUDMILA SMIRNOVA	{"email": "l.smirnova-031978@postgrespro.ru", "phone": "+70429081421"}
0005434826136	60339B	9497 956600	NATALYA SEMENOVA	{"email": "natalya_semenova1974@postgrespro.ru", "phone": "+70966086424"}
0005434826137	CD1788	6231 757127	OKSANA KUZMINA	{"phone": "+70806673882"}
0005434826138	F42D12	0183 487340	NURLAN VOLKOV	{"phone": "+70013685811"}
0005434826139	F42D12	9139 456314	VLADIMIR OSIPOV	{"phone": "+70436124834"}
0005434826140	2F6FDF	1360 447622	GALINA DMITRIEVA	{"email": "galinadmitrieva1963@postgrespro.ru", "phone": "+70824187713"}
0005434826141	F43B8C	4003 181397	TATYANA KUZNECOVA	{"email": "t.kuznecova.1973@postgrespro.ru", "phone": "+70418025712"}
0005434826142	F43B8C	3141 899686	OKSANA MAKAROVA	{"email": "makarovao-091990@postgrespro.ru", "phone": "+70760639656"}
0005434826143	8128F3	4940 671846	LYUDMILA ROMANOVA	{"phone": "+70279579164"}
0005434826144	A7F6D2	6139 373746	OLGA KONOVALOVA	{"email": "konovalova.olga.12091976@postgrespro.ru", "phone": "+70471210262"}
0005434826145	A7F6D2	4178 312891	DANIL MAKAROV	{"email": "dmakarov1981@postgrespro.ru", "phone": "+70623704884"}
0005434826146	CA93CF	2166 102758	TATYANA AKIMOVA	{"email": "akimova.t_20101981@postgrespro.ru", "phone": "+70484681189"}
0005434826147	439C9E	5579 141964	NADEZHDA RODIONOVA	{"phone": "+70498506950"}
0005434826148	36FA24	2374 106878	VITALIY GAVRILOV	{"phone": "+70013493499"}
0005434826149	36FA24	3106 691704	EVGENIY YAKOVLEV	{"phone": "+70720771916"}
0005434826150	02F05C	5333 211790	ANNA NIKITINA	{"email": "nikitinaa071967@postgrespro.ru", "phone": "+70650193856"}
0005434826151	99B1B3	9431 940172	ZOYA NOVIKOVA	{"email": "z-novikova.041962@postgrespro.ru", "phone": "+70998076983"}
0005434826152	99B1B3	6074 819374	DMITRIY MIKHAYLOV	{"email": "dmitriy.mikhaylov1971@postgrespro.ru", "phone": "+70282798467"}
0005434826153	AFF870	1605 156136	ARSENIY KAZAKOV	{"email": "a.kazakov061974@postgrespro.ru", "phone": "+70210403208"}
0005434826154	111D20	0711 466843	MARIYA KOZLOVA	{"phone": "+70858850602"}
0005434826155	14D678	8722 957800	GALINA NOVIKOVA	{"phone": "+70365111895"}
0005434826156	14D678	8511 215357	ANATOLIY ILIN	{"email": "ilin_a.121967@postgrespro.ru", "phone": "+70579012853"}
0005434826157	00F2BF	6060 176291	MARIYA VOROBEVA	{"email": "vorobeva_m-121971@postgrespro.ru", "phone": "+70001341593"}
0005434826158	C43760	2316 439116	ALEKSEY ALEKSEEV	{"email": "alekseyalekseev091978@postgrespro.ru", "phone": "+70569184102"}
0005434826159	67CDC0	5440 392156	MAKSIM MIRONOV	{"phone": "+70669529983"}
0005434826160	9874A9	5435 470003	MARIYA NIKOLAEVA	{"email": "mariya-nikolaeva.011978@postgrespro.ru", "phone": "+70933363562"}
0005434826161	9874A9	8022 377544	ANTON BELOV	{"email": "belova-12021967@postgrespro.ru", "phone": "+70006970380"}
0005434826162	668C0F	4536 723901	IRINA POLYAKOVA	{"phone": "+70185874143"}
0005434826163	668C0F	7070 739501	ALEKSEY AFANASEV	{"email": "afanasev_aleksey.1976@postgrespro.ru", "phone": "+70099064933"}
0005434826164	714431	9868 074400	ANTONIDA ABRAMOVA	{"email": "aabramova-1983@postgrespro.ru", "phone": "+70953878091"}
0005434826165	4C0AA1	2222 549108	ALEKSEY CHERNOV	{"phone": "+70474027394"}
0005434826166	260326	3365 668984	BORIS NAZAROV	{"email": "b_nazarov.061965@postgrespro.ru", "phone": "+70241467439"}
0005434826167	260326	2529 679128	ANASTASIYA PAVLOVA	{"phone": "+70108900890"}
0005434826168	260326	0234 083130	ALEKSANDR MOROZOV	{"phone": "+70559293282"}
0005434826169	783993	6275 890301	NATALYA TROFIMOVA	{"phone": "+70334797965"}
0005434826170	1C880A	3126 481839	LYUDMILA GORBUNOVA	{"phone": "+70226654716"}
0005434826171	388667	1046 229074	SERGEY MATVEEV	{"email": "matveev_sergey03041972@postgrespro.ru", "phone": "+70204405293"}
0005434826172	14B82A	5457 495686	YURIY ALEKSEEV	{"email": "yuriy.alekseev-1971@postgrespro.ru", "phone": "+70128132452"}
0005434826349	CAAFE2	3733 408499	ANNA KARPOVA	{"phone": "+70887063403"}
0005434826173	7E7927	5068 703857	ELENA MALYSHEVA	{"email": "elena-malysheva_031973@postgrespro.ru", "phone": "+70590860920"}
0005434826174	7E7927	4478 118355	PETR ANTONOV	{"email": "antonovpetr021959@postgrespro.ru", "phone": "+70838731316"}
0005434826175	5DE037	7855 658508	ELENA MIKHAYLOVA	{"phone": "+70127879151"}
0005434826176	949CC2	9837 216333	ALEKSANDR ZAKHAROV	{"email": "a-zakharov.20101973@postgrespro.ru", "phone": "+70807659147"}
0005434826177	7C3E8D	3491 104165	YULIYA DENISOVA	{"email": "denisova.yuliya.051973@postgrespro.ru", "phone": "+70992542172"}
0005434826178	7C3E8D	7483 921254	RAMILYA MAKAROVA	{"phone": "+70256169004"}
0005434826179	51E4F2	6080 995610	LILIYA ALEKSEEVA	{"email": "alekseeval-1974@postgrespro.ru", "phone": "+70746673799"}
0005434826180	51E4F2	4542 026122	ANATOLIY MOROZOV	{"phone": "+70100148061"}
0005434826181	69CA58	6607 448411	VASILIY SCHERBAKOV	{"email": "vasiliy_scherbakov_20031975@postgrespro.ru", "phone": "+70459311603"}
0005434826182	69CA58	8716 918976	ELENA MASLOVA	{"phone": "+70072631144"}
0005434826183	1D713D	4892 740643	RADIK MOISEEV	{"phone": "+70021707671"}
0005434826184	75CF34	2414 269623	RAISA MIKHAYLOVA	{"phone": "+70315756312"}
0005434826185	EE3CB2	5497 213820	ALENA IVANOVA	{"phone": "+70188145712"}
0005434826186	EE3CB2	2950 453719	VLADIMIR NIKOLAEV	{"phone": "+70261868441"}
0005434826187	D5E523	2725 147286	EDUARD FILIPPOV	{"phone": "+70139657926"}
0005434826188	9991F0	0058 631601	VALENTINA MARTYNOVA	{"phone": "+70089332794"}
0005434826189	9991F0	1522 458995	FARIDA IVANOVA	{"email": "ivanova.f.16091978@postgrespro.ru", "phone": "+70162761506"}
0005434826190	63B0D4	8914 114480	MIKHAIL VASILEV	{"phone": "+70009072606"}
0005434826191	5D5938	0410 141831	LEONID ZAKHAROV	{"phone": "+70735847980"}
0005434826192	E16010	4343 751689	DMITRIY MAKAROV	{"email": "makarovd1973@postgrespro.ru", "phone": "+70724321404"}
0005434826193	642A3E	0571 891231	ANDREY IVANOV	{"email": "andreyivanov-1976@postgrespro.ru", "phone": "+70061711942"}
0005434826194	E040EC	1583 395335	OLESYA FROLOVA	{"email": "frolova_o.031975@postgrespro.ru", "phone": "+70968360598"}
0005434826195	5CBF2E	4777 442386	TATYANA MATVEEVA	{"phone": "+70380183427"}
0005434826196	4E6B1E	4465 877963	IVAN ILIN	{"phone": "+70787736074"}
0005434826197	4E6B1E	8663 301011	LIDIYA FADEEVA	{"email": "l.fadeeva_13031982@postgrespro.ru", "phone": "+70776473263"}
0005434826198	4E6B1E	1736 956565	DMITRIY NIKOLAEV	{"email": "d_nikolaev031970@postgrespro.ru", "phone": "+70624600293"}
0005434826199	FA91F9	2631 254107	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_071971@postgrespro.ru", "phone": "+70518572043"}
0005434826200	650FCA	2146 971810	NINA ALEKSANDROVA	{"phone": "+70736281903"}
0005434826201	650FCA	2395 841853	RAISA YUDINA	{"phone": "+70971005001"}
0005434826202	BBD6B1	5289 212196	ANATOLIY NAZAROV	{"email": "nazarov.anatoliy_17031970@postgrespro.ru", "phone": "+70557262305"}
0005434826203	BBD6B1	4417 324614	SOFYA RODIONOVA	{"phone": "+70274999949"}
0005434826204	B6F5A3	2306 287671	GALINA ANDREEVA	{"phone": "+70675821390"}
0005434826205	B6F5A3	7784 757122	KLAVDIYA KOROLEVA	{"email": "k.koroleva.021977@postgrespro.ru", "phone": "+70540162983"}
0005434826206	67767B	2746 875017	ANDREY STEPANOV	{"phone": "+70109018211"}
0005434826207	675D69	9870 768276	SERGEY KOZLOV	{"phone": "+70705298943"}
0005434826208	12E677	0114 826256	VADIM KARPOV	{"email": "karpov_v1967@postgrespro.ru", "phone": "+70205371275"}
0005434826209	12E677	8667 874049	VIKTORIYA ANDREEVA	{"email": "andreeva-v.111976@postgrespro.ru", "phone": "+70010652145"}
0005434826210	666E27	6509 741608	VLADIMIR ZHUKOV	{"email": "vladimirzhukov-16061974@postgrespro.ru", "phone": "+70739698056"}
0005434826211	F33193	3454 264208	ALEKSEY GUSEV	{"email": "gusev_a_1975@postgrespro.ru", "phone": "+70397253813"}
0005434826212	9B601B	4847 298906	ILYA SIDOROV	{"phone": "+70649267084"}
0005434826213	9B601B	3536 028510	VSEVOLOD GUSEV	{"email": "gusev.vsevolod_26061968@postgrespro.ru", "phone": "+70392991454"}
0005434826214	9B601B	2511 153569	PETR SCHERBAKOV	{"email": "pscherbakov041968@postgrespro.ru", "phone": "+70636856589"}
0005434826215	169661	9086 253544	RINAT PETROV	{"email": "petrov-rinat.1969@postgrespro.ru", "phone": "+70244120895"}
0005434826216	F20EC4	4650 155646	KIRILL KOZLOV	{"phone": "+70907708664"}
0005434826217	F20EC4	2659 547876	EKATERINA MOISEEVA	{"email": "moiseevae21061979@postgrespro.ru", "phone": "+70664234449"}
0005434826218	5F012E	1275 223021	ARTEM IVANOV	{"email": "ivanov-artem101974@postgrespro.ru", "phone": "+70440887255"}
0005434826219	0431C6	8777 955097	VADIM ILIN	{"email": "ilinvadim_03041968@postgrespro.ru", "phone": "+70293913489"}
0005434826220	0431C6	6079 103052	ANNA VOROBEVA	{"phone": "+70106659761"}
0005434826221	547E31	3963 640388	NATALYA MOROZOVA	{"email": "morozovan-1977@postgrespro.ru", "phone": "+70777003803"}
0005434826222	669310	0049 562610	GRIGORIY SCHERBAKOV	{"email": "gscherbakov-24051964@postgrespro.ru", "phone": "+70546231746"}
0005434826223	669310	7767 158053	NATALYA OVCHINNIKOVA	{"email": "n-ovchinnikova.1963@postgrespro.ru", "phone": "+70765520974"}
0005434826224	51A81F	8093 495350	NATALYA NESTEROVA	{"email": "natalya.nesterova.12061978@postgrespro.ru", "phone": "+70493109702"}
0005434826225	7B4BD5	2687 714290	DENIS ZHUKOV	{"email": "dzhukov_051974@postgrespro.ru", "phone": "+70520299212"}
0005434826226	7B4BD5	0539 802463	VLADIMIR NOVIKOV	{"phone": "+70925536363"}
0005434826227	729B56	0191 483279	OLGA STEPANOVA	{"phone": "+70519988879"}
0005434826228	69D884	5575 366403	ANASTASIYA KUZMINA	{"email": "kuzmina_anastasiya1963@postgrespro.ru", "phone": "+70915516202"}
0005434826229	3AC328	1036 070119	ELENA SMIRNOVA	{"email": "smirnova.e121975@postgrespro.ru", "phone": "+70748127780"}
0005434826230	973EFF	8729 348929	ZINAIDA AFANASEVA	{"email": "zinaidaafanaseva.031971@postgrespro.ru", "phone": "+70790821813"}
0005434826231	973EFF	8334 590205	VASILIY MARTYNOV	{"phone": "+70480114080"}
0005434826232	31D4DC	0797 804244	DANIIL KOROLEV	{"email": "daniilkorolev_1964@postgrespro.ru", "phone": "+70739879449"}
0005434826233	C3E422	8142 209448	SEMEN BORISOV	{"email": "s-borisov-121968@postgrespro.ru", "phone": "+70471015390"}
0005434826234	7FF340	2267 886918	EGOR VOROBEV	{"phone": "+70808562614"}
0005434826235	1DC88B	9020 900226	GALINA MELNIKOVA	{"phone": "+70203069288"}
0005434826236	18AF01	2837 211324	YULIYA SOROKINA	{"email": "yuliyasorokina-1978@postgrespro.ru", "phone": "+70832185617"}
0005434826237	18AF01	2021 567197	YURIY POPOV	{"email": "y_popov.20061971@postgrespro.ru", "phone": "+70318717455"}
0005434826238	18AF01	8378 918033	GALINA NOVIKOVA	{"email": "g_novikova.121977@postgrespro.ru", "phone": "+70634677215"}
0005434826239	250B4C	3718 851662	VLADIMIR SOROKIN	{"email": "sorokin-v.061974@postgrespro.ru", "phone": "+70641049984"}
0005434826240	0D8DEA	9302 974930	PETR BELOV	{"email": "p-belov1982@postgrespro.ru", "phone": "+70137892177"}
0005434826241	6B69C6	0009 330988	GALINA PETROVA	{"phone": "+70952879994"}
0005434826242	3AE99A	6869 555524	RUSLAN MAKAROV	{"email": "makarov_ruslan1969@postgrespro.ru", "phone": "+70032217073"}
0005434826243	3AE99A	7493 274371	ALEVTINA MIKHAYLOVA	{"phone": "+70819715048"}
0005434826244	E60B32	7595 793224	NIKOLAY SERGEEV	{"email": "nikolay-sergeev.031964@postgrespro.ru", "phone": "+70033194288"}
0005434826245	BB7E96	2226 113876	RAISA BELOVA	{"email": "raisa_belova1975@postgrespro.ru", "phone": "+70740700186"}
0005434826246	BB7E96	3787 279698	VITALIY SEMENOV	{"email": "semenov_vitaliy_021964@postgrespro.ru", "phone": "+70446633094"}
0005434826247	8571E8	7639 534978	GALINA MAKAROVA	{"email": "makarova.g.051978@postgrespro.ru", "phone": "+70607540902"}
0005434826248	8571E8	4532 317174	OLGA KOZLOVA	{"phone": "+70933058874"}
0005434826249	A70FE2	8091 488828	VALERIYA KUDRYASHOVA	{"phone": "+70996656809"}
0005434826250	0D9E51	3681 483183	NINA FEDOROVA	{"email": "fedorova_n1971@postgrespro.ru", "phone": "+70898504378"}
0005434826251	0D9E51	9772 685102	VYACHESLAV IVANOV	{"email": "ivanov.v.06101970@postgrespro.ru", "phone": "+70430725190"}
0005434826252	1D6961	9449 263138	ELIZAVETA AKIMOVA	{"email": "e_akimova1984@postgrespro.ru", "phone": "+70890745975"}
0005434826253	1D6961	7239 141679	GALINA SERGEEVA	{"phone": "+70160655697"}
0005434826254	12A2D7	8089 869116	NATALYA NESTEROVA	{"email": "nesterova-n1975@postgrespro.ru", "phone": "+70609140804"}
0005434826255	C97A98	3807 795313	MAKSIM NIKOLAEV	{"email": "nikolaev-maksim.18061983@postgrespro.ru", "phone": "+70145500423"}
0005434826256	6994F8	1025 213463	VERA ZHURAVLEVA	{"email": "zhuravleva_vera.1969@postgrespro.ru", "phone": "+70121034949"}
0005434826257	0EA051	8804 355013	NATALYA FADEEVA	{"phone": "+70641924006"}
0005434826258	2A4518	6187 699003	SERGEY ILIN	{"email": "ilin_s071966@postgrespro.ru", "phone": "+70460455637"}
0005434826259	CA7767	6732 380839	SERGEY ANDREEV	{"phone": "+70299224640"}
0005434826260	F3AA7A	5875 401028	DMITRIY DAVYDOV	{"phone": "+70560385693"}
0005434826261	F3AA7A	2331 566538	LYUBOV OSIPOVA	{"phone": "+70980353718"}
0005434826262	F3AA7A	7300 290074	ARMEN IVANOV	{"email": "armen-ivanov_1981@postgrespro.ru", "phone": "+70267491363"}
0005434826263	5CF4BE	2902 949185	EKATERINA BARANOVA	{"email": "e-baranova.061969@postgrespro.ru", "phone": "+70690740808"}
0005434826264	EB8AE8	8528 497914	ALEKSANDR RODIONOV	{"email": "a-rodionov-1984@postgrespro.ru", "phone": "+70762306012"}
0005434826265	EB8AE8	9937 046878	DMITRIY POPOV	{"email": "popovd_1961@postgrespro.ru", "phone": "+70753034776"}
0005434826266	B16BAF	1782 851081	YURIY KUZNECOV	{"phone": "+70992456345"}
0005434826267	B16BAF	5600 440206	SERGEY MEDVEDEV	{"phone": "+70883273533"}
0005434826268	A981A4	0534 674430	NINA RODIONOVA	{"phone": "+70499084729"}
0005434826269	4E4F46	0793 931696	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov.23041974@postgrespro.ru", "phone": "+70757520178"}
0005434826270	065E18	9548 016455	ALEKSEY SEMENOV	{"email": "aleksey.semenov-061975@postgrespro.ru", "phone": "+70771713199"}
0005434826271	E2DC84	6170 450630	ROMAN MAKAROV	{"phone": "+70379325667"}
0005434826272	A0C0BD	0247 855728	RAISA BORISOVA	{"email": "rborisova.041975@postgrespro.ru", "phone": "+70013343550"}
0005434826273	2FFE8B	9478 164445	MARINA ANDREEVA	{"email": "m.andreeva22071969@postgrespro.ru", "phone": "+70298766971"}
0005434826274	FF8101	1069 564838	IRINA SCHERBAKOVA	{"email": "scherbakova_irina.1971@postgrespro.ru", "phone": "+70537037036"}
0005434826275	5CCFDD	7655 716020	MAKSIM PETROV	{"email": "petrov_m_091982@postgrespro.ru", "phone": "+70766477062"}
0005434826276	7209C0	9036 553366	OLGA FOMINA	{"email": "olgafomina_1980@postgrespro.ru", "phone": "+70069386781"}
0005434826277	EF0F2D	7536 745838	ANNA NIKIFOROVA	{"phone": "+70932758447"}
0005434826278	EF0F2D	7348 048813	SVETLANA KUZNECOVA	{"email": "s-kuznecova-23091980@postgrespro.ru", "phone": "+70682717228"}
0005434826279	10BCD8	9737 349682	ALEKSANDR AFANASEV	{"email": "aleksandr_afanasev.011971@postgrespro.ru", "phone": "+70602012649"}
0005434826280	10BCD8	4323 409954	LARISA GUSEVA	{"email": "guseva-l.06061967@postgrespro.ru", "phone": "+70433421745"}
0005434826281	CD69D7	4656 980614	LYUBOV POLYAKOVA	{"email": "l_polyakova07101974@postgrespro.ru", "phone": "+70483424931"}
0005434826282	CF4252	9804 230181	MAKSIM SERGEEV	{"email": "sergeev.maksim.111973@postgrespro.ru", "phone": "+70217906304"}
0005434826283	CF4252	0158 525756	ANTON TIMOFEEV	{"phone": "+70856236354"}
0005434826284	CE3AAB	5333 265841	KIRILL MATVEEV	{"phone": "+70690155462"}
0005434826285	FBEDB6	2794 682530	ALEKSANDRA MEDVEDEVA	{"email": "medvedevaa29061959@postgrespro.ru", "phone": "+70151622508"}
0005434826286	09CAB4	5368 842099	RISHAT ILIN	{"email": "ilinrishat111977@postgrespro.ru", "phone": "+70285036097"}
0005434826287	D0A29F	0007 608888	LYUBOV ZAKHAROVA	{"phone": "+70325096893"}
0005434826288	915E31	7851 305532	VALERIY IVANOV	{"email": "v-ivanov_26021970@postgrespro.ru", "phone": "+70793827223"}
0005434826289	915E31	1785 822572	NIKITA NIKITIN	{"phone": "+70770942166"}
0005434826290	4FBA64	7974 069985	RAIS SEMENOV	{"email": "r-semenov.05111975@postgrespro.ru", "phone": "+70154371411"}
0005434826291	5B7D33	3424 481673	ANTON GAVRILOV	{"email": "gavrilov_a_12021976@postgrespro.ru", "phone": "+70309400832"}
0005434826292	5B7D33	8472 977399	YURIY IVANOV	{"email": "ivanovy.1989@postgrespro.ru", "phone": "+70772515683"}
0005434826293	42C3AB	3032 854354	YULIYA NIKOLAEVA	{"email": "yuliya-nikolaeva.1972@postgrespro.ru", "phone": "+70097183190"}
0005434826294	2A8801	0230 984376	PETR MOISEEV	{"email": "moiseev-p23101969@postgrespro.ru", "phone": "+70169999064"}
0005434826295	2A8801	9045 945726	ALEKSANDR FOMIN	{"email": "aleksandr.fomin-121977@postgrespro.ru", "phone": "+70640370148"}
0005434826296	B02850	6541 841957	ANASTASIYA NESTEROVA	{"email": "a_nesterova_041972@postgrespro.ru", "phone": "+70030076609"}
0005434826297	139B5E	1135 169730	ANDREY MIRONOV	{"phone": "+70500083956"}
0005434826298	139B5E	4885 571704	VIKTOR MAKSIMOV	{"email": "viktor-maksimov.1963@postgrespro.ru", "phone": "+70568995788"}
0005434826299	58E8C0	4732 281069	EKATERINA RYABOVA	{"email": "eryabova-12101974@postgrespro.ru", "phone": "+70661917402"}
0005434826300	A9A565	5482 020335	DINA MIKHAYLOVA	{"email": "dina.mikhaylova.04041970@postgrespro.ru", "phone": "+70535947306"}
0005434826301	286A21	8671 804775	VERA NIKITINA	{"email": "nikitina_vera1963@postgrespro.ru", "phone": "+70339625479"}
0005434826302	314973	5547 925715	VITALIY IVANOV	{"email": "ivanovvitaliy-111977@postgrespro.ru", "phone": "+70377608240"}
0005434826303	314973	9715 660191	VALENTINA EFREMOVA	{"phone": "+70790790841"}
0005434826304	B4AAB3	6796 853491	DENIS NIKOLAEV	{"phone": "+70122434072"}
0005434826305	A6656F	9362 480242	RAISA GRISHINA	{"email": "grishina_raisa.1970@postgrespro.ru", "phone": "+70019157654"}
0005434826306	DF1EBB	7645 187693	BORIS BELOV	{"email": "belov.boris-31011990@postgrespro.ru", "phone": "+70653131180"}
0005434826307	DF1EBB	9476 489762	ANNA KALININA	{"email": "a_kalinina.121970@postgrespro.ru", "phone": "+70555257487"}
0005434826308	1A698C	2756 572811	DMITRIY BARANOV	{"phone": "+70013848392"}
0005434826309	695299	1680 969541	VALENTINA SERGEEVA	{"email": "sergeeva-v_1979@postgrespro.ru", "phone": "+70931506716"}
0005434826310	695299	7354 042481	ALEKSANDR KRASNOV	{"phone": "+70341064711"}
0005434826311	256C59	0043 114742	YANA NOVIKOVA	{"phone": "+70016870848"}
0005434826312	256C59	9391 489736	SERGEY FEDOTOV	{"phone": "+70295228012"}
0005434826313	41BCF5	1026 920321	ALEKSANDR IVANOV	{"email": "ivanova.081968@postgrespro.ru", "phone": "+70183026459"}
0005434826314	520128	1226 562419	DAVID KARPOV	{"email": "david-karpov-1972@postgrespro.ru", "phone": "+70976892041"}
0005434826315	21C352	5557 503203	KRISTINA SCHERBAKOVA	{"phone": "+70403261520"}
0005434826316	21C352	2292 362836	VYACHESLAV GUSEV	{"phone": "+70833228834"}
0005434826317	9F0C43	7542 599553	NADEZHDA PETROVA	{"email": "petrova.n.05091973@postgrespro.ru", "phone": "+70555666683"}
0005434826318	7036B7	7429 567212	VALENTINA TIKHONOVA	{"phone": "+70576557740"}
0005434826319	7036B7	9673 992727	DMITRIY ALEKSEEV	{"email": "dmitriyalekseev_18071961@postgrespro.ru", "phone": "+70096690467"}
0005434826320	6753DB	0844 673164	SVETLANA ABRAMOVA	{"email": "svetlana_abramova.28121975@postgrespro.ru", "phone": "+70260252270"}
0005434826321	6CDBDE	1690 325142	EVGENIYA GORBUNOVA	{"phone": "+70497255214"}
0005434826322	6CDBDE	1947 726233	ALEKSEY BELOV	{"phone": "+70313375759"}
0005434826323	0289D6	0618 838682	OLGA ZAKHAROVA	{"phone": "+70404637455"}
0005434826324	9EF877	4480 572769	TATYANA KRASNOVA	{"phone": "+70558887868"}
0005434826325	BDED15	4954 862808	VALENTINA ANDREEVA	{"email": "andreeva-valentina.19051978@postgrespro.ru", "phone": "+70359484555"}
0005434826326	32955C	7861 878069	ELENA SEMENOVA	{"phone": "+70441306442"}
0005434826327	15F14C	6074 561822	MARIYA NAUMOVA	{"email": "naumovam-101981@postgrespro.ru", "phone": "+70549034672"}
0005434826328	15F14C	5731 256266	KONSTANTIN MARTYNOV	{"email": "martynov_konstantin.061963@postgrespro.ru", "phone": "+70063085808"}
0005434826329	DD7163	3492 664570	PAVEL NAZAROV	{"email": "nazarov.pavel-13101970@postgrespro.ru", "phone": "+70058300468"}
0005434826330	DD7163	1347 715906	NINA VASILEVA	{"phone": "+70500322848"}
0005434826331	C0FBEB	3656 866774	IVAN ALEKSANDROV	{"phone": "+70423306624"}
0005434826332	C0FBEB	8346 007089	MARIYA DANILOVA	{"phone": "+70098970186"}
0005434826333	030E74	3157 351501	NIKOLAY NIKITIN	{"email": "nikitin-nikolay-1981@postgrespro.ru", "phone": "+70938098747"}
0005434826334	D1F4F0	5974 657189	NATALYA KOMAROVA	{"email": "natalya-komarova-25091976@postgrespro.ru", "phone": "+70438418280"}
0005434826335	D1F4F0	7629 388917	VERA KUZNECOVA	{"email": "kuznecova.vera111982@postgrespro.ru", "phone": "+70072350085"}
0005434826336	D1F4F0	5161 628149	TAISIYA NIKITINA	{"phone": "+70035226517"}
0005434826337	E13D2A	8818 527511	ANATOLIY NIKITIN	{"email": "a.nikitin_18091977@postgrespro.ru", "phone": "+70057839877"}
0005434826338	230D5C	3764 052292	TATYANA VLASOVA	{"phone": "+70379754491"}
0005434826339	F27D5F	8047 198298	VALENTINA SMIRNOVA	{"phone": "+70413608029"}
0005434826340	F27D5F	4955 685183	ELENA SOROKINA	{"phone": "+70679225838"}
0005434826341	12AFB6	6084 606616	NIKITA NOVIKOV	{"phone": "+70605796922"}
0005434826342	6E0BAE	3586 113071	ILYA IVANOV	{"email": "ilya.ivanov1980@postgrespro.ru", "phone": "+70306113770"}
0005434826343	9F3017	8753 382094	MARIYA ORLOVA	{"email": "morlova.1979@postgrespro.ru", "phone": "+70771966911"}
0005434826344	9F3017	7785 265375	ANASTASIYA ABRAMOVA	{"email": "anastasiya.abramova.1974@postgrespro.ru", "phone": "+70170021111"}
0005434826345	BE7086	2219 388448	VERA ERMAKOVA	{"email": "vera_ermakova1971@postgrespro.ru", "phone": "+70510654004"}
0005434826346	BE7086	5145 986440	VADIM SIDOROV	{"phone": "+70203072370"}
0005434826347	08500A	0300 862533	VITALIY NIKITIN	{"phone": "+70643047421"}
0005434826348	13E86B	5066 115911	PAVEL SEMENOV	{"email": "pavel.semenov021969@postgrespro.ru", "phone": "+70103025495"}
0005434826350	CAAFE2	0115 723597	GALINA MIKHAYLOVA	{"email": "galina.mikhaylova061988@postgrespro.ru", "phone": "+70567252572"}
0005434826351	CAAFE2	6456 580530	NATALYA KUZMINA	{"email": "nkuzmina_18071969@postgrespro.ru", "phone": "+70602252301"}
0005434826352	1EA075	5879 775993	DMITRIY ZAKHAROV	{"email": "d_zakharov-061983@postgrespro.ru", "phone": "+70161280170"}
0005434826353	1D697E	5953 219951	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr_11021975@postgrespro.ru", "phone": "+70028636233"}
0005434826354	1D697E	6031 770691	VIKTORIYA OSIPOVA	{"phone": "+70183719935"}
0005434826355	418154	6150 119442	SERGEY FOMIN	{"phone": "+70371757019"}
0005434826356	8BF6A6	0710 418697	ANTONINA KOROLEVA	{"phone": "+70604606324"}
0005434826357	8BF6A6	6477 602956	NIKOLAY GUSEV	{"email": "n_gusev.16041975@postgrespro.ru", "phone": "+70998571199"}
0005434826358	5C6727	2850 014249	VLADIMIR SHEVCHENKO	{"email": "v.shevchenko1980@postgrespro.ru", "phone": "+70994149133"}
0005434826359	5C6727	5721 028296	VERA KUZMINA	{"phone": "+70383027225"}
0005434826360	A8A4FB	1532 633672	ANASTASIYA KOROLEVA	{"email": "anastasiya_koroleva1961@postgrespro.ru", "phone": "+70492484026"}
0005434826361	1EC6D5	3814 044570	ELENA EFIMOVA	{"email": "eefimova-121965@postgrespro.ru", "phone": "+70320224808"}
0005434826362	37BC3E	9717 523059	VALENTINA FROLOVA	{"phone": "+70362203448"}
0005434826363	9FF656	5950 629759	YURIY MAKSIMOV	{"email": "maksimov.yuriy_1963@postgrespro.ru", "phone": "+70343597465"}
0005434826364	9FF656	6501 443430	KIRILL ILIN	{"email": "ilin-kirill.121965@postgrespro.ru", "phone": "+70433896245"}
0005434826365	3D1C86	4032 317622	TATYANA LOGINOVA	{"email": "loginova.t20101974@postgrespro.ru", "phone": "+70723050087"}
0005434826366	FF34F3	2071 764119	VIKTOR PAVLOV	{"phone": "+70119557984"}
0005434826367	0031D9	0464 976322	IRINA DAVYDOVA	{"email": "davydova.irina.1974@postgrespro.ru", "phone": "+70548525813"}
0005434826368	A5EF06	3666 654966	ROZA ZAKHAROVA	{"email": "zakharova.r03111973@postgrespro.ru", "phone": "+70838388787"}
0005434826369	A5EF06	4593 516736	OLEG CHERNOV	{"email": "oleg_chernov.25021971@postgrespro.ru", "phone": "+70703836882"}
0005434826370	1846C5	0748 860051	VYACHESLAV VOROBEV	{"email": "vorobev_v07081964@postgrespro.ru", "phone": "+70491320002"}
0005434826371	1846C5	8997 793891	IGOR TARASOV	{"email": "tarasovigor-1976@postgrespro.ru", "phone": "+70327807548"}
0005434826372	260B00	2313 114693	ANNA KISELEVA	{"email": "anna_kiseleva101983@postgrespro.ru", "phone": "+70326067593"}
0005434826373	862D63	2588 564900	ELENA OSIPOVA	{"phone": "+70662355510"}
0005434826374	862D63	1390 585182	SVETLANA ALEKSEEVA	{"email": "alekseeva.svetlana.1966@postgrespro.ru", "phone": "+70218869527"}
0005434826375	424B19	6536 183334	ALEKSEY ANDREEV	{"email": "andreev_a-1973@postgrespro.ru", "phone": "+70709744219"}
0005434826376	7E3413	2868 697389	NIKOLAY DMITRIEV	{"phone": "+70558571921"}
0005434826377	1AFCDB	5831 038106	OLGA EGOROVA	{"email": "egorovao.071978@postgrespro.ru", "phone": "+70489241172"}
0005434826378	1AFCDB	4916 959929	NADEZHDA VOLKOVA	{"email": "volkova.nadezhda_1970@postgrespro.ru", "phone": "+70007423384"}
0005434826379	B10AD2	4350 065566	ALEKSANDR SIDOROV	{"phone": "+70484336382"}
0005434826380	B10AD2	2265 510721	GALINA KOROLEVA	{"email": "koroleva-galina121971@postgrespro.ru", "phone": "+70148728190"}
0005434826381	293E9F	3080 761955	GENNADIY MIRONOV	{"phone": "+70258722064"}
0005434826382	99BE24	8908 169489	VIKTORIYA RODIONOVA	{"phone": "+70804285531"}
0005434826383	D6E037	9065 079990	ALBINA TIKHONOVA	{"phone": "+70601214175"}
0005434826384	D6E037	1632 907592	OLGA VLASOVA	{"email": "vlasovao-1978@postgrespro.ru", "phone": "+70591212993"}
0005434826385	DEB54B	3107 942780	ANTONINA POPOVA	{"email": "popova_a_1970@postgrespro.ru", "phone": "+70869833236"}
0005434826386	1551D8	9135 155276	ALEKSANDR EGOROV	{"email": "aleksandr-egorov-011971@postgrespro.ru", "phone": "+70995685326"}
0005434826387	CE7DED	6271 639624	MARIYA FADEEVA	{"phone": "+70462979219"}
0005434826388	CE7DED	9103 548667	ALEKSANDR TIKHONOV	{"phone": "+70639435788"}
0005434826389	432A7D	4284 739237	VIKTOR AFANASEV	{"phone": "+70384999892"}
0005434826390	A42545	8897 631143	VASILIY MIKHAYLOV	{"email": "vmikhaylov.23061968@postgrespro.ru", "phone": "+70007261706"}
0005434826391	8E7A92	1825 647534	ALEKSANDR ZAKHAROV	{"phone": "+70873774579"}
0005434826392	47C573	7799 088938	OLGA ANDREEVA	{"phone": "+70166875263"}
0005434826393	F04E6B	6057 780850	DENIS VOLKOV	{"email": "denisvolkov1983@postgrespro.ru", "phone": "+70040721393"}
0005434826394	240ABE	7692 508517	DINA MOROZOVA	{"email": "morozovadina30031960@postgrespro.ru", "phone": "+70114386464"}
0005434826395	6F6D24	0245 188917	ANDREY KUZNECOV	{"email": "andrey_kuznecov_04031968@postgrespro.ru", "phone": "+70586285487"}
0005434826396	4149DC	6577 318905	NADEZHDA IVANOVA	{"phone": "+70359817545"}
0005434826397	B0E587	4438 968461	PAVEL PAVLOV	{"phone": "+70948661549"}
0005434826398	2CE905	6000 745186	ANNA RODIONOVA	{"phone": "+70094610040"}
0005434826399	B95D63	1343 738940	LYUDMILA KUZMINA	{"email": "lyudmilakuzmina12031979@postgrespro.ru", "phone": "+70518596451"}
0005434826400	303588	5478 222484	YURIY MARTYNOV	{"phone": "+70979642887"}
0005434826401	303588	2793 657923	DMITRIY VOLKOV	{"email": "volkov.d_1969@postgrespro.ru", "phone": "+70948296215"}
0005434826402	DC9796	0308 853284	GALINA DENISOVA	{"phone": "+70834821902"}
0005434826403	176674	5531 397249	STEPAN OSIPOV	{"phone": "+70508628619"}
0005434826404	81A776	7949 749226	LYUDMILA TROFIMOVA	{"phone": "+70676918573"}
0005434826405	E733A6	1828 952648	FARIDA ABRAMOVA	{"email": "abramova.f1968@postgrespro.ru", "phone": "+70490468371"}
0005434826406	945350	3735 879725	YURIY ZAKHAROV	{"email": "y_zakharov_1971@postgrespro.ru", "phone": "+70877935185"}
0005434826407	53D5CC	2774 689554	MARIYA ZHURAVLEVA	{"phone": "+70501034895"}
0005434826408	434E72	8145 356462	IVAN ABRAMOV	{"phone": "+70823789223"}
0005434826529	FC03C2	9491 313982	VALERIY ALEKSEEV	{"phone": "+70596649286"}
0005434826409	250B1F	7879 312507	ALISHER ZHUKOV	{"email": "a_zhukov-1980@postgrespro.ru", "phone": "+70090740953"}
0005434826410	D6A306	1139 364714	EVGENIY VASILEV	{"phone": "+70678636686"}
0005434826411	D6A306	7787 136773	ILYA ALEKSEEV	{"email": "alekseev.i26101970@postgrespro.ru", "phone": "+70508311352"}
0005434826412	6BBFC8	6330 727606	VLADIMIR ABRAMOV	{"phone": "+70448968237"}
0005434826413	F75285	0265 145216	LYUBOV MAKAROVA	{"email": "makarova-l_30031970@postgrespro.ru", "phone": "+70301457374"}
0005434826414	EC3B86	3818 100589	MARIYA SOKOLOVA	{"email": "m_sokolova_051977@postgrespro.ru", "phone": "+70831868969"}
0005434826415	1FB3C2	4817 105968	DMITRIY FILIPPOV	{"email": "filippov_dmitriy.18121976@postgrespro.ru", "phone": "+70066648776"}
0005434826416	48D1AF	6928 326363	OKSANA TARASOVA	{"email": "o.tarasova-28031965@postgrespro.ru", "phone": "+70940773329"}
0005434826417	51E8EF	7384 011315	YULIYA OVCHINNIKOVA	{"email": "yuliyaovchinnikova.081976@postgrespro.ru", "phone": "+70524575538"}
0005434826418	51E8EF	7316 987927	IVAN BORISOV	{"phone": "+70293664784"}
0005434826419	2E5A05	4356 652776	OLGA TROFIMOVA	{"phone": "+70452881149"}
0005434826420	2E5A05	7458 085979	DARYA LAZAREVA	{"phone": "+70699135574"}
0005434826421	2E5A05	9507 112491	IVAN ROMANOV	{"phone": "+70387178559"}
0005434826422	CFD4CB	1312 455721	TATYANA ZAKHAROVA	{"phone": "+70024011328"}
0005434826423	A8295B	1704 232063	VALENTINA MAKSIMOVA	{"email": "maksimova_v.031963@postgrespro.ru", "phone": "+70808907543"}
0005434826424	E36B71	6601 151084	TAGIR ZAYCEV	{"phone": "+70694118219"}
0005434826425	B2750C	4552 307706	IVAN ILIN	{"phone": "+70130552158"}
0005434826426	18C30C	2990 575123	ARTUR TIKHONOV	{"email": "artur-tikhonov.041972@postgrespro.ru", "phone": "+70146207462"}
0005434826427	86EB32	0411 921458	ANNA FEDOROVA	{"phone": "+70592346450"}
0005434826428	270B56	3451 140392	SERGEY GUSEV	{"phone": "+70795543950"}
0005434826429	7C5A9C	7200 349556	ELENA DANILOVA	{"email": "danilova-e-1973@postgrespro.ru", "phone": "+70025784320"}
0005434826430	7C5A9C	5253 992467	NATALYA MIKHAYLOVA	{"phone": "+70714534777"}
0005434826431	E90E75	5539 218698	NATALYA GERASIMOVA	{"phone": "+70820624842"}
0005434826432	D7EBF7	8822 837068	NIKITA DAVYDOV	{"phone": "+70413876122"}
0005434826433	A75482	8863 277732	GEORGIY PETROV	{"email": "g-petrov_071976@postgrespro.ru", "phone": "+70036020477"}
0005434826434	163A69	3509 541442	VIKTOR VASILEV	{"email": "vvasilev-16061965@postgrespro.ru", "phone": "+70940779298"}
0005434826435	DACF78	7176 754382	TIMUR BONDARENKO	{"email": "t_bondarenko_1960@postgrespro.ru", "phone": "+70860878495"}
0005434826436	DACF78	9843 794439	GENNADIY POPOV	{"email": "g.popov-09011978@postgrespro.ru", "phone": "+70441711526"}
0005434826437	BCE827	5651 999489	NADEZHDA OSIPOVA	{"email": "n-osipova_1971@postgrespro.ru", "phone": "+70283115764"}
0005434826438	BCE827	3753 581017	ANDREY ROMANOV	{"phone": "+70865471077"}
0005434826439	BCE827	4706 478107	ROMAN FOMIN	{"phone": "+70166655872"}
0005434826440	166763	1385 595767	OLGA SOROKINA	{"phone": "+70121328617"}
0005434826441	0FADB9	7424 718153	OLGA GRISHINA	{"email": "grishinaolga-03061971@postgrespro.ru", "phone": "+70892322848"}
0005434826442	357D88	1487 496045	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva_091976@postgrespro.ru", "phone": "+70907301124"}
0005434826443	E8C8E7	0404 127285	ALEKSANDR ILIN	{"phone": "+70996434741"}
0005434826444	08D9F4	4254 607483	RAISA ALEKSEEVA	{"email": "r.alekseeva_19101967@postgrespro.ru", "phone": "+70245348243"}
0005434826445	08D9F4	6295 324021	VADIM GERASIMOV	{"email": "vadim_gerasimov_021960@postgrespro.ru", "phone": "+70558703945"}
0005434826446	4AC82A	2641 351887	OLEG BORISOV	{"phone": "+70247699252"}
0005434826447	26E211	0007 671103	NATALYA VASILEVA	{"email": "n.vasileva.1964@postgrespro.ru", "phone": "+70464362382"}
0005434826448	26E211	1645 181066	VALENTINA NIKOLAEVA	{"phone": "+70524749301"}
0005434826449	14778E	0148 130564	ANASTASIYA KARPOVA	{"phone": "+70267386272"}
0005434826450	14778E	6448 427440	MIKHAIL KUDRYASHOV	{"email": "m-kudryashov-071966@postgrespro.ru", "phone": "+70177604962"}
0005434826451	65A2AB	8217 189082	YURIY SIDOROV	{"phone": "+70967069301"}
0005434826452	976C3E	0988 231873	VALENTINA SERGEEVA	{"email": "sergeeva_valentina1973@postgrespro.ru", "phone": "+70226379107"}
0005434826453	976C3E	5439 250856	LYUBOV MALYSHEVA	{"email": "malysheva-l_091962@postgrespro.ru", "phone": "+70732543643"}
0005434826454	7C5F58	1202 552534	ALEKSANDRA MAKAROVA	{"email": "aleksandramakarova.29061981@postgrespro.ru", "phone": "+70733624834"}
0005434826455	7C5F58	8018 166768	VYACHESLAV VASILEV	{"email": "v.vasilev.011981@postgrespro.ru", "phone": "+70951917161"}
0005434826456	A6069D	3116 027841	ELENA ANDREEVA	{"email": "eandreeva.08111973@postgrespro.ru", "phone": "+70800128215"}
0005434826457	A6069D	3732 143198	ELENA MOISEEVA	{"email": "moiseeva-elena.1971@postgrespro.ru", "phone": "+70356952525"}
0005434826458	514F1F	4018 408104	TATYANA KONOVALOVA	{"email": "konovalova_t.1970@postgrespro.ru", "phone": "+70392829936"}
0005434826459	514F1F	2940 383832	VITALIY NIKITIN	{"phone": "+70015837225"}
0005434826460	A8D971	0210 093871	VALENTINA ILINA	{"email": "ilinav_1975@postgrespro.ru", "phone": "+70709736942"}
0005434826461	94A29B	0720 246998	SERGEY MIRONOV	{"phone": "+70448714810"}
0005434826462	94A29B	9698 622916	ALEKSANDR STEPANOV	{"phone": "+70405337572"}
0005434826463	0FDD96	9173 441986	NADEZHDA GORBUNOVA	{"phone": "+70218390047"}
0005434826464	77960B	7419 783792	SVETLANA VASILEVA	{"phone": "+70711548031"}
0005434826465	3740CF	9532 270567	VIKTOR ANTONOV	{"email": "antonov.v-20111973@postgrespro.ru", "phone": "+70309265724"}
0005434826466	9BA29B	2310 957291	GENNADIY MATVEEV	{"email": "matveev-g-01071973@postgrespro.ru", "phone": "+70610409600"}
0005434826467	A2DCD9	1279 280205	ALEKSANDR GERASIMOV	{"email": "gerasimov.a-1974@postgrespro.ru", "phone": "+70322694575"}
0005434826530	128A3E	5424 322335	VALENTINA ALEKSEEVA	{"phone": "+70195684342"}
0005434826468	AC43B6	1285 182459	MAKSIM BARANOV	{"email": "baranov.maksim1960@postgrespro.ru", "phone": "+70959594414"}
0005434826469	AC43B6	5531 876518	FLYURA ISAEVA	{"phone": "+70331390402"}
0005434826470	7D803D	8574 787314	OKSANA PETROVA	{"email": "oksana-petrova.061971@postgrespro.ru", "phone": "+70823265259"}
0005434826471	D20C6B	2721 547149	ANTONINA ALEKSANDROVA	{"phone": "+70272905997"}
0005434826472	D20C6B	3103 094328	VITALIY FOMIN	{"email": "vitaliy_fomin_1975@postgrespro.ru", "phone": "+70616024513"}
0005434826473	69EA1A	8890 031639	TATYANA MAKSIMOVA	{"phone": "+70700846168"}
0005434826474	69EA1A	9532 729485	IVAN VASILEV	{"phone": "+70228336022"}
0005434826475	3A13DC	7359 069109	EKATERINA STEPANOVA	{"phone": "+70356731253"}
0005434826476	E41C7C	2176 648263	TAMARA NESTEROVA	{"phone": "+70341764098"}
0005434826477	1581DE	2024 643883	VALERIY MELNIKOV	{"phone": "+70583298846"}
0005434826478	82D85E	4859 309055	ALEKSANDR PAVLOV	{"phone": "+70573424521"}
0005434826479	8703CC	6224 297895	NAIL NAZAROV	{"email": "nazarov-n_1977@postgrespro.ru", "phone": "+70083776290"}
0005434826480	44EF5E	4765 044970	ALEKSANDR SOKOLOV	{"email": "aleksandr-sokolov25021971@postgrespro.ru", "phone": "+70239042453"}
0005434826481	C967DC	5029 754084	YULIYA MOISEEVA	{"phone": "+70720137057"}
0005434826482	0C367B	7211 865869	VIKTOR KOZLOV	{"phone": "+70940503525"}
0005434826483	0C367B	1567 865873	NIKOLAY KISELEV	{"phone": "+70749869246"}
0005434826484	C01E8F	8983 846786	LYUDMILA CHERNOVA	{"email": "chernova-lyudmila1963@postgrespro.ru", "phone": "+70815244830"}
0005434826485	6A97EC	8876 757517	LEONID BELOV	{"phone": "+70242335197"}
0005434826486	8E87E7	3657 009290	LARISA SEMENOVA	{"email": "lsemenova.1968@postgrespro.ru", "phone": "+70432975211"}
0005434826487	5400D8	6643 484732	TAMARA VOLKOVA	{"email": "volkova-tamara_1968@postgrespro.ru", "phone": "+70725188467"}
0005434826488	816975	0797 700016	SERGEY FOMIN	{"phone": "+70799672741"}
0005434826489	12A9A6	8376 918606	MIKHAIL NOVIKOV	{"email": "m-novikov.1980@postgrespro.ru", "phone": "+70149197579"}
0005434826490	504E54	5058 379409	NINA SERGEEVA	{"phone": "+70182458616"}
0005434826491	504E54	9720 594505	ANATOLIY FEDOROV	{"email": "fedorov_anatoliy1957@postgrespro.ru", "phone": "+70769195614"}
0005434826492	C3D5FF	6047 950666	VARVARA ANTONOVA	{"phone": "+70581726073"}
0005434826493	C3D5FF	9791 657771	VLADIMIR SIDOROV	{"email": "v.sidorov041983@postgrespro.ru", "phone": "+70912396049"}
0005434826494	C3D5FF	1707 648516	NIKITA NAZAROV	{"phone": "+70411276281"}
0005434826495	4BF9B7	3242 874398	TAMARA NESTEROVA	{"email": "t-nesterova.081968@postgrespro.ru", "phone": "+70995374524"}
0005434826496	4BF9B7	0729 650454	VLADIMIR IVANOV	{"phone": "+70896740716"}
0005434826497	06107F	9425 546500	SVETLANA KUZMINA	{"email": "svetlana-kuzmina-1974@postgrespro.ru", "phone": "+70183679485"}
0005434826498	86DFA9	5350 535709	SERAFIMA POLYAKOVA	{"email": "s.polyakova_021975@postgrespro.ru", "phone": "+70652173094"}
0005434826499	426119	1797 794157	ANNA NIKOLAEVA	{"email": "anna-nikolaeva.15021968@postgrespro.ru", "phone": "+70857105410"}
0005434826500	4AFC4E	7399 318600	IVAN ZAYCEV	{"email": "zaycev-ivan.1977@postgrespro.ru", "phone": "+70780784037"}
0005434826501	BA19C8	1019 534697	VASILIY DMITRIEV	{"phone": "+70351198591"}
0005434826502	FFD46D	8588 870615	PETR MIRONOV	{"email": "mironovpetr-26041980@postgrespro.ru", "phone": "+70203665745"}
0005434826503	A4FF22	0505 779700	VIKTOR MATVEEV	{"phone": "+70236487698"}
0005434826504	D7E092	0285 785221	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila.091967@postgrespro.ru", "phone": "+70959029953"}
0005434826505	35EEAF	5860 297037	GEORGIY NIKOLAEV	{"email": "nikolaev-g-1973@postgrespro.ru", "phone": "+70485523226"}
0005434826506	E6F1AC	4137 765198	RUSLAN FROLOV	{"phone": "+70701458635"}
0005434826507	71F482	4756 184756	VASILIY OSIPOV	{"phone": "+70427801990"}
0005434826508	D26C27	4676 614739	BORIS ZAKHAROV	{"email": "zakharov.boris1971@postgrespro.ru", "phone": "+70354118382"}
0005434826509	BD9F51	8856 636846	GRIGORIY BELOV	{"phone": "+70854815704"}
0005434826510	BD9F51	3827 348896	LYUDMILA POPOVA	{"email": "lyudmilapopova27121979@postgrespro.ru", "phone": "+70739803916"}
0005434826511	661C54	9374 343471	DMITRIY ALEKSANDROV	{"phone": "+70860604052"}
0005434826512	2657D9	3741 236454	EKATERINA VLASOVA	{"email": "e-vlasova-101972@postgrespro.ru", "phone": "+70859491571"}
0005434826513	1C94EE	9911 759853	NATALIYA ANTONOVA	{"email": "antonovanataliya_17021973@postgrespro.ru", "phone": "+70970954993"}
0005434826514	1C94EE	0121 926024	SVETLANA ARKHIPOVA	{"phone": "+70555792487"}
0005434826515	A507BD	0873 192417	RENAT PETROV	{"phone": "+70103661932"}
0005434826516	095262	5523 075243	ANDREY KUZNECOV	{"email": "a_kuznecov-1985@postgrespro.ru", "phone": "+70316523228"}
0005434826517	7E2A1C	4766 683499	LIDIYA ALEKSANDROVA	{"email": "lidiyaaleksandrova1977@postgrespro.ru", "phone": "+70898505010"}
0005434826518	92051A	2732 635377	YULIYA NOVIKOVA	{"phone": "+70086993492"}
0005434826519	7BB170	8097 533126	RINAT SOKOLOV	{"phone": "+70271388436"}
0005434826520	7BB170	8251 490589	EVGENIY DAVYDOV	{"email": "davydov_evgeniy_08101972@postgrespro.ru", "phone": "+70507833647"}
0005434826521	8E90D5	8756 450836	ANASTASIYA ROMANOVA	{"email": "romanova-anastasiya.1971@postgrespro.ru", "phone": "+70519620687"}
0005434826522	10F433	1569 464452	ELENA KONOVALOVA	{"phone": "+70634226794"}
0005434826523	5BF51B	5769 643903	DMITRIY PAVLOV	{"phone": "+70282718983"}
0005434826524	85DC79	3317 818611	KONSTANTIN NIKITIN	{"phone": "+70665125797"}
0005434826525	E47F67	3494 052506	SERGEY KUZNECOV	{"email": "kuznecov.sergey_041978@postgrespro.ru", "phone": "+70894922917"}
0005434826526	E47F67	1007 512816	MAKSIM KUZNECOV	{"email": "kuznecov-maksim-041982@postgrespro.ru", "phone": "+70909902573"}
0005434826527	E47F67	7705 734078	ANASTASIYA KUZMINA	{"phone": "+70777582884"}
0005434826528	E7F542	8058 686788	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev1972@postgrespro.ru", "phone": "+70945987700"}
0005434826531	1B3C42	7466 890384	SOFYA MAKAROVA	{"email": "makarova.s.25051975@postgrespro.ru", "phone": "+70780277235"}
0005434826532	1B3C42	9874 501642	ANTON POPOV	{"email": "anton.popov_1982@postgrespro.ru", "phone": "+70328717959"}
0005434826533	02F78A	4023 783204	ELENA KONOVALOVA	{"phone": "+70036623239"}
0005434826534	D8B299	5846 492076	SVETLANA IVANOVA	{"email": "svetlana-ivanova_25061966@postgrespro.ru", "phone": "+70609091138"}
0005434826535	FD5E60	5058 188951	SVETLANA DANILOVA	{"phone": "+70033926898"}
0005434826536	FD3C93	0114 873861	PAVEL NAUMOV	{"email": "naumov.p11071971@postgrespro.ru", "phone": "+70483019424"}
0005434826537	4B34EE	1833 851281	VALENTIN MELNIKOV	{"phone": "+70631294162"}
0005434826538	9A689C	5205 592039	OLGA SOLOVEVA	{"email": "soloveva_o_1968@postgrespro.ru", "phone": "+70587741401"}
0005434826539	40F05A	6255 836048	MARIYA BORISOVA	{"email": "borisova-mariya091971@postgrespro.ru", "phone": "+70283811647"}
0005434826540	40F05A	4721 433429	PETR MOROZOV	{"phone": "+70917318429"}
0005434826541	40F05A	7976 740736	SERGEY KARPOV	{"phone": "+70534739602"}
0005434826542	A982B5	3253 558428	LILIYA PAVLOVA	{"phone": "+70932197627"}
0005434826543	29609E	2295 521988	LIDIYA ANTONOVA	{"phone": "+70042314761"}
0005434826544	29609E	5852 792854	YURIY ZHUKOV	{"phone": "+70990190473"}
0005434826545	7E21F2	6371 966428	LEONID ANTONOV	{"email": "antonovleonid-08061973@postgrespro.ru", "phone": "+70640284520"}
0005434826546	7E21F2	3099 745680	IRINA MASLOVA	{"email": "maslova_irina-22031983@postgrespro.ru", "phone": "+70822168755"}
0005434826547	23EDF7	7749 880686	DENIS NIKOLAEV	{"phone": "+70249000073"}
0005434826548	23EDF7	0392 564677	VERA ANTONOVA	{"phone": "+70407317537"}
0005434826549	FE0C1A	8760 026601	ANATOLIY VLASOV	{"email": "anatoliyvlasov.071979@postgrespro.ru", "phone": "+70308291414"}
0005434826550	F03795	3756 004892	ILGIZ KAZAKOV	{"phone": "+70523735072"}
0005434826551	F03795	3638 410390	ELENA IVANOVA	{"email": "ivanova_elena.1953@postgrespro.ru", "phone": "+70790155292"}
0005434826552	E69EA7	4998 674316	MARIYA KONDRATEVA	{"phone": "+70018150903"}
0005434826553	CE969B	6174 274885	OKSANA MOISEEVA	{"phone": "+70871137742"}
0005434826554	CE969B	2038 722861	TATYANA DAVYDOVA	{"phone": "+70474546237"}
0005434826555	B1C85F	8870 031327	GALINA LEBEDEVA	{"phone": "+70201349790"}
0005434826556	B1C85F	5069 451400	LYUBOV POPOVA	{"email": "popova.l_13111955@postgrespro.ru", "phone": "+70373754723"}
0005434826557	A9A29F	9964 502761	NADEZHDA KOROLEVA	{"phone": "+70298159998"}
0005434826558	A9A29F	7009 692790	TAMARA KOROLEVA	{"phone": "+70773867673"}
0005434826559	14E5EF	5796 290206	EKATERINA STEPANOVA	{"email": "ekaterina_stepanova.21071958@postgrespro.ru", "phone": "+70153912320"}
0005434826560	633DBA	6051 298881	ANDREY ILIN	{"email": "ailin_1971@postgrespro.ru", "phone": "+70940420280"}
0005434826561	633DBA	2806 794393	TATYANA KUZNECOVA	{"email": "t_kuznecova031971@postgrespro.ru", "phone": "+70419727225"}
0005434826562	62D354	7098 060403	OKSANA TIKHONOVA	{"email": "o-tikhonova_011977@postgrespro.ru", "phone": "+70248515915"}
0005434826563	E7F692	2994 894300	ALEKSEY ILIN	{"email": "aleksey_ilin.051975@postgrespro.ru", "phone": "+70611127731"}
0005434826564	BC3144	3831 105397	NIKITA ZAYCEV	{"email": "n_zaycev-1972@postgrespro.ru", "phone": "+70394473990"}
0005434826565	BC3144	2113 587519	RASHID RODIONOV	{"phone": "+70286386430"}
0005434826566	C4D02F	9383 896246	EKATERINA SERGEEVA	{"phone": "+70914975537"}
0005434826567	328795	2122 739912	OLGA KULIKOVA	{"email": "kulikova.olga1967@postgrespro.ru", "phone": "+70650798134"}
0005434826568	DA12D5	2256 596065	VYACHESLAV ANDREEV	{"email": "andreev.vyacheslav091976@postgrespro.ru", "phone": "+70946978339"}
0005434826569	52203F	9780 844094	ILYA VOROBEV	{"phone": "+70934069553"}
0005434826570	236CE2	6499 982868	VLADISLAV MOROZOV	{"email": "morozov.v-03011968@postgrespro.ru", "phone": "+70289105949"}
0005434826571	236CE2	5794 497255	SERGEY STEPANOV	{"email": "s_stepanov-1966@postgrespro.ru", "phone": "+70091036055"}
0005434826572	695349	2177 125650	MAKSIM KRASNOV	{"email": "maksim.krasnov-1980@postgrespro.ru", "phone": "+70476471438"}
0005434826573	695349	4690 158346	GENNADIY MIRONOV	{"email": "g.mironov.121980@postgrespro.ru", "phone": "+70573062608"}
0005434826574	475A6A	1042 814205	KHALIDA FILIPPOVA	{"phone": "+70594767586"}
0005434826575	475A6A	8814 062938	ALEKSANDR TARASOV	{"email": "atarasov_23061971@postgrespro.ru", "phone": "+70122769572"}
0005434826576	6BA1C7	0773 828131	LILIYA IVANOVA	{"phone": "+70533558608"}
0005434826577	4A4D27	4069 410162	DMITRIY VOROBEV	{"email": "vorobev_d.061967@postgrespro.ru", "phone": "+70433728885"}
0005434826578	57008A	8992 423431	ELENA FEDOROVA	{"email": "efedorova-20091973@postgrespro.ru", "phone": "+70045012032"}
0005434826579	D4F2C1	5051 860719	ELIZAVETA KOVALEVA	{"email": "elizaveta_kovaleva.1985@postgrespro.ru", "phone": "+70456071938"}
0005434826580	E768FA	8588 564709	OLGA KRASNOVA	{"email": "krasnovao.011975@postgrespro.ru", "phone": "+70947678662"}
0005434826581	954383	1411 678307	LARISA MEDVEDEVA	{"phone": "+70667397479"}
0005434826582	C3155A	7789 994577	MARGARITA VOROBEVA	{"email": "vorobeva-margarita_09061967@postgrespro.ru", "phone": "+70553452536"}
0005434826583	D5F641	3325 980971	OKSANA TARASOVA	{"email": "tarasova-o1980@postgrespro.ru", "phone": "+70923423603"}
0005434826584	07FE69	9990 716026	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr041970@postgrespro.ru", "phone": "+70934621537"}
0005434826585	04C9E7	4082 736409	ALEKSANDR SCHERBAKOV	{"phone": "+70408624931"}
0005434826586	442BFC	0993 301595	NATALYA LAZAREVA	{"phone": "+70643578193"}
0005434826587	84172E	7079 944851	ELLA YAKOVLEVA	{"email": "e.yakovleva.1959@postgrespro.ru", "phone": "+70944096227"}
0005434826588	84172E	2949 435833	ALEKSANDR IVANOV	{"phone": "+70334269585"}
0005434826589	84172E	6858 896243	ANDREY TARASOV	{"email": "atarasov071968@postgrespro.ru", "phone": "+70881487725"}
0005434826590	E9C091	0486 854687	RUSLAN SOLOVEV	{"phone": "+70872107068"}
0005434826591	E9C091	4117 091839	SERGEY ZAKHAROV	{"email": "szakharov.1960@postgrespro.ru", "phone": "+70704022059"}
0005434826592	F9FDE4	2937 366072	VLADIMIR MATVEEV	{"phone": "+70324288398"}
0005434826593	06450B	7929 965167	IRINA FILIPPOVA	{"email": "filippovairina_061968@postgrespro.ru", "phone": "+70342359904"}
0005434826594	F165A9	6213 402587	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr-1975@postgrespro.ru", "phone": "+70519425772"}
0005434826595	F02ECC	4935 757976	DMITRIY KONOVALOV	{"phone": "+70969731878"}
0005434826596	F02ECC	9942 914942	ALEKSANDR OSIPOV	{"email": "osipova-111978@postgrespro.ru", "phone": "+70377288607"}
0005434826597	F02ECC	4324 166465	VIKTOR ZAKHAROV	{"phone": "+70659897813"}
0005434826598	F02ECC	2648 142315	ROMAN PETROV	{"email": "petrov-r.111979@postgrespro.ru", "phone": "+70537248530"}
0005434826599	5B11EC	6432 263759	ALEKSEY POPOV	{"email": "popov.a.031989@postgrespro.ru", "phone": "+70690268946"}
0005434826600	7E646A	5057 373850	VALENTINA VOLKOVA	{"phone": "+70102775739"}
0005434826601	448CE5	6820 230940	NIKOLAY MOROZOV	{"email": "morozov.nikolay.081963@postgrespro.ru", "phone": "+70367621666"}
0005434826657	4FF0A2	5615 524319	ANASTASIYA ZHUKOVA	{"phone": "+70483858041"}
0005434826602	DF777B	2128 423731	LYUDMILA ALEKSEEVA	{"email": "alekseevalyudmila.31081971@postgrespro.ru", "phone": "+70207002342"}
0005434826603	3FE11C	1505 338898	FEDOR TARASOV	{"email": "fedor.tarasov101982@postgrespro.ru", "phone": "+70654456862"}
0005434826604	3FE11C	3445 698666	ALEKSANDR STEPANOV	{"email": "stepanov_a-26041973@postgrespro.ru", "phone": "+70481227102"}
0005434826605	3FE11C	8601 465092	NINA POPOVA	{"email": "n-popova-1966@postgrespro.ru", "phone": "+70850528082"}
0005434826606	36925B	5181 961308	OLGA EFREMOVA	{"email": "o_efremova.011971@postgrespro.ru", "phone": "+70769341171"}
0005434826607	36925B	8663 907790	DENIS SMIRNOV	{"phone": "+70031539805"}
0005434826608	7D8589	6455 340048	YAKOV ZHURAVLEV	{"phone": "+70379640084"}
0005434826609	7DC2E6	0193 565940	ALEKSEY DMITRIEV	{"email": "dmitriev.a1978@postgrespro.ru", "phone": "+70188203500"}
0005434826610	8DC4F4	5801 362161	VALENTINA FILIPPOVA	{"email": "valentina.filippova04031974@postgrespro.ru", "phone": "+70759035895"}
0005434826611	293C54	7233 705841	ANNA PETROVA	{"phone": "+70687074352"}
0005434826612	293C54	4685 365542	IRINA POPOVA	{"phone": "+70145358294"}
0005434826613	2681D6	2214 999059	EKATERINA DAVYDOVA	{"email": "e-davydova_15101975@postgrespro.ru", "phone": "+70102139116"}
0005434826614	FA98F3	3967 360171	LYUBOV IVANOVA	{"email": "ivanova.l-17011974@postgrespro.ru", "phone": "+70288585474"}
0005434826615	FA98F3	3815 737842	SVETLANA SOKOLOVA	{"phone": "+70999934980"}
0005434826616	6414D1	6064 263062	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey_10021969@postgrespro.ru", "phone": "+70869724001"}
0005434826617	6414D1	6415 719582	SVETLANA NIKIFOROVA	{"email": "s-nikiforova-11081975@postgrespro.ru", "phone": "+70281672732"}
0005434826618	6414D1	9696 190483	IGOR IVANOV	{"phone": "+70581856130"}
0005434826619	16C8DE	0744 462523	KRISTINA BELOVA	{"email": "belova-k_29071972@postgrespro.ru", "phone": "+70388485043"}
0005434826620	743005	9287 479401	NADEZHDA NOVIKOVA	{"email": "nadezhda.novikova.111967@postgrespro.ru", "phone": "+70648670043"}
0005434826621	743005	0620 923194	ALEKSEY KRASNOV	{"email": "aleksey_krasnov.24041965@postgrespro.ru", "phone": "+70454459283"}
0005434826622	33F4A4	6872 630528	VYACHESLAV MAKAROV	{"email": "makarovv-30051964@postgrespro.ru", "phone": "+70435515950"}
0005434826623	30DC00	5570 714399	MAKSIM MAKAROV	{"email": "maksim.makarov1975@postgrespro.ru", "phone": "+70957923599"}
0005434826624	30DC00	4570 891405	ALEKSANDR KUZMIN	{"email": "kuzmin.a.011973@postgrespro.ru", "phone": "+70731854916"}
0005434826625	78B7EA	3766 356206	ARINA STEPANOVA	{"email": "a-stepanova_101978@postgrespro.ru", "phone": "+70256305729"}
0005434826626	78B7EA	4875 704196	IVAN KRASNOV	{"email": "i_krasnov.121974@postgrespro.ru", "phone": "+70241457618"}
0005434826627	6154B8	0029 204375	SERGEY STEPANOV	{"email": "stepanov-sergey-1972@postgrespro.ru", "phone": "+70402303538"}
0005434826628	A2E638	8822 941157	VLADIMIR MATVEEV	{"email": "vladimir_matveev_03121954@postgrespro.ru", "phone": "+70902864074"}
0005434826629	53DF64	2808 726118	YULIYA RYABOVA	{"email": "ryabova-yuliya1978@postgrespro.ru", "phone": "+70727910169"}
0005434826630	53DF64	6556 951182	NATALIYA KUZMINA	{"email": "nataliya-kuzmina111980@postgrespro.ru", "phone": "+70540400666"}
0005434826631	313D1E	6237 641082	SERGEY POPOV	{"phone": "+70640898856"}
0005434826632	6A5B33	2072 610139	MAKSIM DMITRIEV	{"phone": "+70353328678"}
0005434826633	6A5B33	9666 648936	ANDREY ZHUKOV	{"phone": "+70089902733"}
0005434826634	CCFCDB	3063 784201	VERA LEBEDEVA	{"phone": "+70169364605"}
0005434826635	456A71	7746 525852	EGOR DENISOV	{"phone": "+70314735686"}
0005434826636	D30045	0153 313499	NATALYA ERMAKOVA	{"email": "ermakova.natalya.19041972@postgrespro.ru", "phone": "+70348832232"}
0005434826637	50162F	3996 476295	YURIY KRASNOV	{"email": "krasnov-y-1974@postgrespro.ru", "phone": "+70556951668"}
0005434826638	C87A5D	5606 808815	DMITRIY SMIRNOV	{"email": "dmitriy-smirnov.1970@postgrespro.ru", "phone": "+70799618616"}
0005434826639	C87A5D	3461 516502	DAMIR STEPANOV	{"phone": "+70115965313"}
0005434826640	6603F8	4460 532984	ROMAN ZAKHAROV	{"phone": "+70859568906"}
0005434826641	6603F8	2189 750539	NIKOLAY FOMIN	{"email": "nikolay_fomin-18021981@postgrespro.ru", "phone": "+70477082532"}
0005434826642	B59825	0244 521694	EKATERINA CHERNOVA	{"phone": "+70543528394"}
0005434826643	B59825	0038 807759	VERA PETROVA	{"phone": "+70247095348"}
0005434826644	2B22F8	5862 690404	ANASTASIYA KALININA	{"phone": "+70878168015"}
0005434826645	CF58BC	9406 872946	NADEZHDA SOROKINA	{"email": "n.sorokina16021988@postgrespro.ru", "phone": "+70849965930"}
0005434826646	CF58BC	3159 233525	SERGEY SOLOVEV	{"phone": "+70139999673"}
0005434826647	815F7C	9012 381105	ELENA SEMENOVA	{"phone": "+70101914876"}
0005434826648	815F7C	8310 050873	IVAN RODIONOV	{"phone": "+70159116233"}
0005434826649	2AC931	8189 074866	NIKOLAY MELNIKOV	{"email": "melnikovn041966@postgrespro.ru", "phone": "+70960754452"}
0005434826650	A1D98D	3755 605065	RAMILYA DANILOVA	{"email": "danilova_ramilya-28111975@postgrespro.ru", "phone": "+70691160988"}
0005434826651	100A6E	6907 066710	KONSTANTIN FEDOROV	{"email": "fedorov.konstantin.1968@postgrespro.ru", "phone": "+70241087430"}
0005434826652	E7BF25	3654 890971	VYACHESLAV KUZNECOV	{"email": "v-kuznecov_021968@postgrespro.ru", "phone": "+70392559067"}
0005434826653	11D953	8959 415355	ALEKSEY POPOV	{"phone": "+70599074455"}
0005434826654	D319FC	9717 021935	ALEKSANDR BORISOV	{"phone": "+70086809201"}
0005434826655	D319FC	3798 846428	NINA ANDREEVA	{"email": "andreeva_nina-23091969@postgrespro.ru", "phone": "+70637575418"}
0005434826656	4CBBF3	6638 070394	YURIY SEMENOV	{"phone": "+70409962449"}
0005434826658	4FF0A2	7543 792086	ALEKSEY KUDRYASHOV	{"phone": "+70908099537"}
0005434826659	0CA600	5666 232698	OLEG SERGEEV	{"email": "osergeev.29011979@postgrespro.ru", "phone": "+70567450513"}
0005434826660	817199	9172 861176	SVETLANA ANDREEVA	{"email": "s_andreeva-021973@postgrespro.ru", "phone": "+70240152804"}
0005434826661	A0CD1D	1589 789821	PETR ANTONOV	{"email": "antonovp-1954@postgrespro.ru", "phone": "+70227181908"}
0005434826662	A0CD1D	0134 385108	VLADISLAV MEDVEDEV	{"phone": "+70660941164"}
0005434826663	5EA0C0	2161 136742	NATALYA IVANOVA	{"phone": "+70411817887"}
0005434826664	5EA0C0	0411 050669	KONSTANTIN FEDOROV	{"phone": "+70141065703"}
0005434826665	C972C6	9971 720162	LIDIYA LEBEDEVA	{"email": "lebedeva-l_051960@postgrespro.ru", "phone": "+70803277573"}
0005434826666	C972C6	3900 878667	ALEKSANDR GAVRILOV	{"email": "gavrilov.a.04101984@postgrespro.ru", "phone": "+70776179567"}
0005434826667	1271A0	1947 565106	VIKTOR MAKAROV	{"email": "makarov_viktor_1958@postgrespro.ru", "phone": "+70575362621"}
0005434826668	EC1421	2365 788207	LARISA NOVIKOVA	{"email": "lnovikova_16051961@postgrespro.ru", "phone": "+70399991280"}
0005434826669	5BA230	5598 338573	MARIYA IVANOVA	{"email": "ivanova_m-121958@postgrespro.ru", "phone": "+70017847028"}
0005434826670	1C1223	5294 488246	MARINA SMIRNOVA	{"phone": "+70618483949"}
0005434826671	1C1223	5956 385439	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov.02121969@postgrespro.ru", "phone": "+70829853358"}
0005434826672	FDE3D7	7786 154238	IRINA POPOVA	{"email": "popova-irina_1955@postgrespro.ru", "phone": "+70761073473"}
0005434826673	4E57A4	5115 885700	ANNA NAZAROVA	{"email": "nazarova.a_021975@postgrespro.ru", "phone": "+70293608894"}
0005434826674	06BD2B	7337 067507	NATALYA NOVIKOVA	{"email": "natalya_novikova071975@postgrespro.ru", "phone": "+70285700882"}
0005434826675	71D557	0717 261260	LARISA KUZMINA	{"phone": "+70745213789"}
0005434826676	80ABCF	8653 647881	EKATERINA MAKAROVA	{"email": "ekaterina.makarova.051977@postgrespro.ru", "phone": "+70271161076"}
0005434826677	D1CD6E	0500 498072	ALEKSEY MAKAROV	{"phone": "+70274595073"}
0005434826678	C4C600	6057 817593	OLGA TARASOVA	{"phone": "+70616507102"}
0005434826679	60EBF0	6788 656853	LYUBOV MOROZOVA	{"email": "morozova_lyubov-051968@postgrespro.ru", "phone": "+70168499419"}
0005434826680	E91F8D	3105 939718	ANASTASIYA ARKHIPOVA	{"email": "aarkhipova-011977@postgrespro.ru", "phone": "+70721647441"}
0005434826681	E91F8D	8560 201796	VIKTORIYA BARANOVA	{"email": "viktoriya.baranova-22051975@postgrespro.ru", "phone": "+70128916157"}
0005434826682	1F4DA5	0068 600590	EKATERINA MALYSHEVA	{"phone": "+70608029955"}
0005434826683	E82325	0612 242654	TATYANA KALININA	{"phone": "+70964132965"}
0005434826684	FA9A67	2517 957289	RUSLAN SERGEEV	{"phone": "+70098423135"}
0005434826685	BE9675	6822 559013	VALENTINA VASILEVA	{"phone": "+70553279751"}
0005434826686	826B63	4807 268716	LYUBOV MALYSHEVA	{"email": "malysheva_l_09101972@postgrespro.ru", "phone": "+70203192160"}
0005434826687	493168	0611 118177	VALENTINA NIKITINA	{"email": "valentinanikitina-1973@postgrespro.ru", "phone": "+70630396989"}
0005434826688	A5B939	6744 161700	ANASTASIYA TIKHONOVA	{"email": "anastasiya-tikhonova-101966@postgrespro.ru", "phone": "+70599024030"}
0005434826689	A5B939	0266 758618	ANATOLIY BARANOV	{"email": "baranov-a-1963@postgrespro.ru", "phone": "+70081517593"}
0005434826690	7C2059	6191 675525	SERGEY BELOV	{"phone": "+70665438029"}
0005434826691	9987D0	6851 903572	VYACHESLAV BORISOV	{"email": "v_borisov.111976@postgrespro.ru", "phone": "+70936535227"}
0005434826692	9987D0	5108 578672	ELENA ZAKHAROVA	{"phone": "+70033394157"}
0005434826693	FE88CA	8408 759623	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr-27041982@postgrespro.ru", "phone": "+70856297815"}
0005434826694	FE88CA	7636 165603	FATIMA MAKAROVA	{"email": "makarovafatima.29011971@postgrespro.ru", "phone": "+70321674897"}
0005434826695	FF5D3E	3379 355076	SERAFIMA BORISOVA	{"email": "s.borisova.071974@postgrespro.ru", "phone": "+70518857504"}
0005434826696	4C338F	6259 543402	VALERIYA FILIPPOVA	{"phone": "+70348800294"}
0005434826697	E83372	0378 346988	NATALYA NAZAROVA	{"email": "nazarova-natalya_19081979@postgrespro.ru", "phone": "+70464848907"}
0005434826698	E83372	0885 887598	ELENA IVANOVA	{"email": "ivanovae-10031971@postgrespro.ru", "phone": "+70420483382"}
0005434826699	11F83C	2579 542406	ALEKSEY KOZLOV	{"email": "kozlov-a091971@postgrespro.ru", "phone": "+70501499943"}
0005434826700	11F83C	5385 093538	ZINAIDA MIRONOVA	{"phone": "+70005939189"}
0005434826701	74A4C6	0101 791857	SERGEY NAUMOV	{"phone": "+70811179491"}
0005434826702	5CB131	7741 943028	ARSENIY VASILEV	{"phone": "+70451219262"}
0005434826703	E9E7CE	2010 063659	KONSTANTIN ZHUKOV	{"phone": "+70586784455"}
0005434826704	9C35BC	6614 391780	TAMARA VASILEVA	{"email": "tamara_vasileva_22091969@postgrespro.ru", "phone": "+70582869484"}
0005434826705	9C35BC	0568 850367	ANDREY POPOV	{"phone": "+70745550135"}
0005434826706	11401D	5913 129051	MARINA GAVRILOVA	{"email": "m_gavrilova.06011970@postgrespro.ru", "phone": "+70258088373"}
0005434826707	11401D	5600 756337	ALEKSANDR MAKSIMOV	{"phone": "+70116815290"}
0005434826708	A2DF96	4009 141303	EVGENIY TIKHONOV	{"phone": "+70942692404"}
0005434826709	F1669A	3203 599395	LIDIYA NAZAROVA	{"email": "lidiya_nazarova-22111975@postgrespro.ru", "phone": "+70811850272"}
0005434826710	BDEF2D	0567 334735	MARIYA NAZAROVA	{"email": "m-nazarova011964@postgrespro.ru", "phone": "+70984030881"}
0005434826711	BDEF2D	7698 076354	IVAN ISAEV	{"phone": "+70947358455"}
0005434826712	A90F1F	8007 633594	ELIZAVETA SMIRNOVA	{"email": "smirnovaelizaveta071966@postgrespro.ru", "phone": "+70145247183"}
0005434826713	456E80	9999 898268	MAKSIM STEPANOV	{"email": "mstepanov.121974@postgrespro.ru", "phone": "+70142416979"}
0005434826714	B38877	1415 742722	GALINA ALEKSEEVA	{"phone": "+70947633998"}
0005434826715	ADCCA1	1529 658355	NATALYA ILINA	{"email": "nilina_14031977@postgrespro.ru", "phone": "+70966646882"}
0005434826716	294DB5	1259 966819	MIKHAIL SIDOROV	{"phone": "+70356426817"}
0005434826717	294DB5	1678 840284	TAMARA KONOVALOVA	{"email": "tkonovalova_15041968@postgrespro.ru", "phone": "+70393020771"}
0005434826718	FFC045	3480 458242	IVAN TIMOFEEV	{"email": "timofeevi_1970@postgrespro.ru", "phone": "+70559634572"}
0005434826719	FFC045	4620 425616	ALEKSANDR KOROLEV	{"phone": "+70253675327"}
0005434826720	6F10B2	2271 575699	IRINA POTAPOVA	{"phone": "+70993912160"}
0005434826721	6F10B2	3939 261075	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d-1970@postgrespro.ru", "phone": "+70194687175"}
0005434826722	113CB8	7359 332551	NIKOLAY TIKHONOV	{"email": "tikhonov.nikolay111961@postgrespro.ru", "phone": "+70106481838"}
0005434826723	113CB8	7002 453652	OLEG EGOROV	{"email": "oegorov_27121980@postgrespro.ru", "phone": "+70124999574"}
0005434826724	D17706	5936 651313	ANDREY KUZNECOV	{"phone": "+70916978151"}
0005434826725	171AE7	4367 860399	SERGEY RODIONOV	{"email": "sergey.rodionov.1972@postgrespro.ru", "phone": "+70065048934"}
0005434826726	171AE7	5424 206149	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-1968@postgrespro.ru", "phone": "+70264851149"}
0005434826727	B37376	2316 328605	VLADIMIR ANDREEV	{"phone": "+70898594731"}
0005434826728	B37376	1060 396053	TATYANA SMIRNOVA	{"email": "smirnovat_23091981@postgrespro.ru", "phone": "+70429750773"}
0005434826729	669D4E	8742 732312	TAMARA FADEEVA	{"email": "fadeeva-t.31071970@postgrespro.ru", "phone": "+70000660134"}
0005434826730	669D4E	0162 067057	LYUDMILA MIKHAYLOVA	{"email": "lyudmila_mikhaylova.1974@postgrespro.ru", "phone": "+70462098276"}
0005434826731	1FEBCC	3257 762353	VLADIMIR SOLOVEV	{"email": "solovev_vladimir.1972@postgrespro.ru", "phone": "+70307173701"}
0005434826732	4FC16E	1314 489069	SVETLANA ARKHIPOVA	{"phone": "+70417315774"}
0005434826733	4639B3	3212 417453	ULYANA SOLOVEVA	{"email": "soloveva-u.121978@postgrespro.ru", "phone": "+70840740978"}
0005434826734	33AC24	3436 844968	IVAN NIKOLAEV	{"phone": "+70634854076"}
0005434826735	33AC24	9748 596765	EVGENIY NIKOLAEV	{"email": "nikolaeve_23071975@postgrespro.ru", "phone": "+70455770060"}
0005434826736	7B3E4A	1468 056455	GEORGIY ROMANOV	{"email": "romanov_georgiy-1972@postgrespro.ru", "phone": "+70071663312"}
0005434826737	7B3E4A	7627 526406	ILYA FOMIN	{"email": "fomin-ilya_05041962@postgrespro.ru", "phone": "+70556517098"}
0005434826738	0AD85A	8712 903588	KLAVDIYA BORISOVA	{"email": "borisova.k-06121960@postgrespro.ru", "phone": "+70751983716"}
0005434826739	86625D	6248 630858	PAVEL IVANOV	{"phone": "+70868423963"}
0005434826740	6A391E	7489 560964	LYUDMILA POLYAKOVA	{"phone": "+70381050722"}
0005434826741	6A391E	0193 634989	MARINA DANILOVA	{"phone": "+70687744161"}
0005434826742	6A391E	2579 661871	VALENTINA KAZAKOVA	{"phone": "+70036060532"}
0005434826743	53B906	2012 129880	VALENTINA AKIMOVA	{"email": "akimovav.1983@postgrespro.ru", "phone": "+70381238306"}
0005434826744	53B906	3085 034236	ARTEM FOMIN	{"email": "a_fomin-05101967@postgrespro.ru", "phone": "+70972987338"}
0005434826745	1C7679	6510 153923	LYUBOV YAKOVLEVA	{"phone": "+70465656756"}
0005434826746	A3FBF6	7973 922145	ANASTASIYA EGOROVA	{"email": "a_egorova-081974@postgrespro.ru", "phone": "+70625952887"}
0005434826747	5DA40A	0328 834388	DMITRIY SERGEEV	{"email": "sergeev_dmitriy.1975@postgrespro.ru", "phone": "+70261424517"}
0005434826748	480D59	2689 606382	TATYANA SAVELEVA	{"phone": "+70707961072"}
0005434826749	E0EBB1	0623 070653	SERGEY VASILEV	{"phone": "+70163104871"}
0005434826750	E0EBB1	0070 895921	IRINA BOGDANOVA	{"phone": "+70868455270"}
0005434826751	56FA92	8626 527829	SERGEY SCHERBAKOV	{"email": "sergey_scherbakov.111964@postgrespro.ru", "phone": "+70255127920"}
0005434826752	DC61E6	5972 901480	DENIS KONOVALOV	{"email": "d_konovalov_061973@postgrespro.ru", "phone": "+70828856599"}
0005434826753	7F6B9C	8039 662055	YURIY GORBUNOV	{"phone": "+70797496283"}
0005434826754	7F6B9C	3603 513351	TAMARA BOGDANOVA	{"phone": "+70614738516"}
0005434826755	0ED44B	0112 553621	GENNADIY VOROBEV	{"phone": "+70169864345"}
0005434826756	0ED44B	3726 340568	ANASTASIYA NOVIKOVA	{"phone": "+70532086662"}
0005434826757	D9F3C8	0140 556636	SVETLANA DENISOVA	{"phone": "+70193011425"}
0005434826758	DA1A7B	3767 408343	LYUBOV GUSEVA	{"email": "guseva.l-31071955@postgrespro.ru", "phone": "+70395303942"}
0005434826759	86700B	7927 846474	EVGENIY MIKHAYLOV	{"email": "mikhaylove.25061967@postgrespro.ru", "phone": "+70540677704"}
0005434826760	526E98	4325 706180	VALENTINA VLASOVA	{"email": "vlasova.valentina-22101969@postgrespro.ru", "phone": "+70628106099"}
0005434826761	4696D3	3322 683459	EDUARD CHERNOV	{"email": "chernov.e-26051972@postgrespro.ru", "phone": "+70608652839"}
0005434826762	CE807F	1964 550159	ARTEM DAVYDOV	{"email": "davydov-artem.22021970@postgrespro.ru", "phone": "+70352732211"}
0005434826763	421B71	9694 276967	OLGA IVANOVA	{"email": "o-ivanova-111975@postgrespro.ru", "phone": "+70760815526"}
0005434826764	421B71	3450 080771	VLADIMIR EGOROV	{"email": "vladimir_egorov.041969@postgrespro.ru", "phone": "+70949920720"}
0005434826765	35F286	4767 497592	FEDOR GERASIMOV	{"email": "gerasimov-f.051980@postgrespro.ru", "phone": "+70670464909"}
0005434826766	35F286	5746 108509	OLGA MIRONOVA	{"phone": "+70172111832"}
0005434826767	35F286	7378 554305	NATALYA MASLOVA	{"phone": "+70509751645"}
0005434826768	B3DD0C	0769 351887	NIKITA KUDRYASHOV	{"phone": "+70795966352"}
0005434826769	4426F8	3925 364721	VERA RYABOVA	{"phone": "+70896236928"}
0005434826770	8D44F0	5096 605434	VALERIYA SOROKINA	{"phone": "+70394961028"}
0005434826771	8D44F0	9439 676129	NIKOLAY IVANOV	{"phone": "+70525066275"}
0005434826772	C9E1DA	6254 529375	SERGEY BELOV	{"email": "belov.sergey.041970@postgrespro.ru", "phone": "+70108989436"}
0005434826773	FFA7AC	8429 882920	ANDREY FOMIN	{"email": "andreyfomin.091980@postgrespro.ru", "phone": "+70891546515"}
0005434826774	691EB8	2408 986853	ALEKSANDR TIKHONOV	{"email": "tikhonovaleksandr.22071975@postgrespro.ru", "phone": "+70360355395"}
0005434826775	691EB8	6538 113527	LUIZA EGOROVA	{"email": "egorova.luiza-1986@postgrespro.ru", "phone": "+70763665375"}
0005434826776	691EB8	5004 095241	VALENTINA MOROZOVA	{"email": "morozova-v1981@postgrespro.ru", "phone": "+70834253945"}
0005434826777	FB4AB8	1686 914146	ARINA SEMENOVA	{"email": "semenova-arina_09011968@postgrespro.ru", "phone": "+70268339837"}
0005434826778	214296	6963 288995	LIDIYA SOKOLOVA	{"phone": "+70588074440"}
0005434826779	8E3F38	4100 625082	GALINA FOMINA	{"email": "galina_fomina_1966@postgrespro.ru", "phone": "+70820629723"}
0005434826780	C8C55D	6988 151375	MIKHAIL KUZNECOV	{"email": "mkuznecov_091964@postgrespro.ru", "phone": "+70990100881"}
0005434826781	C8C55D	8307 390055	EGOR SOLOVEV	{"phone": "+70153633015"}
0005434826782	C8C55D	4926 633973	ALEKSANDR CHERNOV	{"email": "achernov12071969@postgrespro.ru", "phone": "+70939875712"}
0005434826783	578A96	4864 662708	ALEKSANDRA OVCHINNIKOVA	{"email": "ovchinnikova.aleksandra.071965@postgrespro.ru", "phone": "+70839794551"}
0005434826784	578A96	7727 215096	KLARA KOZLOVA	{"phone": "+70729517417"}
0005434826785	3EC992	4448 517053	VLADIMIR IVANOV	{"phone": "+70456838067"}
0005434826786	0A0DEA	8284 494246	TIGRAN NAUMOV	{"phone": "+70035294121"}
0005434826787	0A0DEA	2111 065169	MIKHAIL IVANOV	{"email": "ivanov.mikhail_24011968@postgrespro.ru", "phone": "+70472323320"}
0005434826788	0A0DEA	1654 915498	ANDREY KOROLEV	{"email": "korolev_andrey.1973@postgrespro.ru", "phone": "+70905012205"}
0005434826789	641DAA	1960 018686	DENIS NIKITIN	{"email": "nikitin.d-1976@postgrespro.ru", "phone": "+70084949000"}
0005434826790	9270F7	3445 262323	NIKOLAY NIKITIN	{"phone": "+70233504021"}
0005434826791	A080FC	4803 024878	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr-25121984@postgrespro.ru", "phone": "+70418394444"}
0005434826792	9C7CC5	8647 977290	KRISTINA YAKOVLEVA	{"email": "kristina_yakovleva-071971@postgrespro.ru", "phone": "+70714918416"}
0005434826793	4818B1	8380 305630	MARINA PAVLOVA	{"email": "pavlovamarina_17111961@postgrespro.ru", "phone": "+70082651959"}
0005434826794	4818B1	6186 296411	DANIL ZHURAVLEV	{"email": "danil.zhuravlev091959@postgrespro.ru", "phone": "+70437661214"}
0005434826795	4818B1	6182 953992	SVETLANA MATVEEVA	{"email": "svetlana-matveeva_071969@postgrespro.ru", "phone": "+70745281213"}
0005434826796	CC25C9	0070 877043	GALINA KUZMINA	{"phone": "+70132620309"}
0005434826797	6744C7	7948 560143	ALEKSEY SERGEEV	{"phone": "+70085623690"}
0005434826798	F35F2B	0014 343335	ALEKSEY KONOVALOV	{"email": "konovalov_a-16071969@postgrespro.ru", "phone": "+70811012983"}
0005434826799	F35F2B	0948 010681	YURIY KUZMIN	{"phone": "+70067560194"}
0005434826800	24892C	9563 086523	NINA SERGEEVA	{"email": "sergeeva.nina031967@postgrespro.ru", "phone": "+70305640207"}
0005434826801	937AB6	0356 370390	MARIYA LEBEDEVA	{"phone": "+70600659446"}
0005434826802	0C09BE	5421 832204	OLGA ILINA	{"phone": "+70774882848"}
0005434826803	C9B607	5786 365507	NATALYA KOROLEVA	{"phone": "+70121895886"}
0005434826804	C9B607	0940 880144	VALENTINA KOROLEVA	{"phone": "+70442542465"}
0005434826805	C8CEF5	0667 290653	ANASTASIYA VASILEVA	{"email": "a_vasileva111974@postgrespro.ru", "phone": "+70153536748"}
0005434826806	3FC9DE	6002 544332	ELENA ISAEVA	{"phone": "+70475570790"}
0005434826807	39D3BB	3859 065613	GEORGIY IVANOV	{"phone": "+70193960846"}
0005434826808	BBAD2E	9367 993395	DMITRIY KAZAKOV	{"phone": "+70352634216"}
0005434826809	BE2834	3855 993184	ILSHAT VASILEV	{"email": "i-vasilev.1979@postgrespro.ru", "phone": "+70930011197"}
0005434826810	CBF4B6	5997 961692	ALEKSANDRA RODIONOVA	{"phone": "+70696139745"}
0005434826811	CBF4B6	6616 998150	ANDREY BARANOV	{"email": "andrey.baranov-14061966@postgrespro.ru", "phone": "+70020604118"}
0005434826812	CC0194	0134 468536	MAKSIM DMITRIEV	{"phone": "+70860488770"}
0005434826813	EB295A	7130 838302	ANTONINA SERGEEVA	{"phone": "+70172392672"}
0005434826814	4601B5	6098 998098	OLGA RODIONOVA	{"phone": "+70098065659"}
0005434826815	4601B5	6521 365039	MIKHAIL NIKITIN	{"email": "nikitin.m_27031979@postgrespro.ru", "phone": "+70353196397"}
0005434826816	777E43	1154 792892	ANTONINA ANDREEVA	{"email": "andreevaa-11011978@postgrespro.ru", "phone": "+70620028782"}
0005434826817	777E43	5731 398997	NADEZHDA SCHERBAKOVA	{"phone": "+70747901550"}
0005434826818	CA08FB	7367 611961	VIKTORIYA NIKOLAEVA	{"phone": "+70227137414"}
0005434826819	06CC48	9184 469830	DMITRIY FEDOTOV	{"phone": "+70799817209"}
0005434826820	06CC48	9474 160466	ROMAN MIKHAYLOV	{"email": "mikhaylov_r-011970@postgrespro.ru", "phone": "+70093403697"}
0005434826821	1E23A9	5316 807138	EKATERINA MOROZOVA	{"email": "morozova-ekaterina_041977@postgrespro.ru", "phone": "+70825237619"}
0005434826822	E23ADB	1634 303265	EGOR KUDRYASHOV	{"email": "e.kudryashov1969@postgrespro.ru", "phone": "+70870702900"}
0005434826823	8EB230	6845 685938	DMITRIY PETROV	{"email": "petrov.d-1963@postgrespro.ru", "phone": "+70241687498"}
0005434826824	8EB230	7020 212612	DANIYA FEDOROVA	{"phone": "+70048977554"}
0005434826825	57FA83	5725 119722	YULIYA KUZNECOVA	{"email": "y-kuznecova1966@postgrespro.ru", "phone": "+70240994268"}
0005434826826	57FA83	5401 365765	MARGARITA YAKOVLEVA	{"phone": "+70731548057"}
0005434826827	CF93A9	0311 954364	GALINA IVANOVA	{"email": "ivanova-g.1966@postgrespro.ru", "phone": "+70767965312"}
0005434826828	5AB96C	7228 752604	YULIYA ALEKSEEVA	{"phone": "+70235986677"}
0005434826829	5AB96C	3695 765025	GRIGORIY ANDREEV	{"email": "andreevgrigoriy-1968@postgrespro.ru", "phone": "+70764982197"}
0005434826830	5AB96C	8837 774295	VALENTINA ZHURAVLEVA	{"phone": "+70588503771"}
0005434826831	B73C35	0513 853755	GENNADIY SEMENOV	{"email": "gennadiy-semenov18101967@postgrespro.ru", "phone": "+70150984693"}
0005434826832	86349A	3001 513503	NATALIYA SERGEEVA	{"phone": "+70272458379"}
0005434826833	EA3FEC	1161 367088	VALERIY PETROV	{"phone": "+70601970324"}
0005434826834	A42D5A	3520 211120	YULIYA BARANOVA	{"phone": "+70820729992"}
0005434826835	A42D5A	1204 410247	VALENTINA SOKOLOVA	{"phone": "+70580412661"}
0005434826836	A42D5A	9882 115583	IVAN FEDOROV	{"phone": "+70765291962"}
0005434826837	FA3513	3588 225032	MARIYA NAUMOVA	{"phone": "+70219592794"}
0005434826838	9C7177	1781 686144	DANILA VLASOV	{"phone": "+70566695216"}
0005434826839	DD07F6	1461 701893	TATYANA ALEKSEEVA	{"email": "alekseeva-tatyana-061966@postgrespro.ru", "phone": "+70716993858"}
0005434826840	DE8733	1756 514625	EKATERINA IVANOVA	{"email": "ivanovae-071961@postgrespro.ru", "phone": "+70821513785"}
0005434826841	90C070	2386 060288	ANASTASIYA MELNIKOVA	{"phone": "+70416400634"}
0005434826842	90C070	0879 138948	VLADIMIR KUZNECOV	{"email": "kuznecov.v.13011966@postgrespro.ru", "phone": "+70966341077"}
0005434826843	046B30	2668 475916	SVETLANA KAZAKOVA	{"email": "kazakovasvetlana.1970@postgrespro.ru", "phone": "+70340561156"}
0005434826844	2130D2	0516 432481	ZINAIDA KAZAKOVA	{"email": "zinaida-kazakova.27061967@postgrespro.ru", "phone": "+70341303836"}
0005434826845	2130D2	0109 760252	NINA KUZNECOVA	{"email": "kuznecova_n.1959@postgrespro.ru", "phone": "+70498104843"}
0005434826846	B8A021	0623 740790	ANNA POPOVA	{"email": "anna.popova-1963@postgrespro.ru", "phone": "+70688850941"}
0005434826847	47B8A5	6831 245028	ANNA VASILEVA	{"phone": "+70230310956"}
0005434826848	2A91BF	8221 972522	GULNARA MEDVEDEVA	{"email": "g_medvedeva_1970@postgrespro.ru", "phone": "+70043134659"}
0005434826849	2A91BF	6133 451584	STANISLAV KUZNECOV	{"phone": "+70201262009"}
0005434826850	F4E665	4801 654858	VALENTINA MAKSIMOVA	{"email": "maksimova-valentina_011980@postgrespro.ru", "phone": "+70340134205"}
0005434826851	9ADCEF	5634 751347	IRINA TARASOVA	{"email": "tarasova-irina-071958@postgrespro.ru", "phone": "+70772188526"}
0005434826852	9ADCEF	4351 493048	NIKOLAY YAKOVLEV	{"email": "n-yakovlev_1977@postgrespro.ru", "phone": "+70019986850"}
0005434826853	9ADCEF	2612 356652	NATALYA LOGINOVA	{"email": "natalyaloginova_1959@postgrespro.ru", "phone": "+70795762896"}
0005434826854	8773F8	0290 503710	VASILIY TIMOFEEV	{"email": "timofeev_v.12121978@postgrespro.ru", "phone": "+70062812302"}
0005434826855	FD9642	0793 272218	MIKHAIL SOROKIN	{"email": "msorokin-071982@postgrespro.ru", "phone": "+70012337688"}
0005434826856	30D888	9370 295132	NAILYA SERGEEVA	{"email": "sergeevanailya041977@postgrespro.ru", "phone": "+70261132590"}
0005434826857	FD36B1	2589 259194	ALEKSANDR FEDOTOV	{"email": "fedotov-aleksandr1968@postgrespro.ru", "phone": "+70179586807"}
0005434826858	FD36B1	8456 339101	VLADISLAV ANDREEV	{"phone": "+70404429107"}
0005434826859	B0B40F	0665 363905	SERGEY CHERNOV	{"email": "sergeychernov02071972@postgrespro.ru", "phone": "+70688329869"}
0005434826860	B0B40F	1777 573905	ALFIYA MIRONOVA	{"email": "alfiya.mironova-1973@postgrespro.ru", "phone": "+70829895680"}
0005434826861	B0B40F	1140 685991	OLGA SMIRNOVA	{"phone": "+70909138443"}
0005434826862	C227C0	7576 433699	LYUDMILA POPOVA	{"email": "popova.lyudmila1964@postgrespro.ru", "phone": "+70440461460"}
0005434826863	8A81E3	8353 369831	VALENTIN IVANOV	{"email": "v.ivanov.06091969@postgrespro.ru", "phone": "+70611805183"}
0005434826864	B4EE88	7131 289996	ANDREY BORISOV	{"email": "a.borisov_061971@postgrespro.ru", "phone": "+70530368942"}
0005434826865	EC25E6	3100 107199	YULIYA EGOROVA	{"phone": "+70331240719"}
0005434826866	46DD83	9340 369792	TIMUR POPOV	{"phone": "+70655864572"}
0005434826867	3A55F4	3386 978640	NINA KONOVALOVA	{"email": "konovalovan1982@postgrespro.ru", "phone": "+70427552926"}
0005434826868	3A55F4	4041 885571	EVGENIYA ANISIMOVA	{"email": "anisimovaevgeniya.1978@postgrespro.ru", "phone": "+70896363915"}
0005434826869	D9EC0A	8705 935385	IRINA POTAPOVA	{"phone": "+70590785329"}
0005434826870	D9EC0A	9928 485616	VIKTOR KUDRYASHOV	{"phone": "+70463854752"}
0005434826871	D9EC0A	8093 174045	EKATERINA ZHUKOVA	{"email": "zhukova_e.02111963@postgrespro.ru", "phone": "+70897981274"}
0005434826872	2A2156	6325 815634	OLESYA FILATOVA	{"email": "olesyafilatova-07041979@postgrespro.ru", "phone": "+70816900067"}
0005434826873	2A2156	8234 193296	ILYA RODIONOV	{"phone": "+70862296075"}
0005434826874	A62AB7	3443 472465	VYACHESLAV GRIGOREV	{"phone": "+70357727214"}
0005434826875	B9FACE	7111 113405	EVGENIYA FILATOVA	{"email": "evgeniya_filatova-1979@postgrespro.ru", "phone": "+70218368773"}
0005434826876	B9FACE	4289 531849	GRIGORIY KONOVALOV	{"email": "grigoriy-konovalov_08091965@postgrespro.ru", "phone": "+70848443935"}
0005434826877	F6D695	0669 294248	ELENA ZHURAVLEVA	{"phone": "+70581215374"}
0005434826878	80737D	4229 317920	MIKHAIL TIKHONOV	{"email": "mikhail-tikhonov_24111965@postgrespro.ru", "phone": "+70063911589"}
0005434826879	80737D	7447 675978	KAROLINA EGOROVA	{"phone": "+70444611053"}
0005434826880	A70031	3015 099380	KIRILL VASILEV	{"email": "vasilevk-041965@postgrespro.ru", "phone": "+70751362850"}
0005434826881	88684C	3341 366955	IRINA ABRAMOVA	{"phone": "+70530763642"}
0005434826882	35DDC0	0791 613655	OLGA IVANOVA	{"phone": "+70941779145"}
0005434826883	A08A26	9925 165598	LARISA OSIPOVA	{"email": "osipova.l041975@postgrespro.ru", "phone": "+70659209927"}
0005434826884	566189	9941 892487	RAISA MAKAROVA	{"phone": "+70699948959"}
0005434826885	349A3D	4317 127315	SERGEY KOZLOV	{"email": "sergey_kozlov.1961@postgrespro.ru", "phone": "+70202885132"}
0005434826886	349A3D	9872 564760	LYUDMILA ORLOVA	{"phone": "+70564453659"}
0005434826887	7B938A	7401 441028	SVETLANA TIKHONOVA	{"email": "tikhonovas_1974@postgrespro.ru", "phone": "+70461606924"}
0005434826888	7B938A	6967 621986	DMITRIY ROMANOV	{"email": "romanovdmitriy.22101964@postgrespro.ru", "phone": "+70256591457"}
0005434826889	9C1512	4226 709563	ANDREY IVANOV	{"phone": "+70733072379"}
0005434826890	CFD515	6053 465457	KIRILL POPOV	{"email": "k-popov31121969@postgrespro.ru", "phone": "+70847965153"}
0005434826891	A5F455	7290 443998	IGOR IVANOV	{"phone": "+70132930550"}
0005434826892	612CB7	3879 222062	IVAN SCHERBAKOV	{"phone": "+70639411749"}
0005434826893	10CB47	1882 579467	ALEKSANDR ZAYCEV	{"phone": "+70894970191"}
0005434826894	10CB47	9767 224953	ELIZAVETA NIKITINA	{"email": "elizaveta.nikitina.1978@postgrespro.ru", "phone": "+70493086293"}
0005434826895	771082	3961 974030	NINA ABRAMOVA	{"email": "abramova-nina.1973@postgrespro.ru", "phone": "+70097650360"}
0005434826896	2A1ED9	1981 479854	ALEKSEY PETROV	{"phone": "+70502262514"}
0005434826897	8F994D	7590 214486	TATYANA SERGEEVA	{"phone": "+70190567922"}
0005434826898	16E149	1550 121325	EKATERINA VLASOVA	{"phone": "+70954128573"}
0005434826899	16E149	3109 333535	ANASTASIYA FADEEVA	{"phone": "+70139246089"}
0005434826900	5EEA7D	3173 986325	SERGEY KONOVALOV	{"phone": "+70220710020"}
0005434826901	56D6AC	9745 041526	KIRILL SERGEEV	{"email": "sergeev.k_111961@postgrespro.ru", "phone": "+70880901480"}
0005434826902	0EAAC9	5019 971094	ALEKSANDR AFANASEV	{"phone": "+70397234990"}
0005434826903	0EAAC9	2606 555875	FEDOR FOMIN	{"email": "fomin-fedor.071970@postgrespro.ru", "phone": "+70959224096"}
0005434826904	78482B	5344 150218	EVGENIYA CHERNOVA	{"email": "chernova-e_021975@postgrespro.ru", "phone": "+70931825961"}
0005434826905	097E61	0426 472180	ELENA MIRONOVA	{"email": "emironova.19071969@postgrespro.ru", "phone": "+70411917593"}
0005434826906	4BA8ED	4716 004680	ANTON GORBUNOV	{"email": "anton.gorbunov-1969@postgrespro.ru", "phone": "+70470917082"}
0005434826907	C6C662	6340 284453	YURIY BORISOV	{"phone": "+70302909152"}
0005434826908	B93E44	6564 894418	FARIT STEPANOV	{"email": "stepanov.farit-1972@postgrespro.ru", "phone": "+70654910966"}
0005434826909	31A994	0089 813151	VLADIMIR ZAKHAROV	{"phone": "+70122190106"}
0005434826910	3529EC	5891 952252	VYACHESLAV OSIPOV	{"email": "vyacheslavosipov-051986@postgrespro.ru", "phone": "+70390385979"}
0005434826911	3529EC	4573 376458	ANATOLIY MOROZOV	{"phone": "+70542855566"}
0005434826912	3529EC	3678 750181	YULIYA MASLOVA	{"phone": "+70343651571"}
0005434826913	F1BEF8	4777 812786	YURIY ROMANOV	{"phone": "+70310136382"}
0005434826914	C865CE	7710 489004	ALENA DAVYDOVA	{"phone": "+70036988812"}
0005434826915	DFD931	4896 662509	VIKTOR ANDREEV	{"phone": "+70908883186"}
0005434826916	C135BF	4977 875395	IVAN KUZMIN	{"phone": "+70778870388"}
0005434826917	E409D5	7234 106720	INNA ZHURAVLEVA	{"email": "zhuravleva-inna1983@postgrespro.ru", "phone": "+70038547250"}
0005434826918	968AAD	8961 054373	VASILIY SOKOLOV	{"email": "v.sokolov27121975@postgrespro.ru", "phone": "+70360303802"}
0005434826919	968AAD	4351 120945	VALERIYA ABRAMOVA	{"phone": "+70088394707"}
0005434826920	968AAD	3378 862908	VIKTOR SCHERBAKOV	{"email": "scherbakov_viktor-19031978@postgrespro.ru", "phone": "+70374913429"}
0005434826921	ACC12E	8479 132275	DMITRIY ANDREEV	{"email": "andreev_dmitriy_1974@postgrespro.ru", "phone": "+70808518490"}
0005434826922	ACC12E	5583 065309	OLEG KARPOV	{"email": "karpov_oleg1982@postgrespro.ru", "phone": "+70727056827"}
0005434826923	E2693B	2709 035272	YULIYA KAZAKOVA	{"email": "kazakova.yuliya-05051967@postgrespro.ru", "phone": "+70181804263"}
0005434826924	B8CF81	9201 337356	VALENTIN KISELEV	{"email": "kiselev.v121977@postgrespro.ru", "phone": "+70778383711"}
0005434826925	C507B4	2432 581881	ANATOLIY SCHERBAKOV	{"email": "scherbakov.anatoliy-091985@postgrespro.ru", "phone": "+70315851108"}
0005434826926	FF7793	8355 086300	ILYA IVANOV	{"email": "ilya-ivanov.1965@postgrespro.ru", "phone": "+70169724850"}
0005434826927	FF7793	0016 383617	ALFIYA KAZAKOVA	{"email": "a-kazakova01081975@postgrespro.ru", "phone": "+70143596332"}
0005434826928	131D2D	6125 094690	VALENTINA MIKHAYLOVA	{"email": "v.mikhaylova17091979@postgrespro.ru", "phone": "+70259197301"}
0005434826929	131D2D	5741 495182	LYUBOV MARTYNOVA	{"phone": "+70553474798"}
0005434826930	A78AF3	7857 021256	ALEKSANDR TIMOFEEV	{"email": "a_timofeev-011967@postgrespro.ru", "phone": "+70381511424"}
0005434826931	82D961	3151 884136	DENIS ABRAMOV	{"email": "abramovdenis06041994@postgrespro.ru", "phone": "+70691785511"}
0005434826932	82D961	6337 981036	NATALYA DAVYDOVA	{"email": "davydovanatalya_081975@postgrespro.ru", "phone": "+70191572584"}
0005434826933	A94B45	4873 840022	TATYANA SOKOLOVA	{"email": "sokolova.tatyana-091974@postgrespro.ru", "phone": "+70312705811"}
0005434826934	E51FC5	6094 884236	EKATERINA MELNIKOVA	{"phone": "+70196650335"}
0005434826935	E51FC5	9281 362150	ILDAR IVANOV	{"email": "ivanovi.101971@postgrespro.ru", "phone": "+70751832260"}
0005434826936	407A85	2116 871043	DMITRIY GUSEV	{"phone": "+70659332591"}
0005434826937	B48E4A	2352 407875	YULIYA KUZNECOVA	{"phone": "+70565447750"}
0005434826938	2DDEF2	3784 611924	KIRILL ZAYCEV	{"email": "k-zaycev-1968@postgrespro.ru", "phone": "+70273346573"}
0005434826939	E77811	7952 333327	GALINA MATVEEVA	{"email": "matveevag28061963@postgrespro.ru", "phone": "+70387045442"}
0005434826940	E77811	5899 556526	VALERIY IVANOV	{"email": "ivanov.v.06071974@postgrespro.ru", "phone": "+70247487087"}
0005434826941	E77811	0435 952677	MIKHAIL FILIPPOV	{"phone": "+70158202015"}
0005434826942	4D2F85	9286 410812	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr1972@postgrespro.ru", "phone": "+70498261423"}
0005434826943	4D2F85	8866 077125	MARINA KUZNECOVA	{"email": "marina-kuznecova-051975@postgrespro.ru", "phone": "+70923706293"}
0005434826944	8A1ED0	7351 580641	ALEKSEY VOROBEV	{"phone": "+70366333400"}
0005434826945	8A1ED0	2962 782237	VALENTINA YAKOVLEVA	{"phone": "+70677411383"}
0005434826946	113C95	6993 879813	EGOR MAKSIMOV	{"phone": "+70587854149"}
0005434826947	C7DCAD	4890 026963	DMITRIY KUDRYASHOV	{"email": "dkudryashov_15071969@postgrespro.ru", "phone": "+70530791945"}
0005434826948	864E7B	6100 486535	ALEKSANDRA MIRONOVA	{"phone": "+70190444369"}
0005434826949	864E7B	4864 049268	NIKOLAY KISELEV	{"email": "n_kiselev-1961@postgrespro.ru", "phone": "+70096382277"}
0005434826950	C2E19F	2572 074373	EVGENIYA MOISEEVA	{"email": "e.moiseeva-29111966@postgrespro.ru", "phone": "+70007398879"}
0005434826951	46CCE2	1315 907249	RIMMA MIKHAYLOVA	{"email": "mikhaylova_rimma.1973@postgrespro.ru", "phone": "+70323010496"}
0005434826952	00C68E	5445 016896	ALEKSANDR EGOROV	{"email": "a.egorov27041979@postgrespro.ru", "phone": "+70759536562"}
0005434826953	D01993	3541 063215	EKATERINA ILINA	{"phone": "+70446310339"}
0005434826954	D01993	2560 413571	LYUDMILA GERASIMOVA	{"email": "gerasimova-l_17061969@postgrespro.ru", "phone": "+70612276394"}
0005434826955	61AD36	1869 459405	OLGA MOROZOVA	{"phone": "+70823027587"}
0005434826956	61AD36	8955 307117	OLEG GUSEV	{"phone": "+70076453036"}
0005434826957	C37AAA	0487 201313	ALEKSANDRA MEDVEDEVA	{"email": "medvedevaa1986@postgrespro.ru", "phone": "+70321274362"}
0005434826958	D040C4	3375 278317	ZINAIDA KUDRYASHOVA	{"phone": "+70744170935"}
0005434826959	3DD6CE	9519 416388	ANNA STEPANOVA	{"email": "stepanovaanna1970@postgrespro.ru", "phone": "+70308212051"}
0005434826960	9F18BF	3269 751455	BORIS STEPANOV	{"phone": "+70650776097"}
0005434826961	9F18BF	1361 824189	VLADIMIR KOZLOV	{"email": "vkozlov-011968@postgrespro.ru", "phone": "+70424162857"}
0005434826962	0AA62C	0101 727996	ANTONINA PETROVA	{"phone": "+70070915040"}
0005434826963	CBF082	3169 781099	OLEG SIDOROV	{"email": "o_sidorov-1967@postgrespro.ru", "phone": "+70009939292"}
0005434826964	C1FEE5	3030 733782	ELENA RODIONOVA	{"email": "elena_rodionova-011969@postgrespro.ru", "phone": "+70461962767"}
0005434826965	3A7403	6396 427912	VLADIMIR STEPANOV	{"phone": "+70117652375"}
0005434826966	B381BB	2339 652987	VERA EGOROVA	{"phone": "+70186600894"}
0005434826967	B381BB	6577 695195	VLADIMIR VASILEV	{"email": "vasilev_v.101967@postgrespro.ru", "phone": "+70180018020"}
0005434826968	8D6C67	4902 492400	OLGA ABRAMOVA	{"email": "o-abramova-21081965@postgrespro.ru", "phone": "+70028801295"}
0005434826969	8D6C67	8182 944933	KSENIYA NIKOLAEVA	{"email": "k.nikolaeva_19091972@postgrespro.ru", "phone": "+70283632745"}
0005434826970	8D6C67	9653 408538	EKATERINA SERGEEVA	{"email": "e.sergeeva.23021953@postgrespro.ru", "phone": "+70736521412"}
0005434826971	8D6C67	2232 549579	NADEZHDA NESTEROVA	{"email": "n-nesterova-1971@postgrespro.ru", "phone": "+70404889734"}
0005434826972	5D1275	3149 093773	SVETLANA STEPANOVA	{"email": "stepanova.s_021975@postgrespro.ru", "phone": "+70124223469"}
0005434826973	12E434	6771 908874	NIKITA FOMIN	{"email": "fomin-nikita031969@postgrespro.ru", "phone": "+70686138451"}
0005434826974	C12E30	9685 463071	NADEZHDA DENISOVA	{"phone": "+70145635050"}
0005434826975	957DC6	7106 920509	LYUBOV KUZNECOVA	{"email": "kuznecova_l.08101969@postgrespro.ru", "phone": "+70411085829"}
0005434826976	957DC6	0257 021392	VALENTINA KOLESNIKOVA	{"phone": "+70536952167"}
0005434826977	50EE46	8951 614571	EVGENIY FROLOV	{"phone": "+70353400593"}
0005434826978	1B47A7	5535 057148	ANDREY KUZNECOV	{"phone": "+70124576282"}
0005434826979	1B47A7	8599 710549	ALEKSANDR VASILEV	{"phone": "+70589821026"}
0005434826980	15FB9B	3700 140875	IRINA SMIRNOVA	{"email": "smirnova.irina-11081961@postgrespro.ru", "phone": "+70435571847"}
0005434826981	F0BA84	2690 175457	NINA IVANOVA	{"email": "n_ivanova_14111970@postgrespro.ru", "phone": "+70292441584"}
0005434826982	5B6FD8	3626 585726	TATYANA TIKHONOVA	{"phone": "+70623930253"}
0005434826983	5D714F	7071 871191	ANDREY BELOV	{"email": "belov_a1968@postgrespro.ru", "phone": "+70608792827"}
0005434826984	DBDE20	6941 025364	VLADIMIR FILIPPOV	{"email": "vladimir_filippov.051968@postgrespro.ru", "phone": "+70431624390"}
0005434826985	DBDE20	9338 751410	VALENTIN IVANOV	{"email": "ivanov-v-06021976@postgrespro.ru", "phone": "+70472008699"}
0005434826986	C501E1	7776 795160	DMITRIY FROLOV	{"phone": "+70765038786"}
0005434826987	C73AD4	6048 173340	VALERIYA MIRONOVA	{"phone": "+70187816453"}
0005434826988	C73AD4	4631 578588	OLGA IVANOVA	{"phone": "+70905195313"}
0005434826989	CBE0A4	1279 486112	EKATERINA NOVIKOVA	{"email": "e-novikova_091969@postgrespro.ru", "phone": "+70702593876"}
0005434826990	524754	0636 603491	NATALYA GRISHINA	{"email": "grishina-n.011963@postgrespro.ru", "phone": "+70087946333"}
0005434826991	5BEBBB	0147 455831	ALEKSANDR MATVEEV	{"email": "aleksandrmatveev16061970@postgrespro.ru", "phone": "+70921056727"}
0005434826992	5BEBBB	6734 936685	ZLATA KOMAROVA	{"phone": "+70130402791"}
0005434826993	FFFC8A	4454 334593	YULIYA ILINA	{"phone": "+70159556828"}
0005434826994	340FA6	5188 466204	LYUDMILA SEMENOVA	{"email": "lyudmilasemenova-1963@postgrespro.ru", "phone": "+70496978938"}
0005434826995	340FA6	3903 679821	SERGEY MARTYNOV	{"phone": "+70221789215"}
0005434826996	D555BA	2261 831413	VITALIY SMIRNOV	{"email": "v-smirnov-061957@postgrespro.ru", "phone": "+70025649224"}
0005434826997	D555BA	1522 755049	GENNADIY KRASNOV	{"phone": "+70739921794"}
0005434826998	14197A	7191 702240	NIKOLAY SOKOLOV	{"email": "sokolovnikolay_1965@postgrespro.ru", "phone": "+70023429582"}
0005434826999	F69B73	6421 760887	NIKITA FROLOV	{"phone": "+70075833683"}
0005434827000	2AF4DD	0991 891662	ILMIRA KRASNOVA	{"email": "ikrasnova_061976@postgrespro.ru", "phone": "+70409114495"}
0005434827001	AB9FCD	7618 744705	ANASTASIYA SIDOROVA	{"phone": "+70111998328"}
0005434827002	0360E5	4307 793691	POLINA ABRAMOVA	{"email": "p-abramova_1969@postgrespro.ru", "phone": "+70539328214"}
0005434827003	0360E5	4203 765154	MARIYA IVANOVA	{"email": "ivanovam.18061975@postgrespro.ru", "phone": "+70218313675"}
0005434827004	CE9B3E	2706 891557	ANASTASIYA OSIPOVA	{"email": "a_osipova.031984@postgrespro.ru", "phone": "+70948397466"}
0005434827005	A7675B	2481 613496	VASILIY ZAKHAROV	{"email": "v_zakharov011970@postgrespro.ru", "phone": "+70663913079"}
0005434827006	488365	0602 248651	DMITRIY MIKHAYLOV	{"email": "mikhaylovd-1972@postgrespro.ru", "phone": "+70503278679"}
0005434827007	52E39E	9761 132407	VLADIMIR MIRONOV	{"phone": "+70120482157"}
0005434827008	52E39E	2156 743775	IRINA MAKAROVA	{"email": "irina-makarova-011962@postgrespro.ru", "phone": "+70134466267"}
0005434827009	F7770A	5542 395149	ELMIRA SMIRNOVA	{"phone": "+70037704289"}
0005434827010	E7885D	3087 956851	NADEZHDA SERGEEVA	{"email": "sergeeva.nadezhda18091967@postgrespro.ru", "phone": "+70068965563"}
0005434827011	E7885D	8368 813250	OLEG EGOROV	{"email": "egorovoleg-1982@postgrespro.ru", "phone": "+70056762707"}
0005434827012	4D2C43	5455 322136	KLAVDIYA SOROKINA	{"phone": "+70294343966"}
0005434827013	1E57A0	6291 874334	SVETLANA POTAPOVA	{"email": "potapova_svetlana-111977@postgrespro.ru", "phone": "+70255576758"}
0005434827014	B8A5C2	8904 479851	YULIYA KISELEVA	{"email": "kiseleva.yuliya_011974@postgrespro.ru", "phone": "+70088595553"}
0005434827015	B8A5C2	0025 934330	GALINA MAKSIMOVA	{"phone": "+70308815341"}
0005434827016	E52D26	4908 550121	YURIY FEDOROV	{"email": "y.fedorov_1973@postgrespro.ru", "phone": "+70437499126"}
0005434827017	BD5BDD	3412 769626	ANNA MAKSIMOVA	{"phone": "+70412745140"}
0005434827018	BD5BDD	6887 490146	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin_011980@postgrespro.ru", "phone": "+70745841073"}
0005434827019	350407	2299 852010	ALEKSEY MOROZOV	{"phone": "+70402112918"}
0005434827020	D24BCE	5647 664239	NINA TROFIMOVA	{"phone": "+70788680055"}
0005434827021	D24BCE	6138 684587	TATYANA MAKAROVA	{"phone": "+70106161554"}
0005434827022	D24BCE	1963 697770	EVGENIY IVANOV	{"phone": "+70469619777"}
0005434827023	13E29B	5384 576065	VIKTORIYA STEPANOVA	{"email": "stepanovav1980@postgrespro.ru", "phone": "+70019909721"}
0005434827024	13E29B	7926 839325	LYUDMILA DENISOVA	{"phone": "+70081550176"}
0005434827025	13E29B	2071 491608	ALEKSANDR KUDRYASHOV	{"phone": "+70487917336"}
0005434827026	5BC86B	5307 698928	IRINA VOLKOVA	{"phone": "+70917070094"}
0005434827027	3F2076	0213 095410	ELENA NESTEROVA	{"email": "nesterova-elena-121971@postgrespro.ru", "phone": "+70387250083"}
0005434827028	AB519C	8342 323639	VASILIY ANTONOV	{"phone": "+70242603890"}
0005434827029	AB519C	0365 508697	KIRILL KUZNECOV	{"email": "kuznecovkirill_1970@postgrespro.ru", "phone": "+70275266354"}
0005434827030	AB519C	4425 748715	ANTON POPOV	{"email": "a-popov14081974@postgrespro.ru", "phone": "+70004317937"}
0005434827031	7F1F9B	9656 529275	YURIY DENISOV	{"email": "ydenisov.1961@postgrespro.ru", "phone": "+70497589321"}
0005434827032	7F1F9B	8905 900690	ALEKSANDR BELOV	{"email": "a-belov041983@postgrespro.ru", "phone": "+70459184208"}
0005434827033	7F1F9B	6617 162746	EVGENIY POPOV	{"email": "evgeniy.popov-1972@postgrespro.ru", "phone": "+70190255661"}
0005434827034	3EBE4B	0770 840734	OLGA GRISHINA	{"phone": "+70953049218"}
0005434827035	86497A	4048 181542	ANATOLIY IVANOV	{"phone": "+70423821619"}
0005434827036	53A5AF	1287 798148	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev.25121969@postgrespro.ru", "phone": "+70498986768"}
0005434827037	53A5AF	6231 023561	MIKHAIL AFANASEV	{"email": "afanasevmikhail_20061971@postgrespro.ru", "phone": "+70034129967"}
0005434827038	53A5AF	3916 243152	MARIYA MALYSHEVA	{"phone": "+70155954416"}
0005434827039	FA4DBD	8648 923942	TATYANA KAZAKOVA	{"email": "tatyana_kazakova.011977@postgrespro.ru", "phone": "+70705817471"}
0005434827040	9C4F19	4670 689892	NATALYA NAZAROVA	{"email": "n.nazarova_06121964@postgrespro.ru", "phone": "+70335143859"}
0005434827041	9C4F19	6897 549887	NATALYA ZOTOVA	{"email": "nzotova_22051966@postgrespro.ru", "phone": "+70684846667"}
0005434827042	FFF58D	3515 070423	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana21091970@postgrespro.ru", "phone": "+70603141863"}
0005434827043	F4662D	9956 460995	NIKITA SIDOROV	{"email": "sidorov_nikita.1962@postgrespro.ru", "phone": "+70778871365"}
0005434827044	F4662D	1627 943996	PAVEL VASILEV	{"phone": "+70598846880"}
0005434827045	57FABA	1534 840860	LEONID KUZNECOV	{"email": "kuznecov.leonid24121971@postgrespro.ru", "phone": "+70327523567"}
0005434827046	57FABA	2305 317379	YURIY KUZNECOV	{"phone": "+70462384832"}
0005434827047	43B4D8	7187 613705	ROMAN FROLOV	{"email": "frolovr19121964@postgrespro.ru", "phone": "+70667869002"}
0005434827048	43B4D8	2189 976976	FAINA MOROZOVA	{"phone": "+70026358081"}
0005434827049	BE4903	3930 549169	TAMARA AFANASEVA	{"phone": "+70900632033"}
0005434827050	E815F2	9075 186705	MARIYA POTAPOVA	{"email": "potapova.m_29101972@postgrespro.ru", "phone": "+70204001394"}
0005434827051	272DF8	0069 950298	ALEKSANDR RODIONOV	{"phone": "+70882203958"}
0005434827052	D15F08	3972 590186	VLADIMIR VOROBEV	{"email": "vladimirvorobev-091962@postgrespro.ru", "phone": "+70375929419"}
0005434827053	652C11	6217 646718	ALEKSANDR KUZNECOV	{"email": "a-kuznecov-07041975@postgrespro.ru", "phone": "+70046744039"}
0005434827054	F25C3A	6504 325191	DAMIR SCHERBAKOV	{"phone": "+70924195792"}
0005434827055	F25C3A	6764 553308	NATALYA ROMANOVA	{"phone": "+70616981832"}
0005434827056	999ED1	6353 410775	ELENA PETROVA	{"phone": "+70927154315"}
0005434827057	999ED1	4400 191565	YURIY FOMIN	{"email": "fomin_y_1972@postgrespro.ru", "phone": "+70408901483"}
0005434827058	7C8446	3200 366170	ANNA NIKITINA	{"phone": "+70952480046"}
0005434827059	7FFD74	8392 708305	VITALIY SOKOLOV	{"phone": "+70118609819"}
0005434827060	33242E	1278 825501	NATALYA YAKOVLEVA	{"email": "yakovlevan-1973@postgrespro.ru", "phone": "+70180612043"}
0005434827061	D4E549	3885 128049	OLGA GRISHINA	{"email": "grishinao-1970@postgrespro.ru", "phone": "+70633534540"}
0005434827062	E6CD52	6630 106356	MARIYA SOKOLOVA	{"phone": "+70977751759"}
0005434827063	E6CD52	5280 440332	ANNA ALEKSEEVA	{"phone": "+70269886853"}
0005434827064	E95377	1749 809346	VERONIKA MOISEEVA	{"email": "moiseeva_veronika-05021968@postgrespro.ru", "phone": "+70633267420"}
0005434827065	AA69E9	8414 340715	STEPAN KRASNOV	{"email": "krasnov_s-1975@postgrespro.ru", "phone": "+70725113452"}
0005434827066	EEEDC0	2438 867563	VIKTOR DENISOV	{"email": "viktordenisov.011978@postgrespro.ru", "phone": "+70966784430"}
0005434827067	5C0EB7	0429 996372	VLADIMIR ZAYCEV	{"email": "vladimir-zaycev-12111973@postgrespro.ru", "phone": "+70155160939"}
0005434827068	5C0EB7	5127 946824	ELENA EGOROVA	{"phone": "+70708791726"}
0005434827069	98BFCC	7802 050991	OLGA GERASIMOVA	{"phone": "+70209083537"}
0005434827070	0DC66F	0287 794793	LYUBOV BARANOVA	{"phone": "+70061736284"}
0005434827071	0DC66F	8747 886681	VLADIMIR IVANOV	{"phone": "+70374664634"}
0005434827072	1B8C24	9854 784247	ALEKSANDR ALEKSANDROV	{"phone": "+70001415409"}
0005434827073	3CDAA3	6245 629540	ELENA ILINA	{"phone": "+70609633595"}
0005434827074	3F62D5	3543 706281	VALERIY PETROV	{"phone": "+70837466231"}
0005434827075	A16878	4105 941444	YURIY ABRAMOV	{"email": "abramov_yuriy011962@postgrespro.ru", "phone": "+70954705623"}
0005434827076	A16878	3562 074800	NADEZHDA ZHURAVLEVA	{"email": "n_zhuravleva.041976@postgrespro.ru", "phone": "+70232594936"}
0005434827077	5796C4	3031 620026	ALEKSANDR ZAKHAROV	{"phone": "+70208471832"}
0005434827078	6A2EA0	8270 409767	ELENA KARPOVA	{"email": "elena_karpova_19101982@postgrespro.ru", "phone": "+70927106898"}
0005434827079	75BA2F	3108 456513	OKSANA KAZAKOVA	{"email": "o-kazakova.1969@postgrespro.ru", "phone": "+70621827447"}
0005434827080	75BA2F	6973 074290	NINA VLASOVA	{"phone": "+70932871414"}
0005434827081	DC3744	9070 678417	ARTUR SOROKIN	{"phone": "+70426990459"}
0005434827082	DC3744	5185 528536	GALINA ANDREEVA	{"email": "galina.andreeva-1975@postgrespro.ru", "phone": "+70517956734"}
0005434827083	B6703A	5451 618446	DANILA KARPOV	{"phone": "+70854316467"}
0005434827084	5F117D	0197 265566	TATYANA KUZMINA	{"phone": "+70142785130"}
0005434827085	AF8FE4	1961 298308	NINA KUDRYASHOVA	{"phone": "+70075549741"}
0005434827086	4C7F6A	1616 812357	PAVEL IVANOV	{"phone": "+70863241145"}
0005434827087	DFC791	7188 137067	LYUDMILA EFREMOVA	{"phone": "+70833505666"}
0005434827088	DFC791	6628 843068	ALEKSEY MELNIKOV	{"email": "melnikova.1972@postgrespro.ru", "phone": "+70036713229"}
0005434827089	4222CE	5133 221805	TAMARA GORBUNOVA	{"phone": "+70165876058"}
0005434827090	31B69F	4692 903171	ARTEM SAVELEV	{"email": "artem_savelev-121974@postgrespro.ru", "phone": "+70164122145"}
0005434827091	9F52D4	3636 667956	ALEKSANDR GERASIMOV	{"email": "gerasimov-a_101979@postgrespro.ru", "phone": "+70083145206"}
0005434827092	9F52D4	2510 338896	TATYANA GAVRILOVA	{"phone": "+70401399116"}
0005434827093	7DDCB4	5559 695794	ALINA STEPANOVA	{"email": "stepanova.a-011969@postgrespro.ru", "phone": "+70499322016"}
0005434827094	CFEE9C	7368 773814	KIRILL FILIPPOV	{"email": "filippov.kirill031973@postgrespro.ru", "phone": "+70634531872"}
0005434827095	5DD305	7912 269657	MARIYA AKIMOVA	{"email": "akimova-mariya16091969@postgrespro.ru", "phone": "+70251559222"}
0005434827096	59E941	4379 538516	YULIYA KOROLEVA	{"email": "yuliya.koroleva.031981@postgrespro.ru", "phone": "+70810827946"}
0005434827097	D6C2EC	9726 528897	MARINA FILATOVA	{"email": "marina-filatova-15041966@postgrespro.ru", "phone": "+70573551197"}
0005434827098	06F102	6422 700213	VYACHESLAV SERGEEV	{"phone": "+70261095887"}
0005434827099	06F102	8986 736212	OLGA CHERNOVA	{"email": "chernova-o08011965@postgrespro.ru", "phone": "+70420246569"}
0005434827100	F84800	1927 457220	DANIIL PETROV	{"phone": "+70890021452"}
0005434827101	F84800	2303 865230	ALEKSANDR DAVYDOV	{"email": "adavydov061977@postgrespro.ru", "phone": "+70293256327"}
0005434827102	B3C39A	7448 956264	NIKOLAY RODIONOV	{"email": "n-rodionov081978@postgrespro.ru", "phone": "+70234754171"}
0005434827103	B3C39A	4125 019487	NATALYA FADEEVA	{"email": "n-fadeeva.30091965@postgrespro.ru", "phone": "+70781059847"}
0005434827104	FB15CE	4933 159033	VERA BELOVA	{"email": "v_belova_081980@postgrespro.ru", "phone": "+70580498005"}
0005434827105	FB15CE	8780 468797	VALENTINA PAVLOVA	{"phone": "+70491612598"}
0005434827106	9EC715	0214 545216	BOGDAN VOLKOV	{"phone": "+70432349673"}
0005434827107	9EC715	0244 806106	RUSTAM GORBUNOV	{"phone": "+70283991855"}
0005434827108	58CCAB	3778 863804	TATYANA LEBEDEVA	{"email": "lebedevatatyana_1972@postgrespro.ru", "phone": "+70984965238"}
0005434827109	58CCAB	6969 923856	NATALYA KAZAKOVA	{"email": "n.kazakova_05041965@postgrespro.ru", "phone": "+70520820978"}
0005434827110	52DFC3	2696 974756	VIKTORIYA MELNIKOVA	{"phone": "+70951746914"}
0005434827111	52DFC3	1393 624173	VERONIKA MATVEEVA	{"phone": "+70157492794"}
0005434827112	8B610D	0543 448244	DENIS KARPOV	{"phone": "+70737555156"}
0005434827113	0F34FE	5451 748846	DENIS DAVYDOV	{"email": "denisdavydov_1971@postgrespro.ru", "phone": "+70472164046"}
0005434827114	A0DAED	0503 706136	NIKOLAY POPOV	{"phone": "+70072252443"}
0005434827115	A0DAED	0498 873552	KSENIYA MAKAROVA	{"email": "makarova.k.03121983@postgrespro.ru", "phone": "+70953407400"}
0005434827116	648082	2579 121492	VITALIY IVANOV	{"phone": "+70587541742"}
0005434827117	6F508A	3464 360076	NIKITA POPOV	{"phone": "+70123328461"}
0005434827118	0D79A2	5460 264811	PAVEL SAVELEV	{"phone": "+70447052685"}
0005434827119	0D79A2	2489 763707	MIKHAIL SOKOLOV	{"email": "mikhail.sokolov-071965@postgrespro.ru", "phone": "+70500418237"}
0005434827120	E82C9F	1287 827101	GALINA NIKOLAEVA	{"phone": "+70978507924"}
0005434827121	8591CE	8126 036981	SERGEY ALEKSEEV	{"email": "alekseev.sergey.1971@postgrespro.ru", "phone": "+70515156352"}
0005434827122	8591CE	4217 809621	MAKSIM PAVLOV	{"email": "maksim-pavlov051977@postgrespro.ru", "phone": "+70008283024"}
0005434827123	42423A	7980 612805	NINA ANDREEVA	{"email": "andreeva.n.041977@postgrespro.ru", "phone": "+70642626256"}
0005434827124	42423A	6562 503628	LYUDMILA KUZMINA	{"phone": "+70878342774"}
0005434827125	42423A	1244 051054	PELAGEYA PAVLOVA	{"phone": "+70256894240"}
0005434827126	47D383	9161 056531	SERGEY SOLOVEV	{"email": "solovev-s_1966@postgrespro.ru", "phone": "+70721773748"}
0005434827127	E5091D	5801 018758	FLYURA AFANASEVA	{"phone": "+70328730376"}
0005434827128	E5091D	9785 025560	ANNA ARKHIPOVA	{"phone": "+70966907761"}
0005434827129	4113F2	5732 847539	MAKSIM IVANOV	{"phone": "+70484533107"}
0005434827130	0933AD	4797 934318	VALENTINA FILIPPOVA	{"phone": "+70933157105"}
0005434827131	916A39	0417 606442	VIOLETTA TITOVA	{"phone": "+70830107613"}
0005434827132	16839A	7032 008509	ARTEM VASILEV	{"phone": "+70958177515"}
0005434827133	703D4B	9434 224407	VYACHESLAV NAUMOV	{"phone": "+70277755279"}
0005434827134	703D4B	2373 681404	ALEKSEY GRIGOREV	{"email": "grigorev.a-121964@postgrespro.ru", "phone": "+70635403277"}
0005434827135	8F052A	9216 195656	DIANA ZAKHAROVA	{"email": "d-zakharova02091971@postgrespro.ru", "phone": "+70239161056"}
0005434827136	8E06C5	5081 840813	VALERIYA EGOROVA	{"email": "egorova_v-111982@postgrespro.ru", "phone": "+70693559422"}
0005434827137	C74F43	0804 950372	IGOR PETROV	{"email": "igor_petrov-1963@postgrespro.ru", "phone": "+70732351399"}
0005434827138	DD4848	6176 023442	DMITRIY KONOVALOV	{"phone": "+70513318225"}
0005434827139	E8F09D	7712 099187	ALEKSANDR BONDARENKO	{"email": "abondarenko.29111979@postgrespro.ru", "phone": "+70274432609"}
0005434827140	E0D157	6845 915926	ILYA ALEKSEEV	{"phone": "+70226818833"}
0005434827141	E0D157	9316 359861	ANDREY BELOV	{"email": "andrey-belov_11121979@postgrespro.ru", "phone": "+70829199094"}
0005434827142	E0D157	4465 047021	LYUBOV RODIONOVA	{"email": "lyubov_rodionova_1969@postgrespro.ru", "phone": "+70500873735"}
0005434827143	3F78A2	2835 060746	VALERIYA POPOVA	{"email": "popova.valeriya_081970@postgrespro.ru", "phone": "+70160481642"}
0005434827144	3F78A2	1705 993305	SERGEY ZHURAVLEV	{"phone": "+70672883823"}
0005434827145	3F78A2	0023 888159	ANDREY PETROV	{"email": "andreypetrov_22021971@postgrespro.ru", "phone": "+70968216070"}
0005434827146	0B902C	3877 240940	VALERIY KISELEV	{"phone": "+70246726181"}
0005434827147	D50655	3530 806943	SERGEY KAZAKOV	{"email": "kazakov.s.19121982@postgrespro.ru", "phone": "+70916912145"}
0005434827148	D50655	1974 365607	RUSLAN RODIONOV	{"email": "rrodionov28041968@postgrespro.ru", "phone": "+70796572857"}
0005434827149	246DB7	6529 022821	VALENTINA KUZNECOVA	{"phone": "+70666766680"}
0005434827150	04E2BE	6084 351662	PELAGEYA IVANOVA	{"phone": "+70532116042"}
0005434827151	04E2BE	1270 739442	ALEKSANDR SIDOROV	{"phone": "+70023244478"}
0005434827152	586BE4	9929 461170	KSENIYA IVANOVA	{"email": "kseniya-ivanova-1963@postgrespro.ru", "phone": "+70978338028"}
0005434827153	586BE4	6303 470081	VLADIMIR VOLKOV	{"phone": "+70957291518"}
0005434827154	0F9513	4815 848850	LEV MAKSIMOV	{"email": "maksimov-lev_10031964@postgrespro.ru", "phone": "+70873377944"}
0005434827155	0F9513	8481 390073	PETR RODIONOV	{"phone": "+70669643120"}
0005434827156	31BE45	0570 566234	MARINA IVANOVA	{"email": "m-ivanova_1977@postgrespro.ru", "phone": "+70988256494"}
0005434827157	0C982E	3151 057725	VERA FEDOROVA	{"email": "fedorova.vera.1964@postgrespro.ru", "phone": "+70399921881"}
0005434827158	0C982E	0007 169997	NADEZHDA NESTEROVA	{"phone": "+70114117913"}
0005434827159	ED2220	8716 152892	SVETLANA ZAYCEVA	{"phone": "+70528524827"}
0005434827160	71FE53	1520 151286	ZARINA MAKAROVA	{"phone": "+70031250916"}
0005434827161	71FE53	0346 099702	TATYANA BOGDANOVA	{"phone": "+70579722588"}
0005434827162	C4DE19	1412 213823	IRINA IVANOVA	{"phone": "+70965493101"}
0005434827163	EE0502	7060 708926	EKATERINA SIDOROVA	{"phone": "+70556473192"}
0005434827164	EE0502	0686 653144	TATYANA IVANOVA	{"email": "ivanova_t-19121964@postgrespro.ru", "phone": "+70250192736"}
0005434827165	A67ADA	7695 019292	VLADIMIR GUSEV	{"email": "gusev_vladimir_041982@postgrespro.ru", "phone": "+70461831078"}
0005434827166	11801A	8768 155136	DANIYA PAVLOVA	{"email": "daniya.pavlova1979@postgrespro.ru", "phone": "+70082773413"}
0005434827167	11801A	8533 808775	PETR ZAKHAROV	{"phone": "+70079231935"}
0005434827168	2746B2	0046 130191	VERA IVANOVA	{"phone": "+70274165444"}
0005434827169	144981	7911 562977	GENNADIY KUDRYASHOV	{"phone": "+70349082647"}
0005434827170	A04902	5191 390814	SERGEY MIKHAYLOV	{"email": "mikhaylov-sergey27081974@postgrespro.ru", "phone": "+70538928104"}
0005434827171	A04902	6687 846233	ALEKSANDR BORISOV	{"phone": "+70182246769"}
0005434827172	08FB7F	2001 382923	NINA SMIRNOVA	{"email": "nina-smirnova1967@postgrespro.ru", "phone": "+70673869120"}
0005434827173	08FB7F	9648 234444	VALENTINA KRASNOVA	{"email": "krasnova-valentina-07061981@postgrespro.ru", "phone": "+70546898414"}
0005434827174	77DD29	8138 421745	GALINA GORBUNOVA	{"phone": "+70223191921"}
0005434827175	E11767	6664 140789	ALEKSANDR POPOV	{"phone": "+70702145453"}
0005434827176	E11767	0277 689654	ALEKSANDR ANDREEV	{"phone": "+70428460699"}
0005434827177	8CC6D3	2526 014503	YANA ZHURAVLEVA	{"email": "zhuravleva-yana_071964@postgrespro.ru", "phone": "+70798015113"}
0005434827178	8B12C8	2947 233798	MARINA GERASIMOVA	{"phone": "+70503345922"}
0005434827179	CBAFCD	6751 973371	TAMARA SCHERBAKOVA	{"phone": "+70590614544"}
0005434827180	CBAFCD	3167 762897	OLEG NIKOLAEV	{"email": "nikolaev_o_091966@postgrespro.ru", "phone": "+70815871156"}
0005434827181	CBAFCD	9096 759990	NATALYA ZHURAVLEVA	{"email": "natalya_zhuravleva_1971@postgrespro.ru", "phone": "+70788470702"}
0005434827182	C0B796	0707 156189	LARISA KAZAKOVA	{"email": "kazakova.l-091972@postgrespro.ru", "phone": "+70082166924"}
0005434827183	35C11F	5361 664700	DMITRIY KOZLOV	{"email": "dmitriykozlov071970@postgrespro.ru", "phone": "+70655432628"}
0005434827184	8ED1DA	4778 581145	KSENIYA ALEKSANDROVA	{"email": "aleksandrova-k07101969@postgrespro.ru", "phone": "+70512661804"}
0005434827185	FCA40C	1741 742645	NATALYA FEDOROVA	{"email": "fedorova.n_31081965@postgrespro.ru", "phone": "+70204326860"}
0005434827186	DEE1C9	1787 955842	NATALYA PETROVA	{"phone": "+70473271756"}
0005434827187	131A37	7303 418968	EVGENIY ANDREEV	{"email": "e-andreev14081962@postgrespro.ru", "phone": "+70985094029"}
0005434827188	F77199	6850 583343	LYUDMILA KUZNECOVA	{"phone": "+70362718078"}
0005434827189	F77199	1519 871841	NATALYA TITOVA	{"email": "natalya.titova_011979@postgrespro.ru", "phone": "+70323774505"}
0005434827190	021D54	3997 156865	EVGENIY PAVLOV	{"email": "pavlovevgeniy081980@postgrespro.ru", "phone": "+70062199938"}
0005434827249	653D6D	4209 166974	DMITRIY SOKOLOV	{"phone": "+70133215377"}
0005434827191	021D54	1306 908378	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr23101980@postgrespro.ru", "phone": "+70623221115"}
0005434827192	021D54	6917 210520	VLADIMIR KISELEV	{"email": "kiselev_v_1964@postgrespro.ru", "phone": "+70313692441"}
0005434827193	4137F2	6942 415928	ANDREY ALEKSANDROV	{"email": "aleksandrov-a1973@postgrespro.ru", "phone": "+70320631239"}
0005434827194	D3FADD	7369 962443	GALINA KISELEVA	{"phone": "+70279383024"}
0005434827195	5ED1BD	4573 165056	VALENTINA VASILEVA	{"email": "vasilevavalentina09011989@postgrespro.ru", "phone": "+70082521927"}
0005434827196	5F2038	1096 351197	DARYA DAVYDOVA	{"phone": "+70983118950"}
0005434827197	E07270	4760 951412	ILYA ISAEV	{"phone": "+70823246199"}
0005434827198	E07270	0656 892230	NATALYA MOISEEVA	{"email": "natalya.moiseeva_1974@postgrespro.ru", "phone": "+70893190400"}
0005434827199	58F464	6358 536308	OLGA DENISOVA	{"phone": "+70998670567"}
0005434827200	9727BE	4174 564907	NADEZHDA NOVIKOVA	{"email": "novikova-nadezhda-041977@postgrespro.ru", "phone": "+70357615433"}
0005434827201	572226	1115 409731	YURIY MAKSIMOV	{"phone": "+70868960415"}
0005434827202	C0A1CC	8797 743829	VLADIMIR YAKOVLEV	{"phone": "+70121067277"}
0005434827203	A5E357	2564 113306	VERA PETROVA	{"email": "vera_petrova_09081968@postgrespro.ru", "phone": "+70668455986"}
0005434827204	A5E357	2645 943465	EKATERINA DANILOVA	{"phone": "+70099303380"}
0005434827205	A5E357	9735 322006	ANDREY PAVLOV	{"email": "pavlov.andrey_011972@postgrespro.ru", "phone": "+70292165520"}
0005434827206	A5E357	3425 566535	IGOR RODIONOV	{"email": "rodionov_i.041960@postgrespro.ru", "phone": "+70519380836"}
0005434827207	C652FA	3163 460382	ALEKSANDR RODIONOV	{"phone": "+70482133065"}
0005434827208	C652FA	4265 489082	ILYA BELOV	{"phone": "+70617852762"}
0005434827209	9C5AAB	2342 861978	OLGA CHERNOVA	{"email": "ochernova30061968@postgrespro.ru", "phone": "+70484328068"}
0005434827210	F65197	7940 145071	RAISA DMITRIEVA	{"email": "r.dmitrieva.1966@postgrespro.ru", "phone": "+70620330439"}
0005434827211	A58EDF	5064 059011	ALENA OVCHINNIKOVA	{"email": "a-ovchinnikova-111971@postgrespro.ru", "phone": "+70826411608"}
0005434827212	A58EDF	6772 673235	NADEZHDA MIKHAYLOVA	{"email": "n_mikhaylova.22051971@postgrespro.ru", "phone": "+70870571004"}
0005434827213	1C1A23	8157 392262	YURIY MATVEEV	{"phone": "+70882876612"}
0005434827214	1C1A23	1572 077643	NATALYA KUZMINA	{"email": "natalya_kuzmina031973@postgrespro.ru", "phone": "+70661173676"}
0005434827215	B0270E	3073 975330	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir.11051953@postgrespro.ru", "phone": "+70169777965"}
0005434827216	B0270E	5130 287162	LIDIYA GUSEVA	{"email": "l.guseva.041984@postgrespro.ru", "phone": "+70129821529"}
0005434827217	B0270E	0227 203041	ANTONINA DENISOVA	{"phone": "+70346584275"}
0005434827218	0B1360	0004 765266	TATYANA VASILEVA	{"email": "vasilevatatyana_19121976@postgrespro.ru", "phone": "+70783328662"}
0005434827219	0B1360	1232 058329	ALIYA MAKAROVA	{"phone": "+70692831017"}
0005434827220	095BC4	0597 007904	SVETLANA SOKOLOVA	{"email": "svetlana.sokolova-091977@postgrespro.ru", "phone": "+70540073441"}
0005434827221	095BC4	6442 428003	GENNADIY NIKITIN	{"email": "nikitin.gennadiy091970@postgrespro.ru", "phone": "+70537113804"}
0005434827222	D53057	1413 854075	YURIY VLASOV	{"phone": "+70905247308"}
0005434827223	0AD0D3	2844 198169	EKATERINA SCHERBAKOVA	{"email": "scherbakova-ekaterina_1975@postgrespro.ru", "phone": "+70608700056"}
0005434827224	3DE007	9956 606159	ALEKSANDR ZAYCEV	{"email": "a_zaycev_011983@postgrespro.ru", "phone": "+70478330484"}
0005434827225	333661	1628 131580	TATYANA KUZNECOVA	{"phone": "+70032674483"}
0005434827226	051D15	7097 343080	KRISTINA VOLKOVA	{"phone": "+70810252488"}
0005434827227	051D15	8344 531517	TAMARA PAVLOVA	{"email": "tamara_pavlova101974@postgrespro.ru", "phone": "+70858819477"}
0005434827228	051D15	2852 949685	FARID AFANASEV	{"email": "farid-afanasev-1974@postgrespro.ru", "phone": "+70806962854"}
0005434827229	7655E1	8467 093876	VYACHESLAV KULIKOV	{"email": "vyacheslav_kulikov081958@postgrespro.ru", "phone": "+70481374998"}
0005434827230	7CE093	9114 093434	NAIL IVANOV	{"email": "ivanov_nail.14121964@postgrespro.ru", "phone": "+70253228438"}
0005434827231	5B3D51	3435 488968	ALEKSANDR BORISOV	{"phone": "+70994865539"}
0005434827232	326B50	6651 800618	MIKHAIL TIKHONOV	{"phone": "+70887091603"}
0005434827233	C756D0	7688 001367	ARINA ROMANOVA	{"email": "a_romanova-04091974@postgrespro.ru", "phone": "+70478497384"}
0005434827234	9998B2	6748 796695	KRISTINA DANILOVA	{"email": "danilova_kristina.14111974@postgrespro.ru", "phone": "+70450685609"}
0005434827235	9998B2	8657 185286	YURIY MARTYNOV	{"email": "yuriy.martynov111973@postgrespro.ru", "phone": "+70419610809"}
0005434827236	85A0E0	6885 227716	ELVIRA MAKAROVA	{"phone": "+70267348811"}
0005434827237	59EE10	1313 992632	SVETLANA ZHUKOVA	{"email": "zhukova.s_1972@postgrespro.ru", "phone": "+70806651925"}
0005434827238	C2B61A	1626 646776	ALEKSANDR PETROV	{"email": "petrov.aleksandr-06051979@postgrespro.ru", "phone": "+70918718180"}
0005434827239	5CBC20	9643 717747	VALENTINA GERASIMOVA	{"email": "v-gerasimova.1981@postgrespro.ru", "phone": "+70585733318"}
0005434827240	13E29A	2410 035074	ALEKSANDR MIRONOV	{"phone": "+70878540566"}
0005434827241	13E29A	3969 658554	ANNA SEMENOVA	{"phone": "+70338872178"}
0005434827242	B29331	6203 868016	IRINA KUZNECOVA	{"email": "ikuznecova15091975@postgrespro.ru", "phone": "+70792524894"}
0005434827243	F65DC7	4121 023432	DENIS POPOV	{"email": "d.popov111976@postgrespro.ru", "phone": "+70225218659"}
0005434827244	950B80	8396 128605	ALEKSEY IVANOV	{"email": "ivanov_a-061967@postgrespro.ru", "phone": "+70023461950"}
0005434827245	950B80	3664 607824	ELENA KUZNECOVA	{"phone": "+70081847621"}
0005434827246	93FA2E	4430 127600	ALEKSANDRA AKIMOVA	{"email": "akimova_a_1967@postgrespro.ru", "phone": "+70282891270"}
0005434827247	F551E1	3702 015130	INNA ILINA	{"phone": "+70785559989"}
0005434827248	F551E1	0836 079894	NIKOLAY VOLKOV	{"phone": "+70761656072"}
0005434827250	673B6D	9218 756535	MAKSIM POPOV	{"email": "mpopov.1966@postgrespro.ru", "phone": "+70317279081"}
0005434827251	E2917F	1646 948299	MARIYA KALININA	{"phone": "+70620894712"}
0005434827252	E2917F	3791 583672	PLATON FEDOTOV	{"phone": "+70677671748"}
0005434827253	E85620	7710 094234	GENNADIY PETROV	{"phone": "+70273677402"}
0005434827254	7959F0	6725 787755	LILIYA FROLOVA	{"phone": "+70272861938"}
0005434827255	D25D22	6037 475361	SERGEY MARTYNOV	{"phone": "+70391850005"}
0005434827256	C8EF10	9034 092957	GALINA BELOVA	{"phone": "+70329127120"}
0005434827257	C8EF10	5897 501381	SVETLANA GERASIMOVA	{"phone": "+70829624104"}
0005434827258	D6D60E	2764 717152	OLGA BELYAEVA	{"email": "olga-belyaeva_1983@postgrespro.ru", "phone": "+70112265242"}
0005434827259	1EE5C3	6088 491892	NINA GORBUNOVA	{"phone": "+70389526040"}
0005434827260	1EE5C3	1076 443575	VIKTOR ZAKHAROV	{"email": "viktor-zakharov-12021973@postgrespro.ru", "phone": "+70357097079"}
0005434827261	26D0C9	3898 948717	EKATERINA MASLOVA	{"phone": "+70560394765"}
0005434827262	26D0C9	1486 685242	NADEZHDA EGOROVA	{"phone": "+70083379898"}
0005434827263	C9E92F	7529 310175	ALLA ISAEVA	{"phone": "+70038626952"}
0005434827264	448B4E	9276 356181	SERGEY IVANOV	{"email": "sergeyivanov071971@postgrespro.ru", "phone": "+70862428867"}
0005434827265	448B4E	2896 088572	NIKOLAY KISELEV	{"phone": "+70602131552"}
0005434827266	83DBB6	8455 325060	LIDIYA KRASNOVA	{"email": "krasnova.lidiya-101967@postgrespro.ru", "phone": "+70501171195"}
0005434827267	1394DF	2443 559401	OKSANA ZAYCEVA	{"email": "zayceva-o_051956@postgrespro.ru", "phone": "+70348087691"}
0005434827268	1394DF	7607 823558	YAROSLAV DENISOV	{"phone": "+70859117611"}
0005434827269	67E6E1	0708 648041	EKATERINA ZAKHAROVA	{"phone": "+70066118380"}
0005434827270	57011B	4361 046074	LYUBOV SEMENOVA	{"email": "lyubov.semenova.051995@postgrespro.ru", "phone": "+70117846508"}
0005434827271	4F7068	1427 515448	LARISA FEDOROVA	{"email": "l-fedorova.1975@postgrespro.ru", "phone": "+70675437172"}
0005434827272	F9FC49	3871 004700	VIKTOR NIKITIN	{"email": "viktornikitin-1973@postgrespro.ru", "phone": "+70566146225"}
0005434827273	D9216E	2587 852971	MARIYA KUZMINA	{"email": "mariya-kuzmina021974@postgrespro.ru", "phone": "+70712538386"}
0005434827274	EE87C7	3951 545910	ANDREY KOZLOV	{"phone": "+70151541424"}
0005434827275	EE87C7	1574 932079	ANDREY ROMANOV	{"phone": "+70216586726"}
0005434827276	C7FCA2	1885 151665	KSENIYA MASLOVA	{"email": "maslovakseniya.07051957@postgrespro.ru", "phone": "+70825362299"}
0005434827277	643AAD	8975 603196	DARYA BORISOVA	{"email": "dborisova_1982@postgrespro.ru", "phone": "+70869223430"}
0005434827278	643AAD	7662 192016	VLADIMIR GRIGOREV	{"email": "vladimirgrigorev-031974@postgrespro.ru", "phone": "+70005882356"}
0005434827279	7D7451	3438 148947	ALEKSEY YAKOVLEV	{"email": "yakovlev-aleksey1969@postgrespro.ru", "phone": "+70255938203"}
0005434827280	7D7451	9055 313261	SVETLANA GAVRILOVA	{"email": "svetlana.gavrilova.12071976@postgrespro.ru", "phone": "+70547161957"}
0005434827281	2F4BB0	0585 943120	MIKHAIL YAKOVLEV	{"email": "m-yakovlev.10101963@postgrespro.ru", "phone": "+70922888544"}
0005434827282	F82AC0	9409 618058	SOFYA ANTONOVA	{"phone": "+70047371664"}
0005434827283	F82AC0	4034 102167	VALERIYA FILATOVA	{"phone": "+70372074651"}
0005434827284	CBD1A0	6838 111034	ALEKSANDR IVANOV	{"phone": "+70242171828"}
0005434827285	CBD1A0	9188 956551	LYUDMILA GERASIMOVA	{"phone": "+70124952491"}
0005434827286	D595AE	8391 263758	NIKOLAY POPOV	{"email": "nikolay-popov-051973@postgrespro.ru", "phone": "+70376983735"}
0005434827287	ED4E22	0046 441707	SVETLANA VASILEVA	{"phone": "+70940143891"}
0005434827288	6B3180	3945 611567	INNA FROLOVA	{"email": "i.frolova_071969@postgrespro.ru", "phone": "+70706241179"}
0005434827289	419218	4215 306479	GENNADIY MELNIKOV	{"phone": "+70290926354"}
0005434827290	419218	3332 001608	VASILIY KUZNECOV	{"email": "vasiliykuznecov1978@postgrespro.ru", "phone": "+70398943757"}
0005434827291	6AAF13	1750 015723	ALEKSANDR PETROV	{"phone": "+70924516800"}
0005434827292	17FDA0	3858 668523	ALEKSEY ISAEV	{"phone": "+70989077318"}
0005434827293	17FDA0	5125 115592	IRINA MASLOVA	{"phone": "+70960839563"}
0005434827294	339F9D	4373 634976	NIKITA IVANOV	{"phone": "+70451290825"}
0005434827295	3ED729	7454 815081	ANZHELIKA ZAKHAROVA	{"phone": "+70420298855"}
0005434827296	C6AB68	8813 329684	ALEKSANDR EGOROV	{"email": "egorova_1963@postgrespro.ru", "phone": "+70819594318"}
0005434827297	3D96AF	5933 448933	ALEKSANDR PETROV	{"email": "aleksandr-petrov_13101974@postgrespro.ru", "phone": "+70528086534"}
0005434827298	3D96AF	3565 633205	NATALYA AFANASEVA	{"phone": "+70565120257"}
0005434828648	95A721	9074 831294	TAMARA EGOROVA	{"email": "egorova.tamara-1978@postgrespro.ru", "phone": "+70778997367"}
0005434828649	C192E4	3080 742754	ALEKSANDR MOISEEV	{"phone": "+70812776049"}
0005434828650	C192E4	3203 956890	NIKITA IVANOV	{"phone": "+70536595792"}
0005434828651	6C753A	8388 509369	ALEKSEY OSIPOV	{"phone": "+70438534299"}
0005434828652	494D06	5740 272296	GALINA EGOROVA	{"email": "egorova-g_10061979@postgrespro.ru", "phone": "+70429224891"}
0005434828653	494D06	1571 606138	EKATERINA ZOTOVA	{"phone": "+70043472813"}
0005434828654	C79AB3	5705 178509	ANATOLIY NOVIKOV	{"email": "novikova.091981@postgrespro.ru", "phone": "+70039664118"}
0005434828655	C79AB3	2667 371430	DANILA KRASNOV	{"phone": "+70056396627"}
0005434828656	9553BA	0651 407419	ANNA KONDRATEVA	{"phone": "+70520904073"}
0005434828657	9553BA	2205 539557	EVGENIYA NOVIKOVA	{"email": "novikovae_1972@postgrespro.ru", "phone": "+70035889193"}
0005434828658	9553BA	6317 084959	NATALYA LEBEDEVA	{"email": "n.lebedeva-25061980@postgrespro.ru", "phone": "+70591671590"}
0005434828659	535587	1125 296579	VALENTINA NAZAROVA	{"phone": "+70077688020"}
0005434828660	535587	0208 314479	ELENA NESTEROVA	{"email": "nesterovae.101966@postgrespro.ru", "phone": "+70854283000"}
0005434828661	222618	5789 071058	SERGEY VOROBEV	{"phone": "+70611523643"}
0005434828662	F3AFCE	7938 010494	TATYANA MAKAROVA	{"phone": "+70830019487"}
0005434828663	82EF3F	1341 082503	NADEZHDA ZHUKOVA	{"email": "n-zhukova28111975@postgrespro.ru", "phone": "+70088331738"}
0005434828664	82EF3F	7954 962616	OLGA ZAYCEVA	{"email": "zaycevaolga-051968@postgrespro.ru", "phone": "+70514863020"}
0005434828665	6AA6BC	9811 238460	YURIY MEDVEDEV	{"email": "medvedevy_081973@postgrespro.ru", "phone": "+70105690429"}
0005434828666	D9DCDA	9629 647290	NELYA OSIPOVA	{"phone": "+70855282591"}
0005434828667	0B86D5	5208 929901	OLGA NIKOLAEVA	{"phone": "+70091713924"}
0005434828668	224983	1675 212003	IRINA ISAEVA	{"phone": "+70875513047"}
0005434828669	2F8F1F	7430 067203	YULIYA ABRAMOVA	{"email": "y-abramova.1964@postgrespro.ru", "phone": "+70738778835"}
0005434828670	2A8672	5301 275075	ANTONINA SERGEEVA	{"email": "a-sergeeva031977@postgrespro.ru", "phone": "+70724935374"}
0005434828671	70163B	7152 858205	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov.021974@postgrespro.ru", "phone": "+70116721176"}
0005434828672	00BCCA	0376 855157	DANIIL ALEKSEEV	{"email": "daniil.alekseev.091967@postgrespro.ru", "phone": "+70328258461"}
0005434828673	00BCCA	7886 191978	SERGEY BONDARENKO	{"phone": "+70479373779"}
0005434828674	F562C5	5311 167959	ALENA MOISEEVA	{"email": "moiseeva-alena.1970@postgrespro.ru", "phone": "+70491797094"}
0005434828675	F562C5	3092 773734	SERGEY VLASOV	{"phone": "+70138710732"}
0005434828676	5205AF	5140 684838	GENNADIY DENISOV	{"phone": "+70427423617"}
0005434828677	776F05	8435 462866	DARYA KOROLEVA	{"email": "darya_koroleva-1970@postgrespro.ru", "phone": "+70353284777"}
0005434828678	776F05	2956 698825	SVETLANA YUDINA	{"phone": "+70061207960"}
0005434828679	4E526B	9925 044749	DARYA NIKOLAEVA	{"phone": "+70979740733"}
0005434828680	4E526B	5342 250152	ROMAN MAKAROV	{"email": "roman-makarov27111971@postgrespro.ru", "phone": "+70993782603"}
0005434828681	4E526B	3049 864538	KLAVDIYA NESTEROVA	{"phone": "+70788656536"}
0005434828682	848C85	6776 122098	DMITRIY SHEVCHENKO	{"email": "shevchenko.dmitriy.1973@postgrespro.ru", "phone": "+70870154726"}
0005434828683	F6E52A	0947 192341	PAVEL EGOROV	{"phone": "+70321427483"}
0005434828684	F6E52A	1893 546132	LIDIYA PETROVA	{"phone": "+70677676539"}
0005434828685	5B910C	2982 268677	LIYA DENISOVA	{"email": "l_denisova-091978@postgrespro.ru", "phone": "+70957262220"}
0005434828686	5EB476	4764 450750	MAKSIM NAZAROV	{"phone": "+70095588086"}
0005434828687	9B5965	0862 468751	ANDREY BORISOV	{"email": "a_borisov-061976@postgrespro.ru", "phone": "+70049072859"}
0005434828688	AF5EE9	4959 640042	TATYANA SOLOVEVA	{"email": "soloveva.tatyana.1972@postgrespro.ru", "phone": "+70802180670"}
0005434828689	AF5EE9	2875 065843	IRINA KONOVALOVA	{"email": "i_konovalova-061968@postgrespro.ru", "phone": "+70976939019"}
0005434828690	D3861D	5298 664923	VALERIY KULIKOV	{"phone": "+70161798414"}
0005434828691	FB062E	8705 215731	VALENTINA KARPOVA	{"email": "v_karpova1968@postgrespro.ru", "phone": "+70830590630"}
0005434828692	686EB0	9585 217878	IVAN ROMANOV	{"email": "romanovi1972@postgrespro.ru", "phone": "+70903427052"}
0005434828693	686EB0	3234 163666	NATALYA ZHUKOVA	{"email": "natalya-zhukova.121977@postgrespro.ru", "phone": "+70296508328"}
0005434828694	6A9CA5	0198 304292	DMITRIY SMIRNOV	{"email": "d-smirnov-051982@postgrespro.ru", "phone": "+70345424860"}
0005434828695	6A9CA5	9600 505670	IVAN KRASNOV	{"email": "ivan-krasnov.021972@postgrespro.ru", "phone": "+70187140212"}
0005434828696	5207A7	4538 294671	SERGEY POPOV	{"email": "s_popov-15121970@postgrespro.ru", "phone": "+70271717934"}
0005434828697	3AD035	2102 297459	OKSANA ANTONOVA	{"email": "antonovaoksana_1969@postgrespro.ru", "phone": "+70334197434"}
0005434828698	146DF7	2948 228860	VIKTOR KUDRYASHOV	{"phone": "+70759608456"}
0005434828699	146DF7	7050 468954	NIKOLAY MELNIKOV	{"phone": "+70976835005"}
0005434828700	D608B3	9709 215816	MIKHAIL VASILEV	{"email": "vasilev_m23021965@postgrespro.ru", "phone": "+70467630295"}
0005434828701	958D6E	7676 393576	MIROSLAV ZHUKOV	{"phone": "+70928989427"}
0005434828702	C487B9	2736 786970	NINA DANILOVA	{"phone": "+70017903879"}
0005434828703	C487B9	2605 220041	LEONID BELOV	{"phone": "+70357843134"}
0005434828704	B81E51	9469 351986	MARIYA YUDINA	{"phone": "+70585146023"}
0005434828705	52064D	6208 213894	EVDOKIYA ANTONOVA	{"email": "antonovaevdokiya121964@postgrespro.ru", "phone": "+70962983764"}
0005434828706	52064D	0303 851287	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov19111976@postgrespro.ru", "phone": "+70339631794"}
0005434828707	73C556	8245 121213	YAROSLAV ZAYCEV	{"email": "zaycev-y03081969@postgrespro.ru", "phone": "+70500329235"}
0005434828708	436A0F	5146 773692	GALINA SIDOROVA	{"phone": "+70749473809"}
0005434828709	A4D08D	8021 320895	PETR TIKHONOV	{"email": "petrtikhonov-1966@postgrespro.ru", "phone": "+70320412891"}
0005434828710	A4D08D	6754 393167	IGOR SOLOVEV	{"phone": "+70091748832"}
0005434828711	C60165	0662 089763	VLADIMIR POPOV	{"phone": "+70531663095"}
0005434828712	C60165	5562 610342	VIKTORIYA MOROZOVA	{"email": "viktoriya-morozova.04111984@postgrespro.ru", "phone": "+70465383058"}
0005434828713	D561B1	8968 004076	IRINA ANDREEVA	{"email": "i_andreeva.04051975@postgrespro.ru", "phone": "+70279046094"}
0005434828714	079DA4	0292 330996	EKATERINA MIRONOVA	{"email": "mironova.e061975@postgrespro.ru", "phone": "+70779624317"}
0005434828715	B55A04	2679 125356	LYUBOV KOROLEVA	{"email": "koroleval1973@postgrespro.ru", "phone": "+70226383736"}
0005434828716	F91DED	3144 606769	OLGA KOROLEVA	{"phone": "+70576179621"}
0005434828717	1CBFB6	7072 059602	ELENA FOMINA	{"phone": "+70693479297"}
0005434828718	6656CE	9681 439767	ALEKSANDR VOROBEV	{"phone": "+70631662468"}
0005434828719	6656CE	3806 037894	NADEZHDA MIRONOVA	{"phone": "+70713800532"}
0005434828720	6656CE	8044 962874	KSENIYA MOROZOVA	{"email": "kseniya-morozova-1969@postgrespro.ru", "phone": "+70388862615"}
0005434828721	0531C1	3477 368872	MAKSIM ISAEV	{"phone": "+70261692439"}
0005434828722	064845	1659 177620	GENNADIY BONDARENKO	{"email": "bondarenko_g-1970@postgrespro.ru", "phone": "+70130609152"}
0005434828723	635B09	5627 229119	MARIYA DANILOVA	{"phone": "+70499643088"}
0005434828724	633FAE	9425 070394	VERONIKA PAVLOVA	{"phone": "+70099205072"}
0005434828725	D8D5B2	8521 478091	NADEZHDA KUDRYASHOVA	{"email": "n.kudryashova-091974@postgrespro.ru", "phone": "+70955694345"}
0005434828726	D8D5B2	2939 746390	NATALYA LEBEDEVA	{"email": "lebedeva_natalya_011968@postgrespro.ru", "phone": "+70882799706"}
0005434828727	967847	5729 963657	NAIL KUDRYASHOV	{"phone": "+70119882473"}
0005434828728	82D36A	0667 685489	MARFA ZAYCEVA	{"email": "zayceva-m041965@postgrespro.ru", "phone": "+70294759043"}
0005434828729	0837C1	7069 727721	LYUBOV NAUMOVA	{"phone": "+70750064258"}
0005434828730	719F39	9303 265766	YURIY FROLOV	{"email": "yuriy.frolov101965@postgrespro.ru", "phone": "+70780496684"}
0005434828731	1B34DF	2571 357259	VLADIMIR SOROKIN	{"phone": "+70359098977"}
0005434828732	632F05	9305 394567	OLGA KRASNOVA	{"phone": "+70616269941"}
0005434828733	098A8A	9821 657104	EKATERINA ILINA	{"email": "ekaterina-ilina-19101970@postgrespro.ru", "phone": "+70251107561"}
0005434828734	CD084B	1634 247687	LYUDMILA ANDREEVA	{"email": "l-andreeva.15051960@postgrespro.ru", "phone": "+70925415982"}
0005434828735	CD084B	6968 869776	LARISA ZAYCEVA	{"email": "zayceva.larisa-1956@postgrespro.ru", "phone": "+70884876364"}
0005434828736	DE3EC4	7517 629790	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr1972@postgrespro.ru", "phone": "+70544389164"}
0005434828737	87BC8A	8613 434576	NATALYA VASILEVA	{"email": "vasileva-natalya_1977@postgrespro.ru", "phone": "+70265931894"}
0005434828738	87BC8A	0723 190278	SEMEN FROLOV	{"phone": "+70436056022"}
0005434828739	599002	4026 930152	SVETLANA FILIPPOVA	{"phone": "+70435317162"}
0005434828740	599002	5373 935417	KONSTANTIN FROLOV	{"email": "k_frolov.091974@postgrespro.ru", "phone": "+70613922046"}
0005434828741	599002	7849 441815	ANTONINA TIKHONOVA	{"email": "tikhonovaa-1973@postgrespro.ru", "phone": "+70348258183"}
0005434828742	B6E5E6	4558 175360	LYUBOV ARKHIPOVA	{"phone": "+70639545017"}
0005434828743	AC492A	0041 955506	NATALYA KOZLOVA	{"phone": "+70849214095"}
0005434828744	73B21E	6268 591227	ILYA NIKOLAEV	{"phone": "+70514357448"}
0005434828745	73B21E	3026 521846	NADEZHDA SAVELEVA	{"email": "n_saveleva.1967@postgrespro.ru", "phone": "+70060837598"}
0005434828746	4CF21B	6300 581586	RIMMA AFANASEVA	{"phone": "+70614742086"}
0005434828747	4E11B8	6924 186532	SARIYA ROMANOVA	{"phone": "+70184407222"}
0005434828748	6FE0C1	5610 434862	EVGENIY SOROKIN	{"email": "sorokin-evgeniy1978@postgrespro.ru", "phone": "+70060935067"}
0005434828749	36687B	0573 209937	SERGEY MAKAROV	{"phone": "+70765366889"}
0005434828750	60BFEB	2960 148845	EKATERINA MALYSHEVA	{"phone": "+70612708378"}
0005434828751	3605FC	4089 643301	MAKSIM STEPANOV	{"email": "stepanov-m1969@postgrespro.ru", "phone": "+70479833814"}
0005434828752	15F3C9	5224 709355	RAFAIL FEDOTOV	{"phone": "+70642797279"}
0005434828753	C8668B	1601 902112	GALINA SEMENOVA	{"phone": "+70255261488"}
0005434828754	C8668B	8032 014591	ANZHELA EFIMOVA	{"email": "a.efimova-1967@postgrespro.ru", "phone": "+70672818538"}
0005434828755	5B1049	5403 720529	ARTEM KUZNECOV	{"email": "kuznecov.artem041972@postgrespro.ru", "phone": "+70912867666"}
0005434828756	825E6B	0271 132450	OLGA MOROZOVA	{"email": "morozova-olga-1972@postgrespro.ru", "phone": "+70325439365"}
0005434828757	EE67E1	0471 931296	OKSANA ANDREEVA	{"email": "andreeva.oksana04061978@postgrespro.ru", "phone": "+70391538090"}
0005434828758	EE67E1	1954 543290	YAKOV STEPANOV	{"email": "ystepanov_1971@postgrespro.ru", "phone": "+70513592656"}
0005434828759	7348F3	5854 118536	RAUZA KRASNOVA	{"email": "krasnova_rauza-1958@postgrespro.ru", "phone": "+70073936716"}
0005434828760	7348F3	3833 371395	PETR FEDOTOV	{"phone": "+70176730278"}
0005434828761	59B7A9	1948 956366	DANILA IVANOV	{"phone": "+70646239474"}
0005434828762	1ED9AB	8531 668094	VIKTORIYA NAUMOVA	{"phone": "+70346717585"}
0005434828763	49061B	8839 288165	RUSLAN KISELEV	{"phone": "+70902918829"}
0005434828764	0714CF	8720 982237	ALEKSANDR GAVRILOV	{"email": "gavrilova_111991@postgrespro.ru", "phone": "+70785951696"}
0005434828765	0714CF	5865 259652	MARIYA BELOVA	{"phone": "+70371703246"}
0005434828766	0714CF	6158 030131	NIKOLAY NAZAROV	{"email": "nnazarov1974@postgrespro.ru", "phone": "+70247818365"}
0005434828767	8958F9	6179 721612	NINA SMIRNOVA	{"phone": "+70221832450"}
0005434828768	8958F9	5247 796768	VLADIMIR KAZAKOV	{"email": "kazakov.v.101972@postgrespro.ru", "phone": "+70215345221"}
0005434828769	20F5E0	3233 575619	IVAN ORLOV	{"phone": "+70391812396"}
0005434828770	20F5E0	0305 285267	SVETLANA TARASOVA	{"phone": "+70482212137"}
0005434828771	08D1C9	2777 221025	MARIYA GUSEVA	{"phone": "+70160580940"}
0005434828772	AB2651	4259 461339	SERGEY TARASOV	{"email": "sergey.tarasov_1984@postgrespro.ru", "phone": "+70126591650"}
0005434828773	429BC6	7168 220334	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr24091973@postgrespro.ru", "phone": "+70823891490"}
0005434828774	AE0BF1	2238 325889	YURIY SERGEEV	{"phone": "+70896024467"}
0005434828775	AE0BF1	5989 198544	FILIPP STEPANOV	{"email": "stepanov-filipp_26031977@postgrespro.ru", "phone": "+70085197831"}
0005434831066	A45F85	7121 105215	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr-1968@postgrespro.ru", "phone": "+70433413999"}
0005434831067	B36917	7111 024201	SERGEY ALEKSEEV	{"phone": "+70675017883"}
0005434831068	B36917	5795 934899	ALEKSANDR AFANASEV	{"phone": "+70166320354"}
0005434831069	0C2CC4	3589 403845	SERGEY MELNIKOV	{"email": "melnikov_sergey-19101965@postgrespro.ru", "phone": "+70156826472"}
0005434831070	CE282A	4144 983434	KRISTINA IVANOVA	{"phone": "+70479361318"}
0005434831071	BC05E0	4485 018886	GENNADIY ALEKSANDROV	{"phone": "+70113621614"}
0005434831072	C75888	3578 881671	MAKSIM KUZNECOV	{"email": "maksim-kuznecov_091962@postgrespro.ru", "phone": "+70910238572"}
0005434831073	AE91BF	0308 499020	VLADIMIR POPOV	{"email": "popov_vladimir_1970@postgrespro.ru", "phone": "+70138717768"}
0005434831074	062F67	1979 942287	ANTON MATVEEV	{"email": "matveevanton.15101974@postgrespro.ru", "phone": "+70580771828"}
0005434831075	740A84	3582 181984	MAYYA DAVYDOVA	{"phone": "+70151669805"}
0005434831076	646D16	2686 663005	ELENA FILIPPOVA	{"phone": "+70004463302"}
0005434831077	D31307	6315 467621	NIKOLAY FOMIN	{"email": "fomin_n-13081966@postgrespro.ru", "phone": "+70640232126"}
0005434831078	B9F571	3106 825530	DMITRIY ALEKSANDROV	{"email": "dmitriy-aleksandrov-021967@postgrespro.ru", "phone": "+70442874069"}
0005434831079	AA0C89	1451 563184	ALEKSANDR BONDARENKO	{"email": "aleksandr.bondarenko_20061967@postgrespro.ru", "phone": "+70935815896"}
0005434831080	2D71E9	2757 335099	VLADIMIR NAZAROV	{"phone": "+70121046366"}
0005434831081	2D71E9	6615 838282	EVGENIYA YAKOVLEVA	{"email": "e_yakovleva_081972@postgrespro.ru", "phone": "+70277728839"}
0005434831082	2B2623	0504 342504	SVETLANA POPOVA	{"phone": "+70231432514"}
0005434831083	BDB0F1	5249 471266	VALERIY VLASOV	{"email": "vlasov_valeriy-101981@postgrespro.ru", "phone": "+70126260682"}
0005434831084	6F7D56	2379 445396	ANTONINA DENISOVA	{"email": "adenisova-1977@postgrespro.ru", "phone": "+70526679778"}
0005434831085	6F7D56	9254 700817	MARIYA FILIPPOVA	{"phone": "+70881209100"}
0005434831086	3A7667	5647 880367	DENIS MOROZOV	{"phone": "+70447516995"}
0005434831087	3A7667	5291 224077	EVGENIY ANDREEV	{"phone": "+70347979626"}
0005434831088	80FE93	0657 142651	VYACHESLAV MIRONOV	{"phone": "+70982350420"}
0005434831089	A72430	3333 890714	ELVIRA ILINA	{"email": "elvira.ilina.23101977@postgrespro.ru", "phone": "+70916249198"}
0005434831090	12C342	7404 060441	ILDAR SOROKIN	{"phone": "+70999852027"}
0005434831091	EFB331	1023 922192	NATALYA OSIPOVA	{"email": "osipova.n.1974@postgrespro.ru", "phone": "+70587254025"}
0005434831092	870EBF	2663 940886	VALERIYA MALYSHEVA	{"email": "vmalysheva-1966@postgrespro.ru", "phone": "+70312622746"}
0005434831093	EAD3BE	6952 993087	ANNA IVANOVA	{"email": "a_ivanova-09121977@postgrespro.ru", "phone": "+70891049539"}
0005434831094	5D3732	3373 342916	EVGENIY DMITRIEV	{"email": "dmitrievevgeniy-1975@postgrespro.ru", "phone": "+70078163903"}
0005434831095	149217	5661 623747	LARISA CHERNOVA	{"phone": "+70599248780"}
0005434831096	149217	3158 208469	KONSTANTIN GRIGOREV	{"phone": "+70396248433"}
0005434831097	E885C6	2224 679690	DANIL FROLOV	{"email": "frolovdanil-1974@postgrespro.ru", "phone": "+70573227947"}
0005434831098	B3459D	5795 764180	ELINA KUZNECOVA	{"email": "e_kuznecova_10051976@postgrespro.ru", "phone": "+70444234447"}
0005434831099	B3459D	9442 715124	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir20111973@postgrespro.ru", "phone": "+70449636231"}
0005434831100	214A10	9890 319224	YAROSLAV SERGEEV	{"phone": "+70735154921"}
0005434831101	214A10	1446 131833	EVGENIY PAVLOV	{"email": "evgeniy-pavlov-07121972@postgrespro.ru", "phone": "+70280803658"}
0005434831102	2AA437	9513 610666	ANATOLIY ANTONOV	{"phone": "+70822517238"}
0005434831103	8167A9	7432 870352	VIKTOR SMIRNOV	{"phone": "+70111271364"}
0005434831104	C70AA8	8576 400306	ALEKSEY GORBUNOV	{"email": "gorbunova_1972@postgrespro.ru", "phone": "+70598570275"}
0005434831105	C70AA8	5467 452133	OLGA LOGINOVA	{"phone": "+70786705864"}
0005434831106	B70A45	4655 092867	OLEG SEMENOV	{"email": "oleg.semenov1979@postgrespro.ru", "phone": "+70800827299"}
0005434831107	46BDA6	5271 345935	RAISA TROFIMOVA	{"phone": "+70917196321"}
0005434831108	46BDA6	7760 666097	OLESYA ZAYCEVA	{"phone": "+70017882634"}
0005434831109	584660	5175 956173	TATYANA MELNIKOVA	{"email": "melnikova.t.1981@postgrespro.ru", "phone": "+70883223398"}
0005434831110	7D28FE	0938 597263	ANDREY IVANOV	{"email": "ivanov-andrey.1964@postgrespro.ru", "phone": "+70371257647"}
0005434831111	686794	3068 833092	MAKSIM IVANOV	{"email": "maksimivanov1970@postgrespro.ru", "phone": "+70312463935"}
0005434831112	0C5794	9742 884826	VLADIMIR DAVYDOV	{"email": "davydov.v03011973@postgrespro.ru", "phone": "+70648311552"}
0005434831113	2DB66F	7542 880970	ELENA POPOVA	{"email": "elena.popova.1969@postgrespro.ru", "phone": "+70672323503"}
0005434831114	0E6C12	6939 525140	LYUDMILA PAVLOVA	{"phone": "+70551892849"}
0005434831115	27F926	3898 446878	ZINAIDA SCHERBAKOVA	{"email": "zinaidascherbakova-1969@postgrespro.ru", "phone": "+70240468740"}
0005434831116	0ABEE0	2886 682570	ALEKSANDR KISELEV	{"email": "kiselevaleksandr.041974@postgrespro.ru", "phone": "+70484409287"}
0005434831117	09B4A9	0317 602656	ANDREY IVANOV	{"email": "ivanova_011961@postgrespro.ru", "phone": "+70218213195"}
0005434831118	7C60C6	3423 787582	TATYANA MALYSHEVA	{"email": "malysheva-t16011974@postgrespro.ru", "phone": "+70945167116"}
0005434831119	7C60C6	8478 811052	VIKTOR KOZLOV	{"email": "viktorkozlov25081965@postgrespro.ru", "phone": "+70565539687"}
0005434831120	7C60C6	5153 352358	MIKHAIL VASILEV	{"phone": "+70624643928"}
0005434831121	4DEA6C	4238 558257	EKATERINA POPOVA	{"phone": "+70779953515"}
0005434831122	4DEA6C	8747 742898	ALBINA RODIONOVA	{"email": "a.rodionova-111967@postgrespro.ru", "phone": "+70797249497"}
0005434831123	4DEA6C	6241 405622	ANVAR MIKHAYLOV	{"phone": "+70130222693"}
0005434831124	95203D	1490 434652	ALEKSANDR NIKOLAEV	{"phone": "+70069530422"}
0005434831125	95203D	6313 562723	VASILIY IVANOV	{"phone": "+70900399321"}
0005434831126	5A1C17	0977 102436	PAVEL ALEKSANDROV	{"email": "pavel_aleksandrov1979@postgrespro.ru", "phone": "+70474223072"}
0005434831127	0F0522	8357 352748	ALEKSANDR NIKITIN	{"phone": "+70603024378"}
0005434831128	0F0522	8824 151413	MIKHAIL ZAKHAROV	{"email": "zakharov_mikhail_12051971@postgrespro.ru", "phone": "+70261640220"}
0005434831129	A5E4FF	9440 597386	SVETLANA VOLKOVA	{"phone": "+70014674146"}
0005434831130	A5E4FF	8135 864388	ANATOLIY NOVIKOV	{"phone": "+70241941638"}
0005434831131	A5E4FF	9094 116337	VIKTOR GUSEV	{"email": "viktor_gusev1974@postgrespro.ru", "phone": "+70244750525"}
0005434831132	5D7302	8424 041339	ALEKSANDR STEPANOV	{"phone": "+70364592307"}
0005434831133	E1923B	2835 469389	VIKTORIYA TIMOFEEVA	{"email": "viktoriyatimofeeva-19071958@postgrespro.ru", "phone": "+70678456823"}
0005434831134	9E251C	1843 168156	ANDREY SHEVCHENKO	{"email": "a_shevchenko_12011970@postgrespro.ru", "phone": "+70175245229"}
0005434831135	9E251C	1212 305926	VLADIMIR GUSEV	{"email": "gusev-vladimir-041977@postgrespro.ru", "phone": "+70024518604"}
0005434831136	5F7CA3	7760 782247	OLESYA SCHERBAKOVA	{"email": "scherbakova-olesya_20041970@postgrespro.ru", "phone": "+70592865629"}
0005434831137	25E790	0679 735025	NADEZHDA ALEKSEEVA	{"email": "n.alekseeva.061963@postgrespro.ru", "phone": "+70614553629"}
0005434831138	25E790	8087 946013	EKATERINA ERMAKOVA	{"email": "e_ermakova-061965@postgrespro.ru", "phone": "+70492588685"}
0005434831139	906671	3759 151200	EMIL STEPANOV	{"email": "emilstepanov16111966@postgrespro.ru", "phone": "+70380877015"}
0005434831140	906671	1090 017947	TATYANA PAVLOVA	{"phone": "+70204896519"}
0005434831141	ACE35F	1495 807407	KRISTINA FILATOVA	{"phone": "+70875459429"}
0005434831142	60F441	1302 432217	ANTON TIKHONOV	{"phone": "+70737612945"}
0005434831143	60F441	2943 149519	OLESYA ISAEVA	{"email": "isaeva-o-08061977@postgrespro.ru", "phone": "+70712237256"}
0005434831144	18E31B	9563 746939	ROZA KOZLOVA	{"email": "kozlovar.02071968@postgrespro.ru", "phone": "+70397070215"}
0005434831145	49712C	2178 399613	IGOR IVANOV	{"email": "igor-ivanov23011967@postgrespro.ru", "phone": "+70100334358"}
0005434831146	49712C	4439 645434	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir1967@postgrespro.ru", "phone": "+70207235503"}
0005434831147	49712C	4163 146325	ALEKSANDR MARTYNOV	{"email": "amartynov_1963@postgrespro.ru", "phone": "+70961473540"}
0005434831148	8E9306	9890 387149	ARINA ZHUKOVA	{"email": "arinazhukova.101976@postgrespro.ru", "phone": "+70942810437"}
0005434831149	8E9306	4987 135625	ALEKSANDR KAZAKOV	{"email": "a.kazakov13051967@postgrespro.ru", "phone": "+70719451051"}
0005434831150	8E9306	7137 953372	KIRILL DENISOV	{"phone": "+70960785398"}
0005434831151	C68EAC	2918 667490	DIANA VASILEVA	{"phone": "+70961335048"}
0005434831152	1DCE1E	2017 093322	KRISTINA NAZAROVA	{"email": "kristina.nazarova-24041982@postgrespro.ru", "phone": "+70158055184"}
0005434831153	1DCE1E	4024 836007	YANA TITOVA	{"email": "y-titova.01021977@postgrespro.ru", "phone": "+70667400560"}
0005434831154	1DCE1E	1548 579326	VADIM TIKHONOV	{"email": "v.tikhonov-031967@postgrespro.ru", "phone": "+70372826254"}
0005434831155	06397B	9274 569293	IRINA MARTYNOVA	{"email": "martynova-i-20021967@postgrespro.ru", "phone": "+70163346198"}
0005434831156	62AABF	1885 117431	VYACHESLAV POPOV	{"email": "v_popov-1961@postgrespro.ru", "phone": "+70966729043"}
0005434831157	62AABF	4062 769940	YURIY KARPOV	{"phone": "+70846314243"}
0005434831158	399343	9987 061596	LYUDMILA KARPOVA	{"phone": "+70449886033"}
0005434831159	399343	0073 442844	STANISLAV SHEVCHENKO	{"email": "stanislav.shevchenko.20101983@postgrespro.ru", "phone": "+70206575678"}
0005434831160	6E7A5E	3613 098419	MIKHAIL VASILEV	{"email": "m_vasilev121982@postgrespro.ru", "phone": "+70050344266"}
0005434831161	FB1812	2390 781530	SERGEY ROMANOV	{"phone": "+70770213042"}
0005434831162	FB1812	6582 302618	NATALYA ZAYCEVA	{"phone": "+70448502693"}
0005434831163	5E5696	0037 496714	OLGA FILIPPOVA	{"phone": "+70924467254"}
0005434831164	AE1E24	1857 339548	ARTEM ISAEV	{"phone": "+70100187682"}
0005434831165	AE1E24	8084 400813	ELENA KUZNECOVA	{"email": "elenakuznecova-03091973@postgrespro.ru", "phone": "+70743206854"}
0005434831166	146059	2324 759006	NADEZHDA MAKAROVA	{"email": "n.makarova.1961@postgrespro.ru", "phone": "+70240548461"}
0005434831167	204FE0	4265 124638	TAMARA ZOTOVA	{"phone": "+70310177019"}
0005434831168	10E74F	0827 292085	ZULFIYA BORISOVA	{"phone": "+70084707624"}
0005434831169	FA6981	1749 349640	ALEKSANDRA SOROKINA	{"email": "sorokina.a23081982@postgrespro.ru", "phone": "+70155860548"}
0005434831170	656EDE	0214 088619	ANASTASIYA IVANOVA	{"phone": "+70387355860"}
0005434831171	DE8343	3297 933532	ANASTASIYA KUDRYASHOVA	{"phone": "+70643741124"}
0005434831172	16FB08	1415 912266	YANA KRASNOVA	{"email": "krasnovayana22101963@postgrespro.ru", "phone": "+70935043829"}
0005434831173	16FB08	6318 240790	TATYANA IVANOVA	{"email": "t.ivanova-021959@postgrespro.ru", "phone": "+70860978310"}
0005434831174	55270C	3903 865214	TATYANA KARPOVA	{"phone": "+70959686846"}
0005434831175	14255B	1311 302988	ANATOLIY GAVRILOV	{"email": "a-gavrilov-111966@postgrespro.ru", "phone": "+70842000172"}
0005434831176	14255B	4362 275435	ANATOLIY CHERNOV	{"email": "anatoliy-chernov-1960@postgrespro.ru", "phone": "+70054471863"}
0005434831177	0D8F45	3495 141580	ALEKSEY MOISEEV	{"phone": "+70978418653"}
0005434831178	BBFE70	1304 000025	ALEKSANDR ORLOV	{"phone": "+70032228709"}
0005434831179	A5CA79	9918 744653	ULYANA AFANASEVA	{"phone": "+70474568536"}
0005434831180	8274CB	7559 388629	KONSTANTIN POPOV	{"email": "konstantinpopov041965@postgrespro.ru", "phone": "+70031181412"}
0005434831181	AFD90B	5167 761142	ELENA DMITRIEVA	{"phone": "+70685005630"}
0005434831182	AFD90B	1858 789800	OLGA IVANOVA	{"email": "ivanova.o_111969@postgrespro.ru", "phone": "+70791966356"}
0005434831183	B38FE0	4738 023326	YULIYA EFREMOVA	{"email": "yuliya-efremova_021984@postgrespro.ru", "phone": "+70961316435"}
0005434831184	71A4E8	6660 667562	SVETLANA VASILEVA	{"phone": "+70338778715"}
0005434831185	70307C	2141 415717	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey_16031979@postgrespro.ru", "phone": "+70408377483"}
0005434831186	D7F291	0279 720106	RUSHANIYA KUZNECOVA	{"phone": "+70587156496"}
0005434831187	A00A69	8409 097028	LYUDMILA KUZMINA	{"email": "lkuzmina-011979@postgrespro.ru", "phone": "+70260650777"}
0005434831188	E7B79A	4795 926123	ARTEM NIKITIN	{"email": "artem.nikitin041981@postgrespro.ru", "phone": "+70637743498"}
0005434831189	8CC9AD	9958 842553	EVGENIYA POPOVA	{"email": "popova-evgeniya1973@postgrespro.ru", "phone": "+70004526290"}
0005434831190	CEB822	8185 729829	VLADIMIR MOISEEV	{"phone": "+70254256073"}
0005434831191	F20393	9753 378904	STANISLAV FEDOROV	{"email": "stanislav_fedorov_1963@postgrespro.ru", "phone": "+70099990444"}
0005434831192	A8BD58	0065 912386	NATALIYA DANILOVA	{"email": "danilova-n13061967@postgrespro.ru", "phone": "+70868061836"}
0005434831193	00E885	1223 612726	LYUDMILA MOROZOVA	{"phone": "+70425347688"}
0005434831194	00E885	6896 081754	VALENTINA MAKSIMOVA	{"email": "vmaksimova-041973@postgrespro.ru", "phone": "+70014694667"}
0005434831195	85CBDA	7807 348687	VASILIY VLASOV	{"email": "v-vlasov1981@postgrespro.ru", "phone": "+70922191148"}
0005434831196	C028AE	3448 773489	STANISLAV MAKAROV	{"phone": "+70081149669"}
0005434831197	1C72E6	1643 083222	IREK PETROV	{"email": "irek-petrov_13031975@postgrespro.ru", "phone": "+70956021625"}
0005434831198	E80D24	3265 059310	MILANA KARPOVA	{"email": "karpova-m.031982@postgrespro.ru", "phone": "+70186725634"}
0005434831199	0087F5	3958 830523	SERGEY EGOROV	{"email": "sergey-egorov071965@postgrespro.ru", "phone": "+70667649240"}
0005434831200	687148	3780 904872	DIANA GAVRILOVA	{"email": "gavrilova_diana-031975@postgrespro.ru", "phone": "+70144075119"}
0005434831201	687148	4293 076432	EVDOKIYA SOKOLOVA	{"email": "sokolovaevdokiya_1963@postgrespro.ru", "phone": "+70224615688"}
0005434831202	687148	3594 720134	YANA KUZNECOVA	{"email": "kuznecova_y.081968@postgrespro.ru", "phone": "+70342457850"}
0005434831203	2C76E6	4948 619538	ALEKSEY TIMOFEEV	{"phone": "+70199256406"}
0005434831204	3E1D55	7750 105130	IRINA NIKITINA	{"phone": "+70157026391"}
0005434831205	3E1D55	9908 336096	VASILIY SEMENOV	{"phone": "+70369259149"}
0005434831206	CF68DA	7419 589983	DMITRIY MAKAROV	{"email": "dmitriy.makarov1969@postgrespro.ru", "phone": "+70326159265"}
0005434831207	D37C3C	4432 268163	OLGA ISAEVA	{"email": "isaevaolga-26031974@postgrespro.ru", "phone": "+70595980215"}
0005434831208	40B0E7	1090 948346	FARIDA MIRONOVA	{"email": "f.mironova26101976@postgrespro.ru", "phone": "+70203430812"}
0005434831209	1E860E	8207 188827	TATYANA DANILOVA	{"phone": "+70745568061"}
0005434831210	1E24F5	4592 776600	NINA ZAYCEVA	{"email": "zaycevanina_30081966@postgrespro.ru", "phone": "+70437855009"}
0005434831211	F302D4	6112 308727	IRINA KOZLOVA	{"email": "kozlova-i101969@postgrespro.ru", "phone": "+70112323273"}
0005434831212	BDDA50	5058 750459	ALEKSEY MIRONOV	{"phone": "+70687129624"}
0005434831213	FB7EB4	0729 597226	NINA TARASOVA	{"email": "tarasovanina_1973@postgrespro.ru", "phone": "+70221804241"}
0005434831214	7635AA	3479 467213	NURLAN FEDOROV	{"email": "n_fedorov_1971@postgrespro.ru", "phone": "+70107381467"}
0005434831215	ACE61C	8474 059397	LIYA SCHERBAKOVA	{"phone": "+70200832844"}
0005434831216	B3604D	9577 739374	MARIYA ORLOVA	{"email": "orlova-m-1959@postgrespro.ru", "phone": "+70193140280"}
0005434831217	B3604D	7171 865147	IRINA ROMANOVA	{"email": "romanova-irina-1970@postgrespro.ru", "phone": "+70841635665"}
0005434831218	6A293E	5578 599247	ANDREY PAVLOV	{"email": "apavlov27121965@postgrespro.ru", "phone": "+70285266729"}
0005434831219	1BB4A7	1996 905101	VADIM TARASOV	{"phone": "+70773865797"}
0005434831220	1BB4A7	2763 591920	LYUDMILA SMIRNOVA	{"email": "lyudmila_smirnova.1964@postgrespro.ru", "phone": "+70038329925"}
0005434831221	062919	5329 263812	RAFAIL BONDARENKO	{"phone": "+70559658105"}
0005434831222	0D926A	2454 876459	EDUARD KUZMIN	{"phone": "+70122879134"}
0005434831223	D5B650	9362 619695	VIKTOR ZAYCEV	{"phone": "+70905955564"}
0005434831224	D5B650	1507 885208	YURIY PETROV	{"phone": "+70780000852"}
0005434831225	C19B97	1409 049187	VALENTINA ZHUKOVA	{"email": "zhukovav.011970@postgrespro.ru", "phone": "+70729768962"}
0005434831226	25278C	5802 710400	TATYANA POTAPOVA	{"email": "potapova.tatyana081983@postgrespro.ru", "phone": "+70827995696"}
0005434831227	D64446	2415 595957	TAMARA ZHUKOVA	{"email": "t_zhukova1969@postgrespro.ru", "phone": "+70450081975"}
0005434831228	D64446	7992 169832	YULIYA IVANOVA	{"email": "ivanova.y03091976@postgrespro.ru", "phone": "+70582079004"}
0005434831229	56BE9B	9946 287695	RAIL IVANOV	{"phone": "+70044778428"}
0005434831230	03D670	3495 471425	IRINA KUZNECOVA	{"phone": "+70471549943"}
0005434831231	9B75E9	5231 912818	YURIY BORISOV	{"email": "yuriy_borisov_1970@postgrespro.ru", "phone": "+70662552497"}
0005434831232	B1D66B	3340 060033	IRINA ALEKSANDROVA	{"email": "i.aleksandrova.091964@postgrespro.ru", "phone": "+70616255224"}
0005434831233	B1D66B	9373 456581	VALERIYA NIKITINA	{"phone": "+70937826072"}
0005434831234	626684	3854 371199	VADIM VOLKOV	{"phone": "+70101581243"}
0005434831235	626684	9776 859567	LYUBOV VOLKOVA	{"email": "volkova-l.071973@postgrespro.ru", "phone": "+70653657181"}
0005434831236	7828ED	0934 362549	ALEKSEY IVANOV	{"email": "ivanovaleksey1977@postgrespro.ru", "phone": "+70636147993"}
0005434831237	14647F	5813 825656	NATALYA LEBEDEVA	{"email": "lebedevan-23021967@postgrespro.ru", "phone": "+70844586686"}
0005434831238	47103F	1531 429972	OLGA BELOVA	{"email": "olgabelova_14011983@postgrespro.ru", "phone": "+70334817731"}
0005434831239	47103F	0991 356382	VLADIMIR GUSEV	{"phone": "+70033539002"}
0005434831240	7C2711	3977 730732	OLGA SIDOROVA	{"email": "osidorova_29041972@postgrespro.ru", "phone": "+70191931806"}
0005434831241	7C2711	0930 088140	OLEG BORISOV	{"phone": "+70509019216"}
0005434831242	325C0C	6989 972056	NINA DAVYDOVA	{"phone": "+70604860941"}
0005434831243	C2FCC3	7790 988706	IRINA MAKAROVA	{"email": "makarovairina.101960@postgrespro.ru", "phone": "+70025314059"}
0005434831244	2ECAE4	9981 579697	OLEG MAKAROV	{"phone": "+70556987629"}
0005434831245	A928AA	3194 455829	ROMAN MEDVEDEV	{"email": "r_medvedev.091969@postgrespro.ru", "phone": "+70954337499"}
0005434831246	A5BDEB	0152 464664	FEDOR KUZMIN	{"email": "kuzminf-1972@postgrespro.ru", "phone": "+70599552774"}
0005434831247	D56C81	9413 642591	NADEZHDA DAVYDOVA	{"phone": "+70557436518"}
0005434831248	59E508	5757 295362	ALEKSANDR VLASOV	{"email": "vlasov-aleksandr_1969@postgrespro.ru", "phone": "+70480031588"}
0005434831249	CE4EEF	3953 882446	DMITRIY MAKAROV	{"phone": "+70758989882"}
0005434831250	A35F96	3416 977188	OLGA EFIMOVA	{"phone": "+70022483925"}
0005434831251	A35F96	6469 269661	ALISA ANDREEVA	{"email": "andreeva_alisa-061980@postgrespro.ru", "phone": "+70233079196"}
0005434831252	5ECC1B	5345 978607	IRINA KUZMINA	{"phone": "+70897318913"}
0005434831253	1D4267	8429 956355	ALEKSANDR EGOROV	{"email": "aleksandregorov-101968@postgrespro.ru", "phone": "+70190822778"}
0005434831254	1D4267	6457 070838	SERGEY ILIN	{"phone": "+70335999302"}
0005434831255	FB0D96	8281 513086	PAVEL AFANASEV	{"email": "afanasevp.091963@postgrespro.ru", "phone": "+70924333479"}
0005434831256	283846	6404 361547	VLADIMIR MAKSIMOV	{"email": "maksimov.vladimir.20061984@postgrespro.ru", "phone": "+70780599407"}
0005434831257	8301E7	0624 933280	ALEKSANDRA SIDOROVA	{"phone": "+70760903694"}
0005434831258	AAF8A9	3866 508162	VALENTINA ALEKSEEVA	{"phone": "+70216594640"}
0005434831259	AAF8A9	7265 270142	IGOR BONDARENKO	{"phone": "+70508004137"}
0005434831260	B0F154	6602 041159	OLESYA CHERNOVA	{"phone": "+70978789663"}
0005434831261	2CB2A0	3991 209957	LYUDMILA MOROZOVA	{"email": "lmorozova_061968@postgrespro.ru", "phone": "+70827679509"}
0005434831262	407ECC	7225 018034	VASILIY ANTONOV	{"email": "antonov_vasiliy1966@postgrespro.ru", "phone": "+70580438947"}
0005434831263	A10DD2	7508 156549	EVGENIYA AKIMOVA	{"email": "eakimova.25091977@postgrespro.ru", "phone": "+70730320510"}
0005434831264	8E45AD	1148 196166	TATYANA POLYAKOVA	{"phone": "+70162503450"}
0005434831265	A03B19	9883 480723	VIKTORIYA ANISIMOVA	{"email": "anisimova_v.041967@postgrespro.ru", "phone": "+70029974316"}
0005434831266	A03B19	9105 293979	SANIYA KUZNECOVA	{"phone": "+70170329396"}
0005434831267	13878A	7668 537727	LYUBOV MELNIKOVA	{"email": "l_melnikova-1977@postgrespro.ru", "phone": "+70437011026"}
0005434831268	D12EC5	7876 082249	NATALYA MALYSHEVA	{"phone": "+70008535136"}
0005434831269	F58F01	9609 498638	NIKOLAY NOVIKOV	{"email": "nikolay-novikov_27011963@postgrespro.ru", "phone": "+70108115618"}
0005434831270	B0CE47	1806 047043	SERGEY KUDRYASHOV	{"phone": "+70602288546"}
0005434831271	B0CE47	9068 271522	IVAN KUZNECOV	{"phone": "+70772413232"}
0005434831272	06E2D6	6700 705169	SVETLANA NIKITINA	{"email": "svetlananikitina.06101977@postgrespro.ru", "phone": "+70897723239"}
0005434831273	640CD1	9052 238423	DENIS SIDOROV	{"phone": "+70570288273"}
0005434831274	8B4FDD	4866 409683	VLADIMIR GORBUNOV	{"email": "vladimir.gorbunov1963@postgrespro.ru", "phone": "+70111874698"}
0005434831275	8B4FDD	8778 314321	ELENA FEDOROVA	{"phone": "+70807180525"}
0005434831276	63182B	8288 824144	VALERIY KARPOV	{"email": "karpov_v-081960@postgrespro.ru", "phone": "+70540651966"}
0005434831277	69D2DB	7478 103868	ANASTASIYA PAVLOVA	{"email": "apavlova.16041986@postgrespro.ru", "phone": "+70478350119"}
0005434831278	487701	6529 500687	OKSANA EGOROVA	{"email": "egorova_o.31071971@postgrespro.ru", "phone": "+70310714787"}
0005434831279	487701	9621 231262	TATYANA ANTONOVA	{"phone": "+70246177810"}
0005434831280	56FB49	6923 056097	RIFAT DAVYDOV	{"phone": "+70988360711"}
0005434831281	7A8951	7655 625301	TAMARA TIMOFEEVA	{"email": "timofeeva_t-13071963@postgrespro.ru", "phone": "+70882741459"}
0005434831282	D80EA3	1815 679716	YULIYA ARKHIPOVA	{"email": "yuliya_arkhipova-13071965@postgrespro.ru", "phone": "+70930970216"}
0005434831283	130BC8	9996 784010	SERGEY VOLKOV	{"phone": "+70017703169"}
0005434831284	130BC8	6310 283180	SOFYA SEMENOVA	{"phone": "+70915041575"}
0005434831285	F263B5	5649 023072	SERGEY POPOV	{"email": "spopov_1978@postgrespro.ru", "phone": "+70084293797"}
0005434831286	635BDD	6053 603148	IRINA ANISIMOVA	{"phone": "+70975818679"}
0005434831287	65F3E0	5998 551571	NINA BOGDANOVA	{"email": "bogdanova.nina.1975@postgrespro.ru", "phone": "+70985480619"}
0005434831288	5148A1	2121 796592	TAMARA FEDOROVA	{"phone": "+70192509007"}
0005434831289	5148A1	7013 867916	IGOR MEDVEDEV	{"email": "medvedev.i071962@postgrespro.ru", "phone": "+70299203857"}
0005434831290	5148A1	0658 307260	ALEKSANDR KOZLOV	{"phone": "+70679942178"}
0005434876555	FDFC17	0206 036302	ANDREY ANDREEV	{"email": "andreev_andrey.1985@postgrespro.ru", "phone": "+70037602979"}
0005434876556	FDFC17	6144 160984	NATALYA CHERNOVA	{"phone": "+70286870630"}
0005434876557	6571DB	5785 187477	TATYANA DMITRIEVA	{"phone": "+70402362253"}
0005434876558	B5FFAA	6101 598046	OLEG KONOVALOV	{"email": "konovalov_o-26031977@postgrespro.ru", "phone": "+70278387687"}
0005434876559	8DB7B3	0643 747291	ELENA IVANOVA	{"phone": "+70529497724"}
0005434876560	BFFF44	5588 586110	MARGARITA FOMINA	{"email": "fomina-margarita-081975@postgrespro.ru", "phone": "+70994153871"}
0005434876561	BFFF44	0865 115825	ALINA ISAEVA	{"email": "isaeva-alina.1971@postgrespro.ru", "phone": "+70833906480"}
0005434876562	BFFF44	1737 428132	VYACHESLAV SEMENOV	{"phone": "+70862911684"}
0005434876563	503CCA	0820 690195	ILYA KUZNECOV	{"email": "kuznecovi.081960@postgrespro.ru", "phone": "+70414243550"}
0005434876564	503CCA	3858 375919	ANATOLIY BARANOV	{"email": "a-baranov-1978@postgrespro.ru", "phone": "+70619265810"}
0005434876565	2B9B49	9029 006303	KONSTANTIN CHERNOV	{"phone": "+70925619324"}
0005434876566	2B9B49	1655 831851	ANNA LEBEDEVA	{"phone": "+70865398113"}
0005434876567	861548	3749 879692	DMITRIY ZAKHAROV	{"email": "zakharov_d.111968@postgrespro.ru", "phone": "+70653162066"}
0005434876568	B06C38	2305 443687	VYACHESLAV MOROZOV	{"email": "morozovv-1967@postgrespro.ru", "phone": "+70223365623"}
0005434876569	8703DC	0988 688524	IGOR AFANASEV	{"email": "afanasev-i.071981@postgrespro.ru", "phone": "+70816854040"}
0005434876570	950D5E	6421 956682	OLGA GERASIMOVA	{"email": "o-gerasimova1972@postgrespro.ru", "phone": "+70720686359"}
0005434876571	D17086	3625 312086	YURIY SMIRNOV	{"phone": "+70213040719"}
0005434876572	5DD922	1727 006187	IGOR FILIPPOV	{"email": "filippov-i1970@postgrespro.ru", "phone": "+70703525183"}
0005434876573	9E5EFE	3455 419730	EVGENIYA PAVLOVA	{"email": "e_pavlova-23041964@postgrespro.ru", "phone": "+70741870698"}
0005434876574	0F4878	1612 420584	VLADISLAV PAVLOV	{"email": "vladislav-pavlov.111974@postgrespro.ru", "phone": "+70248764839"}
0005434876575	0F4878	4177 495958	ANASTASIYA ZHURAVLEVA	{"phone": "+70151436843"}
0005434876576	3F9A63	2704 935977	ANNA KOZLOVA	{"email": "kozlova-anna051962@postgrespro.ru", "phone": "+70020034117"}
0005434876577	42C3E5	1233 039350	NATALYA IVANOVA	{"email": "ivanovan1965@postgrespro.ru", "phone": "+70890237831"}
0005434876578	345265	9021 088630	VLADIMIR ZAKHAROV	{"phone": "+70909725659"}
0005434876579	500E78	8263 195197	GALINA POPOVA	{"email": "galinapopova.061974@postgrespro.ru", "phone": "+70176143290"}
0005434876580	500E78	2905 451968	NIKOLAY TARASOV	{"phone": "+70474974887"}
0005434876581	C04BE0	8830 543224	EDUARD NAZAROV	{"email": "nazarove.1975@postgrespro.ru", "phone": "+70160316122"}
0005434876582	C04BE0	3911 128802	VALERIY IVANOV	{"email": "valeriy.ivanov.12091967@postgrespro.ru", "phone": "+70445037202"}
0005434876583	3726D4	5502 870497	DMITRIY SIDOROV	{"email": "sidorovdmitriy26021967@postgrespro.ru", "phone": "+70987824538"}
0005434876584	DA3F08	6763 275118	RAISA MALYSHEVA	{"phone": "+70599722291"}
0005434876585	B4CE8F	1349 076054	ILFAT ABRAMOV	{"phone": "+70755549542"}
0005434876586	4DC164	5632 742213	POLINA MALYSHEVA	{"phone": "+70829735663"}
0005434876587	6F6AC2	0381 985049	ANDREY SEMENOV	{"email": "andrey-semenov_1972@postgrespro.ru", "phone": "+70942471876"}
0005434876588	A9E2E7	2993 097894	IRINA NESTEROVA	{"email": "i_nesterova-101980@postgrespro.ru", "phone": "+70804793409"}
0005434876589	98A065	2496 629437	MAKSIM KUDRYASHOV	{"phone": "+70592930031"}
0005434876590	98A065	4813 255607	VIKTOR DAVYDOV	{"phone": "+70220193569"}
0005434876591	98A065	0849 378091	TATYANA KOLESNIKOVA	{"email": "t.kolesnikova_11031966@postgrespro.ru", "phone": "+70783294367"}
0005434876592	EA9A57	8166 420045	TATYANA SEMENOVA	{"email": "tsemenova-30071975@postgrespro.ru", "phone": "+70671754677"}
0005434876593	EB1470	6299 212569	EVGENIY MAKSIMOV	{"email": "e_maksimov_011974@postgrespro.ru", "phone": "+70123090329"}
0005434876594	EB1470	3885 324720	ALEKSANDR KISELEV	{"email": "a_kiselev021973@postgrespro.ru", "phone": "+70506031122"}
0005434876595	24EC01	9225 376356	DMITRIY TIKHONOV	{"phone": "+70830785715"}
0005434876596	1AD308	9185 176369	ANATOLIY MIKHAYLOV	{"email": "a-mikhaylov_041979@postgrespro.ru", "phone": "+70157952181"}
0005434876597	8C2E06	4297 482167	MAKSIM IVANOV	{"email": "m.ivanov-24011979@postgrespro.ru", "phone": "+70603110257"}
0005434876598	797FF6	7272 370745	SOFYA ORLOVA	{"email": "sofya_orlova_1975@postgrespro.ru", "phone": "+70529452885"}
0005434876599	FD2589	6759 139464	ELENA PETROVA	{"email": "petrova_elena091976@postgrespro.ru", "phone": "+70828820974"}
0005434876600	FD2589	5963 008879	DANIIL STEPANOV	{"phone": "+70286302910"}
0005434876601	FD2589	9569 231677	VIKTOR FEDOTOV	{"email": "v-fedotov_19121974@postgrespro.ru", "phone": "+70328545530"}
0005434876602	A40940	1653 752597	VASILIY SCHERBAKOV	{"phone": "+70102528102"}
0005434876603	410A1B	8950 759606	VLADIMIR SOKOLOV	{"email": "sokolov-vladimir-24111976@postgrespro.ru", "phone": "+70905815311"}
0005434876604	2FC3D1	1525 608532	NATALYA RYABOVA	{"phone": "+70358342466"}
0005434876605	2FC3D1	6401 348309	ANDREY NIKOLAEV	{"phone": "+70581733500"}
0005434876606	807E8F	9869 292021	NADEZHDA ANDREEVA	{"email": "andreeva_n.101987@postgrespro.ru", "phone": "+70841528901"}
0005434876607	CF37BC	8581 177456	LARISA SOKOLOVA	{"email": "sokolova.larisa.22061982@postgrespro.ru", "phone": "+70490205412"}
0005434876608	73F1F4	3932 297287	PAVEL VOROBEV	{"email": "vorobev-pavel_24071971@postgrespro.ru", "phone": "+70311278944"}
0005434876609	323424	8751 500258	ELENA PAVLOVA	{"phone": "+70643824292"}
0005434876610	F1BEDC	1501 992497	ALEKSANDRA SAVELEVA	{"phone": "+70443294013"}
0005434876611	46754D	3928 959311	VLADIMIR NIKITIN	{"phone": "+70157956283"}
0005434876612	E2FE10	7763 558013	VLADIMIR DMITRIEV	{"phone": "+70684121804"}
0005434876613	DFCA5C	6481 512819	IRINA GAVRILOVA	{"email": "i_gavrilova011969@postgrespro.ru", "phone": "+70361028017"}
0005434876614	D143F9	6090 510052	YULIYA ZOTOVA	{"email": "yuliya.zotova05061965@postgrespro.ru", "phone": "+70681232275"}
0005434876615	6B1848	1092 975942	RUSLAN MIKHAYLOV	{"phone": "+70887632873"}
0005434876616	6B1848	8732 374249	VALENTINA ZHUKOVA	{"email": "v.zhukova-101973@postgrespro.ru", "phone": "+70868869275"}
0005434876617	0F897C	1807 137858	NATALYA KONDRATEVA	{"phone": "+70951521277"}
0005434876618	474530	9434 668624	IGOR DAVYDOV	{"email": "davydov_igor.041976@postgrespro.ru", "phone": "+70581945884"}
0005434876619	963A75	6111 142211	DMITRIY NIKITIN	{"phone": "+70880053370"}
0005434876620	A3D8A5	2375 655706	SERGEY GRIGOREV	{"phone": "+70852598624"}
0005434876621	A3D8A5	8794 244191	ANDREY POPOV	{"phone": "+70628189473"}
0005434876622	858F9F	0195 011110	RADIK NAUMOV	{"email": "naumov_radik_081974@postgrespro.ru", "phone": "+70399188806"}
0005434876623	A84C7E	8030 396268	VERA RODIONOVA	{"phone": "+70480708457"}
0005434876624	FC3ED4	6971 366568	SERGEY BORISOV	{"phone": "+70356181108"}
0005434876625	1D2E94	9322 134350	IRINA MARTYNOVA	{"email": "i.martynova.31051961@postgrespro.ru", "phone": "+70678358788"}
0005434876626	1D2E94	9381 854858	ELENA STEPANOVA	{"phone": "+70915325605"}
0005434876627	E36196	9599 015024	VYACHESLAV ROMANOV	{"email": "romanovvyacheslav_091973@postgrespro.ru", "phone": "+70989161805"}
0005434876628	E36196	6530 053298	VIKTOR TARASOV	{"email": "tarasovviktor-1974@postgrespro.ru", "phone": "+70836288336"}
0005434876629	56AB64	0730 565968	YULIYA GRISHINA	{"email": "grishinayuliya1964@postgrespro.ru", "phone": "+70603752180"}
0005434876630	9995DA	9049 449032	MARIYA ISAEVA	{"email": "isaeva.m-081961@postgrespro.ru", "phone": "+70794114984"}
0005434876631	138D6F	7025 104830	PAVEL ILIN	{"email": "pavelilin1971@postgrespro.ru", "phone": "+70038983621"}
0005434876632	740659	0686 802564	ANATOLIY BORISOV	{"phone": "+70891851302"}
0005434876633	6A50B0	7012 292024	TATYANA ANDREEVA	{"phone": "+70412284351"}
0005434876634	D57BF0	1998 064255	VALENTINA KRASNOVA	{"email": "vkrasnova-101983@postgrespro.ru", "phone": "+70888241001"}
0005434876635	DA2F04	0686 528454	GALINA SERGEEVA	{"phone": "+70303984814"}
0005434876636	CF9D6A	3516 683784	SVETLANA DMITRIEVA	{"email": "dmitrievasvetlana.041960@postgrespro.ru", "phone": "+70851131986"}
0005434876637	CF9D6A	7655 612077	IRINA TARASOVA	{"email": "tarasova-irina.1983@postgrespro.ru", "phone": "+70280415948"}
0005434876638	CF9D6A	6442 309703	VERA BELOVA	{"phone": "+70951631421"}
0005434876639	CF9D6A	0577 592660	TAMARA TIKHONOVA	{"email": "ttikhonova-27051963@postgrespro.ru", "phone": "+70077623326"}
0005434876640	AB4625	4552 493084	MARGARITA ANTONOVA	{"phone": "+70326388499"}
0005434876641	E5DF83	1473 981681	EKATERINA VASILEVA	{"phone": "+70576766434"}
0005434876642	52D41C	9150 482946	TATYANA LUKYANOVA	{"email": "tlukyanova_1967@postgrespro.ru", "phone": "+70706073439"}
0005434876643	EF1774	9560 014349	ALINA ALEKSEEVA	{"email": "alekseeva_a1969@postgrespro.ru", "phone": "+70778993479"}
0005434876644	B3199D	4401 666643	VLADISLAV ZAKHAROV	{"phone": "+70758800291"}
0005434876645	60A7CB	3490 450117	NATALYA KARPOVA	{"phone": "+70954753854"}
0005434876646	60A7CB	8300 965702	ALEKSANDR VOROBEV	{"email": "a-vorobev.26041982@postgrespro.ru", "phone": "+70897444066"}
0005434876647	3313FA	7543 442544	IGOR GUSEV	{"email": "gusev-i.22121980@postgrespro.ru", "phone": "+70092708988"}
0005434876648	3313FA	5269 383512	RAMILYA MOROZOVA	{"email": "morozova_ramilya_1953@postgrespro.ru", "phone": "+70784168140"}
0005434876649	35E59F	1168 195763	EKATERINA ZAKHAROVA	{"email": "zakharovae.021985@postgrespro.ru", "phone": "+70445954186"}
0005434876650	FCD09A	0190 829722	ALEKSANDR FROLOV	{"email": "frolov_aleksandr.05091972@postgrespro.ru", "phone": "+70394702019"}
0005434876651	B52F04	2455 406485	IGOR EGOROV	{"email": "egorov_igor031956@postgrespro.ru", "phone": "+70628701148"}
0005434876652	1EE358	1689 863109	ANDREY PETROV	{"email": "andrey-petrov081981@postgrespro.ru", "phone": "+70356098984"}
0005434876653	688471	2684 848999	OLGA RODIONOVA	{"phone": "+70471342149"}
0005434876654	72E4AC	5320 896876	GALINA KUZNECOVA	{"phone": "+70011603652"}
0005434876655	72E4AC	7179 562884	ANASTASIYA MASLOVA	{"phone": "+70918576628"}
0005434876656	84FEE7	5583 131788	LIDIYA KUZMINA	{"phone": "+70485810824"}
0005434876657	B2B82D	1394 028598	SVETLANA SOLOVEVA	{"phone": "+70512448023"}
0005434876658	2080AC	8797 721763	VASILIY KULIKOV	{"email": "v.kulikov.091964@postgrespro.ru", "phone": "+70669806663"}
0005434876659	1D0E45	6055 751477	NIKOLAY DAVYDOV	{"email": "davydov.n_1962@postgrespro.ru", "phone": "+70394060448"}
0005434876660	AA3CAF	9363 580817	ANTONIDA LEBEDEVA	{"email": "a.lebedeva-1965@postgrespro.ru", "phone": "+70438969337"}
0005434876661	AA3CAF	6473 216371	ALEKSEY PETROV	{"phone": "+70092914414"}
0005434876662	AA3CAF	9278 098539	LIDIYA PETROVA	{"phone": "+70887755609"}
0005434876663	B57920	5772 797362	VADIM SEMENOV	{"email": "semenov_v-1971@postgrespro.ru", "phone": "+70751842006"}
0005434876664	CACCB1	7448 713128	DMITRIY ALEKSEEV	{"email": "d_alekseev.28091968@postgrespro.ru", "phone": "+70387347419"}
0005434876665	76F875	7175 064731	SERGEY ZAYCEV	{"phone": "+70485861087"}
0005434876666	CD1E95	7346 261758	ANATOLIY BONDARENKO	{"email": "bondarenko-anatoliy.1969@postgrespro.ru", "phone": "+70458529010"}
0005434876667	DB9AD7	6610 380904	GRIGORIY GAVRILOV	{"email": "gavrilov.g.06011979@postgrespro.ru", "phone": "+70651223177"}
0005434876668	C275E3	5196 818560	ILYA KONOVALOV	{"phone": "+70359239612"}
0005434876669	C275E3	3439 130084	ANNA ALEKSANDROVA	{"email": "aleksandrovaanna-081964@postgrespro.ru", "phone": "+70874767315"}
0005434876670	48210E	6921 523086	VYACHESLAV PETROV	{"email": "petrov_vyacheslav_061972@postgrespro.ru", "phone": "+70013842708"}
0005434876671	48210E	6326 321261	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr_18121973@postgrespro.ru", "phone": "+70977753069"}
0005434876672	48210E	3379 762720	MARIYA KUZNECOVA	{"email": "kuznecova_m_061969@postgrespro.ru", "phone": "+70075977758"}
0005434876673	68538E	0574 276510	EKATERINA KONOVALOVA	{"phone": "+70637122404"}
0005434876674	68538E	4795 435729	VITALIY SERGEEV	{"email": "sergeev-v-1969@postgrespro.ru", "phone": "+70723559694"}
0005434876675	68538E	4384 376263	OLGA ANDREEVA	{"email": "o_andreeva_041976@postgrespro.ru", "phone": "+70015811326"}
0005434876676	216485	4514 421492	YANA MELNIKOVA	{"email": "yana-melnikova27011977@postgrespro.ru", "phone": "+70804575747"}
0005434876677	5E55A4	4380 659421	NADEZHDA NOVIKOVA	{"email": "novikova-n_1964@postgrespro.ru", "phone": "+70655231168"}
0005434876678	B27DCE	1185 557502	ANVAR BORISOV	{"email": "a-borisov-1963@postgrespro.ru", "phone": "+70108176766"}
0005434876679	782ACE	4512 671685	DMITRIY KUZNECOV	{"phone": "+70232834343"}
0005434876680	782ACE	9964 250066	LYUBOV MAKAROVA	{"phone": "+70430209372"}
0005434876681	200B2E	9425 890678	EVGENIY ROMANOV	{"email": "romanov-e-27111983@postgrespro.ru", "phone": "+70409747581"}
0005434876682	A77056	0361 228406	NINA ROMANOVA	{"email": "nromanova021973@postgrespro.ru", "phone": "+70812689957"}
0005434876683	54AB92	0029 927106	LYUDMILA ERMAKOVA	{"email": "ermakova-lyudmila02121978@postgrespro.ru", "phone": "+70989678486"}
0005434876684	AC2521	6337 887354	TATYANA KOROLEVA	{"email": "koroleva_t.19031978@postgrespro.ru", "phone": "+70857969531"}
0005434876685	26CD2D	9087 093060	OKSANA IVANOVA	{"email": "ivanova_o.1979@postgrespro.ru", "phone": "+70232449996"}
0005434876686	F5D5D0	6729 526716	VIKTOR KOZLOV	{"phone": "+70501299752"}
0005434876687	FAED90	8070 274105	ANTONINA NIKOLAEVA	{"email": "a_nikolaeva25021976@postgrespro.ru", "phone": "+70004374613"}
0005434876688	66ECD3	8148 794345	TATYANA MAKAROVA	{"phone": "+70081250269"}
0005434876689	8AB716	0352 449305	VASILIY ZAKHAROV	{"email": "vasiliy-zakharov.16051963@postgrespro.ru", "phone": "+70147601712"}
0005434876690	911081	7754 127397	OLGA VOLKOVA	{"email": "o_volkova-1969@postgrespro.ru", "phone": "+70242132775"}
0005434876691	FBFF88	8661 560033	GENNADIY ANTONOV	{"email": "gennadiy.antonov.17061967@postgrespro.ru", "phone": "+70572509779"}
0005434876692	4E7ED9	3476 664660	MARINA KUDRYASHOVA	{"email": "m.kudryashova.081980@postgrespro.ru", "phone": "+70885744891"}
0005434876693	B86C5A	6083 642731	ZUKHRA KOROLEVA	{"email": "koroleva.zukhra.1966@postgrespro.ru", "phone": "+70775790274"}
0005434876694	0CD9B2	5441 794414	LIDIYA IVANOVA	{"email": "l.ivanova_071975@postgrespro.ru", "phone": "+70441990565"}
0005434876695	5D11DD	6588 300986	ELENA EFIMOVA	{"phone": "+70696520601"}
0005434876696	F86E5B	1004 592146	ELENA FILIPPOVA	{"phone": "+70271207825"}
0005434876697	4A5A0A	2786 922265	DMITRIY ZAKHAROV	{"email": "zakharov-d28091982@postgrespro.ru", "phone": "+70498603627"}
0005434876698	723070	8066 520684	ANDREY EGOROV	{"email": "andrey-egorov091965@postgrespro.ru", "phone": "+70263641155"}
0005434876699	723070	9102 543427	NINA YUDINA	{"phone": "+70269569183"}
0005434876700	EC5836	3234 596104	EKATERINA EGOROVA	{"email": "e.egorova.071977@postgrespro.ru", "phone": "+70633956827"}
0005434876701	EC5836	3089 047211	ANDREY VASILEV	{"email": "andrey_vasilev25091965@postgrespro.ru", "phone": "+70990014273"}
0005434876702	FAD307	6889 464079	IRINA BELYAEVA	{"email": "i-belyaeva.1965@postgrespro.ru", "phone": "+70509720681"}
0005434876703	A03CB9	6712 564487	NATALYA STEPANOVA	{"email": "stepanova_natalya-03061975@postgrespro.ru", "phone": "+70257836679"}
0005434876704	A03CB9	4792 289933	ANNA TITOVA	{"phone": "+70192193163"}
0005434876705	6CAB01	3288 456682	NIKOLAY ALEKSEEV	{"phone": "+70780779661"}
0005434876706	FA20D3	8125 703742	ALEKSANDR SCHERBAKOV	{"phone": "+70727316785"}
0005434876707	FA20D3	8910 145593	DMITRIY SMIRNOV	{"phone": "+70667994052"}
0005434876708	E0CF6B	1607 278740	MARINA FADEEVA	{"email": "marina-fadeeva24051989@postgrespro.ru", "phone": "+70941295790"}
0005434876709	E0CF6B	9656 855619	MARIYA EGOROVA	{"email": "m_egorova-021979@postgrespro.ru", "phone": "+70209772715"}
0005434876710	BB9EAC	6564 326038	ELENA NAZAROVA	{"email": "nazarova.e121968@postgrespro.ru", "phone": "+70168295230"}
0005434876711	341EF1	3059 123248	ELENA ABRAMOVA	{"phone": "+70151048791"}
0005434876712	EB63CD	6242 000311	ALENA MOROZOVA	{"email": "amorozova_11121956@postgrespro.ru", "phone": "+70472324895"}
0005434876713	541149	7960 921732	VLADIMIR PETROV	{"phone": "+70590898830"}
0005434876714	541149	3895 420577	OLGA POLYAKOVA	{"email": "opolyakova.29081971@postgrespro.ru", "phone": "+70133438679"}
0005434876715	0026F8	8355 307130	SERGEY KOZLOV	{"email": "skozlov-1967@postgrespro.ru", "phone": "+70453920532"}
0005434876716	65978E	6334 556333	OLGA VLASOVA	{"email": "ovlasova-021970@postgrespro.ru", "phone": "+70169881141"}
0005434876717	D6FE78	4059 605156	ALEKSANDRA TARASOVA	{"phone": "+70360017845"}
0005434876718	979F9D	9360 880180	PAVEL KUZNECOV	{"phone": "+70244442498"}
0005434876719	6ED6D2	2358 791142	SERGEY EGOROV	{"phone": "+70596646733"}
0005434876720	6ED6D2	9308 945359	EKATERINA BORISOVA	{"email": "ekaterina_borisova.05071974@postgrespro.ru", "phone": "+70850372058"}
0005434876721	D93051	8288 284880	OLGA IVANOVA	{"phone": "+70486659758"}
0005434876722	2B29DA	5352 049479	YULIYA ERMAKOVA	{"email": "ermakova.y-091966@postgrespro.ru", "phone": "+70346250004"}
0005434876723	825E8C	0580 838376	KONSTANTIN KUZNECOV	{"email": "konstantin-kuznecov.121967@postgrespro.ru", "phone": "+70493213548"}
0005434876724	511B84	5129 850632	PETR BELOV	{"phone": "+70376903929"}
0005434876725	6E091D	7401 567033	NIKOLAY MIKHAYLOV	{"phone": "+70635228667"}
0005434876726	6E091D	0806 920546	VLADISLAV NAUMOV	{"email": "naumovvladislav-12021973@postgrespro.ru", "phone": "+70557852147"}
0005434876727	42FBEC	5589 681254	OLGA ANTONOVA	{"phone": "+70058888555"}
0005434876728	42FBEC	8250 620643	VLADIMIR POPOV	{"email": "v-popov28031967@postgrespro.ru", "phone": "+70708574235"}
0005434876729	84DFAA	3412 809814	LYUDMILA ZAYCEVA	{"email": "lyudmila_zayceva-09111974@postgrespro.ru", "phone": "+70329060546"}
0005434876730	84DFAA	7951 631121	OLEG KUZNECOV	{"phone": "+70800406014"}
0005434876731	C4503B	0735 267327	LYUDMILA SERGEEVA	{"email": "lsergeeva-111972@postgrespro.ru", "phone": "+70794561834"}
0005434876732	C4503B	1080 333833	NATALYA VOLKOVA	{"phone": "+70397126153"}
0005434876733	9A6373	5452 926793	NATALYA IVANOVA	{"email": "natalyaivanova_111975@postgrespro.ru", "phone": "+70271601834"}
0005434876734	9A6373	5175 026995	VADIM IVANOV	{"email": "ivanovv.121977@postgrespro.ru", "phone": "+70874594473"}
0005434876735	4B3388	5253 994292	RUSLAN MAKAROV	{"email": "r-makarov21031965@postgrespro.ru", "phone": "+70181290524"}
0005434876736	E64B8C	3653 579391	ALEKSANDR FILIPPOV	{"phone": "+70994833915"}
0005434876737	A12006	3739 825739	RAISA ALEKSANDROVA	{"phone": "+70951547281"}
0005434876738	A12006	2097 216334	LYUDMILA BELOVA	{"phone": "+70532608128"}
0005434876739	B97BF2	6326 114559	POLINA NAUMOVA	{"phone": "+70741381608"}
0005434876740	E362ED	6710 498060	SERGEY SIDOROV	{"phone": "+70128327638"}
0005434876741	8CBB39	3681 271532	SERGEY NIKOLAEV	{"phone": "+70087787798"}
0005434876742	8CBB39	8368 370194	NIKOLAY SCHERBAKOV	{"email": "n_scherbakov041965@postgrespro.ru", "phone": "+70053710824"}
0005434876743	8CBB39	7551 772268	SERGEY KISELEV	{"email": "s.kiselev.1960@postgrespro.ru", "phone": "+70904260208"}
0005434876744	8CBB39	4158 443075	ANTON MOISEEV	{"phone": "+70602145151"}
0005434876745	727263	9012 592944	FLYURA BORISOVA	{"email": "f-borisova-1974@postgrespro.ru", "phone": "+70028687581"}
0005434876746	A431D6	6434 810761	NADEZHDA SCHERBAKOVA	{"email": "scherbakovanadezhda_1977@postgrespro.ru", "phone": "+70256629586"}
0005434876747	20FDEA	6353 614301	ALLA ANDREEVA	{"email": "andreeva_a-1980@postgrespro.ru", "phone": "+70711234329"}
0005434876748	20FDEA	0275 868377	DMITRIY MIRONOV	{"email": "mironov_d1974@postgrespro.ru", "phone": "+70228595740"}
0005434876749	540B4A	7317 818261	TATYANA ALEKSEEVA	{"phone": "+70186749210"}
0005434876750	540B4A	6215 586108	IRINA BORISOVA	{"phone": "+70611334179"}
0005434876751	9E3139	7556 896812	VASILIY MAKAROV	{"phone": "+70233521860"}
0005434876752	6641C8	3143 225523	ELENA ANTONOVA	{"phone": "+70936095010"}
0005434876753	BD2ADC	4420 583998	ILYA VASILEV	{"phone": "+70848145423"}
0005434876754	E541F4	7956 435225	ALEKSANDR NAZAROV	{"email": "a-nazarov.081981@postgrespro.ru", "phone": "+70671684873"}
0005434876755	E0CA07	8771 616816	DENIS KUZMIN	{"phone": "+70769650850"}
0005434876756	6CAC9B	2443 020079	EKATERINA MATVEEVA	{"email": "matveevaekaterina.031973@postgrespro.ru", "phone": "+70573066849"}
0005434876757	6CE043	9198 078542	SVETLANA FROLOVA	{"email": "svetlana-frolova1964@postgrespro.ru", "phone": "+70569002209"}
0005434876758	6CE043	9720 071393	IGOR BORISOV	{"phone": "+70829036600"}
0005434876759	A29774	2143 550075	NIKOLAY SOROKIN	{"email": "nikolay.sorokin-051971@postgrespro.ru", "phone": "+70819176329"}
0005434876760	33E614	6349 393639	SERGEY KRASNOV	{"phone": "+70723671339"}
0005434876761	33E614	7038 712214	NINA AFANASEVA	{"email": "afanaseva.nina.23111974@postgrespro.ru", "phone": "+70742017657"}
0005434876762	DCBB7B	1820 180490	VLADIMIR EGOROV	{"email": "egorov-vladimir_051967@postgrespro.ru", "phone": "+70621996511"}
0005434876763	997076	3275 696038	SERGEY ZHURAVLEV	{"email": "s-zhuravlev07051968@postgrespro.ru", "phone": "+70996283208"}
0005434876764	997076	2002 853711	VIKTOR KUDRYASHOV	{"phone": "+70671295087"}
0005434876765	128BF4	1319 189221	IRINA DMITRIEVA	{"phone": "+70522837465"}
0005434876766	128BF4	7832 002880	ANDREY PETROV	{"email": "petrov-a18011974@postgrespro.ru", "phone": "+70137649611"}
0005434876767	B02183	8510 118465	VALENTIN SOROKIN	{"email": "valentin-sorokin1971@postgrespro.ru", "phone": "+70893638405"}
0005434876768	B02183	3611 684927	IRINA TIKHONOVA	{"email": "irina_tikhonova051975@postgrespro.ru", "phone": "+70777841439"}
0005434876769	CF4A79	0688 425241	NATALYA KRASNOVA	{"email": "krasnova.n_1972@postgrespro.ru", "phone": "+70100980254"}
0005434876770	576C2D	2504 345792	DMITRIY MELNIKOV	{"phone": "+70983873870"}
0005434876771	576C2D	1422 318349	VALERIY MIRONOV	{"phone": "+70884495447"}
0005434876772	E06EA1	1927 064620	VLADIMIR GORBUNOV	{"email": "gorbunov_vladimir_1971@postgrespro.ru", "phone": "+70880489186"}
0005434876773	B7798C	1581 719888	NIKOLAY VOLKOV	{"email": "volkovn_1983@postgrespro.ru", "phone": "+70143446742"}
0005434876774	B7798C	7434 792217	SVETLANA ROMANOVA	{"email": "s.romanova1980@postgrespro.ru", "phone": "+70595971259"}
0005434876775	B7798C	1861 819825	ALEKSANDR VASILEV	{"phone": "+70660505820"}
0005434876776	408908	9106 621261	VERONIKA EFREMOVA	{"phone": "+70308075655"}
0005434876777	7B1EC4	7933 081816	LYUBOV KOMAROVA	{"email": "lyubov_komarova25111969@postgrespro.ru", "phone": "+70776946546"}
0005434876778	2EBA1B	4380 797851	VALENTINA KOROLEVA	{"email": "valentina_koroleva-011969@postgrespro.ru", "phone": "+70791257133"}
0005434876779	75ED8D	0774 676398	DMITRIY ZHUKOV	{"email": "zhukov-dmitriy.03121964@postgrespro.ru", "phone": "+70750363386"}
0005434876780	75ED8D	4556 010367	EVGENIY NIKOLAEV	{"phone": "+70957926628"}
0005434876781	E1DFC4	6528 820392	NADEZHDA CHERNOVA	{"email": "chernova.n_031968@postgrespro.ru", "phone": "+70087885668"}
0005434876782	EAC869	6536 822882	YURIY MOROZOV	{"email": "morozovy-03091964@postgrespro.ru", "phone": "+70295987733"}
0005434876783	EAC869	8458 299591	ELENA MASLOVA	{"phone": "+70640118823"}
0005434876784	BCF8D0	4478 551957	SVETLANA PETROVA	{"email": "petrova.s-14091979@postgrespro.ru", "phone": "+70654259687"}
0005434876785	37C9D7	0191 745747	OKSANA BELYAEVA	{"email": "oksana-belyaeva_05101975@postgrespro.ru", "phone": "+70683176456"}
0005434876786	4D6AA2	8264 321469	ALEKSANDR SMIRNOV	{"email": "smirnov-a_1962@postgrespro.ru", "phone": "+70478682670"}
0005434876787	4D6AA2	3360 973069	ALEKSEY MIKHAYLOV	{"email": "mikhaylov-a071963@postgrespro.ru", "phone": "+70007537416"}
0005434876788	FEFCC7	6262 497482	NINA GERASIMOVA	{"email": "gerasimova.nina_27051976@postgrespro.ru", "phone": "+70112895864"}
0005434876789	FEFCC7	7419 455553	DENIS SEMENOV	{"phone": "+70675889462"}
0005434876790	BA9C1C	8526 824239	LYUDMILA TITOVA	{"email": "l-titova.1974@postgrespro.ru", "phone": "+70573306597"}
0005434876791	BA9C1C	2346 076533	VLADIMIR MELNIKOV	{"email": "v_melnikov-1977@postgrespro.ru", "phone": "+70154287014"}
0005434876792	94FF77	4729 390783	MARINA MIKHAYLOVA	{"phone": "+70591777331"}
0005434876793	8E8C81	2455 998259	OLGA DAVYDOVA	{"email": "davydova.o-031967@postgrespro.ru", "phone": "+70528254041"}
0005434876794	C53303	5698 820953	EKATERINA IVANOVA	{"phone": "+70641332187"}
0005434876795	8CDF90	7990 691932	NADEZHDA ISAEVA	{"email": "nadezhda_isaeva.01081968@postgrespro.ru", "phone": "+70869142842"}
0005434876796	03AAE4	9550 876697	SERGEY GAVRILOV	{"email": "sergey-gavrilov-11011973@postgrespro.ru", "phone": "+70552300401"}
0005434876797	ECAC21	8073 571078	NINA MAKAROVA	{"email": "makarovanina_101965@postgrespro.ru", "phone": "+70773385964"}
0005434876798	BAF0CD	4277 752593	ALEKSANDR NOVIKOV	{"phone": "+70038684883"}
0005434876799	0A0023	5575 864940	VALENTINA KOZLOVA	{"email": "kozlova_valentina.111970@postgrespro.ru", "phone": "+70526454725"}
0005434876800	3B2525	4739 591736	VIKTORIYA MELNIKOVA	{"phone": "+70040211171"}
0005434876801	F3809B	2555 466392	KIRILL IVANOV	{"phone": "+70414328715"}
0005434876802	F3809B	9252 119806	VLADIMIR MOROZOV	{"email": "vladimir.morozov.121969@postgrespro.ru", "phone": "+70223559357"}
0005434876803	D5B507	4425 068401	ZHANNA KALININA	{"phone": "+70630232114"}
0005434876804	529365	3679 645862	ELENA FADEEVA	{"email": "efadeeva-08121971@postgrespro.ru", "phone": "+70917593703"}
0005434876805	CC0D46	5134 321273	ALEKSEY MAKSIMOV	{"email": "maksimov.a.17101980@postgrespro.ru", "phone": "+70827543184"}
0005434876806	25E702	9967 068989	NADEZHDA SEMENOVA	{"email": "semenova.n04091973@postgrespro.ru", "phone": "+70557311221"}
0005434876807	1311D5	6730 492524	VITALIY KAZAKOV	{"phone": "+70687431478"}
0005434876808	3FE103	8709 965998	IRINA MAKSIMOVA	{"email": "irina_maksimova1966@postgrespro.ru", "phone": "+70169338921"}
0005434876809	5F0FD0	4695 666777	DMITRIY KUZNECOV	{"phone": "+70735655630"}
0005434876810	5F0FD0	1675 098941	VIKTOR VASILEV	{"phone": "+70821242457"}
0005434876811	4FCAC9	7563 038485	YURIY GRIGOREV	{"email": "grigorev_y1976@postgrespro.ru", "phone": "+70016990042"}
0005434876812	4FCAC9	6313 399324	ANASTASIYA MEDVEDEVA	{"phone": "+70862363894"}
0005434876813	5E1EE2	5915 347516	NIKOLAY ILIN	{"phone": "+70632464604"}
0005434876814	77A43A	2657 343237	MARIYA GUSEVA	{"phone": "+70349294707"}
0005434876815	77A43A	9400 335635	OLGA BORISOVA	{"email": "o-borisova_1967@postgrespro.ru", "phone": "+70706923338"}
0005434876816	77A43A	8655 841315	VITALIY SOROKIN	{"phone": "+70410571094"}
0005434876817	F71FBB	8134 796264	EVGENIY ZAYCEV	{"phone": "+70372933439"}
0005434876818	7DFBE1	6445 225202	MIKHAIL ZAKHAROV	{"email": "m.zakharov-17071973@postgrespro.ru", "phone": "+70901280569"}
0005434876819	3F647E	2296 361278	EVGENIYA YUDINA	{"email": "evgeniya.yudina.121977@postgrespro.ru", "phone": "+70794493416"}
0005434876820	3F647E	3460 324165	SERGEY BONDARENKO	{"phone": "+70675132994"}
0005434876821	0D40A8	6478 649613	LIDIYA FILIPPOVA	{"email": "lidiya_filippova-021970@postgrespro.ru", "phone": "+70604627030"}
0005434876822	F78BB9	9514 828674	ELENA MOROZOVA	{"phone": "+70289171930"}
0005434876823	F78BB9	9383 421753	ALEKSANDR FROLOV	{"phone": "+70963002742"}
0005434876824	F78BB9	2409 064359	NIKOLAY ISAEV	{"phone": "+70432737454"}
0005434876825	CF5511	3811 214218	IGOR NOVIKOV	{"email": "novikov-i-27071969@postgrespro.ru", "phone": "+70422760077"}
0005434876826	CF5511	1558 172477	OLEG BARANOV	{"email": "o_baranov-041965@postgrespro.ru", "phone": "+70627360188"}
0005434876827	5F5B6E	7493 867018	VLADIMIR MELNIKOV	{"email": "v-melnikov-24121970@postgrespro.ru", "phone": "+70482323000"}
0005434876828	0493EB	3319 356597	YANA SOROKINA	{"email": "sorokina.yana.061975@postgrespro.ru", "phone": "+70207196918"}
0005434876829	0493EB	7205 614225	ALLA MIRONOVA	{"email": "mironova_alla_1970@postgrespro.ru", "phone": "+70865820246"}
0005434876830	0493EB	3244 765224	VLADIMIR NIKITIN	{"phone": "+70439614851"}
0005434876831	C8A964	5655 631654	ALEKSEY PETROV	{"email": "alekseypetrov1970@postgrespro.ru", "phone": "+70248746490"}
0005434876832	C8A964	6048 179514	ANASTASIYA ZAKHAROVA	{"email": "zakharova_a041984@postgrespro.ru", "phone": "+70572362794"}
0005434876833	C8A964	7534 277946	NATALYA FILATOVA	{"email": "natalyafilatova.1968@postgrespro.ru", "phone": "+70303715103"}
0005434876834	5F4EA0	8186 479518	VIKTORIYA ZAYCEVA	{"phone": "+70877844020"}
0005434876835	1B54D7	8119 620979	ELENA POPOVA	{"email": "popova-e1973@postgrespro.ru", "phone": "+70188477205"}
0005434876836	04311E	7853 882532	ELENA TROFIMOVA	{"phone": "+70067747560"}
0005434876837	C77828	1414 042263	ANTONINA ORLOVA	{"phone": "+70234056361"}
0005434876838	C77828	0671 712424	MARIYA LAZAREVA	{"email": "lazareva-m-021971@postgrespro.ru", "phone": "+70928984786"}
0005434876839	2A1B1D	5266 870781	SVETLANA ORLOVA	{"email": "sorlova_24091964@postgrespro.ru", "phone": "+70469907909"}
0005434876840	321247	7071 277758	SABINA SEMENOVA	{"phone": "+70219399129"}
0005434876841	D03A35	9831 112426	ANNA IVANOVA	{"email": "a-ivanova_081974@postgrespro.ru", "phone": "+70868571226"}
0005434876842	5D1736	1282 210849	MARIYA POPOVA	{"phone": "+70193524888"}
0005434876843	2D9A49	9441 329236	GALINA BORISOVA	{"phone": "+70967310904"}
0005434876844	2D9A49	8836 218180	ELENA GERASIMOVA	{"email": "elenagerasimova041977@postgrespro.ru", "phone": "+70671937772"}
0005434876845	720943	0042 207208	ANTONINA KOROLEVA	{"phone": "+70505349933"}
0005434876846	720943	9967 327523	ALEKSANDR BARANOV	{"phone": "+70021162787"}
0005434876847	23D7C7	2209 403112	EVGENIYA DENISOVA	{"phone": "+70905655497"}
0005434876848	0B7ABD	8983 512960	GALINA ROMANOVA	{"phone": "+70016483854"}
0005434876849	0B7ABD	6896 286724	ALINA KOROLEVA	{"phone": "+70491290632"}
0005434876850	3F923B	6005 936322	MIKHAIL SAVELEV	{"phone": "+70076650618"}
0005434876851	529E70	5128 534407	OLEG MAKAROV	{"phone": "+70633501143"}
0005434876852	529E70	0614 165134	ANDREY KOZLOV	{"email": "akozlov-021965@postgrespro.ru", "phone": "+70842555980"}
0005434876853	FEF329	3457 771970	SHAMIL NAUMOV	{"phone": "+70909721974"}
0005434876854	FEF329	4587 443258	LYUDMILA NESTEROVA	{"phone": "+70727627472"}
0005434876855	DB5AB6	1291 341261	VYACHESLAV BELOV	{"email": "v_belov-031970@postgrespro.ru", "phone": "+70746506998"}
0005434876856	1E2283	5317 357248	ALEKSEY GAVRILOV	{"phone": "+70214096036"}
0005434876857	05DD2B	7000 269982	SEMEN OSIPOV	{"phone": "+70816442654"}
0005434876858	8CFD70	8467 967272	EVGENIY GUSEV	{"email": "egusev-22121963@postgrespro.ru", "phone": "+70339126431"}
0005434876859	8CFD70	9851 756864	YULIYA NIKOLAEVA	{"email": "yuliyanikolaeva.29041964@postgrespro.ru", "phone": "+70221037926"}
0005434876860	B20F25	9086 368106	ELENA IVANOVA	{"email": "ivanova-elena_07011968@postgrespro.ru", "phone": "+70522524190"}
0005434876861	851EDE	0637 157387	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova.1976@postgrespro.ru", "phone": "+70179565697"}
0005434876862	851EDE	4003 984149	YULIYA NAUMOVA	{"phone": "+70078927923"}
0005434876863	77F7A4	9445 568022	IVAN KAZAKOV	{"email": "ikazakov-07081973@postgrespro.ru", "phone": "+70209949547"}
0005434876864	77F7A4	4601 163060	IRINA ZHURAVLEVA	{"phone": "+70088076910"}
0005434876865	B0DB42	3961 283498	RUFIYA DANILOVA	{"email": "r_danilova1971@postgrespro.ru", "phone": "+70336286311"}
0005434876866	B10C6C	5078 997930	ALEKSEY ZAKHAROV	{"phone": "+70761440025"}
0005434876867	266BF9	0748 851900	EKATERINA MALYSHEVA	{"phone": "+70625665661"}
0005434876868	824A68	6987 736225	VALENTINA TROFIMOVA	{"email": "trofimova.v12051974@postgrespro.ru", "phone": "+70677824827"}
0005434876869	824A68	0939 998067	LIDIYA FEDOROVA	{"phone": "+70606319526"}
0005434876870	4CA00A	6839 728318	MARIYA KUZNECOVA	{"phone": "+70727754045"}
0005434876871	24519E	5995 960126	RIMA FROLOVA	{"phone": "+70729868930"}
0005434876872	9EE94C	9453 870342	ELENA KUZNECOVA	{"email": "kuznecova.elena-121964@postgrespro.ru", "phone": "+70749671119"}
0005434876873	42A18F	9344 569583	ALEKSANDR SOROKIN	{"phone": "+70384512479"}
0005434876874	22048B	5939 353201	ALEKSANDRA SCHERBAKOVA	{"phone": "+70244994033"}
0005434876875	2B08E1	5307 829350	EKATERINA IVANOVA	{"phone": "+70460593102"}
0005434876876	2B08E1	5662 331950	DMITRIY BONDARENKO	{"email": "bondarenko-dmitriy.06031972@postgrespro.ru", "phone": "+70390007967"}
0005434876877	EC1C88	1629 468164	ALEKSEY SCHERBAKOV	{"email": "ascherbakov10051974@postgrespro.ru", "phone": "+70122535984"}
0005434876878	A89B68	9670 575859	VLADIMIR IVANOV	{"email": "ivanov.vladimir081984@postgrespro.ru", "phone": "+70001983874"}
0005434876879	FA6187	4860 014539	EVGENIY GRIGOREV	{"phone": "+70856655643"}
0005434876880	56427B	1537 728140	VASILISA SEMENOVA	{"email": "semenova-vasilisa-13021974@postgrespro.ru", "phone": "+70839365735"}
0005434876881	56427B	5464 773024	ALEKSANDR FEDOTOV	{"email": "aleksandr_fedotov.28011967@postgrespro.ru", "phone": "+70987722039"}
0005434876882	56427B	4537 743441	VLADISLAV SIDOROV	{"email": "sidorovvladislav111975@postgrespro.ru", "phone": "+70580109569"}
0005434876883	0BB06A	3563 147932	ALEKSEY ROMANOV	{"email": "aromanov.28121968@postgrespro.ru", "phone": "+70606929499"}
0005434876884	0BB06A	7102 153590	NIKOLAY VASILEV	{"email": "vasilev_nikolay.061972@postgrespro.ru", "phone": "+70678451080"}
0005434876885	1FF8F1	9121 899051	EKATERINA IVANOVA	{"email": "ekaterinaivanova.1985@postgrespro.ru", "phone": "+70801714084"}
0005434876886	A120B1	2555 458447	STANISLAV RODIONOV	{"phone": "+70488025815"}
0005434876887	B88222	6789 521858	SERGEY MATVEEV	{"email": "matveev.s-101970@postgrespro.ru", "phone": "+70531918132"}
0005434876888	B88222	0084 238327	IGOR POPOV	{"email": "popov_igor27011970@postgrespro.ru", "phone": "+70139535175"}
0005434876889	10DA95	0320 735068	STANISLAV SIDOROV	{"email": "stanislav.sidorov_1986@postgrespro.ru", "phone": "+70737740912"}
0005434876890	268A63	5947 757430	GENNADIY STEPANOV	{"email": "stepanovg1972@postgrespro.ru", "phone": "+70743573078"}
0005434876891	268A63	7242 358574	IGOR KUZNECOV	{"email": "ikuznecov_051979@postgrespro.ru", "phone": "+70320609294"}
0005434876892	19FD6C	7235 393519	NADEZHDA KISELEVA	{"email": "nadezhda-kiseleva-111974@postgrespro.ru", "phone": "+70791748730"}
0005434876893	19FD6C	5790 890408	NATALIYA YAKOVLEVA	{"phone": "+70164865054"}
0005434876894	92312D	0196 655722	VLADIMIR MAKAROV	{"email": "vladimirmakarov23061979@postgrespro.ru", "phone": "+70493984137"}
0005434876895	92312D	0293 853230	NADEZHDA ZAKHAROVA	{"phone": "+70637757787"}
0005434876896	79AFDC	1488 936982	KLAVDIYA PETROVA	{"phone": "+70265015649"}
0005434876897	CACBD4	5381 393393	ANNA KRASNOVA	{"email": "krasnova-a_30061971@postgrespro.ru", "phone": "+70545289098"}
0005434876898	5A53FA	5074 089177	MARIYA VOROBEVA	{"phone": "+70170263421"}
0005434876899	5A53FA	5512 732773	IRINA KONDRATEVA	{"phone": "+70307567559"}
0005434876900	6464C7	0417 671810	EVGENIY VOROBEV	{"phone": "+70364331016"}
0005434876901	14A277	7724 338358	VALENTINA ANDREEVA	{"email": "andreevavalentina_09051970@postgrespro.ru", "phone": "+70100255857"}
0005434876902	E13176	2818 144989	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr-1965@postgrespro.ru", "phone": "+70906765172"}
0005434876903	035E33	0524 498293	EVGENIY KUZNECOV	{"phone": "+70594577694"}
0005434877129	F68F56	4914 166935	NIKOLAY RODIONOV	{"phone": "+70481811088"}
0005434876904	035E33	1870 835669	NINA LOGINOVA	{"email": "loginova.nina1966@postgrespro.ru", "phone": "+70797366971"}
0005434876905	7CFCEE	6892 302210	GLEB ZAKHAROV	{"email": "gzakharov_041978@postgrespro.ru", "phone": "+70303233271"}
0005434876906	7CFCEE	7497 308912	VLADIMIR GERASIMOV	{"phone": "+70041329067"}
0005434876907	CDD3E0	4660 846940	EKATERINA LUKYANOVA	{"phone": "+70158018077"}
0005434876908	848601	5605 925813	GALINA KOLESNIKOVA	{"email": "galina-kolesnikova.1983@postgrespro.ru", "phone": "+70390952637"}
0005434876909	5F2161	4511 280855	TATYANA KOROLEVA	{"phone": "+70958257244"}
0005434876910	EDF300	7641 226981	ELVIRA VLASOVA	{"email": "vlasovae.101973@postgrespro.ru", "phone": "+70223850076"}
0005434876911	EC594F	0332 298886	VYACHESLAV SCHERBAKOV	{"email": "vyacheslav-scherbakov-16051974@postgrespro.ru", "phone": "+70946931599"}
0005434876912	9E488E	7545 815816	IRINA NAZAROVA	{"email": "nazarova_i_20091961@postgrespro.ru", "phone": "+70784206256"}
0005434876913	9E488E	9692 630678	DMITRIY GUSEV	{"email": "gusev_d091977@postgrespro.ru", "phone": "+70595853312"}
0005434876914	9E488E	0014 252399	VALERIY ROMANOV	{"phone": "+70491711580"}
0005434876915	C49C8A	5584 804914	NIKOLAY POPOV	{"email": "popov-nikolay021974@postgrespro.ru", "phone": "+70521971673"}
0005434876916	FDD0F0	0228 453493	ANDREY STEPANOV	{"phone": "+70875541593"}
0005434876917	FDFBD9	7571 907569	ALEKSANDR RODIONOV	{"email": "rodionov.a_111970@postgrespro.ru", "phone": "+70984903469"}
0005434876918	3CCD12	8144 227132	VERA KUZNECOVA	{"email": "vera_kuznecova_071968@postgrespro.ru", "phone": "+70679406882"}
0005434876919	0F164C	1557 888198	SAMVEL GERASIMOV	{"phone": "+70420273587"}
0005434876920	283642	8409 376578	NADEZHDA KOLESNIKOVA	{"phone": "+70433846905"}
0005434876921	91FC67	4487 280271	EVGENIYA POPOVA	{"phone": "+70837165157"}
0005434876922	FC2E52	5420 039500	YURIY FROLOV	{"phone": "+70543357024"}
0005434876923	71E559	9877 812135	NATALYA ALEKSEEVA	{"phone": "+70616298926"}
0005434876924	8BB06E	1854 424787	OLGA DMITRIEVA	{"email": "dmitrieva-olga.011976@postgrespro.ru", "phone": "+70976613656"}
0005434876925	A238FF	8261 715424	DMITRIY STEPANOV	{"phone": "+70482238239"}
0005434876926	FECD82	4197 385870	IVAN SHEVCHENKO	{"phone": "+70347529726"}
0005434876927	86CF56	6684 604713	ARINA KOZLOVA	{"email": "akozlova_031972@postgrespro.ru", "phone": "+70184907124"}
0005434876928	86CF56	2645 827464	POLINA TARASOVA	{"phone": "+70404882414"}
0005434876929	5B8C75	8687 841579	RAIL ABRAMOV	{"phone": "+70286912441"}
0005434876930	2DF419	4855 623798	NATALYA ZAKHAROVA	{"email": "natalya-zakharova-16101980@postgrespro.ru", "phone": "+70682947997"}
0005434876931	2DF419	2736 632535	LIDIYA MARTYNOVA	{"email": "martynovalidiya1987@postgrespro.ru", "phone": "+70845457770"}
0005434876932	BA6498	0379 090639	MIKHAIL NIKOLAEV	{"email": "m_nikolaev011975@postgrespro.ru", "phone": "+70601325206"}
0005434876933	BA6498	0761 558790	ARINA BELOVA	{"phone": "+70289143197"}
0005434876934	F3D42F	4433 984128	ELENA ANTONOVA	{"email": "elena_antonova.031968@postgrespro.ru", "phone": "+70218900971"}
0005434876935	FD01DD	0680 182806	ELENA ZAKHAROVA	{"email": "e.zakharova-04101977@postgrespro.ru", "phone": "+70088195033"}
0005434876936	A1FC7E	1140 069302	NATALYA KARPOVA	{"phone": "+70620285626"}
0005434876937	4E3CBC	5425 624306	ALEKSANDR CHERNOV	{"email": "aleksandrchernov_13011970@postgrespro.ru", "phone": "+70281479135"}
0005434876938	730833	0503 513658	ANNA FROLOVA	{"phone": "+70398911587"}
0005434876939	730833	4647 347447	ANATOLIY KISELEV	{"email": "kiseleva1973@postgrespro.ru", "phone": "+70748399707"}
0005434876940	894305	0429 122577	OLGA TARASOVA	{"phone": "+70392259173"}
0005434876941	894305	8356 478583	GALINA ILINA	{"email": "galinailina.101966@postgrespro.ru", "phone": "+70263711858"}
0005434876942	6AD117	0495 588731	LYUBOV ISAEVA	{"email": "isaeva.l.041963@postgrespro.ru", "phone": "+70253134825"}
0005434876943	3EE6FC	5406 558768	POLINA BOGDANOVA	{"phone": "+70724177151"}
0005434876944	A4975C	0182 103966	EGOR SMIRNOV	{"phone": "+70722149529"}
0005434876945	C4DB78	9264 452738	OLEG KUZNECOV	{"email": "oleg_kuznecov.1971@postgrespro.ru", "phone": "+70058994756"}
0005434876946	823AEB	8215 772428	VALENTINA SOROKINA	{"email": "sorokina_v-27031994@postgrespro.ru", "phone": "+70933952619"}
0005434876947	F48CEB	0520 834356	VLADISLAV MEDVEDEV	{"email": "medvedev_v1984@postgrespro.ru", "phone": "+70902202455"}
0005434876948	F48CEB	0046 155039	DMITRIY SOROKIN	{"email": "d_sorokin_011982@postgrespro.ru", "phone": "+70420992742"}
0005434876949	110A10	1768 654815	DMITRIY KULIKOV	{"email": "d.kulikov.021980@postgrespro.ru", "phone": "+70511708284"}
0005434876950	852913	0333 457158	ALEKSANDR KUZNECOV	{"phone": "+70453613633"}
0005434876951	8EC2A2	1158 421101	MATVEY FROLOV	{"email": "frolov_m.041961@postgrespro.ru", "phone": "+70586320329"}
0005434876952	8EC2A2	8230 168904	SVETLANA MIRONOVA	{"email": "s.mironova_1976@postgrespro.ru", "phone": "+70227241383"}
0005434876953	F0E63A	1282 897736	EKATERINA ANTONOVA	{"phone": "+70780881184"}
0005434876954	8D6A64	8842 032753	NATALYA POPOVA	{"phone": "+70029799597"}
0005434876955	91B39D	0437 082439	RAISA GORBUNOVA	{"email": "raisa.gorbunova_1974@postgrespro.ru", "phone": "+70059595346"}
0005434876956	91B39D	2733 166289	NATALYA KUZNECOVA	{"email": "kuznecova.natalya_051970@postgrespro.ru", "phone": "+70721917099"}
0005434876957	B1000F	0692 812323	GALINA KUZNECOVA	{"email": "galina.kuznecova.1976@postgrespro.ru", "phone": "+70183814475"}
0005434876958	5F4E81	8110 241400	ARTEM NIKITIN	{"phone": "+70042471182"}
0005434876959	5F4E81	8530 034592	VALERIY KUZNECOV	{"phone": "+70920425348"}
0005434876960	D6CB2F	9766 868208	OLGA NIKIFOROVA	{"email": "olga.nikiforova_19061973@postgrespro.ru", "phone": "+70622056451"}
0005434876961	4C7A5B	7695 523966	MARINA GERASIMOVA	{"email": "m-gerasimova-111976@postgrespro.ru", "phone": "+70642402933"}
0005434876962	4C7A5B	4474 723683	VALERIY VOROBEV	{"email": "v-vorobev12081974@postgrespro.ru", "phone": "+70740041897"}
0005434876963	4C7A5B	5565 679405	VITALIY TIMOFEEV	{"phone": "+70069981061"}
0005434876964	4DEBC6	9505 047340	NIKOLAY GERASIMOV	{"email": "n_gerasimov-021964@postgrespro.ru", "phone": "+70049041116"}
0005434876965	3FE4B4	5549 104259	SERGEY ILIN	{"email": "ilin_sergey_111982@postgrespro.ru", "phone": "+70076681445"}
0005434876966	3FE4B4	1267 315821	ANASTASIYA DANILOVA	{"email": "a_danilova.061971@postgrespro.ru", "phone": "+70364523938"}
0005434876967	7D315E	7273 800098	SERGEY SCHERBAKOV	{"phone": "+70248919481"}
0005434876968	627E1A	1840 487256	SERGEY FEDOROV	{"email": "s.fedorov081968@postgrespro.ru", "phone": "+70326287718"}
0005434876969	C1B633	0992 597236	ANASTASIYA MAKAROVA	{"email": "a_makarova-1969@postgrespro.ru", "phone": "+70675453520"}
0005434876970	6D1119	8582 803359	ALEKSANDR GRIGOREV	{"phone": "+70612362651"}
0005434876971	06B892	7554 902868	ANATOLIY NIKOLAEV	{"email": "anikolaev_1979@postgrespro.ru", "phone": "+70743768314"}
0005434876972	F07206	3558 216299	IRINA POLYAKOVA	{"email": "polyakova-irina071967@postgrespro.ru", "phone": "+70352784271"}
0005434876973	F07206	1612 062780	IRINA GORBUNOVA	{"phone": "+70889943478"}
0005434876974	203090	4063 975101	SERGEY NIKOLAEV	{"phone": "+70859619073"}
0005434876975	D1E7C4	0657 148088	VLADIMIR OSIPOV	{"phone": "+70640584516"}
0005434876976	A518AD	6810 472557	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir_01051981@postgrespro.ru", "phone": "+70316525536"}
0005434876977	8921B4	1811 178457	TATYANA PAVLOVA	{"email": "tpavlova_091960@postgrespro.ru", "phone": "+70646375335"}
0005434876978	8921B4	5437 367373	MIKHAIL PETROV	{"email": "petrovmikhail.04031966@postgrespro.ru", "phone": "+70687526420"}
0005434876979	6C0AFA	1948 666438	MIKHAIL NOVIKOV	{"phone": "+70480770590"}
0005434876980	2508D8	0379 057719	SOFIYA POPOVA	{"email": "popova_sofiya1975@postgrespro.ru", "phone": "+70056180380"}
0005434876981	9E4D4D	3368 952214	DMITRIY POPOV	{"phone": "+70392464509"}
0005434876982	ECE81A	8076 571169	IRINA SMIRNOVA	{"email": "irina_smirnova_18061980@postgrespro.ru", "phone": "+70657521954"}
0005434876983	B2E79A	1236 533553	VALENTINA ABRAMOVA	{"phone": "+70745750818"}
0005434877519	DC06F2	6043 599087	MIKHAIL NIKITIN	{"phone": "+70502543964"}
0005434876984	9CE949	4457 773802	ANTON KOZLOV	{"email": "kozlov.anton-21101967@postgrespro.ru", "phone": "+70025628289"}
0005434876985	F5B9EF	2119 123408	TATYANA MIRONOVA	{"phone": "+70789486625"}
0005434876986	D5D58E	6351 034568	TATYANA ISAEVA	{"phone": "+70154065487"}
0005434876987	0A3E9E	4175 143003	OLGA ZAKHAROVA	{"email": "zakharova-o-19031967@postgrespro.ru", "phone": "+70350552372"}
0005434876988	B555F4	0763 345700	GALINA EGOROVA	{"phone": "+70124273670"}
0005434876989	B555F4	5964 512781	ALEKSANDR ALEKSEEV	{"email": "a.alekseev-1961@postgrespro.ru", "phone": "+70373958140"}
0005434876990	B555F4	8973 458792	IGOR SAVELEV	{"email": "isavelev.14091966@postgrespro.ru", "phone": "+70037402099"}
0005434876991	5DC29B	5321 555010	FARIDA KUDRYASHOVA	{"email": "faridakudryashova10071972@postgrespro.ru", "phone": "+70953950395"}
0005434876992	53B52B	5175 201263	MARINA VOLKOVA	{"email": "volkovamarina18061976@postgrespro.ru", "phone": "+70303637103"}
0005434876993	53B52B	2640 234025	FARIT MOROZOV	{"phone": "+70325514921"}
0005434876994	8E0C6E	1230 673193	SOFYA KOZLOVA	{"phone": "+70892018623"}
0005434876995	CC51E6	7947 365832	VYACHESLAV BARANOV	{"email": "baranovvyacheslav1967@postgrespro.ru", "phone": "+70637107780"}
0005434876996	EEE024	1017 998459	NATALIYA KOMAROVA	{"phone": "+70205867651"}
0005434876997	E86B43	9175 435345	NATALYA ALEKSEEVA	{"phone": "+70345164126"}
0005434876998	E86B43	5805 034116	NIKOLAY KUZNECOV	{"email": "kuznecov.n_30121975@postgrespro.ru", "phone": "+70764528508"}
0005434876999	33A517	0771 235372	SERGEY KUZNECOV	{"email": "kuznecovsergey.1974@postgrespro.ru", "phone": "+70071276958"}
0005434877000	E7A5F7	7758 008982	NATALYA POPOVA	{"email": "popova.n_101957@postgrespro.ru", "phone": "+70293152148"}
0005434877001	E7A5F7	6785 573260	PAVEL KARPOV	{"email": "karpovp-26021973@postgrespro.ru", "phone": "+70342969707"}
0005434877002	69ECCF	1725 858623	NATALYA VOROBEVA	{"email": "vorobeva.natalya30111977@postgrespro.ru", "phone": "+70128781842"}
0005434877003	A4A3FA	2922 469837	NIKOLAY IVANOV	{"phone": "+70790101389"}
0005434877004	47FD7F	5696 990899	LYUDMILA KUZNECOVA	{"phone": "+70870673344"}
0005434877005	47FD7F	7019 488192	NIKOLAY KUZMIN	{"phone": "+70395345917"}
0005434877006	8A803A	4668 725476	ANASTASIYA IVANOVA	{"email": "ivanova.anastasiya091973@postgrespro.ru", "phone": "+70147049850"}
0005434877007	B63A18	0123 737017	VALENTINA OSIPOVA	{"phone": "+70031280911"}
0005434877008	2BF4A6	2722 285944	DMITRIY SERGEEV	{"phone": "+70817501415"}
0005434877009	2BF4A6	9854 548072	ELENA KUZMINA	{"phone": "+70901005954"}
0005434877010	D3EAEA	1738 468279	ANDREY MOISEEV	{"email": "a_moiseev.071967@postgrespro.ru", "phone": "+70455935724"}
0005434877011	76E764	7403 032606	MARINA KUZMINA	{"email": "kuzmina-marina-1967@postgrespro.ru", "phone": "+70771384986"}
0005434877012	76E764	8049 014500	VYACHESLAV KISELEV	{"email": "kiselev-v_1969@postgrespro.ru", "phone": "+70847561075"}
0005434877013	76E764	1361 305440	YAN IVANOV	{"email": "ivanov.yan-21121974@postgrespro.ru", "phone": "+70568021008"}
0005434877014	9586CA	7392 879684	TIMUR IVANOV	{"phone": "+70078952027"}
0005434877015	8CA7D4	5440 679615	VYACHESLAV IVANOV	{"email": "ivanov-v.071970@postgrespro.ru", "phone": "+70873064825"}
0005434877016	8CA7D4	7634 496675	ALEKSEY KUZMIN	{"phone": "+70606677121"}
0005434877017	FFDE7D	2516 356532	IRINA POLYAKOVA	{"phone": "+70502941892"}
0005434877018	F8E89F	4279 992986	VLADIMIR POPOV	{"email": "popov_vladimir1965@postgrespro.ru", "phone": "+70356241277"}
0005434877019	833E18	7668 124447	ANNA KOROLEVA	{"phone": "+70751596027"}
0005434877020	833E18	9768 768705	ALEKSEY MIRONOV	{"phone": "+70141315777"}
0005434877021	B0351A	8247 401152	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-t.051977@postgrespro.ru", "phone": "+70536438055"}
0005434877022	EA8406	8385 389481	VLADIMIR KARPOV	{"email": "karpov.v-18121974@postgrespro.ru", "phone": "+70827475450"}
0005434877023	65D22F	5845 893120	IGOR BARANOV	{"phone": "+70360612407"}
0005434877024	2F2C08	2509 859726	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr-051975@postgrespro.ru", "phone": "+70786057795"}
0005434877025	2F2C08	6588 100999	NIKITA MAKSIMOV	{"phone": "+70032887999"}
0005434877026	2F2C08	3659 590903	SERGEY BELOV	{"email": "sergeybelov.111971@postgrespro.ru", "phone": "+70117258208"}
0005434877027	0EE8CF	4135 677064	DMITRIY VOLKOV	{"email": "volkovdmitriy-111964@postgrespro.ru", "phone": "+70950805064"}
0005434877028	5D5F2B	5058 673669	VITALIY KOZLOV	{"phone": "+70303349337"}
0005434877029	5D5F2B	0887 007513	MARIYA OSIPOVA	{"phone": "+70281641065"}
0005434877030	5176F0	4767 414497	ANNA ERMAKOVA	{"phone": "+70493295930"}
0005434877031	6C8032	7217 805661	PRASKOVYA BORISOVA	{"email": "borisova.p_021974@postgrespro.ru", "phone": "+70169617586"}
0005434877032	B0CA8D	3021 701318	GALINA ZAKHAROVA	{"phone": "+70574143466"}
0005434877033	B0CA8D	8060 921214	NATALYA ALEKSEEVA	{"phone": "+70435090493"}
0005434877034	17D34B	7455 573569	VITALIY PETROV	{"phone": "+70233468435"}
0005434877035	17D34B	3142 034949	MIKHAIL FEDOROV	{"phone": "+70107638766"}
0005434877036	17D34B	6464 957256	EGOR VOLKOV	{"phone": "+70419288845"}
0005434877037	EB7281	2737 946373	DMITRIY MOROZOV	{"email": "dmitriy.morozov1963@postgrespro.ru", "phone": "+70013607358"}
0005434877038	EB7281	4777 784658	GENNADIY FOMIN	{"phone": "+70887291107"}
0005434877039	0DE7CC	6181 879399	SERGEY MEDVEDEV	{"email": "medvedevs021965@postgrespro.ru", "phone": "+70215774007"}
0005434877040	907E54	1362 205251	ALLA IVANOVA	{"phone": "+70419975616"}
0005434877041	2864E9	0682 577288	VLADIMIR MAKAROV	{"email": "v.makarov_17031975@postgrespro.ru", "phone": "+70790040193"}
0005434877042	D6DAC3	5058 231439	NATALYA KAZAKOVA	{"phone": "+70281356016"}
0005434877043	6D41C1	3985 224967	MIKHAIL NIKITIN	{"email": "m.nikitin-20111971@postgrespro.ru", "phone": "+70796679336"}
0005434877044	6D41C1	0407 150663	OLESYA EGOROVA	{"email": "o_egorova_17021987@postgrespro.ru", "phone": "+70077865557"}
0005434877045	3BD9F4	4563 700633	DMITRIY EGOROV	{"email": "d-egorov_061972@postgrespro.ru", "phone": "+70304058747"}
0005434877046	B8367E	9482 304940	ANNA GRISHINA	{"email": "grishina_anna1982@postgrespro.ru", "phone": "+70265884025"}
0005434877047	1C4EBB	9702 318376	LYUDMILA MELNIKOVA	{"phone": "+70868447958"}
0005434877048	297316	9670 160212	DIANA POPOVA	{"phone": "+70725845537"}
0005434877049	EC6D16	9056 224856	IVAN FEDOROV	{"phone": "+70495980235"}
0005434877050	C74C43	4788 376671	IVAN KOROLEV	{"email": "korolev_i_031973@postgrespro.ru", "phone": "+70833929042"}
0005434877051	7E7D0C	8563 474968	NARIMAN DENISOV	{"phone": "+70857308002"}
0005434877052	5D52B4	6615 908814	ELENA SOLOVEVA	{"phone": "+70748845786"}
0005434877053	5D52B4	8279 203320	ALFIYA NAUMOVA	{"email": "alfiyanaumova101981@postgrespro.ru", "phone": "+70781227431"}
0005434877054	BAE6B3	9532 187496	SERGEY ROMANOV	{"email": "romanovs1968@postgrespro.ru", "phone": "+70732800543"}
0005434877055	1FCE93	0793 210087	OLGA KUZNECOVA	{"email": "kuznecova-olga.17011981@postgrespro.ru", "phone": "+70386575700"}
0005434877056	1FCE93	8607 648530	MARIYA NIKITINA	{"email": "nikitina-m_021976@postgrespro.ru", "phone": "+70475536593"}
0005434877057	E0AFD0	4658 879420	NINA SCHERBAKOVA	{"email": "ninascherbakova.23101969@postgrespro.ru", "phone": "+70015436023"}
0005434877058	E0AFD0	2605 413496	MAKSIM MOROZOV	{"phone": "+70558250290"}
0005434877059	367F46	7249 035698	MARIYA PAVLOVA	{"phone": "+70671136765"}
0005434877060	367F46	4543 325880	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda-25091982@postgrespro.ru", "phone": "+70525955047"}
0005434877061	367F46	4537 328407	VLADIMIR VOROBEV	{"phone": "+70147549290"}
0005434877062	76BC3A	0930 174096	MAYYA NIKIFOROVA	{"email": "nikiforova.mayya_1971@postgrespro.ru", "phone": "+70050108419"}
0005434877063	FC680A	9867 031298	VIKTOR KOROLEV	{"phone": "+70369961931"}
0005434877064	B73161	5064 335117	SVETLANA ANTONOVA	{"phone": "+70869892946"}
0005434877065	561D7C	2619 540574	GALINA MELNIKOVA	{"phone": "+70486650400"}
0005434877066	561D7C	7723 168433	NATALYA VOLKOVA	{"phone": "+70181656488"}
0005434877067	07A451	0722 381458	KLARA FADEEVA	{"email": "fadeeva_klara.071971@postgrespro.ru", "phone": "+70878772084"}
0005434877068	07A451	4180 401319	NADEZHDA NAUMOVA	{"email": "nnaumova09041972@postgrespro.ru", "phone": "+70377116775"}
0005434877069	66B4E3	3775 305441	DARYA ANTONOVA	{"phone": "+70231254687"}
0005434877070	E4E8EF	1285 228722	EVGENIYA YAKOVLEVA	{"email": "yakovleva.e.111977@postgrespro.ru", "phone": "+70993515603"}
0005434877071	FA4D37	3411 490986	ALEKSEY MAKAROV	{"email": "makarov.aleksey-05041974@postgrespro.ru", "phone": "+70345632218"}
0005434877072	74EE7C	3501 074278	ELENA IVANOVA	{"email": "elena-ivanova08081965@postgrespro.ru", "phone": "+70948783220"}
0005434877073	A2B4EF	0949 742283	ELENA DAVYDOVA	{"email": "davydova-elena-081965@postgrespro.ru", "phone": "+70696387953"}
0005434877074	6A0D06	1656 800705	MIKHAIL NOVIKOV	{"email": "novikovmikhail031967@postgrespro.ru", "phone": "+70603145322"}
0005434877075	6AEFDD	5545 750954	ALINA POPOVA	{"email": "popova-alina091972@postgrespro.ru", "phone": "+70658244722"}
0005434877076	6AEFDD	5620 388172	SEMEN NIKOLAEV	{"phone": "+70862873213"}
0005434877077	4DA026	1368 915504	LYUDMILA MATVEEVA	{"email": "l_matveeva-121979@postgrespro.ru", "phone": "+70362076106"}
0005434877078	4DA026	1891 740156	GALINA KOVALEVA	{"phone": "+70982835775"}
0005434877079	4DAA55	7390 439549	ALEKSANDR SMIRNOV	{"phone": "+70230257891"}
0005434877080	0EE22F	7087 503585	YURIY PAVLOV	{"phone": "+70818840694"}
0005434877081	0EE22F	7389 568342	LEONID KONOVALOV	{"phone": "+70262327556"}
0005434877082	F40B57	9201 667523	ALISA DAVYDOVA	{"email": "davydova-alisa19111967@postgrespro.ru", "phone": "+70507888237"}
0005434877083	892088	8620 921659	ALEKSANDR EGOROV	{"email": "aleksandr-egorov_071975@postgrespro.ru", "phone": "+70397879110"}
0005434877084	892088	7239 059621	VALERIY OSIPOV	{"phone": "+70528171268"}
0005434877085	5D6E53	6654 322187	ALEKSEY ABRAMOV	{"phone": "+70534936549"}
0005434877086	5D6E53	1811 878672	NATALYA MATVEEVA	{"email": "matveevanatalya-1986@postgrespro.ru", "phone": "+70345311562"}
0005434877087	16CBD6	3912 947263	PETR IVANOV	{"email": "ivanovpetr_1980@postgrespro.ru", "phone": "+70390112778"}
0005434877088	F550CD	2198 489706	PELAGEYA ROMANOVA	{"phone": "+70303891710"}
0005434877089	0B736C	3358 223458	VLADIMIR ANTONOV	{"email": "v_antonov.091964@postgrespro.ru", "phone": "+70562046305"}
0005434877090	134AAC	6069 854288	VERA ROMANOVA	{"phone": "+70858586505"}
0005434877091	134AAC	6768 292795	ANNA SERGEEVA	{"email": "anna.sergeeva101975@postgrespro.ru", "phone": "+70562713537"}
0005434877092	33FBD0	0277 115694	ANNA BOGDANOVA	{"phone": "+70211164928"}
0005434877093	33FBD0	2632 247732	SERGEY IVANOV	{"email": "ivanov_sergey_091973@postgrespro.ru", "phone": "+70195200955"}
0005434877094	8D4439	2352 019812	ALEKSEY ZAKHAROV	{"phone": "+70099004880"}
0005434877095	8D4439	9676 921902	NINA DMITRIEVA	{"phone": "+70875940110"}
0005434877096	8D4439	8099 565350	ALEKSANDR KRASNOV	{"phone": "+70004154683"}
0005434877097	A2794F	3574 451565	MAKSIM FILIPPOV	{"email": "maksim_filippov1981@postgrespro.ru", "phone": "+70705817396"}
0005434877098	60360B	2529 172961	NIKOLAY BARANOV	{"phone": "+70223740741"}
0005434877099	6F1F6F	9855 601316	VALERIY ANDREEV	{"phone": "+70798942279"}
0005434877100	591FFB	4761 866455	NIKOLAY SEMENOV	{"email": "nsemenov.05071970@postgrespro.ru", "phone": "+70602567568"}
0005434877101	A4995A	4831 883162	VALENTINA SOROKINA	{"phone": "+70895171693"}
0005434877102	E62E0F	1435 664461	LYUDMILA MAKAROVA	{"email": "l-makarova.26021969@postgrespro.ru", "phone": "+70181562548"}
0005434877103	20AD53	0173 268805	OLGA SEMENOVA	{"phone": "+70118838854"}
0005434877104	2EC414	2559 670374	SOFYA YUDINA	{"email": "yudina_sofya_041969@postgrespro.ru", "phone": "+70248134284"}
0005434877105	525BEC	6333 704020	TAMARA DAVYDOVA	{"email": "tamara.davydova_1961@postgrespro.ru", "phone": "+70573898097"}
0005434877106	525BEC	9623 556060	OLGA NAUMOVA	{"email": "onaumova.011979@postgrespro.ru", "phone": "+70301049124"}
0005434877107	525BEC	0450 830203	IVAN BORISOV	{"phone": "+70199898888"}
0005434877108	CB03CF	7782 843757	IVAN VOLKOV	{"email": "ivan_volkov.1976@postgrespro.ru", "phone": "+70591607419"}
0005434877109	CB03CF	2952 098491	IVAN RODIONOV	{"email": "i.rodionov1980@postgrespro.ru", "phone": "+70100815726"}
0005434877110	0F1A89	1528 704878	VLADIMIR FEDOTOV	{"email": "vfedotov-23071972@postgrespro.ru", "phone": "+70818824649"}
0005434877111	0F1A89	4945 600436	NINA GUSEVA	{"phone": "+70477587765"}
0005434877112	C38D15	8625 274063	MARIYA PAVLOVA	{"phone": "+70384833241"}
0005434877113	01C576	7107 667985	ELMIRA KOZLOVA	{"phone": "+70680965502"}
0005434877114	5534EF	2553 867774	ARTUR SOKOLOV	{"phone": "+70375427694"}
0005434877115	5534EF	0749 448461	RAIL EGOROV	{"email": "egorov.r25121974@postgrespro.ru", "phone": "+70228852436"}
0005434877116	DB45C9	4152 437286	DMITRIY TIKHONOV	{"phone": "+70945768202"}
0005434877117	B4FF4B	2860 048305	ALEKSANDR ABRAMOV	{"email": "a.abramov-24061965@postgrespro.ru", "phone": "+70247158020"}
0005434877118	3554C8	6356 161447	OLGA NIKITINA	{"email": "olga.nikitina-051976@postgrespro.ru", "phone": "+70467941734"}
0005434877119	5C03DD	4019 700385	OKSANA FILIPPOVA	{"email": "ofilippova20071973@postgrespro.ru", "phone": "+70416335612"}
0005434877120	C6CD05	7328 438672	ELENA KUZNECOVA	{"phone": "+70803514983"}
0005434877121	C6CD05	4621 037456	ALEKSANDR MATVEEV	{"phone": "+70742297230"}
0005434877122	B4E985	0974 443666	LIDIYA TIMOFEEVA	{"phone": "+70684814149"}
0005434877123	B4E985	5291 074820	TAISIYA NESTEROVA	{"phone": "+70348889010"}
0005434877124	9EE239	5787 141026	EVGENIY TIKHONOV	{"phone": "+70672967429"}
0005434877125	9EE239	8641 032437	PETR TARASOV	{"email": "tarasov.p021968@postgrespro.ru", "phone": "+70938404504"}
0005434877126	9EE239	4124 798319	PAVEL IVANOV	{"email": "pavel_ivanov_1974@postgrespro.ru", "phone": "+70293279889"}
0005434877127	A1B562	3892 925926	PAVEL NOVIKOV	{"phone": "+70062271145"}
0005434877128	164B74	5926 298868	DARYA NIKITINA	{"email": "nikitina-d-091960@postgrespro.ru", "phone": "+70330091440"}
0005434877130	4395F5	2533 212364	IVAN MEDVEDEV	{"email": "imedvedev_061970@postgrespro.ru", "phone": "+70951028813"}
0005434877131	4395F5	8637 698578	TAMARA ZOTOVA	{"phone": "+70827823053"}
0005434877132	5B1F7E	5820 810389	MIKHAIL KAZAKOV	{"email": "kazakovm-1973@postgrespro.ru", "phone": "+70114951763"}
0005434877133	4B80E6	5453 805229	VLADIMIR DENISOV	{"email": "v-denisov091980@postgrespro.ru", "phone": "+70364068016"}
0005434877134	4B80E6	4269 454609	ANDREY KUZNECOV	{"phone": "+70876740676"}
0005434877135	FB9AC4	0997 763675	YULIYA NESTEROVA	{"phone": "+70237620253"}
0005434877136	82B4CC	5717 077038	DANILA KUZNECOV	{"phone": "+70607337151"}
0005434877137	82B4CC	2424 082480	IVAN SERGEEV	{"email": "isergeev.17121977@postgrespro.ru", "phone": "+70652962636"}
0005434877138	59C7C3	1151 000767	VITALIY IVANOV	{"email": "ivanov_v_06011984@postgrespro.ru", "phone": "+70087623286"}
0005434877139	11C4AC	2890 999914	DENIS GERASIMOV	{"email": "d.gerasimov-1965@postgrespro.ru", "phone": "+70244983101"}
0005434877140	11C4AC	1969 898230	ANASTASIYA LAZAREVA	{"email": "anastasiya-lazareva_1974@postgrespro.ru", "phone": "+70055237219"}
0005434877141	4383D6	9282 352115	NIKOLAY YAKOVLEV	{"email": "yakovlev.n.22031961@postgrespro.ru", "phone": "+70069317453"}
0005434877142	247637	9195 657546	SVETLANA POLYAKOVA	{"email": "spolyakova1970@postgrespro.ru", "phone": "+70172948352"}
0005434877143	247637	0914 310178	SERGEY KUZNECOV	{"email": "sergey_kuznecov071985@postgrespro.ru", "phone": "+70237717599"}
0005434877144	360178	4457 600133	STANISLAV MEDVEDEV	{"email": "medvedev_s1963@postgrespro.ru", "phone": "+70682744471"}
0005434877145	59BDAD	0773 064629	ALEKSEY FROLOV	{"email": "frolov-a05061975@postgrespro.ru", "phone": "+70143328948"}
0005434877146	A588AB	2856 560563	DANIIL TIKHONOV	{"phone": "+70550344067"}
0005434877147	A588AB	2768 074953	EVGENIY NIKOLAEV	{"email": "evgeniy-nikolaev1961@postgrespro.ru", "phone": "+70244437589"}
0005434877148	A588AB	0451 285100	ALEKSANDRA KUZNECOVA	{"phone": "+70942199973"}
0005434877149	2E0C32	8958 995439	EKATERINA SERGEEVA	{"phone": "+70552244189"}
0005434877150	2E0C32	9726 678490	EVGENIYA SOROKINA	{"email": "evgeniya_sorokina08041971@postgrespro.ru", "phone": "+70384711423"}
0005434877151	2E0C32	1641 541185	ALEKSEY MEDVEDEV	{"phone": "+70510582433"}
0005434877152	98CB0F	2148 669414	ALEKSEY BARANOV	{"phone": "+70266843641"}
0005434877153	98CB0F	4524 536111	NATALYA FROLOVA	{"phone": "+70808654248"}
0005434877154	34FA60	1201 806367	KLAVDIYA ZAYCEVA	{"email": "zaycevaklavdiya_17121969@postgrespro.ru", "phone": "+70262902004"}
0005434877155	34FA60	0994 290268	VALERIY ILIN	{"email": "ilinv_1972@postgrespro.ru", "phone": "+70557230651"}
0005434877156	34FA60	2478 617472	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.091978@postgrespro.ru", "phone": "+70490260274"}
0005434877157	E72D74	7852 068948	VLADIMIR SCHERBAKOV	{"phone": "+70963040118"}
0005434877158	22CE64	7259 112336	YULIYA MAKAROVA	{"email": "y.makarova_12061979@postgrespro.ru", "phone": "+70199334084"}
0005434877159	B5382A	1477 837504	TATYANA DMITRIEVA	{"email": "t-dmitrieva09081976@postgrespro.ru", "phone": "+70181940050"}
0005434877160	DC8C6E	4808 319057	VLADIMIR MIRONOV	{"phone": "+70625300359"}
0005434877161	4B4021	5440 896700	LIDIYA SOROKINA	{"phone": "+70433752588"}
0005434877162	B65823	2494 085206	IRINA SCHERBAKOVA	{"email": "scherbakovairina-14021982@postgrespro.ru", "phone": "+70209205461"}
0005434877163	B65823	2359 687720	NATALYA LAZAREVA	{"phone": "+70548725929"}
0005434877164	8026C6	0610 532469	VALERIY MARTYNOV	{"email": "vmartynov-28091978@postgrespro.ru", "phone": "+70131075028"}
0005434877165	ACF8C9	2563 950135	ANATOLIY DAVYDOV	{"phone": "+70626972052"}
0005434877166	ACF8C9	3004 107582	SVETLANA NESTEROVA	{"phone": "+70545154601"}
0005434877167	C25026	5119 482552	VALERIY SEMENOV	{"email": "semenov-valeriy081963@postgrespro.ru", "phone": "+70776935221"}
0005434877168	7ECF9F	2248 870345	LUIZA FROLOVA	{"phone": "+70514712028"}
0005434877169	0C7223	7578 554044	ALEKSEY SIDOROV	{"phone": "+70560229951"}
0005434877170	AB0280	7597 736153	ELMIRA NIKOLAEVA	{"email": "nikolaeva_elmira.1972@postgrespro.ru", "phone": "+70353790301"}
0005434877171	E863DD	9422 823114	PAVEL ZAYCEV	{"phone": "+70146839159"}
0005434877172	E863DD	2700 908611	ANTONINA KUZNECOVA	{"email": "akuznecova-22041968@postgrespro.ru", "phone": "+70817482312"}
0005434877173	EDE6DD	3610 275755	RUFIYA FADEEVA	{"phone": "+70749937313"}
0005434877174	423FCC	5568 570204	ALEKSANDR GORBUNOV	{"email": "aleksandrgorbunov-111965@postgrespro.ru", "phone": "+70666486765"}
0005434877175	423FCC	2620 326484	MARINA YAKOVLEVA	{"email": "m-yakovleva-19081981@postgrespro.ru", "phone": "+70334231280"}
0005434877176	423FCC	9852 621442	VALENTIN FILIPPOV	{"phone": "+70067732884"}
0005434877177	F14B04	1761 328998	DINARA SMIRNOVA	{"email": "dsmirnova1979@postgrespro.ru", "phone": "+70003383057"}
0005434877178	319E18	6842 662573	SVETLANA RODIONOVA	{"phone": "+70889794699"}
0005434877179	E8B631	4551 357152	VIKTORIYA GORBUNOVA	{"email": "gorbunova.viktoriya-17071968@postgrespro.ru", "phone": "+70613832338"}
0005434877180	2632B5	1758 920079	LYUBOV FILIPPOVA	{"email": "lyubov_filippova.121974@postgrespro.ru", "phone": "+70678218995"}
0005434877181	49A81E	7021 514790	MIKHAIL KULIKOV	{"phone": "+70050557852"}
0005434877182	FC610E	3547 351647	SERGEY KOZLOV	{"phone": "+70171860522"}
0005434877183	FC610E	5480 450808	TATYANA KUZNECOVA	{"email": "kuznecovat031969@postgrespro.ru", "phone": "+70081463671"}
0005434877184	C441EE	6870 407171	ANNA KONOVALOVA	{"phone": "+70466149931"}
0005434877241	7698B3	3754 064010	YULIYA BARANOVA	{"phone": "+70764280027"}
0005434877185	D89149	9542 536383	SERGEY KUZNECOV	{"email": "kuznecov.sergey.06071973@postgrespro.ru", "phone": "+70166375151"}
0005434877186	0E8D28	2877 656265	NIKOLAY YAKOVLEV	{"phone": "+70604942677"}
0005434877187	0E8D28	6435 033902	STEPAN ZAKHAROV	{"email": "zakharovs031977@postgrespro.ru", "phone": "+70106645935"}
0005434877188	A3E1D1	5239 375369	ALISA PAVLOVA	{"phone": "+70956651786"}
0005434877189	FEC562	7276 504591	ANZHELIKA STEPANOVA	{"phone": "+70685713100"}
0005434877190	319536	3388 582973	GENNADIY YAKOVLEV	{"email": "gyakovlev-021972@postgrespro.ru", "phone": "+70695805773"}
0005434877191	319536	4551 235217	LYUDMILA KAZAKOVA	{"email": "l-kazakova1972@postgrespro.ru", "phone": "+70904784007"}
0005434877192	A882A5	0451 339395	YURIY MELNIKOV	{"email": "yuriy.melnikov_01031981@postgrespro.ru", "phone": "+70001765224"}
0005434877193	6D3AFA	5185 511199	VLADIMIR SOLOVEV	{"phone": "+70056897987"}
0005434877194	E2E225	3915 202637	ALEKSANDRA PETROVA	{"phone": "+70738380833"}
0005434877195	90CE99	0700 779381	MARINA PAVLOVA	{"email": "m-pavlova.1982@postgrespro.ru", "phone": "+70540024436"}
0005434877196	7F9CFF	3046 114295	ALEKSANDR ISAEV	{"email": "aleksandrisaev_1972@postgrespro.ru", "phone": "+70627870177"}
0005434877197	79E4E6	7880 646324	EKATERINA KARPOVA	{"phone": "+70220504448"}
0005434877198	953871	7274 127901	ANNA ZOTOVA	{"email": "anna-zotova.13051968@postgrespro.ru", "phone": "+70346740751"}
0005434877199	D32916	1229 261832	ANASTASIYA ALEKSEEVA	{"email": "alekseevaa-1968@postgrespro.ru", "phone": "+70158159317"}
0005434877200	DD86B1	7531 326176	EVGENIY KOZLOV	{"phone": "+70273439880"}
0005434877201	5A0921	6828 806122	DMITRIY ABRAMOV	{"email": "abramov_d.1981@postgrespro.ru", "phone": "+70196459552"}
0005434877202	5A0921	9466 246620	SERGEY OSIPOV	{"email": "osipov.sergey_1978@postgrespro.ru", "phone": "+70474101071"}
0005434877203	350265	8205 407861	ANNA NESTEROVA	{"email": "nesterova_a.081973@postgrespro.ru", "phone": "+70727082630"}
0005434877204	350265	0372 855867	NIKOLAY FROLOV	{"phone": "+70901440730"}
0005434877205	350265	0592 086807	VALENTINA MIRONOVA	{"email": "mironova.valentina.071976@postgrespro.ru", "phone": "+70622774422"}
0005434877206	A2EAEE	1083 191050	NINA KISELEVA	{"phone": "+70686282422"}
0005434877207	A2EAEE	1026 224836	NATALYA KUZNECOVA	{"email": "kuznecovan-071962@postgrespro.ru", "phone": "+70834944812"}
0005434877208	1F4603	6219 095641	VLADIMIR KUZNECOV	{"phone": "+70968127456"}
0005434877209	29E2A2	6048 031628	ILYA ZAKHAROV	{"phone": "+70076430151"}
0005434877210	29E2A2	3861 491030	IGOR ANDREEV	{"phone": "+70558301153"}
0005434877211	29E2A2	3056 008497	GENNADIY KISELEV	{"email": "gennadiy.kiselev-061974@postgrespro.ru", "phone": "+70738416742"}
0005434877212	C98962	4232 974431	VLADIMIR SOLOVEV	{"phone": "+70486186138"}
0005434877213	E7B507	7306 415307	ALEKSANDR YAKOVLEV	{"phone": "+70407602911"}
0005434877214	6DC804	1814 637850	SERGEY YAKOVLEV	{"phone": "+70270260006"}
0005434877215	EFA9E2	5074 964764	OLEG PETROV	{"email": "o_petrov-1976@postgrespro.ru", "phone": "+70548229058"}
0005434877216	83C137	0682 449053	ZINAIDA MOROZOVA	{"email": "z-morozova.16121978@postgrespro.ru", "phone": "+70939886185"}
0005434877217	F8180B	2523 858238	MARIYA KRASNOVA	{"phone": "+70351443723"}
0005434877218	6199CD	6677 107876	LYUBOV ANTONOVA	{"phone": "+70366976774"}
0005434877219	6199CD	3558 164740	ANNA NIKITINA	{"email": "anikitina-1980@postgrespro.ru", "phone": "+70804305680"}
0005434877220	83A09B	2393 980534	ANATOLIY MATVEEV	{"phone": "+70941579434"}
0005434877221	83A09B	6276 920474	ANASTASIYA ILINA	{"email": "ailina_1976@postgrespro.ru", "phone": "+70840630308"}
0005434877222	9E7EE7	1072 328201	ALEKSEY IVANOV	{"phone": "+70499605050"}
0005434877223	D2AEB8	5992 227342	EVGENIY KONOVALOV	{"phone": "+70012627282"}
0005434877224	D2AEB8	7125 349987	NIKOLAY IVANOV	{"email": "ivanov_nikolay_07121982@postgrespro.ru", "phone": "+70329813006"}
0005434877225	2227AC	2116 397102	SERGEY KUZNECOV	{"email": "sergey_kuznecov_11041986@postgrespro.ru", "phone": "+70891158326"}
0005434877226	2227AC	7769 410877	VYACHESLAV EGOROV	{"phone": "+70696301131"}
0005434877227	B7FD9E	7360 018221	ANTON ZHURAVLEV	{"email": "a-zhuravlev-15101979@postgrespro.ru", "phone": "+70478855424"}
0005434877228	453EA0	5351 073120	VALERIY ANTONOV	{"email": "antonov.valeriy09121963@postgrespro.ru", "phone": "+70369465008"}
0005434877229	3889C2	5714 057869	VALENTINA ROMANOVA	{"email": "romanova_valentina-1965@postgrespro.ru", "phone": "+70322142134"}
0005434877230	3889C2	9147 919445	VLADISLAV IVANOV	{"phone": "+70385392285"}
0005434877231	4575BF	8823 760322	PELAGEYA KOROLEVA	{"phone": "+70569071651"}
0005434877232	75E54A	8705 241860	KONSTANTIN SHEVCHENKO	{"email": "shevchenkokonstantin.1991@postgrespro.ru", "phone": "+70094281497"}
0005434877233	2CB318	0058 405884	VASILISA SMIRNOVA	{"email": "smirnova_vasilisa1963@postgrespro.ru", "phone": "+70021913190"}
0005434877234	2CB318	3821 825047	NIKOLAY KUZNECOV	{"phone": "+70957587172"}
0005434877235	677ADC	2111 354291	ANDREY FOMIN	{"email": "andreyfomin21051960@postgrespro.ru", "phone": "+70599756226"}
0005434877236	CBAE40	8770 000376	VLADIMIR KUZNECOV	{"phone": "+70247379051"}
0005434877237	0B0033	2623 311043	AMINA ROMANOVA	{"email": "romanovaamina.11071967@postgrespro.ru", "phone": "+70127750239"}
0005434877238	0B0033	1228 930327	SERGEY MARTYNOV	{"phone": "+70347815021"}
0005434877239	B12206	1733 474826	ELENA BOGDANOVA	{"email": "elenabogdanova011974@postgrespro.ru", "phone": "+70426246538"}
0005434877240	9F5B10	2448 923433	ANNA SOKOLOVA	{"phone": "+70356019447"}
0005434877242	DD84BD	5627 024780	ALEKSEY IVANOV	{"email": "a-ivanov_1983@postgrespro.ru", "phone": "+70615908539"}
0005434877243	DD84BD	4632 535561	ALEKSANDR FOMIN	{"phone": "+70342030909"}
0005434877244	C2D454	8476 339361	VENERA KOROLEVA	{"email": "korolevavenera_09111967@postgrespro.ru", "phone": "+70365899928"}
0005434877245	29104A	0217 038530	ALEKSEY NIKOLAEV	{"phone": "+70114164292"}
0005434877246	9CA293	2106 162221	NIKOLAY POPOV	{"phone": "+70143418705"}
0005434877247	9CA293	8175 187138	IVAN MAKAROV	{"email": "makarov_i.101974@postgrespro.ru", "phone": "+70282283504"}
0005434877248	401254	1108 869102	VITALIY ANDREEV	{"phone": "+70304363902"}
0005434877249	792A5C	2253 572060	OLGA SEMENOVA	{"phone": "+70708114956"}
0005434877250	0FA9AE	7654 625694	ROZA NESTEROVA	{"email": "rozanesterova-22121983@postgrespro.ru", "phone": "+70095024179"}
0005434877251	0FA9AE	5631 944840	YURIY ILIN	{"email": "y.ilin_051980@postgrespro.ru", "phone": "+70769310699"}
0005434877252	266850	6060 562129	ALEKSANDR RODIONOV	{"phone": "+70790563055"}
0005434877253	266850	5139 879371	OKSANA LEBEDEVA	{"email": "oksana-lebedeva-28061960@postgrespro.ru", "phone": "+70136071732"}
0005434877254	6405AC	8730 057908	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikovaanastasiya_101964@postgrespro.ru", "phone": "+70005220984"}
0005434877255	EDA957	0233 649698	TAMARA NESTEROVA	{"phone": "+70003724428"}
0005434877256	6AE96D	9426 578375	RAISA DAVYDOVA	{"email": "r-davydova-071989@postgrespro.ru", "phone": "+70535712616"}
0005434877257	045C84	0473 634063	VALERIY SEMENOV	{"email": "vsemenov_1972@postgrespro.ru", "phone": "+70454977159"}
0005434877258	045C84	0789 835167	IGOR IVANOV	{"email": "igor-ivanov_29031960@postgrespro.ru", "phone": "+70056922779"}
0005434877259	A90380	4800 613438	IRINA ALEKSEEVA	{"email": "alekseeva-irina.101977@postgrespro.ru", "phone": "+70099502973"}
0005434877260	AEB933	7370 457377	RAMIS POPOV	{"phone": "+70390944338"}
0005434877261	202A76	3907 948267	EVGENIYA PETROVA	{"email": "petrova.e_021974@postgrespro.ru", "phone": "+70331373847"}
0005434877262	3F04C6	2993 596884	DMITRIY SERGEEV	{"email": "sergeev_dmitriy_061979@postgrespro.ru", "phone": "+70137276016"}
0005434877263	98848E	1165 302769	OLGA IVANOVA	{"email": "olga_ivanova1975@postgrespro.ru", "phone": "+70911801110"}
0005434877264	1D8D64	6422 930107	NIKOLAY KULIKOV	{"email": "kulikov_n.011972@postgrespro.ru", "phone": "+70313035607"}
0005434877265	D5C27F	8609 832949	IVAN EGOROV	{"email": "egorov.i_1958@postgrespro.ru", "phone": "+70845432182"}
0005434877266	C96FEC	6685 067970	NINA KOROLEVA	{"email": "n_koroleva1983@postgrespro.ru", "phone": "+70427707865"}
0005434877267	B53631	0346 023244	EKATERINA MIRONOVA	{"email": "e-mironova14041964@postgrespro.ru", "phone": "+70163511693"}
0005434877268	3E38E5	4928 111469	KAPITALINA FROLOVA	{"email": "k-frolova.111971@postgrespro.ru", "phone": "+70444339605"}
0005434877269	3E38E5	3429 008209	ANNA IVANOVA	{"email": "annaivanova_1983@postgrespro.ru", "phone": "+70976882202"}
0005434877270	C92B28	6847 379277	SVETLANA SCHERBAKOVA	{"email": "scherbakova.s.20111967@postgrespro.ru", "phone": "+70881362397"}
0005434877271	C92B28	0437 918972	ALEKSEY KAZAKOV	{"email": "kazakovaleksey1977@postgrespro.ru", "phone": "+70576730289"}
0005434877272	E113EA	4602 965375	VALERIYA AFANASEVA	{"phone": "+70280035269"}
0005434877273	E113EA	6490 637709	VIKTOR PAVLOV	{"phone": "+70057366958"}
0005434877274	54C1AE	5787 844363	ALFIYA KOVALEVA	{"email": "kovalevaalfiya031979@postgrespro.ru", "phone": "+70798036932"}
0005434877275	E17041	7938 256494	VITALIY STEPANOV	{"phone": "+70309415993"}
0005434877276	AEF238	1614 743051	ALEKSANDRA KUZNECOVA	{"email": "a-kuznecova1964@postgrespro.ru", "phone": "+70632670097"}
0005434877277	AEF238	3109 007128	YULIYA FEDOROVA	{"phone": "+70081609075"}
0005434877278	149756	8742 995033	VALENTINA MELNIKOVA	{"email": "v-melnikova.01091974@postgrespro.ru", "phone": "+70793597749"}
0005434877279	23298D	3891 458217	IGOR MEDVEDEV	{"email": "igor_medvedev.14121971@postgrespro.ru", "phone": "+70282617215"}
0005434877280	23298D	3936 300913	EVGENIY TIMOFEEV	{"phone": "+70423380988"}
0005434877281	341931	9231 980924	NADEZHDA BELOVA	{"email": "belova.nadezhda-1970@postgrespro.ru", "phone": "+70526949531"}
0005434877282	A9628B	9963 673063	ALEKSANDR NIKITIN	{"email": "anikitin011972@postgrespro.ru", "phone": "+70372378211"}
0005434877283	8B086C	1546 742838	MARGARITA FILIPPOVA	{"email": "mfilippova.1988@postgrespro.ru", "phone": "+70816292523"}
0005434877284	8B086C	1494 138992	ANTON POPOV	{"phone": "+70145393177"}
0005434877285	A90E1A	0945 196179	DARYA MALYSHEVA	{"phone": "+70911204923"}
0005434877286	449836	4484 605078	ALEKSEY SEMENOV	{"email": "asemenov06121978@postgrespro.ru", "phone": "+70462077861"}
0005434877287	E24CBC	3922 753927	ALEKSANDR VOROBEV	{"email": "avorobev-1977@postgrespro.ru", "phone": "+70746542040"}
0005434877288	E24CBC	0259 083599	VALENTIN PAVLOV	{"email": "pavlov_valentin_101971@postgrespro.ru", "phone": "+70635779133"}
0005434877289	89D787	0365 039494	NATALYA MEDVEDEVA	{"phone": "+70131982912"}
0005434877290	91BD01	4342 140969	LYUDMILA AFANASEVA	{"phone": "+70324377887"}
0005434877291	91BD01	2085 357122	IRINA MOISEEVA	{"email": "irinamoiseeva_051977@postgrespro.ru", "phone": "+70811223902"}
0005434877292	549C99	3267 396530	LYUBOV ANDREEVA	{"email": "andreeval.1974@postgrespro.ru", "phone": "+70075637524"}
0005434877293	FA9899	7762 451456	DARYA SERGEEVA	{"phone": "+70240614518"}
0005434877294	8915ED	2896 226154	TATYANA KARPOVA	{"phone": "+70226483156"}
0005434877295	9B27E6	9839 370072	MIKHAIL SHEVCHENKO	{"email": "m-shevchenko.081970@postgrespro.ru", "phone": "+70524762874"}
0005434877296	9B27E6	8723 476769	VYACHESLAV STEPANOV	{"phone": "+70825244479"}
0005434877297	97E7A4	6220 962627	DARYA AKIMOVA	{"email": "d.akimova_091980@postgrespro.ru", "phone": "+70483974893"}
0005434877298	C7DC2C	0999 977385	ELENA ISAEVA	{"email": "elena_isaeva021963@postgrespro.ru", "phone": "+70455839326"}
0005434877299	F6489B	5385 690685	RAMIL ROMANOV	{"phone": "+70306699800"}
0005434877300	6ED89D	4416 266935	VALENTINA LOGINOVA	{"email": "v_loginova.14121965@postgrespro.ru", "phone": "+70112568341"}
0005434877301	61E43E	5313 061122	NATALYA MAKSIMOVA	{"phone": "+70147364906"}
0005434877302	61E43E	1113 178755	IRINA ARKHIPOVA	{"phone": "+70118176482"}
0005434877303	74BCC0	2789 759491	ANDREY SERGEEV	{"email": "a_sergeev_01111973@postgrespro.ru", "phone": "+70983079861"}
0005434877304	74BCC0	2371 106821	PAVEL MIKHAYLOV	{"phone": "+70047468633"}
0005434877305	E71909	1722 141834	TATYANA MAKAROVA	{"phone": "+70382741056"}
0005434877306	5E23E5	4094 342938	DMITRIY POPOV	{"email": "dmitriy.popov.11081975@postgrespro.ru", "phone": "+70852278135"}
0005434877307	628711	6885 218028	TAMARA KOROLEVA	{"email": "koroleva_t-16121983@postgrespro.ru", "phone": "+70826453408"}
0005434877308	3A6F73	7439 183112	ROMAN SIDOROV	{"email": "sidorov-r-1963@postgrespro.ru", "phone": "+70770457058"}
0005434877309	52A5FB	5716 688702	ALEKSEY KUZNECOV	{"phone": "+70005433507"}
0005434877310	52A5FB	9273 976126	ALEVTINA ERMAKOVA	{"email": "ermakovaalevtina121981@postgrespro.ru", "phone": "+70103494279"}
0005434877311	0DF997	0831 797616	VYACHESLAV YAKOVLEV	{"email": "vyacheslavyakovlev25101971@postgrespro.ru", "phone": "+70157879469"}
0005434877312	AA8272	0048 300562	SVETLANA SCHERBAKOVA	{"phone": "+70711525715"}
0005434877313	E2111D	3527 688507	VALENTINA MELNIKOVA	{"email": "melnikova-v081974@postgrespro.ru", "phone": "+70609073165"}
0005434877314	96061E	1802 058280	VALENTINA PETROVA	{"email": "valentina.petrova_081961@postgrespro.ru", "phone": "+70875280705"}
0005434877315	2945E5	0408 266146	ELENA KUDRYASHOVA	{"phone": "+70915095650"}
0005434877316	F01220	7668 218193	ARTEM SOLOVEV	{"email": "artemsolovev.14091965@postgrespro.ru", "phone": "+70172377517"}
0005434877317	83F643	5349 480601	VITALIY ABRAMOV	{"email": "v-abramov091966@postgrespro.ru", "phone": "+70282762734"}
0005434877318	83F643	7538 270084	OLGA TROFIMOVA	{"phone": "+70980165196"}
0005434877319	83F643	1115 297766	OLEG ROMANOV	{"email": "romanov.oleg-26101975@postgrespro.ru", "phone": "+70816076586"}
0005434877320	31CE2A	0704 876375	ALEKSANDR BARANOV	{"email": "aleksandrbaranov-031980@postgrespro.ru", "phone": "+70859054815"}
0005434877321	1D0B4E	3695 771020	OLGA ANDREEVA	{"email": "andreeva-o1976@postgrespro.ru", "phone": "+70656656589"}
0005434877322	9E2D08	5958 773971	ULYANA KUZMINA	{"phone": "+70111225140"}
0005434877323	C420BE	4885 990132	ILYA STEPANOV	{"phone": "+70222756484"}
0005434877324	922F22	6192 566859	DARYA SMIRNOVA	{"email": "smirnovadarya-1961@postgrespro.ru", "phone": "+70252725941"}
0005434877325	922F22	4051 630884	SERGEY KISELEV	{"phone": "+70996757721"}
0005434877326	5FE7D0	3911 612875	DMITRIY GUSEV	{"email": "d-gusev.28041973@postgrespro.ru", "phone": "+70253220252"}
0005434877327	98DC9F	2371 769878	YULIYA MAKSIMOVA	{"email": "maksimova-y-091984@postgrespro.ru", "phone": "+70107938168"}
0005434877328	98DC9F	4734 175758	KONSTANTIN MEDVEDEV	{"email": "medvedevkonstantin-1969@postgrespro.ru", "phone": "+70783996136"}
0005434877329	7EBE01	4118 822711	NATALYA MIKHAYLOVA	{"phone": "+70150128278"}
0005434877330	7EBE01	5679 003783	LYUDMILA GORBUNOVA	{"email": "lyudmilagorbunova-081971@postgrespro.ru", "phone": "+70850752840"}
0005434877331	BC125E	5544 365269	YULIYA VOLKOVA	{"email": "yuliyavolkova25091977@postgrespro.ru", "phone": "+70727509137"}
0005434877332	C30B22	2026 449208	IGOR SAVELEV	{"email": "savelevigor_11071977@postgrespro.ru", "phone": "+70588848597"}
0005434877333	F503FD	7641 622116	ELENA KOMAROVA	{"phone": "+70066061134"}
0005434877334	4F36B0	5654 212374	ANATOLIY AFANASEV	{"email": "afanasev-a-051975@postgrespro.ru", "phone": "+70692850215"}
0005434877335	022B51	4695 867433	VLADISLAV VASILEV	{"email": "vasilev_vladislav-101982@postgrespro.ru", "phone": "+70578680427"}
0005434877336	032F02	5879 531002	FEDOR KRASNOV	{"email": "krasnov.fedor1967@postgrespro.ru", "phone": "+70967752590"}
0005434877337	92D525	2220 806500	VALENTINA KOROLEVA	{"phone": "+70052287137"}
0005434877338	B3CEEE	5688 173985	ALEKSEY SOKOLOV	{"email": "alekseysokolov-01121965@postgrespro.ru", "phone": "+70874609127"}
0005434877339	B3CEEE	9373 832070	VIKTOR KOROLEV	{"email": "korolev_v.121965@postgrespro.ru", "phone": "+70644238972"}
0005434877340	78AC8E	8462 918421	GRIGORIY TARASOV	{"phone": "+70349527013"}
0005434877341	5FBEB4	7153 468993	VITALIY MIKHAYLOV	{"email": "v.mikhaylov02061965@postgrespro.ru", "phone": "+70844829757"}
0005434877342	FE6E88	2216 676110	EVGENIY SHEVCHENKO	{"email": "evgeniyshevchenko061975@postgrespro.ru", "phone": "+70293851097"}
0005434877578	E99D93	1526 317849	NATALYA KONDRATEVA	{"phone": "+70517098611"}
0005434877343	FE6E88	4990 506174	ANNA KALININA	{"email": "a_kalinina.16031966@postgrespro.ru", "phone": "+70502251790"}
0005434877344	B68854	3039 911301	NIKOLAY POPOV	{"phone": "+70689321920"}
0005434877345	B68854	5762 950967	SVETLANA VOROBEVA	{"phone": "+70926073629"}
0005434877346	9FC2D4	8933 359977	MARGARITA IVANOVA	{"phone": "+70447179709"}
0005434877347	5B6F17	9551 890195	ALEKSANDR FEDOTOV	{"email": "a_fedotov-1984@postgrespro.ru", "phone": "+70586656531"}
0005434877348	5B6F17	0552 888786	SVETLANA FOMINA	{"phone": "+70991317692"}
0005434877349	53DC2A	9567 851533	ALEKSANDR GORBUNOV	{"phone": "+70895851376"}
0005434877350	4530B6	7290 252571	RAISA ZOTOVA	{"email": "raisa-zotova-1976@postgrespro.ru", "phone": "+70022455380"}
0005434877351	145122	5291 782118	EKATERINA LEBEDEVA	{"email": "e_lebedeva081974@postgrespro.ru", "phone": "+70908269033"}
0005434877352	D7BA08	7524 783186	PAVEL SOROKIN	{"phone": "+70053150410"}
0005434877353	59A4CD	7380 867601	VALENTINA KAZAKOVA	{"email": "valentina_kazakova-091972@postgrespro.ru", "phone": "+70451667762"}
0005434877354	59A4CD	3889 711972	VALENTINA EFIMOVA	{"email": "efimova-v_051976@postgrespro.ru", "phone": "+70766120912"}
0005434877355	EBC00C	2686 827541	ILDAR OSIPOV	{"email": "osipovi-041967@postgrespro.ru", "phone": "+70167831962"}
0005434877356	0A377B	8809 085510	ALEKSANDR IVANOV	{"email": "ivanov-a30111965@postgrespro.ru", "phone": "+70318721323"}
0005434877357	815DD0	7925 830788	LARISA KUZNECOVA	{"phone": "+70094947913"}
0005434877358	815DD0	1610 591059	VALENTINA MELNIKOVA	{"email": "valentinamelnikova_07091968@postgrespro.ru", "phone": "+70980985894"}
0005434877359	446A99	9150 136656	TATYANA FILATOVA	{"email": "filatovatatyana13031970@postgrespro.ru", "phone": "+70304509226"}
0005434877360	446A99	6150 902587	STEPAN FEDOROV	{"email": "stepan_fedorov.06071976@postgrespro.ru", "phone": "+70870830354"}
0005434877361	CB534E	7966 935058	TAMARA SERGEEVA	{"email": "sergeevat_091975@postgrespro.ru", "phone": "+70941921850"}
0005434877362	CB534E	3752 360372	VLADIMIR ZHURAVLEV	{"email": "zhuravlev-v081954@postgrespro.ru", "phone": "+70554175903"}
0005434877363	AB259A	3101 339543	IRAIDA ABRAMOVA	{"email": "abramova-i021972@postgrespro.ru", "phone": "+70272553135"}
0005434877364	B06816	4244 984102	EVDOKIYA ARKHIPOVA	{"email": "e-arkhipova-14041973@postgrespro.ru", "phone": "+70564405397"}
0005434877365	89CCA7	6588 931464	SVETLANA GAVRILOVA	{"phone": "+70690054273"}
0005434877366	89CCA7	8179 048253	ANATOLIY GAVRILOV	{"phone": "+70604501886"}
0005434877367	BC3DD1	2060 958925	LYUBOV ZAKHAROVA	{"email": "zakharoval.06081969@postgrespro.ru", "phone": "+70917558521"}
0005434877368	BC3DD1	0960 020509	ALEKSEY MOROZOV	{"email": "morozov_aleksey29081978@postgrespro.ru", "phone": "+70772710443"}
0005434877369	43307A	4868 946920	VLADIMIR ZAYCEV	{"email": "zaycev_v_17091974@postgrespro.ru", "phone": "+70759812698"}
0005434877370	43307A	8239 297807	ANASTASIYA SIDOROVA	{"email": "sidorova-a_1965@postgrespro.ru", "phone": "+70201878663"}
0005434877371	295867	3210 897338	NIKOLAY FILIPPOV	{"email": "filippov-n1968@postgrespro.ru", "phone": "+70414355999"}
0005434877372	295867	3380 565762	LYUBOV NAUMOVA	{"phone": "+70745691825"}
0005434877373	BEAD8F	4628 858528	ANDREY POPOV	{"phone": "+70972806777"}
0005434877374	37ABEC	3203 193337	NATALYA AFANASEVA	{"phone": "+70820010461"}
0005434877375	1A233F	0892 958228	NATALYA DENISOVA	{"email": "denisova-n.061965@postgrespro.ru", "phone": "+70686801509"}
0005434877376	3963D4	1097 572703	EKATERINA AFANASEVA	{"email": "eafanaseva.10081971@postgrespro.ru", "phone": "+70246610157"}
0005434877377	4AAD07	7246 784570	EVGENIYA LOGINOVA	{"email": "evgeniya_loginova-081969@postgrespro.ru", "phone": "+70698790116"}
0005434877378	331575	9530 353841	SVETLANA KONOVALOVA	{"phone": "+70867949206"}
0005434877379	5F9290	8934 426076	PAVEL ISAEV	{"email": "pavel.isaev-121975@postgrespro.ru", "phone": "+70641705972"}
0005434877380	5F9290	9602 822584	GALINA MALYSHEVA	{"email": "galina-malysheva.1972@postgrespro.ru", "phone": "+70026583372"}
0005434877381	27D766	6481 053196	VITALIY KOROLEV	{"email": "korolev.vitaliy_071974@postgrespro.ru", "phone": "+70729322172"}
0005434877382	BDDD91	7992 290562	ELENA LUKYANOVA	{"email": "lukyanova_e011982@postgrespro.ru", "phone": "+70339374814"}
0005434877383	6E1F20	9978 579754	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir-1977@postgrespro.ru", "phone": "+70935051484"}
0005434877384	2A62A7	7129 140241	IRINA VOLKOVA	{"email": "volkova-irina-111959@postgrespro.ru", "phone": "+70349876314"}
0005434877385	2A62A7	2217 210734	VARVARA KUZMINA	{"email": "varvarakuzmina_21021974@postgrespro.ru", "phone": "+70219891199"}
0005434877386	422B4B	1124 351330	SERGEY ZHURAVLEV	{"email": "sergeyzhuravlev-1961@postgrespro.ru", "phone": "+70632186224"}
0005434877387	422B4B	3726 705476	VIKTOR TARASOV	{"email": "tarasov_v.041971@postgrespro.ru", "phone": "+70487314981"}
0005434877388	7F60BC	6465 071591	ALENA ORLOVA	{"phone": "+70712633992"}
0005434877389	7F60BC	0205 407728	VYACHESLAV SOROKIN	{"email": "v_sorokin_1973@postgrespro.ru", "phone": "+70020641710"}
0005434877390	2B4D2B	9424 771317	VYACHESLAV GORBUNOV	{"email": "v_gorbunov-03101970@postgrespro.ru", "phone": "+70273236699"}
0005434877391	F9A7EB	7160 208758	LEONID STEPANOV	{"email": "l_stepanov.1972@postgrespro.ru", "phone": "+70181143251"}
0005434877392	AD3D1C	8776 375077	SVETLANA SIDOROVA	{"email": "svetlana-sidorova1980@postgrespro.ru", "phone": "+70439624351"}
0005434877393	0CCEDE	6867 219767	MIKHAIL ROMANOV	{"email": "romanov.m-30091974@postgrespro.ru", "phone": "+70506478935"}
0005434877394	0CCEDE	1834 689165	GALINA DANILOVA	{"phone": "+70810521725"}
0005434877395	7235BA	6138 388489	ALINA KOVALEVA	{"email": "a.kovaleva1968@postgrespro.ru", "phone": "+70539083950"}
0005434877396	7235BA	1290 854538	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov-27081979@postgrespro.ru", "phone": "+70591626489"}
0005434877397	7235BA	4939 142144	VERA ZAYCEVA	{"phone": "+70528382834"}
0005434877398	6608C4	2835 826582	ELENA BARANOVA	{"phone": "+70237505970"}
0005434877399	857327	9441 219868	TIGRAN GUSEV	{"email": "tgusev021976@postgrespro.ru", "phone": "+70383557939"}
0005434877400	E669DC	6949 966998	IVAN MIRONOV	{"phone": "+70842811373"}
0005434877401	F8232D	6701 559114	MATVEY VOLKOV	{"email": "volkovm-21051969@postgrespro.ru", "phone": "+70334185207"}
0005434877402	653663	4320 847794	VERA ISAEVA	{"phone": "+70952599500"}
0005434877403	05B48E	1475 656249	SVETLANA FADEEVA	{"phone": "+70936458870"}
0005434877404	34AB68	9616 408423	SERGEY MAKSIMOV	{"phone": "+70585211861"}
0005434877405	8B6493	3462 824638	ALEKSANDR MAKAROV	{"email": "makarov-a011971@postgrespro.ru", "phone": "+70139348103"}
0005434877406	7524F8	2219 368321	ANDREY ZHURAVLEV	{"email": "a_zhuravlev-26051977@postgrespro.ru", "phone": "+70519931586"}
0005434877407	47CB37	4141 396649	ALEKSANDRA SOROKINA	{"phone": "+70376092325"}
0005434877408	0ED398	9249 032058	VERONIKA FOMINA	{"email": "fominav.081960@postgrespro.ru", "phone": "+70906328139"}
0005434877409	C9BEC2	3486 028463	SVETLANA IVANOVA	{"email": "ivanova_svetlana051977@postgrespro.ru", "phone": "+70412746100"}
0005434877410	C48756	5421 592721	DENIS SOROKIN	{"phone": "+70441790128"}
0005434877411	18A6F0	6341 775363	MAKSIM RODIONOV	{"phone": "+70615859368"}
0005434877412	91974C	1372 807853	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr.20081981@postgrespro.ru", "phone": "+70236998685"}
0005434877413	91974C	8212 931458	DENIS BELOV	{"email": "d.belov_011982@postgrespro.ru", "phone": "+70821135967"}
0005434877414	A0B871	2661 834891	ELENA FILIPPOVA	{"email": "e.filippova.051965@postgrespro.ru", "phone": "+70820629524"}
0005434877415	A0B871	2105 216280	SVETLANA MEDVEDEVA	{"email": "s.medvedeva-091981@postgrespro.ru", "phone": "+70485271059"}
0005434877416	3DA6F9	5487 184522	IVAN SERGEEV	{"email": "i.sergeev.17071975@postgrespro.ru", "phone": "+70733484964"}
0005434877417	69623C	7002 169345	IVAN CHERNOV	{"email": "i_chernov-091959@postgrespro.ru", "phone": "+70236400208"}
0005434877418	68580F	9683 022847	OLEG FEDOROV	{"email": "fedorov.o.1971@postgrespro.ru", "phone": "+70470718259"}
0005434877419	D3F61F	8476 349902	VALENTINA MOISEEVA	{"email": "v_moiseeva_19091967@postgrespro.ru", "phone": "+70649610417"}
0005434877420	9DEB81	4746 418424	MIKHAIL OSIPOV	{"phone": "+70459180401"}
0005434877421	11E459	7543 807069	VALENTINA IVANOVA	{"phone": "+70647651679"}
0005434877422	018865	5811 494942	NATALYA SEMENOVA	{"phone": "+70580736464"}
0005434877423	018865	3876 644562	NAIL MELNIKOV	{"phone": "+70164873836"}
0005434877424	52317E	8877 984725	NATALYA FILATOVA	{"email": "nfilatova_15071962@postgrespro.ru", "phone": "+70234457760"}
0005434877425	FD4A0B	9344 298704	BORIS POPOV	{"phone": "+70533044647"}
0005434877426	FD4A0B	4887 989116	VLADIMIR ZHUKOV	{"phone": "+70731202127"}
0005434877427	8D069E	1509 332880	EKATERINA BARANOVA	{"email": "ebaranova.1973@postgrespro.ru", "phone": "+70628781677"}
0005434877428	F52019	0365 421899	TATYANA CHERNOVA	{"phone": "+70593705905"}
0005434877429	50F1EA	3654 577598	GALINA NAUMOVA	{"phone": "+70202498431"}
0005434877430	B00DFC	3828 459840	ALEKSEY ZAYCEV	{"phone": "+70336280232"}
0005434877431	DF1388	8290 239444	ANDREY BELOV	{"phone": "+70201730827"}
0005434877432	DF1388	0585 026502	ELENA DAVYDOVA	{"email": "edavydova.071976@postgrespro.ru", "phone": "+70272632754"}
0005434877433	81951D	0858 400429	LYUDMILA TARASOVA	{"phone": "+70941820130"}
0005434877434	6C8139	4945 041149	SERGEY AFANASEV	{"phone": "+70016057432"}
0005434877435	6C8139	9988 153201	ARKADIY TIKHONOV	{"phone": "+70592934869"}
0005434877436	31E7BC	7816 448692	VLADIMIR TARASOV	{"email": "vladimir.tarasov_29111970@postgrespro.ru", "phone": "+70068540882"}
0005434877437	4F4D3F	7902 596017	ALEKSEY EGOROV	{"email": "egorovaleksey.051969@postgrespro.ru", "phone": "+70440293978"}
0005434877438	4F4D3F	3925 398010	NURLAN TARASOV	{"phone": "+70321142120"}
0005434877439	D042F1	0585 573019	MAKSIM FEDOROV	{"phone": "+70720525610"}
0005434877440	DE4512	5425 312818	NIKOLAY NIKITIN	{"email": "nikitin-nikolay_1980@postgrespro.ru", "phone": "+70934196549"}
0005434877441	93CCBC	4388 310207	BULAT KUZNECOV	{"email": "b_kuznecov_16121965@postgrespro.ru", "phone": "+70656362901"}
0005434877442	377F6B	1384 352610	FARIT KOZLOV	{"email": "kozlov-f_031977@postgrespro.ru", "phone": "+70896578074"}
0005434877443	216C10	3704 395976	ZINAIDA GAVRILOVA	{"phone": "+70351505097"}
0005434877444	D860D5	8790 243825	NADEZHDA FEDOROVA	{"phone": "+70660396062"}
0005434877445	9AE0E5	3028 128089	VLADIMIR SOKOLOV	{"email": "vsokolov-27091967@postgrespro.ru", "phone": "+70611707014"}
0005434877446	B90845	4985 177494	NIKOLAY SOKOLOV	{"email": "sokolov.nikolay_061973@postgrespro.ru", "phone": "+70151470178"}
0005434877447	B90845	6498 013762	ANASTASIYA DAVYDOVA	{"email": "a-davydova_24081967@postgrespro.ru", "phone": "+70710152953"}
0005434877448	EED202	8344 524839	ANDREY KUZMIN	{"email": "kuzmin_andrey29101976@postgrespro.ru", "phone": "+70027463005"}
0005434877449	E9451C	1507 484534	ARINA KUDRYASHOVA	{"phone": "+70837832444"}
0005434877450	2D4CCB	9755 483025	STANISLAV KUZNECOV	{"phone": "+70947103595"}
0005434877451	6EA2B5	6957 732612	EKATERINA KALININA	{"email": "kalinina_e05031974@postgrespro.ru", "phone": "+70969185523"}
0005434877452	EDE877	2790 738564	TATYANA YUDINA	{"email": "yudina.tatyana-1967@postgrespro.ru", "phone": "+70232792367"}
0005434877453	EDE877	2885 406900	IVAN MIRONOV	{"email": "mironov_i-23021968@postgrespro.ru", "phone": "+70713905609"}
0005434877454	2EBFF8	0522 398823	NATALYA VOLKOVA	{"email": "volkovan_051981@postgrespro.ru", "phone": "+70110364378"}
0005434877455	E9AFFA	7002 373762	VYACHESLAV KRASNOV	{"email": "krasnov_v_1969@postgrespro.ru", "phone": "+70080157752"}
0005434877456	E0F9AE	7287 195169	NATALYA ROMANOVA	{"email": "romanova.n21121958@postgrespro.ru", "phone": "+70149029148"}
0005434877457	E0F9AE	9113 022556	EKATERINA MAKAROVA	{"email": "e-makarova.031974@postgrespro.ru", "phone": "+70325776634"}
0005434877458	DF43DE	9339 688239	ANNA KALININA	{"phone": "+70956743222"}
0005434877459	4A1F5C	7463 628005	ELIZAVETA TIMOFEEVA	{"email": "timofeevae1966@postgrespro.ru", "phone": "+70619475935"}
0005434877460	042A4F	6717 461783	EVGENIY YAKOVLEV	{"phone": "+70197105458"}
0005434877461	4B5405	3015 274821	DMITRIY ZHUKOV	{"email": "zhukov_dmitriy-03121967@postgrespro.ru", "phone": "+70788723157"}
0005434877462	F09EE8	2857 260246	NADEZHDA KULIKOVA	{"phone": "+70444171528"}
0005434877463	5DE596	7208 447420	ALEKSANDR BARANOV	{"email": "baranov.a13041983@postgrespro.ru", "phone": "+70338349205"}
0005434877464	8BCE61	5043 652745	VERA MASLOVA	{"email": "maslova_v.071976@postgrespro.ru", "phone": "+70257722694"}
0005434877465	8BCE61	6304 938380	OLESYA NESTEROVA	{"email": "nesterova_o_1964@postgrespro.ru", "phone": "+70318344411"}
0005434877466	379359	9013 909323	VLADIMIR GAVRILOV	{"phone": "+70692499641"}
0005434877467	7FB68D	1571 105803	EKATERINA MATVEEVA	{"email": "e-matveeva091979@postgrespro.ru", "phone": "+70625174056"}
0005434877468	3026A1	9296 738752	TATYANA KUZNECOVA	{"phone": "+70816457478"}
0005434877469	D38E40	7269 871739	FEDOR TIKHONOV	{"email": "tikhonov_fedor_18021971@postgrespro.ru", "phone": "+70819195431"}
0005434877470	E69DA8	8570 581669	DARINA TARASOVA	{"phone": "+70389144246"}
0005434877471	E69DA8	5701 549336	ALEKSEY VLASOV	{"email": "alekseyvlasov-01011970@postgrespro.ru", "phone": "+70909004032"}
0005434877472	DF42B3	3209 594526	ALEKSANDR ANDREEV	{"phone": "+70727758831"}
0005434877473	DF42B3	5683 170842	OLGA TITOVA	{"phone": "+70194239592"}
0005434877474	D0F72E	6096 534334	ANTON DAVYDOV	{"email": "davydovanton-091962@postgrespro.ru", "phone": "+70658930763"}
0005434877475	D0F72E	6361 499651	DMITRIY ZAYCEV	{"email": "dmitriyzaycev031964@postgrespro.ru", "phone": "+70203539410"}
0005434877476	4F1F1E	2115 918946	ALEKSANDR KULIKOV	{"phone": "+70306068963"}
0005434877477	83BC89	4537 593780	ROZALIYA NAZAROVA	{"email": "r-nazarova1978@postgrespro.ru", "phone": "+70953247213"}
0005434877478	27ACB8	0718 966338	OLGA FILATOVA	{"phone": "+70647860872"}
0005434877479	B40390	6215 854098	OLGA ALEKSEEVA	{"email": "alekseeva.olga1959@postgrespro.ru", "phone": "+70339075502"}
0005434877480	B70628	4074 021479	VLADISLAV NOVIKOV	{"phone": "+70896655203"}
0005434877481	B70628	5921 069486	VERA VOLKOVA	{"email": "volkova_vera011987@postgrespro.ru", "phone": "+70453032797"}
0005434877482	DCF8D0	6310 509883	GRIGORIY KARPOV	{"phone": "+70769844423"}
0005434877483	DCF8D0	5226 414807	ANDREY YAKOVLEV	{"email": "ayakovlev.121968@postgrespro.ru", "phone": "+70137849977"}
0005434877484	EC684D	5606 814663	VIKTOR NIKOLAEV	{"email": "viktor.nikolaev_081962@postgrespro.ru", "phone": "+70272956009"}
0005434877485	701654	8234 450262	MARINA NIKIFOROVA	{"phone": "+70924759386"}
0005434877486	46E80D	7854 765305	ALEKSEY GORBUNOV	{"phone": "+70013380411"}
0005434877487	4AE7CA	2206 094130	NINA KUZNECOVA	{"email": "kuznecova_n.24091963@postgrespro.ru", "phone": "+70008222336"}
0005434877488	C40CAC	7016 347387	RAMIL YAKOVLEV	{"phone": "+70718119804"}
0005434877489	C428AB	4573 886490	VLADIMIR VLASOV	{"email": "vvlasov-1960@postgrespro.ru", "phone": "+70468539679"}
0005434877490	71D17F	5392 067049	ANTON NAUMOV	{"email": "a-naumov_021971@postgrespro.ru", "phone": "+70093171021"}
0005434877491	C7F83F	7901 731379	INNA PETROVA	{"phone": "+70594996647"}
0005434877492	74E4D1	6844 987640	LYUBOV KISELEVA	{"email": "kiseleva_lyubov-1971@postgrespro.ru", "phone": "+70444478307"}
0005434877493	74E4D1	4867 988187	ELENA OSIPOVA	{"email": "osipova-elena-1982@postgrespro.ru", "phone": "+70705502133"}
0005434877494	D8B665	7501 575371	ALEKSEY KRASNOV	{"email": "krasnova-01051967@postgrespro.ru", "phone": "+70891571355"}
0005434877495	668F14	2758 231856	VALENTINA ROMANOVA	{"phone": "+70091238248"}
0005434877496	668F14	3675 304429	OLESYA MOISEEVA	{"email": "o.moiseeva.1989@postgrespro.ru", "phone": "+70550057441"}
0005434877497	359273	0331 496327	OLGA ABRAMOVA	{"email": "abramovaolga.01021977@postgrespro.ru", "phone": "+70030882537"}
0005434877498	9BC0FC	7125 905347	EKATERINA BORISOVA	{"phone": "+70530560503"}
0005434877499	92E8D8	3603 183037	VIKTOR TIMOFEEV	{"phone": "+70065612289"}
0005434877500	BBA8C6	3067 261896	VALENTINA KUZMINA	{"email": "kuzmina.valentina_1970@postgrespro.ru", "phone": "+70314479937"}
0005434877501	29011A	3205 360021	NINA PETROVA	{"phone": "+70437537202"}
0005434877502	3AE60A	8215 701914	ALEKSEY NIKITIN	{"phone": "+70213994906"}
0005434877503	5B91EC	7882 060081	SERGEY GUSEV	{"email": "s-gusev-101969@postgrespro.ru", "phone": "+70019738054"}
0005434877504	895836	0832 091043	IRINA STEPANOVA	{"phone": "+70270036745"}
0005434877505	895836	0221 805773	ANNA EFREMOVA	{"email": "efremovaanna-09031976@postgrespro.ru", "phone": "+70230442970"}
0005434877506	5A9338	0616 981980	ALEKSEY SEMENOV	{"phone": "+70960578949"}
0005434877507	A1848D	6542 542087	SERGEY TIKHONOV	{"email": "sergeytikhonov.07051983@postgrespro.ru", "phone": "+70424946027"}
0005434877508	A7B4C9	9466 868786	TATYANA IVANOVA	{"phone": "+70817184724"}
0005434877509	A7B4C9	1891 268378	LIDIYA BELOVA	{"phone": "+70728044156"}
0005434877510	6AC0AA	0371 585380	EVGENIY FROLOV	{"email": "evgeniy-frolov-091977@postgrespro.ru", "phone": "+70795172962"}
0005434877511	06DD05	3782 229980	ALIYA MARTYNOVA	{"phone": "+70935470205"}
0005434877512	835861	4880 899334	NINA KUZNECOVA	{"email": "kuznecova.nina_1974@postgrespro.ru", "phone": "+70273272358"}
0005434877513	835861	1443 991440	OLGA LEBEDEVA	{"email": "lebedeva_olga-1963@postgrespro.ru", "phone": "+70440389959"}
0005434877514	DBD5F7	7250 425521	ANATOLIY ZAKHAROV	{"phone": "+70308742446"}
0005434877515	72416E	3656 009675	ELENA TARASOVA	{"phone": "+70605121432"}
0005434877516	0942C6	2938 145908	SVETLANA ILINA	{"email": "silina17081969@postgrespro.ru", "phone": "+70810958497"}
0005434877517	DC06F2	6447 190571	EVGENIY SIDOROV	{"email": "e.sidorov-30081979@postgrespro.ru", "phone": "+70711940537"}
0005434877518	DC06F2	3532 337437	ALEKSEY GERASIMOV	{"email": "gerasimova_051960@postgrespro.ru", "phone": "+70910026269"}
0005434877520	28793D	6625 035083	VIKTORIYA AFANASEVA	{"email": "afanaseva-viktoriya.091971@postgrespro.ru", "phone": "+70225569802"}
0005434877521	C1363D	5969 322437	MARIYA NOVIKOVA	{"email": "novikova-m-14121975@postgrespro.ru", "phone": "+70332232259"}
0005434877522	C1363D	5689 828864	NIKOLAY NAUMOV	{"email": "n_naumov_07091980@postgrespro.ru", "phone": "+70168961337"}
0005434877523	49A67B	0085 035680	LIDIYA ROMANOVA	{"email": "romanova_lidiya-1961@postgrespro.ru", "phone": "+70369049327"}
0005434877524	49A67B	4484 815438	YANA MAKAROVA	{"phone": "+70379104612"}
0005434877525	AA31BB	8931 729470	NIKOLAY ZAYCEV	{"email": "nzaycev-1970@postgrespro.ru", "phone": "+70823443818"}
0005434877526	B05B17	3146 556610	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila_09021977@postgrespro.ru", "phone": "+70248284682"}
0005434877527	9CF9AF	4733 580808	TATYANA DENISOVA	{"phone": "+70733176419"}
0005434877528	C96C7A	0889 345925	NIKOLAY VASILEV	{"phone": "+70519995815"}
0005434877529	C96C7A	7813 140649	ANDREY ZHUKOV	{"email": "andrey-zhukov_1971@postgrespro.ru", "phone": "+70173169746"}
0005434877530	C1E065	1188 577145	VIKTOR BONDARENKO	{"phone": "+70480277543"}
0005434877531	A0202D	1132 542130	ALEKSANDR EGOROV	{"phone": "+70761338124"}
0005434877532	A0202D	1985 804398	IRINA DAVYDOVA	{"phone": "+70762872518"}
0005434877533	800A2C	8928 108982	KIRILL MAKAROV	{"email": "makarov-k.041966@postgrespro.ru", "phone": "+70996244255"}
0005434877534	2F4F9F	7256 940964	OLEG AFANASEV	{"email": "afanasev_oleg.26011973@postgrespro.ru", "phone": "+70908895400"}
0005434877535	2F4F9F	6627 619083	STANISLAV SOLOVEV	{"email": "solovevstanislav.11111969@postgrespro.ru", "phone": "+70720855674"}
0005434877536	9F3EB1	7327 418160	OLGA ZAKHAROVA	{"email": "olga.zakharova011978@postgrespro.ru", "phone": "+70697704628"}
0005434877537	9F3EB1	5031 639166	VLADIMIR ANTONOV	{"phone": "+70975074251"}
0005434877538	7849F7	3014 287191	NADEZHDA KOZLOVA	{"email": "n-kozlova.1972@postgrespro.ru", "phone": "+70816681587"}
0005434877539	7849F7	5686 999691	NADEZHDA RODIONOVA	{"email": "rodionova.n.011973@postgrespro.ru", "phone": "+70063483964"}
0005434877540	C93B8F	8747 822668	ALEKSANDR MIKHAYLOV	{"phone": "+70282124009"}
0005434877541	C93B8F	5696 630114	DARYA LUKYANOVA	{"phone": "+70382779686"}
0005434877542	E003A0	6743 930642	ALFIYA NESTEROVA	{"phone": "+70316845716"}
0005434877543	E003A0	1727 686018	EKATERINA KUZNECOVA	{"email": "ekuznecova04121987@postgrespro.ru", "phone": "+70817725183"}
0005434877544	DE342C	9769 749682	NADEZHDA VOLKOVA	{"phone": "+70413502951"}
0005434877545	1A3133	0451 754140	OLGA IVANOVA	{"phone": "+70536978317"}
0005434877546	860D0A	4724 584691	LYUDMILA BORISOVA	{"email": "lyudmila.borisova051965@postgrespro.ru", "phone": "+70792698766"}
0005434877547	780904	3739 876322	IGOR ALEKSEEV	{"phone": "+70883953724"}
0005434877548	25D053	7543 813108	ARTEM GERASIMOV	{"phone": "+70104967826"}
0005434877549	593389	6363 680619	EVGENIY VOLKOV	{"phone": "+70305946842"}
0005434877550	593389	6639 088598	LYUBOV SOROKINA	{"email": "l.sorokina06041974@postgrespro.ru", "phone": "+70162705651"}
0005434877551	20B258	4152 110979	YULIYA VOLKOVA	{"phone": "+70439783023"}
0005434877552	853F8B	5853 935123	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.121976@postgrespro.ru", "phone": "+70849798063"}
0005434877553	853F8B	2201 085222	IRINA MAKAROVA	{"email": "imakarova_02091974@postgrespro.ru", "phone": "+70400179842"}
0005434877554	853F8B	3540 893497	VLADIMIR VASILEV	{"phone": "+70885830114"}
0005434877555	3F4CCB	2470 095393	ANTONINA DMITRIEVA	{"phone": "+70074532961"}
0005434877556	D7365E	2265 385092	SERGEY SOROKIN	{"phone": "+70515589545"}
0005434877557	F94E8D	9847 926863	VYACHESLAV ORLOV	{"email": "orlov.v.071970@postgrespro.ru", "phone": "+70546626643"}
0005434877558	F94E8D	3126 227085	RAISA KUZNECOVA	{"email": "raisa.kuznecova12101968@postgrespro.ru", "phone": "+70643183815"}
0005434877559	F94E8D	4655 408924	ELENA SEMENOVA	{"email": "semenova.e-1969@postgrespro.ru", "phone": "+70424291091"}
0005434877560	1A8140	1167 164528	VIKTOR EGOROV	{"email": "egorov.viktor.1966@postgrespro.ru", "phone": "+70851458104"}
0005434877561	9ED4EB	2569 778329	ANDREY ZAKHAROV	{"email": "a.zakharov.05101962@postgrespro.ru", "phone": "+70310057784"}
0005434877562	F31FEA	9516 699991	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr14071975@postgrespro.ru", "phone": "+70587559515"}
0005434877563	3714D0	2787 030207	IVAN GUSEV	{"email": "gusev_i-1972@postgrespro.ru", "phone": "+70777356659"}
0005434877564	3714D0	2861 636127	KONSTANTIN ZAYCEV	{"email": "konstantin-zaycev-061969@postgrespro.ru", "phone": "+70687245618"}
0005434877565	CABB63	1753 646484	LYUBOV MAKSIMOVA	{"phone": "+70361336507"}
0005434877566	BFB29A	5854 263577	SERGEY IVANOV	{"email": "ivanov_sergey_1969@postgrespro.ru", "phone": "+70382222493"}
0005434877567	4001CF	7290 043121	ALEKSANDR VOLKOV	{"phone": "+70943393505"}
0005434877568	324DD2	3972 804273	OLEG SCHERBAKOV	{"phone": "+70990334596"}
0005434877569	324DD2	4008 573190	TATYANA ILINA	{"phone": "+70480575996"}
0005434877570	EAC170	3495 508961	ANNA KOMAROVA	{"email": "komarova.a26121971@postgrespro.ru", "phone": "+70774781907"}
0005434877571	EAC170	8735 075923	YULIYA NIKITINA	{"email": "nikitina.y.14101979@postgrespro.ru", "phone": "+70957434266"}
0005434877572	52D4E1	7203 579849	ALEKSANDRA SOLOVEVA	{"email": "aleksandra_soloveva-1974@postgrespro.ru", "phone": "+70230499285"}
0005434877795	3685C7	3329 220862	OKSANA ZHURAVLEVA	{"phone": "+70668146716"}
0005434877573	52D4E1	2936 949752	LIDIYA SIDOROVA	{"email": "lidiyasidorova_1969@postgrespro.ru", "phone": "+70072681744"}
0005434877574	261B3C	0693 803307	TATYANA MIRONOVA	{"phone": "+70246779524"}
0005434877575	261B3C	6120 806992	VIKTORIYA ORLOVA	{"phone": "+70256024375"}
0005434877576	15381B	8018 907808	VITALIY ALEKSANDROV	{"email": "v_aleksandrov081966@postgrespro.ru", "phone": "+70901293608"}
0005434877577	D95DEA	0084 271895	TATYANA IVANOVA	{"email": "ivanova-t.011976@postgrespro.ru", "phone": "+70176853333"}
0005434877579	E99D93	1301 080922	VALENTINA KUZNECOVA	{"phone": "+70826664211"}
0005434877580	330E4C	0599 732616	MARGARITA BELOVA	{"email": "m_belova.1960@postgrespro.ru", "phone": "+70234137746"}
0005434877581	DECDDB	7099 283436	LIDIYA STEPANOVA	{"phone": "+70046286256"}
0005434877582	41F7C4	4457 035793	NATALYA MARTYNOVA	{"phone": "+70699036099"}
0005434877583	2218E8	2646 627207	VALENTINA KRASNOVA	{"phone": "+70918884765"}
0005434877584	F3288A	3778 356978	TAMARA AKIMOVA	{"email": "t.akimova-101985@postgrespro.ru", "phone": "+70979884217"}
0005434877585	CB4759	1295 407041	YULIYA BELYAEVA	{"phone": "+70408069563"}
0005434877586	CB4759	9985 846339	OLGA KUZNECOVA	{"email": "kuznecova.olga-22071973@postgrespro.ru", "phone": "+70494396567"}
0005434877587	7C3603	7390 816181	SERGEY FEDOROV	{"phone": "+70682100247"}
0005434877588	56294D	9468 415832	TATYANA NOVIKOVA	{"email": "novikovat_25101969@postgrespro.ru", "phone": "+70965234113"}
0005434877589	8C803B	4096 349797	GENNADIY BELOV	{"phone": "+70765845833"}
0005434877590	DE8098	0684 624820	VLADIMIR VASILEV	{"email": "vasilev-vladimir_21091975@postgrespro.ru", "phone": "+70226037948"}
0005434877591	DE8098	5363 278328	DARYA KUZNECOVA	{"phone": "+70860229868"}
0005434877592	AC822D	6876 321129	MARIYA FADEEVA	{"phone": "+70258170573"}
0005434877593	03BBD8	1962 949806	MARINA SERGEEVA	{"phone": "+70037795769"}
0005434877594	03BBD8	1844 275872	ALEKSEY POPOV	{"email": "apopov_01071962@postgrespro.ru", "phone": "+70902333849"}
0005434877595	0F14FE	8611 931352	ALIYA YAKOVLEVA	{"phone": "+70270732346"}
0005434877596	0F14FE	7894 560585	IRINA SMIRNOVA	{"phone": "+70683943916"}
0005434877597	479312	4200 301421	ELENA MOROZOVA	{"email": "morozovae_1974@postgrespro.ru", "phone": "+70513762430"}
0005434877598	70344F	9377 183704	MARIYA NIKOLAEVA	{"email": "mariya-nikolaeva-1976@postgrespro.ru", "phone": "+70122459177"}
0005434877599	70344F	4312 048034	ALEKSEY SCHERBAKOV	{"phone": "+70622229286"}
0005434877600	70344F	8875 391707	GALINA EFREMOVA	{"email": "galina-efremova_19051972@postgrespro.ru", "phone": "+70373555506"}
0005434877601	0E6BC5	4775 034411	ALEKSANDR SEMENOV	{"email": "semenovaleksandr031972@postgrespro.ru", "phone": "+70978792588"}
0005434877602	0E6BC5	4162 780966	TATYANA KONDRATEVA	{"email": "t.kondrateva_1972@postgrespro.ru", "phone": "+70828526700"}
0005434877603	FE1420	0723 729711	LIDIYA LAZAREVA	{"phone": "+70252948927"}
0005434877604	479CDD	3067 112840	KIRILL BORISOV	{"email": "borisov_k-06121968@postgrespro.ru", "phone": "+70640913626"}
0005434877605	479CDD	5202 271361	NIKOLAY KULIKOV	{"email": "n-kulikov.10031970@postgrespro.ru", "phone": "+70791564382"}
0005434877606	06713E	5914 645085	ALEKSANDR SOROKIN	{"email": "a_sorokin-081980@postgrespro.ru", "phone": "+70335393761"}
0005434877607	FCC64C	8185 243912	RAVZA STEPANOVA	{"email": "ravza_stepanova081969@postgrespro.ru", "phone": "+70727918747"}
0005434877608	FCC64C	5840 199741	ANNA LOGINOVA	{"email": "a-loginova.011972@postgrespro.ru", "phone": "+70608618630"}
0005434877609	FCC64C	9135 902424	GALINA FILATOVA	{"phone": "+70083362629"}
0005434877610	533B02	4039 388537	ANDREY GAVRILOV	{"email": "andrey.gavrilov-29111976@postgrespro.ru", "phone": "+70284036254"}
0005434877611	60ADD3	2113 870915	NATALYA BELYAEVA	{"email": "natalyabelyaeva_22051978@postgrespro.ru", "phone": "+70449862439"}
0005434877612	60ADD3	1904 704458	ULYANA KOZLOVA	{"phone": "+70303331195"}
0005434877613	7F4314	4549 959315	ALEKSANDR FOMIN	{"phone": "+70912025246"}
0005434877614	5F31DF	2342 501992	VLADIMIR GUSEV	{"phone": "+70560899680"}
0005434877615	3CE033	4031 537150	KONSTANTIN KARPOV	{"email": "karpovkonstantin071978@postgrespro.ru", "phone": "+70344420677"}
0005434877616	2E4F3D	2429 405646	VLADIMIR CHERNOV	{"email": "v_chernov10081963@postgrespro.ru", "phone": "+70127135661"}
0005434877617	903E97	1130 461384	SERGEY ROMANOV	{"email": "sergey.romanov1968@postgrespro.ru", "phone": "+70312729674"}
0005434877618	903E97	5521 915907	SVETLANA ZAKHAROVA	{"phone": "+70678432978"}
0005434877619	60C980	1474 492839	DMITRIY POPOV	{"email": "popov-d051965@postgrespro.ru", "phone": "+70624147280"}
0005434877620	60C980	0264 463614	RAISA KUZNECOVA	{"phone": "+70271958631"}
0005434877621	10FC89	8648 219533	LYAYSAN RODIONOVA	{"phone": "+70308940130"}
0005434877622	10FC89	9268 083681	LYUDMILA BELYAEVA	{"phone": "+70811215462"}
0005434877623	08862F	8540 382074	NINA GUSEVA	{"phone": "+70464908562"}
0005434877624	8DB36D	5639 551629	ASIYA SAVELEVA	{"phone": "+70038877566"}
0005434877625	0CDA25	4791 570599	OLGA KUZNECOVA	{"phone": "+70459297594"}
0005434877626	B50583	5634 848821	TIMUR EGOROV	{"phone": "+70801925223"}
0005434877627	66466E	6881 483805	NINA SMIRNOVA	{"email": "nina.smirnova11121965@postgrespro.ru", "phone": "+70926414694"}
0005434877628	66466E	2773 868719	NIKOLAY BARANOV	{"phone": "+70304661435"}
0005434877629	D88ECD	5707 953586	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_111970@postgrespro.ru", "phone": "+70269123382"}
0005434877630	D88ECD	4231 076241	RUSTAM KUZNECOV	{"email": "kuznecov_rustam_31011966@postgrespro.ru", "phone": "+70793580700"}
0005434877631	25DFB1	1284 238284	ROMAN MELNIKOV	{"email": "r-melnikov-101959@postgrespro.ru", "phone": "+70981255317"}
0005434877632	423D83	8554 932954	ELDAR SOKOLOV	{"email": "sokolov-eldar-10081983@postgrespro.ru", "phone": "+70508162255"}
0005434877633	EECC30	0714 977714	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr041971@postgrespro.ru", "phone": "+70680228134"}
0005434877634	D81F50	1283 626786	IGOR SAVELEV	{"phone": "+70731759596"}
0005434877635	2EA51E	3156 954985	SVETLANA DMITRIEVA	{"phone": "+70391459126"}
0005434877636	CC69F5	2295 113801	EVGENIY ORLOV	{"phone": "+70219136207"}
0005434877637	CC69F5	3930 491408	OLESYA ANDREEVA	{"email": "olesyaandreeva12091968@postgrespro.ru", "phone": "+70232389738"}
0005434877638	4D6F17	7543 119768	ALEKSANDR ALEKSEEV	{"phone": "+70500046199"}
0005434877639	4D6F17	4784 247290	DIANA ILINA	{"phone": "+70199956997"}
0005434877640	4D6F17	4856 138917	GALINA IVANOVA	{"phone": "+70382396355"}
0005434877641	DD538C	9861 983178	VASILIY IVANOV	{"email": "vasiliy-ivanov.17061978@postgrespro.ru", "phone": "+70227678652"}
0005434877642	BCCEFB	2676 354569	MAKSIM FEDOTOV	{"email": "fedotov.maksim21031978@postgrespro.ru", "phone": "+70867457073"}
0005434877643	3583C6	3178 891258	ALEKSANDR CHERNOV	{"email": "aleksandr_chernov031968@postgrespro.ru", "phone": "+70674182798"}
0005434877644	651EBD	2676 389655	ELENA NAZAROVA	{"email": "e_nazarova23121970@postgrespro.ru", "phone": "+70127490440"}
0005434877645	F5B44E	7726 774223	VERA DENISOVA	{"email": "denisova_vera.1970@postgrespro.ru", "phone": "+70216913966"}
0005434877646	F068AD	0177 050421	SERGEY MAKAROV	{"phone": "+70089740088"}
0005434877647	B2E2AF	2476 789429	LYUBOV KUZNECOVA	{"phone": "+70246785085"}
0005434877648	5B6744	5596 151514	POLINA MAKSIMOVA	{"phone": "+70557188517"}
0005434877649	5B6744	1294 835900	ANASTASIYA KALININA	{"phone": "+70542333716"}
0005434877650	5B6744	3477 464030	TATYANA TIKHONOVA	{"email": "tikhonova-t-23071982@postgrespro.ru", "phone": "+70908601499"}
0005434877651	EDFB56	3768 698922	SERGEY IVANOV	{"email": "ivanov.s_22101978@postgrespro.ru", "phone": "+70663043003"}
0005434877652	5FAC37	6566 953476	IRINA SEMENOVA	{"email": "irina-semenova.101971@postgrespro.ru", "phone": "+70605649946"}
0005434877653	7AA050	4771 218645	TATYANA VOLKOVA	{"phone": "+70363737735"}
0005434877654	CFD0A5	1440 684828	LYUBOV BELOVA	{"email": "lyubov.belova.1977@postgrespro.ru", "phone": "+70111547071"}
0005434877655	707054	5211 761434	YANA LOGINOVA	{"email": "loginova.yana-21081970@postgrespro.ru", "phone": "+70544722083"}
0005434877656	B52550	9479 642856	EKATERINA PAVLOVA	{"phone": "+70923079267"}
0005434877657	CD3F78	7450 451119	GALINA DAVYDOVA	{"email": "galinadavydova_1975@postgrespro.ru", "phone": "+70277224793"}
0005434877658	4C3E48	0111 791441	VALENTINA GERASIMOVA	{"email": "v-gerasimova.17031973@postgrespro.ru", "phone": "+70540748377"}
0005434877659	4C3E48	6966 915467	MAKSIM IVANOV	{"email": "ivanov.m1966@postgrespro.ru", "phone": "+70176217667"}
0005434877660	4C3E48	3677 467240	OKSANA ORLOVA	{"phone": "+70457923369"}
0005434877661	4E9026	4914 358554	NATALYA KUDRYASHOVA	{"phone": "+70660026319"}
0005434877662	367385	1488 110476	ANTON NAZAROV	{"email": "nazarov.anton-1971@postgrespro.ru", "phone": "+70046799053"}
0005434877663	367385	5668 858021	ALEKSEY VOROBEV	{"email": "vorobevaleksey121969@postgrespro.ru", "phone": "+70556505563"}
0005434877664	303476	5043 006384	NATALYA EGOROVA	{"phone": "+70858352885"}
0005434877665	303476	5798 751079	DARYA ERMAKOVA	{"phone": "+70104934982"}
0005434877666	38FF77	5128 624174	ALEKSANDR KUZMIN	{"phone": "+70968475447"}
0005434877667	38FF77	9480 294312	KRISTINA KUZNECOVA	{"phone": "+70120854774"}
0005434877668	6B6085	0637 454678	ANNA NOVIKOVA	{"phone": "+70235881706"}
0005434877669	6B6085	9639 388476	ELENA SERGEEVA	{"phone": "+70931353885"}
0005434877670	65559D	2832 451177	EVGENIYA VLASOVA	{"phone": "+70671529742"}
0005434877671	D5B91E	6014 908576	ALENA KOMAROVA	{"email": "a_komarova_1967@postgrespro.ru", "phone": "+70843838744"}
0005434877672	19D0FF	2497 054399	ALEKSANDR ROMANOV	{"phone": "+70902301080"}
0005434877673	19D0FF	2909 712661	EVGENIYA ILINA	{"email": "ilina_evgeniya.29071975@postgrespro.ru", "phone": "+70321996869"}
0005434877674	578630	0914 502174	OKSANA MAKAROVA	{"email": "makarova-o_1979@postgrespro.ru", "phone": "+70788366447"}
0005434877675	578630	0056 422469	ALEKSEY PAVLOV	{"email": "pavlovaleksey_19111975@postgrespro.ru", "phone": "+70130287806"}
0005434877676	6BD0F4	7059 448770	ALEKSEY KRASNOV	{"email": "krasnov_a_14051968@postgrespro.ru", "phone": "+70443556161"}
0005434877677	C90B8A	0252 732273	ALEKSEY OSIPOV	{"email": "aleksey.osipov-071976@postgrespro.ru", "phone": "+70435120469"}
0005434877678	30D55B	0471 397892	NIKOLAY MIKHAYLOV	{"phone": "+70123801520"}
0005434877679	23DC5E	6966 777254	SVETLANA IVANOVA	{"email": "ivanova_svetlana.061975@postgrespro.ru", "phone": "+70373840964"}
0005434877680	23DC5E	5983 920446	SVETLANA MAKSIMOVA	{"phone": "+70150609205"}
0005434877681	2E8AA8	7336 052708	OKSANA MAKSIMOVA	{"phone": "+70652603449"}
0005434877682	2E8AA8	0065 710063	ANASTASIYA BARANOVA	{"email": "baranova_a-24011977@postgrespro.ru", "phone": "+70156302471"}
0005434877683	FCC8F7	7796 427821	ALEKSANDR ANDREEV	{"phone": "+70310992085"}
0005434878131	C36CBE	3833 370233	NIKOLAY SMIRNOV	{"phone": "+70401109072"}
0005434877684	FCC8F7	1018 770696	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko.041977@postgrespro.ru", "phone": "+70546802760"}
0005434877685	E84322	9780 814706	SERGEY BORISOV	{"phone": "+70715821158"}
0005434877686	4AA8A4	3107 218992	VIKTOR SEMENOV	{"phone": "+70536329486"}
0005434877687	A8422E	6990 116315	VITALIY SCHERBAKOV	{"phone": "+70749689631"}
0005434877688	A8422E	5765 272117	AZAT IVANOV	{"email": "a.ivanov-29041972@postgrespro.ru", "phone": "+70297363274"}
0005434877689	59133B	6002 973897	VLADIMIR GUSEV	{"email": "gusevvladimir_1964@postgrespro.ru", "phone": "+70009713651"}
0005434877690	949821	3172 556424	OLEG ROMANOV	{"email": "romanov.o.1970@postgrespro.ru", "phone": "+70976283880"}
0005434877691	949821	5309 995102	MAKSIM NOVIKOV	{"phone": "+70799564050"}
0005434877692	949821	2002 102889	LEONID MAKAROV	{"email": "leonid-makarov1962@postgrespro.ru", "phone": "+70520755856"}
0005434877693	F5168D	5559 167525	ELENA BARANOVA	{"email": "elenabaranova_111991@postgrespro.ru", "phone": "+70617399632"}
0005434877694	F5168D	7086 171901	LYUDMILA SOKOLOVA	{"email": "l.sokolova.1973@postgrespro.ru", "phone": "+70117604149"}
0005434877695	0035EF	1593 007951	VLADIMIR BELOV	{"email": "vladimir-belov.041970@postgrespro.ru", "phone": "+70472814435"}
0005434877696	09D72E	2230 929992	NATALYA MAKSIMOVA	{"email": "natalya.maksimova091969@postgrespro.ru", "phone": "+70619304336"}
0005434877697	09D72E	3906 152216	VLADIMIR ZHUKOV	{"phone": "+70992345787"}
0005434877757	AC0DC4	4636 909476	SVETLANA LUKYANOVA	{"phone": "+70119111995"}
0005434877698	09D72E	6804 229854	PAVEL ANTONOV	{"email": "antonov_pavel_1971@postgrespro.ru", "phone": "+70203742315"}
0005434877699	0A5572	9050 423146	BORIS SMIRNOV	{"phone": "+70030909403"}
0005434877700	9C3230	8727 599143	STANISLAV SOROKIN	{"email": "sorokin.stanislav.011972@postgrespro.ru", "phone": "+70912993688"}
0005434877701	4F62A4	6030 023997	YURIY KUZMIN	{"phone": "+70100360568"}
0005434877702	4F62A4	6968 973666	KSENIYA DAVYDOVA	{"email": "kseniya-davydova.11061969@postgrespro.ru", "phone": "+70463261182"}
0005434877703	F64DA2	8802 789493	GALINA ISAEVA	{"email": "galinaisaeva-1961@postgrespro.ru", "phone": "+70277604599"}
0005434877704	A79C80	9546 147156	DMITRIY FROLOV	{"phone": "+70450938809"}
0005434877705	A79C80	5270 661625	LEONID OSIPOV	{"email": "l-osipov_27111973@postgrespro.ru", "phone": "+70453378572"}
0005434877706	F870D4	2394 507384	ANNA ALEKSEEVA	{"email": "annaalekseeva-1974@postgrespro.ru", "phone": "+70874982026"}
0005434877707	1D1081	4737 219599	SERGEY PAVLOV	{"email": "pavlovsergey.14101963@postgrespro.ru", "phone": "+70263757175"}
0005434877708	1D1081	7689 948966	ANNA ZHUKOVA	{"phone": "+70704130862"}
0005434877709	4BFC1A	0440 143641	NATALYA NIKITINA	{"phone": "+70212513611"}
0005434877710	8160EF	8671 445384	NIKOLAY ANDREEV	{"email": "andreev-n_1981@postgrespro.ru", "phone": "+70565030888"}
0005434877711	DF1E46	1809 165084	NINA KISELEVA	{"phone": "+70488588482"}
0005434877712	396F54	3951 254713	ANNA ARKHIPOVA	{"email": "arkhipova-a1974@postgrespro.ru", "phone": "+70620080327"}
0005434877713	35A756	1414 254099	ALEKSANDR SOKOLOV	{"email": "asokolov06051976@postgrespro.ru", "phone": "+70054682409"}
0005434877714	35A756	6627 570575	YANA SERGEEVA	{"email": "sergeeva-yana-08011976@postgrespro.ru", "phone": "+70177276888"}
0005434877715	ECE1CC	1757 576719	NATALYA POPOVA	{"phone": "+70639447994"}
0005434877716	719BFC	3601 921304	NATALYA ALEKSANDROVA	{"phone": "+70269228526"}
0005434877717	616250	9332 638341	VALERIY MAKAROV	{"email": "makarovv-1968@postgrespro.ru", "phone": "+70380739297"}
0005434877718	8F6BF4	9202 643215	NIKOLAY IVANOV	{"phone": "+70540114245"}
0005434877719	FA3EEF	7576 972865	ANASTASIYA NIKITINA	{"email": "anastasiya-nikitina_1970@postgrespro.ru", "phone": "+70037960358"}
0005434877720	FA3EEF	7882 824283	IRINA MASLOVA	{"phone": "+70200734313"}
0005434877721	450C08	3245 004819	ALEKSEY NAUMOV	{"email": "anaumov1968@postgrespro.ru", "phone": "+70832116481"}
0005434877722	6CC912	4411 766273	TAMARA ANDREEVA	{"email": "andreeva-tamara.24091978@postgrespro.ru", "phone": "+70716783604"}
0005434877723	5EFE1B	8156 881440	TAISIYA NIKOLAEVA	{"phone": "+70264110269"}
0005434877724	E2F40F	2375 337594	ELENA NAUMOVA	{"phone": "+70096679469"}
0005434877725	FA22D1	1914 710375	VIKTOR KUZNECOV	{"email": "kuznecov.v041968@postgrespro.ru", "phone": "+70362172408"}
0005434877726	2DDA1D	5311 349282	NIKITA STEPANOV	{"email": "stepanov_nikita27051971@postgrespro.ru", "phone": "+70193931939"}
0005434877727	2DDA1D	5141 164590	SVETLANA ORLOVA	{"phone": "+70970566343"}
0005434877728	85C0E7	1028 447486	ROMAN KRASNOV	{"email": "romankrasnov.021967@postgrespro.ru", "phone": "+70549720917"}
0005434877729	E8F8E3	4236 187511	SERGEY FROLOV	{"phone": "+70167603333"}
0005434877730	E72F35	6567 798135	VITALIY ILIN	{"phone": "+70270399985"}
0005434877731	4438DF	1129 435364	VALERIY ZAKHAROV	{"phone": "+70439488983"}
0005434877732	ABF940	3726 105499	ARTEM FOMIN	{"phone": "+70656623591"}
0005434877733	ABF940	6802 880668	SERGEY PETROV	{"phone": "+70655152934"}
0005434877734	3D2A1F	4004 488634	SERGEY NAZAROV	{"phone": "+70372553307"}
0005434877735	6B5C2E	9892 267185	VYACHESLAV ILIN	{"email": "ilin_v_24071967@postgrespro.ru", "phone": "+70899649009"}
0005434877736	6B5C2E	6036 206035	OKSANA NAZAROVA	{"email": "nazarovaoksana.1977@postgrespro.ru", "phone": "+70652677289"}
0005434877737	E9A850	9011 209071	EKATERINA FEDOROVA	{"email": "fedorova-ekaterina-09031977@postgrespro.ru", "phone": "+70134747658"}
0005434877738	F5C83E	3967 047634	RUSTEM SAVELEV	{"phone": "+70966147965"}
0005434877739	F5C83E	6929 790626	TATYANA MOISEEVA	{"email": "moiseeva-tatyana-051968@postgrespro.ru", "phone": "+70151655153"}
0005434877740	BDED4F	3456 479872	SERGEY FILIPPOV	{"email": "filippovs111971@postgrespro.ru", "phone": "+70285514801"}
0005434877741	BDED4F	9132 804406	VALERIY NIKOLAEV	{"email": "valeriynikolaev.17031967@postgrespro.ru", "phone": "+70115236256"}
0005434877742	892D60	7991 618512	VIKTOR KUZNECOV	{"email": "kuznecovv_18081966@postgrespro.ru", "phone": "+70054782580"}
0005434877743	892D60	4463 779054	ANNA OSIPOVA	{"phone": "+70777429622"}
0005434877744	892D60	7745 137636	VASILIY FILIPPOV	{"phone": "+70594429190"}
0005434877745	4C4634	7088 315426	EVGENIY MEDVEDEV	{"email": "e_medvedev-011970@postgrespro.ru", "phone": "+70384122886"}
0005434877746	4033CD	0031 836719	NATALYA FROLOVA	{"email": "frolova-natalya-1974@postgrespro.ru", "phone": "+70503741057"}
0005434877747	68C294	8058 663740	RUSLAN DMITRIEV	{"phone": "+70954943000"}
0005434877748	F5B98D	1949 457538	VALERIY PETROV	{"email": "vpetrov29011971@postgrespro.ru", "phone": "+70136737344"}
0005434877749	EF0C57	6294 522967	ELENA KOZLOVA	{"email": "e_kozlova.1971@postgrespro.ru", "phone": "+70711959621"}
0005434877750	E394E4	7867 154006	VERONIKA ABRAMOVA	{"email": "abramovav_1966@postgrespro.ru", "phone": "+70712745846"}
0005434877751	E394E4	1999 153987	VYACHESLAV SMIRNOV	{"email": "v_smirnov-27041974@postgrespro.ru", "phone": "+70849223124"}
0005434877752	7D4671	3576 886233	YURIY BARANOV	{"email": "y.baranov.1958@postgrespro.ru", "phone": "+70091864540"}
0005434877753	7D4671	4167 018621	SVETLANA MIRONOVA	{"email": "mironova_svetlana.10011981@postgrespro.ru", "phone": "+70815551453"}
0005434877754	389307	2286 959817	RAFAIL SOLOVEV	{"email": "solovevr-1974@postgrespro.ru", "phone": "+70601095515"}
0005434877755	170CBC	7935 916727	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr-24121984@postgrespro.ru", "phone": "+70203245780"}
0005434877756	AC0DC4	0868 939291	MIKHAIL ZHURAVLEV	{"email": "m-zhuravlev.1962@postgrespro.ru", "phone": "+70946626502"}
0005434877758	AC0DC4	9298 069938	TATYANA TIKHONOVA	{"phone": "+70233647969"}
0005434877759	7F4AFE	5678 907908	ALEKSEY NIKOLAEV	{"phone": "+70528030774"}
0005434877760	7F4AFE	2743 296964	ALEKSANDR MIRONOV	{"email": "aleksandrmironov081975@postgrespro.ru", "phone": "+70464018048"}
0005434877761	59DD1C	2090 981150	SVETLANA ARKHIPOVA	{"email": "s-arkhipova_031972@postgrespro.ru", "phone": "+70021500894"}
0005434877762	3F2922	8244 218023	SNEZHANA NAZAROVA	{"email": "snezhana_nazarova.1974@postgrespro.ru", "phone": "+70663002901"}
0005434877763	3F2922	5030 314757	KLAVDIYA NAZAROVA	{"phone": "+70473359926"}
0005434877764	4BCCA7	0779 406787	ANNA TIKHONOVA	{"phone": "+70100476722"}
0005434877765	DE79D0	4950 377626	IRAIDA KRASNOVA	{"email": "krasnova-i-011978@postgrespro.ru", "phone": "+70886717394"}
0005434877766	E3B21A	7223 634587	OLGA BARANOVA	{"email": "o.baranova.1982@postgrespro.ru", "phone": "+70229098940"}
0005434877767	CFC288	3546 209088	ALEKSEY ANDREEV	{"email": "andreev.a_22071965@postgrespro.ru", "phone": "+70307123423"}
0005434877768	6A808A	4975 777186	ALEKSANDR MAKAROV	{"phone": "+70766212866"}
0005434877769	67A709	2419 013262	ANTONINA TROFIMOVA	{"phone": "+70082660829"}
0005434877770	1056F6	2075 165136	SERGEY STEPANOV	{"phone": "+70148308065"}
0005434877771	1056F6	5540 439035	SVETLANA VOLKOVA	{"phone": "+70042083199"}
0005434877772	1E0908	5671 888377	VLADIMIR NOVIKOV	{"email": "v_novikov-091976@postgrespro.ru", "phone": "+70900007317"}
0005434877773	1E0908	7128 523475	SERGEY KUDRYASHOV	{"phone": "+70742453154"}
0005434877774	56F1BA	5906 758497	OLEG ZAKHAROV	{"phone": "+70209765523"}
0005434877775	56F1BA	6375 814633	ANDREY KISELEV	{"phone": "+70358715135"}
0005434877776	A99EE4	1702 687373	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov.1962@postgrespro.ru", "phone": "+70976802487"}
0005434877777	A99EE4	4840 572288	ALEKSEY KOROLEV	{"email": "korolev_aleksey_15111976@postgrespro.ru", "phone": "+70802950666"}
0005434877778	51799A	1540 942233	EVGENIY MELNIKOV	{"phone": "+70774985100"}
0005434877779	A1E96F	0007 667253	DMITRIY NIKITIN	{"email": "d.nikitin_25091970@postgrespro.ru", "phone": "+70747521081"}
0005434877780	11215B	2203 558103	OLEG SMIRNOV	{"phone": "+70718976262"}
0005434877781	F993AF	6778 900460	SERGEY ABRAMOV	{"email": "sergey-abramov.101976@postgrespro.ru", "phone": "+70102060774"}
0005434877782	332D9F	4247 795828	VLADIMIR ALEKSANDROV	{"email": "vladimir.aleksandrov.061973@postgrespro.ru", "phone": "+70824166311"}
0005434877783	1D9D2B	0738 345202	YANINA VASILEVA	{"email": "vasileva_y-12121979@postgrespro.ru", "phone": "+70661081052"}
0005434877784	50A52E	3652 552389	NADEZHDA CHERNOVA	{"email": "nadezhda-chernova-1965@postgrespro.ru", "phone": "+70788482863"}
0005434877785	1B7486	1584 968727	ANATOLIY VOROBEV	{"email": "vorobev.anatoliy1968@postgrespro.ru", "phone": "+70344134138"}
0005434877786	C64F3A	9588 438749	OLEG OSIPOV	{"email": "osipov.oleg091973@postgrespro.ru", "phone": "+70487052074"}
0005434877787	C64F3A	5812 578771	OLGA KOLESNIKOVA	{"phone": "+70421914136"}
0005434877788	2A1654	1138 883109	IRINA ANTONOVA	{"email": "antonovairina.101981@postgrespro.ru", "phone": "+70244437558"}
0005434877789	309CC2	8800 720553	ANDREY BONDARENKO	{"email": "bondarenko-a16031964@postgrespro.ru", "phone": "+70534277012"}
0005434877790	309CC2	7868 176049	YURIY POPOV	{"email": "yuriy-popov-21081983@postgrespro.ru", "phone": "+70395839434"}
0005434877791	913BDA	2793 888732	VALENTINA ZHURAVLEVA	{"email": "valentina_zhuravleva1971@postgrespro.ru", "phone": "+70740141079"}
0005434877792	A78F47	7007 739693	IRINA NAZAROVA	{"phone": "+70634539057"}
0005434877793	DB3A3E	9089 087176	BORIS NOVIKOV	{"phone": "+70054092788"}
0005434877794	104D0B	5121 913522	NIKOLAY ILIN	{"email": "ilin_nikolay_1973@postgrespro.ru", "phone": "+70337485454"}
0005434877796	7EE39E	6901 520521	ALEKSANDR ABRAMOV	{"email": "a.abramov_09061979@postgrespro.ru", "phone": "+70790546750"}
0005434877797	7EE39E	0125 450410	MARINA ANDREEVA	{"email": "andreeva_m_061968@postgrespro.ru", "phone": "+70216715924"}
0005434877798	70A482	9807 169396	TATYANA FILIPPOVA	{"email": "t_filippova-1974@postgrespro.ru", "phone": "+70476460039"}
0005434877799	70A482	3339 493792	ALEKSEY BORISOV	{"phone": "+70489290828"}
0005434877800	163FB3	6862 105524	LARISA KONDRATEVA	{"phone": "+70689101204"}
0005434877801	8EF285	5602 936078	VLADISLAV IVANOV	{"email": "ivanov.v-101973@postgrespro.ru", "phone": "+70363713634"}
0005434877802	8EF285	7805 965952	VLADIMIR NOVIKOV	{"email": "vnovikov-31121977@postgrespro.ru", "phone": "+70949274389"}
0005434877803	236219	6165 446913	ILDAR GAVRILOV	{"phone": "+70884075737"}
0005434877804	A51F8D	7786 741347	SERGEY PETROV	{"email": "petrov_sergey_10051973@postgrespro.ru", "phone": "+70111990571"}
0005434877805	94658B	4315 027327	LARISA KOROLEVA	{"email": "koroleva-larisa-27091976@postgrespro.ru", "phone": "+70105271447"}
0005434877806	9D1565	6643 368880	IGOR MELNIKOV	{"email": "imelnikov_10051964@postgrespro.ru", "phone": "+70594336446"}
0005434877807	9D1565	7815 419344	SERGEY KONOVALOV	{"phone": "+70989140790"}
0005434877808	9B508E	0406 915062	OLEG TARASOV	{"email": "tarasovoleg_121974@postgrespro.ru", "phone": "+70216577714"}
0005434877809	9B508E	3430 021725	MIKHAIL KULIKOV	{"phone": "+70399504116"}
0005434877810	43CCFA	5249 473947	VALERIY YAKOVLEV	{"email": "v-yakovlev.011978@postgrespro.ru", "phone": "+70617331848"}
0005434877811	DA5CEF	1244 746142	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr.091977@postgrespro.ru", "phone": "+70425624465"}
0005434877812	0BB756	5914 813402	DMITRIY MAKAROV	{"phone": "+70852978712"}
0005434877813	CF566A	3341 560720	YULIYA PETROVA	{"phone": "+70990759230"}
0005434877814	CF566A	9222 910475	RUSLAN VASILEV	{"email": "r_vasilev_011978@postgrespro.ru", "phone": "+70496284091"}
0005434877815	CF566A	8596 705871	ANDREY MELNIKOV	{"phone": "+70805844509"}
0005434877816	173802	2898 164124	ALINA POLYAKOVA	{"email": "polyakova_alina1972@postgrespro.ru", "phone": "+70664111823"}
0005434877935	EC4489	5721 162892	OLEG KOZLOV	{"phone": "+70882015126"}
0005434877817	A02538	5563 660263	TAMARA KONOVALOVA	{"email": "konovalova.t_1971@postgrespro.ru", "phone": "+70139526319"}
0005434877818	A02538	3663 617110	OLGA KUZNECOVA	{"email": "kuznecovaolga1973@postgrespro.ru", "phone": "+70324974363"}
0005434877819	CF0CE7	1961 555040	VYACHESLAV VOROBEV	{"email": "vorobev-v_051968@postgrespro.ru", "phone": "+70994368516"}
0005434877820	D1DB99	8497 603835	ELENA KOROLEVA	{"email": "koroleva_e-111978@postgrespro.ru", "phone": "+70232592100"}
0005434877821	292AFD	4509 936670	ALLA KOMAROVA	{"email": "komarova-alla_1985@postgrespro.ru", "phone": "+70740912123"}
0005434877822	292AFD	0223 204230	TATYANA ANDREEVA	{"email": "t.andreeva-021979@postgrespro.ru", "phone": "+70352080315"}
0005434877823	1A35A7	0189 839578	ALEKSANDRA FADEEVA	{"phone": "+70197196942"}
0005434877824	1A35A7	7239 968332	NATALIYA SMIRNOVA	{"email": "nsmirnova-20121971@postgrespro.ru", "phone": "+70201613116"}
0005434877825	9B91C4	2370 539406	TATYANA MAKAROVA	{"email": "tatyana_makarova-1971@postgrespro.ru", "phone": "+70432340206"}
0005434877826	9B91C4	3340 114669	SERGEY MATVEEV	{"email": "matveevsergey-06011974@postgrespro.ru", "phone": "+70390693000"}
0005434877827	F3B452	4342 644336	ROZA KUZNECOVA	{"email": "roza.kuznecova101964@postgrespro.ru", "phone": "+70636272776"}
0005434877828	066CB8	3514 576218	NATALYA KRASNOVA	{"email": "krasnovanatalya.1968@postgrespro.ru", "phone": "+70576071771"}
0005434877829	066CB8	4843 879525	MIKHAIL MAKAROV	{"phone": "+70440806945"}
0005434877830	6B4992	9509 694241	ANATOLIY ALEKSEEV	{"email": "anatoliy-alekseev-05091961@postgrespro.ru", "phone": "+70691741785"}
0005434877831	6B4992	8377 572016	ROMAN TARASOV	{"phone": "+70716832249"}
0005434877832	A123A6	6824 573073	VIKTORIYA FROLOVA	{"email": "v_frolova.03081970@postgrespro.ru", "phone": "+70873836355"}
0005434877833	A123A6	8641 946833	DARYA NAUMOVA	{"phone": "+70266367164"}
0005434877834	A123A6	2693 221891	EKATERINA FADEEVA	{"phone": "+70032977032"}
0005434877835	F0733F	5119 237692	NIKOLAY SMIRNOV	{"phone": "+70267504374"}
0005434877836	F0733F	1418 803042	VASILIY SOROKIN	{"phone": "+70935366001"}
0005434877837	1DAD03	0293 911494	ILDUS ANDREEV	{"email": "andreev_ildus.051960@postgrespro.ru", "phone": "+70640455039"}
0005434877838	762125	1864 689566	LYUDMILA POPOVA	{"email": "popova-lyudmila_081985@postgrespro.ru", "phone": "+70897451899"}
0005434877839	E68037	1506 771883	ANASTASIYA SOLOVEVA	{"email": "anastasiya.soloveva_1964@postgrespro.ru", "phone": "+70504316684"}
0005434877840	B2CDE9	8962 222784	YURIY GERASIMOV	{"phone": "+70594991389"}
0005434877841	565A93	1430 159045	SVETLANA FEDOROVA	{"email": "fedorovas1967@postgrespro.ru", "phone": "+70729282857"}
0005434877842	F5118B	7297 527482	MIKHAIL ZAKHAROV	{"phone": "+70309527219"}
0005434877843	BA21D3	2342 716194	GALINA TARASOVA	{"email": "gtarasova-081962@postgrespro.ru", "phone": "+70782777114"}
0005434877844	BA21D3	2825 253946	DMITRIY STEPANOV	{"email": "dmitriy-stepanov-1971@postgrespro.ru", "phone": "+70546001193"}
0005434877845	BA21D3	6159 643071	VLADIMIR POPOV	{"email": "vladimir-popov31051960@postgrespro.ru", "phone": "+70220090109"}
0005434877846	E3C6C8	8834 650720	DMITRIY FROLOV	{"email": "frolov_d.26061969@postgrespro.ru", "phone": "+70599022177"}
0005434877847	8CDD4F	5800 297762	RUSLAN SERGEEV	{"phone": "+70683365419"}
0005434877848	A87B06	6560 572427	EKATERINA VOLKOVA	{"phone": "+70923927727"}
0005434877849	C46E6B	6818 559131	GALINA PETROVA	{"email": "g-petrova19111977@postgrespro.ru", "phone": "+70444226935"}
0005434877850	EE5B28	8224 342897	NATALIYA ABRAMOVA	{"email": "abramova.n.04111968@postgrespro.ru", "phone": "+70574861481"}
0005434877851	EE5B28	9056 140062	VALENTIN TIKHONOV	{"email": "tikhonov-v.22101968@postgrespro.ru", "phone": "+70147914825"}
0005434877852	23CFB7	1578 885157	DMITRIY SMIRNOV	{"phone": "+70061844052"}
0005434877853	6956ED	6283 347159	EVGENIY ANDREEV	{"email": "andreev_e-031971@postgrespro.ru", "phone": "+70627558694"}
0005434877854	6956ED	4295 540405	GALINA NIKOLAEVA	{"email": "nikolaeva-galina-1962@postgrespro.ru", "phone": "+70863478040"}
0005434877855	EC6527	6382 431406	EGOR GORBUNOV	{"phone": "+70567511725"}
0005434877856	FB6174	5292 646765	VLADIMIR POPOV	{"email": "v_popov.04041980@postgrespro.ru", "phone": "+70281126942"}
0005434877857	FB6174	0536 126412	OLGA GERASIMOVA	{"phone": "+70483940676"}
0005434877858	FB6174	1361 343610	ANATOLIY FEDOTOV	{"email": "a-fedotov18021969@postgrespro.ru", "phone": "+70816746394"}
0005434877859	830E66	3949 577628	NIKOLAY KISELEV	{"phone": "+70386649719"}
0005434877860	6DFF00	4504 626557	VLADIMIR SAVELEV	{"email": "vsavelev051977@postgrespro.ru", "phone": "+70715309272"}
0005434877861	344BC0	8511 786388	VALENTINA KAZAKOVA	{"phone": "+70936428002"}
0005434877862	344BC0	8103 334953	MIKHAIL NIKOLAEV	{"phone": "+70441588615"}
0005434877863	0ED891	5369 899720	MAKSIM KUZNECOV	{"phone": "+70119500368"}
0005434877864	36D4DB	3502 261351	DARYA MEDVEDEVA	{"phone": "+70095458237"}
0005434877865	36D4DB	8187 330759	ALEKSANDR PAVLOV	{"phone": "+70288805199"}
0005434877866	D6D76A	0198 493011	ILYA BONDARENKO	{"phone": "+70627355762"}
0005434877867	26CA3F	9084 815339	SVETLANA KOROLEVA	{"email": "koroleva_svetlana1967@postgrespro.ru", "phone": "+70467950214"}
0005434877868	26FF40	9758 479119	SVETLANA IVANOVA	{"email": "sivanova.081965@postgrespro.ru", "phone": "+70799688302"}
0005434877869	26FF40	3881 740301	SAMIRA IVANOVA	{"phone": "+70110601520"}
0005434877870	0853B6	6150 666701	YULIYA NIKOLAEVA	{"email": "nikolaeva_yuliya_121969@postgrespro.ru", "phone": "+70693561876"}
0005434877871	84930A	5840 519665	ULYANA YAKOVLEVA	{"email": "yakovleva-u-1960@postgrespro.ru", "phone": "+70222607743"}
0005434877872	118751	4380 141803	MIKHAIL ALEKSANDROV	{"phone": "+70521456952"}
0005434877873	118751	2439 772383	ILYA DENISOV	{"email": "denisov_ilya-1976@postgrespro.ru", "phone": "+70387419094"}
0005434877874	118751	5525 231081	GALINA PAVLOVA	{"email": "pavlovagalina-16121975@postgrespro.ru", "phone": "+70520910331"}
0005434877875	02B1DE	7826 818682	POLINA LOGINOVA	{"email": "loginovap1960@postgrespro.ru", "phone": "+70575271051"}
0005434877876	02B1DE	6855 229968	ALEKSANDR MIKHAYLOV	{"email": "amikhaylov-081976@postgrespro.ru", "phone": "+70674739901"}
0005434877877	02B1DE	0764 602849	VIKTOR NOVIKOV	{"phone": "+70820727527"}
0005434877878	6EB2DA	7611 205789	IRINA NIKOLAEVA	{"email": "irina.nikolaeva_16081965@postgrespro.ru", "phone": "+70384766844"}
0005434877879	A85734	5803 693948	EDUARD MATVEEV	{"phone": "+70914350000"}
0005434877880	BD8BBA	2514 107096	ELENA ZAYCEVA	{"email": "elena.zayceva08121977@postgrespro.ru", "phone": "+70293645185"}
0005434877881	4539F7	7456 705117	TATYANA NIKITINA	{"phone": "+70539285971"}
0005434877882	4539F7	6212 168180	RUSLAN ANTONOV	{"phone": "+70051195492"}
0005434877883	B5012F	3416 663934	VADIM FOMIN	{"email": "fomin-vadim16091976@postgrespro.ru", "phone": "+70430847144"}
0005434877884	7A9051	1183 865380	IRINA TROFIMOVA	{"phone": "+70451822127"}
0005434877885	0E56EF	1445 437865	DARYA ROMANOVA	{"email": "d_romanova29041979@postgrespro.ru", "phone": "+70866359945"}
0005434877886	33CB3F	9763 095393	IRINA TIMOFEEVA	{"phone": "+70934490660"}
0005434877887	7A212B	5918 587452	ANNA FOMINA	{"email": "fomina.a.1976@postgrespro.ru", "phone": "+70899114282"}
0005434877888	C97E09	2651 955209	DMITRIY FEDOROV	{"phone": "+70801059393"}
0005434877889	C97E09	9409 573702	MARIYA SAVELEVA	{"phone": "+70985062193"}
0005434877890	157613	0936 227681	ZINAIDA KOROLEVA	{"phone": "+70590076664"}
0005434877891	112E45	5020 413555	SERGEY MIRONOV	{"email": "sergey.mironov.02071975@postgrespro.ru", "phone": "+70607831573"}
0005434877892	0E218E	1338 382576	ALEKSANDR ZAKHAROV	{"email": "a.zakharov121957@postgrespro.ru", "phone": "+70881665829"}
0005434877893	0E218E	1235 408594	SERGEY FILIPPOV	{"email": "filippovs-031973@postgrespro.ru", "phone": "+70904590134"}
0005434877894	FAA34D	7480 072771	RIMMA ZAYCEVA	{"email": "rimma.zayceva_1970@postgrespro.ru", "phone": "+70939471141"}
0005434877895	FAA34D	6904 117150	GLEB GRIGOREV	{"email": "g-grigorev04081958@postgrespro.ru", "phone": "+70999507419"}
0005434877896	A4D703	4092 376664	ELENA DMITRIEVA	{"email": "dmitrievaelena_071973@postgrespro.ru", "phone": "+70628536054"}
0005434877897	BCA011	5464 167998	LIDIYA SOROKINA	{"email": "sorokina_l091970@postgrespro.ru", "phone": "+70473089622"}
0005434877898	7C8E99	4253 934803	ELENA CHERNOVA	{"email": "chernova_e.1977@postgrespro.ru", "phone": "+70525018949"}
0005434877899	8BF697	1365 411194	NADEZHDA EGOROVA	{"phone": "+70869251335"}
0005434877900	1F9204	8273 552493	ALEKSANDR ISAEV	{"phone": "+70487513018"}
0005434877901	A8595D	6865 337699	OLGA KOMAROVA	{"email": "komarovao-051969@postgrespro.ru", "phone": "+70001762783"}
0005434877902	98E565	2662 828992	VIKTOR KUZNECOV	{"phone": "+70000649670"}
0005434877903	D5B5EF	9486 492518	VASILIY MAKAROV	{"email": "vmakarov_091971@postgrespro.ru", "phone": "+70366628583"}
0005434877904	A69A8B	2635 272653	LARISA FROLOVA	{"phone": "+70365938520"}
0005434877905	9CC51F	4246 892855	EKATERINA ZOTOVA	{"phone": "+70159154842"}
0005434877906	DF2CC9	2489 993097	ARTEM NIKOLAEV	{"email": "nikolaeva_26081973@postgrespro.ru", "phone": "+70322053492"}
0005434877907	944078	5866 476116	MARIYA ZOTOVA	{"email": "zotova.m.04081977@postgrespro.ru", "phone": "+70367620931"}
0005434877908	166202	8460 498661	NATALYA PAVLOVA	{"phone": "+70640656260"}
0005434877909	9FBFFC	9302 519791	MIKHAIL TIMOFEEV	{"email": "mikhailtimofeev-1972@postgrespro.ru", "phone": "+70429445432"}
0005434877910	9FBFFC	9748 030571	ELENA PETROVA	{"email": "elena.petrova04101985@postgrespro.ru", "phone": "+70185474501"}
0005434877911	7BFC3F	0784 935390	YURIY BELOV	{"email": "belov.y.1965@postgrespro.ru", "phone": "+70567968636"}
0005434877912	7BFC3F	1187 095967	POLINA POLYAKOVA	{"email": "polina-polyakova.09061972@postgrespro.ru", "phone": "+70618794300"}
0005434877913	1EDDA6	0915 549553	DARYA GORBUNOVA	{"email": "gorbunova_d_1979@postgrespro.ru", "phone": "+70412629765"}
0005434877914	1EDDA6	6369 684325	SERGEY ALEKSEEV	{"phone": "+70649355059"}
0005434877915	90B5C4	4092 349042	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev1979@postgrespro.ru", "phone": "+70922651798"}
0005434877916	CA399C	9314 341289	MIKHAIL BONDARENKO	{"email": "bondarenko-m.1974@postgrespro.ru", "phone": "+70802060979"}
0005434877917	D67279	9056 255616	ANASTASIYA SIDOROVA	{"email": "anastasiya-sidorova.20031970@postgrespro.ru", "phone": "+70578110306"}
0005434877918	D67279	4553 802915	VYACHESLAV ZHUKOV	{"phone": "+70952266745"}
0005434877919	51B5F3	9122 686897	ANDREY GUSEV	{"phone": "+70378031725"}
0005434877920	51B5F3	0033 262503	YULIYA YAKOVLEVA	{"phone": "+70497205265"}
0005434877921	736849	9650 048089	ROZA MOROZOVA	{"phone": "+70590076678"}
0005434877922	736849	0775 050737	NADEZHDA GUSEVA	{"phone": "+70843374067"}
0005434877923	3A30D3	8285 065948	OLGA MELNIKOVA	{"email": "melnikova.olga.1966@postgrespro.ru", "phone": "+70908675413"}
0005434877924	C7C47E	0509 709682	ALISA KALININA	{"email": "kalinina_a07071985@postgrespro.ru", "phone": "+70661974165"}
0005434877925	24ECA1	5939 067447	ALEKSANDR VOLKOV	{"phone": "+70238477939"}
0005434877926	24ECA1	3241 781098	KHALIDA SAVELEVA	{"phone": "+70592398197"}
0005434877927	E9AEC7	7133 069196	ANASTASIYA GRISHINA	{"email": "agrishina1964@postgrespro.ru", "phone": "+70108503183"}
0005434877928	7FE32E	6378 002007	EVGENIY MAKSIMOV	{"phone": "+70543221160"}
0005434877929	E68C74	0776 984892	OLGA STEPANOVA	{"email": "stepanova.olga-031971@postgrespro.ru", "phone": "+70823387090"}
0005434877930	AE3E79	0392 540221	ALINA MIRONOVA	{"phone": "+70247645110"}
0005434877931	97723A	4760 286647	SVETLANA KOLESNIKOVA	{"phone": "+70902475964"}
0005434877932	97723A	4480 814436	ELENA TIMOFEEVA	{"email": "timofeevae051971@postgrespro.ru", "phone": "+70794034182"}
0005434877933	EEABF3	4253 467852	LYUDMILA KUZNECOVA	{"email": "kuznecova_l.111977@postgrespro.ru", "phone": "+70187970555"}
0005434877934	EC4489	3688 115747	GALINA GUSEVA	{"phone": "+70293809212"}
0005434877936	441465	3934 780111	ALEKSANDR PAVLOV	{"phone": "+70445172575"}
0005434877937	441465	0076 014584	LYUDMILA NOVIKOVA	{"email": "lyudmila-novikova-1968@postgrespro.ru", "phone": "+70648414760"}
0005434877938	552806	1296 484580	MARIYA ROMANOVA	{"email": "mariya_romanova_1973@postgrespro.ru", "phone": "+70964139649"}
0005434877939	552806	3687 030513	ALEKSEY GRIGOREV	{"phone": "+70825569236"}
0005434877940	0FEF3C	9854 948703	NATALYA VOROBEVA	{"phone": "+70268150827"}
0005434877941	BFE6DC	8996 110787	VIKTORIYA IVANOVA	{"email": "ivanova_v.28041977@postgrespro.ru", "phone": "+70060877378"}
0005434877942	BFE6DC	9649 939903	YULIYA ZAKHAROVA	{"phone": "+70816857580"}
0005434877943	DE7CA3	2308 344850	MARINA TIMOFEEVA	{"phone": "+70077333400"}
0005434877944	2F7C08	5404 837623	EVGENIY NOVIKOV	{"email": "evgeniy_novikov-24031963@postgrespro.ru", "phone": "+70323383233"}
0005434877945	2F7C08	8361 018209	ALEKSANDR SOROKIN	{"phone": "+70862114165"}
0005434877946	266D55	5867 558384	VIKTOR MELNIKOV	{"email": "melnikov.v_28041978@postgrespro.ru", "phone": "+70045375686"}
0005434877947	0278C5	8837 877932	LYUBOV IVANOVA	{"phone": "+70370121759"}
0005434877948	0278C5	0594 330711	POLINA TITOVA	{"phone": "+70796132312"}
0005434877949	FACE7B	6201 060113	EKATERINA ZAKHAROVA	{"phone": "+70022181309"}
0005434877950	34FBA9	5357 086614	LILIYA SERGEEVA	{"email": "l.sergeeva_021969@postgrespro.ru", "phone": "+70200039350"}
0005434877951	34FBA9	0721 284310	ANDREY BORISOV	{"phone": "+70941793941"}
0005434877952	B83256	6534 939535	EVGENIY DAVYDOV	{"phone": "+70746825726"}
0005434877953	755ABF	2175 389342	SERGEY GRIGOREV	{"email": "sergey-grigorev_13121979@postgrespro.ru", "phone": "+70900966893"}
0005434877954	6E95D0	6233 207683	ALEKSEY KULIKOV	{"email": "aleksey-kulikov16101973@postgrespro.ru", "phone": "+70315956336"}
0005434877955	6E95D0	8364 604440	ELENA MIRONOVA	{"phone": "+70715329755"}
0005434877956	25BAA8	0008 384023	TATYANA ROMANOVA	{"email": "tatyana-romanova_20091973@postgrespro.ru", "phone": "+70782627398"}
0005434877957	F89598	3612 670831	YURIY BARANOV	{"phone": "+70342946859"}
0005434877958	87C885	0457 322758	ALEKSEY IVANOV	{"phone": "+70226116368"}
0005434877959	87C885	0050 591911	VLADIMIR SOKOLOV	{"phone": "+70719451026"}
0005434877960	454A08	9038 603082	DARYA ALEKSEEVA	{"phone": "+70245997943"}
0005434877961	4A3F84	7555 688397	SERGEY SHEVCHENKO	{"phone": "+70640522946"}
0005434877962	0C5F8E	1056 986380	POLINA GRISHINA	{"phone": "+70988541478"}
0005434877963	0C5F8E	1619 079961	MAKSIM SERGEEV	{"phone": "+70176056702"}
0005434877964	333647	0661 563438	DANILA NAUMOV	{"email": "naumov.d.01021958@postgrespro.ru", "phone": "+70807297298"}
0005434877965	333647	2047 891434	VALENTIN PETROV	{"phone": "+70323183642"}
0005434877966	20F734	3290 160686	ELENA NAUMOVA	{"email": "naumova_elena_1967@postgrespro.ru", "phone": "+70493615762"}
0005434877967	FBDC33	6863 316163	NADEZHDA VOLKOVA	{"email": "volkova_n_15091980@postgrespro.ru", "phone": "+70434413358"}
0005434877968	010203	8437 076175	SERGEY CHERNOV	{"phone": "+70743348367"}
0005434877969	70929C	6782 409538	NINA EGOROVA	{"email": "egorova.nina-04071974@postgrespro.ru", "phone": "+70990672150"}
0005434877970	6957DD	0631 935866	VALERIY SOROKIN	{"email": "sorokinvaleriy_1982@postgrespro.ru", "phone": "+70339152001"}
0005434877971	090B5C	2193 684583	ALFIYA TIMOFEEVA	{"phone": "+70000440378"}
0005434877972	090B5C	0064 268287	IRINA MEDVEDEVA	{"email": "i_medvedeva.011991@postgrespro.ru", "phone": "+70461693139"}
0005434877973	B3A4E3	1954 160785	VERA YAKOVLEVA	{"phone": "+70988747782"}
0005434877974	BD8FD8	9921 721067	ANDREY VASILEV	{"phone": "+70422923203"}
0005434877975	BD8FD8	3772 598427	IRINA SEMENOVA	{"email": "irinasemenova-041958@postgrespro.ru", "phone": "+70051177445"}
0005434877976	70CB19	1263 983901	IVAN SERGEEV	{"email": "sergeev-ivan_101980@postgrespro.ru", "phone": "+70133757081"}
0005434877977	A46B46	3036 706912	PETR FOMIN	{"phone": "+70322139184"}
0005434877978	554ABE	4368 403629	ARTEM AFANASEV	{"phone": "+70437221398"}
0005434877979	554ABE	9248 746637	VYACHESLAV ALEKSEEV	{"phone": "+70498198772"}
0005434877980	3419DD	3153 704306	DMITRIY NIKITIN	{"email": "dnikitin_30061989@postgrespro.ru", "phone": "+70899318200"}
0005434877981	A934FE	3053 236188	IRINA NESTEROVA	{"email": "irinanesterova-02101970@postgrespro.ru", "phone": "+70711519251"}
0005434877982	A934FE	4095 121599	NIKOLAY KARPOV	{"phone": "+70322054612"}
0005434877983	E07083	3197 887236	MARINA FADEEVA	{"phone": "+70436296807"}
0005434877984	020478	4335 303693	ANNA KUZNECOVA	{"phone": "+70462876523"}
0005434877985	3DB315	5290 495017	OLGA TIKHONOVA	{"email": "tikhonovaolga24121970@postgrespro.ru", "phone": "+70532811196"}
0005434877986	3DB315	9266 314811	ARTEM SEMENOV	{"phone": "+70062897245"}
0005434877987	DD6E77	9908 565114	VALENTINA POLYAKOVA	{"phone": "+70150955691"}
0005434877988	750C88	7036 728088	VALENTINA ALEKSANDROVA	{"phone": "+70765743576"}
0005434877989	750C88	7005 840441	OLEG TARASOV	{"email": "tarasov_o_081963@postgrespro.ru", "phone": "+70022725201"}
0005434877990	750C88	3740 570828	ANDREY GUSEV	{"phone": "+70448588197"}
0005434877991	DB4D1D	3847 396100	MARINA MALYSHEVA	{"phone": "+70669174898"}
0005434877992	DB4D1D	2050 170497	YURIY KONOVALOV	{"email": "y-konovalov-1971@postgrespro.ru", "phone": "+70699479803"}
0005434877993	311DC0	0682 983425	ELENA FROLOVA	{"email": "frolova-elena-1976@postgrespro.ru", "phone": "+70815067193"}
0005434877994	311DC0	4240 213635	ALEKSEY GAVRILOV	{"email": "gavrilova_091974@postgrespro.ru", "phone": "+70709234704"}
0005434877995	982466	5503 157358	MIKHAIL SERGEEV	{"email": "sergeevmikhail-1975@postgrespro.ru", "phone": "+70315148294"}
0005434877996	801AFE	3474 179363	GENNADIY YAKOVLEV	{"phone": "+70759267490"}
0005434877997	E08963	6702 315134	VLADIMIR POPOV	{"email": "popovv.111973@postgrespro.ru", "phone": "+70504584984"}
0005434878175	ABAC8C	2195 628198	ANASTASIYA BARANOVA	{"phone": "+70715979244"}
0005434877998	5897BE	9364 148215	ARTEM GRIGOREV	{"email": "grigorev.a14061976@postgrespro.ru", "phone": "+70646949091"}
0005434877999	7F7B4A	0938 037162	LYUDMILA FEDOROVA	{"email": "lyudmila-fedorova_121970@postgrespro.ru", "phone": "+70360618243"}
0005434878000	7F7B4A	5764 196130	ANASTASIYA LEBEDEVA	{"phone": "+70293331532"}
0005434878001	257E09	0986 769422	KSENIYA FROLOVA	{"phone": "+70708128216"}
0005434878002	257E09	5374 800236	TATYANA NIKOLAEVA	{"phone": "+70524438568"}
0005434878003	257E09	8769 356040	PAVEL MIKHAYLOV	{"phone": "+70074636130"}
0005434878004	5CDA5D	3224 240339	OLGA MARTYNOVA	{"phone": "+70097739176"}
0005434878005	5CDA5D	7829 353600	VIKTORIYA FOMINA	{"phone": "+70817255097"}
0005434878006	447A11	0651 011516	DENIS NIKITIN	{"phone": "+70133292090"}
0005434878007	20E710	7071 282101	RUDOLF KUZNECOV	{"phone": "+70951006245"}
0005434878008	EC7633	9450 856100	ANATOLIY AFANASEV	{"phone": "+70072067323"}
0005434878009	19A4FD	8086 538119	ROSTISLAV CHERNOV	{"phone": "+70471472767"}
0005434878010	03E5C5	3275 865178	ALEKSANDRA KARPOVA	{"phone": "+70152267263"}
0005434878011	64315C	8490 688114	ANATOLIY STEPANOV	{"phone": "+70744757451"}
0005434878012	A1660A	3188 847327	PAVEL ISAEV	{"phone": "+70037536974"}
0005434878013	1C151E	8350 066523	ALEKSEY NIKITIN	{"email": "nikitin.a_08041980@postgrespro.ru", "phone": "+70738604460"}
0005434878014	47B660	4575 504371	YURIY MAKSIMOV	{"email": "y-maksimov.11101964@postgrespro.ru", "phone": "+70948783227"}
0005434878015	246762	9885 174945	ALEKSEY ZHURAVLEV	{"email": "a-zhuravlev-1973@postgrespro.ru", "phone": "+70334556573"}
0005434878016	0D9EB1	6586 752946	SAMVEL KOZLOV	{"phone": "+70299533805"}
0005434878017	0D9EB1	7557 122712	VALENTINA ABRAMOVA	{"email": "abramova_v_1973@postgrespro.ru", "phone": "+70399351446"}
0005434878018	A139C7	5896 539397	ELENA MEDVEDEVA	{"email": "medvedeva_elena_1962@postgrespro.ru", "phone": "+70542816870"}
0005434878019	B83899	5120 055661	ALEKSEY ROMANOV	{"email": "romanovaleksey-17091968@postgrespro.ru", "phone": "+70290928751"}
0005434878020	E918B9	0695 266359	NINA KOZLOVA	{"email": "n_kozlova011977@postgrespro.ru", "phone": "+70670147772"}
0005434878021	389106	0983 600261	ALEKSANDR KUDRYASHOV	{"email": "a.kudryashov.1964@postgrespro.ru", "phone": "+70082464983"}
0005434878022	389106	7948 793888	MIKHAIL KOZLOV	{"phone": "+70721288345"}
0005434878023	30A1FC	0596 207782	VALENTINA SMIRNOVA	{"phone": "+70697147281"}
0005434878024	30A1FC	6603 451650	ANTON PETROV	{"email": "apetrov_20101969@postgrespro.ru", "phone": "+70204772503"}
0005434878025	0C5D51	3038 512918	LYUBOV TIMOFEEVA	{"phone": "+70487010638"}
0005434878026	DE27F4	7131 722896	VALERIYA KAZAKOVA	{"email": "kazakova-valeriya-24011961@postgrespro.ru", "phone": "+70811845203"}
0005434878027	DE27F4	9546 933346	EDUARD MIKHAYLOV	{"phone": "+70846289780"}
0005434878028	961FA7	5883 554221	EGOR MELNIKOV	{"phone": "+70132749279"}
0005434878029	961FA7	1466 130295	EGOR PETROV	{"phone": "+70749458962"}
0005434878030	961FA7	8005 922124	SVETLANA VASILEVA	{"email": "svetlana_vasileva_1976@postgrespro.ru", "phone": "+70946649662"}
0005434878031	13FBEC	1016 903249	OKSANA EGOROVA	{"phone": "+70090094014"}
0005434878032	13FBEC	9476 666604	IGOR VOROBEV	{"email": "vorobev_igor.111979@postgrespro.ru", "phone": "+70796285323"}
0005434878033	38CC81	4467 939686	SERGEY KISELEV	{"phone": "+70108217044"}
0005434878034	1FC16E	1448 243643	ANDREY MARTYNOV	{"phone": "+70466623890"}
0005434878035	1FC16E	1768 668690	OLEG MOROZOV	{"email": "morozov_o.08011969@postgrespro.ru", "phone": "+70179425618"}
0005434878036	73056C	7711 135080	LYUDMILA FROLOVA	{"email": "l_frolova_24061974@postgrespro.ru", "phone": "+70310006422"}
0005434878037	73056C	4458 803317	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov14061958@postgrespro.ru", "phone": "+70916317935"}
0005434878038	0D0C63	5106 652258	EKATERINA MEDVEDEVA	{"phone": "+70333369498"}
0005434878039	CCAF6D	8064 223068	MAKSIM PETROV	{"email": "petrov_m091969@postgrespro.ru", "phone": "+70590399474"}
0005434878040	CCAF6D	4355 488859	SVETLANA KULIKOVA	{"email": "kulikova-svetlana_011968@postgrespro.ru", "phone": "+70096112689"}
0005434878041	CE17C0	9736 472531	YURIY KUZNECOV	{"phone": "+70660751804"}
0005434878042	3BBFFA	5493 966710	ALEKSANDR MIKHAYLOV	{"phone": "+70489345461"}
0005434878043	81422E	3690 809878	YULIYA DENISOVA	{"phone": "+70361054430"}
0005434878044	C726E9	0341 816592	DMITRIY IVANOV	{"phone": "+70842861079"}
0005434878045	45E4AF	1878 983251	VLADISLAV GAVRILOV	{"email": "vladislav-gavrilov.07051974@postgrespro.ru", "phone": "+70436542018"}
0005434878046	45E4AF	7543 671222	MARIYA MEDVEDEVA	{"email": "m-medvedeva.031970@postgrespro.ru", "phone": "+70764373153"}
0005434878047	45E4AF	9041 047918	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov_1957@postgrespro.ru", "phone": "+70863768825"}
0005434878048	906EC3	4570 492003	PELAGEYA KONDRATEVA	{"phone": "+70738074267"}
0005434878049	906EC3	0325 930328	SERGEY KUZNECOV	{"email": "kuznecovs_08041975@postgrespro.ru", "phone": "+70329598292"}
0005434878050	F3550F	4053 818591	ELIZAVETA SOKOLOVA	{"phone": "+70369100538"}
0005434878051	C3D50B	1505 592733	SERGEY SAVELEV	{"email": "savelev-s29071970@postgrespro.ru", "phone": "+70562002871"}
0005434878052	56C235	3921 281441	NINA KALININA	{"email": "kalinina-n.071970@postgrespro.ru", "phone": "+70370581930"}
0005434878053	56C235	9383 319071	IVAN PETROV	{"phone": "+70445551822"}
0005434878054	05C8D2	8438 919311	OKSANA TIMOFEEVA	{"phone": "+70721519139"}
0005434878055	B02C0C	2556 481429	VASILIY ROMANOV	{"email": "romanov.vasiliy_11031969@postgrespro.ru", "phone": "+70134772915"}
0005434878056	B02C0C	5415 397267	ANDREY KOROLEV	{"phone": "+70168500158"}
0005434878057	08B95F	3276 528666	ANNA NIKIFOROVA	{"email": "nikiforova.anna.1973@postgrespro.ru", "phone": "+70854148756"}
0005434878058	C2DBE1	9408 665459	ALEKSANDR RODIONOV	{"phone": "+70985754432"}
0005434878059	A284F5	2026 294656	MARINA SAVELEVA	{"email": "saveleva.marina121977@postgrespro.ru", "phone": "+70873789745"}
0005434878060	583E01	3676 825088	NINA VOROBEVA	{"email": "nvorobeva.101971@postgrespro.ru", "phone": "+70245632711"}
0005434878061	FE05BA	8056 628673	MARIYA GORBUNOVA	{"email": "gorbunovamariya23061982@postgrespro.ru", "phone": "+70424672868"}
0005434878062	FE55F1	9075 047092	EVGENIYA SAVELEVA	{"phone": "+70674371043"}
0005434878063	FE55F1	0250 306410	LUIZA KUZNECOVA	{"email": "kuznecova-luiza.1979@postgrespro.ru", "phone": "+70222651443"}
0005434878064	570B78	7687 766791	SERGEY PETROV	{"phone": "+70476928316"}
0005434878065	570B78	4491 513959	MARIYA KRASNOVA	{"email": "mariyakrasnova.26061975@postgrespro.ru", "phone": "+70578209940"}
0005434878066	570B78	6417 481546	MARSEL ISAEV	{"email": "m_isaev03031983@postgrespro.ru", "phone": "+70789061364"}
0005434878067	5A5B25	4356 125566	OKSANA POPOVA	{"email": "o_popova24041971@postgrespro.ru", "phone": "+70076898667"}
0005434878068	439E59	1375 816636	OLGA ZHURAVLEVA	{"email": "olga-zhuravleva-1961@postgrespro.ru", "phone": "+70176155536"}
0005434878069	53596C	6023 743735	MAKSIM CHERNOV	{"email": "chernov_m21071972@postgrespro.ru", "phone": "+70337855295"}
0005434878070	DABF75	6419 112433	ELIZAVETA EGOROVA	{"email": "egorova-elizaveta.12051975@postgrespro.ru", "phone": "+70013082992"}
0005434878071	F59F19	8632 271037	ANDREY BONDARENKO	{"email": "bondarenkoandrey_01031961@postgrespro.ru", "phone": "+70511857059"}
0005434878072	5A99B7	6786 535801	YULIYA MELNIKOVA	{"phone": "+70410259669"}
0005434878073	3A24D9	1673 941072	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr.17121977@postgrespro.ru", "phone": "+70210660628"}
0005434878074	3A24D9	4301 762305	ILDUS PETROV	{"email": "i_petrov22041978@postgrespro.ru", "phone": "+70655678509"}
0005434878075	F28DF3	8116 320071	ALEKSANDR ZAYCEV	{"phone": "+70865999313"}
0005434878076	318D16	4182 112943	ALEKSEY SEMENOV	{"email": "semenov_a.1970@postgrespro.ru", "phone": "+70545692793"}
0005434878077	8AE438	4202 030572	ANASTASIYA SIDOROVA	{"email": "sidorova.a-27081977@postgrespro.ru", "phone": "+70439235677"}
0005434878078	8AE438	1447 724401	ALEKSANDR IVANOV	{"email": "a.ivanov1976@postgrespro.ru", "phone": "+70659557334"}
0005434878079	1185A4	6247 369339	PAVEL KOROLEV	{"email": "korolev_pavel-101979@postgrespro.ru", "phone": "+70670181329"}
0005434878080	1185A4	3239 242084	MIKHAIL NOVIKOV	{"email": "mikhail.novikov.1971@postgrespro.ru", "phone": "+70619589737"}
0005434878081	B1A5B7	4639 070295	YANA ILINA	{"email": "ilinay_14061967@postgrespro.ru", "phone": "+70447701418"}
0005434878082	A76613	3395 583022	PAVEL TARASOV	{"phone": "+70258968548"}
0005434878083	A76613	2781 511645	VLADIMIR MATVEEV	{"email": "vladimir.matveev-091971@postgrespro.ru", "phone": "+70060430791"}
0005434878084	9EFCE1	9691 158435	VADIM KUZMIN	{"phone": "+70778271581"}
0005434878085	C07E3B	3604 569954	DARYA SOKOLOVA	{"email": "dsokolova_25081962@postgrespro.ru", "phone": "+70381548420"}
0005434878086	C07E3B	8316 859954	TATYANA BORISOVA	{"email": "t_borisova.21111977@postgrespro.ru", "phone": "+70168023765"}
0005434878087	DB73FA	8259 664137	DMITRIY SMIRNOV	{"phone": "+70309964607"}
0005434878088	473B57	4108 395080	NATALYA KUZNECOVA	{"email": "kuznecova-n-02091970@postgrespro.ru", "phone": "+70314869125"}
0005434878089	6A2B80	6823 377817	ALEKSANDRA ALEKSEEVA	{"email": "aleksandra.alekseeva.011967@postgrespro.ru", "phone": "+70963106989"}
0005434878090	3C20F2	7272 321412	DENIS BONDARENKO	{"phone": "+70060687096"}
0005434878091	CAA4EE	8658 216577	OLGA POPOVA	{"phone": "+70812852509"}
0005434878092	F46143	2464 526317	ANTON NOVIKOV	{"email": "anovikov.1977@postgrespro.ru", "phone": "+70948051420"}
0005434878093	ABF4AA	6362 902694	SERGEY MIRONOV	{"email": "mironovsergey_1980@postgrespro.ru", "phone": "+70489553728"}
0005434878094	ABF4AA	8660 922961	EKATERINA ARKHIPOVA	{"email": "ekaterinaarkhipova-1960@postgrespro.ru", "phone": "+70674467674"}
0005434878095	ABF4AA	5446 533822	NIKOLAY STEPANOV	{"email": "nikolay-stepanov.1976@postgrespro.ru", "phone": "+70732806034"}
0005434878096	C91621	9243 175555	NIKITA KUDRYASHOV	{"email": "kudryashovnikita-011975@postgrespro.ru", "phone": "+70200741360"}
0005434878097	C4ADED	6092 333179	LARISA ABRAMOVA	{"email": "larisa.abramova.1969@postgrespro.ru", "phone": "+70789589234"}
0005434878098	ED4B9C	1939 469421	ZHANNA TARASOVA	{"email": "zhanna.tarasova_1975@postgrespro.ru", "phone": "+70912343410"}
0005434878099	ED4B9C	0505 714683	ALEKSANDRA ILINA	{"phone": "+70607053447"}
0005434878100	A1F07D	5474 400032	TATYANA LEBEDEVA	{"phone": "+70271202764"}
0005434878101	EAC33D	7587 857664	TIMUR YAKOVLEV	{"phone": "+70703796422"}
0005434878102	930E40	6337 221347	TAMARA KULIKOVA	{"phone": "+70233679680"}
0005434878103	930E40	9301 434002	LIDIYA YAKOVLEVA	{"email": "lidiya_yakovleva1971@postgrespro.ru", "phone": "+70186321352"}
0005434878104	8E0509	7001 201794	TATYANA ROMANOVA	{"phone": "+70825175784"}
0005434878105	8E0509	9982 881886	VALENTINA SERGEEVA	{"phone": "+70756473655"}
0005434878106	AE3604	3659 142194	MIKHAIL SOROKIN	{"email": "sorokin-m_1969@postgrespro.ru", "phone": "+70014306293"}
0005434878107	378817	4214 606441	ANATOLIY KUZMIN	{"email": "kuzmin.anatoliy-1970@postgrespro.ru", "phone": "+70945621452"}
0005434878108	7FD259	7784 793246	VLADIMIR FROLOV	{"email": "v_frolov-02121972@postgrespro.ru", "phone": "+70991296455"}
0005434878109	C98534	9894 857207	KONSTANTIN TARASOV	{"phone": "+70545694188"}
0005434878110	851616	0770 927482	ALEKSEY KULIKOV	{"email": "kulikov_aleksey.1967@postgrespro.ru", "phone": "+70292847110"}
0005434878111	450DB8	2832 170594	ALEKSANDR VASILEV	{"email": "vasilevaleksandr031975@postgrespro.ru", "phone": "+70183946471"}
0005434878112	450DB8	3430 612102	ANFISA FEDOROVA	{"email": "fedorova_a-031972@postgrespro.ru", "phone": "+70532212183"}
0005434878113	39AB94	6315 657903	GALINA POPOVA	{"email": "galinapopova_23051969@postgrespro.ru", "phone": "+70542773592"}
0005434878114	A6902F	5462 547974	VLADISLAV KUZNECOV	{"phone": "+70005165306"}
0005434878115	A6902F	9644 692063	OLGA KOROLEVA	{"phone": "+70778325030"}
0005434878116	E78BA0	3563 271110	ELIZAVETA NAZAROVA	{"email": "nazarovae29111971@postgrespro.ru", "phone": "+70443580089"}
0005434878117	9D84AF	4777 000727	YULIYA ILINA	{"email": "y-ilina_1970@postgrespro.ru", "phone": "+70976071978"}
0005434878118	46F818	5704 676720	NIKOLAY KISELEV	{"email": "kiselev_n.1970@postgrespro.ru", "phone": "+70321280935"}
0005434878119	AFEA49	8181 535439	ALEKSEY KISELEV	{"phone": "+70056550516"}
0005434878120	AFEA49	1997 693694	ANNA KOLESNIKOVA	{"phone": "+70901706210"}
0005434878121	9B8284	4897 588120	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr.021974@postgrespro.ru", "phone": "+70380600245"}
0005434878122	9BB849	6748 918768	NATALYA TIMOFEEVA	{"email": "timofeeva_n_121969@postgrespro.ru", "phone": "+70752037213"}
0005434878123	96A42A	1844 427180	LYUDMILA IVANOVA	{"email": "l.ivanova-091971@postgrespro.ru", "phone": "+70656171772"}
0005434878124	A2514A	9007 082970	DMITRIY IVANOV	{"email": "dmitriy_ivanov_1974@postgrespro.ru", "phone": "+70972872288"}
0005434878125	BD1776	3567 544152	DARYA KONOVALOVA	{"email": "darya-konovalova-04101967@postgrespro.ru", "phone": "+70657391564"}
0005434878126	BD1776	3196 264048	IRINA GERASIMOVA	{"email": "gerasimova.i_1973@postgrespro.ru", "phone": "+70387963563"}
0005434878127	E9A96A	5632 079952	TATYANA EGOROVA	{"email": "tatyana.egorova.21081964@postgrespro.ru", "phone": "+70726067280"}
0005434878128	379084	9653 095557	ANATOLIY MOROZOV	{"phone": "+70467099205"}
0005434878129	7E7E7B	9094 906776	GRIGORIY IVANOV	{"phone": "+70084278261"}
0005434878130	7E7E7B	9666 193348	IRINA FOMINA	{"phone": "+70503651223"}
0005434878132	84135B	4651 953132	ANASTASIYA MELNIKOVA	{"phone": "+70803137458"}
0005434878133	3F5F1A	2116 163880	SERGEY VOROBEV	{"email": "s.vorobev.1978@postgrespro.ru", "phone": "+70882467321"}
0005434878134	3F5F1A	1958 336074	NIKOLAY DMITRIEV	{"phone": "+70022175228"}
0005434878135	1138FC	5250 127354	OLEG BORISOV	{"phone": "+70880204527"}
0005434878136	1760D4	1612 122923	VALENTINA LAZAREVA	{"phone": "+70900772550"}
0005434878137	1760D4	1831 411638	ALEKSANDR IVANOV	{"email": "a_ivanov31011969@postgrespro.ru", "phone": "+70219746069"}
0005434878138	64416E	2359 195006	SERGEY KOROLEV	{"email": "sergey.korolev-101972@postgrespro.ru", "phone": "+70037827045"}
0005434878139	0B1697	7101 942377	NATALYA KARPOVA	{"email": "n_karpova-1970@postgrespro.ru", "phone": "+70042434985"}
0005434878140	0B1697	6510 240527	NIKOLAY BELOV	{"email": "n.belov021970@postgrespro.ru", "phone": "+70338790686"}
0005434878141	C1C7BA	3338 511452	GENNADIY DMITRIEV	{"email": "gennadiy-dmitriev_1980@postgrespro.ru", "phone": "+70129277066"}
0005434878142	C1C7BA	3034 442442	ANDREY ZHURAVLEV	{"phone": "+70984836796"}
0005434878143	C1C7BA	2196 375339	STANISLAV KISELEV	{"phone": "+70186077646"}
0005434878144	DD9663	4013 463980	OLGA SERGEEVA	{"email": "sergeeva.o_12011963@postgrespro.ru", "phone": "+70893014537"}
0005434878145	EFDBA3	2513 636863	NATALYA IVANOVA	{"email": "n.ivanova_111979@postgrespro.ru", "phone": "+70787444624"}
0005434878146	368F88	6242 488024	OLGA AFANASEVA	{"phone": "+70087245552"}
0005434878147	499000	4579 990863	GALINA STEPANOVA	{"email": "gstepanova_071977@postgrespro.ru", "phone": "+70245891420"}
0005434878148	639A01	7717 246543	LILIYA FEDOROVA	{"email": "lfedorova021974@postgrespro.ru", "phone": "+70460023797"}
0005434878149	D209E6	2590 065582	VLADIMIR TIKHONOV	{"email": "tikhonov_v-091968@postgrespro.ru", "phone": "+70780646761"}
0005434878150	D209E6	6820 538202	VALENTINA NIKITINA	{"email": "nikitina-v.1965@postgrespro.ru", "phone": "+70762071472"}
0005434878151	9D99EF	4835 294649	DANILA ANTONOV	{"email": "danila_antonov_02081976@postgrespro.ru", "phone": "+70038722647"}
0005434878152	9D99EF	3092 506837	SVETLANA ANISIMOVA	{"email": "anisimova.svetlana-021976@postgrespro.ru", "phone": "+70824805108"}
0005434878153	64C657	1432 963164	SVETLANA ZAKHAROVA	{"email": "zakharova-svetlana.21101975@postgrespro.ru", "phone": "+70021929308"}
0005434878154	1B5739	8763 658869	OKSANA KISELEVA	{"phone": "+70645463123"}
0005434878155	E83DE4	2663 461562	ANASTASIYA FILIPPOVA	{"email": "anastasiya-filippova-051970@postgrespro.ru", "phone": "+70307064615"}
0005434878156	E83DE4	0131 917712	ZOYA DMITRIEVA	{"email": "zoya.dmitrieva-1968@postgrespro.ru", "phone": "+70752359826"}
0005434878157	DEB4B6	1618 269685	ANDREY BELOV	{"phone": "+70008794371"}
0005434878158	EFA133	7117 590401	ROMAN STEPANOV	{"phone": "+70275171210"}
0005434878159	EFA133	8240 346529	ILYA ABRAMOV	{"email": "ilya_abramov.1974@postgrespro.ru", "phone": "+70325758933"}
0005434878160	1398ED	2557 891326	YURIY KARPOV	{"email": "yuriykarpov_1974@postgrespro.ru", "phone": "+70242943833"}
0005434878161	1398ED	9186 387208	VLADIMIR ROMANOV	{"phone": "+70556014086"}
0005434878162	2FAF11	0829 691232	OLGA SOROKINA	{"email": "olgasorokina-13041970@postgrespro.ru", "phone": "+70829653938"}
0005434878163	2FAF11	8168 193676	NINA CHERNOVA	{"email": "chernova.nina031981@postgrespro.ru", "phone": "+70219724741"}
0005434878164	EFE19F	7067 068963	LARISA MOROZOVA	{"phone": "+70980538149"}
0005434878165	D04375	8099 950038	SERGEY FROLOV	{"phone": "+70511635270"}
0005434878166	0A7CEA	1069 698372	ILYA MIRONOV	{"email": "mironovi_28051974@postgrespro.ru", "phone": "+70345875751"}
0005434878167	9F15FA	9110 401995	ARTEM KUZMIN	{"email": "kuzminartem.121960@postgrespro.ru", "phone": "+70713834899"}
0005434878168	C09F89	5181 503223	GALINA POPOVA	{"email": "popova-galina-041983@postgrespro.ru", "phone": "+70399812083"}
0005434878169	7CBB23	3764 600101	DENIS IVANOV	{"phone": "+70689790195"}
0005434878170	36E46D	2224 202127	ALSU MIRONOVA	{"email": "a.mironova-07121974@postgrespro.ru", "phone": "+70160736257"}
0005434878171	23BDC2	0426 222358	VLADIMIR MAKSIMOV	{"phone": "+70220295912"}
0005434878172	500A06	0738 142258	NIKOLAY SOLOVEV	{"email": "n_solovev.081964@postgrespro.ru", "phone": "+70659503852"}
0005434878173	ABAC8C	0875 682040	VASILIY MAKAROV	{"email": "makarov.vasiliy.111977@postgrespro.ru", "phone": "+70655677219"}
0005434878174	ABAC8C	5268 963021	STANISLAV TARASOV	{"phone": "+70841689381"}
0005434878176	EBBECB	7026 180082	RAMIL CHERNOV	{"phone": "+70936952511"}
0005434878177	EBBECB	8842 333809	SERGEY KUZNECOV	{"email": "kuznecov.sergey.061968@postgrespro.ru", "phone": "+70013469748"}
0005434878178	B3FB17	8416 092535	RUSLAN SMIRNOV	{"phone": "+70125555967"}
0005434878179	FF2AEE	2842 901921	VASILISA MOISEEVA	{"email": "vasilisa-moiseeva051967@postgrespro.ru", "phone": "+70054611858"}
0005434878180	FF2AEE	2096 828711	VIKTOR FEDOROV	{"email": "viktor.fedorov.1975@postgrespro.ru", "phone": "+70977601217"}
0005434878181	529EFF	2927 812759	VERA GUSEVA	{"email": "vera-guseva.23021976@postgrespro.ru", "phone": "+70535728158"}
0005434878182	5D6A21	0319 459288	VLADIMIR GERASIMOV	{"phone": "+70589573262"}
0005434878183	2E5143	4099 657256	DMITRIY BONDARENKO	{"email": "bondarenkod011975@postgrespro.ru", "phone": "+70266736007"}
0005434878184	3630F7	0862 630651	VIKTOR SCHERBAKOV	{"email": "viktor-scherbakov-04051970@postgrespro.ru", "phone": "+70174586850"}
0005434878185	3630F7	6325 325162	KIRILL STEPANOV	{"phone": "+70373365811"}
0005434878186	006081	9655 168878	RAIL BONDARENKO	{"phone": "+70577764024"}
0005434878187	84D3C2	3012 944777	RADIK FOMIN	{"email": "fomin.radik011958@postgrespro.ru", "phone": "+70498869054"}
0005434878188	84D3C2	2396 964789	ZINAIDA LEBEDEVA	{"email": "zinaidalebedeva.16011972@postgrespro.ru", "phone": "+70859805855"}
0005434878189	22572E	9494 540388	ELMIRA ARKHIPOVA	{"phone": "+70235338341"}
0005434878190	257B7D	0953 542146	NATALYA ISAEVA	{"email": "isaeva-n-27011979@postgrespro.ru", "phone": "+70175834743"}
0005434878191	257B7D	8918 294086	DARINA PAVLOVA	{"email": "darina.pavlova.1974@postgrespro.ru", "phone": "+70230909175"}
0005434878192	C536BB	0064 302957	IVAN MELNIKOV	{"phone": "+70555224671"}
0005434878193	B4A466	3475 815970	VALENTINA AFANASEVA	{"email": "v_afanaseva.051960@postgrespro.ru", "phone": "+70950436008"}
0005434878194	C6A75A	6642 732913	ROMAN DAVYDOV	{"phone": "+70763373764"}
0005434878195	4AEAC0	6223 508124	ALINA SOROKINA	{"email": "sorokina-alina_031971@postgrespro.ru", "phone": "+70125338847"}
0005434878196	8F9C86	5395 214610	ILYA KRASNOV	{"email": "krasnov_i_15071971@postgrespro.ru", "phone": "+70642990776"}
0005434878197	F0E187	3802 207240	SERGEY VASILEV	{"phone": "+70589919071"}
0005434878198	05D02F	1864 227194	SULTAN NAZAROV	{"email": "nazarov.sultan_1981@postgrespro.ru", "phone": "+70246186179"}
0005434878199	05D02F	2430 777713	ANASTASIYA BELOVA	{"phone": "+70789916127"}
0005434878200	4A80CC	1435 177582	MAKSIM SHEVCHENKO	{"phone": "+70723163197"}
0005434878201	4A80CC	8852 750460	ANDREY VASILEV	{"email": "vasilev_andrey_30041968@postgrespro.ru", "phone": "+70666791709"}
0005434878202	9943A9	1678 310608	ANNA BORISOVA	{"phone": "+70743842625"}
0005434878203	6D670A	5778 396096	NINA LEBEDEVA	{"phone": "+70612133042"}
0005434878204	898EB6	6263 409220	LIDIYA SEMENOVA	{"phone": "+70731520383"}
0005434878205	CDF8BF	9925 992824	MARIYA ALEKSEEVA	{"phone": "+70823457897"}
0005434878206	3DA4C3	9649 484381	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir_23121976@postgrespro.ru", "phone": "+70903966849"}
0005434878207	FB49A1	4322 031632	TAMARA KOROLEVA	{"phone": "+70905088280"}
0005434878208	FB566D	5487 901575	RUSLAN SEMENOV	{"email": "semenov_r.1972@postgrespro.ru", "phone": "+70148086818"}
0005434878209	0FD0D2	5249 128582	MAKSIM VOROBEV	{"email": "vorobev_maksim_25051972@postgrespro.ru", "phone": "+70777387654"}
0005434878210	0FD0D2	5319 946791	VALERIY VOLKOV	{"email": "v_volkov-011969@postgrespro.ru", "phone": "+70395312248"}
0005434878211	0FD0D2	7740 443511	TATYANA KOLESNIKOVA	{"email": "tatyanakolesnikova071978@postgrespro.ru", "phone": "+70805047504"}
0005434878212	73E257	2864 528485	PETR VOLKOV	{"email": "pvolkov1975@postgrespro.ru", "phone": "+70310647361"}
0005434878213	5E49E5	6304 934465	ROMAN ZHURAVLEV	{"phone": "+70169910643"}
0005434878214	C3F9DA	7373 745130	ELENA FILIPPOVA	{"phone": "+70067839132"}
0005434878215	8E4023	5735 134315	VLADIMIR ROMANOV	{"phone": "+70809483259"}
0005434878216	1E4436	2815 712677	EVGENIY GORBUNOV	{"phone": "+70087019105"}
0005434878217	1E4436	9469 266494	TATYANA KOLESNIKOVA	{"email": "kolesnikova-t-13031973@postgrespro.ru", "phone": "+70520568485"}
0005434878218	1E4436	9282 182237	FARIDA NIKOLAEVA	{"phone": "+70225639922"}
0005434878219	ADB41A	2063 511915	VIKTOR IVANOV	{"phone": "+70442163938"}
0005434878220	2AD96E	0344 925551	LIDIYA MATVEEVA	{"phone": "+70061965816"}
0005434878221	7F4EE8	9482 508383	ALEKSANDR TARASOV	{"email": "a.tarasov_091970@postgrespro.ru", "phone": "+70581559517"}
0005434878222	C025A0	8578 918002	NATALYA NIKOLAEVA	{"email": "nikolaevanatalya_28011971@postgrespro.ru", "phone": "+70651554845"}
0005434878223	C025A0	7942 611661	EKATERINA FEDOROVA	{"email": "e_fedorova_1973@postgrespro.ru", "phone": "+70660838426"}
0005434878224	B80375	2564 506019	ALEKSANDR RODIONOV	{"email": "aleksandrrodionov-101974@postgrespro.ru", "phone": "+70646429928"}
0005434878225	CC65B6	7274 011787	VLADIMIR STEPANOV	{"email": "vladimir.stepanov.26011966@postgrespro.ru", "phone": "+70214002145"}
0005434878226	CC65B6	1892 380283	VERA NIKITINA	{"email": "v-nikitina07121968@postgrespro.ru", "phone": "+70815515171"}
0005434878227	4F7C96	5406 533236	NINA NAZAROVA	{"phone": "+70521873348"}
0005434878228	F8EAA2	4493 508135	LYUDMILA KAZAKOVA	{"phone": "+70337581840"}
0005434878229	15FE3E	9145 018868	SERGEY FOMIN	{"phone": "+70635608413"}
0005434878230	83BEE4	1946 531313	VLADIMIR BORISOV	{"email": "v.borisov-091973@postgrespro.ru", "phone": "+70022953747"}
0005434878231	A2604A	7231 552486	MAKSIM OSIPOV	{"email": "osipov.m-1963@postgrespro.ru", "phone": "+70849605019"}
0005434878232	A2604A	1754 076481	RIFAT STEPANOV	{"email": "rstepanov_111973@postgrespro.ru", "phone": "+70092018502"}
0005434878233	B348BA	7767 084531	ALLA KARPOVA	{"phone": "+70238192673"}
0005434878234	B348BA	5226 537376	MARIYA YAKOVLEVA	{"email": "yakovleva_mariya.031971@postgrespro.ru", "phone": "+70893923314"}
0005434878235	C2CF84	6276 368036	MARGARITA ILINA	{"phone": "+70540314564"}
0005434878236	C2CF84	2297 456801	NIKITA FROLOV	{"email": "frolov_nikita_27111961@postgrespro.ru", "phone": "+70944759185"}
0005434878237	D41108	9707 245744	EVGENIYA PAVLOVA	{"email": "pavlova.e-101964@postgrespro.ru", "phone": "+70796128894"}
0005434878238	752B10	3773 123603	ZULFIYA PETROVA	{"email": "zpetrova.101968@postgrespro.ru", "phone": "+70899729800"}
0005434878239	752B10	0702 364451	PETR BELOV	{"email": "p_belov.28081962@postgrespro.ru", "phone": "+70399417203"}
0005434878240	B889AF	2063 687536	ANASTASIYA ZHURAVLEVA	{"phone": "+70312939602"}
0005434878241	3225AC	3592 551656	PELAGEYA FADEEVA	{"email": "p-fadeeva-1967@postgrespro.ru", "phone": "+70011585361"}
0005434878465	068BAA	9139 627166	LYUBOV VOLKOVA	{"phone": "+70260201011"}
0005434878242	3225AC	5211 151937	ANASTASIYA GAVRILOVA	{"email": "gavrilova_a_1970@postgrespro.ru", "phone": "+70745628241"}
0005434878243	1276ED	4089 107963	NIKOLAY MAKAROV	{"phone": "+70800298954"}
0005434878244	0CCF6C	2114 430342	NIKOLAY EGOROV	{"email": "egorov_n.081969@postgrespro.ru", "phone": "+70116972354"}
0005434878245	227BEC	5061 906095	NIKITA SMIRNOV	{"email": "nsmirnov-061967@postgrespro.ru", "phone": "+70267878103"}
0005434878246	C2B7D8	4878 176281	ALEVTINA KOZLOVA	{"email": "kozlova_a-121972@postgrespro.ru", "phone": "+70961793781"}
0005434878247	C2B7D8	5670 856465	ALEKSANDR KOZLOV	{"email": "kozlova.08011968@postgrespro.ru", "phone": "+70351979020"}
0005434878248	C8AC5D	9386 706218	ALEKSANDR SEMENOV	{"phone": "+70093974051"}
0005434878249	9688AA	4687 200557	ANDREY ALEKSEEV	{"email": "alekseev.a.1978@postgrespro.ru", "phone": "+70422586905"}
0005434878250	4F1437	1033 705933	ARINA BORISOVA	{"email": "borisova.arina_1978@postgrespro.ru", "phone": "+70761690895"}
0005434878251	4F1437	6647 505132	POLINA PETROVA	{"phone": "+70038129087"}
0005434878252	BB377A	6644 377544	VALENTINA VASILEVA	{"email": "valentinavasileva-11061970@postgrespro.ru", "phone": "+70379200760"}
0005434878253	BB377A	0034 771936	GALINA PAVLOVA	{"phone": "+70870486313"}
0005434878254	461806	9377 579217	VLADIMIR SERGEEV	{"email": "vladimir_sergeev.12031964@postgrespro.ru", "phone": "+70656519774"}
0005434878255	71C40A	3747 807777	MATVEY NIKOLAEV	{"email": "m_nikolaev-27041965@postgrespro.ru", "phone": "+70952413695"}
0005434878256	9B74F8	5410 530584	ANTONINA MAKAROVA	{"email": "amakarova-111970@postgrespro.ru", "phone": "+70598784294"}
0005434878257	8CF2BE	1034 013712	VALENTINA ORLOVA	{"phone": "+70121719698"}
0005434878258	8CF2BE	4361 218956	VLADIMIR NOVIKOV	{"email": "novikov_vladimir-061969@postgrespro.ru", "phone": "+70673514806"}
0005434878259	8CF2BE	7735 997000	ALLA ERMAKOVA	{"email": "a-ermakova_01041969@postgrespro.ru", "phone": "+70701035640"}
0005434878260	F1782A	4691 391331	TATYANA CHERNOVA	{"phone": "+70318237397"}
0005434878261	F92DAE	4318 261870	FEDOR FILIPPOV	{"phone": "+70232994994"}
0005434878262	F92DAE	6101 933259	VALENTINA IVANOVA	{"email": "valentina-ivanova-12041972@postgrespro.ru", "phone": "+70100076129"}
0005434878263	96DA0E	8424 426393	NATALYA EGOROVA	{"email": "negorova_011968@postgrespro.ru", "phone": "+70841653301"}
0005434878264	96CB7C	9197 551727	EVGENIY POPOV	{"email": "popov_evgeniy_1989@postgrespro.ru", "phone": "+70946513043"}
0005434878265	A77D24	4787 815675	OLGA MATVEEVA	{"email": "matveeva_olga_14061967@postgrespro.ru", "phone": "+70977026085"}
0005434878266	A77D24	0161 587585	NIKOLAY MIRONOV	{"phone": "+70666196445"}
0005434878267	606EBB	8741 598222	ALEKSEY FILIPPOV	{"email": "a-filippov16061969@postgrespro.ru", "phone": "+70452818944"}
0005434878268	1D0B55	4718 746853	NATALYA SERGEEVA	{"phone": "+70994852971"}
0005434878269	C1E8E7	0986 705667	SERGEY KUDRYASHOV	{"phone": "+70954535752"}
0005434878270	C1E8E7	3306 434645	LIDIYA ANDREEVA	{"phone": "+70584937338"}
0005434878271	7E5B74	6632 677754	BORIS MATVEEV	{"email": "matveev-b-1974@postgrespro.ru", "phone": "+70200921053"}
0005434878272	22503C	4306 427395	MAKSIM ABRAMOV	{"email": "m.abramov021970@postgrespro.ru", "phone": "+70987866163"}
0005434878273	22503C	1796 270171	IRAIDA ANTONOVA	{"email": "antonovairaida_1973@postgrespro.ru", "phone": "+70437016105"}
0005434878274	D74A98	2928 013587	TATYANA VASILEVA	{"email": "vasileva-t-1977@postgrespro.ru", "phone": "+70924024382"}
0005434878275	D74A98	3587 324335	ALEKSEY BORISOV	{"phone": "+70141212809"}
0005434878276	A8B021	9621 829013	RASHID ALEKSANDROV	{"email": "rashidaleksandrov_1975@postgrespro.ru", "phone": "+70697270359"}
0005434878277	A8B021	8061 352940	NATALYA MARTYNOVA	{"email": "martynovan-21091979@postgrespro.ru", "phone": "+70711572032"}
0005434878278	4BBDD7	4611 882359	VASILIY ANDREEV	{"email": "andreevvasiliy-071974@postgrespro.ru", "phone": "+70929701166"}
0005434878279	7C1E4A	9181 252391	IRINA ANDREEVA	{"email": "i_andreeva.1976@postgrespro.ru", "phone": "+70443859933"}
0005434878280	D6ABE9	3393 442246	ELENA KISELEVA	{"email": "kiselevae.081974@postgrespro.ru", "phone": "+70988190693"}
0005434878281	D6ABE9	0614 497353	VIKTOR SMIRNOV	{"phone": "+70579469400"}
0005434878282	D14909	0908 699675	LEV IVANOV	{"email": "ivanov.l_03011973@postgrespro.ru", "phone": "+70450953164"}
0005434878283	AC04C5	6249 406867	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov091978@postgrespro.ru", "phone": "+70581676142"}
0005434878284	6F6630	2943 833828	ALEKSEY SAVELEV	{"phone": "+70741823301"}
0005434878285	AEA648	0312 410930	BORIS ORLOV	{"email": "orlov-boris-22061975@postgrespro.ru", "phone": "+70686163634"}
0005434878286	AEA648	1060 622106	TATYANA KUZNECOVA	{"phone": "+70878079901"}
0005434878762	14C2F7	9756 991060	VALENTIN SAVELEV	{"phone": "+70868363668"}
0005434878287	E96D7B	4928 164620	DMITRIY SAVELEV	{"email": "d-savelev.101972@postgrespro.ru", "phone": "+70608879309"}
0005434878288	D04FC1	1376 059856	OLGA SIDOROVA	{"email": "olga_sidorova_1971@postgrespro.ru", "phone": "+70662365529"}
0005434878289	4E5B52	9798 614775	VYACHESLAV ORLOV	{"phone": "+70128972960"}
0005434878290	8DC78C	1017 818787	STANISLAV DENISOV	{"phone": "+70586480768"}
0005434878291	4F2BA4	6623 547189	BORIS BARANOV	{"email": "baranov_b-23051972@postgrespro.ru", "phone": "+70056552287"}
0005434878292	B15C0A	0027 888031	VIKTOR ZAKHAROV	{"phone": "+70163342712"}
0005434878293	8E7470	3378 727686	ANNA VLASOVA	{"email": "anna-vlasova.101980@postgrespro.ru", "phone": "+70867004354"}
0005434878294	871B38	8166 176267	ALEKSEY POPOV	{"phone": "+70580463124"}
0005434878295	3A4F37	6986 397960	NIKOLAY GRIGOREV	{"phone": "+70320856131"}
0005434878296	992965	8371 098028	EGOR NIKOLAEV	{"phone": "+70765757055"}
0005434878297	9FF3D3	8306 946832	NATALYA SERGEEVA	{"email": "natalya.sergeeva17041968@postgrespro.ru", "phone": "+70385980501"}
0005434878298	E22973	4114 809040	DMITRIY BARANOV	{"email": "baranovdmitriy_05071979@postgrespro.ru", "phone": "+70829273146"}
0005434878299	DB5F3A	9024 503899	ANATOLIY KUZNECOV	{"phone": "+70262273510"}
0005434878300	DB5F3A	9766 981937	ALEKSANDR DAVYDOV	{"phone": "+70894766378"}
0005434878301	BE9CB2	5538 361669	TATYANA SIDOROVA	{"phone": "+70685796678"}
0005434878302	0DE4CE	7279 241376	ALLA ANTONOVA	{"phone": "+70333564773"}
0005434878303	0DE4CE	7840 465443	VLADIMIR SMIRNOV	{"phone": "+70511956525"}
0005434878304	2F4181	2407 835444	OLGA PAVLOVA	{"phone": "+70739357858"}
0005434878305	3E9D66	3089 215006	OLGA RYABOVA	{"phone": "+70298081440"}
0005434878306	3E9D66	0332 543035	LYUDMILA ZAKHAROVA	{"phone": "+70750587858"}
0005434878307	39D497	7808 667489	LEONID VASILEV	{"phone": "+70428275494"}
0005434878308	6F0981	8762 216149	VALERIY KARPOV	{"phone": "+70906723602"}
0005434878309	0415B3	7620 793433	NIKOLAY MOROZOV	{"email": "morozov-n-021972@postgrespro.ru", "phone": "+70764261995"}
0005434878310	F8695C	2072 265145	PETR ZAKHAROV	{"phone": "+70190113588"}
0005434878311	16CD31	7559 243283	ANATOLIY IVANOV	{"email": "a.ivanov011976@postgrespro.ru", "phone": "+70448186516"}
0005434878312	95768B	2390 592200	ALINA KALININA	{"email": "alina_kalinina021976@postgrespro.ru", "phone": "+70321477991"}
0005434878313	95768B	2838 088953	IRINA SOLOVEVA	{"email": "irina_soloveva.19021968@postgrespro.ru", "phone": "+70264578459"}
0005434878314	764D90	4111 906115	MARAT PAVLOV	{"phone": "+70833030526"}
0005434878315	764D90	0846 907384	MARIYA SOKOLOVA	{"phone": "+70884549890"}
0005434878316	140E28	8401 637002	DMITRIY ABRAMOV	{"email": "abramov_dmitriy-071964@postgrespro.ru", "phone": "+70817918243"}
0005434878317	140E28	9406 765166	ELENA EGOROVA	{"email": "egorova_e.1986@postgrespro.ru", "phone": "+70450206318"}
0005434878318	5A8588	3525 835387	VLADIMIR SERGEEV	{"phone": "+70995980199"}
0005434878319	79A87F	2459 673827	PETR KULIKOV	{"phone": "+70636165130"}
0005434878320	79A87F	5444 216566	AMIR POPOV	{"email": "popov_amir041970@postgrespro.ru", "phone": "+70135596991"}
0005434878321	E920FA	2564 814903	NIKITA ROMANOV	{"phone": "+70324562542"}
0005434878322	DF57AD	6816 299412	PAVEL MELNIKOV	{"phone": "+70118297487"}
0005434878323	DF57AD	1571 731436	MARIYA POLYAKOVA	{"email": "mpolyakova_24061966@postgrespro.ru", "phone": "+70172450775"}
0005434878324	DEDE52	0100 444774	ELENA MAKAROVA	{"phone": "+70613679690"}
0005434878325	DEDE52	7175 578761	VALENTINA KUDRYASHOVA	{"phone": "+70468728625"}
0005434878326	485C22	2497 464670	GENNADIY NAZAROV	{"email": "gennadiy-nazarov061980@postgrespro.ru", "phone": "+70529791640"}
0005434878327	485C22	5464 361282	SERGEY EGOROV	{"phone": "+70220267901"}
0005434878328	485C22	1408 642194	NINA LOGINOVA	{"phone": "+70802510421"}
0005434878329	19CF62	4244 460451	OLGA FEDOROVA	{"email": "fedorovaolga.1961@postgrespro.ru", "phone": "+70004257009"}
0005434878330	19CF62	6408 397926	IRINA BOGDANOVA	{"email": "bogdanova.irina-1972@postgrespro.ru", "phone": "+70357442370"}
0005434878331	86639C	2752 297772	ALEKSANDR PAVLOV	{"email": "pavlova20051961@postgrespro.ru", "phone": "+70384103577"}
0005434878332	EA4064	3279 470248	VADIM ROMANOV	{"phone": "+70824830556"}
0005434878333	EA4064	4082 350308	EVGENIY YAKOVLEV	{"phone": "+70535086967"}
0005434878334	836830	8443 814461	ELENA IVANOVA	{"phone": "+70908013883"}
0005434878335	B7C5E6	6023 121120	NINA FROLOVA	{"email": "nina-frolova1979@postgrespro.ru", "phone": "+70753349942"}
0005434878336	B7C5E6	3812 542892	ALEKSEY KULIKOV	{"email": "aleksey-kulikov.121979@postgrespro.ru", "phone": "+70359016620"}
0005434878337	B7C5E6	9810 991029	MAKSIM STEPANOV	{"email": "stepanovmaksim-1966@postgrespro.ru", "phone": "+70381055049"}
0005434878338	B7C5E6	4535 950688	EVGENIYA SIDOROVA	{"phone": "+70565408081"}
0005434878339	2DFBFC	7406 460154	SERGEY NOVIKOV	{"email": "sergeynovikov_041962@postgrespro.ru", "phone": "+70799071141"}
0005434878340	EDB38D	9851 502426	IRINA LUKYANOVA	{"phone": "+70251106598"}
0005434878341	B203F0	3499 452724	ALEKSANDR FEDOTOV	{"phone": "+70912412945"}
0005434878342	15C9C8	1963 497211	LYUDMILA ALEKSEEVA	{"email": "alekseeva-l.051974@postgrespro.ru", "phone": "+70393992029"}
0005434878343	AE62CD	0971 467034	ALENA SMIRNOVA	{"email": "smirnova-a_091971@postgrespro.ru", "phone": "+70013911858"}
0005434878344	097E63	5514 285701	OLEG SCHERBAKOV	{"phone": "+70385375255"}
0005434878345	5F1B26	8134 710978	NATALYA BELYAEVA	{"email": "belyaeva.n011965@postgrespro.ru", "phone": "+70619700171"}
0005434878346	67B62A	9489 325294	YURIY GORBUNOV	{"email": "gorbunovy-1971@postgrespro.ru", "phone": "+70332028616"}
0005434878347	26537C	5239 336021	OLGA SIDOROVA	{"email": "olga_sidorova.09021965@postgrespro.ru", "phone": "+70524455491"}
0005434878348	26537C	8227 445266	TATYANA NOVIKOVA	{"email": "novikova.tatyana-041981@postgrespro.ru", "phone": "+70493217875"}
0005434878349	4CF8AC	1968 824077	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev.081980@postgrespro.ru", "phone": "+70303129017"}
0005434878350	C7D291	6150 213174	VYACHESLAV MAKSIMOV	{"email": "maksimov.v_27111965@postgrespro.ru", "phone": "+70398045023"}
0005434878351	C7D291	0810 898106	MIKHAIL SEMENOV	{"phone": "+70707477958"}
0005434878352	D4B132	7959 433094	TAMARA DAVYDOVA	{"email": "davydova.t_071973@postgrespro.ru", "phone": "+70663757354"}
0005434878353	515478	5651 595115	MIKHAIL MIKHAYLOV	{"phone": "+70641377509"}
0005434878354	9624B6	4459 944812	ANASTASIYA LAZAREVA	{"email": "lazareva.a-30111970@postgrespro.ru", "phone": "+70901443383"}
0005434878355	8FA7B5	4880 517360	ALEKSANDR SIDOROV	{"email": "asidorov.03081966@postgrespro.ru", "phone": "+70907061610"}
0005434878356	BC7970	0487 952494	DARYA ANISIMOVA	{"email": "anisimova.d.101979@postgrespro.ru", "phone": "+70536944494"}
0005434878357	02969A	9786 044444	SVETLANA FILIPPOVA	{"phone": "+70901828482"}
0005434878358	02969A	3893 260870	ALEKSANDR SAVELEV	{"email": "a_savelev_26031962@postgrespro.ru", "phone": "+70879525815"}
0005434878359	2711D2	4552 917540	ELENA MAKAROVA	{"email": "emakarova.06011973@postgrespro.ru", "phone": "+70720511072"}
0005434878360	2711D2	8873 768404	TAISIYA KUZNECOVA	{"phone": "+70379584552"}
0005434878361	7317D4	0016 252780	TATYANA SEMENOVA	{"email": "tatyanasemenova.021970@postgrespro.ru", "phone": "+70755064555"}
0005434878362	7317D4	1992 764051	VALENTIN KOROLEV	{"phone": "+70572973566"}
0005434878363	4A137B	1731 573708	DARINA PETROVA	{"email": "dpetrova_091960@postgrespro.ru", "phone": "+70561097478"}
0005434878364	5A9C36	7120 657413	NINA SOKOLOVA	{"email": "sokolova_n.12071979@postgrespro.ru", "phone": "+70491634936"}
0005434878365	20BFFF	7075 201245	LILIYA FROLOVA	{"email": "frolova-l.09031978@postgrespro.ru", "phone": "+70862154242"}
0005434878366	8D1AB4	9388 700552	SERGEY GUSEV	{"phone": "+70965340880"}
0005434878367	768D6B	4072 965377	VLADIMIR VASILEV	{"email": "vasilevvladimir1972@postgrespro.ru", "phone": "+70677981350"}
0005434878368	1DEAFA	6284 870967	ANTON KUZNECOV	{"email": "anton.kuznecov-061978@postgrespro.ru", "phone": "+70320997723"}
0005434878369	1DEAFA	4855 604320	TAMARA BELOVA	{"email": "tamara_belova-1968@postgrespro.ru", "phone": "+70073123286"}
0005434878370	645EDB	1997 732370	ILYA ILIN	{"phone": "+70838248673"}
0005434878371	B0837B	2035 827328	IVAN KUZNECOV	{"phone": "+70296541786"}
0005434878372	372C7D	7574 604320	IRINA SIDOROVA	{"phone": "+70029524208"}
0005434878373	3C3101	9111 899113	TAISIYA NESTEROVA	{"phone": "+70242872988"}
0005434878374	3C3101	3189 908368	GENNADIY BORISOV	{"phone": "+70705107845"}
0005434878375	0A3A21	0267 957887	VALERIY KARPOV	{"email": "vkarpov.29071980@postgrespro.ru", "phone": "+70204047601"}
0005434878376	D3F146	9838 708848	ANATOLIY SEMENOV	{"phone": "+70041636657"}
0005434878377	6A37F0	4503 275436	SERGEY KARPOV	{"phone": "+70204837554"}
0005434878378	6A37F0	2151 162879	SERGEY NOVIKOV	{"phone": "+70352149429"}
0005434878379	C18977	8035 934827	ELENA MIKHAYLOVA	{"email": "mikhaylova-elena02111979@postgrespro.ru", "phone": "+70959732593"}
0005434878380	2AF761	2275 072330	VITALIY KUZNECOV	{"email": "v.kuznecov021970@postgrespro.ru", "phone": "+70430888373"}
0005434878381	62E047	9835 699760	EKATERINA YUDINA	{"phone": "+70012916260"}
0005434878382	30C84D	4267 987834	IRINA LAZAREVA	{"phone": "+70064212072"}
0005434878383	30C84D	9855 948760	YURIY IVANOV	{"email": "yuriy-ivanov_071972@postgrespro.ru", "phone": "+70356366006"}
0005434878384	30C84D	2722 952880	NIKOLAY MAKAROV	{"phone": "+70540922152"}
0005434878385	EF3B82	2185 963817	ELENA TROFIMOVA	{"phone": "+70044077313"}
0005434878386	EF3B82	0644 708909	ILYA ABRAMOV	{"phone": "+70062979430"}
0005434878387	668C41	1759 740927	ALEKSANDR BARANOV	{"phone": "+70464667243"}
0005434878388	BFEDBD	5060 656659	ALINA AKIMOVA	{"email": "akimova.a_031965@postgrespro.ru", "phone": "+70431721091"}
0005434878389	0C2742	0709 412433	NATALYA STEPANOVA	{"phone": "+70801359216"}
0005434878390	E32D01	4059 926624	ALEKSANDR GUSEV	{"email": "agusev-021980@postgrespro.ru", "phone": "+70823835051"}
0005434878391	E32D01	6768 334509	IVAN PETROV	{"phone": "+70667749977"}
0005434878392	168685	8905 496934	SERGEY SERGEEV	{"phone": "+70874039510"}
0005434878393	B56E10	6845 035868	ANDREY GAVRILOV	{"email": "gavrilovandrey1979@postgrespro.ru", "phone": "+70551483333"}
0005434878394	AF921F	6183 144293	DMITRIY KISELEV	{"phone": "+70154107468"}
0005434878395	AF921F	8413 778239	ARTUR SIDOROV	{"email": "sidorov-a111970@postgrespro.ru", "phone": "+70042333509"}
0005434878396	F8CB50	3642 579177	LYUDMILA ANDREEVA	{"phone": "+70361171228"}
0005434878397	F8CB50	4449 947239	SOFIYA KONOVALOVA	{"email": "sofiyakonovalova101978@postgrespro.ru", "phone": "+70437504346"}
0005434878398	321B48	0932 424677	PAVEL GAVRILOV	{"email": "gavrilov-pavel23051973@postgrespro.ru", "phone": "+70930325033"}
0005434878399	321B48	8100 388498	VALERIY SCHERBAKOV	{"phone": "+70948082350"}
0005434878400	FE846D	9826 085299	VLADISLAV NOVIKOV	{"phone": "+70420803057"}
0005434878401	5B2D81	2377 669567	MARINA ILINA	{"email": "marina.ilina-011962@postgrespro.ru", "phone": "+70971835812"}
0005434878402	686FD9	5743 119769	VASILIY SOROKIN	{"phone": "+70578785917"}
0005434878403	DBF736	6604 099984	YURIY FILIPPOV	{"phone": "+70658825194"}
0005434878404	DBF736	1211 170792	DENIS KUZNECOV	{"email": "d_kuznecov-071968@postgrespro.ru", "phone": "+70156576963"}
0005434878405	ADF419	5507 862989	OLEG NAZAROV	{"email": "o-nazarov031972@postgrespro.ru", "phone": "+70234626719"}
0005434878406	920A19	5443 424361	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-1960@postgrespro.ru", "phone": "+70300205613"}
0005434878407	C24294	8836 848668	NATALYA KONDRATEVA	{"email": "kondrateva-natalya.23111962@postgrespro.ru", "phone": "+70893264326"}
0005434878408	72B39C	8897 508581	VLADIMIR MAKAROV	{"phone": "+70960967483"}
0005434878409	59806F	9346 878893	NATALIYA NAUMOVA	{"email": "naumova.n-021981@postgrespro.ru", "phone": "+70444895692"}
0005434878410	76EF54	5152 093495	SVETLANA KUZMINA	{"email": "svetlana.kuzmina03081962@postgrespro.ru", "phone": "+70222740022"}
0005434878411	98B228	8037 047471	TATYANA POPOVA	{"email": "popova-tatyana121979@postgrespro.ru", "phone": "+70788714856"}
0005434878412	98B228	4644 245443	NATALIYA MARTYNOVA	{"email": "nataliyamartynova_051970@postgrespro.ru", "phone": "+70733836942"}
0005434878413	E5D3BA	0485 197081	ELENA NESTEROVA	{"email": "enesterova041974@postgrespro.ru", "phone": "+70396688594"}
0005434878414	E5D3BA	9890 136128	NATALYA SOKOLOVA	{"email": "sokolova-n_081981@postgrespro.ru", "phone": "+70675411261"}
0005434878415	F94D62	0761 754207	DANIIL OSIPOV	{"email": "osipov.daniil-021976@postgrespro.ru", "phone": "+70704963928"}
0005434878416	D18F9C	3000 211188	ALEKSANDR SEMENOV	{"email": "a_semenov041973@postgrespro.ru", "phone": "+70225950099"}
0005434878417	CC0CA9	9645 608102	YULIYA DMITRIEVA	{"email": "dmitrieva_yuliya_021978@postgrespro.ru", "phone": "+70530924122"}
0005434878418	2FA9D1	0863 555612	ALEKSANDRA MIRONOVA	{"email": "aleksandra-mironova071975@postgrespro.ru", "phone": "+70254861898"}
0005434878419	16CE8D	7248 170644	DANIIL FROLOV	{"email": "frolovdaniil.081961@postgrespro.ru", "phone": "+70206352902"}
0005434878420	C66B07	4450 100281	ALEKSEY IVANOV	{"email": "aleksey_ivanov.101971@postgrespro.ru", "phone": "+70019448250"}
0005434878421	C66B07	4588 121955	ELENA FEDOROVA	{"phone": "+70474795467"}
0005434878422	21F485	9486 625946	TATYANA TROFIMOVA	{"email": "t-trofimova-08081967@postgrespro.ru", "phone": "+70189500244"}
0005434878423	21F485	8203 615287	SERGEY MIRONOV	{"phone": "+70380073284"}
0005434878424	5E34F5	5297 144280	ELENA LEBEDEVA	{"phone": "+70923229163"}
0005434878425	5E34F5	7194 227398	EKATERINA KUZNECOVA	{"email": "e-kuznecova111971@postgrespro.ru", "phone": "+70259313972"}
0005434878426	8297B3	8757 642433	NATALYA VOLKOVA	{"email": "volkova.n.03101990@postgrespro.ru", "phone": "+70242621293"}
0005434878427	1697DE	4492 091197	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr_041972@postgrespro.ru", "phone": "+70567047562"}
0005434878428	00E24D	4965 958156	MIKHAIL VASILEV	{"phone": "+70783216671"}
0005434878429	C9B845	1686 824268	NATALYA MOISEEVA	{"email": "moiseeva-n.051980@postgrespro.ru", "phone": "+70188042381"}
0005434878430	3C4ABE	6708 442496	SVETLANA ARKHIPOVA	{"phone": "+70913637515"}
0005434878431	3C4ABE	6398 577261	ZLATA MARTYNOVA	{"email": "zlata_martynova-101972@postgrespro.ru", "phone": "+70540827730"}
0005434878432	31E750	0344 670102	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov-1974@postgrespro.ru", "phone": "+70461449193"}
0005434878433	31E750	2712 251821	NADEZHDA ROMANOVA	{"phone": "+70390868446"}
0005434878434	CE20F0	6319 741824	VYACHESLAV MIKHAYLOV	{"phone": "+70074413860"}
0005434878435	CE20F0	6203 664240	EKATERINA KOROLEVA	{"phone": "+70517948103"}
0005434878436	A6F631	0344 290876	VLADIMIR BARANOV	{"email": "baranovv1969@postgrespro.ru", "phone": "+70666706679"}
0005434878437	6BF59C	8474 401765	DANIL TIKHONOV	{"phone": "+70045462762"}
0005434878438	6BF59C	2435 712390	VLADIMIR BARANOV	{"phone": "+70082631369"}
0005434878439	2799E8	7367 535851	ALEKSEY NIKOLAEV	{"phone": "+70560444895"}
0005434878440	4AEC88	6899 466080	ALEKSEY GORBUNOV	{"phone": "+70405480756"}
0005434878441	4AEC88	9861 231590	VLADIMIR GUSEV	{"email": "gusev_vladimir-15101962@postgrespro.ru", "phone": "+70200449797"}
0005434878442	9E24B7	3823 361265	VITALIY VLASOV	{"email": "vitaliy.vlasov.15091963@postgrespro.ru", "phone": "+70505827911"}
0005434878443	9E24B7	9190 683688	TATYANA VASILEVA	{"phone": "+70691721727"}
0005434878444	2C2ED9	6802 673117	FAINA EFIMOVA	{"phone": "+70975276840"}
0005434878445	1A98A0	3031 454772	RAISA BELOVA	{"phone": "+70628684273"}
0005434878446	BA5F2B	6142 094573	TATYANA MAKSIMOVA	{"phone": "+70176573856"}
0005434878447	BA5F2B	0017 708910	NINA ABRAMOVA	{"phone": "+70951499029"}
0005434878448	6965F1	5622 512301	KLAVDIYA ALEKSANDROVA	{"email": "k.aleksandrova021965@postgrespro.ru", "phone": "+70556034902"}
0005434878449	08BCCB	3568 306249	VALERIY KAZAKOV	{"phone": "+70595192261"}
0005434878450	F57CF4	1540 940406	ARTEM FEDOTOV	{"email": "fedotov.artem-1976@postgrespro.ru", "phone": "+70672630863"}
0005434878451	1A7C77	7964 879016	TATYANA ISAEVA	{"email": "isaeva_t.1976@postgrespro.ru", "phone": "+70525370513"}
0005434878452	E55588	0518 065842	VALERIY NOVIKOV	{"email": "novikov_valeriy_101973@postgrespro.ru", "phone": "+70731371824"}
0005434878453	52413A	1359 553286	SVETLANA SOKOLOVA	{"phone": "+70752328242"}
0005434878454	861D72	7827 921622	ROMAN OSIPOV	{"email": "r.osipov1976@postgrespro.ru", "phone": "+70371063753"}
0005434878455	C74EAA	0246 834878	VIKTOR PETROV	{"phone": "+70287503539"}
0005434878456	5AB117	3673 726848	LYUDMILA ZAYCEVA	{"email": "lyudmilazayceva011973@postgrespro.ru", "phone": "+70806769378"}
0005434878457	0DE15E	7352 775447	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr-081982@postgrespro.ru", "phone": "+70884751543"}
0005434878458	0DE15E	9819 937548	ALEKSEY KRASNOV	{"phone": "+70574990023"}
0005434878459	2AEE7B	7832 489059	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr1966@postgrespro.ru", "phone": "+70898400081"}
0005434878460	1083D8	5686 609081	VLADIMIR MAKAROV	{"email": "makarov.v1970@postgrespro.ru", "phone": "+70307408864"}
0005434878461	52828B	3662 127911	NIKOLAY FROLOV	{"phone": "+70979251263"}
0005434878462	EA29EF	5754 004760	PETR ZAKHAROV	{"phone": "+70434617180"}
0005434878463	EA29EF	4544 697397	VALENTINA ALEKSEEVA	{"phone": "+70587853946"}
0005434878464	F0C9EB	4029 186729	SVETLANA ISAEVA	{"email": "isaeva.svetlana-01081985@postgrespro.ru", "phone": "+70230799879"}
0005434878466	6B40C3	2084 530489	ALEKSANDR POPOV	{"email": "apopov_26011982@postgrespro.ru", "phone": "+70210606405"}
0005434878467	2C7624	5778 077731	MAKSIM KUZMIN	{"phone": "+70886355874"}
0005434878468	2C7624	2973 098706	NATALYA BELYAEVA	{"email": "nbelyaeva021975@postgrespro.ru", "phone": "+70568308487"}
0005434878469	587BED	2994 496152	OLEG VOLKOV	{"email": "volkovo17121973@postgrespro.ru", "phone": "+70419656411"}
0005434878470	315336	3210 366604	RUSLAN SOKOLOV	{"phone": "+70066837996"}
0005434878471	819942	6977 572491	YURIY MIRONOV	{"email": "mironov_y10021966@postgrespro.ru", "phone": "+70850057259"}
0005434878472	819942	4754 665023	LYUDMILA KOROLEVA	{"email": "koroleval.02021974@postgrespro.ru", "phone": "+70175372619"}
0005434878473	8F87BD	0746 363341	TATYANA MALYSHEVA	{"phone": "+70667862581"}
0005434878474	590DF7	2457 213700	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya.mikhaylova1981@postgrespro.ru", "phone": "+70751745855"}
0005434878475	0D9EBB	7750 249858	OLGA NESTEROVA	{"email": "olga-nesterova-1975@postgrespro.ru", "phone": "+70959689976"}
0005434878476	69B41B	2526 742567	ALEKSANDR SOLOVEV	{"phone": "+70012008050"}
0005434878477	A80E79	7350 310344	ALEKSEY PETROV	{"phone": "+70127343513"}
0005434878478	7614BD	8479 130416	DMITRIY KUZNECOV	{"phone": "+70852991037"}
0005434878479	A5FAA2	5917 920099	BORIS DMITRIEV	{"email": "boris-dmitriev27101978@postgrespro.ru", "phone": "+70661128489"}
0005434878480	17CE43	8097 612649	YURIY VOLKOV	{"email": "volkov_y-1977@postgrespro.ru", "phone": "+70671926202"}
0005434878481	17CE43	0671 013356	VERONIKA KUZNECOVA	{"phone": "+70427447594"}
0005434878482	17CE43	1115 472452	NATALYA BORISOVA	{"email": "natalya-borisova.05041968@postgrespro.ru", "phone": "+70485427923"}
0005434878483	62CA31	6511 778705	SERGEY ROMANOV	{"email": "romanovsergey.091961@postgrespro.ru", "phone": "+70828511288"}
0005434878484	5DD004	9882 152156	ALINA FOMINA	{"phone": "+70393558414"}
0005434878485	5DD004	0497 731171	OLEG SAVELEV	{"phone": "+70081693334"}
0005434878486	97C34B	4747 120104	DMITRIY FOMIN	{"phone": "+70563061527"}
0005434878487	E2FE3F	7084 538945	EKATERINA KOROLEVA	{"email": "ekaterinakoroleva_021977@postgrespro.ru", "phone": "+70558757703"}
0005434878488	B66928	8506 592707	ALEKSEY ANDREEV	{"email": "aleksey-andreev31011971@postgrespro.ru", "phone": "+70891963437"}
0005434878489	D0F4F4	8169 059315	SERGEY AFANASEV	{"email": "safanasev-011980@postgrespro.ru", "phone": "+70802351178"}
0005434878490	E17F3C	3504 609096	ZHANNA TIMOFEEVA	{"email": "timofeeva.z_021973@postgrespro.ru", "phone": "+70759472615"}
0005434878491	9D0D35	5814 274949	MARIYA SAVELEVA	{"email": "m_saveleva08121961@postgrespro.ru", "phone": "+70453851319"}
0005434878492	AC579E	3890 603093	NATALYA MAKSIMOVA	{"phone": "+70255763036"}
0005434878493	359238	5447 973225	TATYANA KUZNECOVA	{"email": "tatyanakuznecova_24021973@postgrespro.ru", "phone": "+70622064775"}
0005434878494	359238	9119 718662	VALERIY ORLOV	{"phone": "+70274714540"}
0005434878495	1FEC41	3064 830551	IRINA NIKIFOROVA	{"email": "nikiforova-i-04041972@postgrespro.ru", "phone": "+70725394495"}
0005434878496	281EB8	4218 852220	IGOR BONDARENKO	{"phone": "+70960265853"}
0005434878497	C3897B	9554 922244	IVAN VASILEV	{"phone": "+70599163059"}
0005434878498	A18D99	3805 361765	GALINA MELNIKOVA	{"phone": "+70933548004"}
0005434878499	2741EA	1605 481098	OKSANA MATVEEVA	{"phone": "+70086631991"}
0005434878500	2741EA	8692 113576	KIRILL KUZNECOV	{"phone": "+70520928754"}
0005434878501	0711CE	2366 331486	TATYANA MAKAROVA	{"phone": "+70959171564"}
0005434878502	75B816	5898 538986	ALEKSANDR ZHUKOV	{"phone": "+70350948879"}
0005434878503	75B816	7834 699868	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr.1969@postgrespro.ru", "phone": "+70617579452"}
0005434878504	75B816	6729 232668	EKATERINA KOZLOVA	{"phone": "+70560141522"}
0005434878505	FE6DEB	9509 446994	SVETLANA LOGINOVA	{"phone": "+70419575300"}
0005434878506	FE6DEB	6094 029652	NIKOLAY KAZAKOV	{"email": "n-kazakov-1981@postgrespro.ru", "phone": "+70156746926"}
0005434878507	9BD90F	1059 129735	VERA SERGEEVA	{"email": "sergeeva-v031970@postgrespro.ru", "phone": "+70992512391"}
0005434878508	B6DE83	1812 106741	ANNA MOROZOVA	{"phone": "+70839782689"}
0005434878509	3F8F46	5597 504676	NADEZHDA MATVEEVA	{"phone": "+70466896333"}
0005434878510	3FD730	7970 721367	ANDREY VOROBEV	{"email": "andrey_vorobev_101966@postgrespro.ru", "phone": "+70341484219"}
0005434878511	7080CF	0409 418710	VLADIMIR NIKITIN	{"email": "nikitin.v-06081966@postgrespro.ru", "phone": "+70109078224"}
0005434878512	7080CF	6985 562664	ALI NOVIKOV	{"phone": "+70763588018"}
0005434878513	4243F9	7216 164586	MAKSIM KRASNOV	{"phone": "+70459254092"}
0005434878514	7A5116	6672 864860	VALERIY KUZMIN	{"phone": "+70981023956"}
0005434878515	C8BE61	6155 033534	ANATOLIY KONOVALOV	{"email": "a.konovalov.14011979@postgrespro.ru", "phone": "+70331519623"}
0005434878516	C8BE61	4362 405600	NATALYA KOLESNIKOVA	{"phone": "+70781349654"}
0005434878517	D12EC1	5035 216892	VLADIMIR KONOVALOV	{"phone": "+70436567840"}
0005434878518	DC1E23	6185 535707	ALEKSANDR KARPOV	{"email": "a-karpov_071980@postgrespro.ru", "phone": "+70386895125"}
0005434878519	DC1E23	1400 461486	GENNADIY TIKHONOV	{"email": "g_tikhonov.061967@postgrespro.ru", "phone": "+70208270905"}
0005434878520	D52E9F	6342 791418	GALINA KUZNECOVA	{"email": "kuznecova.g_1977@postgrespro.ru", "phone": "+70179960920"}
0005434878521	682433	7389 908342	LYUBOV PETROVA	{"email": "petroval.101961@postgrespro.ru", "phone": "+70765577861"}
0005434878522	4BDBC0	5655 186782	VALENTIN KOROLEV	{"email": "valentinkorolev_051981@postgrespro.ru", "phone": "+70776433447"}
0005434878523	4BDBC0	8908 187173	DENIS PETROV	{"email": "petrov-d25111962@postgrespro.ru", "phone": "+70482698011"}
0005434878524	D46F84	7375 562083	VLADIMIR ORLOV	{"phone": "+70995336948"}
0005434878525	D46F84	5061 484268	OLGA KOROLEVA	{"email": "olga_koroleva.20021980@postgrespro.ru", "phone": "+70915566256"}
0005434878526	75DA1F	3618 336602	BOGDAN ZAKHAROV	{"email": "bogdan_zakharov.08121972@postgrespro.ru", "phone": "+70590320629"}
0005434878527	3F5360	5487 167987	LYUDMILA ZAYCEVA	{"phone": "+70099616401"}
0005434878528	3F5360	8636 933108	ANDREY EGOROV	{"email": "andreyegorov-07121977@postgrespro.ru", "phone": "+70427861126"}
0005434878529	235017	4219 743228	PETR ILIN	{"email": "ilin-p_1976@postgrespro.ru", "phone": "+70452088904"}
0005434878530	EEF412	2523 451058	VYACHESLAV KULIKOV	{"phone": "+70621589714"}
0005434878531	83305E	9048 364467	NIKOLAY NIKOLAEV	{"email": "nikolay_nikolaev-24111980@postgrespro.ru", "phone": "+70043853240"}
0005434878532	83305E	2210 813558	DMITRIY KUZNECOV	{"phone": "+70494426667"}
0005434878533	6AC085	5036 580500	VITALIY VASILEV	{"email": "vitaliy-vasilev-091964@postgrespro.ru", "phone": "+70821354426"}
0005434878534	D84263	0612 093854	DANIIL BELOV	{"phone": "+70167064733"}
0005434878535	BFACD7	9257 930676	MARIYA ROMANOVA	{"phone": "+70080991138"}
0005434878536	247AC9	1050 378485	TATYANA VOLKOVA	{"email": "t.volkova1970@postgrespro.ru", "phone": "+70055919009"}
0005434878537	4C426B	3809 546267	ELENA GAVRILOVA	{"email": "gavrilovaelena071961@postgrespro.ru", "phone": "+70118519349"}
0005434878538	2D19D1	4089 717502	ALESYA FROLOVA	{"phone": "+70421999712"}
0005434878539	43A710	5667 007459	RAISA FILIPPOVA	{"email": "rfilippova_24071956@postgrespro.ru", "phone": "+70155144324"}
0005434878540	D8655D	5444 358781	SVETLANA KUDRYASHOVA	{"phone": "+70648839296"}
0005434878541	D8655D	4903 970352	ANASTASIYA ABRAMOVA	{"email": "abramova-a_071952@postgrespro.ru", "phone": "+70458707887"}
0005434878542	32AF21	9313 835808	NADEZHDA RODIONOVA	{"phone": "+70706564597"}
0005434878543	71CC57	1838 378185	VLADIMIR ALEKSANDROV	{"email": "aleksandrovvladimir_1957@postgrespro.ru", "phone": "+70119274138"}
0005434878544	B469EC	9553 338634	NIKITA DAVYDOV	{"phone": "+70047356041"}
0005434878545	B469EC	2550 788686	KIRILL MAKAROV	{"email": "k-makarov.111979@postgrespro.ru", "phone": "+70139492494"}
0005434878546	9C612B	5528 592568	ANTONINA YUDINA	{"email": "yudina.a.29031975@postgrespro.ru", "phone": "+70928709392"}
0005434878547	9C612B	7421 899952	ELENA KUZNECOVA	{"email": "e_kuznecova.1970@postgrespro.ru", "phone": "+70161495518"}
0005434878548	A978F7	5646 730172	DANILA IVANOV	{"email": "danila_ivanov_101973@postgrespro.ru", "phone": "+70656388482"}
0005434878549	9DDFBE	2510 042828	VALENTINA ANISIMOVA	{"email": "anisimova_v021977@postgrespro.ru", "phone": "+70309073013"}
0005434878550	9DDFBE	5027 208565	ALEKSEY MAKAROV	{"phone": "+70643784480"}
0005434878551	B69ECC	7755 910890	VLADISLAV TIMOFEEV	{"phone": "+70805208596"}
0005434878552	A22CD0	6351 177310	YURIY POPOV	{"email": "popov-yuriy091980@postgrespro.ru", "phone": "+70558590456"}
0005434878553	A22CD0	3542 719430	TIKHON VASILEV	{"email": "vasilev-tikhon.071979@postgrespro.ru", "phone": "+70116510128"}
0005434878554	24CDB0	1957 133913	RAFAEL FILIPPOV	{"email": "filippov-rafael_05111977@postgrespro.ru", "phone": "+70495864326"}
0005434878555	24CDB0	6442 880386	NADEZHDA POPOVA	{"phone": "+70058031104"}
0005434878556	F4EA00	4243 538297	GALINA GUSEVA	{"email": "galina-guseva.01121974@postgrespro.ru", "phone": "+70202145792"}
0005434878557	F59258	2703 226457	GALINA NIKOLAEVA	{"email": "gnikolaeva.081963@postgrespro.ru", "phone": "+70300373830"}
0005434878558	C1E359	8181 826278	RENAT ORLOV	{"email": "r_orlov.17021970@postgrespro.ru", "phone": "+70438020267"}
0005434878559	F5D633	1259 985459	NIKITA ALEKSANDROV	{"email": "n_aleksandrov-03091970@postgrespro.ru", "phone": "+70784741977"}
0005434878560	F5D633	4973 613554	VALERIY SMIRNOV	{"phone": "+70421863765"}
0005434878561	330F33	4928 449746	ANATOLIY GUSEV	{"phone": "+70635434060"}
0005434878562	1D9F40	7990 236068	SVETLANA DANILOVA	{"phone": "+70324835358"}
0005434878563	0E8B62	0653 545151	GULFIYA VASILEVA	{"phone": "+70044395718"}
0005434878564	7986E3	0375 124270	ANTONINA MIRONOVA	{"email": "antonina-mironova051967@postgrespro.ru", "phone": "+70638560638"}
0005434878565	7986E3	0852 397865	ANDREY ROMANOV	{"phone": "+70029554967"}
0005434878566	7986E3	5494 571748	YURIY ILIN	{"email": "y-ilin-071963@postgrespro.ru", "phone": "+70078136377"}
0005434878567	4BBB81	5777 330423	IRINA TITOVA	{"email": "titova-i-08031988@postgrespro.ru", "phone": "+70755517100"}
0005434878568	4BBB81	1923 289585	ANASTASIYA KONOVALOVA	{"email": "anastasiya-konovalova.041968@postgrespro.ru", "phone": "+70744848021"}
0005434878569	50AAFB	6952 253042	YURIY SHEVCHENKO	{"email": "shevchenko-yuriy-10011975@postgrespro.ru", "phone": "+70672387289"}
0005434878570	375ACA	5471 776579	NATALYA ARKHIPOVA	{"email": "natalya_arkhipova031980@postgrespro.ru", "phone": "+70585144211"}
0005434878571	375ACA	0567 934809	LYUDMILA NIKOLAEVA	{"phone": "+70232403167"}
0005434878572	04C204	0969 775863	GALINA MAKSIMOVA	{"phone": "+70579756385"}
0005434878573	04C204	5506 567510	SVETLANA KUDRYASHOVA	{"email": "kudryashova.svetlana_30091973@postgrespro.ru", "phone": "+70063101884"}
0005434878574	471D5D	6447 051507	NATALYA MAKSIMOVA	{"email": "maksimova.n.091963@postgrespro.ru", "phone": "+70774157504"}
0005434878575	471D5D	6166 125536	LYUBOV ILINA	{"phone": "+70659390394"}
0005434878576	AB3375	4776 265522	YULIYA EGOROVA	{"email": "y-egorova_04051980@postgrespro.ru", "phone": "+70217925270"}
0005434878577	6ACA19	4984 382442	MARIYA LUKYANOVA	{"email": "lukyanovamariya_031959@postgrespro.ru", "phone": "+70936749057"}
0005434878578	2D0462	0477 584886	ELVIRA SCHERBAKOVA	{"phone": "+70102727505"}
0005434878579	12B251	9865 753378	SVETLANA PETROVA	{"email": "s.petrova.1984@postgrespro.ru", "phone": "+70712616189"}
0005434878580	AC8B6A	9820 486818	TATYANA POPOVA	{"email": "t-popova.31051966@postgrespro.ru", "phone": "+70232296328"}
0005434878581	AC8B6A	6826 202798	TATYANA POPOVA	{"email": "popova_tatyana10031967@postgrespro.ru", "phone": "+70359537666"}
0005434878582	8B1685	7034 795141	EGOR MELNIKOV	{"email": "melnikov.e.28061968@postgrespro.ru", "phone": "+70813501350"}
0005434878583	7DA07A	4164 033294	TATYANA LEBEDEVA	{"email": "tatyana_lebedeva_041983@postgrespro.ru", "phone": "+70956733682"}
0005434878584	870B32	2290 277013	TATYANA MARTYNOVA	{"phone": "+70228079999"}
0005434878585	5870F9	1722 028623	VITALIY FOMIN	{"phone": "+70812240049"}
0005434878586	945B15	3198 450454	ELENA SOROKINA	{"phone": "+70943851738"}
0005434878587	945B15	8504 299767	VALERIY SOLOVEV	{"email": "valeriysolovev04101971@postgrespro.ru", "phone": "+70075977980"}
0005434878588	79C35D	0863 861949	RUSLAN SAVELEV	{"phone": "+70273278047"}
0005434878589	E3B74B	4911 840116	SERGEY BONDARENKO	{"email": "sbondarenko_13031974@postgrespro.ru", "phone": "+70797500071"}
0005434878590	238F1A	3819 677307	EKATERINA ZHUKOVA	{"email": "zhukova.e_091976@postgrespro.ru", "phone": "+70483261216"}
0005434878591	ED730A	3497 673877	VALENTINA TARASOVA	{"email": "v-tarasova-1971@postgrespro.ru", "phone": "+70852526338"}
0005434878592	4E7B1C	2899 379160	ANATOLIY IVANOV	{"phone": "+70998819564"}
0005434878593	A8AF9A	7864 661158	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova.l-1978@postgrespro.ru", "phone": "+70559871375"}
0005434878594	60BB78	9106 120270	NIKOLAY NAZAROV	{"phone": "+70389122210"}
0005434878595	5456A0	5855 075045	ZINAIDA ANTONOVA	{"email": "antonova-zinaida.091964@postgrespro.ru", "phone": "+70750514307"}
0005434878596	4EBE41	0749 979319	KIRILL TARASOV	{"phone": "+70994774074"}
0005434878597	4EBE41	6053 541738	NADEZHDA MIRONOVA	{"phone": "+70343070541"}
0005434878598	BE566D	0019 305241	ALEKSEY MIRONOV	{"email": "aleksey_mironov021978@postgrespro.ru", "phone": "+70923476457"}
0005434878599	995481	4483 214125	NINEL EFIMOVA	{"email": "n_efimova-1974@postgrespro.ru", "phone": "+70175225203"}
0005434878600	5ECDE9	4821 472968	NATALYA NESTEROVA	{"phone": "+70677695246"}
0005434878601	20B0C7	8008 934836	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr-06011968@postgrespro.ru", "phone": "+70724586159"}
0005434878602	5A5F32	9319 538184	IRINA SCHERBAKOVA	{"email": "irinascherbakova_1960@postgrespro.ru", "phone": "+70768428543"}
0005434878603	F86EFE	7450 199262	TAMARA VLASOVA	{"email": "tamara.vlasova.1976@postgrespro.ru", "phone": "+70390048038"}
0005434878604	F86EFE	3478 078121	ANATOLIY PAVLOV	{"email": "anatoliy_pavlov-1968@postgrespro.ru", "phone": "+70753220756"}
0005434878605	4B0A1C	7693 761708	VYACHESLAV ANDREEV	{"email": "vyacheslavandreev051975@postgrespro.ru", "phone": "+70515206389"}
0005434878606	4B0A1C	5094 587705	ALEKSANDR ANDREEV	{"email": "a-andreev_08051972@postgrespro.ru", "phone": "+70412381014"}
0005434878607	4ED631	6669 488934	VALERIY IVANOV	{"email": "v-ivanov.05011975@postgrespro.ru", "phone": "+70441916746"}
0005434878608	4ED631	3502 141490	ELENA ANDREEVA	{"phone": "+70554343340"}
0005434878609	CC3923	0171 411647	LYUDMILA FEDOROVA	{"phone": "+70413541629"}
0005434878610	CC3923	7659 098504	ALESYA BOGDANOVA	{"phone": "+70148003218"}
0005434878611	7F4DF5	6517 957564	VIKTOR AFANASEV	{"phone": "+70600522899"}
0005434878612	B7E905	1896 870703	VERA EGOROVA	{"phone": "+70857194595"}
0005434878613	8E8727	3346 803510	ELENA NAUMOVA	{"phone": "+70514001699"}
0005434878614	8E8727	7919 074940	ALEKSANDR SMIRNOV	{"email": "a.smirnov_111969@postgrespro.ru", "phone": "+70800819618"}
0005434878615	433BB6	1023 601492	SAVELIY ALEKSANDROV	{"email": "aleksandrov-s.10091976@postgrespro.ru", "phone": "+70748522011"}
0005434878616	433BB6	4213 582040	TAMARA OSIPOVA	{"email": "osipova_tamara_051959@postgrespro.ru", "phone": "+70492992970"}
0005434878617	8F75D2	6619 165413	GENNADIY PAVLOV	{"email": "gennadiy_pavlov-03091980@postgrespro.ru", "phone": "+70069634973"}
0005434878618	8F75D2	9213 066817	OLGA NOVIKOVA	{"email": "novikovao_23091974@postgrespro.ru", "phone": "+70643564659"}
0005434878619	90E024	8186 020336	ANDREY VASILEV	{"email": "vasilev_andrey.15041980@postgrespro.ru", "phone": "+70356232880"}
0005434878620	B7E088	0388 537663	ANATOLIY SMIRNOV	{"email": "a-smirnov-02061975@postgrespro.ru", "phone": "+70610514944"}
0005434878621	DC27A4	4438 403412	PAVEL YAKOVLEV	{"phone": "+70611067746"}
0005434878622	4D800F	7753 355568	VIKTOR MIRONOV	{"phone": "+70675081965"}
0005434878623	51EDD4	2242 316263	ALEKSANDR DAVYDOV	{"email": "a.davydov_1963@postgrespro.ru", "phone": "+70527067328"}
0005434878624	51EDD4	7975 485016	NATALIYA STEPANOVA	{"phone": "+70630223658"}
0005434878625	A6F8D7	9081 831182	TATYANA YAKOVLEVA	{"phone": "+70167690286"}
0005434878626	D97096	4207 932779	EKATERINA STEPANOVA	{"email": "stepanova_e-08121980@postgrespro.ru", "phone": "+70641595184"}
0005434878627	D97096	4082 302237	ANATOLIY FROLOV	{"email": "a.frolov-22021970@postgrespro.ru", "phone": "+70395728977"}
0005434878628	8DE4DD	7651 119967	OLGA POLYAKOVA	{"email": "o.polyakova_1977@postgrespro.ru", "phone": "+70053095425"}
0005434878629	54C4B6	0298 888107	VADIM NAZAROV	{"phone": "+70122497348"}
0005434878630	139A5F	4796 866316	MAKSIM ISAEV	{"email": "misaev081976@postgrespro.ru", "phone": "+70104141538"}
0005434878631	0E0D20	3084 445550	SERGEY KOROLEV	{"email": "korolev-s_22021977@postgrespro.ru", "phone": "+70725687491"}
0005434878632	E243BC	6781 431041	ALEKSEY ABRAMOV	{"email": "a-abramov1976@postgrespro.ru", "phone": "+70958207437"}
0005434878633	583105	7871 246450	VIKTOR AFANASEV	{"phone": "+70932295703"}
0005434878634	35D865	6903 493371	NADEZHDA KOZLOVA	{"email": "kozlovanadezhda_25081968@postgrespro.ru", "phone": "+70711679588"}
0005434878635	571BAF	9633 031183	SOFIYA FILIPPOVA	{"email": "s-filippova.1975@postgrespro.ru", "phone": "+70818367272"}
0005434878636	571BAF	3230 786241	SERGEY ZAKHAROV	{"email": "szakharov1970@postgrespro.ru", "phone": "+70895024796"}
0005434878637	47237F	2405 822238	YULIYA KULIKOVA	{"phone": "+70851909450"}
0005434878638	F1AD1F	1532 757781	OLGA EGOROVA	{"email": "oegorova_1970@postgrespro.ru", "phone": "+70973747260"}
0005434878639	B798CA	6466 566178	ANASTASIYA GORBUNOVA	{"email": "anastasiya_gorbunova.1964@postgrespro.ru", "phone": "+70552278888"}
0005434878640	E2D08A	8314 741363	ALEKSANDR KARPOV	{"phone": "+70901103215"}
0005434878641	53A8AD	1784 175726	VIKTOR KOZLOV	{"email": "kozlov_v_26031960@postgrespro.ru", "phone": "+70758130595"}
0005434878642	4D1335	8592 714502	ILYA POPOV	{"email": "popov_ilya.041972@postgrespro.ru", "phone": "+70647306142"}
0005434878643	8BE3E5	9125 806977	ANDREY RODIONOV	{"phone": "+70623131199"}
0005434878644	FA94C1	6380 359313	VIKTORIYA PAVLOVA	{"phone": "+70827395281"}
0005434878645	FA94C1	2606 687834	ANATOLIY VOLKOV	{"email": "a-volkov.03121969@postgrespro.ru", "phone": "+70303689080"}
0005434878646	1F9E15	3949 406983	ALEKSANDR FOMIN	{"phone": "+70092553645"}
0005434878647	1F9E15	5870 802459	ELENA SOROKINA	{"phone": "+70134357207"}
0005434878648	97B06B	5283 540508	LYUDMILA SEMENOVA	{"email": "semenova_lyudmila071968@postgrespro.ru", "phone": "+70574526528"}
0005434878649	97B06B	1595 504609	PETR KUZNECOV	{"email": "kuznecov-petr_20021966@postgrespro.ru", "phone": "+70304076690"}
0005434878650	3C127F	6501 877118	VLADIMIR SAVELEV	{"email": "savelev.vladimir_1984@postgrespro.ru", "phone": "+70343518618"}
0005434878651	32589F	7330 038648	MARIYA KARPOVA	{"email": "m-karpova-22091970@postgrespro.ru", "phone": "+70737450188"}
0005434878652	ED92D6	5964 373905	IRINA KUZMINA	{"email": "irinakuzmina051966@postgrespro.ru", "phone": "+70483079945"}
0005434878653	69B776	4082 844681	DANILA BORISOV	{"email": "d.borisov-1963@postgrespro.ru", "phone": "+70118202859"}
0005434878654	69B776	9732 307809	VADIM NIKITIN	{"email": "v_nikitin_041978@postgrespro.ru", "phone": "+70157237848"}
0005434878655	6AE18F	4929 862372	EVGENIY MIKHAYLOV	{"phone": "+70644084375"}
0005434878656	91A136	7235 704243	NADEZHDA SMIRNOVA	{"email": "nadezhda.smirnova.051963@postgrespro.ru", "phone": "+70391587878"}
0005434878657	91A136	5024 923029	OLEG MAKAROV	{"email": "makarov.oleg.031964@postgrespro.ru", "phone": "+70519220795"}
0005434878658	D6FA26	1660 625850	TAMARA EFREMOVA	{"phone": "+70906775876"}
0005434878659	C11AA1	6299 174301	ALEKSANDR SERGEEV	{"email": "a_sergeev101952@postgrespro.ru", "phone": "+70201106589"}
0005434878660	C11AA1	1934 733029	IVAN FEDOROV	{"email": "fedorov-ivan021976@postgrespro.ru", "phone": "+70584449777"}
0005434878661	9A9E8A	7886 656162	VALENTINA NIKITINA	{"phone": "+70029681038"}
0005434878662	233816	4936 023133	ANDREY VLASOV	{"email": "vlasov-andrey1973@postgrespro.ru", "phone": "+70443664277"}
0005434878663	233816	5870 690532	MAKSIM PETROV	{"email": "maksim-petrov.06021975@postgrespro.ru", "phone": "+70231362357"}
0005434878664	E5BA89	2379 149025	SERGEY MAKAROV	{"phone": "+70652801562"}
0005434878665	27E172	5323 956949	ARTEM FOMIN	{"email": "fomin-artem.18121967@postgrespro.ru", "phone": "+70082171068"}
0005434878666	372419	5535 852925	FARIDA TIKHONOVA	{"email": "farida.tikhonova_121967@postgrespro.ru", "phone": "+70542538891"}
0005434878667	45FBB6	9716 814192	ANTONINA GORBUNOVA	{"email": "gorbunovaa-25121969@postgrespro.ru", "phone": "+70678848700"}
0005434878668	45FBB6	0574 610325	ANDREY EGOROV	{"email": "egorov_a-06081968@postgrespro.ru", "phone": "+70051271139"}
0005434878669	A60CAE	4544 061266	ALEKSEY STEPANOV	{"email": "stepanov.aleksey1971@postgrespro.ru", "phone": "+70616871800"}
0005434878670	C65986	3492 929353	ALEKSEY ANDREEV	{"email": "andreev-a-24041971@postgrespro.ru", "phone": "+70947596412"}
0005434878671	C65986	2848 477259	ALENA SOKOLOVA	{"email": "sokolova_a.29051976@postgrespro.ru", "phone": "+70027644090"}
0005434878672	226B27	2242 404012	OLGA DMITRIEVA	{"phone": "+70057786343"}
0005434878673	4E71F8	6572 175349	ANTONINA VOLKOVA	{"phone": "+70796451656"}
0005434878674	4E71F8	2793 149337	EVGENIY SMIRNOV	{"email": "smirnov-e061966@postgrespro.ru", "phone": "+70382924885"}
0005434878675	DFBE7C	3012 818318	KIRILL STEPANOV	{"phone": "+70647828761"}
0005434878676	DFBE7C	9712 677274	ALLA ROMANOVA	{"email": "allaromanova071972@postgrespro.ru", "phone": "+70523884837"}
0005434878677	8CF9C3	9537 906450	MIKHAIL BARANOV	{"email": "m-baranov1973@postgrespro.ru", "phone": "+70053701643"}
0005434878678	E39E30	9395 047265	ADELINA SIDOROVA	{"email": "sidorova.a1961@postgrespro.ru", "phone": "+70075394171"}
0005434878679	EE4924	6178 480915	NINA RODIONOVA	{"phone": "+70525101635"}
0005434878680	EE4924	4326 717972	IVAN IVANOV	{"email": "ivan-ivanov07091974@postgrespro.ru", "phone": "+70332869543"}
0005434878681	D0C564	4287 396611	NATALYA IVANOVA	{"phone": "+70142600266"}
0005434878682	F2FEE9	7568 373302	LYUDMILA AFANASEVA	{"phone": "+70658436027"}
0005434878683	F2FEE9	7815 139397	NIKOLAY NAUMOV	{"phone": "+70030713844"}
0005434878684	974BA9	4819 986408	SERGEY ALEKSEEV	{"phone": "+70976466001"}
0005434878685	5A1527	1876 668873	ANDREY PAVLOV	{"email": "andrey_pavlov05051967@postgrespro.ru", "phone": "+70523425060"}
0005434878686	70F7B2	6039 479918	ARTEM NIKOLAEV	{"email": "artemnikolaev26121976@postgrespro.ru", "phone": "+70938200802"}
0005434878687	678C81	3547 960338	ANDREY NAUMOV	{"phone": "+70771150970"}
0005434878688	678C81	8240 938517	EVGENIYA NIKITINA	{"email": "evgeniya-nikitina1961@postgrespro.ru", "phone": "+70110031416"}
0005434878689	838FF4	0149 074842	GALINA SOROKINA	{"phone": "+70115434607"}
0005434878690	F4EFE2	0047 802110	GERMAN PAVLOV	{"email": "german.pavlov-111971@postgrespro.ru", "phone": "+70124635216"}
0005434878691	0F565D	8221 378758	VALENTINA NESTEROVA	{"phone": "+70790658653"}
0005434878692	0F565D	8030 912609	EKATERINA GORBUNOVA	{"phone": "+70107441555"}
0005434878693	458FE0	4640 335879	GALINA ZAKHAROVA	{"email": "zakharova.galina_111976@postgrespro.ru", "phone": "+70816356554"}
0005434878694	96E371	8281 813149	ALEKSANDR BARANOV	{"email": "baranova_25041971@postgrespro.ru", "phone": "+70010881149"}
0005434878695	815AC3	4260 035178	RAISA MOISEEVA	{"email": "moiseeva_raisa_091971@postgrespro.ru", "phone": "+70837463153"}
0005434878696	95AB45	3694 947519	LYUDMILA NAZAROVA	{"email": "nazarova.lyudmila28061971@postgrespro.ru", "phone": "+70885812159"}
0005434878697	95AB45	6976 675425	NATALYA KUZNECOVA	{"email": "natalya_kuznecova.04041975@postgrespro.ru", "phone": "+70246547855"}
0005434878698	2E49D8	8740 545675	MARIYA KARPOVA	{"phone": "+70756359245"}
0005434878699	DBF242	8067 058042	NATALIYA TIMOFEEVA	{"phone": "+70364058375"}
0005434878700	DBF242	0241 263882	SERGEY VASILEV	{"phone": "+70557593187"}
0005434878701	EA07A7	7443 535441	GALIYA ZOTOVA	{"email": "gzotova26061960@postgrespro.ru", "phone": "+70667862626"}
0005434878702	ABA3B9	4601 060588	GALINA ZHURAVLEVA	{"email": "galinazhuravleva25081974@postgrespro.ru", "phone": "+70291245966"}
0005434878703	A6AD70	8983 232977	TAMARA POTAPOVA	{"email": "potapova-t1971@postgrespro.ru", "phone": "+70489458829"}
0005434878704	46BC9B	4729 317209	KONSTANTIN TIKHONOV	{"email": "tikhonov.konstantin.1970@postgrespro.ru", "phone": "+70854341346"}
0005434878705	46BC9B	7274 793795	VARVARA BELYAEVA	{"email": "belyaevav-15091968@postgrespro.ru", "phone": "+70662884025"}
0005434878706	D5D2B4	6094 908159	VALENTINA IVANOVA	{"email": "v.ivanova-1961@postgrespro.ru", "phone": "+70791379075"}
0005434878707	2FD365	5821 974664	VITALIY KUZNECOV	{"email": "kuznecov_vitaliy_031962@postgrespro.ru", "phone": "+70674859584"}
0005434878708	3C6AF4	1630 964384	VLADIMIR DAVYDOV	{"phone": "+70842208351"}
0005434878709	44EAB8	7366 637397	ALEKSEY MEDVEDEV	{"phone": "+70661777423"}
0005434878710	401669	6699 129896	YURIY ORLOV	{"email": "orlov.yuriy08121988@postgrespro.ru", "phone": "+70342152325"}
0005434878711	401669	0014 486786	ELENA ANDREEVA	{"email": "e.andreeva.10121967@postgrespro.ru", "phone": "+70493662553"}
0005434878712	12CA65	8464 462243	PAVEL VOLKOV	{"phone": "+70879596914"}
0005434878713	12CA65	8832 370718	VALERIY IVANOV	{"phone": "+70606881756"}
0005434878714	E66EF2	4209 606222	VYACHESLAV ZAYCEV	{"email": "vyacheslav.zaycev-021964@postgrespro.ru", "phone": "+70815432833"}
0005434878715	815BC5	8156 474778	OLESYA SOKOLOVA	{"phone": "+70523080520"}
0005434878716	815BC5	8200 233321	IRINA ILINA	{"phone": "+70569277272"}
0005434878717	092056	4626 498553	VLADIMIR BORISOV	{"email": "vborisov-13031985@postgrespro.ru", "phone": "+70953796238"}
0005434878718	BDB729	6868 254712	RAISA ALEKSEEVA	{"email": "r.alekseeva051974@postgrespro.ru", "phone": "+70879918072"}
0005434878719	BD74D9	4519 225715	GALINA OVCHINNIKOVA	{"email": "ovchinnikova-g_031975@postgrespro.ru", "phone": "+70765623107"}
0005434878720	BD74D9	0082 119277	ALINA SMIRNOVA	{"email": "alinasmirnova.061973@postgrespro.ru", "phone": "+70448229729"}
0005434878721	8587D0	8371 752946	ALEKSEY ANDREEV	{"phone": "+70977848206"}
0005434878722	87DC58	8067 939026	TATYANA STEPANOVA	{"email": "tstepanova_1977@postgrespro.ru", "phone": "+70184347592"}
0005434878723	C560F0	0030 379370	VASILIY VOLKOV	{"phone": "+70634320703"}
0005434878724	DD18F8	2476 855594	ANDREY RODIONOV	{"phone": "+70542965440"}
0005434878725	A083C2	9273 595871	ALEKSEY IVANOV	{"phone": "+70593549140"}
0005434878726	849CB4	0186 160531	LYUBOV ZAYCEVA	{"email": "zayceva-lyubov11101968@postgrespro.ru", "phone": "+70159870314"}
0005434878727	131431	5616 762193	YAROSLAV SIDOROV	{"email": "yaroslavsidorov.1983@postgrespro.ru", "phone": "+70059861315"}
0005434878728	131431	5103 872188	NINA NAZAROVA	{"phone": "+70856082333"}
0005434878729	1805F4	8274 934721	ANDREY KOROLEV	{"email": "akorolev.011970@postgrespro.ru", "phone": "+70154136512"}
0005434878730	1805F4	0911 322847	OKSANA POPOVA	{"phone": "+70052535756"}
0005434878731	1E2CF0	0954 753331	LILIYA YUDINA	{"email": "liliyayudina-1975@postgrespro.ru", "phone": "+70080015547"}
0005434878732	8E7FE2	7948 687111	ALEKSANDR TIKHONOV	{"email": "a.tikhonov-051966@postgrespro.ru", "phone": "+70581365767"}
0005434878733	77CB8C	5476 386252	IRINA DENISOVA	{"email": "denisova_irina.061971@postgrespro.ru", "phone": "+70297333707"}
0005434878734	726DE6	7359 301056	ALBINA SOKOLOVA	{"phone": "+70506515202"}
0005434878735	BEC72F	2447 389900	VALENTINA EGOROVA	{"email": "valentina.egorova041976@postgrespro.ru", "phone": "+70140922229"}
0005434878736	BEC72F	2741 603646	MAKSIM FROLOV	{"phone": "+70445977548"}
0005434878737	BEC72F	4276 739289	GALINA TIKHONOVA	{"email": "galina-tikhonova-111970@postgrespro.ru", "phone": "+70657269826"}
0005434878738	05CD66	1061 735612	VLADIMIR FEDOROV	{"phone": "+70027582001"}
0005434878739	05CD66	8897 701815	ROSTISLAV KOZLOV	{"phone": "+70388863929"}
0005434878740	968204	9856 274451	VALENTINA ANISIMOVA	{"email": "valentina-anisimova-06081970@postgrespro.ru", "phone": "+70709794258"}
0005434878741	F31C91	1563 975816	EKATERINA IVANOVA	{"email": "ivanova_e21061969@postgrespro.ru", "phone": "+70262317373"}
0005434878742	F31C91	9865 801801	IGOR SEMENOV	{"email": "igor.semenov.14031970@postgrespro.ru", "phone": "+70410716120"}
0005434878743	F13383	1296 599883	NADEZHDA GERASIMOVA	{"phone": "+70535588925"}
0005434878744	F13383	0425 414233	OLESYA BELOVA	{"email": "belova.o101967@postgrespro.ru", "phone": "+70589459422"}
0005434878745	F13383	9074 038415	ALEKSANDR TIKHONOV	{"phone": "+70905028231"}
0005434878746	F13383	1303 607871	IRINA KUZMINA	{"email": "i_kuzmina-1971@postgrespro.ru", "phone": "+70357033881"}
0005434878747	1CC508	9192 727479	LYUDMILA KUZNECOVA	{"email": "l-kuznecova_04051966@postgrespro.ru", "phone": "+70371778991"}
0005434878748	141F65	7213 832281	SVETLANA KOZLOVA	{"phone": "+70526650115"}
0005434878749	999DE3	9178 308369	ELENA MOROZOVA	{"phone": "+70382796138"}
0005434878750	D39D8B	3756 210554	YULIYA SIDOROVA	{"phone": "+70902266210"}
0005434878751	C907C7	5783 427720	OLEG NIKOLAEV	{"email": "oleg-nikolaev_121971@postgrespro.ru", "phone": "+70160615132"}
0005434878752	AF13F6	5377 544180	ALEKSEY OSIPOV	{"email": "aleksey_osipov_25061973@postgrespro.ru", "phone": "+70283331926"}
0005434878753	2B8584	4185 203643	VITALIY KAZAKOV	{"phone": "+70623991285"}
0005434878754	9F56E2	7022 246395	TATYANA KOMAROVA	{"email": "t_komarova-12021979@postgrespro.ru", "phone": "+70834966104"}
0005434878755	9F56E2	9381 028479	LYUBOV MATVEEVA	{"phone": "+70627082771"}
0005434878756	6009E7	0894 610582	YURIY TARASOV	{"phone": "+70369778988"}
0005434878757	6009E7	6003 303256	OLGA ZHUKOVA	{"email": "ozhukova_071985@postgrespro.ru", "phone": "+70865320608"}
0005434878758	115825	4674 599438	VLADIMIR IVANOV	{"email": "vladimirivanov_1984@postgrespro.ru", "phone": "+70213128418"}
0005434878759	6EC373	4749 139201	ALEKSANDR ISAEV	{"email": "a-isaev1971@postgrespro.ru", "phone": "+70205487645"}
0005434878760	3F7E74	4410 182358	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev.1973@postgrespro.ru", "phone": "+70719951574"}
0005434878761	14C2F7	5851 785242	NATALYA NIKIFOROVA	{"phone": "+70319841650"}
0005434878763	911915	9559 197826	ANDREY NOVIKOV	{"phone": "+70368489237"}
0005434878764	ECA0AD	7511 308184	ALEKSEY BORISOV	{"phone": "+70438285064"}
0005434878765	3CB393	1360 115784	ANDREY ISAEV	{"email": "a.isaev_051976@postgrespro.ru", "phone": "+70681454132"}
0005434878766	9D68B7	1613 401448	IVAN VASILEV	{"email": "vasilev-i03031965@postgrespro.ru", "phone": "+70751630974"}
0005434878767	94ECD8	9026 771123	NATALYA KOROLEVA	{"phone": "+70140182060"}
0005434878768	FA6942	5955 505451	GALINA NESTEROVA	{"email": "g_nesterova07061966@postgrespro.ru", "phone": "+70655397317"}
0005434878769	00E867	4337 191910	MARIYA VOLKOVA	{"phone": "+70705036592"}
0005434878770	00E867	5492 987167	SVETLANA POTAPOVA	{"email": "svetlana.potapova_1977@postgrespro.ru", "phone": "+70750880855"}
0005434878771	8030D5	2735 811070	VITALIY KUDRYASHOV	{"email": "vitaliy_kudryashov-1972@postgrespro.ru", "phone": "+70460798797"}
0005434878772	07865D	0530 714272	NATALYA KUZNECOVA	{"phone": "+70165256917"}
0005434878773	07865D	8622 108987	IDA VOLKOVA	{"email": "ida-volkova_15031974@postgrespro.ru", "phone": "+70295387044"}
0005434878774	BAA4BB	9642 674144	ALEKSEY KUZMIN	{"email": "a_kuzmin.011980@postgrespro.ru", "phone": "+70621900609"}
0005434878775	BAA4BB	5568 048990	VLADIMIR NAZAROV	{"email": "v-nazarov111971@postgrespro.ru", "phone": "+70286381019"}
0005434878776	0BE0CD	7299 297296	ANNA MASLOVA	{"email": "annamaslova.061959@postgrespro.ru", "phone": "+70334970871"}
0005434878777	0BE0CD	5369 936012	ALEKSANDR POPOV	{"email": "aleksandr_popov.101982@postgrespro.ru", "phone": "+70371744229"}
0005434878778	81B72B	3855 111851	LYUDMILA NIKOLAEVA	{"email": "nikolaeval-121954@postgrespro.ru", "phone": "+70329909811"}
0005434878779	12D166	1094 210652	GALINA MALYSHEVA	{"phone": "+70138388242"}
0005434878780	12D166	9663 740936	ILYA OSIPOV	{"phone": "+70922309235"}
0005434878781	41D80B	2656 388746	MAKSIM FROLOV	{"email": "frolov_m13111967@postgrespro.ru", "phone": "+70569055049"}
0005434878782	FB0E15	1051 586750	VLADIMIR SEMENOV	{"phone": "+70742635122"}
0005434878783	FB0E15	3786 925569	YURIY GAVRILOV	{"phone": "+70254304523"}
0005434878784	913497	9366 202312	RAVIL KARPOV	{"email": "rkarpov-13041964@postgrespro.ru", "phone": "+70470012444"}
0005434878785	913497	2337 195146	TATYANA IVANOVA	{"email": "ivanova_t051974@postgrespro.ru", "phone": "+70762432123"}
0005434878786	789C4F	2019 517896	ALEKSANDR IVANOV	{"phone": "+70719251243"}
0005434878787	98A10C	1896 589436	ARTEM POPOV	{"phone": "+70297193721"}
0005434878788	98A10C	5317 210635	ANATOLIY NOVIKOV	{"phone": "+70575630763"}
0005434878789	DB183B	0381 942857	ALEKSANDR ZHUKOV	{"phone": "+70746377110"}
0005434878790	3C5196	2722 958331	KIRILL KUZMIN	{"email": "kuzmin-kirill-20051971@postgrespro.ru", "phone": "+70243268493"}
0005434878791	3C5196	8363 935911	NIKOLAY POPOV	{"email": "popovn-1963@postgrespro.ru", "phone": "+70824175358"}
0005434878792	56AF50	3279 185869	ELENA TROFIMOVA	{"email": "etrofimova_1970@postgrespro.ru", "phone": "+70911666834"}
0005434878793	6009D4	2824 446189	GENNADIY MAKAROV	{"email": "makarov_g27011974@postgrespro.ru", "phone": "+70600456948"}
0005434878794	C99B49	0181 742704	VIOLETTA PAVLOVA	{"phone": "+70419459928"}
0005434878795	C99B49	9276 346053	ELENA BORISOVA	{"email": "eborisova_1978@postgrespro.ru", "phone": "+70486273651"}
0005434878796	3D1CE1	9820 690597	EVGENIY SERGEEV	{"email": "sergeevevgeniy_091967@postgrespro.ru", "phone": "+70743956043"}
0005434878797	876A87	4118 563201	MIKHAIL SCHERBAKOV	{"phone": "+70323694667"}
0005434878798	876A87	0037 920639	MARGARITA PAVLOVA	{"email": "m-pavlova.011961@postgrespro.ru", "phone": "+70207212796"}
0005434878799	8AFF65	1545 643473	GALINA CHERNOVA	{"email": "chernova_g_1975@postgrespro.ru", "phone": "+70943686329"}
0005434878800	8DA2BB	5034 633317	SERGEY KOZLOV	{"phone": "+70620288971"}
0005434878801	18D3D2	1363 605215	ALEKSANDR SOROKIN	{"email": "aleksandrsorokin_17091965@postgrespro.ru", "phone": "+70031489199"}
0005434878802	8C1A79	8385 066876	ARTEM MARTYNOV	{"email": "artem-martynov-09031974@postgrespro.ru", "phone": "+70280186167"}
0005434878803	8C1A79	6434 382369	IVAN PETROV	{"phone": "+70649151541"}
0005434878804	36EB51	3470 582540	ARTEM ILIN	{"phone": "+70745206203"}
0005434878805	36EB51	0057 101139	EKATERINA ANDREEVA	{"email": "andreeva-ekaterina25121973@postgrespro.ru", "phone": "+70692661137"}
0005434878806	36EB51	6709 097420	STANISLAV DENISOV	{"email": "denisov-s_1973@postgrespro.ru", "phone": "+70768217935"}
0005434878807	36EB51	6999 484564	SERGEY DENISOV	{"email": "sergeydenisov_1976@postgrespro.ru", "phone": "+70475640456"}
0005434878808	765801	9730 854209	VYACHESLAV MEDVEDEV	{"phone": "+70180640979"}
0005434878809	8BEA04	7617 761976	ALEKSEY ZAKHAROV	{"phone": "+70042854626"}
0005434878810	357B85	4941 697620	ALEKSANDR VOLKOV	{"phone": "+70371354879"}
0005434878811	357B85	6720 505250	KSENIYA ALEKSEEVA	{"phone": "+70533623597"}
0005434878812	A11F0E	0166 848937	NADEZHDA FROLOVA	{"phone": "+70084851409"}
0005434878813	8CC5B0	0755 707461	ELENA KUZNECOVA	{"phone": "+70212622415"}
0005434878814	48D50B	6798 552574	NATALYA GAVRILOVA	{"phone": "+70883142802"}
0005434878815	61107E	0949 557854	ANDREY GAVRILOV	{"phone": "+70316115311"}
0005434878816	B9D305	9665 883337	FEDOR KONOVALOV	{"phone": "+70921550759"}
0005434878817	FCEC5F	5891 472098	NADEZHDA NIKIFOROVA	{"email": "nadezhda.nikiforova_06101968@postgrespro.ru", "phone": "+70651022225"}
0005434878818	FCEC5F	7172 974282	IGOR FROLOV	{"email": "frolovigor-08031971@postgrespro.ru", "phone": "+70719822947"}
0005434878819	FCEC5F	7263 346920	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev1969@postgrespro.ru", "phone": "+70542271619"}
0005434878820	FCEC5F	6980 283691	SERGEY POPOV	{"phone": "+70857582426"}
0005434878821	9AA4D6	3612 411357	GALINA DMITRIEVA	{"phone": "+70841956556"}
0005434878822	B8B4A0	8954 675088	VALENTINA ZHUKOVA	{"email": "zhukova-valentina-121970@postgrespro.ru", "phone": "+70544459491"}
0005434878823	05C926	3333 169937	VERONIKA MEDVEDEVA	{"phone": "+70897200299"}
0005434878824	E8BE9A	5614 370896	ANTON YAKOVLEV	{"email": "yakovlev_a-04101971@postgrespro.ru", "phone": "+70287529219"}
0005434878825	69435A	0285 540936	ELENA ERMAKOVA	{"phone": "+70442606492"}
0005434878826	69435A	6210 942931	IRINA ALEKSEEVA	{"phone": "+70404479502"}
0005434878827	1360BA	5141 809455	MARIYA SOROKINA	{"phone": "+70864349985"}
0005434879364	2E3629	6720 088892	ALEKSANDR KONOVALOV	{"phone": "+70472843101"}
0005434878828	9FE304	4137 645408	MAKSIM RODIONOV	{"email": "maksim.rodionov25061968@postgrespro.ru", "phone": "+70207012597"}
0005434878829	6A2AA2	4395 158147	ANNA POPOVA	{"phone": "+70349611787"}
0005434878830	D41563	8462 341212	VALENTINA DAVYDOVA	{"email": "valentinadavydova_1985@postgrespro.ru", "phone": "+70234311152"}
0005434878831	D41563	9011 923198	ANASTASIYA CHERNOVA	{"phone": "+70433325138"}
0005434878832	1EC9C8	8094 105234	VASILIY YAKOVLEV	{"phone": "+70948129180"}
0005434878833	1EC9C8	4402 930328	KRISTINA ROMANOVA	{"phone": "+70646856657"}
0005434878834	2E5A38	9359 071324	RAFAEL NAUMOV	{"email": "rnaumov1976@postgrespro.ru", "phone": "+70219324162"}
0005434878835	2E5A38	8775 966046	IVAN ANDREEV	{"phone": "+70284258350"}
0005434878836	DF0E66	2339 351088	LYUDMILA SERGEEVA	{"phone": "+70470146890"}
0005434878837	816256	0283 357718	VLADIMIR DMITRIEV	{"email": "vladimir_dmitriev-1988@postgrespro.ru", "phone": "+70527624391"}
0005434878838	2BB4EA	2108 607670	VIKTOR BORISOV	{"phone": "+70945190149"}
0005434878839	A83CF3	9872 661376	ELENA RODIONOVA	{"email": "e-rodionova-1983@postgrespro.ru", "phone": "+70275398389"}
0005434878840	440259	7822 844205	YURIY ZAKHAROV	{"email": "yuriy.zakharov021961@postgrespro.ru", "phone": "+70321286121"}
0005434878841	803402	2520 685981	TAISIYA SOROKINA	{"phone": "+70610736501"}
0005434878842	3CAAF1	7383 519372	TATYANA KUZNECOVA	{"phone": "+70670891616"}
0005434878843	3CAAF1	6088 916394	MAKSIM ZAYCEV	{"email": "mzaycev-101966@postgrespro.ru", "phone": "+70836795536"}
0005434878844	416935	9740 877337	ANDREY VASILEV	{"email": "vasilevandrey-1972@postgrespro.ru", "phone": "+70520589230"}
0005434878845	0C7B2A	6640 583861	GRIGORIY ORLOV	{"email": "orlov-g.031976@postgrespro.ru", "phone": "+70730675953"}
0005434878846	9BE500	9190 109727	YANA VOROBEVA	{"email": "vorobeva.y1970@postgrespro.ru", "phone": "+70955221141"}
0005434878847	626022	9726 437485	EVGENIY POPOV	{"phone": "+70772695406"}
0005434878848	F47505	7539 055739	REGINA PETROVA	{"phone": "+70890646978"}
0005434878849	F47505	0644 199423	SEMEN BONDARENKO	{"email": "bondarenko_s.111980@postgrespro.ru", "phone": "+70153412276"}
0005434878850	5D4911	0026 272648	ELIZAVETA ANISIMOVA	{"phone": "+70200715538"}
0005434878851	5D4911	2505 476800	KIRA NESTEROVA	{"phone": "+70273702462"}
0005434878852	E56F58	9156 219573	ANTON ALEKSANDROV	{"email": "aleksandrov_a15061981@postgrespro.ru", "phone": "+70617351654"}
0005434878853	F0AFAF	8395 419746	SERGEY SEMENOV	{"phone": "+70307768385"}
0005434878854	F0AFAF	8076 758577	NADEZHDA MIKHAYLOVA	{"email": "nadezhda-mikhaylova_1967@postgrespro.ru", "phone": "+70684360404"}
0005434878855	12942D	9911 479187	DENIS FOMIN	{"phone": "+70701261612"}
0005434878856	12942D	6205 719197	ANDREY TIKHONOV	{"phone": "+70547499034"}
0005434878857	12942D	8336 960560	EDUARD KOROLEV	{"phone": "+70686141779"}
0005434878858	12942D	2949 435430	PAVEL PAVLOV	{"phone": "+70002717754"}
0005434878859	B52AE3	5480 558028	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov_011972@postgrespro.ru", "phone": "+70365785986"}
0005434878860	B52AE3	2770 781307	NATALYA IVANOVA	{"email": "ivanova-natalya-06061970@postgrespro.ru", "phone": "+70340794437"}
0005434878861	B52AE3	7172 711422	YULIYA ZAKHAROVA	{"phone": "+70184990392"}
0005434878862	496D14	4743 647206	LIYA STEPANOVA	{"email": "lstepanova_121983@postgrespro.ru", "phone": "+70663491811"}
0005434878863	496D14	1559 361114	MIKHAIL SOROKIN	{"email": "sorokin-mikhail-1973@postgrespro.ru", "phone": "+70098767809"}
0005434878864	D4B2AC	0184 322932	SOFIYA KISELEVA	{"email": "kiseleva-sofiya071976@postgrespro.ru", "phone": "+70625368697"}
0005434878865	30F0F2	8257 418752	NIKOLAY ZAKHAROV	{"email": "n.zakharov_16071984@postgrespro.ru", "phone": "+70879197990"}
0005434878866	30F0F2	0396 760631	TATYANA KUZMINA	{"phone": "+70669898317"}
0005434878867	84DC05	6073 191832	VALENTIN KUZNECOV	{"phone": "+70366250714"}
0005434878868	62A94F	3694 663329	GENNADIY SERGEEV	{"email": "gennadiy-sergeev_24111983@postgrespro.ru", "phone": "+70591073023"}
0005434878869	5A60CE	2329 444949	MARIYA RYABOVA	{"email": "m.ryabova_1969@postgrespro.ru", "phone": "+70752915362"}
0005434878870	41696B	6430 947914	NADEZHDA BELOVA	{"email": "belova_nadezhda081980@postgrespro.ru", "phone": "+70570385609"}
0005434878871	F5A75C	5904 081947	ILYA MAKSIMOV	{"phone": "+70849428498"}
0005434878872	749F72	9963 923186	RAISA SIDOROVA	{"email": "sidorova.raisa27081974@postgrespro.ru", "phone": "+70382182915"}
0005434878873	D3296C	3765 334161	GALINA NAZAROVA	{"email": "nazarovag_031984@postgrespro.ru", "phone": "+70399425714"}
0005434878874	5DBB89	1040 133709	YANA NESTEROVA	{"email": "nesterova.y.04041966@postgrespro.ru", "phone": "+70330967403"}
0005434878875	5DBB89	1191 665219	VYACHESLAV MATVEEV	{"phone": "+70286947093"}
0005434878876	4869BD	6455 788990	ROMAN VASILEV	{"phone": "+70677290008"}
0005434878877	441FF9	1380 926315	ALEKSANDR KONOVALOV	{"phone": "+70056006574"}
0005434878878	D41628	0280 016355	ALEKSANDR FILIPPOV	{"email": "afilippov-031974@postgrespro.ru", "phone": "+70892170747"}
0005434878879	33D368	6664 103480	OLEG SEMENOV	{"email": "olegsemenov_23061979@postgrespro.ru", "phone": "+70886796529"}
0005434878880	E95BF7	1819 683477	DANIL KOZLOV	{"email": "dkozlov.021984@postgrespro.ru", "phone": "+70353177211"}
0005434878881	D85BC4	2464 289146	VALENTIN SERGEEV	{"phone": "+70629985738"}
0005434878882	F4A913	2830 659627	ANNA POPOVA	{"phone": "+70342982302"}
0005434878883	F12B16	8880 119032	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev19091975@postgrespro.ru", "phone": "+70897151240"}
0005434878884	6C6DE0	2980 197812	MARIYA VOLKOVA	{"phone": "+70268964790"}
0005434878885	6C6DE0	3577 002263	GEORGIY NAZAROV	{"email": "nazarov_g-26091973@postgrespro.ru", "phone": "+70260708389"}
0005434878886	764B62	4470 094409	VLADIMIR MATVEEV	{"phone": "+70195411312"}
0005434878887	FF3F17	4992 582690	KLAVDIYA ZHURAVLEVA	{"email": "klavdiya_zhuravleva_1976@postgrespro.ru", "phone": "+70515730853"}
0005434878888	AFDAB9	1616 713898	NINA BOGDANOVA	{"email": "n.bogdanova1976@postgrespro.ru", "phone": "+70127908523"}
0005434878889	32516B	1310 069059	YULIYA SIDOROVA	{"email": "sidorovayuliya_1971@postgrespro.ru", "phone": "+70568838665"}
0005434878890	DE38C0	9791 577738	ARINA MARTYNOVA	{"email": "martynova_a05091977@postgrespro.ru", "phone": "+70411950272"}
0005434878891	DE38C0	8254 826728	ZINAIDA KUZNECOVA	{"email": "kuznecovazinaida-111977@postgrespro.ru", "phone": "+70697358668"}
0005434878892	6C45C8	2386 831902	ANDREY SOLOVEV	{"phone": "+70859984862"}
0005434878893	21D58B	5697 337595	TATYANA TROFIMOVA	{"phone": "+70197953495"}
0005434878894	406A8F	7485 877636	OLEG MAKAROV	{"phone": "+70506287040"}
0005434878895	13F503	7962 191402	VALERIY EGOROV	{"phone": "+70952199447"}
0005434878896	13F503	1027 989232	OLGA MATVEEVA	{"email": "omatveeva-101970@postgrespro.ru", "phone": "+70410666799"}
0005434878897	1D939E	3565 314392	PELAGEYA LUKYANOVA	{"email": "lukyanova-pelageya081963@postgrespro.ru", "phone": "+70407487793"}
0005434878898	1D939E	2155 660918	ZOYA KARPOVA	{"phone": "+70252075962"}
0005434878899	FEAEBA	4422 437638	LYUDMILA GUSEVA	{"email": "gusevalyudmila.30081969@postgrespro.ru", "phone": "+70290194531"}
0005434878900	104293	8374 412251	YURIY TIMOFEEV	{"email": "timofeev-yuriy081970@postgrespro.ru", "phone": "+70222623243"}
0005434878901	4B4D9B	5684 266630	ELENA SIDOROVA	{"email": "elena_sidorova-03101964@postgrespro.ru", "phone": "+70821760036"}
0005434878902	9AB83F	8900 833018	NADEZHDA OSIPOVA	{"phone": "+70462754639"}
0005434878903	9AB83F	1338 163304	ALEKSANDR KONOVALOV	{"email": "a_konovalov051966@postgrespro.ru", "phone": "+70613170871"}
0005434878904	7C8F87	9432 399599	GALINA ROMANOVA	{"email": "romanova_galina.20071966@postgrespro.ru", "phone": "+70190378252"}
0005434878905	796283	0759 494372	SVETLANA ANDREEVA	{"email": "s_andreeva1971@postgrespro.ru", "phone": "+70363235654"}
0005434878906	038B98	1594 689800	ANASTASIYA FILATOVA	{"phone": "+70745972259"}
0005434878907	1472C2	0274 510013	VERA STEPANOVA	{"email": "vera.stepanova081964@postgrespro.ru", "phone": "+70180508560"}
0005434878908	8B7D7D	8592 157546	NINA POTAPOVA	{"phone": "+70565826330"}
0005434878909	722DD1	5772 241140	IRINA TITOVA	{"phone": "+70760817596"}
0005434878910	6822DA	9344 895628	ALEKSANDRA KUZNECOVA	{"phone": "+70557934892"}
0005434878911	6822DA	0270 651074	TAMARA VASILEVA	{"phone": "+70901450126"}
0005434878912	6822DA	0335 809372	RAISA KOZLOVA	{"phone": "+70437753395"}
0005434878913	679E34	6810 204167	ANASTASIYA KOZLOVA	{"phone": "+70083332646"}
0005434878914	C3F6CB	8081 689157	SERGEY BORISOV	{"email": "s.borisov-121952@postgrespro.ru", "phone": "+70667816944"}
0005434878915	C3F6CB	3350 154711	PAVEL RODIONOV	{"email": "rodionov-p011961@postgrespro.ru", "phone": "+70867484586"}
0005434878916	0E1975	1075 435027	EKATERINA KAZAKOVA	{"phone": "+70002922359"}
0005434878917	0E1975	7544 185694	TATYANA MAKAROVA	{"phone": "+70430432080"}
0005434878918	0E1975	7772 647975	POLINA NIKOLAEVA	{"email": "pnikolaeva.03091955@postgrespro.ru", "phone": "+70305920328"}
0005434878919	0D0343	0843 352046	TATYANA NIKIFOROVA	{"email": "nikiforovat031972@postgrespro.ru", "phone": "+70206341448"}
0005434878920	DB8BB0	3793 898573	EKATERINA KOZLOVA	{"phone": "+70127965594"}
0005434878921	0B38D4	4433 489693	SVETLANA VOROBEVA	{"email": "vorobeva.s.041979@postgrespro.ru", "phone": "+70188784971"}
0005434878922	BE79D2	9090 116001	ALEKSEY ABRAMOV	{"phone": "+70806898753"}
0005434878923	8C3420	5680 740469	GEORGIY VLASOV	{"email": "vlasov-georgiy-041972@postgrespro.ru", "phone": "+70428681078"}
0005434878924	8C3420	9820 982760	NATALYA MAKSIMOVA	{"email": "maksimovanatalya-1974@postgrespro.ru", "phone": "+70148669323"}
0005434878925	A4E793	8017 848145	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova021979@postgrespro.ru", "phone": "+70288454867"}
0005434878926	A4E793	7543 495383	MAYYA MAKAROVA	{"email": "makarovam03111965@postgrespro.ru", "phone": "+70511797913"}
0005434878927	92C63C	2610 502256	IOSIF ANTONOV	{"phone": "+70702845850"}
0005434878928	92C63C	7134 491604	VALENTINA BARANOVA	{"email": "baranova_v-25071968@postgrespro.ru", "phone": "+70316367918"}
0005434878929	92C63C	3330 756856	ALEKSANDRA FEDOROVA	{"email": "aleksandra-fedorova07091973@postgrespro.ru", "phone": "+70476798473"}
0005434878930	5C9FAC	2304 130350	ALENA MOROZOVA	{"email": "alena_morozova-28081971@postgrespro.ru", "phone": "+70738643609"}
0005434878931	5C9FAC	7745 392761	ROMAN IVANOV	{"phone": "+70690786506"}
0005434878932	789A11	3160 717874	FANIL BARANOV	{"email": "f_baranov.021972@postgrespro.ru", "phone": "+70588672191"}
0005434878933	E0A39A	9500 352619	EVDOKIYA SCHERBAKOVA	{"phone": "+70270521784"}
0005434878934	5A19F8	1085 179112	LEONID RODIONOV	{"email": "rodionov_l1971@postgrespro.ru", "phone": "+70099368484"}
0005434878935	5A19F8	1446 126184	NADEZHDA SMIRNOVA	{"phone": "+70044691216"}
0005434878936	754420	0064 160229	MAKSIM NIKOLAEV	{"phone": "+70416913132"}
0005434878937	3DF81A	9279 483360	GENNADIY DENISOV	{"phone": "+70241963656"}
0005434878938	9BBACC	1965 894746	ALI ANDREEV	{"phone": "+70750536608"}
0005434878939	9BBACC	3331 339271	IGOR STEPANOV	{"email": "stepanov.i25091970@postgrespro.ru", "phone": "+70337318295"}
0005434878940	6590C6	1426 559930	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr121975@postgrespro.ru", "phone": "+70839795382"}
0005434878941	92A90B	6282 429821	ANDREY GORBUNOV	{"email": "a_gorbunov_1973@postgrespro.ru", "phone": "+70538926222"}
0005434878942	9822DE	8529 310243	VLADIMIR MAKSIMOV	{"email": "maksimovvladimir-041965@postgrespro.ru", "phone": "+70589335853"}
0005434878943	73EE21	8706 310125	VALENTINA MAKSIMOVA	{"phone": "+70303795170"}
0005434878944	73EE21	5122 432031	MARIYA RYABOVA	{"phone": "+70832609088"}
0005434878945	73EE21	0837 267842	DARYA NOVIKOVA	{"email": "novikova_darya.29041972@postgrespro.ru", "phone": "+70361098746"}
0005434878946	66A552	7156 886795	TAMARA MAKAROVA	{"email": "tamaramakarova-101972@postgrespro.ru", "phone": "+70623336512"}
0005434878947	EC232D	8504 744537	MARIYA MOROZOVA	{"email": "mariyamorozova-23071963@postgrespro.ru", "phone": "+70669417903"}
0005434878948	5FF178	9503 068082	ANNA ALEKSEEVA	{"email": "alekseevaa-30101965@postgrespro.ru", "phone": "+70351491277"}
0005434878949	81FDF9	8222 922742	VASILIY NAZAROV	{"email": "nazarov.vasiliy-22051971@postgrespro.ru", "phone": "+70344852927"}
0005434878950	D606CA	7186 821040	ANDREY KUZNECOV	{"phone": "+70606095709"}
0005434878951	7750E1	6556 019095	ELENA MASLOVA	{"phone": "+70422568403"}
0005434878952	B1CB47	0018 322682	ELENA VLASOVA	{"email": "e-vlasova.1967@postgrespro.ru", "phone": "+70429486897"}
0005434878953	1D7075	3472 997143	ALEKSANDR MEDVEDEV	{"phone": "+70510836255"}
0005434878954	DC8915	0925 083965	NATALYA KOLESNIKOVA	{"phone": "+70798137299"}
0005434878955	DC8915	8206 325577	VERA NOVIKOVA	{"email": "novikovav.1974@postgrespro.ru", "phone": "+70996258690"}
0005434878956	D0BAB5	8876 449828	EKATERINA BELYAEVA	{"email": "e_belyaeva04111978@postgrespro.ru", "phone": "+70289222834"}
0005434878957	D0BAB5	4252 371587	ANTON EGOROV	{"phone": "+70551599403"}
0005434878958	5AC0E0	7597 010706	RUSTAM KUZNECOV	{"phone": "+70781203168"}
0005434878959	5B89EC	2881 054640	VLADIMIR NIKOLAEV	{"email": "v.nikolaev_19091969@postgrespro.ru", "phone": "+70244406100"}
0005434878960	5E16EE	8333 716066	ALLA FROLOVA	{"email": "frolova.alla_13061968@postgrespro.ru", "phone": "+70750777566"}
0005434878961	5E16EE	6342 804468	SERGEY KUZMIN	{"email": "kuzmin_sergey_05061972@postgrespro.ru", "phone": "+70937129033"}
0005434878962	D2C2E3	9840 029923	IVAN CHERNOV	{"email": "chernov-ivan.1984@postgrespro.ru", "phone": "+70771877383"}
0005434878963	05372E	4090 227486	VLADIMIR KUZMIN	{"email": "vkuzmin_27091971@postgrespro.ru", "phone": "+70596919916"}
0005434878964	A1A7DF	9894 218815	ILYA EGOROV	{"email": "ilyaegorov1974@postgrespro.ru", "phone": "+70239723324"}
0005434878965	A1A7DF	8846 940632	ANDREY BORISOV	{"email": "borisov_andrey_071975@postgrespro.ru", "phone": "+70449764531"}
0005434878966	72679C	5598 758288	DMITRIY MAKAROV	{"email": "dmitriy_makarov_07121972@postgrespro.ru", "phone": "+70046234128"}
0005434878967	80721B	1324 392276	YULIYA BELOVA	{"email": "belova-y.021973@postgrespro.ru", "phone": "+70470891976"}
0005434878968	98DFAA	4814 965163	VALENTINA KOVALEVA	{"email": "valentina-kovaleva.03031979@postgrespro.ru", "phone": "+70192535654"}
0005434878969	98DFAA	4331 178616	DANIIL BELOV	{"email": "daniilbelov_23041984@postgrespro.ru", "phone": "+70338809412"}
0005434878970	F1880D	4485 582918	NATALYA NOVIKOVA	{"phone": "+70977138744"}
0005434878971	F1880D	5246 215793	OLGA GORBUNOVA	{"email": "gorbunova_olga1966@postgrespro.ru", "phone": "+70757640817"}
0005434878972	DDD004	7247 851231	VALENTINA ZAYCEVA	{"email": "v-zayceva.24011968@postgrespro.ru", "phone": "+70842782631"}
0005434878973	4DDC6F	7553 759279	ANDREY IVANOV	{"phone": "+70233351604"}
0005434878974	4DDC6F	8668 872973	LILIYA ORLOVA	{"email": "orlova_liliya.1980@postgrespro.ru", "phone": "+70840716146"}
0005434878975	59A539	4853 611164	TATYANA GAVRILOVA	{"email": "tatyana_gavrilova_1985@postgrespro.ru", "phone": "+70790962113"}
0005434878976	59A539	2762 932922	VLADIMIR GERASIMOV	{"phone": "+70066074423"}
0005434878977	A54B32	0774 158430	KSENIYA SIDOROVA	{"email": "k_sidorova.061961@postgrespro.ru", "phone": "+70763430711"}
0005434878978	A54B32	6731 788298	ALBINA SOROKINA	{"email": "albinasorokina-1970@postgrespro.ru", "phone": "+70016323869"}
0005434878979	012278	7707 801267	IRINA GORBUNOVA	{"phone": "+70724476160"}
0005434878980	C14740	4409 543083	MIKHAIL ALEKSANDROV	{"email": "aleksandrov-m_1972@postgrespro.ru", "phone": "+70124929669"}
0005434878981	B24692	9818 160376	MARIYA MOROZOVA	{"email": "mariya_morozova1981@postgrespro.ru", "phone": "+70990758636"}
0005434878982	30419A	1637 406742	VALERIY SMIRNOV	{"email": "v_smirnov_1963@postgrespro.ru", "phone": "+70965027032"}
0005434878983	E2188A	3129 936419	NINA TIMOFEEVA	{"phone": "+70174468910"}
0005434878984	E2188A	3243 942529	ELENA KUZNECOVA	{"phone": "+70277669230"}
0005434878985	4B8873	7533 723098	OLGA EGOROVA	{"phone": "+70574800622"}
0005434878986	26059D	3628 063692	VALERIY POPOV	{"phone": "+70755474818"}
0005434878987	8891F3	9104 900618	DENIS SHEVCHENKO	{"email": "d_shevchenko-101968@postgrespro.ru", "phone": "+70575275029"}
0005434878988	82DDDE	5351 115728	ZINAIDA FADEEVA	{"email": "zfadeeva031981@postgrespro.ru", "phone": "+70514263399"}
0005434878989	06C56C	8166 245106	NINA VLASOVA	{"email": "n_vlasova-051974@postgrespro.ru", "phone": "+70330267532"}
0005434878990	06C56C	8601 651613	MARINA KRASNOVA	{"phone": "+70118537065"}
0005434878991	953E50	9502 957069	ALEKSANDR POPOV	{"phone": "+70768218281"}
0005434878992	330F89	4250 881475	ZHANNA BELOVA	{"phone": "+70223425950"}
0005434878993	FE870E	3268 771153	KLAVDIYA OSIPOVA	{"email": "osipova-klavdiya22101975@postgrespro.ru", "phone": "+70912446052"}
0005434878994	3E6EE8	1469 814916	OLGA PAVLOVA	{"phone": "+70511055498"}
0005434878995	7BD112	0598 186912	VALENTIN KUZNECOV	{"phone": "+70702048789"}
0005434878996	344CE8	2946 472928	SERGEY MAKAROV	{"phone": "+70471561003"}
0005434878997	C3CC00	3606 188686	TATYANA SCHERBAKOVA	{"email": "scherbakovatatyana-1959@postgrespro.ru", "phone": "+70044757709"}
0005434878998	C3CC00	0207 096868	LIDIYA POPOVA	{"email": "popova.lidiya.27121973@postgrespro.ru", "phone": "+70518476919"}
0005434878999	C3CC00	3365 048260	MARINA PAVLOVA	{"email": "m_pavlova-111978@postgrespro.ru", "phone": "+70683800865"}
0005434879000	DC52ED	3765 276057	MARIYA NAZAROVA	{"phone": "+70251277608"}
0005434879180	349692	8955 494265	ANTON KUZNECOV	{"phone": "+70931760908"}
0005434879001	DC52ED	2512 271643	ALEKSANDR TIKHONOV	{"email": "aleksandr.tikhonov-01101970@postgrespro.ru", "phone": "+70830995667"}
0005434879002	EC79E3	2493 507063	SERGEY TIMOFEEV	{"email": "sergey.timofeev.18011975@postgrespro.ru", "phone": "+70172504088"}
0005434879003	08A98A	2860 806031	AIDA MARTYNOVA	{"email": "martynova-a.1967@postgrespro.ru", "phone": "+70558458344"}
0005434879004	06B8B7	0071 727153	IRINA SMIRNOVA	{"email": "i_smirnova.1969@postgrespro.ru", "phone": "+70478367874"}
0005434879005	06B8B7	9168 371463	MAKSIM KARPOV	{"phone": "+70089037367"}
0005434879006	06B8B7	8575 322909	ALEKSANDR SAVELEV	{"phone": "+70564372700"}
0005434879007	14655E	0490 807678	RAVIL SAVELEV	{"email": "ravilsavelev_071969@postgrespro.ru", "phone": "+70141444364"}
0005434879008	42B5D5	2462 896311	DARYA KUDRYASHOVA	{"email": "kudryashovadarya.1978@postgrespro.ru", "phone": "+70258794636"}
0005434879009	F8C8BE	1762 360604	OLGA KALININA	{"email": "kalinina_olga-061980@postgrespro.ru", "phone": "+70310162891"}
0005434879010	B54F57	7762 140528	YURIY PETROV	{"email": "ypetrov1980@postgrespro.ru", "phone": "+70897448569"}
0005434879011	34661B	0731 082951	IOSIF SCHERBAKOV	{"email": "scherbakov_iosif1973@postgrespro.ru", "phone": "+70903161207"}
0005434879012	34661B	9810 969927	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva_l.1980@postgrespro.ru", "phone": "+70194617413"}
0005434879013	E5990B	9355 900185	ALEKSANDR FEDOROV	{"email": "fedorov.a.031976@postgrespro.ru", "phone": "+70828474930"}
0005434879014	3CD8E8	6006 192380	IVAN SHEVCHENKO	{"email": "ivan_shevchenko1974@postgrespro.ru", "phone": "+70216208968"}
0005434879015	7F821E	2413 710379	LYUDMILA GUSEVA	{"phone": "+70773902901"}
0005434879016	7F821E	6568 287951	IRINA FADEEVA	{"email": "fadeeva_irina-04101967@postgrespro.ru", "phone": "+70317809109"}
0005434879017	6672AC	4397 202065	DMITRIY IVANOV	{"phone": "+70044240652"}
0005434879018	82FA5F	8974 095432	NIKOLAY GAVRILOV	{"email": "gavrilov_n071968@postgrespro.ru", "phone": "+70007558783"}
0005434879019	1954E8	7663 530279	EVGENIY VLASOV	{"phone": "+70540538500"}
0005434879020	9B023B	9766 979308	SERGEY IVANOV	{"email": "s-ivanov-071970@postgrespro.ru", "phone": "+70221255189"}
0005434879021	CDB574	2049 390869	NATALYA MAKSIMOVA	{"phone": "+70868618957"}
0005434879022	FB1E0C	0431 511298	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova_lyudmila-1968@postgrespro.ru", "phone": "+70541283595"}
0005434879023	FB1E0C	7837 073864	NATALYA DAVYDOVA	{"email": "davydova-natalya_27031975@postgrespro.ru", "phone": "+70750440654"}
0005434879024	70C0A8	5239 893884	ALEKSANDR DMITRIEV	{"phone": "+70854860610"}
0005434879025	01AA97	3694 627623	PELAGEYA ZAYCEVA	{"phone": "+70144299084"}
0005434879026	2F31DF	0610 520516	ALEKSANDRA FEDOROVA	{"phone": "+70199796665"}
0005434879027	2F31DF	9513 081049	PAVEL SCHERBAKOV	{"phone": "+70088030647"}
0005434879028	F6DDFF	0427 228578	YURIY ANTONOV	{"phone": "+70048409672"}
0005434879029	F6DDFF	2050 155959	LEONID KUZMIN	{"email": "leonidkuzmin.1968@postgrespro.ru", "phone": "+70491489169"}
0005434879030	99F5EE	7024 096507	VLADIMIR DENISOV	{"phone": "+70486790668"}
0005434879031	99F5EE	2660 851349	SERGEY SEMENOV	{"email": "sergey.semenov_1982@postgrespro.ru", "phone": "+70705406134"}
0005434879032	8B6C0B	4159 782621	ANZHELIKA POPOVA	{"email": "apopova-1962@postgrespro.ru", "phone": "+70104814170"}
0005434879033	B28130	4141 202985	ANGELINA VASILEVA	{"email": "vasilevaangelina_061974@postgrespro.ru", "phone": "+70937787886"}
0005434879034	0C25C7	4721 160601	FARIT IVANOV	{"email": "f-ivanov08061976@postgrespro.ru", "phone": "+70741230408"}
0005434879035	8DC0BD	2745 628788	TATYANA ANTONOVA	{"email": "tatyana.antonova.1978@postgrespro.ru", "phone": "+70218711863"}
0005434879036	49AD5B	2185 176183	ELMIRA MASLOVA	{"email": "maslova.e031967@postgrespro.ru", "phone": "+70275123709"}
0005434879037	49AD5B	3573 638774	ANASTASIYA SERGEEVA	{"email": "anastasiyasergeeva-111968@postgrespro.ru", "phone": "+70221883219"}
0005434879038	8F0D1B	3383 375970	ELENA ILINA	{"phone": "+70360645073"}
0005434879039	8F0D1B	4512 092299	VALENTIN MAKAROV	{"phone": "+70778808130"}
0005434879040	DA89BA	7180 106458	NINA KUZNECOVA	{"email": "n-kuznecova.09021971@postgrespro.ru", "phone": "+70763238587"}
0005434879041	ABD152	7084 376976	EKATERINA SIDOROVA	{"phone": "+70640610412"}
0005434879042	716D2A	5585 801149	SANIYA RODIONOVA	{"email": "rodionova_saniya-01061988@postgrespro.ru", "phone": "+70331365282"}
0005434879043	716D2A	8550 997768	POLINA NIKITINA	{"email": "nikitina.polina.13121979@postgrespro.ru", "phone": "+70543129556"}
0005434879044	7C82CA	8568 974285	ZOYA KUZMINA	{"phone": "+70414363781"}
0005434879045	E964FA	5718 632899	ANATOLIY VOLKOV	{"phone": "+70478086515"}
0005434879046	8B9E73	6304 832623	TAISIYA YAKOVLEVA	{"email": "yakovlevataisiya-29021968@postgrespro.ru", "phone": "+70819673367"}
0005434879047	48E119	1601 704443	VLADIMIR MIKHAYLOV	{"email": "v.mikhaylov23071973@postgrespro.ru", "phone": "+70075569355"}
0005434879048	EFFEEE	9800 713622	SERGEY BORISOV	{"email": "borisov-sergey-061964@postgrespro.ru", "phone": "+70718476341"}
0005434879049	8BA556	7048 100380	TATYANA TROFIMOVA	{"email": "trofimova_t.1980@postgrespro.ru", "phone": "+70591489503"}
0005434879050	08C859	9547 382680	VLADIMIR VOROBEV	{"email": "v.vorobev02121972@postgrespro.ru", "phone": "+70417333319"}
0005434879051	08C859	1489 877846	YANINA IVANOVA	{"email": "ivanova.y-081978@postgrespro.ru", "phone": "+70175930989"}
0005434879052	8F067E	3614 843764	SERGEY FROLOV	{"email": "frolov_s011974@postgrespro.ru", "phone": "+70882790235"}
0005434879053	6BE56C	3641 700824	ALEKSANDR SEMENOV	{"phone": "+70551656194"}
0005434879054	6BE56C	7982 688581	GALINA POPOVA	{"email": "popova-g.1975@postgrespro.ru", "phone": "+70062765767"}
0005434879055	5EA233	8739 285036	KLAVDIYA TARASOVA	{"email": "ktarasova-12061970@postgrespro.ru", "phone": "+70582932122"}
0005434879056	E7E03D	3637 677474	VLADIMIR GORBUNOV	{"phone": "+70629179626"}
0005434879057	EF4E0A	9638 973599	EVGENIY DAVYDOV	{"email": "davydovevgeniy_1969@postgrespro.ru", "phone": "+70680646878"}
0005434879058	51ABE4	5661 063831	ANATOLIY GERASIMOV	{"email": "gerasimov_anatoliy-1964@postgrespro.ru", "phone": "+70383034736"}
0005434879059	51ABE4	2933 284464	OLGA GAVRILOVA	{"phone": "+70347886633"}
0005434879060	D1C05D	4983 558246	VLADIMIR ROMANOV	{"email": "romanov.vladimir-1978@postgrespro.ru", "phone": "+70793942543"}
0005434879061	95AF0F	6617 926035	IVAN FEDOTOV	{"phone": "+70648569931"}
0005434879062	99BE9F	6395 293355	VIKTOR PETROV	{"email": "petrovv071974@postgrespro.ru", "phone": "+70714872649"}
0005434879063	DE85E7	3613 479777	SVETLANA KUZMINA	{"phone": "+70627174254"}
0005434879064	D29FFB	1400 513993	LYUDMILA FEDOROVA	{"phone": "+70631156136"}
0005434879065	F48941	0010 404182	ELENA MARTYNOVA	{"phone": "+70917587156"}
0005434879066	791E6F	5761 423796	MARGARITA PAVLOVA	{"phone": "+70067316343"}
0005434879067	3B3B20	4653 212574	GULIYA KUZNECOVA	{"phone": "+70381450231"}
0005434879068	3B3B20	6483 993072	SERGEY VOROBEV	{"phone": "+70448074479"}
0005434879069	55ECFC	8253 757267	NIKOLAY OSIPOV	{"phone": "+70542467919"}
0005434879070	B82AFD	2802 934634	SERGEY VLASOV	{"email": "s-vlasov17121970@postgrespro.ru", "phone": "+70461929373"}
0005434879071	1ACB89	5158 686993	GALINA NESTEROVA	{"email": "g-nesterova.25051963@postgrespro.ru", "phone": "+70874424047"}
0005434879072	53EA20	4837 684715	DARYA SIDOROVA	{"phone": "+70275358501"}
0005434879073	0167EF	0353 687691	ANASTASIYA TIKHONOVA	{"phone": "+70515646962"}
0005434879074	D95D5A	8638 347429	MARIYA POLYAKOVA	{"email": "polyakova_mariya.011972@postgrespro.ru", "phone": "+70359506408"}
0005434879075	66358A	6160 174873	GALINA LAZAREVA	{"phone": "+70846626482"}
0005434879076	66358A	1248 698055	SOFIYA BELOVA	{"email": "s_belova-29041972@postgrespro.ru", "phone": "+70571865709"}
0005434879077	C6DB44	9472 636516	GRIGORIY ILIN	{"phone": "+70443417228"}
0005434879078	C6DB44	3298 423525	IRINA ISAEVA	{"phone": "+70052944755"}
0005434879079	7EA35F	2605 978351	ALEKSANDR MOROZOV	{"phone": "+70080641280"}
0005434879080	FCE028	7616 101725	ALEKSANDR ANTONOV	{"phone": "+70153432444"}
0005434879081	8E6473	7888 032511	EKATERINA KOROLEVA	{"email": "koroleva_ekaterina09041976@postgrespro.ru", "phone": "+70678357058"}
0005434879082	8E6473	6142 398455	ANATOLIY VOLKOV	{"phone": "+70972370230"}
0005434879083	8E6473	4264 586299	TATYANA POTAPOVA	{"phone": "+70201696194"}
0005434879084	D4CFB2	8704 898974	ANDREY MAKSIMOV	{"email": "andrey.maksimov-051979@postgrespro.ru", "phone": "+70213701738"}
0005434879085	222490	7112 177552	TATYANA SIDOROVA	{"phone": "+70688927707"}
0005434879086	222490	2309 186379	DENIS IVANOV	{"email": "ivanov-denis03031987@postgrespro.ru", "phone": "+70670407545"}
0005434879087	036992	2560 296043	MIKHAIL RODIONOV	{"email": "m.rodionov-111975@postgrespro.ru", "phone": "+70007777484"}
0005434879088	036992	6305 739942	MIKHAIL MIKHAYLOV	{"phone": "+70501106401"}
0005434879089	0E4905	5908 937709	ARTEM BORISOV	{"email": "a_borisov.121974@postgrespro.ru", "phone": "+70990935529"}
0005434879090	0E4905	4301 619962	SERGEY ISAEV	{"email": "s_isaev121969@postgrespro.ru", "phone": "+70920889845"}
0005434879091	62D884	0845 943208	VERA AFANASEVA	{"email": "v.afanaseva_1970@postgrespro.ru", "phone": "+70723455807"}
0005434879092	08765E	7677 442142	OLGA NAUMOVA	{"email": "onaumova-1961@postgrespro.ru", "phone": "+70102533292"}
0005434879093	E03146	0839 487343	VALENTINA LUKYANOVA	{"email": "v.lukyanova-1963@postgrespro.ru", "phone": "+70498164317"}
0005434879094	E03146	3716 293271	LYUBOV POLYAKOVA	{"email": "l_polyakova_11011975@postgrespro.ru", "phone": "+70524674622"}
0005434879095	3D56E6	6976 236753	NATALYA MAKAROVA	{"email": "natalya-makarova-1974@postgrespro.ru", "phone": "+70152670096"}
0005434879096	2C3DEB	1912 060573	SERGEY VOLKOV	{"email": "volkov_s091973@postgrespro.ru", "phone": "+70683756258"}
0005434879097	49A6D0	5406 250129	ALEKSANDR GUSEV	{"phone": "+70551023796"}
0005434879098	23EA95	5187 824572	DMITRIY MEDVEDEV	{"phone": "+70250842051"}
0005434879099	23EA95	4133 873377	ALEKSANDR ALEKSEEV	{"email": "alekseev.aleksandr-1970@postgrespro.ru", "phone": "+70353190465"}
0005434879100	6F676E	6357 624814	IRINA KONDRATEVA	{"phone": "+70476258385"}
0005434879101	0EF323	8198 791945	NIKOLAY TARASOV	{"phone": "+70219642680"}
0005434879102	0B3A35	5614 724706	NATALYA TITOVA	{"phone": "+70516825289"}
0005434879103	2952E4	3065 259780	TIGRAN SMIRNOV	{"email": "smirnov-t1977@postgrespro.ru", "phone": "+70624776548"}
0005434879104	677777	3222 256570	GLEB EGOROV	{"phone": "+70570604725"}
0005434879105	6931C4	3515 763884	DIANA FROLOVA	{"email": "d.frolova.1967@postgrespro.ru", "phone": "+70287608055"}
0005434879106	E81C3A	3649 002835	DENIS ZAKHAROV	{"email": "zakharovdenis1968@postgrespro.ru", "phone": "+70191527796"}
0005434879107	390705	3787 040072	ANTON FEDOROV	{"email": "a.fedorov-041962@postgrespro.ru", "phone": "+70684455012"}
0005434879108	390705	7088 702430	IRINA KOVALEVA	{"phone": "+70448245361"}
0005434879109	B1934E	1860 849873	VIKTOR ANDREEV	{"phone": "+70471918235"}
0005434879110	F013D6	8393 593424	YURIY IVANOV	{"email": "ivanov_yuriy20091972@postgrespro.ru", "phone": "+70126593094"}
0005434879111	5FF301	9137 533593	LYUDMILA ABRAMOVA	{"phone": "+70681043562"}
0005434879112	5FF301	1505 914685	SERGEY VASILEV	{"phone": "+70032357398"}
0005434879113	D15AA2	5184 679349	TATYANA FEDOROVA	{"phone": "+70959210160"}
0005434879114	254005	6379 806547	ALEVTINA ZOTOVA	{"email": "zotova_alevtina_081980@postgrespro.ru", "phone": "+70199817328"}
0005434879115	47286F	7794 226486	IVAN EGOROV	{"email": "egorovi101978@postgrespro.ru", "phone": "+70597851752"}
0005434879116	9A1D80	5913 970218	ALISA ALEKSEEVA	{"email": "alekseeva-alisa1979@postgrespro.ru", "phone": "+70332486419"}
0005434879117	9F94FD	6698 363183	EVGENIY NAZAROV	{"email": "evgeniy_nazarov-10111968@postgrespro.ru", "phone": "+70613314933"}
0005434879118	9F94FD	7488 094726	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov051979@postgrespro.ru", "phone": "+70035804855"}
0005434879119	044FB3	1136 018461	VLADIMIR KOZLOV	{"email": "v_kozlov-091974@postgrespro.ru", "phone": "+70343815584"}
0005434879120	044FB3	9327 625546	RIMMA KOROLEVA	{"email": "rimma-koroleva.01071966@postgrespro.ru", "phone": "+70871022202"}
0005434879121	876EF5	3224 585062	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-01101970@postgrespro.ru", "phone": "+70472614693"}
0005434879122	876EF5	0344 362165	NINA POPOVA	{"phone": "+70423396701"}
0005434879123	76F17D	5726 366110	ANNA ANISIMOVA	{"email": "anisimova-a-09071974@postgrespro.ru", "phone": "+70104746170"}
0005434879124	CEDF6E	1091 526604	OLEG SMIRNOV	{"phone": "+70182638443"}
0005434879125	78BE2F	8561 905946	ANDREY NAZAROV	{"phone": "+70719286339"}
0005434879126	34295A	0227 598218	EVGENIY DAVYDOV	{"phone": "+70736875742"}
0005434879127	2F6330	6556 967054	MARGARITA GUSEVA	{"phone": "+70852928066"}
0005434879128	9BB471	1037 403322	VALENTINA LAZAREVA	{"phone": "+70946117115"}
0005434879129	E5CD84	6726 362346	EKATERINA OVCHINNIKOVA	{"email": "ovchinnikova-ekaterina-1975@postgrespro.ru", "phone": "+70785138262"}
0005434879130	3A2F60	2178 816261	OLESYA MOROZOVA	{"email": "morozova.o-28061963@postgrespro.ru", "phone": "+70804250361"}
0005434879131	672204	6388 247835	MIKHAIL ZHURAVLEV	{"email": "zhuravlev.m_1987@postgrespro.ru", "phone": "+70572467110"}
0005434879132	69FA9F	3693 837333	ALEKSANDR KUZNECOV	{"phone": "+70617179203"}
0005434879133	9B0EE1	4064 952719	MARINA VOLKOVA	{"phone": "+70457035815"}
0005434879134	9B0EE1	7564 169280	ELIZAVETA VOLKOVA	{"email": "volkova.elizaveta021969@postgrespro.ru", "phone": "+70017047215"}
0005434879135	687449	9807 635801	ELIZAVETA ISAEVA	{"phone": "+70226268624"}
0005434879136	687449	0421 639741	LYUDMILA FOMINA	{"email": "lyudmila.fomina.041978@postgrespro.ru", "phone": "+70885746493"}
0005434879137	687449	6897 275441	MIKHAIL NIKOLAEV	{"email": "m.nikolaev_1971@postgrespro.ru", "phone": "+70813260968"}
0005434879138	B2B220	2219 687364	NATALYA MIKHAYLOVA	{"email": "mikhaylova-natalya.09041971@postgrespro.ru", "phone": "+70646983860"}
0005434879139	C41365	2889 139083	ALEKSEY IVANOV	{"phone": "+70445212364"}
0005434879140	C41365	1458 749931	ELENA RYABOVA	{"phone": "+70446255072"}
0005434879141	D6DBE6	0528 316571	MADINA FADEEVA	{"phone": "+70479808033"}
0005434879142	C20804	6282 180292	EDUARD ZHUKOV	{"email": "ezhukov29011984@postgrespro.ru", "phone": "+70895212748"}
0005434879143	C20804	3136 093331	ALEKSANDR POPOV	{"email": "popovaleksandr.23111980@postgrespro.ru", "phone": "+70957588345"}
0005434879144	283D9F	4196 026677	SOFYA PETROVA	{"email": "petrova_sofya-1970@postgrespro.ru", "phone": "+70399826184"}
0005434879145	A44678	5830 164746	VASILIY SOKOLOV	{"phone": "+70395787103"}
0005434879146	0C53A9	7302 155986	DARYA ABRAMOVA	{"phone": "+70171487526"}
0005434879147	DD716E	4736 161168	NIKITA NAZAROV	{"email": "nikita_nazarov.1971@postgrespro.ru", "phone": "+70493865835"}
0005434879148	DD716E	5237 374841	VASILIY TIKHONOV	{"email": "v_tikhonov-1964@postgrespro.ru", "phone": "+70226073791"}
0005434879149	FEB18D	9334 040998	SVETLANA POPOVA	{"phone": "+70244228147"}
0005434879150	F784E3	8425 525605	VIKTOR ROMANOV	{"email": "romanov-v081980@postgrespro.ru", "phone": "+70547488935"}
0005434879151	063A6E	0367 900531	NATALYA IVANOVA	{"email": "ivanova-n-081967@postgrespro.ru", "phone": "+70477038591"}
0005434879152	063A6E	5883 852271	IVAN MAKAROV	{"phone": "+70720548839"}
0005434879153	E05A28	9914 700378	MARINA TARASOVA	{"email": "m-tarasova-111969@postgrespro.ru", "phone": "+70993274785"}
0005434879154	E05A28	9387 362547	KONSTANTIN KISELEV	{"phone": "+70300128790"}
0005434879155	5B46BA	9304 192321	ALEKSEY MELNIKOV	{"phone": "+70962966742"}
0005434879156	5B46BA	7255 946406	MIKHAIL PETROV	{"phone": "+70323258161"}
0005434879157	7AD0CE	5630 507012	ALLA SIDOROVA	{"phone": "+70564038289"}
0005434879158	4B329B	3077 558901	VALENTINA KOMAROVA	{"email": "komarova_v.1978@postgrespro.ru", "phone": "+70627166843"}
0005434879159	4B329B	8009 424148	ANDREY GRIGOREV	{"phone": "+70021175112"}
0005434879160	D28B74	9721 311930	DMITRIY TIKHONOV	{"phone": "+70596170352"}
0005434879161	51DC8B	3058 964914	EVGENIY KULIKOV	{"email": "kulikove06061965@postgrespro.ru", "phone": "+70759676408"}
0005434879162	F4882D	5534 921377	EKATERINA KUZNECOVA	{"phone": "+70573335961"}
0005434879163	00DB59	7090 924757	NINA KUZNECOVA	{"email": "n-kuznecova.1967@postgrespro.ru", "phone": "+70957804945"}
0005434879164	6CDB96	7851 685144	LIYA ORLOVA	{"phone": "+70733974059"}
0005434879165	E5E70B	7500 460556	NATALYA VLASOVA	{"phone": "+70502146370"}
0005434879166	7C2CE0	6409 009350	GALINA ZAKHAROVA	{"phone": "+70747217094"}
0005434879167	C36A08	5302 151856	IVAN VASILEV	{"phone": "+70172105365"}
0005434879168	9C9391	0528 415305	KSENIYA ZAKHAROVA	{"email": "kseniya_zakharova.1968@postgrespro.ru", "phone": "+70666822424"}
0005434879169	68F869	1878 833050	NATALYA EFIMOVA	{"phone": "+70059259476"}
0005434879170	68F869	2099 268024	ANDREY KOROLEV	{"email": "andrey-korolev-1971@postgrespro.ru", "phone": "+70893318793"}
0005434879171	9ED517	7177 141711	IRINA MIKHAYLOVA	{"phone": "+70858032057"}
0005434879172	A8AC5C	0382 439280	ALEKSANDR FEDOTOV	{"phone": "+70870188026"}
0005434879173	A8AC5C	5317 615522	IVAN NIKITIN	{"email": "ivan_nikitin_31101972@postgrespro.ru", "phone": "+70424582199"}
0005434879174	589778	3689 526945	DARYA BOGDANOVA	{"phone": "+70000475017"}
0005434879175	589778	1740 547877	NADEZHDA ZAKHAROVA	{"phone": "+70636356227"}
0005434879176	1FFF09	3592 134781	MATVEY FOMIN	{"email": "fomin_m08101968@postgrespro.ru", "phone": "+70539480024"}
0005434879177	1FFF09	7666 311329	NATALYA ABRAMOVA	{"email": "abramova-natalya.1971@postgrespro.ru", "phone": "+70468621602"}
0005434879178	2302E5	9629 105917	DMITRIY MARTYNOV	{"phone": "+70741397136"}
0005434879179	738787	9956 409755	VLADISLAV SCHERBAKOV	{"email": "vladislav.scherbakov.051979@postgrespro.ru", "phone": "+70349480227"}
0005434879181	90BC41	8439 002789	SERGEY TIKHONOV	{"phone": "+70193159942"}
0005434879182	3CCF2F	6364 813602	ELENA ANDREEVA	{"email": "elena.andreeva12041968@postgrespro.ru", "phone": "+70192282386"}
0005434879183	B751A6	1666 963450	IRINA POPOVA	{"phone": "+70045671731"}
0005434879184	9269D3	5082 679693	MAKSIM KOROLEV	{"email": "korolev_m_111966@postgrespro.ru", "phone": "+70242633426"}
0005434879185	BB8CFC	6596 973919	EVGENIY GRIGOREV	{"phone": "+70702933324"}
0005434879186	60F3D0	1387 714400	VLADIMIR IVANOV	{"email": "v_ivanov.09101977@postgrespro.ru", "phone": "+70952655974"}
0005434879187	60F3D0	7055 815003	MIKHAIL IVANOV	{"email": "m-ivanov09011973@postgrespro.ru", "phone": "+70191591016"}
0005434879188	D5938D	1963 636638	MIKHAIL KUZNECOV	{"email": "kuznecov_m_1970@postgrespro.ru", "phone": "+70494096319"}
0005434879189	D5938D	3605 495872	VITALIY GERASIMOV	{"phone": "+70794304437"}
0005434879190	D5938D	4229 132227	ALEKSANDRA IVANOVA	{"phone": "+70207793083"}
0005434879191	A8A660	8537 588644	ALEKSANDR MEDVEDEV	{"email": "a.medvedev-14011981@postgrespro.ru", "phone": "+70840391878"}
0005434879192	06CA38	2613 140854	NIKOLAY AFANASEV	{"phone": "+70114358553"}
0005434879193	643596	8031 670145	IRINA OSIPOVA	{"email": "i.osipova.041971@postgrespro.ru", "phone": "+70754879796"}
0005434879194	643596	4011 390237	ARTEM GRIGOREV	{"phone": "+70706586357"}
0005434879195	14FAE0	9914 941578	SERGEY STEPANOV	{"email": "sergey-stepanov_1981@postgrespro.ru", "phone": "+70461196920"}
0005434879196	CF3E7E	4408 502700	ILYA FEDOTOV	{"phone": "+70994352233"}
0005434879197	A14F67	1029 419168	ALBINA SOROKINA	{"email": "asorokina-09021975@postgrespro.ru", "phone": "+70656960571"}
0005434879198	A14F67	6990 775562	VLADIMIR CHERNOV	{"email": "chernov-vladimir_1977@postgrespro.ru", "phone": "+70884488160"}
0005434879199	B79020	6002 173941	ANGELINA PETROVA	{"email": "angelina.petrova-03051969@postgrespro.ru", "phone": "+70077331144"}
0005434879200	B79020	8118 270364	STEPAN SOLOVEV	{"email": "solovev-s081972@postgrespro.ru", "phone": "+70197811248"}
0005434879201	BEE8CD	8699 719396	VALENTINA KOMAROVA	{"email": "komarova-v_031966@postgrespro.ru", "phone": "+70354002124"}
0005434879202	02F5F4	4536 862097	YURIY MIRONOV	{"phone": "+70844214456"}
0005434879203	66DD7B	9937 579777	VALENTINA FEDOROVA	{"email": "fedorova-v-13111977@postgrespro.ru", "phone": "+70177742768"}
0005434879204	71BECD	3378 087151	TATYANA MIRONOVA	{"phone": "+70663358585"}
0005434879205	71BECD	3456 895896	PETR MATVEEV	{"email": "petr-matveev.1966@postgrespro.ru", "phone": "+70449380101"}
0005434879206	C14E30	9539 508965	GALINA VASILEVA	{"phone": "+70719784588"}
0005434879207	C14E30	6547 971392	ANASTASIYA ANDREEVA	{"email": "andreeva_anastasiya-19111977@postgrespro.ru", "phone": "+70277633581"}
0005434879208	C14E30	1114 374626	NIKOLAY POPOV	{"phone": "+70997954869"}
0005434879209	7CE38D	9149 926932	ELENA SOKOLOVA	{"phone": "+70591748539"}
0005434879210	60765E	6153 830251	MARINA BOGDANOVA	{"phone": "+70100587710"}
0005434879211	FF3FC0	6911 365874	VALENTINA PETROVA	{"email": "petrova.v-1967@postgrespro.ru", "phone": "+70257425153"}
0005434879212	D8396A	7316 431029	ALIYA KULIKOVA	{"phone": "+70263994596"}
0005434879213	36B2B2	9763 477389	LARISA KARPOVA	{"phone": "+70585786458"}
0005434879214	6375EF	8378 819219	OLGA ORLOVA	{"phone": "+70540472363"}
0005434879215	89E324	7262 216651	TATYANA ORLOVA	{"email": "orlova.t-22051972@postgrespro.ru", "phone": "+70717255820"}
0005434879216	E85CC9	5285 073808	ANTON KUZMIN	{"email": "antonkuzmin27071977@postgrespro.ru", "phone": "+70773612598"}
0005434879217	E85CC9	7478 940324	VYACHESLAV FEDOTOV	{"email": "vyacheslav_fedotov10121965@postgrespro.ru", "phone": "+70210209217"}
0005434879218	754010	8672 905388	EVGENIY SOROKIN	{"phone": "+70373069985"}
0005434879219	4FB0FE	9468 095590	EKATERINA POPOVA	{"email": "popovaekaterina1968@postgrespro.ru", "phone": "+70174887873"}
0005434879220	4FB0FE	2915 844736	NIKOLAY SEMENOV	{"email": "n-semenov.111981@postgrespro.ru", "phone": "+70333576695"}
0005434879221	15DFE4	5441 263685	ALBERT NAZAROV	{"phone": "+70469865237"}
0005434879222	A674EC	7402 741122	IRINA MALYSHEVA	{"email": "malysheva.i_121978@postgrespro.ru", "phone": "+70976483769"}
0005434879223	C42C16	8752 736787	GALINA ABRAMOVA	{"email": "abramovag1975@postgrespro.ru", "phone": "+70476195240"}
0005434879224	C42C16	7377 706170	EVGENIY STEPANOV	{"phone": "+70675364760"}
0005434879225	9AFADA	8305 945351	DAMIR KUZNECOV	{"phone": "+70936357417"}
0005434879226	9AFADA	9730 711109	LEV MEDVEDEV	{"email": "medvedev.l.111972@postgrespro.ru", "phone": "+70467659340"}
0005434879227	8E339A	5761 978434	SERGEY VOROBEV	{"email": "vorobevsergey-1962@postgrespro.ru", "phone": "+70064461492"}
0005434879228	1A50C5	3193 410050	TAMARA SIDOROVA	{"phone": "+70437447146"}
0005434879229	1A50C5	7284 927155	ANASTASIYA LAZAREVA	{"email": "alazareva-26041971@postgrespro.ru", "phone": "+70225548444"}
0005434879230	58FAF8	9391 034872	YURIY YAKOVLEV	{"phone": "+70758828854"}
0005434879231	58FAF8	2187 432611	SERGEY PETROV	{"email": "sergey_petrov.20061964@postgrespro.ru", "phone": "+70367300919"}
0005434879232	D7C0B7	7213 444039	ASKHAT STEPANOV	{"phone": "+70553749437"}
0005434879233	72C853	3876 585830	ELENA CHERNOVA	{"email": "chernova.elena-121970@postgrespro.ru", "phone": "+70708207656"}
0005434879234	7048B5	1076 126294	OLGA AKIMOVA	{"email": "olgaakimova_051970@postgrespro.ru", "phone": "+70474514836"}
0005434879235	0C46FF	8276 038023	ELENA EFREMOVA	{"phone": "+70655828281"}
0005434879236	9D92C2	0273 231798	ANATOLIY NOVIKOV	{"phone": "+70784842074"}
0005434879237	BFFEC7	3342 516820	KHALIDA ROMANOVA	{"email": "romanovak-021973@postgrespro.ru", "phone": "+70429929416"}
0005434879238	BFFEC7	7178 685031	ALEKSANDR FILIPPOV	{"email": "filippova.27121975@postgrespro.ru", "phone": "+70139071222"}
0005434879239	F417A9	8069 927913	SERGEY GORBUNOV	{"email": "s-gorbunov.1964@postgrespro.ru", "phone": "+70861783201"}
0005434879301	BB4C89	0163 987140	MARIYA MAKAROVA	{"phone": "+70396976067"}
0005434879240	F417A9	9496 363812	SOFYA LOGINOVA	{"email": "loginova-s-101976@postgrespro.ru", "phone": "+70642203082"}
0005434879241	3A67C6	7355 325259	LYUBOV SIDOROVA	{"phone": "+70512112056"}
0005434879242	38E9F1	5565 427220	EVGENIYA DMITRIEVA	{"phone": "+70385012420"}
0005434879243	38E9F1	5702 436744	NIKOLAY NAUMOV	{"email": "naumov.n-1977@postgrespro.ru", "phone": "+70072999463"}
0005434879486	4FA743	3155 278100	KIRILL VASILEV	{"phone": "+70030618178"}
0005434879244	38E9F1	0175 502483	YURIY MOROZOV	{"email": "morozov-yuriy.14061952@postgrespro.ru", "phone": "+70162700672"}
0005434879245	66329D	7997 275502	DMITRIY SOROKIN	{"email": "d-sorokin09121964@postgrespro.ru", "phone": "+70706935832"}
0005434879246	89207E	8188 696074	YURIY NOVIKOV	{"phone": "+70676515406"}
0005434879247	89207E	0384 046864	LARISA DANILOVA	{"email": "danilova.larisa091975@postgrespro.ru", "phone": "+70353405013"}
0005434879248	E4D8DF	7034 961412	ANDREY FROLOV	{"phone": "+70985549336"}
0005434879249	8C8419	5821 737114	OLGA SAVELEVA	{"email": "saveleva-o.1971@postgrespro.ru", "phone": "+70518887769"}
0005434879250	8C8419	8881 213332	ARTUR KULIKOV	{"email": "artur.kulikov.031985@postgrespro.ru", "phone": "+70576573850"}
0005434879251	29A892	9149 169811	MARIYA ERMAKOVA	{"phone": "+70580969457"}
0005434879252	DEE23A	5029 575747	MIKHAIL IVANOV	{"phone": "+70924939079"}
0005434879253	7AD7C5	2796 470208	SVETLANA KOROLEVA	{"email": "s-koroleva04101985@postgrespro.ru", "phone": "+70861458237"}
0005434879254	7AD7C5	5389 836282	VALENTINA ILINA	{"email": "ilina-valentina-16101956@postgrespro.ru", "phone": "+70229100076"}
0005434879255	47A48B	6774 127499	GALINA BELOVA	{"phone": "+70845070330"}
0005434879256	E5AAAE	7041 988518	TATYANA KUZNECOVA	{"email": "kuznecova.t.081981@postgrespro.ru", "phone": "+70543802804"}
0005434879257	D4677A	8901 413428	ANNA RODIONOVA	{"phone": "+70880238639"}
0005434879258	D4677A	5170 840777	VALERIY DMITRIEV	{"phone": "+70570665405"}
0005434879259	329BE3	8987 484614	ELIZAVETA KISELEVA	{"email": "kiselevae-1982@postgrespro.ru", "phone": "+70047889473"}
0005434879260	70C83D	5033 775833	LILIYA KOVALEVA	{"phone": "+70371213285"}
0005434879261	6F4E9C	9381 291665	DMITRIY SEMENOV	{"phone": "+70920587194"}
0005434879262	0C4D00	1185 498937	YURIY ZHURAVLEV	{"phone": "+70270838748"}
0005434879263	B11840	4291 689485	VLADIMIR STEPANOV	{"phone": "+70992895737"}
0005434879264	E467F9	4391 642518	EKATERINA NAUMOVA	{"phone": "+70544235608"}
0005434879265	E467F9	9987 650909	VLADIMIR SOROKIN	{"phone": "+70728761322"}
0005434879266	65ACB8	3839 226036	GALINA AKIMOVA	{"email": "g-akimova_061966@postgrespro.ru", "phone": "+70796119674"}
0005434879267	CA615C	1392 649166	RUSLAN POPOV	{"phone": "+70007447060"}
0005434879268	17147A	3336 389089	GALINA ERMAKOVA	{"email": "g.ermakova-111963@postgrespro.ru", "phone": "+70243857186"}
0005434879269	17147A	2381 963983	VLADIMIR ZHURAVLEV	{"phone": "+70056504238"}
0005434879270	5E22D4	1089 765738	NIKOLAY MAKAROV	{"email": "n-makarov-111967@postgrespro.ru", "phone": "+70387072795"}
0005434879271	92C740	2496 876166	MARINA FILIPPOVA	{"phone": "+70751191345"}
0005434879272	92C740	3606 254461	ANDREY IVANOV	{"phone": "+70544457557"}
0005434879273	77F5DD	0454 833056	ELENA ANDREEVA	{"phone": "+70732849318"}
0005434879274	48538E	4390 334758	EKATERINA BELOVA	{"email": "ekaterina-belova-1971@postgrespro.ru", "phone": "+70226723278"}
0005434879275	48538E	4107 724025	FILIPP SIDOROV	{"email": "sidorov.filipp021978@postgrespro.ru", "phone": "+70950673777"}
0005434879276	3C8366	1863 132511	YURIY VASILEV	{"phone": "+70329045528"}
0005434879277	72F134	5920 838213	DMITRIY GERASIMOV	{"email": "gerasimov.d-121974@postgrespro.ru", "phone": "+70170921134"}
0005434879278	743A1F	0078 981713	NADEZHDA DENISOVA	{"phone": "+70130956112"}
0005434879279	743A1F	4186 936390	SERGEY KOZLOV	{"email": "kozlov_s-101982@postgrespro.ru", "phone": "+70735783814"}
0005434879280	C58847	3854 861518	ELENA ANDREEVA	{"email": "andreevae.22021973@postgrespro.ru", "phone": "+70362016244"}
0005434879281	38A009	2404 346389	SVETLANA STEPANOVA	{"email": "svetlana_stepanova15081988@postgrespro.ru", "phone": "+70924454774"}
0005434879282	1D766A	3491 910545	INNA GORBUNOVA	{"email": "gorbunova.inna-011970@postgrespro.ru", "phone": "+70917283255"}
0005434879283	1D766A	0281 156563	VLADIMIR TIMOFEEV	{"email": "vtimofeev-121966@postgrespro.ru", "phone": "+70291705397"}
0005434879284	2064FE	2778 703436	VALERIY NOVIKOV	{"email": "valeriy_novikov06071966@postgrespro.ru", "phone": "+70352964140"}
0005434879285	2064FE	1562 384004	ALEKSANDR ZAYCEV	{"email": "aleksandr-zaycev-1980@postgrespro.ru", "phone": "+70755907459"}
0005434879286	2064FE	5892 153183	MARIYA LEBEDEVA	{"phone": "+70036757247"}
0005434879287	4AC7BD	9989 754656	SERGEY MARTYNOV	{"email": "smartynov-101961@postgrespro.ru", "phone": "+70224933426"}
0005434879288	C96F84	0608 335534	IVAN MIKHAYLOV	{"phone": "+70297996714"}
0005434879289	C96F84	5898 713092	OLGA YAKOVLEVA	{"email": "o_yakovleva_041972@postgrespro.ru", "phone": "+70851717590"}
0005434879290	C96F84	3663 523175	VALERIY IVANOV	{"phone": "+70577089693"}
0005434879291	10F08C	6288 940460	NATALIYA NIKIFOROVA	{"email": "n_nikiforova_02091966@postgrespro.ru", "phone": "+70223308450"}
0005434879292	10F08C	3743 284210	ELENA EFREMOVA	{"phone": "+70766088470"}
0005434879293	19B66A	7668 360098	MAKSIM GAVRILOV	{"email": "gavrilov_maksim-1975@postgrespro.ru", "phone": "+70986502596"}
0005434879294	19B66A	5661 179921	DARYA YAKOVLEVA	{"email": "d.yakovleva.1983@postgrespro.ru", "phone": "+70997877695"}
0005434879295	B62794	2879 339660	SVETLANA FEDOROVA	{"phone": "+70576908092"}
0005434879296	9C1769	9523 773863	ANTON KUZMIN	{"phone": "+70255773116"}
0005434879297	CD39EA	8627 914730	IVAN POPOV	{"phone": "+70687242857"}
0005434879298	CD39EA	1511 207994	NATALYA NIKOLAEVA	{"email": "n.nikolaeva.021966@postgrespro.ru", "phone": "+70150712636"}
0005434879299	DBFBC0	2439 907273	TIMUR POPOV	{"email": "timur_popov_15101968@postgrespro.ru", "phone": "+70157943641"}
0005434879300	33489F	0210 712929	VLADISLAV KUZNECOV	{"phone": "+70563301299"}
0005434879302	BB4C89	6499 714787	ANTON SCHERBAKOV	{"phone": "+70763225034"}
0005434879303	020756	9247 480735	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov_24101962@postgrespro.ru", "phone": "+70454734873"}
0005434879304	020756	5057 080444	ALEKSANDRA NESTEROVA	{"phone": "+70430300949"}
0005434879305	9FA117	6271 685759	LYUBOV TIMOFEEVA	{"phone": "+70768189096"}
0005434879306	F41844	2404 199861	FANIS IVANOV	{"email": "f.ivanov-1962@postgrespro.ru", "phone": "+70230918005"}
0005434879307	A7C352	6024 118581	ELENA KOROLEVA	{"email": "elena_koroleva.18121968@postgrespro.ru", "phone": "+70957477470"}
0005434879308	A7C352	2981 950391	ILYA GERASIMOV	{"email": "i-gerasimov_021987@postgrespro.ru", "phone": "+70704316393"}
0005434879309	9457B0	7369 515074	ALEKSANDR IVANOV	{"email": "aleksandrivanov061969@postgrespro.ru", "phone": "+70918834966"}
0005434879310	7CE0E6	8213 253919	VARVARA VASILEVA	{"email": "v_vasileva_121975@postgrespro.ru", "phone": "+70623557361"}
0005434879311	49570D	4957 341854	GALINA IVANOVA	{"phone": "+70333592580"}
0005434879312	F9951A	8316 158991	IVAN SMIRNOV	{"email": "smirnov.i_13121964@postgrespro.ru", "phone": "+70962725646"}
0005434879313	55AA61	3518 817377	EDUARD GORBUNOV	{"phone": "+70367056319"}
0005434879314	02B52A	7225 863294	SERGEY SOROKIN	{"email": "sorokinsergey_1970@postgrespro.ru", "phone": "+70895950458"}
0005434879315	12FD49	2193 643408	VYACHESLAV NAZAROV	{"phone": "+70808351954"}
0005434879316	4C1535	9790 628492	SERGEY ZAKHAROV	{"email": "zakharov-sergey_061969@postgrespro.ru", "phone": "+70941874224"}
0005434879317	301288	7460 976057	ELENA NIKOLAEVA	{"email": "nikolaeva-elena_03111974@postgrespro.ru", "phone": "+70205350096"}
0005434879318	ED8790	9625 232133	RAISA VOLKOVA	{"email": "volkova.r_04061978@postgrespro.ru", "phone": "+70251376444"}
0005434879319	C11C04	0609 506667	MARINA FADEEVA	{"phone": "+70660692372"}
0005434879320	C11C04	9611 379093	VASILIY SEMENOV	{"email": "semenov.v1968@postgrespro.ru", "phone": "+70607021827"}
0005434879321	351B61	6360 782683	VADIM KULIKOV	{"email": "kulikov_v_101974@postgrespro.ru", "phone": "+70692559762"}
0005434879322	351B61	6389 616353	VALERIY KONOVALOV	{"email": "valeriy_konovalov-1971@postgrespro.ru", "phone": "+70663370856"}
0005434879323	576D25	5892 458750	VASILIY FILIPPOV	{"phone": "+70829654100"}
0005434879324	3F4824	7921 238563	ALEKSANDR VLASOV	{"email": "a_vlasov-121974@postgrespro.ru", "phone": "+70275524320"}
0005434879325	E0E222	7203 514411	AZAT NAZAROV	{"phone": "+70185308472"}
0005434879326	E0E222	5568 112556	MIKHAIL FEDOROV	{"email": "mikhailfedorov-081969@postgrespro.ru", "phone": "+70970256173"}
0005434879327	89D44B	0066 291607	ALEKSANDR KUDRYASHOV	{"phone": "+70312792432"}
0005434879328	34C71E	0908 996976	ROMAN IVANOV	{"email": "roman.ivanov_1964@postgrespro.ru", "phone": "+70188654718"}
0005434879329	6964F0	7135 595160	VLADISLAV OSIPOV	{"email": "v.osipov.07091975@postgrespro.ru", "phone": "+70946175869"}
0005434879330	6BF0CC	2291 756924	ALEKSANDR MIRONOV	{"phone": "+70661725947"}
0005434879331	69D9FD	0992 219335	OLGA FROLOVA	{"phone": "+70224836725"}
0005434879332	0D323A	6764 708741	ANTONINA ANDREEVA	{"email": "aandreeva.14011974@postgrespro.ru", "phone": "+70859411302"}
0005434879333	758F66	4481 338342	NADEZHDA IVANOVA	{"email": "nadezhda.ivanova_10071974@postgrespro.ru", "phone": "+70199709718"}
0005434879334	EBA06B	6677 463391	ANATOLIY EGOROV	{"email": "egorov.a.1980@postgrespro.ru", "phone": "+70612742181"}
0005434879335	CCAE9F	6478 222712	EKATERINA EFIMOVA	{"phone": "+70916714537"}
0005434879336	CCAE9F	5233 683901	ANATOLIY YAKOVLEV	{"phone": "+70731023739"}
0005434879337	4AD5CA	4377 667787	ALEKSANDR SEMENOV	{"email": "semenov.a24021967@postgrespro.ru", "phone": "+70605145920"}
0005434879338	3FAEBC	9731 559181	EVGENIY KOZLOV	{"phone": "+70829668927"}
0005434879339	466CB9	2766 718569	ELENA IVANOVA	{"phone": "+70952520067"}
0005434879340	466CB9	6795 919692	SERGEY TIMOFEEV	{"email": "timofeev_sergey.1972@postgrespro.ru", "phone": "+70706256510"}
0005434879341	78ADC3	3283 467541	LYUBOV KULIKOVA	{"email": "kulikoval061981@postgrespro.ru", "phone": "+70488208654"}
0005434879342	09FFFA	0333 969073	NATALYA TIKHONOVA	{"phone": "+70285095759"}
0005434879343	0ECC2B	2358 060839	MARIYA ZHURAVLEVA	{"email": "zhuravleva.m_17041974@postgrespro.ru", "phone": "+70865966496"}
0005434879344	035528	9587 799969	DAMIR DAVYDOV	{"phone": "+70548555520"}
0005434879345	035528	2690 830690	ANASTASIYA MASLOVA	{"email": "amaslova.1993@postgrespro.ru", "phone": "+70599435295"}
0005434879346	C175F5	8926 086267	OLGA SAVELEVA	{"email": "savelevaolga_021970@postgrespro.ru", "phone": "+70324225700"}
0005434879347	B4D000	2737 590920	SERGEY ROMANOV	{"email": "romanov_s011985@postgrespro.ru", "phone": "+70463518260"}
0005434879348	A56657	2005 810904	MIKHAIL IVANOV	{"phone": "+70387575085"}
0005434879349	7745C5	7526 205135	VLADIMIR POPOV	{"phone": "+70627148579"}
0005434879350	027EDB	4894 519487	MIKHAIL SMIRNOV	{"phone": "+70859966431"}
0005434879351	0BCAE5	1689 794388	ANTON DAVYDOV	{"email": "adavydov_111982@postgrespro.ru", "phone": "+70468983552"}
0005434879352	D67C90	4614 058665	VLADIMIR NIKITIN	{"phone": "+70064263810"}
0005434879353	58ECA2	8407 166603	ANDREY SMIRNOV	{"email": "andrey-smirnov-07041967@postgrespro.ru", "phone": "+70374894258"}
0005434879354	B39C08	9752 060939	ANATOLIY POPOV	{"email": "anatoliy.popov_071971@postgrespro.ru", "phone": "+70630079960"}
0005434879355	B39C08	5702 899742	GALINA EFIMOVA	{"email": "efimova.g-1970@postgrespro.ru", "phone": "+70059831355"}
0005434879356	BE569B	2381 334465	ANTONINA ZHURAVLEVA	{"phone": "+70358515649"}
0005434879357	68CE83	9180 369620	ANTON YAKOVLEV	{"phone": "+70988617973"}
0005434879358	47CA48	0189 622802	LYUDMILA ABRAMOVA	{"phone": "+70604118115"}
0005434879359	FA5E93	9463 673515	YAKOV VOROBEV	{"phone": "+70309420339"}
0005434879360	E61C0C	9995 959234	ALEKSANDR MIKHAYLOV	{"phone": "+70945004157"}
0005434879421	DFC58B	4838 835408	MAKSIM SOROKIN	{"phone": "+70907743439"}
0005434879361	7BAAB0	2337 894927	ALEKSEY GORBUNOV	{"email": "agorbunov06011973@postgrespro.ru", "phone": "+70940119558"}
0005434879362	7BAAB0	6143 799848	OLGA NIKITINA	{"email": "o.nikitina.051959@postgrespro.ru", "phone": "+70294135169"}
0005434879363	7BAAB0	1529 794758	NATALYA LUKYANOVA	{"email": "n_lukyanova_041974@postgrespro.ru", "phone": "+70567203196"}
0005434879365	0B8CA0	8449 991268	NATALYA MEDVEDEVA	{"email": "natalya.medvedeva_16011967@postgrespro.ru", "phone": "+70279359378"}
0005434879366	305E8D	5129 070603	ALEKSANDR SOLOVEV	{"phone": "+70782445316"}
0005434879367	305E8D	1764 938511	ALEKSANDRA GRISHINA	{"phone": "+70436249088"}
0005434879368	853307	8072 372078	VERA BARANOVA	{"email": "baranovav_06061971@postgrespro.ru", "phone": "+70449448748"}
0005434879369	145D9D	8414 074133	LARISA ROMANOVA	{"phone": "+70078351859"}
0005434879370	F326E5	9454 862112	POLINA MIKHAYLOVA	{"phone": "+70664999153"}
0005434879371	F326E5	7371 143660	ARTEM MARTYNOV	{"email": "martynovartem_28031979@postgrespro.ru", "phone": "+70521530499"}
0005434879372	047C62	0819 273578	SERGEY ANTONOV	{"phone": "+70774954080"}
0005434879373	5B3C2A	7767 682359	GALINA BELOVA	{"phone": "+70663111432"}
0005434879374	5B3C2A	0748 100768	NATALYA NOVIKOVA	{"phone": "+70194845593"}
0005434879375	810BAB	2824 103304	VLADIMIR KUZNECOV	{"phone": "+70489956758"}
0005434879376	810BAB	2355 475552	GALINA SCHERBAKOVA	{"phone": "+70230499446"}
0005434879377	F97BA4	2133 466578	EVGENIY ISAEV	{"email": "isaev_evgeniy.1979@postgrespro.ru", "phone": "+70736926428"}
0005434879378	C0E59D	2308 581451	MIKHAIL PAVLOV	{"email": "pavlov-mikhail_061968@postgrespro.ru", "phone": "+70273999355"}
0005434879379	C0E59D	3292 919013	VLADIMIR KAZAKOV	{"phone": "+70704498214"}
0005434879380	55D06F	9401 433408	OLGA DENISOVA	{"phone": "+70200950974"}
0005434879381	A8985A	7270 705259	VLADIMIR SERGEEV	{"email": "v-sergeev041981@postgrespro.ru", "phone": "+70401782379"}
0005434879382	AC558F	2051 947031	GALINA VOROBEVA	{"email": "gvorobeva_021965@postgrespro.ru", "phone": "+70400188415"}
0005434879383	4FEE8E	4391 206957	NIKITA KONOVALOV	{"email": "konovalovn-1968@postgrespro.ru", "phone": "+70476138613"}
0005434879384	266C7E	2975 700347	VALENTINA MEDVEDEVA	{"phone": "+70491420574"}
0005434879385	2E055A	4491 742866	VLADISLAV IVANOV	{"phone": "+70837459909"}
0005434879386	2C7258	0120 059782	ELENA AFANASEVA	{"phone": "+70259057114"}
0005434879387	2C7258	3662 289055	TATYANA STEPANOVA	{"phone": "+70192343831"}
0005434879388	D29003	8423 628275	OLEG RODIONOV	{"phone": "+70677934475"}
0005434879389	654852	9911 990362	VIKTOR BARANOV	{"email": "baranov_viktor_10041978@postgrespro.ru", "phone": "+70977508004"}
0005434879390	654852	1260 500080	FARID MAKAROV	{"phone": "+70573804353"}
0005434879391	048C63	9987 674345	YAROSLAV EGOROV	{"email": "yaroslav_egorov.031973@postgrespro.ru", "phone": "+70021330423"}
0005434879392	048C63	3323 696257	ELIZAVETA ANDREEVA	{"phone": "+70878179521"}
0005434879393	A63490	9424 454772	LIDIYA ANDREEVA	{"email": "andreeva.l-07031976@postgrespro.ru", "phone": "+70935446802"}
0005434879394	A63490	2913 737999	VLADIMIR POPOV	{"phone": "+70449417257"}
0005434879395	F61DAC	8966 349416	VALENTINA ZAYCEVA	{"phone": "+70589738175"}
0005434879396	F61DAC	7786 992418	ROZA NIKIFOROVA	{"email": "nikiforova.r05011964@postgrespro.ru", "phone": "+70847995425"}
0005434879397	E15990	6718 813202	ALEKSANDR VASILEV	{"email": "vasilev.a.21051970@postgrespro.ru", "phone": "+70239060198"}
0005434879398	E15990	7554 177887	ZINAIDA ANDREEVA	{"phone": "+70009419688"}
0005434879399	B1E681	9502 705580	NATALYA IVANOVA	{"email": "ivanova_n_061969@postgrespro.ru", "phone": "+70857741484"}
0005434879400	DE839D	8297 173659	SERGEY PETROV	{"phone": "+70418255941"}
0005434879401	DE839D	9925 662088	FEDOR GORBUNOV	{"email": "f.gorbunov-09041976@postgrespro.ru", "phone": "+70290276584"}
0005434879402	38B7A1	4050 414590	AMIR IVANOV	{"email": "ivanov_amir_1982@postgrespro.ru", "phone": "+70589080076"}
0005434879403	72FCD0	7772 517893	SERGEY BONDARENKO	{"email": "bondarenko_sergey_031978@postgrespro.ru", "phone": "+70638272028"}
0005434879404	E6EC2F	6373 258813	VALERIY ANDREEV	{"email": "valeriy.andreev-20021962@postgrespro.ru", "phone": "+70859589295"}
0005434879405	EB2001	6996 855931	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov-30101966@postgrespro.ru", "phone": "+70075489291"}
0005434879406	26FE72	3572 005645	SEMEN SIDOROV	{"phone": "+70214348287"}
0005434879407	4B16DE	7899 535056	MIKHAIL VOROBEV	{"email": "mvorobev04101969@postgrespro.ru", "phone": "+70835404934"}
0005434879408	28C814	0696 139450	GALINA SEMENOVA	{"phone": "+70290663735"}
0005434879409	28C814	6813 448807	ALEKSANDR KAZAKOV	{"email": "kazakov_a14021960@postgrespro.ru", "phone": "+70484451049"}
0005434879410	12CF8D	4057 640968	SVETLANA ANDREEVA	{"email": "s-andreeva081954@postgrespro.ru", "phone": "+70831379336"}
0005434879411	38E492	0938 598917	VERA MIKHAYLOVA	{"phone": "+70699702707"}
0005434879412	5CC99C	7010 604860	ILYA PETROV	{"email": "i.petrov-11031983@postgrespro.ru", "phone": "+70170122460"}
0005434879413	EBE85F	0980 335733	SERGEY KUZNECOV	{"phone": "+70088137582"}
0005434879414	8133CA	6729 570659	OLGA NOVIKOVA	{"email": "novikova-olga.051958@postgrespro.ru", "phone": "+70962150799"}
0005434879415	D9BDC5	9364 653610	DAVID MIKHAYLOV	{"email": "mikhaylov.d.1969@postgrespro.ru", "phone": "+70863359110"}
0005434879416	40C664	7687 405517	VIKTORIYA SIDOROVA	{"email": "sidorova.v071975@postgrespro.ru", "phone": "+70731749524"}
0005434879417	AAB508	1273 492216	DMITRIY EGOROV	{"phone": "+70554919322"}
0005434879418	AAB508	0576 072143	VALERIY TIKHONOV	{"email": "tikhonov.valeriy_02091981@postgrespro.ru", "phone": "+70965171339"}
0005434879419	D05FDA	9299 371991	KRISTINA KOLESNIKOVA	{"email": "k-kolesnikova.1976@postgrespro.ru", "phone": "+70419777255"}
0005434879420	D05FDA	0937 186295	VADIM ROMANOV	{"email": "v.romanov.16011969@postgrespro.ru", "phone": "+70120964960"}
0005434879422	20908D	5578 177793	EKATERINA GORBUNOVA	{"phone": "+70602817026"}
0005434879423	A138C2	8133 571847	SERGEY ORLOV	{"email": "sergey.orlov.1963@postgrespro.ru", "phone": "+70397963017"}
0005434879424	B65030	8311 873459	MARIYA FOMINA	{"phone": "+70440135593"}
0005434879425	78662D	9086 155814	VIKTOR BARANOV	{"email": "v.baranov-1972@postgrespro.ru", "phone": "+70061198531"}
0005434879426	3F4A8A	4065 271698	DMITRIY SHEVCHENKO	{"email": "shevchenko_d1965@postgrespro.ru", "phone": "+70016640113"}
0005434879427	00D837	3307 016610	SVETLANA LEBEDEVA	{"email": "lebedeva-svetlana-021974@postgrespro.ru", "phone": "+70107571110"}
0005434879428	0E1E45	1552 876028	ANDREY PETROV	{"phone": "+70609834876"}
0005434879429	135EEE	7553 200509	NINA ARKHIPOVA	{"email": "nina-arkhipova-101988@postgrespro.ru", "phone": "+70984862236"}
0005434879430	135EEE	2130 573952	VALENTINA FOMINA	{"phone": "+70631719356"}
0005434879431	615E9C	2155 761383	DENIS SCHERBAKOV	{"email": "scherbakovdenis011976@postgrespro.ru", "phone": "+70451247167"}
0005434879432	9F94BF	5227 832224	ZINAIDA KOROLEVA	{"email": "zinaida.koroleva_081966@postgrespro.ru", "phone": "+70617998838"}
0005434879433	9F94BF	9758 968862	OLGA KARPOVA	{"email": "karpova-o_29011979@postgrespro.ru", "phone": "+70890989097"}
0005434879434	D76B66	3787 608420	ELENA DENISOVA	{"phone": "+70234035879"}
0005434879435	8A48C5	5864 367477	YURIY SEMENOV	{"phone": "+70147937531"}
0005434879436	10CD0F	6806 212299	SERGEY ABRAMOV	{"phone": "+70294953199"}
0005434879437	B584CD	2273 701873	DMITRIY FEDOROV	{"phone": "+70029967230"}
0005434879438	4919C8	8912 274148	PETR ZAYCEV	{"email": "p.zaycev_1968@postgrespro.ru", "phone": "+70587393097"}
0005434879439	59D8A8	5198 802975	ELENA KUDRYASHOVA	{"email": "kudryashova_elena031973@postgrespro.ru", "phone": "+70179531952"}
0005434879440	9054FA	6456 327524	NIKOLAY POPOV	{"email": "nikolay.popov_021972@postgrespro.ru", "phone": "+70432511648"}
0005434879441	26EC6B	8849 908274	VALERIYA POPOVA	{"phone": "+70382990634"}
0005434879442	86D150	1666 375736	ARTEMIY ANTONOV	{"email": "antonov.a-04071972@postgrespro.ru", "phone": "+70468962971"}
0005434879443	86D150	1517 021726	VLADIMIR RODIONOV	{"phone": "+70764751958"}
0005434879444	B85CAD	3654 927106	ALEKSANDR KULIKOV	{"phone": "+70994246303"}
0005434879445	E1872A	5780 718395	TATYANA ANDREEVA	{"phone": "+70900184317"}
0005434879446	E1872A	3248 779699	IVAN VASILEV	{"email": "ivasilev-01051978@postgrespro.ru", "phone": "+70621879851"}
0005434879447	3DBCFE	0278 891455	ALEKSEY ALEKSANDROV	{"email": "aaleksandrov_12061969@postgrespro.ru", "phone": "+70120500334"}
0005434879448	B0F899	5622 445080	ANDREY FEDOROV	{"phone": "+70634122882"}
0005434879449	4DA3C5	1971 379813	TATYANA GERASIMOVA	{"phone": "+70429764192"}
0005434879450	AFBB09	7709 258568	LYUBOV RYABOVA	{"email": "l-ryabova.27121966@postgrespro.ru", "phone": "+70252702443"}
0005434879451	E05BC0	2297 235846	LYUBOV SEMENOVA	{"phone": "+70256626729"}
0005434879452	E05BC0	1806 840527	NIKOLAY SCHERBAKOV	{"phone": "+70384488371"}
0005434879453	4E296D	2361 910398	RUFINA KOROLEVA	{"phone": "+70173567722"}
0005434879454	C84644	1066 589008	ALEKSANDR NAZAROV	{"phone": "+70352511705"}
0005434879455	D9649F	3113 990870	VIKTOR MAKAROV	{"phone": "+70818734437"}
0005434879456	6EC5DF	5870 398736	NIKITA GRIGOREV	{"phone": "+70163883390"}
0005434879457	5BC712	3225 936524	ALEKSANDRA OVCHINNIKOVA	{"email": "a-ovchinnikova-021968@postgrespro.ru", "phone": "+70826200436"}
0005434879458	5BC712	9164 811567	MARIYA KOROLEVA	{"phone": "+70587925878"}
0005434879459	EB8777	3670 504934	MARIYA ZOTOVA	{"phone": "+70439892966"}
0005434879460	049FD7	8739 557526	NIKOLAY NIKITIN	{"email": "nikolay-nikitin.1958@postgrespro.ru", "phone": "+70190548874"}
0005434879461	049FD7	9870 811514	ZHANNA VOROBEVA	{"email": "vorobeva_zhanna-1964@postgrespro.ru", "phone": "+70704098106"}
0005434879462	049FD7	5624 589213	TATYANA EFREMOVA	{"email": "tefremova_041959@postgrespro.ru", "phone": "+70268396052"}
0005434879463	C1C151	7948 306992	ELENA IVANOVA	{"phone": "+70469068779"}
0005434879464	FC1AA6	4665 648851	VITALIY SOROKIN	{"phone": "+70644395982"}
0005434879465	FCDD4F	6589 188753	MARIYA ROMANOVA	{"phone": "+70190587611"}
0005434879466	5107E3	0131 304997	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov-27121979@postgrespro.ru", "phone": "+70427150804"}
0005434879467	8404FE	0036 650869	VLADIMIR EGOROV	{"email": "vladimir.egorov-12031979@postgrespro.ru", "phone": "+70351010672"}
0005434879468	B5B4CB	9225 992330	OLGA MOISEEVA	{"email": "moiseeva.olga071981@postgrespro.ru", "phone": "+70972928574"}
0005434879469	B5B4CB	6629 099777	NADEZHDA MELNIKOVA	{"email": "nadezhda.melnikova-1967@postgrespro.ru", "phone": "+70098052827"}
0005434879470	64DC2C	6463 558360	MARIYA KOROLEVA	{"phone": "+70635804371"}
0005434879471	34C7D5	3747 697750	OLGA ALEKSEEVA	{"email": "alekseevaolga_16081973@postgrespro.ru", "phone": "+70396206811"}
0005434879472	91B8FD	5574 927112	OLGA KUZNECOVA	{"email": "okuznecova_28011986@postgrespro.ru", "phone": "+70572542517"}
0005434879473	91B8FD	5370 829782	ALEKSANDRA SOKOLOVA	{"email": "aleksandra-sokolova.081969@postgrespro.ru", "phone": "+70033328050"}
0005434879474	AACAEA	6932 378327	LILIYA ANDREEVA	{"email": "andreeva-liliya-011977@postgrespro.ru", "phone": "+70486782995"}
0005434879475	AACAEA	3249 807706	SERGEY IVANOV	{"email": "sergey.ivanov021985@postgrespro.ru", "phone": "+70278450975"}
0005434879476	17F311	0322 697570	ELMIRA KOROLEVA	{"phone": "+70005286864"}
0005434879477	C1BC8C	1191 500630	VLADIMIR VASILEV	{"email": "vasilevv-041964@postgrespro.ru", "phone": "+70657688377"}
0005434879478	A430F9	3131 857135	ANASTASIYA MEDVEDEVA	{"email": "amedvedeva011973@postgrespro.ru", "phone": "+70159494034"}
0005434879479	02E1A4	5394 509485	DMITRIY SOLOVEV	{"phone": "+70417362890"}
0005434879480	102397	7557 606585	PAVEL ZAKHAROV	{"email": "pavel-zakharov.101961@postgrespro.ru", "phone": "+70456690351"}
0005434879481	102397	3774 607689	NADEZHDA KUZNECOVA	{"phone": "+70874704783"}
0005434879482	178DA7	6063 863263	FARID VASILEV	{"email": "vasilev-f_02011980@postgrespro.ru", "phone": "+70256826086"}
0005434879483	0F7BE1	9846 974024	ILYA NOVIKOV	{"phone": "+70014471684"}
0005434879484	0F7BE1	2602 002443	YURIY VOROBEV	{"phone": "+70191898128"}
0005434879485	4FA743	7517 469872	ALEKSEY ZHURAVLEV	{"email": "aleksey_zhuravlev011970@postgrespro.ru", "phone": "+70653603883"}
0005434879487	EE84A5	3665 642909	SVETLANA MIKHAYLOVA	{"phone": "+70525946949"}
0005434879488	F10E8A	1011 269705	GRIGORIY DMITRIEV	{"phone": "+70899381793"}
0005434879489	D2A631	2840 910357	VIKTOR AFANASEV	{"email": "v.afanasev.061980@postgrespro.ru", "phone": "+70595431744"}
0005434879490	D2A631	3625 695040	VALERIY IVANOV	{"email": "ivanov.valeriy.29031967@postgrespro.ru", "phone": "+70971025175"}
0005434879491	FB5C80	1352 905761	MIKHAIL VOLKOV	{"email": "volkov-m.1977@postgrespro.ru", "phone": "+70540006796"}
0005434879492	21EF35	2407 696639	NINA MIKHAYLOVA	{"phone": "+70572222961"}
0005434879493	222757	6879 909718	TATYANA ZHURAVLEVA	{"phone": "+70196698533"}
0005434879494	E92AFE	2832 326660	EKATERINA GERASIMOVA	{"email": "ekaterina.gerasimova.14121976@postgrespro.ru", "phone": "+70036237920"}
0005434879495	5A9232	8679 200835	ANNA LAZAREVA	{"email": "anna-lazareva23041973@postgrespro.ru", "phone": "+70517294134"}
0005434879496	F19A19	2881 910934	ALEKSANDRA CHERNOVA	{"phone": "+70725058166"}
0005434879497	F19A19	0582 014750	ANDREY PAVLOV	{"email": "andrey_pavlov_1965@postgrespro.ru", "phone": "+70737330940"}
0005434879498	89B8A0	6559 008049	IGOR ANTONOV	{"email": "i_antonov-1974@postgrespro.ru", "phone": "+70003135855"}
0005434879499	89B8A0	4038 826644	ALEKSANDR SMIRNOV	{"phone": "+70767151602"}
0005434879500	89B8A0	4156 604002	IRINA MOISEEVA	{"email": "moiseeva_irina_04111974@postgrespro.ru", "phone": "+70983188716"}
0005434879501	FC0AD3	3189 960701	GALINA DANILOVA	{"phone": "+70991109222"}
0005434879502	FC0AD3	7478 846089	EVGENIY KARPOV	{"email": "karpov_e_1962@postgrespro.ru", "phone": "+70637966058"}
0005434879503	F469A9	9523 955758	TAMARA KUZNECOVA	{"phone": "+70845097072"}
0005434879504	844776	0295 682641	ANASTASIYA MEDVEDEVA	{"email": "medvedeva-anastasiya_1975@postgrespro.ru", "phone": "+70831944890"}
0005434879505	F2ECAB	8676 486053	ALEKSANDR POPOV	{"email": "popov-aleksandr-1967@postgrespro.ru", "phone": "+70534086150"}
0005434879506	D0F46A	1398 964157	EVGENIY BELOV	{"phone": "+70985788647"}
0005434879507	CA975E	6441 642005	VALERIYA NIKITINA	{"phone": "+70957318809"}
0005434879508	7B655B	1941 332246	NADEZHDA SERGEEVA	{"email": "nadezhda.sergeeva_1983@postgrespro.ru", "phone": "+70272078926"}
0005434879509	292667	6604 884910	SERGEY FILIPPOV	{"email": "filippov-s-14111968@postgrespro.ru", "phone": "+70409327552"}
0005434879510	16964E	1826 508247	MIKHAIL IVANOV	{"phone": "+70317312116"}
0005434879511	C75C4A	6220 178947	NATALYA VOLKOVA	{"email": "n.volkova_22031976@postgrespro.ru", "phone": "+70845402722"}
0005434879512	B2A345	2613 693858	ALENA SEMENOVA	{"phone": "+70718089158"}
0005434879513	ED1B44	5316 528224	ALEKSEY VOLKOV	{"phone": "+70752065520"}
0005434879514	F85BCF	5131 704004	EDUARD VASILEV	{"phone": "+70312547546"}
0005434879515	F85BCF	7647 715731	NINA VOLKOVA	{"phone": "+70835982317"}
0005434879516	F85BCF	6885 217428	EVGENIY KOROLEV	{"phone": "+70160716851"}
0005434879517	E4F6A7	7755 515332	LYUDMILA YAKOVLEVA	{"phone": "+70008562646"}
0005434879518	58D273	2550 608026	LYUBOV SERGEEVA	{"email": "sergeevalyubov-1977@postgrespro.ru", "phone": "+70841864654"}
0005434879519	69C435	2735 342918	NATALIYA EGOROVA	{"phone": "+70189955968"}
0005434879520	69C435	0420 027126	LYUDMILA PAVLOVA	{"email": "l-pavlova.1967@postgrespro.ru", "phone": "+70957718888"}
0005434879521	7CBFA1	4875 916740	VIKTOR PETROV	{"phone": "+70879837841"}
0005434879522	79F722	7889 071415	MARIYA MAKSIMOVA	{"phone": "+70673797054"}
0005434879523	D70178	9249 146333	ALEKSEY SCHERBAKOV	{"phone": "+70843903425"}
0005434879524	D70178	8535 151166	IGOR MAKAROV	{"phone": "+70661867856"}
0005434879525	2C0842	8772 377564	IRINA SEMENOVA	{"email": "semenovairina.22011970@postgrespro.ru", "phone": "+70424371649"}
0005434879526	C62AD4	9590 785073	NADEZHDA ORLOVA	{"phone": "+70593101119"}
0005434879527	C62AD4	9709 426546	VLADIMIR ORLOV	{"email": "v.orlov041969@postgrespro.ru", "phone": "+70041784157"}
0005434879528	C62AD4	0885 278761	VYACHESLAV IVANOV	{"phone": "+70394660516"}
0005434879529	3B43C1	2914 976158	PAVEL ZHUKOV	{"email": "zhukov_p_1982@postgrespro.ru", "phone": "+70003316952"}
0005434879530	3B43C1	5540 017689	VERA BELOVA	{"email": "v_belova_1987@postgrespro.ru", "phone": "+70412938887"}
0005434879531	5F2F92	8968 462869	MARIYA MELNIKOVA	{"phone": "+70176029116"}
0005434879532	D625EA	4293 523293	TATYANA NOVIKOVA	{"email": "novikova.t-07101973@postgrespro.ru", "phone": "+70116887457"}
0005434879533	426B4C	2266 519072	RAMIL FROLOV	{"phone": "+70951064376"}
0005434879534	C1BB2C	0101 378690	IVAN KARPOV	{"email": "karpovi-061972@postgrespro.ru", "phone": "+70768394653"}
0005434879535	D897D3	7968 012132	YULIYA PAVLOVA	{"email": "y-pavlova.27041981@postgrespro.ru", "phone": "+70347311628"}
0005434879536	51348E	7301 982336	ALEKSANDR PETROV	{"email": "petrov-aleksandr_31051970@postgrespro.ru", "phone": "+70976642516"}
0005434879537	93FF6E	6844 994885	ELENA KUZNECOVA	{"phone": "+70192541742"}
0005434879538	0A9FBE	5553 618451	LYUBOV OVCHINNIKOVA	{"phone": "+70715127746"}
0005434879539	0A9FBE	2542 975234	KSENIYA CHERNOVA	{"email": "k_chernova_071969@postgrespro.ru", "phone": "+70128633553"}
0005434879540	0A9FBE	5823 264661	DENIS KOROLEV	{"email": "korolev_denis041968@postgrespro.ru", "phone": "+70037155385"}
0005434879541	8A689A	6966 018239	ANGELINA EGOROVA	{"email": "egorova_angelina-10071966@postgrespro.ru", "phone": "+70762000618"}
0005434879542	3E2517	8765 522526	RUSTAM KOROLEV	{"phone": "+70940839558"}
0005434879543	3AB04E	0462 122308	ANNA GUSEVA	{"email": "aguseva22041973@postgrespro.ru", "phone": "+70935135763"}
0005434879544	078400	5543 937798	VLADIMIR STEPANOV	{"email": "stepanov-v_1969@postgrespro.ru", "phone": "+70150240856"}
0005434879545	078400	5659 014120	SERGEY SCHERBAKOV	{"email": "sscherbakov111973@postgrespro.ru", "phone": "+70967701576"}
0005434879546	E314A3	3280 747994	IVAN TARASOV	{"email": "i-tarasov1976@postgrespro.ru", "phone": "+70679730850"}
0005434879547	4A26C9	1670 917502	OLGA TIMOFEEVA	{"email": "o-timofeeva-081972@postgrespro.ru", "phone": "+70024323540"}
0005434879548	400175	6959 328977	LEONID VOLKOV	{"email": "l.volkov041973@postgrespro.ru", "phone": "+70007628919"}
0005434879549	820D30	7776 646541	SOFYA SAVELEVA	{"email": "s.saveleva.16091969@postgrespro.ru", "phone": "+70471143731"}
0005434879550	423751	1939 960860	ALEKSEY YAKOVLEV	{"phone": "+70267194630"}
0005434879551	0184C7	4892 051349	EGOR NAUMOV	{"email": "naumovegor1972@postgrespro.ru", "phone": "+70729578754"}
0005434879552	0184C7	7480 647369	EGOR TIMOFEEV	{"email": "e_timofeev.28111976@postgrespro.ru", "phone": "+70216646737"}
0005434879553	0184C7	8755 674749	ARTEM ZAKHAROV	{"email": "a.zakharov.1981@postgrespro.ru", "phone": "+70627352853"}
0005434879554	B2F3C3	2556 729061	BOGDAN MIKHAYLOV	{"phone": "+70982516984"}
0005434879555	5B72C5	5575 636210	PAVEL KULIKOV	{"email": "pkulikov.1976@postgrespro.ru", "phone": "+70819563377"}
0005434879556	CE31D4	2398 561345	VADIM GERASIMOV	{"email": "vadim.gerasimov22021967@postgrespro.ru", "phone": "+70970762003"}
0005434879557	CE31D4	3740 947114	SVETLANA KAZAKOVA	{"phone": "+70385074213"}
0005434879558	517FF4	4362 351713	LYUDMILA MATVEEVA	{"email": "l.matveeva-081967@postgrespro.ru", "phone": "+70140755246"}
0005434879559	517FF4	0341 022279	NADEZHDA FOMINA	{"email": "n-fomina.03031978@postgrespro.ru", "phone": "+70605045868"}
0005434879560	EA5DD9	9897 318414	ROMAN POPOV	{"email": "r-popov-1971@postgrespro.ru", "phone": "+70883311893"}
0005434879561	9D9355	9981 129155	SERGEY SOKOLOV	{"email": "sokolov-s.03021971@postgrespro.ru", "phone": "+70094356408"}
0005434879562	9D9355	3298 600437	VLADIMIR IVANOV	{"phone": "+70616612920"}
0005434879563	AF2ED2	4756 839441	VIKTORIYA MIKHAYLOVA	{"phone": "+70349673328"}
0005434879564	AF2ED2	4318 278239	SERGEY AFANASEV	{"email": "afanasevsergey_121959@postgrespro.ru", "phone": "+70462181280"}
0005434879565	10A5C9	3865 840817	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr061967@postgrespro.ru", "phone": "+70875511074"}
0005434879566	10A5C9	4187 740810	ELIZAVETA NIKOLAEVA	{"email": "elizaveta-nikolaeva081972@postgrespro.ru", "phone": "+70610455052"}
0005434879567	10A5C9	2720 767633	PETR MATVEEV	{"phone": "+70462192823"}
0005434879568	B28EF4	1086 479399	NATALYA MIRONOVA	{"phone": "+70436168801"}
0005434879569	B28EF4	8251 644267	RODION PETROV	{"phone": "+70375140332"}
0005434879570	C2FB16	4825 726551	ALEKSANDRA LEBEDEVA	{"phone": "+70325627925"}
0005434879571	CE5FF4	1782 113499	ELENA ABRAMOVA	{"phone": "+70739398838"}
0005434879572	7E4379	0645 582397	NADEZHDA KAZAKOVA	{"phone": "+70542508467"}
0005434879573	7E4379	9067 127314	TATYANA SAVELEVA	{"email": "saveleva_t-1968@postgrespro.ru", "phone": "+70643024310"}
0005434879574	7E4379	7123 308058	VASILIY GORBUNOV	{"phone": "+70883043490"}
0005434879575	7E4379	2714 541055	ANNA NOVIKOVA	{"email": "anovikova-031981@postgrespro.ru", "phone": "+70238559198"}
0005434879576	69F403	6639 440038	VIKTORIYA GUSEVA	{"email": "guseva-v-1967@postgrespro.ru", "phone": "+70150417703"}
0005434879577	955754	6486 381745	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov_031975@postgrespro.ru", "phone": "+70612086208"}
0005434879578	EA37FE	0285 530135	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov-1973@postgrespro.ru", "phone": "+70606088883"}
0005434879579	EA37FE	2854 780968	KHASAN ANTONOV	{"phone": "+70362219722"}
0005434879580	008D90	8882 312042	ILYA GUSEV	{"phone": "+70287994717"}
0005434879581	C4F328	3962 722250	OLGA KOZLOVA	{"phone": "+70475081027"}
0005434879582	C4F328	2838 168337	VERA MIKHAYLOVA	{"phone": "+70835619385"}
0005434879583	5BB970	8014 345400	PAVEL FILIPPOV	{"phone": "+70856118319"}
0005434879584	D591A9	4713 983553	ELIZAVETA BELOVA	{"phone": "+70900889960"}
0005434879585	028C5B	2193 184537	IRAIDA RYABOVA	{"email": "ryabova_iraida_1978@postgrespro.ru", "phone": "+70923224578"}
0005434879586	2D4DD8	6380 588652	ANATOLIY MELNIKOV	{"phone": "+70055929235"}
0005434879587	52ECBC	4413 912527	VALENTINA KARPOVA	{"email": "v.karpova-051962@postgrespro.ru", "phone": "+70541582774"}
0005434879588	FC4077	1864 249793	IVAN TARASOV	{"phone": "+70321112347"}
0005434879589	FC4077	9560 095461	VERA PETROVA	{"email": "v_petrova.18041975@postgrespro.ru", "phone": "+70610189578"}
0005434879590	EE5453	2042 169300	IRINA EGOROVA	{"phone": "+70419814546"}
0005434879591	EE5453	0534 136941	VLADIMIR NIKOLAEV	{"email": "vnikolaev_07121971@postgrespro.ru", "phone": "+70024263085"}
0005434879592	A86CE0	8210 436767	NINA BORISOVA	{"email": "n.borisova_1963@postgrespro.ru", "phone": "+70045979272"}
0005434879593	00C6E6	6356 321640	KIRILL KISELEV	{"phone": "+70261587206"}
0005434879594	3A28FA	2624 376476	SOFYA NESTEROVA	{"email": "s-nesterova_12011966@postgrespro.ru", "phone": "+70886105640"}
0005434879595	C681A1	9240 934172	VALENTINA KOZLOVA	{"email": "valentinakozlova.25021972@postgrespro.ru", "phone": "+70722592590"}
0005434879596	9DC07F	6893 696104	VERA MATVEEVA	{"phone": "+70625593254"}
0005434879597	8E2378	4485 044940	TATYANA VLASOVA	{"email": "tatyana_vlasova.27061968@postgrespro.ru", "phone": "+70756740803"}
0005434879598	FAD3BA	0469 212090	ANZHELIKA NOVIKOVA	{"email": "anzhelika_novikova_1968@postgrespro.ru", "phone": "+70191672325"}
0005434879599	FB878E	7933 635484	SERGEY BONDARENKO	{"email": "s.bondarenko.121975@postgrespro.ru", "phone": "+70186290847"}
0005434879600	FB878E	2874 951764	ANASTASIYA POLYAKOVA	{"phone": "+70906189149"}
0005434879601	0747B7	5172 100049	VLADIMIR MIRONOV	{"phone": "+70203274558"}
0005434879602	0747B7	7962 946488	IVAN KUZNECOV	{"phone": "+70506345807"}
0005434879603	15FE79	1345 990522	RUSLAN SIDOROV	{"email": "rsidorov041978@postgrespro.ru", "phone": "+70700183496"}
0005434879604	5D48F4	2260 145096	GLEB EGOROV	{"email": "egorovgleb-1969@postgrespro.ru", "phone": "+70228728148"}
0005434879605	6D4AA6	6469 875562	ALEKSANDR BORISOV	{"phone": "+70900664633"}
0005434879606	6D4AA6	9590 437242	ALEKSANDR EGOROV	{"email": "egorova.21101976@postgrespro.ru", "phone": "+70507506818"}
0005434879607	96A1EF	1656 406960	VALERIY KISELEV	{"phone": "+70517813687"}
0005434879608	5B2BD2	3451 477719	YURIY FOMIN	{"email": "fomin-yuriy-071974@postgrespro.ru", "phone": "+70818582348"}
0005434879609	5B2BD2	6820 627677	TATYANA ZAKHAROVA	{"phone": "+70880206587"}
0005434879610	AD581B	8669 660145	ELVIRA SIDOROVA	{"email": "sidorovaelvira1970@postgrespro.ru", "phone": "+70888822598"}
0005434879611	AD581B	5073 421880	YURIY STEPANOV	{"phone": "+70347989848"}
0005434879612	F2DE26	0784 350160	YAKOV KUZNECOV	{"email": "yakov_kuznecov-08051969@postgrespro.ru", "phone": "+70189239764"}
0005434879613	F2DE26	8905 148023	IGOR OSIPOV	{"email": "igor.osipov-1976@postgrespro.ru", "phone": "+70492412034"}
0005434879614	F2DE26	7963 940518	OKSANA ILINA	{"email": "ilina-oksana-1980@postgrespro.ru", "phone": "+70953212762"}
0005434879615	2259D9	6113 420461	SERGEY BELOV	{"phone": "+70837440418"}
0005434879616	2259D9	9836 608999	VASILIY ANDREEV	{"phone": "+70163021408"}
0005434879617	0A1C0A	3499 030552	ALEKSANDRA KRASNOVA	{"email": "aleksandra-krasnova.22021981@postgrespro.ru", "phone": "+70007133284"}
0005434879618	0A1C0A	9060 413315	VALENTINA OSIPOVA	{"email": "osipova.v101962@postgrespro.ru", "phone": "+70510276075"}
0005434879619	0A1C0A	9078 372635	RINAT SAVELEV	{"phone": "+70020630718"}
0005434879620	7EFBDE	2823 992317	IGOR AFANASEV	{"phone": "+70914656953"}
0005434879621	34266A	4954 150826	IRINA POPOVA	{"phone": "+70553123800"}
0005434879622	55F790	1290 980774	VASILIY SCHERBAKOV	{"email": "scherbakovv22041976@postgrespro.ru", "phone": "+70072938060"}
0005434879623	51A3C4	2093 873568	KSENIYA BORISOVA	{"phone": "+70619366661"}
0005434879624	E0D926	5846 735729	DMITRIY ROMANOV	{"email": "dromanov_12011978@postgrespro.ru", "phone": "+70853047650"}
0005434879625	0999FE	5121 720432	VIKTORIYA SEMENOVA	{"phone": "+70321003821"}
0005434879626	B39B1C	6384 730977	NADEZHDA LEBEDEVA	{"email": "n-lebedeva.121967@postgrespro.ru", "phone": "+70815536421"}
0005434879627	6C9F53	2313 322452	ELENA KARPOVA	{"email": "karpova-e.11021972@postgrespro.ru", "phone": "+70924641612"}
0005434879628	45A8BD	7387 562123	DENIS FOMIN	{"email": "fomin-d.111980@postgrespro.ru", "phone": "+70920784077"}
0005434879629	26C92C	0992 519298	DARYA VOLKOVA	{"phone": "+70844850306"}
0005434879630	26C92C	5987 007285	VALERIYA FOMINA	{"email": "fomina_valeriya.1979@postgrespro.ru", "phone": "+70828299025"}
0005434879631	26C92C	4609 904751	IRINA SOKOLOVA	{"phone": "+70516919268"}
0005434879632	03AE3A	2056 899878	TATYANA FADEEVA	{"email": "t.fadeeva_1971@postgrespro.ru", "phone": "+70560101560"}
0005434879633	F1202B	8290 556225	LYUDMILA MATVEEVA	{"email": "matveevalyudmila.02071976@postgrespro.ru", "phone": "+70861530786"}
0005434879634	F1202B	2249 723147	VASILIY ILIN	{"email": "ilin.v-1972@postgrespro.ru", "phone": "+70894802541"}
0005434879635	1C937D	2618 535571	MARIYA ZOTOVA	{"email": "mariyazotova_20031960@postgrespro.ru", "phone": "+70704713001"}
0005434879636	D2A38B	9565 186659	OLGA ZHURAVLEVA	{"email": "ozhuravleva-19061981@postgrespro.ru", "phone": "+70670698492"}
0005434879637	7C3AA2	3064 007509	MAKSIM SEMENOV	{"email": "semenovmaksim.1972@postgrespro.ru", "phone": "+70976256570"}
0005434879638	7C3AA2	7679 531259	MARINA BORISOVA	{"phone": "+70570063726"}
0005434879639	A74981	7826 095098	DENIS VOLKOV	{"phone": "+70585095040"}
0005434879640	E7F912	6194 229448	OLGA FADEEVA	{"email": "fadeeva_o-081980@postgrespro.ru", "phone": "+70004358536"}
0005434879641	8C79D8	1162 594126	LEONID SCHERBAKOV	{"email": "scherbakov.leonid-1963@postgrespro.ru", "phone": "+70906501386"}
0005434879642	9008D5	0162 235937	NADEZHDA KOZLOVA	{"email": "kozlova.nadezhda.061982@postgrespro.ru", "phone": "+70460527996"}
0005434879643	AD8BEF	3205 822707	LARISA FROLOVA	{"phone": "+70913471371"}
0005434879644	8AE2D9	3106 000258	VLADIMIR ZAYCEV	{"email": "zaycev_vladimir-091972@postgrespro.ru", "phone": "+70961274987"}
0005434879645	92D419	4223 008511	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr101968@postgrespro.ru", "phone": "+70740807103"}
0005434879646	92D419	8748 821099	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev1985@postgrespro.ru", "phone": "+70516087491"}
0005434879647	8E2576	3301 564599	OLEG GAVRILOV	{"email": "oleg.gavrilov1967@postgrespro.ru", "phone": "+70140805211"}
0005434879648	8E2576	3888 775532	VALENTINA VOLKOVA	{"phone": "+70902614694"}
0005434879649	8E2576	7128 272828	ANDREY SERGEEV	{"phone": "+70198438344"}
0005434879650	BB615C	1423 257228	ALEKSANDR DAVYDOV	{"phone": "+70111737159"}
0005434879651	1B1F75	4241 214501	ALENA GORBUNOVA	{"phone": "+70002374669"}
0005434879652	1B1F75	9131 555779	LYUBOV MALYSHEVA	{"email": "malysheva.l27051974@postgrespro.ru", "phone": "+70845425730"}
0005434879653	4C1BEF	7454 740074	MARINA SOROKINA	{"phone": "+70315527500"}
0005434879654	8D8723	0123 314794	GENNADIY BORISOV	{"phone": "+70244938611"}
0005434879655	EC1BF4	2179 549940	VALERIY KULIKOV	{"email": "kulikovv-08051969@postgrespro.ru", "phone": "+70725476348"}
0005434879656	F872B9	7317 752163	ALINA MELNIKOVA	{"email": "melnikova-alina.01121960@postgrespro.ru", "phone": "+70981184139"}
0005434879657	1B6056	8792 073403	MATVEY FILIPPOV	{"email": "m.filippov_08071969@postgrespro.ru", "phone": "+70857889616"}
0005434879658	5F0EE8	9186 765075	ANTONINA KOLESNIKOVA	{"email": "kolesnikovaantonina_08031970@postgrespro.ru", "phone": "+70429509236"}
0005434879659	1121E2	6980 960566	GLEB FEDOROV	{"email": "g-fedorov071977@postgrespro.ru", "phone": "+70629232141"}
0005434879660	A1FB50	3539 999400	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov.071983@postgrespro.ru", "phone": "+70658768822"}
0005434879661	4AC7B1	0208 955370	KRISTINA ABRAMOVA	{"phone": "+70129846542"}
0005434879662	4E5A21	7981 218106	GULNARA LUKYANOVA	{"email": "g.lukyanova_1972@postgrespro.ru", "phone": "+70346306972"}
0005434879663	3C255F	4769 514071	TATYANA KOROLEVA	{"phone": "+70522824317"}
0005434879664	343437	8296 853680	OLGA MIRONOVA	{"phone": "+70220157301"}
0005434879665	12CD94	9171 651225	ANTON ORLOV	{"phone": "+70431702621"}
0005434879666	B052CC	0867 221142	VIKTOR ROMANOV	{"phone": "+70919890601"}
0005434879667	8728C1	4790 123169	IRINA NOVIKOVA	{"email": "novikovairina_091975@postgrespro.ru", "phone": "+70305103562"}
0005434879668	45B4B0	2238 387604	GALINA NESTEROVA	{"phone": "+70757847140"}
0005434879669	6B720B	9289 000837	ELENA NAZAROVA	{"phone": "+70700754329"}
0005434879670	F1B0F3	1678 441917	MILANA KRASNOVA	{"phone": "+70823506918"}
0005434879671	F1B0F3	5635 377791	VADIM KOZLOV	{"phone": "+70158782738"}
0005434879672	EF7A86	1329 027028	KONSTANTIN SCHERBAKOV	{"phone": "+70098534759"}
0005434879673	C5C4A7	4220 409385	DMITRIY IVANOV	{"email": "ivanov_dmitriy26121979@postgrespro.ru", "phone": "+70967656456"}
0005434879674	E5A0DC	9226 146359	BORIS KOZLOV	{"phone": "+70086692053"}
0005434879675	4265B0	3239 990282	DMITRIY ISAEV	{"email": "d-isaev1966@postgrespro.ru", "phone": "+70377948912"}
0005434879676	4265B0	5686 199032	ALEKSANDR STEPANOV	{"phone": "+70287714342"}
0005434879677	51165B	7135 099971	VASILIY DENISOV	{"email": "denisov-vasiliy021974@postgrespro.ru", "phone": "+70300438266"}
0005434879678	2F0A5A	5359 534328	MARYAM ZHURAVLEVA	{"email": "m.zhuravleva-1977@postgrespro.ru", "phone": "+70780059360"}
0005434879679	35D93A	5302 087904	VALENTINA KRASNOVA	{"email": "valentinakrasnova-111986@postgrespro.ru", "phone": "+70414534717"}
0005434879680	35D93A	0116 032925	MIKHAIL ZAKHAROV	{"phone": "+70213903456"}
0005434879681	D9A08D	0964 248179	SERGEY KAZAKOV	{"email": "skazakov-27031985@postgrespro.ru", "phone": "+70812406279"}
0005434879682	D36DE6	7651 828935	SVETLANA OSIPOVA	{"phone": "+70141570838"}
0005434879683	CE3770	1267 792881	DMITRIY ALEKSANDROV	{"email": "daleksandrov.011961@postgrespro.ru", "phone": "+70093687177"}
0005434879684	4D1DB3	4416 677620	SERGEY MARTYNOV	{"email": "martynov_s1980@postgrespro.ru", "phone": "+70421758339"}
0005434879685	4D1DB3	3847 148587	ARTEM POPOV	{"email": "popov.artem_1966@postgrespro.ru", "phone": "+70534813467"}
0005434879686	AB542D	2267 746350	NINA CHERNOVA	{"phone": "+70091549947"}
0005434879687	5A330F	6744 024334	SVETLANA KUDRYASHOVA	{"phone": "+70546016522"}
0005434879688	5A330F	2449 174974	LYUDMILA BARANOVA	{"phone": "+70702863262"}
0005434879689	A550E6	0592 709821	INNA ANDREEVA	{"phone": "+70004763896"}
0005434879690	A550E6	2486 941088	GALINA ORLOVA	{"email": "galinaorlova29081978@postgrespro.ru", "phone": "+70116123842"}
0005434879691	F9E1D6	6571 186492	RAISA AFANASEVA	{"phone": "+70105344704"}
0005434879692	F9E1D6	2174 996037	NINA PETROVA	{"phone": "+70700765894"}
0005434879693	F9E1D6	4642 758152	VALENTINA YUDINA	{"email": "yudinav121972@postgrespro.ru", "phone": "+70000573968"}
0005434879806	C09FA0	2472 299960	NIKITA TARASOV	{"phone": "+70959273778"}
0005434879694	C53087	1530 154604	GALINA KUZNECOVA	{"email": "kuznecovagalina-021972@postgrespro.ru", "phone": "+70050564766"}
0005434879695	C53087	6128 477623	DMITRIY NOVIKOV	{"email": "novikov_d.1970@postgrespro.ru", "phone": "+70016357736"}
0005434879696	154017	4567 448913	NADEZHDA KULIKOVA	{"email": "nadezhdakulikova_30061978@postgrespro.ru", "phone": "+70295077030"}
0005434879697	3B7A89	8414 561443	VADIM MIRONOV	{"email": "mironov_vadim-111975@postgrespro.ru", "phone": "+70167440369"}
0005434879698	3B7A89	3944 292019	NATALYA KUZNECOVA	{"email": "n.kuznecova_13041970@postgrespro.ru", "phone": "+70622525469"}
0005434879699	75E04F	1374 757831	VASILIY DMITRIEV	{"email": "vasiliy.dmitriev-09101971@postgrespro.ru", "phone": "+70914401423"}
0005434879700	43AC28	3833 319736	ANATOLIY ORLOV	{"phone": "+70078000911"}
0005434879701	74045E	1684 044487	ANASTASIYA PETROVA	{"phone": "+70659556460"}
0005434879702	D83514	8168 940196	DMITRIY MATVEEV	{"phone": "+70122764720"}
0005434879703	D83514	6060 552523	IRINA SEMENOVA	{"email": "i.semenova.1968@postgrespro.ru", "phone": "+70167547062"}
0005434879704	D83514	5747 614025	VERA GUSEVA	{"email": "v_guseva-25041972@postgrespro.ru", "phone": "+70989023640"}
0005434879705	8B0E67	8507 496201	EKATERINA AKIMOVA	{"phone": "+70896520686"}
0005434879706	115ED1	2106 475976	OLGA KARPOVA	{"email": "okarpova.081974@postgrespro.ru", "phone": "+70572430739"}
0005434879707	955C09	2268 317746	LYUDMILA FOMINA	{"email": "l-fomina_071972@postgrespro.ru", "phone": "+70666634922"}
0005434879708	616042	1228 032016	SERGEY PETROV	{"email": "spetrov.041975@postgrespro.ru", "phone": "+70824475100"}
0005434879709	C4ED23	9641 378129	ALEKSANDR VOROBEV	{"email": "a-vorobev-111979@postgrespro.ru", "phone": "+70854061905"}
0005434879710	B95251	4647 163317	VALENTINA NAZAROVA	{"email": "nazarova-v.1972@postgrespro.ru", "phone": "+70306845411"}
0005434879711	5B9372	1667 485737	SVETLANA ANDREEVA	{"phone": "+70525523971"}
0005434879712	5B9372	8233 211174	ALEKSANDR SIDOROV	{"email": "sidorov.a_1973@postgrespro.ru", "phone": "+70524240877"}
0005434879713	D7AA4F	2210 768504	KLAVDIYA KRASNOVA	{"email": "krasnova.k031987@postgrespro.ru", "phone": "+70311066709"}
0005434879714	907BD8	3653 173578	NATALYA KOZLOVA	{"phone": "+70076865163"}
0005434879715	907BD8	8766 012769	OLEG DAVYDOV	{"phone": "+70709719052"}
0005434879716	B0E029	6318 318983	ANNA AKIMOVA	{"email": "akimova.a1966@postgrespro.ru", "phone": "+70819930015"}
0005434879717	DA4A4E	4672 018919	TATYANA LUKYANOVA	{"email": "lukyanova.t_1961@postgrespro.ru", "phone": "+70645198481"}
0005434879718	DA4A4E	8801 700142	NIKOLAY SERGEEV	{"phone": "+70723001159"}
0005434879719	248E77	8985 114013	KHALIDA KUZNECOVA	{"email": "kuznecova.k12111978@postgrespro.ru", "phone": "+70972188166"}
0005434880200	F3C96D	4558 121530	ANDREY IVANOV	{"phone": "+70341800845"}
0005434879720	6E46A8	1270 869682	ALEKSANDR BELOV	{"email": "aleksandrbelov_1961@postgrespro.ru", "phone": "+70307155001"}
0005434879721	EF6ED8	5969 923650	IRINA KONOVALOVA	{"phone": "+70026379195"}
0005434879722	C59CEC	8772 914337	MARINA IVANOVA	{"phone": "+70351180348"}
0005434879723	117D42	8423 400264	YURIY ORLOV	{"phone": "+70258903820"}
0005434879724	284A53	3201 662270	VLADIMIR SMIRNOV	{"phone": "+70068211522"}
0005434879725	6FDAF1	5807 953200	ANASTASIYA DMITRIEVA	{"phone": "+70077590295"}
0005434879726	D7ACB0	6428 831141	VIKTOR NIKOLAEV	{"email": "v_nikolaev.021973@postgrespro.ru", "phone": "+70987526898"}
0005434879727	D7ACB0	6525 952378	ELENA RODIONOVA	{"email": "rodionova.elena-1966@postgrespro.ru", "phone": "+70480011540"}
0005434879728	CD40C8	8010 614128	EDUARD IVANOV	{"email": "ivanoveduard.19101980@postgrespro.ru", "phone": "+70467148762"}
0005434879729	22CB85	3569 893859	ALEKSEY ZAKHAROV	{"phone": "+70861278773"}
0005434879730	22CB85	0003 964928	TAMARA VLASOVA	{"phone": "+70167399695"}
0005434879731	22CB85	8909 599011	TATYANA KONDRATEVA	{"email": "tatyana-kondrateva.1964@postgrespro.ru", "phone": "+70789904732"}
0005434879732	EB1D39	4337 913759	IVAN AFANASEV	{"phone": "+70719949006"}
0005434879733	EB1D39	3607 508576	SVETLANA LOGINOVA	{"phone": "+70363877883"}
0005434879734	D439C4	5527 970867	ALEKSANDRA MAKAROVA	{"phone": "+70729479529"}
0005434879735	2F452C	4579 391363	MIKHAIL BELOV	{"phone": "+70951587580"}
0005434879736	A5A1F7	2178 553487	VALENTINA EGOROVA	{"email": "egorova.v02011984@postgrespro.ru", "phone": "+70191130911"}
0005434879737	C3CC9A	6734 301821	LYUBOV FEDOROVA	{"phone": "+70562873211"}
0005434879738	ADAACF	7613 107684	ANDREY STEPANOV	{"phone": "+70953261578"}
0005434879739	AE5718	7880 718874	NATALYA PAVLOVA	{"phone": "+70803914165"}
0005434879740	AE5718	0138 890459	DMITRIY VOLKOV	{"email": "volkov_d-1968@postgrespro.ru", "phone": "+70163010162"}
0005434879741	082B30	0860 994962	IVAN GUSEV	{"email": "gusevi_1954@postgrespro.ru", "phone": "+70146142636"}
0005434879742	DF1596	7270 649996	EVGENIY YAKOVLEV	{"email": "yakovlevevgeniy.111973@postgrespro.ru", "phone": "+70637019295"}
0005434879743	A03DC7	5987 895575	ALEKSANDR IVANOV	{"phone": "+70800826979"}
0005434879744	E8FB46	3572 403353	GALINA NIKOLAEVA	{"email": "galina_nikolaeva.1978@postgrespro.ru", "phone": "+70975615523"}
0005434879745	37BEC5	6295 856132	SOFIYA KALININA	{"phone": "+70961446348"}
0005434879746	59A32E	3854 281838	NATALYA TIKHONOVA	{"email": "tikhonovan09081971@postgrespro.ru", "phone": "+70726269809"}
0005434879747	59A32E	6842 263584	VLADIMIR ZAKHAROV	{"phone": "+70044122956"}
0005434879748	2AA306	4957 828209	EKATERINA BORISOVA	{"phone": "+70344798038"}
0005434879749	2AA306	9703 767256	GALINA SCHERBAKOVA	{"email": "galina-scherbakova12041974@postgrespro.ru", "phone": "+70933346151"}
0005434879750	B3D4B5	7068 292444	LIDIYA LEBEDEVA	{"email": "lebedeva.l_091975@postgrespro.ru", "phone": "+70583820936"}
0005434879751	4C14DD	6278 253344	ALEKSANDR MAKAROV	{"phone": "+70169386438"}
0005434879752	38B6C5	7468 057156	TATYANA KULIKOVA	{"email": "kulikovatatyana_21101979@postgrespro.ru", "phone": "+70799657074"}
0005434879753	38B6C5	6354 350071	ALEKSANDR BORISOV	{"email": "a_borisov.1976@postgrespro.ru", "phone": "+70487586660"}
0005434879754	D735A6	0755 221618	VIKTOR OSIPOV	{"email": "osipovviktor.081972@postgrespro.ru", "phone": "+70281763313"}
0005434879755	D735A6	3061 734345	SERGEY ILIN	{"phone": "+70553997363"}
0005434879756	1FBE36	1937 774780	SERGEY ANDREEV	{"phone": "+70130744826"}
0005434879757	A0E19D	2278 857129	NIKOLAY GORBUNOV	{"phone": "+70336069803"}
0005434879758	BEBFA8	2839 054920	ALEKSANDRA BORISOVA	{"email": "borisovaaleksandra-06011973@postgrespro.ru", "phone": "+70010231171"}
0005434879759	BEBFA8	8866 881170	EVGENIY NOVIKOV	{"email": "novikov.e.1977@postgrespro.ru", "phone": "+70278170700"}
0005434879760	BEBFA8	2248 771712	LARISA NAZAROVA	{"phone": "+70570286085"}
0005434879761	0C12A8	0937 742952	ELENA YUDINA	{"email": "elena.yudina.08011977@postgrespro.ru", "phone": "+70997683883"}
0005434879762	D2DB97	6793 620991	ANASTASIYA ILINA	{"email": "a_ilina1967@postgrespro.ru", "phone": "+70098543014"}
0005434879763	D2DB97	9952 917581	SERGEY GRIGOREV	{"phone": "+70828688738"}
0005434879764	D2DB97	5364 478235	ANNA ZHUKOVA	{"email": "a-zhukova-1972@postgrespro.ru", "phone": "+70347848301"}
0005434879765	5C9205	0991 778525	IRINA NESTEROVA	{"email": "i-nesterova_06101967@postgrespro.ru", "phone": "+70166591428"}
0005434879766	611D42	7040 512117	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr_1971@postgrespro.ru", "phone": "+70319635847"}
0005434879767	611D42	9322 772362	OLGA ISAEVA	{"phone": "+70670011452"}
0005434879768	BCB926	6062 718452	VASILIY NOVIKOV	{"phone": "+70979884764"}
0005434879769	BCB926	1006 413058	MAKSIM NOVIKOV	{"email": "mnovikov-1975@postgrespro.ru", "phone": "+70304265466"}
0005434879770	37C519	1987 268960	IVAN ISAEV	{"email": "isaevi-1971@postgrespro.ru", "phone": "+70567452843"}
0005434879771	E0DF55	8811 439367	NATALYA MIKHAYLOVA	{"phone": "+70483780556"}
0005434879772	E0DF55	5737 225903	AIDA EFREMOVA	{"phone": "+70481784251"}
0005434879773	74675A	1454 478777	INNA SOLOVEVA	{"email": "inna-soloveva091979@postgrespro.ru", "phone": "+70470432718"}
0005434879774	72C8BE	7278 155459	ANDREY VOLKOV	{"phone": "+70146421336"}
0005434879775	72C8BE	8854 698839	ANDREY OSIPOV	{"email": "osipov-andrey06051973@postgrespro.ru", "phone": "+70658280686"}
0005434879776	E8D69E	3703 392389	VALERIY EGOROV	{"phone": "+70672922469"}
0005434879777	452C3A	3098 895393	KIRILL FEDOTOV	{"email": "fedotov.k02061969@postgrespro.ru", "phone": "+70324838582"}
0005434879778	452C3A	9694 870903	VLADIMIR KOROLEV	{"phone": "+70316493151"}
0005434879779	687941	2827 081247	VLADIMIR MEDVEDEV	{"phone": "+70053439527"}
0005434879780	687941	7116 363676	SERGEY ZHUKOV	{"phone": "+70117376414"}
0005434879781	BBE132	5366 042486	OLGA STEPANOVA	{"phone": "+70028112221"}
0005434879782	BBE132	4465 141572	FARID RODIONOV	{"email": "frodionov-06091977@postgrespro.ru", "phone": "+70850681329"}
0005434879783	BBE132	8815 172630	ALLA NIKIFOROVA	{"email": "nikiforovaalla051971@postgrespro.ru", "phone": "+70504694936"}
0005434879784	013DD8	9803 018975	ALEKSANDR VASILEV	{"email": "vasilev.aleksandr_081972@postgrespro.ru", "phone": "+70864384267"}
0005434879785	2D2840	5638 712786	YURIY VASILEV	{"email": "yuriy_vasilev-051967@postgrespro.ru", "phone": "+70171835979"}
0005434879786	2D2840	6014 814348	DARYA LOGINOVA	{"email": "loginova.darya.12081975@postgrespro.ru", "phone": "+70581400849"}
0005434879787	F8727D	6634 110154	VLADIMIR CHERNOV	{"email": "v.chernov_011974@postgrespro.ru", "phone": "+70549671585"}
0005434879788	F8727D	1419 879852	TAMARA MATVEEVA	{"email": "tmatveeva021971@postgrespro.ru", "phone": "+70980920188"}
0005434879789	BEA21C	9621 706798	DMITRIY SOROKIN	{"email": "sorokin-dmitriy.1961@postgrespro.ru", "phone": "+70427197538"}
0005434879790	4FE2C4	2704 432434	VALERIY MATVEEV	{"email": "valeriy-matveev.1966@postgrespro.ru", "phone": "+70293552564"}
0005434879791	4FE2C4	4670 279865	VLADIMIR NIKOLAEV	{"email": "nikolaev.v091975@postgrespro.ru", "phone": "+70311699436"}
0005434879792	CFAC95	7051 418996	ALEKSANDR TIKHONOV	{"phone": "+70142236824"}
0005434879793	CFAC95	5073 485846	ZINAIDA KOROLEVA	{"email": "z.koroleva1974@postgrespro.ru", "phone": "+70661628282"}
0005434879794	844569	2596 984615	IVAN GUSEV	{"phone": "+70013637368"}
0005434879795	844569	7133 417084	IGOR NOVIKOV	{"phone": "+70172549779"}
0005434879796	F6DDC7	3746 566233	ANDREY SERGEEV	{"email": "andreysergeev-1986@postgrespro.ru", "phone": "+70488391708"}
0005434879797	EAF0FA	5313 115997	LYUDMILA KULIKOVA	{"phone": "+70591654473"}
0005434879798	1ABA54	7950 733252	VLADIMIR MOROZOV	{"phone": "+70158740529"}
0005434879799	689107	3086 875947	VALENTINA KOZLOVA	{"phone": "+70851989147"}
0005434879800	689107	8936 940960	LYUDMILA FROLOVA	{"phone": "+70401372298"}
0005434879801	061619	6952 050828	VALENTIN ZAKHAROV	{"phone": "+70252616789"}
0005434879802	A90F61	1862 954638	MARTA MATVEEVA	{"email": "matveeva-marta.1977@postgrespro.ru", "phone": "+70353131321"}
0005434879803	EB8878	4630 162376	EKATERINA KOROLEVA	{"email": "koroleva.e061965@postgrespro.ru", "phone": "+70340348001"}
0005434879804	EB8878	2538 959819	ELENA KUZNECOVA	{"phone": "+70772728293"}
0005434879805	C09FA0	3854 886111	ELENA TIKHONOVA	{"phone": "+70561443417"}
0005434879807	F0D087	2473 777766	ALEKSEY IVANOV	{"phone": "+70524956614"}
0005434879808	9BCA9F	6411 564320	NIKOLAY SOKOLOV	{"phone": "+70172377449"}
0005434879809	120DEC	4339 988086	TATYANA TARASOVA	{"email": "tatyana.tarasova-01011966@postgrespro.ru", "phone": "+70749009037"}
0005434879810	6EEB68	6241 050923	ALEKSANDR KUZNECOV	{"email": "a-kuznecov02111983@postgrespro.ru", "phone": "+70556939836"}
0005434879811	6EEB68	7625 312654	NATALYA NIKITINA	{"phone": "+70060105787"}
0005434879812	5F2734	6665 940161	DMITRIY NIKOLAEV	{"email": "nikolaev-dmitriy1965@postgrespro.ru", "phone": "+70985809612"}
0005434879813	AD8A85	6592 826351	OLGA TIKHONOVA	{"email": "tikhonova.olga111976@postgrespro.ru", "phone": "+70747533481"}
0005434879814	2454E0	7260 899261	LYUBOV NAUMOVA	{"phone": "+70233312766"}
0005434879815	2454E0	1636 673699	TIMOFEY SOKOLOV	{"email": "sokolov.timofey.071981@postgrespro.ru", "phone": "+70269251852"}
0005434879816	1A176A	2089 831988	IRINA NIKITINA	{"phone": "+70345031900"}
0005434879817	1A176A	2237 288477	DIANA KUZNECOVA	{"email": "d-kuznecova_1972@postgrespro.ru", "phone": "+70459413462"}
0005434879818	09D4EA	9523 944759	ALEKSANDR MAKSIMOV	{"phone": "+70260360221"}
0005434879819	09D4EA	5880 242339	LIDIYA TARASOVA	{"email": "l.tarasova1976@postgrespro.ru", "phone": "+70274869118"}
0005434879820	25D780	3213 209829	GULSHAT POTAPOVA	{"email": "g-potapova061977@postgrespro.ru", "phone": "+70516489328"}
0005434879821	E0AEAF	8142 670160	VLADISLAV ILIN	{"phone": "+70084536622"}
0005434879822	FD853B	1489 408563	TATYANA KUZMINA	{"email": "t.kuzmina081977@postgrespro.ru", "phone": "+70347605655"}
0005434879823	FD853B	7869 608283	EVGENIY SEMENOV	{"email": "semenov-e1974@postgrespro.ru", "phone": "+70034979948"}
0005434879824	17C701	4251 426457	ALEKSANDR BORISOV	{"email": "borisov-a101975@postgrespro.ru", "phone": "+70273301470"}
0005434879825	17C701	5905 026500	ANASTASIYA BELYAEVA	{"phone": "+70234519234"}
0005434879826	57A857	7518 671256	ANATOLIY KARPOV	{"email": "a-karpov-121962@postgrespro.ru", "phone": "+70112138877"}
0005434879827	23F43B	1863 815183	TATYANA FEDOROVA	{"phone": "+70347388504"}
0005434879828	B19B69	2220 419471	SERGEY ALEKSANDROV	{"email": "sergey.aleksandrov23031973@postgrespro.ru", "phone": "+70661334967"}
0005434879829	8E1DB1	3311 591404	NINA GERASIMOVA	{"email": "nina_gerasimova_051972@postgrespro.ru", "phone": "+70527342083"}
0005434879830	8E1DB1	4296 105407	VLADISLAV MAKSIMOV	{"email": "v_maksimov091968@postgrespro.ru", "phone": "+70888418164"}
0005434879831	8E1DB1	2617 498879	RAISA STEPANOVA	{"email": "stepanova-r.081971@postgrespro.ru", "phone": "+70835323390"}
0005434879832	FDD3BA	7323 746717	MAKSIM FROLOV	{"email": "m_frolov.041974@postgrespro.ru", "phone": "+70487936425"}
0005434879833	FDD3BA	2026 608934	ANTON SMIRNOV	{"email": "anton_smirnov061971@postgrespro.ru", "phone": "+70349959109"}
0005434879834	9CFA1E	5627 847349	ANNA ANDREEVA	{"email": "andreeva_a1979@postgrespro.ru", "phone": "+70110009071"}
0005434879835	E0CE2A	9818 887858	EKATERINA IVANOVA	{"phone": "+70688426674"}
0005434879836	E0CE2A	3265 486907	ELENA POPOVA	{"email": "elena_popova011970@postgrespro.ru", "phone": "+70997497127"}
0005434879837	947D5D	4567 507427	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov.1972@postgrespro.ru", "phone": "+70526717948"}
0005434879838	947D5D	2506 142929	ANATOLIY STEPANOV	{"phone": "+70874872501"}
0005434879839	CF39F7	5752 373419	KLAVDIYA FILIPPOVA	{"email": "klavdiya_filippova-051974@postgrespro.ru", "phone": "+70830972049"}
0005434879840	123176	9156 527947	DENIS ZAYCEV	{"email": "zaycev-d.13101981@postgrespro.ru", "phone": "+70878640594"}
0005434879841	DC7FB7	8701 784957	VIKTOR SOKOLOV	{"email": "sokolovviktor-16091966@postgrespro.ru", "phone": "+70700723274"}
0005434879842	530DD5	6825 754249	KSENIYA NIKOLAEVA	{"phone": "+70830587990"}
0005434879843	530DD5	3685 447682	LIDIYA BORISOVA	{"phone": "+70843476987"}
0005434879844	6BB292	5487 246119	YURIY BARANOV	{"phone": "+70683300767"}
0005434879845	6BB292	1704 394707	NATALYA SMIRNOVA	{"phone": "+70233738940"}
0005434879846	678782	5873 069501	SERGEY MELNIKOV	{"email": "s-melnikov011969@postgrespro.ru", "phone": "+70331794521"}
0005434879847	678782	9169 311909	ANDREY ZHURAVLEV	{"phone": "+70560457599"}
0005434879848	9D7774	7855 247206	YAKOV IVANOV	{"email": "ivanov_yakov30091985@postgrespro.ru", "phone": "+70776128867"}
0005434879849	9D7774	0632 979206	ANNA STEPANOVA	{"phone": "+70474415462"}
0005434879850	6E4537	4307 298475	OLEG OSIPOV	{"email": "o-osipov-071984@postgrespro.ru", "phone": "+70330111305"}
0005434879851	300B13	1172 951824	TATYANA RYABOVA	{"phone": "+70974115593"}
0005434879852	300B13	6901 809459	ANASTASIYA KOROLEVA	{"phone": "+70798209499"}
0005434879853	049F6E	1953 522475	ALEKSANDR FEDOROV	{"phone": "+70254923047"}
0005434879854	049F6E	9405 735582	NIKOLAY IVANOV	{"phone": "+70327587773"}
0005434879855	99C258	4669 407580	NATALYA IVANOVA	{"phone": "+70314783276"}
0005434879856	99C258	8193 270303	PETR MAKSIMOV	{"email": "petrmaksimov.061963@postgrespro.ru", "phone": "+70333473621"}
0005434879857	F3147B	2037 467778	NADEZHDA MAKAROVA	{"email": "n-makarova_091966@postgrespro.ru", "phone": "+70984344369"}
0005434879858	4C3F07	0645 908492	ALEKSANDR EGOROV	{"email": "egorova.071976@postgrespro.ru", "phone": "+70978101707"}
0005434879859	4C3F07	8463 321501	NADEZHDA TIKHONOVA	{"phone": "+70114254646"}
0005434879860	B9F8CB	9021 234880	ELIZAVETA POPOVA	{"phone": "+70429667559"}
0005434879861	BF64EF	4053 457360	LUIZA POTAPOVA	{"email": "luizapotapova.061969@postgrespro.ru", "phone": "+70330212790"}
0005434879862	2AF8D0	9397 715459	YURIY SIDOROV	{"email": "yuriy.sidorov-1968@postgrespro.ru", "phone": "+70743986534"}
0005434879863	D1EE2A	0122 436989	ANNA IVANOVA	{"email": "a-ivanova_1958@postgrespro.ru", "phone": "+70038619831"}
0005434879864	D1EE2A	7513 247912	ANDREY KUDRYASHOV	{"email": "kudryashov.a.1976@postgrespro.ru", "phone": "+70137402865"}
0005434879865	0C125F	9682 456669	VIKTORIYA MEDVEDEVA	{"phone": "+70356633346"}
0005434879866	27D5F2	2505 701973	MARGARITA KUZNECOVA	{"email": "kuznecova.margarita1966@postgrespro.ru", "phone": "+70867347859"}
0005434879867	44EEA9	4328 957443	NAIL MIKHAYLOV	{"phone": "+70912294971"}
0005434879868	C7A5A4	1935 988689	IRINA VOLKOVA	{"email": "volkova_irina071974@postgrespro.ru", "phone": "+70556787239"}
0005434879869	CCB534	4465 222967	OLGA STEPANOVA	{"phone": "+70486997679"}
0005434879870	7AA919	0571 541611	ANASTASIYA ANTONOVA	{"phone": "+70861872208"}
0005434879871	E32C85	6744 601858	ALEKSANDR VASILEV	{"phone": "+70944577332"}
0005434879872	D8906F	7525 699171	OKSANA KUZMINA	{"email": "kuzmina-o-1979@postgrespro.ru", "phone": "+70559749031"}
0005434879873	7D80A2	8435 989728	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov.28091964@postgrespro.ru", "phone": "+70133161890"}
0005434879874	7D80A2	7463 356359	OLGA YUDINA	{"email": "o_yudina-1980@postgrespro.ru", "phone": "+70415965351"}
0005434879875	7D80A2	2533 221309	VERA KUZNECOVA	{"phone": "+70374375323"}
0005434879876	DF36DB	1663 733487	YULIYA NIKITINA	{"phone": "+70294982219"}
0005434879877	2E3DDD	2030 980732	ALEKSANDR SOROKIN	{"phone": "+70755042516"}
0005434879878	2E3DDD	2081 608147	KSENIYA VOLKOVA	{"phone": "+70355539289"}
0005434879879	249B94	9869 141218	VALENTINA MIRONOVA	{"phone": "+70970204165"}
0005434879880	C5E256	8190 609930	VASILIY KULIKOV	{"phone": "+70400254796"}
0005434879881	82E7E7	4607 856449	ARTEM VASILEV	{"phone": "+70084562280"}
0005434879882	8DA32F	2703 592813	YAROSLAV ZHURAVLEV	{"phone": "+70830552603"}
0005434879883	1F3384	5118 684059	ALEKSANDR POPOV	{"phone": "+70677589107"}
0005434879884	B59E79	8657 650217	YULIYA TIKHONOVA	{"phone": "+70184714200"}
0005434879885	D2EA90	3534 881677	NATALYA ORLOVA	{"phone": "+70616148443"}
0005434879886	D2EA90	2056 116395	ANATOLIY NAZAROV	{"phone": "+70600680483"}
0005434879887	2DA19D	1463 450943	SERGEY FOMIN	{"email": "fomin.s.1973@postgrespro.ru", "phone": "+70221688214"}
0005434879888	2BC49E	0520 298568	NIKOLAY NAZAROV	{"phone": "+70230975507"}
0005434879889	2BC49E	2874 300247	POLINA KUZNECOVA	{"phone": "+70725173373"}
0005434879890	6526C7	7214 440378	DMITRIY IVANOV	{"email": "ivanov-d.1973@postgrespro.ru", "phone": "+70175451398"}
0005434879891	1D1A3D	0133 518671	NIKITA VOLKOV	{"phone": "+70164956997"}
0005434879892	1D1A3D	6642 222370	VIKTOR AFANASEV	{"email": "afanasevv_1971@postgrespro.ru", "phone": "+70142284552"}
0005434879893	62A9BF	2567 149252	POLINA YUDINA	{"email": "yudina-p.05071963@postgrespro.ru", "phone": "+70437892353"}
0005434879894	6570D9	6507 731454	NADEZHDA KULIKOVA	{"phone": "+70684852130"}
0005434879895	00FD79	8527 666134	ALEKSANDR MOROZOV	{"email": "a_morozov.03081978@postgrespro.ru", "phone": "+70614033333"}
0005434879896	C1824A	3119 179065	OLGA CHERNOVA	{"email": "olga_chernova.25121970@postgrespro.ru", "phone": "+70710531144"}
0005434879897	4375E0	8537 207486	ALEKSANDR NAZAROV	{"email": "nazarov_aleksandr.071964@postgrespro.ru", "phone": "+70356035912"}
0005434879898	21706A	0276 192309	ANATOLIY ISAEV	{"phone": "+70221011858"}
0005434879899	4B7D85	9548 269857	VASILIY KAZAKOV	{"email": "vasiliy_kazakov.03101975@postgrespro.ru", "phone": "+70416228643"}
0005434879900	3AB395	5408 895538	GALINA SIDOROVA	{"phone": "+70166971946"}
0005434879901	515FD9	6742 617149	VALENTINA MATVEEVA	{"phone": "+70653552154"}
0005434879902	29A8D2	2661 756461	TATYANA GERASIMOVA	{"email": "gerasimova-tatyana-07041973@postgrespro.ru", "phone": "+70072049190"}
0005434879903	74CDEE	5622 466431	FATIMA ILINA	{"phone": "+70287091797"}
0005434879904	74CDEE	7683 669170	EVGENIY ANDREEV	{"email": "evgeniy_andreev-22051972@postgrespro.ru", "phone": "+70425709560"}
0005434879905	EE3389	1886 076068	TAMARA FEDOROVA	{"phone": "+70877465443"}
0005434879906	EE3389	9414 701245	RAISA EGOROVA	{"phone": "+70900677945"}
0005434879907	EE3389	5391 491731	NADEZHDA KOZLOVA	{"email": "kozlovan-1970@postgrespro.ru", "phone": "+70735163707"}
0005434879908	EE1494	0097 828666	ALEKSEY ZHUKOV	{"phone": "+70765569991"}
0005434879909	EE1494	3616 136435	OLGA NOVIKOVA	{"email": "novikova.o_1970@postgrespro.ru", "phone": "+70626284604"}
0005434879910	EE1494	4324 329002	ALEKSANDR KOZLOV	{"phone": "+70763067003"}
0005434879911	5BC784	3604 270782	EVGENIY POPOV	{"phone": "+70092610632"}
0005434879912	5BC784	9251 110935	ELENA BARANOVA	{"email": "e_baranova121975@postgrespro.ru", "phone": "+70011011211"}
0005434879913	080E42	1092 047683	KAPITALINA MELNIKOVA	{"email": "kapitalina-melnikova24051981@postgrespro.ru", "phone": "+70126054439"}
0005434879914	080E42	1844 869862	ALEKSANDR BARANOV	{"email": "baranov_a-1972@postgrespro.ru", "phone": "+70949077196"}
0005434879915	3E51D8	8905 859771	SERGEY VASILEV	{"email": "sergey-vasilev-101964@postgrespro.ru", "phone": "+70159476634"}
0005434879916	7F92D7	7356 186173	ANNA GRISHINA	{"phone": "+70924750651"}
0005434879917	43DFDE	2516 596853	SERGEY KRASNOV	{"email": "sergey_krasnov-22041979@postgrespro.ru", "phone": "+70709924431"}
0005434879918	43DFDE	6315 658097	TATYANA VOROBEVA	{"email": "tvorobeva.23061985@postgrespro.ru", "phone": "+70404549364"}
0005434879919	28410D	7568 484932	EVGENIY KOROLEV	{"phone": "+70637909466"}
0005434879920	28410D	5098 432246	ARTEM NOVIKOV	{"phone": "+70042672642"}
0005434879921	16BA72	3799 685708	ELENA PAVLOVA	{"email": "e-pavlova-111976@postgrespro.ru", "phone": "+70913714247"}
0005434879922	AD742E	2264 660285	DMITRIY IVANOV	{"phone": "+70113263001"}
0005434879923	AD742E	0656 720307	ANTON VLASOV	{"phone": "+70865002418"}
0005434879924	89C105	1133 483212	ANASTASIYA VLASOVA	{"email": "vlasova-a_14121958@postgrespro.ru", "phone": "+70028144103"}
0005434879925	89C105	4606 845362	ALEKSANDR GORBUNOV	{"email": "a-gorbunov_1982@postgrespro.ru", "phone": "+70044273400"}
0005434879926	89C105	3115 932160	DMITRIY SOKOLOV	{"email": "dmitriy.sokolov.24031967@postgrespro.ru", "phone": "+70816364473"}
0005434879927	8BF6F4	4921 403389	SERGEY SCHERBAKOV	{"email": "scherbakov_sergey111972@postgrespro.ru", "phone": "+70949158120"}
0005434879928	AA5409	9445 567463	MIKHAIL KRASNOV	{"email": "m.krasnov29061964@postgrespro.ru", "phone": "+70252557866"}
0005434879929	630BAB	7130 668699	ALEKSANDR KRASNOV	{"phone": "+70903809469"}
0005434879930	163532	4832 653845	VALERIY MOISEEV	{"email": "moiseev_v.29031967@postgrespro.ru", "phone": "+70341312611"}
0005434879931	4E2FDB	7016 691392	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov-1971@postgrespro.ru", "phone": "+70697405943"}
0005434879932	B1057C	1294 327520	MIKHAIL CHERNOV	{"phone": "+70949386637"}
0005434879933	CE0ED3	4222 559111	ANATOLIY SOROKIN	{"phone": "+70229714139"}
0005434879934	323CE9	9964 229018	NATALYA ISAEVA	{"email": "natalya.isaeva071960@postgrespro.ru", "phone": "+70968026735"}
0005434879935	9FE59E	7921 314600	FARIDA TARASOVA	{"email": "tarasova.f1966@postgrespro.ru", "phone": "+70707442692"}
0005434879936	9FE59E	4780 627401	KRISTINA NIKITINA	{"phone": "+70631011424"}
0005434879937	DEE2C3	4850 094123	VLADISLAV KRASNOV	{"email": "vkrasnov_26011975@postgrespro.ru", "phone": "+70060575504"}
0005434879938	DEE2C3	3732 407412	MAKSIM NIKOLAEV	{"email": "m-nikolaev19011985@postgrespro.ru", "phone": "+70078416150"}
0005434879939	1E02E4	0033 454443	ALEKSANDR KISELEV	{"phone": "+70337213493"}
0005434879940	32A318	9830 545896	ALEKSANDR MAKAROV	{"phone": "+70565818587"}
0005434879941	32A318	2718 843897	YULIYA BELOVA	{"phone": "+70401597203"}
0005434879942	BD33A2	1658 287712	ALEKSEY MOROZOV	{"phone": "+70617125867"}
0005434879943	E1D806	1368 221902	KONSTANTIN MIKHAYLOV	{"phone": "+70271291897"}
0005434879944	E1D806	5567 767741	VLADIMIR DMITRIEV	{"phone": "+70491968109"}
0005434879945	E1D806	6826 293632	NADEZHDA IVANOVA	{"phone": "+70120511515"}
0005434879946	257B9B	8470 087737	KSENIYA KUZMINA	{"email": "k_kuzmina.05081978@postgrespro.ru", "phone": "+70954546311"}
0005434879947	210972	1896 292091	DMITRIY KUZNECOV	{"phone": "+70871850033"}
0005434879948	DC44FF	2851 372760	SERGEY VOLKOV	{"phone": "+70013258509"}
0005434879949	DC44FF	2591 320707	SERGEY ANTONOV	{"phone": "+70635552057"}
0005434879950	ADE5A3	2275 499931	VALENTINA LOGINOVA	{"email": "valentina_loginova051979@postgrespro.ru", "phone": "+70316081408"}
0005434879951	ADE5A3	1719 644847	OLEG ILIN	{"email": "oilin_1974@postgrespro.ru", "phone": "+70232903775"}
0005434879952	6AA54E	1393 042084	ALEKSEY FROLOV	{"phone": "+70149197065"}
0005434879953	6AA54E	7145 741003	VERA GUSEVA	{"email": "guseva_vera_23061971@postgrespro.ru", "phone": "+70831283724"}
0005434879954	42BBB2	2119 858279	ALEKSANDR PETROV	{"phone": "+70325718703"}
0005434879955	39691A	4043 247999	TATYANA LOGINOVA	{"email": "t-loginova031972@postgrespro.ru", "phone": "+70957894872"}
0005434879956	E95F7E	2617 599334	SVETLANA KUZNECOVA	{"email": "svetlana.kuznecova_071973@postgrespro.ru", "phone": "+70025774279"}
0005434879957	6A058A	3669 328020	ANASTASIYA MELNIKOVA	{"phone": "+70245109627"}
0005434879958	805BEF	3569 942401	NADEZHDA KUZNECOVA	{"email": "kuznecova_n-011976@postgrespro.ru", "phone": "+70831917649"}
0005434879959	805BEF	9586 480328	ELENA SEMENOVA	{"email": "semenova.e.041976@postgrespro.ru", "phone": "+70475250658"}
0005434879960	27597D	3983 505300	MARIYA MOISEEVA	{"email": "m-moiseeva031966@postgrespro.ru", "phone": "+70144317480"}
0005434879961	15AB66	4202 786274	LYUBOV MAKAROVA	{"phone": "+70828253058"}
0005434879962	15AB66	9780 297243	OLGA BARANOVA	{"email": "baranovao-1974@postgrespro.ru", "phone": "+70090092734"}
0005434879963	13AFE3	6174 137200	VLADIMIR FEDOROV	{"email": "vfedorov.31081969@postgrespro.ru", "phone": "+70106668871"}
0005434879964	F596E6	1312 245011	KSENIYA FILATOVA	{"email": "k.filatova1974@postgrespro.ru", "phone": "+70262701530"}
0005434879965	F596E6	6007 113568	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_09121974@postgrespro.ru", "phone": "+70498200489"}
0005434879966	EAAB46	0433 111530	ALEKSEY KOZLOV	{"email": "kozlov_a_11051962@postgrespro.ru", "phone": "+70980029692"}
0005434879967	40F8DE	1220 332042	ANDREY KRASNOV	{"email": "andreykrasnov.1964@postgrespro.ru", "phone": "+70730666289"}
0005434879968	FA6DE2	3391 042885	IGOR BORISOV	{"email": "borisov_igor.05051984@postgrespro.ru", "phone": "+70411621085"}
0005434879969	C9DF80	9821 018684	KIRILL MIKHAYLOV	{"email": "k_mikhaylov011967@postgrespro.ru", "phone": "+70651351503"}
0005434879970	C8F2FC	6640 639762	ALEKSANDR FROLOV	{"email": "frolov_a.101965@postgrespro.ru", "phone": "+70007033242"}
0005434879971	C8F2FC	4491 705496	SERGEY YAKOVLEV	{"email": "yakovlev_sergey.101978@postgrespro.ru", "phone": "+70897953412"}
0005434879972	403BAF	5273 153899	KAMIL ZAKHAROV	{"email": "zakharov-kamil1975@postgrespro.ru", "phone": "+70480308160"}
0005434879973	403BAF	2313 005231	GALINA KRASNOVA	{"email": "krasnova_g_02011975@postgrespro.ru", "phone": "+70555261186"}
0005434879974	58B9F5	2160 287097	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey_1977@postgrespro.ru", "phone": "+70610860276"}
0005434879975	7D771D	0881 200963	VLADIMIR ROMANOV	{"email": "romanov-vladimir-1980@postgrespro.ru", "phone": "+70369451771"}
0005434879976	FFE143	6715 762115	VIKTOR SHEVCHENKO	{"phone": "+70471467157"}
0005434879977	46DDF8	4450 178901	ELENA SERGEEVA	{"phone": "+70595707861"}
0005434879978	DA94BA	1571 567968	ULYANA POPOVA	{"phone": "+70072872017"}
0005434879979	1E64D7	3841 372551	ALENA NOVIKOVA	{"email": "alena.novikova15041966@postgrespro.ru", "phone": "+70248246378"}
0005434879980	C40CAD	2304 829381	LILIYA GRISHINA	{"phone": "+70540430868"}
0005434879981	382421	7535 189630	TATYANA TARASOVA	{"phone": "+70365687642"}
0005434879982	D384B3	6235 347562	VALENTINA ANDREEVA	{"phone": "+70328361419"}
0005434879983	D384B3	5331 110667	VLADIMIR ANDREEV	{"email": "vladimir-andreev031962@postgrespro.ru", "phone": "+70699907503"}
0005434879984	01E22A	1009 483211	SERGEY NAUMOV	{"email": "sergey.naumov041974@postgrespro.ru", "phone": "+70239251214"}
0005434879985	774325	0199 931754	ALEKSEY TIMOFEEV	{"phone": "+70393890430"}
0005434879986	B93698	4617 995332	NATALYA FILIPPOVA	{"phone": "+70495473695"}
0005434879987	1D5C2C	5268 475078	MARIYA KUZMINA	{"phone": "+70974424679"}
0005434879988	6B2392	3796 221538	LYUBOV IVANOVA	{"email": "lyubov-ivanova.04031974@postgrespro.ru", "phone": "+70207487807"}
0005434879989	AFC860	5052 963330	YURIY SCHERBAKOV	{"email": "scherbakovy.1976@postgrespro.ru", "phone": "+70434638488"}
0005434879990	AFC860	4786 521268	DMITRIY TIMOFEEV	{"phone": "+70424873507"}
0005434879991	675973	5758 193508	VIKTOR BARANOV	{"email": "baranov_viktor_021965@postgrespro.ru", "phone": "+70476660807"}
0005434879992	8FB59F	0073 991384	NATALYA LAZAREVA	{"phone": "+70240218234"}
0005434879993	4364D3	0154 586209	ANNA KUZNECOVA	{"phone": "+70602334514"}
0005434879994	4DF328	8816 163587	IRINA SCHERBAKOVA	{"email": "scherbakova_i.1954@postgrespro.ru", "phone": "+70543177981"}
0005434879995	4DF328	3726 281525	ARTEM KUZNECOV	{"email": "artem-kuznecov1978@postgrespro.ru", "phone": "+70162882454"}
0005434879996	0653A3	4300 663326	ANTON ZHUKOV	{"email": "zhukov.anton27101964@postgrespro.ru", "phone": "+70787110279"}
0005434879997	7E9E53	0869 518731	NATALYA SEMENOVA	{"email": "semenova-natalya.03071971@postgrespro.ru", "phone": "+70701418456"}
0005434879998	7E9E53	4201 081010	MARINA SMIRNOVA	{"email": "marinasmirnova121984@postgrespro.ru", "phone": "+70207616468"}
0005434879999	53DD2C	1427 314772	EVGENIYA TROFIMOVA	{"phone": "+70228967392"}
0005434880000	53DD2C	7075 803053	ANATOLIY ANDREEV	{"phone": "+70306044168"}
0005434880001	4CF3F6	7653 940902	SERGEY ORLOV	{"email": "sorlov.1979@postgrespro.ru", "phone": "+70354428399"}
0005434880002	DE5921	7993 181623	VITALIY SIDOROV	{"phone": "+70208318198"}
0005434880003	45F425	3018 454982	ARTEM MAKSIMOV	{"email": "maksimov_artem1981@postgrespro.ru", "phone": "+70757037440"}
0005434880004	2725B6	8705 135632	TATYANA NIKITINA	{"phone": "+70340678117"}
0005434880005	2725B6	0117 170783	KSENIYA NAZAROVA	{"email": "nazarova-k.031973@postgrespro.ru", "phone": "+70347136731"}
0005434880006	B90A1F	8600 389155	TAMARA TIMOFEEVA	{"email": "timofeevatamara_1964@postgrespro.ru", "phone": "+70931645615"}
0005434880007	852817	6820 745619	GALINA IVANOVA	{"phone": "+70739925813"}
0005434880008	6C42A2	6537 663797	VERA SERGEEVA	{"email": "vsergeeva.02031975@postgrespro.ru", "phone": "+70475369867"}
0005434880009	6C42A2	3938 806469	OLEG NIKITIN	{"email": "nikitin-oleg_011970@postgrespro.ru", "phone": "+70598406985"}
0005434880010	6C42A2	5083 644964	VALENTINA IVANOVA	{"email": "valentina.ivanova-021977@postgrespro.ru", "phone": "+70992059532"}
0005434880011	29DA06	5895 328293	KSENIYA SMIRNOVA	{"email": "k_smirnova-1972@postgrespro.ru", "phone": "+70937778784"}
0005434880012	412088	1269 894063	VALENTINA POPOVA	{"phone": "+70387376878"}
0005434880013	F6C88B	1080 682178	ALEKSANDR KUZNECOV	{"phone": "+70932881163"}
0005434880014	F6C88B	8949 976209	YURIY TIKHONOV	{"phone": "+70245950131"}
0005434880015	BB76DA	1293 885700	YURIY VLASOV	{"email": "vlasov-y13061982@postgrespro.ru", "phone": "+70678725289"}
0005434880016	BB76DA	9851 632533	KSENIYA YAKOVLEVA	{"email": "k_yakovleva-04061974@postgrespro.ru", "phone": "+70287320800"}
0005434880017	8FB66F	7004 879904	RUSLAN ZAKHAROV	{"email": "ruslanzakharov-1983@postgrespro.ru", "phone": "+70757865271"}
0005434880018	B3400E	9528 125388	IVAN AFANASEV	{"email": "i-afanasev-09051970@postgrespro.ru", "phone": "+70147090012"}
0005434880019	0E8FE5	1188 157927	BORIS FILIPPOV	{"email": "b_filippov.1976@postgrespro.ru", "phone": "+70458497012"}
0005434880020	E9C674	3999 861715	SERGEY KUZMIN	{"email": "s_kuzmin.07021969@postgrespro.ru", "phone": "+70909674558"}
0005434880021	E9C674	0407 331111	ALEKSEY SAVELEV	{"phone": "+70211767154"}
0005434880022	E9C674	2551 239568	ALEKSANDR IVANOV	{"email": "ivanova-111973@postgrespro.ru", "phone": "+70551773481"}
0005434880023	4A5F95	1836 792167	EVGENIY VASILEV	{"phone": "+70028852825"}
0005434880024	CBBC78	5404 035895	ALEKSANDR SAVELEV	{"phone": "+70029216285"}
0005434880025	FF5731	0975 192175	NATALYA POLYAKOVA	{"phone": "+70634749107"}
0005434880026	888718	0781 231419	ALEKSANDR BARANOV	{"phone": "+70596793220"}
0005434880027	888718	1702 482151	VIKTOR VLASOV	{"phone": "+70490613123"}
0005434880028	B37B89	3492 208006	DMITRIY GRIGOREV	{"phone": "+70139332693"}
0005434880029	548EEC	6975 374593	TATYANA KISELEVA	{"email": "kiseleva_tatyana.091968@postgrespro.ru", "phone": "+70265645277"}
0005434880030	6D2AAA	1171 922203	MIKHAIL IVANOV	{"phone": "+70985827207"}
0005434880031	46CD0C	5537 600675	SVETLANA ALEKSANDROVA	{"email": "saleksandrova1979@postgrespro.ru", "phone": "+70569569388"}
0005434880032	AFE369	7990 074281	NADEZHDA KOROLEVA	{"phone": "+70081127920"}
0005434880033	3BA0F0	2345 332337	LYUDMILA BELOVA	{"email": "belovalyudmila_18091967@postgrespro.ru", "phone": "+70076993023"}
0005434880034	649F40	3846 394135	TATYANA NAUMOVA	{"phone": "+70277241255"}
0005434880035	89948F	7492 381696	ANNA SIDOROVA	{"phone": "+70369164165"}
0005434880036	7AD25A	6716 321209	ANNA KOZLOVA	{"phone": "+70457135308"}
0005434880037	CDF9F4	7520 886960	ELENA ERMAKOVA	{"email": "ermakova.elena_1972@postgrespro.ru", "phone": "+70501895148"}
0005434880038	CDF9F4	3695 753466	YULIYA POPOVA	{"phone": "+70566617986"}
0005434880039	9CB934	5837 051523	SERGEY ZAYCEV	{"email": "sergey-zaycev111962@postgrespro.ru", "phone": "+70693093897"}
0005434880040	9CB934	9755 293803	EVDOKIYA MAKSIMOVA	{"phone": "+70226904201"}
0005434880041	075F4D	2435 349413	ALEKSANDR ANTONOV	{"email": "a_antonov.061974@postgrespro.ru", "phone": "+70818077375"}
0005434880042	64B4BB	2563 618672	EVGENIY SAVELEV	{"phone": "+70176165803"}
0005434880043	4845C4	6481 164394	TATYANA MOROZOVA	{"phone": "+70745994248"}
0005434880044	A7976E	7390 246413	ALEKSANDR IVANOV	{"phone": "+70705217475"}
0005434880045	A8B447	9512 641082	LILIYA ABRAMOVA	{"email": "abramovaliliya.101958@postgrespro.ru", "phone": "+70803788784"}
0005434880046	A8B447	3517 547105	VALENTINA KUZNECOVA	{"phone": "+70771788188"}
0005434880047	D9DB83	6500 485492	RUSTAM SOKOLOV	{"email": "r-sokolov_08061959@postgrespro.ru", "phone": "+70299834452"}
0005434880048	8251BE	9452 234401	YURIY AFANASEV	{"email": "afanasevyuriy-1973@postgrespro.ru", "phone": "+70298222099"}
0005434880049	5096CD	7129 040151	ALEKSANDR GRIGOREV	{"email": "grigorev-a101971@postgrespro.ru", "phone": "+70935418557"}
0005434880050	5096CD	9207 650557	NINA AKIMOVA	{"email": "n.akimova-101974@postgrespro.ru", "phone": "+70707397867"}
0005434880051	78D579	4998 910437	IVAN KUZNECOV	{"email": "ivankuznecov.29041971@postgrespro.ru", "phone": "+70193441320"}
0005434880052	CCA113	6097 501623	VALENTINA VASILEVA	{"phone": "+70584332132"}
0005434880053	4F043F	7589 868995	KONSTANTIN KUZMIN	{"phone": "+70896036211"}
0005434880054	4F043F	7240 736373	VLADIMIR VOROBEV	{"phone": "+70886513492"}
0005434880055	56C8EA	2085 324361	RINAT FEDOROV	{"phone": "+70301410868"}
0005434880056	42A048	7212 675099	SERGEY KARPOV	{"email": "sergeykarpov-071964@postgrespro.ru", "phone": "+70957008181"}
0005434880057	E7EE91	4394 020856	VALENTINA MAKSIMOVA	{"email": "maksimovavalentina-11021967@postgrespro.ru", "phone": "+70660808669"}
0005434880058	C27DFD	4507 066514	VERONIKA SMIRNOVA	{"email": "smirnovav-011974@postgrespro.ru", "phone": "+70340280097"}
0005434880059	4594B2	8365 103806	NATALYA SMIRNOVA	{"phone": "+70664852033"}
0005434880060	4594B2	4859 706301	NATALYA DENISOVA	{"phone": "+70431756889"}
0005434880061	450C5B	8020 506822	SVETLANA POLYAKOVA	{"email": "polyakova_s1967@postgrespro.ru", "phone": "+70985745758"}
0005434880062	E99749	1618 156605	SVETLANA KUZMINA	{"email": "svetlana-kuzmina011969@postgrespro.ru", "phone": "+70676442917"}
0005434880063	DB7D76	6916 265544	ZINAIDA POLYAKOVA	{"email": "polyakovaz.051975@postgrespro.ru", "phone": "+70461456308"}
0005434880064	6CADCD	1548 443481	VALERIY SIDOROV	{"phone": "+70280393204"}
0005434880065	EABF9B	7771 422706	ARTEM TIKHONOV	{"email": "a.tikhonov.091969@postgrespro.ru", "phone": "+70071175284"}
0005434880066	EABF9B	1243 651500	MARIYA AFANASEVA	{"email": "m-afanaseva-1964@postgrespro.ru", "phone": "+70097936356"}
0005434880067	3398C5	7513 652647	VLADISLAV FROLOV	{"email": "frolovv1982@postgrespro.ru", "phone": "+70872557914"}
0005434880068	64880B	4012 912638	GRIGORIY NIKITIN	{"email": "grigoriy-nikitin.14111975@postgrespro.ru", "phone": "+70532803736"}
0005434880069	2138C5	6704 649249	VLADIMIR KISELEV	{"email": "kiselev-vladimir-1971@postgrespro.ru", "phone": "+70513528765"}
0005434880070	A89FE0	8184 374765	GALINA KONDRATEVA	{"email": "kondrateva_galina.1967@postgrespro.ru", "phone": "+70932900750"}
0005434880071	870747	5237 004918	YULIYA GAVRILOVA	{"phone": "+70824640231"}
0005434880072	2F3A25	6604 781990	MARGARITA LOGINOVA	{"email": "loginova.margarita-021969@postgrespro.ru", "phone": "+70764425899"}
0005434880073	B78179	8340 620673	VLADIMIR FOMIN	{"phone": "+70447867970"}
0005434880074	26AEAD	4877 316728	NIKOLAY NAZAROV	{"phone": "+70045330497"}
0005434880075	CE2DBF	5753 488530	EVGENIYA PAVLOVA	{"email": "pavlova_evgeniya-1964@postgrespro.ru", "phone": "+70148702924"}
0005434880076	9B5BBA	9584 338638	KIRILL SIDOROV	{"phone": "+70692908293"}
0005434880077	9B5BBA	7735 226937	ALEKSANDR KUZMIN	{"email": "kuzminaleksandr101980@postgrespro.ru", "phone": "+70144284621"}
0005434880078	0FB068	2117 072890	ALEKSANDR ILIN	{"email": "a.ilin_18091967@postgrespro.ru", "phone": "+70562787919"}
0005434880079	0FB068	4192 952532	KSENIYA IVANOVA	{"email": "kivanova23021972@postgrespro.ru", "phone": "+70173196759"}
0005434880080	AE57EB	6395 202615	DMITRIY MIRONOV	{"phone": "+70991692016"}
0005434880081	494B22	7751 932808	SVETLANA SOROKINA	{"phone": "+70616893475"}
0005434880082	EE02B1	1655 058177	LIDIYA GUSEVA	{"email": "l.guseva08071976@postgrespro.ru", "phone": "+70671087411"}
0005434880083	EE02B1	3055 311423	ELENA LAZAREVA	{"email": "lazareva.elena_081974@postgrespro.ru", "phone": "+70875031742"}
0005434880084	F88603	6700 296863	SERGEY PETROV	{"phone": "+70876051287"}
0005434880085	1B0924	3437 745514	NATALYA DMITRIEVA	{"email": "ndmitrieva1963@postgrespro.ru", "phone": "+70249903204"}
0005434880197	055BDC	3768 528144	MARIYA LOGINOVA	{"phone": "+70914677563"}
0005434880086	8C0B4F	5048 803982	PAVEL KOZLOV	{"email": "kozlovpavel091979@postgrespro.ru", "phone": "+70989974530"}
0005434880087	8C0B4F	4718 146621	ALENA DAVYDOVA	{"email": "davydova-a1968@postgrespro.ru", "phone": "+70803915931"}
0005434880088	9DA5C7	1164 097316	VLADIMIR BONDARENKO	{"email": "vladimir_bondarenko.1972@postgrespro.ru", "phone": "+70597446952"}
0005434880089	92CABC	7152 207448	LYUDMILA AFANASEVA	{"email": "afanaseval_1971@postgrespro.ru", "phone": "+70733463898"}
0005434880090	92CABC	3644 016049	VIKTOR FEDOROV	{"phone": "+70890874073"}
0005434880091	13B906	8966 825795	DARYA KOROLEVA	{"email": "d-koroleva-061966@postgrespro.ru", "phone": "+70505075426"}
0005434880092	62EB8B	2020 808960	LYUBOV BORISOVA	{"phone": "+70181468651"}
0005434880093	8E75BD	8494 918604	LARISA SAVELEVA	{"phone": "+70415832975"}
0005434880094	FA55EE	0381 489864	GENNADIY FEDOROV	{"phone": "+70456096634"}
0005434880095	8C8A50	6886 111264	LYUDMILA KULIKOVA	{"phone": "+70935977958"}
0005434880096	A0145F	0111 876595	IGOR YAKOVLEV	{"email": "yakovlevigor-12051986@postgrespro.ru", "phone": "+70027315065"}
0005434880097	A0145F	3600 446442	NINA KOLESNIKOVA	{"phone": "+70318669052"}
0005434880098	B9FCC3	6933 356148	NADEZHDA ANTONOVA	{"phone": "+70676105648"}
0005434880099	B9FCC3	8376 579891	LIDIYA NOVIKOVA	{"email": "l-novikova1991@postgrespro.ru", "phone": "+70811244989"}
0005434880100	E0FDEF	2406 601602	VYACHESLAV EGOROV	{"email": "egorov-v_021963@postgrespro.ru", "phone": "+70103123979"}
0005434880101	E0FDEF	3796 430590	VLADISLAV EGOROV	{"email": "v-egorov.1973@postgrespro.ru", "phone": "+70880097340"}
0005434880102	E0FDEF	0418 917199	AZAT DENISOV	{"phone": "+70922615689"}
0005434880103	6575F4	9782 097073	VLADIMIR IVANOV	{"email": "vladimir-ivanov.101970@postgrespro.ru", "phone": "+70333014842"}
0005434880104	DE5124	4418 787042	ILYA ZHUKOV	{"email": "i_zhukov07111970@postgrespro.ru", "phone": "+70174260954"}
0005434880105	DE5124	3152 863307	ALEKSEY NAUMOV	{"email": "alekseynaumov_1968@postgrespro.ru", "phone": "+70880560714"}
0005434880106	CB701D	9000 843531	YULIYA OSIPOVA	{"email": "osipova_yuliya_1963@postgrespro.ru", "phone": "+70405638097"}
0005434880107	4AC986	6494 239373	ANDREY MIKHAYLOV	{"phone": "+70924788797"}
0005434880108	AC116F	5761 076560	ALEKSANDR MAKSIMOV	{"email": "maksimov-a.1966@postgrespro.ru", "phone": "+70784762843"}
0005434880109	AC116F	1430 823364	SVETLANA SIDOROVA	{"email": "sidorova-s20091975@postgrespro.ru", "phone": "+70226075282"}
0005434880110	A55964	8066 555539	YANA FROLOVA	{"email": "frolovay30051978@postgrespro.ru", "phone": "+70686755956"}
0005434880111	A55964	9586 314575	IGOR KAZAKOV	{"email": "igorkazakov.18121955@postgrespro.ru", "phone": "+70175559771"}
0005434880112	59464E	8357 385021	OLEG KOROLEV	{"email": "oleg-korolev-021985@postgrespro.ru", "phone": "+70570241963"}
0005434880113	CA896A	0923 240498	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev-091954@postgrespro.ru", "phone": "+70281343537"}
0005434880114	5701D6	8134 048862	ALINA KOZLOVA	{"email": "akozlova.10041966@postgrespro.ru", "phone": "+70217124977"}
0005434880115	5701D6	3990 686669	TATYANA ZHUKOVA	{"phone": "+70592565344"}
0005434880116	C3CDC2	9337 273235	LARISA DAVYDOVA	{"email": "davydova_l-091977@postgrespro.ru", "phone": "+70225193283"}
0005434880117	A83F33	1929 051007	LARISA MAKAROVA	{"email": "makarova-l.121960@postgrespro.ru", "phone": "+70992750193"}
0005434880118	F6D816	4572 906352	LARISA KUZNECOVA	{"email": "kuznecova.larisa_1973@postgrespro.ru", "phone": "+70974514487"}
0005434880119	F6D816	4462 179631	ELENA BOGDANOVA	{"email": "elena-bogdanova051974@postgrespro.ru", "phone": "+70988848773"}
0005434880120	62B739	8881 593446	ANASTASIYA MAKSIMOVA	{"email": "maksimova.a.17101961@postgrespro.ru", "phone": "+70133761529"}
0005434880121	D4E330	3468 738492	ELIZAVETA DMITRIEVA	{"phone": "+70291600034"}
0005434880122	F074B2	8421 669065	SERGEY FROLOV	{"email": "frolov-sergey041966@postgrespro.ru", "phone": "+70477771599"}
0005434880123	D73E82	1740 404848	VALENTINA SOKOLOVA	{"email": "v-sokolova021975@postgrespro.ru", "phone": "+70288290010"}
0005434880124	9FDEB8	6185 087562	EKATERINA KUZNECOVA	{"email": "kuznecova-e_21051984@postgrespro.ru", "phone": "+70903489034"}
0005434880125	9C06C2	6141 066368	KSENIYA MOISEEVA	{"phone": "+70063528481"}
0005434880126	1DDCCE	2741 472609	NIKITA MIRONOV	{"phone": "+70121590169"}
0005434880127	1DDCCE	4702 949734	RUSHANIYA MAKAROVA	{"phone": "+70024899451"}
0005434880128	2E61D3	0845 084098	RUSTYAM KOZLOV	{"email": "kozlov_r.1975@postgrespro.ru", "phone": "+70859907721"}
0005434880129	9D2243	2096 040550	TATYANA BARANOVA	{"phone": "+70141623869"}
0005434880130	6F949F	1616 068602	NADEZHDA GRISHINA	{"phone": "+70292136039"}
0005434880131	1DF95A	8829 005256	ALEKSANDR KULIKOV	{"phone": "+70439921084"}
0005434880132	00849B	2357 485190	ELENA LAZAREVA	{"email": "elazareva-1976@postgrespro.ru", "phone": "+70291378177"}
0005434880133	B9CD20	3353 123225	EVGENIY AFANASEV	{"email": "e_afanasev081980@postgrespro.ru", "phone": "+70136976852"}
0005434880134	3D5C31	3243 042631	ALEKSANDR FOMIN	{"email": "fomin_aleksandr-011975@postgrespro.ru", "phone": "+70802679078"}
0005434880135	2DD232	1415 319180	PAVEL NAZAROV	{"email": "pavel_nazarov_1972@postgrespro.ru", "phone": "+70984154548"}
0005434880136	C1678A	5349 272703	VASILIY ABRAMOV	{"phone": "+70940750155"}
0005434880137	E9F9EE	7574 365858	NIKOLAY MAKAROV	{"phone": "+70609540543"}
0005434880138	9F943A	6387 280044	OLEG SMIRNOV	{"email": "smirnov.o.16121973@postgrespro.ru", "phone": "+70181499230"}
0005434880139	A7E455	5596 304292	SVETLANA FILATOVA	{"email": "svetlana-filatova091983@postgrespro.ru", "phone": "+70390025166"}
0005434880140	A7E455	8692 929775	VIKTOR VOLKOV	{"phone": "+70296815385"}
0005434880141	A7E455	8286 382780	ANATOLIY IVANOV	{"email": "a.ivanov-27091971@postgrespro.ru", "phone": "+70105758500"}
0005434880142	B4F8F0	6053 071483	ELENA POPOVA	{"email": "popovaelena.1965@postgrespro.ru", "phone": "+70201769604"}
0005434880143	9AE892	7311 110718	ALEKSANDR KUZNECOV	{"phone": "+70819374755"}
0005434880144	9AE892	0731 971693	NATALYA MIKHAYLOVA	{"email": "natalya.mikhaylova1970@postgrespro.ru", "phone": "+70480705409"}
0005434880145	9AE892	5574 153331	VLADIMIR ROMANOV	{"email": "v_romanov-1965@postgrespro.ru", "phone": "+70202801330"}
0005434880146	4F7B93	7886 533877	ALEKSANDR PAVLOV	{"phone": "+70579965211"}
0005434880147	75ED02	7613 900262	VLADIMIR NAUMOV	{"email": "vladimirnaumov_03071972@postgrespro.ru", "phone": "+70323994478"}
0005434880148	EC0D37	5490 043788	OLEG FROLOV	{"email": "ofrolov_02101956@postgrespro.ru", "phone": "+70228466040"}
0005434880149	C7473B	2994 773273	ANNA PETROVA	{"email": "apetrova.1973@postgrespro.ru", "phone": "+70018590393"}
0005434880150	DE530A	4826 477443	ALEVTINA FEDOROVA	{"phone": "+70922952296"}
0005434880151	DE530A	6970 969504	OLGA MELNIKOVA	{"email": "melnikovao_11091969@postgrespro.ru", "phone": "+70964897278"}
0005434880152	DE530A	7508 826446	SERGEY BELOV	{"email": "belov.s_051966@postgrespro.ru", "phone": "+70520275125"}
0005434880153	DE530A	1303 514487	ELENA MIKHAYLOVA	{"phone": "+70818680561"}
0005434880154	C4BB45	8060 143062	ARKADIY NAUMOV	{"email": "arkadiy-naumov_041973@postgrespro.ru", "phone": "+70576748605"}
0005434880155	C81381	0438 735701	ANZHELIKA ZHUKOVA	{"email": "zhukova.a-051979@postgrespro.ru", "phone": "+70487773134"}
0005434880156	AF50AA	6764 993398	VIKTORIYA TROFIMOVA	{"email": "viktoriya-trofimova_1961@postgrespro.ru", "phone": "+70187770749"}
0005434880157	3A726A	5445 928688	ELENA SEMENOVA	{"email": "elenasemenova-081973@postgrespro.ru", "phone": "+70249753100"}
0005434880158	1F6A16	5252 760855	NADEZHDA BELOVA	{"phone": "+70841201517"}
0005434880159	81BB77	7566 996310	NAILYA GORBUNOVA	{"phone": "+70527084566"}
0005434880160	81BB77	6504 749520	VALENTIN MATVEEV	{"phone": "+70272077451"}
0005434880161	3013D1	7553 774555	ANDREY FROLOV	{"phone": "+70244149663"}
0005434880162	3013D1	7033 946891	ALEKSANDR MOROZOV	{"phone": "+70307084955"}
0005434880163	74B368	2852 778208	ANDREY KOZLOV	{"phone": "+70589648385"}
0005434880164	74B368	2533 260055	VASILIY ISAEV	{"email": "isaev.vasiliy_28071974@postgrespro.ru", "phone": "+70704502615"}
0005434880165	74B368	9204 511679	ELENA SEMENOVA	{"phone": "+70672923410"}
0005434880166	7CD282	2899 463057	ALEKSANDR PETROV	{"phone": "+70538397408"}
0005434880167	7CD282	2879 464191	ALEKSEY YAKOVLEV	{"phone": "+70531485807"}
0005434880168	09E6E3	2991 855595	LYUDMILA EFREMOVA	{"email": "efremova_lyudmila_06081975@postgrespro.ru", "phone": "+70932403167"}
0005434880169	748AE2	1959 049269	LUIZA ERMAKOVA	{"email": "l.ermakova_011964@postgrespro.ru", "phone": "+70484755688"}
0005434880170	748AE2	1727 456247	NATALYA POPOVA	{"email": "popova_n_1972@postgrespro.ru", "phone": "+70157024173"}
0005434880171	75E61D	9944 457917	RUZALIYA YAKOVLEVA	{"phone": "+70264950328"}
0005434880172	145DA8	3632 334144	ANNA IVANOVA	{"email": "annaivanova.021975@postgrespro.ru", "phone": "+70181466280"}
0005434880173	6AC84F	6704 494082	PAVEL ISAEV	{"phone": "+70259225142"}
0005434880174	E28664	8842 293750	TATYANA KISELEVA	{"email": "tatyana_kiseleva-20111981@postgrespro.ru", "phone": "+70291040132"}
0005434880175	6650DD	9065 940788	SERGEY STEPANOV	{"email": "sergey-stepanov.01011983@postgrespro.ru", "phone": "+70019827487"}
0005434880176	692275	9615 665147	YULIYA STEPANOVA	{"phone": "+70372764185"}
0005434880177	692275	4610 548321	LYUDMILA KULIKOVA	{"email": "lyudmila_kulikova-01061972@postgrespro.ru", "phone": "+70819922999"}
0005434880178	692275	9432 955469	TAMARA CHERNOVA	{"phone": "+70683113715"}
0005434880179	A2DEF6	2850 539244	ANDREY IVANOV	{"phone": "+70281911820"}
0005434880180	12F14C	4671 350749	KONSTANTIN POPOV	{"phone": "+70562553294"}
0005434880181	12F14C	9930 093352	ALEKSANDRA NIKIFOROVA	{"phone": "+70382025903"}
0005434880182	963029	8998 339853	MARINA KOROLEVA	{"phone": "+70576088697"}
0005434880183	2A0CF8	0066 966783	ALENA SERGEEVA	{"email": "asergeeva04071974@postgrespro.ru", "phone": "+70696198263"}
0005434880184	3E817E	4348 315384	TATYANA KOROLEVA	{"email": "koroleva.t_1975@postgrespro.ru", "phone": "+70923063597"}
0005434880185	1F8DA2	7198 989699	TATYANA ANISIMOVA	{"email": "tatyana_anisimova.1978@postgrespro.ru", "phone": "+70986701276"}
0005434880186	FDC510	5383 732418	IGOR GRIGOREV	{"email": "grigorev.igor_051973@postgrespro.ru", "phone": "+70292477196"}
0005434880187	FDC510	5850 990297	FARIDA POPOVA	{"email": "farida_popova011967@postgrespro.ru", "phone": "+70279990426"}
0005434880188	692B4A	4124 845012	ULYANA NIKITINA	{"phone": "+70285902772"}
0005434880189	1AF239	6043 004675	VALENTIN FILIPPOV	{"email": "vfilippov-15121982@postgrespro.ru", "phone": "+70000220219"}
0005434880190	1AF239	3396 280697	VARVARA VLASOVA	{"email": "vlasova_v_1970@postgrespro.ru", "phone": "+70600910337"}
0005434880191	1AF239	9841 735135	VIKTOR IVANOV	{"phone": "+70135142635"}
0005434880192	1AF239	6966 502309	IVAN GRIGOREV	{"phone": "+70287614636"}
0005434880193	345CD1	0191 797638	ANGELINA ANTONOVA	{"email": "antonova_angelina-061977@postgrespro.ru", "phone": "+70947103266"}
0005434880194	345CD1	3575 516756	SVETLANA OVCHINNIKOVA	{"phone": "+70759318683"}
0005434880195	464F84	5266 190678	ALEKSANDR VOROBEV	{"phone": "+70933464122"}
0005434880196	055BDC	6907 278873	PELAGEYA POPOVA	{"email": "popova-p-1985@postgrespro.ru", "phone": "+70645739270"}
0005434880198	561423	7888 333734	KONSTANTIN BORISOV	{"email": "borisov-konstantin-30081965@postgrespro.ru", "phone": "+70201749186"}
0005434880199	590B84	1400 547416	ANDREY FEDOROV	{"phone": "+70268383777"}
0005434880201	A52A1E	6299 518982	ALEKSANDR BORISOV	{"email": "borisov_aleksandr_1981@postgrespro.ru", "phone": "+70726201404"}
0005434880202	D9CDAF	0612 551768	SEMEN VOLKOV	{"email": "s-volkov_121971@postgrespro.ru", "phone": "+70370505538"}
0005434880203	D9CDAF	6733 555783	KRISTINA KOZLOVA	{"phone": "+70621689309"}
0005434880204	D9CDAF	2326 979688	VIKTOR YAKOVLEV	{"phone": "+70161085034"}
0005434880205	3A657D	6977 165813	ALEKSEY SAVELEV	{"phone": "+70783428487"}
0005434880206	2D9D77	7487 294851	NINA LEBEDEVA	{"email": "nina.lebedeva031969@postgrespro.ru", "phone": "+70785280039"}
0005434880207	B19211	0415 098521	ANNA SAVELEVA	{"phone": "+70938580801"}
0005434880208	B103F2	7239 099189	EVGENIY ABRAMOV	{"email": "evgeniyabramov-21111976@postgrespro.ru", "phone": "+70888678702"}
0005434880209	4C95AB	6910 054984	ALEKSANDR ALEKSEEV	{"phone": "+70907109183"}
0005434880210	B2E225	0415 703079	ANATOLIY DMITRIEV	{"email": "dmitriev_a1964@postgrespro.ru", "phone": "+70455068366"}
0005434880211	B668E4	6567 811032	ILYA ROMANOV	{"phone": "+70722787909"}
0005434880212	E5F547	4466 517917	PETR IVANOV	{"email": "petrivanov081973@postgrespro.ru", "phone": "+70015456003"}
0005434880213	E5F547	7763 187043	VLADISLAV GRIGOREV	{"email": "grigorev_vladislav_081962@postgrespro.ru", "phone": "+70441372852"}
0005434880214	A7A7E4	3466 433501	VYACHESLAV EGOROV	{"email": "v-egorov.071976@postgrespro.ru", "phone": "+70983071827"}
0005434880215	7DCEEB	0934 057810	DENIS POPOV	{"email": "popov_denis_111982@postgrespro.ru", "phone": "+70720299259"}
0005434880216	9D0283	1274 723087	ALEKSANDR SAVELEV	{"phone": "+70137895003"}
0005434880217	377C3B	6452 538779	ZHANNA GUSEVA	{"email": "zhanna_guseva.071964@postgrespro.ru", "phone": "+70636443467"}
0005434880218	377C3B	3549 791522	NINA TARASOVA	{"email": "n_tarasova-22051966@postgrespro.ru", "phone": "+70081149012"}
0005434880219	377C3B	0118 060497	ANNA KISELEVA	{"email": "kiselevaa101981@postgrespro.ru", "phone": "+70411644438"}
0005434880220	8E412A	4794 122113	MARINA KOROLEVA	{"email": "koroleva-marina1962@postgrespro.ru", "phone": "+70764236808"}
0005434880221	A4ACEE	4801 038049	SERGEY KULIKOV	{"phone": "+70022399606"}
0005434880222	A4ACEE	1374 092821	ANNA ZHURAVLEVA	{"email": "zhuravlevaa-1980@postgrespro.ru", "phone": "+70834916809"}
0005434880223	CE58D3	7515 658133	DMITRIY IVANOV	{"email": "ivanov_d.29121984@postgrespro.ru", "phone": "+70994167933"}
0005434880224	CE58D3	7443 571506	YULIYA SERGEEVA	{"email": "y-sergeeva_09011971@postgrespro.ru", "phone": "+70745106697"}
0005434880225	E3B52A	8969 568472	VIKTOR VOROBEV	{"phone": "+70322541556"}
0005434880226	185AF5	6497 849335	VYACHESLAV ZAKHAROV	{"email": "zakharov.vyacheslav-26101977@postgrespro.ru", "phone": "+70594461727"}
0005434880227	185AF5	6284 611562	EVGENIYA KONOVALOVA	{"email": "konovalova-e101969@postgrespro.ru", "phone": "+70715192417"}
0005434880228	8C8532	9661 020591	VALENTINA POPOVA	{"phone": "+70850919395"}
0005434880229	E789E9	4824 017711	SERGEY GORBUNOV	{"phone": "+70643284527"}
0005434880230	E789E9	1964 833249	SERGEY GRIGOREV	{"phone": "+70413438121"}
0005434880231	058689	9801 574931	VALENTINA KUZNECOVA	{"phone": "+70147023574"}
0005434880232	2CCC25	7624 653984	VIKTOR SEMENOV	{"phone": "+70005427401"}
0005434880233	2CCC25	4979 674965	VERONIKA STEPANOVA	{"email": "stepanovav_30051966@postgrespro.ru", "phone": "+70382752567"}
0005434880234	2CCC25	8053 775258	OLGA NAZAROVA	{"email": "olga-nazarova-1976@postgrespro.ru", "phone": "+70780192013"}
0005434880235	6E16C4	5346 849781	VYACHESLAV KONOVALOV	{"phone": "+70356923582"}
0005434880236	6E16C4	5461 392470	NINA EFREMOVA	{"email": "nina-efremova_30091969@postgrespro.ru", "phone": "+70959820360"}
0005434880237	6E16C4	9924 213480	VLADISLAV KUZMIN	{"email": "vladislav-kuzmin_1964@postgrespro.ru", "phone": "+70958601421"}
0005434880238	83EF3C	4892 638387	VIKTOR ORLOV	{"phone": "+70800641432"}
0005434880239	141878	2854 234036	GALINA PAVLOVA	{"phone": "+70463556303"}
0005434880240	46C262	1497 662511	TATYANA KULIKOVA	{"phone": "+70606514084"}
0005434880241	5B2016	7552 432335	MAKSIM KUZMIN	{"phone": "+70941581905"}
0005434880242	4B6B5C	0744 425264	ELENA KUZMINA	{"email": "kuzmina-e.25031982@postgrespro.ru", "phone": "+70133688298"}
0005434880243	86BD73	4283 567214	MARINA SCHERBAKOVA	{"email": "scherbakovam.121969@postgrespro.ru", "phone": "+70728657299"}
0005434880244	86BD73	0442 835117	NINA NIKITINA	{"phone": "+70765943352"}
0005434880245	86BD73	9728 278384	NATALYA FEDOROVA	{"email": "natalyafedorova_1972@postgrespro.ru", "phone": "+70028022934"}
0005434880246	03082A	0526 143425	EVGENIY MIKHAYLOV	{"phone": "+70465851512"}
0005434880247	D7D6E5	2728 049490	IRINA EGOROVA	{"email": "irina_egorova.041968@postgrespro.ru", "phone": "+70610855681"}
0005434880248	3015A9	4305 795172	SERGEY PETROV	{"phone": "+70195847933"}
0005434880249	FA9149	1615 246988	YULIYA DENISOVA	{"phone": "+70162186857"}
0005434880250	FA9149	9862 986334	TAMARA KOZLOVA	{"email": "kozlovatamara.121977@postgrespro.ru", "phone": "+70276345914"}
0005434880251	F9D06C	9675 090268	GENNADIY NIKITIN	{"phone": "+70594100583"}
0005434880252	2C502B	6161 899205	IRINA ANTONOVA	{"phone": "+70508825448"}
0005434880253	2C502B	9123 069315	ANATOLIY KOROLEV	{"phone": "+70496654534"}
0005434880254	EBBF69	8542 989367	GALINA MAKSIMOVA	{"phone": "+70022078489"}
0005434880255	B3ACFB	0533 664646	NIKOLAY ISAEV	{"phone": "+70041650261"}
0005434880256	B3ACFB	1688 812998	VADIM KRASNOV	{"phone": "+70589546121"}
0005434880257	FDF0E6	7595 880841	TATYANA POTAPOVA	{"phone": "+70382872435"}
0005434880258	BA8230	3243 621266	ANDREY RODIONOV	{"phone": "+70556496934"}
0005434880259	BA8230	1689 749161	OLGA LEBEDEVA	{"phone": "+70584406475"}
0005434880260	B405E2	8068 381824	ALEKSANDR SIDOROV	{"email": "a-sidorov-1964@postgrespro.ru", "phone": "+70623130815"}
0005434880261	7AA6D9	7859 198131	IRINA BORISOVA	{"phone": "+70920194915"}
0005434880262	7AA6D9	6400 577588	ANDREY MOROZOV	{"phone": "+70050825974"}
0005434880263	1A7EEF	5576 276626	POLINA ERMAKOVA	{"phone": "+70883926004"}
0005434880264	2B10B7	4340 314851	MARINA ZHURAVLEVA	{"email": "zhuravleva.m.1969@postgrespro.ru", "phone": "+70431239746"}
0005434880265	3A5D6A	7601 078829	GALINA KONOVALOVA	{"email": "konovalova.galina1976@postgrespro.ru", "phone": "+70995952350"}
0005434880266	A8743A	4452 228445	VYACHESLAV ILIN	{"phone": "+70797331872"}
0005434880267	A8743A	9791 173144	SERGEY MATVEEV	{"phone": "+70888649783"}
0005434880268	69F30A	2118 979515	VALERIYA RODIONOVA	{"email": "rodionova.valeriya_1960@postgrespro.ru", "phone": "+70849033467"}
0005434880269	69F30A	4784 615531	ALEKSANDR SOLOVEV	{"phone": "+70935686220"}
0005434880270	5E80AC	8397 905923	GALINA NIKITINA	{"phone": "+70809935215"}
0005434880271	5E80AC	0476 575768	ANDREY SOKOLOV	{"email": "a.sokolov.081972@postgrespro.ru", "phone": "+70767407924"}
0005434880272	57A2BE	1471 383284	NIKOLAY TIKHONOV	{"email": "n_tikhonov051971@postgrespro.ru", "phone": "+70383530824"}
0005434880273	1CE76E	6672 489242	DARYA BELYAEVA	{"phone": "+70863063029"}
0005434880274	736760	9069 359027	VALERIY GRIGOREV	{"email": "grigorev_valeriy-26051972@postgrespro.ru", "phone": "+70011232675"}
0005434880275	A23519	6271 017804	ELENA GERASIMOVA	{"email": "gerasimova-elena_1974@postgrespro.ru", "phone": "+70896566078"}
0005434880276	B35819	1617 555305	LYUDMILA NIKIFOROVA	{"email": "nikiforova-l081975@postgrespro.ru", "phone": "+70645586027"}
0005434880277	9260FD	5075 927406	OLEG VASILEV	{"email": "o.vasilev_1961@postgrespro.ru", "phone": "+70302427048"}
0005434880278	CFDEBC	3207 898516	ALEKSANDR SEMENOV	{"email": "semenov.a.14041968@postgrespro.ru", "phone": "+70735777207"}
0005434880279	A43C37	2341 462247	ANTONINA IVANOVA	{"email": "a_ivanova.1952@postgrespro.ru", "phone": "+70955148245"}
0005434880280	7C567D	6513 831474	SERGEY KARPOV	{"phone": "+70515550906"}
0005434880281	7C567D	3774 275046	VALENTINA FROLOVA	{"phone": "+70179493435"}
0005434880282	7C567D	5770 209163	DMITRIY KUZMIN	{"phone": "+70120978285"}
0005434880283	518BFF	7027 602123	SERGEY MEDVEDEV	{"phone": "+70953657710"}
0005434880284	518BFF	0686 376734	KSENIYA POLYAKOVA	{"email": "k-polyakova_22121975@postgrespro.ru", "phone": "+70993546259"}
0005434880285	1EDA49	5705 056580	KLAVDIYA SOLOVEVA	{"phone": "+70172349025"}
0005434880286	1EDA49	9959 920108	ANASTASIYA ALEKSEEVA	{"email": "anastasiya-alekseeva_1973@postgrespro.ru", "phone": "+70655772126"}
0005434880287	A8EA0F	3596 837307	MARIYA AFANASEVA	{"phone": "+70391554659"}
0005434880288	586F2B	0806 064449	VLADISLAV KARPOV	{"email": "karpov_v_13051964@postgrespro.ru", "phone": "+70608896543"}
0005434880289	586F2B	4016 894752	VLADIMIR IVANOV	{"phone": "+70855080768"}
0005434880290	DDD46A	1394 070253	TAISIYA FILATOVA	{"email": "filatova_taisiya.26091974@postgrespro.ru", "phone": "+70556897948"}
0005434880291	BC3B86	4712 655282	TATYANA STEPANOVA	{"phone": "+70095974519"}
0005434880292	CDA58E	6883 248740	SERGEY OSIPOV	{"email": "sosipov.081975@postgrespro.ru", "phone": "+70985873252"}
0005434880293	26F9FB	4406 753728	ALEKSANDR BELOV	{"email": "belov.a.021979@postgrespro.ru", "phone": "+70290396618"}
0005434880294	322CC4	0457 159829	IVAN EGOROV	{"email": "ivan-egorov_17041972@postgrespro.ru", "phone": "+70481070482"}
0005434880295	8952D5	0401 164718	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov_1961@postgrespro.ru", "phone": "+70317598095"}
0005434880296	8952D5	5214 339355	YURIY TIMOFEEV	{"email": "yuriytimofeev.21031974@postgrespro.ru", "phone": "+70782100025"}
0005434880297	293586	3296 283003	YULIYA VOLKOVA	{"phone": "+70174893589"}
0005434880298	E56472	6283 660029	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila10071979@postgrespro.ru", "phone": "+70142952637"}
0005434880299	E56472	2378 737284	SVETLANA FILATOVA	{"phone": "+70247925454"}
0005434880300	5F3D0F	2801 321441	VARVARA KUZMINA	{"email": "varvara_kuzmina_1981@postgrespro.ru", "phone": "+70694051848"}
0005434880301	7D051D	0040 550865	IVAN MAKSIMOV	{"email": "maksimovi10031970@postgrespro.ru", "phone": "+70428629548"}
0005434880302	848FA5	0941 131408	TATYANA ROMANOVA	{"email": "romanova.t_11121972@postgrespro.ru", "phone": "+70856527834"}
0005434880303	848FA5	8009 692003	MARINA KUZNECOVA	{"email": "kuznecova-m1970@postgrespro.ru", "phone": "+70687537207"}
0005434880304	848FA5	1359 872173	DINA DAVYDOVA	{"phone": "+70778852249"}
0005434880305	2A3A2B	8964 817418	NATALYA CHERNOVA	{"email": "n_chernova.121977@postgrespro.ru", "phone": "+70871692850"}
0005434880306	3C5FC6	9752 298687	EKATERINA KUZNECOVA	{"phone": "+70815847781"}
0005434880307	3C5FC6	5789 124609	ELENA DENISOVA	{"phone": "+70756005200"}
0005434880308	33BDB4	4398 956004	GLEB ZAKHAROV	{"email": "gleb-zakharov_28031972@postgrespro.ru", "phone": "+70406944241"}
0005434880309	AA4561	8112 672119	GALINA KONOVALOVA	{"phone": "+70434741458"}
0005434880310	4A6CC0	5527 881375	ALEKSANDR NOVIKOV	{"phone": "+70330828389"}
0005434880311	4A6CC0	2379 167900	SERGEY VOROBEV	{"email": "s.vorobev041973@postgrespro.ru", "phone": "+70477846334"}
0005434880312	B55D44	6038 883848	ARTEM SMIRNOV	{"email": "a.smirnov-101973@postgrespro.ru", "phone": "+70331971947"}
0005434880313	BFBAD5	7098 500391	NINA PETROVA	{"email": "petrova.nina041961@postgrespro.ru", "phone": "+70085816303"}
0005434880314	D7CA00	1692 326165	LYUBOV KOROLEVA	{"email": "l-koroleva_011971@postgrespro.ru", "phone": "+70517768577"}
0005434880315	97F8AB	7652 482297	VIKTOR ABRAMOV	{"email": "abramov.viktor101969@postgrespro.ru", "phone": "+70392167653"}
0005434880316	97F8AB	0910 674042	KIRILL SHEVCHENKO	{"phone": "+70259414441"}
0005434880317	EEE4A1	9965 066830	ALEKSANDRA VOLKOVA	{"phone": "+70306683432"}
0005434880318	EEE4A1	6638 584512	EVGENIYA ERMAKOVA	{"email": "ermakova_evgeniya_011980@postgrespro.ru", "phone": "+70974070145"}
0005434880319	E7CAA5	6506 519132	VLADIMIR DAVYDOV	{"email": "davydovvladimir-1964@postgrespro.ru", "phone": "+70482021736"}
0005434880320	7A63E1	1831 804816	LIDIYA VOLKOVA	{"phone": "+70142918556"}
0005434880321	7A63E1	8174 001855	RUSLAN KARPOV	{"email": "r_karpov_1976@postgrespro.ru", "phone": "+70627478226"}
0005434880322	D7FC63	7127 532702	BORIS ROMANOV	{"phone": "+70248751293"}
0005434880323	947CA5	9549 422040	ALEKSANDR ZAKHAROV	{"phone": "+70359100983"}
0005434880324	84C707	7503 271533	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr-24061962@postgrespro.ru", "phone": "+70186825232"}
0005434880325	273671	4852 760869	ALEKSANDR ALEKSANDROV	{"phone": "+70815125017"}
0005434880326	7B3E49	7773 482564	TAMARA BELOVA	{"email": "belova.t_06011983@postgrespro.ru", "phone": "+70949805344"}
0005434880327	7B3E49	8360 090284	MARIYA ZAKHAROVA	{"email": "mzakharova.31101964@postgrespro.ru", "phone": "+70013604209"}
0005434880328	560027	6926 070192	MARIYA MOISEEVA	{"email": "mariya_moiseeva-1963@postgrespro.ru", "phone": "+70153660577"}
0005434880329	7DC19A	9956 751396	OLGA FEDOROVA	{"phone": "+70918422098"}
0005434880330	7DC19A	7449 424430	ANATOLIY KOROLEV	{"phone": "+70215823311"}
0005434880331	09E80D	7870 990556	VIKTOR CHERNOV	{"email": "chernov_v_071971@postgrespro.ru", "phone": "+70477029557"}
0005434880332	09E80D	9967 159806	VALENTINA VOLKOVA	{"email": "v_volkova.22031984@postgrespro.ru", "phone": "+70578798340"}
0005434880333	8E7A6A	6235 238506	TATYANA SEMENOVA	{"phone": "+70170127656"}
0005434880334	4D8FF3	8666 563774	VYACHESLAV SHEVCHENKO	{"phone": "+70784662438"}
0005434880335	4D8FF3	3565 538784	DANIIL ZHUKOV	{"phone": "+70518100237"}
0005434880336	5FA39A	8548 569225	ANATOLIY AFANASEV	{"email": "afanasev_a051973@postgrespro.ru", "phone": "+70046240995"}
0005434880337	7BAE56	9656 803654	EKATERINA PAVLOVA	{"email": "pavlovae071963@postgrespro.ru", "phone": "+70694614625"}
0005434880338	7BAE56	4470 539661	RITA VASILEVA	{"email": "rita.vasileva-20021977@postgrespro.ru", "phone": "+70968685521"}
0005434880339	D175D4	8990 723764	VLADIMIR ZHURAVLEV	{"phone": "+70567371166"}
0005434880340	EA977A	9974 833044	MARIYA IVANOVA	{"email": "mariya_ivanova.031960@postgrespro.ru", "phone": "+70959452742"}
0005434880341	961FEC	2103 094624	ARTEM BELOV	{"email": "artem_belov-1972@postgrespro.ru", "phone": "+70970006361"}
0005434880342	961FEC	1150 121501	NINA MEDVEDEVA	{"email": "nmedvedeva_1960@postgrespro.ru", "phone": "+70214619736"}
0005434880343	4554D7	2531 742859	LYUDMILA SCHERBAKOVA	{"email": "scherbakovalyudmila-071974@postgrespro.ru", "phone": "+70535159901"}
0005434880344	E7ACD8	5126 619006	ANNA RYABOVA	{"phone": "+70507419427"}
0005434880345	E7ACD8	8603 431006	ULYANA ZAKHAROVA	{"email": "ulyana_zakharova-02081969@postgrespro.ru", "phone": "+70357843635"}
0005434880346	A7E710	8747 513624	ELVIRA VLASOVA	{"phone": "+70293258749"}
0005434880347	A7E710	3318 499262	YURIY GUSEV	{"phone": "+70658979530"}
0005434880348	1EB29C	8384 351885	MIKHAIL MELNIKOV	{"phone": "+70642904477"}
0005434880349	E817B6	1105 571513	ALINA NESTEROVA	{"phone": "+70559892203"}
0005434880350	CD4CC7	3580 199836	OLGA PAVLOVA	{"email": "olga_pavlova.24031965@postgrespro.ru", "phone": "+70941593893"}
0005434880351	CD4CC7	3604 668273	VLADIMIR MOISEEV	{"phone": "+70625637391"}
0005434880352	88C46C	0018 324167	NIKOLAY EGOROV	{"phone": "+70272049101"}
0005434880353	88C46C	1262 882129	NINA KUZNECOVA	{"email": "kuznecova-nina_07031969@postgrespro.ru", "phone": "+70351883356"}
0005434880354	2D39EE	7671 073675	ANTONINA POTAPOVA	{"phone": "+70279018123"}
0005434880355	2D39EE	6638 090819	VLADIMIR SAVELEV	{"phone": "+70152450496"}
0005434880356	028263	5766 632704	KARINA KISELEVA	{"email": "karinakiseleva_03061972@postgrespro.ru", "phone": "+70240090240"}
0005434880357	C664C3	9965 055498	OLGA IVANOVA	{"email": "o_ivanova_1964@postgrespro.ru", "phone": "+70113230317"}
0005434880358	C664C3	2979 299695	ALEKSANDR BORISOV	{"email": "aleksandrborisov.28061972@postgrespro.ru", "phone": "+70764664441"}
0005434880359	B04462	2065 639407	ELENA ROMANOVA	{"phone": "+70216287624"}
0005434880360	45E78F	5909 505320	LYUDMILA SOKOLOVA	{"phone": "+70451712764"}
0005434880361	B1D473	5607 658031	EVGENIY VOLKOV	{"email": "volkov_e1979@postgrespro.ru", "phone": "+70786740930"}
0005434880362	B1D473	9367 818454	ALINA FEDOROVA	{"phone": "+70652306712"}
0005434880363	C94BB6	9829 911709	VADIM KOZLOV	{"email": "kozlov-vadim23011965@postgrespro.ru", "phone": "+70996799063"}
0005434880364	878D9D	5282 989594	TATYANA BELOVA	{"phone": "+70719245936"}
0005434880365	BDAAEE	7666 527309	INNA FEDOROVA	{"email": "fedorova.i_09111967@postgrespro.ru", "phone": "+70740478062"}
0005434880366	BDAAEE	3392 771121	VLADA FOMINA	{"phone": "+70230928721"}
0005434880367	BDAAEE	5566 918432	IGOR BELOV	{"email": "i.belov25101975@postgrespro.ru", "phone": "+70456123281"}
0005434880368	051C01	6695 387907	VLADIMIR BARANOV	{"email": "baranov-vladimir-071971@postgrespro.ru", "phone": "+70914019941"}
0005434880369	051C01	5501 710244	EGOR KUZNECOV	{"email": "kuznecove-1971@postgrespro.ru", "phone": "+70155750260"}
0005434880370	BDB9D6	9246 023652	ALFIYA NAZAROVA	{"phone": "+70359605431"}
0005434880371	BDB9D6	0019 060222	SERGEY TARASOV	{"phone": "+70361714158"}
0005434880372	AEE075	8272 520354	YURIY KUZNECOV	{"email": "ykuznecov.031979@postgrespro.ru", "phone": "+70367355414"}
0005434880373	EF2413	3728 195732	ALEKSANDR FILIPPOV	{"email": "filippov_a_1968@postgrespro.ru", "phone": "+70222895757"}
0005434880374	83BB42	9269 587419	YURIY SAVELEV	{"phone": "+70768402396"}
0005434880375	83BB42	5506 018246	ALENA SOLOVEVA	{"phone": "+70141769035"}
0005434880376	83BB42	7819 622232	LYUDMILA KONDRATEVA	{"phone": "+70998653764"}
0005434880377	2A2865	8058 148719	NIKOLAY AFANASEV	{"phone": "+70786018457"}
0005434880378	4EC41E	5376 708476	LIDIYA YAKOVLEVA	{"phone": "+70588712849"}
0005434880379	A81716	5437 822032	ANTONINA NIKITINA	{"email": "anikitina_30091964@postgrespro.ru", "phone": "+70042176229"}
0005434880380	A81716	7266 795955	SERGEY OSIPOV	{"phone": "+70272411383"}
0005434880381	20A7ED	3310 334524	MAKSIM ZHUKOV	{"email": "zhukovmaksim_1957@postgrespro.ru", "phone": "+70653767590"}
0005434880382	812E58	5257 507760	EVGENIY GERASIMOV	{"email": "gerasimov-evgeniy051975@postgrespro.ru", "phone": "+70601067859"}
0005434880383	AB0A60	5301 406875	SHAMIL SAVELEV	{"email": "shamil.savelev1977@postgrespro.ru", "phone": "+70993583582"}
0005434880384	681404	2741 763514	ROMAN SEMENOV	{"email": "semenovr_1972@postgrespro.ru", "phone": "+70827114712"}
0005434880385	92623D	9381 219097	ELIZAVETA ZAYCEVA	{"email": "elizavetazayceva-1973@postgrespro.ru", "phone": "+70681612314"}
0005434880386	ED81BD	0203 128440	VALERIYA MATVEEVA	{"phone": "+70859400137"}
0005434880387	ED81BD	3780 097360	ALEKSANDR ZAKHAROV	{"email": "zakharov.a-26021972@postgrespro.ru", "phone": "+70605231261"}
0005434880388	042E2D	0054 650398	DMITRIY PETROV	{"phone": "+70560413736"}
0005434880389	042E2D	8200 453712	MARINA FEDOROVA	{"phone": "+70809983778"}
0005434880390	22EFEE	9414 036586	ALEFTINA TIMOFEEVA	{"email": "aleftinatimofeeva-27101966@postgrespro.ru", "phone": "+70189815905"}
0005434880391	917E25	6561 117916	ELENA BARANOVA	{"email": "baranovae-101966@postgrespro.ru", "phone": "+70157505039"}
0005434880392	F76C4B	3370 380239	PAVEL SEMENOV	{"phone": "+70288981102"}
0005434880393	81261E	2173 883311	VASILIY PAVLOV	{"phone": "+70725690681"}
0005434880394	EA8D4A	7601 065859	ANGELINA TIMOFEEVA	{"email": "timofeeva_angelina.031985@postgrespro.ru", "phone": "+70647898500"}
0005434880395	C016EA	5502 949979	ANDREY TIMOFEEV	{"email": "a_timofeev-16021962@postgrespro.ru", "phone": "+70040429526"}
0005434880396	C016EA	8714 514013	DMITRIY ALEKSANDROV	{"phone": "+70752794952"}
0005434880397	C016EA	0787 203109	ALEKSANDR YAKOVLEV	{"phone": "+70552264555"}
0005434880398	D729EE	8742 031666	NIKOLAY SAVELEV	{"email": "savelev.nikolay_021985@postgrespro.ru", "phone": "+70140285602"}
0005434880399	D7ACE6	3609 485772	LYUDMILA GERASIMOVA	{"phone": "+70671037800"}
0005434880400	D7ACE6	4945 953348	OLGA RODIONOVA	{"phone": "+70129774245"}
0005434880401	F7DA06	5478 900666	ANDREY VLASOV	{"email": "vlasov.a.24111968@postgrespro.ru", "phone": "+70280004927"}
0005434880402	0E4A1C	1276 713278	EKATERINA FADEEVA	{"email": "fadeevae1965@postgrespro.ru", "phone": "+70382716225"}
0005434880403	BC8FFE	1273 568822	IVAN ZHURAVLEV	{"phone": "+70027005167"}
0005434880404	B99903	6865 659367	TATYANA BELYAEVA	{"phone": "+70371034147"}
0005434880405	D7B130	5893 113828	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev17021965@postgrespro.ru", "phone": "+70992727384"}
0005434880406	C0CCC1	1007 108342	ALEKSANDR VASILEV	{"email": "vasilev_a11041968@postgrespro.ru", "phone": "+70581190552"}
0005434880407	C0CCC1	7587 877398	GALINA MIKHAYLOVA	{"email": "mikhaylova-g.03061980@postgrespro.ru", "phone": "+70732204599"}
0005434880408	8CDE3C	2866 589796	ANAIT MIRONOVA	{"email": "anait_mironova-29081964@postgrespro.ru", "phone": "+70480193184"}
0005434880409	663A2B	0190 635769	TATYANA SEMENOVA	{"phone": "+70876841007"}
0005434880410	5F2FC8	0807 924672	NINA NESTEROVA	{"email": "n.nesterova071984@postgrespro.ru", "phone": "+70556228262"}
0005434880411	F17961	7801 613754	ALEKSEY FEDOROV	{"phone": "+70381798430"}
0005434880412	B517C4	3890 517493	DMITRIY ZHURAVLEV	{"phone": "+70372134396"}
0005434880413	2514CD	4105 578294	IRINA IVANOVA	{"phone": "+70932209420"}
0005434880414	23C975	2207 794622	VIKTORIYA LOGINOVA	{"phone": "+70015932179"}
0005434880415	181171	1845 213324	ANTON IVANOV	{"phone": "+70825378827"}
0005434880416	94C70E	7017 729171	LILIYA FILATOVA	{"email": "filatova-l_12011979@postgrespro.ru", "phone": "+70645349810"}
0005434880417	7B163B	4180 343605	EKATERINA KOROLEVA	{"phone": "+70466961305"}
0005434880418	C992D5	3564 279468	NIKOLAY BORISOV	{"phone": "+70552049649"}
0005434880419	054243	4959 029227	EKATERINA SIDOROVA	{"email": "sidorova.ekaterina_1970@postgrespro.ru", "phone": "+70068092281"}
0005434880420	054243	4375 245103	GEORGIY POPOV	{"email": "popov.georgiy_121969@postgrespro.ru", "phone": "+70346218004"}
0005434880421	054243	1618 537084	TATYANA KOROLEVA	{"phone": "+70040338212"}
0005434880422	054243	0029 788063	ALEKSANDR DENISOV	{"phone": "+70925864928"}
0005434880423	6FE46B	1710 073059	LYUBOV KONOVALOVA	{"email": "konovalova_l.08111974@postgrespro.ru", "phone": "+70574389996"}
0005434880424	6B3D09	6559 536886	DENIS KRASNOV	{"phone": "+70788898145"}
0005434880425	39DB24	3551 752581	ALEVTINA EFREMOVA	{"email": "efremova-a_031975@postgrespro.ru", "phone": "+70373518269"}
0005434880426	592895	6386 460229	NATALYA IVANOVA	{"email": "ivanova.n13011971@postgrespro.ru", "phone": "+70926667112"}
0005434880427	11FBF4	9914 217947	VYACHESLAV SAVELEV	{"phone": "+70292366365"}
0005434880428	11FBF4	9617 514349	BORIS GORBUNOV	{"phone": "+70376174609"}
0005434880429	E006D3	8164 435234	MARIYA PETROVA	{"phone": "+70543179870"}
0005434880430	316DF2	8559 422711	ALEKSANDR FOMIN	{"email": "aleksandrfomin_08021984@postgrespro.ru", "phone": "+70031748765"}
0005434880431	69928E	1811 007621	RAISA KOROLEVA	{"phone": "+70575185807"}
0005434880432	69928E	0369 038171	ALEKSEY RODIONOV	{"email": "rodionovaleksey_20011973@postgrespro.ru", "phone": "+70855025228"}
0005434880433	FC87CB	3604 410816	LYUBOV MAKAROVA	{"email": "lmakarova-20091966@postgrespro.ru", "phone": "+70389617669"}
0005434880434	1913CD	2566 527273	GULFIYA SMIRNOVA	{"email": "g-smirnova1975@postgrespro.ru", "phone": "+70498710494"}
0005434880435	81AEF9	8650 894752	SERGEY BELOV	{"email": "belov.s15071973@postgrespro.ru", "phone": "+70732071283"}
0005434880436	81AEF9	7126 986097	SERGEY POPOV	{"phone": "+70247228351"}
0005434880437	81AEF9	8746 701340	ELENA ERMAKOVA	{"email": "ermakova-elena1970@postgrespro.ru", "phone": "+70246642608"}
0005434880438	5AE424	4221 202716	NATALYA ANDREEVA	{"email": "n-andreeva_121975@postgrespro.ru", "phone": "+70487366599"}
0005434880439	D93D44	4913 766519	ANASTASIYA POPOVA	{"email": "popova-anastasiya.121971@postgrespro.ru", "phone": "+70474949428"}
0005434880440	01F9E8	2949 987757	LYUDMILA ZAKHAROVA	{"email": "zakharovalyudmila121972@postgrespro.ru", "phone": "+70718849428"}
0005434880441	E4A466	6880 403496	ALEKSANDR SAVELEV	{"phone": "+70914264489"}
0005434880442	E4A466	1115 418677	ANDREY MELNIKOV	{"phone": "+70256813065"}
0005434880443	8964E2	3803 003734	ALEKSANDR SOROKIN	{"phone": "+70226716460"}
0005434880444	A79EA7	0818 283889	VLADIMIR PETROV	{"email": "petrov_v.17121979@postgrespro.ru", "phone": "+70979511199"}
0005434880445	A79EA7	2848 595284	STEPAN FEDOROV	{"email": "s_fedorov-021971@postgrespro.ru", "phone": "+70212792916"}
0005434880446	A79EA7	5258 445977	MIKHAIL KOZLOV	{"email": "mikhail-kozlov_11041962@postgrespro.ru", "phone": "+70410872723"}
0005434880447	435BE4	6190 083843	MARINA FOMINA	{"email": "fomina-marina.09011957@postgrespro.ru", "phone": "+70795382258"}
0005434880448	435BE4	7204 138504	PAVEL ILIN	{"email": "ilinpavel_1973@postgrespro.ru", "phone": "+70246896296"}
0005434880449	D7A4F6	0770 715310	VADIM MATVEEV	{"phone": "+70682578439"}
0005434880450	2F290E	0931 241737	VIKTORIYA VLASOVA	{"email": "viktoriya_vlasova.091983@postgrespro.ru", "phone": "+70443983896"}
0005434880451	D84F80	8475 650170	TAMARA VLASOVA	{"phone": "+70048640747"}
0005434880452	E447A1	7639 599557	LYUDMILA MELNIKOVA	{"email": "l.melnikova-1979@postgrespro.ru", "phone": "+70316285732"}
0005434880453	69D01C	7093 366396	MARINA STEPANOVA	{"phone": "+70506270237"}
0005434880454	F91C9B	1656 155225	SVETLANA SOKOLOVA	{"email": "svetlana.sokolova1975@postgrespro.ru", "phone": "+70597507370"}
0005434880455	F91C9B	0648 069574	KIRILL ANDREEV	{"email": "andreev.kirill_1977@postgrespro.ru", "phone": "+70403559138"}
0005434880456	826B46	4156 648113	ROMAN KONOVALOV	{"phone": "+70583461447"}
0005434880457	826B46	1326 178518	ANASTASIYA STEPANOVA	{"email": "stepanova_a_01031971@postgrespro.ru", "phone": "+70193385590"}
0005434880458	826B46	4489 407758	ELENA KOZLOVA	{"email": "elena_kozlova.1978@postgrespro.ru", "phone": "+70574883379"}
0005434880459	75D8D7	2144 747215	ANTON PETROV	{"email": "a_petrov1974@postgrespro.ru", "phone": "+70613582842"}
0005434880460	75D8D7	5920 389465	VIKTORIYA ANISIMOVA	{"phone": "+70947816848"}
0005434880461	4D46DE	6833 777961	TAMARA KARPOVA	{"email": "t.karpova-13081985@postgrespro.ru", "phone": "+70824312276"}
0005434880462	43B0F8	1636 440678	DMITRIY IVANOV	{"phone": "+70283888259"}
0005434880463	31491F	8694 753578	OLGA VOLKOVA	{"email": "o-volkova-28051970@postgrespro.ru", "phone": "+70561203222"}
0005434880464	5D0D91	5677 639222	VALERIY ZHUKOV	{"email": "zhukov-v-23091961@postgrespro.ru", "phone": "+70898676442"}
0005434880465	C24876	9471 386680	SERGEY ZAKHAROV	{"phone": "+70514176638"}
0005434880466	C24876	5922 859343	VLADISLAV KONOVALOV	{"phone": "+70105938431"}
0005434880467	B2193B	5060 678753	LIDIYA SEMENOVA	{"email": "lidiyasemenova111985@postgrespro.ru", "phone": "+70311875156"}
0005434880468	B2193B	7615 065518	SOFYA SOROKINA	{"email": "sofya-sorokina_06091974@postgrespro.ru", "phone": "+70808430396"}
0005434880469	08593A	6707 940893	ALEKSANDR CHERNOV	{"phone": "+70432628594"}
0005434880470	605EBD	9619 638726	OLGA KUZMINA	{"email": "kuzmina_olga_16101979@postgrespro.ru", "phone": "+70307495005"}
0005434880471	FE9186	1606 159599	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda.1974@postgrespro.ru", "phone": "+70530086318"}
0005434880472	206ED3	2187 626273	EVGENIY MELNIKOV	{"phone": "+70668390196"}
0005434880473	206ED3	1632 610005	VLADIMIR SOKOLOV	{"phone": "+70433810618"}
0005434880474	A78E48	8947 016608	IGOR MAKSIMOV	{"phone": "+70799637229"}
0005434880475	F8F50C	5477 606656	VALERIY MOROZOV	{"email": "morozov-valeriy091974@postgrespro.ru", "phone": "+70380440892"}
0005434880476	F8F50C	9851 440824	DMITRIY BORISOV	{"phone": "+70144588584"}
0005434880477	E0AD25	5337 189564	MIKHAIL SHEVCHENKO	{"email": "m_shevchenko_27081974@postgrespro.ru", "phone": "+70141590209"}
0005434880478	E0AD25	6324 223511	ARINA KOMAROVA	{"phone": "+70550732170"}
0005434880479	B9A1C2	3846 755846	OLEG KOROLEV	{"email": "oleg.korolev1966@postgrespro.ru", "phone": "+70996168840"}
0005434880480	F9502A	2306 712344	NIKOLAY NAUMOV	{"phone": "+70663485308"}
0005434880481	0B2F8C	7027 363448	ELENA MIRONOVA	{"phone": "+70709654624"}
0005434880482	0B2F8C	0108 221513	ARTEM ZHUKOV	{"phone": "+70997754726"}
0005434880483	833327	0850 403103	NADEZHDA SOROKINA	{"phone": "+70526955872"}
0005434880484	833327	6079 997629	PETR SMIRNOV	{"email": "smirnov_p_081982@postgrespro.ru", "phone": "+70755109298"}
0005434880485	2A8E75	9671 001212	VLADIMIR EGOROV	{"email": "vegorov011977@postgrespro.ru", "phone": "+70714980537"}
0005434880486	2A8E75	1043 589572	SVETLANA SOROKINA	{"phone": "+70984534492"}
0005434880487	56EF08	9968 494528	LYUBOV TITOVA	{"phone": "+70830888315"}
0005434880488	D99C7B	7398 913981	VALENTINA MOISEEVA	{"email": "moiseeva-v031973@postgrespro.ru", "phone": "+70293201937"}
0005434880489	D99C7B	7389 551774	STANISLAV ALEKSEEV	{"phone": "+70328209552"}
0005434880490	8A7603	0919 512230	VALENTINA MAKAROVA	{"email": "makarova_valentina_081964@postgrespro.ru", "phone": "+70135492381"}
0005434880491	F5E12C	6462 743438	TATYANA ROMANOVA	{"phone": "+70869852894"}
0005434880492	F5E12C	4850 990704	ILGIZ TIKHONOV	{"email": "ilgiz_tikhonov_20011965@postgrespro.ru", "phone": "+70448950383"}
0005434880493	332074	3808 580603	VIKTOR ANDREEV	{"email": "v-andreev_041984@postgrespro.ru", "phone": "+70835088614"}
0005434880494	332074	6249 168097	ELENA FEDOROVA	{"phone": "+70184023430"}
0005434880495	2DCD3B	8318 701071	OLGA KOZLOVA	{"email": "kozlova.o.031977@postgrespro.ru", "phone": "+70733934229"}
0005434880496	549E4B	2182 331018	VIKTOR FEDOTOV	{"email": "v-fedotov.04111973@postgrespro.ru", "phone": "+70040813102"}
0005434880497	2EFE8E	4369 578951	ELENA MOROZOVA	{"email": "e_morozova.27121973@postgrespro.ru", "phone": "+70667557631"}
0005434880498	56812C	4328 811591	SERGEY NIKOLAEV	{"email": "sergey_nikolaev31081981@postgrespro.ru", "phone": "+70013637364"}
0005434880499	1EDE1E	8344 447116	RINAT KRASNOV	{"email": "rinat-krasnov1980@postgrespro.ru", "phone": "+70639229781"}
0005434880500	1EDE1E	6951 537638	DENIS PETROV	{"phone": "+70508279543"}
0005434880501	4F1A46	7989 984095	ARTEM SIDOROV	{"email": "a.sidorov.1969@postgrespro.ru", "phone": "+70142015323"}
0005434880502	07B038	5066 641961	LEONID DENISOV	{"phone": "+70919134898"}
0005434880503	B9616C	9168 892410	GRIGORIY SMIRNOV	{"phone": "+70323280912"}
0005434880504	4FE32F	6349 209701	VITALIY MARTYNOV	{"phone": "+70023347100"}
0005434880505	B56A8C	2267 602424	ARTEM KULIKOV	{"email": "kulikov.artem_14061980@postgrespro.ru", "phone": "+70091521983"}
0005434880506	403A36	6468 727943	ANNA ALEKSEEVA	{"email": "alekseevaanna091964@postgrespro.ru", "phone": "+70969651650"}
0005434880507	4B07AD	3922 729385	NINA SOLOVEVA	{"phone": "+70505556700"}
0005434880508	D02C1C	2449 610066	LILIYA NAZAROVA	{"email": "l-nazarova-1968@postgrespro.ru", "phone": "+70217384114"}
0005434880509	4FC797	4696 207676	TATYANA OSIPOVA	{"email": "tatyana-osipova26041965@postgrespro.ru", "phone": "+70017679225"}
0005434880510	2F39EC	1492 338173	DANILA ANTONOV	{"phone": "+70093012092"}
0005434880511	A52ECB	8680 835901	IRINA BORISOVA	{"email": "borisova.i.30111968@postgrespro.ru", "phone": "+70780894882"}
0005434880512	B07865	9086 779362	SERGEY FEDOROV	{"email": "fedorov.sergey.1977@postgrespro.ru", "phone": "+70217744526"}
0005434880513	6483D5	6353 971891	LYUDMILA DENISOVA	{"phone": "+70103388879"}
0005434880514	6483D5	6379 862970	ANNA POLYAKOVA	{"phone": "+70095599009"}
0005434880515	DA7660	7267 192022	ZINAIDA PAVLOVA	{"phone": "+70024863648"}
0005434880516	DA7660	4187 336904	ANATOLIY NAZAROV	{"phone": "+70160254642"}
0005434880517	DA7660	3196 177604	OLGA FILIPPOVA	{"phone": "+70784871190"}
0005434880518	A651A4	5658 353736	ARTEM DAVYDOV	{"email": "adavydov_071966@postgrespro.ru", "phone": "+70399754977"}
0005434880519	982610	7006 976937	MARINA PAVLOVA	{"phone": "+70525530469"}
0005434880520	982610	9397 234159	ALEKSANDR KUZMIN	{"email": "a_kuzmin091970@postgrespro.ru", "phone": "+70868453105"}
0005434880521	982610	9091 259535	YULIYA KOZLOVA	{"email": "kozlovayuliya.21091966@postgrespro.ru", "phone": "+70109976406"}
0005434880522	2A0973	4273 684133	VALENTINA ZAYCEVA	{"email": "valentina-zayceva-041978@postgrespro.ru", "phone": "+70745924767"}
0005434880523	142963	4461 208577	EVGENIY NAZAROV	{"email": "nazarov-e-09021973@postgrespro.ru", "phone": "+70296515870"}
0005434880524	6DC692	1920 088744	EKATERINA SOKOLOVA	{"email": "esokolova.1982@postgrespro.ru", "phone": "+70662453825"}
0005434880525	A19243	9766 013391	LYUDMILA ANDREEVA	{"email": "andreeva-lyudmila_1982@postgrespro.ru", "phone": "+70109881171"}
0005434880526	A19243	0884 965617	ELENA MALYSHEVA	{"email": "e.malysheva1966@postgrespro.ru", "phone": "+70208279293"}
0005434880527	A694EC	2043 378048	EVGENIY SAVELEV	{"email": "savelev.evgeniy-21051971@postgrespro.ru", "phone": "+70615268407"}
0005434880528	76690D	4400 102798	IVAN FEDOROV	{"email": "fedorov-ivan_071974@postgrespro.ru", "phone": "+70016268310"}
0005434880529	1FE3F1	9694 958428	VYACHESLAV DENISOV	{"email": "denisovvyacheslav.1959@postgrespro.ru", "phone": "+70759228013"}
0005434880530	1FE3F1	6432 693586	BORIS MARTYNOV	{"phone": "+70251155904"}
0005434880531	932B8F	4931 092669	OLGA SOKOLOVA	{"email": "olga-sokolova_27081976@postgrespro.ru", "phone": "+70524975573"}
0005434880588	C6A384	3518 255982	ELENA ORLOVA	{"phone": "+70842686141"}
0005434880532	50B6AB	3734 249818	DMITRIY ABRAMOV	{"email": "abramov.d_1961@postgrespro.ru", "phone": "+70232414626"}
0005434880533	B1F550	3844 251423	PAVEL GORBUNOV	{"email": "gorbunov.pavel111976@postgrespro.ru", "phone": "+70447729956"}
0005434880534	B1F550	5502 763806	MARIYA MATVEEVA	{"phone": "+70398325322"}
0005434880535	87C71E	6744 630153	EKATERINA IVANOVA	{"email": "ivanova-ekaterina29061978@postgrespro.ru", "phone": "+70397563453"}
0005434880536	1D1CAA	7634 279743	ARTEM SMIRNOV	{"phone": "+70230078436"}
0005434880537	1D1CAA	6192 957797	OLGA GORBUNOVA	{"phone": "+70948990667"}
0005434880538	8BFBE3	6534 628705	ALEKSANDRA IVANOVA	{"email": "aleksandraivanova_04011970@postgrespro.ru", "phone": "+70895478758"}
0005434880539	EB187E	6725 167462	TATYANA EGOROVA	{"email": "t-egorova-1963@postgrespro.ru", "phone": "+70742157555"}
0005434880540	F23177	6579 976506	MIKHAIL TIMOFEEV	{"email": "m_timofeev.02021974@postgrespro.ru", "phone": "+70171139414"}
0005434880541	BF246A	9391 970708	SERGEY SEMENOV	{"phone": "+70815416636"}
0005434880542	BF246A	0217 254098	YANA MELNIKOVA	{"email": "melnikova-y1971@postgrespro.ru", "phone": "+70227291232"}
0005434880543	E40EA6	9271 907045	TATYANA POLYAKOVA	{"phone": "+70367405148"}
0005434880544	E40EA6	3341 232556	TATYANA ZOTOVA	{"phone": "+70505468393"}
0005434880545	A37350	5329 117422	VIKTOR FEDOTOV	{"phone": "+70985525531"}
0005434880546	A37350	7647 034015	YURIY FEDOTOV	{"email": "yfedotov10031982@postgrespro.ru", "phone": "+70108512011"}
0005434880547	E30F86	7269 737214	ANTONINA ZAYCEVA	{"email": "antoninazayceva-14051966@postgrespro.ru", "phone": "+70038103224"}
0005434880548	71D393	6122 681859	IGOR SEMENOV	{"phone": "+70914328174"}
0005434880549	FEB3AC	3298 780256	ALENA IVANOVA	{"email": "ivanova_alena.1970@postgrespro.ru", "phone": "+70310369845"}
0005434880550	2677BD	3365 329894	IGNAT POPOV	{"email": "popovignat_30071974@postgrespro.ru", "phone": "+70719181705"}
0005434880551	2677BD	1114 214891	RADIK MAKSIMOV	{"email": "rmaksimov_19041978@postgrespro.ru", "phone": "+70149483781"}
0005434880552	2677BD	9594 655905	GALINA LOGINOVA	{"email": "loginova_galina.061984@postgrespro.ru", "phone": "+70313423614"}
0005434880553	EA856E	9692 589072	MARGARITA KONDRATEVA	{"phone": "+70472542112"}
0005434880554	FC1061	2232 317647	LYUDMILA NESTEROVA	{"email": "lyudmila.nesterova-19071976@postgrespro.ru", "phone": "+70902155014"}
0005434880555	FC1061	8125 047583	MARIYA MELNIKOVA	{"email": "mariya.melnikova.11121977@postgrespro.ru", "phone": "+70070704283"}
0005434880556	0FAF20	2022 393732	LIDIYA MELNIKOVA	{"phone": "+70215810547"}
0005434880557	0FAF20	9257 714915	ARTEM CHERNOV	{"email": "chernovartem1960@postgrespro.ru", "phone": "+70656608719"}
0005434880558	D77DAD	1716 975219	ELENA POPOVA	{"phone": "+70609872081"}
0005434880559	D77DAD	8286 278113	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr_121978@postgrespro.ru", "phone": "+70684343114"}
0005434880560	A160A4	5898 733479	ELENA KOMAROVA	{"phone": "+70289039111"}
0005434880561	6DB2F8	4993 973605	ALEKSEY KULIKOV	{"email": "akulikov-30041970@postgrespro.ru", "phone": "+70084223771"}
0005434880562	6DB2F8	1581 971229	SERGEY NAZAROV	{"phone": "+70524163625"}
0005434880563	6DB2F8	3270 823415	VALENTINA IVANOVA	{"email": "valentinaivanova_051974@postgrespro.ru", "phone": "+70032734380"}
0005434880564	BE3319	3399 367760	EVGENIY ZHURAVLEV	{"email": "ezhuravlev_1975@postgrespro.ru", "phone": "+70490161202"}
0005434880565	1E7818	1441 438642	OLGA VASILEVA	{"phone": "+70118682973"}
0005434880566	DD3009	4371 038907	YURIY AFANASEV	{"email": "afanasevy_03111981@postgrespro.ru", "phone": "+70482273632"}
0005434880567	1E6DE9	7403 781445	SERGEY FROLOV	{"email": "frolov-s1961@postgrespro.ru", "phone": "+70654602054"}
0005434880568	1E6DE9	5703 065676	NINA FOMINA	{"phone": "+70629437247"}
0005434880569	5A8CC9	6076 850587	IVAN ANDREEV	{"phone": "+70222022739"}
0005434880570	662925	3664 815784	ANNA YAKOVLEVA	{"phone": "+70958675468"}
0005434880571	1AA9CD	0654 602015	VLADIMIR ANDREEV	{"phone": "+70977468354"}
0005434880572	B7AD52	2080 732406	ALEKSANDR KAZAKOV	{"phone": "+70875282502"}
0005434880573	0AB71B	7787 836896	IGNAT POPOV	{"email": "popovi.021973@postgrespro.ru", "phone": "+70479583308"}
0005434880574	9FE6D4	8318 030724	IVAN POPOV	{"phone": "+70670962068"}
0005434880575	30CC4C	0386 986036	ALEKSANDR SOLOVEV	{"email": "a_solovev24051976@postgrespro.ru", "phone": "+70079103146"}
0005434880576	30CC4C	8925 004710	SVETLANA DMITRIEVA	{"phone": "+70092572430"}
0005434880577	B6DAE6	4440 273353	VALENTINA ARKHIPOVA	{"phone": "+70277164121"}
0005434880578	4034B8	1144 806981	ANNA SMIRNOVA	{"phone": "+70088332666"}
0005434880579	4A45B6	9560 135405	VIKTORIYA IVANOVA	{"email": "ivanova_viktoriya-081968@postgrespro.ru", "phone": "+70170491942"}
0005434880580	74B7BE	9879 021403	ELENA KUZNECOVA	{"phone": "+70715677511"}
0005434880581	74B7BE	9797 426749	SERGEY POPOV	{"email": "popov.s_17021978@postgrespro.ru", "phone": "+70230587561"}
0005434880582	C49840	3335 093846	ROZA GORBUNOVA	{"phone": "+70152915443"}
0005434880583	86AECC	2123 319679	BOGDAN NIKITIN	{"email": "nikitin_bogdan061971@postgrespro.ru", "phone": "+70990099684"}
0005434880584	A0E589	5192 651569	SERGEY SIDOROV	{"phone": "+70838741370"}
0005434880585	177746	0474 115674	GALINA YUDINA	{"phone": "+70102480196"}
0005434880586	177746	5906 441258	DARYA FADEEVA	{"phone": "+70901046896"}
0005434880587	8311A2	9896 028727	NAZAR BONDARENKO	{"email": "nazar.bondarenko30091971@postgrespro.ru", "phone": "+70508336359"}
0005434880589	F96233	8713 005952	AYRAT MIKHAYLOV	{"email": "amikhaylov.011972@postgrespro.ru", "phone": "+70012743798"}
0005434880590	3CEA0E	1547 530657	ELIZAVETA SCHERBAKOVA	{"email": "scherbakova-e041959@postgrespro.ru", "phone": "+70235501067"}
0005434880591	CA67DA	5878 892513	ANASTASIYA ZAYCEVA	{"phone": "+70612740067"}
0005434880592	CA67DA	9933 272858	IRINA SOROKINA	{"email": "sorokina.irina111975@postgrespro.ru", "phone": "+70216828943"}
0005434880593	6795C2	3418 582257	MIKHAIL SEMENOV	{"phone": "+70232459049"}
0005434880594	6795C2	0934 420787	VIKTOR ORLOV	{"email": "orlovv17051964@postgrespro.ru", "phone": "+70186148487"}
0005434880595	23B6C6	1537 378874	RAISA ABRAMOVA	{"email": "raisa.abramova-22121970@postgrespro.ru", "phone": "+70459921779"}
0005434880596	085F4B	3158 586163	DARYA BORISOVA	{"phone": "+70494340708"}
0005434880597	085F4B	8822 824555	ANNA KUZNECOVA	{"phone": "+70403201030"}
0005434880598	2C7E06	2788 623775	VALERIY BORISOV	{"email": "v.borisov-17121989@postgrespro.ru", "phone": "+70942888541"}
0005434880599	31D4DA	2313 984902	VLADIMIR KUZNECOV	{"phone": "+70493390308"}
0005434880600	3C00F5	4970 212032	ALEVTINA LEBEDEVA	{"phone": "+70702796222"}
0005434880601	B0AAB7	7319 232032	MIKHAIL KOZLOV	{"email": "mikhail.kozlov021975@postgrespro.ru", "phone": "+70489159302"}
0005434880602	C01296	6096 651733	GALINA DENISOVA	{"phone": "+70438216955"}
0005434880603	2DD2A3	7443 671471	EVGENIY KRASNOV	{"phone": "+70894674255"}
0005434880604	0D8734	9086 302505	NINA FOMINA	{"email": "nina.fomina.1985@postgrespro.ru", "phone": "+70866210778"}
0005434880605	907B36	0970 967120	NIKOLAY SERGEEV	{"email": "nikolay.sergeev.1978@postgrespro.ru", "phone": "+70303609052"}
0005434880606	AE39D1	2499 529378	ALEKSANDR ZAYCEV	{"email": "zayceva041970@postgrespro.ru", "phone": "+70889993646"}
0005434880607	AE39D1	7021 833529	VALERIY TIKHONOV	{"phone": "+70736858233"}
0005434880608	75806D	7189 906109	LYUDMILA ZHUKOVA	{"email": "lyudmila-zhukova.051974@postgrespro.ru", "phone": "+70115794446"}
0005434880609	75806D	7958 619357	MARIYA LUKYANOVA	{"phone": "+70023920218"}
0005434880610	A5BDEF	3074 184734	OLGA MARTYNOVA	{"phone": "+70103058672"}
0005434880611	FA84E6	0031 575326	VERA MOISEEVA	{"email": "vera.moiseeva-111969@postgrespro.ru", "phone": "+70015437044"}
0005434880612	FCE2FA	4302 785391	VASILIY KARPOV	{"email": "karpov.v-071962@postgrespro.ru", "phone": "+70324111429"}
0005434880613	FCE2FA	3390 594795	ELENA KOZLOVA	{"email": "e-kozlova25061968@postgrespro.ru", "phone": "+70598998484"}
0005434880614	DC0BF4	7974 686862	IGOR POPOV	{"phone": "+70139312891"}
0005434880615	10DB1C	4465 377653	NATALIYA PAVLOVA	{"email": "pavlova_n091977@postgrespro.ru", "phone": "+70904944934"}
0005434880616	10DB1C	7202 481222	DARYA TIKHONOVA	{"phone": "+70571378747"}
0005434880617	C7AC8E	4161 075632	VIKTOR KOROLEV	{"email": "korolevviktor-28071974@postgrespro.ru", "phone": "+70078698843"}
0005434880618	54737D	9941 444187	VALENTINA YAKOVLEVA	{"phone": "+70174582194"}
0005434880619	B885C2	5480 514793	IVAN MELNIKOV	{"phone": "+70488450298"}
0005434880620	9C4626	4227 712173	SERGEY YAKOVLEV	{"phone": "+70906805133"}
0005434880621	9C4626	2377 593731	OKSANA VOLKOVA	{"email": "o-volkova_1977@postgrespro.ru", "phone": "+70594165503"}
0005434880622	9C4626	0060 080766	TAMARA IVANOVA	{"email": "t_ivanova_121983@postgrespro.ru", "phone": "+70258068603"}
0005434880623	51C949	7205 761685	DMITRIY KRASNOV	{"phone": "+70522082252"}
0005434880624	54B5A2	5330 104509	SERGEY ALEKSANDROV	{"phone": "+70965740552"}
0005434880625	5AAE60	4292 719717	VIKTOR DENISOV	{"phone": "+70359482445"}
0005434880626	9C5B24	0585 896412	SERGEY VASILEV	{"email": "s-vasilev-1970@postgrespro.ru", "phone": "+70174001635"}
0005434880627	9C5B24	9554 409516	SERGEY MIKHAYLOV	{"email": "mikhaylov-s_13071977@postgrespro.ru", "phone": "+70743851041"}
0005434880628	89A239	2317 630136	EVGENIY ZAKHAROV	{"email": "e.zakharov-1981@postgrespro.ru", "phone": "+70577003541"}
0005434880629	89A239	2778 065645	PAVEL PETROV	{"phone": "+70110346862"}
0005434880630	31DF98	2385 405055	ELEONORA MEDVEDEVA	{"phone": "+70686700621"}
0005434880631	F354DB	9596 372420	BORIS SERGEEV	{"phone": "+70361170567"}
0005434880632	08301B	7166 265344	PAVEL ALEKSEEV	{"email": "alekseevpavel.071973@postgrespro.ru", "phone": "+70807253465"}
0005434880633	5E6363	9852 854563	ALEKSANDR SOKOLOV	{"phone": "+70156017342"}
0005434880634	5E6363	8523 185827	VIKTOR MIKHAYLOV	{"email": "mikhaylov-viktor_20091968@postgrespro.ru", "phone": "+70447575396"}
0005434880635	343764	8491 449464	VYACHESLAV GAVRILOV	{"email": "gavrilov-vyacheslav_28021963@postgrespro.ru", "phone": "+70593249828"}
0005434880636	2D3599	1480 117456	MIKHAIL DMITRIEV	{"email": "mikhail_dmitriev-121971@postgrespro.ru", "phone": "+70268829430"}
0005434880637	2D3599	1638 595909	ALEKSEY VOLKOV	{"email": "volkov.a-111972@postgrespro.ru", "phone": "+70275709571"}
0005434880638	EFF64F	7975 433870	ANNA ZAKHAROVA	{"email": "zakharova_anna_1977@postgrespro.ru", "phone": "+70805872444"}
0005434880639	EFF64F	7822 353523	ELENA ZHUKOVA	{"email": "elenazhukova_11021971@postgrespro.ru", "phone": "+70116768964"}
0005434880640	5D32CF	5426 972818	EKATERINA ZOTOVA	{"email": "ekaterina_zotova1982@postgrespro.ru", "phone": "+70062908280"}
0005434880641	09825E	7379 233445	RINAT TARASOV	{"phone": "+70328412690"}
0005434880642	FEA92F	3632 693787	RAISA ARKHIPOVA	{"email": "raisa_arkhipova-111957@postgrespro.ru", "phone": "+70218460829"}
0005434880643	19C049	8101 118197	YURIY ALEKSEEV	{"phone": "+70472825871"}
0005434880644	B76E12	7318 202719	ELENA STEPANOVA	{"phone": "+70941453908"}
0005434880645	F8CD6D	8713 160576	NATALIYA ZOTOVA	{"email": "zotova.nataliya_1982@postgrespro.ru", "phone": "+70536304867"}
0005434880646	C158B9	3724 818766	NINA POPOVA	{"email": "popovan.13061972@postgrespro.ru", "phone": "+70636498901"}
0005434880647	A5D2F1	3611 361444	ALEKSANDRA FROLOVA	{"phone": "+70497940316"}
0005434880648	A5D2F1	2145 057330	EKATERINA ANDREEVA	{"phone": "+70127841604"}
0005434880649	B5781B	2520 968626	NADEZHDA OSIPOVA	{"phone": "+70001747505"}
0005434880650	F2FBE8	2014 259807	EVGENIY VASILEV	{"email": "evgeniy.vasilev_121970@postgrespro.ru", "phone": "+70309161713"}
0005434880651	F2FBE8	6731 496406	LEONID SMIRNOV	{"email": "smirnov-l.021979@postgrespro.ru", "phone": "+70325649237"}
0005434880652	C91DC6	2027 557923	RUSLAN TIMOFEEV	{"email": "timofeevruslan26061968@postgrespro.ru", "phone": "+70820350549"}
0005434880653	20C4C3	5990 573232	VALENTINA KALININA	{"phone": "+70900743339"}
0005434880654	2C7549	0383 129950	VARVARA MOISEEVA	{"email": "moiseeva_varvara-061970@postgrespro.ru", "phone": "+70562538172"}
0005434880655	E48489	1842 320284	MARINA SOLOVEVA	{"email": "marinasoloveva-1975@postgrespro.ru", "phone": "+70092185200"}
0005434880656	E48489	3252 580565	EVGENIY GAVRILOV	{"phone": "+70639111934"}
0005434880657	E48489	4729 344813	EVGENIY TARASOV	{"phone": "+70127953483"}
0005434880658	315F8A	8158 908720	GULFIYA SEMENOVA	{"phone": "+70972489522"}
0005434880659	30A558	6204 308616	TAMARA NIKIFOROVA	{"phone": "+70996101362"}
0005434880660	30A558	5654 540081	LEONID AFANASEV	{"email": "leonidafanasev.081969@postgrespro.ru", "phone": "+70565639683"}
0005434880661	A33540	5388 627143	TATYANA KOVALEVA	{"email": "kovalevatatyana.06031960@postgrespro.ru", "phone": "+70540252041"}
0005434880662	A33540	5629 812060	ELENA IVANOVA	{"phone": "+70244556828"}
0005434880663	CC1FEE	4633 286693	YURIY MELNIKOV	{"email": "melnikov-y-051968@postgrespro.ru", "phone": "+70154894840"}
0005434880664	B25267	7439 510331	GENNADIY VASILEV	{"phone": "+70512399595"}
0005434880665	71E869	2846 928580	RAISA IVANOVA	{"phone": "+70999291208"}
0005434880666	15C933	5044 602154	GENNADIY DAVYDOV	{"phone": "+70195964973"}
0005434880667	5D358A	2270 819069	ARINA KUZMINA	{"phone": "+70338158796"}
0005434880668	49F455	3325 124264	KRISTINA ZAYCEVA	{"phone": "+70035562170"}
0005434880669	49F455	2968 874625	DARYA ROMANOVA	{"email": "darya-romanova1974@postgrespro.ru", "phone": "+70997601239"}
0005434880670	EF51EB	0404 346289	ELENA SMIRNOVA	{"phone": "+70230974866"}
0005434880671	EF51EB	0057 655146	ALEKSANDR SOROKIN	{"email": "a_sorokin_081978@postgrespro.ru", "phone": "+70255015200"}
0005434880672	BDE567	1648 911114	LYUDMILA KUZMINA	{"phone": "+70794271773"}
0005434880673	75447C	8785 442409	TATYANA MIRONOVA	{"email": "tatyana-mironova1974@postgrespro.ru", "phone": "+70645709525"}
0005434880674	55D7C2	5908 023049	VERA BELYAEVA	{"email": "vera_belyaeva.10111964@postgrespro.ru", "phone": "+70537993663"}
0005434880675	55D7C2	9086 246495	VIKTOR FILIPPOV	{"email": "viktor.filippov_1984@postgrespro.ru", "phone": "+70361564514"}
0005434880676	55D7C2	3348 803451	IRINA BELOVA	{"phone": "+70211845542"}
0005434880677	2117FF	9734 623914	NINA SOROKINA	{"email": "sorokina.nina1968@postgrespro.ru", "phone": "+70745690756"}
0005434880678	2117FF	3433 021239	VADIM ZHUKOV	{"phone": "+70897790434"}
0005434880679	B901E2	1503 848747	GENNADIY SOLOVEV	{"email": "g.solovev.07121966@postgrespro.ru", "phone": "+70829037521"}
0005434880680	B901E2	8933 325063	DARYA SOLOVEVA	{"phone": "+70450876045"}
0005434880681	1D7351	8727 339273	EKATERINA YUDINA	{"email": "yudina_ekaterina.121977@postgrespro.ru", "phone": "+70435172575"}
0005434880682	A942DF	2093 026696	KONSTANTIN NIKOLAEV	{"phone": "+70933812673"}
0005434880683	0B765C	6679 839602	VALENTINA SOLOVEVA	{"phone": "+70610055604"}
0005434880684	0B765C	3301 075815	MARIYA ALEKSEEVA	{"email": "m_alekseeva_1968@postgrespro.ru", "phone": "+70673092360"}
0005434880685	8C88DE	4313 122923	ALEKSANDR SMIRNOV	{"email": "smirnov_a06071978@postgrespro.ru", "phone": "+70882618831"}
0005434880686	8C88DE	6715 032197	MARIYA SOROKINA	{"phone": "+70409387962"}
0005434880687	485652	8957 941803	ANTONINA PETROVA	{"phone": "+70268599651"}
0005434880688	58390A	7326 163785	NAIL PAVLOV	{"phone": "+70657563484"}
0005434880689	097741	6927 228271	DARYA SERGEEVA	{"email": "darya.sergeeva07111972@postgrespro.ru", "phone": "+70299252104"}
0005434880690	26892A	6134 523513	VLADIMIR VOROBEV	{"phone": "+70659466123"}
0005434880691	B4680F	6026 850064	PETR TIKHONOV	{"phone": "+70498141177"}
0005434880692	9FE42E	2098 767033	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr-1975@postgrespro.ru", "phone": "+70788524175"}
0005434880693	9FE42E	5365 119749	MILANA KOROLEVA	{"email": "koroleva-milana-081973@postgrespro.ru", "phone": "+70374568154"}
0005434880694	12AD50	5557 194998	YURIY MOROZOV	{"phone": "+70982701249"}
0005434880695	2A9DA5	4642 542286	DMITRIY FROLOV	{"phone": "+70140362248"}
0005434880696	C43CC8	7219 112747	KRISTINA SOLOVEVA	{"email": "soloveva_kristina011967@postgrespro.ru", "phone": "+70655663936"}
0005434880697	C43CC8	7817 991692	SERGEY ISAEV	{"email": "s-isaev.1975@postgrespro.ru", "phone": "+70355538254"}
0005434880698	AC95E2	1194 590941	NIKITA NOVIKOV	{"email": "nikita_novikov1969@postgrespro.ru", "phone": "+70868582734"}
0005434880699	AC95E2	6516 659819	KLAVDIYA SERGEEVA	{"email": "klavdiya.sergeeva.111973@postgrespro.ru", "phone": "+70959085546"}
0005434880700	FE9AD3	4743 102368	MARIYA MAKAROVA	{"email": "makarova.m.081978@postgrespro.ru", "phone": "+70137001262"}
0005434880701	3D5369	7645 806342	LYUDMILA PAVLOVA	{"email": "lyudmila-pavlova.1962@postgrespro.ru", "phone": "+70155250293"}
0005434880702	73CC85	4135 668908	NADEZHDA KUZMINA	{"phone": "+70195586734"}
0005434880703	E41D46	7003 144765	ELENA IVANOVA	{"phone": "+70640649805"}
0005434880704	9421C0	0197 427712	LIDIYA ZOTOVA	{"email": "zotova.l1975@postgrespro.ru", "phone": "+70348120287"}
0005434880705	D501D8	6948 684922	VLADISLAV SOKOLOV	{"phone": "+70224710197"}
0005434880706	D97BFB	7791 227175	LYUBOV DAVYDOVA	{"email": "ldavydova1969@postgrespro.ru", "phone": "+70079228799"}
0005434880707	461E2D	6715 154514	RAIL VASILEV	{"email": "r_vasilev-1958@postgrespro.ru", "phone": "+70587857782"}
0005434880708	17F104	5470 117004	SERGEY ILIN	{"phone": "+70540570204"}
0005434880709	48F6CA	2761 894223	IRINA ROMANOVA	{"email": "romanova-i.121962@postgrespro.ru", "phone": "+70105222325"}
0005434880710	84CB7D	1688 672548	VALENTINA VLASOVA	{"phone": "+70356285156"}
0005434880711	84CB7D	4512 697407	YULIYA FOMINA	{"email": "fomina_yuliya.1971@postgrespro.ru", "phone": "+70618297507"}
0005434880712	2BA491	5443 946537	ANDREY BORISOV	{"phone": "+70847899149"}
0005434880713	854E24	1913 097057	TATYANA IVANOVA	{"email": "ivanova_t1962@postgrespro.ru", "phone": "+70598300373"}
0005434880714	CC3CE3	1499 593112	NINA KOROLEVA	{"phone": "+70043156016"}
0005434880715	55B292	2525 719733	SERGEY YAKOVLEV	{"phone": "+70524330994"}
0005434880716	12B9DE	3541 856812	EKATERINA ZHURAVLEVA	{"email": "ekaterina.zhuravleva_051973@postgrespro.ru", "phone": "+70640389148"}
0005434880717	1006F8	3457 374277	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov-23081968@postgrespro.ru", "phone": "+70815772969"}
0005434880718	77675B	0185 458214	DMITRIY IVANOV	{"phone": "+70102590194"}
0005434880719	F77476	9615 675354	RASIM FROLOV	{"email": "frolovrasim_1973@postgrespro.ru", "phone": "+70127614686"}
0005434880720	F77476	4999 262412	VIKTOR MARTYNOV	{"phone": "+70388704710"}
0005434880721	41D555	1764 744098	VIKTOR ZAKHAROV	{"email": "zakharov_v_06091969@postgrespro.ru", "phone": "+70851212276"}
0005434880722	3E0D36	8818 664804	NATALYA MAKAROVA	{"phone": "+70894435713"}
0005434880723	420C33	8968 499431	NIKOLAY SOLOVEV	{"email": "n_solovev-011981@postgrespro.ru", "phone": "+70375084390"}
0005434880724	FED14D	9784 320624	ELENA EFIMOVA	{"phone": "+70878018977"}
0005434880725	FED14D	3623 864786	ALEKSEY KARPOV	{"phone": "+70980152062"}
0005434880726	E7CEB7	3753 385867	VERA MOROZOVA	{"email": "morozova_v_121970@postgrespro.ru", "phone": "+70899376394"}
0005434880727	C756EE	4437 637558	LYUDMILA NESTEROVA	{"email": "l-nesterova_01041978@postgrespro.ru", "phone": "+70051967571"}
0005434880728	115E96	5087 847791	SERGEY SERGEEV	{"email": "sergeev.sergey_26061977@postgrespro.ru", "phone": "+70477084977"}
0005434880729	115E96	3724 667600	VLADIMIR ANDREEV	{"email": "andreevv_10021980@postgrespro.ru", "phone": "+70772296001"}
0005434880730	45D540	8615 394613	PAVEL NOVIKOV	{"email": "novikov_pavel_051986@postgrespro.ru", "phone": "+70370207226"}
0005434880731	45D540	1267 175167	YULIYA MIKHAYLOVA	{"phone": "+70989961221"}
0005434880732	EC7978	6947 244708	ASIYA MAKAROVA	{"email": "makarova.asiya-10021976@postgrespro.ru", "phone": "+70325547480"}
0005434880733	076B4C	5773 136644	ALEKSANDR KUZNECOV	{"phone": "+70725263913"}
0005434880734	076B4C	4783 138477	MAKSIM MAKSIMOV	{"email": "maksim_maksimov.1981@postgrespro.ru", "phone": "+70786877281"}
0005434880735	D14AAB	0616 313530	TATYANA KAZAKOVA	{"email": "kazakova_tatyana.27061973@postgrespro.ru", "phone": "+70334421346"}
0005434880736	358DA5	4474 051599	OLGA EFIMOVA	{"email": "o.efimova08041981@postgrespro.ru", "phone": "+70595356679"}
0005434880737	358DA5	2790 759131	LIDIYA VLASOVA	{"email": "vlasova.l1971@postgrespro.ru", "phone": "+70726383384"}
0005434880738	358DA5	1315 364855	VALERIY MIKHAYLOV	{"email": "v_mikhaylov07081974@postgrespro.ru", "phone": "+70919715443"}
0005434880739	21B496	7388 143076	VIKTORIYA IVANOVA	{"phone": "+70644894093"}
0005434880740	21B496	7045 334221	ALEKSANDR ILIN	{"email": "a-ilin1979@postgrespro.ru", "phone": "+70737470527"}
0005434880741	24B7B3	5900 945386	MARIYA ABRAMOVA	{"email": "abramova_mariya_1982@postgrespro.ru", "phone": "+70935145373"}
0005434880742	EABCD0	6389 168343	ANNA MAKAROVA	{"email": "anna_makarova-1976@postgrespro.ru", "phone": "+70462545983"}
0005434880743	344B2B	3458 941530	SVETLANA EGOROVA	{"email": "egorovasvetlana1972@postgrespro.ru", "phone": "+70356236677"}
0005434880804	2CF119	9970 263104	TATYANA KULIKOVA	{"phone": "+70621485436"}
0005434880744	818608	6045 333151	BOGDAN TIKHONOV	{"email": "tikhonovbogdan.081975@postgrespro.ru", "phone": "+70694994789"}
0005434880745	C94FCA	0118 383021	VERONIKA VOROBEVA	{"phone": "+70034283578"}
0005434880746	C94FCA	5723 503440	VLADIMIR ANDREEV	{"phone": "+70706406981"}
0005434880747	1CEDD8	1673 355941	ANNA BELOVA	{"phone": "+70847201006"}
0005434880748	1CEDD8	7626 287038	VARVARA KONOVALOVA	{"phone": "+70910688740"}
0005434880749	F8F253	3728 709713	TATYANA VASILEVA	{"email": "tatyana_vasileva_17071961@postgrespro.ru", "phone": "+70035275049"}
0005434880750	2BA103	7477 985861	IRINA TIKHONOVA	{"email": "i.tikhonova.111969@postgrespro.ru", "phone": "+70493334859"}
0005434880751	06313C	5891 600584	EKATERINA ARKHIPOVA	{"phone": "+70225351263"}
0005434880752	BD2401	3768 946185	OLGA KUZMINA	{"email": "kuzminaolga-071968@postgrespro.ru", "phone": "+70549448691"}
0005434880753	BD2401	1711 879669	VIKTOR SMIRNOV	{"phone": "+70818791615"}
0005434880754	914546	5233 150876	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr-011974@postgrespro.ru", "phone": "+70870815113"}
0005434880755	322619	6074 652935	ALENA FADEEVA	{"email": "a_fadeeva.021985@postgrespro.ru", "phone": "+70988647216"}
0005434880756	C4E1CF	3303 504117	ANNA NESTEROVA	{"email": "nesterovaanna-22051970@postgrespro.ru", "phone": "+70560623802"}
0005434880757	43C7A4	2927 692850	LYUDMILA MIKHAYLOVA	{"phone": "+70011680059"}
0005434880758	8FC863	8255 728625	IRINA VLASOVA	{"phone": "+70541285506"}
0005434880759	2776FA	7414 303928	EVGENIYA EFIMOVA	{"email": "efimova-e_17121965@postgrespro.ru", "phone": "+70580959148"}
0005434880760	DEBA1C	8372 409187	ALEKSANDR ROMANOV	{"email": "romanov_a_27031974@postgrespro.ru", "phone": "+70160342213"}
0005434880761	A9C4E9	1188 568626	ALEKSEY FEDOTOV	{"phone": "+70822827582"}
0005434880762	40E9BE	0704 209413	NADEZHDA NESTEROVA	{"phone": "+70700570678"}
0005434880763	62A475	7379 499956	EKATERINA VOLKOVA	{"phone": "+70696133824"}
0005434880764	541F14	9810 541434	ELIZAVETA BORISOVA	{"email": "borisova-e.26101983@postgrespro.ru", "phone": "+70429979930"}
0005434880765	772D7A	2152 461572	LILIYA ZAKHAROVA	{"email": "lzakharova-1980@postgrespro.ru", "phone": "+70457729385"}
0005434880766	772D7A	9001 791342	MARINA ABRAMOVA	{"phone": "+70808931193"}
0005434880767	2AFD75	1438 705509	YURIY KUZMIN	{"email": "ykuzmin-121975@postgrespro.ru", "phone": "+70933125139"}
0005434880768	A954E4	4128 382054	ANASTASIYA ARKHIPOVA	{"phone": "+70127415879"}
0005434880769	A954E4	1884 535234	NIKOLAY IVANOV	{"phone": "+70724777899"}
0005434880770	A166BB	3859 985550	NATALYA FEDOROVA	{"phone": "+70143083789"}
0005434880771	A166BB	7713 786527	SERGEY TARASOV	{"email": "sergey.tarasov.121979@postgrespro.ru", "phone": "+70712690895"}
0005434880772	A166BB	1268 651848	YURIY TIKHONOV	{"phone": "+70026472611"}
0005434880773	5E3114	6886 431864	ALEKSANDR ZAKHAROV	{"phone": "+70049758804"}
0005434880774	3638D5	0908 699491	TATYANA GRISHINA	{"email": "tatyana.grishina.11031976@postgrespro.ru", "phone": "+70226316423"}
0005434880775	3638D5	9232 389785	IGOR PETROV	{"email": "igorpetrov-26021977@postgrespro.ru", "phone": "+70617552765"}
0005434880776	3638D5	0055 317387	ELENA KONOVALOVA	{"email": "konovalova_e_091975@postgrespro.ru", "phone": "+70221339380"}
0005434880777	43F549	8951 781244	EVGENIY SHEVCHENKO	{"email": "shevchenkoevgeniy21051976@postgrespro.ru", "phone": "+70851610257"}
0005434880778	121413	8434 762593	ELENA KUZMINA	{"email": "kuzmina.elena_24091968@postgrespro.ru", "phone": "+70751412880"}
0005434880779	266E99	6411 018888	ALEKSEY CHERNOV	{"email": "aleksey.chernov18011968@postgrespro.ru", "phone": "+70125565365"}
0005434880780	266E99	0783 405122	ARTEM KUZNECOV	{"phone": "+70569958222"}
0005434880781	266E99	2325 443488	ANNA ORLOVA	{"email": "orlova_anna101972@postgrespro.ru", "phone": "+70452499924"}
0005434880782	B53925	7429 154628	SVETLANA KUZMINA	{"email": "s.kuzmina_23051978@postgrespro.ru", "phone": "+70305732555"}
0005434880783	B53925	0693 733904	OLGA NIKOLAEVA	{"email": "o-nikolaeva-24081967@postgrespro.ru", "phone": "+70503216285"}
0005434880784	110DD5	6299 468547	EVDOKIYA OSIPOVA	{"phone": "+70658094463"}
0005434880785	110DD5	7047 362366	NINA ZAKHAROVA	{"email": "nina.zakharova101970@postgrespro.ru", "phone": "+70546711496"}
0005434880786	110DD5	5654 690521	MARINA ANTONOVA	{"phone": "+70214213475"}
0005434880787	869C19	1345 665572	SERGEY BORISOV	{"phone": "+70821121146"}
0005434880788	34D024	1881 898721	TATYANA KULIKOVA	{"email": "kulikova.tatyana081964@postgrespro.ru", "phone": "+70448846325"}
0005434880789	34D024	5804 254791	MIKHAIL KONOVALOV	{"phone": "+70708301573"}
0005434880790	AAFC70	1134 479330	VALERIY NIKOLAEV	{"email": "vnikolaev-1963@postgrespro.ru", "phone": "+70461874710"}
0005434880791	11313B	9339 538242	NIKOLAY MIRONOV	{"email": "n.mironov_111968@postgrespro.ru", "phone": "+70905683473"}
0005434880792	7DA809	2960 756542	LIDIYA NIKOLAEVA	{"phone": "+70594357327"}
0005434880793	7DA809	6578 341693	IRINA SMIRNOVA	{"phone": "+70770191605"}
0005434880794	2F517F	5232 122143	ELENA KUZNECOVA	{"email": "elena.kuznecova_02121968@postgrespro.ru", "phone": "+70769430162"}
0005434880795	0B7ECC	5259 261487	EKATERINA VASILEVA	{"email": "vasileva.ekaterina.08071957@postgrespro.ru", "phone": "+70515954033"}
0005434880796	117CD2	5097 025697	VYACHESLAV SERGEEV	{"email": "v.sergeev-1969@postgrespro.ru", "phone": "+70500619436"}
0005434880797	7F9386	5833 777044	NATALYA IVANOVA	{"phone": "+70253285291"}
0005434880798	F88334	4658 182987	NIKOLAY ZAKHAROV	{"email": "nikolay-zakharov_31081973@postgrespro.ru", "phone": "+70627382613"}
0005434880799	B7BCCA	5769 667295	VALENTINA ANDREEVA	{"phone": "+70671144374"}
0005434880800	66CAA1	8653 285228	EKATERINA BARANOVA	{"email": "baranovae-18091982@postgrespro.ru", "phone": "+70460048890"}
0005434880801	266627	4123 916724	VIKTORIYA KOMAROVA	{"email": "komarova-v.061972@postgrespro.ru", "phone": "+70727914897"}
0005434880802	266627	1550 582099	PETR MEDVEDEV	{"phone": "+70716134809"}
0005434880803	725B71	5536 759570	DMITRIY ZAKHAROV	{"phone": "+70430954327"}
0005434880805	2CF119	0315 857350	VLADIMIR ANTONOV	{"email": "antonov.vladimir-1976@postgrespro.ru", "phone": "+70704911808"}
0005434880806	1C5651	1754 658310	DMITRIY SAVELEV	{"email": "savelevdmitriy041964@postgrespro.ru", "phone": "+70257355344"}
0005434880807	1C5651	3334 254589	VYACHESLAV CHERNOV	{"phone": "+70183399507"}
0005434880808	8E5FB1	1891 428526	SERGEY NOVIKOV	{"phone": "+70226368851"}
0005434880809	4A8611	7939 923208	NIKITA POPOV	{"phone": "+70141236053"}
0005434880810	559118	3579 426599	ALEKSEY SEMENOV	{"phone": "+70569232015"}
0005434880811	559118	5102 869522	MAKAR KUZNECOV	{"email": "kuznecov_m_06051974@postgrespro.ru", "phone": "+70586199499"}
0005434880812	83CB82	9001 824494	EMIL STEPANOV	{"phone": "+70117525644"}
0005434880813	83CB82	8773 519158	DARINA NIKOLAEVA	{"phone": "+70856087429"}
0005434880814	83CB82	7487 489790	LYUBOV IVANOVA	{"phone": "+70790634875"}
0005434880815	1074F8	8825 111348	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.aleksandr.111975@postgrespro.ru", "phone": "+70210974443"}
0005434880816	B7AFBF	2445 934017	TAMARA NESTEROVA	{"phone": "+70180666850"}
0005434880817	F66054	3328 679363	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev_20061974@postgrespro.ru", "phone": "+70799216189"}
0005434880818	F66054	8334 378496	ANNA MIKHAYLOVA	{"email": "anna_mikhaylova_1970@postgrespro.ru", "phone": "+70317044588"}
0005434880819	B2B993	8509 174895	SERGEY RODIONOV	{"email": "sergey-rodionov_1967@postgrespro.ru", "phone": "+70574047316"}
0005434880820	21E595	0553 891003	ELENA KUZNECOVA	{"phone": "+70878460695"}
0005434880821	21E595	5703 024701	ANDREY ANDREEV	{"email": "andreyandreev.081968@postgrespro.ru", "phone": "+70923588115"}
0005434880822	12DA3A	1696 828900	TATYANA POTAPOVA	{"phone": "+70937987211"}
0005434880823	12DA3A	9171 023174	VASILIY SOLOVEV	{"email": "vasiliy_solovev01071968@postgrespro.ru", "phone": "+70912480141"}
0005434880824	660E0A	7536 453867	SERGEY ROMANOV	{"email": "sergey.romanov06101974@postgrespro.ru", "phone": "+70626132167"}
0005434880825	93E115	3462 965237	ILMIRA AFANASEVA	{"phone": "+70659278494"}
0005434880826	A9CA1C	9088 880653	YURIY DENISOV	{"phone": "+70193397045"}
0005434880827	A9CA1C	3861 579555	ARTEM IVANOV	{"phone": "+70620342692"}
0005434880828	BA4751	4873 525405	ALEKSANDR SERGEEV	{"phone": "+70175676736"}
0005434880829	D3671C	0005 008040	ALEKSANDR BORISOV	{"email": "borisov_a13031972@postgrespro.ru", "phone": "+70091582373"}
0005434880830	D3671C	3230 237077	LARISA TIKHONOVA	{"email": "larisa.tikhonova05091969@postgrespro.ru", "phone": "+70670890013"}
0005434880831	EA69BE	1910 279963	GALINA NESTEROVA	{"email": "galina-nesterova-09061978@postgrespro.ru", "phone": "+70246379309"}
0005434880832	EA69BE	5429 947291	YULIYA FILIPPOVA	{"email": "filippova-y.1967@postgrespro.ru", "phone": "+70620705584"}
0005434880833	E6F31E	8565 719437	LARISA DANILOVA	{"email": "danilovalarisa021980@postgrespro.ru", "phone": "+70524741208"}
0005434880834	92F151	0916 068496	KLAVDIYA KONDRATEVA	{"email": "kondrateva-klavdiya061982@postgrespro.ru", "phone": "+70527498775"}
0005434880835	961BB7	2887 140596	KRISTINA NIKOLAEVA	{"email": "nikolaeva.k_05011971@postgrespro.ru", "phone": "+70286708526"}
0005434880836	B4305B	4039 894750	ALEKSEY BORISOV	{"phone": "+70802495531"}
0005434880837	925E70	3069 747325	GALINA FROLOVA	{"phone": "+70684332705"}
0005434880838	925E70	9617 438457	ANASTASIYA BOGDANOVA	{"email": "bogdanova_anastasiya.17061966@postgrespro.ru", "phone": "+70634530023"}
0005434880839	917786	3981 614880	VALERIY SEMENOV	{"email": "semenov.valeriy.1968@postgrespro.ru", "phone": "+70885799423"}
0005434880840	DE7045	7289 980856	VIKTORIYA VLASOVA	{"email": "vlasovav1967@postgrespro.ru", "phone": "+70901742922"}
0005434880841	33FB36	6609 661115	YURIY ALEKSANDROV	{"email": "yaleksandrov_04091971@postgrespro.ru", "phone": "+70263732267"}
0005434880842	33FB36	2940 649112	OLGA MATVEEVA	{"email": "o_matveeva_1969@postgrespro.ru", "phone": "+70355727640"}
0005434880843	964E1F	1432 569960	NATALYA DAVYDOVA	{"phone": "+70584674230"}
0005434880844	86FF86	8397 479320	ANNA KRASNOVA	{"email": "krasnova-a-021980@postgrespro.ru", "phone": "+70290887594"}
0005434880845	86FF86	4566 743925	ALISA MIKHAYLOVA	{"phone": "+70262578146"}
0005434880846	39AE61	9307 147118	ALEKSANDR FROLOV	{"phone": "+70053225352"}
0005434880847	39AE61	4828 086812	DARYA ZAYCEVA	{"phone": "+70767361679"}
0005434880848	8996D8	1352 207118	VARVARA GUSEVA	{"email": "guseva_v-15061971@postgrespro.ru", "phone": "+70365143434"}
0005434880849	39AD0F	8304 306248	IGOR NIKOLAEV	{"phone": "+70997297357"}
0005434880850	B552B4	2847 884530	ALEKSANDR MEDVEDEV	{"phone": "+70773057929"}
0005434880851	33A1A5	0758 068956	SERGEY BELOV	{"phone": "+70318335774"}
0005434880852	42301D	5073 563721	IVAN KOZLOV	{"email": "kozlovivan17031984@postgrespro.ru", "phone": "+70734018900"}
0005434880853	6DC4C9	1115 424562	ANTONINA PAVLOVA	{"email": "apavlova041983@postgrespro.ru", "phone": "+70548925444"}
0005434880854	BF1012	0412 552777	ELENA MIKHAYLOVA	{"phone": "+70046319729"}
0005434880855	DB9EBC	2135 235729	ANNA SOLOVEVA	{"email": "soloveva.anna-031973@postgrespro.ru", "phone": "+70054578236"}
0005434880856	DB9EBC	6303 025351	SERGEY OSIPOV	{"phone": "+70757242045"}
0005434880857	D6D54E	6619 625478	LIDIYA NOVIKOVA	{"email": "lidiyanovikova_1973@postgrespro.ru", "phone": "+70450604286"}
0005434880858	D6D54E	1271 851045	PAVEL DAVYDOV	{"email": "pavel_davydov_1957@postgrespro.ru", "phone": "+70905561941"}
0005434880859	D6D54E	8003 990231	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev_25081968@postgrespro.ru", "phone": "+70324167741"}
0005434880860	2529BD	9914 691233	MARINA KRASNOVA	{"phone": "+70562330797"}
0005434880861	05F175	8084 031592	MIKHAIL DAVYDOV	{"phone": "+70321553348"}
0005434880862	05F175	2408 300708	MAKSIM TIKHONOV	{"email": "maksim-tikhonov1967@postgrespro.ru", "phone": "+70587355854"}
0005434880863	DA1C94	9133 274394	VALENTINA ROMANOVA	{"email": "romanova_valentina10041974@postgrespro.ru", "phone": "+70580986240"}
0005434880924	651150	8219 023588	ALEKSANDR DMITRIEV	{"phone": "+70012734612"}
0005434880864	2ED813	7338 583632	MAKSIM IVANOV	{"email": "ivanov-maksim-1970@postgrespro.ru", "phone": "+70349383760"}
0005434880865	5BB967	8101 875668	TATYANA KUZMINA	{"phone": "+70965170151"}
0005434880866	1F8D6A	9191 018133	KARINA ZHUKOVA	{"phone": "+70028702699"}
0005434880867	8781ED	7739 579119	IRINA KUZNECOVA	{"phone": "+70405518911"}
0005434880868	4A8CB4	6117 316791	NINA ALEKSANDROVA	{"email": "aleksandrova_n_29121979@postgrespro.ru", "phone": "+70142609249"}
0005434880869	5212EA	3328 626244	VARVARA POPOVA	{"phone": "+70070025940"}
0005434880870	0A5B74	5811 400712	ALEKSANDR VLASOV	{"email": "aleksandrvlasov-111968@postgrespro.ru", "phone": "+70128815502"}
0005434880871	07D801	4079 380832	TATYANA MIKHAYLOVA	{"email": "mikhaylova.t-14021980@postgrespro.ru", "phone": "+70956417121"}
0005434880872	07D801	3906 190013	VERA TARASOVA	{"phone": "+70604245820"}
0005434880873	07D801	5963 692471	LYUBOV DAVYDOVA	{"email": "davydova.l1974@postgrespro.ru", "phone": "+70246192712"}
0005434880874	9722FD	2347 044224	MARIYA SERGEEVA	{"email": "sergeevamariya_08041967@postgrespro.ru", "phone": "+70560865462"}
0005434880875	E2CD73	8492 951520	RIFAT GRIGOREV	{"phone": "+70352475436"}
0005434880876	E1B71A	8328 107741	DMITRIY VASILEV	{"email": "d_vasilev_1964@postgrespro.ru", "phone": "+70625239290"}
0005434880877	5709CF	4768 089067	ANASTASIYA SOKOLOVA	{"phone": "+70210419038"}
0005434880878	A5C23B	5907 827100	LYUDMILA GUSEVA	{"email": "guseva_lyudmila.1985@postgrespro.ru", "phone": "+70239690862"}
0005434880879	953B6C	9456 324237	NINA DAVYDOVA	{"phone": "+70950626344"}
0005434880880	953B6C	0734 859482	RAFIK FROLOV	{"phone": "+70567298820"}
0005434880881	D06E8A	3719 954318	ELVIRA POPOVA	{"phone": "+70844969156"}
0005434880882	67CD5F	4356 193136	SULTAN ZHUKOV	{"email": "zhukov-s.101971@postgrespro.ru", "phone": "+70729493307"}
0005434880883	BDFB87	2074 148446	ANNA NAUMOVA	{"email": "naumova-anna121977@postgrespro.ru", "phone": "+70227894548"}
0005434880884	BDFB87	9481 155517	MIKHAIL IVANOV	{"phone": "+70711645272"}
0005434880885	1B9172	4144 462366	TATYANA MOROZOVA	{"email": "tmorozova.061982@postgrespro.ru", "phone": "+70332110285"}
0005434880886	1B9172	9400 413249	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova-1975@postgrespro.ru", "phone": "+70805375725"}
0005434880887	135153	1324 050362	VIKTOR SERGEEV	{"email": "viktor.sergeev_22091972@postgrespro.ru", "phone": "+70362499178"}
0005434880888	F67E86	1995 593630	OKSANA ALEKSANDROVA	{"email": "aleksandrova-oksana-05041970@postgrespro.ru", "phone": "+70462236169"}
0005434880889	F33B12	4653 161064	MARINA LEBEDEVA	{"phone": "+70027018662"}
0005434880890	F33B12	7590 928206	NIKITA DENISOV	{"phone": "+70889077092"}
0005434880891	28686A	7234 166781	VLADIMIR KRASNOV	{"email": "v_krasnov.081967@postgrespro.ru", "phone": "+70866144765"}
0005434880892	6A827D	5677 316086	SERGEY MIRONOV	{"phone": "+70874843576"}
0005434880893	324F99	3138 664567	GALINA AKIMOVA	{"email": "akimova_galina-021981@postgrespro.ru", "phone": "+70680006731"}
0005434880894	6969BC	5430 789218	NATALYA GORBUNOVA	{"email": "gorbunovanatalya_1973@postgrespro.ru", "phone": "+70978965343"}
0005434880895	EA2639	5787 466604	ELENA ZAYCEVA	{"phone": "+70155678304"}
0005434880896	EA2639	2073 778478	NIKOLAY YAKOVLEV	{"email": "nikolay_yakovlev_22021977@postgrespro.ru", "phone": "+70450918433"}
0005434880897	2ED44E	5150 249898	VALENTINA MELNIKOVA	{"phone": "+70193525400"}
0005434880898	2ED44E	9555 799954	NIKOLAY MAKAROV	{"phone": "+70039943731"}
0005434880899	98BD93	7890 452949	ANDREY TIMOFEEV	{"email": "timofeev_a.061965@postgrespro.ru", "phone": "+70662277376"}
0005434880900	7F6673	3846 143736	LYUDMILA IVANOVA	{"phone": "+70336640640"}
0005434880901	0DBA7C	2395 772391	VIKTORIYA IVANOVA	{"phone": "+70005946932"}
0005434880902	124346	8736 313728	EVDOKIYA MAKAROVA	{"phone": "+70823957907"}
0005434880903	0187DF	6047 035046	ALEKSEY KUZNECOV	{"phone": "+70650581163"}
0005434880904	BEEAE0	0487 280435	LYUBOV ISAEVA	{"email": "lyubov_isaeva-15091978@postgrespro.ru", "phone": "+70096055889"}
0005434880905	EBFFDA	5845 140485	PAVEL MAKAROV	{"email": "p_makarov061979@postgrespro.ru", "phone": "+70199457986"}
0005434880906	D8FA09	2001 281807	IVAN MIKHAYLOV	{"phone": "+70235117382"}
0005434880907	4BB065	6459 242227	ELZA KISELEVA	{"email": "kiseleva-elza1968@postgrespro.ru", "phone": "+70378342456"}
0005434880908	4BB065	1578 137195	MARIYA MOROZOVA	{"phone": "+70545623194"}
0005434880909	BFD1FE	4455 976300	NINA KAZAKOVA	{"phone": "+70849494089"}
0005434880910	BFD1FE	2396 892879	SERGEY SCHERBAKOV	{"email": "scherbakovsergey03021962@postgrespro.ru", "phone": "+70429963978"}
0005434880911	3EA1F1	7984 036652	VITALIY KUZNECOV	{"email": "kuznecovvitaliy-31081970@postgrespro.ru", "phone": "+70086427804"}
0005434880912	3EA1F1	0418 512259	IVAN MEDVEDEV	{"phone": "+70596537377"}
0005434880913	2D9AC6	9975 091891	ALEKSANDR BONDARENKO	{"email": "bondarenko_a.1967@postgrespro.ru", "phone": "+70468852531"}
0005434880914	2D9AC6	5193 531072	ALEKSANDR RODIONOV	{"email": "arodionov_04011969@postgrespro.ru", "phone": "+70385835022"}
0005434880915	A7353B	9544 814766	SERGEY MAKAROV	{"email": "makarov-sergey.101973@postgrespro.ru", "phone": "+70708414720"}
0005434880916	A7353B	1225 774996	VALENTINA BELOVA	{"email": "belovav.1978@postgrespro.ru", "phone": "+70251145644"}
0005434880917	518B29	4052 046644	OLGA MELNIKOVA	{"phone": "+70095656257"}
0005434880918	F90E00	0847 505307	VLADIMIR ZAYCEV	{"email": "v_zaycev-08031978@postgrespro.ru", "phone": "+70358251873"}
0005434880919	6B6D6E	7624 547381	ANNA LOGINOVA	{"email": "loginova_a-1967@postgrespro.ru", "phone": "+70315764976"}
0005434880920	0B2AF9	5071 480750	OLEG SMIRNOV	{"email": "smirnovo_1974@postgrespro.ru", "phone": "+70396850286"}
0005434880921	0B2AF9	0310 475990	ZINAIDA BORISOVA	{"phone": "+70836042645"}
0005434880922	0B2AF9	4246 004638	ALEKSEY TIMOFEEV	{"email": "timofeev_a-25071974@postgrespro.ru", "phone": "+70313771149"}
0005434880923	651150	4385 206270	VIKTOR OSIPOV	{"phone": "+70731032176"}
0005434880925	756EB2	9984 532867	VALENTINA KOROLEVA	{"email": "valentina-koroleva-1960@postgrespro.ru", "phone": "+70795983846"}
0005434880926	10ED85	8023 875724	ELENA KRASNOVA	{"phone": "+70171090354"}
0005434880927	5157F8	4861 501678	MIKHAIL NIKOLAEV	{"email": "nikolaev.mikhail_20021970@postgrespro.ru", "phone": "+70135431228"}
0005434880928	B0F906	8826 262119	STANISLAV IVANOV	{"email": "s-ivanov-1967@postgrespro.ru", "phone": "+70825625019"}
0005434880929	957642	0660 591069	ARKADIY SERGEEV	{"email": "a.sergeev_1985@postgrespro.ru", "phone": "+70255204760"}
0005434880930	4165A5	3608 589561	ANNA ANISIMOVA	{"phone": "+70854113681"}
0005434880931	B0B5A6	1410 388446	SVETLANA KUZMINA	{"email": "svetlana-kuzmina_1986@postgrespro.ru", "phone": "+70679748353"}
0005434880932	B0B5A6	2659 376350	ELENA MOROZOVA	{"phone": "+70271748696"}
0005434880933	54A829	1564 826606	OLGA DAVYDOVA	{"email": "olga-davydova.111984@postgrespro.ru", "phone": "+70855327342"}
0005434880934	54A829	0051 420443	YURIY BONDARENKO	{"email": "bondarenko-yuriy1975@postgrespro.ru", "phone": "+70684953960"}
0005434880935	118D38	1727 080833	ALISA MIKHAYLOVA	{"email": "alisamikhaylova121974@postgrespro.ru", "phone": "+70929007904"}
0005434880936	EDCE61	3596 362272	NADEZHDA VASILEVA	{"email": "nadezhda_vasileva_1972@postgrespro.ru", "phone": "+70351118577"}
0005434880937	69D248	1184 381332	MARK AFANASEV	{"phone": "+70209505947"}
0005434880938	69D248	7661 693738	NINA FOMINA	{"phone": "+70827103953"}
0005434880939	A89094	2112 636875	TATYANA FEDOROVA	{"email": "tatyanafedorova071966@postgrespro.ru", "phone": "+70467200074"}
0005434880940	5673B5	3484 565556	DANIIL PETROV	{"phone": "+70225597376"}
0005434880941	AFF21E	6201 322447	KLAVDIYA MOISEEVA	{"email": "moiseeva-klavdiya_1973@postgrespro.ru", "phone": "+70135561007"}
0005434880942	262560	1054 074067	GALIYA MAKAROVA	{"phone": "+70259126704"}
0005434880943	262560	5158 409129	ALEKSANDR TARASOV	{"email": "tarasovaleksandr_1968@postgrespro.ru", "phone": "+70190509528"}
0005434880944	FDD1E1	2651 331882	NADEZHDA KOMAROVA	{"phone": "+70413226862"}
0005434880945	76C314	8977 130417	GALINA POPOVA	{"email": "popova_galina.1972@postgrespro.ru", "phone": "+70745088493"}
0005434880946	F7294A	6740 551712	NADEZHDA KUZNECOVA	{"email": "n-kuznecova-26091977@postgrespro.ru", "phone": "+70161638173"}
0005434880947	05B67B	4385 481165	VLADIMIR KUZNECOV	{"phone": "+70585026360"}
0005434880948	05B67B	2115 315753	ALEKSANDRA MELNIKOVA	{"email": "melnikova.a_10091973@postgrespro.ru", "phone": "+70994106488"}
0005434880949	3BFC37	7534 961518	ANNA DMITRIEVA	{"email": "anna.dmitrieva1978@postgrespro.ru", "phone": "+70308745955"}
0005434880950	D996D1	9431 233287	KARINA BELOVA	{"phone": "+70020487530"}
0005434880951	28E4A8	7383 885865	VLADIMIR AFANASEV	{"phone": "+70883782746"}
0005434880952	2A30FF	7001 551310	ALEKSANDR MEDVEDEV	{"phone": "+70416398905"}
0005434880953	30589B	4233 505755	KSENIYA KONOVALOVA	{"phone": "+70562040112"}
0005434880954	DE5D08	4411 789171	DMITRIY SCHERBAKOV	{"email": "scherbakovdmitriy091964@postgrespro.ru", "phone": "+70055155726"}
0005434880955	DE5D08	4056 380788	MIKHAIL ALEKSANDROV	{"email": "aleksandrov-mikhail.091967@postgrespro.ru", "phone": "+70351766595"}
0005434880956	67C017	1416 237680	SERGEY FROLOV	{"email": "frolov_sergey_011985@postgrespro.ru", "phone": "+70798792565"}
0005434880957	67C017	5155 718132	RAISA FOMINA	{"phone": "+70315500148"}
0005434880958	DF3305	2659 319522	IGOR DENISOV	{"email": "i-denisov.1971@postgrespro.ru", "phone": "+70690569990"}
0005434880959	23D944	9130 834023	NELLI SOKOLOVA	{"email": "sokolova_nelli.03071977@postgrespro.ru", "phone": "+70283698350"}
0005434880960	2DFA07	8444 872850	DMITRIY ZAYCEV	{"email": "dmitriy_zaycev-11061970@postgrespro.ru", "phone": "+70019005504"}
0005434880961	EFF4A4	8533 519751	ANASTASIYA DAVYDOVA	{"phone": "+70607027092"}
0005434880962	EFF4A4	1120 902859	EKATERINA MEDVEDEVA	{"email": "medvedevaekaterina-1962@postgrespro.ru", "phone": "+70946955137"}
0005434880963	0FE25B	5496 400833	KIRILL ORLOV	{"phone": "+70394698122"}
0005434880964	E5A2F3	3700 819270	NIKOLAY YAKOVLEV	{"phone": "+70129587005"}
0005434880965	E5A2F3	6564 976306	ILYA DAVYDOV	{"phone": "+70189901028"}
0005434880966	91E69C	6563 552281	ALEKSANDRA NOVIKOVA	{"phone": "+70541506086"}
0005434880967	1D8D61	7165 669372	VLADISLAV SEMENOV	{"email": "semenov.vladislav_1969@postgrespro.ru", "phone": "+70292920419"}
0005434880968	1D8D61	7338 020598	VERA SERGEEVA	{"email": "sergeeva.vera.091962@postgrespro.ru", "phone": "+70870894478"}
0005434880969	230C24	0167 671499	OLESYA FROLOVA	{"phone": "+70954130673"}
0005434880970	2AFC67	3265 298158	ANTON TIMOFEEV	{"phone": "+70632896478"}
0005434880971	2FEBE2	4024 869889	NATALYA GUSEVA	{"phone": "+70752697294"}
0005434880972	8C8D59	6935 122988	NIKOLAY FEDOTOV	{"phone": "+70047001902"}
0005434880973	0C05E1	5995 572922	MARGARITA MATVEEVA	{"phone": "+70247437205"}
0005434880974	72F137	1674 507672	ANDREY ALEKSEEV	{"phone": "+70826420687"}
0005434880975	7E2432	2529 616003	MARINA NIKIFOROVA	{"email": "marina-nikiforova.081981@postgrespro.ru", "phone": "+70514787266"}
0005434880976	2C4994	8439 803810	MARGARITA NIKOLAEVA	{"email": "nikolaeva.m_1961@postgrespro.ru", "phone": "+70938119246"}
0005434880977	26F834	5691 632599	KARINA BELYAEVA	{"phone": "+70375608972"}
0005434880978	26F834	2653 413730	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov1968@postgrespro.ru", "phone": "+70938999047"}
0005434880979	DDE4A4	9785 712373	ALEKSANDR KUZNECOV	{"phone": "+70622631879"}
0005434880980	2F1050	3851 611499	SVETLANA MIKHAYLOVA	{"email": "svetlanamikhaylova121965@postgrespro.ru", "phone": "+70402529557"}
0005434880981	E52B50	5505 060725	RUSLAN KULIKOV	{"email": "kulikov-ruslan_1980@postgrespro.ru", "phone": "+70198970385"}
0005434880982	6482C1	9655 701026	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr05011978@postgrespro.ru", "phone": "+70314053952"}
0005434880983	058857	7332 682498	ALEKSEY KONOVALOV	{"phone": "+70995454762"}
0005434880984	A7C066	0699 751496	EVGENIYA SMIRNOVA	{"email": "e-smirnova-021975@postgrespro.ru", "phone": "+70348988402"}
0005434880985	A7C066	6073 116142	RAISA ARKHIPOVA	{"phone": "+70381957471"}
0005434880986	A9C95B	3913 779887	ANDREY SOKOLOV	{"email": "andrey-sokolov.051977@postgrespro.ru", "phone": "+70709268262"}
0005434880987	4797AC	8937 894277	GALINA MELNIKOVA	{"email": "galinamelnikova_061965@postgrespro.ru", "phone": "+70768816485"}
0005434880988	9C433D	5971 981551	EVGENIYA NIKOLAEVA	{"phone": "+70305833384"}
0005434880989	4E5F93	1619 735820	NINA BELOVA	{"email": "nina_belova_041972@postgrespro.ru", "phone": "+70177990579"}
0005434880990	4E5F93	6534 320304	KLAVDIYA DENISOVA	{"email": "klavdiya_denisova-011969@postgrespro.ru", "phone": "+70948296899"}
0005434880991	8BF805	4710 732463	LYUDMILA STEPANOVA	{"email": "lyudmilastepanova_1971@postgrespro.ru", "phone": "+70577349257"}
0005434906359	A96ADE	3565 954953	LYUDMILA STEPANOVA	{"email": "l-stepanova.1980@postgrespro.ru", "phone": "+70275906067"}
0005434906360	20B1BA	1159 324500	ALINA ZAYCEVA	{"phone": "+70771020995"}
0005434906361	9151E6	5254 898589	VIKTOR IVANOV	{"phone": "+70238499618"}
0005434906362	9151E6	3863 109754	OLGA NOVIKOVA	{"email": "olga-novikova-1964@postgrespro.ru", "phone": "+70810035465"}
0005434906363	9D1D40	2154 935437	DANIIL VOLKOV	{"phone": "+70960369294"}
0005434906364	FF3D89	8219 568959	EVGENIYA CHERNOVA	{"phone": "+70422621466"}
0005434906365	2B9365	0889 590995	OLGA MIRONOVA	{"phone": "+70274726009"}
0005434906366	BC9C0D	1484 967020	NATALIYA POTAPOVA	{"phone": "+70751195486"}
0005434906367	A4A71F	4808 914854	ANDREY AFANASEV	{"email": "afanasev.a-18071983@postgrespro.ru", "phone": "+70090023282"}
0005434906368	A4A71F	5433 387971	EVGENIY ALEKSEEV	{"phone": "+70359904705"}
0005434906424	C48AE4	8430 108764	EVGENIY MARTYNOV	{"phone": "+70713146863"}
0005434906369	9DC8D0	1389 837248	NATALYA ZOTOVA	{"email": "nzotova-24061979@postgrespro.ru", "phone": "+70322188396"}
0005434906370	7283AB	0251 055936	MARINA EFIMOVA	{"phone": "+70397663934"}
0005434906371	86D023	9398 700146	MARGARITA SEMENOVA	{"phone": "+70437599462"}
0005434906372	4B769C	7888 384828	ROMAN MAKAROV	{"email": "r.makarov30101962@postgrespro.ru", "phone": "+70585431380"}
0005434906373	2428D0	6998 433729	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov1990@postgrespro.ru", "phone": "+70144592581"}
0005434906374	2428D0	2151 236781	NIKOLAY SMIRNOV	{"email": "nikolay_smirnov-021983@postgrespro.ru", "phone": "+70442517771"}
0005434906375	CCC358	6187 927594	OLEG KOROLEV	{"email": "korolev-oleg-12041969@postgrespro.ru", "phone": "+70224762561"}
0005434906376	CCC358	6189 952795	SNEZHANA VOROBEVA	{"phone": "+70312413791"}
0005434906377	568688	1567 649078	RAISA EGOROVA	{"phone": "+70481383421"}
0005434906378	441380	9582 589178	LYUDMILA ILINA	{"email": "ilinalyudmila101980@postgrespro.ru", "phone": "+70723204891"}
0005434906379	83BCAA	0346 276890	MARIYA ROMANOVA	{"email": "romanova-mariya121968@postgrespro.ru", "phone": "+70040907408"}
0005434906380	83BCAA	5151 092492	DANILA SAVELEV	{"phone": "+70138083960"}
0005434906381	A822CB	5969 521827	NATALYA PAVLOVA	{"email": "natalyapavlova_121965@postgrespro.ru", "phone": "+70317628597"}
0005434906382	9C6EF5	8503 713431	VLADISLAV SAVELEV	{"phone": "+70039642115"}
0005434906383	DF7766	9089 284571	ANATOLIY MIKHAYLOV	{"email": "mikhaylov.anatoliy-1979@postgrespro.ru", "phone": "+70522490035"}
0005434906384	DF7766	4941 982008	DMITRIY BELOV	{"phone": "+70018262847"}
0005434906385	EC2BB7	1499 022863	STEPAN PETROV	{"email": "spetrov-051967@postgrespro.ru", "phone": "+70289954640"}
0005434906386	EC2BB7	9393 427882	MARIYA BELYAEVA	{"email": "m-belyaeva.111982@postgrespro.ru", "phone": "+70580532347"}
0005434906387	EB645B	1560 503666	ELENA GRISHINA	{"phone": "+70351873211"}
0005434906388	EB645B	9967 061606	ANTON POPOV	{"email": "popov-anton071970@postgrespro.ru", "phone": "+70586438463"}
0005434906389	A6A9FB	7672 748990	ANASTASIYA ZAYCEVA	{"email": "anastasiya-zayceva.071959@postgrespro.ru", "phone": "+70597584212"}
0005434906390	A6A9FB	5318 090722	LYUBOV TARASOVA	{"email": "tarasova_lyubov1972@postgrespro.ru", "phone": "+70026500729"}
0005434906391	A6A9FB	0622 975926	VALERIY KULIKOV	{"phone": "+70711459234"}
0005434906392	170A69	3323 549252	VLADIMIR POPOV	{"email": "vladimir_popov_03071968@postgrespro.ru", "phone": "+70179004080"}
0005434906393	170A69	3398 773208	IRINA NOVIKOVA	{"email": "inovikova09071978@postgrespro.ru", "phone": "+70814546031"}
0005434906394	233703	2483 912665	ILYA SMIRNOV	{"phone": "+70010362542"}
0005434906395	798CAC	5545 697285	VLADISLAV RODIONOV	{"phone": "+70359935163"}
0005434906396	528858	1300 669569	LYUBOV MALYSHEVA	{"email": "lyubovmalysheva21081981@postgrespro.ru", "phone": "+70714696199"}
0005434906397	896CE2	5689 235512	VLADISLAV DMITRIEV	{"email": "dmitriev.vladislav-08091960@postgrespro.ru", "phone": "+70139136036"}
0005434906398	C6A699	9692 442230	ANATOLIY MAKSIMOV	{"email": "anatoliy.maksimov.1995@postgrespro.ru", "phone": "+70015148202"}
0005434906399	B09B8A	0957 682436	VLADIMIR FOMIN	{"phone": "+70118814240"}
0005434906400	8B56D5	1570 629784	OLEG ROMANOV	{"email": "romanov.oleg.021968@postgrespro.ru", "phone": "+70086538329"}
0005434906401	29073D	1740 042124	MARINA KOLESNIKOVA	{"phone": "+70323949539"}
0005434906402	9A3E0D	0829 046127	NINA ZAKHAROVA	{"phone": "+70138188274"}
0005434906403	FD35A1	4051 399677	SERGEY SEMENOV	{"email": "semenovs081984@postgrespro.ru", "phone": "+70842707069"}
0005434906404	5DFB84	0973 363232	TATYANA KUZNECOVA	{"phone": "+70343249160"}
0005434906405	F05161	4893 440252	VLADIMIR SMIRNOV	{"email": "vladimir-smirnov-25031968@postgrespro.ru", "phone": "+70675574127"}
0005434906406	F05161	8469 756128	EDUARD PETROV	{"email": "petrove-07061974@postgrespro.ru", "phone": "+70812735806"}
0005434906407	EB411A	8517 972043	ZAKHAR MAKSIMOV	{"email": "zakhar.maksimov-24061967@postgrespro.ru", "phone": "+70487082163"}
0005434906408	221D8D	6738 997947	OKSANA KULIKOVA	{"phone": "+70150600519"}
0005434906409	D85A91	6633 265849	VASILIY BONDARENKO	{"email": "bondarenko.v-18111982@postgrespro.ru", "phone": "+70457464834"}
0005434906410	5D6445	2022 850835	GALINA KUZNECOVA	{"email": "kuznecovagalina.1970@postgrespro.ru", "phone": "+70459142327"}
0005434906411	2EB828	4725 601065	LYUBOV MOISEEVA	{"email": "lyubovmoiseeva.041973@postgrespro.ru", "phone": "+70820150308"}
0005434906412	211BC9	7631 796720	TATYANA ANTONOVA	{"email": "antonovat_20111977@postgrespro.ru", "phone": "+70270152954"}
0005434906413	D3913B	4329 431555	VALERIYA SERGEEVA	{"email": "sergeevavaleriya_1974@postgrespro.ru", "phone": "+70482006068"}
0005434906414	D3913B	7405 905526	RINAT KUZNECOV	{"phone": "+70828218047"}
0005434906415	94D5AA	5582 318437	REGINA MAKAROVA	{"email": "makarova.r06011976@postgrespro.ru", "phone": "+70045546019"}
0005434906416	25713E	8442 739270	ANZHELIKA BOGDANOVA	{"email": "bogdanova-a.011976@postgrespro.ru", "phone": "+70926051862"}
0005434906417	25713E	4731 127155	ANATOLIY POPOV	{"phone": "+70564516695"}
0005434906418	DBF5D8	9002 884260	RISHAT IVANOV	{"email": "ivanov_rishat.101980@postgrespro.ru", "phone": "+70818034755"}
0005434906419	CA6B1B	1567 031157	MARIYA SMIRNOVA	{"email": "smirnova_mariya-17121978@postgrespro.ru", "phone": "+70112780845"}
0005434906420	16B25D	6597 317634	PAVEL KOZLOV	{"email": "pavelkozlov1960@postgrespro.ru", "phone": "+70461889264"}
0005434906421	BDE3E1	0072 410579	VALERIYA FROLOVA	{"phone": "+70252300610"}
0005434906422	BDE3E1	3546 076868	SERGEY DMITRIEV	{"email": "sdmitriev061970@postgrespro.ru", "phone": "+70411388114"}
0005434906423	5FEA11	4239 027784	STEPAN GORBUNOV	{"phone": "+70529404948"}
0005434906425	C48AE4	9038 645000	MAKSIM FEDOTOV	{"email": "fedotovmaksim_011976@postgrespro.ru", "phone": "+70382100098"}
0005434906426	A6BFB3	0862 110852	IRINA KONOVALOVA	{"email": "i_konovalova071972@postgrespro.ru", "phone": "+70796810419"}
0005434906427	9AD29C	2805 048038	ALEKSANDR FROLOV	{"email": "afrolov_10101975@postgrespro.ru", "phone": "+70208447655"}
0005434906428	9AD29C	4161 967264	ALEKSANDR ANDREEV	{"phone": "+70887085775"}
0005434906429	809792	3021 708324	VYACHESLAV MIRONOV	{"email": "mironov.v101971@postgrespro.ru", "phone": "+70072959287"}
0005434906430	809792	2365 564690	VLADIMIR ILIN	{"phone": "+70822974331"}
0005434906431	4E3427	2015 021948	LYUBOV KOVALEVA	{"email": "kovaleva.lyubov.1972@postgrespro.ru", "phone": "+70727282698"}
0005434906432	86791F	3491 252429	SERGEY ZHUKOV	{"phone": "+70681256251"}
0005434906433	49DFF9	5212 886454	ELVIRA TIMOFEEVA	{"phone": "+70754820094"}
0005434906434	32B2E8	8966 818918	TAMARA IVANOVA	{"email": "ivanova_tamara21061978@postgrespro.ru", "phone": "+70754573416"}
0005434906435	49C5CA	1901 179617	RUSLAN VLASOV	{"email": "rvlasov-1963@postgrespro.ru", "phone": "+70025630768"}
0005434906436	C72258	6800 274746	VERA PAVLOVA	{"email": "vera.pavlova.19111962@postgrespro.ru", "phone": "+70681898297"}
0005434906437	906BD4	2733 233083	VYACHESLAV ROMANOV	{"email": "vyacheslavromanov08051975@postgrespro.ru", "phone": "+70029686370"}
0005434906438	906BD4	0668 230609	EKATERINA KAZAKOVA	{"email": "ekaterina.kazakova-1967@postgrespro.ru", "phone": "+70190356528"}
0005434906439	B0C2C5	5513 412097	VADIM ROMANOV	{"email": "vadim.romanov_27111960@postgrespro.ru", "phone": "+70131566059"}
0005434906440	B0C2C5	7149 715604	VALENTINA NIKITINA	{"phone": "+70649457855"}
0005434906441	A06421	8607 966473	ANATOLIY VOLKOV	{"phone": "+70809692116"}
0005434906442	E7A125	0136 459043	ALEKSANDR GUSEV	{"phone": "+70279988603"}
0005434906443	3ED42F	8232 515759	ALEKSEY VASILEV	{"email": "alekseyvasilev041972@postgrespro.ru", "phone": "+70598866590"}
0005434906444	1AB897	1518 018966	ANTON KUZMIN	{"email": "kuzmin-anton_081973@postgrespro.ru", "phone": "+70781762437"}
0005434906445	6C0FD1	7995 628437	ANASTASIYA LOGINOVA	{"email": "loginova.a_29051964@postgrespro.ru", "phone": "+70624314066"}
0005434906446	6C0FD1	1247 350384	MIKHAIL KUZNECOV	{"email": "m_kuznecov28021971@postgrespro.ru", "phone": "+70192433848"}
0005434906447	6C0FD1	5192 056071	MARIYA POPOVA	{"email": "mariya.popova_081978@postgrespro.ru", "phone": "+70279594847"}
0005434906448	5967EF	3070 844357	SVETLANA STEPANOVA	{"email": "stepanova.s-02101971@postgrespro.ru", "phone": "+70687815180"}
0005434906449	5967EF	1908 893112	EKATERINA ZHURAVLEVA	{"email": "e-zhuravleva081973@postgrespro.ru", "phone": "+70377751771"}
0005434906450	43EE52	6797 277581	DMITRIY ZAKHAROV	{"phone": "+70779120597"}
0005434906451	43EE52	9049 064976	ALEKSANDR VOLKOV	{"email": "volkov_a04041972@postgrespro.ru", "phone": "+70177223637"}
0005434906452	EE23BC	9801 825842	RAFAIL SOKOLOV	{"email": "sokolov.r_1966@postgrespro.ru", "phone": "+70024527565"}
0005434906453	EE23BC	1210 956366	VLADIMIR SAVELEV	{"email": "savelev-v081972@postgrespro.ru", "phone": "+70826212141"}
0005434906454	E75E89	1919 469753	DMITRIY ANDREEV	{"phone": "+70486547795"}
0005434906455	246C51	3155 173686	SVETLANA ANDREEVA	{"email": "andreevas-09021963@postgrespro.ru", "phone": "+70543900807"}
0005434906456	692A05	1533 980768	SERGEY YAKOVLEV	{"phone": "+70987853630"}
0005434906457	692A05	1042 026080	INNA KUZNECOVA	{"email": "kuznecova_inna28101969@postgrespro.ru", "phone": "+70546762933"}
0005434906458	26D37E	0030 342759	VLADIMIR ILIN	{"email": "vladimir-ilin1967@postgrespro.ru", "phone": "+70691537436"}
0005434906459	E9E7D8	8353 624795	ALEKSEY PAVLOV	{"email": "pavlov-aleksey_24081982@postgrespro.ru", "phone": "+70238266883"}
0005434906460	E9E7D8	9205 257301	ELENA ZAYCEVA	{"phone": "+70269010358"}
0005434906461	E9E7D8	4951 941476	ANDREY GRIGOREV	{"phone": "+70383462526"}
0005434906462	F706A0	2059 467199	KONSTANTIN EGOROV	{"phone": "+70585420240"}
0005434906463	F706A0	8378 066481	NIKOLAY KUZNECOV	{"phone": "+70149325212"}
0005434906464	AC67BA	2284 957845	ANGELINA MAKAROVA	{"phone": "+70464598720"}
0005434906465	78EF17	9438 583721	ILYA OSIPOV	{"phone": "+70377823591"}
0005434906466	78EF17	7530 063152	RAISA NIKOLAEVA	{"phone": "+70223429674"}
0005434906467	C46F66	7660 838441	VLADISLAV KRASNOV	{"phone": "+70606346816"}
0005434906468	C46F66	1106 200321	VLADIMIR ILIN	{"email": "ilin.v_26121980@postgrespro.ru", "phone": "+70251223827"}
0005434906469	E9EF34	1667 506614	NADEZHDA KUZNECOVA	{"phone": "+70773710470"}
0005434906470	1A3DFC	0906 624891	OKSANA KUZNECOVA	{"email": "kuznecova.o1964@postgrespro.ru", "phone": "+70774065420"}
0005434906471	44FD0A	4121 306859	SERGEY ALEKSEEV	{"phone": "+70935095925"}
0005434906472	44FD0A	7089 029513	ANNA SOROKINA	{"email": "a-sorokina021964@postgrespro.ru", "phone": "+70859890170"}
0005434906473	4C3C52	5928 298753	ELVIRA BORISOVA	{"phone": "+70380389712"}
0005434906474	0AB757	4085 221090	IGOR PETROV	{"email": "i_petrov-101968@postgrespro.ru", "phone": "+70626296131"}
0005434906475	AF55BE	1054 225212	VALENTINA YUDINA	{"email": "valentinayudina21041970@postgrespro.ru", "phone": "+70520412691"}
0005434906476	331DC8	3510 793459	EKATERINA FROLOVA	{"phone": "+70381358140"}
0005434906477	8EE579	0769 229417	LYUBOV NIKOLAEVA	{"email": "lyubovnikolaeva121969@postgrespro.ru", "phone": "+70886541896"}
0005434906478	8E02BD	7914 236349	ANDREY DMITRIEV	{"email": "dmitriev-a_1967@postgrespro.ru", "phone": "+70745513798"}
0005434906479	8E02BD	6942 499329	SERGEY SOLOVEV	{"email": "s-solovev.03111977@postgrespro.ru", "phone": "+70427188831"}
0005434906480	6BA7BB	4516 571353	DMITRIY KISELEV	{"email": "kiselev.dmitriy.1976@postgrespro.ru", "phone": "+70514060590"}
0005434906481	DC9D09	2973 637529	SERGEY KISELEV	{"email": "sergey_kiselev_1972@postgrespro.ru", "phone": "+70018219318"}
0005434906482	97C3FD	2317 651978	ELENA SERGEEVA	{"phone": "+70733366007"}
0005434906483	80A986	3424 647533	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr.27041972@postgrespro.ru", "phone": "+70435064120"}
0005434906484	9CD64E	0718 185323	VALENTINA KAZAKOVA	{"phone": "+70779822660"}
0005434906485	BE0956	5795 104940	ANASTASIYA OVCHINNIKOVA	{"phone": "+70768549602"}
0005434906486	E9E87A	8399 146685	ALEKSANDRA KUZNECOVA	{"phone": "+70209076812"}
0005434906487	F6C7FD	9695 446035	SERGEY IVANOV	{"email": "ivanov_sergey.1962@postgrespro.ru", "phone": "+70376092028"}
0005434906488	F6C7FD	3828 798613	VALERIY MATVEEV	{"phone": "+70893350437"}
0005434906489	282FA6	3947 011799	VLADIMIR MARTYNOV	{"email": "v_martynov01021975@postgrespro.ru", "phone": "+70407535315"}
0005434906490	1A6F62	1276 794009	ALEKSANDR DMITRIEV	{"email": "a-dmitriev11081966@postgrespro.ru", "phone": "+70160306224"}
0005434906491	3AE0BC	7384 965013	YURIY IVANOV	{"email": "yuriy_ivanov-05111977@postgrespro.ru", "phone": "+70578920568"}
0005434906492	42083B	9997 290758	SHAMIL IVANOV	{"email": "shamil-ivanov.19051973@postgrespro.ru", "phone": "+70161903086"}
0005434906493	2D5F3A	4570 228487	ALEKSEY SERGEEV	{"email": "alekseysergeev_1963@postgrespro.ru", "phone": "+70482727950"}
0005434906494	232E7A	6819 841531	IVAN SOKOLOV	{"phone": "+70845729229"}
0005434906495	F59C7F	4822 252163	MARINA TIKHONOVA	{"email": "tikhonovam_01121982@postgrespro.ru", "phone": "+70744883736"}
0005434906496	47ED79	7979 892329	YURIY TARASOV	{"email": "tarasov.yuriy-1963@postgrespro.ru", "phone": "+70403570942"}
0005434906497	FF3179	6946 255442	ALEKSEY DENISOV	{"email": "aleksey-denisov_16111961@postgrespro.ru", "phone": "+70061808550"}
0005434906498	FF3179	9097 351811	ANNA SIDOROVA	{"phone": "+70559339538"}
0005434906499	BF7BBA	1394 094970	NIKOLAY DENISOV	{"email": "n.denisov-011964@postgrespro.ru", "phone": "+70652173502"}
0005434906500	BF7BBA	4110 254553	NIKOLAY PETROV	{"phone": "+70708429238"}
0005434906501	DD30F2	4217 428444	VLADISLAV ABRAMOV	{"phone": "+70475718740"}
0005434906502	C8087D	9655 249623	YANINA NESTEROVA	{"email": "nesterova.y.1973@postgrespro.ru", "phone": "+70713223433"}
0005434906503	B36D28	9465 171611	NADEZHDA VOLKOVA	{"email": "n_volkova.1986@postgrespro.ru", "phone": "+70427850183"}
0005434906504	D65CA5	1335 698676	OLEG PETROV	{"email": "petrovo1970@postgrespro.ru", "phone": "+70822937128"}
0005434906505	B94EF2	4436 060195	GALINA ISAEVA	{"phone": "+70105678359"}
0005434906506	783526	6383 385231	ELENA MATVEEVA	{"email": "matveeva.elena15121970@postgrespro.ru", "phone": "+70504374762"}
0005434906507	550723	1894 102513	ALEKSEY SERGEEV	{"email": "sergeevaleksey.10091968@postgrespro.ru", "phone": "+70830117690"}
0005434906508	2F4ED1	4991 571601	VALENTINA IVANOVA	{"phone": "+70606711873"}
0005434906509	451D4E	0903 575634	DMITRIY ALEKSANDROV	{"phone": "+70384695223"}
0005434906510	451D4E	8501 541525	YULIYA VASILEVA	{"email": "vasileva-yuliya02061966@postgrespro.ru", "phone": "+70751460521"}
0005434906511	47172E	6613 959459	LIDIYA ISAEVA	{"phone": "+70149721872"}
0005434906512	07CDC7	2541 771004	OLGA POPOVA	{"email": "popova.o031970@postgrespro.ru", "phone": "+70650361168"}
0005434906513	74DF1D	5371 139756	DMITRIY ZAKHAROV	{"phone": "+70084542779"}
0005434906514	0BE98B	5863 433004	YURIY VOROBEV	{"phone": "+70352139496"}
0005434906515	0BE98B	3787 062148	VALENTINA PAVLOVA	{"email": "pavlova-v_11091978@postgrespro.ru", "phone": "+70498933808"}
0005434906516	D35C13	4825 483099	YURIY ABRAMOV	{"email": "yabramov.081960@postgrespro.ru", "phone": "+70898212744"}
0005434906517	D35C13	0332 132477	ANDREY ISAEV	{"email": "andrey_isaev061963@postgrespro.ru", "phone": "+70520178228"}
0005434906518	D35C13	5157 104437	NADEZHDA ROMANOVA	{"email": "nadezhda.romanova_15031976@postgrespro.ru", "phone": "+70623285990"}
0005434906519	D6D77B	9004 543366	RAISA MAKAROVA	{"phone": "+70517213534"}
0005434906520	D6D77B	6745 498765	ALEKSANDR VOROBEV	{"email": "avorobev.101975@postgrespro.ru", "phone": "+70803429994"}
0005434906521	48FD2E	9846 334872	YULIYA FADEEVA	{"phone": "+70790936866"}
0005434906522	48FD2E	4351 298380	VALERIY SEMENOV	{"phone": "+70797111360"}
0005434906523	48FD2E	9919 384138	DENIS ORLOV	{"phone": "+70448703533"}
0005434906524	5600EC	3130 208263	EKATERINA ALEKSANDROVA	{"phone": "+70794557759"}
0005434906525	5600EC	3015 589503	MARIYA TROFIMOVA	{"phone": "+70910266570"}
0005434906526	635F6C	1647 630728	ALEKSEY KOZLOV	{"phone": "+70587037248"}
0005434906527	1D945F	5810 490943	NELYA SMIRNOVA	{"phone": "+70288435409"}
0005434906528	9EED55	3823 121892	EVGENIY BORISOV	{"email": "borisov_e_03011972@postgrespro.ru", "phone": "+70418837222"}
0005434906529	C1D4BB	2097 085057	ALEKSANDR GERASIMOV	{"email": "aleksandrgerasimov-11111970@postgrespro.ru", "phone": "+70330257323"}
0005434906530	5503D3	4911 084605	ALLA ALEKSEEVA	{"phone": "+70705039597"}
0005434906531	2D9994	3039 072021	TATYANA SERGEEVA	{"email": "sergeeva-t031989@postgrespro.ru", "phone": "+70176439750"}
0005434906532	062C61	9252 034867	VALENTINA VASILEVA	{"email": "valentinavasileva-091964@postgrespro.ru", "phone": "+70990316700"}
0005434906533	062C61	8078 838138	ALEKSEY KOROLEV	{"phone": "+70538811116"}
0005434906534	9104E3	8241 010047	FANIYA MASLOVA	{"phone": "+70859442405"}
0005434906535	639AC9	7788 464412	DMITRIY SOLOVEV	{"email": "dmitriy-solovev_121963@postgrespro.ru", "phone": "+70831486726"}
0005434906536	DA4521	1926 620814	MARINA PAVLOVA	{"email": "pavlova-marina-11051977@postgrespro.ru", "phone": "+70267220854"}
0005434906537	787FB2	5288 310362	ALEVTINA KONOVALOVA	{"email": "konovalova-alevtina_1965@postgrespro.ru", "phone": "+70539031958"}
0005434906538	32FF3B	6145 443447	OLGA MAKAROVA	{"email": "olgamakarova_1980@postgrespro.ru", "phone": "+70250823818"}
0005434906539	A23240	3628 439334	PETR BELOV	{"phone": "+70916799784"}
0005434906540	020CA3	9415 235722	VALENTINA ROMANOVA	{"email": "romanova.valentina_011962@postgrespro.ru", "phone": "+70156550975"}
0005434906541	BBD869	2845 602134	ILDAR DAVYDOV	{"email": "i-davydov-031976@postgrespro.ru", "phone": "+70925046989"}
0005434906542	BBD869	4761 416059	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov.1967@postgrespro.ru", "phone": "+70479010117"}
0005434906543	F1C84B	5701 381301	ALEKSANDR SCHERBAKOV	{"phone": "+70098863541"}
0005434906544	4512A1	0282 358527	PRASKOVYA IVANOVA	{"email": "praskovya.ivanova.1969@postgrespro.ru", "phone": "+70574517076"}
0005434906545	65D053	4585 651515	LIDIYA MAKSIMOVA	{"email": "maksimova.lidiya101954@postgrespro.ru", "phone": "+70925033147"}
0005434906546	565A09	0193 232817	ELENA CHERNOVA	{"phone": "+70204980550"}
0005434906547	F2EDA4	4788 988876	IGOR OSIPOV	{"phone": "+70935562577"}
0005434906548	986B3B	9935 447067	SERGEY POPOV	{"email": "sergeypopov-06031968@postgrespro.ru", "phone": "+70311937308"}
0005434906549	E9B061	6502 608915	LIDIYA ABRAMOVA	{"email": "lidiya-abramova_071979@postgrespro.ru", "phone": "+70200036663"}
0005434906550	51E917	4770 891489	KSENIYA YAKOVLEVA	{"phone": "+70798648052"}
0005434906551	51E917	7684 125852	TATYANA NIKITINA	{"email": "tatyana-nikitina.21101966@postgrespro.ru", "phone": "+70191919149"}
0005434906552	6858C5	5041 176994	EKATERINA BORISOVA	{"email": "borisovaekaterina_071968@postgrespro.ru", "phone": "+70310023946"}
0005434906553	F95344	9118 319516	ALEKSANDR VOLKOV	{"phone": "+70551092108"}
0005434906554	D378BA	6784 732478	ELENA RODIONOVA	{"phone": "+70608980604"}
0005434906555	BC6EDD	1498 278554	ELENA DANILOVA	{"email": "edanilova.091972@postgrespro.ru", "phone": "+70862838559"}
0005434906556	921E02	7821 409865	DANIL KUZMIN	{"email": "dkuzmin1977@postgrespro.ru", "phone": "+70192291885"}
0005434906557	019400	1103 874323	DENIS KOROLEV	{"email": "korolev_denis_061970@postgrespro.ru", "phone": "+70939458675"}
0005434906558	9BD5EC	7987 317647	VLADIMIR SEMENOV	{"phone": "+70309047896"}
0005434906559	9BD5EC	8654 776675	MARIYA PAVLOVA	{"phone": "+70125740088"}
0005434906560	9BD5EC	3660 009029	KONSTANTIN SCHERBAKOV	{"email": "scherbakov.konstantin25021964@postgrespro.ru", "phone": "+70316479906"}
0005434906561	07E47F	0247 442645	SERGEY YAKOVLEV	{"phone": "+70581437739"}
0005434906562	35F6B8	4730 336689	NADEZHDA ABRAMOVA	{"email": "n_abramova.1957@postgrespro.ru", "phone": "+70752175899"}
0005434906563	D1A077	3108 297681	ILYA TARASOV	{"email": "i-tarasov-1975@postgrespro.ru", "phone": "+70770769020"}
0005434906564	AFC538	0164 446107	OLEG EGOROV	{"email": "olegegorov_1964@postgrespro.ru", "phone": "+70970930517"}
0005434906565	214CB0	2606 793670	SERGEY DAVYDOV	{"phone": "+70765903777"}
0005434906566	C8829F	5257 534247	VITALIY DENISOV	{"email": "denisov-vitaliy_081972@postgrespro.ru", "phone": "+70512006747"}
0005434906567	2C2636	1574 577185	NIKOLAY ALEKSANDROV	{"phone": "+70702171485"}
0005434906568	2C2636	2238 731929	VLADIMIR VLASOV	{"phone": "+70013821050"}
0005434906569	2B11CF	6984 090045	ROMAN KOZLOV	{"email": "roman_kozlov_1972@postgrespro.ru", "phone": "+70451378865"}
0005434906570	926DE3	5131 667287	MARIYA FROLOVA	{"email": "m_frolova.18121969@postgrespro.ru", "phone": "+70532349442"}
0005434906571	DAE0C6	8626 042100	FARID KOZLOV	{"email": "f.kozlov-111983@postgrespro.ru", "phone": "+70867120375"}
0005434906572	57A623	0923 449391	NINA PAVLOVA	{"phone": "+70939848725"}
0005434906573	CD6913	1650 821158	IGOR VASILEV	{"email": "i_vasilev1972@postgrespro.ru", "phone": "+70095498182"}
0005434906574	D1F090	3285 964928	DMITRIY MOISEEV	{"email": "moiseev-dmitriy1968@postgrespro.ru", "phone": "+70748766428"}
0005434906575	7A08AB	4887 709859	VIKTOR KUZNECOV	{"email": "vkuznecov20011971@postgrespro.ru", "phone": "+70545974565"}
0005434906576	1D16C0	1792 458187	DANIIL GUSEV	{"email": "gusevdaniil.1988@postgrespro.ru", "phone": "+70142887542"}
0005434906577	1D16C0	1272 051528	DMITRIY CHERNOV	{"email": "dmitriy-chernov-1972@postgrespro.ru", "phone": "+70946656608"}
0005434906578	C4F357	4667 224482	FEDOR MATVEEV	{"phone": "+70042262400"}
0005434906579	C4F357	9580 229094	VENIAMIN TIKHONOV	{"phone": "+70745585484"}
0005434906580	C4F357	2326 898324	DMITRIY KUZNECOV	{"email": "kuznecov_dmitriy-1965@postgrespro.ru", "phone": "+70449302051"}
0005434906581	87C8CA	2064 668894	VLADISLAV IVANOV	{"phone": "+70682833741"}
0005434906582	AC0D28	0037 931472	VIKTOR STEPANOV	{"phone": "+70371327756"}
0005434906583	AC0D28	9618 650236	OLGA OSIPOVA	{"email": "o-osipova.06041973@postgrespro.ru", "phone": "+70931349307"}
0005434906584	943B2F	1676 009251	ANATOLIY BORISOV	{"phone": "+70362813023"}
0005434906585	70DEB5	1161 240449	DANIL KUZNECOV	{"phone": "+70967301120"}
0005434906586	B2D099	4156 166972	EVGENIY ZAKHAROV	{"phone": "+70364684158"}
0005434906587	6C88D7	9434 303613	GALINA STEPANOVA	{"phone": "+70139960756"}
0005434906588	824CB6	3995 982412	ALEKSANDR KOROLEV	{"email": "korolev.aleksandr_1983@postgrespro.ru", "phone": "+70380827427"}
0005434906589	824CB6	1501 161833	EVDOKIYA YAKOVLEVA	{"phone": "+70495440033"}
0005434906590	C52783	9004 241870	PETR MOROZOV	{"email": "p.morozov-081975@postgrespro.ru", "phone": "+70581698033"}
0005434906646	76E690	8510 109438	MAKSIM MEDVEDEV	{"phone": "+70067668011"}
0005434906591	C52783	8863 789980	ANASTASIYA NIKOLAEVA	{"email": "anastasiya.nikolaeva-1964@postgrespro.ru", "phone": "+70276440803"}
0005434906592	F01B38	9232 543938	VALERIYA NIKITINA	{"email": "valeriya_nikitina_061966@postgrespro.ru", "phone": "+70400190395"}
0005434906593	010973	5268 485376	RASHID PETROV	{"email": "r.petrov.1967@postgrespro.ru", "phone": "+70592988038"}
0005434906594	C865B3	5247 724447	LYUBOV TARASOVA	{"phone": "+70807605118"}
0005434906595	C865B3	9143 503864	KRISTINA KRASNOVA	{"phone": "+70727172032"}
0005434906596	F134AC	5039 158448	MARINA SOROKINA	{"phone": "+70129946082"}
0005434906597	42B948	3870 388287	IRINA NOVIKOVA	{"email": "i.novikova091965@postgrespro.ru", "phone": "+70864508408"}
0005434906598	42B948	0901 632478	VLADIMIR IVANOV	{"email": "ivanovvladimir12081975@postgrespro.ru", "phone": "+70595928715"}
0005434906599	E1ED0C	8129 207644	OKSANA KOROLEVA	{"email": "oksana_koroleva_101971@postgrespro.ru", "phone": "+70821038026"}
0005434906600	458C67	7074 218860	NINA POTAPOVA	{"email": "n.potapova-091981@postgrespro.ru", "phone": "+70120575493"}
0005434906601	2357A8	7621 967231	ANDREY BORISOV	{"email": "a-borisov.081975@postgrespro.ru", "phone": "+70153872926"}
0005434906602	B76B74	8774 533925	VYACHESLAV PAVLOV	{"phone": "+70824223077"}
0005434906603	3F50DE	1122 410509	FARIT KUZMIN	{"email": "fkuzmin-031977@postgrespro.ru", "phone": "+70613921455"}
0005434906604	691FDE	8808 698701	SERGEY MIKHAYLOV	{"email": "s.mikhaylov.30011967@postgrespro.ru", "phone": "+70875922333"}
0005434906605	6276C2	5116 514161	NATALYA ANISIMOVA	{"email": "nanisimova.1973@postgrespro.ru", "phone": "+70559171724"}
0005434906606	F5586F	5686 704596	ANNA IVANOVA	{"email": "aivanova.081971@postgrespro.ru", "phone": "+70824108082"}
0005434906607	F650B4	7235 688250	LILIYA POPOVA	{"email": "liliya-popova_111967@postgrespro.ru", "phone": "+70687328051"}
0005434906608	43B6CB	3519 883273	NADEZHDA GERASIMOVA	{"phone": "+70442555304"}
0005434906609	43B6CB	5915 780079	ALEKSANDR MELNIKOV	{"phone": "+70854412982"}
0005434906610	43B6CB	2474 661876	PETR BELOV	{"phone": "+70039583969"}
0005434906611	46AFFC	0842 346717	VITALIY ZAKHAROV	{"email": "zakharov_vitaliy-23071976@postgrespro.ru", "phone": "+70996802588"}
0005434906612	B1C652	2696 909260	ARSENIY SEMENOV	{"email": "semenov_a091972@postgrespro.ru", "phone": "+70093660483"}
0005434906613	F42EF7	6289 917314	EKATERINA KUZNECOVA	{"phone": "+70834982236"}
0005434906614	4EAB59	3635 910902	ELIZAVETA KONOVALOVA	{"phone": "+70936256004"}
0005434906615	CC3636	8589 030152	ANASTASIYA POPOVA	{"email": "anastasiya-popova16021965@postgrespro.ru", "phone": "+70551324864"}
0005434906616	77C6CC	4652 086089	ANATOLIY KISELEV	{"phone": "+70686000453"}
0005434906617	77C6CC	9410 101738	VIKTORIYA POPOVA	{"email": "v_popova12081974@postgrespro.ru", "phone": "+70063358633"}
0005434906618	77C6CC	9434 709811	SERGEY STEPANOV	{"email": "stepanov-sergey_111960@postgrespro.ru", "phone": "+70865894887"}
0005434906619	120303	9437 744536	MIKHAIL VASILEV	{"email": "vasilev_mikhail.29041962@postgrespro.ru", "phone": "+70003757762"}
0005434906620	682514	3848 990198	NATALYA NIKITINA	{"email": "nikitinanatalya031974@postgrespro.ru", "phone": "+70997230403"}
0005434906621	A25B91	5776 519292	NIKOLAY GERASIMOV	{"phone": "+70576571906"}
0005434906622	70884B	2068 010178	NATALYA KULIKOVA	{"phone": "+70609025010"}
0005434906623	F3D812	5808 793972	ALEKSANDRA IVANOVA	{"email": "ivanova-aleksandra-1959@postgrespro.ru", "phone": "+70280481616"}
0005434906624	2ED95B	4864 488221	OLGA KISELEVA	{"phone": "+70476721827"}
0005434906625	06D7CA	1082 429882	ALLA ZOTOVA	{"email": "zotova-a_1970@postgrespro.ru", "phone": "+70029750307"}
0005434906626	06D7CA	4936 202924	NATALYA NIKOLAEVA	{"phone": "+70712419108"}
0005434906627	AC58A5	1573 038099	PAVEL FOMIN	{"phone": "+70923013316"}
0005434906628	0CEEE9	0456 238699	SVETLANA EGOROVA	{"email": "egorova_s22101974@postgrespro.ru", "phone": "+70952912562"}
0005434906629	B217B2	8992 497741	DENIS PAVLOV	{"phone": "+70671841883"}
0005434906630	B217B2	6055 941703	ARTEM MELNIKOV	{"email": "artem.melnikov_081959@postgrespro.ru", "phone": "+70496380855"}
0005434906631	F4B493	5145 716867	ANNA PETROVA	{"phone": "+70772832481"}
0005434906632	669832	3150 940603	VITALIY PETROV	{"phone": "+70173053945"}
0005434906633	669832	2768 128100	YULIYA KONOVALOVA	{"email": "yuliya.konovalova.1960@postgrespro.ru", "phone": "+70508142072"}
0005434906634	09E67F	3709 780429	ALEKSEY IVANOV	{"email": "ivanov_aleksey_121965@postgrespro.ru", "phone": "+70060513965"}
0005434906635	BA9E24	6643 147239	ALEKSANDR KUZNECOV	{"phone": "+70844028312"}
0005434906636	BA9E24	2822 412852	KRISTINA ANTONOVA	{"email": "kristina.antonova_121976@postgrespro.ru", "phone": "+70135097949"}
0005434906637	CA97D7	1691 187777	NADEZHDA NESTEROVA	{"email": "nesterovanadezhda-30101979@postgrespro.ru", "phone": "+70249911398"}
0005434906638	0DC3B3	2712 985363	NADEZHDA ANDREEVA	{"phone": "+70705641892"}
0005434906639	0DC3B3	7574 504691	OLGA YAKOVLEVA	{"email": "yakovleva_olga_1967@postgrespro.ru", "phone": "+70510247051"}
0005434906640	8E7870	8862 449446	DANILA FEDOROV	{"email": "danila.fedorov_021973@postgrespro.ru", "phone": "+70466503889"}
0005434906641	246F4E	4022 103308	NIKITA POPOV	{"email": "popov.nikita-11081974@postgrespro.ru", "phone": "+70909590292"}
0005434906642	4F1A84	4560 455071	SVYATOSLAV PAVLOV	{"email": "pavlov-s.27061961@postgrespro.ru", "phone": "+70564861104"}
0005434906643	0CCAAB	5522 433210	ALEKSANDR NAZAROV	{"phone": "+70523712594"}
0005434906644	0CCAAB	4178 696814	ANNA GUSEVA	{"email": "guseva-a1963@postgrespro.ru", "phone": "+70894754672"}
0005434906645	76E690	6083 094325	TAMARA MIKHAYLOVA	{"email": "tamara.mikhaylova02061971@postgrespro.ru", "phone": "+70648561084"}
0005434906647	76E690	4442 695938	TATYANA GRISHINA	{"phone": "+70050673268"}
0005434906648	97F7C9	3752 521623	ALEKSEY GORBUNOV	{"phone": "+70455037523"}
0005434906649	2CC5EA	2858 243322	VLADIMIR MATVEEV	{"email": "vladimir_matveev.17091973@postgrespro.ru", "phone": "+70576436276"}
0005434906650	2CC5EA	4404 302208	YURIY VLASOV	{"email": "vlasov-yuriy-09071970@postgrespro.ru", "phone": "+70497905602"}
0005434906651	DCD440	1742 851003	OKSANA BELOVA	{"email": "obelova_1975@postgrespro.ru", "phone": "+70568148254"}
0005434906652	DCD440	1067 512280	SVETLANA SEMENOVA	{"phone": "+70031463055"}
0005434906653	284C68	0938 985750	ALEKSEY ZAYCEV	{"phone": "+70172388528"}
0005434906654	284C68	3826 699895	SVETLANA PAVLOVA	{"email": "svetlana-pavlova101965@postgrespro.ru", "phone": "+70948198734"}
0005434906655	9662D1	0296 228574	ALEKSANDR EGOROV	{"phone": "+70130857435"}
0005434906656	6F1258	6839 353771	IRINA VASILEVA	{"phone": "+70976218967"}
0005434906657	22879C	1457 743404	ELIZAVETA DENISOVA	{"email": "elizaveta_denisova-121974@postgrespro.ru", "phone": "+70244102222"}
0005434906658	22879C	7543 917047	IVAN ROMANOV	{"email": "ivan.romanov-1977@postgrespro.ru", "phone": "+70808681490"}
0005434906659	EBB4EE	9545 975894	VALENTINA DENISOVA	{"email": "valentinadenisova.101982@postgrespro.ru", "phone": "+70830060038"}
0005434906660	EBB4EE	7713 492615	OLGA PETROVA	{"phone": "+70736552428"}
0005434906661	7AD344	7889 990127	EKATERINA KAZAKOVA	{"email": "kazakovaekaterina-21111979@postgrespro.ru", "phone": "+70709739239"}
0005434906662	7AD344	3245 346322	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana_081966@postgrespro.ru", "phone": "+70180885154"}
0005434906663	F8D0AF	3225 505279	BORIS FILIPPOV	{"phone": "+70778904445"}
0005434906664	CCE326	6931 123120	ALEKSANDR ANDREEV	{"phone": "+70273227727"}
0005434906665	67B8F4	6745 519821	ALEKSEY SMIRNOV	{"phone": "+70943210874"}
0005434906666	A33852	1999 775877	NATALYA MATVEEVA	{"email": "nmatveeva.1966@postgrespro.ru", "phone": "+70455659366"}
0005434906667	72C9B3	7823 550207	VALENTINA ABRAMOVA	{"phone": "+70695159649"}
0005434906668	AD6344	2206 172328	KIRILL NAUMOV	{"email": "k-naumov_071977@postgrespro.ru", "phone": "+70051229212"}
0005434906669	AD6344	3006 358596	OLGA BELYAEVA	{"phone": "+70179057716"}
0005434906670	14B499	0938 956563	ANASTASIYA SOKOLOVA	{"phone": "+70398753745"}
0005434906671	5232EC	0764 741324	SERGEY ZAYCEV	{"email": "s.zaycev.29011972@postgrespro.ru", "phone": "+70582075029"}
0005434906672	F37E38	0386 059276	RUSLAN STEPANOV	{"phone": "+70187162183"}
0005434906673	791DCC	8437 429715	TATYANA ANDREEVA	{"phone": "+70681972540"}
0005434906674	791DCC	1574 610315	GALINA GUSEVA	{"phone": "+70491183307"}
0005434906675	791DCC	0530 798487	ANATOLIY VLASOV	{"email": "anatoliyvlasov_15071978@postgrespro.ru", "phone": "+70794675130"}
0005434906676	64C86F	7758 324979	ANNA YAKOVLEVA	{"email": "yakovleva_a.071959@postgrespro.ru", "phone": "+70893031977"}
0005434906677	64C86F	2433 190043	ANNA KUZNECOVA	{"phone": "+70201987737"}
0005434906678	F064D7	2254 602506	ALEKSEY FILIPPOV	{"email": "filippov_aleksey_1969@postgrespro.ru", "phone": "+70292427058"}
0005434906679	F064D7	4514 427961	ELIZAVETA SIDOROVA	{"email": "esidorova.23111980@postgrespro.ru", "phone": "+70012417447"}
0005434906680	F064D7	2520 544545	SERGEY NAUMOV	{"phone": "+70311605569"}
0005434906681	74D0EE	2665 294903	NINA DMITRIEVA	{"phone": "+70899659611"}
0005434906682	74D0EE	3772 132975	TAMARA MOROZOVA	{"phone": "+70156739887"}
0005434906683	178C94	2351 859221	ILYA KARPOV	{"email": "karpovi-1960@postgrespro.ru", "phone": "+70605100364"}
0005434906684	178C94	2352 655911	VLADIMIR ALEKSANDROV	{"email": "aleksandrov_v-1976@postgrespro.ru", "phone": "+70985388738"}
0005434906685	178C94	8897 165334	OLGA MAKAROVA	{"email": "omakarova1980@postgrespro.ru", "phone": "+70038748250"}
0005434906686	EA600B	8649 113414	EDUARD KISELEV	{"phone": "+70193084232"}
0005434906687	C80490	3631 806075	ANASTASIYA DENISOVA	{"email": "denisovaanastasiya_01111975@postgrespro.ru", "phone": "+70915816889"}
0005434906688	C80490	6500 780538	OLGA GORBUNOVA	{"email": "gorbunova.olga061973@postgrespro.ru", "phone": "+70128335178"}
0005434906689	5E7570	4678 566576	LYUDMILA KARPOVA	{"phone": "+70871646062"}
0005434906690	F65C68	7049 614389	IGOR SCHERBAKOV	{"email": "scherbakov_igor.1967@postgrespro.ru", "phone": "+70831514262"}
0005434906691	6643A1	3615 103949	LIDIYA NIKOLAEVA	{"email": "nikolaeva-lidiya-10101960@postgrespro.ru", "phone": "+70873797323"}
0005434906692	6ABEEE	4235 693818	ALEKSANDR ABRAMOV	{"phone": "+70988132219"}
0005434906693	617EBF	3943 710514	VALENTINA DENISOVA	{"email": "v_denisova051967@postgrespro.ru", "phone": "+70709196683"}
0005434906694	88416D	5236 496198	IRINA CHERNOVA	{"phone": "+70569497137"}
0005434906695	88416D	4556 982675	ELIZAVETA BORISOVA	{"phone": "+70431897232"}
0005434906696	B6207E	1554 876560	DMITRIY MIKHAYLOV	{"phone": "+70182244228"}
0005434906697	4659F8	1953 650207	SERGEY MOROZOV	{"phone": "+70723446355"}
0005434906698	F16676	7521 516221	OLGA MELNIKOVA	{"email": "olga_melnikova.111962@postgrespro.ru", "phone": "+70062959943"}
0005434906699	388417	4500 586758	ANATOLIY KULIKOV	{"phone": "+70816482225"}
0005434906700	388417	3506 313905	OLEG KUZNECOV	{"email": "oleg-kuznecov20101968@postgrespro.ru", "phone": "+70950248381"}
0005434906701	388417	7522 308556	PAVEL KAZAKOV	{"email": "kazakovp_091979@postgrespro.ru", "phone": "+70990097859"}
0005434906702	ECA3E9	9517 161091	IRINA FEDOROVA	{"phone": "+70270284665"}
0005434906703	ECA3E9	9143 475818	GENNADIY EGOROV	{"phone": "+70919990899"}
0005434906704	ECA3E9	5383 529704	ZLATA VOLKOVA	{"phone": "+70114226383"}
0005434906705	DBFB89	9558 565359	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov.1978@postgrespro.ru", "phone": "+70619752117"}
0005434906706	DBFB89	4839 147832	ANATOLIY BELOV	{"phone": "+70366830345"}
0005434906707	DBFB89	7884 805675	MARIYA NESTEROVA	{"email": "mariya-nesterova031968@postgrespro.ru", "phone": "+70835073705"}
0005434906708	C08CDC	8515 350506	PAVEL BELOV	{"email": "belov_pavel-15091987@postgrespro.ru", "phone": "+70881822925"}
0005434906709	C08CDC	7533 903369	VIKTOR GAVRILOV	{"phone": "+70113470671"}
0005434906710	9467FA	8562 211082	MARIYA ANTONOVA	{"phone": "+70514415536"}
0005434906711	A255B0	2848 157831	VLADISLAV NAZAROV	{"email": "nazarovv.15041974@postgrespro.ru", "phone": "+70457036413"}
0005434906712	A255B0	3785 666695	VALENTINA KOLESNIKOVA	{"email": "v.kolesnikova1977@postgrespro.ru", "phone": "+70936003416"}
0005434906713	C1DBB3	2054 794499	OLGA SOLOVEVA	{"phone": "+70735346715"}
0005434906714	ABFC35	4122 609385	ALEKSANDRA ANDREEVA	{"phone": "+70115121694"}
0005434906715	7028AD	7917 861274	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr101968@postgrespro.ru", "phone": "+70774367615"}
0005434906716	6D57E2	7515 692065	ALEFTINA SIDOROVA	{"email": "sidorova-a-1989@postgrespro.ru", "phone": "+70503101758"}
0005434906717	6D57E2	8977 969275	NIKITA BELOV	{"email": "belovn061976@postgrespro.ru", "phone": "+70179801985"}
0005434906718	6D57E2	9943 877126	ALEKSANDR KUZMIN	{"phone": "+70124925618"}
0005434906719	7F2FBF	8129 362485	NIKOLAY KRASNOV	{"email": "nikolay_krasnov.1965@postgrespro.ru", "phone": "+70400175068"}
0005434906720	7F2FBF	9372 698105	ANNA ISAEVA	{"email": "a_isaeva.04041972@postgrespro.ru", "phone": "+70125129154"}
0005434906721	303C49	8769 211819	ELIZAVETA PAVLOVA	{"phone": "+70395695252"}
0005434906722	072647	8869 368985	ALEKSANDR TIKHONOV	{"phone": "+70092872834"}
0005434906723	631DD1	5436 633601	ELENA POPOVA	{"email": "popova.elena.22061969@postgrespro.ru", "phone": "+70938997474"}
0005434906724	631DD1	2431 011602	OLESYA KUZNECOVA	{"email": "o_kuznecova-1969@postgrespro.ru", "phone": "+70905106865"}
0005434906725	501ECD	5147 753630	GALINA LOGINOVA	{"email": "g.loginova_1984@postgrespro.ru", "phone": "+70424628839"}
0005434906726	A677CD	0466 220756	LYUDMILA NIKIFOROVA	{"email": "lyudmilanikiforova_13041974@postgrespro.ru", "phone": "+70807959411"}
0005434906727	A677CD	7753 615650	PRASKOVYA ROMANOVA	{"email": "p-romanova-1977@postgrespro.ru", "phone": "+70042499460"}
0005434906728	167881	2447 594941	VIKTOR FEDOTOV	{"phone": "+70625418222"}
0005434906729	167881	5818 260775	SVETLANA TIKHONOVA	{"phone": "+70972820259"}
0005434906730	D645AD	5835 582514	TIMOFEY POPOV	{"phone": "+70257830390"}
0005434906731	FA6986	0797 190958	ALEKSEY ALEKSEEV	{"email": "alekseyalekseev-31081976@postgrespro.ru", "phone": "+70943230648"}
0005434906732	4E581E	2841 753880	OLGA ANTONOVA	{"email": "olgaantonova_1976@postgrespro.ru", "phone": "+70171023280"}
0005434906733	E0E4BB	6722 697818	LYUDMILA KUZNECOVA	{"email": "kuznecovalyudmila091962@postgrespro.ru", "phone": "+70017472896"}
0005434906734	E0E4BB	4780 573199	YURIY VOLKOV	{"phone": "+70887724722"}
0005434906735	39F999	9115 577525	ANATOLIY SERGEEV	{"email": "sergeev-a_071973@postgrespro.ru", "phone": "+70520414212"}
0005434906736	E15054	7562 677546	GENNADIY GERASIMOV	{"email": "g.gerasimov.061984@postgrespro.ru", "phone": "+70892104646"}
0005434906737	25A23D	5011 917661	ELENA FILIPPOVA	{"email": "filippova.e.1980@postgrespro.ru", "phone": "+70004342251"}
0005434906738	DD34E4	4238 260121	NADEZHDA SMIRNOVA	{"phone": "+70561864032"}
0005434906739	A71B3F	5748 303000	NIKOLAY SERGEEV	{"email": "sergeevnikolay.24101986@postgrespro.ru", "phone": "+70861381685"}
0005434906740	A71B3F	2659 425442	VYACHESLAV ZAKHAROV	{"email": "zakharovvyacheslav.021962@postgrespro.ru", "phone": "+70676503387"}
0005434906741	A71B3F	5609 111440	ANTON YAKOVLEV	{"email": "ayakovlev_111967@postgrespro.ru", "phone": "+70530359132"}
0005434906742	D1BE0F	0567 593414	ANASTASIYA TIKHONOVA	{"phone": "+70320797874"}
0005434906743	6C373E	9092 161414	VALENTINA KOLESNIKOVA	{"email": "vkolesnikova-1966@postgrespro.ru", "phone": "+70199433955"}
0005434906744	6C373E	1353 788537	KRISTINA ERMAKOVA	{"phone": "+70297152942"}
0005434906745	BAAA8B	7551 055463	MARIYA KUZMINA	{"phone": "+70708670403"}
0005434906746	BAAA8B	1084 807634	SERGEY OSIPOV	{"phone": "+70661614570"}
0005434906747	BAAA8B	4166 263249	KSENIYA FEDOROVA	{"email": "fedorova.kseniya-071979@postgrespro.ru", "phone": "+70143114760"}
0005434906748	8F7B50	7468 874807	ELENA POPOVA	{"phone": "+70464768339"}
0005434906749	8F7B50	2772 081240	PAVEL MAKAROV	{"email": "pavel_makarov.16051970@postgrespro.ru", "phone": "+70815980395"}
0005434906750	23B502	7135 254715	PETR IVANOV	{"phone": "+70376251332"}
0005434906751	23B502	3714 618140	ANDREY SHEVCHENKO	{"phone": "+70946949606"}
0005434906752	7C85DA	3711 757715	RAFAEL KULIKOV	{"email": "rafael.kulikov1964@postgrespro.ru", "phone": "+70059340867"}
0005434906753	336839	3070 684850	SVETLANA FROLOVA	{"email": "frolova.s09041958@postgrespro.ru", "phone": "+70544016080"}
0005434906754	8BB674	9887 295138	VALENTINA NIKITINA	{"phone": "+70904092461"}
0005434906755	7951C5	4253 000896	DMITRIY BONDARENKO	{"phone": "+70310127961"}
0005434906756	E81EBC	1427 653142	ANASTASIYA SAVELEVA	{"email": "savelevaa.16101974@postgrespro.ru", "phone": "+70739739017"}
0005434906757	458FD7	3112 889388	NELYA ORLOVA	{"phone": "+70463253758"}
0005434906758	FDCDB0	7014 871549	DANA FROLOVA	{"phone": "+70727346506"}
0005434906759	FDCDB0	5322 163383	LYUBOV VASILEVA	{"email": "l-vasileva071977@postgrespro.ru", "phone": "+70381453460"}
0005434906760	AC5BA8	4979 446883	NIKITA MATVEEV	{"phone": "+70068844123"}
0005434906761	FB4914	1779 028312	ALEKSANDR MOISEEV	{"phone": "+70001962582"}
0005434906762	375267	9808 222576	ANDREY ROMANOV	{"phone": "+70620697763"}
0005434906763	B2D41F	2182 868537	KLAVDIYA ABRAMOVA	{"phone": "+70371932731"}
0005434906764	917A11	2172 041068	ALEKSEY MARTYNOV	{"phone": "+70867352634"}
0005434906765	DCB332	7540 737807	EKATERINA NIKITINA	{"phone": "+70751065551"}
0005434906766	90B2F3	4535 003818	OLGA ALEKSANDROVA	{"email": "aleksandrova-o.051967@postgrespro.ru", "phone": "+70782115640"}
0005434906767	90B2F3	3484 007076	NIKOLAY MIKHAYLOV	{"email": "mikhaylov-n-1964@postgrespro.ru", "phone": "+70267830915"}
0005434906768	E86797	4410 200826	EKATERINA NOVIKOVA	{"email": "enovikova_22081966@postgrespro.ru", "phone": "+70869142554"}
0005434906769	158BA2	1353 524836	NIKOLAY MAKSIMOV	{"phone": "+70122410679"}
0005434906770	158BA2	1759 702811	IGOR ILIN	{"email": "ilinigor.1969@postgrespro.ru", "phone": "+70406274179"}
0005434906771	BC928E	8354 455759	ELENA DENISOVA	{"email": "elena.denisova.101970@postgrespro.ru", "phone": "+70464956167"}
0005434906772	37F669	4010 981068	TATYANA VOLKOVA	{"email": "volkova.t-031967@postgrespro.ru", "phone": "+70803541297"}
0005434906773	C9DD47	1491 000800	SERGEY STEPANOV	{"phone": "+70163477043"}
0005434906774	45EE92	8487 977683	VALENTINA GUSEVA	{"email": "gusevavalentina.1981@postgrespro.ru", "phone": "+70497401305"}
0005434906775	CFC2D8	8506 200789	ALEKSEY ZHURAVLEV	{"phone": "+70571238484"}
0005434906776	47E6AB	4974 542688	IRINA KISELEVA	{"phone": "+70159752974"}
0005434906777	47E6AB	7970 182055	VALENTINA KOMAROVA	{"phone": "+70133643004"}
0005434906778	A0936E	1316 919900	VALENTIN NAUMOV	{"email": "valentin-naumov.10081968@postgrespro.ru", "phone": "+70066858293"}
0005434906779	97B6A6	7068 825873	VIKTOR MIKHAYLOV	{"email": "mikhaylov.viktor011974@postgrespro.ru", "phone": "+70814457616"}
0005434906780	97B6A6	2687 419673	ALEKSANDR MEDVEDEV	{"email": "aleksandrmedvedev-10021978@postgrespro.ru", "phone": "+70239892329"}
0005434906781	ED753E	0978 226495	SERGEY STEPANOV	{"email": "stepanovsergey_031972@postgrespro.ru", "phone": "+70516772400"}
0005434906782	F58301	8325 850874	KRISTINA ZAKHAROVA	{"phone": "+70583699819"}
0005434906783	79B3EB	3091 241844	LYUDMILA GRISHINA	{"phone": "+70318762014"}
0005434906784	79B3EB	7198 505631	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov-1975@postgrespro.ru", "phone": "+70603763210"}
0005434906785	0E66BD	4419 660304	LARISA MAKAROVA	{"email": "makarova_larisa_13091973@postgrespro.ru", "phone": "+70496652281"}
0005434906786	58DA51	7601 478557	SOFYA ROMANOVA	{"email": "sofya_romanova-23021973@postgrespro.ru", "phone": "+70000254114"}
0005434906787	58DA51	3086 483265	ARINA EFIMOVA	{"email": "efimova.arina16091963@postgrespro.ru", "phone": "+70420415585"}
0005434906788	718D4B	7398 273700	TATYANA BELOVA	{"email": "tatyana.belova31121969@postgrespro.ru", "phone": "+70495156431"}
0005434906789	56B4CF	9547 917245	TATYANA SERGEEVA	{"phone": "+70969261738"}
0005434906790	56B4CF	1166 531216	DANILA FILIPPOV	{"phone": "+70510322560"}
0005434906791	3EAB56	8340 295504	TATYANA MELNIKOVA	{"email": "melnikova_t_081975@postgrespro.ru", "phone": "+70247885750"}
0005434906792	F688F0	1095 251449	YURIY FEDOTOV	{"phone": "+70919811661"}
0005434906793	C7661D	4192 350728	POLINA KONDRATEVA	{"email": "pkondrateva.121971@postgrespro.ru", "phone": "+70056659387"}
0005434906794	7B9A17	6390 080159	VLADIMIR VASILEV	{"email": "vasilev.v-02111978@postgrespro.ru", "phone": "+70413398969"}
0005434906795	44B57A	7262 056302	IGOR SCHERBAKOV	{"phone": "+70633719262"}
0005434906796	E94B7E	8647 867893	VALENTINA PAVLOVA	{"phone": "+70208471570"}
0005434906797	78F148	3568 545318	MAKSIM MIRONOV	{"email": "mironov.maksim21091980@postgrespro.ru", "phone": "+70750102486"}
0005434906798	A1C92F	9508 561317	YURIY POPOV	{"email": "y_popov.081973@postgrespro.ru", "phone": "+70248241436"}
0005434906799	E35CFF	7434 632784	ALEKSANDR ANDREEV	{"phone": "+70277213780"}
0005434906800	717E78	3027 778187	ANTONINA ILINA	{"phone": "+70259805228"}
0005434906801	BBEB3E	3490 270424	ZINAIDA ZAYCEVA	{"email": "z_zayceva1975@postgrespro.ru", "phone": "+70859753001"}
0005434906802	A1015F	5998 245324	PRASKOVYA SAVELEVA	{"email": "savelevapraskovya.1980@postgrespro.ru", "phone": "+70264860295"}
0005434906803	A1015F	3184 414946	KIRILL FILIPPOV	{"email": "kirill_filippov.051975@postgrespro.ru", "phone": "+70127910881"}
0005434906804	9D76E4	7012 842745	ANTON KISELEV	{"phone": "+70244236447"}
0005434906805	98BA54	6146 229708	EKATERINA NOVIKOVA	{"phone": "+70376534605"}
0005434906806	BD3ABA	8617 092043	IVAN CHERNOV	{"email": "ivan-chernov-15091966@postgrespro.ru", "phone": "+70440143959"}
0005434906807	AC5630	5340 367405	ALEKSANDR POPOV	{"email": "a-popov-23101955@postgrespro.ru", "phone": "+70135918987"}
0005434906808	AC5630	1465 011265	ANATOLIY RODIONOV	{"phone": "+70025249772"}
0005434906809	712E79	6120 674144	MAKSIM KULIKOV	{"email": "kulikov.maksim_101982@postgrespro.ru", "phone": "+70918087597"}
0005434906810	712E79	5574 320595	ALEKSEY KULIKOV	{"phone": "+70380679965"}
0005434906811	29E727	5972 331323	SERGEY KAZAKOV	{"phone": "+70802123641"}
0005434906812	29E727	7299 468276	ANNA POPOVA	{"email": "popova.a13011965@postgrespro.ru", "phone": "+70120576574"}
0005434906813	5F14FC	0198 217843	IVAN KISELEV	{"email": "i_kiselev031967@postgrespro.ru", "phone": "+70863956719"}
0005434906814	CA7AEA	7848 436357	SVETLANA GAVRILOVA	{"email": "gavrilovasvetlana_18121967@postgrespro.ru", "phone": "+70314207595"}
0005434906815	5784B3	3350 919013	ALEKSANDR PAVLOV	{"phone": "+70117552802"}
0005434906816	5784B3	2078 489955	VLADIMIR YAKOVLEV	{"email": "yakovlev_vladimir.25021973@postgrespro.ru", "phone": "+70052193397"}
0005434906817	5784B3	6653 099815	ELENA MASLOVA	{"phone": "+70216089670"}
0005434906818	DCF9AF	2388 529359	NATALYA KOVALEVA	{"email": "n.kovaleva-04031980@postgrespro.ru", "phone": "+70789144116"}
0005434906819	2292A9	9363 738555	VLADISLAV ORLOV	{"email": "orlov.vladislav-1972@postgrespro.ru", "phone": "+70381979928"}
0005434906820	50AC80	8655 563907	ANATOLIY FILIPPOV	{"phone": "+70856414587"}
0005434906821	50AC80	1481 319574	ANNA IVANOVA	{"phone": "+70221971330"}
0005434906822	7BB6F9	9070 331140	NADEZHDA RODIONOVA	{"email": "rodionova.n-27011971@postgrespro.ru", "phone": "+70271244350"}
0005434906823	584766	8845 121825	RUSLAN TARASOV	{"phone": "+70945646460"}
0005434906824	584766	7875 172760	SERGEY KAZAKOV	{"phone": "+70921793142"}
0005434906825	85E592	0902 390106	PAVEL BONDARENKO	{"phone": "+70381935206"}
0005434906826	5C2573	1061 210911	VYACHESLAV IVANOV	{"phone": "+70121873867"}
0005434906827	577102	5354 204664	LILIYA KOROLEVA	{"email": "koroleva.liliya_041967@postgrespro.ru", "phone": "+70410463532"}
0005434906828	577102	7234 569929	VENIAMIN ANTONOV	{"email": "v.antonov-17061973@postgrespro.ru", "phone": "+70585936393"}
0005434906829	2B3115	6426 518454	NATALYA MAKSIMOVA	{"email": "maksimova.natalya.1966@postgrespro.ru", "phone": "+70293150752"}
0005434906830	5EF075	3717 883277	VLADIMIR KOZLOV	{"phone": "+70153737394"}
0005434906831	1E422A	2227 213737	VLADIMIR NAZAROV	{"email": "nazarov_v_16041959@postgrespro.ru", "phone": "+70770032467"}
0005434906832	BAE604	9460 293848	SERGEY KOROLEV	{"email": "korolevsergey-011979@postgrespro.ru", "phone": "+70516108251"}
0005434906833	B77C51	6367 441287	NIKITA FROLOV	{"email": "frolov-n-061975@postgrespro.ru", "phone": "+70219785377"}
0005434906834	588033	1649 910731	SERGEY VASILEV	{"email": "vasilev-sergey15011960@postgrespro.ru", "phone": "+70246518982"}
0005434906835	588033	5211 080959	ALEKSANDR ROMANOV	{"email": "romanov_a-18041966@postgrespro.ru", "phone": "+70101274696"}
0005434906836	588033	4839 552213	VITALIY ZAKHAROV	{"email": "zakharov-v-1968@postgrespro.ru", "phone": "+70384725908"}
0005434906837	F3EB85	5629 340531	ALENA KRASNOVA	{"email": "krasnova-a1966@postgrespro.ru", "phone": "+70812543498"}
0005434906838	3F7159	5560 569245	NADEZHDA FADEEVA	{"phone": "+70088097984"}
0005434906839	03FA0B	4028 872520	TATYANA PETROVA	{"email": "tatyana.petrova.18071974@postgrespro.ru", "phone": "+70634811751"}
0005434906840	B6BE9B	5760 210057	MIKHAIL VOLKOV	{"phone": "+70953410855"}
0005434906841	52D9D0	2235 278125	GENNADIY MAKAROV	{"email": "gennadiy-makarov-31081976@postgrespro.ru", "phone": "+70931548960"}
0005434906842	52D9D0	8309 629132	VIKTOR DAVYDOV	{"email": "v_davydov.03081964@postgrespro.ru", "phone": "+70901644320"}
0005434906843	FACC6F	8410 635864	OKSANA KUZMINA	{"email": "kuzmina_oksana-11041968@postgrespro.ru", "phone": "+70723793007"}
0005434906844	FACC6F	7840 249582	LYUDMILA ALEKSEEVA	{"phone": "+70046947876"}
0005434906845	838C95	3961 809001	POLINA NIKITINA	{"email": "polina-nikitina031971@postgrespro.ru", "phone": "+70428589186"}
0005434906846	838C95	6648 023065	OLEG PETROV	{"phone": "+70770300297"}
0005434906847	C5CA58	7616 711992	DMITRIY FILIPPOV	{"email": "dmitriy-filippov.21101983@postgrespro.ru", "phone": "+70852869781"}
0005434906848	EB70DD	2181 332640	ANNA KUZNECOVA	{"phone": "+70602832713"}
0005434906849	6EF01C	2665 413710	VLADIMIR ZHURAVLEV	{"phone": "+70701484091"}
0005434906850	0D3167	3907 447282	LYUBOV IVANOVA	{"email": "ivanova.lyubov_30031969@postgrespro.ru", "phone": "+70739306840"}
0005434906851	ED05F3	2047 687957	TATYANA AKIMOVA	{"email": "takimova_24101978@postgrespro.ru", "phone": "+70030429380"}
0005434906852	559DEF	4897 442676	VALENTINA MELNIKOVA	{"phone": "+70054979998"}
0005434906853	F82A73	2507 342547	SVETLANA MATVEEVA	{"email": "svetlanamatveeva.07051966@postgrespro.ru", "phone": "+70241199229"}
0005434906854	B28029	5386 239737	ANZHELIKA VOLKOVA	{"email": "a_volkova.071981@postgrespro.ru", "phone": "+70681195198"}
0005434906855	39EB71	9939 521596	NADEZHDA SERGEEVA	{"phone": "+70366727181"}
0005434906856	6A837F	6552 895212	NADEZHDA ALEKSEEVA	{"email": "alekseeva-n_17091974@postgrespro.ru", "phone": "+70129042840"}
0005434906857	663249	8974 238066	TAISIYA MIRONOVA	{"email": "t.mironova-1986@postgrespro.ru", "phone": "+70992033961"}
0005434906858	663249	4109 754888	MARINA TARASOVA	{"email": "tarasova-marina.101972@postgrespro.ru", "phone": "+70094538991"}
0005434906859	A824D8	9396 291830	ANNA BORISOVA	{"email": "aborisova_111974@postgrespro.ru", "phone": "+70664235339"}
0005434906860	1F47F1	0072 988770	MARGARITA SCHERBAKOVA	{"email": "margarita.scherbakova_101978@postgrespro.ru", "phone": "+70635169042"}
0005434906861	6D3E9D	9985 372333	VLADISLAV ROMANOV	{"email": "romanov.v_111974@postgrespro.ru", "phone": "+70438378767"}
0005434906862	9EBCC0	3881 221191	TATYANA KULIKOVA	{"email": "kulikova-tatyana_051972@postgrespro.ru", "phone": "+70709866716"}
0005434906863	737916	7211 401931	NATALIYA SAVELEVA	{"phone": "+70271587079"}
0005434906864	39BA81	4552 892716	NIKITA KUZMIN	{"phone": "+70709346965"}
0005434906865	39BA81	5877 639897	IVAN OSIPOV	{"phone": "+70379606537"}
0005434906866	C64B20	7484 994387	SERGEY TIKHONOV	{"email": "s-tikhonov-101969@postgrespro.ru", "phone": "+70865739270"}
0005434906867	C64B20	1181 627486	ALEKSANDRA VASILEVA	{"phone": "+70801646490"}
0005434906868	7D0EFB	7185 801559	VALENTIN STEPANOV	{"email": "stepanov.valentin.051971@postgrespro.ru", "phone": "+70096125871"}
0005434906869	8772CE	5049 586403	MARIYA MAKAROVA	{"email": "mariya-makarova1971@postgrespro.ru", "phone": "+70866743268"}
0005434906870	24E442	9298 666526	ARINA POPOVA	{"email": "arina-popova16121969@postgrespro.ru", "phone": "+70396560636"}
0005434906871	02411C	5823 546025	DENIS KUZNECOV	{"phone": "+70402257786"}
0005434906872	4166C8	2590 521262	ANASTASIYA SOROKINA	{"email": "anastasiyasorokina1972@postgrespro.ru", "phone": "+70073397277"}
0005434906873	4166C8	0085 560558	VALERIYA SMIRNOVA	{"phone": "+70620469943"}
0005434906874	D4B8C7	3855 768522	YURIY FOMIN	{"email": "yuriy-fomin-10061971@postgrespro.ru", "phone": "+70349614760"}
0005434906875	CD00C6	4547 017537	MIKHAIL NAZAROV	{"email": "mikhail.nazarov081969@postgrespro.ru", "phone": "+70733123730"}
0005434906876	57CB6C	8819 926373	ELENA POPOVA	{"phone": "+70542718581"}
0005434906877	B6642B	3560 930136	IRINA PETROVA	{"phone": "+70919799442"}
0005434906878	B6642B	1357 745134	VLADIMIR KOZLOV	{"phone": "+70812311037"}
0005434906879	206FD9	9450 251289	MARIYA MASLOVA	{"email": "mariya.maslova1975@postgrespro.ru", "phone": "+70285073513"}
0005434906880	5E81C7	8016 420668	LYUBOV KARPOVA	{"phone": "+70539192645"}
0005434906881	5E81C7	0018 115816	ALEKSEY IVANOV	{"phone": "+70083989433"}
0005434906882	66A253	5872 265426	ANTON GERASIMOV	{"phone": "+70122561949"}
0005434906883	91C6AB	3364 229719	DANIIL POPOV	{"phone": "+70539074148"}
0005434906884	91C6AB	3585 617334	LYUDMILA SOLOVEVA	{"phone": "+70615628593"}
0005434906885	6B07B2	5408 419350	IVAN GORBUNOV	{"phone": "+70835410841"}
0005434906886	812D93	3139 443562	ANASTASIYA TIKHONOVA	{"phone": "+70109372482"}
0005434906887	812D93	1435 928740	NURIYA ZAYCEVA	{"email": "nuriya.zayceva_081966@postgrespro.ru", "phone": "+70576401983"}
0005434906888	01D423	9442 644151	NIKITA STEPANOV	{"email": "n.stepanov_111964@postgrespro.ru", "phone": "+70450058380"}
0005434906889	0EB536	1378 938838	OLGA ANTONOVA	{"email": "o.antonova.1960@postgrespro.ru", "phone": "+70794148001"}
0005434906890	410AEB	6634 908457	NATALYA SERGEEVA	{"phone": "+70962376509"}
0005434906891	97C1A0	7885 894772	SERGEY KUZNECOV	{"phone": "+70390425298"}
0005434906892	A91267	2074 577680	EVGENIY YAKOVLEV	{"email": "yakovlevevgeniy_051980@postgrespro.ru", "phone": "+70485803727"}
0005434906893	A91267	4796 954469	DMITRIY SCHERBAKOV	{"phone": "+70032564976"}
0005434906894	9A4974	2789 741434	VIKTORIYA RODIONOVA	{"email": "rodionova_viktoriya_10101961@postgrespro.ru", "phone": "+70964154058"}
0005434906895	018F6A	1306 912586	ANDREY SOROKIN	{"phone": "+70853321367"}
0005434906896	018F6A	0279 914873	NINA NIKOLAEVA	{"phone": "+70665985596"}
0005434906897	301A53	8152 327606	ANASTASIYA PETROVA	{"phone": "+70529482294"}
0005434906898	17836D	9195 613346	VASILIY MIKHAYLOV	{"phone": "+70481277670"}
0005434906899	99EC8F	7196 376097	ALBINA ISAEVA	{"phone": "+70186339332"}
0005434906900	99EC8F	2589 745509	NATALYA MEDVEDEVA	{"email": "natalyamedvedeva_1967@postgrespro.ru", "phone": "+70478199057"}
0005434906901	3D15EF	8980 871068	VIKTORIYA EGOROVA	{"email": "egorova_viktoriya-1985@postgrespro.ru", "phone": "+70594749477"}
0005434906902	3D15EF	5504 331934	ANATOLIY ANDREEV	{"phone": "+70078797349"}
0005434906903	CAE2C5	7841 758399	TAMARA KRASNOVA	{"phone": "+70418931787"}
0005434906904	CAE2C5	8149 266180	VIKTOR AFANASEV	{"email": "viktorafanasev.121979@postgrespro.ru", "phone": "+70230417488"}
0005434906905	670BDE	7990 982309	ALEKSEY VOLKOV	{"phone": "+70486879055"}
0005434906906	670BDE	1332 730125	TATYANA NOVIKOVA	{"email": "t.novikova_1975@postgrespro.ru", "phone": "+70505420092"}
0005434906907	670BDE	0468 515576	MARIYA GAVRILOVA	{"phone": "+70794548407"}
0005434906908	B564AA	5542 468260	ALEKSEY ALEKSEEV	{"email": "aleksey_alekseev1972@postgrespro.ru", "phone": "+70315726506"}
0005434906909	B564AA	3103 722017	ELENA BOGDANOVA	{"phone": "+70325144388"}
0005434906910	3A95E2	3423 425144	NIKOLAY FEDOTOV	{"email": "nikolay_fedotov.1979@postgrespro.ru", "phone": "+70504085917"}
0005434906911	3A95E2	0610 587628	SERGEY ISAEV	{"email": "s_isaev_1963@postgrespro.ru", "phone": "+70411367699"}
0005434906912	AEDC51	1811 723159	VALENTINA SMIRNOVA	{"phone": "+70600664262"}
0005434906913	2C2C7E	2009 111210	TALGAT KULIKOV	{"phone": "+70949351100"}
0005434906914	5AF2E8	4340 359821	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir-041979@postgrespro.ru", "phone": "+70839841227"}
0005434906915	616BC8	6753 939631	IVAN ALEKSEEV	{"phone": "+70308124269"}
0005434906916	4E7633	3274 918026	DANIIL ZAYCEV	{"phone": "+70170406273"}
0005434906917	A90053	4799 960084	TATYANA NIKIFOROVA	{"email": "nikiforova-tatyana.1976@postgrespro.ru", "phone": "+70793965734"}
0005434906918	A2FA3F	7802 029613	TATYANA NIKITINA	{"phone": "+70509744714"}
0005434906919	A2FA3F	6606 452802	SVETLANA STEPANOVA	{"email": "s.stepanova_05041972@postgrespro.ru", "phone": "+70419315300"}
0005434906920	F2D205	2382 319198	ALEKSEY KULIKOV	{"email": "kulikova27121972@postgrespro.ru", "phone": "+70007749872"}
0005434906921	BD34AB	1435 537225	ELENA LEBEDEVA	{"email": "e_lebedeva22081973@postgrespro.ru", "phone": "+70873482127"}
0005434906922	86EDEA	5496 288553	MIKHAIL KOZLOV	{"phone": "+70054602298"}
0005434906923	3EAC37	4138 659510	SHAMIL POPOV	{"email": "s.popov.02021979@postgrespro.ru", "phone": "+70458978842"}
0005434906924	764A89	3972 606794	ELENA KUZNECOVA	{"email": "ekuznecova-021968@postgrespro.ru", "phone": "+70059709672"}
0005434906925	9897F6	4245 843845	VLADIMIR PETROV	{"email": "vladimir_petrov.13031963@postgrespro.ru", "phone": "+70664005125"}
0005434907038	EB62D4	8636 747790	NIKOLAY MAKSIMOV	{"phone": "+70085323367"}
0005434906926	07AE2E	2442 356811	TAMARA ISAEVA	{"email": "t-isaeva17031976@postgrespro.ru", "phone": "+70953409440"}
0005434906927	BD9102	5025 853015	DMITRIY RODIONOV	{"phone": "+70422882795"}
0005434906928	BD9102	8691 517576	YURIY SIDOROV	{"email": "sidorovyuriy.1974@postgrespro.ru", "phone": "+70494820765"}
0005434906929	629211	1844 218332	ELENA PAVLOVA	{"email": "e-pavlova_041965@postgrespro.ru", "phone": "+70677011555"}
0005434906930	F4579F	4242 236322	ALEKSEY KUZNECOV	{"phone": "+70361971101"}
0005434906931	C4CE33	6560 393126	VERA ANDREEVA	{"phone": "+70023515274"}
0005434906932	95C9F3	7729 436416	ALEKSEY GORBUNOV	{"phone": "+70939014185"}
0005434906933	FB1EB0	8906 260698	KSENIYA SERGEEVA	{"email": "sergeeva-kseniya-1977@postgrespro.ru", "phone": "+70546009025"}
0005434906934	FB1EB0	9015 232662	ALEKSEY GERASIMOV	{"email": "gerasimova021970@postgrespro.ru", "phone": "+70946643130"}
0005434906935	3D95A0	6563 461469	LYUDMILA GUSEVA	{"email": "lguseva-16121973@postgrespro.ru", "phone": "+70674376740"}
0005434906936	BB5E68	6337 307094	DMITRIY OSIPOV	{"phone": "+70355383678"}
0005434906937	BB5E68	5111 044762	ANASTASIYA STEPANOVA	{"email": "stepanova_a_1978@postgrespro.ru", "phone": "+70973015094"}
0005434906938	FB5169	8048 118122	SVETLANA KOLESNIKOVA	{"email": "kolesnikova_s.1979@postgrespro.ru", "phone": "+70714056291"}
0005434906939	C88950	8695 113656	ALEKSANDR ZAKHAROV	{"phone": "+70264010611"}
0005434906940	A874BF	1284 801592	VLADIMIR DMITRIEV	{"phone": "+70544874742"}
0005434906941	5334F2	3886 436133	BORIS FROLOV	{"email": "frolov.b121972@postgrespro.ru", "phone": "+70364446300"}
0005434906942	5BCE96	1015 078894	ALEKSANDRA FOMINA	{"phone": "+70681341666"}
0005434906943	9BA1EC	6052 633969	NATALYA ANTONOVA	{"email": "antonova.natalya-021977@postgrespro.ru", "phone": "+70994000191"}
0005434906944	62BA75	4061 095541	GALINA GERASIMOVA	{"phone": "+70017765043"}
0005434906945	384D9D	4119 563138	VLADIMIR PAVLOV	{"email": "v_pavlov.1975@postgrespro.ru", "phone": "+70921869454"}
0005434906946	115664	2194 801061	NINA SCHERBAKOVA	{"email": "scherbakovan_1956@postgrespro.ru", "phone": "+70478324961"}
0005434906947	115664	8994 434739	GALINA KUZMINA	{"phone": "+70025659317"}
0005434906948	30F628	4986 921109	VASILIY MOISEEV	{"phone": "+70666914775"}
0005434906949	16B941	5950 693589	SERGEY BORISOV	{"email": "sergeyborisov061982@postgrespro.ru", "phone": "+70780573650"}
0005434906950	16B941	0030 883592	ALLA IVANOVA	{"email": "ivanovaa_091973@postgrespro.ru", "phone": "+70268087124"}
0005434906951	93FD9C	3649 503793	VASILIY SMIRNOV	{"email": "smirnovvasiliy121966@postgrespro.ru", "phone": "+70748711497"}
0005434906952	93FD9C	7218 845475	VLADIMIR VASILEV	{"email": "vasilev_v.061977@postgrespro.ru", "phone": "+70777479940"}
0005434906953	F90443	0540 517350	YURIY MEDVEDEV	{"email": "yuriy_medvedev1959@postgrespro.ru", "phone": "+70897424451"}
0005434906954	BEE909	0977 651610	LYUDMILA KOROLEVA	{"phone": "+70119073856"}
0005434906955	BEE909	6539 833984	DIANA NESTEROVA	{"email": "nesterovadiana-07101967@postgrespro.ru", "phone": "+70685815795"}
0005434906956	B392F4	3165 844839	PAVEL GRIGOREV	{"email": "p_grigorev_101978@postgrespro.ru", "phone": "+70340533655"}
0005434906957	46968A	8835 530679	ALEKSEY KRASNOV	{"email": "krasnov-aleksey1963@postgrespro.ru", "phone": "+70873713768"}
0005434906958	B34F9F	9543 692032	MARIYA PETROVA	{"email": "petrova.mariya-24021981@postgrespro.ru", "phone": "+70379420606"}
0005434906959	B34F9F	8103 540710	ELMIRA MAKSIMOVA	{"email": "elmira.maksimova_071971@postgrespro.ru", "phone": "+70659176062"}
0005434906960	46ECBE	5502 717910	VLADIMIR NIKITIN	{"phone": "+70761669766"}
0005434906961	46ECBE	1361 712354	DIANA VOROBEVA	{"phone": "+70354301381"}
0005434906962	46ECBE	8085 212212	YULIYA PETROVA	{"email": "petrova_y.111971@postgrespro.ru", "phone": "+70834010213"}
0005434906963	0286E0	6896 901205	NIKOLAY DMITRIEV	{"phone": "+70670181274"}
0005434906964	ABB41E	1721 250465	ALEKSANDR KOZLOV	{"phone": "+70343877876"}
0005434906965	ABB41E	0336 949517	INNA POTAPOVA	{"email": "potapova-inna-051978@postgrespro.ru", "phone": "+70296056708"}
0005434906966	0D0531	0929 576946	ANNA MAKAROVA	{"phone": "+70600616364"}
0005434906967	BB30A0	7082 341711	IRINA NOVIKOVA	{"phone": "+70221101642"}
0005434906968	BB30A0	2071 572287	ALISA BELYAEVA	{"email": "belyaevaalisa.021977@postgrespro.ru", "phone": "+70124674988"}
0005434906969	22C062	6806 543609	ILNUR NAUMOV	{"phone": "+70911880939"}
0005434906970	A85119	6161 223015	ILYA SERGEEV	{"phone": "+70135555917"}
0005434906971	2C8436	3368 699943	TATYANA MAKSIMOVA	{"email": "tatyanamaksimova-071975@postgrespro.ru", "phone": "+70174227720"}
0005434906972	2B56E8	9046 182986	ZINAIDA SERGEEVA	{"phone": "+70429583271"}
0005434906973	2B56E8	9679 647225	DANILA ALEKSEEV	{"email": "d_alekseev_031964@postgrespro.ru", "phone": "+70391702325"}
0005434906974	E0FCAB	3711 159301	TATYANA ALEKSANDROVA	{"email": "taleksandrova_021972@postgrespro.ru", "phone": "+70144664846"}
0005434906975	E0FCAB	6559 589424	NINA DAVYDOVA	{"phone": "+70628551128"}
0005434906976	295D4A	8194 168055	YULIYA SMIRNOVA	{"phone": "+70848923015"}
0005434906977	99EA73	4052 829524	TATYANA OSIPOVA	{"email": "osipova_tatyana_28091967@postgrespro.ru", "phone": "+70065647300"}
0005434906978	99EA73	1506 872220	ALINA ANDREEVA	{"email": "aandreeva071971@postgrespro.ru", "phone": "+70124559542"}
0005434906979	405870	7904 107729	DARYA KARPOVA	{"email": "karpova_darya_101973@postgrespro.ru", "phone": "+70703194370"}
0005434906980	E06BE8	0999 408838	BORIS SCHERBAKOV	{"phone": "+70713986523"}
0005434906981	E06BE8	2843 218181	ELENA MIRONOVA	{"phone": "+70112285627"}
0005434906982	F7F23C	4800 756949	ALEKSANDRA ABRAMOVA	{"email": "abramova-aleksandra021963@postgrespro.ru", "phone": "+70037782067"}
0005434906983	F7F23C	8264 317839	VLADIMIR NOVIKOV	{"phone": "+70904353495"}
0005434906984	F7F23C	7766 390175	DMITRIY STEPANOV	{"phone": "+70959934514"}
0005434906985	55BEF6	7852 980345	MARIYA NESTEROVA	{"email": "nesterova_m_18071970@postgrespro.ru", "phone": "+70469752863"}
0005434906986	B77D60	4882 036313	LYUBOV MASLOVA	{"email": "l-maslova_1969@postgrespro.ru", "phone": "+70466672975"}
0005434906987	9FA863	5843 772201	ANDREY NIKITIN	{"email": "a_nikitin.09121988@postgrespro.ru", "phone": "+70980279266"}
0005434906988	7274AA	0375 045172	NIKITA SEMENOV	{"phone": "+70131955288"}
0005434906989	19D59B	2588 135200	ALINA NIKITINA	{"phone": "+70361597897"}
0005434906990	2345C7	1713 374200	LARISA KUZMINA	{"email": "kuzminal1974@postgrespro.ru", "phone": "+70667129092"}
0005434906991	A2C5A5	9255 899389	SERGEY MAKAROV	{"phone": "+70524197141"}
0005434906992	A2C5A5	4093 954302	SERGEY DMITRIEV	{"email": "dmitrievsergey_1969@postgrespro.ru", "phone": "+70871207669"}
0005434906993	C439AC	4794 246097	NIKOLAY BORISOV	{"email": "borisov_nikolay-21041963@postgrespro.ru", "phone": "+70294693259"}
0005434906994	BBBBD9	8447 738090	RAFIS VOLKOV	{"email": "volkov.rafis-091974@postgrespro.ru", "phone": "+70328863885"}
0005434906995	AE46F9	9812 296140	TATYANA TARASOVA	{"email": "tatyanatarasova1974@postgrespro.ru", "phone": "+70812893263"}
0005434906996	69F8D3	2384 334863	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov_13061972@postgrespro.ru", "phone": "+70492335611"}
0005434906997	69F8D3	2736 811763	PETR IVANOV	{"phone": "+70271343248"}
0005434906998	E2BCA5	9949 186569	NATALYA BELYAEVA	{"phone": "+70835763377"}
0005434906999	75D8AB	0482 036553	ALEKSANDR SOLOVEV	{"phone": "+70047101020"}
0005434907000	297BE2	1116 078606	ROMAN MAKSIMOV	{"email": "roman-maksimov1967@postgrespro.ru", "phone": "+70634600940"}
0005434907298	62117D	6088 710074	SERGEY NOVIKOV	{"phone": "+70510917667"}
0005434907001	EB07A0	7422 518269	SERGEY ALEKSEEV	{"email": "s_alekseev.01051968@postgrespro.ru", "phone": "+70012237587"}
0005434907002	F63231	6858 033460	ALEKSEY AFANASEV	{"phone": "+70923572934"}
0005434907003	B8516E	8936 995362	OKSANA ZAYCEVA	{"phone": "+70409910098"}
0005434907004	B8516E	0894 052639	KSENIYA NAZAROVA	{"phone": "+70189597697"}
0005434907005	BBCADD	3425 740725	IGOR IVANOV	{"email": "i.ivanov.121966@postgrespro.ru", "phone": "+70052314488"}
0005434907006	FC2862	1934 872676	NINEL NESTEROVA	{"phone": "+70834360527"}
0005434907007	730792	3819 192818	SERGEY BONDARENKO	{"phone": "+70364983783"}
0005434907008	730792	7844 831024	SVETLANA IVANOVA	{"email": "ivanovas_111967@postgrespro.ru", "phone": "+70304881515"}
0005434907009	1111E9	6080 561842	OLGA DENISOVA	{"email": "olga.denisova_18041966@postgrespro.ru", "phone": "+70985576927"}
0005434907010	3CF1AC	6701 138915	SVETLANA NESTEROVA	{"email": "svetlana.nesterova1968@postgrespro.ru", "phone": "+70350185919"}
0005434907011	CDA88F	3411 575508	NADEZHDA NOVIKOVA	{"email": "n.novikova.081984@postgrespro.ru", "phone": "+70658054157"}
0005434907012	CDA88F	7115 507505	VERONIKA VOLKOVA	{"phone": "+70559292024"}
0005434907013	A3FE41	7734 630559	ALENA ANDREEVA	{"phone": "+70540335785"}
0005434907014	A3FE41	5499 295002	VALENTINA PAVLOVA	{"phone": "+70941788768"}
0005434907015	7D4415	3647 680554	GUZEL KRASNOVA	{"email": "krasnova.guzel22031980@postgrespro.ru", "phone": "+70965771977"}
0005434907016	69D8DD	0449 833411	MIKHAIL KULIKOV	{"phone": "+70977263732"}
0005434907017	69D8DD	0170 761158	IGOR IVANOV	{"phone": "+70325195039"}
0005434907018	45B67F	7311 906908	IRINA MOISEEVA	{"email": "irina-moiseeva-1967@postgrespro.ru", "phone": "+70960627894"}
0005434907019	4DE21A	6880 707253	EKATERINA GERASIMOVA	{"email": "ekaterina-gerasimova01071968@postgrespro.ru", "phone": "+70737123104"}
0005434907020	168D72	0786 244265	VADIM ISAEV	{"phone": "+70038584625"}
0005434907021	112151	3075 925735	VERA NIKOLAEVA	{"phone": "+70623649048"}
0005434907022	112151	6482 285180	OLGA SOKOLOVA	{"phone": "+70996366479"}
0005434907023	112151	5346 198104	GERMAN GORBUNOV	{"email": "gorbunov.g12101961@postgrespro.ru", "phone": "+70541093989"}
0005434907024	C4E9F7	4962 716590	EKATERINA SERGEEVA	{"phone": "+70108031760"}
0005434907025	A42910	2547 628079	SVETLANA KARPOVA	{"phone": "+70333733822"}
0005434907026	8A6CD7	8021 430569	NADEZHDA OVCHINNIKOVA	{"phone": "+70468148948"}
0005434907027	5211EA	6367 549746	ELENA EGOROVA	{"email": "egorova-e_17121982@postgrespro.ru", "phone": "+70050053334"}
0005434907028	05D278	1830 517589	VLADIMIR MIRONOV	{"phone": "+70712367935"}
0005434907029	05D278	2570 462857	KONSTANTIN GAVRILOV	{"phone": "+70821925067"}
0005434907030	9C566D	9419 741115	NATALYA KONOVALOVA	{"phone": "+70265426143"}
0005434907031	9C566D	6167 883151	ARTEM RODIONOV	{"phone": "+70214227978"}
0005434907032	BFA992	4609 060332	VIKTOR CHERNOV	{"email": "chernov_v.091985@postgrespro.ru", "phone": "+70162357455"}
0005434907033	F4FCD2	9565 955262	VIKTORIYA KUZMINA	{"email": "v-kuzmina-02081962@postgrespro.ru", "phone": "+70851832295"}
0005434907034	F4FCD2	5547 689951	ALEKSEY BARANOV	{"email": "baranova_21111966@postgrespro.ru", "phone": "+70232396106"}
0005434907035	74DB66	1419 758950	IRINA CHERNOVA	{"email": "chernovairina111976@postgrespro.ru", "phone": "+70470409827"}
0005434907036	74DB66	6613 440324	OLEG YAKOVLEV	{"email": "o-yakovlev20081967@postgrespro.ru", "phone": "+70885642125"}
0005434907037	EB62D4	2000 811678	ELENA GRISHINA	{"email": "grishinaelena1968@postgrespro.ru", "phone": "+70663935479"}
0005434907039	FB1B71	8180 001143	EVGENIYA PETROVA	{"phone": "+70842838177"}
0005434907040	B9ADCE	2792 158149	VASILIY DENISOV	{"phone": "+70192196794"}
0005434907041	193DAA	1301 501469	SVETLANA KRASNOVA	{"email": "krasnova.s-031978@postgrespro.ru", "phone": "+70432706000"}
0005434907042	727314	5806 230059	IRINA GAVRILOVA	{"email": "gavrilova-i-11011975@postgrespro.ru", "phone": "+70796431893"}
0005434907043	33242D	6445 454854	VLADIMIR DAVYDOV	{"email": "v-davydov-1977@postgrespro.ru", "phone": "+70322100979"}
0005434907044	BC609B	4779 816048	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir_1978@postgrespro.ru", "phone": "+70235643100"}
0005434907045	3AF691	7344 975124	DMITRIY ZAYCEV	{"phone": "+70339575721"}
0005434907046	3AF691	1269 467116	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila.1972@postgrespro.ru", "phone": "+70548956202"}
0005434907047	CC8BD5	8087 392649	MARINA RYABOVA	{"email": "ryabova_marina.011980@postgrespro.ru", "phone": "+70430648041"}
0005434907048	8197E6	9696 011807	DENIS KARPOV	{"email": "karpov-d-07091962@postgrespro.ru", "phone": "+70887976163"}
0005434907049	8E2475	2731 028494	GALINA MOISEEVA	{"phone": "+70210567284"}
0005434907050	7A5471	9428 804061	GALINA KRASNOVA	{"email": "krasnova_galina_23071977@postgrespro.ru", "phone": "+70876935877"}
0005434907051	7A5471	0785 571168	TAISIYA FILIPPOVA	{"email": "filippovat031971@postgrespro.ru", "phone": "+70362518914"}
0005434907052	9B5ED6	4322 077314	VERA FEDOROVA	{"email": "fedorova_vera-29061969@postgrespro.ru", "phone": "+70132337897"}
0005434907053	9B631D	1153 807276	OLEG ABRAMOV	{"phone": "+70304667412"}
0005434907054	807952	5834 444478	MIKHAIL SOROKIN	{"phone": "+70198691529"}
0005434907055	8A6EDB	2713 575489	VYACHESLAV MARTYNOV	{"email": "vyacheslavmartynov1981@postgrespro.ru", "phone": "+70878919741"}
0005434907056	8A6EDB	3666 769894	VIKTOR KUZNECOV	{"phone": "+70264708159"}
0005434907057	8DDBE5	9780 329406	LARISA SMIRNOVA	{"phone": "+70790383769"}
0005434907058	8DDBE5	9402 588920	ALEKSANDR MAKAROV	{"email": "a-makarov_01121969@postgrespro.ru", "phone": "+70620006787"}
0005434907059	1F981C	3885 857790	SERGEY MIKHAYLOV	{"phone": "+70816225817"}
0005434907060	041698	4096 735919	ALEKSANDR NAZAROV	{"email": "nazarov_aleksandr-02041960@postgrespro.ru", "phone": "+70867035462"}
0005434907061	041698	9187 679245	KONSTANTIN YAKOVLEV	{"email": "yakovlev-k1990@postgrespro.ru", "phone": "+70086606587"}
0005434907062	DC7238	2496 414099	MAKSIM ALEKSEEV	{"email": "alekseev.maksim-091975@postgrespro.ru", "phone": "+70002144685"}
0005434907063	339CB2	7069 031916	STANISLAV MOISEEV	{"email": "stanislav-moiseev_061975@postgrespro.ru", "phone": "+70111783288"}
0005434907064	339CB2	7031 872474	TAMARA MIRONOVA	{"email": "mironovatamara_071980@postgrespro.ru", "phone": "+70622782400"}
0005434907065	FE126B	9148 606277	PAVEL ANDREEV	{"email": "andreev.pavel-07011969@postgrespro.ru", "phone": "+70893901387"}
0005434907066	FE126B	3933 560562	EKATERINA POTAPOVA	{"email": "ekaterina.potapova.021962@postgrespro.ru", "phone": "+70851234540"}
0005434907067	300E74	7599 285408	ELENA TIMOFEEVA	{"phone": "+70867896779"}
0005434907068	A5DEB6	1805 647178	SERGEY SMIRNOV	{"phone": "+70532001424"}
0005434907069	0F4CC6	7285 326407	VYACHESLAV ZHURAVLEV	{"phone": "+70837486412"}
0005434907070	B5CAE8	5467 691327	LYUDMILA ALEKSANDROVA	{"phone": "+70123176622"}
0005434907071	460B2A	9672 601855	ALEKSANDR BORISOV	{"email": "aleksandr-borisov111976@postgrespro.ru", "phone": "+70560087565"}
0005434907072	3A17B7	1275 040850	DARYA CHERNOVA	{"email": "darya-chernova041983@postgrespro.ru", "phone": "+70775897801"}
0005434907073	9443E5	0758 503348	ALEKSEY KARPOV	{"email": "karpovaleksey.081976@postgrespro.ru", "phone": "+70532679349"}
0005434907074	A2082F	7874 649431	MIKHAIL SAVELEV	{"phone": "+70522153067"}
0005434907075	FD2219	5755 107092	ALEKSANDR BELOV	{"email": "a.belov_30081964@postgrespro.ru", "phone": "+70237091662"}
0005434907076	B56115	5306 655479	PETR ROMANOV	{"phone": "+70702057196"}
0005434907077	0D682A	9214 956835	VIKTOR ZAKHAROV	{"phone": "+70110220767"}
0005434907078	52F410	9412 747433	ALEKSANDR MAKSIMOV	{"phone": "+70065992150"}
0005434907079	51480F	6579 852994	TARAS NAZAROV	{"email": "taras.nazarov-051965@postgrespro.ru", "phone": "+70327084163"}
0005434907080	22B01E	4172 705810	VERA KARPOVA	{"email": "karpova_v_1977@postgrespro.ru", "phone": "+70056704365"}
0005434907081	849D7B	4578 928037	PAVEL NIKOLAEV	{"phone": "+70276054721"}
0005434907082	A5981B	6532 255622	LYUBOV VOROBEVA	{"phone": "+70137309468"}
0005434907083	A5981B	6686 305795	LIDIYA KOMAROVA	{"phone": "+70785439836"}
0005434907084	5D8AE0	3218 435008	ZINAIDA GUSEVA	{"phone": "+70976203363"}
0005434907085	587238	8669 556346	ALEKSANDR NIKITIN	{"phone": "+70535865695"}
0005434907086	325468	1089 443494	ILYA SERGEEV	{"email": "sergeev.i081967@postgrespro.ru", "phone": "+70779884770"}
0005434907087	CA4074	4542 886506	KIRILL IVANOV	{"phone": "+70086829936"}
0005434907088	48C685	2259 431775	ELENA IVANOVA	{"phone": "+70661129908"}
0005434907089	48C685	5067 013380	ELENA MIKHAYLOVA	{"email": "elenamikhaylova.1985@postgrespro.ru", "phone": "+70590967293"}
0005434907090	18FBAD	5556 460872	NIKOLAY VLASOV	{"phone": "+70257084981"}
0005434907091	D756D5	7682 367859	VLADIMIR SERGEEV	{"email": "vsergeev.121962@postgrespro.ru", "phone": "+70065513907"}
0005434907092	DEBC24	8627 402347	IVAN FEDOROV	{"email": "i.fedorov-1972@postgrespro.ru", "phone": "+70766105046"}
0005434907093	0973E2	7916 849115	SERGEY YAKOVLEV	{"email": "yakovlev_sergey.081970@postgrespro.ru", "phone": "+70395808753"}
0005434907094	2573CB	8498 356657	GALINA PAVLOVA	{"email": "galina_pavlova101978@postgrespro.ru", "phone": "+70698954728"}
0005434907095	2573CB	5809 121742	ARTEM ANDREEV	{"email": "artem_andreev-081967@postgrespro.ru", "phone": "+70120327848"}
0005434907096	0FC3E3	3994 014185	ALEKSANDRA LOGINOVA	{"email": "a-loginova-1972@postgrespro.ru", "phone": "+70151163873"}
0005434907097	79360F	3921 353581	ARTUR ABRAMOV	{"email": "aabramov1985@postgrespro.ru", "phone": "+70566518054"}
0005434907098	CD90A5	6549 714052	YANA BELOVA	{"email": "belova.yana.29021968@postgrespro.ru", "phone": "+70312549013"}
0005434907099	709E5B	2398 008225	LYUDMILA SOROKINA	{"phone": "+70611346219"}
0005434907100	7B99FF	5780 558221	TAISIYA GERASIMOVA	{"email": "tgerasimova.011976@postgrespro.ru", "phone": "+70289238762"}
0005434907101	726657	8939 227563	YULIYA AFANASEVA	{"email": "afanaseva-y071971@postgrespro.ru", "phone": "+70637216292"}
0005434907102	726657	7223 369923	YANA KOLESNIKOVA	{"email": "yana.kolesnikova_081980@postgrespro.ru", "phone": "+70346764841"}
0005434907103	F5BB29	4579 701482	GALINA MOROZOVA	{"email": "morozova.galina-01101971@postgrespro.ru", "phone": "+70802713765"}
0005434907104	DE3704	7088 010929	VALENTINA KALININA	{"phone": "+70280752942"}
0005434907105	DE3704	1485 767159	ALEVTINA KOZLOVA	{"email": "alevtina-kozlova041970@postgrespro.ru", "phone": "+70285762663"}
0005434907106	78C8C2	2141 377482	TATYANA MEDVEDEVA	{"email": "medvedeva-tatyana-26091972@postgrespro.ru", "phone": "+70252479853"}
0005434907107	78C8C2	6398 308651	EDUARD MAKAROV	{"email": "eduardmakarov_011970@postgrespro.ru", "phone": "+70102198378"}
0005434907108	7CF08E	1274 934532	SERGEY NIKOLAEV	{"email": "nikolaev-sergey_1967@postgrespro.ru", "phone": "+70950804696"}
0005434907109	0D2DFD	0448 581337	ALEKSANDRA EGOROVA	{"email": "a-egorova.091974@postgrespro.ru", "phone": "+70943645857"}
0005434907110	0D2DFD	1301 661029	ALEKSANDR MOISEEV	{"email": "amoiseev-17021980@postgrespro.ru", "phone": "+70538982641"}
0005434907111	E18DE4	1077 548554	VALERIY NIKOLAEV	{"email": "valeriy-nikolaev24111973@postgrespro.ru", "phone": "+70503093562"}
0005434907112	9138FC	3075 658481	VALENTINA TIKHONOVA	{"email": "valentina-tikhonova-10071965@postgrespro.ru", "phone": "+70522903960"}
0005434907113	9138FC	0621 825127	FEDOR SIDOROV	{"phone": "+70931851919"}
0005434907114	BE5392	0624 532115	IRINA BELOVA	{"phone": "+70240880192"}
0005434907115	BE5392	2206 751410	SERGEY PETROV	{"email": "s-petrov_011970@postgrespro.ru", "phone": "+70496916615"}
0005434907116	CD72A8	9064 625584	NATALIYA KONOVALOVA	{"phone": "+70232188858"}
0005434907117	CD72A8	4070 494011	PAVEL BORISOV	{"email": "pavelborisov-061976@postgrespro.ru", "phone": "+70465002022"}
0005434907118	CD72A8	0109 745843	OLGA VASILEVA	{"email": "vasileva_olga05011982@postgrespro.ru", "phone": "+70604701500"}
0005434907119	CD72A8	4615 825596	ANDREY IVANOV	{"email": "ivanovandrey01071972@postgrespro.ru", "phone": "+70410298470"}
0005434907120	418E27	4731 738534	OLGA ANTONOVA	{"email": "o.antonova.1971@postgrespro.ru", "phone": "+70892085340"}
0005434907121	C01D47	6908 760460	MARIYA EFIMOVA	{"email": "mariyaefimova.081966@postgrespro.ru", "phone": "+70637973702"}
0005434907122	46044A	1726 637014	YURIY IVANOV	{"email": "ivanov_y_011967@postgrespro.ru", "phone": "+70163691301"}
0005434907123	6602AA	4009 577843	SERGEY NIKITIN	{"email": "sergey-nikitin24041969@postgrespro.ru", "phone": "+70884717236"}
0005434907124	E53C5A	3332 578260	MARIYA KUZNECOVA	{"phone": "+70407452256"}
0005434907125	E53C5A	1047 448383	ARINA ZOTOVA	{"phone": "+70647894233"}
0005434907126	1E8DC4	8854 325480	MARGARITA PETROVA	{"phone": "+70329748522"}
0005434907127	1E8DC4	5668 038828	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy04091972@postgrespro.ru", "phone": "+70700334593"}
0005434907128	CA8089	4698 056996	ARINA KUDRYASHOVA	{"phone": "+70967822199"}
0005434907129	6DB3B9	9485 861349	VASILIY MOROZOV	{"email": "vasiliy_morozov_1970@postgrespro.ru", "phone": "+70114548420"}
0005434907130	2B1A8E	0153 979099	MARIYA ABRAMOVA	{"email": "mabramova-051974@postgrespro.ru", "phone": "+70635598576"}
0005434907131	91FC1B	7262 039098	ELIZAVETA ISAEVA	{"email": "isaeva.e-12011969@postgrespro.ru", "phone": "+70092936970"}
0005434907132	2A6D0F	8034 777332	ANASTASIYA RODIONOVA	{"email": "a_rodionova28091968@postgrespro.ru", "phone": "+70760508758"}
0005434907133	E62C8C	6281 547405	MAKSIM FILIPPOV	{"phone": "+70824447719"}
0005434907134	A762F5	9342 872340	EKATERINA MEDVEDEVA	{"email": "e-medvedeva-1968@postgrespro.ru", "phone": "+70438330220"}
0005434907135	D67B89	4322 435402	VERA ISAEVA	{"phone": "+70882715867"}
0005434907136	E9DB1E	1602 847656	YULIYA SEMENOVA	{"phone": "+70551781357"}
0005434907137	ABB696	7939 059887	VALERIY KOROLEV	{"phone": "+70765536834"}
0005434907138	6E0E89	9582 657279	EVGENIY KUZMIN	{"email": "ekuzmin1978@postgrespro.ru", "phone": "+70224301005"}
0005434907139	6E0E89	3440 196802	DANILA SCHERBAKOV	{"email": "scherbakov.danila121977@postgrespro.ru", "phone": "+70685278852"}
0005434907140	6E0E89	4777 051383	TATYANA YUDINA	{"email": "tatyana-yudina.1978@postgrespro.ru", "phone": "+70091708719"}
0005434907141	FCF4B5	0054 900156	ALEVTINA OSIPOVA	{"phone": "+70557485118"}
0005434907142	FCF4B5	3048 252502	ALEKSANDR KAZAKOV	{"email": "kazakov.aleksandr.081954@postgrespro.ru", "phone": "+70203306498"}
0005434907143	3DB1CE	6951 407717	ANATOLIY FROLOV	{"phone": "+70939000340"}
0005434907144	F93EE5	6889 461704	YULIYA AFANASEVA	{"email": "yafanaseva_09121984@postgrespro.ru", "phone": "+70762938056"}
0005434907145	5D5705	9589 315373	VALENTINA MELNIKOVA	{"phone": "+70682617321"}
0005434907146	5D5705	8431 335102	IGOR BELOV	{"phone": "+70016713544"}
0005434907147	BC0CF8	4247 478773	MAKSIM KARPOV	{"phone": "+70559036802"}
0005434907148	73DE7F	1126 840862	YULIYA PAVLOVA	{"email": "pavlova.y111965@postgrespro.ru", "phone": "+70880738401"}
0005434907149	27AEEC	2761 011008	ALEKSEY GAVRILOV	{"email": "a.gavrilov1964@postgrespro.ru", "phone": "+70118341483"}
0005434907150	0B9C7F	4854 141241	VERA TIKHONOVA	{"phone": "+70021745566"}
0005434907151	9D8B81	8254 519054	VALENTINA KOVALEVA	{"email": "kovaleva.v.091974@postgrespro.ru", "phone": "+70264165406"}
0005434907152	08D3A8	2032 353762	ANTON POPOV	{"email": "anton_popov121961@postgrespro.ru", "phone": "+70943432234"}
0005434907153	28A29D	2552 942065	VYACHESLAV VASILEV	{"email": "vyacheslav-vasilev.04021971@postgrespro.ru", "phone": "+70115758512"}
0005434907154	1D9DF9	9599 506036	TATYANA ALEKSEEVA	{"email": "alekseeva-t1963@postgrespro.ru", "phone": "+70308916235"}
0005434907155	F422C7	6882 479646	NATALYA POTAPOVA	{"phone": "+70229032072"}
0005434907156	3A381E	0553 289665	IRINA SOKOLOVA	{"email": "sokolova.i081979@postgrespro.ru", "phone": "+70897066102"}
0005434907157	7EA325	6120 645039	SERGEY PAVLOV	{"email": "sergey-pavlov.111969@postgrespro.ru", "phone": "+70256760588"}
0005434907158	7EA325	5758 277957	NIKOLAY MAKAROV	{"email": "makarov_n_081975@postgrespro.ru", "phone": "+70225556570"}
0005434907159	09460C	1263 966199	VIKTOR NAZAROV	{"email": "v.nazarov_1961@postgrespro.ru", "phone": "+70357779994"}
0005434907160	09460C	3799 744477	ALEKSANDRA EGOROVA	{"email": "aegorova-14081976@postgrespro.ru", "phone": "+70164824035"}
0005434907161	72E384	4958 905305	OLGA KUZMINA	{"phone": "+70771923201"}
0005434907162	72E384	1126 439763	TATYANA PAVLOVA	{"email": "tatyana.pavlova.1961@postgrespro.ru", "phone": "+70612520070"}
0005434907163	5D6369	1963 625156	ALEKSANDR KAZAKOV	{"phone": "+70902261062"}
0005434907164	5D6369	4695 600960	DARYA PAVLOVA	{"phone": "+70341040140"}
0005434907165	3D6F9F	3282 232771	ALEKSEY FOMIN	{"email": "alekseyfomin.021971@postgrespro.ru", "phone": "+70167739889"}
0005434907166	33F248	7719 119382	ALINA KISELEVA	{"phone": "+70721753773"}
0005434907167	33F248	0908 558862	STANISLAV KARPOV	{"email": "karpovs031978@postgrespro.ru", "phone": "+70740047406"}
0005434907168	3DF249	7401 512733	VALERIY GORBUNOV	{"phone": "+70333935605"}
0005434907169	B1BE22	8234 661617	SERGEY KAZAKOV	{"phone": "+70135051659"}
0005434907170	B1BE22	6935 846830	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr05091977@postgrespro.ru", "phone": "+70332612932"}
0005434907171	C7020C	2871 842686	ALEKSEY MOISEEV	{"email": "aleksey_moiseev1980@postgrespro.ru", "phone": "+70138293343"}
0005434907172	6EF376	6035 705449	ANASTASIYA FOMINA	{"email": "anastasiya_fomina_081987@postgrespro.ru", "phone": "+70017588213"}
0005434907173	6AFCD0	7025 436703	ALEKSANDRA VASILEVA	{"phone": "+70144053498"}
0005434907235	B610A1	7043 112687	VASILIY NIKITIN	{"phone": "+70068008668"}
0005434907174	D2E363	9034 901220	GALINA DENISOVA	{"email": "g_denisova.091975@postgrespro.ru", "phone": "+70854391809"}
0005434907175	D2E363	6405 633850	NIKOLAY SOKOLOV	{"email": "sokolov.nikolay.09121988@postgrespro.ru", "phone": "+70533234750"}
0005434907176	D2E363	6915 747435	NINA SCHERBAKOVA	{"email": "ninascherbakova1961@postgrespro.ru", "phone": "+70843227470"}
0005434907357	567371	2224 722741	RIM SCHERBAKOV	{"phone": "+70117246908"}
0005434907177	30E3D5	3805 292584	VALENTINA MASLOVA	{"email": "v.maslova_1978@postgrespro.ru", "phone": "+70652675157"}
0005434907178	7A186E	7953 223417	ALEKSANDR MOISEEV	{"phone": "+70995941861"}
0005434907179	AC10E5	8478 761373	GALINA POLYAKOVA	{"phone": "+70707937534"}
0005434907180	3987C2	0801 567542	RAFAIL ZHUKOV	{"phone": "+70547015177"}
0005434907181	3987C2	7146 653632	ALEKSANDR BONDARENKO	{"phone": "+70859673343"}
0005434907182	A6D8AB	8670 515180	VLADISLAV KARPOV	{"email": "karpov_vladislav11091978@postgrespro.ru", "phone": "+70668763263"}
0005434907183	4229EE	3813 765548	TATYANA KOLESNIKOVA	{"email": "tatyana-kolesnikova-1961@postgrespro.ru", "phone": "+70952641133"}
0005434907184	7BEB09	1242 660075	ALEKSANDR GAVRILOV	{"email": "a.gavrilov-23071968@postgrespro.ru", "phone": "+70796086079"}
0005434907185	A5BEFE	6713 164788	VLADIMIR OSIPOV	{"email": "vladimirosipov-1971@postgrespro.ru", "phone": "+70787057956"}
0005434907186	A5BEFE	0427 331084	STANISLAV DENISOV	{"phone": "+70208852295"}
0005434907187	4F17BA	0689 162327	ALEKSANDR FROLOV	{"email": "aleksandr.frolov-08071966@postgrespro.ru", "phone": "+70543225850"}
0005434907188	4F17BA	6464 619313	OLEG MEDVEDEV	{"phone": "+70667180481"}
0005434907189	5F4818	2106 884848	OKSANA VLASOVA	{"email": "o-vlasova-041959@postgrespro.ru", "phone": "+70257590489"}
0005434907190	5F4818	9811 782190	VIKTOR FROLOV	{"phone": "+70622972852"}
0005434907191	6E79D1	6325 560382	VIKTOR SOROKIN	{"email": "sorokin_viktor_1971@postgrespro.ru", "phone": "+70402049960"}
0005434907192	6E79D1	6581 656779	ALEKSANDR ABRAMOV	{"phone": "+70073794182"}
0005434907193	8028E4	4961 731354	TAMARA MALYSHEVA	{"phone": "+70159741548"}
0005434907194	A091DA	5055 339320	DMITRIY KUZMIN	{"email": "kuzmind_121975@postgrespro.ru", "phone": "+70135603625"}
0005434907195	A091DA	8715 291184	VERA ZAYCEVA	{"phone": "+70095845509"}
0005434907196	CBA770	0785 006283	LIDIYA MAKSIMOVA	{"phone": "+70310059329"}
0005434907197	45F4C4	5630 140739	MARINA KUZMINA	{"phone": "+70326921698"}
0005434907198	0713A1	7212 059507	FEDOR YAKOVLEV	{"phone": "+70199504279"}
0005434907199	D54F1D	6614 356808	VALENTINA SERGEEVA	{"email": "v.sergeeva_30041971@postgrespro.ru", "phone": "+70218439020"}
0005434907200	0168A1	0205 068188	OLGA KUZNECOVA	{"email": "okuznecova_27031972@postgrespro.ru", "phone": "+70634475778"}
0005434907201	657951	7943 616699	NATALYA KUZNECOVA	{"email": "kuznecova_natalya-1966@postgrespro.ru", "phone": "+70950271780"}
0005434907202	657951	8796 087443	SVETLANA KRASNOVA	{"phone": "+70063229182"}
0005434907203	031699	1040 436770	LARISA POPOVA	{"phone": "+70138345122"}
0005434907204	BB2F02	7986 276924	SERGEY NAUMOV	{"email": "naumov-s-03101961@postgrespro.ru", "phone": "+70051261079"}
0005434907205	DE32EA	8126 238504	VADIM NIKOLAEV	{"phone": "+70056573594"}
0005434907206	D68038	2040 043831	SERGEY PAVLOV	{"phone": "+70378901160"}
0005434907207	BE9A97	0363 902186	RUSTEM DAVYDOV	{"phone": "+70084860646"}
0005434907208	BE9A97	9402 319571	TIMOFEY GORBUNOV	{"phone": "+70501051914"}
0005434907209	CFCCE3	7768 735009	ANDREY PETROV	{"email": "andreypetrov-1974@postgrespro.ru", "phone": "+70539293955"}
0005434907210	CFCCE3	5195 283802	EKATERINA KISELEVA	{"phone": "+70538673710"}
0005434907211	0C1401	6134 061976	ANTON ALEKSANDROV	{"phone": "+70130481289"}
0005434907212	D22EFC	5593 186340	VERA ZOTOVA	{"email": "zotova.v_1972@postgrespro.ru", "phone": "+70722552109"}
0005434907213	90B5A2	2115 192414	VYACHESLAV VASILEV	{"phone": "+70614162713"}
0005434907214	4F23DC	4221 791556	ALEKSANDR TARASOV	{"email": "aleksandr_tarasov_08061988@postgrespro.ru", "phone": "+70452558566"}
0005434907215	D91AFF	8787 200596	VALENTINA RYABOVA	{"email": "v.ryabova_03101974@postgrespro.ru", "phone": "+70322542217"}
0005434907216	936C49	3957 144990	KSENIYA LUKYANOVA	{"email": "klukyanova_29011971@postgrespro.ru", "phone": "+70726307413"}
0005434907217	DE2A71	2557 831836	ALEKSANDR KUDRYASHOV	{"email": "a-kudryashov.1969@postgrespro.ru", "phone": "+70952134024"}
0005434907218	0F93F0	1572 265236	ANDREY ZAYCEV	{"phone": "+70863019420"}
0005434907219	0F93F0	2304 791564	ANNA IVANOVA	{"email": "ivanova-a.051977@postgrespro.ru", "phone": "+70881502606"}
0005434907220	6FDDF2	7204 968859	GALINA LUKYANOVA	{"phone": "+70443619420"}
0005434907221	6FDDF2	4809 370931	ALEKSEY MIKHAYLOV	{"phone": "+70226775692"}
0005434907222	777880	3263 931042	ANTONIDA SERGEEVA	{"phone": "+70625936891"}
0005434907223	537EA5	1085 564237	LYUBOV DMITRIEVA	{"phone": "+70439545947"}
0005434907224	B65BBE	8614 746473	ELIZAVETA MIRONOVA	{"email": "e_mironova_18011974@postgrespro.ru", "phone": "+70836509484"}
0005434907225	C2D8C1	8477 941164	ALEKSANDRA DAVYDOVA	{"phone": "+70476244701"}
0005434907226	C2D8C1	2133 914401	VENERA KUZNECOVA	{"email": "kuznecova-v-031978@postgrespro.ru", "phone": "+70756203090"}
0005434907227	E462A7	0248 344577	VERA ANDREEVA	{"email": "veraandreeva.21051965@postgrespro.ru", "phone": "+70898397698"}
0005434907228	E462A7	9512 293887	YULIYA ABRAMOVA	{"phone": "+70081308386"}
0005434907229	6C8B88	5828 692681	ANATOLIY KUZMIN	{"email": "anatoliy_kuzmin_031978@postgrespro.ru", "phone": "+70851661757"}
0005434907230	B92902	6232 012779	ALEKSANDR SMIRNOV	{"phone": "+70711065031"}
0005434907231	F40441	9726 930556	EVGENIY ROMANOV	{"phone": "+70240951636"}
0005434907232	F40441	0802 686148	NADEZHDA ERMAKOVA	{"phone": "+70189596540"}
0005434907233	78DDF0	0562 791881	STANISLAV SOLOVEV	{"email": "solovev_s22111980@postgrespro.ru", "phone": "+70647166413"}
0005434907234	4CAFCA	7496 109461	IVAN KULIKOV	{"phone": "+70088738731"}
0005434907236	5BEBEA	8761 963728	EKATERINA ZHURAVLEVA	{"email": "ekaterina-zhuravleva071979@postgrespro.ru", "phone": "+70971316884"}
0005434907237	5BEBEA	6219 993564	MARIYA KRASNOVA	{"phone": "+70243004088"}
0005434907238	5BEBEA	3444 042399	TATYANA NESTEROVA	{"phone": "+70803584702"}
0005434907239	CB3D83	8641 377092	MIKHAIL IVANOV	{"phone": "+70849453798"}
0005434907240	CE5797	1101 563474	VALERIY PAVLOV	{"email": "pavlov_valeriy08061978@postgrespro.ru", "phone": "+70946197266"}
0005434907241	B98B28	9152 946116	RAISA PETROVA	{"email": "petrova.r-1970@postgrespro.ru", "phone": "+70957761039"}
0005434907242	B98B28	9313 310511	ELENA MATVEEVA	{"email": "elena.matveeva1957@postgrespro.ru", "phone": "+70208148608"}
0005434907243	B98B28	0444 704061	NURLAN ABRAMOV	{"email": "abramov-nurlan14031975@postgrespro.ru", "phone": "+70789546218"}
0005434907244	99F1F8	5068 544020	DARYA ROMANOVA	{"phone": "+70614583261"}
0005434907245	99F1F8	3817 682385	SEMEN KRASNOV	{"email": "krasnov.s31031973@postgrespro.ru", "phone": "+70799687886"}
0005434907246	E34B83	2444 436674	VIKTOR YAKOVLEV	{"phone": "+70133883681"}
0005434907247	E34B83	6820 630714	NADEZHDA SOROKINA	{"phone": "+70873283661"}
0005434907248	3B9D55	7179 751344	MARINA KONDRATEVA	{"email": "marina_kondrateva061968@postgrespro.ru", "phone": "+70572517569"}
0005434907249	3B9D55	7392 741687	GALINA ORLOVA	{"phone": "+70147374519"}
0005434907250	CC069E	7883 769229	NINA KAZAKOVA	{"phone": "+70668130922"}
0005434907251	95D535	6233 067114	ANNA AKIMOVA	{"phone": "+70462189244"}
0005434907252	95D535	4237 728888	ANATOLIY KUZMIN	{"phone": "+70985329729"}
0005434907253	95D535	7098 205725	OLESYA KUZNECOVA	{"email": "kuznecova.olesya-1972@postgrespro.ru", "phone": "+70069018608"}
0005434907254	A7CC92	4456 873679	NATALYA ARKHIPOVA	{"phone": "+70184898379"}
0005434907255	792B61	6084 257266	DARYA ABRAMOVA	{"phone": "+70009516413"}
0005434907256	792B61	1262 923682	DENIS ZAYCEV	{"phone": "+70683142600"}
0005434907257	792B61	6717 748123	MARINA NESTEROVA	{"email": "marinanesterova.06071969@postgrespro.ru", "phone": "+70305143900"}
0005434907258	3275A7	9445 963823	DMITRIY FEDOROV	{"email": "fedorov_d.26071954@postgrespro.ru", "phone": "+70991751007"}
0005434907259	91A94E	6335 807406	MIKHAIL BONDARENKO	{"email": "bondarenko-m.1971@postgrespro.ru", "phone": "+70137585720"}
0005434907260	C1EFE7	5257 249176	KONSTANTIN KAZAKOV	{"email": "konstantinkazakov.1977@postgrespro.ru", "phone": "+70301418631"}
0005434907261	834818	2150 644137	LARISA TIKHONOVA	{"email": "tikhonova.larisa.1978@postgrespro.ru", "phone": "+70138664932"}
0005434907262	16372F	1560 450813	YULIYA LAZAREVA	{"email": "ylazareva041969@postgrespro.ru", "phone": "+70724835988"}
0005434907263	EA70A5	9475 873479	LARISA GERASIMOVA	{"email": "lgerasimova-1974@postgrespro.ru", "phone": "+70984462945"}
0005434907264	EA70A5	0136 811571	VALENTINA NAZAROVA	{"email": "nazarova_v_021978@postgrespro.ru", "phone": "+70654947642"}
0005434907265	F1B330	5813 920317	ALEKSANDR MOROZOV	{"phone": "+70308798679"}
0005434907266	5E2467	0851 303250	SERGEY KULIKOV	{"phone": "+70772980451"}
0005434907267	A81604	3632 903936	EVGENIY SERGEEV	{"email": "sergeev.evgeniy-071979@postgrespro.ru", "phone": "+70442432794"}
0005434907268	FE7143	7478 412026	ALISA PETROVA	{"email": "petrova.a.20041971@postgrespro.ru", "phone": "+70096710903"}
0005434907269	2DF488	1094 692786	DMITRIY GERASIMOV	{"phone": "+70849919502"}
0005434907270	2DF488	3987 019525	VALENTIN ALEKSEEV	{"phone": "+70954525263"}
0005434907271	1C9A5A	0217 365476	ZHANNA NAZAROVA	{"email": "zhanna_nazarova.1970@postgrespro.ru", "phone": "+70611015185"}
0005434907272	1EB9E0	9300 042092	ELINA EGOROVA	{"email": "e_egorova18111979@postgrespro.ru", "phone": "+70508467269"}
0005434907273	DD1CB7	0422 006752	YURIY SMIRNOV	{"email": "smirnovy1988@postgrespro.ru", "phone": "+70904839177"}
0005434907274	6F0513	4564 876060	ALBINA ALEKSEEVA	{"phone": "+70945729353"}
0005434907275	0C8D9A	2025 608881	TAISIYA LUKYANOVA	{"email": "t_lukyanova_15071971@postgrespro.ru", "phone": "+70800243869"}
0005434907276	0C8D9A	5055 460139	OLGA POPOVA	{"phone": "+70336680593"}
0005434907277	315F07	5408 982669	LYUDMILA MEDVEDEVA	{"email": "medvedeva-l-04051975@postgrespro.ru", "phone": "+70928336646"}
0005434907278	F2984F	0816 825934	ANATOLIY KUZMIN	{"phone": "+70439550662"}
0005434907279	7A251F	1985 311147	ILYA FROLOV	{"email": "frolov_i.051971@postgrespro.ru", "phone": "+70025107767"}
0005434907280	7A251F	7309 878413	MARIYA ABRAMOVA	{"email": "abramovamariya03011974@postgrespro.ru", "phone": "+70195144137"}
0005434907281	5E95EC	6482 302888	LYUDMILA KUDRYASHOVA	{"phone": "+70105870587"}
0005434907282	B8927C	3170 514513	TAMARA KUZMINA	{"email": "kuzmina_t-14011967@postgrespro.ru", "phone": "+70187106921"}
0005434907283	08FE2E	2875 631293	LYUBOV NESTEROVA	{"email": "l-nesterova_1964@postgrespro.ru", "phone": "+70044856762"}
0005434907284	AD2B2D	9132 178304	MIKHAIL DMITRIEV	{"email": "dmitriev_mikhail091973@postgrespro.ru", "phone": "+70277562954"}
0005434907285	A288FF	3339 873658	ANASTASIYA ZAKHAROVA	{"phone": "+70584471191"}
0005434907286	503408	6028 454157	ALEKSEY TARASOV	{"email": "tarasov.aleksey27081981@postgrespro.ru", "phone": "+70884133571"}
0005434907287	503408	8822 512320	LYUDMILA DAVYDOVA	{"email": "lyudmila-davydova111975@postgrespro.ru", "phone": "+70669677990"}
0005434907288	B89FC4	3574 267645	TAMARA PETROVA	{"email": "tpetrova_1973@postgrespro.ru", "phone": "+70418841258"}
0005434907289	B89FC4	2148 952609	VALERIYA BORISOVA	{"phone": "+70399974080"}
0005434907290	D6ECBA	5530 653560	VALERIY ABRAMOV	{"phone": "+70753769179"}
0005434907291	211E53	0984 009339	MARINA ANISIMOVA	{"phone": "+70931237575"}
0005434907292	211E53	7466 084477	VLADIMIR EGOROV	{"email": "egorovv.091979@postgrespro.ru", "phone": "+70759541618"}
0005434907293	28BDC2	5551 835797	LARISA NOVIKOVA	{"email": "novikovalarisa041959@postgrespro.ru", "phone": "+70713337561"}
0005434907294	B80A17	8121 579452	ANDREY ANDREEV	{"email": "andrey_andreev23041967@postgrespro.ru", "phone": "+70563326434"}
0005434907295	BDD4CD	9909 470974	RAISA SERGEEVA	{"phone": "+70919110296"}
0005434907296	77B2A5	2150 061572	SERGEY GAVRILOV	{"email": "gavrilov-s.1986@postgrespro.ru", "phone": "+70456117665"}
0005434907297	965606	8570 666765	ALEKSANDR BORISOV	{"email": "a.borisov_091968@postgrespro.ru", "phone": "+70002093493"}
0005434907299	B31446	5275 736524	ELIZAVETA ALEKSEEVA	{"email": "e-alekseeva.071977@postgrespro.ru", "phone": "+70077614834"}
0005434907300	E9545A	9664 519538	VLADISLAV BARANOV	{"phone": "+70970768197"}
0005434907301	E09F5D	8028 770096	ALLA KOROLEVA	{"email": "koroleva_a_22071967@postgrespro.ru", "phone": "+70538819121"}
0005434907302	E09F5D	0023 416780	SANIYA DENISOVA	{"phone": "+70541230429"}
0005434907303	E09F5D	0369 264450	VARVARA PETROVA	{"email": "petrova_varvara.1962@postgrespro.ru", "phone": "+70961168368"}
0005434907304	31F3B3	2480 186579	TATYANA MELNIKOVA	{"email": "melnikova.t.20051974@postgrespro.ru", "phone": "+70005566610"}
0005434907305	6DA202	0620 478178	VALERIY KUZNECOV	{"email": "kuznecov.valeriy081976@postgrespro.ru", "phone": "+70443479827"}
0005434907306	9335B6	0352 515560	IVAN CHERNOV	{"phone": "+70264215384"}
0005434907307	9335B6	9889 011262	MARINA ANISIMOVA	{"email": "manisimova_1972@postgrespro.ru", "phone": "+70473331365"}
0005434907308	BC1395	1423 591430	STANISLAV FROLOV	{"email": "s-frolov_04061971@postgrespro.ru", "phone": "+70880836416"}
0005434907309	BC1395	9352 773580	SERGEY NIKITIN	{"email": "s_nikitin_17021963@postgrespro.ru", "phone": "+70783405000"}
0005434907310	BC1395	5676 745046	EVGENIY CHERNOV	{"email": "chernov_evgeniy-1969@postgrespro.ru", "phone": "+70604335313"}
0005434907311	B65FE9	4988 064786	ELENA FROLOVA	{"email": "frolova_e_1971@postgrespro.ru", "phone": "+70718349245"}
0005434907312	B65FE9	2301 606105	ANGELINA DAVYDOVA	{"email": "davydova_a.15061982@postgrespro.ru", "phone": "+70586437621"}
0005434907313	B65FE9	6504 913262	ANDREY PAVLOV	{"phone": "+70412885761"}
0005434907314	94B6F6	9130 973899	MARINA KALININA	{"email": "marina.kalinina_1976@postgrespro.ru", "phone": "+70829294818"}
0005434907315	043A75	8290 574108	ANATOLIY GAVRILOV	{"phone": "+70750886488"}
0005434907316	6C09FD	6984 566741	NINA KOROLEVA	{"email": "nkoroleva.021974@postgrespro.ru", "phone": "+70536933275"}
0005434907317	8C7DE6	6913 573365	NIKITA STEPANOV	{"email": "nstepanov.12121962@postgrespro.ru", "phone": "+70738608608"}
0005434907318	575195	3713 575247	EKATERINA SEMENOVA	{"phone": "+70051901184"}
0005434907319	24FABE	3270 375326	VALENTINA POLYAKOVA	{"phone": "+70732351600"}
0005434907320	24FABE	6494 676560	OLGA SEMENOVA	{"email": "o.semenova_1968@postgrespro.ru", "phone": "+70787771426"}
0005434907321	133232	5935 909031	VLADIMIR MAKAROV	{"phone": "+70678558294"}
0005434907322	6DA8FC	8321 062283	OLGA YUDINA	{"email": "yudina-o1960@postgrespro.ru", "phone": "+70286164296"}
0005434907323	58E5D8	0503 225770	NAZAR KULIKOV	{"email": "nazarkulikov-041973@postgrespro.ru", "phone": "+70369450027"}
0005434907324	58E5D8	8952 703003	SERGEY GUSEV	{"phone": "+70871019255"}
0005434907325	1E0F91	4014 462736	LYUBOV ANDREEVA	{"email": "andreeva.l1965@postgrespro.ru", "phone": "+70502512554"}
0005434907326	1E0F91	2187 486593	OLEG SEMENOV	{"email": "semenov.oleg121990@postgrespro.ru", "phone": "+70667458870"}
0005434907327	80318C	1502 432988	TATYANA PETROVA	{"phone": "+70034667746"}
0005434907328	7A6927	5798 688460	DMITRIY POPOV	{"phone": "+70814132080"}
0005434907329	BC7CE8	1952 729498	ANDREY VASILEV	{"email": "andreyvasilev21061969@postgrespro.ru", "phone": "+70060551166"}
0005434907330	BC7CE8	4641 628510	IRINA RYABOVA	{"email": "ryabova_i-101967@postgrespro.ru", "phone": "+70044904876"}
0005434907331	674B73	0753 029953	ANDREY SIDOROV	{"email": "sidorova07061960@postgrespro.ru", "phone": "+70028188423"}
0005434907332	DFF4E7	6695 950186	ALSU NESTEROVA	{"phone": "+70480855623"}
0005434907333	DFF4E7	6808 786251	VALERIY PETROV	{"email": "petrovvaleriy-1967@postgrespro.ru", "phone": "+70207466042"}
0005434907334	0916D8	9574 192580	VALERIY BELOV	{"email": "belov_v.011969@postgrespro.ru", "phone": "+70752795808"}
0005434907335	53B58E	7797 373674	VLADIMIR TIMOFEEV	{"phone": "+70690038137"}
0005434907336	53B58E	0747 170006	MIKHAIL KUZMIN	{"email": "m.kuzmin.1970@postgrespro.ru", "phone": "+70712235519"}
0005434907337	63091C	9733 990424	VALENTINA MEDVEDEVA	{"email": "medvedeva-v031975@postgrespro.ru", "phone": "+70987576042"}
0005434907338	63091C	6486 037678	EVGENIY CHERNOV	{"phone": "+70056132194"}
0005434907339	33A44E	8346 824951	SVETLANA POTAPOVA	{"email": "potapova.svetlana_24121977@postgrespro.ru", "phone": "+70549003586"}
0005434907340	33A44E	1398 306094	VENERA SOKOLOVA	{"phone": "+70828758162"}
0005434907341	A2D8B3	7892 970673	NATALYA RODIONOVA	{"email": "rodionova_natalya-1981@postgrespro.ru", "phone": "+70078811234"}
0005434907342	11A27A	4490 311371	RAISA NOVIKOVA	{"email": "novikova-raisa-1964@postgrespro.ru", "phone": "+70437952876"}
0005434907343	11A27A	8088 808606	GALINA ZAKHAROVA	{"phone": "+70094296618"}
0005434907344	A355A5	7479 635638	ANASTASIYA SIDOROVA	{"phone": "+70017944926"}
0005434907345	24E2E8	5496 999479	YURIY VASILEV	{"phone": "+70781666634"}
0005434907346	DA0822	4651 990588	RAISA NIKIFOROVA	{"email": "nikiforova.r1965@postgrespro.ru", "phone": "+70182950084"}
0005434907347	DA0822	6997 624664	VIKTOR FEDOROV	{"email": "viktor-fedorov-04041986@postgrespro.ru", "phone": "+70080654582"}
0005434907348	943E18	5766 305107	DMITRIY GUSEV	{"email": "gusevd_071978@postgrespro.ru", "phone": "+70838112422"}
0005434907349	4F1AA1	2624 073581	VALERIY SAVELEV	{"email": "savelevv03121987@postgrespro.ru", "phone": "+70374541079"}
0005434907350	B96960	8478 045520	RIMMA DENISOVA	{"phone": "+70246401453"}
0005434907351	683D4E	3930 092642	NADEZHDA KONDRATEVA	{"phone": "+70892002611"}
0005434907352	BC616A	6781 963012	ALEKSANDR KOROLEV	{"email": "akorolev_1958@postgrespro.ru", "phone": "+70264146623"}
0005434907353	BC616A	7071 989772	ANASTASIYA BARANOVA	{"email": "baranovaanastasiya-13041972@postgrespro.ru", "phone": "+70760683618"}
0005434907354	BC616A	3099 172634	ELENA MAKAROVA	{"email": "e_makarova_04101964@postgrespro.ru", "phone": "+70491926975"}
0005434907355	9015F3	6718 634195	PETR NIKITIN	{"email": "p.nikitin-031968@postgrespro.ru", "phone": "+70929259086"}
0005434907356	82B5A7	7795 456173	LYUBOV SOKOLOVA	{"phone": "+70306606174"}
0005434907358	1C5AD3	4678 135267	RIMMA CHERNOVA	{"email": "rchernova-23091980@postgrespro.ru", "phone": "+70648651851"}
0005434907359	51C281	8648 807475	KONSTANTIN SOROKIN	{"email": "konstantin_sorokin1972@postgrespro.ru", "phone": "+70885764751"}
0005434907360	02AEC7	2302 088174	OKSANA KOROLEVA	{"email": "okoroleva_061981@postgrespro.ru", "phone": "+70628885735"}
0005434907361	BC8644	8501 291815	ALIYA LOGINOVA	{"email": "aliya_loginova-22071975@postgrespro.ru", "phone": "+70719084114"}
0005434907362	BC8644	1788 698148	NIKOLAY ORLOV	{"phone": "+70678874992"}
0005434907363	E8DECE	0254 527392	YULIYA VASILEVA	{"email": "vasileva_y.081969@postgrespro.ru", "phone": "+70389297156"}
0005434907364	43CAF1	6610 682789	IRINA TROFIMOVA	{"email": "trofimovairina.03071964@postgrespro.ru", "phone": "+70594598480"}
0005434907365	A24B9D	6206 069818	EMILIYA AKIMOVA	{"email": "emiliyaakimova.031965@postgrespro.ru", "phone": "+70090384507"}
0005434907366	A64C23	5968 978393	IRINA YUDINA	{"email": "yudinai06051973@postgrespro.ru", "phone": "+70117928598"}
0005434907367	DB6EB8	1888 035563	OLGA AFANASEVA	{"email": "olga.afanaseva_04071975@postgrespro.ru", "phone": "+70089280558"}
0005434907368	353838	7612 123128	TATYANA IVANOVA	{"phone": "+70520657266"}
0005434907369	47615F	3477 726930	PETR STEPANOV	{"email": "pstepanov_14051979@postgrespro.ru", "phone": "+70719393803"}
0005434907370	27FD3E	8689 122818	IGOR SERGEEV	{"email": "sergeevi16111974@postgrespro.ru", "phone": "+70648302488"}
0005434907371	D9CE44	0807 793272	NIKOLAY SHEVCHENKO	{"email": "n.shevchenko1971@postgrespro.ru", "phone": "+70443968666"}
0005434907372	115BB6	1028 096993	MARINA IVANOVA	{"email": "ivanova-m_28031975@postgrespro.ru", "phone": "+70312061466"}
0005434907373	F0D8E9	6907 032747	ALEKSANDR VASILEV	{"phone": "+70560359093"}
0005434907374	F0D8E9	1987 683201	TAISIYA MAKAROVA	{"email": "taisiya-makarova-30011966@postgrespro.ru", "phone": "+70470671297"}
0005434907375	CFDE2A	4962 613554	VLADIMIR ROMANOV	{"phone": "+70765457497"}
0005434907376	CFDE2A	9191 646338	EKATERINA NAZAROVA	{"phone": "+70502547063"}
0005434907377	CFDE2A	5333 500779	TATYANA SEMENOVA	{"email": "semenova_t.041972@postgrespro.ru", "phone": "+70572946984"}
0005434907378	0BE5E0	5802 521721	IRINA ISAEVA	{"phone": "+70372137087"}
0005434907379	AF0C2B	7978 722014	RASHID SMIRNOV	{"phone": "+70318251119"}
0005434907380	AF0C2B	7485 252488	KRISTINA SEMENOVA	{"email": "k.semenova071976@postgrespro.ru", "phone": "+70650398946"}
0005434907381	AF0C2B	6614 020853	NINA FEDOROVA	{"phone": "+70045620415"}
0005434907382	AF0C2B	3568 354892	ALINA MASLOVA	{"email": "maslova.alina1974@postgrespro.ru", "phone": "+70237383318"}
0005434907383	915FE3	8520 553501	LYUBOV YAKOVLEVA	{"email": "yakovleva_l.22101983@postgrespro.ru", "phone": "+70219353724"}
0005434907384	915FE3	8996 824287	RADIK GERASIMOV	{"phone": "+70374074347"}
0005434907385	915FE3	2891 109258	SERGEY KUZNECOV	{"email": "skuznecov-15111966@postgrespro.ru", "phone": "+70590633788"}
0005434907386	B542CC	0386 787957	IVAN ORLOV	{"phone": "+70275369286"}
0005434907387	B542CC	1368 232011	KONSTANTIN IVANOV	{"email": "ivanovkonstantin.15021973@postgrespro.ru", "phone": "+70498569419"}
0005434907388	A47C45	3188 514177	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr1981@postgrespro.ru", "phone": "+70843503203"}
0005434907389	A47C45	6917 851263	SERGEY ZAKHAROV	{"email": "sergey-zakharov-011982@postgrespro.ru", "phone": "+70713378533"}
0005434907390	AC813D	5208 368992	VITALIY ISAEV	{"email": "v.isaev121975@postgrespro.ru", "phone": "+70050681240"}
0005434907391	AC813D	6331 453306	NIKOLAY MAKSIMOV	{"email": "maksimov.n-1967@postgrespro.ru", "phone": "+70763882119"}
0005434907392	BA1814	2210 022447	LYUBOV TIMOFEEVA	{"phone": "+70504010391"}
0005434907393	CE46BD	3394 712188	VLADISLAV PETROV	{"email": "vladislavpetrov-1979@postgrespro.ru", "phone": "+70781133139"}
0005434907394	06A0E2	9968 189453	ANDREY KARPOV	{"email": "andrey_karpov_09091969@postgrespro.ru", "phone": "+70850471321"}
0005434907395	7F83CC	4589 247312	LILIYA SAVELEVA	{"email": "saveleva.liliya.1976@postgrespro.ru", "phone": "+70909063872"}
0005434907396	C15D45	4664 687342	SERGEY ANTONOV	{"email": "sergey.antonov-1979@postgrespro.ru", "phone": "+70696715864"}
0005434907397	F21E3E	4398 878594	VALENTINA LAZAREVA	{"email": "valentinalazareva_24021967@postgrespro.ru", "phone": "+70261866445"}
0005434907398	83A167	4712 336107	VALENTIN KOZLOV	{"email": "kozlov.v-1968@postgrespro.ru", "phone": "+70475760704"}
0005434907399	6D9605	8128 070843	SVETLANA NOVIKOVA	{"phone": "+70639503676"}
0005434907400	6D9605	9585 593764	BORIS MAKAROV	{"phone": "+70797898437"}
0005434907401	8B8E7B	2930 020162	ANTONINA TIKHONOVA	{"phone": "+70915221807"}
0005434907402	8B8E7B	9975 376032	SERGEY MOISEEV	{"email": "s_moiseev05121973@postgrespro.ru", "phone": "+70565160860"}
0005434907403	8CDD35	0793 885939	VLADIMIR NAUMOV	{"email": "vnaumov-1982@postgrespro.ru", "phone": "+70415459072"}
0005434907404	8CDD35	6253 223875	DARYA ZOTOVA	{"phone": "+70228206031"}
0005434907405	8CDD35	0936 050327	ILYA SMIRNOV	{"phone": "+70530369259"}
0005434907406	A3B8EC	4451 970872	POLINA STEPANOVA	{"phone": "+70144277910"}
0005434907407	F91DA3	6000 022831	NATALYA KONOVALOVA	{"email": "natalya-konovalova14101979@postgrespro.ru", "phone": "+70824038140"}
0005434907408	23673F	7087 238140	SVETLANA NAZAROVA	{"phone": "+70890716342"}
0005434907409	B428E0	5076 399139	SERGEY KAZAKOV	{"phone": "+70394909630"}
0005434907410	71F98D	0891 097440	YURIY GAVRILOV	{"email": "gavrilov_y-23111955@postgrespro.ru", "phone": "+70281344220"}
0005434907411	5725C3	4166 562409	RUSLAN TIMOFEEV	{"email": "ruslan-timofeev.31121966@postgrespro.ru", "phone": "+70914933585"}
0005434907412	3DDF79	7841 917791	VLADIMIR STEPANOV	{"phone": "+70820380880"}
0005434907413	6D998A	0792 405335	KLAVDIYA VLASOVA	{"phone": "+70705370176"}
0005434907414	94E843	8407 268273	ANNA MAKAROVA	{"phone": "+70463001456"}
0005434907415	AD9B88	1305 181996	VLADIMIR ORLOV	{"phone": "+70396048802"}
0005434907416	975711	0939 276863	OLEG NOVIKOV	{"phone": "+70190499690"}
0005434907417	81DE00	2118 503240	ALEKSANDR POPOV	{"email": "popov-a.13041975@postgrespro.ru", "phone": "+70663572762"}
0005434907418	991AFD	5498 512935	EVGENIYA FILATOVA	{"email": "filatovaevgeniya-30061972@postgrespro.ru", "phone": "+70604585101"}
0005434907419	8A95A6	2008 496930	INNA ZAKHAROVA	{"phone": "+70287480814"}
0005434907420	8A95A6	7728 506029	VLADIMIR ZAKHAROV	{"phone": "+70428575066"}
0005434907421	8BC4DE	7521 319814	IGOR NOVIKOV	{"email": "novikovi-011970@postgrespro.ru", "phone": "+70331636348"}
0005434907422	C4AB35	3672 599144	LYUDMILA CHERNOVA	{"phone": "+70765069450"}
0005434907423	C4AB35	0941 262785	LYUDMILA VOLKOVA	{"phone": "+70711695903"}
0005434907424	E21957	2600 493223	ALEKSEY VOLKOV	{"email": "volkov_aleksey.08041975@postgrespro.ru", "phone": "+70512864435"}
0005434907425	E21957	6838 743908	NADEZHDA IVANOVA	{"phone": "+70572266915"}
0005434907426	BBF59A	5827 594366	ALEKSANDR KARPOV	{"email": "karpov-a.03081969@postgrespro.ru", "phone": "+70306772660"}
0005434907427	BBF59A	1781 302581	SERGEY NIKITIN	{"email": "sergey.nikitin-061971@postgrespro.ru", "phone": "+70077906399"}
0005434907428	9F9845	8943 290334	SEMEN PAVLOV	{"email": "pavlovs.061986@postgrespro.ru", "phone": "+70109971558"}
0005434907429	B571C2	9331 913390	VLADIMIR FROLOV	{"phone": "+70439730501"}
0005434907430	3647B4	7768 117195	VALENTINA KUZMINA	{"phone": "+70292685640"}
0005434907431	0EC01F	6678 901645	ALEKSEY KUZNECOV	{"phone": "+70281726877"}
0005434907432	0EC01F	8607 213575	KONSTANTIN PETROV	{"email": "k_petrov_22091971@postgrespro.ru", "phone": "+70285852578"}
0005434907433	2EB87C	2464 833437	IGOR GRIGOREV	{"phone": "+70171009743"}
0005434907434	0FD586	1155 732248	SERGEY FEDOTOV	{"phone": "+70083626137"}
0005434907435	C33A0E	9963 425903	OLGA KARPOVA	{"email": "olga-karpova041954@postgrespro.ru", "phone": "+70596197385"}
0005434907436	A756E1	4473 205942	ANZHELA AFANASEVA	{"phone": "+70212341503"}
0005434907437	A756E1	0332 064481	MARIYA KONDRATEVA	{"email": "kondrateva.mariya_1969@postgrespro.ru", "phone": "+70975890388"}
0005434907438	54B990	5963 766061	ALEVTINA ANISIMOVA	{"phone": "+70368585723"}
0005434907439	C913E7	6605 014993	YURIY KUZMIN	{"email": "yuriy_kuzmin.29061973@postgrespro.ru", "phone": "+70424996239"}
0005434907440	37B084	8869 978106	OLGA NAZAROVA	{"email": "nazarova.o061974@postgrespro.ru", "phone": "+70119329867"}
0005434907441	E00C69	8068 584090	IRINA MATVEEVA	{"phone": "+70920879119"}
0005434907442	E2932D	1571 163564	KIRILL KUZMIN	{"email": "kuzmin.kirill.1971@postgrespro.ru", "phone": "+70111805047"}
0005434907443	5E7AE7	4078 995094	KONSTANTIN NIKOLAEV	{"email": "k.nikolaev.28021959@postgrespro.ru", "phone": "+70683728036"}
0005434907444	79AFB2	4446 464310	ELENA MEDVEDEVA	{"email": "emedvedeva_1978@postgrespro.ru", "phone": "+70450382707"}
0005434907445	79AFB2	6367 957271	VALERIY ABRAMOV	{"email": "abramov_v11101970@postgrespro.ru", "phone": "+70540585687"}
0005434907446	0EC4C4	6638 476580	GALINA NIKITINA	{"phone": "+70599317529"}
0005434907447	0EC4C4	7867 925799	RUSTAM ZAKHAROV	{"email": "zakharovrustam-121975@postgrespro.ru", "phone": "+70876887985"}
0005434907448	28096E	9622 965660	LIDIYA TITOVA	{"email": "lidiya.titova-08051977@postgrespro.ru", "phone": "+70772446243"}
0005434907449	622E05	8300 935764	ANGELINA LUKYANOVA	{"phone": "+70149475292"}
0005434907450	A1DEF1	9799 483508	SERGEY MELNIKOV	{"email": "melnikov_s1969@postgrespro.ru", "phone": "+70433253039"}
0005434907451	A1DEF1	9356 126089	SERGEY MAKAROV	{"email": "s-makarov-1969@postgrespro.ru", "phone": "+70981465913"}
0005434907452	4BDA1B	3282 268030	ELENA ZAKHAROVA	{"phone": "+70628539743"}
0005434907453	4BDA1B	5380 296817	SERGEY KUZNECOV	{"phone": "+70405999248"}
0005434907454	13AD2C	3638 100546	OLEG OSIPOV	{"phone": "+70862169686"}
0005434907455	13AD2C	9555 084614	LARISA ROMANOVA	{"email": "romanoval021970@postgrespro.ru", "phone": "+70235575406"}
0005434907456	D898C8	6424 527476	IGOR GUSEV	{"phone": "+70425425161"}
0005434907457	1051A9	6519 687442	YURIY ANTONOV	{"email": "antonovy-1967@postgrespro.ru", "phone": "+70121689549"}
0005434907458	95628A	3801 888530	ELENA TARASOVA	{"phone": "+70338809120"}
0005434907459	2FE60E	8778 165490	VYACHESLAV VASILEV	{"phone": "+70267154809"}
0005434907460	2FE60E	8152 730674	TATYANA IVANOVA	{"phone": "+70496829003"}
0005434907461	4F65F7	7965 120241	TATYANA POPOVA	{"email": "tatyana.popova1981@postgrespro.ru", "phone": "+70742822465"}
0005434907462	008B02	4477 460596	TATYANA ANTONOVA	{"phone": "+70473583097"}
0005434907463	008B02	4122 114287	DMITRIY SMIRNOV	{"phone": "+70835213845"}
0005434907464	D4990D	1004 089737	LIDIYA VOLKOVA	{"phone": "+70073914218"}
0005434907465	63A673	2104 386393	NATALYA SMIRNOVA	{"email": "natalya_smirnova_05091955@postgrespro.ru", "phone": "+70532566875"}
0005434907466	91D2AD	5982 731716	ELENA MATVEEVA	{"email": "matveevaelena-1980@postgrespro.ru", "phone": "+70414453658"}
0005434907467	39355A	8432 126752	ANNA ZAYCEVA	{"email": "zaycevaanna071969@postgrespro.ru", "phone": "+70910522177"}
0005434907468	C9A3B8	9181 090267	ALEVTINA OSIPOVA	{"phone": "+70494796211"}
0005434907469	9AB71A	7074 076640	OLGA POPOVA	{"email": "olga.popova.10071978@postgrespro.ru", "phone": "+70911581779"}
0005434907470	C0DA3D	9867 891418	ANDREY YAKOVLEV	{"email": "andrey-yakovlev-1986@postgrespro.ru", "phone": "+70715437742"}
0005434907471	0677EE	0338 570808	IGOR PETROV	{"email": "petrov.igor-1964@postgrespro.ru", "phone": "+70862296684"}
0005434907472	93AD4E	7065 783080	ALENA KOLESNIKOVA	{"phone": "+70798642386"}
0005434907473	93AD4E	6728 546291	ANASTASIYA NOVIKOVA	{"phone": "+70617149052"}
0005434907474	FEF486	8452 869566	MARIYA IVANOVA	{"phone": "+70572888618"}
0005434907475	F5F0BC	3043 184654	ANTONINA MAKSIMOVA	{"phone": "+70470130456"}
0005434907476	980C98	3581 664457	NIKOLAY PAVLOV	{"email": "pavlov-n091974@postgrespro.ru", "phone": "+70633318444"}
0005434907477	EDA10A	6573 096968	NINA MAKSIMOVA	{"phone": "+70657870765"}
0005434907478	8DACEC	6604 868817	NINA FILIPPOVA	{"phone": "+70955052124"}
0005434907479	E64DDE	0918 839097	OLGA KOLESNIKOVA	{"email": "kolesnikova.o-18021960@postgrespro.ru", "phone": "+70375982596"}
0005434907480	E64DDE	1141 564499	NAIL VOLKOV	{"phone": "+70117084572"}
0005434907481	5584CD	8858 340408	ARTEM TARASOV	{"email": "tarasov_artem-1972@postgrespro.ru", "phone": "+70847082056"}
0005434907482	5584CD	3066 058648	NADEZHDA ROMANOVA	{"phone": "+70208043367"}
0005434907483	5584CD	9451 642908	ALEKSEY MOROZOV	{"phone": "+70254060008"}
0005434907484	B710EB	7190 863486	ILYA ROMANOV	{"phone": "+70303288845"}
0005434907485	B710EB	2777 882686	KRISTINA DANILOVA	{"phone": "+70044483115"}
0005434907486	524A9D	5654 255912	ROMAN KOROLEV	{"email": "korolev_roman-1976@postgrespro.ru", "phone": "+70314449640"}
0005434907487	DE246D	5062 806776	ARTEM MIRONOV	{"phone": "+70584784083"}
0005434907488	997C7B	7246 994325	NADEZHDA BELOVA	{"email": "belova-nadezhda-071968@postgrespro.ru", "phone": "+70830239260"}
0005434907489	60B3E6	9825 073775	DMITRIY KARPOV	{"email": "karpov-d-13031963@postgrespro.ru", "phone": "+70490312476"}
0005434907490	60B3E6	2541 813079	NIKOLAY GRIGOREV	{"email": "grigorev-nikolay.1972@postgrespro.ru", "phone": "+70085070900"}
0005434907491	96274B	4500 337534	ZINAIDA KOZLOVA	{"email": "kozlova-zinaida-1970@postgrespro.ru", "phone": "+70585126802"}
0005434907492	F2C9A1	3552 350160	NIKOLAY DAVYDOV	{"email": "davydov.n-1962@postgrespro.ru", "phone": "+70282469614"}
0005434907493	6138D0	5711 959011	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey_1972@postgrespro.ru", "phone": "+70502831751"}
0005434907494	6C2BCC	4200 635495	VYACHESLAV MATVEEV	{"email": "v-matveev24081965@postgrespro.ru", "phone": "+70285861808"}
0005434907495	C89F02	9169 939883	ELENA KUZNECOVA	{"phone": "+70314630492"}
0005434907496	AAC856	9756 199022	KONSTANTIN SMIRNOV	{"email": "konstantin-smirnov.22021959@postgrespro.ru", "phone": "+70020502565"}
0005434907497	2515A1	3989 791770	KRISTINA KUZNECOVA	{"phone": "+70759710926"}
0005434907498	A006B7	2197 237272	TAMARA RYABOVA	{"phone": "+70720679796"}
0005434907499	AC4F8C	0813 557297	ELENA DMITRIEVA	{"email": "dmitrievae.1976@postgrespro.ru", "phone": "+70594357802"}
0005434907500	C85C0E	6227 052023	VIKTOR SIDOROV	{"email": "vsidorov.1966@postgrespro.ru", "phone": "+70728610402"}
0005434907501	88B964	0534 331586	ILYA FILIPPOV	{"phone": "+70462959053"}
0005434907502	3D1993	8878 998745	ROMAN ZHUKOV	{"phone": "+70798617209"}
0005434907503	431E69	3513 313701	ROMAN BARANOV	{"phone": "+70219231031"}
0005434907504	431E69	8355 501352	VALENTINA DENISOVA	{"phone": "+70442194497"}
0005434907505	431E69	1164 605932	VYACHESLAV KONOVALOV	{"email": "konovalov_v_02061996@postgrespro.ru", "phone": "+70710927731"}
0005434907506	A78B8E	8656 833088	MAKSIM BONDARENKO	{"email": "bondarenkom_18111983@postgrespro.ru", "phone": "+70294743729"}
0005434907507	B34B89	8786 782139	FEDOR GORBUNOV	{"email": "gorbunov.f.15121968@postgrespro.ru", "phone": "+70157693997"}
0005434907508	47FB00	5214 826036	KONSTANTIN PETROV	{"email": "k-petrov1969@postgrespro.ru", "phone": "+70525639532"}
0005434907509	93354A	3275 529251	RAISA DENISOVA	{"phone": "+70140741894"}
0005434907510	988BFF	4486 195315	GALINA POPOVA	{"email": "popovag_1967@postgrespro.ru", "phone": "+70635136990"}
0005434907511	59AA84	3499 999428	DANIIL GERASIMOV	{"phone": "+70926488914"}
0005434907512	B16878	4800 469873	MAKSIM TIMOFEEV	{"email": "maksimtimofeev.02061974@postgrespro.ru", "phone": "+70278634781"}
0005434907513	F67CD6	9347 230266	ELVIRA EFREMOVA	{"phone": "+70582637888"}
0005434907514	1DBDD2	3414 288339	OLGA SOLOVEVA	{"email": "soloveva.o_22021977@postgrespro.ru", "phone": "+70645487142"}
0005434907515	1DBDD2	3444 998277	MAKSIM SCHERBAKOV	{"email": "maksimscherbakov_10091980@postgrespro.ru", "phone": "+70525914764"}
0005434907516	2525AF	5987 595170	DARINA YUDINA	{"email": "yudinadarina_111975@postgrespro.ru", "phone": "+70256663774"}
0005434907517	2525AF	8721 837854	VERA MEDVEDEVA	{"phone": "+70498229998"}
0005434907518	1A74E5	7030 227429	NADEZHDA DAVYDOVA	{"phone": "+70219656026"}
0005434907519	1A74E5	1083 865400	MARIYA ZAKHAROVA	{"email": "zakharova_m_1967@postgrespro.ru", "phone": "+70041255444"}
0005434907520	453F05	0006 461984	KRISTINA ORLOVA	{"email": "orlova.kristina-13061969@postgrespro.ru", "phone": "+70231067815"}
0005434907521	99BE4A	0913 223387	EKATERINA ARKHIPOVA	{"phone": "+70921562346"}
0005434907522	5AA390	4540 582725	ANDREY FROLOV	{"email": "frolov-a_101968@postgrespro.ru", "phone": "+70552850535"}
0005434907523	9B85A4	5665 305432	YULIYA ALEKSEEVA	{"phone": "+70247282244"}
0005434907524	987E94	4690 435740	SVETLANA FILIPPOVA	{"email": "s_filippova-23111973@postgrespro.ru", "phone": "+70491211824"}
0005434907525	987E94	5698 896380	TATYANA ARKHIPOVA	{"email": "t-arkhipova_031966@postgrespro.ru", "phone": "+70675733313"}
0005434907526	ACF627	1835 922237	ALINA SMIRNOVA	{"email": "a-smirnova11071975@postgrespro.ru", "phone": "+70216050579"}
0005434907527	D0FAC4	5970 621538	VERA SAVELEVA	{"email": "savelevav-26051966@postgrespro.ru", "phone": "+70529806809"}
0005434907528	D0FAC4	6131 266756	ALEKSEY BELOV	{"phone": "+70992851144"}
0005434907529	891BBB	3655 688688	NATALIYA PETROVA	{"phone": "+70540177472"}
0005434907530	EED08D	6744 139469	LIDIYA EGOROVA	{"email": "lidiya-egorova-01021963@postgrespro.ru", "phone": "+70416563410"}
0005434907531	EED08D	4850 637479	ALEKSANDR DAVYDOV	{"phone": "+70494049810"}
0005434907532	67D92E	0812 202788	VLADIMIR MAKAROV	{"email": "vmakarov_031972@postgrespro.ru", "phone": "+70904653166"}
0005434907533	67D92E	2464 167431	ANNA KUDRYASHOVA	{"email": "anna-kudryashova1979@postgrespro.ru", "phone": "+70608636056"}
0005434907534	A09AD3	7079 427892	YULIYA SOLOVEVA	{"phone": "+70342826802"}
0005434907535	7BB095	9580 197961	ELENA POPOVA	{"email": "popovae.08071971@postgrespro.ru", "phone": "+70865356845"}
0005434907536	E410B4	7507 438601	ANDREY OSIPOV	{"email": "a.osipov16021972@postgrespro.ru", "phone": "+70158046263"}
0005434907537	E410B4	5063 899088	MIKHAIL OSIPOV	{"email": "osipov_m.1969@postgrespro.ru", "phone": "+70094958728"}
0005434907538	721D10	2502 584659	ELENA ILINA	{"email": "ilina-e-051971@postgrespro.ru", "phone": "+70830506639"}
0005434907539	013513	6216 652462	OLEG ZHURAVLEV	{"phone": "+70144333553"}
0005434907540	013513	1850 643976	SVETLANA VLASOVA	{"email": "vlasova.svetlana-011978@postgrespro.ru", "phone": "+70191366411"}
0005434907541	70C60E	4849 354417	LEONID FILIPPOV	{"email": "filippovl.10071972@postgrespro.ru", "phone": "+70922177942"}
0005434907542	27282F	7962 704957	IGOR MEDVEDEV	{"phone": "+70735115595"}
0005434907543	27282F	1813 192161	LYUBOV ZAYCEVA	{"phone": "+70617643039"}
0005434907544	E82698	1545 779278	RUFINA DMITRIEVA	{"email": "dmitrieva-r_1977@postgrespro.ru", "phone": "+70911425396"}
0005434907545	E82698	7215 921428	ANASTASIYA KONOVALOVA	{"phone": "+70348730760"}
0005434907546	E82698	6281 256588	OLEG FEDOROV	{"phone": "+70784162745"}
0005434907547	7C682E	0997 066715	LYUDMILA FILIPPOVA	{"email": "filippova.l.28011963@postgrespro.ru", "phone": "+70922876091"}
0005434907548	7C682E	9268 153587	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr_1981@postgrespro.ru", "phone": "+70474405726"}
0005434907549	20743D	7885 166493	DMITRIY SOROKIN	{"email": "d.sorokin-061972@postgrespro.ru", "phone": "+70065625961"}
0005434907550	20743D	4513 857372	NINA KOMAROVA	{"phone": "+70939430371"}
0005434907551	D6A698	5340 848501	NADEZHDA ZAYCEVA	{"email": "zayceva.n1972@postgrespro.ru", "phone": "+70239618851"}
0005434907552	A6AD2D	6660 035750	KONSTANTIN NIKITIN	{"email": "konstantinnikitin.1968@postgrespro.ru", "phone": "+70926122780"}
0005434907553	A6AD2D	7571 350189	NATALIYA KOZLOVA	{"phone": "+70813945632"}
0005434907554	A6AD2D	9959 965654	ANNA MOISEEVA	{"email": "moiseevaanna.1965@postgrespro.ru", "phone": "+70243111298"}
0005434907555	48679D	4393 951473	ANTON ALEKSANDROV	{"email": "a.aleksandrov.11051969@postgrespro.ru", "phone": "+70722798673"}
0005434907556	152BEA	1791 707646	VITALIY MAKAROV	{"phone": "+70714721559"}
0005434907557	4897E0	5348 160545	SVETLANA ZAYCEVA	{"phone": "+70268387337"}
0005434907558	93D898	2774 718099	ALEKSEY GORBUNOV	{"phone": "+70605482042"}
0005434907559	93D898	6404 764033	VIKTOR KUZNECOV	{"phone": "+70326732301"}
0005434907560	76BCD6	5209 841586	ANNA KOROLEVA	{"phone": "+70840748115"}
0005434907561	C30B1B	3886 301320	VITALIY VASILEV	{"email": "v-vasilev_18121971@postgrespro.ru", "phone": "+70028349695"}
0005434907562	086209	0517 400999	LYUBOV KUZNECOVA	{"phone": "+70393014536"}
0005434907563	BF44C5	2056 341046	ALEKSANDR BARANOV	{"phone": "+70603352173"}
0005434907564	C5A000	5936 732123	NADEZHDA STEPANOVA	{"phone": "+70954453192"}
0005434907565	052D1D	9105 929267	MIKHAIL SOROKIN	{"phone": "+70085076353"}
0005434907566	5F6DB1	4859 154458	EVGENIYA MAKSIMOVA	{"phone": "+70787580876"}
0005434907567	5F6DB1	1769 539304	OLGA NIKITINA	{"phone": "+70422921156"}
0005434907568	3FC3FC	1109 941112	KRISTINA KUZNECOVA	{"phone": "+70090602180"}
0005434907569	11E32A	3336 022397	NATALYA NESTEROVA	{"phone": "+70852710940"}
0005434907570	EEEFC1	2885 410681	ANDREY IVANOV	{"phone": "+70239980594"}
0005434907571	71A680	2440 656401	EVGENIY FOMIN	{"phone": "+70546289646"}
0005434907572	71A680	0578 472557	DENIS KOZLOV	{"email": "d.kozlov-1967@postgrespro.ru", "phone": "+70131179752"}
0005434907573	4A0EAF	4952 317108	LYUDMILA ILINA	{"email": "l_ilina_1969@postgrespro.ru", "phone": "+70739356666"}
0005434907574	4A0EAF	4569 365141	DMITRIY FILIPPOV	{"email": "d-filippov.24031962@postgrespro.ru", "phone": "+70307666790"}
0005434907575	1D05D1	6654 410286	DARYA FROLOVA	{"phone": "+70919861368"}
0005434907576	AE4CB4	0929 205434	LARISA KOMAROVA	{"email": "lkomarova_1978@postgrespro.ru", "phone": "+70689005324"}
0005434907577	DBD9BC	5282 377939	ANASTASIYA KISELEVA	{"phone": "+70914619763"}
0005434907578	44F22A	7926 172399	ALEKSANDR MOROZOV	{"email": "a.morozov_1967@postgrespro.ru", "phone": "+70000579761"}
0005434907579	2BAB4E	7050 945954	ANVAR AFANASEV	{"email": "afanasevanvar_1978@postgrespro.ru", "phone": "+70455484921"}
0005434907580	6A7785	0102 130409	VITALIY VASILEV	{"phone": "+70830274801"}
0005434907581	E6900E	0549 279747	ALEKSANDR SOLOVEV	{"email": "solovev.a28121974@postgrespro.ru", "phone": "+70065055921"}
0005434907582	39FF8F	9223 297821	SHAVKAT ORLOV	{"phone": "+70515357430"}
0005434907583	39FF8F	5895 361561	VLADIMIR ABRAMOV	{"email": "v_abramov.1978@postgrespro.ru", "phone": "+70636380060"}
0005434907584	D301E2	8039 401179	ALEKSANDR VASILEV	{"email": "vasilev.a.1973@postgrespro.ru", "phone": "+70747030994"}
0005434907585	D569AA	9861 210403	NATALYA SAVELEVA	{"email": "saveleva_n1980@postgrespro.ru", "phone": "+70624423813"}
0005434907586	02B3C6	3013 459224	DMITRIY MIKHAYLOV	{"phone": "+70653593305"}
0005434907587	6E60C2	0768 097327	ELENA ZHUKOVA	{"phone": "+70742449674"}
0005434907588	F33480	2658 442667	MARINA FEDOROVA	{"phone": "+70915495844"}
0005434907589	7D4C17	3716 213468	ANNA PETROVA	{"email": "petrovaa-1976@postgrespro.ru", "phone": "+70458262499"}
0005434907590	7D4C17	8274 970280	NADEZHDA MOROZOVA	{"email": "morozova-n-22031960@postgrespro.ru", "phone": "+70899479634"}
0005434907591	9454F8	0086 870878	ANATOLIY FOMIN	{"email": "fomin-a.081972@postgrespro.ru", "phone": "+70498454811"}
0005434907592	9454F8	6259 929752	SERGEY BORISOV	{"email": "s.borisov_24121962@postgrespro.ru", "phone": "+70657121696"}
0005434907593	62C5B8	7998 346361	VALENTINA POPOVA	{"phone": "+70287568771"}
0005434907594	62C5B8	7911 523068	ALEKSANDR TIMOFEEV	{"phone": "+70810315207"}
0005434907595	2DCB43	8619 714095	EDUARD ZHUKOV	{"phone": "+70805858002"}
0005434907596	E93C33	7850 587271	MAKSIM FEDOTOV	{"email": "maksimfedotov_1965@postgrespro.ru", "phone": "+70786406611"}
0005434907597	4514AF	4064 970710	GALINA DENISOVA	{"phone": "+70252093586"}
0005434907598	D919B4	0639 871057	IRINA MEDVEDEVA	{"email": "irina_medvedeva081959@postgrespro.ru", "phone": "+70283117252"}
0005434907599	F4C8D0	7785 908884	ALEKSANDR TIKHONOV	{"phone": "+70455497958"}
0005434907600	B79D01	3868 517118	VALENTINA KUDRYASHOVA	{"email": "v_kudryashova-1980@postgrespro.ru", "phone": "+70020474955"}
0005434907601	B79D01	6382 892065	ALEKSANDR ALEKSEEV	{"email": "alekseev.a-1962@postgrespro.ru", "phone": "+70258060519"}
0005434907602	26B671	4487 581220	ANDREY KUZNECOV	{"email": "kuznecov_andrey_12011976@postgrespro.ru", "phone": "+70869475749"}
0005434907603	26B671	4506 206071	YURIY KUZMIN	{"email": "yuriy.kuzmin.1957@postgrespro.ru", "phone": "+70948175402"}
0005434907604	F244E0	4066 095036	GALINA KOZLOVA	{"email": "kozlova_galina1979@postgrespro.ru", "phone": "+70758865883"}
0005434907605	35FE5B	1367 526783	LYUDMILA GAVRILOVA	{"phone": "+70075056055"}
0005434907606	CF2F72	6280 672370	VALENTINA KAZAKOVA	{"email": "v_kazakova-081982@postgrespro.ru", "phone": "+70539273149"}
0005434907607	BE25AD	2323 207614	ANNA KONOVALOVA	{"phone": "+70814772804"}
0005434907608	51EF79	8734 595338	ALEKSEY PAVLOV	{"phone": "+70251708404"}
0005434907609	4DF581	2257 852372	ALEKSANDR EGOROV	{"phone": "+70403388395"}
0005434907610	8C9817	9091 140218	ELENA NOVIKOVA	{"email": "novikovaelena-1971@postgrespro.ru", "phone": "+70109539178"}
0005434907611	8C9817	0801 460156	VASILIY ISAEV	{"email": "isaev-v-091974@postgrespro.ru", "phone": "+70651118834"}
0005434907612	6EF16C	6088 923568	ZOYA SERGEEVA	{"phone": "+70012087216"}
0005434907613	5071E1	9969 495372	LIDIYA POLYAKOVA	{"email": "polyakovalidiya.071962@postgrespro.ru", "phone": "+70966729397"}
0005434907614	C62512	0588 728853	KSENIYA LOGINOVA	{"phone": "+70528366482"}
0005434907615	C62512	0736 541082	BORIS ZHUKOV	{"phone": "+70862189126"}
0005434907616	C3FBFE	1209 279450	VALENTINA DENISOVA	{"email": "denisova_valentina-111972@postgrespro.ru", "phone": "+70613377989"}
0005434907617	C3FBFE	8021 551509	YURIY VOLKOV	{"phone": "+70994554650"}
0005434907618	27F9F1	4493 366390	ALEKSANDR IVANOV	{"phone": "+70985532864"}
0005434907619	27F9F1	6534 501866	DARYA NESTEROVA	{"phone": "+70796222362"}
0005434907620	D76080	5910 519223	VALERIY SOLOVEV	{"email": "solovev-v_1970@postgrespro.ru", "phone": "+70961756526"}
0005434907621	B876CE	7673 714906	GALINA YAKOVLEVA	{"email": "yakovleva.galina.1982@postgrespro.ru", "phone": "+70538980021"}
0005434907622	B876CE	4193 652782	TAMARA PETROVA	{"email": "petrova-t-29011976@postgrespro.ru", "phone": "+70568708713"}
0005434907623	53BDFF	1729 529558	SVETLANA ISAEVA	{"phone": "+70762290607"}
0005434907624	973236	5757 180591	MARINA ORLOVA	{"email": "marina-orlova_19011960@postgrespro.ru", "phone": "+70287207367"}
0005434907625	973236	1473 222071	LIYA FILIPPOVA	{"phone": "+70942576833"}
0005434907626	F78739	3141 813738	IGOR KONOVALOV	{"phone": "+70466327893"}
0005434907627	B79F81	8747 910733	ROMAN GUSEV	{"email": "gusev-r041973@postgrespro.ru", "phone": "+70976325477"}
0005434907628	C0443D	4414 314696	SERGEY BONDARENKO	{"phone": "+70054113344"}
0005434907629	74425C	6908 057462	NATALYA KUZMINA	{"phone": "+70420626575"}
0005434907630	74425C	7574 055112	ELIZAVETA GRISHINA	{"email": "egrishina071988@postgrespro.ru", "phone": "+70617600387"}
0005434907631	7D46A9	1757 955111	VALENTINA LUKYANOVA	{"phone": "+70714489457"}
0005434907632	006885	4557 360844	MARIYA MAKSIMOVA	{"email": "maksimova.mariya_1961@postgrespro.ru", "phone": "+70231884091"}
0005434907633	006885	5633 608021	ILYA SOROKIN	{"phone": "+70520655675"}
0005434907634	68D1EF	6592 806074	ELENA MEDVEDEVA	{"phone": "+70507737992"}
0005434907635	68D1EF	3806 037198	EVGENIY OSIPOV	{"email": "osipovevgeniy031979@postgrespro.ru", "phone": "+70911684979"}
0005434907636	E3BDD4	6137 109829	EKATERINA VLASOVA	{"email": "vlasova_ekaterina-051974@postgrespro.ru", "phone": "+70841818093"}
0005434907637	3BA260	6933 912003	OLGA SERGEEVA	{"email": "olga.sergeeva_24031985@postgrespro.ru", "phone": "+70362498575"}
0005434907638	BE02C0	3794 967077	VLADIMIR ABRAMOV	{"phone": "+70904083160"}
0005434907639	D2CC01	7530 393901	VIKTOR PETROV	{"phone": "+70737041024"}
0005434907640	05F1F9	2872 788110	TATYANA MELNIKOVA	{"phone": "+70993840714"}
0005434907641	05F1F9	3513 447516	ZINAIDA ANTONOVA	{"email": "zinaida_antonova.1964@postgrespro.ru", "phone": "+70029622676"}
0005434907642	9ECA4D	6743 495599	VLADIMIR VOLKOV	{"phone": "+70932414807"}
0005434907643	9ECA4D	0583 922610	VLADIMIR RODIONOV	{"email": "v.rodionov_011974@postgrespro.ru", "phone": "+70062219233"}
0005434907644	332A8F	9545 469903	YURIY ANDREEV	{"email": "andreevyuriy-10021975@postgrespro.ru", "phone": "+70411605893"}
0005434907645	B00AF3	8317 230381	OLESYA NIKOLAEVA	{"email": "o.nikolaeva1959@postgrespro.ru", "phone": "+70498399351"}
0005434907646	B00AF3	5596 980370	ALEKSANDR FROLOV	{"phone": "+70921669714"}
0005434907647	4584B1	3346 357307	EVGENIYA KOROLEVA	{"email": "koroleva.e071974@postgrespro.ru", "phone": "+70976619832"}
0005434907648	6CA76C	9803 037750	ALEKSANDR ZAYCEV	{"email": "zaycev_a.1976@postgrespro.ru", "phone": "+70039640423"}
0005434907649	C2DE65	4562 501310	IRINA PETROVA	{"email": "petrova_i-011972@postgrespro.ru", "phone": "+70516086132"}
0005434907650	20699E	1851 554183	ANDREY NIKOLAEV	{"email": "andrey.nikolaev-16121970@postgrespro.ru", "phone": "+70477614307"}
0005434907651	F2DB09	0282 593948	NATALYA SIDOROVA	{"phone": "+70013709193"}
0005434907652	AEEE9E	3343 930729	LYUBOV BELOVA	{"email": "l-belova_111983@postgrespro.ru", "phone": "+70933773771"}
0005434907653	AEEE9E	8058 118189	YULIYA SEMENOVA	{"phone": "+70076455426"}
0005434907654	0D2AB6	0722 096588	VALERIY ANDREEV	{"phone": "+70719912052"}
0005434907655	03290F	6655 746863	ALEKSANDR IVANOV	{"phone": "+70343560641"}
0005434907656	81754F	2648 862377	STANISLAV SHEVCHENKO	{"email": "stanislav-shevchenko_121961@postgrespro.ru", "phone": "+70428996579"}
0005434907657	DEC3B9	7370 478032	TATYANA SEMENOVA	{"phone": "+70517277057"}
0005434907658	5DF7FA	3966 435196	RAISA GERASIMOVA	{"email": "r.gerasimova1966@postgrespro.ru", "phone": "+70289796962"}
0005434907659	5DF7FA	8113 219207	MARINA NIKOLAEVA	{"email": "m.nikolaeva09071958@postgrespro.ru", "phone": "+70418116799"}
0005434907660	FA3663	6054 758609	NATALIYA NOVIKOVA	{"phone": "+70364500008"}
0005434907661	FE1094	5380 618160	NIKOLAY KISELEV	{"phone": "+70799056119"}
0005434907662	FE1094	5766 549902	NIKOLAY IVANOV	{"email": "ivanov.nikolay_27121982@postgrespro.ru", "phone": "+70504837008"}
0005434907663	45D286	1983 725688	NATALYA YAKOVLEVA	{"phone": "+70513910160"}
0005434907664	124935	4737 774908	ARTEM IVANOV	{"email": "ivanov_artem24051967@postgrespro.ru", "phone": "+70292044240"}
0005434907665	45526F	3935 509103	NATALYA MAKAROVA	{"email": "makarova_natalya.081971@postgrespro.ru", "phone": "+70112930250"}
0005434907666	45526F	0626 724858	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr_1971@postgrespro.ru", "phone": "+70944714200"}
0005434907667	32905F	9924 826648	MARAT MOROZOV	{"email": "marat-morozov091984@postgrespro.ru", "phone": "+70431832010"}
0005434907668	C46DE9	5727 675892	GALINA ANISIMOVA	{"email": "anisimova.galina_16071970@postgrespro.ru", "phone": "+70615763182"}
0005434907669	C46DE9	1755 633984	VASILIY IVANOV	{"phone": "+70647082306"}
0005434907670	B99D63	3007 135267	DARYA LAZAREVA	{"email": "d-lazareva_101980@postgrespro.ru", "phone": "+70801505357"}
0005434907671	D442B0	1656 333929	NINA SOLOVEVA	{"email": "nina_soloveva_1970@postgrespro.ru", "phone": "+70391897492"}
0005434907672	BD596A	6094 225111	ROMAN BELOV	{"email": "r_belov-19021965@postgrespro.ru", "phone": "+70929986082"}
0005434907673	750C1E	0702 049082	NIKOLAY PETROV	{"phone": "+70880696571"}
0005434907674	D3D4FA	7422 715891	SVETLANA DENISOVA	{"email": "sdenisova_101974@postgrespro.ru", "phone": "+70984163071"}
0005434907675	AF86D2	3671 739745	GALINA KUZNECOVA	{"email": "kuznecova_galina.02101975@postgrespro.ru", "phone": "+70099267962"}
0005434907676	AF86D2	9775 162292	MIKHAIL SERGEEV	{"phone": "+70424456540"}
0005434907677	87D584	3769 159761	ROMAN MATVEEV	{"phone": "+70669240826"}
0005434907678	EDA231	6174 749997	SVETLANA IVANOVA	{"email": "ivanova-svetlana_1965@postgrespro.ru", "phone": "+70079466074"}
0005434907679	EDA231	1147 694024	NIKOLAY NIKOLAEV	{"phone": "+70892389228"}
0005434907680	FF46D5	7754 364445	IRINA YAKOVLEVA	{"email": "yakovleva.irina101976@postgrespro.ru", "phone": "+70899974063"}
0005434907681	57F779	4349 033740	NURIYA ZAKHAROVA	{"email": "zakharova_nuriya.061968@postgrespro.ru", "phone": "+70307035263"}
0005434907682	FAF019	2529 277602	VALERIY KONOVALOV	{"phone": "+70502670615"}
0005434907683	FAF019	1114 279653	MARIYA KRASNOVA	{"email": "krasnova_mariya_1971@postgrespro.ru", "phone": "+70264996800"}
0005434907684	D87387	4696 143592	ROMAN PETROV	{"email": "petrovr-09101975@postgrespro.ru", "phone": "+70162105343"}
0005434907685	036ED3	0192 516695	EVGENIY SIDOROV	{"phone": "+70408158077"}
0005434907686	92273F	4449 837044	VLADIMIR MAKAROV	{"email": "makarov.v-15031975@postgrespro.ru", "phone": "+70293596871"}
0005434907687	92273F	4249 682765	ILYA SOKOLOV	{"phone": "+70716744628"}
0005434907688	4C0882	1127 639211	FEDOR PAVLOV	{"phone": "+70279450091"}
0005434907689	D7D7A0	2828 028572	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-091978@postgrespro.ru", "phone": "+70500922657"}
0005434907690	D7D7A0	5621 367173	MAKSIM YAKOVLEV	{"email": "maksim-yakovlev-25061968@postgrespro.ru", "phone": "+70859686222"}
0005434907691	089BF1	4841 696221	YANA GUSEVA	{"phone": "+70416059891"}
0005434907692	6F88AD	6978 007568	TATYANA GAVRILOVA	{"email": "t.gavrilova_061973@postgrespro.ru", "phone": "+70112341926"}
0005434907693	6F88AD	9981 638167	DMITRIY NOVIKOV	{"phone": "+70169887134"}
0005434907694	9D1482	9186 486959	SERGEY NIKOLAEV	{"email": "s_nikolaev.011967@postgrespro.ru", "phone": "+70322394440"}
0005434907695	9D1482	8014 588734	MARIYA MOROZOVA	{"email": "morozova-mariya04021979@postgrespro.ru", "phone": "+70702108270"}
0005434907696	89C165	8588 111782	MARIYA NOVIKOVA	{"phone": "+70199094999"}
0005434907697	C0AFDD	3438 075202	YURIY GORBUNOV	{"email": "gorbunov.yuriy.011979@postgrespro.ru", "phone": "+70605185940"}
0005434907698	1951AA	4243 960884	VIKTOR VASILEV	{"email": "v-vasilev061965@postgrespro.ru", "phone": "+70349664209"}
0005434907699	9E108B	2199 557139	TATYANA ABRAMOVA	{"email": "tatyana.abramova-011959@postgrespro.ru", "phone": "+70183249908"}
0005434907700	9E108B	1796 602791	SVETLANA KOROLEVA	{"phone": "+70330169329"}
0005434907701	9E108B	3030 722084	NATALYA GERASIMOVA	{"email": "gerasimova-natalya_03091962@postgrespro.ru", "phone": "+70382024704"}
0005434907702	36F4DE	4562 219942	OLGA VOLKOVA	{"phone": "+70850070138"}
0005434907703	0630BA	8764 299513	GENNADIY BELOV	{"email": "gennadiy-belov.05081971@postgrespro.ru", "phone": "+70166931652"}
0005434907704	39A859	7227 214285	ELINA MOISEEVA	{"phone": "+70756580884"}
0005434907705	39A859	6938 779943	ALEKSANDR MAKSIMOV	{"email": "aleksandr.maksimov061974@postgrespro.ru", "phone": "+70834254502"}
0005434907706	39A859	8024 689418	EVGENIY KUZMIN	{"email": "e.kuzmin_051968@postgrespro.ru", "phone": "+70336113972"}
0005434907707	DB204D	9099 253163	VASILISA KOVALEVA	{"phone": "+70607193900"}
0005434907708	DB204D	3718 563646	ZOYA KALININA	{"phone": "+70957919025"}
0005434907709	D5306D	2929 568559	VIKTOR SOROKIN	{"email": "sorokin-v_19111977@postgrespro.ru", "phone": "+70331611555"}
0005434907710	2A0596	5812 627463	VIKTOR CHERNOV	{"email": "chernov_viktor021972@postgrespro.ru", "phone": "+70204010367"}
0005434907711	23BF55	1518 522613	KONSTANTIN OSIPOV	{"phone": "+70607259071"}
0005434907712	23BF55	0674 125722	LILIYA STEPANOVA	{"email": "stepanova_l_101975@postgrespro.ru", "phone": "+70543234851"}
0005434907713	23BF55	0796 034723	AZAT GAVRILOV	{"email": "a.gavrilov.18101969@postgrespro.ru", "phone": "+70328697236"}
0005434907714	3D17F8	5864 055744	OKSANA ALEKSANDROVA	{"email": "aleksandrova-oksana-071977@postgrespro.ru", "phone": "+70987863699"}
0005434907715	04B48A	6328 569130	POLINA ANDREEVA	{"phone": "+70484711013"}
0005434907716	6CBA09	8257 628914	YULIYA NIKITINA	{"email": "yuliya.nikitina-24081983@postgrespro.ru", "phone": "+70305588767"}
0005434907717	4D9491	6757 785762	NATALYA NAZAROVA	{"phone": "+70020309837"}
0005434907718	4D9491	4441 823056	IRINA ARKHIPOVA	{"email": "irina-arkhipova-14041977@postgrespro.ru", "phone": "+70137977595"}
0005434907719	4D9491	1108 568279	DMITRIY ILIN	{"email": "dmitriyilin.041965@postgrespro.ru", "phone": "+70049058651"}
0005434907720	2E359A	6428 363465	SERGEY STEPANOV	{"phone": "+70719460264"}
0005434907721	84EE02	1389 376864	OLGA YAKOVLEVA	{"email": "yakovleva_o-091970@postgrespro.ru", "phone": "+70057277241"}
0005434907722	84EE02	8566 655974	GLEB MARTYNOV	{"phone": "+70019350077"}
0005434907723	BD22A0	5829 627860	EKATERINA SMIRNOVA	{"email": "ekaterinasmirnova-18011976@postgrespro.ru", "phone": "+70115129196"}
0005434907724	CAB93C	9691 293396	SEMEN IVANOV	{"phone": "+70473529750"}
0005434907725	926B6D	2643 994165	OLGA IVANOVA	{"email": "olgaivanova_22051966@postgrespro.ru", "phone": "+70986438972"}
0005434907726	926B6D	6439 396434	IGOR ROMANOV	{"phone": "+70390998527"}
0005434907727	078B4E	7057 835117	ELIZAVETA FROLOVA	{"email": "frolova_e.081966@postgrespro.ru", "phone": "+70191412214"}
0005434907728	06CABA	3621 540427	ALEKSANDR MOISEEV	{"phone": "+70958944707"}
0005434907729	E88A71	5744 405647	ARKADIY MATVEEV	{"email": "matveev-arkadiy_1968@postgrespro.ru", "phone": "+70059006969"}
0005434907730	4BC450	0573 801074	IRAIDA YAKOVLEVA	{"email": "yakovlevairaida-1974@postgrespro.ru", "phone": "+70990466603"}
0005434907731	0C16F5	2977 940497	NIKOLAY PETROV	{"phone": "+70862393746"}
0005434907732	9CDD31	8197 761343	IGOR KOZLOV	{"email": "kozlovi-071974@postgrespro.ru", "phone": "+70247199350"}
0005434907733	9CDD31	6602 282620	LYUDMILA EGOROVA	{"phone": "+70310568987"}
0005434907734	9CDD31	2453 043188	SERGEY BARANOV	{"email": "s-baranov.041967@postgrespro.ru", "phone": "+70497446097"}
0005434907735	7075DD	7872 645765	RAVIL SOROKIN	{"phone": "+70926989765"}
0005434907736	5BEA01	2931 441321	OLGA ZHUKOVA	{"email": "o-zhukova.1974@postgrespro.ru", "phone": "+70149171218"}
0005434907737	66C8BF	6432 850840	ANNA SOKOLOVA	{"email": "sokolova_a_07031963@postgrespro.ru", "phone": "+70343941411"}
0005434907738	E70015	4579 153013	NIKOLAY ALEKSEEV	{"phone": "+70858272696"}
0005434907739	C66F2C	5343 289299	VALERIY SHEVCHENKO	{"email": "shevchenko.v.051986@postgrespro.ru", "phone": "+70126125647"}
0005434907740	C66F2C	0640 953346	ALEKSEY TARASOV	{"phone": "+70412897819"}
0005434907741	57F01C	0511 569332	ANDREY KUZNECOV	{"email": "a.kuznecov.051963@postgrespro.ru", "phone": "+70957398188"}
0005434907742	267AC4	2832 296969	LIDIYA ZAYCEVA	{"phone": "+70910369031"}
0005434907743	C14C01	4122 391465	VALENTINA SCHERBAKOVA	{"phone": "+70810253793"}
0005434907744	C14C01	6265 047412	YULIYA POPOVA	{"phone": "+70637264349"}
0005434907745	04102C	5984 034828	TATYANA MELNIKOVA	{"email": "t-melnikova-1987@postgrespro.ru", "phone": "+70758742215"}
0005434907746	E30C30	9175 922064	ALEKSANDR ZAYCEV	{"email": "a-zaycev-041973@postgrespro.ru", "phone": "+70003368434"}
0005434907747	DD5558	9198 236038	NADEZHDA DMITRIEVA	{"email": "dmitrieva_n-30081975@postgrespro.ru", "phone": "+70909592719"}
0005434907748	DD5558	3160 895400	ANATOLIY SEMENOV	{"phone": "+70870336282"}
0005434907749	DD5558	4003 451478	RUSLAN IVANOV	{"phone": "+70153714149"}
0005434907750	6D5266	1849 442033	VLADIMIR MIKHAYLOV	{"email": "mikhaylov-v-071976@postgrespro.ru", "phone": "+70509739215"}
0005434907751	7799EB	5874 608599	VALENTINA KRASNOVA	{"email": "krasnova.v08121984@postgrespro.ru", "phone": "+70714775909"}
0005434907752	3DD68C	5996 348849	VIKTOR FROLOV	{"phone": "+70160223308"}
0005434907753	3DD68C	2967 019537	ANGELINA ANDREEVA	{"email": "andreeva-angelina-24081965@postgrespro.ru", "phone": "+70685023759"}
0005434907754	39828E	6852 892986	TAMARA ZAKHAROVA	{"phone": "+70320443750"}
0005434907755	39828E	5080 430321	ALEKSANDR OSIPOV	{"phone": "+70053251042"}
0005434907756	39828E	8689 871968	ANDREY VLASOV	{"phone": "+70142936938"}
0005434907757	A3D174	5145 024591	LIDIYA OSIPOVA	{"phone": "+70336446192"}
0005434907758	FB94DF	5712 508239	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov_061977@postgrespro.ru", "phone": "+70007190227"}
0005434907759	23BBAD	7999 552414	ARTEM CHERNOV	{"phone": "+70087366319"}
0005434907760	23BBAD	8137 682322	TATYANA NAUMOVA	{"phone": "+70435766111"}
0005434907761	93A50C	0979 206048	IRINA KARPOVA	{"email": "irina.karpova.071969@postgrespro.ru", "phone": "+70869439636"}
0005434907762	589985	7146 002516	SERGEY STEPANOV	{"phone": "+70903225383"}
0005434907763	BA86B4	3745 543115	NIKOLAY BONDARENKO	{"email": "bondarenko_n.21101977@postgrespro.ru", "phone": "+70452077153"}
0005434907764	BA86B4	9249 370168	NATALYA EGOROVA	{"phone": "+70548504532"}
0005434907765	BA86B4	7132 236966	TAMARA ISAEVA	{"email": "isaeva.tamara1974@postgrespro.ru", "phone": "+70351484927"}
0005434907766	B9601A	3220 710473	VLADIMIR SOROKIN	{"phone": "+70259264249"}
0005434907767	B9601A	8969 328695	FEDOR FEDOROV	{"email": "fedorov_f_19061973@postgrespro.ru", "phone": "+70276494291"}
0005434907768	7C7295	6155 241421	SERGEY MAKAROV	{"email": "makarov_sergey_061982@postgrespro.ru", "phone": "+70734983695"}
0005434907769	63F40E	3964 378138	OLEG KARPOV	{"phone": "+70442409461"}
0005434907770	63F40E	3118 944455	GULSINA KISELEVA	{"email": "gkiseleva_28011971@postgrespro.ru", "phone": "+70016185237"}
0005434907771	8F8A40	3609 992652	EVGENIYA CHERNOVA	{"phone": "+70209087715"}
0005434907772	F4E599	2755 203605	OLGA NIKOLAEVA	{"phone": "+70909059593"}
0005434907773	6D6E53	8450 971142	ALEKSANDR ISAEV	{"email": "aleksandrisaev1972@postgrespro.ru", "phone": "+70991319971"}
0005434907774	67FE52	8798 541362	ROMAN NAZAROV	{"phone": "+70046110033"}
0005434907775	C4B5FF	8712 776837	TATYANA SERGEEVA	{"email": "sergeeva_t_22041972@postgrespro.ru", "phone": "+70256152013"}
0005434907776	3F0698	3536 125257	ELENA PETROVA	{"phone": "+70336983894"}
0005434907777	7729A0	1618 269952	IRINA KUZMINA	{"email": "kuzmina-i_04031968@postgrespro.ru", "phone": "+70923713518"}
0005434907778	9F022D	2491 265369	OKSANA SOKOLOVA	{"email": "o_sokolova-101974@postgrespro.ru", "phone": "+70828621199"}
0005434907779	7093FB	3532 770053	SERGEY IVANOV	{"email": "ivanov.s1988@postgrespro.ru", "phone": "+70607377793"}
0005434907780	7093FB	9850 011921	MARIYA KUZMINA	{"email": "mariyakuzmina031973@postgrespro.ru", "phone": "+70278379718"}
0005434907781	93B156	5737 323262	VLADIMIR EGOROV	{"email": "vladimir_egorov_011974@postgrespro.ru", "phone": "+70311286805"}
0005434907782	D7167D	8388 279218	TIMUR KUDRYASHOV	{"email": "timur.kudryashov_13061968@postgrespro.ru", "phone": "+70293259041"}
0005434907783	C3F37A	0147 734665	ALINA MAKAROVA	{"email": "makarova-alina-121974@postgrespro.ru", "phone": "+70164484428"}
0005434907784	569599	3248 567672	SERGEY IVANOV	{"phone": "+70721676400"}
0005434907785	569599	8220 825569	NINA KUZMINA	{"email": "kuzmina_n-111966@postgrespro.ru", "phone": "+70460051983"}
0005434907786	569599	8076 656576	ALEKSANDR MAKAROV	{"phone": "+70922800663"}
0005434907787	D9E657	3471 074821	ALINA KUZNECOVA	{"email": "kuznecova_alina-081973@postgrespro.ru", "phone": "+70767941096"}
0005434907788	D9E657	3133 732342	ANGELINA ABRAMOVA	{"email": "a-abramova_1983@postgrespro.ru", "phone": "+70876890581"}
0005434907789	689401	9109 516207	GALINA ZAKHAROVA	{"email": "g.zakharova-15051969@postgrespro.ru", "phone": "+70279599203"}
0005434907790	17D75F	9437 772683	NATALYA SCHERBAKOVA	{"phone": "+70456700614"}
0005434907791	F83956	1812 766832	SERGEY ZHUKOV	{"phone": "+70284952800"}
0005434907792	3F5192	4732 383963	LIDIYA IVANOVA	{"email": "l_ivanova1976@postgrespro.ru", "phone": "+70204736639"}
0005434907793	3B0AD9	5765 474616	RAISA VLASOVA	{"email": "vlasova_raisa-021971@postgrespro.ru", "phone": "+70973119332"}
0005434907794	553C10	7316 195649	SERGEY KONOVALOV	{"phone": "+70720274474"}
0005434907795	57C33A	7566 776071	YULIYA TIKHONOVA	{"email": "tikhonova.y.01031971@postgrespro.ru", "phone": "+70632249949"}
0005434907796	57C33A	2838 200193	VLADIMIR TIKHONOV	{"phone": "+70461787038"}
0005434907797	7E5454	1217 223277	ANDREY SOKOLOV	{"email": "sokolov-a-30061973@postgrespro.ru", "phone": "+70999981010"}
0005434907798	CF835E	1591 530056	VALERIY KUZMIN	{"phone": "+70357307673"}
0005434907799	E6DC19	9868 487114	SERGEY DMITRIEV	{"email": "dmitriev_s-071971@postgrespro.ru", "phone": "+70994360718"}
0005434907800	E6DC19	3430 738905	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova031973@postgrespro.ru", "phone": "+70042992624"}
0005434907801	313CE7	3633 003245	ALEKSANDR NIKOLAEV	{"phone": "+70349111437"}
0005434907802	313CE7	2947 491667	SERAFIMA IVANOVA	{"phone": "+70140727890"}
0005434907803	B231FB	1068 774289	ALEKSANDR ZAKHAROV	{"email": "aleksandr.zakharov-101965@postgrespro.ru", "phone": "+70295062373"}
0005434907804	EA8AA7	3917 337826	ELENA KOROLEVA	{"email": "koroleva_elena-14031960@postgrespro.ru", "phone": "+70341235141"}
0005434907805	E23B3C	4592 647964	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr.02091968@postgrespro.ru", "phone": "+70542824293"}
0005434907806	BA4D29	9435 247684	EGOR OSIPOV	{"phone": "+70960766471"}
0005434907807	045C9B	8200 276800	GALINA YUDINA	{"email": "g-yudina051963@postgrespro.ru", "phone": "+70717646095"}
0005434907808	E5E308	0852 910354	IRINA VOROBEVA	{"email": "irina.vorobeva_1976@postgrespro.ru", "phone": "+70928085241"}
0005434907809	E5E308	4008 294466	TATYANA FEDOROVA	{"phone": "+70477027130"}
0005434907810	6340EF	7014 353425	KIRILL TIMOFEEV	{"phone": "+70964122809"}
0005434907811	7D19D2	3573 249965	NADEZHDA POPOVA	{"email": "nadezhda-popova-051983@postgrespro.ru", "phone": "+70124509810"}
0005434907812	7D19D2	1788 389550	LYUDMILA OSIPOVA	{"email": "osipovalyudmila_041964@postgrespro.ru", "phone": "+70039617066"}
0005434907813	B94042	5587 507963	ELENA ZAYCEVA	{"email": "e.zayceva_1977@postgrespro.ru", "phone": "+70496077778"}
0005434907814	8F0859	8299 253670	NIKOLAY MAKAROV	{"email": "nmakarov-031973@postgrespro.ru", "phone": "+70076807606"}
0005434907815	8F0859	0346 689480	ELENA KOZLOVA	{"phone": "+70766637251"}
0005434907816	23AC79	9576 766089	SOFYA KOVALEVA	{"email": "sofya.kovaleva-05091977@postgrespro.ru", "phone": "+70517706268"}
0005434907817	74E6AF	1779 005754	IRINA KAZAKOVA	{"email": "i-kazakova_091971@postgrespro.ru", "phone": "+70344630228"}
0005434907818	972711	4236 022445	OLGA SERGEEVA	{"email": "o-sergeeva-1980@postgrespro.ru", "phone": "+70187830018"}
0005434907819	6A7645	5768 983856	VALENTINA CHERNOVA	{"email": "v.chernova_121981@postgrespro.ru", "phone": "+70489027340"}
0005434907820	FCDDC6	3885 601120	PAVEL MIRONOV	{"phone": "+70727041008"}
0005434907821	05F262	2702 126204	VYACHESLAV SOLOVEV	{"email": "solovev_vyacheslav.1968@postgrespro.ru", "phone": "+70106159494"}
0005434907822	05F262	8291 083097	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-e1968@postgrespro.ru", "phone": "+70131141728"}
0005434907823	81DB68	6547 973784	ALEKSEY SOLOVEV	{"phone": "+70707889700"}
0005434907824	81DB68	7440 749000	LILIYA SCHERBAKOVA	{"email": "liliyascherbakova.111968@postgrespro.ru", "phone": "+70101421651"}
0005434907825	11A2EB	9725 130292	MARIYA VLASOVA	{"email": "mariyavlasova-1976@postgrespro.ru", "phone": "+70092491298"}
0005434907826	11A2EB	8745 406618	NINA TITOVA	{"phone": "+70827504490"}
0005434907827	355BFF	7379 759098	SERGEY SEMENOV	{"email": "sergey-semenov_1966@postgrespro.ru", "phone": "+70621240756"}
0005434907886	1225CA	8882 615084	ANASTASIYA KUZMINA	{"phone": "+70525202112"}
0005434907828	3BAD8F	1786 633230	SVETLANA BORISOVA	{"email": "svetlana_borisova.1973@postgrespro.ru", "phone": "+70617992979"}
0005434907829	11DFF0	3300 617264	VALENTINA MOISEEVA	{"phone": "+70873805812"}
0005434907830	11DFF0	6730 353153	IVAN MAKSIMOV	{"email": "i_maksimov-06011978@postgrespro.ru", "phone": "+70001548440"}
0005434907831	7CFAB1	8629 860080	MARINA BELOVA	{"email": "belova-marina04071970@postgrespro.ru", "phone": "+70745505010"}
0005434907832	923A63	3706 439159	EKATERINA LEBEDEVA	{"email": "e-lebedeva-05061975@postgrespro.ru", "phone": "+70765150567"}
0005434907833	A6F079	1077 264563	EVGENIY NOVIKOV	{"phone": "+70402986260"}
0005434907834	A6F079	5383 728180	STANISLAV ANDREEV	{"email": "stanislavandreev01091968@postgrespro.ru", "phone": "+70259153962"}
0005434907835	A6F079	5107 004363	NIKOLAY GORBUNOV	{"phone": "+70130847389"}
0005434907836	A6F079	0040 992686	VLADISLAV SMIRNOV	{"phone": "+70095857050"}
0005434907837	7A1372	4699 952596	VASILIY IVANOV	{"email": "vasiliy-ivanov051964@postgrespro.ru", "phone": "+70010289793"}
0005434907838	7A1372	7024 058743	MARINA ORLOVA	{"phone": "+70123923209"}
0005434907839	7A1372	3934 426253	YULIYA NAUMOVA	{"phone": "+70831135749"}
0005434907840	FD3E2B	1522 095164	OLGA GUSEVA	{"email": "olga.guseva12061957@postgrespro.ru", "phone": "+70572425688"}
0005434907841	FD3E2B	3737 347169	ALEKSEY AFANASEV	{"phone": "+70190640478"}
0005434907842	2BB16C	0477 360479	ALEKSANDR NIKITIN	{"email": "a.nikitin121964@postgrespro.ru", "phone": "+70942824472"}
0005434907843	2BB16C	3483 794087	MIKHAIL FOMIN	{"email": "m-fomin_1964@postgrespro.ru", "phone": "+70164449207"}
0005434907844	B053A7	6581 167596	ILYA DAVYDOV	{"email": "davydov.ilya-101971@postgrespro.ru", "phone": "+70111388441"}
0005434907845	5200B1	8093 887209	YULIYA KOROLEVA	{"phone": "+70535620663"}
0005434907846	96F715	8610 192536	POLINA KULIKOVA	{"email": "p_kulikova.051969@postgrespro.ru", "phone": "+70677864182"}
0005434907847	96F715	9025 090978	VYACHESLAV SOROKIN	{"email": "vsorokin_1962@postgrespro.ru", "phone": "+70726466621"}
0005434907848	5231F7	0353 759497	ALEKSANDR VASILEV	{"email": "vasilev_a_31011971@postgrespro.ru", "phone": "+70777885557"}
0005434907849	E691C5	8587 963908	IVAN KISELEV	{"phone": "+70061399316"}
0005434907850	6F537C	5732 256554	TATYANA MIKHAYLOVA	{"phone": "+70419676851"}
0005434907851	1A49CA	4674 885897	ANATOLIY STEPANOV	{"email": "a-stepanov-1977@postgrespro.ru", "phone": "+70383073729"}
0005434907852	1A49CA	6173 141187	SVETLANA ANTONOVA	{"email": "santonova_12041977@postgrespro.ru", "phone": "+70898176081"}
0005434907853	1A49CA	8928 210533	ADELINA ZAYCEVA	{"email": "zayceva.adelina.18051967@postgrespro.ru", "phone": "+70743966017"}
0005434907854	977343	0700 766803	NIKOLAY GAVRILOV	{"phone": "+70145753681"}
0005434907855	977343	0647 186334	GALINA VASILEVA	{"email": "g.vasileva071965@postgrespro.ru", "phone": "+70081336528"}
0005434907856	977343	0146 577674	EVGENIY NAZAROV	{"email": "evgeniy-nazarov_1969@postgrespro.ru", "phone": "+70927650256"}
0005434907857	5ED2ED	9619 455100	BULAT ZAKHAROV	{"phone": "+70390948378"}
0005434907858	F0C098	9863 086156	IRINA MIKHAYLOVA	{"phone": "+70354733778"}
0005434907859	A90BDE	3195 255696	MIKHAIL MIKHAYLOV	{"phone": "+70237167787"}
0005434907860	6A470C	5945 802356	KSENIYA VOROBEVA	{"phone": "+70152880669"}
0005434907861	0F40C7	6385 309238	LYUBOV YUDINA	{"email": "l_yudina121971@postgrespro.ru", "phone": "+70078071803"}
0005434907862	69BF95	0192 055899	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov.08021967@postgrespro.ru", "phone": "+70679640270"}
0005434907863	14C629	3311 311402	YURIY ZAYCEV	{"phone": "+70675668870"}
0005434907864	9F791C	1847 986229	GULSINA ZHUKOVA	{"phone": "+70145711553"}
0005434907865	0E8F71	5565 545027	ALEKSANDRA MATVEEVA	{"phone": "+70941858537"}
0005434907866	F9983E	1561 313783	ARTEM VASILEV	{"email": "vasilevartem.20061960@postgrespro.ru", "phone": "+70435778954"}
0005434907867	F9983E	6080 870092	LIDIYA SOKOLOVA	{"email": "lidiya-sokolova-20011973@postgrespro.ru", "phone": "+70574664957"}
0005434907868	6448A5	0249 537417	VLADISLAV NAZAROV	{"email": "vladislav-nazarov-28021977@postgrespro.ru", "phone": "+70386082198"}
0005434907869	2AB977	2409 256503	VALENTINA VOLKOVA	{"phone": "+70643330508"}
0005434907870	FEB95B	3048 970730	OLGA POPOVA	{"email": "o_popova.08091968@postgrespro.ru", "phone": "+70363021105"}
0005434907871	FEB95B	9293 098328	LYUDMILA MEDVEDEVA	{"phone": "+70763402466"}
0005434907872	3DDE62	7113 638998	MAKSIM ILIN	{"phone": "+70440180311"}
0005434907873	8DCCEF	8649 287243	TATYANA IVANOVA	{"email": "tatyanaivanova.10121984@postgrespro.ru", "phone": "+70507822032"}
0005434907929	239AFB	0402 028481	VALENTINA NAZAROVA	{"phone": "+70575999573"}
0005434907874	59FE39	6030 438294	MILANA GERASIMOVA	{"email": "m_gerasimova-091972@postgrespro.ru", "phone": "+70882186963"}
0005434907875	59FE39	9956 363064	NIKOLAY KISELEV	{"email": "kiselev.nikolay10101961@postgrespro.ru", "phone": "+70491505066"}
0005434907876	59FE39	7606 343291	YANA DENISOVA	{"phone": "+70749813881"}
0005434907877	A5CD79	1824 355224	TATYANA PETROVA	{"email": "petrova.tatyana_1967@postgrespro.ru", "phone": "+70824156769"}
0005434907878	0090C4	8895 688295	EKATERINA KONOVALOVA	{"phone": "+70242819272"}
0005434907879	0090C4	0423 086013	EVGENIYA VOLKOVA	{"email": "volkova-evgeniya28071971@postgrespro.ru", "phone": "+70785348879"}
0005434907880	4A2FC4	8958 354308	ELIZAVETA POPOVA	{"email": "popova-elizaveta061965@postgrespro.ru", "phone": "+70348237220"}
0005434907881	4A2FC4	3245 534912	OLEG EGOROV	{"phone": "+70491139490"}
0005434907882	7BDB9D	1494 509885	SVETLANA NOVIKOVA	{"email": "novikova.s1978@postgrespro.ru", "phone": "+70386523078"}
0005434907883	447AAE	8537 795397	ZOYA YAKOVLEVA	{"email": "z-yakovleva.01071965@postgrespro.ru", "phone": "+70008212337"}
0005434907884	BBE32A	2335 698246	ELIZAVETA ERMAKOVA	{"phone": "+70741412227"}
0005434907885	BBE32A	6219 593386	KONSTANTIN SEMENOV	{"email": "k_semenov-1961@postgrespro.ru", "phone": "+70799636598"}
0005434907887	1225CA	3015 012314	PETR SCHERBAKOV	{"email": "p-scherbakov_1970@postgrespro.ru", "phone": "+70221927672"}
0005434907888	22B2CE	0790 004575	SVETLANA NIKIFOROVA	{"email": "nikiforova_s_041974@postgrespro.ru", "phone": "+70751637528"}
0005434907889	22B2CE	6739 571580	SERGEY MAKAROV	{"phone": "+70279229117"}
0005434907890	22B2CE	0142 013780	ILYA VASILEV	{"email": "i-vasilev_061975@postgrespro.ru", "phone": "+70939468520"}
0005434907891	22B2CE	9714 755071	VALERIYA POLYAKOVA	{"phone": "+70816682414"}
0005434907892	AD1769	7473 954917	ANNA SOKOLOVA	{"email": "asokolova_02111980@postgrespro.ru", "phone": "+70055866992"}
0005434907893	AD1769	3888 257225	PETR POPOV	{"phone": "+70187766746"}
0005434907894	04F4D4	8576 527278	YURIY ZAKHAROV	{"email": "zakharov_yuriy.051980@postgrespro.ru", "phone": "+70083154713"}
0005434907895	04F4D4	6203 039749	ELENA KAZAKOVA	{"phone": "+70336003585"}
0005434907896	4358E8	5561 989353	ALEKSANDR CHERNOV	{"phone": "+70424181262"}
0005434907897	BC8AD2	1858 449719	OKSANA SOKOLOVA	{"email": "oksana_sokolova.13121974@postgrespro.ru", "phone": "+70037006786"}
0005434907898	BD85AE	7557 455601	VALENTINA BELOVA	{"email": "vbelova-061967@postgrespro.ru", "phone": "+70922621516"}
0005434907899	BD85AE	1237 730468	ALEKSEY YAKOVLEV	{"email": "yakovlevaleksey.091970@postgrespro.ru", "phone": "+70547404430"}
0005434907900	BD85AE	9355 032669	DMITRIY CHERNOV	{"email": "chernov.d_111974@postgrespro.ru", "phone": "+70863942221"}
0005434907901	141101	9119 742654	SHAMIL FOMIN	{"email": "sfomin16041964@postgrespro.ru", "phone": "+70551511069"}
0005434907902	141101	1239 944981	VALERIY ANDREEV	{"email": "andreev-valeriy30041966@postgrespro.ru", "phone": "+70002337005"}
0005434907903	E2D0FC	9628 185784	NATALYA NIKOLAEVA	{"phone": "+70273631483"}
0005434907904	CF05AE	2041 360429	NIKOLAY ZAKHAROV	{"phone": "+70631808450"}
0005434907905	BEEDB3	4198 354843	SVETLANA SOLOVEVA	{"email": "soloveva_svetlana071974@postgrespro.ru", "phone": "+70895927031"}
0005434907906	21CE04	1802 001498	SERGEY BONDARENKO	{"phone": "+70465518159"}
0005434907907	95B65E	3581 716729	ANDREY BORISOV	{"phone": "+70477095564"}
0005434907908	30A157	3570 132028	EVGENIY TIKHONOV	{"phone": "+70419441710"}
0005434907909	30A157	5025 335289	MIKHAIL SOROKIN	{"email": "sorokin-mikhail_29031974@postgrespro.ru", "phone": "+70136379740"}
0005434907910	97A8E0	4577 575600	ELENA AFANASEVA	{"email": "elena.afanaseva.1968@postgrespro.ru", "phone": "+70618292391"}
0005434907911	FADBF9	5874 161009	MARIYA KUZNECOVA	{"phone": "+70657371287"}
0005434907912	4F2361	5020 348645	INNA NOVIKOVA	{"email": "i_novikova-1979@postgrespro.ru", "phone": "+70020888659"}
0005434907913	F2FB16	6483 201990	VALERIY SOLOVEV	{"email": "valeriy.solovev_071963@postgrespro.ru", "phone": "+70255389129"}
0005434907914	88A018	4241 256198	VERONIKA ABRAMOVA	{"email": "abramova-veronika1970@postgrespro.ru", "phone": "+70751048123"}
0005434907915	CB9091	5848 000322	GALINA YUDINA	{"phone": "+70358783385"}
0005434907916	CB9091	8721 428832	ALEKSANDR EGOROV	{"email": "aleksandregorov_05061971@postgrespro.ru", "phone": "+70090269114"}
0005434907917	E4BE08	6750 575949	KSENIYA BELYAEVA	{"email": "kbelyaeva1964@postgrespro.ru", "phone": "+70570593353"}
0005434907918	7497D8	2419 180913	ALEKSANDR ABRAMOV	{"phone": "+70327138575"}
0005434907919	7497D8	5828 514553	LYUBOV BELOVA	{"phone": "+70299179011"}
0005434907920	D9B6E8	6279 307285	LYUBOV STEPANOVA	{"phone": "+70298053846"}
0005434907921	858BC7	8598 303330	OLEG SHEVCHENKO	{"email": "o-shevchenko_1979@postgrespro.ru", "phone": "+70066604379"}
0005434907922	858BC7	8824 513456	LILIYA KOZLOVA	{"email": "kozlova.liliya-23031964@postgrespro.ru", "phone": "+70357948829"}
0005434907923	858BC7	6028 337764	POLINA KUZNECOVA	{"email": "kuznecovapolina021976@postgrespro.ru", "phone": "+70472093735"}
0005434907924	AF843A	9003 887848	INNA ZOTOVA	{"email": "i-zotova.051969@postgrespro.ru", "phone": "+70004384189"}
0005434907925	A7BE7F	0293 213488	ZINAIDA ROMANOVA	{"email": "romanova.z_051980@postgrespro.ru", "phone": "+70707681212"}
0005434907926	A7BE7F	6897 456532	KARINA MIKHAYLOVA	{"phone": "+70020022936"}
0005434907927	4BAABE	4573 552698	RASHID MAKSIMOV	{"email": "rashid_maksimov.021967@postgrespro.ru", "phone": "+70865162082"}
0005434907928	4BAABE	4815 732935	IRINA MOROZOVA	{"email": "i.morozova.1969@postgrespro.ru", "phone": "+70602732175"}
0005434907930	239AFB	7866 768634	ALEKSEY KUZMIN	{"phone": "+70298200921"}
0005434907931	68F48B	8552 404092	RADMIR RODIONOV	{"phone": "+70071315723"}
0005434907932	168D8F	9434 987007	TATYANA POPOVA	{"email": "popova.t24071967@postgrespro.ru", "phone": "+70830127406"}
0005434907933	C31793	2015 256683	DENIS SAVELEV	{"phone": "+70150135442"}
0005434907934	21EA86	5207 225740	TAMARA NESTEROVA	{"phone": "+70997310194"}
0005434907935	DBAA01	7688 943847	VALERIY MOISEEV	{"email": "moiseevv-1970@postgrespro.ru", "phone": "+70985767135"}
0005434907936	DBAA01	0937 581621	EVGENIY IVANOV	{"email": "eivanov_05121966@postgrespro.ru", "phone": "+70088745457"}
0005434907937	750245	1830 674717	VYACHESLAV NIKITIN	{"phone": "+70902941308"}
0005434907938	1E8BA2	7557 934212	VLADIMIR TIMOFEEV	{"phone": "+70941308243"}
0005434907939	1E8BA2	1746 591848	SERGEY NIKITIN	{"email": "nikitin_s111970@postgrespro.ru", "phone": "+70701018022"}
0005434907940	CA2DB2	3497 903541	INESSA MELNIKOVA	{"email": "melnikova-inessa16031977@postgrespro.ru", "phone": "+70879829836"}
0005434907941	CA2DB2	9953 222951	EKATERINA KULIKOVA	{"phone": "+70326536067"}
0005434907942	1A6B3D	9796 609865	IRINA MALYSHEVA	{"phone": "+70194555734"}
0005434907943	1A6B3D	0455 242388	ELENA VOROBEVA	{"phone": "+70383689003"}
0005434907944	FDEFB6	2523 620180	IRINA SOKOLOVA	{"email": "sokolova-irina_101969@postgrespro.ru", "phone": "+70620001276"}
0005434907945	510D55	6280 865644	DMITRIY SHEVCHENKO	{"phone": "+70401543218"}
0005434907946	23250D	1724 211542	ELENA ANTONOVA	{"email": "antonova-elena.021975@postgrespro.ru", "phone": "+70611546784"}
0005434907947	23250D	2140 362149	NIKOLAY MIKHAYLOV	{"email": "nikolaymikhaylov_071967@postgrespro.ru", "phone": "+70215923104"}
0005434907948	69EF81	2367 288366	ALEKSANDR PETROV	{"email": "aleksandr_petrov.28051970@postgrespro.ru", "phone": "+70083072729"}
0005434907949	18440F	4918 518240	MIKHAIL SOKOLOV	{"phone": "+70408608896"}
0005434907950	2EE510	7718 039479	LILIYA FOMINA	{"phone": "+70348614847"}
0005434907951	038D40	3736 217105	ELENA KAZAKOVA	{"phone": "+70348204894"}
0005434907952	D2435B	3904 292818	ALEKSANDR MAKAROV	{"email": "amakarov_111973@postgrespro.ru", "phone": "+70604319140"}
0005434907953	F77C4B	7965 692256	NADEZHDA KOROLEVA	{"phone": "+70300488040"}
0005434907954	F77C4B	6905 275880	ELENA ARKHIPOVA	{"email": "elena.arkhipova_011972@postgrespro.ru", "phone": "+70158671417"}
0005434907955	3C4D6A	5924 627640	ALMIRA KOLESNIKOVA	{"email": "kolesnikova_a-111980@postgrespro.ru", "phone": "+70196955777"}
0005434907956	99D533	5652 555711	VYACHESLAV ROMANOV	{"email": "vromanov11081966@postgrespro.ru", "phone": "+70029126404"}
0005434907957	1B8C21	6584 739311	IRINA BORISOVA	{"phone": "+70807982500"}
0005434907958	1B8C21	0797 860085	ALEKSANDR FOMIN	{"email": "fomin-aleksandr041980@postgrespro.ru", "phone": "+70103834858"}
0005434907959	61D12D	0213 361253	ELENA PETROVA	{"phone": "+70178775172"}
0005434907960	0AF93B	2714 828402	YULIYA PETROVA	{"email": "ypetrova1982@postgrespro.ru", "phone": "+70327932987"}
0005434907961	50147E	3987 324928	ANATOLIY YAKOVLEV	{"phone": "+70133542563"}
0005434907962	50147E	0363 021477	MARINA VASILEVA	{"phone": "+70680553730"}
0005434907963	56DF24	1055 100431	ANTONINA BOGDANOVA	{"email": "bogdanova-a081970@postgrespro.ru", "phone": "+70976787639"}
0005434907964	E55FD5	5437 078591	ARTEM SOLOVEV	{"email": "artemsolovev-17111977@postgrespro.ru", "phone": "+70935578700"}
0005434907965	BDF673	2890 401532	GALINA ALEKSEEVA	{"phone": "+70295857888"}
0005434907966	7F0230	6015 589334	ALEKSANDR PETROV	{"email": "petrov_aleksandr-111970@postgrespro.ru", "phone": "+70917763756"}
0005434907967	7F0230	4314 273410	ANASTASIYA NIKIFOROVA	{"email": "nikiforovaanastasiya_14021971@postgrespro.ru", "phone": "+70147996401"}
0005434907968	9D21D3	5438 760908	TAMARA ANDREEVA	{"email": "andreeva_tamara1981@postgrespro.ru", "phone": "+70151978696"}
0005434907969	B2CBBA	8360 652413	TAMARA NIKIFOROVA	{"email": "nikiforova.tamara.1977@postgrespro.ru", "phone": "+70224329180"}
0005434907970	F62EF6	4092 175253	VIKTOR KISELEV	{"email": "vkiselev-24121969@postgrespro.ru", "phone": "+70636786713"}
0005434907971	059FC4	1460 381520	DMITRIY VOLKOV	{"email": "dmitriyvolkov.1971@postgrespro.ru", "phone": "+70548317854"}
0005434907972	AD5A34	5726 425758	YAROSLAV PETROV	{"email": "y-petrov_1981@postgrespro.ru", "phone": "+70016987856"}
0005434907973	EEB367	9422 210192	VASILIY SERGEEV	{"phone": "+70724199417"}
0005434907974	C19BEE	6593 668910	NADEZHDA SOROKINA	{"phone": "+70772522969"}
0005434907975	A3C91C	1077 449006	VITALIY GAVRILOV	{"phone": "+70318483275"}
0005434907976	653BED	7036 872691	TAMARA MEDVEDEVA	{"phone": "+70930113493"}
0005434907977	D763FE	8201 412750	NIKITA MEDVEDEV	{"phone": "+70148614089"}
0005434907978	8807E4	8143 882936	VERA GORBUNOVA	{"email": "v.gorbunova.1978@postgrespro.ru", "phone": "+70876544468"}
0005434907979	9BBA4A	2257 255848	LIDIYA EFREMOVA	{"email": "efremoval.1978@postgrespro.ru", "phone": "+70197200601"}
0005434907980	D94408	6105 019678	ALIK BORISOV	{"phone": "+70901742238"}
0005434907981	92B587	4398 487560	ALEKSEY MAKSIMOV	{"email": "amaksimov_19021963@postgrespro.ru", "phone": "+70118729360"}
0005434907982	92B587	9585 312210	ALEKSANDR ILIN	{"phone": "+70501037871"}
0005434907983	9B6677	5927 221099	LARISA SOLOVEVA	{"phone": "+70336629002"}
0005434907984	612793	5039 325946	MARINA EGOROVA	{"phone": "+70427737282"}
0005434907985	612793	1366 079954	ALEKSANDR TIMOFEEV	{"email": "timofeeva.05031977@postgrespro.ru", "phone": "+70124536735"}
0005434907986	C8F3F5	4194 200317	SERGEY BARANOV	{"email": "sergey.baranov.23121974@postgrespro.ru", "phone": "+70957077925"}
0005434907987	86276D	2508 357105	IRAIDA BOGDANOVA	{"phone": "+70591749814"}
0005434907988	EADC37	3909 904780	SERGEY SERGEEV	{"phone": "+70824473958"}
0005434907989	EADC37	3116 180498	KIRILL SERGEEV	{"phone": "+70229433955"}
0005434907990	3673E0	3993 669434	GALINA KARPOVA	{"email": "karpova-g-09121973@postgrespro.ru", "phone": "+70412276342"}
0005434907991	3673E0	8277 932081	ALEKSANDR SOROKIN	{"phone": "+70329892674"}
0005434907992	D34C7F	5272 512614	SVETLANA FOMINA	{"email": "fomina_svetlana_1976@postgrespro.ru", "phone": "+70262042585"}
0005434907993	23A6DE	3508 622253	MARIYA SMIRNOVA	{"phone": "+70690811258"}
0005434907994	F87821	4162 985540	NAILYA TIMOFEEVA	{"email": "timofeeva-n_13061978@postgrespro.ru", "phone": "+70783856300"}
0005434907995	0F15AC	8917 993410	VADIM ALEKSEEV	{"email": "alekseevvadim.1966@postgrespro.ru", "phone": "+70372102772"}
0005434907996	0F15AC	2709 171820	VALERIY GORBUNOV	{"email": "gorbunov_v.081973@postgrespro.ru", "phone": "+70257947020"}
0005434907997	68720D	8786 873229	SVETLANA STEPANOVA	{"phone": "+70980914218"}
0005434907998	B15416	8090 837070	OLGA KRASNOVA	{"email": "krasnova_olga17081967@postgrespro.ru", "phone": "+70557321725"}
0005434907999	B15416	2831 946431	IRINA TIKHONOVA	{"email": "tikhonova_i_05011978@postgrespro.ru", "phone": "+70077668139"}
0005434908000	B15416	3903 110043	NINA KOZLOVA	{"phone": "+70004637341"}
0005434908001	0DE4D0	2481 368708	DMITRIY SIDOROV	{"phone": "+70275836656"}
0005434908002	DD1C08	9540 759103	TATYANA VOROBEVA	{"email": "vorobevat_03021980@postgrespro.ru", "phone": "+70872793709"}
0005434908003	2F0D14	1596 688507	TATYANA ZAKHAROVA	{"email": "zakharova-t.08101963@postgrespro.ru", "phone": "+70066987124"}
0005434908004	998B5D	7874 118581	ILYA SOROKIN	{"email": "ilya-sorokin-1979@postgrespro.ru", "phone": "+70160733635"}
0005434908005	578E95	6884 156713	VALENTINA IVANOVA	{"email": "v_ivanova091971@postgrespro.ru", "phone": "+70998024750"}
0005434908006	578E95	3657 616010	LYUDMILA ORLOVA	{"phone": "+70827314009"}
0005434908007	E73BC1	6564 106915	EVGENIY STEPANOV	{"phone": "+70958342980"}
0005434908008	E73BC1	0891 324203	MARINA ALEKSANDROVA	{"phone": "+70863501454"}
0005434908009	46552E	4132 031395	NATALIYA NIKITINA	{"phone": "+70669864135"}
0005434908010	46552E	5941 136473	VLADIMIR SEMENOV	{"email": "v.semenov.12031973@postgrespro.ru", "phone": "+70487534365"}
0005434908011	E218CF	8519 117175	LIDIYA MOROZOVA	{"email": "lmorozova1959@postgrespro.ru", "phone": "+70741514557"}
0005434908012	DB4040	7629 397769	VALENTINA EFREMOVA	{"email": "efremova.v.1961@postgrespro.ru", "phone": "+70802104747"}
0005434908013	F1A001	2783 112775	ALEKSEY ZHURAVLEV	{"email": "zhuravlev_a.041982@postgrespro.ru", "phone": "+70264576989"}
0005434908014	0E0E90	7222 576293	GENNADIY SIDOROV	{"phone": "+70810193904"}
0005434908015	0E0E90	5998 618374	ILYA KOZLOV	{"email": "kozlovilya.101966@postgrespro.ru", "phone": "+70094453357"}
0005434908016	CE2D84	2574 036049	EVGENIY CHERNOV	{"phone": "+70237212910"}
0005434908017	83B7DD	4513 204900	DMITRIY KAZAKOV	{"email": "dkazakov.10091966@postgrespro.ru", "phone": "+70754124804"}
0005434908018	AC54DB	0704 847729	ALEKSEY PAVLOV	{"email": "pavlov.aleksey_031969@postgrespro.ru", "phone": "+70814431932"}
0005434908019	AC54DB	8565 173007	YAROSLAV STEPANOV	{"email": "yaroslav_stepanov-091974@postgrespro.ru", "phone": "+70165184009"}
0005434908020	AC54DB	5389 876804	RINAT ORLOV	{"email": "orlov.rinat_041973@postgrespro.ru", "phone": "+70808691695"}
0005434908021	272479	5515 447890	PAVEL TIMOFEEV	{"email": "ptimofeev.121973@postgrespro.ru", "phone": "+70594456929"}
0005434908022	CBDA92	0812 878400	KSENIYA LEBEDEVA	{"email": "lebedeva.kseniya_041974@postgrespro.ru", "phone": "+70339870515"}
0005434908023	C1D041	4799 604204	LYUDMILA KALININA	{"email": "kalinina-l.1973@postgrespro.ru", "phone": "+70051592249"}
0005434908024	C1D041	9844 868559	ANATOLIY IVANOV	{"email": "anatoliyivanov-121973@postgrespro.ru", "phone": "+70787283805"}
0005434908025	A4E54D	7838 142289	YURIY FEDOROV	{"phone": "+70665299666"}
0005434908026	086281	6871 873672	NIKOLAY MAKAROV	{"email": "makarov_n_19011965@postgrespro.ru", "phone": "+70298117718"}
0005434908027	09A60D	0028 703396	TATYANA KUZNECOVA	{"phone": "+70073980754"}
0005434908028	09A60D	7489 417545	ANASTASIYA TARASOVA	{"email": "tarasova_anastasiya1967@postgrespro.ru", "phone": "+70538021814"}
0005434908029	0B12AD	2844 126392	TATYANA MAKAROVA	{"email": "t.makarova_1975@postgrespro.ru", "phone": "+70120516796"}
0005434908030	12724B	2383 716310	VALERIY ZAYCEV	{"phone": "+70439972209"}
0005434908031	7B4610	5538 132385	VERONIKA ALEKSEEVA	{"phone": "+70958589833"}
0005434908032	12E9F5	1361 763020	ALEKSEY TARASOV	{"phone": "+70648845829"}
0005434908033	12E9F5	7670 315212	VASILIY SEMENOV	{"phone": "+70077043466"}
0005434908034	12E9F5	0811 779666	VALERIY AFANASEV	{"phone": "+70223203881"}
0005434908035	136A39	8292 227238	VLADIMIR KUZNECOV	{"email": "kuznecovv-111965@postgrespro.ru", "phone": "+70094457989"}
0005434908036	7B8146	3689 540033	KIRILL AFANASEV	{"email": "afanasev_k-19111981@postgrespro.ru", "phone": "+70922082948"}
0005434908037	11A60B	8381 539272	STEPAN DMITRIEV	{"email": "s_dmitriev_24111970@postgrespro.ru", "phone": "+70711467652"}
0005434908038	10889C	3641 156844	NIKITA KOROLEV	{"email": "n-korolev121972@postgrespro.ru", "phone": "+70781225591"}
0005434908039	0AD8B1	3815 239283	VALENTINA ZHURAVLEVA	{"email": "valentina-zhuravleva07091967@postgrespro.ru", "phone": "+70404494633"}
0005434908040	8DE12D	9658 343135	VALENTIN PAVLOV	{"email": "valentin_pavlov-1967@postgrespro.ru", "phone": "+70684720915"}
0005434908041	21D1B3	7831 923155	IRINA DENISOVA	{"phone": "+70930373631"}
0005434908042	597F00	0635 019251	NATALYA KUZNECOVA	{"email": "n_kuznecova.091967@postgrespro.ru", "phone": "+70213661611"}
0005434908043	F3D6EE	2646 519459	ALEKSANDR NIKITIN	{"phone": "+70973919312"}
0005434908044	DB3961	3753 168746	ALLA KISELEVA	{"phone": "+70975457217"}
0005434908045	49AB1E	3833 156602	ANATOLIY DMITRIEV	{"email": "dmitrieva_1970@postgrespro.ru", "phone": "+70769299610"}
0005434908046	93E575	3335 084830	TATYANA SOLOVEVA	{"phone": "+70711927878"}
0005434908047	DBB0EC	7200 115370	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov-101971@postgrespro.ru", "phone": "+70181183858"}
0005434908048	13C165	9798 901494	ANATOLIY SOLOVEV	{"phone": "+70668001115"}
0005434908049	13C165	3475 848979	OLEG BONDARENKO	{"phone": "+70056863438"}
0005434908050	1A71E5	1406 610667	AZAT MEDVEDEV	{"email": "medvedev_a-021965@postgrespro.ru", "phone": "+70028974533"}
0005434908051	1ECB00	0459 834688	NATALYA BORISOVA	{"phone": "+70724105578"}
0005434908052	1DDDC0	5038 501621	KRISTINA DAVYDOVA	{"email": "kristinadavydova-1982@postgrespro.ru", "phone": "+70356637326"}
0005434908053	4E06CA	0817 827089	ALEKSANDR NOVIKOV	{"email": "a_novikov_031982@postgrespro.ru", "phone": "+70342105256"}
0005434908054	4E06CA	0733 053740	TIMOFEY SERGEEV	{"phone": "+70365512962"}
0005434908055	EEA360	6526 886846	MIKHAIL KRASNOV	{"email": "mikhail-krasnov_31121965@postgrespro.ru", "phone": "+70670047886"}
0005434908056	EEA360	0210 038003	DARYA IVANOVA	{"phone": "+70469579883"}
0005434908057	123844	3797 495547	ANNA EGOROVA	{"phone": "+70729710283"}
0005434908058	123844	9688 382622	MARINA MASLOVA	{"phone": "+70518229157"}
0005434908059	19F93A	2965 253941	LYUDMILA FOMINA	{"email": "fomina-l.1967@postgrespro.ru", "phone": "+70230256688"}
0005434908060	D25565	3902 171614	YULIYA DANILOVA	{"email": "danilova.yuliya.1957@postgrespro.ru", "phone": "+70740722507"}
0005434908061	D25565	3158 783015	LYUBOV VLASOVA	{"email": "vlasova-l.021979@postgrespro.ru", "phone": "+70485806629"}
0005434908062	EDAC51	0104 725320	MARINA KUZNECOVA	{"phone": "+70330788102"}
0005434908063	310269	3229 151429	NIKOLAY MIKHAYLOV	{"email": "n-mikhaylov_05041966@postgrespro.ru", "phone": "+70007526825"}
0005434908064	F8EBAB	4195 332352	VLADISLAV MAKAROV	{"email": "makarov-vladislav021974@postgrespro.ru", "phone": "+70211885960"}
0005434908065	35452C	2111 482113	VLADIMIR BELOV	{"phone": "+70157911802"}
0005434908066	563288	3326 823329	ALEKSANDR FEDOTOV	{"phone": "+70005083256"}
0005434908067	A6BC09	0387 998031	DMITRIY DAVYDOV	{"email": "d_davydov_1959@postgrespro.ru", "phone": "+70399730491"}
0005434908068	A6BC09	7350 952220	NATALYA MIKHAYLOVA	{"email": "natalyamikhaylova-121968@postgrespro.ru", "phone": "+70371166677"}
0005434908069	D5047F	8759 226177	VLADISLAV POPOV	{"email": "popov_vladislav.021974@postgrespro.ru", "phone": "+70185723047"}
0005434908070	145C79	8685 188818	YURIY NIKOLAEV	{"email": "yuriy-nikolaev.16061972@postgrespro.ru", "phone": "+70458591022"}
0005434908071	F30D25	3239 429410	NIKOLAY ZHUKOV	{"phone": "+70772166122"}
0005434908072	F30D25	3533 041990	DMITRIY POPOV	{"email": "popov_dmitriy1961@postgrespro.ru", "phone": "+70183754786"}
0005434908073	A674A6	0886 064125	SVETLANA PAVLOVA	{"email": "s-pavlova-111969@postgrespro.ru", "phone": "+70517894071"}
0005434908074	4ABCE0	1951 603806	TATYANA NIKOLAEVA	{"phone": "+70251677378"}
0005434908075	3A8177	1664 841837	IRINA FEDOROVA	{"phone": "+70684785237"}
0005434908076	54AB07	3607 023800	ALEKSANDRA OVCHINNIKOVA	{"email": "ovchinnikova.a_1977@postgrespro.ru", "phone": "+70825256503"}
0005434908077	54AB07	4674 617383	ELENA KOZLOVA	{"email": "ekozlova16021979@postgrespro.ru", "phone": "+70135129808"}
0005434908078	D8EA89	8803 645841	KLAVDIYA KOROLEVA	{"email": "klavdiya-koroleva-081978@postgrespro.ru", "phone": "+70289532247"}
0005434908079	94BE71	7907 904416	MARTA DAVYDOVA	{"email": "davydovam-1956@postgrespro.ru", "phone": "+70096839382"}
0005434908080	76EF12	5466 835260	TAMARA KOZLOVA	{"phone": "+70842606648"}
0005434908081	76EF12	5817 752728	ILDAR SERGEEV	{"email": "isergeev-031972@postgrespro.ru", "phone": "+70275367407"}
0005434908082	A90859	6926 114764	ANDREY DENISOV	{"email": "denisov_a.121966@postgrespro.ru", "phone": "+70564040584"}
0005434908083	D2A5B5	5895 893649	VALENTINA MOROZOVA	{"email": "v-morozova26121979@postgrespro.ru", "phone": "+70667919251"}
0005434908084	EB4129	1156 597634	MARIYA KUZMINA	{"phone": "+70901754569"}
0005434908085	3C26A2	0765 553289	ALEKSANDR BARANOV	{"phone": "+70420814512"}
0005434908086	86ECEE	6221 207884	IVAN BONDARENKO	{"phone": "+70247496912"}
0005434908087	86ECEE	8195 517500	IVAN STEPANOV	{"email": "ivan-stepanov15061976@postgrespro.ru", "phone": "+70403246675"}
0005434908088	FB72F3	6858 261829	ALEKSEY GUSEV	{"email": "guseva19081982@postgrespro.ru", "phone": "+70143007598"}
0005434908089	FB72F3	5839 497314	NADEZHDA MALYSHEVA	{"email": "nadezhda.malysheva_1957@postgrespro.ru", "phone": "+70572570993"}
0005434908090	C6931D	1508 587880	DMITRIY VASILEV	{"email": "vasilevd_1971@postgrespro.ru", "phone": "+70907545848"}
0005434908091	7FD7FE	7695 844721	ALEKSANDR KULIKOV	{"phone": "+70053109983"}
0005434908092	95F5DE	5429 669535	EVGENIYA MIKHAYLOVA	{"email": "evgeniya_mikhaylova-13041970@postgrespro.ru", "phone": "+70910343749"}
0005434908093	4940AF	5437 854976	MARIYA NIKOLAEVA	{"email": "nikolaevam.031969@postgrespro.ru", "phone": "+70292772826"}
0005434908094	8710D6	8778 952224	YURIY VASILEV	{"email": "vasilev-yuriy-1969@postgrespro.ru", "phone": "+70403773091"}
0005434908095	62DB42	7899 377481	NIKITA KUZNECOV	{"email": "nikita.kuznecov1977@postgrespro.ru", "phone": "+70157480272"}
0005434908096	FB2C63	5818 951956	ALEKSEY FROLOV	{"email": "a.frolov011980@postgrespro.ru", "phone": "+70906115463"}
0005434908097	237FEB	2439 365198	VLADIMIR SOKOLOV	{"phone": "+70579457401"}
0005434908098	237FEB	7361 826322	DIANA YAKOVLEVA	{"email": "yakovleva_d1981@postgrespro.ru", "phone": "+70299703139"}
0005434908099	99D43A	8063 012197	GALINA YAKOVLEVA	{"email": "gyakovleva_1964@postgrespro.ru", "phone": "+70375232414"}
0005434908100	12006B	4454 268360	NATALYA OSIPOVA	{"email": "osipova-natalya.041979@postgrespro.ru", "phone": "+70531134345"}
0005434908101	C3949F	1069 903766	SVETLANA AKIMOVA	{"phone": "+70595151513"}
0005434908102	C1A253	5591 233916	IRINA MOROZOVA	{"email": "imorozova.111964@postgrespro.ru", "phone": "+70756633676"}
0005434908103	6CE85A	3608 816730	IRINA FEDOROVA	{"email": "i-fedorova1986@postgrespro.ru", "phone": "+70748738822"}
0005434908104	6638D6	5670 777125	TAMARA PETROVA	{"phone": "+70210378218"}
0005434908105	7F1DCF	3455 073725	VITALIY SCHERBAKOV	{"phone": "+70773246792"}
0005434908106	4C7BDC	3624 358548	MIKHAIL EGOROV	{"email": "m.egorov02061968@postgrespro.ru", "phone": "+70045588091"}
0005434908107	4C7BDC	0791 339149	MATVEY VASILEV	{"email": "matvey_vasilev_26071980@postgrespro.ru", "phone": "+70270137211"}
0005434908108	6FE79C	3063 175179	MARINA SMIRNOVA	{"email": "m-smirnova_071976@postgrespro.ru", "phone": "+70813768155"}
0005434908109	5F7180	4008 338740	NADEZHDA VOROBEVA	{"phone": "+70257225626"}
0005434908110	620507	0814 184916	ANASTASIYA SMIRNOVA	{"phone": "+70434275025"}
0005434908111	B3C65F	8052 526962	RAISA ISAEVA	{"email": "isaeva.r_20091969@postgrespro.ru", "phone": "+70207613528"}
0005434908112	B3C65F	1737 425742	DMITRIY ZHUKOV	{"phone": "+70273554547"}
0005434908113	C6ECD1	6590 811005	NADEZHDA DMITRIEVA	{"email": "dmitrieva_n_041967@postgrespro.ru", "phone": "+70538533963"}
0005434908114	C6ECD1	7808 292308	SVETLANA BOGDANOVA	{"email": "s-bogdanova18041972@postgrespro.ru", "phone": "+70182501374"}
0005434908115	E39EE8	3955 522995	OLGA DENISOVA	{"email": "denisova_olga_25011962@postgrespro.ru", "phone": "+70864012605"}
0005434908116	1CB63A	5409 320324	OLGA VLASOVA	{"phone": "+70530174304"}
0005434908117	1CB63A	4674 565986	RAFAIL MIRONOV	{"phone": "+70168307543"}
0005434908118	20A5B7	9127 639408	VYACHESLAV MAKAROV	{"phone": "+70891347459"}
0005434908119	F66B8E	8667 873470	VLADIMIR NOVIKOV	{"email": "vnovikov.121964@postgrespro.ru", "phone": "+70563175892"}
0005434908120	920E6D	5687 765510	ELENA KOLESNIKOVA	{"email": "kolesnikova-elena.061959@postgrespro.ru", "phone": "+70810178910"}
0005434908121	26B701	9253 721390	SVETLANA ALEKSEEVA	{"phone": "+70852780827"}
0005434908122	EA797F	8854 999975	ALEKSEY ANDREEV	{"email": "andreev.aleksey.091972@postgrespro.ru", "phone": "+70619406116"}
0005434908123	EA797F	5478 834641	ANNA EGOROVA	{"email": "egorova.a-051975@postgrespro.ru", "phone": "+70228493495"}
0005434908124	EA797F	3956 583485	NIKITA DMITRIEV	{"phone": "+70710871082"}
0005434908125	AB8AE5	3378 200213	VLADIMIR SMIRNOV	{"phone": "+70800260569"}
0005434908126	01F5C7	0217 545911	SVETLANA ALEKSANDROVA	{"phone": "+70125451004"}
0005434908127	11B88C	3048 092100	OLGA DANILOVA	{"phone": "+70695879665"}
0005434908128	11B88C	1124 647698	ILYA BARANOV	{"email": "ilya_baranov121964@postgrespro.ru", "phone": "+70309995228"}
0005434908129	68E88F	7787 906738	ELENA ANDREEVA	{"phone": "+70600009816"}
0005434908130	B38EB7	9374 082003	DMITRIY NIKOLAEV	{"phone": "+70992667683"}
0005434908131	B38EB7	9703 581590	KRISTINA VASILEVA	{"email": "vasileva-k_041975@postgrespro.ru", "phone": "+70047635481"}
0005434908132	FF5167	0262 476120	NADEZHDA FROLOVA	{"email": "frolova_n-04081972@postgrespro.ru", "phone": "+70788913846"}
0005434908133	B4A576	5432 592705	ANDREY KOZLOV	{"email": "a_kozlov.04121967@postgrespro.ru", "phone": "+70626317686"}
0005434908134	B4A576	6460 208969	MARINA SMIRNOVA	{"email": "smirnovamarina.1973@postgrespro.ru", "phone": "+70181075557"}
0005434908135	6AF191	3520 630458	NIKOLAY ROMANOV	{"email": "romanov.n_03011973@postgrespro.ru", "phone": "+70758449851"}
0005434908136	74BDAA	9086 852956	MARINA POPOVA	{"phone": "+70794918305"}
0005434908137	74BDAA	7988 210720	ALEKSANDR PAVLOV	{"email": "pavlov_a.071981@postgrespro.ru", "phone": "+70670251904"}
0005434908138	82D44A	0662 693229	ANZHELIKA SAVELEVA	{"email": "saveleva-a051967@postgrespro.ru", "phone": "+70477255633"}
0005434908139	82D44A	6361 117122	GALINA GORBUNOVA	{"email": "gorbunovagalina-061980@postgrespro.ru", "phone": "+70444238809"}
0005434908140	C8D483	7378 582270	NIKOLAY MOISEEV	{"phone": "+70537333168"}
0005434908141	A893A0	8667 552142	ANDREY ZHUKOV	{"email": "zhukov_andrey_1972@postgrespro.ru", "phone": "+70133782500"}
0005434908142	A893A0	7304 329650	VIKTOR SCHERBAKOV	{"phone": "+70283141852"}
0005434908143	628D8D	8686 666047	RAISA ORLOVA	{"phone": "+70558311365"}
0005434908144	628D8D	8995 280584	VIKTOR SMIRNOV	{"phone": "+70756243689"}
0005434908145	0F4090	6149 040985	ALEKSEY GORBUNOV	{"email": "a.gorbunov.17031976@postgrespro.ru", "phone": "+70194338012"}
0005434908146	0F4090	5446 921307	PELAGEYA POPOVA	{"email": "popovapelageya_1972@postgrespro.ru", "phone": "+70027990414"}
0005434908147	FD2335	6413 525627	MARIYA STEPANOVA	{"phone": "+70506880058"}
0005434908148	211EC8	4803 828224	ANDREY DENISOV	{"phone": "+70909272424"}
0005434908149	138E1D	8041 082155	NADEZHDA MAKSIMOVA	{"phone": "+70086962212"}
0005434908150	43787C	1457 289809	MIKHAIL FEDOROV	{"email": "m_fedorov.1978@postgrespro.ru", "phone": "+70670883537"}
0005434908151	2ABB54	9128 189661	LEV NOVIKOV	{"phone": "+70899063790"}
0005434908152	96A22E	4771 419500	NATALIYA KOROLEVA	{"phone": "+70429403533"}
0005434908153	F8AB52	1781 212553	OKSANA VOROBEVA	{"phone": "+70056024503"}
0005434908154	6A93EE	2420 137557	ANATOLIY FILIPPOV	{"email": "a_filippov.01121969@postgrespro.ru", "phone": "+70223020051"}
0005434908155	4E1571	5607 448821	DMITRIY BELOV	{"phone": "+70977050144"}
0005434908156	D0B838	4060 349423	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr-20021977@postgrespro.ru", "phone": "+70016178292"}
0005434908157	B8183F	7082 291425	RUSLAN RODIONOV	{"email": "rodionovruslan_1983@postgrespro.ru", "phone": "+70827004969"}
0005434908158	B8183F	4764 337050	OLEG MAKAROV	{"phone": "+70933517760"}
0005434908159	EE6CCC	2144 250014	VERA RODIONOVA	{"phone": "+70467685281"}
0005434908160	EE6CCC	2224 379806	RAFIK MIRONOV	{"email": "r.mironov.12061974@postgrespro.ru", "phone": "+70254363602"}
0005434908161	5E16AC	1517 430903	ALEKSANDRA ROMANOVA	{"phone": "+70665090082"}
0005434908162	0954AC	1554 497933	EKATERINA PETROVA	{"phone": "+70068508847"}
0005434908163	47B2C7	5726 929945	ANNA TROFIMOVA	{"phone": "+70048808252"}
0005434908164	47B2C7	9224 808384	ALEKSANDR ANTONOV	{"phone": "+70656426557"}
0005434908165	078A78	5415 441303	SVETLANA ROMANOVA	{"email": "romanova_s_071962@postgrespro.ru", "phone": "+70287459565"}
0005434908166	9A9E6B	8384 940006	VALERIYA ROMANOVA	{"email": "romanova-valeriya-061977@postgrespro.ru", "phone": "+70977338273"}
0005434908167	A3E3FE	2506 847488	SERGEY SOROKIN	{"email": "sorokin.sergey.041992@postgrespro.ru", "phone": "+70301039561"}
0005434908168	A3E3FE	4288 461243	MIKHAIL KUZMIN	{"email": "kuzminmikhail-15021969@postgrespro.ru", "phone": "+70624046515"}
0005434908169	8E14EE	8520 463177	ALEKSANDR NIKOLAEV	{"email": "nikolaeva081965@postgrespro.ru", "phone": "+70212674512"}
0005434908170	B485C4	7950 693603	ALEKSEY TARASOV	{"email": "aleksey-tarasov-051974@postgrespro.ru", "phone": "+70263075662"}
0005434908171	600892	6564 866419	VERONIKA GUSEVA	{"phone": "+70012898708"}
0005434908172	A12D5C	1395 272231	MAKSIM FOMIN	{"email": "maksim.fomin1981@postgrespro.ru", "phone": "+70701001536"}
0005434908173	F25591	9731 669584	MARINA DENISOVA	{"email": "denisova_marina1979@postgrespro.ru", "phone": "+70407128246"}
0005434908174	C47D89	2389 136521	EVGENIY SHEVCHENKO	{"email": "shevchenkoevgeniy-1971@postgrespro.ru", "phone": "+70992462784"}
0005434908175	937902	0339 975051	LYUBOV AFANASEVA	{"phone": "+70007566724"}
0005434908176	937902	1459 474632	ELENA KOROLEVA	{"phone": "+70667372311"}
0005434908177	43DB14	2746 101401	VIKTOR NIKITIN	{"phone": "+70045475969"}
0005434908178	2100B0	4975 996905	ALEKSEY ANDREEV	{"email": "andreev_aleksey-1973@postgrespro.ru", "phone": "+70967239898"}
0005434908179	068F53	6407 270831	ANNA BOGDANOVA	{"phone": "+70748228339"}
0005434908180	6E5CF3	8056 200006	VIKTOR ANTONOV	{"phone": "+70557896025"}
0005434908181	6E5CF3	9808 971049	NAILYA GRISHINA	{"phone": "+70939678667"}
0005434908182	90DAF1	1827 070678	SERGEY POPOV	{"email": "popov_s.1982@postgrespro.ru", "phone": "+70725063024"}
0005434908183	4030DF	3138 045799	ANDREY ABRAMOV	{"phone": "+70888159140"}
0005434908184	DC9F7A	9011 986285	PAVEL ANDREEV	{"email": "pandreev.051974@postgrespro.ru", "phone": "+70089798853"}
0005434908185	DC9F7A	1360 991817	ANATOLIY ANTONOV	{"email": "aantonov_27101968@postgrespro.ru", "phone": "+70264542851"}
0005434908186	613661	2646 584150	IGOR GORBUNOV	{"phone": "+70684077475"}
0005434908187	613661	8883 631532	NINA GUSEVA	{"email": "gusevanina-111972@postgrespro.ru", "phone": "+70885687319"}
0005434908188	D796ED	5639 643724	VYACHESLAV SERGEEV	{"phone": "+70698947790"}
0005434908189	D796ED	3080 123838	RUSLAN POPOV	{"phone": "+70012234480"}
0005434908190	D796ED	5413 617343	MARIYA MIKHAYLOVA	{"phone": "+70208907509"}
0005434908191	51E980	2491 297568	VIKTORIYA KOROLEVA	{"phone": "+70738970467"}
0005434908192	51E980	4830 086400	LEONID KONOVALOV	{"email": "konovalov-leonid1968@postgrespro.ru", "phone": "+70771114031"}
0005434908193	19AF06	3087 766911	NADEZHDA RODIONOVA	{"email": "nrodionova_08061968@postgrespro.ru", "phone": "+70598606594"}
0005434908194	842C24	5824 687141	VALERIY MELNIKOV	{"email": "melnikov-valeriy-1968@postgrespro.ru", "phone": "+70201478049"}
0005434908195	95D90F	2357 465278	NIKOLAY DAVYDOV	{"phone": "+70152626505"}
0005434908196	95D90F	1327 890747	MARINA ANDREEVA	{"email": "andreeva-m.1970@postgrespro.ru", "phone": "+70412726971"}
0005434908197	95D90F	6022 676515	VERA KUZNECOVA	{"email": "v.kuznecova08061969@postgrespro.ru", "phone": "+70302054566"}
0005434908198	4EE2EF	0255 369675	TATYANA SMIRNOVA	{"email": "smirnova.t.16101958@postgrespro.ru", "phone": "+70234160444"}
0005434908199	99E2AE	1880 239404	IVAN IVANOV	{"phone": "+70637255849"}
0005434908200	3BD4A5	4234 000325	YULIYA IVANOVA	{"phone": "+70523329591"}
0005434908201	BC91D9	2571 832146	NIKITA NIKITIN	{"email": "nikitin-nikita.1959@postgrespro.ru", "phone": "+70057042563"}
0005434908202	C0E31D	1047 769359	LARISA TROFIMOVA	{"phone": "+70457767417"}
0005434908203	C0E31D	9051 140516	NATALYA BORISOVA	{"email": "nborisova-021982@postgrespro.ru", "phone": "+70535616607"}
0005434908204	AE21BA	3013 705237	NIKOLAY KARPOV	{"phone": "+70707291119"}
0005434908205	AE21BA	0795 097087	MIKHAIL ALEKSEEV	{"email": "alekseev-m_1980@postgrespro.ru", "phone": "+70531437277"}
0005434908206	76D1E0	0502 791485	KSENIYA SMIRNOVA	{"phone": "+70089112392"}
0005434908207	76D1E0	6149 099191	VYACHESLAV ALEKSANDROV	{"phone": "+70958441592"}
0005434908208	2AADCD	4446 199211	NADEZHDA SEMENOVA	{"email": "nadezhdasemenova-20061975@postgrespro.ru", "phone": "+70765798186"}
0005434908209	6DCF03	6212 486201	ELVIRA AFANASEVA	{"phone": "+70405748465"}
0005434908210	8B3F15	2362 583987	ANATOLIY PAVLOV	{"phone": "+70775329678"}
0005434908211	C4143D	0151 741286	ELENA NAUMOVA	{"phone": "+70071695221"}
0005434908212	D54A8F	8343 567244	ALEKSANDR KONOVALOV	{"phone": "+70943859387"}
0005434908213	1B1B02	9548 022795	ALEKSANDR YAKOVLEV	{"email": "yakovlev_a_111966@postgrespro.ru", "phone": "+70787717706"}
0005434908214	34B751	7584 881547	EVGENIY SERGEEV	{"email": "e-sergeev_31071971@postgrespro.ru", "phone": "+70254800827"}
0005434908215	34B751	9829 804102	SVETLANA LEBEDEVA	{"phone": "+70844773533"}
0005434908216	34B751	6139 989603	VALENTINA SEMENOVA	{"phone": "+70072549247"}
0005434908217	19013D	9573 586701	ELENA KOVALEVA	{"phone": "+70749491106"}
0005434908218	A82CAE	4722 212551	NATALYA IVANOVA	{"email": "natalya-ivanova-051971@postgrespro.ru", "phone": "+70226287836"}
0005434908219	19B1F0	6287 613213	ALEKSANDR TARASOV	{"email": "tarasov.a.24101970@postgrespro.ru", "phone": "+70330695843"}
0005434908220	1F4ECC	2118 909111	ARTEM IVANOV	{"phone": "+70477126743"}
0005434908221	C6D6EC	5751 768025	NAIL SMIRNOV	{"phone": "+70385667357"}
0005434908222	C6D6EC	8712 807052	NIKOLAY MEDVEDEV	{"phone": "+70865953305"}
0005434908223	A85CE4	0055 327498	NATALYA ORLOVA	{"phone": "+70112629060"}
0005434908224	752B8C	6948 820891	ALEKSEY ZHURAVLEV	{"email": "zhuravlev.aleksey-1979@postgrespro.ru", "phone": "+70240746793"}
0005434908225	752B8C	8292 169357	VASILIY KOZLOV	{"phone": "+70052054686"}
0005434908226	752B8C	5055 831200	IVAN PAVLOV	{"phone": "+70709945329"}
0005434908227	752B8C	2226 637877	NADEZHDA POLYAKOVA	{"email": "polyakovan_021964@postgrespro.ru", "phone": "+70526624874"}
0005434908228	4E8F2F	2033 866449	SERGEY KOZLOV	{"phone": "+70044641670"}
0005434908229	4E8F2F	3752 643286	MIKHAIL KUZNECOV	{"phone": "+70524993976"}
0005434908230	1095D0	9479 825651	KAMILA KAZAKOVA	{"email": "kamilakazakova-22111974@postgrespro.ru", "phone": "+70024056856"}
0005434908231	C38555	0850 984880	MIKHAIL STEPANOV	{"phone": "+70034539695"}
0005434908232	C38555	4930 546057	DMITRIY DMITRIEV	{"email": "d-dmitriev_13021970@postgrespro.ru", "phone": "+70482747157"}
0005434908233	70A4E0	0233 599822	EKATERINA CHERNOVA	{"email": "e_chernova_31031964@postgrespro.ru", "phone": "+70937733818"}
0005434908234	ACE8C8	2250 868282	PAVEL KUZNECOV	{"email": "kuznecov_pavel-13061958@postgrespro.ru", "phone": "+70377708089"}
0005434908235	ACE8C8	1165 566496	MIKHAIL TIKHONOV	{"phone": "+70543737699"}
0005434908236	3BFE3A	3316 200737	DAVID IVANOV	{"email": "ivanov.david.011975@postgrespro.ru", "phone": "+70226896065"}
0005434908237	8BC64A	6745 413259	OLGA SOLOVEVA	{"email": "solovevaolga.18111970@postgrespro.ru", "phone": "+70078329344"}
0005434908238	8BC64A	0519 565871	VLADISLAV VASILEV	{"phone": "+70595027856"}
0005434908239	8BC64A	3203 518910	ARINA KISELEVA	{"email": "arina.kiseleva-10101963@postgrespro.ru", "phone": "+70302966919"}
0005434908240	F278C2	9331 310947	IGOR KRASNOV	{"email": "i-krasnov1976@postgrespro.ru", "phone": "+70404917795"}
0005434908241	F278C2	8334 469460	ARTEM ALEKSEEV	{"email": "a-alekseev_1970@postgrespro.ru", "phone": "+70145490907"}
0005434908242	F278C2	9095 825346	SERGEY NIKITIN	{"email": "sergeynikitin091973@postgrespro.ru", "phone": "+70167866401"}
0005434908243	574A96	6816 800875	ANASTASIYA LEBEDEVA	{"phone": "+70732421883"}
0005434908244	9EE144	3083 253408	TATYANA POLYAKOVA	{"phone": "+70585245925"}
0005434908245	9EE144	2322 143302	NATALYA SOLOVEVA	{"phone": "+70736302676"}
0005434908246	AB47A4	5824 349182	IRINA VASILEVA	{"phone": "+70899027466"}
0005434908247	95641C	6815 379454	DANILA KOZLOV	{"email": "danilakozlov_061987@postgrespro.ru", "phone": "+70964615027"}
0005434908248	95641C	2087 474679	ANNA TITOVA	{"phone": "+70389445654"}
0005434908249	E674BB	1814 351227	NIKOLAY VOLKOV	{"phone": "+70642210113"}
0005434908250	1F0584	3149 754109	DMITRIY KUZMIN	{"phone": "+70391355648"}
0005434908251	4CE7C2	7244 534382	RAISA VOLKOVA	{"email": "r-volkova.011969@postgrespro.ru", "phone": "+70325786218"}
0005434908252	25C23E	1558 567655	LIDIYA ZAKHAROVA	{"phone": "+70802719295"}
0005434908253	25C23E	9407 105932	TATYANA ALEKSEEVA	{"phone": "+70527531868"}
0005434908254	2B5BE2	7130 151425	LEONID ROMANOV	{"phone": "+70663653943"}
0005434908255	2B5BE2	9056 564258	TATYANA MARTYNOVA	{"phone": "+70251636131"}
0005434908256	2B5BE2	5953 288999	GALINA POLYAKOVA	{"email": "polyakova_galina_041975@postgrespro.ru", "phone": "+70121097918"}
0005434908257	581904	8086 120928	ALEKSEY ROMANOV	{"email": "romanova.17011971@postgrespro.ru", "phone": "+70918764627"}
0005434908258	2C9D39	9776 449676	OKSANA ROMANOVA	{"phone": "+70528353804"}
0005434908259	232E4C	4980 059057	IVAN SEMENOV	{"email": "semenovivan_28041975@postgrespro.ru", "phone": "+70480354531"}
0005434908260	FB5C2E	5791 048279	TATYANA MOROZOVA	{"email": "morozova-tatyana061979@postgrespro.ru", "phone": "+70075035247"}
0005434908261	FB5C2E	2797 698486	ANTON VOLKOV	{"phone": "+70199900227"}
0005434908262	A159E3	1205 384357	VALENTINA KONDRATEVA	{"email": "v.kondrateva_041976@postgrespro.ru", "phone": "+70497130490"}
0005434908263	0F0A8A	1748 537967	MARINA KARPOVA	{"email": "marina-karpova031970@postgrespro.ru", "phone": "+70722210589"}
0005434908264	0F0A8A	9042 015506	ILYA SAVELEV	{"email": "savelev_ilya07051967@postgrespro.ru", "phone": "+70896834705"}
0005434908265	3BD064	3375 299753	ILYA BONDARENKO	{"phone": "+70129162377"}
0005434908266	D2404F	8015 491662	ZOYA KISELEVA	{"email": "kiseleva_z.121966@postgrespro.ru", "phone": "+70618536575"}
0005434908267	D2404F	5883 454483	ALEKSANDR DMITRIEV	{"email": "a_dmitriev-1974@postgrespro.ru", "phone": "+70338486765"}
0005434908268	D2404F	2555 521127	SERGEY SEMENOV	{"phone": "+70476400144"}
0005434908269	9BF241	6175 595088	GLEB MOISEEV	{"phone": "+70032513160"}
0005434908270	950241	7677 213845	KSENIYA GERASIMOVA	{"email": "gerasimova.kseniya-30011961@postgrespro.ru", "phone": "+70066971718"}
0005434908271	950241	4403 170917	ANDREY OSIPOV	{"email": "osipov-a-041967@postgrespro.ru", "phone": "+70916136570"}
0005434908272	1A9779	2440 551301	VLADIMIR TIMOFEEV	{"phone": "+70235203842"}
0005434908273	46ED3F	2241 660830	NINA SERGEEVA	{"phone": "+70253302428"}
0005434908274	75FFAB	1052 222675	ALEVTINA KUDRYASHOVA	{"email": "a-kudryashova.1963@postgrespro.ru", "phone": "+70793166863"}
0005434908275	75FFAB	1259 448470	ANATOLIY KOZLOV	{"phone": "+70076272977"}
0005434908276	F8288D	9156 599119	IRINA ZAKHAROVA	{"email": "zakharova.irina1974@postgrespro.ru", "phone": "+70460830647"}
0005434908277	AEBF85	1000 174362	VIKTORIYA ROMANOVA	{"phone": "+70391546281"}
0005434908278	C60AC9	0940 740329	SERGEY BARANOV	{"email": "baranovsergey09061974@postgrespro.ru", "phone": "+70372220431"}
0005434908279	FDB6B6	5452 702534	INNA NIKOLAEVA	{"email": "inna-nikolaeva28011980@postgrespro.ru", "phone": "+70403148376"}
0005434908280	FDB6B6	6238 221762	IRINA POLYAKOVA	{"email": "irinapolyakova1964@postgrespro.ru", "phone": "+70277673941"}
0005434908281	0C0002	4634 269075	SERGEY SEMENOV	{"email": "semenovsergey1977@postgrespro.ru", "phone": "+70273619514"}
0005434908282	23DA7E	4011 811739	KSENIYA FEDOROVA	{"phone": "+70184581028"}
0005434908283	FA8DC1	5970 462770	ALEKSANDR VOROBEV	{"email": "vorobev.aleksandr-041980@postgrespro.ru", "phone": "+70509387229"}
0005434908284	FA8DC1	5243 195205	NINA MALYSHEVA	{"email": "nmalysheva121970@postgrespro.ru", "phone": "+70796618273"}
0005434908285	FA8DC1	5332 605501	IVAN EGOROV	{"email": "egorov_ivan21021987@postgrespro.ru", "phone": "+70487745990"}
0005434908286	1391B7	7292 040750	GALIYA MALYSHEVA	{"email": "g_malysheva-1969@postgrespro.ru", "phone": "+70518281803"}
0005434908287	A886DB	4977 390773	RAISA MAKAROVA	{"phone": "+70797354973"}
0005434908288	7DAC46	9673 126818	EKATERINA POPOVA	{"email": "popova.e111970@postgrespro.ru", "phone": "+70059551136"}
0005434908289	7DAC46	7719 466414	SERGEY MIRONOV	{"phone": "+70442395728"}
0005434908290	0BC429	7112 919463	ZINAIDA SERGEEVA	{"email": "z.sergeeva.091979@postgrespro.ru", "phone": "+70450993582"}
0005434908291	D155A8	9224 863344	EVGENIY AFANASEV	{"phone": "+70023004402"}
0005434908292	2A4CBE	0371 991386	SOFIYA VOLKOVA	{"email": "sofiya-volkova_14051976@postgrespro.ru", "phone": "+70817263123"}
0005434908293	6F230D	0638 410680	ALENA SERGEEVA	{"email": "sergeeva-alena.1978@postgrespro.ru", "phone": "+70441821879"}
0005434908294	6F230D	2910 417463	EVGENIY SERGEEV	{"phone": "+70383450239"}
0005434908295	6F230D	5517 488828	ANTON SOROKIN	{"email": "asorokin031963@postgrespro.ru", "phone": "+70147588000"}
0005434908296	3E4937	0587 878021	TAMARA NIKITINA	{"phone": "+70538418633"}
0005434908297	3E4937	1413 237982	MARIYA IVANOVA	{"phone": "+70470897441"}
0005434908298	63B36A	0579 684059	ANDREY VOROBEV	{"email": "a_vorobev-29091973@postgrespro.ru", "phone": "+70129163473"}
0005434908299	81C065	5289 022699	VIKTOR KULIKOV	{"email": "v_kulikov-031989@postgrespro.ru", "phone": "+70719838547"}
0005434908300	C56D0B	7803 186161	KONSTANTIN MAKAROV	{"phone": "+70122697051"}
0005434908301	4EE159	4276 725442	OKSANA IVANOVA	{"phone": "+70146955706"}
0005434908302	4EE159	9604 410108	ALEKSANDRA FILIPPOVA	{"email": "filippovaa_02061969@postgrespro.ru", "phone": "+70757958209"}
0005434908303	E189B5	9902 491519	ANASTASIYA PETROVA	{"phone": "+70078788108"}
0005434908304	E189B5	4222 259367	GUZEL TIMOFEEVA	{"email": "timofeeva-guzel_11041963@postgrespro.ru", "phone": "+70802113393"}
0005434908305	AE4517	1435 341068	LARISA ARKHIPOVA	{"phone": "+70461274839"}
0005434908306	96FAE5	3120 659169	TAMARA VLASOVA	{"phone": "+70506394576"}
0005434908307	96FAE5	9795 839608	YURIY MAKSIMOV	{"phone": "+70918635808"}
0005434908308	9154C6	7003 093585	YURIY ROMANOV	{"email": "y.romanov.10121967@postgrespro.ru", "phone": "+70959395178"}
0005434908309	C5AAC5	1657 782547	MAKSIM BARANOV	{"email": "baranov_maksim.1957@postgrespro.ru", "phone": "+70088704115"}
0005434908310	C5AAC5	2790 162866	TIMUR FILIPPOV	{"email": "timurfilippov07101965@postgrespro.ru", "phone": "+70460048299"}
0005434908311	AF35BD	5592 573252	NINA ROMANOVA	{"phone": "+70405559627"}
0005434908312	AF35BD	3456 471717	KRISTINA DAVYDOVA	{"email": "davydova.k-111964@postgrespro.ru", "phone": "+70583096425"}
0005434908313	FBE3A1	1723 299253	VERA EGOROVA	{"email": "vera-egorova-1973@postgrespro.ru", "phone": "+70971251373"}
0005434908314	66789B	7885 147726	ANNA DAVYDOVA	{"email": "davydovaa_081973@postgrespro.ru", "phone": "+70801152379"}
0005434908315	5EA093	4099 323946	SVETLANA VLASOVA	{"phone": "+70156723483"}
0005434908316	3516E2	1880 422872	ALEKSANDR BORISOV	{"phone": "+70942769228"}
0005434908317	3C65CC	8867 856722	ELENA KOROLEVA	{"phone": "+70054113885"}
0005434908318	6B879F	5796 838282	ANASTASIYA CHERNOVA	{"phone": "+70653698734"}
0005434908319	A0EDBC	8880 022065	TAMARA ZAYCEVA	{"phone": "+70813624331"}
0005434908320	0B9F8E	1500 683097	ILYA GUSEV	{"phone": "+70502193340"}
0005434908321	0B9F8E	5037 761617	ELENA STEPANOVA	{"phone": "+70714628268"}
0005434908322	8FBE76	1680 003192	EVGENIYA NAUMOVA	{"email": "naumova.e-1979@postgrespro.ru", "phone": "+70410744545"}
0005434908323	CF26DE	1725 518206	NIKITA GORBUNOV	{"phone": "+70855505624"}
0005434908324	99A796	3047 845384	OLGA IVANOVA	{"phone": "+70794416831"}
0005434908325	413DFD	9145 597705	DMITRIY KONOVALOV	{"email": "dmitriykonovalov.081966@postgrespro.ru", "phone": "+70551732364"}
0005434908326	209CDC	5795 545757	ALEKSANDR GUSEV	{"email": "gusevaleksandr1978@postgrespro.ru", "phone": "+70703579930"}
0005434908327	209CDC	7675 070231	TIMUR MOROZOV	{"email": "timur_morozov-1981@postgrespro.ru", "phone": "+70809667452"}
0005434908328	7A876B	4184 847533	ANDREY MAKAROV	{"email": "andreymakarov_19041967@postgrespro.ru", "phone": "+70861748345"}
0005434908329	7A876B	2950 089956	VIKTOR ILIN	{"email": "viktor_ilin-17041971@postgrespro.ru", "phone": "+70323014850"}
0005434908330	FB2D35	1328 203526	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr1980@postgrespro.ru", "phone": "+70788348934"}
0005434908331	FB2D35	6691 615785	DMITRIY MIRONOV	{"email": "dmitriy-mironov.05091986@postgrespro.ru", "phone": "+70329422808"}
0005434908332	8500E1	1481 884247	GYUZEL KUZNECOVA	{"phone": "+70201383487"}
0005434908333	B12283	7210 904105	VYACHESLAV RODIONOV	{"email": "v_rodionov1978@postgrespro.ru", "phone": "+70532864183"}
0005434908334	B12283	6088 298204	EVGENIY NAZAROV	{"email": "e-nazarov.26011986@postgrespro.ru", "phone": "+70935980327"}
0005434908335	E82E18	8571 309244	ELENA CHERNOVA	{"email": "chernova_e_22061958@postgrespro.ru", "phone": "+70584228040"}
0005434908336	7A801B	7015 928633	RUSTAM RODIONOV	{"phone": "+70319833637"}
0005434908337	B43D1E	4605 652899	TIMOFEY FOMIN	{"email": "fomin-t_091961@postgrespro.ru", "phone": "+70162651822"}
0005434908338	AD15D5	3678 696731	EVGENIYA GAVRILOVA	{"phone": "+70590614642"}
0005434908339	AD15D5	7504 975632	GALINA BORISOVA	{"phone": "+70794143915"}
0005434908340	593836	3558 024630	ZINAIDA DMITRIEVA	{"email": "z_dmitrieva121977@postgrespro.ru", "phone": "+70477415435"}
0005434908341	066ABE	4370 491184	VADIM SOLOVEV	{"email": "vadimsolovev_1959@postgrespro.ru", "phone": "+70184791447"}
0005434908342	C5B452	8386 458088	ZINAIDA NIKOLAEVA	{"email": "nikolaeva_zinaida-15111962@postgrespro.ru", "phone": "+70815182131"}
0005434908343	E12CEA	5972 381407	MAKSIM RODIONOV	{"phone": "+70267935954"}
0005434908344	2A147B	0067 078641	ALEKSANDR ISAEV	{"email": "a_isaev.05071981@postgrespro.ru", "phone": "+70625147103"}
0005434908345	A82FC1	1458 084595	YULIYA DENISOVA	{"email": "yuliya_denisova_111956@postgrespro.ru", "phone": "+70701852008"}
0005434908346	F9C5AB	8047 004755	ELENA GRISHINA	{"phone": "+70964462409"}
0005434908347	CC37F9	7008 609290	TATYANA ZAYCEVA	{"phone": "+70580262253"}
0005434908348	CC37F9	4504 084081	VLADIMIR POPOV	{"phone": "+70902810975"}
0005434908349	912377	2885 904255	SERGEY MOISEEV	{"phone": "+70507139439"}
0005434908350	DC2C32	8317 118287	DENIS FOMIN	{"email": "fomin_d_27081968@postgrespro.ru", "phone": "+70342749732"}
0005434908351	D2C0C8	1880 980582	RUSTAM KUZNECOV	{"phone": "+70474304576"}
0005434908352	D2C0C8	8785 855127	EVGENIY DMITRIEV	{"email": "e.dmitriev.1965@postgrespro.ru", "phone": "+70127569442"}
0005434908353	572F94	9272 805919	OLGA VASILEVA	{"email": "olga_vasileva_31081962@postgrespro.ru", "phone": "+70868164223"}
0005434908354	E589A4	9964 074671	EVGENIY RODIONOV	{"phone": "+70758176004"}
0005434908355	BA870F	9730 483877	DANIL KOROLEV	{"email": "d-korolev18111977@postgrespro.ru", "phone": "+70559140107"}
0005434908356	BA870F	4941 300784	SVETLANA FILIPPOVA	{"phone": "+70742210486"}
0005434908357	4CECAE	4173 654926	ANDREY VLASOV	{"phone": "+70976362109"}
0005434908358	4CECAE	5370 034878	EVGENIY KUZMIN	{"email": "evgeniy_kuzmin.121968@postgrespro.ru", "phone": "+70328140496"}
0005434908359	770D5E	6814 854440	NATALYA ZHUKOVA	{"phone": "+70194338124"}
0005434908360	770D5E	2984 077636	VLADIMIR SEMENOV	{"phone": "+70046166584"}
0005434908361	E28730	1646 309579	VLADIMIR ORLOV	{"email": "v_orlov111975@postgrespro.ru", "phone": "+70653655976"}
0005434908362	E28730	2994 416433	ALEKSANDR SOKOLOV	{"email": "sokolov.a07061973@postgrespro.ru", "phone": "+70656472104"}
0005434908363	93D42C	6373 582514	LYUDMILA ISAEVA	{"email": "l-isaeva1972@postgrespro.ru", "phone": "+70412231556"}
0005434908364	595C09	9584 475523	ANATOLIY KRASNOV	{"phone": "+70170463031"}
0005434908485	975E52	4698 731501	SERGEY SOROKIN	{"phone": "+70817083787"}
0005434908365	3C0981	7998 508667	ANASTASIYA MEDVEDEVA	{"email": "medvedeva_anastasiya_18031984@postgrespro.ru", "phone": "+70182422716"}
0005434908366	B80ADF	6806 876978	ELENA TARASOVA	{"phone": "+70831976087"}
0005434908367	9A5ABC	7003 462689	EVGENIY SIDOROV	{"phone": "+70228275187"}
0005434908368	9A5ABC	8818 327124	KIRILL KULIKOV	{"email": "kulikov_k-24051968@postgrespro.ru", "phone": "+70406445054"}
0005434908369	590187	0056 872159	DAMIR BORISOV	{"phone": "+70061981790"}
0005434908370	E41865	8313 899726	GENNADIY NOVIKOV	{"phone": "+70204322758"}
0005434908371	E41865	4623 100906	VASILISA FEDOROVA	{"email": "vasilisa_fedorova1971@postgrespro.ru", "phone": "+70245447476"}
0005434908372	B54114	1206 021909	ALEKSANDR FEDOTOV	{"phone": "+70444865958"}
0005434908373	B54114	4299 922195	EKATERINA FILATOVA	{"phone": "+70706511660"}
0005434908374	F6BE63	7294 016771	ANNA ZHUKOVA	{"email": "azhukova25071976@postgrespro.ru", "phone": "+70727033734"}
0005434908375	482CB9	6294 276977	ALLA TIKHONOVA	{"email": "allatikhonova_23031966@postgrespro.ru", "phone": "+70137719518"}
0005434908376	482CB9	4767 071786	OLGA VOLKOVA	{"phone": "+70345538410"}
0005434908377	8D60E0	6267 908528	GENNADIY VOROBEV	{"phone": "+70481911195"}
0005434908378	8D60E0	8759 843203	LIDIYA ZHUKOVA	{"email": "zhukova.lidiya_101964@postgrespro.ru", "phone": "+70592163257"}
0005434908379	8D60E0	8584 768391	KAMILLA KONOVALOVA	{"phone": "+70572533066"}
0005434908380	FAC9F4	4530 991582	SERGEY BONDARENKO	{"email": "s-bondarenko081968@postgrespro.ru", "phone": "+70571306208"}
0005434908381	32061B	3911 503055	MARIYA MELNIKOVA	{"phone": "+70142855046"}
0005434908382	32061B	9042 343925	DMITRIY VASILEV	{"email": "d.vasilev_06091975@postgrespro.ru", "phone": "+70433913638"}
0005434908383	32061B	9498 655683	ALEKSANDR MIRONOV	{"phone": "+70099801981"}
0005434908384	D0E914	4370 553754	EVGENIY PAVLOV	{"email": "evgeniy-pavlov11021972@postgrespro.ru", "phone": "+70700823422"}
0005434908385	273EB9	5568 934182	ALEKSEY VLASOV	{"phone": "+70141898362"}
0005434908386	FDDC46	5535 726625	VALENTINA ZAKHAROVA	{"email": "zakharova-v.28101967@postgrespro.ru", "phone": "+70645434516"}
0005434908387	FDDC46	9760 694754	YAROSLAV MAKAROV	{"email": "makarov-yaroslav.101975@postgrespro.ru", "phone": "+70810967218"}
0005434908388	FDDC46	2743 512769	FAINA KUZMINA	{"email": "fainakuzmina.03061979@postgrespro.ru", "phone": "+70418444180"}
0005434908389	3EDDD9	6076 549961	VALENTIN SIDOROV	{"email": "sidorovv021982@postgrespro.ru", "phone": "+70579283107"}
0005434908390	3EDDD9	8344 383311	ELVIRA IVANOVA	{"email": "ivanova.elvira-101973@postgrespro.ru", "phone": "+70104758244"}
0005434908391	3E0806	6610 569313	ZLATA FROLOVA	{"email": "frolovaz_11111966@postgrespro.ru", "phone": "+70965959882"}
0005434908392	27C068	1297 636380	STANISLAV BORISOV	{"phone": "+70802026360"}
0005434908393	40B6C9	1799 744979	EKATERINA SIDOROVA	{"email": "esidorova.1983@postgrespro.ru", "phone": "+70298147831"}
0005434908394	40B6C9	2620 821029	LEONID ISAEV	{"email": "leonid.isaev-011984@postgrespro.ru", "phone": "+70169029257"}
0005434908395	96C570	3758 213452	TIMUR FROLOV	{"phone": "+70372330561"}
0005434908396	5788B9	6830 868037	MARIYA SOROKINA	{"phone": "+70691493714"}
0005434908397	35E7A6	6454 157448	VERA SOROKINA	{"email": "sorokinavera.07081975@postgrespro.ru", "phone": "+70086321018"}
0005434908398	D5CCFE	5816 473313	IGOR GORBUNOV	{"phone": "+70874598942"}
0005434908399	1820D5	7137 520691	OLEG RODIONOV	{"email": "orodionov021974@postgrespro.ru", "phone": "+70425223523"}
0005434908400	1820D5	9304 595096	DMITRIY AFANASEV	{"email": "afanasev.d.21031966@postgrespro.ru", "phone": "+70846376561"}
0005434908401	4279E3	6193 816799	ZINAIDA AKIMOVA	{"email": "zinaida.akimova_051986@postgrespro.ru", "phone": "+70888802617"}
0005434908402	E3E4D8	6428 317277	VLADIMIR MOISEEV	{"phone": "+70357165943"}
0005434908403	A9CE57	2956 477778	VLADIMIR ZHURAVLEV	{"phone": "+70371156751"}
0005434908404	AF7CF8	9331 462194	NATALYA LEBEDEVA	{"email": "lebedeva-n1965@postgrespro.ru", "phone": "+70679823755"}
0005434908405	AF7CF8	2777 907175	GALINA IVANOVA	{"phone": "+70427306576"}
0005434908406	16DBFC	3319 879198	GENNADIY NOVIKOV	{"phone": "+70663278883"}
0005434908407	3BAD92	8070 055224	IRINA TITOVA	{"phone": "+70717616069"}
0005434908408	01EA19	4420 691588	GALINA BELOVA	{"phone": "+70969199788"}
0005434908409	91D173	7762 917797	ALEKSANDR POPOV	{"email": "a.popov.09081983@postgrespro.ru", "phone": "+70913289445"}
0005434908410	1BCE14	5623 643653	SERGEY BELOV	{"email": "belovsergey_1972@postgrespro.ru", "phone": "+70404724524"}
0005434908411	296BF5	8258 954830	IVAN POPOV	{"email": "ivanpopov121975@postgrespro.ru", "phone": "+70312047248"}
0005434908412	296BF5	0824 347300	OLEG DENISOV	{"email": "denisov_o06011957@postgrespro.ru", "phone": "+70239055381"}
0005434908413	CE9E86	7281 719289	ALEKSEY ZAKHAROV	{"email": "zakharov_a.041971@postgrespro.ru", "phone": "+70779487211"}
0005434908414	E91215	6408 721021	YULIYA POTAPOVA	{"email": "potapova_yuliya30051980@postgrespro.ru", "phone": "+70191793718"}
0005434908415	F81D90	8657 563500	VIKTORIYA VASILEVA	{"phone": "+70135288165"}
0005434908416	D3AEAC	6196 444353	SERGEY GRIGOREV	{"phone": "+70330258894"}
0005434908417	F95E3B	2095 444517	VLADIMIR VOROBEV	{"phone": "+70614192129"}
0005434908418	DAC742	9583 232282	NADEZHDA KRASNOVA	{"email": "n.krasnova-121974@postgrespro.ru", "phone": "+70365648027"}
0005434908419	767222	7638 007171	DMITRIY KUDRYASHOV	{"phone": "+70775470626"}
0005434908420	C3045E	6047 258829	VLADIMIR MATVEEV	{"phone": "+70822737663"}
0005434908421	C3045E	2770 756157	VYACHESLAV MIRONOV	{"phone": "+70406495239"}
0005434908422	B8C58B	9815 445652	VIKTORIYA MOROZOVA	{"phone": "+70281985419"}
0005434908423	C0DE38	1428 072657	YULIYA MAKAROVA	{"email": "y-makarova.031965@postgrespro.ru", "phone": "+70439791711"}
0005434908424	C0DE38	7259 973669	MARINA NAZAROVA	{"phone": "+70237615152"}
0005434908425	51F5FF	7551 934977	IRINA BORISOVA	{"phone": "+70778800086"}
0005434908426	2595DB	3852 828883	NATALYA MAKSIMOVA	{"email": "n-maksimova-14111975@postgrespro.ru", "phone": "+70381419325"}
0005434908427	2595DB	3107 605225	LILIYA MASLOVA	{"phone": "+70218215344"}
0005434908428	3E161D	6839 871347	NATALYA GAVRILOVA	{"phone": "+70634055155"}
0005434908429	955B8D	0075 071513	ANNA FADEEVA	{"phone": "+70192450574"}
0005434908430	4831CF	4097 536645	TAMARA SOROKINA	{"email": "tsorokina_1988@postgrespro.ru", "phone": "+70224851397"}
0005434908431	659F99	1055 141615	ALEKSANDR MIKHAYLOV	{"phone": "+70052366639"}
0005434908432	C9A8A5	6840 561673	MIKHAIL OSIPOV	{"email": "osipovmikhail021974@postgrespro.ru", "phone": "+70976083248"}
0005434908602	214DF2	7995 604480	ANASTASIYA FEDOROVA	{"phone": "+70825037515"}
0005434908433	E7DC3A	9924 920142	LARISA YAKOVLEVA	{"email": "l.yakovleva_1978@postgrespro.ru", "phone": "+70119527648"}
0005434908434	C213C0	0916 363512	IRAIDA DAVYDOVA	{"email": "iraidadavydova-081972@postgrespro.ru", "phone": "+70670118165"}
0005434908435	D7DA22	4012 036420	DMITRIY NAZAROV	{"email": "nazarov-dmitriy_011977@postgrespro.ru", "phone": "+70047247648"}
0005434908436	203935	9398 939695	MADINA POPOVA	{"email": "madina.popova-021967@postgrespro.ru", "phone": "+70846942976"}
0005434908437	C25A79	8223 227659	ELENA AKIMOVA	{"email": "akimovaelena101973@postgrespro.ru", "phone": "+70829507621"}
0005434908438	24A4E4	5454 604548	VYACHESLAV VASILEV	{"phone": "+70661447935"}
0005434908439	24A4E4	6636 490321	ILYA MATVEEV	{"phone": "+70115767272"}
0005434908440	56DDC9	0333 033931	MARIYA DENISOVA	{"email": "mariya-denisova1976@postgrespro.ru", "phone": "+70420507772"}
0005434908441	E91FF9	5546 748757	TAKHIR DENISOV	{"phone": "+70171801456"}
0005434908442	0E67F6	9393 122018	ROMAN POPOV	{"phone": "+70082394048"}
0005434908443	5C6876	7584 564369	NADEZHDA KOROLEVA	{"email": "n_koroleva101975@postgrespro.ru", "phone": "+70187179698"}
0005434908444	85461A	6539 362273	GALINA ORLOVA	{"phone": "+70692371133"}
0005434908445	85461A	6604 406548	VIKTOR ROMANOV	{"email": "romanov.viktor_1988@postgrespro.ru", "phone": "+70043188857"}
0005434908446	555B20	1056 252792	IVAN MELNIKOV	{"email": "i-melnikov-05101977@postgrespro.ru", "phone": "+70968809000"}
0005434908447	C6FC64	8868 040276	ALEKSANDR CHERNOV	{"email": "a_chernov-121986@postgrespro.ru", "phone": "+70286220217"}
0005434908448	C6FC64	6444 855565	ALINA ANDREEVA	{"phone": "+70740970274"}
0005434908449	5F5E9A	4004 689422	NATALIYA IVANOVA	{"email": "n.ivanova1971@postgrespro.ru", "phone": "+70725491012"}
0005434908450	E23326	2396 395428	VLADISLAV PETROV	{"email": "vladislavpetrov.1969@postgrespro.ru", "phone": "+70115925999"}
0005434908451	E03D1E	8453 088454	ZINAIDA TIMOFEEVA	{"phone": "+70575665541"}
0005434908452	D65ECC	1563 359085	OLGA IVANOVA	{"email": "olga_ivanova.21121970@postgrespro.ru", "phone": "+70463626298"}
0005434908453	C44423	9128 147149	INESSA DAVYDOVA	{"email": "davydovai-25081970@postgrespro.ru", "phone": "+70112226728"}
0005434908454	365691	9309 178074	GALINA CHERNOVA	{"email": "galina-chernova_1962@postgrespro.ru", "phone": "+70020831235"}
0005434908455	365691	5585 102545	ALEKSANDR FILIPPOV	{"email": "a-filippov23011979@postgrespro.ru", "phone": "+70180111423"}
0005434908456	F80433	4891 021207	ELENA ILINA	{"phone": "+70738579367"}
0005434908457	5F96C0	2279 264660	RASHID SMIRNOV	{"phone": "+70160358841"}
0005434908458	5F96C0	3409 505077	VERONIKA YAKOVLEVA	{"phone": "+70773829363"}
0005434908459	2144BB	0467 249058	ANZHELIKA MARTYNOVA	{"phone": "+70757786084"}
0005434908460	F738DC	4417 030805	TAMARA TIKHONOVA	{"phone": "+70804443877"}
0005434908461	B673F3	6666 007486	SVETLANA MEDVEDEVA	{"phone": "+70664872898"}
0005434908462	31B6EC	2931 361810	MIKHAIL MOISEEV	{"email": "moiseev-mikhail_1978@postgrespro.ru", "phone": "+70564859201"}
0005434908463	A7B387	8712 818638	LARISA GRISHINA	{"email": "grishina-larisa1969@postgrespro.ru", "phone": "+70533765171"}
0005434908464	A2C1AB	5262 079298	ANDREY SOLOVEV	{"email": "solovevandrey-26041971@postgrespro.ru", "phone": "+70781320674"}
0005434908465	A4D1C5	5304 384980	GALINA TIMOFEEVA	{"email": "g.timofeeva091974@postgrespro.ru", "phone": "+70511509968"}
0005434908466	C7C10E	1129 262198	NIKOLAY IVANOV	{"email": "ivanovn.1974@postgrespro.ru", "phone": "+70734408151"}
0005434908467	B565E2	6501 590990	YURIY SOROKIN	{"phone": "+70069771298"}
0005434908468	3DF0E5	1993 895656	ANGELINA KOZLOVA	{"email": "kozlovaangelina_1975@postgrespro.ru", "phone": "+70209875048"}
0005434908469	70B535	3788 368905	ELENA ANTONOVA	{"phone": "+70469844592"}
0005434908470	B0CC3E	1849 892719	ANNA KONDRATEVA	{"phone": "+70781480823"}
0005434908471	E0B0E7	6461 513820	SERGEY KAZAKOV	{"email": "sergey-kazakov-041984@postgrespro.ru", "phone": "+70629356017"}
0005434908472	AB3847	8269 272908	SERGEY MAKSIMOV	{"phone": "+70252729178"}
0005434908473	5B562E	2608 957346	PELAGEYA TIKHONOVA	{"email": "p.tikhonova.1975@postgrespro.ru", "phone": "+70600339121"}
0005434908474	083655	3988 910638	GALINA SIDOROVA	{"email": "sidorova_g-13111979@postgrespro.ru", "phone": "+70614365947"}
0005434908475	40C527	7638 579655	SERGEY ANDREEV	{"email": "andreev_s.1960@postgrespro.ru", "phone": "+70314555136"}
0005434908476	40C527	7953 611812	MAKSIM KAZAKOV	{"phone": "+70219690810"}
0005434908477	0607F5	6997 240492	MIKHAIL MARTYNOV	{"email": "martynov.mikhail_1983@postgrespro.ru", "phone": "+70328661713"}
0005434908478	D574BD	9421 088454	DMITRIY SAVELEV	{"phone": "+70427679791"}
0005434908479	D574BD	1968 591243	ALLA PETROVA	{"email": "apetrova-24031979@postgrespro.ru", "phone": "+70975807682"}
0005434908480	B5A211	2860 289816	ALEKSANDR TIKHONOV	{"email": "a_tikhonov27091978@postgrespro.ru", "phone": "+70207394734"}
0005434908481	B5A211	1845 825348	EVGENIY GORBUNOV	{"phone": "+70914451728"}
0005434908482	26DDAA	8491 962807	MARIYA BORISOVA	{"phone": "+70189482351"}
0005434908483	B0B67E	7494 549767	ANNA MALYSHEVA	{"phone": "+70044826095"}
0005434908484	975E52	9898 991354	VYACHESLAV ISAEV	{"phone": "+70384894152"}
0005434908486	7E3BC0	3971 195854	TAISIYA POPOVA	{"phone": "+70441332158"}
0005434908487	869FAF	0036 088514	VLADIMIR SIDOROV	{"phone": "+70091362725"}
0005434908488	23AA21	8130 423650	ALENA ZOTOVA	{"phone": "+70959636761"}
0005434908489	23AA21	2788 397505	ALLA NAUMOVA	{"phone": "+70005412111"}
0005434908490	27C7FA	6724 904737	INNA KARPOVA	{"email": "inna_karpova1964@postgrespro.ru", "phone": "+70753284401"}
0005434908491	27C7FA	5320 047367	STEPAN GAVRILOV	{"phone": "+70645965501"}
0005434908492	611596	3170 205349	YULIYA DANILOVA	{"email": "danilovayuliya.05091959@postgrespro.ru", "phone": "+70743841969"}
0005434908493	611596	9990 944400	YURIY PETROV	{"email": "y_petrov-1971@postgrespro.ru", "phone": "+70294354694"}
0005434908494	913837	0520 435134	ALEKSEY BORISOV	{"email": "borisov.aleksey-051986@postgrespro.ru", "phone": "+70114419689"}
0005434908495	913837	4540 925205	RAISA TITOVA	{"phone": "+70924946863"}
0005434908496	B9ABB6	2399 573941	VIOLETTA KUZNECOVA	{"email": "kuznecova-violetta.1982@postgrespro.ru", "phone": "+70674531651"}
0005434908497	36B9B8	5172 356026	VYACHESLAV KULIKOV	{"email": "vyacheslav-kulikov14011975@postgrespro.ru", "phone": "+70333326937"}
0005434908498	3F4064	4709 425246	OKSANA MELNIKOVA	{"email": "melnikova.oksana-09011973@postgrespro.ru", "phone": "+70733944882"}
0005434908499	332587	3808 961904	LYUDMILA POPOVA	{"phone": "+70207309387"}
0005434908500	332587	1830 374411	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov-22071975@postgrespro.ru", "phone": "+70384499353"}
0005434908501	877E41	1832 940547	ANNA FEDOROVA	{"phone": "+70019316539"}
0005434908502	43A7A9	4013 969016	OLGA GORBUNOVA	{"phone": "+70218387745"}
0005434908503	3FD1F0	2802 897489	ALEKSEY PETROV	{"phone": "+70205221862"}
0005434908504	2CEE0D	3622 262821	EKATERINA ILINA	{"email": "e_ilina-021981@postgrespro.ru", "phone": "+70946209332"}
0005434908505	578EEF	7758 669269	DMITRIY MOISEEV	{"email": "moiseev_dmitriy-1967@postgrespro.ru", "phone": "+70782292162"}
0005434908506	578EEF	9677 653040	IGOR TIKHONOV	{"phone": "+70292646749"}
0005434908507	47F50E	0056 267334	DENIS PAVLOV	{"phone": "+70636701560"}
0005434908508	AAFD89	6679 298713	SERGEY VOLKOV	{"email": "sergeyvolkov_1969@postgrespro.ru", "phone": "+70961234108"}
0005434908509	D3A5D4	0544 713568	GALINA KALININA	{"phone": "+70733056085"}
0005434908510	BD3CFB	6676 070253	ELENA NOVIKOVA	{"phone": "+70539228580"}
0005434908511	CE0EAC	9565 610879	TIMUR FILIPPOV	{"phone": "+70302998676"}
0005434908512	E4EEA9	1815 855253	VALENTIN PETROV	{"email": "petrov_v_16051974@postgrespro.ru", "phone": "+70808467052"}
0005434908513	E4EEA9	6290 138903	ILYA MIKHAYLOV	{"phone": "+70265837024"}
0005434908514	B041C0	3183 094274	ALEKSANDR SCHERBAKOV	{"phone": "+70328220396"}
0005434908515	B041C0	1066 069243	OLEG ZHURAVLEV	{"email": "zhuravlevoleg_10031980@postgrespro.ru", "phone": "+70472506117"}
0005434908516	BC0D87	7355 501052	ILYA PAVLOV	{"email": "ilya.pavlov-091961@postgrespro.ru", "phone": "+70441371744"}
0005434908517	1E289E	8583 619258	RAISA ALEKSEEVA	{"phone": "+70516760378"}
0005434908518	1E289E	3191 183271	GALINA DMITRIEVA	{"email": "g.dmitrieva081969@postgrespro.ru", "phone": "+70181793705"}
0005434908519	1E289E	1853 348959	EVGENIY POPOV	{"email": "e-popov_21111967@postgrespro.ru", "phone": "+70959896547"}
0005434908520	FACFA1	0872 517063	ALEKSANDR POPOV	{"email": "popov_a.02091958@postgrespro.ru", "phone": "+70191362973"}
0005434908521	FACFA1	4886 049270	RAIS SOROKIN	{"email": "r-sorokin_1964@postgrespro.ru", "phone": "+70869772298"}
0005434908522	A26FAD	2473 779587	ANATOLIY ZHUKOV	{"phone": "+70695951680"}
0005434908523	A26FAD	1903 230311	VIKTOR GRIGOREV	{"phone": "+70285837406"}
0005434908524	4C3DD1	9858 092518	VLADISLAV SHEVCHENKO	{"email": "shevchenko.vladislav_111954@postgrespro.ru", "phone": "+70908593532"}
0005434908525	4C3DD1	9820 628740	ALEKSANDR ANDREEV	{"phone": "+70864983770"}
0005434908526	209B9F	6789 127662	RAISA BELYAEVA	{"email": "belyaeva.r.08081967@postgrespro.ru", "phone": "+70263798956"}
0005434908527	209B9F	3099 223613	YAROSLAV NAZAROV	{"phone": "+70728027334"}
0005434908528	F20BEB	7546 609222	YAN CHERNOV	{"email": "chernovyan1971@postgrespro.ru", "phone": "+70227979702"}
0005434908529	2FDC4D	0479 799730	YURIY ILIN	{"email": "y_ilin.1965@postgrespro.ru", "phone": "+70999160726"}
0005434908530	2FDC4D	1556 216816	ILNAR KAZAKOV	{"phone": "+70462376613"}
0005434908531	FA8DE0	0471 572962	SERGEY SIDOROV	{"email": "sidorov-sergey-1965@postgrespro.ru", "phone": "+70646620219"}
0005434908532	E3491F	5290 509985	MIKHAIL SAVELEV	{"email": "savelev.mikhail_04031971@postgrespro.ru", "phone": "+70534561669"}
0005434908533	7D8F7B	2179 853460	YULIYA SIDOROVA	{"phone": "+70800134116"}
0005434908534	4FB145	3307 480270	ANASTASIYA MIKHAYLOVA	{"phone": "+70526776162"}
0005434908535	448EF7	4965 741174	TIMUR ZAYCEV	{"email": "timurzaycev_041963@postgrespro.ru", "phone": "+70039415434"}
0005434908536	DF7CCA	1861 497998	DENIS KOZLOV	{"email": "kozlov_denis-121979@postgrespro.ru", "phone": "+70854172729"}
0005434908537	9EF09C	1442 627063	MAKSIM BELOV	{"email": "m_belov.21041967@postgrespro.ru", "phone": "+70333348446"}
0005434908538	18C060	4755 714750	GALINA ALEKSEEVA	{"phone": "+70885842890"}
0005434908539	B73AB4	8297 866772	ANFISA DAVYDOVA	{"phone": "+70406100517"}
0005434908540	A361DD	0076 558133	OLGA KISELEVA	{"email": "kiselevaolga-17101967@postgrespro.ru", "phone": "+70028249523"}
0005434908541	56409F	9926 095034	PAVEL IVANOV	{"email": "p_ivanov07011965@postgrespro.ru", "phone": "+70617275776"}
0005434908542	30577C	6205 052718	EVGENIY RODIONOV	{"email": "erodionov06121965@postgrespro.ru", "phone": "+70508229911"}
0005434908543	30577C	8675 025768	ALEKSANDR NIKOLAEV	{"email": "nikolaev_aleksandr-1978@postgrespro.ru", "phone": "+70779837519"}
0005434908544	6C4DFD	2549 000234	ANASTASIYA BARANOVA	{"email": "anastasiya.baranova03031973@postgrespro.ru", "phone": "+70890373144"}
0005434908545	6C4DFD	5508 082347	ELENA MAKAROVA	{"phone": "+70821762803"}
0005434908546	F6DA8F	0424 489313	BORIS SOLOVEV	{"email": "b.solovev-08041969@postgrespro.ru", "phone": "+70853527935"}
0005434908547	14D7D0	0819 225652	EKATERINA BARANOVA	{"email": "ekaterinabaranova091971@postgrespro.ru", "phone": "+70336771311"}
0005434908548	14D7D0	8036 082129	VLADIMIR NAZAROV	{"email": "vladimir-nazarov101968@postgrespro.ru", "phone": "+70036480917"}
0005434908549	2C8CA9	6205 639861	ANDREY MIRONOV	{"email": "mironov-andrey-031973@postgrespro.ru", "phone": "+70860578397"}
0005434908550	2C8CA9	7657 567240	SEMEN KUZMIN	{"phone": "+70611976206"}
0005434908551	5B9186	8456 698212	LYUDMILA IVANOVA	{"email": "livanova.051991@postgrespro.ru", "phone": "+70649218187"}
0005434908552	5B9186	6025 623272	ELENA IVANOVA	{"email": "eivanova_1969@postgrespro.ru", "phone": "+70426183572"}
0005434908553	5B9186	8201 466141	VERA KOROLEVA	{"email": "koroleva_vera-22101967@postgrespro.ru", "phone": "+70103440700"}
0005434908554	03BBDC	6035 977496	NINA KUZNECOVA	{"phone": "+70918668179"}
0005434908555	03BBDC	2990 411082	TATYANA POPOVA	{"email": "popova_tatyana-21051976@postgrespro.ru", "phone": "+70266148791"}
0005434908556	3D7DA9	0450 845583	MARIYA NESTEROVA	{"email": "m_nesterova-021967@postgrespro.ru", "phone": "+70244868764"}
0005434908557	894C59	0235 374318	SVETLANA TARASOVA	{"email": "svetlana.tarasova1977@postgrespro.ru", "phone": "+70123634512"}
0005434908558	FFF37D	6389 860837	LIDIYA SCHERBAKOVA	{"phone": "+70207824625"}
0005434908559	CCC9A9	7978 754437	ANDREY SMIRNOV	{"phone": "+70390883191"}
0005434908560	CCC9A9	4339 662314	ALEKSANDR OSIPOV	{"phone": "+70542404666"}
0005434908561	D26E97	0840 444780	ELENA DANILOVA	{"phone": "+70175367220"}
0005434908562	D26E97	2724 789380	GENNADIY SIDOROV	{"email": "gsidorov_1969@postgrespro.ru", "phone": "+70670180718"}
0005434908563	E482A0	8125 589103	ZOYA KOZLOVA	{"email": "kozlova.zoya.1972@postgrespro.ru", "phone": "+70197457825"}
0005434908564	E482A0	9029 123598	NATALYA MAKAROVA	{"email": "natalya_makarova.1970@postgrespro.ru", "phone": "+70854596591"}
0005434908565	0B0006	8755 307908	ANTON ZHURAVLEV	{"phone": "+70493659092"}
0005434908566	A241D2	1283 255601	ALEKSEY BELOV	{"phone": "+70928923616"}
0005434908567	5CA149	5738 395577	ANTONINA BELOVA	{"email": "antonina-belova-05071971@postgrespro.ru", "phone": "+70367915288"}
0005434908568	5CA149	7001 511937	NIKOLAY KOZLOV	{"phone": "+70611048502"}
0005434908569	5CA149	5119 238693	ZINAIDA ORLOVA	{"email": "orlova_z-28041974@postgrespro.ru", "phone": "+70701717874"}
0005434908570	11224F	7259 498303	SERGEY BARANOV	{"phone": "+70727820700"}
0005434908571	8FACBC	2166 420592	MARAT MEDVEDEV	{"phone": "+70103103135"}
0005434908572	99C43A	1755 120136	KAMIL MIRONOV	{"email": "kamil-mironov30091967@postgrespro.ru", "phone": "+70183250309"}
0005434908573	99C43A	8051 540327	SVETLANA SOKOLOVA	{"email": "sokolova.svetlana-15071972@postgrespro.ru", "phone": "+70625514253"}
0005434908574	99C43A	0321 723946	ALIYA BORISOVA	{"phone": "+70542276113"}
0005434908575	DA2769	9487 596970	MARAT VASILEV	{"phone": "+70370597531"}
0005434908576	DA2769	4043 872898	LYUBOV ANDREEVA	{"phone": "+70943200962"}
0005434908577	FECF67	5420 921190	IRINA GAVRILOVA	{"email": "irina.gavrilova.1967@postgrespro.ru", "phone": "+70881989665"}
0005434908578	FECF67	0806 775214	ALEKSANDR VOLKOV	{"phone": "+70013131644"}
0005434908579	AA3F64	2955 719058	ELENA MIKHAYLOVA	{"phone": "+70400787983"}
0005434908580	AA3F64	9694 106284	IVAN MEDVEDEV	{"email": "medvedevi_1968@postgrespro.ru", "phone": "+70967928096"}
0005434908581	9C2483	2714 558307	SERGEY DAVYDOV	{"email": "sergey-davydov-1964@postgrespro.ru", "phone": "+70919953272"}
0005434908582	9C2483	2784 567072	EVGENIY ISAEV	{"email": "e_isaev_081983@postgrespro.ru", "phone": "+70555004410"}
0005434908583	B5DC5F	3331 252608	VYACHESLAV FILIPPOV	{"email": "vfilippov081977@postgrespro.ru", "phone": "+70982135819"}
0005434908584	B5DC5F	2636 578377	VALENTINA ANDREEVA	{"phone": "+70292983293"}
0005434908585	769DE8	3984 851698	OKSANA AKIMOVA	{"phone": "+70518452871"}
0005434908586	5A1504	7701 602750	YULIYA POPOVA	{"email": "popova.yuliya_1978@postgrespro.ru", "phone": "+70680096697"}
0005434908587	5A1504	7312 583630	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov-1959@postgrespro.ru", "phone": "+70488109898"}
0005434908588	5A1504	7667 971496	PAVEL ISAEV	{"email": "p_isaev15051967@postgrespro.ru", "phone": "+70980495520"}
0005434908589	478006	7207 828068	VLADIMIR POPOV	{"phone": "+70092858121"}
0005434908590	478006	8629 453803	MIKHAIL ROMANOV	{"phone": "+70284238105"}
0005434908591	6A5208	2458 794928	TATYANA KUZMINA	{"email": "tatyana-kuzmina_111981@postgrespro.ru", "phone": "+70077821404"}
0005434908592	96EE86	2808 536157	MARIYA MASLOVA	{"email": "m_maslova_1977@postgrespro.ru", "phone": "+70724364270"}
0005434908593	96EE86	9736 015667	GENNADIY MATVEEV	{"email": "g.matveev.1978@postgrespro.ru", "phone": "+70384641213"}
0005434908594	906DCE	4569 064173	NIKITA KUZNECOV	{"phone": "+70184919736"}
0005434908595	EB1783	1882 328018	LYUDMILA BELYAEVA	{"email": "belyaeva_lyudmila_21061962@postgrespro.ru", "phone": "+70720629653"}
0005434908596	E1918F	7739 081833	VALENTINA ZAYCEVA	{"phone": "+70338837711"}
0005434908597	677173	6981 027013	PETR ILIN	{"email": "p_ilin_1963@postgrespro.ru", "phone": "+70944347023"}
0005434908598	D2C305	7504 116942	IVAN IVANOV	{"phone": "+70032942233"}
0005434908599	421028	4070 946211	DMITRIY MOROZOV	{"phone": "+70910317426"}
0005434908600	421028	1895 092169	IVAN SOROKIN	{"email": "isorokin011963@postgrespro.ru", "phone": "+70565178509"}
0005434908601	C7634E	3535 032789	PAVEL NIKOLAEV	{"phone": "+70322666386"}
0005434908603	AB57FB	0564 256827	EKATERINA ZHUKOVA	{"phone": "+70640812669"}
0005434908604	47EB3C	7157 063235	SERGEY NAZAROV	{"phone": "+70701496848"}
0005434908605	30A39E	4670 301286	DENIS MAKAROV	{"email": "makarov-d04101962@postgrespro.ru", "phone": "+70360544823"}
0005434908606	636E79	6705 267649	ANDREY VASILEV	{"email": "vasileva26011968@postgrespro.ru", "phone": "+70815354585"}
0005434908607	C442A0	0414 155273	ARTEM GORBUNOV	{"phone": "+70298884273"}
0005434908608	C442A0	2130 271671	DANIIL SMIRNOV	{"phone": "+70609234433"}
0005434908609	1B8640	7196 978027	NATALYA AKIMOVA	{"email": "akimovanatalya_01101964@postgrespro.ru", "phone": "+70055236051"}
0005434908610	04D25A	9318 971900	NADEZHDA EFREMOVA	{"phone": "+70750472422"}
0005434908611	DB4A42	7204 225182	VERA LAZAREVA	{"email": "v-lazareva.1969@postgrespro.ru", "phone": "+70503568279"}
0005434908612	DB4A42	7729 256275	TATYANA VASILEVA	{"phone": "+70176869161"}
0005434908613	391DE7	4171 910056	SVETLANA IVANOVA	{"phone": "+70498360278"}
0005434908614	404C63	4655 919107	MARINA MIKHAYLOVA	{"phone": "+70821983505"}
0005434908615	7E3DAF	7044 245009	ILSHAT MARTYNOV	{"phone": "+70471889470"}
0005434908616	D4E9D2	5754 864448	ELEONORA MOROZOVA	{"phone": "+70445169793"}
0005434908617	4DD4BB	0113 948902	ILYA PAVLOV	{"email": "i_pavlov_1975@postgrespro.ru", "phone": "+70480242232"}
0005434908618	4DD4BB	3289 057866	EVGENIY PETROV	{"email": "e-petrov011974@postgrespro.ru", "phone": "+70542886389"}
0005434908619	007989	6994 533111	VLADIMIR SOKOLOV	{"phone": "+70757396824"}
0005434908620	E5D1D7	7178 893475	VLADIMIR MAKSIMOV	{"email": "v-maksimov.1978@postgrespro.ru", "phone": "+70373060191"}
0005434908621	4231B2	2788 115465	ANDREY EGOROV	{"email": "egorov-andrey_23031968@postgrespro.ru", "phone": "+70303530925"}
0005434908622	8C121F	0690 743015	PAVEL SEMENOV	{"phone": "+70026476183"}
0005434908623	8C121F	3931 444821	YAROSLAV ABRAMOV	{"email": "yaroslavabramov.1975@postgrespro.ru", "phone": "+70460760856"}
0005434908624	AEAF5F	6953 877077	RAMIL VOLKOV	{"email": "r_volkov.041977@postgrespro.ru", "phone": "+70146412829"}
0005434908625	39F918	5959 652044	GRIGORIY SIDOROV	{"phone": "+70255504060"}
0005434908626	024847	4714 261242	GALINA GORBUNOVA	{"email": "gorbunova-galina-101971@postgrespro.ru", "phone": "+70543497188"}
0005434908627	0F6640	7874 914244	ALEKSANDR MOROZOV	{"phone": "+70399104845"}
0005434908628	0F6640	0264 965333	OLEG SEMENOV	{"email": "osemenov_1984@postgrespro.ru", "phone": "+70660777611"}
0005434908629	3FF474	6621 086611	ALEKSANDR SCHERBAKOV	{"phone": "+70141879066"}
0005434908630	138650	9054 011962	ALENA GUSEVA	{"email": "a_guseva_18051978@postgrespro.ru", "phone": "+70194922100"}
0005434908631	37F256	0983 650133	GALINA ARKHIPOVA	{"email": "galina.arkhipova-24031977@postgrespro.ru", "phone": "+70921627219"}
0005434908632	FAF6BF	5951 664002	VALENTINA ZAYCEVA	{"email": "v.zayceva.1965@postgrespro.ru", "phone": "+70836623750"}
0005434908633	FAF6BF	6256 020863	VITALIY IVANOV	{"phone": "+70943337433"}
0005434908634	97C0D6	0463 860684	VERA SERGEEVA	{"email": "vera-sergeeva-1964@postgrespro.ru", "phone": "+70516623188"}
0005434908635	02B75A	4521 872876	MIKHAIL DMITRIEV	{"email": "mikhaildmitriev_1979@postgrespro.ru", "phone": "+70086093126"}
0005434908636	78069D	4360 823355	TATYANA VOLKOVA	{"phone": "+70775114749"}
0005434908637	9D256D	1701 365407	TATYANA NIKITINA	{"email": "tatyana-nikitina.021981@postgrespro.ru", "phone": "+70433496385"}
0005434908638	95E403	9743 111552	ANASTASIYA ANTONOVA	{"email": "anastasiya_antonova041969@postgrespro.ru", "phone": "+70980962210"}
0005434908639	F8E0F9	3260 012672	ALFIYA IVANOVA	{"email": "ivanovaa.061976@postgrespro.ru", "phone": "+70844836564"}
0005434908640	044F0B	8750 365541	LYUDMILA ANDREEVA	{"email": "andreevalyudmila-071966@postgrespro.ru", "phone": "+70275243485"}
0005434908641	044F0B	4956 329097	YURIY CHERNOV	{"email": "yuriy_chernov.1984@postgrespro.ru", "phone": "+70487983756"}
0005434908642	044F0B	9934 072659	NATALYA NOVIKOVA	{"email": "novikova.n_30041971@postgrespro.ru", "phone": "+70806740578"}
0005434908643	2390D9	7171 208841	ALSU VOROBEVA	{"email": "vorobevaa.1979@postgrespro.ru", "phone": "+70295321767"}
0005434908644	FD5353	1171 791248	TAMARA MAKSIMOVA	{"email": "tamara_maksimova_29091963@postgrespro.ru", "phone": "+70790875864"}
0005434908645	B9C942	5904 680005	GENNADIY SCHERBAKOV	{"phone": "+70965082211"}
0005434908646	B6B445	2814 335145	EKATERINA FEDOROVA	{"phone": "+70164960279"}
0005434908647	128DD7	6794 720691	SERGEY KUZNECOV	{"email": "kuznecov_s19091977@postgrespro.ru", "phone": "+70033966495"}
0005434908648	0C8563	5925 224033	ANNA MELNIKOVA	{"phone": "+70877342428"}
0005434908649	0C8563	8573 369178	VIKTOR VOLKOV	{"phone": "+70492360083"}
0005434908650	69B0CE	7283 204110	MARINA SEMENOVA	{"phone": "+70552257025"}
0005434908651	033F6B	4569 658841	VLADISLAV GRIGOREV	{"phone": "+70447687901"}
0005434908652	033F6B	2094 641433	VLADIMIR YAKOVLEV	{"email": "vladimir-yakovlev081963@postgrespro.ru", "phone": "+70248239112"}
0005434908653	033F6B	9944 115977	ARKADIY PAVLOV	{"email": "a-pavlov.30041967@postgrespro.ru", "phone": "+70887395824"}
0005434908654	3FB3CF	8421 626971	DANILA MARTYNOV	{"email": "martynov_danila04081965@postgrespro.ru", "phone": "+70413250173"}
0005434908655	02CCCF	5701 594252	VLADIMIR BELOV	{"phone": "+70417938457"}
0005434908656	02CCCF	7288 609368	LYUDMILA MIKHAYLOVA	{"phone": "+70595517351"}
0005434908657	06C389	7972 011235	ALEKSANDR NIKOLAEV	{"email": "a_nikolaev.18051981@postgrespro.ru", "phone": "+70366687559"}
0005434908658	06C389	3198 618828	NATALYA KUZMINA	{"phone": "+70645015957"}
0005434908659	4A927D	7774 122388	MAKSIM ZHUKOV	{"email": "m-zhukov_041982@postgrespro.ru", "phone": "+70327332241"}
0005434908660	DA0590	0391 339551	VITALIY POPOV	{"email": "popov_vitaliy.021968@postgrespro.ru", "phone": "+70243545880"}
0005434908661	DA0590	9371 709132	VLADIMIR GERASIMOV	{"phone": "+70930852984"}
0005434908662	B6ED2C	1326 717707	RUSLAN NAUMOV	{"phone": "+70016439190"}
0005434908663	B6ED2C	1658 751270	PAVEL IVANOV	{"email": "pavelivanov-011973@postgrespro.ru", "phone": "+70918960626"}
0005434908664	F9F2D1	9292 330161	VIKTOR POPOV	{"phone": "+70685093537"}
0005434908665	D8E12B	7785 627459	DMITRIY YAKOVLEV	{"email": "yakovlev-d1967@postgrespro.ru", "phone": "+70789053006"}
0005434908666	D8E12B	0824 710763	NINA PAVLOVA	{"email": "nina_pavlova16041969@postgrespro.ru", "phone": "+70138191956"}
0005434908667	71F8E0	5751 281096	LYUBOV KUZNECOVA	{"phone": "+70081325964"}
0005434908668	71F8E0	7839 457581	IRINA MIKHAYLOVA	{"email": "mikhaylova_i_111987@postgrespro.ru", "phone": "+70635339554"}
0005434908669	5DA53F	9008 174101	LILIYA DENISOVA	{"email": "denisoval.27021971@postgrespro.ru", "phone": "+70223038342"}
0005434908670	D50CC2	9492 696039	ANTONINA KAZAKOVA	{"phone": "+70918606599"}
0005434908671	8BF936	7012 754308	KSENIYA FADEEVA	{"email": "kseniya.fadeeva_1975@postgrespro.ru", "phone": "+70687272402"}
0005434908672	F576C0	8531 031587	GENNADIY ZHUKOV	{"email": "zhukov_gennadiy_111970@postgrespro.ru", "phone": "+70762598592"}
0005434908673	2325CF	6923 614159	VLADIMIR IVANOV	{"email": "v.ivanov-1962@postgrespro.ru", "phone": "+70914417740"}
0005434908674	171538	7141 155147	OKSANA FILIPPOVA	{"email": "o.filippova-051971@postgrespro.ru", "phone": "+70300022302"}
0005434908675	171538	9747 590363	ANATOLIY MIRONOV	{"email": "mironov-anatoliy-061974@postgrespro.ru", "phone": "+70390820736"}
0005434908676	171538	4581 563773	YULIYA POPOVA	{"email": "y-popova061973@postgrespro.ru", "phone": "+70923480204"}
0005434908677	BFD260	3625 399920	VALENTINA SOROKINA	{"email": "vsorokina011956@postgrespro.ru", "phone": "+70085854783"}
0005434908678	5F0E13	8509 062767	IGOR SOROKIN	{"email": "igor-sorokin.12021975@postgrespro.ru", "phone": "+70602407261"}
0005434908679	9ED483	3368 294650	GALINA SMIRNOVA	{"email": "galina_smirnova.1969@postgrespro.ru", "phone": "+70937141116"}
0005434908680	94F60B	6242 038024	ALEKSEY TARASOV	{"email": "aleksey.tarasov-1958@postgrespro.ru", "phone": "+70183213915"}
0005434908681	94F60B	7374 174635	NATALYA KONDRATEVA	{"phone": "+70837057280"}
0005434908682	C749D7	2643 217280	NIKOLAY STEPANOV	{"phone": "+70179889650"}
0005434908683	8C8436	2415 688765	ELENA TIMOFEEVA	{"phone": "+70913070376"}
0005434908684	8C8436	1512 838867	DARYA GUSEVA	{"email": "guseva-darya-091956@postgrespro.ru", "phone": "+70911991400"}
0005434908685	5B4153	9195 297639	LYUDMILA ZAKHAROVA	{"phone": "+70812443513"}
0005434908686	5B4153	6493 690921	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir-071974@postgrespro.ru", "phone": "+70298640904"}
0005434908687	8660DD	7240 231451	SERGEY MATVEEV	{"phone": "+70383153348"}
0005434908688	B75EDC	3897 937082	IRINA SOROKINA	{"email": "sorokina-irina-031976@postgrespro.ru", "phone": "+70545466866"}
0005434908689	C64740	9401 732415	NIKOLAY KARPOV	{"email": "karpov-nikolay.1976@postgrespro.ru", "phone": "+70554299560"}
0005434908690	2015F7	0143 535304	IVAN MELNIKOV	{"email": "melnikovi-15081981@postgrespro.ru", "phone": "+70149630484"}
0005434908691	CE5108	8876 687053	LYUDMILA TIMOFEEVA	{"email": "ltimofeeva1979@postgrespro.ru", "phone": "+70874966452"}
0005434908692	9F07BC	0018 212378	NADEZHDA DMITRIEVA	{"email": "n_dmitrieva-08051967@postgrespro.ru", "phone": "+70314467448"}
0005434908693	9F07BC	1558 258921	ELENA SERGEEVA	{"email": "elena-sergeeva.1971@postgrespro.ru", "phone": "+70377782897"}
0005434908694	23D868	8942 161108	YURIY NAZAROV	{"email": "nazarov-yuriy_031973@postgrespro.ru", "phone": "+70157865380"}
0005434908695	23D868	1648 501870	MARINA PETROVA	{"email": "petrovamarina-031968@postgrespro.ru", "phone": "+70034871186"}
0005434908696	AD6C1F	1527 083998	ELENA IVANOVA	{"email": "ivanova-elena_1973@postgrespro.ru", "phone": "+70088020853"}
0005434908697	AD6C1F	0428 559662	EVGENIY ALEKSEEV	{"phone": "+70167058099"}
0005434908698	42ADD5	3732 437218	ANDREY MELNIKOV	{"phone": "+70448647927"}
0005434908699	E3D3D4	3143 715157	SERGEY KARPOV	{"phone": "+70369161777"}
0005434908700	6E05A0	1168 271590	LYUBOV SIDOROVA	{"email": "sidoroval1976@postgrespro.ru", "phone": "+70794025587"}
0005434908701	0BFE2B	3751 379560	LYUBOV MELNIKOVA	{"email": "melnikova_l_1967@postgrespro.ru", "phone": "+70310523766"}
0005434908702	BF0756	0042 419482	DANILA ANDREEV	{"phone": "+70272031009"}
0005434908703	BF0756	2313 008751	GENNADIY MOROZOV	{"phone": "+70879870230"}
0005434908704	510A2F	3936 954811	ZINAIDA BORISOVA	{"email": "z_borisova1969@postgrespro.ru", "phone": "+70814571097"}
0005434908705	5D7A2E	6033 010463	ALEKSANDR MELNIKOV	{"email": "amelnikov-1968@postgrespro.ru", "phone": "+70098601279"}
0005434908706	C1758D	9541 305582	NATALYA ANTONOVA	{"phone": "+70916264500"}
0005434908707	53746A	0440 408638	EKATERINA IVANOVA	{"phone": "+70634549551"}
0005434908708	5F3B91	4005 432294	LILIYA YAKOVLEVA	{"email": "yakovleva-l-051977@postgrespro.ru", "phone": "+70364297052"}
0005434908709	5F3B91	4947 924716	SERGEY KUDRYASHOV	{"email": "kudryashov-sergey-30041972@postgrespro.ru", "phone": "+70939244790"}
0005434908710	C7D3EB	4599 006403	ALEKSANDR FEDOTOV	{"phone": "+70033932823"}
0005434908711	67038D	8594 329830	TATYANA ZOTOVA	{"email": "zotova_tatyana_1968@postgrespro.ru", "phone": "+70602330339"}
0005434908712	622540	2860 406436	LYUBOV RODIONOVA	{"phone": "+70013757718"}
0005434908713	228945	8905 327128	MARIYA MEDVEDEVA	{"phone": "+70097069917"}
0005434908714	756F66	0129 103837	EKATERINA KRASNOVA	{"email": "krasnova.e_011980@postgrespro.ru", "phone": "+70796731536"}
0005434908715	756F66	0904 488767	RAFAIL IVANOV	{"email": "rafailivanov.011977@postgrespro.ru", "phone": "+70343025485"}
0005434908716	7A8674	6419 778682	MARIYA IVANOVA	{"phone": "+70764022557"}
0005434908717	C9BB7A	5069 948282	TATYANA POPOVA	{"phone": "+70436709390"}
0005434908718	A0C3D8	3695 496471	ANDREY KOZLOV	{"email": "a-kozlov_21071965@postgrespro.ru", "phone": "+70889690611"}
0005434908719	4536E3	4901 486238	OLEG MEDVEDEV	{"email": "omedvedev.091981@postgrespro.ru", "phone": "+70198008496"}
0005434908720	E1BC65	9821 323084	INNA KOMAROVA	{"email": "komarova.i-1970@postgrespro.ru", "phone": "+70959698446"}
0005434908721	BF0854	7480 230085	DANIIL KUZNECOV	{"email": "d_kuznecov_20111981@postgrespro.ru", "phone": "+70732949891"}
0005434908722	BF0854	0672 960817	VLADIMIR ORLOV	{"phone": "+70976909474"}
0005434908723	3BCBEC	7278 414798	NIKOLAY ZHUKOV	{"phone": "+70820935783"}
0005434908724	043C65	0203 976486	NADEZHDA VOROBEVA	{"email": "vorobeva-n19111979@postgrespro.ru", "phone": "+70279188102"}
0005434908725	191DB8	6494 606230	ILGIZ MELNIKOV	{"phone": "+70985453468"}
0005434908726	882F3A	0040 003545	EKATERINA ZAKHAROVA	{"phone": "+70511610734"}
0005434908727	30F20A	8018 183382	IVAN KONOVALOV	{"phone": "+70339775289"}
0005434908728	43AB4D	6851 146805	SOFIYA LUKYANOVA	{"email": "lukyanova-sofiya1973@postgrespro.ru", "phone": "+70490514841"}
0005434908729	43AB4D	0066 639283	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev.02091977@postgrespro.ru", "phone": "+70133346099"}
0005434908730	AD4809	2630 111774	DARYA LEBEDEVA	{"email": "lebedeva_d1976@postgrespro.ru", "phone": "+70427540965"}
0005434908731	AD4809	1639 945907	ALEKSEY MARTYNOV	{"phone": "+70659330210"}
0005434908732	303BE1	4992 650719	DMITRIY CHERNOV	{"email": "d_chernov-031975@postgrespro.ru", "phone": "+70845594506"}
0005434908733	303BE1	0075 507901	IRINA MASLOVA	{"phone": "+70006419722"}
0005434908734	12C85A	2001 969732	NINA MELNIKOVA	{"phone": "+70484088753"}
0005434908735	AF3706	8816 349234	OLEG SAVELEV	{"email": "olegsavelev_24031966@postgrespro.ru", "phone": "+70758594239"}
0005434908736	202BBA	5200 627352	TATYANA ABRAMOVA	{"phone": "+70512097963"}
0005434908737	202BBA	5515 241676	TAMARA FADEEVA	{"email": "fadeeva-t_1967@postgrespro.ru", "phone": "+70330411781"}
0005434908738	D88086	4967 361924	NINA NESTEROVA	{"phone": "+70010626055"}
0005434908739	CA3114	7141 699025	SERGEY DENISOV	{"phone": "+70619654449"}
0005434908740	5709FB	6312 881341	VADIM KUDRYASHOV	{"phone": "+70533613354"}
0005434908741	B63E17	4327 411388	SVETLANA MALYSHEVA	{"email": "malysheva-s-031981@postgrespro.ru", "phone": "+70411919563"}
0005434908742	83BF51	4046 378961	NATALYA ISAEVA	{"phone": "+70373127370"}
0005434908743	83BF51	2162 859531	NIKOLAY SIDOROV	{"phone": "+70789989904"}
0005434908744	84421B	4142 943027	IVAN NIKITIN	{"phone": "+70448050840"}
0005434908745	D88ACF	4895 813002	TATYANA NESTEROVA	{"email": "nesterova.tatyana-16021980@postgrespro.ru", "phone": "+70403508280"}
0005434908746	9C21CF	0134 463224	NINA FROLOVA	{"email": "frolovanina_1961@postgrespro.ru", "phone": "+70638855463"}
0005434908747	FB0232	1954 924165	OLGA ZAKHAROVA	{"email": "ozakharova.091963@postgrespro.ru", "phone": "+70432739512"}
0005434908748	D6A420	2195 605876	ELENA SMIRNOVA	{"email": "e-smirnova-091972@postgrespro.ru", "phone": "+70289339672"}
0005434908749	7E75C2	5914 687533	VERA STEPANOVA	{"phone": "+70604908096"}
0005434908750	E2D47E	3635 411310	RAISA RODIONOVA	{"email": "raisa-rodionova1969@postgrespro.ru", "phone": "+70003931958"}
0005434908751	17EAB8	6725 821648	YULIYA MAKSIMOVA	{"phone": "+70498251950"}
0005434908752	B3243B	4632 108752	ALEKSANDR ZHUKOV	{"phone": "+70027873860"}
0005434908753	BB0866	5318 534609	ALEKSEY SAVELEV	{"phone": "+70229358064"}
0005434908754	BB0866	4492 307527	ELENA ZOTOVA	{"email": "elenazotova03011982@postgrespro.ru", "phone": "+70880525522"}
0005434908755	0689ED	2116 854813	ALEKSANDR ZAYCEV	{"phone": "+70664442006"}
0005434908756	0689ED	8203 839322	ELENA VOROBEVA	{"email": "elena-vorobeva02031971@postgrespro.ru", "phone": "+70779866361"}
0005434908757	7E9596	5819 487146	ANGELINA POPOVA	{"phone": "+70045999940"}
0005434908758	7E9596	1422 825612	SERGEY MIRONOV	{"phone": "+70832069999"}
0005434908759	8DAAD0	0230 517815	MAKSIM ORLOV	{"email": "maksim_orlov-1970@postgrespro.ru", "phone": "+70186769882"}
0005434908760	C10A0E	0020 134917	TAMARA PAVLOVA	{"email": "t_pavlova111971@postgrespro.ru", "phone": "+70304867192"}
0005434908761	A3A856	1338 425685	ALEKSANDR FEDOROV	{"phone": "+70629261765"}
0005434908762	C28043	0987 706653	ANDREY NIKITIN	{"phone": "+70230470922"}
0005434908763	388120	0300 798876	ALEKSANDR MEDVEDEV	{"email": "a_medvedev_1981@postgrespro.ru", "phone": "+70329441765"}
0005434908764	796331	8899 186462	NATALYA NOVIKOVA	{"phone": "+70463836207"}
0005434908765	875530	1453 161884	MARIYA KOVALEVA	{"email": "kovaleva-mariya.081972@postgrespro.ru", "phone": "+70345528836"}
0005434908766	875530	7132 839791	PETR SIDOROV	{"phone": "+70408323092"}
0005434908767	875530	9103 024177	ANTONINA MIRONOVA	{"phone": "+70007166494"}
0005434908768	857FB2	0239 834928	ROMAN ALEKSEEV	{"email": "alekseev.roman-16041978@postgrespro.ru", "phone": "+70374814589"}
0005434908769	E6077C	7520 585573	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov_1973@postgrespro.ru", "phone": "+70553241623"}
0005434908825	987E0B	1263 681278	TAISIYA MAKAROVA	{"phone": "+70843092283"}
0005434908770	969EC4	8563 543251	MIKHAIL DAVYDOV	{"email": "davydov.mikhail_111979@postgrespro.ru", "phone": "+70518141140"}
0005434908771	6481F5	0201 876742	ANDREY KUZMIN	{"phone": "+70121263410"}
0005434908772	F2FA4A	4560 897426	OLGA ZHUKOVA	{"phone": "+70914000944"}
0005434908773	A60BF7	8155 875651	ALEKSEY IVANOV	{"email": "ivanov.a.101973@postgrespro.ru", "phone": "+70303515439"}
0005434908774	9AAF2D	6696 239113	RAISA SIDOROVA	{"phone": "+70937589870"}
0005434908775	6083BD	4658 474170	ANATOLIY MOISEEV	{"email": "anatoliy_moiseev.1977@postgrespro.ru", "phone": "+70822229867"}
0005434908776	861E28	3479 509447	ANNA STEPANOVA	{"email": "anna_stepanova20091966@postgrespro.ru", "phone": "+70286874354"}
0005434908777	B37DA8	5098 032142	ALEKSANDR TIMOFEEV	{"phone": "+70123540280"}
0005434908778	B37DA8	8444 812088	ELENA ABRAMOVA	{"phone": "+70141155992"}
0005434908779	60E49A	6320 043405	IVAN SCHERBAKOV	{"email": "ivanscherbakov_121968@postgrespro.ru", "phone": "+70350530183"}
0005434908780	6BB7F8	4856 925891	ANZHELA MARTYNOVA	{"phone": "+70903215488"}
0005434908781	F34657	0387 676498	IRINA VASILEVA	{"phone": "+70761924948"}
0005434908782	E42996	9583 429574	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a_1974@postgrespro.ru", "phone": "+70938707735"}
0005434908783	D7BD92	4142 668557	ALEKSANDR AFANASEV	{"email": "afanasev_a-061971@postgrespro.ru", "phone": "+70627118159"}
0005434908784	451AA3	0026 347429	NINA YUDINA	{"phone": "+70271839076"}
0005434908785	451AA3	8276 134791	EKATERINA MAKAROVA	{"email": "e_makarova-031979@postgrespro.ru", "phone": "+70912321956"}
0005434908786	B73B67	2996 908376	NATALYA ZAKHAROVA	{"email": "nzakharova-11101952@postgrespro.ru", "phone": "+70861706236"}
0005434908787	1769DD	0312 934171	VALENTINA SEMENOVA	{"email": "semenova-valentina051972@postgrespro.ru", "phone": "+70106694194"}
0005434908788	1769DD	6930 894567	VLADISLAV ZAYCEV	{"email": "zaycev-v.28051969@postgrespro.ru", "phone": "+70590317741"}
0005434908789	B8E837	0215 575357	KLARA FADEEVA	{"email": "fadeevak.061976@postgrespro.ru", "phone": "+70770478572"}
0005434908790	6BDFCF	1361 991423	GALINA SOLOVEVA	{"email": "soloveva_galina_091952@postgrespro.ru", "phone": "+70053033790"}
0005434908791	0C913A	6960 691869	SERGEY STEPANOV	{"phone": "+70676056955"}
0005434908792	0C913A	7305 979742	GULSINA FADEEVA	{"email": "fadeeva-gulsina_11011966@postgrespro.ru", "phone": "+70960901357"}
0005434908793	DB60DE	0123 412038	ANASTASIYA GAVRILOVA	{"email": "gavrilova_a-1964@postgrespro.ru", "phone": "+70720110190"}
0005434908794	EAB8B0	4461 494067	OKSANA MAKSIMOVA	{"phone": "+70382727278"}
0005434908795	EAB8B0	8214 677058	VALENTINA TIMOFEEVA	{"phone": "+70623053980"}
0005434908796	B0D9D0	4084 215540	PETR PAVLOV	{"email": "pavlov-petr-01021971@postgrespro.ru", "phone": "+70917996123"}
0005434908797	B0D9D0	0183 476274	MIKHAIL VOLKOV	{"email": "mikhailvolkov1977@postgrespro.ru", "phone": "+70650744903"}
0005434908798	0E4028	0576 208180	VALERIY ROMANOV	{"email": "romanov.valeriy15111972@postgrespro.ru", "phone": "+70014579025"}
0005434908799	8EC44D	8711 329331	DMITRIY DMITRIEV	{"phone": "+70576349831"}
0005434908800	8EC44D	8026 759704	DENIS DENISOV	{"email": "denis_denisov1976@postgrespro.ru", "phone": "+70178130372"}
0005434908801	1E5FF0	0557 922446	NATALYA GAVRILOVA	{"phone": "+70417088777"}
0005434908802	3CA305	3076 139439	IGOR ZAKHAROV	{"email": "zakharovi1969@postgrespro.ru", "phone": "+70328069976"}
0005434908803	A62418	4187 423149	EKATERINA ALEKSEEVA	{"phone": "+70108535406"}
0005434908804	202C0C	2512 524931	NINA POPOVA	{"phone": "+70694136569"}
0005434908805	E36BC3	1713 415022	EGOR GUSEV	{"phone": "+70689297835"}
0005434908806	E36BC3	5750 969675	ANNA ILINA	{"email": "anna.ilina.1976@postgrespro.ru", "phone": "+70497879552"}
0005434908807	729F3F	7352 529655	MARINA ALEKSEEVA	{"email": "alekseeva_marina071982@postgrespro.ru", "phone": "+70253072068"}
0005434908808	00F3B9	4829 052511	IRINA FILIPPOVA	{"phone": "+70156490373"}
0005434908809	00F3B9	7349 179319	DANIIL ANTONOV	{"email": "daniil_antonov_23021971@postgrespro.ru", "phone": "+70561626792"}
0005434908810	00F3B9	7460 081373	LIYA VASILEVA	{"phone": "+70898884208"}
0005434908811	D8E69C	4901 061809	SVETLANA VLASOVA	{"email": "vlasovas-14091973@postgrespro.ru", "phone": "+70536083650"}
0005434908812	242C1F	1437 507046	ARTEM MOROZOV	{"email": "morozovartem_101968@postgrespro.ru", "phone": "+70308874324"}
0005434908813	BCEF25	1367 962062	PLATON ALEKSANDROV	{"email": "p.aleksandrov_1968@postgrespro.ru", "phone": "+70244982679"}
0005434908814	9ADAC3	1053 156065	NADEZHDA SOKOLOVA	{"email": "sokolova-n-091989@postgrespro.ru", "phone": "+70255689307"}
0005434908815	528AA8	2234 038768	ALEKSANDR VOLKOV	{"email": "a-volkov.07021965@postgrespro.ru", "phone": "+70901813670"}
0005434908816	D0FE95	3700 377614	YURIY EGOROV	{"phone": "+70277414642"}
0005434908817	6D38EB	8519 690654	DMITRIY KUZNECOV	{"email": "dkuznecov1972@postgrespro.ru", "phone": "+70503262259"}
0005434908818	BE3A6D	0188 152773	NIKITA NIKOLAEV	{"phone": "+70410106057"}
0005434908819	BE3A6D	0130 191076	TAMARA MAKAROVA	{"email": "makarova_t.091973@postgrespro.ru", "phone": "+70611681477"}
0005434908820	585913	8612 219962	ELMIRA SERGEEVA	{"phone": "+70479686862"}
0005434908821	8BF3DC	9193 473262	DENIS FROLOV	{"email": "denisfrolov-101969@postgrespro.ru", "phone": "+70585823815"}
0005434908822	C17516	7449 067289	ALEKSANDR MOROZOV	{"email": "amorozov.23121976@postgrespro.ru", "phone": "+70413706844"}
0005434908823	59795E	7872 351000	DMITRIY KRASNOV	{"email": "dmitriy.krasnov_24081979@postgrespro.ru", "phone": "+70758827962"}
0005434908824	987E0B	2297 562543	DMITRIY DAVYDOV	{"email": "d_davydov.121978@postgrespro.ru", "phone": "+70872508872"}
0005434908826	0A7EAC	6219 315124	EGOR KUDRYASHOV	{"email": "e_kudryashov1974@postgrespro.ru", "phone": "+70947908019"}
0005434908827	AC5C7C	2676 506550	IGOR MAKAROV	{"phone": "+70425477605"}
0005434908828	AC5C7C	4789 827881	PAVEL TIMOFEEV	{"email": "timofeev.pavel1953@postgrespro.ru", "phone": "+70313604185"}
0005434908829	429F8E	1943 045718	VLADISLAV KUZNECOV	{"email": "vladislavkuznecov_1971@postgrespro.ru", "phone": "+70351402228"}
0005434908830	429F8E	1330 846105	MARIYA VOLKOVA	{"phone": "+70368985392"}
0005434908831	D10ED3	4185 213434	ELENA MAKSIMOVA	{"email": "elena.maksimova-10021973@postgrespro.ru", "phone": "+70588279971"}
0005434908832	D10ED3	6035 441941	NIKITA SEMENOV	{"email": "n_semenov.21061956@postgrespro.ru", "phone": "+70713383881"}
0005434908833	D10ED3	9885 013520	ALEKSEY POPOV	{"phone": "+70413076746"}
0005434908834	56086E	7983 225907	ELENA LAZAREVA	{"phone": "+70782280482"}
0005434908835	56086E	4219 353927	MARGARITA ROMANOVA	{"email": "margarita_romanova_121966@postgrespro.ru", "phone": "+70688988469"}
0005434908836	719179	8737 296112	SERGEY IVANOV	{"phone": "+70109124085"}
0005434908837	8F2E9A	9344 773916	PAVEL ZAKHAROV	{"email": "p_zakharov_01081964@postgrespro.ru", "phone": "+70083005719"}
0005434908838	FE3121	5214 950986	ANTON SMIRNOV	{"email": "antonsmirnov-1976@postgrespro.ru", "phone": "+70968267619"}
0005434908839	FE3121	9136 494181	POLINA LUKYANOVA	{"phone": "+70500808179"}
0005434908840	8BDB96	7341 101666	ANASTASIYA CHERNOVA	{"email": "chernova.anastasiya17111967@postgrespro.ru", "phone": "+70420789802"}
0005434908841	8BDB96	1783 379507	VALENTINA KALININA	{"phone": "+70239566215"}
0005434908842	18AEE5	4288 132251	VLADISLAV OSIPOV	{"email": "v-osipov-071986@postgrespro.ru", "phone": "+70799660120"}
0005434908843	0C54C1	0692 529780	OLEG ILIN	{"email": "ilin-oleg.02101974@postgrespro.ru", "phone": "+70495254743"}
0005434908844	C1921C	2698 933348	MARGARITA ZHUKOVA	{"phone": "+70374844723"}
0005434908845	CB57C6	5819 736334	ALEKSANDR BARANOV	{"email": "baranov_a081969@postgrespro.ru", "phone": "+70212647032"}
0005434908846	CAC45D	0346 194329	VERA POPOVA	{"email": "popova-vera-22021977@postgrespro.ru", "phone": "+70925476914"}
0005434908847	839F9A	1125 434495	IGOR VASILEV	{"phone": "+70855329033"}
0005434908848	839F9A	1534 501478	SERGEY MIRONOV	{"phone": "+70416576529"}
0005434908849	68EB69	0957 553386	IVAN FROLOV	{"email": "frolov_ivan.081970@postgrespro.ru", "phone": "+70082909520"}
0005434908850	68EB69	7561 980404	OLGA NIKITINA	{"email": "nikitina_o.14051969@postgrespro.ru", "phone": "+70558313075"}
0005434908851	B96F02	4511 735203	NATALYA SOKOLOVA	{"phone": "+70568663437"}
0005434925316	5CE574	8762 666481	GRIGORIY TIMOFEEV	{"phone": "+70495327277"}
0005434908852	97BF4E	0199 014125	NATALYA ANTONOVA	{"email": "natalya_antonova.26101975@postgrespro.ru", "phone": "+70960311788"}
0005434908853	97BF4E	4339 074946	OLGA EGOROVA	{"email": "olgaegorova_021984@postgrespro.ru", "phone": "+70839090252"}
0005434908854	90AD04	3428 650998	GENNADIY ILIN	{"phone": "+70742338692"}
0005434908855	FF226B	4448 211381	SVETLANA ALEKSEEVA	{"email": "alekseeva_svetlana-1975@postgrespro.ru", "phone": "+70305329284"}
0005434908856	FF226B	4558 240468	ANATOLIY VOROBEV	{"email": "vorobev-a021977@postgrespro.ru", "phone": "+70911103416"}
0005434908857	61EBFC	2326 007976	MAKSIM MOROZOV	{"email": "morozov_maksim-17031974@postgrespro.ru", "phone": "+70566539228"}
0005434908858	AF75B4	1989 908335	OLGA BELYAEVA	{"email": "olga-belyaeva.1984@postgrespro.ru", "phone": "+70457497231"}
0005434908859	AF75B4	5927 334415	ALEKSANDR ROMANOV	{"phone": "+70461462088"}
0005434908860	AF75B4	2553 334365	VLADIMIR ANTONOV	{"email": "vladimir_antonov_1971@postgrespro.ru", "phone": "+70240145510"}
0005434908861	8FFAEF	4632 835651	MIKHAIL KULIKOV	{"email": "kulikovmikhail101967@postgrespro.ru", "phone": "+70249086783"}
0005434908862	8FFAEF	4719 617155	ALBERT KUZNECOV	{"phone": "+70240449875"}
0005434908863	8D059C	2884 500877	ARTEM VASILEV	{"email": "vasilevartem27011969@postgrespro.ru", "phone": "+70189036800"}
0005434908864	8D059C	6318 674629	SVETLANA SOROKINA	{"phone": "+70734734477"}
0005434908865	C4A28D	4348 703307	SVETLANA MOISEEVA	{"email": "moiseeva-s_071975@postgrespro.ru", "phone": "+70923261010"}
0005434908866	C4A28D	0168 256998	MARIYA MOISEEVA	{"email": "moiseeva_mariya-14061962@postgrespro.ru", "phone": "+70125425662"}
0005434908867	A0D61D	9607 459381	VLADIMIR FROLOV	{"email": "frolov-vladimir_1956@postgrespro.ru", "phone": "+70026853218"}
0005434908868	79FD36	7762 310948	FARIDA ZHURAVLEVA	{"email": "f.zhuravleva.061971@postgrespro.ru", "phone": "+70291412441"}
0005434908869	79FD36	6097 673441	OLGA POPOVA	{"phone": "+70718975611"}
0005434908870	247440	9538 076777	ANASTASIYA KUZNECOVA	{"phone": "+70844998636"}
0005434908871	E8AC7F	2631 816423	DMITRIY FOMIN	{"email": "fomindmitriy.1978@postgrespro.ru", "phone": "+70947648564"}
0005434908872	E8AC7F	4634 988449	MARIYA TARASOVA	{"email": "tarasova_mariya.13071978@postgrespro.ru", "phone": "+70910861448"}
0005434908873	CF9B50	6963 768984	RAISA MAKAROVA	{"phone": "+70074579260"}
0005434908874	CFF22A	9370 006848	EKATERINA KOROLEVA	{"email": "ekoroleva.1961@postgrespro.ru", "phone": "+70936521971"}
0005434908875	CFF22A	4569 775399	ILYA SIDOROV	{"email": "ilya_sidorov-23091964@postgrespro.ru", "phone": "+70461992290"}
0005434908876	CFF22A	5768 994659	VALERIY KUZNECOV	{"phone": "+70053070392"}
0005434908877	ABB0F9	8198 887862	KRISTINA KOROLEVA	{"phone": "+70133446879"}
0005434908878	847D66	9789 979419	VLADIMIR ZHURAVLEV	{"phone": "+70121341854"}
0005434908879	391731	9409 112424	VYACHESLAV FROLOV	{"email": "frolov.vyacheslav.25071966@postgrespro.ru", "phone": "+70533526911"}
0005434908880	B50EB6	8629 680349	TATYANA YAKOVLEVA	{"email": "tatyana_yakovleva.20041976@postgrespro.ru", "phone": "+70943001623"}
0005434908881	C7F00C	6578 563809	ALEKSEY ALEKSEEV	{"phone": "+70216272819"}
0005434908882	9C6B20	4521 510515	IRINA MIRONOVA	{"email": "i.mironova-051965@postgrespro.ru", "phone": "+70990658946"}
0005434908883	A53E07	0269 035779	ELENA FOMINA	{"email": "fomina-e041972@postgrespro.ru", "phone": "+70497582919"}
0005434908884	E1D0FE	4122 011216	VALERIY POPOV	{"email": "valeriy.popov_081974@postgrespro.ru", "phone": "+70998355157"}
0005434908885	25BCEC	1245 860925	TATYANA KISELEVA	{"email": "tatyanakiseleva08031972@postgrespro.ru", "phone": "+70834900526"}
0005434908886	0876BD	1452 773238	VASILIY DENISOV	{"phone": "+70330569161"}
0005434908887	0876BD	7821 165402	SERGEY MAKSIMOV	{"phone": "+70046778231"}
0005434908888	E74289	4314 062585	ANNA PETROVA	{"email": "anna.petrova-20011968@postgrespro.ru", "phone": "+70100260077"}
0005434908889	08242B	4926 127039	NINA BARANOVA	{"phone": "+70458237874"}
0005434908890	727EF9	5979 938079	LYUDMILA ABRAMOVA	{"phone": "+70888747250"}
0005434908891	727EF9	0275 772440	ELENA ZOTOVA	{"phone": "+70882757651"}
0005434908892	E139A0	3976 487105	YURIY ROMANOV	{"phone": "+70999224926"}
0005434908893	693FB6	2329 115397	EVGENIY MAKSIMOV	{"email": "evgeniy-maksimov081977@postgrespro.ru", "phone": "+70711486802"}
0005434908894	693FB6	1003 875673	LARISA FEDOROVA	{"phone": "+70300185281"}
0005434908895	D27ACA	8405 044159	NATALYA VLASOVA	{"email": "n.vlasova061960@postgrespro.ru", "phone": "+70746104789"}
0005434908896	D27ACA	9146 319766	LYUBOV ALEKSEEVA	{"phone": "+70309764352"}
0005434908897	FED284	1515 215240	VLADISLAV OSIPOV	{"email": "vladislavosipov-04091967@postgrespro.ru", "phone": "+70604619521"}
0005434908898	677809	8478 361679	TATYANA NAZAROVA	{"email": "nazarova_tatyana.30061975@postgrespro.ru", "phone": "+70288999796"}
0005434908899	677809	3725 689573	LIDIYA EGOROVA	{"email": "egorovalidiya1972@postgrespro.ru", "phone": "+70395034198"}
0005434908900	847186	5693 372379	VASILIY SMIRNOV	{"email": "vasiliy_smirnov.111973@postgrespro.ru", "phone": "+70525581963"}
0005434908901	847186	9810 390705	OLESYA OSIPOVA	{"email": "osipovao_1975@postgrespro.ru", "phone": "+70015081903"}
0005434908902	298DCB	4804 676209	ANASTASIYA ZOTOVA	{"phone": "+70759757990"}
0005434908903	63761C	8777 193481	ROMAN PETROV	{"email": "petrov_roman_20021974@postgrespro.ru", "phone": "+70806907148"}
0005434908904	9800ED	4648 350434	KIRILL IVANOV	{"phone": "+70671073179"}
0005434910068	BE0A4B	6497 507183	VALERIY KOZLOV	{"email": "v_kozlov_051976@postgrespro.ru", "phone": "+70562729868"}
0005434910069	B0AAE5	8220 466155	NATALYA BORISOVA	{"phone": "+70736518711"}
0005434910070	B0AAE5	6326 235577	INNA IVANOVA	{"email": "ivanova.inna.24101968@postgrespro.ru", "phone": "+70723580848"}
0005434910071	42943C	4653 362704	ALEKSANDR BELOV	{"phone": "+70684343300"}
0005434910072	E91845	0936 607033	NATALYA EFREMOVA	{"phone": "+70629709761"}
0005434910073	C144BB	3417 850754	IGOR MIRONOV	{"phone": "+70035675345"}
0005434910074	4D90FF	4909 300145	LYUBOV MASLOVA	{"email": "maslova-lyubov_29111970@postgrespro.ru", "phone": "+70830392693"}
0005434910075	B6F975	8366 939019	NATALYA SOKOLOVA	{"email": "nsokolova_1973@postgrespro.ru", "phone": "+70002488992"}
0005434910076	EBA855	4356 462877	GEORGIY DMITRIEV	{"phone": "+70979100476"}
0005434910077	8B180E	7638 371391	EVGENIY KOZLOV	{"phone": "+70062360894"}
0005434910078	8B180E	2905 971266	RAISA GAVRILOVA	{"email": "rgavrilova_08071975@postgrespro.ru", "phone": "+70843950015"}
0005434910079	89052A	4438 773996	NIKOLAY OSIPOV	{"email": "osipov-n.31081967@postgrespro.ru", "phone": "+70410363396"}
0005434910080	89052A	9551 641998	ALINA MOISEEVA	{"phone": "+70271667751"}
0005434910081	89052A	2629 163382	YURIY BARANOV	{"email": "baranov-yuriy.10081979@postgrespro.ru", "phone": "+70510738338"}
0005434910082	08D453	9527 989398	ELENA KAZAKOVA	{"phone": "+70689300350"}
0005434910083	27F2F6	2039 439380	ANATOLIY ANDREEV	{"email": "andreev-anatoliy-13081974@postgrespro.ru", "phone": "+70350409620"}
0005434910084	510A11	8917 749311	IRINA IVANOVA	{"email": "iivanova021975@postgrespro.ru", "phone": "+70339674975"}
0005434910085	510A11	5602 915253	SERGEY SIDOROV	{"phone": "+70711637502"}
0005434910086	8703B6	0011 174597	OLGA MOISEEVA	{"email": "olga_moiseeva1972@postgrespro.ru", "phone": "+70681287223"}
0005434910087	8703B6	7641 215594	SERGEY KUZNECOV	{"email": "kuznecovs_011972@postgrespro.ru", "phone": "+70698107714"}
0005434910088	5DB086	6923 627773	SERGEY SIDOROV	{"phone": "+70858410413"}
0005434910089	6C3BE1	8105 964956	YURIY SEMENOV	{"email": "ysemenov_1966@postgrespro.ru", "phone": "+70384273003"}
0005434910090	DFE5EA	8215 268705	ILYAS IVANOV	{"phone": "+70546556837"}
0005434910091	89AF15	1195 849660	ZULFIYA SMIRNOVA	{"phone": "+70152355205"}
0005434910092	B083BE	8615 448210	SVETLANA BARANOVA	{"phone": "+70384592106"}
0005434910093	B083BE	2036 212724	NADEZHDA KUZNECOVA	{"email": "nadezhda_kuznecova061977@postgrespro.ru", "phone": "+70712460605"}
0005434910094	B083BE	7795 991869	EVGENIY ALEKSANDROV	{"phone": "+70796800292"}
0005434910095	4B17B3	0879 917833	EVGENIY BORISOV	{"phone": "+70986082532"}
0005434910096	4B17B3	5234 794176	ALEKSANDR NAZAROV	{"phone": "+70085366060"}
0005434910097	310118	1340 684433	VLADIMIR SHEVCHENKO	{"email": "shevchenkovladimir-031975@postgrespro.ru", "phone": "+70625808858"}
0005434910098	310118	3011 585293	MARIYA LEBEDEVA	{"email": "lebedevamariya.1972@postgrespro.ru", "phone": "+70040488640"}
0005434910099	D279FA	7095 418084	NIKOLAY VOLKOV	{"phone": "+70224931966"}
0005434910100	D279FA	1854 168697	OLGA TARASOVA	{"phone": "+70033308730"}
0005434910101	D279FA	7772 844829	ALEKSEY EGOROV	{"email": "aleksey_egorov_27091964@postgrespro.ru", "phone": "+70557955110"}
0005434910102	9BED6A	0334 885408	ALEKSANDRA VASILEVA	{"email": "a.vasileva_10091956@postgrespro.ru", "phone": "+70645496596"}
0005434910103	A8EC6D	6238 890881	IRINA EGOROVA	{"email": "egorova.i-21021972@postgrespro.ru", "phone": "+70111984326"}
0005434910104	A8EC6D	2225 457038	KONSTANTIN FILIPPOV	{"phone": "+70051796180"}
0005434910105	2653B0	4971 408451	OKSANA PAVLOVA	{"phone": "+70585518996"}
0005434910106	2653B0	5919 958267	VLADIMIR POPOV	{"phone": "+70147195753"}
0005434910107	33355B	5566 566923	LYUBOV KONOVALOVA	{"email": "lkonovalova1976@postgrespro.ru", "phone": "+70344011864"}
0005434910108	708166	7526 729099	ANATOLIY VOLKOV	{"email": "anatoliyvolkov081978@postgrespro.ru", "phone": "+70170916208"}
0005434910109	0F5AD5	8258 993046	OLGA GORBUNOVA	{"phone": "+70432130134"}
0005434910110	0F5AD5	3164 956702	VALENTINA TROFIMOVA	{"email": "trofimova-v_031974@postgrespro.ru", "phone": "+70446296313"}
0005434910111	592931	0529 440779	VALENTINA ALEKSEEVA	{"phone": "+70221861318"}
0005434910112	63F049	6397 121204	IVAN ILIN	{"phone": "+70160563512"}
0005434910113	63F049	8378 644870	NINA ZOTOVA	{"phone": "+70149055293"}
0005434910114	C80B14	6725 546684	ADELINA ZHURAVLEVA	{"email": "azhuravleva_07081961@postgrespro.ru", "phone": "+70530645455"}
0005434910115	F5E367	5350 253660	SERGEY KARPOV	{"phone": "+70140070962"}
0005434910116	E3E69D	4980 034841	RENAT SOKOLOV	{"email": "r_sokolov_061977@postgrespro.ru", "phone": "+70803762729"}
0005434910117	6D2F2E	2476 875641	YULIYA PAVLOVA	{"phone": "+70980955069"}
0005434910118	6D2F2E	3653 863597	SERGEY GUSEV	{"email": "gusev_sergey_02111968@postgrespro.ru", "phone": "+70062922753"}
0005434910119	D929AF	6882 218514	EVDOKIYA ZAYCEVA	{"phone": "+70007652877"}
0005434910120	9BB5AE	0960 044211	NATALYA OVCHINNIKOVA	{"phone": "+70131077484"}
0005434910121	22B080	6390 267894	VALENTINA IVANOVA	{"email": "ivanovav-22021975@postgrespro.ru", "phone": "+70575870795"}
0005434910122	22B080	1777 070934	EGOR IVANOV	{"phone": "+70846669254"}
0005434910123	F0B711	3577 776940	MAKSIM GAVRILOV	{"phone": "+70527195078"}
0005434910124	32B2F3	4916 828362	TATYANA ALEKSEEVA	{"phone": "+70973096438"}
0005434910125	D2D0E1	0540 973312	KIRILL TARASOV	{"phone": "+70799773785"}
0005434910126	414D10	2959 859808	VERONIKA CHERNOVA	{"phone": "+70506029954"}
0005434910127	414D10	4686 836699	VLADIMIR KOROLEV	{"phone": "+70347713942"}
0005434910128	414D10	3827 304524	OLEG OSIPOV	{"email": "oosipov041965@postgrespro.ru", "phone": "+70251414130"}
0005434910129	C2F485	2359 605836	ANTONINA YUDINA	{"email": "ayudina.031981@postgrespro.ru", "phone": "+70879647945"}
0005434910130	9F2E7D	8786 844098	TATYANA MOROZOVA	{"phone": "+70462423733"}
0005434910131	9F2E7D	1455 755158	MARINA KUZNECOVA	{"email": "kuznecova.marina.101970@postgrespro.ru", "phone": "+70252530316"}
0005434910132	A0FB26	0774 032757	SVETLANA ROMANOVA	{"email": "romanova-s_1974@postgrespro.ru", "phone": "+70978465163"}
0005434910133	7BFF5C	2746 718195	ALEKSANDR FEDOTOV	{"phone": "+70572489467"}
0005434910134	AECB88	0809 845739	ELENA KOROLEVA	{"email": "elenakoroleva-20071977@postgrespro.ru", "phone": "+70150640048"}
0005434910135	AECB88	4143 810092	YURIY SHEVCHENKO	{"email": "shevchenko.yuriy.011975@postgrespro.ru", "phone": "+70097143668"}
0005434910136	1B7DD2	7010 985650	VERA VOLKOVA	{"email": "volkova.vera06101955@postgrespro.ru", "phone": "+70063346347"}
0005434910137	34D54F	9675 826833	ANASTASIYA SCHERBAKOVA	{"email": "anastasiya-scherbakova.1964@postgrespro.ru", "phone": "+70414928041"}
0005434910138	42A567	8993 480029	VERA MELNIKOVA	{"email": "vera-melnikova.1964@postgrespro.ru", "phone": "+70773588558"}
0005434910139	42A567	0587 268854	EKATERINA MELNIKOVA	{"email": "ekaterinamelnikova.20091980@postgrespro.ru", "phone": "+70309083390"}
0005434910140	964DEC	1194 730870	PRASKOVYA ANDREEVA	{"phone": "+70838152328"}
0005434910141	E39F48	4868 550652	ANNA AFANASEVA	{"phone": "+70507550191"}
0005434910142	E39F48	8576 071597	ELENA OSIPOVA	{"phone": "+70076124822"}
0005434910143	E39F48	9007 790042	GRIGORIY ISAEV	{"phone": "+70492018030"}
0005434910144	2D7DE7	0853 203666	ALEKSANDRA BELOVA	{"phone": "+70957478010"}
0005434910145	AE918E	2054 513023	YULIYA KUDRYASHOVA	{"phone": "+70862430712"}
0005434910146	6849D0	4773 514769	ALEKSEY KUZMIN	{"email": "aleksey_kuzmin_23041991@postgrespro.ru", "phone": "+70846144864"}
0005434910147	AAE2DB	1251 489126	MAKSIM KARPOV	{"phone": "+70232752218"}
0005434910148	8C25A4	0644 115800	YURIY MAKAROV	{"email": "makarov-yuriy051977@postgrespro.ru", "phone": "+70460082810"}
0005434910149	8C25A4	9127 726564	SVETLANA VOLKOVA	{"email": "svetlana-volkova_17011972@postgrespro.ru", "phone": "+70852671981"}
0005434910150	8C7638	8367 742718	YURIY ZAKHAROV	{"phone": "+70679384194"}
0005434910151	F52C21	4624 690789	ELENA FROLOVA	{"email": "elena-frolova-12051971@postgrespro.ru", "phone": "+70497853744"}
0005434910152	83E8E8	6070 487359	VERA SOLOVEVA	{"phone": "+70688591417"}
0005434910153	83E8E8	4028 340661	ALEKSANDRA PETROVA	{"email": "petrova_a.041974@postgrespro.ru", "phone": "+70328309937"}
0005434910154	35637D	1308 586625	VALENTINA IVANOVA	{"phone": "+70351466650"}
0005434910155	420EB8	9205 895216	TATYANA SMIRNOVA	{"phone": "+70624165517"}
0005434910156	5DA92C	3967 757612	VITALIY NOVIKOV	{"phone": "+70243583373"}
0005434910157	19FC0E	9451 104801	VLADIMIR KAZAKOV	{"phone": "+70669055205"}
0005434910158	B97A27	9266 365874	TATYANA KALININA	{"email": "t.kalinina-23091974@postgrespro.ru", "phone": "+70678882318"}
0005434910159	1D9B26	0299 167101	DENIS FEDOTOV	{"email": "fedotovdenis09111979@postgrespro.ru", "phone": "+70640364428"}
0005434910160	51C342	4023 298778	DARYA YAKOVLEVA	{"phone": "+70379336541"}
0005434910161	B1C7CB	2411 206213	ALEVTINA LUKYANOVA	{"email": "lukyanova.alevtina-24111976@postgrespro.ru", "phone": "+70313757886"}
0005434910162	B1C7CB	5644 131834	ILYA MARTYNOV	{"email": "martynovilya_021971@postgrespro.ru", "phone": "+70791905833"}
0005434910163	6256D4	0448 629404	OLGA STEPANOVA	{"email": "stepanova.olga-1965@postgrespro.ru", "phone": "+70381824645"}
0005434910164	6256D4	2050 457739	EGOR MARTYNOV	{"email": "martynov.egor-051969@postgrespro.ru", "phone": "+70899109007"}
0005434910165	918E6A	7614 331776	ANDREY ROMANOV	{"phone": "+70289827008"}
0005434910166	F80386	1690 573473	ANATOLIY TIKHONOV	{"email": "anatoliytikhonov_01061975@postgrespro.ru", "phone": "+70696592242"}
0005434910167	7F5824	7874 096131	TAMARA OVCHINNIKOVA	{"phone": "+70476286385"}
0005434910168	F8443D	7218 325136	KLAVDIYA KUZMINA	{"phone": "+70812780382"}
0005434910169	8835DD	0635 799730	OKSANA SOKOLOVA	{"phone": "+70104235922"}
0005434910170	8835DD	0232 663224	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-1966@postgrespro.ru", "phone": "+70447146019"}
0005434910171	8835DD	1539 632167	NATALIYA POPOVA	{"email": "nataliya_popova021984@postgrespro.ru", "phone": "+70034896612"}
0005434910172	76AC5C	8847 082950	VALENTINA BOGDANOVA	{"phone": "+70051833261"}
0005434910173	A14BFA	8204 367410	ANATOLIY BORISOV	{"email": "borisov.anatoliy_061968@postgrespro.ru", "phone": "+70454142565"}
0005434910174	A14BFA	7365 013516	ALEKSANDR STEPANOV	{"email": "a.stepanov_03091976@postgrespro.ru", "phone": "+70167867516"}
0005434910175	9ABBCA	1785 076916	IVAN BORISOV	{"email": "i-borisov.26031977@postgrespro.ru", "phone": "+70997194967"}
0005434910176	363E43	1868 299816	ANTON DMITRIEV	{"email": "a-dmitriev.1970@postgrespro.ru", "phone": "+70563291505"}
0005434910177	5A27A5	5846 487244	VLADIMIR MAKAROV	{"email": "vladimir_makarov25081975@postgrespro.ru", "phone": "+70307438187"}
0005434910178	C70962	8216 616139	ELENA MIRONOVA	{"email": "elena-mironova_1975@postgrespro.ru", "phone": "+70424635822"}
0005434910179	3F4CD9	9315 327757	VYACHESLAV FOMIN	{"email": "vyacheslav_fomin-07031969@postgrespro.ru", "phone": "+70746113500"}
0005434910180	3F4CD9	7821 337889	NADEZHDA GAVRILOVA	{"phone": "+70518528283"}
0005434910181	3F4CD9	1773 324778	OLGA MOROZOVA	{"phone": "+70444856120"}
0005434910182	C37229	9371 361504	VERA GUSEVA	{"email": "v.guseva.17011969@postgrespro.ru", "phone": "+70490489508"}
0005434925247	B252F5	1732 966087	MARINA YAKOVLEVA	{"phone": "+70066573381"}
0005434925248	700F81	2869 906873	SERGEY BORISOV	{"email": "s.borisov-09121977@postgrespro.ru", "phone": "+70695156011"}
0005434925249	83BBA4	7227 458981	NATALYA SIDOROVA	{"phone": "+70494718754"}
0005434925250	83BBA4	4764 997657	DMITRIY KOZLOV	{"phone": "+70482572875"}
0005434925251	22A3B0	5859 737804	VALERIY NIKOLAEV	{"phone": "+70750943207"}
0005434925252	EBF980	5156 912110	GLEB MOISEEV	{"email": "g.moiseev-1970@postgrespro.ru", "phone": "+70185366205"}
0005434925253	7A39C0	2225 786229	OLGA ZAKHAROVA	{"phone": "+70038556975"}
0005434925254	7A39C0	0361 621475	ELENA IVANOVA	{"phone": "+70575672576"}
0005434925255	17EB3C	5755 209822	ANDREY MARTYNOV	{"email": "martynov-andrey1980@postgrespro.ru", "phone": "+70137814282"}
0005434925256	17EB3C	1209 874135	VITALIY NOVIKOV	{"phone": "+70838039080"}
0005434925257	7B4CF2	7966 157094	EVGENIY MARTYNOV	{"email": "martynov-e121977@postgrespro.ru", "phone": "+70586848489"}
0005434925258	3D2B13	8279 428081	OLESYA BARANOVA	{"phone": "+70589892602"}
0005434925259	3D2B13	5871 007250	EKATERINA LUKYANOVA	{"email": "lukyanova_ekaterina_061976@postgrespro.ru", "phone": "+70443802910"}
0005434925260	089CCC	6640 047920	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov-1973@postgrespro.ru", "phone": "+70937838720"}
0005434925261	333A40	5715 884782	YURIY SERGEEV	{"email": "y.sergeev.1974@postgrespro.ru", "phone": "+70950518989"}
0005434925262	F494BD	4101 621196	VLADIMIR MIRONOV	{"email": "mironovv-18031971@postgrespro.ru", "phone": "+70724558091"}
0005434925263	F494BD	0070 647488	SERGEY SIDOROV	{"email": "s_sidorov091980@postgrespro.ru", "phone": "+70590215240"}
0005434925264	EC11A8	2626 410314	OKSANA KOLESNIKOVA	{"phone": "+70802511949"}
0005434925265	3CF4E5	2868 145616	MARIYA GORBUNOVA	{"phone": "+70635145838"}
0005434925266	3CF4E5	1136 882927	ARTEM KOROLEV	{"email": "korolev.artem_051967@postgrespro.ru", "phone": "+70425869387"}
0005434925267	FD67C4	4397 635639	OLGA GERASIMOVA	{"phone": "+70625359494"}
0005434925268	FD67C4	6965 730995	VALENTINA FILIPPOVA	{"email": "v_filippova_08111974@postgrespro.ru", "phone": "+70564903373"}
0005434925269	CEBE6F	4438 922428	DMITRIY MIKHAYLOV	{"phone": "+70619145401"}
0005434925270	B6F402	3797 863547	SOFYA KARPOVA	{"phone": "+70447150905"}
0005434925271	B6F402	0079 650501	EVGENIY KOROLEV	{"phone": "+70858202881"}
0005434925272	B6F402	7891 448607	LYUBOV VASILEVA	{"email": "vasileva_l-1976@postgrespro.ru", "phone": "+70009868421"}
0005434925273	F9BB51	2503 621921	ELENA NIKOLAEVA	{"phone": "+70687189927"}
0005434925274	78ACC9	3713 890703	ANASTASIYA FILATOVA	{"email": "anastasiya-filatova-011969@postgrespro.ru", "phone": "+70470651996"}
0005434925275	78ACC9	8267 524584	DMITRIY MAKAROV	{"email": "d-makarov-12041965@postgrespro.ru", "phone": "+70291001549"}
0005434925276	8E6D08	4004 229146	IVAN SOROKIN	{"email": "isorokin-1970@postgrespro.ru", "phone": "+70798016546"}
0005434925277	8E6D08	2280 659413	IGOR MOROZOV	{"phone": "+70681467879"}
0005434925278	8E6D08	3407 725578	VASILIY KRASNOV	{"phone": "+70995687867"}
0005434925279	E656A6	1867 379087	SERGEY NOVIKOV	{"email": "novikov_sergey02091960@postgrespro.ru", "phone": "+70399308349"}
0005434925280	7CBF13	2302 967661	GALINA IVANOVA	{"phone": "+70653234177"}
0005434925281	B308BC	4096 315661	NATALYA GRISHINA	{"email": "grishina.natalya051971@postgrespro.ru", "phone": "+70565989420"}
0005434925282	B308BC	5757 993442	NINA LOGINOVA	{"email": "loginova_n_1976@postgrespro.ru", "phone": "+70693008118"}
0005434925283	AE9C44	9679 494697	DMITRIY MIRONOV	{"email": "mironov_d-1972@postgrespro.ru", "phone": "+70081893080"}
0005434925452	73E107	4198 097536	ALEKSANDR DMITRIEV	{"phone": "+70387828899"}
0005434925284	09262A	3062 957337	YULIYA EFREMOVA	{"email": "yuliya-efremova20091971@postgrespro.ru", "phone": "+70380632134"}
0005434925285	8B5B12	3873 875853	ANATOLIY MIKHAYLOV	{"email": "anatoliy.mikhaylov_011965@postgrespro.ru", "phone": "+70286235911"}
0005434925286	8B5B12	4590 082839	ALISA KUDRYASHOVA	{"email": "kudryashova_alisa_051966@postgrespro.ru", "phone": "+70993212274"}
0005434925287	918DB9	0335 655175	POLINA GRISHINA	{"email": "p-grishina_071970@postgrespro.ru", "phone": "+70715337154"}
0005434925288	918DB9	7631 355436	PETR DENISOV	{"email": "pdenisov22071969@postgrespro.ru", "phone": "+70891535670"}
0005434925289	918DB9	4245 145446	EVGENIY MATVEEV	{"phone": "+70180034419"}
0005434925290	2014D0	1377 389109	IRINA SOLOVEVA	{"email": "soloveva_i.16051979@postgrespro.ru", "phone": "+70230981712"}
0005434925291	134A49	8013 709438	TATYANA SERGEEVA	{"email": "sergeeva.tatyana081971@postgrespro.ru", "phone": "+70189382516"}
0005434925292	329310	4233 895951	ALEKSANDR ILIN	{"phone": "+70752067986"}
0005434925293	2AA750	6169 246452	ARINA KUZNECOVA	{"phone": "+70871595052"}
0005434925294	58579D	0299 982055	ANGELINA KUDRYASHOVA	{"email": "akudryashova-1971@postgrespro.ru", "phone": "+70500546628"}
0005434925295	B57385	6273 868750	ELENA SOLOVEVA	{"email": "elenasoloveva-121961@postgrespro.ru", "phone": "+70641611654"}
0005434925296	7721AE	5949 586895	ANNA DENISOVA	{"phone": "+70550372589"}
0005434925297	91F447	5114 818815	VALENTINA FEDOROVA	{"phone": "+70587887175"}
0005434925298	A6C822	2130 038762	ELENA KONDRATEVA	{"email": "kondrateva.elena-1978@postgrespro.ru", "phone": "+70042988166"}
0005434925299	EC08B3	0495 493834	VALERIY MAKAROV	{"phone": "+70252692972"}
0005434925300	EC08B3	5847 073316	OLEG ALEKSEEV	{"email": "oleg.alekseev-1979@postgrespro.ru", "phone": "+70773605372"}
0005434925301	7C1717	9527 187344	PAVEL KUZMIN	{"phone": "+70911523262"}
0005434925302	33C3B3	2206 950836	VIKTOR IVANOV	{"email": "ivanovviktor_1977@postgrespro.ru", "phone": "+70084141557"}
0005434925303	33C3B3	1416 388282	ALEKSANDR MOISEEV	{"phone": "+70844107433"}
0005434925304	D0389A	6876 935937	VLADIMIR SOKOLOV	{"phone": "+70042381620"}
0005434925305	D0389A	6944 040909	ELENA IVANOVA	{"email": "elena_ivanova.04011973@postgrespro.ru", "phone": "+70926542447"}
0005434925306	21A504	6972 622311	POLINA GUSEVA	{"email": "guseva_p1975@postgrespro.ru", "phone": "+70779871957"}
0005434925307	1AA8BE	1071 289538	ALEKSANDR NAZAROV	{"phone": "+70598761660"}
0005434925308	40F028	2185 331948	IGOR KARPOV	{"phone": "+70943932959"}
0005434925489	AB2797	4667 944482	GALINA POPOVA	{"phone": "+70741075546"}
0005434925309	A7372D	0986 069915	ALEKSANDR AFANASEV	{"email": "aleksandr-afanasev_20081979@postgrespro.ru", "phone": "+70460014447"}
0005434925310	84BBD0	3804 301630	VIKTOR KULIKOV	{"phone": "+70361657719"}
0005434925311	AB63FD	6038 831252	NIKOLAY ROMANOV	{"phone": "+70048749290"}
0005434925312	AB63FD	0592 365233	ALEKSANDR MIRONOV	{"email": "a-mironov.16091980@postgrespro.ru", "phone": "+70635767160"}
0005434925313	403E42	8385 007181	ANDREY MIKHAYLOV	{"phone": "+70130459802"}
0005434925314	C9910A	1728 310423	RAFAIL PETROV	{"email": "petrov-r.041982@postgrespro.ru", "phone": "+70448408842"}
0005434925315	351D88	1709 424727	ELENA VASILEVA	{"email": "e_vasileva-05121976@postgrespro.ru", "phone": "+70771366012"}
0005434925317	6A28C2	7435 388296	ALEKSANDR EGOROV	{"phone": "+70100039378"}
0005434925318	9ADD31	1423 572131	NATALYA ZAYCEVA	{"phone": "+70795579041"}
0005434925319	DFB86A	6811 093360	LIDIYA NAUMOVA	{"email": "lidiya_naumova-24091958@postgrespro.ru", "phone": "+70218160736"}
0005434925320	77AB8B	9694 705113	VITALIY PAVLOV	{"email": "v.pavlov-1985@postgrespro.ru", "phone": "+70648467619"}
0005434925321	04B1D8	5422 966200	ANNA FROLOVA	{"email": "anna.frolova.15101969@postgrespro.ru", "phone": "+70287577628"}
0005434925322	1F42F0	3624 904128	REGINA SERGEEVA	{"phone": "+70260089513"}
0005434925323	1F42F0	9996 387460	ELENA FILIPPOVA	{"email": "efilippova1967@postgrespro.ru", "phone": "+70660699450"}
0005434925324	6D6968	5047 276864	DMITRIY SOKOLOV	{"email": "sokolov-dmitriy_061972@postgrespro.ru", "phone": "+70858473627"}
0005434925325	05BBA3	7641 744492	MARFA KONOVALOVA	{"phone": "+70380056793"}
0005434925326	8E072D	4958 054489	IRINA VASILEVA	{"email": "irina_vasileva011965@postgrespro.ru", "phone": "+70563128096"}
0005434925327	B2547B	2991 951507	NADEZHDA ZAYCEVA	{"email": "nadezhda.zayceva1970@postgrespro.ru", "phone": "+70639845642"}
0005434925328	B2547B	8676 308894	STANISLAV ZAYCEV	{"phone": "+70742651454"}
0005434925329	43EAB8	9078 124337	VITALIY GUSEV	{"phone": "+70138072294"}
0005434925330	A1EC14	4369 001562	ANTONINA VLASOVA	{"email": "vlasova-a-1964@postgrespro.ru", "phone": "+70873558465"}
0005434925331	A1EC14	1788 061343	NIKITA KUZNECOV	{"phone": "+70789126600"}
0005434925332	E532C4	7516 275262	YANA GAVRILOVA	{"email": "yana-gavrilova-17091974@postgrespro.ru", "phone": "+70274524265"}
0005434925333	CD0C3E	1989 020667	ANNA KONDRATEVA	{"email": "annakondrateva10091971@postgrespro.ru", "phone": "+70954444294"}
0005434925334	CD0C3E	7009 913521	VALERIY GAVRILOV	{"phone": "+70166421204"}
0005434925335	9347D9	4028 481730	RUSLAN FILIPPOV	{"email": "filippov-r101974@postgrespro.ru", "phone": "+70304361982"}
0005434925336	CC6636	2363 117197	MARIYA FADEEVA	{"phone": "+70265482724"}
0005434925337	AA2864	3233 365605	ROMAN SAVELEV	{"email": "roman.savelev1978@postgrespro.ru", "phone": "+70474771164"}
0005434925338	C6FC60	9161 509579	ANATOLIY ZHUKOV	{"phone": "+70053176641"}
0005434925339	C6FC60	9075 368432	VALERIY VOLKOV	{"email": "v-volkov-19041962@postgrespro.ru", "phone": "+70179243354"}
0005434925340	2FD492	4089 013567	MARIYA TROFIMOVA	{"email": "mtrofimova_06081965@postgrespro.ru", "phone": "+70901911497"}
0005434925341	2FD492	3658 796441	NADEZHDA MAKSIMOVA	{"email": "nadezhdamaksimova.1965@postgrespro.ru", "phone": "+70886108307"}
0005434925342	634484	3593 007300	ANTON TIKHONOV	{"email": "anton-tikhonov.09011965@postgrespro.ru", "phone": "+70755714635"}
0005434925343	6464F2	0719 329409	MIKHAIL GUSEV	{"phone": "+70358084623"}
0005434925344	0C8699	4660 646434	ANASTASIYA ERMAKOVA	{"phone": "+70075726022"}
0005434925345	04CB2A	1779 529838	ELIZAVETA TIKHONOVA	{"email": "tikhonovaelizaveta-1985@postgrespro.ru", "phone": "+70604603250"}
0005434925346	04CB2A	9015 464216	IVAN POPOV	{"phone": "+70356668625"}
0005434925347	5FB951	3751 006549	YULIYA BARANOVA	{"phone": "+70596917943"}
0005434925348	5FB951	8882 330903	VIKTOR BORISOV	{"phone": "+70355815585"}
0005434925349	5FB951	9341 081530	LYUBOV OSIPOVA	{"email": "l.osipova081962@postgrespro.ru", "phone": "+70002625530"}
0005434925350	E8133E	4535 931279	ANTON ABRAMOV	{"phone": "+70109955077"}
0005434925351	63F793	7324 352951	KAMILA NOVIKOVA	{"phone": "+70014683690"}
0005434925352	A1C72F	1701 861473	ALINA MAKSIMOVA	{"email": "alinamaksimova011965@postgrespro.ru", "phone": "+70286142302"}
0005434925353	A0D621	4202 404843	VASILIY VLASOV	{"phone": "+70313874793"}
0005434925354	9745E3	1305 785607	VLADIMIR KOZLOV	{"phone": "+70699745122"}
0005434925355	9745E3	5739 551914	VLADIMIR KUZNECOV	{"phone": "+70000261724"}
0005434925356	356AF5	0203 873959	KSENIYA FEDOROVA	{"email": "fedorova_kseniya.1977@postgrespro.ru", "phone": "+70454946302"}
0005434925357	356AF5	8261 496525	VITALIY SEMENOV	{"email": "semenov.vitaliy_031973@postgrespro.ru", "phone": "+70777932393"}
0005434925358	11AE09	3848 074553	DANA MAKAROVA	{"phone": "+70054560141"}
0005434925359	888B22	7456 589829	MARIYA VOLKOVA	{"phone": "+70926978671"}
0005434925360	888B22	3614 806425	OLEG MAKAROV	{"phone": "+70240854908"}
0005434925361	39F9C5	9450 396433	OLGA MIRONOVA	{"email": "mironova-olga1984@postgrespro.ru", "phone": "+70018927908"}
0005434925362	4F60B1	8125 256798	ELENA DAVYDOVA	{"phone": "+70396200980"}
0005434925363	A4AC55	4443 766893	NATALIYA KRASNOVA	{"email": "krasnova.n-20111973@postgrespro.ru", "phone": "+70876500014"}
0005434925364	A4AC55	6943 878146	OLGA KOZLOVA	{"email": "kozlova_olga.031964@postgrespro.ru", "phone": "+70398748314"}
0005434925365	7EACE4	6675 777077	ROMAN MARTYNOV	{"email": "martynov.roman101976@postgrespro.ru", "phone": "+70330586729"}
0005434925366	7EACE4	2330 429822	VLADISLAV KAZAKOV	{"email": "vladislavkazakov_1951@postgrespro.ru", "phone": "+70735715298"}
0005434925367	AA15CF	4300 468286	DMITRIY DAVYDOV	{"email": "davydovd-071977@postgrespro.ru", "phone": "+70809617619"}
0005434925368	AA15CF	3134 976171	NADEZHDA MOROZOVA	{"email": "morozova_n-071975@postgrespro.ru", "phone": "+70741774198"}
0005434925369	272731	2232 509192	SEMEN KONOVALOV	{"email": "konovalov_semen1971@postgrespro.ru", "phone": "+70078621250"}
0005434925370	B9FA31	4342 203161	LIDIYA SCHERBAKOVA	{"phone": "+70880528100"}
0005434925371	B56271	7326 763602	VENIAMIN SMIRNOV	{"email": "smirnovv.1979@postgrespro.ru", "phone": "+70507408707"}
0005434925372	F98103	2209 339350	IRINA PETROVA	{"email": "petrovairina29011978@postgrespro.ru", "phone": "+70088221301"}
0005434925373	F98103	5888 611933	VALENTINA ZAKHAROVA	{"phone": "+70872530839"}
0005434925374	4F2BA5	1182 220157	VALENTINA KOVALEVA	{"phone": "+70958320968"}
0005434925375	EFE1DF	4156 955410	DARYA MIKHAYLOVA	{"email": "darya_mikhaylova-121975@postgrespro.ru", "phone": "+70045241397"}
0005434925497	4164F3	3131 502149	FANIL ORLOV	{"phone": "+70350767902"}
0005434925376	EFE1DF	1367 860963	FEDOR KUZNECOV	{"email": "fedor.kuznecov_1965@postgrespro.ru", "phone": "+70854875099"}
0005434925377	33C5D1	1907 393934	ELENA STEPANOVA	{"email": "elena.stepanova_1977@postgrespro.ru", "phone": "+70979328765"}
0005434925378	33C5D1	1037 718791	ALEKSANDR VOLKOV	{"phone": "+70689985691"}
0005434925379	13DCF4	4272 276283	EVGENIYA KALININA	{"phone": "+70383773661"}
0005434925380	0F271F	4673 431322	VALERIYA GAVRILOVA	{"phone": "+70204969697"}
0005434925381	C96071	0860 077690	LYUBOV FADEEVA	{"email": "lyubovfadeeva26021980@postgrespro.ru", "phone": "+70970351520"}
0005434925382	81133E	7693 611003	ALEKSANDRA ANDREEVA	{"email": "a.andreeva_16121970@postgrespro.ru", "phone": "+70553215947"}
0005434925383	683D85	4138 566021	TATYANA KONOVALOVA	{"email": "konovalovatatyana1963@postgrespro.ru", "phone": "+70479735882"}
0005434925384	6AD1E7	7623 847346	MARIYA TIMOFEEVA	{"email": "m_timofeeva.08081960@postgrespro.ru", "phone": "+70413476363"}
0005434925385	35374A	2612 548349	ANATOLIY KUZMIN	{"phone": "+70498026425"}
0005434925386	79AD24	2251 855035	VLADIMIR FROLOV	{"phone": "+70766046425"}
0005434925387	16F524	8940 942933	KIRILL ZHUKOV	{"email": "k-zhukov-10031979@postgrespro.ru", "phone": "+70967158063"}
0005434925388	8F0490	1840 062128	SVETLANA IVANOVA	{"phone": "+70111862685"}
0005434925389	A75D27	5551 061581	VLADIMIR ANTONOV	{"email": "antonov-v.1965@postgrespro.ru", "phone": "+70942988402"}
0005434925390	F9143C	7227 740230	EKATERINA KOMAROVA	{"email": "e_komarova_30011973@postgrespro.ru", "phone": "+70756428940"}
0005434925391	7879A0	5421 749883	OLEG VOROBEV	{"phone": "+70192806460"}
0005434925392	AA2BB6	3937 986332	YAROSLAVA EGOROVA	{"email": "yaroslava-egorova.1983@postgrespro.ru", "phone": "+70671620522"}
0005434925393	42947D	4027 921664	ELENA POPOVA	{"phone": "+70145295256"}
0005434925394	42947D	8871 782068	EVGENIYA VASILEVA	{"phone": "+70489906389"}
0005434925395	F2916B	6462 659510	NATALYA YAKOVLEVA	{"phone": "+70171219933"}
0005434925396	C11227	1286 455122	GALINA MOISEEVA	{"email": "moiseeva.galina02111976@postgrespro.ru", "phone": "+70590147604"}
0005434925397	18D092	8270 756651	SERGEY VOLKOV	{"email": "volkov_s.02121978@postgrespro.ru", "phone": "+70319943671"}
0005434925398	9F4E63	3016 995045	ROMAN GORBUNOV	{"email": "gorbunov_r-041968@postgrespro.ru", "phone": "+70867762576"}
0005434925399	9F4E63	8467 294601	EVDOKIYA BELYAEVA	{"phone": "+70488928346"}
0005434925400	B6990A	5304 189662	YULIYA SAVELEVA	{"email": "y-saveleva.02101975@postgrespro.ru", "phone": "+70900381104"}
0005434925401	B6990A	0495 403568	EKATERINA ISAEVA	{"email": "ekaterinaisaeva-1973@postgrespro.ru", "phone": "+70918409421"}
0005434925402	5B05D4	3570 090526	VALENTINA KOLESNIKOVA	{"email": "kolesnikova.valentina-1973@postgrespro.ru", "phone": "+70182877009"}
0005434925403	735AB6	8874 368528	VLADIMIR CHERNOV	{"email": "vladimir_chernov.25111980@postgrespro.ru", "phone": "+70468248545"}
0005434925404	1ADC0F	1333 144402	KONSTANTIN KUDRYASHOV	{"email": "konstantin.kudryashov-01091962@postgrespro.ru", "phone": "+70841345779"}
0005434925405	C60651	1477 808015	SVETLANA LAZAREVA	{"email": "svetlanalazareva_1963@postgrespro.ru", "phone": "+70858836682"}
0005434925406	C60651	1752 333123	ALEKSEY TIMOFEEV	{"phone": "+70068292946"}
0005434925407	C60651	2810 298494	GRIGORIY SERGEEV	{"phone": "+70101662178"}
0005434925408	07C3DC	0059 839589	TATYANA NIKOLAEVA	{"phone": "+70042880872"}
0005434925409	07C3DC	2879 394005	VIKTOR OSIPOV	{"email": "osipov.v.01111978@postgrespro.ru", "phone": "+70179699352"}
0005434925410	73B9EB	3888 469509	SVETLANA GUSEVA	{"phone": "+70659994830"}
0005434925411	63F7C6	8955 505217	NIKOLAY SMIRNOV	{"email": "smirnov.n_16021977@postgrespro.ru", "phone": "+70663390666"}
0005434925412	63F7C6	0513 679913	MARIYA MIRONOVA	{"phone": "+70278362758"}
0005434925413	9CA459	2832 459459	SERGEY PAVLOV	{"email": "sergey.pavlov-091964@postgrespro.ru", "phone": "+70575062188"}
0005434925414	A92AB1	4236 176687	VALERIY ZAKHAROV	{"phone": "+70684173911"}
0005434925415	530583	4978 518108	NATALYA STEPANOVA	{"phone": "+70713027521"}
0005434925416	5C80D5	0283 748547	MIKHAIL SMIRNOV	{"phone": "+70600822773"}
0005434925417	CD27CC	3390 883149	RASHID KOROLEV	{"phone": "+70194485497"}
0005434925418	C95589	4836 666071	OKSANA IVANOVA	{"email": "ivanova-oksana_16051978@postgrespro.ru", "phone": "+70797335205"}
0005434925419	4CA795	8694 700093	DMITRIY DMITRIEV	{"phone": "+70928102579"}
0005434925420	4CA795	1736 995000	ALEKSANDR KUZNECOV	{"email": "kuznecova19011970@postgrespro.ru", "phone": "+70024822335"}
0005434925421	B56F07	7481 837888	ANATOLIY VLASOV	{"email": "vlasov_anatoliy-041979@postgrespro.ru", "phone": "+70449295716"}
0005434925422	863244	1516 221795	ANTONINA STEPANOVA	{"phone": "+70042509402"}
0005434925423	4EC3E6	3264 291497	VALERIY KOZLOV	{"email": "kozlov_valeriy-021984@postgrespro.ru", "phone": "+70483077476"}
0005434925424	9E57F9	8400 132446	ALIYA KOLESNIKOVA	{"phone": "+70024903678"}
0005434925425	3A32B9	5313 933328	NIKOLAY OSIPOV	{"phone": "+70200879726"}
0005434925426	18E701	4508 095829	DMITRIY VOLKOV	{"phone": "+70460942870"}
0005434925427	18E701	4643 828151	ARTEM FILIPPOV	{"email": "filippovartem-1978@postgrespro.ru", "phone": "+70110772579"}
0005434925428	423FD4	5153 067641	VLADIMIR PETROV	{"email": "petrov_v_1970@postgrespro.ru", "phone": "+70355553863"}
0005434925429	423FD4	3036 650935	IGOR AFANASEV	{"phone": "+70184411602"}
0005434925430	5BE6A7	9219 992938	KRISTINA SAVELEVA	{"phone": "+70054744547"}
0005434925431	5EC7D7	9336 958086	IGOR ANTONOV	{"email": "antonovigor.06111979@postgrespro.ru", "phone": "+70849307298"}
0005434925432	B7A571	4667 752605	LYUBOV BOGDANOVA	{"email": "bogdanoval.20121968@postgrespro.ru", "phone": "+70692550313"}
0005434925433	6919FE	7895 501804	TATYANA PAVLOVA	{"email": "pavlova-tatyana-071980@postgrespro.ru", "phone": "+70567978372"}
0005434925434	8FC668	1503 471543	SERGEY PETROV	{"phone": "+70005102081"}
0005434925435	B70AEF	5512 033818	ANASTASIYA KOMAROVA	{"email": "komarova.anastasiya.1972@postgrespro.ru", "phone": "+70885459955"}
0005434925436	B70AEF	8349 232047	NINA GERASIMOVA	{"phone": "+70398633927"}
0005434925437	874119	9899 529624	ELENA BORISOVA	{"email": "eborisova.111962@postgrespro.ru", "phone": "+70454245318"}
0005434925438	874119	7080 302854	ALENA SOLOVEVA	{"phone": "+70992342849"}
0005434925439	FD2A82	7487 809671	DENIS MAKAROV	{"phone": "+70104442008"}
0005434925440	0DC268	2761 322309	SERGEY DMITRIEV	{"phone": "+70352828218"}
0005434925441	03ABE5	7879 345810	SVETLANA DAVYDOVA	{"email": "davydova_s.1967@postgrespro.ru", "phone": "+70714076210"}
0005434925442	F93E5C	8411 117374	ALEKSANDR KUDRYASHOV	{"phone": "+70727239332"}
0005434925443	4E4719	6454 960620	ALEKSANDR KUZNECOV	{"email": "a-kuznecov_091968@postgrespro.ru", "phone": "+70553754378"}
0005434925444	4E4719	2659 984152	LYUDMILA GORBUNOVA	{"phone": "+70862794069"}
0005434925445	F4E581	7841 030723	SERGEY GRIGOREV	{"phone": "+70657751355"}
0005434925446	F4E581	1661 126673	SVETLANA MEDVEDEVA	{"email": "medvedeva-s_1982@postgrespro.ru", "phone": "+70618560462"}
0005434925447	D7B29E	9614 722061	SERGEY ROMANOV	{"email": "romanov_sergey_121968@postgrespro.ru", "phone": "+70952065986"}
0005434925448	D7B29E	3972 965602	ELENA ZHUKOVA	{"phone": "+70260514755"}
0005434925449	5A370B	4587 559480	NINA MIKHAYLOVA	{"email": "mikhaylova_n.14061971@postgrespro.ru", "phone": "+70970713625"}
0005434925450	B428D4	4422 817479	EVGENIY KOZLOV	{"phone": "+70411381389"}
0005434925451	73E107	2373 629128	VALENTINA VOLKOVA	{"email": "v.volkova_26061964@postgrespro.ru", "phone": "+70068153149"}
0005434925453	73E107	2203 822303	GENNADIY CHERNOV	{"phone": "+70043069037"}
0005434925454	D3920E	5798 019353	ELENA KUZNECOVA	{"email": "e_kuznecova061966@postgrespro.ru", "phone": "+70154738601"}
0005434925455	C2E2C3	3694 091017	ALEKSANDRA GRISHINA	{"phone": "+70187654860"}
0005434925456	2F1BF6	9814 978920	NIKOLAY RODIONOV	{"email": "n-rodionov-27051980@postgrespro.ru", "phone": "+70016675236"}
0005434925457	3E2139	2271 201599	ALEKSANDR KUZNECOV	{"email": "a-kuznecov_091971@postgrespro.ru", "phone": "+70032758058"}
0005434925458	3E2139	5857 566741	GALINA POPOVA	{"phone": "+70586590371"}
0005434925459	A2C4EB	7793 468284	DARYA NIKITINA	{"email": "nikitina_d-23081976@postgrespro.ru", "phone": "+70496674179"}
0005434925460	77E340	1831 181103	ELENA POPOVA	{"email": "e-popova_28031970@postgrespro.ru", "phone": "+70695929959"}
0005434925461	67527E	0151 808061	VALENTINA SAVELEVA	{"email": "saveleva_v1981@postgrespro.ru", "phone": "+70022218200"}
0005434925462	67527E	3922 572812	EVGENIYA SEMENOVA	{"email": "e-semenova.03091967@postgrespro.ru", "phone": "+70388865038"}
0005434925463	57812B	0053 820164	ANNA KOZLOVA	{"phone": "+70805510025"}
0005434925464	57812B	8831 872917	ALEKSANDR IVANOV	{"phone": "+70418015335"}
0005434925465	9F5CCF	2243 870804	ALEKSANDR MOROZOV	{"phone": "+70507783265"}
0005434925466	E3D26F	9533 377781	SOFIYA KUDRYASHOVA	{"phone": "+70010675535"}
0005434925467	E3D26F	5638 448376	ANATOLIY KUZMIN	{"email": "a-kuzmin-1971@postgrespro.ru", "phone": "+70452850488"}
0005434925468	9CCC35	2690 829144	KONSTANTIN MAKAROV	{"phone": "+70137968176"}
0005434925469	F8573C	8811 297905	VIKTOR AFANASEV	{"phone": "+70025636757"}
0005434925470	9DEAC6	7998 833889	ALLA FOMINA	{"phone": "+70524647790"}
0005434925471	80822A	1042 403101	VERA ISAEVA	{"phone": "+70145612202"}
0005434925472	80822A	4327 508679	ALEKSEY VLASOV	{"email": "vlasov-aleksey.23011976@postgrespro.ru", "phone": "+70205977008"}
0005434925473	80822A	3335 705996	KSENIYA LAZAREVA	{"email": "k-lazareva_071977@postgrespro.ru", "phone": "+70356025992"}
0005434925474	F4F0DE	5244 931363	VIKTORIYA POPOVA	{"email": "viktoriya.popova_22101978@postgrespro.ru", "phone": "+70494088676"}
0005434925475	F4F0DE	2169 803603	TATYANA TARASOVA	{"phone": "+70902746168"}
0005434925476	D7D352	1905 447977	SERGEY KUZMIN	{"phone": "+70037330699"}
0005434925477	32BB41	0811 479916	OLGA MALYSHEVA	{"email": "malysheva_o_041968@postgrespro.ru", "phone": "+70356589569"}
0005434925478	32BB41	3645 589084	EKATERINA NIKIFOROVA	{"phone": "+70750985351"}
0005434925479	A0B20C	2006 510221	ELENA KISELEVA	{"email": "kiselevaelena1974@postgrespro.ru", "phone": "+70443275088"}
0005434925480	A0B20C	7288 578738	NIKOLAY GRIGOREV	{"email": "nikolay-grigorev.23051976@postgrespro.ru", "phone": "+70541386365"}
0005434925481	5F4F69	1422 271961	GALINA FEDOROVA	{"email": "g-fedorova_26081977@postgrespro.ru", "phone": "+70598164576"}
0005434925482	905956	2608 051013	NATALYA NIKITINA	{"email": "natalya_nikitina-1967@postgrespro.ru", "phone": "+70155019329"}
0005434925483	51B178	8831 615646	ALEKSEY SCHERBAKOV	{"email": "alekseyscherbakov-14081984@postgrespro.ru", "phone": "+70472907059"}
0005434925484	2B4887	3198 994537	YULIYA NIKOLAEVA	{"phone": "+70735385507"}
0005434925485	857186	8536 619032	SVETLANA KULIKOVA	{"email": "kulikova_svetlana111977@postgrespro.ru", "phone": "+70771426372"}
0005434925486	FD8B1E	7543 978696	ELENA KONDRATEVA	{"email": "kondrateva-elena-28121975@postgrespro.ru", "phone": "+70447237012"}
0005434925487	FD8B1E	5171 927856	SOFYA VOROBEVA	{"phone": "+70121838911"}
0005434925488	8CD9FA	0574 939264	ALEKSANDR MEDVEDEV	{"email": "medvedev-a051968@postgrespro.ru", "phone": "+70919532581"}
0005434925490	AB2797	2872 224253	YULIYA IVANOVA	{"phone": "+70275807824"}
0005434925491	AB2797	7756 197055	EKATERINA EFIMOVA	{"phone": "+70822774196"}
0005434925492	5E85F4	8801 006847	DMITRIY KOZLOV	{"email": "kozlov.dmitriy-041970@postgrespro.ru", "phone": "+70543487495"}
0005434925493	934349	1039 720643	NIKOLAY IVANOV	{"email": "n_ivanov23121973@postgrespro.ru", "phone": "+70280849232"}
0005434925494	279B8B	1369 532751	ANDREY KOZLOV	{"email": "a.kozlov.27111964@postgrespro.ru", "phone": "+70651200739"}
0005434925495	279B8B	8820 875819	RENAT EGOROV	{"phone": "+70773167092"}
0005434925496	6AE60B	2035 205673	IGOR FEDOTOV	{"phone": "+70322825515"}
0005434925498	4164F3	6444 597078	NIKOLAY MATVEEV	{"phone": "+70536948642"}
0005434925499	936539	0941 944584	SERGEY ZHUKOV	{"phone": "+70816673980"}
0005434925500	A2471F	9540 655942	KIRILL FEDOROV	{"email": "fedorov-kirill1982@postgrespro.ru", "phone": "+70350257020"}
0005434925501	A2471F	9967 808347	NADEZHDA MARTYNOVA	{"email": "martynova.n_1967@postgrespro.ru", "phone": "+70692622659"}
0005434925502	C05810	9478 973424	YULIYA POPOVA	{"email": "popovay_1963@postgrespro.ru", "phone": "+70017374668"}
0005434925503	46DEA8	3709 659960	NATALIYA ZOTOVA	{"email": "zotova.nataliya_111984@postgrespro.ru", "phone": "+70668571428"}
0005434925504	F3E70E	1163 700614	GRIGORIY DAVYDOV	{"phone": "+70750996333"}
0005434925505	F3E70E	8574 024991	VLADIMIR FOMIN	{"email": "fomin-vladimir.061972@postgrespro.ru", "phone": "+70544526312"}
0005434925506	B46137	2564 549582	ALEKSEY KONOVALOV	{"phone": "+70713775337"}
0005434925507	B46137	3365 288488	VLADIMIR KUDRYASHOV	{"email": "vladimirkudryashov.021971@postgrespro.ru", "phone": "+70632614842"}
0005434925508	FA179C	4705 571555	EVGENIY KUZMIN	{"phone": "+70896729260"}
0005434925509	CDC465	1424 769100	ALEKSANDR VASILEV	{"phone": "+70216206615"}
0005434925510	787B79	5259 090200	YURIY KUZMIN	{"phone": "+70630052719"}
0005434925511	AAC74A	3679 887851	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr_01021968@postgrespro.ru", "phone": "+70418391998"}
0005434925512	8AF6B0	8785 228931	SVETLANA DAVYDOVA	{"email": "svetlanadavydova_1959@postgrespro.ru", "phone": "+70598291851"}
0005434925513	E73667	2605 175309	NADEZHDA GORBUNOVA	{"email": "gorbunova-nadezhda081979@postgrespro.ru", "phone": "+70808528348"}
0005434925514	E73667	4268 485343	KSENIYA SOKOLOVA	{"email": "kseniya.sokolova_22041976@postgrespro.ru", "phone": "+70607772416"}
0005434925515	E73667	1432 351519	ELENA KOZLOVA	{"phone": "+70978403989"}
0005434925516	5E70A3	2898 478078	TAMARA PAVLOVA	{"phone": "+70990621443"}
0005434925517	5E70A3	0311 347781	VLADIMIR VASILEV	{"email": "v_vasilev.021971@postgrespro.ru", "phone": "+70307028730"}
0005434925518	155C80	3931 114417	YURIY ZHUKOV	{"email": "y-zhukov1979@postgrespro.ru", "phone": "+70258537455"}
0005434925519	17860B	9304 384066	EVGENIY GRIGOREV	{"phone": "+70358297583"}
0005434925520	A0B0CE	3282 453651	VLADIMIR ILIN	{"email": "vilin.1958@postgrespro.ru", "phone": "+70469574676"}
0005434925521	05F5FE	2713 169692	NINA SEMENOVA	{"email": "semenovanina041980@postgrespro.ru", "phone": "+70653046405"}
0005434925522	5B8D67	5134 017957	IRINA SIDOROVA	{"email": "irina-sidorova.1972@postgrespro.ru", "phone": "+70681418234"}
0005434925523	37B2A7	0978 648834	OLEG EGOROV	{"email": "egorov-o-041966@postgrespro.ru", "phone": "+70379994251"}
0005434925524	94959F	6730 847963	TATYANA SERGEEVA	{"phone": "+70254544676"}
0005434925525	468B8A	6123 747144	IVAN ABRAMOV	{"email": "iabramov.1961@postgrespro.ru", "phone": "+70959805282"}
0005434925526	B92B3D	0362 919012	VALENTINA MALYSHEVA	{"phone": "+70801165910"}
0005434925527	5C91C6	1679 516067	MAKSIM MARTYNOV	{"email": "martynov.maksim.13091977@postgrespro.ru", "phone": "+70904919526"}
0005434925528	97933E	9139 210670	DARYA MAKSIMOVA	{"phone": "+70834035581"}
0005434925529	FB01BE	2969 242691	FEDOR ZHURAVLEV	{"email": "fzhuravlev_061970@postgrespro.ru", "phone": "+70725687183"}
0005434925530	F5A1F5	7982 041503	SERGEY PETROV	{"phone": "+70832508872"}
0005434925531	F5A1F5	1080 768410	VLADIMIR IVANOV	{"email": "ivanov.v-031975@postgrespro.ru", "phone": "+70945162718"}
0005434925532	F5A1F5	6868 175263	YULIYA KRASNOVA	{"email": "krasnova-yuliya1971@postgrespro.ru", "phone": "+70372032871"}
0005434925533	212703	4506 109173	VENIAMIN FOMIN	{"email": "vfomin_1986@postgrespro.ru", "phone": "+70656672293"}
0005434925534	212703	5038 615403	LYUBOV DENISOVA	{"email": "l-denisova.21021967@postgrespro.ru", "phone": "+70314416226"}
0005434925535	53FB33	1164 613948	PETR NAZAROV	{"phone": "+70168153362"}
0005434925536	4F9B00	0707 023670	TAMARA BORISOVA	{"email": "tborisova.1986@postgrespro.ru", "phone": "+70473413872"}
0005434925537	4F9B00	8664 203144	ANNA KUZMINA	{"phone": "+70754976009"}
0005434925538	3146B6	1134 497071	MARIYA AKIMOVA	{"email": "makimova-121967@postgrespro.ru", "phone": "+70380204133"}
0005434925539	CC6190	5374 657810	ANDREY SCHERBAKOV	{"phone": "+70317423990"}
0005434925540	AC3470	9344 693147	RUSLAN FEDOROV	{"phone": "+70417956165"}
0005434925541	AC3470	5546 356757	KRISTINA ZAYCEVA	{"email": "kristina.zayceva-1979@postgrespro.ru", "phone": "+70719568715"}
0005434925542	93D67A	4692 961895	SERGEY SCHERBAKOV	{"phone": "+70200896049"}
0005434925543	93D67A	2900 898966	ROMAN ANDREEV	{"email": "r-andreev_25061973@postgrespro.ru", "phone": "+70541448467"}
0005434925544	8E71F0	6698 933825	ELENA DMITRIEVA	{"email": "dmitrievaelena-1964@postgrespro.ru", "phone": "+70848586605"}
0005434925545	E3D188	3343 319718	RAISA KRASNOVA	{"email": "r.krasnova_1969@postgrespro.ru", "phone": "+70334933507"}
0005434925546	E3D188	0745 597234	TATYANA LEBEDEVA	{"phone": "+70928135287"}
0005434925547	E3D188	2291 885645	DMITRIY FILIPPOV	{"phone": "+70690935353"}
0005434925548	8B7AA8	0865 387376	ALEKSANDR ALEKSEEV	{"email": "alekseeva.03121971@postgrespro.ru", "phone": "+70128783989"}
0005434925549	2A6E20	4220 195148	RUSLAN KOROLEV	{"email": "korolev_r-1966@postgrespro.ru", "phone": "+70494283789"}
0005434925550	2A6E20	8589 422427	VLADIMIR TIMOFEEV	{"email": "vladimir.timofeev091973@postgrespro.ru", "phone": "+70797196915"}
0005434925551	2A6E20	6440 304327	STANISLAV SOKOLOV	{"email": "sokolov_stanislav-20101972@postgrespro.ru", "phone": "+70319866249"}
0005434925552	6FEAD4	1532 029268	ELENA KRASNOVA	{"email": "elenakrasnova.1969@postgrespro.ru", "phone": "+70177088229"}
0005434925553	9F3919	1866 526110	NATALYA BARANOVA	{"email": "nbaranova031971@postgrespro.ru", "phone": "+70881256344"}
0005434925554	096003	6395 208837	VADIM KUZNECOV	{"phone": "+70052991783"}
0005434925555	775882	3332 585264	ELENA KARPOVA	{"email": "karpovae-1976@postgrespro.ru", "phone": "+70191326060"}
0005434925556	775882	4016 167403	SERGEY TARASOV	{"email": "tarasov_s-011965@postgrespro.ru", "phone": "+70548756552"}
0005434925557	A0964A	6741 699727	NIKOLAY BARANOV	{"email": "baranov-nikolay1972@postgrespro.ru", "phone": "+70750073271"}
0005434925558	B4BA2B	4556 026085	LIDIYA VLASOVA	{"phone": "+70027237138"}
0005434925559	8B8D71	8509 396943	OLESYA KUZNECOVA	{"email": "okuznecova_15091967@postgrespro.ru", "phone": "+70775585261"}
0005434925560	8B8D71	2965 921411	SERGEY IVANOV	{"phone": "+70630309097"}
0005434925561	63A351	8754 724550	ANASTASIYA ZOTOVA	{"email": "anastasiya.zotova1965@postgrespro.ru", "phone": "+70163701712"}
0005434925562	63A351	7899 993339	EVGENIY POPOV	{"phone": "+70014208499"}
0005434925563	63A351	5741 730554	ANATOLIY OSIPOV	{"email": "anatoliy.osipov.071965@postgrespro.ru", "phone": "+70364912213"}
0005434925564	EF2965	4493 838850	MAKSIM YAKOVLEV	{"email": "myakovlev_15111967@postgrespro.ru", "phone": "+70412554756"}
0005434925565	6A87FF	9207 203089	SVETLANA KRASNOVA	{"email": "krasnovas17011978@postgrespro.ru", "phone": "+70620522034"}
0005434925566	6118F4	5996 090376	VALENTINA SAVELEVA	{"email": "saveleva-v-1972@postgrespro.ru", "phone": "+70641525338"}
0005434925567	039E50	8055 778048	VLADIMIR NIKITIN	{"email": "vladimir-nikitin06111973@postgrespro.ru", "phone": "+70996586995"}
0005434925568	039E50	0068 237898	VIKTORIYA POPOVA	{"phone": "+70248103253"}
0005434925569	60F62E	8484 161288	VLADIMIR MAKAROV	{"phone": "+70211140612"}
0005434925570	60F62E	4470 329605	DENIS KUZNECOV	{"phone": "+70455638772"}
0005434925571	0171B6	2170 827622	ALEKSANDR OSIPOV	{"phone": "+70821470270"}
0005434925572	F21524	2871 230391	DMITRIY MATVEEV	{"email": "matveev.dmitriy_28041975@postgrespro.ru", "phone": "+70388576556"}
0005434925573	F21524	2642 039274	KLAVDIYA KOROLEVA	{"phone": "+70630348049"}
0005434925574	C285F6	5683 223834	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir_23081983@postgrespro.ru", "phone": "+70053033508"}
0005434925575	C285F6	2878 843462	ANNA FROLOVA	{"phone": "+70400365583"}
0005434925576	C285F6	7716 740646	ELENA YAKOVLEVA	{"email": "yakovleva.elena.021967@postgrespro.ru", "phone": "+70053271881"}
0005434925577	C0A70B	7601 476612	RENAT SHEVCHENKO	{"email": "r_shevchenko-1963@postgrespro.ru", "phone": "+70176248672"}
0005434925578	3E3E73	6732 489957	LYUDMILA SAVELEVA	{"phone": "+70716227219"}
0005434925579	0DBD8A	1540 696160	ANTONINA FILIPPOVA	{"email": "filippova-antonina.11081965@postgrespro.ru", "phone": "+70163355514"}
0005434925580	C50AE1	7533 163012	LYUBOV AFANASEVA	{"email": "afanaseva-l-23111969@postgrespro.ru", "phone": "+70957076306"}
0005434925581	71776A	1283 175007	IVAN EGOROV	{"phone": "+70025836743"}
0005434925582	E93E5F	0672 734468	EKATERINA NAZAROVA	{"email": "ekaterinanazarova24011974@postgrespro.ru", "phone": "+70506279809"}
0005434925583	C55FCA	5853 671840	SERGEY MARTYNOV	{"email": "martynovs-1974@postgrespro.ru", "phone": "+70111073663"}
0005434925584	C55FCA	1062 926387	ANNA OSIPOVA	{"email": "anna_osipova_091958@postgrespro.ru", "phone": "+70850386607"}
0005434925585	AB9011	8456 187963	ALEKSEY MATVEEV	{"phone": "+70663051298"}
0005434925586	449D82	2143 666302	ANASTASIYA NIKITINA	{"email": "anastasiyanikitina101975@postgrespro.ru", "phone": "+70187428726"}
0005434925587	5BE212	8823 880023	VYACHESLAV PAVLOV	{"email": "vpavlov.121971@postgrespro.ru", "phone": "+70320097032"}
0005434925588	971FD1	6921 995004	ALEKSEY SAVELEV	{"phone": "+70385651062"}
0005434925589	971FD1	7424 644806	ANATOLIY SAVELEV	{"phone": "+70614491935"}
0005434925590	63ED64	3661 227112	VIKTOR ABRAMOV	{"email": "viktor.abramov_1967@postgrespro.ru", "phone": "+70632098096"}
0005434925591	63ED64	0957 554412	MARIYA BORISOVA	{"phone": "+70354551378"}
0005434925592	52546B	2790 343228	ALEKSANDR KOZLOV	{"email": "kozlova031958@postgrespro.ru", "phone": "+70076871225"}
0005434925593	ACA94F	6111 591917	VALENTIN ANTONOV	{"email": "antonov_valentin23061965@postgrespro.ru", "phone": "+70548124625"}
0005434925594	ACA94F	5377 855240	DMITRIY VASILEV	{"phone": "+70576903221"}
0005434925595	D5B561	4939 300550	ANDREY TARASOV	{"email": "tarasov.a.1978@postgrespro.ru", "phone": "+70880806483"}
0005434925596	43DBCF	0603 440608	NIKOLAY NAZAROV	{"phone": "+70584791700"}
0005434925597	6C6130	0980 188172	DENIS KISELEV	{"email": "kiselev.denis.011965@postgrespro.ru", "phone": "+70106404925"}
0005434925598	295A9E	7612 366750	IRINA BOGDANOVA	{"phone": "+70881125118"}
0005434925599	8FF53F	5874 234816	ROMAN FILIPPOV	{"phone": "+70700211541"}
0005434925600	8FF53F	3479 492423	ALEKSANDR ZAYCEV	{"email": "a-zaycev-1981@postgrespro.ru", "phone": "+70053009126"}
0005434925601	C6B4F9	2733 505182	DIANA PAVLOVA	{"phone": "+70582816134"}
0005434925602	C6B4F9	7900 676715	RAISA ILINA	{"email": "r.ilina1976@postgrespro.ru", "phone": "+70759976845"}
0005434925603	1B26B8	1362 552510	ALEKSANDR STEPANOV	{"phone": "+70142778966"}
0005434925604	BF1889	0604 299969	BORIS MAKAROV	{"phone": "+70855840768"}
0005434925605	06627F	0790 969367	TATYANA TIKHONOVA	{"email": "tatyana.tikhonova-051975@postgrespro.ru", "phone": "+70741589766"}
0005434925606	FEC051	2341 156065	KRISTINA MAKAROVA	{"phone": "+70094387001"}
0005434925607	0A5EC6	2442 152277	KHASAN GUSEV	{"email": "gusevkhasan-29011975@postgrespro.ru", "phone": "+70019726010"}
0005434925608	F20F61	4609 977524	ALEKSANDR MEDVEDEV	{"phone": "+70941961641"}
0005434925609	6558F7	3456 241599	ANDREY GRIGOREV	{"phone": "+70308401775"}
0005434925610	6558F7	3502 355033	SERGEY ANTONOV	{"email": "antonov_s_041969@postgrespro.ru", "phone": "+70600378720"}
0005434925611	EDFD19	9730 831990	ALEKSANDR POPOV	{"email": "a.popov_041968@postgrespro.ru", "phone": "+70053371777"}
0005434925612	FC16E5	3827 491039	ALFIYA ERMAKOVA	{"email": "a-ermakova-101978@postgrespro.ru", "phone": "+70073982761"}
0005434925613	F234A7	5838 275913	SVETLANA KONOVALOVA	{"email": "svetlana-konovalova-1969@postgrespro.ru", "phone": "+70146317814"}
0005434925614	23DBDC	8962 342556	NINA TIKHONOVA	{"email": "tikhonova-nina_021976@postgrespro.ru", "phone": "+70738339957"}
0005434925615	23DBDC	8562 809311	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr-29071966@postgrespro.ru", "phone": "+70220645812"}
0005434925616	8177FB	9608 883177	DMITRIY ZHURAVLEV	{"email": "zhuravlevdmitriy.011976@postgrespro.ru", "phone": "+70983495862"}
0005434925617	8177FB	7582 380465	ELENA ROMANOVA	{"phone": "+70521346637"}
0005434925618	A97E38	9866 686006	KIRILL DAVYDOV	{"email": "davydov-kirill.021980@postgrespro.ru", "phone": "+70557155050"}
0005434925619	008ED3	6239 063845	TAGIR VOLKOV	{"email": "volkovt1976@postgrespro.ru", "phone": "+70373105054"}
0005434925620	008ED3	4392 369568	VALENTINA FROLOVA	{"email": "frolovavalentina-13081981@postgrespro.ru", "phone": "+70382893288"}
0005434925621	009AE2	0977 109581	BORIS TIMOFEEV	{"phone": "+70277245628"}
0005434925622	009AE2	9016 499559	OLGA BOGDANOVA	{"email": "bogdanova.olga-111967@postgrespro.ru", "phone": "+70778526466"}
0005434925623	10947D	5165 725801	ILDAR VASILEV	{"phone": "+70764309391"}
0005434925624	0EDAF6	4350 925106	IRINA POTAPOVA	{"email": "potapova.i-1962@postgrespro.ru", "phone": "+70735681580"}
0005434925625	CB5224	6538 027688	ZOYA VASILEVA	{"email": "vasileva_zoya-05021951@postgrespro.ru", "phone": "+70214131892"}
0005434925626	D3C486	7901 060823	NIKOLAY AFANASEV	{"email": "afanasev.nikolay_05121967@postgrespro.ru", "phone": "+70624161472"}
0005434925627	D3C486	4185 820651	YULIYA FEDOROVA	{"phone": "+70939003034"}
0005434925628	3C9D74	1357 675675	ALEKSEY ALEKSANDROV	{"email": "aleksandrova.1975@postgrespro.ru", "phone": "+70335093072"}
0005434925629	3C9D74	9863 573398	EVGENIYA SOROKINA	{"email": "esorokina_031973@postgrespro.ru", "phone": "+70946596034"}
0005434925630	3C9D74	5358 585358	LYUDMILA ERMAKOVA	{"phone": "+70449057809"}
0005434925631	FA1610	2197 601950	ANASTASIYA KISELEVA	{"email": "kiseleva.a101975@postgrespro.ru", "phone": "+70255396443"}
0005434925632	FA1610	8030 411460	YULIYA ANTONOVA	{"email": "antonova-yuliya.051974@postgrespro.ru", "phone": "+70030415088"}
0005434925633	FA1610	5623 421432	ANATOLIY FEDOTOV	{"phone": "+70206590499"}
0005434925634	FA1610	7181 037599	NIKOLAY TIMOFEEV	{"email": "timofeev.nikolay.03051969@postgrespro.ru", "phone": "+70926509351"}
0005434925635	2BA93C	8298 370918	OLGA FEDOROVA	{"email": "fedorova-olga-18011968@postgrespro.ru", "phone": "+70718439759"}
0005434925636	2BA93C	4497 477170	EVELINA ZHURAVLEVA	{"email": "zhuravleva-evelina.23031964@postgrespro.ru", "phone": "+70400591998"}
0005434925637	D64CDE	1898 561305	LYUBOV SAVELEVA	{"email": "saveleva-lyubov_1963@postgrespro.ru", "phone": "+70730705466"}
0005434925638	BE0B73	7388 501325	SERGEY SMIRNOV	{"email": "smirnov-s.31121973@postgrespro.ru", "phone": "+70052801536"}
0005434925639	BE0B73	1881 341143	KIRILL BONDARENKO	{"email": "k.bondarenko_1964@postgrespro.ru", "phone": "+70158651236"}
0005434925640	0DDE42	3727 306508	MAKSIM ORLOV	{"email": "orlovmaksim_11061970@postgrespro.ru", "phone": "+70564038675"}
0005434925641	C49F1E	4515 306032	NATALYA POTAPOVA	{"email": "potapova.n_1981@postgrespro.ru", "phone": "+70879627469"}
0005434925642	BA801A	3792 743148	MARIYA OVCHINNIKOVA	{"email": "mariyaovchinnikova18071965@postgrespro.ru", "phone": "+70839759423"}
0005434925643	BA801A	8572 291142	SERGEY PETROV	{"email": "s-petrov_031968@postgrespro.ru", "phone": "+70837314236"}
0005434925644	8A4856	8345 254218	BORIS MAKAROV	{"email": "makarov-b.1972@postgrespro.ru", "phone": "+70879363163"}
0005434925645	8A4856	3176 153321	NATALYA ZAYCEVA	{"email": "zayceva-n111975@postgrespro.ru", "phone": "+70296344717"}
0005434925646	0C1217	6365 296326	ALEKSEY MOROZOV	{"phone": "+70465798563"}
0005434925647	0C1217	8684 336325	DMITRIY VLASOV	{"email": "dvlasov.1961@postgrespro.ru", "phone": "+70936774330"}
0005434925648	B90AD5	6670 339614	GALINA ARKHIPOVA	{"email": "galina.arkhipova_23121962@postgrespro.ru", "phone": "+70735407447"}
0005434925649	B90AD5	6091 337071	LIDIYA POPOVA	{"email": "lidiya_popova.1972@postgrespro.ru", "phone": "+70462472900"}
0005434925650	737445	3994 423856	ANATOLIY MAKAROV	{"email": "anatoliymakarov-1968@postgrespro.ru", "phone": "+70751268037"}
0005434925651	737445	6900 655864	SVETLANA MAKSIMOVA	{"email": "svetlanamaksimova1972@postgrespro.ru", "phone": "+70041688340"}
0005434925652	B619D3	0086 404212	LYUDMILA MAKAROVA	{"phone": "+70003102665"}
0005434925653	20C420	6499 435447	VLADIMIR SIDOROV	{"email": "sidorov.vladimir1971@postgrespro.ru", "phone": "+70321084160"}
0005434925654	86D38D	1962 919154	VLADIMIR STEPANOV	{"email": "stepanov-vladimir-011976@postgrespro.ru", "phone": "+70039470425"}
0005434925655	1FBD79	5218 062677	ELENA FADEEVA	{"phone": "+70255751205"}
0005434925656	13D385	8183 947338	VIKTOR MARTYNOV	{"phone": "+70300527023"}
0005434925657	4F3842	8908 339762	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova111969@postgrespro.ru", "phone": "+70930732859"}
0005434925658	4F3842	4112 365756	NIKOLAY ABRAMOV	{"email": "nikolay_abramov_091984@postgrespro.ru", "phone": "+70840971620"}
0005434925659	4F3842	8028 302332	VLADIMIR ANDREEV	{"email": "vladimir_andreev25081975@postgrespro.ru", "phone": "+70416928563"}
0005434925660	3CF69B	2676 011904	OKSANA PETROVA	{"email": "oksana-petrova.071979@postgrespro.ru", "phone": "+70406479642"}
0005434925661	E701A5	1497 989772	SERGEY MAKAROV	{"email": "makarov_sergey_13101969@postgrespro.ru", "phone": "+70038965747"}
0005434925662	DEE3C9	2298 621202	DMITRIY AFANASEV	{"phone": "+70549013696"}
0005434925663	DEE3C9	3486 214546	SVETLANA DAVYDOVA	{"phone": "+70344398636"}
0005434925664	02CCEC	6985 812329	IRINA BARANOVA	{"email": "baranova-i_13111966@postgrespro.ru", "phone": "+70153319319"}
0005434925665	E83484	1682 100257	MIKHAIL VASILEV	{"email": "mikhail_vasilev-08101975@postgrespro.ru", "phone": "+70818329186"}
0005434925666	B70C0E	2385 923237	ELENA PETROVA	{"email": "petrova.e1976@postgrespro.ru", "phone": "+70220674870"}
0005434925667	92B000	0832 398337	KIRILL FROLOV	{"email": "frolovk1977@postgrespro.ru", "phone": "+70417902542"}
0005434925668	3747C9	3493 304280	ROMAN POPOV	{"phone": "+70714861260"}
0005434925669	3747C9	4001 989917	GALINA PAVLOVA	{"phone": "+70125909808"}
0005434925670	8E590A	6342 423556	IGOR MAKAROV	{"phone": "+70653490475"}
0005434925671	D9E238	2790 450092	LYUDMILA IVANOVA	{"phone": "+70968956735"}
0005434925672	D9E238	6447 344359	VERA SERGEEVA	{"email": "sergeeva-v101973@postgrespro.ru", "phone": "+70616894276"}
0005434925673	AD2C18	2592 416329	ROMAN MAKSIMOV	{"email": "maksimovroman.26071968@postgrespro.ru", "phone": "+70521636336"}
0005434925674	AD2C18	5915 667913	OLGA DENISOVA	{"email": "denisova-o-1958@postgrespro.ru", "phone": "+70805734172"}
0005434925675	4BBED8	2304 734387	NINA MALYSHEVA	{"phone": "+70479721490"}
0005434925676	C9721D	5856 513205	LYUDMILA ROMANOVA	{"phone": "+70056990197"}
0005434925677	C9721D	8273 671085	SVETLANA IVANOVA	{"phone": "+70531625725"}
0005434925678	5EF39E	5718 286219	VALERIY NIKITIN	{"email": "valeriy_nikitin_1972@postgrespro.ru", "phone": "+70058463079"}
0005434925679	5CD69A	0523 865280	VERA MOROZOVA	{"email": "vera.morozova.1966@postgrespro.ru", "phone": "+70744259582"}
0005434925680	5CD69A	7506 854834	OLGA DMITRIEVA	{"email": "olga_dmitrieva_081965@postgrespro.ru", "phone": "+70273958075"}
0005434925681	5CD69A	0218 460391	YURIY KOROLEV	{"email": "korolev.y-061983@postgrespro.ru", "phone": "+70315318388"}
0005434925682	355458	9465 812547	ALEKSANDR NOVIKOV	{"email": "novikov_a_18031970@postgrespro.ru", "phone": "+70061947015"}
0005434925683	F7E68E	5839 322368	ANASTASIYA RYABOVA	{"email": "a-ryabova.08071969@postgrespro.ru", "phone": "+70307220752"}
0005434925684	F7E68E	1983 475686	VLADIMIR KUDRYASHOV	{"email": "kudryashov_vladimir1975@postgrespro.ru", "phone": "+70528000798"}
0005434925685	8E3807	8263 814354	AMINA ZOTOVA	{"email": "zotova.a_031974@postgrespro.ru", "phone": "+70233130632"}
0005434925686	331688	6194 251856	NIKOLAY SHEVCHENKO	{"phone": "+70638439180"}
0005434925687	331688	2680 068964	MAYA SCHERBAKOVA	{"email": "scherbakovamaya.1960@postgrespro.ru", "phone": "+70961816077"}
0005434925688	19347C	8516 804654	VLADIMIR VOROBEV	{"email": "v.vorobev.28101970@postgrespro.ru", "phone": "+70963958778"}
0005434925689	19347C	2792 609576	MARINA MOISEEVA	{"email": "moiseeva.marina.101968@postgrespro.ru", "phone": "+70196062695"}
0005434925690	19347C	7132 222100	ARTEM POPOV	{"email": "artempopov-081967@postgrespro.ru", "phone": "+70180936050"}
0005434925691	A3CAD1	7181 924583	ANASTASIYA OSIPOVA	{"email": "osipovaa_081968@postgrespro.ru", "phone": "+70011910829"}
0005434925692	B1D7D5	0533 857313	VLADIMIR KULIKOV	{"email": "kulikovvladimir-10031983@postgrespro.ru", "phone": "+70581162034"}
0005434925693	8D7535	4843 867557	VALENTINA MELNIKOVA	{"phone": "+70494706049"}
0005434925694	8D7535	9486 108548	ELENA KOLESNIKOVA	{"email": "kolesnikova_e_1974@postgrespro.ru", "phone": "+70785649311"}
0005434925695	F6A77C	3672 047464	GENNADIY MAKAROV	{"phone": "+70577724076"}
0005434925696	18F2C2	3004 860925	SVETLANA YAKOVLEVA	{"phone": "+70298588469"}
0005434925697	18F2C2	7581 791966	ANDREY MARTYNOV	{"phone": "+70597161790"}
0005434925698	18F2C2	4459 189696	VADIM SMIRNOV	{"email": "vadim.smirnov_1978@postgrespro.ru", "phone": "+70827074506"}
0005434925699	B6FFA0	2477 659346	ALEKSANDR VOROBEV	{"phone": "+70783070583"}
0005434925700	7A73DB	5060 929559	AZAT MOISEEV	{"email": "amoiseev1970@postgrespro.ru", "phone": "+70973271146"}
0005434925701	7A73DB	7874 466459	ALMIRA TIKHONOVA	{"phone": "+70486023655"}
0005434925702	7A73DB	1660 279596	VASILIY POPOV	{"phone": "+70685365012"}
0005434925703	B0B070	9396 507381	ALEKSEY FOMIN	{"phone": "+70348969729"}
0005434925704	1B3885	0346 048133	ARTEM DENISOV	{"phone": "+70267344885"}
0005434925705	1791CB	8842 533336	MARINA SAVELEVA	{"email": "saveleva-marina081959@postgrespro.ru", "phone": "+70360279259"}
0005434925706	1791CB	6032 732319	SVETLANA NESTEROVA	{"phone": "+70885744128"}
0005434925707	17D3DD	9476 463001	VALENTINA SOKOLOVA	{"phone": "+70112118649"}
0005434925708	764807	1151 319011	TAMARA KOZLOVA	{"email": "kozlova_t1974@postgrespro.ru", "phone": "+70858487177"}
0005434925709	764807	6683 325895	SVETLANA SOKOLOVA	{"phone": "+70282479964"}
0005434925710	FD7F99	4796 040379	VLADIMIR SAVELEV	{"phone": "+70259089002"}
0005434925711	0B19E4	8986 322305	ELENA KUZNECOVA	{"email": "kuznecovaelena.03101965@postgrespro.ru", "phone": "+70762255639"}
0005434925712	DBF07E	2224 569886	ELMIRA TROFIMOVA	{"email": "etrofimova_09091967@postgrespro.ru", "phone": "+70662573139"}
0005434925713	19F927	3830 855051	NATALYA GRISHINA	{"phone": "+70955765029"}
0005434925714	A52D1D	1038 636256	VASILIY DAVYDOV	{"phone": "+70412993594"}
0005434925715	A52D1D	6932 613079	IGOR MAKAROV	{"email": "makarov.i.06041985@postgrespro.ru", "phone": "+70657465503"}
0005434925716	95C3F7	6999 143432	IVAN TARASOV	{"phone": "+70638910030"}
0005434925717	37C4DA	6124 365228	NATALYA VLASOVA	{"phone": "+70493912038"}
0005434925718	7B3B12	1854 151700	SHAVKAT FEDOROV	{"email": "fedorov_shavkat.1975@postgrespro.ru", "phone": "+70998764429"}
0005434925719	502C6D	0531 403837	VALERIY MAKAROV	{"email": "v-makarov.1979@postgrespro.ru", "phone": "+70218209549"}
0005434925720	502C6D	1899 119533	SVETLANA GAVRILOVA	{"email": "gavrilova_svetlana_14091976@postgrespro.ru", "phone": "+70936994411"}
0005434925721	306F48	5226 427538	DMITRIY BONDARENKO	{"phone": "+70816550278"}
0005434925722	E9C2F1	1855 566176	NIKOLAY CHERNOV	{"email": "chernovnikolay_101974@postgrespro.ru", "phone": "+70250029818"}
0005434925784	A77C50	7509 369168	IRINA KOROLEVA	{"phone": "+70639677202"}
0005434925723	E9C2F1	6959 806584	DMITRIY PETROV	{"email": "d_petrov-03051969@postgrespro.ru", "phone": "+70157445284"}
0005434925724	1509D8	1107 317918	VALERIY AFANASEV	{"phone": "+70563092067"}
0005434925725	2BD0EB	3304 626729	LIDIYA MAKSIMOVA	{"email": "l_maksimova_011976@postgrespro.ru", "phone": "+70070371052"}
0005434925726	2BD0EB	6317 123030	LYUBOV SOROKINA	{"email": "lsorokina.1983@postgrespro.ru", "phone": "+70127306065"}
0005434925727	940300	7375 832722	GALINA POTAPOVA	{"phone": "+70169410462"}
0005434925728	D7B374	2760 691068	ZOYA POPOVA	{"phone": "+70094851437"}
0005434925729	02ECB2	2990 963830	ANASTASIYA YAKOVLEVA	{"phone": "+70144231700"}
0005434925730	AABB2A	0992 303146	NADEZHDA ZHUKOVA	{"phone": "+70141811542"}
0005434925731	AABB2A	1594 895354	DENIS MELNIKOV	{"email": "melnikov.d.101990@postgrespro.ru", "phone": "+70285300163"}
0005434925732	A6A50B	8717 277335	NINA VOLKOVA	{"phone": "+70077993676"}
0005434925733	470231	0970 918785	OKSANA FROLOVA	{"phone": "+70125768147"}
0005434925734	A1C878	7278 543601	VALENTINA AKIMOVA	{"email": "valentina.akimova-18091974@postgrespro.ru", "phone": "+70892071654"}
0005434925735	2D3CC1	0267 644114	OLEG NIKITIN	{"email": "o_nikitin.1977@postgrespro.ru", "phone": "+70214663770"}
0005434925736	9E273F	3496 710446	YURIY SHEVCHENKO	{"email": "y_shevchenko021972@postgrespro.ru", "phone": "+70983696562"}
0005434925737	9E273F	1513 696204	NATALYA ROMANOVA	{"email": "natalya-romanova.051974@postgrespro.ru", "phone": "+70669989055"}
0005434925738	705119	0892 212967	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr.1970@postgrespro.ru", "phone": "+70869604466"}
0005434925739	D1B56D	5175 091887	OLGA VOROBEVA	{"email": "vorobeva_olga-1967@postgrespro.ru", "phone": "+70782578802"}
0005434925740	94BB53	2031 654527	ALEKSANDR ROMANOV	{"phone": "+70321199243"}
0005434925741	94BB53	2457 974010	SERGEY VOLKOV	{"email": "volkovsergey_1977@postgrespro.ru", "phone": "+70630462770"}
0005434925742	6A7739	9684 232484	SERGEY DMITRIEV	{"email": "s.dmitriev.1966@postgrespro.ru", "phone": "+70341204328"}
0005434925743	6A7739	2658 518147	GENNADIY AFANASEV	{"phone": "+70278558582"}
0005434925744	062316	2004 114115	IGOR GORBUNOV	{"email": "i_gorbunov24031983@postgrespro.ru", "phone": "+70448195074"}
0005434925745	BC20ED	2361 005492	KARINA PAVLOVA	{"phone": "+70452750218"}
0005434925746	EAEBFF	9415 772348	SVETLANA KOZLOVA	{"phone": "+70178834441"}
0005434925747	3639FE	7908 441893	NADEZHDA ABRAMOVA	{"email": "n-abramova_08091988@postgrespro.ru", "phone": "+70660275818"}
0005434925748	40BA6F	4606 464277	VLADIMIR FOMIN	{"phone": "+70112475272"}
0005434925749	40BA6F	8628 969116	KARINA KRASNOVA	{"email": "karina.krasnova-1973@postgrespro.ru", "phone": "+70630701726"}
0005434925750	8E9C75	5281 325641	SERGEY ANDREEV	{"email": "andreev.s_1973@postgrespro.ru", "phone": "+70144407010"}
0005434925751	A36998	7193 534470	DIANA MIKHAYLOVA	{"email": "dmikhaylova_081984@postgrespro.ru", "phone": "+70677157226"}
0005434925752	A36998	3785 351771	IRINA KUZNECOVA	{"email": "i.kuznecova1975@postgrespro.ru", "phone": "+70827939641"}
0005434925753	594BEB	5413 939243	ANATOLIY ORLOV	{"phone": "+70298212427"}
0005434925754	CFEB88	3728 990266	SERGEY IVANOV	{"phone": "+70636720241"}
0005434925755	A425E7	4598 836751	DENIS IVANOV	{"email": "ivanov.denis.26111982@postgrespro.ru", "phone": "+70648750766"}
0005434925756	587538	7103 458713	DMITRIY BORISOV	{"phone": "+70648478157"}
0005434925757	587538	2051 887081	VERONIKA FADEEVA	{"email": "v-fadeeva.051975@postgrespro.ru", "phone": "+70183837598"}
0005434925758	A6EDCD	3654 080112	ARINA SERGEEVA	{"email": "sergeeva-arina-1981@postgrespro.ru", "phone": "+70161512920"}
0005434925759	CEF28B	8203 538306	VALERIY KUZNECOV	{"phone": "+70895725409"}
0005434925760	F136AA	2168 307249	VALENTINA NAUMOVA	{"email": "naumova_valentina1974@postgrespro.ru", "phone": "+70657932354"}
0005434925761	94AA56	8499 367870	TATYANA ZOTOVA	{"phone": "+70852237616"}
0005434925762	6C226B	8578 354164	MARIYA SEMENOVA	{"phone": "+70939575046"}
0005434925763	6C226B	7283 682621	NADEZHDA SOROKINA	{"phone": "+70994694279"}
0005434925764	6C226B	3282 989403	MARIYA KUZNECOVA	{"phone": "+70394447335"}
0005434925765	6C226B	4386 470779	ANATOLIY BARANOV	{"email": "baranov-a.121960@postgrespro.ru", "phone": "+70782513263"}
0005434925766	4C1608	5448 252567	VLADIMIR DENISOV	{"email": "vladimirdenisov18121978@postgrespro.ru", "phone": "+70072790799"}
0005434925767	D8D14E	5836 798385	LIDIYA FEDOROVA	{"email": "fedorova_l_1972@postgrespro.ru", "phone": "+70327657108"}
0005434925768	CF291D	7904 122509	VASILIY SHEVCHENKO	{"email": "vasiliy.shevchenko1984@postgrespro.ru", "phone": "+70807812953"}
0005434925769	CF291D	1839 435614	ELENA KAZAKOVA	{"phone": "+70852531116"}
0005434925770	738A16	0932 492854	ISLAM GERASIMOV	{"phone": "+70567389152"}
0005434925771	738A16	6780 135435	ANASTASIYA FILIPPOVA	{"phone": "+70084511650"}
0005434925772	E206EF	6372 543366	RAISA BARANOVA	{"phone": "+70493819942"}
0005434925773	E206EF	5666 807798	OLGA ABRAMOVA	{"phone": "+70518604281"}
0005434925774	4FD7D4	4507 828903	NAILYA GAVRILOVA	{"phone": "+70517220135"}
0005434925775	4FD7D4	1028 180796	KLIM SERGEEV	{"phone": "+70086391896"}
0005434925776	507CB3	9932 814749	ANDREY VLASOV	{"phone": "+70240875104"}
0005434925777	868275	1707 888497	SVETLANA ILINA	{"email": "svetlana_ilina_1968@postgrespro.ru", "phone": "+70432366660"}
0005434925778	868275	9225 917887	NATALYA FEDOROVA	{"phone": "+70003538931"}
0005434925779	868275	0048 361711	ANASTASIYA EGOROVA	{"phone": "+70476528383"}
0005434925780	E51962	0715 340058	DANIL NIKOLAEV	{"email": "danil.nikolaev_111972@postgrespro.ru", "phone": "+70545043373"}
0005434925781	E51962	2806 359301	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva.1959@postgrespro.ru", "phone": "+70525908052"}
0005434925782	A77C50	3645 081951	MARIYA VLASOVA	{"email": "vlasova-m.15071979@postgrespro.ru", "phone": "+70387353423"}
0005434925783	A77C50	5409 558503	ALEKSANDR FOMIN	{"phone": "+70492260808"}
0005434925785	370DBC	1625 863089	EVGENIY ALEKSANDROV	{"phone": "+70208875327"}
0005434925786	370DBC	4907 828435	MARINA ZAYCEVA	{"phone": "+70844935839"}
0005434925787	97258C	9350 733987	YURIY IVANOV	{"email": "y.ivanov_091970@postgrespro.ru", "phone": "+70981092186"}
0005434925788	97258C	0717 070487	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr.20031963@postgrespro.ru", "phone": "+70789970109"}
0005434925789	1C2D60	1701 934592	VALENTINA ARKHIPOVA	{"phone": "+70997327695"}
0005434925790	48E61F	3231 133275	VERA GRISHINA	{"email": "veragrishina.03061976@postgrespro.ru", "phone": "+70130200986"}
0005434925791	48E61F	8130 678492	MATVEY GRIGOREV	{"phone": "+70641914809"}
0005434925792	DFA136	9860 973806	KONSTANTIN KUZMIN	{"email": "konstantinkuzmin.101959@postgrespro.ru", "phone": "+70811743971"}
0005434925793	DFA136	9036 312036	POLINA ALEKSANDROVA	{"phone": "+70123760580"}
0005434925794	DFA136	0679 799583	ALEKSANDRA POPOVA	{"email": "apopova011977@postgrespro.ru", "phone": "+70108726689"}
0005434925795	21513A	7232 587395	DMITRIY MIRONOV	{"email": "dmitriy_mironov_06011976@postgrespro.ru", "phone": "+70526743783"}
0005434925796	357495	0673 935130	TAMARA TARASOVA	{"email": "tamara.tarasova1986@postgrespro.ru", "phone": "+70149471939"}
0005434925797	9CF59B	5947 494592	NINA MOISEEVA	{"phone": "+70024862508"}
0005434925798	17F58F	8066 040077	DANIIL ANDREEV	{"phone": "+70100532066"}
0005434925799	17F58F	6264 077827	NIKOLAY CHERNOV	{"email": "nikolay-chernov_081977@postgrespro.ru", "phone": "+70616613724"}
0005434925800	F6CA69	2961 251362	OLESYA MARTYNOVA	{"phone": "+70510741254"}
0005434925801	F6CA69	2543 754742	LIDIYA KUZNECOVA	{"phone": "+70907766153"}
0005434925802	DB60B3	0082 422493	LYUBOV MAKSIMOVA	{"email": "l.maksimova_051965@postgrespro.ru", "phone": "+70950177225"}
0005434925803	DB60B3	4367 515954	ALEFTINA KONOVALOVA	{"email": "a.konovalova081981@postgrespro.ru", "phone": "+70293730537"}
0005434925804	ED09B3	7441 990837	ALEKSANDR VOLKOV	{"phone": "+70989390510"}
0005434925805	ED09B3	0653 453970	NADEZHDA KUZNECOVA	{"email": "n-kuznecova-071962@postgrespro.ru", "phone": "+70331762679"}
0005434925806	EBFDA3	2441 394847	ALEKSEY PETROV	{"phone": "+70855989917"}
0005434925807	6D7A0C	6909 171574	ALEKSEY MIRONOV	{"email": "amironov-1967@postgrespro.ru", "phone": "+70876260198"}
0005434925808	6365AC	2727 663458	YAN MARTYNOV	{"phone": "+70972778384"}
0005434925809	629F76	0828 660446	ANTON MIRONOV	{"phone": "+70296838510"}
0005434925810	0E2C82	6745 203965	VLADIMIR IVANOV	{"email": "vivanov051971@postgrespro.ru", "phone": "+70240345866"}
0005434925811	75CC6D	6556 993749	VLADIMIR KONOVALOV	{"phone": "+70073646215"}
0005434925812	2FEF62	2977 512084	MARGARITA KUZNECOVA	{"email": "kuznecovam.051976@postgrespro.ru", "phone": "+70778154116"}
0005434925813	7A7BF1	7020 329840	DMITRIY MIKHAYLOV	{"email": "dmitriy_mikhaylov_101957@postgrespro.ru", "phone": "+70774160754"}
0005434925814	C2D232	5930 160422	DMITRIY ALEKSANDROV	{"email": "dmitriyaleksandrov1964@postgrespro.ru", "phone": "+70569326052"}
0005434925815	3BC3A3	2806 150499	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy-26051965@postgrespro.ru", "phone": "+70952277831"}
0005434925816	B3F6E1	3483 773150	EVGENIYA KAZAKOVA	{"phone": "+70187505449"}
0005434925817	B3F6E1	6062 159968	ALEKSEY YAKOVLEV	{"phone": "+70616504699"}
0005434925818	1EDA15	9760 395564	OLGA ZHUKOVA	{"email": "o.zhukova081975@postgrespro.ru", "phone": "+70595273297"}
0005434925819	1EDA15	9449 394288	ANTON ZAKHAROV	{"phone": "+70687234625"}
0005434925820	7EED31	2902 676184	TATYANA BOGDANOVA	{"phone": "+70275341981"}
0005434925821	A6A6F8	5023 919314	EVGENIY BORISOV	{"email": "borisovevgeniy.1963@postgrespro.ru", "phone": "+70513068201"}
0005434925822	A6A6F8	4044 164960	ALEKSANDR DMITRIEV	{"phone": "+70063700018"}
0005434925823	A6A6F8	3814 152527	SERGEY ZHUKOV	{"email": "zhukov.sergey-081977@postgrespro.ru", "phone": "+70254258034"}
0005434925824	C71D32	7281 775907	LARISA FROLOVA	{"email": "l_frolova_1969@postgrespro.ru", "phone": "+70388497218"}
0005434925825	09A66B	2781 608092	VALENTINA KOMAROVA	{"email": "v.komarova-1979@postgrespro.ru", "phone": "+70064038027"}
0005434925826	C2615A	3990 399114	VITALIY KULIKOV	{"email": "vitaliy.kulikov.031976@postgrespro.ru", "phone": "+70954118299"}
0005434925827	C179FF	3039 382530	ALEKSANDR SEMENOV	{"phone": "+70259957069"}
0005434925828	98C16B	5912 263597	SAVELIY SAVELEV	{"phone": "+70094150909"}
0005434925829	F18347	7554 088859	DMITRIY POPOV	{"email": "popovdmitriy.1958@postgrespro.ru", "phone": "+70456606026"}
0005434925830	BCF89D	3165 812307	SVETLANA GERASIMOVA	{"phone": "+70623808284"}
0005434925831	BCF89D	3430 696962	YAROSLAV VOLKOV	{"phone": "+70799555450"}
0005434925832	FFCF55	9407 084459	OLGA MIKHAYLOVA	{"phone": "+70080814519"}
0005434925833	7468C9	8988 882710	OLGA FADEEVA	{"email": "olga-fadeeva01031976@postgrespro.ru", "phone": "+70401574767"}
0005434925834	7468C9	4758 907660	MARINA KISELEVA	{"email": "kiseleva.marina.21011974@postgrespro.ru", "phone": "+70568283039"}
0005434925835	7468C9	6003 528985	STANISLAV NAZAROV	{"email": "stanislavnazarov-1955@postgrespro.ru", "phone": "+70635023299"}
0005434925836	953217	5098 065844	ANNA NIKITINA	{"phone": "+70591060353"}
0005434925837	8CB4DA	2573 573980	SERGEY FROLOV	{"email": "sfrolov071973@postgrespro.ru", "phone": "+70072927716"}
0005434925838	F55E0B	2823 035028	EVGENIYA ROMANOVA	{"phone": "+70928654441"}
0005434925839	9841FB	1387 428747	EVGENIY SCHERBAKOV	{"email": "scherbakov.evgeniy26011976@postgrespro.ru", "phone": "+70457827229"}
0005434925840	033C00	8993 389106	RAISA GORBUNOVA	{"phone": "+70990287343"}
0005434925841	9BDC07	4018 997052	ELENA KOROLEVA	{"email": "ekoroleva.051982@postgrespro.ru", "phone": "+70452222442"}
0005434925842	1F5149	1947 486008	YANA VOROBEVA	{"phone": "+70459162223"}
0005434925843	1F5149	1922 436737	ANNA VASILEVA	{"email": "vasileva.a.091973@postgrespro.ru", "phone": "+70351131092"}
0005434925844	3B9201	6923 941746	MARIYA VOLKOVA	{"email": "m.volkova1972@postgrespro.ru", "phone": "+70740449125"}
0005434925845	C4D939	6412 394904	DIANA SMIRNOVA	{"email": "dsmirnova19081988@postgrespro.ru", "phone": "+70186279386"}
0005434925846	FC3734	7159 014415	OLEG SMIRNOV	{"phone": "+70320884875"}
0005434925847	119116	2356 845410	NIKOLAY MEDVEDEV	{"phone": "+70098776617"}
0005434925848	D049DF	3978 958482	OLGA KAZAKOVA	{"email": "kazakova-o_011966@postgrespro.ru", "phone": "+70876867983"}
0005434925849	BB4D7D	1314 008341	ANATOLIY NAZAROV	{"phone": "+70851730836"}
0005434925850	CBD1CF	3497 964552	MARIYA NAZAROVA	{"phone": "+70546145074"}
0005434925851	318952	9296 427735	ALEKSANDRA ANISIMOVA	{"phone": "+70088239011"}
0005434925852	32A88B	8836 226685	ARTEM MAKAROV	{"phone": "+70953712871"}
0005434925853	32A88B	5533 332732	OKSANA KUZNECOVA	{"email": "oksana_kuznecova-121969@postgrespro.ru", "phone": "+70987814064"}
0005434925854	62FC76	1673 905767	OLGA POPOVA	{"email": "opopova.08031987@postgrespro.ru", "phone": "+70036416299"}
0005434925855	80B598	6874 679551	MARGARITA KOROLEVA	{"email": "koroleva_margarita-081972@postgrespro.ru", "phone": "+70936593350"}
0005434925856	80B598	0621 595181	GRIGORIY KUZMIN	{"phone": "+70442502160"}
0005434925857	E7ED39	9962 929795	ZOYA MOISEEVA	{"phone": "+70721609576"}
0005434925858	E7ED39	9363 201840	LYUBOV NIKITINA	{"email": "nikitinalyubov_1972@postgrespro.ru", "phone": "+70430872746"}
0005434925859	E7ED39	3638 636455	KSENIYA MIKHAYLOVA	{"phone": "+70473884900"}
0005434925860	F71AF5	5325 709056	RAMILYA TARASOVA	{"phone": "+70515334639"}
0005434925861	7E9667	2336 640932	PETR TIKHONOV	{"phone": "+70581694361"}
0005434925862	390A9F	8609 070406	LYUDMILA OSIPOVA	{"phone": "+70700347391"}
0005434925863	390A9F	9109 202467	GALINA KONOVALOVA	{"phone": "+70661362254"}
0005434925864	390A9F	7353 559718	VLADIMIR SERGEEV	{"phone": "+70323514618"}
0005434925865	3EE153	0165 012903	VALENTINA KUZNECOVA	{"phone": "+70346181859"}
0005434925866	763994	0490 470267	VALENTINA ZAKHAROVA	{"phone": "+70626691381"}
0005434925867	0F03DF	3408 574964	NELLI VOLKOVA	{"phone": "+70587662415"}
0005434925868	D4032E	7501 098991	VADIM ANDREEV	{"email": "andreev.v1972@postgrespro.ru", "phone": "+70231429516"}
0005434925869	FB85B7	3182 919198	IVAN GORBUNOV	{"phone": "+70136463156"}
0005434925870	FB85B7	7442 280423	ILYAS TIKHONOV	{"phone": "+70662056017"}
0005434925871	7EFE4F	2022 280257	LARISA ALEKSEEVA	{"phone": "+70991585294"}
0005434925872	7EFE4F	2926 359887	BORIS STEPANOV	{"phone": "+70042360271"}
0005434925873	8002A9	6752 508205	MARINA DMITRIEVA	{"phone": "+70769888891"}
0005434925874	0A4996	0165 992205	YULIYA SOKOLOVA	{"phone": "+70763118455"}
0005434925875	011B65	9210 777985	YURIY SOROKIN	{"email": "yuriy.sorokin.1965@postgrespro.ru", "phone": "+70459120181"}
0005434925876	011B65	7843 821844	EVGENIY OSIPOV	{"email": "evgeniyosipov-14061972@postgrespro.ru", "phone": "+70220273462"}
0005434925877	011B65	6496 730201	LYUBOV MOROZOVA	{"phone": "+70808029241"}
0005434925878	3BF048	7913 204971	TAISIYA ALEKSEEVA	{"email": "t.alekseeva_25111975@postgrespro.ru", "phone": "+70381524298"}
0005434925879	3BF048	5084 341745	VERA SOLOVEVA	{"phone": "+70037145552"}
0005434925880	5060E7	6961 385410	RISHAT POPOV	{"email": "rishatpopov.1980@postgrespro.ru", "phone": "+70181677721"}
0005434925881	74CFC1	1824 941277	KSENIYA POLYAKOVA	{"email": "kseniyapolyakova091972@postgrespro.ru", "phone": "+70695233760"}
0005434925882	D48956	8612 813996	VLADIMIR CHERNOV	{"phone": "+70944525847"}
0005434925883	03E9D6	9177 351222	VALENTINA YAKOVLEVA	{"phone": "+70168730232"}
0005434925884	34CB38	7670 588898	DENIS ABRAMOV	{"phone": "+70828076733"}
0005434925885	E7D2DF	1297 212861	ANNA GAVRILOVA	{"phone": "+70863995789"}
0005434925886	E7D2DF	9450 728939	RUSTAM MIKHAYLOV	{"email": "rustammikhaylov-011967@postgrespro.ru", "phone": "+70679690850"}
0005434925887	3E87CD	8582 076843	SNEZHANA GAVRILOVA	{"phone": "+70764421118"}
0005434925888	E74CBC	7946 546496	OLEG NIKOLAEV	{"email": "nikolaev-o061976@postgrespro.ru", "phone": "+70951306557"}
0005434925889	19612E	7384 658579	ANASTASIYA DAVYDOVA	{"email": "a.davydova_101968@postgrespro.ru", "phone": "+70267670691"}
0005434925890	19612E	5684 439540	MIKHAIL FEDOTOV	{"email": "fedotov.mikhail-1973@postgrespro.ru", "phone": "+70632409626"}
0005434925891	896C5A	0103 957641	ALEKSANDR KOZLOV	{"phone": "+70043493362"}
0005434925892	896C5A	2707 236310	DMITRIY FROLOV	{"phone": "+70996476661"}
0005434925893	392897	7770 824468	SVETLANA KOMAROVA	{"phone": "+70814979671"}
0005434925894	6A3F57	0023 220379	NINA LOGINOVA	{"email": "loginova.nina.03081979@postgrespro.ru", "phone": "+70374789996"}
0005434925895	E4F6BC	6203 933360	ARTEM EGOROV	{"email": "artemegorov-08071968@postgrespro.ru", "phone": "+70432557352"}
0005434925896	AA8CC6	0100 694453	LIDIYA SOLOVEVA	{"email": "lsoloveva_09031971@postgrespro.ru", "phone": "+70929835319"}
0005434925897	F99CBC	8176 279874	OKSANA BOGDANOVA	{"phone": "+70226831634"}
0005434925898	F99CBC	5447 889349	ALEKSANDR DENISOV	{"email": "denisov_a041974@postgrespro.ru", "phone": "+70722526505"}
0005434925899	C2D6B7	8873 339675	IRINA MIKHAYLOVA	{"email": "imikhaylova-1972@postgrespro.ru", "phone": "+70142859480"}
0005434925900	CC0F7D	2522 167829	ANTONINA IVANOVA	{"email": "antonina_ivanova.021974@postgrespro.ru", "phone": "+70629489227"}
0005434925901	CC0F7D	1909 127964	VALERIY POPOV	{"phone": "+70245264054"}
0005434925902	CC0F7D	0983 460258	ELENA ARKHIPOVA	{"phone": "+70273536783"}
0005434925903	BFF818	2030 018183	MAKSIM GAVRILOV	{"phone": "+70361776112"}
0005434925904	F49922	0954 896721	EVGENIY SERGEEV	{"phone": "+70707815867"}
0005434925905	BBFB38	1306 461974	ANTON SMIRNOV	{"email": "smirnov-anton21101967@postgrespro.ru", "phone": "+70882594104"}
0005434925906	BBFB38	1584 121627	NADEZHDA NOVIKOVA	{"email": "novikovanadezhda_1969@postgrespro.ru", "phone": "+70552497458"}
0005434925907	BBFB38	3492 724200	OKSANA MAKAROVA	{"email": "oksana_makarova.20111977@postgrespro.ru", "phone": "+70363727996"}
0005434925908	C5AF92	2855 112440	ALEKSANDR DENISOV	{"email": "denisov-a1966@postgrespro.ru", "phone": "+70938233938"}
0005434925909	C5AF92	5783 944883	ALEKSANDR ALEKSEEV	{"email": "aalekseev08081975@postgrespro.ru", "phone": "+70176578453"}
0005434925910	C5AF92	7840 547320	DAMIR NAZAROV	{"email": "nazarov_d1979@postgrespro.ru", "phone": "+70623291176"}
0005434925911	F4D6D4	9066 323317	IVAN IVANOV	{"email": "i_ivanov-03101970@postgrespro.ru", "phone": "+70329967252"}
0005434925912	6BE046	8367 454131	ROMAN IVANOV	{"email": "ivanovroman-091984@postgrespro.ru", "phone": "+70426735737"}
0005434925913	6BE046	7050 982877	ARTEM PETROV	{"email": "petrov_artem.071977@postgrespro.ru", "phone": "+70921123821"}
0005434925914	4EEB92	6578 959961	TATYANA IVANOVA	{"email": "ivanova.t.071975@postgrespro.ru", "phone": "+70124148153"}
0005434925915	E17ACB	4853 701047	ELENA ALEKSEEVA	{"email": "elena_alekseeva_031975@postgrespro.ru", "phone": "+70233778969"}
0005434925916	307699	9205 238047	ANTONINA GUSEVA	{"phone": "+70034745323"}
0005434925917	0A8DBA	5454 608883	GUZEL PETROVA	{"email": "petrova_g-041969@postgrespro.ru", "phone": "+70282500434"}
0005434925918	E52B86	5633 220477	ELENA KOVALEVA	{"phone": "+70054834347"}
0005434925919	E52B86	6896 354834	ELENA MIRONOVA	{"email": "elena.mironova.14111981@postgrespro.ru", "phone": "+70285641962"}
0005434925920	E923CD	7804 947095	MARIYA KUZNECOVA	{"phone": "+70639166762"}
0005434925921	E923CD	4892 870051	NINA MOISEEVA	{"email": "moiseeva-nina-1974@postgrespro.ru", "phone": "+70309684251"}
0005434925922	E923CD	4613 811233	SVETLANA EGOROVA	{"email": "egorovasvetlana121963@postgrespro.ru", "phone": "+70896706931"}
0005434925923	3E0829	0830 684927	VASILIY BONDARENKO	{"email": "v.bondarenko.23041969@postgrespro.ru", "phone": "+70195752869"}
0005434925924	AEE60A	7890 025636	VIKTOR BONDARENKO	{"phone": "+70564114120"}
0005434925925	CC4C7F	4838 825249	DMITRIY VASILEV	{"phone": "+70834425522"}
0005434925926	6C8D2D	2348 636371	IRINA BORISOVA	{"email": "borisova-i03091968@postgrespro.ru", "phone": "+70734225509"}
0005434925927	C4A1B2	0121 857205	ALEKSEY ROMANOV	{"email": "romanov_aleksey_1973@postgrespro.ru", "phone": "+70989744580"}
0005434925928	C4A1B2	0450 479020	EMIL FEDOROV	{"email": "emil_fedorov_1956@postgrespro.ru", "phone": "+70247524393"}
0005434925929	C4A1B2	9483 856052	LYUBOV IVANOVA	{"email": "l.ivanova-22081962@postgrespro.ru", "phone": "+70843327447"}
0005434925930	34FAAF	0518 666022	ALEKSANDR MAKSIMOV	{"phone": "+70621817749"}
0005434925931	5FE9C7	6674 365816	IRINA GORBUNOVA	{"phone": "+70092460265"}
0005434925932	395228	7806 995604	ANDREY SCHERBAKOV	{"phone": "+70111161341"}
0005434925933	476855	5143 293853	SERGEY FILIPPOV	{"email": "filippov-s_1971@postgrespro.ru", "phone": "+70244575534"}
0005434925934	564C2D	2368 161429	MAKSIM FEDOTOV	{"phone": "+70239935033"}
0005434925935	564C2D	6655 305145	GRIGORIY ABRAMOV	{"email": "abramov_grigoriy_26051973@postgrespro.ru", "phone": "+70369214413"}
0005434925936	8C70EA	6330 937452	TATYANA MEDVEDEVA	{"phone": "+70916233238"}
0005434925937	C10BB1	5603 568176	VIKTORIYA OSIPOVA	{"phone": "+70299091588"}
0005434925938	C10BB1	7443 965008	ARTEM GRIGOREV	{"email": "grigorev_a_121980@postgrespro.ru", "phone": "+70124553845"}
0005434925939	330781	7031 023935	VERA NAZAROVA	{"phone": "+70009312110"}
0005434925940	EDEF4A	1234 898592	VALENTINA MAKAROVA	{"phone": "+70322223136"}
0005434925941	470037	5280 102715	BORIS IVANOV	{"phone": "+70715316495"}
0005434925942	191EEC	2106 151148	MARINA MARTYNOVA	{"phone": "+70010360869"}
0005434925943	191EEC	4217 641221	IVAN ZAYCEV	{"email": "zaycev-ivan_1977@postgrespro.ru", "phone": "+70175451948"}
0005434925944	54E267	1902 226706	VALENTINA EFREMOVA	{"phone": "+70145485712"}
0005434925945	54E267	5893 090624	ANDREY TARASOV	{"phone": "+70131196423"}
0005434925946	1928CA	4696 987251	ANNA PETROVA	{"email": "anna-petrova-121967@postgrespro.ru", "phone": "+70989784318"}
0005434925947	1928CA	7252 611182	ANDREY SOKOLOV	{"email": "sokolova.041972@postgrespro.ru", "phone": "+70699424051"}
0005434925948	0E9D34	3275 485983	TAMARA SAVELEVA	{"phone": "+70012647281"}
0005434925949	64F6F4	6020 846673	VALENTIN FILIPPOV	{"email": "vfilippov1971@postgrespro.ru", "phone": "+70034833110"}
0005434925950	E3798B	6393 795763	ALEKSEY MIRONOV	{"phone": "+70448374995"}
0005434925951	83118B	9616 452647	ANDREY KUZNECOV	{"email": "kuznecov-andrey-011972@postgrespro.ru", "phone": "+70969065879"}
0005434925952	B231EE	1286 546190	LYUBOV KULIKOVA	{"phone": "+70189755260"}
0005434925953	5CD141	2456 202479	OLGA BELYAEVA	{"phone": "+70341597718"}
0005434925954	7446E5	1258 740404	KIRILL FEDOROV	{"phone": "+70149427202"}
0005434925955	7446E5	4747 316572	DMITRIY SOROKIN	{"phone": "+70188167267"}
0005434925956	760826	2624 883740	RUSLAN RODIONOV	{"email": "ruslan_rodionov_22111974@postgrespro.ru", "phone": "+70634560437"}
0005434925957	760826	4042 648197	IRINA LEBEDEVA	{"phone": "+70831572915"}
0005434925958	E35EFA	1976 099817	VLADLEN SERGEEV	{"email": "vladlen_sergeev051970@postgrespro.ru", "phone": "+70641062312"}
0005434925959	784416	8873 823391	VALENTINA DMITRIEVA	{"email": "vdmitrieva-1972@postgrespro.ru", "phone": "+70622433046"}
0005434925960	08B128	2906 310296	ALEKSEY MEDVEDEV	{"phone": "+70720642591"}
0005434925961	08B128	8013 927762	GRIGORIY IVANOV	{"email": "g_ivanov081966@postgrespro.ru", "phone": "+70029691031"}
0005434925962	C0022F	0185 723517	ARSENIY KUZNECOV	{"phone": "+70763795620"}
0005434925963	5EE99D	1632 087170	ILYA ALEKSANDROV	{"email": "ilya_aleksandrov_10041964@postgrespro.ru", "phone": "+70109765222"}
0005434925964	5F245D	1432 974748	GALINA FILATOVA	{"phone": "+70250154486"}
0005434925965	5F245D	2845 422874	NATALYA NESTEROVA	{"phone": "+70448580179"}
0005434925966	7455D4	2736 144090	ALEKSANDRA KOROLEVA	{"email": "koroleva-aleksandra.22061974@postgrespro.ru", "phone": "+70356049564"}
0005434925967	0A98A0	0046 745100	ALENA ZAYCEVA	{"phone": "+70494689769"}
0005434925968	D611C3	0401 278350	NINA ALEKSEEVA	{"email": "alekseevan-08041966@postgrespro.ru", "phone": "+70128361992"}
0005434925969	DB0DD4	5069 284465	VYACHESLAV POPOV	{"email": "vyacheslav_popov.28031971@postgrespro.ru", "phone": "+70893079032"}
0005434925970	8F1B03	5771 367646	PAVEL ANDREEV	{"email": "andreev-pavel.1979@postgrespro.ru", "phone": "+70324052589"}
0005434925971	002D3A	3899 376625	DMITRIY ALEKSANDROV	{"email": "aleksandrov_d.031974@postgrespro.ru", "phone": "+70865156053"}
0005434925972	68454F	6460 159396	SERGEY VOROBEV	{"email": "vorobev.s_1972@postgrespro.ru", "phone": "+70581390886"}
0005434925973	6FCF49	8884 465219	NIKOLAY DAVYDOV	{"phone": "+70075480121"}
0005434925974	6FCF49	0612 799188	ALEKSANDRA ANISIMOVA	{"phone": "+70953636303"}
0005434925975	D2BCE8	3737 092088	TATYANA DENISOVA	{"email": "denisova-t.23081976@postgrespro.ru", "phone": "+70822776897"}
0005434925976	D2BCE8	4327 341791	TATYANA POTAPOVA	{"phone": "+70946292798"}
0005434925977	E1150A	4803 747650	MARIYA ANISIMOVA	{"phone": "+70438970730"}
0005434925978	B1608E	5514 934620	DANIL IVANOV	{"email": "ivanovdanil-04111975@postgrespro.ru", "phone": "+70457300924"}
0005434925979	8FC1E6	8784 647835	DARYA MEDVEDEVA	{"email": "medvedeva_darya_1966@postgrespro.ru", "phone": "+70545050483"}
0005434925980	8FC1E6	3086 306648	VIKTOR DAVYDOV	{"phone": "+70520723018"}
0005434925981	D9C330	6291 623969	VLADISLAV TARASOV	{"phone": "+70344241560"}
0005434925982	D9C330	0133 642238	VALENTINA ANDREEVA	{"phone": "+70898983770"}
0005434925983	806165	2673 309600	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov-07051976@postgrespro.ru", "phone": "+70036115595"}
0005434925984	A3543B	7195 287183	NIKOLAY ZAKHAROV	{"phone": "+70275440841"}
0005434925985	A3543B	1305 850708	VADIM SIDOROV	{"phone": "+70581612372"}
0005434925986	6698EB	1355 477043	RIMMA EGOROVA	{"email": "rimma-egorova1972@postgrespro.ru", "phone": "+70615412757"}
0005434925987	17A5E4	8704 842889	MARIYA SERGEEVA	{"email": "sergeeva-m_1977@postgrespro.ru", "phone": "+70227672302"}
0005434925988	EB9E8C	1340 387522	ELENA SOROKINA	{"phone": "+70255082296"}
0005434925989	A2BEF2	9513 416306	IRINA EFIMOVA	{"email": "i.efimova051963@postgrespro.ru", "phone": "+70574487491"}
0005434925990	A2BEF2	1169 183849	SERGEY IVANOV	{"phone": "+70793246303"}
0005434925991	17B1C8	6351 812237	NADEZHDA MOISEEVA	{"phone": "+70455105719"}
0005434925992	954998	6445 377842	NIKOLAY EGOROV	{"phone": "+70980081976"}
0005434925993	954998	4392 359106	LIDIYA POTAPOVA	{"email": "l.potapova_021966@postgrespro.ru", "phone": "+70241048491"}
0005434925994	34E3AE	5455 380125	PAVEL KOROLEV	{"phone": "+70739982651"}
0005434925995	34E3AE	0384 802022	ALEKSANDR ANDREEV	{"email": "aleksandrandreev.051982@postgrespro.ru", "phone": "+70547561910"}
0005434925996	B22C2C	3288 824086	ANDREY MIKHAYLOV	{"phone": "+70827375777"}
0005434925997	B36163	7064 378874	EDUARD KOROLEV	{"email": "korolev_e_1979@postgrespro.ru", "phone": "+70628117433"}
0005434925998	158BBB	0039 511558	TATYANA KUZNECOVA	{"phone": "+70961669427"}
0005434925999	8D4B04	6512 395956	ELENA GRISHINA	{"phone": "+70766313177"}
0005434926000	0C968F	8411 368003	VIKTOR DMITRIEV	{"email": "vdmitriev-101986@postgrespro.ru", "phone": "+70360296904"}
0005434926001	6BC2B8	3425 294235	EKATERINA EFREMOVA	{"phone": "+70810973282"}
0005434926002	A6A613	4741 868243	PETR BELOV	{"phone": "+70359700517"}
0005434926003	A6A613	5645 641494	ALEKSEY NIKITIN	{"phone": "+70101670333"}
0005434926004	A6A613	7424 534080	ANNA MIKHAYLOVA	{"phone": "+70193443875"}
0005434926005	05D394	1634 627872	IVAN SAVELEV	{"email": "ivan.savelev-19011980@postgrespro.ru", "phone": "+70157668969"}
0005434926006	D29876	0617 258389	DINA POPOVA	{"phone": "+70074985438"}
0005434926007	B112FC	6246 215451	ILSHAT KISELEV	{"phone": "+70027121030"}
0005434926008	4F453F	2092 205562	DINARA KALININA	{"phone": "+70998947895"}
0005434926009	4F453F	9153 926884	ANASTASIYA SERGEEVA	{"phone": "+70894704480"}
0005434926010	4F453F	0281 462877	MAKSIM KULIKOV	{"email": "maksimkulikov09021973@postgrespro.ru", "phone": "+70833713583"}
0005434926011	AAD403	1714 537194	NIKITA MIKHAYLOV	{"email": "n.mikhaylov_081960@postgrespro.ru", "phone": "+70136966567"}
0005434926012	AAD403	6809 416485	TATYANA DANILOVA	{"phone": "+70820065240"}
0005434926013	F0AAEB	5898 255644	ANASTASIYA VOROBEVA	{"phone": "+70661923916"}
0005434926014	F0AAEB	9992 662580	ANATOLIY KONOVALOV	{"phone": "+70309675776"}
0005434926015	89FFA8	3096 999585	LYUDMILA GERASIMOVA	{"email": "lyudmilagerasimova_1975@postgrespro.ru", "phone": "+70313962878"}
0005434926016	D055E3	8502 345341	ZINAIDA GORBUNOVA	{"phone": "+70474526248"}
0005434926017	C19034	7798 938407	ANNA LEBEDEVA	{"email": "a-lebedeva1973@postgrespro.ru", "phone": "+70636332697"}
0005434926018	59194D	3978 403092	ALEKSANDR NOVIKOV	{"phone": "+70053789482"}
0005434926019	D47E51	9966 201379	MARIYA KOROLEVA	{"phone": "+70568218323"}
0005434926020	EE6F74	5912 950753	ROMAN RODIONOV	{"email": "rodionov_r-26041972@postgrespro.ru", "phone": "+70766414270"}
0005434926021	8BB834	1226 274989	IRINA OVCHINNIKOVA	{"email": "irina.ovchinnikova.111981@postgrespro.ru", "phone": "+70231713203"}
0005434926022	2F6E03	2403 893744	TATYANA SOKOLOVA	{"email": "sokolova_t.021975@postgrespro.ru", "phone": "+70307482108"}
0005434926023	E41E16	6699 396767	RIMMA ANTONOVA	{"email": "rimma-antonova-041986@postgrespro.ru", "phone": "+70273029774"}
0005434926024	E41E16	9845 616673	NIKOLAY VOROBEV	{"email": "nikolay.vorobev-09041977@postgrespro.ru", "phone": "+70379658306"}
0005434926025	E41E16	5069 015629	VIKTOR GERASIMOV	{"email": "viktorgerasimov051971@postgrespro.ru", "phone": "+70347926558"}
0005434926026	28B86A	2021 460209	ILNAR MIKHAYLOV	{"phone": "+70609928185"}
0005434926027	28B86A	0774 114207	NIKOLAY SERGEEV	{"phone": "+70915204762"}
0005434926028	090FBB	5615 183474	MAKSIM ZHURAVLEV	{"email": "zhuravlev-maksim_011976@postgrespro.ru", "phone": "+70218642463"}
0005434926029	7630C2	8892 680616	IGOR KISELEV	{"phone": "+70120833482"}
0005434926030	7630C2	5048 817310	ALEKSEY KOROLEV	{"email": "korolev.aleksey_23051981@postgrespro.ru", "phone": "+70684349678"}
0005434926031	00C34C	6008 280178	YAROSLAV GORBUNOV	{"phone": "+70069467283"}
0005434926032	8F7198	8550 135220	NIKOLAY ROMANOV	{"email": "romanov_n_05111971@postgrespro.ru", "phone": "+70507856459"}
0005434926033	CFD335	5419 674576	NADEZHDA MAKAROVA	{"email": "nadezhda.makarova.1970@postgrespro.ru", "phone": "+70160756153"}
0005434926034	0A093A	5777 622846	ELENA KOZLOVA	{"email": "kozlova.elena.071972@postgrespro.ru", "phone": "+70764147109"}
0005434926035	FF2314	1409 473896	ZULFIYA ARKHIPOVA	{"phone": "+70932004429"}
0005434926036	F24FEE	8473 821691	VALERIY ANDREEV	{"email": "valeriy.andreev-16011966@postgrespro.ru", "phone": "+70635325535"}
0005434926037	C44265	9897 040905	VLADIMIR KAZAKOV	{"email": "v_kazakov081962@postgrespro.ru", "phone": "+70007902995"}
0005434926038	CFA22D	9697 555803	YULIYA ABRAMOVA	{"email": "abramova_yuliya1975@postgrespro.ru", "phone": "+70968269578"}
0005434926039	A7E9ED	8927 630777	NIKOLAY VASILEV	{"phone": "+70654764448"}
0005434926040	A7E9ED	3102 052730	LYUDMILA EGOROVA	{"phone": "+70904231953"}
0005434926041	A7E9ED	3429 405341	DMITRIY ROMANOV	{"email": "romanov.d-26111968@postgrespro.ru", "phone": "+70317972093"}
0005434926042	5768C8	5294 769569	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-24101969@postgrespro.ru", "phone": "+70942957132"}
0005434926043	E7D677	1524 393150	VADIM SAVELEV	{"phone": "+70124215219"}
0005434926044	765066	6162 374342	ALEKSANDR VOLKOV	{"email": "aleksandrvolkov_091972@postgrespro.ru", "phone": "+70418270500"}
0005434926045	9124B3	4983 737118	OLEG STEPANOV	{"email": "stepanov-o1978@postgrespro.ru", "phone": "+70016697424"}
0005434926046	8A2DFA	3620 904215	IGOR ALEKSEEV	{"email": "alekseev-igor_1973@postgrespro.ru", "phone": "+70287380061"}
0005434926047	AD841A	1421 108276	VYACHESLAV NAZAROV	{"email": "vyacheslav.nazarov.23011970@postgrespro.ru", "phone": "+70240952790"}
0005434926048	447B29	2872 257508	KLAVDIYA ISAEVA	{"email": "isaeva.klavdiya-1973@postgrespro.ru", "phone": "+70589415876"}
0005434926049	447B29	7085 879579	LYUDMILA FROLOVA	{"phone": "+70518816187"}
0005434926050	1CFF70	4049 101030	LYUDMILA NIKOLAEVA	{"email": "lyudmila.nikolaeva1966@postgrespro.ru", "phone": "+70158287554"}
0005434926051	1CFF70	4221 584171	TAISIYA PAVLOVA	{"phone": "+70864976223"}
0005434926052	82478B	2385 739511	ALEKSEY SMIRNOV	{"email": "aleksey.smirnov-051968@postgrespro.ru", "phone": "+70927412946"}
0005434926053	B6A333	6759 856486	NINA SCHERBAKOVA	{"email": "n-scherbakova.13011965@postgrespro.ru", "phone": "+70279722654"}
0005434926054	B6A333	3223 208997	DARYA YAKOVLEVA	{"phone": "+70234317043"}
0005434926055	5FED28	0201 723610	VALENTINA SMIRNOVA	{"email": "smirnova_valentina021974@postgrespro.ru", "phone": "+70759906769"}
0005434926056	9EDA5A	7379 742454	OLGA KISELEVA	{"email": "kiseleva.o_28011966@postgrespro.ru", "phone": "+70510317787"}
0005434926057	9EDA5A	6414 289616	SERGEY STEPANOV	{"phone": "+70266306504"}
0005434926058	BF1DE4	9275 838739	TATYANA MARTYNOVA	{"phone": "+70658624657"}
0005434926059	BF1DE4	0678 737017	RADIK ORLOV	{"phone": "+70022857889"}
0005434926060	BBCE83	8495 067536	VLADIMIR AFANASEV	{"phone": "+70420431352"}
0005434926061	74ECCA	1924 618701	ALEKSANDRA ABRAMOVA	{"email": "abramovaa.1973@postgrespro.ru", "phone": "+70699262985"}
0005434926062	05CC14	7521 868314	TAMARA KAZAKOVA	{"email": "t.kazakova_021963@postgrespro.ru", "phone": "+70095279051"}
0005434926063	E1D239	4862 984742	ALEVTINA VASILEVA	{"phone": "+70212599828"}
0005434926064	6B2FE7	5839 904135	OLEG KRASNOV	{"email": "krasnov_oleg121973@postgrespro.ru", "phone": "+70495765218"}
0005434926065	867858	6120 766096	RAISA KRASNOVA	{"email": "rkrasnova-1972@postgrespro.ru", "phone": "+70479317264"}
0005434926066	585C71	2870 962516	OKSANA KUZMINA	{"phone": "+70377323495"}
0005434926067	585C71	2458 368428	EKATERINA MIRONOVA	{"email": "mironova_ekaterina-041973@postgrespro.ru", "phone": "+70923264732"}
0005434926068	B1240E	1042 634137	ALEKSEY ANDREEV	{"phone": "+70561356671"}
0005434926069	F718B9	0495 038110	ZOYA IVANOVA	{"email": "z-ivanova-02051987@postgrespro.ru", "phone": "+70740582774"}
0005434926070	4630D0	5307 368169	OLGA SMIRNOVA	{"phone": "+70773036792"}
0005434926071	0E91F8	3807 348750	MARIYA FEDOROVA	{"email": "fedorovamariya1983@postgrespro.ru", "phone": "+70295538793"}
0005434926072	0E91F8	6471 335695	YULIYA VASILEVA	{"email": "vasileva_yuliya.091970@postgrespro.ru", "phone": "+70031461553"}
0005434926073	42B248	1484 248906	IRINA SEMENOVA	{"phone": "+70640434312"}
0005434926074	5CB549	7018 415708	SERGEY KULIKOV	{"email": "s-kulikov.1967@postgrespro.ru", "phone": "+70540100143"}
0005434926075	924FF6	9182 101036	EVGENIY KONOVALOV	{"phone": "+70306297958"}
0005434926076	2CF618	8073 139263	ELENA ALEKSANDROVA	{"phone": "+70122273691"}
0005434926077	C880D3	3894 515462	VYACHESLAV MIRONOV	{"email": "mironov_v21071972@postgrespro.ru", "phone": "+70287738883"}
0005434926078	581877	2706 338708	GENNADIY KAZAKOV	{"phone": "+70075170893"}
0005434926079	581877	6549 525916	IVAN MIRONOV	{"email": "ivan-mironov1971@postgrespro.ru", "phone": "+70962045652"}
0005434926080	531416	7263 439880	SVETLANA MAKAROVA	{"phone": "+70786825357"}
0005434926081	AD6402	2790 368728	MATVEY VASILEV	{"phone": "+70998494453"}
0005434926082	BC91B0	4512 483557	TATYANA LOGINOVA	{"email": "t-loginova_11071969@postgrespro.ru", "phone": "+70152712148"}
0005434926083	7C2744	8441 180363	IVAN SOKOLOV	{"phone": "+70328325658"}
0005434926084	BA6F5A	5724 904453	ALEKSANDR NOVIKOV	{"phone": "+70564586509"}
0005434926085	BA6F5A	1262 670423	YAROSLAV ALEKSEEV	{"phone": "+70838537588"}
0005434926086	75BD47	4326 276609	IGOR NIKITIN	{"email": "nikitinigor_03071978@postgrespro.ru", "phone": "+70436364660"}
0005434926087	3742D8	6012 575726	VALERIYA DENISOVA	{"phone": "+70857332919"}
0005434926088	3742D8	2695 130194	VASILIY BARANOV	{"phone": "+70187686817"}
0005434926089	8F9949	7064 759420	EVGENIY FROLOV	{"phone": "+70815286372"}
0005434926090	8F9949	5967 725395	ELENA KONDRATEVA	{"phone": "+70924864051"}
0005434926091	8F9949	2344 259831	NIKOLAY MIRONOV	{"phone": "+70697485960"}
0005434926092	B5A269	6702 598215	VLADISLAV POPOV	{"email": "vladislav-popov091968@postgrespro.ru", "phone": "+70528747083"}
0005434926093	15F8F2	5408 159313	ANATOLIY EGOROV	{"email": "anatoliy_egorov_27111983@postgrespro.ru", "phone": "+70920848101"}
0005434926094	5D074C	7178 628762	TATYANA PAVLOVA	{"phone": "+70910608799"}
0005434926095	717857	2786 785794	DMITRIY PETROV	{"phone": "+70991963678"}
0005434926096	717857	3306 841117	SVETLANA ABRAMOVA	{"email": "abramova_s-121971@postgrespro.ru", "phone": "+70971518359"}
0005434926097	D630F4	5877 120728	VALENTIN SIDOROV	{"phone": "+70242817001"}
0005434926098	0A1501	2267 516139	VALENTINA PETROVA	{"email": "petrova-v-11021980@postgrespro.ru", "phone": "+70231209882"}
0005434926099	A99050	6072 050527	RASHIT VOLKOV	{"phone": "+70454107471"}
0005434926100	A99050	5348 834978	ALEKSEY ANTONOV	{"phone": "+70721909946"}
0005434926101	73E6EB	0795 879559	IRINA ZAYCEVA	{"phone": "+70892193472"}
0005434926102	73E6EB	7963 176475	IGOR TARASOV	{"phone": "+70567795983"}
0005434926103	04BF0C	2040 085411	VALERIYA KOMAROVA	{"email": "valeriya.komarova-14101974@postgrespro.ru", "phone": "+70558400005"}
0005434926104	04BF0C	3671 359542	ANASTASIYA TROFIMOVA	{"email": "trofimova.a29071967@postgrespro.ru", "phone": "+70508253909"}
0005434926105	9BE4C0	8255 623397	ELENA IVANOVA	{"email": "ivanovaelena.1994@postgrespro.ru", "phone": "+70414433427"}
0005434926106	A6F492	8158 486110	GALINA IVANOVA	{"phone": "+70111412577"}
0005434926107	A6F492	6539 941066	ELENA KOZLOVA	{"phone": "+70536643191"}
0005434926108	5A68D3	7597 578248	NINA IVANOVA	{"email": "ivanova-n01101966@postgrespro.ru", "phone": "+70529655819"}
0005434926109	D109EE	7204 513082	ANDREY CHERNOV	{"phone": "+70085652852"}
0005434926110	7A60CF	3493 688661	ZINAIDA IVANOVA	{"phone": "+70688017151"}
0005434926111	F77347	6053 234268	ALLA SEMENOVA	{"phone": "+70448507011"}
0005434926112	26CFA5	4330 273942	VLADISLAV KUZNECOV	{"phone": "+70226434065"}
0005434926113	26CFA5	9454 369279	ANASTASIYA ALEKSEEVA	{"email": "alekseeva_a18031965@postgrespro.ru", "phone": "+70156637171"}
0005434926114	53B74D	3771 468076	NADEZHDA BARANOVA	{"email": "n-baranova051971@postgrespro.ru", "phone": "+70541597624"}
0005434926115	64BECC	7785 453065	EVGENIY OSIPOV	{"email": "osipov-e.121971@postgrespro.ru", "phone": "+70554804992"}
0005434926116	2F14AB	1387 534617	MAKSIM IVANOV	{"phone": "+70159066896"}
0005434926117	A1C786	6082 665476	EVGENIYA SAVELEVA	{"email": "e_saveleva-10101969@postgrespro.ru", "phone": "+70771068217"}
0005434926118	D1F370	4368 965827	OLGA OVCHINNIKOVA	{"phone": "+70987931673"}
0005434926119	C90C48	8131 390748	SVETLANA FEDOROVA	{"email": "fedorova.s_041972@postgrespro.ru", "phone": "+70049941678"}
0005434926120	C90C48	3745 007506	OLEG ILIN	{"email": "oilin-081985@postgrespro.ru", "phone": "+70557985913"}
0005434926121	176794	9409 506936	OLGA KUZNECOVA	{"phone": "+70699043284"}
0005434926122	176794	6729 123155	KRISTINA IVANOVA	{"phone": "+70317934575"}
0005434926123	71BF73	7058 637983	ANDREY ZAKHAROV	{"email": "zakharov-a.1970@postgrespro.ru", "phone": "+70679848795"}
0005434926124	521270	6685 319121	IVAN ZAYCEV	{"email": "zaycevi1968@postgrespro.ru", "phone": "+70337209045"}
0005434926125	731108	0488 889883	ANNA ARKHIPOVA	{"email": "arkhipova_a091979@postgrespro.ru", "phone": "+70181916462"}
0005434926126	83CF0F	9194 725213	SERGEY SAVELEV	{"phone": "+70051626593"}
0005434926127	83CF0F	2796 827231	MARGARITA VOLKOVA	{"phone": "+70469359604"}
0005434926128	D6DEAE	7253 003472	ANATOLIY POPOV	{"email": "anatoliy_popov-14111960@postgrespro.ru", "phone": "+70478049427"}
0005434926129	D6DEAE	3268 979193	SERGEY DMITRIEV	{"phone": "+70693469740"}
0005434926130	D6DEAE	5202 811991	ANASTASIYA KUZMINA	{"phone": "+70088892703"}
0005434926131	96AE6E	9312 955286	MARIYA SOROKINA	{"email": "mariyasorokina_021973@postgrespro.ru", "phone": "+70215169863"}
0005434926132	05DCC7	6022 018490	SERGEY SIDOROV	{"email": "sidorov.s1965@postgrespro.ru", "phone": "+70125993008"}
0005434926133	C77703	6184 492480	NATALYA KOMAROVA	{"phone": "+70915779729"}
0005434926134	C77703	5368 181781	ALEKSANDRA KUZNECOVA	{"email": "a-kuznecova.1965@postgrespro.ru", "phone": "+70573930615"}
0005434926135	7E71C2	6647 211369	YULIYA VASILEVA	{"phone": "+70182280950"}
0005434926136	AAE462	1107 605584	VYACHESLAV VASILEV	{"phone": "+70663729655"}
0005434926137	979F74	5400 983151	ELENA SEMENOVA	{"phone": "+70732381086"}
0005434926138	B499A0	4880 907538	IVAN GUSEV	{"email": "gusevivan1981@postgrespro.ru", "phone": "+70910828939"}
0005434926139	B499A0	6404 251443	RUZALIYA ANTONOVA	{"email": "antonovar03091958@postgrespro.ru", "phone": "+70115140076"}
0005434926140	7D0CB2	0280 823216	IRINA KUZNECOVA	{"phone": "+70335573375"}
0005434926141	507FE4	5500 903777	SERGEY BORISOV	{"email": "sergey-borisov.1977@postgrespro.ru", "phone": "+70737387829"}
0005434926142	0455B7	6125 528719	GALINA ISAEVA	{"email": "isaevag.031985@postgrespro.ru", "phone": "+70975794390"}
0005434926143	19654B	1245 604985	ALEKSANDR ALEKSANDROV	{"email": "a-aleksandrov-08121976@postgrespro.ru", "phone": "+70587211409"}
0005434926144	013827	5450 795581	SERGEY SMIRNOV	{"email": "sergey.smirnov.091971@postgrespro.ru", "phone": "+70852633508"}
0005434926145	643AFD	0265 673719	VLADISLAV BARANOV	{"email": "baranov-v1980@postgrespro.ru", "phone": "+70548506456"}
0005434926146	133442	1851 566651	ALENA POTAPOVA	{"email": "potapova-a-1966@postgrespro.ru", "phone": "+70096480649"}
0005434926147	E39AEB	7929 531692	OLEG VOLKOV	{"phone": "+70502185693"}
0005434926148	CB0DED	6445 782103	LYUDMILA OVCHINNIKOVA	{"email": "l-ovchinnikova-1975@postgrespro.ru", "phone": "+70484567252"}
0005434926149	CB0DED	5744 191481	IRINA MAKAROVA	{"email": "makarova.irina.30041971@postgrespro.ru", "phone": "+70351608330"}
0005434926150	CE795B	6612 134968	ANTONINA BARANOVA	{"email": "baranovaa051971@postgrespro.ru", "phone": "+70497103858"}
0005434926151	CE795B	7392 569784	OLGA ZAYCEVA	{"email": "o-zayceva111968@postgrespro.ru", "phone": "+70992286958"}
0005434926152	5EEEC8	2827 911687	NINA GUSEVA	{"email": "nina_guseva_1969@postgrespro.ru", "phone": "+70547192590"}
0005434926153	EB4A30	6593 355676	MIKHAIL EGOROV	{"email": "egorov-mikhail.08071982@postgrespro.ru", "phone": "+70236925397"}
0005434926154	EB4A30	1500 397057	PETR YAKOVLEV	{"email": "p_yakovlev1982@postgrespro.ru", "phone": "+70116987754"}
0005434926155	520822	4130 430623	ALEKSEY VOLKOV	{"phone": "+70779674544"}
0005434926156	520822	2113 223192	NATALYA ZHURAVLEVA	{"phone": "+70499020750"}
0005434926157	520822	2505 690816	VLADIMIR ANDREEV	{"email": "v_andreev-011972@postgrespro.ru", "phone": "+70361868677"}
0005434926158	7A1E37	9698 443534	GALINA KOLESNIKOVA	{"email": "g_kolesnikova.1981@postgrespro.ru", "phone": "+70216557360"}
0005434926159	29478D	6983 339827	TAMARA BORISOVA	{"email": "borisova_t_11021979@postgrespro.ru", "phone": "+70730008218"}
0005434926160	02AE2E	8167 900895	VASILIY KUZNECOV	{"phone": "+70244172509"}
0005434926161	EDEB90	5628 659571	IVAN GORBUNOV	{"phone": "+70954664845"}
0005434926162	51E282	4437 197107	EVGENIY TIMOFEEV	{"email": "timofeev.e1971@postgrespro.ru", "phone": "+70212394675"}
0005434926163	51E282	6179 594089	VALENTINA KAZAKOVA	{"phone": "+70034080163"}
0005434926164	15F7D1	4306 271815	VALERIY TARASOV	{"phone": "+70235726126"}
0005434926165	1BD1F5	1720 207937	ANASTASIYA MARTYNOVA	{"email": "martynova_a.19061980@postgrespro.ru", "phone": "+70922057384"}
0005434926166	A6249F	5876 714102	SVETLANA MAKSIMOVA	{"phone": "+70918775139"}
0005434926167	A6249F	5754 481502	OLEG STEPANOV	{"phone": "+70275213993"}
0005434926168	0F3D64	9998 716526	NATALYA PETROVA	{"phone": "+70865257580"}
0005434926169	FF8A47	7190 265293	ANDREY NIKOLAEV	{"email": "anikolaev_18021974@postgrespro.ru", "phone": "+70318493562"}
0005434926170	2339B9	9465 082656	YANA FROLOVA	{"email": "frolova_y1974@postgrespro.ru", "phone": "+70038830409"}
0005434926171	88D67D	0098 294111	YURIY KOROLEV	{"phone": "+70577795148"}
0005434926172	88D67D	6387 699569	ANDREY TARASOV	{"email": "tarasov.a-12021964@postgrespro.ru", "phone": "+70350866382"}
0005434926173	1C4E8B	0365 742225	DENIS KONOVALOV	{"email": "konovalovd.03061956@postgrespro.ru", "phone": "+70738342662"}
0005434926174	FC80FB	2571 226981	DENIS KUZNECOV	{"email": "kuznecov-denis21031967@postgrespro.ru", "phone": "+70403317407"}
0005434926175	3BB907	4739 649304	ARKADIY ANDREEV	{"email": "aandreev_1967@postgrespro.ru", "phone": "+70520702298"}
0005434926176	04761B	0469 625082	GALINA NIKOLAEVA	{"email": "galina-nikolaeva_09051971@postgrespro.ru", "phone": "+70568898172"}
0005434926177	D6634C	3258 643498	NINA NIKITINA	{"email": "n.nikitina_07121979@postgrespro.ru", "phone": "+70499420793"}
0005434926178	C2A838	8552 429785	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.18041970@postgrespro.ru", "phone": "+70384895080"}
0005434926179	944570	6710 891306	NATALYA ERMAKOVA	{"email": "ermakova-natalya_1973@postgrespro.ru", "phone": "+70040984299"}
0005434926180	1B8693	6086 857924	LYUDMILA NESTEROVA	{"email": "lyudmila_nesterova.091972@postgrespro.ru", "phone": "+70744100591"}
0005434926181	93970E	9872 932224	ANTONINA MAKAROVA	{"phone": "+70262688597"}
0005434926182	2CB8D5	0435 363776	SERGEY GAVRILOV	{"email": "sgavrilov_16091965@postgrespro.ru", "phone": "+70104490924"}
0005434926183	E59C8E	8005 936486	ARTEM ROMANOV	{"email": "artem_romanov_04071972@postgrespro.ru", "phone": "+70044806240"}
0005434926184	E59C8E	4883 839780	TATYANA FILATOVA	{"phone": "+70839794826"}
0005434926185	1991D0	7077 875597	LYUDMILA SOLOVEVA	{"email": "lyudmilasoloveva_06091965@postgrespro.ru", "phone": "+70941094453"}
0005434926186	B5F966	4016 697345	DENIS TARASOV	{"email": "tarasov-denis.23101978@postgrespro.ru", "phone": "+70319412842"}
0005434926187	05B531	2798 576975	LEONID ISAEV	{"email": "leonidisaev_24071976@postgrespro.ru", "phone": "+70860358659"}
0005434926188	A8DD4D	2463 899040	EKATERINA GERASIMOVA	{"phone": "+70497885179"}
0005434926189	A8DD4D	0497 018906	TATYANA MAKSIMOVA	{"email": "t-maksimova.1968@postgrespro.ru", "phone": "+70390388463"}
0005434926190	F03756	6617 392702	ELENA ALEKSEEVA	{"phone": "+70286071040"}
0005434926191	33B1C3	7707 355801	ANTONINA KONOVALOVA	{"email": "a_konovalova-14041976@postgrespro.ru", "phone": "+70316541498"}
0005434926192	33B1C3	7549 250293	ANDREY MELNIKOV	{"phone": "+70641699570"}
0005434926193	0C9D6E	5684 348481	NAIL KISELEV	{"email": "nail_kiselev_1978@postgrespro.ru", "phone": "+70018268690"}
0005434926194	60A35F	3077 800721	NATALIYA SMIRNOVA	{"email": "nataliya_smirnova.08061989@postgrespro.ru", "phone": "+70328908872"}
0005434926195	60A35F	4682 609275	OLEG BONDARENKO	{"phone": "+70568972395"}
0005434926196	65F61D	8227 774636	ARTUR BORISOV	{"phone": "+70022549214"}
0005434926197	2C68EC	8694 642924	DARYA MELNIKOVA	{"phone": "+70930321058"}
0005434926198	2C68EC	6991 866074	VALERIY SERGEEV	{"email": "v_sergeev.16051974@postgrespro.ru", "phone": "+70562221805"}
0005434926199	08A505	3006 014327	SVETLANA RYABOVA	{"email": "ryabovasvetlana04021977@postgrespro.ru", "phone": "+70450757691"}
0005434926200	08A505	4219 349644	ANNA SIDOROVA	{"email": "sidorovaa.1963@postgrespro.ru", "phone": "+70562231232"}
0005434926201	49A52F	6193 313502	DIANA VLASOVA	{"phone": "+70420955345"}
0005434926202	49A52F	6573 346359	ARTUR VLASOV	{"email": "vlasov_a-17041979@postgrespro.ru", "phone": "+70794123844"}
0005434926203	AF1C0B	9282 756649	LIDIYA ZAKHAROVA	{"email": "zakharova_l_091956@postgrespro.ru", "phone": "+70477258946"}
0005434926204	CF2A2F	3149 478682	TATYANA KRASNOVA	{"phone": "+70719392997"}
0005434926205	5FF19B	8989 489031	SERGEY MIKHAYLOV	{"email": "s-mikhaylov051980@postgrespro.ru", "phone": "+70643080882"}
0005434926206	753912	6705 156021	YULIYA MAKAROVA	{"phone": "+70799399988"}
0005434926207	D28376	5462 824674	ANDREY POPOV	{"email": "popovandrey.1977@postgrespro.ru", "phone": "+70511723769"}
0005434926208	16CA54	2898 059957	NADEZHDA NOVIKOVA	{"email": "novikova-n.1961@postgrespro.ru", "phone": "+70903792860"}
0005434926209	16CA54	8490 099117	KIRILL FEDOTOV	{"email": "fedotov-k.1983@postgrespro.ru", "phone": "+70026806932"}
0005434926210	095811	4566 906633	VLADISLAV ALEKSANDROV	{"phone": "+70610777847"}
0005434926211	095811	6243 191018	OLGA POLYAKOVA	{"phone": "+70330886272"}
0005434926212	DD684C	1131 788174	VIKTOR KULIKOV	{"email": "kulikov.viktor-1976@postgrespro.ru", "phone": "+70619495458"}
0005434926213	DD684C	2073 303565	SVETLANA PETROVA	{"email": "petrovas_111963@postgrespro.ru", "phone": "+70234486436"}
0005434926214	1185B8	0442 480140	ANNA AKIMOVA	{"email": "a.akimova27061976@postgrespro.ru", "phone": "+70361432015"}
0005434926215	1185B8	1747 359699	ELENA FROLOVA	{"email": "e_frolova1952@postgrespro.ru", "phone": "+70151465745"}
0005434926216	5DE604	1655 367871	TATYANA KONDRATEVA	{"email": "t_kondrateva_14111973@postgrespro.ru", "phone": "+70323353715"}
0005434926217	B9F454	6863 187653	MIKHAIL ILIN	{"phone": "+70736274675"}
0005434926218	B9F454	1647 510726	KLIM SAVELEV	{"email": "savelevklim11081991@postgrespro.ru", "phone": "+70482309587"}
0005434926219	792D39	0981 926481	ANDREY KUZNECOV	{"email": "andreykuznecov_091981@postgrespro.ru", "phone": "+70333119601"}
0005434926220	B13C51	7140 489599	EKATERINA DAVYDOVA	{"email": "ekaterina-davydova1971@postgrespro.ru", "phone": "+70329800522"}
0005434926221	B13C51	9620 323352	MARIYA MIKHAYLOVA	{"email": "mikhaylovamariya-061976@postgrespro.ru", "phone": "+70229276460"}
0005434926222	B573B5	0929 537294	EKATERINA POTAPOVA	{"email": "e-potapova_1960@postgrespro.ru", "phone": "+70828232180"}
0005434926223	B573B5	2058 583238	IRINA FILIPPOVA	{"email": "irina-filippova-1972@postgrespro.ru", "phone": "+70064006807"}
0005434926224	9F15ED	5717 889887	LYUBOV ANDREEVA	{"email": "l-andreeva_111983@postgrespro.ru", "phone": "+70589304432"}
0005434926225	25841B	4170 204714	SERGEY MARTYNOV	{"phone": "+70999319837"}
0005434926226	EBF000	9035 194140	VERONIKA NIKITINA	{"email": "nikitina_veronika-121979@postgrespro.ru", "phone": "+70913311028"}
0005434926227	B784EF	7828 117108	IRINA MAKSIMOVA	{"phone": "+70573179451"}
0005434926228	B784EF	5904 100251	ANTONINA GAVRILOVA	{"phone": "+70631527941"}
0005434926229	5767C6	9954 847313	VLADISLAV KISELEV	{"phone": "+70238383468"}
0005434926230	5767C6	1168 112653	SERGEY EGOROV	{"email": "sergey.egorov081973@postgrespro.ru", "phone": "+70324119124"}
0005434926231	9678E2	1705 072286	LYUDMILA TIMOFEEVA	{"phone": "+70518216080"}
0005434926232	BD6DEA	8829 094433	ELENA YUDINA	{"phone": "+70297977907"}
0005434926233	BD6DEA	9314 280110	OLGA YAKOVLEVA	{"email": "olga.yakovleva26061971@postgrespro.ru", "phone": "+70154688718"}
0005434926234	DDB456	0677 614256	NATALYA ROMANOVA	{"email": "n.romanova-061972@postgrespro.ru", "phone": "+70456318920"}
0005434926235	7354A6	5851 659882	SVETLANA POLYAKOVA	{"phone": "+70728580475"}
0005434926236	7354A6	6259 765374	VLADIMIR ZAKHAROV	{"email": "vzakharov04121966@postgrespro.ru", "phone": "+70079152227"}
0005434926237	7354A6	3078 354113	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin.101973@postgrespro.ru", "phone": "+70231145493"}
0005434926238	66C59C	6893 418470	ALEKSANDR KOZLOV	{"phone": "+70799967498"}
0005434926239	C7151F	8391 212544	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila20011972@postgrespro.ru", "phone": "+70614884960"}
0005434926240	C7151F	7408 360124	TATYANA KUZNECOVA	{"phone": "+70367677157"}
0005434926241	E4A7BA	2605 502621	SERGEY VOLKOV	{"phone": "+70563100260"}
0005434926242	E4A7BA	0921 339939	NINA ORLOVA	{"phone": "+70655558721"}
0005434926243	E4A7BA	0915 243435	SERGEY ILIN	{"email": "ilin.sergey-20111985@postgrespro.ru", "phone": "+70501993317"}
0005434926244	03F58D	4729 602234	NIKOLAY VLASOV	{"phone": "+70464088805"}
0005434926245	FF7A4F	9261 570062	OLGA SOROKINA	{"phone": "+70012521483"}
0005434926246	217125	7188 528598	MARINA GAVRILOVA	{"email": "mgavrilova081976@postgrespro.ru", "phone": "+70848903114"}
0005434926247	44177A	8177 428448	SERGEY KUZNECOV	{"phone": "+70833209629"}
0005434926248	CAA65C	9461 295550	PETR NIKITIN	{"phone": "+70974453926"}
0005434926249	CAA65C	4771 336304	VLADIMIR IVANOV	{"phone": "+70743776574"}
0005434926250	7855B5	5345 057524	ELINA LEBEDEVA	{"phone": "+70238611412"}
0005434926251	8E3D64	7307 194939	VLADIMIR GORBUNOV	{"phone": "+70247574913"}
0005434926252	DCC4E5	9677 261686	NIKITA SIDOROV	{"email": "n.sidorov1971@postgrespro.ru", "phone": "+70922955727"}
0005434926253	E2514B	0189 234859	NIKOLAY GORBUNOV	{"phone": "+70034166171"}
0005434926254	E2514B	2924 092202	SERGEY ORLOV	{"phone": "+70574784169"}
0005434926255	0C5AD7	9136 154084	ANTON SCHERBAKOV	{"phone": "+70149841557"}
0005434926256	0C5AD7	2115 392947	VALENTIN ISAEV	{"email": "isaevv-07091970@postgrespro.ru", "phone": "+70125805674"}
0005434926257	707A6B	8159 950481	EVGENIY POPOV	{"email": "popov_e-02101969@postgrespro.ru", "phone": "+70795143521"}
0005434926258	707A6B	4416 399318	EKATERINA VASILEVA	{"email": "vasileva-ekaterina_11101974@postgrespro.ru", "phone": "+70621828214"}
0005434926259	707A6B	8094 418402	EVGENIY ZAKHAROV	{"email": "zakharov-evgeniy_22031964@postgrespro.ru", "phone": "+70184094309"}
0005434926260	029C8F	3235 438575	IRINA LUKYANOVA	{"email": "lukyanovairina_051978@postgrespro.ru", "phone": "+70992682368"}
0005434926261	83BEF8	7662 447063	EVGENIY KAZAKOV	{"phone": "+70637141668"}
0005434926262	5C04AD	4286 080479	OLGA KRASNOVA	{"email": "krasnova.o_031969@postgrespro.ru", "phone": "+70810092172"}
0005434926263	28AEA1	1222 149782	ANDREY CHERNOV	{"phone": "+70439130721"}
0005434926264	28AEA1	5213 413170	VIKTOR AFANASEV	{"phone": "+70247226119"}
0005434926265	28AEA1	0539 558241	VALERIY KRASNOV	{"phone": "+70932488918"}
0005434926266	7D5BC5	7215 439117	KIRILL ROMANOV	{"phone": "+70752574901"}
0005434926267	6F910E	2466 080562	NIKOLAY STEPANOV	{"phone": "+70699070246"}
0005434926268	35B993	9594 635866	VALENTINA MATVEEVA	{"phone": "+70490284505"}
0005434926269	9EEB7F	5116 157651	GEORGIY MATVEEV	{"email": "georgiy_matveev1958@postgrespro.ru", "phone": "+70930966728"}
0005434926270	F0B754	3777 321304	ANTON STEPANOV	{"phone": "+70014335110"}
0005434926271	FA1442	7275 705957	PAVEL DAVYDOV	{"phone": "+70779162468"}
0005434926272	EDC8CF	1984 302557	MIKHAIL IVANOV	{"email": "ivanovmikhail.101967@postgrespro.ru", "phone": "+70704988073"}
0005434926273	19A595	3633 975235	TATYANA EFIMOVA	{"email": "tatyana_efimova_1965@postgrespro.ru", "phone": "+70595550045"}
0005434926274	19A595	4763 760330	NINA NIKOLAEVA	{"phone": "+70302109918"}
0005434926275	E0783A	4182 925584	NINA KRASNOVA	{"phone": "+70847787069"}
0005434926276	FD7FCA	8384 665790	VERA CHERNOVA	{"phone": "+70053426481"}
0005434926277	F6A51A	0724 786160	NIKOLAY KULIKOV	{"email": "nkulikov1986@postgrespro.ru", "phone": "+70911431674"}
0005434926278	E14ACA	5807 580436	GENNADIY GUSEV	{"phone": "+70015756302"}
0005434926279	E624F2	6186 696882	TATYANA ALEKSEEVA	{"phone": "+70994358297"}
0005434926280	E624F2	3395 150869	OLGA FILIPPOVA	{"email": "ofilippova_06041980@postgrespro.ru", "phone": "+70359153570"}
0005434926281	E82ECE	3646 499303	EVGENIYA GORBUNOVA	{"phone": "+70884862480"}
0005434926282	6D569B	0519 187645	ELENA YUDINA	{"email": "e_yudina_25011972@postgrespro.ru", "phone": "+70781489369"}
0005434926283	105F1E	9049 917540	NIKOLAY OSIPOV	{"email": "n-osipov-09051965@postgrespro.ru", "phone": "+70452102963"}
0005434926284	105F1E	5439 520425	ANNA GUSEVA	{"phone": "+70463244128"}
0005434926285	40926F	3628 311155	NINA VASILEVA	{"email": "n_vasileva-16071976@postgrespro.ru", "phone": "+70741324448"}
0005434926286	40926F	1841 204339	TAMARA ROMANOVA	{"email": "romanova.tamara.061963@postgrespro.ru", "phone": "+70786425698"}
0005434926287	40D5E4	2579 457850	ALEVTINA FILATOVA	{"phone": "+70098141373"}
0005434926288	3F698E	7173 594446	ANDREY DENISOV	{"email": "a-denisov_1978@postgrespro.ru", "phone": "+70900507871"}
0005434926289	969530	1268 273043	ELENA MASLOVA	{"phone": "+70141266166"}
0005434926290	969530	5223 053967	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.1983@postgrespro.ru", "phone": "+70618078501"}
0005434926291	5E2079	0664 770733	MIKHAIL KOROLEV	{"email": "m.korolev03091976@postgrespro.ru", "phone": "+70719216544"}
0005434926292	68A035	1196 518590	OLGA ARKHIPOVA	{"phone": "+70803814874"}
0005434926293	68A035	4049 268573	SERGEY KUZMIN	{"phone": "+70349717526"}
0005434926294	89895C	8169 002036	NIKOLAY POPOV	{"phone": "+70557400067"}
0005434926295	09E002	0783 890954	RINAT FOMIN	{"email": "r.fomin.1970@postgrespro.ru", "phone": "+70060121772"}
0005434926296	E6CF46	4469 430435	RAISA KONOVALOVA	{"email": "konovalovaraisa_26081967@postgrespro.ru", "phone": "+70754274456"}
0005434926297	D74E37	9217 319334	ZOYA PETROVA	{"phone": "+70241712809"}
0005434926298	D74E37	4106 415826	YURIY KISELEV	{"phone": "+70006413248"}
0005434926299	D74E37	5803 151639	LARISA SOROKINA	{"email": "sorokinal_101981@postgrespro.ru", "phone": "+70335900879"}
0005434926300	2FE6BA	5998 901877	MIKHAIL MATVEEV	{"email": "mikhail-matveev_24121967@postgrespro.ru", "phone": "+70047461038"}
0005434926301	2FE6BA	8286 664138	TATYANA SOLOVEVA	{"phone": "+70083115863"}
0005434926302	2FE6BA	7105 958329	VIKTORIYA PAVLOVA	{"phone": "+70977399403"}
0005434926303	444A67	8079 035252	YURIY POPOV	{"email": "popov_y041972@postgrespro.ru", "phone": "+70163028829"}
0005434926304	444A67	5942 660493	MARIYA KOROLEVA	{"email": "mariya_koroleva-1957@postgrespro.ru", "phone": "+70491952345"}
0005434926305	AA8177	8384 308447	VASILIY ALEKSEEV	{"phone": "+70504365827"}
0005434926306	ED9D4A	7532 960444	ELENA RYABOVA	{"phone": "+70936699942"}
0005434926307	2B85C9	7509 021263	SVETLANA POTAPOVA	{"phone": "+70871557848"}
0005434926308	2B85C9	0666 729871	TATYANA FEDOROVA	{"phone": "+70894460233"}
0005434926309	2B85C9	6623 998578	VALENTINA IVANOVA	{"phone": "+70246859026"}
0005434926310	4FE08B	9832 961867	ANASTASIYA EGOROVA	{"phone": "+70212725038"}
0005434926311	EC9A61	7012 348500	NIKOLAY KONOVALOV	{"email": "konovalov_n-051960@postgrespro.ru", "phone": "+70285410066"}
0005434926312	EC9A61	0072 071393	MARYAM MAKAROVA	{"phone": "+70979530712"}
0005434926313	EC9A61	5538 570058	SERGEY VOROBEV	{"email": "vorobev.s_1975@postgrespro.ru", "phone": "+70911116865"}
0005434926314	EBAF40	5061 054855	TATYANA ALEKSEEVA	{"phone": "+70722961184"}
0005434926315	EBAF40	3815 245688	ANASTASIYA ANISIMOVA	{"phone": "+70622394503"}
0005434926316	7ACD64	5859 232626	KSENIYA MOROZOVA	{"email": "morozova_k.091971@postgrespro.ru", "phone": "+70939884697"}
0005434926317	7ACD64	6846 625771	MARIYA SERGEEVA	{"phone": "+70359815675"}
0005434926318	DA7350	6566 852187	ANTON SOKOLOV	{"email": "sokolov.a-08031974@postgrespro.ru", "phone": "+70687911601"}
0005434926319	DA7350	2385 605566	ALEKSANDR FROLOV	{"email": "a_frolov011973@postgrespro.ru", "phone": "+70560001658"}
0005434926320	F959BA	3204 984130	ANDREY ZAYCEV	{"phone": "+70322610401"}
0005434926321	9335D6	1140 731835	DENIS KAZAKOV	{"phone": "+70917080205"}
0005434926322	9335D6	8646 780450	ALEKSANDR POPOV	{"email": "popov-aleksandr-06021960@postgrespro.ru", "phone": "+70218844583"}
0005434926323	C56D30	9738 580470	NIKOLAY NIKITIN	{"phone": "+70689691606"}
0005434926324	C56D30	5202 188206	MIKHAIL AFANASEV	{"phone": "+70551898296"}
0005434926325	C56D30	9158 356081	TAMARA NESTEROVA	{"email": "tamara-nesterova-101980@postgrespro.ru", "phone": "+70527400977"}
0005434926326	DB8E82	9795 777600	MARIYA DENISOVA	{"phone": "+70555076598"}
0005434926327	D4D559	9397 748276	NIKOLAY ANTONOV	{"email": "nikolay-antonov25071978@postgrespro.ru", "phone": "+70008398175"}
0005434926328	E175E6	3421 415650	DENIS SEMENOV	{"email": "semenov.d071964@postgrespro.ru", "phone": "+70873255257"}
0005434926329	2D5815	4324 420843	IGOR KUZMIN	{"phone": "+70662646936"}
0005434926330	15DD2D	4452 733056	DMITRIY FOMIN	{"phone": "+70972864010"}
0005434926331	6E457E	8402 537126	NIKOLAY KUZNECOV	{"email": "n-kuznecov.05041971@postgrespro.ru", "phone": "+70973082855"}
0005434926332	D248E6	8911 506138	DMITRIY ABRAMOV	{"email": "abramov_dmitriy24111969@postgrespro.ru", "phone": "+70321703243"}
0005434926333	9D134F	4260 944948	ELENA MAKAROVA	{"email": "makarova_e.041974@postgrespro.ru", "phone": "+70687150850"}
0005434926334	79D75F	4618 720513	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov-28011980@postgrespro.ru", "phone": "+70823019610"}
0005434926335	79D75F	0173 468693	OLGA GERASIMOVA	{"phone": "+70045361243"}
0005434926336	00F356	6874 438912	VERA IVANOVA	{"phone": "+70873584430"}
0005434926337	00F356	5218 124086	MIKHAIL MOISEEV	{"phone": "+70882066808"}
0005434926338	9ECC61	7890 560499	DENIS KULIKOV	{"phone": "+70072689475"}
0005434926339	4EDCCC	7967 507508	NIKOLAY PAVLOV	{"email": "pavlov-nikolay-1976@postgrespro.ru", "phone": "+70230062607"}
0005434926340	441175	0043 105394	ALEKSANDR NIKOLAEV	{"email": "nikolaev.aleksandr.1976@postgrespro.ru", "phone": "+70785309128"}
0005434926341	3A7E2B	2700 773365	ELENA ALEKSANDROVA	{"phone": "+70971365628"}
0005434926342	A975F4	0960 030773	RAVILYA ORLOVA	{"email": "rorlova-04091968@postgrespro.ru", "phone": "+70523069089"}
0005434926343	600DE7	0050 002958	DMITRIY OSIPOV	{"email": "dosipov-11031976@postgrespro.ru", "phone": "+70847036301"}
0005434926344	2FD9A9	7688 152517	VIKTOR BELOV	{"email": "belov-v-061978@postgrespro.ru", "phone": "+70050455016"}
0005434926345	2FD9A9	9733 204412	NINA ZHURAVLEVA	{"email": "zhuravleva.n.21121963@postgrespro.ru", "phone": "+70664555474"}
0005434926346	364469	8907 841621	ROMAN IVANOV	{"phone": "+70951826877"}
0005434926347	8E5476	4726 737409	ALEKSEY PAVLOV	{"email": "alekseypavlov.1974@postgrespro.ru", "phone": "+70289680436"}
0005434926348	368D2B	2983 310982	STANISLAV TIKHONOV	{"phone": "+70120942547"}
0005434926349	8B9BD9	1358 584261	ZLATA KULIKOVA	{"phone": "+70778276599"}
0005434926350	D2FC42	8712 786318	VIKTOR ZAYCEV	{"phone": "+70656103585"}
0005434926351	91C0B2	8125 400324	IGOR NAZAROV	{"phone": "+70376159192"}
0005434926352	3277C1	1844 304669	ELIZAVETA FOMINA	{"email": "e-fomina1972@postgrespro.ru", "phone": "+70252308877"}
0005434926353	C78A40	9107 675547	NINA SOKOLOVA	{"email": "sokolova.n.23121988@postgrespro.ru", "phone": "+70221656014"}
0005434926354	C78A40	2656 447522	ANNA KUZNECOVA	{"email": "kuznecova.anna_071973@postgrespro.ru", "phone": "+70486943945"}
0005434926355	3720A0	4859 984990	OLGA GAVRILOVA	{"email": "gavrilova.olga1972@postgrespro.ru", "phone": "+70070687818"}
0005434926356	DD53AC	4923 023021	ALEKSEY MOISEEV	{"phone": "+70359861578"}
0005434926357	968604	5635 996822	NATALYA MIRONOVA	{"email": "natalyamironova_021986@postgrespro.ru", "phone": "+70921358066"}
0005434926358	968604	5979 890662	NATALYA VASILEVA	{"email": "natalya-vasileva.30011981@postgrespro.ru", "phone": "+70844304716"}
0005434926359	95B6BD	4045 426153	TAMARA ZHUKOVA	{"email": "tamara.zhukova.1972@postgrespro.ru", "phone": "+70862050425"}
0005434926360	272BE5	2126 319889	ANNA FEDOROVA	{"email": "anna.fedorova_1967@postgrespro.ru", "phone": "+70932904979"}
0005434926361	272BE5	8478 313716	VLADIMIR ZAKHAROV	{"phone": "+70339670941"}
0005434926362	DE0BF6	5321 073324	SERGEY SOROKIN	{"phone": "+70029088965"}
0005434926363	DE0BF6	0071 086597	VALERIY ILIN	{"email": "valeriy-ilin-041981@postgrespro.ru", "phone": "+70800681781"}
0005434926364	9B196A	6593 473296	PAVEL ZAKHAROV	{"phone": "+70971159085"}
0005434926365	8FEDCB	5394 556672	TATYANA KOLESNIKOVA	{"email": "t_kolesnikova.051971@postgrespro.ru", "phone": "+70226938018"}
0005434926366	9DFD3C	2146 523698	NIKOLAY POPOV	{"email": "npopov_031971@postgrespro.ru", "phone": "+70900217160"}
0005434926367	CDD0E8	9502 679714	VLADIMIR KONOVALOV	{"phone": "+70140126704"}
0005434926368	FCFCCB	5686 345977	ZULFIYA POTAPOVA	{"phone": "+70752618988"}
0005434926369	2E8941	2657 664000	ALEKSEY SEMENOV	{"phone": "+70237384892"}
0005434926370	69787A	0326 918477	NIKITA MARTYNOV	{"phone": "+70963487148"}
0005434926371	FED6FC	6591 995777	VALENTINA KULIKOVA	{"email": "kulikova.valentina1979@postgrespro.ru", "phone": "+70424895967"}
0005434926372	15ADD2	6248 062957	EGOR DMITRIEV	{"phone": "+70353528508"}
0005434926373	41805E	3156 254243	NIKOLAY KUZNECOV	{"email": "nikolaykuznecov.12031985@postgrespro.ru", "phone": "+70932794178"}
0005434926374	2FE5BD	3932 543759	MARINA ISAEVA	{"phone": "+70152355923"}
0005434926375	D65375	4909 630577	VYACHESLAV PAVLOV	{"email": "v_pavlov.121967@postgrespro.ru", "phone": "+70682174520"}
0005434926376	78BAD3	0508 392484	NATALYA FEDOROVA	{"email": "n.fedorova.021964@postgrespro.ru", "phone": "+70969223169"}
0005434926377	EBCE5D	9898 561996	SVETLANA VOLKOVA	{"email": "svetlana_volkova-101972@postgrespro.ru", "phone": "+70074008241"}
0005434926378	EBCE5D	4116 572277	OLEG BARANOV	{"email": "o-baranov04061974@postgrespro.ru", "phone": "+70025861593"}
0005434926379	45D656	2692 059442	LYUDMILA VLASOVA	{"email": "vlasova.lyudmila-1982@postgrespro.ru", "phone": "+70508842094"}
0005434926380	42DAF2	0710 468835	ALFIYA KUZNECOVA	{"phone": "+70801171443"}
0005434926381	BA9DCB	9293 667942	GALIYA KONOVALOVA	{"email": "konovalovagaliya_1974@postgrespro.ru", "phone": "+70373920866"}
0005434926382	BA9DCB	6678 411443	RAISA PAVLOVA	{"email": "pavlovar07081969@postgrespro.ru", "phone": "+70291352348"}
0005434926383	BA9DCB	6447 765602	VERA EGOROVA	{"email": "v.egorova_16121963@postgrespro.ru", "phone": "+70821947374"}
0005434926384	35B3AC	6784 178290	SERGEY ALEKSEEV	{"phone": "+70511376446"}
0005434926385	35B3AC	7411 161890	VALENTINA ZAKHAROVA	{"email": "zakharova-valentina-021975@postgrespro.ru", "phone": "+70006643983"}
0005434926386	893DFB	6975 929677	ALBERT SERGEEV	{"email": "albert_sergeev1977@postgrespro.ru", "phone": "+70255504786"}
0005434926387	594C54	6174 357875	GALINA NOVIKOVA	{"email": "gnovikova-1963@postgrespro.ru", "phone": "+70191965730"}
0005434926388	E3245B	7183 759711	ANTON ISAEV	{"phone": "+70064096555"}
0005434926389	E3245B	9353 961397	EKATERINA OSIPOVA	{"phone": "+70723739104"}
0005434926390	E3245B	2912 970526	DMITRIY NOVIKOV	{"phone": "+70186990713"}
0005434926391	7F25B5	2946 056741	MARIYA BELOVA	{"phone": "+70713052239"}
0005434926392	7F25B5	8971 615194	NATALYA KUZNECOVA	{"email": "kuznecova-n.061971@postgrespro.ru", "phone": "+70617065884"}
0005434926393	99EDE8	2051 574495	VERA FROLOVA	{"phone": "+70267127096"}
0005434926394	F24119	5590 600305	BOGDAN TIKHONOV	{"phone": "+70353357997"}
0005434926395	59A088	6424 531724	ANATOLIY ZAKHAROV	{"phone": "+70084500106"}
0005434926396	59A088	0193 840069	VIKTOR NAZAROV	{"phone": "+70547262915"}
0005434926397	004E04	4023 943964	NIKOLAY EGOROV	{"email": "nikolayegorov_1981@postgrespro.ru", "phone": "+70832189751"}
0005434926398	004E04	3336 733792	MARIYA TIMOFEEVA	{"phone": "+70903714722"}
0005434926399	004E04	5592 586485	VLADIMIR BONDARENKO	{"email": "v-bondarenko_03031980@postgrespro.ru", "phone": "+70081092391"}
0005434926400	1D498F	9304 337138	NATALYA ZAKHAROVA	{"phone": "+70963631546"}
0005434926401	A551B4	9961 365543	NIKITA SAVELEV	{"email": "nsavelev.1977@postgrespro.ru", "phone": "+70258288292"}
0005434926402	A551B4	3816 735289	IVAN ANTONOV	{"email": "antonovi_1965@postgrespro.ru", "phone": "+70372687609"}
0005434926403	72A829	5557 951251	ELENA MARTYNOVA	{"phone": "+70038992214"}
0005434926404	849682	6674 306559	VLADIMIR DAVYDOV	{"email": "vladimir-davydov_081970@postgrespro.ru", "phone": "+70748162543"}
0005434926405	542540	0853 301728	SARIYA NAUMOVA	{"phone": "+70097073121"}
0005434926406	26D602	7419 393427	SERGEY GORBUNOV	{"phone": "+70513118020"}
0005434926407	26D602	3793 519358	EGOR BORISOV	{"email": "borisovegor.10111981@postgrespro.ru", "phone": "+70335346053"}
0005434926408	41EC66	7232 169772	LYUBOV MOISEEVA	{"phone": "+70856537883"}
0005434926409	9970B0	2866 168442	DENIS SHEVCHENKO	{"phone": "+70296940231"}
0005434926410	9A2AC8	7990 439621	TATYANA KUZMINA	{"email": "t-kuzmina_1983@postgrespro.ru", "phone": "+70687020652"}
0005434926411	9A2AC8	7997 884915	KRISTINA DENISOVA	{"phone": "+70746538634"}
0005434926412	4CF1EB	4484 647547	LIDIYA POLYAKOVA	{"phone": "+70626576439"}
0005434926413	547244	2419 156193	TATYANA VOLKOVA	{"email": "volkova.tatyana.101963@postgrespro.ru", "phone": "+70064558604"}
0005434926414	547244	8589 769003	ALEKSANDR KUZMIN	{"phone": "+70644354722"}
0005434926415	547244	5433 153073	ANZHELA ZAYCEVA	{"phone": "+70373767294"}
0005434926416	C67C57	8990 824007	VIKTOR SEMENOV	{"email": "viktor-semenov_26081968@postgrespro.ru", "phone": "+70025398757"}
0005434926417	D95B7A	4597 363410	NAILYA GORBUNOVA	{"email": "gorbunovanailya.111970@postgrespro.ru", "phone": "+70770862664"}
0005434926418	E793EA	9162 724839	TATYANA KONOVALOVA	{"email": "konovalovatatyana_1973@postgrespro.ru", "phone": "+70829946239"}
0005434926419	66A416	8151 743394	DANIL ANDREEV	{"email": "andreevdanil.09021966@postgrespro.ru", "phone": "+70288273792"}
0005434926420	66A416	1885 023673	DAVID FEDOROV	{"email": "d.fedorov_18101973@postgrespro.ru", "phone": "+70691791508"}
0005434926421	51074C	6144 357970	VLADIMIR VOLKOV	{"phone": "+70498897605"}
0005434926422	51074C	2344 486566	ANATOLIY GERASIMOV	{"email": "gerasimov_a_06071974@postgrespro.ru", "phone": "+70862772329"}
0005434926423	718098	5864 693605	VIKTOR SHEVCHENKO	{"phone": "+70770940214"}
0005434926424	97FFD5	6447 634931	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr-011973@postgrespro.ru", "phone": "+70664415561"}
0005434926425	97FFD5	3917 378858	ALEKSANDR MAKSIMOV	{"email": "maksimov_aleksandr.051968@postgrespro.ru", "phone": "+70797378402"}
0005434926426	97FFD5	8567 010269	OLGA KOROLEVA	{"phone": "+70886708946"}
0005434926427	C20000	9936 025193	EKATERINA MARTYNOVA	{"email": "martynova.e.051977@postgrespro.ru", "phone": "+70378679542"}
0005434926428	21DDFE	7380 530147	DMITRIY MARTYNOV	{"phone": "+70488007628"}
0005434926429	D31DDF	5318 302761	TATYANA KRASNOVA	{"email": "t_krasnova1965@postgrespro.ru", "phone": "+70047948487"}
0005434926430	11C905	6495 601850	ANDREY KUZMIN	{"phone": "+70725672159"}
0005434926431	8D6194	0360 906041	ANATOLIY FEDOROV	{"email": "fedorov-a_1955@postgrespro.ru", "phone": "+70614987127"}
0005434926432	E8A07A	4377 170696	ALEKSEY DENISOV	{"email": "a-denisov.02041969@postgrespro.ru", "phone": "+70647051803"}
0005434926433	E8A07A	3415 232879	RASHID VASILEV	{"email": "vasilev_rashid031973@postgrespro.ru", "phone": "+70196388949"}
0005434926434	E8A07A	9969 284309	SVETLANA ORLOVA	{"phone": "+70843401435"}
0005434926435	6772C2	6269 476742	MARGARITA MARTYNOVA	{"email": "martynovam-30061963@postgrespro.ru", "phone": "+70891382082"}
0005434926436	6772C2	2275 715617	SERGEY STEPANOV	{"phone": "+70306010576"}
0005434926437	D9C447	2571 549025	VIKTOR VASILEV	{"email": "vasilevviktor.1978@postgrespro.ru", "phone": "+70147846281"}
0005434926438	A65401	9564 107405	ALEKSANDR KAZAKOV	{"phone": "+70503410388"}
0005434926439	B084C2	6864 718343	SERGEY ZHURAVLEV	{"email": "s-zhuravlev_031979@postgrespro.ru", "phone": "+70083476962"}
0005434926440	35C0E9	8448 377333	ANDREY KRASNOV	{"email": "krasnovandrey-1975@postgrespro.ru", "phone": "+70787626410"}
0005434926441	35C0E9	9299 206609	ARINA ZAYCEVA	{"email": "zayceva_arina.21021974@postgrespro.ru", "phone": "+70521551420"}
0005434926442	0120F7	3153 912841	TAGIR NOVIKOV	{"phone": "+70067924008"}
0005434926443	0120F7	9523 682390	KLARA KRASNOVA	{"email": "k-krasnova1972@postgrespro.ru", "phone": "+70525987153"}
0005434926444	4F651D	2596 249058	VALENTINA MARTYNOVA	{"phone": "+70453004029"}
0005434926445	9A3954	5046 313521	PAVEL MELNIKOV	{"email": "melnikovpavel-1972@postgrespro.ru", "phone": "+70855447035"}
0005434926446	9A3954	8241 826293	NATALYA NAZAROVA	{"email": "nazarova-natalya-17121978@postgrespro.ru", "phone": "+70562753986"}
0005434926447	9A3954	1407 546712	ALEKSANDR MAKSIMOV	{"phone": "+70388529218"}
0005434926448	2F897B	0223 111830	VLADIMIR GAVRILOV	{"email": "vgavrilov081976@postgrespro.ru", "phone": "+70731160093"}
0005434926449	0824A9	8582 365513	DMITRIY KUDRYASHOV	{"phone": "+70229967849"}
0005434926450	0824A9	8884 047427	ANATOLIY SEMENOV	{"email": "semenovanatoliy-05031968@postgrespro.ru", "phone": "+70021275882"}
0005434926451	5C3F19	5351 636854	ALEKSANDR NAZAROV	{"email": "nazarov-a.1958@postgrespro.ru", "phone": "+70717105821"}
0005434926452	36CE47	3056 674649	ALEKSANDR VOLKOV	{"phone": "+70757407217"}
0005434926453	CF888E	7339 523035	GLEB FEDOTOV	{"phone": "+70987556296"}
0005434926454	6BD6A8	4613 737691	YULIYA DMITRIEVA	{"email": "dmitrieva.yuliya-01031982@postgrespro.ru", "phone": "+70482328044"}
0005434926455	6BD6A8	8678 920617	ILYA ZAKHAROV	{"email": "ilya_zakharov-1981@postgrespro.ru", "phone": "+70897411048"}
0005434926456	9E6E68	4888 186355	NATALYA SMIRNOVA	{"email": "nsmirnova_041969@postgrespro.ru", "phone": "+70312391716"}
0005434926457	1F9274	3047 219720	VALERIY SERGEEV	{"phone": "+70352812994"}
0005434926458	1F9274	3792 880173	ANDREY NIKITIN	{"phone": "+70126468420"}
0005434926459	3658B8	5642 843278	SVETLANA NOVIKOVA	{"phone": "+70871675512"}
0005434926460	3658B8	9424 619001	EKATERINA FROLOVA	{"email": "frolova.e_1975@postgrespro.ru", "phone": "+70417973562"}
0005434926461	D7F68E	0229 795990	BORIS BORISOV	{"email": "boris_borisov-051965@postgrespro.ru", "phone": "+70647160568"}
0005434926462	D7F68E	4304 545922	YURIY FROLOV	{"phone": "+70608968828"}
0005434926463	9D129B	7500 720748	VALERIY IVANOV	{"phone": "+70030970885"}
0005434926464	A06A15	8321 927901	IVAN ISAEV	{"phone": "+70330743392"}
0005434926465	1BC05E	6485 490069	ANTONINA SMIRNOVA	{"email": "antonina.smirnova_19011969@postgrespro.ru", "phone": "+70058261979"}
0005434926466	753C39	2789 332983	NADEZHDA PETROVA	{"email": "petrova_nadezhda_111960@postgrespro.ru", "phone": "+70428339703"}
0005434926467	753C39	6676 268688	RAMIL VASILEV	{"phone": "+70621073471"}
0005434926468	C662A6	7776 706855	VALENTINA SOROKINA	{"phone": "+70474234209"}
0005434926469	BA7A55	1305 283483	ALEKSANDR BELOV	{"email": "abelov.1977@postgrespro.ru", "phone": "+70944103536"}
0005434926470	CFA137	9173 006295	NATALYA DAVYDOVA	{"email": "davydova.natalya1988@postgrespro.ru", "phone": "+70658547670"}
0005434926471	CFA137	3471 914206	LYUDMILA KUZNECOVA	{"phone": "+70785107031"}
0005434926472	4D6E57	3022 936390	IRINA MIRONOVA	{"email": "mironova-i021969@postgrespro.ru", "phone": "+70457110840"}
0005434926473	443A31	2144 552065	RUSTAM STEPANOV	{"email": "rstepanov_1966@postgrespro.ru", "phone": "+70613745069"}
0005434926474	443A31	5806 063041	TATYANA VASILEVA	{"phone": "+70764024512"}
0005434926475	F0E70F	7522 197064	MARINA IVANOVA	{"email": "m-ivanova041962@postgrespro.ru", "phone": "+70551837690"}
0005434926476	2C17BF	0814 470574	OLGA PAVLOVA	{"phone": "+70195552386"}
0005434926477	CF487D	5144 439401	EVGENIY MAKSIMOV	{"email": "maksimov.evgeniy.03031981@postgrespro.ru", "phone": "+70244805158"}
0005434926478	10D317	6089 629566	OLGA ZHUKOVA	{"email": "zhukova-o_1954@postgrespro.ru", "phone": "+70366048793"}
0005434926479	10D317	5168 337450	IVAN SOLOVEV	{"email": "solovev.ivan-1967@postgrespro.ru", "phone": "+70826620175"}
0005434926480	10D317	9734 589784	PAVEL MIRONOV	{"phone": "+70986504289"}
0005434926481	1F4509	1204 932459	ANASTASIYA ALEKSEEVA	{"email": "anastasiya-alekseeva08111968@postgrespro.ru", "phone": "+70409289905"}
0005434926482	1AC59B	4190 177914	ALEKSEY SEMENOV	{"email": "a.semenov081964@postgrespro.ru", "phone": "+70206859574"}
0005434926483	51D4CB	8975 299029	EDUARD SHEVCHENKO	{"email": "eduardshevchenko.061970@postgrespro.ru", "phone": "+70292306178"}
0005434926484	51D4CB	4198 566889	SERGEY VOROBEV	{"phone": "+70292798624"}
0005434926485	2093C9	2786 162628	ALEKSANDR IVANOV	{"phone": "+70931363227"}
0005434926486	2093C9	1668 834795	TATYANA IVANOVA	{"email": "ivanova_tatyana011976@postgrespro.ru", "phone": "+70935923518"}
0005434926487	4320B9	9210 060796	NATALYA MAKAROVA	{"email": "makarova.natalya05121972@postgrespro.ru", "phone": "+70205887270"}
0005434926488	4320B9	3401 354511	NATALYA SMIRNOVA	{"email": "n.smirnova_23011972@postgrespro.ru", "phone": "+70187121386"}
0005434926489	A10B9B	7877 676036	SAVELIY SAVELEV	{"email": "savelevsaveliy-1962@postgrespro.ru", "phone": "+70752187492"}
0005434926490	B067ED	3327 620023	NIKOLAY FEDOROV	{"email": "fedorov.n09071970@postgrespro.ru", "phone": "+70278376621"}
0005434926491	703F9D	8194 596413	DMITRIY NIKITIN	{"phone": "+70803822009"}
0005434926492	703F9D	4492 521158	ANASTASIYA SEMENOVA	{"email": "anastasiya_semenova-23061965@postgrespro.ru", "phone": "+70909420354"}
0005434926493	9D1597	6134 785577	ALEKSEY IVANOV	{"phone": "+70183106613"}
0005434926494	9D1597	1050 874637	NIKOLAY KUZMIN	{"phone": "+70077401973"}
0005434926495	F01171	0897 749399	ALEKSANDRA ALEKSEEVA	{"phone": "+70011109351"}
0005434926496	A55E88	3200 728576	LIDIYA BELOVA	{"email": "belova_l1971@postgrespro.ru", "phone": "+70609193703"}
0005434926497	549B8F	0850 513827	VIKTOR PAVLOV	{"email": "pavlov_viktor.1975@postgrespro.ru", "phone": "+70906700050"}
0005434926498	549B8F	1934 001437	RIMMA MELNIKOVA	{"email": "rimma-melnikova-101973@postgrespro.ru", "phone": "+70870325371"}
0005434926499	781F15	4979 167928	LYUBOV MAKAROVA	{"email": "makarova-l.061959@postgrespro.ru", "phone": "+70735624787"}
0005434926500	781F15	8956 669037	ANDREY MAKAROV	{"email": "andrey.makarov_1964@postgrespro.ru", "phone": "+70474538501"}
0005434926501	DF75D4	2679 817214	VALENTINA BORISOVA	{"phone": "+70314805834"}
0005434926502	C9868A	6886 784444	EDUARD PETROV	{"phone": "+70872216400"}
0005434926503	C1DEC4	4961 034427	NADEZHDA POPOVA	{"email": "n-popova.091965@postgrespro.ru", "phone": "+70710396240"}
0005434926504	A2E460	3407 213609	IVAN RODIONOV	{"phone": "+70610336761"}
0005434926505	0A9E6D	1312 383671	ELENA VASILEVA	{"phone": "+70124703998"}
0005434926506	5A660C	6325 347912	OLGA MIRONOVA	{"phone": "+70063471153"}
0005434926507	35CEC1	0208 223771	GEORGIY EGOROV	{"phone": "+70131817339"}
0005434926508	6D2D83	2866 115438	IVAN AFANASEV	{"phone": "+70023277588"}
0005434926509	6D2D83	4548 463422	TATYANA ZOTOVA	{"email": "zotova_t_14031967@postgrespro.ru", "phone": "+70830031855"}
0005434926510	761727	1449 910307	DMITRIY MOISEEV	{"email": "moiseev.d_1974@postgrespro.ru", "phone": "+70275524944"}
0005434926511	893C8C	4444 853624	ELENA MAKSIMOVA	{"email": "e-maksimova-25091967@postgrespro.ru", "phone": "+70397461779"}
0005434926512	D93B14	3544 329443	ELVIRA SEMENOVA	{"email": "semenova.e-02061964@postgrespro.ru", "phone": "+70183329883"}
0005434926513	D93B14	3850 768758	VLADIMIR SEMENOV	{"phone": "+70055406073"}
0005434926514	D93B14	4591 482625	OLGA FILATOVA	{"email": "o-filatova-1965@postgrespro.ru", "phone": "+70120128770"}
0005434926515	0A610C	5249 530160	DENIS FEDOROV	{"email": "d-fedorov02011965@postgrespro.ru", "phone": "+70685615938"}
0005434926516	0A610C	2105 003502	LIDIYA LAZAREVA	{"email": "lazareva_l.09021977@postgrespro.ru", "phone": "+70544391424"}
0005434926517	BAB051	8198 821043	ALEKSEY KONOVALOV	{"email": "akonovalov.06021965@postgrespro.ru", "phone": "+70294025021"}
0005434926518	BAB051	8345 630329	LYUBOV EGOROVA	{"phone": "+70705648323"}
0005434926519	1573D4	1952 969121	EGOR CHERNOV	{"email": "echernov.20121965@postgrespro.ru", "phone": "+70718072050"}
0005434926520	1573D4	2020 117211	SERGEY POPOV	{"email": "s-popov.11051971@postgrespro.ru", "phone": "+70849798877"}
0005434926521	ED2DFD	3394 481883	ALEKSEY ZAYCEV	{"phone": "+70284411204"}
0005434926522	9594C0	6566 004012	LYUBOV ALEKSEEVA	{"email": "alekseeval_1962@postgrespro.ru", "phone": "+70114030807"}
0005434926523	06CD17	0829 058509	MIKHAIL SMIRNOV	{"phone": "+70254561240"}
0005434926524	64CB58	9066 236941	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr-1982@postgrespro.ru", "phone": "+70033973886"}
0005434926525	4B4A56	3262 971266	MARIYA YAKOVLEVA	{"phone": "+70171405705"}
0005434926526	6D1133	8877 051073	DMITRIY VASILEV	{"email": "vasilevdmitriy.02081969@postgrespro.ru", "phone": "+70654528872"}
0005434926527	6D1133	2158 117794	NATALYA NIKIFOROVA	{"email": "nikiforova_natalya_021975@postgrespro.ru", "phone": "+70973139460"}
0005434926528	185439	7687 694078	IVAN KULIKOV	{"email": "kulikov.i-22111966@postgrespro.ru", "phone": "+70800777505"}
0005434926529	E5CAFE	9845 594048	VLADISLAV SMIRNOV	{"phone": "+70785930737"}
0005434926530	FAF30F	4018 671572	SERGEY ZHUKOV	{"email": "s-zhukov01071976@postgrespro.ru", "phone": "+70748859551"}
0005434926531	FAF30F	6257 586312	VLADIMIR STEPANOV	{"phone": "+70751981987"}
0005434926532	FAF30F	2561 430752	PAVEL IVANOV	{"phone": "+70630322312"}
0005434926533	9AB7B7	8225 528277	VLADIMIR VASILEV	{"email": "vasilev_v-1971@postgrespro.ru", "phone": "+70732937992"}
0005434926534	7C4F7A	8213 858697	IVAN DMITRIEV	{"email": "ivan_dmitriev071975@postgrespro.ru", "phone": "+70946776847"}
0005434926535	F22060	8687 976887	ANATOLIY MEDVEDEV	{"email": "medvedev.a_29121979@postgrespro.ru", "phone": "+70486397091"}
0005434926536	2937D5	4553 681114	ANDREY STEPANOV	{"email": "stepanov.a111985@postgrespro.ru", "phone": "+70832165452"}
0005434926537	EFD520	8751 608736	ANDREY BORISOV	{"phone": "+70556581360"}
0005434926538	7F12EC	6589 023058	NINA YUDINA	{"email": "n_yudina_16021979@postgrespro.ru", "phone": "+70181708859"}
0005434926539	719EBE	7606 556195	BORIS IVANOV	{"phone": "+70980476439"}
0005434926540	719EBE	8358 980829	VERA KUZMINA	{"phone": "+70820198549"}
0005434926541	C997DA	0461 336806	EVGENIY FOMIN	{"email": "evgeniyfomin11071983@postgrespro.ru", "phone": "+70398533164"}
0005434926542	8A332B	1233 971771	IRINA TITOVA	{"email": "titovai051969@postgrespro.ru", "phone": "+70670867728"}
0005434926543	E36B0E	9602 166003	ANDREY ZHUKOV	{"email": "a.zhukov.1960@postgrespro.ru", "phone": "+70119542050"}
0005434926544	6179A1	1579 829469	VITALIY KARPOV	{"email": "karpov-v-09071978@postgrespro.ru", "phone": "+70709109588"}
0005434926545	B2971B	3752 976182	ANATOLIY ANTONOV	{"email": "a.antonov_011980@postgrespro.ru", "phone": "+70015048294"}
0005434926546	F86CE2	1823 708903	LYUBOV ISAEVA	{"email": "isaeva.l.1960@postgrespro.ru", "phone": "+70550560559"}
0005434926547	860A0C	8033 751215	VIKTOR ZAKHAROV	{"phone": "+70088681327"}
0005434926548	3229EB	1854 700123	NADEZHDA ZAKHAROVA	{"email": "zakharovanadezhda-1969@postgrespro.ru", "phone": "+70429045260"}
0005434926549	337367	3962 454674	DMITRIY ROMANOV	{"email": "dmitriy-romanov_1967@postgrespro.ru", "phone": "+70877065496"}
0005434926550	337367	7131 484263	TATYANA SEMENOVA	{"email": "t_semenova-11121968@postgrespro.ru", "phone": "+70294192638"}
0005434926551	BD44CC	7401 506967	STANISLAV SIDOROV	{"email": "sidorov-stanislav02061967@postgrespro.ru", "phone": "+70972946255"}
0005434926552	8DCFAD	8410 765337	VALERIY SMIRNOV	{"email": "v.smirnov.081971@postgrespro.ru", "phone": "+70034933771"}
0005434926553	AA2851	7063 531202	MARIYA TIKHONOVA	{"phone": "+70795721069"}
0005434926554	AA2851	3614 080538	KLAVDIYA IVANOVA	{"email": "ivanova.klavdiya.101974@postgrespro.ru", "phone": "+70406840910"}
0005434926555	CE166B	4781 751800	ALEKSANDRA VASILEVA	{"phone": "+70345351241"}
0005434926556	E3F2E6	5594 604257	VADIM ZAYCEV	{"phone": "+70150015979"}
0005434926557	C33547	0144 027111	ALEKSANDR ORLOV	{"email": "a-orlov.021965@postgrespro.ru", "phone": "+70537632020"}
0005434926558	124BCA	2692 445349	SVETLANA POTAPOVA	{"email": "potapova-s.1974@postgrespro.ru", "phone": "+70442102704"}
0005434926559	124BCA	1032 089759	ALEKSANDR IVANOV	{"email": "aleksandrivanov_041971@postgrespro.ru", "phone": "+70951016007"}
0005434926560	A06861	2638 599083	VLADIMIR PAVLOV	{"email": "vladimirpavlov.1969@postgrespro.ru", "phone": "+70820545777"}
0005434926561	A06861	0366 836171	NIKITA VOROBEV	{"email": "vorobev-n.071976@postgrespro.ru", "phone": "+70126883706"}
0005434926562	27BD5E	3570 623415	SERGEY ALEKSEEV	{"phone": "+70397349621"}
0005434926563	27BD5E	8907 610008	TATYANA KOZLOVA	{"phone": "+70517869694"}
0005434926564	278414	9257 988713	VITALIY DAVYDOV	{"email": "davydov_v04031965@postgrespro.ru", "phone": "+70168412902"}
0005434926565	D5D275	7186 316810	SERGEY FEDOROV	{"email": "sergey-fedorov071988@postgrespro.ru", "phone": "+70846516265"}
0005434926566	0C9893	1299 819167	ALEKSANDR GORBUNOV	{"phone": "+70890670829"}
0005434926567	7B6657	8057 983547	DENIS ALEKSANDROV	{"email": "aleksandrov.denis.061974@postgrespro.ru", "phone": "+70371467769"}
0005434926568	7B6657	1088 932107	DMITRIY MOISEEV	{"email": "d_moiseev_021966@postgrespro.ru", "phone": "+70415650661"}
0005434926569	F868B1	4440 670225	VALERIY MAKSIMOV	{"phone": "+70867439517"}
0005434926570	16E120	8897 662757	DAMIR VOROBEV	{"phone": "+70692703905"}
0005434926571	776C3F	9698 475540	ELENA MAKSIMOVA	{"phone": "+70834447346"}
0005434926572	8D08FE	1705 889177	KRISTINA SMIRNOVA	{"phone": "+70798666275"}
0005434926573	8D08FE	9549 846221	EKATERINA TITOVA	{"email": "ekaterina-titova.25031976@postgrespro.ru", "phone": "+70773710792"}
0005434926574	538491	7478 485422	ANASTASIYA ALEKSEEVA	{"email": "anastasiyaalekseeva-1961@postgrespro.ru", "phone": "+70735399977"}
0005434926575	E93F44	7618 547555	YULIYA POPOVA	{"phone": "+70723254061"}
0005434926576	A30DE6	6829 603974	VYACHESLAV MELNIKOV	{"phone": "+70184539936"}
0005434926577	9946AD	4778 966835	REGINA NIKOLAEVA	{"phone": "+70746539120"}
0005434926578	9946AD	0142 506468	ALEKSEY KUZMIN	{"phone": "+70744241235"}
0005434926579	0BC98F	8698 410161	MARGARITA KAZAKOVA	{"email": "kazakova_margarita.1975@postgrespro.ru", "phone": "+70722878413"}
0005434926580	351FDF	1809 910636	ANNA PAVLOVA	{"email": "a.pavlova12031973@postgrespro.ru", "phone": "+70088752844"}
0005434926581	73C671	6192 567354	LARISA ABRAMOVA	{"phone": "+70699561953"}
0005434926582	D89902	3549 204581	VALENTINA FILIPPOVA	{"phone": "+70807897109"}
0005434926583	EDA629	8520 768016	ANASTASIYA LAZAREVA	{"phone": "+70762680549"}
0005434926584	255B5F	5603 290717	ALEKSEY IVANOV	{"phone": "+70923266897"}
0005434926585	F8F021	3728 684802	IGOR ISAEV	{"email": "i_isaev.071976@postgrespro.ru", "phone": "+70366826153"}
0005434926586	F8F021	1284 570635	LILIYA SEMENOVA	{"phone": "+70010462072"}
0005434926587	770FC1	4492 236944	EVGENIY SEMENOV	{"email": "esemenov.011979@postgrespro.ru", "phone": "+70869104449"}
0005434926588	86BD7A	0266 198639	ANNA POPOVA	{"phone": "+70186878429"}
0005434926589	AAA033	2185 888617	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr081971@postgrespro.ru", "phone": "+70199231835"}
0005434926590	AAA033	6449 097043	MIKHAIL YAKOVLEV	{"phone": "+70635652546"}
0005434926591	AB84C6	6859 452845	DMITRIY CHERNOV	{"email": "chernov_d1956@postgrespro.ru", "phone": "+70594321731"}
0005434926592	AA2780	8873 162229	NATALIYA ANISIMOVA	{"email": "anisimovan.1976@postgrespro.ru", "phone": "+70271284697"}
0005434926593	AA2780	5765 338158	SNEZHANA NAUMOVA	{"phone": "+70656229325"}
0005434926594	2EA685	2128 260537	DARYA MASLOVA	{"phone": "+70155427109"}
0005434926595	2EA685	4297 677826	ALEKSANDR MELNIKOV	{"phone": "+70780547211"}
0005434926596	13882C	6568 646933	ALEKSANDR KUZMIN	{"phone": "+70840181390"}
0005434926597	EF7DD3	5520 357359	ALEKSANDR GORBUNOV	{"phone": "+70532043968"}
0005434926598	DA6541	7979 809339	ZINAIDA POLYAKOVA	{"phone": "+70515960705"}
0005434926599	DA6541	0892 029246	PETR KARPOV	{"email": "pkarpov.20111974@postgrespro.ru", "phone": "+70379991977"}
0005434926600	DA6541	0584 166778	GALINA KUZMINA	{"email": "kuzmina-g_1971@postgrespro.ru", "phone": "+70703243317"}
0005434926601	BEE83F	7824 781175	OLEG KOZLOV	{"email": "oleg-kozlov_04071982@postgrespro.ru", "phone": "+70697066962"}
0005434926602	8F8E1C	2304 574401	SERGEY POPOV	{"email": "sergeypopov.021978@postgrespro.ru", "phone": "+70515207903"}
0005434926603	8B75C7	5661 937677	ALEKSANDR KUZNECOV	{"email": "kuznecov-a101973@postgrespro.ru", "phone": "+70233511712"}
0005434926604	8B75C7	5075 369486	DMITRIY MOROZOV	{"email": "d-morozov20111979@postgrespro.ru", "phone": "+70649868019"}
0005434926605	DC24E5	0296 033853	KONSTANTIN TIMOFEEV	{"phone": "+70447006584"}
0005434926606	89C2B6	9876 969765	KRISTINA KISELEVA	{"email": "kiseleva.k.081971@postgrespro.ru", "phone": "+70260260463"}
0005434926607	8AECC3	5572 155028	YURIY ANTONOV	{"phone": "+70129777017"}
0005434926608	8AECC3	1500 265490	NATALYA KOMAROVA	{"phone": "+70890920538"}
0005434926609	362289	0509 254727	OLGA KARPOVA	{"email": "karpovao_1975@postgrespro.ru", "phone": "+70808776725"}
0005434926610	3CF122	3345 787076	ARTEM MEDVEDEV	{"email": "medvedevartem011963@postgrespro.ru", "phone": "+70335000637"}
0005434926611	BF46ED	3913 478576	TAISIYA YAKOVLEVA	{"phone": "+70428958498"}
0005434926612	BF46ED	2256 698898	EVGENIY IVANOV	{"phone": "+70544690677"}
0005434926613	BF46ED	8744 219363	MARK DAVYDOV	{"phone": "+70274195492"}
0005434926614	DA1B25	3256 307722	ELVIRA ZAKHAROVA	{"email": "e-zakharova17091971@postgrespro.ru", "phone": "+70154511811"}
0005434926615	FA1409	8463 338771	ALEKSANDR PAVLOV	{"email": "pavlov_a.1976@postgrespro.ru", "phone": "+70747156149"}
0005434926616	B4A5F7	9846 419612	NADEZHDA ARKHIPOVA	{"email": "arkhipovan-1969@postgrespro.ru", "phone": "+70634334535"}
0005434926617	574DB4	1296 742434	BORIS EGOROV	{"phone": "+70099322956"}
0005434926618	9E178F	2437 135445	EKATERINA SOKOLOVA	{"phone": "+70705444249"}
0005434926619	086B42	1715 544756	SERGEY GAVRILOV	{"email": "sergey.gavrilov.1968@postgrespro.ru", "phone": "+70390209771"}
0005434926620	086B42	6740 831919	DENIS SAVELEV	{"phone": "+70225310967"}
0005434926621	0F44B4	5863 748624	VALENTINA MOROZOVA	{"email": "vmorozova_09041965@postgrespro.ru", "phone": "+70507364506"}
0005434926622	0F44B4	8596 618616	SERGEY DMITRIEV	{"email": "sdmitriev08041977@postgrespro.ru", "phone": "+70839162989"}
0005434926623	55F4BE	5518 557684	VIKTOR EGOROV	{"phone": "+70420787664"}
0005434926624	55F4BE	7879 658136	MARINA KUZNECOVA	{"email": "marina_kuznecova-111974@postgrespro.ru", "phone": "+70261383404"}
0005434926625	277400	3654 607892	ARTEM MAKAROV	{"phone": "+70809317494"}
0005434926626	4ECA8F	9668 090781	VADIM FROLOV	{"email": "frolov_vadim1973@postgrespro.ru", "phone": "+70143341563"}
0005434926627	4ECA8F	2419 530826	MARINA FILATOVA	{"phone": "+70026384802"}
0005434926628	AF2CB9	0551 734824	VLADISLAV KUZNECOV	{"email": "vkuznecov.1962@postgrespro.ru", "phone": "+70100880064"}
0005434926629	AFDA20	3589 692147	VLADIMIR MARTYNOV	{"email": "martynov-v.1966@postgrespro.ru", "phone": "+70572455125"}
0005434926630	C91CF4	5098 885798	ALEKSANDR FOMIN	{"phone": "+70896218839"}
0005434926631	EC3C1D	5031 581175	EKATERINA LUKYANOVA	{"email": "ekaterina_lukyanova05101968@postgrespro.ru", "phone": "+70887525642"}
0005434926632	EC3C1D	8618 058165	ALISA POPOVA	{"phone": "+70542347263"}
0005434926633	0B4C82	4136 529674	TATYANA NAZAROVA	{"email": "nazarova.tatyana-101972@postgrespro.ru", "phone": "+70771153589"}
0005434926634	65C4EB	3368 775218	ANASTASIYA OSIPOVA	{"email": "a_osipova031980@postgrespro.ru", "phone": "+70716343314"}
0005434926635	65C4EB	5100 280302	VYACHESLAV IVANOV	{"phone": "+70667098566"}
0005434926636	2FE9C2	4516 457736	NADEZHDA MAKAROVA	{"phone": "+70287981029"}
0005434926637	92C3A9	5768 257651	DMITRIY STEPANOV	{"email": "stepanov-d_121976@postgrespro.ru", "phone": "+70681872799"}
0005434926638	DFE4B0	1735 581492	POLINA MAKAROVA	{"email": "makarova_p_101970@postgrespro.ru", "phone": "+70780400365"}
0005434926639	DFE4B0	6961 378686	MARINA MAKSIMOVA	{"email": "maksimova_m_021985@postgrespro.ru", "phone": "+70419023208"}
0005434926640	DFE4B0	8981 326401	ALISA PAVLOVA	{"email": "apavlova1962@postgrespro.ru", "phone": "+70158327102"}
0005434926641	019B31	7177 654597	NAIL PAVLOV	{"phone": "+70954569422"}
0005434926642	290FD1	8336 336646	OLGA POLYAKOVA	{"email": "polyakovao081977@postgrespro.ru", "phone": "+70065571465"}
0005434926643	290FD1	2777 057405	TIMOFEY KOZLOV	{"phone": "+70538514281"}
0005434926644	84DCB5	7188 611640	OLGA SERGEEVA	{"phone": "+70059464606"}
0005434926645	84DCB5	1343 557449	MATVEY MIRONOV	{"email": "mironov-m.1978@postgrespro.ru", "phone": "+70510414918"}
0005434926646	BE97E5	2408 474722	RUSTEM ANTONOV	{"phone": "+70822223944"}
0005434926647	BE97E5	7938 763920	ALEKSANDR GAVRILOV	{"phone": "+70104393305"}
0005434926648	89B45A	2409 479055	PAVEL ZAKHAROV	{"email": "pavel_zakharov061984@postgrespro.ru", "phone": "+70379608137"}
0005434926649	89B45A	6737 078421	LEONID CHERNOV	{"phone": "+70182787611"}
0005434926650	DAE6A9	2235 729264	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey.06071960@postgrespro.ru", "phone": "+70188712839"}
0005434926651	DAE6A9	0531 467002	ZLATA PAVLOVA	{"email": "zlata-pavlova1970@postgrespro.ru", "phone": "+70185019397"}
0005434926652	74C59C	5447 415856	ALEKSEY SOKOLOV	{"phone": "+70318466164"}
0005434926653	74C59C	3101 216060	NIKITA BONDARENKO	{"phone": "+70710692234"}
0005434926654	15B295	3051 836121	EKATERINA MIRONOVA	{"phone": "+70578890457"}
0005434926655	98FC64	7113 201058	SERGEY MAKAROV	{"email": "makarov_sergey_101980@postgrespro.ru", "phone": "+70208058385"}
0005434926656	98FC64	4017 108278	ARSENIY NAUMOV	{"email": "arseniy_naumov_1969@postgrespro.ru", "phone": "+70858188456"}
0005434926657	98FC64	8325 421546	MIKHAIL FEDOTOV	{"email": "fedotovmikhail1978@postgrespro.ru", "phone": "+70716666676"}
0005434926658	02B028	6192 094627	ALEKSEY EGOROV	{"email": "egorov.aleksey031973@postgrespro.ru", "phone": "+70695736750"}
0005434926659	0B32BB	9276 231436	SVETLANA ALEKSANDROVA	{"email": "svetlana_aleksandrova_111974@postgrespro.ru", "phone": "+70394261434"}
0005434926660	9B8983	4001 853906	LARISA EGOROVA	{"phone": "+70239212281"}
0005434926661	8EDB63	9571 460604	SVETLANA MELNIKOVA	{"email": "melnikova_s_02061964@postgrespro.ru", "phone": "+70039690198"}
0005434926662	9C35D7	1456 035852	VLADIMIR NIKOLAEV	{"email": "nikolaev_v17071976@postgrespro.ru", "phone": "+70186601388"}
0005434926663	8C9068	4842 300729	NADEZHDA KONDRATEVA	{"email": "nkondrateva121973@postgrespro.ru", "phone": "+70403799180"}
0005434926664	D828E6	6670 614568	SERGEY KUDRYASHOV	{"email": "kudryashov_sergey_08071967@postgrespro.ru", "phone": "+70460480070"}
0005434926665	292B0D	6885 009857	MARAT KRASNOV	{"email": "krasnov_m_24051977@postgrespro.ru", "phone": "+70524681856"}
0005434926666	292B0D	4958 501945	PAVEL NAZAROV	{"email": "pavelnazarov_1959@postgrespro.ru", "phone": "+70837585585"}
0005434926667	1BC32C	6429 749677	VITALIY MATVEEV	{"phone": "+70067559651"}
0005434926668	A081A1	2515 955967	VLADISLAV SMIRNOV	{"phone": "+70127395818"}
0005434926669	A081A1	2565 004307	NATALIYA VOLKOVA	{"email": "nvolkova.051966@postgrespro.ru", "phone": "+70133762881"}
0005434926670	E0602A	7702 244087	SERGEY MIKHAYLOV	{"email": "s.mikhaylov-051991@postgrespro.ru", "phone": "+70574248858"}
0005434926671	E0602A	8639 421454	MARIYA MIRONOVA	{"phone": "+70167303060"}
0005434926672	58BDBC	2509 112312	LIDIYA GUSEVA	{"email": "guseva-lidiya.13031968@postgrespro.ru", "phone": "+70518767411"}
0005434926673	58BDBC	6299 745796	ANATOLIY SOLOVEV	{"email": "solovev_anatoliy.051975@postgrespro.ru", "phone": "+70257757872"}
0005434926674	30AF32	7722 526894	YURIY PETROV	{"phone": "+70279969863"}
0005434926675	2CCCF8	1692 315649	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev.1971@postgrespro.ru", "phone": "+70381091922"}
0005434926676	2CCCF8	8781 389177	ANDREY GORBUNOV	{"email": "gorbunov.a-1967@postgrespro.ru", "phone": "+70507244001"}
0005434926677	C38757	7967 995612	VERA ROMANOVA	{"email": "romanovav.1962@postgrespro.ru", "phone": "+70826882405"}
0005434926678	C38757	7233 277509	ANNA ABRAMOVA	{"phone": "+70074061569"}
0005434926679	E523EF	0964 182255	ANDREY EGOROV	{"email": "a-egorov22121975@postgrespro.ru", "phone": "+70499751881"}
0005434926680	31C7CA	0902 953847	RAVIL ABRAMOV	{"phone": "+70602746971"}
0005434926681	031AE2	7833 114242	POLINA GERASIMOVA	{"email": "pgerasimova1965@postgrespro.ru", "phone": "+70385362562"}
0005434926682	031AE2	6119 873711	ALEKSEY GAVRILOV	{"email": "a-gavrilov1974@postgrespro.ru", "phone": "+70046900001"}
0005434926683	716C2D	0743 546032	MADINA BELOVA	{"phone": "+70764034842"}
0005434926684	716C2D	2512 688097	TAMARA KOZLOVA	{"email": "kozlova_tamara-031979@postgrespro.ru", "phone": "+70911763316"}
0005434926685	FC2559	3406 976723	VERA KUZNECOVA	{"email": "vera.kuznecova-1983@postgrespro.ru", "phone": "+70510947091"}
0005434926686	34BA39	7634 470261	RAISA OVCHINNIKOVA	{"phone": "+70604527691"}
0005434926687	A156E5	6012 993380	ALLA MATVEEVA	{"phone": "+70041778906"}
0005434926688	0A073A	1658 696499	VLADIMIR KISELEV	{"phone": "+70413185639"}
0005434926689	28DC17	7580 345582	VLADIMIR KRASNOV	{"email": "krasnovv.03101977@postgrespro.ru", "phone": "+70583404970"}
0005434926690	FE9AB3	1367 477439	VALENTINA SEMENOVA	{"email": "semenova_v051963@postgrespro.ru", "phone": "+70804476201"}
0005434926691	83A90B	9029 752226	IVAN SERGEEV	{"phone": "+70990099599"}
0005434926692	3E00EF	0357 237183	LYUDMILA KARPOVA	{"phone": "+70127019492"}
0005434926693	554F26	4088 726073	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov.1979@postgrespro.ru", "phone": "+70153247879"}
0005434926694	6F258D	3961 115427	NADEZHDA ZAKHAROVA	{"phone": "+70886339177"}
0005434926695	6F258D	9648 560809	EVGENIY IVANOV	{"email": "ivanovevgeniy1977@postgrespro.ru", "phone": "+70044528846"}
0005434926696	6F258D	1541 752308	STEPAN FEDOTOV	{"phone": "+70321402717"}
0005434926697	E0AD91	0445 897605	ALEKSANDR SOKOLOV	{"email": "a-sokolov.1969@postgrespro.ru", "phone": "+70909724199"}
0005434926698	426CDA	2288 194789	ZOYA OSIPOVA	{"phone": "+70612547982"}
0005434926699	426CDA	3567 185732	DMITRIY TARASOV	{"email": "dtarasov-1965@postgrespro.ru", "phone": "+70145350477"}
0005434926700	434595	1469 118054	VALENTINA IVANOVA	{"email": "valentina-ivanova_111976@postgrespro.ru", "phone": "+70648067068"}
0005434926701	434595	0740 612504	FEDOR DMITRIEV	{"phone": "+70314470836"}
0005434926702	6341BF	5958 017572	LEONID EGOROV	{"email": "l-egorov_091979@postgrespro.ru", "phone": "+70877319506"}
0005434926703	85BDA0	3502 450318	OLGA NAUMOVA	{"email": "naumova-o-1976@postgrespro.ru", "phone": "+70565660964"}
0005434926704	7C5F1B	4967 825082	LYUBOV ANDREEVA	{"phone": "+70222286362"}
0005434926705	F838A9	0747 596621	ALEKSANDR IVANOV	{"phone": "+70384379443"}
0005434926706	79775C	3802 583648	ANDREY FEDOROV	{"phone": "+70493111407"}
0005434926707	979513	6513 064950	NIKITA YAKOVLEV	{"phone": "+70564296090"}
0005434926708	979513	7785 651488	VLADIMIR FILIPPOV	{"email": "vladimir_filippov16061977@postgrespro.ru", "phone": "+70571654302"}
0005434926709	93375A	0240 727052	LIDIYA FILATOVA	{"phone": "+70315622026"}
0005434926710	6999B5	9080 244716	ALEKSANDR VASILEV	{"email": "vasilevaleksandr02041975@postgrespro.ru", "phone": "+70377363530"}
0005434926711	D8683A	3598 406840	ALEKSANDR MAKSIMOV	{"email": "maksimov.aleksandr.121975@postgrespro.ru", "phone": "+70686990781"}
0005434926712	21353C	3686 466654	VASILIY KOROLEV	{"phone": "+70143824506"}
0005434926713	6F5184	2810 361635	VALERIY VOLKOV	{"phone": "+70822385114"}
0005434926714	6F5184	2336 910908	ALEKSANDR BELOV	{"email": "a_belov121965@postgrespro.ru", "phone": "+70501391464"}
0005434926715	1EE5FC	9559 048728	IRINA KUZMINA	{"email": "ikuzmina-1973@postgrespro.ru", "phone": "+70764725600"}
0005434926716	1EE5FC	1897 500823	EVGENIY CHERNOV	{"email": "evgeniy-chernov.031973@postgrespro.ru", "phone": "+70911866313"}
0005434926717	1EE5FC	2054 546179	TATYANA ORLOVA	{"phone": "+70998308425"}
0005434926718	1EE5FC	3219 355083	ALEKSANDR FOMIN	{"phone": "+70552495253"}
0005434926719	0DC3CE	3236 627293	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov-29111979@postgrespro.ru", "phone": "+70985240738"}
0005434926720	4C5001	7906 421800	YURIY NOVIKOV	{"phone": "+70681020494"}
0005434926721	4C5001	0748 613359	MARIYA BELYAEVA	{"email": "mariya-belyaeva-101978@postgrespro.ru", "phone": "+70083771268"}
0005434926722	18B302	3520 236837	MAKSIM BORISOV	{"phone": "+70139116712"}
0005434926723	0EA613	6775 081369	VLADIMIR ROMANOV	{"phone": "+70980906384"}
0005434926724	94D523	1737 119286	OLGA KOZLOVA	{"email": "olgakozlova1973@postgrespro.ru", "phone": "+70775456264"}
0005434926725	A87118	8540 133190	KONSTANTIN SERGEEV	{"phone": "+70459185094"}
0005434926726	19EC09	3665 534493	VALENTIN SAVELEV	{"phone": "+70468779419"}
0005434926727	57AE11	9052 387799	MARINA GORBUNOVA	{"phone": "+70258723199"}
0005434926728	08DD06	2436 832321	EKATERINA AFANASEVA	{"email": "afanaseva.ekaterina-081967@postgrespro.ru", "phone": "+70979461040"}
0005434926729	08DD06	2311 413341	ALEKSANDR POPOV	{"phone": "+70982398716"}
0005434926730	8B4885	5560 391334	VLADISLAV SCHERBAKOV	{"email": "scherbakov_v_021991@postgrespro.ru", "phone": "+70065824765"}
0005434926731	8B4885	9213 049662	NELLI KOLESNIKOVA	{"phone": "+70372822664"}
0005434926732	A524AF	7665 878617	ELVIRA ILINA	{"email": "ilina-elvira-04071968@postgrespro.ru", "phone": "+70991628562"}
0005434926733	A524AF	2438 755565	SERGEY MELNIKOV	{"phone": "+70525320859"}
0005434926734	EBC505	2136 595268	OLEG MATVEEV	{"email": "oleg-matveev_031964@postgrespro.ru", "phone": "+70101583343"}
0005434926735	1EC57F	5289 718850	GALINA MIKHAYLOVA	{"phone": "+70741218363"}
0005434926736	6B304D	9802 305945	LEONID STEPANOV	{"phone": "+70129367713"}
0005434926737	2E08CF	4559 866427	ANTONINA MOROZOVA	{"phone": "+70606872827"}
0005434926738	2E08CF	7433 276191	LYUDMILA LEBEDEVA	{"email": "lebedeval.09081974@postgrespro.ru", "phone": "+70038072943"}
0005434926739	F14C91	6615 138449	VALENTINA MAKSIMOVA	{"email": "valentina_maksimova021976@postgrespro.ru", "phone": "+70409383773"}
0005434926740	F14C91	6670 866159	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr.1960@postgrespro.ru", "phone": "+70129947892"}
0005434926741	D5C9B6	3363 384269	ALENA KULIKOVA	{"email": "alena.kulikova1974@postgrespro.ru", "phone": "+70725507696"}
0005434926742	8F9AA6	1756 001953	ELENA NESTEROVA	{"email": "nesterovae.111978@postgrespro.ru", "phone": "+70330051672"}
0005434926743	713FEB	4478 252149	IGOR POPOV	{"phone": "+70910496546"}
0005434926744	E9FAF7	6555 823011	ANASTASIYA KRASNOVA	{"phone": "+70343947068"}
0005434926745	9EEB07	6335 725985	LEYLA GRISHINA	{"email": "grishina.leyla_30051965@postgrespro.ru", "phone": "+70154585228"}
0005434926746	9EEB07	3327 748859	RAISA LAZAREVA	{"phone": "+70583321948"}
0005434926747	19AC2E	0776 706807	NADEZHDA POPOVA	{"email": "n_popova08071966@postgrespro.ru", "phone": "+70422591340"}
0005434926748	19AC2E	3544 603766	IRINA TIKHONOVA	{"phone": "+70454296410"}
0005434926749	62F5EF	0311 857408	SERGEY KUZNECOV	{"phone": "+70706509282"}
0005434926750	0A0CE3	1371 435483	DMITRIY ABRAMOV	{"email": "d.abramov-13051963@postgrespro.ru", "phone": "+70843335298"}
0005434926751	0A0CE3	7180 972779	ALEKSANDR ZAKHAROV	{"phone": "+70038592850"}
0005434926752	8CB7E4	9834 697367	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda11051967@postgrespro.ru", "phone": "+70707756274"}
0005434926753	C28EEC	1182 876831	ALEKSEY ZAKHAROV	{"email": "zakharov.aleksey16021973@postgrespro.ru", "phone": "+70020040019"}
0005434926754	C28EEC	1671 637745	OLGA DMITRIEVA	{"phone": "+70258302058"}
0005434926755	C28EEC	9559 206692	SVETLANA KARPOVA	{"phone": "+70374708186"}
0005434926756	6ED9D6	9483 174846	OLGA ISAEVA	{"phone": "+70286318741"}
0005434926757	70D20E	3666 823445	ILYA ANDREEV	{"phone": "+70743648133"}
0005434926758	C62499	8685 739939	ALEKSANDR BORISOV	{"phone": "+70249029955"}
0005434926759	222045	5734 327747	YURIY DMITRIEV	{"phone": "+70364195140"}
0005434926760	222045	6180 974038	EVGENIY GAVRILOV	{"email": "gavrilov_evgeniy.021967@postgrespro.ru", "phone": "+70602974103"}
0005434926761	3A9018	5674 133822	ALEKSANDR BELOV	{"email": "belov_aleksandr.30051972@postgrespro.ru", "phone": "+70401346958"}
0005434926762	F945D3	5844 562288	VALENTINA MAKAROVA	{"email": "makarova.valentina_021981@postgrespro.ru", "phone": "+70154461414"}
0005434926763	F945D3	1612 620601	LIDIYA NOVIKOVA	{"email": "lidiya_novikova.1979@postgrespro.ru", "phone": "+70793419330"}
0005434926764	51F33B	8187 743101	ELENA SCHERBAKOVA	{"email": "scherbakova-elena_111983@postgrespro.ru", "phone": "+70824826460"}
0005434926765	567E82	3990 903215	TATYANA MASLOVA	{"phone": "+70747399938"}
0005434926766	262BF4	4231 870034	DENIS KULIKOV	{"email": "kulikov-denis-081965@postgrespro.ru", "phone": "+70482658048"}
0005434926767	262BF4	7222 399454	SERGEY IVANOV	{"phone": "+70274616893"}
0005434926768	61B8B5	2887 363915	KSENIYA LOGINOVA	{"email": "loginova_kseniya.28031982@postgrespro.ru", "phone": "+70503525616"}
0005434926769	61B8B5	1601 674623	SVETLANA MOISEEVA	{"email": "moiseeva_s-111973@postgrespro.ru", "phone": "+70850418159"}
0005434926770	9122B9	7418 787827	EVGENIY DAVYDOV	{"email": "davydov_evgeniy.091962@postgrespro.ru", "phone": "+70178281490"}
0005434926771	F313F8	2739 305174	YULIYA SOKOLOVA	{"email": "y-sokolova.081976@postgrespro.ru", "phone": "+70445434714"}
0005434926772	F313F8	4438 354360	GULFIYA ALEKSEEVA	{"phone": "+70611903391"}
0005434926773	750C0F	9027 609108	LYUBOV YAKOVLEVA	{"email": "yakovleva.lyubov.091962@postgrespro.ru", "phone": "+70007535038"}
0005434926774	53ED99	8901 384489	YURIY MAKAROV	{"email": "makarov_yuriy_22031970@postgrespro.ru", "phone": "+70767261140"}
0005434926775	53ED99	8114 473784	ELENA MASLOVA	{"email": "maslova.e_111971@postgrespro.ru", "phone": "+70579226996"}
0005434926776	9D05BA	8539 497648	GENNADIY ZHURAVLEV	{"email": "zhuravlev_g1968@postgrespro.ru", "phone": "+70609872792"}
0005434926777	6613BA	3641 209903	TATYANA MAKSIMOVA	{"email": "tatyana_maksimova.31051965@postgrespro.ru", "phone": "+70395302078"}
0005434926778	366D4B	5316 391615	VENERA FOMINA	{"phone": "+70814144466"}
0005434926779	83E4EE	7673 011364	ALEKSANDR MIRONOV	{"email": "mironova.13041962@postgrespro.ru", "phone": "+70483871767"}
0005434926780	F64577	1724 444306	GALINA LUKYANOVA	{"email": "galinalukyanova.061973@postgrespro.ru", "phone": "+70920450422"}
0005434926781	CB6E6D	3934 806307	VLADIMIR CHERNOV	{"phone": "+70897349407"}
0005434926782	CB6E6D	1207 581695	NADEZHDA KISELEVA	{"email": "kiselevanadezhda.1967@postgrespro.ru", "phone": "+70275184955"}
0005434926783	5A5011	5735 762749	ANDREY GORBUNOV	{"email": "andrey-gorbunov_1971@postgrespro.ru", "phone": "+70816893323"}
0005434926784	09C1BC	0521 379124	VALENTIN ZAYCEV	{"email": "valentin_zaycev.1986@postgrespro.ru", "phone": "+70253857545"}
0005434926785	09C1BC	8667 287567	LYUBOV ANISIMOVA	{"email": "anisimova.l_111974@postgrespro.ru", "phone": "+70829206158"}
0005434926786	DED50E	5090 684521	EVDOKIYA KOVALEVA	{"phone": "+70711167469"}
0005434926787	8E3C77	8690 409810	VITALIY ROMANOV	{"phone": "+70272935951"}
0005434926788	8E3C77	0074 954045	SERGEY SIDOROV	{"phone": "+70533608386"}
0005434926789	06DB21	6662 852911	LYUDMILA SIDOROVA	{"email": "l_sidorova-19121976@postgrespro.ru", "phone": "+70342753886"}
0005434926790	06DB21	2699 734346	DMITRIY ANDREEV	{"phone": "+70371246391"}
0005434926791	142D43	6345 192800	SVETLANA VLASOVA	{"phone": "+70912583438"}
0005434926792	2862DC	9600 557477	VIKTOR ABRAMOV	{"email": "viktor_abramov.031960@postgrespro.ru", "phone": "+70597329731"}
0005434926793	9E9A2B	2388 153261	MIKHAIL KOROLEV	{"phone": "+70796695754"}
0005434926794	B315E9	4161 467450	ANTON ABRAMOV	{"phone": "+70566514837"}
0005434926795	F5770B	5496 584331	NIKOLAY FEDOROV	{"email": "fedorov.n061971@postgrespro.ru", "phone": "+70141654448"}
0005434926796	803DEC	7673 890432	RAMIL KUZMIN	{"phone": "+70255781401"}
0005434926797	803DEC	7765 597633	EVGENIY VLASOV	{"phone": "+70974160894"}
0005434926798	20E370	9836 110015	ZINAIDA ZHURAVLEVA	{"email": "zhuravleva.zinaida.19031987@postgrespro.ru", "phone": "+70908092675"}
0005434926799	5F370B	4687 500275	TATYANA KONDRATEVA	{"email": "tatyana.kondrateva091976@postgrespro.ru", "phone": "+70583815964"}
0005434926800	5F370B	2898 443049	ELMIRA DAVYDOVA	{"phone": "+70459450102"}
0005434926801	E5E3C4	9893 191667	ROMAN OSIPOV	{"phone": "+70812064435"}
0005434926802	E5E3C4	3439 971403	TATYANA ILINA	{"phone": "+70650471747"}
0005434926803	910BE0	6507 144625	OLEG NIKOLAEV	{"phone": "+70173845473"}
0005434926804	910BE0	7295 101401	RAMIL ZAYCEV	{"email": "r_zaycev_1967@postgrespro.ru", "phone": "+70118594179"}
0005434926805	910BE0	7561 611350	ALEKSANDR KRASNOV	{"email": "aleksandrkrasnov-1985@postgrespro.ru", "phone": "+70873389263"}
0005434926806	4A8EE8	2847 521455	KSENIYA GORBUNOVA	{"email": "kseniya_gorbunova_24101964@postgrespro.ru", "phone": "+70792936303"}
0005434926807	3EC85A	4024 999334	PETR SCHERBAKOV	{"email": "scherbakov_petr-021973@postgrespro.ru", "phone": "+70240341967"}
0005434926808	4AC61D	0767 732222	GALINA VOLKOVA	{"phone": "+70444228026"}
0005434926809	4AC61D	6757 415765	MIKHAIL SERGEEV	{"email": "mikhail_sergeev1967@postgrespro.ru", "phone": "+70470044635"}
0005434926810	74DBF1	9379 823972	ALEKSANDRA FOMINA	{"phone": "+70806319653"}
0005434926811	D0124F	0717 500250	VLADIMIR KUDRYASHOV	{"email": "vladimir-kudryashov25101980@postgrespro.ru", "phone": "+70622697677"}
0005434926812	D0124F	4073 865627	INNA LAZAREVA	{"email": "i-lazareva.23081966@postgrespro.ru", "phone": "+70709224592"}
0005434926813	ED9541	4705 838271	VLADIMIR GERASIMOV	{"email": "vladimirgerasimov10051971@postgrespro.ru", "phone": "+70764027427"}
0005434926814	ED9541	8999 020002	RAVIL TIMOFEEV	{"email": "timofeevravil-31121962@postgrespro.ru", "phone": "+70824462847"}
0005434926815	ED9541	4265 010263	YURIY MIKHAYLOV	{"email": "mikhaylovyuriy_021975@postgrespro.ru", "phone": "+70109459242"}
0005434926816	3EAC41	9888 492621	RAIL YAKOVLEV	{"email": "yakovlev-r.1965@postgrespro.ru", "phone": "+70642130473"}
0005434926817	41876C	9991 481143	ARTEM KUZNECOV	{"phone": "+70781365576"}
0005434926818	E6C2D2	6187 729687	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov_26081983@postgrespro.ru", "phone": "+70303235707"}
0005434926819	E6C2D2	4999 816137	ALLA SCHERBAKOVA	{"email": "scherbakova_a-1980@postgrespro.ru", "phone": "+70899774257"}
0005434926820	293A32	7604 700737	OLGA KALININA	{"phone": "+70724793056"}
0005434926821	0AA044	0712 614306	OKSANA RYABOVA	{"email": "ryabova-o.1971@postgrespro.ru", "phone": "+70508809479"}
0005434926822	FE3971	0876 150551	OLGA KARPOVA	{"email": "o-karpova30121973@postgrespro.ru", "phone": "+70112525257"}
0005434926823	FA1063	2236 490546	ALEKSANDR NIKITIN	{"phone": "+70519724605"}
0005434926824	071515	1208 980556	KARINA GRISHINA	{"phone": "+70581882044"}
0005434926825	071515	1618 951584	NADEZHDA SCHERBAKOVA	{"email": "scherbakova_nadezhda_25071978@postgrespro.ru", "phone": "+70260024583"}
0005434926826	320068	6364 092014	SERGEY SAVELEV	{"email": "s_savelev18091974@postgrespro.ru", "phone": "+70965484410"}
0005434926827	320068	7016 169032	VALENTIN MOROZOV	{"email": "vmorozov1959@postgrespro.ru", "phone": "+70003802882"}
0005434926828	2F0320	5314 442594	VIKTOR IVANOV	{"phone": "+70804733970"}
0005434926829	816C12	4169 653015	ELENA TIMOFEEVA	{"email": "timofeeva-e_01071976@postgrespro.ru", "phone": "+70897417927"}
0005434926830	E56039	0301 115043	MIKHAIL ZAYCEV	{"email": "mikhailzaycev_1978@postgrespro.ru", "phone": "+70130705123"}
0005434926831	EE5373	8595 290677	ALEKSEY GERASIMOV	{"phone": "+70431272027"}
0005434926832	6403CD	7842 429246	LYUBOV BELYAEVA	{"email": "belyaeva_lyubov-111964@postgrespro.ru", "phone": "+70468990220"}
0005434926833	E68AC2	2232 796415	GALINA POPOVA	{"phone": "+70101809254"}
0005434926834	E68AC2	0487 322833	VERA NAZAROVA	{"email": "v.nazarova-1971@postgrespro.ru", "phone": "+70268089293"}
0005434926835	E68AC2	4181 773576	SERGEY ROMANOV	{"email": "romanov_s15051979@postgrespro.ru", "phone": "+70451471475"}
0005434926836	717AE9	0829 478392	SERGEY GUSEV	{"email": "gusev_sergey-1969@postgrespro.ru", "phone": "+70421233019"}
0005434926837	717AE9	7013 761627	GENNADIY NOVIKOV	{"phone": "+70346682844"}
0005434926838	395E18	6330 890559	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova.n-13041966@postgrespro.ru", "phone": "+70982679676"}
0005434926839	90FBF3	5896 794213	ALEKSANDR DAVYDOV	{"email": "adavydov08011971@postgrespro.ru", "phone": "+70237215027"}
0005434926840	962CC2	8919 790387	LYUDMILA TROFIMOVA	{"phone": "+70662012471"}
0005434926841	3C3737	6712 857103	ILMIRA MOROZOVA	{"phone": "+70324251363"}
0005434926842	3C3737	3868 989817	GALINA MAKAROVA	{"email": "g-makarova_021979@postgrespro.ru", "phone": "+70168909810"}
0005434926843	2C4DED	2423 885732	VIKTOR SAVELEV	{"email": "savelev_v.1969@postgrespro.ru", "phone": "+70787118932"}
0005434926844	E04E09	7759 814113	ELVIRA KOZLOVA	{"email": "kozlova.elvira061978@postgrespro.ru", "phone": "+70224470791"}
0005434926845	E04E09	5160 962355	PETR FROLOV	{"phone": "+70234001489"}
0005434926846	327B0F	2577 072350	NATALYA FEDOROVA	{"email": "fedorova_natalya_1959@postgrespro.ru", "phone": "+70739713339"}
0005434926847	327B0F	9472 142274	ANDREY EGOROV	{"email": "egorov-a-1962@postgrespro.ru", "phone": "+70510860003"}
0005434926848	207336	5851 194307	MILANA YAKOVLEVA	{"email": "yakovlevam_1969@postgrespro.ru", "phone": "+70162907638"}
0005434926849	207336	1650 521004	OLEG ALEKSANDROV	{"email": "o_aleksandrov.031974@postgrespro.ru", "phone": "+70578411671"}
0005434926850	8C1FCB	5007 471346	ANTONINA MOISEEVA	{"phone": "+70883849690"}
0005434926851	5B606C	8637 990157	TATYANA FOMINA	{"phone": "+70206498908"}
0005434926852	4C016C	3773 553845	NATALYA SOKOLOVA	{"email": "nsokolova.20121963@postgrespro.ru", "phone": "+70954454248"}
0005434926853	7511B9	0903 979811	IRINA ANISIMOVA	{"email": "anisimovai_1968@postgrespro.ru", "phone": "+70639147669"}
0005434926854	7511B9	7886 870321	VLADIMIR TIKHONOV	{"phone": "+70497129246"}
0005434926855	A9ACBC	4540 292078	TATYANA MARTYNOVA	{"email": "tmartynova_081983@postgrespro.ru", "phone": "+70000464303"}
0005434926856	3C0887	6437 432980	SERGEY RODIONOV	{"phone": "+70535297569"}
0005434926857	699F70	4703 049957	ANTONINA DMITRIEVA	{"email": "dmitrieva-antonina1975@postgrespro.ru", "phone": "+70004098739"}
0005434926858	699F70	1832 250258	VIKTOR SAVELEV	{"email": "savelev_viktor1971@postgrespro.ru", "phone": "+70328013192"}
0005434926859	28B99A	3215 470925	MIKHAIL SAVELEV	{"phone": "+70020603205"}
0005434926860	E0BE5B	4028 878969	NATALYA DANILOVA	{"email": "natalya.danilova.091964@postgrespro.ru", "phone": "+70626170449"}
0005434926861	8DAF58	2281 370786	BOGDAN ANTONOV	{"phone": "+70418036411"}
0005434926862	8DAF58	8878 041318	VALENTINA VASILEVA	{"email": "vvasileva-061985@postgrespro.ru", "phone": "+70730479707"}
0005434926863	696C38	4588 013090	IRINA GORBUNOVA	{"phone": "+70595373409"}
0005434926864	86080C	5870 456059	ALEKSEY VASILEV	{"phone": "+70405773473"}
0005434926865	86080C	7018 954875	VYACHESLAV EGOROV	{"phone": "+70088474183"}
0005434926866	86080C	7975 475051	VIKTOR KOZLOV	{"email": "v.kozlov.061976@postgrespro.ru", "phone": "+70529791580"}
0005434928248	5FF9F4	3733 129946	SERGEY SCHERBAKOV	{"phone": "+70761102247"}
0005434928249	5FF9F4	0661 047603	ANDREY MIKHAYLOV	{"phone": "+70273971720"}
0005434928250	B8B798	9371 833417	NIKOLAY EGOROV	{"phone": "+70405460136"}
0005434928251	B8B798	9768 342757	DMITRIY MAKAROV	{"phone": "+70963883536"}
0005434928252	B69EC4	2621 245322	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov.041974@postgrespro.ru", "phone": "+70172724445"}
0005434928253	B2E4E3	7243 952739	TAISIYA AKIMOVA	{"email": "akimova_t_091974@postgrespro.ru", "phone": "+70089942302"}
0005434928254	F68D9C	7791 825781	DMITRIY OSIPOV	{"email": "osipovdmitriy_071971@postgrespro.ru", "phone": "+70572817432"}
0005434928255	27C9D2	6585 110390	EVGENIY FEDOTOV	{"phone": "+70878375507"}
0005434928256	27C9D2	6711 347410	PAVEL VASILEV	{"email": "vasilev_p-25061972@postgrespro.ru", "phone": "+70619341836"}
0005434928257	27C9D2	0513 599455	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov031971@postgrespro.ru", "phone": "+70654661302"}
0005434928258	E5B415	1173 398269	VLADIMIR SEMENOV	{"phone": "+70834466379"}
0005434928259	A2E6BA	4624 455625	NATALYA MELNIKOVA	{"email": "melnikova_n.1972@postgrespro.ru", "phone": "+70314496926"}
0005434928260	A2E6BA	0872 435602	TATYANA ROMANOVA	{"email": "t.romanova-04111966@postgrespro.ru", "phone": "+70910722205"}
0005434928261	0D50F4	2062 676652	MIKHAIL GUSEV	{"email": "mgusev1971@postgrespro.ru", "phone": "+70091587120"}
0005434928262	0D50F4	2061 568474	DENIS VLASOV	{"email": "vlasovdenis_041978@postgrespro.ru", "phone": "+70481772791"}
0005434928263	EE5A3C	1959 621872	ALINA NIKIFOROVA	{"email": "a_nikiforova14121977@postgrespro.ru", "phone": "+70412249343"}
0005434928264	5912D5	8660 101930	DMITRIY KUZMIN	{"email": "d_kuzmin-111984@postgrespro.ru", "phone": "+70891182208"}
0005434928265	F90DAF	8100 460437	EKATERINA ZAYCEVA	{"email": "e_zayceva_1973@postgrespro.ru", "phone": "+70269151147"}
0005434928266	409800	2130 607163	NINA AKIMOVA	{"phone": "+70743663345"}
0005434928267	10BA85	4378 764244	YURIY IVANOV	{"email": "yuriyivanov.041980@postgrespro.ru", "phone": "+70538447411"}
0005434928268	77A277	9014 467497	DMITRIY KOROLEV	{"email": "korolevd-16031977@postgrespro.ru", "phone": "+70107105081"}
0005434928269	E7943B	0423 155862	POLINA TITOVA	{"email": "titova.polina-021974@postgrespro.ru", "phone": "+70124928380"}
0005434928270	E7943B	9039 296402	ZOYA LAZAREVA	{"email": "lazareva-z-031975@postgrespro.ru", "phone": "+70392023100"}
0005434928271	796AEC	5962 042696	VLADIMIR RODIONOV	{"email": "v-rodionov02091967@postgrespro.ru", "phone": "+70009215242"}
0005434928272	8A1B3C	6708 013051	DANILA MELNIKOV	{"email": "d-melnikov071979@postgrespro.ru", "phone": "+70104790786"}
0005434928273	7C98B9	0934 145730	TATYANA BOGDANOVA	{"email": "tatyana_bogdanova091971@postgrespro.ru", "phone": "+70549614927"}
0005434928274	C4306B	2981 081198	VITALIY GORBUNOV	{"email": "v_gorbunov_1969@postgrespro.ru", "phone": "+70308975817"}
0005434928275	C4306B	7714 568476	ALEKSEY FROLOV	{"email": "a-frolov17081971@postgrespro.ru", "phone": "+70568273897"}
0005434928276	B38E47	8475 777339	GENNADIY SEMENOV	{"email": "semenov_gennadiy-1986@postgrespro.ru", "phone": "+70535099572"}
0005434928277	0896AE	8864 083237	TATYANA GAVRILOVA	{"email": "tatyana_gavrilova.02121970@postgrespro.ru", "phone": "+70087520599"}
0005434928278	426F4B	7766 683421	VALENTINA ZHUKOVA	{"phone": "+70832696172"}
0005434928279	426F4B	0973 789948	SVETLANA SAVELEVA	{"email": "savelevasvetlana05061968@postgrespro.ru", "phone": "+70530588140"}
0005434928280	D63FA9	8619 611082	YURIY PAVLOV	{"phone": "+70545721152"}
0005434928281	D63FA9	3230 627826	ALEKSANDR ZHURAVLEV	{"phone": "+70613304884"}
0005434928282	C8F1F9	8250 924133	VALENTINA KUZNECOVA	{"email": "kuznecovav.12021971@postgrespro.ru", "phone": "+70131793102"}
0005434928283	C27A97	1935 769105	IRINA PAVLOVA	{"phone": "+70442825022"}
0005434928284	8AFF7C	3789 845691	LIDIYA BARANOVA	{"email": "baranova-lidiya-1969@postgrespro.ru", "phone": "+70024538333"}
0005434928285	63CEFB	7746 787470	RUSLAN PAVLOV	{"phone": "+70472073389"}
0005434928286	8A0D7D	4383 134018	OLGA TROFIMOVA	{"phone": "+70060591526"}
0005434928287	8A0D7D	6292 323328	ELDAR KUDRYASHOV	{"email": "e.kudryashov24111973@postgrespro.ru", "phone": "+70218771669"}
0005434928288	E25BB0	9455 072592	SERGEY BONDARENKO	{"phone": "+70069983714"}
0005434928289	EBB3DC	4313 043234	LYUBOV DANILOVA	{"email": "l_danilova.1969@postgrespro.ru", "phone": "+70163508915"}
0005434928290	B27D96	0643 559358	TATYANA POLYAKOVA	{"phone": "+70489908335"}
0005434928291	A93DF0	1045 428686	MARIYA NIKITINA	{"phone": "+70389500655"}
0005434928292	1E077C	5848 727753	ANASTASIYA MAKSIMOVA	{"email": "maksimovaa-14101959@postgrespro.ru", "phone": "+70729968900"}
0005434928293	B187C2	4686 107347	EVGENIY MAKAROV	{"phone": "+70437496018"}
0005434928294	B187C2	3358 128509	MAKSIM KARPOV	{"email": "karpov_maksim.031976@postgrespro.ru", "phone": "+70932336649"}
0005434928295	D8CD4B	1246 317104	TATYANA ANTONOVA	{"email": "tantonova.11091978@postgrespro.ru", "phone": "+70334210541"}
0005434928296	D8CD4B	4613 114141	KRISTINA ABRAMOVA	{"email": "kabramova_061964@postgrespro.ru", "phone": "+70464774466"}
0005434928297	D9E260	9728 155245	RAMIL BORISOV	{"email": "borisov_r_081966@postgrespro.ru", "phone": "+70201732424"}
0005434928298	D9E260	2720 885910	VALENTINA KOZLOVA	{"phone": "+70422061629"}
0005434928299	D9E260	4102 686030	ALINA BELYAEVA	{"email": "belyaeva.alina.09091972@postgrespro.ru", "phone": "+70906770468"}
0005434928300	AC4324	9985 685124	ALEKSEY TIKHONOV	{"phone": "+70592079944"}
0005434928301	D3D9EC	6964 147031	ALEKSEY GORBUNOV	{"phone": "+70463974104"}
0005434928302	6601B3	9836 784615	NATALYA FADEEVA	{"email": "natalyafadeeva_15051977@postgrespro.ru", "phone": "+70085640744"}
0005434928303	6601B3	5620 133283	NATALYA KISELEVA	{"email": "kiseleva-n03021988@postgrespro.ru", "phone": "+70573545767"}
0005434928304	6601B3	4902 581840	OLGA BORISOVA	{"phone": "+70678442969"}
0005434928305	738EAF	9575 422898	IVAN SAVELEV	{"email": "savelevivan1967@postgrespro.ru", "phone": "+70055243972"}
0005434928306	0C488B	0722 793040	LYUDMILA FILIPPOVA	{"phone": "+70683470258"}
0005434928307	EFA815	5370 156887	ALEKSANDRA YUDINA	{"phone": "+70477509827"}
0005434928308	A51DAC	6201 033766	ALEKSEY FROLOV	{"email": "frolov-a_1957@postgrespro.ru", "phone": "+70809978761"}
0005434928309	C965C0	7743 036453	VLADIMIR KRASNOV	{"email": "vladimir_krasnov_101974@postgrespro.ru", "phone": "+70985492708"}
0005434928310	0310E0	7704 134380	MIKHAIL KOZLOV	{"email": "mikhail-kozlov_1968@postgrespro.ru", "phone": "+70512464760"}
0005434928311	93C285	4195 018211	MAKSIM MAKAROV	{"email": "makarov.m_14061967@postgrespro.ru", "phone": "+70243324781"}
0005434928312	9BC0FB	2424 828257	NADEZHDA IVANOVA	{"email": "n-ivanova.071966@postgrespro.ru", "phone": "+70059385825"}
0005434928313	EF4E3A	9157 772230	ANFISA ZAYCEVA	{"phone": "+70352582893"}
0005434928314	880ED0	3648 599776	ZINAIDA NIKOLAEVA	{"email": "z-nikolaeva.1965@postgrespro.ru", "phone": "+70317087644"}
0005434928315	59EBB8	0254 335211	NATALYA KOZLOVA	{"email": "kozlova-n-1977@postgrespro.ru", "phone": "+70858849496"}
0005434928316	00551A	6812 648663	LYUDMILA IVANOVA	{"phone": "+70288649900"}
0005434928317	613582	7388 077626	ELENA ALEKSEEVA	{"email": "e-alekseeva_09021980@postgrespro.ru", "phone": "+70600307673"}
0005434928318	613582	4965 882961	VLADIMIR KUZMIN	{"phone": "+70412122984"}
0005434928319	143E3F	8249 214783	PETR PAVLOV	{"email": "pavlovpetr_04061979@postgrespro.ru", "phone": "+70099646261"}
0005434928320	143E3F	4231 050377	MIKHAIL KONOVALOV	{"email": "m.konovalov_061971@postgrespro.ru", "phone": "+70090591825"}
0005434928321	143E3F	7472 041839	MARINA BELOVA	{"email": "marina_belova-07081984@postgrespro.ru", "phone": "+70191542815"}
0005434928322	E2CA3B	4489 976147	VALENTINA KULIKOVA	{"phone": "+70131573750"}
0005434928323	A3E6E1	2780 177930	DENIS VASILEV	{"email": "vasilev.d-111966@postgrespro.ru", "phone": "+70957738458"}
0005434928324	A3E6E1	8266 299092	ALEKSANDR ORLOV	{"phone": "+70900548001"}
0005434928325	8E11D9	0786 694948	ILYA ZHURAVLEV	{"email": "i.zhuravlev_1966@postgrespro.ru", "phone": "+70920336174"}
0005434928326	08683F	3458 615549	SERGEY DAVYDOV	{"phone": "+70524066899"}
0005434928327	D8AB72	6782 015427	ANDREY YAKOVLEV	{"phone": "+70357640969"}
0005434928328	B112B3	1072 802760	NADEZHDA GORBUNOVA	{"phone": "+70764851342"}
0005434928329	766D55	9200 971080	IGOR SIDOROV	{"phone": "+70526290979"}
0005434928330	3122B4	8809 541678	PAVEL ALEKSANDROV	{"phone": "+70602381179"}
0005434928331	3122B4	0878 070752	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr.031955@postgrespro.ru", "phone": "+70966718990"}
0005434928332	2DEAB2	2886 762081	LEONID PETROV	{"phone": "+70176019823"}
0005434928333	543E2E	0820 886281	OKSANA PETROVA	{"email": "opetrova.071975@postgrespro.ru", "phone": "+70340101887"}
0005434928334	B922C8	5623 151406	ALEKSEY STEPANOV	{"phone": "+70218780931"}
0005434928335	3204F2	4530 566717	VLADIMIR BARANOV	{"email": "vladimirbaranov-071962@postgrespro.ru", "phone": "+70441065283"}
0005434928336	D285B8	1522 479851	SERGEY POPOV	{"email": "popovsergey-071975@postgrespro.ru", "phone": "+70579278673"}
0005434928337	D285B8	6593 708377	ALISA SIDOROVA	{"email": "sidorova-a_041956@postgrespro.ru", "phone": "+70254980243"}
0005434928338	38035F	4914 184565	NADEZHDA BORISOVA	{"phone": "+70490823595"}
0005434928339	BB7277	4549 629003	IRINA BARANOVA	{"phone": "+70132115112"}
0005434928340	732A3E	3914 896646	DENIS NIKOLAEV	{"email": "d-nikolaev18121970@postgrespro.ru", "phone": "+70459053568"}
0005434928341	732A3E	6317 811886	EVGENIY IVANOV	{"phone": "+70616276858"}
0005434928342	FA9E56	6639 756569	SVETLANA KRASNOVA	{"phone": "+70085960247"}
0005434928343	FA9E56	0198 042912	VLADIMIR ZHUKOV	{"email": "zhukov_v-081959@postgrespro.ru", "phone": "+70177398218"}
0005434928344	3C7C57	6901 311240	ZOYA GORBUNOVA	{"phone": "+70929462449"}
0005434928345	0955E2	3653 863341	NATALYA NAUMOVA	{"phone": "+70101964694"}
0005434928346	0955E2	0822 525596	GEORGIY NIKITIN	{"email": "nikitin_georgiy.24061975@postgrespro.ru", "phone": "+70916116617"}
0005434928347	0955E2	1554 740110	ANATOLIY MOISEEV	{"phone": "+70545532604"}
0005434928348	0955E2	2179 204116	ELENA LUKYANOVA	{"phone": "+70598096037"}
0005434928349	BC0CCC	6028 837224	MARIYA OSIPOVA	{"email": "osipova.mariya-19011961@postgrespro.ru", "phone": "+70193062980"}
0005434928350	A6B6D3	6767 100419	ILYA FEDOROV	{"email": "fedorovilya.1971@postgrespro.ru", "phone": "+70625901860"}
0005434928351	B4F8FE	7802 258258	ALEKSANDRA OSIPOVA	{"email": "a.osipova.01111969@postgrespro.ru", "phone": "+70654658815"}
0005434928352	B4F8FE	8783 988046	ALEKSANDR GORBUNOV	{"email": "gorbunova.011981@postgrespro.ru", "phone": "+70315405022"}
0005434928353	B4F8FE	4089 968421	IVAN KUZNECOV	{"phone": "+70180712372"}
0005434928354	57772C	9805 772419	DMITRIY PETROV	{"phone": "+70076515263"}
0005434928355	6391BA	8800 087408	POLINA OVCHINNIKOVA	{"phone": "+70755101107"}
0005434928356	7B65C2	8064 195047	MIKHAIL ANDREEV	{"email": "mikhail_andreev_081973@postgrespro.ru", "phone": "+70786290005"}
0005434928357	A8EF37	0527 854105	ANNA IVANOVA	{"phone": "+70747989832"}
0005434928358	686BF0	1718 749114	DMITRIY ANDREEV	{"email": "dmitriy_andreev-071967@postgrespro.ru", "phone": "+70014665779"}
0005434928359	686BF0	1419 975560	SERGEY NIKITIN	{"email": "nikitin-sergey.1970@postgrespro.ru", "phone": "+70000440802"}
0005434928360	0FB2B1	7048 686025	ALEKSANDR KUZNECOV	{"phone": "+70430601855"}
0005434928361	0FB2B1	3622 933078	TATYANA MIRONOVA	{"phone": "+70327618363"}
0005434928362	804EED	9030 924974	ILYA MARTYNOV	{"phone": "+70778325717"}
0005434928363	804EED	0307 682403	VIKTORIYA IVANOVA	{"email": "viktoriyaivanova091969@postgrespro.ru", "phone": "+70976464600"}
0005434928364	3A35DC	4806 168897	IGOR OSIPOV	{"email": "osipovigor05071977@postgrespro.ru", "phone": "+70427232850"}
0005434928365	A80740	5055 949690	SERGEY MAKAROV	{"email": "sergeymakarov-011972@postgrespro.ru", "phone": "+70918274134"}
0005434928366	79E16E	2992 351294	ELZA CHERNOVA	{"email": "chernova.e-111974@postgrespro.ru", "phone": "+70874291005"}
0005434928367	79E16E	4686 258461	MAKSIM STEPANOV	{"phone": "+70752724314"}
0005434928368	79E16E	3920 211783	NIKOLAY SIDOROV	{"email": "sidorov-n_19051973@postgrespro.ru", "phone": "+70782357395"}
0005434928369	E3E4C2	4857 380005	VIKTOR ANDREEV	{"email": "v_andreev.031976@postgrespro.ru", "phone": "+70101456102"}
0005434928370	3956CC	1369 635406	VLADIMIR POPOV	{"phone": "+70245850142"}
0005434928371	F8810A	8090 709523	IVAN IVANOV	{"email": "ivanov.ivan-15121985@postgrespro.ru", "phone": "+70951349937"}
0005434928372	3D553B	8539 186989	ALEKSANDR FEDOROV	{"email": "fedorov.a.061976@postgrespro.ru", "phone": "+70460156572"}
0005434928373	E00D7D	1210 223631	NATALYA IVANOVA	{"email": "ivanovanatalya.081970@postgrespro.ru", "phone": "+70417618416"}
0005434928374	E00D7D	3671 173267	RAFAEL KUZNECOV	{"email": "r.kuznecov.1984@postgrespro.ru", "phone": "+70777867014"}
0005434928375	5E7C43	2811 701117	MAKSIM SIDOROV	{"phone": "+70411107090"}
0005434928376	050D19	2212 489810	DMITRIY MELNIKOV	{"phone": "+70538167956"}
0005434928377	050D19	8064 556968	EVGENIY DENISOV	{"email": "denisov-e.1973@postgrespro.ru", "phone": "+70319580698"}
0005434928378	8B2892	6377 699084	ELENA IVANOVA	{"email": "ivanova.elena121967@postgrespro.ru", "phone": "+70225041865"}
0005434928379	8A4D73	8086 397090	VITALIY GAVRILOV	{"email": "gavrilov.v-14021970@postgrespro.ru", "phone": "+70560313606"}
0005434928380	4FB062	3856 727927	MARINA MAKAROVA	{"phone": "+70095526894"}
0005434928381	C936DD	4231 854033	TATYANA DAVYDOVA	{"phone": "+70257505560"}
0005434937792	3B7345	5630 625719	ZINAIDA ZOTOVA	{"phone": "+70532780540"}
0005434937793	409E33	4590 899859	RAISA ZAYCEVA	{"phone": "+70807007578"}
0005434937794	A20153	0342 583813	NATALIYA MAKAROVA	{"email": "makarova-nataliya.18011975@postgrespro.ru", "phone": "+70031398743"}
0005434937795	A20153	6241 075105	YURIY YAKOVLEV	{"email": "yuriy_yakovlev_061975@postgrespro.ru", "phone": "+70497499262"}
0005434937796	0E8FA1	4788 684158	ANDREY FILIPPOV	{"phone": "+70646089926"}
0005434937797	2AEBAB	5605 046347	VITALIY KARPOV	{"email": "karpov.vitaliy.081962@postgrespro.ru", "phone": "+70296540733"}
0005434937798	2AEBAB	2594 744000	ARTEM NIKITIN	{"phone": "+70135759803"}
0005434937799	535A13	6594 950359	IRINA ARKHIPOVA	{"phone": "+70343046629"}
0005434937800	64F98D	8190 189690	ALEKSANDRA SOLOVEVA	{"phone": "+70934024322"}
0005434937801	64F98D	0644 349892	ALEKSEY SEMENOV	{"phone": "+70690316726"}
0005434937802	585C31	7264 050154	SERGEY ILIN	{"email": "ilins.101978@postgrespro.ru", "phone": "+70237900099"}
0005434937803	32DC81	6430 334290	ALEKSEY BORISOV	{"phone": "+70790798509"}
0005434937804	E16243	9637 059637	OLGA IVANOVA	{"email": "olgaivanova28051987@postgrespro.ru", "phone": "+70189123778"}
0005434937805	E16243	4128 625421	VALENTINA ANDREEVA	{"email": "andreevav23111979@postgrespro.ru", "phone": "+70298067856"}
0005434937806	5A8D30	5793 945790	SERGEY BORISOV	{"email": "borisovsergey.1979@postgrespro.ru", "phone": "+70400493237"}
0005434937807	82D84D	5505 377096	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr-01031963@postgrespro.ru", "phone": "+70433549581"}
0005434937808	D601DE	4115 555208	EKATERINA VOLKOVA	{"email": "e-volkova-04061978@postgrespro.ru", "phone": "+70926537097"}
0005434937809	D601DE	3714 538963	IRINA KRASNOVA	{"phone": "+70517786040"}
0005434937810	D601DE	1311 888816	ALEKSANDR SOKOLOV	{"phone": "+70864083885"}
0005434937811	C18C86	5440 727439	KRISTINA SERGEEVA	{"email": "sergeeva-kristina1969@postgrespro.ru", "phone": "+70360900956"}
0005434937812	26B505	7499 648782	IVAN SEMENOV	{"email": "semenov.ivan_011970@postgrespro.ru", "phone": "+70151667863"}
0005434937813	157912	0109 068523	OLGA MOISEEVA	{"phone": "+70192609857"}
0005434937814	3ED97F	5489 826218	OLGA GUSEVA	{"email": "gusevao_021968@postgrespro.ru", "phone": "+70656058041"}
0005434937815	3ED97F	3410 076159	PETR SMIRNOV	{"phone": "+70608851071"}
0005434937816	D90662	7996 551784	ANDREY FILIPPOV	{"phone": "+70328046225"}
0005434937817	D90662	8913 126446	VALENTINA NIKIFOROVA	{"email": "nikiforovavalentina-121975@postgrespro.ru", "phone": "+70619382105"}
0005434937818	DFFE44	1215 401408	DMITRIY VASILEV	{"email": "dmitriy-vasilev.101983@postgrespro.ru", "phone": "+70431492735"}
0005434937819	2DC8AD	1304 416115	NADEZHDA MARTYNOVA	{"email": "martynova-nadezhda-26031976@postgrespro.ru", "phone": "+70520355056"}
0005434937820	E69227	4518 981016	DMITRIY IVANOV	{"phone": "+70253448075"}
0005434937821	F97EC9	2692 485596	ZINAIDA MOROZOVA	{"email": "z-morozova.101970@postgrespro.ru", "phone": "+70453558966"}
0005434937822	0562BE	8952 468005	ANZHELIKA ERMAKOVA	{"email": "anzhelika.ermakova05091983@postgrespro.ru", "phone": "+70615317256"}
0005434937823	E09EAB	3334 056252	SVETLANA ZAKHAROVA	{"email": "svetlana_zakharova02021984@postgrespro.ru", "phone": "+70569765069"}
0005434937824	E09EAB	2390 476149	MARINA KOROLEVA	{"email": "korolevam1964@postgrespro.ru", "phone": "+70754945968"}
0005434937825	23608E	9356 056923	OLGA KUZNECOVA	{"email": "olga_kuznecova011977@postgrespro.ru", "phone": "+70464903407"}
0005434937826	11DB0A	5965 433045	PETR BONDARENKO	{"email": "bondarenkopetr.021980@postgrespro.ru", "phone": "+70423960970"}
0005434937827	22C2C4	3799 009379	ANTON ILIN	{"phone": "+70090935993"}
0005434937828	22C2C4	3182 083242	VLADIMIR KOROLEV	{"email": "v-korolev-081966@postgrespro.ru", "phone": "+70967249915"}
0005434937829	22C2C4	5876 760082	TATYANA FROLOVA	{"email": "tatyanafrolova011970@postgrespro.ru", "phone": "+70151803552"}
0005434937830	884B36	9939 699544	ANNA ZHUKOVA	{"phone": "+70384970447"}
0005434937831	5EA909	3911 099636	VALENTINA ANISIMOVA	{"email": "v_anisimova1965@postgrespro.ru", "phone": "+70711281823"}
0005434937832	5EA909	5303 659012	ALEKSEY IVANOV	{"email": "ivanovaleksey_17051972@postgrespro.ru", "phone": "+70399537404"}
0005434937833	1D4A8C	0651 941807	NIKOLAY KUZNECOV	{"phone": "+70687667387"}
0005434937834	33195E	7010 515600	ALEKSEY KRASNOV	{"email": "krasnovaleksey1962@postgrespro.ru", "phone": "+70567281732"}
0005434937835	33195E	0080 825414	VALENTINA SAVELEVA	{"email": "valentinasaveleva.051978@postgrespro.ru", "phone": "+70883474921"}
0005434937836	57FA7D	4378 689308	TATYANA EFIMOVA	{"email": "efimovatatyana.011975@postgrespro.ru", "phone": "+70832219847"}
0005434937837	57FA7D	3934 508240	VIKTOR FEDOROV	{"phone": "+70615436791"}
0005434937838	BCC9F7	6177 535956	VALENTINA SOLOVEVA	{"phone": "+70219590437"}
0005434937839	FD35B5	6384 053972	ALINA ARKHIPOVA	{"phone": "+70655844460"}
0005434937840	75D3E2	2711 471242	MARINA FROLOVA	{"email": "marina-frolova081970@postgrespro.ru", "phone": "+70079565775"}
0005434937841	75D3E2	3649 441534	EKATERINA IVANOVA	{"phone": "+70291946689"}
0005434937842	05034F	3648 220304	YAROSLAV MEDVEDEV	{"phone": "+70766140687"}
0005434937843	AB9E8A	3946 876627	VALERIY MEDVEDEV	{"email": "medvedev.v021962@postgrespro.ru", "phone": "+70460146127"}
0005434937844	D3911C	5915 314668	DANILA ZAKHAROV	{"phone": "+70702316374"}
0005434937845	A3D0A2	5516 205407	VALENTIN MATVEEV	{"email": "matveev-valentin-1959@postgrespro.ru", "phone": "+70058793159"}
0005434937846	FF4E63	3645 126163	KLARA ILINA	{"email": "ilina_k-1978@postgrespro.ru", "phone": "+70490062760"}
0005434937847	677CA1	8645 928076	ANDREY BORISOV	{"phone": "+70581380274"}
0005434937848	677CA1	6298 470398	ELENA ALEKSEEVA	{"email": "e.alekseeva_13031981@postgrespro.ru", "phone": "+70022023792"}
0005434937849	309C51	5728 123193	VLADIMIR IVANOV	{"email": "ivanov_vladimir_03081976@postgrespro.ru", "phone": "+70411987665"}
0005434937850	E1BF77	6774 027277	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir.1962@postgrespro.ru", "phone": "+70398175476"}
0005434937851	0239A2	8308 976102	TATYANA FEDOROVA	{"phone": "+70403842170"}
0005434937852	DD123D	8658 641233	ANNA GERASIMOVA	{"phone": "+70851665819"}
0005434937853	4CA6AB	7293 188933	RODION SCHERBAKOV	{"phone": "+70063910440"}
0005434937854	4CA6AB	6953 890507	LYUDMILA MATVEEVA	{"phone": "+70059594561"}
0005434937855	7C97A3	9194 172685	NADEZHDA MEDVEDEVA	{"email": "medvedeva.nadezhda.23071972@postgrespro.ru", "phone": "+70213142370"}
0005434937856	7C97A3	4285 858681	IRINA VASILEVA	{"email": "irinavasileva_1965@postgrespro.ru", "phone": "+70540773754"}
0005434937857	7C97A3	2297 375666	MARIYA POPOVA	{"email": "m_popova.021970@postgrespro.ru", "phone": "+70457917896"}
0005434937858	99F252	5438 487152	TATYANA ROMANOVA	{"email": "romanova.t_1972@postgrespro.ru", "phone": "+70354120615"}
0005434937859	99F252	6209 198402	ANASTASIYA MOROZOVA	{"email": "morozova-anastasiya.011968@postgrespro.ru", "phone": "+70863846322"}
0005434937860	467F5E	5512 475817	SERGEY KUZMIN	{"phone": "+70429867104"}
0005434937861	17B5F9	9089 440766	ARINA NAZAROVA	{"email": "nazarova-arina-10011969@postgrespro.ru", "phone": "+70819375686"}
0005434937862	17B5F9	4633 835216	ILMIRA VASILEVA	{"email": "vasileva-i06091970@postgrespro.ru", "phone": "+70920739685"}
0005434937863	5A2D04	8455 441669	LYUBOV TIKHONOVA	{"phone": "+70302756041"}
0005434937864	099A63	5044 600119	ALEKSANDR SOKOLOV	{"phone": "+70733859718"}
0005434937865	23264A	9345 144441	ANNA DANILOVA	{"email": "danilovaa_111973@postgrespro.ru", "phone": "+70404394283"}
0005434937866	9FD8FC	1301 972722	OLESYA SOLOVEVA	{"email": "soloveva.o-021982@postgrespro.ru", "phone": "+70470384951"}
0005434937867	BE9983	5197 951398	NIKOLAY DAVYDOV	{"email": "n-davydov-071980@postgrespro.ru", "phone": "+70015952623"}
0005434937868	3560A8	6407 555787	IRINA SOKOLOVA	{"phone": "+70421504581"}
0005434937869	3560A8	8658 227302	VLADIMIR POPOV	{"phone": "+70652257792"}
0005434937870	3560A8	6665 729460	VALENTINA MARTYNOVA	{"phone": "+70302675792"}
0005434937871	A73F35	2393 000716	GENNADIY KUZMIN	{"email": "gennadiy-kuzmin-1964@postgrespro.ru", "phone": "+70878593068"}
0005434937872	F92B58	0763 911819	ELIZAVETA GAVRILOVA	{"email": "elizaveta_gavrilova_12091973@postgrespro.ru", "phone": "+70726563176"}
0005434937873	CAE551	1656 833504	YURIY KRASNOV	{"phone": "+70593528109"}
0005434937874	544D8B	4270 696252	VIKTOR KAZAKOV	{"email": "v.kazakov_071963@postgrespro.ru", "phone": "+70217896216"}
0005434937875	21BF92	8995 205824	ELINA MALYSHEVA	{"phone": "+70851939489"}
0005434937876	EB9951	0685 888791	ANASTASIYA KISELEVA	{"email": "kiseleva.a_041990@postgrespro.ru", "phone": "+70928244125"}
0005434937877	EB9951	7598 892467	KSENIYA VLASOVA	{"email": "vlasovak.02041974@postgrespro.ru", "phone": "+70399047259"}
0005434937878	1C2865	7088 558216	EKATERINA NIKOLAEVA	{"phone": "+70995518006"}
0005434937879	1C2865	6310 965083	NIKOLAY MAKAROV	{"email": "makarov_nikolay-091977@postgrespro.ru", "phone": "+70075798267"}
0005434937880	CBC343	1101 806582	VYACHESLAV BONDARENKO	{"email": "v_bondarenko-1978@postgrespro.ru", "phone": "+70251157405"}
0005434937881	562100	3595 787749	MILANA VOLKOVA	{"email": "milanavolkova-011967@postgrespro.ru", "phone": "+70151058247"}
0005434937882	566594	2740 148541	EKATERINA DMITRIEVA	{"phone": "+70326073815"}
0005434937883	566594	5780 772239	SERGEY ALEKSEEV	{"phone": "+70991074438"}
0005434937884	695F2E	5164 723243	VALENTINA TROFIMOVA	{"phone": "+70295355243"}
0005434937885	695F2E	2064 930893	GALINA SOKOLOVA	{"phone": "+70659611107"}
0005434937886	86B885	9798 423767	YULIYA VASILEVA	{"phone": "+70843626029"}
0005434937887	251356	3979 787223	VERA PAVLOVA	{"phone": "+70275924766"}
0005434937888	33D167	8144 222933	LYUDMILA PAVLOVA	{"phone": "+70012208829"}
0005434937889	33D167	4945 572571	ANGELINA MALYSHEVA	{"email": "malysheva.angelina.031961@postgrespro.ru", "phone": "+70430545658"}
0005434937890	9EBED8	8011 966742	VIKTOR VOROBEV	{"phone": "+70119202541"}
0005434937891	9EBED8	4508 001138	SERGEY DAVYDOV	{"phone": "+70939398933"}
0005434937892	BA6320	5623 899337	VLADIMIR ORLOV	{"email": "v-orlov_18121983@postgrespro.ru", "phone": "+70783985460"}
0005434937893	BA6320	9097 485876	MAKSIM IVANOV	{"email": "maksimivanov26011965@postgrespro.ru", "phone": "+70032935806"}
0005434937894	D82EA3	7228 867723	NINA POPOVA	{"email": "npopova-1975@postgrespro.ru", "phone": "+70778754704"}
0005434937895	D82EA3	8240 806450	KONSTANTIN ZAYCEV	{"phone": "+70891798001"}
0005434937896	C1E300	3583 645909	ALEKSANDR FILIPPOV	{"phone": "+70457973271"}
0005434937897	500B45	1693 661444	YULIANA ORLOVA	{"email": "orlovay-1966@postgrespro.ru", "phone": "+70666401559"}
0005434937898	500B45	6989 046269	KIRILL EGOROV	{"phone": "+70717943250"}
0005434937899	E1FE59	6967 610643	VLADIMIR KUZMIN	{"email": "v_kuzmin_11031974@postgrespro.ru", "phone": "+70318676384"}
0005434937900	828808	0325 810235	LILIYA SOLOVEVA	{"phone": "+70118394257"}
0005434937901	0D9FBA	9184 676279	ELIZAVETA RYABOVA	{"phone": "+70974890114"}
0005434937902	0D9FBA	3026 339615	DMITRIY SOROKIN	{"email": "dmitriysorokin02081972@postgrespro.ru", "phone": "+70659739870"}
0005434937903	2F4BE0	5022 983136	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr.15081957@postgrespro.ru", "phone": "+70692535310"}
0005434937904	AEA133	5292 454247	ALEKSANDR NOVIKOV	{"email": "novikova.07071967@postgrespro.ru", "phone": "+70155438707"}
0005434937905	4FE105	1774 431102	DENIS SAVELEV	{"phone": "+70007648401"}
0005434937906	AB1759	2517 262956	VLADIMIR KAZAKOV	{"email": "vkazakov-1974@postgrespro.ru", "phone": "+70704312373"}
0005434937907	AB1759	6015 291342	VADIM RODIONOV	{"phone": "+70531923919"}
0005434937908	B1D890	0736 327044	TATYANA FROLOVA	{"phone": "+70531133039"}
0005434937909	15B47E	0899 943652	SVETLANA ORLOVA	{"email": "s-orlova_051958@postgrespro.ru", "phone": "+70904796227"}
0005434937910	9A5438	0350 631082	ANTON SCHERBAKOV	{"phone": "+70903805828"}
0005434937911	9A5438	2709 300588	TAMARA KOROLEVA	{"email": "t.koroleva-12021976@postgrespro.ru", "phone": "+70825778268"}
0005434937912	5766DA	9824 016280	VLADIMIR ZAKHAROV	{"phone": "+70953753411"}
0005434937913	EA8F34	2404 750569	PAVEL GERASIMOV	{"email": "pgerasimov.011980@postgrespro.ru", "phone": "+70615266705"}
0005434937914	EA8F34	8086 043629	VALENTINA ROMANOVA	{"email": "romanova.v_051974@postgrespro.ru", "phone": "+70351913178"}
0005434937915	EA8F34	7839 505737	ANNA ALEKSANDROVA	{"phone": "+70261373392"}
0005434937916	325F55	0766 663021	TATYANA IVANOVA	{"phone": "+70330276631"}
0005434937917	FE7B61	0599 252274	ANDREY SCHERBAKOV	{"phone": "+70912084513"}
0005434937918	9F62AA	9110 416159	ROZA TIKHONOVA	{"email": "roza.tikhonova-061971@postgrespro.ru", "phone": "+70528386022"}
0005434937919	EEB078	4319 950399	ILYA VASILEV	{"phone": "+70881477741"}
0005434937920	EEB078	2246 573276	NINA FADEEVA	{"phone": "+70182590630"}
0005434937921	EEB078	3932 986330	ANNA YAKOVLEVA	{"email": "anna_yakovleva_111980@postgrespro.ru", "phone": "+70585626070"}
0005434937922	9D2746	3199 138993	ALEKSANDR KRASNOV	{"phone": "+70825813383"}
0005434937923	2CBDE6	9961 768124	GALINA MAKAROVA	{"phone": "+70612592636"}
0005434937924	2CBDE6	7547 588393	ELENA FOMINA	{"phone": "+70935076068"}
0005434937925	461055	6195 966869	KLAVDIYA NIKIFOROVA	{"phone": "+70649525433"}
0005434937926	25143D	2600 303695	TATYANA TROFIMOVA	{"email": "tatyana_trofimova.13081970@postgrespro.ru", "phone": "+70305806773"}
0005434937927	25143D	0422 547970	NATALYA KUZNECOVA	{"phone": "+70211573007"}
0005434937928	CFBDC4	5332 743025	SVETLANA GRISHINA	{"phone": "+70333627391"}
0005434937929	FEC002	1717 955610	VLADIMIR KAZAKOV	{"email": "vladimirkazakov_101969@postgrespro.ru", "phone": "+70258543997"}
0005434937930	D0AAD3	0822 461623	DMITRIY PETROV	{"email": "d_petrov.02021968@postgrespro.ru", "phone": "+70227019605"}
0005434937931	D22E67	9598 111387	NAIL RODIONOV	{"phone": "+70932576455"}
0005434937932	D22E67	4760 920180	OLGA KUDRYASHOVA	{"phone": "+70984507718"}
0005434937933	80EFE7	3965 940987	MIKHAIL NIKITIN	{"phone": "+70176895836"}
0005434937934	E1745F	2915 843514	VIKTOR TIMOFEEV	{"phone": "+70884562881"}
0005434937935	E1745F	4033 188213	ALEKSEY KUZNECOV	{"email": "alekseykuznecov-05081987@postgrespro.ru", "phone": "+70716915399"}
0005434937936	47416F	4002 931799	VLADIMIR MIRONOV	{"email": "v_mironov.071962@postgrespro.ru", "phone": "+70156877200"}
0005434937937	687100	6304 095848	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov.19021977@postgrespro.ru", "phone": "+70695161453"}
0005434937938	687100	4048 239419	NIKOLAY MATVEEV	{"email": "n.matveev1980@postgrespro.ru", "phone": "+70498944958"}
0005434937939	E7C733	5705 667422	VLADISLAV KISELEV	{"phone": "+70424278081"}
0005434937940	F109E3	7442 326173	EKATERINA ORLOVA	{"email": "eorlova_10071970@postgrespro.ru", "phone": "+70484902371"}
0005434937941	0301C3	0442 485423	SERGEY FEDOROV	{"email": "s-fedorov1977@postgrespro.ru", "phone": "+70050718317"}
0005434937942	62684B	9517 951068	VYACHESLAV TIMOFEEV	{"phone": "+70124576885"}
0005434937943	62684B	0379 104449	TATYANA KOMAROVA	{"phone": "+70225841109"}
0005434937944	2AF682	5003 482783	ALEKSEY STEPANOV	{"phone": "+70154178755"}
0005434937945	46A1CE	0529 684935	DMITRIY MIKHAYLOV	{"email": "dmikhaylov_09121983@postgrespro.ru", "phone": "+70737385934"}
0005434937946	551CAE	3074 443110	VALENTINA NAUMOVA	{"email": "naumova-v-1986@postgrespro.ru", "phone": "+70924187378"}
0005434937947	5DC996	0719 310658	ALEKSANDR TARASOV	{"phone": "+70620244340"}
0005434937948	002427	4922 591422	TATYANA MOROZOVA	{"email": "morozovatatyana-11021970@postgrespro.ru", "phone": "+70444214383"}
0005434937949	7D37D9	1862 460701	NINA BELOVA	{"phone": "+70578518913"}
0005434937950	80FA38	4088 838864	NIKOLAY DMITRIEV	{"phone": "+70436772186"}
0005434937951	80FA38	7751 177361	GALINA VASILEVA	{"email": "vasileva.g_1979@postgrespro.ru", "phone": "+70385474859"}
0005434937952	6CAEDA	0587 569295	SERGEY IVANOV	{"phone": "+70724541448"}
0005434937953	EC62AB	1268 421785	SERGEY VASILEV	{"email": "vasilev-s_20031975@postgrespro.ru", "phone": "+70380041401"}
0005434937954	EC62AB	5090 838755	MARIYA FEDOROVA	{"phone": "+70864976801"}
0005434937955	C5BC96	2274 212657	NATALYA ZAKHAROVA	{"email": "natalya.zakharova_17011980@postgrespro.ru", "phone": "+70206333328"}
0005434937956	87E98D	5909 374627	ALEKSANDR IVANOV	{"email": "aivanov_091968@postgrespro.ru", "phone": "+70742943229"}
0005434937957	34A520	5859 517709	VIKTOR MOISEEV	{"phone": "+70075567341"}
0005434937958	34A520	1885 374388	OLGA ANISIMOVA	{"phone": "+70499853067"}
0005434937959	9FEDD0	8789 562669	ANDREY VLASOV	{"phone": "+70114799866"}
0005434937960	737E5B	0774 666433	IGOR SERGEEV	{"email": "sergeev-i-1963@postgrespro.ru", "phone": "+70299123461"}
0005434937961	737E5B	9635 999446	ARTEM DAVYDOV	{"email": "davydov_artem.16101961@postgrespro.ru", "phone": "+70861143540"}
0005434937962	3C3971	9651 850285	VALENTINA RYABOVA	{"email": "ryabova.v071982@postgrespro.ru", "phone": "+70770518946"}
0005434937963	3C3971	3071 332673	IVAN SAVELEV	{"email": "ivan.savelev1959@postgrespro.ru", "phone": "+70362906471"}
0005434937964	806F7D	1470 964855	RUSLAN ORLOV	{"phone": "+70998874145"}
0005434937965	806F7D	0170 295661	LYUBOV MALYSHEVA	{"email": "lmalysheva.19101973@postgrespro.ru", "phone": "+70291403997"}
0005434937966	E2B070	7170 941246	IGOR DAVYDOV	{"email": "davydovi1968@postgrespro.ru", "phone": "+70992130005"}
0005434937967	E2B070	3314 366416	KLAVDIYA MARTYNOVA	{"email": "martynova.k-111973@postgrespro.ru", "phone": "+70344248244"}
0005434937968	1AF042	4137 239269	NATALIYA BARANOVA	{"phone": "+70521507406"}
0005434937969	7E21BB	8356 221947	TATYANA KOMAROVA	{"email": "komarova-tatyana_23071987@postgrespro.ru", "phone": "+70939091271"}
0005434937970	7E21BB	1062 088264	DMITRIY KUZNECOV	{"phone": "+70887526567"}
0005434937971	336B90	1997 576539	MAKSIM VOROBEV	{"phone": "+70563819696"}
0005434937972	8A87B2	7970 051743	KONSTANTIN DENISOV	{"phone": "+70116063399"}
0005434937973	21CBBA	0228 200685	VERA KUZNECOVA	{"email": "kuznecova-v-1985@postgrespro.ru", "phone": "+70924109708"}
0005434937974	21CBBA	2218 708094	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a121968@postgrespro.ru", "phone": "+70262624846"}
0005434937975	AF6704	6868 558286	ANTON GUSEV	{"phone": "+70530930125"}
0005434937976	AF6704	8190 146015	YULIYA PAVLOVA	{"phone": "+70287706841"}
0005434937977	AF6704	6284 557692	RUSLAN ZHURAVLEV	{"email": "r_zhuravlev061973@postgrespro.ru", "phone": "+70129458846"}
0005434937978	677C18	9601 114138	VIKTOR PETROV	{"phone": "+70108507493"}
0005434937979	3D6B3D	9643 236508	DMITRIY NOVIKOV	{"phone": "+70485262104"}
0005434937980	3D6B3D	4753 685094	ALEKSEY KUZNECOV	{"email": "kuznecov.a.04101975@postgrespro.ru", "phone": "+70158985228"}
0005434937981	29D7C8	8059 142601	STEPAN GUSEV	{"phone": "+70175402083"}
0005434937982	A37A0D	8449 541618	REGINA KUZNECOVA	{"email": "r_kuznecova-101978@postgrespro.ru", "phone": "+70061913752"}
0005434937983	A37A0D	8922 708882	NIKITA VOROBEV	{"email": "n.vorobev_05051968@postgrespro.ru", "phone": "+70072651294"}
0005434937984	97961D	6585 051396	NATALYA DMITRIEVA	{"phone": "+70208475767"}
0005434937985	97961D	5107 720990	ELENA ZOTOVA	{"email": "zotova_e.06061970@postgrespro.ru", "phone": "+70862665388"}
0005434937986	0F2254	2236 686503	ELENA KOZLOVA	{"email": "kozlovaelena_1964@postgrespro.ru", "phone": "+70425557123"}
0005434937987	0F2254	0567 138936	ALEKSEY EGOROV	{"email": "aleksey_egorov_1959@postgrespro.ru", "phone": "+70625659868"}
0005434937988	BD7C0A	7862 376562	TATYANA ZHURAVLEVA	{"email": "tatyana-zhuravleva_16051960@postgrespro.ru", "phone": "+70154207363"}
0005434937989	BD7C0A	6731 126897	POLINA NAUMOVA	{"email": "polina.naumova.1972@postgrespro.ru", "phone": "+70234334768"}
0005434937990	D9F567	3851 619562	ANNA ALEKSANDROVA	{"phone": "+70556409130"}
0005434937991	A6F4FE	4291 147887	ANDREY FILIPPOV	{"phone": "+70051551350"}
0005434937992	694FCC	1746 375059	DENIS SOROKIN	{"email": "sorokin.denis.19081969@postgrespro.ru", "phone": "+70251820450"}
0005434937993	A1F1FA	5810 889296	EVGENIY ALEKSEEV	{"phone": "+70302425319"}
0005434937994	C73D4A	2653 357798	YURIY NAUMOV	{"email": "yuriy_naumov_011965@postgrespro.ru", "phone": "+70179808345"}
0005434937995	140E98	1163 644060	NIKOLAY PAVLOV	{"email": "pavlov.nikolay_041969@postgrespro.ru", "phone": "+70401955811"}
0005434937996	140E98	5020 645757	ALEKSEY SHEVCHENKO	{"email": "shevchenko_a17051977@postgrespro.ru", "phone": "+70499818594"}
0005434937997	BD0C09	8719 347588	SVETLANA KARPOVA	{"phone": "+70578299791"}
0005434937998	BD0C09	0547 330226	VLADIMIR BARANOV	{"email": "baranov-v1968@postgrespro.ru", "phone": "+70824741340"}
0005434937999	AC2405	7888 564681	LYUDMILA KUZNECOVA	{"email": "kuznecova_l1978@postgrespro.ru", "phone": "+70184464323"}
0005434938000	2279E7	8662 580492	NINA STEPANOVA	{"phone": "+70766534174"}
0005434938001	21DECB	7008 612620	EVGENIY SIDOROV	{"email": "evgeniy-sidorov.101965@postgrespro.ru", "phone": "+70165177784"}
0005434938002	21DECB	5391 556413	GALINA MAKAROVA	{"phone": "+70693871210"}
0005434938003	BF684A	1968 226791	TATYANA NIKITINA	{"email": "tnikitina-061982@postgrespro.ru", "phone": "+70521518170"}
0005434938004	A045EE	8961 211623	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr-071976@postgrespro.ru", "phone": "+70180853640"}
0005434938005	75212D	3265 124879	MIKHAIL ZAKHAROV	{"email": "m-zakharov-03041976@postgrespro.ru", "phone": "+70589612254"}
0005434938006	75212D	3001 210092	RAISA KULIKOVA	{"phone": "+70119783776"}
0005434938007	862E2E	9662 480113	OLEG KAZAKOV	{"email": "kazakov_o-111969@postgrespro.ru", "phone": "+70656013573"}
0005434938008	91B2CA	4386 110993	EVGENIY ILIN	{"phone": "+70139303570"}
0005434938009	91B2CA	0522 930678	ALEKSANDR DMITRIEV	{"email": "dmitriev-a-24101960@postgrespro.ru", "phone": "+70322848523"}
0005434938010	4ED296	3335 107386	YULIYA KULIKOVA	{"email": "kulikova_y-1985@postgrespro.ru", "phone": "+70665229535"}
0005434938011	4ED296	8028 269702	YURIY PAVLOV	{"email": "ypavlov111974@postgrespro.ru", "phone": "+70210244249"}
0005434938012	2EFF47	9992 582030	VLADISLAV CHERNOV	{"phone": "+70248376127"}
0005434938013	2EFF47	5814 350325	NIKOLAY MOROZOV	{"email": "nikolaymorozov-031982@postgrespro.ru", "phone": "+70381171840"}
0005434938014	12F9FD	7278 105988	IRINA MIKHAYLOVA	{"phone": "+70265044644"}
0005434938015	00E22F	0826 157090	NIKITA KUZNECOV	{"email": "kuznecovnikita.041972@postgrespro.ru", "phone": "+70458365055"}
0005434938016	00E22F	9650 583816	ELENA KUZNECOVA	{"email": "kuznecovaelena1980@postgrespro.ru", "phone": "+70291323450"}
0005434938017	84F252	5787 324079	EKATERINA MOROZOVA	{"email": "emorozova.081966@postgrespro.ru", "phone": "+70249532416"}
0005434938018	CEEDAF	8817 778907	ROMAN MAKSIMOV	{"phone": "+70971461968"}
0005434938019	7F8F65	5754 368932	IRINA EFIMOVA	{"email": "i.efimova_081961@postgrespro.ru", "phone": "+70629816649"}
0005434938020	7F8F65	8318 566118	EGOR ZAKHAROV	{"email": "zakharov-egor-11051972@postgrespro.ru", "phone": "+70723482937"}
0005434938021	C30BC7	3961 061011	ANNA KAZAKOVA	{"email": "kazakova.anna_061973@postgrespro.ru", "phone": "+70481433936"}
0005434938022	CAAE83	2896 181703	VASILIY KUZNECOV	{"phone": "+70349922984"}
0005434938023	145853	0608 817650	EKATERINA AFANASEVA	{"phone": "+70419236147"}
0005434938024	1845E4	9539 555954	SERGEY MIRONOV	{"phone": "+70094907588"}
0005434938025	1845E4	3127 707841	SVETLANA GAVRILOVA	{"email": "s.gavrilova061969@postgrespro.ru", "phone": "+70410512095"}
0005434938026	340137	4972 969378	ALEKSANDR SAVELEV	{"phone": "+70384035788"}
0005434938027	340137	6775 899850	SERGEY FEDOROV	{"phone": "+70429980673"}
0005434938028	58924B	1477 574675	TATYANA NESTEROVA	{"phone": "+70555279562"}
0005434938029	58924B	8752 002294	SVETLANA PETROVA	{"email": "petrova.s.1973@postgrespro.ru", "phone": "+70722154543"}
0005434938030	58924B	3238 729689	ANASTASIYA FOMINA	{"phone": "+70544348904"}
0005434938031	8B42F5	2981 335370	DIANA CHERNOVA	{"email": "diana-chernova-31101976@postgrespro.ru", "phone": "+70119883595"}
0005434938032	359AC9	7597 124583	MARIYA KOROLEVA	{"phone": "+70788427793"}
0005434938033	44D799	5474 399575	KSENIYA GERASIMOVA	{"phone": "+70997447971"}
0005434938034	44D799	7853 571468	NIKOLAY VOLKOV	{"email": "volkov.nikolay_021982@postgrespro.ru", "phone": "+70264833957"}
0005434938035	AC93C5	8067 277340	LILIYA SEMENOVA	{"email": "l.semenova021973@postgrespro.ru", "phone": "+70534236257"}
0005434938036	FD60CB	3873 448930	ANASTASIYA POPOVA	{"email": "anastasiyapopova_041979@postgrespro.ru", "phone": "+70051852856"}
0005434938037	874F95	1952 869176	TATYANA IVANOVA	{"email": "ivanova-t-071981@postgrespro.ru", "phone": "+70769287092"}
0005434938038	A4F589	2567 689527	ANATOLIY PAVLOV	{"phone": "+70957919570"}
0005434938039	A4F589	5918 021576	SERGEY FROLOV	{"phone": "+70033030069"}
0005434938040	FB4B0D	6394 115376	EVGENIY VLASOV	{"email": "vlasov_evgeniy04021985@postgrespro.ru", "phone": "+70720625334"}
0005434938041	00C98E	3054 135170	ALEKSANDRA MIRONOVA	{"email": "mironova.a-1964@postgrespro.ru", "phone": "+70501114796"}
0005434938042	00C98E	4542 657805	VIKTOR FILIPPOV	{"phone": "+70841598157"}
0005434938043	00C98E	0791 711319	DMITRIY PAVLOV	{"phone": "+70220183014"}
0005434938044	C37AF7	3012 628972	OLEG FEDOROV	{"phone": "+70385004326"}
0005434938045	72EDCF	7489 143200	LYUDMILA BORISOVA	{"email": "borisoval-1975@postgrespro.ru", "phone": "+70927117631"}
0005434938046	72EDCF	2055 311545	VLADIMIR MAKAROV	{"email": "makarov_v101977@postgrespro.ru", "phone": "+70684274334"}
0005434938047	3537EF	2669 235637	RUSLAN NOVIKOV	{"phone": "+70480383069"}
0005434938048	C2A5AF	2996 545648	EGOR FEDOROV	{"phone": "+70873739117"}
0005434938049	C2A5AF	1562 821063	VALERIY ALEKSEEV	{"email": "alekseevvaleriy.051979@postgrespro.ru", "phone": "+70380819229"}
0005434938050	E947A5	2034 928566	YURIY FOMIN	{"email": "yuriy-fomin.09071971@postgrespro.ru", "phone": "+70013700400"}
0005434938051	C2EC73	7509 282050	ANDREY SMIRNOV	{"email": "andrey-smirnov-121980@postgrespro.ru", "phone": "+70129685830"}
0005434938052	C6C8DB	1581 765318	INNA KOZLOVA	{"email": "kozlova_i.04081971@postgrespro.ru", "phone": "+70560940891"}
0005434938053	806135	0776 424152	VALENTINA ZOTOVA	{"email": "zotovavalentina_1970@postgrespro.ru", "phone": "+70678858329"}
0005434938054	806135	7630 179868	TATYANA STEPANOVA	{"email": "stepanova-t_19021967@postgrespro.ru", "phone": "+70024993766"}
0005434938055	35EFF0	4366 051320	ANDREY NOVIKOV	{"email": "a.novikov-091982@postgrespro.ru", "phone": "+70972412205"}
0005434938056	7DFE4D	7350 266970	NIKOLAY VOROBEV	{"email": "vorobev-nikolay-041970@postgrespro.ru", "phone": "+70506974471"}
0005434938057	45EAF4	9360 891366	RIFAT PETROV	{"phone": "+70224440751"}
0005434938058	45EAF4	4432 217905	DANILA KUZNECOV	{"phone": "+70523199548"}
0005434938059	0A6320	8473 324129	VALENTINA SEMENOVA	{"phone": "+70904285902"}
0005434938060	0A6320	4262 385208	NIKOLAY ALEKSEEV	{"phone": "+70335792363"}
0005434938061	8B4364	5756 920832	NIKOLAY KONOVALOV	{"email": "konovalov-n-101963@postgrespro.ru", "phone": "+70471941736"}
0005434938062	DE01BE	2257 600133	PETR POPOV	{"email": "petr-popov_1974@postgrespro.ru", "phone": "+70709138505"}
0005434938063	3429C8	8837 324651	MARGARITA ROMANOVA	{"email": "margarita-romanova.1972@postgrespro.ru", "phone": "+70745859768"}
0005434938064	3429C8	5988 873852	YULIYA STEPANOVA	{"phone": "+70731367263"}
0005434938065	5A3271	1384 912998	ANASTASIYA SIDOROVA	{"phone": "+70021630623"}
0005434938066	5A3271	1233 316995	NATALYA KOMAROVA	{"email": "nkomarova-05061982@postgrespro.ru", "phone": "+70083149829"}
0005434938067	3747A2	6261 643274	ALEKSANDR FOMIN	{"email": "fomin_aleksandr031968@postgrespro.ru", "phone": "+70309133404"}
0005434938068	3747A2	0604 929750	IVAN NIKOLAEV	{"phone": "+70805048085"}
0005434938069	269350	1988 112376	NINA MAKAROVA	{"email": "nina.makarova.13101978@postgrespro.ru", "phone": "+70138549440"}
0005434938070	3E4C23	4651 111645	ANDREY SOROKIN	{"phone": "+70315569130"}
0005434938071	02ECBD	4620 058157	VYACHESLAV KUDRYASHOV	{"phone": "+70165937690"}
0005434938072	02ECBD	6450 313914	ANTON FROLOV	{"phone": "+70259253097"}
0005434938073	209D15	0091 392724	ALENA SEMENOVA	{"phone": "+70471273038"}
0005434938074	90723B	4663 234816	PAVEL OSIPOV	{"phone": "+70507428916"}
0005434938075	1560B8	6417 163194	LYUBOV AFANASEVA	{"email": "afanasevalyubov1977@postgrespro.ru", "phone": "+70140061993"}
0005434938076	85DE1B	1584 557130	TATYANA POPOVA	{"phone": "+70642584905"}
0005434938077	B0DF5B	3739 566430	MILANA GERASIMOVA	{"email": "milanagerasimova1967@postgrespro.ru", "phone": "+70347562443"}
0005434938078	B0DF5B	6069 571422	VADIM ALEKSANDROV	{"phone": "+70531002777"}
0005434938079	6F62B9	8365 158749	SVETLANA VOLKOVA	{"email": "s.volkova.1968@postgrespro.ru", "phone": "+70872501110"}
0005434938080	82FD26	5878 297348	PAVEL NOVIKOV	{"email": "novikov-pavel_051964@postgrespro.ru", "phone": "+70662409572"}
0005434938081	82FD26	7351 229170	ALEKSANDR CHERNOV	{"phone": "+70397646055"}
0005434938082	254382	4946 647262	YURIY KISELEV	{"phone": "+70092748557"}
0005434938083	254382	1812 479790	MARGARITA PETROVA	{"email": "m_petrova.1950@postgrespro.ru", "phone": "+70075799949"}
0005434938084	CBAD43	0579 897618	TAMARA IVANOVA	{"email": "ivanova_t.1976@postgrespro.ru", "phone": "+70624929519"}
0005434938085	EA8EFC	9404 051637	YURIY KISELEV	{"email": "kiselev.y_05101968@postgrespro.ru", "phone": "+70346799117"}
0005434938086	3CAEE9	2143 546063	EVGENIY TARASOV	{"email": "tarasov_evgeniy.111980@postgrespro.ru", "phone": "+70706082542"}
0005434938087	26C1C0	1241 639391	LIDIYA OVCHINNIKOVA	{"email": "ovchinnikova-lidiya-1964@postgrespro.ru", "phone": "+70732514841"}
0005434938088	B1600D	9626 750005	ALLA KOROLEVA	{"phone": "+70537966722"}
0005434938089	A1799F	2701 554944	GRIGORIY ALEKSEEV	{"phone": "+70491772651"}
0005434938090	43FB23	7518 300816	YURIY KUZNECOV	{"email": "kuznecov_yuriy.28101974@postgrespro.ru", "phone": "+70027738911"}
0005434938091	62BB52	0566 785786	FARIT SMIRNOV	{"phone": "+70877319128"}
0005434938092	62BB52	1305 220564	SERGEY ZAKHAROV	{"phone": "+70482117351"}
0005434938093	6EAF95	1785 041669	NATALYA DENISOVA	{"phone": "+70330586436"}
0005434938094	6EAF95	8501 124064	NADEZHDA POLYAKOVA	{"email": "n_polyakova.041967@postgrespro.ru", "phone": "+70063085284"}
0005434938095	5A65EC	6013 934794	OLEG KAZAKOV	{"phone": "+70484076285"}
0005434938096	6E0F4C	4141 121635	LIDIYA GAVRILOVA	{"phone": "+70732326167"}
0005434938097	6E0F4C	0360 449923	VALERIY KULIKOV	{"email": "kulikov.valeriy.29051981@postgrespro.ru", "phone": "+70070478291"}
0005434938098	9CDC06	1228 919779	NATALYA ZAKHAROVA	{"email": "nzakharova.081960@postgrespro.ru", "phone": "+70639493028"}
0005434938099	9CDC06	8151 315302	PETR SEMENOV	{"email": "semenov-petr-031985@postgrespro.ru", "phone": "+70272273746"}
0005434938100	78D455	3235 261222	VALENTINA KONOVALOVA	{"email": "valentina_konovalova02081960@postgrespro.ru", "phone": "+70134038241"}
0005434938101	6AE7EB	6568 519473	ALEKSEY YAKOVLEV	{"phone": "+70700016307"}
0005434938102	6AE7EB	9748 924967	IRINA TIKHONOVA	{"phone": "+70630246822"}
0005434938103	494021	0241 496514	IRINA AFANASEVA	{"phone": "+70512681468"}
0005434938104	494021	9767 730122	VIKTOR IVANOV	{"phone": "+70072175886"}
0005434938105	A21C8F	7642 158023	EVGENIY ANDREEV	{"phone": "+70181895708"}
0005434938106	A21C8F	4477 526634	VALENTINA NESTEROVA	{"phone": "+70502654481"}
0005434938107	0E0B79	8337 966599	NINA ALEKSEEVA	{"phone": "+70985332721"}
0005434938108	610871	0038 831452	LYUBOV NIKOLAEVA	{"phone": "+70065314455"}
0005434938109	C26996	3991 823999	VERA KUDRYASHOVA	{"email": "vera.kudryashova.081968@postgrespro.ru", "phone": "+70377987806"}
0005434938110	B89B34	3925 224542	SERGEY VLASOV	{"phone": "+70894491337"}
0005434938111	A82615	5088 214872	VIKTORIYA FILATOVA	{"email": "viktoriya-filatova_061980@postgrespro.ru", "phone": "+70013291670"}
0005434938112	C2F76B	5443 788968	KSENIYA KONOVALOVA	{"email": "kseniyakonovalova-041967@postgrespro.ru", "phone": "+70152225255"}
0005434938113	C2F76B	8159 834248	IRINA MIRONOVA	{"email": "mironova_i071977@postgrespro.ru", "phone": "+70326945373"}
0005434938114	8F55BB	0159 644509	ALEKSANDR EGOROV	{"email": "egorov.a_111960@postgrespro.ru", "phone": "+70101263288"}
0005434938115	390910	8732 294204	PETR SOLOVEV	{"email": "solovev_p1964@postgrespro.ru", "phone": "+70389690977"}
0005434938116	71FD20	3348 722714	ALEKSEY KUZMIN	{"phone": "+70807008865"}
0005434938117	E63A62	5490 188588	ANZHELIKA EGOROVA	{"email": "egorovaanzhelika.10091978@postgrespro.ru", "phone": "+70497126224"}
0005434938118	F6EE9A	2703 053611	VIKTOR SMIRNOV	{"phone": "+70374132303"}
0005434938119	7AD6E2	9977 742976	DMITRIY KUZNECOV	{"phone": "+70901010009"}
0005434938120	642D1E	3414 228889	ANDREY PETROV	{"email": "a-petrov_1974@postgrespro.ru", "phone": "+70364110299"}
0005434938121	A5B26F	3597 762072	SVETLANA ARKHIPOVA	{"email": "svetlana-arkhipova1967@postgrespro.ru", "phone": "+70174885936"}
0005434938122	A5B26F	0066 926247	ANDREY MIKHAYLOV	{"phone": "+70589548614"}
0005434938123	9975F6	0158 655902	OLGA PETROVA	{"email": "petrovao-041979@postgrespro.ru", "phone": "+70334324375"}
0005434938124	9975F6	3213 675367	IRINA FROLOVA	{"email": "frolova_i.111973@postgrespro.ru", "phone": "+70073832947"}
0005434938125	81DC3D	9818 363595	DMITRIY POPOV	{"email": "dmitriy.popov1959@postgrespro.ru", "phone": "+70527406768"}
0005434938126	81DC3D	9882 255866	ALEKSEY KULIKOV	{"phone": "+70280382703"}
0005434938127	75EDD4	0095 182725	RAMIS ZHURAVLEV	{"email": "zhuravlev-r.1983@postgrespro.ru", "phone": "+70302017255"}
0005434938128	FDBC23	6854 033775	ALEKSANDRA IVANOVA	{"phone": "+70721659588"}
0005434938129	FDBC23	7076 983514	RAVIL KUZMIN	{"phone": "+70858126275"}
0005434938130	94679E	1279 182755	NATALYA BELYAEVA	{"phone": "+70201124700"}
0005434938131	94679E	5605 376956	LYUDMILA ZAKHAROVA	{"phone": "+70350091470"}
0005434938132	9C370B	6863 555175	IVAN KOZLOV	{"email": "kozlov-i25071979@postgrespro.ru", "phone": "+70565332928"}
0005434938133	8C8F79	2446 291073	ANGELINA AKIMOVA	{"email": "akimovaa.031972@postgrespro.ru", "phone": "+70964644184"}
0005434938134	133C1F	6787 160300	INESSA IVANOVA	{"email": "ivanova-i-07111979@postgrespro.ru", "phone": "+70908779741"}
0005434938135	1697BB	6507 459916	VALERIY NAUMOV	{"email": "naumov_valeriy021991@postgrespro.ru", "phone": "+70434131551"}
0005434938136	1697BB	8825 455423	ALEKSANDR VOLKOV	{"phone": "+70636270235"}
0005434938137	1697BB	1039 835199	ALEKSANDR VOLKOV	{"phone": "+70827032052"}
0005434938138	A73052	9211 573401	NIKOLAY DAVYDOV	{"email": "nikolay-davydov.071975@postgrespro.ru", "phone": "+70151651754"}
0005434938139	758E84	8439 240784	TATYANA MIRONOVA	{"phone": "+70343771914"}
0005434938140	758E84	3883 732888	NIKOLAY POPOV	{"email": "n-popov_1975@postgrespro.ru", "phone": "+70131847834"}
0005434938141	758E84	7729 632074	ELENA MOROZOVA	{"phone": "+70500106846"}
0005434938142	E05F43	3368 184182	GALINA STEPANOVA	{"email": "galina-stepanova-041982@postgrespro.ru", "phone": "+70286347876"}
0005434938143	4C5E05	9096 102311	OLGA IVANOVA	{"email": "o.ivanova25041970@postgrespro.ru", "phone": "+70368525439"}
0005434938144	204433	5251 248437	KSENIYA MAKAROVA	{"email": "k.makarova_1978@postgrespro.ru", "phone": "+70914614763"}
0005434938145	204433	8754 457668	ANDREY FEDOTOV	{"phone": "+70549443362"}
0005434938146	ABEA1F	3710 412348	ELVIRA MARTYNOVA	{"email": "martynova.elvira.081968@postgrespro.ru", "phone": "+70523011535"}
0005434938147	5405FE	8348 225343	YULIYA SCHERBAKOVA	{"phone": "+70209527241"}
0005434938148	A4C7B2	5617 610124	SERGEY FILIPPOV	{"phone": "+70337477740"}
0005434938149	34436B	4819 781593	LILIYA DENISOVA	{"phone": "+70329566422"}
0005434938150	7A9553	3513 219012	VALENTINA KULIKOVA	{"email": "vkulikova_1970@postgrespro.ru", "phone": "+70389382225"}
0005434938151	7A9553	8891 486095	ANTON SEMENOV	{"email": "semenov_a-10041968@postgrespro.ru", "phone": "+70379147592"}
0005434938152	FE983A	3018 350964	ANDREY MIRONOV	{"phone": "+70999457267"}
0005434938153	D88D44	1605 558730	VALENTINA KOMAROVA	{"email": "v-komarova-091971@postgrespro.ru", "phone": "+70983296984"}
0005434938154	D88D44	7838 418836	NADEZHDA TIMOFEEVA	{"phone": "+70818708889"}
0005434938155	D9053D	9724 705838	NINA ANDREEVA	{"phone": "+70549146680"}
0005434938156	D9053D	3166 111353	EVGENIYA VASILEVA	{"phone": "+70876117991"}
0005434938157	D9053D	1986 496671	DMITRIY MOISEEV	{"phone": "+70070605425"}
0005434938158	7FE524	2246 380242	ANDREY VOROBEV	{"email": "andreyvorobev_031964@postgrespro.ru", "phone": "+70682069748"}
0005434938159	1384F2	6850 933080	OLGA KAZAKOVA	{"phone": "+70275921366"}
0005434938160	1384F2	7740 701113	TATYANA TARASOVA	{"phone": "+70715827230"}
0005434938161	0EEB12	0438 220935	EVGENIY NIKITIN	{"email": "enikitin.091980@postgrespro.ru", "phone": "+70401799587"}
0005434938162	0EC0FB	1240 379156	OLEG FOMIN	{"phone": "+70876262955"}
0005434938163	5EFA6A	4030 204291	OLGA KOLESNIKOVA	{"phone": "+70432043293"}
0005434938164	92618D	1736 405687	DMITRIY OSIPOV	{"phone": "+70471489970"}
0005434938165	02AFCD	5158 591877	SERGEY VLASOV	{"email": "s.vlasov_081979@postgrespro.ru", "phone": "+70249399598"}
0005434938166	A3057A	3049 709208	NADEZHDA RODIONOVA	{"email": "nadezhda_rodionova071970@postgrespro.ru", "phone": "+70883585070"}
0005434938167	8DD7CF	8553 913454	TATYANA ALEKSANDROVA	{"phone": "+70265119807"}
0005434938168	65D6BA	5563 503616	LYUDMILA POTAPOVA	{"email": "l_potapova_041973@postgrespro.ru", "phone": "+70258469732"}
0005434938169	C03F1F	4276 241046	ANTONINA TIKHONOVA	{"email": "a-tikhonova061968@postgrespro.ru", "phone": "+70910808455"}
0005434938170	56C897	4561 505409	VLADIMIR NIKITIN	{"phone": "+70940400872"}
0005434938171	56C897	3221 275029	GALINA MATVEEVA	{"phone": "+70872538507"}
0005434938172	6E018A	9381 222037	ANTON YAKOVLEV	{"email": "antonyakovlev.091963@postgrespro.ru", "phone": "+70638513183"}
0005434938173	6E018A	0675 714174	VIKTOR STEPANOV	{"email": "vstepanov.101961@postgrespro.ru", "phone": "+70366906446"}
0005434938174	667B19	4431 418652	MARIYA SOROKINA	{"email": "mariyasorokina.101970@postgrespro.ru", "phone": "+70482353044"}
0005434938175	7D56ED	5224 827334	PELAGEYA EGOROVA	{"phone": "+70754074931"}
0005434938176	2F9E1E	0580 927287	ANDREY BELOV	{"phone": "+70336182549"}
0005434938177	7C85DE	4912 266143	VLADIMIR KISELEV	{"phone": "+70292000533"}
0005434938178	26ECC9	9658 002299	IRINA KUDRYASHOVA	{"phone": "+70881731372"}
0005434938179	028644	3367 994863	ELENA TIKHONOVA	{"phone": "+70899360542"}
0005434938180	028644	0738 607618	ALEKSANDR PAVLOV	{"phone": "+70184100129"}
0005434938181	663230	9636 065194	ANDREY IVANOV	{"email": "ivanov-a.15091979@postgrespro.ru", "phone": "+70055569073"}
0005434938182	663230	3544 510902	LYUDMILA ZAKHAROVA	{"email": "zakharova-lyudmila061969@postgrespro.ru", "phone": "+70532546170"}
0005434938183	8342F7	8364 304463	SVETLANA MEDVEDEVA	{"email": "medvedevasvetlana_1980@postgrespro.ru", "phone": "+70347449066"}
0005434938184	8342F7	3775 972952	ALEKSANDR ZHURAVLEV	{"phone": "+70614952210"}
0005434938185	AA23AC	0595 375141	KIRILL DAVYDOV	{"email": "davydov.kirill.101979@postgrespro.ru", "phone": "+70999465907"}
0005434938186	34C065	6796 703615	YURIY RODIONOV	{"phone": "+70921540360"}
0005434938187	93D6C1	4301 316882	ROMAN MAKSIMOV	{"phone": "+70617310593"}
0005434938188	A86404	4036 834098	SERGEY KUZMIN	{"phone": "+70451998216"}
0005434938189	9CA47D	6729 898268	NADEZHDA YAKOVLEVA	{"email": "n.yakovleva_31071981@postgrespro.ru", "phone": "+70213495675"}
0005434938190	9CA47D	7624 342006	NINA PETROVA	{"phone": "+70652892732"}
0005434938191	262B69	6708 941643	MARIYA ILINA	{"email": "mariya-ilina011981@postgrespro.ru", "phone": "+70591205537"}
0005434938192	4C851E	2403 042741	ANFISA ANDREEVA	{"email": "andreevaanfisa.121969@postgrespro.ru", "phone": "+70143560412"}
0005434938193	B1537F	5656 228217	ALEKSANDRA ILINA	{"email": "ilina.a.26061979@postgrespro.ru", "phone": "+70558598337"}
0005434938194	07D352	3041 221758	VIKTORIYA KUZNECOVA	{"email": "kuznecova.viktoriya-30071965@postgrespro.ru", "phone": "+70983479524"}
0005434938195	07D352	6513 490046	SERGEY VASILEV	{"email": "vasilevs.1966@postgrespro.ru", "phone": "+70692341432"}
0005434938196	8EAA06	8916 797940	LYUBOV LUKYANOVA	{"email": "llukyanova.1970@postgrespro.ru", "phone": "+70606784016"}
0005434938197	8EAA06	1954 960929	GALIYA KUZNECOVA	{"email": "kuznecova_galiya_07051963@postgrespro.ru", "phone": "+70307282072"}
0005434938198	1CB0D1	5874 567018	ALEKSANDR POPOV	{"email": "popov.aleksandr-061970@postgrespro.ru", "phone": "+70675515579"}
0005434938317	0AA500	8336 150374	KSENIYA TITOVA	{"phone": "+70882008875"}
0005434938199	470DF0	3462 040133	VIKTOR BORISOV	{"email": "viktor_borisov31011971@postgrespro.ru", "phone": "+70168729119"}
0005434938200	470DF0	2201 739622	ANASTASIYA MOROZOVA	{"email": "a.morozova061956@postgrespro.ru", "phone": "+70623320481"}
0005434938201	1D599A	4955 794635	ALEKSEY FEDOROV	{"email": "fedorov_aleksey-1978@postgrespro.ru", "phone": "+70448902822"}
0005434938202	B3E3B6	0842 674837	VLADISLAV TIKHONOV	{"phone": "+70303900126"}
0005434938203	89F14E	7362 431597	SERGEY NAUMOV	{"email": "snaumov_09071967@postgrespro.ru", "phone": "+70806225099"}
0005434938204	89F14E	4179 074946	SERGEY MOROZOV	{"phone": "+70103082432"}
0005434938205	01B574	2839 420475	SERGEY MOISEEV	{"phone": "+70736112295"}
0005434938206	01B574	5881 010871	ZULFIYA SERGEEVA	{"email": "z_sergeeva.071963@postgrespro.ru", "phone": "+70146580796"}
0005434938207	50DCE2	4633 167476	DMITRIY BARANOV	{"email": "d-baranov-20121961@postgrespro.ru", "phone": "+70293632294"}
0005434938208	50DCE2	7825 801335	MAKSIM ZHURAVLEV	{"phone": "+70214928566"}
0005434938209	33A874	0897 471930	EKATERINA EFIMOVA	{"email": "eefimova011968@postgrespro.ru", "phone": "+70656610167"}
0005434938210	A45BF4	0453 715669	NIKOLAY KUZNECOV	{"email": "kuznecov_n-24031968@postgrespro.ru", "phone": "+70169293870"}
0005434938211	A45BF4	0892 067047	IVAN YAKOVLEV	{"phone": "+70970620034"}
0005434938212	F87E63	0407 084856	TATYANA MAKAROVA	{"phone": "+70248108515"}
0005434938213	67CAC1	8929 443190	IRAIDA KUZNECOVA	{"email": "kuznecova.i_1964@postgrespro.ru", "phone": "+70672084286"}
0005434938214	239E23	8126 029119	GALINA CHERNOVA	{"phone": "+70729793041"}
0005434938215	F6811C	6063 629602	VLADIMIR KAZAKOV	{"phone": "+70237324280"}
0005434938216	EA54C7	4629 251110	YURIY NIKOLAEV	{"email": "nikolaev-y_1983@postgrespro.ru", "phone": "+70140864251"}
0005434938217	CC017B	8069 119076	EKATERINA BELOVA	{"email": "ekaterina-belova-08081963@postgrespro.ru", "phone": "+70351896708"}
0005434938218	37529E	8031 501391	RAFAEL NOVIKOV	{"email": "rafael-novikov-25071966@postgrespro.ru", "phone": "+70894939154"}
0005434938219	37529E	8818 900424	ALEKSANDR SEMENOV	{"email": "semenovaleksandr111974@postgrespro.ru", "phone": "+70977113651"}
0005434938220	D732F2	0255 761044	NATALYA BELOVA	{"phone": "+70956856125"}
0005434938221	D732F2	7759 871647	ALEKSANDR MIRONOV	{"email": "mironov_aleksandr19111960@postgrespro.ru", "phone": "+70083465477"}
0005434938222	E8149C	3711 705316	EKATERINA VASILEVA	{"email": "e-vasileva.23121969@postgrespro.ru", "phone": "+70294752081"}
0005434938223	E8149C	3614 920912	ALEKSANDR MARTYNOV	{"email": "amartynov-19031977@postgrespro.ru", "phone": "+70140309298"}
0005434938224	BA8EA5	3745 776590	VLADIMIR POPOV	{"email": "popov_v061979@postgrespro.ru", "phone": "+70400941159"}
0005434938225	BA8EA5	7129 023070	NIKOLAY SMIRNOV	{"email": "smirnov.nikolay.1981@postgrespro.ru", "phone": "+70668104704"}
0005434938226	03EA6C	7393 897236	DMITRIY STEPANOV	{"email": "stepanov.dmitriy.071981@postgrespro.ru", "phone": "+70520116851"}
0005434938227	03EA6C	3643 275851	ALEKSEY NOVIKOV	{"email": "aleksey-novikov-1970@postgrespro.ru", "phone": "+70563839033"}
0005434938228	03EA6C	9760 487777	ELENA KUZNECOVA	{"phone": "+70743987332"}
0005434938229	2A028D	9163 858025	VITALIY FEDOTOV	{"phone": "+70973076572"}
0005434938230	61532B	5881 863261	OLGA BORISOVA	{"phone": "+70829303499"}
0005434938231	6E23DB	3906 515794	ALEKSANDR IVANOV	{"phone": "+70536923899"}
0005434938232	3B0D5A	8198 151058	ANNA TARASOVA	{"email": "anna-tarasova-19021969@postgrespro.ru", "phone": "+70235007949"}
0005434938233	ED272A	0636 178699	EVDOKIYA KUZNECOVA	{"email": "kuznecova.e_1983@postgrespro.ru", "phone": "+70609054842"}
0005434938234	ED272A	3145 515963	MARK KOROLEV	{"phone": "+70158464836"}
0005434938235	FDA7F4	8369 992288	ANATOLIY SEMENOV	{"phone": "+70047779360"}
0005434938236	351720	5575 512637	ANDREY ZHUKOV	{"phone": "+70271337536"}
0005434938237	351720	9000 262469	MAKSIM SCHERBAKOV	{"phone": "+70945036839"}
0005434938238	830D64	3679 924625	LYUDMILA SOROKINA	{"email": "sorokina-lyudmila061975@postgrespro.ru", "phone": "+70086009177"}
0005434938239	F0CB99	1273 033014	LIDIYA ANISIMOVA	{"email": "anisimova.lidiya29061968@postgrespro.ru", "phone": "+70240082486"}
0005434938240	236BF6	8347 399590	RAISA ZHURAVLEVA	{"phone": "+70032811363"}
0005434938241	9E5D61	0458 524618	FEDOR BELOV	{"email": "fedorbelov_1970@postgrespro.ru", "phone": "+70138375873"}
0005434938242	9E5D61	2128 472267	VALERIY ALEKSEEV	{"phone": "+70032552755"}
0005434938243	9C8D7F	0523 808519	PAVEL POPOV	{"email": "popov-p091981@postgrespro.ru", "phone": "+70937093134"}
0005434938244	723FBB	4304 831404	TATYANA IVANOVA	{"email": "ivanova-t011965@postgrespro.ru", "phone": "+70044621672"}
0005434938245	02A753	3045 957831	GALINA KOZLOVA	{"email": "g_kozlova_071969@postgrespro.ru", "phone": "+70014025164"}
0005434938246	C144BC	1456 114511	EVGENIY MOISEEV	{"email": "e_moiseev-031979@postgrespro.ru", "phone": "+70933986108"}
0005434938247	C144BC	1464 691942	MARGARITA MARTYNOVA	{"phone": "+70664114085"}
0005434938248	A20BBF	4592 344808	VITALIY GAVRILOV	{"phone": "+70379355218"}
0005434938249	B7FA4C	1350 174638	NIKOLAY DMITRIEV	{"phone": "+70603449190"}
0005434938250	7ACC26	0056 813525	NAILYA SOROKINA	{"phone": "+70667102514"}
0005434938309	19E1AE	3907 534411	NATALYA KISELEVA	{"phone": "+70842697660"}
0005434938251	540935	5486 606997	RUSLAN FEDOROV	{"email": "ruslan_fedorov_021974@postgrespro.ru", "phone": "+70144885515"}
0005434938252	61AF9A	5707 180791	NATALIYA PETROVA	{"email": "npetrova.121980@postgrespro.ru", "phone": "+70477514380"}
0005434938253	021904	0932 336474	MAKSIM ROMANOV	{"phone": "+70841284180"}
0005434938254	021904	9149 146302	ANTON KOROLEV	{"email": "korolev-a071978@postgrespro.ru", "phone": "+70576335105"}
0005434938255	0B3C4B	1045 547323	VIKTOR SOKOLOV	{"email": "viktor-sokolov_21031968@postgrespro.ru", "phone": "+70965564122"}
0005434938256	0B3C4B	8732 988567	ALEKSANDR ANDREEV	{"phone": "+70178190332"}
0005434938377	48F684	4009 858955	VALERIY GERASIMOV	{"phone": "+70258546899"}
0005434938257	1EA52F	7777 546204	SVETLANA ZHUKOVA	{"email": "zhukova.s121973@postgrespro.ru", "phone": "+70053793329"}
0005434938258	1EA52F	4952 615653	NIKOLAY TIKHONOV	{"email": "nikolaytikhonov_1967@postgrespro.ru", "phone": "+70074147856"}
0005434938259	F6048F	5799 208373	OLGA BARANOVA	{"email": "olga-baranova06031959@postgrespro.ru", "phone": "+70438806560"}
0005434938260	F6048F	1377 070567	SVETLANA FROLOVA	{"phone": "+70577646195"}
0005434938261	091E30	8872 113023	MARIYA VOROBEVA	{"email": "mariya.vorobeva-16041972@postgrespro.ru", "phone": "+70942233748"}
0005434938262	355456	9763 113958	OLGA VLASOVA	{"phone": "+70390857245"}
0005434938263	470F3F	3027 412456	EGOR MOROZOV	{"phone": "+70022914133"}
0005434938264	BED382	0554 648865	MARIYA VOROBEVA	{"phone": "+70895075877"}
0005434938265	9C00FA	0763 422449	GALINA IVANOVA	{"phone": "+70440225479"}
0005434938266	BA9A22	5760 399257	NINA MEDVEDEVA	{"email": "medvedeva_nina_1963@postgrespro.ru", "phone": "+70094933370"}
0005434938267	3EAA32	4806 591922	SERGEY TIMOFEEV	{"phone": "+70568418994"}
0005434938268	3EAA32	9271 612433	LILIYA KOROLEVA	{"email": "koroleva.l-18111972@postgrespro.ru", "phone": "+70216180603"}
0005434938269	944DCE	5446 958654	TATYANA ROMANOVA	{"phone": "+70929089080"}
0005434938270	999BC2	4088 915288	VERA FOMINA	{"phone": "+70799605786"}
0005434938271	999BC2	2786 956599	ALEKSEY ANDREEV	{"phone": "+70224302811"}
0005434938272	2FA74A	1591 559394	LYUBOV RODIONOVA	{"email": "rodionova-l.11011963@postgrespro.ru", "phone": "+70012916937"}
0005434938273	B50D5C	5500 000062	NADEZHDA GORBUNOVA	{"phone": "+70292007390"}
0005434938274	7353AC	4630 982114	LYUDMILA NESTEROVA	{"email": "nesterova_l031965@postgrespro.ru", "phone": "+70668879916"}
0005434938275	7353AC	7236 964418	YURIY AFANASEV	{"email": "yuriyafanasev-1968@postgrespro.ru", "phone": "+70755191960"}
0005434938276	0579B8	0095 699246	NIKOLAY FEDOTOV	{"email": "nikolay.fedotov_1965@postgrespro.ru", "phone": "+70441353434"}
0005434938277	379C00	3169 043370	DANIL ISAEV	{"email": "isaev_d-29011967@postgrespro.ru", "phone": "+70780104734"}
0005434938278	379C00	6296 943420	DMITRIY FEDOROV	{"email": "dmitriy_fedorov081968@postgrespro.ru", "phone": "+70694492661"}
0005434938279	CCE84E	9005 750897	ILNUR MAKAROV	{"email": "i_makarov111967@postgrespro.ru", "phone": "+70573377250"}
0005434938280	AF82C1	5134 423734	ELENA ARKHIPOVA	{"email": "arkhipovaelena.081974@postgrespro.ru", "phone": "+70795967803"}
0005434938281	CF9300	2920 705785	DMITRIY KUZNECOV	{"email": "kuznecovd-14011975@postgrespro.ru", "phone": "+70801952800"}
0005434938282	CF9300	3888 950065	GALINA KOZLOVA	{"email": "galina_kozlova_25101986@postgrespro.ru", "phone": "+70434386799"}
0005434938283	9E32A2	8106 260195	MARIYA ZOTOVA	{"phone": "+70318981558"}
0005434938284	A23CBA	2954 214441	DMITRIY STEPANOV	{"email": "d_stepanov.121968@postgrespro.ru", "phone": "+70420029902"}
0005434938285	B9E60D	7261 610891	VLADIMIR YAKOVLEV	{"email": "vladimiryakovlev021975@postgrespro.ru", "phone": "+70493933985"}
0005434938286	B9E60D	0426 208022	TATYANA MATVEEVA	{"email": "t_matveeva_21121978@postgrespro.ru", "phone": "+70604362403"}
0005434938287	BACCBB	6979 757316	TATYANA VASILEVA	{"email": "t_vasileva_1977@postgrespro.ru", "phone": "+70839838408"}
0005434938288	3C4B11	2305 804392	IRINA MIRONOVA	{"phone": "+70953079321"}
0005434938289	A83ADD	7711 245008	SERAFIMA KOMAROVA	{"email": "serafimakomarova-09071969@postgrespro.ru", "phone": "+70367278965"}
0005434938290	B81E8D	6304 301338	ANTON IVANOV	{"email": "ivanov.anton_011972@postgrespro.ru", "phone": "+70812884341"}
0005434938291	3F4366	4314 948836	SVETLANA MARTYNOVA	{"email": "s-martynova-1975@postgrespro.ru", "phone": "+70884583201"}
0005434938292	A92AEB	0563 020333	GALINA POLYAKOVA	{"phone": "+70488765872"}
0005434938293	114CCA	1753 330934	EVGENIYA ORLOVA	{"email": "e_orlova_13031973@postgrespro.ru", "phone": "+70873770097"}
0005434938294	F6694D	0062 824191	SANIYA KISELEVA	{"email": "skiseleva.22021974@postgrespro.ru", "phone": "+70702142431"}
0005434938295	212C51	7426 507293	ANASTASIYA KOROLEVA	{"email": "anastasiya-koroleva1985@postgrespro.ru", "phone": "+70332932567"}
0005434938296	CC882B	2477 882472	RAVIL TIMOFEEV	{"email": "timofeev_r-051972@postgrespro.ru", "phone": "+70877448440"}
0005434938297	CC882B	6224 855818	ANATOLIY ILIN	{"phone": "+70117170076"}
0005434938298	376FE7	7683 833520	VALERIY SEMENOV	{"email": "semenov_valeriy_08091967@postgrespro.ru", "phone": "+70331936355"}
0005434938299	376FE7	5817 677677	TATYANA NIKITINA	{"email": "nikitina_t_051973@postgrespro.ru", "phone": "+70933428405"}
0005434938300	43F9B3	3474 583853	ANNA TIMOFEEVA	{"email": "a-timofeeva051983@postgrespro.ru", "phone": "+70818554059"}
0005434938301	43F9B3	4415 690010	LYUBOV ANISIMOVA	{"email": "lyubov-anisimova1975@postgrespro.ru", "phone": "+70102785703"}
0005434938302	A69ADA	8467 352900	YAROSLAV KONOVALOV	{"email": "konovalov.y.05061982@postgrespro.ru", "phone": "+70664157132"}
0005434938303	A69ADA	3647 501705	YULIYA LAZAREVA	{"phone": "+70903258372"}
0005434938304	7AB45F	7352 034702	ALEKSANDR KARPOV	{"email": "karpov.aleksandr_071979@postgrespro.ru", "phone": "+70611770420"}
0005434938305	7AB45F	5513 639287	ALIYA MARTYNOVA	{"phone": "+70133687423"}
0005434938306	7AB45F	4451 999637	VLADIMIR ZAKHAROV	{"phone": "+70828644608"}
0005434938307	884BCA	2033 109903	VIKTOR GUSEV	{"email": "gusevviktor_1967@postgrespro.ru", "phone": "+70520921838"}
0005434938308	19E1AE	5187 545031	ELVIRA SOLOVEVA	{"phone": "+70635891972"}
0005434938310	A04751	9551 522247	SERGEY ISAEV	{"phone": "+70201032415"}
0005434938311	7DD1E9	6775 935652	TATYANA BELYAEVA	{"phone": "+70416127009"}
0005434938312	FA14E7	6877 119886	ELENA TIMOFEEVA	{"email": "e_timofeeva04011984@postgrespro.ru", "phone": "+70342833359"}
0005434938313	FA14E7	3070 930004	ANNA ERMAKOVA	{"email": "ermakova.a_1977@postgrespro.ru", "phone": "+70405708192"}
0005434938314	B79DBB	0224 817697	NINA EGOROVA	{"phone": "+70883900221"}
0005434938315	1B7DFD	0828 806026	YURIY IVANOV	{"phone": "+70553163582"}
0005434938316	0AA500	5115 069269	TAMARA KOZLOVA	{"phone": "+70963065514"}
0005434938318	6B43CD	3357 651091	VLADIMIR GRIGOREV	{"email": "grigorev.v12091976@postgrespro.ru", "phone": "+70445654196"}
0005434938319	87B3F2	9479 785824	TATYANA ARKHIPOVA	{"phone": "+70589692524"}
0005434938320	87B3F2	6604 899510	SERGEY ILIN	{"email": "s-ilin.091960@postgrespro.ru", "phone": "+70244500125"}
0005434938321	7CC9E7	0074 193205	NATALYA GORBUNOVA	{"email": "gorbunovan.24121975@postgrespro.ru", "phone": "+70228336863"}
0005434938322	7CC9E7	9989 034031	OLGA SIDOROVA	{"phone": "+70371099763"}
0005434938323	6E6343	4210 417794	MARAT OSIPOV	{"email": "osipov_m21021974@postgrespro.ru", "phone": "+70142635463"}
0005434938324	6E6343	4432 375385	NATALYA ZAYCEVA	{"phone": "+70828308201"}
0005434938325	D0BF2F	8519 090092	LYUDMILA KOZLOVA	{"email": "lyudmila-kozlova-25041970@postgrespro.ru", "phone": "+70682634498"}
0005434938326	F28710	1910 011860	VERA STEPANOVA	{"email": "stepanova.vera02041972@postgrespro.ru", "phone": "+70841361457"}
0005434938327	F78062	5953 226771	ILYA FILIPPOV	{"email": "i-filippov_091957@postgrespro.ru", "phone": "+70378767657"}
0005434938328	59FD61	8997 663518	VLADISLAV PETROV	{"phone": "+70743594875"}
0005434938329	52E0B6	5573 449276	TATYANA KOROLEVA	{"phone": "+70115397598"}
0005434938330	020BB8	8847 974199	ANASTASIYA RYABOVA	{"email": "ryabova_a_13101975@postgrespro.ru", "phone": "+70488788900"}
0005434938331	020BB8	6197 487969	ANNA MOISEEVA	{"email": "moiseevaa.1975@postgrespro.ru", "phone": "+70132751832"}
0005434938332	34BF9E	2804 968030	ALENA MATVEEVA	{"email": "alena-matveeva_1966@postgrespro.ru", "phone": "+70250344258"}
0005434938333	4F63BF	0432 394264	VLADIMIR NOVIKOV	{"phone": "+70163930589"}
0005434938334	28D5C4	6648 275553	ALEKSEY VASILEV	{"phone": "+70898025570"}
0005434938335	7EB56F	4196 572774	NIKITA NAUMOV	{"email": "nikita_naumov091974@postgrespro.ru", "phone": "+70212320347"}
0005434938336	A29CDF	7857 029693	MARINA FADEEVA	{"email": "fadeeva_m011964@postgrespro.ru", "phone": "+70182637159"}
0005434938337	91AC72	9694 348200	YURIY ANDREEV	{"phone": "+70926871844"}
0005434938338	F2E802	0075 383750	OLEG ROMANOV	{"email": "o_romanov.11061973@postgrespro.ru", "phone": "+70353025889"}
0005434938339	F68C0A	9463 269177	EKATERINA TROFIMOVA	{"phone": "+70538780663"}
0005434938340	4284FF	3443 912071	ELENA EFREMOVA	{"email": "elena.efremova081972@postgrespro.ru", "phone": "+70336183658"}
0005434938341	459412	7791 353825	EVGENIY ABRAMOV	{"email": "abramov.evgeniy-031977@postgrespro.ru", "phone": "+70348269455"}
0005434938342	F8C885	3477 743651	GALINA FROLOVA	{"phone": "+70399657800"}
0005434938343	F8C885	8837 692516	NIKOLAY KUZMIN	{"phone": "+70806131282"}
0005434938344	D9EDE0	2812 425552	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr-041958@postgrespro.ru", "phone": "+70751904429"}
0005434938345	5F65F4	9246 929370	ZINAIDA MATVEEVA	{"phone": "+70049740984"}
0005434938346	DFC1A3	2094 385348	ARSENIY MARTYNOV	{"email": "martynov_a_1962@postgrespro.ru", "phone": "+70108004040"}
0005434938347	CDBAED	7236 214783	KONSTANTIN ORLOV	{"phone": "+70855109722"}
0005434938348	CDBAED	2744 027065	ALEKSANDR FOMIN	{"phone": "+70310292130"}
0005434938349	7948B7	3378 220645	VIKTOR SIDOROV	{"email": "sidorov_v_1976@postgrespro.ru", "phone": "+70091051757"}
0005434938350	7948B7	5385 384951	NIKITA ROMANOV	{"email": "romanovn-1963@postgrespro.ru", "phone": "+70198530629"}
0005434938351	DF52F4	8254 497014	OLGA SOKOLOVA	{"phone": "+70561843100"}
0005434938352	DF52F4	5853 695725	SVETLANA LOGINOVA	{"email": "s-loginova-1970@postgrespro.ru", "phone": "+70762314406"}
0005434938353	9B0A56	4166 343718	NIKOLAY POPOV	{"phone": "+70889859077"}
0005434938354	E30297	9916 482833	DMITRIY GRIGOREV	{"email": "grigorev.d.061964@postgrespro.ru", "phone": "+70256656274"}
0005434938355	6129A5	6772 300038	ANATOLIY EGOROV	{"email": "egorov-a_18081967@postgrespro.ru", "phone": "+70312963587"}
0005434938356	8E6996	8265 975131	SERGEY GAVRILOV	{"email": "sergeygavrilov.20091965@postgrespro.ru", "phone": "+70772825812"}
0005434938357	8E6996	0937 528855	NATALYA BOGDANOVA	{"email": "bogdanova-natalya_1965@postgrespro.ru", "phone": "+70375322426"}
0005434938358	BF34B4	1387 072483	YURIY VASILEV	{"email": "yuriy.vasilev24091961@postgrespro.ru", "phone": "+70242476985"}
0005434938359	BF34B4	7417 632117	KARINA MOISEEVA	{"phone": "+70534307679"}
0005434938360	F9F6D5	5074 429758	IVAN KONOVALOV	{"email": "konovalov_ivan-08111959@postgrespro.ru", "phone": "+70182698326"}
0005434938361	F9F6D5	4645 793908	SVETLANA POPOVA	{"email": "popova_svetlana_071973@postgrespro.ru", "phone": "+70368959999"}
0005434938362	F9F6D5	2584 613548	VYACHESLAV IVANOV	{"phone": "+70104779772"}
0005434938363	FB6C47	0826 381208	DMITRIY ZAYCEV	{"email": "zaycev_dmitriy.121971@postgrespro.ru", "phone": "+70068891536"}
0005434938364	FB6C47	2946 716937	MARIYA KUZMINA	{"email": "m-kuzmina29121970@postgrespro.ru", "phone": "+70871899998"}
0005434938365	AD8B4C	7122 239316	IVAN ZAKHAROV	{"phone": "+70155009678"}
0005434938366	A94DF9	2915 456570	VLADIMIR VOLKOV	{"phone": "+70168690128"}
0005434938367	1467BD	8689 111504	VYACHESLAV MOISEEV	{"email": "v-moiseev.101966@postgrespro.ru", "phone": "+70145892661"}
0005434938368	1467BD	5796 424757	SERGEY FILIPPOV	{"email": "filippov.s-06121974@postgrespro.ru", "phone": "+70791630241"}
0005434938369	308C26	4992 289969	ELENA PETROVA	{"email": "e_petrova_1964@postgrespro.ru", "phone": "+70420726465"}
0005434938370	308C26	1707 534335	VIKTOR NAUMOV	{"email": "v-naumov-1973@postgrespro.ru", "phone": "+70952966628"}
0005434938371	3AEA7B	1460 441625	VALENTINA OVCHINNIKOVA	{"phone": "+70941532241"}
0005434938372	781AAB	1744 192732	EKATERINA LOGINOVA	{"phone": "+70560798974"}
0005434938373	B772CB	5172 907370	MAKSIM SMIRNOV	{"phone": "+70594463600"}
0005434938374	5FEF78	1498 699350	TATYANA IVANOVA	{"phone": "+70559201412"}
0005434938375	471606	6070 649884	GALINA NAZAROVA	{"email": "nazarova.galina.011969@postgrespro.ru", "phone": "+70472012407"}
0005434938376	471606	8285 442631	VLADIMIR SERGEEV	{"email": "sergeev_v021975@postgrespro.ru", "phone": "+70966858829"}
0005434938378	48F684	7613 153072	MARINA ZOTOVA	{"phone": "+70525593962"}
0005434938379	C2C40E	5544 233178	PETR NOVIKOV	{"email": "p.novikov-121962@postgrespro.ru", "phone": "+70649791891"}
0005434938380	A891FF	2541 234300	ELENA POPOVA	{"email": "elena-popova.09071975@postgrespro.ru", "phone": "+70122539555"}
0005434938381	A891FF	9814 408539	MARIYA SMIRNOVA	{"email": "m_smirnova_091969@postgrespro.ru", "phone": "+70451575150"}
0005434938382	A891FF	3022 947651	ALEKSEY MOISEEV	{"email": "moiseev_a-30101970@postgrespro.ru", "phone": "+70698231562"}
0005434938383	9C28BF	6006 581661	ALEKSEY AFANASEV	{"email": "aleksey-afanasev.27041967@postgrespro.ru", "phone": "+70866430605"}
0005434938384	6BA2BF	6651 746563	ELVIRA PAVLOVA	{"email": "elvira_pavlova1976@postgrespro.ru", "phone": "+70043633146"}
0005434938385	99A208	5636 103968	NIKOLAY VASILEV	{"phone": "+70327285250"}
0005434938386	A2E66C	7349 497486	NIKITA KARPOV	{"phone": "+70755730118"}
0005434938387	EC17E2	2033 467649	ZOYA GERASIMOVA	{"phone": "+70387973911"}
0005434938388	8FAA31	9196 758172	DMITRIY PETROV	{"email": "petrov.dmitriy28091970@postgrespro.ru", "phone": "+70814668042"}
0005434938389	8FAA31	3687 706825	VIKTOR KONOVALOV	{"phone": "+70331244901"}
0005434938390	38B994	8747 133169	OLGA SIDOROVA	{"email": "sidorova_o-02101966@postgrespro.ru", "phone": "+70417397415"}
0005434938391	B557D7	7589 426854	ALEKSANDR IVANOV	{"email": "ivanov.a_111980@postgrespro.ru", "phone": "+70737591996"}
0005434938392	00EAC4	1952 004670	RUSLAN SCHERBAKOV	{"email": "r.scherbakov-091974@postgrespro.ru", "phone": "+70669927441"}
0005434938393	5D6B97	6368 108781	ANASTASIYA MOISEEVA	{"phone": "+70841625539"}
0005434938394	F9DDE1	7585 556935	SERGEY BONDARENKO	{"phone": "+70624383678"}
0005434938395	F9DDE1	0377 725240	MAKAR GRIGOREV	{"phone": "+70291625806"}
0005434938396	F9DDE1	1718 882802	ALEKSEY SCHERBAKOV	{"email": "scherbakov.a.091979@postgrespro.ru", "phone": "+70693398918"}
0005434938397	13B251	3802 094714	DMITRIY MIRONOV	{"phone": "+70861635556"}
0005434938398	933223	4854 858795	LYUDMILA ZHUKOVA	{"email": "l-zhukova1982@postgrespro.ru", "phone": "+70320547399"}
0005434938399	933223	7191 620440	MIKHAIL MATVEEV	{"phone": "+70975187857"}
0005434938400	ADA77F	5684 979398	VLADIMIR KUDRYASHOV	{"phone": "+70719468149"}
0005434938401	BA08DA	7338 127300	YULIYA KOMAROVA	{"phone": "+70684786301"}
0005434938402	5106BA	6239 432176	VYACHESLAV KUDRYASHOV	{"email": "v-kudryashov-101982@postgrespro.ru", "phone": "+70290187218"}
0005434938403	6D287C	1455 860685	SVETLANA ANDREEVA	{"email": "andreeva_s_101973@postgrespro.ru", "phone": "+70848302352"}
0005434938404	6D287C	4548 139236	IRINA KONDRATEVA	{"email": "i-kondrateva-1969@postgrespro.ru", "phone": "+70032943016"}
0005434938405	B98286	6405 329763	ELENA NIKOLAEVA	{"email": "nikolaeva.e_091973@postgrespro.ru", "phone": "+70187268134"}
0005434938406	B98286	8005 929425	YANA AKIMOVA	{"email": "akimova_y.1971@postgrespro.ru", "phone": "+70832828718"}
0005434938407	DF956D	4692 863968	GALINA STEPANOVA	{"email": "stepanova.galina_111972@postgrespro.ru", "phone": "+70968024382"}
0005434938408	7326B8	2691 466300	IRINA FOMINA	{"email": "irina-fomina_1975@postgrespro.ru", "phone": "+70514736990"}
0005434938409	EF1BE6	4574 052194	VLADIMIR BORISOV	{"email": "v.borisov.1973@postgrespro.ru", "phone": "+70587123410"}
0005434938410	00860F	5076 174465	IVAN TIMOFEEV	{"email": "timofeevivan-25101970@postgrespro.ru", "phone": "+70909310154"}
0005434938411	E4AFC2	3030 019159	ARTEM MIKHAYLOV	{"email": "a.mikhaylov-14031970@postgrespro.ru", "phone": "+70568228114"}
0005434938412	7C9640	5696 880182	MAKSIM DMITRIEV	{"email": "maksim.dmitriev1976@postgrespro.ru", "phone": "+70488650706"}
0005434938413	FC3E48	7991 069807	NINA VOLKOVA	{"email": "n-volkova-19041976@postgrespro.ru", "phone": "+70197747519"}
0005434938414	FC3E48	6421 412707	VLADIMIR SEMENOV	{"email": "semenov-v-1982@postgrespro.ru", "phone": "+70483118561"}
0005434938415	C1FC42	2167 230689	MATVEY SHEVCHENKO	{"email": "matvey_shevchenko.22031973@postgrespro.ru", "phone": "+70578609110"}
0005434938416	C1FC42	4081 236402	NIKOLAY ORLOV	{"email": "orlov-nikolay-1973@postgrespro.ru", "phone": "+70591563339"}
0005434938417	C1FC42	4275 580397	ALENA MELNIKOVA	{"phone": "+70367267025"}
0005434938418	A01C35	7642 187365	OLEG ORLOV	{"email": "orlovoleg_03061972@postgrespro.ru", "phone": "+70091684601"}
0005434938419	2A4511	0060 049912	ALEKSANDR VASILEV	{"email": "vasileva09031973@postgrespro.ru", "phone": "+70481647665"}
0005434938420	DB37A2	4499 739832	NIKOLAY VASILEV	{"phone": "+70745740637"}
0005434938421	F3D8AA	7168 064567	NADEZHDA STEPANOVA	{"phone": "+70534335914"}
0005434938422	F3D8AA	5882 139575	ALEKSANDR NAUMOV	{"phone": "+70327328850"}
0005434938423	F3D8AA	5982 913284	MARGARITA PAVLOVA	{"phone": "+70845595649"}
0005434938424	F54EB1	9936 512250	DMITRIY KUZNECOV	{"phone": "+70343321596"}
0005434938425	580DB8	8383 820493	KSENIYA BORISOVA	{"email": "borisova-kseniya-011983@postgrespro.ru", "phone": "+70197675835"}
0005434938426	F523BB	7499 113990	ALESYA SMIRNOVA	{"phone": "+70603526860"}
0005434938427	F523BB	8868 976002	LYUDMILA VASILEVA	{"email": "l.vasileva-071971@postgrespro.ru", "phone": "+70013636126"}
0005434938428	7BC4C7	5939 220872	DMITRIY ROMANOV	{"email": "dromanov.061971@postgrespro.ru", "phone": "+70468635035"}
0005434938429	AABC07	0772 735082	ARTEM VOLKOV	{"email": "a-volkov.1961@postgrespro.ru", "phone": "+70842636558"}
0005434938430	947B85	6771 801529	SERGEY PAVLOV	{"email": "pavlov_s-121972@postgrespro.ru", "phone": "+70203351295"}
0005434938431	D94799	2909 535256	ANATOLIY FEDOTOV	{"phone": "+70452473118"}
0005434938432	D94799	2200 836729	ANDREY NAUMOV	{"phone": "+70207939316"}
0005434938433	455812	5940 082492	ALEKSEY VASILEV	{"email": "avasilev-081973@postgrespro.ru", "phone": "+70558530677"}
0005434938434	5399DB	9778 862826	IRINA PETROVA	{"phone": "+70122072065"}
0005434938435	5399DB	9562 792278	VITALIY GAVRILOV	{"phone": "+70942259896"}
0005434938436	9D157D	4667 257674	VALERIY NOVIKOV	{"email": "novikov_valeriy-011969@postgrespro.ru", "phone": "+70367422357"}
0005434938437	8074AB	5677 170155	MIKHAIL TIKHONOV	{"phone": "+70923578111"}
0005434938438	4E7E81	3196 037129	MARIYA KUZNECOVA	{"phone": "+70484395020"}
0005434938439	4E7E81	0057 805056	NINA IVANOVA	{"email": "ivanova-nina.24021968@postgrespro.ru", "phone": "+70089871426"}
0005434938440	4E7E81	0636 674678	VIKTOR SOKOLOV	{"email": "viktor.sokolov_1966@postgrespro.ru", "phone": "+70735915469"}
0005434938441	C6C6E5	8095 245736	TATYANA EGOROVA	{"phone": "+70230407155"}
0005434938442	AD3DA6	8522 418654	EVELINA GRISHINA	{"phone": "+70802104015"}
0005434938443	F4D1F9	8266 482848	ANASTASIYA EGOROVA	{"phone": "+70379073337"}
0005434938444	F4D1F9	0955 205893	VADIM SCHERBAKOV	{"phone": "+70393686621"}
0005434938445	C2BC20	6228 655444	VYACHESLAV ANTONOV	{"email": "antonov-v_06021974@postgrespro.ru", "phone": "+70801108962"}
0005434938446	C52FB0	5775 092768	LYUBOV DAVYDOVA	{"phone": "+70512289690"}
0005434938447	C8A61E	0877 986136	ALEKSEY KUZMIN	{"email": "aleksey-kuzmin_1974@postgrespro.ru", "phone": "+70346691236"}
0005434938448	41DD0D	0728 148350	VERA OVCHINNIKOVA	{"email": "ovchinnikovavera071963@postgrespro.ru", "phone": "+70848211610"}
0005434938449	305641	1590 031796	EKATERINA MIRONOVA	{"email": "mironova_ekaterina.071973@postgrespro.ru", "phone": "+70948209415"}
0005434938450	8B0C7D	9550 255274	EKATERINA KUDRYASHOVA	{"email": "ekudryashova1971@postgrespro.ru", "phone": "+70183227919"}
0005434938451	AD2499	5738 348001	KONSTANTIN NIKOLAEV	{"phone": "+70180914226"}
0005434938452	12F85F	5311 416234	ALEKSANDR MOROZOV	{"email": "morozova-26101971@postgrespro.ru", "phone": "+70310184855"}
0005434938453	836A5C	5338 297561	IVAN KONOVALOV	{"email": "ikonovalov_071970@postgrespro.ru", "phone": "+70593309494"}
0005434938454	71299A	2372 545534	LYUBOV DANILOVA	{"phone": "+70016582158"}
0005434938455	77B91B	5732 188504	ANDREY ZAKHAROV	{"email": "zakharov.andrey.051968@postgrespro.ru", "phone": "+70528552102"}
0005434938456	7F534A	7572 721176	NIKOLAY SIDOROV	{"phone": "+70403597911"}
0005434938457	1AA363	5118 322415	NADEZHDA KUZNECOVA	{"email": "n_kuznecova_21031981@postgrespro.ru", "phone": "+70491137236"}
0005434938458	AFE27D	0377 269423	SVETLANA KISELEVA	{"phone": "+70752719055"}
0005434938459	051E6E	2159 415393	MARGARITA TROFIMOVA	{"email": "trofimova-margarita_1976@postgrespro.ru", "phone": "+70134715519"}
0005434938460	051E6E	7075 085115	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova11051971@postgrespro.ru", "phone": "+70813454509"}
0005434938461	D68A6A	3892 618134	LYUBOV DANILOVA	{"email": "danilovalyubov-28071970@postgrespro.ru", "phone": "+70712698251"}
0005434938462	B2875F	1346 489655	ANDREY EGOROV	{"phone": "+70783840202"}
0005434938463	29C7F5	4766 688804	VERA OSIPOVA	{"phone": "+70391847250"}
0005434938464	7F3391	8656 070295	LEONID MARTYNOV	{"email": "l.martynov1968@postgrespro.ru", "phone": "+70101561230"}
0005434938465	1260CB	4049 184482	RUFIYA KUZNECOVA	{"email": "rufiya-kuznecova_1972@postgrespro.ru", "phone": "+70955263638"}
0005434938466	92D12C	2951 549895	MAKSIM SHEVCHENKO	{"email": "shevchenko.m.1981@postgrespro.ru", "phone": "+70684722689"}
0005434938467	75E89E	0584 846944	NIKOLAY ZAYCEV	{"email": "n.zaycev_051973@postgrespro.ru", "phone": "+70446070834"}
0005434938468	462408	2817 559256	VERA NIKOLAEVA	{"phone": "+70269861988"}
0005434938469	BEF260	2976 482994	ALEKSANDR KOZLOV	{"email": "kozlova.1975@postgrespro.ru", "phone": "+70970664501"}
0005434938470	0F57B3	1098 693512	EKATERINA STEPANOVA	{"email": "ekaterina_stepanova111970@postgrespro.ru", "phone": "+70561243276"}
0005434938471	401D34	9875 713058	SERGEY KUZNECOV	{"email": "kuznecovs.18031965@postgrespro.ru", "phone": "+70418523561"}
0005434938472	3836A3	1231 904033	DMITRIY ORLOV	{"phone": "+70265560236"}
0005434938473	D48818	5753 877002	ZULFIYA KALININA	{"email": "z-kalinina.1962@postgrespro.ru", "phone": "+70617400487"}
0005434938474	C0C0E9	3271 703792	ALEKSANDR SCHERBAKOV	{"phone": "+70140481789"}
0005434938475	C0C0E9	0308 987299	LYUDMILA KAZAKOVA	{"email": "lyudmila-kazakova-25011975@postgrespro.ru", "phone": "+70245830129"}
0005434938476	2D123C	4546 165617	DMITRIY SOROKIN	{"phone": "+70101577417"}
0005434938477	D16B71	2744 556252	IRINA FROLOVA	{"phone": "+70148897331"}
0005434938478	D16B71	5543 564590	ELENA NESTEROVA	{"phone": "+70315835708"}
0005434938479	CA8A1F	4664 107011	GALINA KUZNECOVA	{"email": "kuznecovagalina_1974@postgrespro.ru", "phone": "+70619364499"}
0005434938480	CA8A1F	3988 723004	ALEKSEY KUZNECOV	{"phone": "+70092270199"}
0005434938481	F6998E	0564 337161	VLADIMIR KUZNECOV	{"email": "kuznecovv_10061975@postgrespro.ru", "phone": "+70698281160"}
0005434938482	81F920	2978 323190	SERGEY GORBUNOV	{"email": "sergey_gorbunov-091983@postgrespro.ru", "phone": "+70660059843"}
0005434938483	CA3A52	4425 821585	PAVEL NAZAROV	{"phone": "+70525715352"}
0005434938484	9D55E5	9759 057416	NINA BELYAEVA	{"email": "belyaeva.n_01091975@postgrespro.ru", "phone": "+70110579577"}
0005434938485	18DD4B	7711 552813	GAGIK TIKHONOV	{"phone": "+70592920886"}
0005434938486	A8ED5C	0558 454258	IRINA PETROVA	{"email": "irina_petrova_09101974@postgrespro.ru", "phone": "+70182577118"}
0005434938487	A8ED5C	9174 366596	ANNA KUZNECOVA	{"email": "anna_kuznecova051969@postgrespro.ru", "phone": "+70390802771"}
0005434938488	64F615	1661 550620	BORIS POPOV	{"email": "bpopov1973@postgrespro.ru", "phone": "+70492862923"}
0005434938489	64F615	9555 059105	VERA VASILEVA	{"phone": "+70146832221"}
0005434938490	840A6D	6124 752907	MARIYA POLYAKOVA	{"email": "polyakovam-011975@postgrespro.ru", "phone": "+70465150087"}
0005434938491	840A6D	0200 717395	ANDREY PETROV	{"email": "petrovandrey101970@postgrespro.ru", "phone": "+70034660350"}
0005434938492	DE2D03	8795 032135	OKSANA KOROLEVA	{"phone": "+70417083040"}
0005434938493	DE2D03	7325 504428	KIRILL SCHERBAKOV	{"email": "scherbakov-k061973@postgrespro.ru", "phone": "+70753886789"}
0005434938494	37EE29	8697 103081	MARINA POTAPOVA	{"email": "potapova_marina_1969@postgrespro.ru", "phone": "+70802027740"}
0005434938495	37EE29	1983 537449	ANDREY PAVLOV	{"phone": "+70803282703"}
0005434938496	5170D1	4900 650508	GALINA VOLKOVA	{"email": "volkova_galina-1979@postgrespro.ru", "phone": "+70624903068"}
0005434938497	E22059	4938 382398	GALINA NIKOLAEVA	{"phone": "+70632319391"}
0005434938498	E22059	8732 332857	EKATERINA FROLOVA	{"email": "frolova_ekaterina_02011963@postgrespro.ru", "phone": "+70966795846"}
0005434938499	AD61E6	9220 694226	GALINA LEBEDEVA	{"phone": "+70610970157"}
0005434938500	51E85C	8961 876360	VITALIY MOROZOV	{"email": "vitaliy.morozov.12111968@postgrespro.ru", "phone": "+70745388085"}
0005434938501	630962	0347 803802	NATALYA VLASOVA	{"phone": "+70744272669"}
0005434938502	13A699	1498 150294	OLGA POPOVA	{"phone": "+70448179968"}
0005434938503	13A699	1615 450551	VALENTINA STEPANOVA	{"email": "stepanova-v_1969@postgrespro.ru", "phone": "+70274495051"}
0005434938504	F1B10C	0572 662381	NATALYA MAKAROVA	{"phone": "+70549311776"}
0005434938505	18A90C	5396 967935	EVGENIYA NIKOLAEVA	{"phone": "+70306276153"}
0005434938506	CB72F2	4664 669835	TATYANA SMIRNOVA	{"email": "smirnova_tatyana_22101967@postgrespro.ru", "phone": "+70032624980"}
0005434938507	5A2DAC	7809 515280	ALEKSEY MIKHAYLOV	{"phone": "+70709570942"}
0005434938508	5A2DAC	5058 793093	LIDIYA LOGINOVA	{"email": "loginova-l-17031976@postgrespro.ru", "phone": "+70356738918"}
0005434938509	2870C5	1118 248179	RAISA KUDRYASHOVA	{"email": "kudryashova-raisa_011972@postgrespro.ru", "phone": "+70668013543"}
0005434938510	2870C5	8863 073311	ALEKSANDR KISELEV	{"phone": "+70562997359"}
0005434938511	9E2FFE	0165 475622	VALERIY SCHERBAKOV	{"phone": "+70426406509"}
0005434938512	9E2FFE	3418 609961	VASILIY TARASOV	{"phone": "+70149722090"}
0005434938513	7D101A	5735 455409	MARINA ISAEVA	{"email": "m_isaeva_121972@postgrespro.ru", "phone": "+70569009994"}
0005434938514	384ADA	1679 545508	MAKAR NIKITIN	{"email": "makar-nikitin_1989@postgrespro.ru", "phone": "+70212237444"}
0005434938515	384ADA	0369 658849	LYUDMILA NIKITINA	{"phone": "+70648904422"}
0005434938516	631CF7	7882 739965	ALEKSANDR SEMENOV	{"email": "semenov_aleksandr-01081971@postgrespro.ru", "phone": "+70137272975"}
0005434938517	631CF7	5947 773104	NADEZHDA DANILOVA	{"email": "danilova.nadezhda-081976@postgrespro.ru", "phone": "+70710493459"}
0005434938518	00C8B6	3853 786003	ALSU SERGEEVA	{"phone": "+70991703386"}
0005434938519	00C8B6	4037 379770	SEMEN KUZMIN	{"email": "kuzmin-s-1972@postgrespro.ru", "phone": "+70332794220"}
0005434938520	25E60B	9008 057251	ROMAN POPOV	{"email": "popovr_1964@postgrespro.ru", "phone": "+70888423823"}
0005434938521	25E60B	2057 296372	MARIYA POPOVA	{"email": "popova.mariya1970@postgrespro.ru", "phone": "+70899113366"}
0005434938522	4C8CB8	7184 553024	DMITRIY PETROV	{"phone": "+70655058875"}
0005434938523	4C8CB8	7236 567791	DANIL MAKAROV	{"phone": "+70367451922"}
0005434938524	69E9F7	2300 808695	OLGA SMIRNOVA	{"email": "smirnova.olga_19011966@postgrespro.ru", "phone": "+70529356711"}
0005434938525	C3F5E3	4952 796291	MIKHAIL KONOVALOV	{"phone": "+70263976563"}
0005434938526	27DB3F	1894 756618	VERONIKA FROLOVA	{"phone": "+70517276334"}
0005434938527	27DB3F	6714 541343	VLADISLAV ORLOV	{"phone": "+70684774238"}
0005434938528	8B1B42	1235 980722	LYUDMILA FROLOVA	{"email": "l-frolova_20081984@postgrespro.ru", "phone": "+70488360827"}
0005434938529	0B0E05	3254 242453	SVETLANA LOGINOVA	{"email": "loginova-svetlana1979@postgrespro.ru", "phone": "+70726583135"}
0005434938530	0B0E05	3653 591928	ARTUR ZAYCEV	{"phone": "+70465550771"}
0005434938531	DC70A9	2115 423057	VLADIMIR KUZNECOV	{"email": "kuznecovv-021966@postgrespro.ru", "phone": "+70283139984"}
0005434938532	71C244	7401 575428	NATALYA STEPANOVA	{"email": "stepanova_n_23011976@postgrespro.ru", "phone": "+70045263386"}
0005434938533	5AD041	1411 554166	GLEB PETROV	{"email": "petrov-g.1978@postgrespro.ru", "phone": "+70400699871"}
0005434938534	5AD041	4238 563699	NATALYA ZAKHAROVA	{"phone": "+70565150212"}
0005434938535	D76236	5782 327629	VYACHESLAV POPOV	{"email": "v-popov1966@postgrespro.ru", "phone": "+70340330907"}
0005434938536	10EE9E	8442 534016	ELIZAVETA LOGINOVA	{"phone": "+70492789731"}
0005434938537	0231D4	8170 020480	RUSLAN BORISOV	{"phone": "+70374811148"}
0005434938538	0FC8E0	4264 041368	VYACHESLAV KUZMIN	{"email": "v.kuzmin_19021966@postgrespro.ru", "phone": "+70897631583"}
0005434938539	0FC8E0	0768 019028	MARIYA IVANOVA	{"phone": "+70452777388"}
0005434938540	521E85	7821 477021	ANDREY ANTONOV	{"email": "antonov-a_101988@postgrespro.ru", "phone": "+70652780123"}
0005434938541	4476E1	0039 869356	ANASTASIYA MELNIKOVA	{"phone": "+70471483445"}
0005434938542	4CE45E	9403 636874	VLADIMIR GUSEV	{"phone": "+70351553567"}
0005434938543	9BB1C1	2559 925875	NATALYA DENISOVA	{"email": "denisova-n1976@postgrespro.ru", "phone": "+70312015648"}
0005434938544	9BB1C1	9617 324619	ANTONINA SIDOROVA	{"email": "sidorova-antonina-051966@postgrespro.ru", "phone": "+70525575352"}
0005434938545	C88EE8	5905 334039	VLADIMIR TARASOV	{"phone": "+70071080872"}
0005434938546	6AE867	2959 910697	MARSEL ALEKSANDROV	{"phone": "+70354893882"}
0005434938547	6AE867	9845 897970	ALEFTINA SOKOLOVA	{"phone": "+70293442034"}
0005434938548	7EC7E7	0251 284669	ALEKSANDR PETROV	{"phone": "+70289243236"}
0005434938549	EA964E	3588 971068	TAMARA ILINA	{"phone": "+70955758955"}
0005434938550	FF5D60	6794 159144	OLEG FILIPPOV	{"email": "filippovo_23031983@postgrespro.ru", "phone": "+70176439990"}
0005434938551	FF5D60	1734 670240	ALEKSEY ALEKSANDROV	{"email": "a_aleksandrov.27041963@postgrespro.ru", "phone": "+70209345411"}
0005434938552	96EB12	2021 922837	VLADIMIR NOVIKOV	{"phone": "+70249716141"}
0005434938553	96EB12	7801 660061	LYUDMILA IVANOVA	{"phone": "+70902795310"}
0005434938554	B2C815	1703 847356	ANTON KUZNECOV	{"phone": "+70637567971"}
0005434938555	D3379F	3517 308431	ALEKSANDR NIKITIN	{"phone": "+70830696582"}
0005434938556	182B07	1612 966670	SVETLANA LEBEDEVA	{"email": "svetlana-lebedeva.1967@postgrespro.ru", "phone": "+70935702248"}
0005434938557	B355D7	3484 117516	SVETLANA TIKHONOVA	{"phone": "+70505948729"}
0005434938558	B355D7	5982 101577	ANDREY DMITRIEV	{"phone": "+70026057690"}
0005434938559	B8730A	6232 251689	ALEKSANDR KUDRYASHOV	{"phone": "+70982964274"}
0005434938560	060C07	5550 768778	TATYANA KUZNECOVA	{"phone": "+70424946530"}
0005434938561	DF4D6C	3526 073606	SVETLANA SMIRNOVA	{"email": "smirnovas09011978@postgrespro.ru", "phone": "+70477432094"}
0005434938562	55CE57	0579 737883	EKATERINA KOZLOVA	{"phone": "+70723850486"}
0005434938563	314D64	1138 558009	ANDREY KUZNECOV	{"phone": "+70475541296"}
0005434938564	314D64	9943 737213	VIKTORIYA ZOTOVA	{"email": "zotova.viktoriya_21031970@postgrespro.ru", "phone": "+70858777215"}
0005434938565	FD5368	6386 742691	VLADIMIR CHERNOV	{"phone": "+70878173383"}
0005434938566	FE54FB	8106 226716	NIKOLAY KOZLOV	{"phone": "+70215402340"}
0005434938567	FE54FB	4400 011923	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr.051981@postgrespro.ru", "phone": "+70057686255"}
0005434938568	6E5C21	9121 704800	IRINA ROMANOVA	{"email": "i.romanova.041976@postgrespro.ru", "phone": "+70762112457"}
0005434938569	2C67D1	0983 491123	NATALYA ABRAMOVA	{"phone": "+70058712486"}
0005434938570	2C67D1	0616 769350	EVGENIYA KAZAKOVA	{"email": "kazakova-evgeniya1965@postgrespro.ru", "phone": "+70075582011"}
0005434938571	4217CD	5952 618588	LEONID KOZLOV	{"email": "kozlov_leonid15011957@postgrespro.ru", "phone": "+70283173635"}
0005434938572	8C2794	7326 486134	ELMIRA NESTEROVA	{"phone": "+70421171010"}
0005434938573	8C2794	1038 296516	ALEKSANDR MARTYNOV	{"email": "martynov-a-03121965@postgrespro.ru", "phone": "+70518098509"}
0005434938574	8C2794	6039 868176	ARKADIY SERGEEV	{"email": "a_sergeev_28121969@postgrespro.ru", "phone": "+70690420522"}
0005434938575	A6D598	9240 846105	DMITRIY ZHUKOV	{"phone": "+70741517365"}
0005434938576	10CCE3	7061 405942	VALENTINA MASLOVA	{"phone": "+70691742413"}
0005434938577	04285D	5686 669058	ELENA IVANOVA	{"phone": "+70715945264"}
0005434938578	F49B88	1669 415698	TATYANA TITOVA	{"email": "titova.t27051976@postgrespro.ru", "phone": "+70496888809"}
0005434938579	F49B88	1588 810507	LYUDMILA MASLOVA	{"email": "maslova.l_1974@postgrespro.ru", "phone": "+70568350232"}
0005434938580	F49B88	5514 758855	SERGEY MAKAROV	{"email": "makarov_sergey1967@postgrespro.ru", "phone": "+70593740862"}
0005434938581	456B56	1304 856939	GULNARA GAVRILOVA	{"phone": "+70142005618"}
0005434938582	C55786	5474 801059	OLGA STEPANOVA	{"email": "olgastepanova-081967@postgrespro.ru", "phone": "+70934301089"}
0005434938583	C55786	5082 425506	ANGELINA DMITRIEVA	{"email": "angelina.dmitrieva_121973@postgrespro.ru", "phone": "+70103888854"}
0005434938584	519F97	7982 518783	ANTONINA IVANOVA	{"phone": "+70497667708"}
0005434938585	519F97	9387 685580	MARIYA FILIPPOVA	{"email": "m_filippova1980@postgrespro.ru", "phone": "+70339171474"}
0005434938586	4CFCA6	0865 714273	ALEKSANDR MAKAROV	{"email": "makarov-a.1972@postgrespro.ru", "phone": "+70710525104"}
0005434938587	4CFCA6	0798 974198	ANTON ISAEV	{"email": "anton_isaev_09071969@postgrespro.ru", "phone": "+70755441902"}
0005434938588	3C7898	3044 402476	ALEKSEY EGOROV	{"phone": "+70335833103"}
0005434938589	52B94A	0710 097473	LYUBOV GAVRILOVA	{"email": "gavrilova-l_1972@postgrespro.ru", "phone": "+70555198920"}
0005434938590	52B94A	6443 293247	VLADIMIR KRASNOV	{"email": "vladimir-krasnov061969@postgrespro.ru", "phone": "+70705318896"}
0005434938591	12CA37	0659 882764	KONSTANTIN IVANOV	{"phone": "+70282164583"}
0005434938592	89A0D2	5870 888397	TATYANA ZAKHAROVA	{"email": "zakharova_t-26121973@postgrespro.ru", "phone": "+70579430095"}
0005434938593	0E831A	1990 569390	OLGA KOZLOVA	{"email": "kozlovaolga06041974@postgrespro.ru", "phone": "+70806810479"}
0005434938594	E88A6E	3579 365196	MAKSIM ZAKHAROV	{"email": "maksim_zakharov1971@postgrespro.ru", "phone": "+70414729495"}
0005434938595	2EDEAE	5623 129246	ELIZAVETA KUZMINA	{"email": "kuzminaelizaveta-111975@postgrespro.ru", "phone": "+70083380630"}
0005434938596	41B3C9	8112 912280	ILNUR FILIPPOV	{"email": "ilnur.filippov.071976@postgrespro.ru", "phone": "+70554397199"}
0005434938597	6D765A	9068 597011	YULIYA CHERNOVA	{"email": "y.chernova1988@postgrespro.ru", "phone": "+70034595457"}
0005434938598	786CCE	6252 245748	LYUDMILA NESTEROVA	{"email": "lnesterova.22051970@postgrespro.ru", "phone": "+70430982255"}
0005434938599	786CCE	9108 786240	YULIYA ILINA	{"phone": "+70874039896"}
0005434938600	6B244A	3396 103767	VIKTOR MATVEEV	{"email": "matveevviktor06091978@postgrespro.ru", "phone": "+70003371956"}
0005434938601	092CEB	6233 491909	OLGA DENISOVA	{"phone": "+70188948851"}
0005434938602	B0EACD	4222 564774	ALEKSANDR KOROLEV	{"email": "aleksandr-korolev.07081977@postgrespro.ru", "phone": "+70664851705"}
0005434938603	4F4202	0453 738199	ALEKSANDR SAVELEV	{"phone": "+70192676269"}
0005434938604	313FF6	4217 469681	NIKITA DENISOV	{"email": "n-denisov_1972@postgrespro.ru", "phone": "+70318726432"}
0005434938605	313FF6	6900 500172	LYUBOV DAVYDOVA	{"email": "davydova-l-04121972@postgrespro.ru", "phone": "+70885693310"}
0005434938606	313FF6	9477 650816	VITALIY ALEKSANDROV	{"email": "v-aleksandrov-12031970@postgrespro.ru", "phone": "+70225374923"}
0005434943187	FED26A	4543 564809	ANZHELA TARASOVA	{"phone": "+70574251793"}
0005434938607	E0D6B5	1994 906119	SERGEY FROLOV	{"email": "frolov_s-07021967@postgrespro.ru", "phone": "+70217017708"}
0005434938608	E0D6B5	6496 615113	EGOR ZHUKOV	{"email": "zhukovegor13071965@postgrespro.ru", "phone": "+70663482783"}
0005434938609	B7AE14	8823 661778	DMITRIY IVANOV	{"email": "ivanovdmitriy.1976@postgrespro.ru", "phone": "+70458055712"}
0005434938610	B7AE14	2699 349747	ELIZAVETA SERGEEVA	{"email": "elizavetasergeeva1969@postgrespro.ru", "phone": "+70358239755"}
0005434938611	4222E5	4633 554138	VLADIMIR BORISOV	{"phone": "+70671987646"}
0005434938612	4222E5	4477 265246	VYACHESLAV GUSEV	{"email": "gusevv.12071977@postgrespro.ru", "phone": "+70613029111"}
0005434938613	4222E5	7670 568378	ALEKSEY KISELEV	{"email": "aleksey-kiselev.021973@postgrespro.ru", "phone": "+70701582072"}
0005434938614	C9CCB6	0013 710245	TATYANA TIMOFEEVA	{"phone": "+70949238529"}
0005434938615	31BCF5	4955 008345	VLADIMIR KUZNECOV	{"email": "v.kuznecov-1987@postgrespro.ru", "phone": "+70815222427"}
0005434938616	4D7A04	8455 768631	OLGA SOKOLOVA	{"phone": "+70618838882"}
0005434938617	832992	3004 565447	SVETLANA DENISOVA	{"phone": "+70633629437"}
0005434938618	8ADAD0	3098 692101	MARINA DENISOVA	{"email": "marina_denisova_05031978@postgrespro.ru", "phone": "+70594740964"}
0005434938619	A1AE77	1160 425735	ANASTASIYA POTAPOVA	{"phone": "+70001441186"}
0005434938620	F04A5D	6904 576535	TATYANA FEDOROVA	{"phone": "+70397844712"}
0005434938621	F75B90	7794 126605	EVGENIY MAKAROV	{"email": "makarov.e_021970@postgrespro.ru", "phone": "+70432090711"}
0005434938622	F75B90	1034 309914	NATALYA NIKIFOROVA	{"email": "nikiforova-natalya-1968@postgrespro.ru", "phone": "+70094772125"}
0005434938623	D75CBD	4076 100802	TATYANA BARANOVA	{"phone": "+70323804119"}
0005434938624	3EB050	6302 554560	NINA TITOVA	{"email": "n_titova_12101985@postgrespro.ru", "phone": "+70301694717"}
0005434938625	3EB050	4183 783888	ALEKSANDR MELNIKOV	{"phone": "+70583923560"}
0005434938626	CAE3AA	5438 240722	VYACHESLAV KARPOV	{"email": "v_karpov.051977@postgrespro.ru", "phone": "+70225152061"}
0005434938627	CAE3AA	1879 748729	TATYANA ARKHIPOVA	{"phone": "+70816516693"}
0005434938628	4892DB	3094 511117	FEDOR BONDARENKO	{"email": "bondarenkof_08121963@postgrespro.ru", "phone": "+70698776033"}
0005434938629	B22CDC	5010 701035	ALEKSANDR FILIPPOV	{"email": "a-filippov.121976@postgrespro.ru", "phone": "+70389334965"}
0005434938630	66C726	3690 030682	PETR SOKOLOV	{"phone": "+70728457248"}
0005434938631	66C726	9830 915035	DARYA FOMINA	{"phone": "+70067746852"}
0005434938632	908FAF	5240 110938	SERGEY KUDRYASHOV	{"phone": "+70533878361"}
0005434938633	3657A9	2718 412980	ANATOLIY YAKOVLEV	{"email": "yakovlev.a011965@postgrespro.ru", "phone": "+70041177855"}
0005434938634	B156B2	0064 280778	ALEKSANDR MOROZOV	{"email": "a-morozov.04041980@postgrespro.ru", "phone": "+70662107574"}
0005434938635	47633B	5716 990167	DMITRIY KOROLEV	{"email": "korolev-d.1984@postgrespro.ru", "phone": "+70849021989"}
0005434938636	343036	6943 591438	VALENTINA KAZAKOVA	{"phone": "+70557510294"}
0005434938637	343036	6907 346351	NADEZHDA CHERNOVA	{"phone": "+70626419535"}
0005434938638	C438E8	7313 957101	ANASTASIYA NESTEROVA	{"email": "a_nesterova101975@postgrespro.ru", "phone": "+70709580356"}
0005434938639	C438E8	6976 549451	LYUDMILA NIKITINA	{"phone": "+70250743787"}
0005434938640	A908C1	7062 600865	TATYANA YAKOVLEVA	{"phone": "+70428139869"}
0005434938641	CB8871	2610 360291	GALINA ALEKSANDROVA	{"phone": "+70908052211"}
0005434938642	44139F	3005 380005	RUSLAN NIKOLAEV	{"email": "nikolaevr1965@postgrespro.ru", "phone": "+70868147071"}
0005434938643	D22057	1972 130939	DANIIL ROMANOV	{"phone": "+70862950980"}
0005434938644	BC09C5	8934 643163	NATALYA VOLKOVA	{"email": "volkova-n-18121968@postgrespro.ru", "phone": "+70895830643"}
0005434938645	4A4FCB	8187 685097	MARINA KUZMINA	{"email": "kuzminamarina-30101973@postgrespro.ru", "phone": "+70108868101"}
0005434938646	59E176	2458 897909	IRINA STEPANOVA	{"email": "stepanova-i_1965@postgrespro.ru", "phone": "+70005648550"}
0005434938647	3A024F	1050 787686	TATYANA DANILOVA	{"email": "t.danilova_061974@postgrespro.ru", "phone": "+70960781486"}
0005434938648	5DCAAD	2597 996724	VALENTINA ROMANOVA	{"email": "v.romanova_1985@postgrespro.ru", "phone": "+70757630047"}
0005434938649	5DCAAD	2398 437380	ELENA GRISHINA	{"email": "grishina.e.1960@postgrespro.ru", "phone": "+70338908875"}
0005434938650	D7B2B9	6306 361625	VLADIMIR FROLOV	{"email": "v_frolov_091970@postgrespro.ru", "phone": "+70700184364"}
0005434938651	D7B2B9	0476 463284	NATALYA KOLESNIKOVA	{"phone": "+70528314125"}
0005434938652	B30AF1	1542 200415	IGOR ZAYCEV	{"phone": "+70096363218"}
0005434938653	F99DD4	6425 262092	NIKOLAY KUZNECOV	{"email": "nkuznecov.13061977@postgrespro.ru", "phone": "+70837835151"}
0005434938654	F99DD4	8394 785746	PETR SMIRNOV	{"email": "smirnov.p25021965@postgrespro.ru", "phone": "+70178364822"}
0005434938655	F99DD4	4276 164723	SERGEY STEPANOV	{"email": "s.stepanov-1971@postgrespro.ru", "phone": "+70526408538"}
0005434938656	59EF52	1968 190912	VERONIKA TIKHONOVA	{"email": "tikhonovaveronika28051970@postgrespro.ru", "phone": "+70049184565"}
0005434938657	358DE8	4193 294297	IVAN KONOVALOV	{"phone": "+70398462402"}
0005434938658	358DE8	5983 476963	SERGEY SIDOROV	{"email": "sidorovs-1965@postgrespro.ru", "phone": "+70060471245"}
0005434938659	358DE8	7960 896350	ILYA DAVYDOV	{"phone": "+70649492763"}
0005434938660	9C2895	3557 652298	YURIY VOROBEV	{"email": "vorobevyuriy1975@postgrespro.ru", "phone": "+70822797878"}
0005434938661	C452AA	9929 771065	DMITRIY EGOROV	{"phone": "+70395292790"}
0005434938662	C452AA	7379 978416	YULIYA POPOVA	{"phone": "+70696230345"}
0005434938663	312847	5254 317391	VALENTIN ABRAMOV	{"email": "valentinabramov-031970@postgrespro.ru", "phone": "+70323036427"}
0005434938664	E518FE	9432 993154	SERGEY SERGEEV	{"email": "s.sergeev20041982@postgrespro.ru", "phone": "+70070490410"}
0005434943367	8EEC73	8939 278000	NIKOLAY POPOV	{"phone": "+70044091081"}
0005434938665	E518FE	0433 706115	ALLA FROLOVA	{"email": "frolovaa-101974@postgrespro.ru", "phone": "+70536188943"}
0005434938666	DEA11C	8141 816842	KSENIYA ANDREEVA	{"phone": "+70872582662"}
0005434938667	A3F077	3269 333860	PAVEL KUZNECOV	{"phone": "+70101135255"}
0005434938668	A3F077	9003 892786	VIKTOR GAVRILOV	{"phone": "+70070479607"}
0005434938669	D872A4	8966 130730	ANDREY ALEKSANDROV	{"phone": "+70874049488"}
0005434938670	46A25F	5876 418509	LYUBOV BELOVA	{"email": "belova.l18111965@postgrespro.ru", "phone": "+70555751348"}
0005434938671	C83E88	2482 243047	ANATOLIY BORISOV	{"phone": "+70160163514"}
0005434938672	C83E88	6273 356929	GALINA KAZAKOVA	{"email": "g-kazakova.08071968@postgrespro.ru", "phone": "+70138746219"}
0005434938673	C0F6F6	1969 339834	KLAVDIYA KOROLEVA	{"email": "koroleva_klavdiya-051971@postgrespro.ru", "phone": "+70380851810"}
0005434938674	CA509C	2505 932664	IVAN DAVYDOV	{"phone": "+70305585695"}
0005434938675	CA509C	2784 468669	IGOR VASILEV	{"email": "vasilev.i.16111980@postgrespro.ru", "phone": "+70155301438"}
0005434938676	CA509C	5535 326317	ALEKSEY EGOROV	{"email": "egorova_031972@postgrespro.ru", "phone": "+70441132265"}
0005434938677	92F020	2999 916262	VLADIMIR NAZAROV	{"phone": "+70174259594"}
0005434938678	92F020	9740 312807	ROMAN MAKAROV	{"phone": "+70756261745"}
0005434938679	C0EB53	0955 807500	DMITRIY YAKOVLEV	{"phone": "+70146030958"}
0005434938680	171687	5195 161124	MARIYA AKIMOVA	{"email": "akimovam_02041976@postgrespro.ru", "phone": "+70867675800"}
0005434938681	4FAA0F	0619 000864	IRINA NIKOLAEVA	{"phone": "+70411651777"}
0005434938682	4FAA0F	2680 210659	MARIYA KUZNECOVA	{"phone": "+70796598725"}
0005434938683	A4F8C6	8853 529998	ELENA ZHURAVLEVA	{"phone": "+70706673877"}
0005434938684	AD44FF	0389 803688	ROMAN MAKAROV	{"phone": "+70746044679"}
0005434938685	AFA798	5276 979393	ANTON MAKAROV	{"phone": "+70719642708"}
0005434938686	05EDD9	8897 365016	NATALYA DANILOVA	{"phone": "+70475103933"}
0005434938687	7F45CB	8806 168066	LARISA ISAEVA	{"email": "isaeva.larisa1982@postgrespro.ru", "phone": "+70129684614"}
0005434938688	7F45CB	2723 521351	NINA POPOVA	{"phone": "+70272377132"}
0005434938689	8A2DD9	4544 848133	VALERIY MIRONOV	{"email": "v.mironov_22051974@postgrespro.ru", "phone": "+70596891803"}
0005434938690	A052C9	2896 349515	SVETLANA FOMINA	{"email": "fomina.svetlana-011970@postgrespro.ru", "phone": "+70246445184"}
0005434938691	A052C9	0615 967028	ELENA KISELEVA	{"email": "kiseleva-e-051971@postgrespro.ru", "phone": "+70515251984"}
0005434938692	57794B	8796 033704	GALINA ZHURAVLEVA	{"phone": "+70748600575"}
0005434938693	FB1693	6294 108190	ALEKSANDR MOROZOV	{"phone": "+70731256807"}
0005434938694	FB1693	0090 611906	EVGENIY MEDVEDEV	{"phone": "+70308785533"}
0005434938695	24A279	7958 054215	VLADIMIR SEMENOV	{"email": "semenovv_17091972@postgrespro.ru", "phone": "+70846421763"}
0005434938696	653C9C	8121 236239	VASILIY STEPANOV	{"email": "vasiliy-stepanov.1972@postgrespro.ru", "phone": "+70634204902"}
0005434938697	A3968B	0848 522409	ELENA KALININA	{"email": "kalininaelena-1963@postgrespro.ru", "phone": "+70907272646"}
0005434938698	A3968B	5245 239061	NATALYA MELNIKOVA	{"email": "n_melnikova14011991@postgrespro.ru", "phone": "+70697326769"}
0005434938699	2C8075	6702 995784	TATYANA NAUMOVA	{"phone": "+70210626779"}
0005434938700	5C6C70	3775 000620	ALEKSEY MIKHAYLOV	{"email": "a-mikhaylov.1972@postgrespro.ru", "phone": "+70431716501"}
0005434938701	A449EE	7688 418732	DARYA SIDOROVA	{"phone": "+70354018141"}
0005434938702	AA8656	4545 209177	NADEZHDA TITOVA	{"phone": "+70030268086"}
0005434938703	AA8656	6920 615485	ALEKSANDR SAVELEV	{"email": "a_savelev1962@postgrespro.ru", "phone": "+70189983457"}
0005434938704	963A09	5897 397096	VLADISLAV NOVIKOV	{"email": "v-novikov.1975@postgrespro.ru", "phone": "+70371921626"}
0005434938705	963A09	5152 109522	GRIGORIY SEMENOV	{"phone": "+70110857312"}
0005434938706	963A09	4505 675633	ELENA KARPOVA	{"email": "karpovaelena-101985@postgrespro.ru", "phone": "+70737264609"}
0005434938707	182AB6	1764 088904	OLEG SCHERBAKOV	{"email": "scherbakov-o-041977@postgrespro.ru", "phone": "+70001051823"}
0005434938708	C861C0	4263 899979	ZHANNA GORBUNOVA	{"phone": "+70859545868"}
0005434938709	C861C0	0236 208391	DMITRIY SMIRNOV	{"phone": "+70145476024"}
0005434938710	2C1EA0	4160 513058	VLADIMIR SMIRNOV	{"email": "v_smirnov_031974@postgrespro.ru", "phone": "+70071878202"}
0005434938711	2C1EA0	6684 375942	LYUDMILA ALEKSANDROVA	{"email": "aleksandrova_lyudmila.19021985@postgrespro.ru", "phone": "+70783570325"}
0005434938712	B5BBD2	3066 955904	NATALYA KOZLOVA	{"email": "kozlova_n.08071976@postgrespro.ru", "phone": "+70432037296"}
0005434938713	0D1177	5750 797039	NIKOLAY SOKOLOV	{"phone": "+70294094051"}
0005434938714	0D1177	4440 110586	TAISIYA MIRONOVA	{"email": "mironova.taisiya30031971@postgrespro.ru", "phone": "+70513953052"}
0005434938715	0D1177	5986 555683	SVETLANA FEDOROVA	{"email": "fedorova_s-17041972@postgrespro.ru", "phone": "+70638575091"}
0005434938716	A43F69	4473 628278	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v.28101969@postgrespro.ru", "phone": "+70183022929"}
0005434938717	1D4FD4	2653 507815	ALENA TIKHONOVA	{"email": "a-tikhonova1967@postgrespro.ru", "phone": "+70907881024"}
0005434938718	1D4FD4	3018 731803	ANNA IVANOVA	{"email": "ivanova-a_24081965@postgrespro.ru", "phone": "+70287216595"}
0005434938719	DAB8EF	6752 727486	OLGA MAKAROVA	{"phone": "+70467591571"}
0005434938720	3E98EE	5919 486627	KRISTINA RYABOVA	{"email": "ryabova_k011979@postgrespro.ru", "phone": "+70483696782"}
0005434938721	CD6EC2	0376 767665	LIDIYA MARTYNOVA	{"email": "martynova-lidiya.041975@postgrespro.ru", "phone": "+70883630248"}
0005434943184	64C3E7	7561 525665	MAKSIM NIKITIN	{"email": "nikitin-maksim-12031970@postgrespro.ru", "phone": "+70624570119"}
0005434943185	025AF2	3757 097487	ALEKSEY GAVRILOV	{"phone": "+70670525798"}
0005434943186	A43A5A	5907 127575	ALLA YAKOVLEVA	{"email": "a-yakovleva-1974@postgrespro.ru", "phone": "+70584875413"}
0005434943188	E9FEE0	7645 355167	DIANA FOMINA	{"email": "d.fomina1977@postgrespro.ru", "phone": "+70335483533"}
0005434943189	E9FEE0	4756 187533	VASILIY KUDRYASHOV	{"email": "vasiliy-kudryashov.1971@postgrespro.ru", "phone": "+70095829895"}
0005434943190	410D5F	7724 675740	MAKSIM AFANASEV	{"email": "afanasevm.19091967@postgrespro.ru", "phone": "+70916984976"}
0005434943191	F8F446	3814 364033	SERGEY EGOROV	{"phone": "+70889739604"}
0005434943192	F8F446	5869 153594	DENIS AFANASEV	{"email": "denis-afanasev-051978@postgrespro.ru", "phone": "+70928280213"}
0005434943193	D4051E	2695 212950	ILYA DMITRIEV	{"email": "i-dmitriev_121977@postgrespro.ru", "phone": "+70410745067"}
0005434943194	D4051E	5439 155036	SERGEY TARASOV	{"email": "tarasovs-1982@postgrespro.ru", "phone": "+70414589496"}
0005434943195	905E30	3314 168466	NATALYA POLYAKOVA	{"email": "n.polyakova.01051970@postgrespro.ru", "phone": "+70200765275"}
0005434943196	5B2DFF	4996 565536	NIKOLAY SOLOVEV	{"phone": "+70020602503"}
0005434943197	6C1E75	5524 855383	IGOR VASILEV	{"phone": "+70727429476"}
0005434943198	6C1E75	7248 671618	EDGAR GRIGOREV	{"email": "grigorev-e_121970@postgrespro.ru", "phone": "+70949281595"}
0005434943199	762DBE	1488 433535	NATALIYA POTAPOVA	{"email": "potapova.nataliya.1963@postgrespro.ru", "phone": "+70644041506"}
0005434943200	B55FB1	2690 602154	VERA SOKOLOVA	{"phone": "+70150284443"}
0005434943201	B55FB1	4512 446520	ALEKSANDR EGOROV	{"phone": "+70041105500"}
0005434943202	B5DC93	6773 027156	VENERA SERGEEVA	{"phone": "+70800558148"}
0005434943203	B5DC93	0034 385538	ELENA KULIKOVA	{"email": "elenakulikova-061967@postgrespro.ru", "phone": "+70461947248"}
0005434943204	53DE63	7747 459138	SERGEY MIKHAYLOV	{"phone": "+70207009731"}
0005434943205	C3D898	5429 363023	DANIIL MAKSIMOV	{"email": "d.maksimov_091970@postgrespro.ru", "phone": "+70924331708"}
0005434943206	7801DA	4306 821277	LIDIYA MEDVEDEVA	{"phone": "+70876726595"}
0005434943207	A6A62B	7484 732798	NATALYA DAVYDOVA	{"email": "davydova.n.26011971@postgrespro.ru", "phone": "+70932294118"}
0005434943208	A6A62B	6492 106749	NIKOLAY CHERNOV	{"email": "nikolaychernov091972@postgrespro.ru", "phone": "+70064255405"}
0005434943209	961DD8	4190 061278	DANILA FOMIN	{"phone": "+70310180088"}
0005434943210	517098	2150 288512	ANNA ROMANOVA	{"phone": "+70436471667"}
0005434943211	517098	4412 891678	OLEG BELOV	{"email": "olegbelov.1976@postgrespro.ru", "phone": "+70482704489"}
0005434943212	A2E4E2	5541 052810	DMITRIY NAZAROV	{"email": "dmitriynazarov021974@postgrespro.ru", "phone": "+70633808359"}
0005434943213	D73845	7581 026431	GALINA MIRONOVA	{"phone": "+70581143828"}
0005434943214	197F8A	2438 193375	IRINA ALEKSEEVA	{"email": "ialekseeva_1963@postgrespro.ru", "phone": "+70745524873"}
0005434943215	6F1058	5797 078950	ANNA KUZNECOVA	{"email": "a.kuznecova_1964@postgrespro.ru", "phone": "+70596446385"}
0005434943216	F763C8	7085 494490	SERGEY KOROLEV	{"phone": "+70256234410"}
0005434943217	E0C699	3977 671987	EVGENIY PETROV	{"phone": "+70729967100"}
0005434943218	CF8F14	6459 730228	VASILIY KUZNECOV	{"phone": "+70505285404"}
0005434943219	CF8F14	9041 228721	ANDREY KUDRYASHOV	{"email": "andrey-kudryashov-121978@postgrespro.ru", "phone": "+70103806878"}
0005434943220	5E4C22	2532 173275	ANNA SMIRNOVA	{"phone": "+70644646367"}
0005434943221	AE6727	0723 117026	LYUDMILA KUZNECOVA	{"phone": "+70735469941"}
0005434943222	42867A	0538 763563	VLADISLAV SERGEEV	{"email": "vladislav.sergeev03071964@postgrespro.ru", "phone": "+70437706148"}
0005434943223	132B9C	9247 432745	EVGENIYA VOROBEVA	{"phone": "+70463585468"}
0005434943224	132B9C	9816 833498	ELENA SEMENOVA	{"email": "e.semenova101975@postgrespro.ru", "phone": "+70274240765"}
0005434943225	02C33D	4998 169295	EVGENIY MIRONOV	{"email": "e.mironov.1974@postgrespro.ru", "phone": "+70044919997"}
0005434943226	7E1785	6240 364916	OLEG GERASIMOV	{"phone": "+70386173516"}
0005434943227	7E1785	2539 270380	ZOYA PETROVA	{"phone": "+70368600217"}
0005434943228	2F4062	1261 604683	EGOR SOKOLOV	{"email": "e_sokolov.10061975@postgrespro.ru", "phone": "+70560024819"}
0005434943229	D79FB2	3537 801632	YURIY SOKOLOV	{"phone": "+70548476330"}
0005434943230	A10426	5477 048803	GALINA DENISOVA	{"phone": "+70922097752"}
0005434943231	177D6B	1802 327245	MIKHAIL FEDOTOV	{"email": "fedotovmikhail_1978@postgrespro.ru", "phone": "+70637259870"}
0005434943232	4BEFEC	1168 362412	SERGEY KUZMIN	{"phone": "+70926253613"}
0005434943233	4BEFEC	5807 841967	VIKTORIYA ABRAMOVA	{"email": "viktoriya-abramova-28051970@postgrespro.ru", "phone": "+70295655291"}
0005434943234	BAEC8A	7871 415262	ARTEM POPOV	{"email": "a.popov_061974@postgrespro.ru", "phone": "+70720443372"}
0005434943235	C9943D	2897 975876	TATYANA ILINA	{"email": "ilina.t-22031968@postgrespro.ru", "phone": "+70965331615"}
0005434943236	366DFA	1160 170246	OKSANA OVCHINNIKOVA	{"email": "oksana-ovchinnikova.14041970@postgrespro.ru", "phone": "+70389574979"}
0005434943237	B11F7C	5246 156432	EKATERINA IVANOVA	{"email": "ivanova-e.1967@postgrespro.ru", "phone": "+70864724661"}
0005434943238	2BAA2F	1773 503634	SVETLANA DANILOVA	{"email": "danilova.svetlana.28111960@postgrespro.ru", "phone": "+70380849546"}
0005434943239	BC0B11	5293 566522	ANNA MASLOVA	{"phone": "+70043859619"}
0005434943240	FD559C	7906 256703	ALINA SEMENOVA	{"phone": "+70943666725"}
0005434943241	FD559C	1929 749902	ANASTASIYA MOROZOVA	{"email": "amorozova-11081966@postgrespro.ru", "phone": "+70732467072"}
0005434943242	81DE20	4451 441848	NATALYA MATVEEVA	{"phone": "+70632555768"}
0005434943243	79DF63	4307 245321	ELENA SOLOVEVA	{"email": "elena_soloveva.08051970@postgrespro.ru", "phone": "+70090338885"}
0005434943244	3DBE9D	2454 784772	ALEKSANDR POPOV	{"email": "popov.a.01121975@postgrespro.ru", "phone": "+70371551702"}
0005434943245	3DBE9D	4072 449511	OLGA ORLOVA	{"email": "o_orlova15081978@postgrespro.ru", "phone": "+70918957983"}
0005434943246	2DAE47	9357 987754	MARGARITA FILATOVA	{"phone": "+70895110200"}
0005434943368	54D3EE	0835 656223	EVGENIYA SOLOVEVA	{"phone": "+70280406184"}
0005434943247	2DAE47	0308 697088	LYUBOV AKIMOVA	{"email": "l.akimova.1964@postgrespro.ru", "phone": "+70515268253"}
0005434943248	3CAE2A	7422 529001	ARKADIY FEDOROV	{"email": "a-fedorov_021958@postgrespro.ru", "phone": "+70499381011"}
0005434943249	3CAE2A	4549 699655	SERGEY SEMENOV	{"email": "sergey.semenov.1966@postgrespro.ru", "phone": "+70318597168"}
0005434943250	A2FDA9	4409 611342	GALINA KOMAROVA	{"email": "g-komarova.031976@postgrespro.ru", "phone": "+70875645796"}
0005434943251	DA7C44	2845 397464	TAISIYA DANILOVA	{"phone": "+70412163799"}
0005434943252	1C6F9A	5570 259287	IVAN TIKHONOV	{"phone": "+70794981074"}
0005434943253	46D3B1	1870 074565	IREK NIKOLAEV	{"phone": "+70502366204"}
0005434943254	986BBE	3975 525233	TATYANA NESTEROVA	{"email": "tatyana-nesterova.20121979@postgrespro.ru", "phone": "+70243914394"}
0005434943255	986BBE	5673 662226	ALEKSEY DENISOV	{"phone": "+70952614656"}
0005434943256	D96C17	3408 303086	VIKTOR GAVRILOV	{"email": "gavrilov.v.051975@postgrespro.ru", "phone": "+70289882080"}
0005434943257	70B2D4	1027 118635	ALEKSANDR KUZNECOV	{"phone": "+70290708329"}
0005434943258	70B2D4	9121 803309	ZOYA MOROZOVA	{"email": "z.morozova1971@postgrespro.ru", "phone": "+70294162631"}
0005434943259	B62E10	2773 376114	EKATERINA IVANOVA	{"phone": "+70304216777"}
0005434943260	B62E10	4621 577532	NINA KOLESNIKOVA	{"phone": "+70162137254"}
0005434943261	E6FFC4	2707 806045	LYUBOV KULIKOVA	{"email": "l.kulikova_06041985@postgrespro.ru", "phone": "+70787446786"}
0005434943262	DB3679	6891 244017	ALEKSANDR NOVIKOV	{"phone": "+70183359764"}
0005434943263	DB3679	4778 433998	LIDIYA IVANOVA	{"phone": "+70145826436"}
0005434943264	4FE77D	5135 010314	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov051979@postgrespro.ru", "phone": "+70770438304"}
0005434943265	8C520A	0967 487674	NATALYA VOLKOVA	{"email": "nvolkova_061972@postgrespro.ru", "phone": "+70508156989"}
0005434943266	8C520A	7005 152748	NIKOLAY BORISOV	{"email": "nikolay.borisov1961@postgrespro.ru", "phone": "+70634134201"}
0005434943267	A9D99F	6442 874730	DANIL ZAKHAROV	{"email": "zakharov.danil1968@postgrespro.ru", "phone": "+70775544151"}
0005434943268	D717B5	6808 823174	OLGA ZHUKOVA	{"phone": "+70124840476"}
0005434943269	481C47	3203 548567	RAISA MEDVEDEVA	{"phone": "+70551490481"}
0005434943270	A07F2C	7554 802694	VLADIMIR GERASIMOV	{"email": "gerasimov-vladimir-1970@postgrespro.ru", "phone": "+70794025044"}
0005434943271	3490FC	5669 095723	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov_091968@postgrespro.ru", "phone": "+70610893749"}
0005434943272	055852	5159 477627	ANATOLIY ZHUKOV	{"email": "anatoliy-zhukov-16121963@postgrespro.ru", "phone": "+70721842240"}
0005434943273	FF8E24	8389 629616	GALINA MOROZOVA	{"phone": "+70342106128"}
0005434943274	60FC2F	0922 666699	IRINA BORISOVA	{"phone": "+70551999128"}
0005434943275	312EAD	0726 595852	ALEKSANDRA ZOTOVA	{"email": "a_zotova31051969@postgrespro.ru", "phone": "+70809046137"}
0005434943276	E8DB30	1139 424883	RUSTAM POPOV	{"email": "popov.r31121983@postgrespro.ru", "phone": "+70336048398"}
0005434943277	F0ACF7	5675 283427	ALEKSANDR IVANOV	{"phone": "+70730824795"}
0005434943278	F0ACF7	9108 893419	MATVEY MAKAROV	{"phone": "+70976919343"}
0005434943279	972F17	4794 115652	NATALYA LOGINOVA	{"email": "nloginova-081977@postgrespro.ru", "phone": "+70152414593"}
0005434943280	5A0B47	6127 720046	ALEKSANDR ROMANOV	{"email": "romanov_aleksandr-1988@postgrespro.ru", "phone": "+70974853018"}
0005434943281	466776	9271 123214	ALEKSEY KUZMIN	{"email": "akuzmin_011964@postgrespro.ru", "phone": "+70648645046"}
0005434943282	466776	3384 241777	MATVEY MAKAROV	{"email": "makarov.m.1976@postgrespro.ru", "phone": "+70546095640"}
0005434943283	FC9A50	5019 730090	DAMIR FROLOV	{"phone": "+70134354875"}
0005434943284	B615ED	9778 575881	ELIZAVETA KISELEVA	{"email": "elizavetakiseleva.14041967@postgrespro.ru", "phone": "+70237132313"}
0005434943285	9246AF	5474 769132	NINA TARASOVA	{"phone": "+70134198839"}
0005434943286	3F9171	7903 963479	YANA NOVIKOVA	{"email": "yananovikova_1984@postgrespro.ru", "phone": "+70594708406"}
0005434943287	3F9171	7755 937198	VIKTOR MELNIKOV	{"phone": "+70477205480"}
0005434943288	274050	1092 442728	SERGEY VASILEV	{"phone": "+70158106170"}
0005434943289	A6FF63	9427 373793	ANNA TROFIMOVA	{"email": "trofimova-anna.13091970@postgrespro.ru", "phone": "+70080228015"}
0005434943290	704171	9039 944715	TATYANA EGOROVA	{"phone": "+70342580231"}
0005434943291	D12B58	5794 188375	SERGEY ALEKSEEV	{"phone": "+70805802544"}
0005434943292	D12B58	6069 333295	ANNA SERGEEVA	{"email": "sergeeva_anna-121972@postgrespro.ru", "phone": "+70602347554"}
0005434943293	DB6764	8852 168211	PAVEL ZAYCEV	{"email": "zaycev-p.10011988@postgrespro.ru", "phone": "+70627533555"}
0005434943294	B855A0	6241 741959	NIKOLAY GORBUNOV	{"phone": "+70082854797"}
0005434943295	B855A0	9740 690959	NIKOLAY SMIRNOV	{"email": "n-smirnov.101970@postgrespro.ru", "phone": "+70164442228"}
0005434943296	B5FA11	0688 901407	ANDREY TARASOV	{"email": "andrey-tarasov111971@postgrespro.ru", "phone": "+70614141160"}
0005434943297	9ADF77	0949 937145	ZOYA BARANOVA	{"phone": "+70451581700"}
0005434943298	2412A8	1468 595723	YULIYA FROLOVA	{"email": "y_frolova.021977@postgrespro.ru", "phone": "+70529873755"}
0005434943299	2412A8	8425 505687	MIKHAIL STEPANOV	{"email": "stepanovmikhail-121970@postgrespro.ru", "phone": "+70372599437"}
0005434943300	9EF350	9569 944349	NADEZHDA IVANOVA	{"email": "nadezhda-ivanova.011973@postgrespro.ru", "phone": "+70799582464"}
0005434943301	9EF350	0770 402211	DANILA PAVLOV	{"email": "d_pavlov29041975@postgrespro.ru", "phone": "+70554558205"}
0005434943302	EB2712	6466 105184	ELENA ROMANOVA	{"email": "romanova.e_1975@postgrespro.ru", "phone": "+70146747211"}
0005434943303	9BB275	3981 464653	DMITRIY KUZNECOV	{"email": "dmitriykuznecov_1977@postgrespro.ru", "phone": "+70381649866"}
0005434943304	9BB275	6424 459595	NATALYA IVANOVA	{"phone": "+70819268181"}
0005434943305	3904F1	1517 937130	ANTONINA ANDREEVA	{"email": "a_andreeva.27021979@postgrespro.ru", "phone": "+70771657457"}
0005434943306	3904F1	3267 823366	VERA YAKOVLEVA	{"email": "yakovlevavera_1973@postgrespro.ru", "phone": "+70892597351"}
0005434943307	3904F1	2005 948078	NATALYA NIKIFOROVA	{"email": "nikiforova.n_1972@postgrespro.ru", "phone": "+70795754344"}
0005434943308	5BECD3	4411 316066	IRINA NESTEROVA	{"phone": "+70985496097"}
0005434943309	91B793	3603 098656	EKATERINA SIDOROVA	{"email": "esidorova.081975@postgrespro.ru", "phone": "+70061435113"}
0005434943310	91B793	9376 969262	KARINA YUDINA	{"email": "yudina-k.26081969@postgrespro.ru", "phone": "+70495867600"}
0005434943311	BA4A93	5540 286460	YULIYA TIKHONOVA	{"email": "yuliya-tikhonova-061991@postgrespro.ru", "phone": "+70924573568"}
0005434943312	785385	6963 623673	ALEKSEY ZHUKOV	{"email": "zhukovaleksey.1974@postgrespro.ru", "phone": "+70681952935"}
0005434943313	4FFD8E	9873 292167	GALINA BORISOVA	{"email": "borisova.g24111979@postgrespro.ru", "phone": "+70731710923"}
0005434943314	4FFD8E	8941 098443	SERGEY ABRAMOV	{"phone": "+70935590480"}
0005434943315	4FFD8E	3940 387732	TATYANA NOVIKOVA	{"phone": "+70101461800"}
0005434943316	211367	1591 301369	GRIGORIY ANTONOV	{"phone": "+70607512789"}
0005434943317	FDEC27	4761 446900	TATYANA POPOVA	{"phone": "+70558687372"}
0005434943318	FDEC27	8671 379303	SVETLANA POPOVA	{"phone": "+70298128194"}
0005434943319	FDEC27	1107 519150	NATALYA EGOROVA	{"email": "natalya-egorova.1979@postgrespro.ru", "phone": "+70588291896"}
0005434943320	CF339B	3873 553943	ANATOLIY AFANASEV	{"email": "afanasev.anatoliy-1964@postgrespro.ru", "phone": "+70356872250"}
0005434943321	CF339B	2647 300032	NATALYA KRASNOVA	{"phone": "+70183901974"}
0005434943322	CF339B	8729 101884	NATALYA DAVYDOVA	{"email": "natalya.davydova-1973@postgrespro.ru", "phone": "+70545003993"}
0005434943323	C7DBA8	7416 033401	PAVEL CHERNOV	{"email": "p.chernov_11041975@postgrespro.ru", "phone": "+70736794799"}
0005434943324	EB1197	7267 697360	VALENTINA KARPOVA	{"email": "v-karpova_011961@postgrespro.ru", "phone": "+70822824149"}
0005434943325	5D81E1	1209 530886	RIMMA MAKSIMOVA	{"phone": "+70787977715"}
0005434943326	5D81E1	6826 237603	ANDREY ABRAMOV	{"email": "abramova1976@postgrespro.ru", "phone": "+70891342322"}
0005434943327	C1B51E	0226 255120	ELVIRA ZHURAVLEVA	{"phone": "+70455015992"}
0005434943328	15C537	8132 062480	OLGA POPOVA	{"phone": "+70921065677"}
0005434943329	15C537	5220 490325	MARINA VASILEVA	{"email": "vasileva-m.081965@postgrespro.ru", "phone": "+70615731005"}
0005434943330	15C537	0896 596405	NIKOLAY GAVRILOV	{"email": "n_gavrilov_081971@postgrespro.ru", "phone": "+70689976465"}
0005434943331	0C8846	1099 071885	NADEZHDA NOVIKOVA	{"phone": "+70599674801"}
0005434943332	D611E2	6115 318574	VLADIMIR KUZNECOV	{"phone": "+70320386288"}
0005434943333	D611E2	1524 993728	GALINA ZHURAVLEVA	{"phone": "+70300780521"}
0005434943334	03F9F2	6743 474715	NATALYA SOKOLOVA	{"email": "n-sokolova.1976@postgrespro.ru", "phone": "+70068838006"}
0005434943335	44ED70	8269 839095	VALENTINA ZAYCEVA	{"phone": "+70519599738"}
0005434943336	44ED70	1543 403651	GENNADIY SHEVCHENKO	{"phone": "+70303664501"}
0005434943337	64F5CD	5042 111938	NADEZHDA KUZNECOVA	{"phone": "+70907183413"}
0005434943338	013615	9642 334527	ARTEM KUDRYASHOV	{"email": "kudryashov_artem13021987@postgrespro.ru", "phone": "+70507528212"}
0005434943339	013615	3759 137367	NAIL POPOV	{"phone": "+70117948550"}
0005434943340	247AD5	4027 530703	SERGEY MEDVEDEV	{"phone": "+70606746227"}
0005434943341	AFE222	7671 998571	VALERIY DAVYDOV	{"email": "valeriydavydov_021966@postgrespro.ru", "phone": "+70259131339"}
0005434943342	51F612	6356 885484	ALEKSANDR MIKHAYLOV	{"phone": "+70942175841"}
0005434943343	C6E7F8	9670 432884	GALINA SOROKINA	{"phone": "+70062934373"}
0005434943344	C6E7F8	9201 352413	ALEKSANDR ROMANOV	{"phone": "+70436059195"}
0005434943345	0FDBF8	8944 286055	TATYANA EFREMOVA	{"phone": "+70246125794"}
0005434943346	5D1748	9221 150276	ANATOLIY FROLOV	{"phone": "+70184672452"}
0005434943347	FDC068	6272 593872	ASIYA KONDRATEVA	{"email": "akondrateva11081976@postgrespro.ru", "phone": "+70674547510"}
0005434943348	5F8377	3173 549293	VLADIMIR KULIKOV	{"email": "kulikov-vladimir13061972@postgrespro.ru", "phone": "+70961637780"}
0005434943349	DEEDAD	2798 501052	ANDREY KRASNOV	{"phone": "+70623182122"}
0005434943350	DEEDAD	3269 766652	NATALYA KOLESNIKOVA	{"email": "kolesnikova_n1969@postgrespro.ru", "phone": "+70447557676"}
0005434943351	51F71B	6253 105611	SERGEY POPOV	{"email": "sergey.popov061970@postgrespro.ru", "phone": "+70287681668"}
0005434943352	51F71B	9915 107941	SERGEY VOROBEV	{"phone": "+70783333302"}
0005434943353	C481DE	8166 316010	OLEG KUZNECOV	{"email": "oleg_kuznecov.22121968@postgrespro.ru", "phone": "+70392544298"}
0005434943354	9B515E	9396 290559	OLGA ANTONOVA	{"phone": "+70675854189"}
0005434943355	9B515E	1853 715408	ANTON MATVEEV	{"phone": "+70904635186"}
0005434943356	4F8BBD	0276 996226	TATYANA GORBUNOVA	{"phone": "+70146738800"}
0005434943357	B4DC35	1393 071687	NATALYA ZAKHAROVA	{"email": "zakharova-natalya_041968@postgrespro.ru", "phone": "+70607528756"}
0005434943358	B4DC35	0543 544765	IRINA ERMAKOVA	{"email": "ermakova_i-101967@postgrespro.ru", "phone": "+70543211523"}
0005434943359	55767A	1650 292443	LARISA KUZNECOVA	{"phone": "+70411598541"}
0005434943360	55767A	1637 578735	VADIM SERGEEV	{"phone": "+70178341123"}
0005434943361	F1D0D8	3992 818089	ARTEM SMIRNOV	{"phone": "+70150349241"}
0005434943362	CF5A7B	2000 943270	VLADIMIR POPOV	{"email": "popovv-041971@postgrespro.ru", "phone": "+70689353633"}
0005434943363	80F391	4305 305443	ALEKSANDR FOMIN	{"email": "aleksandrfomin.07041978@postgrespro.ru", "phone": "+70637397438"}
0005434943364	80F391	9882 445261	ANNA RYABOVA	{"email": "ryabova_anna30041963@postgrespro.ru", "phone": "+70242237020"}
0005434943365	DE550D	2334 158703	MAKSIM SOKOLOV	{"email": "sokolov.m1969@postgrespro.ru", "phone": "+70729910237"}
0005434943366	3CBE77	6027 414596	EVGENIYA KONOVALOVA	{"email": "konovalovae.101974@postgrespro.ru", "phone": "+70424318387"}
0005434943369	9387AC	3907 128227	MARAT SOKOLOV	{"phone": "+70538349689"}
0005434943370	EA7377	3570 870850	TATYANA KUZNECOVA	{"phone": "+70979803443"}
0005434943371	977036	2933 985837	RUSLAN GAVRILOV	{"phone": "+70903996784"}
0005434943372	977036	3486 026324	KSENIYA YAKOVLEVA	{"email": "kseniyayakovleva-051970@postgrespro.ru", "phone": "+70637159691"}
0005434943373	80882A	4578 113241	ANDREY TIKHONOV	{"email": "a.tikhonov.04011970@postgrespro.ru", "phone": "+70862480113"}
0005434943374	D85A41	3243 125174	SERGEY NAZAROV	{"email": "sergeynazarov-17101977@postgrespro.ru", "phone": "+70716672108"}
0005434943375	36D580	9771 783949	MARIYA VASILEVA	{"email": "mariya_vasileva25111976@postgrespro.ru", "phone": "+70630525336"}
0005434943376	07FD4A	9083 374070	ANDREY VOROBEV	{"email": "vorobeva_10011966@postgrespro.ru", "phone": "+70042768410"}
0005434943377	3ED5EA	4249 698433	SEMEN DAVYDOV	{"phone": "+70726934972"}
0005434943378	3ED5EA	8112 504933	NATALIYA GUSEVA	{"email": "gusevan-14081972@postgrespro.ru", "phone": "+70900341147"}
0005434943379	4CCF87	9492 290067	PETR ISAEV	{"phone": "+70438244786"}
0005434943380	72EC48	7919 452757	VLADIMIR MOROZOV	{"phone": "+70050817092"}
0005434943381	72EC48	4144 745525	TATYANA PAVLOVA	{"email": "pavlovat.15101978@postgrespro.ru", "phone": "+70870488749"}
0005434943382	A25676	1577 966402	OLGA KISELEVA	{"phone": "+70519277403"}
0005434943383	5408C3	5955 059618	MARINA NESTEROVA	{"phone": "+70313882848"}
0005434943384	BF6712	2492 660827	OLGA SCHERBAKOVA	{"email": "o.scherbakova_071982@postgrespro.ru", "phone": "+70882149836"}
0005434943385	232695	7211 570599	SVETLANA VOROBEVA	{"phone": "+70381445783"}
0005434943386	9F556A	9654 852345	VIKTOR RODIONOV	{"phone": "+70595619781"}
0005434943387	9F556A	8196 472396	REGINA ZHURAVLEVA	{"phone": "+70865552622"}
0005434943388	9F556A	8530 577949	TATYANA BORISOVA	{"email": "t.borisova.1973@postgrespro.ru", "phone": "+70853793139"}
0005434943389	AE6DC5	3832 307638	ROMAN GUSEV	{"phone": "+70203667034"}
0005434943390	0E185D	6525 873332	MIKHAIL STEPANOV	{"email": "stepanov-mikhail_03071962@postgrespro.ru", "phone": "+70393558320"}
0005434943391	88CD67	7850 946607	VLADIMIR KAZAKOV	{"phone": "+70190117805"}
0005434943392	A89E3E	4990 275921	TATYANA ARKHIPOVA	{"email": "arkhipova-tatyana1968@postgrespro.ru", "phone": "+70629332295"}
0005434943393	B463E9	3911 384794	ARTEM NIKITIN	{"phone": "+70022385181"}
0005434943394	8B9261	6865 979395	MARIYA ZHURAVLEVA	{"email": "mariyazhuravleva-1967@postgrespro.ru", "phone": "+70521658057"}
0005434943395	8250AD	2312 606494	DMITRIY KRASNOV	{"email": "krasnov.dmitriy-1974@postgrespro.ru", "phone": "+70105415301"}
0005434943396	8250AD	3923 113382	OLGA KARPOVA	{"email": "o.karpova02041958@postgrespro.ru", "phone": "+70423503048"}
0005434943397	4936D1	1499 757340	GALINA ALEKSEEVA	{"email": "galekseeva.07071970@postgrespro.ru", "phone": "+70527404151"}
0005434943398	4936D1	5864 055792	RAISA ZHURAVLEVA	{"email": "zhuravleva.r_031973@postgrespro.ru", "phone": "+70666200566"}
0005434943399	4936D1	0566 945329	ELENA GAVRILOVA	{"email": "elenagavrilova_27091962@postgrespro.ru", "phone": "+70794597044"}
0005434943400	1E0152	2023 069172	ROZA ZAYCEVA	{"email": "zayceva_r.1972@postgrespro.ru", "phone": "+70487176459"}
0005434943401	1E0152	2953 351611	NIKOLAY PETROV	{"phone": "+70478575024"}
0005434943402	69E5E9	9184 052448	ALBINA KRASNOVA	{"email": "krasnovaalbina_1975@postgrespro.ru", "phone": "+70336528076"}
0005434943403	CFF46F	3933 059100	NINA SMIRNOVA	{"phone": "+70169861460"}
0005434943404	8E9287	1062 434273	ALEKSANDR TIMOFEEV	{"phone": "+70991948600"}
0005434943405	2B4BE0	3133 592635	DMITRIY FILIPPOV	{"phone": "+70404053212"}
0005434943406	55A84C	7671 448818	NINA VOLKOVA	{"email": "nina_volkova.1976@postgrespro.ru", "phone": "+70056258371"}
0005434943407	7F2493	8201 920590	ROMAN MELNIKOV	{"phone": "+70339405519"}
0005434943408	8CB856	2425 992979	YURIY KUZNECOV	{"email": "yuriy.kuznecov.111969@postgrespro.ru", "phone": "+70696002983"}
0005434943409	8CB856	6655 550843	NATALYA DAVYDOVA	{"phone": "+70086197133"}
0005434943410	C517A4	0054 128595	ANTON ZAYCEV	{"phone": "+70201211545"}
0005434943411	C517A4	1851 350252	NIKOLAY DMITRIEV	{"email": "dmitrievnikolay01021976@postgrespro.ru", "phone": "+70853492808"}
0005434943412	FFB976	1658 793386	NATALYA LOGINOVA	{"email": "n_loginova-1955@postgrespro.ru", "phone": "+70780221486"}
0005434943413	31E66E	5534 890676	KIRILL KRASNOV	{"phone": "+70532597976"}
0005434943414	31E66E	2436 610714	GALINA EFIMOVA	{"phone": "+70816413956"}
0005434943415	A56F21	4867 331977	NONNA OVCHINNIKOVA	{"email": "ovchinnikova.n.1981@postgrespro.ru", "phone": "+70236384372"}
0005434943416	708928	9326 878130	ELENA PETROVA	{"email": "elena.petrova-081964@postgrespro.ru", "phone": "+70847200496"}
0005434943417	DDB1BB	4950 283544	VALERIYA VASILEVA	{"email": "valeriya_vasileva11031977@postgrespro.ru", "phone": "+70647408854"}
0005434943418	38EBA4	9665 969198	MARIYA KUZNECOVA	{"phone": "+70279193417"}
0005434943419	F3AE3E	9811 076894	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.aleksey1968@postgrespro.ru", "phone": "+70751745919"}
0005434943420	E2E76D	8731 423441	ELENA PAVLOVA	{"email": "e_pavlova.1968@postgrespro.ru", "phone": "+70027342493"}
0005434943421	EE3D54	8869 514296	SERGEY VOLKOV	{"phone": "+70535662162"}
0005434943422	409A41	4505 859759	VIKTORIYA FROLOVA	{"phone": "+70371409218"}
0005434943423	52DF73	7983 674593	RIMMA TROFIMOVA	{"email": "r.trofimova1969@postgrespro.ru", "phone": "+70002973557"}
0005434943424	3F0DA5	8035 760054	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-m22081975@postgrespro.ru", "phone": "+70038160859"}
0005434943425	BE995D	3000 552447	ALBINA DAVYDOVA	{"email": "davydova-albina051975@postgrespro.ru", "phone": "+70935011991"}
0005434943426	BE995D	5815 372031	NATALYA FEDOROVA	{"email": "natalya_fedorova-02051967@postgrespro.ru", "phone": "+70160004273"}
0005434943427	E7B266	5945 039794	ANNA AKIMOVA	{"email": "annaakimova1976@postgrespro.ru", "phone": "+70734482730"}
0005434943428	E7B266	0033 726327	ANDREY FROLOV	{"email": "frolovandrey25011974@postgrespro.ru", "phone": "+70671601471"}
0005434943429	776FBE	4874 935513	ALEVTINA ILINA	{"email": "a-ilina.05011974@postgrespro.ru", "phone": "+70936628813"}
0005434943430	289562	8056 843813	SERGEY ALEKSANDROV	{"email": "aleksandrovs1984@postgrespro.ru", "phone": "+70148112815"}
0005434943431	2DC6BF	8605 497969	VYACHESLAV KUZNECOV	{"phone": "+70507941621"}
0005434943432	570F87	5155 996681	NIKITA ZHUKOV	{"phone": "+70013819683"}
0005434943433	570F87	7784 849909	ANASTASIYA IVANOVA	{"email": "ivanova.anastasiya-051957@postgrespro.ru", "phone": "+70699299640"}
0005434943434	81EC9B	7577 569119	NIKITA TARASOV	{"phone": "+70957083463"}
0005434943435	0DDB45	3760 702203	YURIY IVANOV	{"phone": "+70714867514"}
0005434943436	1F55B6	4176 760140	VALENTINA KALININA	{"email": "v_kalinina-20081972@postgrespro.ru", "phone": "+70741636658"}
0005434943437	1F55B6	6984 261335	LYUBOV GAVRILOVA	{"email": "lyubov_gavrilova061966@postgrespro.ru", "phone": "+70686401213"}
0005434943438	8E4424	2593 610973	OLGA AKIMOVA	{"email": "akimova_olga-04031967@postgrespro.ru", "phone": "+70195777512"}
0005434943439	780608	9093 082512	ANNA ZHUKOVA	{"email": "azhukova.081971@postgrespro.ru", "phone": "+70382150219"}
0005434943440	C77C84	8566 517220	VERA MEDVEDEVA	{"phone": "+70254966898"}
0005434943441	ABEC9E	7083 705703	ZOYA KOZLOVA	{"email": "zkozlova1968@postgrespro.ru", "phone": "+70635388197"}
0005434943442	ABEC9E	6643 293935	ALEKSEY MIRONOV	{"phone": "+70018973212"}
0005434943443	83AF24	4475 745115	VASILIY TIKHONOV	{"phone": "+70962947695"}
0005434943444	83AF24	1109 239839	VALENTINA SAVELEVA	{"email": "vsaveleva-041978@postgrespro.ru", "phone": "+70319020271"}
0005434943445	29D00E	7872 614012	GALINA YAKOVLEVA	{"phone": "+70262907903"}
0005434943446	74A4DB	1069 881954	SAVELIY MOISEEV	{"phone": "+70456562317"}
0005434943447	7FDCE1	2490 684496	LYUDMILA MAKSIMOVA	{"phone": "+70118968770"}
0005434943448	66585E	0567 253191	ILYA SEMENOV	{"phone": "+70464607900"}
0005434943449	63C4E8	0077 291205	LIDIYA KOROLEVA	{"email": "koroleva-l-19081982@postgrespro.ru", "phone": "+70187577293"}
0005434943450	3CB540	6325 744042	ANNA DAVYDOVA	{"phone": "+70796016631"}
0005434943451	A50AB0	7983 465451	NINA DMITRIEVA	{"phone": "+70327643112"}
0005434943452	267775	2330 995730	YURIY NOVIKOV	{"phone": "+70683079608"}
0005434943453	05F2E9	7431 510479	ANNA IVANOVA	{"email": "ivanova-a.031972@postgrespro.ru", "phone": "+70711508485"}
0005434943454	BABA93	4449 306490	PETR VLASOV	{"phone": "+70078358348"}
0005434943455	DFC18F	3748 558395	VENIAMIN MAKAROV	{"email": "makarov-veniamin-1974@postgrespro.ru", "phone": "+70007761518"}
0005434943456	DFC18F	1518 976901	VALENTINA TROFIMOVA	{"email": "trofimovav_021964@postgrespro.ru", "phone": "+70832467432"}
0005434943457	0042EF	3924 391630	YURIY ZAKHAROV	{"phone": "+70668405687"}
0005434943458	0042EF	2979 868525	RUDOLF BELOV	{"phone": "+70620084808"}
0005434943459	7D983D	7820 820372	SVETLANA NIKOLAEVA	{"email": "nikolaeva-svetlana.1981@postgrespro.ru", "phone": "+70961507394"}
0005434943460	73882D	0754 194935	RAVIL EGOROV	{"email": "r_egorov-1960@postgrespro.ru", "phone": "+70292523187"}
0005434943461	766DF5	9538 471492	ANDREY EGOROV	{"phone": "+70685427998"}
0005434943462	56FD72	3528 199489	ELENA YAKOVLEVA	{"phone": "+70439822279"}
0005434943463	CA7A39	5818 194141	EVGENIY NIKOLAEV	{"phone": "+70507994341"}
0005434943464	CA7A39	2290 708718	YURIY SEMENOV	{"email": "y.semenov.1966@postgrespro.ru", "phone": "+70344452330"}
0005434943465	1876BE	5382 606260	VERONIKA AFANASEVA	{"phone": "+70913512366"}
0005434943466	575838	3774 712583	SERGEY KRASNOV	{"phone": "+70905587349"}
0005434943467	8BC71F	4984 762709	NIKOLAY SMIRNOV	{"phone": "+70547215703"}
0005434943468	01D13B	6998 091433	ALEKSANDR ORLOV	{"email": "orlov_aleksandr-10101974@postgrespro.ru", "phone": "+70205377713"}
0005434943469	1DD17C	0007 221552	LIDIYA FEDOROVA	{"email": "fedorova_lidiya1967@postgrespro.ru", "phone": "+70458010407"}
0005434943470	9FAF09	3863 502679	VLADIMIR VASILEV	{"phone": "+70800130323"}
0005434943471	A0F76E	9438 959194	ALEKSANDR DENISOV	{"phone": "+70561651486"}
0005434943472	3B9087	4023 888635	MARIYA FEDOROVA	{"email": "m_fedorova.1970@postgrespro.ru", "phone": "+70712535353"}
0005434943473	3B9087	2643 637623	VIKTOR KUZNECOV	{"phone": "+70757207532"}
0005434943474	81289E	5733 538196	NIKOLAY KOROLEV	{"phone": "+70262308132"}
0005434943475	099246	9829 763087	GALINA NAUMOVA	{"email": "galina-naumova_011964@postgrespro.ru", "phone": "+70485431540"}
0005434943476	E1ABAF	8758 539413	OLGA NIKITINA	{"email": "olganikitina_081980@postgrespro.ru", "phone": "+70745457120"}
0005434943477	B3BFF6	5574 156020	VALENTINA KOZLOVA	{"email": "kozlova-v_061958@postgrespro.ru", "phone": "+70977308227"}
0005434943478	DA74D1	2322 940187	LYUBOV ROMANOVA	{"phone": "+70742235912"}
0005434943479	D1E1C1	7313 704793	ALEKSEY IVANOV	{"phone": "+70911133884"}
0005434943480	76F0D3	5398 384634	NATALYA BORISOVA	{"email": "natalya-borisova_091964@postgrespro.ru", "phone": "+70024516692"}
0005434943481	76F0D3	8337 240372	TATYANA ILINA	{"phone": "+70638215080"}
0005434943482	DD280D	1178 945937	EVGENIY VASILEV	{"email": "vasilev-evgeniy-1974@postgrespro.ru", "phone": "+70700108297"}
0005434943483	557D2D	4465 534037	SERGEY TIMOFEEV	{"phone": "+70265706085"}
0005434943484	5C4D80	5596 472259	VALENTINA TIKHONOVA	{"phone": "+70855494019"}
0005434943485	0102A4	0943 217097	ANNA FILATOVA	{"email": "filatova-anna_061983@postgrespro.ru", "phone": "+70933555349"}
0005434943486	59C332	3585 937749	ALFIYA MARTYNOVA	{"email": "martynova-alfiya-1976@postgrespro.ru", "phone": "+70599465721"}
0005434943487	668D12	6310 657012	NADEZHDA ISAEVA	{"phone": "+70563721580"}
0005434943488	9022E1	1528 773376	ELENA ANTONOVA	{"phone": "+70705194125"}
0005434943489	A59E22	0929 421019	ALEKSEY KRASNOV	{"email": "a.krasnov071979@postgrespro.ru", "phone": "+70194688769"}
0005434943490	8C6AE9	1221 353764	MIKHAIL MARTYNOV	{"phone": "+70147938169"}
0005434943491	8C6AE9	1985 312755	NATALYA EGOROVA	{"email": "egorovan.1980@postgrespro.ru", "phone": "+70791146365"}
0005434943492	0C49F8	1026 410391	DMITRIY NIKOLAEV	{"phone": "+70854333389"}
0005434943493	14BAF2	6303 801590	VALERIY MAKAROV	{"phone": "+70966147518"}
0005434943494	14BAF2	0956 158409	ANDREY SOROKIN	{"email": "sorokina.13021980@postgrespro.ru", "phone": "+70238458889"}
0005434943495	FAEB5F	9136 108266	IRINA NAZAROVA	{"email": "nazarova-i-1986@postgrespro.ru", "phone": "+70245604428"}
0005434947869	8BD457	1062 781124	SERGEY SMIRNOV	{"phone": "+70565283438"}
0005434943496	FAEB5F	0580 817270	OLGA PETROVA	{"email": "petrova_o.051967@postgrespro.ru", "phone": "+70899272118"}
0005434943497	49E32B	0238 418841	VALENTINA POPOVA	{"email": "valentina.popova1967@postgrespro.ru", "phone": "+70896446371"}
0005434943498	3B9B98	9982 810406	NIKOLAY MATVEEV	{"email": "matveev.n1980@postgrespro.ru", "phone": "+70837405589"}
0005434943499	4469EF	2814 834268	GENNADIY FROLOV	{"email": "gfrolov-1981@postgrespro.ru", "phone": "+70811071636"}
0005434943500	4469EF	7752 312682	ALEKSANDRA KALININA	{"email": "kalinina-a_011977@postgrespro.ru", "phone": "+70311023384"}
0005434943501	5AAFFE	8263 203528	GALINA KUZMINA	{"email": "kuzmina.g_07041963@postgrespro.ru", "phone": "+70924199542"}
0005434943502	5327F9	3480 389690	SERGEY GAVRILOV	{"email": "s-gavrilov_1969@postgrespro.ru", "phone": "+70611415553"}
0005434943503	7B3409	4910 459514	VLADIMIR KARPOV	{"email": "v-karpov101973@postgrespro.ru", "phone": "+70637154428"}
0005434943504	881B3C	2587 013939	YULIYA POLYAKOVA	{"phone": "+70669986660"}
0005434943505	881B3C	4829 509651	OLGA KONDRATEVA	{"phone": "+70593498385"}
0005434943506	4E767D	4142 354656	ILDAR NIKITIN	{"phone": "+70777904421"}
0005434943507	4E767D	5420 052764	VASILIY ALEKSEEV	{"phone": "+70799395385"}
0005434943508	6648D1	2200 100548	DENIS MOROZOV	{"email": "d_morozov.1962@postgrespro.ru", "phone": "+70957325044"}
0005434943509	5E8144	5062 794075	ANNA ZHURAVLEVA	{"phone": "+70251856529"}
0005434943510	94C358	3812 405689	ANASTASIYA ZHUKOVA	{"phone": "+70796274274"}
0005434943511	94C358	6395 159594	ELENA NIKITINA	{"phone": "+70422277740"}
0005434943512	891952	2035 631961	GLEB SEMENOV	{"email": "gleb-semenov-22101967@postgrespro.ru", "phone": "+70290241005"}
0005434943513	BE0A10	6127 357440	GALINA KUZMINA	{"email": "galina.kuzmina08011972@postgrespro.ru", "phone": "+70680869987"}
0005434943514	3633F9	1178 228526	NADEZHDA AKIMOVA	{"email": "nadezhda.akimova_1968@postgrespro.ru", "phone": "+70027179605"}
0005434943515	3633F9	9998 498129	ELENA PETROVA	{"phone": "+70885827795"}
0005434943516	42C175	5783 220274	ROMAN ZAYCEV	{"phone": "+70950994070"}
0005434943517	738D91	3051 837944	NATALYA OSIPOVA	{"email": "natalya-osipova1966@postgrespro.ru", "phone": "+70589641859"}
0005434943518	738D91	8838 786577	VLADIMIR MOROZOV	{"email": "morozov_vladimir1970@postgrespro.ru", "phone": "+70257261901"}
0005434943519	83FB57	2902 537976	NATALYA POPOVA	{"phone": "+70177842528"}
0005434943520	BF289F	4225 167966	MIKHAIL ISAEV	{"email": "isaev-m-111974@postgrespro.ru", "phone": "+70441623805"}
0005434943521	F66939	7238 321987	VITALIY DENISOV	{"phone": "+70780132497"}
0005434943522	54F699	2205 962309	NATALYA VOLKOVA	{"phone": "+70799608340"}
0005434943523	EC15C6	5721 777720	ARTEM SOLOVEV	{"phone": "+70169822206"}
0005434943524	3BFF0A	5689 538021	NATALYA RODIONOVA	{"email": "rodionova_natalya12011968@postgrespro.ru", "phone": "+70455408662"}
0005434943525	1845B5	3182 689075	VITALIY BARANOV	{"phone": "+70658228451"}
0005434943526	E3399B	3745 821733	TATYANA SIDOROVA	{"phone": "+70574275348"}
0005434943527	B3C603	7386 253397	VERA MAKAROVA	{"phone": "+70559842288"}
0005434943528	82283F	9548 228311	NATALYA SERGEEVA	{"phone": "+70967812483"}
0005434943529	FEDD28	7366 844307	ALEKSEY POPOV	{"email": "a_popov.02061962@postgrespro.ru", "phone": "+70950608815"}
0005434943530	FEDD28	4279 154262	MAKSIM BELOV	{"email": "belov.m1972@postgrespro.ru", "phone": "+70370159213"}
0005434943531	FC514F	7753 304984	OLGA MIKHAYLOVA	{"email": "mikhaylovaolga_111976@postgrespro.ru", "phone": "+70038231170"}
0005434943532	FC514F	3996 134236	ANGELINA RODIONOVA	{"phone": "+70165040503"}
0005434943533	D9DBA4	5664 689790	ALEVTINA NAZAROVA	{"email": "a.nazarova.081971@postgrespro.ru", "phone": "+70867160158"}
0005434943534	E2C387	8720 582472	SNEZHANA KOZLOVA	{"email": "kozlova.s_101961@postgrespro.ru", "phone": "+70331736061"}
0005434943535	9D2DE5	4771 516623	VALENTINA ANDREEVA	{"phone": "+70955916741"}
0005434943536	F3FEA6	7142 112866	TATYANA ROMANOVA	{"email": "romanova-tatyana-101973@postgrespro.ru", "phone": "+70314147143"}
0005434943537	19C3C6	1264 351798	ANATOLIY OSIPOV	{"email": "osipova_1978@postgrespro.ru", "phone": "+70598216879"}
0005434943538	0E8D03	1406 648004	NATALYA FROLOVA	{"email": "frolovanatalya_1969@postgrespro.ru", "phone": "+70931296680"}
0005434943539	0E8D03	7656 984939	EKATERINA KUZNECOVA	{"email": "kuznecova_e.1955@postgrespro.ru", "phone": "+70850768150"}
0005434943540	0F6B4D	4448 345081	VERA GAVRILOVA	{"phone": "+70202344044"}
0005434943541	1A3ECC	0073 636027	ELENA DMITRIEVA	{"email": "dmitrieva-elena.091971@postgrespro.ru", "phone": "+70175035226"}
0005434943542	17AEEB	1083 897935	ELENA SEMENOVA	{"phone": "+70583637711"}
0005434943543	17AEEB	9451 615046	VITALIY TIMOFEEV	{"email": "timofeev_vitaliy051980@postgrespro.ru", "phone": "+70156433566"}
0005434943544	64857C	7526 625221	NADEZHDA IVANOVA	{"phone": "+70546148662"}
0005434943545	5BCE7C	4486 345398	NIKOLAY RODIONOV	{"phone": "+70430113049"}
0005434943546	30E30C	7336 160515	IVAN ZHUKOV	{"phone": "+70708727674"}
0005434943547	30E30C	1606 568506	DMITRIY ALEKSEEV	{"phone": "+70811428011"}
0005434943548	35EC63	8086 530533	EVGENIY EGOROV	{"phone": "+70089565643"}
0005434943549	AFFA8D	3063 643115	ALEKSANDR DENISOV	{"email": "aleksandr_denisov-17041980@postgrespro.ru", "phone": "+70906270361"}
0005434943550	F0BCCC	9466 435050	DMITRIY PAVLOV	{"email": "pavlov.d.12021977@postgrespro.ru", "phone": "+70452680077"}
0005434943551	CE1BEA	1497 796772	OLGA NAZAROVA	{"phone": "+70497586925"}
0005434943552	4C1786	0969 591544	OLGA ZAKHAROVA	{"email": "olga_zakharova.051979@postgrespro.ru", "phone": "+70902849910"}
0005434943553	E71A5C	5973 360847	VLADIMIR ZHUKOV	{"email": "zhukov.v.011963@postgrespro.ru", "phone": "+70602785881"}
0005434943554	E71A5C	6675 657525	EKATERINA SMIRNOVA	{"phone": "+70603812585"}
0005434943555	820AA2	1957 949266	ALINA NAUMOVA	{"email": "anaumova1970@postgrespro.ru", "phone": "+70192922977"}
0005434943613	1FCDF5	3801 130423	VALENTINA VASILEVA	{"phone": "+70502142987"}
0005434943556	820AA2	7583 805146	EGOR RODIONOV	{"email": "rodionov.egor_1980@postgrespro.ru", "phone": "+70783247038"}
0005434943557	EB7317	1342 554321	LARISA ZAKHAROVA	{"email": "lzakharova16101968@postgrespro.ru", "phone": "+70354272507"}
0005434943558	EB7317	7097 911812	ANNA VOROBEVA	{"phone": "+70153049283"}
0005434943559	2B020F	3095 804454	ALEKSEY NIKITIN	{"phone": "+70594547687"}
0005434943560	1C6707	5743 417391	TAMARA KUZMINA	{"phone": "+70484682420"}
0005434943561	413DCD	4475 187733	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy.1982@postgrespro.ru", "phone": "+70073365140"}
0005434943562	6B2688	3210 687545	VASILIY ZAKHAROV	{"email": "zakharovv-19071974@postgrespro.ru", "phone": "+70219863176"}
0005434943563	911AD0	0341 729865	SERGEY VASILEV	{"phone": "+70862575666"}
0005434943564	911AD0	0596 316090	ILDAR TIKHONOV	{"email": "tikhonov.ildar071970@postgrespro.ru", "phone": "+70381515078"}
0005434943565	105844	7154 328053	SERGEY KUZNECOV	{"phone": "+70791335197"}
0005434943566	46E4F5	2359 929856	MARIYA POPOVA	{"phone": "+70323399780"}
0005434943567	46E4F5	1639 364323	DMITRIY FROLOV	{"phone": "+70955277875"}
0005434943568	1B1687	3245 352809	VASILIY SAVELEV	{"email": "savelev_vasiliy_051967@postgrespro.ru", "phone": "+70630693920"}
0005434943569	3E19CD	0407 773124	VLADIMIR ANDREEV	{"email": "andreev.vladimir-1983@postgrespro.ru", "phone": "+70233362144"}
0005434943570	2AE03F	9214 961673	GALINA CHERNOVA	{"email": "galina.chernova-10101968@postgrespro.ru", "phone": "+70569423936"}
0005434943571	2AE03F	2066 148766	NIKITA DENISOV	{"phone": "+70172470124"}
0005434943572	260CDD	0767 389923	ALEKSANDR BELOV	{"email": "belov_aleksandr-28121968@postgrespro.ru", "phone": "+70824643104"}
0005434943573	260CDD	3318 792343	MARIYA FILATOVA	{"email": "filatova-mariya-101977@postgrespro.ru", "phone": "+70648406260"}
0005434943574	B60E0C	8560 854214	TATYANA ZAKHAROVA	{"email": "zakharova-tatyana.121970@postgrespro.ru", "phone": "+70549686315"}
0005434943575	50602D	0375 573376	IGOR GAVRILOV	{"phone": "+70816448452"}
0005434943576	50602D	4955 812487	NATALYA SIDOROVA	{"email": "n.sidorova.29081975@postgrespro.ru", "phone": "+70979637392"}
0005434943577	044BB8	0042 947603	VALENTIN KAZAKOV	{"phone": "+70919238464"}
0005434943578	AC7B96	2014 627937	KIRILL VOROBEV	{"phone": "+70131089691"}
0005434943579	6BC9E0	4443 093529	ARTUR SIDOROV	{"phone": "+70344312478"}
0005434943580	6CC73C	2562 699865	ELIZAVETA ABRAMOVA	{"email": "abramova-e30061986@postgrespro.ru", "phone": "+70690825744"}
0005434943581	5CC88B	6728 697946	NATALYA SOKOLOVA	{"phone": "+70183719636"}
0005434943582	5CC88B	8224 367169	ANATOLIY STEPANOV	{"email": "a-stepanov_1970@postgrespro.ru", "phone": "+70037301492"}
0005434943583	C718D4	9830 260504	VIKTOR BARANOV	{"phone": "+70163556701"}
0005434943584	C718D4	2835 035633	DENIS SHEVCHENKO	{"email": "d_shevchenko.081966@postgrespro.ru", "phone": "+70223640320"}
0005434943585	50FABE	2784 075542	MIKHAIL KOZLOV	{"phone": "+70981449352"}
0005434943586	79DAD8	9057 159811	VLADIMIR STEPANOV	{"phone": "+70012812381"}
0005434943587	79DAD8	1329 050758	RENAT DAVYDOV	{"phone": "+70615157914"}
0005434943588	96EC7B	6944 530788	YULIYA SIDOROVA	{"phone": "+70253790336"}
0005434943589	153C35	2177 064654	ANDREY KUZNECOV	{"phone": "+70156031394"}
0005434943590	F970A4	8778 716241	ALEKSANDRA KOROLEVA	{"email": "akoroleva_1974@postgrespro.ru", "phone": "+70588806992"}
0005434943591	2BDE23	7247 247547	TAMARA MELNIKOVA	{"email": "melnikova-t.021977@postgrespro.ru", "phone": "+70732964845"}
0005434943592	2BDE23	7521 045545	MIKHAIL MAKAROV	{"phone": "+70160367324"}
0005434943593	F7CA34	1589 443845	VALENTINA KOVALEVA	{"phone": "+70163195901"}
0005434943594	1D0B49	8322 268522	MIKHAIL YAKOVLEV	{"phone": "+70781049482"}
0005434943595	F8BC36	3221 758829	MIKHAIL GUSEV	{"phone": "+70002116292"}
0005434943596	F8BC36	6300 548515	VLADIMIR FOMIN	{"email": "vladimir.fomin.1975@postgrespro.ru", "phone": "+70949640214"}
0005434943597	2C37EE	4785 989451	GENNADIY MIRONOV	{"email": "mironovgennadiy-041966@postgrespro.ru", "phone": "+70028034737"}
0005434943598	0BFA88	5215 592473	ALEKSANDR NOVIKOV	{"phone": "+70969336411"}
0005434943599	0BFA88	7009 674785	OLEG FROLOV	{"email": "o-frolov_11031983@postgrespro.ru", "phone": "+70175624360"}
0005434943600	0BFA88	6806 691448	NADEZHDA ROMANOVA	{"phone": "+70132102719"}
0005434943601	929999	7483 800617	STANISLAV ANTONOV	{"phone": "+70160304097"}
0005434943602	929999	1212 254986	LEONID ROMANOV	{"email": "romanov-l_14041975@postgrespro.ru", "phone": "+70576701758"}
0005434943603	6445ED	8453 517046	NIKITA FROLOV	{"email": "nikita-frolov.22041974@postgrespro.ru", "phone": "+70758170501"}
0005434943604	722A56	0808 678576	EMIL OSIPOV	{"phone": "+70555901600"}
0005434943605	722A56	8520 728008	IVAN POPOV	{"phone": "+70149509337"}
0005434943606	A19820	6798 828144	OLEG IVANOV	{"email": "ivanovoleg-07021974@postgrespro.ru", "phone": "+70885925403"}
0005434943607	650F0A	4885 207620	IVAN TARASOV	{"phone": "+70420126720"}
0005434943608	650F0A	5643 516866	DARYA FADEEVA	{"phone": "+70547360547"}
0005434943609	91C0D4	2018 187702	ARTEM GRIGOREV	{"email": "grigorev-artem-10051973@postgrespro.ru", "phone": "+70264045607"}
0005434943610	16A292	5193 417189	VLADIMIR KOZLOV	{"email": "kozlov.vladimir-1979@postgrespro.ru", "phone": "+70853340368"}
0005434943611	16A292	2173 436288	NIKOLAY KUZMIN	{"phone": "+70178772154"}
0005434943612	ABB9D7	7433 038198	RUSLAN KISELEV	{"email": "kiselev-ruslan-051959@postgrespro.ru", "phone": "+70265081703"}
0005434943614	7CD621	5621 035462	IVAN NAZAROV	{"email": "nazarov-ivan-061972@postgrespro.ru", "phone": "+70822864476"}
0005434943615	7CD621	2105 857166	NATALYA OSIPOVA	{"phone": "+70980804334"}
0005434943616	6885EA	6015 768835	IGOR KRASNOV	{"email": "krasnov_i-10011972@postgrespro.ru", "phone": "+70020968517"}
0005434943617	0850C3	0463 063707	TATYANA YUDINA	{"phone": "+70714480919"}
0005434947868	6344B2	1616 677006	DMITRIY AFANASEV	{"phone": "+70625398692"}
0005434947870	1A02E6	2308 440743	NIKOLAY KOZLOV	{"phone": "+70643831319"}
0005434947871	A1D9F8	4843 223083	DANILA PAVLOV	{"email": "d.pavlov_06101966@postgrespro.ru", "phone": "+70332458467"}
0005434947872	A1D9F8	5114 824092	ANASTASIYA EGOROVA	{"phone": "+70043452363"}
0005434947873	3A9823	2067 251577	DMITRIY MAKAROV	{"email": "makarovd_20081977@postgrespro.ru", "phone": "+70004194964"}
0005434947874	0C72E0	5107 577370	VLADIMIR RODIONOV	{"phone": "+70747880019"}
0005434947875	EEC2FE	0625 636726	SERGEY IVANOV	{"phone": "+70712705340"}
0005434947876	F73DA8	1644 126858	NIKITA ROMANOV	{"email": "n_romanov.111975@postgrespro.ru", "phone": "+70370683494"}
0005434947877	7A839E	0538 214369	TATYANA LEBEDEVA	{"phone": "+70236593945"}
0005434947878	C6208B	3548 547841	VIKTORIYA LEBEDEVA	{"email": "lebedeva.viktoriya-18011973@postgrespro.ru", "phone": "+70655092312"}
0005434947879	C6208B	0360 577122	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir011973@postgrespro.ru", "phone": "+70439254144"}
0005434947880	B80CC2	3413 866752	TATYANA EGOROVA	{"email": "egorova-t-1968@postgrespro.ru", "phone": "+70516237326"}
0005434947881	9E0D11	4240 987209	NURIYA ZAKHAROVA	{"email": "zakharova-nuriya_1978@postgrespro.ru", "phone": "+70688328595"}
0005434947882	9E0D11	2412 682628	EVGENIY MEDVEDEV	{"email": "medvedevevgeniy-05041963@postgrespro.ru", "phone": "+70843269671"}
0005434947883	AD1D65	7015 079923	VLADIMIR MAKAROV	{"phone": "+70654637988"}
0005434947884	AD1D65	7912 293514	SVETLANA NIKOLAEVA	{"phone": "+70503779374"}
0005434947885	CB6AAD	9600 629195	MIKHAIL SERGEEV	{"email": "mikhailsergeev_1975@postgrespro.ru", "phone": "+70723846525"}
0005434947886	7071DC	2791 931689	MIKHAIL IVANOV	{"phone": "+70022497144"}
0005434947887	7071DC	0047 893248	LARISA NOVIKOVA	{"email": "larisa-novikova.1975@postgrespro.ru", "phone": "+70939624784"}
0005434947888	E0A176	0832 317915	IGOR NIKITIN	{"phone": "+70679619823"}
0005434947889	16E9E7	4399 228169	MAKSIM ABRAMOV	{"email": "maksim.abramov_061973@postgrespro.ru", "phone": "+70857632548"}
0005434947890	9924F8	8985 859241	GLEB PAVLOV	{"phone": "+70540060340"}
0005434947891	C1A031	9077 183699	LIDIYA DMITRIEVA	{"phone": "+70950789203"}
0005434947892	4E67B6	8439 273124	MARIYA EGOROVA	{"email": "egorova-m_01021977@postgrespro.ru", "phone": "+70151740407"}
0005434947893	256292	1127 611858	KARINA MOISEEVA	{"email": "moiseeva.k22041966@postgrespro.ru", "phone": "+70421297838"}
0005434947894	338447	6004 793787	SERGEY POPOV	{"phone": "+70847049045"}
0005434947895	338447	0706 388433	ELENA MIKHAYLOVA	{"email": "mikhaylovae-1965@postgrespro.ru", "phone": "+70250825365"}
0005434947896	00794E	2846 563658	IGOR SOROKIN	{"email": "igorsorokin-1964@postgrespro.ru", "phone": "+70661089377"}
0005434947897	4BA772	9770 100686	ILSHAT MIKHAYLOV	{"email": "ilshatmikhaylov-091981@postgrespro.ru", "phone": "+70900845650"}
0005434947898	487F33	2945 146330	ELENA FROLOVA	{"email": "frolova-e1966@postgrespro.ru", "phone": "+70201905788"}
0005434947899	F5B9FB	3513 547502	NATALYA IVANOVA	{"email": "natalyaivanova_15051973@postgrespro.ru", "phone": "+70143849617"}
0005434947900	3F39FE	3535 642075	ELENA SIDOROVA	{"email": "esidorova.23041971@postgrespro.ru", "phone": "+70445867394"}
0005434947901	3F39FE	5554 956928	IVAN ISAEV	{"phone": "+70605709390"}
0005434947902	F81A4A	6949 970096	VIKTORIYA MEDVEDEVA	{"email": "medvedeva.v1977@postgrespro.ru", "phone": "+70927949271"}
0005434947903	F81A4A	7543 229178	VIKTOR DMITRIEV	{"email": "dmitrievv15091979@postgrespro.ru", "phone": "+70595789294"}
0005434947904	C557D7	6602 506063	ALENA ROMANOVA	{"phone": "+70828441411"}
0005434947905	9EDE42	5657 630871	ANDREY IVANOV	{"email": "a.ivanov.031976@postgrespro.ru", "phone": "+70059784021"}
0005434947906	9EDE42	4361 374071	ALEKSANDR GORBUNOV	{"phone": "+70689965560"}
0005434947907	13EC3F	2319 630307	YULIYA ZOTOVA	{"email": "zotova-y-091975@postgrespro.ru", "phone": "+70100798495"}
0005434947908	13EC3F	6110 089668	ZAKHAR FOMIN	{"phone": "+70171672950"}
0005434947909	EB87FD	9915 288286	TATYANA ALEKSEEVA	{"email": "t_alekseeva_1970@postgrespro.ru", "phone": "+70182813329"}
0005434947910	DD2D36	7719 234316	KAMILA MOROZOVA	{"phone": "+70049612663"}
0005434947911	704C25	1515 692087	ALEKSANDR GERASIMOV	{"email": "gerasimova.061959@postgrespro.ru", "phone": "+70071442331"}
0005434947912	704C25	5327 600478	OLGA NAZAROVA	{"phone": "+70853390010"}
0005434947913	692C93	3827 206657	DMITRIY KULIKOV	{"phone": "+70468504587"}
0005434947914	847DE6	6599 932022	ALEKSEY IVANOV	{"phone": "+70311669027"}
0005434947915	EA2EFE	2601 868385	ALEKSANDR KUZNECOV	{"phone": "+70337599585"}
0005434947916	2C7208	8402 427197	DENIS IVANOV	{"phone": "+70047250528"}
0005434947917	2C7208	9105 852157	IRINA MOROZOVA	{"email": "i.morozova1975@postgrespro.ru", "phone": "+70199961159"}
0005434947918	2C7208	0669 806738	VASILIY FEDOTOV	{"email": "vfedotov-15061965@postgrespro.ru", "phone": "+70082607907"}
0005434947919	0BA3B1	0510 265914	NINA GRISHINA	{"phone": "+70993911251"}
0005434947920	164DE2	6539 298201	NATALYA KOROLEVA	{"email": "natalya.koroleva1967@postgrespro.ru", "phone": "+70477046864"}
0005434947921	164DE2	0556 146502	SERGEY MIKHAYLOV	{"phone": "+70980260093"}
0005434947922	0C6D56	7493 090170	OLGA KUZNECOVA	{"email": "kuznecova-olga-08061986@postgrespro.ru", "phone": "+70721349097"}
0005434947923	D6AE78	1295 142677	EKATERINA TROFIMOVA	{"phone": "+70404029558"}
0005434947924	D0C7C6	4753 623792	NATALYA MEDVEDEVA	{"phone": "+70332246488"}
0005434947925	402727	1839 716914	KSENIYA MAKSIMOVA	{"phone": "+70806319326"}
0005434947926	C13B78	8890 861201	VLADIMIR CHERNOV	{"email": "chernov-vladimir_041968@postgrespro.ru", "phone": "+70731700657"}
0005434947927	EC463E	7863 835791	ILYA DENISOV	{"email": "ilya-denisov-031976@postgrespro.ru", "phone": "+70646257528"}
0005434947928	8D1446	9532 741479	LARISA VOLKOVA	{"email": "l-volkova121976@postgrespro.ru", "phone": "+70859568213"}
0005434947929	C18C2C	2546 428714	LYUBOV FEDOROVA	{"email": "lfedorova.1985@postgrespro.ru", "phone": "+70649920869"}
0005434947930	C18C2C	7878 991290	OLGA YUDINA	{"phone": "+70178160610"}
0005434947931	986D3F	5041 852856	STANISLAV KOROLEV	{"phone": "+70222990472"}
0005434947932	77200E	6598 089851	MARINA KOLESNIKOVA	{"phone": "+70027933279"}
0005434947933	26F393	8482 648908	SERGEY TIMOFEEV	{"email": "stimofeev_051959@postgrespro.ru", "phone": "+70860408614"}
0005434947934	A673E8	9048 072656	NIKOLAY ROMANOV	{"email": "nikolay-romanov-1968@postgrespro.ru", "phone": "+70900536513"}
0005434947935	A673E8	6436 324284	YULIYA IVANOVA	{"email": "ivanova.y-1974@postgrespro.ru", "phone": "+70292181994"}
0005434947936	73A35A	5960 994203	ALEKSANDR ZAYCEV	{"phone": "+70918996035"}
0005434947937	E8D42B	8705 045131	ALEKSEY SOROKIN	{"email": "aleksey_sorokin-051970@postgrespro.ru", "phone": "+70059635251"}
0005434947938	F3D7FD	5421 158713	IRINA POPOVA	{"email": "popova-irina_12021973@postgrespro.ru", "phone": "+70290726655"}
0005434947939	41E22E	6909 265852	NIKOLAY NIKITIN	{"email": "nikitin.nikolay-20101971@postgrespro.ru", "phone": "+70579216123"}
0005434947940	53BCC7	5695 596032	LYUDMILA TARASOVA	{"email": "tarasova_lyudmila.021975@postgrespro.ru", "phone": "+70526293940"}
0005434947941	A50C33	9655 843547	ALEKSANDR MARTYNOV	{"phone": "+70018486658"}
0005434947942	A50C33	5125 120636	MAKSIM POPOV	{"phone": "+70529204043"}
0005434947943	9235E2	0993 886372	ARINA POPOVA	{"email": "popovaa-091969@postgrespro.ru", "phone": "+70297002453"}
0005434947944	9235E2	7817 177593	ANDREY YAKOVLEV	{"email": "andrey.yakovlev29041974@postgrespro.ru", "phone": "+70264818033"}
0005434947945	4571EC	2837 807305	NIKOLAY DENISOV	{"phone": "+70405702323"}
0005434947946	4571EC	0590 134595	TATYANA OSIPOVA	{"email": "osipova_t1965@postgrespro.ru", "phone": "+70708532501"}
0005434947947	BD6020	4151 221924	OLGA EFIMOVA	{"email": "olga-efimova-1970@postgrespro.ru", "phone": "+70697894809"}
0005434947948	BD6020	1242 187758	EVGENIY ABRAMOV	{"email": "evgeniy-abramov.15081967@postgrespro.ru", "phone": "+70122441167"}
0005434947949	8838D4	9377 581292	NADEZHDA MATVEEVA	{"phone": "+70582937154"}
0005434947950	8838D4	7865 104399	VENIAMIN ALEKSEEV	{"phone": "+70981620332"}
0005434947951	50C6E8	3859 302645	NINA VASILEVA	{"phone": "+70353737138"}
0005434947952	27A795	0732 087498	ALEKSANDR KOZLOV	{"phone": "+70144803770"}
0005434947953	27A795	6593 392579	VIKTORIYA ANTONOVA	{"phone": "+70601876440"}
0005434947954	FAE5F7	7439 151065	EKATERINA MAKSIMOVA	{"email": "maksimova.e.031973@postgrespro.ru", "phone": "+70398943667"}
0005434947955	FD2A90	6361 193307	INNA KRASNOVA	{"email": "krasnovainna_1975@postgrespro.ru", "phone": "+70691470672"}
0005434947956	FD2A90	1536 134616	ALEKSEY KONOVALOV	{"phone": "+70391133464"}
0005434947957	3EF409	9993 635360	MARINA MALYSHEVA	{"phone": "+70403589472"}
0005434947958	C1114F	3773 488259	MARAT ZAYCEV	{"phone": "+70348881290"}
0005434947959	C1114F	7138 291112	ANVAR ROMANOV	{"email": "aromanov_09111974@postgrespro.ru", "phone": "+70021679260"}
0005434947960	07F749	0342 374923	ELENA ROMANOVA	{"email": "romanova.e.1980@postgrespro.ru", "phone": "+70484449324"}
0005434947961	F94508	9454 279810	OLGA SERGEEVA	{"phone": "+70315430363"}
0005434947962	AC8F31	3431 880917	NINA SOLOVEVA	{"phone": "+70450382232"}
0005434947963	11F4CF	3059 255426	VITALIY MIKHAYLOV	{"phone": "+70122871196"}
0005434947964	1CF4E6	9993 378274	MARIYA KUZMINA	{"email": "m-kuzmina_121968@postgrespro.ru", "phone": "+70905333888"}
0005434947965	380ACE	2679 291932	NINA BARANOVA	{"phone": "+70548784703"}
0005434947966	380ACE	6869 791978	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr-051967@postgrespro.ru", "phone": "+70072946575"}
0005434947967	ED2010	7191 555388	VALENTINA RODIONOVA	{"email": "v_rodionova.28121964@postgrespro.ru", "phone": "+70359067611"}
0005434948082	C56C96	6766 682985	GENNADIY KUZNECOV	{"phone": "+70332551011"}
0005434947968	FE5D72	3161 634383	SERGEY MARTYNOV	{"email": "martynov.sergey081984@postgrespro.ru", "phone": "+70949028804"}
0005434947969	FE5D72	1587 794976	DANIL GAVRILOV	{"phone": "+70074066207"}
0005434947970	0EAA4F	1874 316671	MAKSIM ORLOV	{"phone": "+70465243189"}
0005434947971	91E5B6	7532 438667	ANNA PETROVA	{"email": "petrova_a101963@postgrespro.ru", "phone": "+70950450808"}
0005434947972	F0E035	2853 941748	ANZHELIKA IVANOVA	{"phone": "+70582342166"}
0005434947973	F0E035	5905 160592	MIKHAIL MEDVEDEV	{"phone": "+70012011784"}
0005434947974	8F7894	7014 545979	VIKTOR IVANOV	{"phone": "+70840722122"}
0005434947975	F29703	0054 336786	LIDIYA FILIPPOVA	{"email": "filippova.l12071983@postgrespro.ru", "phone": "+70137487380"}
0005434947976	13C976	9729 185746	ALEKSEY BELOV	{"email": "aleksey.belov-20121970@postgrespro.ru", "phone": "+70194865471"}
0005434947977	13C976	1956 721119	SVETLANA ILINA	{"email": "ilina_s_17091964@postgrespro.ru", "phone": "+70718203723"}
0005434947978	1718B1	0761 077750	ZUKHRA MAKAROVA	{"phone": "+70749758177"}
0005434947979	1718B1	8745 748905	KLAVDIYA NIKITINA	{"email": "nikitinaklavdiya-01031970@postgrespro.ru", "phone": "+70029470459"}
0005434947980	A94DE8	9661 273545	ZINAIDA DANILOVA	{"phone": "+70290565284"}
0005434947981	A94DE8	5706 296300	POLINA MAKSIMOVA	{"phone": "+70614606792"}
0005434947982	A94DE8	3871 913451	GALINA KUZNECOVA	{"phone": "+70163719176"}
0005434947983	A94DE8	7796 202273	LYUDMILA TARASOVA	{"phone": "+70065368380"}
0005434947984	4A1524	9075 595596	MIKHAIL NAZAROV	{"phone": "+70020768901"}
0005434947985	C22B83	1071 888948	DMITRIY ANDREEV	{"phone": "+70507942585"}
0005434947986	3E86C9	3461 201697	ALEKSANDR PAVLOV	{"phone": "+70420366456"}
0005434947987	3E86C9	1284 185418	ALEKSANDR ZAYCEV	{"email": "a.zaycev_01061966@postgrespro.ru", "phone": "+70818917903"}
0005434947988	596A04	0051 168122	NADEZHDA NIKIFOROVA	{"phone": "+70353392837"}
0005434947989	596A04	8021 481906	OKSANA NIKOLAEVA	{"email": "nikolaevao_24061978@postgrespro.ru", "phone": "+70949742553"}
0005434948112	57522E	9375 547682	OLGA MOISEEVA	{"phone": "+70724234044"}
0005434947990	C99395	0418 950996	ALEKSANDR FEDOROV	{"email": "aleksandrfedorov.011963@postgrespro.ru", "phone": "+70910526399"}
0005434947991	C99395	3187 898814	ANNA SAVELEVA	{"phone": "+70094841455"}
0005434947992	273B17	7110 096369	IVAN KOZLOV	{"phone": "+70472573370"}
0005434947993	643079	6619 075334	ELIZAVETA YAKOVLEVA	{"phone": "+70077545889"}
0005434947994	643079	3494 833691	OLESYA ILINA	{"phone": "+70864309347"}
0005434947995	9AA8CD	0958 102913	VIKTOR VASILEV	{"email": "viktor.vasilev_1968@postgrespro.ru", "phone": "+70399945539"}
0005434947996	7FEE02	8940 028141	IVAN ALEKSEEV	{"email": "alekseev_i-24021963@postgrespro.ru", "phone": "+70641781759"}
0005434947997	7FEE02	1476 073818	OLGA TIMOFEEVA	{"phone": "+70972627640"}
0005434947998	6704DE	1920 070080	NINA FROLOVA	{"email": "frolova_n.18111976@postgrespro.ru", "phone": "+70272163547"}
0005434947999	7425D5	3011 507657	SERGEY BORISOV	{"email": "borisov_s_1976@postgrespro.ru", "phone": "+70360741371"}
0005434948000	800AE1	5246 818669	SERGEY KRASNOV	{"email": "s.krasnov_04101970@postgrespro.ru", "phone": "+70620795509"}
0005434948001	D3C56C	9428 113935	OKSANA VASILEVA	{"phone": "+70816139963"}
0005434948002	F3C888	4747 318893	ZINAIDA STEPANOVA	{"email": "stepanovaz.011984@postgrespro.ru", "phone": "+70010661939"}
0005434948003	AB5050	4214 872497	ARTEM MATVEEV	{"phone": "+70003871190"}
0005434948004	33A877	9311 467983	SERGEY SEMENOV	{"email": "sergey.semenov.081975@postgrespro.ru", "phone": "+70790521640"}
0005434948005	1600D6	1756 890440	NATALYA BOGDANOVA	{"phone": "+70509448608"}
0005434948006	B144DE	2861 323122	OLGA KULIKOVA	{"phone": "+70555668033"}
0005434948007	C22F51	9419 273505	ANATOLIY GAVRILOV	{"phone": "+70777828062"}
0005434948008	C22F51	8014 554982	ANASTASIYA PETROVA	{"email": "petrova_anastasiya.071973@postgrespro.ru", "phone": "+70185758293"}
0005434948009	A71F64	3214 344525	IVAN POPOV	{"phone": "+70092537368"}
0005434948010	A71F64	7406 748770	NATALYA FOMINA	{"email": "n-fomina_11111964@postgrespro.ru", "phone": "+70830220518"}
0005434948011	41F1C2	9023 240128	ARTEM CHERNOV	{"email": "artem_chernov101969@postgrespro.ru", "phone": "+70310763301"}
0005434948012	875252	2902 859025	VITALIY ABRAMOV	{"phone": "+70110679814"}
0005434948013	F28A99	5438 546758	ALEKSANDRA POLYAKOVA	{"email": "polyakova.aleksandra_1976@postgrespro.ru", "phone": "+70809891376"}
0005434948014	49F4B2	0164 029161	MARINA KOZLOVA	{"phone": "+70761119470"}
0005434948015	121826	0871 380759	ELENA NIKOLAEVA	{"phone": "+70262681657"}
0005434948016	A7DD2D	0789 964204	YURIY NIKITIN	{"phone": "+70875971571"}
0005434948017	ACA32B	0253 941701	SERGEY IVANOV	{"phone": "+70718677513"}
0005434948018	ACA32B	6766 198663	ANTON MAKSIMOV	{"email": "a-maksimov.101960@postgrespro.ru", "phone": "+70122522387"}
0005434948019	26E3F1	6311 774914	IGOR DMITRIEV	{"phone": "+70173820656"}
0005434948020	20AEED	4590 906704	IRINA GORBUNOVA	{"phone": "+70059974664"}
0005434948021	20AEED	0494 374992	NADEZHDA KARPOVA	{"email": "nadezhdakarpova-1979@postgrespro.ru", "phone": "+70740330307"}
0005434948022	B17C5A	7092 646679	NAILYA DANILOVA	{"email": "n_danilova-1969@postgrespro.ru", "phone": "+70546713412"}
0005434948023	BEC25E	8159 911346	ALEKSANDR KOZLOV	{"phone": "+70866422728"}
0005434948024	7EB1E6	9943 872792	IVAN NOVIKOV	{"phone": "+70568309972"}
0005434948025	7EB1E6	7650 191908	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr1981@postgrespro.ru", "phone": "+70870636574"}
0005434948026	4A0F34	0536 864908	GALINA VOLKOVA	{"phone": "+70230110240"}
0005434948027	47DB54	7166 681486	MARIYA ORLOVA	{"email": "orlova_m-11071976@postgrespro.ru", "phone": "+70138115441"}
0005434948028	47DB54	7936 212035	NINA POPOVA	{"email": "n-popova-07071978@postgrespro.ru", "phone": "+70992665806"}
0005434948029	BF8853	6330 751824	ANDREY ZAKHAROV	{"phone": "+70037119080"}
0005434948030	E9AB48	9986 108869	VLADISLAV ALEKSANDROV	{"email": "vladislav-aleksandrov1966@postgrespro.ru", "phone": "+70686343248"}
0005434948031	E9AB48	0308 967093	EDUARD BELOV	{"email": "eduardbelov.041976@postgrespro.ru", "phone": "+70148106283"}
0005434948032	E8607E	8793 885257	VIKTORIYA ANDREEVA	{"phone": "+70772100576"}
0005434948033	E8607E	1346 100263	KONSTANTIN SCHERBAKOV	{"email": "scherbakov-k.28071970@postgrespro.ru", "phone": "+70640607658"}
0005434948034	5B1D06	6670 941295	LEONID PETROV	{"phone": "+70738617592"}
0005434948035	289F74	0688 083626	SERGEY KUZNECOV	{"phone": "+70023199038"}
0005434948036	772ACB	0811 027833	ALEKSANDR KARPOV	{"email": "karpov_aleksandr_041973@postgrespro.ru", "phone": "+70283432198"}
0005434948037	A9D771	5220 267068	GALINA ANTONOVA	{"phone": "+70945372084"}
0005434948038	0B45E2	4970 581138	SERGEY MAKSIMOV	{"email": "maksimovs.1976@postgrespro.ru", "phone": "+70079874263"}
0005434948039	0B45E2	6315 528340	VLADIMIR VASILEV	{"email": "vasilev-vladimir24011966@postgrespro.ru", "phone": "+70392781550"}
0005434948040	563163	4207 012031	TAMARA ZAKHAROVA	{"phone": "+70077723341"}
0005434948041	FE8666	1879 668172	VLADISLAV NAZAROV	{"phone": "+70819855151"}
0005434948042	832EF8	0835 124244	MAKSIM YAKOVLEV	{"phone": "+70387811574"}
0005434948043	7F1B9B	1476 841543	IVAN DAVYDOV	{"phone": "+70424949662"}
0005434948044	7F1B9B	2888 437631	YURIY KRASNOV	{"email": "krasnov-y_1973@postgrespro.ru", "phone": "+70242903119"}
0005434948045	3F802E	1787 434556	NATALYA EFIMOVA	{"email": "n_efimova_1982@postgrespro.ru", "phone": "+70851144696"}
0005434948046	3E5864	9586 415547	OLEG SMIRNOV	{"phone": "+70125951568"}
0005434948047	3E5864	0887 750688	DMITRIY GRIGOREV	{"phone": "+70636883388"}
0005434948048	AC271C	8656 312893	YULIYA AFANASEVA	{"email": "afanasevay-1973@postgrespro.ru", "phone": "+70120755506"}
0005434948049	5F60F6	9711 896166	VIKTOR KOZLOV	{"email": "kozlov-viktor-111975@postgrespro.ru", "phone": "+70031784412"}
0005434948050	5AC80A	2726 763155	VLADIMIR SAVELEV	{"email": "v.savelev-091968@postgrespro.ru", "phone": "+70898875368"}
0005434948051	C33354	4391 604475	LYUBOV PETROVA	{"email": "lyubov_petrova17031976@postgrespro.ru", "phone": "+70125731295"}
0005434948052	C33354	9302 982165	PETR KUZNECOV	{"phone": "+70803279536"}
0005434948053	639972	0925 665101	MARINA EFIMOVA	{"email": "m.efimova-011979@postgrespro.ru", "phone": "+70327263904"}
0005434948054	814757	2614 604644	VARVARA ZOTOVA	{"email": "varvara.zotova_091964@postgrespro.ru", "phone": "+70646582967"}
0005434948055	BEDCF5	2679 396200	DMITRIY NIKITIN	{"phone": "+70307191751"}
0005434948056	9EB7FB	8180 773429	NINA SOKOLOVA	{"phone": "+70318044976"}
0005434948057	9EB7FB	8884 807644	TATYANA VOLKOVA	{"email": "tatyana.volkova.10041960@postgrespro.ru", "phone": "+70564208138"}
0005434948058	05477F	5040 361708	POLINA MARTYNOVA	{"phone": "+70557429971"}
0005434948059	74984A	7252 442731	SVETLANA SMIRNOVA	{"phone": "+70667264376"}
0005434948060	74984A	2667 167778	OLESYA ANTONOVA	{"phone": "+70487034829"}
0005434948061	655C35	0125 545546	KONSTANTIN ANDREEV	{"phone": "+70327017616"}
0005434948062	6D3218	1621 628631	MIKHAIL MARTYNOV	{"phone": "+70297268294"}
0005434948063	2F6BF3	6967 722162	TATYANA GUSEVA	{"phone": "+70479917774"}
0005434948064	43D3FA	9251 148246	GULSINA KONOVALOVA	{"phone": "+70960147705"}
0005434948065	43D3FA	9289 715141	LARISA GERASIMOVA	{"phone": "+70893943742"}
0005434948066	F3306F	2107 672993	MIKHAIL SOKOLOV	{"email": "sokolovm_1964@postgrespro.ru", "phone": "+70631448578"}
0005434948067	F3306F	7046 849776	DMITRIY MOROZOV	{"email": "morozovdmitriy-091982@postgrespro.ru", "phone": "+70688231792"}
0005434948068	5022F5	0726 825966	TATYANA KULIKOVA	{"phone": "+70581747606"}
0005434948069	8B92FF	4173 351678	TATYANA NIKOLAEVA	{"phone": "+70649121428"}
0005434948070	B759FF	9953 645736	VERA ARKHIPOVA	{"phone": "+70187456915"}
0005434948071	B759FF	8297 765284	VASILISA TROFIMOVA	{"email": "trofimova_v-1982@postgrespro.ru", "phone": "+70250984982"}
0005434948072	9D69F1	9764 854736	VALENTINA IVANOVA	{"email": "valentina.ivanova28021971@postgrespro.ru", "phone": "+70204677828"}
0005434948073	631686	1742 948045	DIANA LEBEDEVA	{"phone": "+70081930788"}
0005434948074	59CD17	2765 224175	NATALYA SIDOROVA	{"phone": "+70248332169"}
0005434948075	FC0703	0163 930604	OLGA KALININA	{"phone": "+70549338774"}
0005434948076	822FC9	2637 748945	VERA AFANASEVA	{"phone": "+70285506376"}
0005434948077	822FC9	5394 476427	ALEKSANDR KULIKOV	{"email": "kulikov.aleksandr_121970@postgrespro.ru", "phone": "+70432230082"}
0005434948078	822FC9	8140 820761	OLGA ARKHIPOVA	{"phone": "+70031080602"}
0005434948079	B6A7FA	3323 636884	RAISA PAVLOVA	{"email": "rpavlova081970@postgrespro.ru", "phone": "+70667410825"}
0005434948080	6C608B	3430 519922	NIKITA SERGEEV	{"email": "nikita-sergeev.22091981@postgrespro.ru", "phone": "+70037281058"}
0005434948081	C511CB	0511 983091	DMITRIY KRASNOV	{"email": "krasnov_d-101976@postgrespro.ru", "phone": "+70652966589"}
0005434948083	C56C96	4218 494934	ELENA MATVEEVA	{"phone": "+70701101465"}
0005434948084	92AEED	8175 580762	NATALYA KOVALEVA	{"email": "kovaleva.natalya12071961@postgrespro.ru", "phone": "+70963154152"}
0005434948085	92AEED	3454 523905	MARIYA SCHERBAKOVA	{"phone": "+70198485340"}
0005434948086	C53A55	8646 659430	GRIGORIY VOLKOV	{"email": "grigoriy-volkov.1973@postgrespro.ru", "phone": "+70628124878"}
0005434948087	CC06E4	6378 326576	IGOR SOLOVEV	{"email": "igor-solovev_061976@postgrespro.ru", "phone": "+70077455599"}
0005434948088	CC06E4	4377 819479	ANASTASIYA VOLKOVA	{"email": "anastasiyavolkova-1971@postgrespro.ru", "phone": "+70222739699"}
0005434948089	CC06E4	4991 664018	SERGEY NIKOLAEV	{"phone": "+70029208639"}
0005434948090	B0CD03	5678 661764	ALEKSANDR ANTONOV	{"email": "antonova-17101975@postgrespro.ru", "phone": "+70255977491"}
0005434948091	E0CCD8	8231 304076	LIDIYA IVANOVA	{"email": "ivanova.l.15031966@postgrespro.ru", "phone": "+70552952434"}
0005434948092	D9BD15	8230 756869	LYUDMILA GRISHINA	{"phone": "+70741186370"}
0005434948093	D9BD15	2130 218061	ANASTASIYA ZAYCEVA	{"email": "zayceva.anastasiya011969@postgrespro.ru", "phone": "+70098495435"}
0005434948094	2ED20F	6572 272503	VLADIMIR NIKOLAEV	{"phone": "+70128949530"}
0005434948095	2ED20F	8170 277869	NIKOLAY KOZLOV	{"email": "kozlov_n041981@postgrespro.ru", "phone": "+70023504035"}
0005434948096	943A12	5693 310205	ANTONINA NIKOLAEVA	{"email": "nikolaeva_a.021979@postgrespro.ru", "phone": "+70439970989"}
0005434948097	726668	7835 321744	NIKOLAY DENISOV	{"email": "denisov-nikolay011975@postgrespro.ru", "phone": "+70506905674"}
0005434948098	5BEEFB	1531 529331	VERA TIMOFEEVA	{"email": "timofeeva_vera_05111979@postgrespro.ru", "phone": "+70957327471"}
0005434948099	67F2AB	7285 977896	VENERA TIKHONOVA	{"phone": "+70008259862"}
0005434948100	E7FC33	5564 624332	VLADIMIR KONOVALOV	{"email": "konovalov_vladimir-071975@postgrespro.ru", "phone": "+70469404371"}
0005434948101	E7FC33	8846 223881	ALLA IVANOVA	{"phone": "+70907019587"}
0005434948102	323342	5326 479790	AMIR KISELEV	{"email": "kiselev_amir.1967@postgrespro.ru", "phone": "+70944737997"}
0005434948103	C426DE	7744 284258	ANNA IVANOVA	{"phone": "+70038141330"}
0005434948104	ECCF8A	6464 923536	NIKOLAY ANTONOV	{"email": "antonov.n-101978@postgrespro.ru", "phone": "+70359331734"}
0005434948105	ECCF8A	5545 133583	SERGEY MARTYNOV	{"email": "martynov_sergey_101962@postgrespro.ru", "phone": "+70162178858"}
0005434948106	3E9596	1607 193130	KRISTINA SOLOVEVA	{"email": "soloveva-kristina.1972@postgrespro.ru", "phone": "+70237877801"}
0005434948107	132BFF	7575 791194	VALENTINA DENISOVA	{"email": "denisova_valentina-1982@postgrespro.ru", "phone": "+70239102810"}
0005434948108	894469	1068 793489	ALEKSANDR PETROV	{"phone": "+70122930225"}
0005434948109	894469	1030 702327	VLADIMIR ORLOV	{"phone": "+70548063474"}
0005434948110	CE40E6	0133 462238	ELENA FILIPPOVA	{"email": "filippovaelena-101974@postgrespro.ru", "phone": "+70293542915"}
0005434948111	98BBAE	7247 354517	ANASTASIYA GUSEVA	{"email": "aguseva_101976@postgrespro.ru", "phone": "+70602655414"}
0005434948113	57522E	0351 825525	GULNAZ KRASNOVA	{"email": "krasnova_gulnaz07051965@postgrespro.ru", "phone": "+70554033888"}
0005434948114	57522E	8165 515033	NADEZHDA NOVIKOVA	{"email": "nadezhda-novikova.03121966@postgrespro.ru", "phone": "+70249412046"}
0005434948115	9AB8B7	5975 918443	LYUDMILA VOLKOVA	{"email": "lyudmila_volkova.1973@postgrespro.ru", "phone": "+70796019075"}
0005434948116	084F7C	1829 902028	NATALYA STEPANOVA	{"phone": "+70106036180"}
0005434948117	084F7C	4046 350562	GENNADIY SAVELEV	{"email": "savelev.g1964@postgrespro.ru", "phone": "+70963533573"}
0005434948118	A9069F	7430 451772	IRINA KUZNECOVA	{"email": "kuznecova.i08071976@postgrespro.ru", "phone": "+70788044719"}
0005434948119	264A30	8765 553619	KLAVDIYA NAZAROVA	{"phone": "+70635312948"}
0005434948120	264A30	6437 337039	ALEKSEY IVANOV	{"phone": "+70380717164"}
0005434948121	72347A	4005 003713	LYUBOV GORBUNOVA	{"phone": "+70941595216"}
0005434948122	BB28C4	3830 546609	VLADIMIR MIRONOV	{"phone": "+70474593685"}
0005434948123	BB28C4	8539 576241	MIKHAIL SIDOROV	{"email": "sidorovmikhail.05051972@postgrespro.ru", "phone": "+70721018925"}
0005434948124	E7119E	2132 030510	PETR VOLKOV	{"phone": "+70113760429"}
0005434948125	E564E8	1839 177333	ALEKSANDR MOISEEV	{"email": "a-moiseev_11051976@postgrespro.ru", "phone": "+70524219397"}
0005434948126	96F8A1	6108 012788	NADEZHDA PAVLOVA	{"phone": "+70184974783"}
0005434948127	96F8A1	6579 743712	LYUDMILA GRISHINA	{"phone": "+70151272874"}
0005434948128	57E294	3474 373331	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov-091969@postgrespro.ru", "phone": "+70395908060"}
0005434948129	57E294	5017 520800	STANISLAV DAVYDOV	{"phone": "+70494299139"}
0005434948130	57E294	9121 142870	RAISA KONDRATEVA	{"phone": "+70697060962"}
0005434948131	6A69DD	4915 716622	IRINA MATVEEVA	{"email": "matveeva.irina-20071974@postgrespro.ru", "phone": "+70372830273"}
0005434948132	6A69DD	7064 665801	VASILIY TARASOV	{"phone": "+70243756595"}
0005434948133	D45669	9924 844814	GALINA ANTONOVA	{"phone": "+70371436753"}
0005434948134	D45669	4921 704147	NATALYA KUZNECOVA	{"email": "natalya-kuznecova.081978@postgrespro.ru", "phone": "+70846505195"}
0005434948135	D45669	3741 488805	ALEKSEY MARTYNOV	{"email": "aleksey.martynov20121974@postgrespro.ru", "phone": "+70214382199"}
0005434948136	9FB34E	6365 500578	SERGEY KUZNECOV	{"phone": "+70613584487"}
0005434948137	7C3C21	8262 365264	ELENA POLYAKOVA	{"email": "polyakova_elena.1977@postgrespro.ru", "phone": "+70355401196"}
0005434948138	9FD833	6710 627074	NATALYA ZAYCEVA	{"phone": "+70657403087"}
0005434948139	7CB4AA	8608 862766	ARTEM NIKOLAEV	{"email": "artem.nikolaev-121964@postgrespro.ru", "phone": "+70868725493"}
0005434948140	7CB4AA	2201 558452	ELENA TIKHONOVA	{"email": "tikhonova_e.14021965@postgrespro.ru", "phone": "+70974182416"}
0005434948141	629F11	5357 469509	TATYANA MELNIKOVA	{"phone": "+70257166104"}
0005434948142	629F11	2993 804243	ANASTASIYA KISELEVA	{"phone": "+70398190345"}
0005434948143	CED9C6	5518 417508	NATALYA IVANOVA	{"email": "ivanova.natalya.1971@postgrespro.ru", "phone": "+70584968487"}
0005434948144	CED9C6	8041 916496	ALEKSANDRA IVANOVA	{"email": "ivanova-a-041967@postgrespro.ru", "phone": "+70616674307"}
0005434948145	CED9C6	4483 515708	VENIAMIN KUZNECOV	{"phone": "+70371167692"}
0005434948146	CED9C6	0340 783315	ALSU FILIPPOVA	{"phone": "+70532177411"}
0005434948147	6D6AD2	9510 124600	OLGA GAVRILOVA	{"email": "gavrilova_olga21011962@postgrespro.ru", "phone": "+70624241470"}
0005434948148	476850	4088 677832	IGOR SAVELEV	{"phone": "+70342109922"}
0005434948149	D0A53E	3935 112276	ELENA IVANOVA	{"email": "elena-ivanova.061978@postgrespro.ru", "phone": "+70959185027"}
0005434948150	50E18E	8818 618357	OLGA STEPANOVA	{"email": "olga_stepanova-071971@postgrespro.ru", "phone": "+70202137111"}
0005434948151	20E2FE	8597 269962	DAMIR SAVELEV	{"email": "damirsavelev_1973@postgrespro.ru", "phone": "+70402093642"}
0005434948152	795F71	0905 819612	ARTEM MELNIKOV	{"email": "a.melnikov-06071961@postgrespro.ru", "phone": "+70921185942"}
0005434948153	A0FF5C	5113 561166	SEMEN KRASNOV	{"email": "semen_krasnov-111977@postgrespro.ru", "phone": "+70704644467"}
0005434948154	A0FF5C	4095 530835	ALBERT GORBUNOV	{"phone": "+70449678043"}
0005434948155	BD02C5	3208 226648	VIKTOR SCHERBAKOV	{"email": "viktor-scherbakov.091974@postgrespro.ru", "phone": "+70728990774"}
0005434948156	BD02C5	9433 623722	DMITRIY PETROV	{"email": "petrov-d1983@postgrespro.ru", "phone": "+70659584993"}
0005434948157	84A82D	7058 340009	SVETLANA FADEEVA	{"phone": "+70416629786"}
0005434948158	84A82D	0733 059141	SERGEY ZHURAVLEV	{"phone": "+70438358543"}
0005434948159	9EC710	4177 015355	ALEKSANDR VOLKOV	{"phone": "+70552534118"}
0005434948160	9EC710	8088 781879	IVAN IVANOV	{"phone": "+70955117201"}
0005434948161	04A038	5606 179231	YURIY GAVRILOV	{"email": "gavrilov-y_051965@postgrespro.ru", "phone": "+70053032517"}
0005434948162	04A038	0114 726401	OLGA ZAYCEVA	{"phone": "+70754856689"}
0005434948163	04A038	7646 778780	TAMARA ZAYCEVA	{"email": "t.zayceva09071971@postgrespro.ru", "phone": "+70789124789"}
0005434948164	86E2C5	6798 720928	MIKHAIL VASILEV	{"phone": "+70221175579"}
0005434948165	54BD02	0799 325112	ELENA SEMENOVA	{"phone": "+70741347949"}
0005434948166	54BD02	8472 776574	ANNA MASLOVA	{"email": "anna-maslova-16031969@postgrespro.ru", "phone": "+70685444198"}
0005434948167	5F4814	7914 656920	SERGEY PETROV	{"email": "sergey_petrov.19111974@postgrespro.ru", "phone": "+70850863452"}
0005434948168	0659C8	8116 068539	ZINAIDA NIKIFOROVA	{"email": "z.nikiforova.11091959@postgrespro.ru", "phone": "+70610095730"}
0005434948169	448722	8483 947407	TATYANA MARTYNOVA	{"phone": "+70127809115"}
0005434948170	448722	6894 156476	IGOR FILIPPOV	{"email": "filippovi081975@postgrespro.ru", "phone": "+70084179206"}
0005434948171	448722	0724 775951	DMITRIY ANDREEV	{"email": "andreevdmitriy.101977@postgrespro.ru", "phone": "+70747166388"}
0005434948172	CC29BC	4299 973269	VLADIMIR NAUMOV	{"email": "vnaumov1977@postgrespro.ru", "phone": "+70288321097"}
0005434948173	D34AEF	3998 442465	VIKTOR GORBUNOV	{"phone": "+70590057270"}
0005434948174	74984B	5495 340586	VLADIMIR ALEKSEEV	{"email": "alekseevv-1972@postgrespro.ru", "phone": "+70647646545"}
0005434948175	74984B	0685 051459	VITALIY NOVIKOV	{"phone": "+70769292429"}
0005434948176	74984B	6580 025219	VASILIY NOVIKOV	{"email": "vasiliynovikov_1976@postgrespro.ru", "phone": "+70352181771"}
0005434948177	17EEA1	9300 825390	VALERIY MOROZOV	{"phone": "+70271119562"}
0005434948178	879373	5852 737598	OKSANA POPOVA	{"phone": "+70714607053"}
0005434948179	8A2900	9973 895131	ANNA KAZAKOVA	{"email": "anna_kazakova.1974@postgrespro.ru", "phone": "+70494260999"}
0005434948180	03CAA2	6627 130054	TATYANA MEDVEDEVA	{"email": "medvedeva_tatyana.111963@postgrespro.ru", "phone": "+70779273065"}
0005434948181	6F4884	9135 397191	VYACHESLAV SOKOLOV	{"email": "vyacheslav.sokolov1974@postgrespro.ru", "phone": "+70397946601"}
0005434948182	1634BF	0686 551433	NIKITA SHEVCHENKO	{"phone": "+70889744551"}
0005434948183	757E07	2746 512623	SERGEY KULIKOV	{"email": "kulikov-s_1966@postgrespro.ru", "phone": "+70529545324"}
0005434948184	F5B4FF	8531 928008	VASILISA STEPANOVA	{"phone": "+70328399062"}
0005434948185	636457	5938 125229	ANNA MALYSHEVA	{"phone": "+70178262530"}
0005434948186	10F4A8	4047 191405	ANNA ABRAMOVA	{"phone": "+70160920697"}
0005434948187	B22D0C	0877 673602	NIKOLAY KARPOV	{"email": "karpov.nikolay.021975@postgrespro.ru", "phone": "+70614729634"}
0005434948188	47C96C	9939 077926	TAMARA IVANOVA	{"phone": "+70651407054"}
0005434948189	47C96C	4666 150228	ALEKSEY DENISOV	{"email": "denisov-a-031965@postgrespro.ru", "phone": "+70534556872"}
0005434948190	33C5E6	9774 826677	NATALYA ZOTOVA	{"email": "zotova-natalya011969@postgrespro.ru", "phone": "+70559534520"}
0005434948191	33C5E6	5071 564188	VITALIY KAZAKOV	{"phone": "+70457006874"}
0005434948192	735DD4	3517 809637	ALEKSEY ROMANOV	{"email": "romanov_a111978@postgrespro.ru", "phone": "+70701116709"}
0005434948193	EC850D	7821 951683	EVGENIY IVANOV	{"phone": "+70953244823"}
0005434948194	EC850D	1172 365115	IRINA IVANOVA	{"phone": "+70499141753"}
0005434948195	2F0674	6625 888984	GLEB PETROV	{"email": "gleb-petrov14121977@postgrespro.ru", "phone": "+70393493352"}
0005434948196	A5C74F	3989 527783	EVGENIY IVANOV	{"phone": "+70266748544"}
0005434948197	562299	4575 579639	EKATERINA GUSEVA	{"email": "eguseva-041964@postgrespro.ru", "phone": "+70851765573"}
0005434948198	562299	5290 819018	DENIS CHERNOV	{"phone": "+70100032457"}
0005434948199	7F6F45	6419 770337	ELENA ALEKSEEVA	{"email": "alekseevaelena.1972@postgrespro.ru", "phone": "+70532899590"}
0005434948200	8E8A95	4468 702814	ALBERT SAVELEV	{"phone": "+70217637450"}
0005434948201	71C83C	6789 394698	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev_10021968@postgrespro.ru", "phone": "+70772028918"}
0005434948202	0C52EA	1252 184993	VLADIMIR YAKOVLEV	{"email": "yakovlev_vladimir29111980@postgrespro.ru", "phone": "+70312505653"}
0005434948203	0C52EA	5038 157919	GALINA ANDREEVA	{"email": "andreeva.galina.071967@postgrespro.ru", "phone": "+70081387593"}
0005434948204	0C52EA	7235 858237	IRINA OSIPOVA	{"phone": "+70739697460"}
0005434948205	06148E	1203 738575	OLESYA ABRAMOVA	{"email": "abramovaolesya.07111973@postgrespro.ru", "phone": "+70680066651"}
0005434948206	99B080	3146 119434	NIKOLAY STEPANOV	{"email": "stepanov_n_011969@postgrespro.ru", "phone": "+70807548487"}
0005434948207	2DB2C0	9947 693277	ANDREY MOISEEV	{"phone": "+70053747156"}
0005434948208	2DB2C0	1599 869021	VLADIMIR SIDOROV	{"phone": "+70225084051"}
0005434948209	35A051	4825 999803	MARINA IVANOVA	{"email": "ivanova.marina.24091961@postgrespro.ru", "phone": "+70287093291"}
0005434948210	5EAD9B	6859 451750	MARAT KISELEV	{"email": "marat_kiselev_1975@postgrespro.ru", "phone": "+70818862867"}
0005434948211	5EAD9B	3113 182010	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin-1961@postgrespro.ru", "phone": "+70692425894"}
0005434948212	3E01EF	3947 493390	ALEKSANDR SOROKIN	{"phone": "+70807141337"}
0005434948213	3E01EF	7556 930548	YULIYA SEMENOVA	{"email": "semenova_yuliya071967@postgrespro.ru", "phone": "+70321137201"}
0005434948214	8891DA	5179 554055	IRINA FILATOVA	{"phone": "+70063747326"}
0005434948215	2CA504	6296 881207	ELENA GERASIMOVA	{"email": "gerasimova_e_111959@postgrespro.ru", "phone": "+70766915057"}
0005434948216	AC6BA2	3882 200434	ALLA VOLKOVA	{"phone": "+70948522221"}
0005434948217	AC6BA2	0627 810031	YAKOV PAVLOV	{"email": "pavlov-y_1974@postgrespro.ru", "phone": "+70426333827"}
0005434948218	AC6BA2	9576 127430	MARGARITA KOROLEVA	{"phone": "+70847928875"}
0005434948219	7DEF62	5361 140434	EGOR GUSEV	{"email": "gusev-egor1980@postgrespro.ru", "phone": "+70256309246"}
0005434948220	F19954	3253 567993	GERMAN SEMENOV	{"email": "g_semenov-081978@postgrespro.ru", "phone": "+70416920492"}
0005434948221	543CF9	1205 424015	GENNADIY SOKOLOV	{"email": "sokolov.gennadiy_1975@postgrespro.ru", "phone": "+70884725137"}
0005434948222	BFCDD6	6139 064356	VIKTOR KUZNECOV	{"email": "viktor-kuznecov-16081971@postgrespro.ru", "phone": "+70739312215"}
0005434948223	0F360C	1762 364992	SEMEN MOROZOV	{"phone": "+70249486206"}
0005434948224	3A5A4B	1119 304795	TATYANA DANILOVA	{"email": "t-danilova.1973@postgrespro.ru", "phone": "+70335309733"}
0005434948225	3A5A4B	2379 845076	EVGENIY IVANOV	{"phone": "+70892531386"}
0005434948226	9B2D35	7030 720416	VALENTINA KISELEVA	{"phone": "+70189695270"}
0005434948227	953706	0136 611674	VLADIMIR KOROLEV	{"email": "vladimir-korolev_121974@postgrespro.ru", "phone": "+70228238170"}
0005434948228	341A57	8352 772292	LILIYA FADEEVA	{"email": "l-fadeeva.1972@postgrespro.ru", "phone": "+70403396326"}
0005434948229	02CE4C	5885 708337	VLADIMIR SEMENOV	{"email": "semenov.v-1988@postgrespro.ru", "phone": "+70699875138"}
0005434948230	DA88AB	0681 611309	ANDREY ANDREEV	{"email": "andreev-a_1981@postgrespro.ru", "phone": "+70779858237"}
0005434948231	6F06A3	6149 657169	DARYA NOVIKOVA	{"phone": "+70069464192"}
0005434948232	6F06A3	6582 510987	DENIS MOISEEV	{"phone": "+70826510229"}
0005434948233	FDF325	3144 207689	NINA PETROVA	{"email": "petrova.n-12041977@postgrespro.ru", "phone": "+70970521833"}
0005434948234	FDF325	7812 392596	LYAYSAN MIKHAYLOVA	{"phone": "+70772193747"}
0005434948235	4C4952	0119 577400	EKATERINA FROLOVA	{"email": "frolovaekaterina-011970@postgrespro.ru", "phone": "+70368771001"}
0005434948236	061597	7516 982480	ILDAR SEMENOV	{"email": "ildar.semenov.101963@postgrespro.ru", "phone": "+70854362731"}
0005434948237	367AF7	3787 103307	ALEKSANDRA ANTONOVA	{"phone": "+70096333388"}
0005434948238	367AF7	0799 205351	STANISLAV VOROBEV	{"phone": "+70523782295"}
0005434948239	367AF7	8075 962882	ANDREY MOISEEV	{"email": "andrey.moiseev_101961@postgrespro.ru", "phone": "+70309919609"}
0005434948240	447613	5038 247387	EVGENIY IVANOV	{"email": "ivanov_e-17111976@postgrespro.ru", "phone": "+70867729999"}
0005434948241	447613	5897 900800	PAVEL FROLOV	{"phone": "+70794523294"}
0005434948242	54C516	5057 156804	MARINA VLASOVA	{"phone": "+70388546793"}
0005434948243	3C98CA	9449 710421	TATYANA ISAEVA	{"email": "tatyana-isaeva1955@postgrespro.ru", "phone": "+70017010061"}
0005434948244	3C98CA	2855 687333	VIKTOR NAUMOV	{"phone": "+70364331377"}
0005434948245	EDF5EC	2528 173088	FEDOR GRIGOREV	{"phone": "+70015650330"}
0005434948246	AAEE6A	8981 030955	NINA PETROVA	{"email": "n-petrova-011968@postgrespro.ru", "phone": "+70739481965"}
0005434948247	AAEE6A	0365 296948	NIKOLAY IVANOV	{"phone": "+70672333656"}
0005434948248	146C9A	6691 690158	VIKTOR CHERNOV	{"email": "chernov-viktor_061975@postgrespro.ru", "phone": "+70430424726"}
0005434948249	98B787	8352 796781	TAISIYA SIDOROVA	{"phone": "+70884650757"}
0005434948250	687451	0769 546363	OLGA ANDREEVA	{"email": "andreeva_olga.081985@postgrespro.ru", "phone": "+70671018414"}
0005434948251	687451	9056 959483	GALINA ALEKSANDROVA	{"email": "galina_aleksandrova.23041956@postgrespro.ru", "phone": "+70543571876"}
0005434948252	0183D8	0390 962737	ANASTASIYA KUZNECOVA	{"email": "anastasiya_kuznecova-061979@postgrespro.ru", "phone": "+70880693041"}
0005434948253	0183D8	4852 708890	MAKSIM ZHURAVLEV	{"email": "maksimzhuravlev_031966@postgrespro.ru", "phone": "+70809022086"}
0005434948254	4BB1AD	3190 963353	EKATERINA KOROLEVA	{"email": "ekoroleva.011969@postgrespro.ru", "phone": "+70345428075"}
0005434948255	4BB1AD	6413 940279	KRISTINA POPOVA	{"email": "popova.kristina-041973@postgrespro.ru", "phone": "+70076230727"}
0005434948256	EF6375	8927 149463	LYUDMILA SAVELEVA	{"email": "lyudmila_saveleva_021973@postgrespro.ru", "phone": "+70839021420"}
0005434948257	EF6375	4393 935439	DMITRIY SOROKIN	{"phone": "+70382791030"}
0005434948258	321708	3968 064226	GENNADIY SERGEEV	{"email": "g-sergeev.021959@postgrespro.ru", "phone": "+70165670123"}
0005434948259	321708	4544 516528	VLADIMIR PAVLOV	{"email": "v.pavlov.07121973@postgrespro.ru", "phone": "+70015417647"}
0005434948260	3A8373	9795 100770	NATALYA KAZAKOVA	{"email": "n.kazakova-06021969@postgrespro.ru", "phone": "+70709597718"}
0005434948261	3A8373	4803 565167	ELENA KUZNECOVA	{"phone": "+70119211219"}
0005434948262	EBDBAB	3189 575712	ALEKSANDRA FILATOVA	{"phone": "+70434520003"}
0005434948263	699BDB	0274 187177	SVETLANA KONOVALOVA	{"email": "konovalova-s.1968@postgrespro.ru", "phone": "+70231503439"}
0005434948264	EFC1DD	4786 149749	SVETLANA NESTEROVA	{"email": "nesterova.s.24111960@postgrespro.ru", "phone": "+70751197275"}
0005434948265	DD26EA	5137 851248	VERA KOROLEVA	{"phone": "+70825262744"}
0005434948266	4B5787	1799 923323	TATYANA MELNIKOVA	{"email": "tmelnikova-1976@postgrespro.ru", "phone": "+70601892721"}
0005434948267	4B5787	0138 024655	OKSANA KOROLEVA	{"email": "koroleva_o1981@postgrespro.ru", "phone": "+70583239864"}
0005434948268	4B5787	6896 506173	MATVEY SOROKIN	{"email": "m_sorokin.1982@postgrespro.ru", "phone": "+70326685357"}
0005434950450	07AA53	0395 260201	SERGEY GUSEV	{"email": "sgusev.121967@postgrespro.ru", "phone": "+70477235826"}
0005434950451	07AA53	2764 385862	ALEKSANDRA SIDOROVA	{"email": "sidorova.a-081966@postgrespro.ru", "phone": "+70560180169"}
0005434950452	48C987	8478 127457	YULIYA POPOVA	{"email": "y_popova-031968@postgrespro.ru", "phone": "+70570447272"}
0005434950453	662D0D	8356 480731	DMITRIY KOZLOV	{"phone": "+70699222082"}
0005434950454	662D0D	7726 525515	SERGEY DMITRIEV	{"email": "dmitriev.sergey.1970@postgrespro.ru", "phone": "+70603414014"}
0005434950455	E04A3F	6840 653051	ALEKSEY ALEKSANDROV	{"phone": "+70876311353"}
0005434950456	876FBC	9345 286781	ALEKSANDR ORLOV	{"phone": "+70888178734"}
0005434950457	5FEEA9	7090 464807	ILYA PETROV	{"email": "i-petrov.1969@postgrespro.ru", "phone": "+70322417789"}
0005434950458	5FEEA9	6051 055188	SERGEY BONDARENKO	{"email": "bondarenko.s_1964@postgrespro.ru", "phone": "+70244457021"}
0005434950459	DFD97E	3446 874511	ANNA ANISIMOVA	{"email": "a.anisimova.03071967@postgrespro.ru", "phone": "+70168572684"}
0005434950460	DFD97E	3113 403643	VADIM MAKAROV	{"phone": "+70793725565"}
0005434950461	DFD97E	6404 887683	NATALYA FROLOVA	{"phone": "+70593836698"}
0005434950462	ACF5F5	5612 015534	LEONID KUZNECOV	{"phone": "+70098797795"}
0005434950463	52CFC5	7217 953831	YURIY TIKHONOV	{"email": "y-tikhonov-23081974@postgrespro.ru", "phone": "+70642606001"}
0005434950524	468CE8	9096 100439	KLAVDIYA ORLOVA	{"phone": "+70483824056"}
0005434950464	FCA187	0594 477887	KIRILL KUDRYASHOV	{"email": "k-kudryashov051973@postgrespro.ru", "phone": "+70708818071"}
0005434950465	248418	9733 715307	ANTON MARTYNOV	{"phone": "+70058827445"}
0005434950466	135B80	1169 676664	ALEKSANDR IVANOV	{"email": "ivanov_a_05101971@postgrespro.ru", "phone": "+70677688540"}
0005434950467	135B80	7952 390423	OLESYA KAZAKOVA	{"email": "kazakova-olesya_1971@postgrespro.ru", "phone": "+70599252441"}
0005434950468	5013DA	8999 586042	GALINA DANILOVA	{"email": "danilova.galina_03111980@postgrespro.ru", "phone": "+70117326836"}
0005434950469	93B0BB	6212 186868	TATYANA ZHURAVLEVA	{"phone": "+70107315265"}
0005434950470	267056	7100 041610	ANTONINA GRISHINA	{"phone": "+70698568126"}
0005434950471	331CE9	2776 636596	OLGA MOROZOVA	{"phone": "+70934693310"}
0005434950472	7C0F46	8223 311484	ANNA BELYAEVA	{"phone": "+70696155480"}
0005434950473	7C0F46	4505 825457	ALEKSEY MIKHAYLOV	{"email": "aleksey_mikhaylov-011971@postgrespro.ru", "phone": "+70114009708"}
0005434950474	FF712B	8562 349426	GALINA BORISOVA	{"phone": "+70889542435"}
0005434950475	E84B2A	7253 845464	NATALYA KOROLEVA	{"email": "korolevan_1977@postgrespro.ru", "phone": "+70881381140"}
0005434950476	E84B2A	8861 198556	PAVEL ZAKHAROV	{"phone": "+70136185537"}
0005434950477	4F5807	4776 741379	NADEZHDA MAKSIMOVA	{"email": "maksimova-n.1969@postgrespro.ru", "phone": "+70653910333"}
0005434950478	619E72	3356 766336	YULIYA MIKHAYLOVA	{"email": "mikhaylova.yuliya.24111968@postgrespro.ru", "phone": "+70220667259"}
0005434950479	619E72	4655 106208	YULIYA OVCHINNIKOVA	{"email": "y-ovchinnikova021980@postgrespro.ru", "phone": "+70620440859"}
0005434950480	4AB3E2	5130 340922	MARINA ILINA	{"email": "m_ilina-1968@postgrespro.ru", "phone": "+70005441145"}
0005434950481	3D196D	4597 711012	EKATERINA KAZAKOVA	{"phone": "+70241351911"}
0005434950482	3D196D	3260 028044	IRINA ALEKSANDROVA	{"phone": "+70665472009"}
0005434950483	3D196D	8718 938621	TAMARA KONOVALOVA	{"phone": "+70721468313"}
0005434950484	B1F984	8964 878523	MARIYA ANDREEVA	{"phone": "+70418287244"}
0005434950485	B1F984	3300 464431	IGOR KOZLOV	{"email": "kozlov-i-071987@postgrespro.ru", "phone": "+70139798732"}
0005434950486	B11089	0661 111755	EVGENIY STEPANOV	{"phone": "+70282936021"}
0005434950487	EAE093	1813 131095	NIKOLAY VASILEV	{"email": "nvasilev.06111981@postgrespro.ru", "phone": "+70666220716"}
0005434950488	98F525	1450 850805	VALERIY FEDOROV	{"email": "fedorovv.071958@postgrespro.ru", "phone": "+70200740912"}
0005434950489	B4922A	2208 962500	NIKOLAY NIKITIN	{"phone": "+70783152953"}
0005434950490	A61A88	6749 263891	VIKTOR FILIPPOV	{"phone": "+70706089886"}
0005434950491	FB4607	4999 096684	ANASTASIYA VASILEVA	{"phone": "+70238833978"}
0005434950492	FB4607	7702 414086	STEPAN PAVLOV	{"phone": "+70962762502"}
0005434950493	1E3CA0	4168 664205	DENIS ZHURAVLEV	{"email": "d.zhuravlev_13091968@postgrespro.ru", "phone": "+70192415521"}
0005434950494	1E3CA0	7327 148561	MARIYA NIKITINA	{"phone": "+70342530364"}
0005434950495	0B6AF0	0435 616597	OLGA KOZLOVA	{"email": "kozlova-o_18031970@postgrespro.ru", "phone": "+70487961435"}
0005434950496	A5E7D7	5120 748090	SERGEY ISAEV	{"email": "sergey.isaev-111963@postgrespro.ru", "phone": "+70495018898"}
0005434950497	A5E7D7	0777 632999	DENIS SOKOLOV	{"phone": "+70759131332"}
0005434950498	DED030	5632 093110	ALEKSANDRA ARKHIPOVA	{"email": "aleksandra-arkhipova.031972@postgrespro.ru", "phone": "+70587647737"}
0005434950499	DED030	7945 762284	EVGENIY MIKHAYLOV	{"email": "mikhaylov.evgeniy_07041969@postgrespro.ru", "phone": "+70048151803"}
0005434950500	4EE71D	7757 006665	TATYANA KOMAROVA	{"email": "komarovat_051977@postgrespro.ru", "phone": "+70445277932"}
0005434950501	7AD92A	2229 647419	IRINA TIKHONOVA	{"email": "tikhonova-irina.03071969@postgrespro.ru", "phone": "+70856993394"}
0005434950502	77FC7E	2899 829534	EKATERINA ANDREEVA	{"phone": "+70059447425"}
0005434950503	6F8963	6469 151869	DMITRIY IVANOV	{"email": "ivanov_d-051980@postgrespro.ru", "phone": "+70748687008"}
0005434950504	6F8963	4023 524900	DMITRIY POPOV	{"email": "dmitriy_popov_071980@postgrespro.ru", "phone": "+70766490168"}
0005434950505	16A59E	5248 651346	ANNA SERGEEVA	{"email": "sergeevaa-11021969@postgrespro.ru", "phone": "+70002829881"}
0005434950506	16A59E	1753 890649	IVAN ZAYCEV	{"phone": "+70481888572"}
0005434950507	5C0C7F	5906 265355	IVAN ALEKSEEV	{"phone": "+70250609719"}
0005434950508	21B931	9187 127454	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.041977@postgrespro.ru", "phone": "+70310181645"}
0005434950509	947B9C	9281 463435	DARYA ROMANOVA	{"email": "daryaromanova.011987@postgrespro.ru", "phone": "+70931335895"}
0005434950510	5C9D89	0916 092672	TAISIYA OVCHINNIKOVA	{"email": "taisiya.ovchinnikova.1973@postgrespro.ru", "phone": "+70174055718"}
0005434950511	5C9D89	7482 546872	ANATOLIY FEDOROV	{"phone": "+70613273603"}
0005434950512	720A24	3681 744297	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov.111962@postgrespro.ru", "phone": "+70491023116"}
0005434950513	720A24	8969 884405	VASILIY ALEKSEEV	{"email": "alekseev.vasiliy1980@postgrespro.ru", "phone": "+70954393298"}
0005434950514	8C926E	5517 495654	NINA ILINA	{"email": "nina-ilina_071977@postgrespro.ru", "phone": "+70129499464"}
0005434950515	FB201A	1736 163744	MIKHAIL ANDREEV	{"phone": "+70264073815"}
0005434950516	DE7C2F	5731 936709	SERGEY BONDARENKO	{"phone": "+70489060650"}
0005434950517	DE7C2F	5680 937067	GENNADIY GRIGOREV	{"email": "grigorevg-10061971@postgrespro.ru", "phone": "+70468297951"}
0005434950518	82AA82	1125 707193	MARIYA KUZNECOVA	{"phone": "+70773984109"}
0005434950519	C1ABA1	6196 712165	NATALYA KOVALEVA	{"phone": "+70183234485"}
0005434950520	15A5AC	7819 728115	ANASTASIYA POLYAKOVA	{"phone": "+70824526651"}
0005434950521	A6E17A	0418 224395	NATALYA MIKHAYLOVA	{"phone": "+70115838788"}
0005434950522	A6E17A	5754 236247	NADEZHDA SCHERBAKOVA	{"phone": "+70616172675"}
0005434950523	CD5A31	9571 405844	YURIY SOROKIN	{"email": "sorokiny_061970@postgrespro.ru", "phone": "+70623105384"}
0005434950525	F481F2	6939 967720	ANDREY ANDREEV	{"email": "andrey-andreev_121979@postgrespro.ru", "phone": "+70568714496"}
0005434950526	B36748	8188 694028	LINAR MAKAROV	{"email": "linar_makarov.051972@postgrespro.ru", "phone": "+70541067327"}
0005434950527	B36748	2240 444657	MARTA ZHURAVLEVA	{"phone": "+70220927668"}
0005434950528	35E88E	9383 801748	TATYANA POPOVA	{"email": "t.popova091973@postgrespro.ru", "phone": "+70946354036"}
0005434950529	35E88E	0534 189699	VERA EGOROVA	{"phone": "+70095280961"}
0005434950530	661F3D	9523 027656	DMITRIY KUZNECOV	{"email": "kuznecov.d-09031970@postgrespro.ru", "phone": "+70090744416"}
0005434950531	661F3D	9194 741680	ALEKSANDR NAZAROV	{"email": "a.nazarov-21051966@postgrespro.ru", "phone": "+70649184704"}
0005434950590	24B193	5305 107637	YURIY AFANASEV	{"phone": "+70216414523"}
0005434950532	909B0E	9815 239740	KSENIYA PETROVA	{"email": "petrova-kseniya.111976@postgrespro.ru", "phone": "+70282737402"}
0005434950533	C22D49	2617 332055	SVETLANA YAKOVLEVA	{"phone": "+70126196981"}
0005434950534	C22D49	7408 361895	KLAVDIYA MELNIKOVA	{"email": "klavdiya-melnikova041963@postgrespro.ru", "phone": "+70454606259"}
0005434950535	66D728	7286 981562	ALEKSEY NIKITIN	{"phone": "+70362528416"}
0005434950536	D50033	9593 204150	KIRILL SOROKIN	{"email": "ksorokin051967@postgrespro.ru", "phone": "+70746947183"}
0005434950537	577322	5641 830820	MAKSIM KOROLEV	{"email": "mkorolev_1968@postgrespro.ru", "phone": "+70162110396"}
0005434950538	94FCD0	2738 223586	INESSA MALYSHEVA	{"email": "malysheva-inessa29111966@postgrespro.ru", "phone": "+70789826869"}
0005434950539	B60AB0	9208 943870	KIRILL BARANOV	{"phone": "+70006964138"}
0005434950652	B81B6E	3230 243075	OKSANA FEDOROVA	{"phone": "+70176066632"}
0005434950540	A24076	8300 247584	ALEKSEY PAVLOV	{"email": "aleksey_pavlov_25081974@postgrespro.ru", "phone": "+70178236335"}
0005434950541	976B54	1907 924090	ALEKSANDR SCHERBAKOV	{"email": "scherbakova09121973@postgrespro.ru", "phone": "+70837375849"}
0005434950542	976B54	0784 883171	IRINA SCHERBAKOVA	{"email": "ischerbakova-081967@postgrespro.ru", "phone": "+70058517737"}
0005434950543	0AEC26	7205 147113	PAVEL IVANOV	{"phone": "+70951152097"}
0005434950544	0AEC26	3143 089216	KONSTANTIN EGOROV	{"phone": "+70849616746"}
0005434950545	E600FC	7214 207394	IRINA ERMAKOVA	{"email": "irinaermakova26031979@postgrespro.ru", "phone": "+70583377682"}
0005434950546	E600FC	5695 895443	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy25011964@postgrespro.ru", "phone": "+70010592175"}
0005434950547	B554F6	6528 989130	SVETLANA EFIMOVA	{"email": "svetlana-efimova_1985@postgrespro.ru", "phone": "+70092507101"}
0005434950548	2305F4	1262 889306	VLADISLAV TARASOV	{"email": "tarasovvladislav30051984@postgrespro.ru", "phone": "+70725348903"}
0005434950549	7BBE99	6513 568717	ALEKSANDR BORISOV	{"email": "borisov.a.041966@postgrespro.ru", "phone": "+70885688926"}
0005434950550	69EDD2	1397 164336	NADEZHDA SCHERBAKOVA	{"email": "scherbakovan-041972@postgrespro.ru", "phone": "+70955664869"}
0005434950551	5DD9F4	1173 842643	ALEKSANDR NOVIKOV	{"phone": "+70198842645"}
0005434950552	91807F	8770 758398	VALENTINA KOROLEVA	{"email": "valentinakoroleva-08051969@postgrespro.ru", "phone": "+70338078108"}
0005434950553	9500EC	5186 981703	NATALYA MAKAROVA	{"phone": "+70451411101"}
0005434950554	624DE9	6117 664819	KIRILL ANDREEV	{"phone": "+70909436629"}
0005434950555	8A641D	7516 119556	NELLYA ALEKSANDROVA	{"phone": "+70340989786"}
0005434950556	2A31C3	3746 899700	LYUDMILA KOROLEVA	{"phone": "+70427554267"}
0005434950557	0F679E	0397 406970	EKATERINA KONOVALOVA	{"email": "ekonovalova17071979@postgrespro.ru", "phone": "+70211003810"}
0005434950558	C09812	8178 534306	ALEKSANDR FROLOV	{"email": "frolov.aleksandr1972@postgrespro.ru", "phone": "+70134341914"}
0005434950559	87A5EF	1589 203301	ELENA MOROZOVA	{"email": "morozovaelena-091973@postgrespro.ru", "phone": "+70797340759"}
0005434950560	D58952	8888 457700	ALEKSANDR VOLKOV	{"phone": "+70508953499"}
0005434950561	D722D3	3414 103088	VLADIMIR STEPANOV	{"email": "stepanov-vladimir1970@postgrespro.ru", "phone": "+70715397757"}
0005434950562	C09DD7	5159 832767	OLGA NOVIKOVA	{"phone": "+70943512787"}
0005434950563	98D735	5586 106135	VALENTINA TITOVA	{"phone": "+70764438984"}
0005434950564	98D735	5042 590638	NATALIYA KRASNOVA	{"phone": "+70539096833"}
0005434950565	63C661	6784 050744	GEORGIY ILIN	{"phone": "+70530179226"}
0005434950566	57E09E	3903 701456	GALINA KUZNECOVA	{"email": "kuznecovagalina.02081971@postgrespro.ru", "phone": "+70143761007"}
0005434950567	57E09E	9807 863251	DMITRIY SOROKIN	{"phone": "+70944452401"}
0005434950568	9D8354	6713 511710	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr111966@postgrespro.ru", "phone": "+70384737642"}
0005434950569	9D8354	2371 670696	GALINA AFANASEVA	{"email": "g-afanaseva-01021966@postgrespro.ru", "phone": "+70907125303"}
0005434950570	6748A4	4906 001192	SERGEY MARTYNOV	{"email": "martynov_sergey_111982@postgrespro.ru", "phone": "+70322052384"}
0005434950571	74C173	3067 132775	VLADIMIR MIKHAYLOV	{"email": "mikhaylov_vladimir-01101961@postgrespro.ru", "phone": "+70896831939"}
0005434950572	312464	6860 135356	OLEG CHERNOV	{"email": "chernov_o1983@postgrespro.ru", "phone": "+70646674084"}
0005434950573	1675C2	9625 629627	YURIY GUSEV	{"phone": "+70323830821"}
0005434950574	37BBC2	2987 615604	VERA FEDOROVA	{"phone": "+70987465699"}
0005434950575	37BBC2	6431 855020	ANASTASIYA VASILEVA	{"email": "anastasiyavasileva-1974@postgrespro.ru", "phone": "+70107077492"}
0005434950576	D7B782	9933 423618	ALISHER MOROZOV	{"email": "morozova07041967@postgrespro.ru", "phone": "+70783993828"}
0005434950577	4E58BF	2043 435898	YURIY FEDOROV	{"email": "yuriy-fedorov-01101976@postgrespro.ru", "phone": "+70326245628"}
0005434950578	AA9D0F	6961 083658	ALEKSEY MAKAROV	{"phone": "+70587271181"}
0005434950579	CA2F7E	2968 992028	IVAN IVANOV	{"phone": "+70360351162"}
0005434950580	E0A341	6155 433357	IRINA OSIPOVA	{"email": "irina-osipova02051963@postgrespro.ru", "phone": "+70995994323"}
0005434950581	E0A341	4417 826105	ILDUS FEDOTOV	{"phone": "+70858970988"}
0005434950582	E0A341	5172 774062	SVETLANA PAVLOVA	{"phone": "+70290667833"}
0005434950583	A345E7	1023 073539	NATALYA KUZMINA	{"email": "kuzmina_n_041987@postgrespro.ru", "phone": "+70756646776"}
0005434950584	B55C65	1427 321311	NATALYA GORBUNOVA	{"email": "gorbunovanatalya_1967@postgrespro.ru", "phone": "+70460500489"}
0005434950585	78F236	2271 825323	IRINA MELNIKOVA	{"phone": "+70724060674"}
0005434950586	4D59EB	7633 000312	EKATERINA NIKOLAEVA	{"email": "nikolaevaekaterina.15041975@postgrespro.ru", "phone": "+70650103786"}
0005434950587	4D59EB	5883 589911	IGOR PAVLOV	{"phone": "+70588342094"}
0005434950588	C9FD4E	4441 509514	VALERIY VLASOV	{"phone": "+70362276404"}
0005434950589	24B193	6333 377224	KAMIL ISAEV	{"email": "isaevkamil1980@postgrespro.ru", "phone": "+70522111986"}
0005434950591	DBE60E	3922 320213	ALEKSANDR DAVYDOV	{"email": "aleksandr-davydov.041963@postgrespro.ru", "phone": "+70156756728"}
0005434950592	ACB78A	6263 266276	ZHANNA KUDRYASHOVA	{"phone": "+70047923603"}
0005434950593	8CDFE8	4903 949420	MARIYA BELOVA	{"phone": "+70575805670"}
0005434950594	235F60	0923 381431	LYUBOV KUZNECOVA	{"email": "lyubovkuznecova1967@postgrespro.ru", "phone": "+70009412845"}
0005434950595	D60EE8	6424 379569	TATYANA KOROLEVA	{"email": "tatyana.koroleva.1975@postgrespro.ru", "phone": "+70910748079"}
0005434950596	951437	2280 388206	TAMARA GORBUNOVA	{"phone": "+70236121408"}
0005434950597	951437	4894 033836	ANNA POTAPOVA	{"phone": "+70361587005"}
0005434950598	1083D3	3048 033503	LYUBOV ZHUKOVA	{"phone": "+70836043015"}
0005434950599	F34936	7966 770595	NATALYA TIKHONOVA	{"phone": "+70690030859"}
0005434950600	0AEE24	8171 941825	YULIYA KOZLOVA	{"email": "kozlovayuliya-16101969@postgrespro.ru", "phone": "+70608772932"}
0005434950601	8E94F6	7981 394402	GRIGORIY FEDOTOV	{"phone": "+70981679163"}
0005434950602	871D09	7400 015023	SERGEY KULIKOV	{"email": "sergey_kulikov091989@postgrespro.ru", "phone": "+70561611285"}
0005434950603	D88922	4847 100223	IVAN PAVLOV	{"phone": "+70287154527"}
0005434950604	A2D510	6716 467065	VYACHESLAV CHERNOV	{"email": "vyacheslavchernov.08071977@postgrespro.ru", "phone": "+70831073780"}
0005434950605	A2D510	7891 148225	KLAVDIYA EGOROVA	{"phone": "+70842152169"}
0005434950606	51DDC3	3979 092604	TAISIYA RODIONOVA	{"phone": "+70351218635"}
0005434950607	1BD51E	4127 833349	GEORGIY RODIONOV	{"phone": "+70988178595"}
0005434950608	1BD51E	1579 886694	DENIS NAUMOV	{"phone": "+70190494034"}
0005434950609	4B2000	7067 050497	NIKOLAY FEDOROV	{"phone": "+70870576657"}
0005434950610	967026	8179 633231	YURIY IVANOV	{"email": "y.ivanov_02121982@postgrespro.ru", "phone": "+70788980657"}
0005434950611	2EEF15	9516 284089	ALEKSANDR KARPOV	{"email": "aleksandrkarpov-02101967@postgrespro.ru", "phone": "+70225547568"}
0005434950612	2EEF15	1058 892150	NIKITA BONDARENKO	{"phone": "+70285409771"}
0005434950613	18820D	0473 873681	YANA NIKOLAEVA	{"phone": "+70311690843"}
0005434950614	28E1BF	7698 881120	NATALYA ILINA	{"phone": "+70015939762"}
0005434950615	28E1BF	3993 398477	NIKOLAY MAKSIMOV	{"email": "maksimov.nikolay041977@postgrespro.ru", "phone": "+70707846752"}
0005434950616	A3E95D	6251 556747	ALEKSANDR VASILEV	{"phone": "+70100759027"}
0005434950617	A3E95D	5910 320291	EGOR DMITRIEV	{"phone": "+70502276356"}
0005434950618	87FCC6	4166 297888	LARISA KUZNECOVA	{"phone": "+70208898382"}
0005434950619	87FCC6	9286 844448	VLADIMIR DAVYDOV	{"email": "v-davydov16091976@postgrespro.ru", "phone": "+70754169561"}
0005434950620	ED3555	4228 097523	SERGEY VLASOV	{"phone": "+70675202856"}
0005434950621	ED3555	8648 033858	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov_07041972@postgrespro.ru", "phone": "+70357201086"}
0005434950622	86F203	3194 418612	LIDIYA OVCHINNIKOVA	{"phone": "+70773059036"}
0005434950623	873BD1	4879 070029	SERGEY FOMIN	{"email": "sergey.fomin.091968@postgrespro.ru", "phone": "+70432414615"}
0005434950624	873BD1	0705 847832	ELENA SMIRNOVA	{"phone": "+70773250143"}
0005434950625	2CD890	4974 796035	EVGENIY FEDOROV	{"phone": "+70602284532"}
0005434950626	2CD890	3200 623337	VLADIMIR MIRONOV	{"email": "mironov_v_17071982@postgrespro.ru", "phone": "+70165051869"}
0005434950627	AF6EA2	6483 687835	VALENTINA DAVYDOVA	{"phone": "+70171402333"}
0005434950628	AF6EA2	3756 304267	VLADIMIR ORLOV	{"phone": "+70575057277"}
0005434950629	F6039E	9590 477498	MARAT BARANOV	{"phone": "+70535724434"}
0005434950630	8202DE	0747 194819	NATALYA KUZNECOVA	{"email": "n.kuznecova.25051976@postgrespro.ru", "phone": "+70549499792"}
0005434950631	A26698	0099 777290	ANATOLIY ALEKSEEV	{"phone": "+70001458171"}
0005434950632	EBEFAA	9587 281296	RINAT KOZLOV	{"email": "kozlov.r.061972@postgrespro.ru", "phone": "+70217637222"}
0005434950633	EBEFAA	6344 454257	RIMMA GUSEVA	{"phone": "+70710889773"}
0005434950634	D3D767	5464 629921	ILYA VOROBEV	{"email": "ilya.vorobev_1963@postgrespro.ru", "phone": "+70842877221"}
0005434950635	0B55CD	8795 464189	KONSTANTIN MEDVEDEV	{"phone": "+70972748429"}
0005434950636	827C5D	0947 552804	ELENA FEDOROVA	{"phone": "+70910870540"}
0005434950637	827C5D	8748 017854	SERGEY TIMOFEEV	{"email": "timofeevs16101971@postgrespro.ru", "phone": "+70902114610"}
0005434950638	6B24A8	5801 855015	VALENTINA KULIKOVA	{"email": "kulikova-valentina-20111972@postgrespro.ru", "phone": "+70429979980"}
0005434950639	02C5B2	7300 628521	SERGEY SIDOROV	{"email": "sidorov_s.111976@postgrespro.ru", "phone": "+70757427231"}
0005434950640	02C5B2	4939 499892	OLEG SOKOLOV	{"email": "sokolov.oleg_091982@postgrespro.ru", "phone": "+70917589590"}
0005434950641	5C09EC	2373 917448	MIKHAIL SOKOLOV	{"phone": "+70181897096"}
0005434950642	449333	0029 344852	PRASKOVYA STEPANOVA	{"email": "stepanova.praskovya_04111970@postgrespro.ru", "phone": "+70845571428"}
0005434950643	449333	9099 785984	ALEKSEY MELNIKOV	{"phone": "+70293887820"}
0005434950644	FD0C1B	4490 723600	ELENA KONDRATEVA	{"email": "kondratevaelena-23021970@postgrespro.ru", "phone": "+70643665460"}
0005434950645	674F3B	0232 624627	IVAN KONOVALOV	{"email": "konovalov_ivan1980@postgrespro.ru", "phone": "+70991059783"}
0005434950646	85541A	7911 195610	PAVEL YAKOVLEV	{"phone": "+70749302883"}
0005434950647	85541A	3240 899891	ALENA MAKSIMOVA	{"email": "alena.maksimova_1987@postgrespro.ru", "phone": "+70145893251"}
0005434950648	ABA2B3	6087 154992	ROBERT MAKAROV	{"email": "makarov.robert_091967@postgrespro.ru", "phone": "+70224436290"}
0005434950649	096B54	4683 973189	ELIZAVETA MAKAROVA	{"email": "makarovaelizaveta-1970@postgrespro.ru", "phone": "+70071729487"}
0005434950650	ED7FC7	1569 534842	VERA KUZMINA	{"phone": "+70925298103"}
0005434950651	618452	0186 707955	OLGA FILIPPOVA	{"email": "olgafilippova.01111972@postgrespro.ru", "phone": "+70524011593"}
0005434950653	B81B6E	4049 502620	VADIM ROMANOV	{"email": "vadim-romanov_07021969@postgrespro.ru", "phone": "+70046200667"}
0005434950654	89C395	3901 869046	ANATOLIY MEDVEDEV	{"phone": "+70246560160"}
0005434950655	89C395	9946 096605	ANASTASIYA KUZNECOVA	{"phone": "+70470066771"}
0005434950656	ABD781	7464 717906	SABINA ANISIMOVA	{"email": "anisimova-s-111968@postgrespro.ru", "phone": "+70594416956"}
0005434950657	ABD781	9671 512012	ANNA KUZMINA	{"phone": "+70167649519"}
0005434950658	8914A3	1797 135971	IVAN DENISOV	{"phone": "+70418707896"}
0005434950659	8914A3	5120 462360	KIRILL KONOVALOV	{"phone": "+70927778790"}
0005434950660	1D4117	6072 296742	EVGENIYA KAZAKOVA	{"email": "evgeniya.kazakova.031967@postgrespro.ru", "phone": "+70381744762"}
0005434950661	1D4117	5911 694469	VIKTORIYA SOROKINA	{"email": "viktoriya.sorokina091974@postgrespro.ru", "phone": "+70115336689"}
0005434952464	A34399	8211 290069	SERGEY KUZNECOV	{"email": "kuznecov.s.1954@postgrespro.ru", "phone": "+70616372462"}
0005434952465	A34399	9351 435944	LYUBOV GUSEVA	{"email": "guseva_lyubov_1963@postgrespro.ru", "phone": "+70590011469"}
0005434952466	A89A63	0613 453516	TATYANA KUZNECOVA	{"email": "kuznecovat.01081968@postgrespro.ru", "phone": "+70519716027"}
0005434952467	A89A63	0954 027620	ANATOLIY ORLOV	{"phone": "+70099842815"}
0005434952468	9F8262	4008 890892	EKATERINA MELNIKOVA	{"phone": "+70531635311"}
0005434952469	9F8262	8147 987481	ANASTASIYA PAVLOVA	{"phone": "+70129778712"}
0005434952470	E3F6C8	3980 458167	ANASTASIYA KAZAKOVA	{"email": "a-kazakova-25041972@postgrespro.ru", "phone": "+70364914509"}
0005434952471	D2A682	6534 774648	SERGEY GAVRILOV	{"email": "sergeygavrilov.071987@postgrespro.ru", "phone": "+70682010492"}
0005434952472	D2A682	9149 716413	ANATOLIY YAKOVLEV	{"phone": "+70317708569"}
0005434952473	3AD26A	7179 108039	LIDIYA KOROLEVA	{"email": "l_koroleva-02051972@postgrespro.ru", "phone": "+70537538085"}
0005434952474	B5A6AC	4802 251267	EMMA FILIPPOVA	{"email": "e-filippova_091972@postgrespro.ru", "phone": "+70341576289"}
0005434952475	001A6E	3195 896383	ALEKSEY SERGEEV	{"email": "sergeev.aleksey.031970@postgrespro.ru", "phone": "+70172392130"}
0005434952476	001A6E	3411 207836	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila.041962@postgrespro.ru", "phone": "+70874597010"}
0005434952477	80099A	3882 200930	IVAN ZAYCEV	{"phone": "+70053316461"}
0005434952478	10B6BF	4976 587388	DMITRIY FROLOV	{"email": "frolov-dmitriy091978@postgrespro.ru", "phone": "+70123758753"}
0005434952479	10B6BF	7246 242257	ANASTASIYA STEPANOVA	{"phone": "+70919411359"}
0005434952480	A72F73	7795 273621	OLGA FILIPPOVA	{"phone": "+70709203650"}
0005434952481	DA01E3	8545 961807	ALEKSANDR IVANOV	{"email": "ivanov.a_1969@postgrespro.ru", "phone": "+70616092454"}
0005434952482	DA01E3	1839 648479	NADEZHDA PETROVA	{"phone": "+70443555227"}
0005434952483	DA01E3	0252 537465	NADEZHDA NOVIKOVA	{"email": "nadezhda.novikova1965@postgrespro.ru", "phone": "+70638281193"}
0005434952484	BE4B09	6052 420296	DAMIR MATVEEV	{"email": "damir.matveev_1972@postgrespro.ru", "phone": "+70521565509"}
0005434952485	BE4B09	4387 228825	GENNADIY POPOV	{"email": "popovg.1961@postgrespro.ru", "phone": "+70492473546"}
0005434952486	BE4B09	7812 249553	VALERIYA NOVIKOVA	{"phone": "+70646372873"}
0005434952487	F8E260	6272 577467	DMITRIY MIRONOV	{"phone": "+70902266177"}
0005434952488	F8E260	8731 087157	ALEKSANDR KRASNOV	{"phone": "+70955612558"}
0005434952489	F8E260	0897 259620	OLEG NAZAROV	{"email": "nazarov-o121968@postgrespro.ru", "phone": "+70479858327"}
0005434952490	9A7BA4	3696 640109	NADEZHDA ORLOVA	{"email": "n_orlova021975@postgrespro.ru", "phone": "+70949642441"}
0005434952491	9A7BA4	7458 563771	GALINA ANDREEVA	{"phone": "+70470969390"}
0005434952492	85FC0B	7048 635291	OKSANA ANDREEVA	{"email": "andreeva.o.071976@postgrespro.ru", "phone": "+70675331034"}
0005434952493	90B994	1227 540196	EVGENIY STEPANOV	{"email": "stepanove_31011970@postgrespro.ru", "phone": "+70443003734"}
0005434952494	90B994	5391 447498	ANTON POPOV	{"email": "popov-anton.1974@postgrespro.ru", "phone": "+70622890512"}
0005434952495	2185FA	3125 380303	VIKTORIYA GUSEVA	{"phone": "+70226579497"}
0005434952496	E59AE9	8944 267847	PETR KUZNECOV	{"phone": "+70707486504"}
0005434952497	EB4E97	8441 659870	GALIYA BELOVA	{"email": "belova.galiya.101968@postgrespro.ru", "phone": "+70221640990"}
0005434952498	EB4E97	1739 814132	EVGENIY MARTYNOV	{"email": "evgeniy.martynov101976@postgrespro.ru", "phone": "+70882579605"}
0005434952499	741A0E	3482 581990	YULIYA ROMANOVA	{"phone": "+70242385470"}
0005434952500	FB13AD	8764 881376	LYUDMILA AFANASEVA	{"email": "afanasevalyudmila1975@postgrespro.ru", "phone": "+70861337760"}
0005434952501	1D3820	9450 761534	IGOR MIKHAYLOV	{"email": "mikhaylov.i20061977@postgrespro.ru", "phone": "+70175547272"}
0005434952502	59F695	8195 322414	SVETLANA IVANOVA	{"email": "svetlana.ivanova-111980@postgrespro.ru", "phone": "+70227516997"}
0005434952503	22962E	2190 549654	LYUBOV STEPANOVA	{"email": "stepanova_l-1968@postgrespro.ru", "phone": "+70605231099"}
0005434952504	69DF10	0671 417124	YURIY KULIKOV	{"phone": "+70597020591"}
0005434952505	354697	0922 221136	NATALYA SMIRNOVA	{"phone": "+70557817166"}
0005434952506	C749D3	0977 422469	ALEKSANDR MAKSIMOV	{"phone": "+70760718155"}
0005434952507	C749D3	0524 661256	RADIK FROLOV	{"phone": "+70630994565"}
0005434952508	266F4D	8216 277927	TATYANA SOKOLOVA	{"phone": "+70890800343"}
0005434952509	52892F	4028 125165	ANDREY IVANOV	{"phone": "+70666533261"}
0005434952510	EF1157	3579 398179	ANGELINA ROMANOVA	{"email": "a-romanova09101979@postgrespro.ru", "phone": "+70501283220"}
0005434952511	EF1157	6631 899791	ROMAN IVANOV	{"phone": "+70241675783"}
0005434952512	FFBD4F	1744 215197	OLGA STEPANOVA	{"phone": "+70085449018"}
0005434952513	4E1335	7927 095847	NIKITA FOMIN	{"phone": "+70408347897"}
0005434952514	59CAC1	4239 599278	ALEKSANDR KONOVALOV	{"phone": "+70931592891"}
0005434952515	808E4E	3074 683579	FATYMA BELYAEVA	{"phone": "+70781759754"}
0005434952516	E7AFFC	7765 332993	NIKOLAY SMIRNOV	{"phone": "+70794639573"}
0005434952517	EE3A51	8085 817042	DANIIL KISELEV	{"phone": "+70755260486"}
0005434952518	3415BA	3236 925410	IVAN MEDVEDEV	{"phone": "+70612127984"}
0005434952519	3415BA	1568 232251	OLGA EGOROVA	{"email": "o_egorova.081966@postgrespro.ru", "phone": "+70546340116"}
0005434952520	8C5040	0761 699679	GALINA MIKHAYLOVA	{"phone": "+70551540929"}
0005434952521	8C5040	1261 191196	ROMAN ORLOV	{"phone": "+70103620257"}
0005434952522	D4A6DB	1761 389662	OLEG ALEKSEEV	{"email": "oleg-alekseev031970@postgrespro.ru", "phone": "+70809150925"}
0005434952523	6A8A01	8187 166118	MARIYA FEDOROVA	{"phone": "+70072750137"}
0005434952524	1FDDEB	3490 282411	ANATOLIY VOROBEV	{"phone": "+70312536973"}
0005434952525	1FDDEB	2684 176376	MATVEY MELNIKOV	{"email": "melnikov_m1975@postgrespro.ru", "phone": "+70526861320"}
0005434952526	1FDDEB	1923 793087	VLADIMIR POPOV	{"phone": "+70219318201"}
0005434952527	DBF911	4712 674682	VLADIMIR TARASOV	{"phone": "+70176694643"}
0005434952528	A35CEF	4919 917252	YULIYA EGOROVA	{"email": "yegorova19031975@postgrespro.ru", "phone": "+70356708046"}
0005434952529	D0BC06	0510 937577	DENIS DAVYDOV	{"phone": "+70207277841"}
0005434952530	B48553	3980 205020	DMITRIY ANDREEV	{"phone": "+70719847483"}
0005434952531	352370	2588 628496	DMITRIY STEPANOV	{"phone": "+70873861816"}
0005434952532	DA8E4F	3087 910860	SERGEY DAVYDOV	{"email": "davydov_sergey23111965@postgrespro.ru", "phone": "+70238899804"}
0005434952533	2C9212	1452 701386	NIKOLAY EGOROV	{"phone": "+70143079472"}
0005434952534	9264FE	3465 741687	LYUDMILA TARASOVA	{"phone": "+70370833339"}
0005434952535	9264FE	1056 536774	YULIYA KUZMINA	{"email": "kuzminay.011961@postgrespro.ru", "phone": "+70021448754"}
0005434952536	AA982A	6804 169289	NIKOLAY ZHUKOV	{"email": "nikolayzhukov.11081966@postgrespro.ru", "phone": "+70668780670"}
0005434952537	D2F4A0	8844 171787	VALENTINA SAVELEVA	{"email": "saveleva_v-051974@postgrespro.ru", "phone": "+70278607878"}
0005434952538	AE852C	1756 162286	ELENA ORLOVA	{"email": "elena.orlova1982@postgrespro.ru", "phone": "+70485491670"}
0005434952539	040CE5	0710 563465	VALERIYA MOISEEVA	{"email": "moiseeva.valeriya1973@postgrespro.ru", "phone": "+70673910145"}
0005434952540	EB1F83	9749 325047	ARTEM YAKOVLEV	{"email": "yakovlev.a28041976@postgrespro.ru", "phone": "+70147244193"}
0005434952541	EB1F83	4219 900040	PETR TIMOFEEV	{"email": "petrtimofeev-1971@postgrespro.ru", "phone": "+70828351561"}
0005434952542	D03C94	1067 932996	VLADISLAV TARASOV	{"email": "v_tarasov-111982@postgrespro.ru", "phone": "+70953250502"}
0005434952543	D03C94	9106 020945	VIKTOR NAUMOV	{"phone": "+70629213812"}
0005434952544	D03C94	6169 699023	GALINA MAKSIMOVA	{"email": "g.maksimova_19061974@postgrespro.ru", "phone": "+70311636144"}
0005434952545	D03C94	6459 124635	ALEKSEY FEDOTOV	{"phone": "+70207465624"}
0005434952546	EB228E	5243 089556	NATALYA MOISEEVA	{"phone": "+70922257831"}
0005434952547	6DEE7A	9469 368168	ZAKHAR ABRAMOV	{"email": "z_abramov_30121969@postgrespro.ru", "phone": "+70378283506"}
0005434952548	929E95	2445 356787	MARINA LEBEDEVA	{"phone": "+70060065216"}
0005434952549	929E95	5835 644181	TATYANA KISELEVA	{"phone": "+70851998738"}
0005434952550	BD3CFF	3116 161283	NATALYA GUSEVA	{"phone": "+70499784193"}
0005434952551	2D1A94	8639 076711	RAISA TIKHONOVA	{"phone": "+70799922121"}
0005434952552	81925D	3266 678168	ANNA ZHUKOVA	{"email": "zhukovaanna-061976@postgrespro.ru", "phone": "+70885336056"}
0005434952553	81925D	8105 222257	GALINA TITOVA	{"phone": "+70230533957"}
0005434952554	81925D	2506 145945	NATALYA KISELEVA	{"phone": "+70610673573"}
0005434952555	6881AB	5073 024990	MARIYA GERASIMOVA	{"phone": "+70191062690"}
0005434952556	A9CEE4	5061 192986	ZOYA MEDVEDEVA	{"email": "z_medvedeva_1977@postgrespro.ru", "phone": "+70279138111"}
0005434952557	F9C941	6640 421978	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov_031981@postgrespro.ru", "phone": "+70216854129"}
0005434952558	43A903	6486 379293	ALEKSANDR BELOV	{"phone": "+70574816205"}
0005434952559	43A903	7792 100719	LYUBOV KONDRATEVA	{"email": "l_kondrateva-30111956@postgrespro.ru", "phone": "+70501642611"}
0005434952560	7D78B8	2501 431758	ANZHELIKA MALYSHEVA	{"phone": "+70767387737"}
0005434952561	7D78B8	9058 470879	LYUBOV GUSEVA	{"email": "l.guseva061970@postgrespro.ru", "phone": "+70419537256"}
0005434952562	890D36	0203 779664	DMITRIY POPOV	{"phone": "+70570462069"}
0005434952563	890D36	4008 378045	EVGENIY MOISEEV	{"phone": "+70987422857"}
0005434952564	5F5E96	9201 681299	NIKOLAY KISELEV	{"phone": "+70601224899"}
0005434952565	E50A0D	1112 423163	IRINA KONDRATEVA	{"email": "kondrateva-irina1986@postgrespro.ru", "phone": "+70877394997"}
0005434952566	E31FBF	9100 265055	RAIS GAVRILOV	{"phone": "+70056454564"}
0005434952567	E31FBF	4102 849927	ARTEM MAKSIMOV	{"phone": "+70429812444"}
0005434952568	60BB8F	4112 548499	MAKSIM STEPANOV	{"phone": "+70532597936"}
0005434952569	E88937	3747 451740	VALENTINA MAKSIMOVA	{"phone": "+70459141325"}
0005434952570	8CE912	2702 179463	YULIYA VLASOVA	{"phone": "+70768062266"}
0005434952571	8CE912	6621 961725	VIKTOR OSIPOV	{"phone": "+70550250348"}
0005434952572	8CE912	0686 585996	DMITRIY MEDVEDEV	{"phone": "+70210553362"}
0005434952573	190159	6005 113733	ALEKSEY EGOROV	{"email": "egorov-aleksey.23051977@postgrespro.ru", "phone": "+70844998847"}
0005434952574	8CC8AA	1025 796885	NATALYA NIKITINA	{"phone": "+70029611316"}
0005434952575	60C9AC	0089 677121	IGOR MIKHAYLOV	{"email": "mikhaylov_igor-28091967@postgrespro.ru", "phone": "+70125861967"}
0005434952576	ADF688	5404 457850	GENNADIY ZAKHAROV	{"email": "zakharov-gennadiy_1969@postgrespro.ru", "phone": "+70003405953"}
0005434952577	E6CEF0	4887 895283	ALEKSANDRA PETROVA	{"email": "petrova.aleksandra1983@postgrespro.ru", "phone": "+70883859628"}
0005434952578	85C9EE	2489 802569	MARIYA KOZLOVA	{"email": "mariya_kozlova.041966@postgrespro.ru", "phone": "+70671287393"}
0005434952579	9E4E87	0941 249646	KONSTANTIN SAVELEV	{"email": "savelev.k.1969@postgrespro.ru", "phone": "+70186344617"}
0005434952580	9E4E87	3751 880350	VIKTOR GAVRILOV	{"phone": "+70631936724"}
0005434952581	9E4E87	7761 148257	IVAN FROLOV	{"phone": "+70942240258"}
0005434952582	042A43	9302 544750	SERGEY TIMOFEEV	{"phone": "+70499134526"}
0005434952583	042A43	8968 801922	SERGEY MARTYNOV	{"email": "sergey.martynov1976@postgrespro.ru", "phone": "+70802099338"}
0005434952584	3B919B	4902 406250	VALENTINA RODIONOVA	{"email": "valentina-rodionova02121973@postgrespro.ru", "phone": "+70741358229"}
0005434952585	887281	0888 742926	DMITRIY PETROV	{"phone": "+70844125288"}
0005434952586	DEEC1D	0130 754005	RITA VLASOVA	{"phone": "+70503492546"}
0005434952587	0D426C	0303 269467	ANATOLIY TIMOFEEV	{"phone": "+70228458215"}
0005434952588	CE5622	2572 520736	DANIL VOROBEV	{"email": "vorobev-d_1964@postgrespro.ru", "phone": "+70262641376"}
0005434952589	BA478E	1810 201366	GALINA YUDINA	{"phone": "+70431264361"}
0005434952590	A45AD3	8445 570486	OKSANA ROMANOVA	{"phone": "+70048839347"}
0005434952591	9B9735	8187 716310	LYUBOV KUZNECOVA	{"email": "kuznecova-l16031969@postgrespro.ru", "phone": "+70285447143"}
0005434952592	9B9735	4052 659695	MAKSIM KOROLEV	{"email": "maksim_korolev.031978@postgrespro.ru", "phone": "+70967269974"}
0005434952593	7CA3CB	3296 678777	EVGENIY KOZLOV	{"phone": "+70868199635"}
0005434952594	7CA3CB	0973 312125	ZOYA TIMOFEEVA	{"phone": "+70779289850"}
0005434952595	F4E70D	4395 131859	IRINA KUZNECOVA	{"email": "kuznecovairina_29081960@postgrespro.ru", "phone": "+70789503195"}
0005434952596	6ABF18	2155 039043	VIKTORIYA POTAPOVA	{"phone": "+70886465094"}
0005434952597	6ABF18	0532 944935	IVAN DMITRIEV	{"phone": "+70004364206"}
0005434952598	0E9414	1491 171584	IRINA ANDREEVA	{"email": "i_andreeva.101969@postgrespro.ru", "phone": "+70365172135"}
0005434952599	FACC41	7569 112457	YURIY ILIN	{"phone": "+70721963878"}
0005434952600	D15C3E	3460 945595	ANASTASIYA BOGDANOVA	{"phone": "+70537688636"}
0005434952601	59BDBC	1391 534460	VASILIY CHERNOV	{"email": "chernov.vasiliy_1967@postgrespro.ru", "phone": "+70141232703"}
0005434952602	6BA493	2664 590688	LYUBOV ANISIMOVA	{"phone": "+70435587111"}
0005434952603	6BA493	3781 131547	VLADIMIR KARPOV	{"phone": "+70178984069"}
0005434952604	6BA493	3814 658984	TATYANA SEMENOVA	{"phone": "+70386793193"}
0005434952605	4376BF	1914 302587	NIKOLAY FROLOV	{"email": "n_frolov09021975@postgrespro.ru", "phone": "+70030922605"}
0005434952606	6E91C5	4902 870185	ALEKSANDRA DANILOVA	{"phone": "+70581151923"}
0005434952607	60C7D5	1770 672566	NIKOLAY POPOV	{"email": "nikolay.popov_12101975@postgrespro.ru", "phone": "+70730969128"}
0005434952608	EE30FA	1613 688358	OLEG ALEKSANDROV	{"phone": "+70262145796"}
0005434952609	61D122	3919 489101	SERGEY SHEVCHENKO	{"phone": "+70691664733"}
0005434952610	511A88	6074 532635	YURIY POPOV	{"phone": "+70692885971"}
0005434952611	511A88	6055 692593	LYUBOV GUSEVA	{"phone": "+70536382692"}
0005434952612	EFEE7B	1084 130991	NIKOLAY KUZNECOV	{"email": "kuznecov_n.30111970@postgrespro.ru", "phone": "+70733672516"}
0005434952613	EFEE7B	5760 566406	EKATERINA MOISEEVA	{"phone": "+70179464148"}
0005434952614	0AA9CA	9191 184339	ANNA SCHERBAKOVA	{"phone": "+70241386680"}
0005434952615	9AD8CE	1403 352787	POLINA RODIONOVA	{"email": "p.rodionova.29121965@postgrespro.ru", "phone": "+70442252918"}
0005434952616	357EA4	7577 637030	ANDREY MIKHAYLOV	{"email": "andrey.mikhaylov-1978@postgrespro.ru", "phone": "+70467932983"}
0005434952617	357EA4	1533 789084	MARIYA SEMENOVA	{"email": "semenova_m-1969@postgrespro.ru", "phone": "+70587426285"}
0005434952618	E1CC61	8419 293882	ELENA MOISEEVA	{"email": "e.moiseeva021978@postgrespro.ru", "phone": "+70956751197"}
0005434952619	F88C4B	4866 430572	KSENIYA MOROZOVA	{"phone": "+70277662664"}
0005434952620	F88C4B	6238 893481	ALEKSANDRA MAKAROVA	{"email": "aleksandra.makarova.19031972@postgrespro.ru", "phone": "+70725990649"}
0005434952621	F88C4B	2642 549514	EKATERINA ANTONOVA	{"email": "antonovae.041968@postgrespro.ru", "phone": "+70067850009"}
0005434952622	203011	4331 079049	OLGA ZAYCEVA	{"email": "zayceva-olga22061959@postgrespro.ru", "phone": "+70886907373"}
0005434952623	203011	8179 518822	DENIS TIMOFEEV	{"phone": "+70253127541"}
0005434952624	73B710	4858 564353	KRISTINA NOVIKOVA	{"email": "k_novikova-041969@postgrespro.ru", "phone": "+70985097621"}
0005434952625	73B710	4724 629548	ELENA DANILOVA	{"email": "e-danilova_011974@postgrespro.ru", "phone": "+70596298583"}
0005434952626	BAF2BD	6628 976530	ALBERT MEDVEDEV	{"phone": "+70490238337"}
0005434952627	BAF2BD	9829 234823	EVGENIY KUZMIN	{"email": "e-kuzmin-011975@postgrespro.ru", "phone": "+70169672482"}
0005434952628	558BB4	1249 256158	VLADIMIR ZHUKOV	{"email": "v_zhukov.111973@postgrespro.ru", "phone": "+70384997341"}
0005434952629	608994	5043 550621	VLADIMIR ALEKSEEV	{"email": "v-alekseev-17111965@postgrespro.ru", "phone": "+70569001961"}
0005434952630	5619C3	4278 132848	OLEG KUZNECOV	{"email": "oleg_kuznecov-091967@postgrespro.ru", "phone": "+70007253811"}
0005434952631	5619C3	4465 453548	ELENA PETROVA	{"email": "petrovae_021976@postgrespro.ru", "phone": "+70313938783"}
0005434952632	FE76BA	6748 890447	IRINA DENISOVA	{"email": "denisovairina-1984@postgrespro.ru", "phone": "+70900802047"}
0005434952633	782031	4493 811821	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav_1959@postgrespro.ru", "phone": "+70077412225"}
0005434952634	74A7DA	4173 318604	SERGEY FILIPPOV	{"phone": "+70698698772"}
0005434952635	EDAC38	0825 379295	NIKOLAY KOZLOV	{"email": "n_kozlov_1969@postgrespro.ru", "phone": "+70383234536"}
0005434952636	EDAC38	1200 124648	IRINA DMITRIEVA	{"email": "dmitrieva.i_1961@postgrespro.ru", "phone": "+70314065954"}
0005434954537	E384F9	3044 568068	VERA ZAKHAROVA	{"phone": "+70347905930"}
0005434954538	E384F9	0230 725592	EVGENIY MATVEEV	{"email": "evgeniy_matveev_1964@postgrespro.ru", "phone": "+70059883625"}
0005434954539	E384F9	9055 657227	NURIYA GORBUNOVA	{"email": "gorbunova_n081967@postgrespro.ru", "phone": "+70337500899"}
0005434954540	B24010	5624 912355	SERGEY NAUMOV	{"email": "naumov_sergey06021971@postgrespro.ru", "phone": "+70290134539"}
0005434954541	A846B4	2192 510336	NIKOLAY MELNIKOV	{"phone": "+70517139272"}
0005434954542	39CFCD	8801 158820	GALINA MAKAROVA	{"phone": "+70595049737"}
0005434954543	CE7F70	8674 616615	NINA KOROLEVA	{"email": "koroleva.nina_1979@postgrespro.ru", "phone": "+70724163531"}
0005434954544	0EE8EA	3428 542924	SERGEY ABRAMOV	{"phone": "+70460870190"}
0005434954545	0EE8EA	7449 983819	OLESYA ORLOVA	{"email": "o-orlova-04031971@postgrespro.ru", "phone": "+70590063416"}
0005434954546	A8F657	3644 965714	ANDREY NIKITIN	{"phone": "+70051595328"}
0005434954547	CA9498	1075 977827	TATYANA IVANOVA	{"email": "tatyana_ivanova1960@postgrespro.ru", "phone": "+70762049254"}
0005434954548	CA9498	5959 447574	IRINA ZHURAVLEVA	{"email": "i-zhuravleva14111975@postgrespro.ru", "phone": "+70581041152"}
0005434954549	4B40A9	3777 978210	SERGEY MATVEEV	{"phone": "+70876318835"}
0005434954550	4B40A9	7804 992006	ELEONORA NAZAROVA	{"email": "nazarova.e.081971@postgrespro.ru", "phone": "+70728040772"}
0005434954551	77C510	5807 897908	YAROSLAV TARASOV	{"email": "tarasov_yaroslav041977@postgrespro.ru", "phone": "+70998698920"}
0005434954552	6EA9CD	6475 432332	ALENA ZAKHAROVA	{"email": "alenazakharova1957@postgrespro.ru", "phone": "+70658834144"}
0005434954553	6EA9CD	9143 604861	OKSANA TITOVA	{"email": "titovaoksana_21101976@postgrespro.ru", "phone": "+70878245895"}
0005434954554	2BDE5D	6402 859177	YULIYA MOISEEVA	{"phone": "+70980261284"}
0005434954555	2BDE5D	2410 833919	VLADIMIR IVANOV	{"email": "vladimirivanov-06011973@postgrespro.ru", "phone": "+70817689353"}
0005434954556	3BBE23	1053 436598	GALINA RODIONOVA	{"phone": "+70292650779"}
0005434954557	3BBE23	8089 721809	ANTONINA LOGINOVA	{"email": "loginova-a.101978@postgrespro.ru", "phone": "+70480395341"}
0005434954558	3BBE23	3330 939467	ALEKSANDR KARPOV	{"phone": "+70673306832"}
0005434954559	6B75E0	9408 052955	SVETLANA STEPANOVA	{"email": "stepanova.svetlana.1975@postgrespro.ru", "phone": "+70561057646"}
0005434954560	6B75E0	8290 910588	YURIY POPOV	{"phone": "+70842586916"}
0005434954561	7B1632	9053 613322	DANIIL FILIPPOV	{"email": "filippov_daniil_1974@postgrespro.ru", "phone": "+70507722265"}
0005434954562	DC1206	4940 523396	IVAN BORISOV	{"phone": "+70263269666"}
0005434954563	DC1206	4287 766921	IRINA AFANASEVA	{"email": "afanaseva_i.031983@postgrespro.ru", "phone": "+70434711297"}
0005434954564	F0D16B	8023 468597	OLGA GUSEVA	{"phone": "+70816604818"}
0005434954565	F1BB43	0322 486572	ELENA SOKOLOVA	{"email": "elena.sokolova01091975@postgrespro.ru", "phone": "+70012288967"}
0005434954566	8A2804	0946 822667	VALERIY AFANASEV	{"email": "vafanasev_30041966@postgrespro.ru", "phone": "+70434731582"}
0005434954567	7AD5A2	2611 673259	TAISIYA KALININA	{"email": "kalininat.1972@postgrespro.ru", "phone": "+70641016099"}
0005434954568	A88C0E	4045 365181	SVETLANA POPOVA	{"phone": "+70271330237"}
0005434954569	8E1CAF	9295 375016	MIKHAIL EGOROV	{"email": "mikhailegorov1964@postgrespro.ru", "phone": "+70331675987"}
0005434954570	8E1CAF	4220 941830	NINA TIMOFEEVA	{"email": "timofeeva-n111975@postgrespro.ru", "phone": "+70804010353"}
0005434954571	C924E8	5995 204513	RUSLAN FROLOV	{"email": "frolov.r_09071975@postgrespro.ru", "phone": "+70183678699"}
0005434954572	C924E8	7542 734613	NATALYA KOROLEVA	{"email": "natalya-koroleva061978@postgrespro.ru", "phone": "+70315803217"}
0005434954573	DAEC75	4861 374755	SVETLANA POLYAKOVA	{"phone": "+70778998981"}
0005434954574	F13516	0449 214850	SERGEY KOROLEV	{"phone": "+70055399931"}
0005434954575	F13516	7838 833656	PETR KONOVALOV	{"email": "petr-konovalov30031976@postgrespro.ru", "phone": "+70417122016"}
0005434954576	EBFACB	6979 445555	YULIYA ANTONOVA	{"email": "y_antonova-1971@postgrespro.ru", "phone": "+70445878178"}
0005434954577	66D952	1671 287529	VIKTORIYA FILIPPOVA	{"email": "filippovav_1971@postgrespro.ru", "phone": "+70506213196"}
0005434954578	20BF9D	5695 175907	ALEKSANDR IVANOV	{"phone": "+70474198713"}
0005434954579	20BF9D	5604 697146	FEDOR KAZAKOV	{"email": "kazakovf_1974@postgrespro.ru", "phone": "+70243204667"}
0005434954580	A0E6E9	4254 097484	YURIY NAZAROV	{"email": "yuriy.nazarov_18081973@postgrespro.ru", "phone": "+70114411373"}
0005434954581	20E18B	0093 298954	SOFYA MATVEEVA	{"email": "matveeva.sofya-1955@postgrespro.ru", "phone": "+70476518242"}
0005434954582	04CA36	0173 067574	ELENA BOGDANOVA	{"email": "bogdanova_e.1972@postgrespro.ru", "phone": "+70408470765"}
0005434954583	04CA36	7318 083316	MIKHAIL DENISOV	{"email": "denisovmikhail.1969@postgrespro.ru", "phone": "+70244638859"}
0005434954584	93B82A	4272 783341	VIKTOR ROMANOV	{"email": "romanov-viktor.24091973@postgrespro.ru", "phone": "+70769032404"}
0005434954585	648867	5026 437847	OLGA NIKIFOROVA	{"email": "o_nikiforova_23061969@postgrespro.ru", "phone": "+70700932205"}
0005434954586	98EC7D	4583 405218	ELIZAVETA SIDOROVA	{"email": "elizaveta.sidorova_1982@postgrespro.ru", "phone": "+70979373014"}
0005434954587	98EC7D	3505 342060	SERGEY KONOVALOV	{"phone": "+70835265568"}
0005434954588	F23ED0	0871 688212	DENIS TIMOFEEV	{"phone": "+70298346959"}
0005434954708	634A12	4441 699811	ALEKSEY ZAYCEV	{"phone": "+70804849651"}
0005434954589	C87DE0	6979 062351	IRINA NAZAROVA	{"email": "nazarova_irina1970@postgrespro.ru", "phone": "+70848961530"}
0005434954590	1C48F7	5037 261452	VALENTINA RODIONOVA	{"phone": "+70222996189"}
0005434954591	3C56FA	0915 015828	LYUBOV IVANOVA	{"email": "lyubovivanova-06021975@postgrespro.ru", "phone": "+70942878723"}
0005434954592	45832E	5193 533760	ANDREY EGOROV	{"email": "egorov.andrey071969@postgrespro.ru", "phone": "+70483460371"}
0005434954593	45832E	2405 452874	ALEKSANDRA KUZNECOVA	{"phone": "+70362131245"}
0005434954594	E7B42F	8241 802057	ELMIRA GUSEVA	{"phone": "+70013319487"}
0005434954595	6CCF29	5855 735072	POLINA EGOROVA	{"email": "pegorova_21111963@postgrespro.ru", "phone": "+70339093960"}
0005434954596	6CCF29	8662 527228	TATYANA KOZLOVA	{"email": "kozlova-tatyana-041966@postgrespro.ru", "phone": "+70431729099"}
0005434954597	6CCF29	7605 046501	NIKOLAY VASILEV	{"email": "n_vasilev-011972@postgrespro.ru", "phone": "+70460006875"}
0005434954598	20F238	6202 629259	NIKOLAY NAZAROV	{"email": "nazarovnikolay_1974@postgrespro.ru", "phone": "+70760997156"}
0005434954599	DFCE2E	4785 291833	PETR CHERNOV	{"phone": "+70536099915"}
0005434954600	7ADD0D	4252 913098	IRINA KUZNECOVA	{"email": "irina-kuznecova_25081973@postgrespro.ru", "phone": "+70941315057"}
0005434954601	F557E5	5171 846654	SVETLANA BORISOVA	{"email": "borisova_s28011971@postgrespro.ru", "phone": "+70162039292"}
0005434954602	4F3E91	7851 289925	OLGA VASILEVA	{"phone": "+70492849531"}
0005434954603	4F3E91	3964 682410	VLADIMIR MOROZOV	{"phone": "+70979608329"}
0005434954604	E6C970	6680 021722	ALEKSANDR SAVELEV	{"email": "asavelev-041975@postgrespro.ru", "phone": "+70359163244"}
0005434954605	E6C970	6891 875658	LILIYA TARASOVA	{"email": "l_tarasova-1960@postgrespro.ru", "phone": "+70225840583"}
0005434954606	FE95A6	2613 597134	IVAN TIKHONOV	{"email": "tikhonov_ivan-30101975@postgrespro.ru", "phone": "+70927649527"}
0005434954607	B9BECE	3073 081373	ANDREY VOLKOV	{"email": "a-volkov.041980@postgrespro.ru", "phone": "+70397850889"}
0005434954608	632652	5865 265809	VLADIMIR ZAKHAROV	{"phone": "+70007120511"}
0005434954609	3F50EF	9263 822595	INNA AFANASEVA	{"phone": "+70935752194"}
0005434954610	43E8CA	7725 094344	ALEKSANDR MAKSIMOV	{"phone": "+70586152418"}
0005434954611	43E8CA	6378 401821	ALEKSEY KUZNECOV	{"phone": "+70817041366"}
0005434954612	BA89D6	9348 181808	NADEZHDA VLASOVA	{"email": "n-vlasova.1971@postgrespro.ru", "phone": "+70965683489"}
0005434954613	BA89D6	9009 694685	LIDIYA FADEEVA	{"email": "fadeeva_lidiya.16091976@postgrespro.ru", "phone": "+70992324086"}
0005434954614	BA89D6	9374 276272	ELIZAVETA KISELEVA	{"phone": "+70341378711"}
0005434954615	BA89D6	7675 339160	VIKTOR SMIRNOV	{"email": "smirnov.viktor_1967@postgrespro.ru", "phone": "+70046593857"}
0005434954616	EF3115	0833 439801	YULIYA PETROVA	{"phone": "+70074428923"}
0005434954617	4D0DA3	2987 904229	ANNA SEMENOVA	{"email": "a_semenova.06011971@postgrespro.ru", "phone": "+70223386043"}
0005434954618	40DC19	0771 471065	DIANA MARTYNOVA	{"phone": "+70337691946"}
0005434954619	104E5D	8350 162064	VALERIY MAKSIMOV	{"email": "v-maksimov.031975@postgrespro.ru", "phone": "+70354435976"}
0005434954620	D74531	4225 657055	NATALYA FOMINA	{"email": "fomina_natalya-04111968@postgrespro.ru", "phone": "+70460526852"}
0005434954621	597602	7728 926022	VALERIY ILIN	{"phone": "+70097421440"}
0005434954622	3942C6	9468 127187	ZLATA SERGEEVA	{"email": "zlatasergeeva1973@postgrespro.ru", "phone": "+70782702916"}
0005434954623	DFA0C6	1303 526619	SVETLANA SMIRNOVA	{"phone": "+70195048714"}
0005434954624	B39B58	7665 281807	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev_1966@postgrespro.ru", "phone": "+70621417695"}
0005434954625	B39B58	5821 093167	ISLAM TARASOV	{"email": "islam_tarasov21011977@postgrespro.ru", "phone": "+70587546722"}
0005434954626	B39B58	0907 196756	LEV MAKAROV	{"phone": "+70302137447"}
0005434954627	FBD90D	7584 523401	DMITRIY BORISOV	{"phone": "+70631911778"}
0005434954628	FBD90D	4913 780306	NIKOLAY PAVLOV	{"email": "npavlov03031973@postgrespro.ru", "phone": "+70864906724"}
0005434954629	E8E890	3225 746747	ALEKSANDR GAVRILOV	{"email": "gavrilov.aleksandr.12071970@postgrespro.ru", "phone": "+70861238228"}
0005434954630	E8E890	5733 947525	RAMAZAN EGOROV	{"email": "ramazan_egorov-011977@postgrespro.ru", "phone": "+70344960943"}
0005434954631	0C8A0A	6799 460186	DMITRIY KUZNECOV	{"email": "kuznecov.d_061965@postgrespro.ru", "phone": "+70729543728"}
0005434954632	0C8A0A	0243 253134	MARINA EFIMOVA	{"email": "marina.efimova_01101976@postgrespro.ru", "phone": "+70669066251"}
0005434954633	0C8A0A	0477 798871	ANDREY IVANOV	{"phone": "+70415050779"}
0005434954634	C4E5BA	0157 187306	SERGEY KAZAKOV	{"phone": "+70288867131"}
0005434954635	57F58D	0729 681471	SERGEY MOROZOV	{"email": "sergey.morozov_1965@postgrespro.ru", "phone": "+70458361051"}
0005434954636	4EB4C6	6115 203883	ALEKSEY YAKOVLEV	{"email": "a_yakovlev-051972@postgrespro.ru", "phone": "+70257818431"}
0005434954637	4EB4C6	9437 851841	ANTONINA ZOTOVA	{"phone": "+70776745453"}
0005434954638	0EFF55	9921 891906	ANATOLIY MIKHAYLOV	{"phone": "+70049083811"}
0005434954639	578D37	8368 466526	NELLI KOROLEVA	{"email": "koroleva.nelli.10111974@postgrespro.ru", "phone": "+70989946267"}
0005434954640	4BBAFC	9662 020787	YANA MASLOVA	{"phone": "+70021412240"}
0005434954641	98CF07	4659 370703	TATYANA OSIPOVA	{"email": "osipova-t-1958@postgrespro.ru", "phone": "+70539650882"}
0005434954642	CFD6E4	9276 484866	RUSLAN ABRAMOV	{"email": "abramov_ruslan101978@postgrespro.ru", "phone": "+70042214820"}
0005434954643	CFD6E4	5806 906046	MIKHAIL KISELEV	{"phone": "+70479119650"}
0005434954644	491239	6722 271704	ELENA SIDOROVA	{"phone": "+70007509646"}
0005434954645	629D27	1363 325863	ANTONINA NESTEROVA	{"phone": "+70796754147"}
0005434954646	5580B4	6583 636736	VLADISLAV NIKOLAEV	{"phone": "+70056525013"}
0005434954647	1B00CC	7716 982101	ARTEMIY MARTYNOV	{"email": "martynov.a_121959@postgrespro.ru", "phone": "+70300304511"}
0005434954648	1B00CC	2607 781336	SERGEY IVANOV	{"email": "ivanov_s_111977@postgrespro.ru", "phone": "+70934913625"}
0005434954649	D30EA0	9246 032874	ANDREY KUZNECOV	{"email": "andrey_kuznecov.1973@postgrespro.ru", "phone": "+70733634067"}
0005434954650	541AFC	6337 209543	EVGENIY FROLOV	{"email": "frolov-e.29051973@postgrespro.ru", "phone": "+70372040204"}
0005434954651	E6E631	5972 194009	KRISTINA BORISOVA	{"phone": "+70979091652"}
0005434954652	E6E631	9758 940824	SERGEY SEMENOV	{"phone": "+70302157451"}
0005434954653	BE580B	8908 210026	ELENA LEBEDEVA	{"phone": "+70369473958"}
0005434954654	B93B3E	4670 139652	ALEKSEY NOVIKOV	{"phone": "+70547095030"}
0005434954655	283451	4518 888414	NINA ZHURAVLEVA	{"phone": "+70917693309"}
0005434954656	283451	2458 056464	ALEKSANDR MAKSIMOV	{"phone": "+70163497296"}
0005434954657	E50685	7990 004446	RAFAIL BARANOV	{"email": "baranov.r-1978@postgrespro.ru", "phone": "+70535528834"}
0005434954658	746D4B	0345 678199	NATALYA MIKHAYLOVA	{"email": "mikhaylovan_04071979@postgrespro.ru", "phone": "+70726500004"}
0005434954659	746D4B	3171 142415	ANNA ANDREEVA	{"phone": "+70340625640"}
0005434954660	61B49D	1886 088527	BORIS ANTONOV	{"phone": "+70441193473"}
0005434954661	61B49D	0348 269600	YURIY BELOV	{"email": "belovy.14071984@postgrespro.ru", "phone": "+70364605268"}
0005434954662	B0BD3E	6155 390028	SERGEY SIDOROV	{"email": "sidorov.sergey091972@postgrespro.ru", "phone": "+70975424650"}
0005434954663	2F4631	4777 269919	LYUBOV ROMANOVA	{"email": "romanovalyubov1964@postgrespro.ru", "phone": "+70743586205"}
0005434954664	52A9D1	0089 723133	EVGENIY GUSEV	{"phone": "+70145290995"}
0005434954665	52A9D1	3849 145951	ALEKSEY TIMOFEEV	{"email": "a_timofeev-1973@postgrespro.ru", "phone": "+70451757414"}
0005434954666	432425	9199 089341	YURIY KONOVALOV	{"phone": "+70334746102"}
0005434954667	432425	4930 129786	PETR EGOROV	{"phone": "+70099530021"}
0005434954668	9272E7	8916 833670	ANDREY KONOVALOV	{"phone": "+70177832134"}
0005434954669	9272E7	3843 046461	SEMEN SAVELEV	{"phone": "+70810783579"}
0005434954670	CA2B21	2305 137770	VALERIY RODIONOV	{"email": "rodionovvaleriy1973@postgrespro.ru", "phone": "+70728745711"}
0005434954671	CA2B21	1743 818403	YAKOV POPOV	{"email": "y_popov-19041981@postgrespro.ru", "phone": "+70096163331"}
0005434954672	CA2B21	5925 012278	PETR VOLKOV	{"phone": "+70788833541"}
0005434954673	B5946B	2173 560487	ANDREY FOMIN	{"email": "a.fomin1969@postgrespro.ru", "phone": "+70652944150"}
0005434954674	B5946B	8032 902835	VIKTOR STEPANOV	{"email": "stepanov-v101971@postgrespro.ru", "phone": "+70181973922"}
0005434954675	BC7506	7270 694114	SOFYA KOLESNIKOVA	{"email": "s_kolesnikova041964@postgrespro.ru", "phone": "+70303064123"}
0005434954676	5195B7	4976 433964	LYUDMILA SOROKINA	{"email": "lyudmila_sorokina_1968@postgrespro.ru", "phone": "+70453699178"}
0005434954677	2115DC	1956 061087	SERGEY SOROKIN	{"email": "sorokin.sergey.031982@postgrespro.ru", "phone": "+70925779881"}
0005434954678	A095E5	0965 410365	ANDREY RODIONOV	{"email": "rodionov-andrey091966@postgrespro.ru", "phone": "+70986243793"}
0005434954679	A095E5	8429 737879	TAMARA VOLKOVA	{"email": "tamara-volkova_051985@postgrespro.ru", "phone": "+70694697212"}
0005434954680	2EA3F8	5768 156443	TIMUR KUZNECOV	{"email": "t.kuznecov-1971@postgrespro.ru", "phone": "+70050384319"}
0005434954681	DD00CC	0572 609119	IVAN MIKHAYLOV	{"phone": "+70761205612"}
0005434954682	4DB6C3	7359 504144	NELLI KOROLEVA	{"email": "nelli_koroleva.011977@postgrespro.ru", "phone": "+70545332086"}
0005434954683	9BC333	0852 705407	VALENTIN SEMENOV	{"email": "v.semenov18021978@postgrespro.ru", "phone": "+70724098349"}
0005434954684	95C46D	9188 332474	MARIANNA VOROBEVA	{"phone": "+70595568454"}
0005434954685	915399	5167 943089	VADIM GORBUNOV	{"email": "vadim-gorbunov_07021965@postgrespro.ru", "phone": "+70342043238"}
0005434954686	915399	1312 167139	VIKTOR KOZLOV	{"email": "kozlov.viktor22021958@postgrespro.ru", "phone": "+70923181853"}
0005434954687	F9EB2C	2758 919723	LYUDMILA OVCHINNIKOVA	{"phone": "+70409154307"}
0005434954688	F9EB2C	6283 733472	VYACHESLAV ROMANOV	{"email": "vromanov.04051960@postgrespro.ru", "phone": "+70898628349"}
0005434954689	F9EB2C	4296 799361	ALEKSANDR SOKOLOV	{"phone": "+70688439522"}
0005434954690	0F5FD2	3302 710591	NATALYA FILATOVA	{"email": "filatova-n071973@postgrespro.ru", "phone": "+70183646334"}
0005434954691	457F70	5342 400372	ANDREY CHERNOV	{"phone": "+70816088726"}
0005434954692	457F70	0844 095092	NINA MAKAROVA	{"phone": "+70769537063"}
0005434954693	309530	5964 305524	ANNA IVANOVA	{"phone": "+70764489475"}
0005434954694	309530	2740 425502	KONSTANTIN KUZNECOV	{"phone": "+70972218231"}
0005434954695	7F3CFE	4113 974556	YULIYA KAZAKOVA	{"email": "kazakovayuliya-051962@postgrespro.ru", "phone": "+70209317645"}
0005434954696	3CAA77	6439 964841	ALEKSEY SMIRNOV	{"phone": "+70746338129"}
0005434954697	3CAA77	9115 738714	NIKOLAY SOROKIN	{"email": "sorokin-n-29051979@postgrespro.ru", "phone": "+70765838345"}
0005434954698	25D716	0609 744362	ARINA TIMOFEEVA	{"phone": "+70670370953"}
0005434954699	25D716	5026 254552	ARMEN MIKHAYLOV	{"phone": "+70515988872"}
0005434954700	F440E1	5915 897542	PAVEL KOZLOV	{"email": "pavel_kozlov-081969@postgrespro.ru", "phone": "+70530075611"}
0005434954701	19D5A8	4241 292512	LYUDMILA ABRAMOVA	{"email": "abramovalyudmila-1980@postgrespro.ru", "phone": "+70549149791"}
0005434954702	1488C8	4254 566743	LILIYA NAZAROVA	{"email": "l-nazarova-1978@postgrespro.ru", "phone": "+70227116121"}
0005434954703	01AA28	1386 818947	VLADIMIR VASILEV	{"phone": "+70881686257"}
0005434954704	01AA28	4661 958538	GALINA SAVELEVA	{"phone": "+70438644410"}
0005434954705	1C2D1E	4976 000627	DMITRIY BARANOV	{"email": "baranov.d-071971@postgrespro.ru", "phone": "+70690588664"}
0005434954706	CDA21A	7544 917943	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_1959@postgrespro.ru", "phone": "+70958030600"}
0005434954707	CDA21A	2088 169476	ALEKSEY GORBUNOV	{"email": "gorbunov.aleksey-051972@postgrespro.ru", "phone": "+70755825665"}
0005434954709	708192	7082 885315	NATALYA FILIPPOVA	{"phone": "+70365211823"}
0005434954710	708192	1919 638351	ANATOLIY MEDVEDEV	{"email": "medvedev-anatoliy_1966@postgrespro.ru", "phone": "+70579076495"}
0005434954711	E81E66	2613 852116	TATYANA OSIPOVA	{"email": "osipova_tatyana.061976@postgrespro.ru", "phone": "+70393323083"}
0005434954712	1ECD00	1943 106066	GLEB GORBUNOV	{"email": "g.gorbunov-08091960@postgrespro.ru", "phone": "+70916215638"}
0005434954713	1ECD00	5051 616115	YURIY MATVEEV	{"phone": "+70358756362"}
0005434954714	1ECD00	3174 604136	NATALYA MAKSIMOVA	{"email": "n_maksimova23051967@postgrespro.ru", "phone": "+70840227405"}
0005434954715	7C3DF7	1576 518526	OLGA IVANOVA	{"email": "o-ivanova-101979@postgrespro.ru", "phone": "+70631832732"}
0005434954716	7C3DF7	8568 643775	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy-1960@postgrespro.ru", "phone": "+70323961842"}
0005434954717	71D4C4	7897 249469	LYUBOV ISAEVA	{"email": "lyubov.isaeva_20011978@postgrespro.ru", "phone": "+70585141683"}
0005434954718	58E587	0105 998594	ANDREY MIRONOV	{"email": "mironov_andrey_20041966@postgrespro.ru", "phone": "+70994130025"}
0005434954719	58E587	5645 352808	ELENA RYABOVA	{"phone": "+70565023173"}
0005434954720	0B5447	2085 189545	LEONID ISAEV	{"phone": "+70588114525"}
0005434954721	EC1210	7035 065307	ANDREY FOMIN	{"email": "a-fomin04031965@postgrespro.ru", "phone": "+70118442230"}
0005434963895	7F4386	3356 894170	ANDREY IVANOV	{"phone": "+70356481833"}
0005434963896	49C264	4437 361069	ALEKSANDR ISAEV	{"email": "isaevaleksandr_081973@postgrespro.ru", "phone": "+70433754407"}
0005434963897	D14B46	2274 561074	OLESYA STEPANOVA	{"email": "olesya.stepanova1969@postgrespro.ru", "phone": "+70578867925"}
0005434963898	D14B46	6603 702248	LYUBOV VLASOVA	{"email": "lvlasova25051966@postgrespro.ru", "phone": "+70258038959"}
0005434963899	373E9C	4069 533641	SEMEN SIDOROV	{"phone": "+70306370623"}
0005434963900	1A0514	8056 204967	NATALYA FILIPPOVA	{"email": "n_filippova-25081970@postgrespro.ru", "phone": "+70116299268"}
0005434963901	1A0514	3255 630221	SERGEY EGOROV	{"email": "egorovsergey-04021974@postgrespro.ru", "phone": "+70432720786"}
0005434963902	B49D62	8382 670470	MARINA FADEEVA	{"email": "fadeeva_m.1980@postgrespro.ru", "phone": "+70501301989"}
0005434963903	746D57	8349 317194	VYACHESLAV RODIONOV	{"phone": "+70592163990"}
0005434963904	746D57	9484 370276	MARIYA POTAPOVA	{"phone": "+70697075957"}
0005434963905	746D57	5024 069275	DMITRIY SIDOROV	{"phone": "+70537988303"}
0005434963906	376453	9405 254767	YULIYA NOVIKOVA	{"email": "novikova.yuliya-1970@postgrespro.ru", "phone": "+70332122696"}
0005434963907	53793E	3817 397327	IGOR KAZAKOV	{"email": "kazakov.igor-101972@postgrespro.ru", "phone": "+70591437550"}
0005434963908	8A02C8	2706 601116	ANNA MASLOVA	{"email": "amaslova_111964@postgrespro.ru", "phone": "+70668633221"}
0005434963909	8A02C8	6047 714321	YURIY BELOV	{"email": "y.belov-011969@postgrespro.ru", "phone": "+70330835567"}
0005434963910	8A02C8	7639 029618	MIKHAIL POPOV	{"email": "m-popov-021974@postgrespro.ru", "phone": "+70751215112"}
0005434963911	B5C1E9	7803 515881	YULIYA BORISOVA	{"email": "yborisova.1968@postgrespro.ru", "phone": "+70917082970"}
0005434963912	1DDA62	6850 911561	VALENTINA MELNIKOVA	{"email": "v-melnikova-1979@postgrespro.ru", "phone": "+70145174574"}
0005434963913	1DDA62	3118 980326	SERGEY NIKITIN	{"phone": "+70197554834"}
0005434963914	1DDA62	0231 294360	NATALYA POPOVA	{"email": "popova-natalya_1983@postgrespro.ru", "phone": "+70048307017"}
0005434963915	5B131D	7328 947407	VALENTINA TARASOVA	{"email": "valentina-tarasova-1967@postgrespro.ru", "phone": "+70441337316"}
0005434963916	A1283B	5214 575458	VERA KARPOVA	{"phone": "+70983128892"}
0005434963917	92516A	9084 208938	OLGA DMITRIEVA	{"phone": "+70073555420"}
0005434963918	36F63B	5001 105420	EDUARD VLASOV	{"phone": "+70924557928"}
0005434963919	8A2E39	8174 855194	DANIIL VASILEV	{"phone": "+70170023453"}
0005434963920	2FEED8	4751 468087	MARIYA ZHUKOVA	{"email": "zhukovam-101963@postgrespro.ru", "phone": "+70375070317"}
0005434963921	2FEED8	9465 630676	TATYANA ALEKSEEVA	{"email": "alekseeva_t.08021973@postgrespro.ru", "phone": "+70037869913"}
0005434963922	783167	8580 591369	LEONID KAZAKOV	{"email": "l.kazakov-14041968@postgrespro.ru", "phone": "+70114696199"}
0005434963923	D6C0F1	8818 757758	TATYANA SCHERBAKOVA	{"email": "tatyana_scherbakova.1979@postgrespro.ru", "phone": "+70869055596"}
0005434963924	F4F52D	9021 212853	IVAN KRASNOV	{"phone": "+70272854486"}
0005434963925	3A985C	0579 258182	TATYANA ZAKHAROVA	{"phone": "+70173373143"}
0005434963926	3A985C	5338 231988	EVGENIYA MAKAROVA	{"phone": "+70908766271"}
0005434963927	B8FD39	0212 628667	ROZA MOROZOVA	{"email": "morozovar-091988@postgrespro.ru", "phone": "+70723301015"}
0005434963928	ADD48C	1824 612254	EKATERINA MASLOVA	{"email": "ekaterinamaslova.16031972@postgrespro.ru", "phone": "+70417933828"}
0005434963929	242544	8531 777612	VLADIMIR AFANASEV	{"phone": "+70238176851"}
0005434963930	CC54A9	2744 820698	IVAN EGOROV	{"phone": "+70765282048"}
0005434963931	5703C6	9954 519307	ALBINA PETROVA	{"email": "petrova_a-18081978@postgrespro.ru", "phone": "+70668232534"}
0005434963932	9BE13B	6230 590328	OLGA MOISEEVA	{"email": "moiseevaolga-051973@postgrespro.ru", "phone": "+70808095106"}
0005434963933	FBC1A6	5348 893466	YURIY MOROZOV	{"email": "morozov.yuriy_1983@postgrespro.ru", "phone": "+70891369884"}
0005434963934	7CA293	2497 507821	VLADISLAV DENISOV	{"email": "denisov_vladislav-061973@postgrespro.ru", "phone": "+70889749355"}
0005434963935	81FAA2	2202 635675	LYUBOV FADEEVA	{"email": "l_fadeeva1967@postgrespro.ru", "phone": "+70102453909"}
0005434963936	EF28C5	6993 410412	ILYA SAVELEV	{"email": "ilya.savelev.121962@postgrespro.ru", "phone": "+70844403779"}
0005434963937	C93452	2330 934662	ROMAN MIKHAYLOV	{"phone": "+70794017816"}
0005434963938	C93452	3978 800654	NADEZHDA BELYAEVA	{"email": "belyaeva.nadezhda.22011960@postgrespro.ru", "phone": "+70931910535"}
0005434963939	778D93	2507 650100	ANDREY NIKOLAEV	{"email": "andrey-nikolaev_1972@postgrespro.ru", "phone": "+70096666034"}
0005434963940	778D93	0001 329904	VLADIMIR PAVLOV	{"email": "vladimir.pavlov.1971@postgrespro.ru", "phone": "+70936937300"}
0005434963941	06BFEF	5248 859948	STANISLAV MAKAROV	{"email": "smakarov_1978@postgrespro.ru", "phone": "+70601927429"}
0005434963942	717577	6081 966709	ANNA POPOVA	{"phone": "+70964424150"}
0005434963943	D9C768	8423 754513	ARTEM NOVIKOV	{"phone": "+70894391580"}
0005434963944	8CAF32	9316 856550	VITALIY AFANASEV	{"email": "afanasev.v-091965@postgrespro.ru", "phone": "+70565984830"}
0005434963945	8CAF32	1598 942485	ELENA NIKOLAEVA	{"email": "e_nikolaeva.06041965@postgrespro.ru", "phone": "+70259977660"}
0005434963946	6022EE	0791 115659	ALEKSANDR CHERNOV	{"email": "chernov_a25041965@postgrespro.ru", "phone": "+70185046510"}
0005434963947	CA4BEC	8531 530397	ANATOLIY VASILEV	{"phone": "+70376527767"}
0005434963948	60AAD3	0525 994006	NATALYA SEMENOVA	{"phone": "+70039852226"}
0005434963949	60AAD3	1299 674993	GALINA ORLOVA	{"email": "orlova.galina-091973@postgrespro.ru", "phone": "+70789130150"}
0005434963950	60AAD3	5472 685390	DENIS KRASNOV	{"email": "krasnov_denis.1966@postgrespro.ru", "phone": "+70243484780"}
0005434963951	7FEE98	4557 314756	MIKHAIL ALEKSEEV	{"email": "malekseev-071963@postgrespro.ru", "phone": "+70182437518"}
0005434963952	DF875D	1035 715064	GALINA KAZAKOVA	{"email": "gkazakova05091972@postgrespro.ru", "phone": "+70591886853"}
0005434963953	DF875D	9264 469522	ANASTASIYA ALEKSEEVA	{"email": "alekseevaanastasiya_121973@postgrespro.ru", "phone": "+70558591089"}
0005434963954	C12727	0323 348858	LEONID KULIKOV	{"email": "kulikov.l_1960@postgrespro.ru", "phone": "+70811952173"}
0005434963955	C12727	6043 019473	ANATOLIY SIDOROV	{"email": "sidorov.anatoliy1977@postgrespro.ru", "phone": "+70033032335"}
0005434963956	F39BD3	0297 501462	LIDIYA NIKITINA	{"phone": "+70483454078"}
0005434963957	F39BD3	6279 481574	MIKHAIL TIMOFEEV	{"email": "m_timofeev-02091969@postgrespro.ru", "phone": "+70919917608"}
0005434963958	62B6C5	1073 542148	VALENTINA SOLOVEVA	{"email": "soloveva.v_031969@postgrespro.ru", "phone": "+70257572747"}
0005434963959	3EB552	9207 961361	DMITRIY DENISOV	{"email": "d.denisov.1958@postgrespro.ru", "phone": "+70562459200"}
0005434963960	1440F6	8223 737373	ANATOLIY GUSEV	{"phone": "+70664964807"}
0005434963961	BE3A90	2897 805386	YULIYA ANDREEVA	{"phone": "+70229576147"}
0005434963962	74BEBC	9927 357413	NIKOLAY FILIPPOV	{"phone": "+70210850985"}
0005434963963	EB4D54	4551 674891	MAKSIM VOLKOV	{"email": "volkov.maksim-031969@postgrespro.ru", "phone": "+70391833506"}
0005434963964	EB4D54	0455 519736	ALEKSANDR DMITRIEV	{"phone": "+70187614950"}
0005434963965	4A28BA	6269 421910	SERGEY ABRAMOV	{"email": "s-abramov_15041970@postgrespro.ru", "phone": "+70707311385"}
0005434963966	8D077C	5526 924803	ANDREY FEDOROV	{"email": "fedorov.andrey_1976@postgrespro.ru", "phone": "+70523940654"}
0005434963967	8D077C	1912 178860	ALEKSANDRA FILIPPOVA	{"email": "filippovaaleksandra1965@postgrespro.ru", "phone": "+70559693881"}
0005434963968	8D077C	6579 244690	GALINA ALEKSANDROVA	{"phone": "+70691449846"}
0005434963969	270167	2140 931396	KONSTANTIN KUZNECOV	{"phone": "+70474271553"}
0005434963970	0C63F1	0571 212671	EVGENIY IVANOV	{"phone": "+70592265654"}
0005434963971	0C63F1	4675 722917	TATYANA GORBUNOVA	{"email": "tatyanagorbunova13111961@postgrespro.ru", "phone": "+70385527299"}
0005434963972	41387F	3199 486995	ELENA BOGDANOVA	{"phone": "+70643618843"}
0005434963973	4FDF66	6540 771208	LYUBOV ORLOVA	{"email": "orlova.lyubov_24031965@postgrespro.ru", "phone": "+70621042251"}
0005434963974	4FDF66	6554 381454	NADEZHDA FROLOVA	{"email": "n.frolova-06021981@postgrespro.ru", "phone": "+70205067397"}
0005434963975	D33D89	7533 606771	MIKHAIL SMIRNOV	{"phone": "+70445567159"}
0005434963976	D33D89	4761 913144	NINA NIKIFOROVA	{"phone": "+70186538013"}
0005434963977	CD44B7	4926 564558	ALEKSANDR SEMENOV	{"phone": "+70509446052"}
0005434963978	CD44B7	2993 521903	ROMAN KUZMIN	{"email": "rkuzmin-02041967@postgrespro.ru", "phone": "+70319355833"}
0005434963979	C327E1	4175 033504	GENNADIY GORBUNOV	{"email": "g.gorbunov_031969@postgrespro.ru", "phone": "+70444581608"}
0005434963980	C327E1	3096 341966	ANASTASIYA KONOVALOVA	{"phone": "+70047191058"}
0005434963981	2A4456	2540 867618	OKSANA KUZNECOVA	{"phone": "+70985977947"}
0005434963982	2A4456	8912 021741	TATYANA SAVELEVA	{"phone": "+70671442473"}
0005434963983	CA6E6D	2486 861107	NATALYA BORISOVA	{"email": "borisova.natalya_031967@postgrespro.ru", "phone": "+70730336226"}
0005434963984	909EC1	4659 538954	ALEKSEY MELNIKOV	{"email": "melnikov-aleksey_27021973@postgrespro.ru", "phone": "+70875314530"}
0005434963985	4EE7BC	6134 539595	ELENA SEMENOVA	{"phone": "+70493844647"}
0005434963986	4EE7BC	2559 404245	TAMARA NIKITINA	{"phone": "+70558492845"}
0005434963987	621911	4258 575728	EVGENIYA NIKOLAEVA	{"phone": "+70630039035"}
0005434963988	EF1B4B	4915 560363	ALEKSANDRA ZOTOVA	{"phone": "+70947644869"}
0005434963989	9E91C4	3094 934079	MIKHAIL POPOV	{"phone": "+70376914341"}
0005434963990	0EC5CC	2317 817675	ANATOLIY BORISOV	{"email": "aborisov_13031985@postgrespro.ru", "phone": "+70608230546"}
0005434963991	1D9108	3651 244080	TATYANA TITOVA	{"email": "t_titova-07061966@postgrespro.ru", "phone": "+70717481348"}
0005434963992	84C318	3839 465638	ALEKSANDR SERGEEV	{"email": "sergeev-a.1971@postgrespro.ru", "phone": "+70235030759"}
0005434963993	846843	3897 898866	NIKOLAY STEPANOV	{"phone": "+70533847915"}
0005434963994	01F813	9126 386825	NADEZHDA SMIRNOVA	{"email": "smirnova.n-1986@postgrespro.ru", "phone": "+70807386225"}
0005434963995	C4E0E0	5063 989239	VALENTINA PAVLOVA	{"email": "v-pavlova_30121973@postgrespro.ru", "phone": "+70479409899"}
0005434963996	C4E0E0	2983 252726	SERGEY SERGEEV	{"phone": "+70346860259"}
0005434963997	C4E0E0	2679 336020	VLADIMIR ZAYCEV	{"email": "zaycevv1967@postgrespro.ru", "phone": "+70477806368"}
0005434963998	41262A	3185 198949	ROMAN DENISOV	{"phone": "+70637769880"}
0005434963999	41262A	5507 021742	ALLA VOLKOVA	{"phone": "+70496798313"}
0005434964000	41262A	3191 327736	MARIYA ANTONOVA	{"email": "antonova-m_21061973@postgrespro.ru", "phone": "+70338244993"}
0005434964001	287856	9778 620138	NIKOLAY POPOV	{"phone": "+70190383624"}
0005434964002	DE3B0E	4283 468272	VYACHESLAV SHEVCHENKO	{"email": "v-shevchenko031969@postgrespro.ru", "phone": "+70976310842"}
0005434964003	FD59BA	3696 660606	SERGEY MATVEEV	{"phone": "+70627553972"}
0005434964004	07375A	6736 050791	VLADIMIR GAVRILOV	{"email": "vgavrilov-111982@postgrespro.ru", "phone": "+70584128897"}
0005434964005	844552	0429 641680	ALEKSEY FOMIN	{"phone": "+70466495477"}
0005434964006	D80B08	1076 336690	EVGENIY KUDRYASHOV	{"email": "kudryashovevgeniy1979@postgrespro.ru", "phone": "+70720137386"}
0005434964007	4B05E7	7031 795390	VIKTOR MELNIKOV	{"phone": "+70817957912"}
0005434964008	399E06	9117 345425	ELENA PETROVA	{"phone": "+70417322466"}
0005434964009	66C4DB	3287 281551	ALESYA TIKHONOVA	{"phone": "+70073733490"}
0005434964010	A9A96D	4150 204641	LILIYA NOVIKOVA	{"phone": "+70509415200"}
0005434964011	89A96D	7618 807829	RAMIL TIMOFEEV	{"phone": "+70894610429"}
0005434964012	797885	6579 514273	PAVEL DAVYDOV	{"email": "davydov.pavel1972@postgrespro.ru", "phone": "+70116176032"}
0005434964013	797885	7644 373030	SVETLANA KUZMINA	{"phone": "+70347156577"}
0005434964014	2D20BA	4639 881171	VIOLETTA GRISHINA	{"email": "violetta_grishina_12011969@postgrespro.ru", "phone": "+70149112874"}
0005434964015	2D20BA	4777 342094	NATALYA STEPANOVA	{"email": "n.stepanova1971@postgrespro.ru", "phone": "+70097587367"}
0005434964016	BFD8D1	1274 817973	LARISA LEBEDEVA	{"email": "lebedeva.larisa1964@postgrespro.ru", "phone": "+70353659173"}
0005434964017	07E788	4138 575984	NATALYA SERGEEVA	{"email": "sergeeva_natalya22121969@postgrespro.ru", "phone": "+70098980972"}
0005434964018	07E788	4847 256595	VLADISLAV BONDARENKO	{"email": "bondarenko_v.1966@postgrespro.ru", "phone": "+70125316932"}
0005434964019	CA4D04	4286 677775	ANDREY ZAYCEV	{"email": "zaycev_a1963@postgrespro.ru", "phone": "+70266928676"}
0005434964020	6279E3	2880 153831	NIKOLAY NIKOLAEV	{"email": "nikolaevn-111967@postgrespro.ru", "phone": "+70668101006"}
0005434964021	6279E3	0977 546025	ALEKSANDR OSIPOV	{"phone": "+70112532065"}
0005434964022	28FA13	3880 708818	ANATOLIY PAVLOV	{"phone": "+70151735088"}
0005434964023	C8DB64	7157 277468	ALEKSEY KARPOV	{"email": "akarpov.22051982@postgrespro.ru", "phone": "+70413821000"}
0005434964024	596B95	8006 551949	ALEKSANDR DMITRIEV	{"email": "a.dmitriev_1972@postgrespro.ru", "phone": "+70744371648"}
0005434964025	596B95	6064 302578	GENNADIY AFANASEV	{"email": "gennadiyafanasev22091976@postgrespro.ru", "phone": "+70586315868"}
0005434964026	308C30	4985 983483	PAVEL SCHERBAKOV	{"email": "pavelscherbakov_111972@postgrespro.ru", "phone": "+70180255436"}
0005434964027	B63FCA	9269 110261	VALERIYA ORLOVA	{"email": "v-orlova_041971@postgrespro.ru", "phone": "+70507054079"}
0005434964028	3C875B	5498 250504	VLADIMIR SERGEEV	{"email": "sergeev-vladimir07121955@postgrespro.ru", "phone": "+70672852041"}
0005434964029	33FA2B	1872 201778	ALENA EFIMOVA	{"phone": "+70190815848"}
0005434964030	33FA2B	0176 538961	VASILIY FROLOV	{"phone": "+70899915044"}
0005434964031	6FB62F	2304 220959	ALINA DMITRIEVA	{"phone": "+70446414903"}
0005434964032	CFFFC2	3165 772636	LEONID GRIGOREV	{"phone": "+70582824445"}
0005434964033	CFFFC2	6967 174236	VLADIMIR MOROZOV	{"email": "morozovv081962@postgrespro.ru", "phone": "+70156525318"}
0005434964034	900AE6	2823 977476	STANISLAV GERASIMOV	{"email": "s-gerasimov_1981@postgrespro.ru", "phone": "+70466966690"}
0005434964035	900AE6	4814 176581	GEORGIY ZAKHAROV	{"email": "zakharov.georgiy.1965@postgrespro.ru", "phone": "+70472310752"}
0005434964036	9D32DF	7354 655338	MARIYA NIKIFOROVA	{"phone": "+70370586262"}
0005434964037	E81687	0742 709097	ANDREY KUDRYASHOV	{"phone": "+70931404854"}
0005434964038	E81687	0170 014976	YULIYA KOROLEVA	{"phone": "+70850575381"}
0005434964039	67369B	7190 850419	YULIYA SERGEEVA	{"phone": "+70117507500"}
0005434964040	E877FB	1001 659356	MAKSIM IVANOV	{"email": "ivanov_m.12071973@postgrespro.ru", "phone": "+70582886954"}
0005434964041	E877FB	1538 358794	KIRILL KOZLOV	{"phone": "+70692148782"}
0005434964042	2135DD	1872 511103	LIDIYA EGOROVA	{"phone": "+70558893506"}
0005434964043	DA0A6C	6875 643459	NINA POPOVA	{"email": "popovan_02041965@postgrespro.ru", "phone": "+70696604191"}
0005434964044	DA0A6C	0625 511813	SVETLANA IVANOVA	{"phone": "+70336163062"}
0005434964045	9CA088	1208 692852	ROMAN YAKOVLEV	{"email": "roman_yakovlev.1976@postgrespro.ru", "phone": "+70031119539"}
0005434964046	9CA088	5323 573333	IRINA BARANOVA	{"email": "baranova-irina_021972@postgrespro.ru", "phone": "+70956376255"}
0005434964047	C94927	9793 152788	ARTEM MAKAROV	{"email": "makarova_11011977@postgrespro.ru", "phone": "+70032697633"}
0005434964048	7BFD4C	3060 831401	ILYA KONOVALOV	{"phone": "+70338960991"}
0005434964049	279DBC	7872 677574	ALLA SMIRNOVA	{"email": "smirnova.a.071977@postgrespro.ru", "phone": "+70409626618"}
0005434964050	85CB83	2586 707140	SERGEY SCHERBAKOV	{"email": "s_scherbakov.14051984@postgrespro.ru", "phone": "+70446222856"}
0005434964051	85CB83	1474 272658	ELENA GORBUNOVA	{"phone": "+70415427311"}
0005434964052	EED65B	5725 327354	TATYANA GAVRILOVA	{"phone": "+70626015853"}
0005434964053	BAA918	2892 960729	YULIYA ANDREEVA	{"phone": "+70271911468"}
0005434964054	BAA918	1242 912411	RAISA PAVLOVA	{"phone": "+70863479836"}
0005434964055	7943CF	6080 232015	VALENTINA EFREMOVA	{"email": "efremova-v1975@postgrespro.ru", "phone": "+70653789529"}
0005434964056	E4822A	1722 259241	DANIIL ANDREEV	{"phone": "+70948772829"}
0005434964057	730B66	4906 066737	ANNA FROLOVA	{"email": "frolovaa_13041972@postgrespro.ru", "phone": "+70068660018"}
0005434964058	EC7C12	5403 852291	ALISA MAKSIMOVA	{"phone": "+70115746463"}
0005434964059	F7FEAD	1967 928137	VIKTOR MOISEEV	{"email": "viktor.moiseev1971@postgrespro.ru", "phone": "+70899212500"}
0005434964060	838195	4877 908557	ANDREY MAKAROV	{"phone": "+70563074353"}
0005434964061	C51E49	9015 221963	YURIY PETROV	{"phone": "+70448827007"}
0005434964062	62F49A	0335 048635	POLINA YUDINA	{"email": "p-yudina_16091971@postgrespro.ru", "phone": "+70740754812"}
0005434964063	2E4158	3197 069620	KIRILL MAKSIMOV	{"email": "kirill_maksimov081972@postgrespro.ru", "phone": "+70130610425"}
0005434964064	672A39	2706 934913	DANILA SAVELEV	{"phone": "+70908273843"}
0005434964065	D540C5	2286 009850	EVGENIY VASILEV	{"phone": "+70231979435"}
0005434964066	8784BD	7339 330232	OLGA LEBEDEVA	{"phone": "+70920401049"}
0005434964067	E021A5	0309 652705	MARINA BARANOVA	{"email": "marinabaranova.13071969@postgrespro.ru", "phone": "+70382304891"}
0005434964068	4D7DD7	6269 268696	VIKTOR KOZLOV	{"phone": "+70058951055"}
0005434964069	4D7DD7	8048 467508	NATALYA OSIPOVA	{"email": "natalya-osipova-1971@postgrespro.ru", "phone": "+70269922798"}
0005434964070	4D7DD7	6808 869509	ANASTASIYA GORBUNOVA	{"email": "gorbunova.anastasiya17051966@postgrespro.ru", "phone": "+70965781458"}
0005434964071	0D7312	5562 473179	TATYANA MELNIKOVA	{"email": "t_melnikova_1973@postgrespro.ru", "phone": "+70662002949"}
0005434964072	0D7312	3936 200671	GALINA NIKOLAEVA	{"email": "galinanikolaeva_121957@postgrespro.ru", "phone": "+70516065879"}
0005434964073	AD9816	3706 635254	VLADIMIR ISAEV	{"phone": "+70074485975"}
0005434964074	AD9816	4180 741570	KONSTANTIN KOZLOV	{"email": "konstantin-kozlov-25111971@postgrespro.ru", "phone": "+70922383404"}
0005434964075	9453CA	8263 609703	VASILIY BELOV	{"phone": "+70977145706"}
0005434964076	3B9572	6249 444393	ALBINA BORISOVA	{"phone": "+70208458985"}
0005434964077	F51D92	7853 687597	EKATERINA GRISHINA	{"phone": "+70781084055"}
0005434964078	4C7F36	1538 726813	SOFIYA MAKSIMOVA	{"email": "s_maksimova_15091975@postgrespro.ru", "phone": "+70900357133"}
0005434964079	3D7001	7098 059663	KONSTANTIN SOROKIN	{"phone": "+70775113084"}
0005434964080	1FC9E8	6263 919396	ALEKSEY VOLKOV	{"email": "volkov-a1962@postgrespro.ru", "phone": "+70881492952"}
0005434964081	7A66B4	8840 561606	ARSEN ZHUKOV	{"email": "zhukov-a27111972@postgrespro.ru", "phone": "+70055204309"}
0005434964082	F66DD9	3836 491895	SVETLANA DMITRIEVA	{"email": "svetlana_dmitrieva.091972@postgrespro.ru", "phone": "+70183293529"}
0005434964083	F66DD9	8516 299416	MAKSIM GORBUNOV	{"phone": "+70062304669"}
0005434964084	305A4B	7396 335879	EGOR KOROLEV	{"email": "korolev.e1975@postgrespro.ru", "phone": "+70290994636"}
0005434964085	EB789F	1100 686059	MIKHAIL MAKAROV	{"email": "makarov.mikhail-1969@postgrespro.ru", "phone": "+70136750044"}
0005434964086	3E4FFF	8998 354389	YULIYA SEMENOVA	{"email": "y_semenova_1985@postgrespro.ru", "phone": "+70616895461"}
0005434964087	3E4FFF	9917 786492	LYUDMILA GERASIMOVA	{"email": "gerasimova-l121970@postgrespro.ru", "phone": "+70766623919"}
0005434964088	A42ECD	3947 784534	EVGENIY KUZMIN	{"email": "kuzmin_e09111968@postgrespro.ru", "phone": "+70225724691"}
0005434964089	FE059E	5189 889768	ZINAIDA FROLOVA	{"phone": "+70821547220"}
0005434964090	FE059E	9888 832081	SVYATOSLAV SAVELEV	{"phone": "+70968792054"}
0005434964091	1774BA	7733 810214	GEORGIY VASILEV	{"email": "gvasilev1963@postgrespro.ru", "phone": "+70123048015"}
0005434964092	1774BA	4717 590074	ANATOLIY ABRAMOV	{"email": "anatoliy-abramov-101972@postgrespro.ru", "phone": "+70889581294"}
0005434964093	CC0334	2154 900888	TAMARA TIKHONOVA	{"phone": "+70710568147"}
0005434964094	9944A9	3329 639283	ALEKSEY KUZNECOV	{"phone": "+70376987405"}
0005434964095	9944A9	4358 108509	ALEKSANDRA VOLKOVA	{"email": "volkovaaleksandra.05111968@postgrespro.ru", "phone": "+70721300063"}
0005434964096	E7DEEB	8579 325636	IGOR PAVLOV	{"phone": "+70332029299"}
0005434964097	76B413	6852 226539	RAISA KAZAKOVA	{"phone": "+70443765061"}
0005434964098	76B413	0343 531148	VALENTINA POPOVA	{"phone": "+70625930328"}
0005434964099	867FF9	9870 837533	ANDREY SAVELEV	{"email": "savelev.a021966@postgrespro.ru", "phone": "+70144737001"}
0005434964100	CE29C5	7401 185347	ANNA IVANOVA	{"phone": "+70259467050"}
0005434964101	4314EB	1313 637884	NATALYA CHERNOVA	{"email": "chernova_n121980@postgrespro.ru", "phone": "+70446305313"}
0005434964102	4314EB	4184 494130	ANASTASIYA MIKHAYLOVA	{"email": "anastasiyamikhaylova-17031981@postgrespro.ru", "phone": "+70462517246"}
0005434964103	4314EB	9178 860139	YULIYA VLASOVA	{"phone": "+70728230411"}
0005434964104	75249D	1427 080370	VERA GRISHINA	{"email": "grishina.vera-27031971@postgrespro.ru", "phone": "+70820797444"}
0005434964105	F8870C	2193 882981	NIKITA NIKOLAEV	{"email": "nikita-nikolaev.27021979@postgrespro.ru", "phone": "+70724859298"}
0005434964106	247D28	4904 238916	ARTEM OSIPOV	{"email": "osipova.1977@postgrespro.ru", "phone": "+70090585870"}
0005434964107	247D28	6094 863170	VALENTINA FILIPPOVA	{"phone": "+70742204486"}
0005434964108	7FBBA5	7383 524049	ELENA ANDREEVA	{"email": "e_andreeva121982@postgrespro.ru", "phone": "+70490447107"}
0005434964109	DA6047	7321 361095	OKSANA IVANOVA	{"phone": "+70033815411"}
0005434964110	DA6047	2479 761847	NATALYA IVANOVA	{"phone": "+70506462669"}
0005434964111	54A21D	5449 795397	VLADIMIR KOZLOV	{"email": "vladimir.kozlov22041973@postgrespro.ru", "phone": "+70321981271"}
0005434964112	892EB2	8879 893279	GALINA VOLKOVA	{"phone": "+70548064483"}
0005434964113	D44445	4177 400566	OLESYA KOLESNIKOVA	{"email": "kolesnikova_o1973@postgrespro.ru", "phone": "+70801221866"}
0005434964114	692EC1	7001 756053	OLGA MEDVEDEVA	{"phone": "+70347270373"}
0005434964115	BB0B30	5934 007648	LYUBOV MARTYNOVA	{"email": "lyubov.martynova-091966@postgrespro.ru", "phone": "+70752271707"}
0005434964116	BB0B30	0161 780783	ANATOLIY ZHUKOV	{"phone": "+70463260793"}
0005434964117	40BE8F	1790 389574	NAIL PETROV	{"phone": "+70234777923"}
0005434964118	2DACFE	9645 866531	TATYANA TIMOFEEVA	{"phone": "+70407211984"}
0005434964119	2DACFE	3684 095980	VALERIY MIKHAYLOV	{"email": "mikhaylov.valeriy.15091984@postgrespro.ru", "phone": "+70923943583"}
0005434964120	28A3A7	8875 918768	SAVELIY KUZNECOV	{"email": "kuznecov.s_101970@postgrespro.ru", "phone": "+70760861616"}
0005434964121	7E9FAA	5432 135201	NATALIYA NAUMOVA	{"email": "n.naumova-1967@postgrespro.ru", "phone": "+70760875456"}
0005434964122	547E36	2084 363174	AYRAT ZHURAVLEV	{"email": "zhuravlev-ayrat_111978@postgrespro.ru", "phone": "+70477917103"}
0005434964123	AB4396	8678 939045	OLGA VOLKOVA	{"phone": "+70395995081"}
0005434964124	B931B2	6580 338855	LYUBOV FEDOROVA	{"phone": "+70219158632"}
0005434964125	49B13C	3110 202857	ANTON GAVRILOV	{"phone": "+70727540095"}
0005434964126	5100C2	7846 574680	SVETLANA ZAKHAROVA	{"email": "svetlana-zakharova-09071972@postgrespro.ru", "phone": "+70835795112"}
0005434964127	C68AF5	1745 362481	POLINA NOVIKOVA	{"phone": "+70605970374"}
0005434964128	C68AF5	7416 159430	ALEKSEY GORBUNOV	{"email": "aleksey_gorbunov_21111959@postgrespro.ru", "phone": "+70916662013"}
0005434964129	16B335	6937 028137	MIKHAIL OSIPOV	{"email": "osipovmikhail-03011968@postgrespro.ru", "phone": "+70819347510"}
0005434964130	BA5FC2	3204 121126	TATYANA SERGEEVA	{"email": "sergeeva.tatyana_1973@postgrespro.ru", "phone": "+70378665783"}
0005434964131	9AE40C	8337 586691	DMITRIY SIDOROV	{"email": "sidorov_dmitriy10101964@postgrespro.ru", "phone": "+70957062054"}
0005434964132	115BB8	9216 881594	GALINA DANILOVA	{"email": "danilova-g-1983@postgrespro.ru", "phone": "+70176618274"}
0005434964133	115BB8	8410 541201	LIDIYA KUDRYASHOVA	{"email": "kudryashova.lidiya.031975@postgrespro.ru", "phone": "+70702708416"}
0005434964134	115BB8	1148 167246	ZINAIDA ILINA	{"email": "zinaida_ilina_1967@postgrespro.ru", "phone": "+70243406211"}
0005434964135	147566	0772 052237	VALENTINA SEMENOVA	{"phone": "+70214616578"}
0005434964136	147566	6601 596605	TATYANA MIRONOVA	{"phone": "+70140149132"}
0005434964137	147566	9666 088537	VLADISLAV OSIPOV	{"email": "vladislavosipov.1977@postgrespro.ru", "phone": "+70607381011"}
0005434964138	3026E5	0515 777232	MAKSIM SCHERBAKOV	{"phone": "+70286829883"}
0005434964139	3026E5	9270 068327	ALINA SMIRNOVA	{"phone": "+70666480963"}
0005434964140	C91C68	9385 206029	EKATERINA SMIRNOVA	{"phone": "+70235054221"}
0005434964141	8B45DD	1747 449552	ROMAN DMITRIEV	{"email": "dmitriev.roman-071961@postgrespro.ru", "phone": "+70622343630"}
0005434964142	664B3D	8149 244703	VYACHESLAV KOZLOV	{"phone": "+70909746485"}
0005434964143	4F64A9	7975 483106	VIKTOR KUZMIN	{"phone": "+70546333870"}
0005434964144	1A2980	4283 979170	YULIYA SIDOROVA	{"phone": "+70359818947"}
0005434964145	1A2980	6458 338752	LEONID SMIRNOV	{"email": "smirnov-leonid-06031970@postgrespro.ru", "phone": "+70529970958"}
0005434964146	BA9E3B	1921 919232	RAISA FADEEVA	{"phone": "+70863975210"}
0005434964147	BA9E3B	6114 525295	VLADISLAV GAVRILOV	{"phone": "+70786119230"}
0005434964148	17CD63	2974 662410	ALEKSANDR TARASOV	{"phone": "+70940286228"}
0005434964149	37F3F0	6672 969833	VLADIMIR ABRAMOV	{"email": "abramovvladimir.10051983@postgrespro.ru", "phone": "+70776376758"}
0005434964150	3E22F3	5395 909165	ALEKSEY SOKOLOV	{"phone": "+70209714265"}
0005434964151	3E22F3	4861 348157	ANDREY MOROZOV	{"email": "andrey_morozov.11071979@postgrespro.ru", "phone": "+70718507123"}
0005434964152	9B30BD	7819 470130	BORIS ROMANOV	{"phone": "+70495919646"}
0005434964153	9B30BD	3155 225327	LYUDMILA ORLOVA	{"email": "orlova-l.021972@postgrespro.ru", "phone": "+70280560662"}
0005434964154	8BEA98	2074 731553	TATYANA LUKYANOVA	{"phone": "+70920945894"}
0005434964155	8BEA98	0704 978527	ANDREY MOROZOV	{"phone": "+70912536867"}
0005434964156	BD4B65	4235 976912	ALEKSEY SOKOLOV	{"email": "sokolova-1965@postgrespro.ru", "phone": "+70487087156"}
0005434964157	BD4B65	7799 019628	ANNA SIDOROVA	{"email": "sidorovaa1978@postgrespro.ru", "phone": "+70233133800"}
0005434964158	56773A	3130 091356	NATALYA SOKOLOVA	{"email": "n_sokolova.1961@postgrespro.ru", "phone": "+70662670290"}
0005434964159	3CFED5	8891 843200	NIKITA ROMANOV	{"phone": "+70064345932"}
0005434964160	4411A7	7940 491281	ELENA VASILEVA	{"phone": "+70318203545"}
0005434964161	08D779	0493 335752	ALEKSEY GAVRILOV	{"phone": "+70102436103"}
0005434964162	08D779	1646 595071	ANDREY ILIN	{"email": "andrey-ilin1961@postgrespro.ru", "phone": "+70144690082"}
0005434964163	F38D53	2665 200530	EVGENIY NOVIKOV	{"email": "evgeniynovikov-22101992@postgrespro.ru", "phone": "+70954125343"}
0005434964164	F38D53	5242 738858	ALEVTINA RYABOVA	{"phone": "+70572078166"}
0005434964165	724993	7462 881992	SERGEY MIKHAYLOV	{"email": "s.mikhaylov-06111965@postgrespro.ru", "phone": "+70098361491"}
0005434964166	724993	0247 529727	ELIZAVETA SIDOROVA	{"phone": "+70275358644"}
0005434964167	724993	0698 404924	DMITRIY VASILEV	{"phone": "+70613624775"}
0005434964168	5C07E5	2100 265113	ANASTASIYA KONOVALOVA	{"email": "konovalovaa051966@postgrespro.ru", "phone": "+70467069633"}
0005434964169	5C07E5	4356 707305	ELENA ABRAMOVA	{"phone": "+70890068591"}
0005434964170	5C07E5	2217 308713	MAKSIM VOLKOV	{"email": "m.volkov-1961@postgrespro.ru", "phone": "+70220077611"}
0005434964171	82381A	3793 677549	VLADIMIR ROMANOV	{"email": "vladimir-romanov.111975@postgrespro.ru", "phone": "+70386502773"}
0005434964172	0FFB47	7812 549859	VLADISLAV KOZLOV	{"phone": "+70323916263"}
0005434964173	0FFB47	0116 146898	LIDIYA KUZNECOVA	{"email": "kuznecova.l_1964@postgrespro.ru", "phone": "+70527103125"}
0005434964174	7BEFE4	2513 666244	VASILIY ZAKHAROV	{"email": "zakharov-vasiliy_11031972@postgrespro.ru", "phone": "+70064650034"}
0005434964175	7BEFE4	4023 593220	IRINA VASILEVA	{"phone": "+70482536507"}
0005434964176	F6E992	0140 978763	ANATOLIY NOVIKOV	{"phone": "+70724568423"}
0005434964177	CDE3EB	8103 355466	IRINA NIKOLAEVA	{"phone": "+70663983817"}
0005434964178	221680	9268 601177	ALENA NIKITINA	{"phone": "+70196369677"}
0005434964179	36F882	0615 072281	DANIL NIKITIN	{"email": "nikitin-danil_10081975@postgrespro.ru", "phone": "+70057776446"}
0005434964180	CE9B63	3277 720209	VALERIY KULIKOV	{"email": "v_kulikov1974@postgrespro.ru", "phone": "+70395062505"}
0005434964181	D75E3C	3705 167844	PAVEL IVANOV	{"email": "ivanov-p.1971@postgrespro.ru", "phone": "+70840693196"}
0005434964182	2B54AC	3920 628194	GALINA KOROLEVA	{"email": "koroleva.g_1984@postgrespro.ru", "phone": "+70503538003"}
0005434964183	2B54AC	8841 975860	ANDREY PAVLOV	{"email": "pavlov-a_1977@postgrespro.ru", "phone": "+70604048420"}
0005434964184	64E1A5	6068 968263	TATYANA SCHERBAKOVA	{"phone": "+70574907045"}
0005434964185	7B63BE	6412 460139	ANATOLIY RODIONOV	{"phone": "+70840571469"}
0005434964186	148C46	8939 659196	MARINA LOGINOVA	{"phone": "+70596869012"}
0005434964187	148C46	7042 707243	VIKTOR KISELEV	{"email": "v-kiselev-071970@postgrespro.ru", "phone": "+70100776675"}
0005434964248	232287	5752 747854	VASILIY BARANOV	{"phone": "+70821821374"}
0005434964188	148C46	0419 887108	SEMEN MOROZOV	{"email": "smorozov_091977@postgrespro.ru", "phone": "+70840789829"}
0005434964189	148C46	7690 994970	ALEKSEY MAKSIMOV	{"email": "maksimov_a_051971@postgrespro.ru", "phone": "+70601878510"}
0005434964190	148C46	4553 446910	DENIS SIDOROV	{"phone": "+70385810891"}
0005434964191	AC300D	3421 666252	KONSTANTIN STEPANOV	{"phone": "+70377412059"}
0005434964192	4E13CD	3942 286417	LIDIYA NAZAROVA	{"phone": "+70783599140"}
0005434964193	1F45CB	0943 554511	SVETLANA ZAKHAROVA	{"phone": "+70548359394"}
0005434964194	45DEA7	0805 210572	TATYANA SIDOROVA	{"email": "sidorova.t_011983@postgrespro.ru", "phone": "+70773224700"}
0005434964195	45DEA7	1338 047478	MARIYA MOROZOVA	{"email": "morozova-mariya061971@postgrespro.ru", "phone": "+70957221584"}
0005434964196	9502D5	8267 718967	ALEKSANDR ORLOV	{"phone": "+70273871585"}
0005434964197	9502D5	1941 199572	VALENTINA NAUMOVA	{"email": "v-naumova-05081974@postgrespro.ru", "phone": "+70778883710"}
0005434964198	F837C8	1712 534565	EVGENIY FOMIN	{"phone": "+70441486852"}
0005434964199	3D8F2B	5127 645605	SVETLANA GAVRILOVA	{"phone": "+70597199296"}
0005434964200	279087	0802 174683	OLGA NOVIKOVA	{"email": "novikovaolga.07111987@postgrespro.ru", "phone": "+70236381645"}
0005434964201	60D859	4369 677275	VIKTORIYA OVCHINNIKOVA	{"phone": "+70537668698"}
0005434964202	A20673	3362 032301	ALEKSANDRA POPOVA	{"phone": "+70669266093"}
0005434964203	1EEFF6	6719 833880	TATYANA CHERNOVA	{"email": "chernova-tatyana1974@postgrespro.ru", "phone": "+70868365876"}
0005434964204	380312	7472 348851	MARINA DAVYDOVA	{"email": "davydova_marina-1965@postgrespro.ru", "phone": "+70435192317"}
0005434964205	C01298	6950 925446	ALEKSANDR MAKAROV	{"phone": "+70257895080"}
0005434964206	84CAAA	1527 225608	NIKOLAY YAKOVLEV	{"email": "nikolay.yakovlev_021979@postgrespro.ru", "phone": "+70065006349"}
0005434964207	84CAAA	3805 015562	VLADIMIR SOROKIN	{"phone": "+70332385341"}
0005434964208	53BEC0	3329 148139	ALEKSANDR SAVELEV	{"phone": "+70575030800"}
0005434964209	1DCEFF	0942 824153	ALEKSANDR DENISOV	{"email": "denisov-aleksandr.1972@postgrespro.ru", "phone": "+70485456349"}
0005434964210	FADEA6	7042 394088	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova_23061961@postgrespro.ru", "phone": "+70186991762"}
0005434964211	059D09	5561 953886	GULFIYA MALYSHEVA	{"phone": "+70821261563"}
0005434964212	059D09	1292 485642	EVGENIY SIDOROV	{"email": "evgeniy-sidorov1975@postgrespro.ru", "phone": "+70445738173"}
0005434964213	A2855B	6800 714060	SERGEY BORISOV	{"phone": "+70648421968"}
0005434964214	A2855B	2270 237536	PAVEL KUZMIN	{"phone": "+70712681400"}
0005434964215	160E2B	2179 937961	ELENA MAKSIMOVA	{"email": "maksimova_elena_26121976@postgrespro.ru", "phone": "+70877370939"}
0005434964216	69664D	8002 772219	ALEKSANDRA NAZAROVA	{"phone": "+70150661708"}
0005434964217	08818D	0960 535393	ALEKSEY ANDREEV	{"phone": "+70335228546"}
0005434964218	960E3C	1780 003702	VALENTINA SAVELEVA	{"email": "valentinasaveleva101972@postgrespro.ru", "phone": "+70083669779"}
0005434964219	960E3C	7343 873590	NIKOLAY VOROBEV	{"phone": "+70251782444"}
0005434964220	93D137	1504 044674	LYUDMILA MOROZOVA	{"phone": "+70860958443"}
0005434964221	93D137	7204 107190	IRINA KUDRYASHOVA	{"email": "kudryashova_irina_1980@postgrespro.ru", "phone": "+70755010799"}
0005434964222	FC1B46	8115 175068	VASILIY NIKITIN	{"phone": "+70757284443"}
0005434964223	D1E455	2181 451052	SVETLANA FADEEVA	{"phone": "+70232008234"}
0005434964224	23E952	3026 482084	ANGELINA MATVEEVA	{"email": "angelina-matveeva021977@postgrespro.ru", "phone": "+70196394305"}
0005434964225	BD973F	9117 719507	VLADIMIR SMIRNOV	{"email": "smirnovv_091966@postgrespro.ru", "phone": "+70518802058"}
0005434964226	BD973F	1591 661290	ZINAIDA NESTEROVA	{"email": "nesterova-z.31031976@postgrespro.ru", "phone": "+70642814153"}
0005434964227	2636F9	8906 094753	ELENA BOGDANOVA	{"phone": "+70998283621"}
0005434964228	2636F9	2448 822767	MIKHAIL ALEKSANDROV	{"email": "maleksandrov19011960@postgrespro.ru", "phone": "+70636249488"}
0005434964229	D609C8	7188 972292	SERGEY SCHERBAKOV	{"email": "sergey-scherbakov05121975@postgrespro.ru", "phone": "+70850573363"}
0005434964230	D609C8	1656 432297	MIKHAIL SAVELEV	{"phone": "+70551118178"}
0005434964231	7459DD	2821 015564	LYUDMILA MATVEEVA	{"email": "matveeva.lyudmila.101971@postgrespro.ru", "phone": "+70125291437"}
0005434964232	F4AD01	4381 761822	SERGEY AFANASEV	{"phone": "+70137940208"}
0005434964233	AEEC3E	0035 112419	NATALYA SMIRNOVA	{"phone": "+70705015548"}
0005434964234	C1D609	0498 646605	ANDREY GAVRILOV	{"email": "a_gavrilov101973@postgrespro.ru", "phone": "+70086782370"}
0005434964235	78920E	1212 092814	DARYA SEMENOVA	{"email": "dsemenova.1974@postgrespro.ru", "phone": "+70728829345"}
0005434964236	1EF873	4612 452241	OLGA VOLKOVA	{"email": "volkova-o.121973@postgrespro.ru", "phone": "+70409166331"}
0005434964237	88DE8B	7444 427011	EVGENIY MAKAROV	{"phone": "+70302648243"}
0005434964238	88DE8B	3675 215839	GALINA NESTEROVA	{"email": "nesterova.g.101974@postgrespro.ru", "phone": "+70068572543"}
0005434964239	904DC2	2469 606363	EVGENIY FROLOV	{"email": "frolov-e_031977@postgrespro.ru", "phone": "+70106138285"}
0005434964240	904DC2	2123 440456	SERGEY IVANOV	{"phone": "+70751860349"}
0005434964241	E6EFF0	7649 410658	ALEKSANDR KISELEV	{"email": "kiseleva.1981@postgrespro.ru", "phone": "+70775366967"}
0005434964242	2D6406	6486 794776	VIKTOR VOLKOV	{"email": "volkovv-1974@postgrespro.ru", "phone": "+70901358678"}
0005434964243	C0E5E6	1260 011756	NADEZHDA SOROKINA	{"phone": "+70242027895"}
0005434964244	C0E5E6	8659 656016	RUFIYA POPOVA	{"email": "popova-rufiya15081983@postgrespro.ru", "phone": "+70031652844"}
0005434964245	BEBD38	4245 917546	ALEKSANDR ANDREEV	{"email": "aandreev06011970@postgrespro.ru", "phone": "+70883686225"}
0005434964246	BEBD38	9380 130397	FEDOR KAZAKOV	{"email": "kazakov-fedor.1972@postgrespro.ru", "phone": "+70577390467"}
0005434964247	232287	2255 345533	LYUDMILA LEBEDEVA	{"phone": "+70183414831"}
0005434964249	232287	9338 822408	SERGEY NAZAROV	{"phone": "+70530380905"}
0005434964250	65C677	8903 312915	ANDREY NOVIKOV	{"email": "andreynovikov_081969@postgrespro.ru", "phone": "+70087575714"}
0005434964251	588258	0765 389172	TAMARA SMIRNOVA	{"email": "smirnova_tamara.1966@postgrespro.ru", "phone": "+70392165224"}
0005434964252	588258	1095 187299	DANILA KAZAKOV	{"phone": "+70291728830"}
0005434964253	00133E	5993 241758	OLGA SOROKINA	{"email": "sorokina.olga.1978@postgrespro.ru", "phone": "+70115503705"}
0005434964254	98EE93	1978 440045	DENIS YAKOVLEV	{"email": "yakovlevd.06051985@postgrespro.ru", "phone": "+70694685995"}
0005434964255	1EAC0A	2597 532351	YULIYA KUZMINA	{"email": "yuliya-kuzmina-081973@postgrespro.ru", "phone": "+70934887268"}
0005434964256	1EAC0A	0191 895935	MARINA SIDOROVA	{"phone": "+70690204402"}
0005434964257	8DDBAF	9772 461907	VERA ZOTOVA	{"phone": "+70125128708"}
0005434964258	A7554D	8133 471197	TATYANA POPOVA	{"email": "tatyana.popova.121969@postgrespro.ru", "phone": "+70100448367"}
0005434964259	B3D7A5	4453 861241	ELVIRA IVANOVA	{"email": "e-ivanova-091976@postgrespro.ru", "phone": "+70666327686"}
0005434964260	A3B2DC	2056 580390	ALEKSEY KOROLEV	{"email": "korolev.a-1961@postgrespro.ru", "phone": "+70768228949"}
0005434964261	A3B2DC	6268 664320	ANNA IVANOVA	{"phone": "+70211983876"}
0005434964262	A3B2DC	9569 327318	GYUZEL MOROZOVA	{"phone": "+70483410301"}
0005434964263	7E6433	6517 555925	ANATOLIY KULIKOV	{"email": "anatoliy.kulikov_25091975@postgrespro.ru", "phone": "+70625006605"}
0005434964264	F47473	9745 083274	SERGEY SOKOLOV	{"phone": "+70745607653"}
0005434964265	794ECA	1881 686174	ANATOLIY MARTYNOV	{"phone": "+70950709755"}
0005434964266	14654B	4135 615609	ANTON MAKAROV	{"phone": "+70673467342"}
0005434964267	14654B	5978 637541	MARINA NIKIFOROVA	{"email": "marina_nikiforova-101973@postgrespro.ru", "phone": "+70660694289"}
0005434964268	569C6A	1640 567104	OLGA TROFIMOVA	{"email": "olga_trofimova-1962@postgrespro.ru", "phone": "+70708190722"}
0005434964269	36F6C3	7187 120446	VALERIY ALEKSANDROV	{"phone": "+70969652318"}
0005434964270	36F6C3	2136 937750	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr_1967@postgrespro.ru", "phone": "+70544005075"}
0005434964271	DD31A2	5529 658549	SVETLANA KUDRYASHOVA	{"email": "svetlana_kudryashova-121962@postgrespro.ru", "phone": "+70760192738"}
0005434964272	8285E8	4055 090331	ALEKSANDRA EFREMOVA	{"phone": "+70878063021"}
0005434964273	C78F16	5816 782960	VALENTINA ROMANOVA	{"phone": "+70593284645"}
0005434964385	A87897	9491 528462	MAKSIM NIKITIN	{"phone": "+70122468099"}
0005434964274	C78F16	2563 574777	NADEZHDA PETROVA	{"email": "petrova_nadezhda-021966@postgrespro.ru", "phone": "+70827752581"}
0005434964275	1DF28D	0974 696941	RAIL TIKHONOV	{"phone": "+70004082711"}
0005434964276	1DF28D	9035 167396	OLEG CHERNOV	{"phone": "+70265300277"}
0005434964277	1DF28D	9638 275334	SERGEY KUZMIN	{"email": "skuzmin.091980@postgrespro.ru", "phone": "+70663593058"}
0005434964278	36B41F	9553 953201	EDUARD SIDOROV	{"phone": "+70958564763"}
0005434964279	36B41F	8083 005696	OLEG TARASOV	{"email": "olegtarasov1977@postgrespro.ru", "phone": "+70070179731"}
0005434964280	28F032	1801 584766	ANDREY ORLOV	{"email": "a-orlov_031979@postgrespro.ru", "phone": "+70906324484"}
0005434964281	D7E271	4401 906542	MIKHAIL YAKOVLEV	{"phone": "+70095327120"}
0005434964282	757638	9750 078701	MARIYA VASILEVA	{"phone": "+70155111806"}
0005434964283	757638	7160 672084	VALENTIN IVANOV	{"phone": "+70586079002"}
0005434964284	A31BA7	8793 732363	SVETLANA BELOVA	{"phone": "+70322470198"}
0005434964285	E39605	6461 675893	ALEKSANDR ROMANOV	{"phone": "+70690738719"}
0005434964286	FCCFA1	9637 878344	OLGA KOROLEVA	{"phone": "+70164260669"}
0005434964287	BF1094	0098 606175	SVETLANA ANDREEVA	{"phone": "+70720310646"}
0005434964288	BF1094	1678 588619	DIANA AKIMOVA	{"email": "diana-akimova.19041971@postgrespro.ru", "phone": "+70947725935"}
0005434964289	A7C54A	2347 037819	RASIM MATVEEV	{"email": "r_matveev.1981@postgrespro.ru", "phone": "+70842975561"}
0005434964290	A7C54A	4684 815688	ALEKSEY KOZLOV	{"phone": "+70671775321"}
0005434964291	A7C54A	5332 129186	ANNA ORLOVA	{"email": "a-orlova_22041980@postgrespro.ru", "phone": "+70098269997"}
0005434964292	E31275	8945 016568	SERGEY SERGEEV	{"email": "sergeev_sergey-21121978@postgrespro.ru", "phone": "+70289269129"}
0005434964293	E31275	0123 457637	EVGENIY FOMIN	{"email": "e_fomin111974@postgrespro.ru", "phone": "+70926338795"}
0005434964294	270DCB	1135 001632	NIKOLAY FOMIN	{"email": "fominnikolay-05091980@postgrespro.ru", "phone": "+70109409441"}
0005434964295	ED99FB	1658 767647	IRINA BORISOVA	{"phone": "+70006641567"}
0005434964296	E5DC37	9977 761567	IRINA SAVELEVA	{"email": "saveleva_i.1970@postgrespro.ru", "phone": "+70572210823"}
0005434964297	C5A52D	4878 339424	NATALYA BORISOVA	{"phone": "+70962789170"}
0005434964298	6C07CC	1977 882355	ZOYA YAKOVLEVA	{"email": "zyakovleva_021978@postgrespro.ru", "phone": "+70533113237"}
0005434964299	6C07CC	8907 965002	KIRILL ALEKSANDROV	{"phone": "+70262723638"}
0005434964300	0D519C	0107 036170	BORIS STEPANOV	{"email": "b-stepanov1981@postgrespro.ru", "phone": "+70926953717"}
0005434964301	E5AF04	9672 868582	GALINA MAKAROVA	{"phone": "+70151645952"}
0005434964302	458F39	5474 390387	ALEKSANDR ORLOV	{"phone": "+70801060708"}
0005434964303	458F39	9234 805572	NIKITA KAZAKOV	{"email": "kazakov-n-101966@postgrespro.ru", "phone": "+70697341822"}
0005434964304	B2EE57	8648 470834	MIKHAIL ANDREEV	{"phone": "+70905060189"}
0005434964305	71FFC1	9860 656889	VIKTOR SMIRNOV	{"phone": "+70757031853"}
0005434964306	71FFC1	9598 706049	DENIS KOROLEV	{"phone": "+70106387268"}
0005434964307	71FFC1	1656 818436	NELLYA SERGEEVA	{"email": "sergeeva-nellya-031961@postgrespro.ru", "phone": "+70959085864"}
0005434964308	A475B0	9233 542668	IGOR SERGEEV	{"phone": "+70896543070"}
0005434964309	A475B0	4512 210939	ELENA MAKSIMOVA	{"phone": "+70551237048"}
0005434964310	276EDD	1410 958413	VLADIMIR IVANOV	{"email": "vladimir_ivanov_041974@postgrespro.ru", "phone": "+70673993740"}
0005434964311	DC0E9A	9368 199571	IRINA VOROBEVA	{"phone": "+70071166161"}
0005434964312	DC0E9A	8462 066292	EVGENIY ISAEV	{"email": "isaeve-11061975@postgrespro.ru", "phone": "+70665089340"}
0005434964313	56A900	0163 334394	SERGEY IVANOV	{"phone": "+70164958918"}
0005434964314	A399BB	8867 779957	MARINA ALEKSEEVA	{"email": "alekseeva_marina-051953@postgrespro.ru", "phone": "+70854865869"}
0005434964315	943529	0636 039892	ALENA LAZAREVA	{"phone": "+70057016592"}
0005434964316	943529	7968 219995	VALENTINA FILIPPOVA	{"phone": "+70610117626"}
0005434964317	7D0D04	0716 604047	VYACHESLAV ISAEV	{"email": "vyacheslav_isaev_1970@postgrespro.ru", "phone": "+70098142545"}
0005434964318	7D0D04	6511 666128	ANATOLIY VASILEV	{"email": "anatoliyvasilev.28101970@postgrespro.ru", "phone": "+70444146882"}
0005434964319	AC7EED	8838 035607	GALINA ERMAKOVA	{"phone": "+70795317711"}
0005434964320	A2FD79	0721 843275	ULYANA NIKITINA	{"phone": "+70007279281"}
0005434964321	5CB641	7409 667246	SERGEY SIDOROV	{"email": "sidorov-s051976@postgrespro.ru", "phone": "+70727470098"}
0005434964322	E27CA5	6837 517383	VIKTOR FROLOV	{"email": "v_frolov.13121977@postgrespro.ru", "phone": "+70848819642"}
0005434964323	E27CA5	6593 346449	TATYANA PETROVA	{"phone": "+70607058617"}
0005434964324	3E9BDE	6369 026776	NATALYA KUZNECOVA	{"email": "n-kuznecova1965@postgrespro.ru", "phone": "+70527082890"}
0005434964325	5DBC6A	9942 584582	ALEKSEY POPOV	{"phone": "+70497447481"}
0005434964326	31FD0F	6670 852070	LYUDMILA BELOVA	{"email": "belova-lyudmila_071980@postgrespro.ru", "phone": "+70809858143"}
0005434964327	55C97C	8297 629075	NATALYA DMITRIEVA	{"phone": "+70658025876"}
0005434964328	C21961	8948 420468	VALENTINA BORISOVA	{"phone": "+70996366662"}
0005434964329	2213EB	4468 464730	YANA OVCHINNIKOVA	{"phone": "+70977073339"}
0005434964330	332ABC	3978 316393	ALEKSANDR SEMENOV	{"email": "aleksandr_semenov1970@postgrespro.ru", "phone": "+70797629805"}
0005434964331	2A594F	6476 294787	YAROSLAV NOVIKOV	{"email": "novikov_yaroslav04081963@postgrespro.ru", "phone": "+70222565692"}
0005434964332	AC9DF7	4713 869784	SERGEY MOROZOV	{"phone": "+70476492124"}
0005434964333	AC9DF7	1332 277392	VADIM SCHERBAKOV	{"email": "v-scherbakov-021961@postgrespro.ru", "phone": "+70721303858"}
0005434964334	D468C9	0404 071572	ALEKSANDR FOMIN	{"email": "fomin-aleksandr27021966@postgrespro.ru", "phone": "+70366793446"}
0005434964335	001FF3	9501 466451	ELENA ERMAKOVA	{"email": "eermakova-1972@postgrespro.ru", "phone": "+70823006982"}
0005434964336	001FF3	7957 682157	MIKHAIL GAVRILOV	{"phone": "+70661443356"}
0005434964337	7AD45C	8583 814257	ZLATA POTAPOVA	{"email": "z.potapova1974@postgrespro.ru", "phone": "+70347992465"}
0005434964338	262167	0629 295450	ANTON PETROV	{"email": "petrova-041966@postgrespro.ru", "phone": "+70785764718"}
0005434964339	1FC289	5820 776295	OKSANA BORISOVA	{"email": "oksanaborisova.16011975@postgrespro.ru", "phone": "+70149515409"}
0005434964340	1FC289	7398 870124	DMITRIY YAKOVLEV	{"email": "yakovlev.dmitriy01041973@postgrespro.ru", "phone": "+70916625362"}
0005434964341	4F17E8	9070 359384	LILIYA KUZNECOVA	{"email": "l-kuznecova-16051977@postgrespro.ru", "phone": "+70772645368"}
0005434964342	4F17E8	6308 661236	OLESYA VOLKOVA	{"email": "volkovao_031973@postgrespro.ru", "phone": "+70159489568"}
0005434964343	C11619	3488 890343	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov08081965@postgrespro.ru", "phone": "+70119853551"}
0005434964344	8F16CD	1186 198303	MARIYA FILIPPOVA	{"email": "filippovamariya-111977@postgrespro.ru", "phone": "+70432099796"}
0005434964345	F7C229	2410 903318	VALERIY ZHURAVLEV	{"email": "zhuravlev.valeriy.101972@postgrespro.ru", "phone": "+70752688470"}
0005434964346	F7C229	8450 422776	DARYA EGOROVA	{"email": "darya-egorova_1978@postgrespro.ru", "phone": "+70663651201"}
0005434964347	EE2C98	7181 788685	OLGA SIDOROVA	{"phone": "+70127954699"}
0005434964348	68C791	5467 526070	VYACHESLAV MAKSIMOV	{"phone": "+70697651572"}
0005434964349	965DCA	8081 951845	LEONTIY KISELEV	{"email": "kiselev-leontiy-27071975@postgrespro.ru", "phone": "+70714031400"}
0005434964350	959330	6590 956256	NATALIYA TIKHONOVA	{"email": "tikhonova-n_1986@postgrespro.ru", "phone": "+70964200254"}
0005434964351	959330	4342 402832	VALENTINA DAVYDOVA	{"phone": "+70825741930"}
0005434964352	831581	6066 306705	ALEKSANDR STEPANOV	{"phone": "+70883644312"}
0005434964353	880A4A	4181 889220	GENNADIY SOROKIN	{"email": "gennadiy.sorokin_1965@postgrespro.ru", "phone": "+70474004213"}
0005434964354	59083D	4353 153854	OLGA OSIPOVA	{"email": "osipova-o26121969@postgrespro.ru", "phone": "+70515546548"}
0005434964355	9B1A8C	1665 895778	VASILIY GUSEV	{"email": "vgusev_091978@postgrespro.ru", "phone": "+70946935783"}
0005434964356	9B1A8C	5156 961196	VALENTINA KUZNECOVA	{"email": "kuznecovavalentina_021971@postgrespro.ru", "phone": "+70522598613"}
0005434964357	9B1A8C	4930 876010	OLGA VASILEVA	{"email": "vasileva-olga.1977@postgrespro.ru", "phone": "+70323025810"}
0005434964358	31344C	6976 125881	VIKTOR KUZNECOV	{"email": "v_kuznecov-031966@postgrespro.ru", "phone": "+70954767475"}
0005434964359	BC3DAF	4586 016215	SERGEY KOROLEV	{"phone": "+70521798706"}
0005434964360	BC3DAF	8431 402082	ANATOLIY MAKAROV	{"phone": "+70864125730"}
0005434964361	6F5471	4255 766297	MARIYA ANDREEVA	{"email": "mandreeva_111976@postgrespro.ru", "phone": "+70102486253"}
0005434964362	BDBB65	1417 236572	VLADIMIR ANDREEV	{"phone": "+70363337621"}
0005434964363	9E9466	3371 433351	YURIY MAKAROV	{"email": "y-makarov-31071971@postgrespro.ru", "phone": "+70958957989"}
0005434964364	9E9466	5532 600064	ALEKSANDR FOMIN	{"email": "fomin.aleksandr07071965@postgrespro.ru", "phone": "+70645968785"}
0005434964365	4FF716	3651 482142	NINA DMITRIEVA	{"email": "ndmitrieva-1981@postgrespro.ru", "phone": "+70144299545"}
0005434964366	A105C7	6660 826721	ANDREY SCHERBAKOV	{"phone": "+70481149638"}
0005434964367	181CF4	8575 281970	SERGEY TARASOV	{"email": "tarasov-sergey-31011965@postgrespro.ru", "phone": "+70811259999"}
0005434964368	181CF4	6701 951578	NADEZHDA SCHERBAKOVA	{"phone": "+70068093795"}
0005434964369	73AF0B	7655 717509	ANASTASIYA ALEKSANDROVA	{"phone": "+70880373502"}
0005434964370	C5E8A2	4427 958219	VASILIY GORBUNOV	{"email": "vasiliygorbunov_23101969@postgrespro.ru", "phone": "+70450280726"}
0005434964371	C5E8A2	5218 064383	ROZA SMIRNOVA	{"email": "smirnova-r.22011972@postgrespro.ru", "phone": "+70340923788"}
0005434964372	C5E8A2	4010 868319	PAVEL OSIPOV	{"email": "p.osipov.1965@postgrespro.ru", "phone": "+70826374109"}
0005434964373	1CCEEC	3644 815472	YURIY ABRAMOV	{"email": "abramov.yuriy031977@postgrespro.ru", "phone": "+70298114814"}
0005434964374	6E4C7E	4736 931199	VALENTINA ZAKHAROVA	{"email": "zakharova.v-101970@postgrespro.ru", "phone": "+70535666131"}
0005434964375	FD2AB7	2173 996601	TATYANA TIKHONOVA	{"phone": "+70632859388"}
0005434964376	78880D	1830 035727	VLADIMIR DENISOV	{"email": "denisov-vladimir1967@postgrespro.ru", "phone": "+70198652824"}
0005434964377	78880D	0460 696188	ALFIYA RYABOVA	{"email": "alfiya.ryabova-1969@postgrespro.ru", "phone": "+70294085649"}
0005434964378	ED6CEF	6272 193858	FANIS SEMENOV	{"phone": "+70012090345"}
0005434964379	FFD9C9	8066 711654	VALENTINA YAKOVLEVA	{"email": "valentinayakovleva_1980@postgrespro.ru", "phone": "+70307804332"}
0005434964380	FFD9C9	0042 377068	GALINA IVANOVA	{"phone": "+70163729204"}
0005434964381	D53F3F	9965 059522	YULIYA ZHUKOVA	{"email": "yuliyazhukova111977@postgrespro.ru", "phone": "+70546266433"}
0005434964382	108442	5099 337791	VIKTORIYA FOMINA	{"phone": "+70962018509"}
0005434964383	91892B	7327 815646	ANNA KOROLEVA	{"email": "koroleva_anna-041965@postgrespro.ru", "phone": "+70548848638"}
0005434964384	A87897	5077 308544	VALENTINA AFANASEVA	{"phone": "+70955079478"}
0005434964386	765C0E	7021 556270	DAMIR PETROV	{"email": "damir_petrov071978@postgrespro.ru", "phone": "+70064021197"}
0005434964387	2C8AE0	0205 775168	NINA SMIRNOVA	{"email": "smirnova-n_12061981@postgrespro.ru", "phone": "+70853036425"}
0005434964388	448C8B	3356 094262	VYACHESLAV KUZNECOV	{"email": "kuznecov_vyacheslav-10051969@postgrespro.ru", "phone": "+70393751334"}
0005434964389	FDE63B	2468 015770	ZHANNA OSIPOVA	{"email": "z_osipova.1974@postgrespro.ru", "phone": "+70350757045"}
0005434964390	FDE63B	5628 204879	RUSLAN MELNIKOV	{"phone": "+70274483208"}
0005434964391	11D024	1351 767546	NATALYA YAKOVLEVA	{"phone": "+70711259474"}
0005434964392	F3FF1E	0616 252608	OLGA KUDRYASHOVA	{"email": "kudryashova_o.101977@postgrespro.ru", "phone": "+70960000345"}
0005434964393	DAE5A3	0765 591964	NIKOLAY TIMOFEEV	{"phone": "+70466305089"}
0005434964394	DAE5A3	1982 012292	ALEKSEY ALEKSANDROV	{"email": "aleksey.aleksandrov1964@postgrespro.ru", "phone": "+70753388886"}
0005434964395	DAE5A3	4263 198161	IVAN NIKITIN	{"email": "i-nikitin-20111961@postgrespro.ru", "phone": "+70205368924"}
0005434964396	DAE5A3	2010 845459	SERGEY MAKAROV	{"phone": "+70646277191"}
0005434964397	798106	6241 506680	ANDREY ROMANOV	{"email": "romanov_andrey071976@postgrespro.ru", "phone": "+70843531633"}
0005434964398	798106	1740 834643	ANATOLIY NOVIKOV	{"email": "novikov-anatoliy1969@postgrespro.ru", "phone": "+70630506412"}
0005434964399	4F31AB	7728 259773	EKATERINA RODIONOVA	{"phone": "+70154053884"}
0005434964400	520204	1664 357653	LIDIYA ZHUKOVA	{"email": "zhukova_lidiya-29041967@postgrespro.ru", "phone": "+70541409002"}
0005434964401	6591BD	4578 979660	VLADIMIR KRASNOV	{"email": "vkrasnov.05041974@postgrespro.ru", "phone": "+70077301457"}
0005434964402	677C0A	3399 652327	RAISA SIDOROVA	{"phone": "+70464450660"}
0005434964403	677C0A	8295 990749	DENIS MAKSIMOV	{"phone": "+70175954492"}
0005434964404	DBB8A1	7012 386617	MARIYA YUDINA	{"phone": "+70628771176"}
0005434964405	4ADC2F	0713 613045	VLADIMIR FROLOV	{"phone": "+70272278523"}
0005434964406	4ADC2F	8656 007048	ALEKSANDR ABRAMOV	{"phone": "+70170858128"}
0005434964407	C0B962	5556 713637	DMITRIY PETROV	{"phone": "+70291462569"}
0005434964408	C0B962	8201 771607	LYUDMILA TIKHONOVA	{"phone": "+70754229400"}
0005434964409	CCD8CF	1168 636791	OLGA PETROVA	{"phone": "+70498963541"}
0005434964410	CCD8CF	1433 688476	VERA IVANOVA	{"phone": "+70135945245"}
0005434964411	CCD8CF	6135 719298	ALEKSANDR PETROV	{"email": "aleksandr_petrov-1981@postgrespro.ru", "phone": "+70672759240"}
0005434964412	B5572A	4184 433338	DAMIR OSIPOV	{"email": "osipov_damir1971@postgrespro.ru", "phone": "+70423506610"}
0005434964413	B5572A	1247 685844	VIKTOR VOROBEV	{"phone": "+70312435165"}
0005434964414	D97B01	4659 228534	NIKOLAY TIMOFEEV	{"phone": "+70870628275"}
0005434964415	D97B01	2229 682057	ELENA VLASOVA	{"email": "elena.vlasova-1972@postgrespro.ru", "phone": "+70528273493"}
0005434964416	1370BE	4446 088818	ALEKSEY EGOROV	{"phone": "+70055214382"}
0005434964417	8CA410	3328 140451	ALEKSANDR BELOV	{"phone": "+70850406108"}
0005434964418	8CA527	8958 861230	VIKTORIYA KUDRYASHOVA	{"phone": "+70802486217"}
0005434964419	637439	3673 153043	ALEKSEY VASILEV	{"email": "aleksey_vasilev021975@postgrespro.ru", "phone": "+70707793390"}
0005434964420	637439	7534 509599	NIKITA TARASOV	{"phone": "+70253700739"}
0005434964421	A95B25	3368 271460	VLADIMIR MATVEEV	{"email": "v_matveev-05041971@postgrespro.ru", "phone": "+70357549381"}
0005434964422	824A08	0088 104715	KIRILL FROLOV	{"email": "frolovkirill-1977@postgrespro.ru", "phone": "+70353915033"}
0005434964423	56DECB	0252 279512	ALEKSEY MOISEEV	{"phone": "+70019132666"}
0005434964424	56DECB	3892 452819	ALEKSANDR IVANOV	{"email": "ivanovaleksandr18121971@postgrespro.ru", "phone": "+70493943562"}
0005434964425	56DECB	8235 223914	LEV MOISEEV	{"email": "l.moiseev041971@postgrespro.ru", "phone": "+70684301896"}
0005434964426	880652	2622 925512	ELENA NIKOLAEVA	{"email": "nikolaeva_e071970@postgrespro.ru", "phone": "+70392802565"}
0005434964427	2CADE3	7899 291204	RAIL SERGEEV	{"phone": "+70138462497"}
0005434964428	E5EBFA	3763 029649	NIKOLAY CHERNOV	{"phone": "+70226661225"}
0005434964429	E5EBFA	3331 497992	ALEKSANDR KAZAKOV	{"phone": "+70833100893"}
0005434964430	3E21BC	6200 867374	NATALYA ABRAMOVA	{"email": "n.abramova_1972@postgrespro.ru", "phone": "+70155685593"}
0005434964431	3E21BC	4295 859738	RAIS VLASOV	{"email": "rais.vlasov.30081975@postgrespro.ru", "phone": "+70866740852"}
0005434964432	D9F465	6805 339074	ANNA POTAPOVA	{"phone": "+70716901633"}
0005434964433	DE5107	3200 978715	NADEZHDA LEBEDEVA	{"email": "lebedeva_n-25091965@postgrespro.ru", "phone": "+70170787536"}
0005434964434	9EE174	1290 984152	LYUBOV KOZLOVA	{"email": "l.kozlova-03051968@postgrespro.ru", "phone": "+70595905978"}
0005434964435	ABFE3E	7195 898561	ANASTASIYA MIKHAYLOVA	{"phone": "+70575844295"}
0005434964436	642F27	9181 521753	MARIYA SOLOVEVA	{"phone": "+70119954598"}
0005434964437	E6305A	8030 891928	SERGEY RODIONOV	{"phone": "+70070838232"}
0005434964438	C3A373	6889 826750	SERGEY EGOROV	{"phone": "+70265688482"}
0005434964439	C428CC	8797 320067	PAVEL KAZAKOV	{"phone": "+70962066736"}
0005434964440	0427A6	7436 497819	OLGA PETROVA	{"email": "petrovaolga-061982@postgrespro.ru", "phone": "+70228524809"}
0005434964441	0427A6	7434 120942	VLADIMIR MAKAROV	{"phone": "+70809752413"}
0005434964442	B0F548	9525 358627	SERGEY VOLKOV	{"phone": "+70507325416"}
0005434964443	F46BAA	8092 612509	GALINA ABRAMOVA	{"phone": "+70170679735"}
0005434964444	7875FB	8363 448074	VIKTOR MAKAROV	{"phone": "+70703086632"}
0005434964445	7875FB	7536 490637	ANATOLIY MARTYNOV	{"email": "martynov_a.01101966@postgrespro.ru", "phone": "+70538972571"}
0005434964446	7E5D52	5442 812665	SERGEY NAZAROV	{"phone": "+70974880515"}
0005434964447	C357A5	3649 173499	ALEKSEY IVANOV	{"email": "a.ivanov_031969@postgrespro.ru", "phone": "+70155491550"}
0005434964448	942848	0142 109648	DANILA GERASIMOV	{"email": "gerasimov.danila.091984@postgrespro.ru", "phone": "+70657236330"}
0005434964449	00B094	0858 640059	TATYANA BELOVA	{"email": "t-belova-1968@postgrespro.ru", "phone": "+70271430303"}
0005434964450	A0E0A0	0807 827703	GENNADIY KAZAKOV	{"phone": "+70818774140"}
0005434964451	02655A	3000 167434	ALEKSEY KRASNOV	{"phone": "+70630015501"}
0005434964452	746510	1774 239443	VLADIMIR YAKOVLEV	{"email": "yakovlev_v_051957@postgrespro.ru", "phone": "+70810033471"}
0005434964453	22C3EB	9454 652857	EKATERINA SERGEEVA	{"phone": "+70821291413"}
0005434964454	2A72CE	7043 024350	EVGENIY NAZAROV	{"email": "nazarov.evgeniy.02041974@postgrespro.ru", "phone": "+70109979511"}
0005434964455	A64A73	4451 098251	VLADIMIR SERGEEV	{"email": "vladimir_sergeev_06041973@postgrespro.ru", "phone": "+70602898107"}
0005434964456	A64A73	8594 014757	ANDREY MAKAROV	{"phone": "+70316753581"}
0005434964457	BF42E5	2091 562204	VALERIY BELOV	{"phone": "+70625430632"}
0005434964458	F0AFA0	1869 306644	GENNADIY ABRAMOV	{"phone": "+70393206681"}
0005434964459	BA15DE	2862 400250	DMITRIY NIKITIN	{"email": "dnikitin_1976@postgrespro.ru", "phone": "+70549326904"}
0005434964460	53C7AD	2913 059689	SERGEY PETROV	{"phone": "+70731466581"}
0005434964461	53C7AD	6522 651346	GALINA POTAPOVA	{"email": "galina_potapova.021972@postgrespro.ru", "phone": "+70712521542"}
0005434964462	07F6F7	6736 518968	VIKTORIYA KULIKOVA	{"phone": "+70999254052"}
0005434964463	FBFB24	7499 384801	SERGEY KULIKOV	{"email": "s_kulikov-03101966@postgrespro.ru", "phone": "+70284546875"}
0005434964464	A6C496	6727 504460	ILDAR MELNIKOV	{"phone": "+70102837187"}
0005434964465	014D3B	6001 372501	ANATOLIY NIKOLAEV	{"phone": "+70053611064"}
0005434964466	86853A	4974 892564	ALENA IVANOVA	{"phone": "+70134988364"}
0005434964467	86853A	5752 933468	ALEKSEY GORBUNOV	{"email": "gorbunova.101968@postgrespro.ru", "phone": "+70268004836"}
0005434964468	139EBD	1996 982851	OLGA EFIMOVA	{"email": "efimova_o-1964@postgrespro.ru", "phone": "+70948814953"}
0005434964469	139EBD	9069 549383	LYUDMILA IVANOVA	{"phone": "+70241260658"}
0005434964470	139EBD	0855 411054	VALERIY KONOVALOV	{"email": "konovalovv_051972@postgrespro.ru", "phone": "+70336755307"}
0005434964471	59EDC4	1595 663555	VALENTINA ILINA	{"email": "valentina-ilina_13101972@postgrespro.ru", "phone": "+70210000543"}
0005434964472	59EDC4	5304 834157	TAMARA PAVLOVA	{"email": "pavlova-tamara-30061979@postgrespro.ru", "phone": "+70746189995"}
0005434964473	ECCC06	7932 780691	NATALYA KOVALEVA	{"phone": "+70229371693"}
0005434964474	ECCC06	3989 443482	NATALIYA POTAPOVA	{"email": "potapova.nataliya.1971@postgrespro.ru", "phone": "+70586483965"}
0005434964475	B23F46	0338 608757	SERGEY ZHURAVLEV	{"email": "sergey.zhuravlev111974@postgrespro.ru", "phone": "+70371635979"}
0005434964476	85099E	6075 064608	YURIY MIKHAYLOV	{"phone": "+70098620739"}
0005434964477	F94D0B	4621 122035	LYUBOV FADEEVA	{"phone": "+70954681207"}
0005434964478	F94D0B	8901 280281	ALEKSANDR KUZNECOV	{"phone": "+70625286819"}
0005434964479	B5B495	4240 993440	ANDREY SERGEEV	{"email": "sergeeva.16101982@postgrespro.ru", "phone": "+70386866365"}
0005434964480	B5B495	7866 628969	EKATERINA FROLOVA	{"phone": "+70965604930"}
0005434964481	3C84CB	6284 400436	DMITRIY ZAYCEV	{"email": "dzaycev_09111968@postgrespro.ru", "phone": "+70605672987"}
0005434964482	3C84CB	3759 883675	LYUDMILA VOLKOVA	{"email": "lyudmila_volkova_091978@postgrespro.ru", "phone": "+70425730068"}
0005434964483	0FB9A4	0962 963413	DARYA ROMANOVA	{"email": "romanova.d011978@postgrespro.ru", "phone": "+70808873099"}
0005434964484	13E726	0737 244080	EVGENIY IVANOV	{"email": "evgeniyivanov_041979@postgrespro.ru", "phone": "+70395956508"}
0005434964485	9BA060	0781 383884	ANDREY SAVELEV	{"email": "andreysavelev_20091966@postgrespro.ru", "phone": "+70576714358"}
0005434964486	9BA060	9203 781956	ALENA NIKOLAEVA	{"phone": "+70178600324"}
0005434964487	98A40D	5347 676008	RAISA MOROZOVA	{"email": "r.morozova1978@postgrespro.ru", "phone": "+70489345873"}
0005434964488	98A40D	9952 216958	OLGA ZAYCEVA	{"phone": "+70845445672"}
0005434964489	D18A85	5262 137193	VLADIMIR MATVEEV	{"email": "v_matveev.06011972@postgrespro.ru", "phone": "+70018527225"}
0005434964490	7E0D2F	1069 792521	ALEKSEY PETROV	{"email": "a-petrov.1993@postgrespro.ru", "phone": "+70097198675"}
0005434964491	590D4B	2587 427742	ELIZAVETA FILIPPOVA	{"phone": "+70121539776"}
0005434964492	7B740D	2174 021148	ARTEMIY MATVEEV	{"phone": "+70471715467"}
0005434964493	C927E9	3854 621433	PETR VOLKOV	{"phone": "+70254252477"}
0005434964494	C927E9	6748 779051	ILDAR GAVRILOV	{"email": "ildar.gavrilov03041974@postgrespro.ru", "phone": "+70873041655"}
0005434964495	81F536	5820 055194	VALENTINA KISELEVA	{"phone": "+70143617441"}
0005434964496	81F536	0566 213731	NIKOLAY KUZNECOV	{"phone": "+70492647449"}
0005434964497	760005	4094 945873	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr_1978@postgrespro.ru", "phone": "+70268448871"}
0005434964498	5F9BD1	9678 356165	BORIS BORISOV	{"email": "b-borisov.1978@postgrespro.ru", "phone": "+70413930458"}
0005434964499	5F9BD1	4766 975062	ZLATA BELOVA	{"phone": "+70084310459"}
0005434964500	B0E2EA	7368 555234	NATALYA FEDOROVA	{"phone": "+70907162227"}
0005434964501	CCA899	1905 650050	MARINA DENISOVA	{"email": "mdenisova041985@postgrespro.ru", "phone": "+70383957912"}
0005434964502	814688	5463 716951	SERGEY ANDREEV	{"phone": "+70071533231"}
0005434964503	814688	2207 329278	KIRILL PETROV	{"email": "petrovkirill-061975@postgrespro.ru", "phone": "+70785593276"}
0005434964504	645853	5829 151614	YURIY ANDREEV	{"email": "yandreev_1971@postgrespro.ru", "phone": "+70414228005"}
0005434964505	2A2B7D	0930 462038	DARYA BELOVA	{"phone": "+70240426394"}
0005434964506	AD68A2	9745 822668	DMITRIY VOROBEV	{"phone": "+70861224949"}
0005434964507	51760A	8168 051363	VERA GUSEVA	{"phone": "+70097317754"}
0005434964508	A4DF54	1110 073223	VLADIMIR STEPANOV	{"email": "vladimirstepanov_011973@postgrespro.ru", "phone": "+70708443209"}
0005434964509	1E8AA1	4027 286754	VITALIY ZHUKOV	{"email": "vitaliy-zhukov121981@postgrespro.ru", "phone": "+70892435024"}
0005434964510	D6A162	0587 596536	EVGENIY KISELEV	{"email": "evgeniy.kiselev.1970@postgrespro.ru", "phone": "+70482526289"}
0005434964511	7E3EEB	5726 139960	VLADIMIR ILIN	{"email": "ilinv1973@postgrespro.ru", "phone": "+70736674664"}
0005434964512	7E3EEB	5160 550428	MARIYA ALEKSANDROVA	{"email": "mariyaaleksandrova_121974@postgrespro.ru", "phone": "+70490828199"}
0005434964513	AAC29D	6945 951726	LIDIYA ERMAKOVA	{"phone": "+70370446328"}
0005434964514	AAC29D	8134 844764	ALEKSANDR RODIONOV	{"phone": "+70567413158"}
0005434964515	AAC29D	3790 566222	MARIYA MAKAROVA	{"phone": "+70104348602"}
0005434964516	AAC29D	6015 542911	VALERIY NOVIKOV	{"phone": "+70847593180"}
0005434964517	9546F5	9136 907685	EVGENIY ISAEV	{"phone": "+70091068558"}
0005434964518	2DA58A	8842 590168	RASIM NOVIKOV	{"phone": "+70345799629"}
0005434964519	2DA58A	5347 984098	ALEFTINA SMIRNOVA	{"phone": "+70797347926"}
0005434964520	2DA58A	3223 714202	ROMAN KARPOV	{"email": "roman.karpov1961@postgrespro.ru", "phone": "+70721326712"}
0005434964521	51E47B	3222 597026	PAVEL MAKSIMOV	{"phone": "+70845346395"}
0005434964522	B48E35	3870 537622	NATALYA MOISEEVA	{"email": "moiseevan-1957@postgrespro.ru", "phone": "+70466066573"}
0005434964523	7FAFF5	7200 438826	NIKOLAY KUZMIN	{"phone": "+70735303206"}
0005434964524	7FAFF5	1824 222066	NIKOLAY DMITRIEV	{"email": "nikolay.dmitriev23041970@postgrespro.ru", "phone": "+70019882566"}
0005434964525	328D26	1643 291693	SVETLANA YAKOVLEVA	{"phone": "+70603357467"}
0005434964526	328D26	3710 683549	VIKTOR TIMOFEEV	{"email": "timofeevv031973@postgrespro.ru", "phone": "+70798603513"}
0005434964527	5B08E2	0416 729032	ALEKSANDR MAKAROV	{"phone": "+70658283462"}
0005434964528	5B08E2	6381 458816	ALEKSEY FROLOV	{"phone": "+70944188300"}
0005434964529	E4A007	6412 852650	ALBERT KUZNECOV	{"email": "kuznecovalbert-011982@postgrespro.ru", "phone": "+70328083204"}
0005434964530	E4A007	8171 048630	ANATOLIY CHERNOV	{"email": "chernov-anatoliy.1984@postgrespro.ru", "phone": "+70179670255"}
0005434964531	0A8306	5979 295254	SERGEY EGOROV	{"email": "s.egorov_17091972@postgrespro.ru", "phone": "+70651553009"}
0005434964532	D3959C	5126 288495	ROMAN BELOV	{"phone": "+70590049388"}
0005434964533	D3959C	2659 069684	ALEKSANDR DENISOV	{"email": "aleksandr.denisov-111959@postgrespro.ru", "phone": "+70286744730"}
0005434964534	68A8D1	2114 735804	MIKHAIL KUZNECOV	{"phone": "+70101392374"}
0005434964535	68A8D1	0201 310438	EVGENIYA NOVIKOVA	{"email": "e_novikova_1985@postgrespro.ru", "phone": "+70786962759"}
0005434964536	332EF6	8451 235330	TAMARA CHERNOVA	{"phone": "+70357669785"}
0005434964537	D49AD9	4097 999140	TATYANA OVCHINNIKOVA	{"phone": "+70666548851"}
0005434964538	27698B	2326 340741	RAISA TARASOVA	{"email": "tarasova.r.111963@postgrespro.ru", "phone": "+70685308028"}
0005434964539	27698B	5436 674196	NADEZHDA MELNIKOVA	{"phone": "+70597851523"}
0005434964540	27698B	1669 320978	GULNARA POTAPOVA	{"phone": "+70235810261"}
0005434964541	27698B	0107 979132	ELENA FOMINA	{"email": "fomina.elena_11081963@postgrespro.ru", "phone": "+70502861112"}
0005434964542	E85B9D	5883 962817	GALINA KOROLEVA	{"email": "koroleva-g_1981@postgrespro.ru", "phone": "+70387601085"}
0005434964543	E85B9D	0691 585041	ANNA NIKIFOROVA	{"phone": "+70297557853"}
0005434964544	E2AEB2	6770 141015	SERGEY TIMOFEEV	{"email": "timofeev_sergey.011980@postgrespro.ru", "phone": "+70781490582"}
0005434964545	F524D5	2770 066241	PAVEL CHERNOV	{"phone": "+70808400790"}
0005434964546	F524D5	4189 430324	YULIYA KUZNECOVA	{"phone": "+70550486578"}
0005434964547	F524D5	0843 031117	KLAVDIYA KOROLEVA	{"phone": "+70535656120"}
0005434964548	9A288C	3933 653341	VASILIY NOVIKOV	{"email": "v-novikov-031968@postgrespro.ru", "phone": "+70370747586"}
0005434964549	9A288C	0910 259955	OLGA VASILEVA	{"email": "ovasileva1959@postgrespro.ru", "phone": "+70253208845"}
0005434964550	D62E44	6004 041675	OLGA NAZAROVA	{"email": "nazarova_olga.01091975@postgrespro.ru", "phone": "+70642181872"}
0005434964551	D62E44	8858 116345	MARIYA MELNIKOVA	{"email": "mariya.melnikova_26041967@postgrespro.ru", "phone": "+70028335406"}
0005434964552	EE748E	3548 472309	NATALYA KUDRYASHOVA	{"phone": "+70874627531"}
0005434964553	81BB53	1539 162016	RIMMA FILIPPOVA	{"phone": "+70012479979"}
0005434964554	A17891	8660 646122	DMITRIY KRASNOV	{"phone": "+70759398453"}
0005434964555	A17891	6491 147172	SVETLANA NESTEROVA	{"phone": "+70640762248"}
0005434964556	EC105C	6348 442431	LIDIYA OSIPOVA	{"phone": "+70614753916"}
0005434964557	EC105C	5054 028698	VADIM MAKAROV	{"phone": "+70739919670"}
0005434964558	472907	8409 713570	NADEZHDA ROMANOVA	{"phone": "+70410819485"}
0005434964559	304400	1364 936040	NATALYA ROMANOVA	{"email": "romanova-natalya-081966@postgrespro.ru", "phone": "+70744077250"}
0005434964560	2227B4	5276 450610	VYACHESLAV CHERNOV	{"phone": "+70115544725"}
0005434964561	552DF7	0222 543077	IRINA MEDVEDEVA	{"email": "i.medvedeva29081971@postgrespro.ru", "phone": "+70133490098"}
0005434964562	1BA625	7855 329569	NADEZHDA STEPANOVA	{"phone": "+70779082954"}
0005434964563	C67CDF	4000 082105	BORIS TARASOV	{"phone": "+70716728402"}
0005434964564	A006EF	5335 888460	ALEKSEY SEMENOV	{"email": "semenov.aleksey.091963@postgrespro.ru", "phone": "+70166611079"}
0005434964565	6EA4C0	5602 147879	TATYANA SOLOVEVA	{"email": "tatyanasoloveva-12111970@postgrespro.ru", "phone": "+70492129257"}
0005434964566	2B78D6	3907 461146	TATYANA FROLOVA	{"phone": "+70921503608"}
0005434964567	91E65F	4347 419502	ELENA FILIPPOVA	{"email": "filippovae-101966@postgrespro.ru", "phone": "+70179545078"}
0005434964568	91E65F	2410 028731	ANASTASIYA SCHERBAKOVA	{"phone": "+70295772350"}
0005434964569	FF4482	4313 351622	IVAN ISAEV	{"phone": "+70081837329"}
0005434964570	FF4482	9299 852893	YURIY IVANOV	{"phone": "+70920761267"}
0005434964571	45D739	4529 028863	VADIM YAKOVLEV	{"email": "vadim.yakovlev-1974@postgrespro.ru", "phone": "+70523657771"}
0005434964572	06C08B	6818 910802	NINA KOROLEVA	{"email": "n_koroleva_101976@postgrespro.ru", "phone": "+70964928684"}
0005434964573	A97DD6	5654 083281	TATYANA ROMANOVA	{"phone": "+70087027691"}
0005434964574	0D99BA	5671 209110	ALBINA SOKOLOVA	{"phone": "+70714287935"}
0005434964575	851E20	8260 802553	IGOR VOROBEV	{"phone": "+70340062950"}
0005434964576	851E20	0306 320471	ANASTASIYA AFANASEVA	{"email": "afanasevaanastasiya-20111972@postgrespro.ru", "phone": "+70755095784"}
0005434964577	851E20	2928 297478	ELENA ZOTOVA	{"email": "zotova-elena_12071983@postgrespro.ru", "phone": "+70534090445"}
0005434964578	BADE50	6486 188372	DMITRIY SHEVCHENKO	{"phone": "+70153701988"}
0005434964579	47CBDE	1902 030449	KLIM GORBUNOV	{"email": "kgorbunov-25091964@postgrespro.ru", "phone": "+70603659114"}
0005434964580	568360	1950 783630	ANTON CHERNOV	{"email": "a.chernov-22071963@postgrespro.ru", "phone": "+70957148629"}
0005434964581	4E8021	5920 720838	RENATA KARPOVA	{"phone": "+70536122087"}
0005434964582	827660	7304 574112	MARIYA ALEKSEEVA	{"email": "alekseeva-mariya.10121967@postgrespro.ru", "phone": "+70060259535"}
0005434964583	4BAA17	9438 621601	ELENA KUZMINA	{"phone": "+70383237114"}
0005434964584	8FB64F	8918 789631	VLADIMIR MAKAROV	{"email": "vladimir-makarov-1960@postgrespro.ru", "phone": "+70586512493"}
0005434964585	9B987B	5791 523896	MAKSIM VASILEV	{"email": "maksim_vasilev.14071973@postgrespro.ru", "phone": "+70275953393"}
0005434964586	9B987B	8260 445209	EGOR MATVEEV	{"email": "matveev.egor091971@postgrespro.ru", "phone": "+70557037338"}
0005434964587	1A75DD	7630 039389	VLADIMIR ISAEV	{"phone": "+70460128916"}
0005434964588	1A75DD	9933 651726	POLINA ZAYCEVA	{"phone": "+70973231876"}
0005434964589	422898	5969 991721	TATYANA SERGEEVA	{"email": "tatyanasergeeva.101968@postgrespro.ru", "phone": "+70640665660"}
0005434964590	422898	9043 805186	ANNA ZAYCEVA	{"email": "annazayceva111965@postgrespro.ru", "phone": "+70814803785"}
0005434964591	422898	9024 661701	MARIYA KOVALEVA	{"phone": "+70443597953"}
0005434964592	460D3F	6308 730836	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev.1972@postgrespro.ru", "phone": "+70490130362"}
0005434964593	E3A4A9	0969 322581	NINA KUZNECOVA	{"phone": "+70284592504"}
0005434964594	A641E5	4935 668020	NATALIYA DENISOVA	{"phone": "+70477633533"}
0005434964595	A641E5	6272 884443	DAVID SIDOROV	{"phone": "+70530309680"}
0005434964596	32780A	3744 584734	ALLA NAUMOVA	{"phone": "+70811401226"}
0005434964597	4F90DF	1577 726658	RAMIL SOKOLOV	{"email": "sokolov_ramil-1967@postgrespro.ru", "phone": "+70465418245"}
0005434964598	1898F2	1471 262468	SERGEY KUDRYASHOV	{"email": "s_kudryashov-081964@postgrespro.ru", "phone": "+70886581659"}
0005434964599	88986D	9236 700525	EKATERINA ABRAMOVA	{"phone": "+70555879959"}
0005434964600	88986D	5472 926102	MAKSIM PETROV	{"email": "petrov.maksim.1971@postgrespro.ru", "phone": "+70772373387"}
0005434964601	100A3D	0607 745364	IVAN MOROZOV	{"phone": "+70448351176"}
0005434964602	100A3D	0525 536538	IGOR KUDRYASHOV	{"phone": "+70769237165"}
0005434964603	19D93B	8584 274545	YURIY VOROBEV	{"phone": "+70012791260"}
0005434964604	DBF0EB	6189 881194	VALENTINA KOZLOVA	{"email": "valentina_kozlova_121966@postgrespro.ru", "phone": "+70821722211"}
0005434964605	92CAF8	7098 695572	NATALYA DANILOVA	{"phone": "+70452912375"}
0005434964606	8E34BB	2571 321157	ELENA KRASNOVA	{"phone": "+70147116220"}
0005434964607	8E34BB	6873 703990	ANASTASIYA FILIPPOVA	{"email": "filippova-anastasiya_1971@postgrespro.ru", "phone": "+70109933876"}
0005434964608	1CB9DA	2019 966294	SERGEY PETROV	{"phone": "+70544507365"}
0005434964609	3528E1	6751 685469	ELENA KRASNOVA	{"email": "krasnova-e081970@postgrespro.ru", "phone": "+70420341675"}
0005434964610	3528E1	8745 622341	ANTONINA IVANOVA	{"phone": "+70637936647"}
0005434964611	971CCF	2498 587841	TATYANA KUDRYASHOVA	{"phone": "+70496014515"}
0005434964612	7F6A8C	4815 411556	MAKSIM KUZMIN	{"phone": "+70974971394"}
0005434964613	EB13A6	5598 031979	DANILA KUZNECOV	{"phone": "+70369616055"}
0005434964614	11D5C1	2367 783997	SERGEY STEPANOV	{"phone": "+70281126575"}
0005434964615	AC8B01	7017 977657	TATYANA VLASOVA	{"phone": "+70654209261"}
0005434964616	026EF5	1362 198480	DMITRIY MATVEEV	{"email": "matveev.d_31031973@postgrespro.ru", "phone": "+70639847295"}
0005434964617	CD29F3	5187 659125	ELENA PAVLOVA	{"phone": "+70232203876"}
0005434964618	8E8EB2	3930 579506	ANDREY NIKOLAEV	{"email": "anikolaev-24091977@postgrespro.ru", "phone": "+70597585768"}
0005434964619	0E2F96	9106 933324	VADIM KISELEV	{"phone": "+70637430182"}
0005434964620	0E2F96	8838 789289	PAVEL ZAKHAROV	{"phone": "+70817870671"}
0005434964621	A39E35	5597 777940	NELLI KUZNECOVA	{"phone": "+70026226625"}
0005434964622	A39E35	9467 568686	ELENA BARANOVA	{"phone": "+70655392848"}
0005434964623	A888A9	4184 358611	VIKTOR FROLOV	{"email": "frolov.v-071969@postgrespro.ru", "phone": "+70473292694"}
0005434964624	7814CC	7968 239776	AYRAT VOLKOV	{"email": "volkov_ayrat111972@postgrespro.ru", "phone": "+70793498916"}
0005434964625	299309	7441 528694	NADEZHDA VOROBEVA	{"phone": "+70418568700"}
0005434964626	F53D96	5235 230019	VLADIMIR SOKOLOV	{"phone": "+70504195227"}
0005434964627	7D74A2	9748 814997	KLAVDIYA ERMAKOVA	{"email": "k.ermakova-1962@postgrespro.ru", "phone": "+70349221081"}
0005434964628	7D74A2	5931 129026	VITALIY SERGEEV	{"email": "vsergeev-1973@postgrespro.ru", "phone": "+70569700180"}
0005434964629	5214C6	5378 896798	SERGEY FEDOROV	{"email": "s.fedorov_111963@postgrespro.ru", "phone": "+70921686123"}
0005434964630	AC9DB5	9548 782006	DARYA FOMINA	{"email": "fomina_darya081981@postgrespro.ru", "phone": "+70914073915"}
0005434964631	987148	1484 996234	VALENTINA AFANASEVA	{"phone": "+70933548251"}
0005434964632	9CDB5C	9982 029093	ALEKSANDR NIKOLAEV	{"email": "anikolaev.091979@postgrespro.ru", "phone": "+70755094902"}
0005434964633	9CDB5C	4088 861451	EKATERINA RYABOVA	{"phone": "+70714302002"}
0005434964634	C9D124	8297 264172	BOGDAN KULIKOV	{"email": "kulikovb-05021980@postgrespro.ru", "phone": "+70267874997"}
0005434964635	C9D124	5411 818311	SERGEY VOROBEV	{"phone": "+70428878327"}
0005434964636	2997B9	7136 758101	TAKHIR DMITRIEV	{"phone": "+70244340136"}
0005434964637	B5298A	8913 833058	OLGA VLASOVA	{"phone": "+70074519077"}
0005434964638	B5298A	0935 679928	IVAN GERASIMOV	{"phone": "+70138494536"}
0005434964639	456150	7130 305417	VERA MEDVEDEVA	{"phone": "+70595315735"}
0005434964640	456150	6548 493252	NADEZHDA BARANOVA	{"phone": "+70605116583"}
0005434964641	8B20D9	5526 962388	VLADIMIR MOROZOV	{"email": "vladimir_morozov.19071974@postgrespro.ru", "phone": "+70869023699"}
0005434964642	8B20D9	6560 865832	OLGA GAVRILOVA	{"email": "ogavrilova-24021971@postgrespro.ru", "phone": "+70550315650"}
0005434964643	061BD6	0407 498424	TATYANA KUDRYASHOVA	{"email": "kudryashova.tatyana1979@postgrespro.ru", "phone": "+70948584760"}
0005434964644	061BD6	4978 122363	DARYA DMITRIEVA	{"email": "d-dmitrieva.1972@postgrespro.ru", "phone": "+70468059773"}
0005434964645	ECCE3D	1243 049108	OLEG ABRAMOV	{"phone": "+70002889016"}
0005434964646	ECCE3D	4510 235539	GALINA LAZAREVA	{"email": "lazareva.g121965@postgrespro.ru", "phone": "+70767941199"}
0005434964647	7AA213	7870 588311	ILYA ANDREEV	{"phone": "+70803177106"}
0005434964648	98A612	5330 116984	GALINA MOROZOVA	{"phone": "+70663809159"}
0005434964649	ADFA69	3712 702333	KSENIYA GERASIMOVA	{"email": "gerasimovakseniya1956@postgrespro.ru", "phone": "+70055405748"}
0005434964650	ADFA69	5360 872488	IRINA MAKSIMOVA	{"email": "maksimova_i_1978@postgrespro.ru", "phone": "+70401138398"}
0005434964651	A8DC48	3186 703487	ARINA VOLKOVA	{"phone": "+70331239093"}
0005434964652	DA98FB	1491 419827	OLGA ORLOVA	{"email": "olga_orlova.011960@postgrespro.ru", "phone": "+70277158855"}
0005434964653	DA98FB	8116 919317	LIDIYA MOISEEVA	{"phone": "+70880391589"}
0005434964654	DA98FB	1987 518004	ELENA KUZNECOVA	{"email": "e.kuznecova_1949@postgrespro.ru", "phone": "+70066269629"}
0005434964655	317D05	7632 970991	PELAGEYA KOROLEVA	{"email": "pkoroleva_031972@postgrespro.ru", "phone": "+70732559535"}
0005434964656	52D421	9096 185576	TATYANA MEDVEDEVA	{"email": "t-medvedeva_111976@postgrespro.ru", "phone": "+70980210644"}
0005434964657	F04A1D	4397 683310	ANDREY FOMIN	{"email": "andreyfomin-1974@postgrespro.ru", "phone": "+70923299659"}
0005434964658	F04A1D	9688 150600	OLGA GUSEVA	{"email": "guseva_olga_081973@postgrespro.ru", "phone": "+70822020013"}
0005434964659	1C3B1A	3656 410362	TATYANA MOROZOVA	{"phone": "+70961412391"}
0005434964660	1C3B1A	3321 164055	EMMA AFANASEVA	{"email": "afanaseva.e.121965@postgrespro.ru", "phone": "+70013449108"}
0005434964661	3F5536	8210 792590	VIKTOR ORLOV	{"email": "orlov.v-1963@postgrespro.ru", "phone": "+70471947037"}
0005434964662	3F5536	0043 054421	NINA SERGEEVA	{"email": "sergeeva-n091975@postgrespro.ru", "phone": "+70724735540"}
0005434964663	AF8AA8	5067 185520	GALINA MATVEEVA	{"email": "g_matveeva051976@postgrespro.ru", "phone": "+70360996547"}
0005434964664	4FEA01	3240 982983	LARISA PAVLOVA	{"email": "pavlova-larisa_26061967@postgrespro.ru", "phone": "+70979464936"}
0005434964665	0BFCA3	0769 970851	ALEKSANDR PETROV	{"email": "petrovaleksandr_26061971@postgrespro.ru", "phone": "+70074405130"}
0005434964728	184F4E	1281 835159	NATALYA ZHURAVLEVA	{"phone": "+70315633589"}
0005434964666	0BFCA3	2383 808620	DMITRIY STEPANOV	{"email": "stepanov-d.1983@postgrespro.ru", "phone": "+70984028610"}
0005434964667	E6C7A6	2507 043514	PETR FROLOV	{"email": "frolovpetr.1970@postgrespro.ru", "phone": "+70929775850"}
0005434964668	E6C7A6	0240 492129	ALEKSANDR FEDOROV	{"phone": "+70258724516"}
0005434964669	CFB19B	3211 280468	OLGA STEPANOVA	{"email": "stepanovao-21091966@postgrespro.ru", "phone": "+70479384500"}
0005434964670	CFB19B	5833 720905	VASILIY ILIN	{"phone": "+70848963601"}
0005434964671	E047CC	1523 269666	YURIY ZAKHAROV	{"email": "yuriy_zakharov.091971@postgrespro.ru", "phone": "+70984028895"}
0005434964672	E047CC	7486 585821	ALEKSANDR MELNIKOV	{"phone": "+70259215553"}
0005434964673	26B4B2	4097 406364	LYUDMILA RODIONOVA	{"phone": "+70891662293"}
0005434964674	DEF3DC	1414 087561	YULIYA STEPANOVA	{"phone": "+70524927715"}
0005434964675	DEF3DC	0820 209272	ANATOLIY KOROLEV	{"email": "anatoliy-korolev_111968@postgrespro.ru", "phone": "+70466559524"}
0005434964676	22BC75	0377 250233	MARAT STEPANOV	{"email": "stepanovm1978@postgrespro.ru", "phone": "+70213061923"}
0005434964677	E53152	7677 304487	TATYANA POTAPOVA	{"phone": "+70224300317"}
0005434964678	3005E5	1412 377608	ELENA OVCHINNIKOVA	{"email": "elena.ovchinnikova_09061983@postgrespro.ru", "phone": "+70734994026"}
0005434964679	C8738A	2910 786765	DMITRIY ILIN	{"email": "ilin_dmitriy-1975@postgrespro.ru", "phone": "+70676696088"}
0005434964680	5CADFC	2667 201703	SERGEY SEMENOV	{"email": "sergey_semenov.02011982@postgrespro.ru", "phone": "+70065879750"}
0005434964681	4B3563	9240 861694	NINA KUDRYASHOVA	{"phone": "+70967479118"}
0005434964682	37BEDC	2639 450695	DAMIR ANTONOV	{"email": "antonov.d_22071978@postgrespro.ru", "phone": "+70680270055"}
0005434964683	732670	3265 297390	OLEG MAKAROV	{"phone": "+70166419201"}
0005434964684	62E131	7424 942800	LYUDMILA BORISOVA	{"email": "borisova.lyudmila1962@postgrespro.ru", "phone": "+70533728034"}
0005434964685	E83BB6	9160 688516	ANGELINA CHERNOVA	{"phone": "+70817723518"}
0005434964686	A68A55	6330 151229	ELIZAVETA BELYAEVA	{"phone": "+70456427654"}
0005434964687	F519FF	2583 717730	VIKTOR TARASOV	{"phone": "+70796662524"}
0005434964688	90F438	7658 273096	DANIIL GERASIMOV	{"phone": "+70250377253"}
0005434964689	F8E281	0016 763837	ANDREY IVANOV	{"email": "ivanov-a_09091969@postgrespro.ru", "phone": "+70877523475"}
0005434964690	F8E281	2720 643042	LYUBOV KOLESNIKOVA	{"phone": "+70439335849"}
0005434964691	A0FCA4	9222 823148	MARIYA SAVELEVA	{"email": "savelevam-30061965@postgrespro.ru", "phone": "+70822962476"}
0005434964692	A0FCA4	1466 089761	VYACHESLAV KULIKOV	{"phone": "+70949178871"}
0005434964693	017EA6	5768 871832	MARIYA KOLESNIKOVA	{"email": "kolesnikova_m05061971@postgrespro.ru", "phone": "+70408951748"}
0005434964694	D14ED1	7991 756509	OLGA ARKHIPOVA	{"email": "arkhipovaolga_031972@postgrespro.ru", "phone": "+70232226051"}
0005434964695	D8F97C	0524 062450	TATYANA GRISHINA	{"email": "tatyanagrishina-31081961@postgrespro.ru", "phone": "+70483496689"}
0005434964696	4AB09B	3168 205794	NATALYA AKIMOVA	{"phone": "+70400258200"}
0005434964697	93D999	1479 595709	VERA CHERNOVA	{"phone": "+70270157873"}
0005434964698	559596	1272 450176	LYUBOV LUKYANOVA	{"phone": "+70528827153"}
0005434964699	FEFB4E	9111 491606	VIKTOR MOROZOV	{"email": "morozov-v23051976@postgrespro.ru", "phone": "+70708165412"}
0005434964700	FEFB4E	6158 075789	ALEKSANDR KONOVALOV	{"phone": "+70932313736"}
0005434964701	B1D9CE	4557 787714	IRINA GRISHINA	{"email": "irinagrishina.081973@postgrespro.ru", "phone": "+70100804774"}
0005434964702	073E8F	0588 071147	LEONTIY RODIONOV	{"phone": "+70229715779"}
0005434964703	38269A	2819 098218	ELENA EFIMOVA	{"phone": "+70884314627"}
0005434964704	BE21B7	4871 163849	ELENA IVANOVA	{"phone": "+70760558901"}
0005434964705	BD2396	1990 593901	NADEZHDA KARPOVA	{"email": "nadezhdakarpova27061973@postgrespro.ru", "phone": "+70536617695"}
0005434964706	BD2396	4082 568773	YANA MOISEEVA	{"phone": "+70385360350"}
0005434964707	311BF1	7207 043988	ELENA ANTONOVA	{"phone": "+70613614382"}
0005434964708	311BF1	4617 927597	RAISA SOLOVEVA	{"phone": "+70089334888"}
0005434964709	4D868F	1533 812361	VLADIMIR ROMANOV	{"email": "romanovv071989@postgrespro.ru", "phone": "+70381833994"}
0005434964710	BCED10	8054 709945	DMITRIY BORISOV	{"email": "d_borisov1971@postgrespro.ru", "phone": "+70530962031"}
0005434964711	CD6D8C	0362 662092	SERGEY VASILEV	{"phone": "+70502026441"}
0005434964712	8F427B	8502 185918	TAISIYA LUKYANOVA	{"email": "taisiya-lukyanova121991@postgrespro.ru", "phone": "+70229146540"}
0005434964713	8F427B	9467 872231	ZINAIDA VASILEVA	{"email": "zinaida-vasileva.1969@postgrespro.ru", "phone": "+70941389037"}
0005434964714	19BE12	9056 000743	OLEG VOLKOV	{"email": "oleg_volkov-1981@postgrespro.ru", "phone": "+70451851438"}
0005434964715	3A12A3	1083 841691	ARTEM VOROBEV	{"phone": "+70881835034"}
0005434964716	DC27FF	6737 812796	EVGENIY FOMIN	{"phone": "+70277268394"}
0005434964717	DC27FF	9112 947664	VERA ZHUKOVA	{"phone": "+70949277726"}
0005434964718	B3F6ED	7357 621630	LARISA SIDOROVA	{"phone": "+70511151650"}
0005434964719	76B970	2105 890916	VALERIY PAVLOV	{"phone": "+70624318782"}
0005434964720	76B970	5607 882240	MIKHAIL KARPOV	{"email": "karpov.m1976@postgrespro.ru", "phone": "+70564266709"}
0005434964721	78C7C2	9707 237889	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr07081978@postgrespro.ru", "phone": "+70425931157"}
0005434964722	0D7DF3	1420 076006	ALEKSANDR KONOVALOV	{"phone": "+70375422487"}
0005434964723	1344CB	0818 939777	VALENTINA KOVALEVA	{"email": "v_kovaleva.1968@postgrespro.ru", "phone": "+70116357997"}
0005434964724	76208D	8003 149828	ALEKSANDR ZHUKOV	{"phone": "+70208261833"}
0005434964725	76208D	5253 023247	ALEKSEY KOZLOV	{"email": "aleksey_kozlov_031967@postgrespro.ru", "phone": "+70899323867"}
0005434964726	F1E870	3594 643852	MARIYA MELNIKOVA	{"phone": "+70494277764"}
0005434964727	F1E870	6548 204113	DMITRIY SEMENOV	{"phone": "+70274002909"}
0005434964729	1ADB90	1488 786739	TATYANA TARASOVA	{"phone": "+70553521477"}
0005434964730	37BC39	8478 719301	VERONIKA MIKHAYLOVA	{"email": "veronika.mikhaylova1970@postgrespro.ru", "phone": "+70797331877"}
0005434964731	37BC39	1902 597336	VLADIMIR MATVEEV	{"phone": "+70471732131"}
0005434964732	52F121	3074 683147	SERGEY KUZNECOV	{"email": "kuznecov_sergey-1971@postgrespro.ru", "phone": "+70281586129"}
0005434964733	191DA4	9036 987954	VITALIY AFANASEV	{"email": "afanasev-v.1969@postgrespro.ru", "phone": "+70755333283"}
0005434964734	191DA4	7683 322959	ANATOLIY MOROZOV	{"email": "morozovanatoliy1973@postgrespro.ru", "phone": "+70240886646"}
0005434964735	53C017	5043 037292	OLEG IVANOV	{"phone": "+70130966527"}
0005434964736	2ED76D	8570 270765	VALERIY NAZAROV	{"phone": "+70572976336"}
0005434964737	4CC1E8	8066 422159	ALEKSANDR KAZAKOV	{"email": "a-kazakov.1985@postgrespro.ru", "phone": "+70439020861"}
0005434964738	4CC1E8	2886 918383	ROMAN MARTYNOV	{"email": "martynovr-13021976@postgrespro.ru", "phone": "+70922248342"}
0005434964739	CE983B	3426 959919	IGOR DENISOV	{"email": "i.denisov.1984@postgrespro.ru", "phone": "+70157613528"}
0005434964740	CE983B	3364 110415	VERONIKA KAZAKOVA	{"phone": "+70503663022"}
0005434964741	76997A	0311 504910	NATALYA ROMANOVA	{"phone": "+70545496664"}
0005434964742	96FED4	5566 488532	ANATOLIY SAVELEV	{"email": "savelev-anatoliy-021970@postgrespro.ru", "phone": "+70159063883"}
0005434964743	12D917	3649 821705	OLEG TIKHONOV	{"phone": "+70563645513"}
0005434964744	8D87E7	9474 826235	EVGENIY EGOROV	{"email": "egorove-05081960@postgrespro.ru", "phone": "+70917190193"}
0005434964745	8D87E7	8014 496774	ELENA KUZNECOVA	{"phone": "+70662275319"}
0005434964746	73CE5B	9497 836936	VIKTOR PETROV	{"email": "petrovviktor-121969@postgrespro.ru", "phone": "+70329308377"}
0005434964747	2074B2	8513 299926	NIKOLAY FEDOROV	{"email": "fedorovnikolay22091979@postgrespro.ru", "phone": "+70493346205"}
0005434964748	2074B2	2556 533452	ALEKSEY SOROKIN	{"email": "sorokin-aleksey.1969@postgrespro.ru", "phone": "+70354808979"}
0005434964749	2074B2	5746 556910	VALENTINA SOLOVEVA	{"email": "valentina-soloveva06101975@postgrespro.ru", "phone": "+70702225737"}
0005434964750	6A794C	3066 729794	SERGEY ZAKHAROV	{"email": "zakharovs.05101983@postgrespro.ru", "phone": "+70471870648"}
0005434964751	0E3FA4	9124 213779	ELIZAVETA ROMANOVA	{"email": "elizavetaromanova_061959@postgrespro.ru", "phone": "+70638764480"}
0005434964752	ACF11F	3631 146152	SVETLANA NESTEROVA	{"email": "nesterovasvetlana-081986@postgrespro.ru", "phone": "+70831671242"}
0005434964753	ACF11F	5505 361771	RIMMA FOMINA	{"email": "rimma-fomina.25081969@postgrespro.ru", "phone": "+70929767440"}
0005434964754	C17E18	0937 241329	MARINA KUZNECOVA	{"email": "kuznecova.marina-101977@postgrespro.ru", "phone": "+70347020184"}
0005434964755	FC720F	5443 590589	VIKTOR SERGEEV	{"email": "viktorsergeev04121981@postgrespro.ru", "phone": "+70044389789"}
0005434964756	FC720F	8144 764139	ELENA CHERNOVA	{"email": "echernova-10081983@postgrespro.ru", "phone": "+70970048123"}
0005434964757	0B90D0	8604 550579	ELENA ZHUKOVA	{"phone": "+70744688247"}
0005434964758	ABA679	3978 413605	NINA BOGDANOVA	{"phone": "+70134402700"}
0005434964759	803BA5	4978 934697	NATALYA GRISHINA	{"phone": "+70083066482"}
0005434964760	E1E8D1	6849 193583	MARIYA LEBEDEVA	{"phone": "+70333588329"}
0005434964761	A421DF	5651 252213	VALENTINA SOROKINA	{"phone": "+70860835403"}
0005434964762	8128DC	2044 747004	NIKOLAY POPOV	{"email": "nikolay_popov.19041973@postgrespro.ru", "phone": "+70454906107"}
0005434964763	4A097C	3051 513782	ALEKSANDR ZHUKOV	{"phone": "+70061875853"}
0005434964764	232264	4190 963056	ARKADIY IVANOV	{"email": "ivanov-arkadiy.21031970@postgrespro.ru", "phone": "+70479408316"}
0005434964765	54E6B8	6023 567538	VIKTORIYA BELOVA	{"email": "viktoriya-belova091973@postgrespro.ru", "phone": "+70373214493"}
0005434964766	A23E90	0916 316517	VLADIMIR MEDVEDEV	{"phone": "+70892781000"}
0005434964767	A23E90	3891 646184	ILYA NIKITIN	{"phone": "+70163265421"}
0005434964768	6A343C	0810 013161	EVGENIY MIKHAYLOV	{"phone": "+70486428018"}
0005434964769	BFACD8	0874 491650	EKATERINA NIKOLAEVA	{"email": "ekaterinanikolaeva1979@postgrespro.ru", "phone": "+70394029103"}
0005434964770	213FD1	9207 650474	RAISA MAKAROVA	{"phone": "+70781272653"}
0005434964771	AD6853	1544 678786	MARIYA TIMOFEEVA	{"phone": "+70421672277"}
0005434964772	C83134	2989 997076	KARINA CHERNOVA	{"email": "karina.chernova_22071970@postgrespro.ru", "phone": "+70793797584"}
0005434964773	C83134	0518 091817	ANNA POPOVA	{"email": "anna.popova-19061975@postgrespro.ru", "phone": "+70790446769"}
0005434964774	C83134	7519 148427	LYUDMILA KISELEVA	{"phone": "+70843507487"}
0005434964775	0B25AA	1091 313872	ELENA ZAKHAROVA	{"email": "zakharovae.011978@postgrespro.ru", "phone": "+70175425965"}
0005434964776	0B25AA	0803 199318	MARIYA ABRAMOVA	{"email": "abramova-mariya_091964@postgrespro.ru", "phone": "+70059515938"}
0005434964777	3F895D	9647 624067	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev13061965@postgrespro.ru", "phone": "+70540537106"}
0005434964778	3F895D	8850 902210	ZOYA KUZNECOVA	{"phone": "+70821515349"}
0005434964779	A259A6	2072 863580	NIKOLAY DENISOV	{"phone": "+70332735400"}
0005434964780	4339B7	0293 475710	ANNA MOROZOVA	{"email": "annamorozova_101963@postgrespro.ru", "phone": "+70935032227"}
0005434964781	4339B7	0077 326894	ILMIR MIRONOV	{"email": "mironov_ilmir_1965@postgrespro.ru", "phone": "+70899271946"}
0005434964782	4339B7	8012 379344	ANDREY MAKSIMOV	{"phone": "+70355162839"}
0005434964783	39762F	5900 666129	LYUBOV ZAYCEVA	{"phone": "+70332939201"}
0005434964784	39762F	3972 807126	VALERIY EGOROV	{"phone": "+70221424172"}
0005434964785	56FC53	2765 152003	KLAVDIYA GAVRILOVA	{"email": "kgavrilova.12011972@postgrespro.ru", "phone": "+70448679312"}
0005434964786	56FC53	5367 468473	VALENTINA KOLESNIKOVA	{"email": "valentina_kolesnikova041979@postgrespro.ru", "phone": "+70674212059"}
0005434979365	D77B7E	8258 982645	VITALIY ANDREEV	{"phone": "+70252422266"}
0005434964787	BDBFC7	9586 512254	STANISLAV PAVLOV	{"email": "pavlov-stanislav_25081955@postgrespro.ru", "phone": "+70603730098"}
0005434964788	F3A888	6801 335973	ANTON KONOVALOV	{"phone": "+70798466119"}
0005434964789	07C791	4961 533415	NATALYA KUDRYASHOVA	{"phone": "+70795695320"}
0005434964790	C7E1DE	2875 315829	ALEKSANDRA SERGEEVA	{"phone": "+70447332414"}
0005434979281	40E029	0707 005198	MIKHAIL EGOROV	{"phone": "+70531929613"}
0005434979252	25059B	3950 574174	MARIYA FOMINA	{"phone": "+70429352164"}
0005434979253	161E71	3764 607066	VITALIY KAZAKOV	{"phone": "+70854145061"}
0005434979254	161E71	2507 535862	LYUDMILA CHERNOVA	{"email": "l-chernova.31101956@postgrespro.ru", "phone": "+70008473313"}
0005434979255	CA2E01	2434 016495	MARIYA KOZLOVA	{"email": "kozlova-m-041963@postgrespro.ru", "phone": "+70409669597"}
0005434979256	94889C	9377 457902	ALEKSANDR ORLOV	{"email": "aleksandr_orlov_1965@postgrespro.ru", "phone": "+70209063041"}
0005434979257	94889C	9823 959657	VALENTIN MARTYNOV	{"email": "v_martynov081972@postgrespro.ru", "phone": "+70715139194"}
0005434979258	574098	0342 074163	EKATERINA KOVALEVA	{"phone": "+70137143802"}
0005434979259	574098	0957 710587	NATALYA STEPANOVA	{"phone": "+70785140025"}
0005434979260	7452C0	9405 063429	ALLA VOROBEVA	{"email": "vorobeva-a-1967@postgrespro.ru", "phone": "+70662689855"}
0005434979261	56E628	1653 414436	NADEZHDA FROLOVA	{"phone": "+70329197394"}
0005434979262	56E628	3398 967756	ELENA PETROVA	{"email": "e_petrova-041967@postgrespro.ru", "phone": "+70830435351"}
0005434979263	14BCFA	2921 232525	VLADIMIR STEPANOV	{"email": "vladimirstepanov.011972@postgrespro.ru", "phone": "+70071484291"}
0005434979264	14BCFA	9923 431819	ANASTASIYA KUZNECOVA	{"phone": "+70092523555"}
0005434979265	B3DC3C	9575 182850	EVGENIY ZAKHAROV	{"phone": "+70559934849"}
0005434979266	F79CCA	0527 984514	ALEKSANDR SOKOLOV	{"phone": "+70479082042"}
0005434979267	F79CCA	1747 890037	OLGA YUDINA	{"email": "o_yudina_101973@postgrespro.ru", "phone": "+70730855226"}
0005434979268	72BD11	7905 076349	ELENA GAVRILOVA	{"phone": "+70164211321"}
0005434979269	72BD11	3215 011180	ALEKSANDR ABRAMOV	{"email": "a_abramov-041966@postgrespro.ru", "phone": "+70715813596"}
0005434979270	C941FE	3917 295195	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova-21041975@postgrespro.ru", "phone": "+70026331087"}
0005434979271	1F14A9	8247 294034	ALEKSANDR VOROBEV	{"email": "a.vorobev.111977@postgrespro.ru", "phone": "+70976726812"}
0005434979272	6B0A33	8690 801470	ANASTASIYA ZHURAVLEVA	{"email": "zhuravleva.anastasiya_1982@postgrespro.ru", "phone": "+70404290941"}
0005434979273	6B0A33	5100 353893	NADEZHDA ZAKHAROVA	{"email": "zakharova-n_111975@postgrespro.ru", "phone": "+70524037304"}
0005434979274	1307AA	5181 809270	RAMIS BARANOV	{"phone": "+70944253463"}
0005434979275	1307AA	5350 034246	IVAN BORISOV	{"email": "iborisov_03011980@postgrespro.ru", "phone": "+70741574451"}
0005434979276	5A6443	3782 676142	RAMIL MOROZOV	{"email": "r-morozov-1986@postgrespro.ru", "phone": "+70976102164"}
0005434979277	6289B7	8155 861724	RAMIS BORISOV	{"phone": "+70327640819"}
0005434979278	26FE0E	1931 821773	ANASTASIYA POLYAKOVA	{"phone": "+70270869212"}
0005434979279	88253E	7214 511773	YULIYA MOROZOVA	{"phone": "+70084231096"}
0005434979280	7AD9C0	3677 279197	DMITRIY SOROKIN	{"email": "sorokind-1979@postgrespro.ru", "phone": "+70484231486"}
0005434979282	1F183D	7823 405893	EVGENIY NIKITIN	{"email": "e.nikitin-081968@postgrespro.ru", "phone": "+70684775984"}
0005434979283	0D7BB0	8881 468737	ANDREY IVANOV	{"phone": "+70728709587"}
0005434979284	68CD44	1006 063677	VLADIMIR NAUMOV	{"email": "naumov.vladimir_011968@postgrespro.ru", "phone": "+70075676284"}
0005434979285	E6A3A7	6886 018312	ZINAIDA KRASNOVA	{"email": "z.krasnova-22071968@postgrespro.ru", "phone": "+70215026285"}
0005434979286	E6A3A7	5721 328214	VALENTINA TROFIMOVA	{"phone": "+70228378656"}
0005434979287	2B7788	2928 858446	ARTEM SIDOROV	{"phone": "+70818997867"}
0005434979288	B64FCF	8334 565297	IVAN BARANOV	{"email": "ivan_baranov07091972@postgrespro.ru", "phone": "+70630773507"}
0005434979289	B64FCF	8533 972548	NINA NIKOLAEVA	{"email": "n_nikolaeva-1962@postgrespro.ru", "phone": "+70311186549"}
0005434979290	B64FCF	8774 635419	ALEKSANDR EGOROV	{"email": "aleksandregorov-01101965@postgrespro.ru", "phone": "+70805274481"}
0005434979291	5E9225	8303 116007	ELENA KUZMINA	{"phone": "+70262231007"}
0005434979292	3E9886	5397 339054	MIKHAIL MEDVEDEV	{"phone": "+70627762834"}
0005434979293	15D4FF	4592 201499	ANTONINA VOLKOVA	{"email": "a_volkova.101965@postgrespro.ru", "phone": "+70297253301"}
0005434979294	22C7C6	7153 994534	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr1972@postgrespro.ru", "phone": "+70011008354"}
0005434979295	6A3834	6894 335640	RAISA KUZNECOVA	{"email": "raisa_kuznecova011976@postgrespro.ru", "phone": "+70874904520"}
0005434979296	27398D	2571 647349	VLADIMIR KOROLEV	{"email": "vladimirkorolev-051975@postgrespro.ru", "phone": "+70938072420"}
0005434979297	93EFC1	8227 321999	YURIY FILIPPOV	{"phone": "+70633565097"}
0005434979298	93EFC1	5303 732046	ELENA MEDVEDEVA	{"email": "medvedeva-e-031979@postgrespro.ru", "phone": "+70028726133"}
0005434979299	65286A	0207 416040	ALEKSEY PETROV	{"phone": "+70740773695"}
0005434979300	372EFF	4896 041651	VLADISLAV DAVYDOV	{"phone": "+70606906343"}
0005434979301	372EFF	4655 599922	VERA SEMENOVA	{"email": "semenova-v_101976@postgrespro.ru", "phone": "+70129912018"}
0005434979302	D4252E	1234 185816	NIKITA KUZNECOV	{"email": "kuznecov-nikita21091975@postgrespro.ru", "phone": "+70811214804"}
0005434979303	14B65F	5868 680422	NIKOLAY IVANOV	{"phone": "+70741059778"}
0005434979304	B267EA	5354 603148	FAINA KUZNECOVA	{"email": "f_kuznecova_1978@postgrespro.ru", "phone": "+70836847421"}
0005434979305	820E6D	6825 483429	ANNA NIKOLAEVA	{"phone": "+70723494949"}
0005434979306	820E6D	7535 217448	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov-13111959@postgrespro.ru", "phone": "+70274647879"}
0005434979366	D77B7E	8078 817104	NADEZHDA SOLOVEVA	{"phone": "+70445813360"}
0005434979307	DA8F48	5961 084835	ALEKSANDR BARANOV	{"email": "baranov.a_071981@postgrespro.ru", "phone": "+70262066403"}
0005434979308	DA8F48	0512 776264	ANASTASIYA EGOROVA	{"email": "egorova.anastasiya-23081974@postgrespro.ru", "phone": "+70471655091"}
0005434979309	DA8F48	2303 073131	MAKSIM SHEVCHENKO	{"phone": "+70139598931"}
0005434979310	AF0261	5399 531797	OLGA KOVALEVA	{"email": "kovaleva_o-061965@postgrespro.ru", "phone": "+70698824498"}
0005434979311	141275	9589 750961	MIKHAIL PETROV	{"email": "m-petrov.1984@postgrespro.ru", "phone": "+70846855398"}
0005434979312	141275	4048 837724	NATALYA NIKOLAEVA	{"email": "nikolaeva-natalya_1975@postgrespro.ru", "phone": "+70704911634"}
0005434979313	8AF615	6698 063332	NINA IVANOVA	{"email": "ivanova.nina.121968@postgrespro.ru", "phone": "+70102966368"}
0005434979314	38476B	9938 623138	NINA ANTONOVA	{"email": "nina-antonova.091964@postgrespro.ru", "phone": "+70211544934"}
0005434979315	670771	5008 198993	KONSTANTIN DENISOV	{"phone": "+70158179812"}
0005434979316	670771	7371 547193	MAKSIM SIDOROV	{"email": "m.sidorov-031978@postgrespro.ru", "phone": "+70398617927"}
0005434979317	666775	7219 068699	ELENA CHERNOVA	{"email": "e_chernova1978@postgrespro.ru", "phone": "+70637461566"}
0005434979318	CB0395	5741 963176	SERGEY VOLKOV	{"phone": "+70222700408"}
0005434979319	CB0395	5090 838562	VERONIKA ANISIMOVA	{"email": "v_anisimova.1971@postgrespro.ru", "phone": "+70545674009"}
0005434979320	AD969F	4088 400254	RAISA MASLOVA	{"email": "raisa.maslova041977@postgrespro.ru", "phone": "+70691341189"}
0005434979321	AD969F	8343 230988	GULNAZ IVANOVA	{"email": "ivanova_g051977@postgrespro.ru", "phone": "+70775208831"}
0005434979322	AD969F	0438 883083	SERGEY STEPANOV	{"phone": "+70872176170"}
0005434979323	877272	7186 364270	ALEKSANDRA ALEKSANDROVA	{"phone": "+70151725765"}
0005434979324	36526D	8033 717503	EVGENIY MIRONOV	{"email": "mironov-evgeniy-051980@postgrespro.ru", "phone": "+70308529430"}
0005434979325	AB3559	9986 870094	MARINA EGOROVA	{"phone": "+70830038644"}
0005434979326	8F629D	5303 325850	TATYANA GUSEVA	{"email": "t-guseva1970@postgrespro.ru", "phone": "+70626951376"}
0005434979327	7CBCD2	0733 599240	MIKHAIL ZHURAVLEV	{"email": "zhuravlev.mikhail-1971@postgrespro.ru", "phone": "+70107284167"}
0005434979328	0A3028	7119 087741	VALENTINA VOROBEVA	{"phone": "+70842588761"}
0005434979329	409D12	4157 023132	ALEKSEY IVANOV	{"phone": "+70905222338"}
0005434979330	C037C5	9098 963970	VIKTORIYA TROFIMOVA	{"phone": "+70652721920"}
0005434979331	43AB51	2861 465323	LARISA ERMAKOVA	{"email": "larisa_ermakova-101963@postgrespro.ru", "phone": "+70750702993"}
0005434979332	D99364	3209 881976	VALENTINA KARPOVA	{"email": "valentina_karpova101967@postgrespro.ru", "phone": "+70658796121"}
0005434979333	D99364	6093 116858	IGOR ALEKSEEV	{"email": "igoralekseev071973@postgrespro.ru", "phone": "+70830803231"}
0005434979334	6E259C	0449 606909	ELENA KOLESNIKOVA	{"email": "elena.kolesnikova-08091970@postgrespro.ru", "phone": "+70285611047"}
0005434979335	6E259C	8557 627163	VERA VOLKOVA	{"phone": "+70011228479"}
0005434979336	6E259C	9343 721026	VLADIMIR SOROKIN	{"phone": "+70656284851"}
0005434979337	4837A8	5456 519463	POLINA ALEKSEEVA	{"phone": "+70532753064"}
0005434979338	8691C7	4230 843779	EVGENIYA GERASIMOVA	{"phone": "+70982086034"}
0005434979339	6DF438	6329 669212	NINA TROFIMOVA	{"email": "trofimovanina-20091973@postgrespro.ru", "phone": "+70731216453"}
0005434979340	6DF438	3199 165389	NELYA MATVEEVA	{"phone": "+70957211255"}
0005434979341	30C385	2423 186540	ALIYA IVANOVA	{"email": "a_ivanova.1967@postgrespro.ru", "phone": "+70957061117"}
0005434979342	D44218	0932 461641	TATYANA GERASIMOVA	{"phone": "+70274458429"}
0005434979343	59CE32	7332 208535	VALENTINA ZAYCEVA	{"phone": "+70083452480"}
0005434979344	59CE32	2727 552806	TATYANA KOROLEVA	{"phone": "+70262196114"}
0005434979345	E445E6	9573 568498	MIKHAIL SOKOLOV	{"email": "sokolovm.12061975@postgrespro.ru", "phone": "+70115374050"}
0005434979346	58B5CC	3881 557368	ANASTASIYA KAZAKOVA	{"email": "kazakova_a1981@postgrespro.ru", "phone": "+70204959772"}
0005434979347	386A08	8320 369204	NIKOLAY MAKSIMOV	{"email": "nikolay_maksimov1967@postgrespro.ru", "phone": "+70417781369"}
0005434979348	17508E	3520 181031	TATYANA PAVLOVA	{"email": "tatyana-pavlova-121973@postgrespro.ru", "phone": "+70791713113"}
0005434979349	17508E	8625 472990	ZINAIDA FADEEVA	{"phone": "+70645802221"}
0005434979350	59F95C	1897 000314	VALERIY AFANASEV	{"phone": "+70147606224"}
0005434979351	E356FD	8859 019204	LEONID BELOV	{"phone": "+70526485014"}
0005434979352	E356FD	4794 598661	YULIYA EFREMOVA	{"phone": "+70642525133"}
0005434979353	FCE762	4327 176345	IVAN SMIRNOV	{"email": "i_smirnov-07011972@postgrespro.ru", "phone": "+70985607182"}
0005434979354	FCE762	6288 245319	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandrova-aleksandra_1974@postgrespro.ru", "phone": "+70175681928"}
0005434979355	058B82	8189 887245	MIKHAIL KONOVALOV	{"email": "konovalov_mikhail1980@postgrespro.ru", "phone": "+70454210899"}
0005434979356	715186	5008 730784	NAIL KUZNECOV	{"phone": "+70102139295"}
0005434979357	38679F	3227 629323	IRINA DAVYDOVA	{"phone": "+70843420864"}
0005434979358	024F16	8445 929941	ANASTASIYA IVANOVA	{"email": "anastasiya_ivanova_12091966@postgrespro.ru", "phone": "+70797799996"}
0005434979359	A492B3	4762 756527	VLADISLAV ZHUKOV	{"email": "zhukov.vladislav-051971@postgrespro.ru", "phone": "+70406359302"}
0005434979360	A492B3	0410 132260	GALINA ALEKSANDROVA	{"email": "aleksandrovag1969@postgrespro.ru", "phone": "+70284170841"}
0005434979361	0F7D70	3468 814480	SVETLANA KUZMINA	{"email": "svetlana-kuzmina.24071977@postgrespro.ru", "phone": "+70331146872"}
0005434979362	8EEB15	0154 149557	GENNADIY NAZAROV	{"email": "gennadiy_nazarov-10011970@postgrespro.ru", "phone": "+70113294351"}
0005434979363	8EEB15	0165 090677	VLADIMIR VOROBEV	{"email": "vvorobev091972@postgrespro.ru", "phone": "+70614314973"}
0005434979364	9191C2	6995 594277	LYUDMILA KISELEVA	{"email": "lyudmila.kiseleva111969@postgrespro.ru", "phone": "+70576769184"}
0005434979367	8CF37A	0117 763367	IGOR OSIPOV	{"email": "iosipov-021971@postgrespro.ru", "phone": "+70210558191"}
0005434979368	2CE5F5	5441 814520	OLESYA ZOTOVA	{"phone": "+70527347237"}
0005434979369	137628	5952 677423	ANDREY ALEKSANDROV	{"phone": "+70920784232"}
0005434979370	137628	9345 367743	SERGEY SCHERBAKOV	{"email": "scherbakov.sergey_01081972@postgrespro.ru", "phone": "+70394254900"}
0005434979371	C4B4D8	0857 257165	VLADIMIR SOKOLOV	{"email": "vsokolov17121969@postgrespro.ru", "phone": "+70174998229"}
0005434979372	FEA6A5	9895 831912	OLGA TIKHONOVA	{"phone": "+70019164361"}
0005434979373	5BD638	4449 047096	TAMARA MARTYNOVA	{"phone": "+70623632574"}
0005434979374	5BD638	7819 956230	POLINA KUDRYASHOVA	{"phone": "+70080106124"}
0005434979375	84B82C	3152 487544	SVETLANA DANILOVA	{"email": "danilova.s.07121976@postgrespro.ru", "phone": "+70107899609"}
0005434979376	5CF34C	4033 568532	VALENTINA SCHERBAKOVA	{"phone": "+70438248405"}
0005434979377	1AE7A0	4079 387197	MAKSIM MATVEEV	{"email": "mmatveev.051978@postgrespro.ru", "phone": "+70111440748"}
0005434979378	78FD06	7404 106570	EDUARD KOZLOV	{"phone": "+70822891154"}
0005434979379	78FD06	1616 630600	VALENTINA NIKOLAEVA	{"phone": "+70456250452"}
0005434979380	0433AD	6158 593377	NATALIYA STEPANOVA	{"phone": "+70618061871"}
0005434979381	0433AD	7530 041940	ANASTASIYA MIKHAYLOVA	{"email": "mikhaylova-a.02031975@postgrespro.ru", "phone": "+70278037219"}
0005434979382	BF0979	1639 754247	ARTEM NOVIKOV	{"email": "novikovartem_1972@postgrespro.ru", "phone": "+70160506782"}
0005434979383	7AD645	6575 975167	MARINA ILINA	{"email": "ilinamarina.27051983@postgrespro.ru", "phone": "+70309559332"}
0005434979384	7AD645	1385 778130	OLESYA BELYAEVA	{"email": "belyaevao22051969@postgrespro.ru", "phone": "+70841896423"}
0005434979385	40F9FE	8219 564538	EVGENIYA VASILEVA	{"phone": "+70904945061"}
0005434979386	40F9FE	3619 873848	VALERIY DENISOV	{"email": "v-denisov.06081984@postgrespro.ru", "phone": "+70784344115"}
0005434979387	40F9FE	9636 434280	PRASKOVYA MAKSIMOVA	{"phone": "+70979558750"}
0005434979388	5575DA	9678 962274	NIKOLAY POPOV	{"email": "n_popov_1981@postgrespro.ru", "phone": "+70102070842"}
0005434979389	5575DA	2537 045330	VERA SEMENOVA	{"phone": "+70834005013"}
0005434979390	950280	7963 171073	IRINA FILIPPOVA	{"phone": "+70534845320"}
0005434979391	B9F366	9864 937200	IRINA SOLOVEVA	{"email": "solovevai1979@postgrespro.ru", "phone": "+70920758826"}
0005434979392	E54554	8448 024549	LILIYA EGOROVA	{"email": "egorova_liliya.06101969@postgrespro.ru", "phone": "+70638127551"}
0005434979393	FE0929	5442 233609	NADEZHDA DMITRIEVA	{"email": "nadezhdadmitrieva_18081961@postgrespro.ru", "phone": "+70243543347"}
0005434979394	8011C1	2513 233419	VLADIMIR DENISOV	{"email": "denisov_v_30071968@postgrespro.ru", "phone": "+70384137939"}
0005434979395	839D5F	5451 440595	VALENTINA MARTYNOVA	{"email": "v-martynova1968@postgrespro.ru", "phone": "+70899818605"}
0005434979396	E35C5B	4069 285025	ANATOLIY IVANOV	{"email": "ivanov_anatoliy-03071971@postgrespro.ru", "phone": "+70037947815"}
0005434979397	09430B	9558 501863	GALINA YAKOVLEVA	{"phone": "+70281707721"}
0005434979398	804AAF	6913 600705	OLGA SERGEEVA	{"email": "sergeeva_o-1973@postgrespro.ru", "phone": "+70808389448"}
0005434979399	B654F0	0946 886747	NINEL SEMENOVA	{"email": "semenova_ninel-1966@postgrespro.ru", "phone": "+70715156174"}
0005434979400	1D1E0B	9607 458840	TATYANA KOROLEVA	{"email": "t-koroleva-071983@postgrespro.ru", "phone": "+70216674347"}
0005434979401	1D1E0B	6775 890540	VALERIY KOROLEV	{"phone": "+70790863290"}
0005434979402	CE8413	6993 555677	ANATOLIY VOLKOV	{"phone": "+70197694982"}
0005434979403	C4BFD0	9148 047764	TATYANA FEDOROVA	{"phone": "+70884753264"}
0005434979404	05447E	0362 636488	YULIYA MAKAROVA	{"phone": "+70143445859"}
0005434979405	05447E	0292 359351	ANTON MELNIKOV	{"email": "melnikova1961@postgrespro.ru", "phone": "+70378636572"}
0005434979406	05447E	7954 989193	NATALYA ZAYCEVA	{"phone": "+70730758662"}
0005434979407	BDB72E	0530 611322	ALEKSEY KOZLOV	{"email": "kozlova1958@postgrespro.ru", "phone": "+70001600237"}
0005434979408	C77D33	4018 672784	VIKTORIYA AFANASEVA	{"email": "afanaseva_v.1970@postgrespro.ru", "phone": "+70879377212"}
0005434979409	C77D33	9763 592254	LYUDMILA GORBUNOVA	{"email": "gorbunova.lyudmila11061975@postgrespro.ru", "phone": "+70247468664"}
0005434979410	4F96E2	9369 028464	OLGA BELYAEVA	{"phone": "+70677527156"}
0005434979411	C7C00D	8962 973235	GENNADIY FILIPPOV	{"email": "filippov.g.1980@postgrespro.ru", "phone": "+70554795699"}
0005434979412	C7C00D	6790 982052	VLADIMIR IVANOV	{"email": "v_ivanov.1969@postgrespro.ru", "phone": "+70986256446"}
0005434979413	E0A560	9847 019950	NIKOLAY SOROKIN	{"email": "nikolay-sorokin.1965@postgrespro.ru", "phone": "+70122341954"}
0005434979414	D726AE	4455 776587	ALIYA NIKOLAEVA	{"phone": "+70090254947"}
0005434979415	D726AE	8050 034443	LYUBOV FILATOVA	{"email": "filatova-l_081965@postgrespro.ru", "phone": "+70521324117"}
0005434979416	FE626A	1014 389125	DMITRIY BORISOV	{"phone": "+70616574345"}
0005434979417	317E86	0283 743474	IRINA DANILOVA	{"phone": "+70708059837"}
0005434979418	317E86	3062 080480	TAMARA KUZMINA	{"email": "tamara-kuzmina06091975@postgrespro.ru", "phone": "+70246878985"}
0005434979419	AC9BBA	0259 067682	ALEKSANDR KULIKOV	{"phone": "+70261592835"}
0005434979420	AC9BBA	7454 287257	ANNA DMITRIEVA	{"email": "a_dmitrieva.111960@postgrespro.ru", "phone": "+70560229562"}
0005434979421	02E563	7933 975981	ELENA SERGEEVA	{"phone": "+70387585226"}
0005434979422	5F3B71	4351 296551	KIRILL KRASNOV	{"email": "k.krasnov_111970@postgrespro.ru", "phone": "+70049054946"}
0005434979423	5F3B71	1699 405577	GEORGIY VOLKOV	{"email": "g_volkov.11081974@postgrespro.ru", "phone": "+70271602442"}
0005434979424	E96C72	7272 208879	IGOR YAKOVLEV	{"email": "igoryakovlev_041983@postgrespro.ru", "phone": "+70777476470"}
0005434979425	E96C72	7157 739690	SVETLANA AKIMOVA	{"email": "svetlana.akimova121965@postgrespro.ru", "phone": "+70975569282"}
0005434979426	68437A	9608 757435	NIKOLAY GORBUNOV	{"phone": "+70452327784"}
0005434979427	33429E	5091 420151	OLGA SOLOVEVA	{"phone": "+70244651073"}
0005434979428	33429E	8769 312109	IGOR ZHURAVLEV	{"email": "igor.zhuravlev.16091968@postgrespro.ru", "phone": "+70837665533"}
0005434979429	06CAF8	6024 336590	GEORGIY SEMENOV	{"phone": "+70095480288"}
0005434979430	EAAFBA	8170 538837	MARIYA IVANOVA	{"email": "mariyaivanova-091973@postgrespro.ru", "phone": "+70777320329"}
0005434979431	9CFD44	3906 412274	EKATERINA GAVRILOVA	{"phone": "+70644472515"}
0005434979432	3203F5	3308 178198	ALEKSEY ALEKSANDROV	{"email": "aleksey-aleksandrov1974@postgrespro.ru", "phone": "+70729415155"}
0005434979433	3203F5	8350 111727	NADEZHDA ALEKSEEVA	{"email": "n.alekseeva.031969@postgrespro.ru", "phone": "+70887176144"}
0005434979434	C70CFC	1506 593123	DIANA MOISEEVA	{"phone": "+70268068111"}
0005434979435	C70CFC	7610 525443	PAVEL KUZNECOV	{"phone": "+70410010410"}
0005434979436	C70CFC	1394 886397	ELVIRA POPOVA	{"email": "popova-e03031973@postgrespro.ru", "phone": "+70621397538"}
0005434979437	832B7E	0910 669863	VERA SEMENOVA	{"phone": "+70748226460"}
0005434979438	832B7E	7930 484378	VYACHESLAV TIKHONOV	{"phone": "+70041612306"}
0005434979439	9635CC	4743 239101	OLGA IVANOVA	{"email": "olgaivanova_1961@postgrespro.ru", "phone": "+70301529302"}
0005434979440	E51FE8	2592 542750	POLINA DANILOVA	{"email": "danilova.p1965@postgrespro.ru", "phone": "+70384860569"}
0005434979441	E51FE8	1858 777717	ELLA AFANASEVA	{"phone": "+70671552765"}
0005434979442	3F5168	8535 216020	ANNA KULIKOVA	{"email": "anna.kulikova.03081970@postgrespro.ru", "phone": "+70132422714"}
0005434979443	1716FB	7742 461618	PETR KUZNECOV	{"phone": "+70020193145"}
0005434979444	007382	2958 483106	MIKHAIL SEMENOV	{"email": "semenov-m_22081983@postgrespro.ru", "phone": "+70085835229"}
0005434979445	87FB69	1030 743172	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov.1973@postgrespro.ru", "phone": "+70815758904"}
0005434979446	87FB69	3749 957307	VALENTIN EGOROV	{"email": "egorov-valentin-1973@postgrespro.ru", "phone": "+70661973811"}
0005434979447	E6BF8A	8054 269372	ZINAIDA KARPOVA	{"email": "karpova_zinaida1982@postgrespro.ru", "phone": "+70169825355"}
0005434979448	05E6A1	9851 070585	VLADIMIR KOZLOV	{"phone": "+70694123059"}
0005434979449	F3B82C	7478 502469	NIKOLAY FOMIN	{"email": "n.fomin-27041977@postgrespro.ru", "phone": "+70281088405"}
0005434979450	F3B82C	8340 135417	SERGEY BARANOV	{"phone": "+70347856250"}
0005434979451	666A9E	4689 905100	DMITRIY KOZLOV	{"email": "d.kozlov_081981@postgrespro.ru", "phone": "+70714810023"}
0005434979452	666A9E	8725 239419	TAMARA FADEEVA	{"email": "fadeeva.t_15021980@postgrespro.ru", "phone": "+70406249026"}
0005434979453	29B914	1788 617448	KIRILL ZAYCEV	{"email": "zaycev-kirill12091973@postgrespro.ru", "phone": "+70347138891"}
0005434979454	0D0EF2	7312 595239	STANISLAV ZHUKOV	{"email": "stanislavzhukov-1983@postgrespro.ru", "phone": "+70725013431"}
0005434979455	0D0EF2	8895 180023	ELENA NESTEROVA	{"email": "nesterova.elena091978@postgrespro.ru", "phone": "+70002599263"}
0005434979456	0D0EF2	5066 878454	EKATERINA EFREMOVA	{"phone": "+70142210487"}
0005434979457	147BA9	7821 095239	YURIY NIKOLAEV	{"email": "yuriy-nikolaev-1976@postgrespro.ru", "phone": "+70618022266"}
0005434979458	147BA9	6653 864724	LYUBOV YAKOVLEVA	{"email": "yakovleva-l_1979@postgrespro.ru", "phone": "+70643542891"}
0005434979459	B6B256	3964 257885	YULIYA MAKSIMOVA	{"email": "maksimovay.03071971@postgrespro.ru", "phone": "+70160977332"}
0005434979460	9D289D	6911 460896	LYUBOV FOMINA	{"phone": "+70799933161"}
0005434979461	9D289D	5749 051558	NIKOLAY POPOV	{"phone": "+70982425451"}
0005434979462	36BD80	9215 189663	NATALYA SERGEEVA	{"email": "natalya.sergeeva-10031969@postgrespro.ru", "phone": "+70208052840"}
0005434979463	36BD80	6469 672504	OLEG BORISOV	{"phone": "+70422623587"}
0005434979464	36BD80	8198 914370	ALEKSANDR FEDOTOV	{"phone": "+70263823550"}
0005434979465	3CA0D4	8323 153833	NINA GERASIMOVA	{"email": "n.gerasimova.28081971@postgrespro.ru", "phone": "+70277297580"}
0005434979466	562609	0351 245801	ALEKSANDR ZHURAVLEV	{"phone": "+70227872055"}
0005434979467	D127FD	0614 384301	VLADIMIR NIKITIN	{"phone": "+70079979929"}
0005434979468	8DE633	0862 757220	NATALYA ZHUKOVA	{"email": "natalyazhukova.1980@postgrespro.ru", "phone": "+70929021180"}
0005434979469	8DE633	7909 590120	VASILIY VOLKOV	{"email": "vasiliy.volkov101969@postgrespro.ru", "phone": "+70626820115"}
0005434979470	EA5E12	9338 622429	EVGENIYA KALININA	{"email": "kalinina.e_27051978@postgrespro.ru", "phone": "+70531064720"}
0005434979471	EA5E12	8957 211959	STANISLAV KISELEV	{"email": "kiselev.s.03081961@postgrespro.ru", "phone": "+70427209675"}
0005434979472	6CAC24	9191 272882	VERA NIKOLAEVA	{"email": "v_nikolaeva_051970@postgrespro.ru", "phone": "+70338381559"}
0005434979473	6CAC24	8299 665654	OLEG ZHUKOV	{"phone": "+70767516801"}
0005434979474	7C192D	4551 355816	DMITRIY MEDVEDEV	{"phone": "+70549376110"}
0005434979475	7C192D	5608 043706	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v1980@postgrespro.ru", "phone": "+70431727683"}
0005434979476	F4A220	7776 000496	OLGA SERGEEVA	{"phone": "+70084232231"}
0005434979477	F4A220	4332 232323	VASILIY SMIRNOV	{"email": "smirnov-vasiliy1962@postgrespro.ru", "phone": "+70178173132"}
0005434979478	072658	2963 228806	ALEKSANDRA MAKSIMOVA	{"phone": "+70573031009"}
0005434979479	AE2103	3233 830638	NATALYA KUZNECOVA	{"phone": "+70937643142"}
0005434979480	AE2103	2987 008160	MAYYA KULIKOVA	{"phone": "+70454006869"}
0005434979481	AE2103	4667 263788	OLGA SMIRNOVA	{"phone": "+70252565274"}
0005434979482	4CABBC	5271 411102	SHAVKAT ZAYCEV	{"phone": "+70400362918"}
0005434979483	4CABBC	5649 124595	YURIY ALEKSEEV	{"phone": "+70259197126"}
0005434979484	4CABBC	6007 377578	TAISIYA ERMAKOVA	{"phone": "+70372871551"}
0005434979485	62DBEC	7454 678905	VERA MALYSHEVA	{"phone": "+70283068019"}
0005434979486	E76F40	7476 823168	LYUBOV NOVIKOVA	{"email": "novikova-lyubov.08041974@postgrespro.ru", "phone": "+70159265689"}
0005434979487	54CD40	1793 421119	ALEKSANDR SEMENOV	{"email": "semenov-a_03101974@postgrespro.ru", "phone": "+70122723414"}
0005434979488	DF1B1A	1045 127284	SERGEY MATVEEV	{"email": "matveevsergey.011968@postgrespro.ru", "phone": "+70370415522"}
0005434979489	DF1B1A	4018 590352	ALEKSANDR IVANOV	{"phone": "+70011058148"}
0005434979490	DF1B1A	0050 336914	EKATERINA POLYAKOVA	{"phone": "+70152569304"}
0005434979491	A56727	9830 430044	ALEKSANDR MAKSIMOV	{"email": "maksimov_a_24091973@postgrespro.ru", "phone": "+70017327038"}
0005434979492	4D3561	6150 321390	VADIM SHEVCHENKO	{"email": "shevchenkov_19101977@postgrespro.ru", "phone": "+70972375359"}
0005434979493	4C2B8C	4304 536476	ANASTASIYA BORISOVA	{"phone": "+70554151364"}
0005434979494	4C2B8C	4203 588757	VARVARA VASILEVA	{"email": "vasilevavarvara1977@postgrespro.ru", "phone": "+70967820804"}
0005434979495	4C2B8C	4402 445228	ELENA SERGEEVA	{"phone": "+70185096293"}
0005434979496	3403B8	5668 723133	SERGEY NIKITIN	{"email": "nikitins27051970@postgrespro.ru", "phone": "+70947318422"}
0005434979497	1C7543	1677 047904	SERGEY IVANOV	{"email": "sergey.ivanov.031977@postgrespro.ru", "phone": "+70534631466"}
0005434979498	A03BA7	7881 612076	DMITRIY KOROLEV	{"email": "korolev-dmitriy.1968@postgrespro.ru", "phone": "+70897657335"}
0005434979499	7546FF	7637 724703	DENIS PAVLOV	{"phone": "+70688628709"}
0005434979500	DB6CC4	2612 376944	YURIY ZAKHAROV	{"phone": "+70635177018"}
0005434979501	BC4CE2	3922 483245	NIKITA PETROV	{"email": "n.petrov_12051974@postgrespro.ru", "phone": "+70387712068"}
0005434979502	B1F34F	8447 058836	PETR MIRONOV	{"phone": "+70237741257"}
0005434979503	5FAB48	9448 941969	YURIY ANDREEV	{"phone": "+70053838386"}
0005434979504	BAB213	5322 630031	SVETLANA LOGINOVA	{"email": "loginovas.121961@postgrespro.ru", "phone": "+70814711284"}
0005434979505	99FBC4	4428 950300	NIKOLAY KUZNECOV	{"email": "kuznecov_n051971@postgrespro.ru", "phone": "+70214266606"}
0005434979506	99FBC4	2872 835528	NATALYA SERGEEVA	{"phone": "+70793355685"}
0005434979507	5EC0C9	5459 366396	STEPAN KUZNECOV	{"email": "kuznecov_s101976@postgrespro.ru", "phone": "+70472910427"}
0005434979508	F80762	2034 358103	ALEKSANDRA KOROLEVA	{"phone": "+70030295573"}
0005434979509	DDE235	1985 850130	POLINA IVANOVA	{"phone": "+70207432853"}
0005434979510	B8E03A	2694 383833	SVETLANA ROMANOVA	{"phone": "+70021988689"}
0005434979511	38DE2A	5267 472732	GENNADIY SOKOLOV	{"phone": "+70262566610"}
0005434979512	38DE2A	2245 953671	EVGENIY CHERNOV	{"phone": "+70757365720"}
0005434979513	E88D30	0072 871935	RUSLAN PAVLOV	{"email": "ruslanpavlov.10041972@postgrespro.ru", "phone": "+70601383011"}
0005434979514	4E7713	1312 530349	NATALYA SEMENOVA	{"phone": "+70761332750"}
0005434979515	2B8A86	3472 896001	OLGA SOLOVEVA	{"phone": "+70988611131"}
0005434979516	2B8A86	3661 932138	GALINA MATVEEVA	{"phone": "+70043857888"}
0005434979517	747FCE	3740 200990	EKATERINA ZAKHAROVA	{"email": "e-zakharova111963@postgrespro.ru", "phone": "+70536204822"}
0005434979518	746A23	0425 241000	MAKSIM BORISOV	{"email": "borisov-maksim.111963@postgrespro.ru", "phone": "+70873888587"}
0005434979519	3FE37A	4212 345210	GALINA EGOROVA	{"phone": "+70272787433"}
0005434979520	3FE37A	8105 860781	OLGA DMITRIEVA	{"email": "dmitrieva_o-071967@postgrespro.ru", "phone": "+70203894309"}
0005434979521	11C351	7863 103962	SERGEY ISAEV	{"phone": "+70289012019"}
0005434979522	175279	4909 476141	VLADIMIR BORISOV	{"phone": "+70019812420"}
0005434979523	175279	0065 527975	POLINA DAVYDOVA	{"email": "p.davydova12091965@postgrespro.ru", "phone": "+70946498808"}
0005434979524	B1C1C5	6428 324766	ILYA FROLOV	{"email": "frolov_ilya-1969@postgrespro.ru", "phone": "+70348556586"}
0005434979525	8E5FB4	8270 221684	KAMIL POPOV	{"email": "kpopov-1973@postgrespro.ru", "phone": "+70031090262"}
0005434979526	A639D7	1414 143817	ALEKSANDR PAVLOV	{"phone": "+70796361426"}
0005434979527	A639D7	7641 951267	VIKTORIYA MOROZOVA	{"email": "morozova_v_28031974@postgrespro.ru", "phone": "+70057130006"}
0005434979528	A639D7	2328 199089	ALEKSANDR SEMENOV	{"email": "asemenov.16101969@postgrespro.ru", "phone": "+70252894603"}
0005434979529	7179A6	8907 617269	VLADIMIR MARTYNOV	{"phone": "+70835094016"}
0005434979530	51E47E	0815 351723	IRINA EGOROVA	{"email": "irina_egorova29081977@postgrespro.ru", "phone": "+70064114878"}
0005434979531	853A2A	1814 949990	VALENTINA POPOVA	{"email": "popova-valentina_1973@postgrespro.ru", "phone": "+70067772967"}
0005434979532	7F5DE5	9724 630011	NIKOLAY SERGEEV	{"email": "nikolay.sergeev-03021967@postgrespro.ru", "phone": "+70547266497"}
0005434979533	7F5DE5	7002 713894	VIKTOR KUZNECOV	{"email": "kuznecov.viktor_1972@postgrespro.ru", "phone": "+70535557693"}
0005434979534	7F5DE5	2084 445261	IVAN CHERNOV	{"phone": "+70479739470"}
0005434979535	F56B9A	5685 306663	ALEKSANDR DAVYDOV	{"email": "aleksandr_davydov1982@postgrespro.ru", "phone": "+70702657856"}
0005434979536	42031B	5400 380471	VALERIYA FROLOVA	{"phone": "+70468165139"}
0005434979537	42031B	5166 733487	OLGA YAKOVLEVA	{"phone": "+70363344896"}
0005434979538	42031B	6776 417693	ROMAN MAKAROV	{"phone": "+70987354454"}
0005434979539	F3F153	7020 903742	DMITRIY SMIRNOV	{"phone": "+70058516619"}
0005434979540	F3F153	7485 598434	GENNADIY IVANOV	{"phone": "+70292586036"}
0005434979541	7B36A2	7949 721140	KONSTANTIN DAVYDOV	{"phone": "+70518247631"}
0005434979542	7B36A2	3452 146856	GALINA MAKSIMOVA	{"phone": "+70073176197"}
0005434979543	57FF42	5149 413970	VALENTIN KONOVALOV	{"email": "konovalov-v_25041982@postgrespro.ru", "phone": "+70664069880"}
0005434979544	B7E90E	1203 974700	VERA TARASOVA	{"email": "vtarasova29051985@postgrespro.ru", "phone": "+70535217280"}
0005434979545	3A1639	4666 390566	RAVIL SCHERBAKOV	{"email": "scherbakov_ravil021975@postgrespro.ru", "phone": "+70385534435"}
0005434979546	AF645C	5144 757397	ALINA IVANOVA	{"phone": "+70636674617"}
0005434979547	602C57	2706 807922	SERGEY PETROV	{"phone": "+70826454770"}
0005434979548	4FD070	3715 479096	NATALYA ZAYCEVA	{"phone": "+70909608833"}
0005434979549	4FD070	4607 915326	NIKOLAY MOROZOV	{"email": "morozov_n1963@postgrespro.ru", "phone": "+70271890519"}
0005434979550	7E1DB1	9233 291875	VIKTOR VLASOV	{"email": "vlasov_v_1973@postgrespro.ru", "phone": "+70707346864"}
0005434979551	7E1DB1	4129 827915	ILYA AFANASEV	{"phone": "+70364717339"}
0005434979552	29E6D8	8335 486978	ELENA KONDRATEVA	{"email": "kondrateva_elena_28051978@postgrespro.ru", "phone": "+70976985149"}
0005434979553	A632F8	7791 957493	EVGENIYA TIKHONOVA	{"phone": "+70484151443"}
0005434979554	ADD35F	5809 129369	LEONID NIKITIN	{"phone": "+70431146346"}
0005434979555	939196	9007 522747	NATALYA SMIRNOVA	{"email": "smirnova-natalya101963@postgrespro.ru", "phone": "+70825798011"}
0005434979556	47F861	5383 206844	IRINA ILINA	{"email": "ilinai.31011980@postgrespro.ru", "phone": "+70592017704"}
0005434979557	31832C	9014 769671	MARINA AFANASEVA	{"phone": "+70861711445"}
0005434979558	72A557	3194 052715	EVGENIY CHERNOV	{"phone": "+70793640910"}
0005434979559	CE3E40	5589 500681	SERGEY KUZNECOV	{"email": "sergey-kuznecov.1973@postgrespro.ru", "phone": "+70646166537"}
0005434979560	D35628	9575 155918	ELENA GORBUNOVA	{"phone": "+70674153694"}
0005434979561	D35628	5467 775371	MARINA SOLOVEVA	{"phone": "+70915639076"}
0005434979562	3292EA	5405 785507	RIMMA POPOVA	{"phone": "+70731388004"}
0005434979563	96DB8B	3300 213018	PAVEL POPOV	{"email": "popovp121964@postgrespro.ru", "phone": "+70259634344"}
0005434979564	790F99	9264 894197	YULIYA TARASOVA	{"phone": "+70858880173"}
0005434979565	30097F	7038 336558	GALINA KAZAKOVA	{"email": "g.kazakova-23121979@postgrespro.ru", "phone": "+70424600917"}
0005434979566	A8731C	6013 260802	MARINA DANILOVA	{"phone": "+70757801531"}
0005434979567	D0F48A	4228 585241	MIKHAIL TIMOFEEV	{"phone": "+70165312917"}
0005434979568	6B227A	0102 261651	EVGENIY TIKHONOV	{"phone": "+70332108072"}
0005434979569	3EBA3A	2616 483915	MARIYA TROFIMOVA	{"phone": "+70841978962"}
0005434979570	7941A2	7690 816774	EKATERINA NESTEROVA	{"email": "ekaterinanesterova_1976@postgrespro.ru", "phone": "+70659064492"}
0005434979571	FBD882	5979 818444	EKATERINA KOROLEVA	{"email": "e.koroleva-26051967@postgrespro.ru", "phone": "+70758766693"}
0005434979572	FBD882	6993 117179	EKATERINA KOZLOVA	{"email": "e.kozlova.041975@postgrespro.ru", "phone": "+70341459084"}
0005434979573	40CB57	6104 093069	EVGENIYA MOROZOVA	{"email": "e_morozova_081972@postgrespro.ru", "phone": "+70499469236"}
0005434979574	E83724	2054 708369	VLADIMIR NIKITIN	{"phone": "+70743536750"}
0005434979575	E83724	7501 409500	NATALYA SCHERBAKOVA	{"email": "n.scherbakova.051968@postgrespro.ru", "phone": "+70465041206"}
0005434979576	E83724	4120 956806	ALEKSANDR BORISOV	{"email": "aleksandr-borisov-1969@postgrespro.ru", "phone": "+70600076282"}
0005434979577	EB90DB	3671 679496	IRINA KUZNECOVA	{"email": "irinakuznecova17041960@postgrespro.ru", "phone": "+70564288903"}
0005434979578	D1DA2F	2517 975959	SERGEY VOROBEV	{"phone": "+70564463312"}
0005434979579	C6B3D9	8171 510373	NATALYA AFANASEVA	{"phone": "+70442004162"}
0005434979580	C761F3	6326 387293	KRISTINA SMIRNOVA	{"phone": "+70586840729"}
0005434979581	C761F3	5712 650133	LYUBOV FILATOVA	{"phone": "+70399253082"}
0005434979582	1CDFDA	2792 053502	ALLA IVANOVA	{"phone": "+70911687635"}
0005434979583	1CDFDA	6533 119959	EMIL ZAYCEV	{"email": "emilzaycev.1966@postgrespro.ru", "phone": "+70723811966"}
0005434979584	5554EA	0091 839903	EVGENIY POPOV	{"phone": "+70866616478"}
0005434979585	035677	2253 931404	BORIS IVANOV	{"email": "ivanovboris-1977@postgrespro.ru", "phone": "+70366575656"}
0005434979586	035677	1632 204676	ANDREY ZAKHAROV	{"phone": "+70427782561"}
0005434979587	035677	0324 164652	LEONID POPOV	{"phone": "+70532659861"}
0005434979588	0E110D	3973 886113	SVETLANA IVANOVA	{"email": "ivanova.svetlana.19081967@postgrespro.ru", "phone": "+70117610015"}
0005434979589	5EE907	2833 456242	ALINA MOROZOVA	{"email": "amorozova-1966@postgrespro.ru", "phone": "+70190484410"}
0005434979590	5EE907	4364 438152	IGOR NOVIKOV	{"phone": "+70317160193"}
0005434979591	5EE907	3948 730541	ALEKSEY FEDOROV	{"phone": "+70627845019"}
0005434979592	4C0887	4693 285516	NIKITA SHEVCHENKO	{"email": "n-shevchenko-12111974@postgrespro.ru", "phone": "+70840493436"}
0005434979593	4C0887	4827 645115	EKATERINA PAVLOVA	{"email": "pavlova_ekaterina.091971@postgrespro.ru", "phone": "+70861021296"}
0005434979594	4C0887	7611 192272	ALEKSANDR VOLKOV	{"email": "volkov-aleksandr.26111967@postgrespro.ru", "phone": "+70727806314"}
0005434979595	9DBC25	2143 070576	IGOR ZHUKOV	{"phone": "+70581728934"}
0005434979596	012303	9289 497609	LYUBOV KAZAKOVA	{"phone": "+70914093004"}
0005434979597	1D9C58	3930 090356	ANASTASIYA KAZAKOVA	{"email": "kazakova.a_071963@postgrespro.ru", "phone": "+70187633953"}
0005434979598	B184E1	0483 971030	LYUDMILA BORISOVA	{"email": "borisova_l_011979@postgrespro.ru", "phone": "+70559507002"}
0005434979599	D05B06	2000 743347	ALEKSANDR ZHUKOV	{"phone": "+70703903373"}
0005434979600	A0B86B	1676 346669	ARSENIY MATVEEV	{"email": "amatveev.1969@postgrespro.ru", "phone": "+70077916878"}
0005434979601	A0B86B	0940 254215	EVGENIY ISAEV	{"email": "isaev_evgeniy081969@postgrespro.ru", "phone": "+70311252088"}
0005434979602	4F759B	7020 455661	IRINA PETROVA	{"email": "petrova_i.061967@postgrespro.ru", "phone": "+70287364561"}
0005434979603	4F759B	0826 150696	GENNADIY PETROV	{"email": "gennadiypetrov-091979@postgrespro.ru", "phone": "+70193370414"}
0005434979604	5C5A7D	0291 029807	SNEZHANA IVANOVA	{"phone": "+70701090987"}
0005434979605	C02FB1	6659 506761	ALEKSANDR PETROV	{"email": "apetrov-111960@postgrespro.ru", "phone": "+70570390666"}
0005434979606	726B96	7343 916291	ARTUR MELNIKOV	{"email": "a_melnikov_011966@postgrespro.ru", "phone": "+70663604455"}
0005434979607	FC78FC	1208 468377	EVGENIY ALEKSANDROV	{"phone": "+70801039416"}
0005434979608	97112D	7545 858046	TATYANA MIKHAYLOVA	{"email": "mikhaylova-t.01121970@postgrespro.ru", "phone": "+70154056029"}
0005434979609	3AE493	5225 636882	SVETLANA GUSEVA	{"email": "sguseva_22031979@postgrespro.ru", "phone": "+70713064808"}
0005434979610	3C60B9	4701 316153	SERGEY SCHERBAKOV	{"email": "scherbakov.s.111977@postgrespro.ru", "phone": "+70560183250"}
0005434979611	3C60B9	2540 872349	EVGENIY FEDOROV	{"email": "fedorov-e-121978@postgrespro.ru", "phone": "+70030700119"}
0005434979612	A620D3	3998 127926	LYUDMILA FADEEVA	{"phone": "+70250334565"}
0005434979613	745DC5	1414 885873	NATALYA SOROKINA	{"phone": "+70264967934"}
0005434979614	745DC5	4346 588535	ELENA EGOROVA	{"phone": "+70212849936"}
0005434979615	861E08	3798 728835	YULIYA MAKSIMOVA	{"phone": "+70203606682"}
0005434979616	824CFA	2501 921313	IVAN MIRONOV	{"phone": "+70395521197"}
0005434979617	882C40	1292 717993	VITALIY ALEKSEEV	{"phone": "+70936582236"}
0005434979618	67C860	8062 475687	ARTEMIY NAZAROV	{"email": "nazarov.artemiy-02041971@postgrespro.ru", "phone": "+70092255493"}
0005434979619	4B8883	2783 002988	INGA RYABOVA	{"phone": "+70466680805"}
0005434979620	FA4099	1074 830983	LYUDMILA FADEEVA	{"email": "lyudmila_fadeeva.09071963@postgrespro.ru", "phone": "+70382070081"}
0005434979621	FA4099	4164 751507	NATALYA SMIRNOVA	{"phone": "+70610294748"}
0005434979622	4E7000	3490 639010	VLADIMIR KISELEV	{"phone": "+70316861077"}
0005434979623	C02EB0	4926 526009	ANNA PAVLOVA	{"email": "pavlova.anna-111988@postgrespro.ru", "phone": "+70748727315"}
0005434979624	3FBF48	8866 248853	MIKHAIL VLASOV	{"email": "m.vlasov.1967@postgrespro.ru", "phone": "+70031653758"}
0005434979625	F5221C	5285 602637	FANIL KUDRYASHOV	{"phone": "+70444954767"}
0005434979626	F5221C	0156 895700	EKATERINA SAVELEVA	{"email": "saveleva.ekaterina121968@postgrespro.ru", "phone": "+70078974046"}
0005434979627	A7BB72	6776 374274	EGOR YAKOVLEV	{"email": "egor-yakovlev-07021964@postgrespro.ru", "phone": "+70802664152"}
0005434979628	A7BB72	7285 885119	OLEG ZAKHAROV	{"phone": "+70864090291"}
0005434979629	96950B	6895 183556	MARIYA EFIMOVA	{"email": "m-efimova.13011974@postgrespro.ru", "phone": "+70405825267"}
0005434979630	31C131	0132 118167	FATIMA NIKITINA	{"email": "nikitinaf-1974@postgrespro.ru", "phone": "+70593227174"}
0005434979631	31C131	8171 677538	DMITRIY GRIGOREV	{"email": "grigorev_dmitriy_1962@postgrespro.ru", "phone": "+70980096155"}
0005434979632	9FA027	0482 741696	VALENTINA FROLOVA	{"email": "v.frolova-031968@postgrespro.ru", "phone": "+70723212260"}
0005434979633	9FA027	7439 858747	NIKITA ANDREEV	{"phone": "+70041983339"}
0005434979634	C1FD7C	3847 312904	ARTEM BORISOV	{"phone": "+70582946044"}
0005434979635	C1FD7C	8720 963253	LYUBOV CHERNOVA	{"email": "lyubov-chernova.021970@postgrespro.ru", "phone": "+70825099467"}
0005434979636	D6EDCB	0672 159234	MARIYA EGOROVA	{"email": "mariya.egorova_111968@postgrespro.ru", "phone": "+70494584767"}
0005434979637	D6EDCB	0103 839780	NATALYA ANTONOVA	{"email": "antonova.n_1977@postgrespro.ru", "phone": "+70966129104"}
0005434979638	CBA524	9563 248963	ALLA ANTONOVA	{"phone": "+70185914037"}
0005434979639	CBA524	8645 645678	EVGENIY ALEKSANDROV	{"email": "evgeniyaleksandrov_09101977@postgrespro.ru", "phone": "+70149399430"}
0005434979640	776743	1369 070503	SERGEY SOLOVEV	{"phone": "+70572321287"}
0005434979641	776743	3902 269281	YURIY TIMOFEEV	{"phone": "+70277736565"}
0005434979642	DA6472	7162 913282	MARINA MASLOVA	{"email": "maslova-marina.1976@postgrespro.ru", "phone": "+70168131960"}
0005434979643	03F4C2	0389 764299	VALERIY NAUMOV	{"phone": "+70101023052"}
0005434979644	184BCF	7217 931443	NINA MATVEEVA	{"phone": "+70679297409"}
0005434979645	184BCF	5934 139637	EKATERINA KOMAROVA	{"phone": "+70941978670"}
0005434979646	C2778B	8527 559498	VLADIMIR NIKOLAEV	{"email": "v.nikolaev021985@postgrespro.ru", "phone": "+70528380393"}
0005434979647	C2778B	4910 360119	IRINA GUSEVA	{"phone": "+70284511314"}
0005434979648	C2778B	8218 222497	ALLA ILINA	{"email": "ilina-alla-23051978@postgrespro.ru", "phone": "+70711441186"}
0005434979649	B5B781	1106 032197	ALEKSANDR STEPANOV	{"email": "stepanov_aleksandr-27111989@postgrespro.ru", "phone": "+70019087928"}
0005434979650	B4455B	8052 335928	ARTEM SCHERBAKOV	{"email": "artem_scherbakov1969@postgrespro.ru", "phone": "+70618186957"}
0005434979651	B4455B	4000 134223	SERGEY BARANOV	{"phone": "+70103664672"}
0005434979652	B6FB7B	0780 188188	TIMUR VOROBEV	{"email": "t.vorobev081974@postgrespro.ru", "phone": "+70454776639"}
0005434979653	D36C3C	1453 943747	ALEKSANDR ORLOV	{"phone": "+70416408448"}
0005434979654	4E94AF	2957 090618	DMITRIY FOMIN	{"email": "fomin_d1982@postgrespro.ru", "phone": "+70237056033"}
0005434979655	15269D	7510 475505	VIKTOR MOROZOV	{"email": "vmorozov-23061969@postgrespro.ru", "phone": "+70672897070"}
0005434979656	ECE491	5567 363560	ILYA VASILEV	{"email": "vasilev_i1972@postgrespro.ru", "phone": "+70064235611"}
0005434979657	327552	3050 710920	MARINA TITOVA	{"phone": "+70950000168"}
0005434979658	98EDD7	7598 088286	VERA DENISOVA	{"phone": "+70206273296"}
0005434979659	5F8610	4172 813762	ZINAIDA YAKOVLEVA	{"phone": "+70754832343"}
0005434979660	6C14A3	8599 399079	ANDREY MEDVEDEV	{"email": "medvedeva-111959@postgrespro.ru", "phone": "+70928677201"}
0005434979661	6C14A3	4922 734333	ZOYA AFANASEVA	{"phone": "+70213464506"}
0005434979662	6C14A3	2767 764396	LILIYA KAZAKOVA	{"email": "l_kazakova-06081964@postgrespro.ru", "phone": "+70369881165"}
0005434979663	A7CF34	1735 509011	VALERIY SMIRNOV	{"email": "smirnov_valeriy-31051973@postgrespro.ru", "phone": "+70777302003"}
0005434979664	298FE9	8257 700724	SVETLANA ZAKHAROVA	{"phone": "+70420767434"}
0005434979665	75E997	3907 433708	ZINAIDA KALININA	{"phone": "+70874429849"}
0005434979666	75E997	5539 117343	ANATOLIY DMITRIEV	{"phone": "+70371423232"}
0005434979667	6D2FD9	2491 041298	MARGARITA DENISOVA	{"phone": "+70209347304"}
0005434979668	6D2FD9	7209 532975	IRINA VLASOVA	{"email": "i.vlasova_091966@postgrespro.ru", "phone": "+70700642446"}
0005434979669	70A664	7104 814979	FAINA SOKOLOVA	{"phone": "+70261585147"}
0005434979670	70A664	3772 100830	VALENTINA BORISOVA	{"email": "borisovav-1983@postgrespro.ru", "phone": "+70810090923"}
0005434979671	70A664	0658 564944	OLGA MOROZOVA	{"email": "olga_morozova111969@postgrespro.ru", "phone": "+70424421165"}
0005434979672	511B4D	7778 791565	ANATOLIY SEMENOV	{"phone": "+70412079251"}
0005434979673	F52F30	7702 279747	VALENTINA NIKOLAEVA	{"email": "v-nikolaeva021978@postgrespro.ru", "phone": "+70880797053"}
0005434979674	F52F30	6397 456159	NINA ALEKSEEVA	{"email": "alekseeva_nina-1979@postgrespro.ru", "phone": "+70744481794"}
0005434979675	71F94B	5006 476082	YURIY ANTONOV	{"email": "antonov_y_121982@postgrespro.ru", "phone": "+70703715877"}
0005434979676	13629E	4602 049239	ALEKSEY NAUMOV	{"email": "naumov_aleksey-28121974@postgrespro.ru", "phone": "+70404659296"}
0005434979677	7E9BB1	5739 245230	LYUBOV BARANOVA	{"email": "l-baranova.121972@postgrespro.ru", "phone": "+70740555895"}
0005434979678	0603A3	3867 415435	SERGEY KUZNECOV	{"email": "kuznecov.sergey-10061964@postgrespro.ru", "phone": "+70952694761"}
0005434979679	0603A3	9613 560228	VLADIMIR POPOV	{"email": "vladimir-popov051983@postgrespro.ru", "phone": "+70984885610"}
0005434979680	190A6B	2033 872664	ALEKSEY KUZNECOV	{"phone": "+70486616507"}
0005434979681	190A6B	8390 650805	VYACHESLAV GORBUNOV	{"email": "v.gorbunov_10021970@postgrespro.ru", "phone": "+70867189654"}
0005434979682	190A6B	2796 912460	MATVEY GERASIMOV	{"phone": "+70348270707"}
0005434979683	B3C064	4525 067566	ANASTASIYA ISAEVA	{"email": "a_isaeva-03121965@postgrespro.ru", "phone": "+70279389164"}
0005434979684	A688BA	2245 402483	YULIYA ERMAKOVA	{"email": "ermakova_y-15021965@postgrespro.ru", "phone": "+70410562543"}
0005434979685	B7F03A	2792 784266	IRINA FOMINA	{"email": "fomina.irina_07061969@postgrespro.ru", "phone": "+70339480415"}
0005434979686	B7F03A	3195 663412	VALENTINA ALEKSANDROVA	{"phone": "+70431771187"}
0005434979687	A26A60	7271 052556	YULIYA SEMENOVA	{"phone": "+70998672895"}
0005434979688	718F16	6883 456705	LYUBOV BOGDANOVA	{"email": "bogdanova_lyubov-1967@postgrespro.ru", "phone": "+70508633599"}
0005434979689	718F16	3921 835539	SERGEY MAKSIMOV	{"email": "maksimovs.041975@postgrespro.ru", "phone": "+70502511969"}
0005434979690	95585D	2003 121085	ANNA FOMINA	{"email": "a.fomina.051973@postgrespro.ru", "phone": "+70430460769"}
0005434979691	95585D	3204 425304	VLADISLAV KARPOV	{"email": "karpov_vladislav.111971@postgrespro.ru", "phone": "+70036764545"}
0005434979692	7F16E0	0971 071606	YURIY MOISEEV	{"email": "yuriy-moiseev.23091968@postgrespro.ru", "phone": "+70879163271"}
0005434979693	7F16E0	1853 021125	VLADIMIR SOROKIN	{"email": "vladimir-sorokin-30111964@postgrespro.ru", "phone": "+70708088126"}
0005434979694	AF61E2	6559 102684	ALEKSANDR ANDREEV	{"email": "andreeva081976@postgrespro.ru", "phone": "+70008045429"}
0005434979695	125474	2597 829905	EKATERINA ILINA	{"phone": "+70641906097"}
0005434979696	125474	8200 588544	LYUBOV MELNIKOVA	{"email": "melnikova_lyubov-031984@postgrespro.ru", "phone": "+70637480945"}
0005434979697	9D191F	2187 332113	OLGA DENISOVA	{"email": "odenisova_101964@postgrespro.ru", "phone": "+70197050159"}
0005434979698	9D191F	5203 717932	NATALYA VOLKOVA	{"email": "volkova.natalya-081961@postgrespro.ru", "phone": "+70894224120"}
0005434979699	C4C1F6	2298 796340	ALEKSANDR POPOV	{"phone": "+70601646663"}
0005434979700	C4C1F6	5675 959287	ARSEN KOZLOV	{"phone": "+70183468868"}
0005434979701	749F56	9078 418907	ARTEM NIKITIN	{"phone": "+70367336499"}
0005434979702	0D8A88	7130 080942	EKATERINA POPOVA	{"phone": "+70247367220"}
0005434979703	D36702	5105 232451	TATYANA DENISOVA	{"email": "denisova_tatyana071967@postgrespro.ru", "phone": "+70234706723"}
0005434979704	0F5120	9490 598970	DARYA BORISOVA	{"email": "borisovadarya041973@postgrespro.ru", "phone": "+70861721470"}
0005434979705	0F5120	1598 520245	MAKSIM KUZNECOV	{"phone": "+70368601644"}
0005434979706	430E9E	2942 397717	TATYANA TIKHONOVA	{"phone": "+70365611685"}
0005434979707	430E9E	1519 444585	ANASTASIYA KARPOVA	{"email": "anastasiya.karpova-1978@postgrespro.ru", "phone": "+70077531531"}
0005434979708	6212A4	1168 633773	LEV MEDVEDEV	{"email": "l.medvedev-1978@postgrespro.ru", "phone": "+70224547327"}
0005434979709	1C9859	5399 907807	NIKOLAY KOZLOV	{"phone": "+70757479316"}
0005434979710	1C9859	5843 151385	YULIYA NAZAROVA	{"phone": "+70166975646"}
0005434979711	A2BC21	9379 230987	OLGA KOMAROVA	{"email": "olga-komarova-06091970@postgrespro.ru", "phone": "+70015337993"}
0005434979712	1A90F7	3550 492903	RUMIYA KUDRYASHOVA	{"email": "rumiyakudryashova1972@postgrespro.ru", "phone": "+70331783445"}
0005434979713	1A90F7	5977 131780	ELIZAVETA ARKHIPOVA	{"phone": "+70191864144"}
0005434979714	BFD28A	7715 679137	GALINA DENISOVA	{"email": "denisova.galina_1960@postgrespro.ru", "phone": "+70530964664"}
0005434979715	0C6757	3498 458578	OLGA TIMOFEEVA	{"email": "o.timofeeva.071957@postgrespro.ru", "phone": "+70278880659"}
0005434979716	ACB93C	7764 246900	DANIIL MAKAROV	{"email": "makarovdaniil-011972@postgrespro.ru", "phone": "+70232281210"}
0005434979717	CC6657	5132 396435	ANDREY FEDOROV	{"phone": "+70048620270"}
0005434979718	CC6657	5145 399290	VIKTORIYA TIKHONOVA	{"phone": "+70527666289"}
0005434979719	F8EA94	1478 200558	ANISA SERGEEVA	{"email": "sergeeva-a-15011977@postgrespro.ru", "phone": "+70399188393"}
0005434979720	F8EA94	3305 144117	KLAVDIYA POLYAKOVA	{"phone": "+70735624675"}
0005434979721	A1428D	3419 326725	IRINA FOMINA	{"phone": "+70678815242"}
0005434979722	33BA1D	8121 646334	ALBINA LEBEDEVA	{"email": "a_lebedeva1966@postgrespro.ru", "phone": "+70309263078"}
0005434979723	47B5B6	3732 924826	ALEKSANDR GUSEV	{"email": "aleksandrgusev-1967@postgrespro.ru", "phone": "+70524556530"}
0005434979724	B69DF2	3142 422818	NATALYA VOROBEVA	{"phone": "+70610742330"}
0005434979725	B69DF2	1849 290448	VLADIMIR KUDRYASHOV	{"email": "kudryashov_v.1986@postgrespro.ru", "phone": "+70426742183"}
0005434979726	DAA857	9249 657598	ANTONINA ALEKSEEVA	{"phone": "+70255068651"}
0005434979727	1F72AC	8464 773704	GALINA ROMANOVA	{"phone": "+70061203605"}
0005434979728	FEAED4	3338 042454	OKSANA ANTONOVA	{"phone": "+70303292497"}
0005434979729	0C1CF5	2950 548276	YURIY FROLOV	{"email": "yuriyfrolov-111982@postgrespro.ru", "phone": "+70274163586"}
0005434979730	0C1CF5	9883 427925	ANATOLIY KUZNECOV	{"email": "kuznecova.041961@postgrespro.ru", "phone": "+70939967400"}
0005434979731	F573FD	6125 084664	ELENA LAZAREVA	{"email": "elazareva_051980@postgrespro.ru", "phone": "+70781495133"}
0005434979732	9EC1FA	5718 943599	VERA CHERNOVA	{"email": "vera-chernova.081975@postgrespro.ru", "phone": "+70952357729"}
0005434979733	5238B4	4972 764501	IGOR TIKHONOV	{"phone": "+70151113750"}
0005434979734	5238B4	9801 749345	VLADIMIR PAVLOV	{"email": "pavlov_vladimir_24031985@postgrespro.ru", "phone": "+70743481975"}
0005434979735	850629	7689 285485	TATYANA ORLOVA	{"phone": "+70321102464"}
0005434979736	64B4A7	3083 583365	DMITRIY GERASIMOV	{"phone": "+70738089315"}
0005434979737	CD7E70	7835 473853	STANISLAV ALEKSANDROV	{"phone": "+70596485786"}
0005434979738	A9E141	0702 772118	VIKTOR IVANOV	{"email": "ivanov_viktor081964@postgrespro.ru", "phone": "+70008398953"}
0005434979739	AB1FF9	6979 855975	ARINA KISELEVA	{"phone": "+70901862544"}
0005434979740	AB1FF9	9412 410724	ANDREY KUZNECOV	{"phone": "+70709921132"}
0005434979741	DC8C6C	0747 030497	TATYANA NESTEROVA	{"email": "tatyana_nesterova-1976@postgrespro.ru", "phone": "+70464736511"}
0005434979742	4EF888	6998 966220	ALEKSANDRA BORISOVA	{"email": "aborisova29051968@postgrespro.ru", "phone": "+70029662392"}
0005434979743	4EF888	8379 135882	KARINA LOGINOVA	{"email": "k.loginova1972@postgrespro.ru", "phone": "+70836291510"}
0005434979744	0554C4	3240 733594	ANGELINA KOROLEVA	{"email": "angelina-koroleva23031969@postgrespro.ru", "phone": "+70030999575"}
0005434979745	9D5F70	1495 372941	INNA YAKOVLEVA	{"phone": "+70539167876"}
0005434979746	9D5F70	9360 365718	ALEKSANDR VASILEV	{"email": "avasilev-16121969@postgrespro.ru", "phone": "+70039569565"}
0005434979747	BE2CCD	9494 958694	VLADIMIR ROMANOV	{"email": "romanovv_051972@postgrespro.ru", "phone": "+70909493568"}
0005434979748	AD6EC5	7171 757644	MARIYA ANISIMOVA	{"email": "anisimovamariya1978@postgrespro.ru", "phone": "+70627229034"}
0005434979749	0099A2	9720 630488	SERGEY KUZNECOV	{"email": "kuznecov_sergey-01111970@postgrespro.ru", "phone": "+70814926569"}
0005434979750	85B0B9	9414 346033	YANA MAKAROVA	{"phone": "+70499237575"}
0005434979751	C69B90	2739 653559	SERGEY DMITRIEV	{"email": "dmitriev-s_1972@postgrespro.ru", "phone": "+70716964366"}
0005434979752	C69B90	7279 323304	MARINA ANDREEVA	{"email": "m.andreeva.27061980@postgrespro.ru", "phone": "+70866822307"}
0005434979753	00823B	9971 313298	ALEKSEY MAKSIMOV	{"phone": "+70034296091"}
0005434979754	12E905	4565 289874	NIKOLAY KUZNECOV	{"phone": "+70172697297"}
0005434979755	12E905	2958 777301	TATYANA OSIPOVA	{"email": "tatyana-osipova111964@postgrespro.ru", "phone": "+70075613928"}
0005434979756	5941FB	5378 720788	SERGEY BELOV	{"email": "s.belov1969@postgrespro.ru", "phone": "+70013782024"}
0005434979757	5941FB	6584 105593	RAISA AKIMOVA	{"phone": "+70802710635"}
0005434979758	314F09	1043 277813	IGOR GRIGOREV	{"email": "grigorev-i24021960@postgrespro.ru", "phone": "+70812563536"}
0005434979759	8B9C05	8923 479957	ARINA ROMANOVA	{"phone": "+70384088997"}
0005434979760	8B9C05	2703 569510	VIKTORIYA POPOVA	{"phone": "+70890400911"}
0005434979761	D4BCFD	4828 881456	DMITRIY BORISOV	{"email": "dmitriyborisov.101974@postgrespro.ru", "phone": "+70890878775"}
0005434979762	CC0052	0093 791519	TATYANA VASILEVA	{"email": "vasileva-tatyana051970@postgrespro.ru", "phone": "+70461348208"}
0005434979763	CC0052	3902 794743	VALERIY KRASNOV	{"phone": "+70312706050"}
0005434979764	A74228	4152 842327	VLADIMIR NAZAROV	{"email": "vnazarov1962@postgrespro.ru", "phone": "+70970075456"}
0005434979765	A74228	4159 973088	NIKITA SOLOVEV	{"phone": "+70678520475"}
0005434979766	DD5D67	7091 111505	SERGEY TIKHONOV	{"phone": "+70537579203"}
0005434979767	C3DEEB	7769 265548	ANDREY KUZNECOV	{"phone": "+70991182059"}
0005434979768	C3DEEB	2770 751721	ANNA GORBUNOVA	{"phone": "+70331987202"}
0005434979769	479483	0347 588671	ANATOLIY GUSEV	{"email": "anatoliy-gusev.1967@postgrespro.ru", "phone": "+70879307116"}
0005434979770	479483	5585 740997	OLGA FOMINA	{"phone": "+70443817003"}
0005434979771	AC0550	6949 031928	VASILIY PAVLOV	{"phone": "+70105435955"}
0005434979772	6CD584	2496 281481	RUMIYA BARANOVA	{"email": "rumiya.baranova1972@postgrespro.ru", "phone": "+70203350076"}
0005434979773	6CD584	7570 126590	ALEFTINA OSIPOVA	{"phone": "+70428521383"}
0005434979774	6CD584	3338 370849	VASILIY KONOVALOV	{"email": "konovalovv_24021988@postgrespro.ru", "phone": "+70245510353"}
0005434979775	F1ADC2	6868 826231	ELENA GAVRILOVA	{"phone": "+70668268965"}
0005434979776	32EE2E	6056 484057	ALEKSANDR DAVYDOV	{"email": "a_davydov_29041974@postgrespro.ru", "phone": "+70824932206"}
0005434979777	32EE2E	1804 380392	LEYLA KOROLEVA	{"email": "koroleva-l.13101971@postgrespro.ru", "phone": "+70696737919"}
0005434979778	32EE2E	7641 030353	ALEKSEY SOLOVEV	{"email": "a_solovev.121973@postgrespro.ru", "phone": "+70716002143"}
0005434979779	089B2A	7496 725002	NADEZHDA OVCHINNIKOVA	{"email": "nadezhda-ovchinnikova_1971@postgrespro.ru", "phone": "+70541158168"}
0005434979780	290687	4650 848135	NINA VASILEVA	{"email": "vasileva-nina-1966@postgrespro.ru", "phone": "+70081818200"}
0005434979781	290687	0644 918327	KLAVDIYA MATVEEVA	{"phone": "+70873794594"}
0005434979782	290687	0683 840410	DMITRIY PETROV	{"phone": "+70376828376"}
0005434979783	FDF571	7452 784056	ANASTASIYA PETROVA	{"phone": "+70472590024"}
0005434979784	97DA26	8085 612932	IRINA SCHERBAKOVA	{"email": "scherbakova_irina23011981@postgrespro.ru", "phone": "+70180539588"}
0005434979785	97DA26	3398 518484	SERGEY MAKAROV	{"email": "makarov_sergey051972@postgrespro.ru", "phone": "+70257866552"}
0005434979786	93910D	3098 950866	NIKITA KONOVALOV	{"email": "konovalov_nikita.111956@postgrespro.ru", "phone": "+70143970238"}
0005434979787	93910D	7037 797764	ELENA NESTEROVA	{"phone": "+70262695757"}
0005434979788	80C747	4848 519712	GENNADIY GUSEV	{"email": "g_gusev_1969@postgrespro.ru", "phone": "+70261060169"}
0005434979789	58E3F6	4044 590912	TIGRAN CHERNOV	{"phone": "+70110754869"}
0005434979790	58E3F6	0318 272821	NIKOLAY PAVLOV	{"email": "pavlov_nikolay1973@postgrespro.ru", "phone": "+70993498536"}
0005434979791	5D5168	1487 411272	NIKOLAY SHEVCHENKO	{"email": "shevchenko-nikolay_01121966@postgrespro.ru", "phone": "+70931843613"}
0005434979792	B1F675	5224 544438	ANATOLIY ISAEV	{"email": "anatoliy.isaev.051974@postgrespro.ru", "phone": "+70513937678"}
0005434979793	DE19D4	0836 945580	ANDREY POPOV	{"phone": "+70795277905"}
0005434979794	DE19D4	9037 859094	VASILIY DMITRIEV	{"phone": "+70160104576"}
0005434979795	A6DB7C	5984 893340	DMITRIY POPOV	{"phone": "+70467349982"}
0005434979796	A6DB7C	5997 233066	DIANA DANILOVA	{"email": "d_danilova28021974@postgrespro.ru", "phone": "+70060191324"}
0005434979797	0A6AD6	5571 946273	ANTON BARANOV	{"email": "baranov.anton_071984@postgrespro.ru", "phone": "+70210810254"}
0005434979798	0A6AD6	0591 144205	NATALYA LOGINOVA	{"phone": "+70548480855"}
0005434979799	E7E0F0	0734 806226	VLADISLAV MAKAROV	{"email": "makarov.v-22011971@postgrespro.ru", "phone": "+70722612348"}
0005434979800	192226	7357 171796	TAMARA NIKITINA	{"phone": "+70021321958"}
0005434979801	C7C865	2430 038799	OLEG KARPOV	{"phone": "+70178962348"}
0005434979802	F85FF8	1025 745387	LIDIYA KOVALEVA	{"phone": "+70915916968"}
0005434979803	F85FF8	6609 317231	VLADIMIR ZAYCEV	{"phone": "+70587719143"}
0005434979804	D33ED2	9434 128891	EGOR DENISOV	{"phone": "+70017396045"}
0005434979805	D08B55	6246 070637	OLGA KOROLEVA	{"email": "olga-koroleva091969@postgrespro.ru", "phone": "+70821262052"}
0005434979806	18B1BD	4068 913696	NATALYA MOISEEVA	{"email": "n.moiseeva.24041970@postgrespro.ru", "phone": "+70930377821"}
0005434979807	E878BD	0396 308157	POLINA POPOVA	{"email": "p_popova15021981@postgrespro.ru", "phone": "+70689694286"}
0005434979808	E878BD	8839 622792	OLESYA IVANOVA	{"email": "o_ivanova.1968@postgrespro.ru", "phone": "+70465201224"}
0005434979809	7B075F	1853 734097	VADIM PETROV	{"phone": "+70691641909"}
0005434979810	7B075F	3077 960614	NIKOLAY GUSEV	{"email": "gusev.nikolay_1978@postgrespro.ru", "phone": "+70535830218"}
0005434979811	9C2D9E	0435 874368	VLADIMIR VASILEV	{"phone": "+70149490787"}
0005434979812	9C2D9E	6488 949394	NINA IVANOVA	{"email": "nina.ivanova_071969@postgrespro.ru", "phone": "+70673911035"}
0005434979813	92CD73	0793 414302	NIKOLAY KUZNECOV	{"email": "kuznecov_n_051972@postgrespro.ru", "phone": "+70465234256"}
0005434979814	D560B0	4500 512221	LYUDMILA ANTONOVA	{"phone": "+70582108689"}
0005434979815	55EC3B	0671 242835	OKSANA BORISOVA	{"phone": "+70519396404"}
0005434979816	55EC3B	5519 335967	SVETLANA KALININA	{"email": "s.kalinina_031980@postgrespro.ru", "phone": "+70611911687"}
0005434979817	040405	2768 737927	RIM TIMOFEEV	{"email": "timofeevr1973@postgrespro.ru", "phone": "+70033713500"}
0005434979818	87E5AD	8610 459726	ALEKSANDR SMIRNOV	{"email": "smirnov_a_081976@postgrespro.ru", "phone": "+70905705031"}
0005434979819	DE131E	9219 351888	RAISA SIDOROVA	{"email": "rsidorova-031974@postgrespro.ru", "phone": "+70072328082"}
0005434979820	F519BA	8232 213829	ARKADIY MIRONOV	{"email": "arkadiy.mironov.041975@postgrespro.ru", "phone": "+70308951902"}
0005434979821	C61AE2	8405 624263	GALINA MIRONOVA	{"phone": "+70655563020"}
0005434979822	E018F7	4336 817457	NATALYA IVANOVA	{"phone": "+70081712483"}
0005434979823	7E97E6	9933 175115	GALINA FOMINA	{"phone": "+70642800173"}
0005434979824	FE6B63	4495 395653	GALINA MAKAROVA	{"phone": "+70552872371"}
0005434979825	B0BEF4	0167 988119	PAVEL GERASIMOV	{"phone": "+70787231307"}
0005434979826	E38785	9054 073787	EKATERINA FROLOVA	{"phone": "+70424736155"}
0005434979827	7A0A6B	0911 519052	VARVARA ROMANOVA	{"email": "v.romanova_091969@postgrespro.ru", "phone": "+70605069990"}
0005434979828	A5378F	3666 504440	NIKOLAY GUSEV	{"email": "nikolaygusev-05121969@postgrespro.ru", "phone": "+70367981647"}
0005434979829	A5378F	7311 925959	VALENTINA KARPOVA	{"email": "karpova.v_1977@postgrespro.ru", "phone": "+70833664961"}
0005434979830	A5378F	5477 866306	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr_021957@postgrespro.ru", "phone": "+70582630493"}
0005434979831	65ED5A	3722 067946	VLADIMIR NAZAROV	{"email": "v_nazarov.1972@postgrespro.ru", "phone": "+70184844537"}
0005434979832	BB34A4	3005 891414	TATYANA NIKIFOROVA	{"phone": "+70345415519"}
0005434979833	BB34A4	4480 899045	ASIYA ZAKHAROVA	{"phone": "+70085520492"}
0005434979834	D7BFAB	9335 357902	VASILIY MEDVEDEV	{"email": "v-medvedev.1974@postgrespro.ru", "phone": "+70324605049"}
0005434979835	5B2662	4539 451071	NINA BELYAEVA	{"email": "belyaeva-n.22091966@postgrespro.ru", "phone": "+70421227336"}
0005434979836	0B71D3	3600 597652	VLADIMIR POPOV	{"phone": "+70661199888"}
0005434979837	034F38	2042 492216	YURIY KUDRYASHOV	{"email": "y-kudryashov-1968@postgrespro.ru", "phone": "+70476289313"}
0005434979838	034F38	4095 850353	RINAT KOZLOV	{"email": "r.kozlov-10041977@postgrespro.ru", "phone": "+70330603393"}
0005434979839	07F39C	1084 474353	NINA DAVYDOVA	{"email": "davydova_nina_051969@postgrespro.ru", "phone": "+70279259611"}
0005434979840	4B4FF9	8905 740152	DMITRIY ZAKHAROV	{"phone": "+70339414909"}
0005434979841	4DAE00	7305 682273	SVETLANA KUZMINA	{"email": "kuzmina-svetlana031975@postgrespro.ru", "phone": "+70411679651"}
0005434979842	4DAE00	7044 264420	VERA POPOVA	{"email": "vera-popova-041987@postgrespro.ru", "phone": "+70710016056"}
0005434979843	AD1C8E	0538 833331	IRINA MAKAROVA	{"phone": "+70100654607"}
0005434979844	142075	8799 321622	GENNADIY MIRONOV	{"phone": "+70121801141"}
0005434979845	142075	8915 636257	ANNA ORLOVA	{"email": "orlova_a_111970@postgrespro.ru", "phone": "+70080504919"}
0005434979846	DF55CA	5906 137408	ANDREY NOVIKOV	{"phone": "+70432567938"}
0005434979847	ADA3EE	6180 612288	SERGEY MIKHAYLOV	{"email": "s.mikhaylov-041976@postgrespro.ru", "phone": "+70136439717"}
0005434979848	27BD25	4453 905049	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr-1969@postgrespro.ru", "phone": "+70356265906"}
0005434979849	87CA5B	5750 084512	KARINA KUZNECOVA	{"phone": "+70926694046"}
0005434979850	87CA5B	3114 067029	GALINA IVANOVA	{"phone": "+70429233869"}
0005434979851	87CA5B	8255 752199	GALINA ABRAMOVA	{"phone": "+70553199942"}
0005434979852	5DFC2D	9385 864170	LYUDMILA ZHUKOVA	{"phone": "+70284791652"}
0005434979853	18B27B	6726 150829	ALEKSANDR NIKOLAEV	{"phone": "+70833357235"}
0005434979854	18B27B	2612 983163	AMIR KUZNECOV	{"phone": "+70155709467"}
0005434979855	CCB961	2905 748550	DANILA PAVLOV	{"phone": "+70813730041"}
0005434979856	589093	5194 797878	SVETLANA NESTEROVA	{"phone": "+70125521470"}
0005434979857	589093	9219 228833	VALENTINA KOROLEVA	{"email": "koroleva.v1974@postgrespro.ru", "phone": "+70969074545"}
0005434979858	589093	6156 056198	DARYA SAVELEVA	{"phone": "+70681038556"}
0005434979859	F3F60A	3102 098115	LIDIYA IVANOVA	{"email": "lidiyaivanova_16041976@postgrespro.ru", "phone": "+70072411109"}
0005434979860	5160DB	4741 249055	NIKITA EGOROV	{"phone": "+70145547268"}
0005434979861	0D8DDC	5062 529695	ALEKSEY DENISOV	{"email": "alekseydenisov.071973@postgrespro.ru", "phone": "+70286910481"}
0005434979862	987912	8983 390091	POLINA ROMANOVA	{"email": "romanova-p_111962@postgrespro.ru", "phone": "+70590404434"}
0005434979863	987912	4113 798618	TATYANA MAKAROVA	{"phone": "+70794411371"}
0005434979864	68B9E3	7042 468866	NIKOLAY SERGEEV	{"phone": "+70789255851"}
0005434979865	9C13A8	4436 170637	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov1967@postgrespro.ru", "phone": "+70773650321"}
0005434979866	9C13A8	6827 172569	MARINA TROFIMOVA	{"email": "marina_trofimova_1979@postgrespro.ru", "phone": "+70610408137"}
0005434979867	FE2DBC	9887 782298	YURIY PAVLOV	{"phone": "+70919215080"}
0005434979868	701283	5467 113557	NIKITA KISELEV	{"email": "kiselev-nikita.1966@postgrespro.ru", "phone": "+70114685128"}
0005434979869	2AE0AF	8350 394837	VLADIMIR KAZAKOV	{"phone": "+70573043879"}
0005434979870	2AE0AF	9891 410230	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova-1975@postgrespro.ru", "phone": "+70585915304"}
0005434979871	C5EA3F	4450 370469	MARIYA SMIRNOVA	{"email": "m-smirnova.08051971@postgrespro.ru", "phone": "+70837335669"}
0005434979872	700997	7000 363992	RISHAT ZHUKOV	{"email": "r-zhukov.091969@postgrespro.ru", "phone": "+70376014850"}
0005434979873	700997	4491 841447	DMITRIY VOLKOV	{"email": "volkov_dmitriy_1976@postgrespro.ru", "phone": "+70394346100"}
0005434979874	F508B9	5587 366097	VLADIMIR SAVELEV	{"email": "savelev.v_1974@postgrespro.ru", "phone": "+70354832553"}
0005434979875	2FA7B4	9595 971812	YANA KONDRATEVA	{"phone": "+70329054079"}
0005434979876	21D767	7104 766796	IVAN KUZNECOV	{"phone": "+70571757936"}
0005434979877	9C0126	8896 862175	VLADISLAV NAZAROV	{"email": "vladislavnazarov_081974@postgrespro.ru", "phone": "+70799214299"}
0005434979878	5F7F75	4477 946632	ILYA FEDOTOV	{"email": "ilyafedotov_1973@postgrespro.ru", "phone": "+70019433596"}
0005434979879	5F7F75	7074 728188	VARVARA ZAKHAROVA	{"email": "zakharova-varvara091966@postgrespro.ru", "phone": "+70949477196"}
0005434979880	709609	9219 047245	SERGEY IVANOV	{"phone": "+70532760147"}
0005434979881	709609	9951 948448	NADEZHDA KUZNECOVA	{"email": "nkuznecova.1970@postgrespro.ru", "phone": "+70104557379"}
0005434979882	2559BD	4101 740603	NIKOLAY BELOV	{"phone": "+70154827822"}
0005434979883	CC6D65	6491 539820	VYACHESLAV KULIKOV	{"email": "kulikov_v.02051960@postgrespro.ru", "phone": "+70488863206"}
0005434979884	DEC146	6599 893474	LIDIYA GUSEVA	{"phone": "+70135215769"}
0005434979885	341891	0586 581838	EVGENIY KOZLOV	{"phone": "+70999097484"}
0005434979886	341891	2512 191347	SANIYA ALEKSEEVA	{"phone": "+70416137975"}
0005434979887	96D44F	1941 774551	LEONID SMIRNOV	{"email": "leonid-smirnov1965@postgrespro.ru", "phone": "+70112286390"}
0005434979888	343D9D	7237 643276	AMINA SERGEEVA	{"phone": "+70533908344"}
0005434979889	698269	6204 947049	MARIYA SCHERBAKOVA	{"phone": "+70224259405"}
0005434979890	900DC5	7249 034370	YURIY ZAKHAROV	{"email": "y_zakharov31121959@postgrespro.ru", "phone": "+70868822209"}
0005434979891	28CF2A	2704 874308	ARTUR NIKOLAEV	{"email": "nikolaev.artur25031970@postgrespro.ru", "phone": "+70580164360"}
0005434979892	28CF2A	0871 589292	VERA FOMINA	{"email": "vera.fomina.1975@postgrespro.ru", "phone": "+70881062231"}
0005434979893	43DDFA	3376 610942	OLESYA FILIPPOVA	{"email": "olesya.filippova_021977@postgrespro.ru", "phone": "+70360263920"}
0005434979894	43DDFA	4657 412144	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov.13121959@postgrespro.ru", "phone": "+70328020067"}
0005434979895	43DDFA	6040 232533	VERONIKA ZAYCEVA	{"email": "v_zayceva01061971@postgrespro.ru", "phone": "+70894458102"}
0005434979896	17D15C	1147 533033	ALEKSANDR KULIKOV	{"email": "kulikov-aleksandr-071986@postgrespro.ru", "phone": "+70062348702"}
0005434979897	5B9B3B	0446 025850	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr-1959@postgrespro.ru", "phone": "+70428070175"}
0005434979898	6468F5	3346 425475	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey_011968@postgrespro.ru", "phone": "+70476924146"}
0005434979899	6468F5	0474 391312	LYUBOV KUZNECOVA	{"email": "kuznecova_l_29051970@postgrespro.ru", "phone": "+70093992243"}
0005434979900	6468F5	8231 637528	OLEG DMITRIEV	{"phone": "+70476779307"}
0005434979901	652FFF	1903 609820	VASILIY ZAKHAROV	{"email": "zakharov_v.13091962@postgrespro.ru", "phone": "+70663453228"}
0005434979902	652FFF	5034 110466	RADIK ROMANOV	{"email": "romanov-radik-1984@postgrespro.ru", "phone": "+70335468909"}
0005434979903	40142A	0642 413405	IGOR BELOV	{"phone": "+70975172513"}
0005434979904	40142A	5099 816114	ANATOLIY CHERNOV	{"phone": "+70230003742"}
0005434979905	69F5C7	9450 242360	TATYANA DANILOVA	{"email": "danilova.t051974@postgrespro.ru", "phone": "+70025149928"}
0005434979906	69F5C7	5551 311113	SERGEY KRASNOV	{"email": "krasnov_sergey_011972@postgrespro.ru", "phone": "+70685739496"}
0005434979968	DE5166	5123 170877	ANZHELIKA NIKITINA	{"phone": "+70246714959"}
0005434979907	FFC67D	0175 604454	ALEKSANDR KOZLOV	{"email": "a_kozlov1967@postgrespro.ru", "phone": "+70068444683"}
0005434979908	FFC67D	4049 126717	VASILIY ORLOV	{"phone": "+70158250729"}
0005434979909	29C53D	8852 934659	TATYANA IVANOVA	{"email": "tivanova061976@postgrespro.ru", "phone": "+70155461620"}
0005434979910	7CB5A4	7347 848968	EVA ALEKSEEVA	{"phone": "+70994328103"}
0005434979911	51D593	7953 558978	ARTEM GAVRILOV	{"phone": "+70674038225"}
0005434979912	1B2FFF	0950 528786	GALINA GRISHINA	{"phone": "+70997649518"}
0005434979913	1B2FFF	9974 304357	SVETLANA NAUMOVA	{"email": "svetlana_naumova041966@postgrespro.ru", "phone": "+70924395227"}
0005434979914	44CD97	3090 673179	ALEKSANDRA ROMANOVA	{"email": "romanovaa_1972@postgrespro.ru", "phone": "+70515526479"}
0005434979915	C41874	9565 062867	ARKADIY SIDOROV	{"phone": "+70069576236"}
0005434979916	C41874	0972 145199	VALENTINA SEMENOVA	{"phone": "+70926750591"}
0005434979917	2280DC	8901 859776	GULNARA NESTEROVA	{"email": "gulnaranesterova_27071978@postgrespro.ru", "phone": "+70101216734"}
0005434979918	802B0E	1593 020397	ALEKSANDR OSIPOV	{"email": "a-osipov.01101968@postgrespro.ru", "phone": "+70211728235"}
0005434979919	802B0E	1892 089068	EVGENIYA ABRAMOVA	{"phone": "+70420744276"}
0005434979920	E30A3B	7393 947661	MAKSIM ROMANOV	{"phone": "+70925360611"}
0005434979921	94B53E	9841 993639	OLEG IVANOV	{"phone": "+70766064179"}
0005434979922	FA5AD6	0158 285967	IVAN MARTYNOV	{"email": "martynovi_1975@postgrespro.ru", "phone": "+70472101196"}
0005434979923	FA5AD6	4261 913265	ROMAN ALEKSANDROV	{"phone": "+70930505527"}
0005434979924	FC1240	3441 408183	ALEKSEY ILIN	{"email": "ilin-aleksey.051988@postgrespro.ru", "phone": "+70129066458"}
0005434979925	064D94	3141 058410	LIDIYA MAKAROVA	{"email": "makarova.lidiya.10091964@postgrespro.ru", "phone": "+70143672365"}
0005434979926	886452	1658 002864	NATALYA ALEKSANDROVA	{"email": "natalyaaleksandrova.15071965@postgrespro.ru", "phone": "+70658889937"}
0005434979927	886452	1240 844102	ARTEM NIKOLAEV	{"phone": "+70523881687"}
0005434979928	D7E553	0416 754343	VERA DAVYDOVA	{"phone": "+70424200063"}
0005434979929	E1E325	9508 076957	NINA KAZAKOVA	{"phone": "+70371938833"}
0005434979930	E1E325	7448 821625	IVAN KAZAKOV	{"phone": "+70699576345"}
0005434979931	332710	8452 513263	ANDREY YAKOVLEV	{"phone": "+70470178471"}
0005434979932	332710	5577 975177	MARIYA DAVYDOVA	{"email": "davydova_mariya_06111963@postgrespro.ru", "phone": "+70475519714"}
0005434979933	332710	5583 988304	ANNA KUZNECOVA	{"email": "kuznecovaanna-021973@postgrespro.ru", "phone": "+70565173314"}
0005434979934	7EA388	6866 012051	DMITRIY VLASOV	{"email": "d_vlasov-10021972@postgrespro.ru", "phone": "+70450716741"}
0005434979935	7EA388	5625 543811	NINA CHERNOVA	{"phone": "+70550075062"}
0005434979936	7F25CD	9593 600356	DENIS MIRONOV	{"phone": "+70462352805"}
0005434979937	7F25CD	6167 613991	YULIYA LOGINOVA	{"email": "loginova.yuliya.1979@postgrespro.ru", "phone": "+70100967729"}
0005434979938	7F25CD	4226 158533	DMITRIY KOROLEV	{"phone": "+70795538736"}
0005434979939	16F1DD	4342 267332	ELENA YUDINA	{"email": "elena_yudina_15081958@postgrespro.ru", "phone": "+70222183407"}
0005434979940	B4F947	8030 639870	VLADIMIR MATVEEV	{"phone": "+70475417331"}
0005434979941	E9A5FF	0679 763254	YULIYA KUZMINA	{"email": "kuzmina-yuliya.1974@postgrespro.ru", "phone": "+70619963554"}
0005434979942	940F22	8466 292982	OLEG MIRONOV	{"email": "o.mironov.13041958@postgrespro.ru", "phone": "+70755193517"}
0005434979943	940F22	4547 495084	RUSTAM FILIPPOV	{"phone": "+70509555152"}
0005434979944	940F22	6216 914978	ALEKSANDR GORBUNOV	{"email": "aleksandr.gorbunov_12101973@postgrespro.ru", "phone": "+70548527071"}
0005434979945	0F15D0	2509 404477	NIKOLAY SAVELEV	{"email": "savelevnikolay.061972@postgrespro.ru", "phone": "+70063971898"}
0005434979946	4AFE29	5475 859006	GLEB KUZMIN	{"email": "kuzmin-gleb_1971@postgrespro.ru", "phone": "+70235908726"}
0005434979947	564E38	6288 055816	IGOR GRIGOREV	{"phone": "+70803800080"}
0005434979948	F5E938	3477 462853	ALEKSANDR ALEKSEEV	{"email": "aleksandr_alekseev_061978@postgrespro.ru", "phone": "+70500782737"}
0005434979949	638939	3149 597934	VSEVOLOD KUDRYASHOV	{"phone": "+70366287639"}
0005434979950	638939	6864 297590	EKATERINA ANDREEVA	{"email": "andreeva_e1976@postgrespro.ru", "phone": "+70751231435"}
0005434979951	638939	3040 809408	LYUBOV NIKOLAEVA	{"phone": "+70019137111"}
0005434979952	5A6C66	0004 488154	DMITRIY KOZLOV	{"phone": "+70993158664"}
0005434979953	F7FF52	1827 645574	MIKHAIL ALEKSEEV	{"phone": "+70552094514"}
0005434979954	B3ADD8	9774 645300	VIKTOR ISAEV	{"email": "isaevviktor_1966@postgrespro.ru", "phone": "+70708172553"}
0005434979955	89A43A	3243 339636	ALEKSANDR KOZLOV	{"phone": "+70134745807"}
0005434979956	475F20	6442 844549	IVAN VLASOV	{"email": "ivlasov061977@postgrespro.ru", "phone": "+70672059902"}
0005434979957	2044A4	2438 514273	ALEKSANDR TARASOV	{"email": "aleksandrtarasov_1972@postgrespro.ru", "phone": "+70826769444"}
0005434979958	2044A4	9284 194955	TAMARA FROLOVA	{"email": "tamara.frolova_071974@postgrespro.ru", "phone": "+70559505542"}
0005434979959	2044A4	8310 202113	VIKTOR MEDVEDEV	{"phone": "+70953226834"}
0005434979960	7897FD	8732 885261	ANNA MELNIKOVA	{"email": "a_melnikova-101979@postgrespro.ru", "phone": "+70462797391"}
0005434979961	7897FD	9457 098171	ELENA VOLKOVA	{"email": "volkova-elena-1969@postgrespro.ru", "phone": "+70525085603"}
0005434979962	0C82B6	9942 743270	ALBERT ZHUKOV	{"phone": "+70189130272"}
0005434979963	6E4C30	4634 171988	SOFIYA DENISOVA	{"phone": "+70403485604"}
0005434979964	4F8E01	2139 623947	VLADIMIR RODIONOV	{"phone": "+70438082208"}
0005434979965	4F8E01	1617 663594	GALINA ALEKSEEVA	{"email": "alekseevag11071968@postgrespro.ru", "phone": "+70266995763"}
0005434979966	2DA187	3325 844193	ELENA VASILEVA	{"phone": "+70312221952"}
0005434979967	DE5166	2697 750151	NIKOLAY POPOV	{"phone": "+70528596264"}
0005434979969	E95AB8	2253 043782	DMITRIY KUDRYASHOV	{"email": "dmitriy-kudryashov-03011976@postgrespro.ru", "phone": "+70719562018"}
0005434979970	E95AB8	8537 487369	SVETLANA NESTEROVA	{"phone": "+70979337400"}
0005434979971	E95AB8	6203 198924	EVGENIY OSIPOV	{"phone": "+70713462617"}
0005434979972	686539	8144 794106	ELIZAVETA AFANASEVA	{"email": "afanasevaelizaveta.03101982@postgrespro.ru", "phone": "+70654554492"}
0005434979973	686539	8955 588906	VLADISLAV VOLKOV	{"phone": "+70917588881"}
0005434979974	686539	8371 483127	ALEKSANDR SOROKIN	{"phone": "+70075554534"}
0005434979975	A3BACE	9117 663765	TATYANA KUZNECOVA	{"email": "kuznecova.t.021974@postgrespro.ru", "phone": "+70934781109"}
0005434979976	67D3AC	5047 763846	YAROSLAV SAVELEV	{"email": "savelev.y-1973@postgrespro.ru", "phone": "+70113672478"}
0005434979977	E74F35	3485 376646	ANATOLIY KUZMIN	{"phone": "+70463117680"}
0005434979978	E74F35	1985 438129	LYUBOV FADEEVA	{"email": "fadeeva.l.111972@postgrespro.ru", "phone": "+70075554846"}
0005434979979	A3FE48	3730 302160	SERGEY POPOV	{"phone": "+70995717300"}
0005434979980	A3FE48	4608 512120	MARIYA ANISIMOVA	{"phone": "+70425849916"}
0005434979981	224EAC	0650 601461	SERGEY MEDVEDEV	{"phone": "+70473881381"}
0005434979982	C0BBF8	4844 904269	ELENA NESTEROVA	{"email": "nesterova-elena011968@postgrespro.ru", "phone": "+70982752560"}
0005434979983	A66D9F	7608 644823	SVETLANA KUZNECOVA	{"email": "s_kuznecova_081972@postgrespro.ru", "phone": "+70493752843"}
0005434979984	73DE0D	9749 903812	SERGEY KARPOV	{"email": "karpov-sergey_08121971@postgrespro.ru", "phone": "+70873108962"}
0005434979985	73DE0D	0630 427161	EKATERINA KAZAKOVA	{"email": "ekaterina_kazakova.1968@postgrespro.ru", "phone": "+70572509745"}
0005434979986	0B20E5	8606 812257	LARISA KUZNECOVA	{"email": "kuznecova-larisa.01021963@postgrespro.ru", "phone": "+70662064696"}
0005434979987	35DC93	3623 808607	NADEZHDA POTAPOVA	{"email": "potapova.n1969@postgrespro.ru", "phone": "+70740175649"}
0005434979988	5F7E86	4356 951423	RAISA KARPOVA	{"phone": "+70098595974"}
0005434979989	219D38	0160 312910	IVAN DMITRIEV	{"email": "dmitrievivan.1971@postgrespro.ru", "phone": "+70986520236"}
0005434979990	219D38	7291 786036	DANILA FROLOV	{"email": "danila.frolov041979@postgrespro.ru", "phone": "+70923156628"}
0005434979991	9C6D7C	5412 393863	EKATERINA KAZAKOVA	{"phone": "+70335782647"}
0005434979992	DDBF23	4588 852473	VADIM DAVYDOV	{"email": "davydov-v.061976@postgrespro.ru", "phone": "+70218528328"}
0005434979993	D7D01E	2648 076588	ELVIRA VOLKOVA	{"email": "volkova_e.14121969@postgrespro.ru", "phone": "+70660825891"}
0005434979994	3B8D97	7547 763544	VLADIMIR POPOV	{"email": "vladimir.popov_091979@postgrespro.ru", "phone": "+70309963417"}
0005434979995	3887C1	2651 055650	TATYANA NESTEROVA	{"email": "nesterova-tatyana1979@postgrespro.ru", "phone": "+70796207694"}
0005434979996	B451C7	3465 864839	ELENA SAVELEVA	{"phone": "+70112011852"}
0005434979997	048890	2764 803351	LYUDMILA GAVRILOVA	{"phone": "+70625775557"}
0005434979998	D64F78	2468 753793	MARIYA SMIRNOVA	{"email": "smirnova.mariya26041973@postgrespro.ru", "phone": "+70329098007"}
0005434979999	D64F78	3326 833947	ALEKSANDR MOROZOV	{"email": "amorozov-1963@postgrespro.ru", "phone": "+70334391508"}
0005434980000	04046D	4523 203284	VERONIKA BORISOVA	{"email": "veronikaborisova1964@postgrespro.ru", "phone": "+70323252088"}
0005434980001	9BEB44	5928 326660	VIKTOR SEMENOV	{"email": "semenovviktor-111971@postgrespro.ru", "phone": "+70328557536"}
0005434980002	E9DA59	0357 388423	IRINA KUZMINA	{"email": "irina-kuzmina.1968@postgrespro.ru", "phone": "+70930084059"}
0005434980003	62E335	6758 064017	ALI PAVLOV	{"phone": "+70473333316"}
0005434980004	ACC980	0493 669306	DMITRIY ANTONOV	{"email": "antonovd011974@postgrespro.ru", "phone": "+70438768835"}
0005434980005	F25EC4	7489 797777	ALEKSANDR NAZAROV	{"phone": "+70080922270"}
0005434980006	8A78AB	4445 668036	OKSANA ABRAMOVA	{"email": "oksana.abramova-03041973@postgrespro.ru", "phone": "+70094275731"}
0005434980007	2A2B7F	2504 871851	MIKHAIL ISAEV	{"email": "isaev-mikhail-1972@postgrespro.ru", "phone": "+70778901190"}
0005434980008	CA6D92	9562 280453	SERGEY ORLOV	{"email": "sergey.orlov061969@postgrespro.ru", "phone": "+70189253591"}
0005434980009	68F742	8366 972416	TATYANA KUZNECOVA	{"phone": "+70332076365"}
0005434980010	866E93	5137 317521	VITALIY FROLOV	{"phone": "+70227404440"}
0005434980011	36CD5F	6795 675182	TAMARA LUKYANOVA	{"phone": "+70256112083"}
0005434980012	4BF0DB	4337 888258	KLAVDIYA FILIPPOVA	{"email": "filippova_klavdiya_1980@postgrespro.ru", "phone": "+70639650261"}
0005434980013	4BF0DB	4866 416617	IRINA BARANOVA	{"email": "irina-baranova-22061966@postgrespro.ru", "phone": "+70278691866"}
0005434980014	2CB429	1173 665582	NIKITA ZHUKOV	{"phone": "+70416697361"}
0005434980015	E549B2	1137 047605	ANNA NOVIKOVA	{"phone": "+70634006911"}
0005434980016	E549B2	8335 267377	TAMARA POPOVA	{"email": "tamarapopova-1972@postgrespro.ru", "phone": "+70575272363"}
0005434980017	D143ED	5180 175379	NINA BELYAEVA	{"email": "ninabelyaeva1971@postgrespro.ru", "phone": "+70813204187"}
0005434980018	D143ED	2854 755937	LEONID SEMENOV	{"phone": "+70926695919"}
0005434980019	C4C7C5	2044 483955	IGOR NIKOLAEV	{"phone": "+70397868532"}
0005434980020	9E9AB8	4061 442416	VALERIY MEDVEDEV	{"phone": "+70586294043"}
0005434980021	EABD55	1185 099640	GALINA KOROLEVA	{"phone": "+70169203491"}
0005434980022	EABD55	9219 338721	DENIS DENISOV	{"phone": "+70734619124"}
0005434980023	D2E3FC	3539 591841	ALEKSANDR CHERNOV	{"email": "achernov_1968@postgrespro.ru", "phone": "+70153959807"}
0005434980024	07BA8F	9123 589419	LYUDMILA KOZLOVA	{"email": "lkozlova-1977@postgrespro.ru", "phone": "+70224803903"}
0005434980025	CBE6D6	3925 070534	VALERIY KULIKOV	{"email": "v_kulikov_04101959@postgrespro.ru", "phone": "+70912807474"}
0005434980026	CBE6D6	4114 723812	OLGA POPOVA	{"phone": "+70810526412"}
0005434980027	CBE6D6	4838 070259	TATYANA POLYAKOVA	{"email": "polyakova.tatyana-1975@postgrespro.ru", "phone": "+70203744663"}
0005434980028	40F0C8	8544 493039	VADIM CHERNOV	{"phone": "+70477159251"}
0005434980029	FF0916	3737 461871	ILYA FEDOTOV	{"email": "fedotov_i-101963@postgrespro.ru", "phone": "+70231599173"}
0005434980030	564536	7153 690488	VYACHESLAV IVANOV	{"phone": "+70786165718"}
0005434980031	85D81B	9611 598775	ALISA SERGEEVA	{"phone": "+70008352353"}
0005434980032	E6B105	8318 697721	LYUBOV PAVLOVA	{"phone": "+70968698967"}
0005434980033	0C8DA3	8969 802326	MARIYA MOISEEVA	{"phone": "+70053024518"}
0005434980034	0C8DA3	8652 414802	ALEKSEY ABRAMOV	{"email": "abramova1978@postgrespro.ru", "phone": "+70386784674"}
0005434980035	0C3282	0820 403614	ALEKSEY BORISOV	{"email": "borisovaleksey111974@postgrespro.ru", "phone": "+70963301135"}
0005434980036	0C3282	6690 340863	NIKOLAY SCHERBAKOV	{"phone": "+70303596024"}
0005434980037	7FE863	2763 063368	NADEZHDA KUZNECOVA	{"phone": "+70984029550"}
0005434980038	B90677	7833 057738	ANASTASIYA BELOVA	{"email": "belova_anastasiya.1967@postgrespro.ru", "phone": "+70531306053"}
0005434980039	18C48C	2666 548905	VLADIMIR SOLOVEV	{"email": "solovev_vladimir.1975@postgrespro.ru", "phone": "+70223935327"}
0005434980040	1E82AA	2266 266137	IGOR ORLOV	{"phone": "+70488423290"}
0005434980041	BE3AAC	0994 128150	NIKOLAY OSIPOV	{"phone": "+70257694105"}
0005434980042	BE3AAC	4348 007402	ANATOLIY POPOV	{"email": "anatoliy.popov_031973@postgrespro.ru", "phone": "+70776181226"}
0005434980043	BE3AAC	1147 169025	ALEKSEY VASILEV	{"email": "vasilev_a071966@postgrespro.ru", "phone": "+70391368760"}
0005434980044	9E84CF	9664 477759	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova-1970@postgrespro.ru", "phone": "+70425056081"}
0005434980045	9E84CF	9922 117905	MAYYA PAVLOVA	{"phone": "+70004296173"}
0005434980046	327BBB	4625 379443	MARIYA KUZNECOVA	{"email": "mariya-kuznecova_1980@postgrespro.ru", "phone": "+70953835746"}
0005434980047	327BBB	8241 315827	VALENTINA BORISOVA	{"phone": "+70160603338"}
0005434980048	56694D	7976 429476	NIKOLAY DENISOV	{"phone": "+70119002204"}
0005434980049	34B914	5752 956487	GENNADIY SEMENOV	{"email": "semenov.g-1974@postgrespro.ru", "phone": "+70666202642"}
0005434980050	E31F66	1743 222682	NINA ANTONOVA	{"email": "antonova-n08021969@postgrespro.ru", "phone": "+70789756311"}
0005434980051	E31F66	1164 630813	GALINA SCHERBAKOVA	{"email": "scherbakova.g_18101964@postgrespro.ru", "phone": "+70096046850"}
0005434980052	CDFA25	3504 051953	VALENTINA EGOROVA	{"email": "v_egorova.121972@postgrespro.ru", "phone": "+70477461120"}
0005434980053	CDFA25	4183 309858	VLADIMIR KULIKOV	{"email": "kulikov-vladimir-1974@postgrespro.ru", "phone": "+70376420765"}
0005434980054	5541EF	3611 277428	ELENA ALEKSEEVA	{"email": "alekseeva-elena_03051970@postgrespro.ru", "phone": "+70923599769"}
0005434980055	5541EF	9278 425589	IGOR GORBUNOV	{"phone": "+70006988173"}
0005434980056	89858B	3700 087884	ALEKSEY CHERNOV	{"phone": "+70982184988"}
0005434980057	5F36D8	6362 319364	ELENA ZHURAVLEVA	{"phone": "+70838061578"}
0005434980058	5F36D8	4406 419984	YURIY MARTYNOV	{"phone": "+70413931390"}
0005434980059	20DBAC	1151 916283	MAKAR FEDOTOV	{"phone": "+70813860079"}
0005434980060	FBB50F	0639 584506	IVAN KONOVALOV	{"email": "konovalov.ivan_061986@postgrespro.ru", "phone": "+70942555879"}
0005434980061	45DB68	0351 077022	RAVIL IVANOV	{"email": "ravilivanov-05091972@postgrespro.ru", "phone": "+70485735624"}
0005434980062	0AE353	9854 507609	RIMMA FROLOVA	{"email": "frolova.rimma_071985@postgrespro.ru", "phone": "+70440122685"}
0005434980063	F714A1	3529 729504	GENNADIY KOZLOV	{"email": "kozlov-gennadiy-12031979@postgrespro.ru", "phone": "+70696962479"}
0005434980064	5A6565	6036 937623	AIDA AKIMOVA	{"phone": "+70349922899"}
0005434980065	5A6565	1004 216393	ALEKSEY PETROV	{"email": "petrov.a-101973@postgrespro.ru", "phone": "+70433852745"}
0005434980066	5A6565	8540 446612	ALEKSEY VASILEV	{"phone": "+70350230397"}
0005434980067	E40941	2995 488051	ANASTASIYA ALEKSEEVA	{"email": "alekseeva-a-13011974@postgrespro.ru", "phone": "+70590950687"}
0005434980068	15E11F	7450 884911	SERGEY MATVEEV	{"phone": "+70182595367"}
0005434980069	2BDE3E	7323 642436	MIKHAIL SMIRNOV	{"phone": "+70342928070"}
0005434980070	DF77F7	3187 067456	NIKOLAY ANDREEV	{"phone": "+70313298601"}
0005434980071	AA7ABF	4744 587541	NIKOLAY KISELEV	{"phone": "+70848456175"}
0005434980072	473CB9	9190 380494	ANATOLIY FROLOV	{"email": "frolov-anatoliy-081961@postgrespro.ru", "phone": "+70647464415"}
0005434980073	C827C9	1697 463147	NIKOLAY KOZLOV	{"phone": "+70793841593"}
0005434980074	D44987	0730 585245	SERGEY PETROV	{"phone": "+70612876718"}
0005434980075	E897F1	3398 459665	GALINA ALEKSEEVA	{"email": "galina_alekseeva.071977@postgrespro.ru", "phone": "+70822294398"}
0005434980076	76D461	9759 817346	VYACHESLAV SMIRNOV	{"phone": "+70926834457"}
0005434980077	8D1EE5	2551 963127	ALEKSANDR FEDOTOV	{"email": "fedotov-aleksandr.031969@postgrespro.ru", "phone": "+70526416062"}
0005434980078	ABEE34	5390 459461	NINA ABRAMOVA	{"phone": "+70575903844"}
0005434980079	ABEE34	6420 945514	ROMAN GERASIMOV	{"email": "rgerasimov.071968@postgrespro.ru", "phone": "+70110545006"}
0005434980080	F46531	9662 248868	YURIY SOROKIN	{"email": "yuriysorokin121964@postgrespro.ru", "phone": "+70915475339"}
0005434980081	FC071D	0790 233791	ELIZAVETA KUDRYASHOVA	{"email": "ekudryashova.031964@postgrespro.ru", "phone": "+70238164848"}
0005434980082	08A03B	2265 629446	EVGENIYA NIKITINA	{"phone": "+70661015392"}
0005434980083	098E00	6500 318047	ELENA FEDOROVA	{"email": "fedorova-elena_13091972@postgrespro.ru", "phone": "+70138978207"}
0005434980084	098E00	1404 273630	NADEZHDA KUZNECOVA	{"phone": "+70595900310"}
0005434980085	12CEE1	7769 700505	ANDREY VASILEV	{"phone": "+70067306830"}
0005434980086	BF90BC	9965 528198	VALENTINA KUDRYASHOVA	{"email": "kudryashova-v.061967@postgrespro.ru", "phone": "+70736358167"}
0005434980087	BF90BC	7040 014364	YURIY ZHUKOV	{"email": "yuriy-zhukov-1958@postgrespro.ru", "phone": "+70163468383"}
0005434980088	F1C4BB	7527 853881	MARIYA KARPOVA	{"email": "karpovamariya.021975@postgrespro.ru", "phone": "+70845972784"}
0005434980089	F1C4BB	0412 000169	MARINA ERMAKOVA	{"phone": "+70580419249"}
0005434980090	7898FC	1836 487326	VYACHESLAV ROMANOV	{"phone": "+70265118814"}
0005434980091	7898FC	7447 198464	NATALYA NESTEROVA	{"email": "nnesterova_101981@postgrespro.ru", "phone": "+70845874820"}
0005434980092	1043A9	4571 058724	ALEKSEY TIKHONOV	{"phone": "+70285436447"}
0005434980151	BBA2EC	9301 702951	GALINA SOROKINA	{"phone": "+70457195032"}
0005434980093	790EF7	7897 230895	ALEKSEY KUDRYASHOV	{"email": "kudryashov-aleksey-06071980@postgrespro.ru", "phone": "+70049298464"}
0005434980094	73459E	1829 931701	NATALIYA OSIPOVA	{"phone": "+70599618997"}
0005434980095	73459E	6525 432123	LYUDMILA KRASNOVA	{"email": "krasnova_lyudmila-011980@postgrespro.ru", "phone": "+70629232275"}
0005434980096	4BB19D	7857 431757	IGOR IVANOV	{"phone": "+70187052203"}
0005434980097	665A36	3431 369324	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov-101976@postgrespro.ru", "phone": "+70061672285"}
0005434980098	4508D5	3524 305241	SERGEY ZAYCEV	{"email": "sergeyzaycev.1973@postgrespro.ru", "phone": "+70612059493"}
0005434980099	E370B1	9871 238634	ALEKSANDR PAVLOV	{"phone": "+70899762935"}
0005434980100	C32F9C	5166 668663	YULIYA KRASNOVA	{"phone": "+70766805515"}
0005434980101	8B3517	0784 490135	ANATOLIY MIKHAYLOV	{"email": "anatoliymikhaylov-071974@postgrespro.ru", "phone": "+70267334256"}
0005434980102	8B3517	1475 518144	NATALYA ANDREEVA	{"phone": "+70081430896"}
0005434980103	B4146D	3957 210734	OLGA KOVALEVA	{"phone": "+70474525704"}
0005434980104	B4146D	3544 299990	MIKHAIL MAKSIMOV	{"phone": "+70469430952"}
0005434980105	266EAA	9735 256341	NATALIYA FILIPPOVA	{"phone": "+70353081631"}
0005434980106	266EAA	7762 675580	DMITRIY SERGEEV	{"phone": "+70140336095"}
0005434980107	EE8102	8925 342206	IGOR SOKOLOV	{"phone": "+70967250492"}
0005434980108	064492	0084 867580	EVGENIY SOKOLOV	{"phone": "+70773699787"}
0005434980109	064492	0512 085768	IRINA MOISEEVA	{"email": "moiseeva_irina.23091978@postgrespro.ru", "phone": "+70885993719"}
0005434980110	9C860E	7805 494672	SERGEY VOROBEV	{"email": "sergey.vorobev_1969@postgrespro.ru", "phone": "+70996363367"}
0005434980111	9C860E	3870 407612	ALEKSANDR MAKSIMOV	{"email": "maksimov_a-08041970@postgrespro.ru", "phone": "+70429769122"}
0005434980112	A868F3	4374 717164	FEDOR EGOROV	{"email": "egorov.fedor.1973@postgrespro.ru", "phone": "+70930760461"}
0005434980113	ADE9D0	7554 187809	ULYANA VOLKOVA	{"email": "ulyana.volkova.1960@postgrespro.ru", "phone": "+70804810892"}
0005434980114	709390	6826 955171	TATYANA IVANOVA	{"phone": "+70383729813"}
0005434980115	D9B618	3045 994075	GALINA SCHERBAKOVA	{"email": "scherbakova-galina-01011974@postgrespro.ru", "phone": "+70211300826"}
0005434980116	D9B618	7178 600726	ALEKSEY KOZLOV	{"phone": "+70639995455"}
0005434980117	D9B618	4644 620279	LIDIYA EGOROVA	{"email": "egorova_l_07091977@postgrespro.ru", "phone": "+70366796488"}
0005434980118	9C02AA	7409 263550	LIDIYA BELYAEVA	{"email": "lidiya-belyaeva061954@postgrespro.ru", "phone": "+70657758031"}
0005434980119	C1EC3C	3285 081148	ILYA STEPANOV	{"email": "stepanov.ilya1967@postgrespro.ru", "phone": "+70615577974"}
0005434980120	ADDC09	8417 679025	ILYA SCHERBAKOV	{"phone": "+70938556390"}
0005434980121	BDB71A	7752 300344	NATALYA MAKSIMOVA	{"email": "maksimovan_041980@postgrespro.ru", "phone": "+70516256608"}
0005434980122	B09F61	8412 719939	NIKOLAY BARANOV	{"email": "n-baranov_081973@postgrespro.ru", "phone": "+70874676072"}
0005434980123	C6BF4C	4584 757816	NIKOLAY ZAKHAROV	{"phone": "+70981762272"}
0005434980124	C6BF4C	9110 065660	IRINA KUZNECOVA	{"email": "kuznecova_i-071974@postgrespro.ru", "phone": "+70391981159"}
0005434980125	A909E0	8070 388487	IRINA NAUMOVA	{"phone": "+70551949870"}
0005434980126	33F1B1	9630 310925	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir.24011969@postgrespro.ru", "phone": "+70249658253"}
0005434980127	C1B352	5866 996597	ELENA VOLKOVA	{"email": "volkovaelena-1961@postgrespro.ru", "phone": "+70600812677"}
0005434980128	E63ABB	4394 515969	MAKSIM ZHURAVLEV	{"email": "zhuravlevm_1964@postgrespro.ru", "phone": "+70693266662"}
0005434980129	22073C	8011 775097	SVETLANA KUZMINA	{"phone": "+70183106919"}
0005434980130	2783D2	2580 847295	DARYA KONOVALOVA	{"email": "konovalova.d_1976@postgrespro.ru", "phone": "+70115659074"}
0005434980131	22B6DF	9536 901660	NIKOLAY BONDARENKO	{"phone": "+70492922540"}
0005434980132	22B6DF	7889 585065	DMITRIY ALEKSEEV	{"email": "alekseev.dmitriy-20061977@postgrespro.ru", "phone": "+70217636808"}
0005434980133	E3F97F	7291 692943	MARINA FADEEVA	{"email": "marina-fadeeva_011972@postgrespro.ru", "phone": "+70570476115"}
0005434980134	B6874C	6982 118403	ANATOLIY KUZNECOV	{"phone": "+70326076263"}
0005434980135	B6874C	2982 321465	VERA SMIRNOVA	{"email": "vera_smirnova-08011977@postgrespro.ru", "phone": "+70265747496"}
0005434980136	B6874C	4737 348765	TATYANA TIMOFEEVA	{"email": "timofeevatatyana_081978@postgrespro.ru", "phone": "+70554694053"}
0005434980137	8A53FE	5618 325751	SVETLANA IVANOVA	{"email": "ivanovasvetlana1959@postgrespro.ru", "phone": "+70029685513"}
0005434980138	8A53FE	3259 586800	ILMIR MAKAROV	{"phone": "+70115595888"}
0005434980139	D444D4	6806 005733	NATALYA SERGEEVA	{"email": "natalya_sergeeva-081967@postgrespro.ru", "phone": "+70037724273"}
0005434980140	9597DD	3291 203633	DENIS KUDRYASHOV	{"phone": "+70618170157"}
0005434980141	20A953	0857 348179	EVGENIYA GERASIMOVA	{"phone": "+70695233237"}
0005434980142	20A953	7524 342126	ILYA TIMOFEEV	{"email": "itimofeev-031965@postgrespro.ru", "phone": "+70869957806"}
0005434980143	895A96	8180 705708	ALEKSEY FEDOROV	{"phone": "+70392242213"}
0005434980144	F39E1B	7777 063370	NIKITA NIKOLAEV	{"email": "n_nikolaev_06111967@postgrespro.ru", "phone": "+70490624129"}
0005434980145	F39E1B	1432 512585	YULIYA POPOVA	{"email": "popovayuliya_07071965@postgrespro.ru", "phone": "+70697750124"}
0005434980146	F39E1B	9790 403166	ANATOLIY SCHERBAKOV	{"email": "scherbakov_anatoliy-121976@postgrespro.ru", "phone": "+70152212445"}
0005434980147	9771F9	9770 999579	VALERIY GERASIMOV	{"email": "gerasimov.valeriy.1987@postgrespro.ru", "phone": "+70850761448"}
0005434980148	9771F9	5994 072278	TATYANA KONOVALOVA	{"phone": "+70091053808"}
0005434980149	DD5480	2475 043417	MILANA GORBUNOVA	{"email": "gorbunovamilana-29041983@postgrespro.ru", "phone": "+70103397111"}
0005434980150	193C69	1935 544325	MARIYA KARPOVA	{"email": "karpova_mariya.11091984@postgrespro.ru", "phone": "+70506611526"}
0005434980152	BBA2EC	4635 017475	MIKHAIL ROMANOV	{"email": "m.romanov_1967@postgrespro.ru", "phone": "+70568352865"}
0005434980153	2738DA	1811 442621	MIKHAIL FEDOROV	{"email": "m_fedorov05101966@postgrespro.ru", "phone": "+70416637344"}
0005434980154	6251C4	6376 796261	IVAN EGOROV	{"phone": "+70339842670"}
0005434980155	6251C4	3337 440940	MARIYA PETROVA	{"phone": "+70812946270"}
0005434980156	605259	0308 448707	ALISA ISAEVA	{"phone": "+70096502219"}
0005434980157	605259	9676 016236	MIKHAIL PETROV	{"phone": "+70534390754"}
0005434980158	8841B4	3781 260758	OLGA KONOVALOVA	{"email": "konovalova_o-08071980@postgrespro.ru", "phone": "+70635567729"}
0005434980159	1A1EEC	8451 338250	NATALYA TIKHONOVA	{"phone": "+70445476213"}
0005434980160	1A1EEC	5018 674947	DARYA FILIPPOVA	{"phone": "+70478008430"}
0005434980161	7A1BE8	2288 671027	ALEKSANDRA CHERNOVA	{"phone": "+70919133559"}
0005434980162	BAB3E8	6141 576716	TATYANA YAKOVLEVA	{"phone": "+70322709032"}
0005434980163	BAB3E8	2323 370799	VALENTINA ERMAKOVA	{"phone": "+70110799396"}
0005434980164	461722	9135 038994	SERGEY BONDARENKO	{"email": "sergey_bondarenko_1973@postgrespro.ru", "phone": "+70868956655"}
0005434980165	61A6C4	4424 855195	MAKSIM SCHERBAKOV	{"email": "scherbakov-m1961@postgrespro.ru", "phone": "+70624458138"}
0005434980166	9A3573	5603 655396	SERGEY BORISOV	{"email": "sborisov.041980@postgrespro.ru", "phone": "+70746913238"}
0005434980167	6064A4	1089 923104	ELENA STEPANOVA	{"phone": "+70485562043"}
0005434980168	C5C747	9409 333237	GALINA AKIMOVA	{"phone": "+70715595061"}
0005434980169	2B540F	4993 206783	ZINAIDA FROLOVA	{"phone": "+70815116391"}
0005434980170	2B540F	7185 160719	OLGA KOLESNIKOVA	{"phone": "+70053236024"}
0005434980171	2EBDFB	6543 673194	VIKTOR ORLOV	{"phone": "+70732196664"}
0005434980172	1D74F2	9563 857768	EGOR NAZAROV	{"phone": "+70359344712"}
0005434980173	D763B0	6375 698079	ANNA OSIPOVA	{"phone": "+70452559376"}
0005434980174	D763B0	7423 665237	GENNADIY KARPOV	{"email": "karpov.g-081968@postgrespro.ru", "phone": "+70118686315"}
0005434980175	AEBC03	3733 279841	ELENA POPOVA	{"phone": "+70023606050"}
0005434980176	AEBC03	2197 336002	OLEG CHERNOV	{"email": "o-chernov.1968@postgrespro.ru", "phone": "+70672004061"}
0005434980177	9D0F80	4714 506156	VITALIY MIKHAYLOV	{"email": "mikhaylovv_1975@postgrespro.ru", "phone": "+70587167793"}
0005434980178	F12947	4799 056274	OKSANA MEDVEDEVA	{"phone": "+70839154861"}
0005434980179	6B017D	1329 951439	VLADIMIR KUDRYASHOV	{"email": "vladimir.kudryashov_30081968@postgrespro.ru", "phone": "+70168593861"}
0005434980180	5B15A7	8020 231274	ANDREY VASILEV	{"phone": "+70872538916"}
0005434980181	D8FCDD	4212 546255	LYUDMILA FILATOVA	{"email": "l_filatova26111977@postgrespro.ru", "phone": "+70661540041"}
0005434980182	0C1968	4947 157833	IRINA OSIPOVA	{"phone": "+70231972128"}
0005434980183	0C1968	3290 931417	ALENA ALEKSANDROVA	{"email": "a.aleksandrova30031981@postgrespro.ru", "phone": "+70512328634"}
0005434980184	F9DD2A	1361 704743	DMITRIY MAKAROV	{"email": "dmitriy.makarov.1966@postgrespro.ru", "phone": "+70514410702"}
0005434980185	C10D95	8348 719412	ARINA SOKOLOVA	{"phone": "+70395892601"}
0005434980186	C10D95	3464 111854	MARIYA YUDINA	{"email": "yudinam-1986@postgrespro.ru", "phone": "+70264209932"}
0005434980187	2C95A4	9641 101544	LYUBOV MAKAROVA	{"email": "lyubov_makarova051978@postgrespro.ru", "phone": "+70494961317"}
0005434980188	E74E9A	5646 582882	OLGA ILINA	{"phone": "+70561718536"}
0005434980189	317E1F	4318 711763	VIKTOR MIKHAYLOV	{"phone": "+70667809616"}
0005434980190	2663CB	2492 136499	PAVEL KULIKOV	{"email": "pavel-kulikov-1989@postgrespro.ru", "phone": "+70538417809"}
0005434980191	2663CB	1730 378867	OLGA MOROZOVA	{"email": "morozovao101982@postgrespro.ru", "phone": "+70666055849"}
0005434980192	EF99B3	6509 925880	EVDOKIYA DENISOVA	{"email": "denisova_evdokiya051976@postgrespro.ru", "phone": "+70969797573"}
0005434980193	D9DBAA	0782 617684	ALEKSANDR MELNIKOV	{"phone": "+70445915575"}
0005434980194	769E11	2226 071005	YURIY KOROLEV	{"email": "korolevy041974@postgrespro.ru", "phone": "+70526157960"}
0005434980195	769E11	3997 390743	ANNA OSIPOVA	{"email": "anna_osipova_1970@postgrespro.ru", "phone": "+70912165105"}
0005434980196	79A619	8929 184719	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov-1965@postgrespro.ru", "phone": "+70609110205"}
0005434980197	611DD0	4189 896962	VENERA FILIPPOVA	{"phone": "+70593211981"}
0005434980198	7BDC0F	0268 723881	ELENA POLYAKOVA	{"phone": "+70835287040"}
0005434980199	7BDC0F	7052 223538	KSENIYA MAKAROVA	{"email": "k_makarova1979@postgrespro.ru", "phone": "+70057671353"}
0005434980200	731CBB	4890 692357	VLADISLAV SCHERBAKOV	{"email": "scherbakov.v-061968@postgrespro.ru", "phone": "+70681165081"}
0005434980201	263B08	7152 178318	ALEKSEY KUZNECOV	{"email": "kuznecov.a.081974@postgrespro.ru", "phone": "+70477515591"}
0005434980202	263B08	8959 903596	RAISA VOLKOVA	{"email": "volkova.r-1972@postgrespro.ru", "phone": "+70418788519"}
0005434980203	A10511	2418 575384	ALEKSANDR SOKOLOV	{"phone": "+70864007216"}
0005434980204	A10511	5759 740358	NATALYA IVANOVA	{"phone": "+70380239969"}
0005434980205	FD5D99	5669 764125	DARYA MASLOVA	{"phone": "+70661909155"}
0005434980206	1BDDFF	4342 232391	DMITRIY TIMOFEEV	{"phone": "+70994790209"}
0005434980207	00E404	3399 489747	ALENA SOKOLOVA	{"email": "sokolovaalena.1966@postgrespro.ru", "phone": "+70277260544"}
0005434980208	3566E7	9496 979691	NATALIYA KUZMINA	{"phone": "+70925955267"}
0005434980209	3566E7	0342 760513	NIKOLAY KRASNOV	{"phone": "+70429153967"}
0005434980210	A004F4	9291 272876	MIKHAIL PAVLOV	{"phone": "+70259722564"}
0005434980211	A004F4	1573 592288	NIKITA SERGEEV	{"email": "n_sergeev_1969@postgrespro.ru", "phone": "+70641280069"}
0005434980212	07BB5F	0237 950269	DMITRIY SEMENOV	{"phone": "+70957239252"}
0005434980213	841069	8747 268847	VALENTINA OSIPOVA	{"email": "v_osipova28011983@postgrespro.ru", "phone": "+70345180889"}
0005434980214	841069	9553 683348	ANTONINA KUZNECOVA	{"email": "kuznecova-antonina-05051967@postgrespro.ru", "phone": "+70137962512"}
0005434980215	841069	9693 429314	KONSTANTIN SCHERBAKOV	{"phone": "+70585774104"}
0005434980216	841069	4043 434339	ALEKSANDR NIKITIN	{"phone": "+70470996865"}
0005434980217	D073CA	4854 805873	TATYANA PETROVA	{"phone": "+70012380828"}
0005434980218	D073CA	7901 499756	SVETLANA LEBEDEVA	{"email": "lebedeva.svetlana-16091971@postgrespro.ru", "phone": "+70532672353"}
0005434980219	D073CA	2611 079011	ANDREY GAVRILOV	{"phone": "+70844699930"}
0005434980220	880B61	1418 265433	NINA KOROLEVA	{"phone": "+70767364631"}
0005434980221	D9EB9C	2201 300736	ANDREY MATVEEV	{"phone": "+70205686115"}
0005434980222	D9EB9C	6192 887011	LADA SIDOROVA	{"phone": "+70129650290"}
0005434980223	8D55B3	1533 386222	OLESYA MAKAROVA	{"email": "makarova.o_08011961@postgrespro.ru", "phone": "+70952516775"}
0005434980224	8D55B3	1261 658016	EKATERINA EGOROVA	{"email": "egorova.e_15121969@postgrespro.ru", "phone": "+70610348130"}
0005434980225	8220BA	2147 723877	OLGA MATVEEVA	{"phone": "+70772246532"}
0005434980226	8220BA	7740 548211	ALEKSEY ANDREEV	{"email": "aleksey_andreev_041967@postgrespro.ru", "phone": "+70423431314"}
0005434980227	939E09	7571 798553	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov051979@postgrespro.ru", "phone": "+70481629564"}
0005434980228	939E09	1938 062791	MARINA TIKHONOVA	{"email": "tikhonova.m-041967@postgrespro.ru", "phone": "+70235612760"}
0005434980229	939E09	5544 503407	ANDREY ROMANOV	{"email": "andreyromanov_1965@postgrespro.ru", "phone": "+70495094316"}
0005434980230	644B8E	0760 129803	ELENA GORBUNOVA	{"email": "e.gorbunova1969@postgrespro.ru", "phone": "+70465649421"}
0005434980231	4539E6	8061 864960	ANATOLIY IVANOV	{"email": "ivanov_anatoliy_19111967@postgrespro.ru", "phone": "+70797307984"}
0005434980232	A12DD9	2327 580077	MARGARITA STEPANOVA	{"email": "stepanovam-1979@postgrespro.ru", "phone": "+70505705899"}
0005434980233	93F6DB	9348 073303	TATYANA BARANOVA	{"email": "baranovatatyana1980@postgrespro.ru", "phone": "+70267741046"}
0005434980234	ACC6AD	6764 459902	SERAFIM RODIONOV	{"phone": "+70225078342"}
0005434980235	ACC6AD	9149 086019	DMITRIY ZHUKOV	{"phone": "+70789746689"}
0005434980236	3C0287	6879 020579	LYUBOV KAZAKOVA	{"email": "lkazakova.111972@postgrespro.ru", "phone": "+70215870838"}
0005434980237	CBC4A8	4649 525608	VALERIYA ZAKHAROVA	{"email": "valeriya_zakharova-05061979@postgrespro.ru", "phone": "+70410650307"}
0005434980238	CBC4A8	0808 717266	ALEKSEY SOKOLOV	{"phone": "+70029276508"}
0005434980239	D4A610	6680 602112	RUSLAN SAVELEV	{"phone": "+70331422556"}
0005434980240	B33544	9841 110568	TATYANA DENISOVA	{"email": "tatyana.denisova-02091980@postgrespro.ru", "phone": "+70174193993"}
0005434980241	B33544	3084 521692	ANNA PETROVA	{"email": "petrova-anna_061961@postgrespro.ru", "phone": "+70991105554"}
0005434980242	1E3CA1	0887 004705	TATYANA STEPANOVA	{"email": "t_stepanova_061970@postgrespro.ru", "phone": "+70021207265"}
0005434980243	7E707D	9014 104168	VLADIMIR EGOROV	{"email": "vladimiregorov_1969@postgrespro.ru", "phone": "+70797887839"}
0005434980244	7E707D	1887 233313	ZOYA MALYSHEVA	{"phone": "+70141238288"}
0005434980245	7B5C45	2563 274443	RUSTAM IVANOV	{"phone": "+70388021751"}
0005434980246	7B5C45	7851 863993	TATYANA NESTEROVA	{"email": "tatyana_nesterova09101983@postgrespro.ru", "phone": "+70690760459"}
0005434980247	620EAA	5605 522883	ALEKSANDR YAKOVLEV	{"email": "yakovlev.a1956@postgrespro.ru", "phone": "+70843690960"}
0005434980248	FD3AFD	8687 209349	VIKTORIYA KOZLOVA	{"email": "kozlovaviktoriya1981@postgrespro.ru", "phone": "+70429037908"}
0005434980249	2DC759	2107 001146	LYUDMILA ZAKHAROVA	{"email": "zakharova-l.04081975@postgrespro.ru", "phone": "+70444150098"}
0005434980250	2DC759	7875 843797	ALEKSANDRA MAKAROVA	{"phone": "+70976971732"}
0005434980251	9B622F	3091 529453	SERGEY ANTONOV	{"email": "antonovsergey_111968@postgrespro.ru", "phone": "+70516651356"}
0005434980252	626032	5261 033290	IVAN VASILEV	{"phone": "+70854534148"}
0005434980253	19B4D2	1361 016733	RAISA PAVLOVA	{"email": "r.pavlova-1985@postgrespro.ru", "phone": "+70337529526"}
0005434980254	19B4D2	3680 512808	VALERIYA KONOVALOVA	{"phone": "+70007020899"}
0005434980255	AFA43D	4054 735811	VLADIMIR DMITRIEV	{"phone": "+70311537057"}
0005434980256	B3D112	6121 902211	YULIYA FADEEVA	{"phone": "+70679463688"}
0005434980257	FF0862	1850 563235	ALEKSEY CHERNOV	{"email": "a_chernov101964@postgrespro.ru", "phone": "+70197001753"}
0005434980258	595F90	0173 133743	VALERIY KUZNECOV	{"email": "kuznecov_valeriy.091978@postgrespro.ru", "phone": "+70026367970"}
0005434980259	91FA84	0600 145139	VLADIMIR NIKOLAEV	{"email": "vladimir-nikolaev041972@postgrespro.ru", "phone": "+70369964042"}
0005434980260	404770	2477 315563	LYUDMILA NAUMOVA	{"phone": "+70515936230"}
0005434980261	2E872F	6542 762592	MARINA AKIMOVA	{"phone": "+70964262797"}
0005434980262	61B27E	9417 326346	NINA ISAEVA	{"phone": "+70774204242"}
0005434980263	2CE4BC	4094 125565	NIKOLAY PAVLOV	{"phone": "+70871782436"}
0005434980264	F59260	8547 267033	OLEG YAKOVLEV	{"phone": "+70612969541"}
0005434980265	8302BD	3761 140808	NINA YUDINA	{"email": "yudina_nina_071981@postgrespro.ru", "phone": "+70544002926"}
0005434980266	8302BD	1694 388027	ZAKHAR ZAKHAROV	{"phone": "+70955450516"}
0005434980267	EC9F39	5777 209635	ANNA MATVEEVA	{"email": "matveevaanna-061964@postgrespro.ru", "phone": "+70087124498"}
0005434980268	EC9F39	9313 385309	DMITRIY ALEKSANDROV	{"phone": "+70511535229"}
0005434980269	FE37E2	9756 310255	ALEKSANDR ANDREEV	{"phone": "+70884012247"}
0005434980270	FE37E2	3595 381938	SERGEY NIKITIN	{"email": "nikitin-sergey.1971@postgrespro.ru", "phone": "+70814881372"}
0005434980271	FE37E2	2552 325198	ALINA PETROVA	{"email": "petrova.alina121966@postgrespro.ru", "phone": "+70598983247"}
0005434980272	FE37E2	9937 087276	ANNA ALEKSEEVA	{"phone": "+70598880999"}
0005434980331	024455	2744 411784	DIANA TARASOVA	{"phone": "+70198995288"}
0005434980273	5199BB	5463 588761	ELENA KAZAKOVA	{"email": "kazakovaelena-1977@postgrespro.ru", "phone": "+70673133408"}
0005434980274	5199BB	4749 149970	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov08091970@postgrespro.ru", "phone": "+70048874956"}
0005434980275	87AFC4	2388 336247	GEORGIY ANDREEV	{"phone": "+70545229152"}
0005434980276	87AFC4	2742 098144	YULIYA NAZAROVA	{"email": "nazarova.yuliya1972@postgrespro.ru", "phone": "+70794742761"}
0005434980277	750192	0621 986058	NATALYA ALEKSEEVA	{"email": "alekseevanatalya_1976@postgrespro.ru", "phone": "+70276574662"}
0005434980278	395B66	8020 044699	LILIYA AFANASEVA	{"email": "l_afanaseva1964@postgrespro.ru", "phone": "+70779191559"}
0005434980279	DD1C67	3755 725814	ANNA GUSEVA	{"email": "a_guseva-021970@postgrespro.ru", "phone": "+70995874516"}
0005434980280	E11074	8210 791066	NIKOLAY KOZLOV	{"phone": "+70774740530"}
0005434980281	93B6B6	7131 548712	TATYANA MARTYNOVA	{"email": "martynova-t_081964@postgrespro.ru", "phone": "+70153121107"}
0005434980282	9445A8	1613 401892	YULIYA KISELEVA	{"email": "kiselevay_041963@postgrespro.ru", "phone": "+70571938256"}
0005434980283	E9728F	1913 485868	MARINA ZHUKOVA	{"email": "zhukova.m1971@postgrespro.ru", "phone": "+70456436037"}
0005434980284	7A78BC	8958 937691	NIKITA SOKOLOV	{"phone": "+70773685920"}
0005434980285	F5EEF5	3528 424626	MARIYA KOMAROVA	{"phone": "+70157487501"}
0005434980286	0E37BA	5440 446089	ROMAN VOLKOV	{"phone": "+70244290375"}
0005434980287	519000	7323 721744	TATYANA KOZLOVA	{"phone": "+70848568321"}
0005434980288	519000	7431 165172	LILIYA GAVRILOVA	{"email": "l.gavrilova_23101968@postgrespro.ru", "phone": "+70964748407"}
0005434980289	6977E7	7036 212349	ALISA NIKITINA	{"phone": "+70735172816"}
0005434980290	6977E7	9367 161651	LARISA VOLKOVA	{"phone": "+70943428313"}
0005434980291	C920BB	1430 199104	ALEKSANDR GORBUNOV	{"email": "agorbunov-041968@postgrespro.ru", "phone": "+70413574886"}
0005434980292	C920BB	6663 086155	TATYANA ALEKSEEVA	{"phone": "+70754663142"}
0005434980293	1813C8	3198 444277	YULIYA LAZAREVA	{"email": "lazareva.y-10071982@postgrespro.ru", "phone": "+70506341044"}
0005434980294	CD1824	9984 787846	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr-071964@postgrespro.ru", "phone": "+70511885724"}
0005434980295	CD1824	7321 178403	MAKSIM ORLOV	{"email": "orlov_maksim.1962@postgrespro.ru", "phone": "+70858642359"}
0005434980296	360AE8	8074 070652	TATYANA NOVIKOVA	{"email": "tatyananovikova_08061975@postgrespro.ru", "phone": "+70074927638"}
0005434980297	360AE8	1424 439187	NATALYA KUZNECOVA	{"email": "kuznecovan29031975@postgrespro.ru", "phone": "+70135079776"}
0005434980298	495F04	3123 762362	VERA SAVELEVA	{"email": "v-saveleva07041970@postgrespro.ru", "phone": "+70085720795"}
0005434980299	37A4D3	6424 554954	ELENA BARANOVA	{"phone": "+70680481703"}
0005434980300	37A4D3	1565 593453	VALERIY MAKAROV	{"email": "makarovvaleriy1970@postgrespro.ru", "phone": "+70243890408"}
0005434980301	44A333	8037 887207	MAKSIM POPOV	{"email": "mpopov_26031969@postgrespro.ru", "phone": "+70685260788"}
0005434980302	44A333	0366 863168	DENIS STEPANOV	{"email": "stepanov_d28111965@postgrespro.ru", "phone": "+70704949503"}
0005434980303	D2A6B0	5701 370213	IVAN MOISEEV	{"phone": "+70560947193"}
0005434980304	EA1D11	3372 966885	TAMARA FADEEVA	{"phone": "+70311281054"}
0005434980305	10A832	2492 001773	ALEKSANDR SIDOROV	{"email": "sidorov-aleksandr071972@postgrespro.ru", "phone": "+70289148427"}
0005434980306	86F335	1280 300606	SERGEY IVANOV	{"email": "ivanovs_21091970@postgrespro.ru", "phone": "+70961986924"}
0005434980307	B28865	2290 745466	SERGEY FEDOTOV	{"email": "s_fedotov-1970@postgrespro.ru", "phone": "+70414659269"}
0005434980308	B28865	6936 071585	EVGENIY TIMOFEEV	{"phone": "+70017077813"}
0005434980309	B28865	5299 041504	MARIYA FROLOVA	{"phone": "+70182182302"}
0005434980310	0C68A4	8197 012517	VLADIMIR SAVELEV	{"email": "vladimirsavelev17011983@postgrespro.ru", "phone": "+70837286723"}
0005434980311	2F8D45	4194 334863	YURIY DAVYDOV	{"email": "y_davydov.08091974@postgrespro.ru", "phone": "+70011118514"}
0005434980312	2F8D45	7440 033054	LYUDMILA TITOVA	{"phone": "+70213845381"}
0005434980313	1DE06A	0355 338969	PETR ANDREEV	{"phone": "+70709305628"}
0005434980314	A348FC	2136 144196	SERGEY KUZMIN	{"phone": "+70219765314"}
0005434980315	A348FC	0372 475461	VLADIMIR KUZMIN	{"phone": "+70076366554"}
0005434980316	A348FC	3040 536941	RAISA KUZNECOVA	{"phone": "+70132378442"}
0005434980317	3FA540	4096 112559	LYUBOV ZHUKOVA	{"email": "lyubovzhukova.1958@postgrespro.ru", "phone": "+70465688134"}
0005434980318	EC41E4	0629 778645	VLADISLAV PAVLOV	{"email": "pavlov.v-02081958@postgrespro.ru", "phone": "+70576519886"}
0005434980319	057658	7335 799634	ALEKSANDR MATVEEV	{"email": "aleksandr.matveev_071971@postgrespro.ru", "phone": "+70802628055"}
0005434980320	95A4F5	2098 467787	VALERIY FOMIN	{"email": "fominv-1959@postgrespro.ru", "phone": "+70552216648"}
0005434980321	09F433	2806 002869	YANA SOKOLOVA	{"email": "sokolova.yana_041955@postgrespro.ru", "phone": "+70460845045"}
0005434980322	FDC18B	1943 680083	ELENA ISAEVA	{"email": "elena-isaeva.28031975@postgrespro.ru", "phone": "+70624506826"}
0005434980323	58356A	2739 375365	NIKITA NIKOLAEV	{"email": "nikolaev-n_041965@postgrespro.ru", "phone": "+70129273561"}
0005434980324	404275	5546 866576	ALEKSANDRA SOROKINA	{"email": "asorokina061964@postgrespro.ru", "phone": "+70190718977"}
0005434980325	D56888	8093 963863	GALINA KRASNOVA	{"phone": "+70959081436"}
0005434980326	D56888	3537 440343	ALLA BELYAEVA	{"email": "a-belyaeva.061984@postgrespro.ru", "phone": "+70844146904"}
0005434980327	D965D2	7023 729649	ALEKSANDR KARPOV	{"email": "aleksandr_karpov.15041978@postgrespro.ru", "phone": "+70299185974"}
0005434980328	D965D2	7647 413556	OLEG TIKHONOV	{"email": "tikhonov_o031981@postgrespro.ru", "phone": "+70051898376"}
0005434980329	E7C452	7374 471549	ALEKSANDR PAVLOV	{"phone": "+70762134263"}
0005434980330	E7C452	8283 981223	NADEZHDA CHERNOVA	{"email": "chernova-nadezhda.1976@postgrespro.ru", "phone": "+70015577179"}
0005434980332	024455	8475 241800	OLGA ZAKHAROVA	{"phone": "+70684017264"}
0005434980333	511DD2	9536 665504	OLGA ZHURAVLEVA	{"email": "zhuravlevao091977@postgrespro.ru", "phone": "+70353244364"}
0005434980334	0E3258	5450 683491	NIKITA FOMIN	{"phone": "+70439480303"}
0005434980335	B28E01	7518 816267	LARISA ALEKSEEVA	{"email": "l.alekseeva_23021967@postgrespro.ru", "phone": "+70400582197"}
0005434980336	41C360	4228 786450	ANDREY AFANASEV	{"phone": "+70593617943"}
0005434980337	0807EF	9429 461892	POLINA KUZMINA	{"email": "kuzmina.p.1962@postgrespro.ru", "phone": "+70853247150"}
0005434980338	572564	7651 566246	YULIYA MOISEEVA	{"email": "y-moiseeva091973@postgrespro.ru", "phone": "+70341926767"}
0005434980339	5630F0	7276 564168	DMITRIY ABRAMOV	{"phone": "+70835632912"}
0005434980340	0EF48E	3798 727642	KRISTINA EGOROVA	{"phone": "+70672768714"}
0005434980341	96A98E	6284 208695	MAKSIM FROLOV	{"phone": "+70634778475"}
0005434980399	0178F3	6474 959303	VLADIMIR SCHERBAKOV	{"phone": "+70224517445"}
0005434980342	8725A2	2992 812991	VIKTOR ANDREEV	{"email": "andreev.viktor1969@postgrespro.ru", "phone": "+70083269928"}
0005434980343	EEFBA0	3005 628279	SERGEY BORISOV	{"phone": "+70154727273"}
0005434980344	EEFBA0	9392 911970	GALINA PAVLOVA	{"email": "gpavlova111976@postgrespro.ru", "phone": "+70583607284"}
0005434980345	BCA609	3951 654198	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr.11111971@postgrespro.ru", "phone": "+70856738421"}
0005434980346	BCA609	8576 260599	ELIZAVETA ANTONOVA	{"phone": "+70327557209"}
0005434980347	419E27	9205 919163	GULNARA YAKOVLEVA	{"email": "yakovleva-g.031980@postgrespro.ru", "phone": "+70279221548"}
0005434980348	6DFB05	1852 133002	TATYANA MATVEEVA	{"phone": "+70660778556"}
0005434980349	6DFB05	7277 142833	ANNA KUZMINA	{"phone": "+70670573522"}
0005434980350	7F921E	1139 366013	ZINAIDA FOMINA	{"email": "z-fomina031986@postgrespro.ru", "phone": "+70856606139"}
0005434980351	B23BA4	0277 710308	TATYANA CHERNOVA	{"phone": "+70706794227"}
0005434980352	B23BA4	9460 395818	NINA NAZAROVA	{"phone": "+70377177582"}
0005434980353	164167	0010 593565	ANATOLIY FEDOROV	{"email": "fedorov-a_1981@postgrespro.ru", "phone": "+70099421515"}
0005434980354	CD380C	6366 578005	VALENTINA SCHERBAKOVA	{"phone": "+70305010003"}
0005434980355	0CB513	7941 219461	MARIYA GUSEVA	{"phone": "+70601210103"}
0005434980356	1BD055	4391 617701	MIKHAIL NIKITIN	{"phone": "+70216104092"}
0005434980357	E71446	0357 532518	MARIYA VASILEVA	{"email": "m-vasileva17111968@postgrespro.ru", "phone": "+70575718281"}
0005434980358	4A1EE3	5211 523776	VLADISLAV KARPOV	{"email": "karpovvladislav_14121969@postgrespro.ru", "phone": "+70929819259"}
0005434980359	D3E05E	7441 093232	ANNA BOGDANOVA	{"email": "bogdanovaa.12021961@postgrespro.ru", "phone": "+70050952572"}
0005434980360	DB8842	1403 149211	VLADISLAV FEDOROV	{"email": "v.fedorov-1967@postgrespro.ru", "phone": "+70956952225"}
0005434980361	3F3BBF	2262 633810	VALERIY VOLKOV	{"phone": "+70796202879"}
0005434980362	C195DC	3545 370230	ALEKSANDR OSIPOV	{"phone": "+70675287283"}
0005434980363	DBCB42	3674 054486	YURIY SOKOLOV	{"phone": "+70829456714"}
0005434980364	452728	3484 972316	RAISA FROLOVA	{"phone": "+70749914124"}
0005434980365	452728	6313 813643	OKSANA ANISIMOVA	{"phone": "+70459190649"}
0005434980366	985B69	7305 350006	ARINA KOZLOVA	{"email": "akozlova.1974@postgrespro.ru", "phone": "+70988945661"}
0005434980367	985B69	6080 633147	VALERIY ANTONOV	{"phone": "+70571134702"}
0005434980368	985B69	2232 052154	MARINA PETROVA	{"email": "petrova-m.011969@postgrespro.ru", "phone": "+70566424195"}
0005434980369	12430B	2448 971307	MARGARITA VASILEVA	{"email": "vasileva-m-1980@postgrespro.ru", "phone": "+70550563073"}
0005434980370	12430B	6104 989735	VASILIY NOVIKOV	{"email": "vasiliy.novikov_1971@postgrespro.ru", "phone": "+70274870629"}
0005434980371	12430B	3370 130377	VALENTINA MEDVEDEVA	{"phone": "+70883052773"}
0005434980372	E9E915	8570 755171	POLINA SOROKINA	{"phone": "+70197781079"}
0005434980373	E9E915	0405 800311	OLGA KOMAROVA	{"email": "komarova_olga061976@postgrespro.ru", "phone": "+70640734707"}
0005434980374	E9E915	0389 520446	DANIL EGOROV	{"email": "egorov-danil10061968@postgrespro.ru", "phone": "+70319061094"}
0005434980375	3A7F3F	7461 889433	ALEKSANDR SMIRNOV	{"phone": "+70845670557"}
0005434980376	8DF061	4363 702972	ELENA SOKOLOVA	{"phone": "+70877046737"}
0005434980377	8DF061	2567 543336	PAVEL ALEKSEEV	{"phone": "+70719110937"}
0005434980378	8DF061	9184 652560	LYUDMILA KOROLEVA	{"phone": "+70904161932"}
0005434980379	979FBB	7512 449828	NINA YUDINA	{"email": "yudinanina_1967@postgrespro.ru", "phone": "+70013401883"}
0005434980380	F59513	8495 513745	SERGEY YAKOVLEV	{"phone": "+70285874234"}
0005434980381	F59513	1881 287705	EGOR KARPOV	{"phone": "+70874051112"}
0005434980382	D1FACE	4407 315087	TATYANA SMIRNOVA	{"email": "smirnovatatyana051983@postgrespro.ru", "phone": "+70254918997"}
0005434980383	D1FACE	5031 087913	NATALYA FADEEVA	{"email": "fadeeva-n-101964@postgrespro.ru", "phone": "+70510126344"}
0005434980384	E074BC	4763 745226	DMITRIY IVANOV	{"phone": "+70308695102"}
0005434980385	801D99	0131 238185	IRINA MAKSIMOVA	{"email": "imaksimova_011971@postgrespro.ru", "phone": "+70876362383"}
0005434980386	801D99	9375 613140	VADIM KUZNECOV	{"phone": "+70055363339"}
0005434980387	DCBDE7	1841 843871	SERGEY KRASNOV	{"phone": "+70202613286"}
0005434980388	7F7A86	3450 144936	KSENIYA SMIRNOVA	{"phone": "+70960205233"}
0005434980389	3DB3D7	9435 418532	RUSTEM FEDOTOV	{"phone": "+70501638362"}
0005434980390	CF9182	1601 885442	ELENA PETROVA	{"phone": "+70700832122"}
0005434980391	F9DE82	5057 316386	NATALYA DAVYDOVA	{"email": "n.davydova.25091975@postgrespro.ru", "phone": "+70977750114"}
0005434980392	620ED0	2698 281374	LYUDMILA MARTYNOVA	{"email": "lyudmila_martynova071969@postgrespro.ru", "phone": "+70122465467"}
0005434980393	525D54	4946 219972	NADEZHDA BORISOVA	{"phone": "+70217644695"}
0005434980394	525D54	9597 712053	OLGA KAZAKOVA	{"email": "kazakova.olga.111967@postgrespro.ru", "phone": "+70520722373"}
0005434980395	EBB06F	1336 685344	ALEKSEY MOROZOV	{"phone": "+70980080534"}
0005434980396	EFAC3E	7390 903955	ELENA OSIPOVA	{"phone": "+70685928414"}
0005434980397	F03993	1233 183210	RUSLAN SHEVCHENKO	{"phone": "+70703195244"}
0005434980398	F03993	0940 272324	ELENA FADEEVA	{"phone": "+70138784149"}
0005434980400	1FD74A	5456 049909	DMITRIY AFANASEV	{"phone": "+70923132608"}
0005434980401	05F612	1270 050439	DMITRIY GAVRILOV	{"phone": "+70957778959"}
0005434980402	6F337E	5825 922583	NADEZHDA KOVALEVA	{"phone": "+70276548090"}
0005434980403	51DACD	9307 498628	ALEKSEY FEDOROV	{"email": "aleksey-fedorov-1983@postgrespro.ru", "phone": "+70956499395"}
0005434980404	3B681C	6731 389928	NADEZHDA GERASIMOVA	{"email": "nadezhda_gerasimova1973@postgrespro.ru", "phone": "+70161183479"}
0005434980405	D61016	6980 148630	EVGENIY MOISEEV	{"email": "evgeniymoiseev.25011976@postgrespro.ru", "phone": "+70215017630"}
0005434980406	5EBA7C	7219 849005	NADEZHDA ABRAMOVA	{"phone": "+70291056648"}
0005434980407	172C04	4272 669132	TATYANA VASILEVA	{"email": "t_vasileva.09091970@postgrespro.ru", "phone": "+70625750512"}
0005434980408	172C04	9513 170111	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr1971@postgrespro.ru", "phone": "+70831429460"}
0005434980409	0035EC	5088 685371	DMITRIY ROMANOV	{"email": "romanov_d.06011978@postgrespro.ru", "phone": "+70925633013"}
0005434980410	0035EC	9657 995414	MIKHAIL IVANOV	{"phone": "+70717355545"}
0005434980411	DB5F39	6999 533546	OLESYA EFIMOVA	{"phone": "+70956654941"}
0005434980412	DB5F39	9991 036830	LYUBOV NESTEROVA	{"phone": "+70178157016"}
0005434980413	13FA92	2282 713132	YURIY SOKOLOV	{"email": "sokolov.y_061965@postgrespro.ru", "phone": "+70741938559"}
0005434980414	916A00	1421 576528	GENNADIY RODIONOV	{"email": "rodionovgennadiy-041978@postgrespro.ru", "phone": "+70304797920"}
0005434980415	916A00	6490 550926	ILYA BELOV	{"email": "belov-ilya_101974@postgrespro.ru", "phone": "+70329415779"}
0005434980416	8D4E62	4898 279885	YULIYA KOMAROVA	{"email": "ykomarova1964@postgrespro.ru", "phone": "+70136758314"}
0005434980417	8D4E62	5345 011333	DMITRIY MIKHAYLOV	{"email": "d.mikhaylov061971@postgrespro.ru", "phone": "+70369376382"}
0005434980418	D92182	4825 419827	SERGEY PAVLOV	{"email": "pavlov_s27091965@postgrespro.ru", "phone": "+70929953598"}
0005434980419	362613	0728 212641	SVETLANA KUDRYASHOVA	{"phone": "+70670793111"}
0005434980420	9C83CA	6239 986659	ALEKSANDR FOMIN	{"email": "fomin-a071984@postgrespro.ru", "phone": "+70067292122"}
0005434980421	3102BC	9036 841428	VALENTINA VOROBEVA	{"phone": "+70755477352"}
0005434980422	3102BC	5824 321623	MIKHAIL SMIRNOV	{"email": "m-smirnov-121967@postgrespro.ru", "phone": "+70133749742"}
0005434980423	891F4F	0761 321113	IRINA FOMINA	{"phone": "+70937513429"}
0005434980424	62451F	3752 600759	ELENA ALEKSANDROVA	{"email": "aleksandrova.e-1972@postgrespro.ru", "phone": "+70862326818"}
0005434980425	EB92F7	3217 667700	ELENA ZAKHAROVA	{"email": "ezakharova.16011975@postgrespro.ru", "phone": "+70372574264"}
0005434980426	7BA665	4814 790019	LYUDMILA RODIONOVA	{"phone": "+70414154464"}
0005434980427	653C3E	5876 252356	NATALYA NIKITINA	{"email": "n.nikitina-22051969@postgrespro.ru", "phone": "+70418094679"}
0005434980428	653C3E	2189 579356	ANATOLIY SMIRNOV	{"phone": "+70335385382"}
0005434980429	653C3E	4007 050581	NIKOLAY KISELEV	{"email": "nikolay_kiselev-03081971@postgrespro.ru", "phone": "+70584016217"}
0005434980430	C473CD	9096 438980	ANNA NAZAROVA	{"email": "anna-nazarova-041980@postgrespro.ru", "phone": "+70764931792"}
0005434980431	C473CD	7771 553618	NIKOLAY ANDREEV	{"email": "nandreev-03111967@postgrespro.ru", "phone": "+70340743104"}
0005434980432	C473CD	2577 272166	DMITRIY SEMENOV	{"email": "semenovd-1983@postgrespro.ru", "phone": "+70363822809"}
0005434980433	3D9F74	6125 846774	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr_23051972@postgrespro.ru", "phone": "+70697706978"}
0005434980434	74C6D2	3090 158246	TATYANA KARPOVA	{"phone": "+70438023137"}
0005434980435	E24AF4	5407 826285	VALENTINA DENISOVA	{"phone": "+70763644904"}
0005434980436	E24AF4	5866 551864	IGOR FEDOROV	{"phone": "+70562844657"}
0005434980437	309E77	9340 995820	LYUDMILA KOVALEVA	{"email": "lyudmila_kovaleva061968@postgrespro.ru", "phone": "+70689934141"}
0005434980438	309E77	3009 865050	VIKTOR MAKAROV	{"phone": "+70958311911"}
0005434980439	7B5E1D	4566 267699	ALEKSANDR POPOV	{"phone": "+70133857837"}
0005434980440	7B5E1D	6856 389809	MARIYA KAZAKOVA	{"email": "kazakovamariya.1959@postgrespro.ru", "phone": "+70850335751"}
0005434980441	7B5E1D	8793 221329	EVGENIY KUZNECOV	{"email": "evgeniy.kuznecov.20061977@postgrespro.ru", "phone": "+70325274342"}
0005434980442	2B6278	6538 775865	EVGENIY ABRAMOV	{"phone": "+70762357272"}
0005434980443	764A6B	8341 140863	IVAN MAKSIMOV	{"phone": "+70182347148"}
0005434980444	764A6B	6231 582229	RASHID GORBUNOV	{"phone": "+70459561893"}
0005434980445	46069F	8873 159253	ELENA KUZNECOVA	{"email": "elena.kuznecova.10071970@postgrespro.ru", "phone": "+70858320756"}
0005434980446	F3372C	5838 465663	MARIYA MELNIKOVA	{"phone": "+70183646584"}
0005434980447	B11730	4115 788122	GALINA POLYAKOVA	{"email": "galinapolyakova-31051965@postgrespro.ru", "phone": "+70712681252"}
0005434980448	960939	8773 808594	KONSTANTIN SMIRNOV	{"email": "smirnov-konstantin1981@postgrespro.ru", "phone": "+70641799759"}
0005434980449	00F2E5	4570 073068	MAKSIM FOMIN	{"email": "fomin_m-111978@postgrespro.ru", "phone": "+70660660736"}
0005434980450	D371A5	2496 552679	ALEKSANDR KARPOV	{"email": "aleksandr.karpov071971@postgrespro.ru", "phone": "+70675697344"}
0005434980451	1B39CA	5219 214578	VALERIY BELOV	{"email": "v-belov.061966@postgrespro.ru", "phone": "+70750264836"}
0005434980452	1B39CA	6518 632027	VIKTORIYA EFIMOVA	{"email": "viktoriyaefimova-051971@postgrespro.ru", "phone": "+70388802295"}
0005434980453	D22CCA	6104 881609	ALEKSANDR ROMANOV	{"phone": "+70357563884"}
0005434980454	D22CCA	6559 370383	ELIZAVETA ILINA	{"phone": "+70284878093"}
0005434980455	D22CCA	4498 953147	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.aleksandr_17061978@postgrespro.ru", "phone": "+70153907939"}
0005434980456	6E839E	8149 483137	LYUDMILA CHERNOVA	{"email": "l.chernova07031972@postgrespro.ru", "phone": "+70353329076"}
0005434980457	0AF9B5	8182 666402	LYUBOV GORBUNOVA	{"phone": "+70215204220"}
0005434980458	0AF9B5	4516 645287	NINA SOROKINA	{"phone": "+70540357408"}
0005434980459	877709	2557 419939	SERGEY CHERNOV	{"phone": "+70421061877"}
0005434980460	03F05F	1746 732288	LYUDMILA SERGEEVA	{"phone": "+70917780334"}
0005434980461	E0906B	8667 819612	ALEKSANDR ZAKHAROV	{"email": "zakharov_aleksandr_1963@postgrespro.ru", "phone": "+70365257789"}
0005434980462	E0906B	4958 305863	ALEKSANDR KISELEV	{"phone": "+70813099204"}
0005434980463	E0906B	9515 154842	STANISLAV IVANOV	{"phone": "+70328736474"}
0005434980464	4B1211	8372 590722	IRINA OSIPOVA	{"phone": "+70908206700"}
0005434980465	E97B5F	5068 571144	OLGA BARANOVA	{"phone": "+70693328101"}
0005434980466	E97B5F	1881 731798	NIKOLAY KULIKOV	{"phone": "+70780027761"}
0005434980467	E97B5F	6781 487862	EKATERINA PAVLOVA	{"email": "e.pavlova-16011966@postgrespro.ru", "phone": "+70653969531"}
0005434980468	E6A6EC	4827 351253	VLADIMIR EGOROV	{"phone": "+70035751030"}
0005434980469	E6A6EC	4602 153728	GALINA IVANOVA	{"email": "givanova.15031971@postgrespro.ru", "phone": "+70298223821"}
0005434980470	F92FD8	8616 593733	RENAT KOZLOV	{"email": "kozlovrenat.101967@postgrespro.ru", "phone": "+70773127034"}
0005434980471	F92FD8	0994 950532	BORIS GUSEV	{"email": "gusev_b-071981@postgrespro.ru", "phone": "+70493942979"}
0005434980472	3CC8E0	9497 512873	ALEKSANDR FROLOV	{"email": "a-frolov19101979@postgrespro.ru", "phone": "+70656774168"}
0005434980473	430DCA	9093 653048	ROMAN FILIPPOV	{"phone": "+70847367132"}
0005434980474	430DCA	8235 061033	KARINA BOGDANOVA	{"phone": "+70386888337"}
0005434980475	4695EE	1171 050542	VIKTOR GRIGOREV	{"email": "viktor.grigorev-1981@postgrespro.ru", "phone": "+70358414258"}
0005434980476	187168	2204 370720	PAVEL POPOV	{"email": "popovpavel.091980@postgrespro.ru", "phone": "+70887285233"}
0005434980477	74E5B8	9088 498534	NATALYA MALYSHEVA	{"phone": "+70381305482"}
0005434980478	8C8ACC	6985 829974	VALENTINA KRASNOVA	{"email": "v.krasnova1962@postgrespro.ru", "phone": "+70051267581"}
0005434980479	D7047E	9956 804881	ANATOLIY NAZAROV	{"phone": "+70654983636"}
0005434980480	D7047E	7049 612398	TATYANA NIKITINA	{"email": "t_nikitina051970@postgrespro.ru", "phone": "+70586826420"}
0005434980481	7A59F6	5143 148483	OLESYA VLASOVA	{"email": "o_vlasova.11031971@postgrespro.ru", "phone": "+70300349230"}
0005434980482	4B1F9C	6704 186704	DMITRIY IVANOV	{"phone": "+70481903199"}
0005434980483	7B743F	6223 195686	IRINA BOGDANOVA	{"email": "irina_bogdanova.12031973@postgrespro.ru", "phone": "+70976353199"}
0005434980484	1101D7	3503 864136	ALINA ABRAMOVA	{"phone": "+70063318331"}
0005434980485	1101D7	8609 403575	RUFIYA BELOVA	{"email": "belova_rufiya.011960@postgrespro.ru", "phone": "+70921118483"}
0005434980486	396B34	2850 702137	ALEKSEY MEDVEDEV	{"phone": "+70361854613"}
0005434980487	E91179	3991 995214	LYUDMILA GUSEVA	{"email": "gusevalyudmila-1988@postgrespro.ru", "phone": "+70466787787"}
0005434980488	DC49BE	7976 085631	ALEKSANDR VASILEV	{"phone": "+70090458136"}
0005434980489	C6DB1F	4041 598546	VIKTORIYA PAVLOVA	{"email": "v_pavlova.06111984@postgrespro.ru", "phone": "+70203296849"}
0005434980490	4D6080	1430 252217	SOFIYA SAVELEVA	{"phone": "+70161066011"}
0005434980491	CB9774	5827 667505	TIMUR MATVEEV	{"email": "timur.matveev_31011965@postgrespro.ru", "phone": "+70063841687"}
0005434980492	E4B254	2119 804103	KIRILL MEDVEDEV	{"email": "kirill.medvedev-111964@postgrespro.ru", "phone": "+70452043243"}
0005434980493	E4B254	4801 128085	EVGENIYA AKIMOVA	{"email": "e.akimova091975@postgrespro.ru", "phone": "+70542586412"}
0005434980494	AB9566	5700 571007	VALENTINA KISELEVA	{"email": "valentina-kiseleva.31081972@postgrespro.ru", "phone": "+70351920168"}
0005434980495	4112CD	3637 816856	OLEG MOROZOV	{"phone": "+70022672405"}
0005434980496	3EE6F8	1487 104834	LYUBOV ZAYCEVA	{"email": "zayceva.l-061972@postgrespro.ru", "phone": "+70535489951"}
0005434980497	45CF2C	9701 148859	OLGA FEDOROVA	{"email": "fedorova-olga_011977@postgrespro.ru", "phone": "+70447159277"}
0005434980498	750062	6255 437654	ALEKSEY ALEKSANDROV	{"email": "aaleksandrov-29061968@postgrespro.ru", "phone": "+70282313052"}
0005434980499	8CD243	7324 962077	IGOR AFANASEV	{"email": "i.afanasev-051976@postgrespro.ru", "phone": "+70405645892"}
0005434980500	4808EE	1935 080239	DIANA STEPANOVA	{"email": "diana.stepanova1976@postgrespro.ru", "phone": "+70742530772"}
0005434980501	BF73ED	3515 146867	IRINA KOZLOVA	{"phone": "+70410671462"}
0005434980502	F0B8EA	9314 210773	SVETLANA ZAKHAROVA	{"phone": "+70541098696"}
0005434980503	3CC220	8820 558196	STANISLAV KOZLOV	{"email": "stanislav.kozlov29121965@postgrespro.ru", "phone": "+70431391299"}
0005434980504	3CC220	8846 006679	ELENA MIRONOVA	{"email": "elenamironova1968@postgrespro.ru", "phone": "+70694042079"}
0005434980505	A0DBF8	7552 012079	OLGA TROFIMOVA	{"email": "trofimovaolga-25041970@postgrespro.ru", "phone": "+70211694840"}
0005434980506	2F235A	4853 478310	NATALIYA KUZNECOVA	{"email": "nataliya_kuznecova-011974@postgrespro.ru", "phone": "+70268892150"}
0005434980507	575F11	3566 759961	NADEZHDA MARTYNOVA	{"email": "martynovanadezhda-061980@postgrespro.ru", "phone": "+70006538232"}
0005434980508	23649E	7490 266384	YURIY MAKAROV	{"phone": "+70787375653"}
0005434980509	ACB919	2872 324458	ALEKSEY KUZNECOV	{"phone": "+70320574775"}
0005434980510	3CCA1F	7716 351714	OLGA BELYAEVA	{"email": "o.belyaeva-031975@postgrespro.ru", "phone": "+70814860077"}
0005434980511	3CCA1F	0991 841103	VITALIY MIKHAYLOV	{"phone": "+70075359459"}
0005434980512	E9B313	6195 905980	NATALYA KOZLOVA	{"email": "kozlova.n.11081973@postgrespro.ru", "phone": "+70819406235"}
0005434980513	E9B313	6616 144039	NATALYA NIKOLAEVA	{"phone": "+70909102026"}
0005434980514	E88060	0355 932530	REGINA KOVALEVA	{"phone": "+70176591344"}
0005434980515	2F87F5	6791 570681	GRIGORIY EGOROV	{"email": "egorovgrigoriy1962@postgrespro.ru", "phone": "+70439887531"}
0005434980516	897AC9	0426 663647	SERGEY ANDREEV	{"email": "andreevsergey_25051969@postgrespro.ru", "phone": "+70421238526"}
0005434980517	897AC9	9919 288742	VALERIY KUDRYASHOV	{"email": "valeriykudryashov.1968@postgrespro.ru", "phone": "+70608153682"}
0005434980518	97FDCB	1641 632453	KIRILL SOLOVEV	{"email": "solovev.kirill1964@postgrespro.ru", "phone": "+70585634236"}
0005434980519	28F846	9296 928820	NIKOLAY BONDARENKO	{"phone": "+70932677204"}
0005434980520	ABAFDD	5345 082603	GALINA KISELEVA	{"email": "g-kiseleva_061976@postgrespro.ru", "phone": "+70227952397"}
0005434980521	ABAFDD	9538 055962	NATALYA LEBEDEVA	{"email": "nlebedeva.071970@postgrespro.ru", "phone": "+70126390649"}
0005434980522	DD86F7	7461 958387	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya_081979@postgrespro.ru", "phone": "+70426121336"}
0005434980523	DD86F7	3336 508781	NATALYA ROMANOVA	{"email": "natalya_romanova04071974@postgrespro.ru", "phone": "+70559037211"}
0005434980524	35E0B5	3186 585506	ALEKSANDR MOROZOV	{"phone": "+70833550017"}
0005434980525	E44449	8339 037088	VALERIYA RYABOVA	{"email": "ryabova_valeriya.1956@postgrespro.ru", "phone": "+70344569829"}
0005434980526	AEEDB2	4002 810271	VIKTOR SERGEEV	{"phone": "+70452208751"}
0005434980527	1AA242	0887 985665	DENIS IVANOV	{"email": "d_ivanov-1968@postgrespro.ru", "phone": "+70936927922"}
0005434980528	BD4E1B	8484 428566	NADEZHDA NESTEROVA	{"email": "nesterova_n041964@postgrespro.ru", "phone": "+70906419498"}
0005434980529	435AD8	7390 876736	YURIY MOISEEV	{"phone": "+70784027930"}
0005434980530	72A414	0584 019806	OLGA IVANOVA	{"email": "olga-ivanova_121976@postgrespro.ru", "phone": "+70762899028"}
0005434980531	E8797E	0971 748511	ELENA GERASIMOVA	{"email": "gerasimova-e.06111968@postgrespro.ru", "phone": "+70938268163"}
0005434980532	883C0B	7935 874307	VYACHESLAV SOROKIN	{"phone": "+70810608985"}
0005434980533	9064C1	6838 594372	ELENA MARTYNOVA	{"phone": "+70354374642"}
0005434980534	159D2C	1086 223327	NINA KARPOVA	{"phone": "+70811698627"}
0005434980535	5EBD65	7491 694694	VASILIY MAKAROV	{"email": "makarov.vasiliy081973@postgrespro.ru", "phone": "+70610625751"}
0005434980536	5EBD65	8019 450483	PAVEL VOLKOV	{"phone": "+70174546587"}
0005434980537	3086D4	1713 417820	LYUBOV PETROVA	{"phone": "+70549057967"}
0005434980538	E54494	0745 971483	OLGA ERMAKOVA	{"email": "oermakova091967@postgrespro.ru", "phone": "+70913198243"}
0005434980539	E54494	4940 995080	ELENA KOROLEVA	{"phone": "+70510080909"}
0005434980540	3D13E2	1228 000860	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova.15031974@postgrespro.ru", "phone": "+70788016815"}
0005434980541	7587D2	8864 560332	ALEKSEY NOVIKOV	{"phone": "+70307188665"}
0005434980542	D6380B	6046 267188	VLADIMIR SCHERBAKOV	{"phone": "+70001341569"}
0005434980543	A608BC	9694 075942	NIKOLAY SCHERBAKOV	{"phone": "+70128310907"}
0005434980544	818BFB	2356 356548	GALINA NIKITINA	{"email": "nikitinagalina_091978@postgrespro.ru", "phone": "+70725274788"}
0005434980545	6420DE	2220 372128	LYUBOV BELOVA	{"phone": "+70318486068"}
0005434980546	154337	8312 238247	MARINA MARTYNOVA	{"phone": "+70563349343"}
0005434980547	B564C6	1547 409614	KLAVDIYA VOLKOVA	{"email": "volkovak-011969@postgrespro.ru", "phone": "+70416388645"}
0005434980548	841C62	0536 902498	NINA KUZNECOVA	{"email": "nina_kuznecova.1976@postgrespro.ru", "phone": "+70705084886"}
0005434980549	79832D	2025 113336	IRINA MELNIKOVA	{"phone": "+70950611554"}
0005434980550	79832D	8121 499532	OLESYA POPOVA	{"email": "popova.olesya_1962@postgrespro.ru", "phone": "+70135871781"}
0005434980551	3B7B02	4402 129202	TAMARA KOZLOVA	{"phone": "+70564538298"}
0005434980552	C671A6	9277 690373	ALEKSANDR PAVLOV	{"phone": "+70771166697"}
0005434980553	C671A6	0746 063937	ANDREY KONOVALOV	{"email": "konovalovandrey1971@postgrespro.ru", "phone": "+70951059715"}
0005434980554	8FC991	2896 304793	TAMARA KUZNECOVA	{"phone": "+70777861261"}
0005434980555	8FC991	2698 879742	ARKADIY SEMENOV	{"email": "semenov.a-051965@postgrespro.ru", "phone": "+70125485436"}
0005434980556	8FC991	6720 076858	SERGEY PETROV	{"phone": "+70785953800"}
0005434980557	771A1E	7648 014276	VYACHESLAV KISELEV	{"email": "kiselev.vyacheslav.1969@postgrespro.ru", "phone": "+70744328626"}
0005434980558	22C1B0	1420 719558	ANDREY ALEKSEEV	{"email": "andrey.alekseev051974@postgrespro.ru", "phone": "+70890363780"}
0005434980559	AD9913	0841 181141	TATYANA MALYSHEVA	{"phone": "+70867474852"}
0005434980560	C71C01	9665 022525	VLADIMIR DAVYDOV	{"email": "v-davydov1966@postgrespro.ru", "phone": "+70486715364"}
0005434980561	5B18BD	1207 047308	RAIL VLASOV	{"phone": "+70974587381"}
0005434980562	5B18BD	5434 218623	YURIY SEMENOV	{"phone": "+70831827418"}
0005434980563	DEA9E5	0437 044116	VLADIMIR FOMIN	{"email": "vladimir.fomin_031978@postgrespro.ru", "phone": "+70850579785"}
0005434980564	DEA9E5	0131 460550	DARYA EGOROVA	{"email": "darya-egorova_111963@postgrespro.ru", "phone": "+70910929881"}
0005434980565	DEA9E5	1967 574090	ALEKSEY KONOVALOV	{"phone": "+70350760778"}
0005434980566	EEB667	1497 668379	VALENTINA ZHURAVLEVA	{"email": "zhuravleva-valentina_1981@postgrespro.ru", "phone": "+70575822552"}
0005434980567	AF1845	6043 966286	OLGA RODIONOVA	{"phone": "+70891131187"}
0005434980568	42AD9B	1714 362901	MARGARITA AKIMOVA	{"email": "m_akimova-30071961@postgrespro.ru", "phone": "+70045153983"}
0005434980569	0AF7FB	1880 225053	ALEKSEY NAZAROV	{"phone": "+70063550055"}
0005434980570	0AF7FB	1234 097706	ELMIRA EFIMOVA	{"phone": "+70632190603"}
0005434980571	36009B	4406 959821	ANATOLIY SOROKIN	{"phone": "+70117934482"}
0005434980572	36009B	4774 149610	DMITRIY ZHURAVLEV	{"email": "zhuravlev_dmitriy.1975@postgrespro.ru", "phone": "+70966974625"}
0005434980573	36009B	8752 016081	ARTEM ANDREEV	{"phone": "+70174607401"}
0005434980574	D28F0D	4909 502399	SERGEY BARANOV	{"email": "baranov_sergey.1971@postgrespro.ru", "phone": "+70998656919"}
0005434980575	34EB58	4214 671238	NATALIYA KOZLOVA	{"email": "nataliyakozlova31031972@postgrespro.ru", "phone": "+70822768070"}
0005434980576	2E9776	0940 563869	YURIY GRIGOREV	{"phone": "+70074648972"}
0005434980577	2E9776	0447 244214	NATALYA ZHUKOVA	{"phone": "+70049106462"}
0005434980578	BC151D	4391 445931	SERGEY OSIPOV	{"email": "sergey_osipov_1974@postgrespro.ru", "phone": "+70588448439"}
0005434980579	1C1E56	5562 514985	MARIYA ANDREEVA	{"email": "andreeva-m-1967@postgrespro.ru", "phone": "+70240127596"}
0005434980580	1C1E56	5892 483234	RUSLAN NIKOLAEV	{"phone": "+70046985767"}
0005434980581	FC9CE6	5813 152354	IVAN OSIPOV	{"email": "iosipov_061979@postgrespro.ru", "phone": "+70080280777"}
0005434980582	FC9CE6	7845 499098	TATYANA PETROVA	{"phone": "+70863535352"}
0005434980583	7B095B	3588 886855	VALERIYA ERMAKOVA	{"email": "ermakova.valeriya-10061976@postgrespro.ru", "phone": "+70303828088"}
0005434980584	6C9CAC	9690 909180	STEPAN NIKITIN	{"email": "s-nikitin_1974@postgrespro.ru", "phone": "+70437366065"}
0005434980585	5BD244	6882 198478	ALEKSEY KRASNOV	{"email": "krasnov-aleksey21011978@postgrespro.ru", "phone": "+70830132482"}
0005434980586	5BD244	5372 582081	ANNA SEMENOVA	{"email": "semenova.anna121975@postgrespro.ru", "phone": "+70619483918"}
0005434980587	894FCE	5827 294710	SVETLANA CHERNOVA	{"email": "svetlana.chernova.03111982@postgrespro.ru", "phone": "+70605512700"}
0005434980588	C4CF0C	8059 171206	RAMIL MAKAROV	{"phone": "+70636607310"}
0005434980589	5BD9BA	6202 113562	PAVEL NIKOLAEV	{"email": "nikolaev-pavel1983@postgrespro.ru", "phone": "+70811904259"}
0005434980590	5BD9BA	0015 810300	SERGEY KUZNECOV	{"email": "kuznecov-s081963@postgrespro.ru", "phone": "+70957168930"}
0005434980591	E57D1A	5297 664333	ALEKSEY ANTONOV	{"phone": "+70763234381"}
0005434980592	4A468A	2406 149440	ALEKSANDRA GAVRILOVA	{"phone": "+70540589220"}
0005434980593	3B8A1C	7636 808592	RAFAIL MAKAROV	{"phone": "+70525323007"}
0005434980594	D7332E	8070 021003	NATALYA LUKYANOVA	{"phone": "+70503131885"}
0005434980595	8C3C84	9975 828997	ARTEM VASILEV	{"email": "vasilev-artem_03101973@postgrespro.ru", "phone": "+70884860628"}
0005434980596	F980ED	7299 696506	EKATERINA SAVELEVA	{"phone": "+70518661723"}
0005434980597	67DD53	5320 353312	NIKOLAY AFANASEV	{"phone": "+70526044860"}
0005434980598	67DD53	5571 893368	YULIYA MALYSHEVA	{"email": "malysheva.yuliya-1971@postgrespro.ru", "phone": "+70014774320"}
0005434980599	A129F4	4998 606121	VALENTIN MAKSIMOV	{"phone": "+70649824445"}
0005434980600	A129F4	7249 452579	DARYA DAVYDOVA	{"phone": "+70116374784"}
0005434980601	EF5F26	4937 118647	TATYANA TIKHONOVA	{"phone": "+70990126305"}
0005434980602	A9B1A8	3617 146918	ANATOLIY NIKOLAEV	{"email": "nikolaev_a_20121987@postgrespro.ru", "phone": "+70488884341"}
0005434980603	48261A	8485 814508	VIKTOR SOKOLOV	{"phone": "+70450162496"}
0005434980604	48261A	3905 119024	LEV POPOV	{"email": "l_popov_101963@postgrespro.ru", "phone": "+70237922246"}
0005434980605	FD4839	9160 651729	MARINA DMITRIEVA	{"email": "m_dmitrieva_02101977@postgrespro.ru", "phone": "+70638278831"}
0005434980606	191A0D	2894 361331	ANNA ANTONOVA	{"email": "antonovaanna.101978@postgrespro.ru", "phone": "+70977535382"}
0005434980607	191A0D	8755 711424	LIDIYA YUDINA	{"email": "lidiyayudina1986@postgrespro.ru", "phone": "+70799560891"}
0005434980608	1C1A38	4411 225408	TATYANA ROMANOVA	{"email": "tatyana-romanova_041964@postgrespro.ru", "phone": "+70939549307"}
0005434980609	1C1A38	3450 270114	ANASTASIYA PETROVA	{"phone": "+70019523766"}
0005434980610	9D94C7	1285 729386	VLADIMIR MATVEEV	{"phone": "+70286981276"}
0005434980611	F7B195	0895 829129	NIKOLAY IVANOV	{"phone": "+70357249309"}
0005434980612	F75F5B	7067 561053	TATYANA SMIRNOVA	{"email": "t_smirnova_031969@postgrespro.ru", "phone": "+70219540777"}
0005434980613	DF7E2C	8042 860478	SVETLANA ANDREEVA	{"phone": "+70261605350"}
0005434980614	DF7E2C	3955 979474	SERGEY SOLOVEV	{"phone": "+70663933689"}
0005434980615	E0E86E	6408 927224	OLGA SMIRNOVA	{"email": "smirnova.o_31051978@postgrespro.ru", "phone": "+70519994529"}
0005434980616	01F3C0	9731 756493	MARINA ANDREEVA	{"phone": "+70211064531"}
0005434980617	E5BD52	4169 354498	SVETLANA MELNIKOVA	{"email": "melnikova-svetlana061970@postgrespro.ru", "phone": "+70599802659"}
0005434980618	5F4516	8104 575660	ANTON MELNIKOV	{"email": "a_melnikov061972@postgrespro.ru", "phone": "+70815564269"}
0005434980619	5F4516	9056 951180	MAKSIM KUZNECOV	{"phone": "+70539476903"}
0005434980620	6A6266	4610 495111	OLGA NAZAROVA	{"email": "nazarova_olga-20101958@postgrespro.ru", "phone": "+70587561779"}
0005434980621	0B846E	0667 697592	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr101971@postgrespro.ru", "phone": "+70779722140"}
0005434980622	FD8BDA	6896 501483	MAKSIM SAVELEV	{"email": "savelev-maksim1974@postgrespro.ru", "phone": "+70578131661"}
0005434980623	FD8BDA	1522 797009	SVETLANA FILIPPOVA	{"phone": "+70297794782"}
0005434980624	525E5F	4319 919334	VALENTINA EFIMOVA	{"email": "v_efimova_061967@postgrespro.ru", "phone": "+70725816390"}
0005434980625	5C0C2C	3028 132629	OLGA NOVIKOVA	{"phone": "+70818638367"}
0005434980626	AE90BF	4748 260547	ELENA DANILOVA	{"email": "edanilova.1957@postgrespro.ru", "phone": "+70146651219"}
0005434980627	8FFC70	6971 616619	SERGEY AFANASEV	{"phone": "+70124714456"}
0005434980628	0A64D3	9867 136058	GALINA MELNIKOVA	{"phone": "+70783778502"}
0005434980629	013E9F	5319 380978	NIKOLAY NOVIKOV	{"phone": "+70372364467"}
0005434980630	CA3024	8475 373591	TATYANA KONOVALOVA	{"email": "tatyana-konovalova_1975@postgrespro.ru", "phone": "+70670726490"}
0005434980631	8F09D4	5928 929547	NIKOLAY KRASNOV	{"phone": "+70978773802"}
0005434980632	8F09D4	2337 473740	NIKOLAY KUZMIN	{"phone": "+70011078997"}
0005434980633	AC2FA7	2149 940282	NINA NAZAROVA	{"email": "nina-nazarova_1968@postgrespro.ru", "phone": "+70826446294"}
0005434980634	009BEA	4278 526586	MARGARITA FILATOVA	{"phone": "+70732451024"}
0005434980635	009BEA	4153 693046	DIANA KUZNECOVA	{"email": "dkuznecova1965@postgrespro.ru", "phone": "+70162132720"}
0005434980636	F41CE0	1058 855790	LIDIYA EFIMOVA	{"email": "lidiya.efimova_1972@postgrespro.ru", "phone": "+70508670957"}
0005434980637	F41CE0	0062 685721	IRINA TIKHONOVA	{"email": "tikhonova-i_081973@postgrespro.ru", "phone": "+70380908947"}
0005434980638	D08234	9467 772385	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov-a-1968@postgrespro.ru", "phone": "+70664508379"}
0005434980639	4BB831	3839 211823	DMITRIY MAKSIMOV	{"phone": "+70200227622"}
0005434980640	46FF1B	8307 213551	SVETLANA OVCHINNIKOVA	{"email": "s_ovchinnikova_041977@postgrespro.ru", "phone": "+70622594175"}
0005434980641	46FF1B	0682 507960	ALEKSANDR YAKOVLEV	{"email": "aleksandr.yakovlev_1972@postgrespro.ru", "phone": "+70217724690"}
0005434980642	B6C899	1141 730094	ALEKSANDR GERASIMOV	{"email": "a.gerasimov09081968@postgrespro.ru", "phone": "+70841887405"}
0005434980643	5B9A41	4715 854203	VALENTINA KONOVALOVA	{"email": "konovalova_valentina_1974@postgrespro.ru", "phone": "+70967217107"}
0005434980644	17B47D	4953 615198	VLADIMIR SEMENOV	{"email": "vsemenov_1955@postgrespro.ru", "phone": "+70779028620"}
0005434980645	147B8A	0455 221879	ALEKSANDR SAVELEV	{"phone": "+70314642375"}
0005434980646	147B8A	8072 694697	ANNA TITOVA	{"phone": "+70920993828"}
0005434980647	409A3D	9418 204895	MARIYA MALYSHEVA	{"email": "malyshevamariya-1973@postgrespro.ru", "phone": "+70901195960"}
0005434980648	409A3D	3411 023375	LYUBOV PETROVA	{"email": "petrova_lyubov08091979@postgrespro.ru", "phone": "+70002772827"}
0005434980649	68A48E	5808 847440	DENIS BELOV	{"email": "belov.d1957@postgrespro.ru", "phone": "+70901568189"}
0005434980650	9A20A6	5511 943584	VASILIY GUSEV	{"phone": "+70602720062"}
0005434980651	E91F7B	3471 733228	OKSANA OSIPOVA	{"email": "osipova-oksana101967@postgrespro.ru", "phone": "+70899994039"}
0005434980652	3E332F	3767 824988	TATYANA DMITRIEVA	{"phone": "+70129372272"}
0005434980653	3E332F	6742 015521	RAISA KISELEVA	{"email": "raisa_kiseleva.19051974@postgrespro.ru", "phone": "+70765453125"}
0005434980654	3E332F	5539 890022	NADEZHDA ROMANOVA	{"phone": "+70762089607"}
0005434980655	86796F	5340 791730	ALEKSANDRA ANDREEVA	{"phone": "+70246434658"}
0005434980656	9B09FA	3833 254003	NINA KOROLEVA	{"email": "nina-koroleva.1969@postgrespro.ru", "phone": "+70951051552"}
0005434980657	9B09FA	5785 953150	YAROSLAV GORBUNOV	{"phone": "+70909129287"}
0005434980658	62586B	5635 608815	SERGEY IVANOV	{"phone": "+70144288357"}
0005434980659	62586B	1533 257500	VALERIY BONDARENKO	{"email": "v_bondarenko_051978@postgrespro.ru", "phone": "+70765411160"}
0005434980660	2EB636	4293 824630	VLADIMIR NOVIKOV	{"phone": "+70835841679"}
0005434980661	A8E80C	6031 718985	VALENTINA GERASIMOVA	{"phone": "+70907425367"}
0005434980662	CA7CE2	5086 912977	SERGEY ANDREEV	{"email": "andreev.s_1974@postgrespro.ru", "phone": "+70252207602"}
0005434980663	CA7CE2	8692 892810	RAFAEL CHERNOV	{"email": "chernov_r_101974@postgrespro.ru", "phone": "+70558896451"}
0005434980664	3DB446	6004 238491	VLADISLAV DAVYDOV	{"phone": "+70724283813"}
0005434980665	3DB446	9072 885161	VIKTOR GAVRILOV	{"phone": "+70061014551"}
0005434980666	3DB446	1263 039953	DARYA ABRAMOVA	{"email": "d_abramova.21111963@postgrespro.ru", "phone": "+70654307603"}
0005434980667	E554B4	6357 280512	SVETLANA SOKOLOVA	{"phone": "+70023121786"}
0005434980668	E6AF31	8335 029631	OLGA CHERNOVA	{"phone": "+70698925700"}
0005434980669	E6AF31	4298 856217	YURIY EGOROV	{"phone": "+70131801140"}
0005434980670	293D30	8027 729199	ANATOLIY SOKOLOV	{"email": "anatoliy-sokolov-29061975@postgrespro.ru", "phone": "+70094247334"}
0005434980671	8913C1	3215 374035	VERA KOLESNIKOVA	{"email": "vera-kolesnikova-031972@postgrespro.ru", "phone": "+70785670482"}
0005434980672	8913C1	2669 866023	SERGEY ALEKSEEV	{"email": "sergey.alekseev-1976@postgrespro.ru", "phone": "+70166643332"}
0005434980673	CDA1F4	4543 136463	ANDREY ALEKSANDROV	{"phone": "+70099026152"}
0005434980674	174866	5675 824303	ALEKSANDR MOROZOV	{"phone": "+70286452050"}
0005434980675	7F477B	8943 659189	EDUARD ZAKHAROV	{"phone": "+70433532666"}
0005434980676	2AAE0E	4243 272872	ALEKSANDRA VLASOVA	{"email": "vlasovaa_1976@postgrespro.ru", "phone": "+70257278305"}
0005434980677	D251FB	8239 873428	VERA FROLOVA	{"phone": "+70205346545"}
0005434980678	3192AC	1536 080220	EVGENIY IVANOV	{"phone": "+70737359881"}
0005434983193	89ECDE	4810 648594	ALEKSANDRA MAKAROVA	{"phone": "+70690691576"}
0005434983194	89ECDE	3509 974810	SERGEY GAVRILOV	{"email": "sergey_gavrilov_1964@postgrespro.ru", "phone": "+70355075681"}
0005434983195	2B8DAD	2022 979817	LILIYA POPOVA	{"phone": "+70095229630"}
0005434983196	2B8DAD	9345 347281	TIGRAN ORLOV	{"email": "orlovt_1959@postgrespro.ru", "phone": "+70099666636"}
0005434983197	D4BF30	7384 300791	SERGEY DAVYDOV	{"email": "s-davydov-1979@postgrespro.ru", "phone": "+70246071085"}
0005434983198	D4BF30	1147 865519	OLEG MEDVEDEV	{"phone": "+70934425338"}
0005434983199	D6284C	8410 905043	VALENTINA MAKAROVA	{"phone": "+70234581230"}
0005434983200	884932	8430 904881	ALEKSANDR NAZAROV	{"phone": "+70656239216"}
0005434983201	2DACBF	1644 899930	RAMIL VOLKOV	{"phone": "+70789790804"}
0005434983202	5464B0	5856 850528	GULNARA NIKITINA	{"email": "gulnara-nikitina_1968@postgrespro.ru", "phone": "+70538822767"}
0005434983203	5464B0	2926 432465	ELIZAVETA RODIONOVA	{"email": "elizaveta_rodionova021976@postgrespro.ru", "phone": "+70718102081"}
0005434983204	BF170B	1920 259613	ALEKSANDR KRASNOV	{"email": "aleksandr.krasnov-1964@postgrespro.ru", "phone": "+70674430419"}
0005434983205	BF170B	0076 748396	OLGA LAZAREVA	{"phone": "+70455382663"}
0005434983206	FA0906	4049 112003	BORIS VLASOV	{"email": "b.vlasov_1977@postgrespro.ru", "phone": "+70119319912"}
0005434983207	FA0906	5680 433706	IRINA DENISOVA	{"email": "irina-denisova_061978@postgrespro.ru", "phone": "+70221413749"}
0005434983208	CE01CC	2763 247572	NATALYA KOLESNIKOVA	{"phone": "+70401993950"}
0005434983209	131235	3712 897217	INGA NAUMOVA	{"email": "i-naumova_25081969@postgrespro.ru", "phone": "+70755627452"}
0005434983210	65924F	7846 061604	ILDAR IVANOV	{"email": "i_ivanov-15061968@postgrespro.ru", "phone": "+70895194793"}
0005434983211	3C1079	5272 708017	NADEZHDA EGOROVA	{"email": "n_egorova_041972@postgrespro.ru", "phone": "+70333277072"}
0005434983212	3C1079	3658 235586	SERGEY BORISOV	{"email": "s-borisov-061975@postgrespro.ru", "phone": "+70512566864"}
0005434983213	7BFB39	2625 030598	PAVEL NOVIKOV	{"phone": "+70038095727"}
0005434983214	7BFB39	1217 771347	PAVEL FROLOV	{"phone": "+70157976454"}
0005434983215	E677D3	4970 097055	PETR ZAYCEV	{"email": "zaycevpetr1971@postgrespro.ru", "phone": "+70673292328"}
0005434983216	7B8865	6144 826176	EGOR ALEKSEEV	{"email": "e-alekseev_1966@postgrespro.ru", "phone": "+70309407009"}
0005434983217	A0F441	9014 012886	RINAT KAZAKOV	{"email": "kazakovrinat-06091965@postgrespro.ru", "phone": "+70718303667"}
0005434983218	E08668	4815 165264	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.13021975@postgrespro.ru", "phone": "+70142240799"}
0005434983219	D77626	7215 933601	NIKOLAY PETROV	{"email": "n.petrov-1971@postgrespro.ru", "phone": "+70033906527"}
0005434983220	D77626	4084 692923	ROMAN FOMIN	{"email": "fomin.r101971@postgrespro.ru", "phone": "+70213352983"}
0005434983221	3623AC	8690 640674	NADEZHDA DAVYDOVA	{"email": "davydova_n.1967@postgrespro.ru", "phone": "+70914658723"}
0005434983222	3623AC	3272 320386	VLADIMIR IVANOV	{"phone": "+70910163740"}
0005434983223	00C04F	8734 857850	ANTON KARPOV	{"email": "anton-karpov.18011963@postgrespro.ru", "phone": "+70829218955"}
0005434983224	E0540F	8429 333774	TAMARA NIKIFOROVA	{"phone": "+70603805379"}
0005434983225	6F1491	8895 545615	ZINAIDA MELNIKOVA	{"email": "zinaida.melnikova.1970@postgrespro.ru", "phone": "+70919900683"}
0005434983226	6F1491	7598 941767	NADEZHDA OSIPOVA	{"phone": "+70905157114"}
0005434983227	3A1630	4391 771872	ALEKSEY ZAYCEV	{"email": "aleksey_zaycev1975@postgrespro.ru", "phone": "+70782675028"}
0005434983228	6D3603	8059 826782	YAROSLAV FOMIN	{"phone": "+70123933732"}
0005434983229	6D3603	3721 705625	LYUBOV SCHERBAKOVA	{"phone": "+70342868468"}
0005434983230	6D3603	9356 587556	YURIY POPOV	{"phone": "+70420332720"}
0005434983231	A3FC30	9753 887201	PETR ROMANOV	{"phone": "+70082785899"}
0005434983232	A3FC30	3080 412739	MIKHAIL NIKITIN	{"phone": "+70128231271"}
0005434983233	0E6532	1492 156216	VIKTOR SERGEEV	{"phone": "+70664465618"}
0005434983234	0E6532	0195 467192	OKSANA KOVALEVA	{"email": "oksana.kovaleva111964@postgrespro.ru", "phone": "+70362212254"}
0005434983235	781D20	0046 723818	PAVEL MAKAROV	{"phone": "+70098928818"}
0005434983236	F8BE18	5941 863634	ALEKSEY ALEKSEEV	{"phone": "+70783795637"}
0005434983237	11B4E0	3594 339557	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir1989@postgrespro.ru", "phone": "+70962405114"}
0005434983238	BB8D43	6230 749513	ELENA ZHURAVLEVA	{"email": "e-zhuravleva.061969@postgrespro.ru", "phone": "+70894544982"}
0005434983239	99D7DA	4733 671152	SVYATOSLAV GRIGOREV	{"phone": "+70319863687"}
0005434983240	037F62	0793 740696	MATVEY SERGEEV	{"email": "m-sergeev-1977@postgrespro.ru", "phone": "+70249465488"}
0005434983241	037F62	3519 931826	ILDUS MAKAROV	{"phone": "+70311842657"}
0005434983242	80893F	0631 161305	VARVARA POPOVA	{"phone": "+70511009959"}
0005434983243	80893F	7872 234448	SVETLANA NAUMOVA	{"phone": "+70940249511"}
0005434983244	3E7FC2	3404 093238	ALEKSANDR OSIPOV	{"phone": "+70882855433"}
0005434983245	FFB1A7	9654 193440	VIKTOR EGOROV	{"phone": "+70025617351"}
0005434983246	FFB1A7	4838 889732	VIKTOR GAVRILOV	{"email": "gavrilovv041971@postgrespro.ru", "phone": "+70923066417"}
0005434983247	4FAAF2	1465 975983	MARINA PAVLOVA	{"phone": "+70049120831"}
0005434983248	3648B6	5028 065336	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev_1976@postgrespro.ru", "phone": "+70162881419"}
0005434983249	E48C48	0617 908507	VLADISLAV MAKSIMOV	{"email": "vladislavmaksimov091971@postgrespro.ru", "phone": "+70731641034"}
0005434983250	E48C48	2241 639082	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov05021965@postgrespro.ru", "phone": "+70139515645"}
0005434983251	3A37BC	3196 324701	INNA KULIKOVA	{"phone": "+70365761012"}
0005434983252	3A37BC	3305 534353	IVAN SAVELEV	{"email": "savelev_ivan_031972@postgrespro.ru", "phone": "+70583446815"}
0005434983253	EE9837	3644 638067	EKATERINA ERMAKOVA	{"phone": "+70174094498"}
0005434983254	EE9837	5881 845242	DIANA ABRAMOVA	{"phone": "+70044698785"}
0005434983255	565320	5136 392530	OLESYA KUZNECOVA	{"phone": "+70790825269"}
0005434983256	729D28	0380 825459	ANNA FEDOROVA	{"phone": "+70467003732"}
0005434983257	FDC54F	1378 264558	MARIYA STEPANOVA	{"phone": "+70676506032"}
0005434983258	EBBDF6	2424 399905	ARTEM KOROLEV	{"phone": "+70880317672"}
0005434983259	86174B	6958 229821	RUSLAN IVANOV	{"email": "ruslan-ivanov_07031971@postgrespro.ru", "phone": "+70195785615"}
0005434983260	F69EA5	3673 432266	NATALYA GAVRILOVA	{"phone": "+70508130973"}
0005434983261	A076C2	1915 072059	NATALYA KUZMINA	{"phone": "+70504556188"}
0005434983262	5C2977	2548 546693	ELENA MIRONOVA	{"phone": "+70559173000"}
0005434983263	730415	8153 040200	GALINA TROFIMOVA	{"email": "g-trofimova_12021973@postgrespro.ru", "phone": "+70671377068"}
0005434983264	730415	7974 517783	VLADIMIR ZAYCEV	{"phone": "+70369856192"}
0005434983265	03FB11	8258 435084	EVGENIY FEDOROV	{"phone": "+70081627364"}
0005434983266	B4B35B	7156 388239	NIKOLAY MEDVEDEV	{"email": "nmedvedev-07061971@postgrespro.ru", "phone": "+70495114819"}
0005434983267	B4B35B	8030 433817	DENIS ANDREEV	{"email": "denisandreev.1966@postgrespro.ru", "phone": "+70645479241"}
0005434983268	A9ED56	2319 923180	TATYANA KUZMINA	{"email": "tkuzmina_31101976@postgrespro.ru", "phone": "+70204781729"}
0005434983269	86D3D2	8859 565870	NADEZHDA FOMINA	{"email": "nadezhda.fomina1971@postgrespro.ru", "phone": "+70760825470"}
0005434983270	373570	7417 267828	ALIYA ALEKSANDROVA	{"email": "aliya_aleksandrova1964@postgrespro.ru", "phone": "+70032512592"}
0005434983271	3967D5	6422 890988	ILMIR SERGEEV	{"email": "ilmir.sergeev_1968@postgrespro.ru", "phone": "+70007683194"}
0005434983272	3967D5	4705 397642	ELENA DANILOVA	{"phone": "+70659128439"}
0005434983273	3B6314	6005 397517	NATALYA OSIPOVA	{"phone": "+70737675726"}
0005434983274	3B6314	1643 198914	VLADIMIR MAKSIMOV	{"email": "v_maksimov_1967@postgrespro.ru", "phone": "+70879609799"}
0005434983275	3B6314	7233 875654	MARSEL VOLKOV	{"email": "volkov.m1970@postgrespro.ru", "phone": "+70736627941"}
0005434983276	B6AF03	7229 864141	ANNA ANDREEVA	{"phone": "+70694158155"}
0005434983277	B6AF03	1196 563086	RAISA SEMENOVA	{"phone": "+70017504584"}
0005434983278	498C91	7758 115107	LYUDMILA BOGDANOVA	{"phone": "+70887593076"}
0005434983279	AEC09B	0700 003237	ROMAN BORISOV	{"email": "roman.borisov_04031979@postgrespro.ru", "phone": "+70288855198"}
0005434983280	7B26B4	9299 031515	VLADIMIR FROLOV	{"email": "frolov.v_23051971@postgrespro.ru", "phone": "+70606419303"}
0005434983281	8E543C	7263 874174	IRAIDA ZAKHAROVA	{"phone": "+70803189330"}
0005434983282	420622	6917 114681	LYUBOV NOVIKOVA	{"email": "lyubov_novikova_091977@postgrespro.ru", "phone": "+70280466110"}
0005434983283	420622	8879 853282	NIKOLAY GRIGOREV	{"email": "grigorev_nikolay121965@postgrespro.ru", "phone": "+70701778334"}
0005434983284	5768E8	3393 401258	VARVARA ORLOVA	{"email": "vorlova1970@postgrespro.ru", "phone": "+70703407738"}
0005434983285	1A9602	2150 464514	MARIYA NIKIFOROVA	{"phone": "+70572881340"}
0005434983286	1A9602	5798 420949	ALEKSANDR STEPANOV	{"phone": "+70338245795"}
0005434983287	00D5B8	0867 246993	NIKOLAY OSIPOV	{"email": "osipov.n_031982@postgrespro.ru", "phone": "+70268497263"}
0005434983288	A78908	1172 473672	VLADIMIR MEDVEDEV	{"email": "medvedev.vladimir.02021969@postgrespro.ru", "phone": "+70825801254"}
0005434983289	4227B1	5012 344234	EVGENIY KONOVALOV	{"phone": "+70576275559"}
0005434983290	979B71	7159 697287	LIDIYA MAKAROVA	{"email": "lidiyamakarova-021974@postgrespro.ru", "phone": "+70114668068"}
0005434983291	174792	8482 649183	ANASTASIYA MATVEEVA	{"phone": "+70391265160"}
0005434983292	18BAC9	5014 079828	LYUDMILA SOLOVEVA	{"phone": "+70741676248"}
0005434983293	18BAC9	5021 060914	VALENTIN PETROV	{"email": "vpetrov.09061982@postgrespro.ru", "phone": "+70532978572"}
0005434983294	E74377	0372 688793	SERGEY PETROV	{"email": "s-petrov_09111974@postgrespro.ru", "phone": "+70643417096"}
0005434983295	EB4773	5217 830776	DANIIL ZHUKOV	{"email": "zhukov_daniil_101964@postgrespro.ru", "phone": "+70125473752"}
0005434983296	904C89	0317 046862	LYUDMILA SOKOLOVA	{"email": "sokolova.lyudmila.23071986@postgrespro.ru", "phone": "+70968312395"}
0005434983297	904C89	5110 805756	IRINA KUZNECOVA	{"phone": "+70287672105"}
0005434983298	5C9301	3175 217019	ANNA TIKHONOVA	{"phone": "+70160432430"}
0005434983299	5C9301	8417 824079	TATYANA ZHURAVLEVA	{"phone": "+70034925835"}
0005434983300	E08C6C	2297 903271	ANDREY YAKOVLEV	{"phone": "+70300790140"}
0005434983301	7E4CB2	7276 147098	VLADIMIR SIDOROV	{"phone": "+70550928347"}
0005434983302	7E4CB2	9519 327107	MIKHAIL IVANOV	{"email": "mikhail_ivanov.1978@postgrespro.ru", "phone": "+70431967142"}
0005434983303	AAD45C	4891 981643	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda_031981@postgrespro.ru", "phone": "+70889341171"}
0005434983304	AAD45C	5840 396575	SVETLANA SCHERBAKOVA	{"email": "scherbakova.s.1982@postgrespro.ru", "phone": "+70596556428"}
0005434983305	15B4FD	0510 067475	EGOR BONDARENKO	{"email": "bondarenko-e_1970@postgrespro.ru", "phone": "+70570116209"}
0005434983306	15B4FD	0247 089556	MAKSIM ROMANOV	{"phone": "+70321119496"}
0005434983307	E4D22F	5225 519160	MARINA KUZNECOVA	{"email": "marina-kuznecova_1972@postgrespro.ru", "phone": "+70504548162"}
0005434983308	155943	9328 689135	ANNA KUZNECOVA	{"phone": "+70762193821"}
0005434983309	155943	4056 455909	EVGENIY RODIONOV	{"email": "e-rodionov-05041973@postgrespro.ru", "phone": "+70071774123"}
0005434983310	3E5EA5	9632 921444	ALEKSEY NIKOLAEV	{"email": "a-nikolaev_23081973@postgrespro.ru", "phone": "+70492003171"}
0005434983311	9167C8	0561 893917	VIKTORIYA VASILEVA	{"phone": "+70482809958"}
0005434983312	6D0997	5787 177998	EVGENIY BONDARENKO	{"email": "evgeniy_bondarenko_26011980@postgrespro.ru", "phone": "+70180175120"}
0005434983313	8A5E01	3860 031833	LYUDMILA LOGINOVA	{"email": "loginova-lyudmila-091965@postgrespro.ru", "phone": "+70640679224"}
0005434983314	B859D0	4514 352881	ALEKSANDR DENISOV	{"email": "denisovaleksandr_1968@postgrespro.ru", "phone": "+70771789551"}
0005434983315	C84D31	3212 615458	ELENA SCHERBAKOVA	{"email": "elena.scherbakova_1980@postgrespro.ru", "phone": "+70225385399"}
0005434983316	C84D31	6283 978839	ZINAIDA ILINA	{"email": "z.ilina-1974@postgrespro.ru", "phone": "+70529363403"}
0005434983317	847DCF	7213 249508	TATYANA FEDOROVA	{"phone": "+70098773743"}
0005434983318	847DCF	6136 765931	SVETLANA AFANASEVA	{"email": "afanaseva-s1979@postgrespro.ru", "phone": "+70786783895"}
0005434983319	847DCF	0850 621366	VADIM BARANOV	{"phone": "+70996215399"}
0005434983320	A507A4	9126 280970	NIKOLAY KISELEV	{"email": "nikolay-kiselev.011983@postgrespro.ru", "phone": "+70958179940"}
0005434983321	A507A4	5373 833428	LYUDMILA TIKHONOVA	{"email": "tikhonoval-1971@postgrespro.ru", "phone": "+70744801735"}
0005434983322	FD2A5B	3186 047530	KHASAN SOROKIN	{"email": "khasan.sorokin_1970@postgrespro.ru", "phone": "+70139598550"}
0005434988624	5A1657	4288 570203	KIRA LOGINOVA	{"phone": "+70450691108"}
0005434983323	F88BA9	4548 447444	NIKOLAY IVANOV	{"email": "nikolay-ivanov.1971@postgrespro.ru", "phone": "+70914054675"}
0005434983324	F88BA9	4152 132898	TATYANA FILIPPOVA	{"phone": "+70810949313"}
0005434983325	AF018D	7564 332932	VLADIMIR FILIPPOV	{"phone": "+70834121586"}
0005434983326	E1F76A	2968 873824	EVGENIYA ROMANOVA	{"email": "romanovaevgeniya.101968@postgrespro.ru", "phone": "+70711114350"}
0005434983327	E1F76A	0861 890466	MIKHAIL TIMOFEEV	{"email": "timofeev.mikhail-1977@postgrespro.ru", "phone": "+70101076992"}
0005434983328	9A4B0E	2032 285071	OLGA BELYAEVA	{"phone": "+70985774872"}
0005434983329	9A4B0E	0523 202398	ELENA NAUMOVA	{"phone": "+70239494802"}
0005434983330	DDA55D	9241 719304	VLADISLAV GERASIMOV	{"phone": "+70405928083"}
0005434983331	DDA55D	5501 992556	VLADIMIR ABRAMOV	{"phone": "+70549684914"}
0005434983332	DDA55D	7937 564303	VALENTINA SOROKINA	{"email": "valentina-sorokina.1958@postgrespro.ru", "phone": "+70168121701"}
0005434983333	1BAAAB	8081 842480	EKATERINA ZHUKOVA	{"phone": "+70877528553"}
0005434983334	1BAAAB	5200 485483	PETR KAZAKOV	{"phone": "+70677478931"}
0005434983335	3B5A4D	1288 187090	PETR BELOV	{"email": "belovp-1979@postgrespro.ru", "phone": "+70956385082"}
0005434983336	3B5A4D	5326 855261	GENNADIY TARASOV	{"phone": "+70940177353"}
0005434983337	5376DF	6511 861086	NINA MIRONOVA	{"email": "nina_mironova_1969@postgrespro.ru", "phone": "+70401109679"}
0005434983338	24C7E8	8965 163813	ANNA NIKITINA	{"phone": "+70771759257"}
0005434983339	24C7E8	9156 585620	TATYANA YAKOVLEVA	{"email": "tyakovleva_071968@postgrespro.ru", "phone": "+70474890089"}
0005434983340	E5C94A	3225 268988	SERGEY NOVIKOV	{"phone": "+70095085540"}
0005434983341	6A5B97	8611 418878	KSENIYA KOROLEVA	{"email": "kseniya-koroleva-1980@postgrespro.ru", "phone": "+70407685766"}
0005434983342	B0620C	1566 591405	OLGA ZAKHAROVA	{"email": "zakharovaolga.30051965@postgrespro.ru", "phone": "+70033813231"}
0005434983343	30FA7A	4650 560882	NADEZHDA ROMANOVA	{"email": "romanova.nadezhda_1966@postgrespro.ru", "phone": "+70698514880"}
0005434983344	7DA050	0789 291383	NATALYA BORISOVA	{"email": "natalya.borisova.1966@postgrespro.ru", "phone": "+70138093037"}
0005434983345	D96F20	4272 698830	VALERIY ROMANOV	{"email": "romanov-v051978@postgrespro.ru", "phone": "+70230785128"}
0005434983346	D96F20	0876 060754	MARGARITA MEDVEDEVA	{"email": "medvedeva-m_041992@postgrespro.ru", "phone": "+70982406227"}
0005434983347	48465B	0694 493483	SOFYA IVANOVA	{"phone": "+70063230469"}
0005434983348	68F3C6	6249 439269	LYUDMILA MIKHAYLOVA	{"email": "lyudmila-mikhaylova031975@postgrespro.ru", "phone": "+70198353614"}
0005434983349	603127	9509 463728	MARIYA MAKAROVA	{"email": "makarova-m_121984@postgrespro.ru", "phone": "+70145879585"}
0005434983350	F29F96	0803 062291	VLADIMIR GAVRILOV	{"email": "gavrilov-v.25041980@postgrespro.ru", "phone": "+70439434471"}
0005434983351	F29F96	5093 241979	MATVEY MOISEEV	{"email": "matvey-moiseev1971@postgrespro.ru", "phone": "+70580134671"}
0005434983352	B1B09E	7239 331234	SNEZHANA STEPANOVA	{"email": "snezhana_stepanova031965@postgrespro.ru", "phone": "+70941067422"}
0005434983353	836C96	5096 998741	ELENA ANTONOVA	{"email": "e_antonova01051967@postgrespro.ru", "phone": "+70485056317"}
0005434983354	370750	5058 586142	ALEKSANDR TIMOFEEV	{"phone": "+70900854480"}
0005434983355	370750	0579 961398	ILYA SERGEEV	{"phone": "+70456913923"}
0005434983356	492C37	1225 302091	LARISA OSIPOVA	{"email": "osipovalarisa.06041976@postgrespro.ru", "phone": "+70680716264"}
0005434983357	492C37	9290 052346	GALINA MOROZOVA	{"phone": "+70481459951"}
0005434983358	E00814	2175 337004	SERGEY ISAEV	{"phone": "+70279899911"}
0005434983359	E00814	1917 146779	NATALYA GAVRILOVA	{"phone": "+70232468900"}
0005434983360	692D8D	8593 506808	IVAN PAVLOV	{"email": "pavlovi.111965@postgrespro.ru", "phone": "+70903483297"}
0005434983361	DB4D48	2088 668658	OLGA TITOVA	{"email": "olga_titova071974@postgrespro.ru", "phone": "+70521074248"}
0005434983362	B327DF	1328 057307	TAMARA KOLESNIKOVA	{"email": "t_kolesnikova1969@postgrespro.ru", "phone": "+70982425145"}
0005434983363	B327DF	2937 458669	VLADIMIR FEDOROV	{"email": "v.fedorov.19121972@postgrespro.ru", "phone": "+70630016671"}
0005434983364	A0E82B	5410 610316	ANASTASIYA ISAEVA	{"email": "a-isaeva.1968@postgrespro.ru", "phone": "+70214392172"}
0005434983365	522C3D	4622 434068	NATALYA TROFIMOVA	{"phone": "+70250869544"}
0005434983366	251753	2199 202649	IGOR ALEKSANDROV	{"email": "igor.aleksandrov_1978@postgrespro.ru", "phone": "+70044812452"}
0005434983367	251753	3981 434681	NIKOLAY TIMOFEEV	{"email": "n.timofeev25081982@postgrespro.ru", "phone": "+70178119706"}
0005434983368	251753	0896 534788	NATALYA ALEKSEEVA	{"phone": "+70318212179"}
0005434983369	A4086B	5273 288667	NINA MAKAROVA	{"email": "makarova.n-23071963@postgrespro.ru", "phone": "+70251739647"}
0005434983370	F71719	2979 852166	DMITRIY ZAYCEV	{"phone": "+70248410326"}
0005434983371	6A0780	0416 106938	ALEKSEY ROMANOV	{"email": "aleksey-romanov04121978@postgrespro.ru", "phone": "+70227755120"}
0005434983372	F45ED7	2920 281037	EVGENIY MOISEEV	{"phone": "+70440804720"}
0005434983373	07B6A1	8445 221070	TAISIYA KOVALEVA	{"phone": "+70640052819"}
0005434983374	624221	0452 943640	IRINA DAVYDOVA	{"email": "davydova-irina.1973@postgrespro.ru", "phone": "+70979719845"}
0005434983375	EDBE43	3886 372870	ANASTASIYA KUZNECOVA	{"phone": "+70875594795"}
0005434983376	5D63C8	4973 215359	MAKSIM GRIGOREV	{"phone": "+70879808454"}
0005434983377	1EF5F8	9907 658440	AZAT ZHURAVLEV	{"email": "zhuravlev.a-1983@postgrespro.ru", "phone": "+70584189732"}
0005434983378	C11F8F	1656 052703	NIKOLAY MEDVEDEV	{"email": "medvedev.n.081977@postgrespro.ru", "phone": "+70401769781"}
0005434983379	C11F8F	3129 452844	VALENTINA MAKAROVA	{"phone": "+70463392784"}
0005434983380	07F2C1	2156 695242	ALEKSANDR NOVIKOV	{"email": "a-novikov.1965@postgrespro.ru", "phone": "+70547324588"}
0005434983381	B91240	3558 925666	ALEKSANDRA SOKOLOVA	{"phone": "+70036001268"}
0005434983382	F92DF4	4841 138949	ALEKSEY GERASIMOV	{"email": "gerasimov-aleksey-1971@postgrespro.ru", "phone": "+70374721579"}
0005434983383	E59D22	0266 657789	EKATERINA ZAYCEVA	{"email": "zayceva_e_061977@postgrespro.ru", "phone": "+70496214785"}
0005434983384	358088	8428 539139	MARAT DAVYDOV	{"email": "davydovmarat_1976@postgrespro.ru", "phone": "+70054409827"}
0005434983385	0B3506	9105 084469	ELENA VLASOVA	{"phone": "+70053767984"}
0005434983386	6BEDFC	9045 742477	OLEG VASILEV	{"email": "ovasilev-19071963@postgrespro.ru", "phone": "+70371929457"}
0005434983387	6BEDFC	7044 424358	RAISA EGOROVA	{"phone": "+70136783514"}
0005434983388	4F0E20	4217 225950	RUSLAN VLASOV	{"email": "vlasov-ruslan_101966@postgrespro.ru", "phone": "+70538398960"}
0005434983389	644D0D	6236 150243	ANATOLIY DENISOV	{"phone": "+70807723400"}
0005434983390	CA934B	0447 205662	PETR MOROZOV	{"email": "morozovp-1968@postgrespro.ru", "phone": "+70382362494"}
0005434983391	466709	5366 827116	VLADIMIR FEDOTOV	{"email": "v.fedotov.25031986@postgrespro.ru", "phone": "+70903630616"}
0005434983392	FEE062	7525 790280	NATALYA DENISOVA	{"email": "natalya-denisova-071972@postgrespro.ru", "phone": "+70438194891"}
0005434983393	FEE062	7437 229601	EKATERINA POPOVA	{"phone": "+70450227004"}
0005434983394	DAA007	9916 993786	GALINA LEBEDEVA	{"email": "g.lebedeva.1967@postgrespro.ru", "phone": "+70448407546"}
0005434983395	AE999E	3543 621903	ANATOLIY MAKAROV	{"phone": "+70705012632"}
0005434983396	AE999E	8905 247435	YULIYA MOROZOVA	{"email": "morozova_yuliya_051973@postgrespro.ru", "phone": "+70969644185"}
0005434983397	528006	1280 361207	NATALYA KUZMINA	{"email": "kuzminanatalya.13091964@postgrespro.ru", "phone": "+70678436484"}
0005434983398	0F3FEF	7905 805026	MARAT KUZMIN	{"email": "m_kuzmin_11081971@postgrespro.ru", "phone": "+70116680574"}
0005434983399	FCC3D6	4690 994861	ALEKSANDR VOLKOV	{"email": "volkovaleksandr_24071975@postgrespro.ru", "phone": "+70640262630"}
0005434983400	F48241	8593 668051	ARTEM SCHERBAKOV	{"email": "scherbakov.artem.23111975@postgrespro.ru", "phone": "+70550347804"}
0005434983401	F48241	8646 789211	ALEKSANDR VASILEV	{"email": "vasilev.a.06031978@postgrespro.ru", "phone": "+70325358194"}
0005434983402	F48241	6915 837106	ELENA MARTYNOVA	{"phone": "+70112588971"}
0005434983403	F383BD	5087 120778	NADEZHDA IVANOVA	{"email": "nadezhda.ivanova_011972@postgrespro.ru", "phone": "+70257428777"}
0005434983404	F383BD	8542 299055	EVGENIY FILIPPOV	{"phone": "+70115896285"}
0005434983405	F383BD	3300 711562	ALEKSEY GAVRILOV	{"email": "gavrilovaleksey-12101968@postgrespro.ru", "phone": "+70295560787"}
0005434983406	27F012	7011 204002	SERGEY VASILEV	{"email": "sergeyvasilev23091972@postgrespro.ru", "phone": "+70904366149"}
0005434983407	81A56A	7347 309110	SVETLANA KOMAROVA	{"email": "svetlana.komarova1963@postgrespro.ru", "phone": "+70496606928"}
0005434983408	81A56A	2774 263632	NIKOLAY KARPOV	{"email": "karpovn_01081975@postgrespro.ru", "phone": "+70333650039"}
0005434983409	38BD21	3579 919144	TAMARA KISELEVA	{"phone": "+70750355460"}
0005434983410	38BD21	7038 189569	PETR SOLOVEV	{"phone": "+70110427238"}
0005434983411	652D4B	1180 521236	VLADISLAV KAZAKOV	{"phone": "+70587650529"}
0005434983412	D0AB0A	4689 748917	ANNA KRASNOVA	{"email": "anna.krasnova.13041979@postgrespro.ru", "phone": "+70392794493"}
0005434983413	3D3905	4121 122714	ANASTASIYA ZHURAVLEVA	{"phone": "+70760520127"}
0005434983414	3D3905	8316 742174	LYUDMILA MATVEEVA	{"phone": "+70305852938"}
0005434983415	3D3905	1929 348947	MARIYA FROLOVA	{"email": "m-frolova.1980@postgrespro.ru", "phone": "+70245732691"}
0005434983416	8F29A9	7458 081589	ALEKSEY FOMIN	{"email": "aleksey.fomin.02111964@postgrespro.ru", "phone": "+70778832634"}
0005434983417	8F29A9	1808 258201	ANASTASIYA ALEKSEEVA	{"email": "alekseevaanastasiya.1980@postgrespro.ru", "phone": "+70066416850"}
0005434983418	DED894	4234 701650	ANATOLIY TIKHONOV	{"email": "tikhonovanatoliy05071969@postgrespro.ru", "phone": "+70501419864"}
0005434983419	71105F	0184 812132	ANASTASIYA ANDREEVA	{"phone": "+70826015425"}
0005434983420	71105F	0606 751844	OLGA MIRONOVA	{"phone": "+70120584571"}
0005434983421	50A9FD	5989 850258	SERGEY IVANOV	{"email": "s.ivanov1974@postgrespro.ru", "phone": "+70061626274"}
0005434983422	990992	6407 302816	ALEKSANDR SAVELEV	{"phone": "+70086324783"}
0005434983423	E24E29	4416 586419	ILYA MATVEEV	{"email": "ilya_matveev.081961@postgrespro.ru", "phone": "+70985929365"}
0005434983424	CA7AD4	3253 939379	MARINA KUZNECOVA	{"phone": "+70253026802"}
0005434983425	8E1B36	7527 944679	ANTON ILIN	{"email": "ilin_anton-1971@postgrespro.ru", "phone": "+70402895677"}
0005434983426	14DC34	1667 853224	ARINA VOLKOVA	{"phone": "+70681784740"}
0005434983427	14DC34	0679 037572	MIKHAIL MOISEEV	{"phone": "+70109548434"}
0005434983428	D943DD	3261 957114	POLINA GUSEVA	{"phone": "+70880779733"}
0005434983429	B54EA1	7007 181312	GUZEL NAZAROVA	{"phone": "+70017077092"}
0005434983430	624FEF	6826 782332	PLATON ANDREEV	{"phone": "+70711129281"}
0005434983431	4D2B3E	3978 315300	NIKITA KULIKOV	{"phone": "+70980854829"}
0005434983432	4D2B3E	2777 455318	RITA AKIMOVA	{"phone": "+70897146185"}
0005434988555	BDEC23	2373 316413	VALENTINA NIKOLAEVA	{"email": "nikolaeva_valentina_14091974@postgrespro.ru", "phone": "+70975125544"}
0005434988556	A666CE	4472 061025	VITALIY FEDOROV	{"email": "fedorov_vitaliy.12091970@postgrespro.ru", "phone": "+70202481257"}
0005434988557	758CCC	8474 757872	ANTON FILIPPOV	{"phone": "+70521326524"}
0005434988558	24FCD7	3051 291473	VALENTIN STEPANOV	{"phone": "+70687053597"}
0005434988559	109220	7551 095987	YURIY KULIKOV	{"email": "kulikov-y-041964@postgrespro.ru", "phone": "+70521605574"}
0005434988560	85B019	0889 250311	ELENA IVANOVA	{"email": "ivanova-e-23061974@postgrespro.ru", "phone": "+70609036286"}
0005434988561	85B019	5661 926049	ALEKSANDR OSIPOV	{"phone": "+70174570397"}
0005434988562	1809FA	5411 758486	SOFYA IVANOVA	{"phone": "+70675638078"}
0005434988563	1809FA	1722 860300	MARIYA ALEKSEEVA	{"phone": "+70974015203"}
0005434988564	7B470B	6187 025538	ANNA GRISHINA	{"email": "agrishina13051974@postgrespro.ru", "phone": "+70456848389"}
0005434988565	89D241	3298 304984	NADEZHDA KUZNECOVA	{"phone": "+70919550523"}
0005434988566	2517E3	3789 152025	EGOR SHEVCHENKO	{"email": "egor_shevchenko_09101959@postgrespro.ru", "phone": "+70097745413"}
0005434988567	6EFA35	0628 702355	EKATERINA PAVLOVA	{"phone": "+70273827055"}
0005434988568	6EFA35	4216 351421	OLEG KRASNOV	{"email": "oleg-krasnov.121968@postgrespro.ru", "phone": "+70203005958"}
0005434988569	95D163	5293 619296	NATALYA LOGINOVA	{"email": "loginova_n1971@postgrespro.ru", "phone": "+70762101896"}
0005434988570	A63EF4	1433 788720	VALENTINA ZAKHAROVA	{"email": "valentina-zakharova-1959@postgrespro.ru", "phone": "+70369324220"}
0005434988571	1D9791	2645 499258	ALEKSEY SCHERBAKOV	{"phone": "+70964766369"}
0005434988572	026866	6488 550922	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko_081950@postgrespro.ru", "phone": "+70487409452"}
0005434988573	83E8F6	5251 088733	ALEKSEY ABRAMOV	{"phone": "+70169824528"}
0005434988574	ABD8AD	9692 048469	OLGA SIDOROVA	{"email": "o.sidorova_1972@postgrespro.ru", "phone": "+70275935735"}
0005434988575	4E1417	0645 402301	KRISTINA MAKAROVA	{"email": "k_makarova.041973@postgrespro.ru", "phone": "+70718207105"}
0005434988576	4E1417	8768 237879	VALERIY GORBUNOV	{"email": "v.gorbunov-1982@postgrespro.ru", "phone": "+70266431121"}
0005434988577	54A0F5	3750 315524	LIDIYA SIDOROVA	{"email": "sidorova_lidiya_31081970@postgrespro.ru", "phone": "+70250270095"}
0005434988578	54A0F5	6078 109278	MAKSIM IVANOV	{"email": "ivanov.m.111976@postgrespro.ru", "phone": "+70236244306"}
0005434988579	54A0F5	9031 603760	LYUDMILA SCHERBAKOVA	{"phone": "+70614345416"}
0005434988580	E20581	2289 992623	LYUBOV SOKOLOVA	{"phone": "+70385944790"}
0005434988581	E20581	6562 027405	VERA NIKOLAEVA	{"phone": "+70416266638"}
0005434988582	3376C6	1696 406987	TATYANA MOROZOVA	{"email": "tatyanamorozova1980@postgrespro.ru", "phone": "+70506035950"}
0005434988583	A0E2DB	6842 905379	YURIY TARASOV	{"email": "tarasov-y-1967@postgrespro.ru", "phone": "+70087006128"}
0005434988584	A78428	7857 176132	ARINA KONOVALOVA	{"email": "konovalova_a-051962@postgrespro.ru", "phone": "+70962420258"}
0005434988585	A78428	7452 047267	DENIS MOISEEV	{"phone": "+70363436059"}
0005434988586	9A3BD7	8572 548386	RAMAZAN IVANOV	{"email": "ivanov_ramazan081968@postgrespro.ru", "phone": "+70183420034"}
0005434988587	9A3BD7	9796 000592	LYUDMILA KAZAKOVA	{"email": "kazakova_l061961@postgrespro.ru", "phone": "+70010148688"}
0005434988588	68831B	4058 392159	VLADIMIR MAKAROV	{"email": "makarovvladimir04101972@postgrespro.ru", "phone": "+70976086501"}
0005434988589	68831B	3994 683038	ALEKSANDR KOZLOV	{"phone": "+70913243211"}
0005434988590	CAE68B	9276 864302	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_1964@postgrespro.ru", "phone": "+70257947838"}
0005434988591	CAE68B	3259 867724	IRINA NIKOLAEVA	{"email": "nikolaeva-i_13051973@postgrespro.ru", "phone": "+70976418306"}
0005434988592	1B8126	5054 655712	ANTON MOROZOV	{"email": "morozov-a_09111964@postgrespro.ru", "phone": "+70724219803"}
0005434988593	1B8126	8931 795090	NIKOLAY GAVRILOV	{"email": "nikolay-gavrilov_1947@postgrespro.ru", "phone": "+70466188341"}
0005434988594	96F344	6729 405543	ANNA SCHERBAKOVA	{"phone": "+70902380235"}
0005434988595	D3AB4F	6553 134503	ANTON SEMENOV	{"phone": "+70337841080"}
0005434988596	8B479E	6458 780108	ANDREY BELOV	{"phone": "+70276582251"}
0005434988597	E0E187	0044 994333	ALEKSANDR POPOV	{"email": "popov.aleksandr-011969@postgrespro.ru", "phone": "+70784957200"}
0005434988598	8F5BAA	8294 225053	SERGEY MOISEEV	{"phone": "+70314812160"}
0005434988599	B47C20	5616 399550	SERGEY MOISEEV	{"email": "sergeymoiseev-10031972@postgrespro.ru", "phone": "+70538649824"}
0005434988600	B47C20	9204 054893	PETR ORLOV	{"email": "p.orlov_071976@postgrespro.ru", "phone": "+70826374397"}
0005434988601	B0D2C7	0027 970617	VALENTINA SOKOLOVA	{"email": "sokolova-v27021965@postgrespro.ru", "phone": "+70912932485"}
0005434988602	B0D2C7	6628 307332	TAMARA ERMAKOVA	{"phone": "+70381047700"}
0005434988603	622EE5	6711 286572	TATYANA SOKOLOVA	{"phone": "+70236561476"}
0005434988604	622EE5	1686 718191	PAVEL MATVEEV	{"phone": "+70818833031"}
0005434988605	B228AD	8588 989101	SVETLANA SMIRNOVA	{"phone": "+70321058350"}
0005434988606	B228AD	9436 762690	ELMIRA VLASOVA	{"phone": "+70092722934"}
0005434988607	720DF2	1973 110278	RASIM KULIKOV	{"email": "r-kulikov1976@postgrespro.ru", "phone": "+70948258249"}
0005434988608	769D6D	5617 259831	GALINA RODIONOVA	{"phone": "+70776547271"}
0005434988609	7D1617	1510 291026	VLADIMIR ZHUKOV	{"phone": "+70521242502"}
0005434988610	7D1617	8762 529638	NIKOLAY TIKHONOV	{"phone": "+70502914515"}
0005434988611	F3B9F5	5978 284066	EKATERINA KUZNECOVA	{"phone": "+70722578168"}
0005434988612	5A657C	0504 134136	DENIS KUZNECOV	{"phone": "+70987861485"}
0005434988613	6D2152	1855 774425	IRINA SERGEEVA	{"phone": "+70555288897"}
0005434988614	88169E	2580 919371	NADEZHDA IVANOVA	{"email": "nadezhdaivanova-021961@postgrespro.ru", "phone": "+70400334506"}
0005434988615	3C3524	7044 766600	MIKHAIL NOVIKOV	{"phone": "+70507594094"}
0005434988616	DA95C3	3458 742243	EVGENIY ORLOV	{"phone": "+70590382868"}
0005434988617	9BA02F	8517 419880	ANDREY SCHERBAKOV	{"email": "a.scherbakov.011962@postgrespro.ru", "phone": "+70839693234"}
0005434988618	6FF266	1200 354433	ELENA SEMENOVA	{"email": "semenova_e-01091975@postgrespro.ru", "phone": "+70412744516"}
0005434988619	489102	4273 754043	SERGEY BELOV	{"phone": "+70906733593"}
0005434988620	AF879A	9395 128853	VALERIY POPOV	{"email": "vpopov_11061971@postgrespro.ru", "phone": "+70125787038"}
0005434988621	AF879A	5142 383499	MIKHAIL FROLOV	{"phone": "+70547785809"}
0005434988622	780E80	4170 270516	ANASTASIYA NIKIFOROVA	{"phone": "+70381136667"}
0005434988623	5A1657	0691 321497	ALEKSANDRA NAZAROVA	{"email": "nazarova.aleksandra_021979@postgrespro.ru", "phone": "+70550024792"}
0005434988625	DB4A43	6683 074401	BORIS ZHUKOV	{"email": "zhukov-boris-28021975@postgrespro.ru", "phone": "+70076242350"}
0005434988626	DB4A43	6073 183963	ANNA ZAYCEVA	{"email": "zayceva-anna_011970@postgrespro.ru", "phone": "+70145855375"}
0005434988627	9B667B	1182 727138	NATALYA LOGINOVA	{"phone": "+70034475599"}
0005434988628	9B667B	6958 978341	ELENA PAVLOVA	{"phone": "+70593717197"}
0005434988629	7ED22F	9151 140121	ELENA GERASIMOVA	{"email": "gerasimova_e_09101976@postgrespro.ru", "phone": "+70525576819"}
0005434988630	7ED22F	7841 805680	OLGA KULIKOVA	{"email": "kulikova-olga.1978@postgrespro.ru", "phone": "+70469091591"}
0005434988631	4F3392	0539 710448	MARIYA ANTONOVA	{"email": "mariya_antonova_1966@postgrespro.ru", "phone": "+70791227502"}
0005434988632	4F3392	9659 426944	SVETLANA MASLOVA	{"phone": "+70641539610"}
0005434988633	4CC3EA	7160 524749	VALENTINA POLYAKOVA	{"phone": "+70022230296"}
0005434988634	083B1F	8223 022036	IRINA BOGDANOVA	{"phone": "+70812410889"}
0005434988635	C4763E	8477 628225	IRINA LOGINOVA	{"email": "loginova.i_01091974@postgrespro.ru", "phone": "+70556204726"}
0005434988636	8AF6C3	6295 368130	OLEG PAVLOV	{"email": "o-pavlov-021970@postgrespro.ru", "phone": "+70345840250"}
0005434988637	F0E993	4951 029651	RAISA GORBUNOVA	{"phone": "+70101801346"}
0005434988638	3DB2B1	1362 580731	DANIL EGOROV	{"phone": "+70998575218"}
0005434988639	96B50A	6054 838283	ALEKSANDR VASILEV	{"phone": "+70424428758"}
0005434988640	96B50A	4516 262716	MAKSIM SOLOVEV	{"phone": "+70993394112"}
0005434988641	0B2E43	6933 221592	MAKSIM FOMIN	{"phone": "+70578464887"}
0005434988642	6705AF	6662 960945	LEONID SMIRNOV	{"phone": "+70728698112"}
0005434988643	79EC7F	4932 548535	ELISEY KRASNOV	{"email": "krasnove_04031968@postgrespro.ru", "phone": "+70973646728"}
0005434988644	A55E18	6398 265751	VYACHESLAV EGOROV	{"phone": "+70182612687"}
0005434988645	A9C970	4951 192941	SVETLANA RODIONOVA	{"phone": "+70202077258"}
0005434988646	B45F13	4895 469820	PAVEL VOLKOV	{"phone": "+70784790859"}
0005434988647	4FBA53	6029 657589	OLGA FOMINA	{"phone": "+70010362384"}
0005434988648	4FBA53	2225 296088	VALERIY MARTYNOV	{"phone": "+70805725725"}
0005434988649	4FBA53	8669 145285	ARSEN TARASOV	{"phone": "+70658018922"}
0005434988650	0849DD	3637 257724	ANASTASIYA AFANASEVA	{"phone": "+70654240929"}
0005434988651	94D7A2	3555 629506	ANTONINA VOLKOVA	{"phone": "+70400238813"}
0005434988652	94D7A2	8800 670129	VARVARA EFIMOVA	{"email": "varvara-efimova_121971@postgrespro.ru", "phone": "+70807131961"}
0005434988653	EC5F3C	7926 151648	MARK DAVYDOV	{"email": "m.davydov-07031977@postgrespro.ru", "phone": "+70756922358"}
0005434988654	ED6BBB	8228 211280	IRINA ZOTOVA	{"phone": "+70334775244"}
0005434988655	ED6BBB	9474 926742	SALAVAT ZAKHAROV	{"email": "zakharovsalavat-091979@postgrespro.ru", "phone": "+70246793276"}
0005434988656	ED6BBB	6763 837726	DARYA NOVIKOVA	{"phone": "+70585112377"}
0005434988657	F4C5DA	7432 805809	DMITRIY DAVYDOV	{"phone": "+70812901849"}
0005434988658	6822B0	6677 089977	VIKTOR IVANOV	{"phone": "+70698433419"}
0005434988659	916F71	1666 954266	ALEKSANDR BORISOV	{"email": "borisov-aleksandr101962@postgrespro.ru", "phone": "+70274868445"}
0005434988660	916F71	6865 932171	DMITRIY FROLOV	{"email": "frolov_dmitriy_121979@postgrespro.ru", "phone": "+70941882109"}
0005434988661	BCBF4B	2304 939346	ZINAIDA MOROZOVA	{"phone": "+70774425046"}
0005434988662	570A7D	1330 125528	ALFIYA MATVEEVA	{"phone": "+70489223488"}
0005434988663	570A7D	6278 984559	MIKHAIL KUDRYASHOV	{"phone": "+70431194295"}
0005434988664	48BA67	1025 270521	NINA SERGEEVA	{"email": "nsergeeva021963@postgrespro.ru", "phone": "+70042318660"}
0005434988665	6551EB	3197 063494	ALEKSANDR GAVRILOV	{"phone": "+70336676269"}
0005434988666	6399C8	9779 990126	TATYANA DAVYDOVA	{"phone": "+70692933043"}
0005434988667	0056FA	1262 618366	VLADIMIR MAKSIMOV	{"phone": "+70152398024"}
0005434988668	071BB2	8900 694046	TATYANA MELNIKOVA	{"phone": "+70190775259"}
0005434988669	869625	7923 030017	ALINA TIMOFEEVA	{"phone": "+70998872108"}
0005434988670	78F500	4573 033587	NATALYA FILIPPOVA	{"phone": "+70646488456"}
0005434988671	54D383	3603 351015	ANATOLIY GORBUNOV	{"phone": "+70465828836"}
0005434988672	815793	2143 400276	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana_1973@postgrespro.ru", "phone": "+70606858948"}
0005434988673	815793	1165 896674	TATYANA KOZLOVA	{"email": "t_kozlova-1982@postgrespro.ru", "phone": "+70002151486"}
0005434988674	5E2732	8081 442606	ALEKSANDR BONDARENKO	{"email": "a_bondarenko_08031977@postgrespro.ru", "phone": "+70225230718"}
0005434988675	5E2732	2505 308883	ELENA NIKIFOROVA	{"email": "elena-nikiforova1973@postgrespro.ru", "phone": "+70199192416"}
0005434988676	CFC211	9372 834558	VLADIMIR ANTONOV	{"phone": "+70020115552"}
0005434988677	1CC31B	0036 024473	ALEKSEY KUZNECOV	{"phone": "+70622793839"}
0005434988678	3F58A8	1793 701983	ALEKSANDR SHEVCHENKO	{"phone": "+70231050912"}
0005434988679	3F58A8	8902 825749	VLADIMIR TIMOFEEV	{"email": "vtimofeev28111962@postgrespro.ru", "phone": "+70462363405"}
0005434988680	57993D	1302 229630	DANILA SAVELEV	{"phone": "+70086103028"}
0005434988681	57993D	1797 784992	GENNADIY BARANOV	{"phone": "+70159932513"}
0005434988682	69AFFA	8329 074149	YANA EFIMOVA	{"email": "yana.efimova20101982@postgrespro.ru", "phone": "+70237070694"}
0005434988683	F87A7F	1157 027391	TIGRAN MOROZOV	{"phone": "+70482410939"}
0005434988684	F87A7F	2169 244174	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya091978@postgrespro.ru", "phone": "+70235923179"}
0005434988685	F87A7F	5861 154559	IRINA ZOTOVA	{"email": "zotova_irina-23091974@postgrespro.ru", "phone": "+70515453223"}
0005434988686	936436	5868 024618	ALEKSEY IVANOV	{"phone": "+70809452923"}
0005434988687	01A40F	1666 704680	NIKOLAY NAZAROV	{"phone": "+70216709369"}
0005434988688	01A40F	0126 229322	SERGEY DAVYDOV	{"email": "s.davydov.1976@postgrespro.ru", "phone": "+70431548298"}
0005434988689	1AE390	6703 997336	VALENTINA KOROLEVA	{"phone": "+70330353879"}
0005434988690	94ECF7	1379 611085	TAMARA POPOVA	{"phone": "+70725599659"}
0005434988691	506B06	7627 315329	EVGENIY GUSEV	{"phone": "+70142032094"}
0005434988692	4F842C	4345 990286	ANASTASIYA MAKSIMOVA	{"phone": "+70270694009"}
0005434988693	4F842C	7107 453019	LYUDMILA ANISIMOVA	{"phone": "+70036990255"}
0005434988694	E0AB37	4852 666423	LEV ISAEV	{"phone": "+70947993092"}
0005434988695	A7A039	4788 369947	VERA MIRONOVA	{"email": "mironovav_29061969@postgrespro.ru", "phone": "+70187362974"}
0005434988696	36FF94	4595 524918	OLGA GORBUNOVA	{"phone": "+70355971494"}
0005434988697	36FF94	1921 036324	INGA IVANOVA	{"phone": "+70928835807"}
0005434988698	4D8F2D	4303 246227	ANTON MIKHAYLOV	{"email": "mikhaylovanton-06061977@postgrespro.ru", "phone": "+70300130960"}
0005434988699	6E75D8	7906 498389	SERGEY SEMENOV	{"email": "semenovsergey_071972@postgrespro.ru", "phone": "+70510909186"}
0005434988700	6E75D8	5915 218920	LYUDMILA VLASOVA	{"email": "vlasova-lyudmila_1968@postgrespro.ru", "phone": "+70335101929"}
0005434988701	7C0177	7266 291065	EKATERINA KARPOVA	{"phone": "+70272688867"}
0005434988702	2AEAB0	4688 668551	VLADIMIR NIKITIN	{"email": "nikitin.vladimir_061975@postgrespro.ru", "phone": "+70583191299"}
0005434988703	0870F1	4815 671334	SVETLANA VOLKOVA	{"email": "volkova.svetlana.1975@postgrespro.ru", "phone": "+70484140520"}
0005434988704	0870F1	9610 660074	ALEKSANDR STEPANOV	{"phone": "+70194909664"}
0005434988705	C809C0	3362 558280	RAISA ANDREEVA	{"phone": "+70377109783"}
0005434988706	C809C0	6632 885917	ANDREY VOLKOV	{"email": "volkovandrey.071973@postgrespro.ru", "phone": "+70722990531"}
0005434988707	5618AD	7530 706619	EVGENIYA ABRAMOVA	{"phone": "+70540161312"}
0005434988708	4660F4	6852 175344	SERGEY STEPANOV	{"email": "stepanovsergey_02061979@postgrespro.ru", "phone": "+70349643331"}
0005434988709	4660F4	1248 061672	VLADISLAV NAZAROV	{"email": "nazarov-vladislav021987@postgrespro.ru", "phone": "+70674082177"}
0005434988710	7ACF16	5545 727169	VALENTINA SOROKINA	{"phone": "+70040970496"}
0005434988711	7ACF16	1556 734776	TATYANA MARTYNOVA	{"email": "t-martynova_1981@postgrespro.ru", "phone": "+70955487897"}
0005434988712	365DED	1367 795156	LYUBOV KULIKOVA	{"email": "lyubov_kulikova-1973@postgrespro.ru", "phone": "+70391807273"}
0005434988713	A1D935	8989 036436	YURIY TIKHONOV	{"email": "y-tikhonov.061964@postgrespro.ru", "phone": "+70884354241"}
0005434988714	A1D935	0253 102428	VADIM VASILEV	{"email": "vadimvasilev041971@postgrespro.ru", "phone": "+70965230012"}
0005434988715	575166	9697 957572	VALENTINA AFANASEVA	{"phone": "+70373744329"}
0005434988716	575166	6566 497170	ALEKSANDR VLASOV	{"phone": "+70478698209"}
0005434988717	A6E834	2602 519749	ELENA PAVLOVA	{"email": "pavlova.e-1960@postgrespro.ru", "phone": "+70744127665"}
0005434988718	7DB1AF	0953 204937	ANNA MARTYNOVA	{"email": "martynovaa_1972@postgrespro.ru", "phone": "+70071480665"}
0005434988719	44D8F1	0642 076205	ARTEMIY STEPANOV	{"email": "stepanov_artemiy.1963@postgrespro.ru", "phone": "+70817704089"}
0005434988720	44D8F1	3962 643334	EVGENIYA RODIONOVA	{"email": "rodionova_evgeniya.1971@postgrespro.ru", "phone": "+70542633018"}
0005434988721	0A556F	5023 000634	ALINA FROLOVA	{"email": "frolovaalina-31121962@postgrespro.ru", "phone": "+70939485355"}
0005434988722	53FD7C	7082 861519	GALINA ARKHIPOVA	{"phone": "+70390402572"}
0005434988723	53FD7C	4900 629515	OLGA KOROLEVA	{"phone": "+70891476156"}
0005434988724	290AD3	7357 081169	NINA POPOVA	{"phone": "+70411159535"}
0005434988725	278962	1612 566319	VLADIMIR BONDARENKO	{"phone": "+70851970256"}
0005434988726	974D63	9344 977427	DMITRIY KRASNOV	{"phone": "+70890973901"}
0005434988727	974D63	5560 391320	ALEKSANDR MELNIKOV	{"phone": "+70117265702"}
0005434988728	8CCF48	6087 459655	ALENA LOGINOVA	{"email": "alena-loginova.31121992@postgrespro.ru", "phone": "+70403151769"}
0005434988729	27FC51	1705 949510	KSENIYA ZOTOVA	{"phone": "+70952460711"}
0005434988730	F85855	6404 567854	NIKITA BELOV	{"email": "belov-nikita.23051965@postgrespro.ru", "phone": "+70362344252"}
0005434988899	0BB073	5277 943310	SERGEY IVANOV	{"phone": "+70633214293"}
0005434988731	F85855	1520 869290	KSENIYA KONDRATEVA	{"email": "kseniyakondrateva.27121975@postgrespro.ru", "phone": "+70454218888"}
0005434988732	F85855	5122 930276	RAMIL GUSEV	{"email": "gusevramil_09091972@postgrespro.ru", "phone": "+70284117203"}
0005434988733	84FA71	8396 040784	SVETLANA IVANOVA	{"email": "svetlanaivanova_041966@postgrespro.ru", "phone": "+70438610605"}
0005434988734	C9B4F5	4820 412216	ELENA SIDOROVA	{"phone": "+70434191753"}
0005434988735	457ABA	2532 782018	ALEKSANDR ANDREEV	{"phone": "+70766878670"}
0005434988736	457ABA	1504 932106	RIMMA ALEKSANDROVA	{"phone": "+70377223201"}
0005434988737	DC46F7	9891 207042	TATYANA CHERNOVA	{"phone": "+70884463038"}
0005434988738	C7E05E	6778 626077	LEONID PETROV	{"email": "leonid-petrov-101972@postgrespro.ru", "phone": "+70223410882"}
0005434988739	C7E05E	5792 224805	EKATERINA KRASNOVA	{"phone": "+70759130840"}
0005434988740	408EAE	5832 345998	OLGA ANTONOVA	{"phone": "+70454064217"}
0005434988741	E20991	0839 409259	EKATERINA POPOVA	{"email": "e-popova30101966@postgrespro.ru", "phone": "+70141167741"}
0005434988742	E415D6	7112 017547	VLADIMIR SERGEEV	{"email": "v_sergeev24081968@postgrespro.ru", "phone": "+70690815806"}
0005434988743	1FB8EF	8053 786804	VALENTINA GUSEVA	{"email": "v_guseva-1962@postgrespro.ru", "phone": "+70318444520"}
0005434988744	A1CA12	0745 421207	PELAGEYA MASLOVA	{"email": "pelageyamaslova-29041975@postgrespro.ru", "phone": "+70477570595"}
0005434988745	48D253	7984 214901	IRINA KUZNECOVA	{"phone": "+70409907022"}
0005434988746	1DA95F	6344 812615	ZINAIDA SOROKINA	{"email": "zinaida-sorokina.011969@postgrespro.ru", "phone": "+70755597853"}
0005434988747	1DA95F	2472 932832	ALEKSANDR ROMANOV	{"email": "romanovaleksandr-081968@postgrespro.ru", "phone": "+70970062842"}
0005434988748	AFD91B	2738 101365	NIKOLAY VOLKOV	{"phone": "+70464086947"}
0005434988749	9EA6A5	9567 323166	VALENTINA ZAKHAROVA	{"phone": "+70539935502"}
0005434988750	B1E070	9661 039231	VLADIMIR GRIGOREV	{"email": "grigorev.vladimir-23071960@postgrespro.ru", "phone": "+70400181948"}
0005434988751	700C7A	6408 523246	MARIYA VASILEVA	{"phone": "+70676866505"}
0005434988752	94A13F	7933 084504	DMITRIY NAUMOV	{"phone": "+70846134652"}
0005434988753	94A13F	6614 289875	ANASTASIYA GERASIMOVA	{"phone": "+70724814901"}
0005434988754	50CD60	4421 342319	ELENA SEMENOVA	{"phone": "+70861507543"}
0005434988755	50CD60	9602 683193	NIKOLAY MEDVEDEV	{"email": "medvedevnikolay-1975@postgrespro.ru", "phone": "+70636983492"}
0005434988756	0ACE89	4091 354533	DIANA SOLOVEVA	{"phone": "+70013214712"}
0005434988757	6BC5E3	9145 644969	IRINA MELNIKOVA	{"phone": "+70097220080"}
0005434988758	6BC5E3	4303 972186	INESSA KUZNECOVA	{"phone": "+70858288511"}
0005434988759	9C3898	7959 663967	IRINA OSIPOVA	{"email": "osipova_i-111974@postgrespro.ru", "phone": "+70256672779"}
0005434988760	1EFBB2	7992 422326	IRINA VOLKOVA	{"email": "volkova.i121980@postgrespro.ru", "phone": "+70467571509"}
0005434988761	1EFBB2	6196 493937	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov-17041959@postgrespro.ru", "phone": "+70472486595"}
0005434988762	2196EA	7202 818217	NINA KUZNECOVA	{"phone": "+70019192376"}
0005434988763	5E02B8	8356 152028	ELENA KUDRYASHOVA	{"email": "kudryashova.elena101967@postgrespro.ru", "phone": "+70348975466"}
0005434988764	393B8B	2548 624455	DMITRIY KUZNECOV	{"email": "d-kuznecov_1967@postgrespro.ru", "phone": "+70388993841"}
0005434988765	FE73F4	0887 878330	SERGEY SAVELEV	{"email": "savelev.sergey.05081959@postgrespro.ru", "phone": "+70041592136"}
0005434988766	FE73F4	4543 199346	ALEKSANDR NOVIKOV	{"phone": "+70942855744"}
0005434988767	CBF4F1	5175 818614	MADINA BORISOVA	{"email": "borisova-m_23071972@postgrespro.ru", "phone": "+70629229556"}
0005434988768	3B4C5A	8811 868448	MARIYA IVANOVA	{"phone": "+70315865492"}
0005434988769	C64BBF	2218 503208	GEORGIY VLASOV	{"phone": "+70146301121"}
0005434988770	C64BBF	8565 377680	MIKHAIL KUZNECOV	{"email": "mkuznecov_1970@postgrespro.ru", "phone": "+70531216154"}
0005434988771	DFF5E4	7644 448024	MARINA KUDRYASHOVA	{"phone": "+70224812195"}
0005434988772	DFF5E4	9418 920899	TATYANA NIKOLAEVA	{"phone": "+70065113234"}
0005434988773	4A7863	9852 380965	VASILIY ORLOV	{"phone": "+70613381103"}
0005434988774	F2C165	3511 522497	VLADIMIR KUZNECOV	{"phone": "+70147404810"}
0005434988775	F2C165	3360 964594	SERGEY GORBUNOV	{"email": "gorbunov-s.29111973@postgrespro.ru", "phone": "+70847291317"}
0005434988776	49FE48	7200 840494	TIMUR ALEKSEEV	{"email": "timur_alekseev_15071967@postgrespro.ru", "phone": "+70143296328"}
0005434988777	4DA632	9109 473553	DMITRIY FOMIN	{"email": "dmitriy-fomin-1959@postgrespro.ru", "phone": "+70134422836"}
0005434988778	4DA632	6937 171847	RAVIL MIRONOV	{"email": "ravil-mironov1973@postgrespro.ru", "phone": "+70451799194"}
0005434988779	AB33AC	7013 876111	OLEG GUSEV	{"phone": "+70987380138"}
0005434988780	AB33AC	2643 817495	LARISA CHERNOVA	{"email": "chernova-l031971@postgrespro.ru", "phone": "+70644090889"}
0005434988781	AB33AC	1566 336539	IGOR ZAKHAROV	{"email": "zakharov.igor.19101972@postgrespro.ru", "phone": "+70058351826"}
0005434988782	7515F4	0201 286380	EVGENIY IVANOV	{"email": "e-ivanov_091965@postgrespro.ru", "phone": "+70639736645"}
0005434988783	FC4CF0	4830 899544	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e_1967@postgrespro.ru", "phone": "+70863459831"}
0005434988784	4D9DFB	5352 960523	ALEKSANDR ISAEV	{"phone": "+70357132476"}
0005434988785	9DE6C9	4637 469096	VLADIMIR IVANOV	{"phone": "+70561035472"}
0005434988786	8074D8	9679 357988	NATALYA MEDVEDEVA	{"phone": "+70350057039"}
0005434988787	8074D8	6436 249922	IGOR KUZNECOV	{"email": "i.kuznecov.1974@postgrespro.ru", "phone": "+70716715251"}
0005434988788	9D6ECE	8765 643212	NINA CHERNOVA	{"email": "nina.chernova.23011966@postgrespro.ru", "phone": "+70481309175"}
0005434988789	6AB136	7528 681875	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir121966@postgrespro.ru", "phone": "+70203774993"}
0005434988790	6AB136	9966 377470	LEONTIY VASILEV	{"email": "vasilev.l_021973@postgrespro.ru", "phone": "+70389038383"}
0005434988791	A3DABE	0744 043659	SVETLANA BORISOVA	{"email": "borisova_s011989@postgrespro.ru", "phone": "+70298939320"}
0005434988792	A3DABE	6691 522426	VIKTOR SEMENOV	{"email": "semenov_v.24081960@postgrespro.ru", "phone": "+70528766319"}
0005434988793	048ED3	2972 243905	NADEZHDA KULIKOVA	{"email": "nadezhda_kulikova1974@postgrespro.ru", "phone": "+70167198139"}
0005434988794	3B8846	4883 796525	EKATERINA ALEKSEEVA	{"phone": "+70120269786"}
0005434988795	3B8846	9600 186110	VALENTINA RODIONOVA	{"phone": "+70717902003"}
0005434988796	23FE9A	3196 796679	NIKOLAY NIKITIN	{"phone": "+70705338047"}
0005434988797	23FE9A	2089 690118	GALINA KAZAKOVA	{"email": "kazakova_g-041979@postgrespro.ru", "phone": "+70141200705"}
0005434988798	65B2BD	7132 737603	DMITRIY SCHERBAKOV	{"phone": "+70135365267"}
0005434988799	65B2BD	2653 761916	POLINA IVANOVA	{"email": "p_ivanova03091978@postgrespro.ru", "phone": "+70641678138"}
0005434988800	7C0DD1	7863 854726	YULIYA AKIMOVA	{"email": "akimova_y.15101968@postgrespro.ru", "phone": "+70077486304"}
0005434988801	7F4960	1147 033286	PETR KUZNECOV	{"email": "kuznecov_p.091972@postgrespro.ru", "phone": "+70768055407"}
0005434988802	7F4960	7348 849676	EVGENIY IVANOV	{"email": "e.ivanov.041971@postgrespro.ru", "phone": "+70066105409"}
0005434988803	961080	0482 101262	TATYANA SOLOVEVA	{"phone": "+70987443548"}
0005434988804	DA2F4D	4652 052628	TAISIYA ZAKHAROVA	{"phone": "+70081486642"}
0005434988805	138181	6541 221058	EVGENIYA IVANOVA	{"phone": "+70762673351"}
0005434988806	5C00D0	1304 607448	TATYANA VOROBEVA	{"email": "tatyana-vorobeva_121965@postgrespro.ru", "phone": "+70559207839"}
0005434988807	774B0E	2053 257264	NIKOLAY DENISOV	{"phone": "+70986175737"}
0005434988808	774B0E	3638 021468	OLGA SEMENOVA	{"phone": "+70102221607"}
0005434988809	8B67FD	9679 140762	RAISA EFIMOVA	{"email": "raisa-efimova_1973@postgrespro.ru", "phone": "+70655035431"}
0005434988810	9C8D96	8591 384343	VLADIMIR DAVYDOV	{"phone": "+70211801400"}
0005434988811	51B073	1936 631079	ANDREY IVANOV	{"email": "ivanova-051972@postgrespro.ru", "phone": "+70558516446"}
0005434988812	35552A	0665 527238	IRINA MATVEEVA	{"phone": "+70156013873"}
0005434988813	35552A	0780 195183	ALEKSANDRA RYABOVA	{"phone": "+70685013398"}
0005434988814	A6DC41	4294 390794	ALEKSANDR RODIONOV	{"email": "a_rodionov.15081973@postgrespro.ru", "phone": "+70628943849"}
0005434988815	E3E2FE	1355 592885	PAVEL SCHERBAKOV	{"phone": "+70397812550"}
0005434988816	5B66E5	6896 373493	YURIY VOLKOV	{"email": "volkovy.091966@postgrespro.ru", "phone": "+70274515066"}
0005434988817	9AF3F9	2426 788024	ALEKSANDR GRIGOREV	{"phone": "+70079595047"}
0005434988818	70B25E	1166 711780	NADEZHDA VOLKOVA	{"email": "n-volkova_101970@postgrespro.ru", "phone": "+70896483392"}
0005434988819	70B25E	2406 620087	KLAVDIYA NOVIKOVA	{"email": "k-novikova-1960@postgrespro.ru", "phone": "+70043022673"}
0005434988820	8092E1	1027 568151	YURIY BELOV	{"email": "belov-yuriy.02121970@postgrespro.ru", "phone": "+70453586594"}
0005434988821	CA2DA0	2340 156288	NIKOLAY FEDOROV	{"phone": "+70918911510"}
0005434988822	882977	2687 559179	ANASTASIYA SEMENOVA	{"email": "anastasiya.semenova.24101976@postgrespro.ru", "phone": "+70100930780"}
0005434988823	882977	9980 574753	VLADIMIR ZHUKOV	{"email": "zhukov.vladimir_1977@postgrespro.ru", "phone": "+70347145267"}
0005434988824	DCDE4A	3804 388306	NIKOLAY FROLOV	{"email": "frolov-nikolay.1986@postgrespro.ru", "phone": "+70671902849"}
0005434988825	DCDE4A	6899 201964	KSENIYA NESTEROVA	{"email": "k.nesterova-071961@postgrespro.ru", "phone": "+70975488027"}
0005434988826	0A02FE	5104 695681	DANIIL BONDARENKO	{"email": "d_bondarenko.29031978@postgrespro.ru", "phone": "+70074844312"}
0005434988827	2E1680	3883 987748	ALEKSEY SEMENOV	{"phone": "+70756918981"}
0005434988828	6533F2	1894 592590	LYUBOV POLYAKOVA	{"email": "l_polyakova11041973@postgrespro.ru", "phone": "+70104897600"}
0005434988829	DFB782	4461 145546	SERGEY KUZMIN	{"phone": "+70456563289"}
0005434988830	DFB782	6803 420409	TATYANA MATVEEVA	{"phone": "+70309680753"}
0005434988831	A913E6	8336 772925	TAMARA ALEKSANDROVA	{"email": "aleksandrova.t.22051972@postgrespro.ru", "phone": "+70151932665"}
0005434988832	F8BB3E	9628 489870	EVGENIY BORISOV	{"email": "e.borisov24071974@postgrespro.ru", "phone": "+70528402045"}
0005434988833	17092B	4150 712904	EGOR STEPANOV	{"email": "e.stepanov_1981@postgrespro.ru", "phone": "+70719578540"}
0005434988834	17092B	3110 960406	VALERIY ZAKHAROV	{"email": "zakharov_valeriy.23031974@postgrespro.ru", "phone": "+70433468325"}
0005434988835	0C7D63	0593 533849	SERGEY TIKHONOV	{"phone": "+70592685412"}
0005434988836	4EBC22	1921 828368	NATALYA MAKAROVA	{"phone": "+70225226494"}
0005434988837	4EBC22	3135 391953	TATYANA BARANOVA	{"phone": "+70877068087"}
0005434988838	E6A2D5	4150 806399	NATALIYA ALEKSANDROVA	{"phone": "+70003077703"}
0005434988839	A6BA6D	4890 730282	NINA ZHURAVLEVA	{"email": "nina.zhuravleva.08021975@postgrespro.ru", "phone": "+70407403580"}
0005434988840	E3A2F5	9091 836021	ALEKSANDRA VASILEVA	{"email": "vasileva.a051978@postgrespro.ru", "phone": "+70488916128"}
0005434988841	E3A2F5	0852 407908	GENNADIY KAZAKOV	{"phone": "+70437055889"}
0005434988842	F3BD52	9377 657841	NINA FILIPPOVA	{"email": "n.filippova121966@postgrespro.ru", "phone": "+70763241994"}
0005434988843	7D10D3	4684 922226	NIKITA GAVRILOV	{"phone": "+70569085440"}
0005434988844	268B0C	2868 509234	MAKSIM FEDOTOV	{"phone": "+70017098988"}
0005434988845	268B0C	6392 123467	IRINA POPOVA	{"phone": "+70724521097"}
0005434988846	011B81	2254 062780	LIDIYA GAVRILOVA	{"phone": "+70598863605"}
0005434988847	011B81	2989 127537	OLEG MIKHAYLOV	{"email": "mikhaylov_o.1979@postgrespro.ru", "phone": "+70843403877"}
0005434988848	25E80E	9063 412262	ALEKSEY EGOROV	{"phone": "+70063986074"}
0005434988849	DC9AD2	3061 228817	MIKHAIL KARPOV	{"phone": "+70410216918"}
0005434988850	496F31	0651 665172	ILYA SAVELEV	{"email": "savelev-i.1981@postgrespro.ru", "phone": "+70546583313"}
0005434988851	4FAC8D	0988 141657	ALEKSANDR ORLOV	{"email": "aleksandrorlov.12011975@postgrespro.ru", "phone": "+70532163931"}
0005434988852	03BA79	2223 114846	ALEKSEY SERGEEV	{"phone": "+70042674298"}
0005434988853	03BA79	2014 108959	VERONIKA MOISEEVA	{"phone": "+70018971240"}
0005434988854	D9CB83	8505 913865	GRIGORIY DAVYDOV	{"email": "gdavydov011976@postgrespro.ru", "phone": "+70137697457"}
0005434988855	D9CB83	9620 994133	ALEKSEY VASILEV	{"phone": "+70653901645"}
0005434988856	FBE92D	3275 375615	YULIYA POLYAKOVA	{"email": "polyakova-y-071976@postgrespro.ru", "phone": "+70797895974"}
0005434988857	9BE436	5653 934023	TATYANA MELNIKOVA	{"email": "melnikova_tatyana-17011975@postgrespro.ru", "phone": "+70007842767"}
0005434988858	8F450B	6996 043803	VLADIMIR POPOV	{"email": "popov-vladimir031977@postgrespro.ru", "phone": "+70715398689"}
0005434988859	46C84A	4305 200159	ELINA MIKHAYLOVA	{"email": "mikhaylova.elina_10101985@postgrespro.ru", "phone": "+70630315949"}
0005434988860	46C84A	4993 429094	IVAN BELOV	{"email": "belov_i_20031977@postgrespro.ru", "phone": "+70511218261"}
0005434988861	E61E21	4596 718701	GENNADIY KONOVALOV	{"phone": "+70756484798"}
0005434988862	E61E21	1580 661383	REGINA KAZAKOVA	{"phone": "+70685518636"}
0005434988863	C4ABE3	4549 698291	OLESYA SOKOLOVA	{"email": "o_sokolova.031960@postgrespro.ru", "phone": "+70783597605"}
0005434988864	52C760	3573 035671	VALENTINA GAVRILOVA	{"email": "vgavrilova05081962@postgrespro.ru", "phone": "+70611882393"}
0005434988865	02ECD8	9191 737473	PAVEL SEMENOV	{"phone": "+70461882791"}
0005434988866	82B142	0957 083388	IVAN MIRONOV	{"phone": "+70767518569"}
0005434988867	82B142	2333 405510	NATALIYA SAVELEVA	{"phone": "+70596971521"}
0005434988868	0BBE30	7940 416197	ALEKSANDR NIKITIN	{"phone": "+70494492131"}
0005434988869	FF7103	3672 869951	KIRA ALEKSEEVA	{"phone": "+70777944794"}
0005434988870	E0B913	0109 902103	KRISTINA GAVRILOVA	{"phone": "+70667387187"}
0005434988871	C73B2F	5457 869807	POLINA AKIMOVA	{"phone": "+70076432442"}
0005434988872	32A567	2083 246685	POLINA KAZAKOVA	{"phone": "+70879188099"}
0005434988873	32A567	6879 090449	OLGA ZHUKOVA	{"phone": "+70970062053"}
0005434988874	32A567	4651 806808	YURIY ANDREEV	{"phone": "+70425368137"}
0005434988875	FB8F1E	5152 909722	EVGENIY YAKOVLEV	{"phone": "+70923173723"}
0005434988876	3EE777	9011 472166	ALEKSANDR PETROV	{"phone": "+70789694610"}
0005434988877	1F37D6	3204 444816	ELENA KOZLOVA	{"email": "e_kozlova021968@postgrespro.ru", "phone": "+70973510697"}
0005434988878	FBCDE2	2368 566291	ANTON VOROBEV	{"phone": "+70676773406"}
0005434988879	DA53EF	7741 023673	VASILIY VASILEV	{"phone": "+70245131143"}
0005434988880	DA53EF	2671 575412	PAVEL MELNIKOV	{"email": "p_melnikov.19091971@postgrespro.ru", "phone": "+70996616376"}
0005434988881	4A6A96	3392 709302	ALEKSANDRA VASILEVA	{"email": "avasileva1975@postgrespro.ru", "phone": "+70774784000"}
0005434988882	4A6A96	0280 049774	SVETLANA KISELEVA	{"phone": "+70786802373"}
0005434988883	417510	9851 682408	PAVEL SMIRNOV	{"email": "pavel.smirnov1973@postgrespro.ru", "phone": "+70363247161"}
0005434988884	55133F	4215 406728	VERONIKA FOMINA	{"phone": "+70088280399"}
0005434988885	ECF7D3	2846 183642	NATALYA SOLOVEVA	{"email": "soloveva.n_04061972@postgrespro.ru", "phone": "+70453133156"}
0005434988886	9FAC32	3826 976321	DMITRIY KUDRYASHOV	{"phone": "+70854193462"}
0005434988887	FD1D17	6620 037364	KRISTINA OSIPOVA	{"email": "kristina_osipova_1973@postgrespro.ru", "phone": "+70849304909"}
0005434988888	55CA4D	9060 151821	MARIYA ANISIMOVA	{"phone": "+70451144143"}
0005434988889	55CA4D	0537 955126	VERA IVANOVA	{"email": "veraivanova1963@postgrespro.ru", "phone": "+70630121593"}
0005434988890	516FBF	4255 220847	ELENA ISAEVA	{"email": "elenaisaeva1964@postgrespro.ru", "phone": "+70995541014"}
0005434988891	516FBF	6433 885237	DANIIL FROLOV	{"phone": "+70837360187"}
0005434988892	516FBF	6896 643702	ELENA SOKOLOVA	{"email": "sokolova-e-061972@postgrespro.ru", "phone": "+70327148625"}
0005434988893	34463E	3776 961780	GENNADIY STEPANOV	{"email": "stepanovg-111979@postgrespro.ru", "phone": "+70310478187"}
0005434988894	BD570A	9899 020645	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr_11101970@postgrespro.ru", "phone": "+70161246983"}
0005434988895	177646	2203 131271	ELIZAVETA ALEKSANDROVA	{"email": "aleksandrova-e.1972@postgrespro.ru", "phone": "+70195478624"}
0005434988896	177646	0700 644475	LYUDMILA KUZNECOVA	{"email": "lyudmilakuznecova.1982@postgrespro.ru", "phone": "+70657307558"}
0005434988897	7CA388	7385 222305	ANATOLIY SAVELEV	{"phone": "+70005953661"}
0005434988898	7CA388	8067 678488	ANNA EGOROVA	{"phone": "+70625779297"}
0005434988900	ED4D14	1825 763189	GEORGIY MIKHAYLOV	{"phone": "+70020763910"}
0005434988901	ED4D14	2244 133543	VALENTIN STEPANOV	{"email": "stepanov_valentin_26081963@postgrespro.ru", "phone": "+70327351895"}
0005434988902	F33443	0160 676487	DARYA EGOROVA	{"email": "egorova-d.16101982@postgrespro.ru", "phone": "+70845829204"}
0005434988903	930648	5421 453757	EVGENIY PAVLOV	{"email": "pavlov_e_041973@postgrespro.ru", "phone": "+70228604101"}
0005434988904	AEC7DB	4069 836385	ALEKSANDRA SEMENOVA	{"phone": "+70139188302"}
0005434988905	B996E3	1127 078994	ALEKSANDR PETROV	{"phone": "+70216948254"}
0005434988906	B996E3	5396 321896	YULIYA KUZNECOVA	{"phone": "+70894719628"}
0005434988907	2AA7B4	1807 431457	GALINA ALEKSANDROVA	{"email": "aleksandrova_g27101973@postgrespro.ru", "phone": "+70027499182"}
0005434988908	AD799B	8888 636663	ELENA NIKOLAEVA	{"email": "nikolaeva.e.29061973@postgrespro.ru", "phone": "+70444497701"}
0005434988909	E218B2	0495 374816	VYACHESLAV YAKOVLEV	{"phone": "+70481303533"}
0005434988910	4AF645	4783 090393	NATALYA ERMAKOVA	{"email": "n-ermakova.081977@postgrespro.ru", "phone": "+70202125865"}
0005434988911	6EA095	3477 902747	LEONID KAZAKOV	{"phone": "+70002054496"}
0005434988912	4AEE17	9106 667114	SERGEY SEMENOV	{"email": "semenov_sergey12121977@postgrespro.ru", "phone": "+70283844418"}
0005434988913	797E35	9203 113479	VIKTORIYA EGOROVA	{"email": "viktoriya-egorova.1971@postgrespro.ru", "phone": "+70750531994"}
0005434988914	184090	9630 078274	MIKHAIL FEDOTOV	{"phone": "+70205946822"}
0005434988915	389018	1316 602531	VALERIYA POPOVA	{"email": "valeriya_popova111967@postgrespro.ru", "phone": "+70774943669"}
0005434988916	674324	6573 080320	RIMMA DENISOVA	{"phone": "+70531202135"}
0005434988917	D8D0D8	4055 292191	GALINA KISELEVA	{"phone": "+70110246526"}
0005434988918	D8D0D8	1890 259748	YURIY BORISOV	{"phone": "+70896500755"}
0005434988919	90C2CB	9899 612578	VALENTINA EGOROVA	{"email": "valentinaegorova.05031970@postgrespro.ru", "phone": "+70960224572"}
0005434988920	BB3775	3178 571682	MARIYA KOVALEVA	{"phone": "+70312451761"}
0005434988921	862C71	6545 916935	SERGEY KUZNECOV	{"email": "kuznecov.sergey-16021967@postgrespro.ru", "phone": "+70081377156"}
0005434988922	862C71	5888 004294	KRISTINA IVANOVA	{"phone": "+70875568390"}
0005434988923	5B0A6B	7474 912241	TATYANA OSIPOVA	{"email": "tatyanaosipova-1970@postgrespro.ru", "phone": "+70101888760"}
0005434988924	5B0A6B	9325 246026	RUSTYAM KARPOV	{"phone": "+70833578818"}
0005434988925	148C34	4479 361176	ANNA FILATOVA	{"phone": "+70923491722"}
0005434988926	F5D056	3696 722780	NIKOLAY DAVYDOV	{"phone": "+70543424885"}
0005434988927	24FBB7	3656 668767	BORIS NAUMOV	{"email": "naumov.b-1970@postgrespro.ru", "phone": "+70739350005"}
0005434988928	24FBB7	6563 283709	ELENA LAZAREVA	{"email": "lazareva_elena-09081971@postgrespro.ru", "phone": "+70778017283"}
0005434988929	FFB564	7190 931725	PETR KOZLOV	{"email": "kozlov_petr-1972@postgrespro.ru", "phone": "+70568874365"}
0005434988987	E3338D	4865 777032	MAKSIM ZHURAVLEV	{"phone": "+70643642843"}
0005434988930	1E7807	3087 389777	ALEKSEY SOROKIN	{"email": "asorokin.031976@postgrespro.ru", "phone": "+70734980509"}
0005434988931	1E7807	1230 005571	ALEKSEY VOROBEV	{"email": "a.vorobev_1964@postgrespro.ru", "phone": "+70282878793"}
0005434988932	1E7807	3110 554735	DENIS PAVLOV	{"phone": "+70249895110"}
0005434988933	AC9BB3	0232 122194	ALEKSEY KUZNECOV	{"phone": "+70618677468"}
0005434988934	AC9BB3	3199 109202	VALERIY ANTONOV	{"email": "valeriy.antonov10011978@postgrespro.ru", "phone": "+70090613096"}
0005434988935	AC9BB3	3060 250994	MARGARITA IVANOVA	{"email": "ivanovamargarita-19021974@postgrespro.ru", "phone": "+70452009273"}
0005434988936	59CB4A	9704 135850	OKSANA PETROVA	{"email": "petrova_o-1970@postgrespro.ru", "phone": "+70813369401"}
0005434988937	18DA5A	9523 418154	NADEZHDA SMIRNOVA	{"email": "nadezhda-smirnova.09011973@postgrespro.ru", "phone": "+70118792503"}
0005434988938	3C1281	2005 911144	LYUDMILA FOMINA	{"email": "fomina-lyudmila11091980@postgrespro.ru", "phone": "+70340156010"}
0005434988939	3C1281	0819 881783	LIDIYA EFIMOVA	{"email": "efimova-l1977@postgrespro.ru", "phone": "+70259798109"}
0005434988940	EDB842	6957 454764	MARIYA NOVIKOVA	{"email": "novikova.m_011963@postgrespro.ru", "phone": "+70013695137"}
0005434988941	C35597	3564 963550	YURIY PETROV	{"email": "yuriy-petrov051972@postgrespro.ru", "phone": "+70858453441"}
0005434988942	C35597	9619 632218	DARYA SOROKINA	{"phone": "+70932698484"}
0005434988943	3E84C3	8157 655999	SERGEY KUDRYASHOV	{"email": "sergey-kudryashov-04011977@postgrespro.ru", "phone": "+70673793755"}
0005434988944	C8EBAD	1741 760419	TATYANA KOLESNIKOVA	{"email": "kolesnikova-t.061968@postgrespro.ru", "phone": "+70448750641"}
0005434988945	C8EBAD	1525 429829	ALEKSEY KOZLOV	{"email": "alekseykozlov-1964@postgrespro.ru", "phone": "+70613736111"}
0005434988946	23EC67	3429 939207	MIKHAIL ROMANOV	{"phone": "+70806233659"}
0005434988947	23EC67	1669 849954	YULIYA DMITRIEVA	{"phone": "+70079768992"}
0005434988948	7D0EFF	7183 339793	LYUDMILA KOMAROVA	{"email": "l.komarova1967@postgrespro.ru", "phone": "+70151124173"}
0005434988949	7D0EFF	7292 205043	ILYA TARASOV	{"phone": "+70082306400"}
0005434988950	25DEC9	1342 188412	MAKSIM VLASOV	{"phone": "+70169040954"}
0005434988951	D8D150	3040 982725	SERGEY SMIRNOV	{"email": "sergey.smirnov.051963@postgrespro.ru", "phone": "+70715723370"}
0005434988952	6831C8	6478 428148	NATALYA KISELEVA	{"email": "nkiseleva_1967@postgrespro.ru", "phone": "+70859775212"}
0005434988953	486CA9	4935 108064	LIDIYA POPOVA	{"phone": "+70800236353"}
0005434988954	486CA9	2037 086834	SERGEY YAKOVLEV	{"email": "yakovlevs-071981@postgrespro.ru", "phone": "+70721100068"}
0005434988955	7CED17	6977 816577	EKATERINA MAKAROVA	{"phone": "+70794076491"}
0005434988956	7CED17	5720 627926	ALEKSANDR VASILEV	{"email": "vasilevaleksandr-17011979@postgrespro.ru", "phone": "+70514025204"}
0005434988957	7E6710	8224 628056	FEDOR FILIPPOV	{"phone": "+70735639544"}
0005434988958	86F93A	4231 656216	ALINA KOVALEVA	{"phone": "+70997400231"}
0005434988959	86F93A	3915 516101	OLGA SEMENOVA	{"email": "olgasemenova.07021977@postgrespro.ru", "phone": "+70725052602"}
0005434988960	8E34CE	0236 997353	TATYANA BORISOVA	{"email": "borisova_t_23091968@postgrespro.ru", "phone": "+70821950095"}
0005434988961	BB065B	9789 909884	ELEONORA TIMOFEEVA	{"phone": "+70103885423"}
0005434988962	48B1F4	2123 515252	MAKSIM MARTYNOV	{"email": "m.martynov1963@postgrespro.ru", "phone": "+70491728834"}
0005434988963	54DB4C	9363 005667	GALINA GERASIMOVA	{"phone": "+70802642864"}
0005434988964	54DB4C	0712 188371	YAROSLAV MARTYNOV	{"email": "martynov.yaroslav_011970@postgrespro.ru", "phone": "+70399504894"}
0005434988965	679802	8353 216915	SERGEY NAZAROV	{"phone": "+70116206036"}
0005434988966	A8DF67	1327 475605	ARTUR FEDOTOV	{"email": "artur.fedotov-1968@postgrespro.ru", "phone": "+70801604870"}
0005434988967	5F06D0	4519 799584	ALEKSANDR FEDOROV	{"email": "fedorov.a-1970@postgrespro.ru", "phone": "+70935939294"}
0005434988968	6069F4	0978 306040	NATALYA KUZNECOVA	{"phone": "+70176078830"}
0005434988969	93E14B	9918 750796	VIKTOR SMIRNOV	{"email": "smirnov-viktor011976@postgrespro.ru", "phone": "+70019852033"}
0005434988970	93E14B	5506 679682	TATYANA NIKITINA	{"email": "nikitina.t_031968@postgrespro.ru", "phone": "+70532320045"}
0005434988971	65CB4A	4041 288869	NIKOLAY ANTONOV	{"email": "antonovn_1967@postgrespro.ru", "phone": "+70296921838"}
0005434988972	5F69F5	9862 136761	RAFAIL NIKOLAEV	{"email": "nikolaev-rafail.1973@postgrespro.ru", "phone": "+70585404404"}
0005434988973	0D8D0E	4347 205203	LYUDMILA NAUMOVA	{"phone": "+70769465294"}
0005434988974	88E8F0	9546 714791	TAMARA KUZNECOVA	{"email": "kuznecova_t_24051982@postgrespro.ru", "phone": "+70961789451"}
0005434988975	D6246D	8693 846273	VALENTINA KONDRATEVA	{"email": "kondratevavalentina_071971@postgrespro.ru", "phone": "+70778606577"}
0005434988976	B628BE	2338 045482	NATALYA RYABOVA	{"email": "n-ryabova1971@postgrespro.ru", "phone": "+70097556406"}
0005434988977	9EE63F	0252 934159	TAMARA KOLESNIKOVA	{"email": "t-kolesnikova-091977@postgrespro.ru", "phone": "+70060560880"}
0005434988978	D3C972	9653 465871	NINA MOISEEVA	{"email": "moiseeva-n-1985@postgrespro.ru", "phone": "+70235617789"}
0005434988979	D3C972	8369 982725	MIKHAIL KOZLOV	{"phone": "+70955127562"}
0005434988980	CF9C5B	6034 972820	DARYA MARTYNOVA	{"email": "darya.martynova.01041963@postgrespro.ru", "phone": "+70795747628"}
0005434988981	CF9C5B	2143 103547	VIKTOR SEMENOV	{"email": "semenov_viktor_1965@postgrespro.ru", "phone": "+70322938345"}
0005434988982	B18708	3388 550593	SERGEY MIRONOV	{"phone": "+70504372754"}
0005434988983	8A6632	7355 064829	ANTONINA KISELEVA	{"email": "a-kiseleva-1979@postgrespro.ru", "phone": "+70243499144"}
0005434988984	8A6632	1877 041525	GALINA NOVIKOVA	{"email": "g.novikova051965@postgrespro.ru", "phone": "+70112750666"}
0005434988985	2738BF	0005 363547	OLGA SERGEEVA	{"email": "olga-sergeeva.031979@postgrespro.ru", "phone": "+70620687627"}
0005434988986	2738BF	5966 406328	GALINA SIDOROVA	{"email": "galina_sidorova_1969@postgrespro.ru", "phone": "+70298303796"}
0005434988988	B061AE	7538 626693	ELENA MATVEEVA	{"email": "e-matveeva071977@postgrespro.ru", "phone": "+70609590558"}
0005434988989	EA67A9	7835 606769	ALLA VLASOVA	{"phone": "+70038059331"}
0005434988990	9430D7	6791 635548	VALENTINA MOROZOVA	{"phone": "+70329617572"}
0005434988991	9430D7	6039 447331	OKSANA BORISOVA	{"email": "borisovao-081970@postgrespro.ru", "phone": "+70116719188"}
0005434988992	4C8E86	0244 646600	LYUDMILA FEDOROVA	{"email": "lyudmila_fedorova-16091975@postgrespro.ru", "phone": "+70610905042"}
0005434988993	4C8E86	9987 299196	ANDREY ILIN	{"email": "andreyilin_23081964@postgrespro.ru", "phone": "+70696777770"}
0005434988994	091F90	1020 272998	ALEKSANDR NAUMOV	{"email": "naumova_1983@postgrespro.ru", "phone": "+70246062734"}
0005434988995	091F90	3911 775377	MAKSIM POPOV	{"email": "popov-m17061958@postgrespro.ru", "phone": "+70824760427"}
0005434988996	5B1298	9698 849734	EVGENIY FEDOTOV	{"email": "e-fedotov02011969@postgrespro.ru", "phone": "+70807952699"}
0005434988997	DBF49D	8051 657907	ALEKSEY TIMOFEEV	{"email": "a_timofeev-081988@postgrespro.ru", "phone": "+70321204630"}
0005434988998	DBF49D	9495 900993	NADEZHDA ANISIMOVA	{"email": "nadezhda-anisimova-03021967@postgrespro.ru", "phone": "+70884165135"}
0005434988999	DBF49D	8855 476058	VYACHESLAV SEMENOV	{"email": "v_semenov-07081959@postgrespro.ru", "phone": "+70676332989"}
0005434989000	FCBCF0	2408 050257	ANNA EGOROVA	{"phone": "+70104080934"}
0005434989001	FC92BB	5874 138637	MARINA SIDOROVA	{"email": "sidorova-marina.28011967@postgrespro.ru", "phone": "+70497847654"}
0005434989002	FC92BB	0395 943852	ELENA STEPANOVA	{"email": "stepanovae.011988@postgrespro.ru", "phone": "+70943559757"}
0005434989003	FC92BB	4058 165511	VYACHESLAV SMIRNOV	{"email": "smirnov_vyacheslav_051959@postgrespro.ru", "phone": "+70921085232"}
0005434989004	4B9CFF	8667 538683	VIKTOR ROMANOV	{"phone": "+70435604414"}
0005434989005	4B9CFF	4089 653559	KLAVDIYA NIKOLAEVA	{"email": "nikolaeva_klavdiya.19121972@postgrespro.ru", "phone": "+70072903087"}
0005434989006	E81DE7	9464 715686	ALEKSEY GAVRILOV	{"phone": "+70142930333"}
0005434989007	F398A5	7031 115726	YULIYA ROMANOVA	{"phone": "+70028558905"}
0005434989008	EF410E	4289 563268	ELENA ZAKHAROVA	{"email": "e_zakharova-31031972@postgrespro.ru", "phone": "+70860215536"}
0005434989009	D84449	4022 193026	SERGEY NOVIKOV	{"email": "novikov-sergey-081975@postgrespro.ru", "phone": "+70488721471"}
0005434989010	96DD47	1192 649909	FARID ABRAMOV	{"email": "abramov.farid.051967@postgrespro.ru", "phone": "+70108149106"}
0005434989011	96DD47	7162 285227	GALINA NAZAROVA	{"email": "nazarova.g-081969@postgrespro.ru", "phone": "+70657270526"}
0005434989012	A101F6	3475 204695	IRINA BORISOVA	{"email": "borisovai05121980@postgrespro.ru", "phone": "+70897841275"}
0005434989013	A101F6	3054 023137	VALENTIN ROMANOV	{"phone": "+70307587607"}
0005434989014	A101F6	4381 300337	OLGA VOLKOVA	{"email": "volkova.o_1976@postgrespro.ru", "phone": "+70609110483"}
0005434989015	A101F6	7770 409952	DMITRIY SMIRNOV	{"email": "d-smirnov.31081983@postgrespro.ru", "phone": "+70834111095"}
0005434989016	4FDC9D	0711 087628	VALENTIN KOROLEV	{"email": "korolev_v.1963@postgrespro.ru", "phone": "+70647132572"}
0005434989017	7EAEBE	8378 379268	VALENTINA GORBUNOVA	{"phone": "+70665064439"}
0005434989018	7EAEBE	3327 116144	RAMIL AFANASEV	{"phone": "+70959253491"}
0005434989019	585034	9672 280124	SEMEN KARPOV	{"phone": "+70977210987"}
0005434989020	585034	8739 618638	OLGA MALYSHEVA	{"phone": "+70572921459"}
0005434989021	4A3143	5954 500113	OLGA SIDOROVA	{"email": "sidorova_olga-1968@postgrespro.ru", "phone": "+70313947213"}
0005434989022	90F88F	2868 447989	IRINA EGOROVA	{"phone": "+70957201586"}
0005434989023	90F88F	5327 352543	IVAN KULIKOV	{"email": "kulikov-i_1985@postgrespro.ru", "phone": "+70153189567"}
0005434989024	DE8882	5800 347594	VASILIY KUZNECOV	{"email": "kuznecov.v.14011965@postgrespro.ru", "phone": "+70513917353"}
0005434989025	DE8882	0204 095716	IVAN BORISOV	{"email": "borisov.i.25011970@postgrespro.ru", "phone": "+70959639849"}
0005434989026	CB7498	2498 350331	VLADIMIR MAKAROV	{"email": "makarov.vladimir-1983@postgrespro.ru", "phone": "+70772801313"}
0005434989027	8185FC	8981 447770	RUSLAN KUZNECOV	{"email": "kuznecov_ruslan_26031969@postgrespro.ru", "phone": "+70420704307"}
0005434989028	8185FC	9764 397345	NADEZHDA NOVIKOVA	{"email": "novikova.n.051962@postgrespro.ru", "phone": "+70766791673"}
0005434989029	456E12	5089 485403	YANA ARKHIPOVA	{"phone": "+70319973482"}
0005434989030	6874CE	1522 823490	DMITRIY MAKSIMOV	{"email": "dmaksimov_1975@postgrespro.ru", "phone": "+70331987172"}
0005434989031	DF308C	8899 034064	ARTEM KONOVALOV	{"phone": "+70784084345"}
0005434989032	7FCBC1	1195 056270	MIKHAIL VASILEV	{"email": "m.vasilev_09051982@postgrespro.ru", "phone": "+70441027319"}
0005434989033	C83B18	4828 447325	SERGEY RODIONOV	{"phone": "+70794455066"}
0005434989034	47C467	6199 109956	GALINA ZHUKOVA	{"email": "zhukova_g1968@postgrespro.ru", "phone": "+70605800801"}
0005434989035	058B0E	9088 023760	NATALYA MELNIKOVA	{"email": "natalya.melnikova_1978@postgrespro.ru", "phone": "+70213590875"}
0005434989036	EE0DD2	1699 480996	VLADIMIR SCHERBAKOV	{"email": "vladimir-scherbakov-081976@postgrespro.ru", "phone": "+70443875558"}
0005434989037	EE0DD2	5831 881635	TATYANA MELNIKOVA	{"email": "tmelnikova_071977@postgrespro.ru", "phone": "+70658899453"}
0005434989038	501AEC	3287 593058	EKATERINA KUZNECOVA	{"phone": "+70429259885"}
0005434989039	501AEC	0014 827368	MARIYA SERGEEVA	{"phone": "+70520182124"}
0005434989040	6B439C	2208 825900	NATALYA DENISOVA	{"phone": "+70911819847"}
0005434989041	7DFD76	2052 624750	MARINA ALEKSEEVA	{"email": "marina.alekseeva-011980@postgrespro.ru", "phone": "+70216645131"}
0005434989042	B37D23	8900 864250	NINA SMIRNOVA	{"email": "n_smirnova.1964@postgrespro.ru", "phone": "+70493458112"}
0005434989043	B366BB	0538 614327	IVAN TARASOV	{"phone": "+70406330799"}
0005434989044	25E7F3	5080 108531	OLEG ILIN	{"email": "ilin-oleg_021966@postgrespro.ru", "phone": "+70097896730"}
0005434989045	25E7F3	2951 656612	NAILYA SOLOVEVA	{"phone": "+70851675886"}
0005434989046	3BB479	8191 387349	VALENTINA NIKITINA	{"email": "nikitinavalentina.021971@postgrespro.ru", "phone": "+70476317182"}
0005434989047	3BB479	3631 872198	IRINA GAVRILOVA	{"phone": "+70639200540"}
0005434989048	FB880F	5901 182099	OLESYA PAVLOVA	{"phone": "+70503296663"}
0005434989049	FB880F	7934 268759	EVGENIYA LUKYANOVA	{"email": "e.lukyanova021974@postgrespro.ru", "phone": "+70679397950"}
0005434989050	3B87BC	4161 271826	ANTONINA RODIONOVA	{"email": "arodionova1976@postgrespro.ru", "phone": "+70837450384"}
0005434989051	4D16A8	2056 893959	ROMAN ABRAMOV	{"email": "abramov_r_071982@postgrespro.ru", "phone": "+70108582260"}
0005434989052	0FEDE1	8933 346509	ALEKSANDR FEDOROV	{"email": "fedorov_a_091979@postgrespro.ru", "phone": "+70483790474"}
0005434989053	FF523C	5749 694672	SERGEY SMIRNOV	{"phone": "+70560563908"}
0005434989054	44C217	8052 150541	VIKTOR MARTYNOV	{"email": "martynovviktor.051963@postgrespro.ru", "phone": "+70402180503"}
0005434989055	BDA7AE	1907 755960	ALEKSEY NIKITIN	{"phone": "+70042968801"}
0005434989056	A5633A	1170 326643	ANASTASIYA ALEKSEEVA	{"phone": "+70302851958"}
0005434989057	750376	8786 466696	VIKTOR NOVIKOV	{"email": "novikov.viktor-18011969@postgrespro.ru", "phone": "+70480761080"}
0005434989058	23B00E	9854 130860	MIKHAIL ALEKSEEV	{"phone": "+70116435966"}
0005434989059	51404F	8967 871202	SVETLANA ANDREEVA	{"email": "svetlanaandreeva101986@postgrespro.ru", "phone": "+70020508086"}
0005434989060	8C375E	3431 628010	ALEKSANDR SMIRNOV	{"email": "asmirnov-1973@postgrespro.ru", "phone": "+70832131484"}
0005434989061	8C375E	2325 971345	IRINA NESTEROVA	{"phone": "+70077081805"}
0005434989062	0D46C9	9605 558387	MIKHAIL SEMENOV	{"phone": "+70753685293"}
0005434989063	34475E	7660 451925	ALEKSANDR FEDOTOV	{"email": "afedotov.101980@postgrespro.ru", "phone": "+70158618522"}
0005434989064	34475E	4063 012451	KRISTINA EFREMOVA	{"phone": "+70507777467"}
0005434989065	34475E	4177 544067	ILYA FEDOROV	{"email": "fedorov_ilya24011973@postgrespro.ru", "phone": "+70348354133"}
0005434989066	705606	9969 010708	GENNADIY NOVIKOV	{"email": "novikov_gennadiy.1971@postgrespro.ru", "phone": "+70793976020"}
0005434989067	705606	8773 738484	ALEKSEY SOLOVEV	{"email": "aleksey_solovev.021978@postgrespro.ru", "phone": "+70320422550"}
0005434989068	705606	8762 108489	ALEKSANDR CHERNOV	{"phone": "+70117683007"}
0005434989069	0C1147	3704 532843	VALENTINA NAZAROVA	{"email": "nazarova_valentina.071971@postgrespro.ru", "phone": "+70838053411"}
0005434989070	7EE587	6753 508484	GALINA KAZAKOVA	{"email": "galina_kazakova.081974@postgrespro.ru", "phone": "+70946727774"}
0005434989071	7EE587	9818 739621	VIKTOR MATVEEV	{"phone": "+70363289050"}
0005434989072	15A7C3	3913 534004	SVYATOSLAV DENISOV	{"email": "denisovsvyatoslav.081975@postgrespro.ru", "phone": "+70301492320"}
0005434989073	7AE6AA	1101 177259	EVGENIY BORISOV	{"email": "borisov-evgeniy-071965@postgrespro.ru", "phone": "+70337231523"}
0005434989074	7AE6AA	9203 271083	KLAVDIYA VOLKOVA	{"phone": "+70874334743"}
0005434989075	482A70	7938 856195	IVAN ABRAMOV	{"email": "i-abramov.061956@postgrespro.ru", "phone": "+70190367220"}
0005434989076	F4D8CC	8225 041840	VALERIY KUZMIN	{"email": "kuzmin_valeriy.05071977@postgrespro.ru", "phone": "+70278190629"}
0005434989077	52F24F	1359 889754	DMITRIY RODIONOV	{"email": "dmitriy.rodionov051986@postgrespro.ru", "phone": "+70097942247"}
0005434989078	7695EC	3505 948793	YULIYA BELOVA	{"phone": "+70126619036"}
0005434989079	C87CB7	0968 160104	FARIT YAKOVLEV	{"phone": "+70330654056"}
0005434989080	19CBAA	5525 729667	MARINA NAUMOVA	{"email": "marinanaumova_1976@postgrespro.ru", "phone": "+70118391139"}
0005434989081	F1757F	4057 022027	ALEKSANDR GERASIMOV	{"email": "a.gerasimov081970@postgrespro.ru", "phone": "+70359765189"}
0005434989082	28D85B	0346 192803	ELENA GERASIMOVA	{"phone": "+70294688730"}
0005434989083	973639	7417 744011	GALINA NIKOLAEVA	{"phone": "+70542768372"}
0005434989084	973639	9148 523982	ALEKSEY IVANOV	{"phone": "+70007752388"}
0005434989085	363DF0	6797 036387	VIKTOR KISELEV	{"phone": "+70007990287"}
0005434989086	4F7DA6	4230 204618	NAILYA NIKITINA	{"email": "nnikitina1972@postgrespro.ru", "phone": "+70577861278"}
0005434989087	EAE71A	0144 898493	EKATERINA YAKOVLEVA	{"email": "e-yakovleva1968@postgrespro.ru", "phone": "+70681951804"}
0005434989088	EAE71A	8655 661220	ILYA ALEKSANDROV	{"phone": "+70237701445"}
0005434989089	997B8A	2623 096444	ANDREY EGOROV	{"email": "egorov_andrey-22091977@postgrespro.ru", "phone": "+70705820891"}
0005434989090	089222	8080 523449	SVETLANA ALEKSEEVA	{"phone": "+70442430990"}
0005434989091	089222	3473 167281	LYUDMILA ANDREEVA	{"phone": "+70373873587"}
0005434989092	C7384A	7582 599459	TATYANA VLASOVA	{"phone": "+70996537728"}
0005434989093	7FFB1E	9758 322916	EDUARD NAZAROV	{"phone": "+70848818552"}
0005434989094	7FFB1E	0091 491198	LILIYA ZAKHAROVA	{"email": "zakharova_l_021958@postgrespro.ru", "phone": "+70404712405"}
0005434989095	7FFB1E	2479 816571	NINA SOLOVEVA	{"email": "nina.soloveva-21021974@postgrespro.ru", "phone": "+70219188000"}
0005434989096	395BAC	2391 036999	VERA SMIRNOVA	{"email": "smirnova.v.021973@postgrespro.ru", "phone": "+70632976525"}
0005434989097	47539C	9053 510007	DENIS BARANOV	{"phone": "+70515085000"}
0005434989098	47539C	0665 091455	EVGENIY VOLKOV	{"email": "volkovevgeniy-111967@postgrespro.ru", "phone": "+70929912235"}
0005434989099	26AF9A	4093 955077	SVETLANA BELOVA	{"email": "belovasvetlana_091974@postgrespro.ru", "phone": "+70357156088"}
0005434989100	26AF9A	5028 152431	MARIYA TARASOVA	{"email": "tarasova.mariya.1974@postgrespro.ru", "phone": "+70085051536"}
0005434989101	7B2BA9	0839 939952	VYACHESLAV MIRONOV	{"phone": "+70536579846"}
0005434989102	7B2BA9	8083 435043	LYUDMILA ZAKHAROVA	{"email": "zakharova_l1978@postgrespro.ru", "phone": "+70062382386"}
0005434989103	04BA67	6388 652999	ARTEM IVANOV	{"phone": "+70663322209"}
0005434989104	338B27	6959 403032	ELENA TIMOFEEVA	{"email": "timofeeva.elena-111961@postgrespro.ru", "phone": "+70569903760"}
0005434989105	62AA99	9891 567422	ALEKSANDR ILIN	{"phone": "+70239248034"}
0005434989106	C34A05	3977 813388	SERGEY SOKOLOV	{"email": "sokolov-sergey.14051973@postgrespro.ru", "phone": "+70669493506"}
0005434989107	259B8F	6423 260169	IRINA KUZNECOVA	{"email": "irina_kuznecova-1971@postgrespro.ru", "phone": "+70260110072"}
0005434989108	134F7F	5055 887980	VALENTINA ROMANOVA	{"email": "romanovavalentina22121971@postgrespro.ru", "phone": "+70371546270"}
0005434989109	134F7F	1814 565729	SERGEY KUZNECOV	{"email": "skuznecov.071971@postgrespro.ru", "phone": "+70595262713"}
0005434989110	0C1092	9151 147964	YURIY SEMENOV	{"phone": "+70648631335"}
0005434989111	D1FDEE	2745 064553	MIKHAIL FEDOROV	{"email": "mikhail.fedorov-13081967@postgrespro.ru", "phone": "+70483765113"}
0005434989112	E84F78	7972 557033	VLADIMIR EGOROV	{"phone": "+70607984525"}
0005434989113	E84F78	5102 451881	NINA SAVELEVA	{"email": "savelevanina.02091969@postgrespro.ru", "phone": "+70899306475"}
0005434989114	FF1638	0331 568515	VLADIMIR IVANOV	{"phone": "+70880848959"}
0005434989115	7C8041	9317 055622	DMITRIY ANDREEV	{"email": "andreev-d101977@postgrespro.ru", "phone": "+70901816808"}
0005434989116	1305D4	9290 992030	SVETLANA AFANASEVA	{"email": "afanaseva-s-041972@postgrespro.ru", "phone": "+70337319319"}
0005434989117	287D1F	5736 281899	YAROSLAV DMITRIEV	{"email": "dmitrievyaroslav-011972@postgrespro.ru", "phone": "+70359744608"}
0005434989118	4B41FE	0569 758683	MARIYA ARKHIPOVA	{"phone": "+70225278041"}
0005434989119	4B41FE	8865 537117	YULIYA NIKOLAEVA	{"phone": "+70149912591"}
0005434989120	45B0FB	1521 534937	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr.14101970@postgrespro.ru", "phone": "+70188756405"}
0005434989121	45B0FB	7827 746214	RUSLAN OSIPOV	{"email": "ruslan-osipov061962@postgrespro.ru", "phone": "+70360486952"}
0005434989122	45B0FB	1172 030354	VALERIY VOROBEV	{"email": "valeriy-vorobev-28051966@postgrespro.ru", "phone": "+70875624538"}
0005434989123	45B0FB	6068 216366	OKSANA SIDOROVA	{"email": "oksana_sidorova041971@postgrespro.ru", "phone": "+70436114983"}
0005434989124	1897D7	0840 139072	EMMA FILATOVA	{"email": "filatova_emma1981@postgrespro.ru", "phone": "+70234015755"}
0005434989125	4663D5	9615 909082	YULIYA LUKYANOVA	{"email": "lukyanovay_1976@postgrespro.ru", "phone": "+70664155172"}
0005434989126	4663D5	2493 107749	VLADIMIR VASILEV	{"phone": "+70020032376"}
0005434989127	4663D5	4182 133054	TAMARA KALININA	{"phone": "+70995837745"}
0005434989128	4DCDA8	2939 542924	SVETLANA KOROLEVA	{"phone": "+70737467862"}
0005434989129	4DCDA8	5727 290840	TATYANA DMITRIEVA	{"email": "tatyana.dmitrieva_111968@postgrespro.ru", "phone": "+70142208111"}
0005434989130	4DCDA8	4282 143420	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov_1971@postgrespro.ru", "phone": "+70997870003"}
0005434989131	01B91F	4029 904889	VLADIMIR FOMIN	{"phone": "+70338964573"}
0005434989132	D32CB6	4604 978568	NATALIYA ALEKSANDROVA	{"email": "nataliya.aleksandrova081975@postgrespro.ru", "phone": "+70236925161"}
0005434989133	39D425	3127 288453	KIRILL RODIONOV	{"phone": "+70427395279"}
0005434989134	39D425	5754 640022	ELENA NAZAROVA	{"email": "elenanazarova.031975@postgrespro.ru", "phone": "+70575519923"}
0005434989135	EF023B	3275 927513	YURIY KULIKOV	{"phone": "+70933919755"}
0005434993846	17A736	8809 295018	MARINA BARANOVA	{"phone": "+70145924545"}
0005434993847	C7A711	3131 775503	DANILA CHERNOV	{"phone": "+70163339961"}
0005434993848	AD390C	6983 734650	RAIL ZHUKOV	{"phone": "+70276874631"}
0005434993849	AD390C	3343 096734	ANZHELIKA MOROZOVA	{"email": "morozova_anzhelika.071971@postgrespro.ru", "phone": "+70211935922"}
0005434993850	AD390C	8192 851035	NADEZHDA KISELEVA	{"email": "nadezhda_kiseleva-20081964@postgrespro.ru", "phone": "+70117894744"}
0005434993851	5AF1CB	3340 302499	TAKHIR VOROBEV	{"email": "vorobevtakhir_1974@postgrespro.ru", "phone": "+70813382158"}
0005434993852	5AF1CB	3494 918129	IGOR ANTONOV	{"email": "i.antonov_121971@postgrespro.ru", "phone": "+70791330533"}
0005434993853	7A9ECC	2912 591922	ELENA IVANOVA	{"phone": "+70382354455"}
0005434993854	7A9ECC	0533 746739	OLEG BELOV	{"phone": "+70808680915"}
0005434993855	4156C6	2357 597245	OLGA FILIPPOVA	{"phone": "+70957999351"}
0005434993856	C4B3E0	3981 809387	IGOR KOROLEV	{"phone": "+70517013346"}
0005434993857	C4B3E0	2630 030030	DMITRIY DMITRIEV	{"phone": "+70974132723"}
0005434993858	58A218	1189 393653	VLADIMIR KULIKOV	{"email": "kulikovvladimir_041958@postgrespro.ru", "phone": "+70157286672"}
0005434993859	139743	3885 503900	KONSTANTIN ILIN	{"phone": "+70987787788"}
0005434993860	139743	0104 660566	TIMOFEY SIDOROV	{"email": "sidorov.timofey-1963@postgrespro.ru", "phone": "+70964984520"}
0005434993861	C7A7E4	4458 559982	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr011976@postgrespro.ru", "phone": "+70876640282"}
0005434993862	61BC56	4932 048838	VLADIMIR IVANOV	{"phone": "+70037395238"}
0005434993863	2DA5A1	7488 311995	NATALYA EGOROVA	{"phone": "+70430937464"}
0005434993864	25352F	0606 332313	YURIY PETROV	{"phone": "+70280746898"}
0005434993865	F8380B	2628 325603	ANDREY SOKOLOV	{"phone": "+70949713012"}
0005434993866	7CF1AE	8031 694637	ALEKSANDR VLASOV	{"email": "aleksandr.vlasov_091976@postgrespro.ru", "phone": "+70571144593"}
0005434993867	86644E	5052 978700	ANTON MATVEEV	{"email": "a_matveev_101967@postgrespro.ru", "phone": "+70784238903"}
0005434993868	7DAC12	4192 644165	VIKTOR ZAKHAROV	{"email": "zakharov-v_031965@postgrespro.ru", "phone": "+70507983425"}
0005434993869	7DAC12	4063 432870	SERGEY YAKOVLEV	{"email": "yakovlev.s.04121970@postgrespro.ru", "phone": "+70973694114"}
0005434993870	3AF5E6	0385 447983	SHAMIL IVANOV	{"email": "ivanov_shamil.101976@postgrespro.ru", "phone": "+70321873851"}
0005434993871	3AF5E6	1312 845320	IRINA BORISOVA	{"email": "i.borisova_1962@postgrespro.ru", "phone": "+70810560712"}
0005434993872	5B7FED	2453 064287	IRINA SEMENOVA	{"email": "isemenova-041971@postgrespro.ru", "phone": "+70307075543"}
0005434993873	1A06E1	8423 637202	RINAT IVANOV	{"phone": "+70571887018"}
0005434993874	3047C0	4851 390352	NADEZHDA TITOVA	{"email": "titovan101977@postgrespro.ru", "phone": "+70271264134"}
0005434993875	3047C0	5823 793807	GALINA KULIKOVA	{"phone": "+70279786413"}
0005434993876	856B9D	2425 742592	ANASTASIYA EFREMOVA	{"phone": "+70556956063"}
0005434994114	2C6B72	1034 700658	BORIS MOISEEV	{"phone": "+70746691062"}
0005434993877	237C73	1010 546028	VALENTINA TIKHONOVA	{"email": "tikhonova-valentina.1972@postgrespro.ru", "phone": "+70040279119"}
0005434993878	237C73	9117 948818	ANATOLIY KISELEV	{"phone": "+70709390710"}
0005434993879	237C73	8696 538089	VALENTIN ILIN	{"email": "ilin-v1967@postgrespro.ru", "phone": "+70982095620"}
0005434993880	4BC39F	2088 625416	ILYA ZAKHAROV	{"email": "zakharov_i111973@postgrespro.ru", "phone": "+70408956625"}
0005434993881	C8C7A1	8475 044021	ALEKSEY FROLOV	{"phone": "+70176963874"}
0005434993882	4FB523	6440 016707	OKSANA IVANOVA	{"phone": "+70401101970"}
0005434993883	4FB523	5885 354637	IRINA RYABOVA	{"phone": "+70808249308"}
0005434993884	8F9501	5249 669614	NELYA EGOROVA	{"email": "negorova_20081966@postgrespro.ru", "phone": "+70821836262"}
0005434993885	8F9501	6056 447163	PAVEL MATVEEV	{"phone": "+70247588565"}
0005434993886	8F9501	7200 099318	OKSANA SOKOLOVA	{"email": "sokolova_oksana011957@postgrespro.ru", "phone": "+70914043052"}
0005434993887	A0BAD0	7570 943416	EKATERINA SOROKINA	{"phone": "+70001384877"}
0005434993888	10A056	8868 884704	LYUDMILA FEDOROVA	{"email": "fedorovalyudmila-11031952@postgrespro.ru", "phone": "+70621995232"}
0005434993889	CADF17	6677 587117	SERGEY ZAKHAROV	{"email": "zakharov-s-02101966@postgrespro.ru", "phone": "+70416852089"}
0005434993890	CADF17	2413 992363	ARTEM DENISOV	{"email": "a-denisov_28021965@postgrespro.ru", "phone": "+70147388578"}
0005434993891	CADF17	9709 949925	TAISIYA NIKIFOROVA	{"email": "tnikiforova.041963@postgrespro.ru", "phone": "+70458100380"}
0005434993892	EE25BB	3121 154079	DANIIL KAZAKOV	{"email": "dkazakov.111964@postgrespro.ru", "phone": "+70038188057"}
0005434993893	1F5623	0933 235815	LYUDMILA MEDVEDEVA	{"email": "lyudmilamedvedeva17021981@postgrespro.ru", "phone": "+70260063563"}
0005434993894	1F5623	3694 124519	VYACHESLAV KISELEV	{"email": "vyacheslavkiselev.04111963@postgrespro.ru", "phone": "+70756053978"}
0005434993895	3AA58E	9850 281667	ANASTASIYA SMIRNOVA	{"email": "anastasiya-smirnova-031977@postgrespro.ru", "phone": "+70325093951"}
0005434993896	A147AF	3215 041846	ANTONINA KUZMINA	{"phone": "+70679819560"}
0005434993897	A147AF	1084 895918	EVGENIY FEDOROV	{"email": "fedorov_evgeniy-101962@postgrespro.ru", "phone": "+70576807531"}
0005434993898	35843B	3372 210962	IRINA POTAPOVA	{"email": "irina.potapova.18081978@postgrespro.ru", "phone": "+70491253222"}
0005434993899	485210	7109 470288	SERGEY PAVLOV	{"phone": "+70379385300"}
0005434993900	485210	4920 397769	LARISA EGOROVA	{"email": "larisa.egorova_1980@postgrespro.ru", "phone": "+70283020044"}
0005434993901	921038	2905 532934	SVETLANA FILIPPOVA	{"phone": "+70713777434"}
0005434993902	0B5AAD	6112 752906	RUMIYA NESTEROVA	{"phone": "+70296643926"}
0005434993903	0B5AAD	1699 001124	ELENA KRASNOVA	{"email": "krasnova-e_1973@postgrespro.ru", "phone": "+70995442844"}
0005434993904	AA4C58	2195 374714	MAKSIM SAVELEV	{"email": "savelev.maksim03041981@postgrespro.ru", "phone": "+70195769234"}
0005434993905	AA4C58	0652 197821	TATYANA PAVLOVA	{"email": "pavlova_t_081977@postgrespro.ru", "phone": "+70495110663"}
0005434993906	CA4619	0024 133889	VASILIY BONDARENKO	{"email": "bondarenkov_051976@postgrespro.ru", "phone": "+70141488931"}
0005434993907	84F917	2053 711144	SERGEY KUZMIN	{"phone": "+70643051879"}
0005434993908	84F917	0545 470555	TAMARA TIMOFEEVA	{"email": "timofeevatamara.031968@postgrespro.ru", "phone": "+70699815093"}
0005434993909	03F716	4371 004083	GALINA KUZMINA	{"phone": "+70201643387"}
0005434993910	5FD901	5640 967606	NATALYA MEDVEDEVA	{"phone": "+70819065968"}
0005434993911	5FD901	3707 445386	NATALYA LAZAREVA	{"email": "natalyalazareva.1964@postgrespro.ru", "phone": "+70692053857"}
0005434993912	E90287	9449 977216	PETR NIKITIN	{"email": "pnikitin_1967@postgrespro.ru", "phone": "+70614301148"}
0005434993913	E90287	3405 344952	VLADIMIR VLASOV	{"email": "vlasov_v_20031973@postgrespro.ru", "phone": "+70974919173"}
0005434993914	92EA68	4892 741781	GALINA MASLOVA	{"email": "maslovag1965@postgrespro.ru", "phone": "+70792341987"}
0005434993915	B03B34	8391 564594	ANNA SAVELEVA	{"phone": "+70225105840"}
0005434993916	F4184C	9376 428021	YURIY FEDOTOV	{"phone": "+70231181272"}
0005434993917	8FEDC1	9397 561286	ELENA NESTEROVA	{"email": "nesterova_e_1981@postgrespro.ru", "phone": "+70016878036"}
0005434993918	3EC8D7	6093 108358	SERGEY MIRONOV	{"phone": "+70998848731"}
0005434993919	469208	1617 179193	VYACHESLAV GRIGOREV	{"phone": "+70994946579"}
0005434993920	5E10EF	5818 725046	GALINA SOROKINA	{"phone": "+70976272060"}
0005434993921	C50828	3476 757145	NATALYA SOLOVEVA	{"email": "natalyasoloveva23011970@postgrespro.ru", "phone": "+70934034332"}
0005434993922	7590E5	3021 953238	ALLA NESTEROVA	{"email": "nesterova_alla-1972@postgrespro.ru", "phone": "+70889431448"}
0005434993923	10272F	1008 491721	MIKHAIL MOROZOV	{"email": "mikhail_morozov_26071964@postgrespro.ru", "phone": "+70143736598"}
0005434993924	E3B518	2132 180320	ALEKSANDR ABRAMOV	{"phone": "+70878500681"}
0005434993925	C46F4A	4601 294536	ALEKSANDR NOVIKOV	{"email": "novikovaleksandr-1974@postgrespro.ru", "phone": "+70383687512"}
0005434993926	E7AFFA	2211 000401	EMIL MOISEEV	{"email": "e.moiseev.121989@postgrespro.ru", "phone": "+70306088351"}
0005434993927	26CBB5	8353 153383	TATYANA DMITRIEVA	{"phone": "+70693517595"}
0005434993928	D48630	3693 629512	OLGA CHERNOVA	{"email": "ochernova-10031964@postgrespro.ru", "phone": "+70011369356"}
0005434993929	D48630	3181 009278	VLADIMIR ZAKHAROV	{"email": "v-zakharov.12021979@postgrespro.ru", "phone": "+70879927390"}
0005434993930	9A2225	6824 381345	VALENTINA RYABOVA	{"phone": "+70221054360"}
0005434993931	7D1BE3	2514 112001	LYUDMILA DAVYDOVA	{"phone": "+70283664886"}
0005434994051	46C20B	3549 435424	ANDREY VLASOV	{"phone": "+70231733726"}
0005434993932	7D1BE3	8349 807037	RAISA LEBEDEVA	{"email": "raisa_lebedeva_021971@postgrespro.ru", "phone": "+70955054689"}
0005434993933	A58BCF	9388 489501	VITALIY EGOROV	{"email": "egorovv.17031959@postgrespro.ru", "phone": "+70338488180"}
0005434993934	E24C86	6256 362464	DARYA POLYAKOVA	{"email": "polyakova.d.081971@postgrespro.ru", "phone": "+70522068241"}
0005434993935	23B434	3375 610678	OLGA ZAKHAROVA	{"phone": "+70207884462"}
0005434993936	1A5E17	6415 932614	ALEKSANDR TARASOV	{"email": "tarasov_a_1973@postgrespro.ru", "phone": "+70813034258"}
0005434993937	8F16E5	0609 711616	VERA DENISOVA	{"phone": "+70353580615"}
0005434993938	8F16E5	9136 648929	ELENA ANISIMOVA	{"phone": "+70342959481"}
0005434993939	CF8EBC	2690 628038	NIKOLAY MOISEEV	{"email": "nikolay.moiseev.1968@postgrespro.ru", "phone": "+70324980302"}
0005434993940	EDA9C7	6944 501207	ALEKSANDRA KOZLOVA	{"email": "kozlova.a091962@postgrespro.ru", "phone": "+70396171136"}
0005434993941	D533E9	9338 900066	ALEKSANDR NIKITIN	{"email": "nikitin_a051968@postgrespro.ru", "phone": "+70700122494"}
0005434993942	BE1136	5730 297311	ANATOLIY CHERNOV	{"email": "anatoliy_chernov.1963@postgrespro.ru", "phone": "+70586670239"}
0005434993943	BE1136	7566 464657	GALINA PAVLOVA	{"email": "galina_pavlova-16111974@postgrespro.ru", "phone": "+70435627409"}
0005434993944	2D26A7	4003 587026	ARSENIY ANDREEV	{"email": "andreev-a-121973@postgrespro.ru", "phone": "+70016249827"}
0005434993945	2D26A7	1810 466531	EGOR YAKOVLEV	{"email": "egoryakovlev-071968@postgrespro.ru", "phone": "+70749649917"}
0005434993946	05D08D	9016 022206	VLADIMIR IVANOV	{"phone": "+70444954120"}
0005434993947	754D16	6085 510002	VALENTINA MIKHAYLOVA	{"phone": "+70511235281"}
0005434993948	754D16	4348 468503	VIKTOR SCHERBAKOV	{"email": "scherbakov-v1971@postgrespro.ru", "phone": "+70571370861"}
0005434993949	2165CE	7214 219707	NELLI KUZNECOVA	{"email": "nellikuznecova-1974@postgrespro.ru", "phone": "+70571096490"}
0005434993950	C870C3	9393 572305	OLESYA SEMENOVA	{"phone": "+70136867519"}
0005434993951	C870C3	9014 020239	SVETLANA LAZAREVA	{"email": "slazareva.071971@postgrespro.ru", "phone": "+70574568671"}
0005434993952	E4DBF1	8082 582125	MAKSIM SIDOROV	{"email": "sidorov-m_091978@postgrespro.ru", "phone": "+70507417521"}
0005434993953	E4DBF1	1450 788540	SERGEY KUZMIN	{"email": "sergey.kuzmin1964@postgrespro.ru", "phone": "+70884080204"}
0005434993954	E4DBF1	5441 982240	YURIY EGOROV	{"email": "egorov.y_1979@postgrespro.ru", "phone": "+70179779159"}
0005434993955	27F971	8794 964049	ALEKSANDRA OSIPOVA	{"email": "aleksandraosipova061974@postgrespro.ru", "phone": "+70811475700"}
0005434993956	27F971	6145 622718	NINA FEDOROVA	{"phone": "+70076513807"}
0005434993957	143B69	5921 499693	NINA KUZNECOVA	{"phone": "+70360258221"}
0005434993958	BF53B1	8793 955659	TATYANA MEDVEDEVA	{"email": "t-medvedeva-17021976@postgrespro.ru", "phone": "+70362507983"}
0005434993959	A830C6	7035 762285	ALEKSANDR KUZMIN	{"phone": "+70531675633"}
0005434993960	A830C6	9495 367682	DENIS FROLOV	{"email": "frolov_denis.091966@postgrespro.ru", "phone": "+70933177525"}
0005434993961	70D181	8596 620003	OLGA SEMENOVA	{"phone": "+70712115773"}
0005434993962	70D181	0494 641543	OKSANA POPOVA	{"email": "popovao_091965@postgrespro.ru", "phone": "+70999084087"}
0005434993963	EC139D	7912 840754	DENIS IVANOV	{"email": "ivanov.denis_091963@postgrespro.ru", "phone": "+70373439436"}
0005434993964	EC139D	1476 302005	TATYANA SOLOVEVA	{"email": "soloveva_t.1977@postgrespro.ru", "phone": "+70259592731"}
0005434993965	CA8497	1284 239297	NATALYA KOZLOVA	{"email": "n-kozlova-1979@postgrespro.ru", "phone": "+70441739863"}
0005434993966	4B20A5	6406 812694	ANNA FOMINA	{"email": "fomina.anna-19121973@postgrespro.ru", "phone": "+70216597736"}
0005434993967	4B20A5	3967 096959	FEDOR KOROLEV	{"email": "korolev-f-1972@postgrespro.ru", "phone": "+70082053169"}
0005434993968	645114	9511 487150	VLADIMIR GORBUNOV	{"phone": "+70849566162"}
0005434993969	5B713F	0545 774681	NIKOLAY TIKHONOV	{"email": "tikhonovn_27121975@postgrespro.ru", "phone": "+70869742209"}
0005434993970	5B713F	2089 412486	PELAGEYA DMITRIEVA	{"phone": "+70125536829"}
0005434993971	CC6A2F	9667 342602	ALEKSANDR GORBUNOV	{"phone": "+70996930895"}
0005434993972	B50C0D	2178 144978	TATYANA ALEKSEEVA	{"phone": "+70192484811"}
0005434993973	9B118E	8264 292165	VALERIY BORISOV	{"email": "valeriy_borisov081976@postgrespro.ru", "phone": "+70927686884"}
0005434993974	F64CA3	5392 725360	YULIYA SAVELEVA	{"email": "yuliya_saveleva_1964@postgrespro.ru", "phone": "+70470023493"}
0005434993975	25CF16	4052 668038	EVGENIYA FEDOROVA	{"phone": "+70841128451"}
0005434993976	5A7E39	8976 010721	ALEKSEY PETROV	{"email": "apetrov_08011969@postgrespro.ru", "phone": "+70527107708"}
0005434993977	5A7E39	5655 232391	OLGA ILINA	{"phone": "+70827051247"}
0005434993978	D5ADE1	7191 583848	ALEKSANDR NAUMOV	{"email": "a_naumov.29061971@postgrespro.ru", "phone": "+70684785823"}
0005434993979	D5ADE1	1243 197045	POLINA PAVLOVA	{"phone": "+70008266568"}
0005434993980	D5ADE1	5502 570957	KRISTINA SCHERBAKOVA	{"phone": "+70761132766"}
0005434993981	8A90EF	6706 010736	PAVEL VASILEV	{"phone": "+70031009102"}
0005434993982	8A90EF	5727 861302	KRISTINA KONOVALOVA	{"phone": "+70172667772"}
0005434993983	645C0C	5960 165806	SERGEY FEDOTOV	{"email": "sergey-fedotov06021977@postgrespro.ru", "phone": "+70094037856"}
0005434993984	645C0C	8002 395167	ALEKSANDR BORISOV	{"email": "borisov_a_1971@postgrespro.ru", "phone": "+70012999780"}
0005434993985	00054E	1631 784660	GALINA IVANOVA	{"phone": "+70822100939"}
0005434993986	D7C196	7919 628036	VALENTINA VOLKOVA	{"phone": "+70323952608"}
0005434993987	D7C196	0205 070872	ALENA KRASNOVA	{"phone": "+70177199641"}
0005434993988	F454CD	1048 770190	SERGEY GRIGOREV	{"phone": "+70749080132"}
0005434993989	7BB1E6	2688 352261	STANISLAV MAKAROV	{"email": "smakarov_061967@postgrespro.ru", "phone": "+70564231084"}
0005434993990	7BB1E6	9897 375510	ANNA EFIMOVA	{"phone": "+70272588039"}
0005434993991	03BF7D	6161 307560	NADEZHDA LAZAREVA	{"email": "n-lazareva_02121963@postgrespro.ru", "phone": "+70030034537"}
0005434993992	422E2D	2388 409296	RAILYA TROFIMOVA	{"email": "trofimova.railya-1968@postgrespro.ru", "phone": "+70365566421"}
0005434993993	98C6A6	4123 962699	ANNA TIKHONOVA	{"email": "a-tikhonova.011975@postgrespro.ru", "phone": "+70345617792"}
0005434993994	F4BFBD	8130 087782	EVGENIY KONOVALOV	{"phone": "+70849088456"}
0005434993995	F4BFBD	6846 207045	GENNADIY VOLKOV	{"email": "g-volkov.051976@postgrespro.ru", "phone": "+70055700032"}
0005434993996	F4BFBD	8441 445917	ANDREY KRASNOV	{"phone": "+70184409459"}
0005434993997	2AAAF5	3542 504959	ALBINA LUKYANOVA	{"phone": "+70780692723"}
0005434993998	FC9E66	1963 062678	ELENA STEPANOVA	{"email": "stepanova.e_1976@postgrespro.ru", "phone": "+70783997421"}
0005434993999	FC9E66	3354 036152	SERGEY ABRAMOV	{"phone": "+70892483361"}
0005434994000	BF8E2E	3319 012019	EVGENIY KULIKOV	{"phone": "+70728574649"}
0005434994001	A29017	2292 052240	ALEKSEY SERGEEV	{"email": "aleksey_sergeev_1967@postgrespro.ru", "phone": "+70868266275"}
0005434994002	D2E4EA	2726 322464	ANDREY NIKOLAEV	{"email": "a_nikolaev_25081972@postgrespro.ru", "phone": "+70001003150"}
0005434994003	D2E4EA	5250 650592	VIKTOR MOROZOV	{"phone": "+70423688774"}
0005434994004	2E5521	7363 306989	VIKTORIYA GUSEVA	{"phone": "+70687372924"}
0005434994005	2E5521	2917 069108	VALENTINA FEDOROVA	{"email": "fedorova.valentina_1976@postgrespro.ru", "phone": "+70228841241"}
0005434994006	A6187A	1335 668418	RAFIS KUZNECOV	{"phone": "+70271153580"}
0005434994007	A6187A	6401 063983	ELIZAVETA MAKAROVA	{"phone": "+70425676649"}
0005434994008	A6187A	1153 792868	PAVEL KRASNOV	{"phone": "+70570462936"}
0005434994009	43DDB6	5010 558241	VITALIY TARASOV	{"phone": "+70424996712"}
0005434994010	185753	1658 099127	IVAN MIKHAYLOV	{"email": "mikhaylov-i10091976@postgrespro.ru", "phone": "+70458447348"}
0005434994011	AE397C	2589 959178	NINA KALININA	{"phone": "+70579625423"}
0005434994012	167B34	1843 972767	ALEKSANDR SEMENOV	{"email": "a-semenov_121975@postgrespro.ru", "phone": "+70374995926"}
0005434994013	43CBE5	7490 055111	ALEKSANDR SOKOLOV	{"phone": "+70099563199"}
0005434994014	43CBE5	4660 636318	NADEZHDA MEDVEDEVA	{"email": "medvedevanadezhda_02051978@postgrespro.ru", "phone": "+70669340311"}
0005434994015	A7CA4B	8659 651204	GENNADIY OSIPOV	{"email": "osipovgennadiy.14061980@postgrespro.ru", "phone": "+70127484152"}
0005434994016	A9F0BF	9811 065384	MARINA YUDINA	{"email": "myudina-111973@postgrespro.ru", "phone": "+70599945924"}
0005434994017	A9F0BF	4191 901975	GRIGORIY SMIRNOV	{"phone": "+70032104659"}
0005434994018	A9F0BF	9754 728692	SERGEY MIRONOV	{"phone": "+70419018722"}
0005434994019	0F03BE	7013 947277	OLGA VASILEVA	{"email": "o_vasileva111972@postgrespro.ru", "phone": "+70952642867"}
0005434994020	F6096B	2676 134522	ALEKSEY OSIPOV	{"phone": "+70773078142"}
0005434994021	F6096B	1362 169025	ANASTASIYA KOVALEVA	{"phone": "+70776299810"}
0005434994022	F6096B	6459 924671	ALEKSEY KARPOV	{"email": "karpov-a-24071977@postgrespro.ru", "phone": "+70298717446"}
0005434994023	5D984F	7876 935263	DMITRIY SMIRNOV	{"phone": "+70487908566"}
0005434994024	04AF34	7851 073040	IGOR KARPOV	{"email": "igorkarpov.1963@postgrespro.ru", "phone": "+70000643956"}
0005434994025	04AF34	2767 968831	VIKTOR BORISOV	{"phone": "+70292787136"}
0005434994026	A166DB	3959 803396	IVAN BARANOV	{"email": "i.baranov.071959@postgrespro.ru", "phone": "+70732924339"}
0005434994027	EF29FC	6681 558862	MARAT KOROLEV	{"email": "marat_korolev091973@postgrespro.ru", "phone": "+70908120336"}
0005434994028	EF29FC	1046 630472	VALERIYA MIKHAYLOVA	{"email": "mikhaylova_valeriya1968@postgrespro.ru", "phone": "+70044152090"}
0005434994029	DA36A3	6786 750605	SERGEY KOZLOV	{"phone": "+70925232147"}
0005434994030	641819	8399 166759	ELENA MOROZOVA	{"phone": "+70533008567"}
0005434994031	6CF467	9012 636595	VLADIMIR SIDOROV	{"email": "v-sidorov.09071972@postgrespro.ru", "phone": "+70889986141"}
0005434994032	6CF467	2288 909498	ALINA KUDRYASHOVA	{"email": "alina_kudryashova_011971@postgrespro.ru", "phone": "+70418986693"}
0005434994033	5461F8	6511 235429	ELIZAVETA KOMAROVA	{"email": "komarova_e.1977@postgrespro.ru", "phone": "+70370767660"}
0005434994034	18065E	1604 475984	ALINA LAZAREVA	{"phone": "+70039177362"}
0005434994035	18065E	9628 520473	ALEKSANDR KULIKOV	{"email": "aleksandr-kulikov071957@postgrespro.ru", "phone": "+70289960885"}
0005434994036	18065E	6015 979356	ELENA MAKSIMOVA	{"phone": "+70508151571"}
0005434994037	AEA688	7310 599343	DANIIL PAVLOV	{"email": "d_pavlov.15071965@postgrespro.ru", "phone": "+70280136118"}
0005434994038	DACFFD	6119 135239	NATALYA KISELEVA	{"email": "n_kiseleva.1971@postgrespro.ru", "phone": "+70665398543"}
0005434994039	DACFFD	3368 228531	SEMEN ILIN	{"email": "ilin_semen.011975@postgrespro.ru", "phone": "+70493486786"}
0005434994040	B3AD28	0169 664777	YURIY CHERNOV	{"email": "chernov-y_14021960@postgrespro.ru", "phone": "+70051445524"}
0005434994041	326FAD	1868 253427	GENNADIY VASILEV	{"email": "vasilev.gennadiy-22021980@postgrespro.ru", "phone": "+70917197597"}
0005434994042	33B617	9930 621910	NADEZHDA BELOVA	{"email": "nadezhda_belova-1978@postgrespro.ru", "phone": "+70907247748"}
0005434994043	71AAD2	6366 646674	EGOR SOROKIN	{"phone": "+70750698325"}
0005434994044	048B1D	8450 095669	IRINA KULIKOVA	{"phone": "+70559000203"}
0005434994045	7F572A	2651 008121	VIKTORIYA KOZLOVA	{"email": "kozlova-viktoriya26101980@postgrespro.ru", "phone": "+70423925740"}
0005434994046	7F572A	0998 942105	ALEKSANDR KUDRYASHOV	{"phone": "+70904337615"}
0005434994047	2A93DE	6833 224601	OLEG MIKHAYLOV	{"email": "o_mikhaylov-081964@postgrespro.ru", "phone": "+70799148870"}
0005434994048	2A93DE	1172 352613	LARISA KULIKOVA	{"phone": "+70432164627"}
0005434994049	E20E2D	0624 295437	SVETLANA KUZMINA	{"email": "kuzmina-svetlana-07101971@postgrespro.ru", "phone": "+70706986960"}
0005434994050	E20E2D	1712 902770	MARYAM KUZNECOVA	{"phone": "+70501855413"}
0005434994052	48B31F	2172 860825	ARINA POTAPOVA	{"phone": "+70417954489"}
0005434994053	A4B01C	4548 989149	NATALYA SIDOROVA	{"email": "sidorova.n.18091957@postgrespro.ru", "phone": "+70369548152"}
0005434994054	AE5558	1744 199954	ALEKSANDR SOLOVEV	{"email": "a-solovev_111976@postgrespro.ru", "phone": "+70765334163"}
0005434994055	AE5558	0851 526086	VLADIMIR ZHURAVLEV	{"phone": "+70071149333"}
0005434994056	AE5558	5806 895875	MARINA ALEKSEEVA	{"email": "malekseeva_31101961@postgrespro.ru", "phone": "+70264135165"}
0005434994057	A49BE4	9318 464899	ELENA ZAYCEVA	{"phone": "+70944782273"}
0005434994058	F07AE7	9088 676532	NADEZHDA CHERNOVA	{"phone": "+70065114459"}
0005434994059	7C132C	6723 199420	ALEKSEY PETROV	{"email": "aleksey_petrov-1968@postgrespro.ru", "phone": "+70335971539"}
0005434994060	7C132C	4798 682917	VALENTINA ABRAMOVA	{"email": "v-abramova1971@postgrespro.ru", "phone": "+70620654504"}
0005434994061	C4C9B1	5762 229749	YURIY IVANOV	{"phone": "+70558028503"}
0005434994062	FA59AE	0009 996746	MARIYA KONOVALOVA	{"phone": "+70939249525"}
0005434994063	BEBD98	3241 709240	NADEZHDA NAZAROVA	{"email": "nazarova-n-1972@postgrespro.ru", "phone": "+70428526482"}
0005434994064	6AE769	5688 861268	VYACHESLAV GUSEV	{"email": "v_gusev-24021974@postgrespro.ru", "phone": "+70656249610"}
0005434994065	455B1C	1390 449190	OLGA KRASNOVA	{"phone": "+70911477091"}
0005434994066	61CBA3	6962 786756	VADIM SOLOVEV	{"phone": "+70164039057"}
0005434994067	7FD5C0	6934 506057	MAKSIM SHEVCHENKO	{"email": "maksim-shevchenko-1967@postgrespro.ru", "phone": "+70871393769"}
0005434994068	E1C308	1885 333875	OLEG ORLOV	{"email": "oleg-orlov-1970@postgrespro.ru", "phone": "+70478799028"}
0005434994069	1ADC5F	6874 407944	IVAN MATVEEV	{"email": "matveev.i.22081976@postgrespro.ru", "phone": "+70971264283"}
0005434994070	297371	4892 309689	LIDIYA TIMOFEEVA	{"phone": "+70295106856"}
0005434994071	C34CAF	9867 602444	ALENA SIDOROVA	{"email": "alenasidorova-071962@postgrespro.ru", "phone": "+70429827257"}
0005434994072	C34CAF	8211 954822	TATYANA NAZAROVA	{"email": "nazarova-t101973@postgrespro.ru", "phone": "+70441272036"}
0005434994073	8A4CB9	9905 448680	IVAN TARASOV	{"email": "itarasov-011973@postgrespro.ru", "phone": "+70494092378"}
0005434994074	758E2F	2184 288846	YURIY ORLOV	{"phone": "+70469246664"}
0005434994075	758E2F	7272 630041	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova_29011982@postgrespro.ru", "phone": "+70244461721"}
0005434994076	758E2F	4554 884868	OLGA IVANOVA	{"email": "olga-ivanova-09041967@postgrespro.ru", "phone": "+70969393050"}
0005434994077	44DC23	3109 660162	VALENTINA NIKITINA	{"phone": "+70724606684"}
0005434994078	0755DE	2907 856793	OLGA RODIONOVA	{"email": "o_rodionova_061967@postgrespro.ru", "phone": "+70375612285"}
0005434994079	543530	0812 079752	EKATERINA MIKHAYLOVA	{"email": "ekaterina-mikhaylova_1976@postgrespro.ru", "phone": "+70809276312"}
0005434994080	891E91	3982 048044	ALEKSANDR ZAKHAROV	{"phone": "+70753520002"}
0005434994081	891E91	1614 181192	NATALIYA MASLOVA	{"email": "nmaslova.1970@postgrespro.ru", "phone": "+70726625622"}
0005434994082	303FEC	6062 917722	DANIIL VASILEV	{"phone": "+70569392516"}
0005434994083	5F2612	8799 963912	TATYANA TIMOFEEVA	{"phone": "+70300414079"}
0005434994084	5F2612	9647 048515	EDUARD KISELEV	{"phone": "+70021516206"}
0005434994085	05BDC1	9109 525135	ANTONINA IVANOVA	{"email": "antoninaivanova_081971@postgrespro.ru", "phone": "+70188260713"}
0005434994086	C87D91	2164 275433	GRIGORIY SHEVCHENKO	{"phone": "+70068443433"}
0005434994087	91B15A	5043 311284	ANATOLIY ALEKSANDROV	{"email": "anatoliy.aleksandrov-12091973@postgrespro.ru", "phone": "+70067699117"}
0005434994088	91B15A	7056 601443	VLADIMIR FROLOV	{"email": "vladimirfrolov.1968@postgrespro.ru", "phone": "+70662599437"}
0005434994089	65F6A4	6026 759135	TATYANA EGOROVA	{"phone": "+70250351504"}
0005434994090	BD1C3E	1113 563623	ANATOLIY BORISOV	{"phone": "+70867043692"}
0005434994091	061079	4933 251638	MIKHAIL ZAKHAROV	{"phone": "+70063020644"}
0005434994092	061079	3144 236739	DMITRIY GUSEV	{"email": "d.gusev_24061979@postgrespro.ru", "phone": "+70638638841"}
0005434994093	C8B205	1686 125066	NIKOLAY KUZNECOV	{"email": "nkuznecov_031969@postgrespro.ru", "phone": "+70404037013"}
0005434994094	302C12	1986 020159	RENAT IVANOV	{"phone": "+70393419584"}
0005434994095	302C12	6101 505158	ELENA MOISEEVA	{"email": "elena-moiseeva.021977@postgrespro.ru", "phone": "+70108236567"}
0005434994096	29E870	5349 359685	KONSTANTIN FILIPPOV	{"phone": "+70334836643"}
0005434994097	0F6CDE	8060 703663	SERGEY MOROZOV	{"email": "s_morozov-101978@postgrespro.ru", "phone": "+70880344881"}
0005434994098	85789B	6143 524468	IRINA SOLOVEVA	{"email": "soloveva.i-1978@postgrespro.ru", "phone": "+70587846567"}
0005434994099	61A689	4756 555276	ROMAN SEMENOV	{"email": "r.semenov.01041968@postgrespro.ru", "phone": "+70919939480"}
0005434994100	288656	1391 621141	IVAN FEDOROV	{"phone": "+70690257366"}
0005434994101	B0DCA5	8979 591694	VIKTOR MOROZOV	{"phone": "+70813867565"}
0005434994102	0D576F	0986 027422	ILYA VOROBEV	{"email": "vorobev_i10051969@postgrespro.ru", "phone": "+70781752071"}
0005434994103	F6D330	1150 212315	VALENTINA MAKAROVA	{"phone": "+70282223073"}
0005434994104	F6D330	6910 269756	VALENTINA NOVIKOVA	{"phone": "+70416150673"}
0005434994105	E759C9	9082 635686	ELENA SERGEEVA	{"email": "elena_sergeeva_15091975@postgrespro.ru", "phone": "+70877910682"}
0005434994106	761BD7	7520 397357	OLEG SCHERBAKOV	{"email": "scherbakov_o.07011979@postgrespro.ru", "phone": "+70129576705"}
0005434994107	26DDC1	5679 125478	ROMAN KOZLOV	{"phone": "+70210586305"}
0005434994108	B1A49B	1608 853732	ARSENIY VOLKOV	{"email": "a-volkov-091973@postgrespro.ru", "phone": "+70146610574"}
0005434994109	24197B	1529 821287	ARTEM KUZNECOV	{"email": "a.kuznecov23101975@postgrespro.ru", "phone": "+70760146029"}
0005434994110	3B142E	7032 046177	ANNA DAVYDOVA	{"phone": "+70065361195"}
0005434994111	A521F8	6318 296596	MARINA ALEKSANDROVA	{"phone": "+70716997968"}
0005434994112	2D0FDD	3961 364490	ALEKSEY PETROV	{"phone": "+70539991424"}
0005434994113	C003EC	3044 101178	NIKOLAY SEMENOV	{"email": "semenov.nikolay-1975@postgrespro.ru", "phone": "+70397400164"}
0005434994115	BD11F2	8357 901469	YULIYA SOKOLOVA	{"phone": "+70988441603"}
0005434994116	2B8000	1788 256605	ELENA KULIKOVA	{"email": "kulikova_e071978@postgrespro.ru", "phone": "+70047104599"}
0005434994117	E0D3D0	8443 221199	VASILIY KUDRYASHOV	{"email": "kudryashov_v111964@postgrespro.ru", "phone": "+70382602931"}
0005434994118	4537A8	6513 673837	ELMIRA POPOVA	{"phone": "+70183306705"}
0005434994119	B65ED6	4627 617450	TATYANA ZAKHAROVA	{"phone": "+70838619083"}
0005434994120	B65ED6	0493 020488	LIDIYA KARPOVA	{"email": "lidiyakarpova08021967@postgrespro.ru", "phone": "+70556710224"}
0005434994121	6C49C8	2931 966760	ANNA FADEEVA	{"email": "a.fadeeva-021974@postgrespro.ru", "phone": "+70680179607"}
0005434994122	D9F90B	9699 334038	GALINA KUZNECOVA	{"phone": "+70036924688"}
0005434994123	D9F90B	7236 202456	VLADIMIR FOMIN	{"email": "fomin_v-17081977@postgrespro.ru", "phone": "+70110285645"}
0005434994124	947742	9731 660655	ELENA ZAYCEVA	{"email": "zayceva_elena-1980@postgrespro.ru", "phone": "+70293141124"}
0005434994125	961143	1468 262308	VIKTOR KUZNECOV	{"phone": "+70542394402"}
0005434994126	6809B6	7956 631397	LIDIYA ANTONOVA	{"email": "lidiya.antonova_14031979@postgrespro.ru", "phone": "+70318893529"}
0005434994127	4CE829	0387 136364	NADEZHDA NAZAROVA	{"phone": "+70199424301"}
0005434994128	4CE829	1994 118224	DENIS KUZNECOV	{"phone": "+70699752236"}
0005434994129	7F987A	6554 818574	EKATERINA MALYSHEVA	{"phone": "+70039551851"}
0005434994130	7F987A	5856 352157	SERGEY NAZAROV	{"email": "nazarovsergey23111965@postgrespro.ru", "phone": "+70868653455"}
0005434994131	7F987A	8639 151211	MAKSIM ZAKHAROV	{"phone": "+70194220990"}
0005434994132	2732AC	3935 677862	ROMAN SERGEEV	{"phone": "+70220977112"}
0005434994133	2732AC	1831 920513	ANASTASIYA SEMENOVA	{"email": "semenovaa041971@postgrespro.ru", "phone": "+70922179473"}
0005434994134	1531B7	3986 795113	ALEKSANDR AFANASEV	{"phone": "+70229638084"}
0005434994135	405CFE	8499 266099	MIKHAIL NAZAROV	{"phone": "+70137665208"}
0005434994136	A8B811	7309 031407	OLGA POTAPOVA	{"email": "potapovao.22111957@postgrespro.ru", "phone": "+70536810765"}
0005434994137	A8B811	7213 965266	VIKTOR ZAYCEV	{"phone": "+70090064400"}
0005434994138	A8B811	5579 812302	INGA KOROLEVA	{"phone": "+70416741099"}
0005434994139	180146	3286 439463	ANASTASIYA VOROBEVA	{"email": "anastasiya.vorobeva_1969@postgrespro.ru", "phone": "+70549468425"}
0005434994140	180146	3294 757506	NADEZHDA ZHURAVLEVA	{"phone": "+70526169404"}
0005434994141	7DE535	3320 015957	DARYA IVANOVA	{"email": "darya.ivanova_1965@postgrespro.ru", "phone": "+70829237755"}
0005434994142	DDEA53	7456 682444	ALEKSANDR CHERNOV	{"phone": "+70616496841"}
0005434994143	D0B815	2524 119128	MAKSIM IVANOV	{"phone": "+70136604788"}
0005434994144	D0B815	2084 065986	EKATERINA KOLESNIKOVA	{"email": "kolesnikova.e.011977@postgrespro.ru", "phone": "+70067750929"}
0005434994145	C2F8F1	0264 098410	VLADISLAV VOLKOV	{"phone": "+70128893131"}
0005434994146	C2F8F1	9572 972193	YULIYA FILIPPOVA	{"email": "yfilippova_121964@postgrespro.ru", "phone": "+70808820671"}
0005434994147	D02BFD	1914 011466	ALEKSANDR ISAEV	{"phone": "+70918049127"}
0005434994148	82B647	1550 641251	IVAN KISELEV	{"email": "kiselev_i1973@postgrespro.ru", "phone": "+70903822478"}
0005434994149	4D36F9	3596 003203	ANASTASIYA ILINA	{"phone": "+70195703328"}
0005434994150	4D36F9	3211 427763	DMITRIY IVANOV	{"email": "ivanovd_1986@postgrespro.ru", "phone": "+70472223079"}
0005434994151	7138EA	3117 680238	SERGEY STEPANOV	{"email": "sergeystepanov_26101966@postgrespro.ru", "phone": "+70398013833"}
0005434994152	374EF4	3302 243765	VIKTOR ZHUKOV	{"email": "zhukov-v_24031971@postgrespro.ru", "phone": "+70929944666"}
0005434994153	30FD02	1961 274693	MARIYA GUSEVA	{"phone": "+70969901208"}
0005434994154	40FC65	6399 360286	ROMAN MEDVEDEV	{"phone": "+70437187613"}
0005434994155	8682DF	3018 412686	VERONIKA NAZAROVA	{"phone": "+70650408609"}
0005434994156	8682DF	3151 402543	ALEKSANDR SOLOVEV	{"email": "aleksandr-solovev-29051977@postgrespro.ru", "phone": "+70731637565"}
0005434994157	CDC551	9652 551894	ALEKSEY PETROV	{"phone": "+70029340050"}
0005434994158	049C67	6242 728513	ALEKSEY PETROV	{"email": "alekseypetrov.1961@postgrespro.ru", "phone": "+70567353100"}
0005434994159	AD3FBC	7317 919656	NIKOLAY ANDREEV	{"email": "andreev-n1972@postgrespro.ru", "phone": "+70895334912"}
0005434994160	AD3FBC	9278 763266	MARGARITA KALININA	{"email": "kalininam.22051972@postgrespro.ru", "phone": "+70401469259"}
0005434994161	AD3FBC	5930 357738	VLADIMIR SMIRNOV	{"phone": "+70204701053"}
0005434994162	98CDE0	4157 948536	EVGENIYA KOZLOVA	{"phone": "+70520014009"}
0005434994163	716AD8	9806 771011	YULIYA POTAPOVA	{"email": "y-potapova.14051986@postgrespro.ru", "phone": "+70903384516"}
0005434994164	0E71A5	9877 574000	ANASTASIYA DMITRIEVA	{"email": "anastasiyadmitrieva-1972@postgrespro.ru", "phone": "+70572002376"}
0005434994165	8B6293	3576 390676	VLADIMIR TARASOV	{"email": "v.tarasov.05111975@postgrespro.ru", "phone": "+70610011818"}
0005434994166	8B6293	4840 304925	SVETLANA PETROVA	{"phone": "+70686834519"}
0005434994167	8B6293	5763 693443	BORIS EGOROV	{"phone": "+70319404549"}
0005434994168	046150	9169 744217	ANDREY SCHERBAKOV	{"email": "scherbakov.andrey-14061974@postgrespro.ru", "phone": "+70852686098"}
0005434994169	85F0EB	2198 641389	TATYANA POLYAKOVA	{"phone": "+70838823613"}
0005434994170	B78CA6	3792 993730	ALEKSEY EGOROV	{"email": "aegorov_071972@postgrespro.ru", "phone": "+70936572424"}
0005434994171	B78CA6	1121 204616	RODION GRIGOREV	{"phone": "+70988573066"}
0005434994172	B78CA6	7356 891080	ILYA ALEKSANDROV	{"email": "aleksandrov-ilya1968@postgrespro.ru", "phone": "+70511277210"}
0005434994173	E0068D	8789 617464	IGOR FEDOROV	{"phone": "+70758573222"}
0005434994174	4A498E	7163 250159	VITALIY ZAYCEV	{"email": "zaycev.v111970@postgrespro.ru", "phone": "+70179480947"}
0005434994175	FD6414	2413 073485	VYACHESLAV KUZNECOV	{"email": "kuznecov_vyacheslav-1975@postgrespro.ru", "phone": "+70441480380"}
0005434994176	FD6414	3502 346863	SERGEY RODIONOV	{"email": "s_rodionov-011964@postgrespro.ru", "phone": "+70885242709"}
0005434994177	FC567D	8138 939218	DENIS ANDREEV	{"email": "d_andreev-051975@postgrespro.ru", "phone": "+70035029017"}
0005434994178	30BB77	4420 958705	GENNADIY POPOV	{"phone": "+70601088449"}
0005434994179	30BB77	1511 630778	POLINA PAVLOVA	{"email": "pavlova-polina_1973@postgrespro.ru", "phone": "+70744756454"}
0005434994180	93E5BF	0314 769106	ALENA POPOVA	{"email": "a_popova1983@postgrespro.ru", "phone": "+70327626995"}
0005434994181	609998	6811 176630	SANIYA KOMAROVA	{"phone": "+70939191314"}
0005434994182	A33D52	1365 804887	LYUBOV KRASNOVA	{"email": "krasnova.lyubov_031984@postgrespro.ru", "phone": "+70390003016"}
0005434994183	866FF0	2945 516781	LYUDMILA ALEKSEEVA	{"email": "alekseeval_1965@postgrespro.ru", "phone": "+70344779715"}
0005434994184	866FF0	0095 257087	ANASTASIYA BELYAEVA	{"email": "belyaeva.anastasiya.03121965@postgrespro.ru", "phone": "+70165312958"}
0005434994185	D91BC6	8711 561696	VIKTOR DMITRIEV	{"phone": "+70268608440"}
0005434994186	B0BCEB	0199 991121	VLADISLAV ALEKSANDROV	{"phone": "+70887669524"}
0005434994187	016175	0730 302646	KLAVDIYA ANDREEVA	{"phone": "+70240427907"}
0005434994188	34BCE3	1452 929893	LYUDMILA BOGDANOVA	{"phone": "+70789190402"}
0005434994189	6C6989	1442 864213	DANILA TIMOFEEV	{"phone": "+70702509944"}
0005434994190	FCD1FF	0165 787460	EGOR ZHUKOV	{"phone": "+70832812379"}
0005434994191	26BE08	7259 254014	YURIY EGOROV	{"phone": "+70426339303"}
0005434994192	26BE08	3144 216537	EVGENIY VOROBEV	{"phone": "+70188191505"}
0005434994193	26BE08	6593 977166	SVETLANA FOMINA	{"email": "fomina-s091969@postgrespro.ru", "phone": "+70966788951"}
0005434994194	69FEBC	0571 921584	OLGA ANDREEVA	{"phone": "+70005037702"}
0005434994195	21875F	3558 439422	GALINA GUSEVA	{"email": "guseva.galina_08091979@postgrespro.ru", "phone": "+70769865409"}
0005434994196	89D343	8497 415907	LIDIYA ZAKHAROVA	{"phone": "+70910793132"}
0005434994197	77760C	5336 080633	ELENA AFANASEVA	{"phone": "+70031918963"}
0005434994198	E5A8DB	7181 128045	NINA ALEKSEEVA	{"phone": "+70902624736"}
0005434994199	E5A8DB	5404 363548	ZINAIDA FILATOVA	{"phone": "+70220157538"}
0005434994200	4000D5	7800 752137	SERGEY MAKAROV	{"phone": "+70916885033"}
0005434994201	4000D5	0628 080575	NIKOLAY KUZNECOV	{"phone": "+70243891885"}
0005434994202	DE4F75	8189 681519	ANATOLIY BELOV	{"phone": "+70899401617"}
0005434994203	EA35CA	8828 900495	NADEZHDA LAZAREVA	{"email": "lazareva_nadezhda.1965@postgrespro.ru", "phone": "+70123533819"}
0005434994204	EA35CA	9249 611126	ALINA ROMANOVA	{"email": "romanova.alina_15091979@postgrespro.ru", "phone": "+70734112237"}
0005434994205	1165C5	6070 606141	ALEKSANDR GAVRILOV	{"email": "gavrilov_a.30071978@postgrespro.ru", "phone": "+70720755866"}
0005434994206	FAD56F	9919 435146	NINA ALEKSEEVA	{"phone": "+70922820912"}
0005434994207	FAD56F	8632 480726	IRINA SCHERBAKOVA	{"email": "irinascherbakova.08071982@postgrespro.ru", "phone": "+70877555144"}
0005434994208	07BE0F	8815 143137	SERGEY OSIPOV	{"phone": "+70531379525"}
0005434994209	6E48EB	6016 584825	LILIYA POPOVA	{"phone": "+70322761601"}
0005434994210	6E48EB	4505 967190	LEONID FEDOTOV	{"phone": "+70117559628"}
0005434994211	872784	2568 621780	TATYANA AKIMOVA	{"email": "akimova-tatyana101978@postgrespro.ru", "phone": "+70480144163"}
0005434994212	51540E	4228 333438	ARTUR FILIPPOV	{"email": "filippov_artur_08111974@postgrespro.ru", "phone": "+70307003973"}
0005434994213	51540E	9384 146665	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov-10111967@postgrespro.ru", "phone": "+70884222785"}
0005434994214	5A6B6D	7851 709947	VADIM BARANOV	{"email": "baranov.vadim.011981@postgrespro.ru", "phone": "+70284398313"}
0005434994215	88EBE4	3276 896881	TATYANA PETROVA	{"phone": "+70958288181"}
0005434994216	2078F7	4659 504606	MAKSIM NAZAROV	{"email": "nazarov_maksim1982@postgrespro.ru", "phone": "+70556325373"}
0005434994217	671682	2812 481823	ANNA MATVEEVA	{"email": "matveeva-a-091974@postgrespro.ru", "phone": "+70446754719"}
0005434994218	6BA277	8823 605607	ALEKSANDR GAVRILOV	{"phone": "+70135463833"}
0005434994219	1A6153	4256 734666	SERGEY SOKOLOV	{"phone": "+70348237076"}
0005434994220	1A6153	1042 090067	ELLA STEPANOVA	{"email": "ella_stepanova031983@postgrespro.ru", "phone": "+70642051215"}
0005434994221	49BEE8	0324 943508	VALENTINA VASILEVA	{"phone": "+70103828397"}
0005434994222	C3D682	2046 443530	TATYANA KONDRATEVA	{"phone": "+70416873310"}
0005434994223	19AA23	6892 235840	ALEKSANDR MATVEEV	{"phone": "+70634141362"}
0005434994224	81F7C4	2116 724233	ARTEM ZAKHAROV	{"phone": "+70693434364"}
0005434994225	69AB0F	8862 801739	VIKTOR SAVELEV	{"email": "v_savelev_031960@postgrespro.ru", "phone": "+70599078608"}
0005434994226	69AB0F	4602 417943	LIDIYA KISELEVA	{"phone": "+70605040183"}
0005434994227	27BF77	0826 951681	EKATERINA EGOROVA	{"email": "egorova-ekaterina_081968@postgrespro.ru", "phone": "+70379430427"}
0005434994228	C065BB	3958 721398	KRISTINA ALEKSANDROVA	{"phone": "+70667627561"}
0005434994229	CD0981	0150 685384	IGOR SIDOROV	{"phone": "+70854147122"}
0005434994230	D6DD70	4442 977116	VERA MOROZOVA	{"phone": "+70216427361"}
0005434994231	DAB1B3	4006 372860	LYUBOV FEDOROVA	{"phone": "+70044217752"}
0005434994232	DAB1B3	1132 419403	VLADIMIR MEDVEDEV	{"phone": "+70655309442"}
0005434994233	249F68	6635 872872	DENIS KUZMIN	{"phone": "+70207006844"}
0005434994234	EE8F1F	6225 054978	EVGENIY GAVRILOV	{"phone": "+70059395632"}
0005434994235	EE8F1F	6497 974092	ALEKSEY BONDARENKO	{"email": "bondarenko_a-27021971@postgrespro.ru", "phone": "+70863544224"}
0005434994236	EE8F1F	0349 022952	ALEKSEY SOKOLOV	{"email": "a-sokolov051971@postgrespro.ru", "phone": "+70773612049"}
0005434994237	3E36DD	0804 213983	TATYANA ZOTOVA	{"email": "zotova-tatyana_1981@postgrespro.ru", "phone": "+70446193244"}
0005434994238	3E36DD	8384 509699	VYACHESLAV CHERNOV	{"phone": "+70470795246"}
0005434994239	0FB47E	2696 216401	ALEKSEY FEDOTOV	{"email": "alekseyfedotov_1977@postgrespro.ru", "phone": "+70135768609"}
0005434994240	C60495	0784 692211	VALENTINA ABRAMOVA	{"phone": "+70714766961"}
0005434994241	C60495	1608 713000	ANATOLIY SMIRNOV	{"email": "smirnov.anatoliy-18091968@postgrespro.ru", "phone": "+70966487965"}
0005434994242	58569A	3088 914541	NIKOLAY GORBUNOV	{"email": "n-gorbunov-021966@postgrespro.ru", "phone": "+70583730920"}
0005434994243	AE6127	3148 324740	OKSANA STEPANOVA	{"email": "ostepanova25051975@postgrespro.ru", "phone": "+70162033190"}
0005434994244	92A78F	1765 390581	EVGENIY EGOROV	{"email": "e-egorov.23091971@postgrespro.ru", "phone": "+70081238552"}
0005434994245	92A78F	9623 619294	SVETLANA FEDOROVA	{"email": "svetlana.fedorova-1984@postgrespro.ru", "phone": "+70709976439"}
0005434994246	4805D7	7034 898272	VASILIY KULIKOV	{"email": "vasiliy_kulikov111977@postgrespro.ru", "phone": "+70854481726"}
0005434994247	975924	1740 624790	YULIYA NESTEROVA	{"phone": "+70660903191"}
0005434994248	EEA446	7642 024250	EVGENIYA BELOVA	{"email": "belova_evgeniya-05091977@postgrespro.ru", "phone": "+70286581830"}
0005434994249	7AB4BC	0202 659409	ALEKSANDR FROLOV	{"email": "frolov.a_21021973@postgrespro.ru", "phone": "+70489231006"}
0005434994250	97B1CD	4624 888063	NINA NIKITINA	{"email": "nina-nikitina.1965@postgrespro.ru", "phone": "+70108508216"}
0005434994251	153463	2986 635139	GALINA DAVYDOVA	{"email": "davydova.galina_15061968@postgrespro.ru", "phone": "+70948523405"}
0005434994252	2518EA	6203 356347	PAVEL ANDREEV	{"phone": "+70387486910"}
0005434994253	861C18	7869 242407	ALEKSANDR ANTONOV	{"phone": "+70130451140"}
0005434994254	6B8AB7	3378 698801	ANDREY PAVLOV	{"phone": "+70697718624"}
0005434994255	6B8AB7	3382 156009	ALEKSANDR MIKHAYLOV	{"phone": "+70533234359"}
0005434994256	D0B171	0452 956830	VLADIMIR KUDRYASHOV	{"phone": "+70168856722"}
0005434994257	D0B171	5582 466483	ALEKSANDRA KOZLOVA	{"email": "akozlova_15071977@postgrespro.ru", "phone": "+70129707111"}
0005434994258	243D0A	2417 558300	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva_021977@postgrespro.ru", "phone": "+70809624561"}
0005434994259	B33984	2618 251935	NAIL GORBUNOV	{"email": "n_gorbunov-011973@postgrespro.ru", "phone": "+70691657349"}
0005434994260	057C6A	3294 072054	IVAN MIRONOV	{"email": "ivan-mironov_091958@postgrespro.ru", "phone": "+70832385250"}
0005434994261	D64203	0630 201560	ELENA NIKOLAEVA	{"phone": "+70561734080"}
0005434994262	D1E688	4713 213803	MURAT SMIRNOV	{"email": "m_smirnov.1967@postgrespro.ru", "phone": "+70170781680"}
0005434994263	371645	0961 812121	ILYA DMITRIEV	{"phone": "+70802482011"}
0005434994264	CD519A	4761 679310	VERA FADEEVA	{"email": "fadeeva.vera.111956@postgrespro.ru", "phone": "+70685155360"}
0005434994265	453695	1091 791080	ANASTASIYA GERASIMOVA	{"phone": "+70548027120"}
0005434994266	345E6D	4312 156007	GALINA SMIRNOVA	{"email": "g.smirnova-1974@postgrespro.ru", "phone": "+70647048523"}
0005434994267	345E6D	7556 884924	VLADIMIR STEPANOV	{"phone": "+70095402235"}
0005434994268	345E6D	7356 724189	ELENA POTAPOVA	{"phone": "+70972244789"}
0005434994269	345E6D	2624 662143	GALINA ZHUKOVA	{"email": "galina_zhukova081970@postgrespro.ru", "phone": "+70542717026"}
0005434994270	F214F9	4983 147778	VALENTINA IVANOVA	{"phone": "+70704239726"}
0005434994271	0F56A1	0032 420101	MAKSIM VASILEV	{"email": "m_vasilev_03101967@postgrespro.ru", "phone": "+70397894074"}
0005434994272	0F56A1	1334 619939	RADIK MARTYNOV	{"phone": "+70350235744"}
0005434994273	ACE7B0	6001 038508	GALINA OSIPOVA	{"email": "osipovagalina031986@postgrespro.ru", "phone": "+70502434278"}
0005434994274	C899DE	2526 073866	YURIY GAVRILOV	{"phone": "+70451624156"}
0005434994275	AB926D	3727 183364	ANASTASIYA LOGINOVA	{"email": "loginova_anastasiya.011970@postgrespro.ru", "phone": "+70985378489"}
0005434994276	AB926D	0689 845959	YULIYA SAVELEVA	{"phone": "+70021781716"}
0005434994277	0C45CC	7970 228534	ANDREY DAVYDOV	{"phone": "+70018463547"}
0005434994278	0C45CC	0883 369730	GENNADIY OSIPOV	{"phone": "+70950631976"}
0005434994279	A16C25	9372 827446	TATYANA ANDREEVA	{"phone": "+70759999591"}
0005434994280	A16C25	5687 315012	ANASTASIYA FROLOVA	{"phone": "+70514169023"}
0005434994281	7ABB69	4331 351731	DMITRIY MIRONOV	{"phone": "+70265696201"}
0005434994282	7ABB69	9417 990505	ARINA POTAPOVA	{"phone": "+70140091191"}
0005434994283	C28D67	9684 068601	NATALYA SERGEEVA	{"email": "sergeeva.natalya-25011970@postgrespro.ru", "phone": "+70423814184"}
0005434994284	C28D67	2293 857343	IGOR MAKAROV	{"phone": "+70716357061"}
0005434994285	813416	1279 322761	PAVEL IVANOV	{"email": "ivanovp081967@postgrespro.ru", "phone": "+70313757712"}
0005434994286	D1AAF5	2967 487043	ANDREY MIRONOV	{"phone": "+70949697771"}
0005434994287	D1AAF5	0590 352668	ANATOLIY SCHERBAKOV	{"phone": "+70637432708"}
0005434994288	565CC3	7107 552382	ANDREY IVANOV	{"phone": "+70731628380"}
0005434994289	79D04C	7258 783942	ALEKSANDR VOROBEV	{"email": "a-vorobev_11111970@postgrespro.ru", "phone": "+70492510465"}
0005434994290	79D04C	2726 361963	ANDREY ORLOV	{"phone": "+70379973558"}
0005434994291	64E503	9504 209940	ALEKSANDR STEPANOV	{"email": "stepanov-a.22041971@postgrespro.ru", "phone": "+70685294975"}
0005434994292	B98AFC	8652 246540	TATYANA EGOROVA	{"phone": "+70545413261"}
0005434994293	A3B59B	4089 730559	ALEKSEY MELNIKOV	{"email": "melnikov.aleksey25081981@postgrespro.ru", "phone": "+70074750071"}
0005434994294	A3B59B	3029 831660	GALINA SMIRNOVA	{"email": "galina.smirnova_1959@postgrespro.ru", "phone": "+70294497577"}
0005434994295	49FC4C	9535 457751	ALEKSANDR AFANASEV	{"email": "aafanasev31031962@postgrespro.ru", "phone": "+70293784281"}
0005434994296	69633F	3662 525750	VIKTORIYA POPOVA	{"phone": "+70224997201"}
0005434994297	68B9CB	3859 214084	TATYANA SOLOVEVA	{"phone": "+70394596959"}
0005434994298	68B9CB	7972 863575	ANDREY IVANOV	{"email": "andreyivanov19101978@postgrespro.ru", "phone": "+70121969798"}
0005434994299	4C19BC	9922 097491	TAMARA POPOVA	{"email": "t_popova051973@postgrespro.ru", "phone": "+70809561173"}
0005434994300	ECA2F6	9878 978219	MARIYA KOZLOVA	{"email": "kozlovam-041977@postgrespro.ru", "phone": "+70187319851"}
0005434994301	6A0FC7	8212 150246	NATALYA VASILEVA	{"phone": "+70155934873"}
0005434994302	6A0FC7	2318 104271	ZOYA TROFIMOVA	{"phone": "+70889028578"}
0005434994303	31F7EF	9446 193208	ILMIRA ALEKSANDROVA	{"email": "ilmira-aleksandrova08061968@postgrespro.ru", "phone": "+70837002399"}
0005434994304	6B6170	7273 778566	NIKOLAY TIKHONOV	{"email": "tikhonovn061971@postgrespro.ru", "phone": "+70593908365"}
0005434994305	A0B211	6960 265627	ALENA IVANOVA	{"phone": "+70329872806"}
0005434994306	57D9EE	5462 631851	MARIANNA MAKAROVA	{"phone": "+70289133938"}
0005434994307	FBCF83	0523 727767	NADEZHDA BELYAEVA	{"phone": "+70958275236"}
0005434994308	FBCF83	8073 431895	OLGA FROLOVA	{"email": "ofrolova_07081974@postgrespro.ru", "phone": "+70370516825"}
0005434994309	7D0D86	6594 896310	KSENIYA KARPOVA	{"email": "kseniyakarpova1953@postgrespro.ru", "phone": "+70804682819"}
0005434995373	693DB9	7353 124072	GENNADIY VOLKOV	{"phone": "+70258761827"}
0005434995275	F485BF	1869 307172	ALEKSEY MELNIKOV	{"email": "amelnikov.021986@postgrespro.ru", "phone": "+70610791391"}
0005434995276	1FE9E9	6115 243241	ALEKSANDR NOVIKOV	{"email": "novikov_a.031983@postgrespro.ru", "phone": "+70647246882"}
0005434995277	F3AEA0	4295 624874	EGOR TIKHONOV	{"email": "egor_tikhonov-1965@postgrespro.ru", "phone": "+70437402416"}
0005434995278	447B31	0279 021980	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr.05101984@postgrespro.ru", "phone": "+70295595015"}
0005434995279	AF66F5	9688 553010	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir.18091962@postgrespro.ru", "phone": "+70378073300"}
0005434995280	9D4846	0748 508431	SERGEY SCHERBAKOV	{"phone": "+70498794960"}
0005434995281	5450A4	7043 933584	NIKOLAY SAVELEV	{"phone": "+70186780915"}
0005434995282	5450A4	4562 643954	GALINA PAVLOVA	{"email": "pavlova_galina.1958@postgrespro.ru", "phone": "+70711629888"}
0005434995283	B95A04	4224 844530	OKSANA VOROBEVA	{"phone": "+70970014737"}
0005434995284	866FFF	2701 021328	LIDIYA KUZNECOVA	{"email": "l-kuznecova.31031973@postgrespro.ru", "phone": "+70779651641"}
0005434995285	866FFF	2941 099325	VIKTORIYA KAZAKOVA	{"phone": "+70653674167"}
0005434995286	7699EF	9448 605383	DANIIL POPOV	{"email": "popov-daniil1963@postgrespro.ru", "phone": "+70267207862"}
0005434995287	7699EF	2801 989724	ELENA NOVIKOVA	{"email": "elena.novikova-1981@postgrespro.ru", "phone": "+70623446965"}
0005434995288	A4E128	2196 457430	POLINA MATVEEVA	{"email": "matveeva.p.08061963@postgrespro.ru", "phone": "+70071868337"}
0005434995289	780496	8749 433429	EVGENIY ZAYCEV	{"email": "e-zaycev17041964@postgrespro.ru", "phone": "+70151460870"}
0005434995290	780496	5890 165269	ANATOLIY OSIPOV	{"email": "a_osipov1973@postgrespro.ru", "phone": "+70944815748"}
0005434995291	00F232	9198 473495	ANASTASIYA DAVYDOVA	{"phone": "+70332727028"}
0005434995292	0FBE90	5454 280195	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a-20031972@postgrespro.ru", "phone": "+70876296716"}
0005434995293	82A290	9006 074659	LYUDMILA MELNIKOVA	{"email": "lyudmilamelnikova1979@postgrespro.ru", "phone": "+70884363556"}
0005434995294	17761B	6663 776251	ANNA NIKIFOROVA	{"email": "anikiforova.111976@postgrespro.ru", "phone": "+70233915589"}
0005434995295	4B7824	2895 002549	IVAN VASILEV	{"phone": "+70102919018"}
0005434995296	4B7824	7359 755652	VITALIY KUZMIN	{"email": "kuzminvitaliy_1975@postgrespro.ru", "phone": "+70661238110"}
0005434995297	992604	9469 869669	ARTEM BORISOV	{"email": "artemborisov_1974@postgrespro.ru", "phone": "+70334353324"}
0005434995298	992604	5678 796051	TAMARA MAKSIMOVA	{"email": "maksimova.tamara-24021976@postgrespro.ru", "phone": "+70069462859"}
0005434995299	64C881	6119 297440	ELDAR MATVEEV	{"phone": "+70353523717"}
0005434995300	31D557	4009 531534	MARIYA MARTYNOVA	{"email": "martynova-mariya.1969@postgrespro.ru", "phone": "+70160948791"}
0005434995301	43D8F8	7871 651745	ALEKSEY VASILEV	{"email": "vasilev.a-1971@postgrespro.ru", "phone": "+70961641951"}
0005434995302	16FD73	6487 095508	ANDREY BONDARENKO	{"email": "bondarenko-a1976@postgrespro.ru", "phone": "+70719856197"}
0005434995303	CA470F	1999 501427	SVETLANA DENISOVA	{"phone": "+70325006270"}
0005434995304	79E15A	7402 696393	EKATERINA KOZLOVA	{"phone": "+70078991776"}
0005434995305	9D9DB6	9292 543357	EKATERINA TARASOVA	{"phone": "+70307465345"}
0005434995306	B3CA98	6187 707222	EVGENIY BONDARENKO	{"email": "evgeniy-bondarenko.031970@postgrespro.ru", "phone": "+70508480953"}
0005434995307	B3CA98	3074 263881	ELENA MAKAROVA	{"email": "e.makarova-1967@postgrespro.ru", "phone": "+70797731266"}
0005434995308	3B7AA8	4958 248879	MAKSIM STEPANOV	{"phone": "+70638667230"}
0005434995309	3B7AA8	6511 205144	LARISA FILIPPOVA	{"email": "filippova-l-1958@postgrespro.ru", "phone": "+70894054667"}
0005434995310	C0D2F7	5364 446581	ANATOLIY ANTONOV	{"phone": "+70937998245"}
0005434995311	C0D2F7	6576 083331	IRINA AFANASEVA	{"email": "i.afanaseva-1973@postgrespro.ru", "phone": "+70595253760"}
0005434995312	9C24E2	8269 273388	MARIYA GRISHINA	{"phone": "+70449498776"}
0005434995313	9C24E2	7312 334399	NATALYA SERGEEVA	{"email": "sergeeva_natalya.16111972@postgrespro.ru", "phone": "+70309643993"}
0005434995314	9C24E2	0941 884140	MAKSIM SHEVCHENKO	{"phone": "+70058075468"}
0005434995315	FFB5E2	8724 674841	MARIYA PETROVA	{"email": "petrova-m.1961@postgrespro.ru", "phone": "+70949009167"}
0005434995316	FFB5E2	2658 764921	KSENIYA BORISOVA	{"email": "borisova_k_051982@postgrespro.ru", "phone": "+70863618965"}
0005434995317	6B686E	4411 614576	ALEKSANDR ALEKSEEV	{"phone": "+70748443837"}
0005434995318	6B686E	4299 970909	OLGA NIKOLAEVA	{"email": "nikolaeva_olga-091969@postgrespro.ru", "phone": "+70690335586"}
0005434995319	A9FEC6	2558 963901	OLGA MATVEEVA	{"email": "matveeva-olga_1967@postgrespro.ru", "phone": "+70124447144"}
0005434995320	A9FEC6	7935 700185	TATYANA ANDREEVA	{"email": "tatyanaandreeva.1980@postgrespro.ru", "phone": "+70276571613"}
0005434995321	A9FEC6	5835 513724	OLEG FEDOROV	{"email": "o-fedorov_041966@postgrespro.ru", "phone": "+70165894391"}
0005434995322	35EFF6	0326 658098	VERA ABRAMOVA	{"phone": "+70030903390"}
0005434995323	35EFF6	4413 298400	MARIYA ZOTOVA	{"email": "mariya.zotova_01081971@postgrespro.ru", "phone": "+70673033574"}
0005434995324	1CA1A7	8727 176299	BORIS ROMANOV	{"phone": "+70844745824"}
0005434995325	1CA1A7	1518 474451	RIMMA MALYSHEVA	{"phone": "+70287529066"}
0005434995326	E57EEB	3335 092958	ALEKSEY NAZAROV	{"email": "alekseynazarov1963@postgrespro.ru", "phone": "+70107318144"}
0005434995327	C1C160	5157 025491	GALINA MATVEEVA	{"phone": "+70865993456"}
0005434995328	C1C160	9386 384844	VALENTINA KOZLOVA	{"email": "v_kozlova_021982@postgrespro.ru", "phone": "+70749967705"}
0005434995329	C1C160	6461 609133	VALENTINA YAKOVLEVA	{"email": "yakovleva.valentina081970@postgrespro.ru", "phone": "+70255287403"}
0005434995330	A484C3	9767 485784	ANDREY MIKHAYLOV	{"email": "andrey-mikhaylov031977@postgrespro.ru", "phone": "+70785324530"}
0005434995331	A484C3	2822 952134	YULIYA NIKITINA	{"phone": "+70780371305"}
0005434995332	4ABDC6	6537 578909	ANNA MASLOVA	{"phone": "+70983042666"}
0005434995333	8C7101	6309 501899	EKATERINA SMIRNOVA	{"email": "ekaterina_smirnova_1967@postgrespro.ru", "phone": "+70079865850"}
0005434995334	8C7101	1767 410443	AZAT ZAYCEV	{"email": "azatzaycev-15061964@postgrespro.ru", "phone": "+70833254027"}
0005434995335	347C91	8802 747717	NINA PAVLOVA	{"email": "nina-pavlova041966@postgrespro.ru", "phone": "+70577207604"}
0005434995336	B75CFA	5244 260807	ANATOLIY ZHUKOV	{"phone": "+70845791747"}
0005434995337	B75CFA	2215 499762	EKATERINA SMIRNOVA	{"email": "ekaterina-smirnova-1969@postgrespro.ru", "phone": "+70645524009"}
0005434995338	C7D887	7761 266740	VLADIMIR DAVYDOV	{"email": "davydov-vladimir_111964@postgrespro.ru", "phone": "+70153220693"}
0005434995339	16A070	8526 440824	IVAN KAZAKOV	{"phone": "+70316497923"}
0005434995340	16A070	8856 589857	LYUDMILA GUSEVA	{"email": "lyudmila.guseva.20041977@postgrespro.ru", "phone": "+70718597254"}
0005434995341	3F36D7	3997 845568	ANDREY KUZMIN	{"phone": "+70082598930"}
0005434995342	3F36D7	9157 217251	MARIYA SOKOLOVA	{"email": "mariya_sokolova1965@postgrespro.ru", "phone": "+70938379611"}
0005434995343	3F36D7	8785 079150	ELENA MIRONOVA	{"phone": "+70270512015"}
0005434995344	552AB6	1682 914593	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.a_22121966@postgrespro.ru", "phone": "+70577191463"}
0005434995345	552AB6	6667 004882	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-1966@postgrespro.ru", "phone": "+70120732983"}
0005434995346	552AB6	5195 744210	EKATERINA NIKITINA	{"phone": "+70582594404"}
0005434995347	5B391E	8141 763672	ANDREY RODIONOV	{"email": "andreyrodionov.05101977@postgrespro.ru", "phone": "+70121055235"}
0005434995348	5B391E	3358 262174	NADEZHDA CHERNOVA	{"email": "nadezhda.chernova121979@postgrespro.ru", "phone": "+70007605936"}
0005434995349	9531F0	2824 697675	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr1968@postgrespro.ru", "phone": "+70797974199"}
0005434995350	3292E1	1680 232959	ARTEM FROLOV	{"phone": "+70647562458"}
0005434995351	3292E1	8983 405681	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov1971@postgrespro.ru", "phone": "+70127693561"}
0005434995352	E12CA1	0825 518481	ELIZAVETA FILIPPOVA	{"phone": "+70711696882"}
0005434995353	908812	5138 988513	ELENA GUSEVA	{"phone": "+70381682897"}
0005434995354	ABD723	0955 514750	VIKTOR SIDOROV	{"phone": "+70376386534"}
0005434995355	6501A6	7919 790741	ELENA NOVIKOVA	{"email": "novikova-elena_1968@postgrespro.ru", "phone": "+70706376735"}
0005434995356	6501A6	8661 617371	VITALIY NIKOLAEV	{"email": "vitaliy_nikolaev.18061961@postgrespro.ru", "phone": "+70708442928"}
0005434995357	A9BDA6	7776 372938	OLEG SHEVCHENKO	{"phone": "+70580445980"}
0005434995358	090457	1982 483821	VLADIMIR IVANOV	{"phone": "+70723134528"}
0005434995359	090457	4799 432689	DMITRIY DMITRIEV	{"email": "dmitriev_dmitriy-081976@postgrespro.ru", "phone": "+70211412730"}
0005434995360	090457	3286 101940	ANNA SOKOLOVA	{"phone": "+70785059310"}
0005434995361	CC0287	3945 542755	ANTON SEMENOV	{"phone": "+70148960523"}
0005434995362	1DBB30	7001 464323	DMITRIY VASILEV	{"email": "dmitriy-vasilev_1960@postgrespro.ru", "phone": "+70113167953"}
0005434995363	3AB496	4529 242321	ALEKSANDR ILIN	{"phone": "+70497468014"}
0005434995364	3AB496	9545 455545	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy-1975@postgrespro.ru", "phone": "+70911451962"}
0005434995365	2926AD	5574 859224	YURIY ILIN	{"phone": "+70060805199"}
0005434995366	8470B7	1644 917927	NIKOLAY NOVIKOV	{"email": "nikolay_novikov-01101965@postgrespro.ru", "phone": "+70984762246"}
0005434995367	51E735	1318 380196	NINA SERGEEVA	{"email": "sergeevanina_1967@postgrespro.ru", "phone": "+70052317252"}
0005434995368	212EC9	1359 884534	OLESYA SERGEEVA	{"phone": "+70720968929"}
0005434995369	F5870A	4732 713426	VALERIY GORBUNOV	{"email": "valeriy.gorbunov051969@postgrespro.ru", "phone": "+70557875965"}
0005434995370	001EA0	6903 071740	ELENA BORISOVA	{"email": "elena_borisova_051976@postgrespro.ru", "phone": "+70904405877"}
0005434995371	79104C	1719 628568	EVGENIY TARASOV	{"email": "tarasov.e_011980@postgrespro.ru", "phone": "+70151036972"}
0005434995372	2F7A0B	0136 887072	NATALYA CHERNOVA	{"phone": "+70197135838"}
0005434995374	83AF89	6667 928320	PAVEL POPOV	{"email": "pavel-popov1976@postgrespro.ru", "phone": "+70347006651"}
0005434995375	83AF89	5035 536404	NATALYA ZHUKOVA	{"email": "nzhukova111974@postgrespro.ru", "phone": "+70953760451"}
0005434995376	EBB6DA	0741 768127	NADEZHDA KONOVALOVA	{"email": "konovalova_n071980@postgrespro.ru", "phone": "+70107693336"}
0005434995377	EBB6DA	8616 787431	TATYANA DAVYDOVA	{"phone": "+70289445902"}
0005434995378	D4B4F1	0579 378361	ELENA IVANOVA	{"phone": "+70188080538"}
0005434995379	E3DB16	7034 048165	VIKTOR GAVRILOV	{"email": "gavrilovviktor.02021970@postgrespro.ru", "phone": "+70691581551"}
0005434995380	E3DB16	4446 541453	STEPAN YAKOVLEV	{"email": "yakovlev.stepan-1960@postgrespro.ru", "phone": "+70275076224"}
0005434995381	7F591E	5740 535914	MIKHAIL ANTONOV	{"email": "antonov_m-28031963@postgrespro.ru", "phone": "+70831584569"}
0005434995382	8C4B43	2390 734082	VALENTINA TARASOVA	{"phone": "+70501760311"}
0005435006618	3DB713	5760 917897	MARINA NIKIFOROVA	{"phone": "+70625274204"}
0005435006601	88CAE5	0176 912231	ANATOLIY ANDREEV	{"phone": "+70066664484"}
0005435006602	88CAE5	6391 005192	LYUBOV SIDOROVA	{"phone": "+70977836856"}
0005435006603	88CAE5	4707 727583	VIKTORIYA SCHERBAKOVA	{"email": "v_scherbakova_01101970@postgrespro.ru", "phone": "+70276443605"}
0005435006604	F389F6	9830 498073	VITALIY FROLOV	{"phone": "+70943262233"}
0005435006605	F389F6	3857 185802	MARIYA RODIONOVA	{"phone": "+70881983395"}
0005435006606	908442	8113 406588	OLESYA MARTYNOVA	{"email": "olesya.martynova111956@postgrespro.ru", "phone": "+70533702563"}
0005435006607	F34DB6	6822 107551	TATYANA DENISOVA	{"email": "denisova.tatyana051970@postgrespro.ru", "phone": "+70807447944"}
0005435006608	DE9658	4388 637639	ALEKSANDR KARPOV	{"phone": "+70825260035"}
0005435006609	02292D	3506 876141	VERA SIDOROVA	{"phone": "+70138355411"}
0005435006610	02292D	6692 715701	NADEZHDA FROLOVA	{"email": "nadezhda.frolova_1963@postgrespro.ru", "phone": "+70756217174"}
0005435006611	C3791D	0516 331073	OLGA TROFIMOVA	{"phone": "+70171051861"}
0005435006612	C3791D	5432 195002	TATYANA FOMINA	{"email": "fomina_t_051976@postgrespro.ru", "phone": "+70744105833"}
0005435006613	256E84	9153 697470	OLGA KOZLOVA	{"email": "kozlova.o081970@postgrespro.ru", "phone": "+70675448153"}
0005435006614	B8B21D	9316 550511	KIRILL SIDOROV	{"email": "kirill.sidorov1966@postgrespro.ru", "phone": "+70008876203"}
0005435006615	B8B21D	0006 413626	VALERIY BARANOV	{"email": "valeriy.baranov-1975@postgrespro.ru", "phone": "+70537801950"}
0005435006616	F595C2	3454 047104	SERGEY KRASNOV	{"phone": "+70776717139"}
0005435006617	F595C2	2561 071633	GENNADIY PETROV	{"phone": "+70980572798"}
0005435006619	23725C	7320 744032	GALINA MASLOVA	{"email": "maslova.g-061970@postgrespro.ru", "phone": "+70394009858"}
0005435006620	23725C	1196 676124	GALINA YUDINA	{"email": "galina-yudina-1959@postgrespro.ru", "phone": "+70666766578"}
0005435006621	255751	6306 840655	VIKTOR PETROV	{"phone": "+70392294543"}
0005435006622	0AF9CC	3666 415048	NADEZHDA FROLOVA	{"phone": "+70365131851"}
0005435006623	EC2BF8	9780 798724	ANTON ROMANOV	{"email": "romanov.anton_1980@postgrespro.ru", "phone": "+70423847493"}
0005435006624	EC2BF8	8534 092206	TATYANA TIKHONOVA	{"email": "t_tikhonova_1981@postgrespro.ru", "phone": "+70363430214"}
0005435006625	497545	9490 108936	MAKSIM SERGEEV	{"email": "sergeevmaksim_091974@postgrespro.ru", "phone": "+70137842824"}
0005435006626	9CCCAB	9331 175929	ANDREY MIKHAYLOV	{"email": "a.mikhaylov061969@postgrespro.ru", "phone": "+70329455247"}
0005435006627	760D4F	5687 005532	LYUDMILA KOZLOVA	{"email": "lkozlova-061974@postgrespro.ru", "phone": "+70056801441"}
0005435006628	5E2C81	6064 028861	NIKITA BORISOV	{"email": "nikita-borisov-1980@postgrespro.ru", "phone": "+70095251247"}
0005435006629	FBC8F6	3689 225265	SERGEY KUZMIN	{"phone": "+70658815700"}
0005435006630	4FEB10	0165 644308	EVGENIY PAVLOV	{"phone": "+70980358441"}
0005435006631	4FEB10	0358 275222	OKSANA MAKAROVA	{"phone": "+70834864042"}
0005435006632	E48ECD	0290 413160	SERGEY EGOROV	{"phone": "+70522332694"}
0005435006633	E48ECD	6428 743892	VYACHESLAV NIKITIN	{"email": "vyacheslavnikitin.111967@postgrespro.ru", "phone": "+70722915132"}
0005435006634	78066B	1571 994139	OLGA ORLOVA	{"email": "olga_orlova_051969@postgrespro.ru", "phone": "+70194785836"}
0005435006635	6CA289	5186 452053	KIRA MOROZOVA	{"email": "kiramorozova-1963@postgrespro.ru", "phone": "+70169647406"}
0005435006636	96AE51	4489 312405	NIKOLAY BELOV	{"email": "belov.n_13081962@postgrespro.ru", "phone": "+70308004924"}
0005435006637	4C0E9F	6324 589164	SOFYA STEPANOVA	{"phone": "+70072570408"}
0005435006638	1EDB10	5284 513725	RAFAIL ABRAMOV	{"email": "abramovrafail1974@postgrespro.ru", "phone": "+70683671851"}
0005435006639	0D164F	7332 112181	LEONID STEPANOV	{"email": "l_stepanov.1971@postgrespro.ru", "phone": "+70444150575"}
0005435006640	0D164F	5870 922867	VALERIY KARPOV	{"email": "valeriy-karpov-17101977@postgrespro.ru", "phone": "+70919097400"}
0005435006641	0D164F	3364 470742	DANILA MIKHAYLOV	{"email": "danilamikhaylov.1974@postgrespro.ru", "phone": "+70390765240"}
0005435006642	211C27	9791 097294	SERGEY GAVRILOV	{"phone": "+70772336198"}
0005435006643	211C27	8416 588463	NADEZHDA KOROLEVA	{"email": "koroleva-n_13121978@postgrespro.ru", "phone": "+70677784837"}
0005435006644	E20001	3673 891893	ELENA LOGINOVA	{"email": "eloginova1975@postgrespro.ru", "phone": "+70011198021"}
0005435006645	3FB13A	5106 291681	KRISTINA FROLOVA	{"email": "kristina-frolova011963@postgrespro.ru", "phone": "+70458151956"}
0005435006646	3FB13A	0354 542134	ELENA POPOVA	{"phone": "+70178994048"}
0005435006647	7D0E5C	2505 785523	GENNADIY ZHUKOV	{"email": "gzhukov17051971@postgrespro.ru", "phone": "+70053047404"}
0005435006648	2E0B22	5714 486976	SVYATOSLAV DMITRIEV	{"phone": "+70589378195"}
0005435006649	887CF7	4763 853808	TATYANA KARPOVA	{"phone": "+70062549811"}
0005435006650	887CF7	8098 094607	ADELINA NIKOLAEVA	{"email": "nikolaeva_a-1973@postgrespro.ru", "phone": "+70828690632"}
0005435006651	742823	8616 511347	MIKHAIL NIKITIN	{"phone": "+70035277624"}
0005435006652	F0751A	9340 162996	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov-091979@postgrespro.ru", "phone": "+70357555372"}
0005435006653	EA54AC	8852 013929	ANDREY GRIGOREV	{"phone": "+70200247893"}
0005435006654	EA54AC	6137 925153	LYUBOV MELNIKOVA	{"phone": "+70392248337"}
0005435006655	FEE640	4363 099537	DMITRIY DENISOV	{"email": "denisov.d-1975@postgrespro.ru", "phone": "+70751167331"}
0005435006656	FEE640	9767 604893	RAISA POPOVA	{"email": "popovaraisa-1967@postgrespro.ru", "phone": "+70596902133"}
0005435006657	723E6F	5589 079503	MARINA MAKSIMOVA	{"phone": "+70640871538"}
0005435006658	8CB8D5	9037 882666	IVAN IVANOV	{"email": "ivanov-i.1968@postgrespro.ru", "phone": "+70777346514"}
0005435006659	C9FBDD	6853 767788	GULSHAT KOROLEVA	{"phone": "+70322044909"}
0005435006660	C9FBDD	0853 197714	ALEKSANDR BORISOV	{"phone": "+70206494646"}
0005435006661	80369F	7414 862156	VALENTINA POPOVA	{"phone": "+70783762877"}
0005435006662	80369F	7928 003151	KONSTANTIN MARTYNOV	{"email": "martynovkonstantin-1973@postgrespro.ru", "phone": "+70679958233"}
0005435006663	02C2BF	9129 701779	IVAN VLASOV	{"email": "vlasov_i1969@postgrespro.ru", "phone": "+70323631791"}
0005435006664	E8ED94	8037 871606	SVETLANA SEMENOVA	{"email": "s.semenova1966@postgrespro.ru", "phone": "+70073597136"}
0005435006665	588C54	9795 894307	MAKSIM FEDOROV	{"email": "maksim-fedorov1970@postgrespro.ru", "phone": "+70986802352"}
0005435006666	AE7F20	0933 657143	ELENA MOROZOVA	{"email": "elena.morozova_041979@postgrespro.ru", "phone": "+70859877946"}
0005435006667	75F4A5	3033 023842	LYUBOV NOVIKOVA	{"phone": "+70043396361"}
0005435006668	C0058B	4341 334377	SERGEY TARASOV	{"phone": "+70286628825"}
0005435006669	C0058B	2288 902113	DENIS VASILEV	{"phone": "+70417172871"}
0005435006670	1A9979	1081 398269	ELENA ANDREEVA	{"phone": "+70099426537"}
0005435006671	1A9979	5589 892509	OKSANA PETROVA	{"email": "oksana.petrova.1979@postgrespro.ru", "phone": "+70455344368"}
0005435006672	D16E3C	8087 441753	IVAN VOLKOV	{"phone": "+70491904656"}
0005435006673	49DF9F	9411 420675	PAVEL CHERNOV	{"phone": "+70881866431"}
0005435006674	F7B4F1	2475 676355	ALEKSANDR TIKHONOV	{"email": "a.tikhonov.071962@postgrespro.ru", "phone": "+70562153160"}
0005435006675	41F5F5	3276 239816	SABINA POPOVA	{"phone": "+70592254876"}
0005435006676	C14FA0	8362 324631	VLADIMIR NOVIKOV	{"email": "novikov_vladimir13031971@postgrespro.ru", "phone": "+70445852351"}
0005435006677	C14FA0	2637 666178	NADEZHDA KOZLOVA	{"phone": "+70366543015"}
0005435006678	FF8476	6311 117175	VIKTOR SOROKIN	{"phone": "+70413211289"}
0005435006679	CBB794	6261 349328	KIRILL SAVELEV	{"email": "kirillsavelev1981@postgrespro.ru", "phone": "+70788316059"}
0005435006680	CBB794	1772 407367	EVGENIY BORISOV	{"phone": "+70904499880"}
0005435006681	CBB794	2303 437163	ANDREY KISELEV	{"phone": "+70542290239"}
0005435006682	D841DB	1731 202382	ULYANA CHERNOVA	{"phone": "+70974864875"}
0005435006683	E8DD52	0829 033514	NATALYA FEDOROVA	{"email": "fedorova-natalya-1972@postgrespro.ru", "phone": "+70856834730"}
0005435006684	D8C617	0555 699861	ALEKSEY KUDRYASHOV	{"email": "aleksey.kudryashov.1978@postgrespro.ru", "phone": "+70138958890"}
0005435006685	0F6149	3277 572579	VLADIMIR MAKSIMOV	{"email": "v.maksimov.29061973@postgrespro.ru", "phone": "+70488731833"}
0005435006686	B4F535	8886 681746	KIRILL IVANOV	{"email": "ivanovk101968@postgrespro.ru", "phone": "+70622703339"}
0005435006687	F4ABC3	7129 479760	NIKITA SHEVCHENKO	{"phone": "+70655319378"}
0005435006688	36AEFC	5930 641601	NINA FILIPPOVA	{"email": "filippova-n_071974@postgrespro.ru", "phone": "+70640858622"}
0005435006689	03CEF4	1957 912975	SOFYA BELOVA	{"email": "sofya.belova.02071964@postgrespro.ru", "phone": "+70129995640"}
0005435006690	03CEF4	0120 328768	EKATERINA POPOVA	{"phone": "+70731302998"}
0005435006691	A299B7	7025 725904	VALERIYA ERMAKOVA	{"email": "ermakovavaleriya.24031976@postgrespro.ru", "phone": "+70597355470"}
0005435006692	7B6877	2843 671169	VALENTINA NIKOLAEVA	{"phone": "+70398914395"}
0005435006693	4BBE0B	9278 577278	GENNADIY ANDREEV	{"email": "gandreev31051968@postgrespro.ru", "phone": "+70279467184"}
0005435006694	E525FC	2426 923365	ANNA DAVYDOVA	{"phone": "+70108545949"}
0005435006695	E27FAE	6409 058305	VIKTOR ANTONOV	{"email": "vantonov.19121960@postgrespro.ru", "phone": "+70320102632"}
0005435006696	E27FAE	5279 822820	ALEKSANDR ALEKSANDROV	{"phone": "+70496835138"}
0005435006697	E27FAE	5377 900657	ZHANNA LEBEDEVA	{"phone": "+70894750696"}
0005435006698	2BEE12	0834 808478	ANDREY MOISEEV	{"email": "andreymoiseev-101977@postgrespro.ru", "phone": "+70355217960"}
0005435006699	2BEE12	2633 468787	NIKOLAY GERASIMOV	{"phone": "+70250534079"}
0005435006700	77E102	1626 722405	ROMAN ALEKSANDROV	{"email": "aleksandrov.r081974@postgrespro.ru", "phone": "+70917064457"}
0005435006701	EA8277	9863 167470	ANTONINA FROLOVA	{"phone": "+70114292031"}
0005435006702	EA8277	9862 843231	NINA KUZNECOVA	{"email": "kuznecova_nina-1961@postgrespro.ru", "phone": "+70280641309"}
0005435006703	FF034C	2373 948293	ALEKSEY KOZLOV	{"email": "akozlov.10021977@postgrespro.ru", "phone": "+70834217967"}
0005435006704	FF034C	4177 036164	ANDREY KRASNOV	{"email": "krasnov-a-1966@postgrespro.ru", "phone": "+70958756290"}
0005435006705	CBC66D	2166 222348	MARINA FILIPPOVA	{"phone": "+70334779361"}
0005435006706	CBC66D	9521 721500	RAISA KOROLEVA	{"phone": "+70419420419"}
0005435006707	A6522F	8260 773344	VLADIMIR FILIPPOV	{"phone": "+70012349436"}
0005435006708	36C7AA	6720 395467	NIKOLAY NAZAROV	{"email": "nazarov_n-06021969@postgrespro.ru", "phone": "+70211030970"}
0005435006709	A0ECA8	9206 805480	ANDREY STEPANOV	{"email": "andrey_stepanov-01041969@postgrespro.ru", "phone": "+70306889042"}
0005435006710	096955	9986 940104	OLEG PETROV	{"email": "oleg_petrov-30031973@postgrespro.ru", "phone": "+70265545872"}
0005435006711	BDBC5E	7175 896399	TATYANA ERMAKOVA	{"email": "tatyana-ermakova_1975@postgrespro.ru", "phone": "+70972574647"}
0005435006712	5AA6B9	6860 325359	GEORGIY TARASOV	{"email": "georgiy-tarasov.1978@postgrespro.ru", "phone": "+70510244613"}
0005435006713	FEB037	0610 299168	LYUBOV PETROVA	{"email": "petrova.lyubov.28101969@postgrespro.ru", "phone": "+70144222526"}
0005435006714	5A774C	7030 494536	IRINA NIKITINA	{"phone": "+70801986037"}
0005435006715	F2B6D8	5304 985204	MARIYA SAVELEVA	{"phone": "+70736847810"}
0005435006716	F2B6D8	9681 570171	EKATERINA GORBUNOVA	{"email": "gorbunova_ekaterina.101971@postgrespro.ru", "phone": "+70773925315"}
0005435006717	86F3CD	1651 800528	EVGENIY CHERNOV	{"phone": "+70272827745"}
0005435006718	0BEC4F	1137 792462	IRINA FROLOVA	{"email": "i.frolova.27081969@postgrespro.ru", "phone": "+70824513829"}
0005435006719	6142CC	7914 095305	MARIYA MAKAROVA	{"phone": "+70176815801"}
0005435006720	6EAA3B	3962 173429	MIKHAIL ISAEV	{"email": "isaevmikhail19061969@postgrespro.ru", "phone": "+70776461500"}
0005435006721	6EAA3B	9250 248763	YURIY SOKOLOV	{"phone": "+70805405134"}
0005435006722	54D1A5	8833 561134	DMITRIY SIDOROV	{"phone": "+70058823220"}
0005435006723	C7835F	5091 060203	MIKHAIL SIDOROV	{"email": "sidorov-m.031978@postgrespro.ru", "phone": "+70285630013"}
0005435006724	9F696A	3555 856100	BOGDAN KUZNECOV	{"email": "kuznecov-b_021971@postgrespro.ru", "phone": "+70028539348"}
0005435006725	FC8354	8146 828091	DMITRIY GAVRILOV	{"phone": "+70319185482"}
0005435006726	FC8354	6949 063982	VITALIY NAUMOV	{"phone": "+70173349514"}
0005435006727	9660E8	8584 034987	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova_091978@postgrespro.ru", "phone": "+70688568661"}
0005435006728	C137E3	4098 063354	EKATERINA MEDVEDEVA	{"phone": "+70220949409"}
0005435006729	F0B879	3998 248569	RUSLAN KRASNOV	{"email": "krasnovruslan.061980@postgrespro.ru", "phone": "+70027433764"}
0005435006784	750A5F	6465 500616	ANNA ROMANOVA	{"phone": "+70434455415"}
0005435006730	54287D	1258 256238	DMITRIY SMIRNOV	{"email": "d_smirnov.13021981@postgrespro.ru", "phone": "+70002886211"}
0005435006731	7AC44D	0976 496948	SERGEY KAZAKOV	{"phone": "+70098694452"}
0005435006732	7AC44D	7045 511049	ANDREY MOROZOV	{"phone": "+70222629019"}
0005435006733	7AC44D	3450 853663	MIKHAIL MEDVEDEV	{"phone": "+70619961659"}
0005435006734	65708B	1299 228313	RINAT KRASNOV	{"phone": "+70381770992"}
0005435006735	65708B	1377 662400	POLINA VASILEVA	{"email": "vasileva.polina-1978@postgrespro.ru", "phone": "+70953655749"}
0005435006736	65708B	9999 738127	IRINA KOZLOVA	{"phone": "+70858523481"}
0005435006737	550949	6313 578887	NADEZHDA SAVELEVA	{"email": "n.saveleva-121964@postgrespro.ru", "phone": "+70329733967"}
0005435006738	699D73	4321 958592	VIKTOR SOKOLOV	{"email": "sokolov_viktor-111971@postgrespro.ru", "phone": "+70898388021"}
0005435006739	763BE6	9387 649201	MAKSIM IVANOV	{"email": "ivanovm25061968@postgrespro.ru", "phone": "+70016742520"}
0005435006740	763BE6	6622 757515	NINA BORISOVA	{"phone": "+70258957750"}
0005435006741	B17835	7304 839350	NURIYA KONOVALOVA	{"email": "nkonovalova_051982@postgrespro.ru", "phone": "+70876947093"}
0005435006742	C885B8	2479 683970	LIDIYA KRASNOVA	{"email": "l.krasnova08041975@postgrespro.ru", "phone": "+70262862554"}
0005435006743	D89575	8232 520290	EVGENIYA IVANOVA	{"email": "ivanova-evgeniya-09111960@postgrespro.ru", "phone": "+70809160225"}
0005435006744	D89575	7560 751755	SERGEY KARPOV	{"phone": "+70001109606"}
0005435006745	B0E4C1	2728 877662	ANATOLIY KOROLEV	{"email": "korolev.anatoliy_1967@postgrespro.ru", "phone": "+70762023580"}
0005435006746	A0FC46	9213 202578	MARIYA POLYAKOVA	{"phone": "+70480296955"}
0005435006747	80D23D	7894 384851	SERGEY SIDOROV	{"phone": "+70500412335"}
0005435006748	80D23D	3637 961039	VADIM GUSEV	{"email": "gusevvadim.061976@postgrespro.ru", "phone": "+70358077133"}
0005435006749	F0CD47	8736 587988	SERGEY BARANOV	{"email": "baranovsergey-1970@postgrespro.ru", "phone": "+70209132613"}
0005435006750	60C884	6227 201794	YULIYA VOLKOVA	{"phone": "+70143849110"}
0005435006751	221B2E	2410 804843	ALFIYA NIKITINA	{"phone": "+70100820320"}
0005435006752	3CF91D	2542 285127	ILYA MIKHAYLOV	{"email": "mikhaylov.ilya1968@postgrespro.ru", "phone": "+70201188483"}
0005435006753	3CF91D	2963 921245	ANASTASIYA ZAKHAROVA	{"email": "azakharova_091968@postgrespro.ru", "phone": "+70768805943"}
0005435006754	06272C	8816 045983	OLGA ROMANOVA	{"phone": "+70320189679"}
0005435006755	4B1259	4214 134871	GAGIK BORISOV	{"phone": "+70258398908"}
0005435006756	CFF36D	0414 852937	YULIYA OVCHINNIKOVA	{"email": "yuliya.ovchinnikova-031989@postgrespro.ru", "phone": "+70312078657"}
0005435006757	CFF36D	4357 104798	EKATERINA KRASNOVA	{"email": "krasnovaekaterina08121975@postgrespro.ru", "phone": "+70443336190"}
0005435006758	3E3504	6875 500611	OLGA EGOROVA	{"email": "o.egorova13101977@postgrespro.ru", "phone": "+70449043834"}
0005435006759	E06253	0105 106208	LARISA NIKITINA	{"email": "larisanikitina.1980@postgrespro.ru", "phone": "+70676798370"}
0005435006760	31EE4A	8757 833612	NADEZHDA IVANOVA	{"phone": "+70148716560"}
0005435006761	AA8A3A	0046 773827	LYUBOV EGOROVA	{"email": "lyubov_egorova_26041973@postgrespro.ru", "phone": "+70532901969"}
0005435006762	AA8A3A	7699 567329	NAIL POPOV	{"email": "popov.n091969@postgrespro.ru", "phone": "+70691834021"}
0005435006763	05DB67	3310 809461	VALERIY FROLOV	{"email": "frolov-valeriy-20031979@postgrespro.ru", "phone": "+70255837712"}
0005435006764	230286	2128 705536	ARTEM STEPANOV	{"email": "stepanovartem_011964@postgrespro.ru", "phone": "+70680101776"}
0005435006765	54F060	8349 711567	VIKTOR GAVRILOV	{"phone": "+70387714538"}
0005435006766	F148C7	5209 295597	ALEKSANDRA MELNIKOVA	{"email": "melnikova_aleksandra.20061973@postgrespro.ru", "phone": "+70796119093"}
0005435006767	36F51D	6886 047297	NIKOLAY PAVLOV	{"email": "pavlov.nikolay-1965@postgrespro.ru", "phone": "+70303698043"}
0005435006768	36F51D	6434 913006	REGINA SAVELEVA	{"email": "savelevaregina1981@postgrespro.ru", "phone": "+70065605725"}
0005435006769	1BE8DE	1915 714089	VALENTINA LUKYANOVA	{"phone": "+70834295132"}
0005435006770	9F75B2	1600 772116	VALENTINA SOKOLOVA	{"email": "sokolova_valentina_07011960@postgrespro.ru", "phone": "+70322314243"}
0005435006771	9F75B2	9348 773345	NIKOLAY ORLOV	{"email": "orlov-nikolay.24031970@postgrespro.ru", "phone": "+70315856612"}
0005435006772	CE04A4	8803 449645	VASILIY STEPANOV	{"email": "stepanov.vasiliy09031969@postgrespro.ru", "phone": "+70285927727"}
0005435006773	DD9D32	1549 875182	ALEKSANDR NOVIKOV	{"phone": "+70119983301"}
0005435006774	FBA505	8629 688592	NATALIYA ZHUKOVA	{"email": "nataliyazhukova03101973@postgrespro.ru", "phone": "+70804508270"}
0005435006775	CED700	6109 364445	OLGA EGOROVA	{"email": "egorova-olga.02011975@postgrespro.ru", "phone": "+70578391522"}
0005435006836	1FCDF1	2416 229616	LIDIYA RYABOVA	{"phone": "+70296077747"}
0005435006776	CFC7FF	4018 492423	EVGENIYA KUZNECOVA	{"email": "evgeniya.kuznecova-111978@postgrespro.ru", "phone": "+70629932734"}
0005435006777	5793C6	8213 960747	ALEKSEY IVANOV	{"phone": "+70342816786"}
0005435006778	5793C6	2270 847835	MARINA MAKSIMOVA	{"email": "maksimovam.011973@postgrespro.ru", "phone": "+70483620049"}
0005435006779	464E47	1699 351148	VLADIMIR SOLOVEV	{"email": "vsolovev.02051974@postgrespro.ru", "phone": "+70830890459"}
0005435006780	464E47	6700 338759	NADEZHDA LAZAREVA	{"email": "nadezhda-lazareva.1963@postgrespro.ru", "phone": "+70796256914"}
0005435006781	2C233E	4260 879431	VERA YAKOVLEVA	{"email": "vera.yakovleva-06071974@postgrespro.ru", "phone": "+70212735276"}
0005435006782	B1CDB6	7041 818085	ALEKSANDR SCHERBAKOV	{"phone": "+70251620436"}
0005435006783	85CBB6	9342 983634	NIKOLAY VOLKOV	{"email": "nikolayvolkov-061973@postgrespro.ru", "phone": "+70711334892"}
0005435006785	3D118A	4383 161021	RINAT VOROBEV	{"phone": "+70644390686"}
0005435006786	3D118A	3791 679120	SERGEY POPOV	{"email": "popovsergey081977@postgrespro.ru", "phone": "+70833516812"}
0005435006787	A660BA	7599 501590	BORIS NIKITIN	{"email": "boris_nikitin_24051981@postgrespro.ru", "phone": "+70385399634"}
0005435006788	A660BA	7247 964728	MARAT KUDRYASHOV	{"email": "m.kudryashov.1969@postgrespro.ru", "phone": "+70678046438"}
0005435006789	5F322B	0445 444507	ALINA TARASOVA	{"phone": "+70685168287"}
0005435006790	F16400	9400 080935	ELENA ALEKSANDROVA	{"phone": "+70278894279"}
0005435006791	F16400	8158 439571	MARIYA NOVIKOVA	{"email": "m-novikova_14051976@postgrespro.ru", "phone": "+70037317122"}
0005435006792	DAA5F5	4692 862873	DARYA ZAYCEVA	{"email": "d_zayceva.03081980@postgrespro.ru", "phone": "+70604618860"}
0005435006793	51F2F1	9452 857909	VALENTINA TARASOVA	{"phone": "+70045725253"}
0005435006794	9B9678	3282 737880	SERGEY KRASNOV	{"phone": "+70476063639"}
0005435006795	93546A	7125 712899	VARVARA MOROZOVA	{"phone": "+70008771491"}
0005435006796	93546A	8550 400299	ALEKSANDR MAKAROV	{"phone": "+70522800309"}
0005435006797	FAF90F	1844 207315	ARTUR MAKAROV	{"email": "artur_makarov-111975@postgrespro.ru", "phone": "+70824103166"}
0005435006798	C22E59	2373 161320	MAKSIM POPOV	{"email": "m.popov.111969@postgrespro.ru", "phone": "+70524146494"}
0005435006799	E9925D	7702 139522	VALERIYA KOROLEVA	{"phone": "+70959421199"}
0005435006800	E9925D	6320 597244	NINEL ANTONOVA	{"phone": "+70753311765"}
0005435006801	931610	9706 047903	NATALYA VLASOVA	{"phone": "+70438678519"}
0005435006802	387284	2393 456435	NINA ANISIMOVA	{"email": "anisimova-nina081981@postgrespro.ru", "phone": "+70302429127"}
0005435006803	387284	0517 319229	NIKOLAY GORBUNOV	{"email": "gorbunovnikolay-011967@postgrespro.ru", "phone": "+70037391752"}
0005435006804	FEE13B	5975 197443	MARIYA LUKYANOVA	{"email": "mariyalukyanova-081970@postgrespro.ru", "phone": "+70578281569"}
0005435006805	FEE13B	7166 333495	GALINA KULIKOVA	{"phone": "+70166643470"}
0005435006806	1351DC	4286 997967	KSENIYA ZAKHAROVA	{"email": "k_zakharova_1969@postgrespro.ru", "phone": "+70855123503"}
0005435006807	1351DC	8032 467613	TATYANA DMITRIEVA	{"email": "tatyanadmitrieva1980@postgrespro.ru", "phone": "+70886844826"}
0005435006808	B3A523	8299 856488	LIDIYA ZHURAVLEVA	{"email": "lzhuravleva.121960@postgrespro.ru", "phone": "+70575668661"}
0005435006809	B3A523	0038 429518	YULIYA GAVRILOVA	{"email": "gavrilova.y_011979@postgrespro.ru", "phone": "+70622617284"}
0005435006810	5095E7	4949 467096	TATYANA POPOVA	{"phone": "+70635687383"}
0005435006811	BD0713	1754 391524	LIDIYA EGOROVA	{"phone": "+70234790825"}
0005435006812	BD0713	2336 372599	EKATERINA ILINA	{"email": "eilina-051976@postgrespro.ru", "phone": "+70841935319"}
0005435006813	E2A69D	9494 250155	TATYANA PETROVA	{"email": "petrova-tatyana04041964@postgrespro.ru", "phone": "+70867393885"}
0005435006814	E2A69D	7356 066057	OLEG MIRONOV	{"email": "mironov.oleg.20101973@postgrespro.ru", "phone": "+70135754828"}
0005435006815	8A2561	0317 860658	LILIYA VOLKOVA	{"email": "liliyavolkova.01111979@postgrespro.ru", "phone": "+70800728644"}
0005435006816	8A2561	2053 408900	KSENIYA FEDOROVA	{"phone": "+70673173864"}
0005435006817	DB0309	4188 149616	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr.071967@postgrespro.ru", "phone": "+70081749889"}
0005435006818	1FE620	4309 316119	EMILIYA LUKYANOVA	{"email": "emiliya-lukyanova.03021971@postgrespro.ru", "phone": "+70002516999"}
0005435006819	B897A2	5798 337683	ALINA TIKHONOVA	{"email": "alinatikhonova.1969@postgrespro.ru", "phone": "+70912195321"}
0005435006820	B897A2	7315 093609	OLEG CHERNOV	{"phone": "+70663477191"}
0005435006821	32F524	8675 469722	ALEKSANDR ANTONOV	{"phone": "+70050490612"}
0005435006822	2495B7	2644 089052	OLGA FROLOVA	{"phone": "+70767306176"}
0005435006823	CA1E51	3109 573405	ALEKSANDR AFANASEV	{"phone": "+70906586257"}
0005435006824	29807C	7477 968055	SERGEY GUSEV	{"email": "gusev.s.1969@postgrespro.ru", "phone": "+70787536571"}
0005435006825	29807C	9635 933760	NADEZHDA NIKIFOROVA	{"phone": "+70710084752"}
0005435006826	EE706B	5962 996032	NADEZHDA KUZMINA	{"email": "nadezhdakuzmina-07021973@postgrespro.ru", "phone": "+70711838240"}
0005435006827	B18921	4526 030993	MIKHAIL MAKAROV	{"email": "mikhail_makarov.1964@postgrespro.ru", "phone": "+70866714995"}
0005435006828	A4ECA6	7040 232213	EVGENIY SIDOROV	{"email": "sidorove14021964@postgrespro.ru", "phone": "+70632541247"}
0005435006829	FA4B0A	0386 528610	GALINA KISELEVA	{"phone": "+70074855636"}
0005435006830	FA4B0A	5451 871056	TAMARA OSIPOVA	{"email": "tamara-osipova-29111971@postgrespro.ru", "phone": "+70943280561"}
0005435006831	FA4B0A	8525 348856	TAMARA ZHURAVLEVA	{"phone": "+70984919170"}
0005435006832	F46C0C	8277 584566	OLGA DENISOVA	{"email": "denisova-o_1970@postgrespro.ru", "phone": "+70111186685"}
0005435006833	F46C0C	9578 799410	NATALYA ZOTOVA	{"phone": "+70452738992"}
0005435006834	970AB7	5590 637004	PETR ANDREEV	{"email": "andreevp_1965@postgrespro.ru", "phone": "+70052692971"}
0005435006835	970AB7	2487 804782	ALEKSANDR DAVYDOV	{"phone": "+70333937327"}
0005435006837	1FCDF1	3388 854821	SVETLANA FEDOROVA	{"phone": "+70986476922"}
0005435006838	180000	8373 970209	DMITRIY CHERNOV	{"phone": "+70717994854"}
0005435006839	180000	2396 052147	VLADIMIR ABRAMOV	{"email": "vladimir_abramov_24051973@postgrespro.ru", "phone": "+70775153337"}
0005435006840	0CA15B	0897 788979	OLGA PAVLOVA	{"email": "pavlova-olga091982@postgrespro.ru", "phone": "+70871016466"}
0005435006841	0CA15B	8318 005313	LIDIYA GAVRILOVA	{"email": "gavrilovalidiya1965@postgrespro.ru", "phone": "+70760845737"}
0005435006842	EE7FE3	7847 740882	ARTUR KUZMIN	{"phone": "+70659485256"}
0005435006843	07703B	2838 214437	FAINA FROLOVA	{"email": "frolovafaina-1965@postgrespro.ru", "phone": "+70718090395"}
0005435006844	388FC8	8971 353998	MIKHAIL BARANOV	{"phone": "+70552176784"}
0005435006845	388FC8	0599 214703	LYUBOV SMIRNOVA	{"email": "smirnova.lyubov09041972@postgrespro.ru", "phone": "+70978750643"}
0005435006846	EB8DF5	9075 872516	KARINA ANISIMOVA	{"email": "anisimova-karina10011971@postgrespro.ru", "phone": "+70113955682"}
0005435006847	5FD681	7771 620708	EVGENIY SERGEEV	{"phone": "+70715956760"}
0005435006848	3122DD	2332 217187	OLGA NESTEROVA	{"phone": "+70119765461"}
0005435006849	901346	0084 174255	YURIY BONDARENKO	{"email": "yuriy-bondarenko.031978@postgrespro.ru", "phone": "+70385431311"}
0005435006850	DD70FF	9857 923401	OLGA MIKHAYLOVA	{"phone": "+70475325808"}
0005435006851	E3EAF7	3819 406795	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrovaa1999@postgrespro.ru", "phone": "+70440303455"}
0005435006852	2EF514	3271 529699	IVAN KRASNOV	{"email": "krasnov.i.081969@postgrespro.ru", "phone": "+70434807044"}
0005435006853	17EBC6	1170 615815	MIKHAIL SCHERBAKOV	{"email": "mscherbakov.05101973@postgrespro.ru", "phone": "+70102349504"}
0005435006854	1B3BEF	0378 344943	VIKTORIYA ZOTOVA	{"phone": "+70121642656"}
0005435006855	1B3BEF	8397 626325	TATYANA FEDOROVA	{"phone": "+70565625266"}
0005435006856	C10B2E	6730 806701	VALERIY SOROKIN	{"email": "vsorokin.121975@postgrespro.ru", "phone": "+70765057759"}
0005435006857	C10B2E	6299 148086	VLADIMIR SERGEEV	{"email": "sergeev.v-031980@postgrespro.ru", "phone": "+70599199574"}
0005435006858	7B17CF	2807 027104	RAISA DENISOVA	{"email": "denisovaraisa-28011965@postgrespro.ru", "phone": "+70862406789"}
0005435006859	700FD9	5477 543336	ALEKSANDR DMITRIEV	{"email": "admitriev.21111968@postgrespro.ru", "phone": "+70525376400"}
0005435006860	700FD9	7511 439491	VALENTIN SIDOROV	{"email": "valentin.sidorov1978@postgrespro.ru", "phone": "+70159720453"}
0005435006861	700FD9	1098 096147	ALEKSANDRA MELNIKOVA	{"phone": "+70628067692"}
0005435006862	6FE674	1169 545239	ALEKSEY BONDARENKO	{"phone": "+70661317263"}
0005435006863	6FE674	8023 268996	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr-071969@postgrespro.ru", "phone": "+70641626171"}
0005435006864	6FE674	2205 242203	LYUDMILA SIDOROVA	{"phone": "+70116757039"}
0005435006865	5EA1DA	1812 972255	KONSTANTIN GUSEV	{"email": "konstantin_gusev041963@postgrespro.ru", "phone": "+70736984972"}
0005435006866	A03E33	3020 959611	MAKSIM SMIRNOV	{"phone": "+70547630421"}
0005435006867	5E93B1	5457 333524	EDUARD KULIKOV	{"phone": "+70788394240"}
0005435006868	E3E079	6617 503695	MILENA SAVELEVA	{"phone": "+70816337665"}
0005435006869	5E3BC7	6612 045124	VLADIMIR MOROZOV	{"phone": "+70720778338"}
0005435006870	5E3BC7	1645 825709	ALIYA EGOROVA	{"email": "aliya_egorova081968@postgrespro.ru", "phone": "+70845893902"}
0005435006871	1FA132	7575 733411	NADEZHDA SOKOLOVA	{"phone": "+70775341022"}
0005435006872	659A34	5444 323335	LILIYA ANTONOVA	{"phone": "+70318517871"}
0005435006873	659A34	4989 315085	ANNA IVANOVA	{"email": "anna-ivanova_08081962@postgrespro.ru", "phone": "+70897747028"}
0005435006874	C697C9	0590 931317	PETR ANDREEV	{"email": "andreev-p.071963@postgrespro.ru", "phone": "+70076552561"}
0005435006875	AB0444	0691 605320	ELENA LOGINOVA	{"phone": "+70529416218"}
0005435006876	5E91B0	5098 287976	GENNADIY KOROLEV	{"phone": "+70329149010"}
0005435006877	9AA9E6	1255 497740	VYACHESLAV MAKSIMOV	{"email": "v_maksimov30061961@postgrespro.ru", "phone": "+70926917846"}
0005435006878	9AA9E6	8899 360656	ELENA VOLKOVA	{"email": "volkovae-1970@postgrespro.ru", "phone": "+70531542211"}
0005435006879	CD76C8	8082 769419	VERONIKA POLYAKOVA	{"phone": "+70640016495"}
0005435006880	D07C22	0233 060930	OLGA PAVLOVA	{"email": "pavlovao.15071973@postgrespro.ru", "phone": "+70616611401"}
0005435006881	3C779C	1001 965346	VALERIY MAKSIMOV	{"email": "valeriy-maksimov-20111975@postgrespro.ru", "phone": "+70627309368"}
0005435006882	3C779C	5704 461273	IVAN POPOV	{"email": "ipopov_23071964@postgrespro.ru", "phone": "+70430397271"}
0005435006883	3891CD	8749 839366	TATYANA PETROVA	{"email": "tpetrova-1959@postgrespro.ru", "phone": "+70020790066"}
0005435006884	A35E73	3471 526518	VERA MAKAROVA	{"email": "v.makarova.18101968@postgrespro.ru", "phone": "+70428751295"}
0005435006885	07C9B1	9317 596423	EVDOKIYA BELYAEVA	{"email": "belyaeva-e-101960@postgrespro.ru", "phone": "+70309400219"}
0005435006886	07C9B1	1325 969816	VIKTOR ROMANOV	{"phone": "+70103356590"}
0005435006887	07C9B1	1304 187979	MARIYA MARTYNOVA	{"email": "martynova-m_101969@postgrespro.ru", "phone": "+70258980233"}
0005435006888	C08D47	1648 488785	MARINA LAZAREVA	{"email": "m_lazareva021966@postgrespro.ru", "phone": "+70608327307"}
0005435006889	008182	7434 008358	ALEKSANDR VASILEV	{"email": "a_vasilev.25061967@postgrespro.ru", "phone": "+70871835497"}
0005435006890	ED0ADA	3924 536740	OLEG EGOROV	{"email": "egorov_oleg-1967@postgrespro.ru", "phone": "+70870827985"}
0005435006891	CD1825	6799 495843	VLADIMIR TIMOFEEV	{"email": "timofeev.vladimir.03111970@postgrespro.ru", "phone": "+70099252007"}
0005435006892	CD1825	1909 251532	BOGDAN NOVIKOV	{"email": "bogdan-novikov.1965@postgrespro.ru", "phone": "+70022390925"}
0005435006893	9FDB25	3033 844825	NATALYA EGOROVA	{"phone": "+70758444328"}
0005435006894	9FDB25	0422 834514	ALEKSANDR NAZAROV	{"email": "a.nazarov_1967@postgrespro.ru", "phone": "+70110345813"}
0005435006895	72CCA9	0632 588847	NIKOLAY ANDREEV	{"phone": "+70217898096"}
0005435006896	FFF6CF	4346 960939	RAISA MARTYNOVA	{"email": "martynovaraisa.121961@postgrespro.ru", "phone": "+70031510295"}
0005435006897	FFF6CF	5866 454374	VLADIMIR ZAYCEV	{"email": "zaycevv_051963@postgrespro.ru", "phone": "+70865847189"}
0005435006898	189E8B	0671 228373	MARIYA POPOVA	{"email": "popova.m.1975@postgrespro.ru", "phone": "+70306613475"}
0005435006899	714D31	2930 943328	SERGEY MOROZOV	{"phone": "+70357201669"}
0005435006900	714D31	9109 379108	DANIL BARANOV	{"email": "dbaranov-01061968@postgrespro.ru", "phone": "+70956792965"}
0005435006901	1F984F	8926 530761	SERGEY IVANOV	{"email": "sivanov091977@postgrespro.ru", "phone": "+70690376767"}
0005435006902	1F984F	0832 251712	VALENTINA KULIKOVA	{"phone": "+70347177716"}
0005435006903	438AEB	1768 345580	PAVEL IVANOV	{"phone": "+70697799523"}
0005435006904	438AEB	4612 152838	RAMIL ROMANOV	{"email": "romanov_r-30041974@postgrespro.ru", "phone": "+70546498131"}
0005435006905	4BE64F	2246 293303	YULIYA KUDRYASHOVA	{"phone": "+70517363261"}
0005435006906	386A76	5971 250702	VALERIY SCHERBAKOV	{"email": "v_scherbakov.11021968@postgrespro.ru", "phone": "+70609462039"}
0005435006907	386A76	3199 113414	VADIM PAVLOV	{"phone": "+70372607422"}
0005435006908	2FED31	3389 652592	DMITRIY KUZNECOV	{"phone": "+70109261070"}
0005435006909	2FED31	2988 351564	TATYANA TARASOVA	{"email": "t_tarasova_09081971@postgrespro.ru", "phone": "+70657428429"}
0005435006910	2FED31	6056 169960	ALEKSANDR MELNIKOV	{"phone": "+70465610471"}
0005435006911	45748F	1765 627121	ELENA POPOVA	{"phone": "+70382705309"}
0005435006912	AD1E50	2245 260673	TATYANA FEDOROVA	{"email": "t-fedorova-01061976@postgrespro.ru", "phone": "+70439700174"}
0005435006913	AD1E50	8037 752853	EVGENIY KUZNECOV	{"phone": "+70826393197"}
0005435006914	61B4F5	7828 559603	ALEKSANDR TIKHONOV	{"email": "atikhonov_14061972@postgrespro.ru", "phone": "+70585589503"}
0005435006915	9BE0BE	4298 360174	ILONA SOKOLOVA	{"phone": "+70729359962"}
0005435006916	082D76	9590 495454	VALENTIN TIMOFEEV	{"phone": "+70157221674"}
0005435006917	19FBE5	2537 210826	VYACHESLAV ILIN	{"phone": "+70380288291"}
0005435006918	19FBE5	2685 507626	IGOR POPOV	{"phone": "+70767506954"}
0005435006919	7E51DB	9685 079415	IRINA OSIPOVA	{"email": "osipova-i-061967@postgrespro.ru", "phone": "+70766405174"}
0005435006920	7E51DB	0318 202629	VLADISLAV VASILEV	{"email": "vvasilev_14011962@postgrespro.ru", "phone": "+70378897421"}
0005435006921	37A19F	4883 738025	ROMAN VOROBEV	{"email": "roman_vorobev021969@postgrespro.ru", "phone": "+70783398570"}
0005435006922	37A19F	5192 904299	ILYA NOVIKOV	{"email": "ilya-novikov_101983@postgrespro.ru", "phone": "+70691628006"}
0005435006923	F8FD87	5872 625525	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova.101971@postgrespro.ru", "phone": "+70824434132"}
0005435006924	F8FD87	6238 796546	SERGEY BELOV	{"phone": "+70275537973"}
0005435006925	ADBF4B	6265 012016	SVETLANA MELNIKOVA	{"email": "melnikova-svetlana-06071956@postgrespro.ru", "phone": "+70524191869"}
0005435006926	ADBF4B	2713 468640	SVETLANA TROFIMOVA	{"email": "trofimova_svetlana_1977@postgrespro.ru", "phone": "+70748005610"}
0005435006927	972744	7458 944123	ALEKSANDR ILIN	{"phone": "+70314187168"}
0005435006928	972744	2061 109040	TATYANA DAVYDOVA	{"email": "davydova.tatyana.1975@postgrespro.ru", "phone": "+70732558287"}
0005435006929	E99275	1886 516341	DMITRIY MAKSIMOV	{"phone": "+70183683819"}
0005435006930	13E349	3201 532840	NAIL TARASOV	{"email": "ntarasov.1968@postgrespro.ru", "phone": "+70043065561"}
0005435006931	51D1C9	3215 208541	MARINA ROMANOVA	{"phone": "+70634055396"}
0005435006932	51D1C9	1767 705360	NATALYA POPOVA	{"email": "n-popova03041960@postgrespro.ru", "phone": "+70074138541"}
0005435006933	49464F	2678 402446	TATYANA IVANOVA	{"phone": "+70979495012"}
0005435006934	085E29	7096 563720	SVETLANA PETROVA	{"email": "s-petrova_24041971@postgrespro.ru", "phone": "+70640979365"}
0005435006935	77C066	0746 618491	ELENA KOVALEVA	{"phone": "+70639492293"}
0005435006936	6FFBCD	7025 038863	VALERIY IVANOV	{"email": "ivanovv_05071967@postgrespro.ru", "phone": "+70136198581"}
0005435006937	87E17E	4082 912252	OLGA DAVYDOVA	{"email": "davydova.olga.1980@postgrespro.ru", "phone": "+70780515365"}
0005435006938	87E17E	5967 013846	ELMIRA IVANOVA	{"email": "eivanova14071969@postgrespro.ru", "phone": "+70311762053"}
0005435006939	BF2582	1960 534644	PAVEL SHEVCHENKO	{"email": "shevchenko-p-111968@postgrespro.ru", "phone": "+70120644568"}
0005435006940	BF2582	2211 431665	ANDREY KAZAKOV	{"phone": "+70618076505"}
0005435006941	67B9D4	9862 954151	ILYA MAKAROV	{"email": "makarovilya_091989@postgrespro.ru", "phone": "+70883360194"}
0005435006942	242E02	1268 764996	ALEKSANDR MIRONOV	{"phone": "+70163914289"}
0005435006943	3194D8	0336 169594	ALEKSEY PAVLOV	{"email": "apavlov_1982@postgrespro.ru", "phone": "+70566231268"}
0005435006944	9E578A	8957 634574	NIKOLAY SEMENOV	{"phone": "+70860620641"}
0005435006945	B79E7E	8646 570198	GRIGORIY ZAKHAROV	{"email": "g_zakharov-31071972@postgrespro.ru", "phone": "+70407044906"}
0005435006946	AF696B	2531 134145	MIKHAIL VASILEV	{"email": "vasilev-mikhail_1976@postgrespro.ru", "phone": "+70421444136"}
0005435006947	04F9B3	6227 785870	LYUBOV ZHUKOVA	{"email": "lyubovzhukova.1972@postgrespro.ru", "phone": "+70740041420"}
0005435006948	EB786C	8313 126864	PETR POPOV	{"phone": "+70837935822"}
0005435006949	EB786C	1858 394885	VLADIMIR MIKHAYLOV	{"phone": "+70284855211"}
0005435007009	B35ACE	2373 422400	EVGENIY OSIPOV	{"phone": "+70692565480"}
0005435006950	6798E4	5663 459666	FEDOR KUZNECOV	{"email": "fedorkuznecov-061957@postgrespro.ru", "phone": "+70441504995"}
0005435006951	6798E4	8335 943933	KIRILL ILIN	{"phone": "+70007293081"}
0005435006952	F5D5B6	7666 666235	DMITRIY FEDOROV	{"phone": "+70810608585"}
0005435006953	BF4766	1793 054309	ALEKSANDRA CHERNOVA	{"phone": "+70657187255"}
0005435006954	1D2C62	4588 709456	GALINA YAKOVLEVA	{"email": "galina-yakovleva_101976@postgrespro.ru", "phone": "+70224562991"}
0005435006955	8068DD	0351 836313	IRINA VOLKOVA	{"phone": "+70269707225"}
0005435006956	10D63F	4675 538852	SERGEY IVANOV	{"email": "ivanov.sergey.051976@postgrespro.ru", "phone": "+70041372434"}
0005435006957	2A4BAD	7923 297575	IRINA POTAPOVA	{"phone": "+70528058594"}
0005435006958	592083	1141 067942	ELENA OVCHINNIKOVA	{"email": "ovchinnikova.elena041963@postgrespro.ru", "phone": "+70938876218"}
0005435006959	155B8A	6918 818917	ELENA YUDINA	{"email": "e-yudina_1978@postgrespro.ru", "phone": "+70703522680"}
0005435006960	35F4D8	2957 951561	ANDREY OSIPOV	{"email": "osipov.a-101978@postgrespro.ru", "phone": "+70835230098"}
0005435006961	D1ABD3	0289 653288	DMITRIY SMIRNOV	{"phone": "+70963059368"}
0005435006962	F0D63F	1754 612861	VALENTIN ROMANOV	{"email": "romanov_valentin-121978@postgrespro.ru", "phone": "+70208755007"}
0005435006963	CE27F9	7705 992385	PAVEL ISAEV	{"email": "p_isaev_05011968@postgrespro.ru", "phone": "+70312076921"}
0005435006964	0D699D	4581 529932	VERA SMIRNOVA	{"email": "verasmirnova.1978@postgrespro.ru", "phone": "+70985698237"}
0005435006965	041A53	6154 788126	SEMEN SMIRNOV	{"email": "s.smirnov.121979@postgrespro.ru", "phone": "+70780344030"}
0005435006966	041A53	0939 804328	ANDREY ZAYCEV	{"phone": "+70345493726"}
0005435006967	0CACD4	3246 988984	VLADIMIR ABRAMOV	{"email": "abramov-vladimir_1964@postgrespro.ru", "phone": "+70316224054"}
0005435006968	0CACD4	4337 602386	ALEKSEY MAKAROV	{"phone": "+70073026315"}
0005435006969	81CEA9	7504 940761	SERGEY IVANOV	{"phone": "+70677214636"}
0005435006970	704DC3	7140 893837	NATALYA NOVIKOVA	{"email": "novikova_natalya.031982@postgrespro.ru", "phone": "+70629758779"}
0005435006971	4CA7C1	2653 518557	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir-051966@postgrespro.ru", "phone": "+70764548624"}
0005435006972	4CA7C1	7358 414679	ALEKSANDR VASILEV	{"phone": "+70584454955"}
0005435006973	7796CE	7378 202475	SERGEY IVANOV	{"email": "ivanov-sergey-11041977@postgrespro.ru", "phone": "+70744041249"}
0005435006974	A46F83	6607 978702	VITALIY MELNIKOV	{"email": "vitaliy.melnikov1973@postgrespro.ru", "phone": "+70540702595"}
0005435006975	A46F83	5743 082118	ELENA BOGDANOVA	{"phone": "+70346341504"}
0005435006976	385A7C	3058 238465	VIKTORIYA DAVYDOVA	{"email": "davydovaviktoriya-05101976@postgrespro.ru", "phone": "+70694973342"}
0005435006977	385A7C	9563 035876	ANNA MIKHAYLOVA	{"phone": "+70664461477"}
0005435006978	F42A4A	8007 238186	ALEKSEY BELOV	{"email": "a.belov-071966@postgrespro.ru", "phone": "+70809447327"}
0005435006979	702785	3400 190252	ROMAN EGOROV	{"email": "egorov.r-05101978@postgrespro.ru", "phone": "+70716376329"}
0005435006980	A7D9D6	9544 870722	ALEKSEY VOLKOV	{"phone": "+70715307086"}
0005435006981	63DCB1	7244 723936	VLADIMIR NAUMOV	{"email": "vladimirnaumov051982@postgrespro.ru", "phone": "+70085768724"}
0005435006982	63DCB1	0336 271353	NIKOLAY ALEKSANDROV	{"email": "aleksandrovnikolay24081980@postgrespro.ru", "phone": "+70401819747"}
0005435006983	63DCB1	5845 392547	VIKTOR SMIRNOV	{"phone": "+70624019553"}
0005435006984	2CE448	6188 798615	LYUBOV IVANOVA	{"email": "livanova-29091969@postgrespro.ru", "phone": "+70710315424"}
0005435006985	5A5374	1631 427970	ILYA DMITRIEV	{"phone": "+70719863270"}
0005435006986	2AFB1C	4930 161878	IVAN NAZAROV	{"email": "nazarov_ivan_1962@postgrespro.ru", "phone": "+70808594496"}
0005435006987	5924CD	8922 993764	VALERIY SMIRNOV	{"email": "valeriy.smirnov_1969@postgrespro.ru", "phone": "+70268712628"}
0005435006988	FF08CF	5868 132229	NINA FROLOVA	{"email": "frolova_nina1969@postgrespro.ru", "phone": "+70632588223"}
0005435006989	FF08CF	9420 126230	VIKTOR KARPOV	{"phone": "+70237584800"}
0005435006990	90C0D5	0771 897307	DMITRIY FEDOROV	{"phone": "+70167929730"}
0005435006991	3FA12D	3054 829743	VLADIMIR GUSEV	{"phone": "+70150586861"}
0005435006992	3FA12D	0292 160049	VYACHESLAV MARTYNOV	{"phone": "+70740453573"}
0005435006993	9AFA7F	0986 333488	VALENTINA BARANOVA	{"email": "v.baranova06101964@postgrespro.ru", "phone": "+70907998024"}
0005435006994	9AFA7F	2428 884077	ALEKSANDR ISAEV	{"email": "aleksandrisaev-24101976@postgrespro.ru", "phone": "+70265263927"}
0005435006995	3D513B	9100 118370	YURIY ZHUKOV	{"email": "zhukovy_121981@postgrespro.ru", "phone": "+70013823571"}
0005435006996	F1834F	7053 227114	ALEKSANDR ZAKHAROV	{"phone": "+70401363613"}
0005435006997	0A7485	9456 182330	EGOR MELNIKOV	{"phone": "+70079374998"}
0005435006998	0A7485	0764 337151	ALIYA KUDRYASHOVA	{"phone": "+70776575552"}
0005435006999	0A7485	0920 406765	SERGEY KUZNECOV	{"email": "sergeykuznecov.031952@postgrespro.ru", "phone": "+70702547074"}
0005435007000	8C657B	5192 828411	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr-24061963@postgrespro.ru", "phone": "+70753120637"}
0005435007001	8C657B	9571 720930	OLGA KUZMINA	{"email": "kuzmina-o27111977@postgrespro.ru", "phone": "+70928955273"}
0005435007002	353C54	0424 342389	SERGEY BONDARENKO	{"email": "sergey-bondarenko.011978@postgrespro.ru", "phone": "+70548144826"}
0005435007003	7CC010	5578 449573	ANGELINA FADEEVA	{"email": "fadeeva_a.17051969@postgrespro.ru", "phone": "+70254607719"}
0005435007004	D43D81	2857 622419	VIKTORIYA OSIPOVA	{"phone": "+70587542144"}
0005435007005	82606B	8413 216523	VLADIMIR ROMANOV	{"email": "romanov_vladimir.1968@postgrespro.ru", "phone": "+70758781664"}
0005435007006	F98F2B	8852 692001	NIKOLAY KRASNOV	{"email": "krasnov_n.091952@postgrespro.ru", "phone": "+70931517566"}
0005435007007	F98F2B	6039 140751	SERGEY VOLKOV	{"phone": "+70295843621"}
0005435007008	971DDB	0798 871200	SERGEY DMITRIEV	{"email": "s-dmitriev.1973@postgrespro.ru", "phone": "+70566112535"}
0005435007010	B35ACE	4022 848083	DMITRIY SCHERBAKOV	{"phone": "+70120041144"}
0005435007011	B35ACE	0416 292225	SERGEY GORBUNOV	{"phone": "+70051130276"}
0005435007012	EAEFE1	1189 687555	ALBINA PAVLOVA	{"phone": "+70457675353"}
0005435007013	EAEFE1	1360 684706	YULIYA KOVALEVA	{"email": "kovaleva-y.16061971@postgrespro.ru", "phone": "+70285000274"}
0005435007014	1B0CEE	1943 304286	SOFYA VASILEVA	{"email": "vasileva-sofya-1971@postgrespro.ru", "phone": "+70263949175"}
0005435007015	ABE3FF	7223 219351	DMITRIY AFANASEV	{"phone": "+70089220105"}
0005435007016	07045C	3557 941500	OLGA VOLKOVA	{"phone": "+70468799381"}
0005435007017	07045C	6551 705144	SERGEY CHERNOV	{"phone": "+70260630034"}
0005435007018	DB98EA	9590 654519	VALENTINA MOROZOVA	{"email": "v.morozova.061972@postgrespro.ru", "phone": "+70044506780"}
0005435007019	E80040	9873 862894	RAISA MELNIKOVA	{"phone": "+70355665662"}
0005435007020	E80040	4876 071303	LILIYA EGOROVA	{"phone": "+70946278756"}
0005435007021	72852D	5211 681826	ROMAN KOZLOV	{"email": "r.kozlov-04081966@postgrespro.ru", "phone": "+70323918691"}
0005435007022	C8B2F4	2223 540307	DENIS ORLOV	{"phone": "+70087280824"}
0005435007023	E008BC	9550 449853	SERGEY SEMENOV	{"email": "s_semenov041973@postgrespro.ru", "phone": "+70676409137"}
0005435007024	E008BC	9908 542201	ALEKSANDR NAZAROV	{"phone": "+70691317106"}
0005435007025	1648CD	4951 449975	ARKADIY VASILEV	{"email": "vasilev_arkadiy1963@postgrespro.ru", "phone": "+70497099805"}
0005435007026	E0E60E	7351 612067	IVAN MIRONOV	{"phone": "+70642240230"}
0005435007027	80766C	8665 176745	KSENIYA ZAKHAROVA	{"email": "zakharova.kseniya_021978@postgrespro.ru", "phone": "+70456531154"}
0005435007028	CB5907	4758 380214	ALEKSEY EGOROV	{"phone": "+70435188206"}
0005435007029	CB5907	0026 592058	ALEKSANDR NOVIKOV	{"phone": "+70937909254"}
0005435007030	5DDC21	2324 273996	OLGA NIKITINA	{"phone": "+70599727587"}
0005435007031	1F27CB	5223 962964	ALEKSEY MIRONOV	{"email": "aleksey_mironov.1968@postgrespro.ru", "phone": "+70387346991"}
0005435007032	039F4C	3949 211120	NATALYA DENISOVA	{"email": "denisova-natalya.1980@postgrespro.ru", "phone": "+70531460951"}
0005435007033	266BD0	0264 693318	DMITRIY GORBUNOV	{"email": "gorbunovd-04121973@postgrespro.ru", "phone": "+70170136606"}
0005435007034	266BD0	7452 168079	GALINA SOKOLOVA	{"phone": "+70771581752"}
0005435007035	F7B510	3801 978791	VIKTOR EGOROV	{"phone": "+70175825504"}
0005435007036	33BB2A	3459 902356	SVETLANA ZAKHAROVA	{"phone": "+70200998322"}
0005435007037	725AAC	0497 996591	MIKHAIL PETROV	{"phone": "+70252130534"}
0005435007038	9BADDE	5642 091845	VITALIY IVANOV	{"email": "v-ivanov-021968@postgrespro.ru", "phone": "+70714083645"}
0005435007039	9BADDE	3694 034798	ALEKSEY RODIONOV	{"phone": "+70389365627"}
0005435007040	D42400	7647 887610	IGOR GORBUNOV	{"phone": "+70977298474"}
0005435007041	D42400	0830 917043	VLADIMIR BARANOV	{"email": "baranovvladimir-021978@postgrespro.ru", "phone": "+70452941923"}
0005435007042	A7126B	3232 465266	ALEKSEY NAUMOV	{"phone": "+70183026137"}
0005435007043	6FC1B2	1423 372312	VLADIMIR TARASOV	{"email": "tarasov_vladimir-07081977@postgrespro.ru", "phone": "+70284514556"}
0005435007044	DB2AB7	5602 882567	ZINAIDA ZAKHAROVA	{"phone": "+70870605970"}
0005435007045	B36A9F	2737 914967	KIRILL KONOVALOV	{"phone": "+70932970876"}
0005435007046	B36A9F	0298 238622	VLADIMIR ROMANOV	{"email": "romanov_v_05031967@postgrespro.ru", "phone": "+70412375056"}
0005435007047	70F67B	8437 717369	VASILIY FROLOV	{"email": "vasiliy_frolov_111969@postgrespro.ru", "phone": "+70001291357"}
0005435007048	8EDC87	0735 377457	VADIM ZAKHAROV	{"phone": "+70345437418"}
0005435007049	8EDC87	7847 794299	TAMARA ERMAKOVA	{"email": "tamara_ermakova_061961@postgrespro.ru", "phone": "+70029864617"}
0005435007050	98E494	7806 520259	VIKTORIYA SMIRNOVA	{"email": "v.smirnova-111974@postgrespro.ru", "phone": "+70748293197"}
0005435007051	226282	3789 203487	MARIYA GUSEVA	{"email": "gusevamariya1964@postgrespro.ru", "phone": "+70416359358"}
0005435007052	226282	6996 788362	ELENA VASILEVA	{"phone": "+70006777142"}
0005435007053	AAC414	2074 700411	NATALIYA AKIMOVA	{"phone": "+70314430703"}
0005435007054	AAC414	9488 350082	ALEKSANDR ILIN	{"phone": "+70116107371"}
0005435007055	0B844D	7123 854908	ZOYA KALININA	{"email": "kalinina-zoya.07081972@postgrespro.ru", "phone": "+70151115438"}
0005435007056	0C02F3	1870 429289	ANTON GERASIMOV	{"phone": "+70108513921"}
0005435007057	0C02F3	8623 435298	NADEZHDA BORISOVA	{"phone": "+70324568469"}
0005435007058	7A4A07	0406 342756	LARISA MIKHAYLOVA	{"email": "larisa.mikhaylova031968@postgrespro.ru", "phone": "+70059011217"}
0005435007059	2803EA	7404 970422	ARTEM KULIKOV	{"email": "artem_kulikov_1975@postgrespro.ru", "phone": "+70264644040"}
0005435007060	D1F8A6	8442 696457	ILYA SOROKIN	{"email": "sorokin-i05061975@postgrespro.ru", "phone": "+70682395605"}
0005435007061	D1F8A6	8635 975024	VITALIY PETROV	{"phone": "+70189678805"}
0005435007062	D5BC06	9560 478989	ARTEM SEMENOV	{"phone": "+70970259859"}
0005435007063	D834A8	1094 189565	INNA ANTONOVA	{"phone": "+70288285581"}
0005435007064	D834A8	2941 003315	LIDIYA AFANASEVA	{"email": "afanaseval-25031960@postgrespro.ru", "phone": "+70134967677"}
0005435007065	241104	7706 081924	VALERIY NAZAROV	{"phone": "+70675790398"}
0005435007066	6958D1	6507 354993	YULIYA SIDOROVA	{"phone": "+70109653960"}
0005435007067	6958D1	7214 143646	OKSANA FROLOVA	{"phone": "+70199141326"}
0005435007068	D6874A	8761 966856	KIRILL EGOROV	{"phone": "+70309079254"}
0005435007069	D6874A	9215 795054	VLADIMIR SERGEEV	{"phone": "+70514410321"}
0005435007070	D6874A	7251 141304	ALEKSANDR PAVLOV	{"email": "apavlov.041971@postgrespro.ru", "phone": "+70411121208"}
0005435007071	781FF3	5207 607163	ARSENIY SCHERBAKOV	{"phone": "+70052802665"}
0005435007072	781FF3	3396 300072	ALEKSANDR YAKOVLEV	{"phone": "+70486189524"}
0005435007073	9CEF03	8835 979748	SVETLANA BELYAEVA	{"phone": "+70010788358"}
0005435007074	9CEF03	6499 643033	ANDREY SERGEEV	{"email": "andrey.sergeev_1965@postgrespro.ru", "phone": "+70516370896"}
0005435007075	74B12F	5828 471207	VALENTINA VASILEVA	{"phone": "+70379162191"}
0005435007076	74B12F	3757 672341	ALEKSANDR FILIPPOV	{"email": "filippov.a-04081963@postgrespro.ru", "phone": "+70761923450"}
0005435007077	58E3E7	0565 630004	NINA GAVRILOVA	{"email": "ninagavrilova18021964@postgrespro.ru", "phone": "+70758047743"}
0005435007078	58E3E7	6580 431672	ALEKSANDR VOLKOV	{"phone": "+70247318312"}
0005435007079	E611A5	1102 615843	VIKTOR BORISOV	{"email": "borisov_viktor-1972@postgrespro.ru", "phone": "+70298243870"}
0005435007080	E611A5	1085 923714	VYACHESLAV SEMENOV	{"phone": "+70350770774"}
0005435007081	B32E91	2260 521427	ALEKSANDR ANDREEV	{"email": "andreevaleksandr_021987@postgrespro.ru", "phone": "+70865820667"}
0005435007082	14F3ED	7090 633914	ANASTASIYA KOROLEVA	{"email": "a-koroleva_1962@postgrespro.ru", "phone": "+70551649704"}
0005435007083	D038D7	7814 835128	LIDIYA ALEKSANDROVA	{"phone": "+70955469546"}
0005435007084	4A45D6	3050 325729	TATYANA MIRONOVA	{"phone": "+70066057864"}
0005435007085	2D9DB4	1348 201053	RAISA DENISOVA	{"phone": "+70806663490"}
0005435007086	2D9DB4	6557 163124	FANIL VOROBEV	{"email": "fanilvorobev.20051979@postgrespro.ru", "phone": "+70836000847"}
0005435007087	2D9DB4	8435 997063	BORIS DMITRIEV	{"email": "dmitriev.b_091979@postgrespro.ru", "phone": "+70996169992"}
0005435007088	A3F7CA	5834 360363	ANNA IVANOVA	{"email": "ivanova.anna.1976@postgrespro.ru", "phone": "+70703598499"}
0005435007089	A3F7CA	2380 667430	NATALYA NOVIKOVA	{"email": "n.novikova_041967@postgrespro.ru", "phone": "+70827603999"}
0005435007090	2E4515	0851 473109	EVGENIY VOLKOV	{"email": "volkovevgeniy-20031972@postgrespro.ru", "phone": "+70951300113"}
0005435007091	E1237B	1751 080427	ALEKSANDR SOROKIN	{"email": "a.sorokin25081966@postgrespro.ru", "phone": "+70322227660"}
0005435007092	32F97C	0547 025894	NINA POPOVA	{"phone": "+70944231721"}
0005435007093	32F97C	0294 908431	MIKHAIL TIKHONOV	{"phone": "+70348017239"}
0005435007094	55342D	9495 105166	SVETLANA MATVEEVA	{"email": "svetlana-matveeva.1974@postgrespro.ru", "phone": "+70289448786"}
0005435007095	91BADF	4151 330119	RUSLAN ILIN	{"email": "r_ilin_30101967@postgrespro.ru", "phone": "+70787126419"}
0005435007096	91BADF	9845 077176	VLADIMIR SOLOVEV	{"phone": "+70120355564"}
0005435007097	198F60	8862 473724	ELENA ZAYCEVA	{"email": "zayceva-e-111966@postgrespro.ru", "phone": "+70589454090"}
0005435007098	8E0087	3658 547790	OLGA NOVIKOVA	{"email": "novikova-o.29081980@postgrespro.ru", "phone": "+70506604713"}
0005435007099	EFE562	7340 167723	IRINA ALEKSANDROVA	{"email": "aleksandrovai_30101975@postgrespro.ru", "phone": "+70105582377"}
0005435007100	5A9B02	0294 125936	VALERIY CHERNOV	{"email": "chernov.v-17081964@postgrespro.ru", "phone": "+70337320992"}
0005435007101	53B4EF	2704 081955	DMITRIY RODIONOV	{"phone": "+70303407575"}
0005435007102	439B86	2504 411476	GRIGORIY GUSEV	{"email": "ggusev.08041966@postgrespro.ru", "phone": "+70738318775"}
0005435007103	D4EEC6	1596 696612	VLADIMIR KOROLEV	{"phone": "+70940856641"}
0005435007104	49996F	5720 263492	ANNA BELYAEVA	{"email": "belyaeva-anna081973@postgrespro.ru", "phone": "+70367464366"}
0005435007105	01365C	9163 900095	NATALYA SOROKINA	{"email": "sorokina_natalya-17111972@postgrespro.ru", "phone": "+70038538065"}
0005435007106	01365C	7792 208113	ANATOLIY TIMOFEEV	{"phone": "+70637663246"}
0005435007107	01365C	9883 594909	ALEKSANDRA GRISHINA	{"email": "grishina_aleksandra-02121976@postgrespro.ru", "phone": "+70431305804"}
0005435007108	53B6F0	3139 464748	ANZHELIKA NIKOLAEVA	{"phone": "+70914175309"}
0005435007109	9A0D7F	3660 645355	VADIM KRASNOV	{"phone": "+70617350952"}
0005435007110	0E8489	3053 831546	ANNA NIKITINA	{"phone": "+70050926925"}
0005435007111	63894C	6630 294313	VIKTORIYA RODIONOVA	{"email": "rodionovaviktoriya08121988@postgrespro.ru", "phone": "+70981248417"}
0005435007112	7F7E99	4181 644452	VALERIY FILIPPOV	{"email": "valeriy_filippov.061970@postgrespro.ru", "phone": "+70508881248"}
0005435007113	0D1A10	5672 640801	DENIS DENISOV	{"phone": "+70972295905"}
0005435007114	0D1A10	8894 434218	OLGA BARANOVA	{"email": "baranova_o-1967@postgrespro.ru", "phone": "+70938464692"}
0005435007115	0D8F6D	3730 553538	TATYANA LUKYANOVA	{"email": "lukyanova.tatyana.011968@postgrespro.ru", "phone": "+70820737924"}
0005435007116	94579A	2333 385784	OKSANA VOROBEVA	{"email": "o-vorobeva.121985@postgrespro.ru", "phone": "+70491734791"}
0005435007117	94579A	1092 505913	IVAN TIMOFEEV	{"phone": "+70132461815"}
0005435007118	6BB987	2438 800819	TATYANA BORISOVA	{"phone": "+70500612673"}
0005435007119	6BB987	2944 633818	OLGA NIKITINA	{"email": "nikitina.o03061979@postgrespro.ru", "phone": "+70083091419"}
0005435007120	2FAF8A	5038 572223	ALIYA NESTEROVA	{"phone": "+70244753532"}
0005435007121	1383A1	1732 300301	MIKHAIL PETROV	{"phone": "+70820825071"}
0005435007122	0603B2	2439 983769	OLESYA BORISOVA	{"phone": "+70780082612"}
0005435007123	158687	8146 314025	MIKHAIL NIKITIN	{"phone": "+70239207645"}
0005435007124	CDF72B	2196 950782	LYUBOV KOROLEVA	{"email": "lyubovkoroleva_041977@postgrespro.ru", "phone": "+70562954898"}
0005435007125	AC137C	3376 832757	DMITRIY GRIGOREV	{"email": "grigorev_d-1980@postgrespro.ru", "phone": "+70165966651"}
0005435007126	5BFA97	5289 172690	IRINA GRISHINA	{"email": "i_grishina.011978@postgrespro.ru", "phone": "+70202209684"}
0005435007127	64322A	4305 741423	VLADIMIR CHERNOV	{"phone": "+70668165862"}
0005435007128	890BCE	6416 154510	ANTONINA BORISOVA	{"phone": "+70905891241"}
0005435007129	890BCE	4610 913110	MARINA BELOVA	{"email": "belova-marina.19051969@postgrespro.ru", "phone": "+70369286902"}
0005435007130	9A1F56	8516 717025	IGOR KISELEV	{"phone": "+70569013534"}
0005435007131	B256D2	0675 915168	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr.01011976@postgrespro.ru", "phone": "+70009099927"}
0005435007132	B256D2	6958 585022	KLAVDIYA MARTYNOVA	{"phone": "+70922264827"}
0005435007133	2C4263	9400 240536	VALENTINA VASILEVA	{"phone": "+70604095280"}
0005435007134	8A1EE9	1486 796985	GALINA GRISHINA	{"email": "grishina_galina091970@postgrespro.ru", "phone": "+70058137013"}
0005435007135	075448	9527 747260	VALENTIN KAZAKOV	{"phone": "+70339732902"}
0005435007136	075448	7423 289227	ARINA SOROKINA	{"phone": "+70498877155"}
0005435007137	AE51BB	8280 313342	VLADISLAV BELOV	{"email": "vladislav.belov_021972@postgrespro.ru", "phone": "+70635454195"}
0005435007138	577A56	6746 555568	VIKTOR VOROBEV	{"email": "v.vorobev.071977@postgrespro.ru", "phone": "+70119617857"}
0005435007139	A960E0	5642 759935	ANATOLIY KUZNECOV	{"email": "kuznecov.a_071972@postgrespro.ru", "phone": "+70662998533"}
0005435007140	B78591	5758 997772	ROMAN STEPANOV	{"email": "stepanov_r-1978@postgrespro.ru", "phone": "+70982297557"}
0005435007141	D9C85B	6225 577550	OKSANA AFANASEVA	{"email": "o-afanaseva_091974@postgrespro.ru", "phone": "+70019038801"}
0005435007142	3CC824	7015 229869	LARISA OSIPOVA	{"email": "osipova-larisa_05011966@postgrespro.ru", "phone": "+70652194997"}
0005435007143	9FBFD6	9299 284563	GALINA ERMAKOVA	{"phone": "+70666426615"}
0005435007144	319B17	3915 337403	MATVEY RODIONOV	{"email": "rodionov.m.1973@postgrespro.ru", "phone": "+70335764622"}
0005435007145	F4EF37	1019 582794	ROMAN KULIKOV	{"phone": "+70247530535"}
0005435007146	EB70F4	9676 195837	VARVARA NAZAROVA	{"email": "varvaranazarova.1972@postgrespro.ru", "phone": "+70246516522"}
0005435007147	EB70F4	7222 902324	VADIM PETROV	{"phone": "+70083737830"}
0005435007148	F3FA6F	9734 722448	KRISTINA FROLOVA	{"email": "frolova.kristina_21031958@postgrespro.ru", "phone": "+70692647552"}
0005435007149	F3FA6F	3249 424452	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-a.071967@postgrespro.ru", "phone": "+70560799812"}
0005435007150	F3FA6F	3726 256325	MIKHAIL ZHUKOV	{"email": "m.zhukov.06071976@postgrespro.ru", "phone": "+70281564288"}
0005435007151	98E275	4186 094944	ALEKSEY FILIPPOV	{"phone": "+70772692629"}
0005435007152	1B6330	2162 162571	VIKTORIYA RODIONOVA	{"email": "v_rodionova29061978@postgrespro.ru", "phone": "+70603527359"}
0005435007153	1B6330	4201 459711	SVETLANA ARKHIPOVA	{"phone": "+70697037247"}
0005435007154	0185B1	6336 571740	VLADISLAV ILIN	{"phone": "+70378041618"}
0005435007155	0185B1	1159 489884	KSENIYA KAZAKOVA	{"email": "kazakova_k-25051973@postgrespro.ru", "phone": "+70781455930"}
0005435007156	BDCC65	9258 655282	NATALYA SMIRNOVA	{"phone": "+70334771030"}
0005435007157	BDCC65	2628 943375	VALENTINA KOLESNIKOVA	{"email": "v.kolesnikova-011964@postgrespro.ru", "phone": "+70601086023"}
0005435007158	D4CE12	8653 914241	OLESYA VASILEVA	{"phone": "+70815005273"}
0005435007159	23D8D2	1890 046295	EVGENIY POPOV	{"email": "popov-evgeniy-121973@postgrespro.ru", "phone": "+70622696810"}
0005435007160	23D8D2	3736 281549	LYUDMILA ALEKSANDROVA	{"phone": "+70407153691"}
0005435007161	BE8599	3004 587956	ELIZAVETA ANDREEVA	{"email": "andreeva.e-011984@postgrespro.ru", "phone": "+70689501591"}
0005435007162	B4893C	9500 155006	SERGEY ZHUKOV	{"email": "szhukov051976@postgrespro.ru", "phone": "+70051814221"}
0005435007163	A432ED	5847 050539	IVAN FROLOV	{"email": "i.frolov_011975@postgrespro.ru", "phone": "+70750994767"}
0005435007164	1825AC	0924 968504	MAKSIM POPOV	{"phone": "+70014068530"}
0005435007165	999E8D	2293 954594	DARYA ANDREEVA	{"email": "andreevadarya-21021974@postgrespro.ru", "phone": "+70962258655"}
0005435007166	999E8D	4429 486564	ELENA GUSEVA	{"email": "elena-guseva1978@postgrespro.ru", "phone": "+70574871287"}
0005435007167	718430	7464 652916	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr-101978@postgrespro.ru", "phone": "+70428955099"}
0005435007168	AFDB7E	9214 408659	ALEKSEY DENISOV	{"email": "denisov.aleksey_1977@postgrespro.ru", "phone": "+70962652167"}
0005435007169	714110	6392 739427	YULIYA MOROZOVA	{"phone": "+70998091437"}
0005435007170	714110	7898 518569	GLEB VOROBEV	{"phone": "+70943542217"}
0005435007171	57691D	9118 864491	RINAT POPOV	{"phone": "+70653140038"}
0005435007172	6D8B84	5976 192691	OKSANA ZOTOVA	{"email": "o.zotova.011981@postgrespro.ru", "phone": "+70067011434"}
0005435007173	EE1859	3987 502818	GALINA FOMINA	{"phone": "+70595200971"}
0005435007174	EE1859	6090 706872	VALENTINA LUKYANOVA	{"email": "lukyanovavalentina1968@postgrespro.ru", "phone": "+70371870925"}
0005435007175	F79620	9890 084129	NADEZHDA KUZNECOVA	{"email": "n.kuznecova04091964@postgrespro.ru", "phone": "+70635743050"}
0005435007176	F79620	3863 347603	ALEKSANDR GERASIMOV	{"email": "aleksandr.gerasimov.08091975@postgrespro.ru", "phone": "+70733143484"}
0005435007177	537F84	6091 570221	VLADIMIR GUSEV	{"email": "gusev-v_031980@postgrespro.ru", "phone": "+70889544429"}
0005435007178	07E668	1789 503654	OLGA KISELEVA	{"email": "o.kiseleva_111973@postgrespro.ru", "phone": "+70438460179"}
0005435007179	07E668	7522 397757	ANATOLIY EGOROV	{"email": "egorov_anatoliy061979@postgrespro.ru", "phone": "+70782760600"}
0005435007180	51A530	1825 042415	ALIYA FOMINA	{"phone": "+70864826433"}
0005435007181	51A530	3264 050351	ANATOLIY CHERNOV	{"phone": "+70627866010"}
0005435007182	D8F37C	9000 400457	ELENA MELNIKOVA	{"phone": "+70539236407"}
0005435007183	C212D9	6314 352814	ELENA SOKOLOVA	{"email": "sokolovaelena.1977@postgrespro.ru", "phone": "+70261441627"}
0005435007184	9064C9	2284 702467	VYACHESLAV KUZMIN	{"phone": "+70778610988"}
0005435007185	EB7C67	7638 896507	EDUARD SOROKIN	{"email": "eduard.sorokin_1969@postgrespro.ru", "phone": "+70756759104"}
0005435007186	8C205B	1916 540920	VLADIMIR ALEKSEEV	{"phone": "+70640259735"}
0005435007187	3E2ABB	1309 789591	OLESYA KONDRATEVA	{"email": "kondrateva-olesya061979@postgrespro.ru", "phone": "+70947404523"}
0005435007188	3E2ABB	9942 989482	NATALYA ZAYCEVA	{"email": "zayceva.n_1963@postgrespro.ru", "phone": "+70323908369"}
0005435007189	421369	4612 645111	SVETLANA KUZMINA	{"phone": "+70516509956"}
0005435007190	DE9B71	1863 717391	VLADIMIR SMIRNOV	{"phone": "+70425571265"}
0005435007191	DA2DA5	6581 122069	VLADIMIR FEDOTOV	{"phone": "+70922975476"}
0005435007192	DA2DA5	4815 439241	LYUBOV ZAKHAROVA	{"phone": "+70998150356"}
0005435007193	DA2DA5	5601 770840	IVAN VASILEV	{"phone": "+70406188392"}
0005435007194	DA2DA5	5725 472051	GALINA ILINA	{"phone": "+70442826247"}
0005435007195	ABEE4B	2738 753206	LYUDMILA FILIPPOVA	{"phone": "+70275613826"}
0005435007196	CF2F9A	3905 951207	VASILIY FEDOROV	{"phone": "+70568252390"}
0005435007197	042F4D	0224 442841	LYUBOV SIDOROVA	{"email": "lyubovsidorova1976@postgrespro.ru", "phone": "+70329388893"}
0005435007198	FBFE00	9661 054557	ANASTASIYA BORISOVA	{"phone": "+70433597775"}
0005435007199	FBFE00	5913 666196	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova-21021972@postgrespro.ru", "phone": "+70725268854"}
0005435007200	FBFE00	3801 794686	EGOR IVANOV	{"email": "ivanov_e-13051977@postgrespro.ru", "phone": "+70093453053"}
0005435007201	21C140	0410 619351	NIKOLAY SIDOROV	{"email": "sidorov_nikolay-13101968@postgrespro.ru", "phone": "+70023681065"}
0005435007202	8DA649	9983 972974	NIKITA STEPANOV	{"email": "stepanov-n-19051970@postgrespro.ru", "phone": "+70592998179"}
0005435007203	3453D1	9018 468915	VLADISLAV ZAYCEV	{"email": "zaycev.vladislav1967@postgrespro.ru", "phone": "+70422022844"}
0005435007204	3453D1	2346 782477	ANNA ALEKSANDROVA	{"email": "anna.aleksandrova05041971@postgrespro.ru", "phone": "+70685079353"}
0005435007205	71EDF1	1340 243773	MARINA STEPANOVA	{"email": "mstepanova.30091968@postgrespro.ru", "phone": "+70422282005"}
0005435007206	2C0964	3937 924925	ANNA MAKAROVA	{"email": "makarova-a-1977@postgrespro.ru", "phone": "+70692130933"}
0005435007207	601EB7	5647 091206	BORIS KULIKOV	{"phone": "+70922324941"}
0005435007208	380A27	7083 207689	GLEB FOMIN	{"email": "g_fomin1973@postgrespro.ru", "phone": "+70324723119"}
0005435007209	560450	6876 449340	LARISA SOROKINA	{"email": "sorokina.larisa_1965@postgrespro.ru", "phone": "+70129323025"}
0005435007210	560450	0639 726469	SERGEY IVANOV	{"phone": "+70804225859"}
0005435007211	CE8352	4567 084003	VLADIMIR SEMENOV	{"phone": "+70637315721"}
0005435007212	3855BA	7374 717352	ALEKSEY DMITRIEV	{"email": "dmitriev-a101985@postgrespro.ru", "phone": "+70530144331"}
0005435007213	C7114C	7955 924614	MARIYA ALEKSEEVA	{"email": "mariya_alekseeva-07041976@postgrespro.ru", "phone": "+70411414074"}
0005435007214	C7114C	1355 874868	VLADIMIR BONDARENKO	{"phone": "+70133415703"}
0005435007215	1AA0D6	6598 161068	FEDOR BARANOV	{"email": "f_baranov.051975@postgrespro.ru", "phone": "+70542206541"}
0005435007216	E04167	4811 061985	VLADIMIR SMIRNOV	{"phone": "+70945075209"}
0005435007217	B0A0F0	1734 899717	SERGEY IVANOV	{"email": "ivanov_s-15071976@postgrespro.ru", "phone": "+70945459766"}
0005435007218	B0A0F0	8747 626659	RAMIL BELOV	{"email": "belov_ramil.061976@postgrespro.ru", "phone": "+70081712000"}
0005435007219	574C94	2833 961423	DMITRIY ANDREEV	{"phone": "+70785554577"}
0005435007220	0E826C	8548 069423	VLADIMIR VLASOV	{"phone": "+70502393524"}
0005435007221	C92715	3476 841061	EVGENIYA VOLKOVA	{"email": "volkova_evgeniya.111975@postgrespro.ru", "phone": "+70397421642"}
0005435007222	C92715	3149 908790	EVGENIY SERGEEV	{"email": "e.sergeev.1975@postgrespro.ru", "phone": "+70774513375"}
0005435007223	748A10	5382 786704	TATYANA BORISOVA	{"phone": "+70013086277"}
0005435007224	84BE3E	4379 235945	LADA KOZLOVA	{"phone": "+70681052266"}
0005435007225	29D85B	2736 010559	NIKOLAY ORLOV	{"email": "orlov.n08081973@postgrespro.ru", "phone": "+70707600171"}
0005435007226	29D85B	4859 467630	MARIYA EGOROVA	{"email": "egorova_m-18031979@postgrespro.ru", "phone": "+70468373312"}
0005435007227	60E670	2600 076424	VIKTORIYA ERMAKOVA	{"phone": "+70362334003"}
0005435007228	D56E67	7619 378231	GALINA NIKIFOROVA	{"email": "nikiforova-galina14051964@postgrespro.ru", "phone": "+70345515145"}
0005435007229	D82822	0817 102695	MARIYA ABRAMOVA	{"phone": "+70740432563"}
0005435007230	F8D4B8	8702 856598	LYUBOV DENISOVA	{"email": "l-denisova-011964@postgrespro.ru", "phone": "+70751705826"}
0005435007231	F8D4B8	9328 339701	VALENTINA ABRAMOVA	{"phone": "+70008404354"}
0005435007232	2EC8B0	8958 706880	GENNADIY ZAYCEV	{"email": "g-zaycev_1971@postgrespro.ru", "phone": "+70157042278"}
0005435007233	56C1D3	2289 754417	ZOYA FROLOVA	{"email": "zoya.frolova_1960@postgrespro.ru", "phone": "+70415301782"}
0005435007234	5374A0	3994 949698	ANATOLIY KUZMIN	{"phone": "+70055467835"}
0005435007235	A39BB4	1093 469934	VLADISLAV PETROV	{"email": "petrov_vladislav_1974@postgrespro.ru", "phone": "+70316935487"}
0005435007236	769B13	5995 033372	SVETLANA KOVALEVA	{"phone": "+70504142036"}
0005435007237	4A3593	0530 433112	SVETLANA NIKIFOROVA	{"email": "nikiforova.svetlana.061972@postgrespro.ru", "phone": "+70605526814"}
0005435007238	4A3593	5905 148331	ANNA KUZNECOVA	{"email": "kuznecova_anna.1976@postgrespro.ru", "phone": "+70741389471"}
0005435007239	3932DE	8594 867027	IVAN KRASNOV	{"email": "ivankrasnov-1963@postgrespro.ru", "phone": "+70810203074"}
0005435007240	3932DE	9006 290953	EVGENIY SEMENOV	{"phone": "+70702689664"}
0005435007241	9F2093	9398 540494	DARINA AFANASEVA	{"phone": "+70760904348"}
0005435007242	775529	0270 184187	DANIIL AFANASEV	{"email": "d.afanasev_11031974@postgrespro.ru", "phone": "+70986923468"}
0005435007243	775529	6233 889619	MARIYA ALEKSEEVA	{"email": "m.alekseeva101970@postgrespro.ru", "phone": "+70813374445"}
0005435007244	F9AA4C	9352 796623	YURIY VOROBEV	{"email": "y-vorobev-1981@postgrespro.ru", "phone": "+70764682512"}
0005435007245	F9AA4C	1599 860489	VLADIMIR ZAKHAROV	{"email": "zakharov-v.24061961@postgrespro.ru", "phone": "+70236014826"}
0005435007246	1ECD50	1292 789125	RAFAIL NAZAROV	{"phone": "+70536514013"}
0005435007247	1ECD50	5631 428494	ULYANA KUZNECOVA	{"email": "ulyana-kuznecova_061985@postgrespro.ru", "phone": "+70262892357"}
0005435007248	1ECD50	6585 451160	MARIYA NAZAROVA	{"email": "mariya_nazarova.13031971@postgrespro.ru", "phone": "+70662507040"}
0005435007249	F9D8AC	5396 404562	MARIYA ZAYCEVA	{"email": "m-zayceva_1970@postgrespro.ru", "phone": "+70205481630"}
0005435007250	12B886	1355 628116	SVETLANA MAKAROVA	{"email": "makarovasvetlana.071980@postgrespro.ru", "phone": "+70963454145"}
0005435007251	42CF98	8194 403262	ZINAIDA ISAEVA	{"email": "z-isaeva.31121977@postgrespro.ru", "phone": "+70863707641"}
0005435007252	7620B9	1666 614223	VIKTOR ZAKHAROV	{"phone": "+70474884477"}
0005435007253	1F2AB9	5642 646802	ALEKSEY DMITRIEV	{"email": "a-dmitriev-29051970@postgrespro.ru", "phone": "+70379728714"}
0005435007254	CA257E	2259 512609	YURIY NIKOLAEV	{"email": "nikolaev-yuriy101970@postgrespro.ru", "phone": "+70022923388"}
0005435007255	10ACE5	7754 959003	VIKTORIYA KOVALEVA	{"phone": "+70127731976"}
0005435007256	10ACE5	1972 350264	TATYANA LOGINOVA	{"phone": "+70843235761"}
0005435007257	10ACE5	0586 977779	EVGENIY NAUMOV	{"phone": "+70519682281"}
0005435007258	E9DF8E	2089 467833	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr-14031975@postgrespro.ru", "phone": "+70757159813"}
0005435007259	81F921	7637 343194	EVDOKIYA SOROKINA	{"email": "sorokinae-28081976@postgrespro.ru", "phone": "+70451533525"}
0005435007260	CCAC7E	3014 423551	IVAN MIKHAYLOV	{"email": "ivan-mikhaylov-031977@postgrespro.ru", "phone": "+70211910606"}
0005435007261	CCAC7E	6986 288520	MAKSIM ALEKSEEV	{"phone": "+70528146907"}
0005435007262	98A861	5410 819092	EVDOKIYA PETROVA	{"email": "petrova-evdokiya20061956@postgrespro.ru", "phone": "+70855106600"}
0005435007263	3D8298	0275 787431	VALERIY SOROKIN	{"email": "valeriysorokin.1978@postgrespro.ru", "phone": "+70979187908"}
0005435007264	EA38C1	9428 669847	ANDREY PAVLOV	{"phone": "+70635338258"}
0005435007265	EA38C1	9868 410707	VARVARA KAZAKOVA	{"phone": "+70799526441"}
0005435007266	EA38C1	1161 877815	ANNA BOGDANOVA	{"email": "anna_bogdanova.091975@postgrespro.ru", "phone": "+70868332040"}
0005435007267	A4A723	6755 744540	VALENTINA NOVIKOVA	{"email": "novikova.v_1982@postgrespro.ru", "phone": "+70322104849"}
0005435007268	132484	1670 898269	LYUDMILA BELYAEVA	{"phone": "+70937835842"}
0005435007269	7BE852	2846 438676	ANDREY ZAYCEV	{"phone": "+70827968494"}
0005435007270	02B32E	6966 822711	VIKTOR NIKOLAEV	{"email": "nikolaev.v25101973@postgrespro.ru", "phone": "+70609197703"}
0005435007271	02B32E	2439 761489	ALEKSANDR EGOROV	{"email": "egorov.aleksandr_031975@postgrespro.ru", "phone": "+70180110515"}
0005435007272	DFA354	9787 574616	ANASTASIYA MASLOVA	{"email": "anastasiya-maslova_091977@postgrespro.ru", "phone": "+70870007788"}
0005435007273	6B2F31	1329 363956	NADEZHDA FILATOVA	{"phone": "+70116189716"}
0005435007274	A8E1DB	7598 120284	KONSTANTIN GERASIMOV	{"email": "konstantin-gerasimov111980@postgrespro.ru", "phone": "+70986704582"}
0005435007275	A8E1DB	9161 845746	MATVEY EGOROV	{"phone": "+70221854344"}
0005435007276	9910F9	1740 869540	ANASTASIYA MARTYNOVA	{"email": "martynova.anastasiya.1966@postgrespro.ru", "phone": "+70196241822"}
0005435007277	E4C995	3801 975743	VIKTOR POPOV	{"phone": "+70183875240"}
0005435007278	004C90	2744 012178	STANISLAV MOISEEV	{"phone": "+70953725228"}
0005435007279	004C90	0198 004838	GALINA EFIMOVA	{"email": "galinaefimova_111976@postgrespro.ru", "phone": "+70809323604"}
0005435007280	E90670	0783 156419	ILNUR FEDOROV	{"phone": "+70948145643"}
0005435007281	E90670	2862 044598	IRINA SCHERBAKOVA	{"phone": "+70038736700"}
0005435007282	7DBDA7	7127 757788	MARINA GORBUNOVA	{"email": "gorbunova_m-031972@postgrespro.ru", "phone": "+70778988874"}
0005435007283	7DBDA7	1104 286626	DMITRIY BELOV	{"email": "belovdmitriy.20021975@postgrespro.ru", "phone": "+70026495206"}
0005435007284	141063	2565 700939	LYUDMILA ANTONOVA	{"phone": "+70152570709"}
0005435007285	617809	2665 184253	ANDREY STEPANOV	{"phone": "+70723756307"}
0005435007286	617809	2272 055993	DMITRIY GUSEV	{"phone": "+70263383104"}
0005435007287	67737C	9805 093818	YULIYA FROLOVA	{"phone": "+70835476975"}
0005435007288	9C8B73	0000 435585	VASILIY FEDOROV	{"phone": "+70169897864"}
0005435007289	8E9EB2	2948 974913	YANA KUZNECOVA	{"phone": "+70743617821"}
0005435007290	8E9EB2	0556 301097	DENIS SOROKIN	{"email": "sorokind1965@postgrespro.ru", "phone": "+70320898245"}
0005435007291	235A56	7780 491437	SERGEY YAKOVLEV	{"phone": "+70022546481"}
0005435007292	235A56	3280 728306	YAKOV KISELEV	{"phone": "+70139436049"}
0005435007293	957B89	9413 694481	ELENA SAVELEVA	{"email": "elena_saveleva_121971@postgrespro.ru", "phone": "+70461957706"}
0005435007294	5F0CBA	9770 616092	TATYANA KUZNECOVA	{"phone": "+70407130642"}
0005435007295	5F0CBA	8725 867324	DMITRIY OSIPOV	{"email": "osipovdmitriy-04051977@postgrespro.ru", "phone": "+70679714158"}
0005435007296	5F0CBA	1511 488780	DINA TIMOFEEVA	{"email": "d-timofeeva.1973@postgrespro.ru", "phone": "+70541962972"}
0005435007297	5468CD	8742 778638	ALEKSANDR POPOV	{"phone": "+70906101286"}
0005435007298	FE569C	9602 583930	EKATERINA FILIPPOVA	{"email": "ekaterinafilippova1962@postgrespro.ru", "phone": "+70258619422"}
0005435007299	FE569C	8755 611655	VALERIYA IVANOVA	{"phone": "+70000199945"}
0005435007300	E2ACBE	7071 043239	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov051967@postgrespro.ru", "phone": "+70184562150"}
0005435007301	593E69	5760 687472	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov21111978@postgrespro.ru", "phone": "+70627546574"}
0005435007302	F84A37	5312 548396	NINA OVCHINNIKOVA	{"email": "nina-ovchinnikova_081972@postgrespro.ru", "phone": "+70846485860"}
0005435007303	2D6E70	9409 971732	YULIYA MARTYNOVA	{"email": "ymartynova_081975@postgrespro.ru", "phone": "+70390051726"}
0005435007304	73C6F7	6065 619536	ARINA KUZNECOVA	{"email": "arina.kuznecova_08061969@postgrespro.ru", "phone": "+70089132934"}
0005435007305	7CDEDB	4462 678885	DANIL KUZNECOV	{"email": "danil-kuznecov.25041980@postgrespro.ru", "phone": "+70667317299"}
0005435007306	E93E2B	8272 308113	YURIY VOROBEV	{"email": "y.vorobev-1973@postgrespro.ru", "phone": "+70990368716"}
0005435007307	DF9ED2	2213 895860	ZHANNA MIRONOVA	{"phone": "+70447213058"}
0005435007308	5797B7	6200 508126	VALENTINA MATVEEVA	{"email": "vmatveeva-111969@postgrespro.ru", "phone": "+70559209935"}
0005435007309	5797B7	6951 356188	MIKHAIL KONOVALOV	{"email": "mikhail_konovalov111974@postgrespro.ru", "phone": "+70867639602"}
0005435007310	B033B3	0943 932647	MARGARITA BOGDANOVA	{"email": "m-bogdanova-03031963@postgrespro.ru", "phone": "+70316627633"}
0005435007311	B033B3	4501 908511	VALENTIN KUZMIN	{"phone": "+70219706059"}
0005435007312	B033B3	9304 836102	NATALYA ANTONOVA	{"phone": "+70837521374"}
0005435007313	753E42	6266 347955	SVETLANA ROMANOVA	{"email": "romanova-svetlana-1989@postgrespro.ru", "phone": "+70873706981"}
0005435007314	753E42	9512 069551	ALLA KONDRATEVA	{"phone": "+70238467421"}
0005435007315	1E8922	1716 296105	DARYA GERASIMOVA	{"phone": "+70929468031"}
0005435007316	42B9D7	0653 028155	OLGA FILATOVA	{"phone": "+70013458758"}
0005435007317	476A1D	2531 267902	VALENTINA TIKHONOVA	{"phone": "+70319644165"}
0005435007318	D36686	4131 096554	EVGENIY BONDARENKO	{"phone": "+70527235072"}
0005435007319	67D542	5899 189245	SVETLANA MELNIKOVA	{"phone": "+70417608780"}
0005435007320	8F49E2	5220 392570	VLADIMIR SERGEEV	{"email": "v-sergeev-021969@postgrespro.ru", "phone": "+70068220840"}
0005435007321	8F49E2	5092 697585	ANDREY PAVLOV	{"phone": "+70136619344"}
0005435007322	C9B844	4974 552930	LYUBOV MARTYNOVA	{"email": "l-martynova1975@postgrespro.ru", "phone": "+70751866080"}
0005435007323	869348	4397 183185	NINA ZAKHAROVA	{"email": "ninazakharova.10051971@postgrespro.ru", "phone": "+70360642391"}
0005435007324	351D25	7490 486900	YULIYA LAZAREVA	{"phone": "+70518718800"}
0005435007325	DA067B	6521 931582	ANATOLIY MEDVEDEV	{"phone": "+70803705737"}
0005435007326	B9E4DD	1766 008311	ALEKSANDR CHERNOV	{"phone": "+70110406686"}
0005435007327	BBF52A	4397 609383	YURIY SERGEEV	{"email": "sergeev-y09091967@postgrespro.ru", "phone": "+70869770454"}
0005435007328	BBF52A	9208 495168	EVGENIY FEDOROV	{"email": "fedorov_evgeniy051972@postgrespro.ru", "phone": "+70580537805"}
0005435007329	28EA29	3866 626760	YULIYA VOLKOVA	{"phone": "+70168152597"}
0005435007330	BEAD62	8315 375889	VALENTINA ISAEVA	{"email": "isaevavalentina-12101959@postgrespro.ru", "phone": "+70754734136"}
0005435007331	F902B7	9562 858416	ELZA ZAYCEVA	{"phone": "+70081899265"}
0005435007332	F99D89	3479 630823	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov.1975@postgrespro.ru", "phone": "+70350250341"}
0005435007333	663A63	6326 901545	VERA MAKSIMOVA	{"email": "vera-maksimova_061985@postgrespro.ru", "phone": "+70943824556"}
0005435007334	633140	1473 759710	MIKHAIL ABRAMOV	{"email": "abramov.mikhail_1967@postgrespro.ru", "phone": "+70415933730"}
0005435007335	00E9D6	3826 047266	INNA DAVYDOVA	{"email": "i_davydova22081972@postgrespro.ru", "phone": "+70807163804"}
0005435007336	7DE450	3710 493864	TATYANA VOLKOVA	{"phone": "+70343472134"}
0005435007337	0B6CD2	7807 638914	GALINA RODIONOVA	{"phone": "+70212614398"}
0005435007338	1563F8	0258 430028	GALINA MIRONOVA	{"phone": "+70767002168"}
0005435007339	84A0CD	6979 876214	VLADIMIR KAZAKOV	{"phone": "+70500827971"}
0005435007340	84A0CD	1762 675943	ALEKSANDR POPOV	{"email": "a_popov_1982@postgrespro.ru", "phone": "+70891122384"}
0005435007341	4AC299	1918 396187	SVETLANA VOLKOVA	{"email": "svetlanavolkova1965@postgrespro.ru", "phone": "+70663725633"}
0005435007342	4AC299	0549 162895	ANASTASIYA KUZNECOVA	{"phone": "+70983138306"}
0005435007343	3974DB	4064 389668	ANNA ROMANOVA	{"email": "a.romanova22051970@postgrespro.ru", "phone": "+70617923597"}
0005435007344	3974DB	2663 352804	ANNA ZAKHAROVA	{"email": "a.zakharova-15101983@postgrespro.ru", "phone": "+70416080419"}
0005435007345	BD334C	7997 314501	SVETLANA EFREMOVA	{"phone": "+70903224682"}
0005435007346	DD998F	0608 782340	VALERIYA IVANOVA	{"phone": "+70418766418"}
0005435007347	2FFF29	9529 373160	ELIZAVETA DENISOVA	{"email": "elizaveta_denisova24061968@postgrespro.ru", "phone": "+70617550929"}
0005435007348	2FFF29	6993 852330	DMITRIY NIKITIN	{"email": "dmitriy_nikitin.1969@postgrespro.ru", "phone": "+70558904263"}
0005435007349	7CA8F1	3074 905169	VLADIMIR KUZNECOV	{"email": "v-kuznecov.081978@postgrespro.ru", "phone": "+70587430310"}
0005435007350	7CA8F1	5704 174250	VERONIKA MAKAROVA	{"email": "makarovav-111965@postgrespro.ru", "phone": "+70900861767"}
0005435007351	30AA16	9522 000197	RENATA EGOROVA	{"email": "renata_egorova07011963@postgrespro.ru", "phone": "+70279143966"}
0005435007352	36BAA3	2224 880297	SERGEY MOISEEV	{"phone": "+70904427484"}
0005435007353	36BAA3	2597 871410	ALEKSANDR ANDREEV	{"email": "andreev-a.1962@postgrespro.ru", "phone": "+70501819707"}
0005435007354	78F399	1473 059193	TATYANA POPOVA	{"phone": "+70173981119"}
0005435007355	7BE19C	2059 245341	VIKTOR KUZNECOV	{"phone": "+70376989038"}
0005435007356	7BE19C	2352 395297	OLEG ZAYCEV	{"email": "o-zaycev_061979@postgrespro.ru", "phone": "+70299779245"}
0005435007357	8D43A4	3989 854585	NIKOLAY SAVELEV	{"phone": "+70982562316"}
0005435007358	FA92EC	8630 343700	LYUDMILA OSIPOVA	{"email": "l.osipova1963@postgrespro.ru", "phone": "+70358464040"}
0005435007359	C4F46C	3970 777732	MIKHAIL ABRAMOV	{"email": "m_abramov_14091983@postgrespro.ru", "phone": "+70949721620"}
0005435007360	BCB930	7287 182538	KIRILL PETROV	{"phone": "+70314908709"}
0005435007361	BCB930	4059 790435	EKATERINA KUZNECOVA	{"phone": "+70520187967"}
0005435007362	F5A480	7610 121969	RAFAIL KOZLOV	{"email": "kozlov-r.18081972@postgrespro.ru", "phone": "+70508982172"}
0005435007363	F5A480	6897 259016	ELLA ALEKSEEVA	{"email": "alekseeva_e-031968@postgrespro.ru", "phone": "+70044914191"}
0005435007364	33F1BC	3897 318386	MARINA ORLOVA	{"email": "orlova.marina08021979@postgrespro.ru", "phone": "+70358877221"}
0005435007365	33F1BC	0095 165900	TAMARA KONOVALOVA	{"email": "konovalova_tamara1971@postgrespro.ru", "phone": "+70382725477"}
0005435007366	33F1BC	1170 724350	ANTONINA KARPOVA	{"phone": "+70335746499"}
0005435007367	9B5775	8406 696886	NINA GRISHINA	{"phone": "+70572453873"}
0005435007368	81156A	9850 352851	VITALIY GAVRILOV	{"email": "gavrilov_v121982@postgrespro.ru", "phone": "+70082751524"}
0005435007369	181E64	6713 537801	TATYANA ZAYCEVA	{"phone": "+70036918338"}
0005435007370	AA266B	8874 711786	IRINA SEMENOVA	{"phone": "+70918830549"}
0005435007371	80141D	1274 065967	KLAVDIYA SOKOLOVA	{"email": "klavdiya.sokolova1963@postgrespro.ru", "phone": "+70497760373"}
0005435007372	7918F7	8120 619260	ELENA MAKAROVA	{"email": "elena.makarova25031988@postgrespro.ru", "phone": "+70737087784"}
0005435007373	079EC2	0242 665568	NINA KUZNECOVA	{"phone": "+70015780996"}
0005435007374	079EC2	1445 438314	EKATERINA SERGEEVA	{"email": "sergeeva.e_111974@postgrespro.ru", "phone": "+70372775910"}
0005435007375	A5B304	8770 087851	ALENA VASILEVA	{"email": "vasilevaa051964@postgrespro.ru", "phone": "+70501129840"}
0005435007376	824105	6886 766815	KRISTINA SERGEEVA	{"email": "sergeeva.k07041962@postgrespro.ru", "phone": "+70593177266"}
0005435007377	824105	8697 450066	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr.111971@postgrespro.ru", "phone": "+70574691595"}
0005435007378	48338C	0652 592590	ALEKSEY SOROKIN	{"email": "a-sorokin061971@postgrespro.ru", "phone": "+70902328070"}
0005435007379	3B92AB	7603 717961	YURIY DAVYDOV	{"email": "y.davydov1970@postgrespro.ru", "phone": "+70866870004"}
0005435007380	8FE64B	8966 131843	MARIYA TIMOFEEVA	{"email": "m-timofeeva021976@postgrespro.ru", "phone": "+70270748284"}
0005435007381	527413	9152 096982	GALINA PETROVA	{"phone": "+70022927605"}
0005435007382	649A20	9558 877359	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov1980@postgrespro.ru", "phone": "+70743742953"}
0005435007383	649A20	1544 709765	EVGENIY VOROBEV	{"email": "evorobev-081975@postgrespro.ru", "phone": "+70618410066"}
0005435007384	3C0160	2011 900250	DENIS ISAEV	{"phone": "+70894145530"}
0005435007385	3C0160	8046 417979	VLADIMIR CHERNOV	{"phone": "+70827002470"}
0005435007386	6AC18F	0663 706490	DMITRIY KUZMIN	{"email": "kuzmindmitriy_24011964@postgrespro.ru", "phone": "+70494611217"}
0005435007387	A461C8	6786 267300	VYACHESLAV FROLOV	{"phone": "+70235520168"}
0005435007388	A461C8	0950 439349	EVGENIY FROLOV	{"email": "frolov_evgeniy_051980@postgrespro.ru", "phone": "+70370223737"}
0005435007389	B49005	7281 755166	VIKTOR POPOV	{"email": "popov-viktor_06011965@postgrespro.ru", "phone": "+70931235961"}
0005435007390	B49005	4707 995835	LIDIYA ILINA	{"phone": "+70906825799"}
0005435007391	9648EF	3847 340377	VLADIMIR VASILEV	{"phone": "+70394882808"}
0005435007392	C6CC6D	4154 282859	LYUDMILA KONOVALOVA	{"email": "l-konovalova.061965@postgrespro.ru", "phone": "+70025384529"}
0005435007393	661323	2576 628280	ALEKSANDRA ILINA	{"phone": "+70781603441"}
0005435007394	661323	3067 202718	VLADIMIR MAKSIMOV	{"phone": "+70178866900"}
0005435007395	075FCE	0591 612228	STANISLAV SOROKIN	{"email": "sorokin.s111961@postgrespro.ru", "phone": "+70144300725"}
0005435007396	075FCE	3864 643774	ELIZAVETA KONOVALOVA	{"email": "konovalova.e.051979@postgrespro.ru", "phone": "+70759214435"}
0005435007397	63B044	1958 812191	TATYANA ANDREEVA	{"phone": "+70751366583"}
0005435007398	424D5F	0227 745991	SERGEY GUSEV	{"email": "s.gusev_05071974@postgrespro.ru", "phone": "+70547915204"}
0005435007399	83B930	1234 214992	VADIM BELOV	{"phone": "+70971357121"}
0005435007400	83B930	4024 821704	VALERIY DAVYDOV	{"phone": "+70071583546"}
0005435007401	CE69EC	4121 705469	MARIYA FILIPPOVA	{"email": "filippovam_091971@postgrespro.ru", "phone": "+70570457537"}
0005435007402	A03244	4488 776509	MARIYA SAVELEVA	{"email": "mariya_saveleva_091970@postgrespro.ru", "phone": "+70240904462"}
0005435007403	A03244	6562 861812	VLADIMIR NIKITIN	{"email": "v-nikitin-28071969@postgrespro.ru", "phone": "+70443333917"}
0005435007404	1BFE7A	1117 435828	VLADIMIR FILIPPOV	{"phone": "+70972060290"}
0005435007405	032BF8	5618 941236	EVGENIY POPOV	{"phone": "+70078809162"}
0005435007406	0C6DAD	4407 735332	VIKTOR TIMOFEEV	{"phone": "+70647873412"}
0005435007407	0C6DAD	1464 141281	ANATOLIY FOMIN	{"email": "anatoliy-fomin03061976@postgrespro.ru", "phone": "+70084385442"}
0005435007408	ADAE9A	6213 081845	NINA KRASNOVA	{"email": "nina-krasnova.081980@postgrespro.ru", "phone": "+70281843533"}
0005435007409	744FCB	1329 866465	VLADIMIR KUZMIN	{"email": "kuzmin.v-1972@postgrespro.ru", "phone": "+70728873805"}
0005435007410	744FCB	3587 368643	ARINA ZHUKOVA	{"email": "arina_zhukova-091980@postgrespro.ru", "phone": "+70905409440"}
0005435007411	C5CE7D	1496 208566	ANASTASIYA MATVEEVA	{"email": "anastasiyamatveeva_071972@postgrespro.ru", "phone": "+70143605889"}
0005435007412	C5CE7D	1041 999989	OLGA MELNIKOVA	{"email": "melnikovaolga_1968@postgrespro.ru", "phone": "+70647700310"}
0005435007413	3E48C1	3989 932317	ZINAIDA NIKIFOROVA	{"email": "nikiforovaz.1972@postgrespro.ru", "phone": "+70783077172"}
0005435007414	359318	1506 079119	ANASTASIYA KONOVALOVA	{"email": "anastasiya.konovalova_29111969@postgrespro.ru", "phone": "+70970597835"}
0005435007415	C2AA96	4774 215966	VLADISLAV ISAEV	{"phone": "+70819534190"}
0005435007416	C2AA96	7392 125884	GALINA GAVRILOVA	{"email": "g_gavrilova121969@postgrespro.ru", "phone": "+70740418780"}
0005435007417	730649	6980 393589	ELENA MAKAROVA	{"phone": "+70440755610"}
0005435007418	63F98E	6181 144425	OLEG IVANOV	{"email": "ivanov_o_041963@postgrespro.ru", "phone": "+70825662966"}
0005435007419	FFEC6A	8389 378663	PAVEL ANDREEV	{"email": "pavel.andreev_1968@postgrespro.ru", "phone": "+70101801500"}
0005435007420	3417B5	2316 098008	ALEKSANDRA STEPANOVA	{"email": "stepanova-a1961@postgrespro.ru", "phone": "+70470849738"}
0005435007421	D214F9	1546 783405	MARINA IVANOVA	{"email": "marinaivanova041976@postgrespro.ru", "phone": "+70944466199"}
0005435007422	BA69D5	4629 150303	LYUBOV KONOVALOVA	{"email": "konovalova_l.06121974@postgrespro.ru", "phone": "+70918281140"}
0005435007423	CCA35D	3851 497622	MARINA KUZNECOVA	{"email": "kuznecova_marina-1982@postgrespro.ru", "phone": "+70342715348"}
0005435007424	CCA35D	8019 813656	GALINA SERGEEVA	{"email": "sergeeva_galina.081981@postgrespro.ru", "phone": "+70880980390"}
0005435007425	CCA35D	3786 270547	KIRILL PETROV	{"email": "petrov-kirill-011974@postgrespro.ru", "phone": "+70215207735"}
0005435007426	4CFAA8	2475 494924	LYUBOV NAUMOVA	{"email": "lyubovnaumova_1973@postgrespro.ru", "phone": "+70692439075"}
0005435007427	05F36A	6026 218334	ANDREY FILIPPOV	{"email": "a-filippov_091966@postgrespro.ru", "phone": "+70489573039"}
0005435007428	8701D8	9144 119216	VLADIMIR GUSEV	{"email": "v-gusev031971@postgrespro.ru", "phone": "+70953143742"}
0005435007429	8701D8	2210 758457	ANNA KAZAKOVA	{"email": "a_kazakova081979@postgrespro.ru", "phone": "+70429696204"}
0005435007430	6CDA3B	5543 037423	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr_011975@postgrespro.ru", "phone": "+70128937390"}
0005435007431	2F014C	7638 797269	MARGARITA EFREMOVA	{"phone": "+70083304905"}
0005435007612	948883	3189 544139	VALERIY ALEKSEEV	{"phone": "+70699733029"}
0005435007432	E69D08	1873 153343	TATYANA SCHERBAKOVA	{"email": "scherbakova.tatyana.10041969@postgrespro.ru", "phone": "+70918099663"}
0005435007433	95C2C4	1793 379475	ALEKSEY ORLOV	{"phone": "+70047331670"}
0005435007434	95C2C4	3777 642779	VASILIY MELNIKOV	{"email": "melnikov_vasiliy20021984@postgrespro.ru", "phone": "+70835177597"}
0005435007435	35FECF	3546 485659	NATALYA VOROBEVA	{"email": "vorobevan051984@postgrespro.ru", "phone": "+70549535756"}
0005435007436	00D1F7	3844 788435	VLADIMIR MAKAROV	{"phone": "+70416095154"}
0005435007437	232A5C	5461 673377	SERGEY NOVIKOV	{"phone": "+70377561035"}
0005435007438	39E81B	2398 609687	PAVEL MOROZOV	{"email": "morozov-pavel03011969@postgrespro.ru", "phone": "+70197281596"}
0005435007439	58382D	6188 987796	NIKITA MAKSIMOV	{"phone": "+70152966123"}
0005435007440	CDBDDC	2549 002714	ALEKSEY TIMOFEEV	{"phone": "+70486506272"}
0005435007441	4856EE	4539 626742	ANVAR KAZAKOV	{"phone": "+70329701837"}
0005435007442	42631F	3972 783383	NIKOLAY MELNIKOV	{"email": "nikolay.melnikov.101966@postgrespro.ru", "phone": "+70060437446"}
0005435007443	04A582	3017 849913	ARSENIY VASILEV	{"phone": "+70220119352"}
0005435007444	04A582	7597 569344	EVGENIY ALEKSANDROV	{"email": "ealeksandrov_1970@postgrespro.ru", "phone": "+70104134645"}
0005435007445	7431DE	0047 722719	RINAT SIDOROV	{"email": "rinat_sidorov091968@postgrespro.ru", "phone": "+70820848602"}
0005435007446	82D2EF	8211 384058	MAKSIM MARTYNOV	{"phone": "+70418383923"}
0005435007447	63FEBC	8068 928630	ALEKSANDR IVANOV	{"phone": "+70844312219"}
0005435007448	D64563	1369 863679	NINA LAZAREVA	{"email": "n.lazareva_07121970@postgrespro.ru", "phone": "+70442712190"}
0005435007449	9AF2CA	7708 899876	LYUDMILA BELOVA	{"email": "l_belova.021967@postgrespro.ru", "phone": "+70112515104"}
0005435007450	9889FF	8322 058263	IGOR SERGEEV	{"email": "sergeev_i_071977@postgrespro.ru", "phone": "+70927706153"}
0005435007451	0A4AAB	5183 129959	NIKOLAY ABRAMOV	{"email": "nikolay-abramov.121978@postgrespro.ru", "phone": "+70357612399"}
0005435007452	0A4AAB	4309 914052	VLADIMIR BORISOV	{"email": "vladimir.borisov1966@postgrespro.ru", "phone": "+70087258620"}
0005435007453	288F74	7162 213838	VLADISLAV MIKHAYLOV	{"email": "mikhaylov_vladislav.03071960@postgrespro.ru", "phone": "+70556939295"}
0005435007454	94577C	5475 010181	NIKOLAY FROLOV	{"email": "frolov.n09021967@postgrespro.ru", "phone": "+70221013712"}
0005435007455	EB334F	7129 668811	GALINA TITOVA	{"phone": "+70951692478"}
0005435007456	EB334F	8466 197516	NATALYA ORLOVA	{"phone": "+70697848631"}
0005435007457	A175C3	1707 404442	RENAT DENISOV	{"phone": "+70727725093"}
0005435007458	0F7305	0152 282553	NIKOLAY VASILEV	{"phone": "+70566285428"}
0005435007459	0F7305	9392 703389	ANATOLIY MEDVEDEV	{"phone": "+70850973548"}
0005435007460	4A1A94	9836 322955	ALEKSANDR KISELEV	{"email": "kiselev-aleksandr.1968@postgrespro.ru", "phone": "+70156745438"}
0005435007461	4A1A94	4732 796313	VLADISLAV ORLOV	{"email": "orlov-v-1974@postgrespro.ru", "phone": "+70235680887"}
0005435007462	CFF305	5872 734706	FEDOR POPOV	{"email": "f_popov-1975@postgrespro.ru", "phone": "+70752309883"}
0005435007463	CFF305	8670 044520	NADEZHDA GERASIMOVA	{"email": "n.gerasimova-1970@postgrespro.ru", "phone": "+70576674128"}
0005435007464	1A82D1	5707 700533	MATRENA FOMINA	{"phone": "+70117641787"}
0005435007465	60850C	4707 069042	IGOR TIKHONOV	{"email": "i_tikhonov-26101966@postgrespro.ru", "phone": "+70598068767"}
0005435007466	60850C	6336 796531	EKATERINA KISELEVA	{"email": "ekaterina_kiseleva061974@postgrespro.ru", "phone": "+70599607125"}
0005435007467	19115D	8215 026924	IGOR NIKOLAEV	{"email": "nikolaev-igor_1987@postgrespro.ru", "phone": "+70787894692"}
0005435007468	732AFF	8963 726812	ARSENIY RODIONOV	{"email": "arseniy_rodionov1975@postgrespro.ru", "phone": "+70756744437"}
0005435007469	732AFF	5017 437029	SERGEY VOLKOV	{"email": "volkov.sergey121972@postgrespro.ru", "phone": "+70616288853"}
0005435007470	2D28ED	6403 545738	ALEKSEY IVANOV	{"phone": "+70644397832"}
0005435007471	2D28ED	1619 196102	YURIY SEMENOV	{"email": "yuriy.semenov-29071970@postgrespro.ru", "phone": "+70333416017"}
0005435007472	F5EE23	6189 742806	VARVARA ROMANOVA	{"email": "romanovavarvara.1983@postgrespro.ru", "phone": "+70199521945"}
0005435007473	5DEA3F	3354 220041	ELENA IVANOVA	{"phone": "+70052099078"}
0005435007474	090D51	9069 613764	MARINA OSIPOVA	{"email": "osipova_marina-23101978@postgrespro.ru", "phone": "+70467985853"}
0005435007475	090D51	5431 169730	EVGENIY TIMOFEEV	{"phone": "+70877715879"}
0005435007476	D8A914	5421 481887	SERGEY NAZAROV	{"email": "sergey_nazarov-031976@postgrespro.ru", "phone": "+70263909780"}
0005435007477	D8A914	1586 573906	ALEKSANDR FROLOV	{"phone": "+70548607769"}
0005435007478	B36EA9	5263 586210	ANDREY BORISOV	{"phone": "+70134368671"}
0005435007479	B36EA9	0595 693007	GALINA LUKYANOVA	{"phone": "+70131592501"}
0005435007480	1C5ECC	8414 511764	IGOR IVANOV	{"phone": "+70358632243"}
0005435007481	A29B36	4574 734483	VIKTOR MARTYNOV	{"email": "viktor-martynov-111968@postgrespro.ru", "phone": "+70206309048"}
0005435007482	A29B36	2277 706540	LYUDMILA KOLESNIKOVA	{"phone": "+70981249727"}
0005435007483	4AEC2A	0134 298543	ALISA CHERNOVA	{"email": "chernovaalisa-26011972@postgrespro.ru", "phone": "+70746319680"}
0005435007484	986564	3261 918463	GALINA NOVIKOVA	{"phone": "+70478579097"}
0005435007485	2754E5	2686 872623	TATYANA IVANOVA	{"phone": "+70749707049"}
0005435007486	7F9990	0932 722649	KONSTANTIN POPOV	{"phone": "+70911377576"}
0005435007487	7F9990	4650 156576	LYUBOV DENISOVA	{"phone": "+70096728184"}
0005435007488	B8441C	8933 991337	IRINA KONDRATEVA	{"email": "irina_kondrateva_06041984@postgrespro.ru", "phone": "+70989294560"}
0005435007489	B8441C	8355 605887	ALEKSEY SEMENOV	{"email": "semenova_011980@postgrespro.ru", "phone": "+70374509825"}
0005435007490	880C1B	1281 039495	LYUDMILA BARANOVA	{"email": "l_baranova_1972@postgrespro.ru", "phone": "+70145317056"}
0005435007491	79BE8A	3598 322957	IVAN POPOV	{"email": "ivan_popov-1969@postgrespro.ru", "phone": "+70487888677"}
0005435007492	79BE8A	8157 767385	ANASTASIYA SCHERBAKOVA	{"email": "scherbakovaanastasiya04031981@postgrespro.ru", "phone": "+70752500783"}
0005435007493	B806E9	7380 101369	DENIS TIMOFEEV	{"email": "timofeev.denis.17121969@postgrespro.ru", "phone": "+70014155247"}
0005435007494	B806E9	8987 072303	OLEG DMITRIEV	{"phone": "+70661410008"}
0005435007495	B806E9	7454 892908	EVGENIY MOROZOV	{"phone": "+70606265802"}
0005435007496	B806E9	0296 699604	SERGEY KUZNECOV	{"phone": "+70119853208"}
0005435007497	360F4F	1197 511080	VIKTOR IVANOV	{"phone": "+70616375578"}
0005435007498	D11728	1776 399684	SERGEY NOVIKOV	{"phone": "+70654181430"}
0005435007499	99D321	1797 557139	DMITRIY SAVELEV	{"email": "d-savelev_041971@postgrespro.ru", "phone": "+70527505087"}
0005435007500	7DBB01	7471 686601	IRINA FROLOVA	{"phone": "+70736189534"}
0005435007501	4523D0	0862 748303	YURIY ANDREEV	{"phone": "+70163251628"}
0005435007502	0BCEDE	1171 187175	ANTON SIDOROV	{"phone": "+70757106430"}
0005435007503	A276F0	6763 979955	RAMIL IVANOV	{"email": "ivanovr_19111979@postgrespro.ru", "phone": "+70547957609"}
0005435007504	11C490	7270 104039	ALESYA MELNIKOVA	{"phone": "+70588535386"}
0005435007505	7EAD03	5972 042373	ALEKSEY NOVIKOV	{"email": "aleksey_novikov1964@postgrespro.ru", "phone": "+70056228387"}
0005435007506	DC7747	8070 462397	TATYANA KUZNECOVA	{"phone": "+70337220166"}
0005435007507	8C43E0	3727 003212	BORIS MEDVEDEV	{"phone": "+70205380332"}
0005435007508	3405EC	8169 173681	VIKTOR ORLOV	{"phone": "+70029114729"}
0005435007509	3405EC	8538 213928	ANZHELIKA KOVALEVA	{"email": "anzhelika_kovaleva.22021979@postgrespro.ru", "phone": "+70403843166"}
0005435007510	A845A1	4576 317165	ANASTASIYA KULIKOVA	{"phone": "+70453397531"}
0005435007511	A845A1	6708 623287	VALERIY SIDOROV	{"email": "valeriy-sidorov1970@postgrespro.ru", "phone": "+70169256841"}
0005435007512	7F8D89	5616 245900	ANNA LUKYANOVA	{"email": "lukyanova-a051971@postgrespro.ru", "phone": "+70847440809"}
0005435007513	DCF762	3208 530201	VALERIY MOROZOV	{"email": "v.morozov021978@postgrespro.ru", "phone": "+70550510322"}
0005435007514	DCF762	6890 892489	VIKTORIYA KUZNECOVA	{"email": "viktoriya_kuznecova-1969@postgrespro.ru", "phone": "+70330526958"}
0005435007515	DCF762	7091 101397	ELENA SERGEEVA	{"email": "sergeeva.elena02011974@postgrespro.ru", "phone": "+70784517579"}
0005435007516	CD043A	0975 107869	POLINA LOGINOVA	{"phone": "+70414772839"}
0005435007517	8C8E18	6929 800276	ANASTASIYA KAZAKOVA	{"email": "kazakova_anastasiya1976@postgrespro.ru", "phone": "+70716599233"}
0005435007518	03876E	5324 656011	OLGA ROMANOVA	{"phone": "+70188150826"}
0005435007519	119D6F	1835 972282	IRINA NESTEROVA	{"email": "nesterova-irina_1966@postgrespro.ru", "phone": "+70800710607"}
0005435007520	119D6F	3260 887533	SVETLANA BORISOVA	{"phone": "+70756760598"}
0005435007521	119D6F	8005 747740	LYUDMILA FROLOVA	{"phone": "+70301319415"}
0005435007522	80F28F	0570 708006	MAKSIM SEMENOV	{"email": "semenov_maksim_11031966@postgrespro.ru", "phone": "+70214765969"}
0005435007523	485D1B	3055 214493	ZHANNA SMIRNOVA	{"phone": "+70484039707"}
0005435007524	267801	1650 545587	OKSANA IVANOVA	{"email": "ivanova-o.03061971@postgrespro.ru", "phone": "+70011221803"}
0005435007525	235386	8187 201100	TATYANA BELYAEVA	{"email": "tbelyaeva_03121979@postgrespro.ru", "phone": "+70784782961"}
0005435007526	949E5E	6790 082779	RUSLAN NOVIKOV	{"phone": "+70911293398"}
0005435007527	6C8DF2	6882 160901	ALLA TROFIMOVA	{"email": "a.trofimova.031968@postgrespro.ru", "phone": "+70912003249"}
0005435007528	FCC543	3544 657696	DANIIL SOLOVEV	{"email": "solovev.d05061978@postgrespro.ru", "phone": "+70737581200"}
0005435007529	FCC543	1390 127720	DINA KOROLEVA	{"phone": "+70181881943"}
0005435007530	EEF355	8439 852786	ALEKSANDR RODIONOV	{"email": "rodionov_aleksandr1959@postgrespro.ru", "phone": "+70099446754"}
0005435007531	E32912	0790 535248	ANNA TIKHONOVA	{"email": "atikhonova-011958@postgrespro.ru", "phone": "+70513734492"}
0005435007532	324831	1623 069038	ANASTASIYA DANILOVA	{"phone": "+70224992939"}
0005435007533	6D8C35	3827 196360	IRINA MIKHAYLOVA	{"email": "i-mikhaylova1981@postgrespro.ru", "phone": "+70794729188"}
0005435007534	4064C3	2100 419482	SERGEY PAVLOV	{"email": "sergey.pavlov1966@postgrespro.ru", "phone": "+70209303058"}
0005435007535	DE6499	1316 201074	MIKHAIL KUZNECOV	{"email": "mikhail-kuznecov041974@postgrespro.ru", "phone": "+70188254968"}
0005435007536	51C76E	7864 785573	NIKOLAY VASILEV	{"email": "vasilev_nikolay29101970@postgrespro.ru", "phone": "+70578801643"}
0005435007537	51C76E	2296 760167	NIKOLAY OSIPOV	{"phone": "+70628284671"}
0005435007538	D8004C	7976 583212	ALEKSANDR BONDARENKO	{"phone": "+70727678381"}
0005435007539	2524B6	4777 180249	TATYANA MATVEEVA	{"email": "t_matveeva-051981@postgrespro.ru", "phone": "+70628589928"}
0005435007540	FFF840	2454 543472	TAMARA POPOVA	{"phone": "+70868989208"}
0005435007541	D030F2	2234 136792	ANTON VASILEV	{"email": "antonvasilev-21081980@postgrespro.ru", "phone": "+70008403446"}
0005435007542	D030F2	3683 578471	SERGEY MAKSIMOV	{"phone": "+70311372223"}
0005435007543	508B2E	2541 879459	ANNA IVANOVA	{"email": "a_ivanova071974@postgrespro.ru", "phone": "+70218962978"}
0005435007544	37E65E	9944 434837	VLADIMIR FROLOV	{"email": "frolovv041965@postgrespro.ru", "phone": "+70858764274"}
0005435007545	1FEAF9	6661 552166	SVETLANA ANDREEVA	{"email": "andreeva-s.101981@postgrespro.ru", "phone": "+70225956019"}
0005435007546	F631E6	2470 248780	NIKOLAY DAVYDOV	{"email": "davydov-nikolay_10061975@postgrespro.ru", "phone": "+70255266011"}
0005435007547	50995C	2893 482655	NATALYA ROMANOVA	{"email": "natalya_romanova-17111972@postgrespro.ru", "phone": "+70810285008"}
0005435007548	7611E2	6406 891989	ELENA POTAPOVA	{"phone": "+70641790401"}
0005435007549	6295E1	5769 347690	MIKHAIL MIKHAYLOV	{"phone": "+70291334611"}
0005435007550	485068	5126 549491	ANDREY STEPANOV	{"email": "stepanova-25081974@postgrespro.ru", "phone": "+70554690742"}
0005435007551	371C98	1551 569706	MARINA KONDRATEVA	{"phone": "+70996328992"}
0005435007552	965B4B	1659 652117	NATALYA ALEKSEEVA	{"email": "alekseeva.n16081971@postgrespro.ru", "phone": "+70863042227"}
0005435007553	B6D419	4446 805134	ELENA POTAPOVA	{"email": "elena.potapova_04041970@postgrespro.ru", "phone": "+70783316944"}
0005435007554	C6C7E1	2987 905080	ALINA IVANOVA	{"email": "ivanova_a091976@postgrespro.ru", "phone": "+70730043628"}
0005435007555	E4B0E1	8735 986767	TATYANA DENISOVA	{"phone": "+70547378320"}
0005435007556	E4B0E1	3253 682617	STANISLAV ZHURAVLEV	{"phone": "+70558267443"}
0005435007557	A7F3C5	2438 157573	DMITRIY ILIN	{"phone": "+70623769539"}
0005435007558	8B734A	9045 146923	VLADISLAV POPOV	{"phone": "+70600514985"}
0005435007559	A088C0	7365 314470	ZINAIDA KAZAKOVA	{"email": "kazakovaz16111966@postgrespro.ru", "phone": "+70891301263"}
0005435007560	B7E976	5707 122088	VLADIMIR DMITRIEV	{"phone": "+70206540880"}
0005435007561	B7E976	0867 265231	OLGA IVANOVA	{"phone": "+70052134902"}
0005435007562	486EAA	1137 326888	ARTEM MELNIKOV	{"email": "artemmelnikov_1971@postgrespro.ru", "phone": "+70605951782"}
0005435007563	CA7621	2628 628560	LYUDMILA NESTEROVA	{"email": "nesterova-lyudmila-041968@postgrespro.ru", "phone": "+70367550918"}
0005435007564	392CEB	0127 199156	MARIYA POPOVA	{"phone": "+70377873657"}
0005435007565	1A60DF	5658 635012	ANNA VOROBEVA	{"email": "vorobeva_anna_071977@postgrespro.ru", "phone": "+70322070278"}
0005435007566	F89541	3787 044915	VERA VOLKOVA	{"phone": "+70675472556"}
0005435007567	F89541	8467 120933	IGOR FEDOROV	{"phone": "+70698098811"}
0005435007568	F89541	0811 806455	VLADIMIR BARANOV	{"email": "baranov_vladimir.1974@postgrespro.ru", "phone": "+70305397298"}
0005435007569	2C9B95	2550 334748	NINA ZAKHAROVA	{"phone": "+70417790648"}
0005435007570	85908B	1131 286858	DMITRIY PAVLOV	{"email": "dmitriy.pavlov_051972@postgrespro.ru", "phone": "+70746835409"}
0005435007571	85908B	8041 490361	YULIYA VOROBEVA	{"email": "yuliya-vorobeva.051971@postgrespro.ru", "phone": "+70712264344"}
0005435007572	90E33E	6083 678731	ROBERT KUZNECOV	{"email": "rkuznecov.26041968@postgrespro.ru", "phone": "+70567660658"}
0005435007573	400670	0539 261552	ALEKSANDRA EGOROVA	{"phone": "+70459821962"}
0005435007574	400670	8954 316364	ELENA CHERNOVA	{"email": "chernovae.051975@postgrespro.ru", "phone": "+70569572678"}
0005435007575	D5D67E	9815 914438	EGOR MOROZOV	{"email": "egor_morozov-08061972@postgrespro.ru", "phone": "+70081932047"}
0005435007576	D5D67E	3760 325060	ELENA MASLOVA	{"phone": "+70347795734"}
0005435007577	03F338	5420 477010	NATALYA PAVLOVA	{"email": "natalya-pavlova1968@postgrespro.ru", "phone": "+70829777615"}
0005435007578	5D259B	1328 342262	OLGA FEDOROVA	{"email": "olgafedorova.1975@postgrespro.ru", "phone": "+70951704150"}
0005435007579	42B0A6	7691 725128	ALEKSANDR MAKSIMOV	{"phone": "+70624880407"}
0005435007580	42B0A6	8237 807179	SERGEY IVANOV	{"phone": "+70172581249"}
0005435007581	1EAB37	3166 527971	OKSANA MAKAROVA	{"phone": "+70702583593"}
0005435007582	DF1402	5217 516647	ALBINA SEMENOVA	{"phone": "+70778401234"}
0005435007583	5F56C6	4716 451438	VIKTOR BORISOV	{"phone": "+70243316698"}
0005435007584	5AFB10	5030 573817	LYUDMILA RODIONOVA	{"phone": "+70252455280"}
0005435007585	5AFB10	2638 265373	KIRILL YAKOVLEV	{"email": "yakovlev-kirill_11101958@postgrespro.ru", "phone": "+70749087572"}
0005435007586	7405EC	1180 347281	TIMUR BONDARENKO	{"email": "bondarenko_timur_1975@postgrespro.ru", "phone": "+70974647605"}
0005435007587	7405EC	9839 177664	ALEKSANDR VOLKOV	{"phone": "+70752185002"}
0005435007588	7405EC	7291 856624	MARGARITA NIKITINA	{"email": "m-nikitina1975@postgrespro.ru", "phone": "+70747536989"}
0005435007589	0DF226	5607 163103	VALENTINA FOMINA	{"email": "valentina.fomina-04051976@postgrespro.ru", "phone": "+70175096550"}
0005435007590	38A907	8655 615162	ROMAN PETROV	{"phone": "+70543811444"}
0005435007591	AB70A4	5375 987774	ANASTASIYA NAUMOVA	{"phone": "+70523200401"}
0005435007592	AB70A4	9498 345625	TAMARA SERGEEVA	{"phone": "+70280563706"}
0005435007593	6B0A7F	3169 666877	SERGEY MOROZOV	{"email": "s.morozov_081975@postgrespro.ru", "phone": "+70087404349"}
0005435007594	88F6C2	6182 720435	VALENTINA NESTEROVA	{"phone": "+70393340936"}
0005435007595	E51149	5110 880914	VITALIY KAZAKOV	{"email": "kazakov.vitaliy1975@postgrespro.ru", "phone": "+70172088900"}
0005435007596	E51149	1886 867810	ILYA EGOROV	{"email": "egorov-ilya-1970@postgrespro.ru", "phone": "+70533763944"}
0005435007597	3945B8	6113 518237	NIKITA KOZLOV	{"email": "nikita_kozlov_1980@postgrespro.ru", "phone": "+70981650768"}
0005435007598	F82A93	6843 128864	VIKTOR PAVLOV	{"phone": "+70136964012"}
0005435007599	F82A93	5962 559647	VYACHESLAV PETROV	{"email": "v.petrov12061979@postgrespro.ru", "phone": "+70786223409"}
0005435007600	F82A93	1526 041779	ALEKSANDR MAKAROV	{"email": "makarovaleksandr_1969@postgrespro.ru", "phone": "+70286286350"}
0005435007601	7BE58A	3015 562172	MARIYA MOROZOVA	{"email": "morozova-m061973@postgrespro.ru", "phone": "+70731924735"}
0005435007602	7BE58A	9663 019592	NATALYA POPOVA	{"email": "popova.natalya.1979@postgrespro.ru", "phone": "+70889666859"}
0005435007603	7BE58A	8203 515121	ALEKSANDR KONOVALOV	{"phone": "+70932918180"}
0005435007604	8627A2	8439 622515	SVETLANA KALININA	{"email": "s_kalinina_28061974@postgrespro.ru", "phone": "+70699613863"}
0005435007605	546678	2593 075929	ILONA MOROZOVA	{"phone": "+70322556354"}
0005435007606	9681EA	6160 736399	OLEG ZAYCEV	{"phone": "+70677093744"}
0005435007607	0C03BD	6457 086366	EKATERINA MASLOVA	{"email": "maslovae.071968@postgrespro.ru", "phone": "+70223004393"}
0005435007608	0C03BD	9758 849461	YULIYA KUZNECOVA	{"phone": "+70318995057"}
0005435007609	822E15	6993 740621	EGOR ABRAMOV	{"email": "abramov.egor_051966@postgrespro.ru", "phone": "+70367680578"}
0005435007610	2C872F	2190 727991	ALEKSANDR FILIPPOV	{"phone": "+70661106349"}
0005435007611	2C872F	4177 576425	NATALIYA MAKAROVA	{"email": "nataliya_makarova101978@postgrespro.ru", "phone": "+70626616191"}
0005435007613	A05D3B	9740 956636	OLGA KUZNECOVA	{"email": "kuznecova.olga_29071969@postgrespro.ru", "phone": "+70560520788"}
0005435007614	A05D3B	4840 425089	VIKTORIYA SAVELEVA	{"phone": "+70780145038"}
0005435007615	EFD11C	8676 389367	MARINA SERGEEVA	{"email": "sergeevam.13011974@postgrespro.ru", "phone": "+70319963932"}
0005435007616	EFD11C	8839 761478	TATYANA POPOVA	{"email": "popovat-10051975@postgrespro.ru", "phone": "+70656505437"}
0005435007617	684BCE	0773 614827	MARIYA EFIMOVA	{"phone": "+70749255186"}
0005435007618	684BCE	8321 676249	OLGA LAZAREVA	{"email": "olgalazareva_1962@postgrespro.ru", "phone": "+70179955288"}
0005435007619	ED22BC	2294 398909	DMITRIY FEDOROV	{"email": "fedorov-dmitriy-1970@postgrespro.ru", "phone": "+70316954534"}
0005435007620	441C7C	5944 278227	IRINA POPOVA	{"email": "popova-irina26031971@postgrespro.ru", "phone": "+70284992871"}
0005435007621	441C7C	9729 640367	OLEG GUSEV	{"email": "gusev-oleg111967@postgrespro.ru", "phone": "+70416520375"}
0005435007622	77024E	1137 516414	OKSANA ALEKSEEVA	{"email": "oksana-alekseeva.06081979@postgrespro.ru", "phone": "+70925243789"}
0005435007623	EF0E95	9937 392037	TATYANA FOMINA	{"email": "tatyana_fomina.1975@postgrespro.ru", "phone": "+70413460710"}
0005435007624	EF0E95	4891 087863	SERGEY IVANOV	{"email": "ivanovsergey_071970@postgrespro.ru", "phone": "+70289563480"}
0005435007625	0FE710	3619 225424	ALEKSANDR IVANOV	{"phone": "+70239181520"}
0005435007626	92AB72	5208 077639	ZHANNA NIKITINA	{"email": "z_nikitina.1965@postgrespro.ru", "phone": "+70108171643"}
0005435007627	8D0E30	8814 432540	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov-25081978@postgrespro.ru", "phone": "+70468533484"}
0005435007628	5940E3	5615 272990	ALLA DAVYDOVA	{"email": "alla_davydova-031971@postgrespro.ru", "phone": "+70176136277"}
0005435007629	7B80E4	9022 232267	TAMARA ANISIMOVA	{"phone": "+70433720465"}
0005435007630	36180A	7035 877694	TATYANA ALEKSEEVA	{"phone": "+70393152112"}
0005435007631	C9A14B	1984 687976	ANATOLIY SERGEEV	{"phone": "+70222979043"}
0005435007632	E81B82	7660 788097	VLADIMIR DMITRIEV	{"phone": "+70881840552"}
0005435007633	ACB8B4	7298 927009	YURIY ANTONOV	{"phone": "+70228644400"}
0005435007634	3503C4	9500 947459	TATYANA SERGEEVA	{"email": "tatyana-sergeeva-09081978@postgrespro.ru", "phone": "+70741964005"}
0005435007635	6B6A31	4220 647917	ANTON IVANOV	{"email": "ivanovanton24101973@postgrespro.ru", "phone": "+70036147738"}
0005435007636	C002EC	1569 258364	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov121979@postgrespro.ru", "phone": "+70568371581"}
0005435007637	C002EC	7295 209869	SERGEY SOLOVEV	{"email": "solovevsergey.041982@postgrespro.ru", "phone": "+70426650436"}
0005435007638	50FDC6	7467 820710	NIKITA SCHERBAKOV	{"phone": "+70596564371"}
0005435007639	2C5A87	2982 778756	ANATOLIY KISELEV	{"phone": "+70914013459"}
0005435007640	2C5A87	3827 043007	MARAT ANTONOV	{"phone": "+70646683416"}
0005435007641	2C5A87	9507 489013	RINAT MAKSIMOV	{"email": "rinatmaksimov30071970@postgrespro.ru", "phone": "+70746500055"}
0005435007642	DA2D15	0359 556278	EVGENIYA EGOROVA	{"phone": "+70625234901"}
0005435007643	3BD462	3301 839679	OLGA SOLOVEVA	{"email": "soloveva.o-26101963@postgrespro.ru", "phone": "+70151369336"}
0005435007644	AD8AE1	9998 928027	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov-1979@postgrespro.ru", "phone": "+70578839915"}
0005435007645	57FA79	4318 484736	LYUDMILA SOROKINA	{"phone": "+70288745370"}
0005435007646	D5056C	6397 839563	INNA MIKHAYLOVA	{"email": "i_mikhaylova1959@postgrespro.ru", "phone": "+70897036159"}
0005435007647	98AE6B	8158 004708	SERGEY DAVYDOV	{"phone": "+70851677195"}
0005435007648	98AE6B	1089 160019	SERGEY KOZLOV	{"phone": "+70088536462"}
0005435007649	98AE6B	5130 398098	ALEKSANDR POPOV	{"email": "popovaleksandr06051976@postgrespro.ru", "phone": "+70721228187"}
0005435007650	A33376	1419 862498	DMITRIY KRASNOV	{"email": "d_krasnov.13111974@postgrespro.ru", "phone": "+70082082395"}
0005435007651	A33376	5216 495887	ALSU FILATOVA	{"phone": "+70615501121"}
0005435007652	EE325E	7686 528244	OKSANA NAUMOVA	{"email": "o_naumova.21081963@postgrespro.ru", "phone": "+70220262721"}
0005435007653	3C9C7B	2880 375570	DMITRIY SMIRNOV	{"email": "dmitriysmirnov01021967@postgrespro.ru", "phone": "+70827467263"}
0005435007654	3C9C7B	9141 385852	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova_051976@postgrespro.ru", "phone": "+70710954639"}
0005435007655	3C9C7B	1627 540393	VALENTINA ILINA	{"email": "v_ilina_17041986@postgrespro.ru", "phone": "+70446979983"}
0005435007656	282B06	5782 060116	OLGA EFIMOVA	{"email": "efimova.o-24011966@postgrespro.ru", "phone": "+70766079087"}
0005435007657	850E44	9859 897360	OLGA VLASOVA	{"email": "olga.vlasova.051979@postgrespro.ru", "phone": "+70732968756"}
0005435007658	850E44	5560 956225	LYUBOV KUZNECOVA	{"phone": "+70371286149"}
0005435007659	F44C4E	7833 233272	ANDREY KONOVALOV	{"phone": "+70949596309"}
0005435007660	44F55B	6557 816620	KARINA KOROLEVA	{"email": "koroleva-karina.1974@postgrespro.ru", "phone": "+70451530849"}
0005435007661	AAAAAF	6679 421791	ALEKSANDR MAKAROV	{"phone": "+70352310275"}
0005435007662	F40C49	1852 732854	VALENTINA KUDRYASHOVA	{"phone": "+70371129722"}
0005435007663	F72E68	4122 463319	NADEZHDA GORBUNOVA	{"email": "gorbunova_nadezhda.1968@postgrespro.ru", "phone": "+70320969449"}
0005435007664	43F7CF	5415 007184	SERGEY SCHERBAKOV	{"phone": "+70946247330"}
0005435007665	43F7CF	5039 411482	OLGA POTAPOVA	{"email": "olga.potapova.22021973@postgrespro.ru", "phone": "+70021995495"}
0005435007666	2532CB	9927 976600	YURIY KAZAKOV	{"email": "kazakov.y-1971@postgrespro.ru", "phone": "+70236673747"}
0005435007667	EAC42E	1268 708862	ELENA VOROBEVA	{"email": "elena-vorobeva_1964@postgrespro.ru", "phone": "+70978550970"}
0005435007668	EAC42E	1791 682553	MARIYA ALEKSANDROVA	{"phone": "+70546555327"}
0005435007669	C47F8B	0915 993036	IVAN BONDARENKO	{"email": "bondarenko_i031982@postgrespro.ru", "phone": "+70658401147"}
0005435007670	C47F8B	2688 932334	EDUARD IVANOV	{"phone": "+70906806742"}
0005435007671	C47F8B	3268 714081	ALEKSEY KOROLEV	{"phone": "+70188135585"}
0005435007672	4DC735	3323 461896	ANNA KISELEVA	{"phone": "+70830129971"}
0005435007673	8083CA	3919 314358	ANNA FILIPPOVA	{"phone": "+70038074894"}
0005435007674	6945FB	1537 085930	INESSA MAKSIMOVA	{"phone": "+70853503400"}
0005435007675	56D87B	4547 960080	ELENA IVANOVA	{"phone": "+70342259962"}
0005435007676	832D6C	8590 638253	DANILA SCHERBAKOV	{"email": "danila_scherbakov.14111969@postgrespro.ru", "phone": "+70241204672"}
0005435007677	5F9504	3363 002382	PAVEL MATVEEV	{"phone": "+70678063103"}
0005435007678	1A3388	8180 945736	VLADIMIR KRASNOV	{"phone": "+70155181951"}
0005435007679	6FBB3A	3349 846205	ALEKSEY ZAKHAROV	{"email": "a-zakharov-1970@postgrespro.ru", "phone": "+70169235041"}
0005435007680	682E14	7617 682950	NATALYA KAZAKOVA	{"email": "kazakovanatalya26041979@postgrespro.ru", "phone": "+70751041638"}
0005435007681	A7DAB8	7439 568422	NATALYA PETROVA	{"email": "petrova.natalya.1976@postgrespro.ru", "phone": "+70401450564"}
0005435007682	7501CC	4091 304975	KONSTANTIN TIKHONOV	{"phone": "+70460317075"}
0005435007683	7501CC	8824 084385	ALFIYA OVCHINNIKOVA	{"phone": "+70185314596"}
0005435007684	1BF668	9493 533117	OLEG KOZLOV	{"email": "okozlov28061986@postgrespro.ru", "phone": "+70505966479"}
0005435007685	1BF668	6238 246267	DARYA CHERNOVA	{"phone": "+70176988999"}
0005435007686	4DD6C8	9267 385216	ELENA IVANOVA	{"email": "ivanova-elena08071963@postgrespro.ru", "phone": "+70855285287"}
0005435007687	4DD6C8	8096 975980	ILMIR FOMIN	{"phone": "+70727043756"}
0005435007688	DA4911	4529 700203	RINAT KONOVALOV	{"email": "konovalovrinat-1984@postgrespro.ru", "phone": "+70356580470"}
0005435007689	14B0BE	7531 666430	VITALIY SHEVCHENKO	{"email": "shevchenko_vitaliy-011966@postgrespro.ru", "phone": "+70119836328"}
0005435007690	D06729	9015 019929	VLADIMIR GERASIMOV	{"phone": "+70431908101"}
0005435007691	D06729	6491 934684	ANATOLIY YAKOVLEV	{"email": "a_yakovlev.29051965@postgrespro.ru", "phone": "+70790272994"}
0005435007692	D931CB	4420 860879	LYUDMILA SOKOLOVA	{"phone": "+70080494255"}
0005435007693	CCA643	4491 577420	EVGENIY KRASNOV	{"phone": "+70599987292"}
0005435007694	CCA643	9918 359581	ANNA GERASIMOVA	{"email": "a.gerasimova_1980@postgrespro.ru", "phone": "+70551526322"}
0005435007695	9CA52F	2345 947392	KLAVDIYA KUZNECOVA	{"phone": "+70967739957"}
0005435007696	9CA52F	4934 125096	TATYANA FILATOVA	{"email": "t.filatova-071968@postgrespro.ru", "phone": "+70708652726"}
0005435007697	9CA52F	4845 914632	ANATOLIY OSIPOV	{"email": "aosipov-10031962@postgrespro.ru", "phone": "+70730908125"}
0005435007698	D3F8B9	0679 995398	GALINA BARANOVA	{"email": "g_baranova.1960@postgrespro.ru", "phone": "+70503396540"}
0005435007699	9CD785	7961 876419	VLADIMIR MOROZOV	{"phone": "+70395176508"}
0005435007700	BBC5C7	1755 525507	MATRENA IVANOVA	{"phone": "+70143273833"}
0005435007701	BBC5C7	8157 908858	NADEZHDA KONDRATEVA	{"phone": "+70768993169"}
0005435007702	BBC5C7	3966 694726	YULIYA VASILEVA	{"email": "yuliya_vasileva02011975@postgrespro.ru", "phone": "+70897799549"}
0005435007703	D39C99	8457 311053	ZOYA NIKOLAEVA	{"phone": "+70014822407"}
0005435007704	D8F699	3532 504609	YURIY KUZNECOV	{"phone": "+70802503823"}
0005435007705	D8F699	4381 007058	VLADIMIR FEDOROV	{"phone": "+70999001978"}
0005435007706	221A9E	3765 856628	ALENA GUSEVA	{"email": "guseva_alena_041977@postgrespro.ru", "phone": "+70138368322"}
0005435007707	1BDBA2	2732 241568	LYUDMILA KUZNECOVA	{"phone": "+70294145121"}
0005435007708	1BDBA2	5617 804254	MARINA RODIONOVA	{"phone": "+70496153080"}
0005435007709	B786DA	1960 145236	EVGENIY KOZLOV	{"phone": "+70569133844"}
0005435007710	B786DA	7685 725337	ELENA NAZAROVA	{"phone": "+70511792359"}
0005435007711	C6E94A	7650 076796	DANIYA NIKOLAEVA	{"email": "d-nikolaeva27041970@postgrespro.ru", "phone": "+70137870030"}
0005435007712	C6E94A	9434 343606	VALERIY SOLOVEV	{"phone": "+70814822560"}
0005435007713	DF6870	6183 176271	LYUDMILA SOKOLOVA	{"email": "sokolova.l1969@postgrespro.ru", "phone": "+70368880776"}
0005435007714	DF6870	9232 034276	IVAN ALEKSEEV	{"email": "ivan.alekseev-1979@postgrespro.ru", "phone": "+70990079582"}
0005435007715	7005F0	5711 513147	ANASTASIYA NIKITINA	{"email": "nikitina_a15011976@postgrespro.ru", "phone": "+70897633710"}
0005435007716	30F067	0938 892262	OLGA FADEEVA	{"phone": "+70968344254"}
0005435007717	30AA2B	7645 507984	ALEKSANDR MIRONOV	{"phone": "+70822426218"}
0005435007718	61BCA9	3641 284521	YURIY SMIRNOV	{"phone": "+70563485489"}
0005435007719	440E67	1292 871381	ALEKSANDR KISELEV	{"email": "a-kiselev121975@postgrespro.ru", "phone": "+70578078942"}
0005435007720	FBBB08	3431 655946	ALEKSANDR PETROV	{"phone": "+70986319135"}
0005435007721	EB2E2D	1682 879143	TATYANA RYABOVA	{"email": "tatyana_ryabova1970@postgrespro.ru", "phone": "+70190635448"}
0005435007722	EB2E2D	8915 530588	VERA PETROVA	{"email": "v_petrova02121962@postgrespro.ru", "phone": "+70651967079"}
0005435038709	B85EBF	3296 172524	ZINAIDA NIKOLAEVA	{"phone": "+70937403991"}
0005435038710	A21BFB	1335 496331	YULIYA NAZAROVA	{"phone": "+70920234010"}
0005435038610	7EFFB4	9431 161196	VLADIMIR SOROKIN	{"email": "sorokin.v_18081976@postgrespro.ru", "phone": "+70752526806"}
0005435038611	7EFFB4	7192 869644	ANNA FADEEVA	{"phone": "+70123542009"}
0005435038612	7EFFB4	8138 305088	SVETLANA LOGINOVA	{"email": "svetlana_loginova_1963@postgrespro.ru", "phone": "+70804507364"}
0005435038613	867696	8229 071537	YULIYA BORISOVA	{"phone": "+70714591458"}
0005435038614	797BC9	5264 429621	NATALYA NIKOLAEVA	{"phone": "+70381043643"}
0005435038615	797BC9	7967 620632	NINA DENISOVA	{"email": "n_denisova_021980@postgrespro.ru", "phone": "+70044700610"}
0005435038616	171A4A	4586 253138	SVETLANA MALYSHEVA	{"phone": "+70145198947"}
0005435038617	4F405F	5436 103074	OLGA SMIRNOVA	{"email": "o-smirnova_14091964@postgrespro.ru", "phone": "+70482951333"}
0005435038618	17F3EA	7310 274663	IRINA ZAYCEVA	{"phone": "+70757269304"}
0005435038619	17F3EA	3341 294567	VIKTORIYA TARASOVA	{"email": "tarasova_v.1965@postgrespro.ru", "phone": "+70546473879"}
0005435038620	17F3EA	9650 878723	MARIYA MATVEEVA	{"email": "matveeva_m.20061966@postgrespro.ru", "phone": "+70296534199"}
0005435038621	44C9A3	8042 578877	MAKSIM KOROLEV	{"email": "korolev.m18061969@postgrespro.ru", "phone": "+70248958430"}
0005435038622	44C9A3	6660 661003	IVAN BORISOV	{"email": "i.borisov27101976@postgrespro.ru", "phone": "+70700205207"}
0005435038623	0456D6	0884 509061	ALEKSANDR ABRAMOV	{"phone": "+70521376574"}
0005435038624	0456D6	8517 158404	EVGENIY ZAKHAROV	{"email": "zakharov-e_12071966@postgrespro.ru", "phone": "+70342917769"}
0005435038625	D6D97D	0167 058562	GALINA NIKITINA	{"email": "nikitina.galina_041968@postgrespro.ru", "phone": "+70104383205"}
0005435038626	A6DF27	7189 957742	ANTONINA GORBUNOVA	{"email": "gorbunova_a_111983@postgrespro.ru", "phone": "+70105634047"}
0005435038627	00F03D	0570 035232	DARYA IVANOVA	{"email": "d.ivanova19051977@postgrespro.ru", "phone": "+70592735480"}
0005435038628	907ACA	0749 659932	DARYA POLYAKOVA	{"email": "daryapolyakova.011971@postgrespro.ru", "phone": "+70939763235"}
0005435038629	907ACA	9806 342780	GENNADIY SOLOVEV	{"phone": "+70608220959"}
0005435038630	0879FA	0325 340517	TAMARA LOGINOVA	{"phone": "+70549467609"}
0005435038631	A68E57	0796 354436	ILDUS POPOV	{"phone": "+70879071373"}
0005435038632	DD3C8C	1881 159028	VALERIYA KONOVALOVA	{"email": "valeriya.konovalova_19011969@postgrespro.ru", "phone": "+70800891584"}
0005435038633	504759	5610 900751	VLADIMIR VOROBEV	{"email": "vorobev.v_01011978@postgrespro.ru", "phone": "+70238903319"}
0005435038634	DE118E	0394 091428	VADIM KUZNECOV	{"phone": "+70909362510"}
0005435038635	3D1CAA	9819 418188	NIKITA STEPANOV	{"email": "n_stepanov-021976@postgrespro.ru", "phone": "+70908734860"}
0005435038636	078A61	6211 982377	DARYA KOZLOVA	{"email": "dkozlova.30091967@postgrespro.ru", "phone": "+70459193950"}
0005435038637	821278	1638 955366	NATALYA VLASOVA	{"phone": "+70977090170"}
0005435038638	821278	2012 659029	MAKSIM KUZNECOV	{"phone": "+70338057658"}
0005435038639	16A07E	0951 879170	TATYANA KOMAROVA	{"phone": "+70799605799"}
0005435038640	84C6B1	1510 389933	GALINA ABRAMOVA	{"email": "galina_abramova_24101990@postgrespro.ru", "phone": "+70217388439"}
0005435038641	3E56D2	3771 323923	DMITRIY KAZAKOV	{"phone": "+70147221002"}
0005435038642	D6677E	1634 210403	YURIY IVANOV	{"phone": "+70953879428"}
0005435038643	EAB3DF	1616 105928	NIKOLAY PAVLOV	{"email": "nikolay.pavlov.04081970@postgrespro.ru", "phone": "+70251609118"}
0005435038644	55557E	8284 332681	ANDREY VOLKOV	{"phone": "+70669729403"}
0005435038645	DEE494	9192 584210	ALEKSANDR SOKOLOV	{"email": "sokolova081967@postgrespro.ru", "phone": "+70844827218"}
0005435038646	DEE494	3873 783236	VALENTINA KAZAKOVA	{"email": "kazakova_v_1974@postgrespro.ru", "phone": "+70954270296"}
0005435038647	437DDF	9623 496435	NINA FILATOVA	{"phone": "+70201917166"}
0005435038648	B33B70	0302 139803	EVGENIY ABRAMOV	{"email": "evgeniy-abramov.111982@postgrespro.ru", "phone": "+70727850570"}
0005435038649	B33B70	2576 724141	SVETLANA SEMENOVA	{"email": "semenova.s.011985@postgrespro.ru", "phone": "+70607945699"}
0005435038650	9D9E71	5224 298074	OLEG TARASOV	{"phone": "+70553651217"}
0005435038651	9D9E71	3575 813538	IRINA ANISIMOVA	{"email": "anisimova.irina_17091970@postgrespro.ru", "phone": "+70084646962"}
0005435038652	894182	9040 860788	YULIYA SAVELEVA	{"email": "saveleva_yuliya061967@postgrespro.ru", "phone": "+70497635340"}
0005435038653	894182	1078 480105	OKSANA MIKHAYLOVA	{"phone": "+70123344983"}
0005435038654	72F282	2028 904317	EVGENIY FROLOV	{"email": "frolov-evgeniy_091985@postgrespro.ru", "phone": "+70742557802"}
0005435038655	AEAEBD	6509 689044	SVYATOSLAV SMIRNOV	{"email": "ssmirnov_1979@postgrespro.ru", "phone": "+70667797591"}
0005435038656	AEAEBD	8033 398635	NIKITA POPOV	{"email": "popov-nikita_081980@postgrespro.ru", "phone": "+70764118290"}
0005435038657	849084	6906 575093	TAMARA KULIKOVA	{"email": "kulikova-tamara-1973@postgrespro.ru", "phone": "+70763114219"}
0005435038658	33581F	7334 026763	VITALIY FILIPPOV	{"phone": "+70060361359"}
0005435038659	33581F	2530 186124	ELDAR SOROKIN	{"email": "eldar_sorokin1979@postgrespro.ru", "phone": "+70115241215"}
0005435038660	2BAB9B	0723 491552	TATYANA ANTONOVA	{"email": "antonova_tatyana021978@postgrespro.ru", "phone": "+70833047376"}
0005435038661	41362B	2142 784984	ANNA ROMANOVA	{"phone": "+70536284924"}
0005435038662	2C724E	9110 707211	PAVEL KUZNECOV	{"email": "p.kuznecov_1972@postgrespro.ru", "phone": "+70206803892"}
0005435038663	A605D0	6567 690274	ALENA LUKYANOVA	{"email": "lukyanovaalena061978@postgrespro.ru", "phone": "+70001759752"}
0005435038664	D1A7F9	8333 927526	SVETLANA TIMOFEEVA	{"phone": "+70019099393"}
0005435038665	D1A7F9	2233 910747	LYUBOV PETROVA	{"email": "petrova.l-1967@postgrespro.ru", "phone": "+70589266258"}
0005435038666	A9B53A	5990 008449	DENIS BELOV	{"email": "d_belov24041975@postgrespro.ru", "phone": "+70616063829"}
0005435038667	6307B9	4077 520360	LARISA ANISIMOVA	{"email": "anisimova-larisa.1975@postgrespro.ru", "phone": "+70011870867"}
0005435038668	6307B9	3665 050501	DANIIL SEMENOV	{"email": "daniil-semenov1979@postgrespro.ru", "phone": "+70457152798"}
0005435038669	839987	6085 857509	LARISA GORBUNOVA	{"email": "larisagorbunova.27031977@postgrespro.ru", "phone": "+70442464865"}
0005435038670	B781B8	2027 384240	EVGENIYA MIRONOVA	{"email": "evgeniyamironova-1973@postgrespro.ru", "phone": "+70016367537"}
0005435038671	F3DD41	5387 168855	OLGA ORLOVA	{"phone": "+70562954695"}
0005435038672	685C48	0782 833784	RENAT KUZMIN	{"email": "kuzmin.r_1958@postgrespro.ru", "phone": "+70572176838"}
0005435038673	40533E	9973 033936	ALEKSANDR KUZNECOV	{"email": "akuznecov011965@postgrespro.ru", "phone": "+70894587680"}
0005435038674	40533E	3794 955002	MARIYA GRISHINA	{"email": "mariya_grishina1972@postgrespro.ru", "phone": "+70871527874"}
0005435038675	C6AB63	9553 272944	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov.1962@postgrespro.ru", "phone": "+70969182569"}
0005435038676	D1B5AE	3269 341658	MARINA KISELEVA	{"phone": "+70357112488"}
0005435038677	D1B5AE	2796 375003	KRISTINA SCHERBAKOVA	{"phone": "+70861206291"}
0005435038678	746289	0186 115161	ANTON MOROZOV	{"phone": "+70482037498"}
0005435038679	579BDD	0142 910489	SERGEY SMIRNOV	{"phone": "+70412128343"}
0005435038680	6A4885	9279 810289	LIDIYA FROLOVA	{"phone": "+70463593428"}
0005435038681	A5E796	0311 064208	NATALYA POPOVA	{"email": "natalya.popova-1962@postgrespro.ru", "phone": "+70698089796"}
0005435038682	974FB1	6764 415276	EKATERINA KARPOVA	{"phone": "+70326791941"}
0005435038683	77AFE0	2058 035077	NIKOLAY ANTONOV	{"email": "nikolayantonov121959@postgrespro.ru", "phone": "+70111622149"}
0005435038684	DAF4F9	3770 708697	MIKHAIL MOROZOV	{"email": "morozov-mikhail.011969@postgrespro.ru", "phone": "+70291290848"}
0005435038685	DAF4F9	7479 503610	LIDIYA MOROZOVA	{"email": "morozova_l.061980@postgrespro.ru", "phone": "+70431728607"}
0005435038686	2BAFB5	6838 212338	ROMAN POPOV	{"email": "romanpopov-12111975@postgrespro.ru", "phone": "+70623050183"}
0005435038687	CE26E1	8894 757302	NADEZHDA SEMENOVA	{"phone": "+70835282200"}
0005435038688	CE26E1	4639 486258	EGOR KUZNECOV	{"phone": "+70571712274"}
0005435038689	FC7F6B	8156 388074	RUSTAM KULIKOV	{"email": "kulikov.rustam.1966@postgrespro.ru", "phone": "+70448468037"}
0005435038690	D40655	7566 878957	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr.01081975@postgrespro.ru", "phone": "+70924398931"}
0005435038691	7DFE18	4238 182228	VALENTINA CHERNOVA	{"email": "chernovav-1981@postgrespro.ru", "phone": "+70361804646"}
0005435038692	7DFE18	2059 233799	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr.1976@postgrespro.ru", "phone": "+70478595873"}
0005435038693	7DFE18	5007 612876	VLADISLAV KULIKOV	{"phone": "+70185425595"}
0005435038694	A09DCB	8724 397274	PAVEL FEDOTOV	{"email": "fedotov.p.121975@postgrespro.ru", "phone": "+70566057675"}
0005435038695	A37B3F	6938 734548	MARINA POTAPOVA	{"email": "potapova_m101979@postgrespro.ru", "phone": "+70124590644"}
0005435038696	A37B3F	2784 359730	EKATERINA MIKHAYLOVA	{"phone": "+70480217024"}
0005435038697	3CBF8A	6266 348815	ALEKSEY SOROKIN	{"email": "sorokin.aleksey.111975@postgrespro.ru", "phone": "+70888459791"}
0005435038698	3CBF8A	3314 674982	IRINA MELNIKOVA	{"phone": "+70585283566"}
0005435038699	636624	9030 953115	TATYANA KOMAROVA	{"email": "tatyana.komarova051968@postgrespro.ru", "phone": "+70104921318"}
0005435038700	EC5717	0481 296904	MARIYA FILIPPOVA	{"phone": "+70761501771"}
0005435038701	EC5717	7909 075348	ELENA FOMINA	{"phone": "+70704035122"}
0005435038702	2DA489	6285 482520	ALEKSEY VLASOV	{"phone": "+70009592010"}
0005435038703	E7EE81	9838 101644	VLADIMIR ZAKHAROV	{"email": "zakharov_v_1979@postgrespro.ru", "phone": "+70055597405"}
0005435038704	901B30	8789 386845	VERA ROMANOVA	{"email": "romanova-v.27111967@postgrespro.ru", "phone": "+70500962500"}
0005435038705	8C98A0	7051 526228	TATYANA SOKOLOVA	{"email": "tatyana.sokolova1955@postgrespro.ru", "phone": "+70669366847"}
0005435038706	5F3BB7	2399 382301	GALINA PAVLOVA	{"phone": "+70575172171"}
0005435038707	5F3BB7	6528 603469	EKATERINA ANISIMOVA	{"phone": "+70496203060"}
0005435038708	643CF2	4886 232527	ALEKSANDR EGOROV	{"phone": "+70914913996"}
0005435038711	38702D	1507 462152	VIKTORIYA POPOVA	{"email": "viktoriya-popova-081964@postgrespro.ru", "phone": "+70736945906"}
0005435038712	FDEA30	3650 751305	ANATOLIY ILIN	{"phone": "+70446663065"}
0005435038713	C2728A	6411 095167	MARINA KRASNOVA	{"phone": "+70175812181"}
0005435038714	3675E1	7082 791724	ALEKSEY SERGEEV	{"phone": "+70312449639"}
0005435038715	619CE9	6381 622530	VIKTOR PETROV	{"email": "petrov.viktor.12121978@postgrespro.ru", "phone": "+70588688504"}
0005435038716	665971	0014 693847	SERGEY NIKOLAEV	{"phone": "+70912048074"}
0005435038717	665971	2415 599433	TAMARA SEMENOVA	{"email": "t.semenova-13121968@postgrespro.ru", "phone": "+70684557703"}
0005435038718	203CDC	4819 978608	VIKTOR FEDOROV	{"email": "v_fedorov-06031986@postgrespro.ru", "phone": "+70221173168"}
0005435038719	203CDC	0766 680132	ALBERT GAVRILOV	{"email": "gavrilov-albert.101970@postgrespro.ru", "phone": "+70912250098"}
0005435038720	6757EA	8357 503675	PETR MEDVEDEV	{"phone": "+70521888132"}
0005435038721	6757EA	1773 987039	ILYA PETROV	{"email": "i_petrov14101983@postgrespro.ru", "phone": "+70206377225"}
0005435038722	416096	8923 207051	NINA KARPOVA	{"email": "n.karpova25071972@postgrespro.ru", "phone": "+70664946303"}
0005435038723	1A027E	1487 356561	ANASTASIYA TARASOVA	{"email": "tarasova-a.031974@postgrespro.ru", "phone": "+70176151216"}
0005435038724	1A027E	6173 573419	NADEZHDA FILATOVA	{"email": "filatova-nadezhda-1965@postgrespro.ru", "phone": "+70680855825"}
0005435038725	D292CB	8859 465488	EVGENIY ABRAMOV	{"phone": "+70317271578"}
0005435038726	D82588	6854 605938	ALEKSANDR MARTYNOV	{"phone": "+70150743231"}
0005435038727	A8B3E1	4751 899384	IVAN MAKAROV	{"email": "makarov.i-29031965@postgrespro.ru", "phone": "+70876911610"}
0005435038728	7439C5	2871 867712	VIKTOR MAKSIMOV	{"email": "maksimov-viktor-23021975@postgrespro.ru", "phone": "+70843817753"}
0005435038729	D1D1DB	4999 080289	ALEKSANDRA FROLOVA	{"email": "frolova.aleksandra041979@postgrespro.ru", "phone": "+70379233481"}
0005435038730	D1D1DB	4114 080159	OKSANA PAVLOVA	{"email": "opavlova.21031970@postgrespro.ru", "phone": "+70945986397"}
0005435038731	2C9127	2330 778425	MIKHAIL KRASNOV	{"email": "krasnov_mikhail_041960@postgrespro.ru", "phone": "+70278130564"}
0005435038732	B9F506	8667 976277	MAKSIM KOZLOV	{"email": "kozlov.maksim.1976@postgrespro.ru", "phone": "+70517717284"}
0005435038733	DABBC0	7702 240761	MIKHAIL IVANOV	{"email": "m.ivanov.051974@postgrespro.ru", "phone": "+70346848350"}
0005435038734	F9EF93	2834 578401	BORIS SIDOROV	{"email": "b.sidorov_011974@postgrespro.ru", "phone": "+70716164278"}
0005435038735	F9EF93	2108 587998	BORIS ZAYCEV	{"email": "boris_zaycev_121979@postgrespro.ru", "phone": "+70814480406"}
0005435038736	6BEF7C	6314 955952	RAVIL SCHERBAKOV	{"phone": "+70363217412"}
0005435038737	6BEF7C	0925 682178	SVETLANA IVANOVA	{"email": "ivanovasvetlana_02041958@postgrespro.ru", "phone": "+70155201429"}
0005435038738	EFF6FC	3222 733206	DINARA IVANOVA	{"phone": "+70985535785"}
0005435038739	FDAB46	4780 145232	RUDOLF SCHERBAKOV	{"phone": "+70065883318"}
0005435038740	ABACC7	8766 066476	ANDREY IVANOV	{"email": "andrey_ivanov28041966@postgrespro.ru", "phone": "+70141031242"}
0005435038741	ABACC7	8977 804293	RAISA SEMENOVA	{"email": "semenova.raisa-1972@postgrespro.ru", "phone": "+70895757789"}
0005435038742	BA2078	5638 174415	DARYA FILIPPOVA	{"email": "filippova.d1971@postgrespro.ru", "phone": "+70293966146"}
0005435038743	BA2078	4481 767103	LARISA VASILEVA	{"phone": "+70861159321"}
0005435038744	946155	9107 504286	NATALYA SERGEEVA	{"phone": "+70041149535"}
0005435038745	C43D35	7580 505663	VLADIMIR IVANOV	{"email": "ivanov-vladimir.1978@postgrespro.ru", "phone": "+70509518193"}
0005435038746	C43D35	9825 072917	KRISTINA VOLKOVA	{"phone": "+70929276051"}
0005435038747	D55292	6889 843214	EVGENIY FEDOROV	{"phone": "+70258555408"}
0005435038748	03D877	4282 559784	IVAN VASILEV	{"phone": "+70458414357"}
0005435038749	793C74	0821 574985	NIKOLAY NAUMOV	{"phone": "+70846580193"}
0005435038750	765EEA	5174 325064	SERGEY SMIRNOV	{"email": "s-smirnov-041971@postgrespro.ru", "phone": "+70695083258"}
0005435038751	88EA7C	1021 617279	ANDREY MARTYNOV	{"phone": "+70694526862"}
0005435038752	FBF128	2116 131475	DIANA GUSEVA	{"email": "d_guseva11031977@postgrespro.ru", "phone": "+70459249896"}
0005435038753	FBF128	8282 880425	VIKTORIYA VASILEVA	{"phone": "+70424055347"}
0005435038754	679923	8762 204871	ALEKSANDR EGOROV	{"phone": "+70819483971"}
0005435038755	B79123	0180 701313	IVAN VLASOV	{"email": "vlasov-ivan_071961@postgrespro.ru", "phone": "+70183743085"}
0005435038756	B991D6	6589 854807	ANATOLIY STEPANOV	{"email": "anatoliystepanov.16071982@postgrespro.ru", "phone": "+70238411752"}
0005435038757	B991D6	9306 443358	GALINA SIDOROVA	{"email": "g-sidorova061972@postgrespro.ru", "phone": "+70428277181"}
0005435038758	24FBEB	3986 337710	ANNA SIDOROVA	{"email": "sidorova.a.1973@postgrespro.ru", "phone": "+70677524698"}
0005435038759	54598E	4223 739452	NADEZHDA SOROKINA	{"email": "nadezhda-sorokina-1971@postgrespro.ru", "phone": "+70808612545"}
0005435038760	026A44	4758 608909	VIKTOR VOLKOV	{"email": "volkov_viktor-1972@postgrespro.ru", "phone": "+70211863954"}
0005435038761	AD42D2	8022 576618	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey_1970@postgrespro.ru", "phone": "+70154979720"}
0005435038762	A0D104	5009 351744	TAMARA GAVRILOVA	{"phone": "+70874876144"}
0005435038763	27BDCF	4665 238866	MIKHAIL KOZLOV	{"phone": "+70290209421"}
0005435038764	27BDCF	3781 237894	NINA KARPOVA	{"email": "nkarpova.1975@postgrespro.ru", "phone": "+70962826458"}
0005435038765	F939ED	1313 159102	YURIY ZAKHAROV	{"phone": "+70132411909"}
0005435038766	F939ED	3659 209953	IVAN BARANOV	{"phone": "+70875593049"}
0005435038767	1A3744	1338 013074	TATYANA TIKHONOVA	{"email": "tikhonovat09121982@postgrespro.ru", "phone": "+70912236724"}
0005435038768	D9A195	0955 175565	ALEKSANDRA DANILOVA	{"phone": "+70613503160"}
0005435038769	D9A195	4430 501175	NINA NAZAROVA	{"phone": "+70278842605"}
0005435038770	871FF0	9040 377528	ANDREY GERASIMOV	{"email": "gerasimov_a051960@postgrespro.ru", "phone": "+70601927241"}
0005435038771	194789	6814 474415	DMITRIY GERASIMOV	{"email": "gerasimov-d.14011962@postgrespro.ru", "phone": "+70949460634"}
0005435038772	5B9F10	5420 193038	DENIS ISAEV	{"phone": "+70151599749"}
0005435038773	5B9F10	9815 686531	ANATOLIY TIKHONOV	{"phone": "+70481383185"}
0005435038774	61C197	9312 075479	YURIY PETROV	{"phone": "+70518501148"}
0005435038775	61C197	6316 944546	MAKSIM KOZLOV	{"email": "kozlov-m_1993@postgrespro.ru", "phone": "+70162459180"}
0005435038776	65573E	7494 332350	SOFIYA ISAEVA	{"phone": "+70459946793"}
0005435038777	B8DE46	7977 609899	IVAN NAZAROV	{"phone": "+70823910983"}
0005435038778	3B1745	6906 035695	KIRILL MAKSIMOV	{"email": "maksimovkirill.20041971@postgrespro.ru", "phone": "+70026234756"}
0005435038779	406C28	4259 884274	ALEKSANDR KOROLEV	{"email": "a_korolev_1982@postgrespro.ru", "phone": "+70295890904"}
0005435038780	0164EC	5243 726881	SERGEY SOKOLOV	{"email": "sokolovsergey18031976@postgrespro.ru", "phone": "+70475485801"}
0005435038781	186705	0074 517656	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr_11041965@postgrespro.ru", "phone": "+70514089531"}
0005435038782	14508C	0115 341496	ANNA DMITRIEVA	{"email": "a_dmitrieva-021981@postgrespro.ru", "phone": "+70810024158"}
0005435038783	14508C	8314 594207	TAMARA GORBUNOVA	{"phone": "+70587936586"}
0005435038784	21CBA7	9602 422636	VERONIKA KOROLEVA	{"phone": "+70097553106"}
0005435038785	05BAF4	1757 438860	NADEZHDA ZAYCEVA	{"email": "zayceva.nadezhda_1975@postgrespro.ru", "phone": "+70010632386"}
0005435038786	05BAF4	7709 407168	VALERIY BELOV	{"email": "belovvaleriy_1973@postgrespro.ru", "phone": "+70184927916"}
0005435038787	36AD6B	0076 920739	ELENA KUZNECOVA	{"email": "e.kuznecova.1964@postgrespro.ru", "phone": "+70749109763"}
0005435038788	36AD6B	2243 100858	STANISLAV ANDREEV	{"phone": "+70322761829"}
0005435038789	ABEB47	8230 272390	VALERIYA MATVEEVA	{"phone": "+70107285978"}
0005435038790	35B7D4	6715 030848	VLADIMIR KUZNECOV	{"phone": "+70884650149"}
0005435038791	35B7D4	6242 588365	EVGENIY TIKHONOV	{"email": "e_tikhonov.041968@postgrespro.ru", "phone": "+70368837602"}
0005435038792	EBC2D9	8908 828906	SERGEY BONDARENKO	{"phone": "+70893896814"}
0005435038793	FF7725	7354 907498	GALINA NESTEROVA	{"email": "nesterovag_1981@postgrespro.ru", "phone": "+70552649337"}
0005435038794	942598	6888 806072	ZOYA FOMINA	{"email": "z_fomina041968@postgrespro.ru", "phone": "+70933328079"}
0005435038795	5AB7F4	9486 943303	NATALIYA NIKITINA	{"email": "n.nikitina1984@postgrespro.ru", "phone": "+70207164148"}
0005435038796	59323F	8297 011391	IGOR SOKOLOV	{"email": "igor-sokolov_041976@postgrespro.ru", "phone": "+70322595776"}
0005435038797	2C5D58	4655 943520	ARTEM ZAYCEV	{"phone": "+70311948991"}
0005435038798	0F247B	4990 680781	TATYANA NESTEROVA	{"email": "nesterova_tatyana1959@postgrespro.ru", "phone": "+70424592244"}
0005435038799	6D5A17	6463 633795	MAKSIM DMITRIEV	{"phone": "+70119500976"}
0005435038800	8B86FE	3219 406782	GALINA KOVALEVA	{"email": "kovaleva_g011964@postgrespro.ru", "phone": "+70311811900"}
0005435038801	0A20CC	6717 561269	RAISA EGOROVA	{"email": "egorova-r_021971@postgrespro.ru", "phone": "+70760986564"}
0005435038802	110C22	3544 855303	ELENA BOGDANOVA	{"email": "bogdanova-elena101988@postgrespro.ru", "phone": "+70531910326"}
0005435038803	D4CEC4	2888 364690	ILYA FOMIN	{"phone": "+70699538930"}
0005435038804	1CD6BB	7142 900584	KLAVDIYA TIMOFEEVA	{"phone": "+70497954534"}
0005435038805	B3F289	6429 888693	ARTEM GORBUNOV	{"email": "artem_gorbunov1974@postgrespro.ru", "phone": "+70467398706"}
0005435038806	9F352D	1763 501813	YURIY MOISEEV	{"email": "yuriymoiseev091973@postgrespro.ru", "phone": "+70346700880"}
0005435038807	BDFD3A	7586 278337	OLGA POPOVA	{"email": "olga_popova.061976@postgrespro.ru", "phone": "+70426857956"}
0005435038808	81BA36	2879 799632	NATALYA GAVRILOVA	{"email": "gavrilova-natalya-1977@postgrespro.ru", "phone": "+70589826558"}
0005435038809	F25DEF	4710 665787	ALEKSANDRA LAZAREVA	{"phone": "+70960185429"}
0005435038810	F25DEF	2973 349554	YAKOV CHERNOV	{"email": "chernov_yakov-031978@postgrespro.ru", "phone": "+70031116667"}
0005435038811	F25DEF	9781 715945	IRINA LEBEDEVA	{"email": "lebedeva-i.1968@postgrespro.ru", "phone": "+70439807931"}
0005435038812	D5FB8B	0785 456990	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr_13031967@postgrespro.ru", "phone": "+70159864700"}
0005435038813	D5FB8B	2943 129154	ANDREY KULIKOV	{"phone": "+70159958640"}
0005435038814	B8C9BE	8787 423633	NATALYA KUZNECOVA	{"email": "kuznecova.n.06041974@postgrespro.ru", "phone": "+70748536650"}
0005435038815	389874	6336 782332	DANIIL IVANOV	{"phone": "+70846476874"}
0005435038816	75EDBA	1830 478178	LYUDMILA GERASIMOVA	{"email": "l_gerasimova1965@postgrespro.ru", "phone": "+70054243685"}
0005435038817	1FD01A	4402 499411	RUSLAN SAVELEV	{"email": "r.savelev_031967@postgrespro.ru", "phone": "+70433173501"}
0005435038818	7B4F3F	4671 331053	VERONIKA MAKSIMOVA	{"email": "maksimova_v1962@postgrespro.ru", "phone": "+70371391132"}
0005435038819	FB2A8C	2109 490977	OLEG PETROV	{"email": "petrov-o-1960@postgrespro.ru", "phone": "+70057814144"}
0005435038820	FB2A8C	8058 616746	NIKOLAY BORISOV	{"phone": "+70140360547"}
0005435039042	B3BAC7	1913 802179	PETR IVANOV	{"phone": "+70951095726"}
0005435038821	A72557	8951 801625	ZINAIDA POTAPOVA	{"email": "z-potapova-1967@postgrespro.ru", "phone": "+70940075437"}
0005435038822	69E89F	0230 252825	LYUDMILA KRASNOVA	{"phone": "+70548658902"}
0005435038823	69E89F	2565 276491	VIKTOR MARTYNOV	{"phone": "+70925424721"}
0005435038824	69E89F	8801 202109	VASILIY FEDOTOV	{"phone": "+70060546006"}
0005435038825	69E89F	0733 563296	ELENA NIKOLAEVA	{"phone": "+70039554845"}
0005435038826	13A65D	3269 392558	EKATERINA RYABOVA	{"phone": "+70687515915"}
0005435038827	E57D9D	3798 497133	MARIYA NESTEROVA	{"email": "nesterova_m-21011976@postgrespro.ru", "phone": "+70444610314"}
0005435038828	D4396B	2730 746031	SERGEY KUZNECOV	{"email": "sergey_kuznecov-051975@postgrespro.ru", "phone": "+70355754517"}
0005435038829	4142DB	8334 144244	ANDREY KUZNECOV	{"email": "andrey-kuznecov-081977@postgrespro.ru", "phone": "+70297877693"}
0005435038830	560A49	9869 656464	NIKOLAY VLASOV	{"phone": "+70575010242"}
0005435038831	93C587	4202 183756	MARINA ZAKHAROVA	{"phone": "+70238402500"}
0005435038832	93C587	4118 045753	NATALYA KONOVALOVA	{"email": "konovalova-n1975@postgrespro.ru", "phone": "+70742239234"}
0005435038833	93C587	3685 542385	SVETLANA KUZNECOVA	{"email": "kuznecovas081975@postgrespro.ru", "phone": "+70334857880"}
0005435038834	8FB122	8304 768541	MATVEY NIKITIN	{"email": "nikitin-m-23051979@postgrespro.ru", "phone": "+70358107104"}
0005435038835	329F32	7542 716108	ANASTASIYA ZHUKOVA	{"email": "anastasiya_zhukova.1960@postgrespro.ru", "phone": "+70347383471"}
0005435038836	61744C	8820 832018	TATYANA MALYSHEVA	{"phone": "+70003507948"}
0005435038837	1ADB1E	6039 592359	VIKTOR MOISEEV	{"email": "v_moiseev.18061970@postgrespro.ru", "phone": "+70187761110"}
0005435038838	E07CFE	4279 533764	DENIS ANTONOV	{"phone": "+70132768685"}
0005435038839	731BD2	6556 426475	VALERIY MIRONOV	{"email": "valeriy.mironov_011978@postgrespro.ru", "phone": "+70741197698"}
0005435038840	79B2C5	9989 377830	ANNA SEMENOVA	{"email": "a.semenova_1974@postgrespro.ru", "phone": "+70797183476"}
0005435038841	04F451	8456 608608	KONSTANTIN VOLKOV	{"phone": "+70958889193"}
0005435038842	04F451	7914 261833	SERGEY FEDOROV	{"email": "fedorov.s031970@postgrespro.ru", "phone": "+70124804444"}
0005435038843	BDF600	6216 927423	RAUF MELNIKOV	{"email": "melnikov-r-1992@postgrespro.ru", "phone": "+70205879624"}
0005435038844	BDF600	1326 615186	ARINA VASILEVA	{"phone": "+70618648519"}
0005435038845	98234A	9693 923006	GALINA KONDRATEVA	{"phone": "+70065772675"}
0005435038846	98234A	8250 858039	EVDOKIYA RYABOVA	{"phone": "+70705751979"}
0005435038847	A6D700	2553 153264	ANTONINA GUSEVA	{"phone": "+70028350331"}
0005435038848	1D518E	5460 770477	VLADIMIR IVANOV	{"phone": "+70808357571"}
0005435038849	1D518E	8534 760404	VYACHESLAV GUSEV	{"email": "vyacheslav.gusev_1975@postgrespro.ru", "phone": "+70930015568"}
0005435038850	873E6A	9214 117301	SERGEY ROMANOV	{"email": "romanov_sergey1969@postgrespro.ru", "phone": "+70335378572"}
0005435038851	21AD6B	8564 034088	VLADIMIR VASILEV	{"phone": "+70187208409"}
0005435038852	CE7475	1176 258381	ELENA ROMANOVA	{"email": "romanova_e.13071964@postgrespro.ru", "phone": "+70374599125"}
0005435038853	CE7475	5054 223406	VASILIY KUZNECOV	{"phone": "+70321733272"}
0005435038854	B98CB5	7267 479122	GENNADIY DENISOV	{"email": "g.denisov_1979@postgrespro.ru", "phone": "+70169329844"}
0005435038855	F860A0	3575 049952	ANATOLIY VASILEV	{"phone": "+70415160590"}
0005435038856	F860A0	9983 599040	SERGEY MIKHAYLOV	{"email": "mikhaylov.sergey.1958@postgrespro.ru", "phone": "+70911670310"}
0005435038857	0C4ACB	3532 901744	NADEZHDA POLYAKOVA	{"phone": "+70199963680"}
0005435038858	0C4ACB	7405 648495	ANDREY MIRONOV	{"email": "mironov.andrey.11011980@postgrespro.ru", "phone": "+70688620284"}
0005435038859	0C4ACB	5161 254890	EVGENIY KUZNECOV	{"phone": "+70166791988"}
0005435038860	499032	6736 389176	TATYANA KOROLEVA	{"email": "tatyana.koroleva-16021967@postgrespro.ru", "phone": "+70481930085"}
0005435038861	933317	8763 154771	NINA FOMINA	{"email": "fomina-n-20051984@postgrespro.ru", "phone": "+70223872616"}
0005435038862	74359E	6447 243792	GALINA SCHERBAKOVA	{"email": "scherbakova.galina.1965@postgrespro.ru", "phone": "+70482877390"}
0005435038863	01559A	5885 480794	SVETLANA BARANOVA	{"phone": "+70609071185"}
0005435038864	01559A	8268 111882	NINA FOMINA	{"phone": "+70827221094"}
0005435038865	82EB64	7913 276956	ELENA SIDOROVA	{"phone": "+70530746174"}
0005435038866	82EB64	2085 460742	VALERIY SCHERBAKOV	{"phone": "+70424458611"}
0005435038867	ED8950	3489 382404	LYUBOV NOVIKOVA	{"phone": "+70551924780"}
0005435038868	ED8950	4579 096483	VLADIMIR TARASOV	{"email": "vtarasov.1975@postgrespro.ru", "phone": "+70303404988"}
0005435038869	189A0F	7860 800465	YULIYA NOVIKOVA	{"phone": "+70585292909"}
0005435038870	189A0F	1914 141746	VALENTINA MOROZOVA	{"phone": "+70394775349"}
0005435038871	53B3E7	1166 335607	VENIAMIN ALEKSEEV	{"email": "veniaminalekseev-13081972@postgrespro.ru", "phone": "+70238298951"}
0005435038872	53B3E7	2154 386084	POLINA PAVLOVA	{"email": "pavlovapolina.04011971@postgrespro.ru", "phone": "+70295603154"}
0005435038873	B59E02	5828 029123	SVETLANA SMIRNOVA	{"phone": "+70919439569"}
0005435038874	205D1A	6391 045067	ALEKSANDR ROMANOV	{"phone": "+70642504860"}
0005435038875	00C191	5076 079976	ALEKSEY ANDREEV	{"phone": "+70286679275"}
0005435038876	754081	8095 869326	VLADIMIR MAKAROV	{"phone": "+70287115759"}
0005435038877	E7E85F	1623 063184	SERGEY POPOV	{"email": "popov-s_07031984@postgrespro.ru", "phone": "+70425134853"}
0005435038878	E7E85F	0404 290502	KIRILL PETROV	{"email": "petrov-k1970@postgrespro.ru", "phone": "+70755643899"}
0005435038879	48E7FC	1849 543227	IRINA STEPANOVA	{"phone": "+70380835903"}
0005435038880	319E47	4209 927994	NIKOLAY FEDOROV	{"email": "nikolayfedorov-08081966@postgrespro.ru", "phone": "+70982698613"}
0005435038881	319E47	7665 467822	ANATOLIY IVANOV	{"email": "a-ivanov.03061978@postgrespro.ru", "phone": "+70992230268"}
0005435038882	2A65BD	2795 538407	OLGA EFREMOVA	{"email": "efremova.o-051979@postgrespro.ru", "phone": "+70118057844"}
0005435038883	2A65BD	6149 153006	TATYANA GUSEVA	{"phone": "+70389455056"}
0005435038884	2A65BD	5805 149458	NINA LEBEDEVA	{"phone": "+70655766536"}
0005435038885	3E6D0A	6435 356482	OLGA SEMENOVA	{"email": "semenova_olga_1968@postgrespro.ru", "phone": "+70935535534"}
0005435038886	8CBFA8	3770 318393	ILYA KOZLOV	{"email": "kozlov.ilya.13031964@postgrespro.ru", "phone": "+70056949356"}
0005435038887	841046	1852 837698	MARINA FEDOROVA	{"email": "mfedorova.061982@postgrespro.ru", "phone": "+70192750534"}
0005435038888	841046	0568 702405	ALEKSEY MIRONOV	{"phone": "+70327791546"}
0005435038889	949E04	2271 580610	TATYANA DMITRIEVA	{"email": "tatyana_dmitrieva-15031970@postgrespro.ru", "phone": "+70190841377"}
0005435038890	A8ED91	1817 717596	SVETLANA TITOVA	{"phone": "+70177901752"}
0005435038891	A8ED91	0388 459641	MARIYA MOROZOVA	{"email": "morozova.m-07051982@postgrespro.ru", "phone": "+70388158715"}
0005435038892	ACAE66	0697 891395	TATYANA FEDOROVA	{"phone": "+70612968260"}
0005435038893	080A6F	9922 228706	SERGEY NIKITIN	{"email": "sergeynikitin1986@postgrespro.ru", "phone": "+70415755546"}
0005435038894	43B595	9614 383806	NADEZHDA FOMINA	{"email": "nadezhda_fomina-1968@postgrespro.ru", "phone": "+70080742641"}
0005435038895	8A43DA	9536 730103	BORIS VOLKOV	{"email": "volkov_b031972@postgrespro.ru", "phone": "+70110934494"}
0005435038896	E1A7C3	3840 356604	MARINA TROFIMOVA	{"email": "m.trofimova1968@postgrespro.ru", "phone": "+70212875594"}
0005435038897	B96955	6568 078163	LIDIYA MELNIKOVA	{"phone": "+70124287271"}
0005435038898	325856	7353 844232	OLGA EGOROVA	{"phone": "+70708346430"}
0005435038899	193E37	0010 651713	VALERIYA KAZAKOVA	{"phone": "+70588946518"}
0005435038900	7CBD92	6905 325204	SERGEY FEDOROV	{"phone": "+70165404416"}
0005435038901	DD6C93	8827 588677	EVGENIY SOLOVEV	{"phone": "+70422752153"}
0005435038902	DD6C93	2033 930432	TAMARA MAKAROVA	{"email": "t.makarova121970@postgrespro.ru", "phone": "+70447020209"}
0005435038903	DD6C93	3911 766020	VASILIY IVANOV	{"phone": "+70493024047"}
0005435038904	A99140	9199 815539	YURIY STEPANOV	{"phone": "+70938319963"}
0005435038905	111A64	7332 981076	SOFIYA ZOTOVA	{"email": "sofiya-zotova.24031973@postgrespro.ru", "phone": "+70746676928"}
0005435038906	111A64	4544 873009	LYUBOV MAKSIMOVA	{"phone": "+70964751438"}
0005435038907	558E68	7005 745678	SEMEN FROLOV	{"email": "sfrolov_091971@postgrespro.ru", "phone": "+70632645085"}
0005435038908	836EB5	5028 820801	DANIIL ALEKSEEV	{"phone": "+70345438543"}
0005435038909	8FEA4D	4420 882816	VALENTIN EGOROV	{"email": "vegorov27051970@postgrespro.ru", "phone": "+70617510666"}
0005435038910	7ADE77	0036 699267	DMITRIY POPOV	{"phone": "+70166123689"}
0005435038911	04B55A	7592 111397	EVGENIY ROMANOV	{"email": "evgeniy_romanov031982@postgrespro.ru", "phone": "+70556410442"}
0005435038912	1E372F	1066 209908	VLADIMIR MAKAROV	{"phone": "+70395628407"}
0005435038913	1E372F	1011 851454	VALENTINA SIDOROVA	{"email": "sidorova.valentina1969@postgrespro.ru", "phone": "+70275291628"}
0005435038914	F6B927	7312 224938	ANNA KUZNECOVA	{"phone": "+70360430227"}
0005435038915	92FBB6	3434 092311	YURIY FILIPPOV	{"email": "filippov_y1957@postgrespro.ru", "phone": "+70022663789"}
0005435038916	92FBB6	2791 192483	ANAIT MOROZOVA	{"email": "a.morozova.04121974@postgrespro.ru", "phone": "+70231759920"}
0005435038917	F760DE	5235 975071	MIKHAIL YAKOVLEV	{"email": "yakovlev.mikhail-18121973@postgrespro.ru", "phone": "+70957786707"}
0005435038918	99AF1B	1106 992303	NIKOLAY KUZNECOV	{"phone": "+70718934971"}
0005435038919	929866	4859 919643	ANASTASIYA OVCHINNIKOVA	{"email": "anastasiya-ovchinnikova-21081975@postgrespro.ru", "phone": "+70225212426"}
0005435038920	929866	1654 305622	ANNA TARASOVA	{"phone": "+70374920740"}
0005435038921	4CA49D	3823 012851	ANNA TIMOFEEVA	{"email": "anna_timofeeva-12101968@postgrespro.ru", "phone": "+70495877006"}
0005435038922	4CA49D	9297 715793	VALENTINA TIKHONOVA	{"email": "tikhonovav-28101982@postgrespro.ru", "phone": "+70201980384"}
0005435038923	4D1AC0	9243 622386	LYUBOV FOMINA	{"phone": "+70238524568"}
0005435038924	3BB37B	4744 578846	ROMAN ALEKSEEV	{"email": "roman-alekseev-091970@postgrespro.ru", "phone": "+70863797977"}
0005435038925	02EB91	1929 606941	ALEKSEY ILIN	{"email": "ilin-aleksey081980@postgrespro.ru", "phone": "+70603480605"}
0005435038926	878124	7368 266890	VERA KOMAROVA	{"email": "komarova-vera1972@postgrespro.ru", "phone": "+70939860725"}
0005435038927	42D376	3080 363248	NATALYA RODIONOVA	{"phone": "+70270112830"}
0005435038928	6568F6	6786 928833	ALEKSANDRA TIMOFEEVA	{"email": "timofeeva.aleksandra.081973@postgrespro.ru", "phone": "+70462251875"}
0005435038929	56AEA5	6030 136473	IGOR MAKAROV	{"phone": "+70081074204"}
0005435038930	895329	2735 958234	VIKTOR KUDRYASHOV	{"email": "kudryashov-viktor1965@postgrespro.ru", "phone": "+70806361147"}
0005435038931	895329	9554 133393	VENIAMIN STEPANOV	{"email": "stepanov_v-17101972@postgrespro.ru", "phone": "+70266275889"}
0005435038932	72B810	0734 023649	LEV DENISOV	{"email": "lev_denisov121974@postgrespro.ru", "phone": "+70758419925"}
0005435038933	C2AF82	7621 686927	ANNA KUDRYASHOVA	{"email": "kudryashova_anna.061977@postgrespro.ru", "phone": "+70737814726"}
0005435038934	5889C1	4572 160714	ALEKSANDR FEDOROV	{"phone": "+70087382463"}
0005435038935	1AF8E8	6408 917646	SVETLANA BELOVA	{"email": "s.belova.081976@postgrespro.ru", "phone": "+70834582827"}
0005435038936	50055C	5507 521699	OLGA MELNIKOVA	{"email": "olga.melnikova.09121974@postgrespro.ru", "phone": "+70904696055"}
0005435038937	0E5B78	0847 364509	ANDREY ISAEV	{"phone": "+70382325426"}
0005435038938	5336FB	9752 678043	EVGENIY KOROLEV	{"phone": "+70118834001"}
0005435038939	6BDAF7	5685 526978	FATIMA YAKOVLEVA	{"email": "fatimayakovleva_121972@postgrespro.ru", "phone": "+70297193992"}
0005435038940	5AAE37	9590 125674	MARIYA MAKAROVA	{"phone": "+70331499220"}
0005435038941	5AAE37	1479 689995	LEONID POPOV	{"email": "leonid_popov.1974@postgrespro.ru", "phone": "+70375348823"}
0005435038942	3F8456	3640 024862	ANATOLIY KISELEV	{"phone": "+70819880658"}
0005435038943	3F8456	7247 036193	GENNADIY CHERNOV	{"phone": "+70443271622"}
0005435038944	97B643	0851 744775	VLADIMIR RODIONOV	{"email": "v.rodionov.13111982@postgrespro.ru", "phone": "+70484574725"}
0005435038945	E0F8B1	7538 487328	ANASTASIYA GUSEVA	{"email": "gusevaa_1975@postgrespro.ru", "phone": "+70746556702"}
0005435038946	97012E	8553 575552	LYUDMILA KULIKOVA	{"phone": "+70490531915"}
0005435038947	1315AD	0974 888273	VALERIY VOLKOV	{"email": "valeriy.volkov-101980@postgrespro.ru", "phone": "+70734148584"}
0005435038948	46B91D	0529 412296	ANNA ILINA	{"email": "ilina-anna_03081983@postgrespro.ru", "phone": "+70021486302"}
0005435038949	46B91D	6447 470140	KIRILL GRIGOREV	{"email": "k.grigorev_051982@postgrespro.ru", "phone": "+70378706314"}
0005435038950	ED6DEC	9605 195138	ANDREY PAVLOV	{"email": "andrey.pavlov12061973@postgrespro.ru", "phone": "+70145950416"}
0005435038951	2B38F3	1422 841055	FAINA TIKHONOVA	{"phone": "+70877689040"}
0005435038952	F460DD	1253 084455	ARTEM ISAEV	{"email": "artem_isaev.27101974@postgrespro.ru", "phone": "+70888376059"}
0005435038953	F460DD	3926 203825	KSENIYA VOROBEVA	{"phone": "+70525853654"}
0005435038954	082491	7758 102850	LIDIYA GORBUNOVA	{"phone": "+70359967821"}
0005435038955	AF67FC	7297 501438	OLGA SAVELEVA	{"email": "saveleva.olga-1973@postgrespro.ru", "phone": "+70979980483"}
0005435038956	65BC1F	8426 190702	SVETLANA SOKOLOVA	{"email": "s_sokolova.1969@postgrespro.ru", "phone": "+70258089339"}
0005435038957	084DF8	6537 919966	LYUDMILA TIMOFEEVA	{"email": "timofeeva-lyudmila-21011965@postgrespro.ru", "phone": "+70333020493"}
0005435038958	01D740	3255 632775	ELENA KUDRYASHOVA	{"email": "kudryashova.e.061983@postgrespro.ru", "phone": "+70837607887"}
0005435038959	3695B3	8031 175882	YULIYA ANTONOVA	{"email": "yantonova121975@postgrespro.ru", "phone": "+70527153830"}
0005435038960	3695B3	9294 290327	ALEKSANDR ISAEV	{"email": "aleksandr_isaev.10021962@postgrespro.ru", "phone": "+70967727368"}
0005435038961	E4DA25	2663 808836	YURIY NOVIKOV	{"email": "yuriy-novikov-101971@postgrespro.ru", "phone": "+70000031729"}
0005435038962	3BFEB7	9305 616711	ALINA GAVRILOVA	{"phone": "+70745409788"}
0005435038963	FFA63A	7030 052527	VITALIY MOROZOV	{"phone": "+70047854203"}
0005435038964	62419D	6047 878441	EVGENIY KUZNECOV	{"phone": "+70455202619"}
0005435038965	4B5791	9176 385432	LYUDMILA KONOVALOVA	{"email": "l.konovalova_101976@postgrespro.ru", "phone": "+70452922221"}
0005435039265	6B0C0B	1517 234385	ANTONINA MELNIKOVA	{"phone": "+70228216579"}
0005435038966	2D7825	0821 826719	NINA MELNIKOVA	{"email": "n-melnikova-1974@postgrespro.ru", "phone": "+70229296378"}
0005435038967	00C418	2472 771347	OLEG EGOROV	{"email": "egorov.oleg_021973@postgrespro.ru", "phone": "+70667181126"}
0005435038968	00C418	3191 729697	TATYANA GUSEVA	{"phone": "+70641963182"}
0005435038969	45C8DE	9458 727341	IVAN NIKITIN	{"email": "nikitinivan.011978@postgrespro.ru", "phone": "+70921732139"}
0005435038970	45C8DE	6506 607385	DARYA NIKITINA	{"email": "nikitinadarya.1974@postgrespro.ru", "phone": "+70213422906"}
0005435038971	B5D8F0	4433 242322	OLGA KUZMINA	{"email": "kuzmina.olga_25011962@postgrespro.ru", "phone": "+70397783429"}
0005435038972	53B820	4486 629937	ANASTASIYA ZAKHAROVA	{"phone": "+70640724118"}
0005435038973	D487E2	4118 829261	IVAN FEDOROV	{"phone": "+70606589763"}
0005435038974	D487E2	3275 479383	LYUDMILA OSIPOVA	{"phone": "+70719891931"}
0005435038975	3856B9	7190 224365	NIKOLAY STEPANOV	{"email": "nikolay.stepanov1975@postgrespro.ru", "phone": "+70773066330"}
0005435038976	04FF9F	0888 448562	IGOR MAKAROV	{"phone": "+70174496346"}
0005435038977	04FF9F	8649 255850	ELENA MIKHAYLOVA	{"phone": "+70322561005"}
0005435038978	C5F2AE	8554 451939	LARISA SCHERBAKOVA	{"phone": "+70168690358"}
0005435038979	CD883F	1331 276930	LYUDMILA NIKITINA	{"email": "lyudmila_nikitina031969@postgrespro.ru", "phone": "+70187497604"}
0005435038980	BB71A0	7728 132047	SERGEY ANDREEV	{"phone": "+70903755753"}
0005435038981	BB71A0	1116 099940	ELENA SMIRNOVA	{"phone": "+70777680615"}
0005435038982	52B86A	4016 646164	ELENA MELNIKOVA	{"email": "elena_melnikova-31051969@postgrespro.ru", "phone": "+70280823229"}
0005435038983	6629FC	4384 966217	ARTEM SHEVCHENKO	{"email": "artemshevchenko-05011969@postgrespro.ru", "phone": "+70492748869"}
0005435038984	CCA8A0	1056 092893	LYUBOV KONDRATEVA	{"phone": "+70696423401"}
0005435038985	DBA36B	3327 327795	DANILA ILIN	{"email": "dilin.1981@postgrespro.ru", "phone": "+70445571081"}
0005435038986	1F5BE8	4948 487843	ANTON DMITRIEV	{"phone": "+70364308270"}
0005435038987	1C2C4C	4905 650589	GALINA ISAEVA	{"phone": "+70719760193"}
0005435039043	120DD6	3788 361059	VLADIMIR KUZNECOV	{"email": "kuznecov_v29041984@postgrespro.ru", "phone": "+70808001925"}
0005435038988	377DD5	5323 025168	ANASTASIYA NOVIKOVA	{"email": "novikovaanastasiya-25111980@postgrespro.ru", "phone": "+70244982491"}
0005435038989	377DD5	6691 848975	VALERIYA YUDINA	{"phone": "+70575451360"}
0005435038990	4CAD77	3016 427507	ALEKSEY MEDVEDEV	{"email": "aleksey_medvedev1972@postgrespro.ru", "phone": "+70003222179"}
0005435038991	4CDA31	6458 549246	ELENA POLYAKOVA	{"phone": "+70152069074"}
0005435038992	FC5E88	3146 043396	MAKSIM IVANOV	{"phone": "+70130053248"}
0005435038993	E9D6C3	1447 015807	NATALYA OSIPOVA	{"email": "natalyaosipova-1970@postgrespro.ru", "phone": "+70776929473"}
0005435038994	9578A3	9057 267537	TATYANA VOLKOVA	{"phone": "+70396903580"}
0005435038995	9578A3	4351 968345	VALENTINA STEPANOVA	{"phone": "+70497989850"}
0005435038996	A185D1	0294 449979	VASILIY KUZNECOV	{"email": "kuznecovvasiliy_27111975@postgrespro.ru", "phone": "+70585101251"}
0005435038997	3A9B6F	0213 031342	MARIYA EGOROVA	{"email": "mariya-egorova1967@postgrespro.ru", "phone": "+70586595738"}
0005435038998	3A9B6F	0348 584119	ANATOLIY ZAYCEV	{"email": "azaycev06081970@postgrespro.ru", "phone": "+70559707601"}
0005435038999	343289	5776 674977	SEMEN POPOV	{"phone": "+70656502366"}
0005435039000	C63F86	4162 255770	SVETLANA ERMAKOVA	{"phone": "+70732992460"}
0005435039001	38C9C2	9502 164803	NATALYA MARTYNOVA	{"email": "martynova_natalya-08091976@postgrespro.ru", "phone": "+70287534663"}
0005435039002	AD9848	9921 163997	GULFIYA ANDREEVA	{"phone": "+70682195684"}
0005435039003	5D07F6	6304 630506	ALEVTINA EGOROVA	{"email": "egorovaalevtina26041980@postgrespro.ru", "phone": "+70445059279"}
0005435039004	5D07F6	0394 551964	MARIYA KONDRATEVA	{"email": "mariya_kondrateva_27091975@postgrespro.ru", "phone": "+70789126850"}
0005435039005	1C2FE2	9616 452416	VLADIMIR BELOV	{"email": "belovv-041975@postgrespro.ru", "phone": "+70822459797"}
0005435039006	F3B9DC	1513 597027	OLEG VOROBEV	{"email": "o.vorobev1977@postgrespro.ru", "phone": "+70551188652"}
0005435039007	F3B9DC	2091 835037	NATALYA KUZNECOVA	{"email": "natalyakuznecova-1973@postgrespro.ru", "phone": "+70875996802"}
0005435039008	940AC7	5744 305524	TATYANA MALYSHEVA	{"email": "tatyanamalysheva-101977@postgrespro.ru", "phone": "+70271807992"}
0005435039009	940AC7	0087 379727	SAVELIY GUSEV	{"email": "gusevsaveliy_091965@postgrespro.ru", "phone": "+70533024657"}
0005435039010	B53499	0971 956934	VLADIMIR EGOROV	{"email": "egorov.v.05111975@postgrespro.ru", "phone": "+70993758880"}
0005435039011	0ED933	0752 022992	ANATOLIY IVANOV	{"email": "anatoliyivanov_121978@postgrespro.ru", "phone": "+70178113613"}
0005435039012	0ED933	7173 518936	SERGEY MAKSIMOV	{"email": "maksimov_sergey-1958@postgrespro.ru", "phone": "+70486348736"}
0005435039013	0ED933	8120 394117	ELENA TROFIMOVA	{"email": "e-trofimova25111966@postgrespro.ru", "phone": "+70310724610"}
0005435039014	823F8A	8844 866283	ANDREY GAVRILOV	{"email": "gavrilovandrey.061974@postgrespro.ru", "phone": "+70140557621"}
0005435039015	4E9DB9	5356 273017	EKATERINA DMITRIEVA	{"email": "e-dmitrieva_1963@postgrespro.ru", "phone": "+70468063098"}
0005435039016	3EF2CD	9624 882072	ANATOLIY POPOV	{"phone": "+70995514445"}
0005435039017	3EF2CD	9533 172984	DANIL DMITRIEV	{"email": "dmitrievd_041983@postgrespro.ru", "phone": "+70711976571"}
0005435039018	134B75	4889 611096	SERGEY MEDVEDEV	{"email": "medvedev-sergey051979@postgrespro.ru", "phone": "+70864318356"}
0005435039019	8AAD2C	1428 947245	NIKOLAY KUZNECOV	{"phone": "+70993661871"}
0005435039020	A07D3D	8992 615296	LIDIYA GAVRILOVA	{"email": "gavrilova-lidiya.1970@postgrespro.ru", "phone": "+70080113293"}
0005435039021	7D29C1	7331 903528	KIRILL KOZLOV	{"phone": "+70362746489"}
0005435039022	7D29C1	3611 250453	NADEZHDA MATVEEVA	{"phone": "+70773224448"}
0005435039023	4F3F56	2270 684323	SERGEY SOLOVEV	{"email": "solovev_s1984@postgrespro.ru", "phone": "+70331239108"}
0005435039024	8A98E9	6751 360512	SHAMIL VOROBEV	{"email": "vorobev-s-031976@postgrespro.ru", "phone": "+70041838292"}
0005435039025	B3E758	8305 145925	ANDREY PAVLOV	{"phone": "+70468875069"}
0005435039026	32AA7E	1701 108149	ELIZAVETA LUKYANOVA	{"email": "lukyanovaelizaveta1978@postgrespro.ru", "phone": "+70868092551"}
0005435039027	CD26F1	6469 640269	LYUDMILA ARKHIPOVA	{"phone": "+70860133969"}
0005435039028	CD26F1	4424 854544	VERA RODIONOVA	{"email": "vrodionova28121965@postgrespro.ru", "phone": "+70809246341"}
0005435039029	488C53	9360 814961	ALEKSANDR ANTONOV	{"email": "a-antonov.101971@postgrespro.ru", "phone": "+70399231340"}
0005435039030	E1DB2B	3175 112125	LYUDMILA GUSEVA	{"email": "lyudmila-guseva29031962@postgrespro.ru", "phone": "+70663728404"}
0005435039031	79DD89	9959 918915	ANATOLIY KARPOV	{"email": "a_karpov_1988@postgrespro.ru", "phone": "+70987831660"}
0005435039032	45EC2E	0014 377507	TAGIR FROLOV	{"email": "frolov.tagir061976@postgrespro.ru", "phone": "+70056804575"}
0005435039033	B07220	1278 275835	EKATERINA SAVELEVA	{"email": "saveleva_ekaterina1967@postgrespro.ru", "phone": "+70274897947"}
0005435039034	722E34	2820 425178	ANDREY NIKITIN	{"email": "a_nikitin24111975@postgrespro.ru", "phone": "+70426162864"}
0005435039035	F56524	6678 913968	KLAVDIYA GUSEVA	{"phone": "+70502585176"}
0005435039036	F56524	6858 177115	PETR ZHURAVLEV	{"phone": "+70579497367"}
0005435039037	FF46D2	0986 283933	VYACHESLAV ZAYCEV	{"email": "vyacheslav.zaycev.1975@postgrespro.ru", "phone": "+70450833569"}
0005435039038	FF46D2	0038 688073	PAVEL YAKOVLEV	{"email": "yakovlev.p-24071967@postgrespro.ru", "phone": "+70734116162"}
0005435039039	A0D45E	8679 502513	MARIYA ANDREEVA	{"email": "m_andreeva1977@postgrespro.ru", "phone": "+70876666711"}
0005435039040	A0D45E	5311 463589	ILYA VASILEV	{"email": "vasilev_ilya.1960@postgrespro.ru", "phone": "+70362022766"}
0005435039041	61BB26	0289 972619	NINA KOROLEVA	{"phone": "+70103496436"}
0005435039044	6F982A	3067 647744	MARGARITA TIMOFEEVA	{"email": "timofeeva.m.01111976@postgrespro.ru", "phone": "+70659633041"}
0005435039045	6F982A	9948 807118	TATYANA FEDOROVA	{"phone": "+70803628443"}
0005435039046	2EE6C6	7604 981985	EKATERINA BELYAEVA	{"email": "belyaeva-ekaterina-051970@postgrespro.ru", "phone": "+70542723694"}
0005435039047	2EE6C6	3587 365748	TATYANA NAZAROVA	{"email": "nazarova_t-03121963@postgrespro.ru", "phone": "+70350495247"}
0005435039048	3CCADE	4496 831108	LYUBOV DMITRIEVA	{"phone": "+70441087326"}
0005435039049	FD5CA9	8510 483970	ELENA MIRONOVA	{"email": "elenamironova_24051976@postgrespro.ru", "phone": "+70434024807"}
0005435039050	FD5CA9	9799 202914	IVAN FROLOV	{"phone": "+70735993590"}
0005435039051	C356E1	2245 604917	STEPAN TIKHONOV	{"email": "stepan_tikhonov111975@postgrespro.ru", "phone": "+70114988278"}
0005435039052	C356E1	3051 071232	OLGA MAKAROVA	{"phone": "+70436659838"}
0005435039053	3FA6C7	2493 995793	ALEKSANDR SHEVCHENKO	{"phone": "+70258338157"}
0005435039054	3FA6C7	1668 739151	OLGA KUZMINA	{"email": "o_kuzmina15091973@postgrespro.ru", "phone": "+70324503794"}
0005435039055	473005	4664 193729	ELIZAVETA KAZAKOVA	{"phone": "+70580734278"}
0005435039056	54DB8C	5522 139294	SERGEY NAZAROV	{"phone": "+70754544251"}
0005435039057	54DB8C	8742 547353	IVAN GERASIMOV	{"phone": "+70562694629"}
0005435039058	CEAFFA	6534 399588	ANDREY ROMANOV	{"phone": "+70931745501"}
0005435039059	6BBB50	3158 817165	EVGENIY MAKAROV	{"phone": "+70262920030"}
0005435039060	8551D3	7796 967068	IGOR SIDOROV	{"phone": "+70098885686"}
0005435039061	51D8D4	1231 080498	YURIY KUZNECOV	{"email": "kuznecov-yuriy_02031981@postgrespro.ru", "phone": "+70424046269"}
0005435039062	394D75	4725 918126	ALEKSANDR DMITRIEV	{"phone": "+70025810123"}
0005435039063	394D75	4135 581887	EVGENIYA VLASOVA	{"phone": "+70505920091"}
0005435039064	797D30	2395 865117	ANTONINA MIKHAYLOVA	{"phone": "+70877902821"}
0005435039065	366466	1403 400278	ROMAN TIKHONOV	{"phone": "+70631942642"}
0005435039066	D46B21	8955 217872	MIKHAIL KRASNOV	{"phone": "+70809433659"}
0005435039067	CF7702	1282 752857	VIKTOR FILIPPOV	{"phone": "+70513758415"}
0005435039068	7C8406	3955 176366	ALEKSANDR GERASIMOV	{"phone": "+70036038873"}
0005435039069	48E618	1041 454601	IVAN PETROV	{"phone": "+70923195571"}
0005435039070	4BB0DF	5889 726266	LYUDMILA ZAKHAROVA	{"email": "zakharova.l_041971@postgrespro.ru", "phone": "+70486932270"}
0005435039071	8BDE40	1224 739836	VLADISLAV MOROZOV	{"email": "vladislav.morozov031966@postgrespro.ru", "phone": "+70851557443"}
0005435039072	8BDE40	3744 333206	ALEKSEY STEPANOV	{"phone": "+70322873859"}
0005435039073	DC32BA	4553 678021	ARTEM PETROV	{"phone": "+70908629423"}
0005435039074	DC32BA	7717 186344	ALEKSANDRA KUZMINA	{"email": "kuzmina.a_011973@postgrespro.ru", "phone": "+70118132348"}
0005435039075	11A1F3	9822 665112	LYUDMILA MOROZOVA	{"phone": "+70782583764"}
0005435039076	734158	5507 645774	SERGEY GUSEV	{"email": "gusevsergey1966@postgrespro.ru", "phone": "+70370663102"}
0005435039077	734158	5154 405719	NIKITA NOVIKOV	{"phone": "+70928643877"}
0005435039078	734158	9791 686057	ARTEM MAKAROV	{"phone": "+70840878962"}
0005435039079	E418EB	3537 089663	NINA NAZAROVA	{"email": "nazarova.nina_1963@postgrespro.ru", "phone": "+70114148731"}
0005435039080	26CD8E	3631 754581	SVETLANA YAKOVLEVA	{"email": "yakovlevasvetlana_07031972@postgrespro.ru", "phone": "+70665637775"}
0005435039081	26CD8E	6979 003079	IRINA MEDVEDEVA	{"email": "i-medvedeva25031989@postgrespro.ru", "phone": "+70647883593"}
0005435039082	CCE69A	5345 311734	MARINA VOLKOVA	{"phone": "+70767048863"}
0005435039083	A37B12	3832 962551	RIFAT MOROZOV	{"email": "morozov_rifat-02021975@postgrespro.ru", "phone": "+70671316530"}
0005435039084	49BD53	3782 236479	IGOR ABRAMOV	{"phone": "+70031463984"}
0005435039085	E6CCBA	4252 810787	SVETLANA GAVRILOVA	{"email": "gavrilova_s.081971@postgrespro.ru", "phone": "+70949477327"}
0005435039086	E6CCBA	3199 579195	NIKOLAY IVANOV	{"email": "n.ivanov-101961@postgrespro.ru", "phone": "+70311880600"}
0005435039087	391609	9054 711267	VLADIMIR ORLOV	{"email": "orlov_v_04111960@postgrespro.ru", "phone": "+70752035051"}
0005435039088	391609	8063 632952	TAMARA NOVIKOVA	{"phone": "+70315974577"}
0005435039089	A205C8	8144 924950	NIKITA SCHERBAKOV	{"phone": "+70722961458"}
0005435039090	215B18	6625 407589	IGOR BONDARENKO	{"phone": "+70449893507"}
0005435039091	A4BA37	8580 352046	EVGENIY ZAKHAROV	{"email": "evgeniy_zakharov.1977@postgrespro.ru", "phone": "+70257198612"}
0005435039092	A4BA37	1923 702476	ALEKSANDR KUZNECOV	{"phone": "+70105020311"}
0005435039093	D4EC20	5817 741595	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr.1964@postgrespro.ru", "phone": "+70129187484"}
0005435039094	56AFEC	8997 263185	KONSTANTIN PETROV	{"phone": "+70353013604"}
0005435039095	56AFEC	2190 420489	KAMIL KARPOV	{"email": "karpov-kamil_1966@postgrespro.ru", "phone": "+70603320599"}
0005435039096	ED9F98	6545 376844	OLGA LOGINOVA	{"email": "olgaloginova_121967@postgrespro.ru", "phone": "+70629033418"}
0005435039097	EC8F70	6324 657928	ANASTASIYA GERASIMOVA	{"phone": "+70430070124"}
0005435039098	249907	5601 531992	ANTON EGOROV	{"phone": "+70258470681"}
0005435039099	7AB748	2699 004936	DENIS ZAYCEV	{"email": "d.zaycev081965@postgrespro.ru", "phone": "+70668070284"}
0005435039100	879972	1672 432716	NINA MOROZOVA	{"email": "n.morozova.041972@postgrespro.ru", "phone": "+70464055436"}
0005435039101	879972	1841 178357	VALENTINA KONOVALOVA	{"phone": "+70904073389"}
0005435039102	A02B29	1620 102807	TATYANA FADEEVA	{"email": "tatyanafadeeva-05101969@postgrespro.ru", "phone": "+70068114301"}
0005435039103	A02B29	6572 278399	NIKOLAY ALEKSEEV	{"phone": "+70907943504"}
0005435039104	D8823E	8131 399583	GENNADIY MIRONOV	{"email": "mironov_gennadiy_071973@postgrespro.ru", "phone": "+70366591174"}
0005435039105	D0034D	0413 818799	ANASTASIYA KONDRATEVA	{"email": "anastasiya.kondrateva_1959@postgrespro.ru", "phone": "+70136627346"}
0005435039106	D0034D	1482 365771	GALINA MIRONOVA	{"phone": "+70559725417"}
0005435039107	364FA8	2824 544466	VITALIY ILIN	{"email": "ilin-vitaliy-1965@postgrespro.ru", "phone": "+70409553813"}
0005435039108	E0267D	4303 407305	EKATERINA GRISHINA	{"email": "grishina-ekaterina.10091972@postgrespro.ru", "phone": "+70211441484"}
0005435039109	1FBB76	0357 197864	ALEKSANDR ALEKSANDROV	{"email": "aleksandrovaleksandr.091977@postgrespro.ru", "phone": "+70913489322"}
0005435039110	1FBB76	4129 359350	PAVEL ABRAMOV	{"email": "abramovpavel.041969@postgrespro.ru", "phone": "+70925081922"}
0005435039111	6C6166	9046 180984	PAVEL MOROZOV	{"email": "pavelmorozov1982@postgrespro.ru", "phone": "+70283132213"}
0005435039112	6C6166	3092 533702	RAISA KUZNECOVA	{"email": "r_kuznecova_02121980@postgrespro.ru", "phone": "+70616163318"}
0005435039113	E430EB	7222 012863	GALINA TIKHONOVA	{"phone": "+70109082238"}
0005435039114	B4C606	6909 773701	ANDREY SMIRNOV	{"email": "a-smirnov101980@postgrespro.ru", "phone": "+70665181483"}
0005435039115	B4C606	0174 735330	MAKSIM ZHUKOV	{"phone": "+70014547367"}
0005435039116	64F6A4	2745 247268	ALEKSANDR NIKOLAEV	{"phone": "+70556123334"}
0005435039117	64F6A4	2638 848522	ALEKSEY BELOV	{"email": "abelov.021968@postgrespro.ru", "phone": "+70370382816"}
0005435039118	9465A9	6945 546813	VALERIY VLASOV	{"email": "vlasov_v_111970@postgrespro.ru", "phone": "+70931300436"}
0005435039119	E0BDBA	8926 435861	EVGENIYA LOGINOVA	{"email": "e_loginova1964@postgrespro.ru", "phone": "+70454556451"}
0005435039120	D73FBD	5152 634906	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov.101970@postgrespro.ru", "phone": "+70948692660"}
0005435039121	A1BA6B	7024 011597	NINA RODIONOVA	{"phone": "+70119266856"}
0005435039122	06D861	1789 480223	TATYANA KOLESNIKOVA	{"email": "kolesnikova.tatyana.29121978@postgrespro.ru", "phone": "+70679293075"}
0005435039123	C687A6	3746 113614	VIKTOR KULIKOV	{"phone": "+70035580850"}
0005435039124	86279E	6008 449500	IGOR VOROBEV	{"phone": "+70322344993"}
0005435039125	200EBE	0284 741616	TATYANA ALEKSEEVA	{"email": "alekseeva-t121972@postgrespro.ru", "phone": "+70005114623"}
0005435039126	200EBE	1011 938485	PAVEL MAKAROV	{"phone": "+70979057047"}
0005435039127	080A44	8370 823156	TATYANA KUZMINA	{"email": "kuzmina_tatyana1984@postgrespro.ru", "phone": "+70677144466"}
0005435039128	E6486D	0282 801016	LYUBOV ISAEVA	{"email": "l_isaeva_071972@postgrespro.ru", "phone": "+70852636230"}
0005435039129	E6486D	0037 525400	KONSTANTIN GORBUNOV	{"email": "gorbunov-k.101979@postgrespro.ru", "phone": "+70688263377"}
0005435039130	13F673	2204 302340	ANNA KUZNECOVA	{"phone": "+70273715340"}
0005435039131	13F673	5404 651400	GENNADIY SAVELEV	{"email": "g-savelev27061969@postgrespro.ru", "phone": "+70679050807"}
0005435039132	13F673	5811 897373	TAMARA ARKHIPOVA	{"phone": "+70942798490"}
0005435039133	B66DE4	1080 252661	VADIM PETROV	{"phone": "+70050784354"}
0005435039134	E04810	4725 955261	VLADIMIR KUZNECOV	{"phone": "+70456071894"}
0005435039135	92946C	1309 555494	EVGENIY GRIGOREV	{"phone": "+70001259240"}
0005435039136	92946C	7198 033049	ALINA DMITRIEVA	{"phone": "+70282428907"}
0005435039137	92946C	7844 738279	ALINA NESTEROVA	{"phone": "+70265919818"}
0005435039138	8FA1E2	8906 204768	ALEKSANDR SEMENOV	{"phone": "+70079504190"}
0005435039139	8FA1E2	8313 104775	VLADISLAV MIKHAYLOV	{"email": "mikhaylovvladislav.14081971@postgrespro.ru", "phone": "+70384553137"}
0005435039140	8FA1E2	6327 732931	ELENA KAZAKOVA	{"email": "elena.kazakova_1967@postgrespro.ru", "phone": "+70891124668"}
0005435039141	5A5833	8858 884781	NADEZHDA KRASNOVA	{"email": "nadezhda-krasnova-031976@postgrespro.ru", "phone": "+70058202012"}
0005435039142	5A5833	3965 100906	GALINA MEDVEDEVA	{"phone": "+70465342486"}
0005435039143	3F47CA	0441 550520	NINA KOZLOVA	{"phone": "+70089872829"}
0005435039144	3F47CA	4608 710471	LYUBOV MIRONOVA	{"email": "l-mironova.121970@postgrespro.ru", "phone": "+70167349207"}
0005435039145	B86EA3	0398 751165	NINA CHERNOVA	{"email": "chernova-nina1972@postgrespro.ru", "phone": "+70965235617"}
0005435039146	6AFEBD	5707 398492	DENIS MAKAROV	{"email": "denis_makarov091981@postgrespro.ru", "phone": "+70367131535"}
0005435039147	AC37A9	3812 268252	PAVEL MAKAROV	{"phone": "+70222475213"}
0005435039148	AC37A9	1656 298033	MARAT POPOV	{"email": "popovmarat_011979@postgrespro.ru", "phone": "+70436948933"}
0005435039149	1F1EC9	7214 232979	FEDOR SOKOLOV	{"phone": "+70989375493"}
0005435039150	2D2690	4680 784719	NINA KALININA	{"email": "n-kalinina041973@postgrespro.ru", "phone": "+70083721879"}
0005435039151	464CC3	8328 921595	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev011969@postgrespro.ru", "phone": "+70424381896"}
0005435039152	DF8704	2292 416309	ALEKSANDR MAKAROV	{"phone": "+70940038148"}
0005435039153	21C2F5	8983 531714	ROMAN PAVLOV	{"email": "romanpavlov_1979@postgrespro.ru", "phone": "+70930340424"}
0005435039154	0DD485	7419 075659	PAVEL TIKHONOV	{"phone": "+70151765573"}
0005435039155	E1C654	6226 516725	OLGA MAKSIMOVA	{"email": "maksimovaolga_15071981@postgrespro.ru", "phone": "+70885952622"}
0005435039156	36D4A8	7282 353515	VLADIMIR MELNIKOV	{"email": "v_melnikov21011973@postgrespro.ru", "phone": "+70824224758"}
0005435039157	8D7B0A	8363 673682	EDUARD VOROBEV	{"phone": "+70059550988"}
0005435039158	8D7B0A	4414 860221	IVAN NAZAROV	{"email": "nazarov_i_1976@postgrespro.ru", "phone": "+70910112115"}
0005435039159	C443B6	8726 183258	KONSTANTIN EGOROV	{"phone": "+70947512621"}
0005435039160	443B21	0632 041386	VERA FEDOROVA	{"email": "fedorova_vera.1978@postgrespro.ru", "phone": "+70582262800"}
0005435039161	443B21	2283 176412	OLGA VLASOVA	{"email": "olga-vlasova_081977@postgrespro.ru", "phone": "+70426592657"}
0005435039162	4BB39B	2037 568484	ELENA KOVALEVA	{"email": "kovaleva.elena.18111969@postgrespro.ru", "phone": "+70080250619"}
0005435039163	4BB39B	6271 122047	MARINA ZHUKOVA	{"phone": "+70693097996"}
0005435039164	4BB39B	5212 463030	VLADISLAV KULIKOV	{"phone": "+70891967804"}
0005435039165	4BB39B	2018 109715	VLADIMIR DENISOV	{"phone": "+70380004753"}
0005435039166	0EA616	9052 707496	EVGENIY MIKHAYLOV	{"email": "evgeniy.mikhaylov111963@postgrespro.ru", "phone": "+70082226997"}
0005435039167	B5B48A	2656 519452	YULIYA ZAKHAROVA	{"email": "y.zakharova06081978@postgrespro.ru", "phone": "+70589731613"}
0005435039168	B5B48A	9120 774412	IRINA ROMANOVA	{"phone": "+70867264281"}
0005435039169	2B8D4F	2959 955588	NATALYA POPOVA	{"phone": "+70596400239"}
0005435039170	6D460A	0055 968132	VALENTINA ANISIMOVA	{"phone": "+70954973246"}
0005435039171	6D460A	8854 137254	SERGEY ZHUKOV	{"phone": "+70707643513"}
0005435039172	81419A	6806 653487	NINA DENISOVA	{"email": "nina_denisova_1971@postgrespro.ru", "phone": "+70114624592"}
0005435039173	6EAB86	2000 992398	SAVELIY TIKHONOV	{"phone": "+70889930823"}
0005435039174	DB96A7	6890 324275	ARTEM NAUMOV	{"phone": "+70677095601"}
0005435039175	DB96A7	3476 046497	TATYANA BORISOVA	{"phone": "+70031313753"}
0005435039176	EF0B43	5696 628906	GENNADIY ANDREEV	{"email": "g.andreev-06011969@postgrespro.ru", "phone": "+70640992208"}
0005435039177	30A298	1784 265321	EVGENIY GRIGOREV	{"email": "egrigorev25061975@postgrespro.ru", "phone": "+70558835750"}
0005435039178	77AC69	7402 469206	VALENTINA POTAPOVA	{"phone": "+70163056164"}
0005435039179	90AEC4	4754 515534	SERGEY NAUMOV	{"phone": "+70992196150"}
0005435039180	90AEC4	9509 516138	SERGEY FILIPPOV	{"email": "s.filippov_1978@postgrespro.ru", "phone": "+70551955553"}
0005435039181	95BBA6	3073 734870	OLGA DMITRIEVA	{"phone": "+70726308002"}
0005435039182	87819D	8033 552262	TAMARA POPOVA	{"email": "t-popova_06101971@postgrespro.ru", "phone": "+70219270955"}
0005435039183	09773D	3036 658315	NATALYA IVANOVA	{"phone": "+70173248363"}
0005435039184	10A8CA	3272 554830	GRIGORIY BONDARENKO	{"email": "grigoriy-bondarenko-22081974@postgrespro.ru", "phone": "+70416074884"}
0005435039185	10A8CA	4660 272694	VYACHESLAV TIMOFEEV	{"email": "timofeev.v.20111987@postgrespro.ru", "phone": "+70128167404"}
0005435039186	ECD96B	2303 927686	OLGA NOVIKOVA	{"phone": "+70602657123"}
0005435039187	ECD96B	2675 735519	ALEKSANDR AFANASEV	{"email": "a.afanasev081974@postgrespro.ru", "phone": "+70912456049"}
0005435039188	4A4404	5408 157335	SERGEY IVANOV	{"email": "ivanov_sergey1974@postgrespro.ru", "phone": "+70679218077"}
0005435039189	2C9CB3	7058 346102	MIKHAIL BELOV	{"email": "belov-m.06021969@postgrespro.ru", "phone": "+70073610900"}
0005435039190	A1BDB2	3434 176516	NIKOLAY YAKOVLEV	{"phone": "+70633273691"}
0005435039191	570118	2518 786008	NATALIYA MOROZOVA	{"email": "morozova.nataliya20121969@postgrespro.ru", "phone": "+70920181372"}
0005435039192	CB05ED	8531 899411	SERGEY GORBUNOV	{"email": "gorbunov_s-02101976@postgrespro.ru", "phone": "+70269602242"}
0005435039193	F46963	9116 038219	IRINA MAKAROVA	{"email": "irina.makarova-1962@postgrespro.ru", "phone": "+70785964882"}
0005435039194	F46963	9741 980674	IGOR NAUMOV	{"phone": "+70125746565"}
0005435039195	D471BC	6096 772512	ANNA VASILEVA	{"email": "vasileva_anna_1987@postgrespro.ru", "phone": "+70729552272"}
0005435039196	D471BC	1393 355004	OLGA TROFIMOVA	{"email": "trofimova-olga_1974@postgrespro.ru", "phone": "+70513074912"}
0005435039197	C2C4CD	2000 201993	NIKOLAY GAVRILOV	{"email": "gavrilov.nikolay-06021969@postgrespro.ru", "phone": "+70593982942"}
0005435039198	C2C4CD	8038 058336	NIKOLAY SOKOLOV	{"phone": "+70911899297"}
0005435039199	F88469	0547 209267	GALINA FOMINA	{"email": "g-fomina_1979@postgrespro.ru", "phone": "+70492866990"}
0005435039200	F88469	2642 510201	OLGA SOROKINA	{"phone": "+70017436790"}
0005435039201	4DEC0F	3558 271796	ALEKSANDR ANDREEV	{"phone": "+70930265231"}
0005435039202	27F4B8	1256 531664	DMITRIY FROLOV	{"phone": "+70529695431"}
0005435039203	874F44	8129 620344	SERGEY KARPOV	{"phone": "+70358300406"}
0005435039204	FD0B43	1001 747841	ILYA KARPOV	{"phone": "+70391292257"}
0005435039205	4356EB	9668 479157	OLEG IVANOV	{"email": "ivanov_oleg_091955@postgrespro.ru", "phone": "+70358716838"}
0005435039206	B0E165	2869 568844	EVGENIY KISELEV	{"email": "evgeniy_kiselev_1964@postgrespro.ru", "phone": "+70910016905"}
0005435039207	D4F48A	2932 063200	NINA GORBUNOVA	{"email": "ninagorbunova1964@postgrespro.ru", "phone": "+70098095976"}
0005435039208	B0C719	5812 860489	ANNA ZAYCEVA	{"email": "azayceva-12031967@postgrespro.ru", "phone": "+70574500117"}
0005435039209	A101F1	1707 480023	BORIS MELNIKOV	{"phone": "+70943899494"}
0005435039210	A101F1	1836 553386	ANDREY NIKITIN	{"phone": "+70101441660"}
0005435039211	272A2F	7063 027723	DMITRIY KUZNECOV	{"email": "kuznecovdmitriy.04121973@postgrespro.ru", "phone": "+70244474845"}
0005435039212	BFB80C	6081 197699	OLGA LOGINOVA	{"phone": "+70584049485"}
0005435039213	46AEF6	6907 185885	NINA GORBUNOVA	{"email": "nina-gorbunova1979@postgrespro.ru", "phone": "+70639826742"}
0005435039214	A36EF0	1253 562456	GALINA SOROKINA	{"phone": "+70228516773"}
0005435039215	77C3AB	7291 663682	NATALYA SAVELEVA	{"email": "n_saveleva111979@postgrespro.ru", "phone": "+70605294819"}
0005435039216	77C3AB	9529 880927	VARVARA FROLOVA	{"email": "v_frolova_02011982@postgrespro.ru", "phone": "+70026512364"}
0005435039217	0206D7	8969 226566	DARYA MOROZOVA	{"email": "darya_morozova-11011966@postgrespro.ru", "phone": "+70922593886"}
0005435039218	FB1B1F	7618 665356	SERGEY ZHUKOV	{"phone": "+70718974952"}
0005435039219	8CA8B2	8593 276573	EKATERINA ZAKHAROVA	{"phone": "+70012066433"}
0005435039220	8CA8B2	1421 801310	VIKTOR DENISOV	{"phone": "+70962408067"}
0005435039221	194A09	0274 390893	VLADIMIR ZHURAVLEV	{"email": "vladimir-zhuravlev.1970@postgrespro.ru", "phone": "+70624577477"}
0005435039222	5D89A5	6473 796921	ASKHAT DENISOV	{"phone": "+70076109151"}
0005435039223	8ABFF6	7288 957478	SERGEY IVANOV	{"phone": "+70823348207"}
0005435039224	F943D8	3173 772997	ALEKSANDR MOROZOV	{"email": "a_morozov_28121978@postgrespro.ru", "phone": "+70761101673"}
0005435039225	ACD7B2	3995 293073	TATYANA LEBEDEVA	{"phone": "+70309585450"}
0005435039226	5A8F23	1390 612199	IGOR TIMOFEEV	{"phone": "+70290864881"}
0005435039227	5A8F23	1587 580184	ELENA BARANOVA	{"phone": "+70731693123"}
0005435039228	9B0382	1932 766165	VIOLETTA ZHURAVLEVA	{"email": "violettazhuravleva_23011987@postgrespro.ru", "phone": "+70363406009"}
0005435039229	E79547	0193 987635	SERGEY NAUMOV	{"email": "sergey-naumov-081970@postgrespro.ru", "phone": "+70745765479"}
0005435039230	490087	4343 972455	MIKHAIL ORLOV	{"email": "orlov_m1972@postgrespro.ru", "phone": "+70778265054"}
0005435039231	490087	9942 012161	VLADIMIR ANTONOV	{"phone": "+70994953384"}
0005435039232	C98465	6734 056360	YANA ALEKSEEVA	{"email": "yanaalekseeva-23031975@postgrespro.ru", "phone": "+70514036515"}
0005435039233	5D58A2	5875 851860	LYUBOV RYABOVA	{"email": "l-ryabova.21101979@postgrespro.ru", "phone": "+70872171189"}
0005435039234	658621	7220 825482	ALEKSEY BORISOV	{"phone": "+70963753208"}
0005435039235	9B01F9	1489 669268	LYUBOV SEMENOVA	{"phone": "+70616526998"}
0005435039236	9B01F9	2616 076166	MARINA ALEKSANDROVA	{"phone": "+70217978422"}
0005435039237	FD86F5	2430 285890	PAVEL MAKAROV	{"email": "p.makarov-061967@postgrespro.ru", "phone": "+70562426945"}
0005435039238	2FAAC6	2697 759192	EVGENIY NAUMOV	{"email": "naumov.e1961@postgrespro.ru", "phone": "+70388968520"}
0005435039239	B1CD7C	0393 331186	IRINA SEMENOVA	{"email": "i-semenova_021972@postgrespro.ru", "phone": "+70082354362"}
0005435039240	B1CD7C	5006 072875	MIKHAIL NIKITIN	{"email": "nikitin-m_061975@postgrespro.ru", "phone": "+70808203972"}
0005435039241	C23B9C	4411 750168	SERGEY GERASIMOV	{"phone": "+70719214245"}
0005435039242	CFDAD7	0091 157449	DMITRIY GERASIMOV	{"email": "d-gerasimov.031973@postgrespro.ru", "phone": "+70332256773"}
0005435039243	CFDAD7	7101 662544	VLADIMIR IVANOV	{"email": "ivanovvladimir_061956@postgrespro.ru", "phone": "+70749587274"}
0005435039244	7DEABD	7144 515717	MARIYA MIRONOVA	{"email": "m-mironova.26031966@postgrespro.ru", "phone": "+70509278812"}
0005435039245	7DEABD	8295 079255	RUMIYA VASILEVA	{"email": "rvasileva.031969@postgrespro.ru", "phone": "+70367664909"}
0005435039246	A8A1E1	8000 927605	EVGENIY MAKAROV	{"phone": "+70210356755"}
0005435039247	3D38EB	3850 803559	SVETLANA ZHUKOVA	{"phone": "+70438252099"}
0005435039248	719373	7914 390298	DANILA GAVRILOV	{"email": "gavrilov.danila.1976@postgrespro.ru", "phone": "+70043148034"}
0005435039249	A22EAA	8827 884422	OLGA YAKOVLEVA	{"phone": "+70737453196"}
0005435039250	60D7BA	2944 745896	ANNA FILATOVA	{"email": "anna-filatova28091978@postgrespro.ru", "phone": "+70127908186"}
0005435039251	D994D4	9506 344361	KIRILL GERASIMOV	{"email": "gerasimov.k.1981@postgrespro.ru", "phone": "+70468685817"}
0005435039252	D3C3BE	3486 887342	YURIY NOVIKOV	{"email": "yuriy-novikov_111956@postgrespro.ru", "phone": "+70690337860"}
0005435039253	4B1493	2836 771486	NIKOLAY ANTONOV	{"phone": "+70821279295"}
0005435039254	EA055C	6677 816008	VALENTIN MAKAROV	{"email": "v-makarov.11051976@postgrespro.ru", "phone": "+70993009259"}
0005435039255	1DB719	7179 270372	LYUDMILA KRASNOVA	{"email": "krasnova_lyudmila_021970@postgrespro.ru", "phone": "+70652713417"}
0005435039256	741C83	4727 360031	SERGEY SERGEEV	{"phone": "+70788287016"}
0005435039257	741C83	6180 538107	GENNADIY POPOV	{"email": "popov-gennadiy.101968@postgrespro.ru", "phone": "+70264901373"}
0005435039258	848420	0444 987499	EVGENIY FOMIN	{"email": "fomin.evgeniy-1964@postgrespro.ru", "phone": "+70420360129"}
0005435039259	4ECC2C	5430 116687	VSEVOLOD SCHERBAKOV	{"email": "scherbakov_vsevolod_15011979@postgrespro.ru", "phone": "+70492901279"}
0005435039260	633917	0323 632792	VLADIMIR NAUMOV	{"phone": "+70573995588"}
0005435039261	633917	6108 918037	ALENA NAUMOVA	{"email": "alena-naumova1972@postgrespro.ru", "phone": "+70886083014"}
0005435039262	633917	2242 620070	OLGA NOVIKOVA	{"phone": "+70875004228"}
0005435039263	6A2D6D	0085 614120	VASILIY ZAKHAROV	{"email": "zakharov-v121974@postgrespro.ru", "phone": "+70595890294"}
0005435039264	23CC2D	2140 698728	ALEKSANDR NAUMOV	{"email": "aleksandr.naumov_1975@postgrespro.ru", "phone": "+70408855776"}
0005435039266	DD059C	0283 336549	ARTEM KOROLEV	{"email": "artemkorolev.1961@postgrespro.ru", "phone": "+70341455835"}
0005435039267	DD4492	8228 479707	NADEZHDA SOKOLOVA	{"phone": "+70650108079"}
0005435039268	DD4492	5284 669101	ILYA DENISOV	{"email": "ilya.denisov_06011960@postgrespro.ru", "phone": "+70635318440"}
0005435039269	05EEF1	2052 621747	ELENA DENISOVA	{"email": "edenisova061964@postgrespro.ru", "phone": "+70615203110"}
0005435039449	CB1A25	4036 123400	SERGEY MATVEEV	{"phone": "+70661033380"}
0005435039270	C56183	1756 099831	NINA MIKHAYLOVA	{"email": "mikhaylovanina_13061982@postgrespro.ru", "phone": "+70570810644"}
0005435039271	C56183	3179 664573	SERGEY EGOROV	{"phone": "+70454561878"}
0005435039272	36DD07	3985 832851	SEMEN KUZNECOV	{"phone": "+70709086605"}
0005435039273	36DD07	1070 861230	ANTONINA TARASOVA	{"email": "tarasova-antonina081974@postgrespro.ru", "phone": "+70186644169"}
0005435039274	CE9729	5318 243012	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov_07051967@postgrespro.ru", "phone": "+70297852384"}
0005435039275	3CEFCB	0612 222425	YULIYA SOLOVEVA	{"phone": "+70830794486"}
0005435039276	0B55B0	7756 382387	TAMARA IVANOVA	{"email": "t_ivanova.111976@postgrespro.ru", "phone": "+70855763842"}
0005435039277	76A1BA	8648 579606	TIMOFEY ZAYCEV	{"phone": "+70286129707"}
0005435039278	3D2B4A	7913 693500	NIKOLAY SOROKIN	{"email": "sorokin_nikolay.1977@postgrespro.ru", "phone": "+70700291072"}
0005435039279	EC41D6	8396 145357	SVETLANA KOZLOVA	{"phone": "+70615678150"}
0005435039280	1A6285	2846 485842	NINA POLYAKOVA	{"phone": "+70855293547"}
0005435039281	26A87E	3515 349136	MARIYA MAKAROVA	{"phone": "+70089516078"}
0005435039282	CF6A80	1536 566261	MARIYA EFREMOVA	{"email": "efremova.mariya-101968@postgrespro.ru", "phone": "+70704193165"}
0005435039283	CF6A80	7622 674426	TATYANA TIKHONOVA	{"phone": "+70328934774"}
0005435039284	35AA0B	6898 564141	TATYANA NIKOLAEVA	{"email": "nikolaeva-t_111971@postgrespro.ru", "phone": "+70405245833"}
0005435039285	35AA0B	4598 603596	DENIS VLASOV	{"email": "denis-vlasov_1970@postgrespro.ru", "phone": "+70716598219"}
0005435039286	6B39DB	9751 361327	VLADIMIR NAZAROV	{"email": "nazarov.v121983@postgrespro.ru", "phone": "+70671518663"}
0005435039287	13FFEF	5142 730740	VALENTINA PAVLOVA	{"phone": "+70274495257"}
0005435039288	13FFEF	4598 050711	POLINA BORISOVA	{"phone": "+70609971194"}
0005435039289	FDA09C	4134 644188	MARINA NAZAROVA	{"email": "marina-nazarova1980@postgrespro.ru", "phone": "+70408885928"}
0005435039290	FDA09C	9343 235270	IRINA KOZLOVA	{"email": "kozlova-i-061970@postgrespro.ru", "phone": "+70527549526"}
0005435039291	FDA09C	6783 382867	ALEKSANDR TIMOFEEV	{"email": "a.timofeev_1956@postgrespro.ru", "phone": "+70523741495"}
0005435039292	659009	6944 857623	TATYANA KUZNECOVA	{"email": "tkuznecova.031981@postgrespro.ru", "phone": "+70925047050"}
0005435039293	36FC81	2824 614691	TIMUR POPOV	{"email": "timur_popov20061966@postgrespro.ru", "phone": "+70227317363"}
0005435039294	36FC81	2084 757004	ALEKSANDR KAZAKOV	{"phone": "+70016270652"}
0005435039295	E3BDEF	4593 209947	RASHIT OSIPOV	{"phone": "+70318662738"}
0005435039296	5F808A	0757 479574	ANDREY BARANOV	{"email": "baranov-andrey.1978@postgrespro.ru", "phone": "+70051182847"}
0005435039297	0F36E8	8411 328730	NADEZHDA BELOVA	{"phone": "+70468294258"}
0005435039298	B612FF	7030 944070	LYUDMILA POLYAKOVA	{"phone": "+70863002123"}
0005435039299	B612FF	6635 701113	MIKHAIL FEDOTOV	{"email": "fedotov.mikhail-23101971@postgrespro.ru", "phone": "+70660995467"}
0005435039300	4DB3FC	3674 449605	VLADIMIR KARPOV	{"phone": "+70746207123"}
0005435039301	F286B8	8223 276257	EVGENIY VOLKOV	{"phone": "+70612134747"}
0005435039302	4779C9	5527 803981	IVAN SMIRNOV	{"phone": "+70810591017"}
0005435039303	E81CCD	4631 490384	YULIYA ZAKHAROVA	{"phone": "+70121370122"}
0005435039304	6C4154	9747 402702	DMITRIY SEMENOV	{"email": "d.semenov-23101971@postgrespro.ru", "phone": "+70582252415"}
0005435039305	EAA7F9	2423 803358	TATYANA GRISHINA	{"email": "grishina_t_101973@postgrespro.ru", "phone": "+70747403488"}
0005435039306	A15797	6949 915298	YULIYA ORLOVA	{"email": "orlova.y.15061961@postgrespro.ru", "phone": "+70413627114"}
0005435039307	3F2AB3	3478 941132	LIDIYA DENISOVA	{"phone": "+70815501847"}
0005435039308	7661FA	7752 947636	SVETLANA ARKHIPOVA	{"phone": "+70753174107"}
0005435039309	7661FA	9453 113845	VALENTINA ISAEVA	{"phone": "+70321867024"}
0005435039310	7661FA	8597 755663	VALENTIN POPOV	{"email": "popov_valentin_091972@postgrespro.ru", "phone": "+70124566772"}
0005435039311	00D0D4	7371 283609	MIKHAIL IVANOV	{"phone": "+70005123607"}
0005435039312	52AE67	9000 821501	YULIYA VOLKOVA	{"email": "yvolkova-1965@postgrespro.ru", "phone": "+70362939430"}
0005435039313	52AE67	9445 669398	DENIS KUZNECOV	{"email": "kuznecov_d_101971@postgrespro.ru", "phone": "+70152361559"}
0005435039314	CC1145	0310 547187	NADEZHDA MOISEEVA	{"email": "n.moiseeva031972@postgrespro.ru", "phone": "+70393366689"}
0005435039315	1E26A0	0963 594684	NATALYA GORBUNOVA	{"email": "gorbunova.natalya.041972@postgrespro.ru", "phone": "+70627613386"}
0005435039316	1E26A0	4769 166015	VASILIY SHEVCHENKO	{"email": "shevchenko-vasiliy.07011962@postgrespro.ru", "phone": "+70136639439"}
0005435039317	8C7069	5133 099534	YURIY NIKOLAEV	{"email": "y_nikolaev-1984@postgrespro.ru", "phone": "+70001108810"}
0005435039318	8C7069	0546 064916	VIKTORIYA GUSEVA	{"email": "viktoriya_guseva_1972@postgrespro.ru", "phone": "+70583385471"}
0005435039319	263DF8	9511 790837	KIRILL VASILEV	{"phone": "+70271399231"}
0005435039320	263DF8	3633 129119	SERGEY VOROBEV	{"email": "svorobev.29081966@postgrespro.ru", "phone": "+70681323830"}
0005435039321	38BECF	6716 432129	NADEZHDA AFANASEVA	{"email": "nadezhda_afanaseva_1964@postgrespro.ru", "phone": "+70909933391"}
0005435039322	38BECF	1064 400659	MIKHAIL IVANOV	{"phone": "+70031279402"}
0005435039323	2D5A72	0379 072495	RUSLAN IVANOV	{"email": "ivanov-ruslan17091980@postgrespro.ru", "phone": "+70752959672"}
0005435039324	86D1A4	1253 415507	LILIYA EFREMOVA	{"phone": "+70626316771"}
0005435039325	712AC8	7650 971659	YURIY STEPANOV	{"phone": "+70004374655"}
0005435039326	1DB644	7773 486798	ANATOLIY BORISOV	{"phone": "+70369414213"}
0005435039327	1DB644	4029 377346	NATALYA LAZAREVA	{"phone": "+70172669982"}
0005435039328	C9B07C	4784 008894	OLGA POTAPOVA	{"email": "olgapotapova091985@postgrespro.ru", "phone": "+70766414351"}
0005435039329	C9B07C	7231 386941	NIKOLAY KULIKOV	{"phone": "+70009226913"}
0005435039330	9853CD	0544 381935	ELENA BARANOVA	{"email": "e_baranova1966@postgrespro.ru", "phone": "+70273905392"}
0005435039331	C05F83	4961 160368	VASILIY DAVYDOV	{"phone": "+70321126673"}
0005435039332	038B09	9693 905922	EVGENIY NOVIKOV	{"phone": "+70731289666"}
0005435039333	038B09	7720 157993	ANDREY KUZNECOV	{"email": "a.kuznecov22121972@postgrespro.ru", "phone": "+70427298285"}
0005435039334	F90FFC	3645 924192	SVETLANA EGOROVA	{"email": "egorova.s.1964@postgrespro.ru", "phone": "+70364015429"}
0005435039335	F90FFC	2248 987068	NATALYA MIRONOVA	{"phone": "+70211996988"}
0005435039336	6549DA	6479 306568	GALINA MIKHAYLOVA	{"email": "g_mikhaylova29041960@postgrespro.ru", "phone": "+70105546905"}
0005435039337	C66D67	7746 849805	OLGA ZAKHAROVA	{"phone": "+70550636782"}
0005435039338	C66D67	1787 472825	EKATERINA RYABOVA	{"email": "eryabova_11111985@postgrespro.ru", "phone": "+70402776211"}
0005435039339	31733C	0233 953565	ANTON MATVEEV	{"email": "antonmatveev-22041972@postgrespro.ru", "phone": "+70106521157"}
0005435039340	31733C	1726 428418	NATALYA KOROLEVA	{"phone": "+70846602789"}
0005435039341	F3CB11	0400 371204	ANDREY PETROV	{"phone": "+70193535813"}
0005435039342	7F0BC4	4116 140446	ELENA DAVYDOVA	{"email": "davydova-e_1966@postgrespro.ru", "phone": "+70149609421"}
0005435039343	F7F25C	3499 983654	NATALYA KALININA	{"phone": "+70164269085"}
0005435039344	F16197	8635 422864	SERGEY IVANOV	{"email": "s.ivanov.111968@postgrespro.ru", "phone": "+70942327806"}
0005435039345	F16197	5744 614717	EVGENIY KOZLOV	{"email": "evgeniy-kozlov-041975@postgrespro.ru", "phone": "+70586149641"}
0005435039346	9AABE5	3058 023152	OLGA KOZLOVA	{"phone": "+70116882758"}
0005435039347	9AABE5	5541 081222	MURAT IVANOV	{"phone": "+70466210826"}
0005435039348	23166E	7039 603813	LYUDMILA SOLOVEVA	{"phone": "+70119245405"}
0005435039349	F6A479	5557 484172	IGOR ZAYCEV	{"phone": "+70576172850"}
0005435039350	0B5B04	9166 103436	VALENTINA EGOROVA	{"phone": "+70692831557"}
0005435039351	CEBFA6	0363 027800	MARINA PETROVA	{"email": "petrova-m1975@postgrespro.ru", "phone": "+70994307592"}
0005435039352	4FC1C5	0219 181481	ALEKSANDR MAKSIMOV	{"phone": "+70340305029"}
0005435039353	4FC1C5	2632 497153	KONSTANTIN SCHERBAKOV	{"email": "scherbakov_konstantin-1972@postgrespro.ru", "phone": "+70105433614"}
0005435039354	4A3274	1930 904573	ANNA MIKHAYLOVA	{"phone": "+70923949809"}
0005435039355	CAAEC3	5302 940452	EKATERINA KRASNOVA	{"phone": "+70108130357"}
0005435039356	CAAEC3	0357 665966	SERGEY ALEKSEEV	{"email": "alekseev-s_04091961@postgrespro.ru", "phone": "+70360240945"}
0005435039357	62B478	0706 551230	ALEKSEY PAVLOV	{"email": "pavlov_aleksey-071983@postgrespro.ru", "phone": "+70172203863"}
0005435039358	F9D0AE	5021 228802	ALEKSANDR CHERNOV	{"phone": "+70193658604"}
0005435039359	F9D0AE	3773 120820	SVETLANA BARANOVA	{"email": "s-baranova.1972@postgrespro.ru", "phone": "+70905061242"}
0005435039360	E85CEF	0272 252600	VLADIMIR ZAKHAROV	{"phone": "+70882147484"}
0005435039361	415640	6114 240063	IRAIDA ZHURAVLEVA	{"phone": "+70078092939"}
0005435039362	415640	1104 657990	EVGENIYA ALEKSANDROVA	{"email": "evgeniya_aleksandrova_25031984@postgrespro.ru", "phone": "+70571214933"}
0005435039363	68C58D	8131 888565	VLADIMIR ZAYCEV	{"phone": "+70430129842"}
0005435039364	68C58D	9361 787357	MARINA KOROLEVA	{"email": "koroleva-marina_1982@postgrespro.ru", "phone": "+70666045131"}
0005435039365	68C58D	0334 891186	ELENA SOROKINA	{"email": "e.sorokina.21031972@postgrespro.ru", "phone": "+70874102084"}
0005435039366	25C5C7	8527 750046	ANNA ARKHIPOVA	{"email": "arkhipova_a011969@postgrespro.ru", "phone": "+70034540461"}
0005435039367	25C5C7	7200 377772	DANILA ZAKHAROV	{"email": "danila.zakharov_07091967@postgrespro.ru", "phone": "+70573554860"}
0005435039368	6B93DA	9890 971033	DMITRIY FEDOTOV	{"phone": "+70559484976"}
0005435039369	6B93DA	0494 922179	ROSTISLAV VLASOV	{"email": "r-vlasov-04071971@postgrespro.ru", "phone": "+70298755712"}
0005435039370	F57F27	6273 946470	YURIY FEDOTOV	{"email": "fedotov-yuriy041979@postgrespro.ru", "phone": "+70929772394"}
0005435039371	F57F27	0289 345793	ALEKSANDR ZHUKOV	{"email": "zhukov-aleksandr031980@postgrespro.ru", "phone": "+70389482908"}
0005435039372	F57F27	2556 198297	VIKTOR GUSEV	{"email": "viktor.gusev1968@postgrespro.ru", "phone": "+70574237454"}
0005435039373	02E64F	9067 990412	IGOR IVANOV	{"phone": "+70966938441"}
0005435039374	682446	5284 004038	ALEKSANDR FEDOTOV	{"phone": "+70725082996"}
0005435039375	64B3BF	4294 407345	KARINA FEDOROVA	{"phone": "+70340906935"}
0005435039376	0AECAF	1754 190387	ELENA OSIPOVA	{"phone": "+70014129370"}
0005435039377	76A0D6	6989 316957	IRINA SMIRNOVA	{"email": "irina.smirnova.16091970@postgrespro.ru", "phone": "+70057281249"}
0005435039378	2EAA82	8979 724206	YURIY KUDRYASHOV	{"email": "kudryashov.y.12101978@postgrespro.ru", "phone": "+70257610393"}
0005435039379	6FC101	0658 422923	ALEKSANDR NIKOLAEV	{"email": "aleksandr_nikolaev-1984@postgrespro.ru", "phone": "+70416281896"}
0005435039380	4ECFC2	5205 620383	ILYA SEMENOV	{"email": "ilya_semenov.1966@postgrespro.ru", "phone": "+70724476673"}
0005435039381	4ECFC2	9978 076177	NATALYA KISELEVA	{"email": "n_kiseleva_1980@postgrespro.ru", "phone": "+70012181621"}
0005435039382	4ECFC2	9684 209350	YURIY SIDOROV	{"email": "yuriysidorov-25081973@postgrespro.ru", "phone": "+70681941346"}
0005435039383	B3BC66	3427 569696	MARIYA FILATOVA	{"phone": "+70575871870"}
0005435039384	B3BC66	3266 008858	OLGA PAVLOVA	{"email": "olga.pavlova.061953@postgrespro.ru", "phone": "+70487604182"}
0005435039385	4F7323	9734 777624	ELENA KULIKOVA	{"phone": "+70651257861"}
0005435039386	A80ED5	2094 648083	ANTONINA ZOTOVA	{"phone": "+70483969552"}
0005435039387	F4802D	2583 328275	EGOR ORLOV	{"email": "egor_orlov1973@postgrespro.ru", "phone": "+70242398599"}
0005435039388	F4802D	7571 879911	LILIYA ISAEVA	{"phone": "+70482244823"}
0005435039389	C06ABD	5342 801280	LYUDMILA AKIMOVA	{"phone": "+70886864975"}
0005435039390	6E1C42	1015 840192	ELENA KONOVALOVA	{"email": "konovalovaelena_061968@postgrespro.ru", "phone": "+70610708721"}
0005435039391	6E1C42	5297 117089	ANASTASIYA GORBUNOVA	{"phone": "+70618191655"}
0005435039392	8E4955	8562 904600	NATALIYA SEMENOVA	{"email": "nataliya-semenova.20091976@postgrespro.ru", "phone": "+70857908847"}
0005435039393	8E4955	7351 348013	ANNA LAZAREVA	{"email": "a.lazareva081973@postgrespro.ru", "phone": "+70161701799"}
0005435039394	B9CD10	2640 754385	NATALYA OSIPOVA	{"email": "osipova-n-1972@postgrespro.ru", "phone": "+70896668973"}
0005435039395	EDDD9D	5072 384974	IRINA FOMINA	{"email": "irina-fomina_1972@postgrespro.ru", "phone": "+70648227013"}
0005435039396	CAE851	9642 307897	ANFISA MOISEEVA	{"phone": "+70732784388"}
0005435039397	F78970	3798 340881	VLADIMIR ANDREEV	{"email": "andreev_vladimir.20111974@postgrespro.ru", "phone": "+70510773362"}
0005435039398	6F4FD5	0907 392002	IVAN ALEKSANDROV	{"phone": "+70184985927"}
0005435039399	59F621	5814 803451	ANDREY KRASNOV	{"phone": "+70945080071"}
0005435039400	FD8DE2	1741 586122	SVETLANA STEPANOVA	{"email": "stepanova.s-1975@postgrespro.ru", "phone": "+70914562414"}
0005435039401	FD8DE2	6240 462255	YURIY ABRAMOV	{"phone": "+70918343543"}
0005435039402	A3610C	5321 507672	VIKTOR KISELEV	{"phone": "+70188248343"}
0005435039403	18D876	7606 033497	VALERIY KUDRYASHOV	{"email": "kudryashov_valeriy_19051968@postgrespro.ru", "phone": "+70731919592"}
0005435039404	97C5BF	0983 630026	ALINA ZAYCEVA	{"phone": "+70410669853"}
0005435039405	6155BC	7255 178563	MIKHAIL KAZAKOV	{"email": "m-kazakov_121972@postgrespro.ru", "phone": "+70174119053"}
0005435039406	379C22	4986 369551	DARYA EFIMOVA	{"phone": "+70308319154"}
0005435039407	379C22	3733 728427	VERA MIKHAYLOVA	{"email": "mikhaylova_vera_1976@postgrespro.ru", "phone": "+70547048691"}
0005435039408	379C22	4990 215812	INNA SCHERBAKOVA	{"email": "innascherbakova_04011976@postgrespro.ru", "phone": "+70132529590"}
0005435039409	45A425	1126 155144	ELENA TIKHONOVA	{"email": "elena_tikhonova.091970@postgrespro.ru", "phone": "+70784688148"}
0005435039410	89A3E6	8406 511665	MIKHAIL FEDOROV	{"phone": "+70959498211"}
0005435039411	89A3E6	8993 064638	ANATOLIY IVANOV	{"phone": "+70655324759"}
0005435039412	85317F	1399 455489	LYUDMILA LUKYANOVA	{"email": "lyudmila.lukyanova101975@postgrespro.ru", "phone": "+70914303233"}
0005435039413	EAD9E4	3671 877498	NATALYA POPOVA	{"email": "popova.natalya09011980@postgrespro.ru", "phone": "+70333573978"}
0005435039414	501AF7	0969 796259	RINAT NAZAROV	{"email": "nazarov_rinat_15061967@postgrespro.ru", "phone": "+70458177363"}
0005435039415	F9D624	0037 961534	ALEKSANDR MELNIKOV	{"email": "aleksandr_melnikov-1981@postgrespro.ru", "phone": "+70673444132"}
0005435039416	C9590F	1733 163475	ALEKSANDR KAZAKOV	{"phone": "+70064573230"}
0005435039417	790177	2135 489136	ALENA NOVIKOVA	{"phone": "+70577825627"}
0005435039418	776320	6880 921637	SVETLANA FILATOVA	{"phone": "+70712893329"}
0005435039419	A3CCBF	7638 494761	ALEKSANDR KRASNOV	{"phone": "+70320141382"}
0005435039420	78ADC4	0896 663414	ZINAIDA SOKOLOVA	{"phone": "+70883781259"}
0005435039421	78ADC4	3881 732648	LEV SCHERBAKOV	{"phone": "+70427052934"}
0005435039422	83C10E	8204 435685	MAKSIM EGOROV	{"email": "egorov_m.031973@postgrespro.ru", "phone": "+70485275939"}
0005435039423	F023E1	4587 231515	SERGEY YAKOVLEV	{"email": "yakovlevs_091974@postgrespro.ru", "phone": "+70163741791"}
0005435039424	F023E1	7503 903598	YULIYA GAVRILOVA	{"email": "gavrilovayuliya-11031964@postgrespro.ru", "phone": "+70831933885"}
0005435039425	397F26	2222 837445	SERGEY IVANOV	{"phone": "+70033066507"}
0005435039426	C32B88	3112 447893	NATALYA KUZNECOVA	{"phone": "+70131029900"}
0005435039427	C32B88	1943 730225	EVGENIY CHERNOV	{"phone": "+70970397472"}
0005435039428	93E113	0873 747139	ANNA VOLKOVA	{"email": "anna-volkova_071975@postgrespro.ru", "phone": "+70948976765"}
0005435039429	40FC45	2052 186999	OLEG KRASNOV	{"email": "oleg-krasnov_17091971@postgrespro.ru", "phone": "+70534908245"}
0005435039430	D3FC95	7454 289156	IRINA MAKAROVA	{"email": "makarova.irina061988@postgrespro.ru", "phone": "+70148952547"}
0005435039431	1FDDAF	5873 894654	MARINA AKIMOVA	{"phone": "+70688638112"}
0005435039432	274993	9730 075290	PETR GRIGOREV	{"phone": "+70780453870"}
0005435039433	C47AEC	5353 151871	IRINA GRISHINA	{"phone": "+70824244097"}
0005435039434	5F43DF	9962 078746	VALERIYA MALYSHEVA	{"email": "malysheva_v071963@postgrespro.ru", "phone": "+70191048003"}
0005435039435	5F43DF	8562 398434	SERGEY VASILEV	{"phone": "+70353263506"}
0005435039436	B994F5	8919 454849	ELENA VOLKOVA	{"phone": "+70380423952"}
0005435039437	05F7E3	7550 528724	SERGEY POPOV	{"phone": "+70765703214"}
0005435039438	55FF45	2375 298163	ALEKSANDR AFANASEV	{"email": "afanasev-a031967@postgrespro.ru", "phone": "+70078917850"}
0005435039439	55FF45	2625 393796	VLADIMIR KUZMIN	{"email": "vladimirkuzmin_031968@postgrespro.ru", "phone": "+70635146914"}
0005435039440	979B1C	3078 309310	SERGEY FROLOV	{"email": "frolov.s.02071963@postgrespro.ru", "phone": "+70076599552"}
0005435039441	3967ED	1116 886294	SERGEY MIKHAYLOV	{"email": "s.mikhaylov.30011971@postgrespro.ru", "phone": "+70624854933"}
0005435039442	62D3D1	8679 956640	SVETLANA MELNIKOVA	{"email": "s_melnikova.1956@postgrespro.ru", "phone": "+70730142418"}
0005435039443	62D3D1	0056 950622	ALEKSEY BONDARENKO	{"email": "aleksey_bondarenko_121974@postgrespro.ru", "phone": "+70078172657"}
0005435039444	697683	9948 438605	OLGA IVANOVA	{"email": "ivanova-o1974@postgrespro.ru", "phone": "+70575610654"}
0005435039445	00AC32	2702 082026	YURIY NAZAROV	{"email": "nazarovy1971@postgrespro.ru", "phone": "+70075384732"}
0005435039446	3DC0D9	9090 011257	OLGA SAVELEVA	{"email": "o.saveleva.19101979@postgrespro.ru", "phone": "+70013956529"}
0005435039447	3ADFBF	4559 496676	PETR POPOV	{"email": "petr_popov_06111970@postgrespro.ru", "phone": "+70222264506"}
0005435039448	CB1A25	2681 303955	IRINA VASILEVA	{"email": "i-vasileva.1973@postgrespro.ru", "phone": "+70396787543"}
0005435039450	97A36A	3503 907378	MARIYA GERASIMOVA	{"phone": "+70862036977"}
0005435039451	AB4A88	3369 312266	YURIY NIKITIN	{"phone": "+70235934189"}
0005435039452	AB4A88	3960 035301	YULIYA ORLOVA	{"phone": "+70630542076"}
0005435039453	AB4A88	1031 394265	LYUDMILA LAZAREVA	{"email": "lyudmila.lazareva.041965@postgrespro.ru", "phone": "+70528992768"}
0005435039454	B8F3FD	3720 194642	GALINA IVANOVA	{"email": "ivanova_g_05111982@postgrespro.ru", "phone": "+70900885614"}
0005435039455	D3E362	2980 221054	SERGEY DMITRIEV	{"email": "sergey_dmitriev22121981@postgrespro.ru", "phone": "+70113556749"}
0005435039456	FF7902	9625 344131	MAKSIM MAKAROV	{"email": "makarov-maksim_1968@postgrespro.ru", "phone": "+70972509960"}
0005435039457	0EDAB4	1244 920911	LYUDMILA ANDREEVA	{"phone": "+70626629921"}
0005435039458	B82E81	7753 488321	ALENA GORBUNOVA	{"phone": "+70611355204"}
0005435039459	17B1AD	1313 513178	ANTONINA TARASOVA	{"phone": "+70575963386"}
0005435039460	C91405	2806 705299	MARINA TIKHONOVA	{"phone": "+70362235092"}
0005435039461	C91405	1824 125928	VASILIY KUZMIN	{"email": "vkuzmin.081967@postgrespro.ru", "phone": "+70010455723"}
0005435039462	CF5E8D	1338 659848	KSENIYA PAVLOVA	{"phone": "+70218599262"}
0005435039463	B266B8	8090 039745	OLGA FROLOVA	{"phone": "+70156648173"}
0005435039464	28DB8B	7616 596365	ALEKSEY FOMIN	{"email": "afomin-031966@postgrespro.ru", "phone": "+70053189517"}
0005435039465	3E0A41	8580 314145	IVAN ZAKHAROV	{"email": "zakharov_ivan-041981@postgrespro.ru", "phone": "+70899506154"}
0005435039466	D9B6D2	9043 514545	MAKSIM MIKHAYLOV	{"phone": "+70754045009"}
0005435039467	D9B6D2	1018 041805	EKATERINA ROMANOVA	{"email": "e-romanova031977@postgrespro.ru", "phone": "+70201731327"}
0005435039468	DC0583	6822 387896	VLADIMIR KUZNECOV	{"phone": "+70983688957"}
0005435039469	D74FAF	5193 369558	ALEKSANDRA NIKIFOROVA	{"email": "a_nikiforova-091972@postgrespro.ru", "phone": "+70673064373"}
0005435039470	58F801	3455 239151	TATYANA IVANOVA	{"phone": "+70608269450"}
0005435039471	4EEB2B	9992 516001	ALEKSANDR NIKITIN	{"phone": "+70251539916"}
0005435039472	0EB77D	0351 803504	ANDREY SERGEEV	{"phone": "+70242492046"}
0005435039473	0EB77D	0295 472093	ELENA BARANOVA	{"email": "baranova_e_28051980@postgrespro.ru", "phone": "+70125142496"}
0005435039474	40AADD	5820 018241	ANDREY TARASOV	{"phone": "+70286229052"}
0005435039475	40AADD	3286 576415	KSENIYA MALYSHEVA	{"email": "k.malysheva1986@postgrespro.ru", "phone": "+70437398684"}
0005435039476	AB20C0	6918 484441	ALEKSANDR PAVLOV	{"email": "apavlov.12121978@postgrespro.ru", "phone": "+70624763784"}
0005435039477	58788D	3045 374914	EGOR ANDREEV	{"phone": "+70724512298"}
0005435039478	58788D	7309 815964	VALENTINA ZOTOVA	{"email": "zotova_v021967@postgrespro.ru", "phone": "+70335637795"}
0005435039479	820B4F	9485 448741	NATALYA EGOROVA	{"email": "egorovanatalya-22051975@postgrespro.ru", "phone": "+70727935508"}
0005435039480	5D3036	2329 779255	SERGEY SMIRNOV	{"email": "smirnovs-23011968@postgrespro.ru", "phone": "+70042217266"}
0005435039481	2A7657	4195 526531	ALEKSANDR FROLOV	{"email": "frolov_aleksandr.1977@postgrespro.ru", "phone": "+70576263030"}
0005435039482	1DF171	6243 355033	VALERIY VLASOV	{"phone": "+70364127465"}
0005435039483	792206	6646 338860	VASILIY BARANOV	{"phone": "+70718954592"}
0005435039484	2BFCF9	8315 366534	VALERIYA SOLOVEVA	{"email": "vsoloveva_041981@postgrespro.ru", "phone": "+70094259561"}
0005435039485	2BFCF9	9954 442861	MARINA SERGEEVA	{"phone": "+70637711494"}
0005435039486	2BFCF9	6031 481380	ALEKSANDR SOROKIN	{"phone": "+70051504676"}
0005435039487	A4C0E0	6921 725154	PAVEL TARASOV	{"phone": "+70405977243"}
0005435039488	952DD7	4729 082878	NATALYA BELOVA	{"phone": "+70339264261"}
0005435039489	763D67	5576 461387	LARISA OVCHINNIKOVA	{"email": "ovchinnikova.larisa_1978@postgrespro.ru", "phone": "+70478348969"}
0005435039490	30C397	0263 210036	VALERIY ZAYCEV	{"email": "zaycev_valeriy091963@postgrespro.ru", "phone": "+70956987710"}
0005435039491	67CEC2	8267 283733	KONSTANTIN IVANOV	{"email": "ivanov-k30121966@postgrespro.ru", "phone": "+70726251589"}
0005435039492	67CEC2	6733 746214	SVETLANA IVANOVA	{"phone": "+70716474836"}
0005435039493	7A1B6B	5020 097468	MILANA KOROLEVA	{"email": "milana_koroleva_25021970@postgrespro.ru", "phone": "+70106825805"}
0005435039494	56D467	7935 059421	ELVIRA ANISIMOVA	{"email": "anisimovaelvira.14111974@postgrespro.ru", "phone": "+70082498555"}
0005435039495	57FA17	4175 273356	YULIYA MOROZOVA	{"phone": "+70774764859"}
0005435039496	1F2EBA	7223 534692	ANNA ALEKSEEVA	{"email": "a_alekseeva-021968@postgrespro.ru", "phone": "+70051935940"}
0005435039497	B9BE6C	0599 702698	EVGENIYA KOROLEVA	{"email": "evgeniya_koroleva_1974@postgrespro.ru", "phone": "+70282145174"}
0005435039498	09A2E8	7510 484477	ALINA SIDOROVA	{"phone": "+70761877679"}
0005435039499	09A2E8	1703 343693	AZAT IVANOV	{"email": "a.ivanov081981@postgrespro.ru", "phone": "+70984327439"}
0005435039500	71257C	8020 007402	GALINA STEPANOVA	{"email": "galina.stepanova-1971@postgrespro.ru", "phone": "+70447923759"}
0005435039501	B09C8C	0082 651340	IVAN NIKITIN	{"email": "i.nikitin-07011976@postgrespro.ru", "phone": "+70228075020"}
0005435039502	6F4DD2	8337 578782	PAVEL ALEKSANDROV	{"email": "p.aleksandrov.1973@postgrespro.ru", "phone": "+70532696705"}
0005435039503	9E8D56	3504 075156	GALINA DENISOVA	{"phone": "+70068478259"}
0005435039504	60392A	9677 225610	TATYANA PETROVA	{"email": "t-petrova06031972@postgrespro.ru", "phone": "+70244159570"}
0005435039505	C83946	4618 934822	TATYANA FOMINA	{"phone": "+70470950710"}
0005435039506	17C124	3495 837425	LYUBOV ZOTOVA	{"phone": "+70422588036"}
0005435039507	22D960	4462 620051	MARINA ANTONOVA	{"email": "m-antonova-071975@postgrespro.ru", "phone": "+70146846402"}
0005435039508	BAE078	8634 266889	LYUBOV SEMENOVA	{"phone": "+70784414504"}
0005435039509	B88944	2376 557850	PAVEL POPOV	{"phone": "+70055553592"}
0005435039510	8C06ED	9588 706974	ELENA KRASNOVA	{"phone": "+70283056822"}
0005435039511	8C06ED	1856 274735	ANAIT POPOVA	{"phone": "+70478635262"}
0005435039512	96C66F	0167 876757	STEPAN BELOV	{"phone": "+70172928253"}
0005435039513	EA77C3	0998 611872	EVGENIYA MALYSHEVA	{"phone": "+70613242993"}
0005435039514	62E005	4695 702508	OLGA MATVEEVA	{"phone": "+70301829048"}
0005435039515	D347C4	1988 052848	SERGEY MATVEEV	{"email": "matveev_sergey_021966@postgrespro.ru", "phone": "+70850326202"}
0005435039516	27FD0F	7660 720016	SVETLANA VLASOVA	{"phone": "+70292651532"}
0005435039517	27FD0F	9313 921816	ELENA EFIMOVA	{"email": "efimova_elena-1976@postgrespro.ru", "phone": "+70880646598"}
0005435039518	27FD0F	2324 796833	ANDREY BONDARENKO	{"phone": "+70713026341"}
0005435039519	6F62F0	3046 001870	GALINA KAZAKOVA	{"phone": "+70937062534"}
0005435039520	932E9C	1663 384000	VASILIY FOMIN	{"email": "v_fomin_1974@postgrespro.ru", "phone": "+70148450758"}
0005435039521	B62A4D	3700 057930	ELENA MOROZOVA	{"email": "elena-morozova081969@postgrespro.ru", "phone": "+70649365407"}
0005435039522	B62A4D	3188 535940	SVETLANA MIRONOVA	{"email": "mironova-s121972@postgrespro.ru", "phone": "+70867152640"}
0005435039523	91C49A	6021 050656	EKATERINA DENISOVA	{"email": "e-denisova1975@postgrespro.ru", "phone": "+70178767656"}
0005435039524	91C49A	9035 024096	IVAN MAKSIMOV	{"phone": "+70669702168"}
0005435039525	27EC3C	4920 072668	LYUBOV MAKSIMOVA	{"email": "maksimova_lyubov011977@postgrespro.ru", "phone": "+70119517845"}
0005435039526	88AB14	9556 437034	ADELINA SMIRNOVA	{"phone": "+70568514887"}
0005435039527	EE95B7	3952 216314	NATALIYA KOVALEVA	{"phone": "+70979649287"}
0005435039528	7D238D	1481 653276	MARINA TIKHONOVA	{"email": "tikhonova_marina1970@postgrespro.ru", "phone": "+70187469476"}
0005435039529	0E37AB	2167 907918	OLGA POTAPOVA	{"email": "potapova.o_1963@postgrespro.ru", "phone": "+70670768895"}
0005435039530	0E37AB	6549 990441	NATALYA PETROVA	{"email": "petrova_natalya071973@postgrespro.ru", "phone": "+70849651134"}
0005435039531	549B5B	5741 196998	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr_111967@postgrespro.ru", "phone": "+70993398056"}
0005435039532	C6D6D4	8188 237423	LARISA KUZNECOVA	{"email": "kuznecova-l.1971@postgrespro.ru", "phone": "+70071124887"}
0005435039533	E4B99E	7858 316863	MARIYA POTAPOVA	{"email": "potapova-m.30081969@postgrespro.ru", "phone": "+70606672277"}
0005435039534	9EDC2D	4073 536609	OKSANA SOROKINA	{"email": "oksana-sorokina-25061969@postgrespro.ru", "phone": "+70583453571"}
0005435039535	99E8C4	6336 886218	VLADIMIR IVANOV	{"email": "vivanov-121981@postgrespro.ru", "phone": "+70103898665"}
0005435039536	99E8C4	2671 883707	TATYANA FROLOVA	{"email": "tatyana.frolova011969@postgrespro.ru", "phone": "+70563968520"}
0005435039537	99E8C4	2852 112911	NATALYA KULIKOVA	{"email": "n-kulikova.1970@postgrespro.ru", "phone": "+70404000806"}
0005435039538	E809CB	4590 562657	MIKHAIL SCHERBAKOV	{"email": "scherbakov_mikhail06041975@postgrespro.ru", "phone": "+70290025174"}
0005435039539	67FE01	1249 724212	TATYANA FROLOVA	{"email": "frolova-t_1978@postgrespro.ru", "phone": "+70433904646"}
0005435039540	4445EA	3608 060037	EGOR KAZAKOV	{"email": "egorkazakov01071980@postgrespro.ru", "phone": "+70604182516"}
0005435039541	4445EA	3541 830774	NIKOLAY FROLOV	{"email": "n_frolov20121968@postgrespro.ru", "phone": "+70327668530"}
0005435039542	BDB7AA	8072 045617	DENIS NIKOLAEV	{"email": "d_nikolaev31081978@postgrespro.ru", "phone": "+70066108984"}
0005435039543	98546D	8921 781603	ALEKSEY ZHURAVLEV	{"phone": "+70420596521"}
0005435039544	18477C	0911 867063	IRINA ERMAKOVA	{"email": "i_ermakova-08041969@postgrespro.ru", "phone": "+70254234336"}
0005435039545	CE4DCF	4233 154947	ELENA IVANOVA	{"phone": "+70090131653"}
0005435039546	F4686D	3991 296049	MARINA MATVEEVA	{"phone": "+70427574431"}
0005435039547	F4686D	9518 118574	VADIM MIKHAYLOV	{"phone": "+70233264592"}
0005435039548	42EB65	0893 078400	NIKITA SOLOVEV	{"email": "solovev.nikita_061967@postgrespro.ru", "phone": "+70952474788"}
0005435039549	85C134	1749 642038	KIRILL MEDVEDEV	{"email": "medvedevk-1976@postgrespro.ru", "phone": "+70816736277"}
0005435039550	C9F33B	2124 249535	RAISA KUZNECOVA	{"phone": "+70161468652"}
0005435039551	97CEE3	7922 859244	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.101972@postgrespro.ru", "phone": "+70035309133"}
0005435039552	97CEE3	3634 304262	ALEKSANDRA SOKOLOVA	{"email": "aleksandra_sokolova.1975@postgrespro.ru", "phone": "+70187223540"}
0005435039553	18CA70	8179 236479	TATYANA LUKYANOVA	{"phone": "+70898923678"}
0005435039554	18CA70	8101 293187	VIKTOR SOROKIN	{"phone": "+70378624593"}
0005435039555	481F5C	9013 328427	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov.1968@postgrespro.ru", "phone": "+70632081948"}
0005435039556	C9FFD8	6056 717181	GENNADIY GUSEV	{"phone": "+70061126856"}
0005435039557	D7AB4B	7436 396595	ELENA VOROBEVA	{"phone": "+70661963999"}
0005435039558	1150A0	9127 063800	VERA KOROLEVA	{"phone": "+70754792093"}
0005435039559	C9CBE8	5915 839679	ILDAR CHERNOV	{"email": "ichernov-03041975@postgrespro.ru", "phone": "+70231101678"}
0005435039560	BF9FA6	7694 647674	ALFIYA MOROZOVA	{"phone": "+70254406748"}
0005435039561	AED8D5	7314 974400	GULNARA DMITRIEVA	{"phone": "+70024020056"}
0005435039562	BC052D	9993 304010	VLADIMIR MOISEEV	{"email": "v_moiseev1974@postgrespro.ru", "phone": "+70380050127"}
0005435039563	BC052D	2469 045638	ANNA ZAKHAROVA	{"phone": "+70836617055"}
0005435039564	4A2FB6	2497 109683	NADEZHDA LOGINOVA	{"email": "nadezhdaloginova.031969@postgrespro.ru", "phone": "+70556555661"}
0005435039565	2F1115	3075 159551	ELIZAVETA POTAPOVA	{"email": "elizaveta.potapova1971@postgrespro.ru", "phone": "+70069333933"}
0005435039566	BF1B3A	2131 394705	TATYANA SIDOROVA	{"email": "sidorova_t031978@postgrespro.ru", "phone": "+70144884286"}
0005435039567	BF1B3A	2404 651817	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.aleksandr1976@postgrespro.ru", "phone": "+70548070079"}
0005435039568	3D87BF	0922 033114	ALEKSANDR PAVLOV	{"phone": "+70878135001"}
0005435039569	CC7F25	6117 503646	ELENA MAKAROVA	{"phone": "+70997673892"}
0005435039570	F1A0AB	5003 524977	ALEKSANDR MOROZOV	{"phone": "+70297783893"}
0005435039571	1F097E	0906 378043	MARIYA ISAEVA	{"email": "isaevam_26031971@postgrespro.ru", "phone": "+70284497319"}
0005435039572	55185C	2217 898152	PAVEL ISAEV	{"phone": "+70340203130"}
0005435039573	64BB0F	6935 348313	ANDREY BONDARENKO	{"phone": "+70070399061"}
0005435039574	564E17	3149 458832	DMITRIY STEPANOV	{"phone": "+70624128000"}
0005435039575	564E17	2983 501461	YULIYA KISELEVA	{"phone": "+70303828532"}
0005435039576	564E17	6374 096189	SERGEY GORBUNOV	{"email": "s-gorbunov_1973@postgrespro.ru", "phone": "+70775353186"}
0005435039577	9B3A8F	1647 355688	VLADIMIR NAUMOV	{"email": "naumov.v.21071986@postgrespro.ru", "phone": "+70941609454"}
0005435039578	3A77F7	9371 311593	NATALYA KULIKOVA	{"email": "kulikova.n011982@postgrespro.ru", "phone": "+70675888861"}
0005435039579	8BA8A7	5982 315645	NATALYA MAKSIMOVA	{"phone": "+70157302261"}
0005435039580	0E3FE2	9736 651229	ALEKSANDR MEDVEDEV	{"email": "medvedev.aleksandr_1974@postgrespro.ru", "phone": "+70243037650"}
0005435039581	92A96B	4253 200160	NATALYA FEDOROVA	{"phone": "+70769201511"}
0005435039582	8D307B	9117 162240	ARTEM IVANOV	{"phone": "+70009293865"}
0005435039583	E6E382	9460 622528	ILYA MOROZOV	{"email": "morozov_ilya18091965@postgrespro.ru", "phone": "+70414829817"}
0005435039584	E6E382	1400 448373	ALEKSANDR POPOV	{"email": "aleksandr_popov_121972@postgrespro.ru", "phone": "+70503211289"}
0005435039585	4F0C57	9367 398022	VIKTOR BELOV	{"phone": "+70459177967"}
0005435039586	BFF7C3	1374 508023	ELMIRA GUSEVA	{"email": "guseva.e-1963@postgrespro.ru", "phone": "+70799037171"}
0005435039587	0F87EC	7436 297575	DMITRIY GORBUNOV	{"phone": "+70370680188"}
0005435039588	600711	8843 786141	ALEKSANDR MOISEEV	{"email": "moiseev-a06051971@postgrespro.ru", "phone": "+70754312087"}
0005435039589	2E532A	2351 307210	VALERIY VASILEV	{"phone": "+70236631766"}
0005435039590	2E532A	5565 379554	VALERIY ANTONOV	{"phone": "+70764960732"}
0005435039591	2F8CAC	8779 211344	YURIY POPOV	{"phone": "+70295306062"}
0005435039592	2F8CAC	0794 360035	NATALYA KAZAKOVA	{"email": "kazakova-natalya.051958@postgrespro.ru", "phone": "+70120133020"}
0005435039593	E0A2BB	3107 029142	DMITRIY MATVEEV	{"phone": "+70172059441"}
0005435039594	E0A2BB	5836 787748	ZOYA BELOVA	{"phone": "+70512537596"}
0005435039595	036F02	0408 401900	ANTON IVANOV	{"email": "ivanova-051964@postgrespro.ru", "phone": "+70604287739"}
0005435039596	036F02	2847 478722	VALENTINA ANDREEVA	{"email": "v-andreeva121971@postgrespro.ru", "phone": "+70222623800"}
0005435039597	036F02	4935 040275	ELENA BELYAEVA	{"phone": "+70859445176"}
0005435039598	036F02	5266 748109	TATYANA SEMENOVA	{"phone": "+70980904547"}
0005435039599	B79E79	0906 848499	DMITRIY RODIONOV	{"email": "rodionov_d02091964@postgrespro.ru", "phone": "+70304810525"}
0005435039600	F04DDD	0713 633225	YURIY BORISOV	{"email": "yuriy-borisov051972@postgrespro.ru", "phone": "+70195592638"}
0005435039601	F04DDD	3062 591788	VALENTINA EGOROVA	{"email": "egorova_v-021976@postgrespro.ru", "phone": "+70500301370"}
0005435039602	7076AA	6418 071456	ELENA FADEEVA	{"email": "fadeeva-e_051975@postgrespro.ru", "phone": "+70000990377"}
0005435039603	FC87A7	4859 668759	DANIIL BELOV	{"phone": "+70366067734"}
0005435039604	FC87A7	5918 186919	KHALIDA IVANOVA	{"phone": "+70852993320"}
0005435039605	215988	2044 381982	LIDIYA ALEKSANDROVA	{"phone": "+70034875287"}
0005435039606	5D57B9	8042 946657	TAISIYA LAZAREVA	{"phone": "+70464511505"}
0005435039607	AD51B5	1794 815331	EKATERINA IVANOVA	{"phone": "+70610853042"}
0005435039608	8A7656	5350 842145	GALINA TIMOFEEVA	{"email": "timofeeva-g051962@postgrespro.ru", "phone": "+70568295078"}
0005435039609	8A7656	7728 878065	ELMIRA FEDOROVA	{"email": "e_fedorova05081971@postgrespro.ru", "phone": "+70565421979"}
0005435039610	89C894	5622 517389	POLINA MOROZOVA	{"email": "morozova-p.111972@postgrespro.ru", "phone": "+70206167027"}
0005435039611	7A92BD	3052 010516	NATALIYA KOROLEVA	{"phone": "+70702771489"}
0005435039612	42D0AD	1208 997140	LYUDMILA KOMAROVA	{"phone": "+70633193331"}
0005435039613	CC8B08	4959 198853	ANASTASIYA FROLOVA	{"phone": "+70626118534"}
0005435039614	107164	7526 694444	ALISA OSIPOVA	{"phone": "+70387548621"}
0005435039615	107164	1838 329591	RUMIYA VASILEVA	{"phone": "+70206598117"}
0005435039616	E0F82A	2213 083584	ALEKSEY NIKITIN	{"email": "anikitin-21041976@postgrespro.ru", "phone": "+70583538353"}
0005435039617	E0F82A	0788 685860	BORIS SEMENOV	{"phone": "+70480105564"}
0005435039618	037B4B	5105 022137	LYUBOV VOLKOVA	{"phone": "+70412159453"}
0005435039619	037B4B	5828 771008	IVAN POPOV	{"email": "popovivan_06011980@postgrespro.ru", "phone": "+70802891071"}
0005435039620	9AED89	5730 783995	VLADIMIR NAZAROV	{"phone": "+70554782068"}
0005435039621	9AED89	4622 737219	OLGA DANILOVA	{"email": "danilova-o.051965@postgrespro.ru", "phone": "+70857254000"}
0005435039622	9AED89	5262 449703	VLADIMIR FEDOTOV	{"email": "v_fedotov31031973@postgrespro.ru", "phone": "+70785520572"}
0005435039623	448B56	0321 819028	YURIY SMIRNOV	{"email": "y-smirnov.071972@postgrespro.ru", "phone": "+70276244754"}
0005435039624	96EF3A	9739 272735	BORIS MATVEEV	{"email": "matveev_boris1972@postgrespro.ru", "phone": "+70626431206"}
0005435039625	96EF3A	8522 731174	ANATOLIY PETROV	{"email": "anatoliy-petrov021984@postgrespro.ru", "phone": "+70594578111"}
0005435039626	0695A8	8947 714475	SERGEY GAVRILOV	{"email": "gavrilovs.11041983@postgrespro.ru", "phone": "+70744375236"}
0005435039627	0695A8	3654 424061	ALEKSANDR POPOV	{"email": "aleksandrpopov-29031971@postgrespro.ru", "phone": "+70575562571"}
0005435039628	0695A8	6971 180150	ELENA ALEKSANDROVA	{"email": "elena-aleksandrova1960@postgrespro.ru", "phone": "+70286450775"}
0005435039629	228035	7696 121432	ANDREY KISELEV	{"phone": "+70751569658"}
0005435039630	228035	9789 347294	AMINA NAZAROVA	{"email": "anazarova-03071966@postgrespro.ru", "phone": "+70313569670"}
0005435039631	7124ED	6802 617005	VERA GORBUNOVA	{"phone": "+70761938771"}
0005435039632	E80580	5633 950371	NIKOLAY SOKOLOV	{"phone": "+70517204583"}
0005435039633	083E34	2438 258035	ALBINA ALEKSEEVA	{"email": "alekseeva-albina.06061976@postgrespro.ru", "phone": "+70353086905"}
0005435039634	476ED9	2480 736261	VLADIMIR ROMANOV	{"email": "vladimirromanov-061967@postgrespro.ru", "phone": "+70247374084"}
0005435039635	6C9E80	3804 925026	NATALYA AFANASEVA	{"email": "afanasevanatalya-091973@postgrespro.ru", "phone": "+70400140138"}
0005435039636	A7ACA1	9626 569089	ALEKSANDR AFANASEV	{"email": "a.afanasev_16071968@postgrespro.ru", "phone": "+70311361501"}
0005435039637	A8B9A4	8977 026475	VALENTINA MAKAROVA	{"email": "valentina.makarova_06101966@postgrespro.ru", "phone": "+70641411504"}
0005435039638	A8B9A4	4389 179003	VLADISLAV KRASNOV	{"phone": "+70214873733"}
0005435039639	B04F68	2084 395356	MAKSIM ORLOV	{"phone": "+70079472921"}
0005435039640	B04F68	9579 714610	ALEKSANDR KARPOV	{"phone": "+70894890834"}
0005435039641	B04F68	9702 756838	TATYANA DAVYDOVA	{"phone": "+70311699973"}
0005435039642	0CA924	5975 093051	SERGEY STEPANOV	{"phone": "+70889300232"}
0005435039643	58D573	6642 392678	OLESYA NESTEROVA	{"phone": "+70430088200"}
0005435039644	F70722	4798 486626	TAMARA MATVEEVA	{"email": "matveeva-t-091968@postgrespro.ru", "phone": "+70515977974"}
0005435039645	607A43	7819 992590	ELENA SOROKINA	{"phone": "+70621879173"}
0005435039646	7DEA9D	1762 067595	GALINA NIKOLAEVA	{"email": "nikolaeva.g.02051963@postgrespro.ru", "phone": "+70038861730"}
0005435039647	C23FBE	9175 254722	VLADIMIR ANTONOV	{"email": "vladimirantonov-1974@postgrespro.ru", "phone": "+70950788612"}
0005435039648	9646FC	7610 296585	NATALYA VASILEVA	{"email": "nvasileva_21091981@postgrespro.ru", "phone": "+70128160412"}
0005435039649	E87CFD	3312 643547	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov15061968@postgrespro.ru", "phone": "+70668745286"}
0005435039650	308EC6	8021 766173	NATALYA TARASOVA	{"phone": "+70885745198"}
0005435039651	308EC6	8942 585108	MARINA VOLKOVA	{"phone": "+70008765408"}
0005435039652	C25ADA	5985 988171	STANISLAV SIDOROV	{"phone": "+70707819676"}
0005435039653	C25ADA	8764 937184	VALENTIN GORBUNOV	{"email": "gorbunov_valentin-25101975@postgrespro.ru", "phone": "+70706101107"}
0005435039654	0BE1AB	7248 390038	DMITRIY FROLOV	{"email": "frolovdmitriy-1961@postgrespro.ru", "phone": "+70875274640"}
0005435039655	0BE1AB	4798 629924	VIKTORIYA VASILEVA	{"email": "viktoriyavasileva.091976@postgrespro.ru", "phone": "+70759145530"}
0005435039656	F8F66B	6416 198643	VLADIMIR ZHUKOV	{"email": "v_zhukov.011974@postgrespro.ru", "phone": "+70476150606"}
0005435039657	318164	9045 413467	NATALYA SAVELEVA	{"email": "n.saveleva081972@postgrespro.ru", "phone": "+70326511371"}
0005435039769	CABBB7	5044 422752	IGOR ORLOV	{"phone": "+70735574361"}
0005435039658	318164	4216 611629	STANISLAV YAKOVLEV	{"email": "yakovlev_s071981@postgrespro.ru", "phone": "+70518008883"}
0005435039659	19A6F5	4600 294933	FAINA SEMENOVA	{"phone": "+70393609876"}
0005435039660	29D857	4523 022636	IRINA KOROLEVA	{"email": "ikoroleva-051976@postgrespro.ru", "phone": "+70593169032"}
0005435039661	29D857	4408 454405	ALEKSANDR OSIPOV	{"email": "aosipov.22051969@postgrespro.ru", "phone": "+70640275808"}
0005435039662	DB320C	2285 221004	DARYA PETROVA	{"email": "petrovadarya011970@postgrespro.ru", "phone": "+70768433260"}
0005435039663	C3D79B	8905 365108	PAVEL DENISOV	{"phone": "+70947224386"}
0005435039664	C717B6	4035 253650	VALENTINA TIMOFEEVA	{"phone": "+70341682141"}
0005435039665	DBF546	5656 999098	DMITRIY YAKOVLEV	{"email": "yakovlevd1973@postgrespro.ru", "phone": "+70060932891"}
0005435039666	DBF546	2443 463799	EKATERINA MIRONOVA	{"email": "mironova.ekaterina_1976@postgrespro.ru", "phone": "+70305977959"}
0005435039667	AEF8D1	2326 215806	ANTONINA LUKYANOVA	{"email": "antonina-lukyanova.1967@postgrespro.ru", "phone": "+70652831986"}
0005435039668	AEF8D1	5205 779564	VERA POPOVA	{"phone": "+70536065891"}
0005435039669	2157C4	0488 278989	NIKOLAY ALEKSEEV	{"email": "alekseev.nikolay.10041973@postgrespro.ru", "phone": "+70053293509"}
0005435039670	053538	5004 128738	IGOR ALEKSANDROV	{"email": "i-aleksandrov-1983@postgrespro.ru", "phone": "+70083854669"}
0005435039671	053538	3871 226137	VYACHESLAV SCHERBAKOV	{"phone": "+70173497909"}
0005435039672	9086BC	4581 419933	VLADIMIR ZAKHAROV	{"phone": "+70708926089"}
0005435039673	2ABD0D	2940 569648	ARKADIY FROLOV	{"email": "frolov.arkadiy06081967@postgrespro.ru", "phone": "+70274569321"}
0005435039674	219BF1	1909 764129	DENIS KOZLOV	{"email": "kozlov.denis-28011971@postgrespro.ru", "phone": "+70201891901"}
0005435039675	219BF1	5143 909061	ELLA KUZNECOVA	{"email": "e_kuznecova081967@postgrespro.ru", "phone": "+70503124443"}
0005435039676	21B998	2194 979547	VLADIMIR BELOV	{"email": "belovvladimir_26121979@postgrespro.ru", "phone": "+70019409649"}
0005435039677	6A9063	9383 342600	VIKTOR TIMOFEEV	{"email": "viktor_timofeev-1969@postgrespro.ru", "phone": "+70290279414"}
0005435039678	1978AE	0501 397485	OLGA MALYSHEVA	{"email": "o-malysheva-1973@postgrespro.ru", "phone": "+70430675306"}
0005435039679	AC692C	9010 807690	VASILIY MAKAROV	{"email": "makarov_v-09121976@postgrespro.ru", "phone": "+70865620932"}
0005435039680	B90B87	8252 864668	ALEKSANDR SEMENOV	{"email": "a_semenov071982@postgrespro.ru", "phone": "+70813288295"}
0005435039681	BD489D	0274 675194	ALEKSEY MELNIKOV	{"phone": "+70776039247"}
0005435039682	15EE57	4747 304266	DMITRIY SERGEEV	{"phone": "+70560120782"}
0005435039683	834152	7344 541611	VARVARA IVANOVA	{"email": "ivanova.varvara.16011974@postgrespro.ru", "phone": "+70966370116"}
0005435039684	849040	6747 058022	VITALIY FROLOV	{"email": "frolovv_13121976@postgrespro.ru", "phone": "+70181646586"}
0005435039685	E8661C	6416 759359	ELENA TROFIMOVA	{"phone": "+70028955909"}
0005435039686	E8661C	1638 819180	ALEKSANDR KISELEV	{"phone": "+70041301243"}
0005435039687	3A19B2	6820 073754	YURIY SCHERBAKOV	{"email": "scherbakov_y-051962@postgrespro.ru", "phone": "+70297048102"}
0005435039688	F75AB5	4657 899738	ROSTISLAV YAKOVLEV	{"email": "yakovlevr_1966@postgrespro.ru", "phone": "+70021980765"}
0005435039689	F75AB5	8022 514556	KONSTANTIN ORLOV	{"phone": "+70834376770"}
0005435039690	F9C9EF	4363 557785	MARIYA ANDREEVA	{"phone": "+70969587443"}
0005435039691	F1E7D1	8529 191174	VERA KOMAROVA	{"email": "vkomarova_1963@postgrespro.ru", "phone": "+70425459275"}
0005435039692	C76A26	1943 191764	DARYA SOKOLOVA	{"email": "darya-sokolova_1971@postgrespro.ru", "phone": "+70425293902"}
0005435039693	C4B455	1324 691162	EGOR MIKHAYLOV	{"phone": "+70835516332"}
0005435039694	90E810	1442 802624	DMITRIY SEMENOV	{"phone": "+70493420805"}
0005435039695	591EB3	0489 679620	TATYANA GORBUNOVA	{"phone": "+70620981293"}
0005435039696	591EB3	9949 235531	VALERIY NAZAROV	{"email": "nazarov.valeriy1974@postgrespro.ru", "phone": "+70102093848"}
0005435039697	132052	9677 193148	TATYANA MOROZOVA	{"email": "morozova-tatyana24041982@postgrespro.ru", "phone": "+70067313603"}
0005435039698	800CE5	5617 254313	VIKTOR KAZAKOV	{"email": "v-kazakov_071979@postgrespro.ru", "phone": "+70256166851"}
0005435039699	AC7C55	0876 075245	TATYANA KOROLEVA	{"phone": "+70100501216"}
0005435039700	CCB265	8824 372706	ANNA PETROVA	{"email": "petrova-a16061979@postgrespro.ru", "phone": "+70555358359"}
0005435039701	E8BC93	3943 530482	IGOR ANTONOV	{"email": "antonov-i-09051981@postgrespro.ru", "phone": "+70176799244"}
0005435039702	E8BC93	6772 506297	VITALIY KRASNOV	{"phone": "+70451101284"}
0005435039703	5B3DB9	5912 199104	RAISA ROMANOVA	{"phone": "+70400741431"}
0005435039704	5B3DB9	5295 904210	SERGEY VASILEV	{"email": "vasilev-sergey1976@postgrespro.ru", "phone": "+70527153092"}
0005435039705	375939	2669 838236	ALEKSANDR MAKAROV	{"phone": "+70766516080"}
0005435039706	905D7F	1413 485039	OLGA VLASOVA	{"phone": "+70647430197"}
0005435039707	1E2F7C	8738 276368	ELENA ORLOVA	{"phone": "+70991678544"}
0005435039708	35647D	6770 405092	SVETLANA ERMAKOVA	{"email": "ermakova_svetlana031970@postgrespro.ru", "phone": "+70134654496"}
0005435039709	524B1E	3086 887482	TATYANA ORLOVA	{"email": "orlova.tatyana-30031982@postgrespro.ru", "phone": "+70718139859"}
0005435039710	AE2ADD	7742 925433	SVETLANA MATVEEVA	{"email": "s.matveeva1971@postgrespro.ru", "phone": "+70248378162"}
0005435039711	17AAFC	1923 423195	PAVEL DAVYDOV	{"email": "pavel.davydov1981@postgrespro.ru", "phone": "+70119961464"}
0005435039712	17AAFC	2667 165720	VALENTINA MARTYNOVA	{"phone": "+70329930949"}
0005435039713	17AAFC	5588 854554	OLGA BELOVA	{"email": "belovaolga_27041972@postgrespro.ru", "phone": "+70087684365"}
0005435039714	17AAFC	0329 805680	NADEZHDA ANDREEVA	{"email": "andreevanadezhda_031972@postgrespro.ru", "phone": "+70634218794"}
0005435039715	661B2C	5010 185698	ELENA FROLOVA	{"email": "frolova-e021962@postgrespro.ru", "phone": "+70629643981"}
0005435039716	DA9055	2871 879043	VLADIMIR CHERNOV	{"phone": "+70357824797"}
0005435039717	C7037E	8846 486564	DENIS NAUMOV	{"phone": "+70753416309"}
0005435039718	C7037E	7861 628618	OLGA SEMENOVA	{"phone": "+70783623677"}
0005435039719	111A62	6671 859185	IGOR DMITRIEV	{"phone": "+70510054095"}
0005435039720	111A62	3811 270356	VADIM GRIGOREV	{"email": "v-grigorev-1968@postgrespro.ru", "phone": "+70601184956"}
0005435039721	E86F8F	2210 458644	NIKOLAY POPOV	{"phone": "+70063171660"}
0005435039722	E86F8F	3012 317799	RUSLAN SOLOVEV	{"email": "solovev.r.1978@postgrespro.ru", "phone": "+70567611198"}
0005435039723	3310A5	6360 999903	ILYA ABRAMOV	{"phone": "+70045808690"}
0005435039724	54A154	6456 107397	VLADIMIR SIDOROV	{"email": "sidorovv13061967@postgrespro.ru", "phone": "+70419864470"}
0005435039725	54A154	1150 826379	VLADIMIR YAKOVLEV	{"email": "yakovlevvladimir16041965@postgrespro.ru", "phone": "+70109380181"}
0005435039726	C70D24	3053 101776	EVGENIY KULIKOV	{"email": "evgeniykulikov_30041967@postgrespro.ru", "phone": "+70459571857"}
0005435039727	95897B	7342 840033	GALINA SEMENOVA	{"phone": "+70727365106"}
0005435039728	898B10	8027 249065	MARIYA RODIONOVA	{"phone": "+70315519582"}
0005435039729	FE1E4D	1085 376815	EGOR ZAKHAROV	{"email": "zakharov_e-1973@postgrespro.ru", "phone": "+70598560344"}
0005435039730	F286B6	5177 765844	SVETLANA ZHUKOVA	{"email": "zhukovasvetlana1975@postgrespro.ru", "phone": "+70665099370"}
0005435039731	2423F5	6781 597087	MAGOMED KUDRYASHOV	{"phone": "+70371404252"}
0005435039732	2423F5	4875 294401	TAMARA VOLKOVA	{"email": "volkova_t.1974@postgrespro.ru", "phone": "+70023942945"}
0005435039733	5FFA1B	7641 724552	ALEKSEY TARASOV	{"email": "tarasov_a111962@postgrespro.ru", "phone": "+70586955838"}
0005435039734	5FFA1B	3034 276670	EVGENIY NAUMOV	{"phone": "+70210362046"}
0005435039735	5FFA1B	9073 728789	MAKSIM KISELEV	{"email": "mkiselev.1974@postgrespro.ru", "phone": "+70349318023"}
0005435039736	DD5E43	7450 759944	ANDREY SAVELEV	{"phone": "+70754013277"}
0005435039737	116419	3295 751116	SERGEY MATVEEV	{"phone": "+70994775880"}
0005435039738	5D6925	3160 516035	MIKHAIL ZAKHAROV	{"email": "m_zakharov_1987@postgrespro.ru", "phone": "+70270552363"}
0005435039739	5D6925	9973 691162	ALENA NESTEROVA	{"phone": "+70510461047"}
0005435039740	471AC3	0180 711849	VYACHESLAV SERGEEV	{"phone": "+70880623633"}
0005435039741	FCDCED	1362 546436	DANIIL SAVELEV	{"phone": "+70405651087"}
0005435039742	FCDCED	2846 802357	VASILIY VOROBEV	{"phone": "+70807862313"}
0005435039743	C06DC0	6423 081910	LILIYA ZAYCEVA	{"email": "l.zayceva1967@postgrespro.ru", "phone": "+70060110570"}
0005435039744	C06DC0	1846 113414	TIMOFEY POPOV	{"phone": "+70876694604"}
0005435039745	F82687	8482 134137	NADEZHDA FROLOVA	{"email": "frolova-nadezhda_07091972@postgrespro.ru", "phone": "+70559463856"}
0005435039746	F82687	3802 278387	OLGA ABRAMOVA	{"email": "abramova-o.101971@postgrespro.ru", "phone": "+70366250261"}
0005435039747	97C15C	4892 838829	VLADIMIR KAZAKOV	{"email": "v-kazakov.05031969@postgrespro.ru", "phone": "+70825856348"}
0005435039748	66C22C	7518 186738	ANASTASIYA VLASOVA	{"phone": "+70574492918"}
0005435039749	66C22C	7354 966074	VADIM PETROV	{"email": "petrov-v_03121976@postgrespro.ru", "phone": "+70526188063"}
0005435039750	AAE7A0	9498 295449	ALEKSANDR NOVIKOV	{"phone": "+70000427773"}
0005435039751	AF92D8	3009 936495	VALERIY GRIGOREV	{"phone": "+70001470062"}
0005435039752	AF92D8	4169 687103	ALEKSANDR YAKOVLEV	{"phone": "+70775993611"}
0005435039753	AF92D8	2199 474871	VLADIMIR MATVEEV	{"phone": "+70527736292"}
0005435039754	816FDC	8479 034202	ANATOLIY STEPANOV	{"email": "stepanovanatoliy.011974@postgrespro.ru", "phone": "+70576701292"}
0005435039755	EA22B3	3241 186057	ARTEM EGOROV	{"phone": "+70414176409"}
0005435039756	EA22B3	7208 752965	IRINA KISELEVA	{"phone": "+70119196212"}
0005435039757	65528C	8216 894253	GENNADIY MIRONOV	{"email": "mironov.gennadiy.1965@postgrespro.ru", "phone": "+70540000149"}
0005435039758	6162FB	1955 696258	OLEG KUZNECOV	{"email": "kuznecov_oleg.06111980@postgrespro.ru", "phone": "+70221270112"}
0005435039759	6162FB	8782 077082	SAVELIY PETROV	{"email": "saveliy.petrov_111969@postgrespro.ru", "phone": "+70255650159"}
0005435039760	2C2261	9218 005971	KIRILL EGOROV	{"email": "kirillegorov-25081970@postgrespro.ru", "phone": "+70813606971"}
0005435039761	062CDD	0556 276430	IGOR SOKOLOV	{"email": "isokolov_031986@postgrespro.ru", "phone": "+70395752098"}
0005435039762	4FB978	9532 181489	ANASTASIYA SOROKINA	{"email": "sorokina-anastasiya051977@postgrespro.ru", "phone": "+70252217064"}
0005435039763	4FB978	8188 235996	ANATOLIY GUSEV	{"email": "gusevanatoliy-1975@postgrespro.ru", "phone": "+70783892873"}
0005435039764	4FB978	1419 972496	ILYA CHERNOV	{"email": "chernovi.11061964@postgrespro.ru", "phone": "+70665436462"}
0005435039765	05D064	5404 743978	ALEKSANDR MEDVEDEV	{"email": "medvedev-a_01011976@postgrespro.ru", "phone": "+70927011789"}
0005435039766	331DA4	5461 727987	MARINA TROFIMOVA	{"email": "marina_trofimova_28091967@postgrespro.ru", "phone": "+70580074802"}
0005435039767	CABBB7	6892 178988	SERGEY KUZNECOV	{"email": "sergey-kuznecov.1978@postgrespro.ru", "phone": "+70244068061"}
0005435039768	CABBB7	5092 818907	RUSLAN KOZLOV	{"email": "rkozlov1984@postgrespro.ru", "phone": "+70836623652"}
0005435039770	55FF10	3709 004667	DMITRIY MATVEEV	{"email": "d_matveev.021973@postgrespro.ru", "phone": "+70177294739"}
0005435039771	020453	9697 614347	LARISA MOROZOVA	{"phone": "+70820084661"}
0005435039772	B571B8	8567 299055	ANDREY SEMENOV	{"email": "semenov-andrey.1971@postgrespro.ru", "phone": "+70618775480"}
0005435039773	2581D5	4394 041059	MARIYA DANILOVA	{"phone": "+70986561448"}
0005435039774	59842D	7216 664153	OLGA ANISIMOVA	{"phone": "+70785999759"}
0005435039775	DB5C16	4487 448413	EKATERINA KONOVALOVA	{"email": "ekaterina_konovalova-1977@postgrespro.ru", "phone": "+70899699202"}
0005435039776	109275	4925 794970	NADEZHDA STEPANOVA	{"email": "stepanova.nadezhda.101970@postgrespro.ru", "phone": "+70696453488"}
0005435039777	101FAA	0604 829236	PETR PETROV	{"email": "petr-petrov041976@postgrespro.ru", "phone": "+70364331116"}
0005435039778	197B2A	8967 399743	LEV MAKAROV	{"phone": "+70362905409"}
0005435039779	59FA8C	2639 836575	DARYA PETROVA	{"email": "daryapetrova.1973@postgrespro.ru", "phone": "+70401336127"}
0005435039780	0D254A	1978 530399	ROMAN MAKSIMOV	{"email": "roman_maksimov_041971@postgrespro.ru", "phone": "+70134774212"}
0005435039781	39963E	7271 203599	IVAN PETROV	{"phone": "+70006909380"}
0005435039782	39963E	6983 088087	GALINA SCHERBAKOVA	{"phone": "+70327862172"}
0005435039783	6CEA86	4570 300562	SERGEY AFANASEV	{"email": "afanasev.s_12011968@postgrespro.ru", "phone": "+70672609267"}
0005435039784	6CEA86	4640 717667	ANASTASIYA DMITRIEVA	{"email": "a.dmitrieva24041978@postgrespro.ru", "phone": "+70493847468"}
0005435039785	22A6BA	1204 809337	VALENTINA VLASOVA	{"phone": "+70629438874"}
0005435039786	9D95DC	4762 027094	NIKOLAY MOROZOV	{"email": "nikolay.morozov1972@postgrespro.ru", "phone": "+70612968693"}
0005435039787	D1D8E8	2923 303717	DMITRIY KUZNECOV	{"email": "d.kuznecov_06061960@postgrespro.ru", "phone": "+70855645671"}
0005435039788	CCF8E0	7888 150935	LILIYA ALEKSANDROVA	{"phone": "+70050624028"}
0005435039789	CCF8E0	2601 776847	VLADIMIR KUZMIN	{"phone": "+70485998311"}
0005435039790	BEC8C5	4342 502362	VLADIMIR SCHERBAKOV	{"phone": "+70568856498"}
0005435039791	BEC8C5	3314 792429	SERGEY ABRAMOV	{"phone": "+70008933958"}
0005435039792	C6CC09	5939 071322	SERGEY PAVLOV	{"email": "sergey-pavlov-101972@postgrespro.ru", "phone": "+70160794687"}
0005435039793	594716	7588 387925	SERGEY KUZNECOV	{"email": "kuznecov_s_18081977@postgrespro.ru", "phone": "+70115668638"}
0005435039794	B572C6	8968 791362	DENIS IVANOV	{"phone": "+70352106055"}
0005435039795	5AD736	5052 331529	OLEG KUZNECOV	{"email": "kuznecov_oleg_05111973@postgrespro.ru", "phone": "+70574560476"}
0005435039796	5AD736	8618 300677	KRISTINA SOKOLOVA	{"phone": "+70308598230"}
0005435039797	DBAE8B	5631 839034	ALEKSANDR SCHERBAKOV	{"email": "a.scherbakov.1963@postgrespro.ru", "phone": "+70503564932"}
0005435039798	C3B397	3120 890182	RENATA SOLOVEVA	{"phone": "+70692203989"}
0005435039799	CEE1BA	7104 968316	ANNA KOROLEVA	{"email": "anna_koroleva-26041977@postgrespro.ru", "phone": "+70400397973"}
0005435039800	4D3608	3582 914819	NINA KOROLEVA	{"phone": "+70678668950"}
0005435039801	4D3608	3565 257175	NATALYA EGOROVA	{"email": "egorovanatalya.081979@postgrespro.ru", "phone": "+70901535083"}
0005435039802	4A0BFE	3908 370711	SERGEY FOMIN	{"phone": "+70072075792"}
0005435040104	8FFDE5	5911 487839	ZINAIDA RODIONOVA	{"phone": "+70330677060"}
0005435039803	2A52E2	1876 558699	DANIIL IVANOV	{"email": "ivanov_daniil.091971@postgrespro.ru", "phone": "+70106815881"}
0005435039804	2A52E2	0170 118382	ALEKSEY SOLOVEV	{"phone": "+70568611866"}
0005435039805	671568	6082 119496	ANDREY SERGEEV	{"phone": "+70573344420"}
0005435039806	A40B0C	2490 248250	VALENTINA KOZLOVA	{"email": "kozlova.v.1971@postgrespro.ru", "phone": "+70607685969"}
0005435039807	4B500A	7479 092296	SVETLANA GRISHINA	{"email": "s_grishina.1978@postgrespro.ru", "phone": "+70536042410"}
0005435039808	75191F	5267 942124	NATALYA MELNIKOVA	{"phone": "+70499318788"}
0005435039809	8A0351	8705 893644	ANATOLIY MEDVEDEV	{"email": "medvedev_a.021960@postgrespro.ru", "phone": "+70737402988"}
0005435039810	C0B152	7747 128111	MARINA DMITRIEVA	{"email": "m_dmitrieva1965@postgrespro.ru", "phone": "+70883587876"}
0005435039811	A14B2B	1837 705964	ALEKSEY NAZAROV	{"phone": "+70834310039"}
0005435039812	A14B2B	7728 934120	SERGEY ZAKHAROV	{"email": "sergeyzakharov_111966@postgrespro.ru", "phone": "+70698798840"}
0005435039813	D50442	2478 812263	SERGEY GERASIMOV	{"email": "s-gerasimov.16031967@postgrespro.ru", "phone": "+70137296056"}
0005435039814	8C3ED0	0257 137136	KONSTANTIN SHEVCHENKO	{"phone": "+70368373715"}
0005435039815	8C3ED0	7344 099636	SERGEY TARASOV	{"phone": "+70535344562"}
0005435039816	9BFADF	6903 355604	EVGENIYA LOGINOVA	{"email": "evgeniyaloginova_10041972@postgrespro.ru", "phone": "+70498798813"}
0005435039817	DD98DC	3036 843405	VERA MIRONOVA	{"email": "vera_mironova_101969@postgrespro.ru", "phone": "+70458804867"}
0005435039818	DD98DC	1121 341938	VLADIMIR NIKOLAEV	{"phone": "+70584764882"}
0005435039819	CC376A	9117 121505	MARINA SERGEEVA	{"email": "sergeeva-m-1964@postgrespro.ru", "phone": "+70048528726"}
0005435039820	E7ABF6	9873 223610	ALEKSANDR ANDREEV	{"email": "andreev.a-10121970@postgrespro.ru", "phone": "+70516956109"}
0005435039821	F23F15	6895 146263	ANDREY ZAKHAROV	{"email": "a-zakharov_14031975@postgrespro.ru", "phone": "+70236193745"}
0005435039822	032A1E	2862 387246	EVGENIY CHERNOV	{"email": "evgeniy-chernov-111964@postgrespro.ru", "phone": "+70422702631"}
0005435039823	032A1E	9501 121493	NATALIYA KULIKOVA	{"email": "kulikova_nataliya-1974@postgrespro.ru", "phone": "+70809918520"}
0005435039824	4FEEE5	3559 608581	MAKSIM BARANOV	{"phone": "+70327798212"}
0005435039825	278261	3166 539831	OLESYA ARKHIPOVA	{"phone": "+70475808442"}
0005435039826	278261	3243 733897	NIKOLAY MELNIKOV	{"email": "melnikov.n-051964@postgrespro.ru", "phone": "+70588766114"}
0005435039827	983DEA	4935 808757	MIKHAIL DAVYDOV	{"email": "m_davydov_20081964@postgrespro.ru", "phone": "+70744681318"}
0005435039828	47D920	5371 995580	YULIYA NOVIKOVA	{"email": "yuliyanovikova.1978@postgrespro.ru", "phone": "+70852789733"}
0005435039829	7317AA	6402 599865	LYUDMILA EGOROVA	{"phone": "+70650492045"}
0005435039830	46C1EE	2068 602494	DMITRIY POPOV	{"email": "popov-dmitriy_10081971@postgrespro.ru", "phone": "+70471114795"}
0005435039831	81D0F8	1435 878644	VLADIMIR SCHERBAKOV	{"email": "v.scherbakov_111971@postgrespro.ru", "phone": "+70699603611"}
0005435039832	555CEB	0985 338035	GALINA IVANOVA	{"phone": "+70131030260"}
0005435039833	874A84	1903 562499	LYUBOV NAZAROVA	{"phone": "+70628722737"}
0005435039834	EB584C	6665 698877	ANATOLIY VLASOV	{"phone": "+70133648930"}
0005435039835	1BC0B9	4873 821066	LYUBOV NAUMOVA	{"email": "lyubov_naumova-081969@postgrespro.ru", "phone": "+70114466906"}
0005435039836	3881A6	0023 559483	ELENA ALEKSEEVA	{"phone": "+70425505234"}
0005435039837	8C9351	0442 783297	LYUBOV ERMAKOVA	{"email": "ermakova-l_12021978@postgrespro.ru", "phone": "+70777085027"}
0005435039838	8C9351	1536 485347	IGOR AFANASEV	{"email": "afanasevigor_021975@postgrespro.ru", "phone": "+70874891599"}
0005435039839	045FF7	3255 967405	VALENTINA DENISOVA	{"email": "v_denisova1968@postgrespro.ru", "phone": "+70917715434"}
0005435039840	045FF7	8421 373265	ROMAN KAZAKOV	{"email": "roman_kazakov.051970@postgrespro.ru", "phone": "+70453326901"}
0005435039841	04150F	2650 013590	VALENTINA ORLOVA	{"email": "orlova_v1965@postgrespro.ru", "phone": "+70040645677"}
0005435039842	4DA377	2186 319486	OLGA MAKAROVA	{"email": "makarovao.051977@postgrespro.ru", "phone": "+70473107265"}
0005435039843	153BDB	6811 783751	LYUBOV ALEKSEEVA	{"email": "lyubov-alekseeva_1971@postgrespro.ru", "phone": "+70514076724"}
0005435039844	153BDB	2519 079748	SERGEY KUZNECOV	{"phone": "+70863149426"}
0005435039845	153BDB	8935 338836	NINA TITOVA	{"email": "nina_titova_1977@postgrespro.ru", "phone": "+70115505407"}
0005435039846	5ADD28	4527 404397	OLGA KOROLEVA	{"phone": "+70425365277"}
0005435039847	5ADD28	6805 607326	NIKOLAY TIKHONOV	{"email": "n.tikhonov_021970@postgrespro.ru", "phone": "+70325819838"}
0005435039848	C45F1D	4527 723634	SERGEY GORBUNOV	{"phone": "+70565665482"}
0005435039849	C45F1D	8227 985693	VASILIY NOVIKOV	{"phone": "+70296640983"}
0005435039850	9C24D1	6417 543436	SERGEY POPOV	{"phone": "+70945451034"}
0005435039851	9C24D1	4485 979501	GALINA MAKAROVA	{"email": "galina.makarova_101972@postgrespro.ru", "phone": "+70521900057"}
0005435039852	34F70C	9066 419140	YURIY ABRAMOV	{"phone": "+70870081108"}
0005435039853	34F70C	8037 885005	OKSANA KOROLEVA	{"email": "oksana_koroleva.061962@postgrespro.ru", "phone": "+70904295779"}
0005435039854	004561	8356 454155	EKATERINA MIRONOVA	{"phone": "+70520942073"}
0005435039855	759C57	2221 087338	TALGAT NIKOLAEV	{"email": "talgatnikolaev_1979@postgrespro.ru", "phone": "+70706194517"}
0005435039856	759C57	8624 788290	ARSENIY ANTONOV	{"phone": "+70300748355"}
0005435039857	7A1731	0932 771341	ROMAN SEMENOV	{"phone": "+70202859270"}
0005435039858	AD1075	5601 060120	MARAT SERGEEV	{"email": "m_sergeev-1969@postgrespro.ru", "phone": "+70776418053"}
0005435039859	4D3391	4037 011665	IGOR ORLOV	{"phone": "+70366685370"}
0005435039860	563F50	4690 345419	ALEKSANDRA IVANOVA	{"email": "ivanovaaleksandra-061970@postgrespro.ru", "phone": "+70431025828"}
0005435039861	563F50	2639 991934	VLADISLAV KUDRYASHOV	{"email": "v-kudryashov.1980@postgrespro.ru", "phone": "+70003113130"}
0005435039862	650EF2	0479 160387	YULIYA BOGDANOVA	{"email": "yuliyabogdanova.1978@postgrespro.ru", "phone": "+70122526509"}
0005435039863	536E26	8273 035709	SERGEY SIDOROV	{"email": "sidorovs1980@postgrespro.ru", "phone": "+70778274879"}
0005435039864	B5F9E7	5041 500306	OLGA SCHERBAKOVA	{"email": "scherbakovao_121964@postgrespro.ru", "phone": "+70459995411"}
0005435039865	4D24E3	3164 593532	LYUBOV MIRONOVA	{"phone": "+70761301245"}
0005435039866	EC4CA5	6941 782114	IVAN ZAKHAROV	{"phone": "+70501937937"}
0005435039867	D1D692	4735 098295	DMITRIY PETROV	{"email": "dpetrov.021975@postgrespro.ru", "phone": "+70435188090"}
0005435039868	ABA0AF	1998 649422	VERA ROMANOVA	{"phone": "+70451201569"}
0005435039869	ABA0AF	5643 887098	NIKITA KUZNECOV	{"phone": "+70000186584"}
0005435039870	ABA0AF	1545 041740	SERGEY SAVELEV	{"phone": "+70133873682"}
0005435039871	CA45AE	1862 744384	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr_02051972@postgrespro.ru", "phone": "+70931783204"}
0005435039872	CA45AE	8276 124121	ROMAN IVANOV	{"phone": "+70937362016"}
0005435039873	101A50	5396 534063	ALEKSEY SERGEEV	{"email": "aleksey_sergeev1970@postgrespro.ru", "phone": "+70995410256"}
0005435039874	DBF98C	0879 278313	LYUDMILA KOROLEVA	{"email": "koroleva.l-25061972@postgrespro.ru", "phone": "+70454874240"}
0005435039875	8B3AF8	1299 452048	ALEKSANDR OSIPOV	{"phone": "+70237090457"}
0005435039876	8B3AF8	7721 900424	RUSTAM NIKITIN	{"phone": "+70420371108"}
0005435039877	65512A	1227 582202	VIKTORIYA FEDOROVA	{"phone": "+70691742861"}
0005435039878	65512A	7337 467998	RUSLAN FEDOTOV	{"phone": "+70333492023"}
0005435039879	65512A	3083 350966	ANTON ABRAMOV	{"email": "abramov_a-12081971@postgrespro.ru", "phone": "+70575886647"}
0005435039880	85264C	2895 842167	ANDREY KONOVALOV	{"phone": "+70919394810"}
0005435039881	85264C	8672 175677	ALFIYA MIKHAYLOVA	{"email": "alfiya.mikhaylova_1972@postgrespro.ru", "phone": "+70203691919"}
0005435039882	A3045A	0036 128470	MIKHAIL ILIN	{"phone": "+70269201322"}
0005435039883	A3045A	0646 905361	LYUDMILA MAKAROVA	{"phone": "+70508633511"}
0005435039884	A3045A	0380 934538	MARIYA MEDVEDEVA	{"email": "m.medvedeva-31051970@postgrespro.ru", "phone": "+70817186032"}
0005435039885	A3045A	5193 111123	ELENA SERGEEVA	{"email": "sergeeva-e_051960@postgrespro.ru", "phone": "+70043840086"}
0005435039886	9DA923	0040 801879	SVETLANA FILIPPOVA	{"email": "filippova-s_031984@postgrespro.ru", "phone": "+70288624883"}
0005435039887	9DA923	0166 896533	DARYA PETROVA	{"phone": "+70607750852"}
0005435039888	F9C03F	6937 900939	ARTEM IVANOV	{"email": "ivanovartem.121984@postgrespro.ru", "phone": "+70443673149"}
0005435039889	F9C03F	2762 386023	ANDREY ANTONOV	{"email": "andreyantonov-1970@postgrespro.ru", "phone": "+70161957066"}
0005435039890	F30688	6510 852043	LYUBOV MEDVEDEVA	{"email": "medvedeva_l_021979@postgrespro.ru", "phone": "+70157913676"}
0005435039891	C3D63B	6583 964456	LIDIYA DMITRIEVA	{"email": "dmitrievalidiya.27021963@postgrespro.ru", "phone": "+70684844073"}
0005435039892	05BE5D	6252 355510	ELENA GAVRILOVA	{"email": "gavrilova.elena.11061963@postgrespro.ru", "phone": "+70946020984"}
0005435039893	20D479	4868 976209	VIKTOR DAVYDOV	{"phone": "+70823776418"}
0005435039894	20D479	3724 026685	ANDREY MOROZOV	{"email": "morozov-andrey-1978@postgrespro.ru", "phone": "+70937105659"}
0005435039895	C08839	6799 278580	LILIYA KUZNECOVA	{"phone": "+70411459361"}
0005435039896	319C37	4056 266643	LYUDMILA FADEEVA	{"phone": "+70273670215"}
0005435039897	319C37	4904 528181	VERA BOGDANOVA	{"phone": "+70195125425"}
0005435039898	8A9D69	8874 437694	MIKHAIL MAKAROV	{"email": "makarovmikhail.1974@postgrespro.ru", "phone": "+70895641799"}
0005435039899	82D4FE	0477 236240	IRINA ZAKHAROVA	{"phone": "+70728221086"}
0005435039900	F17F1D	4316 502615	OLEG GRIGOREV	{"phone": "+70665170526"}
0005435039901	BDF8E6	7612 402875	ROMAN FILIPPOV	{"email": "roman_filippov1962@postgrespro.ru", "phone": "+70632403845"}
0005435039902	CC48D3	1982 195262	ROMAN MAKAROV	{"email": "rmakarov-24111965@postgrespro.ru", "phone": "+70966964980"}
0005435039903	CC48D3	6511 187375	ALLA TIKHONOVA	{"phone": "+70427344993"}
0005435039904	138EF3	1739 948141	EVGENIY IVANOV	{"phone": "+70083304665"}
0005435039905	138EF3	5498 034957	LARISA PAVLOVA	{"phone": "+70110970998"}
0005435039906	9C65A9	7393 325703	EVGENIYA SIDOROVA	{"phone": "+70188367833"}
0005435039907	CE3FEE	1640 163314	VALERIYA EGOROVA	{"phone": "+70982095032"}
0005435039908	522627	3633 715727	TATYANA ZHUKOVA	{"phone": "+70160741477"}
0005435039909	F1912A	5129 526348	ELIZAVETA NIKITINA	{"email": "elizavetanikitina13111982@postgrespro.ru", "phone": "+70783637893"}
0005435039910	D09598	5964 629525	TATYANA MELNIKOVA	{"email": "melnikova_tatyana_121969@postgrespro.ru", "phone": "+70324483512"}
0005435039911	9AE6BB	4868 190837	OLGA FILATOVA	{"email": "filatova.olga02041970@postgrespro.ru", "phone": "+70676079961"}
0005435039912	08DFF9	4231 565680	YANA IVANOVA	{"phone": "+70964244830"}
0005435039913	08DFF9	7098 724831	MAKSIM PETROV	{"phone": "+70603622088"}
0005435039914	118CDB	5533 835364	NINA VOROBEVA	{"phone": "+70824251123"}
0005435039915	118CDB	7768 933882	ANNA LEBEDEVA	{"email": "a.lebedeva1976@postgrespro.ru", "phone": "+70879392278"}
0005435039916	02D92F	3977 777012	NIKOLAY FOMIN	{"email": "fomin-nikolay.01091969@postgrespro.ru", "phone": "+70549843785"}
0005435039917	9EA997	3356 670549	NIKOLAY DMITRIEV	{"email": "nikolay_dmitriev-1971@postgrespro.ru", "phone": "+70895532765"}
0005435039918	A66A2A	7763 780208	ELENA KOZLOVA	{"email": "elenakozlova-31031967@postgrespro.ru", "phone": "+70384663626"}
0005435039919	4B530F	5192 517303	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.111971@postgrespro.ru", "phone": "+70188652013"}
0005435039920	4B530F	0777 480498	OLEG NIKITIN	{"email": "olegnikitin1972@postgrespro.ru", "phone": "+70707255708"}
0005435039921	69F0CA	2954 545723	VALENTINA KRASNOVA	{"email": "valentinakrasnova1970@postgrespro.ru", "phone": "+70029433564"}
0005435039922	703152	4579 209167	VLADIMIR ANDREEV	{"phone": "+70134818541"}
0005435039923	703152	7736 588851	IVAN NAUMOV	{"email": "ivan_naumov_1972@postgrespro.ru", "phone": "+70154842000"}
0005435039924	350043	8996 079926	MIKHAIL BONDARENKO	{"email": "bondarenko_mikhail1966@postgrespro.ru", "phone": "+70349575787"}
0005435039925	C8E33F	9074 322774	EVGENIY YAKOVLEV	{"phone": "+70546869858"}
0005435039926	C8E33F	4739 833760	NINA DANILOVA	{"phone": "+70870831102"}
0005435039927	DA798E	7991 865398	EKATERINA ALEKSANDROVA	{"email": "e.aleksandrova_1965@postgrespro.ru", "phone": "+70568770770"}
0005435039928	AF65F7	7496 345176	EVGENIY MOROZOV	{"phone": "+70189695258"}
0005435039929	0F5C7A	2358 526025	MIKHAIL SCHERBAKOV	{"phone": "+70040369868"}
0005435039930	0F5C7A	6524 851121	VERA KUZNECOVA	{"email": "kuznecova.v_03081970@postgrespro.ru", "phone": "+70635969161"}
0005435039931	0F5C7A	5349 987168	TAMARA GAVRILOVA	{"phone": "+70452484734"}
0005435039932	2B5B3D	6542 668720	SERGEY SERGEEV	{"phone": "+70253222761"}
0005435039933	2B5B3D	6453 472061	ALEKSANDRA TIMOFEEVA	{"phone": "+70651401129"}
0005435039934	5F3BBE	5335 742123	ALEKSEY GORBUNOV	{"phone": "+70201675019"}
0005435039935	AB1631	4791 404959	TATYANA GRISHINA	{"phone": "+70752087805"}
0005435039936	9C2935	6642 438839	IVAN IVANOV	{"email": "ivanov-i.121962@postgrespro.ru", "phone": "+70433474108"}
0005435039937	7E61F6	6343 639165	ANNA MAKAROVA	{"phone": "+70436782368"}
0005435039938	7E61F6	7638 993255	ANDREY FILIPPOV	{"email": "andreyfilippov_1983@postgrespro.ru", "phone": "+70025307878"}
0005435039939	B963E4	2972 188620	VASILIY MAKAROV	{"phone": "+70511464474"}
0005435039940	B963E4	1672 699542	SERGEY SHEVCHENKO	{"email": "sergeyshevchenko.1973@postgrespro.ru", "phone": "+70162178278"}
0005435039941	ADAD78	7432 825390	MARIYA ZHURAVLEVA	{"email": "zhuravleva-mariya.20021972@postgrespro.ru", "phone": "+70674518207"}
0005435039942	466589	7471 503241	TAMARA YUDINA	{"email": "yudina.tamara-071983@postgrespro.ru", "phone": "+70524524628"}
0005435039943	584A85	7181 260647	SVETLANA ZHUKOVA	{"phone": "+70513735632"}
0005435039944	8D4F94	3493 535331	PETR MELNIKOV	{"phone": "+70232914176"}
0005435039945	FDE1EC	1562 073060	POLINA MELNIKOVA	{"phone": "+70645566532"}
0005435039946	FDE1EC	2595 618634	TATYANA IVANOVA	{"phone": "+70417050796"}
0005435039947	EB5BF3	1907 193120	ELENA SERGEEVA	{"phone": "+70612717677"}
0005435039948	FB1A4E	9373 408734	SERGEY MAKAROV	{"phone": "+70369640848"}
0005435039949	B2CF9C	8214 900891	OLEG BONDARENKO	{"phone": "+70647546468"}
0005435039950	0DA182	1283 215856	NINA KUZNECOVA	{"phone": "+70546431718"}
0005435039951	98F871	8068 823729	GENNADIY DMITRIEV	{"email": "dmitriev.gennadiy_23021971@postgrespro.ru", "phone": "+70661522623"}
0005435039952	8C2430	1865 636845	ELENA VASILEVA	{"phone": "+70367010951"}
0005435039953	9DDDD0	8157 826591	SVETLANA SOKOLOVA	{"phone": "+70423861330"}
0005435039954	24192C	7159 496220	OLEG FOMIN	{"phone": "+70624464249"}
0005435039955	24192C	6723 637252	IGOR NOVIKOV	{"phone": "+70454745898"}
0005435039956	E36F91	2922 393806	VIKTOR MELNIKOV	{"phone": "+70343391889"}
0005435039957	C8606A	0515 617476	VIKTOR NIKITIN	{"phone": "+70901174519"}
0005435039958	C8606A	0330 200544	IGOR NOVIKOV	{"phone": "+70527761571"}
0005435039959	50A40D	9857 208375	ALEKSANDRA MIKHAYLOVA	{"phone": "+70916081992"}
0005435039960	585B1F	5283 360377	SERGEY POPOV	{"phone": "+70749250747"}
0005435039961	D877E4	0667 944073	IGOR MAKAROV	{"phone": "+70533572007"}
0005435039962	D877E4	5191 534966	SERGEY KRASNOV	{"email": "sergey_krasnov.1966@postgrespro.ru", "phone": "+70538221918"}
0005435039963	6B4347	7274 788001	ANDREY TARASOV	{"phone": "+70033293479"}
0005435039964	8D543D	6573 597034	IRINA ALEKSANDROVA	{"phone": "+70678503467"}
0005435039965	8D543D	4227 145113	DMITRIY SHEVCHENKO	{"email": "shevchenkod_071981@postgrespro.ru", "phone": "+70467485804"}
0005435039966	67FE05	8229 149918	OLEG KOROLEV	{"phone": "+70883410777"}
0005435039967	1F12D1	4932 402958	VLADIMIR MAKAROV	{"email": "vladimir-makarov1975@postgrespro.ru", "phone": "+70264053407"}
0005435039968	048005	3803 850236	LYUDMILA YUDINA	{"email": "lyudina-1974@postgrespro.ru", "phone": "+70681147805"}
0005435039969	2804CD	3365 503327	LYUBOV MATVEEVA	{"email": "l-matveeva26081966@postgrespro.ru", "phone": "+70223832822"}
0005435039970	6365CA	5964 179956	NATALYA PAVLOVA	{"phone": "+70839639239"}
0005435039971	C84E09	8826 842381	IRINA YAKOVLEVA	{"phone": "+70530546894"}
0005435039972	20A402	6484 715916	IVAN PETROV	{"email": "petrov.i04101975@postgrespro.ru", "phone": "+70401102940"}
0005435039973	7E89FA	9316 733690	NATALYA ISAEVA	{"phone": "+70212385346"}
0005435039974	1EAF13	4565 407591	VLADIMIR MOISEEV	{"phone": "+70296800848"}
0005435039975	510F84	7567 014237	ALFIYA MASLOVA	{"phone": "+70767579831"}
0005435039976	4A8239	1518 432058	IRINA KAZAKOVA	{"phone": "+70665847416"}
0005435039977	47F4B6	5159 344852	NIKOLAY ZAKHAROV	{"email": "zakharov_n_31121968@postgrespro.ru", "phone": "+70889478123"}
0005435039978	ED4278	9460 394679	EKATERINA MOROZOVA	{"phone": "+70978766805"}
0005435039979	ED4278	5332 523392	ANNA MIRONOVA	{"phone": "+70682843100"}
0005435039980	91D528	2738 921416	SERGEY NIKOLAEV	{"email": "sergey.nikolaev.011975@postgrespro.ru", "phone": "+70237295645"}
0005435039981	7A3CF5	5860 686751	OLESYA NAZAROVA	{"email": "olesyanazarova-13061966@postgrespro.ru", "phone": "+70574744487"}
0005435039982	3C8B80	2517 283056	MARAT ILIN	{"phone": "+70593378973"}
0005435039983	EEDDEC	6972 452379	YURIY ZHURAVLEV	{"email": "zhuravlev_y-111980@postgrespro.ru", "phone": "+70970050639"}
0005435039984	D2A10F	0236 350173	DENIS IVANOV	{"email": "ivanov_d_16011981@postgrespro.ru", "phone": "+70011132394"}
0005435039985	7094B9	3608 423964	ANDREY KAZAKOV	{"email": "andreykazakov.081980@postgrespro.ru", "phone": "+70725373454"}
0005435039986	7094B9	4479 961126	ELIZAVETA AKIMOVA	{"email": "akimovaelizaveta_1972@postgrespro.ru", "phone": "+70251996519"}
0005435039987	6A5018	2669 693422	VALENTINA MIKHAYLOVA	{"email": "mikhaylova.valentina-071968@postgrespro.ru", "phone": "+70121599786"}
0005435039988	3D3B00	4681 946980	ELENA YAKOVLEVA	{"email": "elena-yakovleva_25081972@postgrespro.ru", "phone": "+70849838849"}
0005435039989	D626D7	9341 876649	ALEKSANDR KOZLOV	{"phone": "+70600703184"}
0005435039990	D626D7	8951 045195	DMITRIY FILIPPOV	{"email": "filippovd_1967@postgrespro.ru", "phone": "+70751190575"}
0005435039991	D626D7	3474 990338	IGOR MAKSIMOV	{"phone": "+70029329337"}
0005435039992	967576	9333 849352	SVETLANA GERASIMOVA	{"phone": "+70513818975"}
0005435039993	DAF421	7320 032218	VERONIKA LUKYANOVA	{"phone": "+70049175666"}
0005435039994	DAF421	8018 303919	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov021974@postgrespro.ru", "phone": "+70708519412"}
0005435039995	DAF421	2492 045112	EVA LUKYANOVA	{"phone": "+70882147843"}
0005435039996	52FA41	4510 608390	LILIYA POLYAKOVA	{"email": "polyakova-liliya10011976@postgrespro.ru", "phone": "+70891686074"}
0005435039997	8C3268	7180 428948	ELMIRA EGOROVA	{"email": "egorovae24031969@postgrespro.ru", "phone": "+70211841273"}
0005435039998	8C3268	5497 748866	RUSLAN ANTONOV	{"phone": "+70432638910"}
0005435039999	EDCD5B	4513 542460	TAMARA ANDREEVA	{"email": "andreeva.tamara041965@postgrespro.ru", "phone": "+70352226420"}
0005435040000	EDCD5B	5808 669465	ALEKSEY FEDOROV	{"phone": "+70846545640"}
0005435040001	6D296E	7115 528272	ANTONINA KOROLEVA	{"email": "antonina.koroleva_02121968@postgrespro.ru", "phone": "+70309818796"}
0005435040002	9187EA	9454 479010	EKATERINA ANISIMOVA	{"phone": "+70820947998"}
0005435040003	3229BC	5852 255751	ALEKSEY GORBUNOV	{"email": "gorbunovaleksey1973@postgrespro.ru", "phone": "+70225757841"}
0005435040004	DEDC9C	1257 216745	EGOR STEPANOV	{"email": "e_stepanov-01081963@postgrespro.ru", "phone": "+70112380102"}
0005435040005	B2C2D7	6053 612040	EDUARD BORISOV	{"email": "eduard_borisov23121976@postgrespro.ru", "phone": "+70058694781"}
0005435040006	6F350D	4089 002243	IVAN SAVELEV	{"email": "savelev-ivan.16061981@postgrespro.ru", "phone": "+70935553290"}
0005435040007	6C2F35	7892 686312	ANZHELA POPOVA	{"email": "anzhela.popova081983@postgrespro.ru", "phone": "+70080887103"}
0005435040008	239023	0645 787584	SVETLANA TARASOVA	{"phone": "+70376265890"}
0005435040009	239023	5530 924814	ANNA BORISOVA	{"phone": "+70507556743"}
0005435040010	51393C	6356 985633	DENIS KUZMIN	{"email": "kuzmin_denis.1975@postgrespro.ru", "phone": "+70586985313"}
0005435040011	B101C5	5942 755003	NINA FADEEVA	{"email": "n-fadeeva-1983@postgrespro.ru", "phone": "+70991605496"}
0005435040012	B101C5	5949 970646	POLINA PAVLOVA	{"email": "pavlovap-05121961@postgrespro.ru", "phone": "+70991400278"}
0005435040013	774D0A	5401 504737	ALEKSANDR DAVYDOV	{"phone": "+70919270020"}
0005435040014	0E5860	7655 676253	NADEZHDA DENISOVA	{"email": "denisova_nadezhda-1969@postgrespro.ru", "phone": "+70668885598"}
0005435040015	0E5860	4937 012197	KSENIYA CHERNOVA	{"email": "chernova-kseniya.091972@postgrespro.ru", "phone": "+70186236751"}
0005435040016	E3852C	9956 765457	YULIYA ZOTOVA	{"phone": "+70990529915"}
0005435040017	E3852C	7779 901321	RUSTAM MIKHAYLOV	{"phone": "+70333273687"}
0005435040018	E35E96	6817 876797	ALEKSANDR ABRAMOV	{"phone": "+70444313697"}
0005435040019	240EA6	0933 765053	MIKHAIL ILIN	{"phone": "+70034516392"}
0005435040020	0FAC6E	5502 063018	EDUARD AFANASEV	{"phone": "+70284071913"}
0005435040021	7AB6F2	8490 653656	ANDREY ANTONOV	{"phone": "+70970409157"}
0005435040022	AFAAA5	9100 667004	NADEZHDA FILIPPOVA	{"phone": "+70574594298"}
0005435040023	AFAAA5	6248 168215	INNA DANILOVA	{"phone": "+70613678334"}
0005435040024	AFAAA5	8654 162333	DMITRIY ZAKHAROV	{"email": "zakharov.dmitriy_1967@postgrespro.ru", "phone": "+70316088360"}
0005435040025	B443FC	4135 105696	GALINA ZHUKOVA	{"email": "galinazhukova031966@postgrespro.ru", "phone": "+70710264374"}
0005435040026	AB2448	4351 814874	NATALYA EGOROVA	{"email": "egorova_n08081964@postgrespro.ru", "phone": "+70941167310"}
0005435040027	AB2448	3458 912591	ANASTASIYA GAVRILOVA	{"phone": "+70491058311"}
0005435040028	5AE1AE	9891 951873	ALEKSANDR EGOROV	{"email": "egorov_aleksandr.15021975@postgrespro.ru", "phone": "+70828401518"}
0005435040029	5AE1AE	5968 170677	ELENA PETROVA	{"email": "petrova-e.051971@postgrespro.ru", "phone": "+70948305950"}
0005435040030	D4436E	9294 188804	ELENA IVANOVA	{"phone": "+70879331323"}
0005435040031	D4436E	9703 242691	MIKHAIL MAKSIMOV	{"email": "maksimov-m1985@postgrespro.ru", "phone": "+70913535859"}
0005435040032	E8CF3B	2503 984928	YURIY SIDOROV	{"email": "yuriy.sidorov-101971@postgrespro.ru", "phone": "+70826057756"}
0005435040033	E8CF3B	7923 449344	TATYANA MAKSIMOVA	{"phone": "+70478838425"}
0005435040034	9F4C67	2856 745754	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov-26021968@postgrespro.ru", "phone": "+70177239968"}
0005435040035	5F66A3	4500 643331	VALENTINA ILINA	{"phone": "+70460216760"}
0005435040036	5507FD	0935 554581	LYUDMILA POPOVA	{"email": "popova_lyudmila-101972@postgrespro.ru", "phone": "+70832545928"}
0005435040037	FF0A79	8504 610868	ALEKSEY TARASOV	{"email": "a-tarasov.041989@postgrespro.ru", "phone": "+70581375499"}
0005435040038	FF0A79	0159 498972	DARYA ANDREEVA	{"email": "d_andreeva061985@postgrespro.ru", "phone": "+70400774904"}
0005435040039	E49F74	1299 954370	VLADIMIR IVANOV	{"phone": "+70103803733"}
0005435040040	9A8E69	5984 013282	DIANA KOROLEVA	{"phone": "+70255683677"}
0005435040041	9A8E69	6274 790702	SERGEY KUZMIN	{"email": "kuzmins-121960@postgrespro.ru", "phone": "+70485608348"}
0005435040042	9071C5	4667 176008	VLADIMIR TARASOV	{"phone": "+70828499941"}
0005435040043	9071C5	2927 449609	POLINA DAVYDOVA	{"phone": "+70757298946"}
0005435040044	EA4448	2945 703928	ALINA ANTONOVA	{"phone": "+70795162166"}
0005435040045	B6D95F	9733 109333	EKATERINA KUZNECOVA	{"email": "ekuznecova_011973@postgrespro.ru", "phone": "+70335915272"}
0005435040046	37B540	7198 635479	DENIS FROLOV	{"email": "denis.frolov1975@postgrespro.ru", "phone": "+70301134702"}
0005435040047	37B540	5494 116564	ANNA FADEEVA	{"email": "a_fadeeva.18061974@postgrespro.ru", "phone": "+70793921123"}
0005435040048	84B441	1112 786292	ALEKSEY CHERNOV	{"phone": "+70034247535"}
0005435040049	E57622	4042 933951	BOGDAN MAKAROV	{"email": "makarov_bogdan_18041971@postgrespro.ru", "phone": "+70842732595"}
0005435040050	639B58	5766 769016	LYUBOV VASILEVA	{"phone": "+70292861053"}
0005435040051	EBB7C0	4022 145744	OLGA IVANOVA	{"email": "ivanova-o-071968@postgrespro.ru", "phone": "+70210938963"}
0005435040052	0C8F24	9208 777499	LARISA NOVIKOVA	{"phone": "+70490998018"}
0005435040053	1F9D22	3369 658624	ANDREY GERASIMOV	{"email": "gerasimov.a-1965@postgrespro.ru", "phone": "+70293560408"}
0005435040054	CC00B4	4130 188957	VLADIMIR POPOV	{"email": "popov-v.051971@postgrespro.ru", "phone": "+70062156895"}
0005435040055	14F033	5776 093980	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev_02111975@postgrespro.ru", "phone": "+70751934150"}
0005435040056	C74453	4661 418893	YULIYA SCHERBAKOVA	{"email": "scherbakova-yuliya1973@postgrespro.ru", "phone": "+70004478391"}
0005435040057	7AA7AA	7648 871954	MARINA CHERNOVA	{"email": "marina_chernova011964@postgrespro.ru", "phone": "+70290866314"}
0005435040058	2FDDF9	9096 828843	ELENA DMITRIEVA	{"email": "dmitrieva.e.24061959@postgrespro.ru", "phone": "+70368831882"}
0005435040059	2FDDF9	0548 201895	DENIS IVANOV	{"email": "ivanov.d_1968@postgrespro.ru", "phone": "+70435498731"}
0005435040060	7C59C2	3811 607527	NATALYA ANTONOVA	{"phone": "+70691741274"}
0005435040061	D2A47C	8834 624450	ELENA NOVIKOVA	{"email": "novikovae-091961@postgrespro.ru", "phone": "+70657995809"}
0005435040062	BFA680	4140 878299	IVAN NIKITIN	{"phone": "+70386514317"}
0005435040063	425636	3875 128409	ANDREY KUZNECOV	{"phone": "+70113328777"}
0005435040064	425636	9988 090430	TAISIYA MOROZOVA	{"email": "taisiya.morozova.1981@postgrespro.ru", "phone": "+70180032002"}
0005435040065	7F636B	4826 619254	PAVEL DAVYDOV	{"email": "davydovpavel_121981@postgrespro.ru", "phone": "+70282237319"}
0005435040066	7F636B	8963 995940	OLGA MAKAROVA	{"phone": "+70990447509"}
0005435040067	C9C59F	8909 630463	VLADIMIR CHERNOV	{"email": "v_chernov1968@postgrespro.ru", "phone": "+70938243500"}
0005435040068	D8A291	5568 630079	LYUDMILA SMIRNOVA	{"email": "lyudmila_smirnova.12121975@postgrespro.ru", "phone": "+70370926128"}
0005435040069	4E1A57	6326 400168	TATYANA SEMENOVA	{"email": "semenova_tatyana_05121972@postgrespro.ru", "phone": "+70508935193"}
0005435040070	4E1A57	0308 612558	EDUARD OSIPOV	{"email": "e_osipov_27071977@postgrespro.ru", "phone": "+70615236763"}
0005435040071	6EB026	2595 559269	IGOR MIKHAYLOV	{"email": "mikhaylov.igor.26061966@postgrespro.ru", "phone": "+70110545738"}
0005435040072	3FCA58	3447 292490	KONSTANTIN NIKITIN	{"email": "nikitin-k-24081971@postgrespro.ru", "phone": "+70417975318"}
0005435040073	3FCA58	8540 598781	ANNA GAVRILOVA	{"phone": "+70462054602"}
0005435040074	0D3F91	6645 158025	VIKTOR SMIRNOV	{"email": "smirnov-v.04101977@postgrespro.ru", "phone": "+70616109148"}
0005435040075	0D3F91	7390 227676	EKATERINA BELOVA	{"phone": "+70379532626"}
0005435040076	E4B454	1261 194857	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov.14021974@postgrespro.ru", "phone": "+70535759854"}
0005435040077	70BF29	5941 456173	INNA MIKHAYLOVA	{"email": "mikhaylovainna.15091974@postgrespro.ru", "phone": "+70714565013"}
0005435040078	70BF29	1880 417274	MARINA FROLOVA	{"email": "m_frolova-1977@postgrespro.ru", "phone": "+70102231111"}
0005435040079	7E3A73	5572 005726	VIKTOR RODIONOV	{"phone": "+70412134028"}
0005435040080	90EE87	6849 675542	ALEKSANDR MEDVEDEV	{"email": "medvedev.a-29011972@postgrespro.ru", "phone": "+70301589912"}
0005435040081	B6033A	8692 179463	VIKTOR VASILEV	{"email": "vasilevviktor_031988@postgrespro.ru", "phone": "+70408182105"}
0005435040082	B6033A	6771 371837	ALEKSANDR KUDRYASHOV	{"email": "aleksandr-kudryashov031966@postgrespro.ru", "phone": "+70875869654"}
0005435040083	FEA4B9	1490 636221	VLADIMIR MATVEEV	{"phone": "+70041149759"}
0005435040084	FEA4B9	8836 542351	MIKHAIL IVANOV	{"phone": "+70541563764"}
0005435040085	6057E0	3427 971780	NINA NIKITINA	{"email": "nikitinan.05081972@postgrespro.ru", "phone": "+70490672023"}
0005435040086	3D63C3	5797 352708	ANTON TIKHONOV	{"email": "tikhonov-anton-041960@postgrespro.ru", "phone": "+70518398773"}
0005435040087	3D63C3	4521 678615	SERGEY TARASOV	{"email": "tarasovsergey1970@postgrespro.ru", "phone": "+70333615598"}
0005435040088	1DE3D5	7766 116413	NIKITA YAKOVLEV	{"email": "yakovlev.nikita_04111963@postgrespro.ru", "phone": "+70837808295"}
0005435040089	0B50B2	7756 587144	LEONID ORLOV	{"email": "leonidorlov.1972@postgrespro.ru", "phone": "+70255404840"}
0005435040090	0B50B2	2337 028646	PETR NAZAROV	{"email": "petrnazarov_111965@postgrespro.ru", "phone": "+70259830599"}
0005435040091	A5FF04	6957 438274	ANDREY MEDVEDEV	{"email": "medvedev.a.1969@postgrespro.ru", "phone": "+70668288964"}
0005435040092	DDC7FF	8405 028550	FAINA PAVLOVA	{"email": "fpavlova1970@postgrespro.ru", "phone": "+70792872117"}
0005435040093	DDC7FF	6839 886216	YULIYA PAVLOVA	{"phone": "+70190473752"}
0005435040094	1BEBA5	3522 609530	YULIYA MIKHAYLOVA	{"phone": "+70265977492"}
0005435040095	51BAB6	0375 250585	DANIL DENISOV	{"email": "denisov-d.1968@postgrespro.ru", "phone": "+70239901703"}
0005435040096	51BAB6	4330 494726	GENNADIY ISAEV	{"phone": "+70898643948"}
0005435040097	75A92C	9171 534463	NINA MAKAROVA	{"email": "n.makarova_1972@postgrespro.ru", "phone": "+70284666867"}
0005435040098	837561	4533 395607	LYUDMILA SIDOROVA	{"phone": "+70537129677"}
0005435040099	837561	4074 981771	GALINA FILATOVA	{"phone": "+70515150334"}
0005435040100	908C3A	6007 514588	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila-14011965@postgrespro.ru", "phone": "+70316046024"}
0005435040101	908C3A	6843 405379	ANDREY NIKITIN	{"email": "andreynikitin-21121968@postgrespro.ru", "phone": "+70367600481"}
0005435040102	FB3F40	3080 495791	ALEKSEY MOROZOV	{"phone": "+70890169509"}
0005435040103	37BBE8	1826 622702	EVGENIYA KOROLEVA	{"phone": "+70014728140"}
0005435040105	591BC7	8967 914999	ALEKSANDR ALEKSEEV	{"phone": "+70191579570"}
0005435040106	38D7B3	4724 232363	EVGENIY GRIGOREV	{"email": "grigorev.e1974@postgrespro.ru", "phone": "+70898406332"}
0005435040107	38D7B3	0086 504394	TATYANA ALEKSEEVA	{"email": "tatyana_alekseeva-121957@postgrespro.ru", "phone": "+70664646556"}
0005435040108	E9C9FE	7336 703842	LIDIYA MAKAROVA	{"phone": "+70232100117"}
0005435040109	E9C9FE	7587 356273	ALEKSANDR MOISEEV	{"phone": "+70997492188"}
0005435040110	A80CAA	2287 211185	YULIYA NAZAROVA	{"email": "ynazarova_29041969@postgrespro.ru", "phone": "+70619312573"}
0005435040111	A80CAA	1258 466592	LYUBOV KOZLOVA	{"email": "kozlova-lyubov03061970@postgrespro.ru", "phone": "+70540551914"}
0005435040112	A80CAA	5006 993269	VALERIY GORBUNOV	{"email": "v-gorbunov-1971@postgrespro.ru", "phone": "+70615976781"}
0005435040113	002E15	0777 816362	PETR NIKITIN	{"phone": "+70782815925"}
0005435040114	C94111	7635 371699	LYUBOV BELYAEVA	{"email": "belyaeval_1972@postgrespro.ru", "phone": "+70681990965"}
0005435040115	A14F34	6641 806324	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr.21031968@postgrespro.ru", "phone": "+70072713519"}
0005435040116	44C83D	4495 858479	LYUDMILA SCHERBAKOVA	{"email": "scherbakova-lyudmila_011972@postgrespro.ru", "phone": "+70092397226"}
0005435040117	44C83D	9626 355180	TAMARA ROMANOVA	{"email": "tamararomanova.23031964@postgrespro.ru", "phone": "+70693616616"}
0005435040118	3D53CE	0518 576378	VLADISLAV PAVLOV	{"email": "pavlovvladislav_1966@postgrespro.ru", "phone": "+70122682242"}
0005435040119	3D53CE	4826 222795	DMITRIY BONDARENKO	{"email": "bondarenko_dmitriy-1980@postgrespro.ru", "phone": "+70262889668"}
0005435040120	F6CF61	0209 836963	KIRILL NIKOLAEV	{"email": "nikolaevkirill.031973@postgrespro.ru", "phone": "+70782614248"}
0005435040121	4A775E	5761 198756	VLADIMIR GORBUNOV	{"email": "gorbunov-vladimir_28121966@postgrespro.ru", "phone": "+70710381216"}
0005435040122	4A775E	1492 613280	ANDREY PETROV	{"email": "andrey_petrov_13031979@postgrespro.ru", "phone": "+70593423500"}
0005435040123	4A775E	9498 704915	ELENA SMIRNOVA	{"email": "e-smirnova.01021976@postgrespro.ru", "phone": "+70444992686"}
0005435040124	B1CA24	4106 812291	OKSANA IVANOVA	{"phone": "+70869213094"}
0005435040125	962989	8707 097105	NADEZHDA KISELEVA	{"email": "kiselevan-1982@postgrespro.ru", "phone": "+70148884490"}
0005435040126	878887	6326 450374	TIMUR FROLOV	{"phone": "+70341169307"}
0005435040127	878887	5764 037169	FAINA KOVALEVA	{"phone": "+70640736808"}
0005435040128	47276A	1778 171670	NATALYA MEDVEDEVA	{"email": "n_medvedeva_29071969@postgrespro.ru", "phone": "+70994088627"}
0005435040129	47276A	1002 316213	ARTEM KOZLOV	{"email": "kozlova-21061973@postgrespro.ru", "phone": "+70038709284"}
0005435040130	F789B6	9801 638192	ELENA CHERNOVA	{"phone": "+70469043732"}
0005435040131	F03D3A	0400 878428	KONSTANTIN EGOROV	{"phone": "+70098205118"}
0005435040132	FEB16C	3035 198995	BULAT ZHURAVLEV	{"phone": "+70297646626"}
0005435040133	AC5B88	7616 689684	ANASTASIYA NESTEROVA	{"email": "nesterova_a-091971@postgrespro.ru", "phone": "+70501738512"}
0005435040134	A373A5	1039 009765	DENIS ORLOV	{"phone": "+70880479734"}
0005435040135	A373A5	4793 824318	NIKITA ALEKSANDROV	{"email": "aleksandrov-n.06051970@postgrespro.ru", "phone": "+70645208124"}
0005435040136	C9DD3B	4059 552018	VALENTINA YAKOVLEVA	{"phone": "+70791612402"}
0005435040137	C9DD3B	7601 344545	MARIYA ILINA	{"email": "ilinamariya.1974@postgrespro.ru", "phone": "+70804705278"}
0005435040138	29C183	1716 105584	TATYANA SIDOROVA	{"email": "sidorova-tatyana-1976@postgrespro.ru", "phone": "+70891508955"}
0005435040139	D1C42E	6689 098903	ALEKSANDR SAVELEV	{"email": "savelev-a_04071968@postgrespro.ru", "phone": "+70337150952"}
0005435040140	0C5371	3393 507858	NATALYA MOROZOVA	{"email": "morozovanatalya27011964@postgrespro.ru", "phone": "+70612335235"}
0005435040141	4D78EE	8577 357807	ALEKSANDR ORLOV	{"phone": "+70138322961"}
0005435040142	F1825F	7334 666930	NADEZHDA BELYAEVA	{"phone": "+70501794316"}
0005435040143	B2AF3F	6373 201175	NATALYA KOZLOVA	{"phone": "+70343534536"}
0005435040144	F688B1	9232 059790	NINA BELYAEVA	{"phone": "+70205994939"}
0005435040145	FED445	4384 208966	EVGENIYA VOLKOVA	{"phone": "+70249176808"}
0005435040146	FED445	9454 123300	ANNA MOROZOVA	{"phone": "+70561493674"}
0005435040147	46FA94	4962 753654	NATALIYA KRASNOVA	{"phone": "+70790812060"}
0005435040148	46FA94	6525 344506	ALINA MAKSIMOVA	{"email": "maksimova.a03121970@postgrespro.ru", "phone": "+70955748726"}
0005435040149	CD1337	9710 911334	SVETLANA NIKOLAEVA	{"phone": "+70478866316"}
0005435040150	23F88D	7312 318124	ALENA BELOVA	{"phone": "+70285165914"}
0005435040151	DF74FF	1672 332282	OLGA ALEKSEEVA	{"phone": "+70528837964"}
0005435040152	737A71	8662 214867	ANNA IVANOVA	{"phone": "+70249999594"}
0005435040153	0C0194	9353 585419	TATYANA KAZAKOVA	{"email": "t_kazakova-27111982@postgrespro.ru", "phone": "+70852711479"}
0005435040154	0C0194	9625 586590	GALINA STEPANOVA	{"email": "g.stepanova-041971@postgrespro.ru", "phone": "+70159229103"}
0005435040155	605669	6146 666563	IRINA SAVELEVA	{"phone": "+70735322054"}
0005435040156	605669	4117 937083	MATVEY KARPOV	{"email": "karpovm16101969@postgrespro.ru", "phone": "+70465329737"}
0005435040157	605669	5988 559617	NATALIYA VASILEVA	{"email": "n.vasileva1968@postgrespro.ru", "phone": "+70024988827"}
0005435040158	B41CA4	7202 124297	KARINA NESTEROVA	{"email": "karina.nesterova_18031965@postgrespro.ru", "phone": "+70137305067"}
0005435040159	53AA82	3240 007300	DENIS STEPANOV	{"email": "stepanovd-1963@postgrespro.ru", "phone": "+70685275334"}
0005435040160	53AA82	9904 879615	ANDREY MAKAROV	{"email": "makarov_andrey_091972@postgrespro.ru", "phone": "+70632811173"}
0005435040161	59BFB4	9884 649712	KLAVDIYA ZOTOVA	{"email": "klavdiya_zotova1976@postgrespro.ru", "phone": "+70261762906"}
0005435040162	E2BBD1	9590 848725	ELIZAVETA YUDINA	{"phone": "+70171651622"}
0005435040163	C1A05E	0333 092967	KONSTANTIN SEMENOV	{"email": "semenov-k1964@postgrespro.ru", "phone": "+70912493042"}
0005435040164	C1A05E	0297 660690	EVGENIY VASILEV	{"phone": "+70618204964"}
0005435040165	0661AC	9062 853422	YAKOV SEMENOV	{"email": "semenov_yakov_25121974@postgrespro.ru", "phone": "+70088183100"}
0005435040166	0661AC	9180 021309	ZOYA GUSEVA	{"phone": "+70166625640"}
0005435040167	050998	6572 125459	ALEKSEY GAVRILOV	{"phone": "+70555750594"}
0005435040168	050998	9487 986337	MARINA ARKHIPOVA	{"email": "arkhipovam101978@postgrespro.ru", "phone": "+70154851586"}
0005435040169	ACF0C8	9578 704369	SVETLANA PETROVA	{"phone": "+70764456997"}
0005435040170	ACF0C8	5953 781697	SERGEY TARASOV	{"email": "starasov1979@postgrespro.ru", "phone": "+70352843489"}
0005435040171	7F4BAE	7303 967769	VALERIY VASILEV	{"email": "vasilev_valeriy.27101977@postgrespro.ru", "phone": "+70471642538"}
0005435040172	B0EF76	3285 657174	NIKOLAY TARASOV	{"email": "tarasov-n.1973@postgrespro.ru", "phone": "+70553401957"}
0005435040173	B0EF76	8783 523647	PELAGEYA MEDVEDEVA	{"phone": "+70083626285"}
0005435040174	7408F0	9945 101498	MARINA MATVEEVA	{"email": "marina_matveeva.021978@postgrespro.ru", "phone": "+70712809677"}
0005435040175	5D2FE2	9138 321076	KONSTANTIN ABRAMOV	{"phone": "+70973150108"}
0005435040176	26FF8E	1534 687357	GEORGIY KUZNECOV	{"phone": "+70587527906"}
0005435040177	D0D5D5	9319 705852	NINA ANTONOVA	{"email": "ninaantonova_031967@postgrespro.ru", "phone": "+70207942996"}
0005435040178	999924	9044 376353	MARIYA ANTONOVA	{"email": "m-antonova.071974@postgrespro.ru", "phone": "+70658059489"}
0005435040179	B40720	0102 781318	EVGENIY KRASNOV	{"email": "krasnov.evgeniy_03041965@postgrespro.ru", "phone": "+70704790208"}
0005435040180	06AD2B	7170 104061	IGOR PETROV	{"email": "igorpetrov_051977@postgrespro.ru", "phone": "+70141995686"}
0005435040181	06AD2B	5553 916035	TATYANA VOLKOVA	{"phone": "+70829672622"}
0005435040182	9C7B18	6774 526218	NIKOLAY MOROZOV	{"email": "morozovnikolay_21111970@postgrespro.ru", "phone": "+70751791914"}
0005435040183	9C7B18	2062 660850	LEONID VLASOV	{"email": "leonid-vlasov_031970@postgrespro.ru", "phone": "+70317413650"}
0005435040184	C002F2	4008 642942	IGOR MAKAROV	{"phone": "+70149912917"}
0005435040185	C32C12	9590 950346	SERGEY MAKAROV	{"phone": "+70813763849"}
0005435040186	C32C12	6724 234952	ANASTASIYA KUDRYASHOVA	{"email": "a.kudryashova_011972@postgrespro.ru", "phone": "+70830645118"}
0005435040187	0E480F	0668 537679	TATYANA FROLOVA	{"email": "t.frolova.16011967@postgrespro.ru", "phone": "+70700122105"}
0005435040188	3F62CD	1762 379718	MARIYA SOLOVEVA	{"email": "m.soloveva22011977@postgrespro.ru", "phone": "+70212675402"}
0005435040189	7AB1DF	8878 430317	DMITRIY IVANOV	{"email": "ivanov.d26061981@postgrespro.ru", "phone": "+70138580257"}
0005435040190	101DCC	7118 960996	NATALIYA NESTEROVA	{"email": "nesterova-n-011971@postgrespro.ru", "phone": "+70214209534"}
0005435040191	101DCC	1825 072950	MARINA ORLOVA	{"phone": "+70988266696"}
0005435040192	24C4FA	6673 403132	IVAN MAKAROV	{"email": "makarov_i-12011973@postgrespro.ru", "phone": "+70993938730"}
0005435040193	E42935	1104 827903	OLGA RODIONOVA	{"email": "orodionova041983@postgrespro.ru", "phone": "+70633010862"}
0005435040194	E42935	0549 714802	GALINA SERGEEVA	{"email": "sergeeva.g.061970@postgrespro.ru", "phone": "+70046144204"}
0005435040195	68E646	1163 980742	VIKTOR PAVLOV	{"phone": "+70871517315"}
0005435040196	51B037	6294 887768	NIKOLAY KUDRYASHOV	{"email": "kudryashov_nikolay.121973@postgrespro.ru", "phone": "+70228598535"}
0005435040197	51B037	6363 920694	VERA POLYAKOVA	{"phone": "+70109204580"}
0005435040198	51B037	0263 133348	VLADIMIR EGOROV	{"email": "egorovvladimir.1969@postgrespro.ru", "phone": "+70155624042"}
0005435040199	29D406	1109 185478	VALENTINA NIKOLAEVA	{"email": "nikolaeva_valentina081979@postgrespro.ru", "phone": "+70068794165"}
0005435040200	29D406	2901 460194	SERGEY FOMIN	{"phone": "+70792451179"}
0005435040201	29D406	6003 305476	ALEKSANDR ZAYCEV	{"phone": "+70427523568"}
0005435040202	E3FF33	1384 310301	DMITRIY SAVELEV	{"phone": "+70712174228"}
0005435040203	08CEDC	1922 010024	NIKOLAY KUZNECOV	{"phone": "+70714415173"}
0005435040204	08CEDC	0018 401716	LYUBOV RODIONOVA	{"email": "rodionova-l.17091963@postgrespro.ru", "phone": "+70807946645"}
0005435040205	E09C0B	2457 795911	DMITRIY NIKITIN	{"email": "nikitin_d.16021977@postgrespro.ru", "phone": "+70841422971"}
0005435040206	E09C0B	0598 936690	NADEZHDA SERGEEVA	{"phone": "+70834359830"}
0005435040207	72BF2E	6380 324061	VENERA PETROVA	{"phone": "+70530550900"}
0005435040208	EB9499	9569 539293	YURIY IVANOV	{"email": "ivanov.y-071980@postgrespro.ru", "phone": "+70661733359"}
0005435040209	501E55	7724 956043	OLEG NAZAROV	{"email": "nazarovoleg-02071978@postgrespro.ru", "phone": "+70895845263"}
0005435040210	7FE0FF	2236 915948	PETR MOISEEV	{"email": "moiseevpetr_1972@postgrespro.ru", "phone": "+70958166418"}
0005435040211	46B4CA	6836 430970	ELIZAVETA FROLOVA	{"phone": "+70809446181"}
0005435040212	46B4CA	6074 568924	ALEKSANDR BELOV	{"email": "belova-16011976@postgrespro.ru", "phone": "+70519845799"}
0005435040213	2CAE60	9304 485275	GALINA AKIMOVA	{"phone": "+70263507774"}
0005435040214	C75339	8332 052319	MARINA KUZMINA	{"email": "m.kuzmina-071972@postgrespro.ru", "phone": "+70095185706"}
0005435040215	AFE71D	9625 094656	VYACHESLAV RODIONOV	{"phone": "+70717063629"}
0005435040216	AFE71D	1350 671580	ALEKSANDR VASILEV	{"email": "vasilevaleksandr-30031982@postgrespro.ru", "phone": "+70206491270"}
0005435040217	AFE71D	2614 303335	EVGENIY IVANOV	{"phone": "+70204650266"}
0005435040218	0F4D05	1831 966825	GALINA IVANOVA	{"email": "g-ivanova.121973@postgrespro.ru", "phone": "+70314770901"}
0005435040219	0F4D05	3716 969623	ALINA ZAKHAROVA	{"phone": "+70000133706"}
0005435040220	4B8C7F	4969 109917	ROSTISLAV SAVELEV	{"email": "savelev-r.071977@postgrespro.ru", "phone": "+70782834444"}
0005435040221	59636B	5847 308065	NINA KUDRYASHOVA	{"phone": "+70816268518"}
0005435040222	BDA8EC	5175 507005	VLADIMIR GORBUNOV	{"phone": "+70986321300"}
0005435040223	7CB93D	8278 234812	GENNADIY DMITRIEV	{"phone": "+70846896064"}
0005435040224	3CE090	3367 586218	ANDREY MOROZOV	{"phone": "+70003932711"}
0005435040225	E90B86	4375 822347	ELENA SEMENOVA	{"email": "semenovaelena.051970@postgrespro.ru", "phone": "+70308638848"}
0005435040226	E90B86	3272 653864	ELENA BELYAEVA	{"email": "elena.belyaeva1972@postgrespro.ru", "phone": "+70791116781"}
0005435040227	E19130	2108 494599	NATALYA SAVELEVA	{"email": "natalya_saveleva.091976@postgrespro.ru", "phone": "+70051036148"}
0005435040228	E19130	3055 857443	IRINA LAZAREVA	{"phone": "+70534497669"}
0005435040229	8882A7	6503 088153	NELLI PAVLOVA	{"phone": "+70742521488"}
0005435040230	8882A7	1238 968612	NIKOLAY PETROV	{"phone": "+70381446845"}
0005435040231	8882A7	7977 574085	GALINA KUZNECOVA	{"phone": "+70479277075"}
0005435040232	CCA64B	5857 491887	ALEKSANDR FILIPPOV	{"phone": "+70847019864"}
0005435040233	551CBC	0704 093813	SVETLANA POPOVA	{"email": "popova.svetlana-101967@postgrespro.ru", "phone": "+70960795581"}
0005435040234	EAC59E	8304 981366	RAISA ANTONOVA	{"email": "antonova-r-061973@postgrespro.ru", "phone": "+70998888282"}
0005435040235	1F8890	4231 556779	IVAN TIKHONOV	{"email": "i-tikhonov.1967@postgrespro.ru", "phone": "+70484009604"}
0005435040236	65CAD9	4136 692916	LARISA NAZAROVA	{"email": "l_nazarova-1966@postgrespro.ru", "phone": "+70862244772"}
0005435040237	DE3E64	9886 018579	ELENA SOROKINA	{"email": "sorokina-e-17031976@postgrespro.ru", "phone": "+70593906049"}
0005435040238	10761F	1192 686478	VLADIMIR PETROV	{"email": "petrovvladimir1963@postgrespro.ru", "phone": "+70276056280"}
0005435040239	5B54E0	9923 497930	ANVAR NIKITIN	{"email": "a-nikitin_1972@postgrespro.ru", "phone": "+70506096972"}
0005435040240	5B54E0	6029 157328	TAMARA IVANOVA	{"email": "ivanovatamara1970@postgrespro.ru", "phone": "+70035586164"}
0005435040241	9D3A95	4434 127748	SERGEY ZAKHAROV	{"phone": "+70133904302"}
0005435040242	D8E2DB	7977 690212	RAMILYA LAZAREVA	{"phone": "+70535721943"}
0005435040243	E0E3F8	5426 853026	VALENTINA EFREMOVA	{"phone": "+70975756886"}
0005435040244	1F892F	0015 114718	SERGEY VLASOV	{"email": "vlasov.sergey.011979@postgrespro.ru", "phone": "+70928733045"}
0005435040245	1F892F	0378 795193	DARYA DMITRIEVA	{"phone": "+70252295852"}
0005435040246	937F13	1524 459451	VERA MEDVEDEVA	{"email": "v_medvedeva.1971@postgrespro.ru", "phone": "+70452250734"}
0005435040247	C31CB0	9054 355678	NINA BARANOVA	{"email": "baranova-nina-1973@postgrespro.ru", "phone": "+70117121986"}
0005435040248	06932A	3782 308379	DMITRIY MEDVEDEV	{"phone": "+70150660938"}
0005435040249	0C8408	4537 039557	ELENA ALEKSANDROVA	{"phone": "+70999386620"}
0005435040250	4D58CC	1155 286966	LYUDMILA TARASOVA	{"phone": "+70089262667"}
0005435040251	4D9388	2434 715896	ANASTASIYA NESTEROVA	{"email": "anastasiya-nesterova-1975@postgrespro.ru", "phone": "+70335515046"}
0005435040252	399341	2966 795655	OLGA NAUMOVA	{"email": "onaumova051959@postgrespro.ru", "phone": "+70675056130"}
0005435040253	399341	3828 035844	LYUDMILA RODIONOVA	{"phone": "+70929943042"}
0005435040254	0E27CB	5829 075165	DMITRIY GORBUNOV	{"email": "gorbunov.dmitriy_1963@postgrespro.ru", "phone": "+70271395337"}
0005435040255	CCFAFB	9642 943855	RAFIK ROMANOV	{"email": "rromanov061969@postgrespro.ru", "phone": "+70788679394"}
0005435040256	CCFAFB	1475 919037	LYUBOV EFREMOVA	{"phone": "+70336320097"}
0005435040257	CCFAFB	3570 661254	EVGENIY FEDOROV	{"email": "fedorov.evgeniy-041971@postgrespro.ru", "phone": "+70790622722"}
0005435040258	304C43	9082 084324	VLADISLAV NOVIKOV	{"phone": "+70072201294"}
0005435040259	304C43	1288 393497	DARYA ZAYCEVA	{"email": "darya_zayceva101975@postgrespro.ru", "phone": "+70789129049"}
0005435040260	81E636	4170 398424	NIKITA FEDOROV	{"email": "n_fedorov-04041972@postgrespro.ru", "phone": "+70694639982"}
0005435040261	81E636	5818 502933	SERGEY SMIRNOV	{"email": "ssmirnov-18111969@postgrespro.ru", "phone": "+70376671529"}
0005435040262	CB7CDC	1357 230809	INNA STEPANOVA	{"phone": "+70817801343"}
0005435040263	B70348	5062 003339	DMITRIY BARANOV	{"email": "d.baranov_15121959@postgrespro.ru", "phone": "+70210351756"}
0005435040264	F52DB9	0416 843093	EVGENIY KUZNECOV	{"email": "kuznecov_evgeniy18051973@postgrespro.ru", "phone": "+70177465556"}
0005435040265	F52DB9	8694 329727	VERONIKA VASILEVA	{"email": "vasileva_veronika_031977@postgrespro.ru", "phone": "+70405858051"}
0005435040266	99E24D	9934 026402	ALEKSANDRA RODIONOVA	{"email": "aleksandrarodionova.1960@postgrespro.ru", "phone": "+70984363877"}
0005435040267	963BF0	0050 237730	VALERIY ANTONOV	{"phone": "+70367892898"}
0005435040268	4A6C85	3134 631020	TAMARA ALEKSEEVA	{"email": "t_alekseeva041965@postgrespro.ru", "phone": "+70608470726"}
0005435040269	DBAC32	7921 841141	TAISIYA ILINA	{"phone": "+70330935994"}
0005435040270	3BB7C1	9317 419617	ANTONINA ILINA	{"phone": "+70389822461"}
0005435040271	AE2683	2703 773774	OLGA SERGEEVA	{"phone": "+70224174932"}
0005435040272	11B505	5829 255999	EVGENIY NIKOLAEV	{"email": "evgeniynikolaev_06121972@postgrespro.ru", "phone": "+70783235680"}
0005435040273	716FD2	5720 999961	TATYANA KUZMINA	{"email": "t.kuzmina_1969@postgrespro.ru", "phone": "+70341126024"}
0005435040274	E2C024	4392 429789	IGOR FOMIN	{"email": "fomin.i-27071971@postgrespro.ru", "phone": "+70899104776"}
0005435040275	E2C024	9812 189376	YULIYA SEMENOVA	{"phone": "+70473512809"}
0005435040276	D49648	2133 287224	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov_121971@postgrespro.ru", "phone": "+70858050013"}
0005435040277	D49648	2721 687286	YULIYA MOROZOVA	{"phone": "+70327937069"}
0005435040278	ED739D	5133 717658	ELENA NOVIKOVA	{"email": "enovikova-1979@postgrespro.ru", "phone": "+70948890469"}
0005435040279	EF619B	1912 211322	ALLA ANTONOVA	{"email": "antonova_a.041966@postgrespro.ru", "phone": "+70023684455"}
0005435040280	EF619B	2992 342445	DMITRIY MIRONOV	{"email": "mironov_d1981@postgrespro.ru", "phone": "+70309412906"}
0005435040281	EF619B	3558 604918	EGOR IVANOV	{"email": "egor_ivanov1967@postgrespro.ru", "phone": "+70411454552"}
0005435040342	108E52	2670 654278	ALEKSANDR TARASOV	{"phone": "+70055298477"}
0005435040282	C1F533	9595 984660	MARINA TITOVA	{"email": "m_titova08041969@postgrespro.ru", "phone": "+70686476742"}
0005435040283	00431A	4917 276162	VLADIMIR PETROV	{"phone": "+70911602323"}
0005435040284	EF271A	4952 654205	VALERIYA GRISHINA	{"phone": "+70634346735"}
0005435040285	47114A	5307 767506	EKATERINA IVANOVA	{"email": "ekaterina-ivanova_021972@postgrespro.ru", "phone": "+70114178087"}
0005435040286	47114A	0312 385867	RUSLAN DMITRIEV	{"email": "dmitriev_ruslan.13121978@postgrespro.ru", "phone": "+70952729042"}
0005435040287	7C0994	5191 755100	ADELINA SMIRNOVA	{"email": "asmirnova041972@postgrespro.ru", "phone": "+70525423591"}
0005435040288	F087E8	6479 574871	IRINA KONOVALOVA	{"phone": "+70546042870"}
0005435040289	85DDC6	1993 209104	MARINA MELNIKOVA	{"email": "melnikova-marina-22111970@postgrespro.ru", "phone": "+70103711897"}
0005435040290	028512	3107 421071	ELENA RYABOVA	{"email": "ryabova_elena13041965@postgrespro.ru", "phone": "+70277278699"}
0005435040291	392BDF	4481 558703	YURIY ALEKSANDROV	{"email": "yaleksandrov.121974@postgrespro.ru", "phone": "+70355781227"}
0005435040292	720FA3	8636 873955	PAVEL VLASOV	{"phone": "+70565525362"}
0005435040293	720FA3	6767 720266	YURIY GERASIMOV	{"phone": "+70642778115"}
0005435040294	39EBA0	7552 685605	VENERA IVANOVA	{"phone": "+70705586408"}
0005435040295	3C9827	6336 365694	EGOR SEMENOV	{"phone": "+70399820279"}
0005435040296	3C9827	0597 338397	TAISIYA VOLKOVA	{"email": "volkova_t_091968@postgrespro.ru", "phone": "+70667302010"}
0005435040297	8C3AB4	4804 593157	YULIYA MEDVEDEVA	{"email": "y-medvedeva_091970@postgrespro.ru", "phone": "+70753560869"}
0005435040298	A04556	8842 496660	KONSTANTIN MEDVEDEV	{"phone": "+70438012792"}
0005435040299	941A61	6847 562100	ALEKSANDR BARANOV	{"phone": "+70365717121"}
0005435040300	29E17D	5630 245048	VLADIMIR KUZMIN	{"email": "kuzmin.v.07071976@postgrespro.ru", "phone": "+70892322457"}
0005435040301	29E17D	6591 473565	RUSLAN ORLOV	{"email": "rorlov041976@postgrespro.ru", "phone": "+70527982301"}
0005435040302	249EB6	8830 259763	SVETLANA ANISIMOVA	{"phone": "+70927531174"}
0005435040303	453B80	2339 431111	EVGENIY BONDARENKO	{"email": "bondarenko.evgeniy1965@postgrespro.ru", "phone": "+70335113159"}
0005435040304	5FEFA4	3195 488077	ALEKSEY FEDOROV	{"phone": "+70387493246"}
0005435040305	AE1462	4771 145768	NIKOLAY KUZNECOV	{"phone": "+70022873112"}
0005435040306	B4C4B9	8295 226465	POLINA DENISOVA	{"phone": "+70212077761"}
0005435040307	B4C4B9	0246 304466	PAVEL ALEKSEEV	{"phone": "+70636091631"}
0005435040308	1372C5	4074 272584	LIDIYA ALEKSANDROVA	{"phone": "+70657954033"}
0005435040309	E3293E	6756 183170	ILYA MELNIKOV	{"email": "i.melnikov-13091974@postgrespro.ru", "phone": "+70354103343"}
0005435040310	E3293E	8882 795852	OLEG STEPANOV	{"email": "o-stepanov.24081970@postgrespro.ru", "phone": "+70437409328"}
0005435040311	47D672	9872 590894	VIKTOR EGOROV	{"email": "egorov_viktor.29101966@postgrespro.ru", "phone": "+70951882200"}
0005435040312	93911E	7728 404717	NATALYA NOVIKOVA	{"phone": "+70958408642"}
0005435040313	0F17D3	6816 588546	IRINA BOGDANOVA	{"email": "bogdanova-i.21101970@postgrespro.ru", "phone": "+70782185685"}
0005435040314	F5AD32	4430 285860	OLGA BORISOVA	{"phone": "+70128747612"}
0005435040315	F5AD32	7725 526668	OLGA MIKHAYLOVA	{"email": "mikhaylova-olga-16081970@postgrespro.ru", "phone": "+70191691077"}
0005435040316	F2DDD0	9712 717299	ELENA KUDRYASHOVA	{"phone": "+70002841332"}
0005435040317	F2DDD0	0652 585843	VIKTOR GRIGOREV	{"phone": "+70939997174"}
0005435040318	C7E73D	9233 929911	FEDOR MAKSIMOV	{"phone": "+70031408066"}
0005435040319	C7E73D	5794 483064	NATALYA ORLOVA	{"phone": "+70518085459"}
0005435040320	EC96D9	8311 977962	NIKOLAY ZAKHAROV	{"email": "zakharovn-1962@postgrespro.ru", "phone": "+70916192111"}
0005435040321	EC96D9	0029 403695	SERGEY GERASIMOV	{"email": "sergeygerasimov_1975@postgrespro.ru", "phone": "+70101821120"}
0005435040322	6A75CD	9142 476736	OLEG KUZNECOV	{"phone": "+70271686771"}
0005435040323	C64001	6906 411080	IVAN POPOV	{"email": "popovi_12101973@postgrespro.ru", "phone": "+70708487935"}
0005435040324	C64001	0694 529597	ALEKSEY MOISEEV	{"email": "a-moiseev22111971@postgrespro.ru", "phone": "+70872154222"}
0005435040325	E8FA68	3126 912736	OLGA DMITRIEVA	{"email": "olga-dmitrieva-30011981@postgrespro.ru", "phone": "+70225571601"}
0005435040326	8377FB	7237 817293	NINA LAZAREVA	{"email": "n-lazareva-071988@postgrespro.ru", "phone": "+70265274576"}
0005435040327	E9C4FE	2561 827261	TATYANA SAVELEVA	{"email": "tatyana.saveleva.16111970@postgrespro.ru", "phone": "+70852762076"}
0005435040328	978F33	5225 697344	ARTEM MOROZOV	{"phone": "+70169607564"}
0005435040329	3A5BA9	6137 753655	ANNA MIKHAYLOVA	{"phone": "+70418161278"}
0005435040330	3A5BA9	8391 543019	KIRILL KARPOV	{"email": "karpovk_1972@postgrespro.ru", "phone": "+70811874095"}
0005435040331	56FFA6	6665 558255	ARTEM SIDOROV	{"email": "sidorov_a-021978@postgrespro.ru", "phone": "+70263094159"}
0005435040332	E4A7FC	1428 643754	SERGEY KUZNECOV	{"email": "s-kuznecov_10051966@postgrespro.ru", "phone": "+70806347001"}
0005435040333	E4A7FC	0253 317563	YULIYA KUZMINA	{"email": "kuzmina_yuliya1969@postgrespro.ru", "phone": "+70656390694"}
0005435040334	6753FE	2558 483574	GALINA NOVIKOVA	{"phone": "+70344245745"}
0005435040335	6753FE	4161 181061	ILYA KUZNECOV	{"phone": "+70047833005"}
0005435040336	60AE97	4952 348717	TATYANA EFREMOVA	{"email": "t.efremova.031971@postgrespro.ru", "phone": "+70781552830"}
0005435040337	60AE97	8065 712266	PETR NIKITIN	{"phone": "+70768861463"}
0005435040338	BDAE0A	4179 095035	VALENTINA ALEKSANDROVA	{"email": "v.aleksandrova_02051977@postgrespro.ru", "phone": "+70945350102"}
0005435040339	BDAE0A	3145 594421	ANATOLIY SHEVCHENKO	{"phone": "+70034742029"}
0005435040340	79CB72	1991 562176	ALEKSEY KARPOV	{"email": "karpov.a_121966@postgrespro.ru", "phone": "+70443204579"}
0005435040341	79CB72	3861 893029	IRINA PETROVA	{"email": "petrovai091978@postgrespro.ru", "phone": "+70577071173"}
0005435040343	14A47A	5160 892696	NATALYA ZAKHAROVA	{"phone": "+70982302739"}
0005435040344	B7F033	8283 066525	EVGENIY MAKSIMOV	{"phone": "+70511846419"}
0005435040345	251FAD	0705 196168	ANASTASIYA ANTONOVA	{"phone": "+70060486333"}
0005435040346	599A68	7804 656130	SOFYA SIDOROVA	{"email": "sofyasidorova.1977@postgrespro.ru", "phone": "+70378999287"}
0005435040347	413E71	4846 350540	EGOR GAVRILOV	{"phone": "+70949878847"}
0005435040348	6C9F06	6483 420947	ZHANNA SOKOLOVA	{"email": "zhanna_sokolova1973@postgrespro.ru", "phone": "+70939176654"}
0005435040349	9BAB10	7203 927833	ROMAN KOZLOV	{"email": "kozlov.r_10121969@postgrespro.ru", "phone": "+70934363196"}
0005435040350	9BAB10	7992 928861	BORIS PETROV	{"phone": "+70948997190"}
0005435040351	EA6C93	1873 721545	ALEKSANDR KUDRYASHOV	{"email": "a_kudryashov081981@postgrespro.ru", "phone": "+70947590388"}
0005435040352	481E67	2977 820470	NIKOLAY ANTONOV	{"email": "n_antonov_101970@postgrespro.ru", "phone": "+70083631950"}
0005435040353	481E67	9972 100773	YURIY VOROBEV	{"email": "yuriy-vorobev.061966@postgrespro.ru", "phone": "+70914241373"}
0005435040354	C92F1D	3074 434881	STANISLAV KUZNECOV	{"phone": "+70131784343"}
0005435040355	403B2A	3334 146345	MIKHAIL VASILEV	{"phone": "+70903663965"}
0005435040356	B3A4A3	1629 374183	ELENA ZAKHAROVA	{"phone": "+70104908413"}
0005435040357	785156	6673 863686	VALERIY GRIGOREV	{"email": "grigorev.v-111968@postgrespro.ru", "phone": "+70866762200"}
0005435040358	77DD1B	0993 106780	NATALYA KUZNECOVA	{"phone": "+70725307323"}
0005435040359	CCE387	6812 202446	DANIIL MIKHAYLOV	{"email": "mikhaylovdaniil_10011967@postgrespro.ru", "phone": "+70515265811"}
0005435040360	CCE387	8176 537880	DMITRIY MOISEEV	{"email": "moiseev_d.01021979@postgrespro.ru", "phone": "+70580830967"}
0005435040361	CCE387	4256 100386	ALEKSEY AFANASEV	{"email": "afanasev_aleksey23091958@postgrespro.ru", "phone": "+70203951895"}
0005435040362	1CB991	7003 158646	ANNA ALEKSEEVA	{"email": "alekseeva-anna1986@postgrespro.ru", "phone": "+70341164672"}
0005435040363	1CB991	6627 645476	EVGENIY ABRAMOV	{"email": "abramov_evgeniy_031964@postgrespro.ru", "phone": "+70217514404"}
0005435040364	C0DC00	0117 928241	NATALIYA PAVLOVA	{"phone": "+70278604259"}
0005435040365	3DD786	6341 616945	SERGEY BARANOV	{"phone": "+70348047104"}
0005435040366	3DD786	1128 370610	ARTEM GAVRILOV	{"email": "artem.gavrilov1977@postgrespro.ru", "phone": "+70807611577"}
0005435040367	EA79D7	6808 403075	VERA VASILEVA	{"phone": "+70310997940"}
0005435040368	EA79D7	6601 597093	ANNA GORBUNOVA	{"email": "gorbunova-anna-021973@postgrespro.ru", "phone": "+70341800097"}
0005435040369	FA2BD2	5828 602265	LYUBOV KARPOVA	{"email": "karpova-lyubov.16121986@postgrespro.ru", "phone": "+70502797736"}
0005435040370	E5FA78	3119 440770	RAISA KOVALEVA	{"email": "kovaleva-r-07081966@postgrespro.ru", "phone": "+70785447697"}
0005435040371	AE94F1	5574 958993	GALINA ISAEVA	{"phone": "+70371438989"}
0005435040372	C10712	1728 342363	SERGEY NOVIKOV	{"phone": "+70989574857"}
0005435040373	64F866	4258 694902	DMITRIY SERGEEV	{"email": "d_sergeev081976@postgrespro.ru", "phone": "+70849171881"}
0005435040374	64F866	5826 183741	OLEG ISAEV	{"phone": "+70514844919"}
0005435040375	93ABA0	6335 124327	LIDIYA TARASOVA	{"email": "l_tarasova_1967@postgrespro.ru", "phone": "+70426112686"}
0005435040376	BF8F53	3513 058688	VITALIY SHEVCHENKO	{"phone": "+70280160535"}
0005435040377	BF8F53	9306 419765	DANIIL SEMENOV	{"email": "daniilsemenov-1982@postgrespro.ru", "phone": "+70152358040"}
0005435040378	F8F46F	2044 251909	EVGENIY PETROV	{"email": "e_petrov101969@postgrespro.ru", "phone": "+70592486987"}
0005435040379	F8F46F	5555 867135	SVETLANA GAVRILOVA	{"phone": "+70938512207"}
0005435040380	E4292B	6552 015699	DARYA VOROBEVA	{"email": "dvorobeva091963@postgrespro.ru", "phone": "+70086328638"}
0005435040381	191CD0	0170 170953	YULIYA SEMENOVA	{"phone": "+70992363992"}
0005435040382	191CD0	2829 170622	ALEKSANDR IVANOV	{"phone": "+70059899801"}
0005435040383	4618F9	8800 442287	IGOR ABRAMOV	{"phone": "+70038717565"}
0005435040384	4618F9	9480 544853	KONSTANTIN MOROZOV	{"email": "morozovk-061969@postgrespro.ru", "phone": "+70521426716"}
0005435040385	091F11	1474 879145	NIKOLAY PETROV	{"email": "nikolay-petrov.071983@postgrespro.ru", "phone": "+70003446996"}
0005435040386	FD7A63	3279 344601	ALEKSANDR FOMIN	{"phone": "+70394204996"}
0005435040387	FD7A63	6207 384553	MATVEY PETROV	{"phone": "+70624584223"}
0005435040388	B266DF	1817 685433	IRINA ZHUKOVA	{"email": "zhukova_irina_011957@postgrespro.ru", "phone": "+70140788517"}
0005435040389	F3C97A	1901 975310	ELENA KUZNECOVA	{"email": "kuznecovae_041973@postgrespro.ru", "phone": "+70125680286"}
0005435040390	9F46A1	3910 752810	SERGEY ALEKSEEV	{"phone": "+70333576957"}
0005435040391	AA0CCC	8457 351037	VERA ISAEVA	{"phone": "+70164249454"}
0005435040392	AA0CCC	3664 347154	ANDREY SHEVCHENKO	{"email": "shevchenkoandrey101971@postgrespro.ru", "phone": "+70977918645"}
0005435040393	1715A3	6630 941917	TAMARA MATVEEVA	{"phone": "+70744214211"}
0005435040394	0527A2	8906 539517	NATALYA FILIPPOVA	{"phone": "+70542630163"}
0005435040395	0527A2	8732 656509	EGOR BORISOV	{"email": "e_borisov.091958@postgrespro.ru", "phone": "+70844760453"}
0005435040396	7B4002	1343 063513	VLADIMIR TIKHONOV	{"email": "tikhonovvladimir_1969@postgrespro.ru", "phone": "+70609431065"}
0005435040397	C43E3D	4429 915827	ANASTASIYA IVANOVA	{"phone": "+70042556110"}
0005435040398	9292E0	3589 846904	VERA MELNIKOVA	{"email": "melnikova-v-121966@postgrespro.ru", "phone": "+70498050669"}
0005435040399	31707C	7623 418133	IVAN KAZAKOV	{"email": "ivan_kazakov.11041975@postgrespro.ru", "phone": "+70458092793"}
0005435040400	C7CE3F	5537 181168	ALEKSEY MOROZOV	{"email": "morozov.a1956@postgrespro.ru", "phone": "+70760713254"}
0005435040401	54B7AE	3876 173657	OLEG IVANOV	{"email": "o.ivanov_1968@postgrespro.ru", "phone": "+70320947433"}
0005435040402	54B7AE	8630 525388	IRINA KOZLOVA	{"phone": "+70974337118"}
0005435040403	E7847F	4923 878760	ANASTASIYA IVANOVA	{"phone": "+70363740888"}
0005435040404	E8BF2E	3155 956718	SERGEY DAVYDOV	{"email": "davydov.s-21031970@postgrespro.ru", "phone": "+70910983294"}
0005435040405	A7E54F	7667 661286	IRINA GUSEVA	{"phone": "+70160191785"}
0005435040406	0EE616	0710 788292	TAMARA IVANOVA	{"phone": "+70471883944"}
0005435040407	0EE616	8517 541909	KIRILL ORLOV	{"email": "kirillorlov08081968@postgrespro.ru", "phone": "+70409015667"}
0005435040408	0EE7BF	7533 662909	SERGEY CHERNOV	{"email": "chernovsergey-1971@postgrespro.ru", "phone": "+70699487477"}
0005435040409	78B862	9341 973018	ELIZAVETA KALININA	{"email": "elizaveta.kalinina15061969@postgrespro.ru", "phone": "+70125764673"}
0005435040410	CC7135	8987 296156	MARINA KUZNECOVA	{"phone": "+70540179990"}
0005435040411	CC7135	2195 271675	ANNA AFANASEVA	{"phone": "+70249006354"}
0005435040412	2BC088	1852 619668	ROMAN MIRONOV	{"phone": "+70764004606"}
0005435040413	F23DC8	7263 496240	VYACHESLAV MOROZOV	{"email": "v-morozov_071964@postgrespro.ru", "phone": "+70598500593"}
0005435040414	B42E61	7308 962812	ELENA FOMINA	{"email": "fomina-elena-03021970@postgrespro.ru", "phone": "+70311805633"}
0005435040415	D9FB25	6827 162214	ALEKSANDR ZAKHAROV	{"phone": "+70435601918"}
0005435040416	FC03EF	8506 795627	ANTONINA POPOVA	{"phone": "+70454662382"}
0005435040417	11442E	4801 430689	YURIY ISAEV	{"phone": "+70908200446"}
0005435040418	11442E	7752 715108	GAGIK KUZNECOV	{"email": "kuznecov-gagik11061977@postgrespro.ru", "phone": "+70140594742"}
0005435040419	411FA9	4150 439535	EVGENIYA TARASOVA	{"email": "evgeniyatarasova-1973@postgrespro.ru", "phone": "+70613553974"}
0005435040420	A26358	8189 937987	MARINA EGOROVA	{"email": "marinaegorova-1968@postgrespro.ru", "phone": "+70832732883"}
0005435040421	0ACA5C	8286 674043	ANDREY MELNIKOV	{"email": "a_melnikov_111979@postgrespro.ru", "phone": "+70252092821"}
0005435040422	0ACA5C	8384 333859	ALEKSEY SERGEEV	{"phone": "+70515538229"}
0005435040423	FB2671	8370 606201	VYACHESLAV NOVIKOV	{"email": "novikov_vyacheslav.071964@postgrespro.ru", "phone": "+70857492956"}
0005435040424	E4BE5C	9702 372185	OLGA SMIRNOVA	{"email": "smirnova.olga.19071963@postgrespro.ru", "phone": "+70684395173"}
0005435040425	E4BE5C	6924 675421	RAISA KUZNECOVA	{"email": "kuznecova.r.021972@postgrespro.ru", "phone": "+70830590059"}
0005435040426	84C7BB	0496 644462	VADIM NIKITIN	{"phone": "+70678166304"}
0005435040427	84C7BB	1909 581065	ELENA SIDOROVA	{"phone": "+70291353887"}
0005435040428	B06515	0806 592063	OLGA AKIMOVA	{"email": "o-akimova101969@postgrespro.ru", "phone": "+70068580055"}
0005435040429	2A7DDA	1496 376876	SERGEY NAUMOV	{"email": "naumov-s-1982@postgrespro.ru", "phone": "+70181685484"}
0005435040430	464F5D	1989 848285	LYUBOV BELOVA	{"email": "belova-l_061985@postgrespro.ru", "phone": "+70635499295"}
0005435040431	94EC29	1385 182315	IRINA ANDREEVA	{"phone": "+70437985453"}
0005435040432	25A2AB	9596 651291	TATYANA ALEKSEEVA	{"email": "alekseevatatyana-101980@postgrespro.ru", "phone": "+70111824363"}
0005435040433	0F1466	2038 092581	ELENA FEDOROVA	{"phone": "+70825203510"}
0005435040434	644A4C	7406 674147	DENIS NIKOLAEV	{"email": "d.nikolaev.1972@postgrespro.ru", "phone": "+70054224452"}
0005435040435	EEE070	6260 649208	ELENA MOROZOVA	{"phone": "+70023137030"}
0005435040436	757D6A	5369 676539	VLADIMIR GORBUNOV	{"phone": "+70924675948"}
0005435040437	446714	0792 977969	EKATERINA FOMINA	{"phone": "+70836838049"}
0005435040438	6C876F	9848 055364	GENNADIY FILIPPOV	{"email": "g_filippov_1964@postgrespro.ru", "phone": "+70918485897"}
0005435040439	447181	5863 013578	NAILYA BELYAEVA	{"phone": "+70672448894"}
0005435040440	5CB22F	7975 707618	TATYANA CHERNOVA	{"email": "chernova_t041972@postgrespro.ru", "phone": "+70375915700"}
0005435040441	FBD0BF	6769 022646	ELENA DENISOVA	{"email": "denisova_elena26041970@postgrespro.ru", "phone": "+70764179894"}
0005435040442	61B09D	2074 174744	SERGEY FEDOROV	{"email": "sergey-fedorov.071974@postgrespro.ru", "phone": "+70372158183"}
0005435040443	61B09D	4409 636420	MARINA KONDRATEVA	{"email": "m-kondrateva-29041969@postgrespro.ru", "phone": "+70951001256"}
0005435040444	147B85	8823 379893	TATYANA BORISOVA	{"email": "borisova.tatyana-1975@postgrespro.ru", "phone": "+70452047009"}
0005435040445	0DCB72	1747 698635	MARINA BELOVA	{"email": "belova.marina_1983@postgrespro.ru", "phone": "+70577761129"}
0005435040446	0DCB72	9192 965899	ELENA KUZMINA	{"email": "elenakuzmina17011975@postgrespro.ru", "phone": "+70083834479"}
0005435040447	D01065	4489 126175	YULIYA STEPANOVA	{"email": "yuliya.stepanova.1974@postgrespro.ru", "phone": "+70959529901"}
0005435040448	9451A6	4146 391611	ANDREY TIMOFEEV	{"phone": "+70476737611"}
0005435040449	9D846A	5911 556235	TATYANA SCHERBAKOVA	{"phone": "+70148385172"}
0005435040450	D3A5AB	3385 989190	SVETLANA FEDOROVA	{"phone": "+70828411217"}
0005435040451	047E8F	4675 808917	KRISTINA KOZLOVA	{"email": "kozlova.k.101970@postgrespro.ru", "phone": "+70396094567"}
0005435040452	01FEB5	9670 891302	GALINA NAUMOVA	{"phone": "+70052569157"}
0005435040453	F8808E	9076 721090	ANTON SIDOROV	{"email": "sidorova101967@postgrespro.ru", "phone": "+70119536470"}
0005435040454	E94825	3681 843954	EKATERINA GUSEVA	{"email": "ekaterinaguseva.121960@postgrespro.ru", "phone": "+70506190666"}
0005435040455	63A8A6	5517 356749	ARTUR MIKHAYLOV	{"email": "a-mikhaylov-21051967@postgrespro.ru", "phone": "+70441807016"}
0005435040456	3ACB27	3588 810852	VLADIMIR SIDOROV	{"phone": "+70561624690"}
0005435040457	3ACB27	4734 195854	IRAIDA TIKHONOVA	{"email": "i_tikhonova25081965@postgrespro.ru", "phone": "+70599741172"}
0005435040458	BE4CE9	7631 617679	GALINA SMIRNOVA	{"phone": "+70660344069"}
0005435040459	21EAC9	3071 828081	DMITRIY IVANOV	{"phone": "+70668898745"}
0005435040460	621D22	3692 105543	ROMAN FEDOROV	{"email": "fedorov_roman-061970@postgrespro.ru", "phone": "+70328391455"}
0005435040461	B7AE7A	7840 443226	STANISLAV MIKHAYLOV	{"phone": "+70453710064"}
0005435040462	F16720	3567 159637	ALEKSANDR IVANOV	{"phone": "+70058241131"}
0005435040463	34DE23	3307 217034	VLADIMIR MOROZOV	{"email": "vladimir_morozov1967@postgrespro.ru", "phone": "+70127384954"}
0005435040464	6B8AFD	6435 048248	TATYANA MEDVEDEVA	{"phone": "+70317898729"}
0005435040465	B5B10C	3804 612354	ALEKSANDR KONOVALOV	{"phone": "+70814343010"}
0005435040466	6487A6	4273 137415	VASILIY GERASIMOV	{"email": "gerasimovvasiliy.1966@postgrespro.ru", "phone": "+70543876350"}
0005435040467	B2F992	3051 363442	SERGEY KULIKOV	{"email": "kulikovs_25111965@postgrespro.ru", "phone": "+70104426538"}
0005435040468	EB7FE9	5187 879049	LYUDMILA KOVALEVA	{"email": "lyudmila_kovaleva12101967@postgrespro.ru", "phone": "+70451045041"}
0005435040469	EB7FE9	4420 996505	OLGA IVANOVA	{"email": "o_ivanova1964@postgrespro.ru", "phone": "+70699244806"}
0005435040470	CBE489	8531 181900	RUSLAN NIKOLAEV	{"email": "nikolaev.r1970@postgrespro.ru", "phone": "+70665655252"}
0005435040471	CBE489	5394 673783	ALENA ALEKSEEVA	{"phone": "+70238412627"}
0005435040472	2F013F	1383 774092	SERGEY KUZNECOV	{"email": "kuznecovs_021963@postgrespro.ru", "phone": "+70247227653"}
0005435040473	2F013F	8616 210243	ALEKSEY MOROZOV	{"email": "a_morozov.28061966@postgrespro.ru", "phone": "+70599178105"}
0005435040474	BAEB2B	1306 995750	ALENA KOROLEVA	{"phone": "+70152909916"}
0005435040475	BD80AA	1801 556445	ROMAN VOROBEV	{"phone": "+70757958722"}
0005435040476	21AE65	1116 372027	VALENTINA KOROLEVA	{"phone": "+70544564433"}
0005435040477	CCB9F7	2800 193614	YURIY GORBUNOV	{"phone": "+70015987509"}
0005435040478	0163AF	4213 630836	ELENA VASILEVA	{"phone": "+70141027348"}
0005435040479	0163AF	9507 201712	ALEKSANDR ROMANOV	{"phone": "+70200465638"}
0005435040480	70CEC5	3801 424896	ARTEM KOZLOV	{"phone": "+70142631011"}
0005435040481	70CEC5	1281 854529	ALEKSANDR FEDOTOV	{"phone": "+70430498281"}
0005435040482	E01BB9	4089 240158	SERGEY MIRONOV	{"email": "sergey.mironov-101968@postgrespro.ru", "phone": "+70280754832"}
0005435040483	3876ED	6774 298537	VALENTINA CHERNOVA	{"email": "chernova_v1965@postgrespro.ru", "phone": "+70732987926"}
0005435040484	375E8D	9001 785203	GALINA EGOROVA	{"email": "gegorova02021969@postgrespro.ru", "phone": "+70379297292"}
0005435040485	FC57A6	1905 336252	ANTONINA MAKAROVA	{"phone": "+70659467643"}
0005435040486	FC57A6	8238 577167	DMITRIY MAKAROV	{"email": "dmitriy-makarov_18011964@postgrespro.ru", "phone": "+70565682925"}
0005435040487	41172E	3475 715759	ALEKSEY OSIPOV	{"phone": "+70523455247"}
0005435040488	E5649A	3123 414916	ANDREY NIKOLAEV	{"phone": "+70591332832"}
0005435040489	0A9668	3381 070579	NIKOLAY FEDOROV	{"email": "fedorov-nikolay091968@postgrespro.ru", "phone": "+70409675645"}
0005435040490	0A9668	8119 108100	KONSTANTIN MOROZOV	{"email": "k.morozov.081959@postgrespro.ru", "phone": "+70387339814"}
0005435040491	DEF271	0162 127793	NATALYA YUDINA	{"email": "n-yudina-12111966@postgrespro.ru", "phone": "+70782139133"}
0005435040492	6A5705	2863 934430	ASIYA SIDOROVA	{"email": "asiya-sidorova-1975@postgrespro.ru", "phone": "+70124101784"}
0005435040493	C927FD	2004 813098	VIKTOR IVANOV	{"phone": "+70792986019"}
0005435040494	50B064	0668 227438	NADEZHDA SERGEEVA	{"phone": "+70817601413"}
0005435040495	258F20	7748 928984	ELENA MEDVEDEVA	{"phone": "+70714957152"}
0005435040496	2628FF	0679 885156	SERGEY SEMENOV	{"phone": "+70686786179"}
0005435040497	CE2231	5728 252072	SERGEY PAVLOV	{"email": "spavlov_1976@postgrespro.ru", "phone": "+70186919941"}
0005435040498	2619BC	4502 493744	MARINA MARTYNOVA	{"phone": "+70794621639"}
0005435040499	078235	4337 043937	TAMARA ARKHIPOVA	{"phone": "+70517820294"}
0005435040500	415D47	3525 543391	OLGA DAVYDOVA	{"phone": "+70271751572"}
0005435040501	415D47	8878 625248	ANATOLIY YAKOVLEV	{"email": "yakovlev.anatoliy11101976@postgrespro.ru", "phone": "+70171972097"}
0005435040502	21C274	0417 931722	VALERIY PAVLOV	{"phone": "+70576131263"}
0005435040503	21C274	8462 317106	SERGEY NIKOLAEV	{"phone": "+70330047376"}
0005435040504	824C77	9622 163962	ANTON BONDARENKO	{"phone": "+70293916091"}
0005435040505	8AD218	0768 268864	NELYA DMITRIEVA	{"email": "nelya_dmitrieva-20011993@postgrespro.ru", "phone": "+70225864496"}
0005435040506	A3A0BF	2578 682122	IGOR SEMENOV	{"email": "igor.semenov1980@postgrespro.ru", "phone": "+70075912751"}
0005435040507	F70CAA	0279 778200	RAISA MAKSIMOVA	{"phone": "+70704303369"}
0005435040508	4994FD	8526 830630	ALEKSANDRA KULIKOVA	{"email": "a_kulikova-101967@postgrespro.ru", "phone": "+70157430749"}
0005435040509	85D749	0209 946211	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov_20021986@postgrespro.ru", "phone": "+70703361146"}
0005435040510	DE89FA	0496 969907	ANTON KRASNOV	{"email": "a.krasnov_081972@postgrespro.ru", "phone": "+70113184471"}
0005435040511	DE89FA	8722 593342	VYACHESLAV KUZNECOV	{"email": "kuznecovv_081981@postgrespro.ru", "phone": "+70053255030"}
0005435040512	DE89FA	5487 798594	SERGEY KOZLOV	{"email": "sergeykozlov_25031975@postgrespro.ru", "phone": "+70339176071"}
0005435040513	E8C2FE	6474 210737	MARIYA FADEEVA	{"phone": "+70931027356"}
0005435040514	E8C2FE	8408 601125	EKATERINA IVANOVA	{"phone": "+70812289210"}
0005435040515	ABC13B	3060 694978	MARINA VASILEVA	{"email": "vasilevam_051975@postgrespro.ru", "phone": "+70871101439"}
0005435040516	ABC13B	6794 655169	EVGENIY OSIPOV	{"email": "e.osipov_04121979@postgrespro.ru", "phone": "+70502618165"}
0005435040517	25DE7D	6958 399323	ELENA ZAYCEVA	{"phone": "+70097745655"}
0005435040518	A9CF67	6069 063292	ELENA EFIMOVA	{"email": "efimova-e_1974@postgrespro.ru", "phone": "+70084267650"}
0005435040519	A9CF67	3973 703153	VLADIMIR SOROKIN	{"email": "sorokinv07011955@postgrespro.ru", "phone": "+70119984296"}
0005435040520	2F7ADC	3877 665881	ALEKSANDRA KISELEVA	{"email": "aleksandra_kiseleva-081971@postgrespro.ru", "phone": "+70092442482"}
0005435040521	C4226A	1159 456641	TATYANA KAZAKOVA	{"email": "tatyana_kazakova.1980@postgrespro.ru", "phone": "+70363338896"}
0005435040522	8AE92E	7734 160774	KLAVDIYA NAZAROVA	{"phone": "+70772232279"}
0005435040523	530149	9765 740464	VLADIMIR SMIRNOV	{"phone": "+70371745997"}
0005435040524	530149	5097 098064	EKATERINA MELNIKOVA	{"phone": "+70950201720"}
0005435040525	BB5B02	5477 019993	EVGENIY ILIN	{"phone": "+70243184509"}
0005435040585	B5A148	8401 412922	GALIYA ABRAMOVA	{"phone": "+70361096362"}
0005435040526	BB5B02	1925 380189	GENNADIY MARTYNOV	{"email": "martynov-g.101964@postgrespro.ru", "phone": "+70405923353"}
0005435040527	D65CBC	9933 462904	ANNA SEMENOVA	{"email": "a_semenova011965@postgrespro.ru", "phone": "+70746548422"}
0005435040528	9A5A1E	1130 220935	SVETLANA YAKOVLEVA	{"email": "yakovleva-s_1973@postgrespro.ru", "phone": "+70021239962"}
0005435040529	30FC81	0492 763890	SERGEY DMITRIEV	{"email": "dmitrievsergey.18061970@postgrespro.ru", "phone": "+70775890266"}
0005435040530	081B55	7505 114662	NATALYA NAZAROVA	{"phone": "+70618832972"}
0005435040531	61900F	7801 492076	LYUDMILA KUZNECOVA	{"phone": "+70095214551"}
0005435040532	C7161F	5590 084799	ANASTASIYA KOZLOVA	{"phone": "+70131824649"}
0005435040533	A309AE	9878 454535	NATALYA ZOTOVA	{"email": "zotova-n23051974@postgrespro.ru", "phone": "+70704221517"}
0005435040534	A309AE	6613 147609	NIKOLAY BONDARENKO	{"phone": "+70090113466"}
0005435040535	7131EA	7043 462530	RUSTEM MIRONOV	{"phone": "+70283364417"}
0005435040536	458EC4	3507 032252	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-1981@postgrespro.ru", "phone": "+70101137213"}
0005435040537	458EC4	9531 595138	TIMUR BORISOV	{"email": "borisov-timur.19011973@postgrespro.ru", "phone": "+70985053764"}
0005435040538	05ABE9	7468 484158	ANDREY FROLOV	{"phone": "+70136785334"}
0005435040539	E1F05E	0621 689098	NIKOLAY ALEKSEEV	{"email": "n-alekseev.031968@postgrespro.ru", "phone": "+70140545568"}
0005435040540	6587DF	8704 005849	TATYANA KALININA	{"phone": "+70499839966"}
0005435040541	5E8D50	7365 549777	DARYA NOVIKOVA	{"email": "darya-novikova-051965@postgrespro.ru", "phone": "+70946411857"}
0005435040542	BA6964	7605 461691	VERONIKA SMIRNOVA	{"email": "vsmirnova_1967@postgrespro.ru", "phone": "+70312090610"}
0005435040543	AE8C12	0601 460256	TATYANA KAZAKOVA	{"email": "t.kazakova_1967@postgrespro.ru", "phone": "+70729100673"}
0005435040544	FBFB5D	4770 664366	MARIYA ZHUKOVA	{"phone": "+70908947933"}
0005435040545	DB68D5	2925 373052	OLGA FILATOVA	{"phone": "+70275760692"}
0005435040546	A7DDC9	2956 062285	NATALYA SIDOROVA	{"email": "n.sidorova-1978@postgrespro.ru", "phone": "+70911356504"}
0005435040547	A7DDC9	5517 737326	NATALYA BELYAEVA	{"phone": "+70424605419"}
0005435040548	0DB103	4798 874167	ALEKSANDR TARASOV	{"email": "tarasovaleksandr-051971@postgrespro.ru", "phone": "+70426797686"}
0005435040549	22D8DE	6603 684785	EKATERINA ZHURAVLEVA	{"phone": "+70618065417"}
0005435040550	7278B2	8578 245400	VERA ZAKHAROVA	{"email": "zakharovavera-081981@postgrespro.ru", "phone": "+70369806029"}
0005435040551	7278B2	6041 029501	ELIZAVETA POTAPOVA	{"email": "elizaveta-potapova.22031962@postgrespro.ru", "phone": "+70796167638"}
0005435040552	BDDACA	6770 677332	SERGEY YAKOVLEV	{"phone": "+70727331724"}
0005435040553	E97F96	0531 542978	SERGEY TARASOV	{"phone": "+70452152491"}
0005435040554	137E34	0599 157081	NATALYA KISELEVA	{"phone": "+70231801831"}
0005435040555	137E34	7932 365434	DARYA MASLOVA	{"email": "maslova_darya-10061976@postgrespro.ru", "phone": "+70689792049"}
0005435040556	137E34	7985 211615	ANATOLIY BELOV	{"phone": "+70205670307"}
0005435040557	5B664D	9821 853318	VITALIY NIKITIN	{"email": "nikitin-v_1972@postgrespro.ru", "phone": "+70799624807"}
0005435040558	2A98C9	3305 249112	IGOR KUZNECOV	{"phone": "+70791384384"}
0005435040559	2A98C9	4447 614277	VITALIY KISELEV	{"phone": "+70007508798"}
0005435040560	B450C2	9074 086270	NATALIYA ALEKSANDROVA	{"email": "aleksandrova.nataliya.1979@postgrespro.ru", "phone": "+70061196780"}
0005435040561	B450C2	2853 173406	MARIYA SOLOVEVA	{"phone": "+70614751050"}
0005435040562	E638D2	2009 335956	TATYANA KOZLOVA	{"phone": "+70911225279"}
0005435040563	E638D2	3054 456069	YULIYA MIRONOVA	{"email": "y-mironova.16041978@postgrespro.ru", "phone": "+70136904704"}
0005435040564	93AEC6	6920 924969	ANATOLIY SIDOROV	{"email": "a.sidorov-22101979@postgrespro.ru", "phone": "+70469010095"}
0005435040565	0BB14B	2078 381307	NIKOLAY SIDOROV	{"email": "n_sidorov.08041970@postgrespro.ru", "phone": "+70077893723"}
0005435040566	0BB14B	3867 089842	ALEKSANDR CHERNOV	{"email": "aleksandr-chernov-1967@postgrespro.ru", "phone": "+70394492688"}
0005435040567	046242	8953 134936	TATYANA ZOTOVA	{"phone": "+70920533344"}
0005435040568	046242	2890 689695	SOFYA BARANOVA	{"phone": "+70803180765"}
0005435040569	FF9A5D	7525 342040	ANTON MATVEEV	{"email": "anton_matveev.1972@postgrespro.ru", "phone": "+70123955509"}
0005435040570	54B3B7	7166 460793	STEPAN CHERNOV	{"phone": "+70201963122"}
0005435040571	54B3B7	0428 657894	NIKITA KUZNECOV	{"email": "kuznecov.n.061968@postgrespro.ru", "phone": "+70909832929"}
0005435040572	919D82	7619 341529	ILYA ANTONOV	{"email": "antonov.i031968@postgrespro.ru", "phone": "+70573542239"}
0005435040573	919D82	0759 267379	EKATERINA BELYAEVA	{"email": "belyaevae-061971@postgrespro.ru", "phone": "+70224012728"}
0005435040574	919D82	7472 858862	OLGA TIKHONOVA	{"email": "tikhonova-olga_27061976@postgrespro.ru", "phone": "+70446201725"}
0005435040575	8D92D6	0546 312105	SERGEY KOZLOV	{"phone": "+70258854475"}
0005435040576	8D92D6	9550 862885	EDGAR ZHURAVLEV	{"phone": "+70764497760"}
0005435040577	5F2721	6357 629110	VALENTIN ISAEV	{"email": "valentin.isaev.1966@postgrespro.ru", "phone": "+70793981249"}
0005435040578	E91D5F	6410 688422	POLINA FEDOROVA	{"email": "polina.fedorova051972@postgrespro.ru", "phone": "+70560142852"}
0005435040579	E91D5F	7523 202152	KLAVDIYA FILATOVA	{"email": "klavdiya-filatova_051973@postgrespro.ru", "phone": "+70517638127"}
0005435040580	C9DAD8	4563 874142	DANIIL DENISOV	{"email": "denisov-d.1967@postgrespro.ru", "phone": "+70236701206"}
0005435040581	411422	7327 566177	EGOR IVANOV	{"email": "ivanovegor1980@postgrespro.ru", "phone": "+70816290841"}
0005435040582	08FDB6	5619 111649	YULIYA MAKAROVA	{"phone": "+70656137116"}
0005435040583	B72434	0749 507192	ELENA ZHURAVLEVA	{"email": "zhuravleva-e_29111963@postgrespro.ru", "phone": "+70819287066"}
0005435040584	B72434	9620 032083	NINA ZAYCEVA	{"email": "zayceva_nina071959@postgrespro.ru", "phone": "+70146834632"}
0005435040586	B5A148	3923 550138	RAMIL MIKHAYLOV	{"email": "mikhaylov_ramil-04031977@postgrespro.ru", "phone": "+70196002171"}
0005435040587	7500CF	3784 424818	SERGEY TIKHONOV	{"phone": "+70092678627"}
0005435040588	DB5797	4747 732668	GALINA GORBUNOVA	{"phone": "+70135718204"}
0005435040589	DB5797	9917 546556	KAPITALINA PETROVA	{"phone": "+70037306068"}
0005435040590	D9B5B4	6385 779411	SERGEY KISELEV	{"email": "kiselevsergey061973@postgrespro.ru", "phone": "+70142571350"}
0005435040591	D9B5B4	0248 918147	ALEKSEY PETROV	{"email": "a-petrov_03071977@postgrespro.ru", "phone": "+70810438926"}
0005435040592	60108C	6772 511692	NINA KUZMINA	{"phone": "+70704204638"}
0005435040593	ABC753	3399 805027	MIKHAIL ANTONOV	{"phone": "+70854993983"}
0005435040594	DD3039	7612 673206	SVETLANA POPOVA	{"phone": "+70810356982"}
0005435040595	DD3039	1857 349693	DMITRIY SEMENOV	{"email": "dmitriy.semenov_1977@postgrespro.ru", "phone": "+70673194336"}
0005435040596	4AFA76	1959 093714	ALEKSANDR PETROV	{"email": "petrov_a_1978@postgrespro.ru", "phone": "+70982340455"}
0005435040597	23430F	1441 327414	ALISA ZAKHAROVA	{"email": "alisa.zakharova_12041966@postgrespro.ru", "phone": "+70578810127"}
0005435040598	23430F	6740 217000	TATYANA SIDOROVA	{"email": "t_sidorova.111978@postgrespro.ru", "phone": "+70308944322"}
0005435040599	A61012	3367 342154	OKSANA FILIPPOVA	{"email": "filippova.oksana10031964@postgrespro.ru", "phone": "+70198196521"}
0005435040600	429F8C	7501 767875	RUSLAN VASILEV	{"phone": "+70094170727"}
0005435040601	429F8C	4064 487813	SOFYA TROFIMOVA	{"email": "trofimova.sofya-1969@postgrespro.ru", "phone": "+70131105006"}
0005435040602	083014	7226 475695	ALEKSANDR ZAKHAROV	{"email": "zakharov-aleksandr.021970@postgrespro.ru", "phone": "+70939009641"}
0005435040603	083014	1492 069581	VIKTOR SOLOVEV	{"email": "v.solovev29081964@postgrespro.ru", "phone": "+70666364852"}
0005435040604	F88BA4	9022 313633	ANDREY KUDRYASHOV	{"phone": "+70595206329"}
0005435040605	F88BA4	9160 208415	ELENA KAZAKOVA	{"phone": "+70165656714"}
0005435040606	5F9F06	5436 361082	IRINA PAVLOVA	{"phone": "+70234868696"}
0005435040607	5F9F06	0357 428442	EVGENIY VOLKOV	{"email": "evgeniyvolkov.21061970@postgrespro.ru", "phone": "+70434506482"}
0005435040608	36242F	8839 990208	NAILYA NAZAROVA	{"phone": "+70695965213"}
0005435040609	B98B94	7126 996547	PAVEL ROMANOV	{"phone": "+70088376620"}
0005435040610	02FB03	8513 918719	YURIY MAKAROV	{"phone": "+70203982468"}
0005435040611	ED89C9	6872 274594	GENNADIY ORLOV	{"email": "orlov-gennadiy08041979@postgrespro.ru", "phone": "+70399037090"}
0005435040612	D1DD39	5762 711922	VITALIY DAVYDOV	{"phone": "+70310881680"}
0005435040613	D1DD39	5133 803851	EVGENIY ZHURAVLEV	{"email": "ezhuravlev.1967@postgrespro.ru", "phone": "+70906324855"}
0005435040614	6A5355	8065 759488	SERGEY ABRAMOV	{"phone": "+70916094384"}
0005435040615	EB4768	0434 556482	VLADIMIR KOZLOV	{"email": "v-kozlov_101974@postgrespro.ru", "phone": "+70862501757"}
0005435040616	9B43E9	3981 278227	ARTEMIY GUSEV	{"phone": "+70770257260"}
0005435040617	27798B	0271 211373	NINA KUZNECOVA	{"phone": "+70286546051"}
0005435040618	34CD82	0926 876248	SERGEY FROLOV	{"email": "sergey_frolov-1980@postgrespro.ru", "phone": "+70450219486"}
0005435040619	34CD82	5545 945635	SERGEY KAZAKOV	{"phone": "+70505131285"}
0005435040620	54D5AA	5192 713181	EVGENIY DENISOV	{"phone": "+70053480170"}
0005435040621	80AA12	6617 096220	DARYA LOGINOVA	{"email": "d-loginova-18061975@postgrespro.ru", "phone": "+70926011518"}
0005435040622	BC47D8	6547 531419	ALEKSANDR YAKOVLEV	{"email": "yakovlev-a-22071976@postgrespro.ru", "phone": "+70884172718"}
0005435040623	BC47D8	7880 357028	IRINA VASILEVA	{"phone": "+70935814909"}
0005435040624	C65A91	7199 883355	NATALIYA ZOTOVA	{"phone": "+70584593082"}
0005435040625	C65A91	0162 106307	VIKTOR VASILEV	{"email": "vasilev.v.1986@postgrespro.ru", "phone": "+70351242882"}
0005435040626	E83545	2380 136557	SERGEY AFANASEV	{"email": "afanasev_sergey_05031964@postgrespro.ru", "phone": "+70130526578"}
0005435040627	925764	1835 818274	OLEG SCHERBAKOV	{"phone": "+70806813235"}
0005435040628	27AD03	1148 940618	SABINA RODIONOVA	{"phone": "+70270780889"}
0005435040629	27AD03	9348 859319	ANDREY KISELEV	{"email": "andreykiselev_091973@postgrespro.ru", "phone": "+70189234370"}
0005435040630	9A989D	4194 481591	VLADIMIR ZHUKOV	{"email": "v_zhukov_10091979@postgrespro.ru", "phone": "+70296224057"}
0005435040631	DC701F	6236 920657	DMITRIY MOROZOV	{"email": "morozovdmitriy1982@postgrespro.ru", "phone": "+70988118713"}
0005435040632	8A5FC4	1585 778981	EKATERINA BELOVA	{"phone": "+70357830824"}
0005435040633	6B59F4	3450 490580	ANNA KARPOVA	{"email": "anna-karpova111967@postgrespro.ru", "phone": "+70711635997"}
0005435040634	FCF32C	9133 721056	NATALYA GORBUNOVA	{"email": "gorbunova_n_1967@postgrespro.ru", "phone": "+70180583223"}
0005435040635	FCF32C	1900 148233	OLGA BORISOVA	{"email": "borisova.olga.21101963@postgrespro.ru", "phone": "+70362098898"}
0005435040636	871A33	7909 785479	GALINA FROLOVA	{"email": "galina-frolova.031973@postgrespro.ru", "phone": "+70878218416"}
0005435040637	871A33	1213 314464	VERA PETROVA	{"email": "petrova.vera_081979@postgrespro.ru", "phone": "+70126618864"}
0005435040638	0CDC7F	9638 489248	RAIL SHEVCHENKO	{"email": "r.shevchenko_1985@postgrespro.ru", "phone": "+70698950681"}
0005435040639	0CDC7F	9930 183101	MAYYA ABRAMOVA	{"email": "abramovamayya-101970@postgrespro.ru", "phone": "+70061546682"}
0005435040640	C1BFBA	8503 471160	NINA KUZNECOVA	{"email": "nkuznecova-011986@postgrespro.ru", "phone": "+70501584400"}
0005435040641	C00ECA	4837 262449	DMITRIY ILIN	{"phone": "+70266615378"}
0005435040642	A63CE6	3572 313091	ALEKSANDRA PETROVA	{"phone": "+70356297977"}
0005435040643	A63CE6	3877 493345	ANTON KUZMIN	{"phone": "+70585091625"}
0005435040644	4C6BC6	9634 064578	RAMIS MOROZOV	{"email": "morozov_ramis20061971@postgrespro.ru", "phone": "+70214992867"}
0005435040645	05C3B4	2888 108495	MARGARITA FILATOVA	{"phone": "+70506252546"}
0005435040646	6529DC	0730 320645	DARYA MASLOVA	{"phone": "+70618148694"}
0005435040647	6529DC	7676 301527	NURIYA MATVEEVA	{"email": "matveeva.n-22021984@postgrespro.ru", "phone": "+70568794643"}
0005435040648	6529DC	3482 156051	NATALIYA IVANOVA	{"email": "nataliya.ivanova_071982@postgrespro.ru", "phone": "+70964529778"}
0005435040649	C8C0C5	9549 461292	IRINA OVCHINNIKOVA	{"phone": "+70692267211"}
0005435040650	FF941D	7405 631114	MARINA SMIRNOVA	{"email": "msmirnova_101976@postgrespro.ru", "phone": "+70356942558"}
0005435040651	DF4D4F	9804 031792	DILYARA SMIRNOVA	{"email": "dsmirnova1963@postgrespro.ru", "phone": "+70077012684"}
0005435040652	DF4D4F	2896 792213	ALEKSEY KUZMIN	{"email": "a-kuzmin23071971@postgrespro.ru", "phone": "+70484085981"}
0005435040653	8BC30A	9118 169663	ELENA MOISEEVA	{"phone": "+70189750247"}
0005435040654	4C40E7	9191 129887	LYUDMILA KARPOVA	{"email": "karpova-l-111979@postgrespro.ru", "phone": "+70432118697"}
0005435040655	E02956	5436 453547	GALINA MIKHAYLOVA	{"phone": "+70240735285"}
0005435040656	6D1C55	7179 490785	ANNA MAKSIMOVA	{"email": "a.maksimova_09021972@postgrespro.ru", "phone": "+70111506924"}
0005435040657	6D1C55	7443 984039	KLAVDIYA IVANOVA	{"phone": "+70944275771"}
0005435040658	3DF720	0459 834296	ELENA NIKITINA	{"email": "elena-nikitina1974@postgrespro.ru", "phone": "+70404521589"}
0005435040659	516D8E	2086 905696	NATALYA TITOVA	{"email": "ntitova.12051973@postgrespro.ru", "phone": "+70424201036"}
0005435040660	0E62CF	7241 787261	KSENIYA ISAEVA	{"phone": "+70745841423"}
0005435040661	0E62CF	6264 165382	OLGA OSIPOVA	{"email": "o-osipova-27031968@postgrespro.ru", "phone": "+70796805435"}
0005435040662	DEB8FB	3417 241262	ANASTASIYA TROFIMOVA	{"email": "anastasiyatrofimova_1982@postgrespro.ru", "phone": "+70184550785"}
0005435040663	DEB8FB	5503 145830	MAYA VASILEVA	{"email": "maya-vasileva_041981@postgrespro.ru", "phone": "+70518027277"}
0005435040664	BB56A1	8254 839583	ALEKSEY ROMANOV	{"phone": "+70200378255"}
0005435040665	882999	7042 898944	ANDREY MOROZOV	{"phone": "+70026206149"}
0005435040666	882999	3649 711554	NINA DMITRIEVA	{"phone": "+70070347017"}
0005435040667	8CEBCA	1381 904629	NADEZHDA ANISIMOVA	{"email": "anisimova-n-051971@postgrespro.ru", "phone": "+70076495278"}
0005435040668	EBE8F2	1566 336832	ALEKSANDR MOROZOV	{"phone": "+70054622948"}
0005435040669	52F7A2	5261 558663	ALEKSANDR BONDARENKO	{"email": "bondarenko_a-08061965@postgrespro.ru", "phone": "+70066861133"}
0005435040670	52F7A2	1421 456590	OLGA ABRAMOVA	{"phone": "+70540731456"}
0005435040671	6A6EBF	6134 376600	IVAN FROLOV	{"email": "ivan_frolov_1969@postgrespro.ru", "phone": "+70254002456"}
0005435040672	6A6EBF	3098 182220	RAISA MIRONOVA	{"phone": "+70844580224"}
0005435040673	C849D6	3303 807323	TATYANA PETROVA	{"phone": "+70188122202"}
0005435040674	C849D6	1531 875627	RAISA KUZMINA	{"phone": "+70342168853"}
0005435040675	E8E74F	2003 541754	OLGA TITOVA	{"phone": "+70531664736"}
0005435040676	E8E74F	7819 193440	ALEKSEY IVANOV	{"email": "ivanov.aleksey1974@postgrespro.ru", "phone": "+70868785817"}
0005435040677	E8E74F	6840 292714	TATYANA YAKOVLEVA	{"email": "t-yakovleva051965@postgrespro.ru", "phone": "+70213488761"}
0005435040678	ABA405	0043 126177	ELENA FILATOVA	{"email": "filatova-e09051974@postgrespro.ru", "phone": "+70347454880"}
0005435040679	87C0B7	9526 104732	IGOR NIKITIN	{"email": "i_nikitin.011974@postgrespro.ru", "phone": "+70425292003"}
0005435040680	E04508	0794 266763	ANASTASIYA ABRAMOVA	{"phone": "+70267442865"}
0005435040681	14D60F	4400 708492	VALERIY MARTYNOV	{"email": "valeriy.martynov_1976@postgrespro.ru", "phone": "+70179815398"}
0005435040682	9E464D	4600 352983	ARINA LAZAREVA	{"phone": "+70604080108"}
0005435040683	E77309	1819 249743	NIKOLAY KARPOV	{"email": "n.karpov_30051975@postgrespro.ru", "phone": "+70384377746"}
0005435040684	600C29	5987 059823	SERGEY ALEKSEEV	{"email": "alekseev.sergey-08061972@postgrespro.ru", "phone": "+70854461504"}
0005435040685	600C29	1047 495921	ELENA STEPANOVA	{"email": "e-stepanova.10071972@postgrespro.ru", "phone": "+70313085640"}
0005435040686	8E0F52	7184 661031	VLADIMIR ABRAMOV	{"email": "abramov_vladimir-011977@postgrespro.ru", "phone": "+70066439579"}
0005435040687	8E0F52	8125 468697	DMITRIY SOROKIN	{"phone": "+70369526781"}
0005435040688	8E0F52	5549 009008	LYUBOV ZOTOVA	{"phone": "+70484830905"}
0005435040689	22058B	1897 995938	EVGENIY ANDREEV	{"phone": "+70627842388"}
0005435040690	728581	4330 429777	ANZHELA KUZNECOVA	{"email": "a.kuznecova.041968@postgrespro.ru", "phone": "+70988502040"}
0005435040691	BC56CD	8561 872683	MARINA MATVEEVA	{"phone": "+70142581408"}
0005435040692	BC56CD	5663 295958	ANDREY IVANOV	{"phone": "+70261250854"}
0005435040693	BC56CD	2825 813302	TATYANA BORISOVA	{"email": "borisova.tatyana_1980@postgrespro.ru", "phone": "+70237858180"}
0005435040694	D374A4	4869 231609	LYUBOV GORBUNOVA	{"email": "gorbunovalyubov22081986@postgrespro.ru", "phone": "+70350044504"}
0005435040695	19794D	2995 061601	ELENA YAKOVLEVA	{"phone": "+70771306417"}
0005435040696	19794D	0833 792109	ARKADIY VOLKOV	{"email": "a-volkov25011970@postgrespro.ru", "phone": "+70365057240"}
0005435040697	B850A6	2365 315657	VERA FILIPPOVA	{"phone": "+70188149548"}
0005435040698	B850A6	1128 058736	SVETLANA EFIMOVA	{"phone": "+70335179687"}
0005435040699	B850A6	9135 688705	YURIY GRIGOREV	{"phone": "+70955694123"}
0005435040700	1EC2D3	5561 239078	DMITRIY ANDREEV	{"email": "d.andreev-121966@postgrespro.ru", "phone": "+70007916043"}
0005435040701	69B454	3392 320652	ANDREY SAVELEV	{"phone": "+70641775103"}
0005435040702	5913A8	4060 929847	EKATERINA IVANOVA	{"email": "e.ivanova18111969@postgrespro.ru", "phone": "+70388008083"}
0005435040703	A2F3DB	8556 847556	SVETLANA NIKITINA	{"email": "snikitina07081985@postgrespro.ru", "phone": "+70503487434"}
0005435040704	A2F3DB	9835 306422	IGOR MOISEEV	{"email": "moiseev-i_101969@postgrespro.ru", "phone": "+70104660408"}
0005435040705	444C49	8663 938882	SANIYA YAKOVLEVA	{"phone": "+70085356279"}
0005435040706	F3084C	3080 399040	YURIY FOMIN	{"email": "yuriyfomin-1980@postgrespro.ru", "phone": "+70693953159"}
0005435040707	F3084C	1731 116420	ELENA KOROLEVA	{"phone": "+70716088641"}
0005435040708	3DBBE0	5887 354755	LYUDMILA KUDRYASHOVA	{"phone": "+70550927209"}
0005435040709	3DBBE0	9592 864909	DANILA NAZAROV	{"phone": "+70684427200"}
0005435040710	5F0FEB	7161 817449	RAISA ZOTOVA	{"email": "r.zotova-1970@postgrespro.ru", "phone": "+70649091132"}
0005435040711	2BC2D3	4875 703586	TATYANA KRASNOVA	{"email": "tatyana_krasnova-1967@postgrespro.ru", "phone": "+70737279328"}
0005435040712	048E4B	7844 804142	ANDREY IVANOV	{"phone": "+70772910299"}
0005435040713	4D0D1D	3453 680068	LYUBOV GUSEVA	{"phone": "+70245156077"}
0005435040714	4D0D1D	0075 593730	SERGEY ZHUKOV	{"phone": "+70341389937"}
0005435040715	2214AE	9273 252654	EVGENIY FROLOV	{"email": "frolove_1964@postgrespro.ru", "phone": "+70463273931"}
0005435040716	8EC834	8319 619515	ELENA STEPANOVA	{"phone": "+70669725314"}
0005435040717	CFF475	1443 502821	DMITRIY SMIRNOV	{"email": "smirnovd-28101963@postgrespro.ru", "phone": "+70172514511"}
0005435040718	CFF475	9310 220731	NINA ALEKSANDROVA	{"phone": "+70241359122"}
0005435040719	C452ED	2493 481668	VIKTOR KARPOV	{"email": "viktor.karpov.29031973@postgrespro.ru", "phone": "+70850644174"}
0005435040720	C452ED	2544 938468	SERGEY OSIPOV	{"phone": "+70583464896"}
0005435040721	C452ED	4854 829478	MIKHAIL OSIPOV	{"email": "osipov.m-021975@postgrespro.ru", "phone": "+70929998777"}
0005435040722	F718E9	2714 777461	ROMAN PAVLOV	{"phone": "+70982953445"}
0005435040723	D45374	4920 273059	ALEKSANDR KRASNOV	{"phone": "+70314534059"}
0005435040724	C9BB46	2425 488613	ALEKSEY IVANOV	{"phone": "+70758750225"}
0005435040725	C9BB46	2453 825867	ALEKSEY SERGEEV	{"phone": "+70458779354"}
0005435040726	820F4D	5228 165953	DMITRIY FEDOROV	{"phone": "+70975365914"}
0005435040727	070507	7741 082833	SERGEY POPOV	{"phone": "+70846064835"}
0005435040728	9C39A4	1122 198202	ALENA ZHURAVLEVA	{"phone": "+70956128794"}
0005435040729	9C39A4	5491 716158	ILYA NAUMOV	{"email": "ilya_naumov.051987@postgrespro.ru", "phone": "+70191603056"}
0005435040730	8A316E	8163 508975	VLADISLAV BORISOV	{"email": "v.borisov.06081976@postgrespro.ru", "phone": "+70275662536"}
0005435040731	5C6F7C	3474 788224	MARGARITA FEDOROVA	{"phone": "+70466576892"}
0005435040732	5C6F7C	9104 931280	NADEZHDA KUZMINA	{"phone": "+70165306889"}
0005435040733	D168F5	3361 511415	YULIYA KUZMINA	{"email": "y_kuzmina1984@postgrespro.ru", "phone": "+70798182797"}
0005435040734	DF69B5	3052 506295	ZOYA TROFIMOVA	{"email": "trofimova_z1971@postgrespro.ru", "phone": "+70010743064"}
0005435040735	ACD3C4	7162 862096	LEV POPOV	{"phone": "+70528304951"}
0005435040736	2574E1	2731 038972	EVGENIY SCHERBAKOV	{"phone": "+70662821446"}
0005435040737	66E922	2387 034264	MARIYA MELNIKOVA	{"email": "mmelnikova1972@postgrespro.ru", "phone": "+70986044766"}
0005435040738	66E922	3536 953890	NIKOLAY SOLOVEV	{"email": "solovev_n-17041983@postgrespro.ru", "phone": "+70000662744"}
0005435040739	D3BCBC	1444 520538	ALEKSEY ALEKSEEV	{"phone": "+70287010556"}
0005435040740	D3BCBC	2002 025852	ALEKSEY MARTYNOV	{"phone": "+70366820770"}
0005435040741	BD817D	6034 880157	MARIYA IVANOVA	{"phone": "+70000114261"}
0005435040742	0BE822	5609 344746	ALEKSANDR MAKAROV	{"phone": "+70202602524"}
0005435040743	0BE822	4464 364794	OLGA ANDREEVA	{"email": "olga.andreeva.1967@postgrespro.ru", "phone": "+70161905383"}
0005435040744	70A8F1	2300 575719	OLGA BELYAEVA	{"email": "olgabelyaeva.1979@postgrespro.ru", "phone": "+70910962658"}
0005435040745	32F2A9	7903 181397	ALEKSANDR YAKOVLEV	{"phone": "+70963613884"}
0005435040746	32F2A9	4938 657326	MARIYA SERGEEVA	{"email": "sergeevam.1982@postgrespro.ru", "phone": "+70568195273"}
0005435040747	32F2A9	3767 349697	NIKITA BONDARENKO	{"phone": "+70573579869"}
0005435040748	BF33E8	9242 146150	ANDREY SOKOLOV	{"email": "sokolov-andrey.061983@postgrespro.ru", "phone": "+70789910385"}
0005435040749	99814A	3324 863784	NINA ABRAMOVA	{"email": "abramovan-1982@postgrespro.ru", "phone": "+70235460261"}
0005435040750	1BD7AB	2109 523817	SABINA DANILOVA	{"phone": "+70598066848"}
0005435040751	3A9D82	8271 185123	ANZHELA KISELEVA	{"email": "anzhelakiseleva071975@postgrespro.ru", "phone": "+70852962295"}
0005435040752	3A9D82	6410 637885	DMITRIY FEDOROV	{"email": "dmitriy_fedorov07121958@postgrespro.ru", "phone": "+70417268449"}
0005435040753	2D44B7	4012 067908	KONSTANTIN RODIONOV	{"phone": "+70249950577"}
0005435040754	53AF50	7869 428020	NIKOLAY KOROLEV	{"phone": "+70804543578"}
0005435040755	53AF50	9173 013092	SERGEY SIDOROV	{"phone": "+70356903725"}
0005435040756	53AF50	4239 635901	NATALYA MIRONOVA	{"phone": "+70199657057"}
0005435040757	C5276C	4371 653806	ELENA EFREMOVA	{"phone": "+70787032850"}
0005435040758	C69DB0	5361 395647	ASIYA NAZAROVA	{"phone": "+70749404442"}
0005435040759	C69DB0	9373 929278	LYUDMILA IVANOVA	{"email": "ivanova_l_101960@postgrespro.ru", "phone": "+70507441308"}
0005435040760	CC1107	5272 576030	SERAFIMA KOROLEVA	{"phone": "+70515361862"}
0005435040761	CC1107	9054 439324	MARIYA KUZMINA	{"email": "mkuzmina_1972@postgrespro.ru", "phone": "+70420088375"}
0005435040762	328EC4	0526 455922	VASILIY TIKHONOV	{"email": "tikhonov_v011978@postgrespro.ru", "phone": "+70158585655"}
0005435040763	1817BE	5888 499217	YURIY ROMANOV	{"phone": "+70599083577"}
0005435040764	1817BE	6060 722348	NINA MARTYNOVA	{"email": "nina-martynova.1970@postgrespro.ru", "phone": "+70161314488"}
0005435040765	1817BE	3544 732290	LYUDMILA KOROLEVA	{"email": "koroleva_lyudmila.30091970@postgrespro.ru", "phone": "+70855529432"}
0005435040766	31573B	4736 648119	YULIYA SMIRNOVA	{"email": "smirnova.y-23101974@postgrespro.ru", "phone": "+70259984448"}
0005435040767	31573B	5803 206834	ALEKSEY VASILEV	{"email": "alekseyvasilev.111963@postgrespro.ru", "phone": "+70170831122"}
0005435040768	3278E7	2294 271821	NATALYA ZAYCEVA	{"phone": "+70322544036"}
0005435040769	3278E7	3178 125962	KSENIYA SOROKINA	{"email": "sorokina_kseniya-1974@postgrespro.ru", "phone": "+70277990017"}
0005435040770	08F20B	5009 603245	NATALYA BOGDANOVA	{"email": "natalya.bogdanova-24101972@postgrespro.ru", "phone": "+70278016058"}
0005435040771	9A9035	4256 327762	VALENTINA NOVIKOVA	{"email": "novikova.v-15021965@postgrespro.ru", "phone": "+70000070686"}
0005435040772	9A9035	4727 778001	NATALYA STEPANOVA	{"email": "n.stepanova101972@postgrespro.ru", "phone": "+70270741458"}
0005435040773	6042D6	0695 669119	VITALIY SCHERBAKOV	{"phone": "+70242344156"}
0005435040774	B48B39	5339 544802	VENERA FEDOROVA	{"email": "fedorova_v.051967@postgrespro.ru", "phone": "+70434940126"}
0005435040775	5DBB6D	9579 248685	IRINA NOVIKOVA	{"phone": "+70634505449"}
0005435040776	5DBB6D	3343 860388	NINA ORLOVA	{"phone": "+70227625430"}
0005435040777	CE8CEE	2773 167304	EGOR NIKITIN	{"email": "nikitin-e_1971@postgrespro.ru", "phone": "+70564835212"}
0005435040778	2F6848	7030 161381	VYACHESLAV FEDOROV	{"phone": "+70002073740"}
0005435040779	AC38AB	2769 240903	GALINA GRISHINA	{"phone": "+70643877658"}
0005435040780	11FEBF	0812 756034	VLADIMIR BELOV	{"phone": "+70160091766"}
0005435040781	007649	0676 065359	ANDREY KARPOV	{"phone": "+70672655410"}
0005435040782	63C4F6	1947 692295	LYUDMILA KUZNECOVA	{"email": "lyudmila_kuznecova-12061976@postgrespro.ru", "phone": "+70738324724"}
0005435040783	63C4F6	5298 608273	IVAN KOROLEV	{"phone": "+70097977884"}
0005435040784	AF561B	6647 706314	NIKOLAY KAZAKOV	{"email": "kazakov.n.091981@postgrespro.ru", "phone": "+70350670920"}
0005435040785	EF77B1	1724 088973	ALEKSANDR SEMENOV	{"phone": "+70512644437"}
0005435040786	EF77B1	0751 515038	OLGA KOZLOVA	{"email": "kozlova_olga1964@postgrespro.ru", "phone": "+70864649954"}
0005435040787	EF77B1	0506 107992	TAMARA NAZAROVA	{"email": "t_nazarova.121967@postgrespro.ru", "phone": "+70153274817"}
0005435040788	4EEB78	6518 755485	NIKOLAY FOMIN	{"email": "nikolay_fomin_031972@postgrespro.ru", "phone": "+70685481063"}
0005435040789	085749	1931 370170	VLADIMIR SMIRNOV	{"email": "smirnovvladimir_1965@postgrespro.ru", "phone": "+70374238189"}
0005435040790	E97F1F	6245 307699	YURIY KUZMIN	{"email": "ykuzmin.021976@postgrespro.ru", "phone": "+70316467728"}
0005435040791	E97F1F	8946 422804	MARIYA ANTONOVA	{"email": "antonova-m.31031959@postgrespro.ru", "phone": "+70727262565"}
0005435040792	43FAB0	4031 723975	YURIY SOKOLOV	{"phone": "+70055840705"}
0005435040793	43FAB0	8466 234644	NATALYA SCHERBAKOVA	{"phone": "+70731591470"}
0005435040794	DFEA62	7011 451026	MARINA ANISIMOVA	{"email": "manisimova_1977@postgrespro.ru", "phone": "+70617897395"}
0005435040795	141763	8095 023295	MIKHAIL NAUMOV	{"email": "m-naumov18051972@postgrespro.ru", "phone": "+70768801701"}
0005435040796	9BF864	2327 275823	GRIGORIY KOZLOV	{"email": "kozlov-g_20111974@postgrespro.ru", "phone": "+70557825364"}
0005435040797	9BF864	8966 355700	VYACHESLAV MARTYNOV	{"phone": "+70540718220"}
0005435040798	5B7019	3482 177779	MAKSIM MATVEEV	{"email": "maksim.matveev1970@postgrespro.ru", "phone": "+70403412398"}
0005435040799	5B7019	6778 465131	NIKOLAY ZHUKOV	{"phone": "+70922792914"}
0005435040800	F65BCE	6913 716095	ANDREY MIRONOV	{"phone": "+70751029254"}
0005435040801	4C0373	0391 433945	GENNADIY KRASNOV	{"phone": "+70223506152"}
0005435040802	217E98	3421 706202	DMITRIY SCHERBAKOV	{"email": "dmitriy-scherbakov.26021971@postgrespro.ru", "phone": "+70025588719"}
0005435040803	7B7119	1866 474973	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova-1987@postgrespro.ru", "phone": "+70173653751"}
0005435040804	0F6F3B	9007 780364	EKATERINA LAZAREVA	{"email": "ekaterina.lazareva_071978@postgrespro.ru", "phone": "+70758441920"}
0005435040805	0F6F3B	3117 464006	VALENTINA KUZNECOVA	{"phone": "+70279084530"}
0005435040806	0F6F3B	4179 661671	ALEKSANDR GAVRILOV	{"email": "gavrilov.a-01021978@postgrespro.ru", "phone": "+70463732127"}
0005435040807	540D73	4942 543218	OLGA ZOTOVA	{"email": "zotova-o_1960@postgrespro.ru", "phone": "+70235283699"}
0005435040808	5FAAB7	9654 955587	NINA SOROKINA	{"email": "n.sorokina.30071973@postgrespro.ru", "phone": "+70539171929"}
0005435040809	5FAAB7	4209 497016	NIKITA PETROV	{"phone": "+70004411366"}
0005435040810	6D176A	9130 782181	LYUBOV KONOVALOVA	{"phone": "+70869403905"}
0005435040811	567416	4135 762548	LIDIYA YAKOVLEVA	{"phone": "+70553567438"}
0005435040812	3CFF50	9929 211392	ALEKSANDR FOMIN	{"email": "aleksandr-fomin29041972@postgrespro.ru", "phone": "+70358509739"}
0005435040813	4085D1	6761 989531	VALENTINA SOLOVEVA	{"email": "valentinasoloveva_081975@postgrespro.ru", "phone": "+70634818145"}
0005435040814	4085D1	2545 218399	ALEKSEY FROLOV	{"phone": "+70327725369"}
0005435040815	48B289	2650 517075	FARID KOZLOV	{"email": "kozlov-farid-1972@postgrespro.ru", "phone": "+70846449906"}
0005435040816	EC1FAC	0779 068446	TATYANA SERGEEVA	{"phone": "+70286886650"}
0005435040817	2FE90B	6640 983008	TATYANA ALEKSEEVA	{"email": "alekseeva-t041983@postgrespro.ru", "phone": "+70387064584"}
0005435040818	2FE90B	5580 713748	KSENIYA KUZNECOVA	{"email": "kseniya.kuznecova_121975@postgrespro.ru", "phone": "+70376592809"}
0005435040819	A2378A	6733 740167	OLGA IVANOVA	{"phone": "+70072511438"}
0005435040820	893F81	6657 451140	VALENTINA PETROVA	{"email": "valentina_petrova.101975@postgrespro.ru", "phone": "+70397574554"}
0005435040821	893F81	7022 052084	ANDREY MOROZOV	{"phone": "+70593021248"}
0005435040822	674958	0558 714946	MARINA VASILEVA	{"phone": "+70657357876"}
0005435040823	B5D224	3871 778851	GALINA MELNIKOVA	{"phone": "+70182519214"}
0005435040824	B5D224	9091 246431	MIKHAIL NIKITIN	{"email": "mikhail.nikitin1972@postgrespro.ru", "phone": "+70540447956"}
0005435040825	44CDE5	7264 554411	YURIY RODIONOV	{"phone": "+70987391639"}
0005435040826	CCE7A7	8081 362153	ALEKSEY ABRAMOV	{"email": "abramov.a29091968@postgrespro.ru", "phone": "+70313336422"}
0005435040827	99DCE0	8521 449351	ELENA PAVLOVA	{"email": "elena.pavlova.23061981@postgrespro.ru", "phone": "+70710319552"}
0005435040828	80950A	8922 380476	IVAN ZAYCEV	{"email": "zaycev_ivan-1962@postgrespro.ru", "phone": "+70132277648"}
0005435040829	80950A	7719 233577	ALEKSEY ANDREEV	{"email": "alekseyandreev-1979@postgrespro.ru", "phone": "+70384134363"}
0005435040830	25F946	0702 623538	VALERIYA ZAKHAROVA	{"email": "v.zakharova061980@postgrespro.ru", "phone": "+70732559045"}
0005435040831	20EE69	2026 335353	ANATOLIY EGOROV	{"phone": "+70567714796"}
0005435040832	20EE69	7346 398288	GALINA ALEKSEEVA	{"email": "alekseevag.1971@postgrespro.ru", "phone": "+70558346335"}
0005435040833	756AC7	2288 301477	ELIZAVETA ZAKHAROVA	{"phone": "+70519979938"}
0005435040834	A79914	2841 488279	VLADIMIR STEPANOV	{"phone": "+70878954394"}
0005435040835	A0A369	8403 139182	ALEKSEY KISELEV	{"email": "kiselevaleksey-1973@postgrespro.ru", "phone": "+70318740827"}
0005435040836	DCEFC1	4315 531746	SERGEY SMIRNOV	{"email": "smirnovs.20101963@postgrespro.ru", "phone": "+70884529131"}
0005435040837	DCEFC1	0850 531804	DENIS KUZNECOV	{"email": "dkuznecov-101976@postgrespro.ru", "phone": "+70490897377"}
0005435040838	3945AA	4433 828756	VYACHESLAV IVANOV	{"phone": "+70391760358"}
0005435040839	3945AA	5618 077732	ANDREY KUZNECOV	{"email": "a.kuznecov15031979@postgrespro.ru", "phone": "+70456171750"}
0005435040840	3945AA	0784 531576	ANATOLIY IVANOV	{"email": "ivanov-a16041974@postgrespro.ru", "phone": "+70808167750"}
0005435040841	5F2BBB	0553 345317	SERGEY IVANOV	{"phone": "+70474091513"}
0005435040842	5F2BBB	5529 724077	ALEKSEY MEDVEDEV	{"email": "medvedevaleksey10081962@postgrespro.ru", "phone": "+70755772030"}
0005435040843	911393	2837 525551	MARIYA ANDREEVA	{"phone": "+70665118224"}
0005435040844	911393	6512 194749	IGOR TIKHONOV	{"email": "tikhonov_igor_1975@postgrespro.ru", "phone": "+70689431341"}
0005435040845	911393	9796 729165	LYUDMILA MOISEEVA	{"phone": "+70343837745"}
0005435040846	85AB6E	6060 272606	SERGEY GORBUNOV	{"email": "sergey_gorbunov-051959@postgrespro.ru", "phone": "+70926215687"}
0005435040847	0D7387	6447 029581	LILIYA ANISIMOVA	{"email": "anisimova.liliya28111966@postgrespro.ru", "phone": "+70815947991"}
0005435040848	D84DF4	7880 447703	VLADISLAV GORBUNOV	{"email": "gorbunov.vladislav_20011976@postgrespro.ru", "phone": "+70221008113"}
0005435040849	FB0FAF	5623 705399	VLADIMIR PETROV	{"phone": "+70697789779"}
0005435040850	4E4761	5484 061371	MARIYA CHERNOVA	{"phone": "+70385107028"}
0005435040851	CCF795	6542 540855	DMITRIY ANDREEV	{"phone": "+70618600499"}
0005435040852	1D2C21	8298 625337	MARINA RYABOVA	{"phone": "+70060360839"}
0005435040853	26991E	3673 068989	NIKOLAY MAKAROV	{"email": "makarov-nikolay-061977@postgrespro.ru", "phone": "+70520605718"}
0005435040854	3C2896	8156 335985	MARIYA OSIPOVA	{"phone": "+70287750024"}
0005435040855	C619BB	2040 570346	MARIYA NAZAROVA	{"email": "nazarovam-04071970@postgrespro.ru", "phone": "+70715450732"}
0005435040856	C619BB	3325 028432	VYACHESLAV NOVIKOV	{"email": "vyacheslavnovikov091986@postgrespro.ru", "phone": "+70215887381"}
0005435040857	731A1D	2571 269446	OLGA DANILOVA	{"phone": "+70478483840"}
0005435040858	731A1D	1610 876500	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-01071975@postgrespro.ru", "phone": "+70283330276"}
0005435040859	6246EE	6454 419954	SERGEY SERGEEV	{"email": "sergeev.sergey.071973@postgrespro.ru", "phone": "+70337354179"}
0005435040860	C147E2	0525 481893	MARGARITA KUZMINA	{"email": "m_kuzmina1965@postgrespro.ru", "phone": "+70323960179"}
0005435040861	C147E2	5770 490853	NINA ZAKHAROVA	{"phone": "+70848086130"}
0005435040862	C147E2	4201 657824	MARIYA OSIPOVA	{"email": "osipova-mariya_1972@postgrespro.ru", "phone": "+70287316365"}
0005435040863	6B063F	4887 156920	MARIYA DMITRIEVA	{"phone": "+70875476664"}
0005435040864	267036	4680 414775	OLGA NESTEROVA	{"phone": "+70683241982"}
0005435040865	267036	9990 986671	DANIIL SOKOLOV	{"email": "daniilsokolov_021983@postgrespro.ru", "phone": "+70075650885"}
0005435040866	3A786D	0449 253389	VALENTINA IVANOVA	{"email": "valentinaivanova_011976@postgrespro.ru", "phone": "+70172223947"}
0005435040867	3A786D	0860 188278	STANISLAV RODIONOV	{"email": "rodionov-stanislav08121984@postgrespro.ru", "phone": "+70490955540"}
0005435040868	2A3F38	1787 507196	TATYANA POPOVA	{"email": "tatyana.popova_17021970@postgrespro.ru", "phone": "+70439872041"}
0005435040869	2A3F38	2646 249320	IRINA BOGDANOVA	{"email": "bogdanova-i_1970@postgrespro.ru", "phone": "+70161498511"}
0005435040870	494404	6342 115451	NATALYA MIKHAYLOVA	{"phone": "+70932325363"}
0005435040871	B1B96E	7698 746432	VLADIMIR MOROZOV	{"phone": "+70684924577"}
0005435040872	B1B96E	8919 209432	GALINA NAUMOVA	{"phone": "+70947354042"}
0005435040873	673BC8	2729 084972	OKSANA GRISHINA	{"email": "grishina-oksana081983@postgrespro.ru", "phone": "+70348780457"}
0005435040874	D7CF2A	1133 224271	ALINA PETROVA	{"phone": "+70064317264"}
0005435040875	9A3DDB	6001 235759	PETR DAVYDOV	{"phone": "+70127469988"}
0005435040876	9A3DDB	7351 801607	ANDREY ALEKSEEV	{"email": "alekseev.a_1969@postgrespro.ru", "phone": "+70390834283"}
0005435040877	F7B1D0	1376 795836	SVETLANA IVANOVA	{"phone": "+70415026680"}
0005435040878	352EC5	1841 108454	SERGEY MEDVEDEV	{"phone": "+70447443171"}
0005435040879	352EC5	2597 681071	NINA GERASIMOVA	{"phone": "+70481595840"}
0005435040880	1C9143	5059 629585	EVGENIY KUDRYASHOV	{"email": "e-kudryashov-1974@postgrespro.ru", "phone": "+70499451300"}
0005435040881	09C854	0451 898366	NINA DENISOVA	{"email": "denisova.n_10051980@postgrespro.ru", "phone": "+70471930101"}
0005435040882	09C854	3632 882592	TAISIYA KAZAKOVA	{"phone": "+70375778907"}
0005435040883	95EB4A	4431 245540	ARTEM NAUMOV	{"phone": "+70115316262"}
0005435040884	494159	9875 070329	SERGEY DAVYDOV	{"phone": "+70006520210"}
0005435040885	766ABE	7028 104892	VERA NIKOLAEVA	{"email": "vnikolaeva_1978@postgrespro.ru", "phone": "+70896583869"}
0005435040886	766ABE	1874 522102	LYUDMILA TIMOFEEVA	{"email": "l_timofeeva-1984@postgrespro.ru", "phone": "+70907408809"}
0005435040887	85D973	3857 562995	NATALYA FROLOVA	{"phone": "+70866892401"}
0005435040888	0653B9	1725 742540	PETR KUDRYASHOV	{"email": "p.kudryashov_21041964@postgrespro.ru", "phone": "+70556873876"}
0005435040889	0653B9	0699 330440	VLADIMIR FROLOV	{"phone": "+70292676666"}
0005435040890	9D997D	4834 038475	EVGENIY FILIPPOV	{"phone": "+70031636296"}
0005435040891	024A0E	0536 279631	ANASTASIYA BELOVA	{"email": "belova.a_16071977@postgrespro.ru", "phone": "+70113697290"}
0005435040892	024A0E	5727 504088	SERGEY ALEKSEEV	{"phone": "+70341558320"}
0005435040893	ED85F2	8029 579755	SERGEY KUZMIN	{"email": "sergey.kuzmin-091970@postgrespro.ru", "phone": "+70213608409"}
0005435040894	8813A5	7012 063641	ELIZAVETA POPOVA	{"phone": "+70268099358"}
0005435040895	8813A5	1347 239651	SERGEY POPOV	{"phone": "+70424244077"}
0005435040896	9FC031	5355 572619	DMITRIY TIMOFEEV	{"email": "d.timofeev.1976@postgrespro.ru", "phone": "+70027119685"}
0005435040897	9FC031	7143 300341	ALEKSEY KRASNOV	{"email": "krasnova-1980@postgrespro.ru", "phone": "+70519468462"}
0005435040898	D169FF	9250 984110	IRAIDA LEBEDEVA	{"email": "lebedeva_i_051978@postgrespro.ru", "phone": "+70440605413"}
0005435040899	D169FF	4414 999012	YURIY SOKOLOV	{"email": "sokolov-yuriy1967@postgrespro.ru", "phone": "+70289823190"}
0005435040900	B7B9A2	9160 100703	ANATOLIY VASILEV	{"email": "vasilev_anatoliy-011980@postgrespro.ru", "phone": "+70178496891"}
0005435040901	9A44CE	1304 301315	TAMARA NAUMOVA	{"email": "tamaranaumova_1981@postgrespro.ru", "phone": "+70855684217"}
0005435040902	829040	6583 477023	EVGENIY PAVLOV	{"phone": "+70567058404"}
0005435040903	829040	7817 543205	EDUARD RODIONOV	{"phone": "+70173825492"}
0005435040904	F63707	2071 991050	ELVIRA BORISOVA	{"email": "borisova-elvira1975@postgrespro.ru", "phone": "+70804733776"}
0005435040905	F63707	3388 971302	DMITRIY ABRAMOV	{"email": "abramov_dmitriy-12071966@postgrespro.ru", "phone": "+70862021545"}
0005435040906	A9E32A	4155 115590	GERMAN YAKOVLEV	{"phone": "+70212379009"}
0005435040907	99F1E1	4594 575998	VIKTOR MAKAROV	{"email": "makarov_viktor1964@postgrespro.ru", "phone": "+70313363276"}
0005435040908	99F1E1	3221 070688	GALINA VLASOVA	{"email": "g-vlasova.20111984@postgrespro.ru", "phone": "+70643524324"}
0005435040909	77EAD9	8619 841264	NIKOLAY ZAYCEV	{"email": "nikolay_zaycev.021972@postgrespro.ru", "phone": "+70389543411"}
0005435040910	92B47A	1245 123094	DANIIL SEMENOV	{"email": "daniil_semenov1977@postgrespro.ru", "phone": "+70807515689"}
0005435040911	41768E	0832 992879	PAVEL ZHURAVLEV	{"phone": "+70136744340"}
0005435040912	684760	4564 072749	ELVIRA ORLOVA	{"email": "elviraorlova29101966@postgrespro.ru", "phone": "+70561402109"}
0005435040913	684760	9102 862051	VADIM YAKOVLEV	{"phone": "+70258967276"}
0005435040914	EE4F4F	7923 033977	NATALYA FOMINA	{"email": "fomina.n031970@postgrespro.ru", "phone": "+70969350358"}
0005435040915	EE4F4F	6961 074751	VALENTINA BORISOVA	{"email": "vborisova-061975@postgrespro.ru", "phone": "+70217956632"}
0005435040916	28B894	8737 755199	VALERIY VASILEV	{"email": "vasilev.v20041977@postgrespro.ru", "phone": "+70845645990"}
0005435040917	28B894	0671 484657	ELENA ISAEVA	{"email": "elena.isaeva10071964@postgrespro.ru", "phone": "+70780967922"}
0005435040918	368F36	8943 779273	NATALYA LUKYANOVA	{"email": "lukyanova-n.121976@postgrespro.ru", "phone": "+70036782064"}
0005435040919	9EA5E6	1565 537015	YULIYA STEPANOVA	{"phone": "+70364483591"}
0005435040920	9A0D89	9325 633711	ANTONINA MIKHAYLOVA	{"email": "a_mikhaylova091980@postgrespro.ru", "phone": "+70161662059"}
0005435040921	9A0D89	6608 873445	LYUBOV MEDVEDEVA	{"email": "l_medvedeva_071968@postgrespro.ru", "phone": "+70206201197"}
0005435040922	9A0D89	3304 081465	ALEKSEY KONOVALOV	{"email": "a_konovalov.26041965@postgrespro.ru", "phone": "+70417046322"}
0005435040923	9A0D89	2096 457178	VALERIY FILIPPOV	{"email": "v_filippov-19111967@postgrespro.ru", "phone": "+70470386526"}
0005435040924	166F48	5991 580760	GRIGORIY PETROV	{"email": "petrov_g_1972@postgrespro.ru", "phone": "+70254941779"}
0005435040925	4EFE0A	3958 374181	MIKHAIL KAZAKOV	{"email": "kazakov.mikhail.121956@postgrespro.ru", "phone": "+70169301604"}
0005435040926	4EFE0A	1182 860945	ALEFTINA NOVIKOVA	{"email": "a_novikova-03031977@postgrespro.ru", "phone": "+70262740988"}
0005435040927	B82AC5	7968 427298	DENIS MAKAROV	{"email": "makarov.d_041975@postgrespro.ru", "phone": "+70034186113"}
0005435040928	B82AC5	8815 488409	ALEKSANDR NIKITIN	{"phone": "+70372423202"}
0005435040929	AB3FB7	3914 285908	YURIY IVANOV	{"phone": "+70618942067"}
0005435040930	AB3FB7	7156 766297	TIMUR NIKOLAEV	{"email": "nikolaev.t_051962@postgrespro.ru", "phone": "+70352391040"}
0005435040931	C6CE47	0677 691237	ALEKSEY NIKITIN	{"phone": "+70706225971"}
0005435040932	C6CE47	0368 634790	OLGA NIKITINA	{"phone": "+70395821772"}
0005435040933	D75830	7806 923057	KSENIYA SEMENOVA	{"phone": "+70885428327"}
0005435040934	D75830	8478 707851	ARTEM KOROLEV	{"phone": "+70473106709"}
0005435040935	37232D	6477 096924	ALEKSANDRA ARKHIPOVA	{"email": "aleksandra.arkhipova_06121970@postgrespro.ru", "phone": "+70066669047"}
0005435040936	0F4F67	4220 621848	VYACHESLAV IVANOV	{"phone": "+70779503207"}
0005435040937	2934D1	0313 159446	IVAN EGOROV	{"phone": "+70773568586"}
0005435040938	DBBFAF	2165 323564	VALENTINA GAVRILOVA	{"email": "gavrilova.v09011977@postgrespro.ru", "phone": "+70596903216"}
0005435040939	AA35CE	4131 803838	VERA GAVRILOVA	{"email": "vera_gavrilova-031967@postgrespro.ru", "phone": "+70298790860"}
0005435040940	8585F5	7796 492296	ANDREY BARANOV	{"email": "a_baranov_061972@postgrespro.ru", "phone": "+70271820769"}
0005435040941	17F463	5975 143242	GALINA KUZMINA	{"phone": "+70739183556"}
0005435040942	464383	9518 001738	LYUDMILA ALEKSEEVA	{"phone": "+70048557581"}
0005435040943	FD0836	5614 484178	SERGEY SEMENOV	{"phone": "+70124551543"}
0005435040944	293DFC	6315 923422	ANNA FROLOVA	{"email": "anna-frolova_071973@postgrespro.ru", "phone": "+70562548392"}
0005435040945	7A94B5	2458 799610	SERGEY BONDARENKO	{"email": "s.bondarenko.011966@postgrespro.ru", "phone": "+70346488811"}
0005435040946	7A94B5	1277 697830	MARIYA VASILEVA	{"email": "vasilevamariya.121967@postgrespro.ru", "phone": "+70061631779"}
0005435040947	681AEC	4144 803959	GALINA ANDREEVA	{"email": "galina-andreeva071980@postgrespro.ru", "phone": "+70559679673"}
0005435040948	736565	0543 600766	DANIIL PETROV	{"email": "dpetrov-081966@postgrespro.ru", "phone": "+70471727338"}
0005435040949	58A536	5156 217132	ANTONINA KUZMINA	{"phone": "+70446372914"}
0005435040950	8A1A23	3828 826719	NIKOLAY POPOV	{"email": "popov-nikolay_13011972@postgrespro.ru", "phone": "+70655581312"}
0005435040951	8A1A23	5205 040396	YULIYA ORLOVA	{"email": "orlova_yuliya-071968@postgrespro.ru", "phone": "+70328513811"}
0005435040952	AA39A7	0200 208061	SERGEY BELOV	{"phone": "+70824985703"}
0005435040953	8094A5	3015 660188	YULIYA FILIPPOVA	{"email": "yuliya.filippova-1961@postgrespro.ru", "phone": "+70488977093"}
0005435040954	A1FBCD	4923 106433	ALEKSANDR MOROZOV	{"email": "morozov_a-1976@postgrespro.ru", "phone": "+70192349072"}
0005435040955	4017ED	0712 158059	VLADIMIR ANTONOV	{"phone": "+70890942097"}
0005435040956	5DFD0E	6346 788264	LEONID KUZMIN	{"phone": "+70096747337"}
0005435040957	FC074A	8089 167539	NADEZHDA NIKOLAEVA	{"phone": "+70373563928"}
0005435040958	FC074A	7684 988149	SERGEY KUZNECOV	{"email": "kuznecov_s-021973@postgrespro.ru", "phone": "+70891345447"}
0005435040959	F2B802	3724 448312	PAVEL KOROLEV	{"email": "korolevp-111967@postgrespro.ru", "phone": "+70408116920"}
0005435040960	CC0570	6892 976183	VIKTORIYA SIDOROVA	{"email": "v-sidorova-26101965@postgrespro.ru", "phone": "+70201033765"}
0005435040961	4D0E5F	4183 946792	NATALYA SOKOLOVA	{"phone": "+70571887941"}
0005435040962	659006	8300 703633	ALEKSANDRA KUDRYASHOVA	{"email": "kudryashovaaleksandra.27041979@postgrespro.ru", "phone": "+70456249971"}
0005435040963	4D8EA1	9030 617208	VLADIMIR ROMANOV	{"phone": "+70200620272"}
0005435040964	530024	2737 132285	ELENA KUDRYASHOVA	{"email": "kudryashova-elena-031979@postgrespro.ru", "phone": "+70675884673"}
0005435040965	0C7ACF	2898 808955	OKSANA ROMANOVA	{"email": "romanovao.1980@postgrespro.ru", "phone": "+70082596219"}
0005435040966	0C7ACF	6424 369092	VLADIMIR VOROBEV	{"email": "vorobev.v08011984@postgrespro.ru", "phone": "+70786476313"}
0005435040967	B13FD6	0560 130651	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova-121968@postgrespro.ru", "phone": "+70357643845"}
0005435040968	1693CF	9397 448485	ARINA MASLOVA	{"phone": "+70791938962"}
0005435040969	6BB5BE	9928 145873	GALINA RODIONOVA	{"phone": "+70191219449"}
0005435040970	878E84	1888 649595	PETR GERASIMOV	{"phone": "+70023741249"}
0005435040971	7F6332	3434 975160	DENIS MEDVEDEV	{"phone": "+70030420264"}
0005435040972	7F6332	1736 029879	VITALIY SCHERBAKOV	{"email": "vitaliyscherbakov22071977@postgrespro.ru", "phone": "+70034233504"}
0005435040973	02BFBE	0104 846331	ZINAIDA KUZNECOVA	{"email": "zkuznecova1968@postgrespro.ru", "phone": "+70879910369"}
0005435040974	47719D	1192 497603	LYUDMILA ROMANOVA	{"phone": "+70326037422"}
0005435040975	47719D	6963 676878	NINA TIKHONOVA	{"email": "tikhonova-n041980@postgrespro.ru", "phone": "+70364354395"}
0005435040976	445139	7676 405725	OLESYA GERASIMOVA	{"email": "o.gerasimova_1956@postgrespro.ru", "phone": "+70138877869"}
0005435040977	B2612C	1662 484823	OLESYA FROLOVA	{"phone": "+70784744479"}
0005435040978	B2612C	5587 371193	MAKSIM SEMENOV	{"email": "m_semenov011969@postgrespro.ru", "phone": "+70091892421"}
0005435040979	4DFE7D	9834 845483	ARTEM SOROKIN	{"email": "sorokina-021972@postgrespro.ru", "phone": "+70670329532"}
0005435040980	49C307	8050 653815	TATYANA GERASIMOVA	{"phone": "+70468131135"}
0005435040981	5267E7	4006 164605	MAKSIM KUDRYASHOV	{"email": "m_kudryashov.041971@postgrespro.ru", "phone": "+70212227358"}
0005435040982	F5C61E	7916 428793	IRINA PAVLOVA	{"email": "pavlova_irina091972@postgrespro.ru", "phone": "+70270425692"}
0005435040983	BDCF43	1690 657879	SERGEY KUDRYASHOV	{"phone": "+70192497697"}
0005435040984	22D0E9	7344 702577	OLGA KUZNECOVA	{"email": "o.kuznecova01051973@postgrespro.ru", "phone": "+70278702227"}
0005435040985	015653	4948 082134	ALEKSEY KRASNOV	{"phone": "+70837101699"}
0005435040986	0B5B96	3145 317134	MARIYA MIRONOVA	{"phone": "+70375979296"}
0005435040987	0B5B96	6020 306359	TIMOFEY PETROV	{"phone": "+70167149857"}
0005435040988	D21567	2041 927451	OKSANA FILATOVA	{"email": "o-filatova_1978@postgrespro.ru", "phone": "+70047373931"}
0005435040989	BE8DCE	4827 458068	DANA KRASNOVA	{"email": "krasnovad_05051963@postgrespro.ru", "phone": "+70881870319"}
0005435040990	E1E250	8812 548000	ELENA LUKYANOVA	{"email": "lukyanova_e.13011974@postgrespro.ru", "phone": "+70349677812"}
0005435040991	E1E250	8494 761309	KONSTANTIN BORISOV	{"phone": "+70270248524"}
0005435040992	52B607	9865 263150	MILANA FADEEVA	{"email": "fadeeva.milana-061972@postgrespro.ru", "phone": "+70046143935"}
0005435040993	52B607	4154 729377	OLESYA SMIRNOVA	{"phone": "+70882408701"}
0005435040994	9ABCB0	8915 998608	ELENA ANDREEVA	{"email": "andreeva.elena1969@postgrespro.ru", "phone": "+70880109274"}
0005435040995	8DD3E4	2027 643845	EVDOKIYA BELYAEVA	{"phone": "+70882137736"}
0005435040996	C4CEEC	0643 602301	SERGEY VLASOV	{"phone": "+70832323492"}
0005435040997	4CBEE2	9694 527846	NATALIYA VOLKOVA	{"email": "volkova_n_021964@postgrespro.ru", "phone": "+70434634820"}
0005435040998	4CBEE2	2260 362089	VALENTINA KULIKOVA	{"phone": "+70225733204"}
0005435040999	4CBEE2	6209 973146	MARIYA ANTONOVA	{"email": "mariyaantonova_1978@postgrespro.ru", "phone": "+70507011803"}
0005435041000	80F3EC	7420 255887	KIRILL KOZLOV	{"email": "kozlovkirill_1972@postgrespro.ru", "phone": "+70097896263"}
0005435041001	80F3EC	1087 392133	ANNA TIKHONOVA	{"phone": "+70770287222"}
0005435041002	392D0A	1315 973949	LYUBOV IVANOVA	{"email": "ivanova_l.19081977@postgrespro.ru", "phone": "+70189123980"}
0005435041003	1C8A7F	6229 642504	ROZA PAVLOVA	{"email": "pavlova.r011972@postgrespro.ru", "phone": "+70614619456"}
0005435041004	1C8A7F	1260 312451	OLGA TIMOFEEVA	{"email": "otimofeeva1977@postgrespro.ru", "phone": "+70309627335"}
0005435041005	BD5550	2568 014914	VLADIMIR FEDOROV	{"email": "vladimir_fedorov.1970@postgrespro.ru", "phone": "+70443672264"}
0005435041006	BA5949	9720 855630	ARTUR ABRAMOV	{"email": "a-abramov1969@postgrespro.ru", "phone": "+70544137091"}
0005435041007	BA5949	8973 429706	ILYA TIKHONOV	{"email": "tikhonovi.041970@postgrespro.ru", "phone": "+70240997853"}
0005435041008	1925C6	1857 556529	ALIYA VOLKOVA	{"phone": "+70585883173"}
0005435041009	55A4BF	6649 544301	OLGA FOMINA	{"phone": "+70687814691"}
0005435041010	D34639	6093 409613	NATALYA DENISOVA	{"phone": "+70706806250"}
0005435041011	EDA425	8766 719796	ALINA NIKITINA	{"email": "nikitina-alina_091976@postgrespro.ru", "phone": "+70875912676"}
0005435041012	AB40F9	9046 236096	VIKTOR ZHUKOV	{"email": "v-zhukov01041960@postgrespro.ru", "phone": "+70696983906"}
0005435041013	85B481	8834 299550	VALERIY MAKSIMOV	{"email": "maksimov.v24041979@postgrespro.ru", "phone": "+70422455006"}
0005435041014	E3D65F	4403 618683	ALEKSANDR GERASIMOV	{"phone": "+70218709031"}
0005435041015	A8DE2B	7985 484742	NATALYA KRASNOVA	{"phone": "+70195217442"}
0005435041016	A78A95	4237 598639	ZOYA OSIPOVA	{"email": "z.osipova031966@postgrespro.ru", "phone": "+70580714453"}
0005435041017	AA0700	6094 935668	IRINA NIKOLAEVA	{"phone": "+70451680424"}
0005435041018	A78BB3	0748 533254	IRINA DAVYDOVA	{"email": "i-davydova_041976@postgrespro.ru", "phone": "+70461386945"}
0005435041019	A78BB3	4307 607510	VIKTORIYA RYABOVA	{"phone": "+70340718993"}
0005435041020	9905C2	2979 355694	SERGEY IVANOV	{"email": "ivanov-sergey.22011968@postgrespro.ru", "phone": "+70995045473"}
0005435041021	9905C2	2763 910999	VERA BARANOVA	{"email": "baranovavera_1966@postgrespro.ru", "phone": "+70486480819"}
0005435041022	B9E1FD	2475 403630	IRINA GUSEVA	{"phone": "+70059816483"}
0005435041023	B9C634	6892 413505	YANA GUSEVA	{"email": "yanaguseva_12061973@postgrespro.ru", "phone": "+70205241844"}
0005435041024	1AAB47	2556 210542	NADEZHDA ZAYCEVA	{"email": "nadezhda.zayceva-1977@postgrespro.ru", "phone": "+70826802362"}
0005435041025	1AAB47	9236 862750	VALENTINA TARASOVA	{"email": "tarasovavalentina-091980@postgrespro.ru", "phone": "+70854337331"}
0005435041026	4CDA03	9881 753811	YURIY KRASNOV	{"email": "y.krasnov.27091972@postgrespro.ru", "phone": "+70493071762"}
0005435041027	AB44A2	3904 813332	LYUDMILA KUZNECOVA	{"phone": "+70884055637"}
0005435041028	02C8A8	5877 810928	ANNA FROLOVA	{"phone": "+70897963676"}
0005435041029	0B6E8A	0540 083076	SERGEY SCHERBAKOV	{"phone": "+70106051297"}
0005435041030	A211CD	2490 022438	VIKTOR VASILEV	{"phone": "+70634018603"}
0005435041031	072EFD	5057 954433	ANDREY MOROZOV	{"email": "andrey_morozov_031967@postgrespro.ru", "phone": "+70364567471"}
0005435041032	634A20	8642 477586	SVETLANA CHERNOVA	{"phone": "+70808262152"}
0005435041033	D2A1C4	3159 597415	ALEKSANDR VLASOV	{"email": "a-vlasov02061975@postgrespro.ru", "phone": "+70954742289"}
0005435041034	D2A1C4	6726 749680	VIKTOR IVANOV	{"email": "ivanov-v.1986@postgrespro.ru", "phone": "+70188417119"}
0005435041035	D2A1C4	1302 790873	LYUBOV BELOVA	{"phone": "+70756791603"}
0005435041036	68C4FD	3876 251440	EMILIYA YUDINA	{"phone": "+70557815595"}
0005435041037	8957AC	7967 891389	REGINA NESTEROVA	{"phone": "+70765381686"}
0005435041038	001E72	1649 615996	ANATOLIY CHERNOV	{"phone": "+70481496085"}
0005435041039	28E126	9109 789023	VASILIY BORISOV	{"email": "v_borisov_1970@postgrespro.ru", "phone": "+70506622661"}
0005435041040	FBA851	8389 184432	ALEKSANDR DENISOV	{"phone": "+70699346382"}
0005435041041	36108F	3236 470015	ELENA DANILOVA	{"email": "edanilova.1971@postgrespro.ru", "phone": "+70741552933"}
0005435041042	6BBF48	0889 939695	ILYA SEMENOV	{"email": "ilyasemenov.21111981@postgrespro.ru", "phone": "+70367956978"}
0005435041043	6BBF48	4428 714495	ELIZAVETA VLASOVA	{"email": "e_vlasova.101969@postgrespro.ru", "phone": "+70399155549"}
0005435041044	B3C554	0709 684368	VLADIMIR GUSEV	{"email": "gusev_v051966@postgrespro.ru", "phone": "+70591666718"}
0005435041045	B3C554	8450 163018	VITALIY VLASOV	{"email": "vlasov_vitaliy_121985@postgrespro.ru", "phone": "+70776742570"}
0005435041046	53CF32	2445 723934	OLGA MELNIKOVA	{"email": "melnikova.olga.051981@postgrespro.ru", "phone": "+70619440920"}
0005435041047	53CF32	8947 751648	ALEKSANDR AFANASEV	{"phone": "+70906855371"}
0005435041048	1344E6	3938 470679	TATYANA KRASNOVA	{"phone": "+70015515363"}
0005435041049	1344E6	2808 514434	RAISA NIKOLAEVA	{"email": "nikolaeva-raisa24061979@postgrespro.ru", "phone": "+70166585661"}
0005435041050	1344E6	0457 374821	NATALYA SMIRNOVA	{"phone": "+70002501247"}
0005435041051	CA98D1	9535 548756	SERGEY MAKAROV	{"phone": "+70188225723"}
0005435041052	CA98D1	4567 253843	YULIYA KOROLEVA	{"phone": "+70780765922"}
0005435041053	C3C822	7281 180339	NIKITA ANTONOV	{"email": "antonovnikita_091982@postgrespro.ru", "phone": "+70782523860"}
0005435041054	1FE62C	5705 088339	NINA ZAYCEVA	{"phone": "+70637100060"}
0005435041055	C0BB1E	2776 495095	IVAN NOVIKOV	{"email": "novikov_ivan_05041974@postgrespro.ru", "phone": "+70316699487"}
0005435041056	C0BB1E	3581 291314	ALFIYA PAVLOVA	{"phone": "+70117194851"}
0005435041113	E0518A	1978 369553	NIKOLAY SERGEEV	{"phone": "+70708065289"}
0005435041057	98F7FE	8475 965551	VYACHESLAV ZAYCEV	{"email": "zaycev_vyacheslav.1965@postgrespro.ru", "phone": "+70298571186"}
0005435041058	98F7FE	1878 058684	SERGEY GAVRILOV	{"phone": "+70130541166"}
0005435041059	D226D2	2350 323850	ANDREY DAVYDOV	{"email": "davydov_andrey111978@postgrespro.ru", "phone": "+70478705410"}
0005435041060	D226D2	6097 545167	BORIS VOLKOV	{"phone": "+70702574813"}
0005435041061	F8A5F8	3187 187444	VADIM NIKOLAEV	{"phone": "+70800733684"}
0005435041062	2FA780	1711 089854	ILYAS EGOROV	{"phone": "+70545046850"}
0005435041063	2FA780	3091 984574	ANDREY SEMENOV	{"email": "semenov.andrey_121978@postgrespro.ru", "phone": "+70841810791"}
0005435041064	C04C22	3410 868868	POLINA SEMENOVA	{"phone": "+70369407105"}
0005435041065	78E31D	8012 717042	VIKTOR KUZNECOV	{"email": "kuznecov_v30121973@postgrespro.ru", "phone": "+70532577899"}
0005435041066	BD5EBF	6395 712486	ANTON MOROZOV	{"phone": "+70375275625"}
0005435041067	4EF2F8	8950 511879	ALEKSEY FROLOV	{"phone": "+70712519432"}
0005435041068	4EF2F8	5231 245368	RASHIT KONOVALOV	{"phone": "+70573042601"}
0005435041069	AE23DD	7608 017205	VLADIMIR GRIGOREV	{"email": "grigorev-v_30011974@postgrespro.ru", "phone": "+70371077755"}
0005435041070	2B0ED3	4354 431631	VIKTOR VLASOV	{"phone": "+70709579574"}
0005435041071	3F1F0B	4658 227046	LIDIYA BELYAEVA	{"phone": "+70115505926"}
0005435041072	D59AD2	6119 009856	DARYA KOMAROVA	{"phone": "+70387361903"}
0005435041073	D1264B	2767 611766	EVDOKIYA ZAYCEVA	{"email": "zayceva.e17031958@postgrespro.ru", "phone": "+70600424383"}
0005435041074	BA7682	2701 507228	PAVEL AFANASEV	{"email": "pavel.afanasev.16081974@postgrespro.ru", "phone": "+70037697487"}
0005435041075	EADFE1	6299 432575	GALINA TITOVA	{"phone": "+70109084432"}
0005435041076	71177A	2726 497185	IRINA IVANOVA	{"email": "ivanova.irina25031971@postgrespro.ru", "phone": "+70273924864"}
0005435041077	A87849	4600 009415	ALEKSEY SCHERBAKOV	{"phone": "+70947791904"}
0005435041078	163DF5	7164 999972	MARGARITA SIDOROVA	{"phone": "+70725972435"}
0005435041079	64971B	5388 024343	ALEKSANDR SEMENOV	{"email": "a_semenov20081966@postgrespro.ru", "phone": "+70080173931"}
0005435041080	64971B	5994 093723	ANASTASIYA DAVYDOVA	{"email": "davydova_a.27121979@postgrespro.ru", "phone": "+70778923116"}
0005435041081	5BC021	6261 643309	SERGEY NIKITIN	{"email": "sergey-nikitin111973@postgrespro.ru", "phone": "+70563997796"}
0005435041082	DE4B14	2957 806779	YURIY GERASIMOV	{"phone": "+70800674786"}
0005435041083	DE4B14	7806 200110	ELENA ZHUKOVA	{"email": "elena-zhukova-1977@postgrespro.ru", "phone": "+70650154264"}
0005435041084	B22826	9804 365257	VLADIMIR NOVIKOV	{"phone": "+70457663403"}
0005435041085	B22826	3828 605707	EKATERINA IVANOVA	{"phone": "+70525891483"}
0005435041086	88539D	2234 683086	IVAN BELOV	{"email": "i_belov1979@postgrespro.ru", "phone": "+70408108461"}
0005435041087	A6F846	5684 027878	OLGA KULIKOVA	{"email": "kulikova.o_1972@postgrespro.ru", "phone": "+70720237188"}
0005435041088	A2AE46	8166 099326	KRISTINA EFREMOVA	{"email": "efremova-k1963@postgrespro.ru", "phone": "+70875437787"}
0005435041089	5CA1ED	6699 305778	YULIYA MIKHAYLOVA	{"email": "mikhaylovayuliya04011970@postgrespro.ru", "phone": "+70731164359"}
0005435041090	5CA1ED	5499 182223	ALEKSANDRA EFREMOVA	{"email": "efremovaa-09011967@postgrespro.ru", "phone": "+70361366098"}
0005435041091	0676DE	3553 883687	DMITRIY VOROBEV	{"phone": "+70213507006"}
0005435041092	F37794	1878 651018	ILYA KULIKOV	{"phone": "+70290379169"}
0005435041093	D805F5	0171 635454	VALENTINA BARANOVA	{"email": "baranova_valentina_1970@postgrespro.ru", "phone": "+70675207002"}
0005435041094	D805F5	5002 038115	ALEKSANDR NAZAROV	{"phone": "+70524130447"}
0005435041095	C168B2	9970 376773	ERIK IVANOV	{"phone": "+70942008364"}
0005435041096	C168B2	3399 113729	ALEKSANDR IVANOV	{"phone": "+70592552909"}
0005435041097	589DB9	3876 671682	EVGENIY NIKOLAEV	{"email": "nikolaeve.06061977@postgrespro.ru", "phone": "+70668828886"}
0005435041098	5FDEF2	0292 474154	ALEKSANDRA MAKSIMOVA	{"phone": "+70212617684"}
0005435041099	67BF4E	1540 694278	VADIM NAUMOV	{"phone": "+70846445745"}
0005435041100	478D1F	3217 720637	TATYANA ALEKSEEVA	{"phone": "+70908046200"}
0005435041101	A77F36	4959 814503	ALEKSEY IVANOV	{"phone": "+70689839268"}
0005435041102	5123F1	4285 682270	DANIL DMITRIEV	{"email": "danil-dmitriev-1974@postgrespro.ru", "phone": "+70733377664"}
0005435041103	90FDE6	9746 862512	OLGA MEDVEDEVA	{"email": "olga.medvedeva_31011970@postgrespro.ru", "phone": "+70864064924"}
0005435041104	90FDE6	4427 451582	KRISTINA ANDREEVA	{"phone": "+70495677383"}
0005435041105	6BC518	2610 486487	ALEKSANDR GORBUNOV	{"email": "aleksandr_gorbunov_091969@postgrespro.ru", "phone": "+70623487049"}
0005435041106	6BC518	9436 996140	VALENTINA ILINA	{"email": "valentinailina.27121975@postgrespro.ru", "phone": "+70424949390"}
0005435041107	6BC518	4911 403651	ALEKSANDR SHEVCHENKO	{"phone": "+70145233183"}
0005435041108	A908D8	7248 530565	ANATOLIY IVANOV	{"phone": "+70086918654"}
0005435041109	91811C	9916 860254	NATALIYA VASILEVA	{"email": "vasilevanataliya_1968@postgrespro.ru", "phone": "+70010247088"}
0005435041110	D4BA09	0352 685528	MARIYA SMIRNOVA	{"email": "smirnovam1981@postgrespro.ru", "phone": "+70884565192"}
0005435041111	D4BA09	6601 321650	GALINA SEMENOVA	{"email": "galinasemenova1979@postgrespro.ru", "phone": "+70156363423"}
0005435041112	E0518A	0700 899531	VLADIMIR TARASOV	{"email": "tarasov.vladimir_061974@postgrespro.ru", "phone": "+70047800835"}
0005435041114	A461B1	9210 864966	VIKTOR MATVEEV	{"email": "matveev_v27011967@postgrespro.ru", "phone": "+70480844399"}
0005435041115	A461B1	5851 178330	ANASTASIYA LEBEDEVA	{"email": "lebedeva.anastasiya04011979@postgrespro.ru", "phone": "+70055930205"}
0005435041116	8C9285	5937 430948	ELENA SERGEEVA	{"email": "elena_sergeeva1966@postgrespro.ru", "phone": "+70406059966"}
0005435041117	4C491A	1082 809580	MARIANNA YAKOVLEVA	{"phone": "+70220592127"}
0005435041118	0A4FA3	2480 413385	EVGENIY BELOV	{"email": "belov-e.1970@postgrespro.ru", "phone": "+70135184117"}
0005435041119	0A4FA3	2759 668121	LIDIYA TIMOFEEVA	{"phone": "+70650834954"}
0005435041120	080B56	4552 679664	SERGEY ILIN	{"phone": "+70162973076"}
0005435041121	497BCE	2742 822303	SVETLANA KOVALEVA	{"email": "kovaleva-s-22021966@postgrespro.ru", "phone": "+70959395191"}
0005435041122	7B6629	3094 571211	LIDIYA POPOVA	{"email": "popova-lidiya_1978@postgrespro.ru", "phone": "+70940183858"}
0005435041123	AC8723	5849 921398	PETR STEPANOV	{"email": "stepanov.petr.17121974@postgrespro.ru", "phone": "+70641087531"}
0005435041124	AC8723	1953 187386	NIKITA MATVEEV	{"email": "matveevnikita041972@postgrespro.ru", "phone": "+70871534136"}
0005435041125	C2B0C9	1845 096066	VALERIY ALEKSANDROV	{"phone": "+70510314076"}
0005435041126	515CB2	3971 251903	IRINA MARTYNOVA	{"phone": "+70076138211"}
0005435041127	7C25BE	7195 408287	VASILIY SOROKIN	{"phone": "+70497322661"}
0005435041128	F380DD	8810 969950	ALEKSEY KOZLOV	{"email": "kozlov-aleksey.041971@postgrespro.ru", "phone": "+70018994362"}
0005435041129	F380DD	2243 843885	VLADIMIR SOROKIN	{"email": "vladimir-sorokin.31081973@postgrespro.ru", "phone": "+70057706147"}
0005435041130	3A531B	0323 403011	TAMARA TIKHONOVA	{"phone": "+70209928565"}
0005435041131	4C0ABD	0708 229937	IRINA BARANOVA	{"phone": "+70448428415"}
0005435041132	7C8B8D	8576 943802	NATALYA KUDRYASHOVA	{"email": "kudryashova_n-121967@postgrespro.ru", "phone": "+70189284187"}
0005435041133	818164	5530 353622	MARIYA MAKAROVA	{"phone": "+70156763918"}
0005435041134	C573E5	8093 772846	ALEFTINA TROFIMOVA	{"email": "atrofimova_031976@postgrespro.ru", "phone": "+70644219641"}
0005435041135	715AFE	3891 171944	OLESYA BORISOVA	{"phone": "+70065318021"}
0005435041136	116594	1031 288957	SERGEY SMIRNOV	{"email": "smirnov_s-21101969@postgrespro.ru", "phone": "+70932317294"}
0005435041137	79D1FD	5108 572080	OLGA FILIPPOVA	{"email": "filippovao-1975@postgrespro.ru", "phone": "+70205270653"}
0005435041138	28384D	9540 919458	KLAVDIYA FROLOVA	{"phone": "+70810676237"}
0005435041139	F674F7	5993 319889	ELENA KUZNECOVA	{"email": "elenakuznecova_1983@postgrespro.ru", "phone": "+70981721522"}
0005435041140	5A5CB8	7943 997394	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila-111971@postgrespro.ru", "phone": "+70276867622"}
0005435041141	5A5CB8	8115 229249	YULIYA MIRONOVA	{"email": "yuliyamironova-011969@postgrespro.ru", "phone": "+70219936331"}
0005435041142	5A5CB8	4034 753690	NATALYA KUZMINA	{"phone": "+70950711590"}
0005435041143	478023	1732 830206	ROMAN KOZLOV	{"email": "kozlovroman-04071970@postgrespro.ru", "phone": "+70332286744"}
0005435041144	95D052	0464 292429	YULIYA SCHERBAKOVA	{"email": "yuliya_scherbakova.111973@postgrespro.ru", "phone": "+70576818883"}
0005435041145	3DE5BA	6157 883617	SERGEY TARASOV	{"email": "s.tarasov.1968@postgrespro.ru", "phone": "+70711833758"}
0005435041146	3DE5BA	9089 895786	MAKSIM FEDOROV	{"phone": "+70254095210"}
0005435041147	32842F	1461 306469	NIKITA MAKSIMOV	{"email": "maksimovnikita19101977@postgrespro.ru", "phone": "+70911385908"}
0005435041148	32842F	6716 487005	TIMUR FROLOV	{"email": "frolov_timur-17061973@postgrespro.ru", "phone": "+70911661147"}
0005435041149	D15B3B	1475 375433	ROMAN NAUMOV	{"email": "roman_naumov.1979@postgrespro.ru", "phone": "+70220983788"}
0005435041150	D15B3B	4437 260820	NIKOLAY KUZNECOV	{"phone": "+70733491343"}
0005435041151	4FCC1C	8444 645089	SERGEY BORISOV	{"phone": "+70637507578"}
0005435041152	0591DA	9884 030462	SEMEN SMIRNOV	{"email": "smirnov-semen_1974@postgrespro.ru", "phone": "+70511084585"}
0005435041153	0591DA	2893 190111	VLADIMIR STEPANOV	{"phone": "+70434533304"}
0005435041154	C7859A	5861 263061	VALENTINA NAZAROVA	{"email": "nazarovavalentina08101976@postgrespro.ru", "phone": "+70585161698"}
0005435041155	C7859A	7574 817936	NIKOLAY KULIKOV	{"phone": "+70363354940"}
0005435041156	E7EF2B	9445 802425	RUSLAN KAZAKOV	{"email": "kazakovruslan20061967@postgrespro.ru", "phone": "+70286433820"}
0005435041157	E7EF2B	7131 127619	MIKHAIL NAUMOV	{"email": "naumov_m-1971@postgrespro.ru", "phone": "+70553190097"}
0005435041158	E7EF2B	6095 726767	VLADIMIR PAVLOV	{"email": "pavlov-vladimir.081976@postgrespro.ru", "phone": "+70497267725"}
0005435041159	8E3C30	5892 200272	KONSTANTIN BELOV	{"phone": "+70198602110"}
0005435041160	8E3C30	5997 826729	ANASTASIYA NIKOLAEVA	{"email": "nikolaevaanastasiya.041979@postgrespro.ru", "phone": "+70012701772"}
0005435041161	D66468	9368 603261	LYUDMILA KOZLOVA	{"phone": "+70144493888"}
0005435041162	2103B6	6657 884441	ALEKSEY GUSEV	{"email": "aleksey_gusev1981@postgrespro.ru", "phone": "+70383686492"}
0005435041163	99FA68	3250 280582	LIDIYA STEPANOVA	{"phone": "+70044618305"}
0005435041164	62ED6D	5374 492064	KLAVDIYA ZAKHAROVA	{"phone": "+70219776092"}
0005435041165	C20413	7241 882578	SVETLANA MIKHAYLOVA	{"phone": "+70157461568"}
0005435041166	E222B3	3799 378621	VLADIMIR RODIONOV	{"email": "vrodionov.1967@postgrespro.ru", "phone": "+70341293216"}
0005435041167	E222B3	6954 576978	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev_1963@postgrespro.ru", "phone": "+70325885297"}
0005435041168	FF368D	1280 140319	YURIY IVANOV	{"email": "ivanovy.1963@postgrespro.ru", "phone": "+70768272890"}
0005435041169	280B18	0842 048591	FARIT SOKOLOV	{"phone": "+70353486571"}
0005435041170	19FE00	6404 926766	ANATOLIY NAZAROV	{"email": "anazarov-1968@postgrespro.ru", "phone": "+70269840341"}
0005435041171	2B2700	6213 355445	ANDREY PAVLOV	{"email": "pavlovandrey22101973@postgrespro.ru", "phone": "+70536159158"}
0005435041172	DF9A4B	9388 228706	LYUDMILA KUZNECOVA	{"email": "l_kuznecova-061981@postgrespro.ru", "phone": "+70588298294"}
0005435041173	89D9F0	3695 204225	ARSENIY NIKOLAEV	{"email": "nikolaevarseniy.091962@postgrespro.ru", "phone": "+70585809681"}
0005435041174	EF714C	3615 049065	VENERA KUDRYASHOVA	{"phone": "+70299814720"}
0005435041175	6D6434	8050 023324	OLGA ANDREEVA	{"phone": "+70266395618"}
0005435041176	6D6434	3868 270645	LIDIYA KULIKOVA	{"phone": "+70749674383"}
0005435041177	3A4E37	3826 408612	VLADIMIR OSIPOV	{"email": "v_osipov-031970@postgrespro.ru", "phone": "+70040404990"}
0005435041178	6DE212	5311 791450	ALENA KUDRYASHOVA	{"phone": "+70365373666"}
0005435041179	6DE212	3492 569758	ILYA NIKITIN	{"email": "ilya_nikitin.061964@postgrespro.ru", "phone": "+70161110998"}
0005435041180	C22979	5593 817800	ALEKSEY OSIPOV	{"phone": "+70678499549"}
0005435041181	436D8A	5938 355693	TATYANA MEDVEDEVA	{"email": "medvedevatatyana.1972@postgrespro.ru", "phone": "+70547837404"}
0005435041182	3FA3A9	7291 883112	VALENTINA KONDRATEVA	{"phone": "+70473303620"}
0005435041183	3FA3A9	4957 454700	VLADIMIR ALEKSEEV	{"phone": "+70178000074"}
0005435041184	06CBDD	7879 319646	DENIS VOROBEV	{"phone": "+70223517949"}
0005435041243	29934C	6637 824613	ELENA MELNIKOVA	{"phone": "+70530313640"}
0005435041185	6A5207	4622 168982	ALINA KOVALEVA	{"email": "alina_kovaleva-11111966@postgrespro.ru", "phone": "+70436106497"}
0005435041186	10374D	9797 388845	TATYANA POPOVA	{"email": "popovatatyana-06031972@postgrespro.ru", "phone": "+70682506165"}
0005435041187	DB6F48	4796 894233	ELENA VASILEVA	{"phone": "+70433223477"}
0005435041188	91097F	1426 123204	ELENA STEPANOVA	{"email": "elena.stepanova.051970@postgrespro.ru", "phone": "+70783851361"}
0005435041189	91097F	0219 048302	ALEKSANDR GORBUNOV	{"email": "aleksandr-gorbunov.081969@postgrespro.ru", "phone": "+70744442578"}
0005435041190	DD6A25	6389 549710	VALERIY GAVRILOV	{"email": "valeriy_gavrilov15051973@postgrespro.ru", "phone": "+70401611403"}
0005435041191	8E19E1	9051 470876	ARTEM MAKAROV	{"phone": "+70142644931"}
0005435041192	8E19E1	6402 124076	VLADIMIR KONOVALOV	{"phone": "+70875008978"}
0005435041193	8E19E1	4754 080221	GRIGORIY MATVEEV	{"email": "grigoriymatveev.28091982@postgrespro.ru", "phone": "+70367583851"}
0005435041194	82C56E	4914 775480	YULIYA FROLOVA	{"email": "y-frolova-1970@postgrespro.ru", "phone": "+70519012055"}
0005435041195	82C56E	8575 910161	EKATERINA VOLKOVA	{"email": "volkova.e-30031976@postgrespro.ru", "phone": "+70199591811"}
0005435041196	7BAB71	2474 132648	SOFIYA OSIPOVA	{"phone": "+70365532977"}
0005435041197	9B0800	1036 243229	ELENA ROMANOVA	{"email": "e-romanova.011974@postgrespro.ru", "phone": "+70801832054"}
0005435041198	9B0800	8948 761178	ALENA KUZNECOVA	{"phone": "+70304840508"}
0005435041199	7E11C9	2832 090845	GALINA SCHERBAKOVA	{"phone": "+70642773808"}
0005435041200	7E11C9	6929 929920	RAVILYA KUZNECOVA	{"phone": "+70576339114"}
0005435041201	0E7186	0861 882737	NIKITA IVANOV	{"phone": "+70263309508"}
0005435041202	0E7186	6587 912700	SERGEY KULIKOV	{"email": "sergey_kulikov-091977@postgrespro.ru", "phone": "+70837166814"}
0005435041203	09B578	5019 537981	VIKTOR SCHERBAKOV	{"email": "v_scherbakov.051963@postgrespro.ru", "phone": "+70639572112"}
0005435041204	147500	8445 825916	ALEKSANDR ZHURAVLEV	{"email": "aleksandrzhuravlev.121978@postgrespro.ru", "phone": "+70167910097"}
0005435041205	9DECA3	9636 459500	VLADIMIR KUDRYASHOV	{"email": "kudryashov-v_22011987@postgrespro.ru", "phone": "+70953965449"}
0005435041206	9DECA3	5013 765237	NINA SEMENOVA	{"email": "nina-semenova_17121980@postgrespro.ru", "phone": "+70271554757"}
0005435041207	8B3C0E	2303 820337	ANFISA ANISIMOVA	{"phone": "+70879488963"}
0005435041208	E2A419	1307 846766	LYUDMILA BOGDANOVA	{"phone": "+70392261698"}
0005435041209	E2A419	4429 417291	MIKHAIL PETROV	{"phone": "+70550684337"}
0005435041210	9B9A20	9983 668049	LIDIYA YUDINA	{"email": "yudina.l-1974@postgrespro.ru", "phone": "+70431821240"}
0005435041211	9B9A20	0173 059555	TATYANA ZAYCEVA	{"email": "zayceva-tatyana01061970@postgrespro.ru", "phone": "+70178275211"}
0005435041212	7F6FF8	7275 895078	ALEKSANDR SCHERBAKOV	{"phone": "+70898876047"}
0005435041213	99EF07	4114 648181	MARINA ANDREEVA	{"phone": "+70596583385"}
0005435041214	99EF07	3829 785285	SERGEY ORLOV	{"email": "orlov-sergey-101971@postgrespro.ru", "phone": "+70386719105"}
0005435041215	B54355	3862 285860	OLGA LOGINOVA	{"email": "olga.loginova_09081984@postgrespro.ru", "phone": "+70522488838"}
0005435041216	B54355	3657 227835	NATALYA ZAYCEVA	{"email": "zaycevanatalya.1969@postgrespro.ru", "phone": "+70711849069"}
0005435041217	349453	3441 872286	LEONID SCHERBAKOV	{"phone": "+70034762781"}
0005435041218	654296	8707 439129	VALENTINA NIKITINA	{"phone": "+70394375870"}
0005435041219	21537C	0118 868230	NATALYA VOROBEVA	{"email": "vorobeva_n-1977@postgrespro.ru", "phone": "+70616785703"}
0005435041220	B1EDDA	6392 650911	RASUL POPOV	{"email": "popovrasul.1973@postgrespro.ru", "phone": "+70972192485"}
0005435041221	ECDFDE	2231 397027	ANDREY KAZAKOV	{"email": "kazakov-andrey1972@postgrespro.ru", "phone": "+70466035637"}
0005435041222	ECDFDE	8428 788517	MARIYA NOVIKOVA	{"email": "novikova.m_25091961@postgrespro.ru", "phone": "+70145732013"}
0005435041223	DFAD3F	9139 500649	VIKTOR KRASNOV	{"email": "krasnovv_1957@postgrespro.ru", "phone": "+70279771592"}
0005435041336	AA0904	5942 447086	SERGEY SOKOLOV	{"phone": "+70427890924"}
0005435041224	CAFCF8	8447 868287	OLGA ISAEVA	{"email": "isaeva_o_31031963@postgrespro.ru", "phone": "+70020050477"}
0005435041225	0FF780	5413 393349	OLGA LOGINOVA	{"email": "o.loginova_21031968@postgrespro.ru", "phone": "+70017784411"}
0005435041226	BA8D95	2546 893222	OLGA VOROBEVA	{"email": "vorobeva-olga.051981@postgrespro.ru", "phone": "+70097050304"}
0005435041227	BA8D95	6122 738011	ZINAIDA EGOROVA	{"email": "zegorova-1973@postgrespro.ru", "phone": "+70191830611"}
0005435041228	D272E9	9060 878421	ANNA BARANOVA	{"email": "annabaranova-1973@postgrespro.ru", "phone": "+70626359952"}
0005435041229	5D6E7A	7373 288899	DMITRIY NOVIKOV	{"phone": "+70678269159"}
0005435041230	B6E325	2188 596066	ANNA VASILEVA	{"phone": "+70359583680"}
0005435041231	073844	5565 741293	MARINA AKIMOVA	{"phone": "+70650057859"}
0005435041232	2149B9	6726 956183	VASILIY VASILEV	{"phone": "+70219496631"}
0005435041233	E2E4AB	7449 461642	SVETLANA KOZLOVA	{"email": "svetlana.kozlova07111976@postgrespro.ru", "phone": "+70240785749"}
0005435041234	E2E4AB	9870 151981	LYUDMILA VOLKOVA	{"phone": "+70489793358"}
0005435041235	B4650E	5969 805247	EKATERINA AFANASEVA	{"phone": "+70447429452"}
0005435041236	5D9DA1	3911 110471	VADIM SOROKIN	{"phone": "+70213680414"}
0005435041237	5D9DA1	6317 527186	SERGEY STEPANOV	{"phone": "+70542990129"}
0005435041238	5D9DA1	6082 745810	DANILA MAKAROV	{"phone": "+70145265898"}
0005435041239	E4ACC4	6257 280766	GALINA ALEKSANDROVA	{"email": "aleksandrova_galina_1975@postgrespro.ru", "phone": "+70888284698"}
0005435041240	BC603C	5600 262767	IGOR GERASIMOV	{"phone": "+70442102347"}
0005435041241	5299CE	2867 534591	ARKADIY KOROLEV	{"email": "korolev_arkadiy-071983@postgrespro.ru", "phone": "+70151046798"}
0005435041242	29934C	3400 265083	EVGENIY BORISOV	{"email": "borisovevgeniy.20061986@postgrespro.ru", "phone": "+70272211100"}
0005435041244	D682CE	0736 279320	ALEKSANDR ALEKSEEV	{"email": "alekseevaleksandr_1972@postgrespro.ru", "phone": "+70694110067"}
0005435041245	D682CE	2464 874758	YURIY VOLKOV	{"phone": "+70495173937"}
0005435041246	6A5F53	6063 981518	NINA SOLOVEVA	{"email": "solovevanina.1974@postgrespro.ru", "phone": "+70998500880"}
0005435041247	6EC33B	6617 855522	PAVEL SOLOVEV	{"phone": "+70329900081"}
0005435041248	6EC33B	6372 790473	DMITRIY AFANASEV	{"email": "afanasev_d-25121976@postgrespro.ru", "phone": "+70364346282"}
0005435041249	807BE7	1272 846708	ANATOLIY VASILEV	{"email": "avasilev091969@postgrespro.ru", "phone": "+70809063114"}
0005435041250	BB0108	6587 242555	SERGEY MATVEEV	{"email": "matveev.sergey_25111966@postgrespro.ru", "phone": "+70476127347"}
0005435041251	F1C978	2919 312816	SERGEY KOZLOV	{"email": "s_kozlov05051972@postgrespro.ru", "phone": "+70229489667"}
0005435041252	F1C978	0700 134442	LYUDMILA VOROBEVA	{"email": "lvorobeva_031966@postgrespro.ru", "phone": "+70278463050"}
0005435041253	F1C978	1695 534530	ANASTASIYA BARANOVA	{"phone": "+70878423195"}
0005435041254	79FF3A	4548 876263	TATYANA NESTEROVA	{"email": "tatyananesterova_051962@postgrespro.ru", "phone": "+70023677454"}
0005435041255	1A1CB0	8581 627380	ARINA KUZMINA	{"phone": "+70457409062"}
0005435041256	90EB6D	0442 271439	LYUDMILA ARKHIPOVA	{"email": "l-arkhipova23011967@postgrespro.ru", "phone": "+70080402698"}
0005435041257	AE8DDA	2293 561452	ANDREY KOROLEV	{"phone": "+70840328064"}
0005435041258	35F9BB	7075 656441	ALINA DAVYDOVA	{"email": "a.davydova11101976@postgrespro.ru", "phone": "+70611375685"}
0005435041259	BE9FDE	5135 803273	VLADIMIR ALEKSANDROV	{"email": "aleksandrov.v_1966@postgrespro.ru", "phone": "+70055659763"}
0005435041260	B49B8B	1391 813423	VLADIMIR KUDRYASHOV	{"email": "kudryashov-v_061974@postgrespro.ru", "phone": "+70103872330"}
0005435041261	2BD414	4141 882323	SVETLANA ALEKSEEVA	{"email": "alekseeva_svetlana.19101964@postgrespro.ru", "phone": "+70742193403"}
0005435041262	A9401C	6922 241909	SERGEY POPOV	{"email": "popovsergey.041981@postgrespro.ru", "phone": "+70643991273"}
0005435041263	A9401C	1366 521221	MAKSIM ALEKSANDROV	{"phone": "+70472417568"}
0005435041264	176755	5541 138220	VYACHESLAV KUZMIN	{"email": "kuzmin.vyacheslav-021965@postgrespro.ru", "phone": "+70343000558"}
0005435041265	98946C	3620 115010	VLADIMIR MOROZOV	{"email": "morozov.v-111961@postgrespro.ru", "phone": "+70528752969"}
0005435041266	59F789	5788 582096	KSENIYA MEDVEDEVA	{"phone": "+70025252515"}
0005435041267	59F789	8360 154377	VIKTORIYA MARTYNOVA	{"email": "vmartynova-1960@postgrespro.ru", "phone": "+70475196948"}
0005435041268	E07F4A	8911 823056	OLGA PETROVA	{"email": "o-petrova_1972@postgrespro.ru", "phone": "+70493343627"}
0005435041269	E07F4A	1682 495168	ALENA MIKHAYLOVA	{"phone": "+70656238235"}
0005435041270	1877D4	2655 633401	LYUDMILA POPOVA	{"phone": "+70259305186"}
0005435041271	39CE22	7979 661153	ALEVTINA KUZNECOVA	{"email": "alevtina-kuznecova.111958@postgrespro.ru", "phone": "+70612383649"}
0005435041272	5B9ACF	2410 817305	ALEKSANDR SMIRNOV	{"phone": "+70883800443"}
0005435041273	620404	3283 335874	TATYANA ALEKSANDROVA	{"phone": "+70380375390"}
0005435041274	412E9C	0677 205061	LYUDMILA KOROLEVA	{"phone": "+70689833394"}
0005435041275	CFC99F	6521 223834	TAMARA ISAEVA	{"email": "isaevatamara-1970@postgrespro.ru", "phone": "+70981751282"}
0005435041276	8D7AE6	7845 772545	VASILISA ZHURAVLEVA	{"email": "zhuravleva.v_1975@postgrespro.ru", "phone": "+70403425899"}
0005435041277	8D7AE6	7896 738479	VALENTINA TARASOVA	{"phone": "+70347244989"}
0005435041278	A39ADB	4673 029356	TAMARA MAKSIMOVA	{"email": "maksimova.t-021977@postgrespro.ru", "phone": "+70795503613"}
0005435041279	C98D8A	1298 010243	EVGENIY DMITRIEV	{"email": "edmitriev-1976@postgrespro.ru", "phone": "+70506665415"}
0005435041280	83E79E	5381 431400	ALEKSANDR ANDREEV	{"phone": "+70619234629"}
0005435041281	83E79E	9712 463518	NADEZHDA GORBUNOVA	{"email": "n-gorbunova-111979@postgrespro.ru", "phone": "+70060949884"}
0005435041282	D169F4	4757 479412	LYUDMILA LEBEDEVA	{"email": "lebedeva_l_1983@postgrespro.ru", "phone": "+70899632318"}
0005435041283	110966	5744 853617	NIKOLAY KUZNECOV	{"phone": "+70262558174"}
0005435041284	B5F470	2945 786385	GALINA KULIKOVA	{"email": "g_kulikova-121966@postgrespro.ru", "phone": "+70828322271"}
0005435041285	B5F470	9061 601127	YULIYA KUZNECOVA	{"email": "kuznecova_yuliya_29091973@postgrespro.ru", "phone": "+70809324413"}
0005435041286	18350D	0886 714260	TATYANA SCHERBAKOVA	{"email": "t-scherbakova1981@postgrespro.ru", "phone": "+70418083246"}
0005435041287	2E83BD	4657 605321	ALEKSANDR ZAYCEV	{"phone": "+70697549083"}
0005435041288	CAFD9F	5043 948713	ELENA VASILEVA	{"phone": "+70936093669"}
0005435041289	19083E	5709 307372	OLGA FADEEVA	{"email": "o-fadeeva1965@postgrespro.ru", "phone": "+70992459728"}
0005435041290	19083E	2693 306466	ARTEM MIRONOV	{"email": "mironov_artem_011970@postgrespro.ru", "phone": "+70444632496"}
0005435041291	80066A	1810 821389	NATALYA VASILEVA	{"phone": "+70663662862"}
0005435041292	5A2809	3034 365546	VIKTOR IVANOV	{"email": "ivanov-v-22031979@postgrespro.ru", "phone": "+70373902574"}
0005435041293	16398D	7136 225884	ELENA SAVELEVA	{"email": "e.saveleva_091971@postgrespro.ru", "phone": "+70045837117"}
0005435041294	481685	5396 217576	OLGA FROLOVA	{"email": "frolovao-1967@postgrespro.ru", "phone": "+70115080110"}
0005435041295	6C7CAE	6007 521033	ANTON NAUMOV	{"phone": "+70971749665"}
0005435041296	D83643	3944 810038	VLADISLAV PETROV	{"email": "petrov.vladislav1972@postgrespro.ru", "phone": "+70272929217"}
0005435041297	294433	2079 674045	ELENA GORBUNOVA	{"email": "gorbunova.e08081971@postgrespro.ru", "phone": "+70103299986"}
0005435041298	90C2F0	9783 505885	YULIYA ROMANOVA	{"phone": "+70116474785"}
0005435041299	62B36F	1550 072118	ALEKSEY MELNIKOV	{"phone": "+70964868136"}
0005435041300	9B2910	4993 860377	VLADIMIR VASILEV	{"email": "v.vasilev.051978@postgrespro.ru", "phone": "+70190046336"}
0005435041301	AB3656	8660 102634	ALEKSANDR SIDOROV	{"phone": "+70184861715"}
0005435041302	9FD3FE	3081 746032	YURIY VLASOV	{"email": "yvlasov_13081972@postgrespro.ru", "phone": "+70050698070"}
0005435041303	63F803	2334 299064	EMMA KARPOVA	{"email": "ekarpova_061956@postgrespro.ru", "phone": "+70570369122"}
0005435041304	63F803	1998 366837	NATALYA FILIPPOVA	{"phone": "+70500895135"}
0005435041305	5A6FD6	9310 451648	ALEKSANDR POPOV	{"phone": "+70224303464"}
0005435041306	911555	2410 996879	NATALYA NAZAROVA	{"phone": "+70043690217"}
0005435041307	911555	4345 541924	SERGEY MAKSIMOV	{"phone": "+70311315633"}
0005435041308	911555	3541 395183	NATALYA VOROBEVA	{"email": "nvorobeva-06071966@postgrespro.ru", "phone": "+70718029079"}
0005435041309	D8F116	8628 255912	VASILIY SEMENOV	{"email": "v.semenov_30091972@postgrespro.ru", "phone": "+70300734104"}
0005435041310	C99F41	5417 190869	IRINA STEPANOVA	{"phone": "+70315629998"}
0005435041311	78ECEE	6288 133459	NADEZHDA KISELEVA	{"phone": "+70172891810"}
0005435041312	874028	7293 771100	LIDIYA SAVELEVA	{"phone": "+70008754481"}
0005435041313	DBFEF2	5700 338866	LIDIYA EFREMOVA	{"phone": "+70796226448"}
0005435041314	5501FE	7162 878852	VIKTOR YAKOVLEV	{"phone": "+70246673548"}
0005435041315	5C0B77	2616 103091	VIKTORIYA VOROBEVA	{"phone": "+70372216092"}
0005435041316	836EB8	3596 667651	MARINA KONDRATEVA	{"phone": "+70859056345"}
0005435041317	DD05EA	6735 261464	VLADIMIR EGOROV	{"phone": "+70465036359"}
0005435041318	22A641	7641 096677	KIRILL BORISOV	{"phone": "+70103983309"}
0005435041319	22A641	6663 091765	ALEKSANDR SEMENOV	{"phone": "+70737736899"}
0005435041320	002EA0	7431 454233	VLADIMIR VOROBEV	{"phone": "+70782197209"}
0005435041321	002EA0	7397 193602	VYACHESLAV TIKHONOV	{"email": "tikhonovv_21081971@postgrespro.ru", "phone": "+70423995182"}
0005435041322	41CC0D	2149 002278	MAKSIM SEMENOV	{"email": "semenov.maksim1966@postgrespro.ru", "phone": "+70013141965"}
0005435041323	41CC0D	3057 523040	LYUDMILA PETROVA	{"email": "lyudmilapetrova.081968@postgrespro.ru", "phone": "+70789721200"}
0005435041324	9CE911	2250 434236	MARINA MAKSIMOVA	{"phone": "+70147926039"}
0005435041325	7E7AED	7231 812730	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a_21051970@postgrespro.ru", "phone": "+70506874866"}
0005435041326	7E7AED	6481 565086	TAGIR KISELEV	{"email": "kiselev.tagir-1971@postgrespro.ru", "phone": "+70491342656"}
0005435041327	B7DC93	3691 823189	OLGA NIKITINA	{"email": "o_nikitina.25071963@postgrespro.ru", "phone": "+70103629308"}
0005435041328	B7DC93	3363 289772	OLGA BARANOVA	{"phone": "+70643687240"}
0005435041329	347036	1850 154244	VLADIMIR ILIN	{"phone": "+70471296934"}
0005435041330	B7D379	6436 413336	VALENTINA ANISIMOVA	{"email": "valentina-anisimova091974@postgrespro.ru", "phone": "+70765139976"}
0005435041331	7D6E85	2560 853097	SERGEY FOMIN	{"phone": "+70154565847"}
0005435041332	17ECFD	0033 649617	NATALYA DAVYDOVA	{"email": "davydova_natalya_26091957@postgrespro.ru", "phone": "+70593182993"}
0005435041333	17ECFD	4112 177102	ANTON MIKHAYLOV	{"phone": "+70999406562"}
0005435041334	2FE0BD	0688 106995	TAMARA OSIPOVA	{"phone": "+70787573679"}
0005435041335	2FE0BD	9031 201734	KIRILL MOROZOV	{"email": "morozovkirill_04021982@postgrespro.ru", "phone": "+70619609777"}
0005435041337	BF4C7A	9866 196669	MARIYA PAVLOVA	{"email": "pavlova-mariya04071968@postgrespro.ru", "phone": "+70494515361"}
0005435041338	FC7E35	3362 746682	LYUDMILA PETROVA	{"email": "lyudmila_petrova10081975@postgrespro.ru", "phone": "+70950358774"}
0005435041339	67F13D	0502 741610	SVETLANA PAVLOVA	{"phone": "+70676721549"}
0005435041340	F5B768	0175 704497	OLGA ZOTOVA	{"email": "olga-zotova.041970@postgrespro.ru", "phone": "+70587906576"}
0005435041341	EE5988	4255 080561	SVETLANA ARKHIPOVA	{"email": "svetlana-arkhipova_24091965@postgrespro.ru", "phone": "+70855317887"}
0005435041342	EE5988	1355 630143	ALEKSEY TIKHONOV	{"email": "tikhonova.061971@postgrespro.ru", "phone": "+70612965396"}
0005435041343	1598A8	0813 350359	VYACHESLAV NOVIKOV	{"email": "novikovvyacheslav-12011965@postgrespro.ru", "phone": "+70921528178"}
0005435041344	1598A8	7059 919094	TATYANA TIKHONOVA	{"phone": "+70786020866"}
0005435041345	41D5D9	0877 465051	VALERIY VOROBEV	{"email": "v_vorobev.28091980@postgrespro.ru", "phone": "+70604420374"}
0005435041346	41D5D9	9024 767329	MARGARITA MOISEEVA	{"email": "moiseeva-margarita-1976@postgrespro.ru", "phone": "+70325914801"}
0005435041347	BD1615	5370 187915	NIKITA ORLOV	{"email": "nikita_orlov-071965@postgrespro.ru", "phone": "+70108066593"}
0005435041348	711027	9843 668838	VLADIMIR DMITRIEV	{"email": "vdmitriev111978@postgrespro.ru", "phone": "+70761002475"}
0005435041349	734D0D	1729 355694	VLADIMIR MIRONOV	{"email": "mironovvladimir-19031968@postgrespro.ru", "phone": "+70818504799"}
0005435041350	E8CD1F	3797 451268	TATYANA MEDVEDEVA	{"phone": "+70467350100"}
0005435041351	96F115	9285 106783	IRINA ANDREEVA	{"email": "andreeva-irina.1964@postgrespro.ru", "phone": "+70385541258"}
0005435041352	2DDC2F	5267 774121	STEPAN MARTYNOV	{"phone": "+70704644578"}
0005435041353	2DDC2F	7088 956550	EVGENIYA ROMANOVA	{"phone": "+70574334369"}
0005435041354	323AFB	3719 112709	ANATOLIY NAZAROV	{"phone": "+70956971557"}
0005435041355	A4C9E5	8274 623068	LYUDMILA KOROLEVA	{"phone": "+70092628406"}
0005435041356	8BD350	9571 148113	ALEKSANDR KUDRYASHOV	{"email": "akudryashov-051966@postgrespro.ru", "phone": "+70046791986"}
0005435041357	C272F6	3312 540952	IVAN SEMENOV	{"email": "semenov_i_1982@postgrespro.ru", "phone": "+70174949448"}
0005435041358	C272F6	5585 015324	ALEKSANDRA MAKAROVA	{"phone": "+70053080543"}
0005435041359	4F48A2	1712 888773	ALEKSANDRA MASLOVA	{"phone": "+70015193338"}
0005435041360	8EDE67	4961 605018	RAIL MAKAROV	{"email": "makarov_rail-1978@postgrespro.ru", "phone": "+70972372335"}
0005435041361	C64454	8216 104111	ALEKSANDR NOVIKOV	{"phone": "+70041618907"}
0005435041362	B70875	4859 741939	TAMARA LEBEDEVA	{"email": "t-lebedeva05061980@postgrespro.ru", "phone": "+70137094729"}
0005435041363	46C7AF	3802 442504	ALEKSANDR ALEKSEEV	{"email": "a_alekseev_071970@postgrespro.ru", "phone": "+70704387217"}
0005435041364	DA92E4	0848 571312	VLADIMIR DAVYDOV	{"email": "davydovv_111974@postgrespro.ru", "phone": "+70088853675"}
0005435041365	DA92E4	0667 939221	IRINA FEDOROVA	{"email": "fedorova_i1980@postgrespro.ru", "phone": "+70553604315"}
0005435041366	843094	2347 188628	VLADIMIR TIKHONOV	{"phone": "+70108443740"}
0005435041367	843094	4302 129642	VIKTORIYA KOZLOVA	{"email": "kozlova_viktoriya_05021972@postgrespro.ru", "phone": "+70108758084"}
0005435041368	9F1BC3	0478 861333	ALEKSANDR NAZAROV	{"email": "a.nazarov101982@postgrespro.ru", "phone": "+70138757514"}
0005435041369	9F1BC3	5773 382636	LARISA BORISOVA	{"phone": "+70953405772"}
0005435041370	98CF92	1008 288829	TATYANA MELNIKOVA	{"email": "melnikova-t.071984@postgrespro.ru", "phone": "+70786906688"}
0005435041371	4162B5	1217 561581	IRINA NOVIKOVA	{"email": "novikova_i011975@postgrespro.ru", "phone": "+70405622627"}
0005435041372	7C6BB4	2621 427113	MARTA ZAKHAROVA	{"email": "m-zakharova1963@postgrespro.ru", "phone": "+70875548898"}
0005435041373	114AE6	2709 775953	ALEKSANDR SEMENOV	{"phone": "+70647213554"}
0005435041374	76A19C	4131 538878	ALINA TIKHONOVA	{"phone": "+70693313713"}
0005435041375	76A19C	0462 335134	DARYA ZHUKOVA	{"phone": "+70135302439"}
0005435041376	18FCE1	5306 173313	IRINA KOROLEVA	{"phone": "+70797876899"}
0005435041377	18FCE1	5574 089414	MIKHAIL MARTYNOV	{"email": "martynovm.06121978@postgrespro.ru", "phone": "+70888576665"}
0005435041378	20C299	2717 890012	ALEKSANDRA NESTEROVA	{"email": "aleksandranesterova.101977@postgrespro.ru", "phone": "+70872074142"}
0005435041379	121D72	5034 750808	GALINA MIKHAYLOVA	{"phone": "+70195156969"}
0005435041380	121D72	6586 795201	TAMARA NIKOLAEVA	{"email": "nikolaeva_tamara15011975@postgrespro.ru", "phone": "+70294930072"}
0005435041381	B40DE7	1117 270710	EKATERINA PETROVA	{"phone": "+70095757389"}
0005435041382	0859FA	3241 654619	DENIS KISELEV	{"email": "denis_kiselev-03111974@postgrespro.ru", "phone": "+70325901295"}
0005435041383	B98FF5	4129 400752	ALEKSANDR POPOV	{"phone": "+70492164597"}
0005435041384	B98FF5	2464 121074	ANZHELIKA POPOVA	{"email": "popova-a_10011973@postgrespro.ru", "phone": "+70532620402"}
0005435041385	4F757D	9878 456469	NATALIYA KOMAROVA	{"email": "nkomarova-05091968@postgrespro.ru", "phone": "+70549020838"}
0005435041386	B2A3AC	4089 218703	MARIYA NAUMOVA	{"email": "m.naumova_18051969@postgrespro.ru", "phone": "+70971065564"}
0005435041387	B2A3AC	0209 692372	MARIYA MELNIKOVA	{"email": "melnikovam-1973@postgrespro.ru", "phone": "+70295689247"}
0005435041388	C6F1DD	9930 700940	ANNA VOLKOVA	{"phone": "+70479455502"}
0005435041389	485E39	2334 065392	ELENA SERGEEVA	{"phone": "+70502994978"}
0005435041390	692535	7248 568510	MARIYA IVANOVA	{"email": "mariya-ivanova_19081960@postgrespro.ru", "phone": "+70778656396"}
0005435041391	692535	4909 502848	IRINA TIKHONOVA	{"phone": "+70023386694"}
0005435041392	2DD562	1554 431097	VALERIY KARPOV	{"phone": "+70131793231"}
0005435041393	C4AD6B	7122 667959	SERGEY KOZLOV	{"phone": "+70873838348"}
0005435041394	C4AD6B	4223 877181	VITALIY BARANOV	{"phone": "+70382557382"}
0005435041395	A39088	5768 987083	NIKITA DMITRIEV	{"phone": "+70833416713"}
0005435041396	D63E28	3599 470452	ALEKSANDR IVANOV	{"email": "aleksandrivanov02101971@postgrespro.ru", "phone": "+70758284834"}
0005435041397	5221C6	3081 598307	ANASTASIYA VLASOVA	{"phone": "+70830706747"}
0005435041398	09C5EF	5361 368774	PAVEL ANTONOV	{"phone": "+70386144069"}
0005435041399	09C5EF	1887 793741	OLGA SOKOLOVA	{"phone": "+70899171328"}
0005435041400	D576C4	5218 531168	GALINA POPOVA	{"phone": "+70259475019"}
0005435041401	D576C4	9022 117077	VALERIY ZAYCEV	{"email": "valeriyzaycev1971@postgrespro.ru", "phone": "+70559048633"}
0005435041402	00A099	0862 358709	ANTON SHEVCHENKO	{"email": "shevchenko.a_16101969@postgrespro.ru", "phone": "+70834228594"}
0005435041403	BA9806	1916 259260	KHALIDA MELNIKOVA	{"email": "melnikova-k.101971@postgrespro.ru", "phone": "+70852904117"}
0005435041404	BA9806	9415 976354	PAVEL ROMANOV	{"phone": "+70023690586"}
0005435041405	B80723	2454 351791	ALEKSANDR MOROZOV	{"phone": "+70005152512"}
0005435041406	DB10CC	9233 948161	KARIM MELNIKOV	{"phone": "+70300090297"}
0005435041407	DB10CC	7440 112125	ALEKSANDR DAVYDOV	{"email": "davydov_a1971@postgrespro.ru", "phone": "+70179797856"}
0005435041408	4A1701	8001 670240	IGOR EGOROV	{"email": "iegorov-121969@postgrespro.ru", "phone": "+70201338053"}
0005435041409	4A1701	5212 844932	SERGEY OSIPOV	{"email": "osipov_sergey_1970@postgrespro.ru", "phone": "+70885967111"}
0005435041410	0065DC	4521 205545	ALEKSEY KULIKOV	{"phone": "+70409329306"}
0005435041411	85DDBA	9041 057282	TAMARA STEPANOVA	{"email": "stepanovat_1977@postgrespro.ru", "phone": "+70147529329"}
0005435041412	85DDBA	8921 895342	VLADIMIR POPOV	{"phone": "+70284685536"}
0005435041413	6B1603	5210 930107	IRINA TARASOVA	{"phone": "+70735522516"}
0005435041414	C20A1F	0817 388347	LEONID VLASOV	{"phone": "+70184040438"}
0005435041415	C20A1F	2457 751513	EVGENIY KOZLOV	{"email": "e_kozlov_1983@postgrespro.ru", "phone": "+70858291728"}
0005435041416	C20A1F	3151 584710	ULYANA SOLOVEVA	{"email": "u.soloveva28091958@postgrespro.ru", "phone": "+70002391732"}
0005435041417	80F5D2	7756 222033	ELENA KUZNECOVA	{"email": "e.kuznecova.091992@postgrespro.ru", "phone": "+70977905824"}
0005435041418	80F5D2	3487 096899	VYACHESLAV ZHUKOV	{"email": "vyacheslav.zhukov051976@postgrespro.ru", "phone": "+70783100289"}
0005435041419	84BFD7	1069 207570	INESSA GAVRILOVA	{"email": "inessa.gavrilova.26101963@postgrespro.ru", "phone": "+70439997785"}
0005435041420	6AA02E	8976 748408	IRINA SOROKINA	{"phone": "+70394520361"}
0005435041421	A250D3	2248 662405	NINA ZAKHAROVA	{"phone": "+70172823454"}
0005435041422	A250D3	0096 414368	IRINA GERASIMOVA	{"email": "gerasimova.i-04101969@postgrespro.ru", "phone": "+70522973298"}
0005435041423	64EC44	1079 307515	GENNADIY SMIRNOV	{"email": "smirnov.gennadiy.21061971@postgrespro.ru", "phone": "+70210101080"}
0005435041424	64EC44	6593 552739	LYUBOV KOROLEVA	{"email": "l-koroleva.30071969@postgrespro.ru", "phone": "+70548892817"}
0005435041425	A239EF	3902 049576	SVETLANA KONOVALOVA	{"email": "konovalova.s07021969@postgrespro.ru", "phone": "+70949260164"}
0005435041426	F38CF2	9157 904986	DANIIL FEDOTOV	{"phone": "+70246489952"}
0005435041427	E33745	0196 586234	MATVEY MAKAROV	{"email": "makarov_m11071979@postgrespro.ru", "phone": "+70321158629"}
0005435041428	6D125D	9212 627927	ALEKSEY KONOVALOV	{"email": "konovalov.a_21091972@postgrespro.ru", "phone": "+70745731960"}
0005435041429	2F5C38	9666 849376	IRINA MAKSIMOVA	{"email": "maksimova_irina041979@postgrespro.ru", "phone": "+70090699715"}
0005435041430	9C0287	3645 128760	SVETLANA MIRONOVA	{"email": "mironova.s_091971@postgrespro.ru", "phone": "+70806336682"}
0005435041431	DC6273	3272 443444	TATYANA ALEKSANDROVA	{"phone": "+70470791556"}
0005435041432	02561B	2391 779619	TATYANA MAKSIMOVA	{"phone": "+70144602625"}
0005435041433	02561B	5821 491323	MARK MAKAROV	{"email": "makarov.m.15051961@postgrespro.ru", "phone": "+70902120623"}
0005435041434	C6576C	6618 418307	NATALIYA SAVELEVA	{"email": "saveleva-nataliya_22041970@postgrespro.ru", "phone": "+70952641100"}
0005435041435	B6E1D1	9458 059377	YURIY ANDREEV	{"email": "y-andreev_051973@postgrespro.ru", "phone": "+70473905418"}
0005435041436	B7DB9C	5155 859853	ALEKSANDR GAVRILOV	{"email": "gavrilov-aleksandr-27081966@postgrespro.ru", "phone": "+70199276664"}
0005435041437	DAAFB2	8377 686765	ELENA ILINA	{"email": "elena.ilina.22061967@postgrespro.ru", "phone": "+70743519960"}
0005435041438	9F9C43	1868 209648	NIKOLAY GRIGOREV	{"email": "nikolay-grigorev-22061979@postgrespro.ru", "phone": "+70294153436"}
0005435041439	F3B801	8040 141499	DANIIL KUZNECOV	{"phone": "+70108235484"}
0005435041440	7AB2BF	9932 209304	ANNA NOVIKOVA	{"email": "novikova_anna_03041967@postgrespro.ru", "phone": "+70256602272"}
0005435041441	872083	6214 211086	ANASTASIYA VOROBEVA	{"phone": "+70526848775"}
0005435041442	872083	9119 016076	MAKSIM BELOV	{"phone": "+70789567938"}
0005435041443	21BDAC	9899 195025	ANNA DAVYDOVA	{"email": "a.davydova-1966@postgrespro.ru", "phone": "+70457514016"}
0005435041444	E28AE6	9350 299652	SEMEN FEDOROV	{"phone": "+70686028444"}
0005435041445	E28AE6	3736 499022	VYACHESLAV RODIONOV	{"email": "rodionov-vyacheslav.16051969@postgrespro.ru", "phone": "+70378397230"}
0005435041446	411D56	4339 411982	TIMUR ZAKHAROV	{"email": "zakharov.timur.1968@postgrespro.ru", "phone": "+70477415443"}
0005435041447	1EE459	1138 436510	DMITRIY KOROLEV	{"email": "dmitriy.korolev-30111965@postgrespro.ru", "phone": "+70314571135"}
0005435041448	1EE459	1543 085885	PETR ANTONOV	{"phone": "+70656304554"}
0005435041449	FF34C0	1531 584126	ALEKSANDR NOVIKOV	{"email": "novikova-051963@postgrespro.ru", "phone": "+70428895916"}
0005435041450	4637B4	2198 933100	ANASTASIYA MALYSHEVA	{"email": "a.malysheva_15081975@postgrespro.ru", "phone": "+70522278914"}
0005435041451	4637B4	9196 899290	ANDREY KRASNOV	{"email": "krasnov.a.13101969@postgrespro.ru", "phone": "+70207766396"}
0005435041452	4637B4	7355 560734	IVAN PETROV	{"email": "ivan-petrov15091962@postgrespro.ru", "phone": "+70472887702"}
0005435041453	477A58	3982 834218	VIKTOR FEDOROV	{"email": "fedorov-v-061974@postgrespro.ru", "phone": "+70917030979"}
0005435041454	132547	4676 551560	ILNUR MATVEEV	{"phone": "+70814939269"}
0005435041455	DCB2F0	5931 952603	IVAN ALEKSEEV	{"email": "i_alekseev.011976@postgrespro.ru", "phone": "+70342963326"}
0005435041456	93E0AD	7866 563512	LYUDMILA TITOVA	{"phone": "+70630445188"}
0005435041457	93E0AD	5670 655576	DMITRIY MEDVEDEV	{"email": "d.medvedev.111967@postgrespro.ru", "phone": "+70115120803"}
0005435041458	0EF915	3809 874855	EKATERINA SMIRNOVA	{"email": "ekaterina-smirnova_1970@postgrespro.ru", "phone": "+70835209505"}
0005435041459	487489	0215 484313	OLGA KISELEVA	{"phone": "+70624285345"}
0005435041460	9054D2	3563 382306	ALEKSEY IVANOV	{"phone": "+70118101007"}
0005435041461	B39022	0274 415933	YURIY BARANOV	{"phone": "+70144298536"}
0005435041462	83B336	4121 396443	GALINA IVANOVA	{"email": "ivanova-g.1978@postgrespro.ru", "phone": "+70372642235"}
0005435041463	83B336	3685 360155	YULIYA TIMOFEEVA	{"email": "yuliyatimofeeva.021975@postgrespro.ru", "phone": "+70524812854"}
0005435041464	94B442	9136 436872	NATALIYA MIKHAYLOVA	{"phone": "+70025341929"}
0005435041465	94B442	5719 208225	ALEKSEY EGOROV	{"email": "egorov.aleksey_041968@postgrespro.ru", "phone": "+70997275663"}
0005435041466	94B442	0459 556325	ALEKSANDR TIMOFEEV	{"email": "a.timofeev_19081964@postgrespro.ru", "phone": "+70510992866"}
0005435041467	CA8A0E	7057 529309	LIDIYA IVANOVA	{"phone": "+70953184838"}
0005435041468	CA8A0E	9059 949276	ANASTASIYA KOROLEVA	{"email": "anastasiya_koroleva_1971@postgrespro.ru", "phone": "+70359481503"}
0005435041469	CA8A0E	0918 541343	GALINA VOLKOVA	{"phone": "+70567786567"}
0005435041470	71C935	4530 875996	TATYANA MASLOVA	{"email": "tatyana_maslova021979@postgrespro.ru", "phone": "+70521968559"}
0005435041471	71C935	5972 686531	ALEKSANDR NOVIKOV	{"phone": "+70395863351"}
0005435041472	71C935	0381 986022	MIKHAIL EGOROV	{"email": "megorov.101971@postgrespro.ru", "phone": "+70728705659"}
0005435041473	4F716D	0016 091845	ELENA TITOVA	{"email": "titovae_1979@postgrespro.ru", "phone": "+70546015487"}
0005435041474	D029A5	8567 994102	YULIYA ANDREEVA	{"phone": "+70481957821"}
0005435041475	D029A5	4350 825314	MAKSIM ALEKSEEV	{"phone": "+70806025041"}
0005435041476	6D2761	6475 987850	ELENA KUZMINA	{"email": "kuzminaelena.13111971@postgrespro.ru", "phone": "+70209831223"}
0005435041477	174BEF	7489 890722	PAVEL DMITRIEV	{"phone": "+70340395444"}
0005435041478	ADCAE7	3950 914860	VIKTOR MIRONOV	{"phone": "+70497329877"}
0005435041479	72DB83	5991 031406	VLADIMIR ZHUKOV	{"phone": "+70141286798"}
0005435041480	7F0BD8	4404 393115	ANNA KULIKOVA	{"email": "a.kulikova-1978@postgrespro.ru", "phone": "+70648851980"}
0005435041481	763135	4998 274417	SERGEY DAVYDOV	{"email": "davydov-sergey.25081981@postgrespro.ru", "phone": "+70639695111"}
0005435041482	C08767	2076 405845	VALERIY ILIN	{"email": "ilin-valeriy-1971@postgrespro.ru", "phone": "+70960111424"}
0005435041483	6D6170	6874 961447	TATYANA ZHUKOVA	{"phone": "+70106038236"}
0005435041484	225B66	4565 127518	ALEKSEY NAZAROV	{"phone": "+70916655869"}
0005435041485	84CE79	7627 154146	ANASTASIYA KULIKOVA	{"phone": "+70745370694"}
0005435041486	84CE79	8524 677464	DMITRIY VOLKOV	{"phone": "+70594400944"}
0005435041487	AA41B8	4401 196084	GENNADIY ROMANOV	{"phone": "+70082896561"}
0005435041488	A25043	2921 042340	OLGA KUDRYASHOVA	{"phone": "+70016116857"}
0005435041489	ACD339	1297 968611	NINA ROMANOVA	{"email": "nina_romanova-04041975@postgrespro.ru", "phone": "+70110609373"}
0005435041490	1D4DAF	7983 560052	ELENA TIKHONOVA	{"phone": "+70083305285"}
0005435041491	B3E9C9	5146 368948	ANTON SCHERBAKOV	{"email": "anton_scherbakov.091983@postgrespro.ru", "phone": "+70675612134"}
0005435041492	B3E9C9	4966 406669	ALEKSANDR FEDOROV	{"phone": "+70009358792"}
0005435041493	3E0C28	9594 422463	ALENA SEMENOVA	{"email": "semenova_alena-20061953@postgrespro.ru", "phone": "+70367683732"}
0005435041494	F4B1E3	9181 617717	ALEKSANDR NAUMOV	{"phone": "+70007721010"}
0005435041495	F4B1E3	9481 525770	ELENA KUZNECOVA	{"email": "e-kuznecova121975@postgrespro.ru", "phone": "+70384543440"}
0005435041496	BCBA36	2684 594378	GALINA GORBUNOVA	{"email": "galina.gorbunova-19071973@postgrespro.ru", "phone": "+70769554958"}
0005435041497	1EC628	3805 217984	IRINA POPOVA	{"email": "irina_popova011972@postgrespro.ru", "phone": "+70260456238"}
0005435041498	E6FFD1	7830 588502	ALBERT ZAKHAROV	{"email": "zakharov.albert.22021967@postgrespro.ru", "phone": "+70328076486"}
0005435041499	E6FFD1	6171 425236	ANNA CHERNOVA	{"email": "chernova-a05101971@postgrespro.ru", "phone": "+70048103679"}
0005435041500	D48DDF	4662 689912	NATALYA VASILEVA	{"email": "vasilevanatalya_26061963@postgrespro.ru", "phone": "+70285750740"}
0005435041501	D48DDF	9892 279704	VIKTORIYA MELNIKOVA	{"phone": "+70258227536"}
0005435041557	604006	2474 833109	DARYA NIKOLAEVA	{"phone": "+70217535135"}
0005435041502	F5F025	4916 587348	ROMAN KUZNECOV	{"email": "r_kuznecov091975@postgrespro.ru", "phone": "+70101441112"}
0005435041503	63C035	0904 594748	ANNA CHERNOVA	{"email": "chernova.a-081963@postgrespro.ru", "phone": "+70151637584"}
0005435041504	2BA982	4399 817412	OLGA MELNIKOVA	{"phone": "+70301928072"}
0005435041505	322A6C	0068 686357	NATALYA TIKHONOVA	{"email": "n.tikhonova.1972@postgrespro.ru", "phone": "+70318598712"}
0005435041506	322A6C	5320 494048	IVAN MOROZOV	{"email": "morozovi_25021968@postgrespro.ru", "phone": "+70928004618"}
0005435041507	0707AA	5809 616420	SVETLANA FROLOVA	{"email": "svetlana-frolova_081973@postgrespro.ru", "phone": "+70600178943"}
0005435041508	0707AA	6886 065465	DMITRIY PETROV	{"email": "dmitriy.petrov1983@postgrespro.ru", "phone": "+70535460006"}
0005435041509	7F5F54	8922 805733	ALEKSANDR EGOROV	{"phone": "+70336900217"}
0005435041510	BFF3C7	6122 099892	DMITRIY ALEKSANDROV	{"phone": "+70554915869"}
0005435041511	1C5792	0269 961962	YURIY ZHUKOV	{"email": "yzhukov_02121971@postgrespro.ru", "phone": "+70690115163"}
0005435041512	0E53CD	2532 815620	IVAN IVANOV	{"phone": "+70875574397"}
0005435041513	4EF259	6093 808221	ALEKSANDR MELNIKOV	{"email": "melnikov_aleksandr-091968@postgrespro.ru", "phone": "+70836220894"}
0005435041514	4EF259	8197 190686	ALEKSANDR KONOVALOV	{"email": "a-konovalov-19021972@postgrespro.ru", "phone": "+70937945652"}
0005435041515	1C9D8E	7770 280961	VARVARA ISAEVA	{"email": "isaeva.v.021973@postgrespro.ru", "phone": "+70177817343"}
0005435041516	F78938	6585 152580	ZOYA VASILEVA	{"phone": "+70330399135"}
0005435041517	F78938	2318 309569	ARTEM SEMENOV	{"email": "semenovartem.091982@postgrespro.ru", "phone": "+70226975544"}
0005435041518	E54F63	1100 949563	YURIY KOROLEV	{"email": "korolevyuriy_051967@postgrespro.ru", "phone": "+70876533516"}
0005435041519	1D74A6	3096 603358	MARINA TROFIMOVA	{"email": "m.trofimova_1965@postgrespro.ru", "phone": "+70845661827"}
0005435041520	4ABFFF	1261 338336	LYUBOV TIMOFEEVA	{"email": "timofeeva-l_10011974@postgrespro.ru", "phone": "+70051090775"}
0005435041521	D9704F	2605 313890	ALEKSEY BORISOV	{"email": "a_borisov_111979@postgrespro.ru", "phone": "+70240203352"}
0005435041522	D9704F	7747 868765	ALEKSEY BORISOV	{"email": "a-borisov.26111966@postgrespro.ru", "phone": "+70747767908"}
0005435041523	FB6FB3	0523 015229	ELENA KALININA	{"phone": "+70751475994"}
0005435041524	C439BF	3417 269180	DARYA ERMAKOVA	{"email": "ermakova-d.081973@postgrespro.ru", "phone": "+70678727774"}
0005435041525	565DED	6477 657097	ANATOLIY PETROV	{"phone": "+70504258108"}
0005435041526	73E6C4	9273 480474	DIANA RODIONOVA	{"phone": "+70601092146"}
0005435041527	73E6C4	9300 702608	VIKTORIYA MAKSIMOVA	{"email": "v.maksimova-021977@postgrespro.ru", "phone": "+70240889616"}
0005435041528	B70BE9	1930 422211	ALEKSANDR KARPOV	{"phone": "+70075963623"}
0005435041529	EE6A43	5844 694907	VALERIY SIDOROV	{"email": "sidorovvaleriy.1974@postgrespro.ru", "phone": "+70235657174"}
0005435041530	401DEF	2496 668267	MARIYA NESTEROVA	{"phone": "+70076627412"}
0005435041531	401DEF	3663 232466	SVETLANA KOVALEVA	{"phone": "+70662121744"}
0005435041532	401DEF	3209 806895	ALFIYA NESTEROVA	{"email": "alfiya-nesterova_1980@postgrespro.ru", "phone": "+70216307268"}
0005435041533	61365A	9017 522230	IVAN ALEKSEEV	{"email": "ivan_alekseev02051971@postgrespro.ru", "phone": "+70286430848"}
0005435041534	965970	5928 139143	LARISA FILATOVA	{"email": "filatova-l_1973@postgrespro.ru", "phone": "+70086243340"}
0005435041535	FAB3C9	8821 647364	EVGENIY KAZAKOV	{"email": "kazakovevgeniy_1969@postgrespro.ru", "phone": "+70384912794"}
0005435041536	4DB160	7750 827633	TATYANA TIMOFEEVA	{"email": "t-timofeeva-1962@postgrespro.ru", "phone": "+70230461257"}
0005435041537	4DB160	1975 353816	VERA BORISOVA	{"email": "v_borisova1962@postgrespro.ru", "phone": "+70476769533"}
0005435041538	16EF39	3951 487801	ALEKSANDR TIKHONOV	{"email": "tikhonov-a.02101972@postgrespro.ru", "phone": "+70711630905"}
0005435041539	EA0B7D	9585 581450	KONSTANTIN GUSEV	{"phone": "+70386140355"}
0005435041540	DB33CA	0498 658984	ARTEM BONDARENKO	{"phone": "+70308072606"}
0005435041541	7EFD9C	2685 455823	VIKTORIYA FEDOROVA	{"email": "viktoriya_fedorova111990@postgrespro.ru", "phone": "+70959403084"}
0005435041542	206209	5640 343065	INNA SCHERBAKOVA	{"email": "scherbakovainna_121966@postgrespro.ru", "phone": "+70532044798"}
0005435041543	57EA75	4356 416417	DMITRIY MATVEEV	{"email": "dmitriy.matveev-1976@postgrespro.ru", "phone": "+70285754177"}
0005435041544	C99A2E	2606 788168	GALINA POPOVA	{"phone": "+70531799883"}
0005435041545	8FBC2D	5373 772481	ALEKSANDR KUZNECOV	{"email": "akuznecov_1962@postgrespro.ru", "phone": "+70598218659"}
0005435041546	62881E	5464 048498	MARIYA ANDREEVA	{"email": "mariyaandreeva-1979@postgrespro.ru", "phone": "+70648486820"}
0005435041547	62881E	1307 357921	ELIZAVETA DAVYDOVA	{"phone": "+70873705090"}
0005435041548	69F8C6	5549 366876	ALEKSANDR NAUMOV	{"phone": "+70317661922"}
0005435041549	CC6A77	5098 388950	DANILA ANTONOV	{"email": "danila_antonov-16101975@postgrespro.ru", "phone": "+70493503330"}
0005435041550	8FF21D	7002 912509	ELENA ILINA	{"phone": "+70232607356"}
0005435041551	7F3B49	6934 389036	VASILIY MIKHAYLOV	{"email": "mikhaylov_v1973@postgrespro.ru", "phone": "+70686205371"}
0005435041552	7F3B49	1500 298875	NATALYA MAKAROVA	{"phone": "+70590229599"}
0005435041553	E7B262	8918 457532	ALEKSANDRA ISAEVA	{"phone": "+70769558444"}
0005435041554	E7B262	6182 579091	IRINA MARTYNOVA	{"phone": "+70504373760"}
0005435041555	E7B262	1367 120779	EKATERINA POTAPOVA	{"phone": "+70970900971"}
0005435041556	79B97E	6776 559759	OKSANA FROLOVA	{"phone": "+70660026533"}
0005435041558	1A83E2	7574 913415	MIKHAIL BORISOV	{"email": "m.borisov_25091972@postgrespro.ru", "phone": "+70774229324"}
0005435041559	05C804	9276 714591	YULIYA VOLKOVA	{"email": "yvolkova061977@postgrespro.ru", "phone": "+70684147949"}
0005435041560	143F33	2311 363115	IVAN PAVLOV	{"email": "i.pavlov-1969@postgrespro.ru", "phone": "+70601921001"}
0005435041561	048B95	2892 961573	LYUDMILA VASILEVA	{"phone": "+70032289566"}
0005435041562	E06B25	5432 848753	DMITRIY ZHURAVLEV	{"phone": "+70045739281"}
0005435041563	8B6EAB	6223 104692	SERGEY VASILEV	{"phone": "+70059319417"}
0005435041564	8B6EAB	3634 961668	ALEKSANDR OSIPOV	{"email": "aosipov.061979@postgrespro.ru", "phone": "+70012684407"}
0005435041565	AFF319	8466 571280	VITALIY KUDRYASHOV	{"phone": "+70717664939"}
0005435041566	AFF319	2774 693331	AYRAT MAKSIMOV	{"phone": "+70298149371"}
0005435041567	AFF319	8669 099538	VLADIMIR BONDARENKO	{"phone": "+70623693962"}
0005435041568	AFF319	1338 219683	VERA KISELEVA	{"email": "v.kiseleva.13061972@postgrespro.ru", "phone": "+70370079823"}
0005435041569	0F1111	9176 466785	MAKSIM MAKAROV	{"phone": "+70678946312"}
0005435041570	B1D874	3393 497842	ELENA LAZAREVA	{"email": "lazareva.e-28121976@postgrespro.ru", "phone": "+70135589902"}
0005435041571	33B894	8366 951902	VIKTORIYA STEPANOVA	{"email": "stepanova.v.021978@postgrespro.ru", "phone": "+70112818936"}
0005435041572	33B894	1154 721931	ANTONINA SIDOROVA	{"email": "sidorova-a.1968@postgrespro.ru", "phone": "+70383544510"}
0005435041573	1307F9	9673 385149	VALENTINA TITOVA	{"email": "titova.v_28061961@postgrespro.ru", "phone": "+70755682175"}
0005435041574	1307F9	9734 530768	SOFYA SCHERBAKOVA	{"phone": "+70672049228"}
0005435041575	1307F9	9701 729762	NIKOLAY KARPOV	{"email": "karpovn-1971@postgrespro.ru", "phone": "+70257336536"}
0005435041576	FBC86D	0952 204091	ROMAN AFANASEV	{"email": "afanasev-roman.1979@postgrespro.ru", "phone": "+70887128771"}
0005435041577	262805	1273 705022	VLADISLAV DMITRIEV	{"email": "dmitriev_v_031964@postgrespro.ru", "phone": "+70734303401"}
0005435041578	262805	8177 509188	VERA ZOTOVA	{"email": "zotova.v_1961@postgrespro.ru", "phone": "+70411737429"}
0005435041579	E6B010	4090 419521	OLEG IVANOV	{"phone": "+70290758657"}
0005435041580	E0C148	5630 302738	VIKTORIYA FEDOROVA	{"email": "viktoriya_fedorova_07121975@postgrespro.ru", "phone": "+70117273853"}
0005435041581	E0C148	8683 704521	VIKTOR NAZAROV	{"phone": "+70929264952"}
0005435041582	7D43AA	5937 457648	VIKTOR GORBUNOV	{"email": "gorbunovviktor_1979@postgrespro.ru", "phone": "+70430813811"}
0005435041583	7D43AA	0567 350026	ANASTASIYA KOVALEVA	{"phone": "+70483363045"}
0005435041584	C89BE3	8301 101621	ALEKSANDRA SMIRNOVA	{"phone": "+70506981443"}
0005435041585	2BDD5B	5667 091465	SERGEY KUZNECOV	{"email": "kuznecov.sergey01101961@postgrespro.ru", "phone": "+70031552333"}
0005435041586	7DCA0C	5380 663011	KIRA MATVEEVA	{"phone": "+70445813066"}
0005435041587	7DCA0C	6845 505046	RUSLAN ABRAMOV	{"email": "abramov_ruslan011973@postgrespro.ru", "phone": "+70696963661"}
0005435041588	089941	0764 760608	VALENTINA POLYAKOVA	{"phone": "+70357095811"}
0005435041589	089941	0406 703711	ELENA VASILEVA	{"phone": "+70162090419"}
0005435041590	650175	4439 199154	TATYANA PETROVA	{"phone": "+70536308590"}
0005435041591	650175	4758 279895	ANDREY VOLKOV	{"email": "volkova.22061969@postgrespro.ru", "phone": "+70546689394"}
0005435041592	2D3DB9	9040 772219	ANNA PETROVA	{"phone": "+70865327006"}
0005435041593	00579F	6499 191219	LYUBOV VLASOVA	{"email": "lyubov.vlasova-031965@postgrespro.ru", "phone": "+70358392125"}
0005435041594	F454F6	3564 479654	SERGEY ZAKHAROV	{"phone": "+70577074608"}
0005435041595	F454F6	2193 635742	ALEKSEY DAVYDOV	{"phone": "+70980467297"}
0005435041596	C7B679	3658 595221	VLADIMIR VASILEV	{"email": "vasilev.v061968@postgrespro.ru", "phone": "+70989053415"}
0005435041597	AFB9DE	6843 780728	SVETLANA FEDOROVA	{"phone": "+70566794400"}
0005435041598	AFB9DE	0887 524037	ELENA NESTEROVA	{"email": "nesterova.elena-031971@postgrespro.ru", "phone": "+70158758453"}
0005435041599	14E7DC	1208 112247	VLADIMIR ISAEV	{"email": "vladimir-isaev-1970@postgrespro.ru", "phone": "+70937675538"}
0005435041600	9A213D	1338 158239	VLADIMIR KONOVALOV	{"phone": "+70069301888"}
0005435041601	9A213D	3947 262164	PELAGEYA SMIRNOVA	{"phone": "+70492974295"}
0005435041602	9253AF	9790 436577	ALEKSEY KRASNOV	{"email": "aleksey_krasnov_1978@postgrespro.ru", "phone": "+70294445820"}
0005435041603	9253AF	8285 469097	NIKOLAY NOVIKOV	{"email": "novikov.n_071960@postgrespro.ru", "phone": "+70042492093"}
0005435041604	1825A2	6715 706765	EKATERINA KARPOVA	{"phone": "+70727902861"}
0005435041605	FE545D	8486 378222	NATALYA FILIPPOVA	{"phone": "+70783220513"}
0005435041606	FEFFAB	8629 103076	LARISA PETROVA	{"email": "l-petrova_1972@postgrespro.ru", "phone": "+70518053226"}
0005435041607	A0693D	0888 393480	ANTONINA KUZNECOVA	{"phone": "+70277794298"}
0005435041608	EF6F93	9823 094987	ANATOLIY NOVIKOV	{"email": "novikova-12051974@postgrespro.ru", "phone": "+70877929735"}
0005435041609	EF6F93	6948 538136	VALENTINA OSIPOVA	{"email": "osipova.valentina_071967@postgrespro.ru", "phone": "+70587757976"}
0005435041610	627595	9526 382927	VLADISLAV MAKAROV	{"phone": "+70361583539"}
0005435041611	A26CB8	7349 959310	VASILIY PAVLOV	{"email": "v.pavlov-1970@postgrespro.ru", "phone": "+70617383032"}
0005435041612	EF3133	4218 461828	ALEKSEY NAZAROV	{"email": "nazarov.aleksey_15071973@postgrespro.ru", "phone": "+70883566718"}
0005435041613	EF3133	7955 960231	EKATERINA MASLOVA	{"phone": "+70221178595"}
0005435041614	E51E9B	4520 426783	VIKTOR KARPOV	{"phone": "+70717974263"}
0005435041615	DE026C	6052 113801	IGOR KOZLOV	{"email": "igor-kozlov_091974@postgrespro.ru", "phone": "+70425969799"}
0005435041616	DE026C	5865 168799	NINA KAZAKOVA	{"email": "nina-kazakova_1963@postgrespro.ru", "phone": "+70547345727"}
0005435041617	10CB39	9223 007725	MIKHAIL ILIN	{"phone": "+70408832868"}
0005435041618	F63169	5198 928378	EVGENIYA YUDINA	{"email": "yudina.evgeniya.081966@postgrespro.ru", "phone": "+70516522058"}
0005435041619	F63169	5615 620579	LYUDMILA ANISIMOVA	{"email": "lyudmila-anisimova-111985@postgrespro.ru", "phone": "+70291785904"}
0005435041620	9D5870	1194 232711	YURIY MELNIKOV	{"email": "melnikovy_111975@postgrespro.ru", "phone": "+70719780826"}
0005435041621	9D5870	6564 174307	SERGEY CHERNOV	{"email": "s.chernov_071976@postgrespro.ru", "phone": "+70611789402"}
0005435041622	62D707	6831 928360	VERA BORISOVA	{"phone": "+70800150151"}
0005435041623	62D707	8449 227527	TAGIR KUZNECOV	{"email": "t.kuznecov-07021971@postgrespro.ru", "phone": "+70716073490"}
0005435041624	62D707	2813 036538	SERGEY SOLOVEV	{"email": "solovev-sergey.09091975@postgrespro.ru", "phone": "+70694488741"}
0005435041625	9728A4	6919 368437	TATYANA DMITRIEVA	{"phone": "+70877827027"}
0005435041626	4BDB99	3200 344531	LYUDMILA TARASOVA	{"email": "l_tarasova02111974@postgrespro.ru", "phone": "+70301805853"}
0005435041627	739F42	0483 810940	ANNA GERASIMOVA	{"email": "gerasimova.anna-1953@postgrespro.ru", "phone": "+70545479128"}
0005435041628	739F42	4644 923250	NINA MEDVEDEVA	{"email": "nina.medvedeva-11111966@postgrespro.ru", "phone": "+70607600665"}
0005435041629	0EED19	0883 846120	GALINA DENISOVA	{"phone": "+70791656875"}
0005435041630	189CDF	3006 816827	SERGEY SERGEEV	{"email": "sergey-sergeev_061983@postgrespro.ru", "phone": "+70722162721"}
0005435041631	189CDF	6497 745601	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova-aleksandra-111967@postgrespro.ru", "phone": "+70246129406"}
0005435041632	334856	9111 612725	ILDAR KUZMIN	{"phone": "+70317665477"}
0005435041633	5637B2	6350 382160	TAISA RODIONOVA	{"email": "t-rodionova_011977@postgrespro.ru", "phone": "+70345605269"}
0005435041634	A6A004	2464 056603	DANILA DMITRIEV	{"phone": "+70304645844"}
0005435041635	A6A004	1786 862835	OLGA IVANOVA	{"phone": "+70854386549"}
0005435041636	2FACCB	2214 294296	ELVIRA SOROKINA	{"email": "sorokina.e091961@postgrespro.ru", "phone": "+70853354397"}
0005435041637	2FACCB	2488 310221	SALAVAT PETROV	{"phone": "+70039580788"}
0005435041638	AE726D	2420 729154	ANASTASIYA KALININA	{"phone": "+70708337542"}
0005435041639	AE726D	1672 909821	YURIY STEPANOV	{"email": "y.stepanov041966@postgrespro.ru", "phone": "+70848660228"}
0005435041640	E71667	3799 592862	TATYANA STEPANOVA	{"email": "stepanova_t.1970@postgrespro.ru", "phone": "+70759810175"}
0005435041641	27859B	3227 707579	VALENTINA KAZAKOVA	{"phone": "+70079309944"}
0005435041642	65AA9A	3930 263073	VITALIY IVANOV	{"phone": "+70910048620"}
0005435041643	65FF9F	3261 805308	BORIS KISELEV	{"phone": "+70248170675"}
0005435041644	CEA6C8	7356 524292	VLADIMIR KUZNECOV	{"email": "kuznecov-v_101965@postgrespro.ru", "phone": "+70291618270"}
0005435041645	E1E9F8	6503 788652	GALIYA DENISOVA	{"phone": "+70575873389"}
0005435041646	DD560A	2254 394039	YURIY GERASIMOV	{"email": "gerasimov.y_031969@postgrespro.ru", "phone": "+70855835827"}
0005435041647	DD560A	3975 645355	NIKITA BELOV	{"email": "belov.nikita.1962@postgrespro.ru", "phone": "+70227966413"}
0005435041648	098F88	1294 522348	IGOR ANDREEV	{"phone": "+70135532517"}
0005435041649	098F88	9554 641199	RAVIL NIKOLAEV	{"email": "nikolaev.r_13101969@postgrespro.ru", "phone": "+70177842846"}
0005435041650	F4BF95	3372 866759	IRINA EFREMOVA	{"email": "iefremova07091969@postgrespro.ru", "phone": "+70131995591"}
0005435041651	DD5FE7	0556 653403	NIKOLAY ANTONOV	{"phone": "+70646330544"}
0005435041652	12F65E	0754 218467	FEDOR FOMIN	{"phone": "+70966611971"}
0005435041653	12F65E	2127 702764	IVAN KISELEV	{"email": "kiselev_i1974@postgrespro.ru", "phone": "+70843127264"}
0005435041654	46467F	8056 682029	MARINA FROLOVA	{"email": "mfrolova051960@postgrespro.ru", "phone": "+70492952055"}
0005435041655	5B4C56	8265 502027	ALISA FILATOVA	{"email": "filatova.a_1959@postgrespro.ru", "phone": "+70572623892"}
0005435041656	54811E	3305 403516	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr_15051967@postgrespro.ru", "phone": "+70593825519"}
0005435041657	668EC3	2234 874775	ALEKSANDR IVANOV	{"phone": "+70045066146"}
0005435041658	C421C1	8073 783881	ALEKSEY RODIONOV	{"phone": "+70914053617"}
0005435041659	82941D	6556 564345	VLADISLAV KOZLOV	{"phone": "+70747684805"}
0005435041660	8CBECE	6647 942784	VITALIY KOROLEV	{"phone": "+70712725512"}
0005435041661	8CBECE	5617 386172	LYUBOV GRISHINA	{"phone": "+70572579649"}
0005435041662	36EFBF	8410 017469	VIKTORIYA ISAEVA	{"phone": "+70178644495"}
0005435041663	37E30A	5662 897319	IRINA MAKAROVA	{"phone": "+70438084412"}
0005435041664	867D21	4722 482127	VLADISLAV FEDOROV	{"email": "fedorovvladislav.1971@postgrespro.ru", "phone": "+70252117831"}
0005435041665	E07AB1	7811 731011	NADEZHDA SAVELEVA	{"phone": "+70923155522"}
0005435041666	B8A47B	1396 175475	ALEKSEY PETROV	{"email": "petrov_a.14061979@postgrespro.ru", "phone": "+70963475611"}
0005435041667	85CDE7	4810 497999	LARISA FEDOROVA	{"phone": "+70234291948"}
0005435041668	FED61B	1708 842985	MARIYA TIMOFEEVA	{"phone": "+70042839308"}
0005435041669	FED61B	3246 448006	ROMAN PAVLOV	{"email": "pavlovr_1979@postgrespro.ru", "phone": "+70790099871"}
0005435041670	3E5686	8523 713206	ALEKSANDR EGOROV	{"email": "egorov-aleksandr-1964@postgrespro.ru", "phone": "+70421183482"}
0005435041671	2BA255	0905 585057	ANATOLIY ROMANOV	{"phone": "+70537610282"}
0005435041672	6F1009	2163 836120	ELENA AKIMOVA	{"email": "e.akimova05031967@postgrespro.ru", "phone": "+70983431996"}
0005435041673	A21B6D	4440 520165	PETR SEMENOV	{"phone": "+70794414392"}
0005435041674	A21B6D	1107 871360	PETR SAVELEV	{"phone": "+70773342853"}
0005435041675	A21B6D	4453 719188	ANNA SOROKINA	{"phone": "+70682960392"}
0005435041676	60A74A	5520 619024	MARIYA KALININA	{"phone": "+70770421262"}
0005435041677	60A74A	7158 472514	DARYA VOROBEVA	{"email": "vorobeva.d_03011963@postgrespro.ru", "phone": "+70360245268"}
0005435041678	38E9EE	0084 503191	SERGEY VOROBEV	{"email": "s_vorobev-1963@postgrespro.ru", "phone": "+70468617347"}
0005435041679	0ED703	9867 487183	VERA KUZNECOVA	{"email": "kuznecova_vera27121968@postgrespro.ru", "phone": "+70561945231"}
0005435041680	7B0247	3329 809991	NIKOLAY MELNIKOV	{"email": "n-melnikov1975@postgrespro.ru", "phone": "+70801013933"}
0005435041681	4A9A3D	5369 469423	ALEKSANDR TIKHONOV	{"email": "a.tikhonov-12091972@postgrespro.ru", "phone": "+70485414525"}
0005435041682	4A9A3D	7852 593797	VLADIMIR IVANOV	{"email": "v_ivanov_041974@postgrespro.ru", "phone": "+70981382392"}
0005435041683	77B914	9973 203135	ARSENIY ZAYCEV	{"phone": "+70175777438"}
0005435041684	77B914	9387 898270	OLEG SEMENOV	{"email": "semenov-o-061971@postgrespro.ru", "phone": "+70016684582"}
0005435041685	77B914	4826 526506	ALENA MAKSIMOVA	{"phone": "+70898500434"}
0005435041686	5FEB6E	9838 824995	VLADIMIR STEPANOV	{"email": "stepanov_vladimir-121974@postgrespro.ru", "phone": "+70055243774"}
0005435041687	5FEB6E	3867 736406	NATALYA ZHURAVLEVA	{"phone": "+70290429919"}
0005435041688	F46DFD	3576 887154	ZINAIDA SOROKINA	{"email": "z-sorokina.13101954@postgrespro.ru", "phone": "+70230681052"}
0005435041689	148B59	0093 807061	ALEKSANDR FEDOROV	{"phone": "+70070153966"}
0005435041690	F440EE	3276 380622	MARIYA IVANOVA	{"phone": "+70496468772"}
0005435041691	904B8B	4244 839198	DMITRIY KOZLOV	{"email": "dmitriy_kozlov_031975@postgrespro.ru", "phone": "+70444764848"}
0005435041692	904B8B	0638 770567	MARIYA ROMANOVA	{"phone": "+70510014823"}
0005435041693	D8AD23	8962 729826	LYUBOV MIKHAYLOVA	{"phone": "+70005711436"}
0005435041694	D8AD23	6244 940610	STANISLAV NAUMOV	{"email": "s.naumov-13101964@postgrespro.ru", "phone": "+70329076515"}
0005435041695	EC9964	3439 970979	ANNA EFIMOVA	{"email": "a_efimova02121974@postgrespro.ru", "phone": "+70745739281"}
0005435041696	EA984F	6401 901734	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr091975@postgrespro.ru", "phone": "+70555153501"}
0005435041697	81C1C9	2561 213610	ELISEY GORBUNOV	{"email": "gorbunov-e1967@postgrespro.ru", "phone": "+70273490316"}
0005435041698	75435E	2153 142463	IVAN MOROZOV	{"email": "i_morozov-21061959@postgrespro.ru", "phone": "+70509899515"}
0005435041699	75435E	9398 269626	ANDREY VOLKOV	{"email": "volkov-andrey30031969@postgrespro.ru", "phone": "+70938183743"}
0005435041700	0CF8D1	5319 582799	YURIY TARASOV	{"phone": "+70697038367"}
0005435041701	7B3F03	3542 554029	GALINA PETROVA	{"email": "petrovagalina-1971@postgrespro.ru", "phone": "+70979028508"}
0005435042896	353A7C	7615 167367	EVGENIY KUZNECOV	{"phone": "+70294364936"}
0005435042820	1EFB9A	5575 021523	VLADISLAV FROLOV	{"email": "frolov_v-19021981@postgrespro.ru", "phone": "+70686334690"}
0005435042821	A8E451	4090 397389	YULIYA ANISIMOVA	{"email": "y.anisimova061973@postgrespro.ru", "phone": "+70552534408"}
0005435042822	A8E451	8232 736049	YURIY FOMIN	{"phone": "+70171569301"}
0005435042823	CDD5EE	8768 585099	IVAN TIMOFEEV	{"phone": "+70518941528"}
0005435042824	1BF2DB	6883 125288	EVGENIY PETROV	{"email": "petrove-1978@postgrespro.ru", "phone": "+70049433407"}
0005435042825	1BF2DB	7256 739847	ANDREY MAKSIMOV	{"email": "a_maksimov_021978@postgrespro.ru", "phone": "+70703583132"}
0005435042826	DA7E1E	9222 554060	VADIM IVANOV	{"phone": "+70861779796"}
0005435042827	DA7E1E	8593 398771	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-aleksandr-04111966@postgrespro.ru", "phone": "+70813850285"}
0005435042828	4A396E	3853 829388	ELVIRA SCHERBAKOVA	{"email": "scherbakova-e_061977@postgrespro.ru", "phone": "+70850448700"}
0005435042829	6F72C4	0528 794226	OLGA SERGEEVA	{"phone": "+70817243245"}
0005435042830	6F72C4	5267 260134	DARYA DMITRIEVA	{"email": "dmitrieva.darya.011973@postgrespro.ru", "phone": "+70006545011"}
0005435042831	A82854	5314 566634	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila_021977@postgrespro.ru", "phone": "+70919759677"}
0005435042832	A82854	7906 777580	RINAT VLASOV	{"phone": "+70250612980"}
0005435042833	51AFEB	7783 250872	DMITRIY ZAKHAROV	{"phone": "+70177160858"}
0005435042834	DC3252	3495 613514	TATYANA FROLOVA	{"phone": "+70022319518"}
0005435042835	210DEB	4493 176103	ELENA VOROBEVA	{"email": "vorobevaelena1970@postgrespro.ru", "phone": "+70381619804"}
0005435042836	210DEB	3196 057657	DIANA SAVELEVA	{"phone": "+70323194803"}
0005435042837	FF031A	4463 680522	ALEKSANDR ALEKSEEV	{"phone": "+70291646849"}
0005435042838	5ADFB1	6382 299870	EVGENIY POPOV	{"phone": "+70198366694"}
0005435042839	8E42E5	5180 518744	ALEKSEY SAVELEV	{"email": "aleksey.savelev.06081966@postgrespro.ru", "phone": "+70190431617"}
0005435042840	1283B4	6456 832035	ALEKSEY ORLOV	{"email": "aleksey.orlov.08041987@postgrespro.ru", "phone": "+70934268054"}
0005435042841	E2BD88	0127 881363	ARTEM SOKOLOV	{"phone": "+70787590988"}
0005435042842	7DE720	9220 376778	ALEVTINA KRASNOVA	{"email": "krasnova.a_1963@postgrespro.ru", "phone": "+70572193766"}
0005435042843	8FD9A2	1798 375986	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy_031971@postgrespro.ru", "phone": "+70883696902"}
0005435042844	535668	7953 278931	VLADIMIR KOZLOV	{"phone": "+70976800556"}
0005435042845	908CCE	6619 833432	DMITRIY TIMOFEEV	{"phone": "+70891957415"}
0005435042846	02E66A	6344 535468	SERGEY KISELEV	{"phone": "+70513142617"}
0005435042847	959945	3790 321943	VASILIY RODIONOV	{"phone": "+70290589713"}
0005435042848	5E6CBB	0484 401960	OLGA LEBEDEVA	{"email": "lebedeva_olga08011972@postgrespro.ru", "phone": "+70324899339"}
0005435042849	802AB3	1955 482421	LYUDMILA MALYSHEVA	{"email": "l.malysheva101964@postgrespro.ru", "phone": "+70860395743"}
0005435042850	263E4D	7909 683321	LIYA GERASIMOVA	{"email": "gerasimovaliya-031979@postgrespro.ru", "phone": "+70633346690"}
0005435042851	263E4D	5242 551131	VERA DAVYDOVA	{"email": "vera_davydova_121974@postgrespro.ru", "phone": "+70351702012"}
0005435042852	8E4DE0	4166 086524	ALEKSANDR ALEKSANDROV	{"phone": "+70295843315"}
0005435042853	8E4DE0	3482 061143	VALENTINA KAZAKOVA	{"phone": "+70770359957"}
0005435042854	6E418F	8147 591814	MAKSIM IVANOV	{"phone": "+70161844850"}
0005435042855	6E418F	6552 944044	MARINA MALYSHEVA	{"phone": "+70526265348"}
0005435042856	7C05AD	8788 875452	TATYANA ZAKHAROVA	{"email": "zakharova.t.1976@postgrespro.ru", "phone": "+70527071990"}
0005435042857	7C05AD	6016 069419	TATYANA DAVYDOVA	{"email": "tatyana_davydova1979@postgrespro.ru", "phone": "+70623040054"}
0005435042858	F5C054	8934 359841	DANILA FOMIN	{"email": "fomin-d-1970@postgrespro.ru", "phone": "+70486138695"}
0005435042859	7B51F6	2716 274329	ANNA IVANOVA	{"phone": "+70671368856"}
0005435042860	E7DC0F	4632 843075	ANNA IVANOVA	{"phone": "+70227116239"}
0005435042861	B17725	7931 113789	ANASTASIYA NAZAROVA	{"phone": "+70117048074"}
0005435042862	B17725	2596 791264	MIKHAIL KAZAKOV	{"phone": "+70846492680"}
0005435042863	B17725	3028 242021	ANDREY MIKHAYLOV	{"phone": "+70777994649"}
0005435042864	01BB53	1705 298088	VLADISLAV MELNIKOV	{"email": "v.melnikov101970@postgrespro.ru", "phone": "+70502887741"}
0005435042865	FDDADD	3395 945329	STANISLAV GUSEV	{"phone": "+70145244114"}
0005435042866	462C50	3165 496975	EVGENIY SHEVCHENKO	{"email": "evgeniy_shevchenko1970@postgrespro.ru", "phone": "+70035116130"}
0005435042867	462C50	4257 129415	TATYANA ABRAMOVA	{"phone": "+70856623737"}
0005435042868	26E1F9	4756 775163	EKATERINA KUZNECOVA	{"phone": "+70634467186"}
0005435042869	00395B	7050 377883	SERAFIM KUZMIN	{"email": "kuzmin_s1967@postgrespro.ru", "phone": "+70643184997"}
0005435042870	00395B	9466 605235	NIKOLAY POPOV	{"phone": "+70204334334"}
0005435042871	E99EE2	3522 802777	OLGA SAVELEVA	{"email": "o_saveleva_24051968@postgrespro.ru", "phone": "+70108136489"}
0005435042872	FE19E9	6540 084433	EVGENIYA IVANOVA	{"phone": "+70189288200"}
0005435042873	FE19E9	9785 900518	NIKITA FROLOV	{"phone": "+70090146287"}
0005435042874	F6487D	6458 526669	LYUDMILA POTAPOVA	{"phone": "+70340823321"}
0005435042875	D6894B	7510 836727	SERGEY TARASOV	{"email": "s-tarasov.061971@postgrespro.ru", "phone": "+70558631510"}
0005435042876	0087F3	7191 714466	NIKOLAY DAVYDOV	{"email": "n-davydov03101977@postgrespro.ru", "phone": "+70633169350"}
0005435042877	A5FC46	7419 357761	GALINA KOZLOVA	{"email": "kozlovagalina_1967@postgrespro.ru", "phone": "+70894743733"}
0005435042878	D9A7D5	2348 818038	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov20081969@postgrespro.ru", "phone": "+70856370580"}
0005435042879	2F9EE2	5495 108339	LYUDMILA MARTYNOVA	{"phone": "+70683015318"}
0005435042880	2F9EE2	6325 486891	GLEB KOZLOV	{"email": "g.kozlov_22011981@postgrespro.ru", "phone": "+70845649492"}
0005435042881	2FBA8A	5912 837618	KSENIYA KALININA	{"email": "k.kalinina08021969@postgrespro.ru", "phone": "+70643858485"}
0005435042882	2FBA8A	8330 468584	VALENTINA SAVELEVA	{"phone": "+70663848745"}
0005435042883	2FBA8A	9998 660447	LIDIYA NIKOLAEVA	{"phone": "+70626613446"}
0005435042884	A9D2C8	0473 268024	NINA NAUMOVA	{"phone": "+70536276971"}
0005435042885	EBDA69	3803 867677	NIKITA IVANOV	{"phone": "+70038792327"}
0005435042886	034CBB	0445 397142	ANDREY TARASOV	{"email": "andrey.tarasov-1977@postgrespro.ru", "phone": "+70392112593"}
0005435042887	034CBB	5395 743582	IGOR MAKSIMOV	{"email": "i_maksimov061986@postgrespro.ru", "phone": "+70054216795"}
0005435042888	FE67E8	9247 144092	MIKHAIL VOLKOV	{"phone": "+70098331179"}
0005435042889	FE67E8	0205 111586	ELENA IVANOVA	{"phone": "+70241875467"}
0005435042890	5115E0	6885 067781	SERGEY POPOV	{"email": "sergey-popov.061963@postgrespro.ru", "phone": "+70553914816"}
0005435042891	5115E0	7902 439285	ANGELINA ORLOVA	{"email": "aorlova-22021976@postgrespro.ru", "phone": "+70428724305"}
0005435042892	872381	3680 564965	ANATOLIY IVANOV	{"phone": "+70879631303"}
0005435042893	73ADFE	1852 382030	OLEG DMITRIEV	{"email": "dmitrievo13021974@postgrespro.ru", "phone": "+70942122157"}
0005435042894	73ADFE	1760 825255	VITALIY GUSEV	{"phone": "+70869103162"}
0005435042895	353A7C	8071 987264	DMITRIY FEDOROV	{"phone": "+70608386901"}
0005435042897	B69BB3	6964 472621	VLADIMIR MAKAROV	{"email": "makarov.v.011978@postgrespro.ru", "phone": "+70449261583"}
0005435042898	9BB236	0287 080750	ALEVTINA DAVYDOVA	{"email": "a-davydova-091962@postgrespro.ru", "phone": "+70158949970"}
0005435042899	F69D27	2308 044324	LARISA ANDREEVA	{"phone": "+70999279507"}
0005435042900	7FF372	6680 415741	YULIYA SOKOLOVA	{"email": "ysokolova_10011985@postgrespro.ru", "phone": "+70934827728"}
0005435042901	6A86BB	7001 745572	SERGEY MELNIKOV	{"email": "melnikovsergey-31101975@postgrespro.ru", "phone": "+70989418045"}
0005435042902	3172AB	5418 611222	ANNA MASLOVA	{"phone": "+70944587945"}
0005435042903	87F039	0348 907380	ELENA POPOVA	{"email": "popova_elena.1957@postgrespro.ru", "phone": "+70224574714"}
0005435042904	87F039	9041 926063	ROMAN GRIGOREV	{"email": "grigorev_roman_011979@postgrespro.ru", "phone": "+70584886724"}
0005435042905	87F039	8030 372354	ANDREY PETROV	{"email": "petrovandrey.1967@postgrespro.ru", "phone": "+70036160222"}
0005435042906	34F695	4641 547252	YULIYA BELOVA	{"phone": "+70532898069"}
0005435042907	76E475	0360 023781	SERGEY MIRONOV	{"email": "s-mironov.071968@postgrespro.ru", "phone": "+70444685394"}
0005435042908	C3B2F7	6497 263414	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov-14121971@postgrespro.ru", "phone": "+70729831640"}
0005435042909	50A0B2	1551 914516	YULIYA KAZAKOVA	{"email": "yuliyakazakova.04051979@postgrespro.ru", "phone": "+70470587102"}
0005435042910	505E4F	0745 498229	SERGEY TIKHONOV	{"phone": "+70438060145"}
0005435042911	505E4F	7467 943570	MARINA KOROLEVA	{"phone": "+70527592882"}
0005435042912	0B13CB	0446 087019	IRINA ROMANOVA	{"phone": "+70156021994"}
0005435042913	0B13CB	9402 490056	YURIY DENISOV	{"email": "ydenisov.01121984@postgrespro.ru", "phone": "+70495496767"}
0005435042914	3DCE88	1222 933171	VLADIMIR FEDOTOV	{"phone": "+70776013958"}
0005435042915	32E685	1773 357488	SERGEY ISAEV	{"email": "s-isaev_1966@postgrespro.ru", "phone": "+70679814954"}
0005435042916	32E685	7187 101129	ANATOLIY FROLOV	{"email": "frolova.23021966@postgrespro.ru", "phone": "+70564363586"}
0005435042917	02FF73	5081 245897	ALEKSANDR ZAYCEV	{"email": "zaycev_a-081973@postgrespro.ru", "phone": "+70066096400"}
0005435042918	C3B9F9	5742 671291	VERA FEDOROVA	{"phone": "+70141876541"}
0005435042919	E77182	1152 792413	PETR SHEVCHENKO	{"phone": "+70369671438"}
0005435042920	0C1134	3093 144096	OLGA ILINA	{"email": "ilina_olga.19111983@postgrespro.ru", "phone": "+70543134587"}
0005435042921	0C1134	1297 526984	LYUBOV IVANOVA	{"email": "livanova_31081970@postgrespro.ru", "phone": "+70388555036"}
0005435042922	A0C5C3	1919 108062	EKATERINA KULIKOVA	{"phone": "+70905951520"}
0005435042923	A0C5C3	6166 080060	DINARA KULIKOVA	{"phone": "+70660422941"}
0005435042924	AE3C7C	4811 170804	SVETLANA MAKAROVA	{"email": "svetlana-makarova-13051963@postgrespro.ru", "phone": "+70186843136"}
0005435042925	402480	7179 064859	IGOR ANTONOV	{"email": "antonov_i.06101975@postgrespro.ru", "phone": "+70041182517"}
0005435042926	9BE9FC	0175 296291	TAISA ZAKHAROVA	{"phone": "+70025019922"}
0005435042927	2C3D73	7463 878860	MARIANNA KRASNOVA	{"email": "marianna_krasnova-26101973@postgrespro.ru", "phone": "+70465651556"}
0005435042928	2C3D73	4029 407232	VIKTORIYA MOROZOVA	{"phone": "+70063394087"}
0005435042929	ECFE7A	7939 236526	VASILIY ANDREEV	{"email": "andreev_v.081975@postgrespro.ru", "phone": "+70028282532"}
0005435042930	ECFE7A	0444 330061	SVETLANA ZAKHAROVA	{"phone": "+70880935517"}
0005435042931	C1A44C	2360 862463	ILYA PAVLOV	{"email": "pavlovilya1978@postgrespro.ru", "phone": "+70004391381"}
0005435042932	C1A44C	4806 640380	ANATOLIY EGOROV	{"email": "egorov-a.20081962@postgrespro.ru", "phone": "+70795691763"}
0005435042933	C1A44C	3771 806238	ALEKSANDR SIDOROV	{"phone": "+70092240672"}
0005435042934	344AFD	4873 884352	VALERIY VOLKOV	{"email": "volkov.valeriy-1976@postgrespro.ru", "phone": "+70922014223"}
0005435042935	344AFD	8012 612038	KIRILL ROMANOV	{"email": "romanovkirill-1978@postgrespro.ru", "phone": "+70232346311"}
0005435042936	15FA68	6152 741694	TIMUR MAKAROV	{"phone": "+70422208331"}
0005435042937	10FA09	1070 588244	OLGA VASILEVA	{"email": "vasileva.o.1965@postgrespro.ru", "phone": "+70354146228"}
0005435042938	10FA09	3611 545950	TATYANA MATVEEVA	{"phone": "+70687455699"}
0005435042939	8B69FA	2593 874304	IVAN ZHUKOV	{"phone": "+70656723094"}
0005435043273	3AF885	5642 461852	VALENTINA SOROKINA	{"email": "sorokina_valentina-1983@postgrespro.ru", "phone": "+70365124093"}
0005435043274	029B46	1665 156826	TATYANA GUSEVA	{"email": "guseva_t-011961@postgrespro.ru", "phone": "+70900873432"}
0005435043275	570109	6361 420563	ARINA NESTEROVA	{"email": "nesterova.a.021969@postgrespro.ru", "phone": "+70776359506"}
0005435043276	1E6773	0322 039919	ANNA VASILEVA	{"email": "a-vasileva.101973@postgrespro.ru", "phone": "+70117029905"}
0005435043277	DC5612	0998 879082	MARINA DMITRIEVA	{"phone": "+70240999698"}
0005435043278	22840F	8698 314546	IRINA MAKAROVA	{"phone": "+70298264250"}
0005435043279	391AF9	9971 512478	NATALYA DMITRIEVA	{"phone": "+70990490066"}
0005435043280	391AF9	4492 515672	SERGEY SERGEEV	{"email": "sergey.sergeev_25041961@postgrespro.ru", "phone": "+70999139766"}
0005435043281	568083	7641 216078	ZOYA IVANOVA	{"phone": "+70751681500"}
0005435043282	4EC265	7990 142576	VLADIMIR MELNIKOV	{"phone": "+70241212499"}
0005435043283	36681B	3731 994908	SERGEY STEPANOV	{"email": "sstepanov01031982@postgrespro.ru", "phone": "+70082945401"}
0005435043284	8CF4DF	8893 843474	IRINA NIKITINA	{"phone": "+70164711641"}
0005435043285	F91B30	3711 148166	NATALIYA ZHURAVLEVA	{"phone": "+70295295408"}
0005435043286	37FFE9	9593 215906	ANATOLIY AFANASEV	{"phone": "+70307816766"}
0005435043287	0C6EBB	2389 516520	VLADIMIR SEMENOV	{"email": "v.semenov.27111980@postgrespro.ru", "phone": "+70629682668"}
0005435043288	F88E3C	5218 558236	VIKTOR GORBUNOV	{"email": "gorbunov.v.20111972@postgrespro.ru", "phone": "+70915318161"}
0005435043289	D7D490	2707 199297	ALENA GERASIMOVA	{"email": "a_gerasimova.1970@postgrespro.ru", "phone": "+70967804216"}
0005435043290	12A88A	1602 482164	VLADIMIR FROLOV	{"phone": "+70966956205"}
0005435043291	12A88A	4373 396040	NATALYA KUZNECOVA	{"phone": "+70200032101"}
0005435043292	76ADB0	2361 408436	TAGIR NOVIKOV	{"email": "tagir-novikov1970@postgrespro.ru", "phone": "+70230930785"}
0005435043293	C51216	1015 471228	TATYANA VASILEVA	{"email": "vasilevatatyana.021974@postgrespro.ru", "phone": "+70350779280"}
0005435043294	43E512	4112 673050	GALINA GORBUNOVA	{"email": "galinagorbunova.121965@postgrespro.ru", "phone": "+70807363966"}
0005435043295	65FB7E	2643 724264	VERA VLASOVA	{"phone": "+70497307567"}
0005435043296	B4B15E	0331 323148	LEONID DENISOV	{"phone": "+70913300743"}
0005435043297	EBC15F	5713 351254	SERGEY EGOROV	{"email": "segorov-09071981@postgrespro.ru", "phone": "+70793566680"}
0005435043298	AD6D1C	9343 264621	EVGENIY PETROV	{"phone": "+70330019410"}
0005435043299	29262C	6243 099411	ANASTASIYA ANTONOVA	{"email": "a.antonova1982@postgrespro.ru", "phone": "+70398615015"}
0005435043300	F1B265	2119 334095	VLADIMIR MOISEEV	{"email": "vladimirmoiseev_121972@postgrespro.ru", "phone": "+70710494699"}
0005435043301	F1B265	6775 233273	ALLA NIKOLAEVA	{"email": "alla_nikolaeva_061982@postgrespro.ru", "phone": "+70604895817"}
0005435043302	D2A3B5	1376 278031	LYUDMILA BELYAEVA	{"phone": "+70062688240"}
0005435043303	319AF2	8317 308112	VERA GORBUNOVA	{"email": "gorbunova.vera.021968@postgrespro.ru", "phone": "+70199681365"}
0005435043304	6620F2	5267 473975	DMITRIY AFANASEV	{"email": "dafanasev1977@postgrespro.ru", "phone": "+70453499370"}
0005435043305	CC0629	7311 453133	NAILYA ANDREEVA	{"phone": "+70622438090"}
0005435043306	3894BE	1581 423939	LYUBOV GORBUNOVA	{"email": "gorbunova-l-101965@postgrespro.ru", "phone": "+70614929031"}
0005435043307	9A30EB	7441 908237	EVGENIY GUSEV	{"phone": "+70703174655"}
0005435043308	2F7FF2	0836 626094	ARTEM IVANOV	{"phone": "+70150340853"}
0005435043309	C9C055	5448 461785	NIKOLAY SMIRNOV	{"email": "smirnov-n_041980@postgrespro.ru", "phone": "+70990502085"}
0005435043310	C9C055	2488 912562	ROZA KOMAROVA	{"email": "komarova_r_061977@postgrespro.ru", "phone": "+70926591002"}
0005435043311	89C03F	9997 183509	LYUBOV BELOVA	{"email": "belova-lyubov.101974@postgrespro.ru", "phone": "+70229017986"}
0005435043312	89C03F	6125 188063	YURIY KUZNECOV	{"phone": "+70934022410"}
0005435043313	89C03F	6814 991441	OLGA KUDRYASHOVA	{"phone": "+70815587910"}
0005435068158	AA5CE9	0181 361558	LYUDMILA KUZMINA	{"phone": "+70616383319"}
0005435068159	E2CBEE	8519 965847	ELIZAVETA POPOVA	{"email": "popova_elizaveta081971@postgrespro.ru", "phone": "+70837821652"}
0005435068160	E2CBEE	5134 840338	ANASTASIYA KOZLOVA	{"phone": "+70455608550"}
0005435068161	B4123C	9606 327155	DENIS PAVLOV	{"phone": "+70979663746"}
0005435068162	B4123C	6865 416983	BORIS EGOROV	{"email": "egorovboris05011966@postgrespro.ru", "phone": "+70767994272"}
0005435068163	AA9E6A	3450 840667	NIKITA TARASOV	{"phone": "+70511694888"}
0005435068164	AA9E6A	2331 388504	TATYANA KUDRYASHOVA	{"phone": "+70586735109"}
0005435068165	A756FC	8320 778362	SERGEY MATVEEV	{"email": "matveevsergey.24071962@postgrespro.ru", "phone": "+70061228998"}
0005435068166	AA2B1A	5073 636667	ANNA ANTONOVA	{"phone": "+70407607310"}
0005435068167	AA2B1A	6880 687450	ELENA ALEKSEEVA	{"email": "e_alekseeva.20061974@postgrespro.ru", "phone": "+70829088955"}
0005435068168	3FC9C8	1132 290844	ELENA ILINA	{"email": "ilina-elena.031982@postgrespro.ru", "phone": "+70181175399"}
0005435068169	DBEE6D	5510 862299	VIKTOR STEPANOV	{"phone": "+70173478479"}
0005435068170	08AC28	2307 172708	LIDIYA GERASIMOVA	{"phone": "+70725680877"}
0005435068171	9CD0EC	0238 084752	IDA PETROVA	{"email": "petrovaida-1973@postgrespro.ru", "phone": "+70744183650"}
0005435068172	A59F1C	4780 822711	MIKHAIL GORBUNOV	{"email": "mikhail_gorbunov1973@postgrespro.ru", "phone": "+70402343928"}
0005435068173	109D35	7836 927259	ELENA KOROLEVA	{"email": "koroleva.elena.081979@postgrespro.ru", "phone": "+70906669328"}
0005435068174	109D35	4986 900545	ELENA ZHUKOVA	{"phone": "+70423066468"}
0005435068175	542E6C	9485 425379	ANATOLIY TIMOFEEV	{"phone": "+70063912175"}
0005435068176	887C99	9403 087673	LYUBOV DENISOVA	{"phone": "+70937648377"}
0005435068177	887C99	5617 226356	ILYA SIDOROV	{"email": "i_sidorov-08051976@postgrespro.ru", "phone": "+70543194552"}
0005435068178	2A41E4	2279 445785	GALINA VLASOVA	{"phone": "+70681598565"}
0005435068179	B36D0F	5021 390489	EVGENIY KULIKOV	{"email": "e_kulikov16071975@postgrespro.ru", "phone": "+70871770644"}
0005435068180	B36D0F	0350 434577	OLGA IVANOVA	{"phone": "+70122641457"}
0005435068181	D3B253	9899 997523	LYUDMILA MELNIKOVA	{"email": "melnikova-l-061966@postgrespro.ru", "phone": "+70148676313"}
0005435068182	2A76B3	6350 308442	OKSANA MAKSIMOVA	{"phone": "+70881154815"}
0005435068183	7E63D4	9793 159609	GALINA VASILEVA	{"phone": "+70119620770"}
0005435068184	48D702	1708 364211	ANNA GERASIMOVA	{"email": "gerasimovaa_1984@postgrespro.ru", "phone": "+70788325759"}
0005435068185	48D702	2692 228419	MARINA ZAKHAROVA	{"phone": "+70999403111"}
0005435068186	48D702	8074 436208	RUSLAN SOROKIN	{"email": "ruslansorokin-15011961@postgrespro.ru", "phone": "+70056529821"}
0005435068187	48D702	1760 895564	SERGEY FOMIN	{"email": "fomin.s.1971@postgrespro.ru", "phone": "+70957276572"}
0005435068188	72A4FE	5588 663366	NADEZHDA MATVEEVA	{"phone": "+70741584272"}
0005435068189	72A4FE	1320 126554	ELENA ZHURAVLEVA	{"phone": "+70120740336"}
0005435068190	C8248D	3942 545471	GALINA ANTONOVA	{"email": "g.antonova.14071962@postgrespro.ru", "phone": "+70486886440"}
0005435068191	C8248D	2605 238053	NATALYA IVANOVA	{"phone": "+70835043052"}
0005435068192	DD0F82	7507 183232	GALINA MIRONOVA	{"email": "g.mironova_111975@postgrespro.ru", "phone": "+70952349334"}
0005435068193	DD0F82	0011 412140	NIKOLAY KUZMIN	{"phone": "+70098853606"}
0005435068194	8F6400	3672 348185	MARIYA MOROZOVA	{"phone": "+70850563135"}
0005435068195	889F43	9925 072726	NINA SAVELEVA	{"email": "saveleva.n-111973@postgrespro.ru", "phone": "+70860007700"}
0005435068196	FFF281	0177 236955	ALEKSANDR KOZLOV	{"phone": "+70751305312"}
0005435068197	FFF281	5380 972394	EGOR DENISOV	{"email": "edenisov02081974@postgrespro.ru", "phone": "+70777254636"}
0005435068198	FFF281	5471 356378	ALEKSANDR MIKHAYLOV	{"phone": "+70574985340"}
0005435068199	DBE450	2533 016172	YULIYA KOVALEVA	{"phone": "+70571550925"}
0005435068200	16C1E5	2660 309141	VALENTINA SAVELEVA	{"phone": "+70326446502"}
0005435068201	219AE9	0290 294287	VLADISLAV SMIRNOV	{"email": "smirnov-v19121960@postgrespro.ru", "phone": "+70047227102"}
0005435068202	996EC8	9268 368861	ELENA ANDREEVA	{"email": "elena-andreeva1972@postgrespro.ru", "phone": "+70927822764"}
0005435068203	417A54	3824 206260	NATALYA SOKOLOVA	{"phone": "+70411960265"}
0005435068204	417A54	8089 208232	RUSLAN FEDOTOV	{"phone": "+70280415945"}
0005435068205	58F646	1368 188871	EKATERINA TITOVA	{"email": "titova_ekaterina-22041965@postgrespro.ru", "phone": "+70092116884"}
0005435068206	58F646	2226 186768	VLADIMIR KARPOV	{"email": "vladimir_karpov.031976@postgrespro.ru", "phone": "+70675065207"}
0005435068207	44997C	0955 310872	ELIZAVETA MAKAROVA	{"email": "makarova.elizaveta.081962@postgrespro.ru", "phone": "+70172695348"}
0005435068208	8938F4	0090 353020	YANA ANTONOVA	{"email": "yana_antonova.101974@postgrespro.ru", "phone": "+70137689280"}
0005435068209	1B909D	8046 028311	DARYA BELOVA	{"email": "belovad_091977@postgrespro.ru", "phone": "+70934305717"}
0005435068210	1B909D	6976 197750	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov-11011964@postgrespro.ru", "phone": "+70188628133"}
0005435068211	F57FED	8644 821032	ANNA KRASNOVA	{"phone": "+70014605797"}
0005435068212	54C30F	5887 723312	SOFYA ANDREEVA	{"email": "andreeva.sofya_081967@postgrespro.ru", "phone": "+70037645105"}
0005435068213	56C201	1230 536177	ANATOLIY KUZNECOV	{"phone": "+70058726965"}
0005435068214	159F8D	4576 437045	IVAN DAVYDOV	{"phone": "+70340273107"}
0005435068215	F2A82A	1095 738225	VLADIMIR SAVELEV	{"phone": "+70373220719"}
0005435068216	033CAE	5803 474582	NATALIYA BORISOVA	{"email": "borisova.nataliya_1979@postgrespro.ru", "phone": "+70352108511"}
0005435068217	CCE0F1	8571 473394	ZOYA DAVYDOVA	{"phone": "+70153007354"}
0005435068218	CCE0F1	7678 996428	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr.1966@postgrespro.ru", "phone": "+70786168864"}
0005435068219	5C1E66	8045 194066	GENNADIY GERASIMOV	{"phone": "+70848409210"}
0005435068220	5C1E66	8294 284663	KRISTINA NIKOLAEVA	{"phone": "+70657357735"}
0005435068221	7D3E68	8101 637237	RITA MALYSHEVA	{"email": "rmalysheva-1972@postgrespro.ru", "phone": "+70452561938"}
0005435068222	33DF80	9563 899129	VASILIY NIKITIN	{"email": "nikitinv.081976@postgrespro.ru", "phone": "+70655522820"}
0005435068223	33DF80	1202 785948	OLEG MAKAROV	{"email": "o.makarov1965@postgrespro.ru", "phone": "+70977944581"}
0005435068279	10059E	3604 802187	TATYANA KUZNECOVA	{"phone": "+70762403494"}
0005435068224	33DF80	1935 192937	NIKOLAY STEPANOV	{"email": "nikolay_stepanov_20011970@postgrespro.ru", "phone": "+70233226872"}
0005435068225	A5FD0C	5179 407347	ANNA FROLOVA	{"phone": "+70284999505"}
0005435068226	0A2FDD	3378 759445	RAVIL IVANOV	{"phone": "+70139968382"}
0005435068227	B8171C	6007 761751	NATALIYA IVANOVA	{"email": "ivanovan15031967@postgrespro.ru", "phone": "+70377296538"}
0005435068228	21A143	6413 360093	VALENTINA SERGEEVA	{"email": "sergeeva-v_14111970@postgrespro.ru", "phone": "+70187251236"}
0005435068229	21A143	2401 098278	ALBERT DMITRIEV	{"email": "albertdmitriev-051981@postgrespro.ru", "phone": "+70180427398"}
0005435068230	AB3843	3957 537394	MARINA KUZNECOVA	{"phone": "+70981439951"}
0005435068231	AB3843	1782 602115	ALEKSEY VOROBEV	{"email": "a.vorobev-1973@postgrespro.ru", "phone": "+70618758192"}
0005435068232	F35794	4713 832079	MARIYA MIRONOVA	{"phone": "+70685547323"}
0005435068233	F35794	4771 422811	ALENA ORLOVA	{"phone": "+70820266173"}
0005435068234	CB8F88	6814 857734	TAMARA MOISEEVA	{"phone": "+70553468801"}
0005435068235	112FCA	8261 141432	OLGA NIKOLAEVA	{"email": "o_nikolaeva.07011983@postgrespro.ru", "phone": "+70217833687"}
0005435068236	D25CD9	8608 690167	VIKTOR MAKAROV	{"phone": "+70650821764"}
0005435068237	AF27A3	4537 774725	VLADIMIR ZHUKOV	{"email": "zhukov.vladimir-041976@postgrespro.ru", "phone": "+70390262434"}
0005435068238	3BC224	5645 140781	GRIGORIY ZHURAVLEV	{"email": "grigoriy-zhuravlev.02041984@postgrespro.ru", "phone": "+70401274722"}
0005435068239	3DFCB8	1272 299304	VLADIMIR RODIONOV	{"email": "rodionovvladimir.05061972@postgrespro.ru", "phone": "+70841868542"}
0005435068240	7F5E6C	3085 823187	VERA KOLESNIKOVA	{"email": "v_kolesnikova081969@postgrespro.ru", "phone": "+70178681014"}
0005435068241	7F5E6C	4767 585097	DINA NESTEROVA	{"email": "nesterovad-011973@postgrespro.ru", "phone": "+70621608608"}
0005435068242	18F7D8	7808 357201	LYUDMILA KUZNECOVA	{"email": "lkuznecova111973@postgrespro.ru", "phone": "+70068518807"}
0005435068243	18F7D8	6266 211402	MATVEY SOLOVEV	{"email": "m_solovev.1973@postgrespro.ru", "phone": "+70065384175"}
0005435068244	5D5CC0	5404 250762	ANATOLIY KUZMIN	{"email": "kuzmin_anatoliy_06011981@postgrespro.ru", "phone": "+70464520566"}
0005435068245	0FA7B0	5349 655157	VIKTOR IVANOV	{"email": "ivanov_viktor_01061973@postgrespro.ru", "phone": "+70025834136"}
0005435068246	0FA7B0	4546 958959	SVYATOSLAV KUDRYASHOV	{"email": "kudryashov_svyatoslav1977@postgrespro.ru", "phone": "+70414915908"}
0005435068247	7E9CF2	7286 974778	ELENA NAUMOVA	{"phone": "+70439140840"}
0005435068248	1B1010	1310 699227	LIDIYA YAKOVLEVA	{"phone": "+70968153366"}
0005435068249	4A7A17	5342 400816	MARIYA EFIMOVA	{"phone": "+70078520310"}
0005435068250	6F47A7	9002 668419	GALINA POPOVA	{"phone": "+70093620697"}
0005435068251	4C2874	1723 365320	ALEKSEY VASILEV	{"phone": "+70778390324"}
0005435068252	4C2874	5676 978211	GALINA EFIMOVA	{"email": "gefimova1969@postgrespro.ru", "phone": "+70499436898"}
0005435068253	F6D69C	6467 955837	ALEKSANDR STEPANOV	{"email": "stepanov.a-101984@postgrespro.ru", "phone": "+70319712316"}
0005435068254	F6D69C	4940 962787	ELENA SIDOROVA	{"phone": "+70393897931"}
0005435068255	CF05C7	1756 875378	OLGA FROLOVA	{"phone": "+70077472165"}
0005435068256	189171	8764 891660	YURIY SHEVCHENKO	{"phone": "+70369527934"}
0005435068257	214583	6260 566319	PAVEL VOROBEV	{"phone": "+70076855718"}
0005435068258	214583	2168 483661	ANNA FOMINA	{"phone": "+70787147558"}
0005435068259	393D9E	4031 561152	EVGENIY SIDOROV	{"phone": "+70944243746"}
0005435068260	FD3216	7215 023497	ALEKSANDR MEDVEDEV	{"email": "medvedev-a.21011973@postgrespro.ru", "phone": "+70376043310"}
0005435068261	54AE01	3729 612711	NADEZHDA DANILOVA	{"email": "nadezhda.danilova.17111969@postgrespro.ru", "phone": "+70618268025"}
0005435068262	D17FDE	6122 079121	ELENA EFREMOVA	{"email": "elenaefremova-1967@postgrespro.ru", "phone": "+70352629401"}
0005435068263	5B74F4	5294 273214	ANDREY MOROZOV	{"email": "morozovandrey-091964@postgrespro.ru", "phone": "+70902065223"}
0005435068264	709D0D	1359 338630	YURIY SCHERBAKOV	{"phone": "+70050948340"}
0005435068265	A7D5DD	5442 362962	EVDOKIYA KUZNECOVA	{"email": "kuznecovae.17091976@postgrespro.ru", "phone": "+70667449894"}
0005435068266	B6BCD2	1435 190412	ANNA MAKSIMOVA	{"phone": "+70409959734"}
0005435068267	B6BCD2	0419 258958	OLEG ROMANOV	{"email": "romanov-o.1974@postgrespro.ru", "phone": "+70874621814"}
0005435068268	54118F	4345 256628	ALEKSANDR POPOV	{"email": "popov-a-11091978@postgrespro.ru", "phone": "+70814708490"}
0005435068269	54118F	4719 821968	ALEKSANDR KUZNECOV	{"email": "akuznecov21101968@postgrespro.ru", "phone": "+70532013687"}
0005435068270	BA65F4	1006 373036	VERA BORISOVA	{"email": "v_borisova-1978@postgrespro.ru", "phone": "+70317358897"}
0005435068271	BA65F4	1666 892496	MARGARITA IVANOVA	{"email": "margarita-ivanova-021970@postgrespro.ru", "phone": "+70426490742"}
0005435068272	BA65F4	1563 535412	SERGEY ANTONOV	{"phone": "+70431846331"}
0005435068273	A74636	9125 292645	ELENA VASILEVA	{"email": "elena_vasileva_1972@postgrespro.ru", "phone": "+70804179502"}
0005435068274	235E2D	6907 290000	VALERIYA CHERNOVA	{"email": "valeriya-chernova.071970@postgrespro.ru", "phone": "+70555505249"}
0005435068275	49336D	4157 284396	ANASTASIYA IVANOVA	{"phone": "+70372026409"}
0005435068276	A4C783	5381 079077	VALERIYA MOISEEVA	{"email": "vmoiseeva_31101984@postgrespro.ru", "phone": "+70817669355"}
0005435068277	A4C783	0357 250073	ELENA FEDOROVA	{"email": "fedorova_e.1976@postgrespro.ru", "phone": "+70254065744"}
0005435068278	4B0961	8353 377350	IVAN NIKOLAEV	{"email": "ivan_nikolaev14021966@postgrespro.ru", "phone": "+70499700761"}
0005435068280	10059E	7163 493487	RAISA VOLKOVA	{"email": "volkova-raisa29051979@postgrespro.ru", "phone": "+70764268062"}
0005435068281	2F36AB	2169 976428	NATALYA BOGDANOVA	{"email": "bogdanova_n-13011974@postgrespro.ru", "phone": "+70846060896"}
0005435068282	605BAC	2985 076152	YURIY MAKAROV	{"email": "makarovy.03011975@postgrespro.ru", "phone": "+70352462800"}
0005435068283	605BAC	3062 024603	VASILIY MOROZOV	{"email": "morozov.vasiliy-28111968@postgrespro.ru", "phone": "+70801138638"}
0005435068284	6B5461	3998 527071	VASILIY ILIN	{"email": "v-ilin_011965@postgrespro.ru", "phone": "+70785667899"}
0005435068285	E3A10A	5156 468055	VALENTINA ALEKSEEVA	{"phone": "+70278252525"}
0005435068286	957171	8593 324354	LIDIYA SOROKINA	{"email": "sorokina_lidiya-1984@postgrespro.ru", "phone": "+70008514508"}
0005435068287	7CAD54	7777 166943	NATALYA DMITRIEVA	{"phone": "+70913928850"}
0005435068288	8AC114	1022 648256	ALEKSANDR POPOV	{"email": "popov.aleksandr-10101969@postgrespro.ru", "phone": "+70611591351"}
0005435068289	67C214	7117 235730	SERGEY KULIKOV	{"email": "sergey-kulikov_061981@postgrespro.ru", "phone": "+70457676686"}
0005435068290	67C214	6302 674575	ZINAIDA EFIMOVA	{"phone": "+70704869582"}
0005435068291	67C214	5912 438210	VLADIMIR NIKOLAEV	{"phone": "+70117272667"}
0005435068292	3CCE52	7821 586897	VERA IVANOVA	{"phone": "+70046677983"}
0005435068293	112A78	6147 382910	ANASTASIYA KUZNECOVA	{"email": "anastasiya-kuznecova_1975@postgrespro.ru", "phone": "+70930418420"}
0005435068294	0DEBC3	7722 640786	NIKOLAY VOLKOV	{"email": "nvolkov091965@postgrespro.ru", "phone": "+70976522526"}
0005435068295	0DEBC3	4107 028885	NATALYA ERMAKOVA	{"phone": "+70374145918"}
0005435068296	C96201	8360 130605	NADEZHDA BELOVA	{"phone": "+70459533931"}
0005435068297	C96201	3349 323623	MARINA MOROZOVA	{"phone": "+70706900308"}
0005435068298	CBA840	3976 862714	MARIYA IVANOVA	{"email": "ivanova-m_17021962@postgrespro.ru", "phone": "+70459733924"}
0005435068299	793213	6802 359484	ARTEM TIKHONOV	{"email": "atikhonov_081963@postgrespro.ru", "phone": "+70615072042"}
0005435068300	A260D5	4414 524990	ALEKSEY ROMANOV	{"email": "romanovaleksey.21061976@postgrespro.ru", "phone": "+70520977173"}
0005435068301	04ABD7	7081 720192	ALEKSEY GERASIMOV	{"phone": "+70033340775"}
0005435068302	04ABD7	9199 891116	NINA KOZLOVA	{"email": "kozlovan18021979@postgrespro.ru", "phone": "+70341687474"}
0005435068303	AD99AD	9120 474704	ALEKSEY KUZNECOV	{"email": "kuznecov.a_21071973@postgrespro.ru", "phone": "+70788973182"}
0005435068304	AD4476	3599 038405	ZULFIYA MARTYNOVA	{"email": "zulfiya-martynova_05101966@postgrespro.ru", "phone": "+70113736921"}
0005435068305	51FCA9	6456 949789	EKATERINA SMIRNOVA	{"phone": "+70032856001"}
0005435068306	6E5802	6233 835187	VIKTORIYA MAKAROVA	{"email": "viktoriyamakarova_1972@postgrespro.ru", "phone": "+70508562540"}
0005435068307	6E5802	6568 094400	NIKITA MIKHAYLOV	{"phone": "+70008227442"}
0005435068308	B43888	1447 645193	DANIL ALEKSANDROV	{"phone": "+70373127923"}
0005435068309	B43888	9438 531362	IRINA IVANOVA	{"phone": "+70264665480"}
0005435068310	9DB9C5	0860 299327	NINA ALEKSANDROVA	{"email": "ninaaleksandrova21061981@postgrespro.ru", "phone": "+70644716961"}
0005435068311	9DB9C5	1906 974618	ELENA NIKIFOROVA	{"phone": "+70599535797"}
0005435068312	AEE871	8335 757310	LILIYA VOLKOVA	{"phone": "+70710607755"}
0005435068313	512B5E	4036 261918	ROMAN MOROZOV	{"phone": "+70565931990"}
0005435068314	AFA082	9205 230197	LARISA IVANOVA	{"email": "ivanova.l.051981@postgrespro.ru", "phone": "+70038203611"}
0005435068315	0E4F25	5210 571347	LILIYA POPOVA	{"phone": "+70166839447"}
0005435068316	527477	3551 426515	ANATOLIY PAVLOV	{"phone": "+70619998692"}
0005435068317	527477	7473 016387	ANGELINA NIKOLAEVA	{"email": "nikolaeva-angelina13091975@postgrespro.ru", "phone": "+70841948410"}
0005435068318	3E1D29	1269 626077	NATALYA KUZMINA	{"phone": "+70056429002"}
0005435068319	3E1D29	5844 522623	VALENTINA MOROZOVA	{"phone": "+70325587285"}
0005435068320	053BDB	0386 518505	ROMAN AFANASEV	{"phone": "+70975066253"}
0005435068321	B2E209	3105 699476	MIKHAIL MIRONOV	{"phone": "+70464934893"}
0005435068322	AEA82E	6618 213698	SERGEY RODIONOV	{"email": "sergey.rodionov-1972@postgrespro.ru", "phone": "+70621928128"}
0005435068323	9813A2	2882 668007	NIKOLAY MIKHAYLOV	{"email": "n.mikhaylov_021977@postgrespro.ru", "phone": "+70139507926"}
0005435068324	64C089	9275 222073	MARINA VOROBEVA	{"email": "vorobeva.marina-1981@postgrespro.ru", "phone": "+70214527505"}
0005435068325	EE4F73	3525 027906	FATIMA KULIKOVA	{"phone": "+70731317476"}
0005435068326	4DB955	2992 237675	LYUDMILA KUZNECOVA	{"phone": "+70859564646"}
0005435068327	3DB5B2	0984 152941	LYUDMILA ALEKSEEVA	{"phone": "+70127248609"}
0005435068328	C768CB	5296 751525	ANTONINA ALEKSEEVA	{"phone": "+70070228031"}
0005435068329	D5A93E	2772 067979	SERGEY SOLOVEV	{"email": "sergey_solovev.041978@postgrespro.ru", "phone": "+70891351039"}
0005435068330	CB44E4	2753 095089	DENIS NAUMOV	{"phone": "+70053406610"}
0005435068331	72CB46	1049 906637	IVAN POPOV	{"email": "popovivan-16031977@postgrespro.ru", "phone": "+70972918967"}
0005435068332	010325	9937 086430	ALEKSANDR NIKOLAEV	{"phone": "+70076752052"}
0005435068333	FB9BB1	6709 906404	ALEKSANDR GAVRILOV	{"phone": "+70984845936"}
0005435068334	705CC1	5776 028119	SOFYA TIMOFEEVA	{"phone": "+70163534579"}
0005435068335	705CC1	9634 826204	LYUBOV VLASOVA	{"phone": "+70834339469"}
0005435068446	F6946C	8305 103793	DARYA CHERNOVA	{"phone": "+70815025286"}
0005435068336	15CFE3	5432 804706	VIKTOR SCHERBAKOV	{"email": "v_scherbakov.29061981@postgrespro.ru", "phone": "+70135004839"}
0005435068337	A7D9C4	9546 198297	ALEKSEY MIKHAYLOV	{"phone": "+70918031886"}
0005435068338	ACB3AA	3640 681122	ELENA PAVLOVA	{"phone": "+70627911216"}
0005435068339	ACB3AA	2638 104194	EKATERINA ROMANOVA	{"email": "romanova_ekaterina.1982@postgrespro.ru", "phone": "+70583553100"}
0005435068340	19F40A	2612 775544	ALEKSEY KAZAKOV	{"email": "kazakov_a-1964@postgrespro.ru", "phone": "+70921827427"}
0005435068341	EAA6AA	6206 126241	TATYANA YAKOVLEVA	{"email": "yakovleva-t_061977@postgrespro.ru", "phone": "+70552290961"}
0005435068342	A2E0EB	2987 202209	TATYANA NAZAROVA	{"email": "nazarova-tatyana1960@postgrespro.ru", "phone": "+70392312939"}
0005435068343	BC9124	9124 469939	ELIZAVETA NIKITINA	{"email": "nikitina_elizaveta1979@postgrespro.ru", "phone": "+70847311368"}
0005435068344	A419B7	0299 003598	TATYANA SEMENOVA	{"email": "semenova_t-051976@postgrespro.ru", "phone": "+70703702735"}
0005435068345	A419B7	0563 568436	RAISA MATVEEVA	{"phone": "+70307553805"}
0005435068346	8F6E17	6709 623599	SERGEY MAKSIMOV	{"email": "s_maksimov19121972@postgrespro.ru", "phone": "+70595246097"}
0005435068347	556ABB	0000 214126	NINA GRISHINA	{"email": "nina.grishina_13041974@postgrespro.ru", "phone": "+70767431107"}
0005435068348	00CCC9	3511 384547	NINA EGOROVA	{"email": "egorova.n.021974@postgrespro.ru", "phone": "+70710518013"}
0005435068349	00CCC9	9046 455036	KSENIYA GRISHINA	{"email": "k.grishina05021970@postgrespro.ru", "phone": "+70459475710"}
0005435068350	773CDA	7158 320186	KSENIYA STEPANOVA	{"phone": "+70968904417"}
0005435068351	2F082E	7533 332802	SERAFIM MOISEEV	{"email": "moiseev.serafim.1970@postgrespro.ru", "phone": "+70031283873"}
0005435068352	9D5D17	9265 793851	TAMARA NIKIFOROVA	{"phone": "+70072573358"}
0005435068353	44A824	3173 579547	DANIIL FOMIN	{"email": "fomin-d.21061968@postgrespro.ru", "phone": "+70821401060"}
0005435068354	2D0047	2051 213154	MARIYA KUZNECOVA	{"phone": "+70286795671"}
0005435068355	2D0047	6594 164691	ANDREY SIDOROV	{"email": "sidorova17061981@postgrespro.ru", "phone": "+70843859693"}
0005435068356	2D0047	5420 017776	LYUBOV KUZNECOVA	{"phone": "+70066063319"}
0005435068357	00E84F	5654 040085	SVETLANA EFREMOVA	{"email": "efremova-svetlana.27031981@postgrespro.ru", "phone": "+70523535495"}
0005435068358	00E84F	1442 844285	LILIYA KOZLOVA	{"phone": "+70905319251"}
0005435068359	E628B6	3030 848256	NIKOLAY NIKITIN	{"phone": "+70847495091"}
0005435068360	57C442	2820 841675	OLGA KOROLEVA	{"phone": "+70002232199"}
0005435068361	1AA688	7200 134258	NATALYA MARTYNOVA	{"email": "martynova_n_04111975@postgrespro.ru", "phone": "+70997132654"}
0005435068362	1AA688	0460 858423	OLGA FEDOROVA	{"email": "o_fedorova121959@postgrespro.ru", "phone": "+70545116982"}
0005435068363	C49D6B	8749 684585	VLADISLAV KOROLEV	{"phone": "+70961624285"}
0005435068364	C49D6B	7319 987469	YULIYA KUZNECOVA	{"email": "kuznecova-yuliya_1979@postgrespro.ru", "phone": "+70709283569"}
0005435068365	C49D6B	8668 748707	DARYA YAKOVLEVA	{"email": "d-yakovleva041971@postgrespro.ru", "phone": "+70972275308"}
0005435068366	E7317E	6406 084238	ELMIRA KUZMINA	{"email": "ekuzmina_1982@postgrespro.ru", "phone": "+70357502226"}
0005435068367	E7317E	8680 062023	ALEKSANDR STEPANOV	{"phone": "+70199015703"}
0005435068368	8ED2DC	3299 165762	OLGA IVANOVA	{"email": "olga.ivanova.011987@postgrespro.ru", "phone": "+70766892886"}
0005435068369	D4AECD	0874 850390	ALEKSANDR KOROLEV	{"email": "korolev.a08121974@postgrespro.ru", "phone": "+70205901759"}
0005435068370	D4AECD	3041 448050	VIKTOR KONOVALOV	{"phone": "+70932357045"}
0005435068371	D95678	3863 658799	VADIM NIKITIN	{"phone": "+70669807268"}
0005435068372	547B7A	0651 008045	VLADISLAV MAKSIMOV	{"phone": "+70501035485"}
0005435068373	8F4358	5946 317222	NIKOLAY SOKOLOV	{"email": "sokolov_nikolay10081982@postgrespro.ru", "phone": "+70897507370"}
0005435068374	8F4358	9982 827192	EKATERINA EGOROVA	{"email": "ekaterinaegorova06101973@postgrespro.ru", "phone": "+70521669012"}
0005435068375	F5F213	5439 419182	ELENA KOZLOVA	{"phone": "+70827731833"}
0005435068376	F5F213	8240 787639	RAFAIL GRIGOREV	{"phone": "+70557989383"}
0005435068377	A2A050	0335 793344	IRINA LUKYANOVA	{"phone": "+70117507115"}
0005435068378	A2A050	4957 458054	KONSTANTIN ALEKSANDROV	{"email": "aleksandrov.k_20101977@postgrespro.ru", "phone": "+70366917901"}
0005435068379	404B41	8753 250170	FANIL GRIGOREV	{"phone": "+70104501583"}
0005435068380	5398D6	4568 668407	OLGA MOISEEVA	{"phone": "+70071984828"}
0005435068381	1F5D38	9421 868687	KIRA MIRONOVA	{"email": "mironova_k.31011971@postgrespro.ru", "phone": "+70945495566"}
0005435068382	39AFAA	3877 970553	TATYANA ANISIMOVA	{"phone": "+70616046902"}
0005435068383	39AFAA	7489 031464	DANIL VOLKOV	{"email": "danilvolkov-1975@postgrespro.ru", "phone": "+70995827505"}
0005435068384	DD0311	7335 075021	MARINA MAKAROVA	{"email": "makarova_marina-1969@postgrespro.ru", "phone": "+70034428694"}
0005435068385	CBF875	4499 162718	EGOR MAKAROV	{"phone": "+70411153124"}
0005435068386	C9DFEA	0254 605673	ALEKSANDR KUZMIN	{"phone": "+70724049341"}
0005435068387	C9DFEA	4021 852782	ALEKSANDR MATVEEV	{"email": "matveevaleksandr_041968@postgrespro.ru", "phone": "+70199160089"}
0005435068388	ECCED8	8220 126939	NATALYA SOKOLOVA	{"email": "n-sokolova_1979@postgrespro.ru", "phone": "+70538981294"}
0005435068389	500466	8074 376836	GENNADIY PETROV	{"email": "g_petrov17071967@postgrespro.ru", "phone": "+70974141744"}
0005435068390	500466	0120 641886	ELENA POTAPOVA	{"phone": "+70814540084"}
0005435068558	A40FC0	2391 937861	YULIYA ALEKSANDROVA	{"phone": "+70745988728"}
0005435068391	500466	6847 690222	ALENA NIKITINA	{"email": "nikitina.alena101966@postgrespro.ru", "phone": "+70898573367"}
0005435068392	70E4DD	6319 543467	ANDREY MAKSIMOV	{"phone": "+70323648041"}
0005435068393	6C8DC5	1549 751705	VLADIMIR KUDRYASHOV	{"email": "v-kudryashov_101974@postgrespro.ru", "phone": "+70316366949"}
0005435068394	1836C7	0646 679501	NIKITA CHERNOV	{"phone": "+70049648050"}
0005435068395	C84C1D	9087 926249	ALEKSANDR ALEKSEEV	{"phone": "+70187354504"}
0005435068396	C84C1D	6399 561305	ALEVTINA IVANOVA	{"phone": "+70919070489"}
0005435068397	0AED1C	4540 076401	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov.101967@postgrespro.ru", "phone": "+70010144524"}
0005435068398	A75A66	1329 257580	IRINA ARKHIPOVA	{"email": "iarkhipova28111974@postgrespro.ru", "phone": "+70267825024"}
0005435068399	A75A66	4803 521144	OLGA DAVYDOVA	{"email": "olga.davydova_071962@postgrespro.ru", "phone": "+70085536744"}
0005435068400	9FFB60	0108 237831	ALEKSEY NIKOLAEV	{"email": "aleksey_nikolaev.1971@postgrespro.ru", "phone": "+70538381223"}
0005435068401	C8B056	9663 288392	LYUDMILA ILINA	{"email": "ilina-lyudmila-10091970@postgrespro.ru", "phone": "+70030360661"}
0005435068402	663F92	5461 841940	KRISTINA MATVEEVA	{"phone": "+70961479254"}
0005435068403	663F92	7117 340281	MIKHAIL KOROLEV	{"phone": "+70899468768"}
0005435068404	98BCEC	4424 001889	ROZA MASLOVA	{"phone": "+70234739690"}
0005435068405	D8C4ED	9012 595451	ALEKSEY MAKAROV	{"phone": "+70407837768"}
0005435068406	BBF2A9	8159 269259	ALEKSANDR TIKHONOV	{"email": "a_tikhonov-021965@postgrespro.ru", "phone": "+70821239018"}
0005435068407	05AF52	1125 062223	RAISA IVANOVA	{"phone": "+70981800190"}
0005435068408	160E39	3940 546440	EKATERINA ZOTOVA	{"phone": "+70771827975"}
0005435068409	708743	4913 760591	LYUDMILA MIKHAYLOVA	{"phone": "+70329675055"}
0005435068410	86F13C	4703 749076	LIDIYA TIKHONOVA	{"email": "l_tikhonova-1984@postgrespro.ru", "phone": "+70424236312"}
0005435068411	86F13C	3487 265975	MARINA SEMENOVA	{"email": "semenovamarina_061977@postgrespro.ru", "phone": "+70625285589"}
0005435068412	9B5CB4	3286 131148	ELENA PETROVA	{"email": "petrova_elena121973@postgrespro.ru", "phone": "+70663400742"}
0005435068413	233526	2114 738814	DMITRIY ALEKSEEV	{"email": "alekseevdmitriy-041974@postgrespro.ru", "phone": "+70144405687"}
0005435068414	233526	2872 049146	VLADISLAV SERGEEV	{"email": "sergeev_v_05031974@postgrespro.ru", "phone": "+70825371330"}
0005435068415	233526	5058 456311	ALENA ANDREEVA	{"email": "andreeva-alena_08071971@postgrespro.ru", "phone": "+70763634041"}
0005435068416	442206	8659 968030	ANGELINA NIKOLAEVA	{"phone": "+70013631938"}
0005435068417	442206	5046 497042	KRISTINA MAKAROVA	{"phone": "+70177479298"}
0005435068418	1FF390	5268 704651	NATALYA KUZMINA	{"email": "n_kuzmina-1965@postgrespro.ru", "phone": "+70759272321"}
0005435068419	3BB33C	9126 072287	ANASTASIYA MOROZOVA	{"email": "a.morozova1980@postgrespro.ru", "phone": "+70322998047"}
0005435068420	3BB33C	7354 903495	VLADIMIR POPOV	{"phone": "+70698303851"}
0005435068421	3BB33C	0306 850428	MIKHAIL FEDOROV	{"email": "mikhail.fedorov1974@postgrespro.ru", "phone": "+70116233048"}
0005435068422	E28138	8459 141566	VITALIY SCHERBAKOV	{"email": "vscherbakov.14011976@postgrespro.ru", "phone": "+70222146660"}
0005435068423	87A27A	3264 891290	OLGA BORISOVA	{"phone": "+70869555674"}
0005435068424	6061F4	5679 584474	VYACHESLAV KAZAKOV	{"email": "vyacheslavkazakov_16051973@postgrespro.ru", "phone": "+70742862414"}
0005435068425	BCA85A	9619 987688	MIKHAIL MOROZOV	{"email": "m_morozov.1963@postgrespro.ru", "phone": "+70744457908"}
0005435068426	BCA85A	8461 886027	DMITRIY SERGEEV	{"email": "sergeevdmitriy_29011975@postgrespro.ru", "phone": "+70313615522"}
0005435068427	3ED931	6139 813149	LYUDMILA BOGDANOVA	{"email": "lyudmila-bogdanova1969@postgrespro.ru", "phone": "+70852860918"}
0005435068428	5EC7F8	1792 141667	SERGEY PAVLOV	{"email": "pavlov_s-071972@postgrespro.ru", "phone": "+70291411441"}
0005435068429	F7737B	3609 703765	EKATERINA DENISOVA	{"phone": "+70420957424"}
0005435068430	BBD062	3403 651703	OLEG MOISEEV	{"email": "moiseev.o-081957@postgrespro.ru", "phone": "+70511618670"}
0005435068431	98487A	3692 012997	ALEKSANDR PETROV	{"email": "petrov.aleksandr.1983@postgrespro.ru", "phone": "+70460929216"}
0005435068432	6A6FA4	1159 907289	VLADIMIR KUZNECOV	{"phone": "+70562506005"}
0005435068433	9A613C	9468 574801	ALEKSANDR DAVYDOV	{"phone": "+70802741115"}
0005435068434	E486EC	4269 065640	VIKTORIYA RYABOVA	{"phone": "+70836685771"}
0005435068435	0E603C	1088 812100	ANTON MAKAROV	{"phone": "+70697291732"}
0005435068436	D521AA	1797 013248	NINA SAVELEVA	{"email": "nina.saveleva1967@postgrespro.ru", "phone": "+70976897186"}
0005435068437	1D8344	6611 006655	DMITRIY FEDOTOV	{"email": "dmitriyfedotov-05051979@postgrespro.ru", "phone": "+70994345992"}
0005435068438	D54AC9	9941 050082	RUSTAM NIKITIN	{"phone": "+70980582558"}
0005435068439	4C81C4	7790 996711	SERGEY KOROLEV	{"email": "korolev-s-01061976@postgrespro.ru", "phone": "+70977286905"}
0005435068440	6F173F	2288 472126	MARINA NESTEROVA	{"phone": "+70862977178"}
0005435068441	351DE4	7426 551488	EVGENIYA TARASOVA	{"email": "evgeniyatarasova.041977@postgrespro.ru", "phone": "+70870034588"}
0005435068442	35AC03	6862 799291	VIKTOR KAZAKOV	{"email": "kazakov-v-041964@postgrespro.ru", "phone": "+70629530246"}
0005435068443	5673A9	9281 585297	INESSA KOROLEVA	{"phone": "+70905469992"}
0005435068444	32C5AE	3010 708937	NATALYA ALEKSEEVA	{"email": "n.alekseeva_04101973@postgrespro.ru", "phone": "+70907211485"}
0005435068445	811B1A	6429 420182	SERGEY FEDOROV	{"phone": "+70068475336"}
0005435068447	1EE5A6	4594 349191	VLADIMIR VOLKOV	{"email": "vladimirvolkov-24061989@postgrespro.ru", "phone": "+70520314178"}
0005435068448	1EE5A6	9036 705498	ALEKSANDR NOVIKOV	{"phone": "+70361817012"}
0005435068449	CBB4FC	6398 203865	VYACHESLAV FROLOV	{"email": "v.frolov.111971@postgrespro.ru", "phone": "+70217545105"}
0005435068450	440AE8	5373 378972	OLGA KULIKOVA	{"email": "kulikova-o091980@postgrespro.ru", "phone": "+70761924693"}
0005435068451	530263	1621 039425	DMITRIY KUZNECOV	{"email": "kuznecov_d041973@postgrespro.ru", "phone": "+70532390054"}
0005435068452	530263	1246 906339	ANTON NIKOLAEV	{"phone": "+70726957086"}
0005435068453	345A95	8233 043557	IGOR ALEKSANDROV	{"email": "aleksandrov_i_1973@postgrespro.ru", "phone": "+70252921739"}
0005435068454	345A95	7886 408880	ALENA NIKOLAEVA	{"phone": "+70879105012"}
0005435068455	671C31	3096 337651	NIKOLAY SOLOVEV	{"email": "solovev_nikolay.1978@postgrespro.ru", "phone": "+70555281257"}
0005435068456	671C31	7727 037553	NATALIYA KUZNECOVA	{"email": "kuznecova-nataliya.05011968@postgrespro.ru", "phone": "+70848929603"}
0005435068457	25E8AB	0934 803577	NATALYA MELNIKOVA	{"phone": "+70493441927"}
0005435068458	25E8AB	3921 142694	DIANA KULIKOVA	{"email": "kulikova.diana.1963@postgrespro.ru", "phone": "+70911117653"}
0005435068459	DB379D	9628 723724	VLADISLAV SCHERBAKOV	{"phone": "+70261980936"}
0005435068460	DB379D	2115 294467	GALINA KONDRATEVA	{"phone": "+70015626386"}
0005435068461	819598	3440 194397	FELIKS KAZAKOV	{"phone": "+70023319101"}
0005435068462	B9E3EF	7773 135803	LIDIYA ZAYCEVA	{"email": "lidiya-zayceva_091966@postgrespro.ru", "phone": "+70175769976"}
0005435068463	30AB7B	6244 246720	VLADIMIR OSIPOV	{"phone": "+70493632542"}
0005435068464	A9DEB0	8772 248380	IGOR MELNIKOV	{"phone": "+70136940804"}
0005435068465	C7ED25	2211 400161	VITALIY NOVIKOV	{"email": "novikov_vitaliy_1965@postgrespro.ru", "phone": "+70880006518"}
0005435068466	9A09BA	3683 121081	DARYA AKIMOVA	{"phone": "+70422326598"}
0005435068467	B73283	9225 837283	SVETLANA ANTONOVA	{"email": "s.antonova_011955@postgrespro.ru", "phone": "+70251715604"}
0005435068468	B73283	4091 804590	VALENTINA MELNIKOVA	{"phone": "+70753503672"}
0005435068469	C54267	6003 644615	SERGEY TIKHONOV	{"email": "tikhonov_sergey.081970@postgrespro.ru", "phone": "+70397085047"}
0005435068470	E28559	4123 635415	ANASTASIYA MOISEEVA	{"phone": "+70579137588"}
0005435068471	896495	4165 423523	VALERIY FOMIN	{"email": "valeriy-fomin111976@postgrespro.ru", "phone": "+70588865966"}
0005435068472	29CAEF	9938 556738	EKATERINA MIRONOVA	{"phone": "+70094850162"}
0005435068473	89A1D4	1541 430655	DMITRIY SEMENOV	{"phone": "+70445858127"}
0005435068474	89A1D4	2593 079812	VLADIMIR NAZAROV	{"email": "vladimir-nazarov081975@postgrespro.ru", "phone": "+70615249319"}
0005435068475	32A8A1	8706 635875	SERGEY ANDREEV	{"phone": "+70830375249"}
0005435068476	8AC994	5293 060659	NATALYA TARASOVA	{"phone": "+70201376727"}
0005435068477	D9092A	0334 177276	IGOR KUZNECOV	{"phone": "+70726679119"}
0005435068478	E46A78	5822 037939	TATYANA KUZNECOVA	{"phone": "+70388225716"}
0005435068479	E46A78	5369 291375	ELIZAVETA OSIPOVA	{"email": "osipova.e04021976@postgrespro.ru", "phone": "+70396998027"}
0005435068480	5588A0	9827 560602	ALEKSANDR MAKAROV	{"phone": "+70201049075"}
0005435068481	15BD4B	9890 042629	ALEKSANDRA SOROKINA	{"email": "a_sorokina-041965@postgrespro.ru", "phone": "+70347365453"}
0005435068482	31EE64	9271 472933	KRISTINA KUZMINA	{"email": "kristina-kuzmina-26081973@postgrespro.ru", "phone": "+70360073108"}
0005435068483	C5F241	4227 335584	DMITRIY KUZMIN	{"phone": "+70349458739"}
0005435068484	6ADDEF	7728 352909	IGOR FROLOV	{"phone": "+70638015261"}
0005435068485	6ADDEF	2057 581297	VLADIMIR SEMENOV	{"phone": "+70176894343"}
0005435068486	FC5458	0136 657495	IGOR SMIRNOV	{"phone": "+70667405840"}
0005435068487	51EE0F	4869 023244	ARTEM KUZMIN	{"email": "artem_kuzmin-111963@postgrespro.ru", "phone": "+70258753820"}
0005435068488	11B65F	3840 106186	EKATERINA RYABOVA	{"email": "ryabova-ekaterina_1971@postgrespro.ru", "phone": "+70381135692"}
0005435068489	11B65F	8217 966360	VITALIY KUZNECOV	{"email": "kuznecov-vitaliy-101971@postgrespro.ru", "phone": "+70474774194"}
0005435068490	D65CF1	4050 033499	OLGA FEDOROVA	{"email": "o.fedorova-20051979@postgrespro.ru", "phone": "+70868916236"}
0005435068491	D6E0AC	0492 622165	OLGA MIRONOVA	{"email": "olga-mironova-051962@postgrespro.ru", "phone": "+70701514301"}
0005435068492	52B26E	8219 197514	EVGENIY MEDVEDEV	{"phone": "+70561677772"}
0005435068493	6834AD	0864 382669	ELENA VOROBEVA	{"phone": "+70233726264"}
0005435068494	6834AD	2745 136604	VALENTINA ZAYCEVA	{"email": "zayceva.valentina071967@postgrespro.ru", "phone": "+70501845074"}
0005435068495	0C690A	3977 742693	GALINA BELYAEVA	{"email": "g.belyaeva-091977@postgrespro.ru", "phone": "+70350688053"}
0005435068496	7B3CB6	2218 322184	YURIY FEDOROV	{"email": "fedorovyuriy.031986@postgrespro.ru", "phone": "+70699618779"}
0005435068497	7B3CB6	7099 873413	LILIYA POPOVA	{"phone": "+70890717774"}
0005435068498	59348E	3478 747980	NATALIYA IVANOVA	{"phone": "+70194615469"}
0005435068499	59348E	1806 037903	EVGENIY NIKOLAEV	{"email": "nikolaev-evgeniy1970@postgrespro.ru", "phone": "+70239536487"}
0005435068500	1080E6	9250 545828	ILYA ANDREEV	{"email": "andreev-ilya_021975@postgrespro.ru", "phone": "+70081959083"}
0005435068501	1080E6	1563 893753	MIKHAIL BONDARENKO	{"phone": "+70886318627"}
0005435068502	DE2771	8140 246524	MIKHAIL AFANASEV	{"email": "mikhailafanasev-10051986@postgrespro.ru", "phone": "+70324127574"}
0005435068503	DE634E	1392 710090	OLGA ALEKSANDROVA	{"email": "aleksandrovao_091978@postgrespro.ru", "phone": "+70775756186"}
0005435068504	B35D64	5434 233254	VALENTINA ORLOVA	{"email": "orlova.v-041968@postgrespro.ru", "phone": "+70625466953"}
0005435068505	B35D64	3719 205858	SERGEY BONDARENKO	{"email": "bondarenko.s-051972@postgrespro.ru", "phone": "+70608579136"}
0005435068506	D3684A	6171 584132	VLADIMIR TARASOV	{"phone": "+70483321060"}
0005435068507	3E8764	8414 977098	TIMOFEY MAKAROV	{"phone": "+70073017830"}
0005435068508	9C2F16	6644 698393	VIKTOR ZHUKOV	{"email": "v.zhukov_1975@postgrespro.ru", "phone": "+70480235211"}
0005435068509	9C2F16	1294 732937	SERGEY BARANOV	{"email": "baranov_s-27061978@postgrespro.ru", "phone": "+70867996276"}
0005435068510	EA6643	0858 635628	VITALIY SCHERBAKOV	{"phone": "+70977204667"}
0005435068511	EA6643	2968 904501	ELENA VASILEVA	{"email": "vasileva_e.1962@postgrespro.ru", "phone": "+70195413309"}
0005435068512	5BC288	0597 466075	ELENA TARASOVA	{"phone": "+70603590118"}
0005435068513	4C1068	1339 790218	VIKTORIYA OVCHINNIKOVA	{"email": "vovchinnikova.19061969@postgrespro.ru", "phone": "+70738091998"}
0005435068514	4C1068	8466 162090	KIRILL VOROBEV	{"email": "vorobev.k.27041979@postgrespro.ru", "phone": "+70806362255"}
0005435068515	4C1068	9612 565576	SERGEY KUZNECOV	{"email": "s.kuznecov-021977@postgrespro.ru", "phone": "+70585497739"}
0005435068516	49A7AD	9019 351028	ALENA ZHUKOVA	{"email": "alena-zhukova27061965@postgrespro.ru", "phone": "+70509561135"}
0005435068517	49A7AD	8274 154773	VALENTINA ISAEVA	{"email": "valentina-isaeva-1977@postgrespro.ru", "phone": "+70193162883"}
0005435068518	F581A8	4551 662959	SVETLANA ANTONOVA	{"phone": "+70762091283"}
0005435068519	EBAAB3	1194 874262	NADEZHDA NIKITINA	{"phone": "+70633806578"}
0005435068520	EBAAB3	6397 642115	LARISA DANILOVA	{"email": "l-danilova27121968@postgrespro.ru", "phone": "+70308575443"}
0005435068521	44CB95	2535 857887	EVGENIY PAVLOV	{"email": "e-pavlov-1964@postgrespro.ru", "phone": "+70187785694"}
0005435068522	44CB95	1258 392093	ANDREY CHERNOV	{"email": "chernov-a25071967@postgrespro.ru", "phone": "+70452206056"}
0005435068523	44CB95	3197 752223	ALEKSANDR ALEKSEEV	{"phone": "+70490746054"}
0005435068524	ADEEB7	3063 883239	MARK VLASOV	{"email": "mark.vlasov-14031968@postgrespro.ru", "phone": "+70283846011"}
0005435068525	E91C15	9922 642065	OLGA AKIMOVA	{"phone": "+70105493033"}
0005435068526	7D8093	4164 260101	GALINA OVCHINNIKOVA	{"email": "govchinnikova_111968@postgrespro.ru", "phone": "+70074154137"}
0005435068527	333EFD	0106 949379	NIKOLAY IVANOV	{"email": "nivanov_06101967@postgrespro.ru", "phone": "+70883112802"}
0005435068528	333EFD	3572 544384	NATALYA KUZNECOVA	{"email": "kuznecova.natalya_20061966@postgrespro.ru", "phone": "+70128775273"}
0005435068529	D4DCA5	6912 633164	YURIY DAVYDOV	{"phone": "+70623696044"}
0005435068530	D4DCA5	7578 176936	TATYANA MAKSIMOVA	{"phone": "+70126298706"}
0005435068531	C93012	5419 253501	VARVARA ZAKHAROVA	{"email": "varvara-zakharova091973@postgrespro.ru", "phone": "+70447454327"}
0005435068532	CCDC45	1479 293741	NIKOLAY MOROZOV	{"email": "nikolay_morozov_1981@postgrespro.ru", "phone": "+70026340979"}
0005435068533	CCDC45	8491 292443	ALEKSANDR RODIONOV	{"phone": "+70753916933"}
0005435068534	4922FD	6000 540003	MARINA NAZAROVA	{"email": "marina.nazarova-21031979@postgrespro.ru", "phone": "+70833141868"}
0005435068535	23FED1	9618 539219	ELENA TITOVA	{"phone": "+70437766329"}
0005435068536	CC8A30	4610 429660	ALEKSANDR ZHURAVLEV	{"phone": "+70904942660"}
0005435068537	CC8A30	7858 293023	VLADIMIR FILIPPOV	{"email": "filippov-vladimir03061973@postgrespro.ru", "phone": "+70433772589"}
0005435068538	CC8A30	5790 570880	ELENA MARTYNOVA	{"phone": "+70752847820"}
0005435068539	C0331D	9307 972248	ANTON POPOV	{"email": "popov_anton_1977@postgrespro.ru", "phone": "+70109406378"}
0005435068540	C0331D	7451 942503	MARIYA AKIMOVA	{"email": "m-akimova.14091971@postgrespro.ru", "phone": "+70715617545"}
0005435068541	39B4CB	3254 567744	SERGEY TARASOV	{"phone": "+70639440859"}
0005435068542	39B4CB	3362 854091	AMIR NIKOLAEV	{"phone": "+70762910605"}
0005435068543	4F2372	2300 269287	NIKOLAY ISAEV	{"email": "isaevnikolay1973@postgrespro.ru", "phone": "+70049103929"}
0005435068544	D6AE15	2717 850836	SVETLANA SCHERBAKOVA	{"phone": "+70105661643"}
0005435068545	88CE29	4760 314982	LYUDMILA FADEEVA	{"phone": "+70775240073"}
0005435068546	2BFAEF	2882 009978	ELENA FEDOROVA	{"phone": "+70729439419"}
0005435068547	BA17F3	9726 417277	OLESYA TIKHONOVA	{"email": "olesyatikhonova_051986@postgrespro.ru", "phone": "+70234374037"}
0005435068548	C3A95B	0451 441825	FEDOR KULIKOV	{"email": "kulikov-f-1967@postgrespro.ru", "phone": "+70497121347"}
0005435068549	35256A	5674 627266	SERGEY MEDVEDEV	{"phone": "+70008063181"}
0005435068550	35256A	8160 977172	ALFIYA MOROZOVA	{"phone": "+70656711541"}
0005435068551	257648	9937 295528	EVGENIY ALEKSANDROV	{"email": "evgeniy_aleksandrov-1958@postgrespro.ru", "phone": "+70007968122"}
0005435068552	257648	6881 130441	TATYANA STEPANOVA	{"email": "stepanovatatyana28011966@postgrespro.ru", "phone": "+70710448041"}
0005435068553	A16C33	0961 859590	EVGENIY MAKSIMOV	{"phone": "+70865537868"}
0005435068554	34DE8C	3764 480827	ALEKSEY TIKHONOV	{"email": "tikhonov.aleksey.1970@postgrespro.ru", "phone": "+70120984532"}
0005435068555	63AAE4	4522 466320	ELENA PETROVA	{"email": "elena_petrova13111971@postgrespro.ru", "phone": "+70166653325"}
0005435068556	8CC07C	1890 539305	OLGA DMITRIEVA	{"email": "dmitrieva_o.1964@postgrespro.ru", "phone": "+70219771004"}
0005435068557	E4460B	9350 114213	ANNA KISELEVA	{"email": "akiseleva-16081970@postgrespro.ru", "phone": "+70725300609"}
0005435068559	0BC7E0	9262 507223	ANDREY MARTYNOV	{"phone": "+70316626890"}
0005435068560	2B689D	1641 911557	VITALIY TIKHONOV	{"phone": "+70101648329"}
0005435068561	1F7D1C	0031 384773	MIKHAIL SCHERBAKOV	{"phone": "+70246870917"}
0005435068562	8C789D	9952 554806	VYACHESLAV SOKOLOV	{"phone": "+70362302192"}
0005435068563	480474	2853 710416	ANDREY DAVYDOV	{"email": "andrey-davydov.1982@postgrespro.ru", "phone": "+70927348052"}
0005435068564	480474	0038 851292	ALENA EGOROVA	{"phone": "+70144329129"}
0005435068565	480474	0457 258999	YURIY KOZLOV	{"phone": "+70497128573"}
0005435068566	DEE270	7934 862853	SVETLANA PETROVA	{"phone": "+70782566764"}
0005435068567	29A7F8	5905 737016	VLADISLAV KOROLEV	{"phone": "+70733150659"}
0005435068568	FB6800	4287 205691	VERA KUZMINA	{"email": "kuzmina-v.1970@postgrespro.ru", "phone": "+70157906395"}
0005435068569	FB6800	3844 945292	ALEKSANDR DAVYDOV	{"email": "aleksandr-davydov_061961@postgrespro.ru", "phone": "+70040646950"}
0005435068570	EB3BA7	5451 788887	BORIS NIKOLAEV	{"phone": "+70362609429"}
0005435068571	EB3BA7	7446 008795	OLGA ZHURAVLEVA	{"phone": "+70429646229"}
0005435068572	A478E1	4543 639653	IRINA MOROZOVA	{"email": "morozova-irina-111982@postgrespro.ru", "phone": "+70170910514"}
0005435068573	A478E1	4824 857381	OLEG MIRONOV	{"phone": "+70802215352"}
0005435068574	A478E1	8536 356445	DANIIL KISELEV	{"phone": "+70625612478"}
0005435068575	852B1C	7220 590622	ROMAN FILIPPOV	{"phone": "+70217213931"}
0005435068576	8026FE	0503 816059	SVETLANA LAZAREVA	{"phone": "+70631837088"}
0005435068577	8026FE	4123 968711	ANASTASIYA MASLOVA	{"email": "maslova.anastasiya-17031972@postgrespro.ru", "phone": "+70852729728"}
0005435068578	7257B0	9634 288483	VIKTOR KONOVALOV	{"phone": "+70099328747"}
0005435068579	7257B0	6786 862024	LIDIYA RODIONOVA	{"phone": "+70575236093"}
0005435068580	7257B0	2121 701875	VLADIMIR NAUMOV	{"phone": "+70584447003"}
0005435068581	2953A4	5077 132754	IGOR MIRONOV	{"phone": "+70798942285"}
0005435068582	F67603	7896 428767	MAKSIM SCHERBAKOV	{"phone": "+70712925873"}
0005435068583	D3A1EA	3979 564021	TATYANA ROMANOVA	{"email": "tatyana-romanova.23091967@postgrespro.ru", "phone": "+70681601122"}
0005435068584	175875	6163 305568	LYUDMILA SOLOVEVA	{"phone": "+70453867666"}
0005435068585	175875	5605 782753	NINA ILINA	{"phone": "+70533977519"}
0005435068586	E40F9D	9909 493260	NIKOLAY SOLOVEV	{"email": "solovev.nikolay.16081977@postgrespro.ru", "phone": "+70804624559"}
0005435068587	999E3E	2184 259101	VALENTINA LAZAREVA	{"email": "valentina_lazareva_1977@postgrespro.ru", "phone": "+70234105661"}
0005435068588	C5CEB7	6017 079739	LILIYA LUKYANOVA	{"phone": "+70089219058"}
0005435068589	C5CEB7	6804 562101	DENIS KOZLOV	{"phone": "+70063829894"}
0005435068590	E7B6D4	9927 427291	ANASTASIYA ANDREEVA	{"phone": "+70846738123"}
0005435068591	13E10F	6478 747007	GALINA CHERNOVA	{"email": "galina-chernova-24091974@postgrespro.ru", "phone": "+70332184054"}
0005435068592	7B5042	2981 204677	ALINA MAKAROVA	{"phone": "+70441824123"}
0005435068593	D5D16F	0027 509860	ALEKSANDR SMIRNOV	{"phone": "+70295051413"}
0005435068594	E040EA	2009 396529	NINA KUZNECOVA	{"email": "kuznecova.nina08111984@postgrespro.ru", "phone": "+70932348900"}
0005435068595	E040EA	9871 256158	ELENA FROLOVA	{"email": "e.frolova08031963@postgrespro.ru", "phone": "+70583752208"}
0005435068596	D4FD42	1035 325954	VALERIYA VASILEVA	{"email": "v_vasileva011968@postgrespro.ru", "phone": "+70120517625"}
0005435068597	47AA5F	5406 356701	SVETLANA KOVALEVA	{"email": "skovaleva-22121980@postgrespro.ru", "phone": "+70196620755"}
0005435068598	47AA5F	8414 137991	YURIY ROMANOV	{"email": "yromanov_10041972@postgrespro.ru", "phone": "+70038359182"}
0005435068599	922DFB	8185 913994	GALINA GRISHINA	{"phone": "+70378370903"}
0005435068600	24F37E	0261 178927	IVAN ZAKHAROV	{"phone": "+70487144464"}
0005435068601	24F37E	3190 525280	NADEZHDA KOROLEVA	{"phone": "+70604680486"}
0005435068602	B6B7EE	6232 707257	NIKOLAY MOROZOV	{"email": "nikolaymorozov.19061956@postgrespro.ru", "phone": "+70514983993"}
0005435068603	B6B7EE	0548 314744	ALEKSANDRA ILINA	{"phone": "+70846203122"}
0005435068604	ECC8C8	5764 077391	GALINA PETROVA	{"phone": "+70362892868"}
0005435068605	ECC8C8	9503 238630	ALEKSANDR MOROZOV	{"email": "morozov-a_1979@postgrespro.ru", "phone": "+70427587100"}
0005435068606	4FA872	0760 076924	DMITRIY BELOV	{"email": "belov_dmitriy1970@postgrespro.ru", "phone": "+70186589634"}
0005435068607	EF3DDE	3295 556125	MIKHAIL SERGEEV	{"phone": "+70608822633"}
0005435068608	79FB66	2462 173609	NIKOLAY SCHERBAKOV	{"phone": "+70511101259"}
0005435068609	63072C	1102 397754	ALEKSANDR KRASNOV	{"email": "krasnov-aleksandr1985@postgrespro.ru", "phone": "+70717046718"}
0005435068610	63072C	5911 519562	SVETLANA ABRAMOVA	{"phone": "+70634675416"}
0005435068611	4CAE6A	4084 962369	ELENA MOISEEVA	{"email": "e.moiseeva_26091965@postgrespro.ru", "phone": "+70412264828"}
0005435068612	4BD17D	3971 778050	VALENTINA EGOROVA	{"phone": "+70344933233"}
0005435068613	85FEB1	9635 003635	IGOR KUZNECOV	{"email": "igor-kuznecov.061970@postgrespro.ru", "phone": "+70779776477"}
0005435068614	48F0B9	4571 335111	KRISTINA FROLOVA	{"email": "frolova-kristina_1972@postgrespro.ru", "phone": "+70501870198"}
0005435068615	3C3774	5945 640866	NIKOLAY MIKHAYLOV	{"email": "mikhaylov-n-1980@postgrespro.ru", "phone": "+70756144338"}
0005435068616	C5FBFD	6153 303979	ARMAN GUSEV	{"email": "gusev-a-031965@postgrespro.ru", "phone": "+70774657652"}
0005435068617	2D63EC	9922 388322	ALEKSANDR KAZAKOV	{"email": "a-kazakov-17111974@postgrespro.ru", "phone": "+70605610140"}
0005435068618	9E2BB6	5505 085139	TATYANA FADEEVA	{"email": "fadeevatatyana1967@postgrespro.ru", "phone": "+70467541439"}
0005435068619	71D4D2	9899 003571	ROMAN NIKITIN	{"email": "roman-nikitin16111973@postgrespro.ru", "phone": "+70431771247"}
0005435068620	71D4D2	9016 156046	ELENA NIKOLAEVA	{"email": "enikolaeva22111964@postgrespro.ru", "phone": "+70094285376"}
0005435068621	71D4D2	7717 431481	ALEKSEY MIKHAYLOV	{"phone": "+70441379813"}
0005435068622	F38FC6	6791 804705	ANASTASIYA ABRAMOVA	{"email": "abramova.anastasiya041966@postgrespro.ru", "phone": "+70461996656"}
0005435068623	F38FC6	7177 569392	SERGEY KRASNOV	{"phone": "+70726592281"}
0005435068624	2FE7D6	6178 744158	DANILA DENISOV	{"email": "denisov.danila1963@postgrespro.ru", "phone": "+70647734200"}
0005435068625	D493DD	6922 562147	ALEKSANDR MAKAROV	{"phone": "+70258596323"}
0005435068626	75486D	6761 611843	SVETLANA SOROKINA	{"phone": "+70162167869"}
0005435068627	C6B331	8095 819004	DMITRIY MATVEEV	{"email": "matveev_dmitriy-051971@postgrespro.ru", "phone": "+70800089687"}
0005435068628	E86F31	5534 309647	ALEKSANDR GUSEV	{"email": "a_gusev20091970@postgrespro.ru", "phone": "+70153382611"}
0005435068629	E86F31	7020 796463	YULIYA RODIONOVA	{"phone": "+70098053726"}
0005435068630	51C472	8194 478291	SVETLANA TARASOVA	{"email": "tarasovasvetlana-1966@postgrespro.ru", "phone": "+70422405005"}
0005435068631	5EEECA	5207 519021	VALERIY KISELEV	{"email": "kiselev-valeriy_081976@postgrespro.ru", "phone": "+70152893246"}
0005435068632	5EEECA	8088 097319	NIKOLAY SERGEEV	{"phone": "+70270818583"}
0005435068633	A68EF8	4952 800285	ANASTASIYA KOZLOVA	{"email": "kozlova-anastasiya.121964@postgrespro.ru", "phone": "+70188815991"}
0005435068634	A68EF8	3410 266253	SVETLANA FILIPPOVA	{"email": "filippovas.111971@postgrespro.ru", "phone": "+70492566183"}
0005435068635	099607	8518 458543	OLGA RYABOVA	{"phone": "+70193177268"}
0005435068636	099607	0432 137671	ELENA BORISOVA	{"email": "borisova_elena.16041973@postgrespro.ru", "phone": "+70871677492"}
0005435068637	5B9822	7743 493149	LYUDMILA NAZAROVA	{"email": "nazaroval27091976@postgrespro.ru", "phone": "+70205645384"}
0005435068638	5B9822	6588 969451	ANDREY FEDOTOV	{"email": "afedotov091968@postgrespro.ru", "phone": "+70388804487"}
0005435068639	387990	8057 875240	MIKHAIL KULIKOV	{"email": "mikhail-kulikov_24021964@postgrespro.ru", "phone": "+70082232548"}
0005435068640	387990	7229 079076	NADEZHDA ZAKHAROVA	{"phone": "+70428209987"}
0005435068641	FDB6BA	7613 354853	DMITRIY KULIKOV	{"email": "kulikov.dmitriy1968@postgrespro.ru", "phone": "+70041466545"}
0005435068642	FDB6BA	0933 020611	OLEG DAVYDOV	{"phone": "+70941604450"}
0005435068643	EEE5C5	5189 590771	OKSANA SMIRNOVA	{"email": "smirnova_o-06121987@postgrespro.ru", "phone": "+70233824066"}
0005435068644	59849F	1546 724807	EVGENIY PAVLOV	{"phone": "+70350550383"}
0005435068645	59849F	7019 494564	IGOR MELNIKOV	{"phone": "+70110782501"}
0005435068646	75C881	2381 740003	NAILYA EGOROVA	{"email": "egorova_n_03021970@postgrespro.ru", "phone": "+70826281370"}
0005435068647	98E187	1130 167487	LYUBOV ZAKHAROVA	{"phone": "+70292276217"}
0005435068648	7BA6B2	8836 324428	PAVEL KOZLOV	{"phone": "+70225738792"}
0005435068649	7BA6B2	4484 509942	TATYANA MAKAROVA	{"phone": "+70707257075"}
0005435068650	45078B	6236 329786	KSENIYA GUSEVA	{"email": "k.guseva_05111974@postgrespro.ru", "phone": "+70214744898"}
0005435068651	24FD6F	4997 628044	ANDREY TIKHONOV	{"phone": "+70382951921"}
0005435068652	9C219F	8826 903417	SERGEY VASILEV	{"phone": "+70529996758"}
0005435068653	CE03DF	3588 221173	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr.04111978@postgrespro.ru", "phone": "+70290741450"}
0005435068654	3A2AA7	6516 015487	VLADIMIR ILIN	{"email": "ilin-vladimir.14101974@postgrespro.ru", "phone": "+70041337967"}
0005435068655	3A2AA7	6282 375155	SERGEY NOVIKOV	{"email": "novikov.sergey_1957@postgrespro.ru", "phone": "+70011150056"}
0005435068656	630DAF	5113 906051	EVGENIY DAVYDOV	{"email": "davydovevgeniy_1988@postgrespro.ru", "phone": "+70255821032"}
0005435068657	18B580	5495 603814	ALENA KRASNOVA	{"phone": "+70971693930"}
0005435068658	A323B7	1366 637080	KRISTINA ANTONOVA	{"email": "antonovakristina_1953@postgrespro.ru", "phone": "+70708886046"}
0005435068659	A323B7	5921 385224	VALENTINA IVANOVA	{"phone": "+70963367907"}
0005435068660	C3FB4E	0692 672413	ANDREY IVANOV	{"email": "a.ivanov101984@postgrespro.ru", "phone": "+70204620043"}
0005435068661	C3FB4E	7572 898017	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov.081965@postgrespro.ru", "phone": "+70705412515"}
0005435068662	3CF83B	3874 641612	VLADIMIR KUZNECOV	{"phone": "+70579810957"}
0005435068663	3CF83B	6567 870213	ALINA KUZNECOVA	{"phone": "+70323820100"}
0005435068664	35532C	9077 541079	IVAN EGOROV	{"phone": "+70196634954"}
0005435068665	C43385	8422 696124	NIKOLAY VASILEV	{"email": "n_vasilev-051964@postgrespro.ru", "phone": "+70483196080"}
0005435068666	FB1F16	0782 140174	RAZIYA POPOVA	{"email": "popova-r-20071962@postgrespro.ru", "phone": "+70275616852"}
0005435068667	571855	9380 797371	RAISA SOLOVEVA	{"phone": "+70440358222"}
0005435068668	F31B89	5517 036547	VERA DENISOVA	{"phone": "+70114317365"}
0005435068669	8922AF	7583 047884	LEONID IVANOV	{"phone": "+70177333818"}
0005435068670	7893EA	6169 583028	LYUBOV ZAYCEVA	{"phone": "+70647921797"}
0005435068671	7893EA	8659 880935	TIMOFEY DENISOV	{"email": "denisov.timofey-1962@postgrespro.ru", "phone": "+70321662124"}
0005435068672	3CD739	0210 868839	RINAT FROLOV	{"email": "rinat.frolov.091982@postgrespro.ru", "phone": "+70462776795"}
0005435068673	E80A77	4046 530841	NATALYA SOLOVEVA	{"phone": "+70661186490"}
0005435068674	299151	3653 561490	ALLA PETROVA	{"phone": "+70287291813"}
0005435068675	B29F3C	6058 763685	VALENTINA SOKOLOVA	{"phone": "+70578448235"}
0005435068676	CA0CFD	0140 370475	VIKTOR OSIPOV	{"email": "viktorosipov-111971@postgrespro.ru", "phone": "+70275135928"}
0005435068677	EC5BD2	1944 808110	SERGEY NAUMOV	{"phone": "+70450867321"}
0005435068678	316E25	1454 495557	ANATOLIY SHEVCHENKO	{"email": "shevchenko.a-17051959@postgrespro.ru", "phone": "+70757963300"}
0005435068679	EFCAB2	1174 699586	ELENA STEPANOVA	{"phone": "+70994063441"}
0005435068680	91B96E	3430 859891	LIDIYA KUZNECOVA	{"email": "l.kuznecova_1990@postgrespro.ru", "phone": "+70181165514"}
0005435068681	3DCC7B	2558 032639	MIKHAIL NIKOLAEV	{"phone": "+70017796341"}
0005435068682	3DCC7B	8816 709635	VENERA FROLOVA	{"email": "frolova_venera.071971@postgrespro.ru", "phone": "+70361697804"}
0005435068683	72744B	4907 352809	NADEZHDA MATVEEVA	{"phone": "+70470633410"}
0005435068684	72744B	4269 095034	EKATERINA KULIKOVA	{"phone": "+70984223888"}
0005435068685	564160	0586 733969	BOGDAN ISAEV	{"phone": "+70128799978"}
0005435068686	01D97A	0016 873221	ALISA MIKHAYLOVA	{"phone": "+70365400153"}
0005435068687	01D97A	2492 165945	NATALYA TIMOFEEVA	{"email": "timofeevan-061965@postgrespro.ru", "phone": "+70701963292"}
0005435068688	3EF1A6	9175 818763	OLEG NIKOLAEV	{"phone": "+70520754414"}
0005435068689	E858B4	2180 724353	ANDREY SCHERBAKOV	{"email": "a_scherbakov-31051981@postgrespro.ru", "phone": "+70449371434"}
0005435068690	E858B4	1424 980157	GALINA MOISEEVA	{"email": "g-moiseeva-1969@postgrespro.ru", "phone": "+70319018706"}
0005435068691	9656B4	8757 771592	YANA KUZNECOVA	{"phone": "+70555454556"}
0005435068692	E9C40C	0952 677939	YURIY SEMENOV	{"email": "yuriysemenov_1965@postgrespro.ru", "phone": "+70287375897"}
0005435068693	B6E4AE	5060 296733	OLGA KUDRYASHOVA	{"email": "kudryashova_olga.21041958@postgrespro.ru", "phone": "+70792561394"}
0005435068694	6EDEC2	1253 626312	SERGEY TARASOV	{"email": "s-tarasov19051980@postgrespro.ru", "phone": "+70531517605"}
0005435068695	6EDEC2	3656 345485	PAVEL ZHUKOV	{"email": "zhukov.p1966@postgrespro.ru", "phone": "+70830785178"}
0005435068696	59B963	8107 526562	GALINA SERGEEVA	{"phone": "+70401442027"}
0005435068697	09EF01	0916 775670	YURIY EGOROV	{"email": "yegorov.061973@postgrespro.ru", "phone": "+70072710356"}
0005435068698	09EF01	7035 874756	VITALIY POPOV	{"phone": "+70860792680"}
0005435068699	B8F3CD	8292 305928	VLADISLAV EGOROV	{"phone": "+70608136220"}
0005435068700	B8F3CD	7683 735533	ALEKSEY MEDVEDEV	{"email": "alekseymedvedev_24051971@postgrespro.ru", "phone": "+70109256389"}
0005435068701	87ADF8	4917 582004	YULIYA LEBEDEVA	{"phone": "+70747567903"}
0005435068702	87ADF8	8726 576174	EGOR SOKOLOV	{"email": "e.sokolov.1971@postgrespro.ru", "phone": "+70027562721"}
0005435068703	9F9F4E	5212 051605	EVGENIYA ANDREEVA	{"phone": "+70559303436"}
0005435068704	0A044C	2256 069069	ILYA MELNIKOV	{"phone": "+70192191771"}
0005435068705	D10A86	4124 050078	OLESYA MAKAROVA	{"phone": "+70890115596"}
0005435068706	C02153	2971 346564	VALENTINA KISELEVA	{"email": "kiselevav.15071968@postgrespro.ru", "phone": "+70823191492"}
0005435068707	ECB2CE	8714 483023	ANASTASIYA VOLKOVA	{"phone": "+70001179481"}
0005435068708	ACE86B	6070 994044	ELIZAVETA GORBUNOVA	{"email": "elizaveta.gorbunova.05071971@postgrespro.ru", "phone": "+70935884018"}
0005435068709	ACE86B	2988 168023	VLADIMIR MIKHAYLOV	{"phone": "+70959402068"}
0005435068710	D9B49D	0332 942681	TATYANA SERGEEVA	{"email": "tatyanasergeeva081978@postgrespro.ru", "phone": "+70707074247"}
0005435068711	900774	3908 818927	YURIY KRASNOV	{"phone": "+70855211047"}
0005435068712	D2B806	3034 776484	ANDREY KAZAKOV	{"email": "andrey.kazakov06061978@postgrespro.ru", "phone": "+70110370868"}
0005435068713	3B4505	2396 694318	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila.021977@postgrespro.ru", "phone": "+70335076175"}
0005435068714	3B4505	6762 436951	YURIY GAVRILOV	{"phone": "+70268136780"}
0005435068715	1E4DF8	7355 000029	VLADIMIR GUSEV	{"phone": "+70945507151"}
0005435068716	1E4DF8	0297 651131	NIKOLAY TIMOFEEV	{"email": "timofeev.n.021978@postgrespro.ru", "phone": "+70249242862"}
0005435068717	1F38D9	1126 011239	OLEG KAZAKOV	{"email": "o.kazakov-1965@postgrespro.ru", "phone": "+70732132054"}
0005435068718	3DDA22	3009 664964	EVGENIY STEPANOV	{"phone": "+70725563704"}
0005435068719	7D2703	7413 366362	VIKTOR FOMIN	{"phone": "+70736649000"}
0005435068720	7D2703	6469 011452	YULIYA VASILEVA	{"email": "vasilevayuliya.081980@postgrespro.ru", "phone": "+70855353915"}
0005435068721	1542B1	9716 335900	EKATERINA SOLOVEVA	{"phone": "+70676844818"}
0005435068722	1542B1	9446 591866	MIKHAIL SERGEEV	{"phone": "+70725469652"}
0005435068723	7F291A	9849 768793	ANNA VLASOVA	{"phone": "+70220666080"}
0005435068724	7F291A	4372 498498	ANTON RODIONOV	{"phone": "+70155869522"}
0005435068725	EEC61F	9462 468982	YURIY BORISOV	{"email": "yuriy.borisov_1966@postgrespro.ru", "phone": "+70249994168"}
0005435068726	A27B4C	7968 533058	SERGEY KAZAKOV	{"email": "kazakov_sergey121974@postgrespro.ru", "phone": "+70034362114"}
0005435068727	4B90B3	6259 161832	NINA GRISHINA	{"phone": "+70093960687"}
0005435068728	4B90B3	8005 185139	ANGELINA DENISOVA	{"phone": "+70307633233"}
0005435068729	4B90B3	3504 960283	TATYANA SMIRNOVA	{"phone": "+70596279933"}
0005435068730	76F5E3	3114 923960	NATALYA NAUMOVA	{"phone": "+70594196327"}
0005435068731	64BAD4	6561 734438	ALEKSANDRA OSIPOVA	{"email": "osipova-a1969@postgrespro.ru", "phone": "+70120596243"}
0005435068732	B51B86	9903 285197	ANNA KUZNECOVA	{"email": "a.kuznecova13091977@postgrespro.ru", "phone": "+70081615907"}
0005435068733	516F72	8730 708909	NADEZHDA LUKYANOVA	{"phone": "+70480993115"}
0005435068734	516F72	4480 377133	ANDREY MIRONOV	{"phone": "+70215192557"}
0005435068735	DDDDFF	3656 271476	DMITRIY MOROZOV	{"email": "d.morozov11031962@postgrespro.ru", "phone": "+70104210616"}
0005435068736	07B124	0802 475432	ALEKSANDR MOISEEV	{"email": "moiseev.a.101965@postgrespro.ru", "phone": "+70785146120"}
0005435068737	07B124	6614 473502	NATALYA SOLOVEVA	{"email": "solovevanatalya041972@postgrespro.ru", "phone": "+70108769126"}
0005435068857	372085	1969 065600	TAISA NOVIKOVA	{"phone": "+70165298647"}
0005435068917	17FF5E	4940 796609	VITALIY MEDVEDEV	{"phone": "+70305050542"}
0005435068738	42A61C	1984 349763	SERGEY VOLKOV	{"email": "s.volkov1969@postgrespro.ru", "phone": "+70259018876"}
0005435068739	930CE2	9394 893748	DANIIL MELNIKOV	{"email": "melnikovdaniil_08061975@postgrespro.ru", "phone": "+70747646463"}
0005435068740	930CE2	6669 642017	VASILIY SEMENOV	{"phone": "+70445275594"}
0005435068741	139B6B	2162 312827	TATYANA POTAPOVA	{"phone": "+70848047832"}
0005435068742	139B6B	2198 969354	NATALYA YUDINA	{"email": "yudina_n1979@postgrespro.ru", "phone": "+70185107334"}
0005435068743	90D1AA	5082 971308	VYACHESLAV ROMANOV	{"phone": "+70857959117"}
0005435068744	A2F4AF	9686 255470	SERGEY ISAEV	{"phone": "+70203070476"}
0005435068745	A2F4AF	5671 286963	ANNA FEDOROVA	{"phone": "+70158507993"}
0005435068746	28B2CC	1655 509957	NATALYA KISELEVA	{"email": "kiseleva_n28061974@postgrespro.ru", "phone": "+70006287678"}
0005435068747	28B2CC	7027 950543	ALEKSANDR GRIGOREV	{"phone": "+70484040456"}
0005435068748	28B2CC	4534 913836	ALEKSANDR DMITRIEV	{"email": "dmitriev-a.031974@postgrespro.ru", "phone": "+70480710113"}
0005435068749	49F687	5328 927795	OLGA MELNIKOVA	{"email": "melnikova-olga.1977@postgrespro.ru", "phone": "+70938139927"}
0005435068750	35F450	7839 313736	OLGA KUZMINA	{"phone": "+70863406072"}
0005435068751	35F450	9223 844021	ALLA FILATOVA	{"email": "filatova_alla_05111968@postgrespro.ru", "phone": "+70591660530"}
0005435068752	13BE36	0436 956355	SVETLANA SOLOVEVA	{"email": "s.soloveva.21081976@postgrespro.ru", "phone": "+70487936377"}
0005435068753	830C25	4275 314886	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrovaanastasiya-051979@postgrespro.ru", "phone": "+70390108287"}
0005435068754	C94ED6	3793 873430	MIKHAIL MIKHAYLOV	{"phone": "+70829482747"}
0005435068755	844604	6810 597751	OLGA ZHUKOVA	{"phone": "+70331188235"}
0005435068756	844604	7665 438673	EVGENIY CHERNOV	{"phone": "+70621801766"}
0005435068757	5B8E11	7324 834348	GENNADIY MAKAROV	{"email": "makarov-g101980@postgrespro.ru", "phone": "+70925979022"}
0005435068758	5B8E11	4921 863749	ANDREY MELNIKOV	{"email": "melnikov-a24091971@postgrespro.ru", "phone": "+70032864314"}
0005435068759	D783C7	2789 812492	SERGEY NAZAROV	{"phone": "+70185476181"}
0005435068760	9BEB63	8053 254990	LIDIYA ANDREEVA	{"phone": "+70967786016"}
0005435068761	C2A6ED	6347 343960	NATALIYA ANISIMOVA	{"phone": "+70970841272"}
0005435068762	4E02EF	7558 949433	ALEKSANDR KULIKOV	{"email": "a.kulikov.121977@postgrespro.ru", "phone": "+70703889757"}
0005435068763	4E02EF	8107 676140	LYUBOV NESTEROVA	{"email": "l_nesterova_1971@postgrespro.ru", "phone": "+70334331971"}
0005435068764	33A25C	0848 803848	GLEB VLASOV	{"email": "vlasov_gleb18011974@postgrespro.ru", "phone": "+70048005713"}
0005435068765	C8DABE	2988 583220	ROMAN MAKAROV	{"email": "makarov.roman_20041967@postgrespro.ru", "phone": "+70775205060"}
0005435068766	11A334	6780 746239	ROMAN PETROV	{"email": "romanpetrov.121968@postgrespro.ru", "phone": "+70662200467"}
0005435068767	F4805F	8012 554324	IRINA MEDVEDEVA	{"email": "i-medvedeva-101959@postgrespro.ru", "phone": "+70254499291"}
0005435068768	7DB21A	6087 752054	KIRILL MAKAROV	{"phone": "+70728158580"}
0005435068769	7DB21A	0698 996189	GERMAN DMITRIEV	{"email": "gdmitriev_1985@postgrespro.ru", "phone": "+70714201424"}
0005435068770	7A755A	0059 434205	ALEKSANDR PAVLOV	{"phone": "+70922445094"}
0005435068771	801E27	2257 183367	NINA POPOVA	{"email": "npopova1982@postgrespro.ru", "phone": "+70566345112"}
0005435068772	801E27	8904 084905	ALEKSANDR SEMENOV	{"phone": "+70485470547"}
0005435068773	801E27	6075 356237	ALEKSEY NAZAROV	{"email": "a.nazarov-13081967@postgrespro.ru", "phone": "+70155698680"}
0005435068774	47E8CC	2615 586204	IVAN SCHERBAKOV	{"email": "ivan_scherbakov.1969@postgrespro.ru", "phone": "+70891922066"}
0005435068775	748EA4	5509 926445	GALINA LAZAREVA	{"email": "lazarevag111982@postgrespro.ru", "phone": "+70872226700"}
0005435068776	FA9A50	0462 761297	ELENA FILIPPOVA	{"email": "elenafilippova_1970@postgrespro.ru", "phone": "+70571734294"}
0005435068777	6E5B47	2868 534530	AYRAT SCHERBAKOV	{"phone": "+70989050278"}
0005435068778	739A41	3593 467341	ALINA VOLKOVA	{"email": "avolkova.05121973@postgrespro.ru", "phone": "+70295959865"}
0005435068779	9AD2B7	1361 418631	EKATERINA TIMOFEEVA	{"phone": "+70515548497"}
0005435068780	9AD2B7	0841 778990	NIKOLAY KUZMIN	{"phone": "+70392423861"}
0005435068781	2EB921	2032 379052	VITALIY ALEKSEEV	{"phone": "+70613447861"}
0005435068782	2EB921	3946 307924	YURIY IVANOV	{"phone": "+70466089448"}
0005435068783	86DA5A	3570 573042	OLEG ROMANOV	{"phone": "+70194186702"}
0005435068784	A35FFA	5429 809002	ALEKSANDR KOROLEV	{"email": "korolev-a.041965@postgrespro.ru", "phone": "+70851734459"}
0005435068785	A400BB	9605 408372	YURIY FROLOV	{"email": "y.frolov1981@postgrespro.ru", "phone": "+70834429659"}
0005435068786	CD5B1B	8320 487100	ELENA KONDRATEVA	{"phone": "+70334649219"}
0005435068787	1F5449	6654 294191	LYUDMILA NIKITINA	{"phone": "+70647744643"}
0005435068788	AFE478	2982 556482	DENIS ZAYCEV	{"phone": "+70346313959"}
0005435068789	C17420	7014 319910	IRINA ZHURAVLEVA	{"phone": "+70489982647"}
0005435068790	4DE61C	6191 932698	MIKHAIL VASILEV	{"phone": "+70260786189"}
0005435068791	1D2557	1077 328491	MARIYA OSIPOVA	{"email": "m-osipova.31101970@postgrespro.ru", "phone": "+70039380350"}
0005435068792	1D3312	9557 548040	VALENTINA NIKITINA	{"email": "valentina_nikitina081967@postgrespro.ru", "phone": "+70968771093"}
0005435068793	CEBE43	8341 556339	DENIS PETROV	{"email": "denispetrov111978@postgrespro.ru", "phone": "+70442897134"}
0005435068794	4172FA	8075 809857	ANASTASIYA POPOVA	{"email": "anastasiya-popova-1976@postgrespro.ru", "phone": "+70853665073"}
0005435068795	360A74	4548 437323	VITALIY POPOV	{"email": "vitaliypopov_011960@postgrespro.ru", "phone": "+70810637666"}
0005435068796	A8DD89	0818 481999	GALINA ISAEVA	{"phone": "+70564512998"}
0005435068797	A8DD89	1395 876545	SVETLANA ROMANOVA	{"email": "sromanova.1980@postgrespro.ru", "phone": "+70340555387"}
0005435068798	C4CC98	6286 834164	NATALYA IVANOVA	{"email": "n.ivanova-1972@postgrespro.ru", "phone": "+70560111079"}
0005435068799	E28D23	6323 779121	NIKOLAY SHEVCHENKO	{"email": "n_shevchenko.1982@postgrespro.ru", "phone": "+70640197983"}
0005435068800	5D4F37	9950 250195	NIKOLAY ALEKSANDROV	{"phone": "+70187260364"}
0005435068801	5D4F37	5858 126731	ELENA DAVYDOVA	{"email": "davydovaelena_09021958@postgrespro.ru", "phone": "+70173188645"}
0005435068802	A4D1D1	7424 192818	SERGEY NOVIKOV	{"email": "novikovsergey29071990@postgrespro.ru", "phone": "+70469024766"}
0005435068803	A4D1D1	7519 668562	ALEKSANDR NIKOLAEV	{"phone": "+70317465816"}
0005435068804	A4D1D1	9667 134964	IGOR SHEVCHENKO	{"email": "ishevchenko-08101973@postgrespro.ru", "phone": "+70581465081"}
0005435068805	E803FB	4539 970639	PELAGEYA BORISOVA	{"phone": "+70388921995"}
0005435068806	E803FB	5146 551425	ALEKSANDR KUZNECOV	{"phone": "+70914708830"}
0005435068807	6336A8	1459 362608	DMITRIY ABRAMOV	{"email": "abramovdmitriy_28021983@postgrespro.ru", "phone": "+70554938695"}
0005435068808	6336A8	8277 988789	EVGENIY PETROV	{"email": "evgeniy.petrov_051969@postgrespro.ru", "phone": "+70031529270"}
0005435068809	A0664B	9576 540509	RAIS MIKHAYLOV	{"phone": "+70271634365"}
0005435068810	6BB72A	9805 124518	YURIY MAKSIMOV	{"phone": "+70361515603"}
0005435068811	6BB72A	6554 524328	ALEKSEY MEDVEDEV	{"email": "medvedeva-1969@postgrespro.ru", "phone": "+70909863438"}
0005435068812	E7DF75	8446 789308	GALINA KISELEVA	{"email": "g_kiseleva-051978@postgrespro.ru", "phone": "+70492146593"}
0005435068813	87D2C9	4940 239662	VERA NIKITINA	{"email": "vnikitina1971@postgrespro.ru", "phone": "+70963855613"}
0005435068814	87D2C9	6844 415103	DENIS PETROV	{"phone": "+70831061547"}
0005435068815	698E07	0132 765759	DANILA IVANOV	{"email": "danilaivanov_1979@postgrespro.ru", "phone": "+70324017003"}
0005435068816	5196F7	6648 105258	SERGEY KONOVALOV	{"email": "konovalov-sergey.1974@postgrespro.ru", "phone": "+70487117925"}
0005435068817	18AE36	1846 479755	TATYANA VOLKOVA	{"email": "t_volkova_041968@postgrespro.ru", "phone": "+70462961323"}
0005435068818	B76C30	8601 081287	ELENA SMIRNOVA	{"phone": "+70105625116"}
0005435068819	98BFE7	3149 848663	ALENA FOMINA	{"phone": "+70066269535"}
0005435068820	98BFE7	9048 098099	NIKOLAY KUZNECOV	{"email": "kuznecov_n-041961@postgrespro.ru", "phone": "+70744669954"}
0005435068821	98BFE7	2294 683959	VALERIYA MALYSHEVA	{"email": "v_malysheva26011967@postgrespro.ru", "phone": "+70319143965"}
0005435068822	536B12	6379 460063	MAKSIM ISAEV	{"email": "isaevmaksim_05121969@postgrespro.ru", "phone": "+70551033987"}
0005435068823	082A8A	6576 108178	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev.121977@postgrespro.ru", "phone": "+70870793151"}
0005435068824	684214	6672 874006	VALENTINA MELNIKOVA	{"email": "v.melnikova_05041974@postgrespro.ru", "phone": "+70232981425"}
0005435068825	684214	2139 144742	OLEG VLASOV	{"email": "oleg_vlasov-031971@postgrespro.ru", "phone": "+70482129397"}
0005435068826	3C93F2	5896 488196	NIKOLAY VOLKOV	{"email": "volkov-n021966@postgrespro.ru", "phone": "+70744008807"}
0005435068827	1AEF61	0925 848843	VLADISLAV BONDARENKO	{"phone": "+70984946975"}
0005435068828	5626CE	6780 567053	EVGENIYA NOVIKOVA	{"phone": "+70695288259"}
0005435068829	5626CE	4032 301180	ALEKSANDR EGOROV	{"phone": "+70673827843"}
0005435068830	3EE83C	9300 258326	MARIYA KRASNOVA	{"email": "mariya.krasnova.071959@postgrespro.ru", "phone": "+70165671575"}
0005435068831	3EE83C	0654 298065	SERGEY NIKOLAEV	{"email": "sergey-nikolaev031969@postgrespro.ru", "phone": "+70722522170"}
0005435068832	61794A	1731 901282	SERGEY NIKITIN	{"phone": "+70979893533"}
0005435068833	61794A	0056 668285	KRISTINA NIKOLAEVA	{"phone": "+70113150787"}
0005435068834	D148C3	6648 284951	OLGA ROMANOVA	{"email": "oromanova-041971@postgrespro.ru", "phone": "+70666903175"}
0005435068835	1408A0	3212 800134	IRINA MOISEEVA	{"email": "irina-moiseeva.1971@postgrespro.ru", "phone": "+70484920435"}
0005435068836	27D656	6791 393231	NATALYA MOROZOVA	{"phone": "+70337325510"}
0005435068837	0C5E9C	2638 393203	MARIYA NAUMOVA	{"email": "naumova_m_1987@postgrespro.ru", "phone": "+70049465834"}
0005435068838	A27D19	2410 086288	SERGEY ISAEV	{"email": "sergeyisaev.17011956@postgrespro.ru", "phone": "+70039535342"}
0005435068839	48BB42	9035 981552	OKSANA TARASOVA	{"phone": "+70364988045"}
0005435068840	E8F80C	1429 527814	EVGENIY ZHUKOV	{"email": "e-zhukov21031971@postgrespro.ru", "phone": "+70577096777"}
0005435068841	E8F80C	1820 288984	MAKSIM ZAKHAROV	{"phone": "+70798599039"}
0005435068842	493A24	5652 112485	DENIS MARTYNOV	{"phone": "+70009633679"}
0005435068843	51837F	1355 038704	LARISA DAVYDOVA	{"email": "davydova-larisa1981@postgrespro.ru", "phone": "+70321579653"}
0005435068844	5A90C5	4945 444139	ZINAIDA ZHURAVLEVA	{"email": "zinaida_zhuravleva.031989@postgrespro.ru", "phone": "+70893253093"}
0005435068845	5A90C5	7395 437724	PETR ROMANOV	{"phone": "+70304715368"}
0005435068846	66E488	1422 847236	IRINA LAZAREVA	{"email": "i.lazareva_1980@postgrespro.ru", "phone": "+70716285179"}
0005435068847	5B5725	8249 019393	ARTEM MELNIKOV	{"phone": "+70203302482"}
0005435068848	5B5725	7983 898158	KONSTANTIN SEMENOV	{"phone": "+70466364850"}
0005435068849	E14FA5	3865 393585	SVETLANA YAKOVLEVA	{"phone": "+70208196229"}
0005435068850	E14FA5	2547 574835	ARTEM GRIGOREV	{"email": "artemgrigorev-031966@postgrespro.ru", "phone": "+70090686942"}
0005435068851	746353	2638 953729	EVGENIY ZHURAVLEV	{"phone": "+70494567499"}
0005435068852	746353	5840 263480	ANTON NOVIKOV	{"phone": "+70499391349"}
0005435068853	746353	4595 348017	ARINA POPOVA	{"email": "popova.arina.1973@postgrespro.ru", "phone": "+70726504003"}
0005435068854	6E6D51	9419 746666	VIKTOR KOZLOV	{"phone": "+70762892844"}
0005435068855	BE577F	8673 827350	ANGELINA TARASOVA	{"phone": "+70578959936"}
0005435068856	BE577F	0424 656589	DMITRIY MOROZOV	{"email": "d_morozov1960@postgrespro.ru", "phone": "+70507263493"}
0005435068858	372085	2626 165320	MARIYA SERGEEVA	{"email": "sergeeva-m_1963@postgrespro.ru", "phone": "+70454805987"}
0005435068859	3BA9B7	7310 072507	MARINA KUZMINA	{"phone": "+70454333784"}
0005435068860	BC6AB4	8721 360497	NIKOLAY MAKSIMOV	{"email": "maksimov_nikolay_101962@postgrespro.ru", "phone": "+70708556961"}
0005435068861	EF14DF	8288 246505	VLADIMIR PETROV	{"email": "petrovvladimir1979@postgrespro.ru", "phone": "+70025076116"}
0005435068862	4CC10D	0449 205735	LYUDMILA MARTYNOVA	{"email": "martynoval1980@postgrespro.ru", "phone": "+70332572316"}
0005435068863	4CC10D	7981 608538	IVAN GORBUNOV	{"phone": "+70774519079"}
0005435068864	27EBBF	9492 206335	ELENA KAZAKOVA	{"email": "kazakova_elena.051969@postgrespro.ru", "phone": "+70168118896"}
0005435068865	8B262B	9012 090127	EKATERINA KONOVALOVA	{"email": "konovalova-e1975@postgrespro.ru", "phone": "+70203338644"}
0005435068866	36F31F	3755 993437	VYACHESLAV SERGEEV	{"phone": "+70044753367"}
0005435068867	1A2063	8572 271292	LYUBOV GAVRILOVA	{"email": "lyubov_gavrilova.071970@postgrespro.ru", "phone": "+70966022310"}
0005435068868	6D4121	9546 539575	YULIYA GAVRILOVA	{"email": "gavrilova_y1987@postgrespro.ru", "phone": "+70913057269"}
0005435068869	8B1338	5989 882024	ALEKSANDR IVANOV	{"phone": "+70029602168"}
0005435068870	F29F48	5830 707281	BORIS KONOVALOV	{"email": "b.konovalov_15091973@postgrespro.ru", "phone": "+70272777236"}
0005435068871	ED946F	9028 030467	NIKOLAY ABRAMOV	{"phone": "+70324524988"}
0005435068872	474F2D	0548 344044	EKATERINA KUZNECOVA	{"email": "kuznecova-e.051964@postgrespro.ru", "phone": "+70631803502"}
0005435068873	474F2D	0250 848614	NIKITA STEPANOV	{"phone": "+70107954201"}
0005435068874	412E90	2555 780241	ILYA GERASIMOV	{"phone": "+70370959867"}
0005435068875	70F52B	3777 610605	ARTEM SEMENOV	{"email": "semenov.a1968@postgrespro.ru", "phone": "+70055570330"}
0005435068876	70F52B	7684 243270	ALEKSANDR NIKITIN	{"email": "aleksandr-nikitin.031971@postgrespro.ru", "phone": "+70312125553"}
0005435068877	70F52B	2219 954826	SERGEY BORISOV	{"email": "borisov-s-101974@postgrespro.ru", "phone": "+70579281049"}
0005435068878	0CDB82	9402 418383	DARYA FROLOVA	{"email": "frolova_d121978@postgrespro.ru", "phone": "+70645718646"}
0005435068879	37F086	7560 915591	IRINA EGOROVA	{"email": "i_egorova.11121965@postgrespro.ru", "phone": "+70692234244"}
0005435068880	C16ED7	9206 978490	EVGENIYA SAVELEVA	{"phone": "+70038370416"}
0005435068881	C16ED7	1356 282946	VLADISLAV FOMIN	{"email": "vfomin.15061972@postgrespro.ru", "phone": "+70259994647"}
0005435068882	357524	7774 291572	ELENA ROMANOVA	{"phone": "+70980174904"}
0005435068883	4CC4CC	6360 939673	ANZHELIKA MATVEEVA	{"email": "anzhelika-matveeva_27111975@postgrespro.ru", "phone": "+70297825406"}
0005435068884	6826F8	8057 412419	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov111975@postgrespro.ru", "phone": "+70393374966"}
0005435068885	FD4C2E	9721 143241	ELENA KONDRATEVA	{"phone": "+70180892379"}
0005435068886	E3C0A5	3487 189834	GALIYA BORISOVA	{"email": "g.borisova041974@postgrespro.ru", "phone": "+70365474676"}
0005435068887	E3C0A5	4005 627164	DMITRIY ILIN	{"email": "ilindmitriy.081967@postgrespro.ru", "phone": "+70255861895"}
0005435068888	689422	5447 066727	NATALIYA IVANOVA	{"email": "ivanova_n12021984@postgrespro.ru", "phone": "+70715213580"}
0005435068889	689422	0304 327161	IGOR NAZAROV	{"email": "igor.nazarov1962@postgrespro.ru", "phone": "+70925754947"}
0005435068890	9FDFCA	8973 648445	TATYANA KONOVALOVA	{"phone": "+70107177894"}
0005435068891	CCD11A	7912 688233	IGOR IVANOV	{"email": "ivanovigor.1969@postgrespro.ru", "phone": "+70091150545"}
0005435068892	F024EE	0803 941349	VITALIY MAKAROV	{"phone": "+70832118395"}
0005435068893	86411D	8290 251532	MAKSIM KUZMIN	{"phone": "+70719620838"}
0005435068894	6F9E74	6463 837797	MARIYA KALININA	{"phone": "+70828332177"}
0005435068895	6F9E74	4951 817916	PAVEL GORBUNOV	{"phone": "+70731145234"}
0005435068896	95D75D	5898 623576	GALINA NOVIKOVA	{"phone": "+70793503729"}
0005435068897	B98D9A	8611 623069	DENIS FEDOTOV	{"phone": "+70970870504"}
0005435068898	B98D9A	4611 666840	DMITRIY NIKOLAEV	{"phone": "+70396615262"}
0005435068899	6F04BB	7516 610683	MIKHAIL PETROV	{"phone": "+70180498324"}
0005435068900	6F04BB	9989 297037	MARIYA KONDRATEVA	{"email": "mariya-kondrateva_23121965@postgrespro.ru", "phone": "+70458062441"}
0005435068901	852E63	0190 110333	IGOR SERGEEV	{"phone": "+70228840203"}
0005435068902	941A6E	6303 995073	IGOR TIMOFEEV	{"email": "timofeev-i-081960@postgrespro.ru", "phone": "+70978135419"}
0005435068903	941A6E	5286 309203	SVETLANA BARANOVA	{"phone": "+70736379628"}
0005435068904	114695	4609 709587	YURIY DMITRIEV	{"email": "dmitriev_yuriy_1950@postgrespro.ru", "phone": "+70831524895"}
0005435068905	114695	9346 187234	EGOR MAKSIMOV	{"email": "e.maksimov06011969@postgrespro.ru", "phone": "+70925660478"}
0005435068906	240BB4	7072 420878	VLADIMIR NOVIKOV	{"email": "vladimir.novikov_01031968@postgrespro.ru", "phone": "+70955849148"}
0005435068907	7FB938	6966 840423	IGOR VLASOV	{"email": "vlasov_i_051971@postgrespro.ru", "phone": "+70902456057"}
0005435068908	7FB938	9882 981215	PETR OSIPOV	{"phone": "+70271153494"}
0005435068909	57AA9A	6151 106287	DARYA ALEKSEEVA	{"phone": "+70499110134"}
0005435068910	57AA9A	8291 270533	NADEZHDA PAVLOVA	{"email": "nadezhda.pavlova-03071959@postgrespro.ru", "phone": "+70914117026"}
0005435068911	0B974D	5998 123986	MARINA ILINA	{"email": "ilina_m.28121973@postgrespro.ru", "phone": "+70676207174"}
0005435068912	29580E	4230 422097	VIKTOR NAUMOV	{"email": "v.naumov_051978@postgrespro.ru", "phone": "+70594161901"}
0005435068913	43599B	9695 591539	ALEKSEY TIKHONOV	{"email": "tikhonov_a1971@postgrespro.ru", "phone": "+70993729855"}
0005435068914	3C5F15	5836 626335	MARIYA KOLESNIKOVA	{"phone": "+70201810326"}
0005435068915	3C5F15	0132 125323	OLGA TROFIMOVA	{"phone": "+70573889806"}
0005435068916	9746A6	5082 080785	MARINA BORISOVA	{"email": "borisova_marina_021973@postgrespro.ru", "phone": "+70961806296"}
0005435068918	17FF5E	6176 270720	VIKTOR SOROKIN	{"phone": "+70808716689"}
0005435068919	3DAA65	2415 687525	OLGA MATVEEVA	{"phone": "+70209656804"}
0005435068920	3ADE33	0783 462550	MIKHAIL ROMANOV	{"email": "romanov-mikhail-30081979@postgrespro.ru", "phone": "+70967561349"}
0005435068921	93EE69	4271 927491	ANZHELIKA LAZAREVA	{"phone": "+70543725434"}
0005435068922	B30F94	1575 277147	TATYANA NIKOLAEVA	{"phone": "+70467398647"}
0005435068923	0DCE82	6671 432328	SERGEY MOROZOV	{"email": "sergeymorozov-1969@postgrespro.ru", "phone": "+70502127772"}
0005435068924	E21A74	0782 659584	ELENA KUZNECOVA	{"phone": "+70486172389"}
0005435068925	D11BE5	6439 485837	ROZA KULIKOVA	{"email": "roza-kulikova.16021979@postgrespro.ru", "phone": "+70537854731"}
0005435068926	D11BE5	6499 470938	YULIYA FEDOROVA	{"email": "fedorova_y031982@postgrespro.ru", "phone": "+70198428112"}
0005435068927	97875E	4123 780934	VASILIY FROLOV	{"email": "frolov.v.021967@postgrespro.ru", "phone": "+70138093624"}
0005435068928	01D88E	8595 228425	ALEKSANDR FOMIN	{"email": "aleksandr.fomin-041963@postgrespro.ru", "phone": "+70612449506"}
0005435068929	BB78CD	2919 170407	ANDREY CHERNOV	{"email": "chernov-a_121973@postgrespro.ru", "phone": "+70018458871"}
0005435068930	86189B	9309 047456	YULIYA ROMANOVA	{"email": "romanova_y-1970@postgrespro.ru", "phone": "+70189909051"}
0005435068931	86189B	2399 778236	ELIZAVETA GUSEVA	{"phone": "+70481934997"}
0005435068932	1BA70E	3904 260337	OLEG FEDOROV	{"phone": "+70250651876"}
0005435068933	4B88ED	9748 841781	YULIANA ANTONOVA	{"phone": "+70651194625"}
0005435068934	DEB7F8	5011 154961	VIKTOR KRASNOV	{"email": "krasnov-v-15011974@postgrespro.ru", "phone": "+70910073970"}
0005435068935	692E97	6721 233160	NATALYA KARPOVA	{"email": "n.karpova.041967@postgrespro.ru", "phone": "+70798874051"}
0005435068936	107570	5364 241268	KSENIYA STEPANOVA	{"email": "kseniyastepanova.1976@postgrespro.ru", "phone": "+70299694395"}
0005435068937	107570	2707 798836	ALEKSANDR RODIONOV	{"email": "aleksandr-rodionov_061980@postgrespro.ru", "phone": "+70917913955"}
0005435068938	4F5947	3984 769790	SERGEY YAKOVLEV	{"phone": "+70231609422"}
0005435068939	47DF6B	6502 487428	VALERIY AFANASEV	{"phone": "+70813834017"}
0005435068940	A00D26	7257 384599	ALEFTINA LAZAREVA	{"phone": "+70874373056"}
0005435068941	5A4F84	1440 578769	NIKOLAY IVANOV	{"email": "nikolay.ivanov19071984@postgrespro.ru", "phone": "+70189126872"}
0005435068942	8A24F3	1719 863803	ANDREY KOZLOV	{"email": "andrey.kozlov-15021962@postgrespro.ru", "phone": "+70793181645"}
0005435068943	2DDCC4	8037 367555	ALSU MAKAROVA	{"email": "alsu-makarova_061981@postgrespro.ru", "phone": "+70222170082"}
0005435068944	DD76BB	9797 623366	ILYA BORISOV	{"email": "ilya.borisov_081977@postgrespro.ru", "phone": "+70459847557"}
0005435068945	DD76BB	6400 992644	TATYANA GORBUNOVA	{"email": "gorbunovat-16051982@postgrespro.ru", "phone": "+70181787700"}
0005435068946	562E70	5943 281243	ANATOLIY NIKITIN	{"email": "nikitin.anatoliy_1978@postgrespro.ru", "phone": "+70697198435"}
0005435068947	DEC8B9	3587 056021	KIRILL KUZMIN	{"email": "kuzminkirill.041972@postgrespro.ru", "phone": "+70299870933"}
0005435068948	DEC8B9	0297 620435	ALEKSEY TIMOFEEV	{"phone": "+70413709182"}
0005435068949	C249DF	9243 919604	NIKOLAY KOZLOV	{"phone": "+70223150366"}
0005435068950	C249DF	5563 017255	IVAN SOKOLOV	{"phone": "+70149199541"}
0005435068951	CA2C45	3533 894049	VERONIKA KISELEVA	{"email": "veronika_kiseleva051976@postgrespro.ru", "phone": "+70644267159"}
0005435068952	CA2C45	5143 335738	EVGENIY BARANOV	{"email": "evgeniy.baranov081958@postgrespro.ru", "phone": "+70842189009"}
0005435068953	F5EC89	6612 268621	FARID GRIGOREV	{"email": "faridgrigorev_03111978@postgrespro.ru", "phone": "+70916568634"}
0005435068954	9F5BAC	9259 764900	ELIZAVETA BORISOVA	{"phone": "+70250095323"}
0005435068955	AB0AE9	8067 981246	IRINA MIKHAYLOVA	{"email": "i.mikhaylova1972@postgrespro.ru", "phone": "+70436608515"}
0005435068956	5752C7	6890 046285	SERGEY ZAYCEV	{"phone": "+70884558846"}
0005435068957	FD6562	2609 217519	IGOR SCHERBAKOV	{"email": "scherbakov_i_05021970@postgrespro.ru", "phone": "+70986116766"}
0005435068958	FD6562	7679 597004	ALEKSANDR BELOV	{"email": "a_belov1978@postgrespro.ru", "phone": "+70698304711"}
0005435068959	E0E544	3177 146693	ANATOLIY MOROZOV	{"phone": "+70883748718"}
0005435068960	0DBC03	5333 418272	LYUDMILA VOLKOVA	{"email": "lyudmila_volkova031978@postgrespro.ru", "phone": "+70881598360"}
0005435068961	0190F5	0563 635974	TAMARA FILIPPOVA	{"phone": "+70578731531"}
0005435068962	0190F5	9384 541153	VALENTINA KUZNECOVA	{"phone": "+70428670319"}
0005435068963	0F1297	1720 685553	VALENTINA ILINA	{"email": "ilinavalentina051965@postgrespro.ru", "phone": "+70178106515"}
0005435068964	0F1297	7754 872517	ALEKSANDR MIRONOV	{"phone": "+70864940764"}
0005435068965	7E84EB	0929 348495	IRINA ZAKHAROVA	{"phone": "+70923587720"}
0005435068966	095371	7998 556847	ALEKSEY KISELEV	{"phone": "+70174331068"}
0005435068967	095371	7847 452253	ANASTASIYA VLASOVA	{"phone": "+70672839000"}
0005435068968	93F57B	4317 309087	PAVEL BARANOV	{"phone": "+70183841472"}
0005435068969	93F57B	6347 367477	ANGELINA KUZNECOVA	{"phone": "+70976582835"}
0005435068970	C29431	9457 638192	YANA MIRONOVA	{"email": "mironova.y_1969@postgrespro.ru", "phone": "+70482711206"}
0005435068971	93C877	2650 233439	OLGA MARTYNOVA	{"email": "martynova_olga-22071978@postgrespro.ru", "phone": "+70272537504"}
0005435068972	2922F1	8129 012044	VLADIMIR MATVEEV	{"phone": "+70916947459"}
0005435068973	2922F1	7383 290698	ALEKSEY POPOV	{"phone": "+70107953190"}
0005435068974	1BAB1A	0621 913333	ZINAIDA NIKOLAEVA	{"email": "nikolaeva-z1966@postgrespro.ru", "phone": "+70370880963"}
0005435068975	6FB18B	9661 677702	SVETLANA MEDVEDEVA	{"phone": "+70772726832"}
0005435068976	4A01FC	6259 698789	SERGEY OSIPOV	{"phone": "+70211269092"}
0005435068977	3D09AF	5381 820925	EKATERINA IVANOVA	{"email": "ekaterina-ivanova_1972@postgrespro.ru", "phone": "+70722553155"}
0005435068978	6F4C8A	7643 759632	ALEKSANDR KUZNECOV	{"phone": "+70356395201"}
0005435068979	6F4C8A	2957 576723	DMITRIY SERGEEV	{"email": "sergeev.d31101974@postgrespro.ru", "phone": "+70326142163"}
0005435068980	F79C8F	1792 272293	FEDOR ZAKHAROV	{"phone": "+70630152271"}
0005435068981	A63DE7	4683 933446	SERGEY SHEVCHENKO	{"email": "shevchenko_s-071976@postgrespro.ru", "phone": "+70314251411"}
0005435068982	A5F2DC	7754 181433	EKATERINA SOROKINA	{"phone": "+70904986283"}
0005435068983	0E9993	3220 230793	RAVIL KUDRYASHOV	{"email": "kudryashovravil_14011977@postgrespro.ru", "phone": "+70801856717"}
0005435068984	0E9993	2266 248400	NELYA FILIPPOVA	{"email": "filippova-n_051964@postgrespro.ru", "phone": "+70974143148"}
0005435068985	8B4530	6599 191019	IRINA KRASNOVA	{"email": "krasnova-irina.091962@postgrespro.ru", "phone": "+70539768203"}
0005435068986	8B4530	9745 718603	GALINA FROLOVA	{"phone": "+70828408783"}
0005435068987	7AB2C9	4130 925997	NINA KOZLOVA	{"email": "n_kozlova06101974@postgrespro.ru", "phone": "+70571230783"}
0005435068988	7AB2C9	2691 347955	ANDREY SIDOROV	{"email": "a.sidorov.15041969@postgrespro.ru", "phone": "+70947164894"}
0005435068989	745567	5979 473904	VLADIMIR SMIRNOV	{"email": "v-smirnov1961@postgrespro.ru", "phone": "+70692049177"}
0005435068990	70771E	4427 717352	EKATERINA ILINA	{"email": "ilina.e-031974@postgrespro.ru", "phone": "+70548233432"}
0005435068991	2B9F87	2586 485953	DMITRIY SAVELEV	{"phone": "+70256511469"}
0005435068992	39CC16	9819 793685	VENERA KRASNOVA	{"email": "krasnova_venera061974@postgrespro.ru", "phone": "+70974897795"}
0005435068993	9ED385	9143 343694	ALEKSANDR KRASNOV	{"email": "krasnov_a.061973@postgrespro.ru", "phone": "+70147304955"}
0005435068994	244806	1619 224362	NIKOLAY SMIRNOV	{"email": "nikolay.smirnov1970@postgrespro.ru", "phone": "+70246233837"}
0005435068995	53CCF1	9768 363828	YULIYA RODIONOVA	{"email": "rodionova_yuliya-25111976@postgrespro.ru", "phone": "+70445170893"}
0005435068996	53CCF1	3148 307360	TATYANA BELYAEVA	{"email": "belyaeva-tatyana11071966@postgrespro.ru", "phone": "+70891595156"}
0005435068997	4D6093	4187 086453	ARTEM SCHERBAKOV	{"email": "artem_scherbakov.091964@postgrespro.ru", "phone": "+70222164091"}
0005435068998	4D6093	5258 842304	EKATERINA KISELEVA	{"phone": "+70523907332"}
0005435068999	30869B	1526 257287	NINA DENISOVA	{"email": "denisova_n.23031976@postgrespro.ru", "phone": "+70544667939"}
0005435069000	30869B	3867 144614	VALENTINA TITOVA	{"email": "valentina_titova_24121969@postgrespro.ru", "phone": "+70709570613"}
0005435069001	1DF49E	9992 295120	VLADIMIR ZAYCEV	{"email": "zaycev.v_1975@postgrespro.ru", "phone": "+70143061696"}
0005435069002	56AD5D	4127 508091	VALENTINA FILIPPOVA	{"phone": "+70124425485"}
0005435069003	09E6CF	5988 368721	SVETLANA DENISOVA	{"phone": "+70772648133"}
0005435069004	CFA05B	4644 438062	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr-1973@postgrespro.ru", "phone": "+70309383187"}
0005435069005	39F875	7200 940836	ALEKSANDR KAZAKOV	{"phone": "+70915709782"}
0005435069006	39F875	0995 133402	NAIL KOROLEV	{"phone": "+70663465344"}
0005435069007	C41A9A	0472 160122	TATYANA IVANOVA	{"email": "ivanova_t.071984@postgrespro.ru", "phone": "+70986741171"}
0005435069008	0943B2	9109 926158	OLGA VASILEVA	{"phone": "+70766705222"}
0005435069009	0943B2	6219 785152	VENERA NIKITINA	{"email": "nikitinavenera.051965@postgrespro.ru", "phone": "+70803681928"}
0005435069010	976B3A	4236 501824	IRINA VOLKOVA	{"phone": "+70008095709"}
0005435069011	976B3A	2186 130169	VIKTORIYA LAZAREVA	{"email": "lazareva_v.25111971@postgrespro.ru", "phone": "+70654653582"}
0005435069012	82507C	9641 816905	VLADIMIR RODIONOV	{"email": "vladimir-rodionov041973@postgrespro.ru", "phone": "+70368599726"}
0005435069013	C51E10	1395 003231	VYACHESLAV SMIRNOV	{"email": "smirnov-v_1966@postgrespro.ru", "phone": "+70789660188"}
0005435069014	4A10AE	3657 305803	VERA TARASOVA	{"phone": "+70346637199"}
0005435069015	5663D4	6871 220185	OKSANA DANILOVA	{"phone": "+70622344556"}
0005435069016	4379DB	9091 634646	VIKTOR NAUMOV	{"email": "naumov_v111979@postgrespro.ru", "phone": "+70601478690"}
0005435069017	4379DB	2660 128198	VERA LEBEDEVA	{"email": "lebedevavera.25111952@postgrespro.ru", "phone": "+70821971530"}
0005435069018	4379DB	1839 898937	ALEKSEY SOLOVEV	{"phone": "+70983329280"}
0005435069019	57900E	5092 919488	YAKOV KISELEV	{"phone": "+70703737710"}
0005435069020	57900E	8462 060139	POLINA STEPANOVA	{"phone": "+70088222095"}
0005435069021	723990	9305 068546	IVAN TIMOFEEV	{"phone": "+70106015887"}
0005435069022	723990	8218 457593	ALEKSANDR NAZAROV	{"phone": "+70946608859"}
0005435069023	723990	1333 284421	MAKSIM KRASNOV	{"email": "m.krasnov_071971@postgrespro.ru", "phone": "+70434298893"}
0005435069024	9FD6AD	5296 877447	VIKTOR ZHUKOV	{"email": "zhukov-v1972@postgrespro.ru", "phone": "+70146536792"}
0005435069025	9FD6AD	5962 891846	GALINA KOLESNIKOVA	{"phone": "+70750549277"}
0005435069026	8667D8	0504 773783	GALINA EFREMOVA	{"email": "efremovag1974@postgrespro.ru", "phone": "+70081816515"}
0005435069027	E08EDE	2885 348805	NIKITA MELNIKOV	{"phone": "+70900602814"}
0005435069028	DC7EE6	0648 076531	DANIL IVANOV	{"phone": "+70071374817"}
0005435069029	644CB6	8539 942304	EGOR KUZNECOV	{"email": "egor.kuznecov.071972@postgrespro.ru", "phone": "+70612848391"}
0005435069030	6306B7	6218 559906	ANASTASIYA YAKOVLEVA	{"email": "yakovleva_a1976@postgrespro.ru", "phone": "+70828578649"}
0005435069031	F5342E	1661 665916	VLADIMIR PETROV	{"phone": "+70813524687"}
0005435069032	F5342E	7421 417616	NATALYA CHERNOVA	{"phone": "+70269025410"}
0005435069033	317F3A	4366 118935	ELENA SEMENOVA	{"email": "semenova_elena09101969@postgrespro.ru", "phone": "+70074996098"}
0005435069034	A3CA79	8074 483879	TATYANA ANTONOVA	{"email": "tatyana.antonova.22061976@postgrespro.ru", "phone": "+70301337808"}
0005435069210	DCCEFD	0066 949655	ELENA RYABOVA	{"phone": "+70158525163"}
0005435069035	95CEC7	7610 655917	VERA ALEKSANDROVA	{"email": "aleksandrovav.081971@postgrespro.ru", "phone": "+70213657003"}
0005435069036	C23CDE	8405 949936	FEDOR MOROZOV	{"phone": "+70143873484"}
0005435069037	122D02	8428 203701	ANDREY BELOV	{"email": "abelov1963@postgrespro.ru", "phone": "+70787168677"}
0005435069038	122D02	4121 124657	ALEKSEY FILIPPOV	{"email": "a_filippov051971@postgrespro.ru", "phone": "+70413440636"}
0005435069039	2736BA	2861 041707	LARISA FADEEVA	{"phone": "+70030731652"}
0005435069040	CA58AF	5443 557037	NATALYA MEDVEDEVA	{"email": "natalya.medvedeva.27081969@postgrespro.ru", "phone": "+70856671142"}
0005435069041	9564F2	0517 107215	GALINA ANDREEVA	{"phone": "+70794014250"}
0005435069042	9564F2	5980 925191	IVAN MATVEEV	{"email": "matveev-i-021981@postgrespro.ru", "phone": "+70881294229"}
0005435069043	BFB9B7	4823 434365	IVAN VASILEV	{"email": "i_vasilev_071969@postgrespro.ru", "phone": "+70674761741"}
0005435069044	DD8616	0279 087460	SVETLANA ANISIMOVA	{"email": "svetlana_anisimova091968@postgrespro.ru", "phone": "+70172931980"}
0005435069045	E3A702	3442 610576	NINA VASILEVA	{"email": "vasileva.n-1980@postgrespro.ru", "phone": "+70121487372"}
0005435069046	32C736	6597 250973	LYUBOV IVANOVA	{"phone": "+70661688438"}
0005435069047	C225DE	7605 982698	ANDREY NIKITIN	{"email": "andrey_nikitin27021963@postgrespro.ru", "phone": "+70636854615"}
0005435069048	F5DD29	7330 778776	MAYYA EGOROVA	{"email": "egorova_mayya.29031978@postgrespro.ru", "phone": "+70283633909"}
0005435069049	C3F5F8	9035 201385	ALEKSANDR AFANASEV	{"email": "aafanasev1974@postgrespro.ru", "phone": "+70446157159"}
0005435069050	7BC5D2	3723 801423	GALINA POPOVA	{"phone": "+70903469149"}
0005435069051	322E1E	6012 509982	ELENA IVANOVA	{"email": "elena_ivanova.1972@postgrespro.ru", "phone": "+70603333230"}
0005435069052	322E1E	1926 493919	YANA NIKIFOROVA	{"phone": "+70319907707"}
0005435069053	322E1E	2118 079693	VIKTOR GERASIMOV	{"email": "gerasimov.v-10051970@postgrespro.ru", "phone": "+70695607255"}
0005435069054	361ADC	5645 094667	ANATOLIY DMITRIEV	{"email": "dmitriev-anatoliy_1977@postgrespro.ru", "phone": "+70604384591"}
0005435069055	416DB8	5646 219176	ALEKSEY PETROV	{"email": "apetrov.29011977@postgrespro.ru", "phone": "+70439136838"}
0005435069056	FA4F0E	7709 443071	IRINA KISELEVA	{"email": "i_kiseleva-29051968@postgrespro.ru", "phone": "+70912713579"}
0005435069057	36BFF2	1046 936425	YULIYA MARTYNOVA	{"email": "martynova_y_031983@postgrespro.ru", "phone": "+70378201047"}
0005435069058	92452D	2597 637746	FATIMA NIKOLAEVA	{"email": "f.nikolaeva061970@postgrespro.ru", "phone": "+70577726050"}
0005435069059	EAFD6F	3425 281606	VERONIKA TIKHONOVA	{"email": "veronika.tikhonova-041979@postgrespro.ru", "phone": "+70241829265"}
0005435069060	475379	6653 255318	YANA ERMAKOVA	{"email": "ermakova_yana18071965@postgrespro.ru", "phone": "+70813594318"}
0005435069061	E05098	2731 816430	ROMAN IVANOV	{"phone": "+70815303955"}
0005435069062	34DE72	9608 053137	VIKTOR SOROKIN	{"email": "viktorsorokin1975@postgrespro.ru", "phone": "+70017995567"}
0005435069063	A93609	1815 013746	LYUBOV IVANOVA	{"phone": "+70029782142"}
0005435069064	DC0612	9379 458698	PAVEL YAKOVLEV	{"phone": "+70952558702"}
0005435069065	DC0612	0617 309451	GALINA TIKHONOVA	{"phone": "+70188953500"}
0005435069066	5A312B	3165 216495	LYUDMILA GERASIMOVA	{"email": "gerasimovalyudmila18101965@postgrespro.ru", "phone": "+70427473422"}
0005435069067	0D707D	3370 069198	ALEKSANDRA BORISOVA	{"phone": "+70665873836"}
0005435069068	0D707D	4191 627277	MARIYA LUKYANOVA	{"phone": "+70181646277"}
0005435069069	172E0E	0931 678417	IRAIDA ZHUKOVA	{"email": "zhukovairaida-031974@postgrespro.ru", "phone": "+70936420717"}
0005435069070	7EF5F9	9792 388774	NIKOLAY VASILEV	{"email": "n.vasilev-081971@postgrespro.ru", "phone": "+70308993895"}
0005435069071	7EF5F9	9397 607630	OLGA ORLOVA	{"phone": "+70518018173"}
0005435069072	A258EB	3809 626068	OKSANA SOKOLOVA	{"email": "oksana-sokolova_1966@postgrespro.ru", "phone": "+70095662228"}
0005435069073	3378BA	1224 339838	PAVEL MAKAROV	{"email": "makarov-pavel061978@postgrespro.ru", "phone": "+70096679744"}
0005435069074	F97988	7688 928393	ALEKSANDR GERASIMOV	{"phone": "+70540679721"}
0005435069075	FECDA5	0401 555886	TATYANA ANDREEVA	{"email": "andreeva-t-071974@postgrespro.ru", "phone": "+70698343737"}
0005435069076	4711BE	0030 122944	GALINA OVCHINNIKOVA	{"email": "g_ovchinnikova-071969@postgrespro.ru", "phone": "+70423958835"}
0005435069077	4711BE	4535 715156	OLEG KOZLOV	{"email": "oleg-kozlov.13031960@postgrespro.ru", "phone": "+70440401052"}
0005435069078	3B769B	4574 020893	DMITRIY SCHERBAKOV	{"phone": "+70010365325"}
0005435069079	E1BC89	9278 121280	ANATOLIY MOROZOV	{"phone": "+70596797404"}
0005435069080	203300	7186 537096	MARINA BORISOVA	{"email": "borisova-marina.1970@postgrespro.ru", "phone": "+70121892493"}
0005435069081	203300	9153 409097	ARTEM ZAYCEV	{"phone": "+70701461685"}
0005435069082	203300	1966 721765	DMITRIY SOLOVEV	{"email": "solovevd041974@postgrespro.ru", "phone": "+70436585903"}
0005435069083	457F56	9798 190994	MAKSIM ANDREEV	{"phone": "+70668774542"}
0005435069084	080418	3082 364155	SERGEY MOROZOV	{"email": "s.morozov.101972@postgrespro.ru", "phone": "+70327331329"}
0005435069085	080418	3315 155873	SERGEY IVANOV	{"phone": "+70418585069"}
0005435069086	13155C	1306 520903	VLADIMIR KONOVALOV	{"phone": "+70817743304"}
0005435069087	231A57	6557 893043	RAFIK KUZNECOV	{"email": "r.kuznecov-081974@postgrespro.ru", "phone": "+70754895790"}
0005435069088	B6A3B1	0696 617447	OLGA MEDVEDEVA	{"email": "o_medvedeva_14011969@postgrespro.ru", "phone": "+70355402292"}
0005435069089	AF9A2D	9180 222750	VIKTOR YAKOVLEV	{"email": "v_yakovlev25091963@postgrespro.ru", "phone": "+70562598888"}
0005435069090	AF9A2D	6165 158995	DANILA ALEKSANDROV	{"phone": "+70084411524"}
0005435069091	AF9A2D	6969 852796	ARINA VOLKOVA	{"email": "arina_volkova.1971@postgrespro.ru", "phone": "+70633321112"}
0005435069092	B68484	0807 632912	OKSANA DMITRIEVA	{"email": "o-dmitrieva121985@postgrespro.ru", "phone": "+70476785762"}
0005435069093	7F86A0	5085 369620	ALEKSEY BORISOV	{"email": "aborisov.23061979@postgrespro.ru", "phone": "+70884074741"}
0005435069094	CAB302	4218 461217	MARIYA KOZLOVA	{"phone": "+70726736781"}
0005435069095	CAB302	9934 677038	DMITRIY IVANOV	{"email": "ivanovdmitriy-03011963@postgrespro.ru", "phone": "+70125705616"}
0005435069096	C3E952	7559 440822	RAFAEL DENISOV	{"phone": "+70391601992"}
0005435069097	C3E952	6312 801766	TATYANA NOVIKOVA	{"email": "t_novikova_1982@postgrespro.ru", "phone": "+70150244789"}
0005435069098	4CE228	9097 683542	VIKTORIYA KULIKOVA	{"phone": "+70094942263"}
0005435069099	4CE228	6845 865860	DANIIL SIDOROV	{"phone": "+70436516472"}
0005435069100	50AF7D	7514 540290	ALEKSANDR ZAKHAROV	{"phone": "+70305408695"}
0005435069101	50AF7D	7531 683982	ANNA ALEKSANDROVA	{"phone": "+70776160014"}
0005435069102	13D2D1	7931 582751	TATYANA LUKYANOVA	{"email": "tatyanalukyanova.1961@postgrespro.ru", "phone": "+70894037615"}
0005435069103	BFB601	9563 884377	OLGA PETROVA	{"email": "o-petrova_061976@postgrespro.ru", "phone": "+70502241707"}
0005435069104	8E72FE	6158 311855	ANZHELA LEBEDEVA	{"email": "anzhelalebedeva.021972@postgrespro.ru", "phone": "+70519360989"}
0005435069105	77C4B2	3899 995895	GALINA KOLESNIKOVA	{"phone": "+70031332215"}
0005435069106	77C4B2	1912 639062	SABINA TIMOFEEVA	{"email": "timofeeva.s-1966@postgrespro.ru", "phone": "+70423960190"}
0005435069107	ED6B37	9058 062982	GALINA VASILEVA	{"phone": "+70927807697"}
0005435069108	9245B3	7196 171504	VLADIMIR MAKSIMOV	{"phone": "+70779516138"}
0005435069109	9245B3	2628 974767	GALINA MATVEEVA	{"email": "matveevagalina-1964@postgrespro.ru", "phone": "+70917538899"}
0005435069110	A8A679	7419 070142	MAKSIM KUZNECOV	{"email": "m.kuznecov.1976@postgrespro.ru", "phone": "+70771108596"}
0005435069111	A8A679	9976 588478	MIKHAIL FEDOTOV	{"phone": "+70517199113"}
0005435069112	0EA3CD	3835 995022	YURIY NIKOLAEV	{"email": "nikolaevyuriy.1966@postgrespro.ru", "phone": "+70337624567"}
0005435069113	0EA3CD	7054 542912	VLADISLAV NIKITIN	{"phone": "+70783157394"}
0005435069114	1618D5	9233 770861	VALENTINA MIKHAYLOVA	{"phone": "+70200042657"}
0005435069115	8F89C8	8688 599638	KARINA AKIMOVA	{"email": "karinaakimova1968@postgrespro.ru", "phone": "+70373784856"}
0005435069116	8F89C8	7266 466186	ANNA STEPANOVA	{"email": "stepanova-anna-05011974@postgrespro.ru", "phone": "+70972426384"}
0005435069117	00B2BC	3950 506807	ALEKSEY MARTYNOV	{"phone": "+70630938498"}
0005435069118	6CFBE4	6872 492678	ULYANA MELNIKOVA	{"phone": "+70298615415"}
0005435069119	32AD20	6018 559845	GRIGORIY KUZNECOV	{"email": "kuznecovg.23031975@postgrespro.ru", "phone": "+70584556989"}
0005435069120	4B2E4E	5516 192480	ELENA LAZAREVA	{"phone": "+70722623470"}
0005435069121	4B2E4E	7688 053637	SOFYA FROLOVA	{"email": "s_frolova-1977@postgrespro.ru", "phone": "+70028421534"}
0005435069122	054160	7589 352485	ANASTASIYA RODIONOVA	{"phone": "+70114220293"}
0005435069123	054160	3961 919677	VIKTOR ABRAMOV	{"email": "v.abramov_1969@postgrespro.ru", "phone": "+70451406178"}
0005435069124	913194	1214 621816	ALEKSANDR PAVLOV	{"email": "aleksandr.pavlov-1980@postgrespro.ru", "phone": "+70443521595"}
0005435069125	847D02	7333 839313	KARINA SOROKINA	{"email": "sorokinakarina-031971@postgrespro.ru", "phone": "+70445023049"}
0005435069126	847D02	9467 038089	ELIZAVETA SOROKINA	{"phone": "+70916174544"}
0005435069127	13CB3E	6248 245099	SERGEY ALEKSEEV	{"email": "alekseev_s-18071968@postgrespro.ru", "phone": "+70073471838"}
0005435069128	17C0E3	6164 441610	SVETLANA KUZNECOVA	{"phone": "+70340621500"}
0005435069129	BB52BF	8055 071673	PETR DMITRIEV	{"phone": "+70098538806"}
0005435069130	E621BB	0782 366324	TATYANA GUSEVA	{"email": "tatyana-guseva.1964@postgrespro.ru", "phone": "+70461873235"}
0005435069131	EF3422	2390 529502	GALINA MAKAROVA	{"email": "makarovag28041974@postgrespro.ru", "phone": "+70678290775"}
0005435069132	D1A17A	4630 081154	VITALIY ORLOV	{"phone": "+70943058469"}
0005435069133	D1A17A	5660 180053	VLADIMIR ILIN	{"email": "v-ilin111973@postgrespro.ru", "phone": "+70655822800"}
0005435069134	6984CF	1265 865320	MARIYA NESTEROVA	{"email": "m.nesterova_1968@postgrespro.ru", "phone": "+70556992481"}
0005435069135	6D45E4	4505 791091	EGOR STEPANOV	{"phone": "+70383252372"}
0005435069136	6D45E4	7013 227153	MARIYA ZAKHAROVA	{"email": "mariya-zakharova_1977@postgrespro.ru", "phone": "+70067061767"}
0005435069137	50D70F	1746 323271	TATYANA RYABOVA	{"email": "ryabova_tatyana_06091963@postgrespro.ru", "phone": "+70677733852"}
0005435069138	50D70F	1491 532306	GEORGIY NAZAROV	{"phone": "+70831391263"}
0005435069139	1B33A0	7663 498117	IGOR GUSEV	{"email": "gusev-i-011968@postgrespro.ru", "phone": "+70290500375"}
0005435069140	C8A4C7	6679 265772	ALEKSANDR MIKHAYLOV	{"phone": "+70829826660"}
0005435069141	C8A4C7	7963 629773	ELIZAVETA OSIPOVA	{"phone": "+70350806088"}
0005435069142	E40C9D	2053 539567	SERGEY KISELEV	{"email": "skiselev.071976@postgrespro.ru", "phone": "+70046426893"}
0005435069143	E40C9D	1599 938715	ALEKSEY NIKOLAEV	{"phone": "+70595358380"}
0005435069144	E40C9D	3212 035841	MIKHAIL KUZNECOV	{"phone": "+70162807977"}
0005435069145	4B8FAE	4283 830439	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-041970@postgrespro.ru", "phone": "+70364370572"}
0005435069146	591E44	8306 654810	NINA BELOVA	{"email": "belovanina08111973@postgrespro.ru", "phone": "+70861157997"}
0005435069147	325C30	7885 982388	VLADIMIR KAZAKOV	{"phone": "+70551143812"}
0005435069148	91D4C8	2504 342983	NINA VOLKOVA	{"phone": "+70806116392"}
0005435069149	E9AA8B	0062 804448	ELENA POPOVA	{"email": "popova-e_081981@postgrespro.ru", "phone": "+70957474246"}
0005435069150	E9AA8B	0947 693526	ANNA MIKHAYLOVA	{"email": "annamikhaylova031973@postgrespro.ru", "phone": "+70483632511"}
0005435069151	83849F	1480 953370	IRAIDA KULIKOVA	{"email": "kulikova_iraida121973@postgrespro.ru", "phone": "+70949888349"}
0005435069152	08ECF3	8060 033032	ZOYA MAKSIMOVA	{"email": "maksimova.zoya_11041962@postgrespro.ru", "phone": "+70935829655"}
0005435069153	29B4FC	9910 051108	NIKOLAY KUDRYASHOV	{"email": "nikolay.kudryashov_1973@postgrespro.ru", "phone": "+70905867133"}
0005435069154	32E87E	8250 413711	TATYANA SOLOVEVA	{"phone": "+70608883238"}
0005435069155	8FE690	0515 296973	KRISTINA MASLOVA	{"phone": "+70247273989"}
0005435069156	852260	6272 980581	ALENA DMITRIEVA	{"email": "dmitrievaa-031973@postgrespro.ru", "phone": "+70032941087"}
0005435069157	852260	8408 795094	OLEG KOZLOV	{"email": "o-kozlov01041974@postgrespro.ru", "phone": "+70458432503"}
0005435069158	A0E44C	8757 237561	OKSANA MIKHAYLOVA	{"phone": "+70367716544"}
0005435069159	A0E44C	0922 781321	GENNADIY STEPANOV	{"email": "g-stepanov-081977@postgrespro.ru", "phone": "+70939945435"}
0005435069160	1E81EE	6552 471699	SERGEY ANTONOV	{"email": "santonov30051983@postgrespro.ru", "phone": "+70832010530"}
0005435069161	18A9FC	8751 913886	NINA AKIMOVA	{"email": "akimova-nina_041967@postgrespro.ru", "phone": "+70075672945"}
0005435069162	5A4C18	5864 893791	YURIY TARASOV	{"phone": "+70232974303"}
0005435069163	5A4C18	0363 072539	TATYANA MAKAROVA	{"phone": "+70987985290"}
0005435069164	686B84	7155 678483	SAMIR SCHERBAKOV	{"email": "s.scherbakov.01071963@postgrespro.ru", "phone": "+70296457450"}
0005435069165	686B84	4266 208111	OLGA DMITRIEVA	{"phone": "+70329774518"}
0005435069166	686B84	9701 313555	YULIYA SCHERBAKOVA	{"email": "y.scherbakova_121973@postgrespro.ru", "phone": "+70630256630"}
0005435069167	023751	0410 556091	YULIYA ALEKSEEVA	{"email": "y.alekseeva_121965@postgrespro.ru", "phone": "+70343655373"}
0005435069168	023751	0530 369116	SERGEY ANDREEV	{"email": "andreev-sergey_31011978@postgrespro.ru", "phone": "+70587843915"}
0005435069169	D4CF5C	4107 143540	VALENTINA YUDINA	{"email": "yudina.valentina_011977@postgrespro.ru", "phone": "+70100926608"}
0005435069170	75D7B1	2708 071742	KSENIYA DAVYDOVA	{"email": "k_davydova_23081980@postgrespro.ru", "phone": "+70017601221"}
0005435069171	88FFA0	6929 002184	MARIYA SIDOROVA	{"email": "sidorova.mariya_20071973@postgrespro.ru", "phone": "+70350091894"}
0005435069172	12D171	6468 144637	MILENA CHERNOVA	{"email": "chernova_milena_1959@postgrespro.ru", "phone": "+70012932796"}
0005435069173	31CFCA	4697 414838	TATYANA FILIPPOVA	{"email": "filippovatatyana04011967@postgrespro.ru", "phone": "+70722964948"}
0005435069174	0FB19D	9370 573380	DIANA MIKHAYLOVA	{"email": "diana-mikhaylova_1964@postgrespro.ru", "phone": "+70920966660"}
0005435069175	0FB19D	3994 087772	ELENA ANISIMOVA	{"phone": "+70616275643"}
0005435069176	150F64	0154 706303	MIKHAIL DMITRIEV	{"email": "dmitriev.m_071963@postgrespro.ru", "phone": "+70352742622"}
0005435069177	119BD5	5451 645343	SVETLANA VOROBEVA	{"phone": "+70484347297"}
0005435069178	119BD5	6601 570388	TIMOFEY KAZAKOV	{"phone": "+70017457144"}
0005435069179	7C57C1	3254 470619	SERGEY ANDREEV	{"email": "sergey.andreev1979@postgrespro.ru", "phone": "+70262759732"}
0005435069180	030B12	4244 604959	SEMEN ANTONOV	{"email": "antonov_semen.1973@postgrespro.ru", "phone": "+70854108957"}
0005435069181	030B12	4830 949956	VALERIY GAVRILOV	{"email": "v-gavrilov-111969@postgrespro.ru", "phone": "+70283364176"}
0005435069182	030B12	6979 684490	IGOR NIKITIN	{"email": "igor-nikitin10011973@postgrespro.ru", "phone": "+70758642647"}
0005435069183	F93BF1	0803 860436	RODION SIDOROV	{"email": "rsidorov_091976@postgrespro.ru", "phone": "+70789155588"}
0005435069184	BC80BE	6888 700423	TAMARA TROFIMOVA	{"email": "trofimova_tamara071968@postgrespro.ru", "phone": "+70019817247"}
0005435069185	BC80BE	2039 391251	VALERIY TIKHONOV	{"email": "valeriy-tikhonov15101971@postgrespro.ru", "phone": "+70514582860"}
0005435069186	9791DC	2797 249478	ALEKSANDR MAKSIMOV	{"email": "maksimova101979@postgrespro.ru", "phone": "+70569814610"}
0005435069187	AEEE7A	4668 020712	ANNA EFREMOVA	{"phone": "+70810558979"}
0005435069188	AEEE7A	3724 947184	TATYANA KOROLEVA	{"email": "tkoroleva-24111979@postgrespro.ru", "phone": "+70397467546"}
0005435069189	38F838	6812 016895	ALEKSEY MOISEEV	{"email": "alekseymoiseev_1965@postgrespro.ru", "phone": "+70546554479"}
0005435069190	0EBC9F	8228 606046	VLADIMIR ALEKSANDROV	{"phone": "+70231659217"}
0005435069191	4CA0AE	5030 008238	GENNADIY GRIGOREV	{"phone": "+70375923181"}
0005435069192	F89677	4024 410347	VITALIY SERGEEV	{"phone": "+70169247461"}
0005435069193	F89677	0470 115326	ALINA MAKAROVA	{"email": "makarova.alina-15091976@postgrespro.ru", "phone": "+70293657170"}
0005435069194	543425	7666 288151	NATALYA BELOVA	{"email": "belovan-1975@postgrespro.ru", "phone": "+70717417361"}
0005435069195	6FB686	3969 416999	VERA MEDVEDEVA	{"email": "v.medvedeva-1971@postgrespro.ru", "phone": "+70443481633"}
0005435069196	FE8D41	8845 416441	GALINA LUKYANOVA	{"phone": "+70643355839"}
0005435069197	D3B39C	8697 341233	ZOYA MAKAROVA	{"email": "makarova.z_1973@postgrespro.ru", "phone": "+70265216031"}
0005435069198	514E8C	8720 126959	ALEKSANDR SOROKIN	{"email": "a_sorokin-1980@postgrespro.ru", "phone": "+70004173381"}
0005435069199	896336	9101 133326	ROMAN SERGEEV	{"phone": "+70310513178"}
0005435069200	896336	9520 844769	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_16031980@postgrespro.ru", "phone": "+70347687896"}
0005435069201	4B2615	0720 107542	SERGEY SEMENOV	{"phone": "+70311755734"}
0005435069202	4B2615	8556 362135	LYUDMILA SIDOROVA	{"email": "l_sidorova_06051970@postgrespro.ru", "phone": "+70612476991"}
0005435069203	DC1999	3353 629251	MARIYA MELNIKOVA	{"phone": "+70992801601"}
0005435069204	DC1999	3643 024990	SVETLANA NIKOLAEVA	{"email": "nikolaeva_s1981@postgrespro.ru", "phone": "+70470959467"}
0005435069205	2B72E9	9693 234556	IGOR DAVYDOV	{"email": "davydov_igor.1975@postgrespro.ru", "phone": "+70675899253"}
0005435069206	763945	5179 020014	GENNADIY YAKOVLEV	{"email": "gennadiy-yakovlev-091976@postgrespro.ru", "phone": "+70656938243"}
0005435069207	4CBA56	9817 408240	OLGA GUSEVA	{"email": "guseva.o1982@postgrespro.ru", "phone": "+70435012726"}
0005435069208	75F999	8662 736499	SERGEY ISAEV	{"email": "isaev-sergey_1970@postgrespro.ru", "phone": "+70214739141"}
0005435069209	DCCEFD	8351 697714	MARIYA ABRAMOVA	{"phone": "+70710249964"}
0005435069211	3075F9	8662 764604	PELAGEYA PETROVA	{"phone": "+70636305251"}
0005435069212	FEE87F	8936 487885	NADEZHDA VASILEVA	{"phone": "+70651621495"}
0005435069213	429706	7880 188646	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova_27121980@postgrespro.ru", "phone": "+70185709679"}
0005435069214	E40ED8	2891 177782	NINA EFREMOVA	{"phone": "+70855819097"}
0005435069215	E40ED8	7961 312775	ALISA KONOVALOVA	{"phone": "+70371774919"}
0005435069216	2B0112	1630 329115	SERGEY SERGEEV	{"phone": "+70915766196"}
0005435069217	2B0112	4095 240028	IVAN GRIGOREV	{"email": "grigorev-i-14071975@postgrespro.ru", "phone": "+70217010043"}
0005435069218	2E0463	3493 565432	DANILA GAVRILOV	{"email": "danilagavrilov.12011970@postgrespro.ru", "phone": "+70014518601"}
0005435069219	45C9F8	5899 824545	SVETLANA MAKAROVA	{"phone": "+70419283735"}
0005435069220	DA4CA5	5588 736993	MAKSIM FEDOROV	{"email": "maksim-fedorov_1975@postgrespro.ru", "phone": "+70076475356"}
0005435069221	DA4CA5	6147 794827	MIKHAIL VLASOV	{"phone": "+70615264342"}
0005435069222	7619D3	0990 938350	ALLA KALININA	{"phone": "+70335425150"}
0005435069223	CF052C	5087 465409	PAVEL NIKOLAEV	{"email": "p-nikolaev-1968@postgrespro.ru", "phone": "+70280883898"}
0005435069224	CF052C	2458 369723	MATVEY TIMOFEEV	{"email": "matvey_timofeev.1977@postgrespro.ru", "phone": "+70195670305"}
0005435069225	9DAA5D	4707 928396	NIKOLAY TARASOV	{"email": "nikolay-tarasov121966@postgrespro.ru", "phone": "+70419351766"}
0005435069226	9DAA5D	1054 909562	VLADIMIR ALEKSEEV	{"phone": "+70669729201"}
0005435069227	9DAA5D	6704 364947	TATYANA CHERNOVA	{"email": "tatyana.chernova-13041979@postgrespro.ru", "phone": "+70690743195"}
0005435069228	E11A0A	0470 279746	OLGA ISAEVA	{"phone": "+70744842141"}
0005435069229	01D101	1143 195264	DARYA KAZAKOVA	{"email": "kazakova_darya.051959@postgrespro.ru", "phone": "+70128163862"}
0005435069230	01D101	3032 377032	VYACHESLAV NAZAROV	{"phone": "+70105688468"}
0005435069231	AA4387	8065 126550	ALEKSANDR NAZAROV	{"phone": "+70979928947"}
0005435069232	AA4387	3662 083095	MARINA MAKSIMOVA	{"email": "marinamaksimova.03041986@postgrespro.ru", "phone": "+70548149236"}
0005435069233	4B7E71	8930 521481	VIKTOR POPOV	{"phone": "+70529533671"}
0005435069234	DC5F24	2105 029118	MAKSIM VLASOV	{"email": "vlasov-m.1975@postgrespro.ru", "phone": "+70074448031"}
0005435069235	DC5F24	6961 889246	YULIYA KOLESNIKOVA	{"email": "kolesnikova_y-1967@postgrespro.ru", "phone": "+70933040088"}
0005435069236	0F98CC	6041 289313	ILYA KOROLEV	{"email": "ilya-korolev-01091967@postgrespro.ru", "phone": "+70072697401"}
0005435069237	B86188	9834 762256	ALEKSEY SMIRNOV	{"email": "smirnov.a19061972@postgrespro.ru", "phone": "+70066353879"}
0005435069238	B86188	6749 575082	ANNA POLYAKOVA	{"email": "polyakovaa.111975@postgrespro.ru", "phone": "+70647154296"}
0005435069239	B86188	4850 665131	ALEKSEY BARANOV	{"email": "baranov-aleksey-051981@postgrespro.ru", "phone": "+70708814467"}
0005435069240	827F72	0035 524467	ANATOLIY YAKOVLEV	{"email": "yakovlev_a-021966@postgrespro.ru", "phone": "+70570615540"}
0005435069241	08106C	5385 441166	ELIZAVETA BOGDANOVA	{"email": "e.bogdanova.071981@postgrespro.ru", "phone": "+70018569311"}
0005435069242	4A1CAF	0282 447551	VALENTINA MALYSHEVA	{"email": "valentina_malysheva21101977@postgrespro.ru", "phone": "+70045042264"}
0005435069243	4A1CAF	2027 938764	ANASTASIYA MIKHAYLOVA	{"phone": "+70171922708"}
0005435069244	C84D53	3767 280459	NATALIYA ABRAMOVA	{"phone": "+70772295077"}
0005435069245	F3EC62	7572 759389	OLGA ISAEVA	{"email": "isaeva.o_1983@postgrespro.ru", "phone": "+70801736891"}
0005435069246	F3EC62	8532 207054	OLGA FROLOVA	{"email": "o-frolova_011969@postgrespro.ru", "phone": "+70160073192"}
0005435069247	F3EC62	4105 771607	SERGEY VOROBEV	{"phone": "+70016690554"}
0005435069248	87033E	5762 640805	TAISIYA KOZLOVA	{"email": "taisiya.kozlova121976@postgrespro.ru", "phone": "+70307415862"}
0005435069249	87033E	2737 002107	VLADISLAV PETROV	{"phone": "+70268233968"}
0005435069250	779F4E	9732 942993	ELENA KOZLOVA	{"phone": "+70789962091"}
0005435069251	824628	6950 029549	OLEG PETROV	{"email": "petrovo.1978@postgrespro.ru", "phone": "+70426406640"}
0005435069252	3DA624	9865 835419	PAVEL IVANOV	{"email": "ivanov_p20091976@postgrespro.ru", "phone": "+70487993056"}
0005435069253	98559C	4983 391816	DMITRIY MAKAROV	{"phone": "+70690493365"}
0005435069254	FEDCB2	7758 647540	IVAN PAVLOV	{"phone": "+70854288987"}
0005435069255	08BF57	5822 953972	ALEKSEY IVANOV	{"email": "ivanov-a_25111968@postgrespro.ru", "phone": "+70235071016"}
0005435069256	C57AC5	1423 389266	KLAVDIYA LOGINOVA	{"email": "k-loginova.22011966@postgrespro.ru", "phone": "+70504154735"}
0005435069257	C57AC5	6841 966505	TATYANA FROLOVA	{"email": "t-frolova-061983@postgrespro.ru", "phone": "+70715634546"}
0005435069258	901FCB	1448 733808	LYUBOV SMIRNOVA	{"email": "lyubovsmirnova_1964@postgrespro.ru", "phone": "+70904930333"}
0005435069259	C57A0E	8385 875147	OLGA ISAEVA	{"phone": "+70195572691"}
0005435069260	05B902	3793 112179	VIKTORIYA KOVALEVA	{"email": "kovalevav031966@postgrespro.ru", "phone": "+70625154074"}
0005435069261	05B902	3622 015812	ARTEM ISAEV	{"email": "isaeva.07021967@postgrespro.ru", "phone": "+70455118928"}
0005435069262	2FAADB	1972 551459	GALINA ARKHIPOVA	{"phone": "+70534838128"}
0005435069263	CA7FC0	7548 229776	KONSTANTIN MOISEEV	{"email": "moiseev_konstantin.02051970@postgrespro.ru", "phone": "+70610867089"}
0005435069264	CA7FC0	7597 465826	DIANA EFIMOVA	{"phone": "+70041844916"}
0005435069265	BD4A04	8540 774279	DANIYA SIDOROVA	{"phone": "+70124964804"}
0005435069266	BD4A04	3093 885889	NIKOLAY FEDOROV	{"phone": "+70055794138"}
0005435069267	0DACDD	7661 140614	NINA GERASIMOVA	{"phone": "+70332302496"}
0005435069268	AB1406	0713 721079	ANDREY MATVEEV	{"phone": "+70322083755"}
0005435069269	AB1406	6648 943483	VYACHESLAV STEPANOV	{"phone": "+70871718728"}
0005435069270	04D89E	5764 318586	ANTONINA KRASNOVA	{"email": "antoninakrasnova.04081970@postgrespro.ru", "phone": "+70269884579"}
0005435069271	04D89E	3472 603043	DANIIL SOLOVEV	{"phone": "+70950878955"}
0005435069272	1F92BB	4121 436367	DANILA FOMIN	{"phone": "+70001206708"}
0005435069273	BA9666	5745 054049	PETR MARTYNOV	{"phone": "+70092300978"}
0005435069274	177B04	4106 186178	EDUARD ILIN	{"email": "eduardilin.04031981@postgrespro.ru", "phone": "+70830243184"}
0005435069275	151D0F	7231 003076	VIKTOR MOROZOV	{"phone": "+70298978050"}
0005435069276	12D8D6	8492 696349	VALENTINA VOLKOVA	{"phone": "+70375568652"}
0005435069277	0C7A22	7507 077147	VIKTOR CHERNOV	{"email": "v-chernov31081971@postgrespro.ru", "phone": "+70283961508"}
0005435069278	39A89F	5107 540003	ELENA LAZAREVA	{"phone": "+70382136845"}
0005435069279	1F078D	5110 194234	ALEKSANDR NAUMOV	{"email": "a.naumov.031971@postgrespro.ru", "phone": "+70715094602"}
0005435069280	B7C6C7	8706 362193	ELIZAVETA KOROLEVA	{"phone": "+70823866346"}
0005435069281	A490D1	6026 329882	VYACHESLAV PETROV	{"phone": "+70823046137"}
0005435069282	58A249	8620 478092	VLADIMIR KUDRYASHOV	{"email": "vladimirkudryashov081971@postgrespro.ru", "phone": "+70117114947"}
0005435069283	58A249	9040 535076	NATALYA FEDOROVA	{"phone": "+70649673999"}
0005435069284	58A249	8119 105027	ANATOLIY KUZMIN	{"email": "kuzmin_anatoliy-07101963@postgrespro.ru", "phone": "+70381894707"}
0005435069285	18BB35	3861 021743	LIDIYA CHERNOVA	{"email": "l_chernova.26071963@postgrespro.ru", "phone": "+70395903373"}
0005435069286	2670C7	6691 229047	NATALYA MELNIKOVA	{"email": "n-melnikova.081970@postgrespro.ru", "phone": "+70296203889"}
0005435069287	8A3F0D	2592 895227	EVGENIY FILIPPOV	{"phone": "+70128850077"}
0005435069288	D749AA	4470 915573	GRIGORIY ZAKHAROV	{"email": "zakharov-g-071973@postgrespro.ru", "phone": "+70243808324"}
0005435069289	EC439C	0080 576348	TATYANA ROMANOVA	{"email": "romanova_t.031980@postgrespro.ru", "phone": "+70681266736"}
0005435069290	724213	0394 891176	ALEKSEY BORISOV	{"email": "borisovaleksey.15021977@postgrespro.ru", "phone": "+70449723954"}
0005435069291	59C6BB	6516 240988	MIKHAIL ZAYCEV	{"email": "zaycev.m.031979@postgrespro.ru", "phone": "+70231269487"}
0005435069292	DA0A16	5949 456458	DMITRIY FEDOROV	{"phone": "+70410683388"}
0005435069293	DA0A16	7805 025621	VLADISLAV VOROBEV	{"phone": "+70482416337"}
0005435069294	DA0A16	0819 925121	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin_1967@postgrespro.ru", "phone": "+70512671295"}
0005435069295	49DF8B	0025 314401	VITALIY PETROV	{"email": "vitaliypetrov1974@postgrespro.ru", "phone": "+70587171707"}
0005435069296	49DF8B	5499 669196	GALINA MEDVEDEVA	{"email": "gmedvedeva_1968@postgrespro.ru", "phone": "+70581504207"}
0005435069297	49DF8B	2776 297027	EVGENIYA MELNIKOVA	{"phone": "+70297713738"}
0005435069298	D67583	7482 164887	ALEKSEY BONDARENKO	{"email": "bondarenko-a1970@postgrespro.ru", "phone": "+70888058622"}
0005435069299	CF5EA4	7323 958550	TATYANA DENISOVA	{"phone": "+70393514676"}
0005435069300	87F383	7001 035859	ANDREY OSIPOV	{"email": "andrey-osipov.01061968@postgrespro.ru", "phone": "+70474786578"}
0005435069301	C527DE	7597 695305	DARYA TIKHONOVA	{"phone": "+70966526769"}
0005435069302	F6ABED	2671 950419	MAKSIM EGOROV	{"email": "egorov-maksim13031979@postgrespro.ru", "phone": "+70258280951"}
0005435069303	289A50	7752 647624	NIKOLAY KULIKOV	{"email": "nikolay-kulikov_1975@postgrespro.ru", "phone": "+70228449278"}
0005435069304	289A50	4114 389762	VYACHESLAV BELOV	{"phone": "+70525605208"}
0005435069305	C5DEDA	5297 543397	LYUBOV GERASIMOVA	{"email": "l-gerasimova_061970@postgrespro.ru", "phone": "+70696746049"}
0005435069306	D6F60C	8922 430325	ALEKSANDR NIKITIN	{"email": "nikitin.aleksandr_011964@postgrespro.ru", "phone": "+70966235095"}
0005435069307	D6F60C	9970 357214	VLADIMIR ILIN	{"email": "ilin-vladimir.071973@postgrespro.ru", "phone": "+70824453605"}
0005435069308	D7CD95	2063 907535	NATALYA ZAYCEVA	{"phone": "+70017545159"}
0005435069309	1D5762	8060 573101	ELENA ZAKHAROVA	{"phone": "+70046054630"}
0005435069310	1D5762	2923 418131	VADIM SEMENOV	{"email": "vadim.semenov1982@postgrespro.ru", "phone": "+70785723762"}
0005435069311	98A653	3145 196076	BORIS KUZNECOV	{"phone": "+70164547338"}
0005435069312	4F172B	2157 105047	ALEKSANDR PAVLOV	{"phone": "+70300866711"}
0005435069313	4F172B	9123 984616	NADEZHDA MAKAROVA	{"email": "n.makarova.26071972@postgrespro.ru", "phone": "+70757470045"}
0005435069314	4F172B	3383 392035	LYUDMILA KONOVALOVA	{"email": "l_konovalova06081980@postgrespro.ru", "phone": "+70574979122"}
0005435069315	90E975	6059 640327	VALENTIN MAKAROV	{"email": "v_makarov13111975@postgrespro.ru", "phone": "+70728659846"}
0005435069316	90E975	2185 459344	VYACHESLAV VOLKOV	{"email": "volkov-v06101976@postgrespro.ru", "phone": "+70128701175"}
0005435069317	D561DE	6537 266167	SVETLANA TIKHONOVA	{"email": "tikhonova_s_021963@postgrespro.ru", "phone": "+70665639429"}
0005435069318	ECEBA1	7786 984595	VIKTOR NIKOLAEV	{"email": "viktor-nikolaev-1977@postgrespro.ru", "phone": "+70107678279"}
0005435069319	ECEBA1	5732 313332	ANASTASIYA EFREMOVA	{"email": "efremovaanastasiya_1970@postgrespro.ru", "phone": "+70650805358"}
0005435069320	AA1129	2083 836836	TAMARA MAKSIMOVA	{"email": "tmaksimova-24031969@postgrespro.ru", "phone": "+70053867571"}
0005435069321	AA1129	8168 876748	MARIYA MOROZOVA	{"email": "morozova.mariya-011973@postgrespro.ru", "phone": "+70302379372"}
0005435069322	46B05F	6081 716920	LYUDMILA DANILOVA	{"email": "l-danilova.1971@postgrespro.ru", "phone": "+70506311208"}
0005435069323	6A4C93	0000 373841	IGOR SEMENOV	{"email": "igorsemenov-1967@postgrespro.ru", "phone": "+70556133621"}
0005435069324	4E7719	5275 591066	EVGENIY PETROV	{"phone": "+70980335261"}
0005435069325	14BD43	3386 373393	NATALYA ERMAKOVA	{"phone": "+70616323976"}
0005435069326	E0FC0C	2229 302093	BORIS SEMENOV	{"phone": "+70979272779"}
0005435069327	5CE6F8	7215 833360	VLADIMIR VOLKOV	{"phone": "+70265319420"}
0005435069328	5CE6F8	2455 478948	VLADIMIR MAKAROV	{"phone": "+70281019351"}
0005435069329	A8A29C	0700 484957	LYUDMILA LUKYANOVA	{"phone": "+70265223268"}
0005435069330	A937EF	5463 470557	NADEZHDA KOMAROVA	{"phone": "+70746934222"}
0005435069331	A937EF	0704 905465	RAMIL IVANOV	{"email": "ivanov.r.19111972@postgrespro.ru", "phone": "+70653385143"}
0005435069332	2997E8	6001 437883	EDUARD MIRONOV	{"phone": "+70418314656"}
0005435069333	2997E8	8625 269974	ANTON BORISOV	{"email": "aborisov26021974@postgrespro.ru", "phone": "+70485527681"}
0005435069334	CCA108	5283 018517	GALINA MIKHAYLOVA	{"phone": "+70426198323"}
0005435069335	4297FD	0582 741472	VIKTOR MAKAROV	{"phone": "+70781103483"}
0005435069336	4297FD	4235 366051	ANDREY SOKOLOV	{"phone": "+70424093001"}
0005435069337	B1DAE4	3609 510944	GALINA MOROZOVA	{"phone": "+70980466845"}
0005435069338	3A9E6C	1046 283947	VALERIY MIRONOV	{"phone": "+70014282475"}
0005435069339	4D203B	8998 442218	SERGEY ZAYCEV	{"email": "szaycev.1971@postgrespro.ru", "phone": "+70132457552"}
0005435069340	97FAC0	7562 581106	OKSANA NESTEROVA	{"phone": "+70677339109"}
0005435069452	C0D9C6	7086 197217	ELENA OSIPOVA	{"phone": "+70923804815"}
0005435069341	4BF5A1	3746 519534	NIKOLAY NOVIKOV	{"email": "nikolay-novikov21071975@postgrespro.ru", "phone": "+70983982566"}
0005435069342	CD15DA	6537 512593	ANNA KAZAKOVA	{"phone": "+70337842716"}
0005435069343	CD15DA	6124 515637	EKATERINA VOROBEVA	{"email": "e.vorobeva_1975@postgrespro.ru", "phone": "+70630237578"}
0005435069344	DBFDC6	5336 091135	MARIYA VLASOVA	{"email": "mariyavlasova.16051965@postgrespro.ru", "phone": "+70883504433"}
0005435069345	7B7096	3075 208748	MARIYA KOZLOVA	{"phone": "+70502069315"}
0005435069346	7B7096	5344 356889	SERGEY KUZNECOV	{"email": "kuznecov-s-17091974@postgrespro.ru", "phone": "+70072700940"}
0005435069347	B96702	4070 449753	MIKHAIL PAVLOV	{"email": "pavlov_m031964@postgrespro.ru", "phone": "+70659273308"}
0005435069348	320681	3260 819544	ELENA IVANOVA	{"phone": "+70664209641"}
0005435069349	320681	3397 951100	ELVIRA MOROZOVA	{"email": "morozova.elvira1973@postgrespro.ru", "phone": "+70445079689"}
0005435069350	68322D	7970 026052	YULIYA PETROVA	{"phone": "+70057782433"}
0005435069351	7594A9	6280 061340	ANNA CHERNOVA	{"phone": "+70325770608"}
0005435069352	7594A9	2774 286465	ANDREY IVANOV	{"phone": "+70116430331"}
0005435069353	1AB218	5287 063855	KONSTANTIN SOROKIN	{"phone": "+70619436755"}
0005435069354	FBC8CD	2137 118247	VASILIY ALEKSANDROV	{"email": "aleksandrovvasiliy-01101964@postgrespro.ru", "phone": "+70712869210"}
0005435069355	BABFE7	9237 019822	TATYANA VOLKOVA	{"email": "volkova-tatyana021970@postgrespro.ru", "phone": "+70517899965"}
0005435069356	2401F9	2641 170583	MIKHAIL IVANOV	{"phone": "+70951739951"}
0005435069357	2401F9	2751 820008	VALERIY ANDREEV	{"email": "valeriyandreev091960@postgrespro.ru", "phone": "+70748629210"}
0005435069358	7337B8	7424 564535	OLEG GORBUNOV	{"phone": "+70582141906"}
0005435069359	7337B8	9215 591393	NATALYA BOGDANOVA	{"phone": "+70725462751"}
0005435069360	7337B8	0158 693242	FEDOR KUDRYASHOV	{"phone": "+70844355443"}
0005435069361	CB3718	7176 061346	VLADIMIR MEDVEDEV	{"phone": "+70895284801"}
0005435069362	3CF32D	7613 747967	ALEKSANDR KISELEV	{"phone": "+70826300984"}
0005435069363	D4EFED	0036 645142	MIKHAIL SERGEEV	{"phone": "+70623063045"}
0005435069364	2C1A0C	9725 904954	ALEKSEY POPOV	{"email": "a-popov_16071972@postgrespro.ru", "phone": "+70454361087"}
0005435069365	7AE81F	3913 190692	VALENTINA KUZNECOVA	{"email": "kuznecova-v_011964@postgrespro.ru", "phone": "+70623602379"}
0005435069366	AB8565	0766 399622	YURIY ISAEV	{"phone": "+70414436679"}
0005435069367	AB8565	5336 696511	ALESYA SEMENOVA	{"phone": "+70761534288"}
0005435069368	AB8565	4826 700159	SERGEY KOZLOV	{"phone": "+70165180003"}
0005435069369	8181C7	1749 258115	VALENTINA FROLOVA	{"email": "valentinafrolova_20111971@postgrespro.ru", "phone": "+70181434076"}
0005435069370	861F43	9499 809855	NATALIYA PAVLOVA	{"email": "pavlova_nataliya121972@postgrespro.ru", "phone": "+70840521184"}
0005435069371	CBFC19	8329 837430	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir.1963@postgrespro.ru", "phone": "+70669429809"}
0005435069372	7F9AF4	0377 212975	ANGELINA IVANOVA	{"phone": "+70269185676"}
0005435069373	7F9AF4	9398 819219	YULIYA NESTEROVA	{"phone": "+70123015935"}
0005435069374	7F9AF4	1866 058211	GALINA NESTEROVA	{"phone": "+70238684299"}
0005435069375	C20FCC	0548 693792	ROMAN ALEKSANDROV	{"email": "aleksandrovr-14121987@postgrespro.ru", "phone": "+70749090000"}
0005435069376	C20FCC	5665 489401	ARTEM CHERNOV	{"email": "achernov051977@postgrespro.ru", "phone": "+70460458962"}
0005435069377	0C88DB	2830 958842	MAKSIM DAVYDOV	{"phone": "+70900946222"}
0005435069378	0C88DB	7001 447680	SERGEY RODIONOV	{"email": "s-rodionov.021969@postgrespro.ru", "phone": "+70631504606"}
0005435069379	D061E0	6192 719350	IRINA GORBUNOVA	{"phone": "+70894838132"}
0005435069380	2B973C	0379 122991	ALEKSEY ISAEV	{"email": "isaev.aleksey1980@postgrespro.ru", "phone": "+70023646886"}
0005435069381	2B973C	7738 294574	DARYA VASILEVA	{"phone": "+70816751451"}
0005435069382	2B973C	7712 731880	VALERIYA RYABOVA	{"email": "ryabovavaleriya_21071974@postgrespro.ru", "phone": "+70566986881"}
0005435069383	2E277F	7082 709278	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay_051983@postgrespro.ru", "phone": "+70564286736"}
0005435069384	426BF2	6674 768723	ALEKSANDR IVANOV	{"email": "a_ivanov_091962@postgrespro.ru", "phone": "+70994993475"}
0005435069385	426BF2	2957 033932	VERA VOLKOVA	{"email": "vera_volkova.1969@postgrespro.ru", "phone": "+70688773991"}
0005435069386	BBAA39	7234 348491	VALENTINA NIKOLAEVA	{"phone": "+70341135503"}
0005435069387	9913D3	8751 823419	ANASTASIYA SEMENOVA	{"phone": "+70829854389"}
0005435069388	B9D602	2195 480128	TATYANA BELOVA	{"email": "belova-t-1972@postgrespro.ru", "phone": "+70390570659"}
0005435069389	73A52E	8706 765075	ALEKSEY MELNIKOV	{"email": "aleksey-melnikov.031974@postgrespro.ru", "phone": "+70959694287"}
0005435069390	59C2D1	1606 404558	IRINA NIKITINA	{"email": "i_nikitina121978@postgrespro.ru", "phone": "+70298754045"}
0005435069391	59C2D1	0281 584538	GALINA MASLOVA	{"phone": "+70715693569"}
0005435069392	B33213	8634 503665	IVAN ROMANOV	{"email": "ivan-romanov-14041962@postgrespro.ru", "phone": "+70265499986"}
0005435069393	0E647D	6043 786335	EVGENIY TIMOFEEV	{"email": "timofeev.e_1977@postgrespro.ru", "phone": "+70752685572"}
0005435069394	0E647D	9802 684621	VLADIMIR GUSEV	{"email": "vgusev_1982@postgrespro.ru", "phone": "+70488740437"}
0005435069395	0E647D	9900 438404	MARIYA BARANOVA	{"email": "m_baranova.1965@postgrespro.ru", "phone": "+70581858602"}
0005435069396	7E2E6B	8856 587881	ELENA KOMAROVA	{"email": "e_komarova-121966@postgrespro.ru", "phone": "+70603817702"}
0005435069397	DCB2F8	9913 356086	MARIYA SEMENOVA	{"email": "mariya_semenova081973@postgrespro.ru", "phone": "+70361825157"}
0005435069398	B8DED5	6533 698772	PAVEL ABRAMOV	{"phone": "+70818931298"}
0005435069399	B8DED5	1527 331037	OKSANA POPOVA	{"email": "o.popova_1978@postgrespro.ru", "phone": "+70165185894"}
0005435069400	59CD27	9002 885321	SERGEY GERASIMOV	{"phone": "+70405157268"}
0005435069401	450512	8368 107995	DIANA TARASOVA	{"phone": "+70992334115"}
0005435069402	AFB691	5978 426147	MARIYA AFANASEVA	{"phone": "+70205912137"}
0005435069403	C59A22	3950 668047	OLEG PETROV	{"email": "olegpetrov-24011981@postgrespro.ru", "phone": "+70767390441"}
0005435069404	C59A22	6106 466684	VERA BARANOVA	{"email": "v.baranova.1970@postgrespro.ru", "phone": "+70328380589"}
0005435069405	3378B9	4313 390772	VALENTINA ROMANOVA	{"phone": "+70995286052"}
0005435069406	DD1FC4	0366 842874	NATALYA GORBUNOVA	{"email": "natalyagorbunova_121971@postgrespro.ru", "phone": "+70376266593"}
0005435069407	DD1FC4	7486 043594	ALEKSEY NOVIKOV	{"phone": "+70981187128"}
0005435069408	69B263	3338 913084	IRINA DENISOVA	{"phone": "+70487327204"}
0005435069409	69B263	8501 543914	MARINA ORLOVA	{"email": "marinaorlova.21111979@postgrespro.ru", "phone": "+70813666520"}
0005435069410	5EEB21	9561 782028	LYUDMILA ZAKHAROVA	{"email": "lyudmilazakharova081970@postgrespro.ru", "phone": "+70824681550"}
0005435069411	5EEB21	8196 503505	RIMMA ISAEVA	{"phone": "+70589132927"}
0005435069412	E1902D	7179 063075	PAVEL NIKITIN	{"email": "p_nikitin071977@postgrespro.ru", "phone": "+70573528815"}
0005435069413	E1902D	2650 554104	ALINA SEMENOVA	{"phone": "+70339039068"}
0005435069414	E55BC5	8133 264679	MAKSIM STEPANOV	{"email": "stepanovmaksim-011965@postgrespro.ru", "phone": "+70638427159"}
0005435069415	E55BC5	6505 915377	VLADIMIR AFANASEV	{"phone": "+70455585135"}
0005435069416	B6B0E3	9443 444140	ALEKSEY PAVLOV	{"phone": "+70562617559"}
0005435069417	B6B0E3	1805 073005	ANASTASIYA FOMINA	{"email": "anastasiyafomina-1968@postgrespro.ru", "phone": "+70598168071"}
0005435069418	55D902	0819 584003	VYACHESLAV FROLOV	{"phone": "+70962423607"}
0005435069419	BF5477	7144 997500	EKATERINA MIKHAYLOVA	{"email": "ekaterina_mikhaylova051975@postgrespro.ru", "phone": "+70046789394"}
0005435069420	327F0F	7377 723807	RAISA STEPANOVA	{"email": "raisa_stepanova-1976@postgrespro.ru", "phone": "+70026939837"}
0005435069421	A805CE	3362 555430	TATYANA FOMINA	{"phone": "+70796744147"}
0005435069422	A805CE	5749 045135	NADEZHDA SIDOROVA	{"phone": "+70351022641"}
0005435069423	BFDEB0	3349 288732	TATYANA ISAEVA	{"email": "t.isaeva.011979@postgrespro.ru", "phone": "+70672540208"}
0005435069424	BFDEB0	7942 090092	RINAT GORBUNOV	{"email": "r-gorbunov_27011980@postgrespro.ru", "phone": "+70943094204"}
0005435069425	88F013	4577 130004	ALEKSANDR GERASIMOV	{"email": "aleksandrgerasimov.03111977@postgrespro.ru", "phone": "+70795792203"}
0005435069426	2833A2	2468 884379	IGOR KOROLEV	{"email": "korolev-igor_091968@postgrespro.ru", "phone": "+70131087859"}
0005435069427	2833A2	6229 778007	NATALYA MIRONOVA	{"phone": "+70912555140"}
0005435069428	E6210A	7306 445310	DANIIL SIDOROV	{"email": "sidorov-daniil.111970@postgrespro.ru", "phone": "+70611315864"}
0005435069429	79E07B	6947 956444	YULIYA IVANOVA	{"email": "ivanova-yuliya.20071975@postgrespro.ru", "phone": "+70629780659"}
0005435069430	1C35DC	8111 428785	TATYANA KARPOVA	{"phone": "+70878252061"}
0005435069431	CE7A37	0599 575853	VLADIMIR RODIONOV	{"email": "vrodionov_031973@postgrespro.ru", "phone": "+70794731951"}
0005435069432	9E1860	4090 103608	TATYANA OSIPOVA	{"email": "osipova.tatyana.15081966@postgrespro.ru", "phone": "+70873871475"}
0005435069433	13E6CD	2269 833295	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev01081969@postgrespro.ru", "phone": "+70777497261"}
0005435069434	C3F64A	3690 474858	ALEKSANDR IVANOV	{"email": "aleksandrivanov.23021976@postgrespro.ru", "phone": "+70068215566"}
0005435069435	C3F64A	1472 858799	ALEKSEY DMITRIEV	{"email": "aleksey.dmitriev-1958@postgrespro.ru", "phone": "+70634749298"}
0005435069436	AF9411	0317 479944	TATYANA MOISEEVA	{"phone": "+70110592591"}
0005435069437	B02F56	8779 023890	NATALYA KRASNOVA	{"email": "krasnova_natalya-1973@postgrespro.ru", "phone": "+70148285717"}
0005435069438	7FE627	5640 496381	YULIYA GERASIMOVA	{"email": "gerasimova.y-15071976@postgrespro.ru", "phone": "+70367800200"}
0005435069439	40ACCB	3883 505309	GALINA MELNIKOVA	{"email": "melnikova_galina-061981@postgrespro.ru", "phone": "+70627558523"}
0005435069440	ED52C9	5447 769425	ELIZAVETA MOROZOVA	{"email": "e_morozova_10041965@postgrespro.ru", "phone": "+70680043299"}
0005435069441	ED52C9	0977 083682	ANNA NESTEROVA	{"phone": "+70889521494"}
0005435069442	B92844	5475 766916	TATYANA ZAYCEVA	{"email": "t.zayceva011973@postgrespro.ru", "phone": "+70693511188"}
0005435069443	0F6825	2618 878788	ELENA EFREMOVA	{"email": "efremovaelena_1964@postgrespro.ru", "phone": "+70776162977"}
0005435069444	0F6825	0084 222413	NATALIYA MELNIKOVA	{"phone": "+70694423142"}
0005435069445	DBE61A	6162 679966	ANASTASIYA IVANOVA	{"phone": "+70411917623"}
0005435069446	DBE61A	5184 697582	SERGEY STEPANOV	{"phone": "+70678216745"}
0005435069447	249FA8	9044 282376	VIKTOR BELOV	{"email": "vbelov_121969@postgrespro.ru", "phone": "+70272077122"}
0005435069448	CBB4F1	8039 013655	ZINAIDA ROMANOVA	{"email": "z-romanova-071982@postgrespro.ru", "phone": "+70189162861"}
0005435069449	555061	0321 056178	NIKITA ZAKHAROV	{"phone": "+70154830351"}
0005435069450	F36909	8316 310283	MATRENA EGOROVA	{"email": "egorova_matrena-061983@postgrespro.ru", "phone": "+70195638003"}
0005435069451	307CF2	0615 266805	TATYANA SMIRNOVA	{"phone": "+70574647626"}
0005435069453	C0D9C6	1986 335252	MAKSIM MOROZOV	{"email": "m_morozov_02071965@postgrespro.ru", "phone": "+70688836928"}
0005435069454	F2FEE7	1631 998868	NATALYA MOROZOVA	{"email": "morozova.natalya-21111979@postgrespro.ru", "phone": "+70846815083"}
0005435069455	BB90F1	1267 415158	OLEG VOROBEV	{"phone": "+70210192153"}
0005435069456	208F52	5003 958814	LIDIYA KONDRATEVA	{"email": "lidiyakondrateva.121975@postgrespro.ru", "phone": "+70790523281"}
0005435069457	B10D75	2715 351615	VALENTIN DMITRIEV	{"email": "dmitrievv.06111980@postgrespro.ru", "phone": "+70834829165"}
0005435069458	9EFF3D	3460 627969	TAMARA ORLOVA	{"email": "orlova.t-11101972@postgrespro.ru", "phone": "+70120659834"}
0005435069459	D9813B	1474 088338	DENIS SOROKIN	{"phone": "+70100914904"}
0005435069460	D9813B	9491 645124	IVAN ILIN	{"phone": "+70627625180"}
0005435069461	D9813B	1506 627055	ANNA KRASNOVA	{"email": "krasnovaanna-1968@postgrespro.ru", "phone": "+70444931556"}
0005435069462	D5D875	7410 097532	EVGENIY BONDARENKO	{"phone": "+70338719324"}
0005435069463	BB5733	2651 177203	SERGEY ANDREEV	{"phone": "+70749526943"}
0005435069464	BB5733	1182 454423	SVETLANA OSIPOVA	{"email": "osipova.s.101976@postgrespro.ru", "phone": "+70188916029"}
0005435069465	BB5733	8502 052337	ZHANNA IVANOVA	{"phone": "+70316986302"}
0005435069466	BE002D	7717 420148	ILYA ALEKSANDROV	{"email": "aleksandrov-i_23021965@postgrespro.ru", "phone": "+70952189561"}
0005435069467	746B2F	0606 717174	MILANA FILIPPOVA	{"phone": "+70452675096"}
0005435069468	746B2F	4059 089103	ELENA BELYAEVA	{"phone": "+70467070891"}
0005435069469	214FD2	9977 386737	DARYA FILIPPOVA	{"phone": "+70529168545"}
0005435069470	1F7ADA	3578 860655	VALENTINA BELYAEVA	{"email": "vbelyaeva.09011976@postgrespro.ru", "phone": "+70801869624"}
0005435069471	1F7ADA	2976 553841	MIKHAIL KONOVALOV	{"phone": "+70439163673"}
0005435069472	58F60F	5257 192306	VALENTINA DMITRIEVA	{"email": "dmitrieva-v_01101975@postgrespro.ru", "phone": "+70842049149"}
0005435069473	675393	3505 082602	RUSLAN DENISOV	{"email": "r_denisov_1965@postgrespro.ru", "phone": "+70785427143"}
0005435069474	F28038	6376 865797	VLADISLAV STEPANOV	{"email": "stepanovvladislav061982@postgrespro.ru", "phone": "+70737886362"}
0005435069475	F28038	4996 651867	VYACHESLAV KUZNECOV	{"phone": "+70300865102"}
0005435069476	E02538	2324 402757	NATALYA VOLKOVA	{"phone": "+70604212292"}
0005435069477	7B3CED	9042 562568	ANNA EFREMOVA	{"phone": "+70140059476"}
0005435069478	5AF04C	7255 565373	GALINA FEDOROVA	{"phone": "+70069404253"}
0005435069479	467B87	3573 776510	ALEKSANDR KUZNECOV	{"phone": "+70545067566"}
0005435069480	467B87	0409 439703	ELVIRA DAVYDOVA	{"email": "davydova_elvira-031981@postgrespro.ru", "phone": "+70179633885"}
0005435069481	35B4E2	5411 277227	ELENA FEDOROVA	{"email": "efedorova.1975@postgrespro.ru", "phone": "+70346716443"}
0005435069482	A97C65	8168 979799	RAFAEL DENISOV	{"email": "rdenisov-061970@postgrespro.ru", "phone": "+70437665978"}
0005435069483	28A58C	8042 026466	GALIYA SMIRNOVA	{"email": "smirnova_g_03081966@postgrespro.ru", "phone": "+70392501133"}
0005435069484	28A58C	6363 183670	ALEKSEY MAKAROV	{"phone": "+70361278030"}
0005435069485	37FDF8	8106 589849	VITALIY MIKHAYLOV	{"email": "vitaliy.mikhaylov.28111984@postgrespro.ru", "phone": "+70475958051"}
0005435069486	37FDF8	7419 079703	ILGIZ POPOV	{"phone": "+70157162983"}
0005435069487	37FDF8	6482 349775	ARTEM FROLOV	{"email": "frolov-artem-16051966@postgrespro.ru", "phone": "+70640254191"}
0005435069488	D1F711	1256 025079	LYUBOV IVANOVA	{"phone": "+70404874650"}
0005435069489	191E95	7025 168561	NATALYA SCHERBAKOVA	{"email": "n.scherbakova051979@postgrespro.ru", "phone": "+70623826709"}
0005435069490	579655	9005 802761	VLADIMIR GUSEV	{"phone": "+70402533761"}
0005435069491	579655	4090 819764	INGA ZHURAVLEVA	{"email": "zhuravleva_inga1978@postgrespro.ru", "phone": "+70600479401"}
0005435069492	E6CC38	9061 591012	EKATERINA NIKITINA	{"email": "nikitinaekaterina.101968@postgrespro.ru", "phone": "+70594031581"}
0005435069493	E6CC38	0459 649194	ALENA IVANOVA	{"phone": "+70247538271"}
0005435069494	AFF062	3823 070700	EVDOKIYA NIKITINA	{"email": "e-nikitina15091970@postgrespro.ru", "phone": "+70638987663"}
0005435069495	E5D34D	2201 066038	YULIYA SOLOVEVA	{"phone": "+70054315511"}
0005435069496	E5D34D	2696 929577	ALEKSANDRA KUZNECOVA	{"phone": "+70901289011"}
0005435069497	777AED	3677 569481	YURIY DMITRIEV	{"email": "dmitrievy.041961@postgrespro.ru", "phone": "+70302718265"}
0005435069498	4386C8	4662 214155	DMITRIY GERASIMOV	{"email": "gerasimov-d-31031978@postgrespro.ru", "phone": "+70259692798"}
0005435069499	4386C8	6377 535032	RASIM MIRONOV	{"email": "mironov_r08051970@postgrespro.ru", "phone": "+70163204424"}
0005435069500	CED333	0298 029589	RIMA NIKOLAEVA	{"email": "nikolaeva.r_23081966@postgrespro.ru", "phone": "+70154742526"}
0005435069501	CED333	4210 433618	OLESYA MAKAROVA	{"phone": "+70547480696"}
0005435069502	779BF3	3128 845447	VERA SMIRNOVA	{"email": "v.smirnova-081979@postgrespro.ru", "phone": "+70661066429"}
0005435069503	779BF3	6469 275365	YULIYA KARPOVA	{"phone": "+70841209161"}
0005435069504	A27A75	4956 363669	IVAN FOMIN	{"email": "i-fomin1981@postgrespro.ru", "phone": "+70515334119"}
0005435069505	FC7281	4155 624944	ANASTASIYA OVCHINNIKOVA	{"phone": "+70326759711"}
0005435069506	707C3B	1689 766368	VERA MOROZOVA	{"phone": "+70914144657"}
0005435069507	BA4EB3	0094 259719	OLGA MIKHAYLOVA	{"phone": "+70024716400"}
0005435069508	456882	2444 199906	NIKOLAY SERGEEV	{"email": "nikolay.sergeev1976@postgrespro.ru", "phone": "+70789767261"}
0005435069509	0E6C2D	4247 760232	ALEKSANDR SHEVCHENKO	{"phone": "+70383311560"}
0005435069510	98D6B3	1300 766149	ELENA DAVYDOVA	{"phone": "+70196130600"}
0005435069511	98D6B3	7668 568591	ALEKSEY KRASNOV	{"phone": "+70437767842"}
0005435069512	98D6B3	2587 076346	PAVEL SOROKIN	{"phone": "+70897054751"}
0005435069513	54E87C	0482 641461	OLEG GUSEV	{"phone": "+70244711381"}
0005435069514	5049C8	2460 650300	LYUBOV NIKITINA	{"phone": "+70061294404"}
0005435069515	8A4D2E	1909 034709	SERGEY BONDARENKO	{"email": "bondarenkos_1974@postgrespro.ru", "phone": "+70251162985"}
0005435069516	8D5148	9941 350324	TAMARA FEDOROVA	{"email": "fedorovatamara_1973@postgrespro.ru", "phone": "+70675720839"}
0005435069517	DA70BF	2353 087249	DMITRIY GERASIMOV	{"phone": "+70928079325"}
0005435069518	F5A00B	4268 500755	LYUBOV PAVLOVA	{"phone": "+70060756179"}
0005435069519	F5A00B	1203 854134	RUSTAM ZAYCEV	{"phone": "+70561762694"}
0005435069520	AC1B70	7813 950348	ALEKSANDR IVANOV	{"phone": "+70718178836"}
0005435069521	AC1B70	5246 515855	NATALYA ILINA	{"email": "n_ilina.091969@postgrespro.ru", "phone": "+70088476135"}
0005435069522	392AD7	5988 887478	ANTON VOROBEV	{"email": "vorobev_anton24101964@postgrespro.ru", "phone": "+70372419439"}
0005435069523	FFD65F	4891 607925	LEONID STEPANOV	{"email": "leonid-stepanov1975@postgrespro.ru", "phone": "+70081773642"}
0005435069524	A8F613	8135 542963	ALEKSEY SERGEEV	{"email": "sergeev_aleksey-031965@postgrespro.ru", "phone": "+70940708266"}
0005435069525	A8F613	4389 705244	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr.071970@postgrespro.ru", "phone": "+70014602432"}
0005435069526	A8F613	4353 594060	DMITRIY PETROV	{"phone": "+70634478326"}
0005435069527	2CEDF0	0161 865547	EVELINA ZHUKOVA	{"email": "evelina_zhukova.28091968@postgrespro.ru", "phone": "+70033491432"}
0005435069528	471BFE	4136 987756	ALEKSEY MELNIKOV	{"email": "a.melnikov-24081967@postgrespro.ru", "phone": "+70427981350"}
0005435069529	471BFE	6607 656996	LYUDMILA MATVEEVA	{"email": "matveeval1971@postgrespro.ru", "phone": "+70645877498"}
0005435069530	365947	3733 888257	NINA CHERNOVA	{"phone": "+70478920969"}
0005435069531	AA0E31	2277 093346	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov_1979@postgrespro.ru", "phone": "+70729581926"}
0005435069532	AA0E31	7822 694637	SERGEY KUZNECOV	{"phone": "+70688006543"}
0005435069533	AA0E31	2517 545240	VALENTINA MASLOVA	{"phone": "+70045364737"}
0005435069534	AA0E31	0937 798491	ANASTASIYA KOROLEVA	{"phone": "+70699545978"}
0005435069535	3DF440	0422 060474	YULIYA SOLOVEVA	{"email": "soloveva.yuliya22121978@postgrespro.ru", "phone": "+70270656866"}
0005435069536	F6D68C	3274 088176	ARTEM SCHERBAKOV	{"email": "a_scherbakov17081977@postgrespro.ru", "phone": "+70904263006"}
0005435069537	13F726	7114 220731	PAVEL STEPANOV	{"email": "pavel.stepanov.1986@postgrespro.ru", "phone": "+70175648205"}
0005435069538	6EF1EF	0533 911809	SERGEY FROLOV	{"email": "sergey_frolov_111978@postgrespro.ru", "phone": "+70587844726"}
0005435069539	38B942	5750 118614	PAVEL KAZAKOV	{"phone": "+70490022386"}
0005435069540	0AC3DB	2305 890674	RUSLAN KAZAKOV	{"email": "kazakov.r1983@postgrespro.ru", "phone": "+70266380415"}
0005435069541	0AC3DB	8882 712455	ALFIYA MATVEEVA	{"email": "matveeva.alfiya_111971@postgrespro.ru", "phone": "+70590505639"}
0005435069542	7D4E34	1057 361108	LYUDMILA IVANOVA	{"email": "ivanova_l.12091968@postgrespro.ru", "phone": "+70474981880"}
0005435069543	C1FB54	8076 848619	KONSTANTIN SEMENOV	{"email": "ksemenov_1967@postgrespro.ru", "phone": "+70967336646"}
0005435069544	CA78CE	4478 782470	RUDOLF KUZNECOV	{"email": "kuznecov_r-15041975@postgrespro.ru", "phone": "+70674801122"}
0005435069545	CA78CE	5651 846063	DIANA EGOROVA	{"phone": "+70030424142"}
0005435069546	676BFC	8865 255658	ALEKSEY PETROV	{"email": "petrov-aleksey-08071967@postgrespro.ru", "phone": "+70303968770"}
0005435069547	676BFC	4712 664058	ALISA GUSEVA	{"phone": "+70833310722"}
0005435069548	2C1AB2	5720 304233	ANASTASIYA SOLOVEVA	{"email": "solovevaanastasiya-1980@postgrespro.ru", "phone": "+70391405483"}
0005435069549	2C1AB2	8674 198949	ANTON POPOV	{"phone": "+70056360792"}
0005435069550	086741	9247 601931	VALENTINA ROMANOVA	{"email": "v-romanova_09101974@postgrespro.ru", "phone": "+70382416315"}
0005435069551	086741	2329 345445	SERGEY ZAYCEV	{"phone": "+70771511517"}
0005435069552	086741	6339 648830	FARID NIKITIN	{"email": "nikitin_f.121962@postgrespro.ru", "phone": "+70632700632"}
0005435069553	26141A	6191 291651	LYUBOV ZAKHAROVA	{"phone": "+70148738706"}
0005435069554	26141A	6043 828344	VASILIY IVANOV	{"email": "ivanov_vasiliy_04031972@postgrespro.ru", "phone": "+70175361923"}
0005435069555	EA0181	1107 909708	MARINA ANDREEVA	{"phone": "+70066248278"}
0005435069556	EA0181	6103 831992	IRINA SAVELEVA	{"phone": "+70862061988"}
0005435069557	EA0181	5585 578381	IRINA KISELEVA	{"email": "kiseleva.irina_18071983@postgrespro.ru", "phone": "+70074545522"}
0005435069558	3A9A2A	5528 462173	ANTONINA MAKAROVA	{"phone": "+70117107107"}
0005435069559	8A8104	8997 210936	POLINA DANILOVA	{"email": "danilovapolina_1966@postgrespro.ru", "phone": "+70843587892"}
0005435069560	8A8104	8249 935328	VIKTOR IVANOV	{"phone": "+70901938631"}
0005435069561	FF2DA3	5879 098296	ALEKSANDRA YAKOVLEVA	{"email": "a.yakovleva071968@postgrespro.ru", "phone": "+70690310465"}
0005435069562	FF2DA3	4453 722176	ALEKSANDR ZAYCEV	{"email": "zaycev_aleksandr031962@postgrespro.ru", "phone": "+70857126612"}
0005435069563	9BBC2B	2803 723078	ALEKSANDR GAVRILOV	{"email": "gavrilov.a19121982@postgrespro.ru", "phone": "+70136389781"}
0005435069619	2C198A	8063 803910	PAVEL KUZNECOV	{"email": "pavel_kuznecov-17051978@postgrespro.ru", "phone": "+70637615611"}
0005435069564	71F8D0	6601 272762	VALENTINA KUZNECOVA	{"email": "valentinakuznecova_21051969@postgrespro.ru", "phone": "+70826006528"}
0005435069565	71F8D0	6973 470804	KONSTANTIN SCHERBAKOV	{"phone": "+70192748214"}
0005435069566	71F8D0	6823 826758	VLADIMIR KUZNECOV	{"email": "kuznecovv-1975@postgrespro.ru", "phone": "+70870624728"}
0005435069567	197037	0702 279342	EKATERINA KUZNECOVA	{"email": "kuznecovae-07041970@postgrespro.ru", "phone": "+70360201103"}
0005435069568	197037	6005 217499	SERGEY SEMENOV	{"phone": "+70134930294"}
0005435069569	1773AA	4233 573606	MARINA POPOVA	{"email": "marina_popova_071964@postgrespro.ru", "phone": "+70617729767"}
0005435069570	1773AA	7125 891048	LYUDMILA NIKOLAEVA	{"phone": "+70310303424"}
0005435069571	72D910	6832 712329	DIANA RODIONOVA	{"phone": "+70624554744"}
0005435069572	EB79D7	5439 115382	NAIL POPOV	{"email": "popov.n_03121975@postgrespro.ru", "phone": "+70704811849"}
0005435069573	CBC113	7681 505152	LIDIYA MOROZOVA	{"email": "morozova-lidiya.23051966@postgrespro.ru", "phone": "+70147910165"}
0005435069574	A58C0C	5047 540604	ALEVTINA GUSEVA	{"phone": "+70836110294"}
0005435069575	BAAE48	2337 928985	NADEZHDA POPOVA	{"email": "nadezhda.popova-23031981@postgrespro.ru", "phone": "+70187154320"}
0005435069576	17A9E3	5672 423795	SVETLANA ANTONOVA	{"email": "svetlanaantonova-101976@postgrespro.ru", "phone": "+70030715790"}
0005435069577	F945AF	9933 072789	KONSTANTIN SOROKIN	{"phone": "+70848531478"}
0005435069578	F945AF	8773 958475	SERGEY BELOV	{"phone": "+70053941068"}
0005435069579	749FC0	8631 397773	ALEKSANDR ISAEV	{"email": "isaeva-23031976@postgrespro.ru", "phone": "+70884876727"}
0005435069580	749FC0	0799 083522	ANATOLIY BORISOV	{"phone": "+70097193801"}
0005435069581	34A582	4995 069410	IVAN ORLOV	{"email": "i-orlov-121965@postgrespro.ru", "phone": "+70512167238"}
0005435069582	32BAB9	6509 012173	VERA ARKHIPOVA	{"phone": "+70176935756"}
0005435069583	32BAB9	3343 292267	ANATOLIY SAVELEV	{"email": "saveleva_041959@postgrespro.ru", "phone": "+70359251996"}
0005435069584	BDCD97	4582 367492	OLEG VLASOV	{"email": "oleg_vlasov12041969@postgrespro.ru", "phone": "+70177236523"}
0005435069585	6F56E7	8008 195935	DMITRIY PETROV	{"email": "petrov_d-1969@postgrespro.ru", "phone": "+70869553381"}
0005435069586	6F56E7	8393 167771	VALENTINA ORLOVA	{"email": "orlova_valentina12101964@postgrespro.ru", "phone": "+70452765738"}
0005435069587	531765	7465 824442	DMITRIY BONDARENKO	{"email": "bondarenko_dmitriy_27101967@postgrespro.ru", "phone": "+70777461924"}
0005435069588	D7EA6E	7966 569496	TATYANA YAKOVLEVA	{"email": "yakovleva.tatyana.071975@postgrespro.ru", "phone": "+70734320722"}
0005435069589	EFA0FA	3420 812407	NIKOLAY MIKHAYLOV	{"phone": "+70064303005"}
0005435069590	4EFBD1	3509 944523	MARIYA ZAYCEVA	{"email": "zaycevamariya.1984@postgrespro.ru", "phone": "+70511372769"}
0005435069591	E3B5DB	5029 673560	LARISA ZAKHAROVA	{"phone": "+70071802874"}
0005435069592	738CD8	1142 649534	YULIYA ANDREEVA	{"email": "yuliya_andreeva121967@postgrespro.ru", "phone": "+70705308697"}
0005435069593	738CD8	3913 408328	ASKHAT PETROV	{"phone": "+70731895945"}
0005435069594	B733A0	6109 434833	ANNA DANILOVA	{"email": "danilova_a-1970@postgrespro.ru", "phone": "+70677066819"}
0005435069595	B733A0	3523 410100	TATYANA MATVEEVA	{"phone": "+70757302270"}
0005435069596	109BC0	9771 859307	DMITRIY NOVIKOV	{"email": "novikovd_1970@postgrespro.ru", "phone": "+70369568071"}
0005435069597	89D5E4	7076 236205	NIKOLAY ANDREEV	{"phone": "+70040343748"}
0005435069598	5A757B	7519 198317	EVGENIY TARASOV	{"email": "evgeniytarasov.1967@postgrespro.ru", "phone": "+70240974217"}
0005435069599	16F6A6	6715 114715	ZLATA NOVIKOVA	{"phone": "+70087549591"}
0005435069600	6FA70A	2792 456351	ELENA NIKOLAEVA	{"email": "elenanikolaeva.31011978@postgrespro.ru", "phone": "+70842963552"}
0005435069601	981188	2794 838916	PAVEL ISAEV	{"email": "p.isaev_1970@postgrespro.ru", "phone": "+70403561582"}
0005435069602	981188	6746 237408	ANGELINA KONOVALOVA	{"email": "angelina-konovalova1956@postgrespro.ru", "phone": "+70959213385"}
0005435069603	487051	1035 802785	ANNA SMIRNOVA	{"email": "a-smirnova_28101981@postgrespro.ru", "phone": "+70529430864"}
0005435069604	487051	2058 812406	SERGEY GORBUNOV	{"phone": "+70138302656"}
0005435069605	94CD14	2465 645016	NIKOLAY KOZLOV	{"email": "nikolaykozlov-121977@postgrespro.ru", "phone": "+70296308037"}
0005435069606	3FE9FF	8940 663871	ILYA KUZMIN	{"email": "kuzminilya-1965@postgrespro.ru", "phone": "+70850303166"}
0005435069607	9BF9C6	0433 110068	RAVILYA KUZNECOVA	{"email": "rkuznecova-27051975@postgrespro.ru", "phone": "+70011761393"}
0005435069608	8F2F68	0062 183809	TATYANA FOMINA	{"email": "tatyanafomina_081960@postgrespro.ru", "phone": "+70088686624"}
0005435069609	4DD484	1624 600597	VLADIMIR GRIGOREV	{"email": "grigorevv.101978@postgrespro.ru", "phone": "+70919471908"}
0005435069610	1AB8D0	8704 958979	VALERIY KUZMIN	{"phone": "+70613872078"}
0005435069611	6826DE	8766 745318	VALENTINA ROMANOVA	{"phone": "+70943634640"}
0005435069612	6758D3	5019 510120	ELENA KUZNECOVA	{"phone": "+70744284919"}
0005435069613	6758D3	8258 620113	VLADIMIR MAKAROV	{"email": "makarov_v071977@postgrespro.ru", "phone": "+70236599969"}
0005435069614	6758D3	2079 378612	ALISA KUZNECOVA	{"email": "kuznecovaa111964@postgrespro.ru", "phone": "+70121607989"}
0005435069615	5666C8	6404 002556	VLADIMIR MARTYNOV	{"email": "martynov-vladimir_18051979@postgrespro.ru", "phone": "+70215762666"}
0005435069616	BDEBFF	0983 665414	MARIYA KUZMINA	{"email": "kuzmina_mariya1965@postgrespro.ru", "phone": "+70627902225"}
0005435069617	BDEBFF	1709 901290	ELENA BOGDANOVA	{"email": "bogdanova-elena_1974@postgrespro.ru", "phone": "+70055187416"}
0005435069618	3C25CF	8616 673925	ANATOLIY SAVELEV	{"phone": "+70714854173"}
0005435069620	CB436D	3824 550117	VLADIMIR IVANOV	{"phone": "+70357011683"}
0005435069621	429000	4790 075385	LYUDMILA TIKHONOVA	{"email": "tikhonova_lyudmila1960@postgrespro.ru", "phone": "+70381209310"}
0005435069622	F4FF93	1260 942875	SVETLANA SEMENOVA	{"phone": "+70161275771"}
0005435069623	BCC68E	9425 667630	KAMIL DAVYDOV	{"phone": "+70251155511"}
0005435069624	BCC68E	7673 806034	YURIY NOVIKOV	{"phone": "+70296281402"}
0005435069625	2F9338	4000 339381	ZOYA FILIPPOVA	{"email": "filippovaz.12011965@postgrespro.ru", "phone": "+70432299588"}
0005435069626	2F9338	6166 162665	ELIZAVETA OSIPOVA	{"email": "e-osipova1975@postgrespro.ru", "phone": "+70582330860"}
0005435069627	6468A0	5775 412917	ARTEM TIKHONOV	{"email": "tikhonov.artem.1979@postgrespro.ru", "phone": "+70016878579"}
0005435069628	6468A0	7130 205347	IVAN ALEKSEEV	{"phone": "+70751119618"}
0005435069629	6468A0	0338 310695	ELENA KONDRATEVA	{"phone": "+70622422687"}
0005435069630	84A271	2348 544244	ANDREY KRASNOV	{"email": "krasnov.a.101976@postgrespro.ru", "phone": "+70532100182"}
0005435069631	22DDCE	2521 063550	OLGA KOZLOVA	{"email": "kozlovaolga-011967@postgrespro.ru", "phone": "+70684983663"}
0005435069632	077044	5202 875375	VIKTORIYA MATVEEVA	{"phone": "+70647370372"}
0005435069633	3AF946	5282 395822	NATALYA KUZNECOVA	{"phone": "+70149123318"}
0005435069634	441559	8347 286427	LYUDMILA NAUMOVA	{"email": "naumovalyudmila.17011970@postgrespro.ru", "phone": "+70658403307"}
0005435069635	441559	7994 970110	ALEKSEY KUZMIN	{"phone": "+70969178097"}
0005435069636	B10667	5958 626057	VASILIY SIDOROV	{"phone": "+70365895352"}
0005435069637	81096B	3052 045438	ANDREY SERGEEV	{"phone": "+70144108130"}
0005435069638	46DEF4	9062 867396	ELENA IVANOVA	{"email": "ivanovaelena-21061978@postgrespro.ru", "phone": "+70068971551"}
0005435069639	46DEF4	4812 631453	SOFYA BARANOVA	{"email": "baranovasofya-02021971@postgrespro.ru", "phone": "+70638334517"}
0005435069640	091791	4313 972647	NATALYA BELOVA	{"email": "belovanatalya.111978@postgrespro.ru", "phone": "+70068539189"}
0005435069641	6BFB7E	6971 048017	SVETLANA PAVLOVA	{"email": "pavlova-s.021969@postgrespro.ru", "phone": "+70563351246"}
0005435069642	6BFB7E	6808 694948	MARIYA BORISOVA	{"phone": "+70970093389"}
0005435069643	B8822B	9537 227057	ALBERT GAVRILOV	{"email": "albert.gavrilov_05021975@postgrespro.ru", "phone": "+70364028686"}
0005435069644	B5A360	3714 445050	OLGA POLYAKOVA	{"email": "polyakova_o-1963@postgrespro.ru", "phone": "+70088878053"}
0005435069645	E4745F	4287 896894	ANATOLIY MAKAROV	{"phone": "+70599421076"}
0005435069646	D81D07	7990 392729	EVGENIY MOROZOV	{"phone": "+70891356278"}
0005435069647	EB89BB	2281 187887	ANTON FEDOROV	{"email": "anton.fedorov_091973@postgrespro.ru", "phone": "+70594220507"}
0005435069648	EB89BB	3442 971880	ALEKSEY SCHERBAKOV	{"phone": "+70055590615"}
0005435069649	D0B37F	2489 983911	SERGEY GORBUNOV	{"phone": "+70569313513"}
0005435069650	3AB240	2626 002718	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay.111975@postgrespro.ru", "phone": "+70812373105"}
0005435069651	789543	9450 919807	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov13011974@postgrespro.ru", "phone": "+70160527437"}
0005435069652	2864E3	0261 954805	IGOR EGOROV	{"email": "egorovigor_25121965@postgrespro.ru", "phone": "+70691385086"}
0005435069653	F968C9	0483 645468	VALERIY ZHURAVLEV	{"email": "zhuravlev-valeriy.1986@postgrespro.ru", "phone": "+70743147141"}
0005435069654	F968C9	4259 862116	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov16091988@postgrespro.ru", "phone": "+70729575130"}
0005435069655	DE056D	4035 431707	RENAT SEMENOV	{"email": "semenov_renat-091973@postgrespro.ru", "phone": "+70880760724"}
0005435069656	DE056D	3027 410651	SERGEY DENISOV	{"email": "sergey-denisov21121974@postgrespro.ru", "phone": "+70483000059"}
0005435069657	864A5B	4289 819395	MIKHAIL GORBUNOV	{"phone": "+70220664521"}
0005435069658	864A5B	2424 724684	MARIYA EGOROVA	{"phone": "+70648919939"}
0005435069659	864A5B	7252 082593	IVAN GUSEV	{"email": "i-gusev-1972@postgrespro.ru", "phone": "+70326765303"}
0005435069660	FFABD4	2225 233242	OLGA VASILEVA	{"email": "olga_vasileva.051972@postgrespro.ru", "phone": "+70889734102"}
0005435069661	DC22EF	5729 000006	SERGEY PETROV	{"phone": "+70271678890"}
0005435069662	DC22EF	9525 936269	LYUBOV PETROVA	{"email": "lyubov.petrova.111973@postgrespro.ru", "phone": "+70517614217"}
0005435069663	5C722B	8757 536990	ANDREY OSIPOV	{"email": "osipovandrey.12031976@postgrespro.ru", "phone": "+70538103834"}
0005435069664	5C722B	7335 723899	VITALIY IVANOV	{"email": "v_ivanov_071979@postgrespro.ru", "phone": "+70777447458"}
0005435069665	7E2F1C	3888 985825	VIKTOR ROMANOV	{"email": "romanov.v.051972@postgrespro.ru", "phone": "+70110397539"}
0005435069666	7E2F1C	8942 415044	GEORGIY MEDVEDEV	{"email": "medvedev_georgiy_1983@postgrespro.ru", "phone": "+70688465177"}
0005435069667	B3BEB7	1907 582840	MIKHAIL MEDVEDEV	{"email": "mikhail-medvedev-1972@postgrespro.ru", "phone": "+70195439240"}
0005435069668	1C886E	2778 438233	YANA KRASNOVA	{"phone": "+70547814946"}
0005435069669	B0D880	7443 160825	ALEKSANDR ORLOV	{"phone": "+70546965080"}
0005435069670	DF03F3	0095 031782	NIKITA VASILEV	{"email": "nvasilev19071977@postgrespro.ru", "phone": "+70554916479"}
0005435069671	7B4BC0	8939 517799	TATYANA POPOVA	{"phone": "+70428915308"}
0005435069672	7B4BC0	2436 890129	ALEKSEY KOROLEV	{"email": "korolev-a26021973@postgrespro.ru", "phone": "+70953950512"}
0005435069673	54F75D	5706 161254	TAMARA NIKITINA	{"email": "nikitina_t101982@postgrespro.ru", "phone": "+70267070787"}
0005435069674	570620	0920 375435	NINA IVANOVA	{"phone": "+70895573484"}
0005435069675	570620	4430 883348	OLGA GRISHINA	{"phone": "+70201778677"}
0005435069676	570620	0665 830720	VALERIY BELOV	{"email": "belov.valeriy-081972@postgrespro.ru", "phone": "+70358620231"}
0005435069677	97F84C	6244 738031	YURIY TIKHONOV	{"email": "yuriytikhonov-1974@postgrespro.ru", "phone": "+70250367750"}
0005435069678	97F84C	6124 807566	YANA SMIRNOVA	{"phone": "+70744580113"}
0005435069679	7FE884	4708 874466	VIKTOR SOROKIN	{"phone": "+70158941916"}
0005435069680	687727	8074 322189	NADEZHDA VASILEVA	{"email": "vasilevan_09031966@postgrespro.ru", "phone": "+70272206039"}
0005435069681	051924	8929 649380	EVGENIYA FILIPPOVA	{"email": "filippova_e.30101979@postgrespro.ru", "phone": "+70663035460"}
0005435069682	5E7D9C	3398 475584	YURIY BONDARENKO	{"email": "y.bondarenko-1972@postgrespro.ru", "phone": "+70667553569"}
0005435069683	5E7D9C	4254 295509	NIKOLAY TIMOFEEV	{"email": "ntimofeev1965@postgrespro.ru", "phone": "+70494847962"}
0005435069684	C33545	2186 026887	ANNA KRASNOVA	{"phone": "+70915891378"}
0005435069685	C33545	8593 318149	LYAYSAN FROLOVA	{"phone": "+70473691076"}
0005435069686	0F325E	5803 853650	SVETLANA SOKOLOVA	{"phone": "+70079923847"}
0005435069687	6CF459	2414 331715	MARGARITA LEBEDEVA	{"email": "lebedeva.margarita_1966@postgrespro.ru", "phone": "+70843248722"}
0005435069688	2F271A	0744 334385	LYUDMILA ANDREEVA	{"email": "andreeva-lyudmila_28071978@postgrespro.ru", "phone": "+70220829810"}
0005435069689	2F271A	3659 019587	VLADIMIR SOLOVEV	{"phone": "+70776512307"}
0005435069690	1BFD46	1940 116704	NIKOLAY ILIN	{"phone": "+70701984459"}
0005435069691	420F89	9716 358499	NIKOLAY MOROZOV	{"phone": "+70094369185"}
0005435069692	031894	0204 503534	SVETLANA KAZAKOVA	{"email": "s-kazakova-121965@postgrespro.ru", "phone": "+70830289318"}
0005435069693	031894	9518 386174	ANNA PAVLOVA	{"phone": "+70942388714"}
0005435069694	E0FFC4	5769 378362	LARISA NAUMOVA	{"phone": "+70069324856"}
0005435069695	64D4DC	5740 876514	RADIK ANDREEV	{"phone": "+70415770320"}
0005435069696	64D4DC	5173 054754	DMITRIY VLASOV	{"email": "vlasovd-28051968@postgrespro.ru", "phone": "+70845692291"}
0005435069697	C3DDFC	9167 826989	IVAN TIKHONOV	{"phone": "+70959868257"}
0005435069698	C98424	6573 567734	PAVEL SHEVCHENKO	{"email": "pshevchenko14121982@postgrespro.ru", "phone": "+70518601460"}
0005435069699	F91A07	3749 951251	ANDREY SEMENOV	{"email": "a_semenov-051966@postgrespro.ru", "phone": "+70419705302"}
0005435069700	00975D	4589 535055	BORIS NIKITIN	{"phone": "+70876123803"}
0005435069701	00975D	8124 487274	DANIL STEPANOV	{"email": "stepanovd071979@postgrespro.ru", "phone": "+70899465116"}
0005435069702	A0CF1A	6142 221671	DENIS KRASNOV	{"phone": "+70486879049"}
0005435069703	EBCB5D	7089 499529	IRINA FEDOROVA	{"phone": "+70578706481"}
0005435069704	F374D8	7851 916635	ANTON PETROV	{"email": "petrov.anton_021981@postgrespro.ru", "phone": "+70407423077"}
0005435069705	B69782	1992 938963	PAVEL RODIONOV	{"email": "rodionov.p1969@postgrespro.ru", "phone": "+70535024300"}
0005435069706	19D089	7979 081790	OLGA MASLOVA	{"email": "maslova.o.09081963@postgrespro.ru", "phone": "+70292404176"}
0005435069707	19D089	3304 292013	VLADIMIR ZAKHAROV	{"phone": "+70093191478"}
0005435069708	19D089	5610 208986	EVGENIY BORISOV	{"phone": "+70795160159"}
0005435069709	E1E510	3079 710915	IVAN MIKHAYLOV	{"email": "mikhaylov_ivan.1981@postgrespro.ru", "phone": "+70749093919"}
0005435069710	17C543	9260 872815	YURIY EGOROV	{"email": "egorov.y021976@postgrespro.ru", "phone": "+70099750138"}
0005435069711	272F62	1774 180456	TAMARA MAKSIMOVA	{"phone": "+70867006562"}
0005435069712	80543C	7652 351234	EVGENIY EGOROV	{"email": "egorov.evgeniy.1971@postgrespro.ru", "phone": "+70426298953"}
0005435069713	A7EDC0	4300 155194	IVAN MOROZOV	{"phone": "+70054002110"}
0005435069714	A7EDC0	5246 119830	PELAGEYA BARANOVA	{"email": "pelageyabaranova-20031964@postgrespro.ru", "phone": "+70497422765"}
0005435069715	C5DE5F	4231 815004	ANDREY MOROZOV	{"email": "morozov-andrey.1978@postgrespro.ru", "phone": "+70946271955"}
0005435069716	224202	1295 488965	DARYA KOMAROVA	{"phone": "+70217826555"}
0005435069717	1B898E	3834 249157	LYUDMILA SEMENOVA	{"phone": "+70544124921"}
0005435069718	A00BF6	6615 777695	GLEB ZAYCEV	{"phone": "+70350735051"}
0005435069719	C9AA23	9498 265169	EVGENIYA FILIPPOVA	{"phone": "+70163154717"}
0005435069720	E7562A	5429 911926	ALEKSANDR ZAYCEV	{"email": "zaycev.aleksandr_071971@postgrespro.ru", "phone": "+70233282078"}
0005435069721	EA46EF	1604 549855	VLADIMIR IVANOV	{"phone": "+70081277133"}
0005435069722	16A981	9935 993751	YURIY VASILEV	{"phone": "+70000267821"}
0005435069723	31A50D	8167 918154	OLGA NIKITINA	{"email": "nikitinao25081972@postgrespro.ru", "phone": "+70853685950"}
0005435069724	DE5F12	6919 742155	ALENA KARPOVA	{"email": "a-karpova25041978@postgrespro.ru", "phone": "+70897106457"}
0005435069725	DE5F12	2421 827052	TAISIYA VASILEVA	{"email": "vasileva.t-021975@postgrespro.ru", "phone": "+70019414083"}
0005435069726	861EEA	6687 699677	SERGEY KUZNECOV	{"phone": "+70007617516"}
0005435069727	861EEA	1842 831530	SOFYA KUDRYASHOVA	{"email": "sofya_kudryashova-081963@postgrespro.ru", "phone": "+70500314382"}
0005435069728	861EEA	9323 629775	TAMARA POPOVA	{"phone": "+70862459359"}
0005435069729	98153E	8744 419261	KARINA KONOVALOVA	{"email": "k_konovalova_101965@postgrespro.ru", "phone": "+70381875966"}
0005435069730	3108D7	4705 056146	DENIS ILIN	{"email": "ilin_denis.1969@postgrespro.ru", "phone": "+70057356777"}
0005435069731	D8BAB0	1976 935316	YURIY NAUMOV	{"email": "naumov.y-23051960@postgrespro.ru", "phone": "+70068693960"}
0005435069732	D8BAB0	7204 204016	TATYANA IVANOVA	{"phone": "+70739894518"}
0005435069733	087914	6790 896423	VIKTOR SAVELEV	{"phone": "+70882113420"}
0005435069734	7292FD	6628 037873	OLGA STEPANOVA	{"phone": "+70846628233"}
0005435069735	4D8B0D	3811 056963	YULIYA NESTEROVA	{"phone": "+70010969402"}
0005435069736	4EDD2D	2791 783885	VLADIMIR ANDREEV	{"phone": "+70680340326"}
0005435069737	C0DC7A	5020 571905	NATALYA POTAPOVA	{"email": "potapovan.1973@postgrespro.ru", "phone": "+70128639221"}
0005435069738	A68FE2	2931 452940	RAIS ZAYCEV	{"email": "zaycevr_1971@postgrespro.ru", "phone": "+70728107885"}
0005435069739	A68FE2	3593 377214	SERGEY KOZLOV	{"phone": "+70493443555"}
0005435069740	B88DB1	2094 685128	OKSANA KARPOVA	{"phone": "+70013488673"}
0005435069741	B88DB1	5923 962131	DINA PAVLOVA	{"email": "pavlova_dina-101976@postgrespro.ru", "phone": "+70673611077"}
0005435069742	052174	2112 301938	ALEKSEY KUZNECOV	{"phone": "+70108442296"}
0005435069743	8E2950	4090 974916	IRINA TROFIMOVA	{"email": "i_trofimova_29031968@postgrespro.ru", "phone": "+70793900995"}
0005435069744	34AB55	9302 726059	VERA KISELEVA	{"email": "kiseleva.vera-1970@postgrespro.ru", "phone": "+70846805491"}
0005435069745	34AB55	5574 858866	NATALYA KOLESNIKOVA	{"phone": "+70445727655"}
0005435069746	7B1039	2922 123778	NATALYA IVANOVA	{"email": "n_ivanova041979@postgrespro.ru", "phone": "+70814816799"}
0005435069747	5408D1	0565 104646	KONSTANTIN ALEKSEEV	{"email": "alekseev-k-22111966@postgrespro.ru", "phone": "+70654866831"}
0005435069748	5408D1	0112 823645	ANDREY ZAYCEV	{"email": "andrey.zaycev.061972@postgrespro.ru", "phone": "+70533972623"}
0005435069749	507BA2	7760 135111	ALEKSEY GORBUNOV	{"phone": "+70073664504"}
0005435069750	CC898A	9034 980494	OLGA LUKYANOVA	{"email": "olga-lukyanova1979@postgrespro.ru", "phone": "+70432540144"}
0005435069751	CC898A	6505 441844	ARTEM SOROKIN	{"email": "asorokin.051994@postgrespro.ru", "phone": "+70904298829"}
0005435069752	E56F8E	4224 715793	PETR DENISOV	{"email": "petr_denisov.07091971@postgrespro.ru", "phone": "+70870584621"}
0005435069753	B45B45	4356 518451	NIKOLAY IVANOV	{"phone": "+70373322341"}
0005435069754	A0543A	8696 962245	NATALYA ILINA	{"email": "natalya_ilina-1967@postgrespro.ru", "phone": "+70248394928"}
0005435069755	AEE12A	5952 461333	VADIM KOROLEV	{"email": "korolev-vadim-25011983@postgrespro.ru", "phone": "+70944577241"}
0005435069756	AEE12A	4091 810430	OLGA CHERNOVA	{"phone": "+70940728030"}
0005435069757	1566A0	5762 013752	ANDREY NAZAROV	{"email": "nazarov-andrey-1987@postgrespro.ru", "phone": "+70851265807"}
0005435069758	420851	9394 840178	VALENTIN IVANOV	{"email": "valentinivanov24061969@postgrespro.ru", "phone": "+70766811331"}
0005435069759	420851	9206 580211	TAMARA PETROVA	{"phone": "+70518642633"}
0005435069760	B9E0D1	6331 084647	ALEKSEY ZHURAVLEV	{"email": "a_zhuravlev16101965@postgrespro.ru", "phone": "+70140125851"}
0005435069761	8DCCE5	7383 773488	ALEKSEY KUZMIN	{"phone": "+70385632561"}
0005435069762	D7605A	9754 275748	ANDREY MAKAROV	{"phone": "+70610955090"}
0005435069763	29AF6A	3560 727085	VLADIMIR SOROKIN	{"email": "sorokin.v071976@postgrespro.ru", "phone": "+70923683779"}
0005435069764	0BB742	8962 927166	VLADIMIR ILIN	{"email": "v_ilin_1976@postgrespro.ru", "phone": "+70064786241"}
0005435069765	0BB742	6958 846432	OLESYA MIKHAYLOVA	{"phone": "+70220506118"}
0005435069766	690DFB	8697 273673	LIDIYA ZOTOVA	{"phone": "+70940949680"}
0005435069767	DA0139	9386 993467	NADEZHDA GRISHINA	{"email": "nadezhdagrishina_30081988@postgrespro.ru", "phone": "+70988088670"}
0005435069768	9E2F02	2755 467375	VITALIY ALEKSANDROV	{"email": "aleksandrov_vitaliy.22061978@postgrespro.ru", "phone": "+70205428149"}
0005435069769	F330CE	8498 954567	ILYA SOLOVEV	{"phone": "+70011842830"}
0005435069770	012213	7125 657992	OLEG CHERNOV	{"email": "oleg-chernov_091970@postgrespro.ru", "phone": "+70768695973"}
0005435069771	012213	3029 283873	MIKHAIL MOROZOV	{"phone": "+70425692616"}
0005435069772	438B40	7224 041816	ILYA KONOVALOV	{"email": "konovalov_i-051974@postgrespro.ru", "phone": "+70126398639"}
0005435069773	2B4CB2	5485 928815	NIKOLAY ORLOV	{"email": "orlovnikolay091969@postgrespro.ru", "phone": "+70224070362"}
0005435069774	2B4CB2	5979 806519	IVAN DMITRIEV	{"phone": "+70003831470"}
0005435069775	46EE29	2561 850645	ANTONINA SOROKINA	{"phone": "+70759931119"}
0005435069776	20E4D5	4008 955405	EKATERINA YAKOVLEVA	{"phone": "+70376202937"}
0005435069777	5377D3	0081 743762	OLESYA BARANOVA	{"email": "o_baranova-101965@postgrespro.ru", "phone": "+70517102753"}
0005435069778	E7BD86	2884 441199	NIKOLAY EGOROV	{"phone": "+70927998061"}
0005435069779	FE1354	4844 254424	VLADIMIR CHERNOV	{"phone": "+70514872035"}
0005435069780	FE1354	3687 232703	GALINA ZAKHAROVA	{"phone": "+70587542633"}
0005435069781	7474BC	3470 689587	ALEKSEY KISELEV	{"phone": "+70745762035"}
0005435069782	00BEEA	6183 888853	NIKITA VLASOV	{"email": "nikita-vlasov1972@postgrespro.ru", "phone": "+70407110400"}
0005435069783	00BEEA	3215 405746	LYUBOV VLASOVA	{"phone": "+70576401998"}
0005435069784	00BEEA	1897 532039	SERGEY ZAKHAROV	{"email": "szakharov23121963@postgrespro.ru", "phone": "+70600874647"}
0005435069785	568862	7980 782082	YANA MOROZOVA	{"phone": "+70750777511"}
0005435069786	EDC25C	9081 390066	ANASTASIYA ANDREEVA	{"email": "a_andreeva.04091976@postgrespro.ru", "phone": "+70439422648"}
0005435069787	EDC25C	4596 761408	RAISA LAZAREVA	{"email": "r-lazareva061967@postgrespro.ru", "phone": "+70281614984"}
0005435069788	EDC25C	4374 320847	SERGEY SOKOLOV	{"phone": "+70412682615"}
0005435069789	161AB4	2521 640864	VLADISLAV IVANOV	{"email": "v_ivanov15061985@postgrespro.ru", "phone": "+70173690989"}
0005435069790	207528	1926 147001	MARINA ZOTOVA	{"email": "marinazotova1975@postgrespro.ru", "phone": "+70490903428"}
0005435069791	207528	9256 195183	VIKTOR NOVIKOV	{"email": "viktor_novikov1958@postgrespro.ru", "phone": "+70946763515"}
0005435069792	E70AA6	6252 951575	KIRILL ALEKSEEV	{"email": "alekseevk.081981@postgrespro.ru", "phone": "+70756345231"}
0005435069793	DD939F	7516 632687	ZINAIDA OVCHINNIKOVA	{"phone": "+70701099723"}
0005435069794	DCC7CA	5523 144692	IGOR TIKHONOV	{"email": "itikhonov1970@postgrespro.ru", "phone": "+70492506563"}
0005435069795	691CC7	5658 409849	POLINA IVANOVA	{"phone": "+70253679485"}
0005435069796	EE897A	8741 895952	ANATOLIY NIKOLAEV	{"phone": "+70954616661"}
0005435069797	DC3307	4361 439127	NATALYA BELOVA	{"phone": "+70418579928"}
0005435069798	E16771	7579 381951	VLADIMIR TARASOV	{"phone": "+70810452908"}
0005435069799	E16771	8776 195762	ALEKSANDR ANTONOV	{"email": "a.antonov_1979@postgrespro.ru", "phone": "+70328878112"}
0005435069800	E16771	7799 440914	KRISTINA BELOVA	{"phone": "+70614317953"}
0005435069801	4BDD4E	6620 290180	ELENA FEDOROVA	{"email": "e_fedorova.12081972@postgrespro.ru", "phone": "+70712208984"}
0005435069802	E8E231	8466 923507	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya021970@postgrespro.ru", "phone": "+70384494637"}
0005435069803	6EF2DB	7675 181029	ANATOLIY CHERNOV	{"phone": "+70020617719"}
0005435069804	6EF2DB	0597 995618	EVGENIYA MASLOVA	{"phone": "+70704085804"}
0005435069805	FB8306	0100 831346	GALINA MATVEEVA	{"email": "matveevag_1970@postgrespro.ru", "phone": "+70328910738"}
0005435069806	FFB910	1159 288767	YULIYA MAKAROVA	{"email": "makarova_y_18111957@postgrespro.ru", "phone": "+70197707326"}
0005435069807	842A4C	1888 660579	ANDREY SAVELEV	{"email": "a.savelev_07021970@postgrespro.ru", "phone": "+70032577854"}
0005435069808	36025D	7738 987679	SVETLANA AFANASEVA	{"email": "svetlana-afanaseva.041982@postgrespro.ru", "phone": "+70370802373"}
0005435069809	4DE700	7805 130168	TAMARA BELOVA	{"email": "belova_t.1970@postgrespro.ru", "phone": "+70072443000"}
0005435069810	E3212F	4474 981433	ANDREY MIRONOV	{"email": "a_mironov.11021980@postgrespro.ru", "phone": "+70209626819"}
0005435069811	E3212F	4478 298097	ANDREY KULIKOV	{"phone": "+70203489984"}
0005435069812	E3212F	1626 533319	KIRILL ROMANOV	{"email": "romanov.kirill_1969@postgrespro.ru", "phone": "+70160136541"}
0005435069813	285F64	5780 475857	IVAN FILIPPOV	{"phone": "+70514428287"}
0005435069814	285F64	8783 915363	ALEKSANDR NIKOLAEV	{"phone": "+70334322787"}
0005435069815	90EBC6	2790 300122	OLESYA BARANOVA	{"phone": "+70113158564"}
0005435069816	483B96	6082 815082	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov_091975@postgrespro.ru", "phone": "+70139139247"}
0005435069817	9FAC95	4005 917972	ELENA SOKOLOVA	{"phone": "+70779428969"}
0005435069818	9FAC95	5351 493528	DARYA KUZMINA	{"email": "darya-kuzmina.071978@postgrespro.ru", "phone": "+70218556854"}
0005435069819	9FAC95	9455 392833	EVGENIY FEDOROV	{"phone": "+70911246348"}
0005435069820	551DF3	6666 671296	ALEKSANDR BARANOV	{"email": "a-baranov-061981@postgrespro.ru", "phone": "+70364857033"}
0005435069821	616CBA	1971 959139	ELENA BORISOVA	{"email": "e-borisova_061972@postgrespro.ru", "phone": "+70409786387"}
0005435069822	A6C7C3	7492 189975	GALINA ALEKSANDROVA	{"email": "galina-aleksandrova071985@postgrespro.ru", "phone": "+70529973501"}
0005435069823	90F1C5	3463 641336	AZAT MIRONOV	{"phone": "+70444242047"}
0005435069824	ED4A6B	5335 968600	ANNA DANILOVA	{"email": "a_danilova-31051975@postgrespro.ru", "phone": "+70531865567"}
0005435069825	ED4A6B	5672 501714	ALIYA ANISIMOVA	{"phone": "+70759868693"}
0005435069826	B68116	6694 266361	SERGEY MEDVEDEV	{"email": "s_medvedev.111973@postgrespro.ru", "phone": "+70040761830"}
0005435069827	B68116	0168 271352	VALENTINA IVANOVA	{"phone": "+70170080228"}
0005435069828	B68116	2594 206197	GENNADIY NAZAROV	{"email": "nazarov_g1978@postgrespro.ru", "phone": "+70057999835"}
0005435069829	78070D	3352 868799	ANNA ZAYCEVA	{"email": "annazayceva1978@postgrespro.ru", "phone": "+70896517938"}
0005435069830	3FC7C8	3877 604489	ALEKSEY MIKHAYLOV	{"email": "mikhaylovaleksey1969@postgrespro.ru", "phone": "+70347617839"}
0005435069831	3F9826	6651 630885	IVAN ILIN	{"email": "ilin-ivan1967@postgrespro.ru", "phone": "+70742409899"}
0005435069832	AD5C91	3574 311202	VLADIMIR ZHURAVLEV	{"phone": "+70377058419"}
0005435069833	E1AF25	5814 982347	TATYANA SOROKINA	{"email": "sorokina-t071981@postgrespro.ru", "phone": "+70107255204"}
0005435069834	4A4C48	7029 351224	VERA KUZNECOVA	{"email": "v-kuznecova31071962@postgrespro.ru", "phone": "+70220669600"}
0005435069835	D4C7E7	1714 239779	ANNA MARTYNOVA	{"phone": "+70091194497"}
0005435069836	A0ED85	4364 297778	ELENA KUDRYASHOVA	{"phone": "+70334243165"}
0005435069837	E786AF	3678 122744	TATYANA TIKHONOVA	{"email": "tikhonova_t-1985@postgrespro.ru", "phone": "+70716908232"}
0005435069838	E786AF	9678 797944	IGOR MOROZOV	{"email": "morozov.i-091967@postgrespro.ru", "phone": "+70459057590"}
0005435069839	D7C8E6	7517 310282	SERGEY FROLOV	{"email": "sfrolov.23101976@postgrespro.ru", "phone": "+70672065000"}
0005435069840	F387B4	9295 461131	EKATERINA KOMAROVA	{"phone": "+70479072625"}
0005435069841	DCC90A	9299 907382	IGOR NAZAROV	{"phone": "+70605560464"}
0005435069842	EC5E63	6230 099544	NATALYA ZAKHAROVA	{"phone": "+70187852269"}
0005435069843	54B608	5346 656361	ALEKSANDR FROLOV	{"phone": "+70724216894"}
0005435069844	54B608	0812 397881	LARISA NAZAROVA	{"phone": "+70468429100"}
0005435069845	54B608	6782 225439	EVGENIY PETROV	{"email": "petrov_evgeniy_26101977@postgrespro.ru", "phone": "+70607135029"}
0005435069846	1CB022	6096 010487	LILIYA GUSEVA	{"email": "gusevaliliya.021974@postgrespro.ru", "phone": "+70994049113"}
0005435069847	1CB022	9364 549044	ALEKSANDR AFANASEV	{"email": "aafanasev-061976@postgrespro.ru", "phone": "+70876001943"}
0005435069848	75AACB	8307 599901	MAKSIM YAKOVLEV	{"email": "myakovlev_12041957@postgrespro.ru", "phone": "+70993487681"}
0005435069849	75AACB	7786 800289	ALEKSEY MATVEEV	{"email": "aleksey-matveev10101965@postgrespro.ru", "phone": "+70865625809"}
0005435069850	4D1C1C	1279 819672	IVAN KOZLOV	{"phone": "+70984000506"}
0005435069851	87FD13	7306 596927	SVETLANA NIKIFOROVA	{"phone": "+70413265984"}
0005435069852	87FD13	1494 802120	ANATOLIY IVANOV	{"phone": "+70543620905"}
0005435069853	8922EC	1738 986209	MAKSIM KAZAKOV	{"email": "m-kazakov-1975@postgrespro.ru", "phone": "+70984773038"}
0005435069854	8922EC	0910 914428	RINAT VOLKOV	{"phone": "+70923523392"}
0005435069855	67ED04	1396 976446	VERA KOZLOVA	{"phone": "+70628819322"}
0005435069856	67ED04	3124 982034	ANDREY FEDOROV	{"email": "andrey-fedorov.101962@postgrespro.ru", "phone": "+70578709533"}
0005435069857	5080F6	6649 458461	VASILIY KOZLOV	{"phone": "+70318877415"}
0005435069858	D7F60A	5278 939394	YULIYA SERGEEVA	{"phone": "+70629629038"}
0005435069859	D7F60A	7543 852707	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr.1979@postgrespro.ru", "phone": "+70295963149"}
0005435069860	A7F66A	8202 100723	ELENA KRASNOVA	{"email": "e-krasnova061972@postgrespro.ru", "phone": "+70448929424"}
0005435069861	A7F66A	5403 901925	LYUBOV ROMANOVA	{"phone": "+70931008898"}
0005435069862	B64D3B	4877 033064	EVGENIY MIKHAYLOV	{"email": "mikhaylov_e1970@postgrespro.ru", "phone": "+70665422611"}
0005435069863	D9886E	6403 903254	VERA SCHERBAKOVA	{"email": "v_scherbakova_051969@postgrespro.ru", "phone": "+70561224483"}
0005435069864	596B27	3399 172163	EKATERINA SEMENOVA	{"phone": "+70681527168"}
0005435069865	E76585	3571 446483	GEORGIY ZAKHAROV	{"phone": "+70249078849"}
0005435069866	63BB07	7525 361979	DARYA PETROVA	{"phone": "+70795773717"}
0005435069867	63BB07	7361 852927	ANDREY ROMANOV	{"email": "romanov_a-021971@postgrespro.ru", "phone": "+70512761745"}
0005435069868	65FB42	2798 119622	ALEKSEY ABRAMOV	{"email": "abramov.aleksey041974@postgrespro.ru", "phone": "+70793404400"}
0005435069869	EC1AD1	3077 296601	SVETLANA ROMANOVA	{"phone": "+70756106949"}
0005435069870	13599F	7630 419350	VALENTINA CHERNOVA	{"email": "valentina.chernova-1971@postgrespro.ru", "phone": "+70503324468"}
0005435069871	AA6CAD	2407 314138	TAMARA DAVYDOVA	{"phone": "+70709761545"}
0005435069872	C68C81	8214 259069	VIKTORIYA NAZAROVA	{"email": "nazarova.viktoriya.13121960@postgrespro.ru", "phone": "+70876102730"}
0005435069873	850EC6	1873 955965	VYACHESLAV NAUMOV	{"phone": "+70947383433"}
0005435069874	B4CEFF	8341 690109	NIKOLAY NAUMOV	{"email": "nikolay_naumov-1975@postgrespro.ru", "phone": "+70432688606"}
0005435069875	CE543B	5482 115524	VLADIMIR KONOVALOV	{"phone": "+70444191681"}
0005435069876	CE543B	1376 547897	OLGA DAVYDOVA	{"email": "olga_davydova011980@postgrespro.ru", "phone": "+70533851193"}
0005435069877	D52F5E	6168 494275	DMITRIY ZAKHAROV	{"email": "d.zakharov.1973@postgrespro.ru", "phone": "+70231278606"}
0005435069878	A5968B	4479 698363	KRISTINA ARKHIPOVA	{"phone": "+70566760723"}
0005435069879	00BC4F	4684 207559	VLADIMIR VLASOV	{"phone": "+70217334744"}
0005435069880	505526	8777 068544	ELENA KUZNECOVA	{"phone": "+70050572285"}
0005435069881	505526	9743 498723	RASIM MAKSIMOV	{"email": "r_maksimov_071967@postgrespro.ru", "phone": "+70055729161"}
0005435069882	09790C	6732 073375	TATYANA KARPOVA	{"phone": "+70602734996"}
0005435069883	91FE2C	3575 981321	EKATERINA BARANOVA	{"phone": "+70994219218"}
0005435069884	91FE2C	2936 654546	GALINA BELOVA	{"phone": "+70278285503"}
0005435069885	15C1FD	4152 552963	STANISLAV SHEVCHENKO	{"phone": "+70876997768"}
0005435069886	15C1FD	0796 462655	SERGEY BORISOV	{"phone": "+70108378975"}
0005435069887	15C1FD	5772 675730	VIKTOR NIKOLAEV	{"email": "nikolaev_v041970@postgrespro.ru", "phone": "+70387992800"}
0005435069888	4C4C1C	4619 974063	ELIZAVETA ORLOVA	{"phone": "+70067758564"}
0005435069889	4C4C1C	6603 128727	RAISA DENISOVA	{"phone": "+70277132791"}
0005435069890	8394BA	6891 105041	TATYANA MARTYNOVA	{"email": "martynova.t.01021970@postgrespro.ru", "phone": "+70481965837"}
0005435069891	8394BA	7039 893513	ANDREY FEDOROV	{"phone": "+70436790716"}
0005435069892	FC7802	8104 859468	ALEKSANDR MAKSIMOV	{"email": "amaksimov-041957@postgrespro.ru", "phone": "+70823151350"}
0005435069893	FC7802	0159 828838	MAKSIM BELOV	{"email": "mbelov_071977@postgrespro.ru", "phone": "+70201703770"}
0005435069894	8AE916	8507 301270	ALEKSANDR IVANOV	{"email": "ivanov-a-101975@postgrespro.ru", "phone": "+70997803030"}
0005435069895	8AE916	4914 188743	ALEKSANDR ILIN	{"email": "aleksandr-ilin_061978@postgrespro.ru", "phone": "+70171924515"}
0005435069896	B0C3B0	3183 793910	GALINA TITOVA	{"phone": "+70014648332"}
0005435069897	C3DD0F	6811 598597	NINA ROMANOVA	{"phone": "+70271905842"}
0005435069898	CEABAF	7835 893248	ALEKSANDR FOMIN	{"phone": "+70434489485"}
0005435070178	FF6B98	6760 906059	IRINA NIKIFOROVA	{"phone": "+70838790470"}
0005435069899	141C50	0967 257232	NATALYA GERASIMOVA	{"email": "gerasimovanatalya30031963@postgrespro.ru", "phone": "+70591343406"}
0005435069900	AA7CCB	4964 722426	TAMARA SOKOLOVA	{"email": "sokolova_t121971@postgrespro.ru", "phone": "+70538325347"}
0005435069901	AA7CCB	6596 728264	POLINA KULIKOVA	{"email": "kulikova-polina-021975@postgrespro.ru", "phone": "+70472419425"}
0005435069902	AA7CCB	7780 753302	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a_1967@postgrespro.ru", "phone": "+70484690515"}
0005435069903	FE6401	0693 462314	NELYA EGOROVA	{"email": "egorovanelya.14051964@postgrespro.ru", "phone": "+70804853979"}
0005435069904	7E213B	1213 120218	SVETLANA SERGEEVA	{"phone": "+70341775779"}
0005435069905	C90B4A	9264 838657	NIKOLAY VOROBEV	{"email": "n.vorobev.01121966@postgrespro.ru", "phone": "+70433444434"}
0005435069906	2D168D	4769 847534	ALEKSEY EGOROV	{"phone": "+70567614752"}
0005435069907	D93827	7141 408482	DENIS KRASNOV	{"email": "krasnov_d.23061971@postgrespro.ru", "phone": "+70567863475"}
0005435069908	8777A7	9504 225146	NELLI DMITRIEVA	{"email": "nelli_dmitrieva031977@postgrespro.ru", "phone": "+70430532523"}
0005435069909	8777A7	3908 847460	DMITRIY NIKITIN	{"email": "nikitin_d.081973@postgrespro.ru", "phone": "+70131844044"}
0005435069910	9F82BF	8777 741343	NINA EGOROVA	{"phone": "+70798828075"}
0005435069911	9F82BF	0677 350910	ROMAN VOLKOV	{"email": "volkov-roman_19101978@postgrespro.ru", "phone": "+70521779728"}
0005435069912	6F0D90	4036 157135	LUIZA ZAYCEVA	{"email": "zayceva_luiza_011975@postgrespro.ru", "phone": "+70821422645"}
0005435069913	6F0D90	1238 959965	EKATERINA KUZNECOVA	{"email": "e_kuznecova.12051970@postgrespro.ru", "phone": "+70890069082"}
0005435069914	57DEFC	6439 596336	IGOR SOROKIN	{"email": "isorokin1966@postgrespro.ru", "phone": "+70191391582"}
0005435069915	E8E700	7874 758138	VALENTIN KOZLOV	{"email": "kozlov.valentin.111982@postgrespro.ru", "phone": "+70630043752"}
0005435069916	F6689D	6936 907577	MARIYA AKIMOVA	{"phone": "+70612200123"}
0005435069917	81AB3B	1977 256142	NADEZHDA FADEEVA	{"phone": "+70471368863"}
0005435069918	81AB3B	1761 800606	ANTON FOMIN	{"email": "a-fomin.21111968@postgrespro.ru", "phone": "+70217629743"}
0005435069919	CF457B	4799 303993	VLADIMIR ILIN	{"email": "ilin.v_13021983@postgrespro.ru", "phone": "+70122687711"}
0005435069920	6DD31D	8947 444297	ALENA KOVALEVA	{"email": "alena.kovaleva_01041977@postgrespro.ru", "phone": "+70263656681"}
0005435069921	BFB440	3847 376573	TATYANA NIKOLAEVA	{"phone": "+70597027494"}
0005435069922	F3F629	7598 702588	OLESYA MIRONOVA	{"email": "mironovao1969@postgrespro.ru", "phone": "+70332450922"}
0005435069923	60CB59	9264 858808	TATYANA SOROKINA	{"email": "tatyanasorokina031977@postgrespro.ru", "phone": "+70566812859"}
0005435069924	F575E5	6368 496134	MARGARITA GUSEVA	{"email": "guseva_m1968@postgrespro.ru", "phone": "+70734456406"}
0005435069925	F575E5	5105 775664	MARINA EGOROVA	{"email": "m_egorova.1975@postgrespro.ru", "phone": "+70848954963"}
0005435069926	A3D52A	0275 958898	PAVEL ROMANOV	{"email": "pavel_romanov1972@postgrespro.ru", "phone": "+70320234226"}
0005435069927	EFB405	3452 806244	ZINAIDA ILINA	{"email": "zinaida_ilina1972@postgrespro.ru", "phone": "+70290166429"}
0005435069928	EFB405	6625 612929	ELENA MIKHAYLOVA	{"email": "elenamikhaylova_23101968@postgrespro.ru", "phone": "+70582177259"}
0005435069929	EFB405	4916 896635	TATYANA OSIPOVA	{"email": "t-osipova-111968@postgrespro.ru", "phone": "+70552759496"}
0005435069930	0FE840	5865 765346	ALEKSANDR EGOROV	{"phone": "+70851417960"}
0005435069931	E2D305	5355 817928	NIKOLAY KONOVALOV	{"phone": "+70322211429"}
0005435069932	D05F70	2625 077653	SVETLANA BORISOVA	{"phone": "+70412794684"}
0005435069933	5B5070	4761 448272	ANASTASIYA ABRAMOVA	{"email": "abramova.anastasiya-30111976@postgrespro.ru", "phone": "+70862509698"}
0005435069934	2C4A59	8006 011139	NIKOLAY ALEKSANDROV	{"phone": "+70635502214"}
0005435069935	3296EB	8415 940501	NINA NIKOLAEVA	{"email": "nikolaeva_n-1978@postgrespro.ru", "phone": "+70924658088"}
0005435069936	3296EB	8596 256734	RUSLAN SOLOVEV	{"email": "solovevruslan.29041975@postgrespro.ru", "phone": "+70695072553"}
0005435069937	BFF9D2	6833 614863	ALBINA MOROZOVA	{"email": "a-morozova-041978@postgrespro.ru", "phone": "+70859129583"}
0005435069938	652E93	3574 139782	EKATERINA ANISIMOVA	{"email": "ekaterina.anisimova1966@postgrespro.ru", "phone": "+70963639315"}
0005435069939	8C7572	3891 456113	LYUBOV OSIPOVA	{"email": "osipova.lyubov.101976@postgrespro.ru", "phone": "+70772218563"}
0005435069940	8C7572	6617 183227	RUSLAN ZAYCEV	{"phone": "+70884708550"}
0005435069941	62E293	5748 757334	VLADIMIR GERASIMOV	{"phone": "+70287715789"}
0005435069942	C8A25A	7119 376429	GALINA GRISHINA	{"phone": "+70764015611"}
0005435069943	C8A25A	9733 252673	OKSANA ANTONOVA	{"email": "antonova_o_071964@postgrespro.ru", "phone": "+70591207291"}
0005435069944	626B02	7562 840976	LIDIYA ALEKSEEVA	{"email": "lalekseeva_1973@postgrespro.ru", "phone": "+70841078384"}
0005435069945	626B02	7145 848861	SVETLANA SOROKINA	{"email": "s.sorokina011972@postgrespro.ru", "phone": "+70873108817"}
0005435069946	E1DF5B	7033 333343	ANTON MIKHAYLOV	{"phone": "+70570075834"}
0005435069947	E1DF5B	2335 813078	MARIYA MAKAROVA	{"email": "m_makarova.111977@postgrespro.ru", "phone": "+70442385911"}
0005435069948	C36993	2176 988538	RAISA RYABOVA	{"email": "ryabova.raisa-1976@postgrespro.ru", "phone": "+70391634614"}
0005435069949	15D6A9	7829 921267	NIKITA IVANOV	{"phone": "+70964385246"}
0005435069950	15D6A9	2032 476714	IREK FEDOTOV	{"email": "fedotovirek.011966@postgrespro.ru", "phone": "+70360901707"}
0005435069951	15D6A9	3001 410857	VASILIY SEMENOV	{"phone": "+70685889912"}
0005435069952	15D6A9	4855 306137	ULYANA ORLOVA	{"email": "orlova.u091992@postgrespro.ru", "phone": "+70495245165"}
0005435069953	A161BB	1341 429141	LYUBOV MAKSIMOVA	{"phone": "+70875500114"}
0005435069954	A161BB	5275 195124	ILYA MELNIKOV	{"email": "melnikov-ilya-04101976@postgrespro.ru", "phone": "+70904296392"}
0005435069955	549992	4436 023950	EKATERINA RODIONOVA	{"email": "rodionova.e.091972@postgrespro.ru", "phone": "+70540308846"}
0005435069956	09E9C8	7680 083376	ANATOLIY POPOV	{"email": "popov.a-21081975@postgrespro.ru", "phone": "+70005176866"}
0005435069957	C5728F	0232 233590	IVAN POPOV	{"phone": "+70439842833"}
0005435069958	C5728F	2161 693053	SERGEY KISELEV	{"email": "kiselev_sergey.061971@postgrespro.ru", "phone": "+70177264721"}
0005435069959	244215	6732 258519	ALEKSANDR MOROZOV	{"email": "amorozov-28031981@postgrespro.ru", "phone": "+70693517411"}
0005435069960	7CCBD9	9772 622373	ALINA SCHERBAKOVA	{"email": "alina-scherbakova-16021971@postgrespro.ru", "phone": "+70403089566"}
0005435069961	62BD5E	4185 417222	TATYANA MALYSHEVA	{"email": "tatyanamalysheva-1974@postgrespro.ru", "phone": "+70746907511"}
0005435069962	62BD5E	7040 708416	NATALYA ZHURAVLEVA	{"email": "zhuravleva.n10031970@postgrespro.ru", "phone": "+70787730794"}
0005435069963	CF6FC0	5567 157274	EVGENIY KAZAKOV	{"email": "e_kazakov-08021964@postgrespro.ru", "phone": "+70165030877"}
0005435069964	CF6FC0	8633 933947	DMITRIY BARANOV	{"email": "dmitriy_baranov.1966@postgrespro.ru", "phone": "+70224163520"}
0005435069965	F37616	1199 392371	OLGA ALEKSEEVA	{"email": "oalekseeva_31071966@postgrespro.ru", "phone": "+70830282247"}
0005435069966	F37616	4825 051069	IRINA MALYSHEVA	{"email": "malysheva_i.071979@postgrespro.ru", "phone": "+70188935103"}
0005435069967	89BFCE	6965 379273	EVGENIY SMIRNOV	{"email": "e_smirnov-09111973@postgrespro.ru", "phone": "+70253703209"}
0005435069968	89BFCE	0287 598524	LYUDMILA KUDRYASHOVA	{"phone": "+70117468260"}
0005435069969	89BFCE	7202 398807	LYUBOV PETROVA	{"email": "petrova.lyubov.1975@postgrespro.ru", "phone": "+70754148055"}
0005435069970	28EEB1	2444 342820	VLADIMIR KOZLOV	{"email": "vladimir.kozlov-031980@postgrespro.ru", "phone": "+70292279634"}
0005435069971	28EEB1	0415 893565	ANNA NOVIKOVA	{"phone": "+70172654247"}
0005435069972	28EEB1	1594 107193	LYUBOV GUSEVA	{"phone": "+70330394843"}
0005435069973	962C21	1397 191461	VLADISLAV ANDREEV	{"phone": "+70137084857"}
0005435069974	FD52E0	5215 478968	RAFAEL FROLOV	{"phone": "+70810725079"}
0005435069975	FD52E0	6124 533029	NATALYA TARASOVA	{"phone": "+70209270554"}
0005435069976	E14746	5340 237839	SVETLANA FOMINA	{"email": "svetlana.fomina.071977@postgrespro.ru", "phone": "+70198350905"}
0005435069977	058DB3	5482 618033	SERGEY KOZLOV	{"phone": "+70110431096"}
0005435069978	10CA7A	8899 327612	VLADIMIR SAVELEV	{"email": "vsavelev_18071970@postgrespro.ru", "phone": "+70982788593"}
0005435069979	10CA7A	9841 547111	ZOYA ZAYCEVA	{"phone": "+70601841107"}
0005435069980	B39B50	5783 703002	LYUBOV KOZLOVA	{"email": "lyubov.kozlova-1985@postgrespro.ru", "phone": "+70501295140"}
0005435069981	B39B50	2264 836521	VIKTOR FEDOROV	{"phone": "+70650951966"}
0005435069982	56DF72	5242 922704	VALERIY KUZNECOV	{"email": "v-kuznecov_1981@postgrespro.ru", "phone": "+70214945758"}
0005435069983	E5447B	1303 703674	ALEKSEY KAZAKOV	{"email": "aleksey.kazakov18091984@postgrespro.ru", "phone": "+70808083045"}
0005435069984	40EA05	9331 235808	PAVEL ANTONOV	{"email": "antonov.p-1967@postgrespro.ru", "phone": "+70186616426"}
0005435069985	40EA05	0541 717671	ANASTASIYA RODIONOVA	{"phone": "+70582167226"}
0005435069986	F7D9F4	0511 292532	VIKTOR NOVIKOV	{"email": "viktor_novikov_1988@postgrespro.ru", "phone": "+70712726493"}
0005435069987	EF1B3B	5688 634384	VALENTINA RYABOVA	{"phone": "+70401820714"}
0005435069988	EF1B3B	2207 371223	SERGEY KUZNECOV	{"phone": "+70735755754"}
0005435069989	82B3BB	8579 132266	OLGA VOROBEVA	{"email": "o-vorobeva10061983@postgrespro.ru", "phone": "+70912970262"}
0005435069990	82B3BB	1345 048622	YURIY POPOV	{"phone": "+70233027754"}
0005435069991	0A5C48	9003 624004	OLGA OVCHINNIKOVA	{"email": "ovchinnikova.o1969@postgrespro.ru", "phone": "+70242044444"}
0005435069992	93BEFE	1710 118687	IVAN KUZMIN	{"phone": "+70200680592"}
0005435069993	0FB964	6219 289184	IRINA AFANASEVA	{"email": "afanaseva.i_111964@postgrespro.ru", "phone": "+70133926146"}
0005435069994	0FB964	4515 618399	SERGEY KUZMIN	{"email": "kuzminsergey_1969@postgrespro.ru", "phone": "+70697911935"}
0005435069995	A2A95E	8173 145355	TATYANA GORBUNOVA	{"email": "tatyana-gorbunova.03111970@postgrespro.ru", "phone": "+70520782773"}
0005435069996	79E1F4	6493 364964	SVETLANA PAVLOVA	{"phone": "+70913854988"}
0005435069997	F94CF5	7008 009170	VLADIMIR SEMENOV	{"email": "vladimirsemenov-061971@postgrespro.ru", "phone": "+70589672188"}
0005435069998	422A49	7970 265086	ELENA ANISIMOVA	{"phone": "+70401343275"}
0005435069999	3FD303	7856 707449	ALEKSANDR MARTYNOV	{"phone": "+70957171827"}
0005435070000	992EE3	3341 013378	OKSANA MARTYNOVA	{"phone": "+70138794167"}
0005435070001	8BDD76	0475 445630	EKATERINA VOLKOVA	{"email": "volkovae_061971@postgrespro.ru", "phone": "+70392801960"}
0005435070002	8BDD76	8151 099945	NINA TIKHONOVA	{"phone": "+70782022504"}
0005435070003	07BF26	2003 408604	IRINA KUZMINA	{"phone": "+70629434071"}
0005435070004	C17835	1669 415706	ALEKSANDR ANTONOV	{"email": "aleksandr_antonov21021969@postgrespro.ru", "phone": "+70645925448"}
0005435070005	C17835	4274 280369	MAKSIM ORLOV	{"email": "orlov-maksim_1969@postgrespro.ru", "phone": "+70026788075"}
0005435070006	E7A33A	3616 356309	IVAN SEMENOV	{"phone": "+70180755852"}
0005435070007	E1B86C	5838 879638	MARINA ANTONOVA	{"email": "marina.antonova_1977@postgrespro.ru", "phone": "+70082316738"}
0005435070008	85EA8F	4177 182630	ELENA SOROKINA	{"email": "sorokina.e21061970@postgrespro.ru", "phone": "+70415681583"}
0005435070009	1CBEC9	9267 307093	NADEZHDA YUDINA	{"email": "nadezhda.yudina.05031975@postgrespro.ru", "phone": "+70720303290"}
0005435070010	398FF7	7161 685486	IRINA BELOVA	{"email": "belova-i12061970@postgrespro.ru", "phone": "+70680634820"}
0005435070011	398FF7	2442 258817	NINA LEBEDEVA	{"phone": "+70331768439"}
0005435070012	6456F7	2430 368090	VALENTINA POLYAKOVA	{"phone": "+70248099217"}
0005435070013	1BEB1E	5001 568135	VIKTOR ANDREEV	{"email": "viktorandreev-1969@postgrespro.ru", "phone": "+70765808089"}
0005435070014	7918FF	7957 704283	GALINA BORISOVA	{"email": "borisova-galina.021970@postgrespro.ru", "phone": "+70645718953"}
0005435070015	AFCBF6	9835 571567	GALINA ILINA	{"email": "ilina_galina_12021972@postgrespro.ru", "phone": "+70404424782"}
0005435070016	78D7DF	4439 610709	EKATERINA MIRONOVA	{"phone": "+70474076014"}
0005435070017	D1AA1F	1994 941903	KONSTANTIN KULIKOV	{"phone": "+70932595557"}
0005435070018	D1AA1F	8705 866284	GALINA POPOVA	{"email": "g.popova.081982@postgrespro.ru", "phone": "+70876052644"}
0005435070019	D1AA1F	8759 530725	NINA STEPANOVA	{"phone": "+70022282827"}
0005435070020	083B64	7537 826550	ANATOLIY OSIPOV	{"email": "osipov.a-091979@postgrespro.ru", "phone": "+70500423092"}
0005435070021	083B64	6597 262132	EVGENIYA LAZAREVA	{"email": "lazareva-evgeniya-081975@postgrespro.ru", "phone": "+70633777206"}
0005435070022	A985E1	3440 601115	OLGA KOZLOVA	{"email": "kozlova.olga_081967@postgrespro.ru", "phone": "+70029851232"}
0005435070023	4F88EC	3894 872652	VALENTIN ILIN	{"email": "ilinv1976@postgrespro.ru", "phone": "+70108793595"}
0005435070024	4F88EC	3633 770438	VLADIMIR SEMENOV	{"phone": "+70600858452"}
0005435070025	CA5705	9887 031355	NATALIYA MAKAROVA	{"email": "nataliya_makarova-051971@postgrespro.ru", "phone": "+70709987590"}
0005435070026	EA861C	4341 517080	MARAT ZAKHAROV	{"email": "zakharov-m19121967@postgrespro.ru", "phone": "+70438281032"}
0005435070027	EA861C	5566 724089	SERGEY ZAYCEV	{"email": "zaycevs-1976@postgrespro.ru", "phone": "+70628095156"}
0005435070028	000BD8	6156 020148	ELIZAVETA AKIMOVA	{"email": "eakimova-051973@postgrespro.ru", "phone": "+70826096532"}
0005435070029	000BD8	5679 062007	ALEKSANDR VASILEV	{"phone": "+70384923596"}
0005435070030	F9D283	9448 011162	ANASTASIYA ISAEVA	{"email": "isaevaanastasiya_30111979@postgrespro.ru", "phone": "+70017571868"}
0005435070031	F9D283	2943 456879	NADEZHDA KOROLEVA	{"phone": "+70610020010"}
0005435070032	6885DB	7007 025596	DARYA VLASOVA	{"email": "vlasova.darya.021958@postgrespro.ru", "phone": "+70743323589"}
0005435070033	762865	2379 856310	TIMUR GORBUNOV	{"phone": "+70467270565"}
0005435070034	43A98E	9510 990943	ELENA POPOVA	{"email": "popova-e_02111977@postgrespro.ru", "phone": "+70546777446"}
0005435070035	203C94	2115 015011	VLADIMIR KOROLEV	{"phone": "+70724219893"}
0005435070036	203C94	7916 418249	GENNADIY GAVRILOV	{"phone": "+70741390972"}
0005435070037	914971	2287 677967	ANNA NOVIKOVA	{"phone": "+70272861407"}
0005435070038	6ACF2A	5000 463483	EVGENIYA MELNIKOVA	{"phone": "+70210794144"}
0005435070039	B23AFB	4717 265080	OLGA RYABOVA	{"email": "ryabovaolga.01091969@postgrespro.ru", "phone": "+70176334622"}
0005435070040	735549	2145 218126	ARTEM MAKAROV	{"phone": "+70020150859"}
0005435070041	981E78	2051 145485	TAMARA MAKAROVA	{"phone": "+70108688159"}
0005435070042	981E78	1834 697695	VALENTINA ZAYCEVA	{"email": "zayceva_valentina-05081975@postgrespro.ru", "phone": "+70765547335"}
0005435070164	B1C8A2	8294 094170	IVAN IVANOV	{"phone": "+70549067452"}
0005435070043	4041F6	9304 381110	VLADISLAV KOZLOV	{"email": "v-kozlov071976@postgrespro.ru", "phone": "+70673769790"}
0005435070044	4041F6	6879 270762	ELENA EFIMOVA	{"phone": "+70105896011"}
0005435070045	863BB1	5160 201705	VLADISLAV VASILEV	{"email": "vladislav-vasilev_1977@postgrespro.ru", "phone": "+70404514082"}
0005435070046	1876A9	3385 646986	KLIM KULIKOV	{"email": "klim.kulikov_061979@postgrespro.ru", "phone": "+70469227434"}
0005435070047	2BA480	0482 831202	NADEZHDA SOKOLOVA	{"phone": "+70318307185"}
0005435070048	8AF3E1	8460 136306	NIKOLAY MIRONOV	{"email": "mironov.n.1968@postgrespro.ru", "phone": "+70153074989"}
0005435070049	5024C6	4488 495242	VIKTOR FEDOTOV	{"email": "fedotov_viktor-1971@postgrespro.ru", "phone": "+70020615728"}
0005435070050	37E09D	7445 983512	DENIS DENISOV	{"phone": "+70134177148"}
0005435070051	37E09D	5710 400065	TAMARA SERGEEVA	{"email": "tamarasergeeva-13081978@postgrespro.ru", "phone": "+70403600865"}
0005435070052	6E4725	9486 141926	VLADIMIR FOMIN	{"phone": "+70360975223"}
0005435070053	6E4725	4111 483388	VADIM KONOVALOV	{"email": "v-konovalov_15061971@postgrespro.ru", "phone": "+70321840404"}
0005435070054	01E257	3615 348561	DMITRIY ABRAMOV	{"email": "abramovdmitriy.26071981@postgrespro.ru", "phone": "+70620420233"}
0005435070055	01E257	1931 812129	ANFISA EFREMOVA	{"email": "anfisa_efremova16061978@postgrespro.ru", "phone": "+70403434600"}
0005435070056	81475B	8540 370784	ALEKSEY PAVLOV	{"email": "pavlovaleksey-1981@postgrespro.ru", "phone": "+70003243337"}
0005435070057	81475B	4741 655374	EKATERINA SOKOLOVA	{"email": "sokolova_e_101974@postgrespro.ru", "phone": "+70941536333"}
0005435070058	07D27D	6607 424244	LYUBOV LUKYANOVA	{"email": "lyubov.lukyanova.121972@postgrespro.ru", "phone": "+70017410325"}
0005435070059	5E0873	9092 300545	VALENTINA SCHERBAKOVA	{"phone": "+70652361205"}
0005435070060	5E0873	2879 766898	ALEKSANDR KOZLOV	{"email": "kozlov.aleksandr_03011976@postgrespro.ru", "phone": "+70665938933"}
0005435070061	FA8ECE	0126 427801	DANIL MOROZOV	{"phone": "+70922137411"}
0005435070062	9399B2	0362 246073	VIKTOR MIRONOV	{"phone": "+70653041279"}
0005435070063	9399B2	5533 619382	MARIYA VASILEVA	{"phone": "+70117916438"}
0005435070064	18CCE5	6009 147333	SERGEY FILIPPOV	{"email": "filippov_s_071979@postgrespro.ru", "phone": "+70067939493"}
0005435070065	18CCE5	6942 731909	EKATERINA OVCHINNIKOVA	{"phone": "+70020344007"}
0005435070066	CFC105	7282 112816	DARYA KUZNECOVA	{"phone": "+70582568386"}
0005435070067	CFC105	4563 984930	ANASTASIYA TARASOVA	{"phone": "+70348193651"}
0005435070068	B370AD	9684 576857	VIKTOR VOROBEV	{"phone": "+70931900728"}
0005435070069	4C92A1	5418 236608	VLADIMIR GORBUNOV	{"email": "vgorbunov.081970@postgrespro.ru", "phone": "+70503588952"}
0005435070070	3B8A32	2737 031541	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy13061992@postgrespro.ru", "phone": "+70120221192"}
0005435070071	957FCD	9513 407096	YURIY MIKHAYLOV	{"email": "yuriy-mikhaylov_03061962@postgrespro.ru", "phone": "+70869792791"}
0005435070072	4D7F6A	8232 782248	TAMARA SEMENOVA	{"phone": "+70504136685"}
0005435070073	322ECE	5884 541447	ALISA VOLKOVA	{"phone": "+70969635228"}
0005435070074	322ECE	4559 323980	ALINA NIKOLAEVA	{"email": "nikolaeva.alina_22041974@postgrespro.ru", "phone": "+70625554413"}
0005435070075	E67149	8647 463651	MIKHAIL ROMANOV	{"email": "mikhailromanov.14011979@postgrespro.ru", "phone": "+70047765193"}
0005435070076	E572D4	0931 642779	GALINA BELOVA	{"email": "gbelova_081976@postgrespro.ru", "phone": "+70182672380"}
0005435070077	B8A118	3386 983183	PAVEL SERGEEV	{"email": "psergeev.1974@postgrespro.ru", "phone": "+70113381889"}
0005435070078	B8A118	0824 879809	LYUDMILA NIKOLAEVA	{"email": "nikolaeva.lyudmila_02041965@postgrespro.ru", "phone": "+70787525991"}
0005435070079	A62F11	4822 126300	ELIZAVETA LUKYANOVA	{"phone": "+70782905901"}
0005435070080	A62F11	4222 985267	VIKTOR VOROBEV	{"email": "vorobev_viktor-1966@postgrespro.ru", "phone": "+70737035820"}
0005435070081	23EA05	0178 559652	TAMARA KOLESNIKOVA	{"email": "kolesnikovat101961@postgrespro.ru", "phone": "+70339133697"}
0005435070082	5FB8F7	2644 412018	MARIANNA MEDVEDEVA	{"phone": "+70144312764"}
0005435070083	5B47A6	1386 145540	ALEKSEY VASILEV	{"phone": "+70989235278"}
0005435070084	BC57A5	1636 897733	ZINAIDA YAKOVLEVA	{"phone": "+70966382209"}
0005435070085	C9C80C	8914 511685	TATYANA DAVYDOVA	{"phone": "+70842500114"}
0005435070086	18F3E6	6286 155562	VLADISLAV CHERNOV	{"email": "vladislav.chernov.021968@postgrespro.ru", "phone": "+70893154859"}
0005435070087	856075	3211 589934	ROMAN IVANOV	{"phone": "+70178889483"}
0005435070088	FA9577	4450 385243	SVETLANA KUZNECOVA	{"phone": "+70410174398"}
0005435070089	FA9577	4658 549093	ELENA SAVELEVA	{"phone": "+70413824058"}
0005435070090	5844A5	0930 347283	EVGENIY SOROKIN	{"email": "sorokinevgeniy-101985@postgrespro.ru", "phone": "+70478579862"}
0005435070091	5844A5	4002 989785	LYUDMILA ZAKHAROVA	{"phone": "+70550719577"}
0005435070092	7EA96B	3040 778440	ALEKSEY SEMENOV	{"email": "semenov_aleksey29091974@postgrespro.ru", "phone": "+70273167116"}
0005435070093	7EA96B	3001 122573	GALINA MATVEEVA	{"email": "matveeva.g04061978@postgrespro.ru", "phone": "+70170269756"}
0005435070094	0D190B	5771 430031	MATVEY MOROZOV	{"email": "morozovmatvey-111979@postgrespro.ru", "phone": "+70292240393"}
0005435070095	0D190B	6010 606516	TAMARA PETROVA	{"phone": "+70150553104"}
0005435070096	DCB9C8	4630 020776	OLGA MAKAROVA	{"phone": "+70590897972"}
0005435070097	DCB9C8	8783 961693	TAMARA SOROKINA	{"email": "sorokina.tamara-081963@postgrespro.ru", "phone": "+70109058435"}
0005435070098	3C6211	4115 841349	EVGENIY GRIGOREV	{"phone": "+70543428005"}
0005435070099	29587C	5122 783121	VALENTINA ILINA	{"email": "vilina_061971@postgrespro.ru", "phone": "+70431980666"}
0005435070100	ED85BE	8134 735554	ALEKSANDR ZAKHAROV	{"phone": "+70984731896"}
0005435070101	ED85BE	5140 005759	LYUDMILA SMIRNOVA	{"phone": "+70558619071"}
0005435070102	EA6680	5994 816388	EVGENIYA NOVIKOVA	{"email": "novikova_e-081973@postgrespro.ru", "phone": "+70965743744"}
0005435070103	387F72	5007 960441	NIKOLAY KUZNECOV	{"phone": "+70207790263"}
0005435070104	387F72	3769 475207	IRINA MARTYNOVA	{"phone": "+70857352535"}
0005435070105	698EE2	0239 819084	YAROSLAV VLASOV	{"phone": "+70171649349"}
0005435070106	942D85	6351 755195	EKATERINA PAVLOVA	{"phone": "+70256868662"}
0005435070107	942D85	5105 685454	VERA VOLKOVA	{"email": "volkova_v07081975@postgrespro.ru", "phone": "+70301604030"}
0005435070108	96419F	9227 922007	SERGEY VOLKOV	{"phone": "+70605956020"}
0005435070109	8EC49A	6857 824783	IVAN TARASOV	{"phone": "+70045316926"}
0005435070110	8EC49A	2773 867331	YURIY NOVIKOV	{"email": "novikovyuriy-081973@postgrespro.ru", "phone": "+70161920314"}
0005435070111	568934	7437 404842	MIKHAIL FILIPPOV	{"phone": "+70023720379"}
0005435070112	549392	4186 129022	VALERIYA KUZNECOVA	{"email": "kuznecova_v-20011980@postgrespro.ru", "phone": "+70586412039"}
0005435070113	549392	6115 938294	VALENTINA LOGINOVA	{"email": "loginova-v.02051971@postgrespro.ru", "phone": "+70320140919"}
0005435070114	6FF6DD	7213 812951	EKATERINA EFIMOVA	{"phone": "+70390760471"}
0005435070115	6FF6DD	6129 698661	ILYA KARPOV	{"phone": "+70206040847"}
0005435070116	CF2B4C	9275 649333	ALEKSANDRA IVANOVA	{"email": "a-ivanova01091975@postgrespro.ru", "phone": "+70822101087"}
0005435070117	445C00	3829 284384	IRINA KUZNECOVA	{"phone": "+70671902860"}
0005435070118	445C00	2112 712801	MARAT FOMIN	{"phone": "+70347172113"}
0005435070119	F5769A	1508 474159	SOFYA KULIKOVA	{"email": "kulikova_sofya091975@postgrespro.ru", "phone": "+70089550733"}
0005435070120	F5769A	1546 568795	KONSTANTIN ORLOV	{"email": "korlov_1971@postgrespro.ru", "phone": "+70381311708"}
0005435070121	6C46A7	0921 610653	ELENA KUDRYASHOVA	{"email": "e.kudryashova.091971@postgrespro.ru", "phone": "+70459913443"}
0005435070122	6C46A7	5820 048892	ALEKSANDR NAZAROV	{"phone": "+70893065821"}
0005435070123	6C23EC	8793 957242	DMITRIY IVANOV	{"email": "ivanovd30011971@postgrespro.ru", "phone": "+70826732721"}
0005435070124	6C23EC	9389 562820	ALEKSEY KAZAKOV	{"phone": "+70519946377"}
0005435070125	E79492	0927 035446	KRISTINA LEBEDEVA	{"phone": "+70078109064"}
0005435070126	E79492	8095 627178	MARINA LOGINOVA	{"email": "marinaloginova1982@postgrespro.ru", "phone": "+70721553366"}
0005435070127	AF2A37	0253 376221	OLEG PETROV	{"email": "o-petrov29121974@postgrespro.ru", "phone": "+70165932591"}
0005435070128	DA0D30	9627 584732	ALEKSANDR PAVLOV	{"phone": "+70776381512"}
0005435070129	DA0D30	9367 092327	DINARA CHERNOVA	{"phone": "+70178784278"}
0005435070130	65BBA5	1003 185327	SERGEY FROLOV	{"email": "sergeyfrolov_15011957@postgrespro.ru", "phone": "+70476859294"}
0005435070131	EA7A7A	7068 046886	ALEKSEY FEDOROV	{"phone": "+70794422509"}
0005435070132	C02DB2	5668 368027	ANTONINA MATVEEVA	{"email": "matveeva.antonina.111972@postgrespro.ru", "phone": "+70560425155"}
0005435070133	0E95E9	1356 434935	TATYANA AKIMOVA	{"phone": "+70907202239"}
0005435070134	A2123F	4986 683263	YURIY GUSEV	{"email": "yuriy-gusev061961@postgrespro.ru", "phone": "+70337482908"}
0005435070135	A2123F	4021 222413	ALEKSEY SOROKIN	{"phone": "+70508013542"}
0005435070136	A2123F	8474 533206	ANTON TIKHONOV	{"email": "tikhonov-anton01041977@postgrespro.ru", "phone": "+70849123601"}
0005435070137	BF7711	1903 838679	VASILIY CHERNOV	{"email": "chernov_vasiliy.1961@postgrespro.ru", "phone": "+70337917300"}
0005435070138	BF7711	0606 581027	VIKTOR ZAYCEV	{"phone": "+70703437946"}
0005435070139	9C2A1C	4160 317277	IRINA EFIMOVA	{"email": "efimova.irina.1966@postgrespro.ru", "phone": "+70521323727"}
0005435070140	595CFB	2174 495906	OLGA FROLOVA	{"phone": "+70966590287"}
0005435070141	54C4C8	6228 668469	ANDREY DMITRIEV	{"phone": "+70415996348"}
0005435070142	F21E3F	1224 016771	VALERIYA TARASOVA	{"phone": "+70703704836"}
0005435070143	7B43CE	7881 378213	ANNA KOVALEVA	{"phone": "+70165094669"}
0005435070144	8586E5	1712 349009	ALEKSANDR SOROKIN	{"email": "sorokin-a071962@postgrespro.ru", "phone": "+70105794853"}
0005435070145	86C2B3	7901 836674	GALINA RODIONOVA	{"email": "rodionovagalina_011965@postgrespro.ru", "phone": "+70700711304"}
0005435070146	54F62F	4030 540234	RUSTAM ZAKHAROV	{"email": "zakharovrustam_1971@postgrespro.ru", "phone": "+70361537300"}
0005435070147	385409	5448 820490	VALENTIN MELNIKOV	{"phone": "+70038170334"}
0005435070148	9C147D	2919 918974	YULIYA GORBUNOVA	{"email": "gorbunova.y_14111968@postgrespro.ru", "phone": "+70059364675"}
0005435070149	51B9B4	6474 593553	ANNA BELOVA	{"phone": "+70112970912"}
0005435070150	AAC936	3020 693069	VALERIYA POPOVA	{"email": "valeriya.popova_101969@postgrespro.ru", "phone": "+70263967535"}
0005435070151	AAC936	8895 097241	YURIY NAUMOV	{"phone": "+70812183466"}
0005435070152	31B627	9490 506693	ANGELINA NIKOLAEVA	{"email": "angelina-nikolaeva_1974@postgrespro.ru", "phone": "+70355395179"}
0005435070153	27165A	0002 172242	OLGA FEDOROVA	{"phone": "+70555291695"}
0005435070154	27165A	0659 863077	ANATOLIY BONDARENKO	{"email": "bondarenko.anatoliy.111972@postgrespro.ru", "phone": "+70359454727"}
0005435070155	27165A	1325 283885	ARKADIY VLASOV	{"phone": "+70115636071"}
0005435070156	B30D24	6711 773594	DANIL MIRONOV	{"phone": "+70773806800"}
0005435070157	4F9E21	6308 992986	SERGEY IVANOV	{"phone": "+70337840106"}
0005435070158	0F29EC	7527 645988	VERA MARTYNOVA	{"email": "martynovavera-10121979@postgrespro.ru", "phone": "+70514064775"}
0005435070159	A2EB9A	8193 741509	GULSINA ROMANOVA	{"phone": "+70007901029"}
0005435070160	DDDBC8	2245 689429	NADEZHDA MALYSHEVA	{"phone": "+70301797107"}
0005435070161	28B464	6412 537508	ANTON VASILEV	{"email": "vasileva.101986@postgrespro.ru", "phone": "+70574967719"}
0005435070162	D4E4D7	5337 732791	SEMEN BELOV	{"phone": "+70308734830"}
0005435070163	D5CDE2	9333 852020	OLGA FROLOVA	{"phone": "+70972418932"}
0005435070165	6907FC	2704 319020	LYUBOV KULIKOVA	{"email": "lyubovkulikova.031960@postgrespro.ru", "phone": "+70786654741"}
0005435070166	058E88	3300 306298	DANIIL POPOV	{"email": "popovdaniil1965@postgrespro.ru", "phone": "+70408855098"}
0005435070167	6FB17C	8466 945631	NATALIYA NESTEROVA	{"email": "nesterova_n1966@postgrespro.ru", "phone": "+70679420103"}
0005435070168	6FB17C	8429 907942	ALEKSANDR KUZNECOV	{"phone": "+70573281297"}
0005435070169	172207	1398 702980	LYUBOV GAVRILOVA	{"phone": "+70421960947"}
0005435070170	BD9A9C	8566 739551	ZINAIDA AFANASEVA	{"email": "afanaseva_zinaida24081965@postgrespro.ru", "phone": "+70554125474"}
0005435070171	38EA8A	8290 046077	VLADIMIR FROLOV	{"phone": "+70569031350"}
0005435070172	BF1BB9	5520 114564	TAMARA BOGDANOVA	{"email": "t-bogdanova-1973@postgrespro.ru", "phone": "+70816092027"}
0005435070173	78667F	0719 614081	OKSANA SAVELEVA	{"phone": "+70681455061"}
0005435070174	78667F	6945 537432	EVGENIY AFANASEV	{"phone": "+70076795104"}
0005435070175	95C850	0286 552185	LYUBOV ORLOVA	{"email": "orlova-l.1976@postgrespro.ru", "phone": "+70145431506"}
0005435070176	95C850	8891 336538	VALENTIN KAZAKOV	{"phone": "+70119086806"}
0005435070177	FF6B98	3200 345528	EVGENIY POPOV	{"phone": "+70871132889"}
0005435070179	4A1BC1	1355 366112	ELENA KARPOVA	{"email": "karpova-e-121969@postgrespro.ru", "phone": "+70470451932"}
0005435070180	073F95	3386 061652	DMITRIY VASILEV	{"email": "dmitriyvasilev.21051977@postgrespro.ru", "phone": "+70052487117"}
0005435070181	2B987C	0292 287706	MAKSIM IVANOV	{"phone": "+70158316433"}
0005435070182	8B40E6	5395 187989	OLGA KALININA	{"phone": "+70601362482"}
0005435070183	876F86	2022 683664	VALENTINA GERASIMOVA	{"phone": "+70911075506"}
0005435070184	876F86	6379 777321	MARGARITA KARPOVA	{"email": "m-karpova.1955@postgrespro.ru", "phone": "+70373033886"}
0005435070185	A1980F	2951 577964	YURIY TARASOV	{"phone": "+70477680001"}
0005435070186	178B6B	9653 056565	SALAVAT MEDVEDEV	{"phone": "+70014783655"}
0005435070187	178B6B	5189 122498	VARVARA SMIRNOVA	{"phone": "+70825280532"}
0005435070188	178B6B	1716 951416	YURIY IVANOV	{"phone": "+70793838741"}
0005435070189	CD04D1	8249 881668	GERMAN TIKHONOV	{"phone": "+70910477625"}
0005435070190	CD04D1	2943 889663	KRISTINA BOGDANOVA	{"email": "bogdanova_kristina.091964@postgrespro.ru", "phone": "+70786582770"}
0005435070191	6B4831	0470 163561	YULIYA TITOVA	{"phone": "+70811485793"}
0005435070192	8D58E7	1837 385116	VITALIY DMITRIEV	{"email": "vitaliydmitriev_1973@postgrespro.ru", "phone": "+70724061970"}
0005435070193	8D58E7	2165 800707	ALEKSEY BONDARENKO	{"email": "bondarenkoaleksey.28011983@postgrespro.ru", "phone": "+70817494887"}
0005435070194	8AE619	6477 127847	NADEZHDA POTAPOVA	{"email": "n_potapova-071967@postgrespro.ru", "phone": "+70034977670"}
0005435070195	CD38EF	9169 090341	KIRILL ISAEV	{"email": "isaev_kirill-041981@postgrespro.ru", "phone": "+70879440763"}
0005435070196	CD38EF	6163 002089	SVETLANA POLYAKOVA	{"email": "polyakova.svetlana.28031981@postgrespro.ru", "phone": "+70357230501"}
0005435070197	0E5A16	8639 878728	ANASTASIYA VOLKOVA	{"phone": "+70133133633"}
0005435070198	0E5A16	3657 192676	ELENA NIKITINA	{"email": "e_nikitina-051971@postgrespro.ru", "phone": "+70071183004"}
0005435070199	49E9B1	4572 554839	EVELINA SIDOROVA	{"email": "evelina_sidorova20031976@postgrespro.ru", "phone": "+70362487420"}
0005435070200	49E9B1	4621 921686	VASILIY TIKHONOV	{"phone": "+70553389325"}
0005435070201	49E9B1	3600 379781	ANASTASIYA KUZNECOVA	{"email": "kuznecova-anastasiya_15051973@postgrespro.ru", "phone": "+70076832912"}
0005435070202	224E7D	1649 437478	ANDREY MOROZOV	{"email": "morozova_1984@postgrespro.ru", "phone": "+70554403663"}
0005435070203	BC3E19	9983 235782	ALEKSANDR KULIKOV	{"phone": "+70879891299"}
0005435070204	72A6F6	1334 401633	IRINA NAZAROVA	{"email": "nazarova-i1974@postgrespro.ru", "phone": "+70412504181"}
0005435070205	1B2769	3840 229114	TATYANA DAVYDOVA	{"phone": "+70305712795"}
0005435070206	1B2769	4939 959307	SVETLANA FOMINA	{"phone": "+70843990502"}
0005435070207	0F4977	9878 126723	VALENTIN IVANOV	{"phone": "+70733550728"}
0005435070208	0F4977	0477 360973	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva_20021976@postgrespro.ru", "phone": "+70873578523"}
0005435070209	AB1AD1	6177 153541	GULFIYA TARASOVA	{"phone": "+70167894179"}
0005435070210	AB1AD1	6104 981675	PAVEL FROLOV	{"phone": "+70165814118"}
0005435070211	ABFDAF	6754 336811	ILYAS FOMIN	{"email": "fomini_1975@postgrespro.ru", "phone": "+70657798701"}
0005435070212	F79ED1	1312 953108	VASILIY IVANOV	{"phone": "+70302389515"}
0005435070213	F94B4D	1272 370223	YULIYA AKIMOVA	{"phone": "+70553466681"}
0005435070214	8087FB	3399 224845	TATYANA KOROLEVA	{"email": "tatyana.koroleva.1963@postgrespro.ru", "phone": "+70086475662"}
0005435070215	8087FB	4932 996355	TAMARA KONOVALOVA	{"phone": "+70890446799"}
0005435070216	2D96FF	9447 293560	ALEKSEY KUZNECOV	{"email": "akuznecov-021964@postgrespro.ru", "phone": "+70140276472"}
0005435070217	F6F290	5575 899738	GALINA MEDVEDEVA	{"phone": "+70529948747"}
0005435070218	F6F290	7022 359769	ILYAS IVANOV	{"phone": "+70437949865"}
0005435070219	DEDB2A	2549 212869	VALENTINA ALEKSEEVA	{"email": "alekseeva-valentina101967@postgrespro.ru", "phone": "+70604024543"}
0005435070220	DE6EE4	1487 080690	LYUBOV SMIRNOVA	{"email": "smirnova_l.28061972@postgrespro.ru", "phone": "+70199577300"}
0005435070221	641C41	7669 091675	NATALYA SIDOROVA	{"email": "n-sidorova-121959@postgrespro.ru", "phone": "+70700483514"}
0005435070222	641C41	3379 702939	VITALIY KONOVALOV	{"email": "konovalov.v121971@postgrespro.ru", "phone": "+70713770556"}
0005435070223	641C41	7619 461543	ANTONINA KUZMINA	{"email": "kuzmina.antonina_13061976@postgrespro.ru", "phone": "+70699267022"}
0005435070224	7A1C93	2189 249361	NADIYA YAKOVLEVA	{"email": "n_yakovleva19061965@postgrespro.ru", "phone": "+70733411197"}
0005435070225	2AE6A2	1922 665819	ANDREY ANDREEV	{"phone": "+70643307275"}
0005435070226	B37F64	1229 534201	NATALYA AFANASEVA	{"phone": "+70175381417"}
0005435070227	9C17B6	1172 015868	SERGEY ZAYCEV	{"email": "zaycev-sergey.031966@postgrespro.ru", "phone": "+70085578582"}
0005435070228	F14E6E	9480 183807	IVAN BORISOV	{"phone": "+70145229548"}
0005435070229	F14E6E	1634 277070	ANATOLIY PETROV	{"phone": "+70390369495"}
0005435070230	F14E6E	2448 395596	NATALYA KONOVALOVA	{"email": "konovalova.natalya-27121978@postgrespro.ru", "phone": "+70904249385"}
0005435070231	CF1644	1407 719400	MAKSIM KOZLOV	{"email": "m-kozlov_17071963@postgrespro.ru", "phone": "+70866340426"}
0005435070232	3297F8	0524 334091	MARGARITA KISELEVA	{"email": "kiselevamargarita-1987@postgrespro.ru", "phone": "+70718760938"}
0005435070233	EFCAD9	0656 612778	LEV TIMOFEEV	{"phone": "+70490682123"}
0005435070234	EC85FC	8758 840379	KRISTINA SMIRNOVA	{"phone": "+70518245062"}
0005435070235	6CE70E	9127 168239	MIKHAIL EGOROV	{"email": "egorov-m26111972@postgrespro.ru", "phone": "+70254851211"}
0005435070236	C3C06C	3074 815928	KLAVDIYA KOLESNIKOVA	{"email": "kolesnikovaklavdiya.051974@postgrespro.ru", "phone": "+70062298870"}
0005435070237	C3C06C	8029 947720	REGINA GAVRILOVA	{"email": "gavrilova_r041969@postgrespro.ru", "phone": "+70032944690"}
0005435070238	EB9C81	9643 979805	ALEKSANDR ANDREEV	{"phone": "+70679789113"}
0005435070239	4DBC26	0534 653331	VERA NESTEROVA	{"email": "nesterova_vera.30011970@postgrespro.ru", "phone": "+70424463278"}
0005435070240	4DBC26	0839 492821	IRINA DAVYDOVA	{"phone": "+70985100035"}
0005435070241	0EEA16	2567 686233	NATALYA NAUMOVA	{"phone": "+70194945270"}
0005435070242	0EEA16	4498 506595	EKATERINA ANDREEVA	{"email": "ekaterina-andreeva071973@postgrespro.ru", "phone": "+70728592444"}
0005435070243	E0F41E	0615 267601	OLEG GUSEV	{"email": "gusevoleg_031976@postgrespro.ru", "phone": "+70127435427"}
0005435070244	044758	8238 339459	EKATERINA GAVRILOVA	{"phone": "+70309489574"}
0005435070245	8BE26E	0746 933908	ALEKSANDR FEDOROV	{"phone": "+70978890480"}
0005435070246	3753CB	8485 543938	IVAN ILIN	{"phone": "+70919710731"}
0005435070247	3753CB	7295 053270	DENIS KOZLOV	{"email": "denis_kozlov1974@postgrespro.ru", "phone": "+70225598360"}
0005435070248	8AAE06	2430 690999	OLGA MARTYNOVA	{"email": "olga.martynova111984@postgrespro.ru", "phone": "+70711790857"}
0005435070249	8AAE06	0367 941226	NATALYA OSIPOVA	{"phone": "+70210282503"}
0005435070250	8AAE06	6495 420805	IGOR ZAKHAROV	{"email": "zakharov.igor1972@postgrespro.ru", "phone": "+70238028767"}
0005435070251	8D4B4F	6732 346564	ALEKSANDR MAKAROV	{"phone": "+70863995081"}
0005435070252	B19AB9	3922 239912	VLADIMIR KULIKOV	{"email": "kulikovv.121975@postgrespro.ru", "phone": "+70254911760"}
0005435070253	B19AB9	1052 436579	OLEG BONDARENKO	{"email": "bondarenko-oleg.011959@postgrespro.ru", "phone": "+70781602037"}
0005435070254	AE2A7A	1897 430792	LYUBOV KUZNECOVA	{"phone": "+70627477260"}
0005435070255	AE2A7A	5045 641602	ANDREY KOROLEV	{"email": "a_korolev_031976@postgrespro.ru", "phone": "+70521179852"}
0005435070256	9F738C	1528 871289	VERA FILIPPOVA	{"email": "filippovavera-101973@postgrespro.ru", "phone": "+70733396091"}
0005435070257	9F738C	6333 634541	ARTEM SIDOROV	{"phone": "+70127608647"}
0005435070258	728284	4145 255180	ELENA BELYAEVA	{"phone": "+70875364219"}
0005435070259	728284	8951 387447	VALENTINA KONOVALOVA	{"phone": "+70259606764"}
0005435070260	F871C2	4141 149055	ALBINA AFANASEVA	{"phone": "+70279555288"}
0005435070261	F871C2	2535 385993	SVETLANA GUSEVA	{"email": "s-guseva_1978@postgrespro.ru", "phone": "+70517327189"}
0005435070262	08A0E7	5716 233725	LYUDMILA SIDOROVA	{"phone": "+70100905855"}
0005435070263	6454B4	8399 453561	DMITRIY VLASOV	{"email": "vlasov-dmitriy_20121961@postgrespro.ru", "phone": "+70069397391"}
0005435070264	57D7B5	9526 937469	TATYANA GUSEVA	{"email": "tatyana-guseva.28061971@postgrespro.ru", "phone": "+70383561833"}
0005435070265	5140DD	8671 684710	SERGEY KUZNECOV	{"phone": "+70849230167"}
0005435070266	5140DD	4175 630256	NATALIYA ROMANOVA	{"phone": "+70406959078"}
0005435070267	D2BEC7	4646 185625	VALENTINA KUZNECOVA	{"email": "valentina-kuznecova.1965@postgrespro.ru", "phone": "+70488039177"}
0005435070268	D2BEC7	5952 056454	LYUDMILA MAKSIMOVA	{"email": "maksimoval.1969@postgrespro.ru", "phone": "+70366382782"}
0005435070269	1BBF4B	9781 039023	OLGA POTAPOVA	{"phone": "+70648541727"}
0005435070270	70972B	0265 996985	TATYANA OSIPOVA	{"email": "tosipova041967@postgrespro.ru", "phone": "+70550796221"}
0005435070271	6A0B0E	7189 274613	DENIS KARPOV	{"email": "dkarpov.11021970@postgrespro.ru", "phone": "+70812974075"}
0005435070272	39D61A	4164 752955	GALINA FOMINA	{"phone": "+70721722494"}
0005435070273	1B359B	5064 483098	MAKSIM ZHURAVLEV	{"phone": "+70643299777"}
0005435070274	50424A	4925 024352	VYACHESLAV SERGEEV	{"phone": "+70021279089"}
0005435070275	50424A	9911 052059	SVETLANA NIKOLAEVA	{"email": "nikolaeva-s_031969@postgrespro.ru", "phone": "+70634337400"}
0005435070276	031123	3462 064736	ARTEM MOISEEV	{"phone": "+70188150738"}
0005435070277	C31A13	5702 137871	KSENIYA PAVLOVA	{"phone": "+70314757629"}
0005435070278	C31A13	9402 761740	NIKITA TIKHONOV	{"email": "nikita_tikhonov.1972@postgrespro.ru", "phone": "+70527776670"}
0005435070279	E42063	7127 582614	VIKTOR DMITRIEV	{"email": "dmitriev-viktor23111972@postgrespro.ru", "phone": "+70103638275"}
0005435070280	E42063	2110 085040	TAMARA ILINA	{"phone": "+70252141151"}
0005435070281	933AEF	8503 196974	YURIY TIKHONOV	{"email": "yuriytikhonov1972@postgrespro.ru", "phone": "+70804072015"}
0005435070282	BD2327	1393 488923	NIKOLAY KISELEV	{"email": "kiselevn-1979@postgrespro.ru", "phone": "+70005797831"}
0005435070283	01FC52	4720 290119	ELENA ARKHIPOVA	{"phone": "+70437327702"}
0005435070284	C785F1	5216 954383	DMITRIY MAKAROV	{"phone": "+70733396793"}
0005435070285	F71A43	4821 415821	ALEKSANDR SMIRNOV	{"email": "smirnovaleksandr.121970@postgrespro.ru", "phone": "+70580228148"}
0005435070286	CDC49B	6756 392910	EVELINA SOROKINA	{"phone": "+70748591199"}
0005435070287	84AD78	1801 984553	ARTUR BARANOV	{"phone": "+70141721732"}
0005435070288	D9F973	5490 436398	ANDREY ANTONOV	{"email": "a.antonov.18071972@postgrespro.ru", "phone": "+70499348164"}
0005435070289	028D70	0665 861302	ANTONINA BARANOVA	{"email": "a-baranova.1970@postgrespro.ru", "phone": "+70293435702"}
0005435070290	5A9024	2791 857721	GERMAN ZAYCEV	{"email": "zaycev_g_041980@postgrespro.ru", "phone": "+70440752355"}
0005435070291	5A9024	9641 774481	SERGEY RODIONOV	{"email": "rodionovsergey_1967@postgrespro.ru", "phone": "+70288952588"}
0005435070292	DD6762	2219 936683	NAIL MIRONOV	{"phone": "+70953165191"}
0005435070293	1DC968	9392 693086	IVAN ZHUKOV	{"email": "ivan-zhukov-081974@postgrespro.ru", "phone": "+70593549431"}
0005435070294	C0B6BE	8175 896835	VALENTIN KOZLOV	{"email": "kozlov_valentin_30031970@postgrespro.ru", "phone": "+70539906019"}
0005435070295	D47461	6693 515383	VITALIY KONOVALOV	{"email": "vitaliy_konovalov-13051970@postgrespro.ru", "phone": "+70378836294"}
0005435070296	87AE29	8576 674406	YULIYA IVANOVA	{"email": "yivanova_1971@postgrespro.ru", "phone": "+70525125949"}
0005435070297	38D00B	6071 345085	POLINA FROLOVA	{"email": "frolova-polina-1968@postgrespro.ru", "phone": "+70675209694"}
0005435070298	38D00B	9749 842259	VYACHESLAV MAKSIMOV	{"email": "maksimov-vyacheslav_1962@postgrespro.ru", "phone": "+70321579004"}
0005435070299	F61F41	7308 159510	MAKSIM TARASOV	{"phone": "+70129701203"}
0005435070300	F61F41	4085 091100	ANTON BARANOV	{"phone": "+70934588829"}
0005435070301	F61F41	0517 937293	BORIS ANTONOV	{"phone": "+70225549964"}
0005435070302	F61F41	0553 424342	YULIYA RYABOVA	{"email": "ryabovay_111964@postgrespro.ru", "phone": "+70433129051"}
0005435070303	241CB0	2875 787479	ELENA TITOVA	{"phone": "+70851750765"}
0005435070304	DB3275	2750 267055	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir.24081975@postgrespro.ru", "phone": "+70981661233"}
0005435070305	9AB28A	6649 314621	MIKHAIL ANDREEV	{"phone": "+70899758461"}
0005435070306	87FAC3	9704 179267	TATYANA KUZNECOVA	{"phone": "+70346699595"}
0005435070307	87FAC3	1399 002321	ILYA DENISOV	{"phone": "+70135265715"}
0005435070308	5B5685	4654 058986	NIKITA SOKOLOV	{"email": "sokolov_nikita_021964@postgrespro.ru", "phone": "+70390998286"}
0005435070309	5B5685	1357 390812	ANNA IVANOVA	{"email": "ivanova_a.1984@postgrespro.ru", "phone": "+70804314112"}
0005435070310	23D57F	2847 516022	ALEKSEY FOMIN	{"email": "fomin-aleksey_11111965@postgrespro.ru", "phone": "+70051161493"}
0005435070311	67DBC8	7607 218279	ILMIRA ABRAMOVA	{"email": "abramova-i-19041963@postgrespro.ru", "phone": "+70088141849"}
0005435070312	67DBC8	4499 945386	OLGA ABRAMOVA	{"email": "oabramova_1962@postgrespro.ru", "phone": "+70668775105"}
0005435070313	4CDF14	9959 837069	ALEKSEY FOMIN	{"email": "fomin.aleksey-20081967@postgrespro.ru", "phone": "+70077927415"}
0005435070314	4CDF14	3755 298962	SVETLANA KRASNOVA	{"email": "krasnova_s1977@postgrespro.ru", "phone": "+70901675702"}
0005435070315	4CDF14	8841 833802	NIKOLAY KUZMIN	{"email": "nikolaykuzmin_28041971@postgrespro.ru", "phone": "+70606854167"}
0005435070316	0F04B5	2526 667466	ALEKSANDR KUZNECOV	{"phone": "+70873524337"}
0005435070317	49DC71	1950 782766	TATYANA TARASOVA	{"phone": "+70018798225"}
0005435070318	49DC71	8294 500441	VALENTINA KARPOVA	{"phone": "+70725816875"}
0005435070319	1F7ED7	3766 856632	EVGENIY FEDOTOV	{"email": "evgeniy_fedotov_1971@postgrespro.ru", "phone": "+70604010468"}
0005435070320	853103	2537 355186	VLADIMIR MAKAROV	{"phone": "+70116516175"}
0005435070321	E405DB	6260 247992	VYACHESLAV ROMANOV	{"email": "romanov_vyacheslav.1980@postgrespro.ru", "phone": "+70591258189"}
0005435070322	E8C82E	9255 634792	EVGENIYA ZAKHAROVA	{"email": "zakharova.evgeniya_1973@postgrespro.ru", "phone": "+70077706854"}
0005435070323	E8C82E	9532 388598	MARIYA EGOROVA	{"phone": "+70762030552"}
0005435070324	F49B25	8416 403569	IRINA ARKHIPOVA	{"email": "irina-arkhipova1970@postgrespro.ru", "phone": "+70017800695"}
0005435070325	3BEE22	6978 792479	TATYANA BELYAEVA	{"phone": "+70961515322"}
0005435070326	5D211D	6665 789459	MARINA SERGEEVA	{"email": "sergeeva_m_05051971@postgrespro.ru", "phone": "+70004071599"}
0005435070327	5D211D	4888 367371	ALEKSANDR SIDOROV	{"phone": "+70273920880"}
0005435070328	5D211D	3180 246312	LYUDMILA IVANOVA	{"email": "ivanova_l1962@postgrespro.ru", "phone": "+70898572434"}
0005435070329	701C12	2836 437228	LIDIYA FOMINA	{"email": "lidiya_fomina20101964@postgrespro.ru", "phone": "+70911039460"}
0005435070330	701C12	3242 177040	NATALYA EFIMOVA	{"email": "n_efimova-16011967@postgrespro.ru", "phone": "+70970956426"}
0005435070331	701C12	8479 046862	IRINA MOROZOVA	{"email": "morozova.i_071972@postgrespro.ru", "phone": "+70765913057"}
0005435070332	3F06AB	4346 545074	NATALYA FROLOVA	{"email": "n_frolova-021969@postgrespro.ru", "phone": "+70925804546"}
0005435070333	EFC5B6	1025 768684	MIKHAIL MEDVEDEV	{"email": "medvedev.mikhail27111975@postgrespro.ru", "phone": "+70791780772"}
0005435070334	EFC5B6	2642 933267	VITALIY KUZMIN	{"email": "kuzmin-vitaliy-18091984@postgrespro.ru", "phone": "+70491475182"}
0005435070335	3D2A91	1700 684110	TATYANA IVANOVA	{"phone": "+70587556509"}
0005435070336	B61A7D	4600 964659	TATYANA CHERNOVA	{"phone": "+70198625356"}
0005435070337	5866DC	0184 496886	ELENA MAKAROVA	{"email": "makarova_e_05041973@postgrespro.ru", "phone": "+70185998944"}
0005435070338	5A551C	7956 077676	LARISA NIKOLAEVA	{"email": "nikolaeva_l101971@postgrespro.ru", "phone": "+70503079670"}
0005435070339	5A551C	5158 998743	MARINA POPOVA	{"email": "marina.popova-19071970@postgrespro.ru", "phone": "+70985074404"}
0005435070340	BBA439	7021 433757	NIKOLAY DMITRIEV	{"phone": "+70631469489"}
0005435070341	E0FB3C	8260 533700	NIKOLAY VASILEV	{"email": "vasilev_nikolay-101973@postgrespro.ru", "phone": "+70445953943"}
0005435070342	8E0E49	3854 984443	LYUBOV DANILOVA	{"email": "danilova.lyubov031970@postgrespro.ru", "phone": "+70168135792"}
0005435070343	3362D7	9466 814603	MARIYA KOROLEVA	{"email": "korolevamariya_1973@postgrespro.ru", "phone": "+70980344395"}
0005435070344	3362D7	9066 186639	NIKOLAY ORLOV	{"email": "orlov-n-041979@postgrespro.ru", "phone": "+70808283072"}
0005435070345	6C9F67	4198 430048	GALINA VOROBEVA	{"phone": "+70486282889"}
0005435070346	E0338E	3176 393578	ARTUR MIKHAYLOV	{"phone": "+70816650697"}
0005435070347	734513	3476 402752	LIDIYA VOROBEVA	{"email": "l_vorobeva081975@postgrespro.ru", "phone": "+70966806498"}
0005435070348	6FDFCF	1380 604833	DARYA ZAKHAROVA	{"phone": "+70602353973"}
0005435070349	8EF6E2	0074 451759	TIMOFEY PAVLOV	{"email": "pavlovt.091980@postgrespro.ru", "phone": "+70294577584"}
0005435070350	304B69	8709 412703	EVGENIY BELOV	{"phone": "+70253731305"}
0005435070351	304B69	0418 132083	SERGEY FEDOROV	{"phone": "+70165794148"}
0005435070352	304B69	3001 315184	OLGA MAKAROVA	{"email": "makarova.o-23061954@postgrespro.ru", "phone": "+70852509154"}
0005435070353	A22FC4	4126 142187	ALEKSANDR SERGEEV	{"email": "a-sergeev_06071972@postgrespro.ru", "phone": "+70518135823"}
0005435070354	A32190	6587 677764	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko_121962@postgrespro.ru", "phone": "+70832956218"}
0005435070355	AC56C1	4560 113644	VALERIY BELOV	{"phone": "+70923428111"}
0005435070356	699E48	2045 120610	VLADIMIR SCHERBAKOV	{"email": "scherbakov_vladimir021964@postgrespro.ru", "phone": "+70403393106"}
0005435070357	699E48	1806 459611	LYUBOV KOVALEVA	{"phone": "+70679223641"}
0005435070358	89395E	6551 069118	BORIS SOROKIN	{"email": "b_sorokin_1972@postgrespro.ru", "phone": "+70081753804"}
0005435070359	68A39F	8992 595061	ILNUR KONOVALOV	{"phone": "+70197923132"}
0005435070360	68A39F	9547 618910	VALERIY VASILEV	{"phone": "+70110058970"}
0005435070361	26069C	8832 151116	DMITRIY DAVYDOV	{"phone": "+70892234783"}
0005435070362	F32586	3375 829707	ALEKSEY KRASNOV	{"email": "aleksey_krasnov-1976@postgrespro.ru", "phone": "+70568566939"}
0005435070363	51AC64	5682 547767	ANASTASIYA DAVYDOVA	{"email": "anastasiya_davydova.121961@postgrespro.ru", "phone": "+70565651440"}
0005435070364	7EB426	5550 222487	LIDIYA FROLOVA	{"email": "lfrolova101970@postgrespro.ru", "phone": "+70286500329"}
0005435070365	051432	1893 021445	NADEZHDA MIKHAYLOVA	{"email": "nadezhda_mikhaylova_12011975@postgrespro.ru", "phone": "+70820068167"}
0005435070366	D755F7	1915 079249	ALEKSANDR ALEKSEEV	{"phone": "+70522151347"}
0005435070367	D755F7	0511 086984	ALEKSANDR IVANOV	{"email": "ivanova-061965@postgrespro.ru", "phone": "+70829390197"}
0005435070368	D7BD47	9686 809706	OLESYA MOROZOVA	{"email": "o-morozova.11081991@postgrespro.ru", "phone": "+70016161851"}
0005435070369	D7BD47	0151 630454	VLADISLAV ALEKSANDROV	{"phone": "+70570000631"}
0005435070370	EA15E5	7193 309098	VLADIMIR GERASIMOV	{"phone": "+70931113330"}
0005435070371	EA15E5	4635 149649	IVAN ZHURAVLEV	{"phone": "+70389378521"}
0005435070372	5DDEA5	5247 821172	YURIY ZAYCEV	{"phone": "+70800600703"}
0005435070373	3F715C	1024 938341	GALINA IVANOVA	{"phone": "+70215460363"}
0005435070374	3F715C	7627 768172	NATALIYA EGOROVA	{"email": "egorova.nataliya_1982@postgrespro.ru", "phone": "+70305476948"}
0005435070375	31207E	9732 889989	YANA ANDREEVA	{"phone": "+70877093689"}
0005435070376	DDB1F8	4446 897309	YAROSLAV MOISEEV	{"phone": "+70723907179"}
0005435070377	DDB1F8	6150 845520	VIOLETTA IVANOVA	{"phone": "+70794347293"}
0005435070378	EFFEFA	2253 237773	ALEKSANDR SIDOROV	{"phone": "+70268026756"}
0005435070379	259049	6596 293674	IVAN ABRAMOV	{"phone": "+70841358397"}
0005435070380	259049	9548 597228	NIKITA ZHUKOV	{"phone": "+70038202221"}
0005435070381	335F3B	6046 982649	ELENA KISELEVA	{"email": "kiseleva_elena.1975@postgrespro.ru", "phone": "+70281144953"}
0005435070382	971C98	2593 085835	ARTEM KUZNECOV	{"phone": "+70494785642"}
0005435070383	E65AFF	8157 552207	IGOR VOLKOV	{"email": "volkovi-14011974@postgrespro.ru", "phone": "+70066968381"}
0005435070384	F23472	4049 169571	MIKHAIL SMIRNOV	{"email": "smirnov_m.021977@postgrespro.ru", "phone": "+70246462263"}
0005435070385	504B6D	0009 390875	ANDREY KRASNOV	{"email": "krasnov-andrey1963@postgrespro.ru", "phone": "+70576209396"}
0005435070386	504B6D	7310 029036	MIKHAIL BARANOV	{"phone": "+70626918849"}
0005435070387	CD0059	9736 128787	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-1976@postgrespro.ru", "phone": "+70260409995"}
0005435070388	0B2E0B	8018 983232	ANATOLIY MEDVEDEV	{"email": "a_medvedev.011974@postgrespro.ru", "phone": "+70022466471"}
0005435070389	0B2E0B	2683 984475	NATALYA KARPOVA	{"phone": "+70010376179"}
0005435070390	0B2E0B	4062 633433	GRIGORIY ALEKSEEV	{"email": "grigoriy_alekseev1978@postgrespro.ru", "phone": "+70964744495"}
0005435070391	B5DF42	1037 906764	VIKTORIYA VASILEVA	{"email": "viktoriya_vasileva_1964@postgrespro.ru", "phone": "+70884607845"}
0005435070392	B5DF42	5666 030907	OLESYA PETROVA	{"email": "olesya-petrova_1976@postgrespro.ru", "phone": "+70906705675"}
0005435070393	4B62A9	4626 643465	VALENTINA ZAYCEVA	{"phone": "+70170803906"}
0005435070394	48B710	1172 731557	RAVIL KISELEV	{"email": "ravil.kiselev.07011972@postgrespro.ru", "phone": "+70069438519"}
0005435070395	E186F6	3533 015375	LYUDMILA SOROKINA	{"phone": "+70438020332"}
0005435070396	E186F6	0290 255047	OLGA ZAKHAROVA	{"phone": "+70306115262"}
0005435070397	ED6354	8108 827931	MAKSIM MOISEEV	{"phone": "+70105083125"}
0005435070398	13A9F1	3588 527955	ARSENIY NOVIKOV	{"email": "novikovarseniy_01021971@postgrespro.ru", "phone": "+70174767352"}
0005435070399	13A9F1	2762 608825	LYUDMILA KUZNECOVA	{"email": "kuznecova_lyudmila.101965@postgrespro.ru", "phone": "+70017960079"}
0005435070400	63D3A7	5057 473054	VLADIMIR TIMOFEEV	{"email": "v.timofeev.101971@postgrespro.ru", "phone": "+70119294568"}
0005435070401	70F5D9	5571 153798	YURIY SEMENOV	{"phone": "+70874945304"}
0005435070402	70F5D9	6005 917020	VALERIY FEDOROV	{"phone": "+70355532750"}
0005435070403	4D0469	3165 060838	ALINA TARASOVA	{"phone": "+70691332366"}
0005435070404	9F3F55	1532 343823	NADEZHDA SERGEEVA	{"phone": "+70783232794"}
0005435070405	C2C34C	9883 167759	GEORGIY DENISOV	{"email": "gdenisov041965@postgrespro.ru", "phone": "+70564336860"}
0005435070406	FFE229	4680 908883	RAISA VLASOVA	{"email": "vlasova.raisa101970@postgrespro.ru", "phone": "+70887313391"}
0005435070407	916456	0445 519896	ELENA ALEKSEEVA	{"email": "alekseeva-e-091982@postgrespro.ru", "phone": "+70534994228"}
0005435070408	F74AAA	5976 337109	YURIY MAKAROV	{"phone": "+70863466134"}
0005435070409	F74AAA	2807 086964	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy1978@postgrespro.ru", "phone": "+70992526771"}
0005435070410	F74AAA	6765 638661	VERA LEBEDEVA	{"phone": "+70778843173"}
0005435070411	E35EF9	2201 539032	LYUDMILA KARPOVA	{"email": "l-karpova-071976@postgrespro.ru", "phone": "+70282984354"}
0005435070412	518D6B	3239 789246	VLADIMIR MARTYNOV	{"email": "martynov_v21031975@postgrespro.ru", "phone": "+70578474014"}
0005435070413	4915A6	0552 955055	GENNADIY FILIPPOV	{"phone": "+70485247932"}
0005435070414	0A98DA	9482 857425	GENNADIY RODIONOV	{"phone": "+70537992375"}
0005435070415	E076F9	0794 311121	OLGA ERMAKOVA	{"phone": "+70543210240"}
0005435070416	CD267E	0510 005616	ANDREY ZAYCEV	{"phone": "+70950750912"}
0005435070417	CD267E	4917 441339	FARIDA ROMANOVA	{"phone": "+70495496248"}
0005435070418	80355D	1565 579498	ALINA ZAKHAROVA	{"email": "zakharova_a20101964@postgrespro.ru", "phone": "+70506778905"}
0005435070419	D18919	3926 720245	ALEKSANDR DAVYDOV	{"phone": "+70023539349"}
0005435070420	BF96A2	3221 104561	VERA EGOROVA	{"phone": "+70421332340"}
0005435070421	289B05	2151 428958	ZINAIDA GUSEVA	{"phone": "+70870234969"}
0005435070422	B68E6A	4059 151045	ALEKSEY BONDARENKO	{"email": "a-bondarenko011965@postgrespro.ru", "phone": "+70809475692"}
0005435070423	9809BE	2759 387593	OLGA KULIKOVA	{"phone": "+70362557361"}
0005435070424	177620	5296 887017	ALEKSEY KONOVALOV	{"email": "konovalovaleksey_081966@postgrespro.ru", "phone": "+70027078804"}
0005435070425	2143F7	7204 305180	VYACHESLAV MIKHAYLOV	{"phone": "+70100681308"}
0005435070426	09B092	7938 658564	IRINA ANISIMOVA	{"phone": "+70392202436"}
0005435070427	09B092	8886 663355	TATYANA EGOROVA	{"email": "egorova_tatyana-1973@postgrespro.ru", "phone": "+70823363020"}
0005435070428	09B092	4766 615778	VASILIY ALEKSANDROV	{"phone": "+70554534481"}
0005435070429	3E6C4B	8619 715767	YULIYA NIKITINA	{"email": "y.nikitina.1977@postgrespro.ru", "phone": "+70588735968"}
0005435070430	495592	4305 153063	ANATOLIY MELNIKOV	{"email": "melnikov-a_031974@postgrespro.ru", "phone": "+70267188793"}
0005435070431	980CFF	8108 878715	ELENA KUZNECOVA	{"email": "kuznecova.e11041964@postgrespro.ru", "phone": "+70014638855"}
0005435070432	2BB0AB	0123 295249	MARIYA ORLOVA	{"email": "mariyaorlova-22041977@postgrespro.ru", "phone": "+70868641851"}
0005435070433	2BB0AB	2953 510368	VYACHESLAV ANTONOV	{"phone": "+70331068663"}
0005435070434	BEE593	7519 721887	ARKADIY MEDVEDEV	{"email": "a_medvedev-101961@postgrespro.ru", "phone": "+70424275605"}
0005435070435	BF76B9	8194 014942	EVGENIYA KAZAKOVA	{"phone": "+70145457214"}
0005435070436	79D279	0854 206497	EVGENIY VASILEV	{"email": "vasilev-e.07051969@postgrespro.ru", "phone": "+70684030202"}
0005435070437	62022A	6005 985968	VALENTINA SOLOVEVA	{"email": "valentina_soloveva_1973@postgrespro.ru", "phone": "+70821375477"}
0005435070438	A09826	6727 187090	RUZALIYA KRASNOVA	{"email": "krasnova_ruzaliya.041963@postgrespro.ru", "phone": "+70554470126"}
0005435070439	315043	1245 576582	LYUBOV ZOTOVA	{"email": "zotova.lyubov1972@postgrespro.ru", "phone": "+70446739523"}
0005435070440	5966B5	1043 679872	DENIS BORISOV	{"email": "borisov.denis.041958@postgrespro.ru", "phone": "+70008146075"}
0005435070441	ABAC4D	6560 663121	ANTONINA EFIMOVA	{"email": "aefimova091961@postgrespro.ru", "phone": "+70113399146"}
0005435070442	1DFAE2	8599 914557	IRINA NESTEROVA	{"phone": "+70917528214"}
0005435070443	7EF0BA	2774 592711	NATALYA MIKHAYLOVA	{"email": "natalya-mikhaylova091965@postgrespro.ru", "phone": "+70149190028"}
0005435070444	F0C2EB	1695 228141	LILIYA IVANOVA	{"phone": "+70121133705"}
0005435070445	A5A631	5156 735310	NIKITA SCHERBAKOV	{"email": "scherbakov-nikita-1968@postgrespro.ru", "phone": "+70684106222"}
0005435070446	BF55FE	1982 856233	VALENTINA SEMENOVA	{"email": "semenova.valentina_23051975@postgrespro.ru", "phone": "+70565246868"}
0005435070447	BF55FE	3341 926485	ALSU POPOVA	{"phone": "+70417199678"}
0005435070448	BF55FE	3069 001381	SVETLANA YAKOVLEVA	{"email": "yakovleva-svetlana1973@postgrespro.ru", "phone": "+70819626767"}
0005435070449	787209	5821 975481	GALINA VASILEVA	{"phone": "+70621632153"}
0005435070450	2B7AE9	3954 713535	SERGEY KULIKOV	{"phone": "+70373926645"}
0005435070451	8CBB38	6383 512319	VLADIMIR ILIN	{"phone": "+70099886726"}
0005435070452	AA1DD2	0979 900273	NIKOLAY MIKHAYLOV	{"phone": "+70518736458"}
0005435070453	4C1DC5	4595 739158	SERGEY ANTONOV	{"email": "antonov-s_1965@postgrespro.ru", "phone": "+70524099435"}
0005435070454	CC06AA	5493 414652	DARYA ILINA	{"email": "d.ilina1977@postgrespro.ru", "phone": "+70511302863"}
0005435070455	FFFC1A	9052 564336	ANATOLIY KUZMIN	{"phone": "+70493240160"}
0005435070456	FFFC1A	9792 361349	ROMAN BONDARENKO	{"email": "r-bondarenko.1969@postgrespro.ru", "phone": "+70367640659"}
0005435070457	FFFC1A	5155 910949	ANTON GORBUNOV	{"phone": "+70151429395"}
0005435070458	07F4D1	2422 106491	VALENTIN IVANOV	{"phone": "+70202199509"}
0005435070459	98B1A4	7045 336772	MARINA EGOROVA	{"email": "m.egorova_111968@postgrespro.ru", "phone": "+70187723043"}
0005435070460	EAD2DD	3370 356038	DENIS AFANASEV	{"email": "dafanasev071959@postgrespro.ru", "phone": "+70381025700"}
0005435070461	EAD2DD	6456 826950	SVETLANA MATVEEVA	{"phone": "+70074172547"}
0005435070462	EAD2DD	5693 370746	GALINA SIDOROVA	{"email": "sidorova.galina.09121974@postgrespro.ru", "phone": "+70393590715"}
0005435070463	64EDEE	7702 973149	MIKHAIL STEPANOV	{"email": "mstepanov12091967@postgrespro.ru", "phone": "+70673226470"}
0005435070464	64EDEE	9531 387515	NINA ZAYCEVA	{"phone": "+70770404655"}
0005435070465	9039A9	5604 303795	SERGEY BONDARENKO	{"phone": "+70655307228"}
0005435070466	2E8D8B	8780 097244	ELENA TIMOFEEVA	{"phone": "+70223711030"}
0005435070467	2E8D8B	5298 961331	VERONIKA MIRONOVA	{"email": "mironova-veronika-011963@postgrespro.ru", "phone": "+70008571986"}
0005435070468	F68715	3673 397734	SNEZHANA ORLOVA	{"email": "snezhana_orlova-1980@postgrespro.ru", "phone": "+70229095176"}
0005435070469	CCAAAB	9952 754890	SERGEY VLASOV	{"phone": "+70228689877"}
0005435070470	D4B533	4423 012936	ANDREY NAZAROV	{"phone": "+70990503556"}
0005435070471	A9BDC2	2539 013377	DANIIL FROLOV	{"email": "daniilfrolov.1971@postgrespro.ru", "phone": "+70816234816"}
0005435070472	55EC74	0386 260230	ILNAR BELOV	{"email": "ilnar-belov_101971@postgrespro.ru", "phone": "+70805089613"}
0005435070473	55EC74	9798 186787	VALERIY IVANOV	{"phone": "+70166369837"}
0005435070474	F6FBAE	7011 934871	VALENTINA MIRONOVA	{"phone": "+70249154264"}
0005435070475	F6FBAE	4489 143268	ELENA MEDVEDEVA	{"email": "medvedevae.051963@postgrespro.ru", "phone": "+70704464214"}
0005435070476	685A81	7128 790554	OLGA IVANOVA	{"phone": "+70301396455"}
0005435070477	685A81	8413 066791	LYUDMILA MIKHAYLOVA	{"email": "l.mikhaylova_15031980@postgrespro.ru", "phone": "+70069849678"}
0005435070478	621720	1787 265015	MIKHAIL KAZAKOV	{"email": "m_kazakov.101978@postgrespro.ru", "phone": "+70284846561"}
0005435070479	C5A97C	1593 061365	SVETLANA BELYAEVA	{"phone": "+70145592639"}
0005435070480	83A2D0	1251 173916	OLGA IVANOVA	{"email": "ivanova_o.031978@postgrespro.ru", "phone": "+70434457197"}
0005435070481	5CB13C	7109 470673	VLADIMIR KUZMIN	{"email": "kuzmin_vladimir.1972@postgrespro.ru", "phone": "+70318170489"}
0005435070482	7C2E39	3278 539021	NINA KOROLEVA	{"email": "koroleva_n-051974@postgrespro.ru", "phone": "+70836268102"}
0005435070483	7C2E39	0123 740592	EGOR EGOROV	{"email": "egor_egorov-16031966@postgrespro.ru", "phone": "+70093079991"}
0005435070484	F02F6C	1158 390231	OLGA GUSEVA	{"phone": "+70060378848"}
0005435070485	684CCF	6500 812430	VADIM KUZNECOV	{"email": "vadim_kuznecov-03101985@postgrespro.ru", "phone": "+70175111896"}
0005435070486	684CCF	6055 392007	KSENIYA DANILOVA	{"email": "danilovakseniya-101971@postgrespro.ru", "phone": "+70176516687"}
0005435070487	156823	3969 764153	ELENA MAKAROVA	{"email": "makarova-elena21061967@postgrespro.ru", "phone": "+70110625542"}
0005435070488	BD08A1	5046 629484	EVDOKIYA POTAPOVA	{"phone": "+70136705951"}
0005435070489	6F4865	3496 428229	SERGEY MELNIKOV	{"email": "sergeymelnikov.08101965@postgrespro.ru", "phone": "+70549917481"}
0005435070490	6F4865	4512 607001	VLADIMIR SIDOROV	{"email": "vladimir-sidorov.051984@postgrespro.ru", "phone": "+70126030220"}
0005435070491	666E00	8401 349929	VLADIMIR VASILEV	{"email": "vladimirvasilev.1981@postgrespro.ru", "phone": "+70003371613"}
0005435070492	666E00	0088 931369	DMITRIY OSIPOV	{"phone": "+70260888239"}
0005435070493	E1DDAB	0736 602855	RUSLAN GUSEV	{"email": "gusev-ruslan23071983@postgrespro.ru", "phone": "+70756460484"}
0005435070494	E1DDAB	4863 765499	NATALYA LEBEDEVA	{"phone": "+70109313137"}
0005435070495	EC3935	2302 031600	ALEKSANDR IVANOV	{"email": "ivanov-a.091982@postgrespro.ru", "phone": "+70316431380"}
0005435070496	111387	9368 426042	GLEB ISAEV	{"email": "isaev-g.011974@postgrespro.ru", "phone": "+70228028618"}
0005435070497	111387	0646 515941	NATALYA GORBUNOVA	{"phone": "+70280788438"}
0005435070498	111387	3382 117957	MARIYA POLYAKOVA	{"email": "polyakova-mariya-21121976@postgrespro.ru", "phone": "+70317716381"}
0005435070499	18D9FE	2036 228512	INGA POPOVA	{"phone": "+70144404270"}
0005435070500	18D9FE	5208 818640	VALENTINA ZHURAVLEVA	{"phone": "+70543526689"}
0005435070501	18D9FE	9802 292707	ALEKSANDR GAVRILOV	{"email": "gavrilova.20011980@postgrespro.ru", "phone": "+70437408622"}
0005435070502	D49391	2146 584516	VALENTINA OSIPOVA	{"phone": "+70340771992"}
0005435070503	C1FC70	7201 829282	ANNA MOROZOVA	{"email": "anna.morozova24091984@postgrespro.ru", "phone": "+70572476693"}
0005435070504	A323AA	4233 483798	ANDREY SMIRNOV	{"email": "smirnov-andrey-101972@postgrespro.ru", "phone": "+70478145624"}
0005435070505	07E382	4447 986637	ALEKSEY SAVELEV	{"phone": "+70262900124"}
0005435070506	07E382	4316 744547	ALEKSANDR MAKAROV	{"phone": "+70076811644"}
0005435070507	07E382	1693 888880	SERGEY SCHERBAKOV	{"phone": "+70474557517"}
0005435070508	7EBFB9	6647 846050	GULNARA NIKITINA	{"email": "gulnaranikitina_05071973@postgrespro.ru", "phone": "+70724864319"}
0005435070509	1C47F0	0416 238613	RUZALIYA VASILEVA	{"phone": "+70592564096"}
0005435070510	058FBC	1586 688772	DENIS BONDARENKO	{"phone": "+70016856217"}
0005435070511	32A442	5235 797205	DARYA DMITRIEVA	{"phone": "+70039732474"}
0005435070512	BC7B45	0808 887123	EVGENIY VASILEV	{"phone": "+70815681021"}
0005435070513	A03014	3461 219007	ANATOLIY BORISOV	{"email": "anatoliy.borisov101969@postgrespro.ru", "phone": "+70064006467"}
0005435070514	558A34	0897 209400	NADEZHDA ZAKHAROVA	{"phone": "+70640852072"}
0005435070515	C45394	3265 794161	EMILIYA POPOVA	{"phone": "+70858037833"}
0005435070516	71D976	1088 060123	SVETLANA BELYAEVA	{"phone": "+70931267557"}
0005435070517	71D976	0283 040487	EVGENIY ORLOV	{"email": "e-orlov1971@postgrespro.ru", "phone": "+70011649603"}
0005435070518	E4FD8B	3169 694021	OLGA FEDOROVA	{"email": "fedorovaolga.03051979@postgrespro.ru", "phone": "+70609176598"}
0005435070519	D62DDD	6656 093223	SERGEY SOROKIN	{"phone": "+70068874169"}
0005435070520	5C51BD	9680 730235	REGINA SERGEEVA	{"email": "sergeeva-r14031980@postgrespro.ru", "phone": "+70039574799"}
0005435070521	5C51BD	0049 621621	IRINA FOMINA	{"email": "irina_fomina_091971@postgrespro.ru", "phone": "+70525614983"}
0005435070522	1486D7	4142 372626	ALEKSANDR BELOV	{"email": "belov-aleksandr101976@postgrespro.ru", "phone": "+70400079472"}
0005435070523	1486D7	1357 852184	SERGEY DAVYDOV	{"email": "s.davydov-071955@postgrespro.ru", "phone": "+70478735530"}
0005435070524	886575	5648 861614	MARGARITA ALEKSEEVA	{"phone": "+70183790154"}
0005435070525	CCD3E8	0871 512994	VALENTINA KARPOVA	{"phone": "+70137381790"}
0005435070526	BAA4A9	5357 173528	MIKHAIL SERGEEV	{"email": "sergeev.m_27011976@postgrespro.ru", "phone": "+70148214494"}
0005435070527	F2CBFD	3313 898581	TATYANA LAZAREVA	{"phone": "+70162275338"}
0005435070528	93CBAC	6460 898253	EKATERINA NESTEROVA	{"phone": "+70330130436"}
0005435070529	1EB38D	8806 667577	IRINA KOROLEVA	{"phone": "+70909573152"}
0005435070530	3DE7CF	5166 987635	YULIYA VLASOVA	{"email": "yuliya-vlasova_051970@postgrespro.ru", "phone": "+70655464555"}
0005435070531	8CBDD6	7699 826643	YULIYA FOMINA	{"email": "fomina-yuliya.021972@postgrespro.ru", "phone": "+70498610952"}
0005435070532	8CBDD6	9094 496726	ANDREY MIRONOV	{"phone": "+70982265795"}
0005435070533	D08B2C	8725 709318	ELENA KRASNOVA	{"email": "elena.krasnova.31101970@postgrespro.ru", "phone": "+70376633600"}
0005435070534	749DC3	3534 332756	DMITRIY NAZAROV	{"email": "dmitriy-nazarov1973@postgrespro.ru", "phone": "+70838235043"}
0005435070535	2EC0FC	4009 699748	KSENIYA KISELEVA	{"email": "kseniya_kiseleva-051968@postgrespro.ru", "phone": "+70261550792"}
0005435070536	A32F9A	3550 099167	ELENA KONDRATEVA	{"phone": "+70062388575"}
0005435070537	F21EB9	2562 171921	SERGEY ALEKSANDROV	{"email": "s_aleksandrov1965@postgrespro.ru", "phone": "+70802014711"}
0005435070538	763565	3544 277120	ANASTASIYA DMITRIEVA	{"email": "a_dmitrieva.12051982@postgrespro.ru", "phone": "+70256566083"}
0005435070539	7DDDCA	1693 095408	DMITRIY IVANOV	{"email": "ivanov.d1980@postgrespro.ru", "phone": "+70834410047"}
0005435070540	64212C	6491 025212	TATYANA IVANOVA	{"email": "tivanova.1974@postgrespro.ru", "phone": "+70672473553"}
0005435070541	9210CC	0055 062821	ANASTASIYA ANTONOVA	{"email": "anastasiyaantonova-061974@postgrespro.ru", "phone": "+70870392369"}
0005435070542	7474A1	6959 907820	KARINA EFIMOVA	{"email": "karina-efimova_28101973@postgrespro.ru", "phone": "+70754182140"}
0005435070543	005E4E	8058 184530	SERGEY SEMENOV	{"phone": "+70177516622"}
0005435070544	9B7015	7978 007316	DANIL NIKOLAEV	{"email": "d_nikolaev_07111971@postgrespro.ru", "phone": "+70784525487"}
0005435070545	218FA4	9093 335752	LIDIYA SIDOROVA	{"email": "lidiya_sidorova-101978@postgrespro.ru", "phone": "+70659222210"}
0005435070546	E0994A	6264 606886	ZINAIDA BOGDANOVA	{"phone": "+70809448812"}
0005435070547	6C8A07	8879 027935	YULIYA CHERNOVA	{"email": "y_chernova-12051969@postgrespro.ru", "phone": "+70477558140"}
0005435070548	6C8A07	6827 392482	TATYANA YAKOVLEVA	{"phone": "+70210246144"}
0005435070549	419202	2008 975981	MARIYA NAUMOVA	{"email": "m-naumova041976@postgrespro.ru", "phone": "+70922905162"}
0005435070550	519DC3	2378 128765	MARIYA FADEEVA	{"phone": "+70038437590"}
0005435070551	050A86	7587 103781	MIKHAIL ANDREEV	{"phone": "+70660667797"}
0005435070552	E4A7FA	4573 027952	VALENTIN KUDRYASHOV	{"email": "valentin-kudryashov.1972@postgrespro.ru", "phone": "+70608857518"}
0005435070553	90C727	8698 922748	LYUBOV NAZAROVA	{"email": "lyubov_nazarova-071977@postgrespro.ru", "phone": "+70091028221"}
0005435070554	90C727	2705 176009	ILYA TARASOV	{"phone": "+70717971227"}
0005435070555	72EFEA	8701 420583	SERGEY CHERNOV	{"phone": "+70139561440"}
0005435070556	28B5BD	0225 556111	ALEKSANDRA KRASNOVA	{"email": "aleksandra.krasnova041965@postgrespro.ru", "phone": "+70948721869"}
0005435070557	28B5BD	4393 313903	VLADISLAV ILIN	{"email": "ilin.vladislav-05021970@postgrespro.ru", "phone": "+70629935701"}
0005435070558	973297	0087 553980	NATALYA ILINA	{"phone": "+70318396277"}
0005435070559	973297	1444 450659	SERGEY IVANOV	{"email": "ivanovs.011969@postgrespro.ru", "phone": "+70126252799"}
0005435070560	973297	3816 211521	SERGEY PETROV	{"email": "sergey_petrov.1972@postgrespro.ru", "phone": "+70772588711"}
0005435070561	EE3A84	0260 364268	LILIYA CHERNOVA	{"email": "lchernova.081970@postgrespro.ru", "phone": "+70112663685"}
0005435070562	D19364	2951 154297	LEV BARANOV	{"phone": "+70074181344"}
0005435070563	B5A571	9852 246495	ELENA BELOVA	{"phone": "+70750486321"}
0005435070564	0CB905	6532 224864	MARIYA FROLOVA	{"phone": "+70845026042"}
0005435070565	2BFA41	8395 916409	IVAN YAKOVLEV	{"email": "yakovlev_ivan-25061973@postgrespro.ru", "phone": "+70624920846"}
0005435070566	2BFA41	5523 291616	ARTEM SAVELEV	{"phone": "+70857995868"}
0005435070567	376F60	7427 650733	ALEKSANDR KAZAKOV	{"phone": "+70115234780"}
0005435070568	376F60	2831 560381	ANGELINA AKIMOVA	{"phone": "+70927920200"}
0005435070569	F7E070	2509 523727	INNA IVANOVA	{"email": "ivanova_i.071968@postgrespro.ru", "phone": "+70394705020"}
0005435070570	F7E070	1458 887430	ANATOLIY KARPOV	{"phone": "+70795835499"}
0005435070571	209B83	8228 412511	TATYANA KULIKOVA	{"email": "tatyana-kulikova.03011968@postgrespro.ru", "phone": "+70312683221"}
0005435070572	209B83	5732 621079	IRINA POPOVA	{"phone": "+70837780165"}
0005435078063	DC2100	2735 953886	RAISA GRISHINA	{"email": "grishina.r_121968@postgrespro.ru", "phone": "+70129973041"}
0005435078064	B8780C	0451 270760	VLADIMIR RODIONOV	{"email": "rodionovvladimir04081969@postgrespro.ru", "phone": "+70393700751"}
0005435078065	D97CFE	7970 904934	TATYANA POPOVA	{"email": "t_popova_09061970@postgrespro.ru", "phone": "+70960978353"}
0005435078066	A2CA2B	9328 102191	STEPAN SCHERBAKOV	{"email": "scherbakov.stepan.1967@postgrespro.ru", "phone": "+70242699408"}
0005435078067	A2CA2B	6641 038673	KONSTANTIN SEMENOV	{"phone": "+70870628056"}
0005435078068	951C26	0816 771290	VALENTINA NAUMOVA	{"email": "naumovav.1965@postgrespro.ru", "phone": "+70660199123"}
0005435078069	B86091	9657 652499	OLEG MAKSIMOV	{"email": "maksimovoleg_1970@postgrespro.ru", "phone": "+70614045747"}
0005435078070	FDF75A	5173 176514	ARTUR SOKOLOV	{"email": "sokolov.a.1973@postgrespro.ru", "phone": "+70097399433"}
0005435078071	0C3FF7	6941 030176	VLADIMIR GORBUNOV	{"email": "v_gorbunov22061969@postgrespro.ru", "phone": "+70063940039"}
0005435078072	440214	4941 601065	ALEKSEY PETROV	{"email": "aleksey_petrov-121970@postgrespro.ru", "phone": "+70922070476"}
0005435078073	69EE94	2108 764557	ALEKSEY MATVEEV	{"email": "alekseymatveev1986@postgrespro.ru", "phone": "+70697441232"}
0005435078074	6012BA	1906 520806	SVETLANA IVANOVA	{"email": "svetlanaivanova_1964@postgrespro.ru", "phone": "+70026290898"}
0005435078075	6012BA	9409 833977	LIDIYA LAZAREVA	{"phone": "+70620101117"}
0005435078076	A23BC7	9007 569673	SERGEY FEDOROV	{"email": "fedorov.sergey-1971@postgrespro.ru", "phone": "+70437834646"}
0005435078077	A23BC7	4420 290939	IVAN KUZNECOV	{"email": "i_kuznecov.041963@postgrespro.ru", "phone": "+70840682372"}
0005435078078	E7FECB	7244 542626	OLGA KUZNECOVA	{"email": "kuznecova_olga_031975@postgrespro.ru", "phone": "+70642708094"}
0005435078079	E7FECB	1495 634289	NADEZHDA EFIMOVA	{"phone": "+70192841116"}
0005435078080	D0C28F	9641 266266	TATYANA PAVLOVA	{"email": "tatyanapavlova091972@postgrespro.ru", "phone": "+70231078947"}
0005435078081	6B96E5	4871 920685	YULIYA YUDINA	{"phone": "+70836292206"}
0005435078082	628D3C	5429 582064	LYUBOV ALEKSEEVA	{"email": "alekseeva-l.111967@postgrespro.ru", "phone": "+70728355069"}
0005435078083	628D3C	3677 088429	SVETLANA VASILEVA	{"email": "vasilevas-051975@postgrespro.ru", "phone": "+70925757870"}
0005435078084	E78912	8568 069300	SERGEY MARTYNOV	{"phone": "+70525909571"}
0005435078085	E78912	2138 005510	ELIZAVETA YAKOVLEVA	{"phone": "+70132514668"}
0005435078086	FE8B30	6934 037529	VALENTINA KOZLOVA	{"email": "valentina-kozlova.111980@postgrespro.ru", "phone": "+70183301673"}
0005435078087	BA48E8	4448 589678	MAKSIM MATVEEV	{"phone": "+70270817194"}
0005435078088	E7266E	7093 890755	NIKOLAY IVANOV	{"email": "ivanov-nikolay-01101973@postgrespro.ru", "phone": "+70109378969"}
0005435078089	BEB240	4273 008202	ANDREY MEDVEDEV	{"email": "andrey-medvedev-24031968@postgrespro.ru", "phone": "+70927652918"}
0005435078090	05D832	0584 043016	VALERIY MARTYNOV	{"email": "martynov-valeriy-07011975@postgrespro.ru", "phone": "+70455057356"}
0005435078091	D40AE0	7077 902615	EVGENIY MOROZOV	{"email": "morozov.evgeniy_101969@postgrespro.ru", "phone": "+70699768894"}
0005435078092	E57357	2700 728104	VLADIMIR GRIGOREV	{"email": "grigorevv_07021977@postgrespro.ru", "phone": "+70058056646"}
0005435078093	2A677A	1260 433730	LIDIYA DANILOVA	{"email": "l-danilova.101966@postgrespro.ru", "phone": "+70430294841"}
0005435078094	B37C69	2416 539754	LYUBOV YAKOVLEVA	{"phone": "+70896324109"}
0005435078095	B37C69	3329 256456	NIKOLAY NAUMOV	{"phone": "+70031371104"}
0005435078096	29ECCF	2004 544620	LYUBOV ZAYCEVA	{"email": "zayceva.l121972@postgrespro.ru", "phone": "+70170903349"}
0005435078097	FCE758	4694 074806	NIKITA ALEKSANDROV	{"phone": "+70579656642"}
0005435078098	AD5EE8	7467 364578	SERGEY MIRONOV	{"email": "s.mironov_081974@postgrespro.ru", "phone": "+70351759774"}
0005435078099	AD5EE8	2583 483616	ARTUR VOLKOV	{"phone": "+70800331688"}
0005435078100	3D4E77	2390 620468	NATALYA KOVALEVA	{"email": "kovaleva-natalya1966@postgrespro.ru", "phone": "+70842888941"}
0005435078101	359A79	2848 734516	MIKHAIL KISELEV	{"phone": "+70960613352"}
0005435078102	8A7485	4080 214753	ANASTASIYA SOKOLOVA	{"phone": "+70086062708"}
0005435078103	8A7485	4071 383569	NATALYA MASLOVA	{"phone": "+70040778065"}
0005435078104	F8EFCE	5818 510454	YULIYA ZAYCEVA	{"email": "zayceva_yuliya_1974@postgrespro.ru", "phone": "+70965259620"}
0005435078105	37B026	3468 346681	PETR NOVIKOV	{"email": "novikovpetr021961@postgrespro.ru", "phone": "+70282193392"}
0005435078106	90801B	5709 295587	POLINA LOGINOVA	{"phone": "+70711116647"}
0005435078107	BC707D	4313 616483	LYUBOV ZAYCEVA	{"phone": "+70780535828"}
0005435078108	A0BB07	0672 846619	SVETLANA SMIRNOVA	{"email": "s_smirnova_051965@postgrespro.ru", "phone": "+70003335002"}
0005435078109	87BF35	9492 709527	EGOR MIKHAYLOV	{"phone": "+70122837918"}
0005435078110	0E598C	3133 195492	MARIYA NOVIKOVA	{"phone": "+70448397897"}
0005435078111	0E598C	7429 368949	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.021970@postgrespro.ru", "phone": "+70672829393"}
0005435078112	0E598C	5253 456283	OLEG KUZNECOV	{"email": "oleg_kuznecov_1976@postgrespro.ru", "phone": "+70824580965"}
0005435078113	8694AE	8325 795157	VALERIY KOROLEV	{"email": "korolev-valeriy_31071963@postgrespro.ru", "phone": "+70302861531"}
0005435078114	7D0BEB	1313 791527	NIKITA MIRONOV	{"phone": "+70695653229"}
0005435078115	87913E	5798 207846	SERGEY SOKOLOV	{"email": "s-sokolov_1976@postgrespro.ru", "phone": "+70264491168"}
0005435078116	67CB30	0086 423539	MARINA ANISIMOVA	{"phone": "+70630025710"}
0005435078117	0E5073	0608 226439	VIKTOR POPOV	{"email": "popov_viktor.081977@postgrespro.ru", "phone": "+70540495137"}
0005435078118	0E5073	4771 822245	VERA ILINA	{"phone": "+70518855129"}
0005435078119	2437C2	9961 186653	MARIYA MAKAROVA	{"email": "makarovam-031971@postgrespro.ru", "phone": "+70419594315"}
0005435078120	53500C	5331 348515	NATALYA SERGEEVA	{"phone": "+70139546082"}
0005435078121	53500C	9820 589818	POLINA MELNIKOVA	{"email": "melnikova-p-29101977@postgrespro.ru", "phone": "+70630264805"}
0005435078122	364F39	9547 585438	NADEZHDA BORISOVA	{"phone": "+70607906967"}
0005435078123	364F39	7178 521803	NADEZHDA FADEEVA	{"phone": "+70490000112"}
0005435078124	6B1095	8985 774776	KARINA POPOVA	{"email": "karina-popova-011964@postgrespro.ru", "phone": "+70369094655"}
0005435078125	627EE2	8361 164390	ZOYA KULIKOVA	{"email": "zoyakulikova_1978@postgrespro.ru", "phone": "+70074527531"}
0005435078126	625DFF	6227 142080	NINA ZAKHAROVA	{"email": "zakharova.n_051969@postgrespro.ru", "phone": "+70923671339"}
0005435078127	625DFF	1834 746933	INNA TITOVA	{"phone": "+70799192633"}
0005435078128	B7B2F9	2727 564625	LYUDMILA SEMENOVA	{"phone": "+70715627516"}
0005435078129	B7B2F9	5650 673296	NIKOLAY STEPANOV	{"phone": "+70430298744"}
0005435078130	FA12CB	5651 471235	EVGENIY PAVLOV	{"phone": "+70717096210"}
0005435078131	FA12CB	1502 107813	MATRENA SOROKINA	{"email": "sorokina-matrena.091962@postgrespro.ru", "phone": "+70837297662"}
0005435078132	69D2FA	4008 944453	SVETLANA VOROBEVA	{"email": "vorobeva.s.071976@postgrespro.ru", "phone": "+70142077003"}
0005435078133	A589B3	3092 914092	DARYA ZAYCEVA	{"email": "daryazayceva-23061963@postgrespro.ru", "phone": "+70760848648"}
0005435078134	A589B3	1291 324157	VLADIMIR KUZNECOV	{"email": "kuznecov_v1987@postgrespro.ru", "phone": "+70929272469"}
0005435078135	C701A9	5178 052684	YURIY NIKITIN	{"email": "y-nikitin_071970@postgrespro.ru", "phone": "+70867826413"}
0005435078136	C701A9	6974 916246	GALINA KONOVALOVA	{"email": "g.konovalova-17081975@postgrespro.ru", "phone": "+70047431424"}
0005435078137	0EA699	7182 073191	GENNADIY KUZNECOV	{"email": "kuznecov_g1972@postgrespro.ru", "phone": "+70550732310"}
0005435078138	E39C1B	8172 983197	DMITRIY ROMANOV	{"phone": "+70532322404"}
0005435078139	EE49A5	6019 869487	SERGEY MOISEEV	{"email": "moiseev.s.121971@postgrespro.ru", "phone": "+70797834410"}
0005435078140	EE49A5	2636 764107	MIKHAIL TARASOV	{"email": "tarasov.mikhail-1967@postgrespro.ru", "phone": "+70143343694"}
0005435078141	EE49A5	5864 175984	IVAN VOLKOV	{"email": "ivolkov-011983@postgrespro.ru", "phone": "+70670256832"}
0005435078142	79B126	1768 711013	NATALYA KAZAKOVA	{"email": "n.kazakova_051978@postgrespro.ru", "phone": "+70750503316"}
0005435078143	6CCC6A	5848 465351	EKATERINA MELNIKOVA	{"phone": "+70871560581"}
0005435078144	702AAA	0106 495234	NATALYA MOROZOVA	{"email": "n-morozova1972@postgrespro.ru", "phone": "+70072114944"}
0005435078145	DBD36B	1428 715745	TATYANA ALEKSANDROVA	{"phone": "+70555290666"}
0005435078146	188C0A	2411 420337	IRINA GRISHINA	{"phone": "+70203986523"}
0005435078147	DF08AA	4061 509378	ALEKSANDR MELNIKOV	{"phone": "+70439389515"}
0005435078148	39D35A	8427 308004	ALEKSANDR KULIKOV	{"phone": "+70165307204"}
0005435078149	39D35A	9855 379493	MIKHAIL SERGEEV	{"phone": "+70976974276"}
0005435078150	F53FE8	1547 154328	OLGA MIKHAYLOVA	{"phone": "+70352773363"}
0005435078151	7AC50B	5288 918681	NATALYA DANILOVA	{"phone": "+70676551680"}
0005435078152	78DF50	3666 518881	SALAVAT SMIRNOV	{"email": "smirnovsalavat.041968@postgrespro.ru", "phone": "+70539866598"}
0005435078153	78DF50	7812 383413	YULIYA FROLOVA	{"email": "frolovay.09091968@postgrespro.ru", "phone": "+70248772974"}
0005435078154	335FF2	9772 345261	SERGEY BELOV	{"email": "belovs_1972@postgrespro.ru", "phone": "+70972231853"}
0005435078155	10A141	3200 446696	ANASTASIYA GAVRILOVA	{"phone": "+70390931952"}
0005435078156	92942C	4647 778049	OLGA ALEKSEEVA	{"email": "alekseeva_o.1978@postgrespro.ru", "phone": "+70318193409"}
0005435078157	92942C	2995 123087	ANTONINA ANDREEVA	{"phone": "+70117412225"}
0005435078158	D40BC4	3818 070741	TATYANA KUZNECOVA	{"phone": "+70677885705"}
0005435078159	25A5C0	8543 579194	LARISA LUKYANOVA	{"email": "lukyanova.l-021970@postgrespro.ru", "phone": "+70923769647"}
0005435078160	407A9E	4235 642424	LYUDMILA DAVYDOVA	{"phone": "+70687832952"}
0005435078161	407A9E	4692 088979	SERGEY MARTYNOV	{"phone": "+70922623823"}
0005435078162	9808AB	5208 976364	YURIY MIKHAYLOV	{"email": "ymikhaylov.06091979@postgrespro.ru", "phone": "+70312724382"}
0005435078163	CFF8C2	0808 694896	DMITRIY SCHERBAKOV	{"email": "d_scherbakov-08081973@postgrespro.ru", "phone": "+70168311738"}
0005435078164	CFF8C2	9155 829887	PAVEL STEPANOV	{"phone": "+70306063569"}
0005435078165	CFF8C2	5418 587616	YURIY ZHURAVLEV	{"email": "zhuravlev-y1961@postgrespro.ru", "phone": "+70886618199"}
0005435078166	D1D090	5156 484209	SVETLANA FOMINA	{"email": "fomina_svetlana_1969@postgrespro.ru", "phone": "+70761087097"}
0005435078167	D1D090	9591 687668	LYUDMILA ORLOVA	{"phone": "+70144288512"}
0005435078168	7AFB16	8148 078965	GENNADIY ZHURAVLEV	{"email": "zhuravlev-gennadiy26111987@postgrespro.ru", "phone": "+70732791264"}
0005435078169	7AFB16	1108 888886	NIKOLAY IVANOV	{"email": "n_ivanov1967@postgrespro.ru", "phone": "+70469559930"}
0005435078170	61B8D1	7464 689956	OLGA LEBEDEVA	{"phone": "+70364634931"}
0005435078171	61B8D1	9761 857773	LYUDMILA MAKAROVA	{"email": "makarova_lyudmila.20051974@postgrespro.ru", "phone": "+70187295127"}
0005435078172	997A1A	3859 409869	ELENA KISELEVA	{"phone": "+70369510054"}
0005435078173	942CB2	9108 023623	MAKSIM KUZNECOV	{"email": "m_kuznecov-1970@postgrespro.ru", "phone": "+70160762887"}
0005435078174	A0F937	9516 656485	VLADISLAV MIKHAYLOV	{"email": "vladislav_mikhaylov1975@postgrespro.ru", "phone": "+70705412528"}
0005435078175	192D9A	6700 463232	ALEKSANDR MIKHAYLOV	{"phone": "+70550948042"}
0005435078176	9C9986	8254 177562	MARIYA SERGEEVA	{"phone": "+70594055286"}
0005435078177	245CDA	9652 966671	VYACHESLAV SOKOLOV	{"email": "v.sokolov_031971@postgrespro.ru", "phone": "+70395361706"}
0005435078178	814BEB	6220 153581	DMITRIY BELOV	{"email": "dmitriybelov_061968@postgrespro.ru", "phone": "+70005154233"}
0005435078179	814BEB	2985 507509	YULIYA ANDREEVA	{"email": "andreeva_yuliya-1976@postgrespro.ru", "phone": "+70547723351"}
0005435078180	A6803F	8397 083403	ELVIRA AFANASEVA	{"phone": "+70460606052"}
0005435078181	A6803F	4310 692233	ELENA RYABOVA	{"email": "eryabova_25121970@postgrespro.ru", "phone": "+70929329342"}
0005435078182	A6803F	7863 988878	VITALIY VOLKOV	{"email": "vitaliyvolkov.20111974@postgrespro.ru", "phone": "+70662304780"}
0005435078183	A6803F	8344 684374	MARIYA PETROVA	{"email": "petrovamariya1964@postgrespro.ru", "phone": "+70255260714"}
0005435078184	6DB657	4536 608313	TATYANA DANILOVA	{"email": "t_danilova.101973@postgrespro.ru", "phone": "+70826107366"}
0005435078185	764FA6	1778 272601	ANATOLIY STEPANOV	{"email": "stepanov_anatoliy.06111960@postgrespro.ru", "phone": "+70436490275"}
0005435078186	764FA6	0326 171281	LYUDMILA ZAYCEVA	{"email": "zaycevalyudmila-05041986@postgrespro.ru", "phone": "+70746915471"}
0005435078187	571535	3786 963562	EKATERINA SEMENOVA	{"phone": "+70748934838"}
0005435078188	571535	1310 761152	LILIYA GRISHINA	{"email": "l_grishina.051978@postgrespro.ru", "phone": "+70612149387"}
0005435078189	1892EF	8997 208765	VALENTINA KONOVALOVA	{"email": "valentinakonovalova111974@postgrespro.ru", "phone": "+70790520693"}
0005435078190	4FB055	6655 222501	MARK NAZAROV	{"email": "nazarov_m_17031959@postgrespro.ru", "phone": "+70096445236"}
0005435078191	A7C47E	7285 237914	DMITRIY SMIRNOV	{"email": "smirnov.d-051977@postgrespro.ru", "phone": "+70334247375"}
0005435078192	A7C47E	3337 453219	NADEZHDA ROMANOVA	{"email": "nromanova-26081977@postgrespro.ru", "phone": "+70785204843"}
0005435078193	F9F733	2842 107847	VYACHESLAV MAKAROV	{"email": "v.makarov1968@postgrespro.ru", "phone": "+70376462655"}
0005435078194	F9F733	4053 694353	NINA KUZNECOVA	{"phone": "+70957921557"}
0005435078195	598FDC	0222 274855	NAILYA KUZMINA	{"email": "n-kuzmina_1966@postgrespro.ru", "phone": "+70417468738"}
0005435078196	450F98	3628 412042	ALEKSEY SAVELEV	{"phone": "+70984956746"}
0005435078197	450F98	4260 458665	ALEKSEY SCHERBAKOV	{"phone": "+70270055908"}
0005435078198	A94DC0	3837 184808	ELENA EGOROVA	{"phone": "+70701567118"}
0005435078199	951D02	5572 952803	ALEKSANDR SHEVCHENKO	{"email": "ashevchenko-031973@postgrespro.ru", "phone": "+70993160290"}
0005435078200	7D243F	7071 458407	ANASTASIYA DENISOVA	{"phone": "+70302032507"}
0005435078201	29ABBE	5152 562255	ELENA KOROLEVA	{"email": "elena_koroleva_30081979@postgrespro.ru", "phone": "+70056766235"}
0005435078202	29ABBE	5214 625183	ELENA POLYAKOVA	{"email": "e-polyakova.05011973@postgrespro.ru", "phone": "+70182854646"}
0005435078203	BF11D3	9097 425956	VYACHESLAV GRIGOREV	{"phone": "+70913632433"}
0005435078204	C019FD	4427 213094	EKATERINA GERASIMOVA	{"phone": "+70000622712"}
0005435078205	073CDE	9626 863757	DIANA ERMAKOVA	{"email": "ermakova.d-1976@postgrespro.ru", "phone": "+70961472290"}
0005435078206	5CEACB	3383 964418	VALERIY GAVRILOV	{"email": "gavrilov.valeriy-111963@postgrespro.ru", "phone": "+70479142241"}
0005435078207	FE26CA	8735 571162	ALEKSEY VOLKOV	{"email": "alekseyvolkov_091973@postgrespro.ru", "phone": "+70606969583"}
0005435078208	91B160	7794 258544	ROMAN MAKAROV	{"email": "rmakarov101974@postgrespro.ru", "phone": "+70926654217"}
0005435078209	91B160	5190 231597	MAKSIM ZAKHAROV	{"phone": "+70359613680"}
0005435078210	4F3EDC	5417 969932	ANNA RYABOVA	{"email": "anna.ryabova_1960@postgrespro.ru", "phone": "+70301606928"}
0005435078211	4F3EDC	0998 668257	OKSANA EFREMOVA	{"phone": "+70030102948"}
0005435078212	C53A46	2834 316543	NADEZHDA ALEKSANDROVA	{"email": "n_aleksandrova_1969@postgrespro.ru", "phone": "+70855207440"}
0005435078213	239DFE	8352 676724	LYUDMILA DMITRIEVA	{"email": "dmitrieva-l081970@postgrespro.ru", "phone": "+70622123035"}
0005435078214	E3A130	8249 949189	POLINA GERASIMOVA	{"phone": "+70660053348"}
0005435078215	E3A130	4436 006607	FEDOR KOROLEV	{"email": "f_korolev.1983@postgrespro.ru", "phone": "+70526337066"}
0005435078216	A19A39	2977 699151	ANATOLIY MEDVEDEV	{"email": "medvedev-a_051970@postgrespro.ru", "phone": "+70398126631"}
0005435078217	256BEC	1000 310238	OLGA AKIMOVA	{"email": "olga_akimova_10121965@postgrespro.ru", "phone": "+70103154349"}
0005435078218	1BA32C	2847 363179	BORIS MELNIKOV	{"email": "melnikov-boris.10021967@postgrespro.ru", "phone": "+70064943887"}
0005435078219	79983C	0892 049738	ANDREY KOZLOV	{"phone": "+70946948334"}
0005435078220	79983C	9631 366250	IGOR MAKAROV	{"email": "i-makarov-051959@postgrespro.ru", "phone": "+70892364218"}
0005435078221	BFA862	0691 280689	DMITRIY CHERNOV	{"phone": "+70504787756"}
0005435078277	E096A6	9921 454529	NINA NIKOLAEVA	{"phone": "+70963129247"}
0005435078222	BFA862	9839 088516	NATALYA ROMANOVA	{"email": "natalyaromanova-08121973@postgrespro.ru", "phone": "+70264991985"}
0005435078223	973B84	4555 839193	SABINA IVANOVA	{"email": "ivanova-sabina1972@postgrespro.ru", "phone": "+70775255653"}
0005435078224	AB63BC	6949 747053	SERGEY VOLKOV	{"phone": "+70696960030"}
0005435078225	AB63BC	4822 982588	GLEB ZHURAVLEV	{"email": "zhuravlev_g1961@postgrespro.ru", "phone": "+70694578590"}
0005435078226	AB63BC	7845 438513	TATYANA GRISHINA	{"phone": "+70568490350"}
0005435078227	1246FE	9815 675268	EVGENIYA VASILEVA	{"phone": "+70902356583"}
0005435078228	449FB4	1049 216116	ANDREY KAZAKOV	{"email": "a_kazakov.26011977@postgrespro.ru", "phone": "+70210506949"}
0005435078229	449FB4	8851 524464	ANATOLIY POPOV	{"email": "a_popov-1976@postgrespro.ru", "phone": "+70846331762"}
0005435078230	9D9D3F	1138 290510	RAMIL RODIONOV	{"email": "r.rodionov-1971@postgrespro.ru", "phone": "+70369401884"}
0005435078231	9D9D3F	8502 148728	VITALIY ILIN	{"email": "v_ilin-20081968@postgrespro.ru", "phone": "+70231124658"}
0005435078232	6B5722	3310 961550	ALEKSANDR DMITRIEV	{"email": "aleksandr-dmitriev101975@postgrespro.ru", "phone": "+70842986876"}
0005435078233	6B5722	6904 113980	ANATOLIY ROMANOV	{"email": "romanovanatoliy.111975@postgrespro.ru", "phone": "+70266329572"}
0005435078234	6B5722	0528 913793	TATYANA SMIRNOVA	{"email": "tatyana_smirnova.01081979@postgrespro.ru", "phone": "+70588340880"}
0005435078235	7D2C4D	0547 290098	KLAVDIYA GORBUNOVA	{"phone": "+70593919651"}
0005435078236	7D2C4D	4001 405831	ANASTASIYA ZAYCEVA	{"email": "zaycevaanastasiya-071974@postgrespro.ru", "phone": "+70216602718"}
0005435078237	DC69F4	1047 238948	ILMIR ALEKSANDROV	{"email": "i.aleksandrov.19051958@postgrespro.ru", "phone": "+70211960309"}
0005435078238	B0C8B4	4948 195094	MARIYA EGOROVA	{"phone": "+70798005184"}
0005435078239	C983D3	4055 643768	GALINA SIDOROVA	{"email": "g.sidorova-1977@postgrespro.ru", "phone": "+70098986334"}
0005435078240	CD1C59	1156 283625	KONSTANTIN MOROZOV	{"phone": "+70063630784"}
0005435078241	3E07D7	2088 179489	TATYANA ZAYCEVA	{"email": "tatyana.zayceva15111969@postgrespro.ru", "phone": "+70621515448"}
0005435078242	0CC2C6	6774 475373	SERGEY ALEKSEEV	{"email": "sergey_alekseev081973@postgrespro.ru", "phone": "+70777924638"}
0005435078243	5947C5	2982 097515	ANDREY BONDARENKO	{"email": "andreybondarenko-051986@postgrespro.ru", "phone": "+70847819068"}
0005435078244	5947C5	9984 985934	YULIYA ALEKSANDROVA	{"email": "aleksandrova-y_1967@postgrespro.ru", "phone": "+70996154131"}
0005435078245	FDF337	3758 144669	ANASTASIYA FEDOROVA	{"email": "fedorova_anastasiya.30061981@postgrespro.ru", "phone": "+70133652220"}
0005435078246	3A2ECA	6825 733907	NADEZHDA ROMANOVA	{"email": "romanova-n-27121967@postgrespro.ru", "phone": "+70624459502"}
0005435078247	3A2ECA	0888 248278	ALEKSANDR KUZNECOV	{"email": "kuznecova-09031967@postgrespro.ru", "phone": "+70263350271"}
0005435078248	E51CB3	7878 935001	VYACHESLAV TIKHONOV	{"phone": "+70259167196"}
0005435078249	F3F194	5716 009704	DMITRIY SEMENOV	{"phone": "+70109423373"}
0005435078250	F3F194	1464 217832	MARIYA NAZAROVA	{"email": "mariyanazarova_20101971@postgrespro.ru", "phone": "+70543878640"}
0005435078251	997FA0	6614 683749	VALERIY MOISEEV	{"phone": "+70929800888"}
0005435078252	997FA0	3757 900987	EKATERINA VOLKOVA	{"phone": "+70377418310"}
0005435078253	997FA0	6133 807612	SERGEY SCHERBAKOV	{"phone": "+70008436936"}
0005435078254	05C113	8684 997740	ELIZAVETA MAKAROVA	{"phone": "+70330997575"}
0005435078255	FAF268	3263 135657	NATALYA GORBUNOVA	{"email": "natalya_gorbunova_25021975@postgrespro.ru", "phone": "+70841856895"}
0005435078256	FAF268	6412 868439	OLGA DMITRIEVA	{"email": "dmitrieva_o.061969@postgrespro.ru", "phone": "+70981121729"}
0005435078257	FCC3B0	5590 494507	PETR DAVYDOV	{"email": "davydov-petr-11031964@postgrespro.ru", "phone": "+70160030904"}
0005435078258	4476E2	8977 441828	ELENA KOZLOVA	{"phone": "+70808667028"}
0005435078259	4F6AAB	2707 906403	NATALYA BORISOVA	{"phone": "+70168402308"}
0005435078260	06A334	3450 988760	MIKHAIL POPOV	{"phone": "+70027319397"}
0005435078261	06A334	3054 810851	VYACHESLAV ZAKHAROV	{"email": "vyacheslav_zakharov.051962@postgrespro.ru", "phone": "+70014914570"}
0005435078262	304377	4564 696054	IGOR MARTYNOV	{"email": "igor-martynov-1965@postgrespro.ru", "phone": "+70780281882"}
0005435078263	F0A1D2	9789 969094	ALEKSANDR SOROKIN	{"email": "sorokin-a.12011979@postgrespro.ru", "phone": "+70311202398"}
0005435078264	DD039F	4684 775833	ALFIYA MEDVEDEVA	{"phone": "+70731019066"}
0005435078265	DD039F	6238 956961	SERGEY ANTONOV	{"phone": "+70442743522"}
0005435078266	7C7C44	8589 609157	OLESYA RODIONOVA	{"email": "rodionova_olesya-1969@postgrespro.ru", "phone": "+70904672352"}
0005435078267	7C7C44	7153 884736	SERGEY BORISOV	{"phone": "+70925670919"}
0005435078268	27A435	5664 197637	VLADIMIR GORBUNOV	{"email": "gorbunovv-01061965@postgrespro.ru", "phone": "+70888923192"}
0005435078269	27A435	0593 501046	FARIT KISELEV	{"phone": "+70837988772"}
0005435078270	83CC02	1097 233393	NAIL KAZAKOV	{"phone": "+70947236990"}
0005435078271	83CC02	2234 066926	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr071968@postgrespro.ru", "phone": "+70276189597"}
0005435078272	78F3A1	0226 284369	FATIMA PETROVA	{"email": "petrova.f_121967@postgrespro.ru", "phone": "+70057256245"}
0005435078273	18314F	4135 241440	MARIYA OVCHINNIKOVA	{"email": "mariya_ovchinnikova.07101977@postgrespro.ru", "phone": "+70893793381"}
0005435078274	69E520	5698 795378	IGOR DENISOV	{"phone": "+70764097208"}
0005435078275	E096A6	8386 172038	ALEKSANDRA LOGINOVA	{"phone": "+70128893577"}
0005435078276	E096A6	1127 740134	OLEG KRASNOV	{"email": "krasnovo-1975@postgrespro.ru", "phone": "+70747056199"}
0005435078278	E096A6	3113 594841	ALEKSANDRA DAVYDOVA	{"email": "aleksandradavydova_13061972@postgrespro.ru", "phone": "+70813462860"}
0005435078279	12B1D6	6600 784636	LYUBOV MOISEEVA	{"phone": "+70553508936"}
0005435078280	6927F7	9476 574592	STEPAN NIKITIN	{"phone": "+70268705466"}
0005435078281	DF2930	0006 223854	IRINA STEPANOVA	{"email": "stepanova.irina_091967@postgrespro.ru", "phone": "+70380055954"}
0005435078282	91B030	6968 664019	TAMARA KOROLEVA	{"email": "koroleva_tamara_1964@postgrespro.ru", "phone": "+70882602029"}
0005435078283	217378	3825 619918	SERGEY DAVYDOV	{"phone": "+70612050609"}
0005435078284	0D967B	9773 784578	TATYANA TIKHONOVA	{"email": "t_tikhonova1977@postgrespro.ru", "phone": "+70315809418"}
0005435078285	D30364	3009 064400	SVETLANA AKIMOVA	{"email": "akimova.s.081979@postgrespro.ru", "phone": "+70683357338"}
0005435078286	D30364	0935 017830	ALESYA ARKHIPOVA	{"phone": "+70681382176"}
0005435078287	C43BA7	7543 567609	TATYANA NIKIFOROVA	{"email": "nikiforova.t.041968@postgrespro.ru", "phone": "+70473023111"}
0005435078288	515B45	4576 569189	OLGA VOLKOVA	{"phone": "+70439351063"}
0005435078289	3F52B3	8100 750746	VALENTINA FOMINA	{"email": "fominavalentina_011977@postgrespro.ru", "phone": "+70447902757"}
0005435078290	3A20E4	1174 108128	ARINA KOROLEVA	{"phone": "+70692157860"}
0005435078291	208B66	5746 589059	KARINA EGOROVA	{"phone": "+70255029245"}
0005435078292	C33581	0231 220587	ALEKSANDR KOZLOV	{"email": "kozlov.a.061969@postgrespro.ru", "phone": "+70435441855"}
0005435078293	CE3736	1788 982040	EGOR SMIRNOV	{"email": "egor-smirnov1962@postgrespro.ru", "phone": "+70403739803"}
0005435078294	CE3736	2618 527888	RUMIYA KALININA	{"phone": "+70163221345"}
0005435078295	E0D755	1420 735598	OLGA TITOVA	{"email": "titova.olga.18121979@postgrespro.ru", "phone": "+70054349230"}
0005435078296	2380D0	1424 636051	IVAN IVANOV	{"email": "ivan-ivanov-031968@postgrespro.ru", "phone": "+70142283330"}
0005435078297	B4D19F	3299 488629	OLGA MAKAROVA	{"phone": "+70349059242"}
0005435078298	B4D19F	3249 477312	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr.25021977@postgrespro.ru", "phone": "+70601680624"}
0005435078299	B35473	0995 707614	IRINA RYABOVA	{"phone": "+70370638566"}
0005435078300	81DE4E	6139 661733	LYUDMILA KOMAROVA	{"phone": "+70490311741"}
0005435078301	81DE4E	1593 729103	ALEKSEY ALEKSANDROV	{"email": "alekseyaleksandrov07121980@postgrespro.ru", "phone": "+70109741950"}
0005435078302	3E487D	2618 073493	NIKITA VOLKOV	{"email": "nvolkov.25091965@postgrespro.ru", "phone": "+70066990010"}
0005435078303	3E487D	1486 497401	RAISA KAZAKOVA	{"phone": "+70463529201"}
0005435078304	2CD504	1719 564784	ELENA PETROVA	{"phone": "+70495933309"}
0005435078305	64647E	5241 945939	RUSLAN TIMOFEEV	{"email": "r_timofeev-061965@postgrespro.ru", "phone": "+70754245365"}
0005435078306	407A47	2577 919251	GALINA ANDREEVA	{"email": "galina-andreeva-1975@postgrespro.ru", "phone": "+70325264429"}
0005435078307	B846CF	6212 342806	SVETLANA FEDOROVA	{"email": "fedorova-s.061972@postgrespro.ru", "phone": "+70045460716"}
0005435078308	B846CF	0696 673128	DMITRIY ALEKSEEV	{"email": "dmitriyalekseev-26091974@postgrespro.ru", "phone": "+70419601089"}
0005435078309	C47871	2222 459049	ELENA KAZAKOVA	{"email": "kazakova-elena.121986@postgrespro.ru", "phone": "+70990371313"}
0005435078310	EFF154	7692 719919	INNA ISAEVA	{"email": "inna_isaeva21051979@postgrespro.ru", "phone": "+70138513477"}
0005435078311	EFD97F	2847 388029	MAKSIM GAVRILOV	{"email": "maksim.gavrilov081974@postgrespro.ru", "phone": "+70163556241"}
0005435078312	EFD97F	2471 752361	DAVID DMITRIEV	{"phone": "+70981634082"}
0005435078313	0E0E85	2843 675783	VIKTORIYA POPOVA	{"email": "popovaviktoriya-101965@postgrespro.ru", "phone": "+70429627168"}
0005435078314	BF6089	7312 796142	LYUDMILA BORISOVA	{"phone": "+70402592908"}
0005435078315	991332	0950 193969	VLADIMIR KARPOV	{"email": "karpov-vladimir_111971@postgrespro.ru", "phone": "+70083115143"}
0005435078316	3E05C4	3296 135174	ALINA KULIKOVA	{"email": "kulikova_a-1976@postgrespro.ru", "phone": "+70045717801"}
0005435078317	3E05C4	8987 271712	NADEZHDA BORISOVA	{"email": "n-borisova07101989@postgrespro.ru", "phone": "+70745433002"}
0005435078318	2FF8E4	2596 197120	NIKITA ZHURAVLEV	{"email": "zhuravlev.nikita011974@postgrespro.ru", "phone": "+70075390655"}
0005435078319	B45C01	4933 422607	IVAN KUZNECOV	{"email": "ivankuznecov17041971@postgrespro.ru", "phone": "+70521794257"}
0005435078320	E78DBF	9362 390085	ANTONINA KOROLEVA	{"email": "a-koroleva21081963@postgrespro.ru", "phone": "+70050186647"}
0005435078321	E78DBF	0698 608569	MIKHAIL SHEVCHENKO	{"phone": "+70846555252"}
0005435078322	492AE4	6350 842392	VALENTINA TIKHONOVA	{"email": "vtikhonova.20021963@postgrespro.ru", "phone": "+70482294554"}
0005435078323	492AE4	1344 256035	SERGEY MOISEEV	{"phone": "+70358695738"}
0005435078324	B999F7	1588 531648	MAKSIM MOROZOV	{"phone": "+70201549031"}
0005435078325	66812D	6367 088867	VIKTORIYA PAVLOVA	{"phone": "+70418592579"}
0005435078326	2BB252	8911 283168	NADEZHDA KONDRATEVA	{"phone": "+70147782614"}
0005435078327	2BB252	9191 972433	SERGEY TARASOV	{"phone": "+70070067513"}
0005435078328	24232F	6078 300493	VLADIMIR SIDOROV	{"email": "vladimir_sidorov101960@postgrespro.ru", "phone": "+70644296541"}
0005435078329	24232F	2048 441022	ANATOLIY KAZAKOV	{"phone": "+70053173491"}
0005435078330	BD5E3E	0878 983083	NATALYA ORLOVA	{"email": "orlova-natalya111961@postgrespro.ru", "phone": "+70465716212"}
0005435078331	BD5E3E	3137 665361	NINA AKIMOVA	{"email": "nakimova111979@postgrespro.ru", "phone": "+70793112040"}
0005435078332	3EB644	8165 175530	ELENA KARPOVA	{"email": "karpova.e_1960@postgrespro.ru", "phone": "+70664204412"}
0005435078333	3EB644	0416 868863	MIKHAIL FEDOROV	{"email": "mikhail.fedorov10111969@postgrespro.ru", "phone": "+70786199398"}
0005435078334	9F2EE5	2671 124814	PAVEL RODIONOV	{"email": "p_rodionov.09111968@postgrespro.ru", "phone": "+70021987619"}
0005435078335	3F22E5	4491 832207	SOFYA EGOROVA	{"email": "s_egorova_011982@postgrespro.ru", "phone": "+70798708955"}
0005435078336	A3B43B	8793 374704	ANNA NIKITINA	{"email": "a_nikitina081973@postgrespro.ru", "phone": "+70105613727"}
0005435078337	78F8FE	9977 202828	EGOR ZHURAVLEV	{"email": "zhuravlev-egor.091977@postgrespro.ru", "phone": "+70759114416"}
0005435078338	78F8FE	9928 298297	RUSLAN YAKOVLEV	{"phone": "+70412211387"}
0005435078339	56AC88	0961 002698	RINAT SCHERBAKOV	{"email": "scherbakovrinat1968@postgrespro.ru", "phone": "+70070128485"}
0005435078340	56AC88	0804 825794	ROMAN MATVEEV	{"phone": "+70082954305"}
0005435078341	9AF1B5	7473 748986	VIKTOR ALEKSEEV	{"email": "viktor-alekseev_091967@postgrespro.ru", "phone": "+70221838778"}
0005435078342	9AF1B5	7036 565245	VERA TIKHONOVA	{"phone": "+70483841092"}
0005435078343	67BC21	7658 745108	VALENTINA ZAYCEVA	{"phone": "+70999688802"}
0005435078344	79F20A	0886 924107	YULIYA SERGEEVA	{"phone": "+70579612845"}
0005435078345	79F20A	2783 397494	ALEKSEY VOLKOV	{"email": "volkov_a.051975@postgrespro.ru", "phone": "+70184239675"}
0005435078346	582745	8476 719253	DMITRIY PETROV	{"phone": "+70631774121"}
0005435078347	582745	1756 321285	NATALIYA SMIRNOVA	{"email": "n_smirnova-061978@postgrespro.ru", "phone": "+70043454741"}
0005435078348	DB1B58	7178 006628	REGINA MOISEEVA	{"email": "moiseeva-regina.15081980@postgrespro.ru", "phone": "+70021859991"}
0005435078349	A4AD00	3095 315192	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova-1968@postgrespro.ru", "phone": "+70134368602"}
0005435078350	5BE7F7	2396 397487	ZOYA KOZLOVA	{"phone": "+70040663344"}
0005435078351	3AEC11	3719 267589	ALEKSANDR KULIKOV	{"phone": "+70247193806"}
0005435078352	DCA21F	5632 196130	ANDREY VOROBEV	{"email": "vorobev.a031964@postgrespro.ru", "phone": "+70019678847"}
0005435078353	424BC9	3493 598898	MARIYA VOROBEVA	{"phone": "+70275203167"}
0005435078354	D270CC	9104 069772	ALEKSANDR TIKHONOV	{"phone": "+70879655138"}
0005435078355	D270CC	5471 155116	IGOR GUSEV	{"email": "igor-gusev22051973@postgrespro.ru", "phone": "+70551745896"}
0005435078356	A172CE	4891 640041	VIKTORIYA VOROBEVA	{"email": "v_vorobeva071974@postgrespro.ru", "phone": "+70776308818"}
0005435078357	A172CE	8096 461958	NIKOLAY FROLOV	{"phone": "+70912405014"}
0005435078358	36FAEA	1103 970763	TAMARA KUZMINA	{"email": "kuzmina-t_1949@postgrespro.ru", "phone": "+70502654460"}
0005435078359	AB299F	8935 123977	IGOR SERGEEV	{"phone": "+70482540532"}
0005435078360	AB299F	7893 642015	MARINA ANTONOVA	{"phone": "+70577105018"}
0005435078361	3D1CC2	8692 830359	GALINA POLYAKOVA	{"email": "polyakovagalina-02121968@postgrespro.ru", "phone": "+70721108366"}
0005435078362	46F185	8114 246429	YULIYA VOLKOVA	{"email": "volkova-yuliya28061964@postgrespro.ru", "phone": "+70079108488"}
0005435078363	019DAE	3296 597213	GENNADIY AFANASEV	{"email": "afanasev.gennadiy.061981@postgrespro.ru", "phone": "+70729449405"}
0005435078364	8AA18A	1281 250877	MAKSIM AFANASEV	{"email": "maksim_afanasev111981@postgrespro.ru", "phone": "+70434240642"}
0005435078365	8AA18A	4510 818085	LYUDMILA TARASOVA	{"phone": "+70482836360"}
0005435078366	A71774	4259 421511	ANDREY MIKHAYLOV	{"email": "a.mikhaylov.101965@postgrespro.ru", "phone": "+70757776673"}
0005435078367	A71774	7763 609340	ALEKSEY CHERNOV	{"phone": "+70336603900"}
0005435078368	FF6608	1606 117328	VALENTINA POPOVA	{"email": "popova-valentina-1972@postgrespro.ru", "phone": "+70389599133"}
0005435078369	EA716A	7406 941234	TATYANA SOROKINA	{"phone": "+70262090726"}
0005435078370	EA716A	0182 903929	VLADIMIR GORBUNOV	{"email": "gorbunovv.03101971@postgrespro.ru", "phone": "+70982982223"}
0005435078371	EA716A	1468 323962	VIKTORIYA TIKHONOVA	{"email": "tikhonova-viktoriya_05121961@postgrespro.ru", "phone": "+70384195889"}
0005435078372	D22390	6560 451547	DARINA NIKITINA	{"phone": "+70386998283"}
0005435078373	ED8286	0753 242327	TATYANA ALEKSANDROVA	{"email": "taleksandrova.14091955@postgrespro.ru", "phone": "+70121791485"}
0005435078374	4533CE	0356 531945	GEORGIY DAVYDOV	{"email": "davydov-georgiy.061977@postgrespro.ru", "phone": "+70047982031"}
0005435078375	43A542	6561 974576	ROMAN CHERNOV	{"email": "r.chernov.1972@postgrespro.ru", "phone": "+70893050180"}
0005435078376	0F8192	8796 497379	IRINA EFIMOVA	{"phone": "+70467241480"}
0005435078377	0F8192	1048 183629	ANTONINA ZAYCEVA	{"phone": "+70542330690"}
0005435078378	DF56FB	5135 436926	ARTEM SCHERBAKOV	{"email": "a.scherbakov.1964@postgrespro.ru", "phone": "+70262838833"}
0005435078379	33AB3C	8538 388881	DANIIL STEPANOV	{"email": "d.stepanov_1969@postgrespro.ru", "phone": "+70218049696"}
0005435078380	6EAD90	6429 771979	YULIYA KOROLEVA	{"email": "koroleva.y.1963@postgrespro.ru", "phone": "+70256499565"}
0005435078381	6EAD90	4393 087456	OLGA RYABOVA	{"phone": "+70066963110"}
0005435078382	B84573	3972 149738	YURIY NAUMOV	{"phone": "+70796926644"}
0005435078383	1C5B75	6581 655001	STANISLAV KOZLOV	{"email": "kozlovs1957@postgrespro.ru", "phone": "+70501471298"}
0005435078384	1C5B75	8499 421707	FARIDA KOROLEVA	{"email": "faridakoroleva-111961@postgrespro.ru", "phone": "+70406856289"}
0005435078385	5419AC	4569 437632	TATYANA MATVEEVA	{"email": "matveeva-t.1969@postgrespro.ru", "phone": "+70774949436"}
0005435078386	5419AC	5799 670245	MARGARITA MAKAROVA	{"email": "makarova.m19101966@postgrespro.ru", "phone": "+70825195819"}
0005435078387	6AA8EA	8436 739186	LARISA TIKHONOVA	{"email": "tikhonovalarisa-071971@postgrespro.ru", "phone": "+70586901511"}
0005435078388	C740CD	2061 417460	DENIS ALEKSEEV	{"phone": "+70478391048"}
0005435078389	441C51	4306 772751	VADIM EGOROV	{"phone": "+70670488879"}
0005435078390	441C51	9047 952649	NIKOLAY RODIONOV	{"phone": "+70464563862"}
0005435078391	D33FA8	4158 167650	SVETLANA CHERNOVA	{"email": "chernova_s_08081977@postgrespro.ru", "phone": "+70961844518"}
0005435078392	D33FA8	7018 015407	ANVAR FILIPPOV	{"email": "a-filippov_28091972@postgrespro.ru", "phone": "+70048509017"}
0005435078393	805D71	2523 954179	EGOR ISAEV	{"email": "egorisaev-1975@postgrespro.ru", "phone": "+70357442954"}
0005435078394	805D71	7014 063985	VALERIY VOLKOV	{"phone": "+70358525482"}
0005435078395	D2E724	0436 110968	ANNA ROMANOVA	{"email": "annaromanova_011966@postgrespro.ru", "phone": "+70366069589"}
0005435078396	9C93E9	4462 428217	TAMARA VOROBEVA	{"email": "vorobevat_17031971@postgrespro.ru", "phone": "+70149785134"}
0005435078397	9C93E9	4340 221150	VALERIY MOROZOV	{"email": "v-morozov11081958@postgrespro.ru", "phone": "+70110644485"}
0005435078398	9C93E9	6825 170910	INNA BORISOVA	{"phone": "+70722249218"}
0005435078399	EAA75D	5066 896876	TATYANA SEMENOVA	{"phone": "+70954667236"}
0005435078400	AD913A	0716 087742	NIKOLAY GRIGOREV	{"email": "grigorev-nikolay.30031978@postgrespro.ru", "phone": "+70211263584"}
0005435078401	3E7DBC	8238 568192	SERGEY MAKAROV	{"phone": "+70769630033"}
0005435078402	3E7DBC	9272 048650	EGOR GORBUNOV	{"phone": "+70820206899"}
0005435078403	6D7E08	5820 692771	NIKITA BELOV	{"phone": "+70231671704"}
0005435078404	6D7E08	6528 079577	DARYA FADEEVA	{"email": "fadeeva_darya_051966@postgrespro.ru", "phone": "+70160737038"}
0005435078405	DA8911	0363 389251	VLADIMIR IVANOV	{"email": "vladimir-ivanov041960@postgrespro.ru", "phone": "+70880603707"}
0005435078406	DA8911	7886 376004	ALEKSANDR VOLKOV	{"phone": "+70721514279"}
0005435078407	AD0D4A	0543 596450	GALINA POTAPOVA	{"phone": "+70831491682"}
0005435078408	81B4C5	6596 814384	GENNADIY ROMANOV	{"phone": "+70496416723"}
0005435078409	67CB18	5520 798524	OLGA NESTEROVA	{"email": "nesterovao_071979@postgrespro.ru", "phone": "+70566283999"}
0005435078410	7E8C65	9555 698293	NINA VASILEVA	{"phone": "+70834110357"}
0005435078411	7F735F	4598 109563	RAISA EFREMOVA	{"email": "efremova-raisa_13111964@postgrespro.ru", "phone": "+70693205258"}
0005435078412	2B7869	4400 508324	TATYANA ALEKSEEVA	{"phone": "+70155633907"}
0005435078413	2B7869	9996 237498	ELVIRA SEMENOVA	{"email": "e-semenova_1974@postgrespro.ru", "phone": "+70233237080"}
0005435078414	EFD781	8314 394700	MAKSIM SMIRNOV	{"phone": "+70839790331"}
0005435078415	EFD781	9131 803235	NIKOLAY VASILEV	{"phone": "+70997174244"}
0005435078416	944ADD	1846 872564	ELENA KONOVALOVA	{"email": "konovalova_elena.1983@postgrespro.ru", "phone": "+70602158886"}
0005435078417	944ADD	9913 211237	VIKTOR KULIKOV	{"phone": "+70352307212"}
0005435078418	F09E98	6152 959133	IRINA KOROLEVA	{"phone": "+70838422735"}
0005435078419	1E673B	7855 689926	IRINA MIKHAYLOVA	{"email": "irinamikhaylova_071975@postgrespro.ru", "phone": "+70147790010"}
0005435078420	1E673B	4267 681338	OLGA ANDREEVA	{"phone": "+70328526333"}
0005435078421	1E673B	4733 645609	ALEKSANDR MAKSIMOV	{"email": "maksimov-a-081973@postgrespro.ru", "phone": "+70219350220"}
0005435078422	5DAE30	7922 290276	GALINA FROLOVA	{"email": "g-frolova_11071969@postgrespro.ru", "phone": "+70091989993"}
0005435078423	8B1B2E	1871 354361	NIKITA GAVRILOV	{"phone": "+70884181198"}
0005435078424	8B1B2E	0524 768602	MARINA MAKSIMOVA	{"email": "marina.maksimova-03091973@postgrespro.ru", "phone": "+70034487211"}
0005435078425	BD2906	9081 622280	VALENTINA BORISOVA	{"email": "valentina_borisova.091964@postgrespro.ru", "phone": "+70373239807"}
0005435078426	BD2906	0335 296143	ANATOLIY ROMANOV	{"phone": "+70244452780"}
0005435078427	BD2906	9580 010062	IVAN PAVLOV	{"phone": "+70898543812"}
0005435078428	AB361B	8119 678354	ANDREY KUDRYASHOV	{"email": "andrey.kudryashov.101960@postgrespro.ru", "phone": "+70118930899"}
0005435078429	C36D08	3096 551895	KONSTANTIN SEMENOV	{"phone": "+70777247123"}
0005435078430	877E83	3104 842628	MARIYA MOROZOVA	{"email": "mariya.morozova.1974@postgrespro.ru", "phone": "+70844935811"}
0005435078431	5FEACE	2781 526125	VALERIYA KOVALEVA	{"email": "valeriyakovaleva-1971@postgrespro.ru", "phone": "+70766822771"}
0005435078432	5FEACE	2006 102056	ELENA BORISOVA	{"phone": "+70797610955"}
0005435078433	687942	8083 632110	ZOYA KOZLOVA	{"phone": "+70331052742"}
0005435078434	687942	3576 720823	VALERIY AFANASEV	{"email": "valeriy_afanasev_02021980@postgrespro.ru", "phone": "+70753772795"}
0005435078435	687942	3104 760287	EGOR GERASIMOV	{"email": "gerasimov_e_081982@postgrespro.ru", "phone": "+70963824692"}
0005435078436	81EB16	2898 301447	NIKOLAY POPOV	{"phone": "+70944250585"}
0005435078437	81EB16	8884 865376	ANNA ZAYCEVA	{"email": "azayceva_19031978@postgrespro.ru", "phone": "+70109147217"}
0005435078438	81EB16	6930 910860	ANATOLIY OSIPOV	{"email": "anatoliy.osipov.05041974@postgrespro.ru", "phone": "+70608167774"}
0005435078439	7EB574	4596 195183	DMITRIY MIKHAYLOV	{"email": "mikhaylov_dmitriy-24051967@postgrespro.ru", "phone": "+70565145652"}
0005435078440	495626	1709 718482	MARGARITA SAVELEVA	{"email": "m_saveleva.031966@postgrespro.ru", "phone": "+70020709614"}
0005435078441	495626	7371 580151	MARIYA ZAKHAROVA	{"phone": "+70404023376"}
0005435078442	A87045	8797 424698	ARINA VOLKOVA	{"email": "volkova.arina-111972@postgrespro.ru", "phone": "+70071831527"}
0005435078443	5EABF9	4132 215761	EGOR ZAKHAROV	{"email": "e_zakharov1975@postgrespro.ru", "phone": "+70373279990"}
0005435078444	32CE34	8988 985451	ANDREY MELNIKOV	{"email": "a.melnikov-1955@postgrespro.ru", "phone": "+70784444173"}
0005435078445	32CE34	8882 228793	YURIY SERGEEV	{"phone": "+70818542903"}
0005435078446	8AD0B8	4241 146191	TATYANA ERMAKOVA	{"email": "termakova.06101969@postgrespro.ru", "phone": "+70547276304"}
0005435078447	130D21	7035 032604	IVAN KONOVALOV	{"email": "konovalov.ivan-1967@postgrespro.ru", "phone": "+70049192320"}
0005435078448	8B582A	4354 570436	LYUBOV BORISOVA	{"email": "borisova_l_1971@postgrespro.ru", "phone": "+70148964842"}
0005435078449	8B582A	7833 342564	NATALYA SMIRNOVA	{"email": "smirnovan_06011980@postgrespro.ru", "phone": "+70945223696"}
0005435078450	38BFF4	5465 211092	ANASTASIYA IVANOVA	{"phone": "+70168548250"}
0005435078451	38BFF4	7684 665333	TAMARA ARKHIPOVA	{"email": "arkhipovatamara1985@postgrespro.ru", "phone": "+70648383010"}
0005435078452	202111	4720 742757	ALEKSANDR STEPANOV	{"email": "a.stepanov-18051968@postgrespro.ru", "phone": "+70476154523"}
0005435078453	46AB54	1291 136260	ANNA VLASOVA	{"email": "vlasovaa-071975@postgrespro.ru", "phone": "+70361622699"}
0005435078454	E2A64A	4507 006190	ALEKSANDR ZAKHAROV	{"phone": "+70534017957"}
0005435078455	E2A64A	4589 481501	YULIYA ILINA	{"email": "ilinay-011967@postgrespro.ru", "phone": "+70178474103"}
0005435078456	47D93D	5624 490583	VLADIMIR FROLOV	{"phone": "+70591743965"}
0005435078457	97DB56	4852 707442	SERGEY TIMOFEEV	{"email": "sergey-timofeev111972@postgrespro.ru", "phone": "+70653339618"}
0005435078458	97DB56	6873 842854	NINA KONDRATEVA	{"email": "nkondrateva10101977@postgrespro.ru", "phone": "+70208083074"}
0005435078459	A94DB6	4608 473059	ANATOLIY ZHURAVLEV	{"phone": "+70980376934"}
0005435078460	6BAF12	9437 213778	ALEKSEY EGOROV	{"email": "egorov.a.26081970@postgrespro.ru", "phone": "+70996497181"}
0005435078461	9E64BE	0502 330055	DENIS ROMANOV	{"email": "denisromanov-051978@postgrespro.ru", "phone": "+70587185401"}
0005435078462	B6D023	8209 846055	LYUBOV KOLESNIKOVA	{"email": "kolesnikova.l.1975@postgrespro.ru", "phone": "+70582764367"}
0005435078463	2ADE18	7520 395583	VLADIMIR TIMOFEEV	{"email": "timofeev.vladimir_011981@postgrespro.ru", "phone": "+70343612501"}
0005435078464	AE316B	1635 302254	NATALYA MAKAROVA	{"phone": "+70483695354"}
0005435078465	78DDFE	0222 549025	ALEKSANDR GAVRILOV	{"phone": "+70517086018"}
0005435078466	FCAC17	1973 414197	ANGELINA KUZNECOVA	{"email": "kuznecova.a-1965@postgrespro.ru", "phone": "+70307267482"}
0005435078467	F6386E	7344 345768	ALEKSEY VOLKOV	{"email": "aleksey-volkov.1971@postgrespro.ru", "phone": "+70604657475"}
0005435078468	342689	1876 850375	DMITRIY BELOV	{"phone": "+70659209744"}
0005435078469	342689	9420 782946	GALINA BOGDANOVA	{"phone": "+70271316187"}
0005435078470	AE7530	5960 822414	YULIYA MOROZOVA	{"phone": "+70703743959"}
0005435078471	AE7530	9362 789483	ANNA TIKHONOVA	{"email": "tikhonovaa1976@postgrespro.ru", "phone": "+70228655944"}
0005435078472	A5B298	5555 333030	VALERIY VASILEV	{"email": "vasilev-valeriy-27081981@postgrespro.ru", "phone": "+70951068163"}
0005435078473	7F1B05	3745 045178	VLADIMIR SOROKIN	{"email": "v-sorokin_21011978@postgrespro.ru", "phone": "+70100188630"}
0005435078474	44E2F1	9652 286007	ARTEM MAKAROV	{"email": "makarov.artem_1974@postgrespro.ru", "phone": "+70731994201"}
0005435078475	0EEDAE	6208 895181	ANASTASIYA SOKOLOVA	{"phone": "+70525217899"}
0005435078476	8C6864	1877 410044	RAISA BORISOVA	{"phone": "+70528766627"}
0005435078477	E58184	0568 123534	OLGA NIKITINA	{"phone": "+70090918030"}
0005435078478	E58184	5509 309044	NINA SERGEEVA	{"email": "sergeeva.nina_15051972@postgrespro.ru", "phone": "+70740839945"}
0005435078479	E58184	6958 005358	SVETLANA NIKITINA	{"phone": "+70570246455"}
0005435078480	2D3D27	3545 993493	IVAN AFANASEV	{"email": "ivan-afanasev_1975@postgrespro.ru", "phone": "+70772934047"}
0005435078481	94C0FA	3655 083562	ANDREY BORISOV	{"email": "andrey.borisov_041981@postgrespro.ru", "phone": "+70390118390"}
0005435078482	D35F5B	9965 637077	ALEKSANDR KUDRYASHOV	{"phone": "+70882657537"}
0005435078483	D35F5B	8987 908433	VLADIMIR ZAKHAROV	{"phone": "+70143220956"}
0005435078484	7E3349	1705 094161	ALEKSANDR DMITRIEV	{"email": "dmitriev_a08011977@postgrespro.ru", "phone": "+70493121329"}
0005435078485	AA58B4	9077 076268	SERGEY YAKOVLEV	{"phone": "+70235379701"}
0005435078486	AA58B4	4398 439986	DMITRIY VLASOV	{"phone": "+70531943477"}
0005435078487	9F6786	2394 515556	ALMIRA AFANASEVA	{"email": "almira_afanaseva051972@postgrespro.ru", "phone": "+70818108467"}
0005435078488	32DC5F	7475 149974	PAVEL ZHUKOV	{"email": "pavel-zhukov02041971@postgrespro.ru", "phone": "+70019154313"}
0005435078489	32DC5F	3022 988684	OLGA MIRONOVA	{"phone": "+70746766561"}
0005435078490	B7C571	1998 506113	OLGA NESTEROVA	{"email": "onesterova_071980@postgrespro.ru", "phone": "+70599642926"}
0005435078491	04954C	5318 202988	ILYA KOZLOV	{"phone": "+70526901142"}
0005435078492	3E8F51	4543 575012	EVGENIY SCHERBAKOV	{"phone": "+70260258955"}
0005435078493	48BC78	6258 210413	SERGEY SMIRNOV	{"email": "smirnov.sergey-091964@postgrespro.ru", "phone": "+70551862626"}
0005435078494	DD3467	2603 718311	VLADIMIR MAKAROV	{"email": "v_makarov16051977@postgrespro.ru", "phone": "+70803215221"}
0005435078495	16379E	4397 019600	DMITRIY GAVRILOV	{"phone": "+70391712068"}
0005435078496	C791BA	2852 236391	ULYANA NOVIKOVA	{"phone": "+70423211057"}
0005435078497	84B836	5175 295799	VYACHESLAV ANDREEV	{"phone": "+70731962149"}
0005435078498	BCAC70	1935 918494	VALENTINA NOVIKOVA	{"email": "novikovav.23031969@postgrespro.ru", "phone": "+70431333676"}
0005435078499	F5FE91	4392 124945	KIRILL VLASOV	{"email": "k_vlasov12011981@postgrespro.ru", "phone": "+70388972576"}
0005435078500	4D3837	0670 586521	MAKSIM KUZNECOV	{"email": "maksim-kuznecov.1984@postgrespro.ru", "phone": "+70397929597"}
0005435078501	4D3837	5022 659020	VARVARA SOKOLOVA	{"phone": "+70214453774"}
0005435078502	5529A8	0779 555039	ARINA PETROVA	{"email": "petrova.arina051966@postgrespro.ru", "phone": "+70780219870"}
0005435078503	5529A8	0726 724185	ANASTASIYA PAVLOVA	{"phone": "+70270212974"}
0005435078504	46210B	2971 756173	MARK SOROKIN	{"phone": "+70739220818"}
0005435078505	5DC8A4	6239 466874	VIKTORIYA NIKITINA	{"phone": "+70703464470"}
0005435078506	148F27	1240 865379	MATVEY DMITRIEV	{"phone": "+70575850920"}
0005435078507	148F27	5220 878020	EDUARD SMIRNOV	{"phone": "+70730723045"}
0005435078508	49C37F	7463 471892	IRINA KULIKOVA	{"email": "kulikova_irina_1977@postgrespro.ru", "phone": "+70843586090"}
0005435078509	49C37F	9698 388301	IRINA SOKOLOVA	{"phone": "+70408119410"}
0005435078510	49C37F	1991 214820	ANTON KUDRYASHOV	{"phone": "+70044840818"}
0005435078511	DBFFC9	0468 470546	LYUBOV BELOVA	{"phone": "+70326596781"}
0005435078512	5195CD	4818 119425	VLADIMIR SMIRNOV	{"email": "vladimirsmirnov_21101978@postgrespro.ru", "phone": "+70141858641"}
0005435078513	F35F99	6407 046025	ELENA ZAYCEVA	{"phone": "+70545030433"}
0005435078514	F35F99	8500 881160	GENNADIY VASILEV	{"phone": "+70328427960"}
0005435078515	F35F99	9092 082691	RUSTYAM MEDVEDEV	{"email": "medvedev_rustyam_1975@postgrespro.ru", "phone": "+70383678851"}
0005435078516	552489	1987 551142	ALEKSANDRA EGOROVA	{"email": "aegorova.061972@postgrespro.ru", "phone": "+70044477757"}
0005435078517	A748C3	7803 851242	ALEKSANDR ANTONOV	{"email": "aantonov1955@postgrespro.ru", "phone": "+70943252636"}
0005435078518	A748C3	8763 724062	GRIGORIY YAKOVLEV	{"email": "grigoriy_yakovlev-101984@postgrespro.ru", "phone": "+70521243755"}
0005435078519	F51DEE	4624 258729	MARGARITA KUDRYASHOVA	{"phone": "+70470502411"}
0005435078520	D02EB6	0341 838796	EKATERINA KUZNECOVA	{"email": "e-kuznecova.011975@postgrespro.ru", "phone": "+70411974542"}
0005435078521	D02EB6	8142 651814	OLGA BORISOVA	{"phone": "+70519328499"}
0005435078522	944FAF	0504 653670	VLADIMIR IVANOV	{"email": "vladimirivanov-1975@postgrespro.ru", "phone": "+70393488403"}
0005435078523	944FAF	9392 366279	VERA FILATOVA	{"email": "filatova-v_1975@postgrespro.ru", "phone": "+70712266909"}
0005435078524	BA5DEF	8126 555949	MAKSIM SEMENOV	{"email": "msemenov10121959@postgrespro.ru", "phone": "+70514251177"}
0005435078525	BA5DEF	7441 265007	NURIYA YAKOVLEVA	{"phone": "+70327392166"}
0005435078526	307FB7	5569 566680	ALEKSEY FROLOV	{"phone": "+70053976034"}
0005435078527	35C66F	3930 457434	ALINA MIKHAYLOVA	{"phone": "+70517176742"}
0005435078528	12BFCC	0463 999702	VALERIY KRASNOV	{"email": "valeriy_krasnov-021971@postgrespro.ru", "phone": "+70257007859"}
0005435078529	058E51	3814 922144	GRIGORIY KUZNECOV	{"email": "gkuznecov_1979@postgrespro.ru", "phone": "+70404753783"}
0005435078530	DCBE2E	9069 369151	ALEKSEY ISAEV	{"email": "aleksey.isaev.041966@postgrespro.ru", "phone": "+70297260339"}
0005435078531	DCBE2E	0503 784648	OLGA CHERNOVA	{"phone": "+70402804609"}
0005435078532	DB0EF7	4366 693817	ALEKSEY ANTONOV	{"email": "a-antonov-12111964@postgrespro.ru", "phone": "+70774508341"}
0005435078533	DB0EF7	7529 745131	ELENA ALEKSANDROVA	{"phone": "+70260788110"}
0005435078534	58AD72	3814 297320	YULIYA POPOVA	{"phone": "+70430785627"}
0005435078535	2E0A4A	7606 265217	OKSANA ANDREEVA	{"email": "andreeva-oksana081969@postgrespro.ru", "phone": "+70398432306"}
0005435078536	2F5DD6	4790 691065	ANDREY ILIN	{"phone": "+70459057895"}
0005435078537	9A81D2	4987 420922	NATALYA GORBUNOVA	{"email": "natalya.gorbunova.21101976@postgrespro.ru", "phone": "+70165943548"}
0005435078538	02C962	0549 552021	ANDREY MELNIKOV	{"phone": "+70044205473"}
0005435078539	FE5FCF	7173 664685	OLGA SIDOROVA	{"email": "o.sidorova.1974@postgrespro.ru", "phone": "+70072507635"}
0005435078540	FE5FCF	6990 218767	RAISA SERGEEVA	{"phone": "+70796657337"}
0005435078541	F43154	3096 247894	ALEKSANDRA FILATOVA	{"phone": "+70979644200"}
0005435078542	F43154	4794 810215	MARIYA IVANOVA	{"email": "ivanova.m-20081980@postgrespro.ru", "phone": "+70797163316"}
0005435078543	BE0609	0877 545991	MARAT MAKAROV	{"email": "mmakarov-041974@postgrespro.ru", "phone": "+70433163038"}
0005435078544	008441	6737 545539	YULIYA KUZNECOVA	{"phone": "+70061706626"}
0005435078545	31DCCF	4890 572471	ELENA GORBUNOVA	{"email": "gorbunovaelena-24021983@postgrespro.ru", "phone": "+70706098712"}
0005435078546	E4AF6B	0268 810832	NATALYA KUZNECOVA	{"email": "kuznecova_n31121958@postgrespro.ru", "phone": "+70647246771"}
0005435078547	307D58	0934 179755	VITALIY SIDOROV	{"email": "vsidorov28081972@postgrespro.ru", "phone": "+70137149764"}
0005435078548	9429B8	5028 753013	STANISLAV KOZLOV	{"phone": "+70727331162"}
0005435078549	DF74E0	9134 485489	IRINA AKIMOVA	{"email": "iakimova031984@postgrespro.ru", "phone": "+70964478476"}
0005435078550	767B56	9151 223951	SERGEY POPOV	{"email": "sergey_popov.011979@postgrespro.ru", "phone": "+70456442179"}
0005435078551	767B56	1909 036342	LYUBOV MOROZOVA	{"email": "lyubovmorozova.101973@postgrespro.ru", "phone": "+70123149963"}
0005435078552	317BC9	6200 099604	NATALYA IVANOVA	{"email": "ivanovan.041968@postgrespro.ru", "phone": "+70182410440"}
0005435078553	317BC9	5066 020543	POLINA MARTYNOVA	{"email": "martynova.p11061964@postgrespro.ru", "phone": "+70822696315"}
0005435078554	B86290	9585 897233	ZHANNA KUZMINA	{"phone": "+70272397596"}
0005435078555	64624A	9236 207953	OLGA EFIMOVA	{"email": "oefimova1969@postgrespro.ru", "phone": "+70129568384"}
0005435078556	30BDF1	2865 304862	GRIGORIY GRIGOREV	{"phone": "+70583835017"}
0005435078557	30BDF1	5256 894304	SERGEY KUZMIN	{"email": "kuzmins-1964@postgrespro.ru", "phone": "+70819979800"}
0005435078558	30BDF1	0942 136389	IVAN FROLOV	{"email": "i.frolov-30121967@postgrespro.ru", "phone": "+70483664066"}
0005435078559	C68839	0019 504641	KARINA TROFIMOVA	{"email": "trofimova_karina_011974@postgrespro.ru", "phone": "+70978630280"}
0005435078560	C68839	6031 265050	MATVEY VOROBEV	{"email": "m.vorobev-091972@postgrespro.ru", "phone": "+70175477486"}
0005435078561	E08037	2901 346764	VALENTINA GORBUNOVA	{"email": "v.gorbunova_15101970@postgrespro.ru", "phone": "+70347074968"}
0005435078562	E08037	7405 426878	TATYANA OSIPOVA	{"email": "osipova-t021979@postgrespro.ru", "phone": "+70745704219"}
0005435078563	A1EAE5	5660 919339	VYACHESLAV AFANASEV	{"phone": "+70705996293"}
0005435078564	F2169E	1957 596260	TATYANA MAKAROVA	{"phone": "+70406816655"}
0005435078565	88D315	6006 347324	ANASTASIYA ANDREEVA	{"phone": "+70847430058"}
0005435078566	88D315	1387 936458	OLGA BELOVA	{"email": "olgabelova_091971@postgrespro.ru", "phone": "+70375787491"}
0005435078567	80569B	3923 471749	ALEKSEY SCHERBAKOV	{"phone": "+70253747319"}
0005435078568	64BE1A	8902 957398	VLADIMIR BORISOV	{"phone": "+70806306786"}
0005435078569	64BE1A	2349 195743	LYUDMILA ZHUKOVA	{"email": "l-zhukova19101969@postgrespro.ru", "phone": "+70573538948"}
0005435078570	121040	7974 097832	IGOR CHERNOV	{"email": "chernovigor-25071961@postgrespro.ru", "phone": "+70564706083"}
0005435078571	DA838B	6993 688496	NADEZHDA SAVELEVA	{"email": "saveleva_n-15041970@postgrespro.ru", "phone": "+70450223891"}
0005435078572	74F4B3	6789 899198	VALENTIN KISELEV	{"phone": "+70106781578"}
0005435078573	5EA508	4828 730923	VLADIMIR MOROZOV	{"phone": "+70541308416"}
0005435078574	624E9F	7181 736232	EVGENIY MAKAROV	{"phone": "+70816367918"}
0005435078575	206AF7	8527 395800	ALEKSANDR MATVEEV	{"phone": "+70710427710"}
0005435078576	597586	2035 487267	LIDIYA OVCHINNIKOVA	{"phone": "+70008504331"}
0005435078577	597586	4800 357014	VALERIY VASILEV	{"phone": "+70631889172"}
0005435078578	927CE9	6458 018097	IRINA TITOVA	{"email": "irina_titova.111977@postgrespro.ru", "phone": "+70716060881"}
0005435078579	27DF3D	5602 128576	VLADIMIR FROLOV	{"email": "frolov.v.031980@postgrespro.ru", "phone": "+70031481565"}
0005435078580	933B4A	3318 870736	ALEKSEY DAVYDOV	{"phone": "+70776253024"}
0005435078581	9ADBE2	6831 200275	VIKTOR VOROBEV	{"phone": "+70646756165"}
0005435078582	105D72	0945 893315	SERGEY MIRONOV	{"phone": "+70444284638"}
0005435078583	105D72	7202 720098	MAKSIM ROMANOV	{"email": "m_romanov_061976@postgrespro.ru", "phone": "+70558876808"}
0005435078584	4EDA34	4443 265307	ALEKSANDR KUDRYASHOV	{"phone": "+70832652459"}
0005435078585	4EDA34	5338 091043	OLEG GUSEV	{"email": "o-gusev.1970@postgrespro.ru", "phone": "+70400723436"}
0005435078586	E62FA8	3862 921842	MARIYA TROFIMOVA	{"email": "m.trofimova061964@postgrespro.ru", "phone": "+70962608050"}
0005435078587	E62FA8	5864 248337	VERA YAKOVLEVA	{"phone": "+70716953652"}
0005435078588	A796C2	0529 284298	NATALYA FILIPPOVA	{"email": "filippova.natalya1968@postgrespro.ru", "phone": "+70281220578"}
0005435078589	CB32D5	9766 572296	VLADIMIR KUZMIN	{"phone": "+70052221506"}
0005435078590	31F78C	4942 753485	NINA BOGDANOVA	{"phone": "+70558909984"}
0005435078591	BC68A9	9923 904700	SULTAN ILIN	{"email": "sultanilin_121978@postgrespro.ru", "phone": "+70893174631"}
0005435078592	4D6AF3	4893 898528	DMITRIY TIMOFEEV	{"phone": "+70728045389"}
0005435078593	4D6AF3	3473 467863	ALBINA SAVELEVA	{"email": "albina_saveleva-02051979@postgrespro.ru", "phone": "+70148819497"}
0005435078594	4D6AF3	8924 016471	NATALYA BELOVA	{"phone": "+70444984385"}
0005435078595	8D0EBB	8631 379835	PAVEL EGOROV	{"email": "p-egorov-1973@postgrespro.ru", "phone": "+70033861132"}
0005435078596	7A6B65	3786 534479	ALEKSANDR SERGEEV	{"email": "asergeev071970@postgrespro.ru", "phone": "+70004198833"}
0005435078597	5908E5	6874 113520	LYUDMILA MATVEEVA	{"phone": "+70584193626"}
0005435078598	20B558	5442 460539	SERGEY ROMANOV	{"email": "romanov_s_1972@postgrespro.ru", "phone": "+70896559455"}
0005435078599	20B558	6133 824369	ALEKSANDR TIKHONOV	{"phone": "+70627316873"}
0005435078600	20B558	6327 560665	DMITRIY SIDOROV	{"email": "sidorovd.041975@postgrespro.ru", "phone": "+70870230148"}
0005435078601	924199	2598 185595	OLEG ALEKSEEV	{"email": "oleg_alekseev091976@postgrespro.ru", "phone": "+70479518195"}
0005435078602	68D770	7674 196860	IRINA MOROZOVA	{"phone": "+70565189021"}
0005435078603	68D770	8693 213979	GRIGORIY MEDVEDEV	{"email": "gmedvedev-041981@postgrespro.ru", "phone": "+70452250413"}
0005435078604	68D770	6279 372334	GRIGORIY SOKOLOV	{"email": "sokolov.grigoriy-1981@postgrespro.ru", "phone": "+70320229184"}
0005435078605	78C5E3	0447 560303	SERGEY PAVLOV	{"email": "pavlov_sergey.1968@postgrespro.ru", "phone": "+70692623524"}
0005435078606	78C5E3	6505 046865	ALEKSEY FROLOV	{"phone": "+70410541036"}
0005435078607	E942B3	2961 032805	ANNA MELNIKOVA	{"email": "melnikova-anna-08031973@postgrespro.ru", "phone": "+70497782400"}
0005435078608	BDAF23	4225 837043	EKATERINA VASILEVA	{"email": "e.vasileva_1964@postgrespro.ru", "phone": "+70905256982"}
0005435078609	BDAF23	6245 893778	PAVEL MIKHAYLOV	{"email": "mikhaylov.p_14081980@postgrespro.ru", "phone": "+70305774304"}
0005435078610	C49F07	6390 329159	VIKTOR EGOROV	{"phone": "+70079182655"}
0005435078611	0D11B8	2012 055808	SVETLANA POPOVA	{"email": "svetlana.popova.111972@postgrespro.ru", "phone": "+70462218164"}
0005435078612	0A566A	4395 355253	VITALIY KUZNECOV	{"email": "kuznecovvitaliy1978@postgrespro.ru", "phone": "+70557803145"}
0005435078613	F1D553	9079 208364	EVGENIYA ROMANOVA	{"email": "e-romanova-061983@postgrespro.ru", "phone": "+70006543114"}
0005435078614	155574	0390 168211	GRIGORIY KONOVALOV	{"phone": "+70726337833"}
0005435078615	155574	0947 533903	SERGEY POPOV	{"phone": "+70849597277"}
0005435078616	6CD992	2689 774839	ANTON VASILEV	{"phone": "+70746212703"}
0005435078617	6CD992	9689 829072	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.t.031975@postgrespro.ru", "phone": "+70309723168"}
0005435078618	8614E5	0922 109001	VIKTOR KUZNECOV	{"phone": "+70253859147"}
0005435078619	092CF4	7107 012279	EGOR ANDREEV	{"email": "e.andreev.091975@postgrespro.ru", "phone": "+70932545534"}
0005435078620	8DFE2F	0096 840009	DMITRIY KONOVALOV	{"phone": "+70036600278"}
0005435078621	B717BE	8651 313766	IRINA SMIRNOVA	{"phone": "+70585878626"}
0005435078622	4E5E51	3463 553867	NIKOLAY MOROZOV	{"email": "nikolay_morozov-29111969@postgrespro.ru", "phone": "+70520639961"}
0005435078623	56BE5F	0493 730433	LYUDMILA TITOVA	{"phone": "+70521047836"}
0005435078624	56BE5F	6550 441702	IRINA FEDOROVA	{"email": "fedorova_i_041967@postgrespro.ru", "phone": "+70907795587"}
0005435078625	166890	6681 065176	YULIYA SOROKINA	{"email": "sorokina-y.041964@postgrespro.ru", "phone": "+70647710712"}
0005435078626	166890	9691 919958	ANDREY FOMIN	{"phone": "+70264930798"}
0005435078627	6F90FC	5138 473468	ALEKSANDR IVANOV	{"email": "ivanov-a.25071968@postgrespro.ru", "phone": "+70415997456"}
0005435078628	39C078	5281 835759	KSENIYA RYABOVA	{"email": "ryabova_k.071979@postgrespro.ru", "phone": "+70856933918"}
0005435078629	39C078	3996 213586	ANTONINA NIKITINA	{"phone": "+70899434061"}
0005435078630	B66F71	4057 298802	PAVEL SEMENOV	{"phone": "+70044785669"}
0005435078631	B66F71	5771 719038	TATYANA IVANOVA	{"email": "tatyanaivanova_1970@postgrespro.ru", "phone": "+70146324992"}
0005435078632	B66F71	5514 503796	VADIM ZAYCEV	{"email": "vadim.zaycev09061978@postgrespro.ru", "phone": "+70765145093"}
0005435078633	F03D9F	9083 311774	ANDREY KOROLEV	{"phone": "+70268092420"}
0005435078634	779276	6853 623503	VLADIMIR ISAEV	{"email": "isaev_v-021967@postgrespro.ru", "phone": "+70075539199"}
0005435078635	2A5BA3	4515 820596	MIKHAIL NAUMOV	{"phone": "+70014416089"}
0005435078636	F8ABD2	6581 738605	NADEZHDA ZAYCEVA	{"email": "zayceva-nadezhda_31031965@postgrespro.ru", "phone": "+70186059151"}
0005435078637	F8ABD2	7460 750065	VASILIY ANDREEV	{"email": "v_andreev091982@postgrespro.ru", "phone": "+70302805984"}
0005435078638	05B7C4	0832 861540	VASILIY CHERNOV	{"phone": "+70204488270"}
0005435078639	79019F	2490 241495	PETR MIRONOV	{"email": "p.mironov19021974@postgrespro.ru", "phone": "+70387117540"}
0005435078640	79019F	3136 108226	NINA ILINA	{"phone": "+70925425027"}
0005435078641	5BF80D	7195 768030	OLGA OSIPOVA	{"phone": "+70780708006"}
0005435078642	52B700	9867 507048	VALERIY KUDRYASHOV	{"email": "kudryashov-v.10091967@postgrespro.ru", "phone": "+70255768552"}
0005435078643	5A028C	7634 622274	VLADISLAV IVANOV	{"email": "vivanov_121956@postgrespro.ru", "phone": "+70556478831"}
0005435078644	5A028C	5579 555452	VIKTOR NIKITIN	{"email": "nikitin.v-21061974@postgrespro.ru", "phone": "+70589480413"}
0005435078645	5A028C	6789 851135	SERGEY BONDARENKO	{"phone": "+70404553844"}
0005435078646	2CA84E	3786 185736	LARISA VASILEVA	{"email": "larisa_vasileva_18021964@postgrespro.ru", "phone": "+70587672011"}
0005435078647	0A6687	5104 981300	LYUBOV POPOVA	{"email": "popova.lyubov_1981@postgrespro.ru", "phone": "+70247959039"}
0005435078648	0A6687	5723 854996	VITALIY PAVLOV	{"email": "vitaliy-pavlov_101966@postgrespro.ru", "phone": "+70478138055"}
0005435078649	2669AA	6810 130795	YURIY MOROZOV	{"phone": "+70519870029"}
0005435078650	22E204	1589 298018	VYACHESLAV KUZNECOV	{"email": "vkuznecov.041971@postgrespro.ru", "phone": "+70499061516"}
0005435078651	22E204	5735 409045	SERGEY DAVYDOV	{"email": "davydov.s_1960@postgrespro.ru", "phone": "+70499349886"}
0005435078652	5D28D8	3251 495618	NATALYA ALEKSEEVA	{"email": "n.alekseeva-091968@postgrespro.ru", "phone": "+70861868098"}
0005435078653	36016F	8318 415458	LARISA PETROVA	{"phone": "+70847257000"}
0005435078654	3C74FA	1729 705400	GENNADIY KRASNOV	{"email": "gennadiy.krasnov-071965@postgrespro.ru", "phone": "+70518326833"}
0005435078655	3C74FA	7068 538511	ANATOLIY MAKAROV	{"phone": "+70812875576"}
0005435078656	E88A0F	8521 253464	IVAN FROLOV	{"email": "i.frolov.051979@postgrespro.ru", "phone": "+70941645897"}
0005435078657	6F18C1	1100 525385	LYUBOV KUZMINA	{"phone": "+70669448457"}
0005435078658	F040E1	3979 679352	ANNA KOROLEVA	{"email": "a_koroleva-04071977@postgrespro.ru", "phone": "+70967098618"}
0005435078659	A27B1F	8713 485114	ANASTASIYA TARASOVA	{"email": "tarasovaa.10021968@postgrespro.ru", "phone": "+70766651450"}
0005435078660	AFCC93	5188 343294	MIKHAIL VASILEV	{"phone": "+70218356474"}
0005435078661	34BCB1	7305 467214	VYACHESLAV ILIN	{"phone": "+70967128245"}
0005435078662	D18AC8	7286 551660	ALEKSEY MEDVEDEV	{"phone": "+70555723249"}
0005435078663	D18AC8	6247 791598	NADEZHDA MEDVEDEVA	{"email": "medvedeva-nadezhda.101968@postgrespro.ru", "phone": "+70929569595"}
0005435078664	2E618D	8755 510423	ALEKSANDR KRASNOV	{"phone": "+70785533276"}
0005435078665	2E618D	5042 072703	GALINA DENISOVA	{"phone": "+70445532744"}
0005435078666	A7A3FF	0086 270368	ALEKSEY FOMIN	{"phone": "+70711872248"}
0005435078667	1B7E5F	8491 134204	ALEKSANDR MAKSIMOV	{"phone": "+70257058327"}
0005435078668	1B7E5F	6413 187852	OLGA CHERNOVA	{"phone": "+70843768490"}
0005435078669	D66B47	4634 355867	ALEKSANDR ISAEV	{"email": "aleksandr_isaev_101962@postgrespro.ru", "phone": "+70052750101"}
0005435078670	60163B	5075 144196	VERA FEDOROVA	{"email": "fedorovav_061970@postgrespro.ru", "phone": "+70575782003"}
0005435078671	8D8F4F	7581 543177	MIKHAIL CHERNOV	{"email": "mikhail.chernov-1976@postgrespro.ru", "phone": "+70075141308"}
0005435078672	8166A4	1969 388500	TATYANA RYABOVA	{"email": "ryabova-tatyana_081979@postgrespro.ru", "phone": "+70964760938"}
0005435078673	8166A4	0381 516459	TAMARA YAKOVLEVA	{"email": "t_yakovleva1985@postgrespro.ru", "phone": "+70032052616"}
0005435078674	43479A	5956 508136	MAKSIM MIRONOV	{"phone": "+70763595566"}
0005435078675	43479A	1658 327697	SVETLANA MAKAROVA	{"phone": "+70817477208"}
0005435078676	2AC594	9640 926468	MARIYA GORBUNOVA	{"email": "mariya-gorbunova.31121983@postgrespro.ru", "phone": "+70921631470"}
0005435078677	653094	7796 818688	NIKOLAY FEDOROV	{"email": "nfedorov-051979@postgrespro.ru", "phone": "+70650703684"}
0005435078678	653094	9712 713777	MARIYA SEMENOVA	{"phone": "+70745254734"}
0005435078679	92B4DB	7218 235522	LYUBOV ALEKSEEVA	{"email": "alekseeva_lyubov1966@postgrespro.ru", "phone": "+70614375272"}
0005435078680	92B4DB	8367 619092	NINA FEDOROVA	{"phone": "+70297583245"}
0005435078681	92B4DB	3508 692882	DMITRIY BARANOV	{"phone": "+70342818761"}
0005435078682	07AFBC	4318 363499	SVETLANA DENISOVA	{"email": "sdenisova_07091970@postgrespro.ru", "phone": "+70190245928"}
0005435078683	07AFBC	6651 844271	ELENA YUDINA	{"email": "yudina_elena1968@postgrespro.ru", "phone": "+70767716514"}
0005435078684	8E2DC5	2264 541695	SERGEY BARANOV	{"phone": "+70230095952"}
0005435078685	8E2DC5	7042 968350	YURIY ZAKHAROV	{"email": "y_zakharov_101986@postgrespro.ru", "phone": "+70918711277"}
0005435078686	B05B4A	1609 734386	OLGA TARASOVA	{"email": "olga_tarasova-021973@postgrespro.ru", "phone": "+70866673425"}
0005435078687	0211F2	5279 341602	SULTAN BORISOV	{"email": "sultan-borisov091980@postgrespro.ru", "phone": "+70639230139"}
0005435078688	0211F2	8775 336617	LIDIYA LUKYANOVA	{"email": "lidiya-lukyanova-1974@postgrespro.ru", "phone": "+70804671984"}
0005435078689	41A794	1571 183625	ALEFTINA NIKOLAEVA	{"email": "nikolaeva.a.16081980@postgrespro.ru", "phone": "+70295518755"}
0005435078690	385B3D	9410 668659	OKSANA SOKOLOVA	{"phone": "+70951169577"}
0005435078691	385B3D	8452 800200	EKATERINA SIDOROVA	{"email": "sidorovae081971@postgrespro.ru", "phone": "+70243221604"}
0005435078692	28F421	8869 926751	RISHAT STEPANOV	{"email": "r_stepanov1971@postgrespro.ru", "phone": "+70325019002"}
0005435078693	53B86F	1272 268008	NIKITA PAVLOV	{"phone": "+70424545478"}
0005435078694	866EA6	5855 154350	SEMEN TIMOFEEV	{"email": "semen-timofeev061973@postgrespro.ru", "phone": "+70638950198"}
0005435078695	32E092	3925 826925	TATYANA AKIMOVA	{"phone": "+70959743165"}
0005435078696	32E092	8145 657390	IGOR SIDOROV	{"phone": "+70889315054"}
0005435078697	E3DFEF	7875 322610	NATALYA STEPANOVA	{"phone": "+70912091430"}
0005435078698	BBFC21	5958 627614	GLEB DMITRIEV	{"email": "dmitrievgleb01091967@postgrespro.ru", "phone": "+70372244017"}
0005435078699	4C53CE	0565 737583	ARTEM VLASOV	{"email": "vlasova_091981@postgrespro.ru", "phone": "+70529105731"}
0005435078700	4C53CE	5295 011945	FARID POPOV	{"email": "f.popov.021974@postgrespro.ru", "phone": "+70156094222"}
0005435078701	67973B	5971 056740	ALEKSANDR KUZMIN	{"phone": "+70004865692"}
0005435078702	BDD425	9328 851046	ELENA TIKHONOVA	{"phone": "+70925203191"}
0005435078703	D969D4	7767 056041	LYUBOV TITOVA	{"phone": "+70670392414"}
0005435078704	DAA0C9	7275 401064	NATALYA SOLOVEVA	{"email": "solovevan.111978@postgrespro.ru", "phone": "+70808077517"}
0005435078705	5AADD9	8413 783496	NIKOLAY CHERNOV	{"email": "chernov_n041971@postgrespro.ru", "phone": "+70767987658"}
0005435078706	5AADD9	8769 984707	ULYANA OSIPOVA	{"phone": "+70127797296"}
0005435078707	5AADD9	6364 399992	VLADISLAV IVANOV	{"email": "ivanovvladislav_19031967@postgrespro.ru", "phone": "+70632960785"}
0005435078708	255BB0	6142 537568	KLARA MELNIKOVA	{"phone": "+70063291291"}
0005435078709	79D154	1622 713470	KLAVDIYA IVANOVA	{"phone": "+70718474004"}
0005435078710	B13F51	4179 002416	IVAN BELOV	{"email": "belov_i_1967@postgrespro.ru", "phone": "+70051601595"}
0005435078711	58CD42	6568 743357	IGOR VOROBEV	{"email": "i.vorobev.12101978@postgrespro.ru", "phone": "+70307040900"}
0005435078712	E18AD2	8350 407168	DAMIR SMIRNOV	{"email": "damir-smirnov.061970@postgrespro.ru", "phone": "+70980935096"}
0005435078713	07B535	0614 907290	RAVZA KOROLEVA	{"email": "r_koroleva_101990@postgrespro.ru", "phone": "+70253101910"}
0005435078714	07B535	6142 959827	VYACHESLAV GERASIMOV	{"email": "gerasimov_v10011966@postgrespro.ru", "phone": "+70861337186"}
0005435078715	07B535	7440 075468	VALENTIN ZAKHAROV	{"email": "v-zakharov-081969@postgrespro.ru", "phone": "+70021692915"}
0005435078716	F5E5E7	7105 322724	VADIM ROMANOV	{"email": "romanov_vadim1988@postgrespro.ru", "phone": "+70709903442"}
0005435078717	C9F5FF	0400 853033	DMITRIY IVANOV	{"email": "divanov_1981@postgrespro.ru", "phone": "+70793426627"}
0005435078718	C9F5FF	4477 904331	KONSTANTIN ZHURAVLEV	{"phone": "+70958586088"}
0005435078719	4843CC	5809 562605	NIKITA IVANOV	{"email": "ivanov.n011973@postgrespro.ru", "phone": "+70598249458"}
0005435078720	4843CC	5746 690808	NATALYA GORBUNOVA	{"phone": "+70567532039"}
0005435078721	4843CC	4042 691474	MAKSIM FOMIN	{"phone": "+70030398538"}
0005435078722	19C7DA	4547 154676	TATYANA PAVLOVA	{"phone": "+70688912250"}
0005435078723	19C7DA	6492 309894	OLGA PETROVA	{"email": "o.petrova-1966@postgrespro.ru", "phone": "+70734041127"}
0005435078724	19C7DA	9854 444629	OLGA ROMANOVA	{"phone": "+70372079032"}
0005435078725	646787	3899 828864	VERA MEDVEDEVA	{"email": "vmedvedeva-1977@postgrespro.ru", "phone": "+70529812734"}
0005435078726	646787	2648 851166	EVGENIY KONOVALOV	{"phone": "+70719691203"}
0005435078727	F3B6A8	7606 057266	VLADIMIR VOROBEV	{"email": "vladimir.vorobev_21041967@postgrespro.ru", "phone": "+70070860067"}
0005435078728	15F6D0	3590 940288	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova-041972@postgrespro.ru", "phone": "+70972497437"}
0005435078729	3A4AF1	0025 904010	NIKITA POPOV	{"phone": "+70142811507"}
0005435078730	3A4AF1	6748 734886	OKSANA MIKHAYLOVA	{"email": "mikhaylova-oksana.021975@postgrespro.ru", "phone": "+70319379959"}
0005435078731	EC1963	0747 361713	MARIANNA KOZLOVA	{"email": "kozlova.m.081967@postgrespro.ru", "phone": "+70351522225"}
0005435078732	FC1EB3	3851 123381	OLGA NIKITINA	{"phone": "+70941916210"}
0005435078733	46ACA0	5234 364063	LEONID SIDOROV	{"email": "lsidorov.1976@postgrespro.ru", "phone": "+70575309247"}
0005435078734	46ACA0	3505 103604	ELIZAVETA DAVYDOVA	{"phone": "+70421917451"}
0005435078735	930C1F	9286 058480	ANASTASIYA YAKOVLEVA	{"email": "yakovlevaa_13111960@postgrespro.ru", "phone": "+70071721188"}
0005435078736	9576FA	6559 764145	ELENA KONOVALOVA	{"phone": "+70280252937"}
0005435078737	9576FA	7810 789293	EKATERINA ORLOVA	{"email": "orlovaekaterina031968@postgrespro.ru", "phone": "+70520273099"}
0005435078738	C35D83	2822 978002	NIKOLAY STEPANOV	{"phone": "+70543452450"}
0005435078739	C35D83	2146 891914	LIDIYA ERMAKOVA	{"email": "ermakova.lidiya-12111976@postgrespro.ru", "phone": "+70504470263"}
0005435078740	C35D83	4921 552237	ADELINA NIKOLAEVA	{"phone": "+70998838925"}
0005435078741	24D88C	3382 475206	IVAN ALEKSANDROV	{"email": "ialeksandrov24121962@postgrespro.ru", "phone": "+70170706632"}
0005435078742	B1182B	9627 572932	SVETLANA KONOVALOVA	{"email": "konovalovasvetlana-1968@postgrespro.ru", "phone": "+70491211673"}
0005435078743	B1182B	0809 103895	DMITRIY RODIONOV	{"email": "rodionov_dmitriy.061972@postgrespro.ru", "phone": "+70270014269"}
0005435078744	D0F02B	8819 858207	RAUF KRASNOV	{"phone": "+70847838435"}
0005435078745	DEC834	1652 611887	PAVEL ZAYCEV	{"email": "p_zaycev-061970@postgrespro.ru", "phone": "+70501743046"}
0005435078746	3E37F3	4542 928919	MURAT NAZAROV	{"email": "nazarovmurat011974@postgrespro.ru", "phone": "+70617152228"}
0005435078747	3E37F3	2172 739328	SVETLANA LOGINOVA	{"email": "loginova_svetlana.031978@postgrespro.ru", "phone": "+70572252016"}
0005435078748	09FC36	3568 972065	ROZA MIKHAYLOVA	{"phone": "+70516736358"}
0005435078749	8012A0	2653 276672	MARINA TARASOVA	{"email": "m_tarasova1976@postgrespro.ru", "phone": "+70231664905"}
0005435078750	83179F	0439 214662	NINA TIKHONOVA	{"email": "tikhonova_nina051979@postgrespro.ru", "phone": "+70146486290"}
0005435078751	83179F	4516 686089	ANATOLIY GORBUNOV	{"email": "anatoliy_gorbunov-17061976@postgrespro.ru", "phone": "+70426236109"}
0005435078752	208AC1	5143 163452	SERGEY MAKAROV	{"email": "makarovs_03071967@postgrespro.ru", "phone": "+70119861397"}
0005435078753	96C4AB	5907 584467	EVGENIY IVANOV	{"email": "ivanov-evgeniy.011986@postgrespro.ru", "phone": "+70139731911"}
0005435078754	96C4AB	4063 133611	SERGEY ANTONOV	{"phone": "+70610045117"}
0005435078755	542D69	5200 756061	ANNA KUZNECOVA	{"email": "kuznecova-anna-22061983@postgrespro.ru", "phone": "+70901781862"}
0005435078756	CFDBFF	3940 510362	LUIZA NIKOLAEVA	{"phone": "+70751907241"}
0005435078757	9895FE	1735 546318	DMITRIY ABRAMOV	{"email": "d-abramov-22081960@postgrespro.ru", "phone": "+70365604112"}
0005435078758	D8C59F	4194 952017	MAKSIM FEDOTOV	{"phone": "+70445516014"}
0005435078759	75A295	9594 220861	MIKHAIL TIKHONOV	{"email": "m-tikhonov-1986@postgrespro.ru", "phone": "+70952820057"}
0005435078760	A51A37	0278 119307	NINA NIKOLAEVA	{"email": "nina_nikolaeva_021975@postgrespro.ru", "phone": "+70437982971"}
0005435078761	680D1C	2221 092838	TATYANA TROFIMOVA	{"phone": "+70448990590"}
0005435078762	680D1C	2170 000589	TATYANA ANDREEVA	{"phone": "+70180832220"}
0005435078763	AA0779	5544 710883	VLADISLAV ALEKSANDROV	{"phone": "+70198852889"}
0005435078764	B93CEE	1441 492460	ANASTASIYA RODIONOVA	{"phone": "+70278642642"}
0005435078765	B93CEE	1329 226180	MARIYA YUDINA	{"phone": "+70007695471"}
0005435078766	B93CEE	3013 434768	PAVEL ANTONOV	{"email": "p.antonov_061962@postgrespro.ru", "phone": "+70884854230"}
0005435078767	662402	6654 184965	ALEKSANDR NOVIKOV	{"email": "a-novikov_031968@postgrespro.ru", "phone": "+70934542805"}
0005435078768	64FE24	6900 467969	FEDOR KONOVALOV	{"email": "f_konovalov22021977@postgrespro.ru", "phone": "+70273791591"}
0005435078769	64FE24	6078 098877	IGOR YAKOVLEV	{"email": "yakovlev-igor.121975@postgrespro.ru", "phone": "+70069833805"}
0005435078770	B4A432	3410 801624	SERGEY IVANOV	{"phone": "+70111033503"}
0005435078771	21101F	1744 865853	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin-30091969@postgrespro.ru", "phone": "+70257039012"}
0005435078772	1EB599	2309 416379	ALEKSANDRA KOVALEVA	{"email": "kovaleva_aleksandra.041968@postgrespro.ru", "phone": "+70073814275"}
0005435078773	191DBA	3952 334581	OKSANA DMITRIEVA	{"phone": "+70328322600"}
0005435078774	B837F0	5847 387455	LYUBOV VLASOVA	{"email": "vlasova_l_25061964@postgrespro.ru", "phone": "+70277677109"}
0005435078775	918108	2677 157617	POLINA KALININA	{"email": "polinakalinina.1972@postgrespro.ru", "phone": "+70694517402"}
0005435078776	918108	8435 134590	NADEZHDA FILIPPOVA	{"email": "filippova.nadezhda-28121978@postgrespro.ru", "phone": "+70090276674"}
0005435078777	715E8F	3217 428428	ANNA VASILEVA	{"email": "anna_vasileva29121969@postgrespro.ru", "phone": "+70162085867"}
0005435078778	94AB1F	8432 147472	VITALIY PAVLOV	{"phone": "+70303205927"}
0005435078779	9D0583	3651 292190	ALEKSANDRA MIKHAYLOVA	{"phone": "+70166958532"}
0005435078780	DD4F78	4097 707893	LYUDMILA MAKAROVA	{"email": "makarova.lyudmila.08101975@postgrespro.ru", "phone": "+70786599647"}
0005435078781	DD4F78	7603 467943	MARIYA MIRONOVA	{"email": "m.mironova_1981@postgrespro.ru", "phone": "+70826101195"}
0005435078782	A8BF86	5895 163950	ANATOLIY PETROV	{"phone": "+70288105585"}
0005435078783	7AECE2	3925 411995	ELDAR CHERNOV	{"phone": "+70031634583"}
0005435078784	1EB351	5417 215977	IRINA BORISOVA	{"email": "borisova.irina_10101980@postgrespro.ru", "phone": "+70141027831"}
0005435078785	1EB351	1000 642633	OLEG KUZMIN	{"email": "kuzmin.o-07031980@postgrespro.ru", "phone": "+70835287725"}
0005435078786	9BDFB1	6103 582777	OLGA TARASOVA	{"phone": "+70049986727"}
0005435078787	870B17	9490 033279	DENIS YAKOVLEV	{"email": "d_yakovlev-16031962@postgrespro.ru", "phone": "+70089968246"}
0005435078788	870B17	1519 612731	VALERIYA VLASOVA	{"email": "vlasova.valeriya_011967@postgrespro.ru", "phone": "+70285925696"}
0005435078789	E6E916	8991 806767	MARIYA PETROVA	{"email": "petrova.mariya.121976@postgrespro.ru", "phone": "+70856917384"}
0005435078790	E6E916	2154 933312	VERA NOVIKOVA	{"email": "novikovavera.15101964@postgrespro.ru", "phone": "+70785691730"}
0005435078791	E05E0E	0500 317208	VIKTOR KAZAKOV	{"email": "viktor_kazakov111967@postgrespro.ru", "phone": "+70413593111"}
0005435078792	5BC64B	3246 989196	ALEKSANDRA SMIRNOVA	{"email": "aleksandra_smirnova-011974@postgrespro.ru", "phone": "+70770528447"}
0005435078793	BAABBF	2753 905841	TATYANA POPOVA	{"email": "popova.tatyana1983@postgrespro.ru", "phone": "+70853750990"}
0005435078794	BAABBF	1533 594082	ALBERT RODIONOV	{"phone": "+70268135367"}
0005435082643	5D0FE8	7844 548966	SERGEY FEDOTOV	{"phone": "+70400891029"}
0005435082644	19E392	5931 629988	VALERIY MIRONOV	{"phone": "+70029141835"}
0005435082645	CFF7A6	6642 495774	IRINA MATVEEVA	{"phone": "+70681321025"}
0005435082646	60C84B	1106 906456	ALEKSEY SERGEEV	{"email": "alekseysergeev-1975@postgrespro.ru", "phone": "+70804973622"}
0005435082647	60C84B	1542 369171	ALEKSANDR VASILEV	{"phone": "+70220935747"}
0005435082648	8F714E	7049 440635	VADIM NOVIKOV	{"phone": "+70728188989"}
0005435082649	8F714E	6318 581902	YULIYA TIMOFEEVA	{"email": "yuliyatimofeeva1977@postgrespro.ru", "phone": "+70567299491"}
0005435082650	27673E	9054 669280	KRISTINA PAVLOVA	{"email": "kristinapavlova.121982@postgrespro.ru", "phone": "+70786044783"}
0005435082651	C332E8	5322 863563	OLESYA SEMENOVA	{"phone": "+70236783721"}
0005435082652	8511F2	0944 184291	MARIYA ALEKSEEVA	{"email": "m_alekseeva.1972@postgrespro.ru", "phone": "+70155759690"}
0005435082653	8511F2	8899 946492	MARIYA DMITRIEVA	{"phone": "+70866928847"}
0005435082654	89C011	3934 968098	LARISA LOGINOVA	{"email": "loginovalarisa1967@postgrespro.ru", "phone": "+70746783634"}
0005435082655	0F9CD3	8087 233315	NIKITA KUZNECOV	{"phone": "+70546709482"}
0005435082656	0F9CD3	2731 156034	ELENA NAZAROVA	{"phone": "+70479752309"}
0005435082657	F25059	8327 516841	LYUBOV ISAEVA	{"phone": "+70476742994"}
0005435082658	F25059	2931 612955	NIKOLAY FEDOROV	{"phone": "+70801856297"}
0005435082659	F25059	2769 259916	MARGARITA GERASIMOVA	{"email": "margaritagerasimova-1980@postgrespro.ru", "phone": "+70985848879"}
0005435082660	8F66C9	4219 352525	VASILIY KUDRYASHOV	{"phone": "+70499841853"}
0005435082661	8F66C9	1378 693826	OLEG SEMENOV	{"email": "osemenov_27111959@postgrespro.ru", "phone": "+70231913614"}
0005435082662	B3CD75	8691 849561	NATALYA KONOVALOVA	{"phone": "+70302307788"}
0005435082663	B3CD75	8497 931417	VERA ROMANOVA	{"phone": "+70113409088"}
0005435082664	5B1E01	5397 051614	VLADIMIR MAKAROV	{"email": "v-makarov_1977@postgrespro.ru", "phone": "+70161968546"}
0005435082665	5B1E01	4205 688098	EVGENIY ALEKSANDROV	{"email": "aleksandrov_e_1974@postgrespro.ru", "phone": "+70203998820"}
0005435082666	C6B9DA	5367 300292	ANDREY FILIPPOV	{"email": "a_filippov111980@postgrespro.ru", "phone": "+70767534918"}
0005435082667	EEA925	3065 433533	NIKOLAY POPOV	{"email": "popov_nikolay.111971@postgrespro.ru", "phone": "+70018479023"}
0005435082668	5ACC85	0953 969689	TATYANA FOMINA	{"phone": "+70437382147"}
0005435082669	21D306	9769 433834	ANNA ABRAMOVA	{"email": "abramova_anna-03121970@postgrespro.ru", "phone": "+70524546830"}
0005435082670	63C688	7555 882637	ALEKSANDR KOZLOV	{"email": "akozlov011949@postgrespro.ru", "phone": "+70540517002"}
0005435082671	37756E	3276 567111	EVELINA VASILEVA	{"email": "evelina.vasileva-10111966@postgrespro.ru", "phone": "+70595469503"}
0005435082672	52FBE8	6723 639947	LARISA KOZLOVA	{"phone": "+70159875162"}
0005435082673	0F5308	9881 237801	ANNA IVANOVA	{"phone": "+70367887887"}
0005435082674	0F5308	0574 090871	VIKTOR MIRONOV	{"email": "viktormironov_29011976@postgrespro.ru", "phone": "+70332370563"}
0005435082675	707F30	1955 259320	IVAN RODIONOV	{"email": "rodionovivan111973@postgrespro.ru", "phone": "+70240630752"}
0005435082676	9A35EA	4403 845768	SVETLANA BARANOVA	{"phone": "+70780436560"}
0005435082677	6768A4	2457 916935	NINA EGOROVA	{"phone": "+70812213205"}
0005435082678	50E167	4287 212534	ALEKSANDR GUSEV	{"phone": "+70352813765"}
0005435082679	D326CA	9016 322186	NATALYA ANDREEVA	{"email": "andreeva.natalya-121972@postgrespro.ru", "phone": "+70279247734"}
0005435082680	223109	8266 564144	ANNA OSIPOVA	{"email": "a.osipova.021979@postgrespro.ru", "phone": "+70287980338"}
0005435082681	6AA55F	3176 379998	EVDOKIYA AFANASEVA	{"email": "afanaseva-evdokiya1974@postgrespro.ru", "phone": "+70706711018"}
0005435082682	6AA55F	4471 827327	ARTEM PETROV	{"phone": "+70600669794"}
0005435082683	6AA55F	6125 577287	ALEKSANDR ALEKSEEV	{"phone": "+70252741494"}
0005435082684	BA19F1	7947 858333	LARISA KALININA	{"phone": "+70255107939"}
0005435082685	B414A2	9935 644609	VALENTINA MOISEEVA	{"phone": "+70249113622"}
0005435082686	B414A2	0867 469782	ANTON EGOROV	{"email": "egorovanton.19091971@postgrespro.ru", "phone": "+70571381903"}
0005435082687	66D126	0648 555938	EVGENIY IVANOV	{"email": "evgeniy-ivanov1966@postgrespro.ru", "phone": "+70364636864"}
0005435082688	549214	4515 521515	SERGEY KULIKOV	{"email": "kulikovsergey_17081983@postgrespro.ru", "phone": "+70434323053"}
0005435082689	549214	7292 127950	IRINA BOGDANOVA	{"phone": "+70927127430"}
0005435082690	A27301	9615 718460	TATYANA ANISIMOVA	{"phone": "+70405988103"}
0005435082691	A27301	7905 936515	VYACHESLAV BONDARENKO	{"email": "vyacheslav-bondarenko29021976@postgrespro.ru", "phone": "+70177077581"}
0005435082692	A27301	4546 220297	ANDREY KISELEV	{"email": "kiselev-a_07021966@postgrespro.ru", "phone": "+70961216582"}
0005435082693	A27301	9178 421810	VASILIY KISELEV	{"phone": "+70634554878"}
0005435082694	C5EE4F	3638 265505	EKATERINA MEDVEDEVA	{"phone": "+70283650480"}
0005435082695	65FB0E	0792 858823	KIRA FILIPPOVA	{"email": "filippovak.1965@postgrespro.ru", "phone": "+70175876481"}
0005435082696	65FB0E	1120 717340	ALENA IVANOVA	{"phone": "+70709554092"}
0005435082697	FBC273	4995 862297	VLADIMIR ABRAMOV	{"phone": "+70773313973"}
0005435082698	CF5CC6	4723 078026	VENIAMIN PETROV	{"phone": "+70054558306"}
0005435082699	EF83C6	4158 063287	NIKOLAY BELOV	{"email": "belov-nikolay_1971@postgrespro.ru", "phone": "+70953439863"}
0005435082700	EF83C6	8135 256721	ELENA VOLKOVA	{"email": "volkova.e-06091974@postgrespro.ru", "phone": "+70368534134"}
0005435082701	E4AFC3	6379 103223	VLADIMIR ROMANOV	{"phone": "+70041738218"}
0005435082702	E4AFC3	7590 101398	RAISA PAVLOVA	{"email": "pavlova.r1977@postgrespro.ru", "phone": "+70325315455"}
0005435082703	BEB020	5647 044840	ALEKSANDR PAVLOV	{"email": "pavlova13071977@postgrespro.ru", "phone": "+70476372266"}
0005435082704	4D3487	2466 698557	NADEZHDA KUZMINA	{"phone": "+70937609137"}
0005435082705	4D3487	1161 148736	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev.1966@postgrespro.ru", "phone": "+70348084343"}
0005435082706	B9785E	6027 463724	NATALYA KOLESNIKOVA	{"email": "natalyakolesnikova061979@postgrespro.ru", "phone": "+70748695844"}
0005435082707	B9785E	7734 441199	IRINA KUZNECOVA	{"phone": "+70329935084"}
0005435082708	A4BD18	1653 004327	VYACHESLAV TARASOV	{"email": "vyacheslav-tarasov.08101975@postgrespro.ru", "phone": "+70845420332"}
0005435082709	F29F70	7908 815340	RAISA DMITRIEVA	{"phone": "+70821649667"}
0005435082710	D5C9FC	9128 900182	LILIYA SMIRNOVA	{"email": "liliya.smirnova_031972@postgrespro.ru", "phone": "+70896631802"}
0005435082711	190361	7473 950966	ELENA KUZNECOVA	{"phone": "+70130395793"}
0005435082712	190361	9946 256063	OLGA EFIMOVA	{"email": "efimova.o-1971@postgrespro.ru", "phone": "+70355062053"}
0005435082713	190361	3271 830127	SERGEY SAVELEV	{"email": "savelevsergey091973@postgrespro.ru", "phone": "+70797882293"}
0005435082714	054BD8	9932 717823	YULIYA SMIRNOVA	{"email": "smirnova.y_01041968@postgrespro.ru", "phone": "+70251871292"}
0005435082715	6D48AB	5344 382662	ELENA BORISOVA	{"email": "elenaborisova_22021975@postgrespro.ru", "phone": "+70842603570"}
0005435082716	A75C19	6095 930909	YULIYA GORBUNOVA	{"email": "y_gorbunova-1966@postgrespro.ru", "phone": "+70936432021"}
0005435082717	228BEC	5380 838019	EVGENIY GUSEV	{"phone": "+70303799441"}
0005435082718	F727A9	5296 679892	VLADIMIR MAKSIMOV	{"email": "v-maksimov.111986@postgrespro.ru", "phone": "+70474356009"}
0005435082719	4278C5	0792 525925	ALEKSANDR NOVIKOV	{"phone": "+70245204884"}
0005435082720	9F6D9B	9424 142402	GENNADIY SHEVCHENKO	{"email": "shevchenko_gennadiy_1961@postgrespro.ru", "phone": "+70848821965"}
0005435082721	BC36D8	5606 389910	VIKTORIYA MIRONOVA	{"email": "mironova.viktoriya_01121969@postgrespro.ru", "phone": "+70484434598"}
0005435082722	A85921	7495 311111	YULIYA VASILEVA	{"email": "vasilevayuliya_1969@postgrespro.ru", "phone": "+70362139876"}
0005435082723	5D7C98	4628 600563	SERGEY MARTYNOV	{"email": "smartynov_051975@postgrespro.ru", "phone": "+70033244079"}
0005435082724	5D7C98	0074 156237	VLADIMIR EGOROV	{"phone": "+70401131503"}
0005435082725	E205DA	2319 553021	YULIYA KAZAKOVA	{"email": "kazakova.y1975@postgrespro.ru", "phone": "+70000447334"}
0005435082726	31CC18	6767 334379	VASILIY KONOVALOV	{"email": "konovalovvasiliy.061987@postgrespro.ru", "phone": "+70797904245"}
0005435082727	31CC18	2784 816919	EVGENIYA ZHURAVLEVA	{"phone": "+70581873351"}
0005435082728	76B4AF	3241 427762	LYUBOV VOLKOVA	{"phone": "+70522900865"}
0005435082729	48EB86	2982 537457	DARYA SIDOROVA	{"email": "sidorovadarya-1968@postgrespro.ru", "phone": "+70887256798"}
0005435082730	8F9DE8	8304 056446	ANDREY SEMENOV	{"email": "semenov.a091966@postgrespro.ru", "phone": "+70727180483"}
0005435082731	8F9DE8	4970 088968	VERA VOLKOVA	{"phone": "+70791846268"}
0005435082732	BD5E4E	5900 110205	VALENTINA MIKHAYLOVA	{"email": "mikhaylovavalentina-1978@postgrespro.ru", "phone": "+70120234373"}
0005435082733	BD5E4E	2485 717551	VALENTINA FROLOVA	{"email": "v.frolova011972@postgrespro.ru", "phone": "+70487022075"}
0005435082734	F339E7	4735 566021	EVGENIY MIRONOV	{"email": "mironov.evgeniy-091969@postgrespro.ru", "phone": "+70981167396"}
0005435082735	F339E7	8712 710261	KSENIYA TIMOFEEVA	{"email": "timofeevak.13091965@postgrespro.ru", "phone": "+70714284136"}
0005435082736	7BAC7E	5020 869397	POLINA VOROBEVA	{"email": "vorobeva.p.041963@postgrespro.ru", "phone": "+70391307151"}
0005435082737	7BAC7E	2438 126603	RAISA BELOVA	{"phone": "+70670680280"}
0005435082738	72DEE9	4193 668428	ELENA ISAEVA	{"phone": "+70289651323"}
0005435082739	957B31	7642 779921	OKSANA LUKYANOVA	{"email": "lukyanova.oksana051974@postgrespro.ru", "phone": "+70408078510"}
0005435082740	67C1B2	9808 959794	ANTONINA MAKAROVA	{"phone": "+70533525567"}
0005435082741	160A96	0818 841675	IRINA PETROVA	{"phone": "+70612247431"}
0005435082742	EC9020	8512 336259	TATYANA ERMAKOVA	{"email": "ermakova-t071963@postgrespro.ru", "phone": "+70898217761"}
0005435082743	86F887	4680 608044	ZINAIDA KOZLOVA	{"phone": "+70694132061"}
0005435082744	0E5F84	3412 722529	RUSLAN NAZAROV	{"email": "r_nazarov1974@postgrespro.ru", "phone": "+70901429292"}
0005435082745	D6DF9E	4682 964944	YULIYA VOLKOVA	{"email": "volkovay_031973@postgrespro.ru", "phone": "+70551854708"}
0005435082746	D6DF9E	3026 107395	ALEKSANDR ROMANOV	{"phone": "+70112958317"}
0005435082747	608D59	4114 659134	OLESYA PAVLOVA	{"phone": "+70478856632"}
0005435082748	85BD7C	1698 875726	LYUBOV SERGEEVA	{"phone": "+70192215258"}
0005435082749	85BD7C	6895 384932	ANASTASIYA ANDREEVA	{"phone": "+70413936484"}
0005435082750	D1E1FE	1810 095146	ALEKSANDR MAKSIMOV	{"phone": "+70684724848"}
0005435082751	2EA935	0589 273311	TATYANA ZAKHAROVA	{"phone": "+70101615349"}
0005435082752	FCD9A2	3530 564956	DENIS IVANOV	{"email": "d.ivanov-22051979@postgrespro.ru", "phone": "+70219410595"}
0005435082753	DFDD8F	5108 476729	NINA DENISOVA	{"email": "n.denisova-23091973@postgrespro.ru", "phone": "+70639055040"}
0005435082754	DFDD8F	2748 253588	LIDIYA KUZMINA	{"phone": "+70396632427"}
0005435082755	DFDD8F	9014 583609	VALENTINA MAKSIMOVA	{"phone": "+70039043054"}
0005435082756	07C6E3	4764 342376	NATALYA ANDREEVA	{"email": "andreevanatalya1978@postgrespro.ru", "phone": "+70550980794"}
0005435082757	07C6E3	8929 882677	DENIS KOZLOV	{"email": "denis_kozlov.111979@postgrespro.ru", "phone": "+70859249034"}
0005435082758	07C6E3	9554 841860	VADIM MAKAROV	{"phone": "+70366857472"}
0005435082759	E61B7A	2571 965383	ALEKSEY IVANOV	{"email": "a_ivanov-031968@postgrespro.ru", "phone": "+70183651097"}
0005435082760	E61B7A	3340 362074	IGOR SOKOLOV	{"phone": "+70332806191"}
0005435082761	8EE476	4592 516230	KONSTANTIN GUSEV	{"email": "k.gusev.111969@postgrespro.ru", "phone": "+70653675346"}
0005435082762	99D4EA	2124 207493	PETR PETROV	{"phone": "+70926416664"}
0005435082763	99D4EA	2658 032678	NIKOLAY GAVRILOV	{"email": "nikolay.gavrilov-05021987@postgrespro.ru", "phone": "+70344310056"}
0005435082764	B6F95F	2470 650296	ALEKSANDR MARTYNOV	{"phone": "+70049336105"}
0005435082765	ECDB0B	5614 252134	ALEKSEY POPOV	{"email": "aleksey_popov21011972@postgrespro.ru", "phone": "+70005312492"}
0005435082766	22650A	7577 992058	VLADIMIR FROLOV	{"email": "frolov_v_1972@postgrespro.ru", "phone": "+70418598865"}
0005435082767	22650A	9880 580766	GALINA MARTYNOVA	{"phone": "+70646777949"}
0005435082768	5984CA	0606 821375	NINA BARANOVA	{"email": "baranovan-071977@postgrespro.ru", "phone": "+70068835156"}
0005435082769	C76676	0264 188781	NINA KRASNOVA	{"email": "krasnova-nina-1975@postgrespro.ru", "phone": "+70050238480"}
0005435082770	8D0B1D	2571 103452	VLADIMIR DAVYDOV	{"email": "v_davydov_051974@postgrespro.ru", "phone": "+70048573365"}
0005435082771	A74667	7148 886804	MADINA ROMANOVA	{"phone": "+70860713006"}
0005435082772	5087CE	2057 357327	IRINA GERASIMOVA	{"email": "gerasimova_i-27121979@postgrespro.ru", "phone": "+70510312971"}
0005435082773	4C937F	9748 357328	TATYANA SMIRNOVA	{"phone": "+70934772853"}
0005435082774	6E03D8	2043 920965	VALERIY RODIONOV	{"phone": "+70827338380"}
0005435082775	6E03D8	1937 941471	SVETLANA KOZLOVA	{"phone": "+70252903119"}
0005435082776	BE085D	7364 825515	TATYANA ALEKSANDROVA	{"phone": "+70858810524"}
0005435082777	6AEC55	6059 764934	NATALYA VASILEVA	{"phone": "+70566159059"}
0005435082778	5ACA14	2711 960553	MIKHAIL IVANOV	{"email": "mikhail_ivanov.19111982@postgrespro.ru", "phone": "+70767022666"}
0005435082779	5ACA14	6619 182986	TATYANA BOGDANOVA	{"email": "tatyana_bogdanova.051975@postgrespro.ru", "phone": "+70721705641"}
0005435082780	39FAE2	2943 030615	LEONID MIKHAYLOV	{"email": "mikhaylov.leonid-05081954@postgrespro.ru", "phone": "+70758556041"}
0005435082781	C9C49F	4798 164949	NADEZHDA ORLOVA	{"email": "orlovan08111975@postgrespro.ru", "phone": "+70201008046"}
0005435082782	4FC88A	3006 619850	VIKTOR ABRAMOV	{"phone": "+70808104446"}
0005435082783	4FC88A	7452 754094	NIKOLAY MATVEEV	{"email": "matveev.n.121970@postgrespro.ru", "phone": "+70729206772"}
0005435082784	4A3F1D	9879 672236	SERGEY CHERNOV	{"phone": "+70727942716"}
0005435082785	C50B63	1896 502182	LYUDMILA AKIMOVA	{"phone": "+70862878820"}
0005435082786	58DD87	9350 680817	VALENTIN IVANOV	{"email": "ivanov_v111972@postgrespro.ru", "phone": "+70221523537"}
0005435082787	56C4C3	7933 871756	ELENA GAVRILOVA	{"email": "elena.gavrilova03011974@postgrespro.ru", "phone": "+70751430271"}
0005435082788	20BDBA	7063 381853	NATALYA SIDOROVA	{"email": "sidorova-n.111981@postgrespro.ru", "phone": "+70440113389"}
0005435082789	1AED26	7255 115055	LYUDMILA ZAYCEVA	{"phone": "+70323060279"}
0005435082790	2A9ACF	5266 630173	IVAN BARANOV	{"email": "i-baranov1981@postgrespro.ru", "phone": "+70163464011"}
0005435082791	A29F03	5819 284543	IRINA ALEKSANDROVA	{"email": "ialeksandrova_111965@postgrespro.ru", "phone": "+70972478994"}
0005435082792	A29F03	4493 178452	ELIZAVETA GERASIMOVA	{"phone": "+70392505502"}
0005435082793	4E2A96	9793 122529	DMITRIY KULIKOV	{"phone": "+70860224600"}
0005435082794	B5BB52	4184 886856	VALENTINA SOKOLOVA	{"phone": "+70101290582"}
0005435082795	B10F89	7676 805941	SERGEY MIKHAYLOV	{"phone": "+70093322722"}
0005435082796	B10F89	3970 244842	NADEZHDA ISAEVA	{"email": "isaeva-n-21071973@postgrespro.ru", "phone": "+70244069237"}
0005435082797	0E210F	6902 925692	OLGA MIRONOVA	{"phone": "+70074365718"}
0005435082912	AEB174	7623 969052	ANDREY NIKOLAEV	{"phone": "+70441951518"}
0005435082798	0E210F	2404 495514	TIMOFEY ZAKHAROV	{"email": "tzakharov_01011989@postgrespro.ru", "phone": "+70271608285"}
0005435082799	95DE52	1222 200056	YURIY SIDOROV	{"phone": "+70799003339"}
0005435082800	95DE52	2276 162603	VERA MOISEEVA	{"phone": "+70515845504"}
0005435082801	95DE52	6716 376347	VYACHESLAV KUZNECOV	{"phone": "+70388111971"}
0005435082802	8AF034	3704 375402	VLADISLAV MELNIKOV	{"phone": "+70259632074"}
0005435082803	8AF034	9902 511505	IRINA EGOROVA	{"phone": "+70878761592"}
0005435082804	A6285D	0613 762652	LYUBOV ROMANOVA	{"email": "romanoval24011973@postgrespro.ru", "phone": "+70030307473"}
0005435082805	A6285D	3498 413353	TATYANA KALININA	{"phone": "+70114264896"}
0005435082806	7B532F	9536 793698	SERGEY MIKHAYLOV	{"phone": "+70101114307"}
0005435082807	E533CF	2932 331671	MIKHAIL ISAEV	{"email": "misaev04051960@postgrespro.ru", "phone": "+70343673558"}
0005435082808	5F63AC	0312 778822	STANISLAV KUZNECOV	{"email": "s_kuznecov121974@postgrespro.ru", "phone": "+70666898832"}
0005435082809	C6AD4B	0688 882422	MARIYA KUZNECOVA	{"phone": "+70095076121"}
0005435082810	830CD6	5275 101685	TATYANA ZAKHAROVA	{"phone": "+70255643968"}
0005435082811	558E99	4504 620522	SERGEY FEDOROV	{"email": "s_fedorov_30041972@postgrespro.ru", "phone": "+70493725039"}
0005435082812	558E99	3701 501888	ANTON DENISOV	{"phone": "+70654965954"}
0005435082813	CBA2DD	4883 726432	LYUBOV IVANOVA	{"phone": "+70359717205"}
0005435082814	CBA2DD	7178 131205	IRINA ANISIMOVA	{"email": "irina.anisimova14121979@postgrespro.ru", "phone": "+70993205651"}
0005435082815	3D06C5	6481 202567	NIKOLAY MAKSIMOV	{"email": "nikolaymaksimov_1973@postgrespro.ru", "phone": "+70201557261"}
0005435082816	BB3DA5	6159 752768	SVETLANA DAVYDOVA	{"phone": "+70804176250"}
0005435082817	A65D05	6055 817244	RUSLAN MELNIKOV	{"phone": "+70829853786"}
0005435082818	2D66F0	9192 554264	EVGENIY GRIGOREV	{"phone": "+70311707763"}
0005435082819	2D66F0	2717 807825	ILYA VASILEV	{"email": "ilya.vasilev_1982@postgrespro.ru", "phone": "+70199994638"}
0005435082820	B2B652	9272 551235	EVGENIYA PETROVA	{"email": "petrova-evgeniya.01071974@postgrespro.ru", "phone": "+70740876243"}
0005435082821	B2B652	9922 703860	ALEKSEY IVANOV	{"phone": "+70439211070"}
0005435082822	B2B652	6242 912067	SERGEY ALEKSEEV	{"email": "alekseev.sergey-22031987@postgrespro.ru", "phone": "+70824352402"}
0005435082823	FBF78A	4774 077118	NATALIYA NIKITINA	{"email": "nataliya.nikitina_10101977@postgrespro.ru", "phone": "+70491776452"}
0005435082824	FBF78A	4982 656417	TAMARA ARKHIPOVA	{"email": "arkhipova.t.121964@postgrespro.ru", "phone": "+70030966660"}
0005435082825	FE6D8E	5211 412301	ELENA MAKSIMOVA	{"phone": "+70504047921"}
0005435082826	FE6D8E	7678 168368	EVGENIY ANDREEV	{"phone": "+70076074274"}
0005435082827	2C2DE0	7101 222109	MARIYA ZAKHAROVA	{"email": "zakharova.mariya061970@postgrespro.ru", "phone": "+70042415022"}
0005435082828	2C2DE0	8943 505094	SVETLANA SERGEEVA	{"email": "sergeeva_svetlana-1979@postgrespro.ru", "phone": "+70700299415"}
0005435082829	7E3B64	6699 473034	VIKTOR YAKOVLEV	{"phone": "+70765612731"}
0005435082830	D8CF8B	8476 856243	LYUDMILA KARPOVA	{"email": "lyudmila.karpova_1966@postgrespro.ru", "phone": "+70383852955"}
0005435082831	3D1247	2427 313478	SERGEY ANTONOV	{"phone": "+70391513723"}
0005435082832	005AFA	6775 340690	MARINA SIDOROVA	{"email": "sidorova-m.021983@postgrespro.ru", "phone": "+70004963455"}
0005435082833	8E852C	1809 087292	GENNADIY KULIKOV	{"phone": "+70668649900"}
0005435082834	24D29B	3422 195438	ALEKSANDR KUDRYASHOV	{"email": "akudryashov-081968@postgrespro.ru", "phone": "+70642190759"}
0005435082835	24D29B	5145 425298	SERGEY PETROV	{"phone": "+70780317215"}
0005435082836	75731B	5092 941535	AMINA NESTEROVA	{"phone": "+70373447482"}
0005435082837	36B844	6559 352535	SERGEY KOZLOV	{"email": "kozlov_s29121984@postgrespro.ru", "phone": "+70786912679"}
0005435082838	36B844	2629 929082	OLEG ISAEV	{"phone": "+70811720537"}
0005435082839	2FA2FA	8300 427925	ALEKSANDR VOROBEV	{"phone": "+70864618437"}
0005435082840	A4A057	2148 546285	ALEKSANDRA MELNIKOVA	{"phone": "+70597029030"}
0005435082841	5B6D65	8848 846756	LIDIYA KUZMINA	{"email": "l-kuzmina_1962@postgrespro.ru", "phone": "+70581220551"}
0005435082842	5B6D65	3067 674712	RAFAIL SOLOVEV	{"email": "r-solovev_1981@postgrespro.ru", "phone": "+70100225171"}
0005435082843	4C3518	4693 806644	ANNA POLYAKOVA	{"phone": "+70208091352"}
0005435082844	4C3518	8328 953541	NATALYA NAZAROVA	{"email": "nazarova-n.111969@postgrespro.ru", "phone": "+70277910327"}
0005435082845	E01423	8025 605892	YULIYA MEDVEDEVA	{"phone": "+70485154429"}
0005435082846	73B8EE	6275 974364	NIKOLAY SHEVCHENKO	{"phone": "+70804129722"}
0005435082847	56AD22	0498 968010	ALEKSANDR GERASIMOV	{"phone": "+70388291197"}
0005435082848	56AD22	9832 042239	ALEKSANDR MELNIKOV	{"email": "a.melnikov10051971@postgrespro.ru", "phone": "+70234395339"}
0005435082849	4B2ADF	8566 525397	ELENA ERMAKOVA	{"phone": "+70472680239"}
0005435082850	8E5758	4441 778218	ZINAIDA TROFIMOVA	{"phone": "+70794021827"}
0005435082851	2B8B66	7630 141524	GALINA FROLOVA	{"phone": "+70418699201"}
0005435082852	2B8B66	2012 682442	TIMOFEY KUZNECOV	{"email": "kuznecov.t.1967@postgrespro.ru", "phone": "+70825231493"}
0005435082853	C5D6BD	8224 994980	LYUDMILA FOMINA	{"email": "lyudmila_fomina-071985@postgrespro.ru", "phone": "+70890405925"}
0005435082854	395825	6568 735436	GEORGIY VLASOV	{"phone": "+70539018313"}
0005435082855	395825	4962 974109	NATALYA KUZNECOVA	{"email": "nkuznecova.121970@postgrespro.ru", "phone": "+70529145159"}
0005435082856	6F0DC4	5938 425148	IRINA TARASOVA	{"phone": "+70829555561"}
0005435082857	12CF94	5114 811832	OLGA IVANOVA	{"phone": "+70898044949"}
0005435082858	12CF94	9404 991040	LYUBOV KOZLOVA	{"email": "kozlova.l_1971@postgrespro.ru", "phone": "+70792220737"}
0005435082859	AE68E8	0564 294164	ALEKSEY ALEKSEEV	{"phone": "+70203996765"}
0005435082860	87EE67	0046 288549	ANATOLIY SCHERBAKOV	{"email": "scherbakovanatoliy.111965@postgrespro.ru", "phone": "+70296215276"}
0005435082861	DC2C2A	3968 198802	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov051984@postgrespro.ru", "phone": "+70902881347"}
0005435082862	DC2C2A	0645 743093	VIKTOR NAZAROV	{"email": "vnazarov-091969@postgrespro.ru", "phone": "+70738037693"}
0005435082863	476814	5632 535928	ALEKSEY MIRONOV	{"phone": "+70981009766"}
0005435082864	1CFCC0	6685 031018	MAKSIM KOROLEV	{"phone": "+70580214224"}
0005435082865	073E1C	8983 430921	ANDREY GUSEV	{"email": "andrey-gusev.061965@postgrespro.ru", "phone": "+70864442913"}
0005435082866	073E1C	0743 688063	ANDREY POPOV	{"phone": "+70145450602"}
0005435082867	073E1C	4026 176502	ALEKSANDR KRASNOV	{"phone": "+70673774476"}
0005435082868	A210EC	2708 254104	MARIYA OSIPOVA	{"phone": "+70592813405"}
0005435082869	0DF9A3	4189 037527	YULIYA VASILEVA	{"phone": "+70965131433"}
0005435082870	9135F5	5567 186946	LARISA NESTEROVA	{"email": "l-nesterova_1966@postgrespro.ru", "phone": "+70788982694"}
0005435082871	9135F5	0119 455778	SERGEY ANDREEV	{"phone": "+70406368339"}
0005435082872	BDD53E	8406 909918	SVETLANA ALEKSEEVA	{"email": "svetlanaalekseeva06121970@postgrespro.ru", "phone": "+70731978886"}
0005435082873	AC4E49	6149 033950	IGOR KISELEV	{"phone": "+70390556843"}
0005435082874	910681	7146 586747	PAVEL MAKAROV	{"phone": "+70674782157"}
0005435082875	910681	8694 149311	VASILIY MARTYNOV	{"phone": "+70662008311"}
0005435082876	910681	0459 202111	DARYA IVANOVA	{"email": "darya.ivanova-031960@postgrespro.ru", "phone": "+70163188717"}
0005435082877	939AE1	7987 610277	EGOR NIKOLAEV	{"phone": "+70985725366"}
0005435082878	271155	7860 899209	SVETLANA GORBUNOVA	{"phone": "+70778826775"}
0005435082879	271155	0249 255539	NATALYA ALEKSANDROVA	{"email": "natalya_aleksandrova.091974@postgrespro.ru", "phone": "+70723427474"}
0005435082880	2A5C1B	0030 914832	NINA ZHURAVLEVA	{"phone": "+70038807098"}
0005435082881	2A5C1B	2266 577801	TATYANA ANTONOVA	{"phone": "+70232265075"}
0005435082882	B34FCD	1141 474207	KRISTINA VOROBEVA	{"email": "k.vorobeva_111962@postgrespro.ru", "phone": "+70909212229"}
0005435082883	3B3F6D	9823 082955	ALEKSEY KUZNECOV	{"email": "akuznecov.25021990@postgrespro.ru", "phone": "+70656010644"}
0005435082884	3B3F6D	2561 797935	LYUBOV ABRAMOVA	{"email": "abramova-l_011983@postgrespro.ru", "phone": "+70682670000"}
0005435082885	3B3F6D	9886 360889	EKATERINA VOROBEVA	{"email": "ekaterina_vorobeva-091961@postgrespro.ru", "phone": "+70371447893"}
0005435082886	7235CC	0143 339291	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir.081966@postgrespro.ru", "phone": "+70084234949"}
0005435082887	F9A0F3	2854 926423	EVGENIY SHEVCHENKO	{"phone": "+70939105159"}
0005435082888	C98F26	2098 419779	ELVIRA EGOROVA	{"email": "egorova_e_12011972@postgrespro.ru", "phone": "+70675004779"}
0005435082889	C98F26	1651 667890	ANDREY FROLOV	{"phone": "+70521218468"}
0005435082890	5F95AE	4987 554701	ANNA VLASOVA	{"phone": "+70130258580"}
0005435082891	9ED305	6102 361025	IVAN POPOV	{"phone": "+70811544161"}
0005435082892	CF488C	3494 582132	LARISA KOROLEVA	{"phone": "+70231792780"}
0005435082893	CF488C	7350 463059	ZOYA NESTEROVA	{"email": "nesterova-z_1955@postgrespro.ru", "phone": "+70196026882"}
0005435082894	FFD7FA	4553 151922	LYUDMILA KARPOVA	{"email": "lyudmila-karpova_071974@postgrespro.ru", "phone": "+70787223714"}
0005435082895	8B0FA9	1115 081459	VALENTINA MIKHAYLOVA	{"phone": "+70025004169"}
0005435082896	8B0FA9	8792 772892	ALEKSEY GERASIMOV	{"email": "a.gerasimov.14081983@postgrespro.ru", "phone": "+70282809759"}
0005435082897	169F9C	4136 578892	ANNA MIKHAYLOVA	{"phone": "+70939510415"}
0005435082898	6EC876	4809 187938	GALINA LAZAREVA	{"phone": "+70908308125"}
0005435082899	6EC876	1220 581247	SERGEY MIKHAYLOV	{"phone": "+70385285228"}
0005435082900	80190D	5695 198994	OLGA IVANOVA	{"phone": "+70222473487"}
0005435082901	79176A	7079 042180	NINA VASILEVA	{"phone": "+70563616874"}
0005435082902	C029BA	6396 301878	ARTEM ZHUKOV	{"phone": "+70176194105"}
0005435082903	2093B1	5682 820966	IRINA AFANASEVA	{"phone": "+70258820928"}
0005435082904	DB866C	8973 920527	YANA BELOVA	{"email": "yana_belova.30101983@postgrespro.ru", "phone": "+70216595822"}
0005435082905	DB866C	9974 656227	VALENTINA TARASOVA	{"email": "tarasova_v05101978@postgrespro.ru", "phone": "+70391314830"}
0005435082906	AAA4C3	3742 242472	DANILA VOLKOV	{"phone": "+70342995942"}
0005435082907	D7AB82	9312 436379	KIRILL FOMIN	{"phone": "+70923287237"}
0005435082908	D7AB82	6388 016673	OLGA SMIRNOVA	{"email": "o.smirnova_011966@postgrespro.ru", "phone": "+70285217475"}
0005435082909	DF7F49	4939 821148	ELENA KAZAKOVA	{"email": "kazakova.e_06101976@postgrespro.ru", "phone": "+70104388140"}
0005435082910	CD8269	0436 008581	FAIL SIDOROV	{"phone": "+70362939943"}
0005435082911	AEB174	5778 722138	IRINA ZHURAVLEVA	{"email": "irina.zhuravleva-081978@postgrespro.ru", "phone": "+70303373987"}
0005435082913	AEB174	0070 070978	VALERIY ILIN	{"email": "v_ilin-121978@postgrespro.ru", "phone": "+70835038632"}
0005435082914	4F8747	5781 084091	RUSHANIYA ILINA	{"phone": "+70304001291"}
0005435082915	4F8747	5200 842649	VLADIMIR MEDVEDEV	{"email": "v_medvedev_20031975@postgrespro.ru", "phone": "+70513112393"}
0005435082916	11BE0D	3345 577120	KIRILL KUDRYASHOV	{"phone": "+70041141520"}
0005435082917	370653	4330 484570	MARIYA SOROKINA	{"email": "mariya_sorokina-01051967@postgrespro.ru", "phone": "+70331044899"}
0005435082918	1F26EA	6293 703591	EVDOKIYA MOISEEVA	{"email": "e-moiseeva-1975@postgrespro.ru", "phone": "+70748011916"}
0005435082919	8E8095	0841 427550	LYUBOV IVANOVA	{"email": "ivanova.lyubov-13111967@postgrespro.ru", "phone": "+70996996855"}
0005435082920	E343A8	3780 257163	LYUDMILA CHERNOVA	{"phone": "+70622902115"}
0005435082921	E343A8	0698 225295	ARTUR MOROZOV	{"phone": "+70244737904"}
0005435082922	5A0467	6990 793423	ALEKSANDR ZAYCEV	{"phone": "+70608420585"}
0005435082923	5A0467	0987 135154	VLADIMIR VASILEV	{"email": "vvasilev_11091971@postgrespro.ru", "phone": "+70141658034"}
0005435082924	99A8C9	6161 786003	GALINA MATVEEVA	{"phone": "+70893942800"}
0005435082925	A1BE15	3993 343994	OLGA NESTEROVA	{"email": "nesterova.olga-011976@postgrespro.ru", "phone": "+70490480359"}
0005435082926	A1BE15	9059 164837	OLGA TARASOVA	{"phone": "+70547592410"}
0005435082927	539AEB	1880 522277	MIKHAIL SHEVCHENKO	{"phone": "+70129368803"}
0005435082928	24DA65	8403 588361	YULIYA TARASOVA	{"email": "yuliya-tarasova1965@postgrespro.ru", "phone": "+70428856104"}
0005435082929	601191	8427 986882	VIKTOR DMITRIEV	{"phone": "+70844435788"}
0005435082930	CEC3C6	2242 954787	ELVIRA BARANOVA	{"phone": "+70858267214"}
0005435082931	A8B1A4	8012 633435	LYUDMILA IVANOVA	{"email": "ivanova.l.09111972@postgrespro.ru", "phone": "+70433003509"}
0005435082932	2BF47C	7330 199494	ALEKSANDR NOVIKOV	{"phone": "+70117050782"}
0005435082933	039A50	4619 359636	NATALYA MAKAROVA	{"phone": "+70389047956"}
0005435082934	D9B2CE	0656 664921	VYACHESLAV TIKHONOV	{"phone": "+70569855040"}
0005435082935	D9B2CE	5192 464319	ILYA KULIKOV	{"phone": "+70699281075"}
0005435082936	52897B	7671 366786	MARIYA PAVLOVA	{"phone": "+70909657688"}
0005435082937	82AB9A	4161 893289	ARINA KRASNOVA	{"phone": "+70826379876"}
0005435082938	82AB9A	6533 351009	YURIY VOLKOV	{"email": "y-volkov_05091986@postgrespro.ru", "phone": "+70831767294"}
0005435082939	82AB9A	9300 276229	MARINA SEMENOVA	{"phone": "+70784308732"}
0005435082940	EFBA81	5273 957400	NATALYA IVANOVA	{"email": "n.ivanova_11061977@postgrespro.ru", "phone": "+70442610780"}
0005435082941	652044	3827 025164	DARYA KUZNECOVA	{"email": "darya.kuznecova.081969@postgrespro.ru", "phone": "+70568145460"}
0005435082942	E7DB9F	5121 719637	ANTONINA SCHERBAKOVA	{"email": "scherbakovaantonina_041976@postgrespro.ru", "phone": "+70196650428"}
0005435082943	E7DB9F	7929 628898	GALINA IVANOVA	{"phone": "+70241743133"}
0005435082944	7CC005	4933 469071	ANATOLIY MAKSIMOV	{"phone": "+70806516744"}
0005435082945	A11931	0548 305943	EVGENIYA ANTONOVA	{"phone": "+70580634545"}
0005435082946	B284B1	0119 048616	SERGEY ALEKSANDROV	{"email": "aleksandrov-sergey-1967@postgrespro.ru", "phone": "+70230423181"}
0005435082947	CFEC8C	4681 606041	TATYANA KONOVALOVA	{"phone": "+70191700691"}
0005435082948	A93F5B	7783 386876	SNEZHANA MIRONOVA	{"email": "s_mironova_081972@postgrespro.ru", "phone": "+70776946981"}
0005435082949	125CB5	3979 049052	VLADIMIR SOKOLOV	{"phone": "+70022632765"}
0005435082950	A5F4CD	0341 164472	OKSANA ZAKHAROVA	{"email": "oksana-zakharova-09021961@postgrespro.ru", "phone": "+70742141227"}
0005435082951	C63D6A	4165 271957	RUSTAM TIMOFEEV	{"phone": "+70626891233"}
0005435082952	1DF57A	5829 362729	VYACHESLAV TIKHONOV	{"phone": "+70970794347"}
0005435082953	91C3BC	2171 711659	YURIY GUSEV	{"phone": "+70779914821"}
0005435082954	91C3BC	9257 906794	EKATERINA ZHURAVLEVA	{"email": "ekaterina.zhuravleva.02021960@postgrespro.ru", "phone": "+70491277603"}
0005435082955	E2B4C4	6096 056554	GALINA ANTONOVA	{"email": "antonova_galina121971@postgrespro.ru", "phone": "+70520484601"}
0005435082956	5D10DF	2779 891350	DENIS MEDVEDEV	{"phone": "+70967519272"}
0005435082957	E6E6CA	6103 788827	YULIYA OSIPOVA	{"email": "y_osipova.041970@postgrespro.ru", "phone": "+70594077416"}
0005435082958	A08842	1534 501795	VLADIMIR PETROV	{"email": "petrov_vladimir.22111970@postgrespro.ru", "phone": "+70354727400"}
0005435082959	FFEC85	5504 090819	ALEKSANDRA EGOROVA	{"email": "egorova-a-07111971@postgrespro.ru", "phone": "+70723392480"}
0005435082960	FFEC85	1957 013618	ALEKSANDR SERGEEV	{"phone": "+70770168285"}
0005435082961	6D7838	5430 268366	OLEG FEDOROV	{"phone": "+70114280915"}
0005435082962	FD3CA2	0470 201385	YURIY FILIPPOV	{"email": "yuriy-filippov_1971@postgrespro.ru", "phone": "+70255312328"}
0005435082963	1D6538	5545 700016	NATALYA ISAEVA	{"email": "n.isaeva1975@postgrespro.ru", "phone": "+70134068933"}
0005435082964	1D6538	2743 591522	GALINA MOROZOVA	{"phone": "+70548979054"}
0005435082965	A51B4A	8799 361809	VLADIMIR FEDOROV	{"email": "fedorov.v-021969@postgrespro.ru", "phone": "+70954031949"}
0005435082966	D88A3B	8713 303481	ANNA SOKOLOVA	{"email": "sokolova-a.28021968@postgrespro.ru", "phone": "+70094113419"}
0005435082967	D88A3B	8694 065186	DMITRIY MELNIKOV	{"email": "melnikov.d06121961@postgrespro.ru", "phone": "+70185841819"}
0005435082968	DD62DC	0528 006634	IVAN NIKOLAEV	{"email": "ivan.nikolaev03021971@postgrespro.ru", "phone": "+70952857410"}
0005435082969	470592	3167 247247	OLGA VOROBEVA	{"email": "vorobeva_o.1972@postgrespro.ru", "phone": "+70605270626"}
0005435082970	3DD8FC	5235 945365	RUSTAM ANDREEV	{"email": "r_andreev.12021978@postgrespro.ru", "phone": "+70600095382"}
0005435082971	0B2D07	8739 609649	YURIY FROLOV	{"email": "yuriy.frolov20061984@postgrespro.ru", "phone": "+70068084312"}
0005435082972	0B2D07	5578 536507	SERGEY ROMANOV	{"phone": "+70688255536"}
0005435082973	6A2292	0870 981481	KLAVDIYA SOROKINA	{"email": "k_sorokina.101973@postgrespro.ru", "phone": "+70356633924"}
0005435082974	FCB84D	7136 926060	NATALYA SERGEEVA	{"email": "n.sergeeva_1966@postgrespro.ru", "phone": "+70185830571"}
0005435082975	F7D796	0976 312690	RAFIK DENISOV	{"phone": "+70223780447"}
0005435082976	7F08EA	3750 904596	NATALIYA YUDINA	{"email": "n.yudina_1965@postgrespro.ru", "phone": "+70841913733"}
0005435082977	5E649D	8819 633202	VLADIMIR MAKAROV	{"email": "makarov_v.06091976@postgrespro.ru", "phone": "+70194027008"}
0005435082978	D0E0EE	5852 874489	ILYA SMIRNOV	{"email": "i-smirnov-111977@postgrespro.ru", "phone": "+70905704449"}
0005435082979	26B17F	5032 290963	VASILIY RODIONOV	{"phone": "+70404750195"}
0005435082980	26B17F	4171 685671	YULIYA DANILOVA	{"email": "danilovayuliya_20041969@postgrespro.ru", "phone": "+70001008873"}
0005435082981	5EBB4F	6485 062662	TATYANA SOLOVEVA	{"phone": "+70580791259"}
0005435082982	5EBB4F	4019 008249	YURIY NAUMOV	{"email": "y-naumov_101985@postgrespro.ru", "phone": "+70786609948"}
0005435082983	BA7457	3763 241278	LYUDMILA ROMANOVA	{"email": "lyudmilaromanova1963@postgrespro.ru", "phone": "+70922236454"}
0005435082984	43C728	3554 474425	MARIYA ROMANOVA	{"email": "romanova-mariya.13061971@postgrespro.ru", "phone": "+70073641097"}
0005435082985	C63B70	7924 924390	NIKITA SERGEEV	{"phone": "+70541405919"}
0005435082986	991DDA	7174 703175	DANIIL SHEVCHENKO	{"phone": "+70001648450"}
0005435082987	BAA22F	4531 170312	MIKHAIL ALEKSANDROV	{"phone": "+70682516719"}
0005435082988	BAA22F	5037 195701	RAIS ROMANOV	{"email": "romanovrais_081970@postgrespro.ru", "phone": "+70818101922"}
0005435082989	250BE3	4738 699341	ALEKSANDR MARTYNOV	{"phone": "+70616227332"}
0005435082990	250BE3	6190 092666	EVGENIYA SOKOLOVA	{"email": "evgeniya_sokolova-23121983@postgrespro.ru", "phone": "+70518611035"}
0005435082991	751A95	4743 907246	NATALYA BELOVA	{"phone": "+70344597146"}
0005435082992	751A95	3783 787253	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev011966@postgrespro.ru", "phone": "+70306935543"}
0005435082993	0A8942	3512 113501	GALINA MELNIKOVA	{"email": "galina.melnikova101970@postgrespro.ru", "phone": "+70571191873"}
0005435082994	0A8942	2675 625186	KLAVDIYA DAVYDOVA	{"phone": "+70745037801"}
0005435082995	DFEF99	0732 372562	TATYANA KOZLOVA	{"email": "kozlova.t.17121978@postgrespro.ru", "phone": "+70119510639"}
0005435082996	4D5D4F	1574 783735	EVGENIY IVANOV	{"email": "ivanov-e-121977@postgrespro.ru", "phone": "+70734386914"}
0005435082997	B1235B	0665 667367	YULIYA POLYAKOVA	{"email": "polyakova_y111974@postgrespro.ru", "phone": "+70960173045"}
0005435082998	298A73	4904 978917	YULIYA ZAYCEVA	{"phone": "+70824432786"}
0005435082999	0BBB8D	7518 201009	VALERIY KOZLOV	{"phone": "+70184889630"}
0005435083000	DDDACA	8056 982084	DENIS MARTYNOV	{"phone": "+70466252879"}
0005435083001	6D3835	0859 249906	OLEG ZHUKOV	{"email": "zhukov-oleg1980@postgrespro.ru", "phone": "+70258285273"}
0005435083002	6D3835	9828 980783	ALEKSEY KOZLOV	{"email": "aleksey_kozlov_061971@postgrespro.ru", "phone": "+70291472029"}
0005435083003	6D3835	7788 516196	SERGEY ZAYCEV	{"email": "zaycev_s-14101970@postgrespro.ru", "phone": "+70729037622"}
0005435083004	C850C8	9233 958622	LARISA KUZNECOVA	{"email": "larisa-kuznecova.02081963@postgrespro.ru", "phone": "+70552107817"}
0005435083005	C850C8	4132 601704	SANIYA BORISOVA	{"phone": "+70726842032"}
0005435083006	DDF8F5	4934 105146	EKATERINA MEDVEDEVA	{"email": "ekaterina-medvedeva1971@postgrespro.ru", "phone": "+70180670321"}
0005435083007	DDF8F5	4496 647977	EGOR YAKOVLEV	{"email": "eyakovlev_1968@postgrespro.ru", "phone": "+70943526161"}
0005435083008	43C82F	2103 728458	VALENTINA TARASOVA	{"phone": "+70257590144"}
0005435083009	041B2E	2700 556280	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov1960@postgrespro.ru", "phone": "+70902670676"}
0005435083010	88F755	4939 934214	VALENTINA SOLOVEVA	{"email": "valentinasoloveva_021971@postgrespro.ru", "phone": "+70172725091"}
0005435083011	43BB49	2052 414529	MARIYA KUZNECOVA	{"email": "mkuznecova-07061967@postgrespro.ru", "phone": "+70144973626"}
0005435083012	43BB49	3544 778785	ELENA EFIMOVA	{"email": "elenaefimova-18101966@postgrespro.ru", "phone": "+70280636949"}
0005435083013	057331	9439 328333	TATYANA KULIKOVA	{"phone": "+70500099278"}
0005435083014	057331	6042 079913	OLGA GAVRILOVA	{"phone": "+70019095001"}
0005435083015	98085F	4052 218089	YULIYA VOLKOVA	{"email": "volkova_yuliya-1977@postgrespro.ru", "phone": "+70346138385"}
0005435083016	D96F25	5662 452016	ANATOLIY GORBUNOV	{"email": "gorbunov_anatoliy121973@postgrespro.ru", "phone": "+70329094916"}
0005435083017	16F3DA	8711 809661	ILGIZ KONOVALOV	{"phone": "+70403600611"}
0005435083018	D0832B	5787 531680	NATALYA ALEKSEEVA	{"email": "natalya-alekseeva-031974@postgrespro.ru", "phone": "+70882517676"}
0005435083019	D0832B	6835 950345	ALEKSANDR PAVLOV	{"email": "a_pavlov-1967@postgrespro.ru", "phone": "+70328543753"}
0005435083020	0A349C	4797 249605	TATYANA KUZNECOVA	{"email": "t.kuznecova.25101964@postgrespro.ru", "phone": "+70595263696"}
0005435083021	0A349C	6946 771700	TATYANA MOROZOVA	{"email": "morozovatatyana071972@postgrespro.ru", "phone": "+70906443109"}
0005435083022	90E0D7	0179 289738	VYACHESLAV SOKOLOV	{"email": "vyacheslav-sokolov.06081964@postgrespro.ru", "phone": "+70818933931"}
0005435083023	B49246	9979 127948	VALENTIN KAZAKOV	{"phone": "+70430167518"}
0005435083024	E4ED3A	9351 450791	ALEKSANDR DMITRIEV	{"phone": "+70589279702"}
0005435083025	634A1D	1759 211861	NADEZHDA SIDOROVA	{"phone": "+70258575728"}
0005435083026	95EECD	4000 844683	ALINA VOROBEVA	{"email": "vorobeva-a-16091975@postgrespro.ru", "phone": "+70845674525"}
0005435083027	95EECD	2753 674732	RAISA KOMAROVA	{"phone": "+70556256823"}
0005435083028	33C9E2	2008 212649	ANDREY EGOROV	{"email": "egorov.andrey05011979@postgrespro.ru", "phone": "+70361485262"}
0005435083029	4E0E91	2177 618435	KSENIYA KUZNECOVA	{"phone": "+70948051426"}
0005435083030	6FA6FB	0734 916059	SERGEY SOKOLOV	{"phone": "+70113528115"}
0005435083031	16C609	8704 622628	MARAT SOROKIN	{"phone": "+70577825468"}
0005435083032	E98C67	5696 623148	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov26021971@postgrespro.ru", "phone": "+70749584974"}
0005435083033	3F5F1D	4617 446755	YURIY VASILEV	{"phone": "+70683443399"}
0005435083034	846CD3	7600 844034	IVAN VLASOV	{"email": "ivan-vlasov03041971@postgrespro.ru", "phone": "+70849902302"}
0005435083035	64495B	6527 781170	SVETLANA VOROBEVA	{"phone": "+70886847718"}
0005435083036	002B46	3008 529163	ALEKSANDR POPOV	{"phone": "+70644227992"}
0005435083037	77D595	1066 877165	ILYA KISELEV	{"email": "i-kiselev-08041980@postgrespro.ru", "phone": "+70943844914"}
0005435083038	77D595	7088 807006	ELENA RODIONOVA	{"phone": "+70304171367"}
0005435083039	828ACC	3529 470359	ALEKSANDR IVANOV	{"email": "a-ivanov11011983@postgrespro.ru", "phone": "+70633592369"}
0005435083040	828ACC	2586 642408	IRINA KOZLOVA	{"email": "kozlovairina_1979@postgrespro.ru", "phone": "+70499285691"}
0005435086755	DC8BF5	7735 002454	TATYANA RODIONOVA	{"phone": "+70409137916"}
0005435086700	F00A3C	8537 171317	VLADISLAV KISELEV	{"email": "vladislav_kiselev_1985@postgrespro.ru", "phone": "+70745387046"}
0005435086701	DBA8E9	0387 094690	ELENA KOROLEVA	{"email": "koroleva-e.27091966@postgrespro.ru", "phone": "+70569976494"}
0005435086702	51E047	3014 141237	EVGENIYA ANDREEVA	{"phone": "+70289318551"}
0005435086703	75D50F	5995 744541	VIKTORIYA BORISOVA	{"email": "borisova.v_06011979@postgrespro.ru", "phone": "+70382812871"}
0005435086704	4AB832	9475 024915	BULAT SEMENOV	{"phone": "+70260890590"}
0005435086705	4AB832	2962 261682	ALEKSANDR GRIGOREV	{"email": "grigorev.a.051972@postgrespro.ru", "phone": "+70224782351"}
0005435086706	463A28	5184 179040	IGOR SOROKIN	{"phone": "+70419875632"}
0005435086707	D75DC9	9886 835433	TATYANA EFREMOVA	{"phone": "+70605019485"}
0005435086708	D75DC9	7233 016605	PETR ZHURAVLEV	{"email": "zhuravlev.petr-071965@postgrespro.ru", "phone": "+70621174086"}
0005435086709	FD4B65	3130 535929	VALENTINA ABRAMOVA	{"email": "abramovav_081974@postgrespro.ru", "phone": "+70520118737"}
0005435086710	CF0FE4	1734 194408	SVETLANA GRISHINA	{"email": "s.grishina-1962@postgrespro.ru", "phone": "+70264310784"}
0005435086711	CF0FE4	0970 457053	VLADIMIR BARANOV	{"phone": "+70143092067"}
0005435086712	72275F	3396 503882	NATALIYA NIKOLAEVA	{"email": "nnikolaeva.15121951@postgrespro.ru", "phone": "+70367382739"}
0005435086713	72275F	2387 758111	VALERIY PETROV	{"email": "valeriy-petrov_23021974@postgrespro.ru", "phone": "+70947520115"}
0005435086714	EE49C8	0274 783271	STEPAN GORBUNOV	{"phone": "+70444163497"}
0005435086715	EE49C8	9800 492275	MAKSIM KUZNECOV	{"phone": "+70645748920"}
0005435086716	E8390C	8544 454695	LARISA KRASNOVA	{"phone": "+70090747516"}
0005435086717	75FA3A	8366 126018	LIDIYA TIMOFEEVA	{"email": "l_timofeeva-031990@postgrespro.ru", "phone": "+70775925522"}
0005435086718	D4FF92	6961 663770	EKATERINA SOKOLOVA	{"phone": "+70589360787"}
0005435086719	D6EBFB	4719 352324	ARTEM VOROBEV	{"phone": "+70057662817"}
0005435086720	1B3DA1	9547 736141	MIKHAIL GAVRILOV	{"phone": "+70219404787"}
0005435086721	1B3DA1	5679 616278	TATYANA FEDOROVA	{"email": "tatyana.fedorova101963@postgrespro.ru", "phone": "+70925503480"}
0005435086722	DBB9E4	6647 520864	MAKSIM ALEKSEEV	{"email": "m-alekseev-121970@postgrespro.ru", "phone": "+70849743463"}
0005435086723	8102D4	9914 799947	DMITRIY DENISOV	{"phone": "+70235276942"}
0005435086724	CB5A46	4772 685167	SERGEY MAKSIMOV	{"email": "maksimov_sergey1972@postgrespro.ru", "phone": "+70917220286"}
0005435086725	F69C1B	7530 391519	ALEKSANDRA NAUMOVA	{"phone": "+70958609683"}
0005435086726	C4D366	4324 343957	IVAN MIKHAYLOV	{"email": "ivanmikhaylov-30081968@postgrespro.ru", "phone": "+70053358489"}
0005435086727	00EFCC	6122 582337	EVGENIY NIKOLAEV	{"email": "nikolaeve_101974@postgrespro.ru", "phone": "+70113156932"}
0005435086728	00EFCC	5522 328201	NADEZHDA LEBEDEVA	{"email": "n_lebedeva-031975@postgrespro.ru", "phone": "+70894746810"}
0005435086729	28DA37	0508 349322	ALEKSANDR ANDREEV	{"phone": "+70731012585"}
0005435086730	28DA37	4095 447857	EVDOKIYA NOVIKOVA	{"phone": "+70145954372"}
0005435086731	CE6D87	1544 951994	KSENIYA STEPANOVA	{"phone": "+70319812123"}
0005435086732	CE6D87	5180 715842	SERGEY ANTONOV	{"phone": "+70665830603"}
0005435086733	79D9F0	0064 022492	IRINA MELNIKOVA	{"email": "irinamelnikova08091980@postgrespro.ru", "phone": "+70000669542"}
0005435086734	79D9F0	8861 624185	ANDREY SOLOVEV	{"phone": "+70205023034"}
0005435086735	69B42B	7619 634619	ANATOLIY TIKHONOV	{"email": "tikhonov_anatoliy1967@postgrespro.ru", "phone": "+70224410791"}
0005435086736	69B42B	8756 785036	VALENTINA BORISOVA	{"email": "v_borisova_1979@postgrespro.ru", "phone": "+70005815894"}
0005435086737	61EF40	1852 206090	RUSLAN MAKAROV	{"email": "makarov.ruslan1956@postgrespro.ru", "phone": "+70562123502"}
0005435086738	C3F0E2	6799 826014	LYUDMILA ANDREEVA	{"phone": "+70837011504"}
0005435086739	59CFE8	5397 168915	VALENTINA BARANOVA	{"phone": "+70308212306"}
0005435086740	A3E52D	0557 505647	VADIM MAKAROV	{"email": "v-makarov_19091970@postgrespro.ru", "phone": "+70463659425"}
0005435086741	A3E52D	6232 857905	TATYANA VASILEVA	{"email": "vasileva-tatyana_1969@postgrespro.ru", "phone": "+70651183984"}
0005435086742	1B59FA	7794 168044	LYUDMILA ISAEVA	{"phone": "+70836073541"}
0005435086743	1B59FA	5631 518647	SVETLANA NOVIKOVA	{"phone": "+70649353144"}
0005435086744	1B59FA	7798 942849	SVETLANA MARTYNOVA	{"email": "s.martynova021974@postgrespro.ru", "phone": "+70615157044"}
0005435086745	BA978A	6425 598719	DMITRIY MIKHAYLOV	{"phone": "+70339312291"}
0005435086746	853CC4	9077 629446	SERGEY SEMENOV	{"email": "semenovsergey1965@postgrespro.ru", "phone": "+70175133518"}
0005435086747	67E0C9	4093 614781	ALEKSANDR PAVLOV	{"phone": "+70017787233"}
0005435086748	67E0C9	3577 729032	ALEKSANDR ZAYCEV	{"email": "zaycev_aleksandr_031974@postgrespro.ru", "phone": "+70965813425"}
0005435086749	5EEE53	2327 203820	SERGEY VOROBEV	{"phone": "+70616280472"}
0005435086750	D764E2	0946 231947	NINA ZAKHAROVA	{"phone": "+70517945281"}
0005435086751	FFE33F	5609 520885	TATYANA POPOVA	{"phone": "+70138493961"}
0005435086752	FFE33F	5966 183199	ALEKSANDR IVANOV	{"phone": "+70955236007"}
0005435086753	3C8193	4762 881826	DMITRIY SMIRNOV	{"phone": "+70781308633"}
0005435086754	3C8193	3301 043147	DMITRIY CHERNOV	{"phone": "+70487635757"}
0005435086756	DFA933	9647 482754	NINA EGOROVA	{"email": "n-egorova.081966@postgrespro.ru", "phone": "+70002380930"}
0005435086757	7970D9	7504 865316	NADEZHDA TIKHONOVA	{"email": "tikhonova-n-1960@postgrespro.ru", "phone": "+70426851404"}
0005435086758	787FE1	4733 083867	IGOR IVANOV	{"email": "ivanovi061975@postgrespro.ru", "phone": "+70962911590"}
0005435086759	EDF0C7	0374 576060	TAMARA BOGDANOVA	{"email": "bogdanova.tamara25061969@postgrespro.ru", "phone": "+70920334658"}
0005435086760	4FA06C	8565 310853	NATALYA VOLKOVA	{"email": "volkova_natalya1962@postgrespro.ru", "phone": "+70692455921"}
0005435086761	6AA940	1179 037597	ALEKSANDR ALEKSEEV	{"email": "alekseevaleksandr05041966@postgrespro.ru", "phone": "+70000195190"}
0005435086762	EEC3DA	8535 366145	ANATOLIY NIKITIN	{"email": "anatoliy-nikitin1965@postgrespro.ru", "phone": "+70500777646"}
0005435086763	EEC3DA	1969 575056	SERGEY MATVEEV	{"email": "sergeymatveev_11121977@postgrespro.ru", "phone": "+70458649731"}
0005435086764	6B9411	8832 182591	IVAN PAVLOV	{"phone": "+70329229899"}
0005435086765	6B9411	0825 433941	NINA MAKAROVA	{"email": "makarova-nina1966@postgrespro.ru", "phone": "+70513666720"}
0005435086766	79017A	8368 903910	VALENTINA KAZAKOVA	{"phone": "+70184198807"}
0005435086767	79017A	9174 263341	EVGENIY ANTONOV	{"email": "e.antonov081967@postgrespro.ru", "phone": "+70047974357"}
0005435086768	262C5B	5861 870629	TATYANA SOKOLOVA	{"phone": "+70579560889"}
0005435086769	D70A95	5233 017651	PLATON NIKITIN	{"email": "platon.nikitin_03011968@postgrespro.ru", "phone": "+70758053604"}
0005435086770	75AF3A	5527 566712	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila-1962@postgrespro.ru", "phone": "+70695025726"}
0005435086771	69F1EA	6915 897068	ALEKSANDR PETROV	{"phone": "+70377376811"}
0005435086772	14B177	8027 693865	YURIY DENISOV	{"phone": "+70570740621"}
0005435086773	14B177	5768 646996	LIDIYA KUZNECOVA	{"email": "lkuznecova.1968@postgrespro.ru", "phone": "+70328781559"}
0005435086774	F4081B	4182 952904	ALEKSEY SAVELEV	{"email": "a.savelev_17011972@postgrespro.ru", "phone": "+70395000965"}
0005435086775	B3D2B9	2179 604509	ALEKSANDR MAKSIMOV	{"phone": "+70690575958"}
0005435086776	790BEC	5976 314620	ALEKSEY STEPANOV	{"phone": "+70321253353"}
0005435086777	790BEC	5112 997168	ANGELINA KUZNECOVA	{"email": "a-kuznecova-021968@postgrespro.ru", "phone": "+70868289257"}
0005435086778	82D744	3869 971465	ANNA NIKITINA	{"email": "anna_nikitina-04071985@postgrespro.ru", "phone": "+70323453181"}
0005435086779	1C9C71	0461 488046	NADEZHDA DANILOVA	{"phone": "+70972889448"}
0005435086780	3B0A57	2543 616510	OLGA BELYAEVA	{"email": "olgabelyaeva-05021970@postgrespro.ru", "phone": "+70532945186"}
0005435086781	42184F	1812 892124	NINA BARANOVA	{"phone": "+70606882049"}
0005435086782	42184F	7766 406721	NATALYA SOLOVEVA	{"phone": "+70118981341"}
0005435086783	813534	2097 241239	MARINA KONOVALOVA	{"phone": "+70402510066"}
0005435086784	AFAD73	7020 464433	OLESYA NIKOLAEVA	{"phone": "+70732949365"}
0005435086785	707742	2898 444286	NIKOLAY PETROV	{"email": "petrov.n_1976@postgrespro.ru", "phone": "+70228244920"}
0005435086786	707742	6350 076593	ALINA YAKOVLEVA	{"email": "yakovleva_alina021980@postgrespro.ru", "phone": "+70261728460"}
0005435086787	637EAA	5579 075763	IRINA POTAPOVA	{"email": "irinapotapova.091980@postgrespro.ru", "phone": "+70169656184"}
0005435086788	4C8FE1	8179 161447	MARIYA MOROZOVA	{"phone": "+70252374919"}
0005435086789	4C8FE1	4908 069989	DARYA SOKOLOVA	{"phone": "+70720344970"}
0005435086790	DC2881	7050 736742	ANTON KRASNOV	{"email": "a-krasnov.121973@postgrespro.ru", "phone": "+70265437917"}
0005435086791	B02971	6942 886931	ALEKSANDR ISAEV	{"email": "a_isaev_04031977@postgrespro.ru", "phone": "+70825890789"}
0005435086792	8BD38D	0968 936853	VASILIY NOVIKOV	{"email": "v_novikov-011973@postgrespro.ru", "phone": "+70235328573"}
0005435086793	8BD38D	8776 089265	VIKTOR IVANOV	{"email": "viktor-ivanov-13091976@postgrespro.ru", "phone": "+70242056006"}
0005435086794	0D3031	8718 209782	GALINA VOROBEVA	{"phone": "+70867126846"}
0005435086795	0D3031	2727 254168	EVGENIYA MALYSHEVA	{"email": "malyshevaevgeniya.091972@postgrespro.ru", "phone": "+70374352742"}
0005435086796	4B4B40	2978 637611	ELENA IVANOVA	{"email": "e_ivanova061977@postgrespro.ru", "phone": "+70362289476"}
0005435086797	4B4B40	7136 610852	ELIZAVETA MEDVEDEVA	{"phone": "+70335496431"}
0005435086798	FE390E	1845 514135	ALEKSEY NAZAROV	{"email": "aleksey_nazarov_28081974@postgrespro.ru", "phone": "+70487816028"}
0005435086799	890A48	7741 009639	VERA ROMANOVA	{"email": "v.romanova-25041968@postgrespro.ru", "phone": "+70730921989"}
0005435086800	890A48	1672 172099	VLADIMIR STEPANOV	{"email": "v_stepanov.01081967@postgrespro.ru", "phone": "+70519733586"}
0005435086801	9A963A	2265 685669	EVGENIYA BOGDANOVA	{"email": "bogdanova_evgeniya06101973@postgrespro.ru", "phone": "+70334564246"}
0005435086802	383496	9294 478113	VALENTINA MAKAROVA	{"phone": "+70428774606"}
0005435086803	383496	5621 744951	INNA KISELEVA	{"phone": "+70574133308"}
0005435086804	D67F4F	2413 694370	GRIGORIY MATVEEV	{"email": "matveevgrigoriy101975@postgrespro.ru", "phone": "+70960686311"}
0005435086805	2C3596	6717 760470	VALERIYA ANISIMOVA	{"email": "valeriyaanisimova-1967@postgrespro.ru", "phone": "+70344878503"}
0005435086806	2C3596	0082 943390	ANNA GAVRILOVA	{"phone": "+70097798924"}
0005435086807	F7F35D	2808 040141	MARINA KOLESNIKOVA	{"email": "marinakolesnikova_1978@postgrespro.ru", "phone": "+70936016005"}
0005435086808	F7F35D	2980 564245	OLGA BARANOVA	{"phone": "+70781830059"}
0005435086809	040499	2121 627329	NATALYA VASILEVA	{"email": "n_vasileva-24091975@postgrespro.ru", "phone": "+70467891302"}
0005435086810	040499	8622 628663	MARIYA ROMANOVA	{"phone": "+70381258326"}
0005435086811	988094	3805 149682	VALERIY NIKITIN	{"email": "v_nikitin1960@postgrespro.ru", "phone": "+70275131985"}
0005435086812	4F685D	0674 882369	ANASTASIYA NIKITINA	{"phone": "+70751022001"}
0005435086813	C6E0A1	9141 537495	MAKSIM KUZNECOV	{"email": "maksim.kuznecov1978@postgrespro.ru", "phone": "+70365131166"}
0005435086814	C6E0A1	9708 888897	ANASTASIYA PETROVA	{"email": "petrovaa111968@postgrespro.ru", "phone": "+70005001134"}
0005435086815	2CAB57	7390 097806	OLGA KARPOVA	{"email": "karpova_o-1980@postgrespro.ru", "phone": "+70182319648"}
0005435086816	E8196D	5506 739091	ANDREY MOISEEV	{"phone": "+70765642436"}
0005435086817	9E562D	0446 286777	EKATERINA NESTEROVA	{"phone": "+70043828786"}
0005435086818	9E562D	1840 453598	LADA CHERNOVA	{"email": "l-chernova24031968@postgrespro.ru", "phone": "+70246234128"}
0005435086819	80FFE2	6079 555774	EVGENIY GERASIMOV	{"email": "e.gerasimov-13011986@postgrespro.ru", "phone": "+70335567398"}
0005435086820	17B8CF	8736 025821	ELENA KAZAKOVA	{"email": "kazakovae.081975@postgrespro.ru", "phone": "+70731060246"}
0005435086821	54C25E	7295 118051	VERA BOGDANOVA	{"email": "bogdanova-vera_101979@postgrespro.ru", "phone": "+70059029420"}
0005435086822	54C25E	5913 721773	VALENTINA DAVYDOVA	{"phone": "+70844857124"}
0005435086823	D2B1C2	1481 933263	NATALIYA MATVEEVA	{"email": "nataliya.matveeva.021975@postgrespro.ru", "phone": "+70432507429"}
0005435086824	4F0443	1503 354651	NIKOLAY MIKHAYLOV	{"phone": "+70923023452"}
0005435086825	2AF5D3	2812 524883	VITALIY KUZNECOV	{"email": "vitaliy.kuznecov21021977@postgrespro.ru", "phone": "+70047541267"}
0005435086826	621983	2704 228577	IRINA IVANOVA	{"email": "ivanova-irina01081974@postgrespro.ru", "phone": "+70075849608"}
0005435086827	88F2EA	7845 856363	ELENA NIKITINA	{"phone": "+70741619834"}
0005435086828	328C0F	6420 518567	YULIYA AFANASEVA	{"phone": "+70653328802"}
0005435086829	328C0F	2120 830533	ANATOLIY BELOV	{"email": "belov_a-1969@postgrespro.ru", "phone": "+70898294385"}
0005435086830	B47937	3441 642000	SERGEY NAUMOV	{"phone": "+70995378607"}
0005435086831	220EBC	0822 588021	EGOR GAVRILOV	{"phone": "+70373332706"}
0005435086832	0885A8	5551 394600	OLGA SMIRNOVA	{"phone": "+70769573975"}
0005435086833	0885A8	7147 892936	EVGENIYA OVCHINNIKOVA	{"email": "ovchinnikova_evgeniya10021969@postgrespro.ru", "phone": "+70835285682"}
0005435086834	0885A8	4409 702305	ALIYA KOROLEVA	{"email": "korolevaa041971@postgrespro.ru", "phone": "+70476367939"}
0005435086835	DCD082	6276 724881	PETR RODIONOV	{"email": "petr_rodionov_12091985@postgrespro.ru", "phone": "+70019916818"}
0005435086836	D31A6A	3183 810399	BORIS FEDOROV	{"phone": "+70325392998"}
0005435086837	9E7E4D	2634 480871	IRINA ZOTOVA	{"phone": "+70385902611"}
0005435086838	9E7E4D	7690 881033	KRISTINA FADEEVA	{"email": "kristina_fadeeva-31101982@postgrespro.ru", "phone": "+70905835146"}
0005435086839	658CA8	4934 454727	NATALYA SOLOVEVA	{"email": "n-soloveva-03101962@postgrespro.ru", "phone": "+70985678716"}
0005435086840	F0F7D2	8437 279085	VALENTINA ALEKSANDROVA	{"email": "aleksandrovavalentina1979@postgrespro.ru", "phone": "+70506416892"}
0005435086841	4BF6E4	2052 965731	ALINA FEDOROVA	{"email": "fedorova-alina_071983@postgrespro.ru", "phone": "+70471189942"}
0005435086842	2406E8	0267 657275	PETR TARASOV	{"phone": "+70816635738"}
0005435086843	F23938	4629 666818	ALEKSEY NIKITIN	{"phone": "+70435659532"}
0005435086844	2DFC77	6723 800364	VYACHESLAV RODIONOV	{"email": "vyacheslav-rodionov-30061975@postgrespro.ru", "phone": "+70397315141"}
0005435086845	2DFC77	2745 942960	TAMARA ZAYCEVA	{"phone": "+70339248727"}
0005435086846	8268D8	8117 271822	ANNA TARASOVA	{"email": "a.tarasova.101982@postgrespro.ru", "phone": "+70163542841"}
0005435086847	A0083E	1592 308851	VLADIMIR VLASOV	{"email": "vlasov_vladimir_1967@postgrespro.ru", "phone": "+70170995988"}
0005435086848	5A6116	7446 313465	ALEKSEY TARASOV	{"email": "aleksey-tarasov.1964@postgrespro.ru", "phone": "+70508684566"}
0005435086849	052F3F	9605 786874	OLGA PAVLOVA	{"phone": "+70620210693"}
0005435086850	052F3F	3886 561728	NIKOLAY ALEKSEEV	{"phone": "+70563338158"}
0005435086851	C0DB8D	2621 153023	LARISA KOVALEVA	{"phone": "+70046021076"}
0005435086852	C0DB8D	3167 962807	NADEZHDA IVANOVA	{"email": "nadezhda-ivanova011977@postgrespro.ru", "phone": "+70579973321"}
0005435086853	9D81D5	6902 477612	LARISA GORBUNOVA	{"email": "larisa-gorbunova011971@postgrespro.ru", "phone": "+70328351799"}
0005435086854	2EF833	7498 360462	VLADIMIR KOZLOV	{"email": "vkozlov28071952@postgrespro.ru", "phone": "+70800884876"}
0005435086855	16EDA7	8374 985039	NADEZHDA KOROLEVA	{"email": "korolevan.31011976@postgrespro.ru", "phone": "+70051142177"}
0005435086856	16EDA7	4442 571027	MAYA KOROLEVA	{"phone": "+70828048103"}
0005435086857	34869E	3968 115068	SERGEY TIKHONOV	{"phone": "+70002149862"}
0005435086858	34869E	0487 760865	EVA ZAKHAROVA	{"email": "eva.zakharova-051967@postgrespro.ru", "phone": "+70178492903"}
0005435086859	C5302F	0132 647334	DINARA GRISHINA	{"phone": "+70306034842"}
0005435086860	C5302F	4540 591927	PAVEL YAKOVLEV	{"email": "yakovlev_pavel_061977@postgrespro.ru", "phone": "+70746622475"}
0005435086861	76A3F1	7497 663268	PAVEL ISAEV	{"email": "isaevp_27021969@postgrespro.ru", "phone": "+70507427789"}
0005435086862	177A6D	0113 686774	NATALIYA KAZAKOVA	{"phone": "+70846154920"}
0005435086863	437C27	2807 163751	LYUBOV TROFIMOVA	{"email": "l-trofimova-1971@postgrespro.ru", "phone": "+70998949959"}
0005435086864	1EE241	7414 098909	TATYANA ARKHIPOVA	{"email": "arkhipova_tatyana-081973@postgrespro.ru", "phone": "+70916807455"}
0005435086865	6B4B37	0644 204124	YURIY ISAEV	{"phone": "+70924790065"}
0005435086866	6B4B37	0685 652491	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina_121978@postgrespro.ru", "phone": "+70649957181"}
0005435086867	7E4DA4	7802 201720	OKSANA ORLOVA	{"phone": "+70031649654"}
0005435086868	939E5B	5396 462148	ELENA SEMENOVA	{"email": "elena_semenova.051979@postgrespro.ru", "phone": "+70502136271"}
0005435086869	939E5B	4836 781623	VLADIMIR SERGEEV	{"email": "sergeev.v26111974@postgrespro.ru", "phone": "+70573521799"}
0005435086870	939E5B	9367 619325	POLINA FROLOVA	{"phone": "+70076432945"}
0005435086871	C2B2A2	7291 838289	VYACHESLAV FROLOV	{"phone": "+70293800177"}
0005435086872	A8D2AD	0075 831964	NATALYA LAZAREVA	{"phone": "+70065566604"}
0005435086873	AEB2B1	0039 573868	NIKOLAY TARASOV	{"phone": "+70465997635"}
0005435086874	AB4511	3482 198889	VLADIMIR SOROKIN	{"email": "sorokin_v.061976@postgrespro.ru", "phone": "+70075188953"}
0005435086875	AB4511	2898 081163	DENIS IVANOV	{"email": "ivanov.d051977@postgrespro.ru", "phone": "+70252001557"}
0005435086876	F6A658	1457 191762	LYUDMILA NOVIKOVA	{"email": "novikova_lyudmila03011976@postgrespro.ru", "phone": "+70846331860"}
0005435086877	F6A658	1565 006290	SERGEY ALEKSANDROV	{"email": "s-aleksandrov-091977@postgrespro.ru", "phone": "+70141427234"}
0005435086878	B83175	1983 346352	ALEKSANDR KUDRYASHOV	{"phone": "+70511053913"}
0005435086879	B83175	7775 990580	TAMARA POPOVA	{"phone": "+70912278775"}
0005435086880	0721C5	6828 172577	VALENTINA PAVLOVA	{"phone": "+70842332393"}
0005435086881	0721C5	9142 692390	SERGEY SERGEEV	{"phone": "+70630508121"}
0005435086882	A5DD8F	8073 960343	OLGA ZAYCEVA	{"email": "o_zayceva23051975@postgrespro.ru", "phone": "+70187755822"}
0005435086883	13DEF9	6284 943234	MIKHAIL ROMANOV	{"email": "romanov-mikhail-1969@postgrespro.ru", "phone": "+70412953086"}
0005435086884	13DEF9	5112 948176	NIKOLAY ANDREEV	{"phone": "+70148406723"}
0005435086885	DD001D	0845 151318	ILYA SMIRNOV	{"email": "ilya_smirnov21011965@postgrespro.ru", "phone": "+70299571979"}
0005435086886	F41341	4702 914506	ALFIYA SOROKINA	{"phone": "+70354481894"}
0005435086887	B39C57	1300 429476	ALEKSEY KUDRYASHOV	{"email": "alekseykudryashov071968@postgrespro.ru", "phone": "+70749944072"}
0005435086888	B39C57	5969 393421	ALFIYA NAUMOVA	{"email": "a-naumova-111964@postgrespro.ru", "phone": "+70924011325"}
0005435086889	B4F7B3	5564 638018	EKATERINA EGOROVA	{"phone": "+70493169145"}
0005435086890	33D2CA	5380 942314	SERGEY DENISOV	{"email": "denisov-sergey_1976@postgrespro.ru", "phone": "+70618481658"}
0005435086891	7C9814	0340 485180	ALEKSANDR FROLOV	{"phone": "+70173583567"}
0005435086892	5116DB	7776 589463	SERGEY KOROLEV	{"email": "korolevs111977@postgrespro.ru", "phone": "+70742434175"}
0005435086893	0C046F	8771 738024	VALENTINA BORISOVA	{"email": "borisovavalentina_1964@postgrespro.ru", "phone": "+70373749535"}
0005435086894	D0FB2E	0114 115709	LYUDMILA ANDREEVA	{"email": "lyudmila-andreeva.031974@postgrespro.ru", "phone": "+70332837463"}
0005435086895	BF346D	1263 845641	ANNA SMIRNOVA	{"phone": "+70969171421"}
0005435086896	7C88A5	5135 211227	NATALYA SIDOROVA	{"phone": "+70034933310"}
0005435086897	04F72F	3472 921925	ILYA BARANOV	{"phone": "+70505515487"}
0005435086898	C6AB32	0017 803019	OLESYA TIMOFEEVA	{"phone": "+70142379397"}
0005435086899	7B4119	3071 108024	VLADIMIR ORLOV	{"phone": "+70072746742"}
0005435086900	6F4D1F	1718 282778	VIKTOR FEDOROV	{"phone": "+70930220666"}
0005435086901	18BB1C	0466 765761	PAVEL VOROBEV	{"phone": "+70992895687"}
0005435086902	18BB1C	5249 091451	RAISA KAZAKOVA	{"email": "kazakova_r1970@postgrespro.ru", "phone": "+70535089406"}
0005435086903	FAA904	5618 995762	ANDREY ABRAMOV	{"phone": "+70945491125"}
0005435086904	130B5D	8122 601411	IGOR KRASNOV	{"phone": "+70078567921"}
0005435086905	113C82	8260 480986	VALENTINA IVANOVA	{"phone": "+70879249835"}
0005435086906	BA01EB	1313 147870	INNA KUDRYASHOVA	{"email": "ikudryashova1976@postgrespro.ru", "phone": "+70836447576"}
0005435086907	AD2763	5903 165889	OLGA NAZAROVA	{"phone": "+70037218706"}
0005435086908	AD2763	7046 423623	YULIYA YAKOVLEVA	{"phone": "+70132002273"}
0005435086909	D39243	2119 661503	ALEKSANDR OSIPOV	{"email": "aleksandr.osipov-19061973@postgrespro.ru", "phone": "+70632043828"}
0005435086910	5D1F7E	8206 569647	PELAGEYA MELNIKOVA	{"phone": "+70648863838"}
0005435086911	344A62	4109 891702	NADEZHDA VASILEVA	{"email": "n_vasileva_11101969@postgrespro.ru", "phone": "+70805328006"}
0005435086912	344A62	6191 997675	LYUBOV DAVYDOVA	{"email": "lyubov.davydova-081975@postgrespro.ru", "phone": "+70636853157"}
0005435086913	6A2FD1	1986 688551	ANNA STEPANOVA	{"phone": "+70273408928"}
0005435086914	6A2FD1	8464 931488	TIMOFEY MIRONOV	{"email": "t_mironov-111975@postgrespro.ru", "phone": "+70455671096"}
0005435086915	E917D1	3600 829331	TATYANA KOVALEVA	{"phone": "+70414213698"}
0005435086916	FCF005	5837 641862	EVGENIY ALEKSEEV	{"email": "alekseevevgeniy.111974@postgrespro.ru", "phone": "+70272720937"}
0005435086917	AF5F06	9312 016498	VLADIMIR IVANOV	{"phone": "+70880007982"}
0005435086918	AF5F06	6269 149279	LIDIYA KULIKOVA	{"phone": "+70356123744"}
0005435086919	AF5F06	5530 794934	VALENTINA ARKHIPOVA	{"phone": "+70148986635"}
0005435086920	F5075C	8139 535213	VADIM PAVLOV	{"email": "v_pavlov-22111977@postgrespro.ru", "phone": "+70600095899"}
0005435086921	F5075C	3102 202867	NINA YAKOVLEVA	{"email": "yakovleva-nina_111964@postgrespro.ru", "phone": "+70240220763"}
0005435086922	7491BB	6669 048073	EVGENIY FOMIN	{"email": "fominevgeniy1982@postgrespro.ru", "phone": "+70849511928"}
0005435086923	7491BB	3758 018340	KLAVDIYA KOROLEVA	{"phone": "+70703704966"}
0005435086924	D328E4	4491 780282	TAMARA MIRONOVA	{"email": "mironova_tamara.1962@postgrespro.ru", "phone": "+70817997417"}
0005435086925	1671A4	1689 547377	ARTEM GORBUNOV	{"phone": "+70350282803"}
0005435086926	BD65CE	6223 494789	ALEKSANDR GUSEV	{"email": "aleksandr.gusev_1966@postgrespro.ru", "phone": "+70106628977"}
0005435086927	B4D04E	6874 593971	ANATOLIY NAZAROV	{"email": "a-nazarov.01031965@postgrespro.ru", "phone": "+70309369081"}
0005435086928	B4D04E	9938 787179	LYUBOV ANTONOVA	{"email": "lyubov_antonova19061967@postgrespro.ru", "phone": "+70849904995"}
0005435086929	CF3D02	4637 133925	YULIYA NAZAROVA	{"email": "nazarova_y-1966@postgrespro.ru", "phone": "+70446848383"}
0005435086930	CF3D02	0473 613634	ANNA MASLOVA	{"email": "maslova-a-31121970@postgrespro.ru", "phone": "+70613584548"}
0005435086931	10F9F2	7493 443071	VERA ARKHIPOVA	{"phone": "+70977374967"}
0005435086932	9E2DC1	9086 538314	MIKHAIL DMITRIEV	{"email": "mikhail_dmitriev_09071966@postgrespro.ru", "phone": "+70485634911"}
0005435086933	9E2DC1	6645 311766	GLEB DAVYDOV	{"phone": "+70244969812"}
0005435086934	9E2DC1	1590 910516	VASILIY BARANOV	{"phone": "+70119945220"}
0005435086935	778816	5159 980965	NINA POPOVA	{"email": "popova-nina_1967@postgrespro.ru", "phone": "+70187319725"}
0005435086936	778816	9380 680062	GALINA KUZNECOVA	{"phone": "+70527549122"}
0005435086937	2E3CCC	4331 503630	YULIYA BORISOVA	{"email": "y_borisova1980@postgrespro.ru", "phone": "+70985603906"}
0005435086938	2E3CCC	3498 430445	VITALIY SMIRNOV	{"email": "smirnov_vitaliy.031976@postgrespro.ru", "phone": "+70999452456"}
0005435086939	B95A0D	5436 002190	SEMEN IVANOV	{"email": "semen-ivanov1972@postgrespro.ru", "phone": "+70560477932"}
0005435086940	D2438D	4849 829316	VIKTOR ALEKSEEV	{"phone": "+70475043981"}
0005435086941	5A123C	9546 515274	TATYANA VOROBEVA	{"phone": "+70469445282"}
0005435086942	51D793	2532 211820	EVGENIY DAVYDOV	{"email": "evgeniy.davydov.1977@postgrespro.ru", "phone": "+70899249493"}
0005435086943	541B20	6023 115777	NATALIYA FADEEVA	{"email": "fadeeva.n091971@postgrespro.ru", "phone": "+70705104339"}
0005435086944	B0A74F	3612 793985	NINA KRASNOVA	{"email": "ninakrasnova_121972@postgrespro.ru", "phone": "+70543771799"}
0005435086945	B0A74F	9899 701561	ELENA DAVYDOVA	{"email": "davydova_e-1984@postgrespro.ru", "phone": "+70095891783"}
0005435086946	657340	6370 329133	EVGENIY KONOVALOV	{"phone": "+70960926903"}
0005435086947	29FD6D	0283 270761	LYUDMILA BORISOVA	{"phone": "+70251435487"}
0005435086948	29FD6D	7610 606657	VIKTOR KARPOV	{"email": "karpov_v041979@postgrespro.ru", "phone": "+70319594528"}
0005435086949	DA21FC	6367 964424	VIKTOR AFANASEV	{"phone": "+70527425695"}
0005435086950	DA21FC	8612 090490	YULIYA MIRONOVA	{"phone": "+70478780269"}
0005435086951	DA71D0	0089 792176	SVETLANA TITOVA	{"email": "titova.svetlana.08011970@postgrespro.ru", "phone": "+70170870440"}
0005435086952	FF5F59	9021 692544	VLADIMIR SMIRNOV	{"phone": "+70231046928"}
0005435086953	6E5F83	6689 064014	DARYA ALEKSANDROVA	{"phone": "+70721874636"}
0005435086954	B2FF5B	7004 884540	ALEKSEY TIMOFEEV	{"phone": "+70982479359"}
0005435086955	406A42	8782 741345	OLGA VOLKOVA	{"phone": "+70830591164"}
0005435086956	23DE1A	5768 850220	ALEKSEY TARASOV	{"email": "aleksey.tarasov21021971@postgrespro.ru", "phone": "+70184347067"}
0005435086957	A3E491	3019 074248	NINA VLASOVA	{"email": "vlasova-n021973@postgrespro.ru", "phone": "+70913531196"}
0005435086958	264AC5	9358 946338	KSENIYA FADEEVA	{"email": "k-fadeeva.121961@postgrespro.ru", "phone": "+70447558803"}
0005435086959	234084	1661 435882	OLEG ORLOV	{"email": "orlov_o24031973@postgrespro.ru", "phone": "+70266406081"}
0005435086960	B48A58	4588 576378	ALEKSANDR MOROZOV	{"phone": "+70644373793"}
0005435086961	C352C1	9212 421592	LIDIYA SMIRNOVA	{"phone": "+70513610084"}
0005435086962	C352C1	9933 438901	ZHANNA ALEKSANDROVA	{"email": "aleksandrova_zhanna.09051984@postgrespro.ru", "phone": "+70787263482"}
0005435086963	2CC002	6656 003708	ANNA KOROLEVA	{"email": "anna.koroleva.23021977@postgrespro.ru", "phone": "+70255794569"}
0005435086964	76E8E3	5455 552562	YULIYA ZOTOVA	{"phone": "+70843695056"}
0005435086965	12A49C	8899 138128	ELIZAVETA KONOVALOVA	{"email": "konovalova-e_041986@postgrespro.ru", "phone": "+70783844991"}
0005435086966	12A49C	3719 240257	VLADIMIR KUDRYASHOV	{"email": "vladimirkudryashov051967@postgrespro.ru", "phone": "+70695956858"}
0005435086967	40AEEB	0937 626107	IRINA VLASOVA	{"phone": "+70981289514"}
0005435086968	C7AEC6	3321 618993	YURIY MOROZOV	{"phone": "+70031041539"}
0005435086969	4B758B	3335 988185	SVETLANA SIDOROVA	{"email": "sidorova-s041965@postgrespro.ru", "phone": "+70599651861"}
0005435086970	4B758B	4281 996677	SERGEY GRIGOREV	{"phone": "+70237906087"}
0005435086971	1D7288	9603 672248	NINA MIKHAYLOVA	{"phone": "+70228007023"}
0005435086972	67EE9D	0126 286054	OLGA SCHERBAKOVA	{"phone": "+70801348625"}
0005435086973	21FF6E	7158 024244	TATYANA POPOVA	{"phone": "+70592117618"}
0005435086974	21FF6E	2612 932342	SERGEY MIKHAYLOV	{"phone": "+70428431229"}
0005435086975	21FF6E	4940 099897	NATALYA MOISEEVA	{"phone": "+70347954536"}
0005435086976	D1CD07	0850 622129	EKATERINA ARKHIPOVA	{"email": "e_arkhipova.021967@postgrespro.ru", "phone": "+70411939987"}
0005435086977	218A75	6300 146785	ANATOLIY AFANASEV	{"email": "afanasev_anatoliy_021975@postgrespro.ru", "phone": "+70949225212"}
0005435086978	34BBCF	5570 197507	ELENA KOROLEVA	{"phone": "+70113418945"}
0005435086979	1357A8	8105 827170	LYUDMILA KAZAKOVA	{"phone": "+70601474479"}
0005435086980	FBC9DE	6274 309456	NADEZHDA ORLOVA	{"email": "n-orlova091985@postgrespro.ru", "phone": "+70729391386"}
0005435086981	6DC579	4534 420610	ALEKSANDR ISAEV	{"phone": "+70117218059"}
0005435086982	C7A690	3068 757314	IRINA PAVLOVA	{"email": "pavlovairina-05121978@postgrespro.ru", "phone": "+70524130885"}
0005435086983	54D1E8	0496 294836	ALISA ALEKSEEVA	{"phone": "+70629851545"}
0005435086984	54D1E8	8496 324151	NIKOLAY ZAKHAROV	{"email": "zakharov_nikolay-021965@postgrespro.ru", "phone": "+70895434323"}
0005435086985	4F1BFE	5796 022881	TAMARA ZAKHAROVA	{"email": "tamarazakharova_14091975@postgrespro.ru", "phone": "+70877346334"}
0005435086986	4F1BFE	6844 025284	ALEKSANDRA LUKYANOVA	{"email": "a_lukyanova1971@postgrespro.ru", "phone": "+70171522197"}
0005435086987	4F1BFE	0456 756235	RIMA MATVEEVA	{"email": "matveeva-rima_1975@postgrespro.ru", "phone": "+70178804766"}
0005435086988	817B75	0409 142704	SERGEY MARTYNOV	{"phone": "+70664921385"}
0005435086989	505206	3978 287913	VIKTOR TARASOV	{"phone": "+70978350061"}
0005435086990	505206	2236 016391	SVETLANA FROLOVA	{"email": "svetlana.frolova091972@postgrespro.ru", "phone": "+70769205954"}
0005435086991	43C186	3817 194142	TAMARA MAKAROVA	{"email": "makarovatamara061967@postgrespro.ru", "phone": "+70802315795"}
0005435086992	43C186	6378 007573	TATYANA KUZMINA	{"phone": "+70787563747"}
0005435086993	8B1147	2706 839652	GALINA TIMOFEEVA	{"email": "timofeevag-071974@postgrespro.ru", "phone": "+70505071630"}
0005435086994	F6DFDD	3105 334690	MAKSIM NOVIKOV	{"phone": "+70691366109"}
0005435086995	F6DFDD	7263 481320	LYUBOV MAKAROVA	{"email": "makarova_lyubov.1979@postgrespro.ru", "phone": "+70686365579"}
0005435086996	B65039	2916 586989	ALBINA KUZNECOVA	{"email": "kuznecovaa_1982@postgrespro.ru", "phone": "+70030487886"}
0005435086997	B65039	7903 980250	OLGA TIMOFEEVA	{"phone": "+70255070269"}
0005435086998	CAA2E5	1973 709266	ELENA MELNIKOVA	{"phone": "+70230000507"}
0005435086999	CAA2E5	4287 207368	OLGA PAVLOVA	{"email": "olgapavlova071974@postgrespro.ru", "phone": "+70229439900"}
0005435087000	065595	6580 718260	ALEKSANDR NIKOLAEV	{"email": "nikolaev.a.101979@postgrespro.ru", "phone": "+70153950232"}
0005435087001	3F4EE5	6530 765239	ANASTASIYA KUZMINA	{"email": "kuzmina-a.091975@postgrespro.ru", "phone": "+70336391998"}
0005435087002	60727B	8469 914993	RINAT NAZAROV	{"email": "nazarov-r02091976@postgrespro.ru", "phone": "+70252181008"}
0005435087003	60727B	9556 507992	YULIYA GAVRILOVA	{"email": "yuliya-gavrilova051971@postgrespro.ru", "phone": "+70857205889"}
0005435087004	A81DDA	7500 237682	OLEG ZAYCEV	{"email": "o_zaycev-1972@postgrespro.ru", "phone": "+70395899616"}
0005435087005	7BE46B	5472 712858	ANNA EGOROVA	{"email": "egorova-anna.05071973@postgrespro.ru", "phone": "+70753793820"}
0005435087006	C6A549	5862 748763	VLADIMIR TIKHONOV	{"email": "v.tikhonov.18091965@postgrespro.ru", "phone": "+70244937779"}
0005435087007	6B02CE	7509 996593	ALEKSANDR SOLOVEV	{"email": "aleksandr_solovev-1974@postgrespro.ru", "phone": "+70105350216"}
0005435087008	DD9A5F	4535 540764	GLEB IVANOV	{"email": "ivanov_gleb.22051969@postgrespro.ru", "phone": "+70952873103"}
0005435087009	B2940F	0364 753521	VLADIMIR SOROKIN	{"phone": "+70009073644"}
0005435087010	CCC107	2400 787101	NIKOLAY FEDOTOV	{"email": "n-fedotov-091970@postgrespro.ru", "phone": "+70180630490"}
0005435087011	160809	1533 774280	VERA MIKHAYLOVA	{"email": "mikhaylovav_041965@postgrespro.ru", "phone": "+70803611543"}
0005435087012	116B6B	2135 532691	NATALYA OSIPOVA	{"email": "n-osipova_23091985@postgrespro.ru", "phone": "+70130136284"}
0005435087013	DAE8DA	9829 842590	VLADIMIR GERASIMOV	{"email": "gerasimov-vladimir-091965@postgrespro.ru", "phone": "+70774022178"}
0005435087014	DAE8DA	4644 687382	YULIYA ILINA	{"phone": "+70475296872"}
0005435087015	89C8A9	4262 515622	IVAN NAZAROV	{"phone": "+70678293922"}
0005435087016	89C8A9	0905 121349	NIKOLAY STEPANOV	{"email": "stepanovn_121985@postgrespro.ru", "phone": "+70640616848"}
0005435087017	89C8A9	8791 477877	ALEKSANDR NAZAROV	{"email": "nazarova-1973@postgrespro.ru", "phone": "+70038563392"}
0005435087018	07E44F	6762 576750	FARIT FEDOROV	{"phone": "+70486671375"}
0005435087019	A31F43	5904 386730	ALEKSANDR PAVLOV	{"phone": "+70586001168"}
0005435087020	F77C9C	8033 990054	ELENA PETROVA	{"phone": "+70946301796"}
0005435087021	F77C9C	0506 496171	EKATERINA VOROBEVA	{"email": "ekaterina_vorobeva_12021973@postgrespro.ru", "phone": "+70819795549"}
0005435087022	65ACFF	8336 260300	YANA KAZAKOVA	{"phone": "+70841390914"}
0005435087023	1D000B	5592 157913	EVGENIY SAVELEV	{"email": "savelev-e.111972@postgrespro.ru", "phone": "+70951831699"}
0005435087024	D8CA2F	2943 208200	ELENA ZHUKOVA	{"phone": "+70924066823"}
0005435087025	D8CA2F	5184 394015	EVGENIY KULIKOV	{"phone": "+70702732507"}
0005435087026	26FD7A	4823 325269	VASILIY SOROKIN	{"phone": "+70662159501"}
0005435087027	22BE7A	3252 348139	LIDIYA POLYAKOVA	{"email": "l_polyakova.08101961@postgrespro.ru", "phone": "+70846048760"}
0005435087028	327409	1967 938739	TATYANA POPOVA	{"email": "popova-t-30031983@postgrespro.ru", "phone": "+70439272544"}
0005435087029	327409	5791 013841	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov_08071970@postgrespro.ru", "phone": "+70687422734"}
0005435087030	1C977D	4477 033873	MARINA EGOROVA	{"email": "egorova-marina-011974@postgrespro.ru", "phone": "+70652477800"}
0005435087031	C6FC97	2983 782825	NADEZHDA SIDOROVA	{"phone": "+70695183036"}
0005435087032	C6FC97	7049 687589	TATYANA ORLOVA	{"phone": "+70456981450"}
0005435087033	F7221A	9833 583783	TATYANA KONOVALOVA	{"email": "t-konovalova-27051966@postgrespro.ru", "phone": "+70970899897"}
0005435087034	D3F572	1432 334743	ALEKSEY KARPOV	{"email": "karpov-aleksey_011980@postgrespro.ru", "phone": "+70178608815"}
0005435087035	E459C3	7393 179859	SERGEY STEPANOV	{"phone": "+70198029069"}
0005435087036	F3C853	3270 571677	VALENTINA LOGINOVA	{"email": "loginova.v_02011979@postgrespro.ru", "phone": "+70681523437"}
0005435087037	C7C07B	7839 165653	MARAT ZHUKOV	{"phone": "+70346166516"}
0005435087038	10C928	9991 947375	ELIZAVETA DENISOVA	{"email": "e_denisova-16031968@postgrespro.ru", "phone": "+70630877038"}
0005435087039	10C928	2608 770006	TAMARA POPOVA	{"phone": "+70153870714"}
0005435087040	210C1E	0837 864629	VLADIMIR BELOV	{"email": "belov_v_071971@postgrespro.ru", "phone": "+70773307129"}
0005435087041	76333E	8648 186703	VIKTOR ZAKHAROV	{"phone": "+70098037664"}
0005435087042	928EDD	2546 774197	GALINA DMITRIEVA	{"email": "gdmitrieva_15121969@postgrespro.ru", "phone": "+70322401543"}
0005435087043	F0838C	5290 244827	VYACHESLAV FEDOTOV	{"phone": "+70428412454"}
0005435087044	69CDA3	9276 576326	ANASTASIYA MAKAROVA	{"email": "a_makarova07071973@postgrespro.ru", "phone": "+70468753644"}
0005435087045	781ECA	4353 970801	NIKOLAY MEDVEDEV	{"email": "n_medvedev-021985@postgrespro.ru", "phone": "+70412400542"}
0005435087046	1C8C14	6095 562357	MIKHAIL ANDREEV	{"email": "andreev_m.061971@postgrespro.ru", "phone": "+70639073186"}
0005435087047	B8699F	5306 421966	ANDREY GORBUNOV	{"email": "gorbunova.07061977@postgrespro.ru", "phone": "+70989983004"}
0005435087048	B8699F	9412 587010	ELENA KONOVALOVA	{"email": "konovalova-elena_101973@postgrespro.ru", "phone": "+70105415505"}
0005435087049	2035A4	5009 505774	ANDREY SCHERBAKOV	{"email": "scherbakov_andrey.19051973@postgrespro.ru", "phone": "+70639277131"}
0005435087050	2035A4	1098 373809	TATYANA LUKYANOVA	{"email": "t.lukyanova.07111969@postgrespro.ru", "phone": "+70838872097"}
0005435087051	F99C45	8199 571948	NATALYA MAKAROVA	{"email": "natalya-makarova1978@postgrespro.ru", "phone": "+70074332886"}
0005435087052	FF4EFF	6689 729819	TATYANA ORLOVA	{"phone": "+70340876232"}
0005435087053	FF4EFF	3135 162291	VITALIY SIDOROV	{"email": "v_sidorov_18031966@postgrespro.ru", "phone": "+70272416497"}
0005435087054	095ABD	0626 060929	TATYANA SOKOLOVA	{"email": "tatyana.sokolova.15051979@postgrespro.ru", "phone": "+70608277993"}
0005435087055	9DADEF	7174 414983	TIMUR CHERNOV	{"phone": "+70103240151"}
0005435087056	B31CA5	1763 339425	ELENA ZAKHAROVA	{"email": "e.zakharova-051975@postgrespro.ru", "phone": "+70196270820"}
0005435087057	5C9B6D	4747 130981	POLINA ZHURAVLEVA	{"phone": "+70542556409"}
0005435087058	FCDC30	8092 588537	NIKOLAY STEPANOV	{"email": "stepanov.n1979@postgrespro.ru", "phone": "+70116980002"}
0005435087059	31F82A	6664 487569	LIDIYA DMITRIEVA	{"phone": "+70075594177"}
0005435087060	E5FBF6	3922 904411	VALERIY KOROLEV	{"phone": "+70273222040"}
0005435087061	5070F2	3996 955811	ANATOLIY ALEKSEEV	{"email": "alekseev.anatoliy.28081976@postgrespro.ru", "phone": "+70335221365"}
0005435087062	EC8A8A	2029 675848	ROMAN KUZNECOV	{"email": "kuznecov-roman_15101973@postgrespro.ru", "phone": "+70353473330"}
0005435087063	3F45B5	6646 595008	KIRILL SHEVCHENKO	{"phone": "+70194730684"}
0005435091892	672305	1687 416009	DARYA SERGEEVA	{"email": "sergeeva.d.071973@postgrespro.ru", "phone": "+70426441273"}
0005435091893	840486	1392 051873	VIKTOR KOROLEV	{"phone": "+70749206084"}
0005435091894	D97AD8	6225 859977	SVETLANA VOLKOVA	{"phone": "+70849867895"}
0005435091895	DE956E	3402 441104	MIKHAIL MOROZOV	{"email": "morozovmikhail-1987@postgrespro.ru", "phone": "+70879217969"}
0005435091896	DE956E	2079 535144	VIKTOR KUZNECOV	{"email": "viktorkuznecov_1969@postgrespro.ru", "phone": "+70314482531"}
0005435091897	3B749A	5855 882948	ANTONINA NAUMOVA	{"phone": "+70265640646"}
0005435091898	76F4BA	2492 837120	ALEKSANDR SOLOVEV	{"phone": "+70304037392"}
0005435091899	76F4BA	9813 393592	SERGEY BELOV	{"email": "sergeybelov.1974@postgrespro.ru", "phone": "+70127297957"}
0005435091900	420A96	7086 137518	ALEKSANDRA SMIRNOVA	{"phone": "+70092566551"}
0005435091901	8368CC	4601 070475	SVETLANA NOVIKOVA	{"phone": "+70614128210"}
0005435091902	036AD2	0263 588462	DENIS KONOVALOV	{"email": "konovalov-denis.051974@postgrespro.ru", "phone": "+70465960991"}
0005435091903	036AD2	9993 248282	EVGENIY KUZNECOV	{"phone": "+70327310692"}
0005435091904	8F127F	9592 139725	ANASTASIYA POLYAKOVA	{"phone": "+70085187616"}
0005435091905	37B8CD	5814 033216	ALEKSANDR KULIKOV	{"email": "aleksandr.kulikov1977@postgrespro.ru", "phone": "+70654308350"}
0005435091906	62CDBC	9443 406158	NATALYA STEPANOVA	{"phone": "+70103648922"}
0005435091907	6EF140	8882 399475	NIKOLAY POPOV	{"email": "popov_nikolay-08011964@postgrespro.ru", "phone": "+70086411538"}
0005435091908	6EF140	1992 576275	ELENA KOZLOVA	{"email": "elena_kozlova19031975@postgrespro.ru", "phone": "+70808563722"}
0005435091909	6EF140	7873 808413	VALENTINA SEMENOVA	{"email": "valentina-semenova-25101973@postgrespro.ru", "phone": "+70470675426"}
0005435091910	0FE596	0906 939839	ALEKSANDR GRIGOREV	{"email": "grigoreva-06031974@postgrespro.ru", "phone": "+70747032399"}
0005435091911	FD2731	1410 526873	VLADISLAV FILIPPOV	{"phone": "+70629577407"}
0005435091912	FD2731	0500 356491	ANDREY KRASNOV	{"email": "krasnov_a-30041973@postgrespro.ru", "phone": "+70658128570"}
0005435091913	B7D94B	8678 071198	IGOR VOROBEV	{"phone": "+70116449969"}
0005435091914	66AA1A	0903 560772	ALEKSEY SIDOROV	{"email": "sidorov_aleksey.071987@postgrespro.ru", "phone": "+70254628605"}
0005435091915	66AA1A	6548 504405	VLADIMIR TIKHONOV	{"phone": "+70267448536"}
0005435091916	C34518	4707 696951	DANILA SEMENOV	{"phone": "+70189751313"}
0005435091917	93E3A4	6308 217952	ANATOLIY ZAYCEV	{"email": "zaycev.a1961@postgrespro.ru", "phone": "+70499987609"}
0005435091918	7B77D9	9004 713138	DMITRIY PAVLOV	{"phone": "+70945560023"}
0005435091919	0F124E	1670 915970	ZOYA POLYAKOVA	{"phone": "+70228891620"}
0005435091920	F661AE	4358 530774	LIDIYA FEDOROVA	{"phone": "+70508375215"}
0005435091921	48DA34	4814 926996	VERONIKA POPOVA	{"email": "popovav.20081976@postgrespro.ru", "phone": "+70020256174"}
0005435091922	F2691A	2153 366858	NIKITA EGOROV	{"email": "egorov-nikita1968@postgrespro.ru", "phone": "+70088964510"}
0005435091923	F2691A	8928 110931	ALEKSANDR MAKAROV	{"phone": "+70629900679"}
0005435091924	B91B0D	8801 418014	EVGENIY IVANOV	{"email": "ivanove15071978@postgrespro.ru", "phone": "+70625942331"}
0005435091925	C9C07A	8143 849227	ALEKSANDR FEDOTOV	{"email": "a_fedotov_27061979@postgrespro.ru", "phone": "+70147202532"}
0005435091926	C9C07A	3545 797334	IGOR SEMENOV	{"phone": "+70919348486"}
0005435091927	C9C07A	1208 457714	SERGEY DAVYDOV	{"email": "davydov-s.101974@postgrespro.ru", "phone": "+70717680966"}
0005435091928	48CCFF	4236 443613	SERGEY AFANASEV	{"phone": "+70524056416"}
0005435091929	FCB4E0	6375 855749	EVGENIY KOROLEV	{"email": "evgeniy.korolev.1971@postgrespro.ru", "phone": "+70006942967"}
0005435091930	A9DE4A	8872 016949	VIKTOR VOROBEV	{"email": "vorobevv_23031971@postgrespro.ru", "phone": "+70086507155"}
0005435091931	A9DE4A	9450 137660	OKSANA SCHERBAKOVA	{"phone": "+70502423290"}
0005435091932	A0BBA2	5698 336479	SERGEY GORBUNOV	{"phone": "+70708618011"}
0005435091933	6C6FB0	9769 358882	SVETLANA MAKSIMOVA	{"email": "maksimova.svetlana-1971@postgrespro.ru", "phone": "+70488058455"}
0005435091934	BD87DF	0897 196413	OKSANA KUZNECOVA	{"email": "kuznecova.o011977@postgrespro.ru", "phone": "+70527353418"}
0005435091935	C11431	2676 074491	VLADIMIR BELOV	{"phone": "+70092879932"}
0005435091936	C11431	1323 204532	NIKOLAY FILIPPOV	{"phone": "+70779457293"}
0005435091937	01FCE2	4835 060238	YURIY ALEKSEEV	{"email": "alekseevy_091976@postgrespro.ru", "phone": "+70828738991"}
0005435091938	DAD4EF	2240 255166	ANATOLIY ROMANOV	{"phone": "+70929798098"}
0005435091939	7B6830	6173 617409	MAKSIM BELOV	{"email": "belov_m-111974@postgrespro.ru", "phone": "+70692812725"}
0005435091940	7B6830	5617 926686	VALENTINA SOROKINA	{"phone": "+70034663881"}
0005435091941	1DAEEE	8889 949762	MARIYA BELOVA	{"email": "belova_m-24041968@postgrespro.ru", "phone": "+70495523629"}
0005435091942	1DAEEE	5433 828957	NATALYA NIKOLAEVA	{"email": "nnikolaeva-08041979@postgrespro.ru", "phone": "+70240267071"}
0005435091943	190E9E	4797 952910	OLGA MATVEEVA	{"email": "matveeva.o.1975@postgrespro.ru", "phone": "+70380824283"}
0005435091944	93D345	3112 493618	DIANA GERASIMOVA	{"phone": "+70101430571"}
0005435091945	277828	3318 352099	SERGEY POPOV	{"phone": "+70911561348"}
0005435091946	277828	4614 397967	AZAT SIDOROV	{"email": "sidorova_031967@postgrespro.ru", "phone": "+70362680223"}
0005435091947	AA9E98	8762 201342	IRINA EFREMOVA	{"email": "irina.efremova_22031972@postgrespro.ru", "phone": "+70296492532"}
0005435091948	BD121B	3931 277498	LYUBOV FILATOVA	{"email": "filatova.lyubov_30101967@postgrespro.ru", "phone": "+70817110650"}
0005435091949	D92744	9859 733030	SERGEY FILIPPOV	{"email": "sergeyfilippov.16031959@postgrespro.ru", "phone": "+70851141905"}
0005435091950	F2AABC	1811 415015	IGOR MELNIKOV	{"phone": "+70021350532"}
0005435091951	B41E09	9043 778208	ARTUR VOROBEV	{"email": "vorobev-artur101969@postgrespro.ru", "phone": "+70926267994"}
0005435091952	7AD17D	3708 822799	VALENTINA RODIONOVA	{"phone": "+70927525953"}
0005435091953	1C6E99	3833 633833	GALINA MATVEEVA	{"email": "galinamatveeva1971@postgrespro.ru", "phone": "+70385288976"}
0005435091954	99F916	6360 031280	OKSANA PETROVA	{"phone": "+70783713112"}
0005435091955	75301F	2650 224519	NINA SOLOVEVA	{"email": "soloveva.n-28081960@postgrespro.ru", "phone": "+70966669498"}
0005435091956	0B65C2	4580 571093	VIKTOR DENISOV	{"phone": "+70563765701"}
0005435091957	F72A67	7888 403153	NAIL TARASOV	{"phone": "+70283893302"}
0005435091958	F72A67	8350 453466	VLADIMIR MAKAROV	{"phone": "+70206178301"}
0005435091959	FC0119	3750 387335	OKSANA SEMENOVA	{"phone": "+70776958321"}
0005435091960	ACFFD7	0593 300189	VALERIYA SERGEEVA	{"email": "valeriya_sergeeva.1976@postgrespro.ru", "phone": "+70459062715"}
0005435091961	ACFFD7	9183 523223	TATYANA NIKITINA	{"phone": "+70127504124"}
0005435091962	5394EC	9452 712689	VLADIMIR ZAKHAROV	{"email": "v.zakharov-101968@postgrespro.ru", "phone": "+70058058885"}
0005435091963	5394EC	0789 124016	TATYANA KUDRYASHOVA	{"phone": "+70442301368"}
0005435091964	5394EC	8620 859825	SERGEY SEMENOV	{"email": "s_semenov-1964@postgrespro.ru", "phone": "+70175016131"}
0005435091965	3711D1	3014 819274	OLGA ISAEVA	{"phone": "+70602387020"}
0005435091966	3711D1	4304 699000	ANNA VOROBEVA	{"email": "vorobeva_anna101968@postgrespro.ru", "phone": "+70813441125"}
0005435091967	BB1BD7	8690 681672	ALEKSANDR TARASOV	{"phone": "+70282702241"}
0005435091968	92D86C	3976 753336	MARIYA MAKAROVA	{"phone": "+70360674758"}
0005435091969	864F74	4358 195792	ALEKSANDR DAVYDOV	{"email": "a.davydov_021971@postgrespro.ru", "phone": "+70465667459"}
0005435091970	E90FDF	0267 192870	SERGEY ROMANOV	{"phone": "+70092178312"}
0005435091971	E90FDF	9525 874046	NATALYA YUDINA	{"phone": "+70493625116"}
0005435091972	E65A3D	0579 994241	TATYANA MIRONOVA	{"email": "tatyanamironova.07021964@postgrespro.ru", "phone": "+70864334471"}
0005435091973	E65A3D	3154 958042	DINARA EFREMOVA	{"email": "efremova-dinara1981@postgrespro.ru", "phone": "+70649176757"}
0005435091974	9FD54A	2655 187962	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr-061981@postgrespro.ru", "phone": "+70137657351"}
0005435091975	90DD78	5394 173795	EVGENIY FEDOROV	{"email": "evgeniyfedorov111967@postgrespro.ru", "phone": "+70851943612"}
0005435091976	BAA625	8377 789592	ANDREY KARPOV	{"phone": "+70527003101"}
0005435091977	9D3303	1840 170247	ANTON MIKHAYLOV	{"phone": "+70326209662"}
0005435091978	097F02	7407 121221	LYUBOV BARANOVA	{"phone": "+70515796337"}
0005435091979	097F02	3247 953696	TAMARA NOVIKOVA	{"email": "t_novikova-04121974@postgrespro.ru", "phone": "+70118123541"}
0005435091980	097F02	3002 865811	LYUDMILA ISAEVA	{"email": "isaeva_lyudmila.1983@postgrespro.ru", "phone": "+70503772384"}
0005435091981	B7D3A0	9402 506083	GENNADIY ZHURAVLEV	{"email": "zhuravlev_gennadiy_02111959@postgrespro.ru", "phone": "+70183336410"}
0005435091982	175F67	6769 173671	SERGEY MAKSIMOV	{"email": "maksimovs.121961@postgrespro.ru", "phone": "+70873882274"}
0005435091983	64FD47	4263 827403	ALEKSEY ORLOV	{"phone": "+70888760503"}
0005435091984	47469D	4386 203634	LYUDMILA KUZMINA	{"phone": "+70601040986"}
0005435091985	47469D	5161 846661	GALINA NIKOLAEVA	{"email": "nikolaeva-galina1962@postgrespro.ru", "phone": "+70922673061"}
0005435091986	F8D9A5	1765 400467	LYUBOV NOVIKOVA	{"email": "novikova_lyubov-1970@postgrespro.ru", "phone": "+70694594998"}
0005435091987	AA28A7	5474 323474	ANDREY GUSEV	{"email": "andrey.gusev-17111970@postgrespro.ru", "phone": "+70805198285"}
0005435091988	894A2C	8465 909800	NATALYA VOROBEVA	{"phone": "+70734759678"}
0005435091989	039F2A	1075 389120	VERA YAKOVLEVA	{"email": "yakovlevav.091966@postgrespro.ru", "phone": "+70102856737"}
0005435091990	8A2B14	2175 357789	OLEG YAKOVLEV	{"phone": "+70974390090"}
0005435091991	984BEA	2848 733308	LYUDMILA POTAPOVA	{"email": "potapova.l13021974@postgrespro.ru", "phone": "+70272855264"}
0005435091992	F20924	4944 999173	YULIYA NAZAROVA	{"phone": "+70055048956"}
0005435091993	6D7E3A	8005 692789	EVGENIY ZAYCEV	{"phone": "+70406441516"}
0005435091994	6D7E3A	0926 169993	VALERIY VLASOV	{"email": "vlasov.v04121981@postgrespro.ru", "phone": "+70636076413"}
0005435091995	6D7E3A	5259 099849	NATALYA EFIMOVA	{"email": "n.efimova.1972@postgrespro.ru", "phone": "+70261296749"}
0005435091996	B3F844	3723 699332	TATYANA ANDREEVA	{"phone": "+70605989538"}
0005435091997	EEAA4A	9430 778723	TATYANA KUDRYASHOVA	{"phone": "+70658128021"}
0005435091998	EEAA4A	6482 712005	EVGENIY SHEVCHENKO	{"email": "shevchenkoevgeniy_26101970@postgrespro.ru", "phone": "+70406028144"}
0005435091999	EEAA4A	7910 745295	ALEKSANDR FEDOROV	{"email": "afedorov.1970@postgrespro.ru", "phone": "+70271309621"}
0005435092000	E181CD	4018 502904	LYUBOV ROMANOVA	{"phone": "+70040145946"}
0005435092001	E181CD	9424 733480	ALEKSANDRA KUZNECOVA	{"phone": "+70107681059"}
0005435092002	FBDEAC	6490 217366	RAISA ZOTOVA	{"email": "r_zotova09111972@postgrespro.ru", "phone": "+70323805880"}
0005435092003	427E05	6321 516713	OLGA KONOVALOVA	{"phone": "+70550315742"}
0005435092004	13EF2B	7177 850215	MIKHAIL ZAYCEV	{"phone": "+70392380275"}
0005435092005	13EF2B	0511 393204	YURIY DMITRIEV	{"email": "yuriy_dmitriev-1970@postgrespro.ru", "phone": "+70424093110"}
0005435092006	D2E047	9087 030781	ANASTASIYA DMITRIEVA	{"email": "anastasiyadmitrieva-1974@postgrespro.ru", "phone": "+70492738425"}
0005435092007	D2E047	8593 820354	EKATERINA MAKAROVA	{"phone": "+70595502962"}
0005435092008	6182DE	7558 412844	ANASTASIYA DAVYDOVA	{"email": "davydova.a-17101975@postgrespro.ru", "phone": "+70509189861"}
0005435092009	1CD154	8688 566706	IGOR ANDREEV	{"phone": "+70357887075"}
0005435092010	10C1D3	0593 854776	DMITRIY IVANOV	{"phone": "+70810042895"}
0005435092011	10C1D3	3313 992117	VERA VOLKOVA	{"phone": "+70297244960"}
0005435092012	72A9CC	3819 918227	RUZALIYA SOROKINA	{"email": "ruzaliya-sorokina.1975@postgrespro.ru", "phone": "+70043658319"}
0005435092013	2DFC98	5238 077354	KLAVDIYA KOLESNIKOVA	{"email": "kolesnikova.klavdiya_031965@postgrespro.ru", "phone": "+70736689109"}
0005435092014	812829	6500 407877	ANTONINA FROLOVA	{"phone": "+70476049850"}
0005435092015	E1FDDA	6939 241932	DMITRIY SERGEEV	{"email": "dmitriy.sergeev.22031981@postgrespro.ru", "phone": "+70079435752"}
0005435092016	3CC982	0659 897183	YURIY TARASOV	{"phone": "+70781184217"}
0005435092017	3CC982	2784 982718	MIKHAIL KOZLOV	{"phone": "+70217791698"}
0005435092018	7E45BF	0674 789194	ANNA GERASIMOVA	{"email": "gerasimova-a_1969@postgrespro.ru", "phone": "+70039016182"}
0005435092019	2D0C2F	8745 809552	ALEKSEY SOROKIN	{"phone": "+70864972781"}
0005435092020	C47D8A	0678 496818	ALEKSANDR NAUMOV	{"phone": "+70137782883"}
0005435092021	8A4D76	2355 699123	NADEZHDA AFANASEVA	{"phone": "+70445657647"}
0005435092022	8A4D76	5294 364376	ANTON TIMOFEEV	{"phone": "+70480237546"}
0005435092023	8A4D76	7310 934802	ILYA KUZNECOV	{"phone": "+70863374509"}
0005435092024	4EA40F	4151 689959	ALEKSEY VOLKOV	{"email": "a.volkov_31051974@postgrespro.ru", "phone": "+70309226037"}
0005435092025	28903B	9826 504063	ANDREY KOZLOV	{"phone": "+70554379132"}
0005435092026	28903B	5500 285216	ALENA MEDVEDEVA	{"email": "a-medvedeva_1966@postgrespro.ru", "phone": "+70545203723"}
0005435092027	28903B	5183 659453	IVAN KISELEV	{"phone": "+70121594303"}
0005435092028	B032BA	9499 720982	TAMARA KUZMINA	{"phone": "+70486048509"}
0005435092029	AC1D98	1423 616945	NATALYA SIDOROVA	{"phone": "+70480493741"}
0005435092030	D6060A	8814 886805	YULIYA FROLOVA	{"phone": "+70365120461"}
0005435092031	024A7B	0786 046958	NATALYA OSIPOVA	{"phone": "+70092778693"}
0005435092032	024A7B	2212 843409	NATALYA SOKOLOVA	{"phone": "+70119563492"}
0005435092033	C51B6C	2582 449023	DENIS DAVYDOV	{"email": "davydovd051982@postgrespro.ru", "phone": "+70271331515"}
0005435092034	C51B6C	9549 318857	SERGEY VASILEV	{"email": "s-vasilev.16091977@postgrespro.ru", "phone": "+70250902282"}
0005435092035	161EA3	6950 907809	RAZIYA MELNIKOVA	{"email": "melnikova-r-121982@postgrespro.ru", "phone": "+70642844742"}
0005435092036	037354	7421 068368	NINA SERGEEVA	{"email": "sergeeva-n_031969@postgrespro.ru", "phone": "+70117236797"}
0005435092037	0C2E5C	0397 975224	SHAMIL NIKOLAEV	{"phone": "+70286769197"}
0005435092038	2F34CC	2469 491870	OLEG YAKOVLEV	{"email": "o_yakovlev.1969@postgrespro.ru", "phone": "+70218310797"}
0005435092039	2F34CC	5426 427675	ANNA KOZLOVA	{"email": "anna_kozlova_23101964@postgrespro.ru", "phone": "+70702891082"}
0005435092040	CFD79E	2802 774837	ANNA ILINA	{"email": "ilina-a_16031962@postgrespro.ru", "phone": "+70527339356"}
0005435092041	CFD79E	4970 939166	SERGEY GERASIMOV	{"email": "sergey-gerasimov_081963@postgrespro.ru", "phone": "+70395154824"}
0005435092042	D1785D	7433 862814	KIRILL IVANOV	{"email": "kirill-ivanov.1982@postgrespro.ru", "phone": "+70634153751"}
0005435092043	CF3558	7843 906847	VIKTOR IVANOV	{"phone": "+70664634750"}
0005435092044	61C73A	3030 857763	TATYANA KOLESNIKOVA	{"email": "t.kolesnikova.091972@postgrespro.ru", "phone": "+70888794683"}
0005435092045	E659D4	0502 814645	VASILIY ROMANOV	{"email": "romanov-vasiliy011971@postgrespro.ru", "phone": "+70082768024"}
0005435092046	AF7673	5706 768903	ELMIRA KUZMINA	{"phone": "+70253438384"}
0005435092047	51DF0B	0242 770191	TAISIYA KUZNECOVA	{"email": "kuznecovataisiya_16021975@postgrespro.ru", "phone": "+70496629842"}
0005435092048	0DA596	6282 739534	TATYANA SOROKINA	{"phone": "+70023090034"}
0005435092049	0DA596	6720 699948	GALIYA DAVYDOVA	{"phone": "+70478098466"}
0005435092050	D89019	5308 006668	DMITRIY IVANOV	{"email": "ivanov-d.071979@postgrespro.ru", "phone": "+70274753636"}
0005435092051	D89019	6381 682962	ALEKSEY ILIN	{"phone": "+70357007307"}
0005435092052	E7068B	0547 000380	VLADIMIR MAKAROV	{"phone": "+70444042529"}
0005435092053	2DF64C	4696 307865	LIDIYA PETROVA	{"phone": "+70828277067"}
0005435092054	2DF64C	1441 296148	LYUBOV KONDRATEVA	{"phone": "+70130925648"}
0005435092055	2DF64C	2306 351796	MARINA LEBEDEVA	{"email": "lebedeva.m17081973@postgrespro.ru", "phone": "+70073811500"}
0005435092056	5ACB9B	0746 769423	IGOR IVANOV	{"email": "ivanov.i.29051978@postgrespro.ru", "phone": "+70624502689"}
0005435092057	5ACB9B	8527 536319	LYUBOV DANILOVA	{"email": "danilova_lyubov.07021978@postgrespro.ru", "phone": "+70321268385"}
0005435092058	5ACB9B	7043 224904	NATALYA SCHERBAKOVA	{"email": "natalya_scherbakova03011963@postgrespro.ru", "phone": "+70154137676"}
0005435092059	468A82	9449 671339	MAKSIM PAVLOV	{"email": "pavlov.m-05091966@postgrespro.ru", "phone": "+70816865762"}
0005435092060	FB92D5	1207 952425	VIKTOR MOROZOV	{"phone": "+70246608655"}
0005435092061	6AED7B	2290 147627	ILYA SEMENOV	{"email": "semenov-ilya_091971@postgrespro.ru", "phone": "+70551277025"}
0005435092062	292A9F	7120 229471	IRINA RYABOVA	{"email": "ryabova_irina.1978@postgrespro.ru", "phone": "+70109163188"}
0005435092063	A1EEB5	0848 520208	DENIS BONDARENKO	{"email": "denis.bondarenko_1965@postgrespro.ru", "phone": "+70343061031"}
0005435092064	A1EEB5	5997 421335	ALEKSANDR KUZMIN	{"phone": "+70700434353"}
0005435092065	A1EEB5	4105 386572	VLADIMIR DENISOV	{"email": "v-denisov_071968@postgrespro.ru", "phone": "+70537703092"}
0005435092066	644CB2	6926 945890	SVETLANA NIKITINA	{"email": "s.nikitina-1964@postgrespro.ru", "phone": "+70282167097"}
0005435092067	F8A3C2	9552 945931	TAMARA NESTEROVA	{"phone": "+70538067829"}
0005435092068	A3FFAB	6370 102919	ELIZAVETA KUZNECOVA	{"email": "elizaveta.kuznecova.041974@postgrespro.ru", "phone": "+70423443937"}
0005435092069	A3FFAB	9420 777192	LIDIYA STEPANOVA	{"email": "lidiyastepanova.25121973@postgrespro.ru", "phone": "+70594054285"}
0005435092070	D1F540	9792 016728	TATYANA VASILEVA	{"email": "tvasileva_011971@postgrespro.ru", "phone": "+70386271335"}
0005435092071	B3EB4B	4638 483898	LYUBOV ROMANOVA	{"email": "lyubovromanova18061974@postgrespro.ru", "phone": "+70542960738"}
0005435092072	B3EB4B	8136 889328	LYUDMILA NIKIFOROVA	{"email": "nikiforova.l031973@postgrespro.ru", "phone": "+70290480367"}
0005435092073	8D7692	7553 064530	DARYA PETROVA	{"phone": "+70119849861"}
0005435092074	A7A687	6197 080282	ELENA CHERNOVA	{"phone": "+70262210655"}
0005435092075	A7A687	8185 241766	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov_111969@postgrespro.ru", "phone": "+70230807819"}
0005435092076	B0D3A0	8630 187586	GALINA SOROKINA	{"phone": "+70961986443"}
0005435092077	CCAFF9	1132 957604	NATALYA ORLOVA	{"phone": "+70718890924"}
0005435092078	31D732	5808 636336	EKATERINA KUZNECOVA	{"phone": "+70268745793"}
0005435092079	31D732	1971 822935	ALEVTINA KARPOVA	{"phone": "+70033667185"}
0005435092080	778FF3	9755 041670	OLGA TITOVA	{"phone": "+70189514632"}
0005435092081	48DCB4	0130 070840	MARINA KONOVALOVA	{"email": "marina.konovalova051968@postgrespro.ru", "phone": "+70159157544"}
0005435092082	6D61A1	5056 180499	TATYANA BARANOVA	{"phone": "+70874953498"}
0005435092083	6D61A1	5209 365150	EKATERINA TIKHONOVA	{"email": "e_tikhonova.1970@postgrespro.ru", "phone": "+70088755634"}
0005435092084	6D61A1	8785 952368	VLADIMIR SOKOLOV	{"email": "v.sokolov-06081971@postgrespro.ru", "phone": "+70565342571"}
0005435092085	BB5CF6	4860 315832	MARIYA ALEKSEEVA	{"phone": "+70796835260"}
0005435092086	BB5CF6	2805 706430	SERGEY ZHURAVLEV	{"phone": "+70160724718"}
0005435092087	7C767E	0559 853808	IRINA KARPOVA	{"phone": "+70877390906"}
0005435092088	15E3FB	4523 534655	NINA ANDREEVA	{"phone": "+70042464612"}
0005435092089	4183EF	1264 180425	ARTUR SCHERBAKOV	{"phone": "+70892332793"}
0005435092090	4183EF	5592 259761	LYUBOV MIRONOVA	{"email": "lmironova_06071960@postgrespro.ru", "phone": "+70096818631"}
0005435092091	CB03DA	2259 093238	VIKTOR GORBUNOV	{"email": "v_gorbunov_1985@postgrespro.ru", "phone": "+70116756451"}
0005435092092	F5A847	9325 074466	PAVEL KUZNECOV	{"email": "kuznecov_pavel.1973@postgrespro.ru", "phone": "+70044074860"}
0005435092093	F5A847	7757 102327	NIKITA RODIONOV	{"phone": "+70873166495"}
0005435092094	E4E271	7735 349219	NIKOLAY ANTONOV	{"phone": "+70562665786"}
0005435092095	427089	0249 816802	DMITRIY MELNIKOV	{"phone": "+70538177823"}
0005435092096	D01151	5488 307886	ALENA ZHURAVLEVA	{"email": "zhuravleva-alena_111979@postgrespro.ru", "phone": "+70530287885"}
0005435092097	D01151	1782 603696	ILYA NOVIKOV	{"email": "novikov-i-1987@postgrespro.ru", "phone": "+70131613988"}
0005435092098	F63D75	2861 813674	VALERIY ILIN	{"phone": "+70095031337"}
0005435092099	869E32	3756 199595	VALENTIN VOROBEV	{"email": "vorobevv.22081983@postgrespro.ru", "phone": "+70036604996"}
0005435092100	869E32	3524 610258	VIKTOR SCHERBAKOV	{"email": "v_scherbakov_081962@postgrespro.ru", "phone": "+70790172103"}
0005435092101	B7A596	5643 777828	GENNADIY ROMANOV	{"email": "gennadiy.romanov1962@postgrespro.ru", "phone": "+70870552398"}
0005435092102	BBA0FE	5695 835278	ALEKSANDR IVANOV	{"phone": "+70643107580"}
0005435092103	BBA0FE	0536 538189	ILSHAT ZAKHAROV	{"phone": "+70956935738"}
0005435092104	3E7595	2460 695763	TATYANA ISAEVA	{"email": "isaeva_tatyana111973@postgrespro.ru", "phone": "+70545469606"}
0005435092105	9D0F00	0864 584574	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_galina14041967@postgrespro.ru", "phone": "+70743765873"}
0005435092106	9D0F00	9421 301438	ARTEM GAVRILOV	{"email": "gavrilov_artem-26081979@postgrespro.ru", "phone": "+70294913787"}
0005435092107	5203BC	9418 462159	TATYANA MELNIKOVA	{"phone": "+70376819414"}
0005435092108	EF8B0C	2985 397710	KONSTANTIN MIKHAYLOV	{"email": "konstantinmikhaylov_15111957@postgrespro.ru", "phone": "+70651100913"}
0005435092109	EF8B0C	0250 370981	ANNA BELYAEVA	{"email": "belyaeva.a031976@postgrespro.ru", "phone": "+70060027733"}
0005435092110	8F7960	0535 344638	NATALYA KUZNECOVA	{"email": "kuznecova-natalya_051979@postgrespro.ru", "phone": "+70044422142"}
0005435092111	8F7960	4906 510980	TATYANA MIRONOVA	{"phone": "+70480551243"}
0005435092112	6AF310	4373 832606	ANZHELIKA FEDOROVA	{"email": "fedorova.anzhelika.1981@postgrespro.ru", "phone": "+70389328134"}
0005435092113	7FDCAA	0523 882711	ANNA ANISIMOVA	{"phone": "+70480585029"}
0005435092114	7FDCAA	9809 699775	NELLI MAKAROVA	{"phone": "+70524586548"}
0005435092115	07B827	7926 327275	KARINA POPOVA	{"phone": "+70164326319"}
0005435092116	4F2343	5009 972880	SERGEY FEDOROV	{"phone": "+70928616702"}
0005435092117	E24F4B	3005 397014	VALENTINA SOKOLOVA	{"email": "valentinasokolova061961@postgrespro.ru", "phone": "+70897300997"}
0005435092118	A4D7DC	2334 525915	SVETLANA ZOTOVA	{"phone": "+70654062177"}
0005435092119	CFD201	4996 911680	LYUBOV GORBUNOVA	{"email": "lyubovgorbunova.1978@postgrespro.ru", "phone": "+70472223201"}
0005435092120	CFD201	9675 272006	MILANA ISAEVA	{"email": "m_isaeva_071974@postgrespro.ru", "phone": "+70163575720"}
0005435092121	1202C6	0198 860229	ELENA POPOVA	{"phone": "+70059037385"}
0005435092122	4530FA	1286 365606	NIKITA ORLOV	{"phone": "+70092828442"}
0005435092123	4530FA	2962 584943	VIKTOR MOROZOV	{"phone": "+70220419302"}
0005435092124	C5D167	0258 736175	YULIYA KOLESNIKOVA	{"phone": "+70133947519"}
0005435092125	C5D167	7966 180464	VERA MATVEEVA	{"email": "vera.matveeva-28031970@postgrespro.ru", "phone": "+70847527930"}
0005435092126	64C49E	2057 420236	MARIYA EGOROVA	{"email": "mariya_egorova.30111975@postgrespro.ru", "phone": "+70258097369"}
0005435092127	18EDF0	4912 820933	EVGENIY ANDREEV	{"phone": "+70023934610"}
0005435092128	D3F652	8338 791150	IRINA FILIPPOVA	{"phone": "+70649569037"}
0005435092129	D3F652	9120 966601	OLGA DMITRIEVA	{"phone": "+70284710563"}
0005435092130	4EB624	9706 552816	NATALIYA ZAYCEVA	{"email": "zayceva.nataliya_1971@postgrespro.ru", "phone": "+70061823565"}
0005435092131	4EB624	4876 033957	ANASTASIYA MAKSIMOVA	{"email": "maksimova-anastasiya-1959@postgrespro.ru", "phone": "+70680789523"}
0005435092132	3E040C	2454 653627	ELENA ROMANOVA	{"email": "e-romanova.081968@postgrespro.ru", "phone": "+70658692240"}
0005435092133	03D4E5	8165 798623	VIKTOR KOZLOV	{"phone": "+70849997517"}
0005435092134	664623	6508 850654	VADIM NIKOLAEV	{"phone": "+70155970038"}
0005435092135	25A900	8134 032570	ALEKSANDR MAKAROV	{"email": "makarov_a04101970@postgrespro.ru", "phone": "+70673534324"}
0005435092136	B32FE2	0817 196679	ELENA SERGEEVA	{"phone": "+70667081087"}
0005435092137	46EEED	3014 582445	EKATERINA MOISEEVA	{"email": "moiseevae.1965@postgrespro.ru", "phone": "+70680048175"}
0005435092138	81504C	4762 742478	VLADIMIR MIKHAYLOV	{"email": "vladimir_mikhaylov-1973@postgrespro.ru", "phone": "+70091968084"}
0005435092139	81504C	7195 086369	GALINA KUDRYASHOVA	{"phone": "+70149246843"}
0005435092140	35EDE3	1108 333190	TATYANA KOROLEVA	{"email": "tatyanakoroleva.021978@postgrespro.ru", "phone": "+70745303918"}
0005435092141	35EDE3	2784 608183	OLGA SERGEEVA	{"phone": "+70479896704"}
0005435092142	A45B1E	5765 696454	VERA MATVEEVA	{"phone": "+70603523516"}
0005435092143	FFABA3	5850 818503	RUSTAM KOZLOV	{"phone": "+70453596606"}
0005435092144	C07C01	8435 704798	ANDREY VASILEV	{"phone": "+70420653298"}
0005435092145	BE9004	8253 945747	EVGENIY PETROV	{"email": "petrov-evgeniy1974@postgrespro.ru", "phone": "+70508519630"}
0005435092146	D4EC04	9683 544837	ALEKSANDR ALEKSEEV	{"phone": "+70478176971"}
0005435092147	F00CCC	5272 653837	ANDREY AFANASEV	{"phone": "+70847789690"}
0005435092148	9108B9	8242 003448	OKSANA ANISIMOVA	{"email": "oksanaanisimova_1969@postgrespro.ru", "phone": "+70861143252"}
0005435092149	6C33E8	2585 045104	DMITRIY SOLOVEV	{"email": "dmitriy_solovev061978@postgrespro.ru", "phone": "+70403058973"}
0005435092150	23D3A9	7682 630309	VLADISLAV STEPANOV	{"email": "vladislav_stepanov_26121966@postgrespro.ru", "phone": "+70800415448"}
0005435092151	23D3A9	0489 010809	OLGA CHERNOVA	{"email": "olga-chernova_111970@postgrespro.ru", "phone": "+70117317824"}
0005435092152	1FBE41	0130 456993	GALINA MAKAROVA	{"phone": "+70696557524"}
0005435092153	C46FDA	8180 334481	ANTON SOROKIN	{"email": "anton-sorokin_1977@postgrespro.ru", "phone": "+70266999372"}
0005435092154	940101	0886 346252	ALEVTINA KUZNECOVA	{"email": "a.kuznecova-1973@postgrespro.ru", "phone": "+70286363875"}
0005435092267	0804F6	4817 993807	LYUDMILA ZHUKOVA	{"phone": "+70128499381"}
0005435092155	940101	4457 202351	OLESYA MASLOVA	{"email": "o-maslova07081982@postgrespro.ru", "phone": "+70746557214"}
0005435092156	641332	4600 404998	LIDIYA SIDOROVA	{"phone": "+70403562558"}
0005435092157	641332	3413 832822	OLGA SOROKINA	{"email": "sorokina-olga_1958@postgrespro.ru", "phone": "+70178844408"}
0005435092158	B964C8	1789 912337	ELENA VASILEVA	{"email": "vasileva-elena1982@postgrespro.ru", "phone": "+70353562558"}
0005435092159	B964C8	6913 507548	ALEKSANDR PAVLOV	{"phone": "+70160693319"}
0005435092160	3599C5	7531 023665	IRAIDA EGOROVA	{"phone": "+70150838266"}
0005435092161	29C293	1284 120014	ELENA MOROZOVA	{"email": "morozova_e-19111976@postgrespro.ru", "phone": "+70720466297"}
0005435092162	49A677	4423 687552	IVAN OSIPOV	{"email": "i_osipov.12011980@postgrespro.ru", "phone": "+70866803250"}
0005435092163	229E64	1602 344923	NATALYA LOGINOVA	{"email": "natalya_loginova_1972@postgrespro.ru", "phone": "+70479314496"}
0005435092164	05DCB9	9483 334696	KSENIYA MAKAROVA	{"phone": "+70017290111"}
0005435092165	0D046F	3894 081531	NIKOLAY ALEKSEEV	{"phone": "+70977220674"}
0005435092166	72751E	7909 474979	EVGENIYA BORISOVA	{"phone": "+70426870609"}
0005435092167	72751E	1213 720302	VALERIY DMITRIEV	{"email": "dmitriev.v_1978@postgrespro.ru", "phone": "+70773889663"}
0005435092168	063462	9814 788926	RAFIK KUZNECOV	{"phone": "+70551271287"}
0005435092169	6224C7	9014 757523	EKATERINA ROMANOVA	{"email": "romanova.ekaterina-031966@postgrespro.ru", "phone": "+70867967744"}
0005435092170	D88E80	4675 752187	VALERIY MIKHAYLOV	{"phone": "+70870126310"}
0005435092171	D88E80	3068 476308	ANASTASIYA AKIMOVA	{"email": "a.akimova_1962@postgrespro.ru", "phone": "+70470926126"}
0005435092172	85A380	7514 889325	SERGEY DAVYDOV	{"phone": "+70296031726"}
0005435092173	85A380	1845 629576	NATALYA VOLKOVA	{"email": "nvolkova-12091968@postgrespro.ru", "phone": "+70539630237"}
0005435092174	85F8A6	8455 622824	MAKSIM NIKOLAEV	{"email": "nikolaevm061974@postgrespro.ru", "phone": "+70019948554"}
0005435092175	85F8A6	4967 129510	EVGENIYA BELOVA	{"phone": "+70947257397"}
0005435092176	E4ADE7	4727 050715	OLGA SCHERBAKOVA	{"phone": "+70221118162"}
0005435092177	45B779	6100 825978	ALBINA ROMANOVA	{"email": "romanovaa_29051961@postgrespro.ru", "phone": "+70342896326"}
0005435092178	87B51F	0642 347330	RAFIK BORISOV	{"email": "r_borisov-29051978@postgrespro.ru", "phone": "+70059594525"}
0005435092179	76D69C	3793 990869	SERGEY BARANOV	{"phone": "+70382131142"}
0005435092180	3937D9	5200 498665	DMITRIY IVANOV	{"email": "ivanovdmitriy1968@postgrespro.ru", "phone": "+70791584628"}
0005435092181	3937D9	3722 782609	ELENA KOROLEVA	{"phone": "+70092723305"}
0005435092182	3937D9	5633 215269	OLGA TIMOFEEVA	{"phone": "+70394799611"}
0005435092183	FBC7A4	0665 593551	ANGELINA TARASOVA	{"email": "tarasova-angelina-1971@postgrespro.ru", "phone": "+70452530156"}
0005435092184	FBC7A4	4792 184774	VLADIMIR KULIKOV	{"email": "kulikovvladimir_011967@postgrespro.ru", "phone": "+70832445159"}
0005435092185	FBC7A4	0807 384027	ALEKSANDR ZAKHAROV	{"phone": "+70313996597"}
0005435092186	277ECC	3256 653001	DMITRIY EGOROV	{"email": "egorov_dmitriy.1978@postgrespro.ru", "phone": "+70950421170"}
0005435092187	277ECC	7035 843079	SVETLANA KUZNECOVA	{"phone": "+70033982476"}
0005435092188	D15F35	8967 277730	DMITRIY ALEKSEEV	{"phone": "+70731876679"}
0005435092189	55ABDC	3759 755459	ARMEN PETROV	{"phone": "+70686563422"}
0005435092190	02AD46	1736 375319	YURIY ILIN	{"phone": "+70021863958"}
0005435092191	61EC07	1371 337033	ELENA PAVLOVA	{"phone": "+70517754567"}
0005435092192	A4E191	6404 912950	ALEKSANDRA MAKAROVA	{"email": "aleksandramakarova-13041984@postgrespro.ru", "phone": "+70136413762"}
0005435092193	A23A1F	7077 161270	EKATERINA SOROKINA	{"email": "e.sorokina081983@postgrespro.ru", "phone": "+70838184006"}
0005435092194	A23A1F	9859 739861	ANASTASIYA SAVELEVA	{"phone": "+70095524505"}
0005435092195	B17EC9	6845 950857	NIKOLAY MELNIKOV	{"email": "melnikovn1969@postgrespro.ru", "phone": "+70839643048"}
0005435092196	B17EC9	3301 852644	MIKHAIL GAVRILOV	{"email": "m_gavrilov111978@postgrespro.ru", "phone": "+70633737711"}
0005435092197	981EDF	9520 140151	ALEKSEY IVANOV	{"phone": "+70455553137"}
0005435092198	9ABDE9	9375 854339	IRINA GUSEVA	{"email": "guseva.irina-041969@postgrespro.ru", "phone": "+70236316992"}
0005435092199	9ABDE9	1017 175917	ALEKSANDR TARASOV	{"phone": "+70189718743"}
0005435092200	FC620A	1963 370328	ANTON ZAYCEV	{"phone": "+70974516867"}
0005435092201	EB4396	0150 375663	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov_1974@postgrespro.ru", "phone": "+70033383702"}
0005435092202	345A66	5544 629024	DMITRIY YAKOVLEV	{"email": "dmitriyyakovlev_22021971@postgrespro.ru", "phone": "+70062886127"}
0005435092203	2B5853	3420 797944	LILIYA TROFIMOVA	{"phone": "+70781557758"}
0005435092204	2B5853	3191 500347	ELVIRA MALYSHEVA	{"email": "elvira.malysheva051966@postgrespro.ru", "phone": "+70865888991"}
0005435092205	E35509	7697 064337	SERGEY BORISOV	{"email": "sergey_borisov-30061974@postgrespro.ru", "phone": "+70774516668"}
0005435092206	98D079	6764 039296	YURIY BARANOV	{"email": "y-baranov-1980@postgrespro.ru", "phone": "+70723348669"}
0005435092207	6C3841	2290 259866	KLAVDIYA KOLESNIKOVA	{"email": "k-kolesnikova12041973@postgrespro.ru", "phone": "+70688999314"}
0005435092208	6C3841	1324 895241	ALEKSANDR ORLOV	{"phone": "+70065812649"}
0005435092209	6FA2A5	2668 482181	KARIM PETROV	{"phone": "+70254698262"}
0005435092210	6FA2A5	4175 962210	IRINA GORBUNOVA	{"email": "irina_gorbunova21081968@postgrespro.ru", "phone": "+70177367789"}
0005435092211	B43CA4	6468 627839	VARVARA KOROLEVA	{"email": "v-koroleva.091974@postgrespro.ru", "phone": "+70749741480"}
0005435092212	3F5CC9	6225 368605	EVGENIY PETROV	{"phone": "+70957192394"}
0005435092213	03E51E	9017 411005	ELENA MAKSIMOVA	{"phone": "+70148364291"}
0005435092214	47FCE7	6613 289665	ALEKSANDR KOZLOV	{"phone": "+70844301556"}
0005435092215	95515A	8679 282299	OLEG SOROKIN	{"email": "oleg_sorokin_1969@postgrespro.ru", "phone": "+70609573131"}
0005435092216	D3197B	8984 680567	IVAN VOROBEV	{"phone": "+70398446732"}
0005435092217	D3197B	8364 781004	SERGEY IVANOV	{"email": "sergey-ivanov_08021976@postgrespro.ru", "phone": "+70498097385"}
0005435092218	7E5F26	2809 404063	VASILIY MAKAROV	{"phone": "+70168115199"}
0005435092219	C389E1	6922 797089	ILYA AFANASEV	{"phone": "+70897117709"}
0005435092220	C389E1	6010 019665	EKATERINA EFIMOVA	{"email": "efimovae_12041977@postgrespro.ru", "phone": "+70222442638"}
0005435092221	634789	1669 823323	ELENA IVANOVA	{"email": "ivanova.elena021974@postgrespro.ru", "phone": "+70607652939"}
0005435092222	B1637A	0582 262054	SERGEY SOLOVEV	{"email": "s_solovev.1967@postgrespro.ru", "phone": "+70914353016"}
0005435092223	24CE14	8582 515105	LYUBOV BELYAEVA	{"email": "belyaeval-1981@postgrespro.ru", "phone": "+70349673532"}
0005435092224	24CE14	0113 750538	PETR ROMANOV	{"phone": "+70690729321"}
0005435092225	24CE14	1543 200334	GALINA KUZNECOVA	{"email": "kuznecova.galina1970@postgrespro.ru", "phone": "+70827060794"}
0005435092226	BD0FEA	3544 947830	KRISTINA ALEKSEEVA	{"email": "kristina-alekseeva061974@postgrespro.ru", "phone": "+70296198643"}
0005435092227	DA30E8	5054 818291	VALENTINA GERASIMOVA	{"phone": "+70749015459"}
0005435092228	DA30E8	8691 447620	SERGEY ROMANOV	{"phone": "+70824951825"}
0005435092229	85B351	2545 124180	MIKHAIL KARPOV	{"phone": "+70728477088"}
0005435092230	8F181F	7264 448839	REGINA PETROVA	{"email": "regina_petrova-25061983@postgrespro.ru", "phone": "+70305454095"}
0005435092231	23C1C7	7739 710526	NATALIYA SIDOROVA	{"phone": "+70939780785"}
0005435092232	B1387B	7196 332623	YANA SIDOROVA	{"email": "sidorova.yana.111977@postgrespro.ru", "phone": "+70938345846"}
0005435092233	DA246A	3184 451177	VLADIMIR KISELEV	{"phone": "+70370281386"}
0005435092234	E4EAC4	5245 885331	GALINA BELYAEVA	{"email": "g.belyaeva-111972@postgrespro.ru", "phone": "+70604885535"}
0005435092235	E4EAC4	7219 650885	ALEKSEY KOZLOV	{"phone": "+70867366660"}
0005435092236	E4EAC4	8540 857547	DENIS MELNIKOV	{"phone": "+70691248201"}
0005435092237	7E96F6	3523 316891	OLGA SIDOROVA	{"phone": "+70162680441"}
0005435092238	7E96F6	6187 492450	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila_081963@postgrespro.ru", "phone": "+70012852336"}
0005435092239	237559	3833 346626	VALERIY POPOV	{"email": "valeriypopov-21061971@postgrespro.ru", "phone": "+70006273870"}
0005435092240	CCD152	9165 516631	ANDREY FROLOV	{"email": "andrey-frolov_1976@postgrespro.ru", "phone": "+70896084663"}
0005435092241	5F43E2	4662 178752	ANTONINA BELOVA	{"phone": "+70666897727"}
0005435092242	BCDA46	8348 933663	SERGEY KUZNECOV	{"phone": "+70324531429"}
0005435092243	BCDA46	9071 344468	VIKTOR ZHURAVLEV	{"email": "v.zhuravlev-1972@postgrespro.ru", "phone": "+70127770961"}
0005435092244	E68091	3332 186544	ANATOLIY NAUMOV	{"email": "anatoliy.naumov.091966@postgrespro.ru", "phone": "+70733373971"}
0005435092245	D51DBB	5640 468986	NATALYA FOMINA	{"phone": "+70538214835"}
0005435092246	D51DBB	1194 741995	OLGA KUZMINA	{"phone": "+70737430471"}
0005435092247	C48D49	6436 284137	DMITRIY TIKHONOV	{"phone": "+70211529881"}
0005435092248	21D8B9	0871 098536	NATALYA IVANOVA	{"email": "natalya-ivanova.1966@postgrespro.ru", "phone": "+70477973238"}
0005435092249	5CA7C9	3376 454057	ANNA BORISOVA	{"phone": "+70111847638"}
0005435092250	5012D5	5835 171272	NIKOLAY ISAEV	{"email": "n_isaev1967@postgrespro.ru", "phone": "+70166695248"}
0005435092251	32B31E	4429 639698	ZHANNA MARTYNOVA	{"email": "martynova.zhanna.19031974@postgrespro.ru", "phone": "+70601007356"}
0005435092252	5613E6	3247 058689	ELENA SERGEEVA	{"email": "sergeeva-elena_18111967@postgrespro.ru", "phone": "+70470618842"}
0005435092253	5613E6	0013 958150	TATYANA PETROVA	{"phone": "+70515413123"}
0005435092254	919097	5784 441640	IVAN NIKITIN	{"email": "inikitin051973@postgrespro.ru", "phone": "+70136424362"}
0005435092255	10822C	3055 181624	ALEKSEY BELOV	{"email": "belov_aleksey.11051967@postgrespro.ru", "phone": "+70853491129"}
0005435092256	1C9BCC	9049 941645	ALEKSANDR KONOVALOV	{"phone": "+70360806057"}
0005435092257	D3E142	1020 008072	KARINA MOROZOVA	{"email": "k.morozova.18051985@postgrespro.ru", "phone": "+70418875983"}
0005435092258	4F4494	1130 163841	EDUARD GUSEV	{"email": "gusev-eduard_1970@postgrespro.ru", "phone": "+70390817198"}
0005435092259	4F4494	6657 479948	MARAT KOZLOV	{"phone": "+70374805396"}
0005435092260	22FFB4	9844 146529	LARISA PETROVA	{"email": "petrova_larisa_111973@postgrespro.ru", "phone": "+70404717715"}
0005435092261	86B25A	7629 349516	VALENTINA NIKIFOROVA	{"email": "valentina.nikiforova-13111956@postgrespro.ru", "phone": "+70703811009"}
0005435092262	72D406	1796 144514	NATALYA BORISOVA	{"phone": "+70161729522"}
0005435092263	72D406	5448 811736	MAKSIM EGOROV	{"email": "egorovmaksim_1981@postgrespro.ru", "phone": "+70579985065"}
0005435092264	72D406	5707 051139	VIKTOR ORLOV	{"phone": "+70809246995"}
0005435092265	B5D812	7663 053240	MIKHAIL KAZAKOV	{"email": "kazakov-mikhail-121980@postgrespro.ru", "phone": "+70181818343"}
0005435092266	0804F6	9091 417991	IVAN FEDOTOV	{"phone": "+70829966914"}
0005435092268	0804F6	8632 550239	MARIYA ZHURAVLEVA	{"email": "mariya.zhuravleva29081964@postgrespro.ru", "phone": "+70021600903"}
0005435092269	A242A4	7216 179800	ELENA ANTONOVA	{"phone": "+70748769249"}
0005435092270	6D8F4A	4807 096568	NINA GERASIMOVA	{"phone": "+70603113864"}
0005435092271	8E525E	4999 279069	MARIYA STEPANOVA	{"phone": "+70338820504"}
0005435092272	8E525E	9997 450461	TATYANA FILATOVA	{"email": "tfilatova_1977@postgrespro.ru", "phone": "+70727427451"}
0005435092273	E2256F	5665 218472	YULIANA ILINA	{"email": "yilina-1966@postgrespro.ru", "phone": "+70147230690"}
0005435092274	CE166D	2179 202967	LYUDMILA OSIPOVA	{"email": "osipova-lyudmila.1974@postgrespro.ru", "phone": "+70202818139"}
0005435092275	6B4691	6253 764972	IGOR POPOV	{"email": "igor_popov.1973@postgrespro.ru", "phone": "+70194627887"}
0005435092276	4F431C	2724 908945	ALENA IVANOVA	{"phone": "+70693538129"}
0005435092277	D8E0AB	3123 354012	KSENIYA KAZAKOVA	{"email": "kkazakova.1974@postgrespro.ru", "phone": "+70602712525"}
0005435092278	D8E0AB	5457 579174	ALEKSANDRA MARTYNOVA	{"phone": "+70309571439"}
0005435092279	1D864B	2687 625673	OLEG POPOV	{"email": "oleg-popov-28081973@postgrespro.ru", "phone": "+70036454387"}
0005435092280	1D864B	7716 618504	LYUBOV TARASOVA	{"email": "tarasova_lyubov_1963@postgrespro.ru", "phone": "+70426617175"}
0005435092281	2C192F	5556 348927	YURIY KUZNECOV	{"phone": "+70487604800"}
0005435092282	EE3230	8617 681285	NIKOLAY SIDOROV	{"phone": "+70170343994"}
0005435092283	51E3E6	7766 510447	EKATERINA NESTEROVA	{"phone": "+70240395264"}
0005435092284	657FA7	3395 551667	KLAVDIYA ZAYCEVA	{"email": "zayceva-klavdiya-21111984@postgrespro.ru", "phone": "+70996192964"}
0005435092285	4A2C4B	2543 449935	ALEKSANDR NAUMOV	{"email": "a_naumov-1973@postgrespro.ru", "phone": "+70411333222"}
0005435092286	73707E	6918 021427	ALEKSANDR SEMENOV	{"email": "semenovaleksandr031975@postgrespro.ru", "phone": "+70239149468"}
0005435092287	73707E	7343 123156	VLADIMIR NIKITIN	{"email": "nikitinv1980@postgrespro.ru", "phone": "+70861893097"}
0005435092288	73707E	7673 129364	NADEZHDA POLYAKOVA	{"email": "polyakova.nadezhda1967@postgrespro.ru", "phone": "+70272882575"}
0005435092289	342E4B	7569 920426	NATALIYA SOROKINA	{"email": "sorokina-n-041974@postgrespro.ru", "phone": "+70741032801"}
0005435092290	A3DEC9	5813 348051	OLGA ORLOVA	{"email": "orlovao-1963@postgrespro.ru", "phone": "+70581010167"}
0005435092291	A491C9	0598 911100	MAKSIM KUZNECOV	{"phone": "+70151085369"}
0005435092292	FD9F93	7087 844477	ANATOLIY PETROV	{"phone": "+70558497993"}
0005435092293	4E1869	9792 313972	ALBERT KARPOV	{"email": "karpov.a.15061975@postgrespro.ru", "phone": "+70492687909"}
0005435092294	1433B9	9829 414851	RUSLAN MIKHAYLOV	{"email": "rmikhaylov_1969@postgrespro.ru", "phone": "+70720066431"}
0005435092295	DF9736	6894 290073	NINA GORBUNOVA	{"phone": "+70319474688"}
0005435092296	F5493D	6028 120664	TAMARA SEMENOVA	{"email": "tamara-semenova061971@postgrespro.ru", "phone": "+70173727404"}
0005435092297	5F6F2D	9889 277715	ALINA ALEKSEEVA	{"email": "alinaalekseeva-1961@postgrespro.ru", "phone": "+70048057590"}
0005435092298	945E85	0662 357990	DMITRIY KUZMIN	{"email": "kuzmin_dmitriy.22091977@postgrespro.ru", "phone": "+70757840125"}
0005435092299	6AB9CE	8754 362135	ARTEM KARPOV	{"email": "karpovartem.1973@postgrespro.ru", "phone": "+70372897808"}
0005435092300	7BED2A	1991 037815	TATYANA KAZAKOVA	{"email": "tatyanakazakova_011979@postgrespro.ru", "phone": "+70977383675"}
0005435092301	9FC84A	8743 981885	IRINA TARASOVA	{"phone": "+70415244905"}
0005435092302	B684E5	1558 219308	VIKTOR ISAEV	{"phone": "+70807949670"}
0005435092303	725CEA	3801 038280	ALEKSANDR ZAYCEV	{"phone": "+70396379171"}
0005435092304	725CEA	7769 449458	IRINA KOZLOVA	{"phone": "+70795376561"}
0005435092305	725CEA	1376 888975	EKATERINA SOLOVEVA	{"email": "esoloveva.25121955@postgrespro.ru", "phone": "+70472621091"}
0005435092306	ED9002	1772 130439	IVAN TARASOV	{"phone": "+70592233325"}
0005435092307	83E677	7954 772413	ZUKHRA AFANASEVA	{"email": "afanaseva-zukhra-041965@postgrespro.ru", "phone": "+70512461687"}
0005435092308	F20189	3627 308477	STEPAN KUZNECOV	{"email": "kuznecov.s.16081982@postgrespro.ru", "phone": "+70929858452"}
0005435092309	F20189	7506 306454	ANZHELA TARASOVA	{"email": "anzhelatarasova14021969@postgrespro.ru", "phone": "+70515482762"}
0005435092310	F20189	9817 254468	VASILIY SOKOLOV	{"phone": "+70548570183"}
0005435092311	F20189	8639 200267	PAVEL KULIKOV	{"phone": "+70447912332"}
0005435092312	E1E9E5	0708 886570	VLADISLAV PAVLOV	{"email": "pavlov_vladislav_081977@postgrespro.ru", "phone": "+70901486987"}
0005435092313	B905C3	0230 901770	ALEKSANDR ROMANOV	{"email": "romanov-aleksandr-1969@postgrespro.ru", "phone": "+70112465704"}
0005435092314	C787BB	5288 583381	NINA VOLKOVA	{"phone": "+70187964241"}
0005435092315	06834C	1076 524581	KSENIYA MOISEEVA	{"email": "kseniya-moiseeva_29081970@postgrespro.ru", "phone": "+70412058222"}
0005435092316	B0F2E4	3387 194627	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr_1971@postgrespro.ru", "phone": "+70423021563"}
0005435092317	BA046C	1579 595965	ANNA BORISOVA	{"email": "borisovaa_011968@postgrespro.ru", "phone": "+70690567270"}
0005435092318	380F86	2964 556093	LYUBOV EFREMOVA	{"email": "efremova.lyubov-28031965@postgrespro.ru", "phone": "+70662526806"}
0005435092319	380F86	0841 505551	VIKTOR SCHERBAKOV	{"email": "scherbakov_v_23051979@postgrespro.ru", "phone": "+70485255615"}
0005435092320	FD24D8	1678 876622	VLADIMIR POPOV	{"email": "popovvladimir.27081974@postgrespro.ru", "phone": "+70584197979"}
0005435092321	FD24D8	9103 807429	ALBERT TARASOV	{"phone": "+70725293077"}
0005435092322	BC8338	7481 697375	ANASTASIYA IVANOVA	{"email": "anastasiya-ivanova.031973@postgrespro.ru", "phone": "+70789754010"}
0005435092323	DE63CC	2752 117394	VLADIMIR GRIGOREV	{"phone": "+70734388249"}
0005435092324	95F7B8	2309 439027	SERGEY EGOROV	{"email": "sergey.egorov16041972@postgrespro.ru", "phone": "+70225906608"}
0005435092325	7193EE	8862 879676	VALENTINA ALEKSEEVA	{"email": "v_alekseeva_1964@postgrespro.ru", "phone": "+70761689552"}
0005435092326	7193EE	0814 134186	ALEKSANDR ZHUKOV	{"phone": "+70151887403"}
0005435092327	646D1A	9400 104887	ANDREY SERGEEV	{"email": "andrey_sergeev_021961@postgrespro.ru", "phone": "+70075191934"}
0005435092328	5D1E71	7792 287094	DANIL BORISOV	{"phone": "+70355783578"}
0005435092329	5D1E71	8575 733167	ALEKSANDR ROMANOV	{"email": "romanovaleksandr081964@postgrespro.ru", "phone": "+70845792072"}
0005435092330	2DFD11	4782 181549	IGOR TIKHONOV	{"email": "tikhonovigor-29121973@postgrespro.ru", "phone": "+70520760807"}
0005435092331	2DFD11	5598 501991	SERGEY ZAKHAROV	{"phone": "+70367077501"}
0005435092332	03A5FA	3963 754643	TAMARA MALYSHEVA	{"phone": "+70400618779"}
0005435092333	72F272	2854 131277	DMITRIY MIRONOV	{"phone": "+70303027788"}
0005435092334	72F272	9591 924304	SERGEY GAVRILOV	{"phone": "+70362389554"}
0005435092335	D25BB9	6358 368054	ANDREY ROMANOV	{"email": "a-romanov-12091976@postgrespro.ru", "phone": "+70979847411"}
0005435092336	D25BB9	8355 832380	DMITRIY DENISOV	{"phone": "+70297214195"}
0005435092337	D25BB9	4136 480325	ILDAR BONDARENKO	{"email": "ildarbondarenko_06111968@postgrespro.ru", "phone": "+70571347925"}
0005435092338	8B333F	3807 581777	BORIS NIKOLAEV	{"email": "boris_nikolaev_041971@postgrespro.ru", "phone": "+70148411957"}
0005435092339	C09CD7	6874 048365	SVETLANA BORISOVA	{"email": "svetlana_borisova071967@postgrespro.ru", "phone": "+70594002382"}
0005435092340	8C1705	7329 605556	ALEKSEY MEDVEDEV	{"email": "a_medvedev-18071969@postgrespro.ru", "phone": "+70460849101"}
0005435092341	3FD7AA	2903 412274	LYUDMILA MAKAROVA	{"email": "makaroval_1963@postgrespro.ru", "phone": "+70721376933"}
0005435092342	CEF62A	6695 770655	GENNADIY ROMANOV	{"email": "g_romanov_03111968@postgrespro.ru", "phone": "+70036817048"}
0005435092343	34ED8B	8485 961090	DMITRIY MOROZOV	{"phone": "+70673497284"}
0005435092344	34ED8B	8846 746381	LYUBOV STEPANOVA	{"phone": "+70162546474"}
0005435092345	1C8E54	0167 559560	OLGA ISAEVA	{"phone": "+70987146522"}
0005435092346	B28111	9719 051201	ALEKSANDR NAUMOV	{"email": "naumova_06011979@postgrespro.ru", "phone": "+70287457009"}
0005435092347	B28111	9287 514592	NADEZHDA YAKOVLEVA	{"email": "nadezhda.yakovleva101974@postgrespro.ru", "phone": "+70459930042"}
0005435092348	B28111	0472 381001	NATALYA GERASIMOVA	{"email": "n-gerasimova_09081969@postgrespro.ru", "phone": "+70401044757"}
0005435092349	81540C	6586 517061	VALENTINA STEPANOVA	{"email": "stepanovavalentina-1983@postgrespro.ru", "phone": "+70582074316"}
0005435092350	81540C	8620 689618	IRINA SMIRNOVA	{"email": "i.smirnova-1971@postgrespro.ru", "phone": "+70640860885"}
0005435092351	070C1D	2699 777521	LYUDMILA ARKHIPOVA	{"phone": "+70111445356"}
0005435092352	CBBA2B	1682 049316	LIDIYA MIRONOVA	{"email": "mironoval_05021966@postgrespro.ru", "phone": "+70296573352"}
0005435092353	A85A5B	9298 008198	ALEKSEY DAVYDOV	{"phone": "+70941737773"}
0005435092354	980C9E	4825 702287	VALENTINA ZHUKOVA	{"email": "valentina.zhukova-1971@postgrespro.ru", "phone": "+70351160080"}
0005435092355	F54F14	0109 523017	VALERIY BONDARENKO	{"email": "valeriy-bondarenko.30061981@postgrespro.ru", "phone": "+70888853898"}
0005435092356	48D883	2410 507662	KONSTANTIN ZHURAVLEV	{"phone": "+70024954768"}
0005435092357	0FDED3	0201 189755	VALENTINA NOVIKOVA	{"phone": "+70231528317"}
0005435092358	0FDED3	0654 802931	ALENA SOROKINA	{"email": "alena.sorokina-1979@postgrespro.ru", "phone": "+70025337895"}
0005435092359	C2EE63	3116 902864	DMITRIY ZAKHAROV	{"email": "d.zakharov-1969@postgrespro.ru", "phone": "+70712767754"}
0005435092360	C2EE63	9677 624916	TATYANA KOLESNIKOVA	{"email": "t.kolesnikova.15011974@postgrespro.ru", "phone": "+70770634151"}
0005435092361	681F73	9883 144657	STEPAN BARANOV	{"phone": "+70103674454"}
0005435092362	681F73	2038 594727	NINA ARKHIPOVA	{"phone": "+70358552331"}
0005435092363	71209E	8584 425575	OLEG IVANOV	{"email": "o.ivanov.25091983@postgrespro.ru", "phone": "+70521796533"}
0005435092364	71209E	0689 559756	YULIYA ALEKSEEVA	{"email": "alekseeva_y-1981@postgrespro.ru", "phone": "+70496354925"}
0005435092365	CE90CB	8911 293306	IRINA SEMENOVA	{"phone": "+70646892356"}
0005435092366	E58F20	4519 708636	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey1971@postgrespro.ru", "phone": "+70099772817"}
0005435092367	E58F20	5601 389901	ELENA ALEKSEEVA	{"phone": "+70173995993"}
0005435097043	0E60C9	4286 543808	VLADIMIR KUZMIN	{"email": "v.kuzmin-081973@postgrespro.ru", "phone": "+70987688392"}
0005435097044	CB9914	6762 771733	TATYANA KUZNECOVA	{"phone": "+70985357620"}
0005435097045	CB9914	5613 340910	LIDIYA FEDOROVA	{"phone": "+70584561500"}
0005435097046	FE5DB6	6979 228785	IRINA VASILEVA	{"email": "irina_vasileva-121969@postgrespro.ru", "phone": "+70628169028"}
0005435097047	FE5DB6	2909 762282	PRASKOVYA MALYSHEVA	{"phone": "+70649395191"}
0005435097048	B5E2A0	0089 977636	YURIY KUZMIN	{"email": "yuriykuzmin.061970@postgrespro.ru", "phone": "+70957433615"}
0005435097049	B5E2A0	3775 418806	KLAVDIYA MAKSIMOVA	{"phone": "+70127770328"}
0005435097050	009884	5824 580664	IGOR VASILEV	{"phone": "+70572811421"}
0005435097051	F11F52	9143 250311	SVETLANA VASILEVA	{"phone": "+70481246820"}
0005435097052	62AA0F	8577 585556	VALENTINA MAKSIMOVA	{"email": "maksimova.valentina-1976@postgrespro.ru", "phone": "+70041321617"}
0005435097053	62AA0F	8831 107595	DMITRIY FROLOV	{"email": "frolovd-1967@postgrespro.ru", "phone": "+70074789855"}
0005435097054	0D0303	8724 450622	SVETLANA MOROZOVA	{"email": "s_morozova13121961@postgrespro.ru", "phone": "+70597452526"}
0005435097055	CB5F01	1722 847138	NINA ROMANOVA	{"email": "n-romanova.1979@postgrespro.ru", "phone": "+70965454182"}
0005435097056	1E99F4	4998 869214	OKSANA SMIRNOVA	{"email": "o.smirnova_30031968@postgrespro.ru", "phone": "+70998347853"}
0005435097057	1E99F4	4878 144269	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova_031974@postgrespro.ru", "phone": "+70979373017"}
0005435097058	E5892D	5511 416755	ELENA KUZMINA	{"phone": "+70919101278"}
0005435097059	E5892D	3552 762384	NATALYA MAKAROVA	{"email": "makarova.n_16051966@postgrespro.ru", "phone": "+70484226323"}
0005435097060	E655EF	2097 040443	TIMUR IVANOV	{"email": "ivanov-timur-1973@postgrespro.ru", "phone": "+70768915201"}
0005435097061	E655EF	4545 259174	OLGA NAZAROVA	{"email": "o-nazarova_081969@postgrespro.ru", "phone": "+70899397526"}
0005435097062	396606	0049 071780	NIKOLAY ZHUKOV	{"phone": "+70864269284"}
0005435097063	396606	3478 298592	VLADIMIR NIKITIN	{"phone": "+70272568144"}
0005435097064	E21D3E	7456 710945	KSENIYA MALYSHEVA	{"email": "kmalysheva-1962@postgrespro.ru", "phone": "+70655370113"}
0005435097121	E0C047	6089 369199	SVETLANA LOGINOVA	{"phone": "+70283170855"}
0005435097065	FFA17D	5722 529298	EVGENIY MAKSIMOV	{"email": "maksimov_evgeniy_061971@postgrespro.ru", "phone": "+70271371072"}
0005435097066	FFA17D	2461 901503	NATALYA KUZMINA	{"phone": "+70154410787"}
0005435097067	1FFB87	4491 310176	ALEKSANDR SHEVCHENKO	{"email": "aleksandr.shevchenko_1975@postgrespro.ru", "phone": "+70803522396"}
0005435097068	6B43C0	7819 436000	SERGEY KONOVALOV	{"phone": "+70345574459"}
0005435097069	205BA1	8037 915571	VLADIMIR SOKOLOV	{"email": "vladimir.sokolov_19121970@postgrespro.ru", "phone": "+70934200142"}
0005435097070	35A35B	6450 446199	NIKOLAY BELOV	{"email": "belov.n1980@postgrespro.ru", "phone": "+70721645165"}
0005435097071	35A35B	5764 732594	IGOR BORISOV	{"email": "borisov.igor_031969@postgrespro.ru", "phone": "+70331181128"}
0005435097072	61740C	1155 978460	YAROSLAV SMIRNOV	{"email": "smirnov_yaroslav-1973@postgrespro.ru", "phone": "+70947127475"}
0005435097073	949E53	3913 460511	YULIYA ISAEVA	{"email": "isaeva.y.29081956@postgrespro.ru", "phone": "+70887118032"}
0005435097074	949E53	3156 815638	OLGA SOKOLOVA	{"phone": "+70707855070"}
0005435097075	1920BA	0762 094191	SERGEY KUZMIN	{"phone": "+70820555559"}
0005435097076	1920BA	2184 405912	ANTON KOROLEV	{"phone": "+70872457849"}
0005435097077	D6595C	2535 516534	SERGEY ILIN	{"phone": "+70796060224"}
0005435097078	D6F0C6	2938 764469	VLADISLAV GERASIMOV	{"email": "gerasimov_vladislav_1966@postgrespro.ru", "phone": "+70822504440"}
0005435097079	5540C1	5512 333888	OLGA KUZMINA	{"email": "kuzmina.olga_1974@postgrespro.ru", "phone": "+70008218155"}
0005435097080	5540C1	4528 529449	SVETLANA ROMANOVA	{"email": "romanova.s.061980@postgrespro.ru", "phone": "+70490026695"}
0005435097081	11FB93	1762 147743	BORIS KAZAKOV	{"phone": "+70591111079"}
0005435097082	0F9BED	2628 339272	ELENA KULIKOVA	{"phone": "+70094300295"}
0005435097083	27B435	9619 394578	ELENA KONDRATEVA	{"phone": "+70164296991"}
0005435097084	FCC4CE	0260 188338	SERGEY PETROV	{"phone": "+70740016839"}
0005435097085	ED3168	6587 281640	ALEKSEY KULIKOV	{"email": "a-kulikov-051976@postgrespro.ru", "phone": "+70149931535"}
0005435097086	ED3168	6851 939316	OLEG OSIPOV	{"email": "osipovo-021985@postgrespro.ru", "phone": "+70308028672"}
0005435097087	ED3168	6439 070006	ALINA SERGEEVA	{"email": "a-sergeeva-01011981@postgrespro.ru", "phone": "+70412774318"}
0005435097088	9EFD34	4412 504989	MARGARITA FEDOROVA	{"phone": "+70814125846"}
0005435097089	7AEF1C	5782 997312	SVETLANA SERGEEVA	{"phone": "+70901215650"}
0005435097090	F76134	0375 075007	SERGEY CHERNOV	{"phone": "+70094613332"}
0005435097091	ACDDA7	9221 784305	SERGEY SOROKIN	{"email": "sergey_sorokin1966@postgrespro.ru", "phone": "+70346816906"}
0005435097092	9E1DDF	6200 465002	YURIY KISELEV	{"email": "kiselev_yuriy-1973@postgrespro.ru", "phone": "+70937202012"}
0005435097093	9E1DDF	1250 468467	NATALIYA MAKSIMOVA	{"email": "n.maksimova_1964@postgrespro.ru", "phone": "+70545002732"}
0005435097094	9E1DDF	6910 096715	LYUBOV IVANOVA	{"phone": "+70472984418"}
0005435097095	EB1247	9129 990737	MARINA ABRAMOVA	{"email": "abramova.marina_111974@postgrespro.ru", "phone": "+70957913864"}
0005435097096	3709A7	8395 064366	SERGEY KAZAKOV	{"email": "skazakov051973@postgrespro.ru", "phone": "+70795639775"}
0005435097097	233442	2588 864380	ZINAIDA ZHUKOVA	{"phone": "+70910775280"}
0005435097098	4E2CD6	9187 068216	VLADIMIR MOISEEV	{"email": "moiseev_vladimir051957@postgrespro.ru", "phone": "+70705495088"}
0005435097099	B09F92	9504 129440	MARIYA FEDOROVA	{"phone": "+70004249293"}
0005435097100	006B6D	2228 016096	YURIY POPOV	{"email": "popovyuriy081969@postgrespro.ru", "phone": "+70102733141"}
0005435097101	A0DE71	7280 638022	ANATOLIY BARANOV	{"email": "baranovanatoliy101975@postgrespro.ru", "phone": "+70413400062"}
0005435097102	BFCC17	2840 950165	DMITRIY NAUMOV	{"phone": "+70727141373"}
0005435097103	BFCC17	0790 947706	TATYANA TIKHONOVA	{"phone": "+70249560629"}
0005435097104	BFCC17	6473 970647	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr.1982@postgrespro.ru", "phone": "+70612563325"}
0005435097105	20D78D	1348 429212	ANASTASIYA POPOVA	{"email": "popova_a.10111982@postgrespro.ru", "phone": "+70977581593"}
0005435097106	CA6C20	9342 642086	ALEKSEY SMIRNOV	{"phone": "+70993352210"}
0005435097107	091014	2645 997288	GALINA GERASIMOVA	{"email": "gerasimova-galina_21081970@postgrespro.ru", "phone": "+70757251158"}
0005435097108	C683ED	2654 692241	LIDIYA DAVYDOVA	{"email": "davydova-l-1983@postgrespro.ru", "phone": "+70703605942"}
0005435097109	F25B61	6960 842312	ALEKSEY MOROZOV	{"email": "aleksey-morozov-021966@postgrespro.ru", "phone": "+70719551489"}
0005435097110	EEB59B	5405 112572	VLADIMIR VASILEV	{"email": "vasilevv_051972@postgrespro.ru", "phone": "+70030515997"}
0005435097111	EEB59B	3303 881992	ALEKSEY KONOVALOV	{"phone": "+70531774224"}
0005435097112	1E592B	6952 316807	MARINA ZAYCEVA	{"phone": "+70328658505"}
0005435097113	1E592B	6927 235867	YURIY NAZAROV	{"email": "yuriy_nazarov-1977@postgrespro.ru", "phone": "+70596763644"}
0005435097114	1E592B	4342 489275	VLADIMIR PETROV	{"email": "petrov.v_011972@postgrespro.ru", "phone": "+70212360239"}
0005435097115	90B02B	0911 454528	ELIZAVETA KAZAKOVA	{"email": "kazakovaelizaveta101979@postgrespro.ru", "phone": "+70767681485"}
0005435097116	183570	7649 562784	NIKOLAY VOROBEV	{"phone": "+70627729923"}
0005435097117	1126A7	0000 931651	ALEKSEY ANTONOV	{"phone": "+70545657579"}
0005435097118	1126A7	2356 919713	DAMIR OSIPOV	{"email": "damir_osipov01061963@postgrespro.ru", "phone": "+70109399368"}
0005435097119	415E7E	8220 322289	ANDREY BARANOV	{"phone": "+70902758053"}
0005435097120	E0C047	9458 207414	GENNADIY POPOV	{"email": "gennadiy.popov1971@postgrespro.ru", "phone": "+70800609005"}
0005435097122	AAF231	7933 766951	ALEKSEY ROMANOV	{"email": "aleksey_romanov111968@postgrespro.ru", "phone": "+70864498739"}
0005435097123	8CA23E	5241 817921	LARISA SAVELEVA	{"phone": "+70552069573"}
0005435097124	8CA23E	6591 006654	ELIZAVETA DMITRIEVA	{"email": "dmitrieva_elizaveta-1976@postgrespro.ru", "phone": "+70460586607"}
0005435097125	70600E	0041 287259	ELENA PETROVA	{"email": "petrova_elena.28021968@postgrespro.ru", "phone": "+70948343766"}
0005435097126	4AAD29	7866 643874	SERGEY POPOV	{"phone": "+70431258729"}
0005435097127	4AAD29	8721 950580	NATALYA NIKIFOROVA	{"phone": "+70947241963"}
0005435097128	14B377	8506 234953	ANNA TIKHONOVA	{"email": "a-tikhonova_011972@postgrespro.ru", "phone": "+70612784442"}
0005435097129	14B377	6614 133588	NIKOLAY PETROV	{"phone": "+70097211860"}
0005435097130	57DA76	1491 099618	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov_1981@postgrespro.ru", "phone": "+70922527496"}
0005435097131	57DA76	3034 192021	ALEKSANDR VASILEV	{"phone": "+70204715949"}
0005435097132	26D28A	4271 156780	SERGEY YAKOVLEV	{"phone": "+70532371131"}
0005435097133	2B6FCF	8967 706306	VIKTOR MATVEEV	{"phone": "+70650737812"}
0005435097134	EDB10B	6847 790397	ALEKSEY KISELEV	{"email": "a.kiselev.28071973@postgrespro.ru", "phone": "+70489200399"}
0005435097135	B6CCEE	1358 655467	SVETLANA NOVIKOVA	{"email": "s-novikova.23041967@postgrespro.ru", "phone": "+70475901315"}
0005435097136	B6CCEE	6125 149996	NADEZHDA EGOROVA	{"email": "nadezhda-egorova081975@postgrespro.ru", "phone": "+70031140099"}
0005435097137	865E4C	7867 372918	VYACHESLAV SAVELEV	{"email": "v-savelev-23041971@postgrespro.ru", "phone": "+70237763708"}
0005435097138	389065	7476 041929	VIKTOR FROLOV	{"email": "viktor.frolov_1979@postgrespro.ru", "phone": "+70425434063"}
0005435097139	389065	3218 536264	VITALIY ALEKSEEV	{"email": "v_alekseev_011976@postgrespro.ru", "phone": "+70744708727"}
0005435097140	389065	1741 144350	VYACHESLAV FROLOV	{"email": "frolov.vyacheslav-021974@postgrespro.ru", "phone": "+70397351042"}
0005435097141	E20687	4298 304742	GUZEL KUZNECOVA	{"phone": "+70987736724"}
0005435097142	8C671B	9214 202369	ALEKSEY EGOROV	{"email": "egorov_a.101983@postgrespro.ru", "phone": "+70433985087"}
0005435097143	8C671B	4300 211492	DMITRIY MOROZOV	{"phone": "+70770994348"}
0005435097144	8D76BF	5575 087710	SERGEY SOROKIN	{"email": "sorokin_sergey.1979@postgrespro.ru", "phone": "+70200926507"}
0005435097145	8D76BF	2787 282688	IRINA NESTEROVA	{"email": "nesterova-irina-10021983@postgrespro.ru", "phone": "+70854297370"}
0005435097146	6552D5	1214 567290	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov041972@postgrespro.ru", "phone": "+70372460518"}
0005435097147	E7679C	3366 806630	ALISA PETROVA	{"email": "petrova.alisa.051969@postgrespro.ru", "phone": "+70529027534"}
0005435097148	E7679C	8746 807884	GALINA MATVEEVA	{"phone": "+70287312887"}
0005435097149	4179BF	1088 919398	KIRILL SCHERBAKOV	{"phone": "+70014834555"}
0005435097150	4179BF	4021 195600	DINARA RYABOVA	{"phone": "+70045354717"}
0005435097151	4179BF	3308 474010	GALINA NAZAROVA	{"phone": "+70895155110"}
0005435097152	A1C7B1	1673 482563	EVGENIY GAVRILOV	{"phone": "+70476548898"}
0005435097153	F03A16	8629 320029	NIKOLAY ILIN	{"email": "n-ilin_1977@postgrespro.ru", "phone": "+70917044822"}
0005435097154	5053A4	1756 650522	ALEKSANDR KUZNECOV	{"phone": "+70664773632"}
0005435097155	5053A4	9048 208365	ANDREY NIKITIN	{"phone": "+70340142292"}
0005435097156	5053A4	0997 412289	ALLA ILINA	{"phone": "+70275090059"}
0005435097157	30949A	5390 665482	NIKITA SCHERBAKOV	{"phone": "+70488667391"}
0005435097158	D8AF00	6941 148140	ARTEM SMIRNOV	{"email": "a-smirnov-15101979@postgrespro.ru", "phone": "+70245854701"}
0005435097159	5ED490	5012 617670	YURIY YAKOVLEV	{"phone": "+70068601345"}
0005435097160	5B3FE5	8620 087109	BORIS KOZLOV	{"phone": "+70446643775"}
0005435097161	606CE0	8590 204411	OKSANA DAVYDOVA	{"email": "oksana.davydova081963@postgrespro.ru", "phone": "+70286017684"}
0005435097162	8D6308	1127 891815	PAVEL KUDRYASHOV	{"email": "p-kudryashov081961@postgrespro.ru", "phone": "+70968545606"}
0005435097163	8D6308	5052 470950	ARTEM MAKSIMOV	{"email": "artem_maksimov.08121970@postgrespro.ru", "phone": "+70120949990"}
0005435097164	D242EC	8623 724657	KONSTANTIN IVANOV	{"phone": "+70762546881"}
0005435097165	D242EC	8880 703893	DMITRIY MAKAROV	{"email": "makarov-d.19111974@postgrespro.ru", "phone": "+70173867404"}
0005435097166	A94E73	8923 669681	ELENA MAKAROVA	{"phone": "+70750334047"}
0005435097167	EE473A	5080 458630	VALENTINA KOLESNIKOVA	{"email": "valentina-kolesnikova_27041978@postgrespro.ru", "phone": "+70579275059"}
0005435097168	EE473A	9207 608813	TAMARA TIMOFEEVA	{"phone": "+70474314699"}
0005435097169	EE473A	4724 966956	SVETLANA KALININA	{"phone": "+70535589102"}
0005435097170	EAF5DF	6326 712007	POLINA IVANOVA	{"phone": "+70765224792"}
0005435097171	71B36C	2286 321890	ANATOLIY FEDOROV	{"email": "a.fedorov-30041965@postgrespro.ru", "phone": "+70993179697"}
0005435097172	252062	8783 720750	IRINA MOROZOVA	{"email": "irina-morozova_011983@postgrespro.ru", "phone": "+70728723129"}
0005435097173	252062	1526 320041	RAISA EGOROVA	{"email": "raisa_egorova-1972@postgrespro.ru", "phone": "+70091871156"}
0005435097174	EE25E2	0012 256145	DMITRIY ZHURAVLEV	{"email": "zhuravlevd_121968@postgrespro.ru", "phone": "+70373247449"}
0005435097175	EE25E2	0063 272653	RAISA NIKOLAEVA	{"email": "r_nikolaeva.011988@postgrespro.ru", "phone": "+70122883339"}
0005435097176	EF1A95	0453 237157	SVETLANA KUZMINA	{"email": "svetlanakuzmina14011970@postgrespro.ru", "phone": "+70230837899"}
0005435097512	0EDB9D	5908 110261	YULIYA ALEKSEEVA	{"phone": "+70387166964"}
0005435097177	EF1A95	7002 325503	KLAVDIYA TIKHONOVA	{"email": "tikhonova_k_1973@postgrespro.ru", "phone": "+70312502773"}
0005435097178	A5366B	6841 435155	SERGEY NIKITIN	{"phone": "+70380512889"}
0005435097179	B739D9	9960 642623	GULNARA VASILEVA	{"phone": "+70235415590"}
0005435097180	E4B77E	4821 575736	NATALYA SERGEEVA	{"phone": "+70028390890"}
0005435097181	B38D49	0699 702660	TATYANA FEDOROVA	{"email": "fedorovat_07111982@postgrespro.ru", "phone": "+70416608652"}
0005435097182	39D99B	8278 500428	LYUDMILA DAVYDOVA	{"email": "l.davydova121988@postgrespro.ru", "phone": "+70318142162"}
0005435097183	CDA1AA	9754 052879	MARINA GAVRILOVA	{"email": "gavrilova-marina.1967@postgrespro.ru", "phone": "+70987472753"}
0005435097184	CDA1AA	3201 415442	SVETLANA TARASOVA	{"email": "svetlanatarasova.1971@postgrespro.ru", "phone": "+70589999367"}
0005435097185	CDA1AA	3767 484134	EKATERINA FEDOROVA	{"phone": "+70504622563"}
0005435097186	9542D6	4488 527034	POLINA TARASOVA	{"phone": "+70423790808"}
0005435097187	9542D6	7240 801129	NADEZHDA SOROKINA	{"phone": "+70502810772"}
0005435097188	AF2FFF	6339 612459	NIKOLAY PAVLOV	{"phone": "+70461807633"}
0005435097189	19991B	5269 410724	ANTON ROMANOV	{"email": "a-romanov-25071967@postgrespro.ru", "phone": "+70292246835"}
0005435097190	1AA601	7167 105723	VLADISLAV GORBUNOV	{"email": "gorbunov.vladislav_1967@postgrespro.ru", "phone": "+70123749232"}
0005435097191	1713FE	3233 408475	MARINA ANISIMOVA	{"phone": "+70886310866"}
0005435097192	C4B5FD	6757 995137	YURIY SAVELEV	{"email": "savelev.y1965@postgrespro.ru", "phone": "+70349147695"}
0005435097193	F4936F	6241 398214	TATYANA VLASOVA	{"email": "tatyana-vlasova121966@postgrespro.ru", "phone": "+70292919632"}
0005435097194	A15D1B	6231 802731	ALEKSANDR FROLOV	{"phone": "+70716586044"}
0005435097195	6ECEDE	4888 862752	TATYANA ANDREEVA	{"phone": "+70507594657"}
0005435097196	E3FE90	2820 789497	ANASTASIYA MELNIKOVA	{"email": "anastasiya_melnikova1975@postgrespro.ru", "phone": "+70206573783"}
0005435097197	E3FE90	2011 143044	EKATERINA KUZNECOVA	{"email": "kuznecova.e_101972@postgrespro.ru", "phone": "+70842255677"}
0005435097198	E3FE90	7210 247786	VITALIY KUZNECOV	{"phone": "+70295126757"}
0005435097199	E25FD1	8293 618866	SERGEY TIKHONOV	{"email": "sergey.tikhonov1967@postgrespro.ru", "phone": "+70680908105"}
0005435097200	A5396A	4060 643874	DMITRIY ZHUKOV	{"email": "dmitriy-zhukov-051963@postgrespro.ru", "phone": "+70135373381"}
0005435097201	A5396A	3641 440730	ANNA MATVEEVA	{"phone": "+70624542409"}
0005435097202	7D67D2	9473 385725	NATALYA OSIPOVA	{"email": "natalya.osipova.01121970@postgrespro.ru", "phone": "+70486809046"}
0005435097203	F70269	7353 255743	NIKOLAY KONOVALOV	{"email": "nikolay-konovalov_1972@postgrespro.ru", "phone": "+70250725103"}
0005435097204	F70269	4964 962799	SERGEY PAVLOV	{"phone": "+70013180125"}
0005435097205	C1338A	6086 315238	MARIYA MIRONOVA	{"email": "mironovam031969@postgrespro.ru", "phone": "+70386894859"}
0005435097206	663067	0691 563383	GLEB SCHERBAKOV	{"email": "gleb_scherbakov-03011971@postgrespro.ru", "phone": "+70016224795"}
0005435097207	663067	4606 661966	ALEKSEY SEMENOV	{"email": "aleksey.semenov10091968@postgrespro.ru", "phone": "+70050792414"}
0005435097208	6B319D	8640 892099	YURIY VOROBEV	{"email": "vorobev.yuriy.061968@postgrespro.ru", "phone": "+70825083928"}
0005435097209	6B319D	3469 553799	VALENTINA ZHUKOVA	{"phone": "+70098100901"}
0005435097210	998F5F	7446 894347	ALEKSEY NOVIKOV	{"email": "a.novikov-121983@postgrespro.ru", "phone": "+70124936633"}
0005435097211	17FE53	1635 100185	LYUDMILA TIKHONOVA	{"phone": "+70838658727"}
0005435097212	9459EF	5682 387346	OLGA MAKSIMOVA	{"phone": "+70894076810"}
0005435097213	9459EF	4266 158470	KSENIYA PAVLOVA	{"phone": "+70987893131"}
0005435097214	BB59E3	3536 544285	RAMIL GAVRILOV	{"phone": "+70582113020"}
0005435097215	BB59E3	3252 642866	ALEKSANDR POPOV	{"phone": "+70078830681"}
0005435097216	1CB2EE	0746 930823	DMITRIY GORBUNOV	{"email": "gorbunov_d-1977@postgrespro.ru", "phone": "+70506047627"}
0005435097217	1CB2EE	1562 646468	VLADIMIR RODIONOV	{"email": "rodionov-vladimir_091972@postgrespro.ru", "phone": "+70015921365"}
0005435097218	6B2D8E	0972 829406	YULIYA MIRONOVA	{"phone": "+70758805427"}
0005435097219	6B2D8E	6039 833689	NAILYA YUDINA	{"email": "yudina-n-14101964@postgrespro.ru", "phone": "+70004823685"}
0005435097220	9E48AF	2083 050488	ELENA ABRAMOVA	{"email": "abramova.e_091979@postgrespro.ru", "phone": "+70586469609"}
0005435097221	AD75D2	0702 784416	EVGENIYA KISELEVA	{"phone": "+70934592253"}
0005435097222	AD75D2	0785 331356	SERGEY SOKOLOV	{"phone": "+70681943174"}
0005435097223	DEE3DA	9736 559990	TATYANA ALEKSANDROVA	{"phone": "+70905689620"}
0005435097224	864978	9078 483758	ELIZAVETA ILINA	{"phone": "+70411082023"}
0005435097225	7335E6	4699 749112	GYUZEL ISAEVA	{"email": "isaevag-29101977@postgrespro.ru", "phone": "+70676897846"}
0005435097226	7335E6	8533 149392	IRINA NIKITINA	{"email": "irina.nikitina-1967@postgrespro.ru", "phone": "+70707109886"}
0005435097227	05B2BC	6396 325067	ALEKSANDR SEMENOV	{"phone": "+70440065361"}
0005435097228	D57C9A	1836 304678	EKATERINA YAKOVLEVA	{"phone": "+70629309187"}
0005435097229	D57C9A	9738 128541	ROBERT BONDARENKO	{"email": "r.bondarenko-011971@postgrespro.ru", "phone": "+70836274483"}
0005435097230	0FF37F	4617 127427	NATALYA IVANOVA	{"phone": "+70608150268"}
0005435097231	2FAC0D	2247 022038	ARTEMIY GERASIMOV	{"email": "agerasimov.31051974@postgrespro.ru", "phone": "+70908053330"}
0005435097232	1A8E38	5129 312583	DMITRIY KOROLEV	{"email": "d.korolev.081980@postgrespro.ru", "phone": "+70840219773"}
0005435097233	1A8E38	1653 789867	OLGA KOROLEVA	{"email": "koroleva.o_27101975@postgrespro.ru", "phone": "+70567217080"}
0005435097234	49640E	4053 263742	IVAN TARASOV	{"email": "tarasov_i_101974@postgrespro.ru", "phone": "+70752743831"}
0005435097235	0919BA	4772 549151	ELENA SMIRNOVA	{"phone": "+70384809422"}
0005435097236	BB255C	7167 646649	ALEKSANDR KUZNECOV	{"phone": "+70056973919"}
0005435097237	F9334B	5925 094435	ALEKSANDR ANDREEV	{"phone": "+70404993606"}
0005435097238	7A4B30	0512 723352	PAVEL SOROKIN	{"email": "pavel_sorokin_19071973@postgrespro.ru", "phone": "+70457615584"}
0005435097239	E29403	6711 397655	NATALYA KOLESNIKOVA	{"email": "kolesnikovan_011964@postgrespro.ru", "phone": "+70731751196"}
0005435097240	2BE690	5696 570086	SVETLANA SEMENOVA	{"email": "svetlana-semenova.121978@postgrespro.ru", "phone": "+70511457696"}
0005435097241	DA3672	0818 230472	ANNA PETROVA	{"email": "petrova_a-011977@postgrespro.ru", "phone": "+70552733554"}
0005435097242	DA3672	4749 529465	YULIYA ABRAMOVA	{"phone": "+70959087408"}
0005435097243	179BC6	7131 180126	OLGA ZAYCEVA	{"email": "zaycevao_03041980@postgrespro.ru", "phone": "+70780472041"}
0005435097244	018F3E	5004 382694	TIKHON MAKAROV	{"phone": "+70233766563"}
0005435097245	018F3E	9536 612489	VYACHESLAV MAKAROV	{"phone": "+70156485410"}
0005435097246	018F3E	3185 986646	ARTEM ROMANOV	{"email": "a_romanov-051975@postgrespro.ru", "phone": "+70128638824"}
0005435097247	9B3376	8473 337049	SERGEY SOROKIN	{"email": "sorokin.sergey_1971@postgrespro.ru", "phone": "+70667105897"}
0005435097248	2F4B91	8226 877358	DIANA ZAKHAROVA	{"email": "zakharovad_031980@postgrespro.ru", "phone": "+70314003065"}
0005435097249	5B0F19	7500 380557	NIKITA ANTONOV	{"phone": "+70360543289"}
0005435097250	B9300A	9125 098353	LYUBOV MOISEEVA	{"phone": "+70658476196"}
0005435097251	D1398B	6806 598354	LYUDMILA VLASOVA	{"phone": "+70019088019"}
0005435097252	D793BF	5617 679148	VALENTIN SOROKIN	{"email": "v-sorokin.03101977@postgrespro.ru", "phone": "+70924748934"}
0005435097253	7C004E	9411 372061	EMMA BELOVA	{"phone": "+70047664610"}
0005435097254	B7075C	2892 527507	ELENA IVANOVA	{"phone": "+70013637666"}
0005435097255	5396E4	0561 703194	MAKSIM VLASOV	{"email": "maksimvlasov-28121969@postgrespro.ru", "phone": "+70806938187"}
0005435097256	99D24B	2392 176996	VALERIY VASILEV	{"phone": "+70936097828"}
0005435097257	77B664	1724 304046	VIKTOR VOLKOV	{"phone": "+70353140324"}
0005435097258	0655F9	6194 751175	LYUBOV NIKOLAEVA	{"phone": "+70846859182"}
0005435097259	8B4EEA	1823 685101	RAVIL ROMANOV	{"email": "romanov-r.071966@postgrespro.ru", "phone": "+70449696925"}
0005435097260	8B4EEA	3516 783235	GENNADIY VOROBEV	{"email": "g.vorobev_011984@postgrespro.ru", "phone": "+70415315630"}
0005435097261	3B2E09	4302 383304	KRISTINA MOROZOVA	{"email": "morozova_k27111981@postgrespro.ru", "phone": "+70233228036"}
0005435097262	83F4CF	3062 344340	EVGENIY SHEVCHENKO	{"phone": "+70714199847"}
0005435097263	0F8F8B	8195 752279	MAYA ZAYCEVA	{"email": "zayceva-m-031968@postgrespro.ru", "phone": "+70427485427"}
0005435097264	525D73	2066 868761	SERGEY KUZMIN	{"phone": "+70727503213"}
0005435097265	525D73	5791 823504	DMITRIY KONOVALOV	{"phone": "+70533326905"}
0005435097266	520C0C	7816 785589	TATYANA EFREMOVA	{"email": "efremova.t-15031971@postgrespro.ru", "phone": "+70261844102"}
0005435097267	3A5F0A	7099 287447	ALEKSANDR VLASOV	{"email": "a_vlasov03091973@postgrespro.ru", "phone": "+70462729727"}
0005435097268	6CAA4E	9393 592388	VALENTINA LUKYANOVA	{"email": "valentina.lukyanova-081982@postgrespro.ru", "phone": "+70498245042"}
0005435097269	E4C868	6278 816995	IVAN KAZAKOV	{"email": "kazakov_i-06081967@postgrespro.ru", "phone": "+70108770757"}
0005435097270	E6D81C	4551 663321	ANDREY FROLOV	{"phone": "+70720714770"}
0005435097271	E6D81C	5986 165082	LYUDMILA NESTEROVA	{"phone": "+70180276238"}
0005435097272	E6D81C	7781 187306	MARIYA BELYAEVA	{"email": "belyaeva.m-051979@postgrespro.ru", "phone": "+70488183808"}
0005435097273	212E1E	3695 831296	VALENTINA VLASOVA	{"phone": "+70758990088"}
0005435097274	F89D3D	4573 229137	ALENA NESTEROVA	{"email": "nesterovaalena-051984@postgrespro.ru", "phone": "+70911057106"}
0005435097275	5584D0	1715 440046	ELENA DENISOVA	{"phone": "+70351593100"}
0005435097276	C0E9A2	0426 694654	SERGEY FEDOTOV	{"email": "sfedotov-021973@postgrespro.ru", "phone": "+70223832488"}
0005435097277	C0E9A2	2014 782137	SERGEY NOVIKOV	{"phone": "+70440883687"}
0005435097278	1B4E69	0267 592434	VALENTINA SEMENOVA	{"phone": "+70207887414"}
0005435097279	1B4E69	0972 975898	MARINA ANDREEVA	{"email": "andreeva_marina1972@postgrespro.ru", "phone": "+70741624678"}
0005435097280	A6FB3E	1601 780281	ALBINA LUKYANOVA	{"email": "lukyanova.albina-06031971@postgrespro.ru", "phone": "+70406462246"}
0005435097281	A6FB3E	5265 077504	MARIYA NIKOLAEVA	{"email": "nikolaevam_1971@postgrespro.ru", "phone": "+70340643446"}
0005435097282	945931	7772 311263	VADIM KOZLOV	{"phone": "+70723320182"}
0005435097283	6C0AEF	0758 104224	ANNA ANTONOVA	{"email": "antonova_anna_09121983@postgrespro.ru", "phone": "+70297274308"}
0005435097284	6C0AEF	1249 784089	NATALYA GERASIMOVA	{"email": "ngerasimova-07041973@postgrespro.ru", "phone": "+70044934586"}
0005435097285	D231E4	4320 421473	VLADIMIR MOROZOV	{"phone": "+70340694508"}
0005435097286	A6F7F9	2764 742036	VALENTINA ZHURAVLEVA	{"email": "zhuravleva-v_1970@postgrespro.ru", "phone": "+70240495974"}
0005435097287	0DA4DE	0916 011475	ANASTASIYA SERGEEVA	{"phone": "+70594903190"}
0005435097288	0DA4DE	8794 665767	ELENA KOVALEVA	{"email": "elena.kovaleva021973@postgrespro.ru", "phone": "+70434057417"}
0005435097289	0DA4DE	9225 219752	DANILA IVANOV	{"email": "ivanovd-041964@postgrespro.ru", "phone": "+70977292534"}
0005435097290	E5FB03	1725 846650	ANDREY SEMENOV	{"email": "semenovandrey_041975@postgrespro.ru", "phone": "+70960238801"}
0005435097291	D7F322	8008 960105	VIKTORIYA OVCHINNIKOVA	{"email": "ovchinnikova.v.1971@postgrespro.ru", "phone": "+70031865054"}
0005435097292	3A100F	5100 990062	ELENA DAVYDOVA	{"email": "e.davydova-121975@postgrespro.ru", "phone": "+70818416040"}
0005435097293	6A7DE3	4109 269970	ANASTASIYA NIKITINA	{"phone": "+70868985666"}
0005435097294	6A7DE3	0372 239256	OLEG AFANASEV	{"email": "afanasevoleg_121976@postgrespro.ru", "phone": "+70398228122"}
0005435097295	6A7DE3	3709 907003	KONSTANTIN SOROKIN	{"phone": "+70005989686"}
0005435097296	51AF68	3892 287038	EVGENIY KAZAKOV	{"phone": "+70043568491"}
0005435097297	D03836	3408 416223	ALEKSANDRA SOKOLOVA	{"email": "aleksandra-sokolova1967@postgrespro.ru", "phone": "+70581453440"}
0005435097298	A99E90	1932 712373	ALEKSEY SCHERBAKOV	{"email": "a.scherbakov_10111958@postgrespro.ru", "phone": "+70069253262"}
0005435097299	A99E90	7573 208602	VALENTINA ALEKSEEVA	{"email": "alekseevav091975@postgrespro.ru", "phone": "+70863142693"}
0005435097300	1131EF	5025 137423	SERGEY ROMANOV	{"email": "s_romanov-061972@postgrespro.ru", "phone": "+70949459584"}
0005435097301	ADBB4E	3263 337607	ALEKSEY NAUMOV	{"email": "aleksey_naumov1963@postgrespro.ru", "phone": "+70585952041"}
0005435097302	44A7B0	2515 147199	MIKHAIL ZHUKOV	{"email": "zhukov_m1975@postgrespro.ru", "phone": "+70489578182"}
0005435097303	BD9028	3772 588519	LYUBOV GAVRILOVA	{"email": "l-gavrilova.22061973@postgrespro.ru", "phone": "+70431578030"}
0005435097304	BD9028	9262 828133	VITALIY KOZLOV	{"phone": "+70904813598"}
0005435097305	C06C45	5018 586566	VIKTOR SOROKIN	{"phone": "+70482820858"}
0005435097306	A831FC	2299 398816	ILYA FEDOROV	{"email": "ilya_fedorov.28111972@postgrespro.ru", "phone": "+70452875790"}
0005435097307	C36205	0455 446256	GALINA NAZAROVA	{"email": "nazarovag_31051967@postgrespro.ru", "phone": "+70936082218"}
0005435097308	C36205	6093 292357	IGOR KISELEV	{"email": "i_kiselev_21041969@postgrespro.ru", "phone": "+70255481104"}
0005435097309	ACD337	3435 319428	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev_021959@postgrespro.ru", "phone": "+70278841271"}
0005435097310	B840E1	1861 914126	ROMAN SERGEEV	{"email": "romansergeev-021969@postgrespro.ru", "phone": "+70963121193"}
0005435097311	B840E1	9114 510333	MARIYA KOZLOVA	{"email": "kozlova-m.23111972@postgrespro.ru", "phone": "+70898863502"}
0005435097312	6035F5	4508 138139	VLADIMIR ALEKSEEV	{"phone": "+70959855363"}
0005435097313	B4C4E6	1768 567234	EKATERINA CHERNOVA	{"email": "chernova.e.1972@postgrespro.ru", "phone": "+70777381679"}
0005435097314	B4C4E6	9827 203942	EKATERINA NESTEROVA	{"email": "e-nesterova031976@postgrespro.ru", "phone": "+70661297484"}
0005435097315	6F4ADD	4033 275309	IVAN ZAKHAROV	{"phone": "+70635907504"}
0005435097316	E713F2	9343 788721	BORIS NAZAROV	{"email": "b-nazarov.041967@postgrespro.ru", "phone": "+70601928145"}
0005435097317	E713F2	5518 121248	ANGELINA POPOVA	{"email": "angelina_popova1968@postgrespro.ru", "phone": "+70539119599"}
0005435097318	F51AC5	1302 227896	ANDREY ANTONOV	{"phone": "+70853332006"}
0005435097319	6D4AFB	2310 415745	VIKTOR KULIKOV	{"phone": "+70860492697"}
0005435097320	B0BF09	1943 406711	VLADIMIR SOKOLOV	{"phone": "+70370382140"}
0005435097321	B0BF09	1551 414796	EVGENIY ZAKHAROV	{"email": "zakharov-evgeniy.23021973@postgrespro.ru", "phone": "+70283794474"}
0005435097322	E674A8	5616 501247	ANASTASIYA GAVRILOVA	{"email": "anastasiya-gavrilova-23091972@postgrespro.ru", "phone": "+70559471149"}
0005435097323	04A8B8	9872 487182	VADIM NIKITIN	{"email": "nikitin_vadim091979@postgrespro.ru", "phone": "+70334121986"}
0005435097324	04A8B8	9627 399138	MAKSIM MARTYNOV	{"phone": "+70839200553"}
0005435097325	A533F4	7830 087764	YULIYA BORISOVA	{"email": "borisovayuliya.1980@postgrespro.ru", "phone": "+70576370295"}
0005435097326	49519A	0327 618436	IRINA KAZAKOVA	{"phone": "+70096273976"}
0005435097327	49519A	0470 013344	OLEG BORISOV	{"email": "borisov.oleg_1964@postgrespro.ru", "phone": "+70306294549"}
0005435097328	989E44	2773 955836	DMITRIY FROLOV	{"phone": "+70531054391"}
0005435097329	EDFA55	7598 457294	KRISTINA KUZMINA	{"phone": "+70447715186"}
0005435097330	EDFA55	0061 609871	ELENA MAKSIMOVA	{"email": "elenamaksimova-011964@postgrespro.ru", "phone": "+70985184745"}
0005435097331	434274	5736 157848	VITALIY ZAYCEV	{"email": "vitaliy.zaycev25021966@postgrespro.ru", "phone": "+70020355401"}
0005435097332	B860AC	9015 759742	RAISA VOROBEVA	{"phone": "+70751894632"}
0005435097333	B860AC	0318 817808	MIKHAIL PAVLOV	{"phone": "+70291788942"}
0005435097334	03EC2D	1218 214342	ALEKSANDR SAVELEV	{"email": "a-savelev1964@postgrespro.ru", "phone": "+70720209562"}
0005435097335	03EC2D	2615 828353	PETR ZAKHAROV	{"email": "pzakharov-1961@postgrespro.ru", "phone": "+70029546755"}
0005435097336	03EC2D	9855 488380	ALINA KUZNECOVA	{"email": "alina-kuznecova.07061968@postgrespro.ru", "phone": "+70368581555"}
0005435097337	7BF965	3592 724043	ALEKSEY OSIPOV	{"phone": "+70467405760"}
0005435097338	7BF965	8099 529078	IRINA SEMENOVA	{"email": "i-semenova.1966@postgrespro.ru", "phone": "+70351272033"}
0005435097339	A746EE	7395 155469	OLGA DAVYDOVA	{"email": "o-davydova.081974@postgrespro.ru", "phone": "+70510305844"}
0005435097340	DC7952	9076 123569	YURIY KOZLOV	{"email": "yuriy_kozlov_1968@postgrespro.ru", "phone": "+70318430197"}
0005435097341	7E1A90	3726 962865	SERGEY TIKHONOV	{"phone": "+70223667479"}
0005435097342	F8F580	7197 988659	MARIYA ALEKSEEVA	{"phone": "+70486661792"}
0005435097343	4A3394	3239 635433	ANATOLIY YAKOVLEV	{"email": "ayakovlev_1963@postgrespro.ru", "phone": "+70365768266"}
0005435097344	4A3394	7895 622900	RAFIK MATVEEV	{"email": "matveevr091985@postgrespro.ru", "phone": "+70011635179"}
0005435097345	8313DD	6070 692749	LYUBOV IVANOVA	{"phone": "+70826865231"}
0005435097346	CDED1E	7859 236678	ELINA FROLOVA	{"phone": "+70335297440"}
0005435097347	CDED1E	2148 996635	VLADIMIR MAKAROV	{"phone": "+70362119005"}
0005435097348	CDED1E	8287 650991	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova.a-011980@postgrespro.ru", "phone": "+70980028225"}
0005435097349	BB13D4	9432 084039	BORIS ANDREEV	{"phone": "+70083134232"}
0005435097350	BB13D4	2741 946580	TATYANA ILINA	{"phone": "+70299563478"}
0005435097351	09522B	9680 559482	TATYANA SOLOVEVA	{"email": "tatyana.soloveva-041972@postgrespro.ru", "phone": "+70458186305"}
0005435097352	09522B	7656 474178	VLADIMIR MELNIKOV	{"phone": "+70512458972"}
0005435097353	7F4B44	3411 507788	ALEKSEY ZHUKOV	{"email": "zhukov_a-05011970@postgrespro.ru", "phone": "+70390537104"}
0005435097354	9E5435	9040 968983	OLGA SMIRNOVA	{"phone": "+70403630973"}
0005435097355	9E5435	2885 590818	KRISTINA KUZNECOVA	{"email": "k-kuznecova_091978@postgrespro.ru", "phone": "+70928519916"}
0005435097356	19F050	4801 382895	NINA VASILEVA	{"email": "vasilevanina.1976@postgrespro.ru", "phone": "+70988365973"}
0005435097357	15D956	4971 492932	IRINA MIKHAYLOVA	{"email": "mikhaylova.i_1981@postgrespro.ru", "phone": "+70205743198"}
0005435097358	B04226	5248 259659	LYUDMILA ORLOVA	{"phone": "+70472706011"}
0005435097359	7F3EA2	4639 796655	ANTON KONOVALOV	{"email": "a.konovalov.051971@postgrespro.ru", "phone": "+70228069169"}
0005435097360	8C74A6	2316 951446	VASILIY ANTONOV	{"email": "antonov_vasiliy.11101988@postgrespro.ru", "phone": "+70869980488"}
0005435097361	859E60	6790 422944	VLADIMIR MAKAROV	{"phone": "+70959728629"}
0005435097362	8D0A85	6090 108639	OLGA FOMINA	{"phone": "+70696020565"}
0005435097363	4D3A2C	9237 522482	ZINAIDA VASILEVA	{"phone": "+70839977807"}
0005435097364	1E91F6	6038 663639	VIKTOR MATVEEV	{"phone": "+70891852767"}
0005435097365	0D6B1C	0114 305551	OLGA PETROVA	{"email": "olga_petrova.1968@postgrespro.ru", "phone": "+70844482226"}
0005435097366	80009C	2855 485861	YULIYA VOLKOVA	{"phone": "+70303122018"}
0005435097367	D1F5FA	2818 504094	DMITRIY KARPOV	{"phone": "+70261420180"}
0005435097368	D1F5FA	7693 932799	YURIY NOVIKOV	{"email": "novikovy-09081979@postgrespro.ru", "phone": "+70377071676"}
0005435097369	C5178B	2516 475819	LEONID IVANOV	{"email": "l-ivanov.041962@postgrespro.ru", "phone": "+70972312879"}
0005435097370	C5178B	8642 792919	SERGEY KUZNECOV	{"phone": "+70777612132"}
0005435097371	D5895D	8169 253726	EVGENIY KUZNECOV	{"phone": "+70549873289"}
0005435097372	536CCE	1070 994461	VIKTOR MELNIKOV	{"email": "viktor_melnikov1965@postgrespro.ru", "phone": "+70521623138"}
0005435097373	536CCE	1967 442933	TATYANA SERGEEVA	{"phone": "+70526736271"}
0005435097374	19688A	0848 400988	ALEKSANDRA YUDINA	{"email": "yudinaa_1966@postgrespro.ru", "phone": "+70695686095"}
0005435097375	19688A	2927 780953	NIKOLAY SAVELEV	{"phone": "+70375471205"}
0005435097376	839766	0061 879119	ALENA SMIRNOVA	{"email": "smirnovaalena-1972@postgrespro.ru", "phone": "+70403332042"}
0005435097377	839766	3174 577679	VIKTOR MIRONOV	{"email": "mironov_v1984@postgrespro.ru", "phone": "+70820431237"}
0005435097378	839766	2360 786803	TATYANA PETROVA	{"email": "tpetrova24051968@postgrespro.ru", "phone": "+70783531852"}
0005435097379	B8572B	7899 354906	ALEKSEY NIKOLAEV	{"email": "nikolaev-a-091965@postgrespro.ru", "phone": "+70035153173"}
0005435097380	7256CB	2151 858536	ANDREY DAVYDOV	{"email": "davydov-a-091968@postgrespro.ru", "phone": "+70043876191"}
0005435097381	7256CB	1221 995006	ANTON KONOVALOV	{"email": "konovalov_anton-10111968@postgrespro.ru", "phone": "+70956571867"}
0005435097382	B3B89B	4729 756870	RAISA FADEEVA	{"phone": "+70542446886"}
0005435097383	68962E	9075 666358	ALEKSEY KUZNECOV	{"phone": "+70009774763"}
0005435097384	68962E	8175 178828	IVAN ROMANOV	{"phone": "+70709563040"}
0005435097385	68962E	3572 196436	NIKOLAY SOROKIN	{"phone": "+70477699873"}
0005435097386	2C35C1	1604 206912	VENIAMIN GUSEV	{"phone": "+70531058914"}
0005435097387	612B5F	8264 865366	ELENA VASILEVA	{"email": "vasileva-elena-20051982@postgrespro.ru", "phone": "+70045797392"}
0005435097388	612B5F	0496 588138	IRINA VASILEVA	{"phone": "+70950232458"}
0005435097389	2C471F	7860 736109	EKATERINA ABRAMOVA	{"email": "e.abramova051979@postgrespro.ru", "phone": "+70267369602"}
0005435097390	617781	7191 828802	VADIM KUZMIN	{"phone": "+70770800311"}
0005435097391	E7F327	3726 908351	ALEKSANDR FROLOV	{"phone": "+70121983688"}
0005435097392	E7F327	8627 293132	LYUBOV FILATOVA	{"phone": "+70068030667"}
0005435097393	429A8B	8043 571283	DMITRIY IVANOV	{"email": "dmitriyivanov-041971@postgrespro.ru", "phone": "+70903169370"}
0005435097394	429A8B	2481 245490	ALEKSANDR PETROV	{"email": "petrov_a_1966@postgrespro.ru", "phone": "+70120052687"}
0005435097395	1470EA	3003 409982	ELENA SAVELEVA	{"email": "elenasaveleva.1975@postgrespro.ru", "phone": "+70040169524"}
0005435097396	CB7CDE	6158 281559	DENIS SERGEEV	{"phone": "+70173270601"}
0005435097397	332545	8243 142134	TATYANA PETROVA	{"phone": "+70794134613"}
0005435097398	7A925C	1921 054850	SERGEY FILIPPOV	{"email": "sergey.filippov021970@postgrespro.ru", "phone": "+70761614311"}
0005435097399	7A925C	3977 571550	MARIYA FILIPPOVA	{"phone": "+70678351634"}
0005435097400	C8B8DB	1246 552880	VASILIY VOROBEV	{"email": "vorobev_v-05031975@postgrespro.ru", "phone": "+70211419543"}
0005435097401	A34F40	3709 147340	SERGEY GUSEV	{"email": "sergey-gusev_1968@postgrespro.ru", "phone": "+70767014606"}
0005435097402	A34F40	4534 148663	VIKTOR KULIKOV	{"phone": "+70027400015"}
0005435097403	376B80	1160 448742	MARINA GAVRILOVA	{"phone": "+70785883913"}
0005435097404	F211F3	1824 500544	VALENTINA KOROLEVA	{"phone": "+70385941684"}
0005435097405	5CFF47	5090 627612	MAKSIM SEMENOV	{"email": "semenov-m-18101972@postgrespro.ru", "phone": "+70173840990"}
0005435097406	5CFF47	2849 418157	ANATOLIY KARPOV	{"email": "akarpov-121976@postgrespro.ru", "phone": "+70307943046"}
0005435097407	1F4AED	6277 648272	OLGA FEDOROVA	{"email": "o-fedorova.1971@postgrespro.ru", "phone": "+70686333288"}
0005435097408	3A1A54	3734 839838	NADEZHDA CHERNOVA	{"email": "chernova_nadezhda.1975@postgrespro.ru", "phone": "+70680957628"}
0005435097409	0CF639	0196 930004	ARTEM TARASOV	{"email": "tarasov_a041990@postgrespro.ru", "phone": "+70309224147"}
0005435097410	A0C4CB	2929 802063	ALEKSANDR SAVELEV	{"email": "savelev_a1971@postgrespro.ru", "phone": "+70426596304"}
0005435097411	D64CC9	8068 675067	GALINA MAKAROVA	{"phone": "+70659309369"}
0005435097412	515608	5037 303074	SERGEY NIKOLAEV	{"email": "s_nikolaev111978@postgrespro.ru", "phone": "+70447234714"}
0005435097413	11954E	4045 998777	ZINAIDA ANDREEVA	{"email": "zinaida-andreeva_24041978@postgrespro.ru", "phone": "+70721335949"}
0005435097414	11954E	0790 755317	TAMARA KOROLEVA	{"phone": "+70257275799"}
0005435097415	513126	1509 424801	VERA IVANOVA	{"phone": "+70663115559"}
0005435097416	1B1E59	0428 772228	VERA ROMANOVA	{"email": "vromanova.051969@postgrespro.ru", "phone": "+70525796168"}
0005435097417	1B1E59	1586 521565	ANASTASIYA EFREMOVA	{"email": "anastasiya-efremova-04061982@postgrespro.ru", "phone": "+70097079862"}
0005435097418	70A5CF	1040 413313	VIKTOR ZAYCEV	{"email": "zaycev.v-071980@postgrespro.ru", "phone": "+70370273918"}
0005435097419	EAEC7A	7139 491956	DMITRIY MIRONOV	{"email": "d-mironov-26041973@postgrespro.ru", "phone": "+70700657633"}
0005435097420	505DAB	1854 636128	IVAN STEPANOV	{"email": "stepanov_ivan_111979@postgrespro.ru", "phone": "+70308254920"}
0005435097421	505DAB	2252 610392	DMITRIY KOROLEV	{"email": "korolev_d-29101975@postgrespro.ru", "phone": "+70893261707"}
0005435097422	F7D6DC	1169 732409	VLADIMIR GORBUNOV	{"phone": "+70540936013"}
0005435097423	9EE977	9589 901928	RUSLAN YAKOVLEV	{"email": "ruslan-yakovlev_01041970@postgrespro.ru", "phone": "+70367848925"}
0005435097424	A4094D	5685 759095	LYUBOV ROMANOVA	{"phone": "+70866211353"}
0005435097425	EF9066	3876 905897	TATYANA NIKIFOROVA	{"phone": "+70226683294"}
0005435097426	98B2E1	9747 711092	VLADIMIR MATVEEV	{"phone": "+70978871091"}
0005435097427	7F4F08	2305 615302	MARIYA ALEKSEEVA	{"phone": "+70044480555"}
0005435097428	7F4F08	1204 939374	KIRILL NAZAROV	{"email": "kirill_nazarov_011970@postgrespro.ru", "phone": "+70553648154"}
0005435097429	012902	4240 990961	SVETLANA GRISHINA	{"phone": "+70630798876"}
0005435097430	79E7E7	1282 834106	ALEKSANDRA SERGEEVA	{"phone": "+70329003748"}
0005435097431	E2B771	0743 216828	SVETLANA AFANASEVA	{"email": "afanaseva_s_101966@postgrespro.ru", "phone": "+70676050330"}
0005435097432	E59491	6614 494162	VALENTIN FEDOROV	{"email": "valentin_fedorov-1966@postgrespro.ru", "phone": "+70381450521"}
0005435097433	C12FAA	3290 434498	VALENTINA FROLOVA	{"phone": "+70364180661"}
0005435097434	AC9C22	6565 923013	ALEKSANDR FEDOTOV	{"phone": "+70206213570"}
0005435097435	065425	6126 596541	ALEKSANDR EGOROV	{"email": "egorov_aleksandr-06091977@postgrespro.ru", "phone": "+70282562012"}
0005435097436	0ED676	1181 314874	NATALYA BELYAEVA	{"email": "natalya.belyaeva_111972@postgrespro.ru", "phone": "+70741820214"}
0005435097437	78E1B2	2317 975656	LYUDMILA FEDOROVA	{"email": "fedorova.l-25101969@postgrespro.ru", "phone": "+70271598464"}
0005435097438	F31C15	0253 216992	YURIY MOROZOV	{"email": "morozov-y_031983@postgrespro.ru", "phone": "+70105848739"}
0005435097439	BC7C14	4512 639427	DMITRIY GORBUNOV	{"email": "gorbunovd_18051980@postgrespro.ru", "phone": "+70409012646"}
0005435097440	C8E003	9557 745057	LYUBOV MOROZOVA	{"phone": "+70013805215"}
0005435097441	56A1E8	5144 400073	NIKOLAY ZHUKOV	{"phone": "+70499592843"}
0005435097442	5AEA61	5701 841402	TATYANA PAVLOVA	{"phone": "+70876428331"}
0005435097443	5AEA61	0381 952163	ALEKSANDR MAKSIMOV	{"email": "maksimov_aleksandr-1978@postgrespro.ru", "phone": "+70029023577"}
0005435097444	5AEA61	3586 196962	VLADIMIR ALEKSANDROV	{"phone": "+70919218795"}
0005435097445	5AEA61	1879 461996	VLADIMIR POPOV	{"email": "popov-v_27091976@postgrespro.ru", "phone": "+70819882496"}
0005435097446	E75B11	6919 359775	NATALYA KOMAROVA	{"phone": "+70850496592"}
0005435097447	38365E	5419 160460	KIRILL MELNIKOV	{"email": "k-melnikov.1964@postgrespro.ru", "phone": "+70623424692"}
0005435097448	D2C6E6	4710 677391	SERGEY STEPANOV	{"phone": "+70365327204"}
0005435097449	D2C6E6	1672 935688	ELIZAVETA MAKAROVA	{"email": "makarova_elizaveta_051967@postgrespro.ru", "phone": "+70199470324"}
0005435097450	5B907B	4017 073346	NIKOLAY GUSEV	{"phone": "+70147017621"}
0005435097451	5F569E	6492 825154	ANNA POTAPOVA	{"phone": "+70449975256"}
0005435097452	5F569E	5212 618945	SVETLANA KUZNECOVA	{"phone": "+70193479533"}
0005435097453	C1BD72	5210 841317	TATYANA NIKOLAEVA	{"phone": "+70430969193"}
0005435097454	C1BD72	4954 570904	VALENTINA STEPANOVA	{"email": "stepanovavalentina071977@postgrespro.ru", "phone": "+70393721018"}
0005435097455	2EF80E	1916 487971	VIKTOR VOROBEV	{"phone": "+70666631193"}
0005435097456	8BAE20	3388 232819	MIKHAIL BONDARENKO	{"email": "bondarenko.mikhail1974@postgrespro.ru", "phone": "+70830667250"}
0005435097457	8BAE20	1774 731437	NATALYA NIKITINA	{"email": "nikitinanatalya_1977@postgrespro.ru", "phone": "+70492837857"}
0005435097458	7C0B01	9125 583392	VLADIMIR POPOV	{"email": "popov_vladimir-09041983@postgrespro.ru", "phone": "+70955268505"}
0005435097459	48F62F	1554 694541	POLINA GORBUNOVA	{"email": "polina_gorbunova_08101960@postgrespro.ru", "phone": "+70743221853"}
0005435097460	48F62F	3819 032460	VITALIY IVANOV	{"email": "ivanov-v_24051975@postgrespro.ru", "phone": "+70249133599"}
0005435097461	20F2E8	8766 663032	VALENTINA MAKAROVA	{"phone": "+70703264133"}
0005435097462	100A16	4991 874617	DENIS MIKHAYLOV	{"email": "mikhaylov-denis-1972@postgrespro.ru", "phone": "+70494954220"}
0005435097463	100A16	0081 373059	IGOR GRIGOREV	{"phone": "+70969299701"}
0005435097464	81560C	0993 001534	VLADIMIR ANDREEV	{"email": "vladimir-andreev_1977@postgrespro.ru", "phone": "+70473559041"}
0005435097465	81560C	3047 140411	OLGA ROMANOVA	{"phone": "+70512795749"}
0005435097466	81560C	5497 202819	EVGENIY MELNIKOV	{"email": "evgeniy_melnikov.091965@postgrespro.ru", "phone": "+70204355350"}
0005435097467	1DA5C0	6192 604957	ALEKSANDRA SCHERBAKOVA	{"phone": "+70548958316"}
0005435097468	1DA5C0	3597 179530	GALINA ALEKSANDROVA	{"phone": "+70641477227"}
0005435097469	B564C7	2633 890292	YULIYA ZAYCEVA	{"phone": "+70336721811"}
0005435097470	B564C7	3156 377893	GENNADIY NAUMOV	{"phone": "+70259830124"}
0005435097471	0657D7	8945 214266	SERGEY SEMENOV	{"email": "sergeysemenov.1975@postgrespro.ru", "phone": "+70832381833"}
0005435097472	0657D7	7114 476994	POLINA MIRONOVA	{"email": "p_mironova.061969@postgrespro.ru", "phone": "+70467985750"}
0005435097473	0657D7	4892 456551	ARTUR GAVRILOV	{"email": "arturgavrilov31011967@postgrespro.ru", "phone": "+70568990666"}
0005435097474	DB0598	3745 174212	RASHID ROMANOV	{"email": "romanov_r-16101974@postgrespro.ru", "phone": "+70464929372"}
0005435097475	DB0598	9098 727909	PAVEL NAUMOV	{"email": "p_naumov13021969@postgrespro.ru", "phone": "+70238395126"}
0005435097476	FAD5CA	2606 250853	EKATERINA EGOROVA	{"email": "ekaterinaegorova05081969@postgrespro.ru", "phone": "+70384566014"}
0005435097477	077BF5	0160 838022	NATALYA IVANOVA	{"phone": "+70791148009"}
0005435097478	25166E	4884 440203	GALINA TROFIMOVA	{"phone": "+70618220471"}
0005435097479	8E3449	8451 985882	VYACHESLAV MAKAROV	{"email": "makarovv07091964@postgrespro.ru", "phone": "+70901260600"}
0005435097480	5D212C	3546 043655	OLESYA MOROZOVA	{"phone": "+70042702721"}
0005435097481	082B85	1326 507399	ALEFTINA ZAKHAROVA	{"phone": "+70648548071"}
0005435097482	D313B8	7952 717094	MIKHAIL MARTYNOV	{"email": "martynovmikhail_091963@postgrespro.ru", "phone": "+70724428346"}
0005435097483	DEA094	3197 845717	EVGENIY KUZNECOV	{"phone": "+70368577627"}
0005435097484	DEA094	9999 363644	VIKTOR NOVIKOV	{"phone": "+70342379264"}
0005435097485	DEA094	2331 221012	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov-051970@postgrespro.ru", "phone": "+70420952213"}
0005435097486	55E596	2519 245269	VALENTINA SMIRNOVA	{"phone": "+70697533726"}
0005435097487	83F65C	4017 448775	NINA ROMANOVA	{"email": "romanova_nina25061991@postgrespro.ru", "phone": "+70621275093"}
0005435097488	83F65C	6863 275088	DENIS BORISOV	{"email": "d.borisov.1960@postgrespro.ru", "phone": "+70865318099"}
0005435097489	50C914	7634 553572	MARIYA FEDOROVA	{"phone": "+70152316958"}
0005435097490	2F3810	8203 651161	ALLA ORLOVA	{"phone": "+70039302084"}
0005435097491	F01548	7648 056793	VLADISLAV EGOROV	{"phone": "+70016158665"}
0005435097492	F01548	1524 722140	KIRILL NIKITIN	{"phone": "+70048969982"}
0005435097493	858271	7754 432788	EKATERINA FILATOVA	{"phone": "+70243178552"}
0005435097494	FAD7CF	2245 902882	DANILA ISAEV	{"email": "danila_isaev1979@postgrespro.ru", "phone": "+70598485111"}
0005435097495	FAD7CF	0842 959486	MAYYA IVANOVA	{"phone": "+70642330752"}
0005435097496	9228B6	7896 827039	TATYANA FEDOROVA	{"phone": "+70852759515"}
0005435097497	9228B6	7214 318807	KSENIYA AFANASEVA	{"phone": "+70036078013"}
0005435097498	420A8F	4596 204956	SVETLANA KARPOVA	{"phone": "+70123338442"}
0005435097499	50982D	6733 919617	OKSANA KULIKOVA	{"phone": "+70120906241"}
0005435097500	AB16A8	5998 510405	IRINA MEDVEDEVA	{"email": "irinamedvedeva_1975@postgrespro.ru", "phone": "+70663782554"}
0005435097501	6166F0	9117 768068	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov_061952@postgrespro.ru", "phone": "+70374427968"}
0005435097502	6166F0	6055 924597	ALEKSANDR ORLOV	{"phone": "+70295963240"}
0005435097503	BF97FE	8467 571172	TATYANA PETROVA	{"phone": "+70899465890"}
0005435097504	D38262	4052 001112	OLGA DAVYDOVA	{"email": "davydova_o.1980@postgrespro.ru", "phone": "+70523546541"}
0005435097505	CD8421	0339 117648	OLGA KOZLOVA	{"phone": "+70700902509"}
0005435097506	CD8421	9555 286348	ALBINA KRASNOVA	{"phone": "+70935551969"}
0005435097507	653613	8484 397676	ANASTASIYA MASLOVA	{"email": "maslova_a-081969@postgrespro.ru", "phone": "+70692635898"}
0005435097508	8D9CED	5965 743424	NATALYA STEPANOVA	{"email": "n-stepanova1970@postgrespro.ru", "phone": "+70182319244"}
0005435097509	8D9CED	7301 428360	NIKITA MELNIKOV	{"phone": "+70578992660"}
0005435097510	4E64EE	7217 461752	VIKTOR ZHURAVLEV	{"email": "zhuravlev-v.1980@postgrespro.ru", "phone": "+70349771058"}
0005435097511	4E64EE	8155 943072	LYUBOV ANDREEVA	{"email": "lyubovandreeva_1966@postgrespro.ru", "phone": "+70421611140"}
0005435097513	136F5E	3462 319113	VALERIY CHERNOV	{"email": "chernov.valeriy.19031973@postgrespro.ru", "phone": "+70225828552"}
0005435097514	136F5E	6506 925712	NATALIYA ISAEVA	{"email": "nisaeva-24061979@postgrespro.ru", "phone": "+70314212444"}
0005435097515	672B1B	9151 780342	ELENA SOROKINA	{"email": "sorokina-elena-1963@postgrespro.ru", "phone": "+70852432792"}
0005435097516	38EABA	1299 965068	SVETLANA BORISOVA	{"email": "borisova-svetlana-29111958@postgrespro.ru", "phone": "+70310012245"}
0005435097517	38EABA	2360 765739	OLGA FILIPPOVA	{"phone": "+70417636079"}
0005435097518	EFC524	1987 020459	IVAN SOROKIN	{"phone": "+70314617074"}
0005435097519	C875E1	9495 951794	VADIM BARANOV	{"phone": "+70075704484"}
0005435097520	C875E1	8162 195455	ANATOLIY SCHERBAKOV	{"phone": "+70958163328"}
0005435097521	ED1E11	1860 326327	ALEKSANDR VOLKOV	{"email": "volkov_a_031971@postgrespro.ru", "phone": "+70123108226"}
0005435097522	ED1E11	9329 628938	ANNA FROLOVA	{"email": "a.frolova.21051972@postgrespro.ru", "phone": "+70127472615"}
0005435097523	F278C7	6171 679751	NATALYA VLASOVA	{"email": "natalya.vlasova-16041965@postgrespro.ru", "phone": "+70349937117"}
0005435097524	F278C7	0835 363018	FATYMA AKIMOVA	{"email": "fakimova.1965@postgrespro.ru", "phone": "+70771483277"}
0005435097525	A650C2	8712 151288	ZULFIYA FROLOVA	{"email": "frolova.z.1979@postgrespro.ru", "phone": "+70989874240"}
0005435097526	CFD420	9719 399898	LYUBOV ALEKSEEVA	{"phone": "+70284293616"}
0005435097527	A732DF	9872 510576	LYUBOV VASILEVA	{"email": "l_vasileva.081967@postgrespro.ru", "phone": "+70203867059"}
0005435097528	A732DF	7768 814757	KIRILL KUZNECOV	{"phone": "+70673830876"}
0005435097529	7378C2	5596 711800	LYUBOV ANTONOVA	{"email": "lyubov-antonova_1980@postgrespro.ru", "phone": "+70474764567"}
0005435098521	7B0A4E	9488 493509	VLADIMIR ZAYCEV	{"email": "vzaycev.02111965@postgrespro.ru", "phone": "+70326018015"}
0005435098522	AC8747	9497 140755	SVETLANA EGOROVA	{"phone": "+70923166813"}
0005435098523	E74098	1041 390074	TATYANA KOMAROVA	{"email": "komarova.t21031965@postgrespro.ru", "phone": "+70643465773"}
0005435098524	E74098	7848 241812	VLADIMIR SMIRNOV	{"phone": "+70768701873"}
0005435098525	9FC5DA	6622 311396	ANDREY KRASNOV	{"email": "a-krasnov-1979@postgrespro.ru", "phone": "+70258043647"}
0005435098526	9FC5DA	9469 179116	NURIYA IVANOVA	{"email": "nuriya.ivanova.071981@postgrespro.ru", "phone": "+70278991226"}
0005435098527	FA052B	3834 319024	TATYANA ZAYCEVA	{"email": "zaycevatatyana111971@postgrespro.ru", "phone": "+70651937324"}
0005435098528	4691EE	4935 126278	ELENA SOROKINA	{"email": "sorokina.e-1969@postgrespro.ru", "phone": "+70171531214"}
0005435098529	EA9BE9	8698 152158	OLGA NIKITINA	{"phone": "+70764762627"}
0005435098530	10AA0E	1810 735096	SERGEY NIKITIN	{"email": "sergey.nikitin.28071972@postgrespro.ru", "phone": "+70556462584"}
0005435098531	97FD18	8059 153351	PAVEL KARPOV	{"email": "karpov.pavel1989@postgrespro.ru", "phone": "+70967526825"}
0005435098532	DEA6F8	2103 184181	GALINA MELNIKOVA	{"email": "galina.melnikova08031974@postgrespro.ru", "phone": "+70001845439"}
0005435098533	DEA6F8	4506 517975	NIKOLAY MOROZOV	{"email": "morozov.nikolay_08111967@postgrespro.ru", "phone": "+70716341212"}
0005435098534	AB69E4	5848 322408	VALENTINA PAVLOVA	{"email": "valentina.pavlova.091971@postgrespro.ru", "phone": "+70366493638"}
0005435098535	40A555	5748 420659	NIKOLAY NOVIKOV	{"email": "nnovikov.26011965@postgrespro.ru", "phone": "+70424502590"}
0005435098536	7B305D	4852 932841	VERA ZAKHAROVA	{"phone": "+70346604468"}
0005435098537	7B305D	0184 980353	VALENTINA KOROLEVA	{"email": "koroleva.v.081967@postgrespro.ru", "phone": "+70426269944"}
0005435098538	2DADED	9886 704160	STANISLAV KUZMIN	{"phone": "+70865871783"}
0005435098539	2DADED	4850 118649	DMITRIY KOROLEV	{"email": "d-korolev.101990@postgrespro.ru", "phone": "+70791656773"}
0005435098540	FF61D0	3663 219246	PAVEL GUSEV	{"email": "gusevp-24051963@postgrespro.ru", "phone": "+70520458883"}
0005435098541	6EF4F5	2915 213938	NIKOLAY NAZAROV	{"email": "nazarov-n.26121980@postgrespro.ru", "phone": "+70665445294"}
0005435098542	9BF088	2528 390145	PETR MAKSIMOV	{"phone": "+70180676187"}
0005435098543	9BF088	3903 910357	ELENA MOROZOVA	{"email": "morozova_elena091964@postgrespro.ru", "phone": "+70454464396"}
0005435098544	6A4836	1533 513934	ALEKSANDRA IVANOVA	{"email": "aivanova.28101968@postgrespro.ru", "phone": "+70212288962"}
0005435098545	DBF907	7705 366221	VLADIMIR MAKAROV	{"phone": "+70251745859"}
0005435098546	84F1A1	4219 654539	ALEKSEY KOROLEV	{"email": "korolev.aleksey_22101963@postgrespro.ru", "phone": "+70650102829"}
0005435098547	820F4F	6960 196811	IVAN POPOV	{"email": "ipopov_04041971@postgrespro.ru", "phone": "+70332202871"}
0005435098548	820F4F	8247 842895	VERA NIKOLAEVA	{"email": "v_nikolaeva-081972@postgrespro.ru", "phone": "+70429496070"}
0005435098549	5B2F97	9283 026923	YULIYA BORISOVA	{"email": "borisovayuliya11021977@postgrespro.ru", "phone": "+70337136092"}
0005435098550	5B2F97	0184 602769	GRIGORIY KARPOV	{"email": "grigoriy-karpov-18091961@postgrespro.ru", "phone": "+70775033578"}
0005435098551	1CF1FA	5662 371752	SERGEY VASILEV	{"email": "sergey.vasilev1963@postgrespro.ru", "phone": "+70441458654"}
0005435098552	589897	7578 875083	ALEKSANDR KONOVALOV	{"email": "a_konovalov-17091969@postgrespro.ru", "phone": "+70856893633"}
0005435098553	056FC7	3006 426858	LILIYA TIMOFEEVA	{"email": "l-timofeeva_01091976@postgrespro.ru", "phone": "+70865643267"}
0005435098554	056FC7	0923 442323	ANNA KULIKOVA	{"phone": "+70683680487"}
0005435098555	056FC7	8303 280959	OLEG SOKOLOV	{"phone": "+70277147651"}
0005435098556	472EC9	3029 729963	OLEG SEMENOV	{"phone": "+70470454707"}
0005435098557	ECB5CB	2868 891493	RAISA ZAKHAROVA	{"email": "raisazakharova_1975@postgrespro.ru", "phone": "+70642898845"}
0005435098558	85BFB5	4248 896200	LYUDMILA LUKYANOVA	{"phone": "+70329539771"}
0005435098559	85BFB5	2581 384834	EKATERINA AKIMOVA	{"phone": "+70102816104"}
0005435098560	85BFB5	5569 446840	ANATOLIY KUZNECOV	{"phone": "+70442227343"}
0005435098561	7BE5C4	6729 264419	NIKOLAY VOLKOV	{"phone": "+70839762581"}
0005435098562	C60389	7879 696309	OLEG OSIPOV	{"email": "oosipov-1975@postgrespro.ru", "phone": "+70215968660"}
0005435098563	C60389	4135 239614	OLGA ANDREEVA	{"email": "andreevaolga.111961@postgrespro.ru", "phone": "+70525586195"}
0005435098564	FD5A0A	4384 365407	ANZHELIKA ZAKHAROVA	{"phone": "+70572637874"}
0005435098565	FD5A0A	3969 000338	OLEG ALEKSEEV	{"phone": "+70236897802"}
0005435098566	E37F55	1273 568710	MAKSIM MARTYNOV	{"phone": "+70062382293"}
0005435098567	6407A1	9867 541910	MIKHAIL VASILEV	{"email": "m_vasilev1975@postgrespro.ru", "phone": "+70353978950"}
0005435098568	6407A1	4585 927491	RINAT RODIONOV	{"email": "rodionov_r_1979@postgrespro.ru", "phone": "+70125077618"}
0005435098569	6407A1	6119 807806	VIKTOR KISELEV	{"phone": "+70828663115"}
0005435098570	8B1B3C	9232 302277	ANDREY KOZLOV	{"phone": "+70594401269"}
0005435098571	627CBA	3469 984573	EKATERINA KOROLEVA	{"email": "koroleva.e_091972@postgrespro.ru", "phone": "+70879615410"}
0005435098572	DD9008	5318 173785	ANTON SIDOROV	{"email": "anton.sidorov.051965@postgrespro.ru", "phone": "+70296012660"}
0005435098573	F46E95	7053 195089	KRISTINA MOROZOVA	{"email": "k.morozova_06051965@postgrespro.ru", "phone": "+70840136656"}
0005435098574	60E5D6	8684 124499	RAISA ROMANOVA	{"email": "rromanova_1969@postgrespro.ru", "phone": "+70937301636"}
0005435098575	60E5D6	2405 040355	ALEKSANDRA YUDINA	{"email": "aleksandra.yudina.06091963@postgrespro.ru", "phone": "+70049710705"}
0005435098576	959611	9467 031487	MARINA LEBEDEVA	{"email": "lebedeva-marina.1971@postgrespro.ru", "phone": "+70162720241"}
0005435098577	959611	0063 852219	GEORGIY TIMOFEEV	{"phone": "+70611165632"}
0005435098578	8699B4	5453 234283	STANISLAV ZAYCEV	{"phone": "+70761082121"}
0005435098579	1BB5C1	0948 273590	ALEKSEY YAKOVLEV	{"phone": "+70116914588"}
0005435098580	1BB5C1	5105 750065	YAKOV DMITRIEV	{"email": "yakov.dmitriev.09041971@postgrespro.ru", "phone": "+70746416179"}
0005435098581	74E5B6	7662 372182	VALENTINA KISELEVA	{"phone": "+70655252153"}
0005435098582	74E5B6	0837 572956	PAVEL SEMENOV	{"phone": "+70867535101"}
0005435098583	EDBE41	0633 609630	TATYANA MALYSHEVA	{"phone": "+70916558668"}
0005435098584	25D52B	3786 349903	EVGENIY KUDRYASHOV	{"phone": "+70112943887"}
0005435098585	25D52B	7127 316166	DMITRIY SHEVCHENKO	{"phone": "+70537170958"}
0005435098586	CE34E0	3152 097229	SERGEY KOROLEV	{"email": "s.korolev.08041984@postgrespro.ru", "phone": "+70268636230"}
0005435098587	D9940C	6467 276294	IVAN ZHUKOV	{"email": "zhukov-ivan-101969@postgrespro.ru", "phone": "+70555689058"}
0005435098588	195CF5	5535 419145	MAKSIM PETROV	{"phone": "+70733798760"}
0005435098589	6B10F7	7730 374684	OLESYA LEBEDEVA	{"email": "lebedeva.o-20111974@postgrespro.ru", "phone": "+70802250232"}
0005435098590	7A6BF0	2681 405194	ALEKSANDR ALEKSEEV	{"phone": "+70028241216"}
0005435098591	EDA2F9	2233 111089	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov.111965@postgrespro.ru", "phone": "+70892869981"}
0005435098592	EDA2F9	5964 297188	SOFYA ROMANOVA	{"phone": "+70624662959"}
0005435098593	067DDB	9992 176075	ANASTASIYA FROLOVA	{"phone": "+70610889229"}
0005435098594	F424E0	1678 045202	YULIYA ZAKHAROVA	{"phone": "+70118464645"}
0005435098595	F424E0	7458 747853	ANNA ALEKSEEVA	{"email": "anna_alekseeva17021970@postgrespro.ru", "phone": "+70429361637"}
0005435098596	B952F0	9008 962597	RUSLAN SIDOROV	{"phone": "+70113416702"}
0005435098597	B952F0	4691 125950	SVETLANA ILINA	{"email": "ilina-s-1970@postgrespro.ru", "phone": "+70997792492"}
0005435098598	22BB7D	4470 029413	ILYA KISELEV	{"email": "kiselev_ilya.1965@postgrespro.ru", "phone": "+70311881589"}
0005435098599	22BB7D	7196 421059	SVETLANA SOROKINA	{"email": "sorokina_svetlana-1965@postgrespro.ru", "phone": "+70111595864"}
0005435098600	A50A1C	5407 939252	VLADIMIR SMIRNOV	{"phone": "+70834011628"}
0005435098601	28F487	0265 407653	EKATERINA VASILEVA	{"phone": "+70686062702"}
0005435098602	28F487	6356 252195	NATALYA KONOVALOVA	{"email": "konovalovanatalya_1970@postgrespro.ru", "phone": "+70590347052"}
0005435098603	7B5933	1998 755624	KONSTANTIN MOROZOV	{"email": "konstantin_morozov-1979@postgrespro.ru", "phone": "+70882407487"}
0005435098604	7B5933	1092 817450	NATALYA PAVLOVA	{"phone": "+70324026311"}
0005435098605	175537	2062 178829	SERGEY KUDRYASHOV	{"email": "kudryashov-sergey-1974@postgrespro.ru", "phone": "+70420991751"}
0005435098606	175537	6093 809493	ANTON SOROKIN	{"email": "anton_sorokin-1963@postgrespro.ru", "phone": "+70995672854"}
0005435098607	175537	6180 571274	LYUBOV MAKSIMOVA	{"email": "maksimova-l051983@postgrespro.ru", "phone": "+70545686845"}
0005435098608	CCF065	7196 067573	YURIY MEDVEDEV	{"phone": "+70454539328"}
0005435098609	715F87	8029 663242	VALENTINA MAKSIMOVA	{"phone": "+70221669375"}
0005435098610	D449AA	4504 532285	TATYANA PAVLOVA	{"phone": "+70213794470"}
0005435098611	D449AA	0162 356441	ANDREY KUZNECOV	{"phone": "+70093101901"}
0005435098612	50D0F1	3832 665468	TATYANA LEBEDEVA	{"phone": "+70861748190"}
0005435098613	83CAEC	1854 458843	LILIYA DENISOVA	{"email": "l.denisova-011975@postgrespro.ru", "phone": "+70866149498"}
0005435098614	AA66C9	7280 056648	VASILIY TIKHONOV	{"phone": "+70394482331"}
0005435098615	AA66C9	4526 815506	RAISA FADEEVA	{"phone": "+70387888504"}
0005435098616	DC5066	0979 018308	SOFYA DMITRIEVA	{"email": "s-dmitrieva24011974@postgrespro.ru", "phone": "+70916717691"}
0005435098617	35C52E	7933 106215	TAISIYA TIKHONOVA	{"phone": "+70311720099"}
0005435100069	1B8718	3469 987903	INNA TARASOVA	{"email": "i_tarasova1979@postgrespro.ru", "phone": "+70276427225"}
0005435100070	1B8718	4372 040322	VALENTINA KUZNECOVA	{"email": "kuznecova_v04081961@postgrespro.ru", "phone": "+70424243994"}
0005435100071	FE0462	8365 883036	OLEG VASILEV	{"phone": "+70356911253"}
0005435100072	7F72B9	6545 905224	ALEKSEY POPOV	{"phone": "+70969609432"}
0005435100073	7F72B9	0709 504239	TATYANA RODIONOVA	{"phone": "+70705596389"}
0005435100074	1F1392	3784 332138	IVAN KUZMIN	{"email": "ivan-kuzmin_17111981@postgrespro.ru", "phone": "+70497810032"}
0005435100075	5071F7	6990 072599	MARINA KOROLEVA	{"email": "koroleva-marina.11101970@postgrespro.ru", "phone": "+70644157031"}
0005435100076	18881D	9237 690576	NIKOLAY SHEVCHENKO	{"phone": "+70311431043"}
0005435100077	14211A	2470 595827	LYUBOV KOZLOVA	{"phone": "+70330368201"}
0005435100078	6254BE	0912 092365	VYACHESLAV KULIKOV	{"phone": "+70162486540"}
0005435100079	D98574	8834 053587	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev.15101978@postgrespro.ru", "phone": "+70123097901"}
0005435100080	E6ABE8	2621 886584	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_121956@postgrespro.ru", "phone": "+70571956949"}
0005435100081	C7BC74	9468 658463	TAMARA MAKAROVA	{"email": "makarova.t_30051976@postgrespro.ru", "phone": "+70651657298"}
0005435100082	C7BC74	2190 658246	TATYANA KONDRATEVA	{"phone": "+70395627893"}
0005435100083	3AE6E0	7089 126132	NURIYA KUZNECOVA	{"email": "n-kuznecova_1978@postgrespro.ru", "phone": "+70775668156"}
0005435100084	3AE6E0	3385 931651	NINA FROLOVA	{"phone": "+70491205852"}
0005435100085	4AA596	1550 549963	ANDREY IVANOV	{"email": "ivanov-a.051966@postgrespro.ru", "phone": "+70121568198"}
0005435100086	85128D	6137 819484	NIKOLAY MEDVEDEV	{"phone": "+70090952692"}
0005435100087	C78B26	1009 835732	SERGEY SIDOROV	{"email": "sergey.sidorov_1976@postgrespro.ru", "phone": "+70845183738"}
0005435100088	C78B26	3980 273078	ALEKSANDR KOZLOV	{"phone": "+70312109865"}
0005435100089	9C80D0	3485 099439	ANTON SAVELEV	{"email": "savelev_anton17051974@postgrespro.ru", "phone": "+70578978163"}
0005435100090	BF564D	7961 038249	VLADIMIR MIKHAYLOV	{"email": "vmikhaylov23091964@postgrespro.ru", "phone": "+70640801460"}
0005435100091	83D433	3011 653191	VASILIY KAZAKOV	{"email": "kazakov_v-121975@postgrespro.ru", "phone": "+70391318207"}
0005435100092	83D433	5281 929877	OLGA MIRONOVA	{"email": "mironova_o-1969@postgrespro.ru", "phone": "+70576426320"}
0005435100093	67DA22	5620 065366	DMITRIY POPOV	{"email": "d.popov.101969@postgrespro.ru", "phone": "+70969114214"}
0005435100094	67DA22	5910 847492	ALEKSEY BORISOV	{"email": "borisov.a1967@postgrespro.ru", "phone": "+70512565376"}
0005435100095	C2D237	6759 630673	NIKOLAY NIKITIN	{"email": "nikitin.nikolay.1970@postgrespro.ru", "phone": "+70632278903"}
0005435100096	CAA8A9	6820 414733	VLADA GORBUNOVA	{"email": "vlada-gorbunova-1970@postgrespro.ru", "phone": "+70825307663"}
0005435100097	66C9D6	9456 407207	EVDOKIYA KUZMINA	{"phone": "+70736979108"}
0005435100098	66C9D6	6326 058972	ANATOLIY KUZNECOV	{"email": "a.kuznecov-10051972@postgrespro.ru", "phone": "+70895426413"}
0005435100099	59CCBC	8026 804965	LYUDMILA ZOTOVA	{"phone": "+70852832734"}
0005435100100	1B868C	0416 735671	TATYANA ANTONOVA	{"email": "t_antonova.20041977@postgrespro.ru", "phone": "+70108462650"}
0005435100101	1B868C	8881 560211	VENERA ZAKHAROVA	{"email": "vzakharova-1966@postgrespro.ru", "phone": "+70414740352"}
0005435100102	1BF683	0059 628123	SERGEY ABRAMOV	{"phone": "+70728611509"}
0005435100103	D77EFE	5438 143973	MARINA ANTONOVA	{"phone": "+70296626736"}
0005435100104	8397F3	3531 747432	SOFIYA KOROLEVA	{"email": "koroleva-s-121987@postgrespro.ru", "phone": "+70822855622"}
0005435100105	8397F3	9303 892342	VLADIMIR MIKHAYLOV	{"phone": "+70398909105"}
0005435100106	1A74C0	4980 387877	IRINA FILIPPOVA	{"phone": "+70363157949"}
0005435100107	1A74C0	5799 694128	NIKITA KUZNECOV	{"email": "n_kuznecov1971@postgrespro.ru", "phone": "+70267250793"}
0005435100108	7998C0	6215 135444	SERGEY FOMIN	{"email": "s-fomin.21051971@postgrespro.ru", "phone": "+70804325672"}
0005435100109	7998C0	4245 870724	DANIL ANDREEV	{"phone": "+70356305174"}
0005435100110	CC65A0	9320 937773	ALINA BELYAEVA	{"email": "belyaeva_alina.08051977@postgrespro.ru", "phone": "+70757503718"}
0005435100111	ED3128	1555 263751	ANGELINA ROMANOVA	{"email": "romanova-angelina-27011970@postgrespro.ru", "phone": "+70631696567"}
0005435100112	90FFC7	5987 697219	SERGEY VASILEV	{"phone": "+70766199232"}
0005435100113	90FFC7	4274 960851	OLGA BELOVA	{"phone": "+70750331701"}
0005435100114	DB330E	4731 966527	VIKTOR KOROLEV	{"email": "korolev-viktor.091975@postgrespro.ru", "phone": "+70473487789"}
0005435100115	DFD1D2	6344 696736	NATALYA KOZLOVA	{"phone": "+70169191138"}
0005435100116	A0D7E6	5219 085415	VLADIMIR GAVRILOV	{"email": "vladimir_gavrilov_20041975@postgrespro.ru", "phone": "+70220536456"}
0005435100117	D2E27E	0206 674336	TAMARA VOROBEVA	{"email": "tamara_vorobeva1968@postgrespro.ru", "phone": "+70575262154"}
0005435100118	A702BA	9423 425980	EVGENIY PETROV	{"phone": "+70907774653"}
0005435100119	404F4D	6152 122941	YULIYA ZHUKOVA	{"phone": "+70950519518"}
0005435100120	C94670	2764 742278	EVGENIYA EGOROVA	{"phone": "+70204356925"}
0005435100121	53F4D7	7309 545235	PAVEL KRASNOV	{"email": "krasnovpavel.1975@postgrespro.ru", "phone": "+70682205602"}
0005435100122	42B74E	7453 113934	EKATERINA FROLOVA	{"phone": "+70743549608"}
0005435100123	51288F	4649 238111	SERGEY SCHERBAKOV	{"email": "s-scherbakov-29071972@postgrespro.ru", "phone": "+70332424476"}
0005435100124	51288F	1776 410007	LYUDMILA ILINA	{"phone": "+70367261733"}
0005435100125	51288F	5895 098288	NIKOLAY ABRAMOV	{"phone": "+70112245415"}
0005435100126	D4B024	5900 581806	VALERIYA STEPANOVA	{"phone": "+70848884653"}
0005435100127	41ED7E	3288 361910	YURIY NIKITIN	{"phone": "+70188539501"}
0005435100128	5BC252	1370 275355	KLAVDIYA PETROVA	{"email": "k.petrova-02081967@postgrespro.ru", "phone": "+70682453651"}
0005435100129	D359A2	9947 057083	BOGDAN KUZNECOV	{"phone": "+70320906625"}
0005435100130	E26EF3	8677 118676	ELENA SOKOLOVA	{"email": "e.sokolova.23011975@postgrespro.ru", "phone": "+70704761593"}
0005435100131	469B15	0420 992103	TATYANA STEPANOVA	{"email": "stepanova_tatyana_101958@postgrespro.ru", "phone": "+70054111518"}
0005435100132	143866	3758 595912	GENNADIY KONOVALOV	{"email": "gennadiy_konovalov04061973@postgrespro.ru", "phone": "+70990867717"}
0005435100133	AEAD21	3171 458209	ANDREY ILIN	{"email": "ilin.andrey.111980@postgrespro.ru", "phone": "+70016254295"}
0005435100134	E21035	9304 303823	ALEKSEY VASILEV	{"phone": "+70927212360"}
0005435100135	15832F	0130 996311	ANDREY NIKOLAEV	{"phone": "+70394986784"}
0005435100136	A1D83D	4616 950679	NIKOLAY MELNIKOV	{"phone": "+70332895938"}
0005435100137	A1D83D	6093 697442	ARTEM PETROV	{"email": "a.petrov_09071971@postgrespro.ru", "phone": "+70761748825"}
0005435100138	840B0E	0872 365276	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_aleksey-1983@postgrespro.ru", "phone": "+70650580242"}
0005435100139	840B0E	0133 306155	VITALIY VASILEV	{"phone": "+70699914788"}
0005435100140	66E015	0021 836841	NINA POPOVA	{"phone": "+70261618800"}
0005435100141	9690B8	7375 205349	NIKOLAY VOLKOV	{"phone": "+70556557869"}
0005435100142	CEF8E9	0169 861971	ZINAIDA KUZMINA	{"phone": "+70171809733"}
0005435100143	CEF8E9	1438 171685	ELIZAVETA MATVEEVA	{"phone": "+70281716184"}
0005435100144	CEF8E9	4204 880248	EKATERINA ANDREEVA	{"phone": "+70140557035"}
0005435100145	1C1995	5579 002841	LYUDMILA KONOVALOVA	{"phone": "+70987321239"}
0005435100146	52BBD2	5935 090784	MAKSIM YAKOVLEV	{"email": "maksim.yakovlev_21121973@postgrespro.ru", "phone": "+70946487184"}
0005435100147	52BBD2	4990 819476	VALERIYA VLASOVA	{"email": "valeriya_vlasova.22111975@postgrespro.ru", "phone": "+70544946183"}
0005435100148	5677FC	0576 493077	EKATERINA IVANOVA	{"phone": "+70670760810"}
0005435100149	95C033	8423 733490	MARIYA ORLOVA	{"email": "mariya_orlova_1964@postgrespro.ru", "phone": "+70238878218"}
0005435103910	2CC83A	8707 406876	VLADIMIR MAKSIMOV	{"phone": "+70980850685"}
0005435100150	2AE1CE	8186 939728	MAKSIM FILIPPOV	{"email": "m.filippov_1975@postgrespro.ru", "phone": "+70973858624"}
0005435100151	786E84	6010 858001	EKATERINA KUZNECOVA	{"phone": "+70078784844"}
0005435100152	145D28	4982 296468	RAISA NIKITINA	{"phone": "+70355860014"}
0005435100153	C568A1	8771 271310	VIKTORIYA EFIMOVA	{"email": "viktoriya_efimova_28101977@postgrespro.ru", "phone": "+70172153587"}
0005435100154	846335	3690 605690	ALEKSANDR ISAEV	{"email": "isaev-a11091988@postgrespro.ru", "phone": "+70923523693"}
0005435100155	924D14	0519 142069	OKSANA MOROZOVA	{"email": "morozova.o.1972@postgrespro.ru", "phone": "+70228485280"}
0005435100156	924D14	0648 874485	YULIYA ZOTOVA	{"phone": "+70770953856"}
0005435100157	48C200	9998 032929	NINA EFIMOVA	{"phone": "+70774287435"}
0005435100158	A56655	0601 110594	VLADIMIR OSIPOV	{"phone": "+70040341356"}
0005435100159	E5D2BD	6261 521542	NINA BELOVA	{"phone": "+70452344159"}
0005435100160	E5D2BD	0748 557973	KLAVDIYA MIKHAYLOVA	{"phone": "+70559056487"}
0005435100161	E5D2BD	4164 731994	MARIYA GERASIMOVA	{"phone": "+70126643629"}
0005435100162	6616C3	0570 770515	SOFYA BELOVA	{"phone": "+70667178656"}
0005435100163	6616C3	3668 416766	ALEKSANDR PAVLOV	{"email": "pavlov.a-23011980@postgrespro.ru", "phone": "+70479640747"}
0005435100164	3723FF	6943 276212	ALEKSEY FEDOROV	{"email": "fedorov_aleksey_1967@postgrespro.ru", "phone": "+70842514638"}
0005435100165	02446D	3832 134826	FEDOR ANTONOV	{"phone": "+70765567535"}
0005435100166	CAFB07	0237 057305	SERGEY FILIPPOV	{"email": "filippovs03031974@postgrespro.ru", "phone": "+70446976123"}
0005435100167	BD3C72	2640 217700	NINA NESTEROVA	{"email": "n_nesterova.1968@postgrespro.ru", "phone": "+70794280968"}
0005435100168	047F28	8944 107941	ALEKSEY SAVELEV	{"phone": "+70081314701"}
0005435100169	047F28	6810 190588	VASILIY KUDRYASHOV	{"email": "kudryashov.vasiliy.27081971@postgrespro.ru", "phone": "+70920246271"}
0005435100170	690474	1305 250481	MIKHAIL NIKOLAEV	{"phone": "+70495801968"}
0005435100171	A5BC8A	8257 530619	ANTONINA MAKSIMOVA	{"email": "antonina-maksimova_051971@postgrespro.ru", "phone": "+70596630655"}
0005435100172	4CFAF6	9335 202361	SERGEY CHERNOV	{"phone": "+70456469540"}
0005435100173	4CFAF6	8823 174225	NATALYA SERGEEVA	{"email": "natalyasergeeva1981@postgrespro.ru", "phone": "+70731849975"}
0005435100174	8F00A1	2363 216071	ANASTASIYA VASILEVA	{"email": "avasileva_021976@postgrespro.ru", "phone": "+70710340733"}
0005435100175	8F00A1	1370 750777	RIMMA KUZNECOVA	{"email": "rimma.kuznecova-16121966@postgrespro.ru", "phone": "+70867953643"}
0005435100176	DFADD6	0195 732219	IVAN MAKSIMOV	{"email": "maksimovi_081978@postgrespro.ru", "phone": "+70052854338"}
0005435100177	DFADD6	8439 730889	OLEG KUZNECOV	{"email": "olegkuznecov.19021971@postgrespro.ru", "phone": "+70433010598"}
0005435100178	357647	4426 392002	ARINA EGOROVA	{"email": "a-egorova-071975@postgrespro.ru", "phone": "+70917461286"}
0005435100179	357647	6071 898865	ANTON ZHUKOV	{"phone": "+70832209824"}
0005435100180	AB24FB	2457 618126	TIMUR SHEVCHENKO	{"email": "shevchenkot04041972@postgrespro.ru", "phone": "+70501056129"}
0005435100181	C0C1FD	3701 208318	RUSLAN KISELEV	{"email": "kiselev.r_071973@postgrespro.ru", "phone": "+70106780788"}
0005435100182	C0C1FD	6483 451046	IRINA KALININA	{"phone": "+70278958657"}
0005435100183	55DCFC	0911 994076	PAVEL IVANOV	{"phone": "+70780060175"}
0005435100184	C20435	8058 245102	TAMARA KUZNECOVA	{"phone": "+70136867980"}
0005435100185	ED165A	1376 716991	MAKSIM KUZMIN	{"phone": "+70740104764"}
0005435100186	C19449	5056 377210	ANASTASIYA ANTONOVA	{"phone": "+70281823846"}
0005435100187	C19449	1117 302079	ALEKSANDR YAKOVLEV	{"email": "yakovlevaleksandr-23061964@postgrespro.ru", "phone": "+70490577068"}
0005435100188	2AF10E	8248 515583	ANNA ALEKSEEVA	{"email": "a.alekseeva031968@postgrespro.ru", "phone": "+70200523128"}
0005435100189	2AF10E	4274 862074	LYUBOV KISELEVA	{"phone": "+70758474810"}
0005435100190	659197	2086 786381	MIKHAIL KULIKOV	{"email": "kulikov_m121968@postgrespro.ru", "phone": "+70778485495"}
0005435100191	9FC971	2379 810991	ANNA KOZLOVA	{"email": "kozlova-anna_051982@postgrespro.ru", "phone": "+70483372353"}
0005435100192	9FC971	0602 118230	YURIY KISELEV	{"email": "y-kiselev-051968@postgrespro.ru", "phone": "+70902488875"}
0005435100193	E3C083	6947 870710	ANDREY VLASOV	{"email": "vlasov.a.02011970@postgrespro.ru", "phone": "+70331813122"}
0005435100194	E3C083	6715 334425	DARYA MOROZOVA	{"email": "d_morozova_051975@postgrespro.ru", "phone": "+70307027726"}
0005435100195	432BEC	8772 852109	MARINA ROMANOVA	{"email": "marina_romanova.1972@postgrespro.ru", "phone": "+70156645382"}
0005435100196	432BEC	2263 707879	YULIYA NAZAROVA	{"email": "nazarova_y.24071966@postgrespro.ru", "phone": "+70037008386"}
0005435100197	7B704D	5305 604434	SERGEY DENISOV	{"phone": "+70634068084"}
0005435100198	7B704D	6194 707381	SERGEY ROMANOV	{"email": "sergey_romanov_011979@postgrespro.ru", "phone": "+70003996184"}
0005435100199	EB68ED	4458 650123	ANNA MAKAROVA	{"phone": "+70867225607"}
0005435100200	EB68ED	1729 114546	ANASTASIYA MAKAROVA	{"phone": "+70490194234"}
0005435100201	C1919E	5711 365869	YULIYA EGOROVA	{"email": "egorova-yuliya1953@postgrespro.ru", "phone": "+70927029125"}
0005435100202	CC1AB8	3366 654675	ALEKSANDRA ZAKHAROVA	{"phone": "+70631479730"}
0005435100203	CC1AB8	7662 155507	LYUDMILA ZAKHAROVA	{"phone": "+70454007389"}
0005435100204	83527D	8983 381271	GALINA SERGEEVA	{"email": "sergeevagalina1974@postgrespro.ru", "phone": "+70049668861"}
0005435100205	514DDF	1995 333029	NADEZHDA SMIRNOVA	{"phone": "+70932886991"}
0005435100206	9FD464	1322 979398	EKATERINA MIRONOVA	{"email": "ekaterina_mironova_1973@postgrespro.ru", "phone": "+70326429418"}
0005435100207	2C005E	2610 453699	ELENA SOROKINA	{"phone": "+70098014325"}
0005435100208	461EBB	0579 514097	ANDREY SERGEEV	{"email": "andrey_sergeev1967@postgrespro.ru", "phone": "+70027755935"}
0005435103911	E7F11B	2807 976340	ALEKSEY KUZNECOV	{"phone": "+70063715851"}
0005435100209	C826D4	0284 619605	ANDREY BONDARENKO	{"email": "bondarenkoandrey_1973@postgrespro.ru", "phone": "+70027535756"}
0005435100210	450CD6	9727 716934	ANASTASIYA LAZAREVA	{"phone": "+70654298646"}
0005435100211	450CD6	6748 374923	OLEG RODIONOV	{"phone": "+70251223278"}
0005435103793	6A9963	9809 282257	YULIYA KARPOVA	{"phone": "+70348775970"}
0005435103794	C2274D	0916 025213	SERGEY SEMENOV	{"phone": "+70766822235"}
0005435103795	C2274D	5504 595154	VYACHESLAV ZAKHAROV	{"email": "vyacheslav.zakharov1977@postgrespro.ru", "phone": "+70144983489"}
0005435103796	CA5A12	2039 454179	YULIYA FOMINA	{"phone": "+70682809169"}
0005435103797	8EDDAB	0478 186712	KSENIYA PETROVA	{"phone": "+70680082932"}
0005435103798	3702C8	9775 585461	MAKSIM CHERNOV	{"email": "chernov_m.09041957@postgrespro.ru", "phone": "+70524584010"}
0005435103799	3CE822	2776 990899	ALINA VASILEVA	{"email": "vasilevaalina121968@postgrespro.ru", "phone": "+70602044666"}
0005435103800	3CE822	6879 542455	NATALYA KARPOVA	{"email": "natalya_karpova.051971@postgrespro.ru", "phone": "+70563014947"}
0005435103801	F9924A	1389 333793	GRIGORIY NIKOLAEV	{"phone": "+70107597017"}
0005435103802	9B2CBB	1200 813851	SERGEY DENISOV	{"phone": "+70271626205"}
0005435103803	A0AA80	3599 017561	PAVEL GERASIMOV	{"email": "gerasimov.pavel_26071976@postgrespro.ru", "phone": "+70367611665"}
0005435103804	8B251D	5617 024226	LIDIYA BORISOVA	{"phone": "+70590229960"}
0005435103805	8B251D	5601 507068	NATALYA VOROBEVA	{"email": "vorobevanatalya_23061973@postgrespro.ru", "phone": "+70916345865"}
0005435103806	BBDF02	9294 282813	MIKHAIL KULIKOV	{"email": "kulikov_m-1967@postgrespro.ru", "phone": "+70891481917"}
0005435103807	44C785	1859 914671	TATYANA GAVRILOVA	{"email": "gavrilovatatyana.22071968@postgrespro.ru", "phone": "+70237487926"}
0005435103808	44C785	7816 863109	ANNA SOROKINA	{"email": "sorokina-anna-14061978@postgrespro.ru", "phone": "+70969988377"}
0005435103809	ED6311	8668 942103	NATALYA KUZNECOVA	{"email": "natalya_kuznecova24091969@postgrespro.ru", "phone": "+70079779061"}
0005435103810	6055E2	7623 016170	SERGEY SEMENOV	{"email": "semenov.sergey061984@postgrespro.ru", "phone": "+70238254089"}
0005435103811	95A3C7	4625 634382	DENIS CHERNOV	{"email": "denis.chernov_10011960@postgrespro.ru", "phone": "+70763298056"}
0005435103812	1BFB47	9418 926326	DARYA POLYAKOVA	{"email": "darya_polyakova-1972@postgrespro.ru", "phone": "+70164910994"}
0005435103813	1BFB47	7419 324025	KRISTINA TIKHONOVA	{"email": "tikhonova-k_121971@postgrespro.ru", "phone": "+70869064549"}
0005435103814	C48441	3000 635690	RAFAEL PAVLOV	{"phone": "+70691955264"}
0005435103815	190B5D	6477 652495	ZAKHAR SOKOLOV	{"email": "sokolovz091971@postgrespro.ru", "phone": "+70273523706"}
0005435103816	1FDD87	3086 577874	IVAN NIKOLAEV	{"phone": "+70000526435"}
0005435103817	47AD42	2538 664952	ANATOLIY AFANASEV	{"phone": "+70179930306"}
0005435103818	E6FE14	1743 273157	BORIS DAVYDOV	{"email": "bdavydov06081971@postgrespro.ru", "phone": "+70434953378"}
0005435103819	DC0803	5904 708664	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr061975@postgrespro.ru", "phone": "+70802720694"}
0005435103820	8278F7	2686 406659	SERGEY KOZLOV	{"phone": "+70232916688"}
0005435103821	62E534	1980 997245	ANDREY SHEVCHENKO	{"email": "shevchenko_a-24021967@postgrespro.ru", "phone": "+70464663098"}
0005435103822	62E534	5221 796138	ALBINA ZAKHAROVA	{"phone": "+70930063818"}
0005435103823	EA6C33	8317 235413	LYUDMILA KRASNOVA	{"phone": "+70712667632"}
0005435103824	1C1FE4	5048 006034	VLADIMIR ALEKSEEV	{"phone": "+70494806148"}
0005435103825	172B68	1278 825304	VADIM FILIPPOV	{"email": "filippov-v23061974@postgrespro.ru", "phone": "+70966502174"}
0005435103826	4A56F9	6426 114420	GALINA MAKAROVA	{"phone": "+70573381431"}
0005435103827	4A56F9	9266 679191	ARTEM IVANOV	{"email": "a.ivanov-10041977@postgrespro.ru", "phone": "+70025700941"}
0005435103828	24138C	0035 405586	SERGEY MIRONOV	{"phone": "+70512668298"}
0005435103829	495358	1796 472229	ROMAN ISAEV	{"email": "isaev.roman_16111968@postgrespro.ru", "phone": "+70570217344"}
0005435103830	ED351F	9853 851365	VALERIY NOVIKOV	{"phone": "+70948280433"}
0005435103831	BDC189	8180 753466	MAKSIM SEMENOV	{"phone": "+70806963194"}
0005435103832	BDC189	3833 478615	PETR KULIKOV	{"phone": "+70299870628"}
0005435103833	39F67B	0752 422538	VLADIMIR AFANASEV	{"phone": "+70727453943"}
0005435103834	2ED72A	9410 022441	VIKTORIYA MARTYNOVA	{"phone": "+70140273244"}
0005435103835	8DFD45	4759 847956	SERGEY ROMANOV	{"email": "s_romanov121967@postgrespro.ru", "phone": "+70081236227"}
0005435103836	136666	1390 310807	ARINA LAZAREVA	{"phone": "+70280989799"}
0005435103837	136666	3691 682256	NINA GERASIMOVA	{"email": "gerasimova_nina.09101972@postgrespro.ru", "phone": "+70808289616"}
0005435103838	57F43F	2596 042220	LYUDMILA RODIONOVA	{"phone": "+70904250112"}
0005435103839	14C54F	8713 012878	DMITRIY STEPANOV	{"email": "d-stepanov1970@postgrespro.ru", "phone": "+70710016859"}
0005435103840	237833	5425 095023	VALENTINA POPOVA	{"email": "popova.valentina-13071970@postgrespro.ru", "phone": "+70888993441"}
0005435103841	39374E	1074 881898	TATYANA ZOTOVA	{"phone": "+70016907148"}
0005435103842	5D0D65	1000 277450	SERGEY NIKITIN	{"phone": "+70018426796"}
0005435103843	5D0D65	2523 850569	ANDREY KONOVALOV	{"phone": "+70963519522"}
0005435103844	559D73	9043 125642	NIKOLAY KISELEV	{"email": "nikolay_kiselev.091978@postgrespro.ru", "phone": "+70016704969"}
0005435103845	6E5F7F	5750 524500	LIDIYA KAZAKOVA	{"phone": "+70023352433"}
0005435103846	2E7B89	0342 786488	IRINA KONOVALOVA	{"email": "konovalova-irina-26031976@postgrespro.ru", "phone": "+70575631340"}
0005435103847	2E7B89	4042 973894	TATYANA FADEEVA	{"email": "fadeeva-t-22091968@postgrespro.ru", "phone": "+70554085379"}
0005435103848	0B0CA5	0960 872044	NATALYA BELOVA	{"email": "belovanatalya.16021966@postgrespro.ru", "phone": "+70833555444"}
0005435103849	0B0CA5	1902 193820	EVGENIY KOZLOV	{"email": "e_kozlov.101966@postgrespro.ru", "phone": "+70781147849"}
0005435103850	9C3511	1600 079565	EKATERINA SEMENOVA	{"email": "ekaterina.semenova_18071965@postgrespro.ru", "phone": "+70983188043"}
0005435103851	9C3511	9362 907324	VYACHESLAV ZAKHAROV	{"email": "vyacheslav.zakharov111972@postgrespro.ru", "phone": "+70710942122"}
0005435103852	7D262A	7612 727168	GALINA PAVLOVA	{"email": "pavlova_galina1976@postgrespro.ru", "phone": "+70435545942"}
0005435103853	61C014	5526 505060	GRIGORIY BELOV	{"email": "g-belov24061976@postgrespro.ru", "phone": "+70205633365"}
0005435103854	20301F	2241 027834	VLADIMIR SOKOLOV	{"phone": "+70445188228"}
0005435103855	20301F	2753 191749	ELENA MARTYNOVA	{"phone": "+70738892107"}
0005435103856	367FE8	4585 446244	ANTON NIKOLAEV	{"phone": "+70179281061"}
0005435103857	455FD3	8161 917276	FARID EGOROV	{"phone": "+70102376586"}
0005435103858	E57D05	0479 301627	TAMARA PAVLOVA	{"email": "pavlova.tamara.081968@postgrespro.ru", "phone": "+70215533432"}
0005435103859	318C3B	4418 408251	NIKOLAY RODIONOV	{"email": "nikolay-rodionov031967@postgrespro.ru", "phone": "+70811854303"}
0005435103860	1BE803	9636 461498	VLADISLAV OSIPOV	{"phone": "+70413787764"}
0005435103861	1BE803	3941 624660	SERGEY ANDREEV	{"email": "sandreev.13071984@postgrespro.ru", "phone": "+70630310206"}
0005435103862	3CC7AF	3467 359195	ANNA LEBEDEVA	{"email": "a.lebedeva_13041973@postgrespro.ru", "phone": "+70803678402"}
0005435103863	A5CDF9	9279 620810	ELIZAVETA PETROVA	{"phone": "+70228108586"}
0005435103864	AC7D28	2228 099314	VIKTOR SCHERBAKOV	{"email": "scherbakov-v.021965@postgrespro.ru", "phone": "+70735977682"}
0005435103865	AC7D28	3379 755405	TATYANA ALEKSANDROVA	{"email": "aleksandrova_tatyana121976@postgrespro.ru", "phone": "+70265327502"}
0005435103866	40753B	9020 997278	SERGEY KRASNOV	{"phone": "+70775628550"}
0005435103867	AE59BD	4673 020923	OLGA NAZAROVA	{"email": "o.nazarova081969@postgrespro.ru", "phone": "+70758568001"}
0005435103868	AE59BD	9585 570622	LYUDMILA NESTEROVA	{"phone": "+70008519576"}
0005435103869	AE59BD	3680 476623	PAVEL NIKITIN	{"email": "p-nikitin1961@postgrespro.ru", "phone": "+70618118567"}
0005435103870	5BE566	6461 990451	VIKTORIYA AKIMOVA	{"email": "viktoriyaakimova.05041955@postgrespro.ru", "phone": "+70803848808"}
0005435103871	9DA489	1207 271992	TATYANA MATVEEVA	{"email": "matveeva-t.02071966@postgrespro.ru", "phone": "+70906120133"}
0005435103872	9DA489	2584 495165	VIKTOR MAKAROV	{"email": "makarov.v.1962@postgrespro.ru", "phone": "+70843179517"}
0005435103873	7EEBFD	4146 702006	NINA SEMENOVA	{"phone": "+70583615404"}
0005435103874	BD69E3	4458 453842	EVGENIYA VOLKOVA	{"phone": "+70703624153"}
0005435103875	BD69E3	7912 757835	MARIYA SEMENOVA	{"phone": "+70502289739"}
0005435103876	644EE6	5922 372823	NINA MAKAROVA	{"email": "makarova-nina061965@postgrespro.ru", "phone": "+70738710854"}
0005435103877	644EE6	8183 925361	VLADIMIR VOROBEV	{"email": "vorobevv.1971@postgrespro.ru", "phone": "+70129955116"}
0005435103878	E17079	8720 544713	LYUDMILA TROFIMOVA	{"phone": "+70952909555"}
0005435103879	E17079	6352 526123	NATALYA KUZMINA	{"email": "kuzmina_n.081972@postgrespro.ru", "phone": "+70707429343"}
0005435103880	7B5431	1767 111121	VERA FEDOROVA	{"phone": "+70044655306"}
0005435103881	7B5431	1095 561380	ALEKSANDR MAKSIMOV	{"phone": "+70843030115"}
0005435103882	A74DCC	9787 508075	EVGENIYA KUZNECOVA	{"phone": "+70767630623"}
0005435103883	A74DCC	4946 282085	VALENTINA GAVRILOVA	{"email": "gavrilovavalentina-1967@postgrespro.ru", "phone": "+70217530871"}
0005435103884	380F60	8190 120854	LYUDMILA MASLOVA	{"email": "maslova.lyudmila1971@postgrespro.ru", "phone": "+70143346874"}
0005435103885	19687F	1792 113488	TATYANA FOMINA	{"phone": "+70379746011"}
0005435103886	9BC132	4763 579289	ALEKSANDR POPOV	{"phone": "+70521327081"}
0005435103887	1248DB	2606 913995	IRINA ISAEVA	{"email": "i_isaeva.08081976@postgrespro.ru", "phone": "+70786367987"}
0005435103888	1F436F	8512 672658	DENIS DENISOV	{"phone": "+70023787810"}
0005435103889	D4F7B5	1735 113450	OKSANA VOLKOVA	{"email": "ovolkova-121983@postgrespro.ru", "phone": "+70710467807"}
0005435103890	D4F7B5	4488 054367	ILMIR ZHURAVLEV	{"phone": "+70340759669"}
0005435103891	0A747B	9440 457598	VLADIMIR NIKOLAEV	{"phone": "+70014983114"}
0005435103892	F963EC	1891 818757	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr.1970@postgrespro.ru", "phone": "+70483423315"}
0005435103893	9435AE	4253 833937	EKATERINA ROMANOVA	{"email": "romanova-e_18011979@postgrespro.ru", "phone": "+70082044687"}
0005435103894	E01DDE	3617 901773	OLGA KOMAROVA	{"email": "o-komarova21121976@postgrespro.ru", "phone": "+70949302652"}
0005435103895	E01DDE	5571 292812	GALINA BORISOVA	{"phone": "+70851074138"}
0005435103896	ABC2C0	7834 026703	EVA KUZNECOVA	{"phone": "+70013617565"}
0005435103897	D8508F	3964 119661	NATALYA SIDOROVA	{"email": "sidorova_n1964@postgrespro.ru", "phone": "+70124233287"}
0005435103898	D8508F	2252 397111	VIKTOR NAUMOV	{"phone": "+70162214242"}
0005435103899	348A9C	8273 127852	ALEKSANDR DENISOV	{"phone": "+70916742497"}
0005435103900	39AA48	3207 409731	VLADIMIR MIRONOV	{"phone": "+70144419890"}
0005435103901	25B0DE	1206 264564	LYUDMILA PETROVA	{"phone": "+70037190434"}
0005435103902	4601AD	0763 794711	ALEKSANDR OSIPOV	{"phone": "+70969002927"}
0005435103903	CD2905	3861 967173	EKATERINA KUZNECOVA	{"email": "kuznecova-e-081970@postgrespro.ru", "phone": "+70646338409"}
0005435103904	CD2905	4659 765557	NADEZHDA KONDRATEVA	{"email": "kondrateva_n_13111973@postgrespro.ru", "phone": "+70238094558"}
0005435103905	3FEF7E	6323 029167	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov061978@postgrespro.ru", "phone": "+70646433067"}
0005435103906	3FEF7E	6626 693322	TATYANA PAVLOVA	{"email": "pavlova_tatyana.29101973@postgrespro.ru", "phone": "+70222205145"}
0005435103907	78658C	5046 649743	TATYANA PAVLOVA	{"phone": "+70015884177"}
0005435103908	DFCDBD	8349 986547	MARIYA GORBUNOVA	{"phone": "+70784378818"}
0005435103909	2470C3	4685 346782	MAKSIM POPOV	{"email": "m.popov.041974@postgrespro.ru", "phone": "+70628044621"}
0005435103912	E7F11B	5239 422706	TATYANA ZAKHAROVA	{"phone": "+70414782967"}
0005435103913	F319DE	4757 303898	TATYANA MALYSHEVA	{"phone": "+70438698277"}
0005435103914	F319DE	2044 279263	NIKOLAY GRIGOREV	{"phone": "+70279281987"}
0005435103915	943484	9033 648758	ALEKSANDR CHERNOV	{"email": "chernov.a.061967@postgrespro.ru", "phone": "+70044204851"}
0005435103916	0FCD37	3298 639167	ELENA FILATOVA	{"phone": "+70358242115"}
0005435103917	0FCD37	4315 521646	VLADIMIR ZAYCEV	{"phone": "+70872026473"}
0005435103918	9C99DE	6931 615655	NINA KUZNECOVA	{"email": "n.kuznecova1961@postgrespro.ru", "phone": "+70440040167"}
0005435103919	4865CB	0723 788991	SERGEY FEDOTOV	{"email": "sergey.fedotov.20031968@postgrespro.ru", "phone": "+70956959192"}
0005435103920	C4495E	9271 352245	MIKHAIL KUZNECOV	{"email": "mikhail_kuznecov-1972@postgrespro.ru", "phone": "+70659022212"}
0005435103921	8F0CD9	8072 800959	ALEKSANDR ZHUKOV	{"email": "zhukov-a_061978@postgrespro.ru", "phone": "+70729233323"}
0005435103922	8C8357	3343 733927	DENIS DENISOV	{"email": "denis.denisov1968@postgrespro.ru", "phone": "+70809210069"}
0005435103923	D377A9	2222 461218	ANDREY MAKSIMOV	{"phone": "+70653067239"}
0005435103924	837C3B	1284 118466	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr-091972@postgrespro.ru", "phone": "+70688266611"}
0005435103925	C74590	9908 004773	ANNA KAZAKOVA	{"phone": "+70700654590"}
0005435103926	29ED20	4704 639729	ANASTASIYA GRISHINA	{"phone": "+70929145168"}
0005435103927	29ED20	8973 684999	YURIY NAZAROV	{"email": "y-nazarov011975@postgrespro.ru", "phone": "+70315147743"}
0005435103928	5C7CC8	5109 454333	VLADIMIR GORBUNOV	{"phone": "+70270772533"}
0005435103929	3F265B	3473 938615	POLINA KONDRATEVA	{"email": "kondratevapolina28091960@postgrespro.ru", "phone": "+70254798816"}
0005435103930	3F265B	2418 027858	ANASTASIYA DMITRIEVA	{"email": "a.dmitrieva.08081964@postgrespro.ru", "phone": "+70749500858"}
0005435103931	3F265B	3918 779380	DIANA FILIPPOVA	{"phone": "+70834281792"}
0005435103932	C6C44A	2103 265699	ANDREY ALEKSEEV	{"phone": "+70804964489"}
0005435103933	F15192	5763 744240	ALEKSANDR SOLOVEV	{"phone": "+70062335447"}
0005435103934	270355	7554 532903	ALEKSEY IVANOV	{"email": "ivanov_a-111967@postgrespro.ru", "phone": "+70310790363"}
0005435103935	B1F85D	9198 161854	ANDREY VLASOV	{"phone": "+70355976565"}
0005435103936	5B18B8	7879 334460	MARIYA KOZLOVA	{"email": "mariya.kozlova.011979@postgrespro.ru", "phone": "+70893249210"}
0005435103937	8F81D7	3673 292477	ALEKSEY PAVLOV	{"phone": "+70163206311"}
0005435103938	FC7624	3117 246477	VLADIMIR GUSEV	{"email": "v.gusev.021968@postgrespro.ru", "phone": "+70883154443"}
0005435103939	FC7624	1996 555096	KRISTINA MIRONOVA	{"email": "kristinamironova-1977@postgrespro.ru", "phone": "+70757412031"}
0005435103940	FC7624	1729 912907	NIKOLAY KUZNECOV	{"phone": "+70999919760"}
0005435103941	328C55	3641 476331	VLADIMIR TIMOFEEV	{"phone": "+70208357412"}
0005435103942	B1B098	7758 591596	DMITRIY ROMANOV	{"phone": "+70708091986"}
0005435103943	B1B098	1883 984555	VLADIMIR GUSEV	{"email": "gusev.vladimir1964@postgrespro.ru", "phone": "+70889147793"}
0005435103944	B1B098	6476 660930	SERGEY MIKHAYLOV	{"phone": "+70875335976"}
0005435103945	9E91DC	2323 069183	RIM KUZNECOV	{"email": "rkuznecov_021991@postgrespro.ru", "phone": "+70178157420"}
0005435103946	755A8E	1397 745169	ALEKSEY OSIPOV	{"email": "osipov-aleksey.03101966@postgrespro.ru", "phone": "+70095578578"}
0005435103947	755A8E	4192 839407	RODION NIKITIN	{"phone": "+70601916462"}
0005435103948	28A9C6	8584 484473	NATALIYA NAUMOVA	{"email": "naumova-n_09111963@postgrespro.ru", "phone": "+70070748421"}
0005435103949	28A9C6	7837 939994	SERGEY SEMENOV	{"phone": "+70334727330"}
0005435103950	170DFC	6130 933135	ALEKSANDRA FILIPPOVA	{"email": "filippova.a-07081965@postgrespro.ru", "phone": "+70783097194"}
0005435103951	170DFC	1263 473066	OLGA GERASIMOVA	{"phone": "+70705856658"}
0005435103952	21DDA8	4684 557420	NIKOLAY GRIGOREV	{"email": "n.grigorev.1968@postgrespro.ru", "phone": "+70225980662"}
0005435103953	427B07	7854 149591	TAMARA POPOVA	{"phone": "+70842773955"}
0005435103954	77F1B9	3767 152069	ALEKSEY MEDVEDEV	{"phone": "+70559469547"}
0005435103955	6C3EAB	7534 096217	TAMARA MARTYNOVA	{"phone": "+70875524418"}
0005435103956	937A85	1694 157377	EGOR MARTYNOV	{"email": "martynov-egor_041960@postgrespro.ru", "phone": "+70179079245"}
0005435103957	7C40C2	0431 030088	ZOYA ERMAKOVA	{"email": "zermakova-11101966@postgrespro.ru", "phone": "+70690385376"}
0005435103958	32654C	2071 363120	YULIYA GERASIMOVA	{"email": "gerasimova.yuliya_1984@postgrespro.ru", "phone": "+70195550710"}
0005435103959	F163B1	9288 073600	TATYANA MAKAROVA	{"phone": "+70036273603"}
0005435103960	C3BF3E	4714 733598	VALENTIN MAKSIMOV	{"email": "maksimov-valentin.1976@postgrespro.ru", "phone": "+70555993220"}
0005435103961	C3BF3E	1700 198487	VITALIY GRIGOREV	{"phone": "+70302318942"}
0005435103962	E54BBA	4832 938160	NINA KISELEVA	{"phone": "+70640154032"}
0005435103963	5E02DB	1581 526445	RIMMA NESTEROVA	{"email": "rimmanesterova_081978@postgrespro.ru", "phone": "+70236014395"}
0005435103964	D5F70A	7783 683652	OLGA SERGEEVA	{"email": "sergeeva_o_1969@postgrespro.ru", "phone": "+70346306359"}
0005435103965	D5F70A	7475 232305	SERGEY AFANASEV	{"email": "sergey-afanasev.14061981@postgrespro.ru", "phone": "+70380132603"}
0005435103966	4D1D97	3432 872926	ELENA SERGEEVA	{"email": "sergeeva_e.081978@postgrespro.ru", "phone": "+70786616358"}
0005435103967	4D1D97	4787 603709	ALEKSANDR MELNIKOV	{"email": "a.melnikov_1972@postgrespro.ru", "phone": "+70853213509"}
0005435103968	D07214	6708 517927	ALEKSEY NAUMOV	{"phone": "+70174818468"}
0005435103969	D07214	7340 613591	ELENA FILATOVA	{"email": "filatova_elena20121968@postgrespro.ru", "phone": "+70970865601"}
0005435103970	83157B	4608 184167	OLGA KUZNECOVA	{"email": "kuznecova-o26091972@postgrespro.ru", "phone": "+70824920247"}
0005435103971	83157B	3845 648100	VLADA BORISOVA	{"email": "borisovav.011968@postgrespro.ru", "phone": "+70573617957"}
0005435103972	F16ED5	9878 123602	VALERIY SOKOLOV	{"email": "sokolov_v-03021971@postgrespro.ru", "phone": "+70662088785"}
0005435103973	F16ED5	2263 143333	EKATERINA VASILEVA	{"phone": "+70750767375"}
0005435103974	F5F1EA	8575 094290	OLGA NESTEROVA	{"email": "olganesterova121962@postgrespro.ru", "phone": "+70379003300"}
0005435103975	42751C	0168 251295	VLADIMIR ISAEV	{"phone": "+70191846940"}
0005435103976	42751C	4735 911396	VALENTIN MEDVEDEV	{"phone": "+70485972865"}
0005435103977	42751C	1372 134517	ANNA KONOVALOVA	{"email": "konovalovaa16051969@postgrespro.ru", "phone": "+70648672216"}
0005435103978	D72065	6838 284816	IRINA CHERNOVA	{"email": "i-chernova.07031974@postgrespro.ru", "phone": "+70134387775"}
0005435103979	902284	8931 004231	VIKTOR SEMENOV	{"email": "semenov.v.1973@postgrespro.ru", "phone": "+70796418659"}
0005435103980	E440DA	8157 148448	IGOR DAVYDOV	{"email": "davydov.i071977@postgrespro.ru", "phone": "+70464536526"}
0005435103981	4F5CD7	8523 940915	OLGA MOISEEVA	{"email": "o_moiseeva-1986@postgrespro.ru", "phone": "+70046360923"}
0005435103982	8F8228	8197 457926	OKSANA KISELEVA	{"phone": "+70647030186"}
0005435103983	72EAB9	4880 746520	ROZA VOLKOVA	{"email": "r_volkova.011978@postgrespro.ru", "phone": "+70459665594"}
0005435103984	056368	9495 414252	ARTEM POPOV	{"phone": "+70145892472"}
0005435103985	056368	7151 663150	KIRILL SIDOROV	{"phone": "+70386935363"}
0005435103986	AAAE44	6613 964737	ALEKSANDR MAKAROV	{"phone": "+70526838416"}
0005435103987	9FD3B6	8765 152894	TATYANA VLASOVA	{"email": "vlasova_tatyana.061974@postgrespro.ru", "phone": "+70201311059"}
0005435103988	9FD3B6	4006 761060	OLGA MEDVEDEVA	{"phone": "+70043286538"}
0005435103989	4AE2F0	2955 530050	ALEKSANDR GAVRILOV	{"email": "aleksandrgavrilov051960@postgrespro.ru", "phone": "+70233255468"}
0005435103990	2873A1	0153 256121	MARIYA KULIKOVA	{"phone": "+70957020267"}
0005435103991	BF2389	3460 173852	ALEKSEY SCHERBAKOV	{"email": "ascherbakov_1977@postgrespro.ru", "phone": "+70179637322"}
0005435103992	F95C7C	0951 910820	ALEKSANDR KUZNECOV	{"email": "kuznecov.a1993@postgrespro.ru", "phone": "+70559486951"}
0005435103993	B98433	4641 836948	GALINA ANTONOVA	{"email": "antonova.galina1963@postgrespro.ru", "phone": "+70498079259"}
0005435103994	4413F1	4611 548947	VALENTINA SIDOROVA	{"email": "sidorova_valentina_12081963@postgrespro.ru", "phone": "+70018190553"}
0005435103995	389235	2118 977103	KLAVDIYA KONOVALOVA	{"phone": "+70995904894"}
0005435103996	389235	6841 689308	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_1970@postgrespro.ru", "phone": "+70627548615"}
0005435103997	D223A7	7746 953645	NATALYA NESTEROVA	{"email": "nesterova_natalya1978@postgrespro.ru", "phone": "+70747763756"}
0005435103998	F049E8	2612 090206	EKATERINA SIDOROVA	{"email": "e.sidorova121953@postgrespro.ru", "phone": "+70797272647"}
0005435103999	898180	7031 149363	VERA POPOVA	{"email": "v.popova.111972@postgrespro.ru", "phone": "+70370408550"}
0005435104000	771DA0	6038 803134	YURIY PETROV	{"phone": "+70542556455"}
0005435104001	771DA0	0148 369532	NINA VASILEVA	{"email": "nvasileva_31081972@postgrespro.ru", "phone": "+70174085912"}
0005435104002	17A4D4	0605 865394	OLEG SMIRNOV	{"email": "smirnov_o_1969@postgrespro.ru", "phone": "+70884832911"}
0005435104003	FED488	1430 160611	ANASTASIYA VOLKOVA	{"email": "volkova_a.24091969@postgrespro.ru", "phone": "+70454113195"}
0005435104004	5A4458	2923 415733	VLADIMIR YAKOVLEV	{"email": "vyakovlev_03071978@postgrespro.ru", "phone": "+70468362023"}
0005435104005	5A4458	4495 595780	IRINA DENISOVA	{"email": "denisova-irina-13111969@postgrespro.ru", "phone": "+70595643598"}
0005435104006	812285	5904 394454	GALINA IVANOVA	{"phone": "+70073099628"}
0005435104007	5FD8AD	5836 736710	VIKTOR GERASIMOV	{"phone": "+70490507784"}
0005435104008	CFB40B	6253 528508	LYUDMILA POPOVA	{"email": "lyudmila-popova-1973@postgrespro.ru", "phone": "+70636752639"}
0005435104009	CFB40B	1535 644274	SERGEY PETROV	{"phone": "+70986392492"}
0005435104010	3E5B18	2072 226880	TATYANA VASILEVA	{"email": "vasileva-t.1974@postgrespro.ru", "phone": "+70930650154"}
0005435104011	08478D	7434 463074	ANASTASIYA ALEKSANDROVA	{"email": "aleksandrova.a.1979@postgrespro.ru", "phone": "+70696888528"}
0005435104012	08478D	5997 089525	LIDIYA MOROZOVA	{"phone": "+70774475327"}
0005435104013	08478D	6948 841071	DENIS ALEKSANDROV	{"email": "aleksandrov.d041968@postgrespro.ru", "phone": "+70398233059"}
0005435104014	88DE13	5845 024495	EKATERINA NIKOLAEVA	{"phone": "+70572190342"}
0005435104015	13B3DD	6365 971216	SERGEY KRASNOV	{"phone": "+70044031308"}
0005435104016	DE5911	1387 913558	ANASTASIYA BARANOVA	{"email": "a-baranova1970@postgrespro.ru", "phone": "+70518746019"}
0005435104017	E29457	4080 221333	EVGENIY MATVEEV	{"phone": "+70412135890"}
0005435104018	8BEAA1	5980 589878	LYUBOV ZHURAVLEVA	{"phone": "+70110612039"}
0005435104019	D3D08A	9043 962105	TATYANA TITOVA	{"email": "t-titova.21041977@postgrespro.ru", "phone": "+70812440433"}
0005435104020	D3D08A	7638 181104	EVGENIY SOROKIN	{"email": "evgeniy-sorokin09081963@postgrespro.ru", "phone": "+70722575836"}
0005435104021	DF469E	2561 398654	ELVINA ORLOVA	{"phone": "+70589051273"}
0005435104022	134634	0424 827365	GALINA ANTONOVA	{"email": "galina_antonova.071974@postgrespro.ru", "phone": "+70322996062"}
0005435104023	7A4E11	3661 484221	ANDREY MIRONOV	{"email": "mironovandrey-24041972@postgrespro.ru", "phone": "+70199269057"}
0005435104024	27DEE5	6582 866245	VLADIMIR ZAKHAROV	{"phone": "+70848117667"}
0005435104025	2CC96A	9490 307947	OLGA CHERNOVA	{"email": "chernovao.031978@postgrespro.ru", "phone": "+70590287934"}
0005435104026	7425FE	9082 179203	ALEKSANDR OSIPOV	{"email": "osipova-031970@postgrespro.ru", "phone": "+70632335593"}
0005435104027	743F66	7913 347552	VIKTOR CHERNOV	{"email": "chernov.viktor_27021985@postgrespro.ru", "phone": "+70841324799"}
0005435104028	BECEA8	4767 889853	ALEKSANDR ANDREEV	{"email": "a_andreev_26031974@postgrespro.ru", "phone": "+70869282269"}
0005435104029	BECEA8	6570 532728	NATALIYA NAZAROVA	{"phone": "+70740059831"}
0005435104030	FC28B2	2583 424910	MATVEY YAKOVLEV	{"phone": "+70737538971"}
0005435104031	5C0678	8679 697695	LYUBOV SAVELEVA	{"email": "lyubov_saveleva27111973@postgrespro.ru", "phone": "+70960196526"}
0005435104032	7C62A1	4529 670250	ALENA GUSEVA	{"email": "aguseva-30121973@postgrespro.ru", "phone": "+70248343218"}
0005435104033	CFAC05	8636 612030	NINA ZAKHAROVA	{"phone": "+70744317572"}
0005435104034	572C66	9475 032004	VERA MAKAROVA	{"phone": "+70790870455"}
0005435104035	572C66	8721 637975	NATALYA KUZNECOVA	{"email": "kuznecova-natalya.081973@postgrespro.ru", "phone": "+70649982450"}
0005435104036	DC2B74	0384 050272	DANILA NOVIKOV	{"phone": "+70955838922"}
0005435104037	CEE95B	9667 551422	LYAYSAN AKIMOVA	{"email": "akimoval-1974@postgrespro.ru", "phone": "+70910034800"}
0005435104038	B6CBDA	4838 712710	ANDREY NAZAROV	{"email": "nazarov-andrey.20121968@postgrespro.ru", "phone": "+70661571559"}
0005435104039	B6CBDA	5098 648815	MIKHAIL SOROKIN	{"email": "m-sorokin-071976@postgrespro.ru", "phone": "+70683742281"}
0005435104040	939EDC	8816 194247	TATYANA FROLOVA	{"email": "tfrolova-05031970@postgrespro.ru", "phone": "+70716446272"}
0005435104153	081B37	1294 413279	RAISA KARPOVA	{"phone": "+70848687804"}
0005435104041	8C3824	9288 410523	TATYANA SIDOROVA	{"email": "sidorova-tatyana.21101968@postgrespro.ru", "phone": "+70906216507"}
0005435104042	E9775D	1628 229040	IGOR SIDOROV	{"phone": "+70340278030"}
0005435104043	E9775D	1390 115720	MIKHAIL MOISEEV	{"phone": "+70727882031"}
0005435104044	E9775D	2351 302662	GALINA GORBUNOVA	{"phone": "+70614769943"}
0005435104045	7D99AC	7002 951816	MARINA STEPANOVA	{"email": "marina-stepanova_11071971@postgrespro.ru", "phone": "+70786771065"}
0005435104046	BA9EBF	5481 030844	IVAN KUZNECOV	{"phone": "+70607734692"}
0005435104047	BA9EBF	3025 723569	VLADIMIR IVANOV	{"email": "vladimirivanov.011969@postgrespro.ru", "phone": "+70050307495"}
0005435104048	578F47	2717 183896	LYUDMILA ZAKHAROVA	{"email": "lyudmila.zakharova_22041976@postgrespro.ru", "phone": "+70251557517"}
0005435104049	C59671	3113 333193	LYUDMILA ABRAMOVA	{"email": "lyudmilaabramova_041969@postgrespro.ru", "phone": "+70903677277"}
0005435104050	C59671	5988 259567	YULIYA KAZAKOVA	{"phone": "+70496538843"}
0005435104051	528571	1357 458218	TAISIYA ZOTOVA	{"phone": "+70276054837"}
0005435104052	D784A4	3801 043305	VLADIMIR MOROZOV	{"email": "v.morozov_02041975@postgrespro.ru", "phone": "+70669761174"}
0005435104053	BF3D7E	6964 416240	LIDIYA ALEKSEEVA	{"email": "alekseeva_lidiya11121978@postgrespro.ru", "phone": "+70304505397"}
0005435104054	1F30BD	2858 217862	SERGEY KOZLOV	{"email": "kozlov.s_1977@postgrespro.ru", "phone": "+70251447095"}
0005435104055	C4C85F	8235 499022	ANATOLIY ABRAMOV	{"phone": "+70317069314"}
0005435104056	C4C85F	9269 456457	GALINA ORLOVA	{"email": "gorlova-011965@postgrespro.ru", "phone": "+70774164054"}
0005435104057	0CA304	6851 503125	VALERIY ZAKHAROV	{"email": "valeriy-zakharov_081971@postgrespro.ru", "phone": "+70900743755"}
0005435104058	B47051	4346 421624	ANDREY VOLKOV	{"email": "andrey.volkov-041962@postgrespro.ru", "phone": "+70973046746"}
0005435104059	182592	3633 793020	ZOYA DENISOVA	{"phone": "+70600590870"}
0005435104060	7E2224	8929 409146	KARINA FEDOROVA	{"phone": "+70727161612"}
0005435104061	D1D8AA	4971 503412	RAMIL PAVLOV	{"email": "r.pavlov.061984@postgrespro.ru", "phone": "+70914147183"}
0005435104062	98897F	2188 384130	EKATERINA EFIMOVA	{"phone": "+70921738709"}
0005435104063	98897F	9092 862221	VLADIMIR SIDOROV	{"email": "sidorov-vladimir-12021967@postgrespro.ru", "phone": "+70243540532"}
0005435104064	DA46EB	7280 307707	TATYANA MAKSIMOVA	{"phone": "+70220743106"}
0005435104065	DA46EB	7251 904794	YAN FEDOROV	{"phone": "+70968721209"}
0005435104066	4AEC81	7945 185376	PETR MARTYNOV	{"phone": "+70368746708"}
0005435104067	B5A8D8	8117 133758	VERA TARASOVA	{"email": "tarasova-v_101974@postgrespro.ru", "phone": "+70560293449"}
0005435104068	B5A8D8	7060 865311	NATALYA PETROVA	{"email": "petrovanatalya061976@postgrespro.ru", "phone": "+70676556351"}
0005435104069	34B73C	4173 482534	TATYANA KONOVALOVA	{"phone": "+70617693324"}
0005435104070	77E351	9548 013387	NINA MASLOVA	{"email": "maslova-nina091984@postgrespro.ru", "phone": "+70700766176"}
0005435104071	17C74B	7042 356460	ELENA ANDREEVA	{"email": "elenaandreeva041975@postgrespro.ru", "phone": "+70983551114"}
0005435104072	119D72	1758 230725	OLGA KOLESNIKOVA	{"email": "olga.kolesnikova_1974@postgrespro.ru", "phone": "+70377810292"}
0005435104073	119D72	6331 341552	ALEKSANDR GUSEV	{"email": "gusevaleksandr1960@postgrespro.ru", "phone": "+70639695959"}
0005435104074	135992	4195 714907	OKSANA FEDOROVA	{"phone": "+70536150074"}
0005435104075	135992	8505 689117	MARIYA PAVLOVA	{"phone": "+70414613270"}
0005435104076	135992	1913 779017	DENIS GAVRILOV	{"email": "gavrilovdenis1982@postgrespro.ru", "phone": "+70961719456"}
0005435104077	CB648C	0771 051731	ANATOLIY CHERNOV	{"email": "a_chernov111980@postgrespro.ru", "phone": "+70193984746"}
0005435104078	D27F7D	5045 305993	VLADIMIR FILIPPOV	{"email": "filippovvladimir_28081971@postgrespro.ru", "phone": "+70117081844"}
0005435104079	D27F7D	7286 242356	NIKOLAY ILIN	{"email": "ilin-nikolay_18051978@postgrespro.ru", "phone": "+70168368366"}
0005435104080	83AB53	3074 332407	YULIYA SOKOLOVA	{"phone": "+70824963362"}
0005435104081	8A0424	4699 010611	ALEKSEY ZAYCEV	{"email": "zaycev_aleksey.1977@postgrespro.ru", "phone": "+70324413971"}
0005435104082	EA852D	9400 994940	TATYANA POTAPOVA	{"email": "t-potapova-021976@postgrespro.ru", "phone": "+70495607387"}
0005435104083	71B9FF	4546 854356	VLADIMIR BORISOV	{"phone": "+70678912022"}
0005435104084	6DB5F1	1154 200720	LARISA TIMOFEEVA	{"phone": "+70083488909"}
0005435104085	20DBAF	0713 978556	EVGENIY ANTONOV	{"email": "e-antonov-101974@postgrespro.ru", "phone": "+70632073390"}
0005435104086	20DBAF	3987 923446	DIANA SAVELEVA	{"phone": "+70457084825"}
0005435104087	7628DC	3534 979327	IRINA LEBEDEVA	{"email": "i_lebedeva_1974@postgrespro.ru", "phone": "+70133444833"}
0005435104088	569785	3694 748579	REGINA TROFIMOVA	{"phone": "+70563040467"}
0005435104089	569785	1358 322567	VALERIYA FILATOVA	{"phone": "+70036693646"}
0005435104090	963200	0578 667296	ALEKSEY DENISOV	{"phone": "+70574687929"}
0005435104091	4FC7F2	6767 774884	ELENA KISELEVA	{"phone": "+70404686651"}
0005435104092	E02D32	5092 616327	EVGENIY FOMIN	{"phone": "+70276776055"}
0005435104093	9ADB0D	1207 870015	ILYA MELNIKOV	{"phone": "+70535039130"}
0005435104094	9ADB0D	1239 133807	DANILA MOROZOV	{"phone": "+70985779603"}
0005435104095	C1CA4E	7985 380765	MARINA EGOROVA	{"phone": "+70083694119"}
0005435104096	3E6ADC	6570 703381	IRINA KOZLOVA	{"email": "i-kozlova-16051974@postgrespro.ru", "phone": "+70797922212"}
0005435104097	3E6ADC	6074 088128	ANASTASIYA TARASOVA	{"email": "anastasiya-tarasova-031975@postgrespro.ru", "phone": "+70887932866"}
0005435104098	147EF9	0055 193400	IRINA MOISEEVA	{"phone": "+70516733415"}
0005435104099	BDC7D6	1578 593582	VALENTINA ISAEVA	{"email": "isaeva-valentina-28081975@postgrespro.ru", "phone": "+70802523909"}
0005435104100	B9B189	5873 548580	SERGEY KUZNECOV	{"email": "kuznecov-sergey.19021977@postgrespro.ru", "phone": "+70342838419"}
0005435104101	B9B189	6626 118756	MIKHAIL OSIPOV	{"phone": "+70962394147"}
0005435104102	B9B189	9275 892836	TAMARA KISELEVA	{"phone": "+70937466741"}
0005435104103	33128C	3378 690883	MIKHAIL KOZLOV	{"email": "m.kozlov031975@postgrespro.ru", "phone": "+70696972633"}
0005435104104	33128C	9602 723855	EKATERINA SOROKINA	{"email": "ekaterina_sorokina_1963@postgrespro.ru", "phone": "+70250257902"}
0005435104105	43BF3A	2410 911198	ANDREY ALEKSEEV	{"email": "andrey_alekseev20111978@postgrespro.ru", "phone": "+70572635839"}
0005435104106	A7936F	8789 492383	OLESYA NOVIKOVA	{"phone": "+70931712211"}
0005435104107	9BBDB8	7750 508364	NIKOLAY SEMENOV	{"email": "nikolay_semenov-1967@postgrespro.ru", "phone": "+70766254286"}
0005435104108	4AD43D	1820 742068	RUSTAM KARPOV	{"email": "karpov_rustam.01021963@postgrespro.ru", "phone": "+70123279626"}
0005435104109	184F8B	8979 683228	ELENA ISAEVA	{"email": "isaeva-elena-30111967@postgrespro.ru", "phone": "+70906619889"}
0005435104110	184F8B	2987 890266	VASILIY IVANOV	{"phone": "+70703892134"}
0005435104111	341155	0392 496595	IGOR DENISOV	{"phone": "+70353632733"}
0005435104112	341155	9807 027637	NIKITA BARANOV	{"email": "baranov_n_28041978@postgrespro.ru", "phone": "+70094298071"}
0005435104113	E13BFC	8407 005605	IRAIDA SOKOLOVA	{"phone": "+70256034030"}
0005435104114	EB27A2	2664 469276	LIDIYA PAVLOVA	{"email": "pavlova_lidiya.1978@postgrespro.ru", "phone": "+70546295525"}
0005435104115	16CD30	3991 907779	ELENA ROMANOVA	{"email": "elena.romanova_1966@postgrespro.ru", "phone": "+70786284242"}
0005435104116	16CD30	5043 902288	YULIYA NIKIFOROVA	{"email": "nikiforova_yuliya.1964@postgrespro.ru", "phone": "+70066598589"}
0005435104117	1228DF	1307 560391	NATALYA KUDRYASHOVA	{"phone": "+70394745171"}
0005435104118	B3C93C	5800 312130	NADEZHDA YAKOVLEVA	{"phone": "+70654637974"}
0005435104119	A63F34	7191 391658	IRINA NIKITINA	{"email": "nikitina-i-02111964@postgrespro.ru", "phone": "+70689442354"}
0005435104120	11465A	7708 828806	PETR KUZMIN	{"email": "pkuzmin26121972@postgrespro.ru", "phone": "+70560921667"}
0005435104121	11465A	9481 514963	TATYANA TROFIMOVA	{"phone": "+70796717303"}
0005435104122	6E1081	7353 470548	LYUDMILA KUZNECOVA	{"phone": "+70646492048"}
0005435104123	9028CC	7651 193527	OLGA AKIMOVA	{"phone": "+70246603630"}
0005435104124	9028CC	6736 979750	NATALYA ZHUKOVA	{"email": "natalya.zhukova_08011973@postgrespro.ru", "phone": "+70700040217"}
0005435104125	D2FA46	7491 405581	MARIYA MAKAROVA	{"phone": "+70318353519"}
0005435104126	BE6E9F	7742 805859	MARIYA IVANOVA	{"phone": "+70537294021"}
0005435104127	374729	5901 035507	OLGA KUZMINA	{"email": "o-kuzmina18041980@postgrespro.ru", "phone": "+70355716443"}
0005435104128	024650	7332 522558	ANNA MELNIKOVA	{"phone": "+70249426716"}
0005435104129	024650	3470 100434	EKATERINA VASILEVA	{"email": "ekaterina-vasileva.041969@postgrespro.ru", "phone": "+70682849458"}
0005435104130	56DB20	6872 852058	LYUDMILA TIMOFEEVA	{"email": "lyudmila-timofeeva_121972@postgrespro.ru", "phone": "+70287301321"}
0005435104131	56DB20	2034 248489	IVAN RODIONOV	{"email": "ivan-rodionov051978@postgrespro.ru", "phone": "+70107772657"}
0005435104132	5CFBB1	6744 640736	ALEKSANDR KUZNECOV	{"phone": "+70951915628"}
0005435104133	5CFBB1	8422 771318	PETR YAKOVLEV	{"phone": "+70947166333"}
0005435104134	6E17A9	3175 912508	TATYANA YAKOVLEVA	{"phone": "+70013419105"}
0005435104135	2613B4	7766 767502	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev-091976@postgrespro.ru", "phone": "+70611824070"}
0005435104136	7BB4B7	5932 554501	EVGENIY SOROKIN	{"email": "sorokin-evgeniy071969@postgrespro.ru", "phone": "+70313549037"}
0005435104137	5D8B7F	7940 505840	ALEKSANDR NIKITIN	{"phone": "+70725173275"}
0005435104138	769D93	0996 955032	SERGEY VOLKOV	{"phone": "+70392548207"}
0005435104139	929613	3882 128073	RAISA EGOROVA	{"phone": "+70473090483"}
0005435104140	8BA207	4922 843458	NADEZHDA IVANOVA	{"phone": "+70041762803"}
0005435104141	794564	3597 735142	EVGENIY RODIONOV	{"phone": "+70639460243"}
0005435104142	794564	9164 584300	ALEKSANDR EGOROV	{"email": "egorov.aleksandr-121978@postgrespro.ru", "phone": "+70843813731"}
0005435104143	9424F4	6251 788488	YANA FROLOVA	{"phone": "+70628345604"}
0005435104144	247ACC	8105 142315	VLADIMIR PETROV	{"phone": "+70551695593"}
0005435104145	247ACC	1506 533528	VALENTINA ZHURAVLEVA	{"email": "v.zhuravleva1968@postgrespro.ru", "phone": "+70982156433"}
0005435104146	FD6749	1027 817193	ANDREY IVANOV	{"email": "ivanov_a_071964@postgrespro.ru", "phone": "+70103700125"}
0005435104147	90D814	3695 029590	ELENA ZAKHAROVA	{"phone": "+70580682980"}
0005435104148	90D814	7801 168611	YURIY GERASIMOV	{"phone": "+70173952603"}
0005435104149	85A084	0756 210800	LIDIYA ZHUKOVA	{"email": "zhukovalidiya.1965@postgrespro.ru", "phone": "+70696361037"}
0005435104150	91199D	9143 223242	MIKHAIL BORISOV	{"phone": "+70268078566"}
0005435104151	91199D	8347 485895	ALEKSANDR SERGEEV	{"phone": "+70160497824"}
0005435104152	081B37	2826 610024	ROMAN TARASOV	{"email": "roman.tarasov1984@postgrespro.ru", "phone": "+70378599081"}
0005435104154	081B37	9061 389703	SVETLANA BELOVA	{"phone": "+70520916467"}
0005435104155	85C11F	0299 670758	RAISA EGOROVA	{"phone": "+70433198998"}
0005435104156	623ECF	3891 357256	YULIYA IVANOVA	{"email": "ivanova_y_1981@postgrespro.ru", "phone": "+70324993613"}
0005435104157	449CE4	2048 514625	NIKOLAY POPOV	{"email": "nikolay_popov13011971@postgrespro.ru", "phone": "+70041698488"}
0005435104158	449CE4	0782 115118	ANATOLIY ROMANOV	{"phone": "+70727099232"}
0005435104159	041F37	3712 763444	YULIYA KOLESNIKOVA	{"email": "kolesnikova-yuliya_031977@postgrespro.ru", "phone": "+70245436002"}
0005435104160	041F37	3450 932365	ELENA ZHUKOVA	{"email": "zhukova-elena.101973@postgrespro.ru", "phone": "+70816350340"}
0005435104161	6476F3	7120 221530	VALERIY ISAEV	{"email": "isaev.valeriy-1962@postgrespro.ru", "phone": "+70856277901"}
0005435104162	65CEE7	3175 410428	EVGENIY SMIRNOV	{"email": "evgeniysmirnov-111971@postgrespro.ru", "phone": "+70063577520"}
0005435104163	8CDE23	1556 244446	LYUDMILA KUZNECOVA	{"phone": "+70852622456"}
0005435104164	068E55	3423 546930	ELENA SEMENOVA	{"email": "semenovae_1978@postgrespro.ru", "phone": "+70866964887"}
0005435104165	7EECCE	4488 625076	VASILIY MIRONOV	{"phone": "+70396532188"}
0005435104166	39284A	0753 458001	ANNA FROLOVA	{"phone": "+70353258873"}
0005435104167	39284A	7338 854427	GENNADIY MAKAROV	{"email": "makarovgennadiy.20111976@postgrespro.ru", "phone": "+70689195731"}
0005435104168	BFF5E3	6743 132793	SVETLANA LAZAREVA	{"email": "svetlanalazareva.10061982@postgrespro.ru", "phone": "+70660715239"}
0005435104169	BFF5E3	4885 867378	DIANA CHERNOVA	{"email": "chernova_diana1982@postgrespro.ru", "phone": "+70137623141"}
0005435104170	E40C96	2729 098106	NADEZHDA BARANOVA	{"email": "baranovan_29101969@postgrespro.ru", "phone": "+70420972959"}
0005435104171	F0E4F1	8213 374658	ELENA MASLOVA	{"email": "maslova.e.011977@postgrespro.ru", "phone": "+70880534933"}
0005435104172	F0E4F1	0876 033458	PAVEL IVANOV	{"email": "ivanov_pavel-1978@postgrespro.ru", "phone": "+70767146641"}
0005435104173	BEA064	6607 594813	ANDREY NIKITIN	{"phone": "+70774786220"}
0005435104174	46FBA5	1869 231460	ALEKSANDR FROLOV	{"email": "frolov.aleksandr1968@postgrespro.ru", "phone": "+70670511237"}
0005435104175	593452	3014 391968	VLADISLAV FEDOROV	{"email": "vladislav.fedorov21051963@postgrespro.ru", "phone": "+70674528565"}
0005435104176	ADD778	9075 532259	ANASTASIYA NIKITINA	{"email": "nikitina-a_1972@postgrespro.ru", "phone": "+70196068129"}
0005435104177	ADD778	9362 134006	ARTEM ALEKSEEV	{"email": "alekseev.a.1971@postgrespro.ru", "phone": "+70085470631"}
0005435104178	EDF164	6818 622498	LIDIYA OVCHINNIKOVA	{"email": "l-ovchinnikova.021968@postgrespro.ru", "phone": "+70715058414"}
0005435104179	EDF164	9388 794074	SVETLANA GUSEVA	{"email": "gusevasvetlana_091975@postgrespro.ru", "phone": "+70858097516"}
0005435104180	EDF164	4178 169633	IRINA PETROVA	{"email": "irina.petrova101969@postgrespro.ru", "phone": "+70483910569"}
0005435104181	B9360A	6992 627058	VERA MAKAROVA	{"phone": "+70681536598"}
0005435104182	07D6C6	0381 014055	ARTEM DENISOV	{"email": "denisov_artem24041972@postgrespro.ru", "phone": "+70608819589"}
0005435104183	E36A3F	0753 753684	EKATERINA PETROVA	{"email": "petrova-e-021971@postgrespro.ru", "phone": "+70454804211"}
0005435104184	92A537	8885 509824	TATYANA YAKOVLEVA	{"email": "yakovleva-t051975@postgrespro.ru", "phone": "+70839410654"}
0005435104185	119974	3236 538623	IRINA SERGEEVA	{"email": "sergeeva.irina_1967@postgrespro.ru", "phone": "+70465884302"}
0005435104186	AD6F39	5498 141195	SERGEY NIKITIN	{"email": "nikitin-s-1962@postgrespro.ru", "phone": "+70256843481"}
0005435104187	7B29B5	9845 150895	LIDIYA GUSEVA	{"email": "lguseva.29121958@postgrespro.ru", "phone": "+70827825049"}
0005435104188	7B29B5	6778 739817	SERGEY IVANOV	{"phone": "+70190968061"}
0005435104189	959E5F	7863 732445	ELENA YUDINA	{"email": "yudina_elena_1971@postgrespro.ru", "phone": "+70561681164"}
0005435104190	959E5F	4030 038067	ANNA SCHERBAKOVA	{"phone": "+70456470733"}
0005435104191	506A5B	1612 917696	GEORGIY IVANOV	{"email": "g.ivanov-23051975@postgrespro.ru", "phone": "+70829464183"}
0005435104192	506A5B	9633 977444	VLADIMIR TIKHONOV	{"email": "v-tikhonov111974@postgrespro.ru", "phone": "+70483265840"}
0005435104193	E6CCD3	0391 829507	ANDREY ORLOV	{"phone": "+70664139542"}
0005435104194	BFD4DF	2142 803468	SERGEY TIMOFEEV	{"phone": "+70023447282"}
0005435104195	E34EFD	7003 783571	ANNA ZHUKOVA	{"email": "zhukova-a-101968@postgrespro.ru", "phone": "+70277421224"}
0005435104196	E34EFD	4102 931052	VIKTOR DAVYDOV	{"email": "vdavydov_021961@postgrespro.ru", "phone": "+70113828890"}
0005435104197	A10DC4	4854 018417	ALLA MOROZOVA	{"phone": "+70313687437"}
0005435104198	A10DC4	6053 092510	VITALIY SCHERBAKOV	{"phone": "+70307069041"}
0005435104199	94A695	4923 863957	OLGA EGOROVA	{"email": "egorova.olga_1967@postgrespro.ru", "phone": "+70104469590"}
0005435104200	75D27F	0225 507617	VALENTINA KOZLOVA	{"phone": "+70446781772"}
0005435104201	75D27F	7999 392397	ANASTASIYA MATVEEVA	{"phone": "+70528548158"}
0005435104202	2B8A08	7950 536127	TATYANA DENISOVA	{"phone": "+70799095001"}
0005435104203	2B8A08	2775 403005	VLADIMIR GERASIMOV	{"email": "gerasimov-v_121975@postgrespro.ru", "phone": "+70458592085"}
0005435104204	5F42D8	2220 406351	ANNA POPOVA	{"email": "a-popova_19071974@postgrespro.ru", "phone": "+70200436867"}
0005435104205	5F42D8	9925 157588	ANATOLIY YAKOVLEV	{"email": "anatoliy-yakovlev14121993@postgrespro.ru", "phone": "+70193520162"}
0005435104206	5F42D8	0153 966378	MAKSIM ORLOV	{"email": "orlov-m-1962@postgrespro.ru", "phone": "+70405526904"}
0005435104207	0C7D87	1358 840631	SERGEY IVANOV	{"phone": "+70068097904"}
0005435104208	17447C	4681 364039	ANASTASIYA VOROBEVA	{"email": "a_vorobeva_1983@postgrespro.ru", "phone": "+70723487966"}
0005435104209	E24037	9742 523847	VLADIMIR SAVELEV	{"phone": "+70811719885"}
0005435104210	9D9098	1498 163167	MARIYA SMIRNOVA	{"email": "mariya.smirnova23101987@postgrespro.ru", "phone": "+70778958100"}
0005435104211	9D9098	7795 181117	YURIY IVANOV	{"email": "y_ivanov.1965@postgrespro.ru", "phone": "+70989914724"}
0005435104212	2EAA0B	2846 847409	TATYANA FILATOVA	{"email": "filatova_tatyana.07121972@postgrespro.ru", "phone": "+70220933557"}
0005435104213	0D0AA4	0465 865151	OKSANA VASILEVA	{"email": "vasilevaoksana-081969@postgrespro.ru", "phone": "+70060228811"}
0005435104214	B04FA9	7730 895222	LYUDMILA PAVLOVA	{"email": "lyudmila_pavlova_031971@postgrespro.ru", "phone": "+70061348506"}
0005435104215	35738C	3289 186184	YURIY ANTONOV	{"email": "antonov.y_1976@postgrespro.ru", "phone": "+70876673450"}
0005435104216	E069E9	3094 629746	OLGA GORBUNOVA	{"email": "o-gorbunova-09011965@postgrespro.ru", "phone": "+70157462670"}
0005435104217	E069E9	5016 129249	ELENA YAKOVLEVA	{"phone": "+70437056077"}
0005435104218	9F3A9E	7748 808575	NIKOLAY KUZNECOV	{"phone": "+70389238448"}
0005435104219	9F3A9E	8900 672862	MIKHAIL FOMIN	{"email": "fominm-16031974@postgrespro.ru", "phone": "+70887762086"}
0005435104220	7E5F93	3527 232386	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir07121975@postgrespro.ru", "phone": "+70502340144"}
0005435104221	7E5F93	8206 620651	DMITRIY MOISEEV	{"email": "d.moiseev-081964@postgrespro.ru", "phone": "+70734916287"}
0005435104222	7E5F93	8968 087513	NATALYA MEDVEDEVA	{"email": "medvedeva_n14051965@postgrespro.ru", "phone": "+70260959433"}
0005435104223	57E7B2	0962 353511	IRINA LEBEDEVA	{"phone": "+70250199876"}
0005435104224	E91EFA	9206 994708	SERGEY MAKAROV	{"phone": "+70632852771"}
0005435104225	0AF15B	2795 929627	LYUBOV KAZAKOVA	{"phone": "+70331308315"}
0005435104226	0AF15B	6741 946479	GALINA NESTEROVA	{"email": "nesterova_g16061960@postgrespro.ru", "phone": "+70627582726"}
0005435104227	984C8E	3995 461036	KONSTANTIN SCHERBAKOV	{"email": "konstantin_scherbakov20061980@postgrespro.ru", "phone": "+70044902258"}
0005435104228	3FA1C5	4793 542762	RAVIL VOLKOV	{"phone": "+70866613671"}
0005435104229	66B02A	7593 102207	GALINA VASILEVA	{"phone": "+70165173336"}
0005435104230	4DE9B0	3451 730185	VIKTORIYA SOKOLOVA	{"email": "sokolova_viktoriya.111971@postgrespro.ru", "phone": "+70977410267"}
0005435104231	4DE9B0	8956 002311	NATALYA ZHUKOVA	{"email": "natalya_zhukova_021960@postgrespro.ru", "phone": "+70122337719"}
0005435104232	57BE88	9332 753974	ARTEM GERASIMOV	{"phone": "+70525904764"}
0005435104233	E4A4E4	6490 767577	TATYANA FILATOVA	{"email": "t.filatova_15101973@postgrespro.ru", "phone": "+70701760090"}
0005435104234	E4A4E4	9981 726785	LARISA SMIRNOVA	{"email": "larisa.smirnova-1978@postgrespro.ru", "phone": "+70520131679"}
0005435104235	6DE66C	8046 230139	EKATERINA NIKIFOROVA	{"phone": "+70241430604"}
0005435104236	6DE66C	1756 384819	ANDREY SCHERBAKOV	{"email": "scherbakov_a.071971@postgrespro.ru", "phone": "+70082505124"}
0005435104237	B13986	9779 458314	LIDIYA MIKHAYLOVA	{"email": "lidiya_mikhaylova-29111979@postgrespro.ru", "phone": "+70386924645"}
0005435104238	B13986	7247 841644	NADEZHDA FOMINA	{"phone": "+70366219823"}
0005435104239	F2F1D6	6887 642179	ALEKSANDRA KISELEVA	{"email": "kiseleva_a.011975@postgrespro.ru", "phone": "+70995638743"}
0005435104240	F2F1D6	5353 082890	ALFIYA MEDVEDEVA	{"phone": "+70974304806"}
0005435104241	F2F1D6	5017 987228	ALISA ZHURAVLEVA	{"email": "alisa.zhuravleva1971@postgrespro.ru", "phone": "+70625262156"}
0005435104242	F2F1D6	5937 805590	IVAN ALEKSEEV	{"email": "alekseev-ivan1970@postgrespro.ru", "phone": "+70528705970"}
0005435104243	F12411	2638 493591	ALISA ISAEVA	{"email": "isaeva-a.101972@postgrespro.ru", "phone": "+70975511606"}
0005435104244	F12411	9496 564178	DMITRIY SHEVCHENKO	{"phone": "+70722061803"}
0005435104245	746906	5151 980007	EKATERINA PAVLOVA	{"email": "pavlova-ekaterina_13031968@postgrespro.ru", "phone": "+70533231057"}
0005435104246	E22E73	6141 388775	KSENIYA IVANOVA	{"phone": "+70532430429"}
0005435104247	E22E73	1642 423403	SVETLANA NIKITINA	{"email": "snikitina.25101971@postgrespro.ru", "phone": "+70299983902"}
0005435104248	E22E73	3815 441350	VADIM TARASOV	{"email": "tarasov-v1978@postgrespro.ru", "phone": "+70336650832"}
0005435104249	E22E73	4523 316873	FATIMA FILIPPOVA	{"email": "ffilippova.20111963@postgrespro.ru", "phone": "+70152937039"}
0005435104250	4323C8	2754 617976	MARIYA EGOROVA	{"email": "m_egorova.081966@postgrespro.ru", "phone": "+70779781370"}
0005435104251	F4646F	5706 654797	EVGENIY GAVRILOV	{"email": "gavrilov.e-06011966@postgrespro.ru", "phone": "+70939925593"}
0005435104252	AA859F	2291 927928	DENIS NIKITIN	{"email": "nikitin.d041961@postgrespro.ru", "phone": "+70575377387"}
0005435104253	BAFB3D	2519 136740	ELENA FOMINA	{"phone": "+70818370636"}
0005435104254	0400E5	7596 742003	NAILYA ANTONOVA	{"email": "antonovanailya-1965@postgrespro.ru", "phone": "+70136419068"}
0005435104255	0400E5	7915 849987	NATALYA KONDRATEVA	{"email": "natalyakondrateva091972@postgrespro.ru", "phone": "+70696621609"}
0005435104256	0400E5	1131 123314	DENIS MELNIKOV	{"phone": "+70363864615"}
0005435104257	D99BB1	0157 478836	NINA TARASOVA	{"phone": "+70008904679"}
0005435104258	3F1472	6835 255614	OLGA KONDRATEVA	{"phone": "+70869610573"}
0005435104259	3F1472	8570 356843	MAKSIM MELNIKOV	{"phone": "+70247106267"}
0005435104260	4FC657	5662 713376	VALENTINA FADEEVA	{"phone": "+70057809531"}
0005435104261	1115D1	1589 953317	VLADIMIR POPOV	{"email": "popovv1976@postgrespro.ru", "phone": "+70604463207"}
0005435104262	1115D1	7720 178733	NATALYA ROMANOVA	{"phone": "+70010731887"}
0005435104263	3E081F	9810 084485	IVAN KUZNECOV	{"phone": "+70431651248"}
0005435104264	3E081F	2617 341027	VYACHESLAV ANTONOV	{"email": "v_antonov-031972@postgrespro.ru", "phone": "+70375751448"}
0005435104265	23983D	7074 041172	PAVEL GUSEV	{"phone": "+70099092607"}
0005435104266	F9441B	9499 769584	NATALYA PETROVA	{"phone": "+70121745657"}
0005435104267	64E49D	1495 988910	GALINA DAVYDOVA	{"phone": "+70615921890"}
0005435104268	64E49D	6395 653941	ALEKSEY ANDREEV	{"phone": "+70947851572"}
0005435104269	9C40E9	3109 977191	VALENTINA DENISOVA	{"phone": "+70507050271"}
0005435104270	815D00	6276 535778	ALEKSANDR FROLOV	{"email": "aleksandr-frolov1963@postgrespro.ru", "phone": "+70290838212"}
0005435104271	815D00	8210 383127	MARINA MALYSHEVA	{"email": "m.malysheva.1963@postgrespro.ru", "phone": "+70846543623"}
0005435104272	2C2199	1286 079149	NATALYA SOROKINA	{"email": "natalya.sorokina_1971@postgrespro.ru", "phone": "+70164273958"}
0005435104273	8C8A71	2589 180680	NATALIYA SOKOLOVA	{"email": "sokolova-n.1959@postgrespro.ru", "phone": "+70359973253"}
0005435104274	8C8A71	9360 325992	VYACHESLAV SOROKIN	{"email": "v.sorokin-1981@postgrespro.ru", "phone": "+70194656747"}
0005435104275	1BF2CB	6094 272089	MARIYA ALEKSEEVA	{"phone": "+70019594057"}
0005435104276	1BF2CB	5865 452306	ALENA VLASOVA	{"email": "avlasova_20091966@postgrespro.ru", "phone": "+70947565061"}
0005435104277	D08B0A	4878 692349	FATIMA OSIPOVA	{"email": "osipova_fatima-1966@postgrespro.ru", "phone": "+70736137382"}
0005435104278	D08B0A	0774 541639	ANDREY FEDOROV	{"email": "fedorovandrey_29041962@postgrespro.ru", "phone": "+70581495391"}
0005435104279	E1366E	4460 785462	VLADIMIR ZAKHAROV	{"email": "v_zakharov-31121964@postgrespro.ru", "phone": "+70294920060"}
0005435104280	8F7964	4782 873308	VALERIY BORISOV	{"email": "valeriy-borisov09071968@postgrespro.ru", "phone": "+70078423970"}
0005435104281	45E326	6860 951431	ARTEM SHEVCHENKO	{"email": "shevchenko.artem_02111978@postgrespro.ru", "phone": "+70939064776"}
0005435104282	25DAB0	8700 424871	LYUDMILA ERMAKOVA	{"email": "ermakova_l.09101971@postgrespro.ru", "phone": "+70946191507"}
0005435104283	731758	8919 899249	ANISA IVANOVA	{"email": "aivanova_081976@postgrespro.ru", "phone": "+70219348753"}
0005435104284	731758	4659 478744	ALEKSANDR VASILEV	{"email": "a-vasilev-121970@postgrespro.ru", "phone": "+70609452262"}
0005435104285	E0A314	2077 985425	AMIR KONOVALOV	{"email": "akonovalov.081965@postgrespro.ru", "phone": "+70516288500"}
0005435104286	0844AA	2067 429344	RAISA BOGDANOVA	{"phone": "+70293688671"}
0005435104287	01B644	2700 212681	IRINA EFREMOVA	{"email": "i_efremova17041965@postgrespro.ru", "phone": "+70530873423"}
0005435104288	6933FD	2804 649259	IVAN KUZNECOV	{"email": "kuznecov-i-1985@postgrespro.ru", "phone": "+70554472234"}
0005435104289	7085F2	5352 099680	DMITRIY NAZAROV	{"email": "dmitriy_nazarov_28121962@postgrespro.ru", "phone": "+70821551460"}
0005435104290	195A79	6270 764329	ELENA NIKITINA	{"email": "nikitina_elena29021968@postgrespro.ru", "phone": "+70743514284"}
0005435104291	937335	8176 757583	MAKSIM DENISOV	{"email": "mdenisov1969@postgrespro.ru", "phone": "+70384482320"}
0005435104292	D8581F	0895 513215	IGOR BARANOV	{"phone": "+70303258742"}
0005435104293	E3A3A2	7039 115368	RAISA GAVRILOVA	{"phone": "+70666328326"}
0005435104294	AD2E97	9051 975456	ELENA FILATOVA	{"email": "filatovaelena_1975@postgrespro.ru", "phone": "+70189747267"}
0005435104295	AD2E97	0262 987919	SVETLANA FILIPPOVA	{"email": "filippovasvetlana-23011963@postgrespro.ru", "phone": "+70661127080"}
0005435104296	AD2E97	3953 182700	ELENA GORBUNOVA	{"email": "e.gorbunova-111969@postgrespro.ru", "phone": "+70270656247"}
0005435104297	199573	9839 041658	ALEKSEY MAKAROV	{"phone": "+70013722001"}
0005435104298	B9A2DB	9467 937206	LARISA KRASNOVA	{"phone": "+70786213272"}
0005435104299	CEA43F	9480 165062	VLADIMIR DMITRIEV	{"email": "dmitriev.v_02071972@postgrespro.ru", "phone": "+70600944870"}
0005435104300	740020	9551 988369	ALEKSEY SERGEEV	{"email": "sergeev_aleksey-21021963@postgrespro.ru", "phone": "+70979794441"}
0005435104301	CFDAA0	5625 271482	ALEKSANDR MELNIKOV	{"phone": "+70325131751"}
0005435104302	85240F	2654 069880	ARINA MOROZOVA	{"phone": "+70457764199"}
0005435104303	633B34	8054 486367	NATALYA KALININA	{"email": "kalinina_natalya_1988@postgrespro.ru", "phone": "+70651801481"}
0005435104304	EA1723	2650 131880	DARYA NIKIFOROVA	{"phone": "+70914926230"}
0005435104305	2B0BDB	8920 733082	SERGEY RODIONOV	{"email": "rodionovsergey-1977@postgrespro.ru", "phone": "+70702501041"}
0005435104306	BFCF82	0904 252029	VASILIY MATVEEV	{"email": "v.matveev021974@postgrespro.ru", "phone": "+70753012082"}
0005435104307	EDF09E	9043 118171	ALEKSANDR ISAEV	{"email": "isaev_aleksandr-081977@postgrespro.ru", "phone": "+70218346332"}
0005435104308	3D15A5	5604 923299	SERGEY KONOVALOV	{"phone": "+70835757088"}
0005435104309	60B9C7	4262 765071	ALEKSEY KUZNECOV	{"email": "kuznecova_031968@postgrespro.ru", "phone": "+70805364270"}
0005435104310	CA5D40	8876 892548	DARYA MOROZOVA	{"phone": "+70243843047"}
0005435104311	40E31B	3696 534504	YANA VASILEVA	{"phone": "+70434103657"}
0005435104312	40E31B	4538 221738	VALENTINA DMITRIEVA	{"email": "dmitrievavalentina_1975@postgrespro.ru", "phone": "+70371945598"}
0005435104313	7D9A4D	0171 936795	DMITRIY NIKOLAEV	{"phone": "+70472324459"}
0005435104314	423945	0496 718747	DENIS POPOV	{"phone": "+70375689507"}
0005435104315	7A61F4	9596 561168	ALEKSANDR KULIKOV	{"phone": "+70412440962"}
0005435104316	7A61F4	9420 924836	GALINA KUZMINA	{"phone": "+70901106543"}
0005435104317	7C19D2	0997 959174	MARINA VOROBEVA	{"email": "marina-vorobeva-17051971@postgrespro.ru", "phone": "+70633809023"}
0005435104318	D84358	4416 066616	LYUDMILA BELOVA	{"phone": "+70952567208"}
0005435104319	3F5F6E	8674 861636	KSENIYA BELOVA	{"email": "kseniya.belova-28041975@postgrespro.ru", "phone": "+70482410311"}
0005435104320	8B7E3D	5037 464869	NIKITA VLASOV	{"phone": "+70146565838"}
0005435104321	5511BB	0221 137692	IRINA ZAKHAROVA	{"phone": "+70601291526"}
0005435104322	E0637C	4003 589625	KRISTINA SCHERBAKOVA	{"phone": "+70439716681"}
0005435104323	571A64	8663 349324	LYUDMILA KULIKOVA	{"email": "l-kulikova-061968@postgrespro.ru", "phone": "+70140519812"}
0005435104324	D52ED4	5189 679291	MIKHAIL SIDOROV	{"phone": "+70207002557"}
0005435104325	35CDDA	9610 583608	VLADISLAV MOROZOV	{"email": "morozov.vladislav-1965@postgrespro.ru", "phone": "+70095900622"}
0005435104326	421254	6666 955319	SERGEY GORBUNOV	{"phone": "+70352638352"}
0005435104327	421254	9545 049020	SVETLANA ZAKHAROVA	{"phone": "+70234718401"}
0005435104328	A0EB07	4564 563207	GALINA FROLOVA	{"email": "frolova_galina.16021962@postgrespro.ru", "phone": "+70379797766"}
0005435104329	F51B6E	8990 057958	NIKOLAY ANDREEV	{"phone": "+70658620468"}
0005435104330	F51B6E	4898 912670	SVETLANA SAVELEVA	{"email": "saveleva.svetlana_03061971@postgrespro.ru", "phone": "+70673524167"}
0005435104331	DFB399	5791 148094	VALERIY POPOV	{"email": "popovv.17021971@postgrespro.ru", "phone": "+70413400587"}
0005435104332	DFB399	7609 914491	ANATOLIY POPOV	{"email": "a_popov-08121959@postgrespro.ru", "phone": "+70750784787"}
0005435104333	773A0D	2288 717447	EKATERINA BOGDANOVA	{"email": "ekaterina-bogdanova_29021960@postgrespro.ru", "phone": "+70715260730"}
0005435104334	E5E32F	9508 766767	NADEZHDA VASILEVA	{"phone": "+70002000066"}
0005435104335	7EDD16	2340 879724	PETR SCHERBAKOV	{"email": "p-scherbakov091974@postgrespro.ru", "phone": "+70604871400"}
0005435104336	B21E56	9643 626121	MARIYA ANTONOVA	{"email": "m-antonova.01021975@postgrespro.ru", "phone": "+70532430305"}
0005435104337	B21E56	6685 909269	ALEKSANDR FOMIN	{"phone": "+70675186932"}
0005435104338	CDD2E8	1720 370336	VADIM KUZNECOV	{"email": "v_kuznecov-09121974@postgrespro.ru", "phone": "+70309336783"}
0005435104339	C34F65	2826 177918	LYUBOV ALEKSANDROVA	{"email": "aleksandrovalyubov.08041960@postgrespro.ru", "phone": "+70553574126"}
0005435104340	AE66D4	8277 206106	KSENIYA MAKAROVA	{"email": "makarova_kseniya-07051978@postgrespro.ru", "phone": "+70034851370"}
0005435104341	AE66D4	3343 519038	MIKHAIL IVANOV	{"email": "ivanov.mikhail1963@postgrespro.ru", "phone": "+70230075830"}
0005435104342	67BCDD	2455 605030	SERGEY SEMENOV	{"email": "semenov_s_111971@postgrespro.ru", "phone": "+70779149185"}
0005435104343	A9F8D9	8263 053040	OKSANA KOZLOVA	{"email": "o-kozlova1961@postgrespro.ru", "phone": "+70652223665"}
0005435104344	98CA7F	5406 599534	DMITRIY ALEKSEEV	{"email": "d-alekseev.031972@postgrespro.ru", "phone": "+70745764356"}
0005435104345	956F83	7112 557017	GENNADIY SOKOLOV	{"phone": "+70738814016"}
0005435104346	3C88E6	8728 660759	ALEKSANDR ABRAMOV	{"phone": "+70116006546"}
0005435104347	FA3023	7765 027204	PETR GAVRILOV	{"email": "petrgavrilov-1972@postgrespro.ru", "phone": "+70685941067"}
0005435104348	FA3023	2516 927103	LYUDMILA KUDRYASHOVA	{"phone": "+70328159640"}
0005435104349	6BC27C	8949 881732	OLESYA MOISEEVA	{"email": "moiseeva_o-091974@postgrespro.ru", "phone": "+70283609731"}
0005435104350	2A6F06	7281 428348	PAVEL FOMIN	{"email": "pavel_fomin.04091974@postgrespro.ru", "phone": "+70296482913"}
0005435104351	2A6F06	5403 204885	VALERIY BORISOV	{"phone": "+70062731572"}
0005435104352	0F3B0E	9532 531197	NATALYA YUDINA	{"email": "n-yudina.1973@postgrespro.ru", "phone": "+70682912200"}
0005435104353	BDB776	0108 231422	BORIS STEPANOV	{"phone": "+70522692016"}
0005435104354	C0856E	8723 203381	NIKITA SOROKIN	{"email": "nikita.sorokin.081978@postgrespro.ru", "phone": "+70113919088"}
0005435104355	C0856E	5825 917746	YURIY CHERNOV	{"email": "ychernov_081971@postgrespro.ru", "phone": "+70274244741"}
0005435104356	9AA4FD	8852 649281	VLADIMIR DMITRIEV	{"phone": "+70776228925"}
0005435104357	9AA4FD	2994 724152	VLADIMIR VOLKOV	{"email": "volkov_v-1971@postgrespro.ru", "phone": "+70801935674"}
0005435104358	1FF6BE	0679 005644	IRINA KAZAKOVA	{"phone": "+70965405562"}
0005435104359	098FCD	2455 738767	DENIS SCHERBAKOV	{"email": "scherbakov_d_061980@postgrespro.ru", "phone": "+70430603020"}
0005435104360	098FCD	9465 560953	VLADIMIR KRASNOV	{"email": "vladimir_krasnov_1981@postgrespro.ru", "phone": "+70210049276"}
0005435104361	DBFB11	4728 114670	IVAN ANTONOV	{"email": "i.antonov.071975@postgrespro.ru", "phone": "+70868512059"}
0005435104362	3BB8C5	1338 982933	DMITRIY ZHURAVLEV	{"phone": "+70038466897"}
0005435104363	3BB8C5	9400 287761	ALEKSANDR KOZLOV	{"phone": "+70476843203"}
0005435104364	3BB8C5	7748 017275	SERGEY ABRAMOV	{"phone": "+70530827450"}
0005435104365	C3212F	2165 091115	VIKTOR YAKOVLEV	{"email": "yakovlevviktor-101974@postgrespro.ru", "phone": "+70749223177"}
0005435104366	88B0B6	2988 294929	EVGENIY NAUMOV	{"phone": "+70531994269"}
0005435104367	77F51B	0014 824237	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev_051971@postgrespro.ru", "phone": "+70491492883"}
0005435104368	49A07C	5235 011297	ANATOLIY KUZNECOV	{"phone": "+70750284720"}
0005435104369	96A674	0697 653561	VLADIMIR ORLOV	{"email": "orlov_vladimir.041960@postgrespro.ru", "phone": "+70680040167"}
0005435104370	EA4EC3	0183 621780	IRINA NOVIKOVA	{"email": "novikovai_081971@postgrespro.ru", "phone": "+70693865669"}
0005435104371	EA4EC3	9672 975601	NIKOLAY KULIKOV	{"phone": "+70717144932"}
0005435104372	EA4EC3	2230 281895	DENIS NOVIKOV	{"phone": "+70657494769"}
0005435104373	086BC3	9175 047752	VALENTINA SAVELEVA	{"email": "v.saveleva_031975@postgrespro.ru", "phone": "+70557912726"}
0005435104374	FB7124	5503 902902	DMITRIY GRIGOREV	{"email": "grigorevdmitriy_1972@postgrespro.ru", "phone": "+70192919296"}
0005435104375	454606	4886 405347	NATALYA BORISOVA	{"phone": "+70483647854"}
0005435104376	FC5BEA	0375 214161	LYUDMILA KOZLOVA	{"email": "kozlova-l_1976@postgrespro.ru", "phone": "+70252130387"}
0005435104377	6167F9	1993 852255	ALEKSANDR KONOVALOV	{"phone": "+70717188828"}
0005435104378	BCAEE7	9864 320050	ANATOLIY NIKOLAEV	{"email": "anikolaev.031968@postgrespro.ru", "phone": "+70305909340"}
0005435104379	169028	8180 383892	MARINA MAKAROVA	{"phone": "+70510096237"}
0005435104380	EC7A0D	5573 033234	VITALIY ISAEV	{"phone": "+70281309364"}
0005435104381	3175D3	5974 124966	PAVEL EGOROV	{"phone": "+70336480691"}
0005435104382	98A7F7	2213 170397	LYUDMILA ZAKHAROVA	{"email": "zakharova.lyudmila31101968@postgrespro.ru", "phone": "+70183819944"}
0005435104383	98A7F7	6052 439203	NINA ZAYCEVA	{"email": "zaycevan-041977@postgrespro.ru", "phone": "+70676107260"}
0005435104384	125AD5	6105 282726	LYUDMILA KARPOVA	{"email": "l_karpova-07081974@postgrespro.ru", "phone": "+70067564707"}
0005435126024	8E1DFF	1458 013289	ANASTASIYA ALEKSANDROVA	{"phone": "+70698963179"}
0005435104385	093A09	2708 682354	GULSINA EGOROVA	{"email": "egorovagulsina.1975@postgrespro.ru", "phone": "+70776073983"}
0005435104386	093A09	6847 369021	ANNA MAKAROVA	{"phone": "+70561120164"}
0005435104387	093A09	0250 002133	VALENTINA RODIONOVA	{"phone": "+70395791798"}
0005435104388	2E9061	6592 007756	ALEKSANDR IVANOV	{"phone": "+70835688266"}
0005435104389	2E9061	8620 293239	TIMOFEY NIKOLAEV	{"phone": "+70606136184"}
0005435105923	6287D5	5299 183792	MIKHAIL BORISOV	{"email": "borisov-mikhail_01101980@postgrespro.ru", "phone": "+70599505786"}
0005435105924	6287D5	8608 895033	ANNA KUZMINA	{"email": "kuzminaa091971@postgrespro.ru", "phone": "+70851322128"}
0005435105925	6287D5	3386 225928	SVETLANA VOROBEVA	{"email": "vorobeva_s071971@postgrespro.ru", "phone": "+70692815552"}
0005435105926	05B64E	2731 965146	DIANA LUKYANOVA	{"phone": "+70109355053"}
0005435105927	FC94AE	9800 691515	IGOR SOLOVEV	{"phone": "+70652671703"}
0005435105928	8478D6	1913 146691	SVETLANA ALEKSEEVA	{"email": "svetlana.alekseeva-081972@postgrespro.ru", "phone": "+70707403889"}
0005435105929	8478D6	7435 566263	VALENTINA GUSEVA	{"phone": "+70835253428"}
0005435105930	1C0756	2994 308155	VALENTINA PETROVA	{"phone": "+70071302874"}
0005435105931	E835E8	3623 222284	LIDIYA NIKIFOROVA	{"phone": "+70146453873"}
0005435105932	4ED94B	6356 249426	ROMAN KARPOV	{"phone": "+70409263184"}
0005435105933	935DE7	7418 437858	NATALYA KRASNOVA	{"phone": "+70600673931"}
0005435105934	B456A3	2757 513641	TATYANA DAVYDOVA	{"email": "tatyana.davydova_011975@postgrespro.ru", "phone": "+70280923305"}
0005435105935	9E4E8C	1646 909987	TATYANA MELNIKOVA	{"email": "melnikovat21041964@postgrespro.ru", "phone": "+70844187549"}
0005435105936	9E4E8C	9998 859408	ELENA PETROVA	{"phone": "+70581690314"}
0005435105937	D5CB90	9483 359896	YURIY IVANOV	{"phone": "+70795588670"}
0005435105938	0A0BBA	7449 176212	ANNA KOVALEVA	{"phone": "+70204415806"}
0005435105939	3FFAF9	7172 004338	MARIYA PAVLOVA	{"phone": "+70325922741"}
0005435105940	8B370B	3131 815120	VLADIMIR NIKOLAEV	{"phone": "+70865340588"}
0005435105941	F699F4	1515 290549	SNEZHANA KUZMINA	{"email": "kuzmina_s_14111959@postgrespro.ru", "phone": "+70542276756"}
0005435105942	F699F4	1669 625269	DARYA PETROVA	{"phone": "+70722882397"}
0005435105943	F699F4	9748 199382	NINA KUZNECOVA	{"phone": "+70488727724"}
0005435105944	76A29C	3401 252222	DMITRIY SEMENOV	{"phone": "+70682844478"}
0005435105945	277DDE	7594 387827	KLAVDIYA KUDRYASHOVA	{"email": "k-kudryashova-061966@postgrespro.ru", "phone": "+70362965451"}
0005435105946	277DDE	5983 402511	YULIYA RODIONOVA	{"phone": "+70695781683"}
0005435105947	277DDE	7514 362685	SVETLANA FOMINA	{"email": "sfomina.1981@postgrespro.ru", "phone": "+70289404217"}
0005435105948	496E98	8126 750483	NINA MAKSIMOVA	{"phone": "+70507377056"}
0005435105949	CE6918	4240 259790	ANDREY VOLKOV	{"phone": "+70920444724"}
0005435105950	CE6918	5419 532880	MIKHAIL POPOV	{"phone": "+70428011472"}
0005435105951	A1B45D	7933 671443	ELENA MASLOVA	{"phone": "+70853967392"}
0005435105952	A1B45D	6822 636463	VARVARA FEDOROVA	{"phone": "+70219790677"}
0005435105953	C28B21	1274 259250	OKSANA ROMANOVA	{"phone": "+70666220920"}
0005435105954	718CC4	0610 391371	LYUDMILA MELNIKOVA	{"phone": "+70336362947"}
0005435105955	924516	8594 684762	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin_021980@postgrespro.ru", "phone": "+70979108476"}
0005435105956	5EA6F4	7254 826561	RINAT MEDVEDEV	{"email": "medvedev.r-29091971@postgrespro.ru", "phone": "+70261666827"}
0005435105957	E5BCB2	2490 328116	OLGA MELNIKOVA	{"email": "o.melnikova-071972@postgrespro.ru", "phone": "+70987301612"}
0005435105958	E5BCB2	5196 241925	YANA KOROLEVA	{"email": "yana.koroleva1972@postgrespro.ru", "phone": "+70513599218"}
0005435105959	FF6C86	6159 509291	ANASTASIYA VLASOVA	{"email": "a.vlasova_1983@postgrespro.ru", "phone": "+70776447246"}
0005435105960	040310	7667 840505	ELENA NAZAROVA	{"email": "e.nazarova_051966@postgrespro.ru", "phone": "+70654303764"}
0005435105961	040310	4815 359444	MARIYA ZAKHAROVA	{"email": "mariya_zakharova14041974@postgrespro.ru", "phone": "+70743472480"}
0005435105962	0E199E	3551 829494	PAVEL KUZNECOV	{"phone": "+70069415435"}
0005435105963	DCBBDD	2507 302053	ANTON PAVLOV	{"phone": "+70846968449"}
0005435105964	60B146	2914 272817	ANDREY OSIPOV	{"phone": "+70477625849"}
0005435105965	47C51A	4953 512924	LYUBOV SIDOROVA	{"phone": "+70154219443"}
0005435105966	47C51A	1795 511694	TATYANA DAVYDOVA	{"email": "davydova.tatyana_1964@postgrespro.ru", "phone": "+70268203161"}
0005435105967	B42A50	0836 383154	SERGEY PAVLOV	{"email": "sergey.pavlov_121968@postgrespro.ru", "phone": "+70156856576"}
0005435105968	3F3DD5	2043 033903	ELIZAVETA VOROBEVA	{"email": "elizaveta_vorobeva_081974@postgrespro.ru", "phone": "+70854304144"}
0005435105969	3F3DD5	6178 000017	GALINA POPOVA	{"email": "popovagalina24011965@postgrespro.ru", "phone": "+70917912386"}
0005435105970	76652E	4475 768760	KRISTINA TITOVA	{"phone": "+70569952198"}
0005435105971	95784E	6579 167114	ALEKSANDR MIKHAYLOV	{"phone": "+70066410868"}
0005435105972	C70353	7209 963189	VIKTORIYA FADEEVA	{"email": "v.fadeeva30111974@postgrespro.ru", "phone": "+70248705534"}
0005435105973	C70353	6330 690298	ELENA BORISOVA	{"phone": "+70104115407"}
0005435105974	A42102	1462 813794	ANDREY KUZNECOV	{"phone": "+70736297659"}
0005435105975	825B03	7290 933015	LYUDMILA VASILEVA	{"email": "l.vasileva_1971@postgrespro.ru", "phone": "+70694464847"}
0005435105976	B97E5D	2066 014453	DANIIL STEPANOV	{"phone": "+70077507520"}
0005435105977	3919DD	1942 855431	SVETLANA NESTEROVA	{"email": "snesterova-101981@postgrespro.ru", "phone": "+70825548531"}
0005435105978	301745	8301 598839	MIKHAIL VOLKOV	{"email": "mikhail_volkov-1961@postgrespro.ru", "phone": "+70941887453"}
0005435105979	22A8A0	0418 038919	GALINA MARTYNOVA	{"email": "martynova_galina-061978@postgrespro.ru", "phone": "+70918117054"}
0005435105980	22A8A0	1530 161533	RINAT IVANOV	{"email": "rivanov.111983@postgrespro.ru", "phone": "+70330075733"}
0005435105981	46691C	5664 389554	ANASTASIYA SMIRNOVA	{"email": "smirnova.anastasiya-06081958@postgrespro.ru", "phone": "+70343207382"}
0005435105982	7BEC5B	6482 685203	GRIGORIY STEPANOV	{"phone": "+70534126231"}
0005435105983	7BEC5B	9377 282261	IRINA SEMENOVA	{"email": "semenova.irina091966@postgrespro.ru", "phone": "+70127204217"}
0005435105984	D70C7D	3719 635754	NATALYA KOZLOVA	{"email": "kozlovanatalya21041967@postgrespro.ru", "phone": "+70062599463"}
0005435105985	8FC11D	0478 432640	VLADIMIR SEMENOV	{"email": "semenov_v-021965@postgrespro.ru", "phone": "+70306943798"}
0005435105986	BE3CF1	4045 079341	ALINA ANDREEVA	{"email": "alina.andreeva.1975@postgrespro.ru", "phone": "+70735038613"}
0005435105987	3A54A2	8328 619069	NIKOLAY SHEVCHENKO	{"phone": "+70579767919"}
0005435105988	1D9444	3390 463839	OLGA IVANOVA	{"email": "olga_ivanova.18011969@postgrespro.ru", "phone": "+70694657061"}
0005435105989	FB9AB3	2734 689719	YULIYA SERGEEVA	{"email": "ysergeeva_1960@postgrespro.ru", "phone": "+70282195991"}
0005435105990	FB9AB3	5917 923101	OLGA FROLOVA	{"email": "frolova.olga-1968@postgrespro.ru", "phone": "+70636939869"}
0005435105991	0EA716	4923 192993	TIMUR EGOROV	{"email": "egorov.timur_021978@postgrespro.ru", "phone": "+70753279245"}
0005435105992	C63319	4445 608252	MIKHAIL SIDOROV	{"phone": "+70550371068"}
0005435105993	C63319	9392 650163	VLADIMIR ANTONOV	{"phone": "+70112010241"}
0005435105994	C63319	0947 944308	VITALIY MIKHAYLOV	{"email": "v_mikhaylov.1972@postgrespro.ru", "phone": "+70487095009"}
0005435105995	7499D3	2876 743725	ANTONINA DAVYDOVA	{"email": "a-davydova-09121958@postgrespro.ru", "phone": "+70321873981"}
0005435105996	9E8901	7534 523795	ALEKSANDR PAVLOV	{"email": "apavlov_1964@postgrespro.ru", "phone": "+70360490200"}
0005435105997	2F3F2D	5218 343838	ELENA ZAKHAROVA	{"email": "elenazakharova_011984@postgrespro.ru", "phone": "+70393840383"}
0005435105998	99DAB6	9700 177485	OLGA MAKSIMOVA	{"phone": "+70059773987"}
0005435105999	B96C5C	8017 319199	LYUDMILA PETROVA	{"phone": "+70486366972"}
0005435106000	0C8874	0345 368714	EDUARD SEMENOV	{"email": "eduardsemenov-1971@postgrespro.ru", "phone": "+70397276883"}
0005435106001	0C8874	6620 308806	ELENA POTAPOVA	{"phone": "+70402702999"}
0005435106002	AD542E	6103 698749	MARINA ORLOVA	{"phone": "+70916963609"}
0005435106003	9D00C6	3286 219063	ANASTASIYA FILIPPOVA	{"phone": "+70924676376"}
0005435106004	4D7644	0701 393070	ANNA ANDREEVA	{"email": "anna-andreeva_05081971@postgrespro.ru", "phone": "+70641944122"}
0005435106005	4D7644	8821 626617	TAMARA DMITRIEVA	{"email": "dmitrieva.tamara-09081980@postgrespro.ru", "phone": "+70167796780"}
0005435106006	F6D28B	4557 400636	VLADIMIR KONOVALOV	{"email": "konovalov-v.1975@postgrespro.ru", "phone": "+70334287423"}
0005435106007	A1E959	5231 054321	DMITRIY PETROV	{"email": "petrov_dmitriy_08111979@postgrespro.ru", "phone": "+70344954815"}
0005435106008	E69BF7	1073 166285	GALINA KONOVALOVA	{"email": "konovalova.g_011972@postgrespro.ru", "phone": "+70597747360"}
0005435106009	D1B650	9101 540773	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov1983@postgrespro.ru", "phone": "+70951262263"}
0005435106010	D1B650	1422 892139	VASILIY IVANOV	{"email": "ivanov_vasiliy25091963@postgrespro.ru", "phone": "+70503706868"}
0005435106011	8ACE69	8401 063269	MARIYA KUZMINA	{"email": "kuzmina_m_011966@postgrespro.ru", "phone": "+70155534919"}
0005435106012	8ACE69	2683 127253	NINA PETROVA	{"email": "n.petrova.041978@postgrespro.ru", "phone": "+70989580394"}
0005435106013	EC1497	6061 327406	VIKTOR SCHERBAKOV	{"email": "viktor_scherbakov1978@postgrespro.ru", "phone": "+70486708181"}
0005435106014	22681D	4613 451950	TATYANA ANTONOVA	{"phone": "+70189346311"}
0005435106015	4AD81B	0907 620665	ALEKSANDR FROLOV	{"phone": "+70840677566"}
0005435106016	131251	3399 298000	VALENTINA KRASNOVA	{"phone": "+70994500516"}
0005435106017	691398	9132 184658	MARINA FILIPPOVA	{"phone": "+70127886173"}
0005435106018	691398	9469 631083	VIKTOR KUZMIN	{"phone": "+70886044368"}
0005435106019	691398	6620 007169	VALERIY MELNIKOV	{"email": "melnikovv.1969@postgrespro.ru", "phone": "+70676491548"}
0005435106020	691398	3703 729329	NIKOLAY MAKAROV	{"phone": "+70034173468"}
0005435106021	691398	7657 322870	RUSTEM DMITRIEV	{"email": "dmitrievr-121979@postgrespro.ru", "phone": "+70848669039"}
0005435106022	0F6C68	2603 610910	ARTEM ROMANOV	{"email": "romanova_10081964@postgrespro.ru", "phone": "+70731790182"}
0005435106023	0F6C68	7843 130564	ARTEM POPOV	{"email": "a.popov.081965@postgrespro.ru", "phone": "+70360859280"}
0005435106024	FB08C6	6594 461375	ALEKSANDR CHERNOV	{"phone": "+70206395992"}
0005435106025	61806D	0219 158315	OLGA POLYAKOVA	{"email": "o_polyakova.29111972@postgrespro.ru", "phone": "+70184473834"}
0005435106026	61806D	1749 889995	LYUDMILA KUZNECOVA	{"phone": "+70267361031"}
0005435106027	61806D	6914 760469	LIDIYA SIDOROVA	{"email": "sidorovalidiya_1976@postgrespro.ru", "phone": "+70521919633"}
0005435106028	745ACF	6697 487298	TAMARA AKIMOVA	{"email": "tamara-akimova_081981@postgrespro.ru", "phone": "+70544825730"}
0005435106029	9F5B13	6118 840426	PAVEL VASILEV	{"phone": "+70829775051"}
0005435106030	9F5B13	3696 874175	NIKOLAY NAZAROV	{"email": "nazarovnikolay1988@postgrespro.ru", "phone": "+70382963796"}
0005435106031	103BA7	9095 520859	MIKHAIL MIKHAYLOV	{"phone": "+70881911140"}
0005435106032	5E5995	4895 852677	YULIYA NESTEROVA	{"phone": "+70239330128"}
0005435106033	5E5995	5301 538224	IGOR ZHUKOV	{"phone": "+70477775127"}
0005435106034	631710	0017 952833	ROZALIYA NIKOLAEVA	{"email": "r.nikolaeva16071954@postgrespro.ru", "phone": "+70048982387"}
0005435106035	631710	2600 515496	NADEZHDA ERMAKOVA	{"email": "n_ermakova-051981@postgrespro.ru", "phone": "+70613806581"}
0005435106036	A70BDF	2458 695169	SERGEY TIKHONOV	{"phone": "+70698826181"}
0005435106037	A70BDF	2804 655730	IVAN ZHUKOV	{"phone": "+70633792905"}
0005435126025	C6B03B	0083 351587	ANNA SOROKINA	{"phone": "+70340183185"}
0005435106038	DEFA92	7820 359894	LYUDMILA KOZLOVA	{"email": "l_kozlova-101977@postgrespro.ru", "phone": "+70899347252"}
0005435106039	FD5774	2387 145097	SERGEY MAKAROV	{"phone": "+70864855939"}
0005435106040	C0DC19	5078 785320	VIKTORIYA NAUMOVA	{"email": "v-naumova-031966@postgrespro.ru", "phone": "+70959891368"}
0005435106041	0D3144	4476 530994	TATYANA SOKOLOVA	{"email": "tatyanasokolova.15091972@postgrespro.ru", "phone": "+70677226800"}
0005435106042	BBDC4E	6873 740041	RAISA BORISOVA	{"phone": "+70231518712"}
0005435106043	BBDC4E	2831 554295	EGOR NIKITIN	{"phone": "+70837195361"}
0005435106044	3477D3	0574 666204	MARIYA VASILEVA	{"phone": "+70174112576"}
0005435106045	6C0105	0398 458580	IVAN SCHERBAKOV	{"phone": "+70463468332"}
0005435106046	6C0105	1232 506106	ANATOLIY OSIPOV	{"phone": "+70222205348"}
0005435106047	9DC524	3154 848051	ANATOLIY POPOV	{"phone": "+70795660639"}
0005435106048	E4A7FD	8622 688315	EVGENIY SIDOROV	{"phone": "+70640067176"}
0005435106049	E4A7FD	8207 274417	ALEKSEY NIKITIN	{"email": "anikitin_21061963@postgrespro.ru", "phone": "+70159374347"}
0005435106050	D103F0	2564 350822	ALEKSANDR MEDVEDEV	{"email": "medvedev_a021967@postgrespro.ru", "phone": "+70757945743"}
0005435106051	D103F0	3894 319894	EVGENIY NAZAROV	{"email": "evgeniy-nazarov_051977@postgrespro.ru", "phone": "+70497041942"}
0005435106052	329271	1260 376387	ELENA VOLKOVA	{"email": "volkova_elena.081983@postgrespro.ru", "phone": "+70041373389"}
0005435106053	0114CF	9555 446389	NATALYA FILATOVA	{"email": "n_filatova20081959@postgrespro.ru", "phone": "+70537577934"}
0005435106054	0FFF0A	4848 531592	MARIYA ZOTOVA	{"phone": "+70627230056"}
0005435106055	701077	0892 584228	ALEKSEY KAZAKOV	{"phone": "+70377984147"}
0005435106056	2A5805	4354 437175	ZINAIDA MELNIKOVA	{"phone": "+70637196238"}
0005435106057	2A5805	5787 195724	EVGENIY VASILEV	{"email": "evgeniy.vasilev.29101983@postgrespro.ru", "phone": "+70711468221"}
0005435106058	2A5805	1610 831980	ILYA MOISEEV	{"email": "ilyamoiseev1975@postgrespro.ru", "phone": "+70494108341"}
0005435106059	E56072	8689 599145	NADEZHDA FROLOVA	{"phone": "+70021477461"}
0005435106060	A7F30E	5764 780195	VYACHESLAV BONDARENKO	{"phone": "+70864107020"}
0005435106061	34CCE5	5773 896474	NATALYA ZOTOVA	{"email": "zotova.n_28091985@postgrespro.ru", "phone": "+70595060178"}
0005435106062	0522DF	2936 399777	NINA ZHUKOVA	{"phone": "+70650001569"}
0005435106063	195F76	3179 342114	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev_30121958@postgrespro.ru", "phone": "+70326072399"}
0005435106064	1D0184	8033 051960	IVAN VLASOV	{"email": "vlasov.ivan041971@postgrespro.ru", "phone": "+70730062427"}
0005435106065	6027D9	3649 731007	NINA SMIRNOVA	{"phone": "+70417936096"}
0005435106066	56D43C	6491 482188	IRINA GRISHINA	{"phone": "+70912130443"}
0005435106067	56D43C	9815 559915	ANDREY ABRAMOV	{"phone": "+70106584909"}
0005435106068	D464B8	6083 721593	EVGENIY PETROV	{"email": "petrov_e_1976@postgrespro.ru", "phone": "+70589183062"}
0005435106069	18DC69	9492 683073	ELIZAVETA KOROLEVA	{"email": "ekoroleva101976@postgrespro.ru", "phone": "+70418164208"}
0005435106070	DEF21D	8980 707061	MARIYA IVANOVA	{"email": "m-ivanova-08111977@postgrespro.ru", "phone": "+70091753912"}
0005435106071	DEF21D	4284 288942	DMITRIY FEDOROV	{"email": "fedorov_d.071980@postgrespro.ru", "phone": "+70330139607"}
0005435106072	4F3BB0	3848 831299	OLEG KISELEV	{"phone": "+70934387444"}
0005435106073	4F3BB0	7386 998319	ALEKSANDR MAKSIMOV	{"email": "a.maksimov1980@postgrespro.ru", "phone": "+70023841096"}
0005435125652	032180	6790 707170	DMITRIY VOLKOV	{"phone": "+70406446404"}
0005435125647	55C705	9568 659225	NIKOLAY VOROBEV	{"email": "vorobevnikolay.1977@postgrespro.ru", "phone": "+70769343220"}
0005435125648	55C705	6703 946491	ZOYA SOLOVEVA	{"email": "soloveva_z_051965@postgrespro.ru", "phone": "+70275089560"}
0005435125649	E31A25	3517 065525	OLGA ROMANOVA	{"email": "romanova_olga-071962@postgrespro.ru", "phone": "+70267913350"}
0005435125650	848AD2	6118 075074	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova-041972@postgrespro.ru", "phone": "+70969418292"}
0005435125651	848AD2	7250 848349	TIMUR BORISOV	{"phone": "+70764060063"}
0005435125653	032180	7902 370290	EGOR ANDREEV	{"email": "andreev-egor-091958@postgrespro.ru", "phone": "+70235603836"}
0005435125654	032180	1532 238616	VALERIYA OSIPOVA	{"email": "v-osipova-1967@postgrespro.ru", "phone": "+70537606244"}
0005435125655	626F6B	3567 103223	IRINA KONOVALOVA	{"email": "konovalova.irina-1968@postgrespro.ru", "phone": "+70250017546"}
0005435125656	802828	7154 543835	EVGENIY KUZNECOV	{"phone": "+70390727957"}
0005435125657	E02355	6736 229604	KONSTANTIN KISELEV	{"phone": "+70154298404"}
0005435125658	F64D90	4984 425043	NIKITA MEDVEDEV	{"phone": "+70262707499"}
0005435125659	F64D90	2758 613327	VERA FROLOVA	{"phone": "+70300076398"}
0005435125660	A77AF4	8662 753914	NATALYA FEDOROVA	{"email": "n.fedorova.01061975@postgrespro.ru", "phone": "+70664830643"}
0005435125661	EE072B	9785 231051	MARIYA FEDOROVA	{"email": "fedorova.m-1965@postgrespro.ru", "phone": "+70009335375"}
0005435125662	EE072B	8726 131560	ANDREY TARASOV	{"email": "andrey-tarasov15041973@postgrespro.ru", "phone": "+70262311906"}
0005435125663	27926F	9851 262350	ROMAN SCHERBAKOV	{"email": "scherbakovroman.15031969@postgrespro.ru", "phone": "+70281873970"}
0005435125664	48223A	5671 801898	ALEKSEY FILIPPOV	{"phone": "+70929917179"}
0005435125665	6A969B	0244 691556	VALERIY SERGEEV	{"email": "valeriy.sergeev.011971@postgrespro.ru", "phone": "+70042514399"}
0005435125666	6A969B	4876 709601	TATYANA KUZMINA	{"email": "kuzmina-tatyana09091974@postgrespro.ru", "phone": "+70170918700"}
0005435125667	E07E5F	5745 245807	EVGENIY ILIN	{"email": "ilin_evgeniy_031966@postgrespro.ru", "phone": "+70225883157"}
0005435125668	624BAB	5832 582815	VALERIY MAKAROV	{"phone": "+70768585444"}
0005435125669	624BAB	8695 338963	IRINA AFANASEVA	{"email": "afanasevai.09091984@postgrespro.ru", "phone": "+70013150601"}
0005435126142	48B753	7882 015599	ANZHELIKA PETROVA	{"phone": "+70093060082"}
0005435125670	AABF76	1895 911952	YURIY CHERNOV	{"email": "chernov-y.121971@postgrespro.ru", "phone": "+70231418405"}
0005435125671	FC43DE	8461 847704	VADIM ZAYCEV	{"phone": "+70971421329"}
0005435125672	4745B5	0362 880367	ZINAIDA LOGINOVA	{"phone": "+70312689777"}
0005435125673	4745B5	7080 781863	ALEKSEY TIMOFEEV	{"email": "a-timofeev_1971@postgrespro.ru", "phone": "+70417748042"}
0005435125674	BCCD8E	4833 830437	ALEKSANDR KISELEV	{"phone": "+70792990450"}
0005435125675	081318	8390 038738	KRISTINA ARKHIPOVA	{"phone": "+70335477354"}
0005435125676	081318	2233 230190	LYUDMILA NOVIKOVA	{"email": "lyudmilanovikova-1970@postgrespro.ru", "phone": "+70123704217"}
0005435125677	AF73D6	3969 571946	NATALYA LOGINOVA	{"email": "loginovanatalya.06081963@postgrespro.ru", "phone": "+70270239687"}
0005435125678	AF73D6	4806 796539	NIKITA ZHUKOV	{"email": "zhukovn.031990@postgrespro.ru", "phone": "+70573298410"}
0005435125679	177576	7145 540426	ALEKSANDRA ROMANOVA	{"email": "romanovaa071976@postgrespro.ru", "phone": "+70145358470"}
0005435125680	B107F8	9711 734221	NATALIYA FILIPPOVA	{"email": "nataliya_filippova_1966@postgrespro.ru", "phone": "+70267162345"}
0005435125681	2550B6	7625 403864	SEMEN PETROV	{"email": "petrovs101964@postgrespro.ru", "phone": "+70401673335"}
0005435125682	467240	1233 020850	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr021973@postgrespro.ru", "phone": "+70765411494"}
0005435125683	ABA7C9	1618 783559	ALEKSANDR SAVELEV	{"email": "savelev_aleksandr-1961@postgrespro.ru", "phone": "+70210785686"}
0005435125684	1C18AA	8472 905214	OLGA EFREMOVA	{"email": "o-efremova1967@postgrespro.ru", "phone": "+70368477794"}
0005435125685	C9A699	1650 415614	ZINAIDA VOROBEVA	{"phone": "+70303238332"}
0005435125686	D768A5	9162 289518	NATALYA KULIKOVA	{"phone": "+70281124949"}
0005435125687	322A79	3441 168391	NATALYA ROMANOVA	{"email": "n_romanova-1977@postgrespro.ru", "phone": "+70889325727"}
0005435125688	322A79	3540 547904	IRINA DENISOVA	{"email": "irina.denisova.25061985@postgrespro.ru", "phone": "+70148635993"}
0005435125689	6E6B8E	8656 289889	MARIYA POPOVA	{"email": "m_popova1976@postgrespro.ru", "phone": "+70944879932"}
0005435125690	6E6B8E	7558 649114	SERGEY PETROV	{"phone": "+70290296188"}
0005435125691	7076DC	5823 789009	KRISTINA FILIPPOVA	{"email": "kristina.filippova.061975@postgrespro.ru", "phone": "+70533628145"}
0005435125692	7076DC	2040 265456	ANTON IVANOV	{"email": "ivanov.anton-1973@postgrespro.ru", "phone": "+70519234165"}
0005435125693	2D7987	1433 711084	VALENTINA KOROLEVA	{"email": "valentina_koroleva_1967@postgrespro.ru", "phone": "+70743431557"}
0005435125694	B01216	4129 768288	ARTUR IVANOV	{"phone": "+70522798462"}
0005435125695	6A2662	6124 546631	MARIYA PETROVA	{"email": "mariya.petrova.061975@postgrespro.ru", "phone": "+70687341512"}
0005435125696	6A2662	9937 794254	YURIY ZAKHAROV	{"phone": "+70129968315"}
0005435125697	26137E	2327 141384	ELENA MIKHAYLOVA	{"email": "elena.mikhaylova_091982@postgrespro.ru", "phone": "+70242759464"}
0005435125698	26137E	1413 820892	ALISA TITOVA	{"phone": "+70828806596"}
0005435125699	20438B	1472 721859	ZINAIDA POPOVA	{"email": "popova.z.08041970@postgrespro.ru", "phone": "+70584419213"}
0005435125700	20438B	9487 506972	ALEKSEY ZHURAVLEV	{"phone": "+70627046159"}
0005435125701	D7A547	5208 375972	NIKOLAY GAVRILOV	{"email": "gavrilov_n051967@postgrespro.ru", "phone": "+70038925571"}
0005435125702	B68549	1777 735416	OLGA GUSEVA	{"phone": "+70150363507"}
0005435125703	446C75	2500 054169	DARYA VASILEVA	{"phone": "+70270208308"}
0005435125704	81DA1B	4220 130008	FARIT MELNIKOV	{"phone": "+70624545103"}
0005435125705	F6FAFA	6038 509821	ELENA GERASIMOVA	{"email": "elena_gerasimova.021965@postgrespro.ru", "phone": "+70146176211"}
0005435125706	9FDF85	3483 884932	POLINA POPOVA	{"email": "ppopova-081985@postgrespro.ru", "phone": "+70756007569"}
0005435125707	FF0F73	7737 338085	VLADIMIR ABRAMOV	{"email": "abramov.v_1968@postgrespro.ru", "phone": "+70294004994"}
0005435125708	FF0F73	6548 761061	NATALYA RYABOVA	{"phone": "+70415660657"}
0005435125709	46F365	0288 829166	IRINA PETROVA	{"phone": "+70151593049"}
0005435125710	EA21D6	9996 141818	GALINA DANILOVA	{"email": "danilova.g1970@postgrespro.ru", "phone": "+70117434107"}
0005435125711	3E16A2	5733 924825	DENIS POPOV	{"email": "d.popov_071977@postgrespro.ru", "phone": "+70016296994"}
0005435125712	3E16A2	4004 531404	RAISA SERGEEVA	{"phone": "+70533119388"}
0005435125713	D08ACF	0172 925031	ALBINA KULIKOVA	{"email": "kulikova-a.12101971@postgrespro.ru", "phone": "+70128763506"}
0005435125714	705AF1	8533 876788	ANATOLIY FEDOTOV	{"email": "fedotova.1971@postgrespro.ru", "phone": "+70438542978"}
0005435125715	2293CE	5982 400764	ALEKSEY KOZLOV	{"phone": "+70249537327"}
0005435125716	03B1C6	7825 488252	BOGDAN TARASOV	{"phone": "+70469411394"}
0005435125717	03B1C6	0646 827928	LYUDMILA ZHUKOVA	{"email": "zhukovalyudmila_02081967@postgrespro.ru", "phone": "+70536324968"}
0005435125718	642ED5	6140 014115	MARIYA ZAYCEVA	{"email": "m-zayceva_091977@postgrespro.ru", "phone": "+70634401934"}
0005435125719	C29EB4	5510 256064	TATYANA FROLOVA	{"email": "tatyana.frolova_10071967@postgrespro.ru", "phone": "+70630642304"}
0005435125720	C2DD9A	1337 227767	DINA ROMANOVA	{"email": "dina_romanova031972@postgrespro.ru", "phone": "+70616659763"}
0005435125721	FA0704	2297 181086	ALEKSANDR ISAEV	{"email": "isaev.aleksandr_091977@postgrespro.ru", "phone": "+70635562625"}
0005435125722	FA0704	4444 073659	VALENTINA VOLKOVA	{"phone": "+70933697172"}
0005435125723	3CD75E	7094 004504	MARIYA DENISOVA	{"email": "mariyadenisova28061970@postgrespro.ru", "phone": "+70095116664"}
0005435125724	3CD75E	1909 995082	ANATOLIY NAZAROV	{"email": "nazarov.anatoliy.091971@postgrespro.ru", "phone": "+70741253453"}
0005435125725	EC2A84	2487 965582	IRINA KONOVALOVA	{"email": "i-konovalova-30011968@postgrespro.ru", "phone": "+70330802130"}
0005435125726	19A741	3570 056981	YULIYA VOROBEVA	{"phone": "+70122729210"}
0005435125727	19A741	8506 928000	LIDIYA MARTYNOVA	{"phone": "+70604492394"}
0005435125728	F98FF2	0058 108620	NINA KARPOVA	{"email": "karpovan.12021980@postgrespro.ru", "phone": "+70248266165"}
0005435125729	A47530	7555 935856	ANNA ROMANOVA	{"email": "romanova-anna11091972@postgrespro.ru", "phone": "+70562891609"}
0005435125730	320F58	0591 667324	TATYANA NIKITINA	{"email": "t-nikitina.111973@postgrespro.ru", "phone": "+70893387990"}
0005435125731	320F58	9014 282344	ALEKSANDR MIRONOV	{"email": "aleksandrmironov.18051981@postgrespro.ru", "phone": "+70238699583"}
0005435125732	320F58	3337 079429	EKATERINA IVANOVA	{"phone": "+70023798025"}
0005435125733	DB8693	0930 636586	ILYA MAKAROV	{"phone": "+70765622859"}
0005435125734	DB8693	1480 961891	SERGEY IVANOV	{"email": "sergey-ivanov.23111976@postgrespro.ru", "phone": "+70925666819"}
0005435125735	DB8693	1593 978629	ELENA KUZNECOVA	{"phone": "+70146773611"}
0005435125736	59972F	2925 659507	ELENA DAVYDOVA	{"email": "davydova-e_051974@postgrespro.ru", "phone": "+70687321445"}
0005435125737	B9A8E6	5949 453690	OLGA ROMANOVA	{"email": "romanova_olga.081970@postgrespro.ru", "phone": "+70513371175"}
0005435125738	F681AD	2193 520698	ANDREY SOKOLOV	{"phone": "+70222638441"}
0005435125739	F681AD	9247 514476	ELIZAVETA ARKHIPOVA	{"phone": "+70826283968"}
0005435125740	F681AD	5295 842887	VLADIMIR TARASOV	{"email": "tarasovv.15021970@postgrespro.ru", "phone": "+70211948661"}
0005435125741	F34580	1840 855435	ZINAIDA ROMANOVA	{"email": "zinaida.romanova29081971@postgrespro.ru", "phone": "+70718969094"}
0005435125742	A72C53	3663 217540	NADEZHDA BOGDANOVA	{"phone": "+70686541711"}
0005435125743	772754	7568 228035	VALENTINA KUZNECOVA	{"email": "kuznecovav.1964@postgrespro.ru", "phone": "+70899837339"}
0005435125744	772754	4845 982587	NATALYA RYABOVA	{"email": "ryabovanatalya-14121966@postgrespro.ru", "phone": "+70676573927"}
0005435125745	D59B88	5094 912775	MARINA NAZAROVA	{"phone": "+70152270891"}
0005435125746	7A6E4A	8820 672932	SVETLANA TROFIMOVA	{"phone": "+70198220403"}
0005435125747	0820EA	0023 146914	ANASTASIYA ABRAMOVA	{"phone": "+70390746782"}
0005435125748	0820EA	1801 412476	ANATOLIY ABRAMOV	{"email": "a.abramov.1986@postgrespro.ru", "phone": "+70959168215"}
0005435125749	0820EA	7801 356599	VLADIMIR MIRONOV	{"phone": "+70020336876"}
0005435125750	E76186	3609 701753	ALEKSANDR GAVRILOV	{"email": "a.gavrilov_1962@postgrespro.ru", "phone": "+70978335190"}
0005435125751	D22C04	3255 558953	RAMIS POPOV	{"email": "ramispopov-14031977@postgrespro.ru", "phone": "+70881194318"}
0005435125752	351D3D	1073 909810	ELENA ISAEVA	{"email": "e-isaeva-1977@postgrespro.ru", "phone": "+70548653323"}
0005435125753	DF6302	3746 923360	VLADISLAV KONOVALOV	{"email": "vladislav.konovalov.1975@postgrespro.ru", "phone": "+70590618066"}
0005435125754	DF6302	2066 780784	NADEZHDA FOMINA	{"phone": "+70679931249"}
0005435125755	501043	8747 486924	TATYANA FEDOROVA	{"phone": "+70782976964"}
0005435125756	98DCE8	6184 363237	VIKTOR NAUMOV	{"email": "naumovviktor_1976@postgrespro.ru", "phone": "+70157388838"}
0005435125757	98DCE8	6788 289414	SERGEY NOVIKOV	{"phone": "+70846354795"}
0005435125758	FD063F	6484 947210	ROMAN SERGEEV	{"phone": "+70403185986"}
0005435125759	FD063F	9772 742228	VASILIY MELNIKOV	{"email": "vasiliy_melnikov1969@postgrespro.ru", "phone": "+70429710520"}
0005435125760	D669EB	5668 653548	ANNA KONOVALOVA	{"email": "a-konovalova.13011968@postgrespro.ru", "phone": "+70084630505"}
0005435125761	D669EB	3015 838879	NIKITA DAVYDOV	{"email": "davydovn_25071965@postgrespro.ru", "phone": "+70442712891"}
0005435125762	96533F	3873 958489	TATYANA ANTONOVA	{"email": "antonova_tatyana_091973@postgrespro.ru", "phone": "+70658577871"}
0005435125763	18F046	7476 437118	VALENTINA ZAKHAROVA	{"email": "vzakharova.18051979@postgrespro.ru", "phone": "+70442259900"}
0005435125764	ABF600	1956 082865	DMITRIY GUSEV	{"phone": "+70487031105"}
0005435125765	B312B3	1202 990790	SVETLANA ILINA	{"email": "ilina-svetlana15041968@postgrespro.ru", "phone": "+70643281143"}
0005435125766	FA5D3E	6150 638375	NATALYA EFREMOVA	{"email": "efremova.natalya.1969@postgrespro.ru", "phone": "+70355799529"}
0005435125767	BF8F05	1593 271663	NIKOLAY ISAEV	{"email": "nikolay_isaev051981@postgrespro.ru", "phone": "+70217928343"}
0005435125768	98EAF9	6565 041105	ELENA OVCHINNIKOVA	{"phone": "+70422511057"}
0005435125769	1223FD	2720 785783	SERGEY NIKOLAEV	{"email": "s-nikolaev-031982@postgrespro.ru", "phone": "+70900827192"}
0005435125770	0AD6F1	9616 874491	VLADIMIR BORISOV	{"phone": "+70456360713"}
0005435125771	EC336B	7009 391529	ALEKSEY TIKHONOV	{"phone": "+70664114540"}
0005435125772	D834D6	0769 657229	SVETLANA EFIMOVA	{"email": "efimovasvetlana_10111979@postgrespro.ru", "phone": "+70101611226"}
0005435125773	D834D6	8027 692244	MARIYA ANTONOVA	{"phone": "+70916182514"}
0005435125774	D834D6	0471 349291	SERGEY NIKOLAEV	{"phone": "+70992937019"}
0005435125775	573EBD	7210 831695	TATYANA SIDOROVA	{"phone": "+70088925029"}
0005435125776	573EBD	8239 022070	OLGA KOVALEVA	{"email": "kovaleva_o031975@postgrespro.ru", "phone": "+70706536853"}
0005435125777	895AB0	3168 665400	TATYANA POTAPOVA	{"email": "potapova_t20091983@postgrespro.ru", "phone": "+70541264692"}
0005435125778	895AB0	9364 034610	NADEZHDA SMIRNOVA	{"email": "smirnovan-11051975@postgrespro.ru", "phone": "+70282392017"}
0005435125779	AF566A	9154 738563	INNA KUZNECOVA	{"email": "kuznecova-i.04111962@postgrespro.ru", "phone": "+70158303041"}
0005435125780	AF566A	5505 172196	ILYAS KUZMIN	{"email": "kuzmin_i-081987@postgrespro.ru", "phone": "+70308449169"}
0005435125781	7A3C12	3662 118268	ANATOLIY KUZMIN	{"phone": "+70917698991"}
0005435125782	E6313C	9603 932898	ALEKSEY VLASOV	{"phone": "+70408755875"}
0005435125783	E6313C	9993 874168	NIKITA OSIPOV	{"phone": "+70367236440"}
0005435125784	E6313C	5049 535619	KSENIYA MOROZOVA	{"phone": "+70160898198"}
0005435125785	8500C8	9727 558401	KLAVDIYA AKIMOVA	{"phone": "+70595323555"}
0005435125786	5563C4	1432 110482	DMITRIY ANTONOV	{"email": "dmitriyantonov1977@postgrespro.ru", "phone": "+70119811947"}
0005435125787	6A85E3	2162 718410	NADEZHDA PAVLOVA	{"phone": "+70256558231"}
0005435125788	DAF731	0885 482201	TAMARA VASILEVA	{"email": "t_vasileva_07121981@postgrespro.ru", "phone": "+70781598643"}
0005435125789	DAF731	7831 498028	NATALYA DMITRIEVA	{"email": "n-dmitrieva_18121963@postgrespro.ru", "phone": "+70447556775"}
0005435125790	EEA775	6106 754564	ALEKSANDR NAZAROV	{"phone": "+70667311815"}
0005435125791	8C9F5F	2342 997961	PETR POPOV	{"email": "petrpopov_071976@postgrespro.ru", "phone": "+70517670629"}
0005435125792	E47CCB	1351 966129	ANATOLIY IVANOV	{"email": "ivanov-anatoliy02111973@postgrespro.ru", "phone": "+70170291454"}
0005435125793	BD033A	5048 797712	ALEKSEY ANDREEV	{"email": "andreevaleksey_18071970@postgrespro.ru", "phone": "+70562422059"}
0005435125794	BD033A	3924 208170	MARINA KOROLEVA	{"email": "marinakoroleva-1968@postgrespro.ru", "phone": "+70075047210"}
0005435125795	6AAC62	9826 820123	KONSTANTIN ANDREEV	{"email": "andreev-k18101971@postgrespro.ru", "phone": "+70317026638"}
0005435125796	6AAC62	3729 067820	INNA VASILEVA	{"phone": "+70671579347"}
0005435125797	4C662B	5335 728515	TATYANA NAZAROVA	{"phone": "+70154365258"}
0005435125798	A1A401	7743 777979	DARYA VASILEVA	{"email": "daryavasileva09011970@postgrespro.ru", "phone": "+70774795401"}
0005435125799	0C98DD	6118 529659	ZINAIDA BOGDANOVA	{"email": "zbogdanova-071982@postgrespro.ru", "phone": "+70360116680"}
0005435125800	0B8191	8057 068431	LIDIYA ERMAKOVA	{"email": "lidiyaermakova_071962@postgrespro.ru", "phone": "+70680912079"}
0005435125801	D64F03	3139 928101	ALEKSANDR KOZLOV	{"phone": "+70965219804"}
0005435125802	641EB7	1735 570505	ALEKSANDRA PAVLOVA	{"phone": "+70544728192"}
0005435125803	641EB7	3539 006622	NINA KUZNECOVA	{"email": "kuznecovan-09081975@postgrespro.ru", "phone": "+70211073294"}
0005435125804	221A4B	2652 479181	ALEKSANDR MAKAROV	{"phone": "+70182650145"}
0005435125805	221A4B	9686 384394	VERA SOROKINA	{"phone": "+70165603356"}
0005435125806	0B1671	5867 506366	ALEKSANDR TIMOFEEV	{"phone": "+70577421503"}
0005435125807	86BACB	0332 759405	IGOR NOVIKOV	{"email": "novikovi_13081972@postgrespro.ru", "phone": "+70225806071"}
0005435125808	86BACB	7923 525351	MARIYA NAZAROVA	{"phone": "+70917304552"}
0005435125809	9A7485	9725 436034	ANASTASIYA SOKOLOVA	{"email": "sokolova-a-20111962@postgrespro.ru", "phone": "+70478666571"}
0005435125810	B41369	8793 436422	NINA ALEKSANDROVA	{"email": "ninaaleksandrova.021983@postgrespro.ru", "phone": "+70110217169"}
0005435125811	B41369	3048 553475	VIKTOR DENISOV	{"phone": "+70589965662"}
0005435125812	87086A	2553 695471	DARYA MIKHAYLOVA	{"email": "mikhaylova-darya1962@postgrespro.ru", "phone": "+70507145463"}
0005435125813	87086A	0286 462306	PETR KUDRYASHOV	{"phone": "+70482142388"}
0005435125814	7ADF70	6768 251884	VLADIMIR MIKHAYLOV	{"email": "v-mikhaylov_1972@postgrespro.ru", "phone": "+70162584526"}
0005435125815	FE4BE5	7810 324406	KLAVDIYA MELNIKOVA	{"email": "klavdiya_melnikova_1966@postgrespro.ru", "phone": "+70296131263"}
0005435125816	2A5A03	4146 551586	ANATOLIY BORISOV	{"email": "borisov_anatoliy021969@postgrespro.ru", "phone": "+70327091601"}
0005435125817	50E052	4044 311073	PETR EGOROV	{"email": "p.egorov.021982@postgrespro.ru", "phone": "+70534479036"}
0005435125930	4A608C	9271 609371	IGOR MIKHAYLOV	{"phone": "+70013245894"}
0005435125818	B648E8	4152 536952	TATYANA BORISOVA	{"email": "borisova_tatyana-07091977@postgrespro.ru", "phone": "+70122770250"}
0005435125819	B648E8	5285 407745	VERA EFIMOVA	{"email": "efimova-v.22091966@postgrespro.ru", "phone": "+70008252925"}
0005435125820	B648E8	2157 921451	VIKTOR KUZNECOV	{"email": "viktor.kuznecov_15061985@postgrespro.ru", "phone": "+70506159633"}
0005435125821	E08815	7319 413567	SVETLANA AFANASEVA	{"phone": "+70272243877"}
0005435125822	23683E	8933 319289	MARGARITA KULIKOVA	{"phone": "+70389057405"}
0005435125823	23683E	4041 638219	IRINA ZAYCEVA	{"phone": "+70952225554"}
0005435125824	910053	1736 708416	ROSTISLAV KUZNECOV	{"phone": "+70972899340"}
0005435125825	5D775B	3393 370523	TAISIYA KRASNOVA	{"email": "taisiya_krasnova1976@postgrespro.ru", "phone": "+70474691235"}
0005435125826	144B90	9277 748418	VYACHESLAV SMIRNOV	{"phone": "+70098678003"}
0005435125827	087B7D	8380 194933	ELENA SMIRNOVA	{"email": "elena-smirnova_02061967@postgrespro.ru", "phone": "+70769514018"}
0005435125828	087B7D	6288 080853	ANTONINA AFANASEVA	{"phone": "+70409857594"}
0005435125829	1F1E88	9363 988521	VALERIY PETROV	{"email": "petrovv111966@postgrespro.ru", "phone": "+70555476591"}
0005435125830	850683	3457 134982	MARIYA POPOVA	{"email": "popova_mariya_111971@postgrespro.ru", "phone": "+70762795708"}
0005435125831	850683	7179 452915	ANATOLIY ISAEV	{"email": "a-isaev-071966@postgrespro.ru", "phone": "+70519537708"}
0005435125832	51B0F0	0155 695057	IVAN PETROV	{"phone": "+70197661279"}
0005435125833	B23618	1483 693676	ROMAN NIKOLAEV	{"phone": "+70528102556"}
0005435125834	F2BF63	0639 581143	GLEB NOVIKOV	{"phone": "+70917364636"}
0005435125835	16AD01	2613 385335	VERA MIRONOVA	{"email": "mironova.vera.081965@postgrespro.ru", "phone": "+70364873868"}
0005435125836	114A9A	0540 038557	DENIS STEPANOV	{"email": "d_stepanov_1961@postgrespro.ru", "phone": "+70253640196"}
0005435125837	25251F	8276 369686	RIFAT FILIPPOV	{"phone": "+70103771056"}
0005435125838	3BE4A7	7496 081199	OLGA MIRONOVA	{"phone": "+70437583628"}
0005435125839	F6A813	1640 192358	IVAN NOVIKOV	{"email": "novikov-i_061977@postgrespro.ru", "phone": "+70184570648"}
0005435125840	F6A813	6358 621504	NELYA LAZAREVA	{"email": "lazareva_n051965@postgrespro.ru", "phone": "+70864968988"}
0005435125841	BCD485	4595 422171	EVGENIY KUDRYASHOV	{"email": "kudryashov-e051973@postgrespro.ru", "phone": "+70257340769"}
0005435125842	50F7D3	0233 876323	OLGA NAZAROVA	{"email": "nazarova-o_20021966@postgrespro.ru", "phone": "+70247276398"}
0005435125843	E2D399	7952 500529	YULIYA ARKHIPOVA	{"email": "yuliya_arkhipova.29081969@postgrespro.ru", "phone": "+70046473643"}
0005435125844	E23A19	6375 706433	POLINA PETROVA	{"phone": "+70683846445"}
0005435126264	4CF8BB	3887 024935	PAVEL OSIPOV	{"phone": "+70841607430"}
0005435125845	3D5A4C	3793 693263	EGOR FILIPPOV	{"email": "filippov-e_091978@postgrespro.ru", "phone": "+70041796469"}
0005435125846	06EF31	5072 823065	NATALYA VASILEVA	{"email": "natalya-vasileva_1953@postgrespro.ru", "phone": "+70111563749"}
0005435125847	06EF31	8642 678613	ALEKSANDR ISAEV	{"phone": "+70702893462"}
0005435125848	1B9BD8	2493 516888	PETR GORBUNOV	{"email": "p-gorbunov.22091972@postgrespro.ru", "phone": "+70087815432"}
0005435125849	1D9582	7138 185540	ANASTASIYA SOROKINA	{"phone": "+70669703050"}
0005435125850	1D9582	2287 311843	TATYANA NAUMOVA	{"email": "naumova_tatyana.121970@postgrespro.ru", "phone": "+70532327145"}
0005435125851	DD84F5	7532 070728	MAKSIM ORLOV	{"email": "m.orlov-121972@postgrespro.ru", "phone": "+70109364218"}
0005435125852	DD84F5	5716 833794	IRINA FOMINA	{"email": "fominai101971@postgrespro.ru", "phone": "+70601911074"}
0005435125853	2A41AB	1662 639348	NIKOLAY GRIGOREV	{"email": "grigorev-nikolay05121974@postgrespro.ru", "phone": "+70887450134"}
0005435125854	2A41AB	4882 712391	MAKSIM MAKSIMOV	{"phone": "+70149521371"}
0005435125855	2A41AB	9466 532832	MARINA GERASIMOVA	{"email": "gerasimova-marina111980@postgrespro.ru", "phone": "+70301184865"}
0005435125856	FA44CA	5707 460992	EKATERINA KRASNOVA	{"phone": "+70508008578"}
0005435125857	FA44CA	9363 941530	ALISA ALEKSEEVA	{"phone": "+70634700977"}
0005435125858	B03B9D	9255 361467	TARAS MOROZOV	{"phone": "+70085206551"}
0005435125859	B03B9D	4930 981790	ALEKSANDR TIMOFEEV	{"phone": "+70695544645"}
0005435125860	040346	8430 130094	MAKSIM POPOV	{"phone": "+70352886649"}
0005435125861	98F8AE	9617 031973	LIDIYA MAKSIMOVA	{"email": "maksimova_lidiya-1980@postgrespro.ru", "phone": "+70103983199"}
0005435125862	98F8AE	1782 848314	NATALYA POPOVA	{"email": "popova_n031968@postgrespro.ru", "phone": "+70965480572"}
0005435125863	CC5718	0739 123099	GENNADIY SOLOVEV	{"phone": "+70361741918"}
0005435125864	CC5718	5292 616274	VITALIY VOLKOV	{"email": "vvolkov-1970@postgrespro.ru", "phone": "+70703527256"}
0005435125865	5A127C	6347 415843	ALEKSEY MOROZOV	{"email": "amorozov-05091979@postgrespro.ru", "phone": "+70454745880"}
0005435125866	61987B	9919 558683	ALENA MIKHAYLOVA	{"email": "mikhaylova_alena.1969@postgrespro.ru", "phone": "+70028510474"}
0005435125867	E91A91	0140 114096	ALEKSANDR ALEKSEEV	{"email": "alekseev_a-021978@postgrespro.ru", "phone": "+70473837688"}
0005435125868	615F66	9497 582970	VLADIMIR RODIONOV	{"email": "rodionov-v_1959@postgrespro.ru", "phone": "+70598188346"}
0005435125869	ABCE11	1315 747593	ANASTASIYA SMIRNOVA	{"email": "anastasiyasmirnova1970@postgrespro.ru", "phone": "+70738866374"}
0005435125870	E86CED	4588 976642	RINAT PETROV	{"email": "petrov_r1965@postgrespro.ru", "phone": "+70590072388"}
0005435125871	599B71	3806 911792	IRINA FEDOROVA	{"email": "fedorova.i.1975@postgrespro.ru", "phone": "+70917972088"}
0005435125872	94A42F	8642 655811	LADA PAVLOVA	{"phone": "+70196085806"}
0005435125873	110BED	6087 216924	ANATOLIY MOROZOV	{"email": "amorozov.1968@postgrespro.ru", "phone": "+70193095178"}
0005435125874	110BED	9534 171426	ALEKSANDR MAKSIMOV	{"email": "maksimov-a.21121982@postgrespro.ru", "phone": "+70588130388"}
0005435125875	4923E7	0509 591267	PAVEL NOVIKOV	{"phone": "+70133239539"}
0005435125876	4923E7	2401 332001	ILYA SOKOLOV	{"phone": "+70831555316"}
0005435125877	03FF70	4626 753530	MARINA PETROVA	{"phone": "+70616198240"}
0005435125878	5FFB79	2039 804588	VERA KARPOVA	{"phone": "+70850618443"}
0005435125879	52389A	4033 853221	OLGA RODIONOVA	{"phone": "+70617046030"}
0005435125880	211291	0600 034827	ALEKSANDR NOVIKOV	{"phone": "+70699319225"}
0005435125881	6BC4A7	5956 654201	IVAN MELNIKOV	{"email": "ivan-melnikov16011958@postgrespro.ru", "phone": "+70602232019"}
0005435125882	F84629	4574 789552	SERGEY DAVYDOV	{"phone": "+70852100776"}
0005435125883	F84629	8531 244985	EDUARD YAKOVLEV	{"email": "eduard-yakovlev.1971@postgrespro.ru", "phone": "+70778730621"}
0005435125884	209649	0258 044074	MARINA NESTEROVA	{"email": "nesterova_marina011977@postgrespro.ru", "phone": "+70678700455"}
0005435125885	209649	5102 849762	VIKTOR FROLOV	{"email": "viktor-frolov_111971@postgrespro.ru", "phone": "+70992843501"}
0005435125886	D5004B	3635 930178	KONSTANTIN SOKOLOV	{"email": "k_sokolov.111964@postgrespro.ru", "phone": "+70908099749"}
0005435125887	D5004B	2763 911848	NATALYA GORBUNOVA	{"phone": "+70383120118"}
0005435125888	3AEF13	0932 067725	LYUDMILA KUZNECOVA	{"email": "kuznecova.lyudmila.091970@postgrespro.ru", "phone": "+70572678605"}
0005435125889	2E819F	8350 830064	ALEKSEY TIMOFEEV	{"phone": "+70408068453"}
0005435125890	2E819F	8563 336586	NADEZHDA MATVEEVA	{"phone": "+70388672551"}
0005435125891	FB9F7E	0903 458362	VYACHESLAV FILIPPOV	{"email": "filippov-vyacheslav_111975@postgrespro.ru", "phone": "+70943987986"}
0005435125892	E0AF9C	5167 381620	ANASTASIYA TIKHONOVA	{"email": "tikhonovaanastasiya_1974@postgrespro.ru", "phone": "+70285513039"}
0005435125893	E0AF9C	2152 168597	OLGA SMIRNOVA	{"email": "olga-smirnova061968@postgrespro.ru", "phone": "+70509544157"}
0005435125894	5A039A	8280 227846	IGOR NAZAROV	{"phone": "+70228416960"}
0005435125895	5A039A	2170 257658	SVETLANA KULIKOVA	{"phone": "+70152248768"}
0005435125896	5A039A	6673 813598	MIKHAIL AFANASEV	{"phone": "+70587748596"}
0005435125897	D82E09	5356 787897	TAISIYA KUDRYASHOVA	{"phone": "+70637819111"}
0005435125898	A56B80	8753 950545	ALEKSEY FILIPPOV	{"phone": "+70893642953"}
0005435125899	C91BAA	3341 709529	BORIS VASILEV	{"phone": "+70667166307"}
0005435125900	68EAFE	3066 859414	ANASTASIYA LEBEDEVA	{"email": "lebedeva_a-1960@postgrespro.ru", "phone": "+70134665808"}
0005435125901	68EAFE	0864 631619	DMITRIY IVANOV	{"email": "d-ivanov_26091968@postgrespro.ru", "phone": "+70794923481"}
0005435125902	0556E6	3242 109807	STANISLAV MAKAROV	{"email": "makarov-s_07071966@postgrespro.ru", "phone": "+70802273613"}
0005435125903	0556E6	0963 075609	ALENA SOKOLOVA	{"email": "sokolova_alena021975@postgrespro.ru", "phone": "+70989470343"}
0005435125904	45EA14	1630 300696	ANNA KUZNECOVA	{"email": "kuznecova-anna-26021969@postgrespro.ru", "phone": "+70973277940"}
0005435125905	3DEF88	7458 161062	MARINA SEMENOVA	{"phone": "+70063265247"}
0005435125906	3DEF88	3857 081924	OLGA DENISOVA	{"phone": "+70968014485"}
0005435125907	76FD0C	2551 084736	YURIY KAZAKOV	{"email": "yuriykazakov-011976@postgrespro.ru", "phone": "+70097344242"}
0005435125908	05C688	8541 766386	FAINA KRASNOVA	{"email": "fkrasnova-1962@postgrespro.ru", "phone": "+70483600598"}
0005435125909	4CF279	3248 484033	RAFAIL MIKHAYLOV	{"phone": "+70221020212"}
0005435125910	9740B8	7195 446452	NIKOLAY NAZAROV	{"phone": "+70369516593"}
0005435125911	9740B8	1930 239232	ANDREY OSIPOV	{"phone": "+70426067598"}
0005435125912	565C4C	8688 047225	OLGA ALEKSANDROVA	{"email": "aleksandrovao-1971@postgrespro.ru", "phone": "+70380557577"}
0005435125913	565C4C	7365 516413	YULIYA MATVEEVA	{"phone": "+70907939909"}
0005435125914	A0922A	2446 792129	ELIZAVETA GORBUNOVA	{"email": "egorbunova28061978@postgrespro.ru", "phone": "+70523894172"}
0005435125915	A0922A	7808 490269	SERGEY DMITRIEV	{"phone": "+70181402457"}
0005435125916	E92A78	2873 499695	ANDREY GERASIMOV	{"email": "andrey-gerasimov-22011969@postgrespro.ru", "phone": "+70048477989"}
0005435125917	27C36C	6367 471251	YULIYA EGOROVA	{"phone": "+70079464198"}
0005435125918	F9D520	3888 047608	SERGEY ZAKHAROV	{"phone": "+70843931751"}
0005435125919	F9D520	9997 789459	DENIS MOISEEV	{"phone": "+70966721380"}
0005435125920	F9D520	5933 334878	IGOR STEPANOV	{"phone": "+70693863544"}
0005435125921	86ACEB	3318 325490	MARINA KUZNECOVA	{"email": "kuznecovam_111966@postgrespro.ru", "phone": "+70931846740"}
0005435125922	627780	7394 221533	GALINA DMITRIEVA	{"email": "dmitrieva-g-011964@postgrespro.ru", "phone": "+70358668828"}
0005435125923	F3B211	2253 636995	ANNA LOGINOVA	{"email": "loginova.anna.041981@postgrespro.ru", "phone": "+70304678180"}
0005435125924	F3B211	1159 003526	NIKOLAY GAVRILOV	{"phone": "+70260243400"}
0005435125925	4DD066	0706 786560	OLGA KISELEVA	{"phone": "+70422786647"}
0005435125926	4DD066	1368 426366	MARINA FROLOVA	{"email": "marina-frolova_091976@postgrespro.ru", "phone": "+70077942245"}
0005435125927	B8CE60	7089 710493	OLGA GAVRILOVA	{"phone": "+70541144684"}
0005435125928	FEDA26	5970 737552	SEMEN KONOVALOV	{"email": "konovalov.semen-04031962@postgrespro.ru", "phone": "+70003378106"}
0005435125929	0F1EDD	1926 815360	SVETLANA KISELEVA	{"email": "kiseleva_svetlana-1975@postgrespro.ru", "phone": "+70490124560"}
0005435125931	D7A771	8773 246637	VLADISLAV KISELEV	{"email": "kiselev_vladislav061966@postgrespro.ru", "phone": "+70066097628"}
0005435125932	D7A771	5568 437333	NATALIYA ERMAKOVA	{"phone": "+70685593909"}
0005435125933	CE73F0	5804 270605	ALEKSANDRA TIKHONOVA	{"phone": "+70051983286"}
0005435125934	9B9E4C	8386 812072	VIKTOR DMITRIEV	{"email": "v_dmitriev-29121981@postgrespro.ru", "phone": "+70258490168"}
0005435125935	24A06C	3917 526138	MARINA GAVRILOVA	{"email": "gavrilovamarina-03081975@postgrespro.ru", "phone": "+70465370854"}
0005435125936	32E147	9341 240012	NATALYA FADEEVA	{"email": "n-fadeeva-07121977@postgrespro.ru", "phone": "+70400260142"}
0005435125937	49C82C	9158 324602	OLEG DAVYDOV	{"phone": "+70937973194"}
0005435125938	0BA589	0790 770083	ALEKSEY SOROKIN	{"phone": "+70769734869"}
0005435125939	D535B0	2389 342595	BORIS ANTONOV	{"email": "borisantonov061964@postgrespro.ru", "phone": "+70607746660"}
0005435125940	36EAE4	6793 015702	ALEKSEY NOVIKOV	{"email": "a_novikov.02101970@postgrespro.ru", "phone": "+70104047015"}
0005435125941	BBC506	2155 052069	YULIYA MELNIKOVA	{"email": "y_melnikova.011968@postgrespro.ru", "phone": "+70650548958"}
0005435125942	CDCCF4	8877 127670	SERGEY ZHUKOV	{"email": "sergey_zhukov.19101960@postgrespro.ru", "phone": "+70039998644"}
0005435125943	BD7988	7247 564699	EVGENIY SMIRNOV	{"email": "smirnove_1971@postgrespro.ru", "phone": "+70341839441"}
0005435125944	FA70C8	6028 834934	VIKTOR NIKITIN	{"phone": "+70945361393"}
0005435125945	A4852A	7328 987793	ANDREY DENISOV	{"phone": "+70197880228"}
0005435125946	A4852A	6675 797138	KLAVDIYA PETROVA	{"phone": "+70732033038"}
0005435125947	2616A2	4100 855008	DENIS MAKAROV	{"email": "dmakarov.1979@postgrespro.ru", "phone": "+70252057327"}
0005435125948	C531AF	0140 126462	ANATOLIY PETROV	{"email": "petrov.anatoliy071975@postgrespro.ru", "phone": "+70228896747"}
0005435125949	C531AF	8329 716678	IRINA IVANOVA	{"phone": "+70670809978"}
0005435125950	956E99	2665 644267	SERGEY KOZLOV	{"email": "sergey-kozlov.06091968@postgrespro.ru", "phone": "+70759194730"}
0005435125951	9A1FE9	7953 997990	NINA KUZMINA	{"email": "kuzmina_n-081972@postgrespro.ru", "phone": "+70161476215"}
0005435125952	71EAE7	2653 071689	GALINA AKIMOVA	{"email": "galinaakimova13071980@postgrespro.ru", "phone": "+70078277003"}
0005435125953	71EAE7	4615 346151	IRINA DMITRIEVA	{"phone": "+70484517866"}
0005435125954	71EAE7	8652 978106	ANASTASIYA POPOVA	{"phone": "+70777320855"}
0005435125955	9A2D3E	9871 738501	LARISA FILATOVA	{"phone": "+70838787825"}
0005435125956	9A2D3E	0120 190728	VALENTINA STEPANOVA	{"phone": "+70782137251"}
0005435125957	A85472	1483 736035	VLADISLAV ISAEV	{"phone": "+70370396289"}
0005435125958	A85472	3893 349524	EKATERINA ANISIMOVA	{"phone": "+70161826734"}
0005435125959	A85472	2814 898177	LYUBOV ERMAKOVA	{"phone": "+70495849240"}
0005435125960	84ADD3	4194 264679	VIKTOR KISELEV	{"phone": "+70344984479"}
0005435125961	84ADD3	7131 330875	MATVEY ZAYCEV	{"email": "mzaycev_081974@postgrespro.ru", "phone": "+70942290599"}
0005435125962	C39AD4	0067 246360	ELENA KUZNECOVA	{"email": "ekuznecova.031975@postgrespro.ru", "phone": "+70643587055"}
0005435125963	F52B8A	6834 123958	ALEKSANDR BELOV	{"phone": "+70418651587"}
0005435125964	19E1BF	3804 876146	SERGEY POPOV	{"email": "popov.s-04021974@postgrespro.ru", "phone": "+70939086788"}
0005435125965	F00675	9523 594656	ARTEM FEDOTOV	{"phone": "+70141160937"}
0005435126381	DEBEFF	1882 221995	VERA KUZNECOVA	{"phone": "+70352546653"}
0005435125966	F00675	3962 905341	FARID ALEKSEEV	{"email": "alekseev_farid_1970@postgrespro.ru", "phone": "+70006819319"}
0005435125967	8EDAAF	5325 458014	MIKHAIL MIKHAYLOV	{"email": "m.mikhaylov_1967@postgrespro.ru", "phone": "+70708171320"}
0005435125968	DD160B	0264 407558	LYUBOV SAVELEVA	{"phone": "+70013543161"}
0005435125969	DD160B	5291 424459	VERA BELOVA	{"phone": "+70829280210"}
0005435125970	1B3E15	1893 400405	IRINA SOROKINA	{"phone": "+70232096928"}
0005435125971	33F10B	7973 425227	OLGA MAKSIMOVA	{"email": "maksimovaolga.051971@postgrespro.ru", "phone": "+70398645599"}
0005435125972	7CB8E8	5396 388746	DMITRIY OSIPOV	{"email": "osipov.dmitriy-091969@postgrespro.ru", "phone": "+70217341644"}
0005435125973	E47938	4202 357279	YULIYA SIDOROVA	{"phone": "+70557685977"}
0005435125974	A8C036	5563 593310	ARTEM ROMANOV	{"email": "romanov_artem1978@postgrespro.ru", "phone": "+70743350987"}
0005435125975	E79535	3478 211723	SERGEY IVANOV	{"email": "sergey-ivanov-16121971@postgrespro.ru", "phone": "+70659498690"}
0005435125976	E79535	4714 858817	SERGEY PETROV	{"email": "sergey_petrov_03071966@postgrespro.ru", "phone": "+70904119044"}
0005435125977	E79535	0627 604885	NINA POTAPOVA	{"email": "potapova.nina-07071959@postgrespro.ru", "phone": "+70251204502"}
0005435125978	6B8802	9884 515029	OLGA CHERNOVA	{"email": "chernova-olga1980@postgrespro.ru", "phone": "+70047642841"}
0005435125979	BBCB70	3364 712912	MARAT KISELEV	{"phone": "+70653221654"}
0005435125980	C6A9E9	4459 845272	DMITRIY VOLKOV	{"phone": "+70679213464"}
0005435125981	BD5425	6147 451411	ZINAIDA KONOVALOVA	{"email": "konovalova_z_1965@postgrespro.ru", "phone": "+70193371074"}
0005435125982	BD5425	2200 362235	NADEZHDA SOROKINA	{"email": "nsorokina-061974@postgrespro.ru", "phone": "+70630858635"}
0005435125983	A61E12	9708 830152	ALEKSANDR FROLOV	{"phone": "+70210976341"}
0005435125984	A61E12	6972 528536	PAVEL KOZLOV	{"phone": "+70177927234"}
0005435125985	FA66DA	3361 692943	EKATERINA NAZAROVA	{"phone": "+70086458777"}
0005435125986	FA66DA	1941 638082	KAPITALINA AKIMOVA	{"phone": "+70662235506"}
0005435126151	8F89A9	6211 582940	ANASTASIYA TARASOVA	{"phone": "+70223688565"}
0005435125987	7CB0E4	9862 037293	ELINA FILIPPOVA	{"email": "filippova.elina.021957@postgrespro.ru", "phone": "+70807259884"}
0005435125988	7CB0E4	4291 414609	LIDIYA ANDREEVA	{"email": "andreeva_l_111972@postgrespro.ru", "phone": "+70194175300"}
0005435125989	8BE032	6580 483620	STANISLAV FEDOROV	{"email": "fedorov.s071970@postgrespro.ru", "phone": "+70470797466"}
0005435125990	8BE032	1462 184903	LIDIYA EFIMOVA	{"email": "l_efimova.27041971@postgrespro.ru", "phone": "+70719251114"}
0005435125991	BB285F	0494 605837	SOFYA NIKIFOROVA	{"email": "nikiforova_sofya-1961@postgrespro.ru", "phone": "+70603208640"}
0005435125992	C2D91D	2054 528213	LYUDMILA MEDVEDEVA	{"phone": "+70382901311"}
0005435125993	DC86CA	6130 152395	ANASTASIYA ZHURAVLEVA	{"email": "a-zhuravleva.05101971@postgrespro.ru", "phone": "+70024106600"}
0005435125994	176EE4	2345 087048	ANTONINA ZHUKOVA	{"phone": "+70784854682"}
0005435125995	F19FFE	4710 202527	SVETLANA IVANOVA	{"phone": "+70822058950"}
0005435125996	A32E63	1433 338258	LIDIYA VOROBEVA	{"email": "l_vorobeva.25081985@postgrespro.ru", "phone": "+70519680860"}
0005435125997	2468A0	9796 499066	LYUBOV TARASOVA	{"phone": "+70148824506"}
0005435125998	2468A0	7571 433820	MIKHAIL ZAYCEV	{"email": "zaycev-mikhail.021971@postgrespro.ru", "phone": "+70411519879"}
0005435125999	2468A0	8561 377615	ALEKSANDR DENISOV	{"email": "aleksandr.denisov081968@postgrespro.ru", "phone": "+70281038179"}
0005435126000	634401	9232 632721	VALENTINA VOLKOVA	{"email": "volkova.v031982@postgrespro.ru", "phone": "+70871813967"}
0005435126001	96C98B	0098 139283	EVGENIY POPOV	{"phone": "+70288242957"}
0005435126002	8FA102	1758 105913	SERGEY VASILEV	{"email": "s_vasilev-29041972@postgrespro.ru", "phone": "+70757916000"}
0005435126003	8FA102	0273 296213	ELENA BELYAEVA	{"email": "e_belyaeva-1970@postgrespro.ru", "phone": "+70447766609"}
0005435126004	9D0BF4	0510 252973	ALBINA ALEKSANDROVA	{"phone": "+70078259871"}
0005435126005	9D0BF4	3332 915492	MAKSIM KARPOV	{"email": "maksim_karpov_071984@postgrespro.ru", "phone": "+70527001128"}
0005435126006	A4B94F	7537 180024	OLGA ABRAMOVA	{"phone": "+70951903643"}
0005435126007	A4B94F	0187 780728	RODION SMIRNOV	{"phone": "+70719316062"}
0005435126008	337EDE	9919 393060	MARINA BELOVA	{"email": "m_belova-1965@postgrespro.ru", "phone": "+70737363686"}
0005435126009	733F31	5386 532394	VLADIMIR MELNIKOV	{"phone": "+70028345269"}
0005435126010	23F616	1373 618377	VITALIY FEDOTOV	{"phone": "+70249485707"}
0005435126011	23F616	3769 769539	IRINA SMIRNOVA	{"email": "i_smirnova1967@postgrespro.ru", "phone": "+70470466075"}
0005435126012	E71D0D	6687 547648	SVETLANA MAKSIMOVA	{"email": "maksimova-s_071981@postgrespro.ru", "phone": "+70524772946"}
0005435126013	E71D0D	1708 830702	NADEZHDA KULIKOVA	{"phone": "+70078176649"}
0005435126014	E71D0D	9634 537522	MIKHAIL ANDREEV	{"phone": "+70252744256"}
0005435126015	4EDEE2	2943 504867	ALBINA ALEKSEEVA	{"phone": "+70166885229"}
0005435126016	A6BB01	4567 095314	ALEKSEY FROLOV	{"email": "frolova-031975@postgrespro.ru", "phone": "+70927628169"}
0005435126017	A6BB01	5981 644385	MARINA BELOVA	{"email": "m-belova.081975@postgrespro.ru", "phone": "+70197406075"}
0005435126018	93460E	6068 608925	DMITRIY VASILEV	{"email": "d_vasilev.1975@postgrespro.ru", "phone": "+70155415671"}
0005435126019	20C41B	2931 721706	MAKSIM NOVIKOV	{"email": "novikov-m-061971@postgrespro.ru", "phone": "+70125503687"}
0005435126020	3E7EF9	4391 655537	ALBERT MIKHAYLOV	{"email": "mikhaylov.a-051978@postgrespro.ru", "phone": "+70492407666"}
0005435126021	60104F	0268 866840	SERGEY SAVELEV	{"email": "savelev-s_1974@postgrespro.ru", "phone": "+70554098965"}
0005435126022	E1B50C	3188 733721	NADEZHDA ILINA	{"email": "nadezhda.ilina_1967@postgrespro.ru", "phone": "+70488847412"}
0005435126023	8E1DFF	0318 946642	LYUBOV GORBUNOVA	{"email": "gorbunova-lyubov.051970@postgrespro.ru", "phone": "+70722313366"}
0005435126026	C6B03B	8470 513915	YURIY FEDOTOV	{"email": "yfedotov071979@postgrespro.ru", "phone": "+70955431658"}
0005435126027	CDB374	4782 723990	ALEKSANDR ABRAMOV	{"phone": "+70503550803"}
0005435126028	A6938E	8037 524571	VIKTOR VASILEV	{"phone": "+70985286680"}
0005435126029	547918	5349 516505	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a1982@postgrespro.ru", "phone": "+70258752876"}
0005435126030	BF2831	8354 934512	SOFIYA ZAYCEVA	{"email": "zaycevas_061977@postgrespro.ru", "phone": "+70414868157"}
0005435126031	380101	3636 329742	ANATOLIY VASILEV	{"email": "vasilev_anatoliy1969@postgrespro.ru", "phone": "+70579378214"}
0005435126032	380101	1111 120117	VIKTOR MATVEEV	{"email": "viktor.matveev.081986@postgrespro.ru", "phone": "+70123457153"}
0005435126033	22AFBD	9341 873813	ALEKSANDR NIKITIN	{"phone": "+70463340677"}
0005435126034	22AFBD	5459 838072	VALENTIN TIMOFEEV	{"email": "timofeev_v-1985@postgrespro.ru", "phone": "+70667518297"}
0005435126035	497AB7	3422 435946	ALEKSANDRA TIKHONOVA	{"email": "a_tikhonova.111971@postgrespro.ru", "phone": "+70566026553"}
0005435126036	497AB7	4178 254712	RAFAIL DENISOV	{"phone": "+70619403011"}
0005435126037	497AB7	9964 371806	NADEZHDA FROLOVA	{"email": "frolova_n.061966@postgrespro.ru", "phone": "+70965268433"}
0005435126038	83F47E	8274 906144	NIKOLAY FILIPPOV	{"email": "filippovn.29061977@postgrespro.ru", "phone": "+70297725282"}
0005435126039	3FADC3	5056 928826	TAMARA IVANOVA	{"email": "tamara.ivanova1983@postgrespro.ru", "phone": "+70932388398"}
0005435126040	5F1EA6	6078 058789	YURIY ZAKHAROV	{"phone": "+70237656992"}
0005435126041	D02F29	5632 170991	KLAVDIYA TITOVA	{"phone": "+70962419469"}
0005435126042	A7E9B8	5601 691306	RAMIL TIMOFEEV	{"email": "timofeev.r30071976@postgrespro.ru", "phone": "+70366424769"}
0005435126043	C6304F	2901 701323	ANATOLIY IVANOV	{"email": "ivanov-anatoliy29031975@postgrespro.ru", "phone": "+70507904444"}
0005435126044	C6304F	0902 812671	ANNA MIRONOVA	{"email": "a_mironova06051973@postgrespro.ru", "phone": "+70863103276"}
0005435126045	C6304F	3118 717338	SVETLANA MAKSIMOVA	{"email": "svetlana_maksimova10081973@postgrespro.ru", "phone": "+70878581724"}
0005435126046	BCD1C2	9562 461244	DARYA LUKYANOVA	{"phone": "+70473458096"}
0005435126047	BCD1C2	3344 227516	EVGENIY SAVELEV	{"email": "e.savelev.071969@postgrespro.ru", "phone": "+70013272586"}
0005435126048	F91E9A	3731 225086	ANASTASIYA KAZAKOVA	{"email": "kazakovaanastasiya08111970@postgrespro.ru", "phone": "+70767524684"}
0005435126049	F91E9A	7108 970757	AMINA EGOROVA	{"email": "egorova_a.16031981@postgrespro.ru", "phone": "+70881185666"}
0005435126050	F91E9A	8155 085841	NINA SOROKINA	{"email": "nina_sorokina.1980@postgrespro.ru", "phone": "+70828384224"}
0005435126051	6D0F3D	1105 712085	SERGEY SHEVCHENKO	{"phone": "+70775761763"}
0005435126052	6D0F3D	5049 960366	IRINA NIKITINA	{"email": "nikitina-irina.1978@postgrespro.ru", "phone": "+70887170707"}
0005435126053	A68ADA	9645 498585	ELENA PAVLOVA	{"email": "e-pavlova-051969@postgrespro.ru", "phone": "+70785058314"}
0005435126054	A68ADA	4468 824964	PAVEL YAKOVLEV	{"phone": "+70910663719"}
0005435126055	3C413B	2527 147210	DAVID ILIN	{"phone": "+70290445532"}
0005435126056	AA0AB9	4963 278748	TATYANA IVANOVA	{"phone": "+70964031056"}
0005435126057	F5A52C	8363 008273	ZINAIDA KOMAROVA	{"email": "komarovazinaida_02111973@postgrespro.ru", "phone": "+70076128564"}
0005435126058	F5A52C	4099 061291	ANDREY DENISOV	{"email": "denisov-a.1973@postgrespro.ru", "phone": "+70099053912"}
0005435126059	A26F63	6188 922778	DARYA ALEKSEEVA	{"phone": "+70070943422"}
0005435126060	016DE2	1372 406283	ALEKSANDR BELOV	{"phone": "+70427355430"}
0005435126061	940D61	1167 236300	TATYANA MELNIKOVA	{"phone": "+70087998999"}
0005435126062	833E6C	8351 105899	SERGEY ANDREEV	{"email": "sergeyandreev.051970@postgrespro.ru", "phone": "+70489543943"}
0005435126063	833E6C	0622 373476	NADEZHDA OVCHINNIKOVA	{"email": "nadezhdaovchinnikova-20071974@postgrespro.ru", "phone": "+70816509658"}
0005435126064	AC7A53	6679 614049	ILYA SERGEEV	{"email": "sergeev_ilya-27031975@postgrespro.ru", "phone": "+70730332635"}
0005435126065	F4E7F8	8213 398298	NINA ILINA	{"phone": "+70665165746"}
0005435126066	867E43	0280 214137	GENNADIY ZAKHAROV	{"email": "gzakharov031972@postgrespro.ru", "phone": "+70659986168"}
0005435126067	867E43	3416 982835	VALENTINA BORISOVA	{"email": "borisova.v-1974@postgrespro.ru", "phone": "+70971280577"}
0005435126068	C49E64	1372 271991	ROZA LUKYANOVA	{"phone": "+70247068924"}
0005435126069	EA6312	8401 416859	VALENTINA BELYAEVA	{"email": "belyaeva_v.071973@postgrespro.ru", "phone": "+70701483692"}
0005435126070	0CD097	4471 888918	DIANA BARANOVA	{"email": "diana_baranova-1965@postgrespro.ru", "phone": "+70182202042"}
0005435126071	0588EF	4956 633141	LYUDMILA EFIMOVA	{"email": "efimova-l_28081966@postgrespro.ru", "phone": "+70513836607"}
0005435126072	A283EB	2630 925374	IRINA LOGINOVA	{"email": "i_loginova.121980@postgrespro.ru", "phone": "+70478611846"}
0005435126073	A283EB	2305 641545	ANNA ZAKHAROVA	{"email": "anna_zakharova061983@postgrespro.ru", "phone": "+70140471150"}
0005435126074	B27C2C	5770 965261	ROMAN VOLKOV	{"email": "r-volkov1977@postgrespro.ru", "phone": "+70706571122"}
0005435126075	46188A	6433 817344	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova-17011979@postgrespro.ru", "phone": "+70581370298"}
0005435126076	9CC4E2	4818 214129	RAFAEL ZAKHAROV	{"email": "rafael-zakharov_1972@postgrespro.ru", "phone": "+70637338556"}
0005435126077	9CC4E2	3435 728447	NINA MOISEEVA	{"phone": "+70080482344"}
0005435126078	F4D78E	7080 934311	NADEZHDA MALYSHEVA	{"email": "malyshevanadezhda.17101972@postgrespro.ru", "phone": "+70202643854"}
0005435126079	DFA909	4658 149525	IGOR TARASOV	{"phone": "+70105238280"}
0005435126080	244011	4301 954827	ARTEM GUSEV	{"phone": "+70780402972"}
0005435126081	244011	7230 301082	NIKITA BARANOV	{"email": "nikita_baranov061979@postgrespro.ru", "phone": "+70491314549"}
0005435126082	28CEA6	5471 101031	MARINA BELOVA	{"email": "belovamarina-05031975@postgrespro.ru", "phone": "+70115279390"}
0005435126083	F73C63	0996 809790	RAVIL IVANOV	{"email": "ravil_ivanov1977@postgrespro.ru", "phone": "+70085295363"}
0005435126084	80F156	9107 194121	RAISA VOROBEVA	{"phone": "+70643093186"}
0005435126085	7AA030	0383 136477	EKATERINA MEDVEDEVA	{"phone": "+70137943869"}
0005435126086	D867E7	9823 216596	RAISA SEMENOVA	{"phone": "+70484270836"}
0005435126087	9F035A	1726 298403	IVAN IVANOV	{"email": "ivan_ivanov14101988@postgrespro.ru", "phone": "+70883251845"}
0005435126088	5846A9	6942 425618	STANISLAV SOROKIN	{"phone": "+70621278780"}
0005435126089	08C374	8538 138673	VIKTOR DENISOV	{"phone": "+70160809437"}
0005435126090	08C374	0039 491337	SERGEY MOROZOV	{"phone": "+70975983385"}
0005435126091	3ED961	0604 304734	NIKOLAY FROLOV	{"phone": "+70693367435"}
0005435126092	3ED961	4322 010220	ALEKSANDR MAKSIMOV	{"phone": "+70047616600"}
0005435126093	5B9DD3	7197 209114	OLGA KARPOVA	{"phone": "+70738334621"}
0005435126094	385ADA	8932 904691	TATYANA GORBUNOVA	{"phone": "+70774125467"}
0005435126095	385ADA	3741 701890	LYUDMILA FEDOROVA	{"email": "fedorova_l-081981@postgrespro.ru", "phone": "+70425033684"}
0005435126096	BC563C	6654 031463	VASILIY MAKSIMOV	{"email": "vmaksimov29121976@postgrespro.ru", "phone": "+70568893954"}
0005435126208	1E9138	1510 975067	NADEZHDA POPOVA	{"phone": "+70812537727"}
0005435126097	BC563C	1694 484000	ANNA DMITRIEVA	{"email": "a.dmitrieva121971@postgrespro.ru", "phone": "+70859103935"}
0005435126098	B6E579	9814 248327	DENIS KUZNECOV	{"email": "d-kuznecov.1971@postgrespro.ru", "phone": "+70409229523"}
0005435126099	F4A1CD	4630 377690	NIKOLAY IVANOV	{"email": "n_ivanov101979@postgrespro.ru", "phone": "+70848142949"}
0005435126100	059822	5214 326045	VLADIMIR ROMANOV	{"phone": "+70829131406"}
0005435126101	059822	1882 096457	SERGEY TIKHONOV	{"email": "sergey-tikhonov-30121960@postgrespro.ru", "phone": "+70287989021"}
0005435126102	42776D	9250 642059	EKATERINA ERMAKOVA	{"email": "e-ermakova_1968@postgrespro.ru", "phone": "+70900669897"}
0005435126103	4EF242	6903 320112	ELENA SOROKINA	{"email": "e-sorokina.1982@postgrespro.ru", "phone": "+70051195255"}
0005435126104	41EC09	6528 766960	LEONID NAUMOV	{"email": "naumov_l.021974@postgrespro.ru", "phone": "+70870127891"}
0005435126105	41EC09	6307 251512	VYACHESLAV SIDOROV	{"email": "vyacheslavsidorov11051979@postgrespro.ru", "phone": "+70563558287"}
0005435126106	8A7AFE	4937 591027	VLADIMIR CHERNOV	{"phone": "+70936761170"}
0005435126107	0244BF	9802 047388	TATYANA KULIKOVA	{"email": "tatyanakulikova-091959@postgrespro.ru", "phone": "+70089822464"}
0005435126108	0244BF	1622 473757	ALEKSANDR SEMENOV	{"email": "aleksandr.semenov021980@postgrespro.ru", "phone": "+70549655895"}
0005435126109	1A5EF2	4075 790826	LIDIYA GORBUNOVA	{"phone": "+70813866363"}
0005435126110	41C117	8430 627581	MARINA TIKHONOVA	{"phone": "+70906350367"}
0005435126111	A97878	0596 782639	VLADIMIR STEPANOV	{"email": "vladimirstepanov-1972@postgrespro.ru", "phone": "+70344176430"}
0005435126112	444020	3566 834748	OLGA OVCHINNIKOVA	{"email": "o-ovchinnikova.111974@postgrespro.ru", "phone": "+70795565466"}
0005435126113	2902B8	4086 246313	ALEKSEY IVANOV	{"email": "ivanov-aleksey.18091958@postgrespro.ru", "phone": "+70180536965"}
0005435126114	2902B8	4576 766150	KRISTINA NOVIKOVA	{"phone": "+70884963591"}
0005435126115	2A4494	1210 069464	ANDREY ANTONOV	{"phone": "+70070991685"}
0005435126116	448F03	4405 622930	RUSTEM DENISOV	{"phone": "+70845122523"}
0005435126117	7EAB94	8834 581953	MIKHAIL BONDARENKO	{"email": "m_bondarenko_111966@postgrespro.ru", "phone": "+70328962816"}
0005435126118	0968A9	4098 394354	ARTUR SERGEEV	{"email": "artur_sergeev_1969@postgrespro.ru", "phone": "+70885112015"}
0005435126119	0968A9	2494 899267	EVGENIY BARANOV	{"phone": "+70456213059"}
0005435126120	6C77AB	0833 629043	ANNA KOMAROVA	{"phone": "+70063921392"}
0005435126121	7C3FFE	7927 242869	EVGENIY KARPOV	{"email": "karpov-evgeniy20041970@postgrespro.ru", "phone": "+70043994024"}
0005435126122	7C3FFE	9915 324244	DANIYA CHERNOVA	{"phone": "+70308439436"}
0005435126123	7320CC	2292 124129	ZULFIYA NIKITINA	{"email": "nikitina-zulfiya21101980@postgrespro.ru", "phone": "+70057000051"}
0005435126124	7320CC	5860 714434	TAMARA MELNIKOVA	{"email": "melnikova_t-07101984@postgrespro.ru", "phone": "+70143012901"}
0005435126125	A33479	2836 711515	IGOR ROMANOV	{"phone": "+70483766498"}
0005435126126	ECEECC	2494 150288	MILENA ILINA	{"phone": "+70678895043"}
0005435126127	5B5BB9	6275 426142	ANASTASIYA EFREMOVA	{"phone": "+70719923912"}
0005435126128	5B5BB9	4191 504649	VLADIMIR MOROZOV	{"email": "morozov-vladimir.19081970@postgrespro.ru", "phone": "+70000470032"}
0005435126129	A3D40C	6764 140048	RUSTAM KUZMIN	{"email": "kuzmin_rustam.1960@postgrespro.ru", "phone": "+70517682864"}
0005435126130	A3D40C	5177 636209	VIKTORIYA GERASIMOVA	{"phone": "+70033094731"}
0005435126131	BBAFCD	4492 250298	ALBINA KUZNECOVA	{"phone": "+70487550769"}
0005435126132	BBAFCD	9920 628376	ELENA VASILEVA	{"email": "evasileva_1964@postgrespro.ru", "phone": "+70019922271"}
0005435126133	5F3F1C	5981 231484	TATYANA FOMINA	{"email": "fominat_1957@postgrespro.ru", "phone": "+70803934895"}
0005435126134	5A898E	4746 265164	SOFIYA DAVYDOVA	{"email": "davydova_s.061982@postgrespro.ru", "phone": "+70270799542"}
0005435126135	CB2042	9025 950834	IRINA TARASOVA	{"email": "i-tarasova-051981@postgrespro.ru", "phone": "+70354530323"}
0005435126136	CB2042	3797 000408	NATALYA GERASIMOVA	{"email": "gerasimova_n1970@postgrespro.ru", "phone": "+70520434302"}
0005435126137	C8455B	8766 505864	NATALYA GORBUNOVA	{"email": "n-gorbunova.081966@postgrespro.ru", "phone": "+70601248375"}
0005435126138	C8455B	1348 376625	GEORGIY ORLOV	{"email": "g.orlov_1985@postgrespro.ru", "phone": "+70996001967"}
0005435126139	BB6AAC	2139 078323	SERGEY BARANOV	{"email": "baranov_s-02061974@postgrespro.ru", "phone": "+70204214582"}
0005435126140	DA6700	5569 145983	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov17091968@postgrespro.ru", "phone": "+70019534360"}
0005435126141	B55AD6	3189 765294	MARIYA PETROVA	{"phone": "+70557791558"}
0005435126143	BF4A81	7621 340882	VERA BOGDANOVA	{"email": "vera.bogdanova_25021966@postgrespro.ru", "phone": "+70544595389"}
0005435126144	BF4A81	9474 709828	VALENTINA PAVLOVA	{"email": "v.pavlova-1971@postgrespro.ru", "phone": "+70406471172"}
0005435126145	E434DB	8321 215881	ALEKSANDR KUZNECOV	{"email": "kuznecov-aleksandr_081975@postgrespro.ru", "phone": "+70077570998"}
0005435126146	FFE703	1970 584725	ALEKSANDR NOVIKOV	{"email": "a_novikov.06031970@postgrespro.ru", "phone": "+70633160886"}
0005435126147	FFE703	9942 457005	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev.111963@postgrespro.ru", "phone": "+70629967519"}
0005435126148	FFE703	1329 897252	OLEG MIKHAYLOV	{"phone": "+70899696794"}
0005435126149	70E6B2	0021 309027	YULIYA EFREMOVA	{"email": "efremova.yuliya1970@postgrespro.ru", "phone": "+70319955640"}
0005435126150	FEFE37	3024 119221	YURIY KRASNOV	{"email": "yuriy.krasnov.12031979@postgrespro.ru", "phone": "+70246229139"}
0005435126152	8D11F2	1261 468294	TATYANA EGOROVA	{"email": "egorova-tatyana.011972@postgrespro.ru", "phone": "+70346194947"}
0005435126153	8D11F2	8444 412969	GULNAZ KOZLOVA	{"email": "g.kozlova-21101974@postgrespro.ru", "phone": "+70401167347"}
0005435126154	0F9954	1054 689124	IVAN CHERNOV	{"email": "ivan_chernov.03081964@postgrespro.ru", "phone": "+70567649623"}
0005435126155	0F9954	5448 094157	ANNA GORBUNOVA	{"phone": "+70249288008"}
0005435126156	E58EA6	9134 933320	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev_051982@postgrespro.ru", "phone": "+70192880776"}
0005435126157	ED4E8F	8007 087990	IVAN TARASOV	{"phone": "+70625433783"}
0005435126158	ED4E8F	5071 112374	SERGEY KULIKOV	{"email": "s-kulikov.021962@postgrespro.ru", "phone": "+70823044614"}
0005435126159	756ABB	6359 952708	IGOR NAUMOV	{"phone": "+70406964884"}
0005435126160	AF34E1	3504 349053	MATVEY NAUMOV	{"phone": "+70494934777"}
0005435126161	AF34E1	1020 513546	VLADISLAV GORBUNOV	{"email": "gorbunovvladislav_20121977@postgrespro.ru", "phone": "+70896111628"}
0005435126162	676C4E	7556 867529	IGOR ANDREEV	{"phone": "+70140406611"}
0005435126163	028995	8897 647934	EGOR VOLKOV	{"phone": "+70967835181"}
0005435126164	028995	0396 641190	OLESYA STEPANOVA	{"phone": "+70697834925"}
0005435126165	028995	2944 923835	ANDREY YAKOVLEV	{"email": "andrey-yakovlev1967@postgrespro.ru", "phone": "+70823162881"}
0005435126166	B483E5	7208 739052	TATYANA MAKSIMOVA	{"email": "tatyana.maksimova121981@postgrespro.ru", "phone": "+70685088140"}
0005435126167	B483E5	1260 080492	IRINA NIKOLAEVA	{"email": "irina.nikolaeva-14081968@postgrespro.ru", "phone": "+70784722108"}
0005435126168	05191D	8588 552492	LYUDMILA SAVELEVA	{"email": "saveleva-l-061975@postgrespro.ru", "phone": "+70832234657"}
0005435126169	53C346	8793 548496	SERGEY OSIPOV	{"email": "osipov.sergey_011978@postgrespro.ru", "phone": "+70426137903"}
0005435126170	BFE097	3615 793192	ALEKSANDR VLASOV	{"phone": "+70937769279"}
0005435126171	A85063	9172 243888	SVETLANA GRISHINA	{"phone": "+70631877248"}
0005435126172	A85063	6702 152823	MARINA DAVYDOVA	{"email": "davydova_marina.1965@postgrespro.ru", "phone": "+70977601057"}
0005435126173	2D2314	8091 899688	LYUBOV BELYAEVA	{"phone": "+70736363441"}
0005435126174	7C6AE5	9651 824290	KSENIYA MIKHAYLOVA	{"phone": "+70343926017"}
0005435126175	2ECF1D	1650 929185	DAMIR SEMENOV	{"phone": "+70253046956"}
0005435126176	2ECF1D	0324 616592	AZAT VLASOV	{"phone": "+70348301517"}
0005435126177	78F3EB	6983 446006	ALEKSANDR KRASNOV	{"email": "krasnov_a.20121964@postgrespro.ru", "phone": "+70483358936"}
0005435126178	87392E	5406 189747	VYACHESLAV KUZNECOV	{"phone": "+70363325682"}
0005435126179	D59FCC	9559 668806	TATYANA TARASOVA	{"phone": "+70506727862"}
0005435126180	A7B4E1	3195 943321	MARINA MOROZOVA	{"phone": "+70168589956"}
0005435126181	A7B4E1	7433 760902	LYUBOV TIKHONOVA	{"phone": "+70227264559"}
0005435126182	A7B4E1	2755 815618	NINA SOKOLOVA	{"phone": "+70074110945"}
0005435126183	EF2869	2542 459248	OLEG KRASNOV	{"email": "krasnovo_02071970@postgrespro.ru", "phone": "+70736575144"}
0005435126184	EF2869	5426 570152	VIKTOR NAZAROV	{"email": "nazarov.v_081978@postgrespro.ru", "phone": "+70164401986"}
0005435126185	9CEF04	9209 508020	ELENA DMITRIEVA	{"phone": "+70011688458"}
0005435126186	3E6280	4340 273347	IRINA KUZNECOVA	{"email": "ikuznecova1972@postgrespro.ru", "phone": "+70823888450"}
0005435126187	0A9BA7	6444 776043	LARISA POPOVA	{"email": "popova-larisa-20081973@postgrespro.ru", "phone": "+70418382427"}
0005435126188	D31B3D	7446 036866	VLADIMIR KAZAKOV	{"email": "vladimir_kazakov_21091976@postgrespro.ru", "phone": "+70605938785"}
0005435126189	D31B3D	2698 321931	RAVIL YAKOVLEV	{"email": "yakovlev-ravil.051971@postgrespro.ru", "phone": "+70674529252"}
0005435126190	27B957	6314 625987	ANNA SOROKINA	{"email": "sorokinaanna.18101986@postgrespro.ru", "phone": "+70752593886"}
0005435126191	B7CE3C	9792 678452	DMITRIY BORISOV	{"email": "d.borisov.16051977@postgrespro.ru", "phone": "+70448823581"}
0005435126192	B7CE3C	7957 248548	ANASTASIYA BELOVA	{"email": "belova.anastasiya.1979@postgrespro.ru", "phone": "+70611727701"}
0005435126193	357706	0146 630609	MATVEY VLASOV	{"email": "mvlasov-1973@postgrespro.ru", "phone": "+70655117712"}
0005435126194	A0711C	6090 603167	DMITRIY KONOVALOV	{"email": "konovalov_dmitriy_111971@postgrespro.ru", "phone": "+70814036095"}
0005435126195	CC46CF	5340 931448	ALENA ALEKSEEVA	{"email": "alekseevaalena.1964@postgrespro.ru", "phone": "+70893415828"}
0005435126196	CC46CF	7616 076267	IRINA KOROLEVA	{"phone": "+70464807160"}
0005435126197	CC46CF	0915 575629	SERGEY SOKOLOV	{"email": "sokolov-sergey.24011978@postgrespro.ru", "phone": "+70314900988"}
0005435126198	235146	6173 199881	YULIYA VASILEVA	{"email": "y.vasileva01071981@postgrespro.ru", "phone": "+70984814082"}
0005435126199	235146	3043 992311	DENIS ANDREEV	{"email": "d_andreev-071968@postgrespro.ru", "phone": "+70353507015"}
0005435126200	36AF5A	8316 033828	MARIYA BARANOVA	{"phone": "+70292605289"}
0005435126201	36AF5A	2556 381180	ALEKSANDR POPOV	{"phone": "+70036908023"}
0005435126202	AD1688	9858 278524	ALEKSANDR ANTONOV	{"phone": "+70573490643"}
0005435126203	AD1688	6154 974619	ANDREY KARPOV	{"email": "andrey.karpov041959@postgrespro.ru", "phone": "+70936005008"}
0005435126204	1BFA02	9744 022900	ANTONINA KALININA	{"phone": "+70609559918"}
0005435126205	1BFA02	2830 305648	MARAT MOISEEV	{"email": "m_moiseev.1962@postgrespro.ru", "phone": "+70404022335"}
0005435126206	1BFA02	3783 108918	VITALIY KOROLEV	{"phone": "+70076085127"}
0005435126207	3EC42A	4729 292129	OLGA TIKHONOVA	{"email": "tikhonova-o23041980@postgrespro.ru", "phone": "+70246738022"}
0005435126209	B5EEAC	5525 929798	TATYANA ROMANOVA	{"phone": "+70522124201"}
0005435126210	F7F92E	1519 253806	VYACHESLAV GUSEV	{"phone": "+70326974243"}
0005435126211	9F0EF4	8428 234093	ALBINA SOROKINA	{"email": "asorokina1973@postgrespro.ru", "phone": "+70088880453"}
0005435126212	E4855C	4688 390880	NINA MALYSHEVA	{"email": "nina_malysheva.27031979@postgrespro.ru", "phone": "+70636830434"}
0005435126213	E4855C	4860 345094	ALEKSEY GAVRILOV	{"email": "gavrilov-aleksey-081983@postgrespro.ru", "phone": "+70485519581"}
0005435126214	E4855C	6590 597682	EVGENIY ABRAMOV	{"phone": "+70600100611"}
0005435126215	852FC9	4676 773332	MAKSIM MAKSIMOV	{"phone": "+70174673450"}
0005435126216	FA88BC	1620 792845	NIKITA NIKITIN	{"phone": "+70456853095"}
0005435126217	FA88BC	8193 688955	EVGENIY PAVLOV	{"phone": "+70021559745"}
0005435126218	1702E8	8800 807170	LARISA KAZAKOVA	{"email": "larisa.kazakova-13061979@postgrespro.ru", "phone": "+70334108994"}
0005435126219	08E98D	3801 108893	LYUDMILA EGOROVA	{"email": "lyudmila_egorova.1957@postgrespro.ru", "phone": "+70293125605"}
0005435126220	5D908B	4773 330946	VIKTOR SMIRNOV	{"email": "vsmirnov-1971@postgrespro.ru", "phone": "+70143894126"}
0005435126221	3CC99C	0175 222372	EKATERINA BORISOVA	{"email": "ekaterina.borisova-27071976@postgrespro.ru", "phone": "+70848006808"}
0005435126222	2AAD18	3868 526576	VERONIKA IVANOVA	{"email": "ivanova-veronika.1973@postgrespro.ru", "phone": "+70042246331"}
0005435126223	938CAA	8345 143803	ALENA KALININA	{"phone": "+70129911246"}
0005435126224	7FF03E	3832 399317	ANDREY PETROV	{"email": "a_petrov_23111969@postgrespro.ru", "phone": "+70029240369"}
0005435126225	DBE435	3936 230466	VLADIMIR VOROBEV	{"phone": "+70191942303"}
0005435126226	DBE435	3911 863278	MARIYA NIKOLAEVA	{"phone": "+70965703183"}
0005435126227	DBE435	3949 413568	IGOR FROLOV	{"email": "ifrolov08021977@postgrespro.ru", "phone": "+70435436868"}
0005435126228	B7FC25	0556 960254	VIKTORIYA FILIPPOVA	{"phone": "+70156713176"}
0005435126229	61B800	9835 376526	GENNADIY BORISOV	{"email": "gborisov1986@postgrespro.ru", "phone": "+70742065873"}
0005435126230	61B800	0386 367322	IRINA IVANOVA	{"email": "i-ivanova.061982@postgrespro.ru", "phone": "+70285568074"}
0005435126231	7CDA35	6007 480119	ANDREY DMITRIEV	{"phone": "+70493264774"}
0005435126232	42B181	1477 666810	VERA PAVLOVA	{"phone": "+70242824401"}
0005435126233	6E5222	2000 312468	ALEKSANDRA MIKHAYLOVA	{"phone": "+70837085018"}
0005435126234	6E5222	1191 389776	NATALYA FEDOROVA	{"email": "n.fedorova.08101973@postgrespro.ru", "phone": "+70683724618"}
0005435126235	FC5F17	4012 035631	PETR GAVRILOV	{"phone": "+70726674206"}
0005435126236	FC5F17	3989 963405	NADEZHDA NOVIKOVA	{"phone": "+70327926297"}
0005435126237	FC5F17	1961 838724	ANATOLIY KISELEV	{"email": "kiselev-a-19031973@postgrespro.ru", "phone": "+70733124057"}
0005435126238	3C1DDA	2802 418079	TAMARA KALININA	{"email": "tamara_kalinina_1970@postgrespro.ru", "phone": "+70239329419"}
0005435126239	612779	7798 193623	VIKTOR MELNIKOV	{"email": "v.melnikov.02091968@postgrespro.ru", "phone": "+70992398781"}
0005435126240	50B074	5324 396089	YULIYA SOKOLOVA	{"phone": "+70116234652"}
0005435126241	50B074	1993 155218	YURIY KUZMIN	{"email": "y.kuzmin071960@postgrespro.ru", "phone": "+70682783202"}
0005435126242	50B074	6152 120750	YANA KARPOVA	{"email": "yana_karpova17071966@postgrespro.ru", "phone": "+70521836835"}
0005435126243	EF3D81	8324 498724	DMITRIY NOVIKOV	{"email": "novikov-d_121970@postgrespro.ru", "phone": "+70292968570"}
0005435126244	DD3062	8538 506319	SERGEY SMIRNOV	{"email": "smirnov.s_1971@postgrespro.ru", "phone": "+70893465005"}
0005435126245	0F372A	7541 476050	TAMARA FILIPPOVA	{"email": "tamara.filippova_1972@postgrespro.ru", "phone": "+70645770269"}
0005435126246	CC786F	5302 852097	ANASTASIYA KONDRATEVA	{"email": "anastasiya_kondrateva.1967@postgrespro.ru", "phone": "+70382576912"}
0005435126247	CC786F	5095 574230	ANDREY TIMOFEEV	{"email": "timofeev.andrey-1972@postgrespro.ru", "phone": "+70493196254"}
0005435126248	99E6F9	6511 744535	YULIYA GUSEVA	{"phone": "+70217555546"}
0005435126249	410D2D	7100 145374	IGOR KULIKOV	{"phone": "+70224304315"}
0005435126250	410D2D	6027 863634	OLGA SAVELEVA	{"phone": "+70809606156"}
0005435126251	E97834	0128 026892	ALEKSANDR ABRAMOV	{"phone": "+70416368865"}
0005435126252	836E33	8064 620202	MIKHAIL SCHERBAKOV	{"email": "scherbakov.m_041979@postgrespro.ru", "phone": "+70974476476"}
0005435126253	E83DDD	9410 224112	ANDREY SIDOROV	{"phone": "+70588303128"}
0005435126254	7FD7C1	0979 002563	ANASTASIYA VLASOVA	{"email": "a.vlasova_26011974@postgrespro.ru", "phone": "+70388438579"}
0005435126255	3A563E	0659 909049	ANATOLIY ORLOV	{"email": "orlov-a_1966@postgrespro.ru", "phone": "+70982286518"}
0005435126256	EE3B88	0168 751114	ELENA MAKSIMOVA	{"phone": "+70756890899"}
0005435126257	333EEF	9204 644756	TATYANA ROMANOVA	{"phone": "+70579390209"}
0005435126258	B6C986	7048 193886	TATYANA IVANOVA	{"email": "tatyana.ivanova-121981@postgrespro.ru", "phone": "+70760449417"}
0005435126259	B6C986	1900 973743	NIKOLAY VOROBEV	{"email": "vorobevn_051974@postgrespro.ru", "phone": "+70281519402"}
0005435126260	F3AC16	6750 964198	TATYANA FEDOROVA	{"email": "tatyana_fedorova_091975@postgrespro.ru", "phone": "+70257559192"}
0005435126261	F3AC16	2484 050052	DMITRIY ORLOV	{"phone": "+70868986393"}
0005435126262	8BF156	0098 465089	SVETLANA TITOVA	{"phone": "+70839625040"}
0005435126263	8BF156	6392 312645	SVETLANA MELNIKOVA	{"phone": "+70731320527"}
0005435126265	4CB325	4812 797217	VLADIMIR MARTYNOV	{"email": "martynov_vladimir-1976@postgrespro.ru", "phone": "+70577692999"}
0005435126266	4CB325	0471 762435	NATALIYA MAKAROVA	{"email": "makarova_n03021980@postgrespro.ru", "phone": "+70965455571"}
0005435126267	8093E6	1174 311880	EVGENIY TIKHONOV	{"email": "e.tikhonov_08061976@postgrespro.ru", "phone": "+70831102264"}
0005435126268	5A96DB	9875 869919	NIKOLAY DENISOV	{"phone": "+70826065580"}
0005435126269	9A180C	7606 424807	SERGEY ISAEV	{"phone": "+70617380461"}
0005435126270	57B275	5005 181245	LARISA MELNIKOVA	{"email": "larisa.melnikova-1980@postgrespro.ru", "phone": "+70298789332"}
0005435126271	57B275	8734 504651	VALERIY VLASOV	{"email": "vlasovv.30011970@postgrespro.ru", "phone": "+70749933088"}
0005435126272	367D0D	7914 569424	VLADIMIR KUDRYASHOV	{"phone": "+70503573510"}
0005435126273	F69EBD	8968 103307	DARYA ZAYCEVA	{"email": "zayceva.d_1976@postgrespro.ru", "phone": "+70536637971"}
0005435126274	02D6C3	0251 471105	ANASTASIYA NAZAROVA	{"phone": "+70114024876"}
0005435126275	3672A8	1982 337357	IRINA STEPANOVA	{"phone": "+70672518977"}
0005435126276	3672A8	8821 138543	ALENA GORBUNOVA	{"email": "alena.gorbunova1971@postgrespro.ru", "phone": "+70085007363"}
0005435126277	FBD42B	3522 132945	SERGEY IVANOV	{"phone": "+70714152037"}
0005435126278	FBD42B	6677 951930	EKATERINA YAKOVLEVA	{"email": "yakovlevae_14031975@postgrespro.ru", "phone": "+70526711587"}
0005435126279	23BB30	5223 704894	VALENTINA BORISOVA	{"phone": "+70732609832"}
0005435126280	49436F	4806 541669	OLGA NIKOLAEVA	{"phone": "+70585298065"}
0005435126281	49436F	4575 537451	TAMARA KARPOVA	{"email": "karpovat-041972@postgrespro.ru", "phone": "+70801900153"}
0005435126282	84FAC0	3237 868237	VALERIY TIMOFEEV	{"email": "vtimofeev-1973@postgrespro.ru", "phone": "+70807472406"}
0005435126283	E42073	7401 056458	MARIYA SIDOROVA	{"phone": "+70594073034"}
0005435126284	37D2CF	0976 408572	ILDAR SHEVCHENKO	{"phone": "+70523976694"}
0005435126285	A55293	5411 265252	MIKHAIL BARANOV	{"email": "baranov-m.041962@postgrespro.ru", "phone": "+70125877065"}
0005435126286	FD3504	8194 390980	VLADIMIR SERGEEV	{"email": "vladimir-sergeev_03051971@postgrespro.ru", "phone": "+70643933572"}
0005435126287	30A2E3	2276 159071	KIRILL STEPANOV	{"email": "stepanov_k_1979@postgrespro.ru", "phone": "+70612666736"}
0005435126288	015B92	0797 522368	ANTONINA ROMANOVA	{"phone": "+70708670224"}
0005435126289	015B92	7359 023501	LYUBOV DENISOVA	{"email": "ldenisova031966@postgrespro.ru", "phone": "+70489695720"}
0005435126290	300C5E	8645 247770	VADIM KUZNECOV	{"email": "v-kuznecov12031979@postgrespro.ru", "phone": "+70116419459"}
0005435126291	1C9132	4754 242289	PETR SOROKIN	{"email": "sorokin.p.1983@postgrespro.ru", "phone": "+70506441610"}
0005435126292	8034DE	6285 061697	GALINA IVANOVA	{"email": "galina.ivanova-05111974@postgrespro.ru", "phone": "+70197263590"}
0005435126293	8034DE	0035 374481	LYUBOV KOROLEVA	{"email": "lkoroleva15011967@postgrespro.ru", "phone": "+70898631666"}
0005435126294	8415E3	4260 388104	NIKITA MOROZOV	{"email": "morozov.nikita-1965@postgrespro.ru", "phone": "+70754000788"}
0005435126295	C26980	9428 662819	SVETLANA EFIMOVA	{"email": "efimova_s-1970@postgrespro.ru", "phone": "+70656097618"}
0005435126296	5A8AB3	7737 781935	DANIIL TARASOV	{"email": "d.tarasov1975@postgrespro.ru", "phone": "+70325298885"}
0005435126297	17B11F	3691 478783	RINAT MOROZOV	{"phone": "+70490002517"}
0005435126298	931672	8988 457687	RAIS ABRAMOV	{"email": "abramov_rais1973@postgrespro.ru", "phone": "+70534217597"}
0005435126299	931672	5042 474898	OKSANA FILIPPOVA	{"email": "o-filippova-1967@postgrespro.ru", "phone": "+70592183544"}
0005435126300	931672	7222 039537	KONSTANTIN MAKSIMOV	{"phone": "+70146825942"}
0005435126301	E2E8DE	0923 894016	VYACHESLAV TARASOV	{"email": "vyacheslavtarasov.19101981@postgrespro.ru", "phone": "+70472889471"}
0005435126302	F6C320	1271 244599	VYACHESLAV VASILEV	{"email": "vyacheslav-vasilev_081981@postgrespro.ru", "phone": "+70376242676"}
0005435126303	325A85	9901 223672	VIKTOR MOROZOV	{"email": "viktormorozov-081978@postgrespro.ru", "phone": "+70139881663"}
0005435126304	0EB086	2151 062889	DARYA SOROKINA	{"phone": "+70936305269"}
0005435126305	0EB086	5386 739454	ALEKSEY FEDOTOV	{"email": "fedotov.aleksey_10011989@postgrespro.ru", "phone": "+70034340976"}
0005435126306	DFB060	3544 398830	ANATOLIY RODIONOV	{"email": "a_rodionov071971@postgrespro.ru", "phone": "+70804809878"}
0005435126307	0F24A7	2398 601651	GALINA SEMENOVA	{"phone": "+70066488796"}
0005435126308	DF47F3	3127 883960	MARIYA BELOVA	{"email": "belova.m-1979@postgrespro.ru", "phone": "+70361566816"}
0005435126309	DF47F3	7336 337731	ALEKSANDR FEDOROV	{"phone": "+70308936484"}
0005435126310	FEF469	1308 659417	NATALYA TROFIMOVA	{"phone": "+70545844875"}
0005435126311	FEF469	6024 908725	TATYANA PETROVA	{"phone": "+70883944699"}
0005435126312	04DC3F	1696 262036	ANATOLIY GUSEV	{"email": "a_gusev-041970@postgrespro.ru", "phone": "+70527010397"}
0005435126313	04DC3F	0546 679490	LYUDMILA ERMAKOVA	{"email": "ermakova-l121978@postgrespro.ru", "phone": "+70342410563"}
0005435126314	A569A2	4847 398629	BORIS AFANASEV	{"email": "b-afanasev.21051973@postgrespro.ru", "phone": "+70352681528"}
0005435126315	A569A2	0553 315975	ANTON DAVYDOV	{"email": "davydov_anton.19111963@postgrespro.ru", "phone": "+70092204702"}
0005435126316	A569A2	2753 113210	IRINA EFREMOVA	{"phone": "+70620328713"}
0005435126317	3EC6FC	2980 402508	TATYANA ZHUKOVA	{"phone": "+70541245366"}
0005435126318	CFF2BF	7449 449827	ALEKSEY PAVLOV	{"phone": "+70693457464"}
0005435126319	09484A	1699 623372	OLGA KUDRYASHOVA	{"email": "okudryashova-1982@postgrespro.ru", "phone": "+70344907026"}
0005435126320	581142	3196 753328	ANDREY ZAKHAROV	{"email": "a-zakharov-01051968@postgrespro.ru", "phone": "+70242413263"}
0005435126321	D9D981	0606 290142	EKATERINA MAKSIMOVA	{"phone": "+70686706301"}
0005435126322	4340C2	1302 387090	VALENTINA MELNIKOVA	{"email": "melnikovavalentina.26031976@postgrespro.ru", "phone": "+70566810988"}
0005435126323	4B1977	4961 244432	MARK OSIPOV	{"email": "osipovm_1976@postgrespro.ru", "phone": "+70043900932"}
0005435126324	BD018D	9274 229131	FEDOR ALEKSEEV	{"email": "fedor.alekseev_26011979@postgrespro.ru", "phone": "+70302072297"}
0005435126325	BD018D	4818 340083	TATYANA SOLOVEVA	{"email": "t_soloveva-101960@postgrespro.ru", "phone": "+70444823946"}
0005435126326	BD018D	4317 179491	ALEKSANDR AFANASEV	{"email": "afanasev-a-081971@postgrespro.ru", "phone": "+70252352164"}
0005435126327	4F2CA3	9795 194452	NINA ANTONOVA	{"email": "n.antonova1962@postgrespro.ru", "phone": "+70719115867"}
0005435126328	86A7D2	2750 044170	MARIYA NIKIFOROVA	{"phone": "+70618517959"}
0005435126329	86A7D2	9737 513842	ALEKSANDR IVANOV	{"phone": "+70318868812"}
0005435126330	23C4D6	7489 779768	ELIZAVETA KOROLEVA	{"email": "elizaveta_koroleva-051962@postgrespro.ru", "phone": "+70172842890"}
0005435126331	43D9C7	9435 246287	MIKHAIL NAZAROV	{"email": "m-nazarov_061973@postgrespro.ru", "phone": "+70639615217"}
0005435126332	43D9C7	0773 508152	RIMMA STEPANOVA	{"email": "rimmastepanova081969@postgrespro.ru", "phone": "+70846622586"}
0005435126333	678FEE	1338 057167	YURIY ISAEV	{"email": "y-isaev_1981@postgrespro.ru", "phone": "+70775469758"}
0005435126334	678FEE	3889 976730	VERA MAKAROVA	{"email": "makarovavera24041977@postgrespro.ru", "phone": "+70973683381"}
0005435126335	0C33A9	9766 490544	SVETLANA KRASNOVA	{"email": "krasnova_svetlana-1972@postgrespro.ru", "phone": "+70354594901"}
0005435126336	A68501	3113 005433	ANDREY KUZNECOV	{"phone": "+70615680988"}
0005435126337	A68501	4331 993562	VALENTIN MELNIKOV	{"phone": "+70809247477"}
0005435126338	2916C1	7191 612032	OLGA ZAKHAROVA	{"email": "zakharova-olga.1983@postgrespro.ru", "phone": "+70585634840"}
0005435126339	6D7050	1872 567249	EKATERINA VOLKOVA	{"phone": "+70597198102"}
0005435126340	4B61E5	7194 426341	LEONID MIRONOV	{"phone": "+70359540887"}
0005435126341	E35D76	5129 201555	TAMARA NOVIKOVA	{"phone": "+70956988663"}
0005435126342	C74354	2109 442181	ANATOLIY STEPANOV	{"phone": "+70615894631"}
0005435126343	7C722A	9796 086563	TATYANA SIDOROVA	{"phone": "+70296752727"}
0005435126344	7C722A	1208 991285	ANTONINA FILATOVA	{"email": "a_filatova_1975@postgrespro.ru", "phone": "+70590678612"}
0005435126345	7C722A	5652 691194	ALEKSANDR NIKITIN	{"email": "nikitin_aleksandr.041974@postgrespro.ru", "phone": "+70132713099"}
0005435126346	752C1D	2731 517634	EKATERINA MOISEEVA	{"phone": "+70390899380"}
0005435126347	752C1D	5514 950204	VIKTOR ANTONOV	{"email": "antonov.v-09021977@postgrespro.ru", "phone": "+70671304529"}
0005435126348	0A0E90	2429 841210	ANASTASIYA ZAKHAROVA	{"email": "zakharovaanastasiya06111974@postgrespro.ru", "phone": "+70756091284"}
0005435126349	0A0E90	5959 324944	IRINA DMITRIEVA	{"email": "dmitrieva-irina05121964@postgrespro.ru", "phone": "+70773357299"}
0005435126350	29FF53	6533 144109	LARISA LOGINOVA	{"email": "larisa-loginova_16081980@postgrespro.ru", "phone": "+70909768955"}
0005435126351	A3371A	2872 357118	TATYANA KUZNECOVA	{"email": "tatyanakuznecova.031966@postgrespro.ru", "phone": "+70767641816"}
0005435126352	A3371A	5419 214768	ILYA SERGEEV	{"email": "sergeev.ilya-1963@postgrespro.ru", "phone": "+70560941069"}
0005435126353	AB7BBB	4863 668353	NATALYA FROLOVA	{"phone": "+70385510254"}
0005435126354	586D17	9546 950840	VITALIY FEDOROV	{"email": "vitaliy_fedorov111989@postgrespro.ru", "phone": "+70433700476"}
0005435126355	BBBF9B	2537 041800	ANZHELA NAZAROVA	{"phone": "+70615322733"}
0005435126356	BBBF9B	2697 948008	NATALYA NIKIFOROVA	{"email": "nikiforova-natalya.04021980@postgrespro.ru", "phone": "+70333381913"}
0005435126357	BBBF9B	7933 427981	TATYANA SMIRNOVA	{"email": "smirnova_t_1969@postgrespro.ru", "phone": "+70904394285"}
0005435126358	BBA3EF	6403 427106	MARIYA GERASIMOVA	{"phone": "+70159404013"}
0005435126359	BBA3EF	1296 697397	KIRILL ABRAMOV	{"email": "k.abramov21071969@postgrespro.ru", "phone": "+70213698199"}
0005435126360	937308	1724 490001	ALEKSANDR STEPANOV	{"email": "stepanov.aleksandr15121967@postgrespro.ru", "phone": "+70374327998"}
0005435126361	A94B2A	0318 540798	IRINA STEPANOVA	{"email": "stepanova.irina.1978@postgrespro.ru", "phone": "+70418736849"}
0005435126362	D7B629	3069 931818	ELENA VASILEVA	{"email": "elena_vasileva_081979@postgrespro.ru", "phone": "+70752882921"}
0005435126363	51D00F	7313 742306	GALINA PAVLOVA	{"phone": "+70710525290"}
0005435126364	51D00F	1984 230580	NINA SOLOVEVA	{"email": "solovevanina_16111972@postgrespro.ru", "phone": "+70126818196"}
0005435126365	15E9B2	2523 898031	SOFYA RYABOVA	{"email": "s-ryabova1969@postgrespro.ru", "phone": "+70845920269"}
0005435126366	15E9B2	3021 895873	ELENA NOVIKOVA	{"email": "e-novikova.1970@postgrespro.ru", "phone": "+70690210973"}
0005435126367	EA56A9	1405 382232	EKATERINA DENISOVA	{"phone": "+70123410558"}
0005435126368	EA56A9	4774 655163	NIKOLAY FILIPPOV	{"phone": "+70195391920"}
0005435126369	34E6BE	2169 951820	ANASTASIYA RODIONOVA	{"phone": "+70713020396"}
0005435126370	34E6BE	9477 237746	NIKOLAY NIKITIN	{"email": "nikolay-nikitin041969@postgrespro.ru", "phone": "+70097695537"}
0005435126371	75C528	2406 706806	MIKHAIL PETROV	{"email": "m-petrov-1975@postgrespro.ru", "phone": "+70245529851"}
0005435126372	75C528	6801 038421	ELENA PETROVA	{"phone": "+70099930832"}
0005435126373	B797C0	4925 924995	YURIY KONOVALOV	{"phone": "+70114537487"}
0005435126374	B797C0	2970 669955	GALINA MAKAROVA	{"phone": "+70411103025"}
0005435126375	546A14	9061 678085	ALENA PETROVA	{"email": "apetrova121968@postgrespro.ru", "phone": "+70992406364"}
0005435126376	514B48	1919 810646	DARYA TITOVA	{"phone": "+70346370691"}
0005435126377	74485F	9126 272164	YULIYA MAKAROVA	{"phone": "+70180350390"}
0005435126378	74485F	4582 208984	VALENTINA KUZNECOVA	{"email": "v.kuznecova22071979@postgrespro.ru", "phone": "+70708688159"}
0005435126379	6E05E6	2691 493360	PETR SOLOVEV	{"email": "solovevpetr121973@postgrespro.ru", "phone": "+70122246187"}
0005435126380	CEA6E4	5036 626846	OKSANA FEDOROVA	{"phone": "+70169440517"}
0005435126382	9FFC37	5184 854372	VIKTOR VASILEV	{"email": "vasilevv-121982@postgrespro.ru", "phone": "+70226654732"}
0005435126383	9FFC37	5559 130568	VLADIMIR CHERNOV	{"phone": "+70001362522"}
0005435126384	FE9947	0548 724082	ALEKSEY MOROZOV	{"email": "morozovaleksey1970@postgrespro.ru", "phone": "+70099312521"}
0005435126385	FE9947	4295 231213	EKATERINA CHERNOVA	{"phone": "+70377666871"}
0005435126386	D4E0AE	8523 802351	YURIY MIRONOV	{"email": "mironov_y.031984@postgrespro.ru", "phone": "+70119816084"}
0005435126387	D4E0AE	8058 844576	KONSTANTIN KUZNECOV	{"phone": "+70379824002"}
0005435126388	18DC27	6912 473331	NATALYA FILIPPOVA	{"email": "n-filippova-011974@postgrespro.ru", "phone": "+70787212728"}
0005435126389	18DC27	6531 519395	ELENA TARASOVA	{"phone": "+70594746017"}
0005435126390	13691F	5094 371284	DANIIL MOROZOV	{"phone": "+70913392509"}
0005435126391	6DAC6D	0301 582615	IVAN BONDARENKO	{"email": "ibondarenko-29071951@postgrespro.ru", "phone": "+70185955821"}
0005435126392	BF84C6	0265 789723	DIANA BORISOVA	{"email": "diana.borisova-1977@postgrespro.ru", "phone": "+70097164456"}
0005435126393	F16C1A	4873 289657	ELENA MAKAROVA	{"email": "e-makarova-121972@postgrespro.ru", "phone": "+70250733483"}
0005435126394	21981F	0788 286350	EVGENIY MIRONOV	{"phone": "+70256521348"}
0005435126395	EF2495	7236 363589	ELVIRA SCHERBAKOVA	{"email": "elvirascherbakova1962@postgrespro.ru", "phone": "+70223442475"}
0005435126396	B0292C	1753 637713	YURIY PETROV	{"email": "petrov.y-02021958@postgrespro.ru", "phone": "+70077864770"}
0005435126397	B0292C	9192 177144	MARIYA CHERNOVA	{"email": "mariyachernova_05021970@postgrespro.ru", "phone": "+70458060738"}
0005435126398	897C00	6763 004725	ANATOLIY PETROV	{"phone": "+70824878352"}
0005435126399	897C00	0257 249931	VIKTORIYA MAKSIMOVA	{"phone": "+70674061841"}
0005435126400	9B7E58	7653 724778	FATYMA GAVRILOVA	{"email": "gavrilova-fatyma-11101971@postgrespro.ru", "phone": "+70827942116"}
0005435126401	9B7E58	7640 195796	ANNA SMIRNOVA	{"email": "anna.smirnova.1976@postgrespro.ru", "phone": "+70035446344"}
0005435126402	C6464C	8610 371669	ROZA MALYSHEVA	{"email": "malysheva_roza1980@postgrespro.ru", "phone": "+70608836492"}
0005435126403	C6464C	7313 861081	DARYA MARTYNOVA	{"phone": "+70092891874"}
0005435126404	0B41B7	3679 766230	GALINA GERASIMOVA	{"email": "gerasimova_galina.041983@postgrespro.ru", "phone": "+70476578254"}
0005435126405	0B41B7	5906 234538	NINA POPOVA	{"phone": "+70892309465"}
0005435126406	E21E3A	2616 613280	VIKTOR SAVELEV	{"phone": "+70259914298"}
0005435126407	A0AE1E	2284 597469	ELENA PAVLOVA	{"email": "elena-pavlova.1971@postgrespro.ru", "phone": "+70003669088"}
0005435126408	6CFBC2	7184 761279	SERGEY TARASOV	{"email": "tarasov.s_28061964@postgrespro.ru", "phone": "+70986127920"}
0005435126409	211B07	7789 435284	PRASKOVYA SEMENOVA	{"phone": "+70636987155"}
0005435126410	211B07	2966 964960	YANA ZAYCEVA	{"email": "yana_zayceva_11041975@postgrespro.ru", "phone": "+70207110853"}
0005435126411	2AF7A6	3944 521343	VALENTINA KOZLOVA	{"email": "kozlovav_101971@postgrespro.ru", "phone": "+70827215727"}
0005435126412	1883F6	9230 444041	VYACHESLAV KUZNECOV	{"email": "vyacheslavkuznecov1968@postgrespro.ru", "phone": "+70616059936"}
0005435126413	1883F6	4424 997889	ANDREY KUZNECOV	{"email": "andrey_kuznecov_1974@postgrespro.ru", "phone": "+70499593281"}
0005435126414	63FAD6	8707 129355	KSENIYA KUZNECOVA	{"phone": "+70739976136"}
0005435126415	097974	5778 523433	DENIS NAUMOV	{"email": "naumovdenis.121983@postgrespro.ru", "phone": "+70600297295"}
0005435126416	FE46F7	7784 711876	OLEG ANDREEV	{"phone": "+70419088626"}
0005435126417	FAC37A	7900 786097	GALINA ZAYCEVA	{"phone": "+70280066054"}
0005435126418	5B3C9E	8777 342387	YULIYA PETROVA	{"phone": "+70819180484"}
0005435126419	BEB75C	6448 415050	ANDREY ANDREEV	{"phone": "+70639729906"}
0005435126420	6F51A9	7771 507915	OLGA VOLKOVA	{"phone": "+70711100352"}
0005435126421	20A89B	4876 854165	ILYA SHEVCHENKO	{"email": "ilya-shevchenko071982@postgrespro.ru", "phone": "+70600741419"}
0005435126422	20A89B	9689 948645	TATYANA SCHERBAKOVA	{"email": "t.scherbakova121980@postgrespro.ru", "phone": "+70837328353"}
0005435126423	89A339	9436 299426	TAISA BELYAEVA	{"email": "belyaeva.taisa-1966@postgrespro.ru", "phone": "+70395086448"}
0005435126424	89A339	5865 520057	LIDIYA PAVLOVA	{"phone": "+70551525707"}
0005435126425	1422A1	8009 049518	VASILIY OSIPOV	{"phone": "+70543539620"}
0005435126426	1422A1	7836 972575	SERGEY CHERNOV	{"email": "sergey-chernov-03121969@postgrespro.ru", "phone": "+70080419007"}
0005435126427	462A8F	3727 673470	IVAN MAKSIMOV	{"phone": "+70151947410"}
0005435126428	156019	7146 105321	ANDREY ABRAMOV	{"phone": "+70116750597"}
0005435126429	CE5B30	9852 808154	ALEKSANDR KOROLEV	{"phone": "+70910764216"}
0005435126430	CE5B30	8258 348133	ALEKSANDR FROLOV	{"phone": "+70970609062"}
0005435126431	5B5A13	3716 927201	BORIS KUZMIN	{"phone": "+70212089872"}
0005435126432	7396EB	1775 645127	YURIY RODIONOV	{"phone": "+70653915814"}
0005435126433	7396EB	0114 877947	KSENIYA KUZNECOVA	{"phone": "+70051576100"}
0005435126434	4224D5	4701 695949	ALEKSEY KONOVALOV	{"email": "konovalov.aleksey.11061975@postgrespro.ru", "phone": "+70329071243"}
0005435126435	6E828F	6334 087661	OKSANA SOROKINA	{"phone": "+70667395976"}
0005435126436	E8709B	1806 212805	MARIYA TITOVA	{"email": "titova.m17051968@postgrespro.ru", "phone": "+70583412184"}
0005435126437	929A9A	9269 374499	ALEKSEY IVANOV	{"phone": "+70907917192"}
0005435126438	CABF4A	2686 767931	PETR ZHURAVLEV	{"phone": "+70687345624"}
0005435126439	FBD697	1029 649822	YURIY SERGEEV	{"email": "yuriy.sergeev-071978@postgrespro.ru", "phone": "+70709088522"}
0005435126440	B1D3D6	4912 746495	IVAN NAZAROV	{"phone": "+70979434625"}
0005435126441	67E341	5560 829772	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr-121973@postgrespro.ru", "phone": "+70151751224"}
0005435126442	B98AE4	8044 727119	ALEKSANDR ANDREEV	{"email": "a-andreev06101976@postgrespro.ru", "phone": "+70773886764"}
0005435126443	E7F0E1	4299 647387	NIKOLAY KONOVALOV	{"email": "konovalovn-1973@postgrespro.ru", "phone": "+70098397077"}
0005435126444	24DD71	2729 088499	LINAR PETROV	{"phone": "+70287807733"}
0005435126445	E88F68	4548 556566	OLGA BELYAEVA	{"email": "olga-belyaeva1966@postgrespro.ru", "phone": "+70666987547"}
0005435126446	E88F68	8296 613894	ALLA EGOROVA	{"email": "aegorova1971@postgrespro.ru", "phone": "+70054879744"}
0005435126447	BFB300	6196 873142	TATYANA POPOVA	{"phone": "+70416658757"}
0005435126448	0BE63B	2033 768946	ANTON ZHUKOV	{"email": "anton-zhukov18051964@postgrespro.ru", "phone": "+70932302904"}
0005435126449	0BE63B	2412 294548	NATALYA RODIONOVA	{"email": "rodionovanatalya041972@postgrespro.ru", "phone": "+70371167567"}
0005435126450	0BE63B	3959 444180	SVETLANA KOLESNIKOVA	{"phone": "+70246477439"}
0005435126451	294A4C	7817 626720	MARIYA AFANASEVA	{"email": "mariya.afanaseva-1964@postgrespro.ru", "phone": "+70323889467"}
0005435126452	ECE2CD	4962 588532	VERA SCHERBAKOVA	{"phone": "+70944690059"}
0005435126453	ECE2CD	1788 974796	KRISTINA KULIKOVA	{"email": "kulikova-kristina16021976@postgrespro.ru", "phone": "+70345269560"}
0005435126454	AE6C0B	2514 857508	ELVIRA KUZNECOVA	{"phone": "+70602878167"}
0005435126455	78C05C	3702 842823	ANDREY MAKSIMOV	{"phone": "+70821353173"}
0005435126456	78C05C	1409 499751	ALEKSANDR ISAEV	{"phone": "+70501504035"}
0005435126457	1EC118	6724 465325	ELENA VOROBEVA	{"phone": "+70214924126"}
0005435126458	1EC118	9063 368156	ALEKSEY SEMENOV	{"phone": "+70995405330"}
0005435126459	196312	2320 880855	ALEKSANDR ALEKSANDROV	{"phone": "+70734835099"}
0005435126460	38F460	7984 024626	SVETLANA ABRAMOVA	{"email": "svetlanaabramova121977@postgrespro.ru", "phone": "+70673643603"}
0005435126461	B9D960	5436 102515	OLGA MATVEEVA	{"phone": "+70223048936"}
0005435126462	B9D960	2514 651768	VIKTOR ROMANOV	{"email": "romanovviktor-071977@postgrespro.ru", "phone": "+70288492749"}
0005435126463	DADBB3	0550 813991	ALFIYA EGOROVA	{"phone": "+70338902104"}
0005435126464	884442	5326 900119	ELENA KUDRYASHOVA	{"phone": "+70303071482"}
0005435126465	2D63B0	6412 657187	IGOR FROLOV	{"phone": "+70759522096"}
0005435126466	F641B5	2282 990019	RAISA KAZAKOVA	{"phone": "+70272520379"}
0005435126467	4BE8C3	2112 659255	ANATOLIY KRASNOV	{"phone": "+70839347220"}
0005435126468	4BE8C3	6043 682990	OKSANA SERGEEVA	{"phone": "+70049945521"}
0005435126469	7BAEE3	5039 376339	OLEG GAVRILOV	{"email": "o.gavrilov061973@postgrespro.ru", "phone": "+70146103580"}
0005435126470	19B607	4784 426049	VADIM SHEVCHENKO	{"email": "shevchenko.v-02031974@postgrespro.ru", "phone": "+70025280998"}
0005435126471	19B607	6209 961641	POLINA KOMAROVA	{"phone": "+70452942902"}
0005435126472	99718F	2230 330406	OLGA MOROZOVA	{"phone": "+70357462181"}
0005435126473	685F03	2454 930558	OLGA VOLKOVA	{"phone": "+70169786789"}
0005435126474	4725B2	7835 023710	MARIYA MIRONOVA	{"phone": "+70400595251"}
0005435126475	4725B2	8194 064091	VALENTINA OVCHINNIKOVA	{"phone": "+70841184079"}
0005435126476	0D1104	2605 823461	BORIS GUSEV	{"phone": "+70572683682"}
0005435126477	0D1104	7928 902217	RAFAEL SEMENOV	{"email": "semenov_rafael_121976@postgrespro.ru", "phone": "+70888148270"}
0005435126478	DC9AC9	0229 733203	ALEKSANDR EGOROV	{"email": "egorov_a15101968@postgrespro.ru", "phone": "+70198630055"}
0005435126479	3D5C17	4840 035003	SERGEY FROLOV	{"email": "s.frolov.051978@postgrespro.ru", "phone": "+70889401829"}
0005435126480	3D5C17	1236 844142	VIKTORIYA ALEKSANDROVA	{"email": "viktoriya-aleksandrova-08091965@postgrespro.ru", "phone": "+70824034901"}
0005435126481	02D727	9120 161192	MARINA IVANOVA	{"email": "marina-ivanova12021967@postgrespro.ru", "phone": "+70672112040"}
0005435126482	D08C83	1144 057336	ALEKSANDR MOROZOV	{"phone": "+70937598764"}
0005435126483	25DD85	9044 748505	ALENA ANDREEVA	{"email": "alena_andreeva.121969@postgrespro.ru", "phone": "+70706326875"}
0005435126484	25DD85	1607 059377	MIKHAIL AFANASEV	{"email": "m-afanasev_07061977@postgrespro.ru", "phone": "+70341193375"}
0005435126485	CDF09E	3439 851621	ALEKSANDRA BOGDANOVA	{"phone": "+70066981533"}
0005435126486	58FBD3	6209 995447	RIMMA ISAEVA	{"phone": "+70872863070"}
0005435126487	B5C0D2	6795 709736	OLGA GRISHINA	{"phone": "+70892790215"}
0005435126488	72FDBA	3439 486433	VIKTORIYA ZAYCEVA	{"email": "v-zayceva13111976@postgrespro.ru", "phone": "+70064893795"}
0005435126489	72FDBA	4016 193428	OLGA TARASOVA	{"phone": "+70919981910"}
0005435126490	0A5727	3528 000730	OLEG BONDARENKO	{"phone": "+70788513721"}
0005435126491	0A5727	3803 689750	YURIY KUZMIN	{"email": "yuriy_kuzmin18061967@postgrespro.ru", "phone": "+70302597371"}
0005435126492	BE0434	8893 023018	ANDREY ALEKSEEV	{"phone": "+70902055625"}
0005435126493	E5D5FE	9200 065686	MARIYA ALEKSEEVA	{"phone": "+70802736511"}
0005435126494	0D12D0	8941 639638	LYUBOV EFREMOVA	{"phone": "+70200242907"}
0005435126495	42EBF0	8138 188451	NIKOLAY KARPOV	{"email": "karpov.n-16061982@postgrespro.ru", "phone": "+70816596796"}
0005435126496	42EBF0	9396 189427	OKSANA EGOROVA	{"email": "egorova-oksana.1968@postgrespro.ru", "phone": "+70018541711"}
0005435126497	42EBF0	9111 279582	VYACHESLAV VOLKOV	{"email": "volkov-vyacheslav-18061982@postgrespro.ru", "phone": "+70621067132"}
0005435126498	12C60D	0580 630342	DENIS MAKAROV	{"email": "makarovdenis-10061964@postgrespro.ru", "phone": "+70411897548"}
0005435126499	767FA5	1096 533005	ARTEM KUDRYASHOV	{"email": "kudryashov-artem-1969@postgrespro.ru", "phone": "+70628655084"}
0005435126500	AC29B7	3618 219294	SABINA BOGDANOVA	{"email": "bogdanova.sabina19101966@postgrespro.ru", "phone": "+70164349096"}
0005435126501	B363AA	8540 986469	SERGEY IVANOV	{"phone": "+70874441364"}
0005435126502	5C5BB1	8113 047770	VITALIY STEPANOV	{"email": "v-stepanov_10041968@postgrespro.ru", "phone": "+70614025821"}
0005435126503	0F6643	1330 462069	MARIYA LEBEDEVA	{"phone": "+70324183876"}
0005435126504	51EBCE	7169 124392	KONSTANTIN SMIRNOV	{"email": "ksmirnov_1965@postgrespro.ru", "phone": "+70359517009"}
0005435126505	08251B	5207 089101	GEORGIY POPOV	{"phone": "+70873994401"}
0005435126506	08251B	8529 911303	IRINA KUZMINA	{"email": "kuzmina-irina-081973@postgrespro.ru", "phone": "+70246234414"}
0005435126507	5AC794	2921 240154	KSENIYA DANILOVA	{"email": "danilova_kseniya.04031979@postgrespro.ru", "phone": "+70328212699"}
0005435126508	75F707	7545 972964	SVETLANA ZAKHAROVA	{"phone": "+70985736048"}
0005435126509	6C8BA7	1894 666742	OLGA CHERNOVA	{"email": "o.chernova1960@postgrespro.ru", "phone": "+70631762251"}
0005435126510	5E7D4B	4075 058663	NIKOLAY PAVLOV	{"phone": "+70696704834"}
0005435126511	5E7D4B	1019 508189	SAMIR MARTYNOV	{"phone": "+70343881482"}
0005435126512	469A07	8050 943333	OLGA NIKOLAEVA	{"phone": "+70762734069"}
0005435126513	07A05D	7803 543760	ELIZAVETA FROLOVA	{"email": "frolovae.30041974@postgrespro.ru", "phone": "+70155780046"}
0005435126514	93CCCE	4945 320143	NINA FEDOROVA	{"phone": "+70508569285"}
0005435126515	4BFFAE	1909 865894	VLADIMIR KOROLEV	{"phone": "+70381047972"}
0005435126516	56BED1	0707 516200	ALEKSEY SERGEEV	{"email": "sergeev.aleksey1970@postgrespro.ru", "phone": "+70685216300"}
0005435126517	DF1CE8	2338 231614	NADEZHDA ZOTOVA	{"email": "n-zotova-1975@postgrespro.ru", "phone": "+70662139043"}
0005435126518	BA890B	7140 132824	EVGENIYA LAZAREVA	{"phone": "+70068700262"}
0005435126519	23764B	1256 361670	ANASTASIYA FOMINA	{"phone": "+70313599050"}
0005435126520	23764B	8762 034011	NINA ALEKSANDROVA	{"phone": "+70978639078"}
0005435126521	D3BFDE	4267 856242	SERGEY NOVIKOV	{"email": "novikov_s_1975@postgrespro.ru", "phone": "+70149193749"}
0005435126522	43FECA	5101 136570	NIKOLAY ALEKSEEV	{"email": "n_alekseev1981@postgrespro.ru", "phone": "+70279042925"}
0005435126523	16FF57	7093 477093	ALEKSANDR PETROV	{"email": "petrov_a.091967@postgrespro.ru", "phone": "+70539670198"}
0005435126524	748A7D	0613 098733	ELENA GRISHINA	{"email": "grishina_e-18071968@postgrespro.ru", "phone": "+70581659553"}
0005435126525	301D6D	8573 631210	MARGARITA MAKAROVA	{"phone": "+70926413577"}
0005435126526	88F4AB	4325 848613	EKATERINA BELOVA	{"email": "belovae1965@postgrespro.ru", "phone": "+70695356665"}
0005435126527	DBA435	3232 597778	IVAN AFANASEV	{"phone": "+70704471003"}
0005435126528	DBA435	8372 456311	INNA VOROBEVA	{"phone": "+70270286453"}
0005435126529	DBA435	9064 394276	NATALYA IVANOVA	{"phone": "+70174076337"}
0005435126530	C90436	1289 640000	YULIYA NIKITINA	{"email": "nikitina_yuliya_1984@postgrespro.ru", "phone": "+70310977902"}
0005435126531	CEBAC7	3806 274660	VALERIY GRIGOREV	{"email": "grigorevvaleriy-17061978@postgrespro.ru", "phone": "+70227512067"}
0005435126532	CEBAC7	4299 911129	YULIYA ABRAMOVA	{"phone": "+70786928085"}
0005435126533	B3AA6C	6834 341321	VASILIY POPOV	{"phone": "+70628137155"}
0005435126534	B3AA6C	9573 129783	VIKTOR SMIRNOV	{"phone": "+70284678547"}
0005435126535	C59A88	9234 146149	LARISA KOMAROVA	{"phone": "+70816614274"}
0005435126536	E24231	0499 065359	OKSANA BORISOVA	{"phone": "+70879228712"}
0005435126537	E24231	9727 767014	NINA TARASOVA	{"email": "tarasovan.1975@postgrespro.ru", "phone": "+70807520558"}
0005435126538	8E809C	8808 409330	RAMIL EGOROV	{"phone": "+70343803299"}
0005435126539	E6A9EC	3566 517513	DMITRIY KAZAKOV	{"phone": "+70382581813"}
0005435126540	25D11B	7604 466568	OLGA AKIMOVA	{"email": "akimova_olga1964@postgrespro.ru", "phone": "+70355514973"}
0005435126541	33A4AC	2589 181550	SVETLANA IVANOVA	{"email": "ivanova.s1975@postgrespro.ru", "phone": "+70633078441"}
0005435126542	CBE7BB	2144 262552	ANASTASIYA STEPANOVA	{"email": "a.stepanova-25101962@postgrespro.ru", "phone": "+70507533067"}
0005435126543	99FBB1	2891 455171	YURIY GERASIMOV	{"email": "y_gerasimov-091972@postgrespro.ru", "phone": "+70509327563"}
0005435126544	C7E5BC	1057 958436	RAUF VASILEV	{"phone": "+70732165978"}
0005435126545	563240	5393 795125	TATYANA VASILEVA	{"phone": "+70681463083"}
0005435126546	5771A0	8698 356521	GULFIYA KUZNECOVA	{"phone": "+70775259064"}
0005435126547	895A8A	0387 904161	TIMUR ALEKSANDROV	{"phone": "+70081598842"}
0005435126548	D32BD9	4610 755432	DINARA GAVRILOVA	{"phone": "+70217143697"}
0005435126549	D32BD9	7688 400256	VITALIY VOROBEV	{"email": "vorobev_v23041962@postgrespro.ru", "phone": "+70539948400"}
0005435126550	F45806	8577 362096	SERGEY SOKOLOV	{"email": "sokolov-s121974@postgrespro.ru", "phone": "+70016202603"}
0005435126551	78485D	9684 572891	YURIY IVANOV	{"phone": "+70809951677"}
0005435126552	EF0AF5	2930 497059	EMILIYA BORISOVA	{"email": "emiliya-borisova121974@postgrespro.ru", "phone": "+70677864569"}
0005435126553	EF0AF5	5584 136827	LYUBOV MELNIKOVA	{"email": "melnikova_l-041971@postgrespro.ru", "phone": "+70161476906"}
0005435126554	806906	3505 508549	OLGA KUZMINA	{"phone": "+70630737813"}
0005435126555	806906	3875 108745	DANILA ZAKHAROV	{"email": "zakharov.danila_26051974@postgrespro.ru", "phone": "+70972311802"}
0005435126556	9B9632	7013 219785	NADEZHDA ARKHIPOVA	{"phone": "+70141535818"}
0005435126557	CDF9DD	5929 079597	ANTON ILIN	{"phone": "+70279071714"}
0005435126558	CDF9DD	7256 052765	NATALYA GRISHINA	{"email": "natalya.grishina-111969@postgrespro.ru", "phone": "+70171509220"}
0005435126559	816693	5773 335169	ALENA KAZAKOVA	{"email": "kazakova_alena-031972@postgrespro.ru", "phone": "+70663615324"}
0005435126560	816693	8798 628245	NIKOLAY ANDREEV	{"phone": "+70908221158"}
0005435126561	C60C04	6388 616360	SVETLANA MAKSIMOVA	{"phone": "+70451695562"}
0005435126562	C60C04	2307 647553	DMITRIY FEDOROV	{"email": "d_fedorov.111977@postgrespro.ru", "phone": "+70215383662"}
0005435126563	4B055E	3144 785038	ANDREY MAKAROV	{"phone": "+70610245900"}
0005435126564	65ECD9	0004 892442	GENNADIY EGOROV	{"email": "gegorov_04021968@postgrespro.ru", "phone": "+70358347280"}
0005435126565	D4710F	4095 026781	GENNADIY IVANOV	{"email": "g-ivanov_031984@postgrespro.ru", "phone": "+70134119076"}
0005435126566	BE534A	9709 578335	ANDREY ILIN	{"email": "andrey.ilin-1977@postgrespro.ru", "phone": "+70656320907"}
0005435126567	F658D6	8090 827997	ELENA BELOVA	{"phone": "+70188946717"}
0005435126568	A0CDC6	1112 759954	ALEKSANDR EGOROV	{"phone": "+70006435547"}
0005435126569	A0CDC6	4499 731312	ANATOLIY IVANOV	{"phone": "+70460982063"}
0005435126570	49DF7F	0123 710842	GALINA POLYAKOVA	{"phone": "+70908229735"}
0005435126571	49DF7F	6610 806333	EVGENIY MARTYNOV	{"phone": "+70695277277"}
0005435126572	C9B429	7437 136337	ALEKSEY STEPANOV	{"phone": "+70681748106"}
0005435126573	22EB41	9570 725808	OKSANA RODIONOVA	{"phone": "+70072545803"}
0005435126574	1D638D	6124 373974	OKSANA MOROZOVA	{"phone": "+70135226818"}
0005435126575	275B3C	7433 657914	VIKTOR SEMENOV	{"email": "viktorsemenov.23031972@postgrespro.ru", "phone": "+70044068647"}
0005435126576	1A725D	4340 669669	NIKITA KAZAKOV	{"email": "n.kazakov10081969@postgrespro.ru", "phone": "+70349173396"}
0005435126577	D4B206	0213 703202	NATALYA ALEKSEEVA	{"email": "natalya.alekseeva-031973@postgrespro.ru", "phone": "+70958458209"}
0005435126578	D4B206	4823 203373	MARGARITA MELNIKOVA	{"phone": "+70764510578"}
0005435126579	293184	2801 297685	IGOR ISAEV	{"email": "isaev-igor30101968@postgrespro.ru", "phone": "+70102053159"}
0005435126580	FAE212	2776 715388	SERGEY ISAEV	{"phone": "+70152920656"}
0005435126581	FAE212	1422 809938	OLGA EGOROVA	{"phone": "+70647732815"}
0005435126582	FAE212	9006 390357	LYUBOV IVANOVA	{"phone": "+70422090542"}
0005435126583	E96FDB	3105 784023	ZINAIDA TITOVA	{"email": "z-titova.1969@postgrespro.ru", "phone": "+70503151696"}
0005435126584	4A50DE	1802 181675	RAISA BELYAEVA	{"phone": "+70005505776"}
0005435126585	4A50DE	5999 162067	IRINA KRASNOVA	{"email": "ikrasnova1972@postgrespro.ru", "phone": "+70140188510"}
0005435126586	21493E	4378 851650	EVGENIYA ZHURAVLEVA	{"email": "evgeniya.zhuravleva-1968@postgrespro.ru", "phone": "+70763194014"}
0005435126587	116302	4293 235006	ALEKSEY ABRAMOV	{"email": "aabramov121970@postgrespro.ru", "phone": "+70702976798"}
0005435126588	116302	8879 069629	ILYA IVANOV	{"email": "ivanov-ilya-1970@postgrespro.ru", "phone": "+70877095546"}
0005435126589	C6E3B9	3000 443529	EVGENIY NOVIKOV	{"email": "enovikov_061968@postgrespro.ru", "phone": "+70076989157"}
0005435126590	C6E3B9	2998 603516	MARIYA ZHURAVLEVA	{"email": "zhuravlevam-03101962@postgrespro.ru", "phone": "+70774851992"}
0005435126591	71B3FA	2291 286484	NATALYA NAZAROVA	{"email": "n-nazarova.1966@postgrespro.ru", "phone": "+70988788515"}
0005435126592	F6FA6B	5453 218531	ARTEM SCHERBAKOV	{"email": "artemscherbakov.011973@postgrespro.ru", "phone": "+70910142002"}
0005435126593	F6FA6B	4774 486353	DENIS BORISOV	{"email": "denisborisov14091968@postgrespro.ru", "phone": "+70175222689"}
0005435126594	4FA007	4846 716758	MIKHAIL FROLOV	{"email": "mikhail_frolov-1984@postgrespro.ru", "phone": "+70543776942"}
0005435126595	6E8AF7	9166 697948	DANIIL YAKOVLEV	{"phone": "+70315823003"}
0005435126596	7245FC	8964 936943	YURIY NAZAROV	{"email": "yuriynazarov041966@postgrespro.ru", "phone": "+70304139140"}
0005435126597	7245FC	9562 097003	NINA PAVLOVA	{"phone": "+70662455612"}
0005435126598	7B11DC	0877 248962	ELENA SOROKINA	{"phone": "+70808167265"}
0005435126599	7B11DC	9701 897144	NINA KAZAKOVA	{"email": "nina-kazakova_27071971@postgrespro.ru", "phone": "+70471269806"}
0005435126600	5D0E88	1480 334937	ALEKSEY VLASOV	{"phone": "+70072285819"}
0005435126601	5D0E88	5316 150844	SERGEY TARASOV	{"email": "sergeytarasov-031973@postgrespro.ru", "phone": "+70093340175"}
0005435126602	FC258C	6951 428015	GALINA EFREMOVA	{"phone": "+70291220897"}
0005435126603	18BD9E	1503 486960	IRINA MASLOVA	{"phone": "+70150553182"}
0005435126604	A6BFBC	5831 345115	ALEKSANDR SAVELEV	{"email": "saveleva_021974@postgrespro.ru", "phone": "+70454564565"}
0005435126605	576311	5602 219660	VALENTINA DAVYDOVA	{"phone": "+70892588536"}
0005435126606	576311	1364 108465	VLADIMIR MAKAROV	{"email": "makarovvladimir_20091986@postgrespro.ru", "phone": "+70570680612"}
0005435126607	576311	9181 661553	IVAN SAVELEV	{"phone": "+70187324366"}
0005435126608	B7D5DC	6051 083306	DANIIL VASILEV	{"phone": "+70220883119"}
0005435126609	19C861	4637 248234	NIKOLAY NOVIKOV	{"email": "n.novikov.1967@postgrespro.ru", "phone": "+70331262915"}
0005435126610	4F9FCC	9259 387251	PETR MOROZOV	{"email": "petr_morozov.031969@postgrespro.ru", "phone": "+70533273127"}
0005435126611	25153A	8403 928008	ALEKSANDR VOLKOV	{"phone": "+70462813085"}
0005435126612	E37CBF	0621 369103	ALEKSANDRA KONDRATEVA	{"email": "a-kondrateva-04041976@postgrespro.ru", "phone": "+70464929956"}
0005435126613	CBFA9F	8684 511869	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr1967@postgrespro.ru", "phone": "+70591027527"}
0005435126614	CBFA9F	3967 145771	ALENA PETROVA	{"phone": "+70086165861"}
0005435126615	CBFA9F	7554 196462	MARINA MAKAROVA	{"phone": "+70684398170"}
0005435126616	C44741	1408 831048	VLADIMIR ALEKSANDROV	{"phone": "+70674036253"}
0005435126617	A4823F	3242 754642	VALERIY DENISOV	{"phone": "+70742822904"}
0005435126618	A4823F	9450 589996	ANDREY SOROKIN	{"email": "sorokin_andrey_041965@postgrespro.ru", "phone": "+70832790216"}
0005435126619	52C22C	2105 103731	OLGA ANDREEVA	{"email": "o_andreeva_22111967@postgrespro.ru", "phone": "+70390901761"}
0005435126620	287A03	3491 220833	ANDREY KARPOV	{"email": "karpov.a21021973@postgrespro.ru", "phone": "+70274116182"}
0005435126621	287A03	2140 613975	MARIYA POTAPOVA	{"phone": "+70158129456"}
0005435126622	DFA19C	5630 970749	IRINA IVANOVA	{"email": "iivanova_1970@postgrespro.ru", "phone": "+70904347839"}
0005435126623	16D0E4	9355 344903	SERGEY FILIPPOV	{"phone": "+70238783857"}
0005435126624	16D0E4	5308 719674	MAGOMED FROLOV	{"email": "frolov-m_111991@postgrespro.ru", "phone": "+70289885985"}
0005435126625	1F8B3F	3983 774628	ANATOLIY ROMANOV	{"email": "romanov-anatoliy.081966@postgrespro.ru", "phone": "+70449323550"}
0005435126626	BC3927	9458 825177	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey-1984@postgrespro.ru", "phone": "+70299763750"}
0005435126627	1978B7	8669 096036	NADEZHDA KUZNECOVA	{"phone": "+70698771937"}
0005435126628	753D21	6360 484768	LYUDMILA NIKITINA	{"email": "l_nikitina1960@postgrespro.ru", "phone": "+70826165862"}
0005435126629	753D21	5865 193777	DANIIL SCHERBAKOV	{"email": "daniilscherbakov_20061968@postgrespro.ru", "phone": "+70075947794"}
0005435126630	963480	5842 677710	ELENA IVANOVA	{"phone": "+70047422786"}
0005435126631	72016B	8467 541410	KSENIYA NIKOLAEVA	{"email": "kseniyanikolaeva18021970@postgrespro.ru", "phone": "+70611572818"}
0005435126632	2BACC8	8245 053905	VLADIMIR OSIPOV	{"phone": "+70693566244"}
0005435126633	EFE74A	0442 253617	YULIYA VOLKOVA	{"email": "volkova-y081970@postgrespro.ru", "phone": "+70242688878"}
0005435126634	0978B4	1164 546838	VALENTINA ANISIMOVA	{"phone": "+70846152820"}
0005435126635	8FB2EC	3899 067628	OLEG MAKSIMOV	{"phone": "+70041360058"}
0005435126636	8FB2EC	4327 830071	NIKITA SERGEEV	{"email": "sergeev-n-121974@postgrespro.ru", "phone": "+70220619333"}
0005435126637	4A14AF	4923 219665	MARIYA SCHERBAKOVA	{"phone": "+70451085472"}
0005435126638	93920F	6495 882275	VLADISLAV FILIPPOV	{"phone": "+70103399349"}
0005435126639	93920F	6365 743671	NIKOLAY KUZNECOV	{"phone": "+70374891859"}
0005435126640	AB5139	9145 802778	YANA SEMENOVA	{"email": "ysemenova-1980@postgrespro.ru", "phone": "+70315485478"}
0005435126641	DF6EAE	0476 262997	INGA KUZNECOVA	{"email": "kuznecova_i_091981@postgrespro.ru", "phone": "+70652374646"}
0005435126642	B1BE27	9029 097920	ANATOLIY RODIONOV	{"phone": "+70323164114"}
0005435126643	83BB51	5216 632704	DENIS SOROKIN	{"email": "d.sorokin-04031978@postgrespro.ru", "phone": "+70693648011"}
0005435126644	83BB51	2935 646428	ALEKSANDR PETROV	{"email": "petrov.a1966@postgrespro.ru", "phone": "+70547556175"}
0005435126645	7B4921	1779 528880	DMITRIY PETROV	{"phone": "+70778978602"}
0005435126646	DBFFA1	2664 312752	ALEKSEY IVANOV	{"email": "aleksey.ivanov11111967@postgrespro.ru", "phone": "+70278965059"}
0005435126647	DBFFA1	5193 399113	SERGEY IVANOV	{"phone": "+70529870661"}
0005435126648	AA635F	6368 659460	LIDIYA MOROZOVA	{"email": "morozova-l27061979@postgrespro.ru", "phone": "+70395870578"}
0005435126649	606F08	4900 932522	VLADIMIR SMIRNOV	{"email": "smirnov.v-051976@postgrespro.ru", "phone": "+70944160287"}
0005435126650	4F07C2	0062 849409	MARGARITA SAVELEVA	{"phone": "+70947461147"}
0005435126651	1A3246	9076 453228	LYUDMILA TIMOFEEVA	{"phone": "+70723104401"}
0005435126652	4019D2	7796 798324	FEDOR ILIN	{"phone": "+70455557407"}
0005435126653	672F06	2602 350092	ASIYA KULIKOVA	{"phone": "+70986183797"}
0005435126654	672F06	7273 078816	TAMARA LEBEDEVA	{"email": "lebedeva.t04101975@postgrespro.ru", "phone": "+70006728459"}
0005435126655	EF0684	9209 067083	NATALIYA POPOVA	{"phone": "+70445539897"}
0005435126656	EF0684	2640 950040	VLADIMIR IVANOV	{"email": "ivanov_v25081977@postgrespro.ru", "phone": "+70731867594"}
0005435126657	EF0684	5495 052552	TATYANA GUSEVA	{"phone": "+70114185224"}
0005435126658	A72B9A	3469 224047	EMIL BARANOV	{"email": "baranovemil_091966@postgrespro.ru", "phone": "+70272063757"}
0005435126659	99214B	3825 016791	ROMAN KONOVALOV	{"email": "konovalovroman.1964@postgrespro.ru", "phone": "+70595759153"}
0005435126660	99214B	8791 344487	ALEKSEY SMIRNOV	{"email": "asmirnov1966@postgrespro.ru", "phone": "+70999585120"}
0005435126661	99214B	2509 434626	MIKHAIL SMIRNOV	{"email": "smirnov-m16081967@postgrespro.ru", "phone": "+70050505375"}
0005435126662	C59503	3952 483547	ALEKSEY DENISOV	{"email": "denisov_a_021969@postgrespro.ru", "phone": "+70606819931"}
0005435126663	C59503	0111 104907	VERA KUZNECOVA	{"phone": "+70853450705"}
0005435126664	B2F267	4839 275831	ELENA SEMENOVA	{"email": "semenova.elena_17111970@postgrespro.ru", "phone": "+70838594747"}
0005435126665	DBF591	6445 379661	ANATOLIY KAZAKOV	{"phone": "+70415699965"}
0005435126666	05F30E	4991 097043	VLADIMIR MELNIKOV	{"email": "melnikov.v_1965@postgrespro.ru", "phone": "+70014187572"}
0005435126667	E016F3	9879 042644	DMITRIY SHEVCHENKO	{"email": "shevchenkod_1980@postgrespro.ru", "phone": "+70133208387"}
0005435126668	E016F3	1616 200585	LARISA MOROZOVA	{"phone": "+70702449126"}
0005435126669	E016F3	2301 373102	SVETLANA MEDVEDEVA	{"phone": "+70493843389"}
0005435126670	42A2A7	6824 850734	ARKADIY MOROZOV	{"phone": "+70003165652"}
0005435126671	804F93	0686 484162	VIKTOR SERGEEV	{"email": "viktorsergeev031969@postgrespro.ru", "phone": "+70988440687"}
0005435126672	D3BDD8	5262 424588	EKATERINA MIRONOVA	{"email": "mironovaekaterina_1975@postgrespro.ru", "phone": "+70720380547"}
0005435126673	D3BDD8	5740 000459	YURIY EGOROV	{"email": "y-egorov_1966@postgrespro.ru", "phone": "+70235908062"}
0005435126674	BB63FF	7712 621454	SVETLANA POPOVA	{"email": "s_popova-031981@postgrespro.ru", "phone": "+70517641885"}
0005435126675	BB63FF	4429 633519	NATALIYA PAVLOVA	{"phone": "+70053937857"}
0005435126676	7A637F	6876 844393	OLGA VLASOVA	{"phone": "+70755130193"}
0005435126677	2FAE93	3647 299750	ANATOLIY IVANOV	{"email": "anatoliyivanov.1972@postgrespro.ru", "phone": "+70650237332"}
0005435126678	916EAB	2475 046707	NINA VASILEVA	{"email": "vasileva_nina_051976@postgrespro.ru", "phone": "+70651073071"}
0005435126679	01D459	2476 349508	IRINA KARPOVA	{"phone": "+70983346985"}
0005435126680	B026A4	6791 472562	RAISA MAKSIMOVA	{"phone": "+70212148763"}
0005435126681	EAEA10	9764 179780	VLADIMIR MATVEEV	{"email": "matveevv_15111977@postgrespro.ru", "phone": "+70723322055"}
0005435126682	03B123	3028 340537	OLGA BELYAEVA	{"email": "o_belyaeva29121971@postgrespro.ru", "phone": "+70660657085"}
0005435126683	03B123	5316 966020	NATALYA STEPANOVA	{"email": "stepanova-n-011977@postgrespro.ru", "phone": "+70574403180"}
0005435126684	6384CB	8621 922020	ANASTASIYA NAZAROVA	{"email": "anastasiya-nazarova031977@postgrespro.ru", "phone": "+70387228625"}
0005435126685	ADA408	0121 756048	GALINA YUDINA	{"phone": "+70681512903"}
0005435126686	ADA408	9332 958355	VIOLETTA OVCHINNIKOVA	{"phone": "+70643642006"}
0005435126687	ADA408	8528 673453	IGOR ABRAMOV	{"email": "i.abramov.03101972@postgrespro.ru", "phone": "+70200714642"}
0005435126688	908E21	4118 799122	PELAGEYA IVANOVA	{"email": "ivanova-pelageya1985@postgrespro.ru", "phone": "+70626368566"}
0005435126689	A55F69	2615 856886	IGOR FOMIN	{"phone": "+70005334909"}
0005435126690	4B4B1E	8943 474308	VLADIMIR SMIRNOV	{"phone": "+70077990318"}
0005435126691	33EDEB	1868 732717	PETR SEMENOV	{"phone": "+70331834060"}
0005435126692	33EDEB	2905 473890	OLGA TARASOVA	{"email": "olga.tarasova-101968@postgrespro.ru", "phone": "+70330657885"}
0005435126693	3064D1	5154 212322	VLADIMIR SIDOROV	{"email": "vsidorov-24051958@postgrespro.ru", "phone": "+70155099372"}
0005435126694	2875B9	4542 090293	IGOR ANTONOV	{"email": "antonov.i-1977@postgrespro.ru", "phone": "+70631767023"}
0005435126695	5DE38A	8943 349097	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr_25011963@postgrespro.ru", "phone": "+70364186313"}
0005435126696	5DE38A	0931 735059	ANATOLIY POPOV	{"phone": "+70280279666"}
0005435126697	4B2FED	3191 877955	SERGEY ANTONOV	{"email": "antonovsergey-1981@postgrespro.ru", "phone": "+70196913574"}
0005435126698	8D808A	9646 096591	STEPAN KUZMIN	{"phone": "+70069714369"}
0005435126699	CA19F7	8049 477449	NATALYA IVANOVA	{"email": "ivanova_n-101985@postgrespro.ru", "phone": "+70064684122"}
0005435126700	AEE45C	9927 168152	MIKHAIL MATVEEV	{"phone": "+70489031995"}
0005435126701	6D4945	5482 028526	NIKOLAY FILIPPOV	{"phone": "+70993410174"}
0005435126702	AE26C2	3641 818189	IGOR SERGEEV	{"phone": "+70278196991"}
0005435126703	973B87	4795 504417	NADEZHDA CHERNOVA	{"phone": "+70519175799"}
0005435126704	F14127	1633 204097	LYUBOV EGOROVA	{"email": "l.egorova.111965@postgrespro.ru", "phone": "+70653615332"}
0005435126705	D73F20	1446 574666	IVAN NAUMOV	{"phone": "+70233102056"}
0005435126706	319F17	7717 065971	NIKITA MIKHAYLOV	{"email": "n.mikhaylov_24011981@postgrespro.ru", "phone": "+70746382868"}
0005435126707	319F17	6967 187320	ALEKSEY GORBUNOV	{"email": "aleksey-gorbunov-1961@postgrespro.ru", "phone": "+70175599944"}
0005435126708	2EE3CA	4170 936112	ELENA EGOROVA	{"email": "egorova.e021968@postgrespro.ru", "phone": "+70218975172"}
0005435126709	2EE3CA	4503 548104	ALEKSANDR DMITRIEV	{"email": "dmitriev_a-1967@postgrespro.ru", "phone": "+70392215168"}
0005435126710	8C892C	3234 275984	VYACHESLAV RODIONOV	{"phone": "+70075566532"}
0005435126711	F05BCC	5439 584616	VERA SOKOLOVA	{"phone": "+70582166412"}
0005435126712	F05BCC	3571 993381	VIKTOR BORISOV	{"email": "borisov_viktor_1976@postgrespro.ru", "phone": "+70295304226"}
0005435126713	EC78F0	6697 547195	VLADIMIR MIRONOV	{"phone": "+70941027326"}
0005435126714	C9F9BF	4276 793945	ALBINA KALININA	{"phone": "+70264769692"}
0005435126715	78F68F	9992 261142	MARINA NIKITINA	{"phone": "+70634363804"}
0005435126716	78F68F	6511 652594	SAVELIY RODIONOV	{"email": "s.rodionov.121974@postgrespro.ru", "phone": "+70966859489"}
0005435126717	86C741	7501 156013	RUSLAN MAKSIMOV	{"email": "ruslan.maksimov_041974@postgrespro.ru", "phone": "+70076435358"}
0005435126718	41742E	7735 970600	LYUBOV FADEEVA	{"email": "lyubov.fadeeva_071973@postgrespro.ru", "phone": "+70313270457"}
0005435126719	41742E	3149 846004	TATYANA GRISHINA	{"phone": "+70867422965"}
0005435126720	8433E8	6952 462013	NIKOLAY DAVYDOV	{"email": "davydov-nikolay11081973@postgrespro.ru", "phone": "+70137483750"}
0005435126721	8433E8	5540 695195	TATYANA MELNIKOVA	{"phone": "+70531924241"}
0005435126722	BBEB20	2776 934963	YURIY BONDARENKO	{"phone": "+70160518541"}
0005435126723	9BEBB7	9735 850787	LYUBOV BELOVA	{"email": "l_belova1965@postgrespro.ru", "phone": "+70980146788"}
0005435126724	D68792	0171 836612	VALERIY KUDRYASHOV	{"email": "kudryashov-valeriy-1970@postgrespro.ru", "phone": "+70926740309"}
0005435126725	D68792	8383 903507	NADEZHDA YAKOVLEVA	{"email": "yakovleva-n-30101966@postgrespro.ru", "phone": "+70198226519"}
0005435126726	61CD9F	0843 212960	TATYANA KUZNECOVA	{"phone": "+70200962669"}
0005435126727	E680B3	6999 892598	LYUDMILA GRISHINA	{"phone": "+70549766660"}
0005435126728	E680B3	5695 220883	ULYANA IVANOVA	{"email": "ivanova-ulyana-011972@postgrespro.ru", "phone": "+70316660662"}
0005435126729	94A0E9	9605 032908	ANDREY PAVLOV	{"email": "a-pavlov091973@postgrespro.ru", "phone": "+70840552513"}
0005435126730	94A0E9	7522 122808	VITALIY BARANOV	{"phone": "+70555413066"}
0005435126731	94A0E9	1196 297564	OLGA NAZAROVA	{"email": "nazarova.o.1971@postgrespro.ru", "phone": "+70733429991"}
0005435126732	BF7A9F	7023 469068	ANATOLIY KUZNECOV	{"email": "a.kuznecov_09041972@postgrespro.ru", "phone": "+70349381836"}
0005435126733	2E5A2F	1167 066958	FATIMA GRISHINA	{"phone": "+70171464981"}
0005435126734	9A231D	7704 106894	OLGA PETROVA	{"phone": "+70310281645"}
0005435126735	9A231D	5279 032726	NADEZHDA POPOVA	{"email": "n_popova021964@postgrespro.ru", "phone": "+70064693086"}
0005435126736	2A5EAE	2267 291749	ALEKSANDR MEDVEDEV	{"email": "medvedev_a031971@postgrespro.ru", "phone": "+70206098853"}
0005435126737	7BC54B	5165 615871	TAMARA YUDINA	{"phone": "+70083496290"}
0005435126738	7BC54B	2616 742921	LYUDMILA NESTEROVA	{"email": "nesterova.l-16061961@postgrespro.ru", "phone": "+70853450244"}
0005435126739	0961A2	3000 727952	SERGEY SMIRNOV	{"email": "smirnov-s121968@postgrespro.ru", "phone": "+70567637711"}
0005435126740	72E09F	6528 144745	ALEKSANDR KRASNOV	{"email": "a.krasnov_101971@postgrespro.ru", "phone": "+70887588473"}
0005435126741	EB27CC	7381 942655	EVGENIY IVANOV	{"phone": "+70641097816"}
0005435126742	EB27CC	9186 790040	ROMAN MEDVEDEV	{"email": "medvedevr.111974@postgrespro.ru", "phone": "+70089691617"}
0005435126743	DBA583	7196 536425	MARIYA ZAYCEVA	{"phone": "+70562826932"}
0005435126744	AD8042	4116 431414	IVAN BONDARENKO	{"phone": "+70772200800"}
0005435126745	BAC361	9800 875826	EKATERINA MATVEEVA	{"phone": "+70247107661"}
0005435126746	A53703	8740 691988	ELIZAVETA SOROKINA	{"phone": "+70977417819"}
0005435126747	CC9976	0381 990631	GALINA NIKOLAEVA	{"email": "g.nikolaeva_051979@postgrespro.ru", "phone": "+70574221520"}
0005435126748	CC9976	9515 727550	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov_041986@postgrespro.ru", "phone": "+70344551978"}
0005435126749	E9F0BF	1878 634189	DANIIL SEMENOV	{"phone": "+70596836982"}
0005435126750	EAEC27	9711 022190	ANASTASIYA PETROVA	{"phone": "+70270891152"}
0005435126751	78B5B1	7910 198398	OLGA BELYAEVA	{"email": "belyaevao_11091974@postgrespro.ru", "phone": "+70824104736"}
0005435126752	D733E4	2708 539196	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev.081968@postgrespro.ru", "phone": "+70309438057"}
0005435126753	D733E4	3382 078104	YULIYA POPOVA	{"phone": "+70282218916"}
0005435126754	69C7E4	7787 851151	OLESYA DANILOVA	{"phone": "+70218290051"}
0005435126755	011078	5577 341553	GERMAN ANTONOV	{"email": "antonovg-1982@postgrespro.ru", "phone": "+70504755807"}
0005435126756	EC34A2	1641 385633	ALEKSEY MOISEEV	{"phone": "+70169678892"}
0005435126757	19719E	4038 906147	YULIYA MAKAROVA	{"email": "yuliya_makarova_22071966@postgrespro.ru", "phone": "+70437885356"}
0005435126758	19719E	1738 583438	ANATOLIY NAUMOV	{"email": "naumova-081985@postgrespro.ru", "phone": "+70614437065"}
0005435126759	7C543B	0214 298234	ALEKSEY GRIGOREV	{"phone": "+70891559149"}
0005435126760	7C543B	4340 181220	OLEG ILIN	{"email": "o-ilin-16071961@postgrespro.ru", "phone": "+70268421825"}
0005435126761	0E9C8A	7594 952029	ELENA PETROVA	{"phone": "+70952144574"}
0005435126762	0E9C8A	9489 241341	ALEKSEY SIDOROV	{"phone": "+70065559855"}
0005435126763	4EF491	5666 648767	FLYURA KAZAKOVA	{"email": "flyurakazakova15111965@postgrespro.ru", "phone": "+70751885479"}
0005435126764	C824B6	6503 849275	SERGEY BELOV	{"phone": "+70052372028"}
0005435126765	E7E687	5182 607165	VERA TARASOVA	{"phone": "+70187713112"}
0005435126766	E7E687	4876 481353	NATALYA ROMANOVA	{"email": "romanova_n_16011980@postgrespro.ru", "phone": "+70168462529"}
0005435126767	66666E	3376 380317	ANDREY SOLOVEV	{"email": "asolovev-021978@postgrespro.ru", "phone": "+70877109501"}
0005435126768	66666E	0189 454622	RAMIL ALEKSEEV	{"phone": "+70705358360"}
0005435126769	66666E	1882 178141	ALEKSANDR KULIKOV	{"phone": "+70460293066"}
0005435126770	6EABDD	2657 936118	NINA ZAYCEVA	{"email": "nina_zayceva.021969@postgrespro.ru", "phone": "+70110725514"}
0005435126771	2D10C5	7143 126864	ALEKSANDR KOROLEV	{"email": "korolevaleksandr031971@postgrespro.ru", "phone": "+70213971887"}
0005435126772	A6B71B	3258 700742	DENIS GAVRILOV	{"phone": "+70433761040"}
0005435126773	A6B71B	7128 584527	MARINA YAKOVLEVA	{"email": "yakovlevam.25031969@postgrespro.ru", "phone": "+70623820435"}
0005435126774	9459D5	6185 147667	VIKTOR ZAKHAROV	{"email": "zakharov-viktor-11011973@postgrespro.ru", "phone": "+70293067199"}
0005435126775	BBD630	7037 853464	VALERIY ILIN	{"email": "ilin-v-031972@postgrespro.ru", "phone": "+70149876845"}
0005435126776	7C808C	6746 375735	SERGEY MIRONOV	{"phone": "+70751307677"}
0005435126777	CAB7E9	4437 768149	ROMAN NAZAROV	{"email": "romannazarov-24051976@postgrespro.ru", "phone": "+70144395858"}
0005435126778	3264D2	0784 721363	VALENTINA ZHURAVLEVA	{"email": "valentinazhuravleva-1978@postgrespro.ru", "phone": "+70790508915"}
0005435126779	22794D	9864 990982	ALENA DENISOVA	{"email": "denisova.a_10101974@postgrespro.ru", "phone": "+70542990709"}
0005435126780	E64F25	4759 221407	VALENTINA ERMAKOVA	{"phone": "+70746314302"}
0005435126781	0824C5	7247 393204	ALEKSANDR MATVEEV	{"phone": "+70095062310"}
0005435126782	0824C5	1745 826066	NINA KRASNOVA	{"phone": "+70876976071"}
0005435126783	C841B4	9012 872215	ANASTASIYA ZHUKOVA	{"phone": "+70391638719"}
0005435126784	C841B4	9347 363242	EKATERINA GORBUNOVA	{"phone": "+70635813273"}
0005435126785	B9151C	2487 045869	SVETLANA SIDOROVA	{"phone": "+70875856496"}
0005435126786	B9151C	0301 105180	RAFAEL MAKAROV	{"email": "makarov.r.31071960@postgrespro.ru", "phone": "+70204274306"}
0005435126787	815B54	9570 130726	KIRILL PETROV	{"phone": "+70695594661"}
0005435126788	78850A	4932 204030	VLADIMIR MOISEEV	{"phone": "+70264214147"}
0005435126789	EFDB2F	1658 948430	ANATOLIY SIDOROV	{"phone": "+70178050133"}
0005435126790	EFDB2F	8372 031177	SANIYA MEDVEDEVA	{"email": "s.medvedeva_1972@postgrespro.ru", "phone": "+70077228136"}
0005435126791	CB6041	1458 362887	ELIZAVETA SMIRNOVA	{"email": "smirnovaelizaveta26071972@postgrespro.ru", "phone": "+70840503497"}
0005435126792	50E658	5488 473017	ANDREY DENISOV	{"email": "a-denisov_1959@postgrespro.ru", "phone": "+70934379924"}
0005435126793	F3430E	4086 937870	MAKSIM MOISEEV	{"phone": "+70704959659"}
0005435126794	CA4505	0423 809792	NATALYA MAKSIMOVA	{"email": "maksimova.natalya091961@postgrespro.ru", "phone": "+70906337149"}
0005435126795	8F1166	4976 130532	KONSTANTIN MAKSIMOV	{"email": "maksimovk.121965@postgrespro.ru", "phone": "+70477407731"}
0005435126796	8D1E1C	2954 375403	RUSLAN BORISOV	{"email": "ruslanborisov051980@postgrespro.ru", "phone": "+70330200440"}
0005435126797	E7A386	0071 233828	NATALYA ZHUKOVA	{"email": "zhukova_n1970@postgrespro.ru", "phone": "+70732485325"}
0005435126798	9CEBF3	8513 576334	SERGEY ZAKHAROV	{"phone": "+70282193533"}
0005435126799	BDE76D	3792 773706	DARYA ALEKSANDROVA	{"email": "aleksandrova_d-1978@postgrespro.ru", "phone": "+70330441798"}
0005435126800	2297E4	1545 869636	NIKOLAY DENISOV	{"phone": "+70256585359"}
0005435126801	C9643E	8168 810694	SERGEY ANDREEV	{"phone": "+70355184990"}
0005435126802	C9643E	7543 177073	DMITRIY RODIONOV	{"email": "drodionov-01101963@postgrespro.ru", "phone": "+70437051083"}
0005435126803	C9643E	9189 695572	ILNUR ALEKSANDROV	{"phone": "+70967848159"}
0005435126804	0C075C	0447 027832	NIKITA MIKHAYLOV	{"email": "n_mikhaylov_071974@postgrespro.ru", "phone": "+70100276016"}
0005435126805	1D680C	4429 103120	MARINA SAVELEVA	{"phone": "+70288149162"}
0005435126806	1D680C	2797 718608	MIKHAIL SEMENOV	{"email": "m.semenov-02021972@postgrespro.ru", "phone": "+70768810456"}
0005435126807	E841CB	0143 713257	ALEKSANDR SMIRNOV	{"phone": "+70362866179"}
0005435126808	557DBC	1243 513909	NIKOLAY SMIRNOV	{"phone": "+70742850718"}
0005435126809	557DBC	9995 635489	ANDREY KISELEV	{"email": "kiseleva01111974@postgrespro.ru", "phone": "+70574414632"}
0005435126810	204BA1	3361 512083	ANDREY SMIRNOV	{"email": "smirnov.a09081972@postgrespro.ru", "phone": "+70832365038"}
0005435126811	D193BA	7600 927484	TATYANA KOLESNIKOVA	{"email": "tatyana-kolesnikova-10081973@postgrespro.ru", "phone": "+70221071516"}
0005435126812	D193BA	3768 196046	VLADIMIR ANDREEV	{"email": "v_andreev071955@postgrespro.ru", "phone": "+70694058601"}
0005435126813	2239DC	1650 709011	KIRILL VOROBEV	{"email": "kvorobev.1973@postgrespro.ru", "phone": "+70778929809"}
0005435126814	EA0C03	1737 201464	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov1964@postgrespro.ru", "phone": "+70123572104"}
0005435126815	29DFCB	0945 675563	ANNA BARANOVA	{"email": "annabaranova_1982@postgrespro.ru", "phone": "+70512868131"}
0005435126816	0FE72C	4627 674881	ANDREY KONOVALOV	{"email": "konovalov_andrey_071969@postgrespro.ru", "phone": "+70297507944"}
0005435126817	0FE72C	8969 449735	NATALYA DANILOVA	{"email": "danilova-n-1978@postgrespro.ru", "phone": "+70458760193"}
0005435126818	B3540B	9033 208356	VIKTORIYA TIMOFEEVA	{"phone": "+70745086992"}
0005435126819	B3540B	5357 813358	SERGEY ZAKHAROV	{"phone": "+70644057757"}
0005435126820	E475C7	6487 955381	IRINA KUZMINA	{"phone": "+70643095498"}
0005435126821	632B96	4355 125418	RITA KARPOVA	{"phone": "+70949171882"}
0005435126822	632B96	5769 650640	IRINA ANDREEVA	{"email": "i.andreeva-051982@postgrespro.ru", "phone": "+70461831207"}
0005435126823	632B96	0648 915828	LYUDMILA RYABOVA	{"phone": "+70689745329"}
0005435126824	7B23CD	7347 004382	NATALIYA ISAEVA	{"email": "nataliya_isaeva101971@postgrespro.ru", "phone": "+70829228059"}
0005435126825	81703F	3213 683961	VALERIYA VOLKOVA	{"phone": "+70633224303"}
0005435126826	50B556	4131 215879	PAVEL GAVRILOV	{"email": "p-gavrilov.1963@postgrespro.ru", "phone": "+70944521631"}
0005435126827	F3C8E2	2005 677148	VALENTINA FADEEVA	{"email": "v-fadeeva-011980@postgrespro.ru", "phone": "+70892048872"}
0005435126828	B4223D	1913 173731	RASUL ANDREEV	{"phone": "+70769458732"}
0005435126829	06DBF1	5253 883682	VALENTINA SAVELEVA	{"email": "v-saveleva08091981@postgrespro.ru", "phone": "+70449650778"}
0005435126830	5EC5EB	3289 257375	VERA VASILEVA	{"phone": "+70755618976"}
0005435126831	AA7742	7013 783251	DENIS SAVELEV	{"phone": "+70677242611"}
0005435126832	0A504C	8962 090308	LYUDMILA POTAPOVA	{"email": "potapova_lyudmila_1977@postgrespro.ru", "phone": "+70151827984"}
0005435126833	9DD4C9	8524 028592	VASILIY MIKHAYLOV	{"email": "vasiliymikhaylov-1963@postgrespro.ru", "phone": "+70837853853"}
0005435126834	B474F2	7244 525762	MARIYA FEDOROVA	{"email": "m.fedorova.081979@postgrespro.ru", "phone": "+70534826754"}
0005435126835	726CC2	5100 019890	DAVID VOLKOV	{"phone": "+70168653185"}
0005435126836	726CC2	2634 749897	ANATOLIY SMIRNOV	{"phone": "+70117498281"}
0005435126837	33D7D6	7940 710689	ANDREY SCHERBAKOV	{"phone": "+70662308001"}
0005435126838	33D7D6	4724 227790	TATYANA ILINA	{"email": "ilina-t-021971@postgrespro.ru", "phone": "+70334771946"}
0005435126839	BD99ED	0492 091438	MARIYA CHERNOVA	{"email": "m.chernova_101974@postgrespro.ru", "phone": "+70283358522"}
0005435126840	304266	6201 032313	RAISA GUSEVA	{"email": "guseva.r-121982@postgrespro.ru", "phone": "+70586732954"}
0005435126841	2C4BA8	1018 852474	SERGEY NAUMOV	{"phone": "+70939006981"}
0005435126842	2C4BA8	7554 940182	IRINA KOLESNIKOVA	{"email": "irina.kolesnikova1976@postgrespro.ru", "phone": "+70260428371"}
0005435126843	8B6118	0087 162817	MARIYA OVCHINNIKOVA	{"phone": "+70265957077"}
0005435126844	85EBAA	1371 935529	SERGEY ALEKSANDROV	{"phone": "+70864554399"}
0005435126845	E0AD10	8251 946477	ELVIRA LUKYANOVA	{"email": "lukyanova-elvira06041971@postgrespro.ru", "phone": "+70818471400"}
0005435126846	E0AD10	9662 235854	SERGEY EGOROV	{"phone": "+70687390857"}
0005435126847	299666	2433 312641	EVGENIYA LOGINOVA	{"phone": "+70164893225"}
0005435126848	B67746	8762 506432	VIKTORIYA MALYSHEVA	{"phone": "+70711702731"}
0005435126849	B67746	9925 933336	DARYA SCHERBAKOVA	{"email": "scherbakova.d-1963@postgrespro.ru", "phone": "+70969374083"}
0005435126850	CB50CC	2538 600937	ANDREY ZHURAVLEV	{"phone": "+70209488144"}
0005435126851	CFCBFF	1953 042517	RAISA NIKOLAEVA	{"phone": "+70874679495"}
0005435126852	9EAF42	9245 110712	MIKHAIL KUZNECOV	{"phone": "+70830365501"}
0005435126853	915B26	9419 889583	VLADIMIR IVANOV	{"phone": "+70639533893"}
0005435126854	915B26	8831 882812	IVAN ANTONOV	{"phone": "+70683022765"}
0005435126855	038ED1	8097 221850	ALEKSANDRA VOLKOVA	{"phone": "+70290954394"}
0005435126856	23EC21	0152 571553	ILMIR SCHERBAKOV	{"email": "ilmir.scherbakov.16031979@postgrespro.ru", "phone": "+70626413204"}
0005435126857	942FC9	3391 106782	ALIYA EFREMOVA	{"phone": "+70756481412"}
0005435126858	DE91D6	4791 068273	TATYANA ZAKHAROVA	{"email": "tatyanazakharova_051983@postgrespro.ru", "phone": "+70420013536"}
0005435126859	C3E597	4946 096225	LYUDMILA TIMOFEEVA	{"phone": "+70981964692"}
0005435126860	C3E597	0656 177569	ANNA FILATOVA	{"email": "filatova_anna.081970@postgrespro.ru", "phone": "+70329505869"}
0005435126861	22ADCA	8412 497809	YULIYA ROMANOVA	{"email": "romanova.y.051970@postgrespro.ru", "phone": "+70268940994"}
0005435126862	22ADCA	3674 955808	NIKITA FOMIN	{"email": "fomin.nikita021959@postgrespro.ru", "phone": "+70572756027"}
0005435126863	470463	6271 408686	VALENTINA FEDOROVA	{"email": "fedorova.valentina-101972@postgrespro.ru", "phone": "+70921724821"}
0005435126864	E6A322	3787 904077	GALINA GORBUNOVA	{"phone": "+70569773587"}
0005435126865	EB556A	7930 846003	ELENA ARKHIPOVA	{"email": "arkhipova-e031969@postgrespro.ru", "phone": "+70213193781"}
0005435126866	BF0AF5	5648 342526	NIKOLAY KUDRYASHOV	{"phone": "+70360764586"}
0005435126867	BF0AF5	9726 525698	NATALYA EFIMOVA	{"phone": "+70462256521"}
0005435126868	65C326	0611 352090	ANNA MEDVEDEVA	{"phone": "+70761823487"}
0005435126869	65C326	8907 109875	PETR PAVLOV	{"email": "p-pavlov-1977@postgrespro.ru", "phone": "+70545167336"}
0005435126870	EFD7B2	8888 332220	DENIS SERGEEV	{"phone": "+70045448537"}
0005435126871	EFD7B2	7821 419836	INNA FEDOROVA	{"phone": "+70606256557"}
0005435126872	19810C	2383 237453	NATALIYA SERGEEVA	{"email": "sergeevan-04091977@postgrespro.ru", "phone": "+70853614262"}
0005435126873	19810C	1490 755705	ANNA POPOVA	{"phone": "+70317770100"}
0005435126874	19810C	0916 937940	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila1980@postgrespro.ru", "phone": "+70658608029"}
0005435126875	E8B93F	8726 778679	VALENTINA KOROLEVA	{"email": "koroleva_v-1962@postgrespro.ru", "phone": "+70869805350"}
0005435126876	E8B93F	5927 149149	EVGENIYA SERGEEVA	{"email": "evgeniya_sergeeva-1969@postgrespro.ru", "phone": "+70132812356"}
0005435126877	E8B93F	0434 696172	ANASTASIYA ARKHIPOVA	{"phone": "+70822715271"}
0005435126878	BB60E2	8538 954829	VALERIY MAKAROV	{"phone": "+70687907057"}
0005435126879	08E04D	7637 307167	ZOYA ZHURAVLEVA	{"email": "zhuravleva.z-1975@postgrespro.ru", "phone": "+70294915004"}
0005435126880	5DBA5E	6487 300013	MARINA GERASIMOVA	{"email": "gerasimovamarina28111967@postgrespro.ru", "phone": "+70326583506"}
0005435126881	D87857	4606 023161	ARINA IVANOVA	{"phone": "+70253640780"}
0005435126937	637F2E	8332 940957	ANVAR GRIGOREV	{"phone": "+70393850419"}
0005435126882	E0A251	7283 536014	MARIYA FILATOVA	{"email": "mariya_filatova_1974@postgrespro.ru", "phone": "+70268740207"}
0005435126883	9A85E9	3686 976264	IVAN ZHUKOV	{"email": "zhukovi1979@postgrespro.ru", "phone": "+70613811107"}
0005435126884	9A85E9	6113 569648	SVETLANA ZAYCEVA	{"email": "svetlanazayceva-071978@postgrespro.ru", "phone": "+70718842988"}
0005435126885	C8C977	8135 432827	ALEKSANDR DENISOV	{"email": "denisov-aleksandr011971@postgrespro.ru", "phone": "+70065152939"}
0005435126886	8162FF	2350 634678	MARIYA TARASOVA	{"email": "mariyatarasova121969@postgrespro.ru", "phone": "+70998891517"}
0005435126887	8162FF	3829 047674	GALINA MELNIKOVA	{"phone": "+70902874537"}
0005435126888	2980A8	4792 817863	ALEKSANDRA DAVYDOVA	{"phone": "+70927691541"}
0005435126889	2980A8	8557 339944	YULIYA ORLOVA	{"phone": "+70430200520"}
0005435126890	CAF352	8099 540485	KSENIYA DAVYDOVA	{"email": "davydovak10011980@postgrespro.ru", "phone": "+70315206901"}
0005435126891	CAF352	1726 758946	KLAVDIYA MOROZOVA	{"phone": "+70734246506"}
0005435126892	770320	8534 216221	ALEKSANDR ALEKSEEV	{"phone": "+70693859759"}
0005435126893	821210	4460 953831	ANASTASIYA ZAKHAROVA	{"email": "zakharova.anastasiya_121972@postgrespro.ru", "phone": "+70109159048"}
0005435126894	B93926	9701 531746	ALEKSANDRA ZAYCEVA	{"email": "zayceva-aleksandra.1969@postgrespro.ru", "phone": "+70679563469"}
0005435126895	67BB14	4057 044678	ANNA ANTONOVA	{"phone": "+70787617917"}
0005435126896	67BB14	8987 876540	ALEKSANDR KISELEV	{"email": "kiselev.aleksandr.31101977@postgrespro.ru", "phone": "+70736455448"}
0005435126897	F18A58	5955 610107	TAMARA RYABOVA	{"phone": "+70353638250"}
0005435126898	9A5C31	8439 700233	ANAIT KUZNECOVA	{"phone": "+70486576713"}
0005435126899	E72E88	5349 909492	ANASTASIYA EFIMOVA	{"email": "efimova-anastasiya081968@postgrespro.ru", "phone": "+70822585544"}
0005435126900	E72E88	3923 724524	SERGEY PETROV	{"phone": "+70284912423"}
0005435126901	825333	5091 808557	KSENIYA PETROVA	{"email": "kseniya_petrova_1967@postgrespro.ru", "phone": "+70546658899"}
0005435126902	825333	2902 622792	KSENIYA MIRONOVA	{"email": "kmironova081977@postgrespro.ru", "phone": "+70731167564"}
0005435126903	825333	4288 813717	VALENTINA NOVIKOVA	{"phone": "+70752591767"}
0005435126904	EB20DA	0343 424393	ELENA MOROZOVA	{"email": "elena_morozova01041959@postgrespro.ru", "phone": "+70800484129"}
0005435126905	EB20DA	4953 357967	EVGENIY SCHERBAKOV	{"email": "evgeniy.scherbakov111984@postgrespro.ru", "phone": "+70548083815"}
0005435126906	2C06C2	4467 216685	GALINA KONDRATEVA	{"email": "kondrateva.g-08021974@postgrespro.ru", "phone": "+70226702422"}
0005435126907	0A4F61	8927 027355	EVGENIYA FADEEVA	{"email": "evgeniya_fadeeva021966@postgrespro.ru", "phone": "+70537287034"}
0005435126908	0A4F61	3842 429893	ALEKSANDR VOLKOV	{"phone": "+70982106916"}
0005435126909	B2F08F	4773 564387	TATYANA KUZNECOVA	{"phone": "+70093519325"}
0005435126910	F9C25D	7067 930407	NINA FILATOVA	{"email": "nina_filatova1962@postgrespro.ru", "phone": "+70350057586"}
0005435126911	AE994B	0266 457656	VALERIY PAVLOV	{"email": "valeriy.pavlov-10051972@postgrespro.ru", "phone": "+70376422769"}
0005435126912	8F7AE6	4681 047815	VALENTINA DMITRIEVA	{"email": "dmitrievav_09121969@postgrespro.ru", "phone": "+70341071938"}
0005435126913	A90D2F	9256 139301	NINA MEDVEDEVA	{"phone": "+70118545511"}
0005435126914	A28C26	5624 207296	YURIY NOVIKOV	{"email": "novikov.y.121972@postgrespro.ru", "phone": "+70989720302"}
0005435126915	A28C26	6622 282193	TATYANA NESTEROVA	{"phone": "+70992847269"}
0005435126916	A28C26	2173 199393	SERGEY ANDREEV	{"email": "andreevs-07091975@postgrespro.ru", "phone": "+70646978872"}
0005435126917	1E3CD0	2827 516895	REGINA NOVIKOVA	{"phone": "+70431303313"}
0005435126918	1E3CD0	0057 341500	KLAVDIYA SEMENOVA	{"email": "k.semenova1970@postgrespro.ru", "phone": "+70806472756"}
0005435126919	080BCA	8162 014141	VLADIMIR SCHERBAKOV	{"phone": "+70732005484"}
0005435126920	AEAF88	4797 900872	VALENTINA KUZNECOVA	{"email": "valentina.kuznecova-13071965@postgrespro.ru", "phone": "+70491909214"}
0005435126921	23B09E	1313 167025	GALINA IVANOVA	{"email": "galinaivanova_091967@postgrespro.ru", "phone": "+70214811233"}
0005435126922	A69346	3661 806502	ALISA NESTEROVA	{"phone": "+70325428724"}
0005435126923	A69346	3921 230317	IRINA KISELEVA	{"email": "kiseleva_i-1981@postgrespro.ru", "phone": "+70191011170"}
0005435126924	39591B	1680 796446	SERGEY VOLKOV	{"phone": "+70435572914"}
0005435126925	39591B	0138 742909	SVETLANA POPOVA	{"email": "s.popova1968@postgrespro.ru", "phone": "+70593969109"}
0005435126926	28C4AB	3588 754485	GEORGIY BORISOV	{"phone": "+70235154091"}
0005435126927	9EC4FE	1078 707524	ARTEM IVANOV	{"phone": "+70555858634"}
0005435126928	9EC4FE	2060 153424	VALENTINA KRASNOVA	{"email": "valentina.krasnova-04121979@postgrespro.ru", "phone": "+70988994423"}
0005435126929	84F5D0	6866 936729	VLADIMIR NAZAROV	{"phone": "+70957098864"}
0005435126930	84F5D0	1336 320068	ANDREY ALEKSANDROV	{"phone": "+70272599160"}
0005435126931	EB6DAB	2300 528222	VLADIMIR BELOV	{"email": "belov_vladimir021968@postgrespro.ru", "phone": "+70671271919"}
0005435126932	EB6DAB	9367 605074	GALINA MAKAROVA	{"email": "makarova.galina_31081971@postgrespro.ru", "phone": "+70629104438"}
0005435126933	29338A	6184 191907	NIKOLAY SOKOLOV	{"email": "nikolay-sokolov-24091975@postgrespro.ru", "phone": "+70963263775"}
0005435126934	48E955	7633 218833	VALENTINA PAVLOVA	{"email": "pavlova_valentina.081969@postgrespro.ru", "phone": "+70283920960"}
0005435126935	48E955	7384 551788	MARIYA DENISOVA	{"email": "mariyadenisova-17071966@postgrespro.ru", "phone": "+70692188873"}
0005435126936	AF986D	3116 733165	OLGA MALYSHEVA	{"phone": "+70498514464"}
0005435126938	C872C9	7197 448126	ALEKSANDR ABRAMOV	{"email": "a_abramov_041970@postgrespro.ru", "phone": "+70456336691"}
0005435126939	C872C9	1428 676498	SVETLANA MATVEEVA	{"phone": "+70730985991"}
0005435126940	7DA596	6588 382275	GENNADIY GERASIMOV	{"email": "g-gerasimov-1970@postgrespro.ru", "phone": "+70744882498"}
0005435126941	7DA596	0817 102444	VALENTINA EFREMOVA	{"email": "efremova_v-1964@postgrespro.ru", "phone": "+70764380593"}
0005435126942	DBB8FB	4396 734472	ARTEM KUZNECOV	{"email": "a_kuznecov-07061963@postgrespro.ru", "phone": "+70079944978"}
0005435126943	879694	3893 811664	VIKTOR KUZNECOV	{"phone": "+70722742567"}
0005435126944	879694	4662 599592	NATALYA MOROZOVA	{"email": "morozova-n061965@postgrespro.ru", "phone": "+70722222364"}
0005435126945	36AD78	5991 649180	SVETLANA VOROBEVA	{"phone": "+70929774445"}
0005435126946	36AD78	3937 356057	ALEKSANDR SAVELEV	{"phone": "+70144808275"}
0005435126947	D2673D	3600 425009	MARIYA NIKITINA	{"phone": "+70960146921"}
0005435126948	6EA0F0	9361 362476	TAISA KUZNECOVA	{"email": "taisakuznecova.11051984@postgrespro.ru", "phone": "+70769451080"}
0005435126949	530F26	7738 099922	LYUDMILA ROMANOVA	{"phone": "+70606886936"}
0005435126950	530F26	7517 549038	NATALYA MIRONOVA	{"phone": "+70175884251"}
0005435126951	4BAF5D	5877 122014	NIKOLAY SMIRNOV	{"phone": "+70140731456"}
0005435126952	4FAD62	5326 059541	VLADIMIR VASILEV	{"email": "vladimir-vasilev.031971@postgrespro.ru", "phone": "+70283799025"}
0005435126953	E070FC	1526 089028	VLADIMIR VASILEV	{"phone": "+70534916041"}
0005435126954	BDA74B	6458 072696	ANASTASIYA KOROLEVA	{"email": "anastasiyakoroleva-07031987@postgrespro.ru", "phone": "+70478558224"}
0005435126955	A5DCD2	3341 244097	RAISA ZAKHAROVA	{"phone": "+70097332158"}
0005435126956	E5B6F9	3426 065428	SVETLANA MIRONOVA	{"email": "mironova-svetlana-061980@postgrespro.ru", "phone": "+70411593714"}
0005435126957	7EB458	4161 408245	VALERIY AFANASEV	{"email": "v.afanasev.10111974@postgrespro.ru", "phone": "+70566293859"}
0005435126958	7EB458	5165 289816	VIKTOR NAZAROV	{"email": "nazarov.viktor19061972@postgrespro.ru", "phone": "+70058658932"}
0005435126959	7EB458	7719 796379	KARINA KOROLEVA	{"email": "korolevak_091987@postgrespro.ru", "phone": "+70074666760"}
0005435126960	2366CA	9749 025513	ALBINA ROMANOVA	{"email": "romanova_a-03071974@postgrespro.ru", "phone": "+70185867758"}
0005435126961	2366CA	4552 297555	ARINA ROMANOVA	{"email": "romanovaa_03041966@postgrespro.ru", "phone": "+70705882476"}
0005435126962	98D7C3	6332 540102	DMITRIY KOZLOV	{"email": "d_kozlov-30031967@postgrespro.ru", "phone": "+70234600215"}
0005435126963	C128B5	6760 784493	VIKTOR BARANOV	{"phone": "+70322116225"}
0005435126964	8ACC32	3724 986396	TATYANA ALEKSEEVA	{"phone": "+70415678850"}
0005435126965	49D7A0	6745 616948	VLADIMIR SEMENOV	{"phone": "+70835657216"}
0005435126966	1FCE9A	7379 055403	ALFIYA NAZAROVA	{"phone": "+70373771233"}
0005435126967	1FCE9A	5546 183054	IRINA IVANOVA	{"phone": "+70810857180"}
0005435126968	81C0D9	6998 723982	LYUBOV KUDRYASHOVA	{"phone": "+70041965912"}
0005435126969	506BD5	7037 723000	LYUBOV MIKHAYLOVA	{"email": "l_mikhaylova.1966@postgrespro.ru", "phone": "+70561025334"}
0005435126970	506BD5	3814 391906	ROMAN MARTYNOV	{"phone": "+70254712036"}
0005435126971	EC406F	3383 565271	YULIYA MALYSHEVA	{"phone": "+70382298207"}
0005435126972	0CAA3B	7717 069266	ALEKSEY VASILEV	{"phone": "+70044428646"}
0005435126973	0CAA3B	8293 878963	ANASTASIYA KOROLEVA	{"phone": "+70496778783"}
0005435126974	F3973D	0784 569186	MARIYA ZAKHAROVA	{"email": "mariya.zakharova_24111974@postgrespro.ru", "phone": "+70239755476"}
0005435126975	7E97F6	6632 347345	PAVEL CHERNOV	{"email": "pavel.chernov1976@postgrespro.ru", "phone": "+70877932890"}
0005435126976	7E97F6	7807 478570	NATALYA ZOTOVA	{"email": "zotova.n-091983@postgrespro.ru", "phone": "+70923116410"}
0005435126977	D40755	6831 587946	DMITRIY EGOROV	{"email": "d_egorov-021964@postgrespro.ru", "phone": "+70734772173"}
0005435126978	E2A4FD	5218 645536	ANNA LOGINOVA	{"phone": "+70662999513"}
0005435126979	E2A4FD	5053 785500	IRINA POPOVA	{"email": "i-popova-20021976@postgrespro.ru", "phone": "+70069454207"}
0005435126980	E2A4FD	8683 076978	SERGEY SERGEEV	{"phone": "+70555044551"}
0005435126981	B2EA0B	9293 723979	MARINA IVANOVA	{"phone": "+70214058503"}
0005435126982	B2EA0B	6259 723924	ANDREY KUDRYASHOV	{"phone": "+70828182063"}
0005435126983	CA3044	5496 942024	EVGENIY MOISEEV	{"phone": "+70070845365"}
0005435126984	8CF1B4	0027 398342	TATYANA SOKOLOVA	{"email": "sokolova_tatyana-20091977@postgrespro.ru", "phone": "+70462101041"}
0005435126985	407295	3209 213902	NIKOLAY GAVRILOV	{"phone": "+70127090712"}
0005435126986	DEC0AD	3294 159932	EVGENIY MAKAROV	{"phone": "+70941206657"}
0005435126987	C61F30	0058 958418	GALINA YUDINA	{"phone": "+70221009675"}
0005435126988	C61F30	7880 696948	EVGENIYA EFIMOVA	{"email": "efimova-evgeniya26011972@postgrespro.ru", "phone": "+70373178157"}
0005435126989	E737DF	2089 045268	BORIS BONDARENKO	{"phone": "+70728248915"}
0005435126990	5CB403	6444 074797	VASILIY GRIGOREV	{"email": "grigorev_v.1966@postgrespro.ru", "phone": "+70948524717"}
0005435126991	189E41	6622 633295	ANDREY SERGEEV	{"email": "sergeev.a.17031977@postgrespro.ru", "phone": "+70511956191"}
0005435126992	327321	5253 257830	NINA ILINA	{"phone": "+70211133511"}
0005435126993	76DBC5	8229 869820	ALEKSANDR GRIGOREV	{"email": "grigorevaleksandr1975@postgrespro.ru", "phone": "+70304697779"}
0005435126994	76DBC5	1454 732325	NINA POPOVA	{"email": "popovanina_091963@postgrespro.ru", "phone": "+70619197347"}
0005435126995	D556AE	7012 281611	VLADIMIR ZAKHAROV	{"email": "vladimir-zakharov-101975@postgrespro.ru", "phone": "+70295997327"}
0005435126996	6CD28D	6062 004788	DMITRIY KUZMIN	{"phone": "+70852397467"}
0005435126997	68583B	7945 786229	NINA TITOVA	{"email": "titova_nina12101980@postgrespro.ru", "phone": "+70952821293"}
0005435126998	68583B	6642 877520	VADIM SOLOVEV	{"email": "solovev-vadim.071971@postgrespro.ru", "phone": "+70190578127"}
0005435126999	CA7740	4988 733390	ILYAS VOLKOV	{"email": "volkov_i-111974@postgrespro.ru", "phone": "+70158201146"}
0005435127000	4ACEFF	4115 233260	EVGENIY SOROKIN	{"email": "sorokine-03021966@postgrespro.ru", "phone": "+70744528231"}
0005435127001	3BE649	4716 836244	VLADISLAV ANDREEV	{"phone": "+70626742259"}
0005435127002	541C55	7063 920878	ANASTASIYA PAVLOVA	{"email": "pavlovaa-19051969@postgrespro.ru", "phone": "+70048909704"}
0005435127003	E6CD0F	1983 249876	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov1972@postgrespro.ru", "phone": "+70444216956"}
0005435127004	82D0AF	7746 340649	VYACHESLAV PETROV	{"email": "vyacheslav.petrov19061967@postgrespro.ru", "phone": "+70633488219"}
0005435127005	9D462E	7156 909098	ANNA ORLOVA	{"email": "orlova-a1964@postgrespro.ru", "phone": "+70719638224"}
0005435127006	5CA394	1645 382714	ANDREY PAVLOV	{"email": "andrey_pavlov-1981@postgrespro.ru", "phone": "+70601988118"}
0005435127007	5CA394	6973 009153	VALERIY ANDREEV	{"email": "andreevvaleriy-10061968@postgrespro.ru", "phone": "+70290777233"}
0005435127008	84D4B4	8017 092563	OKSANA KAZAKOVA	{"phone": "+70554018249"}
0005435127009	1C9D8A	8274 161757	ALISA FILIPPOVA	{"email": "filippovaa_121969@postgrespro.ru", "phone": "+70420499138"}
0005435127010	BD8832	6218 910679	ANDREY PAVLOV	{"email": "pavlov.andrey_021968@postgrespro.ru", "phone": "+70550017468"}
0005435127011	03421B	2772 671924	VIKTORIYA POTAPOVA	{"email": "viktoriya-potapova.24071975@postgrespro.ru", "phone": "+70320309096"}
0005435127012	03421B	1607 868862	KONSTANTIN SIDOROV	{"phone": "+70026039900"}
0005435127013	72A27E	7041 137604	IGOR DAVYDOV	{"phone": "+70104403681"}
0005435127014	883784	4544 433584	ANATOLIY POPOV	{"email": "popova.111968@postgrespro.ru", "phone": "+70760995317"}
0005435127015	883784	7957 470896	MARINA BORISOVA	{"email": "m_borisova-31031968@postgrespro.ru", "phone": "+70569777170"}
0005435127016	0FD707	7517 145131	IGOR STEPANOV	{"email": "stepanovi1971@postgrespro.ru", "phone": "+70690749507"}
0005435127017	ED8C7E	2869 090599	VALERIY KRASNOV	{"phone": "+70299499322"}
0005435127018	4741FE	3891 502511	OLEG VLASOV	{"email": "vlasovo-071968@postgrespro.ru", "phone": "+70717931476"}
0005435127019	6EE923	2200 991967	YAROSLAV VASILEV	{"phone": "+70686643637"}
0005435127020	6EE923	8385 805354	NIKITA NAZAROV	{"email": "nazarovn-021980@postgrespro.ru", "phone": "+70309942225"}
0005435127021	4F1B6E	3300 066195	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov-041962@postgrespro.ru", "phone": "+70899852332"}
0005435127022	70A8B8	6899 130140	MAKSIM VOLKOV	{"phone": "+70536899101"}
0005435127023	70A8B8	4191 735667	VIKTORIYA KRASNOVA	{"phone": "+70401007434"}
0005435127024	2C89E8	9485 619239	SERGEY PAVLOV	{"email": "s-pavlov_06071971@postgrespro.ru", "phone": "+70071497439"}
0005435127025	2C89E8	8921 379642	LIDIYA ILINA	{"email": "l_ilina-1969@postgrespro.ru", "phone": "+70348401622"}
0005435127026	86D94E	3943 392495	KIRILL VOROBEV	{"phone": "+70442064800"}
0005435127027	943428	4303 142612	VLADIMIR ZHUKOV	{"email": "vzhukov_021974@postgrespro.ru", "phone": "+70124014745"}
0005435127028	7D5691	2739 809762	VLADIMIR VASILEV	{"phone": "+70170559353"}
0005435127029	ED763A	9670 023830	ELENA MIKHAYLOVA	{"phone": "+70227849541"}
0005435127030	09A615	7799 232765	VIKTOR MAKSIMOV	{"email": "viktor_maksimov.1965@postgrespro.ru", "phone": "+70673882017"}
0005435127031	09A615	5361 221372	VALERIY GORBUNOV	{"email": "valeriy-gorbunov.121974@postgrespro.ru", "phone": "+70828999632"}
0005435127032	33CAD7	1199 691984	VADIM ANDREEV	{"email": "vadim_andreev.051969@postgrespro.ru", "phone": "+70918077285"}
0005435127033	A7F8E9	1202 746086	YULIYA PETROVA	{"phone": "+70939299189"}
0005435127034	AD0B93	6346 218750	PRASKOVYA TARASOVA	{"email": "praskovya_tarasova_1985@postgrespro.ru", "phone": "+70486552652"}
0005435127035	BA207E	8764 850305	OKSANA SEMENOVA	{"email": "o_semenova07091976@postgrespro.ru", "phone": "+70813481865"}
0005435127036	3D51E6	1526 014459	ILDAR SOKOLOV	{"email": "sokolovi_1978@postgrespro.ru", "phone": "+70375326705"}
0005435127037	3D51E6	1626 970600	ELENA NIKOLAEVA	{"email": "e_nikolaeva1972@postgrespro.ru", "phone": "+70096932491"}
0005435127038	D664C9	9389 753264	VALENTINA TIKHONOVA	{"phone": "+70601100227"}
0005435127039	119C18	0300 815151	VLADIMIR NAZAROV	{"email": "nazarov-v-021969@postgrespro.ru", "phone": "+70524915455"}
0005435127040	888910	6286 194040	VALERIY SIDOROV	{"email": "sidorov_valeriy_1977@postgrespro.ru", "phone": "+70259710899"}
0005435127041	906209	5800 585258	IRINA STEPANOVA	{"phone": "+70525244840"}
0005435127042	C1DEC7	9098 780363	TAISIYA FILATOVA	{"phone": "+70933532054"}
0005435127043	353C83	1139 616734	RINAT GRIGOREV	{"phone": "+70418102049"}
0005435127044	FD0D9C	4712 250996	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova.14121976@postgrespro.ru", "phone": "+70674595951"}
0005435127045	D029B1	7515 423071	ELENA ROMANOVA	{"email": "romanova-e071973@postgrespro.ru", "phone": "+70195685877"}
0005435127225	BE95A1	1637 852042	ELENA KAZAKOVA	{"phone": "+70969643299"}
0005435127046	E51988	6285 755623	NATALYA KONOVALOVA	{"email": "natalya-konovalova.26041963@postgrespro.ru", "phone": "+70712892266"}
0005435127047	E51988	7288 058440	VASILIY KOROLEV	{"email": "vasiliy-korolev_091975@postgrespro.ru", "phone": "+70304677788"}
0005435127048	DE766A	2995 039388	TATYANA KOMAROVA	{"phone": "+70417056033"}
0005435127049	E848D3	8019 410411	MARINA YAKOVLEVA	{"email": "yakovleva-marina-07101975@postgrespro.ru", "phone": "+70794459824"}
0005435127050	39ACCD	2451 931491	ALEKSEY GAVRILOV	{"phone": "+70927557814"}
0005435127051	39ACCD	6614 598570	ANDREY MAKAROV	{"email": "makarov_a_021969@postgrespro.ru", "phone": "+70151003546"}
0005435127052	993CA2	6133 439178	LEONID KUZMIN	{"email": "kuzminl111986@postgrespro.ru", "phone": "+70683424438"}
0005435127053	460B5A	3496 399337	NATALYA SMIRNOVA	{"phone": "+70494751873"}
0005435127054	1652CE	7827 861992	ELIZAVETA NIKOLAEVA	{"email": "nikolaevaelizaveta1979@postgrespro.ru", "phone": "+70907606443"}
0005435127055	C4866D	0073 798814	IGOR OSIPOV	{"phone": "+70402713661"}
0005435127056	378A0A	9590 443558	VALENTIN KUZMIN	{"email": "v_kuzmin1965@postgrespro.ru", "phone": "+70107765385"}
0005435127057	2F8E83	5279 220733	ANTON ANDREEV	{"email": "andreevanton-021972@postgrespro.ru", "phone": "+70131733331"}
0005435127058	38505B	6353 805864	NATALYA MAKAROVA	{"phone": "+70048536448"}
0005435127059	89EA1E	3489 074317	ALEKSEY KISELEV	{"phone": "+70904280952"}
0005435127060	2E35DC	8624 776818	MAKSIM MOISEEV	{"phone": "+70292390350"}
0005435127061	E449B0	7045 766258	OLESYA PAVLOVA	{"phone": "+70131564483"}
0005435127062	F0890E	2653 873526	ANASTASIYA ZAKHAROVA	{"phone": "+70523183840"}
0005435127063	8D930F	0328 307201	KHALIDA KOZLOVA	{"email": "kozlova.k1966@postgrespro.ru", "phone": "+70442999414"}
0005435127064	019C7C	8868 478741	IRINA SMIRNOVA	{"phone": "+70163479790"}
0005435127065	019C7C	3200 875260	TATYANA VASILEVA	{"phone": "+70472108750"}
0005435127066	C05BE9	5649 698797	KONSTANTIN FROLOV	{"email": "frolov-k-061981@postgrespro.ru", "phone": "+70587506125"}
0005435127067	FD4912	4682 522483	GENNADIY MELNIKOV	{"email": "melnikovg-1975@postgrespro.ru", "phone": "+70439438034"}
0005435127068	FD4912	6764 386461	OLGA POPOVA	{"phone": "+70824569248"}
0005435127069	E09FAD	8049 814219	SERGEY PAVLOV	{"phone": "+70141956436"}
0005435127070	E09FAD	7743 436609	VALENTINA VOLKOVA	{"email": "volkova_v-031980@postgrespro.ru", "phone": "+70290830997"}
0005435127071	E6BDE6	0508 089166	KLAVDIYA RYABOVA	{"phone": "+70274080562"}
0005435127072	237EDA	2972 240951	IRINA LOGINOVA	{"email": "iloginova_13031973@postgrespro.ru", "phone": "+70889443443"}
0005435127073	14EEE8	0027 541751	ARSENIY FILIPPOV	{"email": "filippovarseniy-1972@postgrespro.ru", "phone": "+70424941544"}
0005435127074	14EEE8	5929 476080	NATALYA MIKHAYLOVA	{"email": "mikhaylova-natalya-061975@postgrespro.ru", "phone": "+70176509337"}
0005435127075	F2A18D	0896 232436	ANTON MIKHAYLOV	{"phone": "+70225819045"}
0005435127076	AECF0D	3644 978248	VLADIMIR TARASOV	{"email": "tarasovvladimir.091963@postgrespro.ru", "phone": "+70840477890"}
0005435127077	268514	3383 071954	ANDREY MATVEEV	{"phone": "+70474689050"}
0005435127078	0F3370	6200 607369	GLEB MAKAROV	{"email": "makarovgleb14051978@postgrespro.ru", "phone": "+70219829735"}
0005435127079	3E84BC	0973 394182	ANDREY KULIKOV	{"email": "kulikova_27121965@postgrespro.ru", "phone": "+70477771032"}
0005435127080	E32A08	5630 599189	NINA ZAYCEVA	{"phone": "+70976702730"}
0005435127081	E32A08	7044 825071	RAISA SMIRNOVA	{"phone": "+70231565384"}
0005435127082	EBAE3E	0076 504701	SERGEY DMITRIEV	{"email": "dmitriev_sergey-02081961@postgrespro.ru", "phone": "+70567071821"}
0005435127083	8B2E7E	2713 206076	GALINA EFIMOVA	{"email": "efimovagalina.03051965@postgrespro.ru", "phone": "+70458800224"}
0005435127084	828B7A	2991 440701	ELENA SOROKINA	{"email": "sorokina.elena.011973@postgrespro.ru", "phone": "+70434899936"}
0005435127085	9E10EA	0748 143701	VALERIY SAVELEV	{"phone": "+70878330923"}
0005435127086	A0EA46	2929 051560	SERGEY MIRONOV	{"phone": "+70459182863"}
0005435127087	A0EA46	0905 885134	VLADIMIR PETROV	{"email": "petrov_v28081977@postgrespro.ru", "phone": "+70773811968"}
0005435127088	FA54FE	2418 019542	SERGEY ZHUKOV	{"email": "zhukov_s081982@postgrespro.ru", "phone": "+70267735791"}
0005435127089	FA54FE	8414 851239	ALEKSEY BELOV	{"phone": "+70764887738"}
0005435127090	3AB1E9	2798 304579	LYUBOV KOROLEVA	{"email": "l_koroleva-09121973@postgrespro.ru", "phone": "+70601506949"}
0005435127091	CBB081	8246 483723	TATYANA LUKYANOVA	{"phone": "+70608876243"}
0005435127092	CBB081	6016 517129	KLAVDIYA AKIMOVA	{"phone": "+70465406934"}
0005435127093	C9DB0D	1788 507804	EDGAR KOZLOV	{"email": "kozlov-edgar1974@postgrespro.ru", "phone": "+70265949414"}
0005435127094	C9DB0D	1847 426310	ALEKSANDR VOLKOV	{"phone": "+70880926969"}
0005435127095	C9DB0D	4222 519016	SERGEY TARASOV	{"email": "tarasov-sergey_15061967@postgrespro.ru", "phone": "+70882562850"}
0005435127096	18506A	1951 175776	VLADIMIR SERGEEV	{"phone": "+70415417421"}
0005435127097	18506A	8206 977337	DANIIL SOKOLOV	{"email": "sokolov-d.29061975@postgrespro.ru", "phone": "+70328042169"}
0005435127098	A0E461	7443 404352	TATYANA LEBEDEVA	{"email": "tlebedeva-02071964@postgrespro.ru", "phone": "+70465199320"}
0005435127099	CC7110	3249 366437	DARINA YAKOVLEVA	{"email": "yakovleva.d_1971@postgrespro.ru", "phone": "+70543468734"}
0005435127100	CDEFD2	5089 007298	VALENTINA IVANOVA	{"phone": "+70262068525"}
0005435127101	CDEFD2	2324 486849	IRINA NIKOLAEVA	{"phone": "+70420584188"}
0005435127102	25B848	9764 940695	VERONIKA KULIKOVA	{"email": "veronika-kulikova19031973@postgrespro.ru", "phone": "+70750341936"}
0005435127103	279A53	8166 510657	LYUBOV ANTONOVA	{"email": "antonova-l22061978@postgrespro.ru", "phone": "+70071829251"}
0005435127104	279A53	7287 834433	ANASTASIYA ROMANOVA	{"phone": "+70851665624"}
0005435127105	8F264A	7510 350879	YURIY KONOVALOV	{"email": "konovalovyuriy_10061977@postgrespro.ru", "phone": "+70883289953"}
0005435127106	EB9452	1813 764725	DMITRIY SERGEEV	{"email": "sergeev.dmitriy-051975@postgrespro.ru", "phone": "+70306284120"}
0005435127107	AC4494	1756 706742	ALEKSEY ZAKHAROV	{"email": "a-zakharov_12081981@postgrespro.ru", "phone": "+70014844580"}
0005435127108	275E4A	4952 623705	FEDOR ANDREEV	{"email": "andreev.f.1976@postgrespro.ru", "phone": "+70572584208"}
0005435127109	EDE88C	3530 010678	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov_1972@postgrespro.ru", "phone": "+70270946817"}
0005435127110	1F77C7	4025 802902	ANASTASIYA VOLKOVA	{"email": "a-volkova.011979@postgrespro.ru", "phone": "+70668955630"}
0005435127111	D1243B	7118 197864	NATALYA BORISOVA	{"phone": "+70491240623"}
0005435127112	3AE83E	5128 287846	OLGA POTAPOVA	{"email": "olgapotapova-31101975@postgrespro.ru", "phone": "+70502761505"}
0005435127113	3AE83E	0825 205667	NATALYA SERGEEVA	{"email": "natalyasergeeva01041976@postgrespro.ru", "phone": "+70809053998"}
0005435127114	F637EF	1704 969972	ELIZAVETA MAKAROVA	{"email": "makarova.e24121963@postgrespro.ru", "phone": "+70456794754"}
0005435127115	4376E3	9113 514854	YURIY MOROZOV	{"phone": "+70835466495"}
0005435127116	479805	3469 748588	VIKTOR MATVEEV	{"email": "matveev-viktor.1974@postgrespro.ru", "phone": "+70858611085"}
0005435127117	F60801	3358 619192	SERGEY ZAKHAROV	{"phone": "+70287573012"}
0005435127118	C6AF23	0480 068277	SERGEY MAKSIMOV	{"phone": "+70751746811"}
0005435127119	A7D3DC	9480 768127	OLGA PETROVA	{"email": "o.petrova-27111971@postgrespro.ru", "phone": "+70490834486"}
0005435127120	A7D3DC	8385 741226	SERGEY BARANOV	{"email": "sergey.baranov.1971@postgrespro.ru", "phone": "+70561628717"}
0005435127121	A7D3DC	5444 290985	FEDOR KOZLOV	{"email": "kozlov-f-1965@postgrespro.ru", "phone": "+70060258584"}
0005435127122	E61CED	8425 509353	NINA ANISIMOVA	{"email": "anisimovan051967@postgrespro.ru", "phone": "+70293142546"}
0005435127123	E61CED	2640 926721	EVGENIY IVANOV	{"email": "e-ivanov-20011965@postgrespro.ru", "phone": "+70970912533"}
0005435127124	8ECBBF	9900 909404	ANATOLIY SMIRNOV	{"email": "a_smirnov04071967@postgrespro.ru", "phone": "+70067060142"}
0005435127125	4CEFAD	1039 759453	ALEKSEY NAUMOV	{"phone": "+70496836984"}
0005435127126	AA01C8	3970 641911	DARYA LAZAREVA	{"phone": "+70675217185"}
0005435127127	AA01C8	9692 928922	SERGEY GUSEV	{"email": "gusevsergey1977@postgrespro.ru", "phone": "+70317533161"}
0005435127128	525C71	0514 287393	EVGENIY EGOROV	{"email": "eegorov1962@postgrespro.ru", "phone": "+70097755754"}
0005435127129	525C71	7417 063239	IVAN IVANOV	{"email": "ivanovi-061977@postgrespro.ru", "phone": "+70097332956"}
0005435127130	C9D979	8284 271437	MAKSIM SHEVCHENKO	{"phone": "+70179244459"}
0005435127131	991ECD	2281 294852	ANATOLIY SOKOLOV	{"email": "anatoliy.sokolov.1972@postgrespro.ru", "phone": "+70554997042"}
0005435127132	991ECD	6866 155462	EKATERINA EGOROVA	{"phone": "+70428052935"}
0005435127133	0C384A	6785 072597	IRINA SOKOLOVA	{"email": "sokolova-i_121974@postgrespro.ru", "phone": "+70502446828"}
0005435127134	9DDD77	0927 876370	SABINA VLASOVA	{"email": "vlasova-sabina_06101975@postgrespro.ru", "phone": "+70184482340"}
0005435127135	351F8A	5364 411241	GENNADIY POPOV	{"phone": "+70263933735"}
0005435127136	EF031B	6805 742110	TATYANA PETROVA	{"email": "tatyanapetrova_28091971@postgrespro.ru", "phone": "+70384757912"}
0005435127137	EF031B	4783 491967	YURIY STEPANOV	{"email": "y.stepanov-061962@postgrespro.ru", "phone": "+70880244686"}
0005435127138	EF031B	7951 867855	ANNA GAVRILOVA	{"email": "gavrilovaanna-121977@postgrespro.ru", "phone": "+70189020326"}
0005435127139	8A95DA	2858 325233	ELENA ALEKSANDROVA	{"email": "aleksandrova_elena.1960@postgrespro.ru", "phone": "+70847805579"}
0005435127140	8BB07D	0223 137033	EKATERINA POLYAKOVA	{"phone": "+70346659062"}
0005435127141	8BB07D	4368 472795	OKSANA SERGEEVA	{"phone": "+70266266179"}
0005435127142	594897	3592 604650	TATYANA MIKHAYLOVA	{"phone": "+70575144915"}
0005435127143	EC6CFE	5007 472899	ANASTASIYA KOROLEVA	{"email": "a.koroleva_1978@postgrespro.ru", "phone": "+70934261867"}
0005435127144	137D85	3732 219627	ALEKSANDR EGOROV	{"email": "aleksandr.egorov_11071975@postgrespro.ru", "phone": "+70705460138"}
0005435127145	137D85	9905 893166	VERA TIKHONOVA	{"email": "tikhonova-v.1977@postgrespro.ru", "phone": "+70403265483"}
0005435127146	137D85	6496 463787	NATALYA MASLOVA	{"phone": "+70178569865"}
0005435127147	137D85	2765 009141	NATALYA IVANOVA	{"email": "nivanova.081982@postgrespro.ru", "phone": "+70602172510"}
0005435127148	A8B5C3	2500 919651	ALEKSANDRA KONOVALOVA	{"phone": "+70673025997"}
0005435127149	2C0E78	8117 112435	ALEKSANDR NOVIKOV	{"email": "novikov_aleksandr.081968@postgrespro.ru", "phone": "+70816251193"}
0005435127150	846EA2	7178 942009	VLADIMIR KULIKOV	{"email": "kulikov_vladimir_111970@postgrespro.ru", "phone": "+70619577658"}
0005435127151	8FF371	2384 996235	DMITRIY FEDOROV	{"email": "dmitriyfedorov1975@postgrespro.ru", "phone": "+70184216032"}
0005435127152	B9519B	2043 538204	ALEKSEY GAVRILOV	{"email": "gavrilova-13081961@postgrespro.ru", "phone": "+70823024087"}
0005435127153	DA07E2	6189 480375	EMIL SAVELEV	{"phone": "+70242041587"}
0005435127154	57EC4B	8630 328416	ANATOLIY DAVYDOV	{"phone": "+70823677862"}
0005435127155	C09159	6902 293479	DMITRIY ANDREEV	{"email": "dmitriy.andreev.20071976@postgrespro.ru", "phone": "+70314628103"}
0005435127156	2985B6	6476 132887	PAVEL GAVRILOV	{"email": "pavel.gavrilov_1983@postgrespro.ru", "phone": "+70762605968"}
0005435127157	2AF355	2298 604293	SERGEY KAZAKOV	{"email": "kazakovs-121973@postgrespro.ru", "phone": "+70127814348"}
0005435127158	B33DDD	3441 683503	YURIY KUZNECOV	{"phone": "+70614802165"}
0005435127159	030AAE	6525 013677	ALENA TIMOFEEVA	{"phone": "+70167180810"}
0005435127160	DFFBC5	4455 893795	OKSANA SMIRNOVA	{"phone": "+70305463815"}
0005435127161	C66056	2097 260668	ALEKSANDR ANDREEV	{"phone": "+70915988769"}
0005435127162	5CD11F	0355 204067	NATALYA GAVRILOVA	{"phone": "+70559646363"}
0005435127163	5CD11F	9953 311883	TATYANA ILINA	{"email": "tatyana_ilina.121970@postgrespro.ru", "phone": "+70862762876"}
0005435127164	4CCAE5	4567 972911	LYUBOV VLASOVA	{"email": "l-vlasova13021972@postgrespro.ru", "phone": "+70571500265"}
0005435127165	E50234	1918 841174	YULIYA MAKAROVA	{"phone": "+70673842782"}
0005435127166	D1D894	7559 951009	ANDREY OSIPOV	{"phone": "+70658818876"}
0005435127167	125364	9917 682028	OLGA NESTEROVA	{"email": "o.nesterova_22071983@postgrespro.ru", "phone": "+70957714861"}
0005435127168	53D14A	5780 538590	VALENTINA AFANASEVA	{"email": "v_afanaseva_1970@postgrespro.ru", "phone": "+70906469251"}
0005435127169	41F659	6397 934016	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina-26051967@postgrespro.ru", "phone": "+70267306574"}
0005435127170	5E6494	1164 804792	VLADIMIR ROMANOV	{"email": "vladimirromanov-031964@postgrespro.ru", "phone": "+70563344745"}
0005435127171	5E6494	0036 589971	YANA GUSEVA	{"phone": "+70633619472"}
0005435127172	10DA63	1157 997230	ALLA VOLKOVA	{"phone": "+70886636074"}
0005435127173	2D8B1D	7964 392926	EKATERINA VOLKOVA	{"email": "volkovaekaterina.22041958@postgrespro.ru", "phone": "+70891691060"}
0005435127174	2D8B1D	2968 252984	VIKTORIYA ISAEVA	{"phone": "+70953836703"}
0005435127175	6BCAE5	4428 003161	RAISA KOVALEVA	{"email": "kovaleva-raisa_1970@postgrespro.ru", "phone": "+70616233544"}
0005435127176	6BCAE5	2995 408453	NADEZHDA NOVIKOVA	{"phone": "+70096480857"}
0005435127177	01521C	7452 863057	OLGA ALEKSEEVA	{"phone": "+70729464217"}
0005435127178	204F3B	5525 657388	OLGA BELOVA	{"email": "obelova1973@postgrespro.ru", "phone": "+70371368080"}
0005435127179	E31263	4807 268761	SVETLANA ALEKSEEVA	{"phone": "+70659539317"}
0005435127180	3DD2CC	2094 489008	ANDREY PETROV	{"email": "andrey_petrov.081966@postgrespro.ru", "phone": "+70013309426"}
0005435127181	0D170E	2053 503251	LIDIYA KOLESNIKOVA	{"phone": "+70201620621"}
0005435127182	0D170E	4432 040295	VYACHESLAV YAKOVLEV	{"phone": "+70507256752"}
0005435127183	3417B6	4007 153955	EVGENIY ALEKSEEV	{"phone": "+70822900409"}
0005435127184	946593	7207 382740	LARISA MELNIKOVA	{"phone": "+70174372615"}
0005435127185	946593	2246 973451	NADEZHDA ANTONOVA	{"phone": "+70539280382"}
0005435127186	8E259D	1400 961738	KRISTINA PAVLOVA	{"email": "pavlova.k121967@postgrespro.ru", "phone": "+70569622773"}
0005435127187	8E259D	5032 591292	NIKOLAY KRASNOV	{"phone": "+70492440184"}
0005435127188	8E259D	8862 252019	LYUDMILA MOROZOVA	{"phone": "+70405854245"}
0005435127189	8E259D	8644 100573	TATYANA FILATOVA	{"email": "filatova.tatyana.11021967@postgrespro.ru", "phone": "+70983334536"}
0005435127190	B49511	8196 948405	SERGEY MIKHAYLOV	{"phone": "+70854188941"}
0005435127191	7FC4BA	9945 824076	MIKHAIL NIKITIN	{"email": "nikitinm071969@postgrespro.ru", "phone": "+70712989640"}
0005435127192	FBD0FB	4432 435781	VLADIMIR VASILEV	{"email": "vasilev-vladimir_1968@postgrespro.ru", "phone": "+70709200395"}
0005435127193	A1A400	2547 432972	ILYA YAKOVLEV	{"phone": "+70161849375"}
0005435127194	A1A400	6551 900165	TATYANA MAKAROVA	{"phone": "+70045425429"}
0005435127195	A1A400	2351 209027	IGOR DAVYDOV	{"email": "davydovi101979@postgrespro.ru", "phone": "+70974780844"}
0005435127196	97E966	1576 755852	INESSA KOVALEVA	{"email": "kovaleva-i.13011980@postgrespro.ru", "phone": "+70470899811"}
0005435127197	F7B936	7208 694658	IVAN SIDOROV	{"phone": "+70076614587"}
0005435127198	F7B936	8240 663574	VIKTOR EGOROV	{"email": "egorovviktor-061982@postgrespro.ru", "phone": "+70536778211"}
0005435127199	8CEA98	2268 203768	ELENA TARASOVA	{"phone": "+70505489843"}
0005435127200	C4B642	8612 906730	DENIS SOLOVEV	{"email": "denis.solovev061981@postgrespro.ru", "phone": "+70249279601"}
0005435127201	BB0A1D	9536 009584	VLADIMIR NAZAROV	{"email": "vladimir_nazarov_1972@postgrespro.ru", "phone": "+70463085648"}
0005435127202	C18D14	0673 459809	MIKHAIL MAKSIMOV	{"phone": "+70735378086"}
0005435127203	DD41C7	2244 907356	KSENIYA DANILOVA	{"phone": "+70339887247"}
0005435127204	DD41C7	2525 915429	GALINA KONOVALOVA	{"phone": "+70637801537"}
0005435127205	1E9F9F	4418 964055	NIKOLAY POPOV	{"phone": "+70893915977"}
0005435127206	999972	4306 750672	EGOR ZAYCEV	{"phone": "+70953480484"}
0005435127207	999972	2631 846888	ANASTASIYA KRASNOVA	{"phone": "+70405937760"}
0005435127208	E77173	0719 348403	ELVIRA KOLESNIKOVA	{"email": "kolesnikova-e_07031975@postgrespro.ru", "phone": "+70158494170"}
0005435127209	7B2D64	6203 705577	YULIYA BARANOVA	{"email": "baranovayuliya1967@postgrespro.ru", "phone": "+70278664147"}
0005435127210	7B2D64	4163 443874	VARVARA MELNIKOVA	{"email": "melnikova.varvara_041974@postgrespro.ru", "phone": "+70372176448"}
0005435127211	CD7128	7935 564506	SERGEY KUZNECOV	{"phone": "+70941177613"}
0005435127212	859C61	0990 266002	SVETLANA LOGINOVA	{"email": "sloginova-01041964@postgrespro.ru", "phone": "+70698897316"}
0005435127213	859C61	9012 408481	EVGENIY SCHERBAKOV	{"email": "scherbakov_e-1967@postgrespro.ru", "phone": "+70482715835"}
0005435127214	F1EB70	7152 469493	EKATERINA ILINA	{"phone": "+70205784380"}
0005435127215	F1EB70	0478 158820	IGOR SIDOROV	{"phone": "+70092514932"}
0005435127216	D7B97D	9214 606397	ANNA EFIMOVA	{"phone": "+70343153620"}
0005435127217	D7B97D	1027 788836	SERGEY ZAYCEV	{"email": "sergeyzaycev041966@postgrespro.ru", "phone": "+70070818369"}
0005435127218	D7B97D	1488 172157	EKATERINA ALEKSEEVA	{"phone": "+70096286395"}
0005435127219	684067	5234 147590	OLEG STEPANOV	{"phone": "+70629628415"}
0005435127220	220C5E	0239 514645	PETR GAVRILOV	{"email": "petr.gavrilov-17011961@postgrespro.ru", "phone": "+70018830146"}
0005435127221	C532E6	9886 939446	LYUBOV MIKHAYLOVA	{"email": "mikhaylova.l22041972@postgrespro.ru", "phone": "+70289353589"}
0005435127222	C532E6	3396 237274	VIKTORIYA EGOROVA	{"email": "egorova_viktoriya.1965@postgrespro.ru", "phone": "+70102287343"}
0005435127223	AA8199	0423 522828	PAVEL ZHUKOV	{"email": "pavel-zhukov.04021973@postgrespro.ru", "phone": "+70535684540"}
0005435127224	BE95A1	6972 440067	ALEKSANDRA DMITRIEVA	{"phone": "+70103720002"}
0005435127226	796321	3833 290031	IGOR POPOV	{"phone": "+70319140011"}
0005435127227	ABE048	9651 650908	LILIYA SOROKINA	{"email": "sorokina-l.31011984@postgrespro.ru", "phone": "+70952215490"}
0005435127228	C0A158	0508 375695	TAMARA STEPANOVA	{"phone": "+70565585446"}
0005435127229	477600	3100 907260	ERIK FOMIN	{"email": "fomin-erik_1955@postgrespro.ru", "phone": "+70314918453"}
0005435127230	2688E4	3154 768696	ELENA ERMAKOVA	{"email": "e-ermakova-27011973@postgrespro.ru", "phone": "+70102502503"}
0005435127231	2688E4	3220 593201	SVETLANA OVCHINNIKOVA	{"email": "svetlana.ovchinnikova.041973@postgrespro.ru", "phone": "+70278064011"}
0005435127232	2688E4	2666 311786	VYACHESLAV ALEKSANDROV	{"email": "aleksandrov-vyacheslav_061963@postgrespro.ru", "phone": "+70286087359"}
0005435127233	CA5C65	2416 895507	ALEKSANDR DENISOV	{"phone": "+70572581198"}
0005435127234	CA5C65	5714 275405	VIKTORIYA KOROLEVA	{"email": "vkoroleva_1980@postgrespro.ru", "phone": "+70533855925"}
0005435127235	DC5FD6	3335 516656	ALEKSANDR NIKITIN	{"phone": "+70016360019"}
0005435127236	F92280	0178 044414	RAFAIL IVANOV	{"email": "ivanovr.011969@postgrespro.ru", "phone": "+70728271672"}
0005435127237	49FEFB	8012 933984	ANASTASIYA NAZAROVA	{"email": "nazarova-a.091979@postgrespro.ru", "phone": "+70279199066"}
0005435127238	8EEBBA	3417 559210	ALEKSANDR SIDOROV	{"email": "sidorov-a.061981@postgrespro.ru", "phone": "+70546783608"}
0005435127239	8EEBBA	7190 516363	NATALYA ANDREEVA	{"email": "n-andreeva.081986@postgrespro.ru", "phone": "+70052127583"}
0005435127240	F58C2B	4933 661756	ALEKSANDR KUZMIN	{"phone": "+70772465704"}
0005435127241	F58C2B	9691 561128	ALEKSEY KOROLEV	{"phone": "+70799431979"}
0005435127242	158B2D	5492 486733	MARGARITA ZAYCEVA	{"email": "margarita.zayceva1968@postgrespro.ru", "phone": "+70206555445"}
0005435127243	70A629	2174 101779	ELENA GORBUNOVA	{"phone": "+70150734405"}
0005435127244	70A629	7285 378389	MAKSIM ZAYCEV	{"phone": "+70729370269"}
0005435127245	2D9538	1631 930657	LYUDMILA BELYAEVA	{"phone": "+70896476408"}
0005435127246	D4F1B8	6356 445326	SOFIYA BELOVA	{"phone": "+70402787629"}
0005435127247	D4F1B8	4508 447824	GALINA OVCHINNIKOVA	{"email": "ovchinnikova_galina031976@postgrespro.ru", "phone": "+70963681707"}
0005435127248	0AA4BD	3654 993248	VIKTOR POPOV	{"phone": "+70931579273"}
0005435127249	0AA4BD	4693 700574	IGOR FEDOTOV	{"email": "fedotov_i.1970@postgrespro.ru", "phone": "+70117661529"}
0005435127250	43D053	0674 226717	SERGEY ALEKSEEV	{"email": "sergey_alekseev_021969@postgrespro.ru", "phone": "+70304878783"}
0005435127251	481CCF	4431 178245	VASILIY SMIRNOV	{"phone": "+70703923837"}
0005435127252	C85215	2587 484935	ANNA GORBUNOVA	{"email": "gorbunovaanna-20031976@postgrespro.ru", "phone": "+70933101536"}
0005435127253	E5811A	3891 935127	MATVEY ZHUKOV	{"phone": "+70257505456"}
0005435127254	E5811A	4906 460129	SERGEY MAKSIMOV	{"phone": "+70077944413"}
0005435127255	602ED1	4372 085793	VLADISLAV PETROV	{"email": "vladislav_petrov30091970@postgrespro.ru", "phone": "+70249242118"}
0005435127256	0CF561	6829 432275	EVGENIYA GERASIMOVA	{"email": "gerasimova-e-30101972@postgrespro.ru", "phone": "+70799667494"}
0005435127257	EFC057	9047 586386	DENIS PAVLOV	{"phone": "+70496914673"}
0005435127258	3A7481	2498 692141	ILMIRA ARKHIPOVA	{"phone": "+70383458641"}
0005435127259	77A6DC	8268 051603	RINAT KAZAKOV	{"email": "r_kazakov.1975@postgrespro.ru", "phone": "+70086935022"}
0005435127260	77A6DC	1309 291043	TATYANA PAVLOVA	{"email": "pavlova-tatyana21081968@postgrespro.ru", "phone": "+70273712210"}
0005435127261	5FC2D8	4132 928196	MIKHAIL VOLKOV	{"phone": "+70105230745"}
0005435127262	294071	2052 037699	PAVEL KUZNECOV	{"phone": "+70673193381"}
0005435127263	0B41D3	2803 745405	ILYA NIKITIN	{"email": "ilya.nikitin.061978@postgrespro.ru", "phone": "+70013941516"}
0005435127264	0B41D3	5713 148112	DMITRIY YAKOVLEV	{"email": "yakovlevd_1975@postgrespro.ru", "phone": "+70156921902"}
0005435127265	C690C1	3662 049953	EVGENIYA IVANOVA	{"email": "eivanova_1983@postgrespro.ru", "phone": "+70762081199"}
0005435127266	C690C1	5001 226168	VSEVOLOD KAZAKOV	{"email": "vsevolod.kazakov_07081967@postgrespro.ru", "phone": "+70255935755"}
0005435127267	B6D370	1631 423972	LYUDMILA POTAPOVA	{"email": "l-potapova_091974@postgrespro.ru", "phone": "+70479119055"}
0005435127268	12F176	9840 313742	VLADISLAV BORISOV	{"phone": "+70792677859"}
0005435127269	12F176	7800 542260	ROMAN FEDOROV	{"phone": "+70110988827"}
0005435127270	2ECC81	9591 110528	MARIYA NAUMOVA	{"email": "naumova-m.06031974@postgrespro.ru", "phone": "+70791638133"}
0005435127271	655003	4364 825360	DENIS KUZNECOV	{"email": "denis-kuznecov.041980@postgrespro.ru", "phone": "+70178944079"}
0005435127272	4CED9F	2488 024728	DARYA FILATOVA	{"email": "darya_filatova-1971@postgrespro.ru", "phone": "+70349911289"}
0005435127273	49C690	5030 066013	VERA AFANASEVA	{"email": "afanaseva_vera07091973@postgrespro.ru", "phone": "+70232415363"}
0005435127274	A38CF9	9391 773914	NAIL POPOV	{"email": "n.popov1959@postgrespro.ru", "phone": "+70862864465"}
0005435127275	C3BD0B	7490 281849	ZHANNA TARASOVA	{"phone": "+70772892727"}
0005435127276	0DE927	0907 399818	GENNADIY SIDOROV	{"email": "sidorov-g1960@postgrespro.ru", "phone": "+70521359450"}
0005435127277	0DE927	8518 840735	LILIYA KOZLOVA	{"email": "liliya.kozlova041969@postgrespro.ru", "phone": "+70335776685"}
0005435127278	8F160B	3205 599164	MARINA POPOVA	{"phone": "+70424305910"}
0005435127279	8F160B	7612 889981	GALINA ZAKHAROVA	{"phone": "+70765315877"}
0005435127280	D2B6E7	6537 225694	ANASTASIYA ARKHIPOVA	{"phone": "+70585494840"}
0005435127281	1164F2	0344 251910	LYUBOV KRASNOVA	{"email": "krasnova-l-29011970@postgrespro.ru", "phone": "+70816823880"}
0005435127282	AB8596	6629 575455	VERONIKA SCHERBAKOVA	{"phone": "+70513084382"}
0005435127283	AB8596	9589 552776	DARYA KUZNECOVA	{"phone": "+70166993385"}
0005435127284	A2E12E	2527 904490	IVAN FEDOROV	{"phone": "+70015224560"}
0005435127285	294693	7149 074842	TATYANA TIKHONOVA	{"phone": "+70414511046"}
0005435127286	294693	2449 163961	VALENTINA DENISOVA	{"email": "valentinadenisova-23091968@postgrespro.ru", "phone": "+70208994428"}
0005435127287	CE607D	2946 126061	ALEKSEY IVANOV	{"email": "aleksey_ivanov13091964@postgrespro.ru", "phone": "+70963459758"}
0005435127288	CE607D	6586 690621	ROBERT SEMENOV	{"email": "r.semenov02021970@postgrespro.ru", "phone": "+70442239289"}
0005435127289	DC7265	4147 367877	NADEZHDA MALYSHEVA	{"phone": "+70074114689"}
0005435127290	DC7265	5122 588339	NADEZHDA DAVYDOVA	{"phone": "+70682001557"}
0005435127291	44A77B	7213 777065	ELENA FROLOVA	{"email": "frolovaelena_1980@postgrespro.ru", "phone": "+70830409713"}
0005435127292	6A1741	9678 870613	ZOYA BELOVA	{"phone": "+70381774548"}
0005435127293	BA464A	5844 212718	YULIYA SERGEEVA	{"email": "sergeeva_y.091981@postgrespro.ru", "phone": "+70488301527"}
0005435127294	BA464A	1918 841414	VYACHESLAV MIRONOV	{"email": "vyacheslavmironov-1969@postgrespro.ru", "phone": "+70528658275"}
0005435127295	61A19F	1658 737000	ALINA KUZNECOVA	{"phone": "+70077189894"}
0005435127296	A801B5	6249 249424	VLADIMIR ILIN	{"email": "ilin.vladimir11121977@postgrespro.ru", "phone": "+70883783937"}
0005435127297	5FA975	0798 959044	ARTUR FEDOROV	{"phone": "+70715492963"}
0005435127298	1ECB45	1002 270648	VLADIMIR MAKSIMOV	{"email": "vladimir-maksimov-13021989@postgrespro.ru", "phone": "+70946900322"}
0005435127299	7F7901	1680 063456	IVAN RODIONOV	{"email": "rodionovivan_09051969@postgrespro.ru", "phone": "+70442875109"}
0005435127300	68A869	2526 880101	ARTEM KOZLOV	{"phone": "+70988195070"}
0005435127301	68A869	5599 636484	VLADIMIR ZHUKOV	{"email": "zhukov_v.02091969@postgrespro.ru", "phone": "+70348611005"}
0005435127302	7D62CE	9917 072538	ALEKSANDR KULIKOV	{"phone": "+70355028499"}
0005435127303	9032B3	2035 126869	RASHIT KUZNECOV	{"phone": "+70216533748"}
0005435127304	C036A7	7495 052189	ELENA POTAPOVA	{"phone": "+70304981805"}
0005435127305	C036A7	6542 517503	TATYANA TIMOFEEVA	{"phone": "+70522971912"}
0005435127306	0D68F2	9550 567571	TATYANA GERASIMOVA	{"email": "gerasimovat25021962@postgrespro.ru", "phone": "+70361728024"}
0005435127307	3C9E9C	2049 728053	GALINA EFREMOVA	{"phone": "+70529840950"}
0005435127308	3AD83F	0545 016362	ILMIRA VOLKOVA	{"phone": "+70584090065"}
0005435127309	3AD83F	8303 619003	IGOR KUZNECOV	{"phone": "+70846819680"}
0005435127310	78DDAB	1283 492331	OLGA LUKYANOVA	{"phone": "+70283632212"}
0005435127311	78DDAB	8767 639355	RUSLAN MAKAROV	{"phone": "+70261710194"}
0005435127312	541DC9	6456 849841	NIKITA FEDOTOV	{"phone": "+70520353605"}
0005435127313	541DC9	9117 920379	VERA KAZAKOVA	{"phone": "+70824251566"}
0005435127314	763F3E	5529 484141	DMITRIY TARASOV	{"email": "dtarasov_22021972@postgrespro.ru", "phone": "+70608881053"}
0005435127315	F750BC	4214 070423	VALERIY GORBUNOV	{"email": "gorbunovv_1973@postgrespro.ru", "phone": "+70605354631"}
0005435127316	CEEBB3	0208 020235	EKATERINA KOVALEVA	{"phone": "+70460879543"}
0005435127317	18E4F7	4589 241207	ALEKSANDRA TITOVA	{"email": "aleksandratitova_17041967@postgrespro.ru", "phone": "+70259962096"}
0005435127318	5AAD34	2760 720997	SHAVKAT SEMENOV	{"phone": "+70637378495"}
0005435127319	5AAD34	3090 191801	NADEZHDA MOISEEVA	{"phone": "+70879778763"}
0005435127320	00519C	5383 526794	NATALYA ROMANOVA	{"phone": "+70615356672"}
0005435127321	00519C	0158 755105	VASILIY GUSEV	{"phone": "+70479058263"}
0005435127322	00519C	5713 332672	EVGENIY MIKHAYLOV	{"email": "mikhaylov-evgeniy1974@postgrespro.ru", "phone": "+70024190521"}
0005435127323	739547	4537 405467	VYACHESLAV MATVEEV	{"email": "v-matveev_03071980@postgrespro.ru", "phone": "+70687477127"}
0005435127324	739547	7764 383111	TATYANA IVANOVA	{"email": "ivanovatatyana_081974@postgrespro.ru", "phone": "+70725522281"}
0005435127325	739547	8364 795089	IVAN RODIONOV	{"phone": "+70914281582"}
0005435127326	E7C75A	6351 657568	ANDREY VOROBEV	{"phone": "+70260880371"}
0005435127327	B2EB41	5942 565434	VALERIY SEMENOV	{"phone": "+70191974951"}
0005435127328	B2EB41	0663 260533	ELENA FEDOROVA	{"email": "fedorova-elena-1984@postgrespro.ru", "phone": "+70428254958"}
0005435127329	85523B	6261 109315	ELENA RODIONOVA	{"phone": "+70525322256"}
0005435127330	944CCC	0988 097351	TATYANA VASILEVA	{"email": "tvasileva1965@postgrespro.ru", "phone": "+70773929290"}
0005435127331	F8F9EE	1312 534963	SERGEY ALEKSEEV	{"phone": "+70031027930"}
0005435127332	638C11	4773 585550	TAKHIR ISAEV	{"phone": "+70473927629"}
0005435127333	638C11	9823 210003	MIKHAIL BELOV	{"email": "belovm031968@postgrespro.ru", "phone": "+70071840518"}
0005435127334	638C11	9471 657010	RUMIYA OSIPOVA	{"phone": "+70261970342"}
0005435127335	49660E	8782 653781	ELENA SEMENOVA	{"email": "semenovaelena-1970@postgrespro.ru", "phone": "+70463572053"}
0005435127336	F6A677	6089 744250	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr-23061981@postgrespro.ru", "phone": "+70488845507"}
0005435127337	F6A677	2570 518824	ELENA TIMOFEEVA	{"phone": "+70465684206"}
0005435127338	B1A122	6546 248073	IRINA YUDINA	{"phone": "+70505583180"}
0005435127339	CD8188	6204 159447	VLADIMIR KUZNECOV	{"phone": "+70353224274"}
0005435127340	D4AF42	9286 002663	VIKTOR KAZAKOV	{"email": "kazakov-viktor17041970@postgrespro.ru", "phone": "+70749653493"}
0005435127341	F16631	3755 028968	EVGENIY BONDARENKO	{"email": "bondarenko.evgeniy111963@postgrespro.ru", "phone": "+70452637040"}
0005435127342	0ABEA7	4680 986798	OLEG MELNIKOV	{"email": "melnikov_o17051975@postgrespro.ru", "phone": "+70502658480"}
0005435127343	0ABEA7	1201 507899	TATYANA BELYAEVA	{"email": "tatyanabelyaeva_091986@postgrespro.ru", "phone": "+70483453612"}
0005435127344	86609E	6290 636772	KIRILL MIRONOV	{"email": "kirill_mironov.021976@postgrespro.ru", "phone": "+70166394179"}
0005435127345	19AFAC	3882 357856	LYUBOV LOGINOVA	{"email": "lloginova.1971@postgrespro.ru", "phone": "+70238309266"}
0005435127346	19AFAC	9679 930012	SERGEY ILIN	{"phone": "+70300508387"}
0005435127347	19AFAC	4672 202797	BOGDAN DMITRIEV	{"email": "dmitrievb_011992@postgrespro.ru", "phone": "+70051664257"}
0005435127348	19AFAC	7133 510385	SERGEY SIDOROV	{"email": "sidorov-s-1982@postgrespro.ru", "phone": "+70570591282"}
0005435127349	FB8D72	6677 183229	YURIY ILIN	{"phone": "+70289260477"}
0005435127350	FB8D72	3477 468498	LARISA FEDOROVA	{"phone": "+70952924841"}
0005435127351	F60211	9345 131927	ANASTASIYA KONDRATEVA	{"email": "anastasiyakondrateva061976@postgrespro.ru", "phone": "+70900033808"}
0005435127352	AAB61B	5978 936115	MIKHAIL CHERNOV	{"email": "chernovm_041976@postgrespro.ru", "phone": "+70557910098"}
0005435127353	AAB61B	8137 015418	IRINA NIKITINA	{"email": "nikitina.irina.29081975@postgrespro.ru", "phone": "+70375981970"}
0005435127354	286944	4419 487891	NIKOLAY SOROKIN	{"email": "n-sorokin.1969@postgrespro.ru", "phone": "+70462422601"}
0005435127355	286944	6032 627337	YULIYA EFREMOVA	{"email": "yuliyaefremova-1981@postgrespro.ru", "phone": "+70817658963"}
0005435127356	274FC0	3469 887519	PETR RODIONOV	{"email": "petrrodionov-02121970@postgrespro.ru", "phone": "+70446161113"}
0005435127357	274FC0	8366 840788	ALEKSANDRA MOISEEVA	{"phone": "+70058724175"}
0005435127358	B09377	7190 181929	NIKOLAY SERGEEV	{"email": "nikolay-sergeev.22071968@postgrespro.ru", "phone": "+70076168335"}
0005435127359	B09377	0076 419993	ALLA ALEKSEEVA	{"email": "alekseeva-alla081975@postgrespro.ru", "phone": "+70123602471"}
0005435127360	B09377	0400 692061	NADEZHDA GORBUNOVA	{"phone": "+70975121860"}
0005435127361	700FA9	8141 799407	ULYANA DMITRIEVA	{"email": "dmitrieva-ulyana-06101959@postgrespro.ru", "phone": "+70572259609"}
0005435127362	AB9451	4504 552156	SERGEY MOROZOV	{"email": "sergey.morozov.1977@postgrespro.ru", "phone": "+70146314390"}
0005435127363	43DC4B	8681 616574	SVETLANA MALYSHEVA	{"phone": "+70295249660"}
0005435127364	C42114	1106 055821	BOGDAN IVANOV	{"phone": "+70427401086"}
0005435127365	3BE08B	9733 994043	EVGENIYA BORISOVA	{"phone": "+70974052729"}
0005435127366	B9923E	9734 836560	ANNA KOROLEVA	{"phone": "+70884058668"}
0005435127367	5C5562	9972 415459	ELENA ALEKSANDROVA	{"phone": "+70303076271"}
0005435127368	AD69C4	6715 159607	DARYA ZHUKOVA	{"email": "zhukova.d_1964@postgrespro.ru", "phone": "+70182300983"}
0005435127369	107A7B	6252 111635	DMITRIY OSIPOV	{"phone": "+70778894003"}
0005435127370	5DF4CC	9101 929328	ELENA EGOROVA	{"phone": "+70440675909"}
0005435127371	A60D50	9037 060602	SERGEY GUSEV	{"email": "s-gusev.1982@postgrespro.ru", "phone": "+70771692623"}
0005435127372	A60D50	2094 773905	ALEKSANDR ILIN	{"email": "ailin_021972@postgrespro.ru", "phone": "+70940633703"}
0005435127373	4EDA4F	9812 728806	SERGEY KUZNECOV	{"phone": "+70877309934"}
0005435127374	4EDA4F	4164 382371	LYUCIYA IVANOVA	{"phone": "+70852168375"}
0005435127375	991DFA	7823 206817	TATYANA AKIMOVA	{"email": "tatyana_akimova24101978@postgrespro.ru", "phone": "+70772327708"}
0005435127376	0F280C	1050 560926	ELENA KUZNECOVA	{"phone": "+70115634035"}
0005435127377	CFEE84	1244 249867	YURIY EGOROV	{"phone": "+70982368790"}
0005435127378	A1FF6D	9859 231152	RUFINA KARPOVA	{"email": "rufina.karpova_1968@postgrespro.ru", "phone": "+70256479880"}
0005435127379	A1FF6D	8563 785966	KONSTANTIN MIRONOV	{"phone": "+70989258870"}
0005435127380	41BAF0	3955 197260	KIRILL OSIPOV	{"phone": "+70967863200"}
0005435127381	41BAF0	8579 417932	ALEKSANDR SOKOLOV	{"email": "aleksandr_sokolov22021970@postgrespro.ru", "phone": "+70430400668"}
0005435127382	C0E667	9721 852999	TATYANA KUZNECOVA	{"email": "kuznecova.t_081974@postgrespro.ru", "phone": "+70992931638"}
0005435127383	C0E667	0448 885246	EVGENIY VOROBEV	{"phone": "+70774097206"}
0005435127384	2720A4	6909 335249	ALEKSANDR SIDOROV	{"phone": "+70307134302"}
0005435127385	B910A8	9014 124291	DMITRIY FOMIN	{"email": "d.fomin.25051971@postgrespro.ru", "phone": "+70597938379"}
0005435127386	BD3C5E	4064 754867	VASILIY GUSEV	{"phone": "+70084024431"}
0005435127387	06E9FD	7282 714493	GALINA KULIKOVA	{"email": "galinakulikova.011964@postgrespro.ru", "phone": "+70732649562"}
0005435127388	06E9FD	6041 144101	LYUBOV FOMINA	{"phone": "+70879791046"}
0005435127389	ED8D5C	1505 356751	ELENA TIKHONOVA	{"phone": "+70092734761"}
0005435127390	A7D65D	7436 181872	ALEKSEY FEDOROV	{"phone": "+70065932132"}
0005435127391	A7D65D	9465 484513	SOFYA KOVALEVA	{"phone": "+70136404437"}
0005435127392	AADA9D	0128 089011	LYUDMILA AKIMOVA	{"email": "lyudmila-akimova18081977@postgrespro.ru", "phone": "+70918073851"}
0005435127393	574249	4457 743735	VIKTOR KAZAKOV	{"email": "viktor_kazakov.1972@postgrespro.ru", "phone": "+70616208353"}
0005435127394	511E5F	7822 721518	VLADISLAV IVANOV	{"phone": "+70700890901"}
0005435127395	511E5F	2076 873423	VYACHESLAV EGOROV	{"email": "vyacheslav.egorov.091981@postgrespro.ru", "phone": "+70332761740"}
0005435127396	DF6B2A	7078 043450	VALERIY MAKSIMOV	{"email": "maksimov-valeriy23061979@postgrespro.ru", "phone": "+70435163495"}
0005435127397	540061	5566 941920	SERGEY GUSEV	{"email": "gusev_s041969@postgrespro.ru", "phone": "+70731778279"}
0005435127398	C3A034	7643 615371	ALEKSEY GAVRILOV	{"phone": "+70901193924"}
0005435127399	55BA19	7404 325130	ARTEM SEMENOV	{"email": "a.semenov_21121969@postgrespro.ru", "phone": "+70382054042"}
0005435127400	E6BDC0	5016 154058	VASILIY ANDREEV	{"phone": "+70533888775"}
0005435127401	CD9160	9558 180321	VIKTORIYA LEBEDEVA	{"phone": "+70854096843"}
0005435127402	F12024	7477 786175	EVGENIY VOROBEV	{"phone": "+70964593563"}
0005435127403	E46F8F	0278 812159	ANATOLIY FROLOV	{"email": "frolovanatoliy021966@postgrespro.ru", "phone": "+70319388273"}
0005435127404	1DBD3C	3214 536956	SVETLANA EFIMOVA	{"phone": "+70846929739"}
0005435127405	2FE5C7	6618 363631	IGOR MAKSIMOV	{"email": "maksimov-igor_061970@postgrespro.ru", "phone": "+70790791725"}
0005435127406	56A2A7	8560 623929	ZHANNA KUZNECOVA	{"email": "kuznecova.zhanna-1972@postgrespro.ru", "phone": "+70238165695"}
0005435127467	C59DA5	4265 706895	VLADIMIR TARASOV	{"phone": "+70115426174"}
0005435127407	56A2A7	2111 469037	ROMAN VLASOV	{"email": "vlasov.roman-1964@postgrespro.ru", "phone": "+70809700279"}
0005435127408	4C29D0	4923 817744	VALENTINA NIKITINA	{"email": "nikitina.valentina.1972@postgrespro.ru", "phone": "+70969902625"}
0005435127409	5D4116	8735 179770	DMITRIY POPOV	{"email": "popovdmitriy091973@postgrespro.ru", "phone": "+70964162637"}
0005435127410	5D4116	4527 766505	VLADIMIR BELOV	{"email": "vladimir.belov-1972@postgrespro.ru", "phone": "+70277226811"}
0005435127411	94E2A9	2724 543747	KONSTANTIN VASILEV	{"email": "vasilevk.1968@postgrespro.ru", "phone": "+70671161218"}
0005435127412	3EDD7F	0506 590255	VLADIMIR ILIN	{"email": "vilin_111980@postgrespro.ru", "phone": "+70130176315"}
0005435127413	3EDD7F	4615 185671	YULIYA SAVELEVA	{"phone": "+70910551893"}
0005435127414	EE9455	7233 990964	ELENA GRISHINA	{"phone": "+70310684881"}
0005435127415	8228FB	5799 185838	DMITRIY KUZMIN	{"phone": "+70371894781"}
0005435127416	8228FB	3417 847044	LILIYA TIMOFEEVA	{"phone": "+70245847436"}
0005435127417	1B3E07	5038 146074	OLGA YAKOVLEVA	{"email": "yakovleva_olga-06101980@postgrespro.ru", "phone": "+70335649661"}
0005435127418	862479	1556 779600	ALEKSANDR POPOV	{"phone": "+70587689364"}
0005435127419	862479	0717 084727	IRINA VASILEVA	{"phone": "+70813385835"}
0005435127420	84A765	5405 079582	LEONID SERGEEV	{"email": "sergeev-l-061971@postgrespro.ru", "phone": "+70367208228"}
0005435127421	04C125	8325 177424	POLINA NESTEROVA	{"phone": "+70306198087"}
0005435127422	20A41F	9222 507437	MAKSIM ZAKHAROV	{"phone": "+70940964629"}
0005435127423	D93D5B	0865 509933	ALEKSEY MATVEEV	{"email": "amatveev-1962@postgrespro.ru", "phone": "+70025138721"}
0005435127424	9D352D	5861 485817	DANIIL FILIPPOV	{"email": "filippovdaniil.23021984@postgrespro.ru", "phone": "+70962758423"}
0005435127425	62C011	2141 248256	ALEKSEY MOROZOV	{"email": "alekseymorozov.09011961@postgrespro.ru", "phone": "+70167471045"}
0005435127426	94531D	3209 536206	NATALYA MAKAROVA	{"email": "natalya-makarova.041973@postgrespro.ru", "phone": "+70811898276"}
0005435127427	850D34	4805 458487	NADEZHDA SERGEEVA	{"phone": "+70448713234"}
0005435127428	4E3C9A	2311 303933	ANFISA EGOROVA	{"email": "egorova.anfisa20121966@postgrespro.ru", "phone": "+70111981215"}
0005435127429	1D4EDC	4316 727566	LYUBOV IVANOVA	{"phone": "+70859941254"}
0005435127430	1D4EDC	4590 854850	VASILIY FILIPPOV	{"email": "filippovv101966@postgrespro.ru", "phone": "+70650941482"}
0005435127431	38CBC6	7097 302328	ANDREY POPOV	{"phone": "+70875366767"}
0005435127432	D82748	0177 991603	KIRILL PETROV	{"email": "petrov_k_081962@postgrespro.ru", "phone": "+70340223332"}
0005435127433	67D326	9921 977329	NATALIYA FILIPPOVA	{"email": "n.filippova.1973@postgrespro.ru", "phone": "+70300542252"}
0005435127434	67D326	4596 219825	TATYANA MAKSIMOVA	{"email": "maksimova-tatyana-23031966@postgrespro.ru", "phone": "+70202901904"}
0005435127435	DCF5D0	0645 427924	VLADIMIR NAUMOV	{"email": "vladimirnaumov.12101969@postgrespro.ru", "phone": "+70430661218"}
0005435127436	DCF5D0	7936 478820	NIKOLAY ROMANOV	{"email": "romanovn1977@postgrespro.ru", "phone": "+70191293184"}
0005435127437	296E57	6069 711190	SERGEY MATVEEV	{"email": "s_matveev_021973@postgrespro.ru", "phone": "+70669438773"}
0005435127438	296E57	8882 404722	NADEZHDA ANDREEVA	{"email": "andreeva_n-061969@postgrespro.ru", "phone": "+70616269480"}
0005435127439	00101D	4809 072965	TATYANA BELOVA	{"phone": "+70466263301"}
0005435127440	00101D	9487 649938	ALEKSEY MAKAROV	{"phone": "+70612187734"}
0005435127441	A594B0	4422 896127	MARIYA STEPANOVA	{"phone": "+70383652515"}
0005435127442	A594B0	8120 175542	LYUBOV MOROZOVA	{"email": "morozova_l-19051966@postgrespro.ru", "phone": "+70838295675"}
0005435127443	E9D368	1882 291735	IRINA SEMENOVA	{"email": "semenova-irina.25111972@postgrespro.ru", "phone": "+70923121037"}
0005435127444	B50B75	5627 403569	VLADIMIR TARASOV	{"phone": "+70435647483"}
0005435127445	B50B75	4811 007227	ANASTASIYA KUZNECOVA	{"email": "kuznecova.anastasiya_16021969@postgrespro.ru", "phone": "+70678062732"}
0005435127446	71F764	4474 534295	DENIS POPOV	{"phone": "+70922730293"}
0005435127447	7F12C8	5038 390569	TATYANA FADEEVA	{"email": "fadeeva.t_28031979@postgrespro.ru", "phone": "+70440235546"}
0005435127448	7F12C8	3061 094869	SERGEY MOISEEV	{"email": "s-moiseev1964@postgrespro.ru", "phone": "+70195376672"}
0005435127449	316D64	1887 361192	OLEG ISAEV	{"email": "isaev.oleg081972@postgrespro.ru", "phone": "+70857841718"}
0005435127450	BADDA1	1335 107673	KAPITALINA NIKIFOROVA	{"phone": "+70643143553"}
0005435127451	BADDA1	4216 858754	ULYANA EFIMOVA	{"phone": "+70698272181"}
0005435127452	E5FE84	5326 151166	YULIYA KUZNECOVA	{"phone": "+70714269470"}
0005435127453	E5FE84	4353 647357	ELENA POLYAKOVA	{"phone": "+70515156197"}
0005435127454	E5FE84	2032 231045	SERGEY DAVYDOV	{"phone": "+70805208312"}
0005435127455	9DC3C9	2442 895994	ELENA NIKOLAEVA	{"email": "nikolaeva_elena.27041973@postgrespro.ru", "phone": "+70366506308"}
0005435127456	415886	8368 410216	NINA YAKOVLEVA	{"phone": "+70677998376"}
0005435127457	415886	8875 954519	ANASTASIYA ILINA	{"phone": "+70523039385"}
0005435127458	415886	8799 604509	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr_23061963@postgrespro.ru", "phone": "+70688265165"}
0005435127459	5418FE	3284 122527	ALEKSEY FEDOTOV	{"email": "alekseyfedotov_081963@postgrespro.ru", "phone": "+70232133322"}
0005435127460	59A376	3886 827209	ANDREY NIKOLAEV	{"phone": "+70789994455"}
0005435127461	59A376	3899 978374	IVAN KOZLOV	{"phone": "+70199485532"}
0005435127462	CF9C9F	1633 501337	VLADIMIR FILIPPOV	{"email": "vfilippov041973@postgrespro.ru", "phone": "+70013088372"}
0005435127463	721D08	1240 270162	ELENA KUZMINA	{"email": "kuzminaelena091969@postgrespro.ru", "phone": "+70055373543"}
0005435127464	1F8CA0	5010 577267	DANIIL VASILEV	{"email": "daniil-vasilev19021985@postgrespro.ru", "phone": "+70258835112"}
0005435127465	1F8CA0	4836 420993	SERGEY KUZNECOV	{"phone": "+70299379406"}
0005435127466	C59DA5	4022 292805	VASILIY BELOV	{"email": "v.belov1966@postgrespro.ru", "phone": "+70581714889"}
0005435127468	9F8424	7127 383986	OLGA GORBUNOVA	{"email": "gorbunova_o_21031975@postgrespro.ru", "phone": "+70567253389"}
0005435127469	00817F	8990 702733	OLGA VOLKOVA	{"phone": "+70162528056"}
0005435127470	8FF37C	0580 634106	GALINA MIRONOVA	{"email": "mironovagalina_15061982@postgrespro.ru", "phone": "+70900346710"}
0005435127471	C6F1D1	4029 255007	MARINA OSIPOVA	{"phone": "+70839044884"}
0005435127472	0FF86A	2443 758502	DIANA POLYAKOVA	{"email": "d-polyakova.1965@postgrespro.ru", "phone": "+70706874609"}
0005435127473	9A27A9	3120 961478	GAGIK STEPANOV	{"email": "gagik.stepanov_13051975@postgrespro.ru", "phone": "+70725056162"}
0005435127474	9A27A9	1418 828594	ANNA FILIPPOVA	{"email": "filippova-a13021971@postgrespro.ru", "phone": "+70582464808"}
0005435127475	C82044	3591 538760	ALEKSANDR VASILEV	{"phone": "+70226294080"}
0005435127476	C82044	8893 904747	ELENA YAKOVLEVA	{"email": "yakovlevaelena1971@postgrespro.ru", "phone": "+70434461213"}
0005435127477	C82044	7875 399701	VITALIY PETROV	{"email": "vitaliypetrov041968@postgrespro.ru", "phone": "+70548150154"}
0005435127478	D298B5	7381 317993	IVAN ZAKHAROV	{"email": "izakharov.1976@postgrespro.ru", "phone": "+70333124000"}
0005435127479	B0E3C3	4689 369809	VLADIMIR BORISOV	{"email": "borisovvladimir-031984@postgrespro.ru", "phone": "+70583082332"}
0005435127480	FE6D95	7331 761124	VERA GORBUNOVA	{"email": "gorbunova_v-021975@postgrespro.ru", "phone": "+70026367469"}
0005435127481	F5B38F	6676 079252	ALEKSANDR KAZAKOV	{"email": "a_kazakov_27051975@postgrespro.ru", "phone": "+70615749102"}
0005435127482	F5B38F	2037 832577	ALEKSEY SERGEEV	{"phone": "+70097388121"}
0005435127483	7BCCF1	3501 977322	IRINA SMIRNOVA	{"email": "smirnova_irina-091972@postgrespro.ru", "phone": "+70029580896"}
0005435127484	AB20EE	8571 616481	RAISA SOROKINA	{"email": "sorokina_r_1961@postgrespro.ru", "phone": "+70937280554"}
0005435127485	F7A035	4084 873267	VLADISLAV NAZAROV	{"email": "vnazarov-28091964@postgrespro.ru", "phone": "+70521917900"}
0005435127486	F7A035	2852 165368	NIKOLAY NOVIKOV	{"email": "novikov.n-10101965@postgrespro.ru", "phone": "+70306180761"}
0005435127487	58D5F8	9569 862795	ALEKSANDRA ANDREEVA	{"phone": "+70457924481"}
0005435127488	9636D4	4623 921528	ELENA ZOTOVA	{"phone": "+70203063041"}
0005435127489	E88CD0	9457 202105	OLGA KALININA	{"phone": "+70987897115"}
0005435127490	7F9BEC	5230 016163	VYACHESLAV BORISOV	{"phone": "+70352622458"}
0005435127491	E51616	3948 563982	OLGA OSIPOVA	{"phone": "+70573144259"}
0005435127492	E51616	7976 618387	EMIL NAUMOV	{"email": "naumovemil_021964@postgrespro.ru", "phone": "+70670042589"}
0005435127493	0200BD	1929 748948	OLESYA FOMINA	{"phone": "+70273854434"}
0005435127494	7EE1B8	7880 703359	SERGEY SEMENOV	{"email": "s_semenov11081968@postgrespro.ru", "phone": "+70694800951"}
0005435127495	7C6FC2	0793 237185	YULIYA DAVYDOVA	{"phone": "+70221195208"}
0005435127496	3AB4C6	4055 108964	DMITRIY KONOVALOV	{"email": "dkonovalov.111980@postgrespro.ru", "phone": "+70581205914"}
0005435127497	3AB4C6	6890 647439	ANDREY MAKSIMOV	{"phone": "+70168275541"}
0005435127498	3AB4C6	2439 880770	NATALYA STEPANOVA	{"email": "stepanova-natalya_121968@postgrespro.ru", "phone": "+70760655730"}
0005435127499	0892AA	2699 541115	MAKSIM SMIRNOV	{"phone": "+70241140291"}
0005435127500	0892AA	0812 799064	PETR SOLOVEV	{"email": "p-solovev1966@postgrespro.ru", "phone": "+70654423400"}
0005435127501	0892AA	1625 447040	NADEZHDA ANTONOVA	{"email": "nadezhda.antonova061969@postgrespro.ru", "phone": "+70560349275"}
0005435127502	B2DCDC	7975 583937	SVETLANA KOROLEVA	{"phone": "+70503653533"}
0005435127503	DC88C1	5662 151487	ZINAIDA KUDRYASHOVA	{"phone": "+70654464036"}
0005435127504	DC88C1	2568 387134	TATYANA TIMOFEEVA	{"email": "timofeeva-t-1959@postgrespro.ru", "phone": "+70155074213"}
0005435127505	765609	0124 578725	EVGENIY BORISOV	{"phone": "+70262621347"}
0005435127506	6E35F1	6983 347029	ALEKSEY TARASOV	{"email": "tarasovaleksey.01101968@postgrespro.ru", "phone": "+70883181163"}
0005435127507	6E35F1	9956 029856	VADIM TARASOV	{"phone": "+70095009838"}
0005435127508	D66708	1060 599614	IRINA VASILEVA	{"email": "irinavasileva.17091992@postgrespro.ru", "phone": "+70728159608"}
0005435127509	AF6FBB	7095 959516	TATYANA LUKYANOVA	{"phone": "+70221074640"}
0005435127510	41E70F	3761 076425	DANILA ALEKSANDROV	{"email": "aleksandrov-danila1968@postgrespro.ru", "phone": "+70777401832"}
0005435127511	41E70F	0719 055153	DMITRIY TIMOFEEV	{"phone": "+70727717679"}
0005435127512	261D2A	2873 838238	ALEKSANDR GRIGOREV	{"email": "grigorev_a.25051966@postgrespro.ru", "phone": "+70100165684"}
0005435127513	A96FCE	1955 785926	NINA SAVELEVA	{"email": "saveleva_nina-111975@postgrespro.ru", "phone": "+70892252185"}
0005435127514	A96FCE	4584 361933	VITALIY DENISOV	{"email": "denisov-vitaliy-10061963@postgrespro.ru", "phone": "+70073346609"}
0005435127515	317771	3524 015842	TATYANA KOVALEVA	{"phone": "+70828655621"}
0005435127516	12981A	0648 561332	NATALYA DENISOVA	{"email": "denisovan17111955@postgrespro.ru", "phone": "+70721486399"}
0005435127517	12981A	5905 675330	NIKOLAY KUZNECOV	{"phone": "+70201494380"}
0005435127518	67BA74	7572 794603	ARTUR SIDOROV	{"phone": "+70632532617"}
0005435127519	3063EA	8418 712008	LYUDMILA VASILEVA	{"phone": "+70712827522"}
0005435127520	9E54C1	3209 112390	VYACHESLAV STEPANOV	{"phone": "+70998943525"}
0005435127521	4CDF65	5260 974276	OLEG ANDREEV	{"phone": "+70930853707"}
0005435127522	4CDF65	0118 478874	EGOR ANDREEV	{"email": "egor.andreev_03021973@postgrespro.ru", "phone": "+70638353795"}
0005435127523	64A516	2301 341050	TATYANA KUDRYASHOVA	{"phone": "+70657713497"}
0005435127524	08E152	6518 141665	MARIYA BELOVA	{"phone": "+70413355967"}
0005435127525	70E5DD	3635 451928	GALIYA FOMINA	{"email": "fomina.g-031982@postgrespro.ru", "phone": "+70290227868"}
0005435127526	D9A67F	1983 025808	EKATERINA KUZMINA	{"phone": "+70776669117"}
0005435127527	D9A67F	7335 001889	VALERIY ROMANOV	{"phone": "+70558680089"}
0005435127528	BDDEF7	3374 409008	ANDREY PAVLOV	{"email": "pavlov_a_1972@postgrespro.ru", "phone": "+70251933403"}
0005435127529	BDDEF7	1053 725950	ALEKSANDR VOLKOV	{"email": "aleksandrvolkov031971@postgrespro.ru", "phone": "+70145449385"}
0005435127530	7FD5F9	8136 152752	NATALYA TIKHONOVA	{"phone": "+70571185468"}
0005435127531	EDC815	9031 722605	ANASTASIYA KUZNECOVA	{"email": "kuznecovaa-29111960@postgrespro.ru", "phone": "+70991101198"}
0005435127532	4288FE	1921 862052	ALEKSANDR SOLOVEV	{"email": "aleksandr_solovev.29041982@postgrespro.ru", "phone": "+70479334271"}
0005435127533	39617B	6437 641585	ALBERT ZAYCEV	{"phone": "+70730386615"}
0005435127534	EDC9B7	2737 067837	SERGEY FROLOV	{"email": "s-frolov1964@postgrespro.ru", "phone": "+70393233425"}
0005435127535	EDC9B7	6438 241282	VLADIMIR SIDOROV	{"email": "sidorov_v_29101973@postgrespro.ru", "phone": "+70438133128"}
0005435127536	E1023A	9260 617888	ARTEM NIKITIN	{"email": "artem-nikitin_1976@postgrespro.ru", "phone": "+70346336269"}
0005435127537	74BAA6	9782 695583	VIKTOR ISAEV	{"email": "isaev_viktor.011969@postgrespro.ru", "phone": "+70059427328"}
0005435127538	26AF65	3891 204822	TATYANA FILIPPOVA	{"email": "tatyana-filippova.1974@postgrespro.ru", "phone": "+70951639379"}
0005435127539	26AF65	9853 655697	POLINA POTAPOVA	{"email": "polinapotapova_1979@postgrespro.ru", "phone": "+70499770270"}
0005435127540	A6E3F1	2197 623849	ALEKSANDR SCHERBAKOV	{"email": "scherbakovaleksandr.12071971@postgrespro.ru", "phone": "+70239144776"}
0005435127541	A6E3F1	8015 823246	LYUBOV NAUMOVA	{"phone": "+70123291135"}
0005435127542	2E356C	4906 814094	ANDREY ABRAMOV	{"phone": "+70194781152"}
0005435127543	2E356C	3101 577884	PETR ALEKSANDROV	{"email": "aleksandrov_p.011963@postgrespro.ru", "phone": "+70921547393"}
0005435127544	2E356C	3094 902082	KONSTANTIN ORLOV	{"phone": "+70947535349"}
0005435127545	65F405	1702 970784	ARTUR POPOV	{"email": "a-popov.04111973@postgrespro.ru", "phone": "+70393931053"}
0005435127546	7ECD10	1875 489392	NADEZHDA LAZAREVA	{"email": "n-lazareva061977@postgrespro.ru", "phone": "+70726664542"}
0005435127547	8693FB	6359 507017	IRINA SOLOVEVA	{"email": "soloveva_i-25061976@postgrespro.ru", "phone": "+70330726839"}
0005435127548	FC7DCE	1934 254405	TATYANA PETROVA	{"email": "t.petrova1967@postgrespro.ru", "phone": "+70817924745"}
0005435127549	FC7DCE	0198 622351	TATYANA ZAKHAROVA	{"email": "t.zakharova.121975@postgrespro.ru", "phone": "+70860408218"}
0005435127550	FC7DCE	3993 239428	ZOYA NAUMOVA	{"phone": "+70872941353"}
0005435127551	6C6FE9	2402 446961	OKSANA KONOVALOVA	{"email": "konovalova-o10031975@postgrespro.ru", "phone": "+70400712811"}
0005435127552	ECD4F1	9642 690268	VALENTIN KUZNECOV	{"phone": "+70675930389"}
0005435127553	D9BF68	3604 966762	OLGA KOROLEVA	{"phone": "+70162809554"}
0005435127554	D9BF68	9177 090420	DANIL MOISEEV	{"phone": "+70243348107"}
0005435127555	6C9C2E	7534 884455	ROMAN NAZAROV	{"email": "roman.nazarov.1969@postgrespro.ru", "phone": "+70024539725"}
0005435127556	6C9C2E	3561 136943	GENNADIY DENISOV	{"phone": "+70045575505"}
0005435127557	3EB686	3213 105406	GULSHAT LUKYANOVA	{"email": "lukyanovag_031976@postgrespro.ru", "phone": "+70656241787"}
0005435127558	547788	4903 590343	ALEKSANDR RODIONOV	{"email": "rodionovaleksandr-17061970@postgrespro.ru", "phone": "+70781386199"}
0005435127559	CBE23C	2945 389337	VLADIMIR SMIRNOV	{"phone": "+70064229128"}
0005435127560	C1453B	5245 832372	EKATERINA SMIRNOVA	{"email": "ekaterina.smirnova_1964@postgrespro.ru", "phone": "+70161900038"}
0005435127561	65F7EB	9965 547935	ANDREY ILIN	{"email": "ilin.a1978@postgrespro.ru", "phone": "+70610702256"}
0005435127562	896F99	5861 450772	ELIZAVETA GUSEVA	{"phone": "+70923414581"}
0005435127563	896F99	2346 843807	LEV SAVELEV	{"phone": "+70996926225"}
0005435127564	DB310B	6261 434308	LYUDMILA KOMAROVA	{"phone": "+70172268384"}
0005435127565	DB28C4	7390 080343	NATALYA KULIKOVA	{"email": "kulikova_natalya_16081976@postgrespro.ru", "phone": "+70497275154"}
0005435127566	435357	8025 019678	SERGEY VOROBEV	{"email": "sergey-vorobev13091971@postgrespro.ru", "phone": "+70001569282"}
0005435127567	6E6167	8902 984404	YULIYA NIKOLAEVA	{"email": "nikolaeva.yuliya-02021966@postgrespro.ru", "phone": "+70801248588"}
0005435127568	5926C1	0215 431303	DMITRIY KUDRYASHOV	{"phone": "+70094074624"}
0005435127569	3577D2	5710 780354	ALEKSANDR FOMIN	{"email": "a-fomin.08091977@postgrespro.ru", "phone": "+70970232516"}
0005435127570	1D153A	9133 021871	ALEKSEY KUZNECOV	{"phone": "+70070971874"}
0005435127571	1D153A	7500 201050	TATYANA SIDOROVA	{"phone": "+70546041821"}
0005435127572	4B8A6E	6224 215224	VIKTOR KUZNECOV	{"email": "viktor.kuznecov.1961@postgrespro.ru", "phone": "+70402022952"}
0005435127573	4B8A6E	0979 736711	NATALYA GRISHINA	{"email": "grishina-natalya031969@postgrespro.ru", "phone": "+70189110310"}
0005435127574	F8A58F	4396 066800	VLADIMIR AFANASEV	{"phone": "+70134042124"}
0005435127575	352AAE	0567 473362	SVETLANA NIKOLAEVA	{"email": "svetlana-nikolaeva031975@postgrespro.ru", "phone": "+70418087176"}
0005435127576	352AAE	0918 231281	DMITRIY ABRAMOV	{"phone": "+70304671518"}
0005435127577	0064D1	9073 434423	VLADIMIR YAKOVLEV	{"email": "yakovlev-v_12051966@postgrespro.ru", "phone": "+70064630044"}
0005435127578	9AB20C	3267 250577	RUSLAN KRASNOV	{"email": "rkrasnov-1982@postgrespro.ru", "phone": "+70360911842"}
0005435127579	CE716A	2228 482951	YANA ANDREEVA	{"phone": "+70571607589"}
0005435127580	DB23D9	9691 736331	YULIYA IVANOVA	{"phone": "+70769672550"}
0005435127581	DB23D9	9102 094842	MARIYA KOROLEVA	{"email": "m_koroleva_07041976@postgrespro.ru", "phone": "+70892002119"}
0005435127582	1D7438	1012 833767	SERGEY POPOV	{"email": "sergey-popov_031973@postgrespro.ru", "phone": "+70392691246"}
0005435127583	6CDDA4	1294 703659	OLGA POPOVA	{"email": "popova_olga_1961@postgrespro.ru", "phone": "+70797623715"}
0005435127584	2035DF	0575 348112	LYUDMILA KARPOVA	{"email": "l_karpova.23041980@postgrespro.ru", "phone": "+70706585713"}
0005435127585	D3A09C	9152 135347	LEV KISELEV	{"email": "l_kiselev_1965@postgrespro.ru", "phone": "+70271659485"}
0005435127586	D3A09C	4267 677514	INNA ANDREEVA	{"phone": "+70617880788"}
0005435127587	7492A9	7287 265183	TATYANA MATVEEVA	{"email": "matveeva.tatyana.22091973@postgrespro.ru", "phone": "+70740528411"}
0005435127588	F5F4BC	2663 702280	VLADIMIR MATVEEV	{"phone": "+70931719221"}
0005435127589	87C2DB	0367 290250	NATALYA VLASOVA	{"phone": "+70231089340"}
0005435127590	87C2DB	0732 803213	SERGEY FROLOV	{"email": "s-frolov_101981@postgrespro.ru", "phone": "+70635239383"}
0005435132694	2A4E1D	5985 056535	DENIS MAKAROV	{"email": "makarov.d.1976@postgrespro.ru", "phone": "+70999671432"}
0005435132695	2A4E1D	9699 513897	SERGEY MEDVEDEV	{"email": "medvedevsergey13121969@postgrespro.ru", "phone": "+70878627060"}
0005435132696	7F14CE	9839 774209	SVETLANA POPOVA	{"phone": "+70982935052"}
0005435132697	7F14CE	1084 855497	VENIAMIN BONDARENKO	{"email": "veniamin.bondarenko-16021968@postgrespro.ru", "phone": "+70102530287"}
0005435132698	718435	2803 665708	MAKSIM KAZAKOV	{"email": "maksim-kazakov-1974@postgrespro.ru", "phone": "+70641706144"}
0005435132699	67D5F8	3625 062303	MAKSIM ZHUKOV	{"phone": "+70954645698"}
0005435132700	67D5F8	5997 185214	NINA SIDOROVA	{"phone": "+70308748921"}
0005435132701	0FE493	6304 572568	DENIS DENISOV	{"phone": "+70144168903"}
0005435132702	A75BAC	4223 033410	NATALYA KOROLEVA	{"phone": "+70711795294"}
0005435132703	A75BAC	5736 215161	VERA VOROBEVA	{"email": "vvorobeva_1978@postgrespro.ru", "phone": "+70999045352"}
0005435132704	A75BAC	0374 416272	ALENA FEDOROVA	{"phone": "+70168623709"}
0005435132705	6E35A6	2501 636535	SERGEY KOROLEV	{"email": "korolevsergey_12101977@postgrespro.ru", "phone": "+70515670880"}
0005435132706	931BCF	5888 600266	SVETLANA NAZAROVA	{"email": "nazarova.svetlana1968@postgrespro.ru", "phone": "+70312417868"}
0005435132707	41F376	0419 726861	NATALYA OSIPOVA	{"email": "osipova-natalya.071959@postgrespro.ru", "phone": "+70473152975"}
0005435132708	51CE24	7978 677659	VALENTINA LAZAREVA	{"email": "vlazareva-16121980@postgrespro.ru", "phone": "+70283178974"}
0005435132709	C5CB2B	2668 939719	ALEKSANDR ALEKSEEV	{"email": "aleksandralekseev081977@postgrespro.ru", "phone": "+70989676254"}
0005435132710	C5CB2B	4560 823405	ALEKSANDR VLASOV	{"email": "a.vlasov.1969@postgrespro.ru", "phone": "+70022136465"}
0005435132711	B2F515	3036 015195	VALENTINA KOROLEVA	{"email": "koroleva-v-23111974@postgrespro.ru", "phone": "+70130087290"}
0005435132712	B2F515	4505 518519	ANASTASIYA NOVIKOVA	{"phone": "+70628546020"}
0005435132713	4C4E11	4260 044789	ALEKSANDR MOISEEV	{"email": "a-moiseev_091972@postgrespro.ru", "phone": "+70871801359"}
0005435132714	5298B3	3715 820825	GRIGORIY KUZNECOV	{"phone": "+70309367978"}
0005435132715	BE4B3F	6436 347354	EVGENIYA DANILOVA	{"phone": "+70303694748"}
0005435132716	D93FED	5001 217310	ANNA KUZMINA	{"email": "kuzminaanna-021968@postgrespro.ru", "phone": "+70794458327"}
0005435132717	C6B39C	7274 129197	ALEKSEY SERGEEV	{"phone": "+70709356849"}
0005435132718	C6B39C	5492 024370	VLADIMIR FEDOTOV	{"phone": "+70300082838"}
0005435132719	8FD2C4	9181 462178	ELENA MELNIKOVA	{"phone": "+70729037859"}
0005435132720	A19DB9	6944 090062	ANDREY NIKOLAEV	{"email": "nikolaev.andrey23111965@postgrespro.ru", "phone": "+70657033858"}
0005435132721	BB7641	9825 009292	NATALYA ZAKHAROVA	{"email": "natalya.zakharova-121982@postgrespro.ru", "phone": "+70728143066"}
0005435132722	AC4C31	3902 660632	TATYANA ROMANOVA	{"email": "romanova.t011982@postgrespro.ru", "phone": "+70966498653"}
0005435132723	921F9F	1731 935114	TATYANA KOROLEVA	{"email": "tkoroleva_071973@postgrespro.ru", "phone": "+70957047010"}
0005435132724	921F9F	6507 134488	OLGA TROFIMOVA	{"email": "trofimova-o_061969@postgrespro.ru", "phone": "+70748237197"}
0005435132725	03EE5F	4693 390981	VLADIMIR SEMENOV	{"phone": "+70217323515"}
0005435132726	D1EE87	8552 156339	GALINA ZAKHAROVA	{"phone": "+70092706081"}
0005435132727	ED82CD	5409 680334	VLADIMIR MAKAROV	{"email": "v_makarov.19101975@postgrespro.ru", "phone": "+70890524328"}
0005435132728	ED82CD	5142 781138	DINARA EFIMOVA	{"email": "d-efimova18061979@postgrespro.ru", "phone": "+70880618835"}
0005435132729	55426A	0140 815891	ALEKSANDR MAKSIMOV	{"email": "maksimov_a-22081969@postgrespro.ru", "phone": "+70714329454"}
0005435132730	FAFB46	0700 259915	SERGEY NAUMOV	{"email": "naumov_s_1971@postgrespro.ru", "phone": "+70746983497"}
0005435132731	604CC3	8906 105599	IGOR BELOV	{"email": "igorbelov-071976@postgrespro.ru", "phone": "+70090387871"}
0005435132732	604CC3	6492 556192	DMITRIY SOKOLOV	{"phone": "+70792508673"}
0005435132733	C41F4E	4496 804119	YURIY SERGEEV	{"email": "y_sergeev_05041960@postgrespro.ru", "phone": "+70695254062"}
0005435132734	2E1FC2	4769 206895	MARINA DMITRIEVA	{"email": "mdmitrieva-18081985@postgrespro.ru", "phone": "+70306768630"}
0005435132735	2E1FC2	2601 253193	VLADIMIR BORISOV	{"phone": "+70451755094"}
0005435132736	822ADE	0072 869167	TATYANA NAZAROVA	{"email": "nazarova-t.011979@postgrespro.ru", "phone": "+70666722360"}
0005435132737	822ADE	9194 617199	VYACHESLAV BELOV	{"email": "vyacheslav.belov.1968@postgrespro.ru", "phone": "+70449726623"}
0005435132738	E94814	9578 870968	VALENTINA BELYAEVA	{"phone": "+70907489862"}
0005435132739	D33BA9	0298 339806	DARYA DANILOVA	{"email": "danilova-darya051986@postgrespro.ru", "phone": "+70693439811"}
0005435132740	0FDB10	0751 448510	IGNAT STEPANOV	{"phone": "+70212121930"}
0005435132741	30BCCC	2068 824894	NADEZHDA KUZNECOVA	{"email": "kuznecova-nadezhda_06111957@postgrespro.ru", "phone": "+70607446224"}
0005435132742	A33B5D	6770 987300	ALEKSANDR SMIRNOV	{"email": "a_smirnov-1967@postgrespro.ru", "phone": "+70339276517"}
0005435132743	A33B5D	6008 156173	VYACHESLAV KOZLOV	{"email": "kozlov-v.1967@postgrespro.ru", "phone": "+70715048217"}
0005435132744	00903C	8824 518387	VALENTINA MAKAROVA	{"phone": "+70374305085"}
0005435132745	00903C	2256 682400	ELIZAVETA RYABOVA	{"email": "ryabova.elizaveta-081965@postgrespro.ru", "phone": "+70705191589"}
0005435132746	A796DD	4637 310681	ALEKSANDR MOROZOV	{"phone": "+70414361079"}
0005435132747	A796DD	0859 828443	NADEZHDA KONOVALOVA	{"email": "konovalovanadezhda-18111976@postgrespro.ru", "phone": "+70304910642"}
0005435132748	31F99C	2004 688618	YULIYA LEBEDEVA	{"phone": "+70972372818"}
0005435132749	2D78C4	2606 294678	MIKHAIL MOISEEV	{"email": "m-moiseev-17061963@postgrespro.ru", "phone": "+70157860127"}
0005435132750	2D78C4	3861 390746	ALENA SERGEEVA	{"phone": "+70044722819"}
0005435132751	08910B	2100 704296	NATALYA MASLOVA	{"email": "n.maslova04011975@postgrespro.ru", "phone": "+70744393312"}
0005435132752	08910B	3704 269971	DMITRIY PETROV	{"phone": "+70190536284"}
0005435132753	74012C	8225 133016	EVGENIY MARTYNOV	{"phone": "+70076163135"}
0005435132754	551223	1169 077927	ALENA SOKOLOVA	{"email": "sokolova.alena-011978@postgrespro.ru", "phone": "+70928307519"}
0005435132755	1519E9	9695 321262	GALINA SIDOROVA	{"email": "sidorova.g051958@postgrespro.ru", "phone": "+70612907274"}
0005435132756	049E5D	8541 791841	NINA VOLKOVA	{"phone": "+70055892993"}
0005435132757	100D3E	1666 084313	SVETLANA SIDOROVA	{"phone": "+70530205315"}
0005435132758	0ADA80	8551 882995	VASILIY SOLOVEV	{"email": "vasiliy.solovev.111971@postgrespro.ru", "phone": "+70357118781"}
0005435132759	236E5C	1516 689882	ALEKSANDR KUDRYASHOV	{"phone": "+70676802665"}
0005435132760	FA790A	3603 014171	OLGA MATVEEVA	{"email": "olga-matveeva1982@postgrespro.ru", "phone": "+70053293804"}
0005435132761	7B7AAA	5574 051538	KSENIYA SAVELEVA	{"email": "k-saveleva-07111959@postgrespro.ru", "phone": "+70233148634"}
0005435132762	E11A70	6213 308711	SERGEY GORBUNOV	{"email": "sgorbunov-1974@postgrespro.ru", "phone": "+70948644251"}
0005435132763	CD164A	8623 059440	EKATERINA DENISOVA	{"email": "denisova-e.08111974@postgrespro.ru", "phone": "+70507371106"}
0005435132764	0F8A33	5498 330936	IRINA ZAKHAROVA	{"email": "i-zakharova-03081953@postgrespro.ru", "phone": "+70088980735"}
0005435132765	0F8A33	8631 374897	ANTONINA SOLOVEVA	{"phone": "+70853859821"}
0005435132766	1E1EDE	4227 618337	TATYANA MAKAROVA	{"email": "t.makarova.061977@postgrespro.ru", "phone": "+70410074241"}
0005435132767	8F03C7	1911 259811	SERGEY NAUMOV	{"phone": "+70191873483"}
0005435132768	8275B4	8043 399415	VYACHESLAV SOKOLOV	{"email": "vyacheslav-sokolov.111968@postgrespro.ru", "phone": "+70324954224"}
0005435132769	8275B4	5224 028782	SVETLANA MARTYNOVA	{"phone": "+70167347886"}
0005435132770	863A57	5968 952655	ALEKSEY CHERNOV	{"phone": "+70151552662"}
0005435132771	1C2D13	4926 859803	ALEKSANDR SMIRNOV	{"email": "aleksandr_smirnov-1973@postgrespro.ru", "phone": "+70395904469"}
0005435132772	1C2D13	4724 765215	NATALYA SCHERBAKOVA	{"email": "scherbakova_natalya_091972@postgrespro.ru", "phone": "+70013391416"}
0005435132773	843E14	2551 871313	LILIYA ABRAMOVA	{"email": "abramova.l.1975@postgrespro.ru", "phone": "+70878320357"}
0005435132774	843E14	2105 737746	LYUBOV ALEKSANDROVA	{"email": "aleksandrovalyubov1976@postgrespro.ru", "phone": "+70814176902"}
0005435132775	88690C	8814 201288	ALEKSANDR MOISEEV	{"email": "aleksandr.moiseev-1975@postgrespro.ru", "phone": "+70948024926"}
0005435132776	88690C	8038 298320	OLEG TARASOV	{"phone": "+70081554526"}
0005435132777	72A31B	3863 895184	VLADIMIR BELOV	{"email": "vladimir.belov.021985@postgrespro.ru", "phone": "+70286607245"}
0005435132778	070299	1699 430509	IGOR SHEVCHENKO	{"email": "shevchenkoigor.1975@postgrespro.ru", "phone": "+70606205019"}
0005435132779	8B689E	2035 719590	VIKTOR ALEKSEEV	{"phone": "+70338009655"}
0005435132780	27F200	5959 134708	ROMAN MELNIKOV	{"email": "r.melnikov.1975@postgrespro.ru", "phone": "+70582546935"}
0005435132781	8787AE	6202 375722	PAVEL ZAKHAROV	{"email": "pavel-zakharov-051974@postgrespro.ru", "phone": "+70502936791"}
0005435132782	8787AE	6033 652320	SERGEY TIKHONOV	{"phone": "+70054276397"}
0005435132783	67FB8E	7523 146108	YULIYA VLASOVA	{"email": "yuliya.vlasova1979@postgrespro.ru", "phone": "+70465504346"}
0005435132784	67FB8E	8841 743271	EVGENIY VOLKOV	{"email": "e-volkov.24111976@postgrespro.ru", "phone": "+70158635735"}
0005435132785	D48EDA	2532 916399	SERGEY NIKITIN	{"email": "sergey-nikitin_1977@postgrespro.ru", "phone": "+70784560443"}
0005435132786	D48EDA	7084 122872	GALINA PETROVA	{"email": "gpetrova.30121974@postgrespro.ru", "phone": "+70988458925"}
0005435132787	573734	4689 143315	EVDOKIYA KOMAROVA	{"phone": "+70898560273"}
0005435132788	9CC5E4	5901 310626	VADIM YAKOVLEV	{"phone": "+70038533274"}
0005435132789	1B2B73	2415 696736	VIKTORIYA KAZAKOVA	{"email": "viktoriyakazakova_081970@postgrespro.ru", "phone": "+70993677531"}
0005435132790	DB3077	7990 128716	ALEKSANDR TARASOV	{"phone": "+70500975077"}
0005435132791	DB3077	7717 853996	NATALYA OSIPOVA	{"email": "natalya_osipova-15051972@postgrespro.ru", "phone": "+70543126075"}
0005435132792	5E8CF5	0790 950734	VALENTINA ZAKHAROVA	{"phone": "+70222621172"}
0005435132793	38EAFC	7462 635668	DARYA ZAYCEVA	{"phone": "+70564822237"}
0005435132794	769763	8795 016174	ALEKSANDR TIMOFEEV	{"phone": "+70121843510"}
0005435132795	678801	2851 031122	NATALYA KONDRATEVA	{"email": "n_kondrateva021976@postgrespro.ru", "phone": "+70959982372"}
0005435132796	678801	2385 136056	VALENTINA ARKHIPOVA	{"phone": "+70529494579"}
0005435132797	678801	3495 574771	VALENTINA CHERNOVA	{"email": "chernova-valentina-19021979@postgrespro.ru", "phone": "+70558542110"}
0005435132798	25014B	4029 738288	VERONIKA NIKITINA	{"email": "veronika.nikitina.22071978@postgrespro.ru", "phone": "+70673089639"}
0005435132799	25014B	0240 319798	ANNA BOGDANOVA	{"email": "bogdanovaa111974@postgrespro.ru", "phone": "+70970695261"}
0005435132800	10CAC4	3820 740898	KONSTANTIN KARPOV	{"phone": "+70338188724"}
0005435132801	9B82F3	8159 176947	ILYA TARASOV	{"email": "ilya.tarasov_08011970@postgrespro.ru", "phone": "+70784281365"}
0005435132802	0E376C	0980 015211	EKATERINA ANDREEVA	{"email": "andreeva-ekaterina1973@postgrespro.ru", "phone": "+70195765366"}
0005435132803	C4601F	7577 133932	RIMMA MOROZOVA	{"email": "morozova-r21061983@postgrespro.ru", "phone": "+70122113197"}
0005435132804	AA1E32	8474 520298	NIKOLAY ZAKHAROV	{"email": "n.zakharov011984@postgrespro.ru", "phone": "+70567698873"}
0005435132805	CC147C	6888 362104	RUSTYAM CHERNOV	{"email": "rustyam-chernov_1962@postgrespro.ru", "phone": "+70601259380"}
0005435132806	9E5EA4	5336 676669	ALEKSEY SEMENOV	{"phone": "+70822624338"}
0005435132807	8DE860	0361 407963	SVETLANA NOVIKOVA	{"phone": "+70545469012"}
0005435132808	8DE860	1540 168405	NIKITA DAVYDOV	{"email": "n_davydov_06111982@postgrespro.ru", "phone": "+70935696676"}
0005435132809	392B94	1143 110129	KONSTANTIN MARTYNOV	{"email": "martynov-konstantin.1986@postgrespro.ru", "phone": "+70622814302"}
0005435132810	189952	8380 808867	NINA STEPANOVA	{"email": "nina-stepanova091967@postgrespro.ru", "phone": "+70056047649"}
0005435132811	6426B2	8941 641143	TATYANA KOZLOVA	{"phone": "+70671053548"}
0005435132812	89139F	9485 392215	DMITRIY KISELEV	{"phone": "+70906904469"}
0005435132813	7C6C2D	9106 497625	MIKHAIL KONOVALOV	{"email": "m-konovalov-051971@postgrespro.ru", "phone": "+70861784023"}
0005435132814	7C6C2D	0316 025290	IGOR PETROV	{"email": "petrov-igor-1971@postgrespro.ru", "phone": "+70408675761"}
0005435132815	7C6C2D	4466 942509	SEMEN ABRAMOV	{"phone": "+70039250852"}
0005435132816	7D7AA7	9080 922052	ANDREY SMIRNOV	{"phone": "+70359945261"}
0005435132817	28161C	2848 833398	NATALYA KOROLEVA	{"phone": "+70660635661"}
0005435132818	28161C	1311 784062	YULIYA MOISEEVA	{"email": "moiseeva-yuliya.051958@postgrespro.ru", "phone": "+70334085586"}
0005435132819	28161C	0559 773196	IRAIDA FROLOVA	{"email": "i-frolova03091983@postgrespro.ru", "phone": "+70598252616"}
0005435132820	080BBD	0880 751763	DINA NIKITINA	{"phone": "+70623711305"}
0005435132821	178E3F	5551 440045	ALEKSANDR NIKOLAEV	{"phone": "+70150297258"}
0005435132822	535767	2413 244479	OLEG PAVLOV	{"phone": "+70537481414"}
0005435132823	E5058C	6138 516101	ALEKSANDR VOROBEV	{"email": "vorobeva-091966@postgrespro.ru", "phone": "+70425443931"}
0005435132824	E5058C	2722 845899	ALEKSANDR VOROBEV	{"phone": "+70951892617"}
0005435132825	7F10FA	8365 467101	LIDIYA NOVIKOVA	{"email": "novikova.lidiya.091972@postgrespro.ru", "phone": "+70718297282"}
0005435132826	17CABE	6494 411838	DANIIL BELOV	{"phone": "+70130575459"}
0005435132827	17CABE	6325 394807	ALEKSANDR ISAEV	{"email": "a-isaev041980@postgrespro.ru", "phone": "+70647507120"}
0005435132828	473574	6314 493143	TAISIYA NAZAROVA	{"phone": "+70039887718"}
0005435132829	473574	7636 842780	ANDREY KULIKOV	{"email": "kulikov.andrey_15101964@postgrespro.ru", "phone": "+70038790360"}
0005435132830	473574	9703 860136	OLGA MAKAROVA	{"email": "makarova.olga.01011971@postgrespro.ru", "phone": "+70333408653"}
0005435132831	22B826	5015 445367	IGOR BORISOV	{"email": "borisov-i-121972@postgrespro.ru", "phone": "+70650898634"}
0005435132832	782DF6	8922 009126	KRISTINA KALININA	{"email": "kkalinina1967@postgrespro.ru", "phone": "+70631130090"}
0005435132833	782DF6	4352 320719	NADEZHDA IVANOVA	{"email": "n_ivanova.01071976@postgrespro.ru", "phone": "+70309472639"}
0005435132834	75435C	3035 193963	ANNA MARTYNOVA	{"email": "a.martynova1964@postgrespro.ru", "phone": "+70301632412"}
0005435132835	599A5C	7151 905313	POLINA ANDREEVA	{"phone": "+70474477973"}
0005435132836	97E8E2	1653 510804	MIKHAIL BONDARENKO	{"email": "m.bondarenko_121963@postgrespro.ru", "phone": "+70246789486"}
0005435132837	97E8E2	8925 206794	ANDREY SERGEEV	{"email": "andrey_sergeev1980@postgrespro.ru", "phone": "+70725250725"}
0005435132838	928179	1481 194877	ANDREY MELNIKOV	{"email": "a.melnikov.1962@postgrespro.ru", "phone": "+70027984199"}
0005435132839	BA1682	3836 708719	SVETLANA PAVLOVA	{"phone": "+70814393001"}
0005435132840	AE7AB4	7686 817006	ELIZAVETA MOROZOVA	{"email": "morozova.elizaveta_111975@postgrespro.ru", "phone": "+70900611005"}
0005435132841	69D8FE	7339 048375	SERGEY MELNIKOV	{"email": "s_melnikov1982@postgrespro.ru", "phone": "+70809760336"}
0005435132842	69D8FE	2658 456085	STANISLAV GERASIMOV	{"email": "stanislav.gerasimov_021972@postgrespro.ru", "phone": "+70680019685"}
0005435132843	E8DA38	8507 021385	VYACHESLAV MAKAROV	{"email": "v_makarov_1963@postgrespro.ru", "phone": "+70281017268"}
0005435132844	A5A4F8	5402 091902	EVGENIY ALEKSEEV	{"email": "alekseev-evgeniy-011981@postgrespro.ru", "phone": "+70822176753"}
0005435132845	6BBD50	1323 029650	ALEKSANDRA KALININA	{"email": "kalinina.aleksandra1975@postgrespro.ru", "phone": "+70175564031"}
0005435132846	2E4A5D	6328 756406	ANATOLIY ANTONOV	{"phone": "+70212293154"}
0005435132847	2E4A5D	8719 878534	IRINA LUKYANOVA	{"phone": "+70571221482"}
0005435132848	1CEEE5	6561 717051	BOGDAN BARANOV	{"email": "baranovb061973@postgrespro.ru", "phone": "+70523173284"}
0005435132849	1CEEE5	6585 750159	LYUDMILA DENISOVA	{"phone": "+70458538246"}
0005435132850	FF50E5	2605 988944	NIKOLAY GERASIMOV	{"email": "gerasimov.nikolay_09061979@postgrespro.ru", "phone": "+70045734283"}
0005435132851	FF50E5	2530 764231	RAVIL MELNIKOV	{"phone": "+70639536644"}
0005435132852	403D67	2918 533206	NINA IVANOVA	{"email": "n_ivanova.031977@postgrespro.ru", "phone": "+70882534398"}
0005435132853	403D67	0029 039458	ZULFIYA ZOTOVA	{"email": "zotova-z.051987@postgrespro.ru", "phone": "+70305717265"}
0005435132854	55BF43	2264 912402	IVAN IVANOV	{"phone": "+70623031624"}
0005435132855	E15041	2658 052417	IRINA KOLESNIKOVA	{"phone": "+70977546164"}
0005435132856	C38CEE	0730 533695	YULIYA KULIKOVA	{"email": "kulikova.yuliya.1990@postgrespro.ru", "phone": "+70968450491"}
0005435132857	C38CEE	1031 570056	TAMARA ROMANOVA	{"email": "romanova_t_25031969@postgrespro.ru", "phone": "+70154365449"}
0005435132858	55F122	1249 432705	ALEKSANDR GUSEV	{"email": "gusev.a.1970@postgrespro.ru", "phone": "+70359531315"}
0005435132859	BA7748	5602 687098	IVAN ZHURAVLEV	{"email": "ivan-zhuravlev-12021965@postgrespro.ru", "phone": "+70585873260"}
0005435132860	BA7748	0483 793931	DARYA AKIMOVA	{"phone": "+70666173148"}
0005435132861	695543	1032 985226	DMITRIY ABRAMOV	{"email": "d-abramov16011968@postgrespro.ru", "phone": "+70097268540"}
0005435132862	485D39	0288 083293	MARIYA POPOVA	{"phone": "+70699009515"}
0005435132863	485D39	3289 297981	SERGEY MOROZOV	{"phone": "+70038181074"}
0005435132864	FCF72C	8532 848152	YURIY KUZNECOV	{"email": "kuznecovyuriy_081976@postgrespro.ru", "phone": "+70417258610"}
0005435132865	AC69E1	1166 799067	YURIY GORBUNOV	{"email": "ygorbunov-1966@postgrespro.ru", "phone": "+70090111866"}
0005435132866	AC69E1	6350 880765	LYUBOV KOZLOVA	{"email": "lyubov.kozlova_1983@postgrespro.ru", "phone": "+70942012577"}
0005435132867	E7AE99	0051 742794	SERGEY GERASIMOV	{"phone": "+70699342617"}
0005435132868	F8FE2C	0596 986038	YURIY MOROZOV	{"email": "morozov.y.111976@postgrespro.ru", "phone": "+70196886742"}
0005435132869	6302EB	2742 538336	DARYA FILIPPOVA	{"email": "filippova_darya-071975@postgrespro.ru", "phone": "+70339355425"}
0005435132870	DCB0A2	9539 764583	PAVEL ABRAMOV	{"phone": "+70704889233"}
0005435132871	83ADE2	8721 335630	ZOYA KUZNECOVA	{"email": "kuznecova.z1964@postgrespro.ru", "phone": "+70111282643"}
0005435132872	1A5588	6851 419648	IGOR PETROV	{"email": "igor-petrov04121964@postgrespro.ru", "phone": "+70427851971"}
0005435132873	949F0E	5884 099965	SERGEY GAVRILOV	{"phone": "+70727295132"}
0005435132874	3A3382	6385 466192	NINA LEBEDEVA	{"phone": "+70683615434"}
0005435132875	9C5791	9866 278628	ELENA OVCHINNIKOVA	{"email": "e_ovchinnikova-1973@postgrespro.ru", "phone": "+70143937748"}
0005435132876	9C5791	2634 127228	OLGA ZAYCEVA	{"phone": "+70760511235"}
0005435132877	3BDC3D	0723 002764	VASILIY ISAEV	{"email": "vasiliyisaev-05061982@postgrespro.ru", "phone": "+70933757983"}
0005435132878	0BC585	6644 789118	NINA IVANOVA	{"phone": "+70203317795"}
0005435132879	0B32CE	0531 569584	ANASTASIYA VOLKOVA	{"email": "volkova.a.1966@postgrespro.ru", "phone": "+70391531702"}
0005435132880	DF8F40	5258 713938	ALEKSANDR ALEKSANDROV	{"email": "aleksandrov_aleksandr21011963@postgrespro.ru", "phone": "+70733165461"}
0005435132881	210D54	2899 597701	ILDUS VLASOV	{"phone": "+70544078489"}
0005435132882	63F76F	7218 290803	MIKHAIL IVANOV	{"phone": "+70725366866"}
0005435132883	B66D3B	6574 805195	IGOR ANDREEV	{"email": "andreev_igor_051981@postgrespro.ru", "phone": "+70116756547"}
0005435132884	65E910	2982 603609	OLGA ISAEVA	{"phone": "+70982239141"}
0005435132885	964E72	6446 430237	TATYANA NOVIKOVA	{"email": "tatyana-novikova-12101965@postgrespro.ru", "phone": "+70667935405"}
0005435132886	88CAF9	2093 549109	ALEKSANDR ALEKSEEV	{"phone": "+70544681708"}
0005435132887	5F6AD8	4679 447747	VLADIMIR VLASOV	{"email": "vladimirvlasov.1983@postgrespro.ru", "phone": "+70220527123"}
0005435132888	5F6AD8	9328 613810	LYUDMILA GUSEVA	{"email": "lyudmila-guseva_30111958@postgrespro.ru", "phone": "+70140962894"}
0005435132889	A5B2F4	7099 263601	DMITRIY FEDOROV	{"email": "fedorovd.081974@postgrespro.ru", "phone": "+70146666991"}
0005435132890	A5B2F4	3722 673567	NINA ISAEVA	{"phone": "+70746030838"}
0005435132891	E0F415	3232 323662	NINA BOGDANOVA	{"email": "bogdanova_nina-111972@postgrespro.ru", "phone": "+70620306430"}
0005435132892	E0F415	5721 021618	NATALYA IVANOVA	{"email": "ivanova-natalya.071967@postgrespro.ru", "phone": "+70645382680"}
0005435132893	ED51F7	7879 588072	DMITRIY GUSEV	{"phone": "+70210845925"}
0005435132894	ED51F7	9585 999660	MARINA ALEKSANDROVA	{"phone": "+70631183271"}
0005435132895	2019E9	3221 663314	EKATERINA GRISHINA	{"phone": "+70208586193"}
0005435132896	2019E9	0227 554891	ANDREY DENISOV	{"email": "a_denisov_111967@postgrespro.ru", "phone": "+70673708884"}
0005435132897	CD6CF6	9181 544751	DMITRIY NIKITIN	{"email": "nikitin-dmitriy_101972@postgrespro.ru", "phone": "+70142490749"}
0005435132898	CD6CF6	6627 089984	PETR GORBUNOV	{"phone": "+70068214744"}
0005435132899	7C92DB	3469 566557	DARYA VASILEVA	{"email": "vasileva-d-08051971@postgrespro.ru", "phone": "+70958233601"}
0005435132900	BB4763	0568 051254	EVDOKIYA SAVELEVA	{"phone": "+70416254330"}
0005435132901	3F7AB0	5586 323720	ILGIZ KISELEV	{"phone": "+70978022352"}
0005435132902	3F7AB0	5613 032858	VLADIMIR VASILEV	{"email": "vasilev-v_011974@postgrespro.ru", "phone": "+70327222465"}
0005435132903	3F7AB0	1269 024545	KSENIYA ZAKHAROVA	{"phone": "+70156071714"}
0005435132904	F05773	8741 225725	ANNA VOROBEVA	{"phone": "+70693557388"}
0005435132905	F05773	3329 127989	MARIYA YUDINA	{"email": "yudinam-051966@postgrespro.ru", "phone": "+70715578074"}
0005435132906	F05773	2614 021384	DMITRIY POPOV	{"email": "popovd_061966@postgrespro.ru", "phone": "+70915734840"}
0005435132907	62950D	1117 425230	ALEVTINA SIDOROVA	{"phone": "+70097844144"}
0005435132908	3C7D51	6733 124428	SERGEY EGOROV	{"phone": "+70583138989"}
0005435132909	DA1AF6	7764 062780	OLGA ARKHIPOVA	{"email": "o_arkhipova-09071976@postgrespro.ru", "phone": "+70594907098"}
0005435132910	8143D4	7252 001948	OLEG VLASOV	{"email": "vlasov-o.041974@postgrespro.ru", "phone": "+70681262699"}
0005435132911	4D2822	4464 765103	ALEKSEY ANDREEV	{"email": "aleksey.andreev1976@postgrespro.ru", "phone": "+70057276132"}
0005435132912	4CAEA9	8057 441807	NIKOLAY SMIRNOV	{"phone": "+70713621541"}
0005435132913	4CAEA9	1369 667048	TATYANA NESTEROVA	{"phone": "+70672113579"}
0005435132914	99C6F1	5859 136690	MARINA NAZAROVA	{"email": "m.nazarova.14071970@postgrespro.ru", "phone": "+70035461535"}
0005435132915	C5EA77	3945 144077	LYUBOV FROLOVA	{"email": "frolova.l.31081969@postgrespro.ru", "phone": "+70214867947"}
0005435132916	5C739B	4900 113484	VLADIMIR KOZLOV	{"email": "kozlov-v_18041970@postgrespro.ru", "phone": "+70067060869"}
0005435132917	8F172C	8032 477551	VALENTINA GAVRILOVA	{"email": "gavrilova.valentina1972@postgrespro.ru", "phone": "+70089709563"}
0005435132918	654123	9186 815651	DMITRIY PAVLOV	{"email": "d-pavlov17021969@postgrespro.ru", "phone": "+70500989564"}
0005435132919	654123	6627 130788	MARGARITA NESTEROVA	{"phone": "+70019089321"}
0005435132920	858972	8404 706453	MIKHAIL RODIONOV	{"phone": "+70912935259"}
0005435133041	53B8BF	9919 013778	VALERIY MAKAROV	{"phone": "+70100465260"}
0005435132921	858972	5673 846693	LYUDMILA KONDRATEVA	{"email": "kondrateva_l.17071974@postgrespro.ru", "phone": "+70020086390"}
0005435132922	C49A49	0940 610351	ALEKSEY MOISEEV	{"email": "moiseev.aleksey_11071969@postgrespro.ru", "phone": "+70719628008"}
0005435132923	7EA85F	2517 026599	GALINA SOLOVEVA	{"email": "solovevag1971@postgrespro.ru", "phone": "+70456418028"}
0005435132924	95F984	5749 851680	VIKTOR FEDOROV	{"email": "v-fedorov_22111968@postgrespro.ru", "phone": "+70752333170"}
0005435132925	CF02A5	1225 188544	EDUARD KONOVALOV	{"email": "konovalov.e_101977@postgrespro.ru", "phone": "+70391973960"}
0005435132926	CF02A5	6146 245997	LYUDMILA KONDRATEVA	{"phone": "+70926276044"}
0005435132927	90D973	8464 893173	ALINA VOLKOVA	{"email": "alinavolkova-02081966@postgrespro.ru", "phone": "+70636466006"}
0005435132928	437942	7915 281895	OLGA NESTEROVA	{"email": "nesterova-o.1979@postgrespro.ru", "phone": "+70034682418"}
0005435132929	B528EF	5118 411795	OKSANA EGOROVA	{"email": "egorova_o021961@postgrespro.ru", "phone": "+70629276069"}
0005435132930	669145	3187 099737	LYUDMILA ZAKHAROVA	{"email": "zakharova_l.16041983@postgrespro.ru", "phone": "+70869856370"}
0005435132931	EBE39F	9563 851644	VIKTOR TIMOFEEV	{"phone": "+70331480187"}
0005435132932	8346CF	3633 816803	TATYANA SEMENOVA	{"email": "tsemenova1967@postgrespro.ru", "phone": "+70807239470"}
0005435132933	04D956	5336 000546	ANDREY NIKOLAEV	{"phone": "+70486048774"}
0005435132934	04D956	4588 096427	ANNA MARTYNOVA	{"email": "martynova_a091975@postgrespro.ru", "phone": "+70839015785"}
0005435132935	04D956	4538 930409	LILIYA KOROLEVA	{"phone": "+70179377146"}
0005435132936	4662BD	7571 521898	VALENTINA KAZAKOVA	{"phone": "+70242959893"}
0005435132937	4662BD	2831 072973	MARIYA STEPANOVA	{"email": "stepanovamariya_021971@postgrespro.ru", "phone": "+70351732862"}
0005435132938	D58A39	9863 158375	TATYANA MOROZOVA	{"email": "t_morozova_1963@postgrespro.ru", "phone": "+70864150075"}
0005435132939	04219C	7440 483497	EVGENIYA STEPANOVA	{"email": "e_stepanova1974@postgrespro.ru", "phone": "+70444761571"}
0005435132940	1CBCC4	8630 090482	LILIYA ILINA	{"phone": "+70109846004"}
0005435132941	1CBCC4	8784 450790	NATALYA ROMANOVA	{"phone": "+70770770947"}
0005435132942	1A3226	2787 400537	TATYANA TIKHONOVA	{"phone": "+70650095134"}
0005435132943	4FBD7F	0747 559234	VALENTIN SOLOVEV	{"phone": "+70962528021"}
0005435132944	F9A260	2527 773337	ELENA SEMENOVA	{"email": "elenasemenova_17011964@postgrespro.ru", "phone": "+70257950730"}
0005435132945	C3C9E5	5947 156717	NINA FOMINA	{"email": "nina.fomina.081966@postgrespro.ru", "phone": "+70084287514"}
0005435132946	2AF318	4475 508550	ALEKSANDR TIKHONOV	{"phone": "+70373727982"}
0005435132947	C34755	4988 700415	VLADIMIR ANTONOV	{"email": "vladimir_antonov23041980@postgrespro.ru", "phone": "+70271285819"}
0005435132948	099C75	6963 088584	GENNADIY NAZAROV	{"phone": "+70573746769"}
0005435132949	4E9362	3427 697014	YURIY IVANOV	{"email": "ivanov_yuriy_09031976@postgrespro.ru", "phone": "+70890419114"}
0005435132950	80C2A3	3049 567026	LYUBOV KUZNECOVA	{"phone": "+70051917675"}
0005435132951	234DCE	6913 783414	MIKHAIL GRIGOREV	{"phone": "+70094885106"}
0005435132952	234DCE	3693 851333	ILNUR NAUMOV	{"phone": "+70489344051"}
0005435132953	6590FF	2270 397394	TATYANA ILINA	{"email": "ilinatatyana_1964@postgrespro.ru", "phone": "+70941354285"}
0005435132954	BE7D03	4991 529674	ALEKSEY KOROLEV	{"phone": "+70724826020"}
0005435132955	BE7D03	9080 525818	ELENA VASILEVA	{"phone": "+70323057511"}
0005435132956	BAB43B	7579 858950	MARIYA VASILEVA	{"email": "vasilevamariya08031974@postgrespro.ru", "phone": "+70809048375"}
0005435132957	736A54	5756 443655	DMITRIY MOISEEV	{"email": "dmitriy_moiseev_29101978@postgrespro.ru", "phone": "+70145421377"}
0005435132958	736A54	1377 025626	OLESYA MARTYNOVA	{"email": "o_martynova.031963@postgrespro.ru", "phone": "+70794113926"}
0005435132959	736A54	9742 624368	OKSANA BELOVA	{"email": "belova.oksana061970@postgrespro.ru", "phone": "+70728209024"}
0005435132960	614225	5995 783133	ANGELINA CHERNOVA	{"phone": "+70592128864"}
0005435132961	614225	6985 260222	ELENA FILIPPOVA	{"phone": "+70721152080"}
0005435132962	B95424	6155 061890	YULIYA FADEEVA	{"email": "y.fadeeva.041979@postgrespro.ru", "phone": "+70571842332"}
0005435132963	B95424	4946 379982	MARIYA SOLOVEVA	{"email": "soloveva-m_1981@postgrespro.ru", "phone": "+70039865234"}
0005435132964	0A015C	9877 921828	VLADIMIR KRASNOV	{"email": "krasnov.vladimir-19071973@postgrespro.ru", "phone": "+70973989167"}
0005435132965	52732C	9830 707129	NADEZHDA NIKIFOROVA	{"phone": "+70593472756"}
0005435132966	52732C	3716 505943	NATALYA NIKITINA	{"phone": "+70593518848"}
0005435132967	6DBAEF	3465 160249	IRINA KULIKOVA	{"email": "i.kulikova-081980@postgrespro.ru", "phone": "+70325150316"}
0005435132968	B42BCE	1277 014805	YULIYA RYABOVA	{"email": "ryabova.yuliya.1975@postgrespro.ru", "phone": "+70760065531"}
0005435132969	B42BCE	0383 342224	VLADIMIR ZAYCEV	{"email": "zaycev_vladimir16031969@postgrespro.ru", "phone": "+70990607516"}
0005435132970	1140B6	9934 139221	ARTEM IVANOV	{"email": "ivanov-a01041975@postgrespro.ru", "phone": "+70019992656"}
0005435132971	80A3E0	6214 158828	GENNADIY OSIPOV	{"phone": "+70540399701"}
0005435132972	492032	2701 149948	ANTONINA KOVALEVA	{"phone": "+70132116812"}
0005435132973	40C0AB	0800 393230	OLGA FADEEVA	{"email": "olga-fadeeva_031977@postgrespro.ru", "phone": "+70841738968"}
0005435132974	CFE4EB	5058 081351	NIKOLAY MIRONOV	{"phone": "+70867960172"}
0005435132975	CFE4EB	1967 966181	NADEZHDA LOGINOVA	{"email": "loginova.nadezhda15111977@postgrespro.ru", "phone": "+70639410550"}
0005435132976	1E908E	2265 074440	EVGENIYA IVANOVA	{"email": "ivanova.evgeniya-1961@postgrespro.ru", "phone": "+70427373182"}
0005435132977	1E908E	1282 355383	LYUDMILA MARTYNOVA	{"email": "lyudmila_martynova_1972@postgrespro.ru", "phone": "+70151810833"}
0005435132978	FE3E18	6622 010877	NIKOLAY MIKHAYLOV	{"phone": "+70608776168"}
0005435132979	2665D9	0230 521693	DMITRIY MELNIKOV	{"phone": "+70337457080"}
0005435132980	2665D9	4714 118257	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr.1977@postgrespro.ru", "phone": "+70438975860"}
0005435132981	956141	1244 291951	ANDREY SOKOLOV	{"phone": "+70811346999"}
0005435132982	956141	8705 205188	VLADIMIR SIDOROV	{"email": "sidorov-vladimir06111974@postgrespro.ru", "phone": "+70640342872"}
0005435132983	964206	2338 890889	MAKSIM SMIRNOV	{"phone": "+70399583897"}
0005435132984	B409C2	6600 902598	OLGA MAKAROVA	{"email": "omakarova-15101969@postgrespro.ru", "phone": "+70388286885"}
0005435132985	659BFE	4317 404439	GRIGORIY VASILEV	{"phone": "+70898326762"}
0005435132986	984680	5476 594443	ALEKSANDR MOROZOV	{"phone": "+70709855457"}
0005435132987	8AE0EA	5750 997963	OLGA KUZNECOVA	{"email": "kuznecova-o121972@postgrespro.ru", "phone": "+70045205489"}
0005435132988	8AE0EA	9930 460941	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikovasvetlana_051961@postgrespro.ru", "phone": "+70753958801"}
0005435132989	AED357	5107 378911	IRINA SOROKINA	{"email": "irina.sorokina-081977@postgrespro.ru", "phone": "+70502645110"}
0005435132990	AED357	2463 311948	VLADIMIR ABRAMOV	{"email": "abramovvladimir-091980@postgrespro.ru", "phone": "+70308623874"}
0005435132991	AED357	8032 780107	ALEKSANDR ALEKSEEV	{"phone": "+70264037296"}
0005435132992	805363	5175 397864	ANTONINA SOLOVEVA	{"email": "soloveva.antonina1967@postgrespro.ru", "phone": "+70555840389"}
0005435132993	70F95E	7154 316348	PAVEL VASILEV	{"email": "vasilev-pavel13081975@postgrespro.ru", "phone": "+70636990146"}
0005435132994	CE7D99	4266 169907	OKSANA ZAKHAROVA	{"email": "zakharovao06031967@postgrespro.ru", "phone": "+70658005203"}
0005435132995	8300F6	7180 166752	DMITRIY MARTYNOV	{"email": "dmitriy-martynov_1976@postgrespro.ru", "phone": "+70452604101"}
0005435132996	8300F6	1376 367970	TATYANA FOMINA	{"phone": "+70945901632"}
0005435132997	9FC5F3	8466 314976	ARTEM ZHUKOV	{"email": "a.zhukov031974@postgrespro.ru", "phone": "+70701484994"}
0005435132998	AE595B	8271 774098	ELENA SOLOVEVA	{"phone": "+70638721823"}
0005435132999	58D01F	4942 331676	VERA SAVELEVA	{"phone": "+70480048949"}
0005435133000	58D01F	6771 373019	VERA VOLKOVA	{"phone": "+70019059366"}
0005435133001	321AB1	0083 040150	ROMAN VLASOV	{"email": "rvlasov.22061975@postgrespro.ru", "phone": "+70218202725"}
0005435133002	321AB1	6389 340775	EVGENIY DENISOV	{"phone": "+70258102400"}
0005435133003	0332A8	9381 666527	YANA FROLOVA	{"email": "y-frolova-1977@postgrespro.ru", "phone": "+70699815737"}
0005435133004	0332A8	1467 007194	ELENA TARASOVA	{"email": "tarasova.e_06121980@postgrespro.ru", "phone": "+70666896639"}
0005435133005	64FF3A	7963 195094	ZINAIDA NIKOLAEVA	{"email": "nikolaeva-z021974@postgrespro.ru", "phone": "+70110474608"}
0005435133006	64FF3A	5648 203012	ANATOLIY MAKAROV	{"email": "makarov-anatoliy_061967@postgrespro.ru", "phone": "+70050693332"}
0005435133007	370300	8898 685718	MARIYA ZAKHAROVA	{"phone": "+70886940841"}
0005435133008	370300	7652 593996	ALEKSANDR MIRONOV	{"phone": "+70714462626"}
0005435133009	0977A7	6940 908560	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov.021977@postgrespro.ru", "phone": "+70473547382"}
0005435133010	2D8E11	3289 347467	MATVEY KUZNECOV	{"phone": "+70624786378"}
0005435133011	2147ED	8191 030743	MIKHAIL BORISOV	{"phone": "+70322912634"}
0005435133012	2147ED	4017 935368	ARKADIY ANTONOV	{"phone": "+70454027995"}
0005435133013	A505CD	6512 001298	SERGEY ISAEV	{"email": "isaev_sergey.21031974@postgrespro.ru", "phone": "+70674650497"}
0005435133014	A505CD	6473 872908	VLADIMIR PAVLOV	{"email": "pavlovv-041972@postgrespro.ru", "phone": "+70704636306"}
0005435133015	DCD7AD	0627 399329	MARIYA KAZAKOVA	{"phone": "+70707840567"}
0005435133016	7E57C3	0163 958254	ALEKSANDR ABRAMOV	{"email": "abramov_a_1962@postgrespro.ru", "phone": "+70155093573"}
0005435133017	4053D8	5622 789616	ANTON ROMANOV	{"phone": "+70445606862"}
0005435133018	4053D8	2260 289096	IVAN KRASNOV	{"phone": "+70020418191"}
0005435133019	5C3B6E	4013 475295	TATYANA KOZLOVA	{"phone": "+70750277073"}
0005435133020	29755A	3547 492061	VLADIMIR SERGEEV	{"phone": "+70352998734"}
0005435133021	65ED0B	8751 860454	VALENTINA EGOROVA	{"phone": "+70637571676"}
0005435133022	8D27E6	4525 203166	KIRILL IVANOV	{"email": "kirill-ivanov_071983@postgrespro.ru", "phone": "+70565385424"}
0005435133023	6112A2	0714 089685	ALI FILIPPOV	{"phone": "+70253391753"}
0005435133024	AB5D02	6830 742831	MAKSIM GRIGOREV	{"email": "grigorev.maksim1975@postgrespro.ru", "phone": "+70539023271"}
0005435133025	DFA0DE	2882 276561	VLADIMIR KISELEV	{"email": "vladimir.kiselev_1970@postgrespro.ru", "phone": "+70181083231"}
0005435133026	C081BA	5991 079954	VLADIMIR MAKAROV	{"phone": "+70484415440"}
0005435133027	C081BA	6318 182838	NADEZHDA PAVLOVA	{"email": "pavlova_n.28101973@postgrespro.ru", "phone": "+70963573372"}
0005435133028	9B0B2F	4003 380487	OLEG BARANOV	{"email": "obaranov1976@postgrespro.ru", "phone": "+70798648272"}
0005435133029	2642E2	9781 545654	OLGA NOVIKOVA	{"phone": "+70918117040"}
0005435133030	6D12B4	8458 633531	MARINA ZOTOVA	{"phone": "+70054052676"}
0005435133031	B0A06A	6773 295146	OLEG PAVLOV	{"phone": "+70235864758"}
0005435133032	B0A06A	7128 235144	NIKOLAY POPOV	{"email": "nikolay.popov_121966@postgrespro.ru", "phone": "+70255871273"}
0005435133033	240F3D	2920 854892	VALERIY MAKAROV	{"phone": "+70243018621"}
0005435133034	EDEBC0	4357 296722	NATALYA KONOVALOVA	{"email": "konovalovanatalya111967@postgrespro.ru", "phone": "+70664039936"}
0005435133035	EDEBC0	1569 152768	GENNADIY KUZNECOV	{"phone": "+70647424449"}
0005435133036	B95D6D	1953 721086	ALFIYA KAZAKOVA	{"phone": "+70342665073"}
0005435133037	28826B	5435 566347	IRINA MIRONOVA	{"phone": "+70773411589"}
0005435133038	28826B	4051 313138	LARISA ANDREEVA	{"email": "larisaandreeva24061977@postgrespro.ru", "phone": "+70912115745"}
0005435133039	28826B	5994 281266	SERGEY KUZNECOV	{"phone": "+70780937829"}
0005435133040	9CFEBA	5300 744386	LYUDMILA KRASNOVA	{"phone": "+70353099455"}
0005435133042	E8C4D2	7781 537963	TATYANA ZAKHAROVA	{"email": "zakharova.tatyana.23111968@postgrespro.ru", "phone": "+70718247607"}
0005435133043	54F79A	9321 777807	OLEG SERGEEV	{"phone": "+70918804470"}
0005435133044	EDECBE	9391 325833	NATALYA GRISHINA	{"email": "grishina.natalya25031974@postgrespro.ru", "phone": "+70786063679"}
0005435133045	218781	4018 465472	PETR MELNIKOV	{"email": "melnikov_p1964@postgrespro.ru", "phone": "+70680293008"}
0005435133046	032B15	5401 833142	ANDREY NIKOLAEV	{"email": "a_nikolaev.27121965@postgrespro.ru", "phone": "+70844335866"}
0005435133047	420304	7864 004666	YANA TIKHONOVA	{"phone": "+70761109901"}
0005435133048	AD6B2B	8355 517349	VIKTOR ABRAMOV	{"phone": "+70770268645"}
0005435133049	7D4804	2188 162577	VALERIY KUZMIN	{"phone": "+70543029280"}
0005435133050	7D4804	2405 702065	GALINA ZHURAVLEVA	{"email": "gzhuravleva.09091982@postgrespro.ru", "phone": "+70574153801"}
0005435133051	B372AA	8829 591111	TATYANA EGOROVA	{"phone": "+70882383151"}
0005435133052	B372AA	7665 763557	VLADIMIR MAKSIMOV	{"phone": "+70290092306"}
0005435133053	FCB6FF	3432 514897	MARIYA SEMENOVA	{"email": "mariya-semenova031979@postgrespro.ru", "phone": "+70524670564"}
0005435133054	36A4AD	7134 447393	NADEZHDA POPOVA	{"phone": "+70143558193"}
0005435133055	1D0EDA	4593 801698	LYUBOV LEBEDEVA	{"email": "lebedeva-lyubov-18021958@postgrespro.ru", "phone": "+70754143309"}
0005435133056	46C18B	8945 026502	VLADIMIR BELOV	{"email": "belov-v081981@postgrespro.ru", "phone": "+70098021056"}
0005435133057	5D8C4A	5545 203418	OKSANA VLASOVA	{"phone": "+70872561948"}
0005435133058	39A9EA	2104 947983	IVAN ANTONOV	{"email": "ivan-antonov1977@postgrespro.ru", "phone": "+70481682233"}
0005435133059	C7A0CD	5575 083434	IGOR KULIKOV	{"email": "ikulikov_111967@postgrespro.ru", "phone": "+70793872951"}
0005435133060	550E1C	8154 668365	ELENA VASILEVA	{"email": "vasilevae-1965@postgrespro.ru", "phone": "+70401413143"}
0005435133061	F2C573	4453 370300	NADEZHDA MASLOVA	{"phone": "+70812417670"}
0005435133062	F2C573	1229 999696	VLADISLAV ANDREEV	{"email": "v-andreev.1968@postgrespro.ru", "phone": "+70766890444"}
0005435133063	8A0F62	9509 018218	EVA TARASOVA	{"phone": "+70965206602"}
0005435133064	E1180A	3494 627254	VIKTOR MATVEEV	{"email": "matveev-v_10041977@postgrespro.ru", "phone": "+70884811403"}
0005435133065	E1180A	7763 871870	RUZALIYA SMIRNOVA	{"email": "r.smirnova_1965@postgrespro.ru", "phone": "+70362246594"}
0005435133066	ED4E8A	8491 262913	SERGEY AFANASEV	{"phone": "+70011888917"}
0005435133067	92FF64	8766 639863	OLEG KOROLEV	{"phone": "+70308865215"}
0005435133068	B258B7	7003 509219	ANASTASIYA VASILEVA	{"phone": "+70306985477"}
0005435133069	425C0D	2041 734312	DENIS MARTYNOV	{"phone": "+70882640289"}
0005435133070	381952	5603 073782	LIDIYA NIKITINA	{"email": "nikitina.l.1960@postgrespro.ru", "phone": "+70196225188"}
0005435133071	CA5CF1	5696 791285	SERGEY DMITRIEV	{"email": "s-dmitriev_1980@postgrespro.ru", "phone": "+70125616244"}
0005435133072	09C827	1604 978591	NIKOLAY ALEKSEEV	{"email": "alekseev.n_041977@postgrespro.ru", "phone": "+70418369430"}
0005435133073	F87F5C	2436 862060	VIKTOR SMIRNOV	{"phone": "+70296375883"}
0005435133074	5D4C8F	4567 260437	KLAVDIYA ZHURAVLEVA	{"phone": "+70517316328"}
0005435133075	4E46B5	2686 106951	EGOR ROMANOV	{"phone": "+70097288469"}
0005435133076	4E46B5	1600 015116	VLADIMIR MAKSIMOV	{"phone": "+70580305200"}
0005435133077	1DF3B0	8968 317856	OLGA FEDOROVA	{"phone": "+70942998229"}
0005435133078	1DF3B0	3741 296081	LARISA MIKHAYLOVA	{"phone": "+70023257245"}
0005435133079	6D0BBB	2184 896293	VALENTINA MARTYNOVA	{"phone": "+70733482537"}
0005435133080	3E9329	6462 016948	ANNA SAVELEVA	{"phone": "+70124647883"}
0005435133081	23740F	7137 583666	ALEKSANDR ANTONOV	{"phone": "+70153283748"}
0005435133082	82A847	0991 342974	NIKOLAY FEDOROV	{"email": "fedorov_nikolay.1971@postgrespro.ru", "phone": "+70821577739"}
0005435133083	08ED3E	8049 181858	YURIY BORISOV	{"phone": "+70858990475"}
0005435133084	08ED3E	4793 551151	IVAN GRIGOREV	{"phone": "+70031686615"}
0005435133085	08ED3E	6493 116910	YURIY ANTONOV	{"phone": "+70526355566"}
0005435133086	0A5D6C	0515 719959	ALINA VASILEVA	{"phone": "+70109368465"}
0005435133087	0A5D6C	0286 727722	DMITRIY CHERNOV	{"email": "chernov.dmitriy101963@postgrespro.ru", "phone": "+70900817862"}
0005435133088	A2CCA9	7828 764132	IVAN SEMENOV	{"email": "i_semenov-16051969@postgrespro.ru", "phone": "+70559106729"}
0005435133089	5852F2	7633 544968	ELMIRA NIKITINA	{"email": "elmira.nikitina_121972@postgrespro.ru", "phone": "+70519454465"}
0005435133090	33E483	4369 271763	ANATOLIY ZAYCEV	{"email": "zaycev_anatoliy.081983@postgrespro.ru", "phone": "+70489607025"}
0005435133091	26E544	7501 152404	VITALIY PAVLOV	{"phone": "+70387424496"}
0005435133092	A85750	4960 031819	NATALYA KULIKOVA	{"email": "natalyakulikova_21091972@postgrespro.ru", "phone": "+70303805324"}
0005435133093	61D3E6	4805 966265	LYUBOV SCHERBAKOVA	{"email": "scherbakova.l_091969@postgrespro.ru", "phone": "+70160524683"}
0005435133094	885A82	0885 110532	LEONID SCHERBAKOV	{"email": "leonid-scherbakov.1981@postgrespro.ru", "phone": "+70325846446"}
0005435133095	B0EFE1	5162 129198	ANASTASIYA DMITRIEVA	{"phone": "+70645642820"}
0005435133096	173AA2	6099 331375	LYUDMILA PAVLOVA	{"email": "lpavlova_26071963@postgrespro.ru", "phone": "+70382377490"}
0005435133097	143D38	8852 345170	ANDREY SEMENOV	{"email": "semenov_andrey_101972@postgrespro.ru", "phone": "+70955890900"}
0005435133098	143D38	3699 475406	TATYANA ALEKSEEVA	{"phone": "+70708496507"}
0005435133099	6C892B	3952 532614	VIKTOR MOISEEV	{"phone": "+70543865152"}
0005435133100	27736A	5088 798253	VIKTOR MATVEEV	{"phone": "+70429871994"}
0005435133101	AE8E52	1988 257444	TAMARA SAVELEVA	{"email": "t-saveleva_021963@postgrespro.ru", "phone": "+70889887970"}
0005435133102	48EF81	6802 216145	ARMAN MIKHAYLOV	{"phone": "+70613975155"}
0005435133103	7A7579	8740 197820	ANTONINA SOROKINA	{"phone": "+70844947191"}
0005435133104	F15931	4812 125043	IGOR IVANOV	{"phone": "+70638903316"}
0005435133105	00CCAD	8363 819187	KIRILL FEDOROV	{"email": "fedorovk_1985@postgrespro.ru", "phone": "+70908120919"}
0005435133106	DF729B	3574 454319	EKATERINA KUZNECOVA	{"phone": "+70813624517"}
0005435133107	5F8D83	2159 595651	VLADIMIR KISELEV	{"email": "v-kiselev1971@postgrespro.ru", "phone": "+70083419418"}
0005435133108	5F8D83	8261 410474	TATYANA ARKHIPOVA	{"phone": "+70976111855"}
0005435133109	9E3542	7654 742572	POLINA NIKITINA	{"phone": "+70164649242"}
0005435133110	F53961	7012 251568	DIANA ERMAKOVA	{"phone": "+70923681938"}
0005435133111	217442	6805 029309	ELENA ZHUKOVA	{"email": "e_zhukova.04031972@postgrespro.ru", "phone": "+70917392024"}
0005435133112	925ED5	5197 655627	ANASTASIYA AFANASEVA	{"email": "anastasiyaafanaseva111965@postgrespro.ru", "phone": "+70230107291"}
0005435133113	FCD056	7520 076823	SOFYA KOMAROVA	{"email": "komarova.sofya031974@postgrespro.ru", "phone": "+70390088245"}
0005435133114	FCD056	5034 590156	OKSANA ZAKHAROVA	{"phone": "+70497650658"}
0005435133115	BF7EE1	9247 676013	ALEKSANDR ZAKHAROV	{"phone": "+70660465415"}
0005435133116	3C0E31	6550 069661	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr.1977@postgrespro.ru", "phone": "+70505123766"}
0005435133117	3C0E31	3642 875075	NIKOLAY KULIKOV	{"email": "nikolay.kulikov.03121975@postgrespro.ru", "phone": "+70317695248"}
0005435133118	FB64A8	5410 003695	ALEKSEY FEDOTOV	{"email": "fedotova-1965@postgrespro.ru", "phone": "+70342009837"}
0005435133119	8DA8E1	2246 368480	YURIY BELOV	{"email": "belov_y-1973@postgrespro.ru", "phone": "+70008013555"}
0005435133120	EFE1E0	7299 317358	EDUARD ZAYCEV	{"phone": "+70774198120"}
0005435133121	F6E246	2401 395234	ALINA SMIRNOVA	{"email": "asmirnova.011975@postgrespro.ru", "phone": "+70948264267"}
0005435133122	7812DD	9808 852430	GULFIYA BARANOVA	{"phone": "+70435442999"}
0005435133123	8F53A6	5775 284342	ELENA MAKSIMOVA	{"email": "elena_maksimova051973@postgrespro.ru", "phone": "+70530434198"}
0005435133124	A63E07	6568 577904	ANNA BARANOVA	{"phone": "+70217182606"}
0005435133125	A63E07	1388 826974	OLGA PAVLOVA	{"phone": "+70551404432"}
0005435133126	81772F	1696 421151	NATALIYA MIKHAYLOVA	{"email": "nataliyamikhaylova-1977@postgrespro.ru", "phone": "+70045628107"}
0005435133127	81772F	8244 682577	LEONID PAVLOV	{"phone": "+70409492515"}
0005435133128	81772F	4225 006207	SERGEY SCHERBAKOV	{"phone": "+70944075733"}
0005435133129	7F9C20	8895 157661	OKSANA DMITRIEVA	{"email": "dmitrievaoksana_16111974@postgrespro.ru", "phone": "+70929729181"}
0005435133130	A07058	3803 897097	IVAN NOVIKOV	{"phone": "+70833491860"}
0005435133131	7B11CE	6245 821087	LYUBOV VOROBEVA	{"email": "vorobeva_l.051961@postgrespro.ru", "phone": "+70354835766"}
0005435133132	863A58	7273 585188	OLGA PAVLOVA	{"email": "o-pavlova_1976@postgrespro.ru", "phone": "+70984587632"}
0005435133133	863A58	2876 649145	SERGEY EGOROV	{"phone": "+70021758497"}
0005435133134	863A58	2552 515582	DENIS YAKOVLEV	{"phone": "+70653269511"}
0005435133135	87C7E8	1862 634922	ANDREY ZAYCEV	{"phone": "+70318151887"}
0005435133136	87C7E8	9459 334225	NADEZHDA ORLOVA	{"phone": "+70337277177"}
0005435133137	6D8206	6292 368686	ZAKHAR KRASNOV	{"email": "z.krasnov-26041966@postgrespro.ru", "phone": "+70116840624"}
0005435133138	DA3D37	2293 358552	SERGEY EGOROV	{"phone": "+70069862196"}
0005435133139	4AE8D4	5261 001858	VALERIY SOKOLOV	{"email": "sokolov_valeriy_111967@postgrespro.ru", "phone": "+70690739095"}
0005435133140	96B2BB	9728 353465	LIDIYA NIKOLAEVA	{"email": "nikolaeval121975@postgrespro.ru", "phone": "+70567992321"}
0005435133141	E6DEA4	4051 101505	MARIYA ABRAMOVA	{"phone": "+70572909991"}
0005435133142	F5F844	5741 905171	PETR VOLKOV	{"phone": "+70497873495"}
0005435133143	F59905	2377 132213	VALERIY ZAKHAROV	{"phone": "+70521287673"}
0005435133144	94A64D	3979 078415	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov_071963@postgrespro.ru", "phone": "+70762412856"}
0005435133145	A5A3E4	0957 984774	BOGDAN ILIN	{"phone": "+70852633272"}
0005435133146	53E5E1	6565 658082	RAISA BORISOVA	{"phone": "+70858623213"}
0005435133147	D882FC	9363 881700	MATVEY NIKITIN	{"email": "nikitinm.1962@postgrespro.ru", "phone": "+70507243334"}
0005435133148	D882FC	5876 883726	TAMARA BELOVA	{"email": "belova-t.051976@postgrespro.ru", "phone": "+70433871836"}
0005435133149	45C588	6377 989422	NATALYA PETROVA	{"phone": "+70052905123"}
0005435133150	138610	7184 147036	MARIYA MAKSIMOVA	{"email": "maksimovamariya_1974@postgrespro.ru", "phone": "+70616536466"}
0005435133151	138610	4581 312688	DMITRIY GORBUNOV	{"email": "gorbunov_d_1971@postgrespro.ru", "phone": "+70385925276"}
0005435133152	4EF561	5312 298112	SERGEY SOROKIN	{"email": "sergeysorokin20011986@postgrespro.ru", "phone": "+70595199943"}
0005435133153	2A25FF	7906 094303	PETR CHERNOV	{"phone": "+70146084170"}
0005435133154	9770E1	4884 938772	MAKSIM VOLKOV	{"email": "volkov.maksim.04051980@postgrespro.ru", "phone": "+70310880694"}
0005435133155	772C9C	9784 953434	ELIZAVETA EGOROVA	{"email": "elizaveta.egorova.03081978@postgrespro.ru", "phone": "+70477262035"}
0005435133156	202819	5027 471873	NATALYA MELNIKOVA	{"email": "n_melnikova30051967@postgrespro.ru", "phone": "+70552778142"}
0005435133157	6EA8D9	0869 944421	OLGA ZAKHAROVA	{"email": "olgazakharova.29081980@postgrespro.ru", "phone": "+70478943813"}
0005435133158	6EA8D9	1451 853076	MAKAR SCHERBAKOV	{"email": "makar-scherbakov-04051968@postgrespro.ru", "phone": "+70888379617"}
0005435133159	43C750	9917 710582	ALEKSEY ORLOV	{"phone": "+70622086385"}
0005435133160	481E8F	7034 501457	DMITRIY SIDOROV	{"phone": "+70628657467"}
0005435133161	424B48	8888 482111	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr.26041979@postgrespro.ru", "phone": "+70763143760"}
0005435133162	424B48	7956 578389	GRIGORIY DENISOV	{"phone": "+70927558190"}
0005435133163	90C864	0874 860206	ANFISA BORISOVA	{"email": "borisova.anfisa_23091979@postgrespro.ru", "phone": "+70147706339"}
0005435133164	66E618	3525 278506	ALEKSEY FROLOV	{"phone": "+70507872895"}
0005435133165	66E618	9837 275065	ANDREY KOZLOV	{"phone": "+70018932912"}
0005435133166	850245	8973 336933	VLADIMIR GUSEV	{"phone": "+70350990959"}
0005435133167	3D30C9	0215 194132	ALEKSEY DMITRIEV	{"phone": "+70619286659"}
0005435133168	4122A3	0042 023584	VALERIY ANDREEV	{"phone": "+70671539631"}
0005435133169	4122A3	1483 883526	ALEKSANDR OSIPOV	{"email": "aleksandr-osipov1963@postgrespro.ru", "phone": "+70418426567"}
0005435133170	1FFF9B	4495 596702	NIKOLAY VLASOV	{"phone": "+70603480486"}
0005435133171	1FFF9B	6540 704190	ROMAN MAKSIMOV	{"email": "maksimov.roman_1974@postgrespro.ru", "phone": "+70130839059"}
0005435133172	1FFF9B	7948 826449	POLINA ARKHIPOVA	{"phone": "+70647401463"}
0005435133173	E0789D	0246 110469	GALINA PETROVA	{"phone": "+70226332425"}
0005435133174	833280	3350 053185	ANTONINA KUDRYASHOVA	{"email": "antoninakudryashova.31101975@postgrespro.ru", "phone": "+70909341611"}
0005435133175	434677	4409 898830	MARAT PAVLOV	{"email": "pavlov.marat-051970@postgrespro.ru", "phone": "+70990810827"}
0005435133176	095B46	7457 225319	GALINA ROMANOVA	{"phone": "+70229609660"}
0005435133177	02ECD3	7796 484416	OLEG SOKOLOV	{"email": "oleg-sokolov071974@postgrespro.ru", "phone": "+70574493473"}
0005435133178	01F382	2990 663770	LIDIYA YAKOVLEVA	{"email": "l.yakovleva-081971@postgrespro.ru", "phone": "+70378052726"}
0005435133179	82A7C6	0681 406435	SOFYA NOVIKOVA	{"email": "sofya.novikova051964@postgrespro.ru", "phone": "+70626639372"}
0005435133180	A972C2	1977 936856	VERA GUSEVA	{"email": "vera_guseva-1961@postgrespro.ru", "phone": "+70636664139"}
0005435133181	A972C2	1124 629031	YURIY NAZAROV	{"phone": "+70560960991"}
0005435133182	4910FF	4646 636729	ELENA VOROBEVA	{"phone": "+70518812186"}
0005435133183	D93F30	1398 392007	STEPAN KISELEV	{"email": "s.kiselev_1975@postgrespro.ru", "phone": "+70176839645"}
0005435133184	D93F30	1486 290042	GALINA KUZNECOVA	{"email": "kuznecova-galina021982@postgrespro.ru", "phone": "+70798844729"}
0005435133185	1138DB	5973 067714	NIKOLAY POPOV	{"email": "popov_nikolay.13121964@postgrespro.ru", "phone": "+70928395641"}
0005435133186	6FE0C9	3843 015926	MIKHAIL SOROKIN	{"email": "sorokin_m071972@postgrespro.ru", "phone": "+70862415906"}
0005435133187	233ED6	1351 922556	EKATERINA ORLOVA	{"phone": "+70324233314"}
0005435133188	233ED6	4661 915023	MARINA SOROKINA	{"phone": "+70984796070"}
0005435133189	561AB5	3061 904124	ALEKSEY SOROKIN	{"phone": "+70350365414"}
0005435133190	56B44D	7316 788692	ALEKSEY MIRONOV	{"phone": "+70562252825"}
0005435133191	7F9D6E	8109 272359	EVGENIY VASILEV	{"phone": "+70494627719"}
0005435133192	7F9D6E	3253 182399	IRINA GORBUNOVA	{"email": "gorbunova.irina_1976@postgrespro.ru", "phone": "+70369708966"}
0005435133193	F14C4B	0136 617474	LARISA FEDOROVA	{"phone": "+70042885580"}
0005435133194	D36E79	4504 248860	IRINA KONOVALOVA	{"email": "konovalovairina-091971@postgrespro.ru", "phone": "+70918307689"}
0005435133195	D36E79	9672 971869	EKATERINA POLYAKOVA	{"phone": "+70510068368"}
0005435133196	912989	7393 639816	DMITRIY FROLOV	{"email": "frolov-dmitriy-16021972@postgrespro.ru", "phone": "+70354743973"}
0005435133197	DBA480	8148 597741	GENNADIY KRASNOV	{"email": "krasnov-g-121969@postgrespro.ru", "phone": "+70475126363"}
0005435133198	BFC5E7	9448 846010	EKATERINA KUDRYASHOVA	{"email": "kudryashova.ekaterina_26121973@postgrespro.ru", "phone": "+70370778523"}
0005435133199	2E8C9C	7475 804375	NATALYA KUZNECOVA	{"phone": "+70153750039"}
0005435133200	2E8C9C	6283 298637	RADIK KOZLOV	{"phone": "+70779766882"}
0005435135587	22B4C6	4472 317225	MIKHAIL ANTONOV	{"phone": "+70370179240"}
0005435135582	658171	3306 017636	MAKSIM ZAKHAROV	{"phone": "+70378018618"}
0005435135583	658171	8541 345972	VLADIMIR MATVEEV	{"phone": "+70355626764"}
0005435135584	3642FC	1976 198141	ALEKSANDR FEDOTOV	{"phone": "+70908198624"}
0005435135585	3642FC	6186 161631	MAKSIM MIRONOV	{"phone": "+70950084500"}
0005435135586	1C12EA	2808 500443	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev-1965@postgrespro.ru", "phone": "+70310463330"}
0005435135588	22B4C6	7748 975405	NADEZHDA KRASNOVA	{"phone": "+70008241298"}
0005435135589	E5A847	2228 780490	ALEKSANDR POPOV	{"email": "apopov09111962@postgrespro.ru", "phone": "+70782086594"}
0005435135590	E5A847	5410 998307	MARINA POTAPOVA	{"email": "potapova_marina10011981@postgrespro.ru", "phone": "+70567128127"}
0005435135591	BD8819	1612 120032	VLADIMIR KUZNECOV	{"email": "kuznecov-v29011962@postgrespro.ru", "phone": "+70895624595"}
0005435135592	1EBF4F	5402 383386	ILYA ZAKHAROV	{"email": "zakharovi-071977@postgrespro.ru", "phone": "+70847628767"}
0005435135593	ED233D	2775 992246	VASILIY VOLKOV	{"email": "v.volkov-03011962@postgrespro.ru", "phone": "+70831649880"}
0005435135594	DEC751	4295 050581	ALEKSANDR BORISOV	{"phone": "+70518386738"}
0005435135595	82E42E	2043 746980	ALEKSEY ABRAMOV	{"email": "abramov_aleksey_061970@postgrespro.ru", "phone": "+70860013334"}
0005435135596	E14EC3	8421 055954	LYUDMILA KONOVALOVA	{"email": "l_konovalova02051980@postgrespro.ru", "phone": "+70378346046"}
0005435135597	E14EC3	8556 396233	SERGEY VASILEV	{"phone": "+70197308871"}
0005435135598	04B0E7	3302 818806	LYUDMILA TARASOVA	{"phone": "+70622780614"}
0005435135599	E49496	8140 179359	EVGENIY GAVRILOV	{"phone": "+70500564254"}
0005435135600	802733	6641 834068	LYUBOV POPOVA	{"email": "popova.l_12051962@postgrespro.ru", "phone": "+70975500338"}
0005435135601	802733	8287 414264	SERGEY KULIKOV	{"phone": "+70350822303"}
0005435135602	D1836C	6764 345760	ALEKSEY NAUMOV	{"phone": "+70512354474"}
0005435135603	D1836C	6182 323262	FARIDA EGOROVA	{"phone": "+70218399995"}
0005435135604	B07FE4	9056 295564	MARIYA MIRONOVA	{"email": "m-mironova_061966@postgrespro.ru", "phone": "+70394060174"}
0005435135605	B07FE4	0101 169099	ROMAN MOROZOV	{"phone": "+70720004617"}
0005435135606	B08260	2863 335640	OLEG MOROZOV	{"phone": "+70846562732"}
0005435135607	22980B	4042 282220	MARGARITA SIDOROVA	{"email": "margarita_sidorova-1969@postgrespro.ru", "phone": "+70975996769"}
0005435135608	465738	7629 818580	VYACHESLAV KULIKOV	{"email": "vkulikov.1972@postgrespro.ru", "phone": "+70101611067"}
0005435135609	465738	1567 200097	LYUDMILA SIDOROVA	{"email": "sidorova-l.111976@postgrespro.ru", "phone": "+70795371716"}
0005435135610	465738	3024 988428	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a.27091974@postgrespro.ru", "phone": "+70220251232"}
0005435135611	8AB4AF	7048 736800	YULIYA MOROZOVA	{"email": "yuliyamorozova.1969@postgrespro.ru", "phone": "+70096449993"}
0005435135612	984BD0	7260 226100	YURIY ABRAMOV	{"email": "yuriyabramov.021982@postgrespro.ru", "phone": "+70712779237"}
0005435135613	BAC858	2443 062565	VALENTINA TARASOVA	{"phone": "+70864620206"}
0005435135614	BAC858	7413 194996	DAVID ABRAMOV	{"email": "abramovdavid_24011972@postgrespro.ru", "phone": "+70929044730"}
0005435135615	CD3AA9	2259 543356	VARVARA NIKOLAEVA	{"email": "v-nikolaeva1976@postgrespro.ru", "phone": "+70320735326"}
0005435135616	CD3AA9	0886 575748	EVGENIY FOMIN	{"email": "efomin-041978@postgrespro.ru", "phone": "+70834747301"}
0005435135617	E3D0D4	2746 553417	ALEKSANDR GERASIMOV	{"phone": "+70322562379"}
0005435135618	E3D0D4	4201 253556	ANASTASIYA ZHUKOVA	{"phone": "+70682913914"}
0005435135619	851889	2587 571968	SVETLANA STEPANOVA	{"phone": "+70984057546"}
0005435135620	F645B0	6940 795991	GENNADIY MIKHAYLOV	{"phone": "+70500205104"}
0005435135621	F645B0	0851 258799	VALERIY CHERNOV	{"email": "valeriy.chernov.121972@postgrespro.ru", "phone": "+70172203512"}
0005435135622	5B1232	5791 875678	OLESYA ZHUKOVA	{"phone": "+70910781607"}
0005435135623	5B1232	2413 468717	OLGA NESTEROVA	{"email": "nesterovao.091965@postgrespro.ru", "phone": "+70559539460"}
0005435135624	0ED1FC	9218 293769	DMITRIY SEMENOV	{"phone": "+70006878022"}
0005435135625	DFF34B	4742 498109	VLADIMIR BARANOV	{"phone": "+70179340186"}
0005435135626	416644	1578 645139	ALEKSANDR SIDOROV	{"email": "sidorov.a1971@postgrespro.ru", "phone": "+70086185876"}
0005435135627	78486F	5899 950238	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva091961@postgrespro.ru", "phone": "+70478847066"}
0005435135628	6FBBF5	6027 557462	MARGARITA VASILEVA	{"email": "margaritavasileva1970@postgrespro.ru", "phone": "+70541645674"}
0005435135629	6FBBF5	9065 766267	MARIYA KUZNECOVA	{"phone": "+70381762680"}
0005435135630	A67EBF	2574 788022	FARID MEDVEDEV	{"email": "farid-medvedev_1983@postgrespro.ru", "phone": "+70921338966"}
0005435135631	54C85D	9584 588230	GALINA OSIPOVA	{"email": "g_osipova-1976@postgrespro.ru", "phone": "+70085465828"}
0005435135632	54C85D	7650 667561	EKATERINA FOMINA	{"email": "e-fomina_30041968@postgrespro.ru", "phone": "+70271608424"}
0005435135633	AF5760	9646 944988	KRISTINA YUDINA	{"email": "kristina_yudina.051974@postgrespro.ru", "phone": "+70972697190"}
0005435135634	1A8B14	1078 813169	VIKTOR KUZNECOV	{"phone": "+70047842458"}
0005435135635	119BD0	7463 131141	EKATERINA SERGEEVA	{"phone": "+70740705319"}
0005435135636	DAA6B0	7323 505957	VALENTINA YUDINA	{"email": "valentina.yudina.1980@postgrespro.ru", "phone": "+70055469612"}
0005435135637	E66555	9600 718528	ROMAN POPOV	{"phone": "+70266938076"}
0005435135638	E66555	7001 929092	LYUBOV SOROKINA	{"email": "sorokina-lyubov.081973@postgrespro.ru", "phone": "+70451576898"}
0005435135639	B29B00	9957 863838	ALEKSANDRA MAKAROVA	{"phone": "+70043441458"}
0005435135640	F5BD25	3150 644171	ELENA PAVLOVA	{"email": "pavlova-elena041972@postgrespro.ru", "phone": "+70394891829"}
0005435135641	4E715E	5644 132934	NIKOLAY SIDOROV	{"email": "nsidorov-021983@postgrespro.ru", "phone": "+70785671239"}
0005435135642	718879	6364 030034	OLGA FROLOVA	{"phone": "+70936908032"}
0005435135643	718879	5668 542832	DMITRIY SCHERBAKOV	{"email": "scherbakov.dmitriy.081964@postgrespro.ru", "phone": "+70014504413"}
0005435135644	E595AB	9248 773093	FARIT BARANOV	{"phone": "+70043090261"}
0005435135645	AD33D8	2647 393803	LIDIYA SERGEEVA	{"email": "l_sergeeva_1975@postgrespro.ru", "phone": "+70329408657"}
0005435135646	93B182	4469 611191	VLADIMIR YAKOVLEV	{"email": "yakovlev-vladimir10111969@postgrespro.ru", "phone": "+70524061241"}
0005435135647	ADD49F	0011 443575	TATYANA BORISOVA	{"email": "borisova_t-02031963@postgrespro.ru", "phone": "+70656917025"}
0005435135648	ADD49F	9021 735266	LYUDMILA FEDOROVA	{"phone": "+70261835238"}
0005435135649	7D1937	3780 421948	EKATERINA TARASOVA	{"phone": "+70304504532"}
0005435135650	7D1937	4864 469295	DIANA YAKOVLEVA	{"email": "diana-yakovleva_1970@postgrespro.ru", "phone": "+70605105598"}
0005435135651	7D1937	3316 031630	EVGENIY FOMIN	{"phone": "+70990524396"}
0005435135652	61CCB5	8334 589393	GENNADIY SEMENOV	{"phone": "+70442995470"}
0005435135653	F7B3C4	4508 295861	SERGEY BORISOV	{"phone": "+70279038222"}
0005435135654	F7B3C4	3381 095094	VALENTINA MATVEEVA	{"phone": "+70540633876"}
0005435135655	FFE6D3	1316 803932	NADEZHDA DENISOVA	{"email": "ndenisova-091978@postgrespro.ru", "phone": "+70422709655"}
0005435135656	3748E8	5321 708121	NINA DANILOVA	{"phone": "+70219920762"}
0005435135657	B8D29A	4438 814379	VLADISLAV TIKHONOV	{"phone": "+70698537857"}
0005435135658	C754DE	4248 710767	KSENIYA MAKSIMOVA	{"phone": "+70736398249"}
0005435135659	2B8877	4536 157463	NADEZHDA ALEKSEEVA	{"email": "alekseevanadezhda-111974@postgrespro.ru", "phone": "+70901658179"}
0005435135660	2B8877	5209 495859	ALEKSEY FILIPPOV	{"email": "filippovaleksey.1971@postgrespro.ru", "phone": "+70057365674"}
0005435135661	BC0ED4	2189 931672	MAKSIM SCHERBAKOV	{"email": "m.scherbakov15101969@postgrespro.ru", "phone": "+70472619052"}
0005435135662	247CC2	7075 681168	SERGEY IVANOV	{"email": "ivanov.sergey.1968@postgrespro.ru", "phone": "+70168703005"}
0005435135663	1B1771	1508 886587	ALEKSANDR PETROV	{"phone": "+70664083674"}
0005435135664	1B1771	1503 771008	VIKTOR MAKAROV	{"email": "makarov-v-071970@postgrespro.ru", "phone": "+70943749234"}
0005435135665	2F50DE	1194 944147	EDUARD MOROZOV	{"email": "eduard.morozov_27051986@postgrespro.ru", "phone": "+70797396161"}
0005435135666	2F50DE	0127 636950	SVETLANA EFIMOVA	{"phone": "+70578315740"}
0005435135667	DE0A0F	5579 949342	FEDOR KOZLOV	{"email": "kozlov_fedor061976@postgrespro.ru", "phone": "+70045370657"}
0005435135668	ED0AB2	5203 598673	IRINA MOISEEVA	{"phone": "+70212196085"}
0005435135669	C792BF	8756 092141	DMITRIY PAVLOV	{"phone": "+70422398561"}
0005435135670	A3A237	8290 814182	NIKITA BARANOV	{"email": "baranov-n17021979@postgrespro.ru", "phone": "+70464798094"}
0005435135671	0B60C1	7032 359670	MIKHAIL ZAYCEV	{"email": "mikhailzaycev.16101985@postgrespro.ru", "phone": "+70590484547"}
0005435135672	0B60C1	7344 926348	VERONIKA SCHERBAKOVA	{"phone": "+70095442485"}
0005435135673	95CCA0	0888 264727	LIDIYA GRISHINA	{"email": "grishina.lidiya-15121981@postgrespro.ru", "phone": "+70592452846"}
0005435135674	ECDA1F	2705 888727	LIDIYA KARPOVA	{"email": "karpovalidiya_1987@postgrespro.ru", "phone": "+70875288106"}
0005435135675	99D97B	4268 602701	IRINA NESTEROVA	{"phone": "+70512540854"}
0005435135676	D3E25F	3756 608663	OLGA DENISOVA	{"email": "o_denisova-071980@postgrespro.ru", "phone": "+70602623507"}
0005435135677	90DDDC	2791 128648	DMITRIY FEDOTOV	{"phone": "+70701420811"}
0005435135678	90DDDC	3686 880095	ROMAN RODIONOV	{"email": "rodionov-roman-04101970@postgrespro.ru", "phone": "+70507841727"}
0005435135679	90DDDC	9644 931224	DMITRIY MIKHAYLOV	{"email": "dmitriymikhaylov-111971@postgrespro.ru", "phone": "+70418896420"}
0005435135680	C0DEC9	0304 483819	YULIYA RODIONOVA	{"email": "rodionova-yuliya_1981@postgrespro.ru", "phone": "+70118736520"}
0005435135681	EC8C88	0631 758093	LYUBOV BOGDANOVA	{"email": "bogdanova.lyubov.1983@postgrespro.ru", "phone": "+70797557396"}
0005435135682	7BAD5A	8883 359466	SOFYA TITOVA	{"email": "s.titova_1980@postgrespro.ru", "phone": "+70322057995"}
0005435135683	7BAD5A	5701 879440	VLADIMIR PAVLOV	{"phone": "+70815571184"}
0005435135684	06139C	3467 161761	MARIYA BORISOVA	{"email": "borisovamariya_06071980@postgrespro.ru", "phone": "+70076586513"}
0005435135685	134E05	2400 361324	VLADIMIR SEMENOV	{"email": "semenov.vladimir.081964@postgrespro.ru", "phone": "+70713225557"}
0005435135686	1AC088	1769 602988	OLGA POPOVA	{"phone": "+70758215466"}
0005435135687	1AC088	3157 630288	OLGA KUZNECOVA	{"phone": "+70540794397"}
0005435135688	327F9C	2530 098580	EVGENIY GRIGOREV	{"phone": "+70630680048"}
0005435135689	327F9C	9039 956278	DMITRIY ALEKSANDROV	{"phone": "+70773678941"}
0005435135690	432648	9441 477048	MARIYA VASILEVA	{"email": "m_vasileva-1972@postgrespro.ru", "phone": "+70161360492"}
0005435135691	913E34	7907 727957	EVGENIY ROMANOV	{"email": "e-romanov25081971@postgrespro.ru", "phone": "+70878778374"}
0005435135692	189F12	8750 297798	IRAIDA MOROZOVA	{"email": "morozova.i.011981@postgrespro.ru", "phone": "+70351999344"}
0005435135693	298F7A	3552 054226	VLADIMIR CHERNOV	{"email": "chernov_v-18021969@postgrespro.ru", "phone": "+70266331428"}
0005435135694	298F7A	7795 465733	SERGEY ROMANOV	{"phone": "+70591743626"}
0005435135695	77936B	7411 748735	DANIIL EGOROV	{"phone": "+70062723738"}
0005435135696	77936B	2242 672228	TATYANA MAKAROVA	{"phone": "+70136982541"}
0005435135697	EB7CDD	4877 713455	ANTONINA KALININA	{"email": "kalinina.a-061978@postgrespro.ru", "phone": "+70606915549"}
0005435135698	EB7CDD	5808 457463	LYUBOV SIDOROVA	{"phone": "+70034270740"}
0005435135699	A7C683	5127 809629	SVETLANA ALEKSANDROVA	{"phone": "+70667426077"}
0005435135700	A7C683	6311 792835	RADIK ZHURAVLEV	{"phone": "+70196236340"}
0005435135701	A37BE1	9290 519411	MARINA ANTONOVA	{"email": "marina_antonova_091978@postgrespro.ru", "phone": "+70933708963"}
0005435135702	27C256	3636 048449	EVGENIYA KUZNECOVA	{"phone": "+70397349874"}
0005435135703	A6EDE2	1756 259921	LILIYA KALININA	{"phone": "+70879983354"}
0005435135704	02E3E4	7105 950272	DMITRIY VOLKOV	{"email": "dvolkov_051962@postgrespro.ru", "phone": "+70539566175"}
0005435135705	27CEEE	5186 711654	SERGEY GUSEV	{"email": "sgusev121968@postgrespro.ru", "phone": "+70323681485"}
0005435135706	7C3650	9696 476673	ANNA KOMAROVA	{"email": "a_komarova-011971@postgrespro.ru", "phone": "+70760625832"}
0005435135707	23FD6E	7137 735544	FILIPP TIKHONOV	{"email": "tikhonov_filipp-1962@postgrespro.ru", "phone": "+70213358867"}
0005435135708	23FD6E	7783 126342	NADEZHDA GERASIMOVA	{"email": "nadezhda.gerasimova.23021979@postgrespro.ru", "phone": "+70114063381"}
0005435135709	3102D1	2594 626247	MARIYA NAZAROVA	{"phone": "+70572904855"}
0005435135710	6A7F88	2865 765819	LYUDMILA SMIRNOVA	{"email": "lyudmila.smirnova_18051961@postgrespro.ru", "phone": "+70719888248"}
0005435135711	7DCC67	6965 244110	ANATOLIY TARASOV	{"email": "anatoliy-tarasov051967@postgrespro.ru", "phone": "+70006254215"}
0005435135712	D5007C	5819 750348	ROMAN MIKHAYLOV	{"email": "r-mikhaylov_17041958@postgrespro.ru", "phone": "+70468976313"}
0005435135713	D5007C	5670 694600	RUSLAN ILIN	{"phone": "+70498139746"}
0005435135714	3634B0	3592 135468	SERGEY MATVEEV	{"email": "matveev-sergey_14121976@postgrespro.ru", "phone": "+70545516805"}
0005435135715	3634B0	6548 656064	ALSU BELOVA	{"phone": "+70339039368"}
0005435135716	C5E74D	4518 454776	EKATERINA ALEKSEEVA	{"phone": "+70270176484"}
0005435135717	86E272	8892 454409	ANASTASIYA KOZLOVA	{"email": "kozlovaanastasiya_08121978@postgrespro.ru", "phone": "+70991377818"}
0005435135718	A92D3E	8631 291173	REGINA KOROLEVA	{"email": "regina_koroleva_30031970@postgrespro.ru", "phone": "+70671301389"}
0005435135719	A92D3E	6868 439547	VLADIMIR NOVIKOV	{"phone": "+70557394323"}
0005435135720	5488F7	2658 913974	VADIM DAVYDOV	{"email": "vadimdavydov-13081979@postgrespro.ru", "phone": "+70457705994"}
0005435135721	8253A7	9466 138512	NIKITA PAVLOV	{"email": "pavlov.nikita_121986@postgrespro.ru", "phone": "+70378886185"}
0005435135722	8F1C2E	4698 907413	LARISA BORISOVA	{"email": "borisova.larisa.1976@postgrespro.ru", "phone": "+70646886316"}
0005435135723	503768	6679 148997	SVETLANA VOLKOVA	{"email": "svolkova.31011965@postgrespro.ru", "phone": "+70200775579"}
0005435135724	503768	1692 568013	VERA DAVYDOVA	{"email": "v.davydova-061975@postgrespro.ru", "phone": "+70099417003"}
0005435135725	503768	8270 082285	VLADIMIR NIKOLAEV	{"email": "nikolaev.v.1968@postgrespro.ru", "phone": "+70419984803"}
0005435135726	2A6B6F	7072 599691	EDUARD ANDREEV	{"phone": "+70534546061"}
0005435135727	B1FC55	7314 801121	VIKTOR STEPANOV	{"email": "stepanov.viktor-1969@postgrespro.ru", "phone": "+70653287224"}
0005435135728	B1FC55	2728 033382	MARIYA GERASIMOVA	{"email": "gerasimova-mariya-1976@postgrespro.ru", "phone": "+70348059709"}
0005435135729	E4B723	3018 675047	DANIL SOROKIN	{"email": "sorokind_081967@postgrespro.ru", "phone": "+70307808808"}
0005435135730	69FAE5	8961 901330	SVETLANA MELNIKOVA	{"phone": "+70182878117"}
0005435135731	C75F2F	6518 684018	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr_081979@postgrespro.ru", "phone": "+70904357256"}
0005435135732	C65928	1819 320769	DIANA ANTONOVA	{"email": "antonova-d.25051971@postgrespro.ru", "phone": "+70157695851"}
0005435135733	7F0132	1000 777362	DANILA BORISOV	{"phone": "+70129895300"}
0005435135734	7F0132	0440 184517	NINA GORBUNOVA	{"phone": "+70922112915"}
0005435135735	9F1DA2	1602 332778	VALENTINA SERGEEVA	{"email": "valentina_sergeeva_02061965@postgrespro.ru", "phone": "+70554680826"}
0005435135736	DF1990	3470 571783	DMITRIY VOROBEV	{"email": "d_vorobev-1973@postgrespro.ru", "phone": "+70314405664"}
0005435135737	DF1990	5491 838768	NINA EFIMOVA	{"phone": "+70670297806"}
0005435135738	DA9997	2071 221342	VIKTOR NIKOLAEV	{"email": "nikolaev.v1986@postgrespro.ru", "phone": "+70570001063"}
0005435135739	DD4CBA	7454 307043	GEORGIY TARASOV	{"phone": "+70284911318"}
0005435135740	37E55E	8678 531484	LARISA VLASOVA	{"email": "vlasova_larisa.1965@postgrespro.ru", "phone": "+70539678249"}
0005435135741	616D43	1248 933212	VIKTORIYA KONOVALOVA	{"email": "viktoriya_konovalova.091972@postgrespro.ru", "phone": "+70627005793"}
0005435135742	616D43	4241 112133	IGOR PETROV	{"email": "petrov.i_22081960@postgrespro.ru", "phone": "+70931808195"}
0005435135743	B8F0F8	7798 655641	TATYANA EFIMOVA	{"email": "tatyanaefimova.101980@postgrespro.ru", "phone": "+70535940534"}
0005435135744	CEA020	6321 612314	NATALIYA ILINA	{"phone": "+70180957423"}
0005435135745	CEA020	7778 255443	VLADIMIR POPOV	{"email": "v-popov_24091969@postgrespro.ru", "phone": "+70104265059"}
0005435135746	E52433	3363 278467	TATYANA LAZAREVA	{"phone": "+70981510600"}
0005435135747	0AF10B	2499 558259	ANASTASIYA EFIMOVA	{"email": "efimovaa_20021985@postgrespro.ru", "phone": "+70613220137"}
0005435135748	B5B01F	4064 712711	POLINA MAKSIMOVA	{"phone": "+70511947731"}
0005435135749	B5B01F	2565 001785	OLGA ZAKHAROVA	{"phone": "+70922725211"}
0005435135750	1599EE	3458 024274	SVETLANA TIKHONOVA	{"email": "tikhonovas.1969@postgrespro.ru", "phone": "+70102442506"}
0005435135751	DAA318	6617 938587	ALEKSEY TARASOV	{"email": "a.tarasov-07011986@postgrespro.ru", "phone": "+70686258933"}
0005435135752	218137	8506 757961	GALINA FILATOVA	{"phone": "+70647739702"}
0005435135753	218137	8030 067835	NATALYA MEDVEDEVA	{"email": "n_medvedeva111975@postgrespro.ru", "phone": "+70220405943"}
0005435135754	12606D	4913 880585	ELENA GUSEVA	{"email": "elena-guseva011980@postgrespro.ru", "phone": "+70421659702"}
0005435135755	F357FA	0236 682986	OLEG IVANOV	{"email": "oleg_ivanov.011976@postgrespro.ru", "phone": "+70875666959"}
0005435135756	B82C0D	1765 015567	TAMARA KOMAROVA	{"email": "t.komarova-1972@postgrespro.ru", "phone": "+70526993779"}
0005435135757	B82C0D	3814 289459	TATYANA NIKOLAEVA	{"phone": "+70268668219"}
0005435135758	4551DA	3274 285361	ANASTASIYA LAZAREVA	{"email": "alazareva.101979@postgrespro.ru", "phone": "+70154730952"}
0005435135759	F47E27	5155 830811	ALINA LOGINOVA	{"phone": "+70545234785"}
0005435135760	F47E27	4428 352033	SVETLANA VOROBEVA	{"phone": "+70927276242"}
0005435135761	54C2F1	6013 803399	ALEKSANDR EGOROV	{"email": "aegorov-1980@postgrespro.ru", "phone": "+70353017310"}
0005435135762	42533C	3564 380920	OLGA ALEKSANDROVA	{"phone": "+70001994941"}
0005435135763	52815A	1663 367757	ROMAN BORISOV	{"email": "rborisov-051973@postgrespro.ru", "phone": "+70768216075"}
0005435135764	060573	4348 555750	OLEG SERGEEV	{"email": "o_sergeev_1979@postgrespro.ru", "phone": "+70298213229"}
0005435135765	D484AA	3188 446935	VLADISLAV KUZNECOV	{"email": "kuznecovv_071972@postgrespro.ru", "phone": "+70663401505"}
0005435135766	820DCC	5626 894995	ANTONINA EFREMOVA	{"phone": "+70066498196"}
0005435135767	6CCE1D	7887 965049	VADIM FEDOROV	{"phone": "+70019694913"}
0005435135768	626E0C	8857 049381	NADEZHDA AFANASEVA	{"email": "nadezhdaafanaseva11101969@postgrespro.ru", "phone": "+70612849535"}
0005435135769	D6CAA7	1209 677354	IVAN MARTYNOV	{"email": "i_martynov.121973@postgrespro.ru", "phone": "+70848839645"}
0005435135770	255813	9553 052243	LYUBOV NAUMOVA	{"email": "lyubov-naumova-1964@postgrespro.ru", "phone": "+70354943087"}
0005435135771	C62906	4022 084144	LEYLA SMIRNOVA	{"email": "smirnova.l_1964@postgrespro.ru", "phone": "+70475365268"}
0005435135772	8929E6	7205 452086	KLAVDIYA KUZMINA	{"email": "klavdiya-kuzmina_1974@postgrespro.ru", "phone": "+70484642557"}
0005435135773	5B5537	8358 561435	RAISA GERASIMOVA	{"phone": "+70156656225"}
0005435135774	B48C96	0623 974559	DMITRIY KUZNECOV	{"email": "dmitriy_kuznecov22111986@postgrespro.ru", "phone": "+70260402725"}
0005435135775	B48C96	3099 148642	IGOR BONDARENKO	{"email": "bondarenko-igor-1973@postgrespro.ru", "phone": "+70847321065"}
0005435135776	E858D1	1054 424392	ARTEM VLASOV	{"phone": "+70893007864"}
0005435135777	FC3CEC	6817 519274	MAKSIM MIRONOV	{"email": "mironovmaksim10071981@postgrespro.ru", "phone": "+70409135157"}
0005435135778	FC3CEC	9809 639122	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko_15121970@postgrespro.ru", "phone": "+70782125006"}
0005435135779	FC3CEC	2826 409096	MARIYA KISELEVA	{"email": "kiseleva.m.1971@postgrespro.ru", "phone": "+70729828019"}
0005435135780	D0B2C2	9716 981398	NIKOLAY SEMENOV	{"phone": "+70004475086"}
0005435135781	EAA488	3279 949636	VLADISLAV KRASNOV	{"email": "v.krasnov1964@postgrespro.ru", "phone": "+70587534305"}
0005435142488	B5B6B8	7051 153434	OLGA SOKOLOVA	{"phone": "+70675362604"}
0005435135782	D72BC4	8351 923101	KONSTANTIN IVANOV	{"email": "ivanovk-071975@postgrespro.ru", "phone": "+70032835532"}
0005435135783	D72BC4	9162 636445	VALENTIN KOROLEV	{"phone": "+70306927926"}
0005435135784	D72BC4	3384 314495	LYUDMILA MATVEEVA	{"phone": "+70403780239"}
0005435135785	0EAD0D	1983 155923	PETR GUSEV	{"email": "petr_gusev-1969@postgrespro.ru", "phone": "+70757500840"}
0005435135786	FDBEA3	3798 401882	YULIYA YUDINA	{"email": "yuliya.yudina.051965@postgrespro.ru", "phone": "+70086312213"}
0005435135787	3E6731	2579 946542	ELENA TARASOVA	{"phone": "+70746644261"}
0005435135788	5C2914	5611 647389	ELENA TIMOFEEVA	{"email": "timofeeva.e_091981@postgrespro.ru", "phone": "+70203458831"}
0005435135789	1AEC75	0641 534420	VADIM VOLKOV	{"phone": "+70062213125"}
0005435135790	1AEC75	2790 071828	SERGEY GRIGOREV	{"phone": "+70614040998"}
0005435135791	D35DD7	6564 718712	ALEKSANDR KUZNECOV	{"phone": "+70355990563"}
0005435135792	A89CEE	6184 043253	VALENTINA KULIKOVA	{"email": "v-kulikova041966@postgrespro.ru", "phone": "+70977882232"}
0005435135793	E1F3EE	4996 760688	RUSLAN AFANASEV	{"phone": "+70135438136"}
0005435135794	E1F3EE	1098 987880	DIANA ZAKHAROVA	{"email": "zakharova.diana_091988@postgrespro.ru", "phone": "+70728707740"}
0005435135795	218487	5564 920527	IGOR OSIPOV	{"phone": "+70071486787"}
0005435135796	F3CBA2	9320 475692	VASILIY PAVLOV	{"phone": "+70347026631"}
0005435135797	8BC30F	1513 640365	SERGEY FOMIN	{"phone": "+70253863074"}
0005435135798	6D408F	8121 346929	NATALYA STEPANOVA	{"email": "stepanova_natalya_1978@postgrespro.ru", "phone": "+70798581376"}
0005435135799	976013	7983 611936	ELENA DENISOVA	{"phone": "+70220783441"}
0005435135800	FB4EE0	2969 036612	NATALYA TARASOVA	{"email": "n_tarasova.011963@postgrespro.ru", "phone": "+70174514916"}
0005435135801	E21434	1591 214535	NADEZHDA ISAEVA	{"email": "isaevanadezhda.1970@postgrespro.ru", "phone": "+70861373781"}
0005435135802	E21434	9457 443606	NIKOLAY POPOV	{"email": "popovnikolay_121975@postgrespro.ru", "phone": "+70179791636"}
0005435135803	83CC8A	7818 608687	OLGA MELNIKOVA	{"email": "olga.melnikova.1976@postgrespro.ru", "phone": "+70579887441"}
0005435135804	F1A80D	1113 643312	SERGEY VLASOV	{"phone": "+70690427402"}
0005435135805	F1A80D	5111 707996	LILIYA NIKOLAEVA	{"phone": "+70266836776"}
0005435135806	1DF120	6124 388065	SERGEY PETROV	{"phone": "+70190823002"}
0005435135807	FCF3A4	4279 049815	MIKHAIL TARASOV	{"phone": "+70931559868"}
0005435135808	1B08DF	1582 106127	MAKAR NAZAROV	{"email": "nazarovmakar_111985@postgrespro.ru", "phone": "+70595268758"}
0005435135809	1B08DF	0786 098008	ELENA NOVIKOVA	{"email": "elena-novikova-19051976@postgrespro.ru", "phone": "+70717106623"}
0005435142344	B4F9C8	8114 886065	IRINA POLYAKOVA	{"phone": "+70770225052"}
0005435142335	0ACF38	2256 932087	YURIY IVANOV	{"email": "y.ivanov-29041982@postgrespro.ru", "phone": "+70296221760"}
0005435142336	22D689	5324 155239	MARINA KUZNECOVA	{"email": "kuznecovamarina.1970@postgrespro.ru", "phone": "+70821392227"}
0005435142337	58F78B	6363 520111	NATALYA KOMAROVA	{"phone": "+70290802481"}
0005435142338	58F78B	0152 167503	ANDREY SMIRNOV	{"email": "smirnov_a_07111974@postgrespro.ru", "phone": "+70208536094"}
0005435142339	6A9737	4012 297392	MIKHAIL FEDOROV	{"email": "fedorov-mikhail_051966@postgrespro.ru", "phone": "+70287826222"}
0005435142340	C2290E	4443 364635	MIKHAIL MIKHAYLOV	{"email": "mikhaylov_mikhail_1982@postgrespro.ru", "phone": "+70346654102"}
0005435142341	012EB6	4889 930484	TAMARA MARTYNOVA	{"phone": "+70856886512"}
0005435142342	464466	6810 250745	ALEKSEY AFANASEV	{"email": "aafanasev-31011980@postgrespro.ru", "phone": "+70663999200"}
0005435142343	037B30	3714 468997	MIKHAIL KUZMIN	{"email": "kuzmin_mikhail31011961@postgrespro.ru", "phone": "+70983149382"}
0005435142345	8EB336	6384 582688	ANATOLIY VOROBEV	{"email": "a.vorobev021964@postgrespro.ru", "phone": "+70797979038"}
0005435142346	8EB336	3056 568935	ANDREY DENISOV	{"phone": "+70545877503"}
0005435142347	5D3A58	7461 402383	LARISA KARPOVA	{"phone": "+70488637085"}
0005435142348	8EC62E	7223 876426	OLEG POPOV	{"phone": "+70643737406"}
0005435142349	63357E	0442 753301	ALEKSANDR FEDOROV	{"email": "aleksandr_fedorov-01051969@postgrespro.ru", "phone": "+70411666900"}
0005435142350	63357E	8094 292677	EVGENIY CHERNOV	{"email": "chernovevgeniy-1978@postgrespro.ru", "phone": "+70343195084"}
0005435142351	9AC4AC	8191 794013	ELIZAVETA SERGEEVA	{"phone": "+70745880767"}
0005435142352	9AC4AC	6255 764161	VIKTORIYA LEBEDEVA	{"email": "viktoriya_lebedeva-081965@postgrespro.ru", "phone": "+70045567518"}
0005435142353	24B887	6214 464548	POLINA ILINA	{"email": "pilina121967@postgrespro.ru", "phone": "+70812736456"}
0005435142354	57A4ED	8347 792941	IGOR ANDREEV	{"phone": "+70684227301"}
0005435142355	15B47A	6744 476107	VALERIY ZAYCEV	{"email": "zaycev-v21041968@postgrespro.ru", "phone": "+70034416375"}
0005435142356	15B47A	1300 914552	VIKTOR FILIPPOV	{"email": "filippovv071967@postgrespro.ru", "phone": "+70073431992"}
0005435142357	E47B3F	4459 742969	ELIZAVETA OSIPOVA	{"email": "osipova-e061974@postgrespro.ru", "phone": "+70438868158"}
0005435142358	7CCDAB	5452 450842	IVAN GERASIMOV	{"email": "ivan_gerasimov.1964@postgrespro.ru", "phone": "+70325014971"}
0005435142359	BA73EC	0827 072538	NADEZHDA LAZAREVA	{"phone": "+70628838204"}
0005435142360	C50F7F	9140 543566	ANASTASIYA DANILOVA	{"email": "a-danilova_1973@postgrespro.ru", "phone": "+70551915703"}
0005435142361	C50F7F	4406 867656	NATALYA KAZAKOVA	{"phone": "+70718927796"}
0005435142362	A2A5F6	8742 079289	SVETLANA MELNIKOVA	{"phone": "+70856909198"}
0005435142363	5471D6	7861 362296	ELENA FILATOVA	{"email": "filatova.e.101972@postgrespro.ru", "phone": "+70040374653"}
0005435142364	9111BA	2967 095911	MARIYA ZAYCEVA	{"phone": "+70528138419"}
0005435142365	185946	9846 975617	IGOR SAVELEV	{"email": "i_savelev_011968@postgrespro.ru", "phone": "+70613531196"}
0005435142366	ECDC80	5981 374305	NATALIYA POPOVA	{"phone": "+70382544038"}
0005435142367	971637	1840 561506	VALENTINA VASILEVA	{"email": "vasileva_valentina-11101977@postgrespro.ru", "phone": "+70362926112"}
0005435142368	971637	3933 791753	ELENA ISAEVA	{"phone": "+70705328550"}
0005435142369	EA7F4D	0237 459724	ALEKSANDR NOVIKOV	{"phone": "+70172671618"}
0005435142370	A3E832	0763 548146	EVGENIYA ALEKSEEVA	{"email": "evgeniya-alekseeva1968@postgrespro.ru", "phone": "+70930735943"}
0005435142371	A3E832	7390 962251	ANNA NIKOLAEVA	{"email": "nikolaeva_anna.1975@postgrespro.ru", "phone": "+70404559336"}
0005435142372	FCD6B4	2199 559633	VLADIMIR KUZNECOV	{"email": "kuznecov_v-101972@postgrespro.ru", "phone": "+70465091205"}
0005435142373	940347	1422 922810	VALERIY POPOV	{"email": "valeriy.popov_1972@postgrespro.ru", "phone": "+70379374864"}
0005435142374	CAE8B9	1405 669489	IRINA SIDOROVA	{"phone": "+70665162448"}
0005435142375	EFF498	6436 226826	VITALIY MARTYNOV	{"email": "martynov_v_20101969@postgrespro.ru", "phone": "+70336452308"}
0005435142376	EFF498	4130 570123	MARIYA LOGINOVA	{"phone": "+70451857079"}
0005435142377	1143E3	0265 222606	YURIY EGOROV	{"email": "egorov-y-02051974@postgrespro.ru", "phone": "+70201992815"}
0005435142378	1143E3	7535 793557	ELENA BOGDANOVA	{"phone": "+70752563816"}
0005435142379	AAEDE8	2757 419922	NATALYA BOGDANOVA	{"email": "bogdanovanatalya-09121972@postgrespro.ru", "phone": "+70511341946"}
0005435142380	AAEDE8	0973 275725	BORIS BELOV	{"phone": "+70144567782"}
0005435142381	AAEDE8	0279 583746	ARTEMIY ZAKHAROV	{"phone": "+70309636298"}
0005435142382	62F4E3	1441 291093	YURIY SIDOROV	{"email": "sidorovy.28121983@postgrespro.ru", "phone": "+70485472666"}
0005435142383	62F4E3	2680 972173	ANNA RODIONOVA	{"phone": "+70151138098"}
0005435142384	74CCAA	6734 619152	TATYANA BARANOVA	{"email": "tbaranova-041967@postgrespro.ru", "phone": "+70098502978"}
0005435142385	343D0F	1329 430500	TATYANA GRISHINA	{"email": "grishina_t.06091981@postgrespro.ru", "phone": "+70301727585"}
0005435142386	516D54	7004 426035	VITALIY VASILEV	{"email": "vasilevvitaliy021978@postgrespro.ru", "phone": "+70753251100"}
0005435142387	516D54	6602 770231	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev.061970@postgrespro.ru", "phone": "+70070918405"}
0005435142388	516D54	3910 054066	SVETLANA DMITRIEVA	{"phone": "+70154870253"}
0005435142389	77F8EE	4785 119127	PAVEL POPOV	{"phone": "+70005227015"}
0005435142390	C9B500	4872 295413	IGOR KUZNECOV	{"phone": "+70766662722"}
0005435142391	C9B500	5020 090807	NADEZHDA ILINA	{"email": "n_ilina-13081966@postgrespro.ru", "phone": "+70648310111"}
0005435142392	D1C41A	6042 809796	ANDREY MAKSIMOV	{"phone": "+70862401703"}
0005435142393	D1C41A	6466 103387	NATALYA MOISEEVA	{"email": "moiseeva.n-19021989@postgrespro.ru", "phone": "+70659310268"}
0005435142394	643C65	4915 070487	ALEKSANDR POPOV	{"email": "popovaleksandr-15011974@postgrespro.ru", "phone": "+70776840000"}
0005435142395	89E008	1034 381363	TATYANA MAKSIMOVA	{"phone": "+70612855606"}
0005435142396	89E008	4549 028011	ELENA SEMENOVA	{"email": "semenova_elena-071968@postgrespro.ru", "phone": "+70988498654"}
0005435142397	0DE93F	8940 191838	ALEKSANDR GUSEV	{"phone": "+70904045205"}
0005435142398	9B8699	7529 287121	MIKHAIL KRASNOV	{"phone": "+70046648667"}
0005435142399	A2069D	1443 867780	ROZALIYA GERASIMOVA	{"phone": "+70444766450"}
0005435142400	A2069D	6875 690656	NIKOLAY GORBUNOV	{"email": "gorbunov-n-1975@postgrespro.ru", "phone": "+70795590664"}
0005435142401	903291	3262 054792	ANTONINA RYABOVA	{"email": "ryabova-a1980@postgrespro.ru", "phone": "+70637733510"}
0005435142402	020E2A	7189 662728	ANATOLIY KOROLEV	{"email": "a_korolev.01121978@postgrespro.ru", "phone": "+70971828091"}
0005435142403	A0A4B7	0855 731758	LIDIYA MATVEEVA	{"phone": "+70409417904"}
0005435142404	A0A4B7	3853 794958	ELENA IVANOVA	{"email": "elenaivanova.1981@postgrespro.ru", "phone": "+70635658917"}
0005435142405	9DA257	8281 017943	NIKOLAY SIDOROV	{"phone": "+70709962599"}
0005435142406	9F867D	1008 619197	NATALYA IVANOVA	{"phone": "+70492677836"}
0005435142407	CD4060	4950 546879	DARYA RYABOVA	{"phone": "+70564522869"}
0005435142408	CC4B60	8825 557768	VERA VASILEVA	{"email": "v.vasileva1980@postgrespro.ru", "phone": "+70151260737"}
0005435142409	1EA901	0277 697772	ZHANNA VOLKOVA	{"phone": "+70641051845"}
0005435142410	1EA901	2670 238614	TATYANA IVANOVA	{"phone": "+70371542098"}
0005435142411	1EA901	0654 741734	PAVEL ZHUKOV	{"phone": "+70559515613"}
0005435142412	8D2A8D	6257 372843	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov_20011968@postgrespro.ru", "phone": "+70707607146"}
0005435142413	BFFA1E	9025 011429	ANDREY FEDOROV	{"email": "andrey.fedorov-1968@postgrespro.ru", "phone": "+70415238796"}
0005435142414	27A604	1170 839655	VIKTOR SCHERBAKOV	{"phone": "+70638829941"}
0005435142415	27A604	0849 146040	VERA SOROKINA	{"email": "v_sorokina-1975@postgrespro.ru", "phone": "+70279901311"}
0005435142416	33CD7D	1680 051148	LYUBOV MAKAROVA	{"email": "makarova_lyubov_28031969@postgrespro.ru", "phone": "+70376168786"}
0005435142417	29913E	2041 366621	ALEKSEY KISELEV	{"phone": "+70280038146"}
0005435142418	BFC174	1140 563068	SERGEY SMIRNOV	{"email": "sergeysmirnov-1971@postgrespro.ru", "phone": "+70271898106"}
0005435142419	BFC174	6655 899591	VASILIY NIKOLAEV	{"phone": "+70208452043"}
0005435142420	69BED9	6184 433338	DANILA NOVIKOV	{"email": "danila-novikov-26091978@postgrespro.ru", "phone": "+70728481412"}
0005435142421	75FBCD	9979 878476	MARIYA SOROKINA	{"phone": "+70198760282"}
0005435142422	75FBCD	1677 137508	IVAN IVANOV	{"email": "ivanov-ivan1966@postgrespro.ru", "phone": "+70562962479"}
0005435142423	D1451A	4560 492386	NATALYA NIKIFOROVA	{"phone": "+70282467220"}
0005435142424	D1451A	2141 643986	SERGEY EGOROV	{"email": "s_egorov-111953@postgrespro.ru", "phone": "+70658585635"}
0005435142425	24CFA3	8549 530198	ALEKSEY SOLOVEV	{"email": "solovev_aleksey.1974@postgrespro.ru", "phone": "+70497242287"}
0005435142426	099E22	0621 819159	SERGEY ANTONOV	{"phone": "+70390923279"}
0005435142427	099E22	5153 654684	ANASTASIYA SEMENOVA	{"email": "semenova_anastasiya-1977@postgrespro.ru", "phone": "+70612627207"}
0005435142428	CC1EB6	6930 771719	VYACHESLAV KUZNECOV	{"phone": "+70233853689"}
0005435142429	213197	3667 451669	ELIZAVETA IVANOVA	{"phone": "+70950473331"}
0005435142430	213197	2273 749059	NIKOLAY VOLKOV	{"phone": "+70469197875"}
0005435142431	04BDD9	7092 532597	ANATOLIY ILIN	{"email": "anatoliyilin_041971@postgrespro.ru", "phone": "+70836301910"}
0005435142432	04A0B1	8020 024522	ALEKSANDR ANDREEV	{"email": "andreev.a30011982@postgrespro.ru", "phone": "+70310932709"}
0005435142433	2A6F78	6143 291128	VALENTINA IVANOVA	{"email": "v.ivanova011967@postgrespro.ru", "phone": "+70586045833"}
0005435142434	FE12F0	8006 945317	GALINA VOLKOVA	{"email": "volkova-g-31081973@postgrespro.ru", "phone": "+70174207688"}
0005435142435	B3E311	6598 003319	DARYA KISELEVA	{"email": "kiseleva-d091981@postgrespro.ru", "phone": "+70868719485"}
0005435142436	FB98AF	8226 376274	GALINA VASILEVA	{"phone": "+70434224209"}
0005435142437	1BA307	5948 397220	TATYANA FOMINA	{"phone": "+70022192813"}
0005435142438	8F74D3	4971 255757	LYUBOV IVANOVA	{"phone": "+70878318192"}
0005435142439	ABFF7F	1455 864102	ELENA FROLOVA	{"phone": "+70043440886"}
0005435142440	ABFF7F	5023 716504	BORIS GORBUNOV	{"phone": "+70121283908"}
0005435142441	D2FA9A	3702 060688	NIKOLAY ALEKSEEV	{"email": "nalekseev_05101974@postgrespro.ru", "phone": "+70565495703"}
0005435142442	A3D648	2240 711192	NATALYA PETROVA	{"email": "petrova_natalya-27051983@postgrespro.ru", "phone": "+70926335713"}
0005435142443	CC094B	8232 641287	ALEKSANDR GUSEV	{"email": "a-gusev-031980@postgrespro.ru", "phone": "+70275336200"}
0005435142444	8D8F59	5739 620960	GALINA KUZNECOVA	{"phone": "+70395442318"}
0005435142445	FF5E39	7347 370211	ELIZAVETA KUDRYASHOVA	{"email": "e-kudryashova_1971@postgrespro.ru", "phone": "+70635567107"}
0005435142446	FF5E39	1605 714339	NIKITA IVANOV	{"phone": "+70216139713"}
0005435142447	5EB0BF	8602 119211	NIKOLAY ANDREEV	{"email": "nikolay_andreev1978@postgrespro.ru", "phone": "+70039822877"}
0005435142448	7D8D96	1534 028159	DANIL KUZNECOV	{"email": "d-kuznecov19061966@postgrespro.ru", "phone": "+70038036235"}
0005435142449	1AF862	0416 909060	IRINA SEMENOVA	{"email": "irina_semenova-071977@postgrespro.ru", "phone": "+70168082224"}
0005435142450	2FAE67	2070 020690	MIKHAIL KISELEV	{"email": "mikhail_kiselev.16101972@postgrespro.ru", "phone": "+70731849766"}
0005435142451	17BBD6	5587 777032	OLGA MIKHAYLOVA	{"phone": "+70208782619"}
0005435142452	DDC7D2	8281 470977	ALEKSANDR ORLOV	{"email": "orlov.a.021969@postgrespro.ru", "phone": "+70281521191"}
0005435142453	DDC7D2	6326 286307	OLGA KOZLOVA	{"email": "okozlova_1953@postgrespro.ru", "phone": "+70632305968"}
0005435142454	A97927	3250 365100	NADEZHDA BOGDANOVA	{"phone": "+70537337319"}
0005435142455	A97927	8137 970621	RASHID MOISEEV	{"phone": "+70811519765"}
0005435142456	6806F3	4795 623899	NIKOLAY NIKOLAEV	{"phone": "+70738601757"}
0005435142457	3F8774	9658 858852	SERGEY NIKITIN	{"phone": "+70652066813"}
0005435142458	3F8774	6512 958275	ALEVTINA LOGINOVA	{"email": "a_loginova12091969@postgrespro.ru", "phone": "+70350579630"}
0005435142459	1772BD	7166 878867	ALEKSANDRA EGOROVA	{"email": "egorova_aleksandra-1977@postgrespro.ru", "phone": "+70271840549"}
0005435142460	464151	9516 134458	VYACHESLAV IVANOV	{"phone": "+70859449449"}
0005435142461	464151	1198 446701	YULIYA PAVLOVA	{"phone": "+70616083392"}
0005435142462	13C208	9008 634490	KONSTANTIN BARANOV	{"email": "konstantin.baranov_27061966@postgrespro.ru", "phone": "+70618391566"}
0005435142463	CF2A24	4838 449230	SVETLANA KAZAKOVA	{"phone": "+70964919075"}
0005435142464	CF2A24	6709 146072	NINA TARASOVA	{"email": "n-tarasova05011974@postgrespro.ru", "phone": "+70387638155"}
0005435142465	CF2A24	0017 582900	MARIYA KUZMINA	{"email": "mkuzmina-011970@postgrespro.ru", "phone": "+70453265201"}
0005435142466	FFCF05	4679 235511	ELENA BORISOVA	{"email": "borisova_elena_1963@postgrespro.ru", "phone": "+70562676347"}
0005435142467	80626A	8814 659897	SERGEY NOVIKOV	{"phone": "+70652953027"}
0005435142468	E0D74E	6828 932866	IVAN EGOROV	{"phone": "+70224778465"}
0005435142469	25FE7F	0944 858913	VASILIY ALEKSEEV	{"phone": "+70899223648"}
0005435142470	434EDE	5306 594805	KSENIYA ZOTOVA	{"phone": "+70192611861"}
0005435142471	434EDE	7497 388321	ANASTASIYA OSIPOVA	{"email": "osipova.a-021972@postgrespro.ru", "phone": "+70028080525"}
0005435142472	75D579	5079 282064	VLADIMIR ILIN	{"email": "vladimirilin.28101966@postgrespro.ru", "phone": "+70170444645"}
0005435142473	75D579	7043 415079	VERA PETROVA	{"email": "v-petrova_061978@postgrespro.ru", "phone": "+70663193261"}
0005435142474	81D7CB	8927 019621	MARIYA ZAKHAROVA	{"email": "zakharova.m-09121973@postgrespro.ru", "phone": "+70517721739"}
0005435142475	5F0F6E	9051 503478	EVGENIYA MIRONOVA	{"phone": "+70798931400"}
0005435142476	76A19E	3760 891298	ALEKSEY KOZLOV	{"email": "alekseykozlov.011970@postgrespro.ru", "phone": "+70049044422"}
0005435142477	76A19E	5251 530388	RENAT MOROZOV	{"phone": "+70053204636"}
0005435142478	D20A3F	9631 526593	ELENA EGOROVA	{"phone": "+70582612719"}
0005435142479	B403F8	4701 157858	VERA ZHUKOVA	{"phone": "+70247373504"}
0005435142480	4A35DE	6147 819518	ARTEM BARANOV	{"email": "baranov_a-24021965@postgrespro.ru", "phone": "+70317652174"}
0005435142481	DE4D19	1300 864529	ELENA EGOROVA	{"phone": "+70593616613"}
0005435142482	BBDE79	1143 879259	SERGEY MAKAROV	{"email": "makarov-sergey.091971@postgrespro.ru", "phone": "+70798190375"}
0005435142483	5D7A87	2073 094472	TATYANA MATVEEVA	{"phone": "+70264166719"}
0005435142484	5D7A87	9211 087015	VLADISLAV ORLOV	{"phone": "+70219400700"}
0005435142485	5D7A87	7409 543165	SERGEY ALEKSANDROV	{"phone": "+70108183172"}
0005435142486	623241	0472 009658	DANIIL CHERNOV	{"phone": "+70781182630"}
0005435142487	03A3FC	5121 632514	VERA PETROVA	{"email": "petrova-vera-1979@postgrespro.ru", "phone": "+70764973502"}
0005435142489	DCC5B3	5863 455421	OLGA GORBUNOVA	{"phone": "+70430286993"}
0005435142490	DCC5B3	3017 719492	ALEKSANDR VASILEV	{"phone": "+70406167480"}
0005435142491	DCC5B3	5222 998165	KONSTANTIN IVANOV	{"phone": "+70298211135"}
0005435142492	11318F	0627 994741	DMITRIY NIKITIN	{"email": "dmitriy.nikitin-011978@postgrespro.ru", "phone": "+70671850270"}
0005435142493	5CD723	3214 063038	MATVEY MATVEEV	{"phone": "+70077552380"}
0005435142494	5CD723	8910 211104	OLGA ORLOVA	{"email": "o-orlova_021968@postgrespro.ru", "phone": "+70605093466"}
0005435142495	F4FD50	6182 284649	EGOR SHEVCHENKO	{"email": "e-shevchenko-021974@postgrespro.ru", "phone": "+70225112558"}
0005435142496	4FEA43	1375 387718	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr_1969@postgrespro.ru", "phone": "+70111625708"}
0005435142497	970EAE	2544 666342	NIKOLAY NIKOLAEV	{"phone": "+70049018497"}
0005435142498	3CD654	4756 258175	ANASTASIYA GERASIMOVA	{"phone": "+70358935298"}
0005435142499	0F0F8D	7025 703609	IRINA ANDREEVA	{"phone": "+70375574532"}
0005435142500	B7463D	8213 835934	DANILA POPOV	{"phone": "+70581320123"}
0005435142501	906867	6779 839739	ANNA KAZAKOVA	{"email": "kazakova-a1972@postgrespro.ru", "phone": "+70960065329"}
0005435142502	906867	9287 117349	DMITRIY VASILEV	{"phone": "+70194653511"}
0005435142503	381704	1085 404890	DMITRIY YAKOVLEV	{"phone": "+70566221301"}
0005435142504	381704	4975 786772	TATYANA BELOVA	{"phone": "+70154803694"}
0005435142505	364E5C	1818 173988	NATALYA GERASIMOVA	{"phone": "+70317514147"}
0005435142506	4B5B96	4964 247951	IGOR MAKAROV	{"phone": "+70138817025"}
0005435142507	BE40E7	8549 606925	TIMOFEY DAVYDOV	{"phone": "+70102061057"}
0005435142508	BE40E7	9230 564385	LYUDMILA SMIRNOVA	{"phone": "+70867258197"}
0005435142509	D4EB29	6605 925098	STEPAN ANTONOV	{"phone": "+70635525638"}
0005435142510	D4EB29	4767 514235	YURIY MAKSIMOV	{"email": "maksimov-y1973@postgrespro.ru", "phone": "+70214601005"}
0005435142511	55B212	8209 745819	ANASTASIYA ANDREEVA	{"email": "andreeva-a.02081979@postgrespro.ru", "phone": "+70331719812"}
0005435142512	55B212	7767 688227	SERGEY KULIKOV	{"email": "kulikov-s_1990@postgrespro.ru", "phone": "+70210481244"}
0005435142739	0AA853	8615 478721	NELLYA ARKHIPOVA	{"phone": "+70430064409"}
0005435142964	12DD3C	3493 776488	VLADIMIR IVANOV	{"phone": "+70633711603"}
0005435142513	0510FD	2930 428272	VLADIMIR BONDARENKO	{"email": "bondarenko.v.051976@postgrespro.ru", "phone": "+70600806955"}
0005435142514	CF0C83	5206 517025	ANDREY ZAKHAROV	{"email": "andrey-zakharov-091972@postgrespro.ru", "phone": "+70953331464"}
0005435142515	F52114	2571 050633	YULIYA EGOROVA	{"phone": "+70226661821"}
0005435142516	F52114	2451 443085	NIKOLAY KUZMIN	{"email": "kuzmin.nikolay1979@postgrespro.ru", "phone": "+70615858129"}
0005435142517	F52114	5645 513457	ZINAIDA MARTYNOVA	{"email": "martynovazinaida121972@postgrespro.ru", "phone": "+70683055659"}
0005435142518	3A5D8A	8744 212872	OLGA VLASOVA	{"email": "olga.vlasova18051977@postgrespro.ru", "phone": "+70964640354"}
0005435142519	CA1DC9	7063 879947	ANASTASIYA KULIKOVA	{"phone": "+70311020447"}
0005435142520	CA1DC9	7204 494641	NATALYA POTAPOVA	{"email": "n_potapova24111971@postgrespro.ru", "phone": "+70216800988"}
0005435142521	CA1DC9	0095 775020	NATALYA VOLKOVA	{"phone": "+70657301432"}
0005435142522	CA1DC9	0810 251339	VALERIYA IVANOVA	{"phone": "+70863525639"}
0005435142523	8615BB	4241 380017	ALEKSANDR IVANOV	{"email": "a-ivanov.27091969@postgrespro.ru", "phone": "+70389216952"}
0005435142524	EA0B8B	3042 932505	ULYANA RYABOVA	{"email": "u.ryabova.1967@postgrespro.ru", "phone": "+70761336336"}
0005435142525	EA0B8B	8222 888885	ALEKSANDR KONOVALOV	{"phone": "+70820690647"}
0005435142526	EA0B8B	1654 857918	EGOR ZHUKOV	{"phone": "+70805335522"}
0005435142527	EA0B8B	6667 175114	GALINA KUZNECOVA	{"phone": "+70018632100"}
0005435142528	B233A8	8293 972483	MIKHAIL KUDRYASHOV	{"phone": "+70941158806"}
0005435142529	B233A8	0122 174745	ANASTASIYA VOLKOVA	{"phone": "+70545582697"}
0005435142530	07F35A	0497 063090	RAISA ARKHIPOVA	{"email": "arkhipovaraisa.19031971@postgrespro.ru", "phone": "+70989176544"}
0005435142531	07F35A	3754 216354	VLADIMIR PETROV	{"email": "vladimirpetrov_1974@postgrespro.ru", "phone": "+70962892354"}
0005435142532	971CC4	3100 089952	ALEKSANDR DMITRIEV	{"email": "aleksandr_dmitriev-31121978@postgrespro.ru", "phone": "+70048765073"}
0005435142533	971CC4	6679 641586	ALEKSEY SOROKIN	{"email": "aleksey_sorokin_111974@postgrespro.ru", "phone": "+70874209190"}
0005435142534	BEC398	8287 882683	ALEKSANDR MARTYNOV	{"phone": "+70181952153"}
0005435142535	BEC398	4855 751921	ROMAN SCHERBAKOV	{"email": "roman.scherbakov1974@postgrespro.ru", "phone": "+70080565516"}
0005435142536	61124F	2198 968775	VERA ERMAKOVA	{"phone": "+70134787921"}
0005435142537	B74891	7287 240639	VITALIY SMIRNOV	{"phone": "+70753174217"}
0005435142538	B74891	7846 328827	ALEKSEY KUZNECOV	{"phone": "+70285498620"}
0005435142539	FFD85C	0331 523232	ELENA KONOVALOVA	{"phone": "+70032419280"}
0005435142540	FA00F0	3511 318878	ANDREY KUZNECOV	{"phone": "+70926534173"}
0005435142541	FA00F0	8432 034033	DMITRIY MOISEEV	{"email": "moiseev-d-06121976@postgrespro.ru", "phone": "+70926023904"}
0005435142542	8858E9	5811 178049	PAVEL TARASOV	{"phone": "+70495593302"}
0005435142543	F6D106	6846 704768	SERGEY YAKOVLEV	{"email": "s_yakovlev1972@postgrespro.ru", "phone": "+70109151833"}
0005435142544	F6D106	0316 972491	VALENTINA BOGDANOVA	{"phone": "+70410031399"}
0005435142545	F068E0	7472 795374	ALEKSANDR STEPANOV	{"email": "stepanov.a1968@postgrespro.ru", "phone": "+70995037775"}
0005435142546	F068E0	5300 698083	TATYANA NAZAROVA	{"phone": "+70664137745"}
0005435142547	CB6C92	6176 237590	NIKOLAY ZHUKOV	{"phone": "+70496795956"}
0005435142548	B4C024	8531 228638	DARYA ZHUKOVA	{"email": "zhukova.darya_1968@postgrespro.ru", "phone": "+70990524500"}
0005435142610	C576EB	0547 184375	OLGA FOMINA	{"phone": "+70971773694"}
0005435142549	256231	3250 102373	ALEKSANDR STEPANOV	{"email": "astepanov06111983@postgrespro.ru", "phone": "+70987783849"}
0005435142550	0686E2	0477 208274	RADMIR SOLOVEV	{"phone": "+70079813693"}
0005435142551	C77D95	8093 492625	VALENTINA MAKAROVA	{"email": "vmakarova-08021983@postgrespro.ru", "phone": "+70846045557"}
0005435142552	E9C0C7	4623 011635	OLESYA MEDVEDEVA	{"phone": "+70160644125"}
0005435142553	E9C0C7	6358 822312	LYUDMILA ORLOVA	{"email": "orlova.lyudmila.031980@postgrespro.ru", "phone": "+70791029289"}
0005435142554	A848E3	1321 105497	ALEKSEY SEMENOV	{"phone": "+70801429102"}
0005435142555	E4A796	3690 437939	ELENA MEDVEDEVA	{"phone": "+70383721977"}
0005435142556	2C89FA	7229 294941	VERA RYABOVA	{"email": "ryabova_v.1970@postgrespro.ru", "phone": "+70858193435"}
0005435142557	E8E4C9	2440 322908	MIKHAIL DAVYDOV	{"email": "davydov-m061964@postgrespro.ru", "phone": "+70047741471"}
0005435142558	A87B2F	7076 626816	SERGEY ANTONOV	{"email": "sergey_antonov.091971@postgrespro.ru", "phone": "+70486054840"}
0005435142559	4A0E7E	5139 086005	NATALYA MOROZOVA	{"email": "natalya.morozova.11051965@postgrespro.ru", "phone": "+70848520252"}
0005435142560	4A0E7E	5957 914249	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr.1973@postgrespro.ru", "phone": "+70203712230"}
0005435142561	91EDA8	5318 533315	IGOR KONOVALOV	{"phone": "+70291805799"}
0005435142562	91EDA8	4481 665290	GALINA BELOVA	{"phone": "+70662257506"}
0005435142563	32F7E2	2082 526681	MIKHAIL ALEKSEEV	{"email": "alekseevmikhail_051977@postgrespro.ru", "phone": "+70237587873"}
0005435142564	BCE079	4664 862663	EVGENIYA LUKYANOVA	{"email": "lukyanovae_1973@postgrespro.ru", "phone": "+70568264729"}
0005435142565	06176A	5235 861492	INNA IVANOVA	{"phone": "+70032938168"}
0005435142566	06176A	8944 930156	ALEKSANDR ILIN	{"phone": "+70100646155"}
0005435142567	9E758F	0645 825018	PAVEL KARPOV	{"phone": "+70974822793"}
0005435142568	C1BDAA	7342 699089	GYUZEL KAZAKOVA	{"phone": "+70532673584"}
0005435142569	670303	6786 604674	VALENTINA POPOVA	{"email": "popova-v_04091976@postgrespro.ru", "phone": "+70212553518"}
0005435142570	670303	8457 403758	VALERIY VASILEV	{"phone": "+70987197901"}
0005435142571	800574	5220 898226	VYACHESLAV EGOROV	{"email": "v_egorov.021976@postgrespro.ru", "phone": "+70975852834"}
0005435142572	800574	6181 048225	SERGEY KUZNECOV	{"phone": "+70463789945"}
0005435142573	800574	5791 677195	VERA MAKSIMOVA	{"email": "maksimova_v.1981@postgrespro.ru", "phone": "+70724173912"}
0005435142574	BFA482	5708 662065	ANNA SOLOVEVA	{"phone": "+70675929315"}
0005435142575	99CA47	2115 024923	VALENTIN MATVEEV	{"email": "matveev-valentin.1977@postgrespro.ru", "phone": "+70545691888"}
0005435142576	99CA47	1839 764696	LIDIYA TARASOVA	{"email": "l.tarasova121976@postgrespro.ru", "phone": "+70634090351"}
0005435142577	58A3C9	1675 609971	SVETLANA SOKOLOVA	{"phone": "+70392655504"}
0005435142578	58A3C9	1913 052124	ZOYA SIDOROVA	{"phone": "+70646106177"}
0005435142579	AAD364	3000 113389	ANASTASIYA BORISOVA	{"email": "borisovaa_14021956@postgrespro.ru", "phone": "+70711290966"}
0005435142580	C0044E	8209 194039	RAISA NESTEROVA	{"phone": "+70587558835"}
0005435142581	E4D386	5013 872624	ANASTASIYA KOZLOVA	{"phone": "+70741231807"}
0005435142582	4B5854	6802 239879	OLEG KUZNECOV	{"phone": "+70393240520"}
0005435142583	A45014	1118 570476	GALINA SOLOVEVA	{"email": "galina.soloveva_02091971@postgrespro.ru", "phone": "+70585835950"}
0005435142584	8C0A48	1727 636672	ALBINA PETROVA	{"email": "petrova_albina_1969@postgrespro.ru", "phone": "+70746850533"}
0005435142585	C37159	6918 392706	ELENA FILATOVA	{"phone": "+70900444254"}
0005435142586	057124	8147 229589	IRINA MOROZOVA	{"email": "morozova_i-041983@postgrespro.ru", "phone": "+70329918190"}
0005435142587	057124	5611 340821	SVETLANA KONDRATEVA	{"phone": "+70013801795"}
0005435142588	CB3764	8146 650480	YULIYA MIKHAYLOVA	{"email": "mikhaylova.yuliya.011976@postgrespro.ru", "phone": "+70358441058"}
0005435142589	023232	2664 466760	DMITRIY DMITRIEV	{"email": "ddmitriev_1978@postgrespro.ru", "phone": "+70130275641"}
0005435142590	C095B6	7482 768683	EVGENIY KOZLOV	{"phone": "+70260857645"}
0005435142591	937EFE	6561 995888	LYUDMILA FEDOROVA	{"phone": "+70726929558"}
0005435142592	995B51	6651 544195	YURIY VLASOV	{"phone": "+70478711875"}
0005435142593	995B51	8688 280333	IGOR KOZLOV	{"phone": "+70535850799"}
0005435142594	B1F69A	4847 650017	IRINA KOZLOVA	{"phone": "+70993907321"}
0005435142595	B1F69A	3556 469178	PAVEL CHERNOV	{"email": "pavel-chernov021968@postgrespro.ru", "phone": "+70807610252"}
0005435142596	B1F69A	2030 586312	VYACHESLAV ALEKSEEV	{"phone": "+70796660800"}
0005435142597	72773E	0052 814590	TATYANA KUZMINA	{"phone": "+70336510443"}
0005435142598	92BC6C	9103 326709	EDUARD KOROLEV	{"email": "korolev_e.091967@postgrespro.ru", "phone": "+70966330440"}
0005435142599	4CAB1C	5098 920860	ELENA NAZAROVA	{"email": "nazarova_e_101972@postgrespro.ru", "phone": "+70202105757"}
0005435142600	1E252A	8316 374620	ALEKSEY SOROKIN	{"email": "sorokin-a.121972@postgrespro.ru", "phone": "+70395970551"}
0005435142601	F86487	0319 273374	ANTONINA NIKOLAEVA	{"phone": "+70764292640"}
0005435142602	65D58F	5904 732659	ELENA YUDINA	{"email": "e.yudina.101967@postgrespro.ru", "phone": "+70964534579"}
0005435142603	65D58F	3819 454582	VALERIY KOROLEV	{"phone": "+70636022773"}
0005435142604	E6D9DF	9871 123675	ANTON SCHERBAKOV	{"email": "ascherbakov-1957@postgrespro.ru", "phone": "+70074376115"}
0005435142605	E6D9DF	9118 481339	VLADIMIR VASILEV	{"phone": "+70768428256"}
0005435142606	820AA1	4242 114844	ROMAN KONOVALOV	{"email": "roman_konovalov_051960@postgrespro.ru", "phone": "+70058183088"}
0005435142607	4ACE8C	1966 525717	NADEZHDA VLASOVA	{"email": "vlasova.n-1971@postgrespro.ru", "phone": "+70042915647"}
0005435142608	4ACE8C	2672 481838	LIDIYA TIKHONOVA	{"phone": "+70372051493"}
0005435142609	A39595	5885 764637	ALEKSANDR MEDVEDEV	{"phone": "+70486184914"}
0005435142611	CF2F06	3111 411580	MIKHAIL ZAKHAROV	{"phone": "+70197084447"}
0005435142612	87DC48	6154 872326	EKATERINA PAVLOVA	{"phone": "+70800716400"}
0005435142613	6D6423	2699 406492	VALENTINA BELYAEVA	{"email": "belyaeva.valentina_29101965@postgrespro.ru", "phone": "+70357342220"}
0005435142614	869C99	3270 743348	SERGEY VASILEV	{"phone": "+70890224382"}
0005435142615	869C99	5425 023521	OLEG KOZLOV	{"phone": "+70933589856"}
0005435142616	3E2F66	1640 443006	RAISA ZHURAVLEVA	{"phone": "+70555634005"}
0005435142617	3E2F66	8931 440240	NATALYA VASILEVA	{"email": "natalya.vasileva_26021969@postgrespro.ru", "phone": "+70117065353"}
0005435142618	C1CB8B	6685 369691	KIRILL DAVYDOV	{"email": "kirill-davydov1973@postgrespro.ru", "phone": "+70254113871"}
0005435142619	C1CB8B	8721 171076	RAISA KOLESNIKOVA	{"email": "kolesnikova-raisa041979@postgrespro.ru", "phone": "+70273133373"}
0005435142620	9743C8	2687 707510	IGOR MAKAROV	{"phone": "+70035692461"}
0005435142621	29B5B3	1767 197238	ARTEM IVANOV	{"phone": "+70036475859"}
0005435142622	986868	5220 300716	OKSANA GUSEVA	{"email": "oksana.guseva-10111975@postgrespro.ru", "phone": "+70988361141"}
0005435142623	9FB0A4	2921 003086	MIKHAIL GAVRILOV	{"phone": "+70323044563"}
0005435142624	6B5A2F	3013 214515	NADEZHDA ZHURAVLEVA	{"phone": "+70119354578"}
0005435142625	89CCF2	4682 554564	ANTONINA ANTONOVA	{"phone": "+70624595407"}
0005435142626	B07435	7926 471169	ROMAN SOKOLOV	{"email": "sokolov.r071972@postgrespro.ru", "phone": "+70175059847"}
0005435142627	CC28A7	0653 315016	VERONIKA PAVLOVA	{"email": "pavlova-veronika.091973@postgrespro.ru", "phone": "+70297698308"}
0005435142628	AF6DD7	1980 828768	ALEKSANDR KUZMIN	{"phone": "+70031174949"}
0005435142629	15942F	3442 634541	DARYA ROMANOVA	{"email": "romanova.darya03071970@postgrespro.ru", "phone": "+70510267149"}
0005435142630	15942F	3870 234876	VERA VASILEVA	{"phone": "+70683081784"}
0005435142631	51C3AA	2660 281307	TAMARA ANISIMOVA	{"phone": "+70959841909"}
0005435142632	51C3AA	7852 613394	LYUBOV YAKOVLEVA	{"email": "yakovleva-l_071966@postgrespro.ru", "phone": "+70362393701"}
0005435142633	D88285	2475 096845	ALEKSANDR IVANOV	{"phone": "+70993189030"}
0005435142634	D88285	6318 777758	YURIY ILIN	{"email": "ilin_yuriy_29111965@postgrespro.ru", "phone": "+70347286690"}
0005435142635	D88285	4943 922719	KARINA DENISOVA	{"phone": "+70957766697"}
0005435142636	6D22C5	8689 558754	DANILA OSIPOV	{"phone": "+70236378714"}
0005435142637	6D22C5	2660 660676	ALEKSEY FILIPPOV	{"phone": "+70900256463"}
0005435142638	1176BB	0473 322142	ELENA ZHUKOVA	{"phone": "+70828358177"}
0005435142639	DCCF24	8581 199813	ALEKSEY AFANASEV	{"email": "afanasev-a.28051971@postgrespro.ru", "phone": "+70339252051"}
0005435142640	51F040	3941 260300	VASILIY MATVEEV	{"email": "matveev_v.081982@postgrespro.ru", "phone": "+70970989783"}
0005435142641	51F040	4680 833839	PETR FEDOROV	{"phone": "+70036342125"}
0005435142642	9CF0B8	8101 694281	MARIYA ZAKHAROVA	{"phone": "+70597631607"}
0005435142643	9CF0B8	1144 577806	ANNA CHERNOVA	{"phone": "+70070676292"}
0005435142644	4CEE33	2847 385903	EKATERINA ILINA	{"email": "ekaterina-ilina-041968@postgrespro.ru", "phone": "+70079723637"}
0005435142645	B13D1C	4851 166486	ANDREY ILIN	{"phone": "+70673798880"}
0005435142646	BB0C75	7945 525549	LARISA KUZMINA	{"email": "larisa.kuzmina_1983@postgrespro.ru", "phone": "+70556816623"}
0005435142647	225956	0882 017839	ELIZAVETA SOKOLOVA	{"phone": "+70855493933"}
0005435142648	225956	3035 437283	LIDIYA OVCHINNIKOVA	{"email": "lidiya_ovchinnikova-091961@postgrespro.ru", "phone": "+70713596333"}
0005435142649	61B1A3	0044 425625	YURIY ZAKHAROV	{"email": "yuriy_zakharov121976@postgrespro.ru", "phone": "+70826632733"}
0005435142650	F830EF	6199 239316	SERGEY FOMIN	{"email": "fomin_sergey_1970@postgrespro.ru", "phone": "+70321652151"}
0005435142651	B1E31D	7082 752586	VLADISLAV MOISEEV	{"phone": "+70749965960"}
0005435142652	66B5C7	7867 559031	VLADIMIR ILIN	{"email": "v.ilin_031971@postgrespro.ru", "phone": "+70595442589"}
0005435142653	66B5C7	2672 405461	SERGEY MOROZOV	{"phone": "+70494515098"}
0005435142654	4AB00C	2126 980416	ILNUR POPOV	{"email": "popov-i.1987@postgrespro.ru", "phone": "+70042434758"}
0005435142655	A394F5	0653 028986	KONSTANTIN VOROBEV	{"phone": "+70329445198"}
0005435142656	1EAE03	6290 902034	KONSTANTIN NIKITIN	{"phone": "+70997644920"}
0005435142657	CFFAB7	9745 493453	SERGEY STEPANOV	{"email": "sergey_stepanov.27061966@postgrespro.ru", "phone": "+70364144895"}
0005435142658	240DB6	7983 876312	ILYA SOROKIN	{"email": "sorokinilya-021979@postgrespro.ru", "phone": "+70037075317"}
0005435142659	78EFAE	1941 514582	GENNADIY KOZLOV	{"email": "kozlovgennadiy.111966@postgrespro.ru", "phone": "+70545743250"}
0005435142660	78EFAE	4649 704897	OLGA SMIRNOVA	{"phone": "+70908620442"}
0005435142661	5DFE4F	0557 273684	ALEKSANDR MEDVEDEV	{"email": "a.medvedev.1973@postgrespro.ru", "phone": "+70383524408"}
0005435142662	5DFE4F	7064 817580	MIKHAIL VASILEV	{"phone": "+70353527474"}
0005435142663	96056F	4140 372540	ZHANNA ARKHIPOVA	{"phone": "+70314401924"}
0005435142664	02831D	1106 853349	OLGA AFANASEVA	{"email": "afanaseva_o_23101957@postgrespro.ru", "phone": "+70829662073"}
0005435142665	CC8752	3504 618370	VALENTINA KALININA	{"phone": "+70178128659"}
0005435142666	10D6AD	7158 649394	ELENA PAVLOVA	{"email": "elena.pavlova22101974@postgrespro.ru", "phone": "+70321685231"}
0005435142667	780B11	4666 848751	EVGENIY VOLKOV	{"phone": "+70816593032"}
0005435142668	28AC42	8532 647990	EKATERINA POPOVA	{"phone": "+70787123270"}
0005435142669	3F3769	1569 879805	NADEZHDA PAVLOVA	{"email": "n_pavlova-21091966@postgrespro.ru", "phone": "+70733330178"}
0005435142670	3F3769	2214 615752	LARISA KUZMINA	{"email": "kuzmina-l-1971@postgrespro.ru", "phone": "+70696807449"}
0005435142671	3F3769	4350 524502	EVGENIY RODIONOV	{"email": "rodionov_evgeniy_08031965@postgrespro.ru", "phone": "+70362625388"}
0005435142672	765398	6478 119009	OLESYA IVANOVA	{"phone": "+70898061090"}
0005435142673	AD5363	6792 887400	VITALIY FEDOTOV	{"phone": "+70387141871"}
0005435142674	037651	5574 618540	GENNADIY KOZLOV	{"phone": "+70648429467"}
0005435142675	6C02B2	1555 554723	YURIY TIKHONOV	{"email": "tikhonovyuriy_071972@postgrespro.ru", "phone": "+70903843765"}
0005435142676	4A1BBF	9922 363268	DENIS ANDREEV	{"phone": "+70850397370"}
0005435142677	3FBDB2	8644 236549	MARINA NOVIKOVA	{"phone": "+70296334574"}
0005435142678	F2BA00	3695 564270	VALERIY MOROZOV	{"phone": "+70009469367"}
0005435142679	9FDB3C	4417 994645	ELENA KULIKOVA	{"email": "e.kulikova1967@postgrespro.ru", "phone": "+70007533469"}
0005435142680	AF1F38	4735 353814	DMITRIY ILIN	{"phone": "+70848314498"}
0005435142681	C0AA9C	0697 828242	LYUDMILA POPOVA	{"email": "popoval_011984@postgrespro.ru", "phone": "+70568156982"}
0005435142682	EE1AF7	5016 415801	ALEKSEY OSIPOV	{"phone": "+70684578786"}
0005435142683	866993	0182 906785	VALENTIN CHERNOV	{"email": "v-chernov-051974@postgrespro.ru", "phone": "+70982556898"}
0005435142684	D9E480	2894 381376	VERA ZAYCEVA	{"email": "zayceva_v-26021975@postgrespro.ru", "phone": "+70978946331"}
0005435142685	AAEDC2	0931 515248	ELENA ZAKHAROVA	{"phone": "+70498617261"}
0005435142686	953755	8978 555079	ANDREY PETROV	{"phone": "+70190367214"}
0005435142687	C97BBF	7927 813400	NATALYA PETROVA	{"phone": "+70815194179"}
0005435142688	BB6248	8185 002499	ANNA KUZNECOVA	{"email": "kuznecova-anna26111978@postgrespro.ru", "phone": "+70900245504"}
0005435142689	BB6248	6087 084333	NIKOLAY ALEKSANDROV	{"email": "aleksandrov_nikolay101976@postgrespro.ru", "phone": "+70841617835"}
0005435142690	437341	3706 564872	SERGEY TIKHONOV	{"phone": "+70747766553"}
0005435142691	5BEEEC	0093 677293	VLADIMIR CHERNOV	{"email": "v_chernov-041970@postgrespro.ru", "phone": "+70165806969"}
0005435142692	84260D	3464 015095	SERGEY ZAYCEV	{"email": "zaycev-sergey.1969@postgrespro.ru", "phone": "+70226042613"}
0005435142693	84260D	3537 971650	SVETLANA VOLKOVA	{"phone": "+70968881146"}
0005435142694	C32E65	9768 216126	FAINA ANDREEVA	{"phone": "+70703907627"}
0005435142695	F8A3F2	2182 523639	SERGEY BELOV	{"email": "belov-sergey-081986@postgrespro.ru", "phone": "+70275437857"}
0005435142696	9BACC9	0181 818227	SVETLANA KUZNECOVA	{"email": "s_kuznecova06081967@postgrespro.ru", "phone": "+70723210146"}
0005435142697	5B96F3	6547 855429	VALENTINA POTAPOVA	{"phone": "+70630257947"}
0005435142698	5B96F3	4077 532692	OLGA GORBUNOVA	{"phone": "+70371960269"}
0005435142699	AC1CE4	5989 327748	YULIYA OVCHINNIKOVA	{"phone": "+70581606548"}
0005435142700	82F397	0505 941224	ANNA ERMAKOVA	{"phone": "+70281550438"}
0005435142701	33496A	2413 240859	SVETLANA YUDINA	{"email": "yudinasvetlana11111973@postgrespro.ru", "phone": "+70830729518"}
0005435142702	BF7B15	5520 239494	ANNA ISAEVA	{"phone": "+70068768940"}
0005435142703	F7A79C	6701 970705	DMITRIY MELNIKOV	{"email": "d.melnikov_1974@postgrespro.ru", "phone": "+70562272737"}
0005435142704	31DD36	4209 786137	YURIY MELNIKOV	{"email": "melnikov.yuriy.04051973@postgrespro.ru", "phone": "+70634106214"}
0005435142705	876156	6821 752924	VLADIMIR BELOV	{"phone": "+70083317146"}
0005435142706	876156	5270 800915	GALINA GORBUNOVA	{"phone": "+70152168185"}
0005435142707	876156	3685 164683	ALFIYA POLYAKOVA	{"email": "polyakova-alfiya_17011974@postgrespro.ru", "phone": "+70078745115"}
0005435142708	C1A7FC	7589 770386	DANILA NIKITIN	{"phone": "+70555097926"}
0005435142709	C1A7FC	6027 571734	TATYANA SIDOROVA	{"email": "t.sidorova.031959@postgrespro.ru", "phone": "+70452232667"}
0005435142710	548864	1419 063642	DANIIL STEPANOV	{"email": "stepanov.daniil-11101976@postgrespro.ru", "phone": "+70127223533"}
0005435142711	548864	3543 051710	ZUKHRA KAZAKOVA	{"phone": "+70584799959"}
0005435142712	CA6D5F	1236 276521	TAMARA KULIKOVA	{"phone": "+70133987786"}
0005435142713	CA6D5F	6041 312244	DARYA BELOVA	{"email": "belova_darya.21041975@postgrespro.ru", "phone": "+70466005064"}
0005435142714	650D08	3686 298692	ARTEM ORLOV	{"phone": "+70897427648"}
0005435142715	22FD9E	5998 715693	LARISA KOROLEVA	{"phone": "+70183094779"}
0005435142716	22FD9E	9532 516386	EVGENIYA IVANOVA	{"email": "evgeniyaivanova07031960@postgrespro.ru", "phone": "+70800204643"}
0005435142717	0B3B48	7248 733871	IGOR KRASNOV	{"email": "krasnov_i-041970@postgrespro.ru", "phone": "+70580920200"}
0005435142718	0B3B48	0874 894220	VIKTOR KARPOV	{"email": "viktor_karpov-011979@postgrespro.ru", "phone": "+70942982817"}
0005435142719	490F88	5913 535813	ROMAN SOROKIN	{"email": "sorokin-r.101971@postgrespro.ru", "phone": "+70817688621"}
0005435142720	632D82	7478 323204	TATYANA ILINA	{"email": "ilinatatyana_1979@postgrespro.ru", "phone": "+70239375111"}
0005435142721	632D82	5325 160586	OKSANA ANDREEVA	{"phone": "+70560539380"}
0005435142722	E63E86	5709 662810	NINA NOVIKOVA	{"email": "n.novikova-101971@postgrespro.ru", "phone": "+70494989505"}
0005435142723	E63E86	9944 863409	VIKTOR ANTONOV	{"phone": "+70792291694"}
0005435142724	A160BD	6670 319035	PAVEL MIKHAYLOV	{"email": "mikhaylov-p1978@postgrespro.ru", "phone": "+70113258035"}
0005435142725	8A96D8	9760 494434	VIKTORIYA MIKHAYLOVA	{"phone": "+70594700714"}
0005435142726	8A96D8	5839 192105	YULIYA TIMOFEEVA	{"phone": "+70661481238"}
0005435142727	8A96D8	4401 819361	SERGEY FROLOV	{"phone": "+70541296083"}
0005435142728	7F2B7B	3812 231876	VIKTOR PETROV	{"email": "v.petrov-1977@postgrespro.ru", "phone": "+70264837494"}
0005435142729	DE0763	4258 218795	OLGA ZAYCEVA	{"email": "o_zayceva_29081963@postgrespro.ru", "phone": "+70596207548"}
0005435142730	401156	3954 133522	VALERIY POPOV	{"email": "popov-valeriy_011976@postgrespro.ru", "phone": "+70756385791"}
0005435142731	7BD33C	5355 581910	MARIYA KOVALEVA	{"phone": "+70711589077"}
0005435142732	52E546	2703 335557	OLGA DMITRIEVA	{"email": "dmitrieva-o-101973@postgrespro.ru", "phone": "+70031174154"}
0005435142733	78FC92	1549 282925	SERGEY SERGEEV	{"email": "sergeev.s-18071969@postgrespro.ru", "phone": "+70144823772"}
0005435142734	1BEE9B	0235 514490	IRINA GERASIMOVA	{"email": "irinagerasimova_09041965@postgrespro.ru", "phone": "+70895469358"}
0005435142735	909E2F	5017 611600	SVETLANA ANTONOVA	{"email": "svetlana-antonova-1970@postgrespro.ru", "phone": "+70380035986"}
0005435142736	206A07	8419 049773	LYUDMILA AFANASEVA	{"phone": "+70585808836"}
0005435142737	10A768	3015 950360	IGOR EGOROV	{"phone": "+70333300254"}
0005435142738	95E5FC	8683 894223	YULIYA ALEKSEEVA	{"phone": "+70457645095"}
0005435142740	47BB2A	7445 482999	NADEZHDA KAZAKOVA	{"email": "kazakova-nadezhda_1973@postgrespro.ru", "phone": "+70187876181"}
0005435142741	709286	7248 196291	ANNA ANTONOVA	{"email": "anna.antonova.1972@postgrespro.ru", "phone": "+70819613356"}
0005435142742	709286	1046 120167	DMITRIY FEDOROV	{"phone": "+70383536658"}
0005435142743	321DF3	0523 340431	ANVAR VOROBEV	{"phone": "+70375171571"}
0005435142744	0C2086	3414 825958	ELENA MEDVEDEVA	{"phone": "+70689828097"}
0005435142745	A160B3	9228 394124	ANATOLIY EGOROV	{"email": "aegorov23061971@postgrespro.ru", "phone": "+70145080973"}
0005435142746	C27EAD	9706 602673	TATYANA STEPANOVA	{"phone": "+70572416361"}
0005435142747	E4D4F3	5294 064661	MARIYA ZOTOVA	{"phone": "+70273765876"}
0005435142748	813CAA	3981 471453	DARYA SOKOLOVA	{"phone": "+70763542090"}
0005435142749	813CAA	6468 251543	EVGENIY OSIPOV	{"email": "e.osipov.23121976@postgrespro.ru", "phone": "+70281140309"}
0005435142750	8C3AEB	4132 544504	GALINA MOISEEVA	{"phone": "+70259700390"}
0005435142751	812B74	1634 601778	SERGEY FEDOROV	{"phone": "+70194948689"}
0005435142752	812B74	8790 632122	TATYANA KOMAROVA	{"phone": "+70539937667"}
0005435142753	B8DCB2	6568 222377	SVETLANA MIKHAYLOVA	{"phone": "+70909352742"}
0005435142754	59EFBC	8050 661369	SVETLANA BARANOVA	{"phone": "+70888522997"}
0005435142755	51344D	9691 961662	VALERIYA KUZNECOVA	{"email": "v_kuznecova-1963@postgrespro.ru", "phone": "+70852199159"}
0005435142756	6154CD	3964 110360	YURIY SIDOROV	{"phone": "+70256685114"}
0005435142757	6154CD	4816 540812	VLADIMIR MIRONOV	{"email": "v_mironov.23091977@postgrespro.ru", "phone": "+70599674889"}
0005435142758	FA001B	0576 626783	OLEG KUZNECOV	{"email": "okuznecov-17111960@postgrespro.ru", "phone": "+70058033893"}
0005435142759	9F0925	7366 080901	TATYANA ANDREEVA	{"email": "tatyana-andreeva-091966@postgrespro.ru", "phone": "+70595325634"}
0005435142760	1B50CB	5967 771250	SERGEY EGOROV	{"phone": "+70719071218"}
0005435142761	DE3B8D	3273 649254	NATALYA GERASIMOVA	{"email": "n-gerasimova.1964@postgrespro.ru", "phone": "+70412131757"}
0005435142762	DE3B8D	4838 971953	ANDREY FROLOV	{"email": "a-frolov.31051968@postgrespro.ru", "phone": "+70173319817"}
0005435142763	DE3B8D	4068 600983	NINA SMIRNOVA	{"phone": "+70447886293"}
0005435142764	983516	3824 839064	ALEKSANDR SOLOVEV	{"phone": "+70100967104"}
0005435142765	C1022C	0035 160254	ANDREY VASILEV	{"email": "andrey-vasilev-06071961@postgrespro.ru", "phone": "+70819924366"}
0005435142766	AE253D	9660 061677	ANDREY MAKAROV	{"email": "makarov-a-30091977@postgrespro.ru", "phone": "+70966064589"}
0005435142767	AE253D	2708 298055	LYUBOV ZAYCEVA	{"email": "zayceva-lyubov_011986@postgrespro.ru", "phone": "+70042927667"}
0005435142768	971F42	7162 887706	GALINA KUZMINA	{"email": "kuzminagalina_1976@postgrespro.ru", "phone": "+70063386160"}
0005435142769	971F42	9049 394823	ALEKSANDR GUSEV	{"phone": "+70682557595"}
0005435142770	12FCD9	9543 979072	TAMARA ABRAMOVA	{"phone": "+70900479846"}
0005435142771	12FCD9	7351 546471	TATYANA MAKSIMOVA	{"phone": "+70285028586"}
0005435142772	AA6569	5002 527138	LYUDMILA RODIONOVA	{"email": "rodionova.lyudmila.20091974@postgrespro.ru", "phone": "+70622293240"}
0005435142773	AA6569	3296 804602	INESSA POPOVA	{"phone": "+70498129350"}
0005435142774	5F9D79	8807 280456	EKATERINA FEDOROVA	{"email": "e-fedorova-22111973@postgrespro.ru", "phone": "+70930858803"}
0005435142775	392478	4137 352346	ANTONINA OSIPOVA	{"email": "a_osipova1963@postgrespro.ru", "phone": "+70252885584"}
0005435142776	9C7332	0178 246364	DENIS KUZNECOV	{"phone": "+70361922592"}
0005435142777	16E5BB	4434 005560	ANNA IVANOVA	{"phone": "+70809934772"}
0005435142778	5F1523	3241 101400	SERGEY BORISOV	{"email": "borisov.s-1975@postgrespro.ru", "phone": "+70459382692"}
0005435142779	9BD54B	8603 815530	NATALYA KOROLEVA	{"phone": "+70811693947"}
0005435142780	ACF12A	4993 403311	VALERIY MATVEEV	{"phone": "+70303203765"}
0005435142781	CAE732	8856 440738	TATYANA MAKSIMOVA	{"email": "maksimovat_121973@postgrespro.ru", "phone": "+70646392069"}
0005435142782	CAE732	7222 643773	VLADIMIR FILIPPOV	{"phone": "+70466509899"}
0005435142783	CAE732	2107 971131	MARIYA MELNIKOVA	{"email": "melnikovamariya.011976@postgrespro.ru", "phone": "+70330331885"}
0005435142784	BF2A38	2135 628583	ALEKSANDR ANTONOV	{"phone": "+70288785078"}
0005435142785	BF2A38	6321 529163	SERGEY DMITRIEV	{"email": "sergeydmitriev_30101975@postgrespro.ru", "phone": "+70131736472"}
0005435142786	148B20	1665 123191	OLEG KULIKOV	{"phone": "+70604858612"}
0005435142787	148B20	3910 623673	NATALYA LOGINOVA	{"email": "loginova-natalya-111970@postgrespro.ru", "phone": "+70636555608"}
0005435142788	ED970E	0786 773930	ANTONINA KONDRATEVA	{"phone": "+70989361047"}
0005435142789	C0CF44	9150 458192	ANDREY SOROKIN	{"phone": "+70171430542"}
0005435142790	9B03CC	5473 759147	MATVEY VLASOV	{"phone": "+70477092812"}
0005435142791	2BFBED	6580 041217	VASILIY KONOVALOV	{"email": "vasiliy-konovalov021967@postgrespro.ru", "phone": "+70665553362"}
0005435142792	2BFBED	9530 891877	VENERA MAKAROVA	{"phone": "+70767567925"}
0005435142793	60CA85	7798 782465	VLADIMIR NIKITIN	{"phone": "+70891262622"}
0005435142794	75393C	0293 770979	ALEKSEY CHERNOV	{"email": "chernova-071959@postgrespro.ru", "phone": "+70279204917"}
0005435142795	CB6882	9959 738321	IVAN NOVIKOV	{"email": "ivan-novikov-1978@postgrespro.ru", "phone": "+70750935086"}
0005435142851	F3F5A3	4116 343249	SVETLANA DENISOVA	{"phone": "+70464919560"}
0005435142796	E40200	0316 373714	VALERIY ZHUKOV	{"email": "vzhukov1966@postgrespro.ru", "phone": "+70346442154"}
0005435142797	D8F329	9095 983766	NADEZHDA NIKOLAEVA	{"email": "nikolaeva.n-26121986@postgrespro.ru", "phone": "+70981722362"}
0005435142798	39AF7C	5380 629312	YURIY ISAEV	{"email": "isaev_yuriy.23071979@postgrespro.ru", "phone": "+70215115604"}
0005435142799	9F0C1E	5696 172837	TATYANA ZAYCEVA	{"email": "tatyana_zayceva_051974@postgrespro.ru", "phone": "+70268474171"}
0005435142800	9F0C1E	4637 199763	VIKTORIYA KUZNECOVA	{"email": "viktoriyakuznecova-16081970@postgrespro.ru", "phone": "+70664200413"}
0005435142801	242EBE	9380 520968	LYUDMILA BELYAEVA	{"email": "belyaevalyudmila-22091970@postgrespro.ru", "phone": "+70958360452"}
0005435142802	CF21DC	2690 661614	ELENA ZAKHAROVA	{"email": "zakharovaelena.021979@postgrespro.ru", "phone": "+70195622708"}
0005435142803	F1E168	0278 168273	EKATERINA MARTYNOVA	{"email": "martynova.ekaterina-19081980@postgrespro.ru", "phone": "+70234466039"}
0005435142804	E8700F	5158 390780	OKSANA PAVLOVA	{"email": "pavlovaoksana_23041980@postgrespro.ru", "phone": "+70625112881"}
0005435142805	E8700F	9963 792548	NATALYA EGOROVA	{"email": "egorovanatalya061976@postgrespro.ru", "phone": "+70828015187"}
0005435142806	6C4B3B	6364 867127	OLGA FILATOVA	{"phone": "+70354619253"}
0005435142807	6C4B3B	3947 867412	IVAN EGOROV	{"email": "egorov-ivan-051976@postgrespro.ru", "phone": "+70480119923"}
0005435142808	C06F27	3310 252758	MARK NAZAROV	{"email": "nazarov-mark1986@postgrespro.ru", "phone": "+70757929548"}
0005435142809	3259A7	0006 001561	EVGENIY IVANOV	{"phone": "+70600357555"}
0005435142810	3259A7	4020 995407	VALERIY NAZAROV	{"email": "nazarov.valeriy.091973@postgrespro.ru", "phone": "+70087990394"}
0005435142811	3259A7	2886 888932	OLEG ANDREEV	{"email": "oleg-andreev29031977@postgrespro.ru", "phone": "+70072732038"}
0005435142812	8F5AAF	2370 567218	MAKSIM DENISOV	{"phone": "+70164348919"}
0005435142813	F148CF	2361 793061	IRINA SOKOLOVA	{"phone": "+70189249611"}
0005435142814	D969F7	8101 754080	MAKSIM ZAYCEV	{"phone": "+70252061985"}
0005435142815	D969F7	6119 625570	VLADIMIR NOVIKOV	{"phone": "+70201846320"}
0005435142816	6C7415	4266 216369	GENNADIY BELOV	{"phone": "+70344749339"}
0005435142817	370088	8985 464058	LYUDMILA KONDRATEVA	{"phone": "+70985273006"}
0005435142818	DF86AB	9386 151696	VLADIMIR KULIKOV	{"email": "v.kulikov-04121974@postgrespro.ru", "phone": "+70783727500"}
0005435142819	9717A6	9453 475143	LYUBOV FROLOVA	{"email": "l.frolova.15091970@postgrespro.ru", "phone": "+70247193894"}
0005435142820	3DAD3E	1941 877726	OLEG SOLOVEV	{"email": "o.solovev.1970@postgrespro.ru", "phone": "+70212841763"}
0005435142821	3DAD3E	9236 482741	OLGA ILINA	{"phone": "+70207977658"}
0005435142822	5DD8CC	2041 553385	IGOR KUZNECOV	{"email": "igor_kuznecov-15031977@postgrespro.ru", "phone": "+70713470887"}
0005435142823	66AC8A	4895 004177	EKATERINA MEDVEDEVA	{"phone": "+70526152223"}
0005435142824	1E16FD	9797 667264	OLGA ROMANOVA	{"phone": "+70032487166"}
0005435142825	1E16FD	7001 579853	VADIM KUZNECOV	{"phone": "+70603778442"}
0005435142826	1E16FD	1135 927875	VALENTINA ANTONOVA	{"email": "antonova_v.011961@postgrespro.ru", "phone": "+70432702602"}
0005435142827	21BA8B	9271 449963	KONSTANTIN NOVIKOV	{"phone": "+70530745071"}
0005435142828	2D4205	6366 558639	ANDREY FROLOV	{"email": "frolovandrey.10041974@postgrespro.ru", "phone": "+70409054267"}
0005435142829	D11804	5549 494464	NIKOLAY SMIRNOV	{"phone": "+70518453388"}
0005435142830	2235D3	2587 357101	EVGENIY MAKAROV	{"phone": "+70451698500"}
0005435142831	2235D3	1316 019480	SERGEY KUZNECOV	{"email": "s_kuznecov-091972@postgrespro.ru", "phone": "+70187393163"}
0005435142832	2235D3	7676 103071	VASILIY MIKHAYLOV	{"email": "mikhaylov_vasiliy.081966@postgrespro.ru", "phone": "+70847217198"}
0005435142833	A1614A	2660 022779	ULYANA NOVIKOVA	{"email": "novikovau-11051968@postgrespro.ru", "phone": "+70675954284"}
0005435142834	A63B33	6879 571192	YURIY ISAEV	{"phone": "+70835626112"}
0005435142835	3463A4	1024 322696	EGOR MOISEEV	{"email": "e_moiseev_1965@postgrespro.ru", "phone": "+70705388334"}
0005435142836	3C4053	5321 266237	VYACHESLAV KUZNECOV	{"phone": "+70357031286"}
0005435142837	732E8F	7191 064908	ANATOLIY SMIRNOV	{"email": "smirnov.a_091973@postgrespro.ru", "phone": "+70327859716"}
0005435142838	41FADC	5422 787645	SERGEY DENISOV	{"phone": "+70245212200"}
0005435142839	A070FE	5068 448642	SAMVEL OSIPOV	{"email": "s_osipov_04061973@postgrespro.ru", "phone": "+70707127801"}
0005435142840	A070FE	7774 548314	ALEKSEY PETROV	{"phone": "+70103794299"}
0005435142841	720655	5749 959415	KLAVDIYA MELNIKOVA	{"phone": "+70556612213"}
0005435142842	720655	5464 430985	ANATOLIY STEPANOV	{"email": "stepanovanatoliy.03091970@postgrespro.ru", "phone": "+70592843156"}
0005435142843	3AA8ED	4151 069674	VALENTINA VLASOVA	{"email": "valentinavlasova.13021973@postgrespro.ru", "phone": "+70501629090"}
0005435142844	DF81A4	2899 689546	NATALYA PAVLOVA	{"phone": "+70603369624"}
0005435142845	BE7DCF	2067 583438	EVDOKIYA DANILOVA	{"phone": "+70171822706"}
0005435142846	633A46	8006 486500	ELENA TIMOFEEVA	{"email": "timofeeva-elena_08081968@postgrespro.ru", "phone": "+70809848981"}
0005435142847	633A46	3656 616629	SERGEY KAZAKOV	{"email": "s-kazakov-121961@postgrespro.ru", "phone": "+70301752322"}
0005435142848	633A46	1781 414323	NADEZHDA LAZAREVA	{"phone": "+70612516198"}
0005435142849	F3F5A3	8733 546453	LIDIYA MOISEEVA	{"email": "l-moiseeva.06111976@postgrespro.ru", "phone": "+70788652359"}
0005435142850	F3F5A3	2567 089088	LYUDMILA IVANOVA	{"email": "l.ivanova-051958@postgrespro.ru", "phone": "+70639025836"}
0005435142852	91EE08	6908 323489	LYUBOV LUKYANOVA	{"email": "lukyanova.l.091961@postgrespro.ru", "phone": "+70356275669"}
0005435142853	91EE08	5731 443194	ANTON MAKAROV	{"phone": "+70894323183"}
0005435142854	6C1034	3651 129673	SERGEY IVANOV	{"phone": "+70999899683"}
0005435142855	B06310	6509 887755	OKSANA SOKOLOVA	{"phone": "+70352754570"}
0005435142856	EF66E9	3988 499434	TAMARA TIMOFEEVA	{"email": "timofeevatamara.1969@postgrespro.ru", "phone": "+70391288225"}
0005435142857	EF66E9	4595 706964	RAMIL KISELEV	{"phone": "+70104618415"}
0005435142858	F83185	4279 790813	NIKOLAY MATVEEV	{"phone": "+70454998357"}
0005435142859	F24F6A	1835 107801	ALEKSANDR KUZMIN	{"phone": "+70011984327"}
0005435142860	F24F6A	8447 630339	ALEKSANDR TARASOV	{"phone": "+70170082864"}
0005435142861	411522	5342 677810	LYUBOV KALININA	{"phone": "+70248211937"}
0005435142862	DE27EA	4377 668584	NIKITA VOROBEV	{"email": "vorobev_n.091968@postgrespro.ru", "phone": "+70482209134"}
0005435142863	2FE113	9671 412640	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin_071977@postgrespro.ru", "phone": "+70335506384"}
0005435142864	6307F0	2974 604298	OLGA FEDOROVA	{"email": "fedorova-o.071970@postgrespro.ru", "phone": "+70272764569"}
0005435142865	6307F0	7471 843440	IRINA KULIKOVA	{"email": "kulikova.i_051973@postgrespro.ru", "phone": "+70990074002"}
0005435142866	AF2B11	4576 360928	SERGEY ZAKHAROV	{"email": "sergey-zakharov_1978@postgrespro.ru", "phone": "+70047644856"}
0005435142867	AF2B11	9810 142187	FEDOR IVANOV	{"phone": "+70390775263"}
0005435142868	A2A2A0	3704 770768	VENIAMIN NOVIKOV	{"email": "v.novikov.081974@postgrespro.ru", "phone": "+70997555967"}
0005435142869	A2A2A0	9763 062370	VLADISLAV SMIRNOV	{"email": "smirnov_v_051971@postgrespro.ru", "phone": "+70067872816"}
0005435142870	E6625F	4464 906752	ROMAN SMIRNOV	{"phone": "+70305563373"}
0005435142871	E6625F	4631 451340	NADEZHDA VLASOVA	{"phone": "+70781861363"}
0005435142872	9198FD	3088 374880	VALERIYA KONOVALOVA	{"phone": "+70770585843"}
0005435142873	DED848	9906 865357	VLADIMIR ANDREEV	{"phone": "+70595062436"}
0005435142874	43559B	8692 580784	DMITRIY FEDOROV	{"phone": "+70158732750"}
0005435142875	FC55CC	1648 292453	LYUDMILA OSIPOVA	{"email": "osipova_l.101974@postgrespro.ru", "phone": "+70548521351"}
0005435142876	5CB3D3	2694 154490	GALINA KULIKOVA	{"phone": "+70574930080"}
0005435142877	4B682E	4757 340401	VYACHESLAV TARASOV	{"phone": "+70992638610"}
0005435142878	998E79	5027 692899	ALEKSANDRA VASILEVA	{"phone": "+70978368262"}
0005435142879	876FF9	8417 635494	SVETLANA ROMANOVA	{"phone": "+70959538207"}
0005435142880	3AFA30	7625 500667	NATALYA NIKOLAEVA	{"email": "n_nikolaeva-051969@postgrespro.ru", "phone": "+70616050541"}
0005435142881	3AFA30	2274 143691	LARISA DENISOVA	{"email": "denisovalarisa_1975@postgrespro.ru", "phone": "+70456928920"}
0005435142882	3AFA30	2706 848589	OLGA STEPANOVA	{"email": "stepanova-olga-041975@postgrespro.ru", "phone": "+70084607952"}
0005435142883	3A1374	4450 513215	DMITRIY NIKOLAEV	{"email": "nikolaev.dmitriy.1970@postgrespro.ru", "phone": "+70280870139"}
0005435142884	87798C	2386 915925	IVAN KOZLOV	{"phone": "+70645174218"}
0005435142885	7BBF12	1183 320148	OLGA SOKOLOVA	{"email": "olga.sokolova.27031974@postgrespro.ru", "phone": "+70571251485"}
0005435142886	A154AA	7088 877280	PAVEL KOZLOV	{"email": "kozlov-p111978@postgrespro.ru", "phone": "+70894456993"}
0005435142887	A154AA	8881 636409	SERGEY SEMENOV	{"email": "semenovsergey-041980@postgrespro.ru", "phone": "+70514317182"}
0005435142888	A154AA	2951 710010	VERA ZAKHAROVA	{"email": "zakharova-vera09021963@postgrespro.ru", "phone": "+70001881024"}
0005435142889	2918D7	0981 365045	GALINA DMITRIEVA	{"email": "dmitrieva.galina.111964@postgrespro.ru", "phone": "+70614984387"}
0005435142890	2918D7	3658 743598	ANZHELA SERGEEVA	{"phone": "+70673331826"}
0005435142891	43CE3E	3016 580782	EKATERINA KOROLEVA	{"email": "e-koroleva-101962@postgrespro.ru", "phone": "+70393318167"}
0005435142892	30A404	4383 204513	YURIY DMITRIEV	{"email": "yuriy.dmitriev_031976@postgrespro.ru", "phone": "+70549715611"}
0005435142893	3E078C	3290 891370	GRIGORIY NIKOLAEV	{"phone": "+70943844103"}
0005435142894	3E078C	1263 369749	DIANA POPOVA	{"email": "popova.d-01111979@postgrespro.ru", "phone": "+70473638366"}
0005435142895	3011D4	3621 443669	SERGEY NAUMOV	{"phone": "+70825848944"}
0005435142896	27D1C1	6162 209105	NADEZHDA MEDVEDEVA	{"email": "n.medvedeva-101967@postgrespro.ru", "phone": "+70199625669"}
0005435142897	27D1C1	8850 789225	ARTUR MEDVEDEV	{"email": "artur.medvedev_24041970@postgrespro.ru", "phone": "+70095371916"}
0005435142898	81036F	7730 352551	SVETLANA NIKOLAEVA	{"phone": "+70739017523"}
0005435142899	C539AC	5503 873387	SERGEY CHERNOV	{"email": "sergey-chernov061978@postgrespro.ru", "phone": "+70728233935"}
0005435142900	1DD91A	5715 720275	TAMARA EGOROVA	{"email": "t-egorova-101977@postgrespro.ru", "phone": "+70810986604"}
0005435142901	6B71EB	0332 704940	VERA KUZNECOVA	{"phone": "+70942199572"}
0005435142902	294E51	5670 470854	TATYANA MEDVEDEVA	{"phone": "+70631014909"}
0005435142903	E18D53	7740 098297	EVGENIY IVANOV	{"phone": "+70472268316"}
0005435142904	E18D53	8470 024641	YURIY SHEVCHENKO	{"phone": "+70095164755"}
0005435142905	0A7E3D	6811 257922	YULIYA LOGINOVA	{"email": "loginova_yuliya-1969@postgrespro.ru", "phone": "+70724260464"}
0005435142906	0A7E3D	7987 164329	EKATERINA BORISOVA	{"phone": "+70646267487"}
0005435142907	A02911	3389 224803	BORIS AFANASEV	{"email": "boris.afanasev.25061962@postgrespro.ru", "phone": "+70170133291"}
0005435142908	82335B	2907 479604	VALERIY MELNIKOV	{"email": "melnikov_valeriy-1969@postgrespro.ru", "phone": "+70316712116"}
0005435142909	F3247B	3337 126312	ALEKSEY ZHUKOV	{"email": "aleksey.zhukov_021968@postgrespro.ru", "phone": "+70720477383"}
0005435142910	F3247B	9647 374128	ANTON CHERNOV	{"phone": "+70214572225"}
0005435142911	068FCC	3520 574154	YULIYA KAZAKOVA	{"email": "y-kazakova.061987@postgrespro.ru", "phone": "+70858745903"}
0005435142912	068FCC	7261 091074	LYUDMILA SIDOROVA	{"phone": "+70542492430"}
0005435142913	068FCC	8402 566189	VLADISLAV KUZMIN	{"email": "vkuzmin.121976@postgrespro.ru", "phone": "+70322682375"}
0005435142914	72579A	9349 110913	VALENTINA PAVLOVA	{"email": "valentina_pavlova.041957@postgrespro.ru", "phone": "+70737998950"}
0005435149876	5B449C	1342 753949	ROMAN FEDOROV	{"phone": "+70215466296"}
0005435142915	477F48	8726 579003	ELENA SOKOLOVA	{"email": "elena-sokolova.1982@postgrespro.ru", "phone": "+70732084088"}
0005435142916	900849	7030 300252	VIKTOR POPOV	{"email": "popov.v_27101970@postgrespro.ru", "phone": "+70362312150"}
0005435142917	900849	7517 913819	NATALYA DENISOVA	{"phone": "+70045372532"}
0005435142918	783B91	6523 890551	ALEKSEY SOKOLOV	{"phone": "+70389227551"}
0005435142919	7226BB	3473 992622	DENIS NOVIKOV	{"email": "novikov_d.071974@postgrespro.ru", "phone": "+70993085632"}
0005435142920	7226BB	1860 136328	ELENA SMIRNOVA	{"email": "elena.smirnova.03091965@postgrespro.ru", "phone": "+70184348444"}
0005435142921	AD9D02	8824 019643	LYUDMILA NAUMOVA	{"phone": "+70409281859"}
0005435142922	C17D32	5197 487296	YURIY BARANOV	{"phone": "+70306757387"}
0005435142923	C17D32	3767 417196	VALENTINA MIRONOVA	{"email": "v.mironova_021954@postgrespro.ru", "phone": "+70742678686"}
0005435142924	09F685	5729 417699	GALINA KULIKOVA	{"email": "kulikova.galina.1973@postgrespro.ru", "phone": "+70860260842"}
0005435142925	B34170	8880 239291	MARINA NOVIKOVA	{"email": "novikova_m-1971@postgrespro.ru", "phone": "+70860847784"}
0005435142926	B34170	2575 075760	EKATERINA ZHURAVLEVA	{"email": "zhuravlevae_071976@postgrespro.ru", "phone": "+70503663335"}
0005435142927	ADCC67	3849 276913	FEDOR MAKSIMOV	{"phone": "+70389418698"}
0005435142928	3CECE6	8934 339698	IRINA GUSEVA	{"email": "guseva-irina.111965@postgrespro.ru", "phone": "+70107755419"}
0005435142929	B167A9	3353 594083	TATYANA SCHERBAKOVA	{"email": "tatyanascherbakova.101966@postgrespro.ru", "phone": "+70297674778"}
0005435142930	91CA77	8431 181494	VIKTOR KARPOV	{"phone": "+70286190862"}
0005435142931	CF6723	5621 287853	ELENA MELNIKOVA	{"email": "melnikovaelena.1975@postgrespro.ru", "phone": "+70032553993"}
0005435142932	24123C	4546 824797	TATYANA KUZNECOVA	{"phone": "+70758857101"}
0005435142933	25C633	5134 828280	VLADIMIR MIKHAYLOV	{"phone": "+70262815238"}
0005435142934	2193D4	2061 124913	IGOR VOLKOV	{"email": "volkov.igor-041973@postgrespro.ru", "phone": "+70224615781"}
0005435142935	2193D4	6298 523154	GALINA SOKOLOVA	{"email": "sokolova_g-1976@postgrespro.ru", "phone": "+70739872126"}
0005435142936	2193D4	2805 933112	TATYANA NIKOLAEVA	{"phone": "+70722041257"}
0005435142937	7C2CA9	6511 119857	MIKHAIL ZHURAVLEV	{"email": "m-zhuravlev-121972@postgrespro.ru", "phone": "+70058950740"}
0005435142938	11F421	3295 788189	LYUBOV EGOROVA	{"email": "lyubov-egorova-03111974@postgrespro.ru", "phone": "+70787417708"}
0005435142939	11F421	6257 285327	YAROSLAV ANDREEV	{"email": "andreev-y-1968@postgrespro.ru", "phone": "+70631215209"}
0005435142940	8E929E	0698 667599	DMITRIY ILIN	{"email": "ilin.d.31081967@postgrespro.ru", "phone": "+70334180516"}
0005435142941	F4F4D2	1606 895286	NIKOLAY SOLOVEV	{"phone": "+70263106326"}
0005435142942	F4F4D2	6797 051402	EKATERINA KUZMINA	{"phone": "+70549688702"}
0005435142943	81626A	5858 118447	LARISA VASILEVA	{"email": "vasileval.27121964@postgrespro.ru", "phone": "+70879513341"}
0005435142944	690362	6562 585121	ALEKSEY KOROLEV	{"phone": "+70878339751"}
0005435142945	84FA95	3502 873995	LARISA ISAEVA	{"email": "lisaeva_031971@postgrespro.ru", "phone": "+70812544171"}
0005435142946	348531	7160 272230	MAKSIM IVANOV	{"phone": "+70444624419"}
0005435142947	348531	6212 641939	TATYANA SEMENOVA	{"phone": "+70382650537"}
0005435142948	BBA140	1186 001610	ARTEM SERGEEV	{"email": "artem.sergeev.101986@postgrespro.ru", "phone": "+70631080272"}
0005435142949	E16A67	4807 904673	OKSANA LEBEDEVA	{"phone": "+70286277709"}
0005435142950	440EC6	7503 076494	ELENA MIKHAYLOVA	{"email": "mikhaylova-elena.071979@postgrespro.ru", "phone": "+70955696825"}
0005435142951	440EC6	5346 168287	VLADIMIR KULIKOV	{"phone": "+70688437255"}
0005435142952	346F01	7563 377419	VITALIY KAZAKOV	{"phone": "+70983272465"}
0005435142953	346F01	9611 930411	PETR ANTONOV	{"phone": "+70395303407"}
0005435142954	C6F17A	7427 654382	VENIAMIN POPOV	{"email": "v_popov121964@postgrespro.ru", "phone": "+70117216756"}
0005435142955	C6F17A	0019 644385	GENNADIY VASILEV	{"phone": "+70230482100"}
0005435142956	D7F70E	0840 415017	ANNA RYABOVA	{"phone": "+70513334055"}
0005435142957	D7F70E	5228 148270	SVETLANA IVANOVA	{"email": "s_ivanova-30121970@postgrespro.ru", "phone": "+70510373473"}
0005435142958	B8B920	1356 888624	NINA KUZMINA	{"email": "nkuzmina081965@postgrespro.ru", "phone": "+70435581598"}
0005435142959	D9ED24	1096 773532	BORIS SCHERBAKOV	{"phone": "+70954811390"}
0005435142960	D9ED24	2284 369595	VLADIMIR SMIRNOV	{"email": "smirnovv_1965@postgrespro.ru", "phone": "+70232242936"}
0005435142961	7AE9EE	6031 368990	VASILIY ROMANOV	{"phone": "+70580423829"}
0005435142962	A39D5D	2951 445858	VLADIMIR RODIONOV	{"phone": "+70934644181"}
0005435142963	A39D5D	4382 653318	MARIYA KOZLOVA	{"phone": "+70716994854"}
0005435142965	BDDCF5	7790 534551	VLADIMIR FILIPPOV	{"phone": "+70280688187"}
0005435142966	BDDCF5	3019 452810	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina.1978@postgrespro.ru", "phone": "+70012205706"}
0005435142967	329601	0207 635068	DMITRIY FEDOROV	{"email": "fedorov-dmitriy.1968@postgrespro.ru", "phone": "+70812732831"}
0005435142968	9E8229	3205 367490	YULIYA ANISIMOVA	{"email": "anisimova.yuliya081974@postgrespro.ru", "phone": "+70063929476"}
0005435142969	6DDDCA	5844 681077	IRINA MATVEEVA	{"phone": "+70664904107"}
0005435142970	269C6F	7598 955852	VALENTINA KOLESNIKOVA	{"phone": "+70498972695"}
0005435142971	7A7BE3	3752 999852	ROMAN TARASOV	{"email": "r_tarasov091979@postgrespro.ru", "phone": "+70513748675"}
0005435142972	6845C6	9885 223194	NADEZHDA KUZNECOVA	{"email": "kuznecova_n10121973@postgrespro.ru", "phone": "+70180779438"}
0005435142973	560C00	3314 457397	NIKOLAY KUZNECOV	{"phone": "+70081809096"}
0005435142974	560C00	9137 695185	SVETLANA MIKHAYLOVA	{"email": "s_mikhaylova.111978@postgrespro.ru", "phone": "+70635826260"}
0005435142975	207718	6809 162480	VASILIY SOROKIN	{"email": "vasiliy-sorokin-031977@postgrespro.ru", "phone": "+70997203464"}
0005435142976	EEA162	0655 534148	ELIZAVETA IVANOVA	{"email": "ivanova-elizaveta021969@postgrespro.ru", "phone": "+70600276565"}
0005435142977	F061E1	0966 372963	ANNA FOMINA	{"email": "fomina-a.17061985@postgrespro.ru", "phone": "+70482826523"}
0005435142978	56F488	4930 658316	VLADISLAV NIKITIN	{"email": "vladislav_nikitin.22121969@postgrespro.ru", "phone": "+70462177065"}
0005435142979	A2A592	0401 759819	ANNA SMIRNOVA	{"phone": "+70660115281"}
0005435142980	C865FB	3770 491968	SVETLANA EGOROVA	{"phone": "+70558420403"}
0005435142981	68CDBE	4774 979903	VALERIYA MEDVEDEVA	{"phone": "+70757800682"}
0005435142982	8102D8	6182 183089	EVGENIY DMITRIEV	{"phone": "+70497750942"}
0005435142983	376FF2	2824 453757	NIKOLAY MOISEEV	{"email": "n_moiseev.011965@postgrespro.ru", "phone": "+70976282908"}
0005435142984	7FDE36	4767 047799	DENIS MELNIKOV	{"email": "melnikov_denis1972@postgrespro.ru", "phone": "+70270137749"}
0005435142985	693F07	9599 074640	ALEKSANDR FILIPPOV	{"email": "filippova_1967@postgrespro.ru", "phone": "+70798743362"}
0005435142986	F3F321	9864 180289	VIKTORIYA IVANOVA	{"phone": "+70704819207"}
0005435142987	F3F321	2070 537963	OLGA DENISOVA	{"email": "denisova-olga061985@postgrespro.ru", "phone": "+70797572584"}
0005435142988	2140D8	0061 193544	TATYANA MEDVEDEVA	{"email": "medvedeva-t.1976@postgrespro.ru", "phone": "+70956664200"}
0005435142989	80640E	2870 744852	IRINA SMIRNOVA	{"phone": "+70088787846"}
0005435142990	59D47E	1287 905733	SVYATOSLAV SHEVCHENKO	{"email": "sshevchenko-061968@postgrespro.ru", "phone": "+70622076192"}
0005435142991	10833C	8811 673863	OLEG KUZNECOV	{"email": "kuznecov_o-1965@postgrespro.ru", "phone": "+70344612832"}
0005435142992	10833C	7642 052456	OLEG NOVIKOV	{"phone": "+70929687643"}
0005435142993	10833C	8712 476700	NIKOLAY ALEKSEEV	{"phone": "+70555330096"}
0005435142994	6489BC	9055 815748	YURIY IVANOV	{"email": "ivanov_y.1977@postgrespro.ru", "phone": "+70314773380"}
0005435142995	6489BC	9741 943069	STANISLAV KUZMIN	{"email": "kuzminstanislav1990@postgrespro.ru", "phone": "+70428819092"}
0005435142996	1A97BC	6603 225304	ANNA NESTEROVA	{"email": "a_nesterova1984@postgrespro.ru", "phone": "+70318355863"}
0005435142997	1A97BC	0178 086360	LYUBOV KUDRYASHOVA	{"email": "kudryashoval.1982@postgrespro.ru", "phone": "+70117690708"}
0005435142998	6448FE	9989 545869	VIKTOR KOROLEV	{"phone": "+70888340416"}
0005435142999	6448FE	9727 810497	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov19101971@postgrespro.ru", "phone": "+70386722488"}
0005435143000	6448FE	1742 727765	ANASTASIYA NESTEROVA	{"email": "anastasiya-nesterova22021968@postgrespro.ru", "phone": "+70182404890"}
0005435143001	BBDC9B	7633 413695	TATYANA TIMOFEEVA	{"phone": "+70706843661"}
0005435143002	BBDC9B	9527 417894	IRINA KUZMINA	{"phone": "+70248356861"}
0005435143003	BBDC9B	3642 922849	TAMARA IVANOVA	{"email": "ivanovat.1972@postgrespro.ru", "phone": "+70176891501"}
0005435149785	E3C996	8208 404926	OLEG KUZNECOV	{"email": "okuznecov091977@postgrespro.ru", "phone": "+70292024081"}
0005435149786	E3C996	9437 063757	ANGELINA BORISOVA	{"email": "borisovaa-22011974@postgrespro.ru", "phone": "+70664787570"}
0005435149787	C2AEDD	3756 137275	LIDIYA IVANOVA	{"email": "l-ivanova_111969@postgrespro.ru", "phone": "+70521282047"}
0005435149788	C2AEDD	7429 932892	MARINA NIKITINA	{"email": "nikitina_marina.1966@postgrespro.ru", "phone": "+70912784552"}
0005435149789	930F83	2195 714030	NINA BELYAEVA	{"email": "belyaeva-nina051966@postgrespro.ru", "phone": "+70339767697"}
0005435149790	930F83	2524 733995	ANASTASIYA IVANOVA	{"phone": "+70993289292"}
0005435149791	930F83	4609 113949	ELENA NIKITINA	{"phone": "+70740229982"}
0005435149792	26849E	6968 181947	NATALYA KOLESNIKOVA	{"phone": "+70564224153"}
0005435149793	18C09C	9015 295371	LIDIYA CHERNOVA	{"phone": "+70042967774"}
0005435149794	18C09C	6940 448221	TATYANA NAZAROVA	{"email": "nazarovatatyana_081963@postgrespro.ru", "phone": "+70887687605"}
0005435149795	400EBD	0179 426697	VALENTINA IVANOVA	{"email": "ivanova_valentina15081968@postgrespro.ru", "phone": "+70260278579"}
0005435149796	400EBD	5190 900421	VALERIY NIKOLAEV	{"phone": "+70202536412"}
0005435149797	1AAA03	3663 482987	MARINA NIKITINA	{"email": "nikitina.marina23031980@postgrespro.ru", "phone": "+70120205850"}
0005435149798	1A5FFC	7579 096761	SERGEY KUDRYASHOV	{"phone": "+70417854826"}
0005435149799	1A5FFC	4948 445733	SANIYA BARANOVA	{"email": "baranovas1972@postgrespro.ru", "phone": "+70117375941"}
0005435149800	E09BF8	3101 962623	TATYANA DMITRIEVA	{"phone": "+70957840743"}
0005435149801	EB0B66	7794 993808	MARIYA STEPANOVA	{"phone": "+70258056405"}
0005435149802	A8DDD4	9937 898952	NATALYA TIMOFEEVA	{"phone": "+70008420076"}
0005435149803	8119CB	0814 593736	DANILA BONDARENKO	{"email": "danila-bondarenko-20071971@postgrespro.ru", "phone": "+70393969040"}
0005435149804	8119CB	3432 072173	EVGENIYA MEDVEDEVA	{"phone": "+70604167381"}
0005435149805	CAA975	1403 296585	EKATERINA IVANOVA	{"email": "ekaterina-ivanova.071966@postgrespro.ru", "phone": "+70681056024"}
0005435149806	186BF5	4605 969645	OLGA BOGDANOVA	{"email": "bogdanova_olga.13101968@postgrespro.ru", "phone": "+70662404203"}
0005435149807	186BF5	1739 843181	VALENTIN KARPOV	{"phone": "+70707974806"}
0005435149808	7FB491	5855 238693	ALEKSANDR NAZAROV	{"email": "aleksandr.nazarov.051975@postgrespro.ru", "phone": "+70060372331"}
0005435149809	449CF3	3501 867844	SERGEY NOVIKOV	{"phone": "+70695169014"}
0005435149810	449CF3	2267 490962	LARISA MARTYNOVA	{"phone": "+70902905423"}
0005435149811	7D3FD7	4308 762964	RAISA DMITRIEVA	{"email": "dmitrieva_raisa.091964@postgrespro.ru", "phone": "+70317360327"}
0005435149812	7D3FD7	8983 007296	NINA STEPANOVA	{"phone": "+70549138281"}
0005435149813	FCBB92	6049 123387	TATYANA TIKHONOVA	{"email": "tatyana.tikhonova-041980@postgrespro.ru", "phone": "+70653972238"}
0005435149814	FCBB92	6197 594348	TATYANA NAUMOVA	{"email": "t_naumova_09061983@postgrespro.ru", "phone": "+70931814499"}
0005435149815	D6C362	4618 906810	DANIL SCHERBAKOV	{"phone": "+70307036287"}
0005435149816	014C47	7419 546039	IRINA KUZMINA	{"email": "kuzmina.i_1971@postgrespro.ru", "phone": "+70419777036"}
0005435149817	014C47	3119 888364	KONSTANTIN KONOVALOV	{"email": "konstantin.konovalov.101966@postgrespro.ru", "phone": "+70820387965"}
0005435149818	007602	8406 658463	PETR KUZNECOV	{"email": "petr-kuznecov1962@postgrespro.ru", "phone": "+70181250574"}
0005435149819	007602	8290 815246	ELMIRA KUZNECOVA	{"phone": "+70473527732"}
0005435149820	007602	7646 071225	SVETLANA SIDOROVA	{"email": "sidorovasvetlana_16091968@postgrespro.ru", "phone": "+70438762955"}
0005435149821	914B7E	4155 361655	ELENA KONOVALOVA	{"phone": "+70423687852"}
0005435149822	914B7E	0732 279349	KIRILL MIRONOV	{"email": "mironov_k_1973@postgrespro.ru", "phone": "+70723476534"}
0005435149823	2E656F	4947 464116	ALEKSANDR KRASNOV	{"email": "krasnova_031968@postgrespro.ru", "phone": "+70807159174"}
0005435149824	2E656F	9633 554211	VASILIY KUZNECOV	{"email": "vasiliy.kuznecov-1980@postgrespro.ru", "phone": "+70995772170"}
0005435149825	95FA38	4490 759924	LYUDMILA IVANOVA	{"email": "ivanovalyudmila_15031976@postgrespro.ru", "phone": "+70900572939"}
0005435149826	0C9AD9	4513 686803	DMITRIY MAKAROV	{"phone": "+70726044585"}
0005435149827	48C4EC	7070 305551	ANDREY ZAYCEV	{"phone": "+70118205398"}
0005435149828	99DDB2	9329 222410	KRISTINA IVANOVA	{"email": "ivanova-kristina.011975@postgrespro.ru", "phone": "+70367754632"}
0005435149829	99DDB2	6164 903916	LYUBOV RYABOVA	{"email": "l-ryabova031959@postgrespro.ru", "phone": "+70372152183"}
0005435149830	18539A	8452 094157	OLGA NOVIKOVA	{"email": "novikovaolga_1974@postgrespro.ru", "phone": "+70217535980"}
0005435149831	3B6DE5	1433 413165	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey011970@postgrespro.ru", "phone": "+70791056432"}
0005435149832	E0954D	5295 398631	VALERIY KOZLOV	{"phone": "+70555869001"}
0005435149833	8662F7	1940 934330	NADEZHDA ALEKSEEVA	{"phone": "+70191077723"}
0005435149834	5BCF9D	8457 664579	TATYANA MOROZOVA	{"email": "t.morozova-03091971@postgrespro.ru", "phone": "+70995729619"}
0005435149835	5BCF9D	7097 371987	KIRILL ABRAMOV	{"email": "abramov_k.121973@postgrespro.ru", "phone": "+70763899462"}
0005435149836	72CC33	1229 537876	ANATOLIY NOVIKOV	{"phone": "+70693858898"}
0005435149837	72CC33	0228 341577	YURIY POPOV	{"phone": "+70799342444"}
0005435149838	50AD2B	0407 554319	TATYANA OSIPOVA	{"email": "t.osipova_1970@postgrespro.ru", "phone": "+70038158324"}
0005435149839	553193	2518 275197	VLADIMIR POPOV	{"phone": "+70623605248"}
0005435149840	553193	5137 300418	ILYA ANTONOV	{"phone": "+70844793850"}
0005435149841	D1883E	6944 832234	KIRA MAKAROVA	{"phone": "+70767583034"}
0005435149842	D1883E	5519 980940	YURIY SAVELEV	{"phone": "+70720961488"}
0005435149843	A57AED	8191 365732	ELIZAVETA FOMINA	{"phone": "+70850183741"}
0005435149844	3AEB61	1417 244462	ANDREY TARASOV	{"phone": "+70553544775"}
0005435149845	7DB2CC	6948 380531	ANATOLIY NIKITIN	{"email": "a-nikitin08051977@postgrespro.ru", "phone": "+70821282249"}
0005435149846	7DB2CC	3043 462373	PAVEL VOLKOV	{"email": "p.volkov01051971@postgrespro.ru", "phone": "+70079449160"}
0005435149847	488079	6916 823666	YURIY KRASNOV	{"phone": "+70711649582"}
0005435149848	488079	0967 821815	IVAN SMIRNOV	{"email": "smirnov-ivan.081975@postgrespro.ru", "phone": "+70093874377"}
0005435149849	EFAC45	1017 740623	SERGEY FEDOROV	{"phone": "+70157258565"}
0005435149850	EFAC45	3605 330227	ZOYA MEDVEDEVA	{"phone": "+70595726501"}
0005435149851	10CDCE	0626 512988	ROZA KUZNECOVA	{"email": "kuznecova_roza-101974@postgrespro.ru", "phone": "+70146737681"}
0005435149852	10CDCE	0748 109111	LYUDMILA IVANOVA	{"email": "l_ivanova-24071973@postgrespro.ru", "phone": "+70839259324"}
0005435149853	5EB3F2	7449 657193	EVGENIY KARPOV	{"phone": "+70596746275"}
0005435149854	EEAEB5	5064 677614	VLADISLAV KUZNECOV	{"phone": "+70305457657"}
0005435149855	EA4D53	0867 402926	LYUDMILA ALEKSEEVA	{"email": "alekseeva.lyudmila23051979@postgrespro.ru", "phone": "+70551990993"}
0005435149856	BFC266	9889 733334	NIKOLAY SOKOLOV	{"phone": "+70062049076"}
0005435149857	BFC266	2213 074877	MIKHAIL VOLKOV	{"email": "volkov.m_13021971@postgrespro.ru", "phone": "+70039212436"}
0005435149858	88E9B4	6035 792124	VALERIY SEMENOV	{"phone": "+70912913233"}
0005435149859	19D078	4704 340070	EVGENIY FEDOTOV	{"email": "fedotov-e.011974@postgrespro.ru", "phone": "+70624766291"}
0005435149860	19D078	4112 611951	DARYA YUDINA	{"phone": "+70849627645"}
0005435149861	610BE9	4024 117704	NIKOLAY KULIKOV	{"email": "n.kulikov-10111958@postgrespro.ru", "phone": "+70528326131"}
0005435149862	610BE9	6915 370385	ALEKSANDR MEDVEDEV	{"phone": "+70041822229"}
0005435149863	610BE9	0444 942902	ALENA EGOROVA	{"email": "a_egorova_071973@postgrespro.ru", "phone": "+70278515656"}
0005435149864	CB81FA	3792 062101	MARIYA BELYAEVA	{"phone": "+70419627576"}
0005435149865	C994C9	6950 938671	LARISA OSIPOVA	{"phone": "+70549636937"}
0005435149866	2EDD77	6249 830275	ANDREY MEDVEDEV	{"email": "medvedev.a02041976@postgrespro.ru", "phone": "+70489273455"}
0005435149867	A9FE96	1301 147276	LYUBOV KONDRATEVA	{"email": "kondrateva_lyubov.1965@postgrespro.ru", "phone": "+70038808132"}
0005435149868	831E64	3228 620635	KONSTANTIN DMITRIEV	{"email": "dmitriev-k.1971@postgrespro.ru", "phone": "+70996283699"}
0005435149869	831E64	0848 490114	TAMARA BARANOVA	{"phone": "+70353238686"}
0005435149870	C4BCBF	2287 628512	ALEKSANDRA KULIKOVA	{"email": "kulikova.a_1980@postgrespro.ru", "phone": "+70784450118"}
0005435149871	C4BCBF	7065 792385	SVETLANA ZAKHAROVA	{"email": "s.zakharova_101963@postgrespro.ru", "phone": "+70458703236"}
0005435149872	C0B700	5269 486184	KRISTINA PETROVA	{"phone": "+70893710915"}
0005435149873	6E0BA0	9285 956143	ELENA OSIPOVA	{"phone": "+70087503494"}
0005435149874	5B449C	5395 549647	ELENA SOROKINA	{"email": "esorokina041963@postgrespro.ru", "phone": "+70365157443"}
0005435149875	5B449C	6220 471718	VALENTINA KARPOVA	{"email": "karpova_valentina031973@postgrespro.ru", "phone": "+70087078623"}
0005435149877	5A75F8	0270 365246	NATALYA KUZNECOVA	{"phone": "+70985596473"}
0005435149878	154A7D	4798 001558	ELENA POPOVA	{"email": "elenapopova_1976@postgrespro.ru", "phone": "+70649709915"}
0005435149879	154A7D	6735 942155	NIKOLAY PETROV	{"email": "petrovnikolay.1976@postgrespro.ru", "phone": "+70997394132"}
0005435149880	ED2628	6564 975054	TIMUR KOROLEV	{"email": "timurkorolev_01011961@postgrespro.ru", "phone": "+70386028943"}
0005435149881	3A4BFE	5963 196699	VLADIMIR KUDRYASHOV	{"phone": "+70093469730"}
0005435149882	F1DFA0	1336 249369	MARAT ILIN	{"email": "m_ilin.11011966@postgrespro.ru", "phone": "+70691167272"}
0005435149883	12C909	1546 362342	ALISHER MOROZOV	{"email": "morozov_a_06061972@postgrespro.ru", "phone": "+70487220412"}
0005435149884	56754D	7665 386351	MIKHAIL STEPANOV	{"email": "stepanov_m_1970@postgrespro.ru", "phone": "+70251343060"}
0005435149885	712EA4	4642 992515	VIKTORIYA MOROZOVA	{"email": "viktoriya_morozova-14101963@postgrespro.ru", "phone": "+70836984984"}
0005435149886	CC8A68	7427 509149	KONSTANTIN KAZAKOV	{"email": "konstantin.kazakov-051979@postgrespro.ru", "phone": "+70129108327"}
0005435149887	D8E1B0	0233 137387	PRASKOVYA KALININA	{"email": "kalininapraskovya071971@postgrespro.ru", "phone": "+70075002756"}
0005435149888	8364B5	6341 042787	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov.1990@postgrespro.ru", "phone": "+70300233399"}
0005435149889	C0E89D	8731 778755	DMITRIY DAVYDOV	{"email": "davydov.d-031979@postgrespro.ru", "phone": "+70756830702"}
0005435149890	C0E89D	5489 975561	VASILIY ZAYCEV	{"email": "vasiliy_zaycev_1973@postgrespro.ru", "phone": "+70345635423"}
0005435149891	7B5243	6626 084225	OLEG IVANOV	{"email": "o.ivanov24031979@postgrespro.ru", "phone": "+70210865857"}
0005435149892	5F9197	1102 872065	YURIY NOVIKOV	{"email": "y.novikov1977@postgrespro.ru", "phone": "+70328186419"}
0005435149893	5F9197	8162 113540	MARIYA FROLOVA	{"email": "m_frolova_071976@postgrespro.ru", "phone": "+70458029181"}
0005435149894	067B37	6563 499965	VYACHESLAV VASILEV	{"phone": "+70386264980"}
0005435149895	7BED5A	4066 021362	SVETLANA EFREMOVA	{"email": "s_efremova.031971@postgrespro.ru", "phone": "+70554567498"}
0005435149896	3B9644	8837 333775	VALENTINA ZAYCEVA	{"email": "valentina-zayceva_101974@postgrespro.ru", "phone": "+70495854157"}
0005435149897	3B9644	0324 649126	SVETLANA KOMAROVA	{"phone": "+70601065397"}
0005435149898	F4E254	3139 964860	SOFYA SOLOVEVA	{"email": "s-soloveva21101965@postgrespro.ru", "phone": "+70822728043"}
0005435149899	5247D6	4423 769346	LARISA MOROZOVA	{"email": "morozova-l.121974@postgrespro.ru", "phone": "+70753693142"}
0005435149900	BD0F1A	7812 684705	LYUBOV NIKOLAEVA	{"phone": "+70666729456"}
0005435149901	9EE3AA	9118 931530	ALSU PAVLOVA	{"email": "pavlova-alsu-021969@postgrespro.ru", "phone": "+70638216662"}
0005435149902	9EE3AA	4244 964056	LYAYSAN MAKSIMOVA	{"email": "lyaysan-maksimova_1971@postgrespro.ru", "phone": "+70561249153"}
0005435149903	9937A1	1227 376463	ARTUR MAKSIMOV	{"phone": "+70467039448"}
0005435149904	9937A1	7732 045404	MARIYA KOVALEVA	{"email": "kovalevam.051973@postgrespro.ru", "phone": "+70789729132"}
0005435149905	9937A1	5378 463525	EVGENIY MELNIKOV	{"email": "emelnikov.24051975@postgrespro.ru", "phone": "+70161322762"}
0005435149906	508100	0324 294017	ALINA IVANOVA	{"phone": "+70319049939"}
0005435149907	509849	7279 524889	GENNADIY IVANOV	{"email": "ivanov_gennadiy.19081973@postgrespro.ru", "phone": "+70624322905"}
0005435149908	509849	4461 820028	DAMIR MEDVEDEV	{"email": "medvedev.d-11011975@postgrespro.ru", "phone": "+70700748149"}
0005435149909	D904CC	4852 560584	OLEG NIKOLAEV	{"phone": "+70404283892"}
0005435149910	D904CC	6275 248997	IGOR EGOROV	{"email": "igoregorov.111968@postgrespro.ru", "phone": "+70443690756"}
0005435149911	A6B5FD	4521 264273	POLINA PETROVA	{"email": "p.petrova-1974@postgrespro.ru", "phone": "+70545222568"}
0005435149912	53F85D	8324 951063	ROMAN BELOV	{"email": "belovr_21111974@postgrespro.ru", "phone": "+70326359028"}
0005435149913	53F85D	6068 374521	TATYANA FADEEVA	{"email": "t-fadeeva_041982@postgrespro.ru", "phone": "+70924976802"}
0005435149914	E3A809	9764 712436	RAISA FOMINA	{"email": "r_fomina.1971@postgrespro.ru", "phone": "+70875264910"}
0005435149915	9A6E53	7648 314410	ILYA ABRAMOV	{"email": "abramov_i-1962@postgrespro.ru", "phone": "+70701131010"}
0005435149916	F72E11	3628 999917	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov1968@postgrespro.ru", "phone": "+70026291593"}
0005435149917	89C923	5174 904312	DMITRIY OSIPOV	{"phone": "+70133151855"}
0005435149918	3CA29A	1525 863813	TATYANA KULIKOVA	{"phone": "+70026196908"}
0005435149919	3CA29A	1159 065272	EGOR KARPOV	{"email": "e.karpov-1965@postgrespro.ru", "phone": "+70504212599"}
0005435149920	DD8736	3271 806370	ALEKSANDR KONOVALOV	{"email": "konovalov_a_30081965@postgrespro.ru", "phone": "+70413663895"}
0005435149921	DD8736	2093 107376	NIKITA KOZLOV	{"email": "kozlov.n16071980@postgrespro.ru", "phone": "+70997134291"}
0005435149922	3D4042	2816 005825	NATALYA POPOVA	{"email": "n.popova-051975@postgrespro.ru", "phone": "+70671868379"}
0005435149923	3D4042	5477 775027	ARINA MAKSIMOVA	{"phone": "+70992816309"}
0005435149924	0ACDD0	2564 245682	EKATERINA ZAYCEVA	{"phone": "+70053977473"}
0005435149925	0ACDD0	5904 845928	TATYANA ARKHIPOVA	{"phone": "+70776180330"}
0005435149926	24EC98	6782 167593	ELENA TIMOFEEVA	{"email": "e.timofeeva17121974@postgrespro.ru", "phone": "+70013914237"}
0005435149927	93C9F1	2743 880608	ANTONINA ANTONOVA	{"phone": "+70262851341"}
0005435149928	79E321	4340 665865	RAMILYA GORBUNOVA	{"phone": "+70271665472"}
0005435149929	06633F	0567 801901	LYUBOV OVCHINNIKOVA	{"phone": "+70563487507"}
0005435149930	7A10AB	6987 538780	ANDREY ROMANOV	{"phone": "+70754367276"}
0005435149931	3DE226	4763 602291	IGOR KRASNOV	{"phone": "+70165965968"}
0005435149932	A28D1B	8996 737293	IGOR NOVIKOV	{"phone": "+70688906836"}
0005435149933	43C77F	0111 274006	ANATOLIY ROMANOV	{"phone": "+70571436445"}
0005435149934	2FFA17	1406 764732	VALENTIN ALEKSEEV	{"phone": "+70282773087"}
0005435149935	5FECB9	3032 534146	YULIANA KAZAKOVA	{"email": "yuliana_kazakova_111967@postgrespro.ru", "phone": "+70636878236"}
0005435149936	5FECB9	4958 607749	DENIS TARASOV	{"email": "tarasov.d-1972@postgrespro.ru", "phone": "+70062389761"}
0005435149937	A84DDE	9049 271733	NATALYA KISELEVA	{"phone": "+70840938188"}
0005435149938	A84DDE	2240 133833	NIKOLAY IVANOV	{"email": "n-ivanov1987@postgrespro.ru", "phone": "+70744918086"}
0005435149939	8C79C4	4511 162868	RIMMA SERGEEVA	{"phone": "+70792219613"}
0005435149940	341A23	4051 773454	GALINA TITOVA	{"phone": "+70057168182"}
0005435149941	5436D2	2840 577396	ANDREY BORISOV	{"email": "borisov_andrey30011970@postgrespro.ru", "phone": "+70410560276"}
0005435149942	2EDD82	3370 189891	ROMAN FEDOROV	{"email": "romanfedorov.1989@postgrespro.ru", "phone": "+70782335268"}
0005435149943	0A8F40	8953 595333	DENIS MEDVEDEV	{"email": "medvedev.denis1983@postgrespro.ru", "phone": "+70045832492"}
0005435149944	8A4125	8678 635850	GALINA NIKITINA	{"phone": "+70629564549"}
0005435149945	753ED1	8108 753585	MARIYA SAVELEVA	{"email": "mariya-saveleva121979@postgrespro.ru", "phone": "+70197860462"}
0005435149946	CA4E10	8284 987925	TATYANA MOISEEVA	{"email": "t_moiseeva1978@postgrespro.ru", "phone": "+70303691616"}
0005435149947	CA4E10	9165 417916	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov_121966@postgrespro.ru", "phone": "+70626869587"}
0005435149948	1BF619	7792 912506	ALEKSANDR EGOROV	{"email": "egorov-a_18121975@postgrespro.ru", "phone": "+70917542123"}
0005435149949	1BF619	1116 355332	ANNA GORBUNOVA	{"phone": "+70431413365"}
0005435149950	C36B72	6765 486010	ELENA LAZAREVA	{"email": "lazareva-elena1988@postgrespro.ru", "phone": "+70946456085"}
0005435149951	DD0DB7	5773 688722	SERGEY EGOROV	{"email": "egorov.s-011965@postgrespro.ru", "phone": "+70205015627"}
0005435149952	CB1672	9533 918664	OLESYA DAVYDOVA	{"phone": "+70516816038"}
0005435149953	52778B	4592 982703	SVETLANA MAKAROVA	{"phone": "+70292225186"}
0005435149954	52778B	2067 220960	MARIYA SOROKINA	{"phone": "+70121106589"}
0005435149955	573C16	6899 374316	VIKTOR SEMENOV	{"phone": "+70364545334"}
0005435149956	A3E080	1896 078804	ROSTISLAV IVANOV	{"phone": "+70613066476"}
0005435149957	A3E080	2257 199359	OLGA POTAPOVA	{"phone": "+70999705744"}
0005435149958	57878D	1706 905946	EKATERINA KUZMINA	{"email": "ekuzmina-041968@postgrespro.ru", "phone": "+70218536654"}
0005435149959	57878D	8016 835816	GALINA ALEKSANDROVA	{"phone": "+70430648648"}
0005435149960	A03968	4299 958950	ALEVTINA KUZNECOVA	{"phone": "+70245127254"}
0005435149961	C3BF1A	5185 302466	VIKTOR KUZNECOV	{"phone": "+70469857755"}
0005435149962	6E2CEB	7214 028914	TATYANA MAKAROVA	{"email": "makarovat26061984@postgrespro.ru", "phone": "+70127646108"}
0005435149963	FA86B9	9090 849569	RAISA VOLKOVA	{"phone": "+70214807679"}
0005435149964	4AD8D3	5863 811836	RIMMA DMITRIEVA	{"email": "r-dmitrieva1982@postgrespro.ru", "phone": "+70049492175"}
0005435149965	4AD8D3	1953 762066	GALINA IVANOVA	{"email": "ivanova-galina_23031971@postgrespro.ru", "phone": "+70283982327"}
0005435149966	88C617	8175 392328	SERGEY ILIN	{"email": "s-ilin22061967@postgrespro.ru", "phone": "+70306731489"}
0005435149967	409F9F	3656 060525	ELIZAVETA GUSEVA	{"email": "elizavetaguseva_1960@postgrespro.ru", "phone": "+70927238711"}
0005435149968	409F9F	5864 792719	EVGENIY POPOV	{"email": "popov_e-03081969@postgrespro.ru", "phone": "+70978465329"}
0005435149969	E38003	4590 382381	EVGENIY ANDREEV	{"email": "e.andreev.1972@postgrespro.ru", "phone": "+70014610111"}
0005435149970	E38003	8029 704866	SVETLANA KUZNECOVA	{"email": "s.kuznecova_1971@postgrespro.ru", "phone": "+70116594476"}
0005435149971	EA3CB8	3018 911986	ARTEM VASILEV	{"email": "artem_vasilev_011975@postgrespro.ru", "phone": "+70452652189"}
0005435149972	B7284A	3826 782415	NATALYA FROLOVA	{"email": "frolovan-1974@postgrespro.ru", "phone": "+70979203007"}
0005435149973	B7284A	0179 223784	VERONIKA SMIRNOVA	{"phone": "+70925309048"}
0005435149974	798391	0927 804623	ALLA RYABOVA	{"email": "alla_ryabova.081971@postgrespro.ru", "phone": "+70786926881"}
0005435149975	93F4AD	4153 250456	DARYA PETROVA	{"phone": "+70166086915"}
0005435149976	D100BD	4433 837234	EVGENIYA GUSEVA	{"email": "e-guseva.031976@postgrespro.ru", "phone": "+70668517340"}
0005435149977	D100BD	6379 164759	LYUDMILA SOKOLOVA	{"phone": "+70775898273"}
0005435149978	C68F9B	7569 351228	TATYANA ZAYCEVA	{"phone": "+70131326049"}
0005435149979	2E914B	4678 758279	MARIYA ZAKHAROVA	{"email": "zakharova-mariya_1973@postgrespro.ru", "phone": "+70110935990"}
0005435149980	13EFE1	3717 318043	MARINA NIKIFOROVA	{"email": "marinanikiforova07071971@postgrespro.ru", "phone": "+70878808236"}
0005435149981	13EFE1	3434 239950	IRINA ZAYCEVA	{"email": "irina-zayceva061969@postgrespro.ru", "phone": "+70551313360"}
0005435149982	CE34CA	3553 939804	LYUBOV MASLOVA	{"phone": "+70071558747"}
0005435149983	89C90B	9875 528384	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir08021976@postgrespro.ru", "phone": "+70197880130"}
0005435149984	A99C84	2165 281135	MARINA PAVLOVA	{"email": "pavlova-marina.12051980@postgrespro.ru", "phone": "+70226999844"}
0005435149985	832AAD	5302 605139	GEORGIY NIKOLAEV	{"phone": "+70612742544"}
0005435149986	39EA33	6136 401686	LYUBOV SERGEEVA	{"email": "lsergeeva.1987@postgrespro.ru", "phone": "+70262797812"}
0005435149987	7AD541	3858 867196	SERGEY OSIPOV	{"email": "sergey.osipov-1970@postgrespro.ru", "phone": "+70009220741"}
0005435149988	458966	0898 341420	RAMILYA ROMANOVA	{"email": "rromanova22121967@postgrespro.ru", "phone": "+70726270350"}
0005435149989	458966	0287 479461	VASILIY KOROLEV	{"email": "korolevv_091981@postgrespro.ru", "phone": "+70486589755"}
0005435149990	2919DB	6058 031007	TATYANA IVANOVA	{"email": "t-ivanova-07121970@postgrespro.ru", "phone": "+70947076082"}
0005435149991	2919DB	3043 715447	ARTEMIY STEPANOV	{"email": "stepanov.a12011966@postgrespro.ru", "phone": "+70685066038"}
0005435149992	101D8C	7871 823297	NATALYA SMIRNOVA	{"email": "nsmirnova101965@postgrespro.ru", "phone": "+70773826701"}
0005435149993	101D8C	8234 514443	GALINA ZOTOVA	{"email": "zotova_g_15011961@postgrespro.ru", "phone": "+70529229613"}
0005435149994	610A9F	2965 935007	YULIYA OSIPOVA	{"email": "osipova_y.041975@postgrespro.ru", "phone": "+70841714440"}
0005435149995	610A9F	8919 065276	KLAVDIYA KONOVALOVA	{"email": "k_konovalova1973@postgrespro.ru", "phone": "+70059523770"}
0005435149996	1BCCE0	8090 844170	IVAN MAKAROV	{"email": "makarov-i.121975@postgrespro.ru", "phone": "+70147177480"}
0005435149997	C2EC22	0982 551030	DMITRIY TIMOFEEV	{"email": "timofeev.d.081977@postgrespro.ru", "phone": "+70544935591"}
0005435149998	F28879	0510 727756	POLINA ABRAMOVA	{"phone": "+70912883134"}
0005435149999	F05A31	9091 635173	ALEKSANDR KUZNECOV	{"phone": "+70041977438"}
0005435150000	F92E8F	7195 186012	ALEKSANDR NIKOLAEV	{"phone": "+70175233693"}
0005435150001	F92E8F	8772 270250	ALEKSANDR MEDVEDEV	{"email": "medvedeva091972@postgrespro.ru", "phone": "+70130158392"}
0005435150002	FD751D	7689 436990	ANDREY ANDREEV	{"email": "aandreev.1980@postgrespro.ru", "phone": "+70708781340"}
0005435150003	1A87FD	1372 058787	TIMUR GORBUNOV	{"email": "timur-gorbunov-121977@postgrespro.ru", "phone": "+70470036775"}
0005435150004	F8BA8A	9327 095902	RUSLAN KUZMIN	{"phone": "+70294472747"}
0005435150005	EAE030	3527 673918	IRINA GERASIMOVA	{"email": "gerasimovairina1972@postgrespro.ru", "phone": "+70385047646"}
0005435150006	EAE030	4639 327016	LIDIYA GERASIMOVA	{"email": "gerasimova_lidiya_1974@postgrespro.ru", "phone": "+70636167356"}
0005435150007	38391D	0470 497374	RAFIK ALEKSEEV	{"email": "alekseev-rafik_1972@postgrespro.ru", "phone": "+70144066624"}
0005435150008	A0CDB4	7736 997028	FEDOR MIKHAYLOV	{"email": "mikhaylov-fedor-1959@postgrespro.ru", "phone": "+70917036402"}
0005435150009	3D65C9	8363 559248	ELENA KUZNECOVA	{"email": "e_kuznecova.27021979@postgrespro.ru", "phone": "+70507676714"}
0005435150010	3D65C9	2071 967620	ALEKSANDR SOROKIN	{"email": "asorokin.26041979@postgrespro.ru", "phone": "+70198190046"}
0005435150011	47DD85	0033 504158	DMITRIY VOROBEV	{"phone": "+70661223851"}
0005435150012	15F0A8	1720 515780	SVETLANA SMIRNOVA	{"email": "smirnova_s-031979@postgrespro.ru", "phone": "+70918645569"}
0005435150013	F420ED	7434 661236	OLESYA GORBUNOVA	{"email": "o_gorbunova11111974@postgrespro.ru", "phone": "+70932535930"}
0005435150014	F420ED	7880 377501	PAVEL SAVELEV	{"email": "savelev-pavel_11091975@postgrespro.ru", "phone": "+70499949885"}
0005435150015	6C6F8A	4317 020333	LYUBOV KRASNOVA	{"email": "krasnova-l.011972@postgrespro.ru", "phone": "+70036796688"}
0005435150016	A53F88	0128 835461	SERGEY MARTYNOV	{"phone": "+70043757368"}
0005435150017	A53F88	9019 020893	MIKHAIL FILIPPOV	{"phone": "+70961259269"}
0005435150018	FFDC4C	9439 083662	NATALYA EFIMOVA	{"phone": "+70668788148"}
0005435150019	92043D	4020 605348	GENNADIY FEDOTOV	{"email": "gennadiyfedotov26011969@postgrespro.ru", "phone": "+70592671197"}
0005435150020	2C44AF	4819 923071	OLEG VOLKOV	{"email": "volkov.oleg-1965@postgrespro.ru", "phone": "+70844858084"}
0005435150021	2C44AF	9750 825731	ANASTASIYA KISELEVA	{"email": "kiseleva-a.21091972@postgrespro.ru", "phone": "+70728122644"}
0005435150022	2E7C0A	3611 953592	IRINA TROFIMOVA	{"phone": "+70088160027"}
0005435150023	2C7363	3691 660987	MARINA MIKHAYLOVA	{"email": "mikhaylova-marina20101975@postgrespro.ru", "phone": "+70847108925"}
0005435150024	64B791	9094 415425	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir-041973@postgrespro.ru", "phone": "+70259653557"}
0005435150025	444322	8867 660573	ALEKSANDR MATVEEV	{"email": "a.matveev-1961@postgrespro.ru", "phone": "+70297842444"}
0005435150026	5B08CC	2241 894735	ANATOLIY KONOVALOV	{"phone": "+70986564049"}
0005435150027	5B08CC	7256 085987	SERAFIMA KOZLOVA	{"email": "s_kozlova-041975@postgrespro.ru", "phone": "+70916749396"}
0005435150028	DEA156	9053 797457	EKATERINA ANTONOVA	{"phone": "+70530857351"}
0005435150029	5CDDFB	1652 845612	DMITRIY MAKAROV	{"email": "makarov.d07011973@postgrespro.ru", "phone": "+70772074340"}
0005435150030	544BDB	4790 675666	LYUBOV IVANOVA	{"email": "ivanova.l20111974@postgrespro.ru", "phone": "+70174299480"}
0005435150031	5545BE	2175 220700	NIKOLAY DAVYDOV	{"email": "davydov_n_1964@postgrespro.ru", "phone": "+70988251617"}
0005435150032	5545BE	6487 387969	VIKTOR IVANOV	{"phone": "+70419825547"}
0005435150033	275B1B	6016 156826	YULIYA KUZNECOVA	{"phone": "+70781489821"}
0005435150034	E6E0BF	1625 496729	VIKTORIYA SAVELEVA	{"phone": "+70486688078"}
0005435150035	A10CBD	4986 741250	NATALYA YAKOVLEVA	{"email": "natalya-yakovleva_29061972@postgrespro.ru", "phone": "+70092006947"}
0005435150036	EA83E0	5453 978923	TAMARA BOGDANOVA	{"phone": "+70627127880"}
0005435150037	104F5F	6287 490400	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev1971@postgrespro.ru", "phone": "+70970295014"}
0005435150038	0C7F61	9948 274772	VADIM NAZAROV	{"email": "nazarov_v-091973@postgrespro.ru", "phone": "+70298440651"}
0005435150039	803401	2489 155154	PAVEL ANTONOV	{"phone": "+70164146098"}
0005435150040	61DF3A	7330 960489	OLGA FILIPPOVA	{"phone": "+70296731672"}
0005435150041	61DF3A	2708 765695	VLADISLAV ZAYCEV	{"phone": "+70410652163"}
0005435150042	56BD37	1347 159413	ALEKSEY MELNIKOV	{"email": "melnikov-aleksey_111983@postgrespro.ru", "phone": "+70960138658"}
0005435150043	56BD37	4348 267169	SVETLANA KOLESNIKOVA	{"phone": "+70507722565"}
0005435150044	95AF34	3533 266459	STEPAN FEDOROV	{"email": "fedorov-stepan_16101978@postgrespro.ru", "phone": "+70798690210"}
0005435150045	504BDF	9187 528924	ALEKSANDR GORBUNOV	{"email": "a-gorbunov16111972@postgrespro.ru", "phone": "+70444882918"}
0005435150046	504BDF	9313 794844	OLGA MELNIKOVA	{"phone": "+70396868708"}
0005435150047	E75A77	5986 743041	MARINA GRISHINA	{"email": "marinagrishina.071972@postgrespro.ru", "phone": "+70256197131"}
0005435150048	D73C8F	2599 109850	MATVEY MOISEEV	{"email": "moiseev.matvey-1972@postgrespro.ru", "phone": "+70980430890"}
0005435150049	D73C8F	5569 672124	DMITRIY PAVLOV	{"phone": "+70132143484"}
0005435150050	54DF71	4955 004654	ANASTASIYA KRASNOVA	{"phone": "+70950556537"}
0005435150051	54DF71	8442 949960	NADEZHDA BELYAEVA	{"email": "n_belyaeva_081969@postgrespro.ru", "phone": "+70650090300"}
0005435150052	0C2548	0391 193000	ALBINA KALININA	{"phone": "+70155650893"}
0005435150053	02CAF9	9428 815307	ANATOLIY IVANOV	{"email": "ivanov-anatoliy-01041963@postgrespro.ru", "phone": "+70542368068"}
0005435150054	9016E2	2676 290884	NATALYA MARTYNOVA	{"email": "martynova_natalya.1973@postgrespro.ru", "phone": "+70194529438"}
0005435150055	E95E47	2744 915444	ALEKSEY SOLOVEV	{"phone": "+70972685969"}
0005435150056	2DA21D	2475 516751	OLEG FROLOV	{"email": "ofrolov_1985@postgrespro.ru", "phone": "+70028065153"}
0005435150057	A7546D	9923 063320	SVETLANA SAVELEVA	{"phone": "+70088763295"}
0005435150058	A7546D	2166 684823	VYACHESLAV KUZNECOV	{"email": "kuznecov.vyacheslav_01011970@postgrespro.ru", "phone": "+70958401491"}
0005435150059	5764CE	2478 377328	NIKOLAY VOROBEV	{"email": "vorobev_n-22121974@postgrespro.ru", "phone": "+70932762324"}
0005435150060	2EEB7B	7620 728235	IGOR KUZNECOV	{"email": "kuznecov_i.24021978@postgrespro.ru", "phone": "+70512639793"}
0005435150061	511315	1225 439109	NINA MOROZOVA	{"phone": "+70477129113"}
0005435150062	511315	0257 434627	VALENTIN VOLKOV	{"phone": "+70516678667"}
0005435150063	E119FA	0530 175368	ARTEM VLASOV	{"email": "avlasov-051981@postgrespro.ru", "phone": "+70498946865"}
0005435150064	E119FA	9711 779759	MIKHAIL KUZMIN	{"phone": "+70880391049"}
0005435150065	65D4FE	9237 901725	ALEKSEY ANDREEV	{"phone": "+70990027160"}
0005435150066	24FD92	4641 829620	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin-1977@postgrespro.ru", "phone": "+70964987218"}
0005435150067	35E390	1838 029236	LEONID GUSEV	{"phone": "+70780136823"}
0005435150068	39EE59	5747 333080	POLINA OVCHINNIKOVA	{"phone": "+70861096307"}
0005435150069	39EE59	8516 706189	SVETLANA DMITRIEVA	{"phone": "+70630205757"}
0005435150070	39EE59	1725 247909	ALEKSEY KOROLEV	{"email": "alekseykorolev22111972@postgrespro.ru", "phone": "+70064971077"}
0005435150071	592CE0	6808 361753	MARINA FEDOROVA	{"email": "fedorova_m071970@postgrespro.ru", "phone": "+70017489336"}
0005435150072	592CE0	1290 104205	VLADIMIR FROLOV	{"phone": "+70938035024"}
0005435150073	592CE0	0696 920008	MAKSIM KOZLOV	{"email": "kozlov-maksim_1969@postgrespro.ru", "phone": "+70841145304"}
0005435150074	019632	4477 772449	OLESYA NAZAROVA	{"phone": "+70990697788"}
0005435150075	463FE8	2111 930965	NIKOLAY MAKAROV	{"phone": "+70155394688"}
0005435150076	463FE8	0771 536906	NATALYA BORISOVA	{"email": "borisovanatalya17101982@postgrespro.ru", "phone": "+70239884172"}
0005435150077	29B14A	8644 117242	DMITRIY BORISOV	{"phone": "+70302412038"}
0005435150078	29B14A	2053 129465	TATYANA MOISEEVA	{"email": "t_moiseeva_30011971@postgrespro.ru", "phone": "+70822656086"}
0005435150079	6A586F	8711 943708	ANDREY VOROBEV	{"email": "andrey_vorobev071971@postgrespro.ru", "phone": "+70281749951"}
0005435150080	6A586F	4190 790609	VERONIKA VLASOVA	{"email": "v_vlasova1967@postgrespro.ru", "phone": "+70742849606"}
0005435150081	6A586F	1753 038092	YURIY KUDRYASHOV	{"phone": "+70167538208"}
0005435150082	C3A568	6304 519407	DENIS ISAEV	{"phone": "+70041353634"}
0005435150083	33DF6A	8186 380705	SVETLANA FILATOVA	{"phone": "+70878582760"}
0005435150084	33DF6A	5101 529014	DARYA OSIPOVA	{"phone": "+70834245346"}
0005435150085	A75D11	5967 694634	OLGA EFIMOVA	{"phone": "+70474590598"}
0005435150086	33DBCD	7415 663010	ALEKSANDR PETROV	{"email": "aleksandr.petrov101964@postgrespro.ru", "phone": "+70847906327"}
0005435150087	0452AF	8263 013589	MIKHAIL EGOROV	{"email": "egorov-m-1970@postgrespro.ru", "phone": "+70661192177"}
0005435150088	11F292	0114 231971	ALEKSANDRA SAVELEVA	{"email": "saveleva_aleksandra.15051970@postgrespro.ru", "phone": "+70060073275"}
0005435150089	E616B3	5762 845919	OLGA FOMINA	{"phone": "+70351825714"}
0005435150090	2B441C	6819 227929	NADEZHDA KAZAKOVA	{"phone": "+70877057395"}
0005435150091	D6D45A	2469 363622	DANIL KOROLEV	{"phone": "+70708420299"}
0005435150092	53A838	4544 485935	IVAN NIKITIN	{"email": "nikitin_i.091966@postgrespro.ru", "phone": "+70899915732"}
0005435150093	B18CB0	3258 370817	ALEKSANDR GUSEV	{"email": "gusev_aleksandr_1975@postgrespro.ru", "phone": "+70209744872"}
0005435150094	EF2878	2141 853420	ARTEM AFANASEV	{"phone": "+70391344171"}
0005435150095	EF2878	8325 191223	NATALYA RODIONOVA	{"phone": "+70229961945"}
0005435150096	C27CE1	6664 922451	DMITRIY NIKITIN	{"email": "nikitin.d_061962@postgrespro.ru", "phone": "+70386728962"}
0005435150097	8C2086	9791 552985	ILYA SAVELEV	{"email": "ilyasavelev051970@postgrespro.ru", "phone": "+70306712895"}
0005435150098	1AD531	5649 392378	EVGENIY STEPANOV	{"email": "evgeniy-stepanov-121977@postgrespro.ru", "phone": "+70191965918"}
0005435150099	0DE196	2144 151133	YURIY BORISOV	{"phone": "+70254488151"}
0005435150100	B86CF0	9750 788994	ALLA KUZMINA	{"email": "alla-kuzmina-29011978@postgrespro.ru", "phone": "+70260220267"}
0005435150101	0E1BA6	2043 186584	NATALYA PAVLOVA	{"phone": "+70600624567"}
0005435150102	726E21	8312 776985	GRIGORIY MIKHAYLOV	{"phone": "+70406804257"}
0005435150103	7BD79A	8168 097264	EVGENIY ZAKHAROV	{"email": "zakharov-evgeniy_23111967@postgrespro.ru", "phone": "+70341442399"}
0005435150104	7BD79A	6288 877316	OLGA NESTEROVA	{"phone": "+70897067426"}
0005435150105	FD4701	1028 038331	ZHANNA MASLOVA	{"email": "zmaslova.091966@postgrespro.ru", "phone": "+70246067995"}
0005435150106	A62EEA	8687 526726	VERA ERMAKOVA	{"phone": "+70346665805"}
0005435150107	A62EEA	4345 782112	LYUBOV KONOVALOVA	{"email": "konovaloval.111968@postgrespro.ru", "phone": "+70728300910"}
0005435150108	B02156	2033 950636	MIKHAIL MAKAROV	{"phone": "+70284762201"}
0005435150109	B02156	6766 113058	SERGEY KUZNECOV	{"phone": "+70282650640"}
0005435150110	F64D81	7926 368400	OLEG MAKSIMOV	{"email": "omaksimov.1976@postgrespro.ru", "phone": "+70911637766"}
0005435150111	CDFCE8	5040 615424	LIDIYA IVANOVA	{"email": "ivanova.lidiya1976@postgrespro.ru", "phone": "+70690489012"}
0005435150112	450D54	1008 284537	GALINA KUZNECOVA	{"phone": "+70495558715"}
0005435150113	AD2FE7	5249 844528	VITALIY GERASIMOV	{"phone": "+70855736909"}
0005435150114	06ADC5	9412 793976	VIKTOR PAVLOV	{"email": "pavlov-viktor1987@postgrespro.ru", "phone": "+70787079795"}
0005435150115	06ADC5	4998 639728	ALEKSEY OSIPOV	{"phone": "+70820771633"}
0005435150116	06ADC5	6869 027312	VITALIY FILIPPOV	{"email": "filippov_vitaliy_1958@postgrespro.ru", "phone": "+70148048098"}
0005435150117	A01DDE	0133 843665	SERGEY DENISOV	{"email": "denisov-s071959@postgrespro.ru", "phone": "+70076787487"}
0005435150118	1E186C	6642 827932	NIKOLAY MAKAROV	{"email": "makarov_nikolay_01061962@postgrespro.ru", "phone": "+70148017402"}
0005435150119	FEE8A7	7573 587473	ANTON POPOV	{"phone": "+70181798200"}
0005435150120	6D1857	5134 012782	ALEKSEY VASILEV	{"email": "vasilev_aleksey051979@postgrespro.ru", "phone": "+70155380417"}
0005435150121	988C87	8628 782628	ANDREY FEDOTOV	{"email": "fedotov_a-121970@postgrespro.ru", "phone": "+70283101269"}
0005435150122	42E8AB	2339 990571	VLADIMIR KUZMIN	{"phone": "+70479369650"}
0005435150123	42E8AB	8330 259028	TAMARA RODIONOVA	{"phone": "+70239343914"}
0005435150124	E086C7	4325 512437	DMITRIY POPOV	{"phone": "+70962761058"}
0005435150125	4E19FD	6023 205237	SOFYA ALEKSEEVA	{"email": "alekseeva.sofya071970@postgrespro.ru", "phone": "+70253228841"}
0005435150126	F4A989	9722 259241	VALENTINA PAVLOVA	{"phone": "+70268803550"}
0005435150127	07204F	8673 629586	VYACHESLAV ANDREEV	{"email": "andreev.vyacheslav-1981@postgrespro.ru", "phone": "+70316962675"}
0005435150128	18F3E4	9389 083347	ALEKSANDR TIKHONOV	{"phone": "+70039040136"}
0005435150129	F02272	8250 797825	VLADIMIR NIKITIN	{"phone": "+70026322944"}
0005435150130	BAB599	6235 525091	IVAN ANDREEV	{"phone": "+70419041825"}
0005435150131	BAB599	0511 100704	VLADIMIR KONOVALOV	{"email": "konovalovvladimir.121954@postgrespro.ru", "phone": "+70754140959"}
0005435150132	BAB599	4030 939943	IVAN ANTONOV	{"email": "antonov.i-12051979@postgrespro.ru", "phone": "+70229544515"}
0005435150133	9B9ACD	8268 809354	ELENA KOMAROVA	{"phone": "+70108149900"}
0005435150134	9B9ACD	9412 994095	NIKOLAY YAKOVLEV	{"phone": "+70396647748"}
0005435150135	2AE0B5	7362 564436	VALENTINA GRISHINA	{"email": "grishina.v.081980@postgrespro.ru", "phone": "+70871399618"}
0005435150136	2AE0B5	3281 968448	IVAN GRIGOREV	{"email": "grigorevivan_27071981@postgrespro.ru", "phone": "+70604094344"}
0005435150137	2AE0B5	7518 333272	VIKTOR VASILEV	{"email": "vasilevv_061988@postgrespro.ru", "phone": "+70514977242"}
0005435150138	2AE0B5	8205 026308	ANASTASIYA TIKHONOVA	{"phone": "+70690086654"}
0005435150139	D9E3BB	4650 288622	ARTEM STEPANOV	{"email": "stepanov.artem-08061964@postgrespro.ru", "phone": "+70577658981"}
0005435150140	529C61	5032 474473	OLGA TARASOVA	{"email": "o_tarasova-1976@postgrespro.ru", "phone": "+70015831465"}
0005435150141	106B6B	0267 344960	EVGENIYA KUZMINA	{"email": "e_kuzmina-091970@postgrespro.ru", "phone": "+70544671246"}
0005435150142	E987D4	5471 254714	ALBERT FROLOV	{"email": "albert-frolov_1971@postgrespro.ru", "phone": "+70080219553"}
0005435150143	4AEB84	7635 873579	VLADIMIR SHEVCHENKO	{"email": "shevchenko.v061971@postgrespro.ru", "phone": "+70273954968"}
0005435150144	E12F49	5628 714923	ALEKSANDRA PETROVA	{"email": "petrova-a_061986@postgrespro.ru", "phone": "+70823272810"}
0005435150145	77B67D	8643 388097	OLGA IVANOVA	{"phone": "+70536252210"}
0005435150146	77B67D	1212 472149	ELENA LAZAREVA	{"email": "lazareva.e1963@postgrespro.ru", "phone": "+70117266273"}
0005435150147	EF4478	2091 687815	PETR TIKHONOV	{"email": "petrtikhonov_1974@postgrespro.ru", "phone": "+70692970324"}
0005435150148	FACE13	9857 531211	ALEKSEY SIDOROV	{"email": "alekseysidorov-101976@postgrespro.ru", "phone": "+70538169072"}
0005435150149	5EC371	5516 002911	EKATERINA SCHERBAKOVA	{"email": "e.scherbakova-041978@postgrespro.ru", "phone": "+70791787308"}
0005435150150	5EC371	6192 085813	EGOR EGOROV	{"phone": "+70106556625"}
0005435150207	EF1971	4121 253671	KRISTINA MIKHAYLOVA	{"phone": "+70690255679"}
0005435150151	EA6F58	7540 308923	ELENA SERGEEVA	{"email": "e-sergeeva_26091972@postgrespro.ru", "phone": "+70864005265"}
0005435150152	F432B9	8192 440862	NIKOLAY VOLKOV	{"phone": "+70784591158"}
0005435150153	5EDBC1	6815 842864	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov_05031979@postgrespro.ru", "phone": "+70538449757"}
0005435150154	5EDBC1	4020 846005	MATVEY NIKOLAEV	{"email": "m_nikolaev_25121971@postgrespro.ru", "phone": "+70127242623"}
0005435150155	EA8CA4	7719 450744	DENIS KUZNECOV	{"phone": "+70767833437"}
0005435150156	F29A90	5865 616997	PAVEL DMITRIEV	{"email": "dmitriev_p-11071968@postgrespro.ru", "phone": "+70620027961"}
0005435150157	1B9B03	0169 667128	DARYA BELOVA	{"email": "darya.belova.24061970@postgrespro.ru", "phone": "+70828266590"}
0005435150158	AC9DF8	2973 569481	IVAN SMIRNOV	{"phone": "+70500058708"}
0005435150159	0ECE54	9051 200648	GALINA SERGEEVA	{"phone": "+70668859984"}
0005435150160	E53B41	8772 701939	NATALYA GRISHINA	{"email": "n.grishina.1976@postgrespro.ru", "phone": "+70816672844"}
0005435150161	A2CC0E	8599 683557	VIKTOR GRIGOREV	{"email": "grigorev-viktor_041966@postgrespro.ru", "phone": "+70025641581"}
0005435150162	A2CC0E	3528 948594	NATALYA SERGEEVA	{"phone": "+70796872643"}
0005435150163	226004	8800 466491	NINA VOROBEVA	{"phone": "+70231416286"}
0005435150164	226004	5298 761429	NIKOLAY KARPOV	{"email": "nikolay_karpov-071980@postgrespro.ru", "phone": "+70441056847"}
0005435150165	8F7117	6844 842499	RAFAEL NAZAROV	{"phone": "+70794047198"}
0005435150166	2D6F49	4809 176232	OLGA LOGINOVA	{"email": "loginova-olga30091970@postgrespro.ru", "phone": "+70079453401"}
0005435150167	2D6F49	2449 182229	VITALIY NAZAROV	{"phone": "+70776798566"}
0005435150168	7DCD5E	2670 783674	ZINAIDA EFIMOVA	{"email": "z.efimova.111976@postgrespro.ru", "phone": "+70387137764"}
0005435150169	7DCD5E	9805 202362	SERGEY KOROLEV	{"email": "korolev.s071976@postgrespro.ru", "phone": "+70457061940"}
0005435150170	4D1E45	6459 568155	ANASTASIYA POPOVA	{"email": "popova_a-111974@postgrespro.ru", "phone": "+70308015848"}
0005435150171	4D1E45	3263 837134	IVAN FEDOROV	{"phone": "+70858868002"}
0005435150172	8E909F	7117 453106	ELENA KUZNECOVA	{"email": "kuznecova-elena1963@postgrespro.ru", "phone": "+70238513821"}
0005435150173	8E909F	8792 005291	LYUDMILA IVANOVA	{"phone": "+70674114895"}
0005435150174	4CC7E1	7216 255456	NINA ZHUKOVA	{"phone": "+70991768767"}
0005435150175	4CC7E1	0658 919921	NATALYA IVANOVA	{"email": "n_ivanova051978@postgrespro.ru", "phone": "+70639959013"}
0005435150176	618E6F	5047 067128	EDUARD MELNIKOV	{"phone": "+70925901165"}
0005435150177	618E6F	7963 764991	DMITRIY KOROLEV	{"email": "d.korolev1978@postgrespro.ru", "phone": "+70766094197"}
0005435150178	B95A14	9439 519034	IVAN MARTYNOV	{"phone": "+70928888216"}
0005435150179	B95A14	0163 022764	NIKOLAY TARASOV	{"email": "tarasov_nikolay1963@postgrespro.ru", "phone": "+70856327288"}
0005435150180	800288	9476 598870	OLGA NAZAROVA	{"email": "o.nazarova.031974@postgrespro.ru", "phone": "+70586794352"}
0005435150181	7669AE	2093 260253	AMIR TARASOV	{"email": "amir_tarasov_30081967@postgrespro.ru", "phone": "+70096457894"}
0005435150182	7669AE	0910 254082	NATALIYA PAVLOVA	{"email": "npavlova101973@postgrespro.ru", "phone": "+70702865822"}
0005435150183	2CD339	5923 492798	DENIS FILIPPOV	{"phone": "+70544633680"}
0005435150184	6C581D	1447 899181	ANNA POLYAKOVA	{"phone": "+70740635294"}
0005435150185	08D554	1319 610009	VIKTOR ROMANOV	{"email": "v.romanov_1978@postgrespro.ru", "phone": "+70729939506"}
0005435150186	443F57	4488 712566	VLADIMIR KUZNECOV	{"email": "vkuznecov.031984@postgrespro.ru", "phone": "+70599667344"}
0005435150187	443F57	7359 676831	SEMEN NIKOLAEV	{"phone": "+70547904142"}
0005435150188	A7A0FA	0448 515522	ALEKSEY NIKOLAEV	{"email": "nikolaev-a_07121969@postgrespro.ru", "phone": "+70962806614"}
0005435150189	A7A0FA	0457 405148	ALEKSANDR SOROKIN	{"email": "sorokin_a_24021967@postgrespro.ru", "phone": "+70616638094"}
0005435150190	C9CF3F	5457 306136	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr-04031970@postgrespro.ru", "phone": "+70190436085"}
0005435150191	9E6E29	7348 580677	SERGEY ILIN	{"email": "ilin-sergey091986@postgrespro.ru", "phone": "+70188915994"}
0005435150192	C0697C	4437 370674	NINA KUDRYASHOVA	{"phone": "+70290143587"}
0005435150193	FB0CEB	0599 020302	VALERIY TIKHONOV	{"phone": "+70507196398"}
0005435150194	7D04E3	3560 455312	LILIYA VOLKOVA	{"phone": "+70076647975"}
0005435150195	7D04E3	8421 442031	SERGEY ZAKHAROV	{"phone": "+70991782598"}
0005435150196	7D04E3	1065 138215	VLADIMIR TARASOV	{"phone": "+70072432591"}
0005435150197	5F0789	3170 602735	KLAVDIYA SERGEEVA	{"phone": "+70242004465"}
0005435150198	19DCC1	2920 685005	YANA POTAPOVA	{"email": "potapova-y091972@postgrespro.ru", "phone": "+70840972627"}
0005435150199	19DCC1	3185 228863	ILDAR EGOROV	{"phone": "+70767170376"}
0005435150200	19DCC1	6251 423985	SVETLANA NAZAROVA	{"email": "nazarovasvetlana1974@postgrespro.ru", "phone": "+70317173948"}
0005435150201	25C8B2	5131 360087	ANDREY GORBUNOV	{"phone": "+70518930266"}
0005435150202	25C8B2	8011 386768	IRINA KONOVALOVA	{"email": "irina-konovalova.1968@postgrespro.ru", "phone": "+70823029985"}
0005435150203	3DA020	5637 218453	OLGA IVANOVA	{"email": "olga_ivanova071963@postgrespro.ru", "phone": "+70936492155"}
0005435150204	CE23CF	4530 965445	RAVIL MEDVEDEV	{"phone": "+70168656563"}
0005435150205	5C8DC0	7623 692819	VLADIMIR NOVIKOV	{"email": "novikovvladimir_051977@postgrespro.ru", "phone": "+70278661994"}
0005435150206	2C3150	5649 084457	TIMUR ORLOV	{"phone": "+70299839865"}
0005435150208	85AB61	0829 469675	ALEKSANDR SEMENOV	{"email": "semenovaleksandr.091974@postgrespro.ru", "phone": "+70623647120"}
0005435150209	85AB61	5882 012189	ANATOLIY PETROV	{"phone": "+70980421132"}
0005435150210	85AB61	9379 094219	SERGEY KULIKOV	{"email": "kulikovsergey_071982@postgrespro.ru", "phone": "+70726255386"}
0005435150211	AA114F	9039 675299	YAN GRIGOREV	{"email": "yan_grigorev.12081975@postgrespro.ru", "phone": "+70822515442"}
0005435150212	FE78A8	7092 242284	SERGEY BARANOV	{"email": "s.baranov_24011983@postgrespro.ru", "phone": "+70306056436"}
0005435150213	23129F	7678 033221	VIKTOR SIDOROV	{"email": "viktor.sidorov-28071971@postgrespro.ru", "phone": "+70123321079"}
0005435150214	FDBAFB	7296 230973	MARINA FILATOVA	{"email": "filatova_marina_051978@postgrespro.ru", "phone": "+70526384658"}
0005435150215	EC690B	5827 406310	ANNA SCHERBAKOVA	{"email": "scherbakovaanna_101982@postgrespro.ru", "phone": "+70636665304"}
0005435150216	EC690B	5754 027134	KSENIYA KUZNECOVA	{"email": "kuznecova_k.101976@postgrespro.ru", "phone": "+70297006808"}
0005435150217	56BFAC	8254 157461	MARINA GRISHINA	{"email": "grishina.marina.1956@postgrespro.ru", "phone": "+70579707187"}
0005435150218	AF8225	6740 122341	VYACHESLAV IVANOV	{"email": "ivanov_vyacheslav.30061982@postgrespro.ru", "phone": "+70545950008"}
0005435150219	77B869	5446 075464	TAMARA SMIRNOVA	{"email": "smirnova_tamara1984@postgrespro.ru", "phone": "+70463983960"}
0005435150220	5F5752	3796 075599	TATYANA IVANOVA	{"phone": "+70886463941"}
0005435150221	5F5752	2894 348097	NATALYA SOROKINA	{"email": "sorokina.natalya_03081980@postgrespro.ru", "phone": "+70888829844"}
0005435150222	74E417	4474 075514	DARYA FILIPPOVA	{"phone": "+70095794143"}
0005435150223	17FFE6	3700 558024	ALEKSEY SERGEEV	{"email": "sergeevaleksey1977@postgrespro.ru", "phone": "+70968975652"}
0005435150224	17FFE6	7604 867928	OLGA DANILOVA	{"email": "danilova.o_1975@postgrespro.ru", "phone": "+70573494717"}
0005435150225	D8EC41	3738 423699	RAISA OSIPOVA	{"email": "raisa.osipova-021975@postgrespro.ru", "phone": "+70051618317"}
0005435150226	D8EC41	4325 031728	ELENA FADEEVA	{"phone": "+70274996435"}
0005435150227	AFEF3C	6685 853240	ANTONINA PETROVA	{"email": "petrova_a.1973@postgrespro.ru", "phone": "+70368763176"}
0005435150228	1B57F2	9025 303901	STANISLAV IVANOV	{"email": "sivanov_111961@postgrespro.ru", "phone": "+70221479008"}
0005435150229	1B57F2	3130 947185	DMITRIY BELOV	{"phone": "+70872785733"}
0005435150230	4E90BE	6587 597424	EVGENIY VLASOV	{"email": "vlasov.e.21031981@postgrespro.ru", "phone": "+70625578512"}
0005435150231	EDD1BE	8068 631069	NIKOLAY MOROZOV	{"email": "morozovn_011972@postgrespro.ru", "phone": "+70633690351"}
0005435150232	FD18BA	8421 560473	NATALYA RODIONOVA	{"phone": "+70904299793"}
0005435150233	FD18BA	2505 252898	VLADIMIR ROMANOV	{"phone": "+70546411612"}
0005435150234	529591	9062 863114	DMITRIY ILIN	{"email": "ilin-dmitriy-1973@postgrespro.ru", "phone": "+70418561539"}
0005435150235	FC1634	8855 367242	ARTEM ZAYCEV	{"email": "a.zaycev_1984@postgrespro.ru", "phone": "+70769074491"}
0005435150236	A33C93	7904 455683	ANNA KUZNECOVA	{"phone": "+70549216808"}
0005435150237	AAC758	1821 249878	EKATERINA DANILOVA	{"phone": "+70558927357"}
0005435150238	67DF8F	2916 068419	MARIYA VOROBEVA	{"email": "m.vorobeva.1981@postgrespro.ru", "phone": "+70730581159"}
0005435150239	7E438E	8447 173804	OLGA NIKITINA	{"email": "nikitinaolga_121972@postgrespro.ru", "phone": "+70891623758"}
0005435150240	7E438E	6021 661559	ALEKSEY ALEKSEEV	{"phone": "+70364672015"}
0005435150241	02B94D	0219 501189	EKATERINA KOZLOVA	{"phone": "+70395308385"}
0005435150242	D82BAD	2913 721105	EVGENIY SERGEEV	{"phone": "+70176124017"}
0005435150243	D82BAD	6009 954938	DENIS VLASOV	{"phone": "+70356249000"}
0005435150244	262F9D	3487 219317	LYUBOV NIKOLAEVA	{"email": "lyubov-nikolaeva.041965@postgrespro.ru", "phone": "+70197407327"}
0005435150245	262F9D	5454 752437	EKATERINA LUKYANOVA	{"phone": "+70947585295"}
0005435150246	7BD71C	7629 209477	ELENA KAZAKOVA	{"email": "e-kazakova_12071994@postgrespro.ru", "phone": "+70393277772"}
0005435150247	DDCCEE	0735 077145	KONSTANTIN ROMANOV	{"email": "k-romanov.17041969@postgrespro.ru", "phone": "+70932296728"}
0005435150248	555EC5	7365 761878	LEONID OSIPOV	{"phone": "+70994827419"}
0005435150249	555EC5	3914 038019	RUSHANIYA KOMAROVA	{"email": "rkomarova.1969@postgrespro.ru", "phone": "+70526750652"}
0005435150250	AC8243	3529 317953	VASILIY FEDOROV	{"email": "v_fedorov.18121964@postgrespro.ru", "phone": "+70557519698"}
0005435150251	9FCC58	1618 005093	DENIS ZHUKOV	{"email": "zhukov_d19121961@postgrespro.ru", "phone": "+70952292395"}
0005435150252	9FCC58	7292 784060	YURIY IVANOV	{"phone": "+70430415804"}
0005435150253	3834B3	3153 524203	SERGEY MARTYNOV	{"phone": "+70530858097"}
0005435150254	0C69EA	3715 803855	ANDREY SOKOLOV	{"email": "asokolov-101971@postgrespro.ru", "phone": "+70859742653"}
0005435150255	0C69EA	1071 958655	VALENTINA NOVIKOVA	{"email": "novikova_v.02051981@postgrespro.ru", "phone": "+70381715221"}
0005435150256	E2A1C2	9633 822272	NINA MOROZOVA	{"phone": "+70566434055"}
0005435150257	E2A1C2	1027 661723	VALERIY KUDRYASHOV	{"phone": "+70618057664"}
0005435150258	74E4C3	8175 219193	SERGEY NAUMOV	{"phone": "+70484292341"}
0005435150259	F4FE49	5576 043772	NATALYA POPOVA	{"email": "popova-n.061970@postgrespro.ru", "phone": "+70083391553"}
0005435150260	617414	2687 109803	VALENTINA KRASNOVA	{"email": "valentina-krasnova_1973@postgrespro.ru", "phone": "+70104676925"}
0005435150261	C9BC30	5600 634899	LYUDMILA YAKOVLEVA	{"phone": "+70471014548"}
0005435150262	C9BC30	5509 438433	ALEKSANDR VASILEV	{"phone": "+70381706900"}
0005435150263	D5F466	0468 935354	OLEG KUZNECOV	{"phone": "+70575055813"}
0005435150264	7403FB	1780 001895	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr-1964@postgrespro.ru", "phone": "+70785588654"}
0005435150265	3BF4EB	0497 012889	ILYA EGOROV	{"phone": "+70365811124"}
0005435150266	3BF4EB	5306 138230	ANDREY ZAYCEV	{"phone": "+70592373471"}
0005435150267	27A739	2257 798693	TATYANA KULIKOVA	{"email": "t-kulikova_011983@postgrespro.ru", "phone": "+70607991509"}
0005435150268	B188CA	3123 516404	ALEKSEY VOLKOV	{"email": "a_volkov.11041982@postgrespro.ru", "phone": "+70272274974"}
0005435150269	065E40	2876 200027	ANATOLIY SOKOLOV	{"email": "a-sokolov-1973@postgrespro.ru", "phone": "+70970048376"}
0005435150270	065E40	0954 611956	NIKITA MAKAROV	{"email": "makarovnikita-21121966@postgrespro.ru", "phone": "+70294805223"}
0005435150271	BBA8FE	8309 982046	NATALYA FEDOROVA	{"phone": "+70171038675"}
0005435150272	BBA8FE	8925 328159	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov.071986@postgrespro.ru", "phone": "+70845516938"}
0005435150273	F68C7E	5403 228703	ALEKSANDR VOLKOV	{"phone": "+70591487745"}
0005435150274	58C899	6899 120891	GALINA NIKITINA	{"email": "nikitina-galina.041977@postgrespro.ru", "phone": "+70471415006"}
0005435150275	58C899	6431 419081	EVGENIY GAVRILOV	{"phone": "+70477267604"}
0005435150276	ACD922	3052 487257	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr.1973@postgrespro.ru", "phone": "+70175519377"}
0005435150277	A2CC83	0745 059794	LYUBOV SIDOROVA	{"email": "l.sidorova10031970@postgrespro.ru", "phone": "+70819698554"}
0005435150278	8562FD	0189 711822	VADIM ZAYCEV	{"phone": "+70524345122"}
0005435150279	8562FD	7095 184514	RIMMA NESTEROVA	{"email": "rimma.nesterova011970@postgrespro.ru", "phone": "+70051151809"}
0005435150280	4AE391	9920 808483	VLADIMIR FROLOV	{"phone": "+70836315708"}
0005435150281	7C901E	0854 708567	LYUDMILA YUDINA	{"email": "lyudina.01101975@postgrespro.ru", "phone": "+70615235419"}
0005435150282	3C501F	7072 759417	DMITRIY ROMANOV	{"email": "romanov-dmitriy_09111963@postgrespro.ru", "phone": "+70994798237"}
0005435150283	2C9CE2	9273 872493	SERGEY OSIPOV	{"phone": "+70784300833"}
0005435150284	2C9CE2	3590 785371	GENNADIY BONDARENKO	{"email": "bondarenkog.081981@postgrespro.ru", "phone": "+70843829081"}
0005435150285	0883B2	9840 586156	ANNA BOGDANOVA	{"email": "a.bogdanova.18081967@postgrespro.ru", "phone": "+70182691238"}
0005435150286	62EC98	0802 609928	EVGENIYA ORLOVA	{"phone": "+70625503474"}
0005435150287	8F626D	3093 424937	ANASTASIYA ANDREEVA	{"email": "andreeva.anastasiya-061966@postgrespro.ru", "phone": "+70105427791"}
0005435150288	B0E93A	8803 980255	OLEG YAKOVLEV	{"email": "oleg.yakovlev_1974@postgrespro.ru", "phone": "+70733995528"}
0005435153654	A290AA	7324 249103	VALENTINA NOVIKOVA	{"phone": "+70965547274"}
0005435150289	05924B	0720 360011	VALENTINA NAZAROVA	{"email": "nazarova-valentina.07101968@postgrespro.ru", "phone": "+70058462322"}
0005435150290	38324A	6203 485231	NATALYA DANILOVA	{"email": "danilovanatalya-1971@postgrespro.ru", "phone": "+70605139783"}
0005435150291	38324A	5638 637675	GALINA KUZMINA	{"email": "galinakuzmina.1974@postgrespro.ru", "phone": "+70566614845"}
0005435150292	367F6E	4253 572674	ANATOLIY KUZNECOV	{"email": "anatoliykuznecov_091971@postgrespro.ru", "phone": "+70070089087"}
0005435150293	47B91B	2416 289999	VASILIY NIKITIN	{"phone": "+70268289501"}
0005435150294	27A76B	8589 584034	ZINAIDA OSIPOVA	{"phone": "+70647274695"}
0005435150295	EBC6D9	0970 050101	TAISIYA AKIMOVA	{"email": "akimovat-081969@postgrespro.ru", "phone": "+70056603780"}
0005435150296	0639B0	3098 673741	TATYANA EFREMOVA	{"phone": "+70363433757"}
0005435150297	FC3DE3	9110 418348	GALINA PETROVA	{"phone": "+70035070735"}
0005435150298	FC3DE3	9779 105073	YURIY VOROBEV	{"email": "y-vorobev-05081967@postgrespro.ru", "phone": "+70179362341"}
0005435150299	DEADE8	3274 202523	IRINA VLASOVA	{"email": "vlasova.irina_041971@postgrespro.ru", "phone": "+70695788999"}
0005435150300	F06B20	0248 690594	SERGEY POPOV	{"email": "sergey-popov.02091979@postgrespro.ru", "phone": "+70458160479"}
0005435150301	F06B20	6468 110916	ARINA MALYSHEVA	{"email": "a.malysheva1975@postgrespro.ru", "phone": "+70787687501"}
0005435150302	E29856	4809 661595	VALENTINA KOZLOVA	{"phone": "+70887595866"}
0005435150303	E29856	4929 595079	NATALYA KAZAKOVA	{"phone": "+70523135369"}
0005435150304	36EEEA	0117 139298	LARISA KONOVALOVA	{"email": "larisa_konovalova1976@postgrespro.ru", "phone": "+70060018148"}
0005435150305	9C7F96	2658 690139	NADEZHDA PAVLOVA	{"phone": "+70558085780"}
0005435150306	10F12C	0542 244795	VLADISLAV PAVLOV	{"phone": "+70034402513"}
0005435150307	A24A69	4030 660176	MIKHAIL NAZAROV	{"email": "mikhail.nazarov1975@postgrespro.ru", "phone": "+70496889851"}
0005435150308	5D2A63	1988 814195	YURIY MARTYNOV	{"email": "martynov-yuriy.15051967@postgrespro.ru", "phone": "+70004197082"}
0005435150309	7ACBBC	1461 439088	MIKHAIL CHERNOV	{"email": "m_chernov.11081986@postgrespro.ru", "phone": "+70438625078"}
0005435150310	7ACBBC	1901 013183	ALEVTINA KONOVALOVA	{"phone": "+70552673517"}
0005435150311	A5A4E2	5414 047306	NIKITA RODIONOV	{"email": "nikita.rodionov-061987@postgrespro.ru", "phone": "+70186921193"}
0005435150312	291295	0268 763763	NINA ZAKHAROVA	{"email": "zakharova.nina.09041973@postgrespro.ru", "phone": "+70757228449"}
0005435150313	947CFD	0736 437547	VALENTINA AKIMOVA	{"email": "valentina.akimova_091965@postgrespro.ru", "phone": "+70435845254"}
0005435150314	91296D	6028 345524	OLGA MAKAROVA	{"phone": "+70315826856"}
0005435150315	91296D	4282 416717	GRIGORIY PETROV	{"email": "g-petrov_091978@postgrespro.ru", "phone": "+70021342043"}
0005435150316	F9B0CC	7560 727777	LARISA ABRAMOVA	{"phone": "+70248653987"}
0005435150317	F8A582	8229 451378	OKSANA GUSEVA	{"email": "gusevaoksana_25111974@postgrespro.ru", "phone": "+70624710621"}
0005435150318	2E8374	5383 263355	GERMAN VOROBEV	{"email": "vorobev-german-1972@postgrespro.ru", "phone": "+70036768327"}
0005435150319	B34B4A	8251 523227	NIKOLAY DAVYDOV	{"phone": "+70974983380"}
0005435150320	B34B4A	8051 219037	RAISA VOLKOVA	{"email": "raisa_volkova1973@postgrespro.ru", "phone": "+70979501518"}
0005435150321	A86E63	3696 016249	TATYANA NOVIKOVA	{"email": "novikovat_081973@postgrespro.ru", "phone": "+70512817560"}
0005435150322	FD943E	1725 013934	EKATERINA KUZNECOVA	{"email": "ekaterina-kuznecova-1968@postgrespro.ru", "phone": "+70022996719"}
0005435150323	ACB4C6	3736 500912	MARINA KUZMINA	{"email": "marina_kuzmina-1977@postgrespro.ru", "phone": "+70628417006"}
0005435150324	5C0FA0	9656 908594	KIRILL OSIPOV	{"email": "kirill.osipov091975@postgrespro.ru", "phone": "+70883053684"}
0005435150325	5C0FA0	6152 601516	ALEKSANDR KOZLOV	{"phone": "+70225757025"}
0005435150326	D13073	7272 146991	DARYA SOROKINA	{"email": "sorokina.d24071966@postgrespro.ru", "phone": "+70738677538"}
0005435150327	F23EA4	5696 648945	NADEZHDA FOMINA	{"email": "nadezhda-fomina.16061974@postgrespro.ru", "phone": "+70072071437"}
0005435150328	4829C3	2706 247423	SERGEY ZHURAVLEV	{"email": "sergey-zhuravlev-1980@postgrespro.ru", "phone": "+70495498538"}
0005435150329	CDE5FB	9026 242385	MARIYA ROMANOVA	{"phone": "+70676771880"}
0005435150330	7B1A99	9238 060626	VALENTINA BELOVA	{"phone": "+70429577142"}
0005435150331	982455	9732 208073	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov021976@postgrespro.ru", "phone": "+70711562641"}
0005435150332	4F0848	7844 021092	ANASTASIYA FROLOVA	{"phone": "+70243301962"}
0005435150333	3323F6	4201 370477	PETR ABRAMOV	{"phone": "+70398621760"}
0005435150334	C236AB	4536 928058	SERGEY KISELEV	{"phone": "+70362752493"}
0005435150335	C236AB	4729 257219	YURIY NAZAROV	{"email": "nazarov-yuriy_25031974@postgrespro.ru", "phone": "+70872561954"}
0005435150336	877704	8584 862764	NIKOLAY SERGEEV	{"phone": "+70322924597"}
0005435150337	877704	7427 823447	ANNA ISAEVA	{"email": "isaeva-anna.1967@postgrespro.ru", "phone": "+70370810812"}
0005435150338	ED3F3B	5683 938362	ALEKSEY VOROBEV	{"phone": "+70642809412"}
0005435150339	96C8ED	9724 003274	IRINA MAKSIMOVA	{"phone": "+70738240539"}
0005435150340	96C8ED	6566 362055	ANASTASIYA ROMANOVA	{"email": "anastasiyaromanova.03011966@postgrespro.ru", "phone": "+70649240307"}
0005435150341	96C8ED	7058 726904	SERGEY ANDREEV	{"email": "s.andreev.14101975@postgrespro.ru", "phone": "+70726531517"}
0005435150342	3A8232	3323 912605	DMITRIY OSIPOV	{"phone": "+70252644092"}
0005435150343	493F54	7487 043309	LARISA FILIPPOVA	{"email": "filippova-larisa_12061961@postgrespro.ru", "phone": "+70053982123"}
0005435150344	214066	7264 746917	DMITRIY VOLKOV	{"phone": "+70187804927"}
0005435150345	0F12B7	1306 560318	YURIY POPOV	{"email": "popov_yuriy011963@postgrespro.ru", "phone": "+70299653713"}
0005435150346	B8D3F3	9532 883105	SVETLANA EFREMOVA	{"phone": "+70914332953"}
0005435150347	B8D3F3	1661 967861	SERGEY MAKAROV	{"phone": "+70007332588"}
0005435150348	B8D3F3	5857 603641	MARINA ANDREEVA	{"email": "marina_andreeva_1967@postgrespro.ru", "phone": "+70789941819"}
0005435150349	3CAA5C	6498 816790	VLADISLAV POPOV	{"email": "popov-v-18011964@postgrespro.ru", "phone": "+70651756086"}
0005435150350	91CFF5	4238 762980	DMITRIY SMIRNOV	{"email": "smirnov-dmitriy_061968@postgrespro.ru", "phone": "+70528417073"}
0005435150351	124B7E	2687 656245	ELENA GERASIMOVA	{"phone": "+70772022538"}
0005435150352	124B7E	8620 292476	SERGEY FILIPPOV	{"phone": "+70455486603"}
0005435150353	C625B2	7836 138660	AYRAT STEPANOV	{"phone": "+70725995279"}
0005435150354	C625B2	8002 717874	ELENA LUKYANOVA	{"email": "lukyanova_elena051965@postgrespro.ru", "phone": "+70441477098"}
0005435150355	715194	3191 009349	VALENTINA PETROVA	{"email": "vpetrova-28011971@postgrespro.ru", "phone": "+70043627743"}
0005435150356	28FB23	3464 186446	MARIYA BARANOVA	{"email": "baranova_mariya021983@postgrespro.ru", "phone": "+70380227858"}
0005435150357	28FB23	0286 505442	TATYANA STEPANOVA	{"phone": "+70180418618"}
0005435150358	3AC2FF	5323 899470	ANATOLIY KISELEV	{"phone": "+70657422203"}
0005435150359	3AC2FF	9911 474145	VERONIKA OSIPOVA	{"email": "v-osipova.081979@postgrespro.ru", "phone": "+70085906405"}
0005435150360	0B4684	1122 262615	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylovaa.09091967@postgrespro.ru", "phone": "+70476832895"}
0005435150361	1E6D8A	2563 568310	EKATERINA STEPANOVA	{"phone": "+70575799045"}
0005435150362	E2E1F5	9745 974342	OLGA BORISOVA	{"phone": "+70322564152"}
0005435150363	D95AC1	2684 736097	VLADIMIR ANTONOV	{"email": "antonov-v1974@postgrespro.ru", "phone": "+70915771410"}
0005435150364	C3067E	1493 412546	SERGEY SMIRNOV	{"email": "sergey-smirnov06061981@postgrespro.ru", "phone": "+70223036867"}
0005435150365	B260D4	7735 542557	ANTONINA NIKIFOROVA	{"email": "antonina_nikiforova_01051961@postgrespro.ru", "phone": "+70814826377"}
0005435150366	A8D015	6551 866841	LIDIYA SOLOVEVA	{"phone": "+70734679017"}
0005435150367	439925	5018 884723	OLESYA VOROBEVA	{"email": "vorobeva.olesya071964@postgrespro.ru", "phone": "+70649158734"}
0005435150368	718682	9805 008580	NATALYA KUZNECOVA	{"email": "n_kuznecova_1976@postgrespro.ru", "phone": "+70574539311"}
0005435150369	394A39	3042 748455	ALEKSEY TARASOV	{"phone": "+70243722970"}
0005435150370	394A39	5285 204278	TIMOFEY NIKITIN	{"email": "nikitintimofey.1980@postgrespro.ru", "phone": "+70199988913"}
0005435150371	5D3599	8466 007842	PAVEL SERGEEV	{"phone": "+70148454507"}
0005435150372	CA7F1A	2907 154312	EVGENIY KUDRYASHOV	{"email": "evgeniy.kudryashov-22091957@postgrespro.ru", "phone": "+70199736022"}
0005435150373	BB01E5	8062 262103	ARINA STEPANOVA	{"email": "arinastepanova-06071971@postgrespro.ru", "phone": "+70416439443"}
0005435150374	BB01E5	2536 477433	ARTEM MIRONOV	{"phone": "+70122591063"}
0005435150375	91D584	5010 346123	MARIYA KISELEVA	{"email": "kiselevamariya1979@postgrespro.ru", "phone": "+70209628422"}
0005435150376	91D584	3991 287530	DMITRIY KOROLEV	{"email": "d.korolev.1980@postgrespro.ru", "phone": "+70926024970"}
0005435150377	C4FEAF	6021 796612	DMITRIY KONOVALOV	{"phone": "+70761108495"}
0005435150378	5D5B4E	5415 886566	YULIYA MIKHAYLOVA	{"email": "mikhaylova.yuliya.061976@postgrespro.ru", "phone": "+70032463848"}
0005435150379	5D5B4E	7434 654074	IVAN KUZMIN	{"email": "kuzmini_1963@postgrespro.ru", "phone": "+70856539239"}
0005435150380	F877B1	8167 479341	MARINA POPOVA	{"email": "m.popova-24041979@postgrespro.ru", "phone": "+70608752778"}
0005435150381	F5C840	8786 499016	KIRILL AFANASEV	{"email": "k_afanasev-051976@postgrespro.ru", "phone": "+70238776649"}
0005435150382	B58900	4027 168565	NATALYA NAZAROVA	{"email": "nazarova.natalya071974@postgrespro.ru", "phone": "+70354048973"}
0005435150383	E46120	3246 985730	VALERIYA EGOROVA	{"phone": "+70109977113"}
0005435150384	E46120	7121 518785	ALEKSEY POPOV	{"email": "popovaleksey-091971@postgrespro.ru", "phone": "+70991440001"}
0005435150385	AD933A	4432 887926	ALEKSANDR VASILEV	{"phone": "+70658815374"}
0005435150386	509E6E	0788 658159	MIKHAIL BARANOV	{"phone": "+70513569466"}
0005435150387	509E6E	2800 031275	ANNA NIKOLAEVA	{"phone": "+70184208328"}
0005435150388	8C98C6	1475 189819	ANNA NAUMOVA	{"email": "naumova-a-08041973@postgrespro.ru", "phone": "+70595226412"}
0005435150389	215A79	7205 126322	YULIYA BARANOVA	{"phone": "+70305638627"}
0005435150390	43B070	8222 994118	EGOR SMIRNOV	{"phone": "+70667608124"}
0005435150391	553146	0816 257645	IGOR NOVIKOV	{"email": "novikov_i_20071976@postgrespro.ru", "phone": "+70762661304"}
0005435150392	553146	8713 925797	VASILIY NIKOLAEV	{"email": "nikolaev_v-22021981@postgrespro.ru", "phone": "+70250502006"}
0005435150393	953090	3093 477031	GRIGORIY SOLOVEV	{"email": "grigoriy-solovev_1963@postgrespro.ru", "phone": "+70398435062"}
0005435150394	953090	2561 387598	ANATOLIY ILIN	{"email": "anatoliy_ilin011982@postgrespro.ru", "phone": "+70672767999"}
0005435150395	AE2CED	9391 629999	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail_1974@postgrespro.ru", "phone": "+70795976464"}
0005435150396	AE2CED	8404 760232	TATYANA ZAKHAROVA	{"phone": "+70668948603"}
0005435150397	E5BCE1	9673 789190	KLAVDIYA MIKHAYLOVA	{"email": "mikhaylova.klavdiya1974@postgrespro.ru", "phone": "+70870853035"}
0005435150398	158A68	3338 072815	ALEVTINA SMIRNOVA	{"email": "smirnova-alevtina-031975@postgrespro.ru", "phone": "+70797778353"}
0005435150399	DA6F10	7874 264313	NIKOLAY MOROZOV	{"email": "nikolaymorozov.27071964@postgrespro.ru", "phone": "+70295411258"}
0005435150400	DA6F10	0376 582950	LIDIYA ALEKSANDROVA	{"email": "aleksandrovalidiya-06021968@postgrespro.ru", "phone": "+70241199538"}
0005435150401	DB83CF	0440 828118	ANGELINA ANTONOVA	{"phone": "+70043737743"}
0005435150402	0715F6	7531 782125	TAMARA MELNIKOVA	{"phone": "+70284129294"}
0005435150403	1D611C	3957 153756	VALERIY IVANOV	{"email": "v_ivanov-021956@postgrespro.ru", "phone": "+70311307464"}
0005435150404	5C3882	0674 775227	NINA VOLKOVA	{"email": "n-volkova05061974@postgrespro.ru", "phone": "+70360362057"}
0005435150405	95B9DE	9928 779801	SVETLANA PAVLOVA	{"phone": "+70380175068"}
0005435150406	95B9DE	5830 603566	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov_08121979@postgrespro.ru", "phone": "+70523101959"}
0005435150407	6E03D3	6562 023758	ANASTASIYA GRISHINA	{"phone": "+70612655446"}
0005435150408	03D807	4399 987549	VIKTOR FOMIN	{"email": "viktor.fomin.1976@postgrespro.ru", "phone": "+70159732154"}
0005435150409	03D807	8826 357962	OLGA POPOVA	{"phone": "+70824703047"}
0005435150410	01394E	0435 309849	EGOR ZAYCEV	{"email": "zaycev.e-1977@postgrespro.ru", "phone": "+70121074682"}
0005435150411	02F349	8026 588128	ELENA IVANOVA	{"email": "ivanova-elena_071968@postgrespro.ru", "phone": "+70118111050"}
0005435150412	02F349	9727 466716	OLGA KUZNECOVA	{"email": "o_kuznecova_1970@postgrespro.ru", "phone": "+70711127016"}
0005435150413	987482	5368 949262	VIKTORIYA NOVIKOVA	{"email": "viktoriya.novikova-17081981@postgrespro.ru", "phone": "+70549438643"}
0005435150414	950AD0	9628 112961	ANATOLIY NOVIKOV	{"email": "anovikov1952@postgrespro.ru", "phone": "+70054362540"}
0005435150415	B45F1C	3428 268770	EVGENIYA KULIKOVA	{"email": "evgeniya.kulikova-061974@postgrespro.ru", "phone": "+70737346160"}
0005435150416	0C2A8B	1478 143339	VALERIY MOROZOV	{"email": "morozov.v-051978@postgrespro.ru", "phone": "+70184239286"}
0005435150417	4E0EA3	6990 175555	EKATERINA KUZNECOVA	{"phone": "+70832233202"}
0005435150418	03EDF5	6462 108322	VALENTINA FOMINA	{"phone": "+70482160280"}
0005435150419	830C59	0661 068785	EKATERINA KRASNOVA	{"email": "krasnovae_28081974@postgrespro.ru", "phone": "+70540945586"}
0005435150420	830C59	0564 913122	LYUBOV SMIRNOVA	{"phone": "+70657499370"}
0005435150421	924288	7910 296926	ILDAR SOROKIN	{"email": "sorokinildar1973@postgrespro.ru", "phone": "+70284030000"}
0005435150422	924288	9092 477643	GALINA FOMINA	{"phone": "+70313062179"}
0005435150423	693325	4441 605103	SVETLANA YUDINA	{"email": "svetlanayudina.1978@postgrespro.ru", "phone": "+70901132037"}
0005435150424	C0FC6D	0465 181855	TATYANA TIKHONOVA	{"phone": "+70843125158"}
0005435150425	C0FC6D	4634 287769	SNEZHANA SMIRNOVA	{"email": "s_smirnova07051959@postgrespro.ru", "phone": "+70234491410"}
0005435150426	1CFD7D	2398 625871	REGINA ANDREEVA	{"email": "r.andreeva_061969@postgrespro.ru", "phone": "+70370722527"}
0005435150427	42C1B4	5795 877823	EKATERINA ORLOVA	{"email": "e_orlova_1974@postgrespro.ru", "phone": "+70529570851"}
0005435150428	21732D	4073 819923	OLEG KOZLOV	{"phone": "+70805711898"}
0005435150429	21732D	1591 034785	EVGENIY RODIONOV	{"email": "evgeniy-rodionov-05121981@postgrespro.ru", "phone": "+70962766860"}
0005435150430	DB5B7D	7370 692106	ANNA ABRAMOVA	{"phone": "+70960949371"}
0005435150431	67FC7F	4643 130698	ALEKSANDR KULIKOV	{"phone": "+70218046773"}
0005435150432	67FC7F	6841 111181	ALEKSEY ZHURAVLEV	{"phone": "+70381793411"}
0005435150433	1C3EBA	9971 620767	ANATOLIY POPOV	{"phone": "+70883557318"}
0005435150434	1C3EBA	8698 319097	IVAN SCHERBAKOV	{"email": "i_scherbakov02021976@postgrespro.ru", "phone": "+70856377861"}
0005435150435	1C3EBA	6875 557870	NIKOLAY KULIKOV	{"phone": "+70007909498"}
0005435150436	DCCD38	2016 128567	ANDREY SCHERBAKOV	{"email": "andrey-scherbakov1968@postgrespro.ru", "phone": "+70580104626"}
0005435150437	DCCD38	3676 603520	SVETLANA KOLESNIKOVA	{"email": "kolesnikova.svetlana-1964@postgrespro.ru", "phone": "+70806856534"}
0005435153658	64D072	3382 720805	GALINA PETROVA	{"phone": "+70559847634"}
0005435153626	B2FFDD	0056 239237	SERGEY GORBUNOV	{"phone": "+70055550987"}
0005435153627	6739A8	4109 776914	VIKTOR OSIPOV	{"phone": "+70972049275"}
0005435153628	6739A8	3926 088464	BORIS SMIRNOV	{"phone": "+70988020259"}
0005435153629	73F5CE	3428 492129	VLADIMIR RODIONOV	{"phone": "+70407542642"}
0005435153630	73F5CE	0943 230549	RAFAIL KULIKOV	{"email": "kulikov_rafail-12041987@postgrespro.ru", "phone": "+70074210946"}
0005435153631	6916CE	8159 667942	MIKHAIL SEMENOV	{"phone": "+70819047153"}
0005435153632	4C02F8	9037 637593	ALEKSANDRA MELNIKOVA	{"email": "melnikovaaleksandra1974@postgrespro.ru", "phone": "+70768662392"}
0005435153633	4C02F8	6671 247181	ANDREY SCHERBAKOV	{"phone": "+70420878635"}
0005435153634	ABD82E	8061 499502	DARYA MOROZOVA	{"phone": "+70091704889"}
0005435153635	B99E26	6172 472963	TAMARA PETROVA	{"email": "petrovatamara_081980@postgrespro.ru", "phone": "+70174950972"}
0005435153636	B99E26	9945 017969	ANASTASIYA POPOVA	{"phone": "+70578308237"}
0005435153637	B99E26	8748 984179	ANNA ALEKSEEVA	{"phone": "+70689050292"}
0005435153638	1E7D74	0002 149087	ANATOLIY FROLOV	{"phone": "+70489570382"}
0005435153639	1E7D74	4384 079916	DMITRIY FOMIN	{"email": "dmitriy.fomin1969@postgrespro.ru", "phone": "+70547110983"}
0005435153640	B7F423	9002 471752	VALERIY POPOV	{"phone": "+70323254831"}
0005435153641	39F265	7274 069449	OLGA NOVIKOVA	{"phone": "+70254454433"}
0005435153642	39F265	5834 843376	FEDOR CHERNOV	{"email": "chernov.f101968@postgrespro.ru", "phone": "+70672735252"}
0005435153643	5F8E5A	3715 448448	EKATERINA TARASOVA	{"phone": "+70829095927"}
0005435153644	65FD16	4417 541114	OLGA BELYAEVA	{"phone": "+70846215346"}
0005435153645	65FD16	7453 835314	VIKTOR SCHERBAKOV	{"email": "viktor-scherbakov-08121968@postgrespro.ru", "phone": "+70223517112"}
0005435153646	E38B98	6750 558721	GALINA ANTONOVA	{"phone": "+70324516577"}
0005435153647	E38B98	1670 609991	NIKITA KUZNECOV	{"email": "kuznecov_n.31101975@postgrespro.ru", "phone": "+70631237682"}
0005435153648	0194B4	0015 859917	OLGA KUZNECOVA	{"phone": "+70690956530"}
0005435153649	2EC494	1506 434255	ELIZAVETA MOROZOVA	{"phone": "+70499402859"}
0005435153650	B99D70	4713 176403	ALEKSANDR SOKOLOV	{"phone": "+70518713838"}
0005435153651	6306F7	6502 360187	ELENA NAUMOVA	{"phone": "+70176088231"}
0005435153652	6306F7	3532 793322	VALENTINA SCHERBAKOVA	{"phone": "+70729128741"}
0005435153653	9B97FC	1616 899985	OLESYA IVANOVA	{"email": "olesya_ivanova.03051976@postgrespro.ru", "phone": "+70945837963"}
0005435153655	97953C	4451 655510	ARTEM SOKOLOV	{"phone": "+70072243343"}
0005435153656	97953C	4437 525494	EVA KOROLEVA	{"phone": "+70255893257"}
0005435153657	97953C	8735 941090	ALEKSEY PETROV	{"email": "alekseypetrov.09021967@postgrespro.ru", "phone": "+70960481702"}
0005435153659	3F81FA	0468 542434	MAKSIM KULIKOV	{"phone": "+70650820706"}
0005435153660	205D7E	2707 052568	ALEKSEY ALEKSANDROV	{"email": "alekseyaleksandrov1974@postgrespro.ru", "phone": "+70806436187"}
0005435153661	1FE4B2	2309 953571	KONSTANTIN ROMANOV	{"phone": "+70874631620"}
0005435153662	E5EF46	6966 058327	ILYA IVANOV	{"phone": "+70988208758"}
0005435153663	E5EF46	1346 926870	PETR VOROBEV	{"email": "p.vorobev-21071972@postgrespro.ru", "phone": "+70635214214"}
0005435153664	3C059C	3828 644907	YURIY DAVYDOV	{"email": "yuriy_davydov1965@postgrespro.ru", "phone": "+70032568694"}
0005435153665	85FD25	0925 388642	LYUDMILA CHERNOVA	{"phone": "+70252078865"}
0005435153666	CAC329	4077 654355	YULIYA IVANOVA	{"email": "ivanova-yuliya061969@postgrespro.ru", "phone": "+70126343467"}
0005435153667	3878DC	0445 665951	LEONID FROLOV	{"email": "l-frolov25071978@postgrespro.ru", "phone": "+70659823335"}
0005435153668	727313	4273 131320	ALEKSANDR EGOROV	{"email": "egorov.a121982@postgrespro.ru", "phone": "+70720812345"}
0005435153669	17521A	8111 305277	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov-07061968@postgrespro.ru", "phone": "+70263865205"}
0005435153670	5BAE4F	0680 260373	TAISA IVANOVA	{"email": "taisa_ivanova18091973@postgrespro.ru", "phone": "+70837442313"}
0005435153671	85EF28	1238 106005	ANNA MOROZOVA	{"phone": "+70297719896"}
0005435153672	9225DE	4502 621554	DMITRIY YAKOVLEV	{"email": "yakovlev-dmitriy_18101971@postgrespro.ru", "phone": "+70636673174"}
0005435153673	9225DE	2507 466150	PAVEL ANDREEV	{"phone": "+70727574251"}
0005435153674	932F26	7254 344478	DMITRIY ORLOV	{"email": "orlovd.041978@postgrespro.ru", "phone": "+70912362294"}
0005435153675	932F26	5115 661148	IRINA DANILOVA	{"email": "irinadanilova.081967@postgrespro.ru", "phone": "+70924019075"}
0005435153676	932F26	3472 858326	TATYANA POTAPOVA	{"phone": "+70138680223"}
0005435153677	84F0F6	7980 055832	SVETLANA LUKYANOVA	{"email": "lukyanova_s.02021972@postgrespro.ru", "phone": "+70998929532"}
0005435153678	84F0F6	5994 519933	ALEKSEY BONDARENKO	{"email": "aleksey_bondarenko08031977@postgrespro.ru", "phone": "+70488847447"}
0005435153679	84F0F6	8798 704434	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_28051974@postgrespro.ru", "phone": "+70909221594"}
0005435153680	2F39EB	1018 770336	POLINA DANILOVA	{"email": "polina_danilova031971@postgrespro.ru", "phone": "+70176298246"}
0005435153681	E90836	6868 389757	NATALYA IVANOVA	{"phone": "+70416812216"}
0005435153682	84B76D	0838 283830	NIKOLAY KUZNECOV	{"phone": "+70067126859"}
0005435153683	695BB6	9709 673296	SERGEY ILIN	{"email": "sergey-ilin.1974@postgrespro.ru", "phone": "+70136660797"}
0005435153684	695BB6	1712 647361	ALEKSEY ZAKHAROV	{"email": "zakharovaleksey-121972@postgrespro.ru", "phone": "+70091345526"}
0005435153685	194A67	4376 679830	ANZHELIKA VOLKOVA	{"phone": "+70701812343"}
0005435153686	E566FF	6753 602202	NINA SOLOVEVA	{"email": "soloveva-n.021961@postgrespro.ru", "phone": "+70635116720"}
0005435153687	1FFF3E	8855 445039	IRINA IVANOVA	{"phone": "+70060690994"}
0005435153688	5B9DEA	0484 493753	ALLA EGOROVA	{"email": "a-egorova-15081964@postgrespro.ru", "phone": "+70155122679"}
0005435153689	813788	9496 897601	NATALYA ISAEVA	{"phone": "+70928425197"}
0005435153690	813788	5825 047308	EKATERINA KRASNOVA	{"phone": "+70533367689"}
0005435153691	777601	2644 100424	NIKITA ZAYCEV	{"phone": "+70639293578"}
0005435153692	97DF3A	0552 884523	GALINA GRISHINA	{"phone": "+70985926532"}
0005435153693	97DF3A	0732 759425	PAVEL ANDREEV	{"email": "andreev.pavel-06041979@postgrespro.ru", "phone": "+70178136865"}
0005435153694	80D62E	1053 463820	ALEKSEY MAKAROV	{"email": "aleksey-makarov1977@postgrespro.ru", "phone": "+70320585527"}
0005435153695	F6E607	2488 372190	NIKOLAY DENISOV	{"email": "nikolaydenisov-031973@postgrespro.ru", "phone": "+70298282672"}
0005435153696	F6E607	1752 702744	IVAN BONDARENKO	{"email": "ivan-bondarenko101969@postgrespro.ru", "phone": "+70597533383"}
0005435153697	DA6AA7	5562 124277	LYUDMILA FROLOVA	{"phone": "+70878518027"}
0005435153698	79564B	6659 746454	LYUDMILA SOLOVEVA	{"phone": "+70010280975"}
0005435153699	D3E18F	0122 087695	TATYANA YUDINA	{"email": "yudina-tatyana_121980@postgrespro.ru", "phone": "+70428345872"}
0005435153700	D3E18F	7783 105666	ALEKSANDR SEMENOV	{"email": "semenova_121978@postgrespro.ru", "phone": "+70072081111"}
0005435153701	E67F16	2237 362310	NADEZHDA POPOVA	{"email": "n-popova_011972@postgrespro.ru", "phone": "+70284545698"}
0005435153702	BE7F95	4864 722885	ANTONINA MEDVEDEVA	{"phone": "+70943010506"}
0005435153703	BE7F95	0318 934831	ELDAR BONDARENKO	{"phone": "+70736314714"}
0005435153704	8899FB	7153 050790	EDUARD SHEVCHENKO	{"phone": "+70574186459"}
0005435153705	8899FB	1487 148865	IRINA KOZLOVA	{"email": "kozlovai-1966@postgrespro.ru", "phone": "+70900631123"}
0005435153706	8899FB	0792 903168	NADEZHDA TARASOVA	{"phone": "+70485832628"}
0005435153707	929575	0467 412150	LYUBOV GUSEVA	{"email": "lyubov_guseva-111970@postgrespro.ru", "phone": "+70625420866"}
0005435153708	929575	4343 122184	SERGEY VASILEV	{"phone": "+70042988283"}
0005435153709	EEF8B3	1581 674175	ZHANNA ALEKSEEVA	{"email": "zhannaalekseeva-061966@postgrespro.ru", "phone": "+70626790122"}
0005435153710	301A16	6167 988767	ALEKSANDR GERASIMOV	{"phone": "+70453040553"}
0005435153711	301A16	4061 856214	ELENA TIMOFEEVA	{"phone": "+70616351976"}
0005435153712	EEAF34	9753 866949	NINA VOLKOVA	{"email": "volkova.nina_091971@postgrespro.ru", "phone": "+70941124947"}
0005435153713	A4143D	2184 327393	NATALYA GAVRILOVA	{"email": "gavrilovan.20021972@postgrespro.ru", "phone": "+70172332303"}
0005435153714	A4143D	4862 693319	MAKSIM DAVYDOV	{"phone": "+70712918971"}
0005435153715	94440D	8847 116049	FILIPP KARPOV	{"phone": "+70791564628"}
0005435153716	79B650	7321 146639	ALEKSANDR FOMIN	{"phone": "+70396790231"}
0005435153717	76D8DA	4940 672059	DANIYA SEMENOVA	{"email": "semenova_daniya11031971@postgrespro.ru", "phone": "+70515055298"}
0005435153718	093153	4153 691954	SERGEY ALEKSANDROV	{"phone": "+70039253803"}
0005435153719	26D28E	3122 667383	OLEG GRIGOREV	{"email": "grigorevo-12111962@postgrespro.ru", "phone": "+70449811975"}
0005435153720	26D28E	5729 031304	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr-061985@postgrespro.ru", "phone": "+70956387557"}
0005435153721	26D28E	0823 367505	IRINA KAZAKOVA	{"email": "kazakovairina_01081968@postgrespro.ru", "phone": "+70369899232"}
0005435153722	26D28E	0747 043754	VIKTOR DENISOV	{"email": "denisovviktor20091971@postgrespro.ru", "phone": "+70474672875"}
0005435153723	044420	2289 402338	VALERIY VOROBEV	{"email": "vorobevvaleriy31081966@postgrespro.ru", "phone": "+70327482437"}
0005435153724	044420	5571 793311	LYUDMILA BELYAEVA	{"phone": "+70710277568"}
0005435153725	067714	3774 455071	EVGENIY IVANOV	{"email": "evgeniy.ivanov1973@postgrespro.ru", "phone": "+70214547912"}
0005435153726	ECD8BF	6393 721015	GALINA FADEEVA	{"phone": "+70639058798"}
0005435153727	119E30	3348 613744	VALENTINA ABRAMOVA	{"email": "abramova-v.041976@postgrespro.ru", "phone": "+70953521595"}
0005435153728	79D94D	3064 042953	VYACHESLAV ALEKSANDROV	{"email": "aleksandrov-vyacheslav-21091980@postgrespro.ru", "phone": "+70981510227"}
0005435153729	0CB120	7859 341971	ALEKSEY DENISOV	{"email": "aleksey-denisov-1964@postgrespro.ru", "phone": "+70006815272"}
0005435153730	0CB120	6356 598173	YULIYA DAVYDOVA	{"email": "yuliya.davydova-1960@postgrespro.ru", "phone": "+70293636518"}
0005435153731	BF202E	7987 930167	PETR BONDARENKO	{"email": "bondarenko_petr_1971@postgrespro.ru", "phone": "+70141563147"}
0005435153732	8BD371	3713 958988	VLADIMIR NAUMOV	{"phone": "+70320606061"}
0005435153733	8BD371	8538 371390	SERGEY BELOV	{"email": "belov-s.091971@postgrespro.ru", "phone": "+70663345853"}
0005435153734	01C515	7117 565024	LIDIYA FADEEVA	{"email": "fadeevalidiya-22051977@postgrespro.ru", "phone": "+70728626735"}
0005435153735	01C515	0622 529296	TATYANA FROLOVA	{"email": "tatyana-frolova081968@postgrespro.ru", "phone": "+70676577606"}
0005435153736	B67EE1	4967 928663	ROZA FEDOROVA	{"email": "r_fedorova.1969@postgrespro.ru", "phone": "+70217806997"}
0005435153737	0D9D02	8259 397864	VYACHESLAV ISAEV	{"email": "vyacheslav.isaev-1971@postgrespro.ru", "phone": "+70339730428"}
0005435153738	0D9D02	2254 584904	ANASTASIYA MAKSIMOVA	{"email": "maksimova_a1982@postgrespro.ru", "phone": "+70086238116"}
0005435153739	7B92AF	1572 699365	EVGENIY FOMIN	{"email": "fomine-1963@postgrespro.ru", "phone": "+70878834578"}
0005435153740	7C85EE	9660 014956	NATALYA FOMINA	{"phone": "+70788973206"}
0005435153741	7C85EE	2778 434242	SVETLANA GUSEVA	{"phone": "+70726589432"}
0005435153742	BBE3D4	5614 596668	GALINA EFREMOVA	{"email": "efremovag.24061976@postgrespro.ru", "phone": "+70372789023"}
0005435153743	326859	2513 335716	ROMAN BORISOV	{"phone": "+70147031781"}
0005435153744	326859	8066 378238	ELENA ANTONOVA	{"phone": "+70283825251"}
0005435153745	EE2871	7517 058813	ANTONINA MAKAROVA	{"email": "antoninamakarova.101960@postgrespro.ru", "phone": "+70290984378"}
0005435153746	D3219E	8815 756779	GALINA KUZNECOVA	{"phone": "+70257085998"}
0005435153747	D3219E	7686 643302	LILIYA DENISOVA	{"phone": "+70754710751"}
0005435153748	60B7D0	8642 402014	ROMAN EGOROV	{"phone": "+70546859854"}
0005435153749	01DC97	2894 172864	VITALIY FEDOTOV	{"email": "fedotov-vitaliy.11121985@postgrespro.ru", "phone": "+70602235183"}
0005435153750	20BD89	9219 137640	ALEKSANDR ANDREEV	{"phone": "+70347911920"}
0005435153751	20BD89	3284 185581	VIKTOR FOMIN	{"email": "vfomin.051963@postgrespro.ru", "phone": "+70330171906"}
0005435153752	E35AAC	1715 765617	VLADIMIR MAKSIMOV	{"email": "maksimov-vladimir.1968@postgrespro.ru", "phone": "+70829831106"}
0005435153753	297E97	3301 199349	IVAN SHEVCHENKO	{"phone": "+70957588113"}
0005435153754	3807A6	4308 505051	ALEKSANDR NIKITIN	{"phone": "+70522555820"}
0005435153755	EBFD8C	2625 606822	VERA MARTYNOVA	{"phone": "+70165465829"}
0005435153756	56E37C	6739 366468	ALEKSANDR NOVIKOV	{"phone": "+70690941502"}
0005435153757	BDADD1	1263 487607	VALERIY FEDOROV	{"email": "fedorov.v_18111977@postgrespro.ru", "phone": "+70068086995"}
0005435153758	2A7DC6	8509 870924	POLINA VASILEVA	{"email": "vasileva-p20091970@postgrespro.ru", "phone": "+70326435541"}
0005435153759	2FEA5B	1483 503600	IVAN BORISOV	{"email": "ivan.borisov_041973@postgrespro.ru", "phone": "+70495566783"}
0005435153760	2FEA5B	9785 771757	LYUBOV KALININA	{"phone": "+70226924862"}
0005435153761	E6E8EA	2717 197942	YULIYA VOLKOVA	{"phone": "+70640348438"}
0005435153762	896A7E	1640 681988	MARIYA ZHURAVLEVA	{"phone": "+70112529311"}
0005435153763	FA1930	4297 760310	EVGENIY ANDREEV	{"email": "andreevevgeniy-021973@postgrespro.ru", "phone": "+70787807076"}
0005435153764	D04E89	2143 281859	NIKOLAY PETROV	{"phone": "+70124564533"}
0005435153765	F34AA3	4712 610380	GALINA FADEEVA	{"phone": "+70868100175"}
0005435153766	145A27	6866 333155	GALINA TIMOFEEVA	{"email": "timofeeva-g.1974@postgrespro.ru", "phone": "+70694699683"}
0005435153767	8CA0EC	3476 219734	VYACHESLAV KUZNECOV	{"phone": "+70927410469"}
0005435153768	36F35E	0843 671607	ELENA ROMANOVA	{"phone": "+70521107087"}
0005435153769	36F35E	4443 928320	ELENA BORISOVA	{"email": "elena.borisova29091978@postgrespro.ru", "phone": "+70735182902"}
0005435153770	36F35E	0844 458855	TATYANA SIDOROVA	{"phone": "+70346655757"}
0005435153771	C8191B	1582 428255	VADIM YAKOVLEV	{"email": "vadim.yakovlev1970@postgrespro.ru", "phone": "+70908264822"}
0005435153772	D4FB8A	8289 333416	ANDREY DENISOV	{"email": "andrey.denisov1963@postgrespro.ru", "phone": "+70884506683"}
0005435153773	D4439B	1779 933040	OLGA KOROLEVA	{"phone": "+70777360841"}
0005435153774	CC0221	5067 727175	ANDREY ZHUKOV	{"email": "zhukov.a_07101987@postgrespro.ru", "phone": "+70854751167"}
0005435153775	CC0221	6641 205650	VLADIMIR VASILEV	{"phone": "+70851182729"}
0005435153776	FA2379	4201 958853	ANDREY ZAKHAROV	{"email": "andrey-zakharov.091970@postgrespro.ru", "phone": "+70842136003"}
0005435153777	FA2379	7578 159977	MARINA IVANOVA	{"email": "ivanova.m-1972@postgrespro.ru", "phone": "+70329617019"}
0005435153778	FA2379	3999 070731	ARTEM DENISOV	{"email": "artem-denisov101972@postgrespro.ru", "phone": "+70006576019"}
0005435153779	27212F	7459 379706	GENNADIY KOZLOV	{"phone": "+70625420173"}
0005435153780	27212F	6204 539602	ANDREY FEDOTOV	{"email": "fedotov-andrey-071972@postgrespro.ru", "phone": "+70759886332"}
0005435153781	A732C2	0357 833826	VLADIMIR PAVLOV	{"email": "pavlov.vladimir_071970@postgrespro.ru", "phone": "+70043890393"}
0005435153782	88DDAF	0960 939963	NIKOLAY NOVIKOV	{"email": "novikov-nikolay.18071962@postgrespro.ru", "phone": "+70712918998"}
0005435153783	88DDAF	8742 030513	VALENTINA DAVYDOVA	{"email": "davydovavalentina-1973@postgrespro.ru", "phone": "+70997906804"}
0005435153784	FEBA04	8855 346520	EDUARD MIKHAYLOV	{"email": "eduard.mikhaylov021977@postgrespro.ru", "phone": "+70257851314"}
0005435153785	FEBA04	7271 325835	ALEKSANDR KUZNECOV	{"email": "akuznecov-051963@postgrespro.ru", "phone": "+70459828825"}
0005435153786	FEBA04	8006 483513	EDGAR BELOV	{"phone": "+70758880587"}
0005435153787	519831	8293 312441	ZLATA ZAKHAROVA	{"phone": "+70379879319"}
0005435153788	519831	9472 463021	SERGEY DMITRIEV	{"email": "dmitriev-s.091972@postgrespro.ru", "phone": "+70974473380"}
0005435153789	519831	4460 210331	YANA MALYSHEVA	{"email": "y-malysheva-121976@postgrespro.ru", "phone": "+70229379896"}
0005435153790	E711DA	9857 726419	OLGA KUDRYASHOVA	{"email": "olga-kudryashova-071983@postgrespro.ru", "phone": "+70858096937"}
0005435153791	6DBF75	6341 255699	IGOR YAKOVLEV	{"email": "i.yakovlev_1973@postgrespro.ru", "phone": "+70487688106"}
0005435153792	6DBF75	6716 873388	IRINA KUZNECOVA	{"phone": "+70906369739"}
0005435153793	30D71F	6605 838350	DMITRIY BELOV	{"email": "belovdmitriy_1982@postgrespro.ru", "phone": "+70288884022"}
0005435153794	ED53AF	6546 635574	NATALYA SMIRNOVA	{"phone": "+70997376266"}
0005435153795	ED53AF	2032 205881	ALEKSANDR POPOV	{"phone": "+70314457671"}
0005435153796	423975	3683 736948	ELENA KUZNECOVA	{"phone": "+70909116927"}
0005435153797	219FDE	7184 552673	NATALYA FADEEVA	{"email": "n-fadeeva30061983@postgrespro.ru", "phone": "+70144330420"}
0005435153798	AD1C2F	4761 511385	IGOR ROMANOV	{"phone": "+70592781415"}
0005435153799	AD1C2F	6739 884600	VYACHESLAV ZAYCEV	{"email": "vyacheslavzaycev_23111969@postgrespro.ru", "phone": "+70453803082"}
0005435153800	78FD7E	9455 377208	ANNA VOLKOVA	{"email": "a-volkova_1980@postgrespro.ru", "phone": "+70684895829"}
0005435153801	78FD7E	8842 817469	IVAN SOROKIN	{"email": "sorokin-ivan_041968@postgrespro.ru", "phone": "+70148664656"}
0005435153802	B6205B	6410 330740	VERA ALEKSANDROVA	{"email": "aleksandrova.vera11011981@postgrespro.ru", "phone": "+70512342105"}
0005435153803	E40D21	6802 200153	MIKHAIL MAKAROV	{"email": "makarov.mikhail_1965@postgrespro.ru", "phone": "+70443398547"}
0005435153804	E40D21	2702 668975	ALEKSEY TIMOFEEV	{"phone": "+70022355094"}
0005435153805	CE8F23	1123 742576	VLADIMIR DMITRIEV	{"email": "v-dmitriev.071962@postgrespro.ru", "phone": "+70157185316"}
0005435153806	B6145F	4606 392443	VALERIY ANDREEV	{"email": "valeriy_andreev.08121965@postgrespro.ru", "phone": "+70351400092"}
0005435153807	B6145F	1572 344037	ANNA KAZAKOVA	{"email": "kazakova_a_1979@postgrespro.ru", "phone": "+70166292155"}
0005435153808	64A562	4452 935366	ARTEM KRASNOV	{"email": "krasnov_artem.22091979@postgrespro.ru", "phone": "+70476049120"}
0005435153809	2B8D3E	3098 324491	LYUDMILA IVANOVA	{"email": "lyudmila_ivanova1974@postgrespro.ru", "phone": "+70727205025"}
0005435153810	05C9E8	2631 036108	OLGA KUZNECOVA	{"email": "kuznecova_o.091968@postgrespro.ru", "phone": "+70961504886"}
0005435153811	C1D96E	0364 507738	VITALIY SOROKIN	{"phone": "+70427771511"}
0005435153812	C1D96E	3736 324853	TATYANA DANILOVA	{"email": "tatyana_danilova1968@postgrespro.ru", "phone": "+70069323685"}
0005435153813	F04A0E	3748 870290	ANATOLIY MEDVEDEV	{"email": "anatoliy_medvedev-1972@postgrespro.ru", "phone": "+70361005876"}
0005435153814	7F81E6	5663 492641	NIKOLAY VOROBEV	{"phone": "+70520165925"}
0005435153815	7F81E6	7383 741010	ALEKSANDR MOROZOV	{"phone": "+70237677487"}
0005435153816	DAD8C4	4729 512315	VLADIMIR ANTONOV	{"phone": "+70888410558"}
0005435153817	A107D7	1209 628895	ALEKSANDR FROLOV	{"phone": "+70924605694"}
0005435153818	A107D7	1865 122385	ALINA ILINA	{"email": "alina.ilina-1978@postgrespro.ru", "phone": "+70948741478"}
0005435153819	934D96	7776 206288	ELENA NIKITINA	{"phone": "+70305699132"}
0005435153820	934D96	9661 304505	EVGENIY NIKOLAEV	{"phone": "+70129550445"}
0005435153821	0AC503	7722 756585	DMITRIY DAVYDOV	{"phone": "+70728939380"}
0005435153822	1F2F3F	5238 152078	SAMIRA GAVRILOVA	{"phone": "+70687813881"}
0005435153823	69CE68	5050 760045	ANATOLIY GERASIMOV	{"email": "gerasimov-anatoliy-111976@postgrespro.ru", "phone": "+70663719853"}
0005435153824	0E1FB5	8936 529153	NADEZHDA VASILEVA	{"phone": "+70417751238"}
0005435153825	C46C1D	4459 461704	ALEKSEY MIRONOV	{"phone": "+70743853756"}
0005435153826	C46C1D	6159 328850	ALENA MAKAROVA	{"phone": "+70949096371"}
0005435153827	8CCD36	2202 603661	OLGA ROMANOVA	{"phone": "+70827210033"}
0005435153828	8CCD36	3731 843737	SERGEY POPOV	{"phone": "+70052524758"}
0005435153829	06C548	2826 003266	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova_14101974@postgrespro.ru", "phone": "+70960110050"}
0005435153830	7ACC89	5158 440935	NADEZHDA KUZMINA	{"email": "n_kuzmina_26121967@postgrespro.ru", "phone": "+70520996645"}
0005435153831	A6654A	0638 412646	VLADIMIR ZHURAVLEV	{"email": "zhuravlev-vladimir.061968@postgrespro.ru", "phone": "+70631655570"}
0005435153832	2926D4	9757 593290	SVETLANA GRISHINA	{"email": "grishina_svetlana_20071966@postgrespro.ru", "phone": "+70594825877"}
0005435153833	91632D	7018 982669	VITALIY ALEKSEEV	{"email": "alekseevvitaliy_1970@postgrespro.ru", "phone": "+70918605325"}
0005435153834	91632D	8037 857534	ALEKSANDR ILIN	{"email": "aleksandr-ilin1967@postgrespro.ru", "phone": "+70885741258"}
0005435153835	91632D	0100 728118	IVAN FEDOTOV	{"email": "ivan_fedotov-061977@postgrespro.ru", "phone": "+70451280725"}
0005435153836	00E0B1	1409 428981	TATYANA MARTYNOVA	{"phone": "+70271642326"}
0005435153837	00E0B1	3787 031859	LYUBOV POPOVA	{"phone": "+70903801034"}
0005435153838	00E0B1	5969 564696	DARINA BELOVA	{"phone": "+70024671005"}
0005435153839	A8B368	2228 600376	SVETLANA IVANOVA	{"email": "sivanova_111981@postgrespro.ru", "phone": "+70272787730"}
0005435153840	A8B368	5808 498226	NATALYA SIDOROVA	{"phone": "+70033055756"}
0005435153841	719641	0836 304105	KARINA GUSEVA	{"email": "guseva.karina1980@postgrespro.ru", "phone": "+70323594391"}
0005435153842	546DF9	2418 958339	IRINA OSIPOVA	{"email": "irina_osipova_1984@postgrespro.ru", "phone": "+70406679377"}
0005435153843	4A40DC	7431 291289	SERGEY TARASOV	{"email": "starasov.1970@postgrespro.ru", "phone": "+70201853931"}
0005435153844	710300	6851 264107	VLADISLAV MARTYNOV	{"email": "v-martynov1976@postgrespro.ru", "phone": "+70025810425"}
0005435153845	911D84	2121 721300	ANDREY FEDOTOV	{"phone": "+70977861771"}
0005435153846	B08D18	0583 055133	ALEKSEY MOROZOV	{"email": "aleksey.morozov.111966@postgrespro.ru", "phone": "+70508370315"}
0005435153847	3D3A54	5551 920120	IVAN IVANOV	{"phone": "+70890089569"}
0005435153848	3D3A54	6537 389071	VLADIMIR MEDVEDEV	{"phone": "+70555023120"}
0005435153849	5BF6E3	1328 541929	VLADIMIR IVANOV	{"phone": "+70391277781"}
0005435153850	05C476	0819 691392	IGOR KOROLEV	{"phone": "+70708778280"}
0005435153851	05C476	7053 441823	RAMIL GERASIMOV	{"email": "gerasimov-ramil.26081964@postgrespro.ru", "phone": "+70786001821"}
0005435153852	05C476	1923 271296	OLEG MAKAROV	{"phone": "+70100409307"}
0005435153853	A8D0A8	6155 039435	VERA MELNIKOVA	{"email": "melnikova.vera-1976@postgrespro.ru", "phone": "+70839273581"}
0005435153854	7FEC80	5118 053100	ARTEM IVANOV	{"phone": "+70213097700"}
0005435153855	7FEC80	7871 878128	ANDREY DENISOV	{"email": "adenisov_26071975@postgrespro.ru", "phone": "+70446440190"}
0005435153856	51CF21	9882 422422	VALENTINA GUSEVA	{"email": "gusevavalentina11031983@postgrespro.ru", "phone": "+70500413300"}
0005435153857	74C3DE	2673 021108	TAMARA GUSEVA	{"email": "t-guseva_061971@postgrespro.ru", "phone": "+70080711760"}
0005435153858	74C3DE	1665 518964	TATYANA MOROZOVA	{"phone": "+70239607095"}
0005435153859	74C3DE	6228 703513	VERA FOMINA	{"email": "fominavera_13101977@postgrespro.ru", "phone": "+70317390913"}
0005435153860	4A9DDE	0695 667566	ROMAN ORLOV	{"email": "r_orlov.1972@postgrespro.ru", "phone": "+70923790626"}
0005435153861	CBC77E	4274 085432	GALINA ROMANOVA	{"email": "romanovagalina_071976@postgrespro.ru", "phone": "+70469264623"}
0005435153862	C69393	3987 581460	OKSANA KONDRATEVA	{"phone": "+70511659142"}
0005435153863	C69393	9991 660590	VYACHESLAV TARASOV	{"email": "vyacheslav_tarasov_1976@postgrespro.ru", "phone": "+70974266023"}
0005435153864	517F33	6950 161299	TATYANA ORLOVA	{"email": "t-orlova101972@postgrespro.ru", "phone": "+70571186325"}
0005435153865	197900	1584 073186	LYUBOV ZHURAVLEVA	{"phone": "+70982383248"}
0005435153866	E253BE	1365 688261	SERGEY MAKAROV	{"phone": "+70625807800"}
0005435153867	4CF7B8	2024 223976	VADIM YAKOVLEV	{"phone": "+70608335087"}
0005435153868	4CF7B8	7339 305401	SERGEY SOKOLOV	{"phone": "+70148645115"}
0005435153869	7D512E	6564 910563	ANTONINA TROFIMOVA	{"email": "trofimova-antonina_1973@postgrespro.ru", "phone": "+70784905878"}
0005435153870	29B0EC	8608 790717	LYUDMILA FILATOVA	{"email": "l_filatova24041968@postgrespro.ru", "phone": "+70484211205"}
0005435153871	95BB40	9689 831842	TAMARA DAVYDOVA	{"phone": "+70170576887"}
0005435153872	8EDD4B	2452 335239	KIRILL KUZMIN	{"phone": "+70204751081"}
0005435153873	8EDD4B	7254 261587	ILYAS KUDRYASHOV	{"phone": "+70567372379"}
0005435153874	8EDD4B	3177 532426	ALEKSANDR YAKOVLEV	{"phone": "+70439634638"}
0005435153875	98D161	6532 248022	MARSEL KULIKOV	{"email": "m-kulikov_051979@postgrespro.ru", "phone": "+70282630981"}
0005435153876	5275CE	3026 250645	EVELINA PAVLOVA	{"email": "e_pavlova.1975@postgrespro.ru", "phone": "+70284484888"}
0005435153877	7A70AE	7654 273708	YULIYA POPOVA	{"email": "popova_yuliya-01051962@postgrespro.ru", "phone": "+70273057495"}
0005435153878	7A70AE	2253 076545	DMITRIY KOZLOV	{"phone": "+70778860469"}
0005435153879	547797	8006 376825	ANDREY TIMOFEEV	{"phone": "+70108820198"}
0005435153880	27CACD	7784 000705	GALINA VASILEVA	{"email": "vasileva.g-011964@postgrespro.ru", "phone": "+70403734372"}
0005435153881	9ABA68	5160 717195	NINA KULIKOVA	{"email": "kulikova.nina-1961@postgrespro.ru", "phone": "+70886540878"}
0005435153882	9ABA68	7609 053956	LYUBOV VOROBEVA	{"email": "vorobeva.lyubov_021973@postgrespro.ru", "phone": "+70277516632"}
0005435153883	9ABA68	7622 688517	VLADIMIR ZHUKOV	{"phone": "+70176377613"}
0005435153884	7E6B54	7096 750593	VALERIY KAZAKOV	{"email": "kazakov-valeriy_1967@postgrespro.ru", "phone": "+70367805871"}
0005435153885	7CABC2	2645 471929	ALEKSANDR SIDOROV	{"phone": "+70367269269"}
0005435153886	DA93BC	8049 691554	OLGA KRASNOVA	{"email": "krasnovao.011981@postgrespro.ru", "phone": "+70334196084"}
0005435153887	363EB2	4194 444448	NINA DMITRIEVA	{"email": "dmitrieva_nina.1972@postgrespro.ru", "phone": "+70921773489"}
0005435153888	A19377	8809 105920	YURIY BELOV	{"email": "yuriy-belov18071971@postgrespro.ru", "phone": "+70308056809"}
0005435153889	3A7422	8866 972185	OLGA KUZMINA	{"phone": "+70557663149"}
0005435153890	1DAE1A	7977 399480	MIKHAIL ISAEV	{"email": "isaevmikhail-06021967@postgrespro.ru", "phone": "+70536881092"}
0005435153891	572C86	2421 915637	LYUBOV TROFIMOVA	{"email": "trofimova-l_031970@postgrespro.ru", "phone": "+70831244536"}
0005435153892	8B3053	7889 557078	ALEKSEY TARASOV	{"email": "tarasovaleksey_28111981@postgrespro.ru", "phone": "+70395211121"}
0005435153893	7717A2	5402 439440	VALENTINA NOVIKOVA	{"phone": "+70479664607"}
0005435153894	61F227	7316 354259	ZLATA EFREMOVA	{"phone": "+70967290422"}
0005435153895	21D470	9285 195791	VENIAMIN FROLOV	{"email": "frolov.veniamin-011978@postgrespro.ru", "phone": "+70209532230"}
0005435153896	5FDF26	3449 739952	TAMARA PETROVA	{"email": "tamara.petrova19021968@postgrespro.ru", "phone": "+70630419071"}
0005435153897	2FC4AE	3240 763500	MARIYA KISELEVA	{"phone": "+70838042218"}
0005435153898	2FC4AE	0559 615418	ANDREY SEMENOV	{"email": "semenov-andrey.091973@postgrespro.ru", "phone": "+70710421497"}
0005435153899	2FC4AE	4704 107309	KSENIYA VASILEVA	{"phone": "+70733817022"}
0005435153900	CE274F	8348 298540	VASILIY DENISOV	{"phone": "+70468237776"}
0005435153901	5A3B7F	5940 533498	IRINA FEDOROVA	{"phone": "+70117589473"}
0005435153902	67C8E3	1501 431836	VLADIMIR SOLOVEV	{"phone": "+70212185877"}
0005435153903	225775	1764 991408	ANVAR PETROV	{"phone": "+70598488446"}
0005435153904	B7F8F4	0844 794826	OLGA SIDOROVA	{"email": "sidorova-o_021966@postgrespro.ru", "phone": "+70874223592"}
0005435153905	B7F8F4	6309 898707	SERGEY AFANASEV	{"phone": "+70134110930"}
0005435153906	F3D840	9150 842832	SVETLANA DAVYDOVA	{"email": "s_davydova-1983@postgrespro.ru", "phone": "+70728798811"}
0005435153907	F3D840	6479 238748	YANA PAVLOVA	{"phone": "+70607764535"}
0005435153908	A9E325	7586 716092	EKATERINA ZHUKOVA	{"email": "zhukova-ekaterina-011977@postgrespro.ru", "phone": "+70440067517"}
0005435153909	F4A9E6	4608 697485	ANASTASIYA BOGDANOVA	{"email": "anastasiyabogdanova011966@postgrespro.ru", "phone": "+70518712644"}
0005435153910	F4A9E6	5261 033268	ELIZAVETA NIKOLAEVA	{"phone": "+70349338502"}
0005435153911	CE2E1F	7755 167085	ALEKSANDR KONOVALOV	{"phone": "+70291234987"}
0005435153912	CE2E1F	2310 712273	VLADIMIR PETROV	{"phone": "+70873092748"}
0005435153913	784ABC	4213 499667	ANASTASIYA VOROBEVA	{"email": "anastasiya.vorobeva08011974@postgrespro.ru", "phone": "+70329352639"}
0005435153914	784ABC	4430 390323	EKATERINA STEPANOVA	{"email": "e.stepanova.28031966@postgrespro.ru", "phone": "+70513949696"}
0005435153915	784ABC	1850 470152	IVAN KUZMIN	{"email": "i_kuzmin-1975@postgrespro.ru", "phone": "+70568391937"}
0005435153916	017FB4	2598 854879	ELENA VASILEVA	{"phone": "+70583676891"}
0005435153917	683722	9902 333819	VERA FILATOVA	{"phone": "+70317661449"}
0005435153918	61F615	0191 631655	VALENTINA EGOROVA	{"email": "valentina.egorova.1973@postgrespro.ru", "phone": "+70701120013"}
0005435153919	B806E2	4489 790797	LARISA KOLESNIKOVA	{"phone": "+70659556450"}
0005435153920	592A1B	5733 870021	LYUDMILA MAKSIMOVA	{"email": "lyudmila.maksimova.1966@postgrespro.ru", "phone": "+70413312528"}
0005435153921	592A1B	7802 535411	ANASTASIYA DAVYDOVA	{"phone": "+70325414483"}
0005435153922	592A1B	5297 536653	ALEKSANDR IVANOV	{"phone": "+70099909388"}
0005435153923	344A87	9356 063056	TATYANA YAKOVLEVA	{"phone": "+70851405572"}
0005435153924	6CBA17	1339 043920	MIKHAIL NIKITIN	{"email": "mikhail_nikitin_051965@postgrespro.ru", "phone": "+70272258057"}
0005435153925	D4CF29	0484 414126	RINAT KUZNECOV	{"phone": "+70139192855"}
0005435153926	36E03D	6026 059107	EKATERINA ABRAMOVA	{"phone": "+70324588398"}
0005435153927	26BB76	9700 885110	VERA SERGEEVA	{"email": "verasergeeva-101962@postgrespro.ru", "phone": "+70148621479"}
0005435153928	26BB76	4179 765611	LARISA POPOVA	{"phone": "+70432368495"}
0005435153929	294C62	9045 336695	VLADIMIR SERGEEV	{"phone": "+70959114391"}
0005435153930	6FB90B	9829 912858	ANNA KISELEVA	{"phone": "+70469076259"}
0005435153931	BEC1B6	7500 915296	ALEKSANDR SIDOROV	{"email": "sidorov_a.081967@postgrespro.ru", "phone": "+70493340959"}
0005435153932	F17762	7033 769394	TATYANA DANILOVA	{"phone": "+70695075331"}
0005435153933	F17762	6904 158398	ALEKSEY KUZNECOV	{"email": "kuznecova.071975@postgrespro.ru", "phone": "+70240232211"}
0005435153934	51A17B	1209 806467	SVETLANA EFIMOVA	{"email": "efimova_svetlana-29011973@postgrespro.ru", "phone": "+70734737248"}
0005435153935	52C3D3	3879 485515	ANTONINA KARPOVA	{"phone": "+70369115936"}
0005435153936	52C3D3	2748 681759	SERGEY MOROZOV	{"email": "morozovs_1978@postgrespro.ru", "phone": "+70658704343"}
0005435153937	5E38D2	0224 389902	EDUARD ZHUKOV	{"email": "eduardzhukov.031981@postgrespro.ru", "phone": "+70004363221"}
0005435153938	5E38D2	8396 348997	ANNA FADEEVA	{"phone": "+70807447451"}
0005435153939	69BE78	9094 073297	OLEG POPOV	{"email": "popovoleg.011970@postgrespro.ru", "phone": "+70634493254"}
0005435153940	899F93	1142 004276	DMITRIY ALEKSANDROV	{"email": "dmitriy.aleksandrov15091967@postgrespro.ru", "phone": "+70677074908"}
0005435153941	861E93	2745 108835	LYUBOV EGOROVA	{"phone": "+70190030812"}
0005435153942	861E93	0536 761182	ALENA KRASNOVA	{"phone": "+70063307531"}
0005435154580	025204	5402 690115	VLADIMIR FROLOV	{"email": "frolovv07021965@postgrespro.ru", "phone": "+70423489595"}
0005435154581	5780E6	7609 272740	ELENA KOROLEVA	{"email": "ekoroleva-1971@postgrespro.ru", "phone": "+70552630994"}
0005435154582	76EF67	6238 020932	ALEKSANDR GUSEV	{"email": "aleksandr_gusev_091969@postgrespro.ru", "phone": "+70483162329"}
0005435154583	2BCDE5	9845 403007	VALENTIN DAVYDOV	{"phone": "+70483552287"}
0005435154584	2BCDE5	7579 886854	VLADIMIR ANDREEV	{"phone": "+70883731060"}
0005435154585	2BCDE5	4798 446579	GENNADIY MATVEEV	{"phone": "+70735721446"}
0005435154586	648339	3227 330967	ELENA POPOVA	{"email": "elenapopova_1959@postgrespro.ru", "phone": "+70659053877"}
0005435154587	648339	3916 024282	ALEKSEY MEDVEDEV	{"email": "medvedev.aleksey-1983@postgrespro.ru", "phone": "+70444940507"}
0005435154588	587773	4182 879281	VLADIMIR SIDOROV	{"email": "vsidorov-121975@postgrespro.ru", "phone": "+70554352776"}
0005435154589	764B8F	6502 390950	BORIS KOROLEV	{"email": "b.korolev_1978@postgrespro.ru", "phone": "+70995453839"}
0005435154590	764B8F	3252 536273	ANTON PETROV	{"phone": "+70117245804"}
0005435154591	4F3582	6903 684950	VALENTINA ALEKSANDROVA	{"email": "aleksandrova.valentina-13081968@postgrespro.ru", "phone": "+70831902484"}
0005435154592	410002	6084 655741	VALENTINA ANTONOVA	{"email": "antonova-v1952@postgrespro.ru", "phone": "+70052636265"}
0005435154593	379766	8585 595837	SERGEY SMIRNOV	{"phone": "+70906589406"}
0005435154594	30792D	7948 140663	TATYANA KUZNECOVA	{"phone": "+70103892640"}
0005435154595	7B836D	6207 973175	ELENA ZAKHAROVA	{"email": "zakharova-e.071974@postgrespro.ru", "phone": "+70813971956"}
0005435154596	A55338	7960 458045	LYUDMILA NIKOLAEVA	{"phone": "+70515866072"}
0005435154597	A55338	4418 868705	VYACHESLAV ALEKSEEV	{"email": "vyacheslav-alekseev.011972@postgrespro.ru", "phone": "+70026920944"}
0005435154598	CE1EBA	6641 552417	VLADIMIR KUDRYASHOV	{"phone": "+70479857153"}
0005435154599	D04E56	7822 651313	ALEKSANDRA NAZAROVA	{"email": "nazarova_a041979@postgrespro.ru", "phone": "+70824573829"}
0005435154600	813F56	8625 446755	NADEZHDA STEPANOVA	{"email": "n-stepanova061970@postgrespro.ru", "phone": "+70456630135"}
0005435154601	813F56	5668 497511	STANISLAV GUSEV	{"email": "gusevs_10031967@postgrespro.ru", "phone": "+70738579399"}
0005435154602	9CE5D4	7111 463908	ANTONINA ZHUKOVA	{"email": "zhukovaantonina-011975@postgrespro.ru", "phone": "+70020855923"}
0005435154603	8D712F	5890 425135	VLADIMIR ANDREEV	{"email": "v-andreev-121972@postgrespro.ru", "phone": "+70854897017"}
0005435154604	8D712F	7207 537409	EVGENIY KONOVALOV	{"phone": "+70582355238"}
0005435154605	EB6AC2	2512 364938	MIKHAIL SOKOLOV	{"email": "sokolov_m-21121965@postgrespro.ru", "phone": "+70633949778"}
0005435154606	D1AA95	7566 231613	NATALYA NAZAROVA	{"email": "n-nazarova_13011972@postgrespro.ru", "phone": "+70720502549"}
0005435154607	D1AA95	1859 117603	IRINA KOZLOVA	{"email": "irina_kozlova-091984@postgrespro.ru", "phone": "+70862918147"}
0005435154608	06BBD4	3016 542133	NATALYA SCHERBAKOVA	{"email": "n-scherbakova021974@postgrespro.ru", "phone": "+70785151980"}
0005435154609	DB6C79	3156 605224	VYACHESLAV FEDOTOV	{"email": "fedotovv_11091973@postgrespro.ru", "phone": "+70411619350"}
0005435154610	340F3E	0520 864031	GENNADIY MATVEEV	{"phone": "+70309684489"}
0005435154611	E43DCE	2013 916740	ZOYA VOLKOVA	{"phone": "+70751279280"}
0005435154612	AC444F	0592 919143	OLGA ABRAMOVA	{"email": "oabramova_071972@postgrespro.ru", "phone": "+70990128645"}
0005435154613	AC444F	1326 810058	VLADIMIR IVANOV	{"email": "ivanov-vladimir.27101972@postgrespro.ru", "phone": "+70354760946"}
0005435154614	BD5CD6	7865 071473	ANDREY KOZLOV	{"phone": "+70015665911"}
0005435154615	D1CA73	0327 774203	ELENA POPOVA	{"email": "elenapopova-1970@postgrespro.ru", "phone": "+70956179768"}
0005435154616	E44370	6577 743192	SERGEY MAKAROV	{"email": "makarovs24051974@postgrespro.ru", "phone": "+70674061218"}
0005435154617	E44370	3501 194848	VLADIMIR GRIGOREV	{"phone": "+70012960287"}
0005435154618	D10CDA	8214 351971	MIKHAIL KOROLEV	{"phone": "+70608677241"}
0005435154619	231205	7844 460375	ALEKSANDR IVANOV	{"phone": "+70725438888"}
0005435154620	231205	4134 927687	LYUDMILA POLYAKOVA	{"email": "l.polyakova.1978@postgrespro.ru", "phone": "+70575822289"}
0005435154621	61ABF2	7954 401419	TIMUR MIKHAYLOV	{"phone": "+70639562341"}
0005435154622	61ABF2	9075 291318	LYUDMILA ZAYCEVA	{"email": "lyudmila.zayceva-17101976@postgrespro.ru", "phone": "+70941604694"}
0005435154623	9C06A0	4396 583206	MAKSIM TARASOV	{"phone": "+70992367603"}
0005435154624	00C213	7125 988984	ALEKSANDRA TIMOFEEVA	{"email": "timofeevaa01111973@postgrespro.ru", "phone": "+70406796351"}
0005435154625	B1DA13	1345 246908	MARIYA IVANOVA	{"phone": "+70489263553"}
0005435154626	7CA9E1	2031 673062	ALEKSANDR ZAKHAROV	{"phone": "+70393550073"}
0005435154627	904346	9613 838372	ALBINA ARKHIPOVA	{"email": "arkhipova.albina-061972@postgrespro.ru", "phone": "+70929421946"}
0005435154628	4E5DB0	2204 933077	LYUDMILA IVANOVA	{"phone": "+70410759400"}
0005435154629	B2C2F4	6738 142919	ILMIRA SOKOLOVA	{"phone": "+70073113507"}
0005435154630	67FEFE	2300 897236	ALENA IVANOVA	{"email": "ivanova.a-021969@postgrespro.ru", "phone": "+70695929844"}
0005435154631	6545C9	0832 059750	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova-s.14091980@postgrespro.ru", "phone": "+70457025063"}
0005435154632	6545C9	2957 111610	ARMEN DMITRIEV	{"email": "a-dmitriev-1964@postgrespro.ru", "phone": "+70092450628"}
0005435154633	66416B	5325 168014	ANNA EGOROVA	{"phone": "+70089727400"}
0005435154634	66416B	2796 294087	VALERIYA ZHUKOVA	{"email": "zhukovav_07111983@postgrespro.ru", "phone": "+70896196142"}
0005435154635	5D086E	7094 630112	SERGEY SAVELEV	{"phone": "+70808533610"}
0005435154636	D4D075	7126 861112	SVETLANA OSIPOVA	{"email": "s_osipova_031972@postgrespro.ru", "phone": "+70664808166"}
0005435154637	B8C7E6	9658 295858	ANTONINA POTAPOVA	{"email": "potapova_antonina-31071973@postgrespro.ru", "phone": "+70580219618"}
0005435154638	ACD888	2966 986463	NONNA DENISOVA	{"email": "denisova_n_1963@postgrespro.ru", "phone": "+70779805483"}
0005435154639	CADD43	7836 029708	ALEKSANDR SEMENOV	{"email": "semenovaleksandr-11081980@postgrespro.ru", "phone": "+70065137785"}
0005435154640	51F6CE	5248 459328	NIKOLAY ALEKSEEV	{"email": "nalekseev.1968@postgrespro.ru", "phone": "+70164242751"}
0005435154641	51F6CE	7553 879773	TATYANA SOLOVEVA	{"phone": "+70090247300"}
0005435154642	51F6CE	1069 554648	MAKSIM SERGEEV	{"email": "sergeev.maksim-22071970@postgrespro.ru", "phone": "+70938331432"}
0005435154643	C1725F	0340 112650	NIKOLAY VOLKOV	{"phone": "+70776616677"}
0005435154644	C1725F	4040 689882	RAFAEL BARANOV	{"phone": "+70705958518"}
0005435154645	AD1DB3	9042 070468	ALEKSANDRA FROLOVA	{"phone": "+70891803425"}
0005435154646	B72D94	9446 438861	LYUDMILA EGOROVA	{"phone": "+70815965777"}
0005435154647	27CF49	2290 692892	YURIY NAZAROV	{"phone": "+70610996301"}
0005435154648	5C33B9	1679 294260	IRINA AFANASEVA	{"phone": "+70241808316"}
0005435154649	5C33B9	2243 676766	MARINA MALYSHEVA	{"phone": "+70591992697"}
0005435154650	B44CAB	0420 277640	RUSLAN KUZNECOV	{"email": "kuznecov-ruslan.11091966@postgrespro.ru", "phone": "+70047285221"}
0005435154651	B44CAB	1490 121867	OLEG FEDOTOV	{"email": "fedotov-oleg_051968@postgrespro.ru", "phone": "+70970662564"}
0005435154652	1A2323	7517 838469	VYACHESLAV FEDOTOV	{"phone": "+70793447039"}
0005435154653	7DAC66	3733 486437	GULFIYA MIKHAYLOVA	{"email": "mikhaylova_g101974@postgrespro.ru", "phone": "+70851833622"}
0005435154654	135C92	1203 534047	LYUDMILA MOISEEVA	{"phone": "+70682663197"}
0005435154655	135C92	3255 927412	ALEKSANDR ISAEV	{"phone": "+70520686540"}
0005435154656	F70D71	2852 300610	NATALYA MOROZOVA	{"email": "natalya-morozova.21101970@postgrespro.ru", "phone": "+70723720511"}
0005435154657	7CA3E2	4195 305011	VLADIMIR ZAYCEV	{"email": "zaycev_v1962@postgrespro.ru", "phone": "+70136580473"}
0005435154658	BC1194	9989 969998	ANTON FROLOV	{"phone": "+70688819174"}
0005435154659	BC1194	6610 851387	VASILIY GUSEV	{"email": "v-gusev.18031968@postgrespro.ru", "phone": "+70044602835"}
0005435154660	0E7F4A	5055 468878	VLADISLAV BORISOV	{"phone": "+70520658562"}
0005435154661	1DFE7E	1441 064082	ALINA FILATOVA	{"phone": "+70294811238"}
0005435154662	CD3C1D	9486 293648	TAISIYA KUZNECOVA	{"phone": "+70422708529"}
0005435154663	3B0BB0	5880 139390	ANTON ZAYCEV	{"phone": "+70636883890"}
0005435154664	92BDD0	8843 578660	ELENA KULIKOVA	{"phone": "+70432111555"}
0005435154665	92BDD0	3599 294840	OLGA BELYAEVA	{"email": "belyaeva_olga-21051974@postgrespro.ru", "phone": "+70342750208"}
0005435154666	8D86FF	2489 856880	KIRA IVANOVA	{"phone": "+70548428350"}
0005435154667	8D86FF	8734 635353	EVGENIY MAKAROV	{"email": "makarove071965@postgrespro.ru", "phone": "+70251739733"}
0005435154668	DB6DD0	4473 100656	MARIYA PETROVA	{"email": "mpetrova.101977@postgrespro.ru", "phone": "+70255765771"}
0005435154669	DB6DD0	3017 706931	EVGENIYA FOMINA	{"email": "fominaevgeniya.051973@postgrespro.ru", "phone": "+70722129280"}
0005435154670	491FE9	1198 657222	ANASTASIYA DENISOVA	{"phone": "+70206545400"}
0005435154671	8E3EF0	6258 362181	MIKHAIL DENISOV	{"email": "denisov-mikhail06061968@postgrespro.ru", "phone": "+70025495614"}
0005435154672	8E3EF0	2969 956980	VALENTINA PETROVA	{"email": "vpetrova-051976@postgrespro.ru", "phone": "+70410692976"}
0005435154673	76137C	5924 698624	SERGEY NIKITIN	{"email": "nikitin_s_031981@postgrespro.ru", "phone": "+70345040830"}
0005435154674	73912E	1769 956145	PAVEL ANDREEV	{"phone": "+70506124264"}
0005435154675	453CBC	7784 936841	ANDREY GUSEV	{"email": "guseva-1984@postgrespro.ru", "phone": "+70349155719"}
0005435154676	453CBC	8508 470883	DZHAMILYA LUKYANOVA	{"email": "lukyanovad081978@postgrespro.ru", "phone": "+70865829330"}
0005435154677	6F3880	3030 415087	GALINA VOROBEVA	{"email": "galina-vorobeva-04081972@postgrespro.ru", "phone": "+70639581020"}
0005435154678	6F3880	7415 793442	NINA ZHUKOVA	{"phone": "+70923188813"}
0005435154679	6F3880	7681 867899	NIKOLAY MEDVEDEV	{"phone": "+70480039507"}
0005435154680	36801C	0504 859537	GALINA BELYAEVA	{"phone": "+70040105772"}
0005435154681	36801C	9731 628101	ALEKSEY BORISOV	{"phone": "+70886545911"}
0005435154682	E85AD9	9872 645431	EVGENIY IVANOV	{"phone": "+70870161064"}
0005435154683	E85AD9	0034 193710	SVETLANA IVANOVA	{"email": "ivanova-s-14071974@postgrespro.ru", "phone": "+70147248236"}
0005435154684	BE64C8	6885 137605	ANATOLIY TIKHONOV	{"phone": "+70412725310"}
0005435154685	BE64C8	0320 763357	NIKOLAY BORISOV	{"phone": "+70702869007"}
0005435154686	BE64C8	0769 994653	TAMARA RODIONOVA	{"email": "rodionova-tamara.21121970@postgrespro.ru", "phone": "+70680502031"}
0005435154687	1F47EF	1621 189049	ALEKSANDR SOROKIN	{"phone": "+70527780810"}
0005435154688	4E6448	2742 256755	ANASTASIYA RODIONOVA	{"email": "arodionova071955@postgrespro.ru", "phone": "+70151146868"}
0005435154689	FE6A67	3654 785384	VLADIMIR ALEKSEEV	{"phone": "+70279379199"}
0005435154690	453DD9	8991 970139	PETR CHERNOV	{"phone": "+70724059736"}
0005435154691	2412AD	7721 750737	ANATOLIY SEMENOV	{"phone": "+70356922597"}
0005435154692	2412AD	5189 958610	VIKTOR STEPANOV	{"phone": "+70643941151"}
0005435154693	ED4C2E	1561 188378	KIRA NESTEROVA	{"phone": "+70629284182"}
0005435154694	9496ED	4581 974990	ZINAIDA ANDREEVA	{"email": "andreeva_zinaida-1982@postgrespro.ru", "phone": "+70205229822"}
0005435154695	9496ED	3071 155721	VIKTOR GUSEV	{"phone": "+70967199777"}
0005435154696	CB3FB6	8762 307780	VLADISLAV VOLKOV	{"email": "vvolkov.21111981@postgrespro.ru", "phone": "+70545280626"}
0005435154697	E427DE	1689 773846	PAVEL DENISOV	{"email": "denisovp-12111961@postgrespro.ru", "phone": "+70267236414"}
0005435154698	015226	6952 799728	OLGA KOLESNIKOVA	{"phone": "+70923657523"}
0005435154699	BEF2CC	1034 967719	ALINA VASILEVA	{"phone": "+70253776691"}
0005435154700	D29BB6	7510 556021	SVETLANA EFREMOVA	{"email": "efremova_s.30031976@postgrespro.ru", "phone": "+70611600056"}
0005435154701	89C12B	7836 148224	VALENTINA ZAYCEVA	{"phone": "+70701921391"}
0005435154702	89C12B	6007 755983	VLADIMIR MIRONOV	{"phone": "+70363031543"}
0005435154703	E96269	7700 993688	LYUBOV POPOVA	{"phone": "+70090095545"}
0005435154704	036339	0223 024452	YURIY ZAKHAROV	{"email": "yuriy-zakharov.17011963@postgrespro.ru", "phone": "+70241834049"}
0005435154705	61F26D	5402 934740	ALEKSEY ISAEV	{"phone": "+70753070655"}
0005435154706	61F26D	0830 202936	VITALIY MARTYNOV	{"email": "v-martynov.061967@postgrespro.ru", "phone": "+70546741151"}
0005435154707	87FA35	1918 918506	MARIYA MIRONOVA	{"phone": "+70743289597"}
0005435154708	A4A1BE	1580 065833	ZINAIDA POPOVA	{"phone": "+70048410667"}
0005435160103	662B3E	8191 162225	VALENTINA ANDREEVA	{"phone": "+70488538982"}
0005435160104	662B3E	5484 002909	POLINA ZAYCEVA	{"email": "zayceva.polina_1964@postgrespro.ru", "phone": "+70088989168"}
0005435160105	4E917A	0837 307960	EVGENIYA MIKHAYLOVA	{"email": "emikhaylova_1970@postgrespro.ru", "phone": "+70144360700"}
0005435160106	9A20ED	1773 178943	VALENTINA MEDVEDEVA	{"email": "v.medvedeva121979@postgrespro.ru", "phone": "+70638412281"}
0005435160107	9A20ED	9410 632449	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr.1971@postgrespro.ru", "phone": "+70541447990"}
0005435160108	6FDDAE	2693 748612	DARYA GORBUNOVA	{"email": "gorbunova_darya.13061970@postgrespro.ru", "phone": "+70578813150"}
0005435160109	A4EA59	1093 182357	ALEKSEY CHERNOV	{"email": "a_chernov_13121981@postgrespro.ru", "phone": "+70726326652"}
0005435160110	E952EB	3666 827404	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr_1961@postgrespro.ru", "phone": "+70762219342"}
0005435160111	B40E31	0107 276667	ARTEM DAVYDOV	{"email": "a_davydov.061967@postgrespro.ru", "phone": "+70169675064"}
0005435160112	7FAB2B	2984 657271	BORIS ALEKSANDROV	{"phone": "+70298678723"}
0005435160113	02A4E3	4690 890835	SVETLANA VOLKOVA	{"phone": "+70203507941"}
0005435160114	40AC25	2067 286008	SERGEY FILIPPOV	{"email": "filippov_s-1968@postgrespro.ru", "phone": "+70706039049"}
0005435160115	6812D7	7360 603073	SVETLANA ILINA	{"email": "ilina_s041968@postgrespro.ru", "phone": "+70163361463"}
0005435160116	DEF3F1	2964 294083	EVGENIY KUZMIN	{"phone": "+70082356102"}
0005435160117	5FAB1B	4278 093656	OLGA FEDOROVA	{"email": "fedorova.olga_28081965@postgrespro.ru", "phone": "+70622311070"}
0005435160118	5FAB1B	1908 650483	LYUBOV SERGEEVA	{"email": "sergeeva-l_101962@postgrespro.ru", "phone": "+70951119235"}
0005435160119	76D4A2	6884 438540	DARYA SOROKINA	{"email": "d.sorokina-1972@postgrespro.ru", "phone": "+70506799184"}
0005435160120	76D4A2	9447 551566	MIKHAIL ZAKHAROV	{"phone": "+70363949243"}
0005435160121	191C00	2183 189271	ELENA KUZMINA	{"email": "elenakuzmina1964@postgrespro.ru", "phone": "+70504914518"}
0005435160122	11F9AA	4365 073901	ANASTASIYA OVCHINNIKOVA	{"email": "aovchinnikova_1966@postgrespro.ru", "phone": "+70672412932"}
0005435160123	11F9AA	9232 460212	VASILIY ANDREEV	{"email": "andreev_v021966@postgrespro.ru", "phone": "+70284823055"}
0005435160124	AD0D21	5966 357789	ALEKSANDR ZAYCEV	{"email": "a_zaycev.051966@postgrespro.ru", "phone": "+70173928265"}
0005435160125	401EAE	1246 536924	DAVID STEPANOV	{"phone": "+70613084535"}
0005435160126	C796F3	6559 808028	NATALYA NIKOLAEVA	{"email": "n-nikolaeva-15051974@postgrespro.ru", "phone": "+70876485152"}
0005435160127	C796F3	6973 560181	VALENTINA GAVRILOVA	{"phone": "+70689647671"}
0005435160128	C796F3	4961 733382	ARTUR ANDREEV	{"phone": "+70924255770"}
0005435160129	A5033D	3434 428523	VALENTINA CHERNOVA	{"phone": "+70097471667"}
0005435160130	7B0DC6	1907 868408	NATALYA PAVLOVA	{"email": "pavlova_natalya_1966@postgrespro.ru", "phone": "+70698089291"}
0005435160131	7B0DC6	7736 191187	ELENA KONDRATEVA	{"email": "e-kondrateva021965@postgrespro.ru", "phone": "+70620201488"}
0005435160132	09FA2F	1227 564985	VADIM KULIKOV	{"phone": "+70378224285"}
0005435160133	6EB827	4827 004210	ANASTASIYA SOKOLOVA	{"email": "sokolovaanastasiya.11011977@postgrespro.ru", "phone": "+70770190934"}
0005435160134	6EB827	9455 245710	MARIYA ILINA	{"email": "ilina.mariya.081977@postgrespro.ru", "phone": "+70725924710"}
0005435160135	F1A067	0475 491093	EKATERINA ERMAKOVA	{"email": "ermakova.ekaterina_09041974@postgrespro.ru", "phone": "+70002740888"}
0005435160136	F396F9	7322 665509	VLADISLAV MELNIKOV	{"email": "melnikov-v.22091970@postgrespro.ru", "phone": "+70048949230"}
0005435160137	9A5E4A	7812 752808	NADEZHDA SEMENOVA	{"phone": "+70757273747"}
0005435160138	DDA133	6382 234323	SVETLANA POTAPOVA	{"phone": "+70432703228"}
0005435160139	2EDBBC	7958 448850	OLGA KUZNECOVA	{"email": "olga.kuznecova-081972@postgrespro.ru", "phone": "+70779577940"}
0005435160140	010016	8539 790456	RADIK ZAKHAROV	{"phone": "+70437374266"}
0005435160141	8F5814	7391 480679	DMITRIY BELOV	{"phone": "+70147141027"}
0005435160142	261452	3308 648146	YURIY MOROZOV	{"email": "morozovyuriy_23021979@postgrespro.ru", "phone": "+70205316456"}
0005435160143	261452	6527 790652	ANDREY YAKOVLEV	{"email": "ayakovlev.021979@postgrespro.ru", "phone": "+70095579775"}
0005435160144	8C48E8	1121 697887	LYUDMILA BORISOVA	{"email": "l-borisova_1964@postgrespro.ru", "phone": "+70793943773"}
0005435160145	8C48E8	1461 115353	RAISA KALININA	{"email": "kalinina_r_1973@postgrespro.ru", "phone": "+70183623940"}
0005435160146	8C48E8	2648 802083	TAMARA MELNIKOVA	{"email": "melnikova-tamara.111973@postgrespro.ru", "phone": "+70493958650"}
0005435160147	D24425	8852 297055	GRIGORIY SEMENOV	{"email": "g_semenov-14051962@postgrespro.ru", "phone": "+70052275330"}
0005435160148	D24425	8657 185077	ANASTASIYA DMITRIEVA	{"phone": "+70928948005"}
0005435160149	D24425	8583 742174	ARTEM ABRAMOV	{"email": "abramov.a041962@postgrespro.ru", "phone": "+70042906251"}
0005435160150	47B634	7230 004045	MARIYA BELOVA	{"email": "belova.mariya1967@postgrespro.ru", "phone": "+70658891520"}
0005435160151	02422C	1704 319341	NADEZHDA MAKAROVA	{"email": "makarova-nadezhda.1961@postgrespro.ru", "phone": "+70464786987"}
0005435160152	624170	4376 646966	EVGENIYA DENISOVA	{"email": "denisovae17081976@postgrespro.ru", "phone": "+70928381498"}
0005435160153	EFEC34	7150 585063	MARAT VOROBEV	{"email": "vorobev.marat.1969@postgrespro.ru", "phone": "+70415255949"}
0005435160154	EFEC34	2113 947704	NATALYA MELNIKOVA	{"email": "melnikova-n_051974@postgrespro.ru", "phone": "+70102218949"}
0005435160155	3178EE	5604 611450	ROMAN FEDOROV	{"email": "fedorov.r_1980@postgrespro.ru", "phone": "+70480250517"}
0005435160156	FAFAA3	9195 075102	VASILIY IVANOV	{"email": "ivanov_vasiliy121975@postgrespro.ru", "phone": "+70124870752"}
0005435160157	4236B8	0834 713201	SERGEY SCHERBAKOV	{"email": "scherbakov_s_01111968@postgrespro.ru", "phone": "+70153549654"}
0005435160158	7A60D2	0625 984114	NIKOLAY IVANOV	{"email": "nikolay.ivanov-101962@postgrespro.ru", "phone": "+70445890703"}
0005435160159	7A60D2	3674 253258	IRINA DMITRIEVA	{"phone": "+70026364582"}
0005435160160	48E1EF	4515 299762	ZLATA VOLKOVA	{"phone": "+70319810379"}
0005435160161	857566	9972 327008	ALEKSANDRA KISELEVA	{"email": "a-kiseleva1983@postgrespro.ru", "phone": "+70887099870"}
0005435160162	E242F2	6132 601107	IVAN MIKHAYLOV	{"phone": "+70818799746"}
0005435160163	CFF953	3567 224780	DARINA AKIMOVA	{"phone": "+70854321852"}
0005435160164	CFF953	8346 596350	BORIS DAVYDOV	{"email": "davydovboris.121965@postgrespro.ru", "phone": "+70285193629"}
0005435160165	C66C88	5233 541644	SERGEY MELNIKOV	{"phone": "+70044540769"}
0005435160166	5AF17D	8428 864709	ALEKSANDR FEDOROV	{"phone": "+70220401213"}
0005435160167	0CA4B5	2902 720275	RUSTAM NIKOLAEV	{"email": "rustamnikolaev1968@postgrespro.ru", "phone": "+70063679773"}
0005435160168	0F9DDF	1119 663378	TAMARA KUZMINA	{"email": "kuzminat.11111975@postgrespro.ru", "phone": "+70758986693"}
0005435160169	206575	2128 935094	ALEKSEY VASILEV	{"phone": "+70647794906"}
0005435160170	206575	5016 573866	ELENA AFANASEVA	{"phone": "+70296781650"}
0005435160171	750227	6379 629792	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov.071983@postgrespro.ru", "phone": "+70876430979"}
0005435160172	67E488	0394 639267	SVETLANA POLYAKOVA	{"phone": "+70311574878"}
0005435160173	C1A7CB	6880 347526	IRINA KOROLEVA	{"phone": "+70355367345"}
0005435160174	FDDDAA	3858 019294	ANATOLIY MAKAROV	{"phone": "+70608190445"}
0005435160175	F246B5	0588 742946	NIKOLAY POPOV	{"email": "popov.n.09081987@postgrespro.ru", "phone": "+70709813934"}
0005435160176	F246B5	4625 853611	SERGEY VOROBEV	{"email": "s-vorobev26021974@postgrespro.ru", "phone": "+70945583931"}
0005435160177	46E325	9158 651157	MIKHAIL KUZNECOV	{"phone": "+70591473274"}
0005435160178	46E325	5830 164522	VERA ROMANOVA	{"phone": "+70484180766"}
0005435160179	D9023C	4222 496818	PAVEL IVANOV	{"phone": "+70736006050"}
0005435160180	89B8C9	9484 420659	ANDREY EGOROV	{"email": "egorov-andrey_11101973@postgrespro.ru", "phone": "+70501861036"}
0005435160181	A1CA17	9508 683928	VASILIY VASILEV	{"phone": "+70890947209"}
0005435160182	DE305A	2691 852807	OLEG POPOV	{"phone": "+70282368541"}
0005435160183	24FC82	5695 563232	EVGENIY VOLKOV	{"phone": "+70668202596"}
0005435160184	24FC82	5741 550558	NADEZHDA STEPANOVA	{"email": "stepanovan_18071969@postgrespro.ru", "phone": "+70267662245"}
0005435160185	456385	1008 563051	VASILIY NOVIKOV	{"email": "v.novikov.051964@postgrespro.ru", "phone": "+70832653936"}
0005435160186	AE06CD	8193 349527	OLGA IVANOVA	{"phone": "+70948543632"}
0005435160187	EA713E	9246 799310	NIKOLAY STEPANOV	{"email": "stepanovnikolay08101967@postgrespro.ru", "phone": "+70244552764"}
0005435160188	E6E30A	7532 180528	NIKOLAY KAZAKOV	{"phone": "+70787258491"}
0005435160189	E6E30A	5867 658085	LYUDMILA OSIPOVA	{"phone": "+70112816696"}
0005435160190	E1D435	4707 421926	ALEKSEY KAZAKOV	{"phone": "+70605499414"}
0005435160191	372ECD	0448 481604	NADEZHDA VASILEVA	{"email": "n.vasileva_071977@postgrespro.ru", "phone": "+70901872073"}
0005435160192	902DC9	3146 878646	ALEKSANDR PETROV	{"phone": "+70344546848"}
0005435160193	ABCC9C	4433 074838	DENIS IVANOV	{"email": "denis-ivanov-1969@postgrespro.ru", "phone": "+70153033135"}
0005435160194	309B53	9638 868023	SERGEY SMIRNOV	{"phone": "+70074610390"}
0005435160195	B505A2	1447 407972	VLADISLAV BARANOV	{"email": "baranovv.011973@postgrespro.ru", "phone": "+70435652136"}
0005435160196	A2A882	9102 046936	NINA EFIMOVA	{"phone": "+70374490049"}
0005435160197	2DBE16	0384 690502	NATALYA VASILEVA	{"email": "vasilevanatalya.071964@postgrespro.ru", "phone": "+70607160035"}
0005435160198	2DBE16	8805 693264	NATALYA TIMOFEEVA	{"phone": "+70399494152"}
0005435160199	BF9828	1262 786874	SERGEY BONDARENKO	{"phone": "+70392439562"}
0005435160200	68F592	0627 857399	ELENA FEDOROVA	{"phone": "+70914900014"}
0005435160201	D55BDA	4401 752321	NATALYA SMIRNOVA	{"email": "smirnova.n_101987@postgrespro.ru", "phone": "+70336536810"}
0005435160202	AAB785	7757 268716	VLADIMIR NIKOLAEV	{"phone": "+70185692134"}
0005435160203	AAB785	3907 990865	YURIY SOLOVEV	{"phone": "+70600910826"}
0005435160204	FA4CF9	7104 708390	ALINA FADEEVA	{"phone": "+70696226308"}
0005435160205	A06229	9638 215823	VIKTORIYA ROMANOVA	{"phone": "+70719803991"}
0005435160206	97609A	8005 820975	ILYA PAVLOV	{"phone": "+70955807406"}
0005435160207	A809AA	0953 092926	VIKTORIYA OSIPOVA	{"email": "vosipova1986@postgrespro.ru", "phone": "+70389010058"}
0005435160208	6C543B	7363 996219	VLADIMIR ZAYCEV	{"email": "vladimirzaycev-01031965@postgrespro.ru", "phone": "+70139234451"}
0005435160209	C3E56C	5780 680930	SVETLANA NIKITINA	{"phone": "+70580910151"}
0005435160210	C3E56C	0468 234963	VYACHESLAV ANDREEV	{"phone": "+70491149735"}
0005435160211	25695B	3147 621250	IGOR MIRONOV	{"phone": "+70928615638"}
0005435160212	FDC0A2	1234 599634	SERGEY KUZNECOV	{"phone": "+70460173088"}
0005435160213	FDC0A2	9561 851569	LYUDMILA KONOVALOVA	{"phone": "+70484321811"}
0005435160214	FDC0A2	6166 827913	ALINA NAZAROVA	{"email": "alina.nazarova-061979@postgrespro.ru", "phone": "+70793413891"}
0005435160215	014E39	4088 380173	VLADISLAV MAKAROV	{"phone": "+70004271040"}
0005435160216	014E39	0538 082552	ALEKSANDR KONOVALOV	{"phone": "+70745059835"}
0005435160217	79C68F	2924 452553	VLADIMIR FEDOROV	{"email": "vfedorov-081967@postgrespro.ru", "phone": "+70272415680"}
0005435160218	402657	3611 041677	MIKHAIL FEDOROV	{"phone": "+70537047087"}
0005435160219	DF4E69	6513 948003	EVGENIY RODIONOV	{"phone": "+70090340566"}
0005435160220	CEF149	5568 702976	LYUDMILA NIKITINA	{"phone": "+70188588380"}
0005435160221	DDF9A7	2108 527898	ALEKSANDR SOROKIN	{"email": "sorokin_a091971@postgrespro.ru", "phone": "+70164430442"}
0005435160222	DDF9A7	8747 467612	ANATOLIY STEPANOV	{"email": "anatoliy-stepanov_1961@postgrespro.ru", "phone": "+70396763394"}
0005435160223	EE2C96	8087 134591	KSENIYA KISELEVA	{"phone": "+70923463911"}
0005435160224	B0F51E	4158 920706	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov-29011967@postgrespro.ru", "phone": "+70366967435"}
0005435160225	DCEA2C	9293 425333	VLADIMIR NIKOLAEV	{"phone": "+70052058348"}
0005435160226	D98B15	4701 081955	ALENA NAZAROVA	{"email": "alena_nazarova_1968@postgrespro.ru", "phone": "+70369959951"}
0005435160227	1E014C	1826 598380	VALERIY SCHERBAKOV	{"email": "v.scherbakov05101972@postgrespro.ru", "phone": "+70998044140"}
0005435160228	A24527	2834 315105	EVGENIYA VLASOVA	{"email": "vlasovae_1980@postgrespro.ru", "phone": "+70845603939"}
0005435160229	C73BDC	6995 047399	NIKITA PETROV	{"email": "nikitapetrov_111977@postgrespro.ru", "phone": "+70862057303"}
0005435160230	E2B675	7715 549766	SERGEY KISELEV	{"phone": "+70267078634"}
0005435160231	BAD8C0	6470 054823	EVGENIY ZHURAVLEV	{"email": "zhuravlevevgeniy-20061959@postgrespro.ru", "phone": "+70252581650"}
0005435160232	A4759A	6439 766864	ALEKSANDR FEDOROV	{"phone": "+70784841532"}
0005435160233	751404	7784 582769	GALINA ZAYCEVA	{"email": "gzayceva-09021973@postgrespro.ru", "phone": "+70070405781"}
0005435160234	3A4A4C	8678 726911	ALEKSANDR FILIPPOV	{"phone": "+70784687332"}
0005435160235	6DF6EF	3149 293496	KIRILL GUSEV	{"phone": "+70239918008"}
0005435160236	6DF6EF	7928 106596	NIKOLAY KUZNECOV	{"phone": "+70255791303"}
0005435160237	6DF6EF	8870 422496	EKATERINA KAZAKOVA	{"phone": "+70552798889"}
0005435160238	3AE206	7182 662282	NATALYA GORBUNOVA	{"phone": "+70041186122"}
0005435160239	475441	5230 107872	VASILIY ZAKHAROV	{"email": "vasiliy-zakharov_1972@postgrespro.ru", "phone": "+70684009235"}
0005435160240	307364	6348 318727	VIKTOR ZAKHAROV	{"phone": "+70895662744"}
0005435160241	A85D57	1702 168752	NATALYA FILATOVA	{"email": "filatovanatalya011972@postgrespro.ru", "phone": "+70594628540"}
0005435160242	A85D57	4996 613505	ANTON NIKITIN	{"phone": "+70049959807"}
0005435160243	0783F9	0896 617091	OLGA ANTONOVA	{"phone": "+70159818969"}
0005435160244	68EAE9	2453 241664	MARGARITA MIRONOVA	{"phone": "+70680671170"}
0005435160245	68EAE9	2577 554692	SVETLANA ALEKSANDROVA	{"phone": "+70057596024"}
0005435160246	9E9CD0	2102 182394	VASILIY GRIGOREV	{"phone": "+70094270576"}
0005435160247	309462	6167 129210	ANNA SIDOROVA	{"phone": "+70882104597"}
0005435160248	0BCAB9	7805 068600	DMITRIY MARTYNOV	{"email": "martynov.d111968@postgrespro.ru", "phone": "+70816729021"}
0005435160249	0BCAB9	4663 097289	RAVIL FEDOTOV	{"email": "ravil.fedotov-05091973@postgrespro.ru", "phone": "+70704017202"}
0005435160250	0C6228	3741 971519	LEONID AFANASEV	{"email": "lafanasev_27081966@postgrespro.ru", "phone": "+70013195576"}
0005435160419	96D4C6	5901 739612	MARINA NIKITINA	{"phone": "+70980240272"}
0005435160251	0C6228	2470 108333	IRINA POTAPOVA	{"email": "potapova-i_1975@postgrespro.ru", "phone": "+70476381437"}
0005435160252	083A92	8994 660338	OLGA POPOVA	{"phone": "+70742020853"}
0005435160253	083A92	3882 747025	TATYANA LAZAREVA	{"phone": "+70285191270"}
0005435160254	083A92	2404 730233	VLADIMIR FILIPPOV	{"phone": "+70565815652"}
0005435160255	03D505	3676 290134	TATYANA KOLESNIKOVA	{"phone": "+70397297887"}
0005435160256	AB324F	8695 385934	ALEKSANDR TIKHONOV	{"email": "tikhonov-a.111974@postgrespro.ru", "phone": "+70992761471"}
0005435160257	85D369	3757 656130	NATALYA VOROBEVA	{"phone": "+70492300101"}
0005435160258	85D369	7066 652363	VIKTOR VOLKOV	{"phone": "+70302953302"}
0005435160259	41EB15	8282 850357	ANDREY GAVRILOV	{"phone": "+70422028252"}
0005435160260	D773C7	1500 038592	ZULFIYA MIRONOVA	{"email": "mironova-z-1972@postgrespro.ru", "phone": "+70414071609"}
0005435160261	E0076E	5872 993333	DMITRIY ROMANOV	{"phone": "+70422756768"}
0005435160262	07EAC3	2746 653563	IRINA ISAEVA	{"phone": "+70463125659"}
0005435160263	07EAC3	0594 272187	ALEKSANDR ZHUKOV	{"phone": "+70260924343"}
0005435160264	BC1CD8	6335 290473	ZINAIDA MIKHAYLOVA	{"phone": "+70447513074"}
0005435160265	2649F6	4547 914056	MARINA SEMENOVA	{"email": "semenovam-1956@postgrespro.ru", "phone": "+70576005000"}
0005435160266	6D2CFA	2211 949675	LYUBOV EFREMOVA	{"email": "efremova_lyubov.10111969@postgrespro.ru", "phone": "+70779471539"}
0005435160267	81E571	1944 844958	SERGEY GUSEV	{"phone": "+70472799510"}
0005435160268	81E571	8771 144642	NATALYA YAKOVLEVA	{"phone": "+70139898735"}
0005435160269	FCCA5E	7221 802980	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr.20081965@postgrespro.ru", "phone": "+70117980452"}
0005435160270	FCCA5E	6005 180565	MIKHAIL MELNIKOV	{"email": "melnikovm051970@postgrespro.ru", "phone": "+70732954418"}
0005435160271	E80B76	4751 799279	STEPAN SMIRNOV	{"email": "smirnov.s1970@postgrespro.ru", "phone": "+70547783690"}
0005435160272	E80B76	8048 817165	TAMARA NOVIKOVA	{"email": "novikova_tamara-091975@postgrespro.ru", "phone": "+70738885045"}
0005435160273	AE97C9	7389 665806	DARYA MAKSIMOVA	{"email": "d.maksimova_1971@postgrespro.ru", "phone": "+70903005031"}
0005435160274	9119F1	1317 546613	VIKTOR NAUMOV	{"phone": "+70654959399"}
0005435160275	9119F1	5300 959461	ALINA CHERNOVA	{"email": "alinachernova021984@postgrespro.ru", "phone": "+70856064745"}
0005435160276	FB98E6	7973 568284	ROMAN SHEVCHENKO	{"phone": "+70071897270"}
0005435160277	E2066B	2055 780807	GALINA KOROLEVA	{"email": "korolevagalina-23031975@postgrespro.ru", "phone": "+70171909522"}
0005435160278	2F8415	0624 001169	NATALYA ANDREEVA	{"email": "n.andreeva_071968@postgrespro.ru", "phone": "+70427710718"}
0005435160279	792999	5683 451033	NINA MAKAROVA	{"email": "nmakarova-101976@postgrespro.ru", "phone": "+70420965872"}
0005435160280	18178F	3847 179821	DMITRIY SOLOVEV	{"phone": "+70480850058"}
0005435160281	A4DFD9	9077 822163	ANNA DAVYDOVA	{"email": "anna.davydova_17031974@postgrespro.ru", "phone": "+70723927081"}
0005435160282	71BB41	0113 426573	NIKITA IVANOV	{"email": "ivanov.nikita011971@postgrespro.ru", "phone": "+70586840923"}
0005435160283	4C1D9C	6933 712659	OKSANA GERASIMOVA	{"phone": "+70809713787"}
0005435160284	D7AB8A	5828 384315	ANDREY DENISOV	{"email": "denisov-a-1961@postgrespro.ru", "phone": "+70562565496"}
0005435160285	D7AB8A	8418 711900	OLGA RYABOVA	{"email": "o-ryabova-1971@postgrespro.ru", "phone": "+70398205516"}
0005435160286	5AC3AA	2865 786195	VALENTINA PETROVA	{"email": "petrova-v.051975@postgrespro.ru", "phone": "+70323256741"}
0005435160287	5AC3AA	0670 111488	LILIYA KOROLEVA	{"phone": "+70049647510"}
0005435160288	5AC3AA	3192 501131	SERGEY IVANOV	{"email": "ivanov-s021975@postgrespro.ru", "phone": "+70431141747"}
0005435160289	808730	6726 805077	ALENA BORISOVA	{"phone": "+70731966225"}
0005435160290	3F53DD	3163 757083	VALENTINA BARANOVA	{"email": "valentina-baranova.011975@postgrespro.ru", "phone": "+70431560637"}
0005435160291	3F53DD	5220 056630	GALINA KUZNECOVA	{"email": "kuznecova_g.01111976@postgrespro.ru", "phone": "+70675653975"}
0005435160292	1F21EB	5614 507138	NIKOLAY OSIPOV	{"email": "osipov.n-11071974@postgrespro.ru", "phone": "+70191167772"}
0005435160293	871AFF	0000 916567	MARIYA KRASNOVA	{"phone": "+70392649081"}
0005435160294	600E8E	7315 704621	GALINA YUDINA	{"email": "yudina-g_061972@postgrespro.ru", "phone": "+70718520669"}
0005435160295	600E8E	4146 577016	YULIYA NOVIKOVA	{"email": "novikovay091968@postgrespro.ru", "phone": "+70117129688"}
0005435160296	D6705B	0488 815303	AIDA LAZAREVA	{"email": "lazareva_aida_1960@postgrespro.ru", "phone": "+70087228012"}
0005435160297	00A48B	8363 600953	SERGEY ZHURAVLEV	{"phone": "+70189278892"}
0005435160298	00A48B	8660 399230	SVETLANA GERASIMOVA	{"email": "gerasimova-svetlana1972@postgrespro.ru", "phone": "+70366002033"}
0005435160299	B5E955	6685 468923	DIANA POPOVA	{"email": "popova-d.021975@postgrespro.ru", "phone": "+70908055280"}
0005435160300	71ED16	0786 872206	VIKTOR CHERNOV	{"email": "chernov.viktor.12031964@postgrespro.ru", "phone": "+70008878335"}
0005435160301	71ED16	6583 326188	IGOR VASILEV	{"phone": "+70652199991"}
0005435160302	F79705	5153 306677	NATALYA SMIRNOVA	{"phone": "+70608609782"}
0005435160303	84685B	7735 166853	LYUDMILA ANDREEVA	{"email": "lyudmila_andreeva12121956@postgrespro.ru", "phone": "+70123291270"}
0005435160304	84685B	1440 753621	DMITRIY ILIN	{"phone": "+70009692293"}
0005435160305	298763	3350 374007	ANATOLIY KONOVALOV	{"email": "a_konovalov121970@postgrespro.ru", "phone": "+70186613122"}
0005435160306	298763	8694 017958	NIKOLAY PAVLOV	{"phone": "+70125993584"}
0005435160307	BC167E	0476 639325	LYUBOV VOLKOVA	{"email": "volkova.l_021979@postgrespro.ru", "phone": "+70763484210"}
0005435160308	E5A5B4	0176 923506	VLADISLAV NIKITIN	{"phone": "+70351159214"}
0005435160309	019608	0955 796633	SVETLANA MALYSHEVA	{"email": "s.malysheva-061969@postgrespro.ru", "phone": "+70608983172"}
0005435160310	E80126	6159 926143	VALENTINA VASILEVA	{"phone": "+70223462139"}
0005435160311	E80126	2594 788617	ARTEM GERASIMOV	{"email": "artem.gerasimov051979@postgrespro.ru", "phone": "+70410680761"}
0005435160312	E80126	4538 974559	VIKTOR AFANASEV	{"phone": "+70948250009"}
0005435160313	06FCCA	4139 044296	ALEKSANDR VLASOV	{"phone": "+70411680948"}
0005435160314	06FCCA	6346 907170	ELENA SOLOVEVA	{"email": "soloveva-e.12111974@postgrespro.ru", "phone": "+70242103191"}
0005435160315	AF7B14	6967 586286	GALINA MIRONOVA	{"email": "mironova_g.17011971@postgrespro.ru", "phone": "+70689423328"}
0005435160316	AF7B14	5240 769575	TAISIYA SOROKINA	{"phone": "+70199021419"}
0005435160317	47EFA6	4767 624678	VERA VOLKOVA	{"email": "volkova.v1966@postgrespro.ru", "phone": "+70032343898"}
0005435160318	A93990	7557 215256	TAMARA PAVLOVA	{"phone": "+70694823015"}
0005435160319	F85C8E	9825 546862	LIDIYA KOROLEVA	{"email": "lidiya-koroleva.031966@postgrespro.ru", "phone": "+70427960545"}
0005435160320	FA915D	6318 578989	NIKITA TIKHONOV	{"phone": "+70723046913"}
0005435160321	A7D1CB	2247 981352	MARGARITA PETROVA	{"email": "m-petrova09021965@postgrespro.ru", "phone": "+70622959791"}
0005435160322	BDB682	2661 633109	ALESYA FEDOROVA	{"email": "fedorova-a_081961@postgrespro.ru", "phone": "+70053250109"}
0005435160323	BDB682	8971 840598	ALEKSANDR PETROV	{"email": "petrov_aleksandr_1970@postgrespro.ru", "phone": "+70876543805"}
0005435160324	E36831	2992 268291	VLADISLAV BORISOV	{"email": "v-borisov.121976@postgrespro.ru", "phone": "+70944427557"}
0005435160325	E36831	1516 949938	YANA MATVEEVA	{"email": "y.matveeva-17011970@postgrespro.ru", "phone": "+70029946456"}
0005435160326	AF397E	9808 725175	AZAT ALEKSEEV	{"email": "alekseev_azat-1967@postgrespro.ru", "phone": "+70429682360"}
0005435160327	583204	6864 428281	SERGEY KUZMIN	{"email": "kuzminsergey24071977@postgrespro.ru", "phone": "+70278821894"}
0005435160328	BCFCB4	8829 690584	MARIYA POPOVA	{"email": "popovamariya-24121973@postgrespro.ru", "phone": "+70700296727"}
0005435160329	3BAC65	3676 840162	OKSANA DAVYDOVA	{"email": "davydova_o1972@postgrespro.ru", "phone": "+70155205755"}
0005435160330	3BAC65	3222 128605	OLGA FEDOROVA	{"email": "o.fedorova_1974@postgrespro.ru", "phone": "+70377261824"}
0005435160331	817F0B	1402 867480	LILIYA GERASIMOVA	{"email": "gerasimova_l-071979@postgrespro.ru", "phone": "+70914883937"}
0005435160332	817F0B	2118 433403	IRINA DAVYDOVA	{"phone": "+70110425625"}
0005435160333	369E2D	5212 385152	SERGEY TARASOV	{"email": "tarasov_s.18011963@postgrespro.ru", "phone": "+70513039628"}
0005435160334	CC8786	7838 312264	MARINA ALEKSEEVA	{"phone": "+70257742870"}
0005435160335	BEABE0	1484 186260	REGINA FEDOROVA	{"phone": "+70884206265"}
0005435160336	94C945	6562 614274	VALENTINA SMIRNOVA	{"email": "smirnovav1976@postgrespro.ru", "phone": "+70054764024"}
0005435160337	94C945	4853 662684	OLGA FILIPPOVA	{"phone": "+70598045292"}
0005435160338	27CC34	5244 664660	NIKITA EGOROV	{"email": "nikita_egorov_21101983@postgrespro.ru", "phone": "+70903491568"}
0005435160339	EA79C5	9483 072202	IVAN BELOV	{"phone": "+70402254638"}
0005435160340	8A8B59	6518 922750	LYUDMILA KOVALEVA	{"phone": "+70258903594"}
0005435160341	8A8B59	1775 584373	LYUBOV KOZLOVA	{"phone": "+70991136537"}
0005435160342	F4BD65	8796 404993	IRINA SEMENOVA	{"email": "i-semenova.22111985@postgrespro.ru", "phone": "+70335982210"}
0005435160343	6F57F5	2698 784947	NATALYA ERMAKOVA	{"phone": "+70464239652"}
0005435160344	9DB572	0751 569597	MARIYA GORBUNOVA	{"phone": "+70766960669"}
0005435160345	879999	7913 456612	MARINA KUZNECOVA	{"email": "m.kuznecova_1970@postgrespro.ru", "phone": "+70173280423"}
0005435160346	879999	4899 024415	IVAN GAVRILOV	{"email": "i_gavrilov071980@postgrespro.ru", "phone": "+70663235836"}
0005435160347	879999	7061 775177	VLADIMIR GAVRILOV	{"email": "vladimir_gavrilov_011967@postgrespro.ru", "phone": "+70325428581"}
0005435160348	17C651	9942 296143	NATALYA IVANOVA	{"email": "ivanova_natalya1967@postgrespro.ru", "phone": "+70382905143"}
0005435160349	17C651	2367 568525	SERGEY KUZMIN	{"email": "kuzmin-sergey_23021973@postgrespro.ru", "phone": "+70861871058"}
0005435160350	D6D00B	6728 605249	NIKOLAY TARASOV	{"phone": "+70610417067"}
0005435160351	B71944	4653 392004	ANGELINA NAZAROVA	{"phone": "+70779341695"}
0005435160352	56EF97	7252 899034	ANATOLIY ZAKHAROV	{"email": "zakharov-anatoliy.1971@postgrespro.ru", "phone": "+70940702131"}
0005435160353	56EF97	6928 823357	EVGENIY FEDOROV	{"phone": "+70307664233"}
0005435160354	2C7D1C	8438 014877	IVAN NAZAROV	{"email": "nazarovivan_1970@postgrespro.ru", "phone": "+70194011348"}
0005435160355	FAC8E1	5082 718461	ELENA ANDREEVA	{"phone": "+70800704333"}
0005435160356	432B19	1308 846512	OLGA ZAKHAROVA	{"phone": "+70904463853"}
0005435160357	920D46	7934 855149	NADEZHDA RYABOVA	{"email": "ryabova-nadezhda1960@postgrespro.ru", "phone": "+70613366935"}
0005435160358	6A12B3	6269 502434	OLEG NIKITIN	{"phone": "+70134585905"}
0005435160359	AEAE72	2963 859295	DMITRIY KONOVALOV	{"email": "konovalov-dmitriy-17041979@postgrespro.ru", "phone": "+70591788696"}
0005435160360	7E70DA	7089 929992	MAKSIM PAVLOV	{"phone": "+70381708285"}
0005435160361	60C47F	9828 963791	ALEKSANDR SERGEEV	{"email": "sergeeva051973@postgrespro.ru", "phone": "+70234132735"}
0005435160362	60C47F	3708 582988	VIKTORIYA KONDRATEVA	{"phone": "+70761286219"}
0005435160363	1097D2	5531 087037	NAILYA ALEKSEEVA	{"email": "alekseeva_n.1975@postgrespro.ru", "phone": "+70510059852"}
0005435160364	1097D2	0922 111347	PAVEL VOLKOV	{"phone": "+70524051883"}
0005435160365	46B5EA	5655 971000	IRINA KOMAROVA	{"phone": "+70886844671"}
0005435160366	DE8CE4	1992 081947	ANNA KOROLEVA	{"phone": "+70906836743"}
0005435160367	2446EB	8280 160642	SVETLANA GORBUNOVA	{"email": "svetlana-gorbunova26071966@postgrespro.ru", "phone": "+70062268422"}
0005435160368	2446EB	0140 226491	LIDIYA IVANOVA	{"phone": "+70088512594"}
0005435160369	F95A96	3580 042991	LYUDMILA LEBEDEVA	{"phone": "+70694986535"}
0005435160370	C53182	0666 503648	MARIYA ISAEVA	{"phone": "+70763587403"}
0005435160371	594A25	4280 466230	SVETLANA CHERNOVA	{"email": "chernova_svetlana021973@postgrespro.ru", "phone": "+70457846143"}
0005435160372	594A25	1005 960046	STANISLAV SOKOLOV	{"phone": "+70685163306"}
0005435160373	D163F5	2635 616422	ALEKSANDR SERGEEV	{"phone": "+70034153195"}
0005435160374	D163F5	5528 206812	ANTON GERASIMOV	{"email": "gerasimov-a.101969@postgrespro.ru", "phone": "+70675620857"}
0005435160375	CA5615	2515 024504	LYUBOV GAVRILOVA	{"phone": "+70451266320"}
0005435160376	083A7B	3954 662662	EVGENIY FILIPPOV	{"phone": "+70828681242"}
0005435160377	083A7B	3260 602689	PETR ALEKSEEV	{"email": "alekseev.petr-1968@postgrespro.ru", "phone": "+70054121642"}
0005435160378	01C2E9	9998 088721	MARIYA KUZMINA	{"email": "m_kuzmina_021979@postgrespro.ru", "phone": "+70302570497"}
0005435160379	01C2E9	8876 783081	PAVEL CHERNOV	{"phone": "+70453419552"}
0005435160380	DE4589	0074 208847	DMITRIY ANTONOV	{"phone": "+70497662718"}
0005435160381	DE4589	2760 655461	ZHANNA DENISOVA	{"email": "denisova.zhanna.01101961@postgrespro.ru", "phone": "+70077155018"}
0005435160382	8ED114	1000 200317	ALEKSANDR MARTYNOV	{"email": "martynova.19071961@postgrespro.ru", "phone": "+70395975297"}
0005435160383	8ED114	5607 935625	ANTONINA ZAKHAROVA	{"email": "a_zakharova_111988@postgrespro.ru", "phone": "+70653005560"}
0005435160384	791A62	9534 512407	DMITRIY NIKOLAEV	{"phone": "+70287049484"}
0005435160385	791A62	7889 381653	ANDREY SERGEEV	{"email": "sergeevandrey1970@postgrespro.ru", "phone": "+70536718999"}
0005435160386	66872A	4865 976557	IVAN ZHURAVLEV	{"phone": "+70280065983"}
0005435160387	F48728	2800 285755	EVGENIYA VOLKOVA	{"email": "volkova.e-1969@postgrespro.ru", "phone": "+70538438679"}
0005435160388	F48728	3405 637181	IRINA ANDREEVA	{"email": "iandreeva_28121977@postgrespro.ru", "phone": "+70054770937"}
0005435160389	D0EABA	2277 221798	OLGA VOROBEVA	{"phone": "+70943735197"}
0005435160390	485609	4251 831372	SVETLANA BORISOVA	{"email": "borisova_s.1975@postgrespro.ru", "phone": "+70681056146"}
0005435160391	ED9CB3	1414 513387	SOFIYA KUZNECOVA	{"phone": "+70345792405"}
0005435160392	0E4A5F	7440 928214	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov041966@postgrespro.ru", "phone": "+70443816735"}
0005435160393	18662F	0139 691804	IGOR DENISOV	{"phone": "+70556595534"}
0005435160394	18662F	3518 049077	GENNADIY IVANOV	{"email": "ivanov-g_1985@postgrespro.ru", "phone": "+70306623843"}
0005435160395	3BE451	1826 629878	TATYANA SEMENOVA	{"phone": "+70038439493"}
0005435160396	6C5A52	0891 615066	DMITRIY MAKAROV	{"email": "makarovdmitriy_01031971@postgrespro.ru", "phone": "+70980593481"}
0005435160397	0AEA80	0590 259134	VALENTINA DMITRIEVA	{"phone": "+70823805684"}
0005435160398	0CB1BC	0994 176045	KARINA POPOVA	{"phone": "+70366678671"}
0005435160399	9F0741	5312 667324	DMITRIY BONDARENKO	{"phone": "+70695707539"}
0005435160400	9F0741	2190 574615	SERGEY IVANOV	{"email": "ivanov.sergey-06021982@postgrespro.ru", "phone": "+70219063264"}
0005435160401	9F0741	5593 261289	NATALYA ANTONOVA	{"email": "antonova_natalya-111978@postgrespro.ru", "phone": "+70481503355"}
0005435160402	7C7EF2	3416 936822	PAVEL DENISOV	{"email": "p-denisov-03081970@postgrespro.ru", "phone": "+70714947683"}
0005435160403	4DFDB2	0602 159014	ELENA SEMENOVA	{"email": "e-semenova-27011973@postgrespro.ru", "phone": "+70374582934"}
0005435160404	3D13AF	8289 504167	VALENTINA KUZMINA	{"phone": "+70058146126"}
0005435160405	CDB698	6764 776380	NIKITA KOZLOV	{"email": "kozlovnikita-25091973@postgrespro.ru", "phone": "+70974274216"}
0005435160406	6D431B	9281 029113	MIKHAIL NOVIKOV	{"phone": "+70906924413"}
0005435160407	F8747C	9693 580092	NINA SOROKINA	{"email": "sorokina-nina_11041969@postgrespro.ru", "phone": "+70912395919"}
0005435160408	751469	4509 529573	GALINA EGOROVA	{"phone": "+70021090628"}
0005435160409	751469	5537 933437	TATYANA DMITRIEVA	{"phone": "+70685769868"}
0005435160410	730B3D	2854 323384	VALENTINA PAVLOVA	{"email": "v_pavlova.19071968@postgrespro.ru", "phone": "+70985984183"}
0005435160411	730B3D	0681 952675	LYUDMILA KOVALEVA	{"email": "kovaleva_l-091970@postgrespro.ru", "phone": "+70488080471"}
0005435160412	730B3D	3062 915080	ALEKSEY MOROZOV	{"email": "aleksey-morozov.081969@postgrespro.ru", "phone": "+70626958496"}
0005435160413	A2724B	8674 757687	DANILA SCHERBAKOV	{"phone": "+70685710810"}
0005435160414	A2724B	0740 450032	NATALYA AKIMOVA	{"phone": "+70680537651"}
0005435160415	CFC76B	7533 988378	TAISIYA IVANOVA	{"phone": "+70476650015"}
0005435160416	6B2169	6774 568037	VLADIMIR ZHUKOV	{"email": "zhukov_vladimir_011968@postgrespro.ru", "phone": "+70704324872"}
0005435160417	6B2169	4436 973912	VLADIMIR MIRONOV	{"email": "vladimir-mironov-1985@postgrespro.ru", "phone": "+70515439158"}
0005435160418	96D4C6	5528 243631	INNA POLYAKOVA	{"phone": "+70567851325"}
0005435160420	766E4A	0277 118109	TATYANA ZAKHAROVA	{"email": "t.zakharova_10081982@postgrespro.ru", "phone": "+70682590827"}
0005435160421	766E4A	1574 508784	ELENA NIKOLAEVA	{"phone": "+70832031751"}
0005435160422	5A8288	4505 413601	ALEKSANDR SCHERBAKOV	{"phone": "+70182975444"}
0005435160423	D8C69E	7901 008130	IGOR KISELEV	{"phone": "+70227195326"}
0005435160424	0ED0F1	6631 893789	KONSTANTIN MEDVEDEV	{"email": "k.medvedev_021971@postgrespro.ru", "phone": "+70703024006"}
0005435160425	0ED0F1	8665 720678	RUFIYA SIDOROVA	{"email": "r-sidorova-16111981@postgrespro.ru", "phone": "+70505272223"}
0005435160426	0ED0F1	6020 584471	SERGEY MAKSIMOV	{"phone": "+70925510880"}
0005435160427	0ED0F1	4272 678111	ANNA GRISHINA	{"email": "a-grishina-01101968@postgrespro.ru", "phone": "+70262863416"}
0005435160428	6B416B	5060 717662	OLGA STEPANOVA	{"phone": "+70416299785"}
0005435160429	775C6B	9429 643900	EKATERINA TIKHONOVA	{"email": "tikhonova.ekaterina.21021969@postgrespro.ru", "phone": "+70487652939"}
0005435160430	775C6B	7276 263331	ELENA KOMAROVA	{"phone": "+70714134795"}
0005435160431	B55843	5252 767066	MIKHAIL PETROV	{"email": "petrov-m-1983@postgrespro.ru", "phone": "+70733960279"}
0005435160432	E3FCFE	4642 470263	ANASTASIYA VASILEVA	{"phone": "+70386565805"}
0005435160433	EAE8D1	8447 420675	NIKITA NAZAROV	{"phone": "+70442493025"}
0005435160434	C66FDF	3999 873337	DARYA POPOVA	{"phone": "+70728478119"}
0005435160435	C66FDF	4386 374682	TATYANA VOLKOVA	{"phone": "+70913255513"}
0005435160436	27A555	1008 246043	OLGA TROFIMOVA	{"email": "olga.trofimova_051967@postgrespro.ru", "phone": "+70990075848"}
0005435160437	9D476E	1600 290750	EVGENIY MIRONOV	{"phone": "+70289120552"}
0005435160438	9D476E	5484 114354	ANDREY MOROZOV	{"phone": "+70118305138"}
0005435160439	5998F6	7375 753662	EKATERINA NIKIFOROVA	{"email": "ekaterinanikiforova26011971@postgrespro.ru", "phone": "+70168223837"}
0005435160440	136F7F	1870 203242	MARIYA NOVIKOVA	{"email": "novikova-m111971@postgrespro.ru", "phone": "+70504027301"}
0005435160441	0290A5	8326 543025	SERGEY ALEKSANDROV	{"email": "aleksandrov_sergey1969@postgrespro.ru", "phone": "+70616214429"}
0005435160442	DE6DE0	7140 098372	VADIM IVANOV	{"email": "ivanovvadim081974@postgrespro.ru", "phone": "+70461487026"}
0005435160443	DE6DE0	9767 122173	EKATERINA KUZNECOVA	{"email": "kuznecova_e_021976@postgrespro.ru", "phone": "+70163186218"}
0005435160444	730CDA	6891 139233	OLGA STEPANOVA	{"email": "stepanova-o_08081982@postgrespro.ru", "phone": "+70198530216"}
0005435160445	CB2FC3	7315 218566	MARIYA KAZAKOVA	{"email": "kazakova-m.111977@postgrespro.ru", "phone": "+70247505293"}
0005435160446	B71C35	3784 751503	TAMARA NAZAROVA	{"phone": "+70064708953"}
0005435160447	B71C35	1312 276673	SERGEY GERASIMOV	{"email": "gerasimov_sergey_14091968@postgrespro.ru", "phone": "+70984388171"}
0005435160448	DCD111	2596 024204	RAISA SOROKINA	{"phone": "+70623742298"}
0005435160449	DCD111	0973 305185	ZINAIDA ZAKHAROVA	{"phone": "+70723004642"}
0005435160450	DCD111	0895 425701	MIKHAIL SERGEEV	{"phone": "+70649775674"}
0005435160451	3A5720	6497 753615	ANVAR GUSEV	{"email": "anvar_gusev_15081978@postgrespro.ru", "phone": "+70496434390"}
0005435160452	D0549F	7465 801407	SVETLANA ILINA	{"phone": "+70189917768"}
0005435160453	8BDEF3	9512 554109	ANASTASIYA VASILEVA	{"phone": "+70652337370"}
0005435160454	901934	3404 313296	SERGEY EGOROV	{"email": "sergey_egorov.23061972@postgrespro.ru", "phone": "+70551747773"}
0005435160455	E7FA95	4781 415004	ALEKSANDR TIMOFEEV	{"phone": "+70012554849"}
0005435160456	E24AC2	6731 035711	VYACHESLAV FEDOROV	{"phone": "+70145302090"}
0005435160457	E24AC2	8137 913110	SERGEY POPOV	{"phone": "+70178580820"}
0005435160458	A2590B	2979 640265	TATYANA LOGINOVA	{"email": "t-loginova.031971@postgrespro.ru", "phone": "+70160083942"}
0005435160459	646044	6316 814455	VLADIMIR SOLOVEV	{"email": "solovevvladimir19031966@postgrespro.ru", "phone": "+70232674661"}
0005435160460	A576A8	7669 346282	TATYANA ANDREEVA	{"phone": "+70041389035"}
0005435160461	6EB48F	1648 893683	ALEKSEY KOROLEV	{"phone": "+70068042432"}
0005435160462	BC771A	9293 887863	SERGEY KUZNECOV	{"email": "kuznecov_s.041975@postgrespro.ru", "phone": "+70943730137"}
0005435160463	BC771A	5381 398991	ANVAR GRIGOREV	{"email": "a-grigorev-24011976@postgrespro.ru", "phone": "+70622047081"}
0005435160464	9826D4	2746 357205	ALENA PETROVA	{"phone": "+70421020206"}
0005435160465	9826D4	7516 141068	NADEZHDA MOROZOVA	{"email": "n_morozova.011979@postgrespro.ru", "phone": "+70902797735"}
0005435160466	87CC27	0475 087080	IGOR FEDOROV	{"phone": "+70982175538"}
0005435160467	281C57	2308 720452	MARIYA SEMENOVA	{"email": "semenova-mariya-07091992@postgrespro.ru", "phone": "+70986174168"}
0005435176594	B993CE	2747 460398	SVETLANA MALYSHEVA	{"phone": "+70370458933"}
0005435160468	7658BE	6294 643936	VALENTINA ANTONOVA	{"email": "antonova_valentina.031966@postgrespro.ru", "phone": "+70819760552"}
0005435160469	CE91D0	9116 823236	VIKTOR MAKSIMOV	{"phone": "+70594781264"}
0005435160470	238DA2	4755 373484	DANIIL NIKOLAEV	{"email": "nikolaevdaniil-10041969@postgrespro.ru", "phone": "+70094544665"}
0005435160471	2CFDC1	4571 143300	KSENIYA KUZNECOVA	{"phone": "+70849693591"}
0005435160472	A4C44B	6008 470538	ALINA MIRONOVA	{"phone": "+70718045816"}
0005435160473	57B8EC	8481 370621	YURIY DMITRIEV	{"email": "y-dmitriev12101975@postgrespro.ru", "phone": "+70512958033"}
0005435160474	07276A	2971 059266	YURIY KOROLEV	{"email": "yuriy_korolev1972@postgrespro.ru", "phone": "+70568483545"}
0005435160475	423BA2	0431 199023	ALEKSANDR NIKOLAEV	{"phone": "+70354219956"}
0005435160476	521396	0064 188336	VALENTINA VOLKOVA	{"email": "valentina_volkova_101970@postgrespro.ru", "phone": "+70676332606"}
0005435160477	6E39C2	4932 857960	SERGEY SHEVCHENKO	{"email": "sshevchenko.091978@postgrespro.ru", "phone": "+70436042428"}
0005435160478	19BA4A	6544 581318	SERGEY CHERNOV	{"email": "s-chernov.09041963@postgrespro.ru", "phone": "+70829080163"}
0005435160479	19BA4A	7430 372634	RAISA MAKAROVA	{"email": "makarovaraisa_1961@postgrespro.ru", "phone": "+70726918394"}
0005435160480	506F6D	4029 569650	TIMOFEY ZAKHAROV	{"email": "zakharovt041975@postgrespro.ru", "phone": "+70717015517"}
0005435160481	ACF6E3	6114 927342	ELENA POPOVA	{"phone": "+70186232031"}
0005435160482	FF6ADA	6891 491609	SERGEY STEPANOV	{"email": "stepanov_sergey28011961@postgrespro.ru", "phone": "+70666208376"}
0005435160483	A98C3E	4012 997528	SVETLANA ANTONOVA	{"phone": "+70079914908"}
0005435160484	A98C3E	6475 326353	IVAN ZAKHAROV	{"phone": "+70680999382"}
0005435160485	B25ACF	6198 848002	MARIYA TIKHONOVA	{"phone": "+70155128954"}
0005435160486	8772CF	2802 214441	OLGA MEDVEDEVA	{"phone": "+70032507120"}
0005435160487	3A14AF	8416 778234	EKATERINA MOROZOVA	{"phone": "+70131781750"}
0005435160488	3A14AF	1653 546078	SERGEY STEPANOV	{"email": "stepanovs-30101978@postgrespro.ru", "phone": "+70920291188"}
0005435160489	5F77B2	2060 721370	LYUDMILA ERMAKOVA	{"phone": "+70876937177"}
0005435160490	DE7D74	2350 336298	VITALIY GERASIMOV	{"email": "gerasimov-vitaliy-011974@postgrespro.ru", "phone": "+70171569172"}
0005435160491	DE7D74	7375 988328	MARINA BARANOVA	{"email": "baranova_m-29091967@postgrespro.ru", "phone": "+70855970785"}
0005435160492	E86312	0696 363328	SERGEY POPOV	{"phone": "+70120153143"}
0005435160493	5E6BC2	2283 661913	LYUBOV STEPANOVA	{"email": "stepanova_lyubov071968@postgrespro.ru", "phone": "+70637049340"}
0005435160494	90E954	5883 880364	IRINA PETROVA	{"phone": "+70959711723"}
0005435160495	14C656	8474 390575	ANDREY DAVYDOV	{"phone": "+70183434538"}
0005435160496	5CBCAA	1967 082202	VALENTINA NIKITINA	{"email": "valentina_nikitina.1964@postgrespro.ru", "phone": "+70451771908"}
0005435160497	3ECE1E	9129 136685	NATALYA PETROVA	{"phone": "+70302770873"}
0005435160498	A0C099	7323 319021	ALINA KUZMINA	{"email": "akuzmina101959@postgrespro.ru", "phone": "+70906494285"}
0005435160499	A0C099	4006 735281	ILYA DAVYDOV	{"phone": "+70243874193"}
0005435160500	4E4868	4969 479681	ANTONINA NESTEROVA	{"phone": "+70285027192"}
0005435160501	4E4868	4711 251312	TATYANA BORISOVA	{"phone": "+70673557783"}
0005435160502	096316	0290 920484	IRINA ORLOVA	{"phone": "+70750575851"}
0005435160503	486478	1289 718140	ARTEM STEPANOV	{"phone": "+70087449558"}
0005435160504	00297D	9332 215672	GENNADIY SMIRNOV	{"email": "gennadiy.smirnov.1971@postgrespro.ru", "phone": "+70246839367"}
0005435160505	0E66E9	6967 160631	LYUDMILA ILINA	{"phone": "+70511532599"}
0005435160506	ED2248	0137 639059	ANATOLIY EGOROV	{"email": "egorov_a.16091973@postgrespro.ru", "phone": "+70952838954"}
0005435160507	ED2248	4888 528502	YULIYA POTAPOVA	{"email": "potapova.y-1970@postgrespro.ru", "phone": "+70376049744"}
0005435160508	B48877	1181 283604	VERA DAVYDOVA	{"phone": "+70753048255"}
0005435160509	F783C2	0668 420703	NIKOLAY ROMANOV	{"email": "romanov_n-13091971@postgrespro.ru", "phone": "+70892708150"}
0005435160510	70E1ED	9378 746972	OLGA NESTEROVA	{"email": "nesterova-olga_1970@postgrespro.ru", "phone": "+70443483140"}
0005435160511	801B42	4588 569465	LEV FOMIN	{"email": "l.fomin-20011970@postgrespro.ru", "phone": "+70509290085"}
0005435160512	0D987A	2522 049905	DMITRIY POPOV	{"phone": "+70110644943"}
0005435160513	011854	0444 942336	SERGEY ZAYCEV	{"phone": "+70013982842"}
0005435160514	C6F846	5883 524064	SVETLANA KOMAROVA	{"email": "komarova_s.1967@postgrespro.ru", "phone": "+70715988617"}
0005435160515	AF39B8	1619 054601	YURIY PETROV	{"phone": "+70491958539"}
0005435160516	A6EDCE	4596 268888	VALENTINA TITOVA	{"email": "titova_valentina_1986@postgrespro.ru", "phone": "+70909611668"}
0005435160517	A6EDCE	4328 801932	SERGEY MIKHAYLOV	{"phone": "+70110834206"}
0005435160518	91FFD1	4224 297543	YURIY TIKHONOV	{"phone": "+70821696999"}
0005435160519	91FFD1	4539 763393	ALEKSANDR MELNIKOV	{"phone": "+70513708790"}
0005435160520	832D4C	2429 321613	NINA GRISHINA	{"email": "n.grishina.01091968@postgrespro.ru", "phone": "+70885825459"}
0005435160521	832D4C	8876 058193	NINA ROMANOVA	{"email": "romanova.n101979@postgrespro.ru", "phone": "+70198898751"}
0005435160522	D4514B	7430 883352	NAIL ORLOV	{"email": "nail-orlov-16011970@postgrespro.ru", "phone": "+70208405814"}
0005435160523	059C7A	0008 200386	LYUBOV KRASNOVA	{"email": "krasnova_l_1974@postgrespro.ru", "phone": "+70047202162"}
0005435160524	059C7A	6409 296060	LYUBOV SEMENOVA	{"phone": "+70555649470"}
0005435160525	47DF6D	7159 984298	OLGA SAVELEVA	{"phone": "+70723034215"}
0005435160526	A6D712	0187 224523	POLINA KARPOVA	{"email": "karpova.polina.1968@postgrespro.ru", "phone": "+70914819679"}
0005435160527	1A64A8	1713 504088	NIKOLAY KUDRYASHOV	{"phone": "+70146970563"}
0005435160528	1A64A8	2436 879953	VITALIY KISELEV	{"email": "vitaliy.kiselev-1985@postgrespro.ru", "phone": "+70493772546"}
0005435160529	03F79E	0456 612703	NIKOLAY FILIPPOV	{"email": "filippov-nikolay_1970@postgrespro.ru", "phone": "+70916868421"}
0005435160530	03F79E	3413 951442	ANASTASIYA KUZNECOVA	{"phone": "+70708915642"}
0005435160531	03F79E	0999 381739	SERGEY POPOV	{"phone": "+70593305324"}
0005435160532	B49BB6	7516 927162	RADIK ZAYCEV	{"email": "zaycev.radik1986@postgrespro.ru", "phone": "+70660714851"}
0005435160533	9C5F3F	5293 412791	SVETLANA SERGEEVA	{"email": "s_sergeeva-24041972@postgrespro.ru", "phone": "+70502669393"}
0005435160534	BA8F49	0496 293393	ALEKSANDR ZHURAVLEV	{"phone": "+70657229218"}
0005435160535	BA8F49	9512 104325	ANDREY GAVRILOV	{"email": "andrey-gavrilov.121967@postgrespro.ru", "phone": "+70446718977"}
0005435160536	4CB871	3131 492457	KARINA PAVLOVA	{"phone": "+70904887815"}
0005435160537	4CB871	7692 048118	EKATERINA MAKSIMOVA	{"email": "e_maksimova-1972@postgrespro.ru", "phone": "+70399533809"}
0005435160538	02C784	5870 083747	TATYANA ZHUKOVA	{"email": "t-zhukova.111964@postgrespro.ru", "phone": "+70720743306"}
0005435160539	02C784	6332 843244	DENIS SMIRNOV	{"email": "smirnovdenis1975@postgrespro.ru", "phone": "+70076476265"}
0005435160540	3A7DB6	8430 889071	VASILISA ANDREEVA	{"email": "andreeva_vasilisa-1968@postgrespro.ru", "phone": "+70307530373"}
0005435160541	862784	8633 255034	ALEKSANDR MARTYNOV	{"email": "martynov.a1977@postgrespro.ru", "phone": "+70556014181"}
0005435160542	803ADB	7937 853632	VALENTINA PETROVA	{"email": "petrovavalentina1972@postgrespro.ru", "phone": "+70015867109"}
0005435160543	F5624D	0803 825522	ALEKSEY CHERNOV	{"email": "aleksey.chernov.19021972@postgrespro.ru", "phone": "+70962619164"}
0005435160544	D40092	3505 426085	YURIY SEMENOV	{"email": "semenovyuriy.1969@postgrespro.ru", "phone": "+70634824705"}
0005435160545	D40092	7965 847013	TATYANA BELOVA	{"email": "tatyanabelova-1979@postgrespro.ru", "phone": "+70769188799"}
0005435160546	D40092	4269 889542	PETR KUZNECOV	{"email": "kuznecovp_24111966@postgrespro.ru", "phone": "+70537844092"}
0005435160547	EAD94A	6718 998866	SERGEY NIKOLAEV	{"phone": "+70205968131"}
0005435160548	EAD94A	0682 683611	SVETLANA SOROKINA	{"phone": "+70901402428"}
0005435160549	7E5C85	5947 780709	ELENA RYABOVA	{"phone": "+70987424790"}
0005435160550	050982	6219 923714	KAMIL GERASIMOV	{"email": "gerasimov_kamil.041979@postgrespro.ru", "phone": "+70614654897"}
0005435160551	050982	1342 236488	MIKHAIL VASILEV	{"phone": "+70035457646"}
0005435160552	A2D234	5353 217689	NATALYA TROFIMOVA	{"email": "trofimovanatalya-23021966@postgrespro.ru", "phone": "+70602062896"}
0005435160553	3F8E32	9488 441348	OLGA NESTEROVA	{"email": "o_nesterova-1971@postgrespro.ru", "phone": "+70840507472"}
0005435160554	3F8E32	1045 469411	NIKOLAY POPOV	{"phone": "+70932829291"}
0005435160555	908E35	2738 348280	VASILISA CHERNOVA	{"phone": "+70083383008"}
0005435160556	D420C4	1119 743276	ANASTASIYA FEDOROVA	{"phone": "+70711969844"}
0005435160557	E51BF6	1866 246611	VALENTINA PETROVA	{"email": "valentina_petrova121965@postgrespro.ru", "phone": "+70146901871"}
0005435160558	E51BF6	6430 350168	GENNADIY NAZAROV	{"phone": "+70126693737"}
0005435160559	E4B89E	0325 638450	YULIYA SEMENOVA	{"phone": "+70392155721"}
0005435160560	07B737	8269 211232	OLGA NIKOLAEVA	{"phone": "+70601914186"}
0005435160561	60E025	2968 689388	TAISA TITOVA	{"phone": "+70620915486"}
0005435160562	292EFE	4647 172642	ALEKSANDR ZAYCEV	{"phone": "+70398760906"}
0005435160563	292EFE	0172 685445	ANASTASIYA SEMENOVA	{"phone": "+70552246691"}
0005435160564	F24BA8	1496 838513	MIKHAIL SCHERBAKOV	{"email": "scherbakov-mikhail1982@postgrespro.ru", "phone": "+70540737427"}
0005435160565	6B0444	0269 205226	DARYA EGOROVA	{"email": "d-egorova_061968@postgrespro.ru", "phone": "+70848401201"}
0005435160566	2C76D4	5434 686355	KRISTINA DMITRIEVA	{"phone": "+70536797749"}
0005435160567	2C76D4	1119 785303	LYUDMILA FILIPPOVA	{"email": "filippoval_101972@postgrespro.ru", "phone": "+70473533655"}
0005435160568	A86B3C	6710 512482	KONSTANTIN STEPANOV	{"email": "konstantinstepanov13111967@postgrespro.ru", "phone": "+70037597202"}
0005435160569	8751D5	4043 515662	ANATOLIY FEDOROV	{"email": "a_fedorov.051971@postgrespro.ru", "phone": "+70904999814"}
0005435160570	8751D5	0105 449309	SERGEY SOKOLOV	{"phone": "+70555240338"}
0005435160571	8751D5	2644 896249	NATALYA FILATOVA	{"phone": "+70337258912"}
0005435160572	433A89	1949 928780	ULYANA AFANASEVA	{"email": "ulyana-afanaseva.031980@postgrespro.ru", "phone": "+70284579087"}
0005435160573	433A89	0228 871081	ALEKSEY GRIGOREV	{"phone": "+70740525670"}
0005435160574	5515B1	3067 416412	OLGA TITOVA	{"email": "o_titova_07031975@postgrespro.ru", "phone": "+70094766078"}
0005435160575	50F154	8091 342278	ZINAIDA MIKHAYLOVA	{"phone": "+70622026395"}
0005435160576	50F154	4228 150815	NIKOLAY BONDARENKO	{"email": "n-bondarenko-091972@postgrespro.ru", "phone": "+70731475289"}
0005435160577	124E7C	8122 791488	YURIY KUDRYASHOV	{"email": "kudryashovy081973@postgrespro.ru", "phone": "+70446803248"}
0005435160578	D3FA1A	5351 479547	EVGENIY TARASOV	{"email": "e-tarasov1969@postgrespro.ru", "phone": "+70052704891"}
0005435160579	819DEA	3486 587173	ANDREY SMIRNOV	{"phone": "+70770284317"}
0005435160580	819DEA	9128 449015	LYUDMILA KONOVALOVA	{"email": "konovalova.l_1972@postgrespro.ru", "phone": "+70064860875"}
0005435160581	10432B	2067 932175	TATYANA NOVIKOVA	{"phone": "+70267364683"}
0005435160582	10432B	6962 879307	ZHANNA LEBEDEVA	{"email": "z-lebedeva-27051970@postgrespro.ru", "phone": "+70537569992"}
0005435160583	B9CA03	6502 643652	LYUBOV VOLKOVA	{"email": "volkovalyubov.011976@postgrespro.ru", "phone": "+70579083708"}
0005435160584	B9CA03	5317 032659	ANTONINA VOLKOVA	{"phone": "+70337541305"}
0005435160585	6FFC89	2605 337668	DMITRIY ORLOV	{"email": "orlovdmitriy-081972@postgrespro.ru", "phone": "+70969541089"}
0005435160586	6FFC89	0390 941309	VERA NIKOLAEVA	{"email": "vera-nikolaeva02031976@postgrespro.ru", "phone": "+70164194456"}
0005435160587	F77611	3022 192026	ALEKSANDR IVANOV	{"phone": "+70882462064"}
0005435160588	691980	1961 374196	VLADIMIR SOKOLOV	{"email": "sokolov-vladimir_18111971@postgrespro.ru", "phone": "+70922211363"}
0005435160589	23EC24	2755 192576	YURIY GUSEV	{"phone": "+70263780293"}
0005435160590	23EC24	6770 855447	EVGENIY ABRAMOV	{"email": "evgeniy.abramov-03031972@postgrespro.ru", "phone": "+70897525436"}
0005435160591	23EC24	2894 134870	ILYA DENISOV	{"phone": "+70178905664"}
0005435160592	C74C07	6667 725977	SERGEY MIKHAYLOV	{"email": "mikhaylov-s121972@postgrespro.ru", "phone": "+70110799055"}
0005435160593	F2DE17	5441 109377	GALINA GRISHINA	{"phone": "+70418804810"}
0005435160594	F2DE17	2092 758979	SERGEY ORLOV	{"email": "s-orlov-1973@postgrespro.ru", "phone": "+70674112445"}
0005435160595	E7EFFB	2261 100325	ALEKSEY MEDVEDEV	{"phone": "+70117990659"}
0005435160596	47D6C5	8227 770725	MARINA NOVIKOVA	{"phone": "+70836526188"}
0005435160597	47D6C5	4460 313471	NADEZHDA VASILEVA	{"phone": "+70627048706"}
0005435160598	8AAA5E	7129 806859	IRINA BARANOVA	{"email": "baranova_i.1970@postgrespro.ru", "phone": "+70270364861"}
0005435160599	8AAA5E	0557 787654	LYUBOV NOVIKOVA	{"phone": "+70917073414"}
0005435160600	D00F23	4557 957861	DMITRIY EGOROV	{"email": "egorov_d.09011975@postgrespro.ru", "phone": "+70756974008"}
0005435160601	2807B8	5163 572450	YURIY KUZMIN	{"phone": "+70125189387"}
0005435160602	2807B8	5696 300655	ELENA KUZNECOVA	{"email": "elena.kuznecova1965@postgrespro.ru", "phone": "+70505635982"}
0005435160603	623D6F	7070 564949	NIKOLAY GRIGOREV	{"phone": "+70871749985"}
0005435160604	623D6F	4115 627051	DANIIL AFANASEV	{"phone": "+70356944498"}
0005435160605	2F801F	1901 776373	TATYANA KRASNOVA	{"email": "tatyana-krasnova_051959@postgrespro.ru", "phone": "+70492018209"}
0005435160606	EED446	9564 734438	ANATOLIY MAKAROV	{"phone": "+70866168895"}
0005435160607	76F162	8492 208414	MARIYA KUZMINA	{"email": "kuzmina-m_1975@postgrespro.ru", "phone": "+70039517438"}
0005435160608	E4963B	6762 484452	ANTON SCHERBAKOV	{"email": "scherbakov.a_15021981@postgrespro.ru", "phone": "+70520326202"}
0005435160609	E4963B	7635 172686	ANASTASIYA MASLOVA	{"email": "anastasiya_maslova-1967@postgrespro.ru", "phone": "+70087045364"}
0005435160610	02D314	2557 089982	INNA DANILOVA	{"email": "inna-danilova.1971@postgrespro.ru", "phone": "+70416131832"}
0005435160611	7591CF	4579 754823	GENNADIY GORBUNOV	{"email": "g-gorbunov_03101968@postgrespro.ru", "phone": "+70579773180"}
0005435160612	D0ECEB	7029 073160	TATYANA ALEKSEEVA	{"email": "alekseevatatyana_1967@postgrespro.ru", "phone": "+70972118751"}
0005435160613	F40F23	8473 777416	NADEZHDA VASILEVA	{"email": "n-vasileva05121975@postgrespro.ru", "phone": "+70310139488"}
0005435160614	2C80E5	3016 884531	MARIYA KARPOVA	{"email": "karpova_m_25071971@postgrespro.ru", "phone": "+70642963731"}
0005435160615	C414D2	0965 782210	VIKTOR KULIKOV	{"phone": "+70013625080"}
0005435160616	C057D2	5392 101920	NATALYA VLASOVA	{"email": "natalya_vlasova.29121967@postgrespro.ru", "phone": "+70667947073"}
0005435160617	123CD6	1660 196381	ANTON ISAEV	{"phone": "+70198076973"}
0005435160618	123CD6	3877 300765	ANDREY IVANOV	{"email": "ivanov.andrey_1966@postgrespro.ru", "phone": "+70116145842"}
0005435160619	34EE33	2513 089111	VYACHESLAV MOISEEV	{"phone": "+70454697021"}
0005435160620	34EE33	6922 448189	MARIYA DAVYDOVA	{"email": "davydovamariya_1979@postgrespro.ru", "phone": "+70760689887"}
0005435160621	EBEB18	9399 717322	ALEKSANDR IVANOV	{"phone": "+70895291741"}
0005435160622	449701	2431 029573	ELENA SERGEEVA	{"email": "e-sergeeva.081966@postgrespro.ru", "phone": "+70543671109"}
0005435160623	236412	8395 182994	AMINA POPOVA	{"phone": "+70228449727"}
0005435163211	9E6E42	5481 959526	RAISA IVANOVA	{"phone": "+70420023319"}
0005435163139	E29598	2657 710162	LARISA SERGEEVA	{"phone": "+70988643336"}
0005435163140	DDF192	1436 402298	OLGA KISELEVA	{"email": "kiseleva.o051961@postgrespro.ru", "phone": "+70512619403"}
0005435163141	DDF192	2798 251787	VALERIY MOISEEV	{"phone": "+70195936090"}
0005435163142	FCD274	7018 542580	NIKITA MAKAROV	{"phone": "+70174841231"}
0005435163143	FCD274	6045 101823	LEYLA NIKITINA	{"email": "nikitina_leyla.111983@postgrespro.ru", "phone": "+70250406517"}
0005435163144	FCD274	1279 269363	VYACHESLAV YAKOVLEV	{"email": "yakovlev.vyacheslav.1972@postgrespro.ru", "phone": "+70727873387"}
0005435163145	A71408	5849 732984	LARISA SOKOLOVA	{"phone": "+70581621092"}
0005435163146	A71408	0731 833279	ANDREY SIDOROV	{"email": "sidorova_15081975@postgrespro.ru", "phone": "+70276569650"}
0005435163147	1E7705	0397 500373	ALEKSEY SOLOVEV	{"phone": "+70019013339"}
0005435163148	CE33F8	9791 252682	LARISA NIKOLAEVA	{"email": "l-nikolaeva_121975@postgrespro.ru", "phone": "+70583883168"}
0005435163149	CE33F8	4164 539628	IGOR MOROZOV	{"email": "igor.morozov_111986@postgrespro.ru", "phone": "+70758469975"}
0005435163150	12B0DD	7553 940208	ELENA KISELEVA	{"email": "kiseleva.elena_1978@postgrespro.ru", "phone": "+70964724198"}
0005435163151	12B0DD	0509 194156	LYUDMILA BARANOVA	{"email": "baranova.lyudmila-021979@postgrespro.ru", "phone": "+70773017408"}
0005435163152	7CCBB5	0169 414225	MARIYA DENISOVA	{"phone": "+70655588150"}
0005435163153	8184A1	3260 026935	ALEKSANDR DENISOV	{"email": "adenisov-041963@postgrespro.ru", "phone": "+70946209991"}
0005435163154	5312ED	9108 095079	ALEKSEY GAVRILOV	{"email": "aleksey.gavrilov1982@postgrespro.ru", "phone": "+70801646160"}
0005435163155	71F3C7	8344 055519	VALENTINA LEBEDEVA	{"email": "vlebedeva-1987@postgrespro.ru", "phone": "+70727044807"}
0005435163156	634CD6	0848 420210	MARIYA IVANOVA	{"phone": "+70655195221"}
0005435163157	3192D0	0265 023773	NIKOLAY MAKSIMOV	{"email": "maksimov-n.01051973@postgrespro.ru", "phone": "+70318752490"}
0005435163158	3192D0	7975 002190	ALEKSANDR FOMIN	{"phone": "+70014618092"}
0005435163159	C6DCF2	9327 842959	PAVEL KUZNECOV	{"phone": "+70287393691"}
0005435163160	C6DCF2	9412 698441	DARYA NESTEROVA	{"phone": "+70983385581"}
0005435163161	1804F7	0858 254394	POLINA GRISHINA	{"phone": "+70974359284"}
0005435163162	E08CD6	8433 386845	OLGA TARASOVA	{"email": "tarasova_o-081972@postgrespro.ru", "phone": "+70448389793"}
0005435163163	277295	6896 981568	ANDREY ALEKSEEV	{"phone": "+70820196964"}
0005435163164	710CA2	0498 569159	OLEG NIKITIN	{"phone": "+70738390388"}
0005435163165	FFDE20	7999 940724	STEPAN ZAYCEV	{"email": "stepan.zaycev-1969@postgrespro.ru", "phone": "+70227335841"}
0005435163166	E05E8E	9906 479851	LYUBOV MIKHAYLOVA	{"phone": "+70604384361"}
0005435163167	6555BC	8857 826051	NIKOLAY KOZLOV	{"phone": "+70290813257"}
0005435163168	2C78B8	4749 656531	GENNADIY IVANOV	{"email": "gennadiy_ivanov_1975@postgrespro.ru", "phone": "+70355992740"}
0005435163169	2C78B8	2802 024393	EKATERINA FEDOROVA	{"email": "ekaterina-fedorova-1964@postgrespro.ru", "phone": "+70241170885"}
0005435163170	2C78B8	3791 140748	VASILIY VOLKOV	{"email": "v_volkov081965@postgrespro.ru", "phone": "+70137485615"}
0005435163171	D6D6D1	9702 551599	ALEKSANDR VASILEV	{"email": "a.vasilev_17041963@postgrespro.ru", "phone": "+70271881414"}
0005435163172	D6D6D1	8032 678015	SERGEY KONOVALOV	{"email": "sergey_konovalov.1979@postgrespro.ru", "phone": "+70322043253"}
0005435163173	59EF61	7700 052104	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr_101971@postgrespro.ru", "phone": "+70923721694"}
0005435163174	C87E10	0014 375354	OLGA AFANASEVA	{"email": "afanaseva_olga-1967@postgrespro.ru", "phone": "+70556594235"}
0005435163175	C87E10	8143 916789	DENIS SEMENOV	{"email": "dsemenov_1965@postgrespro.ru", "phone": "+70920236431"}
0005435163176	54F126	9060 206224	ALEKSANDR GAVRILOV	{"phone": "+70205451235"}
0005435163177	54F126	7054 504529	AYRAT NAZAROV	{"phone": "+70745798383"}
0005435163178	5231F2	4238 117408	TATYANA FEDOROVA	{"email": "fedorova.tatyana-12091975@postgrespro.ru", "phone": "+70231043478"}
0005435163179	B3440F	9855 112629	RAISA POPOVA	{"email": "popova-raisa1983@postgrespro.ru", "phone": "+70206598491"}
0005435163180	294425	9113 733411	ILYA PAVLOV	{"email": "pavlov_ilya_101975@postgrespro.ru", "phone": "+70304280321"}
0005435163181	294425	5173 491321	PETR MAKAROV	{"email": "petr.makarov_1970@postgrespro.ru", "phone": "+70503605539"}
0005435163182	8F4010	8627 662198	VALERIY DENISOV	{"phone": "+70756754499"}
0005435163183	41C348	3606 140211	ALEKSANDR MOROZOV	{"email": "morozov-aleksandr.1974@postgrespro.ru", "phone": "+70567000037"}
0005435163184	A5E5F9	7480 946083	GRIGORIY KARPOV	{"phone": "+70088326258"}
0005435163185	B0E931	0066 870914	RUSLAN KRASNOV	{"phone": "+70516783553"}
0005435163186	49D80C	7635 667848	DIANA EGOROVA	{"email": "egorovad_121974@postgrespro.ru", "phone": "+70607730274"}
0005435163187	745306	2038 025201	IGOR VASILEV	{"email": "i-vasilev.1989@postgrespro.ru", "phone": "+70214766115"}
0005435163188	CACB30	2359 083616	LYUDMILA DMITRIEVA	{"phone": "+70321532481"}
0005435163189	77876C	4185 828264	ANNA ANISIMOVA	{"phone": "+70972343096"}
0005435163190	06ACDE	0595 416203	EKATERINA DENISOVA	{"email": "e.denisova_101979@postgrespro.ru", "phone": "+70007535365"}
0005435163191	06ACDE	6949 645732	LYUBOV KOLESNIKOVA	{"email": "lyubov-kolesnikova.10011972@postgrespro.ru", "phone": "+70579930970"}
0005435163192	D18B1C	3461 086874	IRINA SOROKINA	{"email": "sorokina.irina_101971@postgrespro.ru", "phone": "+70026751058"}
0005435163193	D18B1C	7663 990506	VALENTINA POLYAKOVA	{"email": "vpolyakova_101962@postgrespro.ru", "phone": "+70484333569"}
0005435163194	FD448E	4424 354674	KONSTANTIN KAZAKOV	{"phone": "+70264855820"}
0005435163195	FD448E	7099 263087	VALERIY IVANOV	{"phone": "+70148645892"}
0005435163196	07E7BA	2636 993421	YULIYA KAZAKOVA	{"email": "ykazakova021960@postgrespro.ru", "phone": "+70078099577"}
0005435163197	EBC716	7609 149738	IRINA KOROLEVA	{"phone": "+70559048410"}
0005435163198	F26A33	5847 829973	NADEZHDA SIDOROVA	{"phone": "+70495858157"}
0005435163199	F26A33	8081 320540	EGOR MAKAROV	{"email": "makarov.egor_1974@postgrespro.ru", "phone": "+70476194449"}
0005435163200	0B2B71	9052 036227	ANGELINA OVCHINNIKOVA	{"email": "aovchinnikova07081975@postgrespro.ru", "phone": "+70076596311"}
0005435163201	951620	0157 401854	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy_01021970@postgrespro.ru", "phone": "+70148001148"}
0005435163202	7281BA	5748 565974	GENNADIY POPOV	{"phone": "+70663029785"}
0005435163203	7281BA	2461 612327	ELIZAVETA MALYSHEVA	{"email": "malysheva.e_101974@postgrespro.ru", "phone": "+70069664395"}
0005435163204	7281BA	0119 309931	ANATOLIY ISAEV	{"email": "isaev_a051970@postgrespro.ru", "phone": "+70721329983"}
0005435163205	0ED14F	8805 225479	KONSTANTIN POPOV	{"email": "popov_k_061980@postgrespro.ru", "phone": "+70972072071"}
0005435163206	C86232	0812 758808	MIKHAIL KUZNECOV	{"email": "mikhail.kuznecov.071970@postgrespro.ru", "phone": "+70741861117"}
0005435163207	646D84	4417 724290	ALEKSANDR GRIGOREV	{"phone": "+70848909038"}
0005435163208	646D84	5349 383296	OLGA IVANOVA	{"phone": "+70805783594"}
0005435163209	EBF8D0	5749 188765	LYUDMILA MAKAROVA	{"phone": "+70720018626"}
0005435163210	EBF8D0	9944 869031	SVETLANA ANISIMOVA	{"phone": "+70425362559"}
0005435163212	BF6A0D	0091 979762	SERGEY NAUMOV	{"email": "naumov-sergey.16111973@postgrespro.ru", "phone": "+70405362344"}
0005435163213	BF6A0D	7268 665947	RISHAT MIKHAYLOV	{"phone": "+70231259564"}
0005435163214	E3AE21	4928 224067	OKSANA YUDINA	{"email": "yudina_o1986@postgrespro.ru", "phone": "+70708328724"}
0005435163215	897FD2	6443 758312	OLGA POPOVA	{"email": "popova_o-02071975@postgrespro.ru", "phone": "+70788459133"}
0005435163216	897FD2	7420 289742	DMITRIY POPOV	{"email": "d-popov1979@postgrespro.ru", "phone": "+70793381611"}
0005435163217	2625E7	1517 477103	PETR KRASNOV	{"email": "petr-krasnov-29041979@postgrespro.ru", "phone": "+70839378345"}
0005435163218	2625E7	1765 837288	DENIS PETROV	{"phone": "+70270013797"}
0005435163219	C2CADE	9791 749120	VASILIY ZAKHAROV	{"email": "zakharov-vasiliy15011978@postgrespro.ru", "phone": "+70441814115"}
0005435163220	D46862	5045 619464	GENNADIY GAVRILOV	{"email": "gavrilovg-1953@postgrespro.ru", "phone": "+70731572727"}
0005435163221	EE0ACF	0515 223563	KLAVDIYA GERASIMOVA	{"email": "gerasimovak21011981@postgrespro.ru", "phone": "+70201052864"}
0005435163222	4F8020	9301 589401	MARAT KRASNOV	{"email": "krasnov.marat01071969@postgrespro.ru", "phone": "+70155689609"}
0005435163223	E8F164	9496 410716	ALINA FROLOVA	{"phone": "+70381843967"}
0005435163224	7C02DE	5595 782067	MARIYA IVANOVA	{"email": "ivanova_m.1971@postgrespro.ru", "phone": "+70784076206"}
0005435163225	96A30F	5317 827695	TAISIYA TITOVA	{"phone": "+70549176789"}
0005435163226	96A30F	4604 654510	VALERIY MAKAROV	{"email": "v-makarov-021970@postgrespro.ru", "phone": "+70673745948"}
0005435163227	77E999	9579 166447	ANDREY YAKOVLEV	{"phone": "+70335017725"}
0005435163228	25FAE1	6823 533607	IVAN NAUMOV	{"email": "naumov_i091979@postgrespro.ru", "phone": "+70152951978"}
0005435163229	38DC3C	9307 708249	OLEG SIDOROV	{"phone": "+70918415976"}
0005435163230	38DC3C	5959 267051	IGOR KISELEV	{"email": "kiselevigor.1975@postgrespro.ru", "phone": "+70475305782"}
0005435163231	8D9FBA	8106 787024	DMITRIY MATVEEV	{"email": "matveev-dmitriy.12121974@postgrespro.ru", "phone": "+70275920793"}
0005435163232	8D9FBA	4633 265795	ALINA POPOVA	{"email": "popova.a-1978@postgrespro.ru", "phone": "+70666113375"}
0005435163233	9EDCF9	8913 769623	ALEKSANDR MAKSIMOV	{"email": "maksimovaleksandr061967@postgrespro.ru", "phone": "+70951938168"}
0005435163234	9EDCF9	4832 431868	ALEKSANDR AFANASEV	{"email": "a.afanasev.071979@postgrespro.ru", "phone": "+70553749865"}
0005435163235	9EDCF9	0253 089368	IVAN KONOVALOV	{"email": "konovalov-i-26011977@postgrespro.ru", "phone": "+70103197472"}
0005435163236	10E042	4924 543982	GALINA MASLOVA	{"phone": "+70751110058"}
0005435163237	34287A	5599 531061	VITALIY VLASOV	{"email": "vlasov_vitaliy.071969@postgrespro.ru", "phone": "+70271439038"}
0005435163238	34287A	8539 009921	TATYANA SAVELEVA	{"phone": "+70633860154"}
0005435163239	8C26BF	8648 439621	MARIYA FEDOROVA	{"email": "fedorova_m_061969@postgrespro.ru", "phone": "+70305688278"}
0005435163240	775A5E	8897 424159	ALEKSEY TIMOFEEV	{"phone": "+70410779024"}
0005435163241	E3A33C	7118 239344	NATALYA ZAKHAROVA	{"phone": "+70793754264"}
0005435163242	E3A33C	0252 139796	ALEKSANDR BONDARENKO	{"email": "bondarenko-a.19021965@postgrespro.ru", "phone": "+70525848980"}
0005435163243	002FDC	6551 436927	ANTON NAZAROV	{"phone": "+70943789293"}
0005435163244	BD22C2	7149 375466	GENNADIY CHERNOV	{"email": "chernov_g1978@postgrespro.ru", "phone": "+70789345726"}
0005435163245	BD22C2	0286 406306	VERA VASILEVA	{"email": "v.vasileva031967@postgrespro.ru", "phone": "+70960573057"}
0005435163246	F5E358	7003 212105	ALEKSEY MAKAROV	{"phone": "+70316285543"}
0005435163247	92ED2B	5145 593749	KIRILL KISELEV	{"email": "k.kiselev16051959@postgrespro.ru", "phone": "+70724543078"}
0005435163248	92ED2B	8422 711832	MIKHAIL KUZMIN	{"phone": "+70772255993"}
0005435163249	B612D6	4879 628433	IVAN GRIGOREV	{"phone": "+70699687158"}
0005435163250	C3C24A	5721 794289	GENNADIY KUZNECOV	{"email": "gennadiy.kuznecov.091960@postgrespro.ru", "phone": "+70977910570"}
0005435163251	D4E82C	7362 856383	ELENA KUZMINA	{"phone": "+70296213215"}
0005435163252	3DB62B	6261 173059	ANNA SERGEEVA	{"email": "annasergeeva061967@postgrespro.ru", "phone": "+70384867768"}
0005435163253	81094D	8685 520974	ALEKSANDR ROMANOV	{"email": "aromanov-101965@postgrespro.ru", "phone": "+70896032091"}
0005435163254	1B1747	0245 202297	ELENA DAVYDOVA	{"phone": "+70543535929"}
0005435163255	6C01D1	5808 125737	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-11041970@postgrespro.ru", "phone": "+70258299770"}
0005435163256	6C01D1	2418 064118	DANIIL KUZNECOV	{"email": "kuznecovd.10011966@postgrespro.ru", "phone": "+70584139439"}
0005435163257	BEF1B4	4551 454774	SERGEY FEDOROV	{"phone": "+70870895020"}
0005435163258	1EB127	6032 780456	SVETLANA SOKOLOVA	{"phone": "+70191640530"}
0005435163259	1EB127	0317 732724	VLADIMIR YAKOVLEV	{"email": "yakovlev_v_30061968@postgrespro.ru", "phone": "+70035017729"}
0005435163260	2CC0D9	4394 089088	ZAKHAR SCHERBAKOV	{"phone": "+70028352791"}
0005435163261	1B36D4	4258 664523	NIKOLAY SCHERBAKOV	{"email": "scherbakov_n-031984@postgrespro.ru", "phone": "+70971800518"}
0005435163262	1B36D4	2619 133069	DINA ZHURAVLEVA	{"email": "dina-zhuravleva-051972@postgrespro.ru", "phone": "+70068419454"}
0005435163263	DE188F	5790 690738	NADEZHDA FROLOVA	{"phone": "+70993990659"}
0005435163264	3B56D0	4695 456323	ROMAN DENISOV	{"email": "romandenisov-10041979@postgrespro.ru", "phone": "+70226458119"}
0005435163265	322043	6689 136899	ALSU KISELEVA	{"phone": "+70803021208"}
0005435163266	322043	9418 565892	TATYANA NIKOLAEVA	{"email": "t.nikolaeva1981@postgrespro.ru", "phone": "+70004378660"}
0005435163267	FB7388	4659 236741	SERGEY FILIPPOV	{"phone": "+70772525794"}
0005435163268	F880C8	3119 485162	VIKTOR MATVEEV	{"phone": "+70338987059"}
0005435163269	985B70	2999 087344	TATYANA ILINA	{"phone": "+70842061474"}
0005435163270	315F30	0677 565857	NATALYA EGOROVA	{"phone": "+70272593314"}
0005435163271	1BF235	7383 468159	EKATERINA SOKOLOVA	{"email": "sokolova-ekaterina071975@postgrespro.ru", "phone": "+70983685998"}
0005435163272	5B9D36	8185 331586	EMILIYA ERMAKOVA	{"phone": "+70500363281"}
0005435163273	30391A	8036 532764	VLADISLAV SIDOROV	{"phone": "+70037678764"}
0005435163274	DFD2DA	5031 927184	KONSTANTIN IVANOV	{"email": "ivanovkonstantin08051969@postgrespro.ru", "phone": "+70319605346"}
0005435163275	A37504	5457 988812	DMITRIY SHEVCHENKO	{"email": "shevchenko-d.081971@postgrespro.ru", "phone": "+70117160460"}
0005435163276	ACFE3A	7888 603264	ZHANNA PAVLOVA	{"phone": "+70375582362"}
0005435163277	DCF24C	8552 698884	VYACHESLAV KISELEV	{"phone": "+70550976933"}
0005435163278	DCF24C	1618 779481	NINA GERASIMOVA	{"email": "ngerasimova-081968@postgrespro.ru", "phone": "+70221139726"}
0005435163279	F3AFF8	2224 625874	LARISA EGOROVA	{"phone": "+70887706185"}
0005435163280	EA4813	1218 573160	VERA VASILEVA	{"email": "v_vasileva-101959@postgrespro.ru", "phone": "+70378660336"}
0005435163281	EA4813	0829 798214	ROZA PAVLOVA	{"email": "pavlova-roza_061973@postgrespro.ru", "phone": "+70334975140"}
0005435163282	C0CF76	7305 489712	VALENTINA VASILEVA	{"email": "vasileva-valentina.101972@postgrespro.ru", "phone": "+70361151613"}
0005435163283	924E41	5160 457982	YURIY MARTYNOV	{"phone": "+70378172853"}
0005435163284	1530FA	0658 105228	VALENTINA ANTONOVA	{"email": "v_antonova28011971@postgrespro.ru", "phone": "+70613185097"}
0005435163285	EE5F91	8864 193736	YULIYA KULIKOVA	{"email": "kulikovayuliya.09111964@postgrespro.ru", "phone": "+70178874659"}
0005435163286	EE5F91	3410 079529	ANDREY VOROBEV	{"phone": "+70026481064"}
0005435163287	826C30	4576 165833	NATALYA POTAPOVA	{"email": "potapova-natalya.021970@postgrespro.ru", "phone": "+70956527758"}
0005435163288	DF6E54	5655 626481	NIKITA IVANOV	{"phone": "+70399041380"}
0005435163289	5B7653	8288 152998	LYUDMILA KISELEVA	{"phone": "+70982114252"}
0005435163290	5B7653	2734 225675	NADEZHDA ERMAKOVA	{"phone": "+70328854178"}
0005435163291	5B7653	9882 639476	YULIYA VOLKOVA	{"phone": "+70673043574"}
0005435163292	8262F3	1912 767928	SERGEY IVANOV	{"email": "ivanovs-091975@postgrespro.ru", "phone": "+70937990749"}
0005435163293	59912D	3446 477739	VLADIMIR VLASOV	{"phone": "+70432225623"}
0005435163294	95A3DA	2103 783051	VALENTIN EGOROV	{"email": "egorov-valentin-101975@postgrespro.ru", "phone": "+70218877510"}
0005435163295	602C5B	3018 616295	ALEKSANDR DMITRIEV	{"phone": "+70833719737"}
0005435163296	FF3CFB	6759 848964	NATALYA NAZAROVA	{"phone": "+70949013503"}
0005435163297	FF3CFB	5692 094881	NIKOLAY VASILEV	{"phone": "+70598656094"}
0005435163298	C7DF4D	4612 935045	NINA ZAKHAROVA	{"phone": "+70817512965"}
0005435163299	C7DF4D	0707 881129	LEV AFANASEV	{"email": "afanasev-l_13051970@postgrespro.ru", "phone": "+70877121260"}
0005435163300	8956D7	6168 456977	TATYANA ALEKSEEVA	{"phone": "+70010228437"}
0005435163301	8956D7	4846 383445	ELENA MOISEEVA	{"phone": "+70414330257"}
0005435163302	CFDE08	9145 211390	NATALYA KUDRYASHOVA	{"email": "kudryashovan.091975@postgrespro.ru", "phone": "+70359122408"}
0005435163303	B79DD2	4998 613780	NIKOLAY GRIGOREV	{"phone": "+70391352879"}
0005435163304	B79DD2	6654 141936	EVGENIYA TIKHONOVA	{"email": "e_tikhonova-101975@postgrespro.ru", "phone": "+70968977258"}
0005435163305	326F50	5336 454858	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr05081976@postgrespro.ru", "phone": "+70539838851"}
0005435163306	326F50	0573 560149	MARINA GRISHINA	{"phone": "+70893031927"}
0005435163307	97CECD	0849 299283	IGOR ALEKSANDROV	{"email": "igor-aleksandrov-05121974@postgrespro.ru", "phone": "+70658012905"}
0005435163308	F0E9A4	3732 080041	ZINAIDA TIKHONOVA	{"email": "z_tikhonova.061957@postgrespro.ru", "phone": "+70590134514"}
0005435163309	0999A5	4435 062042	DANIL STEPANOV	{"phone": "+70977075323"}
0005435163310	A75E6C	8650 430492	NADEZHDA ZHUKOVA	{"email": "zhukova-nadezhda_031977@postgrespro.ru", "phone": "+70418382040"}
0005435163311	4FF60B	7429 391274	MARIYA GERASIMOVA	{"phone": "+70323074749"}
0005435163312	60F21D	0243 561309	NATALYA SOROKINA	{"phone": "+70290546120"}
0005435163313	023043	2913 134291	GEORGIY DAVYDOV	{"email": "georgiy-davydov.31051967@postgrespro.ru", "phone": "+70688183708"}
0005435163314	023043	1193 063233	SERGEY PAVLOV	{"phone": "+70907676444"}
0005435163315	8A705B	3421 996035	ALEKSEY POPOV	{"email": "popovaleksey_041978@postgrespro.ru", "phone": "+70095972999"}
0005435163316	8A705B	2765 379121	MIKHAIL VASILEV	{"phone": "+70785621887"}
0005435163317	CCBA76	7027 372148	ANTONINA SAVELEVA	{"email": "saveleva-a1982@postgrespro.ru", "phone": "+70749248506"}
0005435163318	D09F90	4301 468916	ANASTASIYA NIKITINA	{"phone": "+70960605493"}
0005435163319	52AC18	9205 672365	LYUDMILA FEDOROVA	{"email": "fedoroval-28011976@postgrespro.ru", "phone": "+70496509677"}
0005435163320	52AC18	2253 869278	SVETLANA SIDOROVA	{"email": "s_sidorova.101964@postgrespro.ru", "phone": "+70726349754"}
0005435163321	52AC18	3851 286858	OLGA POLYAKOVA	{"phone": "+70866862653"}
0005435163322	F530C4	0642 268226	ALEKSANDR TIKHONOV	{"phone": "+70634981397"}
0005435163323	BAF417	0612 576820	VLADIMIR DENISOV	{"email": "denisov_v20021976@postgrespro.ru", "phone": "+70960724238"}
0005435163324	BAF417	1883 656775	MARINA ZOTOVA	{"phone": "+70736867279"}
0005435163325	92F6C1	8793 483507	MARIYA MELNIKOVA	{"phone": "+70855279407"}
0005435163326	A3778E	7697 829936	YULIYA KONDRATEVA	{"email": "y.kondrateva.03041967@postgrespro.ru", "phone": "+70001385922"}
0005435163327	2C5418	2679 557069	NIKITA IVANOV	{"phone": "+70427398915"}
0005435163328	7B322D	3423 527586	ALEKSEY PETROV	{"phone": "+70150195462"}
0005435163329	0F6135	1336 541946	KIRILL KAZAKOV	{"phone": "+70624724037"}
0005435163330	3FA1BE	0113 847371	MAKSIM BELOV	{"email": "belovmaksim.1963@postgrespro.ru", "phone": "+70516304259"}
0005435163331	38617B	1630 284086	MARIYA ERMAKOVA	{"email": "m_ermakova1980@postgrespro.ru", "phone": "+70921098963"}
0005435163332	38617B	0760 150862	DMITRIY NAZAROV	{"email": "nazarovd_18081974@postgrespro.ru", "phone": "+70131291118"}
0005435163333	015EF5	5632 747958	ALEKSANDR BELOV	{"phone": "+70588751786"}
0005435163334	015EF5	1652 918062	ANDREY ALEKSANDROV	{"phone": "+70234228944"}
0005435163335	69761F	7832 830559	SVETLANA MOISEEVA	{"phone": "+70142197063"}
0005435163336	D21EE2	2102 808185	VITALIY FILIPPOV	{"phone": "+70248200876"}
0005435163337	9A428D	1118 198797	ALEKSANDR KUZMIN	{"phone": "+70031794507"}
0005435163338	1CA60E	2938 631111	LYUBOV DMITRIEVA	{"email": "lyubov_dmitrieva1978@postgrespro.ru", "phone": "+70711466479"}
0005435163339	025B0F	5401 273633	NADEZHDA SOROKINA	{"phone": "+70583993471"}
0005435163340	FC1A88	8551 938075	SERGEY ALEKSEEV	{"email": "s-alekseev-031964@postgrespro.ru", "phone": "+70449721291"}
0005435163341	4BC339	5289 851503	VALERIY KRASNOV	{"email": "krasnov.valeriy_1974@postgrespro.ru", "phone": "+70372465420"}
0005435163342	4BC339	1922 989227	EKATERINA BELOVA	{"phone": "+70508052113"}
0005435163343	E20AD8	9093 542448	ROMAN BORISOV	{"email": "r-borisov_06011962@postgrespro.ru", "phone": "+70015618607"}
0005435163344	DC925A	9822 080575	NIKOLAY TARASOV	{"email": "n_tarasov021982@postgrespro.ru", "phone": "+70902861899"}
0005435163345	DC925A	9381 444972	ALEKSEY DAVYDOV	{"phone": "+70537177811"}
0005435163346	911227	9705 962695	NIKITA NIKOLAEV	{"email": "nikolaevnikita-31101964@postgrespro.ru", "phone": "+70257602801"}
0005435163347	911227	7581 989709	RUSTAM SERGEEV	{"email": "rustamsergeev_051974@postgrespro.ru", "phone": "+70110478466"}
0005435163348	258CE4	3853 736015	IRINA NOVIKOVA	{"phone": "+70769082064"}
0005435163349	2229F9	2802 235163	VIKTOR YAKOVLEV	{"email": "v_yakovlev051970@postgrespro.ru", "phone": "+70699752224"}
0005435163350	2229F9	6827 862326	SERGEY FEDOTOV	{"phone": "+70238564997"}
0005435163351	B2CB3D	5491 871812	NINA YUDINA	{"phone": "+70442046432"}
0005435163352	78FBCB	6064 828616	LYUDMILA TROFIMOVA	{"email": "lyudmila_trofimova15091967@postgrespro.ru", "phone": "+70486269357"}
0005435163353	78FBCB	5075 369441	NINA ALEKSANDROVA	{"email": "aleksandrova_nina_20101976@postgrespro.ru", "phone": "+70010527849"}
0005435163354	C06BBD	8075 447066	VLADIMIR MATVEEV	{"email": "matveevvladimir-16041970@postgrespro.ru", "phone": "+70842410465"}
0005435163355	A10BE5	3069 119345	SVETLANA SCHERBAKOVA	{"email": "s.scherbakova-10011974@postgrespro.ru", "phone": "+70616994868"}
0005435163356	A10BE5	7020 224919	ANDREY KONOVALOV	{"email": "konovalov-andrey-28011986@postgrespro.ru", "phone": "+70153962446"}
0005435163357	590F3D	5337 745064	ALEKSEY ANTONOV	{"email": "a.antonov_121974@postgrespro.ru", "phone": "+70670249622"}
0005435163358	A017FD	3809 575799	YURIY IVANOV	{"phone": "+70876171421"}
0005435163359	22B43B	7737 917179	MARINA AKIMOVA	{"email": "marina.akimova-011960@postgrespro.ru", "phone": "+70897395198"}
0005435163360	A35312	8464 778065	SERGEY IVANOV	{"email": "sergey-ivanov_011962@postgrespro.ru", "phone": "+70168500663"}
0005435163361	A35312	7277 836431	NADEZHDA KUZNECOVA	{"phone": "+70359636455"}
0005435163362	505B3B	5170 252360	NADEZHDA MOROZOVA	{"email": "n_morozova.1974@postgrespro.ru", "phone": "+70022860348"}
0005435163363	505B3B	2789 667809	ANDREY ZAKHAROV	{"phone": "+70706427508"}
0005435163364	B11A67	2621 591741	KRISTINA EGOROVA	{"phone": "+70853111426"}
0005435163365	B11A67	8357 609779	DENIS GAVRILOV	{"email": "gavrilov.d_19061966@postgrespro.ru", "phone": "+70104589664"}
0005435163366	4422F2	8534 532707	GALIYA KUZMINA	{"email": "galiya-kuzmina16091969@postgrespro.ru", "phone": "+70713087215"}
0005435163367	BC7026	7990 736758	VALENTIN FOMIN	{"email": "v-fomin1976@postgrespro.ru", "phone": "+70059438092"}
0005435163368	3AC160	9327 967311	EKATERINA NESTEROVA	{"phone": "+70472797045"}
0005435163369	3AC160	0376 017507	ELENA SOLOVEVA	{"email": "solovevaelena-111972@postgrespro.ru", "phone": "+70288466616"}
0005435163370	93E4D8	5431 348369	ALEKSEY ZAYCEV	{"email": "azaycev.051967@postgrespro.ru", "phone": "+70046464911"}
0005435163371	9B8CDD	1998 111426	DENIS KAZAKOV	{"phone": "+70075368087"}
0005435163372	A9C65C	1708 991357	EVGENIY KAZAKOV	{"phone": "+70400063659"}
0005435163373	2CC272	2010 889586	OKSANA VOROBEVA	{"phone": "+70479618305"}
0005435163374	ED8DA2	6098 222326	ALEKSEY FEDOROV	{"email": "fedorov_aleksey.1974@postgrespro.ru", "phone": "+70002705644"}
0005435163375	ED8DA2	6966 645124	OKSANA DANILOVA	{"phone": "+70686273809"}
0005435163376	F1C129	7510 533434	VIKTOR ILIN	{"phone": "+70636891038"}
0005435163377	EFCC82	3406 713865	ALEKSANDR SEMENOV	{"email": "semenovaleksandr_07011970@postgrespro.ru", "phone": "+70491455219"}
0005435163378	37CE1D	8865 205550	NADEZHDA LAZAREVA	{"email": "nadezhda.lazareva.26031977@postgrespro.ru", "phone": "+70450780397"}
0005435163379	37CE1D	0950 066765	VIKTORIYA VASILEVA	{"phone": "+70276118155"}
0005435163380	9968FD	7410 821947	MARIYA BELOVA	{"email": "belovam.06121978@postgrespro.ru", "phone": "+70214852374"}
0005435163381	F24C03	8092 369219	YULIYA SOKOLOVA	{"email": "sokolova-yuliya_15111981@postgrespro.ru", "phone": "+70494846458"}
0005435163382	F24C03	6195 778751	NIKOLAY VLASOV	{"phone": "+70038563163"}
0005435163383	C3CC1F	5566 687688	KONSTANTIN IVANOV	{"phone": "+70543492286"}
0005435163384	DB778E	0119 793960	TATYANA DENISOVA	{"phone": "+70973894004"}
0005435163385	36BCAB	8095 813295	TATYANA KUZNECOVA	{"phone": "+70199729225"}
0005435163386	36BCAB	7009 380182	KONSTANTIN KAZAKOV	{"phone": "+70826823199"}
0005435163387	FA7301	8968 108102	NIKOLAY SOROKIN	{"phone": "+70096241741"}
0005435163388	63CEFC	4493 488256	YURIY CHERNOV	{"email": "chernov.yuriy.18051971@postgrespro.ru", "phone": "+70676739920"}
0005435163389	63CEFC	7927 717111	VLADIMIR GAVRILOV	{"email": "gavrilovvladimir061977@postgrespro.ru", "phone": "+70161839551"}
0005435163390	E2E8A6	7719 388273	MARIYA AKIMOVA	{"email": "m_akimova08061977@postgrespro.ru", "phone": "+70932822171"}
0005435163391	E2E8A6	9394 558829	NIKOLAY NIKOLAEV	{"email": "nikolay.nikolaev-071973@postgrespro.ru", "phone": "+70768301366"}
0005435176732	CCD94C	7305 965477	ALISA GRISHINA	{"phone": "+70016123625"}
0005435176585	D65D08	5017 528073	NATALYA ZAYCEVA	{"email": "zayceva.natalya.091978@postgrespro.ru", "phone": "+70373163915"}
0005435176586	C9E0A5	2201 874172	IGOR BARANOV	{"phone": "+70696712822"}
0005435176587	C9E0A5	9551 318476	ANNA PAVLOVA	{"email": "pavlova.anna-06021956@postgrespro.ru", "phone": "+70076464973"}
0005435176588	9CBC9E	4642 036648	OLGA VASILEVA	{"email": "vasileva_o.01031960@postgrespro.ru", "phone": "+70119655474"}
0005435176589	9CBC9E	7064 666445	DMITRIY SCHERBAKOV	{"email": "d.scherbakov.1965@postgrespro.ru", "phone": "+70716758921"}
0005435176590	F28F5A	6441 406460	YULIYA VASILEVA	{"phone": "+70793293708"}
0005435176591	3D14B2	6396 758718	LARISA IVANOVA	{"phone": "+70769317592"}
0005435176592	DAD368	9454 297828	VIKTORIYA FADEEVA	{"phone": "+70273361313"}
0005435176593	B993CE	5661 628734	KONSTANTIN KOROLEV	{"email": "konstantin-korolev.081975@postgrespro.ru", "phone": "+70147906399"}
0005435176595	C1853E	8238 135724	GLEB SMIRNOV	{"email": "smirnovgleb-071981@postgrespro.ru", "phone": "+70978559704"}
0005435176596	C1853E	7521 100886	VLADIMIR SCHERBAKOV	{"phone": "+70030577736"}
0005435176597	BDE860	0310 978141	RUSLAN IVANOV	{"email": "ivanov-r_20011974@postgrespro.ru", "phone": "+70307289572"}
0005435176598	804D50	6762 603135	EDUARD VASILEV	{"email": "eduard_vasilev_1966@postgrespro.ru", "phone": "+70734036536"}
0005435176599	577D08	1344 127474	LYUDMILA TIKHONOVA	{"phone": "+70098635788"}
0005435176600	577D08	4075 047244	NIKOLAY POPOV	{"email": "popov-n04121965@postgrespro.ru", "phone": "+70062227723"}
0005435176601	BAED0A	4605 866692	MARGARITA BOGDANOVA	{"email": "bogdanova.margarita.1969@postgrespro.ru", "phone": "+70757758727"}
0005435176602	A66A9C	7430 410881	SVETLANA YAKOVLEVA	{"email": "yakovleva_s-081983@postgrespro.ru", "phone": "+70007479930"}
0005435176603	EE4891	6158 834332	MIKHAIL NIKOLAEV	{"phone": "+70499131935"}
0005435176604	EE4891	7682 140195	NIKOLAY ALEKSANDROV	{"email": "aleksandrovnikolay1981@postgrespro.ru", "phone": "+70617747157"}
0005435176605	D59EA1	8550 990354	YURIY MAKAROV	{"phone": "+70277487202"}
0005435176606	1C7DF5	3569 673718	ANTONINA GAVRILOVA	{"phone": "+70897990721"}
0005435176607	1C7DF5	3170 210391	VIKTORIYA KRASNOVA	{"email": "viktoriya_krasnova.1978@postgrespro.ru", "phone": "+70027220594"}
0005435176608	096B68	4939 267141	GALINA SOKOLOVA	{"email": "sokolovagalina08061968@postgrespro.ru", "phone": "+70469646339"}
0005435176609	B4187B	4508 280895	SVETLANA LEBEDEVA	{"email": "lebedeva.s.051980@postgrespro.ru", "phone": "+70217204787"}
0005435176610	0609FF	2833 680173	IGOR KULIKOV	{"email": "igor-kulikov30071967@postgrespro.ru", "phone": "+70187952674"}
0005435176611	307860	7362 867406	NATALYA TITOVA	{"phone": "+70419893545"}
0005435176612	307860	4061 773404	NATALYA FROLOVA	{"email": "frolova_natalya.1965@postgrespro.ru", "phone": "+70188974263"}
0005435176613	689748	3059 001070	ELENA IVANOVA	{"phone": "+70796580663"}
0005435176614	689748	5006 782549	VARVARA VLASOVA	{"email": "v_vlasova-1966@postgrespro.ru", "phone": "+70694407218"}
0005435176615	8B6796	9848 830326	ANATOLIY DAVYDOV	{"email": "davydov_anatoliy-1971@postgrespro.ru", "phone": "+70344831982"}
0005435176616	DEBACD	0882 831471	ELENA MIKHAYLOVA	{"phone": "+70335796904"}
0005435176617	2C7DE9	0659 778084	EKATERINA BORISOVA	{"phone": "+70078845670"}
0005435176618	D667A1	5781 154231	IVAN KUZNECOV	{"email": "kuznecov-ivan1975@postgrespro.ru", "phone": "+70133844488"}
0005435176619	D667A1	4783 770097	TATYANA KAZAKOVA	{"email": "kazakova_tatyana11081974@postgrespro.ru", "phone": "+70433249238"}
0005435176620	D667A1	4911 273459	VLADIMIR ZHUKOV	{"phone": "+70698995934"}
0005435176621	D667A1	2528 729370	ANTON GUSEV	{"phone": "+70312381380"}
0005435176622	71C082	6350 915041	ANASTASIYA VOROBEVA	{"email": "vorobeva-anastasiya05111966@postgrespro.ru", "phone": "+70291192927"}
0005435176623	71C082	4463 839722	SERGEY SCHERBAKOV	{"phone": "+70105045856"}
0005435176624	6F51AC	0917 027539	ALEKSANDR PETROV	{"phone": "+70585520455"}
0005435176625	6F51AC	8934 080377	VALERIYA ZHURAVLEVA	{"email": "zhuravleva_v08091975@postgrespro.ru", "phone": "+70194345820"}
0005435176626	9A2130	9780 779888	TAMARA EGOROVA	{"email": "egorova-tamara_041957@postgrespro.ru", "phone": "+70870065270"}
0005435176627	10E0C6	8444 844347	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr20081968@postgrespro.ru", "phone": "+70988354765"}
0005435176628	6BEF77	2755 733348	VLADIMIR SOKOLOV	{"phone": "+70757442931"}
0005435176629	E45C0A	3260 543064	ILYAS SEMENOV	{"email": "semenov-i_071973@postgrespro.ru", "phone": "+70997331470"}
0005435176630	E45C0A	6777 200290	EVGENIY SCHERBAKOV	{"email": "evgeniy_scherbakov_1968@postgrespro.ru", "phone": "+70454962598"}
0005435176631	DF86F7	8439 035833	VLADISLAV ZHUKOV	{"phone": "+70701671848"}
0005435176632	DF86F7	7048 601466	SERAFIMA ARKHIPOVA	{"phone": "+70606239254"}
0005435176633	802731	2088 942900	MIKHAIL KONOVALOV	{"email": "mikhail_konovalov30121972@postgrespro.ru", "phone": "+70936129897"}
0005435176634	0807F0	6513 779768	DMITRIY FEDOROV	{"email": "dmitriy.fedorov.1969@postgrespro.ru", "phone": "+70718437379"}
0005435176635	0807F0	0049 361006	VALERIY SCHERBAKOV	{"phone": "+70295739821"}
0005435176636	0807F0	8689 466583	VERA ANDREEVA	{"phone": "+70871868276"}
0005435176637	9B30C2	4500 142470	KONSTANTIN IVANOV	{"phone": "+70084169148"}
0005435176638	73984D	1906 062522	VALERIY FEDOROV	{"email": "fedorovv-071969@postgrespro.ru", "phone": "+70056818243"}
0005435176639	FEBDA5	5018 531604	EVGENIYA GAVRILOVA	{"email": "gavrilovae.1980@postgrespro.ru", "phone": "+70896772775"}
0005435176640	D89287	6783 822079	ZOYA IVANOVA	{"phone": "+70631582560"}
0005435176641	D89287	3075 859035	VASILIY BELOV	{"email": "belov-vasiliy-051980@postgrespro.ru", "phone": "+70755904248"}
0005435176642	06B885	1241 683697	VIKTOR SIDOROV	{"phone": "+70666147309"}
0005435176643	F76407	6189 938848	VLADIMIR VLASOV	{"email": "vlasov.vladimir-111981@postgrespro.ru", "phone": "+70095203099"}
0005435176644	900F31	3981 236955	MARIYA MAKAROVA	{"email": "mariya_makarova-031969@postgrespro.ru", "phone": "+70725001660"}
0005435176645	4724C2	0008 332492	VLADIMIR KUZNECOV	{"email": "v-kuznecov-20071973@postgrespro.ru", "phone": "+70635939480"}
0005435176646	61ADD4	7807 333546	NINA RYABOVA	{"email": "ryabova-nina_08061969@postgrespro.ru", "phone": "+70853146855"}
0005435176647	25600C	9358 124355	SVETLANA YUDINA	{"email": "s_yudina-1971@postgrespro.ru", "phone": "+70980978880"}
0005435176648	25600C	9959 391491	VLADIMIR SMIRNOV	{"email": "smirnovvladimir031976@postgrespro.ru", "phone": "+70616144619"}
0005435176649	93DB15	7887 551192	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr-25041968@postgrespro.ru", "phone": "+70619741112"}
0005435176650	93DB15	9472 508506	RUSTAM FILIPPOV	{"email": "filippov-rustam-111969@postgrespro.ru", "phone": "+70516632981"}
0005435176651	60F705	9912 102616	ANATOLIY MOROZOV	{"email": "a_morozov.12021970@postgrespro.ru", "phone": "+70414956490"}
0005435176652	EDE238	0348 553738	IRINA LUKYANOVA	{"email": "i.lukyanova-1990@postgrespro.ru", "phone": "+70567362427"}
0005435176653	82AF90	2440 663866	VALERIY NIKOLAEV	{"email": "nikolaevv.111975@postgrespro.ru", "phone": "+70677825072"}
0005435176654	7A939D	1167 179427	RAISA KONOVALOVA	{"email": "r_konovalova.1964@postgrespro.ru", "phone": "+70147698884"}
0005435176655	83F940	5763 943622	VADIM EGOROV	{"email": "vadim-egorov.101958@postgrespro.ru", "phone": "+70698036404"}
0005435176656	8F3CDC	1793 536106	OKSANA TIKHONOVA	{"phone": "+70413831430"}
0005435176657	8F3CDC	5769 785768	GALINA NAUMOVA	{"email": "g-naumova.14101975@postgrespro.ru", "phone": "+70838034225"}
0005435176658	7F0A88	6759 466607	GALINA DMITRIEVA	{"phone": "+70428598238"}
0005435176659	0167A9	4013 788386	NAILYA ANDREEVA	{"phone": "+70642785741"}
0005435176660	58327B	6833 813244	KONSTANTIN ANDREEV	{"email": "andreev.k1975@postgrespro.ru", "phone": "+70388772982"}
0005435176661	58327B	1929 355406	IRINA NAUMOVA	{"email": "inaumova121982@postgrespro.ru", "phone": "+70581035651"}
0005435176662	B351CF	6810 061003	GALINA VASILEVA	{"email": "vasileva-g.25011960@postgrespro.ru", "phone": "+70973170977"}
0005435176663	3638B1	4916 348469	ANNA VOROBEVA	{"email": "vorobeva-a.1970@postgrespro.ru", "phone": "+70151197294"}
0005435176664	C81BA0	6159 437035	VYACHESLAV MAKSIMOV	{"email": "maksimov.v_121969@postgrespro.ru", "phone": "+70752725009"}
0005435176665	B68FA8	5638 519875	ALEKSANDR FILIPPOV	{"phone": "+70757735088"}
0005435176666	B68FA8	0999 259435	KARINA DAVYDOVA	{"phone": "+70823242055"}
0005435176667	B68FA8	8459 653862	EGOR KISELEV	{"phone": "+70203264916"}
0005435176668	38FFA4	6598 164070	DARYA LUKYANOVA	{"phone": "+70988159262"}
0005435176669	497A73	3123 606884	OLEG SCHERBAKOV	{"phone": "+70944288860"}
0005435176670	0CD54B	2264 065469	VLADIMIR ROMANOV	{"email": "romanov.v.03081989@postgrespro.ru", "phone": "+70006459628"}
0005435176671	0CD54B	0781 251991	SVETLANA ZAKHAROVA	{"phone": "+70625496306"}
0005435176672	6DBC80	8343 748985	SERGEY TIMOFEEV	{"email": "timofeev-s_051990@postgrespro.ru", "phone": "+70175369639"}
0005435176673	737A5D	6515 689997	OLGA KUZNECOVA	{"email": "olgakuznecova23011972@postgrespro.ru", "phone": "+70848817064"}
0005435176674	C23795	7856 211244	NATALYA RODIONOVA	{"email": "rodionova_n.27091979@postgrespro.ru", "phone": "+70379462866"}
0005435176675	C23795	2287 189368	PAVEL TIKHONOV	{"phone": "+70531325348"}
0005435176676	81D91A	8575 832546	VIKTOR MELNIKOV	{"phone": "+70484600753"}
0005435176677	81D91A	1122 542327	ELENA GORBUNOVA	{"email": "gorbunovaelena.011969@postgrespro.ru", "phone": "+70872163941"}
0005435176678	81D91A	5096 509991	OKSANA POLYAKOVA	{"email": "polyakovao.26081971@postgrespro.ru", "phone": "+70919776801"}
0005435176679	AEF675	0519 574919	MARINA ZAKHAROVA	{"phone": "+70462138272"}
0005435176680	AEF675	6976 491062	OLGA ANDREEVA	{"phone": "+70398732258"}
0005435176681	1F7AB3	9202 502931	MARINA POPOVA	{"email": "m.popova1967@postgrespro.ru", "phone": "+70563065377"}
0005435176682	58CA33	2083 411234	TATYANA EGOROVA	{"phone": "+70981725706"}
0005435176683	B9BE7E	6790 123805	SVETLANA POTAPOVA	{"phone": "+70816272843"}
0005435176684	8D2E0C	2789 352454	OLGA KOROLEVA	{"phone": "+70098620551"}
0005435176685	22A83D	3693 284938	NADEZHDA GUSEVA	{"email": "n-guseva_121970@postgrespro.ru", "phone": "+70474611560"}
0005435176686	92BBAB	7429 763674	ROMAN MELNIKOV	{"email": "melnikov.roman.1970@postgrespro.ru", "phone": "+70463629066"}
0005435176687	92BBAB	5198 158353	LARISA MASLOVA	{"phone": "+70787104373"}
0005435176688	0D0F57	9609 561951	SERGEY KOZLOV	{"phone": "+70087812306"}
0005435176689	A1F607	7811 078157	ANNA KULIKOVA	{"email": "kulikova-anna_1981@postgrespro.ru", "phone": "+70866135290"}
0005435176690	A1F607	1584 358713	SVETLANA MAKAROVA	{"email": "svetlana.makarova-1971@postgrespro.ru", "phone": "+70622902234"}
0005435176691	9A5023	1348 150849	ALEKSEY SCHERBAKOV	{"phone": "+70374970867"}
0005435176692	67BFBF	5895 253566	OLGA VASILEVA	{"phone": "+70372936317"}
0005435176693	1E2139	1537 473089	SVETLANA IVANOVA	{"phone": "+70247285811"}
0005435176694	1E2139	7592 164161	ANATOLIY NIKITIN	{"email": "anatoliy-nikitin.30121971@postgrespro.ru", "phone": "+70255350965"}
0005435176695	9F7BEF	2230 270868	MARIYA ANTONOVA	{"email": "antonova_m.03121965@postgrespro.ru", "phone": "+70299353838"}
0005435176696	04A5BF	1775 713858	SVETLANA ALEKSANDROVA	{"phone": "+70168475830"}
0005435176697	FC7603	9164 326493	ANATOLIY FEDOROV	{"email": "fedorov_a_1970@postgrespro.ru", "phone": "+70399022315"}
0005435176698	CD0B95	7047 963411	OLGA IVANOVA	{"phone": "+70090005841"}
0005435176699	3912CD	4394 860974	POLINA BELOVA	{"phone": "+70945352674"}
0005435176700	3912CD	0403 605912	GALINA SERGEEVA	{"phone": "+70547113442"}
0005435176701	31FFCD	9926 049245	OLGA IVANOVA	{"phone": "+70349405197"}
0005435176702	31FFCD	0967 928410	ANDREY VOROBEV	{"phone": "+70060176876"}
0005435176703	31FFCD	4513 466149	NATALYA ZAKHAROVA	{"email": "zakharova.n.1964@postgrespro.ru", "phone": "+70938455813"}
0005435176704	744ED5	8608 132123	VALERIYA CHERNOVA	{"phone": "+70601607591"}
0005435176705	43C42C	4290 563306	ILYA ZHURAVLEV	{"phone": "+70333384780"}
0005435176706	A9A461	7847 699093	ALEKSEY IVANOV	{"phone": "+70423462413"}
0005435176707	B103F0	8954 934472	ALINA ANDREEVA	{"phone": "+70199939766"}
0005435176708	B103F0	9249 092396	GALINA SERGEEVA	{"phone": "+70597662476"}
0005435176709	AE9F71	7911 793361	TATYANA ZAKHAROVA	{"email": "zakharova.t_121971@postgrespro.ru", "phone": "+70879557295"}
0005435176710	77C793	9279 679460	VLADIMIR MOROZOV	{"phone": "+70640211197"}
0005435176711	E1D2C2	4227 344760	EKATERINA KOROLEVA	{"phone": "+70161542226"}
0005435176712	EE8003	8446 278895	ZHANNA TITOVA	{"email": "z_titova.061974@postgrespro.ru", "phone": "+70620097885"}
0005435176713	0DCC54	4279 737086	ALEKSANDR MEDVEDEV	{"phone": "+70325520267"}
0005435176714	58541D	5372 486994	LYUBOV DAVYDOVA	{"phone": "+70474680000"}
0005435176715	821101	0261 961112	TAMARA BARANOVA	{"email": "tbaranova.011986@postgrespro.ru", "phone": "+70296129524"}
0005435176716	A590A9	0943 858797	ARTEM PETROV	{"phone": "+70614493364"}
0005435176717	A590A9	1478 745965	OLESYA NIKOLAEVA	{"phone": "+70376597109"}
0005435176718	0877CC	6504 837464	VALERIY KUDRYASHOV	{"phone": "+70208756200"}
0005435176719	0877CC	7108 589363	OLEG KONOVALOV	{"phone": "+70499427941"}
0005435176720	32727A	9372 094988	NATALYA ISAEVA	{"phone": "+70941721084"}
0005435176721	32727A	4597 224575	ALEKSANDR FEDOROV	{"email": "a-fedorov_011961@postgrespro.ru", "phone": "+70696188679"}
0005435176722	22FE8D	7746 368279	IGOR IVANOV	{"phone": "+70094477061"}
0005435176723	3ED98B	5933 749198	OLGA NESTEROVA	{"email": "o_nesterova_011976@postgrespro.ru", "phone": "+70938275294"}
0005435176724	B58127	3542 770162	VITALIY POPOV	{"email": "vitaliy.popov101968@postgrespro.ru", "phone": "+70847437530"}
0005435176725	8BF801	7432 304306	ANATOLIY POPOV	{"email": "popov.a.071966@postgrespro.ru", "phone": "+70713254626"}
0005435176726	64BD2F	5822 607011	SVETLANA ZAKHAROVA	{"email": "svetlana.zakharova-1962@postgrespro.ru", "phone": "+70255339960"}
0005435176727	0F9299	7727 750353	ELENA ILINA	{"phone": "+70006399502"}
0005435176728	664508	2355 692174	IRINA DENISOVA	{"phone": "+70850122692"}
0005435176729	664508	0685 849094	EDUARD POPOV	{"email": "epopov.111973@postgrespro.ru", "phone": "+70802387836"}
0005435176730	361A39	5538 231151	KONSTANTIN SAVELEV	{"phone": "+70986105968"}
0005435176731	361A39	0514 419653	MARINA VOLKOVA	{"phone": "+70541046620"}
0005435176733	206F30	9172 967017	ANDREY PAVLOV	{"email": "pavlovandrey.02031968@postgrespro.ru", "phone": "+70888417059"}
0005435176734	1E5232	0028 961948	IGOR KUZNECOV	{"email": "igorkuznecov.121962@postgrespro.ru", "phone": "+70803969979"}
0005435176735	1E5232	8034 764788	SVETLANA KUZNECOVA	{"phone": "+70845771018"}
0005435176736	F1FA03	9097 847707	MARIYA KONOVALOVA	{"email": "m-konovalova-051983@postgrespro.ru", "phone": "+70086912758"}
0005435176737	F1FA03	9417 262043	ARTUR GAVRILOV	{"phone": "+70300995477"}
0005435176738	F1FA03	5929 103357	MATVEY IVANOV	{"phone": "+70723510521"}
0005435176739	C12C25	7405 542839	VERA VASILEVA	{"email": "veravasileva22091972@postgrespro.ru", "phone": "+70937032931"}
0005435176740	C12C25	7585 674765	ELENA ROMANOVA	{"phone": "+70964366353"}
0005435176741	70C16A	5202 567453	OLEG SOROKIN	{"email": "oleg.sorokin.071976@postgrespro.ru", "phone": "+70286290896"}
0005435176742	D86228	9187 820703	SERGEY SOKOLOV	{"email": "sergey-sokolov_1980@postgrespro.ru", "phone": "+70808590192"}
0005435176743	3C183F	0961 889665	ANDREY MELNIKOV	{"phone": "+70368488855"}
0005435176744	6394E8	7786 845700	NIKOLAY YAKOVLEV	{"email": "yakovlev-nikolay-091977@postgrespro.ru", "phone": "+70958019043"}
0005435176745	08D495	2895 575473	ANNA KOLESNIKOVA	{"email": "kolesnikovaa.071976@postgrespro.ru", "phone": "+70712471951"}
0005435176746	08D495	3231 320157	TATYANA YAKOVLEVA	{"email": "tyakovleva_06121985@postgrespro.ru", "phone": "+70549487078"}
0005435176747	A385F8	4597 464863	VALENTINA MAKAROVA	{"phone": "+70650257228"}
0005435176748	A385F8	1922 029396	ARTEM GERASIMOV	{"email": "gerasimov-a071967@postgrespro.ru", "phone": "+70503589979"}
0005435176749	54DFC4	8840 351619	NATALYA NAUMOVA	{"email": "naumova-natalya-1978@postgrespro.ru", "phone": "+70461919895"}
0005435176750	54DFC4	9693 217103	SERGEY ZAKHAROV	{"phone": "+70867145105"}
0005435176751	927161	0487 467512	LIDIYA ZAYCEVA	{"phone": "+70274693136"}
0005435176752	7F42BD	0597 282155	VIKTORIYA NOVIKOVA	{"phone": "+70954275737"}
0005435176753	3286B4	1988 346283	EVGENIY IVANOV	{"phone": "+70414937633"}
0005435176754	3286B4	8794 313421	VASILIY OSIPOV	{"email": "v-osipov-03091979@postgrespro.ru", "phone": "+70265424760"}
0005435176755	3286B4	2279 832271	VITALIY MOROZOV	{"phone": "+70859321865"}
0005435176756	F181AE	0747 188425	EGOR PAVLOV	{"phone": "+70778035543"}
0005435176757	F181AE	7965 020843	GALINA GERASIMOVA	{"phone": "+70099506887"}
0005435176758	92C59A	5415 837516	ALEKSANDR NIKITIN	{"email": "a_nikitin_26121973@postgrespro.ru", "phone": "+70608313218"}
0005435176759	DD0775	6090 932916	MARIYA DENISOVA	{"email": "mariya_denisova17041972@postgrespro.ru", "phone": "+70551945490"}
0005435176760	B2722C	4588 583263	VALENTINA CHERNOVA	{"phone": "+70024297398"}
0005435176761	B2722C	5364 229749	NIKITA KUZNECOV	{"phone": "+70293989258"}
0005435176762	00F1CF	7303 241031	PETR KRASNOV	{"phone": "+70661065004"}
0005435176763	6D187E	8289 297503	OKSANA KOZLOVA	{"email": "kozlovao.10101965@postgrespro.ru", "phone": "+70033617108"}
0005435176764	D33B9B	8654 711032	PAVEL VLASOV	{"phone": "+70473840592"}
0005435176765	D33B9B	6250 831780	TATYANA SOROKINA	{"email": "t.sorokina02111972@postgrespro.ru", "phone": "+70477605066"}
0005435176766	E8390B	7030 224461	DMITRIY MAKAROV	{"email": "d-makarov_011983@postgrespro.ru", "phone": "+70417509866"}
0005435176767	E8390B	3726 646648	ALINA DENISOVA	{"email": "denisova-alina091975@postgrespro.ru", "phone": "+70057592370"}
0005435176768	1E0668	4557 803816	OLGA ZHURAVLEVA	{"phone": "+70775312582"}
0005435176769	925355	1252 701430	LYUDMILA RYABOVA	{"email": "lyudmila-ryabova_25011964@postgrespro.ru", "phone": "+70400997505"}
0005435176770	925355	2517 279125	IGOR DENISOV	{"phone": "+70252752607"}
0005435176771	3EF209	0746 077161	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr03021974@postgrespro.ru", "phone": "+70000889421"}
0005435176772	79B92C	1914 203698	ALEKSANDR IVANOV	{"email": "ivanov-a_21111973@postgrespro.ru", "phone": "+70346465398"}
0005435176773	9ED5DA	5455 782052	VALENTINA ARKHIPOVA	{"email": "v_arkhipova1968@postgrespro.ru", "phone": "+70038539539"}
0005435176774	9ED5DA	6803 591519	KSENIYA DANILOVA	{"email": "danilovakseniya-1983@postgrespro.ru", "phone": "+70348100871"}
0005435176775	D7D781	4391 516979	VLADIMIR MIKHAYLOV	{"phone": "+70977926448"}
0005435176776	82F153	9348 445604	MARIYA POPOVA	{"email": "m-popova.121974@postgrespro.ru", "phone": "+70065642419"}
0005435176777	0B3559	3252 152862	VERA DMITRIEVA	{"phone": "+70246659529"}
0005435176778	0B3559	8871 123359	LYUBOV MIKHAYLOVA	{"phone": "+70788970178"}
0005435176779	3F8C75	4290 335092	VALENTINA FEDOROVA	{"email": "valentinafedorova-25091975@postgrespro.ru", "phone": "+70788953621"}
0005435176780	3F8C75	6593 185864	VLADIMIR ALEKSEEV	{"email": "alekseev_vladimir-26011960@postgrespro.ru", "phone": "+70976876727"}
0005435176781	F8C415	0280 797323	ZINAIDA LUKYANOVA	{"email": "lukyanova-z1983@postgrespro.ru", "phone": "+70343037506"}
0005435176782	F8C415	8091 641253	KSENIYA KUZMINA	{"phone": "+70233688387"}
0005435176783	BCD4F3	8734 075150	DARINA MATVEEVA	{"phone": "+70713740832"}
0005435176784	BCD4F3	7923 751365	GLEB AFANASEV	{"phone": "+70536233776"}
0005435176785	AB240C	2291 542190	DMITRIY MIKHAYLOV	{"email": "mikhaylov-d121973@postgrespro.ru", "phone": "+70184335070"}
0005435176786	AB240C	5608 063654	NINA YAKOVLEVA	{"email": "ninayakovleva.061974@postgrespro.ru", "phone": "+70843108156"}
0005435176787	88DFF8	3298 081665	ALSU PETROVA	{"phone": "+70852186267"}
0005435176788	C3BE7B	5253 169895	ANASTASIYA KONDRATEVA	{"email": "kondrateva_a.26121972@postgrespro.ru", "phone": "+70743378263"}
0005435176789	6449C7	9631 028693	IVAN ZHUKOV	{"email": "ivan.zhukov081972@postgrespro.ru", "phone": "+70813148749"}
0005435176790	32452F	0337 113757	DENIS IVANOV	{"phone": "+70090592320"}
0005435176791	50C17F	9746 452297	NADEZHDA KOVALEVA	{"phone": "+70675706837"}
0005435176792	50C17F	5350 264202	TATYANA AKIMOVA	{"email": "akimova.t-1963@postgrespro.ru", "phone": "+70084539109"}
0005435176793	94441D	6693 658044	DMITRIY IVANOV	{"email": "ivanovdmitriy29031974@postgrespro.ru", "phone": "+70087258359"}
0005435176794	94441D	0198 725240	ALEKSANDR NIKOLAEV	{"phone": "+70354625184"}
0005435176795	CC7641	8962 146328	EKATERINA NIKIFOROVA	{"phone": "+70489063578"}
0005435176796	6B06D3	5390 715595	LYUDMILA MAKAROVA	{"email": "makarova-lyudmila-19121966@postgrespro.ru", "phone": "+70926773434"}
0005435176797	6B06D3	8214 860071	VIKTOR MELNIKOV	{"phone": "+70407240564"}
0005435176798	A179F6	7231 865728	VALENTINA MIRONOVA	{"email": "mironova_valentina05081963@postgrespro.ru", "phone": "+70636406239"}
0005435176799	AE909A	7799 477958	IRINA NIKIFOROVA	{"email": "nikiforova_irina_021977@postgrespro.ru", "phone": "+70531635473"}
0005435176800	6DA6FA	3244 297251	VALENTINA NIKITINA	{"email": "valentina.nikitina_1960@postgrespro.ru", "phone": "+70573950647"}
0005435176801	6DA6FA	1644 525426	DMITRIY KUDRYASHOV	{"email": "kudryashovdmitriy-081974@postgrespro.ru", "phone": "+70741667239"}
0005435176802	D718B0	0192 784899	MAKSIM FEDOROV	{"phone": "+70469265202"}
0005435176803	D718B0	0296 912305	MARINA BORISOVA	{"email": "marina.borisova-04011972@postgrespro.ru", "phone": "+70209039880"}
0005435176804	8A7EDF	1399 582236	SERGEY GUSEV	{"phone": "+70801378161"}
0005435176805	01C0D1	1332 776401	NATALYA EGOROVA	{"email": "egorovan1969@postgrespro.ru", "phone": "+70640634066"}
0005435176806	01C0D1	1235 690303	EVGENIY BARANOV	{"email": "e.baranov-23061981@postgrespro.ru", "phone": "+70738794849"}
0005435176807	39451B	1488 081673	NATALYA FADEEVA	{"email": "fadeevan.1962@postgrespro.ru", "phone": "+70944348567"}
0005435176808	DBDD04	1038 883748	DMITRIY AFANASEV	{"email": "afanasev.d.29011960@postgrespro.ru", "phone": "+70763602023"}
0005435176809	30B787	7756 558903	NIKITA KUZMIN	{"email": "nikitakuzmin-19101975@postgrespro.ru", "phone": "+70343560797"}
0005435176810	4A8C95	7844 867976	IRINA PETROVA	{"phone": "+70817743239"}
0005435176811	E12414	7847 399835	ELENA NIKIFOROVA	{"email": "nikiforova-elena-111961@postgrespro.ru", "phone": "+70480077214"}
0005435176812	6FB27D	5545 340803	LARISA KAZAKOVA	{"phone": "+70886790973"}
0005435176813	5EDBCD	4407 120246	OKSANA ERMAKOVA	{"email": "ermakova.oksana-1962@postgrespro.ru", "phone": "+70753058356"}
0005435176814	CA6F4F	9432 115855	ALEKSANDR IVANOV	{"email": "ivanov_a_121980@postgrespro.ru", "phone": "+70064612652"}
0005435176815	45BF98	3259 303935	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov-011980@postgrespro.ru", "phone": "+70104453590"}
0005435176816	BE9069	2639 232805	YULIYA ZHUKOVA	{"email": "zhukovayuliya_1982@postgrespro.ru", "phone": "+70857523123"}
0005435176817	FB32EB	0381 445733	LYUDMILA SOROKINA	{"phone": "+70116555543"}
0005435176818	23A5D9	0483 279911	VALERIY STEPANOV	{"email": "valeriy.stepanov_011969@postgrespro.ru", "phone": "+70015468167"}
0005435176819	23A5D9	6859 470866	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova-anastasiya.121975@postgrespro.ru", "phone": "+70877983784"}
0005435176820	923C03	9073 160791	NELYA KOROLEVA	{"email": "koroleva-n20031964@postgrespro.ru", "phone": "+70110246297"}
0005435176821	AEA784	7431 743538	ARTEM KUZNECOV	{"phone": "+70051252506"}
0005435176822	C98567	3648 821470	RUMIYA VOROBEVA	{"email": "vorobeva.r_1966@postgrespro.ru", "phone": "+70361677874"}
0005435176823	C98567	4462 405285	LYUBOV PETROVA	{"email": "petrova.lyubov-31081981@postgrespro.ru", "phone": "+70483511804"}
0005435176824	286670	9882 042256	NADEZHDA NIKOLAEVA	{"email": "nikolaeva-nadezhda_031974@postgrespro.ru", "phone": "+70677872916"}
0005435176825	543892	5791 691776	SVETLANA KARPOVA	{"phone": "+70241761066"}
0005435176826	73217C	0123 542186	ELENA LEBEDEVA	{"phone": "+70252209272"}
0005435176827	262948	0294 584576	OLGA ALEKSANDROVA	{"phone": "+70049864101"}
0005435176828	BB7BA3	0917 034023	NATALYA POPOVA	{"phone": "+70450218905"}
0005435176829	BB7BA3	3337 025777	ALEKSEY ZHUKOV	{"email": "aleksey_zhukov04111971@postgrespro.ru", "phone": "+70019681523"}
0005435176830	AD7262	2610 246343	KAMIL SOLOVEV	{"email": "solovev_kamil1968@postgrespro.ru", "phone": "+70014511486"}
0005435176831	42719E	6271 393273	VLADIMIR BORISOV	{"phone": "+70057730140"}
0005435176832	8FF560	2399 003097	SERGEY KOZLOV	{"phone": "+70338593204"}
0005435176833	4580AC	9701 808801	ANNA ZHUKOVA	{"email": "anna.zhukova.21111985@postgrespro.ru", "phone": "+70557168039"}
0005435176834	8675D0	0977 077317	NINA ANDREEVA	{"email": "nina-andreeva-31101971@postgrespro.ru", "phone": "+70212631745"}
0005435176835	4CB807	0679 429867	RAVIL MIRONOV	{"email": "r_mironov-1975@postgrespro.ru", "phone": "+70650242250"}
0005435176836	A06157	3958 780681	KLAVDIYA GAVRILOVA	{"email": "kgavrilova091962@postgrespro.ru", "phone": "+70272275438"}
0005435176837	CF908C	5805 899179	NIKITA MEDVEDEV	{"phone": "+70942746930"}
0005435176838	14159D	2865 977508	NATALYA NESTEROVA	{"phone": "+70961769516"}
0005435176839	5228CD	5985 314473	IGNAT TIMOFEEV	{"phone": "+70863546843"}
0005435176840	5228CD	6401 222291	ANASTASIYA KOROLEVA	{"email": "anastasiya_koroleva22111962@postgrespro.ru", "phone": "+70643554326"}
0005435176841	027F24	2570 590082	ANTON KUDRYASHOV	{"email": "akudryashov.1978@postgrespro.ru", "phone": "+70057684912"}
0005435176842	027F24	1375 931571	DMITRIY KOZLOV	{"email": "kozlov_dmitriy1968@postgrespro.ru", "phone": "+70292550752"}
0005435176843	E8AAF9	8916 911106	ANDREY ZHURAVLEV	{"phone": "+70656183180"}
0005435176844	6E2B34	4700 354324	VLADIMIR ORLOV	{"email": "orlov_vladimir-17091972@postgrespro.ru", "phone": "+70429074150"}
0005435176845	07DDCD	8244 423712	EKATERINA VASILEVA	{"email": "e_vasileva.23041966@postgrespro.ru", "phone": "+70773084005"}
0005435176846	E42A69	1415 713522	TAMARA KOZLOVA	{"phone": "+70197580734"}
0005435176847	DAB25D	2798 545780	ROMAN SOROKIN	{"email": "sorokinr_20071976@postgrespro.ru", "phone": "+70230465547"}
0005435176848	1EFC9F	2511 749810	ANTON IVANOV	{"phone": "+70964435199"}
0005435176849	FAF5CA	6011 551630	SERGEY ANTONOV	{"email": "s_antonov121978@postgrespro.ru", "phone": "+70045817420"}
0005435176850	F693B4	1535 049974	SVETLANA IVANOVA	{"phone": "+70082913987"}
0005435176851	685DBE	3298 573833	LARISA MATVEEVA	{"email": "matveeva.larisa1968@postgrespro.ru", "phone": "+70895831447"}
0005435176852	44BABA	8544 851903	EVGENIYA YAKOVLEVA	{"email": "yakovlevaevgeniya.06081974@postgrespro.ru", "phone": "+70539697225"}
0005435176853	FC501C	4169 930161	VIKTORIYA EGOROVA	{"email": "egorovaviktoriya_1974@postgrespro.ru", "phone": "+70601016941"}
0005435176854	DAD3EA	7876 430465	ANATOLIY VASILEV	{"email": "vasilevanatoliy_05121966@postgrespro.ru", "phone": "+70482492815"}
0005435176855	D9E400	2761 909628	DANIIL MIKHAYLOV	{"phone": "+70619430600"}
0005435176856	99D065	8296 131609	MARINA EGOROVA	{"email": "marina.egorova121963@postgrespro.ru", "phone": "+70308791630"}
0005435176857	23DB9F	9754 458206	DMITRIY KRASNOV	{"phone": "+70513205310"}
0005435176858	B139DD	3558 606574	OLGA IVANOVA	{"email": "ivanova.olga_061971@postgrespro.ru", "phone": "+70151542923"}
0005435176859	B139DD	4055 379513	VLADISLAV KOROLEV	{"email": "v-korolev-25031976@postgrespro.ru", "phone": "+70709546988"}
0005435176860	AF8739	2644 770319	SVETLANA POTAPOVA	{"email": "potapovasvetlana-021970@postgrespro.ru", "phone": "+70418543963"}
0005435176861	732C2C	8955 242041	FEDOR KUZNECOV	{"email": "kuznecov_fedor-1963@postgrespro.ru", "phone": "+70837817832"}
0005435176862	732C2C	2810 282916	SERGEY YAKOVLEV	{"email": "syakovlev-061975@postgrespro.ru", "phone": "+70012561574"}
0005435176863	488E26	6171 635865	ALEKSEY SERGEEV	{"email": "sergeev.aleksey.11081967@postgrespro.ru", "phone": "+70246707742"}
0005435176864	488E26	7186 100931	NATALYA MELNIKOVA	{"email": "melnikova_natalya_16041968@postgrespro.ru", "phone": "+70139282849"}
0005435176865	212AAB	5572 293947	ELENA ROMANOVA	{"phone": "+70501363877"}
0005435176866	01AE35	1030 187729	SERGEY MATVEEV	{"email": "s-matveev.07081966@postgrespro.ru", "phone": "+70469765327"}
0005435176867	370560	8285 250950	ALEKSANDR ISAEV	{"email": "isaev.aleksandr071952@postgrespro.ru", "phone": "+70105405802"}
0005435176868	9FFE9A	5708 691686	ELENA SOROKINA	{"phone": "+70583438441"}
0005435176869	2F675F	0424 295206	NINA PETROVA	{"phone": "+70694856909"}
0005435176870	2F675F	4098 012577	DAMIR STEPANOV	{"email": "dstepanov051986@postgrespro.ru", "phone": "+70425573489"}
0005435176871	3B6A39	4147 091907	LYUDMILA TIMOFEEVA	{"email": "timofeeva.lyudmila_1979@postgrespro.ru", "phone": "+70731998397"}
0005435176872	3AA09E	1817 548656	LYUDMILA NOVIKOVA	{"email": "novikova.lyudmila_1970@postgrespro.ru", "phone": "+70139774621"}
0005435176873	3AA09E	2407 636208	ALEKSANDR POPOV	{"email": "popov.aleksandr1981@postgrespro.ru", "phone": "+70845919170"}
0005435176874	825AC2	8087 900766	OLGA IVANOVA	{"phone": "+70898407018"}
0005435176875	93EEDA	8439 544482	IRINA POPOVA	{"email": "irina-popova_13101960@postgrespro.ru", "phone": "+70624201525"}
0005435176876	C2E97D	2198 398440	SERGEY MIRONOV	{"email": "sergeymironov.061974@postgrespro.ru", "phone": "+70401715334"}
0005435176877	7BEBF3	5924 836814	ANDREY KOROLEV	{"phone": "+70058622304"}
0005435176878	69BF54	2176 391048	ALEKSANDRA NIKOLAEVA	{"email": "a-nikolaeva31081978@postgrespro.ru", "phone": "+70216335392"}
0005435176879	E34A98	7480 550998	VERA KRASNOVA	{"email": "v-krasnova_121972@postgrespro.ru", "phone": "+70044693161"}
0005435176880	E34A98	6939 016712	YURIY KRASNOV	{"email": "krasnov_y.1968@postgrespro.ru", "phone": "+70167047588"}
0005435176881	E34A98	3281 544921	GALINA VOLKOVA	{"email": "galina.volkova.30101970@postgrespro.ru", "phone": "+70483645622"}
0005435176882	CA0F7F	2325 242341	LYUDMILA NAZAROVA	{"email": "nazaroval-12091982@postgrespro.ru", "phone": "+70547248431"}
0005435176883	73EC62	8598 796045	ANATOLIY SOKOLOV	{"email": "sokolov-anatoliy_1970@postgrespro.ru", "phone": "+70468839735"}
0005435176884	73EC62	4880 627494	ELENA AKIMOVA	{"phone": "+70954512053"}
0005435176885	9A2AC6	3024 382560	ALINA KAZAKOVA	{"email": "kazakova-a.1967@postgrespro.ru", "phone": "+70526041659"}
0005435176886	C2C5F2	8529 036760	LYUBOV IVANOVA	{"phone": "+70820267993"}
0005435176887	C2C5F2	0748 624393	DMITRIY NOVIKOV	{"phone": "+70020545466"}
0005435176888	9537BD	3755 409886	TATYANA TIMOFEEVA	{"email": "timofeeva-t_101977@postgrespro.ru", "phone": "+70713760561"}
0005435176889	379C26	5888 533553	LYUDMILA ARKHIPOVA	{"email": "arkhipova.lyudmila.04081973@postgrespro.ru", "phone": "+70641816542"}
0005435176890	C8D630	0182 729886	LIDIYA MIKHAYLOVA	{"phone": "+70350362058"}
0005435176891	64E0DF	9190 325880	DENIS GRIGOREV	{"email": "grigorev_d-061971@postgrespro.ru", "phone": "+70118322860"}
0005435176892	78AC19	6021 443766	ALEKSANDRA POPOVA	{"email": "popova_aleksandra-17071976@postgrespro.ru", "phone": "+70244953821"}
0005435176893	17DDAA	0855 144638	PETR GAVRILOV	{"phone": "+70222639191"}
0005435176894	BE6199	4133 137123	STEPAN MOROZOV	{"email": "smorozov.1980@postgrespro.ru", "phone": "+70074499657"}
0005435176895	33903E	4424 142958	SERGEY NAZAROV	{"phone": "+70141689807"}
0005435176896	917120	6411 737190	VLADIMIR SIDOROV	{"email": "vsidorov-19031963@postgrespro.ru", "phone": "+70172611357"}
0005435176897	917120	2300 768636	SVETLANA LOGINOVA	{"email": "loginova.svetlana.16071977@postgrespro.ru", "phone": "+70147192272"}
0005435176898	917120	8616 582466	IRINA SOKOLOVA	{"email": "i_sokolova-081973@postgrespro.ru", "phone": "+70948341018"}
0005435176899	2CE616	8434 046743	NIKOLAY ZHURAVLEV	{"email": "nikolayzhuravlev_101984@postgrespro.ru", "phone": "+70818067693"}
0005435176900	2CE616	7745 133353	ALEKSANDR KUZNECOV	{"phone": "+70279212475"}
0005435176901	1B2607	6878 881316	VALENTINA ALEKSANDROVA	{"email": "v_aleksandrova.101975@postgrespro.ru", "phone": "+70100600855"}
0005435176902	84366D	5682 995756	MARIYA VLASOVA	{"phone": "+70321442629"}
0005435176903	16F5B4	7130 976644	TAMARA KULIKOVA	{"phone": "+70546292007"}
0005435176904	16F5B4	6619 661203	IRINA KUZNECOVA	{"email": "i-kuznecova_1965@postgrespro.ru", "phone": "+70134713346"}
0005435176905	3583F2	4673 668008	ANGELINA BARANOVA	{"email": "a_baranova-1961@postgrespro.ru", "phone": "+70625855472"}
0005435176906	3583F2	0712 810065	OKSANA TIKHONOVA	{"phone": "+70689022142"}
0005435176907	209288	6139 592364	EVGENIYA BELOVA	{"phone": "+70396854459"}
0005435176908	3E5919	5089 386983	YAROSLAV KUZNECOV	{"email": "kuznecovyaroslav.28121970@postgrespro.ru", "phone": "+70195664453"}
0005435176909	3E5919	7954 303181	VLADISLAV SEMENOV	{"email": "v-semenov.11091964@postgrespro.ru", "phone": "+70110105820"}
0005435176910	93AFEA	7809 784430	ZINAIDA LEBEDEVA	{"email": "z.lebedeva-021976@postgrespro.ru", "phone": "+70273603219"}
0005435176911	5D799E	1941 638742	LILIYA NESTEROVA	{"email": "liliyanesterova_1977@postgrespro.ru", "phone": "+70842349745"}
0005435176912	2F77B9	9934 059424	OLGA FEDOROVA	{"phone": "+70271451105"}
0005435176913	B90732	1682 971461	PETR KOROLEV	{"email": "korolev-p-15091978@postgrespro.ru", "phone": "+70894657731"}
0005435176914	F55DE3	6787 406884	MARIYA LEBEDEVA	{"phone": "+70341148461"}
0005435176915	F55DE3	1976 169833	RINAT MOISEEV	{"phone": "+70008346718"}
0005435176916	F55DE3	2359 969387	DENIS KUZMIN	{"phone": "+70510703185"}
0005435176917	91B365	1439 121682	YULIYA MOROZOVA	{"phone": "+70130654556"}
0005435176918	94B508	1450 926612	ANDREY KRASNOV	{"email": "akrasnov1974@postgrespro.ru", "phone": "+70725817092"}
0005435176919	94B508	4556 361491	RAMIS SCHERBAKOV	{"email": "ramis_scherbakov.121973@postgrespro.ru", "phone": "+70331893873"}
0005435176920	1F88E3	3217 327072	ALEKSEY ANDREEV	{"phone": "+70184306949"}
0005435176921	1F88E3	8699 696395	ANTON KOZLOV	{"email": "kozlov-anton.011961@postgrespro.ru", "phone": "+70789424744"}
0005435176922	E7ECC9	2171 098741	VIKTOR SHEVCHENKO	{"email": "viktor_shevchenko-061979@postgrespro.ru", "phone": "+70898735340"}
0005435176923	511863	1514 644402	OLEG YAKOVLEV	{"email": "yakovlev_o_1986@postgrespro.ru", "phone": "+70067364664"}
0005435176924	511863	3754 825731	MARGARITA ANTONOVA	{"email": "m-antonova-1981@postgrespro.ru", "phone": "+70600026697"}
0005435176925	F1A4DB	9047 672419	KSENIYA VOROBEVA	{"email": "vorobeva-k-01071958@postgrespro.ru", "phone": "+70118159027"}
0005435176926	789186	6882 668175	GENNADIY MOROZOV	{"email": "g.morozov22091975@postgrespro.ru", "phone": "+70864197720"}
0005435176927	789186	0673 187038	YULIYA GUSEVA	{"email": "guseva-yuliya.03081966@postgrespro.ru", "phone": "+70222875770"}
0005435176928	C28CEF	1838 300399	SERGEY SEMENOV	{"email": "semenov_s-1969@postgrespro.ru", "phone": "+70617080753"}
0005435176929	8F9A0C	5540 274318	VLADIMIR ABRAMOV	{"email": "abramovv.03051964@postgrespro.ru", "phone": "+70200052411"}
0005435176930	328CF4	2573 316830	ANGELINA SIDOROVA	{"email": "angelina.sidorova.091968@postgrespro.ru", "phone": "+70136870859"}
0005435176931	814C52	5229 141192	YURIY GAVRILOV	{"phone": "+70940426857"}
0005435176932	A0961D	2685 473925	TATYANA LAZAREVA	{"email": "lazareva-t-14101971@postgrespro.ru", "phone": "+70923672119"}
0005435176933	A0961D	9153 255677	MARIYA VASILEVA	{"phone": "+70318263327"}
0005435176934	298B8D	3665 266026	SVETLANA SAVELEVA	{"phone": "+70048667322"}
0005435176935	CD084D	3958 549469	OLGA STEPANOVA	{"email": "o-stepanova.021977@postgrespro.ru", "phone": "+70737842748"}
0005435176936	5D52EE	6837 918532	NATALIYA DAVYDOVA	{"email": "nataliyadavydova17031968@postgrespro.ru", "phone": "+70563244298"}
0005435176937	036B29	2433 072939	ANDREY CHERNOV	{"email": "chernov_andrey.12101974@postgrespro.ru", "phone": "+70252965262"}
0005435176938	D5049F	5709 183531	ANASTASIYA DENISOVA	{"email": "denisova_anastasiya08041971@postgrespro.ru", "phone": "+70214090631"}
0005435176939	F31190	0447 241598	ANASTASIYA IVANOVA	{"phone": "+70576499014"}
0005435176940	E6F85E	6250 582160	TAMARA KARPOVA	{"phone": "+70045755153"}
0005435176941	90C52E	1531 072485	ALIYA KARPOVA	{"phone": "+70357514011"}
0005435176942	90C52E	6263 998407	NIKITA BARANOV	{"phone": "+70840143863"}
0005435176943	284EA0	2485 206609	SERGEY ABRAMOV	{"email": "sabramov1966@postgrespro.ru", "phone": "+70889736261"}
0005435176944	284EA0	7924 122638	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov_051968@postgrespro.ru", "phone": "+70035194984"}
0005435176945	CBCA29	0369 649104	NADEZHDA ARKHIPOVA	{"phone": "+70403240454"}
0005435176946	CBCA29	1829 995537	ALEKSANDRA GRISHINA	{"email": "a-grishina1969@postgrespro.ru", "phone": "+70001561045"}
0005435176947	6958F2	3448 675564	LYUDMILA PETROVA	{"email": "lyudmilapetrova.26101967@postgrespro.ru", "phone": "+70616812205"}
0005435176948	6958F2	2905 340164	KSENIYA ORLOVA	{"email": "kseniyaorlova.09071966@postgrespro.ru", "phone": "+70263633713"}
0005435176949	6958F2	6056 458028	ANASTASIYA POPOVA	{"phone": "+70110340497"}
0005435176950	717116	6153 376225	ANASTASIYA AFANASEVA	{"email": "afanasevaanastasiya.04041973@postgrespro.ru", "phone": "+70264389967"}
0005435176951	FE1EE3	3647 012420	VLADIMIR IVANOV	{"phone": "+70808516927"}
0005435176952	F09D24	7105 439317	ELENA ZAYCEVA	{"email": "elena_zayceva_1983@postgrespro.ru", "phone": "+70015823047"}
0005435176953	9492FB	9531 277023	ALEKSEY MEDVEDEV	{"email": "alekseymedvedev_091969@postgrespro.ru", "phone": "+70286237011"}
0005435176954	2D155B	8424 408694	PETR OSIPOV	{"email": "posipov.121977@postgrespro.ru", "phone": "+70408611158"}
0005435176955	AC1C63	6832 056243	SERGEY SCHERBAKOV	{"email": "sscherbakov.1970@postgrespro.ru", "phone": "+70101620992"}
0005435176956	E1E522	1321 570832	OLGA ISAEVA	{"phone": "+70722455800"}
0005435176957	D7BDC7	0978 359255	ANDREY NIKOLAEV	{"email": "nikolaev_a.01061973@postgrespro.ru", "phone": "+70406945266"}
0005435176958	D7BDC7	6268 644442	DARYA TARASOVA	{"phone": "+70312657863"}
0005435176959	E5DFF9	6415 807436	GAGIK SCHERBAKOV	{"email": "scherbakov.g_1975@postgrespro.ru", "phone": "+70065057563"}
0005435176960	6717CE	0692 362584	DENIS PAVLOV	{"email": "pavlovdenis011974@postgrespro.ru", "phone": "+70856356329"}
0005435176961	6717CE	2961 619732	ALEKSANDR EGOROV	{"email": "aleksandregorov30011976@postgrespro.ru", "phone": "+70979773459"}
0005435176962	AEEB8A	1158 390435	NIKOLAY CHERNOV	{"email": "n_chernov_071974@postgrespro.ru", "phone": "+70325124145"}
0005435176963	7AEC88	7364 087142	LIDIYA RODIONOVA	{"email": "rodionova_l-29081983@postgrespro.ru", "phone": "+70220097977"}
0005435176964	7AEC88	4226 938973	GERMAN SMIRNOV	{"email": "g.smirnov-1971@postgrespro.ru", "phone": "+70291940096"}
0005435176965	E1DC3C	8710 910991	LYUBOV PETROVA	{"email": "l.petrova-081974@postgrespro.ru", "phone": "+70311235779"}
0005435176966	E1DC3C	7323 499158	TATYANA KOZLOVA	{"phone": "+70353733891"}
0005435176967	9C99E6	4838 443933	ALEKSANDRA MATVEEVA	{"email": "matveeva_aleksandra_1974@postgrespro.ru", "phone": "+70216114690"}
0005435176968	9C99E6	9422 787999	OLESYA ILINA	{"phone": "+70623920664"}
0005435176969	E8B04F	0269 387461	YURIY STEPANOV	{"email": "y.stepanov_121973@postgrespro.ru", "phone": "+70186968646"}
0005435176970	E8B04F	0576 977331	DMITRIY CHERNOV	{"phone": "+70472754754"}
0005435176971	896CDA	5353 838577	MIKHAIL DMITRIEV	{"phone": "+70121817072"}
0005435176972	05E3FF	0084 872410	VIKTORIYA TIKHONOVA	{"phone": "+70305405553"}
0005435176973	C2FDA6	3260 114667	SERGEY MOISEEV	{"email": "moiseev.sergey-14031965@postgrespro.ru", "phone": "+70053386524"}
0005435176974	C2FDA6	4746 242446	OLGA FILIPPOVA	{"email": "filippova-o.24101969@postgrespro.ru", "phone": "+70890264552"}
0005435176975	7027E1	1419 208639	ALEKSEY EGOROV	{"email": "egorov-aleksey_081978@postgrespro.ru", "phone": "+70887656097"}
0005435176976	7027E1	5701 960039	NATALYA DENISOVA	{"email": "denisova_n_22121979@postgrespro.ru", "phone": "+70487052559"}
0005435176977	57E361	8358 057192	EKATERINA NOVIKOVA	{"email": "ekaterina.novikova.051970@postgrespro.ru", "phone": "+70176226551"}
0005435176978	57E361	6501 581410	ALEKSEY KUZMIN	{"phone": "+70632674844"}
0005435176979	57E361	7324 752299	VITALIY IVANOV	{"email": "ivanovvitaliy.1963@postgrespro.ru", "phone": "+70349035250"}
0005435176980	BE95F7	3319 589835	EVGENIY ZHURAVLEV	{"phone": "+70667009428"}
0005435176981	BE95F7	8802 371683	NIKOLAY PAVLOV	{"email": "pavlov-n_1969@postgrespro.ru", "phone": "+70731649892"}
0005435176982	F82CB8	1092 922901	SVETLANA TIMOFEEVA	{"email": "timofeeva-svetlana.101966@postgrespro.ru", "phone": "+70387732217"}
0005435176983	F82CB8	9032 113508	INNA MARTYNOVA	{"email": "i-martynova_031977@postgrespro.ru", "phone": "+70819509673"}
0005435176984	206DC3	6502 593369	NATALYA ARKHIPOVA	{"phone": "+70570128669"}
0005435176985	206DC3	9175 862019	ANTONINA AKIMOVA	{"email": "antoninaakimova.111971@postgrespro.ru", "phone": "+70434246065"}
0005435176986	206DC3	2849 316250	VIKTOR SHEVCHENKO	{"email": "shevchenko-viktor_19091973@postgrespro.ru", "phone": "+70061887537"}
0005435176987	206DC3	4720 510768	VALENTINA YUDINA	{"email": "v-yudina.061977@postgrespro.ru", "phone": "+70591652423"}
0005435176988	FD6401	4703 123380	PETR MEDVEDEV	{"phone": "+70154366952"}
0005435176989	773BA4	3916 661542	SERGEY BORISOV	{"phone": "+70613346671"}
0005435176990	773BA4	5510 687725	MARIYA POTAPOVA	{"email": "potapova.mariya-12021974@postgrespro.ru", "phone": "+70052922783"}
0005435176991	16CAF3	7070 012100	ARINA VASILEVA	{"phone": "+70358621666"}
0005435176992	4D7737	5448 384475	TATYANA KUZNECOVA	{"email": "kuznecovat1970@postgrespro.ru", "phone": "+70274083508"}
0005435176993	4D7737	0624 279224	ALEKSEY NOVIKOV	{"email": "novikov_aleksey.031973@postgrespro.ru", "phone": "+70029861219"}
0005435176994	4D7737	1917 522229	TALGAT PAVLOV	{"email": "pavlov_talgat_1969@postgrespro.ru", "phone": "+70055519031"}
0005435176995	D9533E	2730 272895	SOFYA IVANOVA	{"email": "sofya_ivanova.011966@postgrespro.ru", "phone": "+70211531675"}
0005435176996	D9533E	6241 540784	ALEKSANDR RODIONOV	{"email": "a.rodionov-1964@postgrespro.ru", "phone": "+70151276347"}
0005435176997	32EA61	5403 424863	TAMARA ZHUKOVA	{"phone": "+70345481610"}
0005435176998	172CC6	5873 190879	IGOR ALEKSEEV	{"phone": "+70594562607"}
0005435176999	7CCCBE	4450 091339	IGOR PETROV	{"phone": "+70776134257"}
0005435177000	7CCCBE	1957 302251	VALENTINA MIKHAYLOVA	{"phone": "+70760745935"}
0005435177001	D7A8E4	8211 772687	NIKOLAY MIRONOV	{"phone": "+70182367914"}
0005435177002	5699FA	3887 098878	ALEKSEY KOZLOV	{"email": "aleksey-kozlov_18021974@postgrespro.ru", "phone": "+70655077511"}
0005435177003	B6188A	4250 592361	NATALYA VOROBEVA	{"email": "vorobeva_n011970@postgrespro.ru", "phone": "+70944626046"}
0005435177004	B6188A	0652 176524	LYUDMILA SIDOROVA	{"phone": "+70781970013"}
0005435177005	717B40	4149 762187	DMITRIY ILIN	{"phone": "+70312551986"}
0005435177006	717B40	6288 631420	GALINA TITOVA	{"email": "galina-titova-1982@postgrespro.ru", "phone": "+70089864037"}
0005435177007	A9BE30	3763 943045	VLADIMIR ANDREEV	{"phone": "+70617335301"}
0005435177008	3D918D	3884 822859	ALEKSEY KOROLEV	{"email": "aleksey_korolev_26041978@postgrespro.ru", "phone": "+70512345417"}
0005435177009	D81B89	5752 218595	ELENA ANTONOVA	{"email": "eantonova06101964@postgrespro.ru", "phone": "+70614233788"}
0005435177010	EE215F	2597 682465	NATALYA ERMAKOVA	{"email": "ermakova.n-24071980@postgrespro.ru", "phone": "+70293268289"}
0005435177011	99E6CA	1373 694118	DMITRIY FOMIN	{"phone": "+70004294192"}
0005435177012	A2CC3F	3025 314530	TATYANA LOGINOVA	{"phone": "+70632701571"}
0005435177013	8B43B5	1391 830235	NADEZHDA NAZAROVA	{"phone": "+70060548154"}
0005435177014	4B5964	2352 886631	ALEKSANDR PAVLOV	{"phone": "+70749392717"}
0005435177015	4B5964	2361 996361	VLADIMIR IVANOV	{"email": "v.ivanov_13041980@postgrespro.ru", "phone": "+70694101990"}
0005435177016	694C4E	9209 271870	TAISIYA IVANOVA	{"email": "ivanova-taisiya_18031983@postgrespro.ru", "phone": "+70038362068"}
0005435177017	3E8CE6	3299 752937	ALEKSANDR PETROV	{"phone": "+70626037020"}
0005435177018	3E8CE6	2465 177501	VADIM GERASIMOV	{"phone": "+70946478617"}
0005435177019	25316C	1978 039368	PETR CHERNOV	{"email": "p_chernov_16091975@postgrespro.ru", "phone": "+70297036092"}
0005435177020	25316C	3740 960260	DINA IVANOVA	{"email": "d.ivanova_1959@postgrespro.ru", "phone": "+70032336424"}
0005435177021	E61D0A	9036 982466	LIDIYA BARANOVA	{"email": "l-baranova.031975@postgrespro.ru", "phone": "+70786062530"}
0005435177022	E61D0A	5915 811959	ANASTASIYA KOROLEVA	{"phone": "+70434328077"}
0005435177023	905456	2613 683314	TATYANA MOISEEVA	{"phone": "+70386982297"}
0005435177024	ACB88A	1207 659023	VALERIY NAZAROV	{"email": "valeriy.nazarov121979@postgrespro.ru", "phone": "+70261777190"}
0005435177025	ACB88A	6775 960860	TAMARA IVANOVA	{"phone": "+70696621944"}
0005435177026	21AE6E	9650 384552	VYACHESLAV KOZLOV	{"email": "v_kozlov.01101966@postgrespro.ru", "phone": "+70265675673"}
0005435177027	173DB1	4617 494481	ALEKSEY DENISOV	{"phone": "+70006939530"}
0005435177028	173DB1	5771 792581	EGOR MEDVEDEV	{"phone": "+70978067299"}
0005435177029	351C1E	2048 886665	OLEG DENISOV	{"email": "oleg.denisov.23101977@postgrespro.ru", "phone": "+70900930263"}
0005435177030	6BE1BB	0137 613577	IVAN TIMOFEEV	{"email": "i-timofeev011969@postgrespro.ru", "phone": "+70805731339"}
0005435177031	6BE1BB	3284 216240	TATYANA TARASOVA	{"phone": "+70199166229"}
0005435177032	3BF737	7909 998102	NATALYA IVANOVA	{"phone": "+70428165433"}
0005435177033	779CEB	5073 802788	VADIM BORISOV	{"phone": "+70495346400"}
0005435177034	FE0A24	6923 210594	LYUBOV MIKHAYLOVA	{"email": "mikhaylova-lyubov22041985@postgrespro.ru", "phone": "+70256242427"}
0005435177035	BDCB21	0530 657073	VALENTINA PETROVA	{"phone": "+70021482589"}
0005435177036	BDCB21	2702 700780	VITALIY IVANOV	{"email": "vitaliy.ivanov1974@postgrespro.ru", "phone": "+70656681732"}
0005435177037	D1474D	9915 370060	KIRILL GAVRILOV	{"phone": "+70463259311"}
0005435177038	D1474D	3627 118890	ANASTASIYA LUKYANOVA	{"phone": "+70152308019"}
0005435177039	B2D73E	0405 978659	LYUDMILA KUZMINA	{"email": "kuzmina.l031970@postgrespro.ru", "phone": "+70907196517"}
0005435177040	B2D73E	1328 935298	VERA KUZMINA	{"phone": "+70792931993"}
0005435177041	B2D73E	3894 260204	DENIS ILIN	{"phone": "+70968423198"}
0005435177042	A09B06	6777 210294	POLINA LUKYANOVA	{"phone": "+70594798230"}
0005435177043	05B66B	7364 486188	TIMUR NAZAROV	{"email": "nazarov.t-1975@postgrespro.ru", "phone": "+70358496000"}
0005435177044	0F19CF	1442 447857	VLADIMIR IVANOV	{"phone": "+70339050930"}
0005435177045	C9E8B2	4046 230825	ALEKSANDR GAVRILOV	{"email": "gavrilov.a-111974@postgrespro.ru", "phone": "+70596430137"}
0005435177046	C9E8B2	2574 967468	IVAN ALEKSEEV	{"phone": "+70028261268"}
0005435177047	E07785	7926 111044	VALERIY NIKOLAEV	{"email": "nikolaevv_081972@postgrespro.ru", "phone": "+70586689341"}
0005435177048	E07785	0883 446941	VIKTOR KONOVALOV	{"email": "konovalov.viktor_24091971@postgrespro.ru", "phone": "+70185315971"}
0005435177049	E07785	6452 645931	MAKSIM KUZNECOV	{"email": "kuznecov.maksim.1979@postgrespro.ru", "phone": "+70373913339"}
0005435177050	CFAD35	7271 332671	NIKOLAY SAVELEV	{"phone": "+70248607197"}
0005435177051	8D4B8F	1281 806388	ZAKHAR MAKSIMOV	{"email": "zakhar-maksimov-20041965@postgrespro.ru", "phone": "+70065841465"}
0005435177052	AF59FE	9870 274892	MARIYA GAVRILOVA	{"phone": "+70075567454"}
0005435177053	AF59FE	2576 479857	NATALIYA KARPOVA	{"email": "n_karpova.1968@postgrespro.ru", "phone": "+70181501541"}
0005435177054	82FCEC	5582 080597	NURIYA ALEKSANDROVA	{"email": "aleksandrova_nuriya-031964@postgrespro.ru", "phone": "+70684653236"}
0005435177055	82FCEC	1937 230819	NIKOLAY VOLKOV	{"phone": "+70019228041"}
0005435177056	DF1E75	4786 893696	YURIY BELOV	{"email": "belov-y051972@postgrespro.ru", "phone": "+70638730803"}
0005435177057	D0A06C	5099 760620	OKSANA IVANOVA	{"email": "oksana.ivanova.1967@postgrespro.ru", "phone": "+70896731981"}
0005435177058	8AAF0E	5724 192136	LYUDMILA BORISOVA	{"email": "l_borisova_1964@postgrespro.ru", "phone": "+70711981828"}
0005435177059	E41ADC	7138 824600	NIKOLAY KUZNECOV	{"phone": "+70481891600"}
0005435177060	3C1381	6753 749785	VIKTOR ZHUKOV	{"phone": "+70057545882"}
0005435177061	A7E231	2309 916331	ALEKSANDR BELOV	{"email": "a-belov-081968@postgrespro.ru", "phone": "+70795091955"}
0005435177062	5E6842	0172 729248	ZOYA POPOVA	{"email": "popova_zoya101974@postgrespro.ru", "phone": "+70895923450"}
0005435177063	CCE8A8	6830 531213	VYACHESLAV SEMENOV	{"email": "v-semenov.22011965@postgrespro.ru", "phone": "+70155384375"}
0005435177064	CCE8A8	7092 139799	RUFINA IVANOVA	{"email": "ivanova-rufina_20101963@postgrespro.ru", "phone": "+70050222504"}
0005435177065	F48CCA	7159 712236	TAMARA NESTEROVA	{"phone": "+70024278565"}
0005435177066	E8D8E2	7954 129528	SVETLANA MOROZOVA	{"phone": "+70106702510"}
0005435177067	490CA0	8684 756797	ALEKSANDR VOROBEV	{"email": "vorobev_a.031971@postgrespro.ru", "phone": "+70882091428"}
0005435177068	59F6BA	7406 843221	VITALIY BELOV	{"email": "vitaliy.belov_1990@postgrespro.ru", "phone": "+70748338982"}
0005435177069	DCF372	3408 464824	NADEZHDA KOVALEVA	{"phone": "+70593291484"}
0005435177070	DCF372	7514 169693	IRINA NAZAROVA	{"email": "irina-nazarova03031965@postgrespro.ru", "phone": "+70713827025"}
0005435177071	DCF372	3200 019697	ALEKSANDR PETROV	{"phone": "+70883580081"}
0005435177072	7AD22A	4860 209239	VALENTINA BOGDANOVA	{"email": "v.bogdanova21071971@postgrespro.ru", "phone": "+70027553772"}
0005435177073	3DD8FB	7621 069115	ELENA FILIPPOVA	{"email": "filippovae.1979@postgrespro.ru", "phone": "+70398164462"}
0005435177074	D68863	0995 996321	LYUDMILA SAVELEVA	{"phone": "+70515735683"}
0005435177075	B023D4	1210 796780	OLEG SEMENOV	{"phone": "+70792661551"}
0005435177076	D2697B	2186 967377	OLEG KONOVALOV	{"email": "konovalov.o.111965@postgrespro.ru", "phone": "+70799813041"}
0005435177077	E0358D	8533 820043	TATYANA YAKOVLEVA	{"email": "tatyana_yakovleva-1971@postgrespro.ru", "phone": "+70046995545"}
0005435177078	E0358D	0292 784381	VLADIMIR SCHERBAKOV	{"email": "scherbakovv.1964@postgrespro.ru", "phone": "+70849643060"}
0005435177079	E0358D	6432 164110	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir-07091982@postgrespro.ru", "phone": "+70665955797"}
0005435177080	F3B268	5942 809587	OLEG PAVLOV	{"email": "oleg.pavlov.1971@postgrespro.ru", "phone": "+70643572555"}
0005435177081	24BA6D	7185 479817	EVGENIYA FILATOVA	{"phone": "+70838551987"}
0005435177082	24BA6D	1355 100366	NADEZHDA BOGDANOVA	{"email": "n-bogdanova.021981@postgrespro.ru", "phone": "+70416994704"}
0005435177083	1E9CE5	5089 130109	VYACHESLAV ILIN	{"email": "ilin-vyacheslav_021965@postgrespro.ru", "phone": "+70003134227"}
0005435177084	F149ED	3738 442634	SERGEY GUSEV	{"email": "gusev_s06061980@postgrespro.ru", "phone": "+70419983489"}
0005435177085	F149ED	7155 509138	LILIYA ZAYCEVA	{"phone": "+70356308740"}
0005435177086	F149ED	6956 510475	OLGA EGOROVA	{"email": "egorova.olga_1978@postgrespro.ru", "phone": "+70235623028"}
0005435177087	A66C91	8604 237068	NADEZHDA MOROZOVA	{"email": "morozova_nadezhda-121979@postgrespro.ru", "phone": "+70654832785"}
0005435177088	EE220B	6123 903274	MARINA ANISIMOVA	{"phone": "+70920190686"}
0005435177089	19725A	5104 545428	EKATERINA CHERNOVA	{"phone": "+70471967704"}
0005435177090	CFF19D	3867 311601	MARGARITA KRASNOVA	{"phone": "+70966008100"}
0005435177091	DA43F4	1629 419593	POLINA STEPANOVA	{"email": "p_stepanova.05071964@postgrespro.ru", "phone": "+70098576671"}
0005435177092	6049B4	5765 460235	IVAN FEDOROV	{"email": "fedorov-i-1969@postgrespro.ru", "phone": "+70858573266"}
0005435177093	6049B4	8180 382661	DMITRIY IVANOV	{"email": "dmitriy-ivanov-29051973@postgrespro.ru", "phone": "+70217039810"}
0005435177094	D1C387	4953 231956	ANTONINA ALEKSEEVA	{"email": "alekseeva-antonina_1974@postgrespro.ru", "phone": "+70684581036"}
0005435177095	1C64A1	8062 937650	OLEG KOZLOV	{"email": "kozlov-oleg_1990@postgrespro.ru", "phone": "+70884559834"}
0005435177096	1C64A1	4759 399936	NATALYA TITOVA	{"email": "natalya.titova-051973@postgrespro.ru", "phone": "+70904586831"}
0005435177097	F4C0CB	8888 274164	KIRILL TIMOFEEV	{"email": "timofeev-kirill091964@postgrespro.ru", "phone": "+70086481966"}
0005435177098	7DA2F6	8763 307861	MARINA BOGDANOVA	{"phone": "+70579301625"}
0005435177099	7DA2F6	9795 589870	ROMAN PETROV	{"email": "petrov_roman_1968@postgrespro.ru", "phone": "+70942221559"}
0005435177100	F9C2F2	4800 368676	FEDOR ANDREEV	{"email": "andreev-f_1964@postgrespro.ru", "phone": "+70898354547"}
0005435177101	F9C2F2	0217 494554	ANATOLIY EGOROV	{"email": "egorov.anatoliy_06041981@postgrespro.ru", "phone": "+70513363997"}
0005435177102	3FED86	9596 211361	LARISA SOROKINA	{"phone": "+70037145575"}
0005435177103	1FC837	3026 303133	ANTON POPOV	{"phone": "+70507835419"}
0005435177104	2A4D14	8571 367355	ANDREY BELOV	{"email": "belov-a.21051971@postgrespro.ru", "phone": "+70541767135"}
0005435177105	AF9E20	4675 948559	EDUARD KUZMIN	{"email": "e.kuzmin_1974@postgrespro.ru", "phone": "+70645759310"}
0005435177106	A11671	3370 771240	ANNA DMITRIEVA	{"email": "anna.dmitrieva-08071984@postgrespro.ru", "phone": "+70704953585"}
0005435177107	BE69B5	0895 727878	RAFAEL SIDOROV	{"email": "sidorov.rafael-1972@postgrespro.ru", "phone": "+70266774762"}
0005435177108	6FF108	8482 958607	SVETLANA KOROLEVA	{"phone": "+70623979885"}
0005435177109	3809EF	0994 228281	ANATOLIY BORISOV	{"email": "borisov.a.101981@postgrespro.ru", "phone": "+70656864944"}
0005435177110	E49EE3	6779 917218	VITALIY VASILEV	{"email": "vasilev.v-07041974@postgrespro.ru", "phone": "+70766015974"}
0005435177111	F6B3C9	9701 050849	RAISA ZHUKOVA	{"email": "raisa_zhukova-07021980@postgrespro.ru", "phone": "+70835894699"}
0005435177112	CE019E	0730 478218	VALENTINA LAZAREVA	{"phone": "+70984409691"}
0005435177113	CE019E	5841 234451	DENIS KUZNECOV	{"email": "kuznecov-denis1966@postgrespro.ru", "phone": "+70887348966"}
0005435177114	051B02	1685 305760	ANATOLIY YAKOVLEV	{"phone": "+70118479200"}
0005435177115	127EF2	1072 611706	ELENA ZAKHAROVA	{"phone": "+70686866786"}
0005435177116	26F5D2	8694 998305	VLADIMIR MOISEEV	{"email": "vladimir-moiseev121965@postgrespro.ru", "phone": "+70872893667"}
0005435177117	717EC4	0774 268764	TATYANA BORISOVA	{"email": "borisova_tatyana1971@postgrespro.ru", "phone": "+70965955691"}
0005435177118	540358	9356 675275	ANDREY STEPANOV	{"phone": "+70804615703"}
0005435177119	35DAE9	6820 757206	VALENTINA VLASOVA	{"email": "valentinavlasova_1977@postgrespro.ru", "phone": "+70625659571"}
0005435177120	1A7C38	2923 259033	SERGEY ANTONOV	{"email": "sergey.antonov_15081968@postgrespro.ru", "phone": "+70506291155"}
0005435177121	1A7C38	8540 095015	NAIL ORLOV	{"phone": "+70547192823"}
0005435177122	48E03D	7571 359300	ANDREY POPOV	{"email": "andrey-popov-021977@postgrespro.ru", "phone": "+70944991325"}
0005435177123	C5BD67	8493 974706	SVETLANA NIKOLAEVA	{"email": "s-nikolaeva_1962@postgrespro.ru", "phone": "+70876700746"}
0005435177124	BCFF51	5283 461470	MIKHAIL ISAEV	{"email": "m.isaev-1974@postgrespro.ru", "phone": "+70462088191"}
0005435177125	C80788	5976 769666	OLGA POPOVA	{"phone": "+70927483232"}
0005435177126	A0B099	2337 915897	EGOR KUDRYASHOV	{"phone": "+70956696014"}
0005435177127	B8EC82	5593 118459	ELENA ZAKHAROVA	{"email": "zakharova-e.1978@postgrespro.ru", "phone": "+70921110361"}
0005435177128	B8EC82	7400 477102	GALINA KULIKOVA	{"email": "g-kulikova-1974@postgrespro.ru", "phone": "+70924518085"}
0005435177129	C531C2	4255 122211	ALEKSEY KULIKOV	{"email": "aleksey-kulikov1979@postgrespro.ru", "phone": "+70566169446"}
0005435177130	C531C2	5588 211508	TATYANA ZOTOVA	{"email": "zotovatatyana.14091969@postgrespro.ru", "phone": "+70479006616"}
0005435177131	9429A5	0402 062843	ELENA GORBUNOVA	{"phone": "+70634415725"}
0005435177132	9429A5	2582 796799	ALLA KOZLOVA	{"phone": "+70728675763"}
0005435177133	9429A5	4382 929632	ALEKSANDR CHERNOV	{"phone": "+70120535552"}
0005435177134	1BC357	4046 618373	SVETLANA KUZNECOVA	{"phone": "+70573373873"}
0005435177135	7910C9	3561 820311	DENIS SOKOLOV	{"phone": "+70569851659"}
0005435177136	25B0F4	1630 968194	TATYANA ZOTOVA	{"email": "tatyana-zotova-1970@postgrespro.ru", "phone": "+70520638920"}
0005435177137	8802C1	6722 820513	VLADIMIR ANTONOV	{"phone": "+70335532767"}
0005435177138	DDEF55	3182 230759	MIKHAIL DAVYDOV	{"phone": "+70124895827"}
0005435177139	003096	7217 379164	VALERIY IVANOV	{"email": "v_ivanov-27091971@postgrespro.ru", "phone": "+70334536370"}
0005435177140	003096	3084 150099	DINARA KOVALEVA	{"phone": "+70216842977"}
0005435177141	FDC677	8959 620523	EDGAR SOROKIN	{"email": "e_sorokin_1974@postgrespro.ru", "phone": "+70633845963"}
0005435177142	DE5058	7148 370197	VLADIMIR TIMOFEEV	{"phone": "+70069545791"}
0005435177143	BE6166	7051 201643	ELENA FADEEVA	{"email": "e.fadeeva1980@postgrespro.ru", "phone": "+70447740021"}
0005435177144	BE6166	4688 807510	VIKTOR ANDREEV	{"email": "andreev-v24051971@postgrespro.ru", "phone": "+70774365949"}
0005435177145	E5ACEE	5561 602448	ALEKSANDR KOZLOV	{"phone": "+70894209848"}
0005435177146	E5ACEE	3410 935660	NINA SCHERBAKOVA	{"email": "scherbakovan.061978@postgrespro.ru", "phone": "+70163426642"}
0005435177147	174277	5553 176210	ANASTASIYA CHERNOVA	{"email": "a_chernova-14051978@postgrespro.ru", "phone": "+70392161408"}
0005435177148	D644CB	6417 447793	VLADIMIR ROMANOV	{"email": "romanov.vladimir-031973@postgrespro.ru", "phone": "+70735855498"}
0005435177149	2621B7	2024 743410	ELENA ERMAKOVA	{"phone": "+70624393542"}
0005435177150	2621B7	6676 451224	ELENA KRASNOVA	{"email": "elena.krasnova_051963@postgrespro.ru", "phone": "+70652672067"}
0005435177151	2621B7	3084 862076	GALINA GORBUNOVA	{"phone": "+70830263069"}
0005435177152	943152	8728 295700	ZINAIDA IVANOVA	{"email": "ivanova.zinaida-1973@postgrespro.ru", "phone": "+70851780541"}
0005435177153	66EE84	3091 349697	ZOYA LAZAREVA	{"phone": "+70147037148"}
0005435177154	56BB02	1121 398437	VENERA YUDINA	{"email": "v.yudina_031969@postgrespro.ru", "phone": "+70997898974"}
0005435177155	6E724B	8111 193526	SVETLANA KUZMINA	{"email": "s.kuzmina-1976@postgrespro.ru", "phone": "+70008038940"}
0005435177156	0EC9AE	5708 021547	ANNA BOGDANOVA	{"phone": "+70066449042"}
0005435177157	0EC9AE	3563 132723	VALERIY ZHUKOV	{"phone": "+70868978543"}
0005435177158	5E5F78	8293 670683	ELENA AFANASEVA	{"phone": "+70373918720"}
0005435177159	BF06B6	4335 089791	ANDREY ANTONOV	{"email": "a_antonov.091974@postgrespro.ru", "phone": "+70331397500"}
0005435177160	493501	9999 287854	SERGEY ZHURAVLEV	{"phone": "+70962858350"}
0005435177161	6889E0	5266 172023	GALINA NESTEROVA	{"email": "nesterova_galina_05081972@postgrespro.ru", "phone": "+70480112967"}
0005435177162	71A5FD	7164 948820	ALSU SERGEEVA	{"email": "a.sergeeva.041970@postgrespro.ru", "phone": "+70122845465"}
0005435177163	71A5FD	8571 024452	ANASTASIYA ZAKHAROVA	{"email": "zakharova-anastasiya.081966@postgrespro.ru", "phone": "+70499030038"}
0005435177164	71A5FD	1671 669822	MARIYA MAKAROVA	{"email": "makarova-m041979@postgrespro.ru", "phone": "+70957223499"}
0005435177165	AE5A9A	1657 282483	STANISLAV KONOVALOV	{"email": "konovalovs111975@postgrespro.ru", "phone": "+70425917908"}
0005435177166	5C0DA1	3209 772266	NIKITA NIKITIN	{"email": "n-nikitin_20051967@postgrespro.ru", "phone": "+70601619067"}
0005435177167	82B712	9767 654184	TATYANA ROMANOVA	{"phone": "+70031114768"}
0005435177168	955FA4	3566 769252	LYUDMILA NAUMOVA	{"phone": "+70172962141"}
0005435177169	EE94E7	6555 601966	MAKSIM ALEKSANDROV	{"phone": "+70766911686"}
0005435177170	75825D	1460 694431	LYUBOV MIRONOVA	{"email": "mironova.l111970@postgrespro.ru", "phone": "+70343205176"}
0005435177171	75825D	7530 980392	VLADIMIR OSIPOV	{"email": "v_osipov.19111961@postgrespro.ru", "phone": "+70894619584"}
0005435177172	9AB31D	1384 735434	MARINA NIKOLAEVA	{"phone": "+70586839404"}
0005435177173	9AB31D	5268 092840	VALENTINA MIKHAYLOVA	{"email": "vmikhaylova.27111970@postgrespro.ru", "phone": "+70286335379"}
0005435177455	65A59E	7984 991237	ANASTASIYA BARANOVA	{"phone": "+70834052182"}
0005435177174	1CC13F	4256 348542	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-1967@postgrespro.ru", "phone": "+70250450799"}
0005435177175	39B296	9176 957723	ALEKSEY GORBUNOV	{"email": "aleksey_gorbunov.1967@postgrespro.ru", "phone": "+70439804459"}
0005435177176	39B296	3105 073768	NIKOLAY ABRAMOV	{"phone": "+70648937324"}
0005435177177	703D56	2371 641981	NATALYA BORISOVA	{"phone": "+70852173135"}
0005435177178	289569	9179 030732	MIKHAIL TIMOFEEV	{"phone": "+70967784838"}
0005435177179	16F0C0	6027 909458	EVGENIYA KUZMINA	{"phone": "+70598324638"}
0005435177180	1198B1	5208 505139	ELENA VASILEVA	{"email": "vasileva-e1982@postgrespro.ru", "phone": "+70591602361"}
0005435177181	916C94	2144 170909	ELENA KALININA	{"email": "kalinina.elena_051977@postgrespro.ru", "phone": "+70462342223"}
0005435177182	916C94	8219 941594	ANNA GAVRILOVA	{"phone": "+70260437156"}
0005435177183	916C94	8616 834291	MARIYA KUZNECOVA	{"phone": "+70809808742"}
0005435177184	CFBFF0	0488 006025	ALEKSANDR ORLOV	{"phone": "+70386715896"}
0005435177185	CFBFF0	5271 854030	SOFIYA ZAYCEVA	{"phone": "+70218842164"}
0005435177186	8A2501	7544 113407	EVGENIY POPOV	{"email": "popov.e.011972@postgrespro.ru", "phone": "+70674116906"}
0005435177187	7B8C05	4986 943240	KLAVDIYA BOGDANOVA	{"email": "bogdanova.k.1969@postgrespro.ru", "phone": "+70778747048"}
0005435177188	7B8C05	3995 669814	DANIL GORBUNOV	{"phone": "+70168043079"}
0005435177189	F4CBC4	3438 627188	ARTEM KISELEV	{"phone": "+70453614879"}
0005435177190	378B4C	8214 248735	NATALIYA MOISEEVA	{"email": "nmoiseeva.031956@postgrespro.ru", "phone": "+70239767653"}
0005435177191	1B6406	5714 925639	SERGEY ILIN	{"phone": "+70713464600"}
0005435177192	21D679	3748 620445	LYUDMILA LUKYANOVA	{"email": "lyudmila.lukyanova-011980@postgrespro.ru", "phone": "+70647635711"}
0005435177193	F9F47C	5032 379190	IGOR BORISOV	{"email": "iborisov041974@postgrespro.ru", "phone": "+70049188524"}
0005435177194	32F5C0	3947 463109	IGOR FROLOV	{"phone": "+70089567938"}
0005435177195	6EB255	5192 986252	MARIYA BELYAEVA	{"phone": "+70149664421"}
0005435177196	6EB255	3648 384918	SVETLANA KAZAKOVA	{"phone": "+70825352422"}
0005435177197	EEAD0A	4798 289056	RAISA NAZAROVA	{"phone": "+70892848961"}
0005435177198	F4C105	2846 102938	ALEKSANDR MAKSIMOV	{"phone": "+70824427487"}
0005435177199	6D4A13	5168 031217	VALENTINA KOVALEVA	{"phone": "+70840988766"}
0005435177200	5774A6	4776 576801	DENIS FOMIN	{"email": "d-fomin.14021977@postgrespro.ru", "phone": "+70827296798"}
0005435177201	BD8D33	8299 713477	EVGENIY ZAYCEV	{"email": "evgeniy_zaycev.13051972@postgrespro.ru", "phone": "+70408467645"}
0005435177202	BB1F19	1851 551080	ANDREY BELOV	{"email": "belov.a-20071961@postgrespro.ru", "phone": "+70073995818"}
0005435177203	BB1F19	6170 112862	SERGEY POPOV	{"email": "popov_s121974@postgrespro.ru", "phone": "+70536816669"}
0005435177204	CAD016	8564 473819	VALENTINA KUZNECOVA	{"email": "kuznecova.valentina-121979@postgrespro.ru", "phone": "+70571540534"}
0005435177205	3BDF58	8418 956924	TATYANA OVCHINNIKOVA	{"phone": "+70130975133"}
0005435177206	A20819	9030 118182	ANTONINA KUDRYASHOVA	{"email": "kudryashova-antonina_09091974@postgrespro.ru", "phone": "+70174952765"}
0005435177207	A20819	2977 566450	ALEKSANDR ILIN	{"phone": "+70492666015"}
0005435177208	AA8D67	1208 845032	OLGA PETROVA	{"email": "opetrova-1963@postgrespro.ru", "phone": "+70700297905"}
0005435177209	AA8D67	5606 644185	PAVEL SERGEEV	{"phone": "+70059790206"}
0005435177210	AA8D67	3970 012439	ANDREY ROMANOV	{"phone": "+70119323898"}
0005435177211	1ADF7A	4347 038755	GALINA SMIRNOVA	{"email": "smirnovagalina_081963@postgrespro.ru", "phone": "+70239599283"}
0005435177212	677C27	8578 311171	NADEZHDA NIKITINA	{"phone": "+70605965924"}
0005435177213	677C27	5674 226454	OLGA KRASNOVA	{"email": "o-krasnova.12051976@postgrespro.ru", "phone": "+70742580616"}
0005435177214	677C27	4410 578906	IRINA MIKHAYLOVA	{"phone": "+70101910274"}
0005435177215	A33635	9206 485252	TATYANA ANTONOVA	{"phone": "+70384097239"}
0005435177216	A33635	9126 243644	ELENA ILINA	{"phone": "+70392390764"}
0005435177217	6F3C09	2093 494174	SVETLANA TITOVA	{"email": "svetlana_titova.121968@postgrespro.ru", "phone": "+70057940592"}
0005435177218	C09E93	1431 737224	ALEKSANDR POPOV	{"phone": "+70233353373"}
0005435177219	70BAA6	7283 892861	EKATERINA KISELEVA	{"email": "kiseleva-e121975@postgrespro.ru", "phone": "+70489198647"}
0005435177220	6E0746	2644 637102	MARINA EGOROVA	{"email": "egorova_marina22101968@postgrespro.ru", "phone": "+70633958212"}
0005435177221	6E0746	3484 841687	YURIY YAKOVLEV	{"phone": "+70119532484"}
0005435177222	022AE2	4700 162948	VITALIY VLASOV	{"phone": "+70332843724"}
0005435177223	C20B38	9231 853494	MIKHAIL KUZNECOV	{"phone": "+70930491679"}
0005435177224	5A8F1F	5870 333729	OLEG FROLOV	{"phone": "+70741883622"}
0005435177225	434E45	4157 798744	EKATERINA SIDOROVA	{"email": "ekaterina_sidorova.111959@postgrespro.ru", "phone": "+70374211799"}
0005435177226	AE8691	9075 454555	YURIY KOROLEV	{"email": "yuriy_korolev_011977@postgrespro.ru", "phone": "+70261068442"}
0005435177227	AE8691	4979 548316	ALEKSANDRA BORISOVA	{"email": "aleksandra-borisova-26121969@postgrespro.ru", "phone": "+70566855627"}
0005435177228	064940	0237 763666	IVAN POPOV	{"phone": "+70856804415"}
0005435177229	CBCCA7	4521 362394	MAKSIM ZHURAVLEV	{"email": "zhuravlevmaksim121968@postgrespro.ru", "phone": "+70210773638"}
0005435177230	CBCCA7	9165 182379	LYUDMILA ZHURAVLEVA	{"phone": "+70154295501"}
0005435177231	C15F41	9260 129957	OLEG KOZLOV	{"email": "kozlov.oleg-1982@postgrespro.ru", "phone": "+70206821233"}
0005435177232	C15F41	3318 932892	ARTEM MATVEEV	{"phone": "+70504807118"}
0005435177233	760BEC	0069 421359	ANASTASIYA AFANASEVA	{"phone": "+70076719360"}
0005435177234	E3887C	0532 898460	ANASTASIYA POPOVA	{"phone": "+70844949141"}
0005435177235	F3CEC8	0040 390737	GALINA MIRONOVA	{"email": "galina-mironova-051969@postgrespro.ru", "phone": "+70260401377"}
0005435177236	4183A1	1901 053358	ANDREY KOZLOV	{"phone": "+70138221135"}
0005435177237	960C2C	2492 728658	DMITRIY ORLOV	{"email": "d-orlov111967@postgrespro.ru", "phone": "+70397647187"}
0005435177238	37D73B	3489 243766	EKATERINA SCHERBAKOVA	{"phone": "+70469655758"}
0005435177239	37D73B	5341 607015	MARINA GORBUNOVA	{"phone": "+70030103353"}
0005435177240	DA16D7	7258 232887	ELENA FROLOVA	{"phone": "+70786137924"}
0005435177241	DA16D7	6314 118910	NIKITA BORISOV	{"email": "n_borisov_021965@postgrespro.ru", "phone": "+70776696229"}
0005435177242	B54205	7496 928224	RAISA VASILEVA	{"email": "rvasileva081962@postgrespro.ru", "phone": "+70195802998"}
0005435177243	BE1D6F	1275 555940	MIKHAIL NAUMOV	{"email": "naumov_m-25081962@postgrespro.ru", "phone": "+70640653506"}
0005435177244	6FF8DD	3336 432794	ANDREY NIKOLAEV	{"email": "andrey_nikolaev.111978@postgrespro.ru", "phone": "+70687613026"}
0005435177245	D672D1	5647 891352	GRIGORIY SOROKIN	{"phone": "+70767231243"}
0005435177246	E06C0A	7846 489689	MARIYA ZHURAVLEVA	{"phone": "+70689711798"}
0005435177247	33B54F	4018 331316	OLGA SOKOLOVA	{"email": "sokolova-olga.021971@postgrespro.ru", "phone": "+70985707479"}
0005435177248	33B54F	4030 835692	ANNA SEMENOVA	{"email": "a.semenova07111961@postgrespro.ru", "phone": "+70606443631"}
0005435177249	CA6AC9	5282 468950	MARIYA LAZAREVA	{"phone": "+70609958376"}
0005435177250	15B7D1	2511 639886	ILYAS ANDREEV	{"phone": "+70833540467"}
0005435177251	15B7D1	6000 619159	MARINA CHERNOVA	{"email": "m_chernova.1976@postgrespro.ru", "phone": "+70025376590"}
0005435177252	AAA3CE	7424 496447	SVETLANA PETROVA	{"email": "petrova.svetlana111981@postgrespro.ru", "phone": "+70144463653"}
0005435177253	AAA3CE	7085 825707	SERGEY ISAEV	{"phone": "+70228764283"}
0005435177254	AAA3CE	7685 756964	SVETLANA ROMANOVA	{"email": "romanova-svetlana1979@postgrespro.ru", "phone": "+70639362540"}
0005435177255	E80442	0695 747268	ANATOLIY GRIGOREV	{"email": "anatoliy_grigorev.031963@postgrespro.ru", "phone": "+70092045191"}
0005435177256	79351E	7873 386181	TATYANA ROMANOVA	{"phone": "+70968345318"}
0005435177257	79351E	4844 917403	TATYANA KAZAKOVA	{"email": "t_kazakova_1965@postgrespro.ru", "phone": "+70171790531"}
0005435177258	7A7E36	1992 324964	KIRILL ISAEV	{"phone": "+70033113395"}
0005435177259	9BA859	8658 389768	IRINA NIKITINA	{"email": "i-nikitina_071965@postgrespro.ru", "phone": "+70312587450"}
0005435177260	B1CB75	2304 570587	NATALYA KOLESNIKOVA	{"email": "nkolesnikova.29101977@postgrespro.ru", "phone": "+70054089199"}
0005435177261	ACCF58	4143 766207	KSENIYA TIMOFEEVA	{"phone": "+70904923238"}
0005435177262	F95F92	3024 286931	ELVIRA NIKOLAEVA	{"email": "enikolaeva-10031983@postgrespro.ru", "phone": "+70917071352"}
0005435177263	F95F92	1677 673126	IGOR KUZMIN	{"email": "i-kuzmin1978@postgrespro.ru", "phone": "+70454255539"}
0005435177264	E3B324	1525 501278	NADEZHDA ILINA	{"email": "n_ilina19011979@postgrespro.ru", "phone": "+70193422106"}
0005435177265	E3B324	8274 611347	ANATOLIY OSIPOV	{"email": "osipov_a-1979@postgrespro.ru", "phone": "+70448572772"}
0005435177266	513F87	2788 655899	OLGA KUZNECOVA	{"phone": "+70500291993"}
0005435177267	513F87	0100 920479	ELENA KUZNECOVA	{"phone": "+70167673739"}
0005435177268	513F87	9101 665606	OKSANA IVANOVA	{"phone": "+70566734690"}
0005435177269	270681	9687 935458	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov_041981@postgrespro.ru", "phone": "+70651439388"}
0005435177270	270681	3983 331088	SVETLANA FROLOVA	{"email": "frolova_svetlana1976@postgrespro.ru", "phone": "+70422584187"}
0005435177271	D7CCFC	7601 627687	ALEKSANDR POPOV	{"email": "popova_031953@postgrespro.ru", "phone": "+70494408547"}
0005435177272	D7CCFC	5962 372938	KLAVDIYA FOMINA	{"email": "fomina-k-15101978@postgrespro.ru", "phone": "+70975473050"}
0005435177273	F4F5E8	9088 960116	NAILYA DMITRIEVA	{"phone": "+70205428819"}
0005435177274	317179	0609 875755	ALEKSANDR ANTONOV	{"email": "antonov.a.1981@postgrespro.ru", "phone": "+70626275780"}
0005435177275	9C9F3B	5950 786307	TATYANA MALYSHEVA	{"email": "tmalysheva.08081970@postgrespro.ru", "phone": "+70503182766"}
0005435177276	42FA09	8934 871609	TATYANA ZHUKOVA	{"phone": "+70815640656"}
0005435177277	42FA09	7805 714353	TATYANA ZHUKOVA	{"phone": "+70511283137"}
0005435177278	2B9C64	4793 936379	NATALYA TARASOVA	{"phone": "+70986873460"}
0005435177279	177A6C	0093 705803	MARAT VLASOV	{"email": "m_vlasov_081976@postgrespro.ru", "phone": "+70269578542"}
0005435177280	B73859	6194 444816	NATALYA NESTEROVA	{"email": "natalya-nesterova_121966@postgrespro.ru", "phone": "+70442007279"}
0005435177281	B73859	1070 032341	OLGA KULIKOVA	{"email": "okulikova.1977@postgrespro.ru", "phone": "+70428453342"}
0005435177282	EB4E0A	9172 157166	DARYA KOZLOVA	{"email": "d.kozlova-121977@postgrespro.ru", "phone": "+70722337285"}
0005435177283	0E4B3E	8570 032942	OLGA EGOROVA	{"email": "egorova_o_18041966@postgrespro.ru", "phone": "+70909800830"}
0005435177284	0E4B3E	2479 577463	SERGEY NAUMOV	{"phone": "+70665320470"}
0005435177285	45189C	4271 506626	EKATERINA ERMAKOVA	{"email": "ermakova-ekaterina23051976@postgrespro.ru", "phone": "+70449595894"}
0005435177286	EB701D	0267 719352	MARIYA ZHUKOVA	{"phone": "+70841235553"}
0005435177287	BBD754	9279 087512	PETR DENISOV	{"email": "p_denisov23111972@postgrespro.ru", "phone": "+70053719850"}
0005435177288	6E5ABE	1847 143813	NADEZHDA ABRAMOVA	{"phone": "+70026916118"}
0005435177289	67EBDE	6967 488544	PAVEL ALEKSEEV	{"phone": "+70042405953"}
0005435177290	4E8382	0243 667217	ELENA GERASIMOVA	{"email": "gerasimova.e-021976@postgrespro.ru", "phone": "+70902074682"}
0005435177291	B975D7	0774 466056	KRISTINA ZAKHAROVA	{"email": "zakharova-k-1981@postgrespro.ru", "phone": "+70761877629"}
0005435177292	20A0F6	8728 700987	IVAN ILIN	{"phone": "+70579784580"}
0005435177293	B5409E	1171 211909	VALERIY TIKHONOV	{"email": "tikhonovvaleriy-111960@postgrespro.ru", "phone": "+70022048957"}
0005435177294	B5409E	7362 777666	INNA KOLESNIKOVA	{"email": "i_kolesnikova_1960@postgrespro.ru", "phone": "+70794141001"}
0005435177295	B5409E	9903 298562	VIKTOR KOZLOV	{"email": "vkozlov_121977@postgrespro.ru", "phone": "+70185433755"}
0005435177296	CBA268	8499 438023	EDGAR DENISOV	{"email": "denisov-edgar.1973@postgrespro.ru", "phone": "+70708017379"}
0005435177297	CBA268	9637 671069	SERGEY ANTONOV	{"email": "antonovsergey.1965@postgrespro.ru", "phone": "+70680492922"}
0005435177298	65F8B0	7913 512643	NATALYA IVANOVA	{"email": "ivanovan-03111976@postgrespro.ru", "phone": "+70664685270"}
0005435177299	FFCABD	6438 201543	PETR MIKHAYLOV	{"email": "petr-mikhaylov-101971@postgrespro.ru", "phone": "+70238357329"}
0005435177300	B003C3	6859 051376	LYUDMILA DANILOVA	{"email": "danilova.lyudmila-031982@postgrespro.ru", "phone": "+70252152118"}
0005435177301	E528D5	6246 079527	VALENTIN EGOROV	{"phone": "+70433485605"}
0005435177302	E528D5	7432 024243	MARIYA ORLOVA	{"phone": "+70759075842"}
0005435177303	379CFD	7577 780446	NIKOLAY FILIPPOV	{"phone": "+70402392417"}
0005435177304	175D2B	5332 661106	SVETLANA NESTEROVA	{"email": "s-nesterova_1971@postgrespro.ru", "phone": "+70031491124"}
0005435177305	F080DC	6165 417542	MARINA ABRAMOVA	{"email": "m_abramova_101974@postgrespro.ru", "phone": "+70742964443"}
0005435177306	7536B2	7409 673336	OLGA EFIMOVA	{"email": "o_efimova-1959@postgrespro.ru", "phone": "+70443930506"}
0005435177307	EAE264	3502 140911	NIKOLAY KUZNECOV	{"phone": "+70192873755"}
0005435177308	D7A816	1626 827113	VLADIMIR BONDARENKO	{"phone": "+70534470229"}
0005435177309	EC4F8D	9183 206837	ALEKSANDR KUZNECOV	{"phone": "+70175170206"}
0005435177310	EC4F8D	5036 898475	ANATOLIY KISELEV	{"phone": "+70545830028"}
0005435177311	EC4F8D	2883 329144	SVETLANA ZAKHAROVA	{"email": "svetlana_zakharova-1967@postgrespro.ru", "phone": "+70162240567"}
0005435177312	F58C0C	2235 112953	EVGENIYA NIKITINA	{"email": "nikitina_e-061967@postgrespro.ru", "phone": "+70496704129"}
0005435177313	578A58	6032 758757	IVAN DAVYDOV	{"phone": "+70475762867"}
0005435177314	578A58	1201 104402	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova.1969@postgrespro.ru", "phone": "+70032455360"}
0005435177315	A562BE	0918 564671	NATALYA TIKHONOVA	{"phone": "+70931593313"}
0005435177316	A562BE	1477 527956	ANGELINA KOZLOVA	{"email": "kozlova_a-13021976@postgrespro.ru", "phone": "+70057287082"}
0005435177317	668CA2	1984 357011	EKATERINA MOROZOVA	{"phone": "+70986441560"}
0005435177318	668CA2	8923 314807	ALEKSEY MAKAROV	{"phone": "+70161664597"}
0005435177319	6045F8	4538 627218	SERGEY PETROV	{"phone": "+70676305441"}
0005435177320	C73B83	1411 197689	YULIYA ANTONOVA	{"email": "yuliya-antonova1982@postgrespro.ru", "phone": "+70993658532"}
0005435177321	E32DD6	0321 873393	VLADIMIR BORISOV	{"email": "vladimir.borisov-23061970@postgrespro.ru", "phone": "+70904513726"}
0005435177322	F26074	2485 825110	VALENTINA MAKAROVA	{"email": "makarovavalentina061967@postgrespro.ru", "phone": "+70687247567"}
0005435177323	351036	6610 361611	DMITRIY KOZLOV	{"phone": "+70076395329"}
0005435177324	351036	4661 325495	ANATOLIY ANDREEV	{"email": "andreev_anatoliy-1967@postgrespro.ru", "phone": "+70445732359"}
0005435177325	351036	9413 017200	FEDOR SCHERBAKOV	{"phone": "+70390198386"}
0005435177326	B155FA	7325 776862	YULIYA FILIPPOVA	{"phone": "+70836000254"}
0005435177327	DA66A9	1192 899033	ALEKSANDR ALEKSEEV	{"phone": "+70811302534"}
0005435177328	9F6D0F	4871 079651	RAISA DMITRIEVA	{"email": "raisa.dmitrieva.17061973@postgrespro.ru", "phone": "+70135894849"}
0005435177329	B8A1CD	2098 344321	ALEKSANDR IVANOV	{"phone": "+70783611051"}
0005435177330	B8A1CD	4485 755031	ELENA MASLOVA	{"email": "maslovaelena1973@postgrespro.ru", "phone": "+70675388658"}
0005435177331	03F1F6	1121 778951	DMITRIY POPOV	{"email": "dmitriypopov-1973@postgrespro.ru", "phone": "+70987878078"}
0005435177332	A0D129	4800 577738	NATALYA KUZNECOVA	{"phone": "+70124422906"}
0005435177333	7BD6BC	4142 845339	LYUDMILA PETROVA	{"email": "petrova_lyudmila_27041967@postgrespro.ru", "phone": "+70064739500"}
0005435177334	7BD6BC	9065 145711	MARIYA ZAKHAROVA	{"phone": "+70079440553"}
0005435177335	95EA4A	3462 442333	MARINA PAVLOVA	{"email": "pavlova-m_121969@postgrespro.ru", "phone": "+70355437645"}
0005435177336	95EA4A	9227 949975	LYUDMILA GUSEVA	{"phone": "+70781300020"}
0005435177337	DC0F4E	4471 547195	NIKOLAY ISAEV	{"email": "isaev-n-041977@postgrespro.ru", "phone": "+70395164244"}
0005435177338	83B895	5164 375582	VENIAMIN NOVIKOV	{"phone": "+70196985171"}
0005435177339	EA9A48	1336 806186	OLGA ZOTOVA	{"phone": "+70125968160"}
0005435177340	867239	6450 013947	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir.041969@postgrespro.ru", "phone": "+70620528408"}
0005435177341	A7370B	3970 671934	NINA MELNIKOVA	{"phone": "+70568655969"}
0005435177342	A7370B	6675 917386	TATYANA LOGINOVA	{"email": "loginova.tatyana.041965@postgrespro.ru", "phone": "+70867424449"}
0005435177343	A75EEE	3841 551519	OKSANA PETROVA	{"email": "oksanapetrova_22071966@postgrespro.ru", "phone": "+70986470154"}
0005435177344	34831A	7764 910740	NATALYA KALININA	{"email": "kalininan-1973@postgrespro.ru", "phone": "+70246653922"}
0005435177345	34831A	6314 740857	VALENTINA IVANOVA	{"email": "v.ivanova.1968@postgrespro.ru", "phone": "+70357307825"}
0005435177346	011DD3	8826 079604	YULIYA DANILOVA	{"phone": "+70306182157"}
0005435177347	7C411F	5265 331683	IRINA VOLKOVA	{"email": "volkova-irina121980@postgrespro.ru", "phone": "+70880678085"}
0005435177348	53C860	1293 920269	ROZA KUZMINA	{"phone": "+70652266608"}
0005435177349	839988	3591 328048	LARISA GERASIMOVA	{"email": "gerasimova-larisa1982@postgrespro.ru", "phone": "+70746946744"}
0005435177350	4B7E91	6528 206830	NIKITA NIKITIN	{"phone": "+70496212735"}
0005435177351	4B7E91	9119 719113	EKATERINA NIKITINA	{"phone": "+70417010851"}
0005435177352	4B7E91	4483 155789	TATYANA SOROKINA	{"email": "sorokina.tatyana.121974@postgrespro.ru", "phone": "+70073928034"}
0005435177353	51FD34	3590 215765	NIKOLAY FEDOTOV	{"email": "nikolay_fedotov_051977@postgrespro.ru", "phone": "+70025380230"}
0005435177354	46986D	7179 548254	NIKITA SERGEEV	{"email": "sergeevn_04021969@postgrespro.ru", "phone": "+70916588736"}
0005435177355	0C79BB	7647 175713	DMITRIY NOVIKOV	{"email": "d.novikov_11121968@postgrespro.ru", "phone": "+70159928385"}
0005435177356	61F8B5	2337 836528	GEORGIY ROMANOV	{"email": "g-romanov-031974@postgrespro.ru", "phone": "+70119936292"}
0005435177357	61F8B5	7391 097492	GEORGIY NIKOLAEV	{"email": "g.nikolaev-1968@postgrespro.ru", "phone": "+70332312084"}
0005435177358	61F8B5	3788 414706	ALEKSANDR TARASOV	{"phone": "+70180442162"}
0005435177359	0792D8	9480 481621	DMITRIY MAKAROV	{"phone": "+70734045952"}
0005435177360	6739D0	7564 570719	ANDREY IVANOV	{"phone": "+70328891155"}
0005435177361	EF840F	7725 108935	NINA KOROLEVA	{"email": "n.koroleva.1973@postgrespro.ru", "phone": "+70228311408"}
0005435177362	5E4891	9543 069719	TATYANA MOROZOVA	{"email": "tmorozova.28121963@postgrespro.ru", "phone": "+70231694972"}
0005435177363	3AB81A	4242 807683	EKATERINA GAVRILOVA	{"phone": "+70052765972"}
0005435177364	61D124	9342 575659	ALEKSEY MATVEEV	{"phone": "+70627916439"}
0005435177365	A5E496	2780 809960	EKATERINA RYABOVA	{"phone": "+70305692190"}
0005435177366	2DB9E1	9440 194399	KRISTINA SCHERBAKOVA	{"email": "kristina.scherbakova.091974@postgrespro.ru", "phone": "+70201181101"}
0005435177367	5D0E7A	3200 092309	ANATOLIY VASILEV	{"email": "a.vasilev02121963@postgrespro.ru", "phone": "+70035449412"}
0005435177368	9C3247	8313 163286	TATYANA KUZNECOVA	{"email": "tkuznecova061962@postgrespro.ru", "phone": "+70481007141"}
0005435177369	87E9C2	4582 542621	IRINA KISELEVA	{"phone": "+70699882106"}
0005435177370	87E9C2	3421 903479	ALEKSEY DAVYDOV	{"email": "a.davydov.30101972@postgrespro.ru", "phone": "+70950211694"}
0005435177371	C8897F	3757 625127	VALERIY ZAKHAROV	{"phone": "+70748418013"}
0005435177372	70BE4D	0311 923651	ANNA KOMAROVA	{"phone": "+70584851040"}
0005435177373	2CD31F	3171 935609	RAISA MASLOVA	{"email": "maslova-raisa-111961@postgrespro.ru", "phone": "+70244335573"}
0005435177374	F1F23E	8170 052091	NATALYA DENISOVA	{"email": "denisova-n051981@postgrespro.ru", "phone": "+70843575398"}
0005435177375	B557A0	0651 454739	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev-aleksandr-031959@postgrespro.ru", "phone": "+70022970639"}
0005435177376	DABBE4	8228 831879	NADEZHDA ILINA	{"phone": "+70970684961"}
0005435177377	F79E1D	8441 826462	YURIY PAVLOV	{"email": "pavlov-yuriy.05081978@postgrespro.ru", "phone": "+70525981546"}
0005435177378	D1634C	5176 670438	LYUDMILA KUZNECOVA	{"email": "l-kuznecova.031971@postgrespro.ru", "phone": "+70529536081"}
0005435177379	D1634C	4413 361937	DMITRIY VASILEV	{"email": "dvasilev_25101985@postgrespro.ru", "phone": "+70511616391"}
0005435177380	D1634C	3139 736288	SVETLANA MIKHAYLOVA	{"phone": "+70342062590"}
0005435177381	24B118	6238 014055	ELENA NESTEROVA	{"email": "e_nesterova_121970@postgrespro.ru", "phone": "+70650699302"}
0005435177382	C4D2BA	0802 287319	GALINA FROLOVA	{"email": "galina-frolova121973@postgrespro.ru", "phone": "+70082666538"}
0005435177383	DF447A	2640 571577	DANIIL SAVELEV	{"phone": "+70947590128"}
0005435177384	CCA59B	1532 499074	ELENA NIKOLAEVA	{"email": "enikolaeva-18021976@postgrespro.ru", "phone": "+70104037123"}
0005435177385	CCA59B	4922 272320	VLADIMIR TARASOV	{"email": "vladimirtarasov-1970@postgrespro.ru", "phone": "+70075201499"}
0005435177386	E18FD8	0779 189325	PETR ROMANOV	{"phone": "+70163078518"}
0005435177387	E18FD8	7696 734336	ANNA KOROLEVA	{"email": "koroleva.a_1974@postgrespro.ru", "phone": "+70948543653"}
0005435177388	E18FD8	3949 238502	DMITRIY KUZNECOV	{"phone": "+70479763259"}
0005435177389	93465F	2353 430090	DMITRIY MOROZOV	{"phone": "+70077918960"}
0005435177390	93465F	0019 365590	SVETLANA KOROLEVA	{"email": "s-koroleva.1970@postgrespro.ru", "phone": "+70288283016"}
0005435177391	CFCC40	2434 696323	VLADISLAV SAVELEV	{"email": "savelev.vladislav1968@postgrespro.ru", "phone": "+70106082978"}
0005435177392	CFCC40	6563 867917	VLADIMIR NIKOLAEV	{"phone": "+70882310833"}
0005435177393	53A32D	1456 109952	SVETLANA NIKIFOROVA	{"email": "nikiforovasvetlana.031970@postgrespro.ru", "phone": "+70508890587"}
0005435177394	53A32D	3352 720350	YULIYA NAZAROVA	{"email": "ynazarova051981@postgrespro.ru", "phone": "+70968998264"}
0005435177395	ADF9D6	8034 575031	RAIL KUZMIN	{"email": "kuzmin_rail-25111981@postgrespro.ru", "phone": "+70441685158"}
0005435177396	ADF9D6	3276 751827	ANTONIDA ALEKSEEVA	{"phone": "+70973526439"}
0005435177397	239B63	4069 664177	ANDREY TARASOV	{"email": "a_tarasov1982@postgrespro.ru", "phone": "+70971140390"}
0005435177398	90B372	2835 916737	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_valentina_011970@postgrespro.ru", "phone": "+70842150198"}
0005435177399	90B372	5975 831058	TAMARA DAVYDOVA	{"phone": "+70422534574"}
0005435177400	A99519	8055 840563	RAFIS ALEKSANDROV	{"phone": "+70201659242"}
0005435177401	A99519	6399 919708	MARINA GRISHINA	{"email": "grishina.marina.04121974@postgrespro.ru", "phone": "+70496248288"}
0005435177402	40CF38	5610 190265	EVGENIYA SMIRNOVA	{"phone": "+70343541603"}
0005435177403	40CF38	5627 565460	OLGA ABRAMOVA	{"phone": "+70116725410"}
0005435177404	2228C1	9882 888756	VIKTOR MIKHAYLOV	{"phone": "+70733135978"}
0005435177405	2228C1	5783 402957	IVAN TARASOV	{"email": "tarasovivan.101972@postgrespro.ru", "phone": "+70039822562"}
0005435177406	170C0E	8628 414281	INNA ANTONOVA	{"phone": "+70437249150"}
0005435177407	170C0E	0729 734053	MIKHAIL TIMOFEEV	{"email": "timofeev.mikhail.011985@postgrespro.ru", "phone": "+70051133589"}
0005435177408	170C0E	9385 050832	YURIY MEDVEDEV	{"email": "medvedevyuriy_051985@postgrespro.ru", "phone": "+70675500643"}
0005435177409	86FE1A	3256 151899	NATALIYA LEBEDEVA	{"phone": "+70072102880"}
0005435177410	067ABC	9368 738208	ALEKSANDR BELOV	{"email": "aleksandr.belov121952@postgrespro.ru", "phone": "+70587610758"}
0005435177411	26ECCB	2453 401240	ELENA FADEEVA	{"email": "elena_fadeeva1972@postgrespro.ru", "phone": "+70189177063"}
0005435177412	59A2AE	7664 358729	IVAN KUDRYASHOV	{"email": "kudryashovi_031976@postgrespro.ru", "phone": "+70429979924"}
0005435177413	516FE3	4616 782496	TATYANA DENISOVA	{"phone": "+70531453241"}
0005435177414	4143F4	7537 824823	MARIYA FEDOROVA	{"phone": "+70863684348"}
0005435177415	4143F4	4510 929341	EVGENIY NIKITIN	{"phone": "+70517315202"}
0005435177416	8DE3E6	5631 103953	OLGA KAZAKOVA	{"email": "olga.kazakova.041971@postgrespro.ru", "phone": "+70644073657"}
0005435177417	8DE3E6	3154 100014	SERGEY KARPOV	{"phone": "+70315790036"}
0005435177418	77CEA3	6613 425002	VASILIY EGOROV	{"email": "egorovvasiliy18011970@postgrespro.ru", "phone": "+70003621058"}
0005435177419	B93591	1090 797484	LYUDMILA KOZLOVA	{"phone": "+70691515697"}
0005435177420	0337A0	8543 391730	MAKSIM SAVELEV	{"phone": "+70967182640"}
0005435177421	77CC75	9589 341571	ROMAN CHERNOV	{"email": "chernov-roman-1978@postgrespro.ru", "phone": "+70508681453"}
0005435177422	F44A85	0183 587565	MARIYA ALEKSEEVA	{"phone": "+70626935734"}
0005435177423	F44A85	1702 803733	YURIY IVANOV	{"email": "yivanov011975@postgrespro.ru", "phone": "+70323216490"}
0005435177424	DA5508	1428 492428	ANNA YAKOVLEVA	{"email": "anna-yakovleva-031967@postgrespro.ru", "phone": "+70791272357"}
0005435177425	19D7B3	3603 945758	IVAN NOVIKOV	{"phone": "+70125815794"}
0005435177426	00923E	2954 329555	LYUDMILA IVANOVA	{"phone": "+70134937369"}
0005435177427	6D5F15	0569 198951	ANTON FROLOV	{"email": "frolov.anton-021960@postgrespro.ru", "phone": "+70964731536"}
0005435177428	850A77	0809 302402	NINA KUZNECOVA	{"phone": "+70804475025"}
0005435177429	850A77	7158 189791	EVGENIY DENISOV	{"phone": "+70501597507"}
0005435177430	AD2F0A	1125 466275	ANATOLIY KAZAKOV	{"email": "kazakov-a_1980@postgrespro.ru", "phone": "+70068753309"}
0005435177431	6E9A6C	5743 324082	MIKHAIL TIMOFEEV	{"phone": "+70880048375"}
0005435177432	B269F9	7971 215882	STEPAN TARASOV	{"phone": "+70858527933"}
0005435177433	7C2C5C	0246 458635	MARIYA SIDOROVA	{"phone": "+70191926345"}
0005435177434	7C2C5C	6238 971510	ELENA NOVIKOVA	{"email": "e_novikova_28051974@postgrespro.ru", "phone": "+70397651270"}
0005435177435	4B913E	5865 796187	EVGENIY IVANOV	{"email": "ivanov.e011969@postgrespro.ru", "phone": "+70239269218"}
0005435177436	D47EFD	2460 855654	YULIYA ISAEVA	{"email": "isaeva_y1984@postgrespro.ru", "phone": "+70769932917"}
0005435177437	853D04	1749 425933	VLADIMIR DMITRIEV	{"email": "dmitriev.v.1971@postgrespro.ru", "phone": "+70609188292"}
0005435177438	853D04	3663 084492	NATALIYA BORISOVA	{"email": "borisovan.071971@postgrespro.ru", "phone": "+70756599102"}
0005435177439	5EE723	9620 188150	ANASTASIYA POLYAKOVA	{"phone": "+70870408037"}
0005435177440	2027AB	1750 472309	SOFYA YAKOVLEVA	{"phone": "+70108463717"}
0005435177441	BB346B	5036 295049	ALEKSANDR MEDVEDEV	{"email": "aleksandr_medvedev_09041971@postgrespro.ru", "phone": "+70626303014"}
0005435177442	BB346B	1117 713672	TATYANA ZHUKOVA	{"phone": "+70530826012"}
0005435177443	DDB184	9442 620380	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr.1979@postgrespro.ru", "phone": "+70115551385"}
0005435177444	E756BA	9342 667492	RUSLAN SEMENOV	{"phone": "+70646944147"}
0005435177445	4974BF	2888 271892	IGOR POPOV	{"phone": "+70303538895"}
0005435177446	4974BF	9091 997221	EVGENIY NAUMOV	{"phone": "+70689818630"}
0005435177447	4A34A3	0021 790450	YULIYA MATVEEVA	{"email": "matveeva-yuliya25101979@postgrespro.ru", "phone": "+70850362188"}
0005435177448	690F36	3959 769247	EGOR NAUMOV	{"phone": "+70937212637"}
0005435177449	690F36	6425 804331	LIDIYA ILINA	{"email": "ilina_l-091974@postgrespro.ru", "phone": "+70707267421"}
0005435177450	34CDD2	7169 795029	VALENTINA SOKOLOVA	{"phone": "+70783976144"}
0005435177451	582E47	9101 006776	SVETLANA SOROKINA	{"email": "sorokina_s.031981@postgrespro.ru", "phone": "+70559566288"}
0005435177452	A44977	5388 229675	ANDREY SEMENOV	{"phone": "+70170220337"}
0005435177453	65A59E	0034 595848	OLGA NIKOLAEVA	{"email": "nikolaevao1972@postgrespro.ru", "phone": "+70492924517"}
0005435177454	65A59E	2595 383177	OLGA FILATOVA	{"phone": "+70365876572"}
0005435177456	7A31E8	3637 291907	MIKHAIL KUZNECOV	{"phone": "+70073568523"}
0005435177457	140D4C	5040 135652	MIKHAIL POPOV	{"phone": "+70878243960"}
0005435177458	140D4C	0609 400753	EKATERINA SERGEEVA	{"email": "ekaterina.sergeeva-101959@postgrespro.ru", "phone": "+70603375461"}
0005435177459	C7E403	8599 444248	VLADIMIR SEMENOV	{"phone": "+70691213841"}
0005435177460	3B179E	7054 015183	TAMARA FILIPPOVA	{"email": "filippova.tamara_101969@postgrespro.ru", "phone": "+70615340900"}
0005435177461	3B179E	7221 410563	VLADISLAV GAVRILOV	{"phone": "+70896113617"}
0005435177462	79D96D	8656 516015	MAKSIM ALEKSEEV	{"phone": "+70111253840"}
0005435177463	ECF4FC	7606 340988	SHAMIL SHEVCHENKO	{"phone": "+70973882144"}
0005435177464	7E5B4C	8267 623654	VIKTOR KISELEV	{"phone": "+70903961980"}
0005435177465	7E5B4C	5870 318721	VLADIMIR BELOV	{"email": "vbelov.01071986@postgrespro.ru", "phone": "+70458801715"}
0005435177466	7E5B4C	7126 499890	OLGA MOISEEVA	{"phone": "+70285202190"}
0005435177467	7E5B4C	3322 619765	ELENA MELNIKOVA	{"phone": "+70158234236"}
0005435177468	DA82A2	1324 902874	DMITRIY GERASIMOV	{"phone": "+70231327807"}
0005435177469	ABD0BC	2564 393198	OLEG MEDVEDEV	{"email": "o-medvedev_08091974@postgrespro.ru", "phone": "+70067662568"}
0005435177470	ABD0BC	1028 242868	VLADIMIR MAKAROV	{"email": "makarov_vladimir-14011970@postgrespro.ru", "phone": "+70119960282"}
0005435177471	86CD15	5200 574198	EVDOKIYA KAZAKOVA	{"email": "evdokiyakazakova081962@postgrespro.ru", "phone": "+70330623587"}
0005435177472	4507E1	3106 558630	SERGEY ANTONOV	{"email": "antonov.s_12061971@postgrespro.ru", "phone": "+70448982003"}
0005435177473	4507E1	1008 606122	VLADIMIR SOLOVEV	{"phone": "+70080749549"}
0005435177474	9B1886	9003 749355	IRINA NOVIKOVA	{"phone": "+70154513393"}
0005435177475	9E51AC	5973 341779	GALINA SMIRNOVA	{"email": "galina_smirnova-1965@postgrespro.ru", "phone": "+70536440785"}
0005435177476	000B91	2091 598274	MIKHAIL ALEKSANDROV	{"email": "m_aleksandrov.23051969@postgrespro.ru", "phone": "+70337495138"}
0005435177477	AEC6C8	3097 053816	PAVEL BORISOV	{"email": "p.borisov_1965@postgrespro.ru", "phone": "+70458238890"}
0005435177478	83CB9F	5386 912345	IGOR EGOROV	{"email": "i.egorov.16091981@postgrespro.ru", "phone": "+70706522659"}
0005435177479	54BA68	1492 486469	TAGIR SOKOLOV	{"email": "tagir-sokolov.06011970@postgrespro.ru", "phone": "+70711765479"}
0005435177480	54BA68	7188 626534	SERGEY KOZLOV	{"phone": "+70880671786"}
0005435177481	4C5C35	8027 445567	ANATOLIY FEDOROV	{"phone": "+70785927176"}
0005435177482	4C5C35	2899 830529	MIKHAIL STEPANOV	{"email": "mstepanov.1969@postgrespro.ru", "phone": "+70985690800"}
0005435177483	463A07	1393 526293	VLADIMIR SOLOVEV	{"phone": "+70942735097"}
0005435177484	463A07	9168 655696	LYUDMILA SMIRNOVA	{"email": "l-smirnova05121959@postgrespro.ru", "phone": "+70878574455"}
0005435177485	8ABBF5	3527 157910	ZINAIDA KUZNECOVA	{"phone": "+70272155109"}
0005435177486	95E2D2	9429 210234	ANNA FEDOROVA	{"phone": "+70932887655"}
0005435177487	95E2D2	3837 882305	DMITRIY NIKOLAEV	{"phone": "+70011798467"}
0005435177488	D6846B	7612 143715	ANATOLIY NIKITIN	{"phone": "+70157419394"}
0005435177489	835C1C	1430 637060	TATYANA ILINA	{"phone": "+70558018554"}
0005435177490	835C1C	6187 180447	ALEKSANDR SEMENOV	{"phone": "+70409725258"}
0005435177491	F19378	4250 684379	EVGENIY GUSEV	{"phone": "+70553073290"}
0005435177492	331D25	1009 266531	VLADISLAV MAKSIMOV	{"phone": "+70127200887"}
0005435177493	331D25	9340 116644	VADIM IVANOV	{"phone": "+70495322894"}
0005435177494	1A770B	9129 542175	ANTON NIKITIN	{"phone": "+70117157733"}
0005435177495	CB2B97	2588 147554	VLADIMIR ALEKSEEV	{"email": "alekseevvladimir.1964@postgrespro.ru", "phone": "+70048906543"}
0005435177496	3F9E77	0257 968979	ANGELINA IVANOVA	{"phone": "+70134312958"}
0005435177497	6F6AB2	9982 458900	LYUDMILA FEDOROVA	{"phone": "+70716330749"}
0005435177498	6193AD	4109 629315	NATALYA SERGEEVA	{"email": "sergeevan_071978@postgrespro.ru", "phone": "+70444118881"}
0005435177499	D7CA4F	9077 186876	MARIYA NIKOLAEVA	{"email": "m-nikolaeva101981@postgrespro.ru", "phone": "+70872365537"}
0005435177500	4AC01D	2790 926712	DANIIL MAKAROV	{"email": "makarov_daniil.04111972@postgrespro.ru", "phone": "+70515529424"}
0005435177501	127A93	0858 668721	NAILYA ISAEVA	{"email": "isaevan_25091967@postgrespro.ru", "phone": "+70594013463"}
0005435177502	E68A60	6835 748939	ALEKSANDR PETROV	{"email": "apetrov091976@postgrespro.ru", "phone": "+70518775087"}
0005435177503	E68A60	6870 361147	ELENA TIMOFEEVA	{"phone": "+70580730944"}
0005435177504	0666EC	8773 306558	MAKSIM IVANOV	{"phone": "+70628732727"}
0005435177505	5AF4DE	6712 403208	OLGA SEMENOVA	{"phone": "+70876693516"}
0005435177506	5AF4DE	1551 874939	ELENA EFIMOVA	{"email": "efimova-e_05051970@postgrespro.ru", "phone": "+70184860626"}
0005435177507	760BEA	1922 517152	VITALIY TIKHONOV	{"phone": "+70714439685"}
0005435177508	AFE044	6803 007436	IVAN KOZLOV	{"phone": "+70924527356"}
0005435177509	AFE044	8491 629263	FARID VLASOV	{"phone": "+70899284743"}
0005435177510	73EB9D	9154 172294	SERGEY MELNIKOV	{"phone": "+70985488849"}
0005435177511	46B9D3	8769 058987	ALEKSANDR MOROZOV	{"phone": "+70895432580"}
0005435177512	513592	6095 206728	VYACHESLAV SCHERBAKOV	{"phone": "+70292775310"}
0005435177513	C22EFB	2971 836271	ELENA TIKHONOVA	{"phone": "+70939602300"}
0005435177514	D09482	3897 257527	DENIS DENISOV	{"email": "d.denisov14091971@postgrespro.ru", "phone": "+70434460634"}
0005435177515	A5650B	7329 428420	YULIYA VLASOVA	{"phone": "+70940641183"}
0005435177516	559AD3	8844 016217	GALINA FEDOROVA	{"email": "fedorova-g25091978@postgrespro.ru", "phone": "+70571729564"}
0005435177517	559AD3	7049 536504	MARFA GAVRILOVA	{"phone": "+70245008718"}
0005435177518	BEB249	8488 434361	VLADIMIR OSIPOV	{"phone": "+70237176823"}
0005435177519	BEB249	4343 996089	VALERIY FEDOTOV	{"email": "fedotovvaleriy_1972@postgrespro.ru", "phone": "+70126957911"}
0005435177520	353B6F	3240 290911	GALINA SOKOLOVA	{"email": "galina.sokolova-1963@postgrespro.ru", "phone": "+70448472295"}
0005435177521	41CBC4	0908 400355	VLADIMIR KRASNOV	{"email": "krasnovvladimir_30071972@postgrespro.ru", "phone": "+70345673763"}
0005435177522	777B52	3689 616883	ANDREY SIDOROV	{"phone": "+70290057031"}
0005435177523	777B52	7764 037993	TATYANA DMITRIEVA	{"phone": "+70202666486"}
0005435177524	E738AE	2282 398903	KIRILL SCHERBAKOV	{"phone": "+70559055836"}
0005435177525	ED18BB	9951 303799	IRINA KONOVALOVA	{"phone": "+70000295773"}
0005435177526	ED18BB	6153 914493	VLADIMIR ROMANOV	{"email": "romanov.v22121971@postgrespro.ru", "phone": "+70895219250"}
0005435177527	F39E66	2964 570166	NIKITA IVANOV	{"phone": "+70892003905"}
0005435177528	F39E66	0003 351093	OKSANA FADEEVA	{"phone": "+70748612222"}
0005435177529	B6BE76	0225 734114	KONSTANTIN IVANOV	{"email": "ivanovkonstantin_051976@postgrespro.ru", "phone": "+70996922404"}
0005435177530	B6BE76	7377 670894	ALEKSANDR ALEKSEEV	{"phone": "+70446191019"}
0005435177531	B7C836	8975 238178	SERGEY SEMENOV	{"phone": "+70583296216"}
0005435177532	6DE8C2	5259 505740	ELENA KUZNECOVA	{"phone": "+70841040873"}
0005435177533	D98B31	7296 440616	ALEKSANDRA POTAPOVA	{"phone": "+70707054057"}
0005435177534	0B9029	4179 460002	IGOR BARANOV	{"phone": "+70569093430"}
0005435177535	C603B6	4115 491779	MARINA PETROVA	{"email": "m-petrova.111963@postgrespro.ru", "phone": "+70308687351"}
0005435177536	F2FACD	3270 147683	VIKTOR KUDRYASHOV	{"email": "kudryashov-viktor_1975@postgrespro.ru", "phone": "+70052959200"}
0005435177537	651774	9735 838322	SERGEY RODIONOV	{"phone": "+70421430788"}
0005435177538	001FA7	5034 436011	LYUDMILA BELYAEVA	{"phone": "+70646808271"}
0005435177539	001FA7	2086 655659	OLGA MIKHAYLOVA	{"phone": "+70330730964"}
0005435177540	3FE3E7	2744 297450	EVGENIYA KOVALEVA	{"phone": "+70326157425"}
0005435177541	3FE3E7	6680 459126	ILYA IVANOV	{"email": "ivanovilya-19091968@postgrespro.ru", "phone": "+70958367393"}
0005435177542	571B24	6158 554637	DMITRIY ILIN	{"email": "ilin.dmitriy_1970@postgrespro.ru", "phone": "+70332878463"}
0005435177543	571B24	9636 263356	IVAN ZHURAVLEV	{"phone": "+70593661639"}
0005435177544	9BC6E9	1110 478273	IOSIF NAZAROV	{"email": "nazarov-iosif1968@postgrespro.ru", "phone": "+70594156501"}
0005435177545	9BC6E9	7494 031095	ELENA NIKOLAEVA	{"email": "nikolaeva.elena.08071975@postgrespro.ru", "phone": "+70424393352"}
0005435177546	067176	9132 531943	NADEZHDA KRASNOVA	{"email": "krasnova_n011967@postgrespro.ru", "phone": "+70495591134"}
0005435177547	067176	0533 123048	NATALYA ZAKHAROVA	{"phone": "+70284232742"}
0005435177548	2C6D30	7765 324313	ELENA MEDVEDEVA	{"phone": "+70763649901"}
0005435177549	2C6D30	1982 443993	ZINAIDA KOROLEVA	{"phone": "+70108192804"}
0005435177550	CB9358	4298 245577	ALEKSANDRA EFREMOVA	{"phone": "+70195454172"}
0005435177551	CB9358	6351 924573	SEMEN ABRAMOV	{"email": "s.abramov.051961@postgrespro.ru", "phone": "+70148252429"}
0005435177552	EF86DF	1420 680485	MARIYA MAKAROVA	{"phone": "+70679386161"}
0005435177553	E66DB2	9133 986755	LYUBOV PAVLOVA	{"email": "l.pavlova-111966@postgrespro.ru", "phone": "+70712237632"}
0005435177554	C9EA41	6648 226750	TATYANA FROLOVA	{"email": "frolova-tatyana-061967@postgrespro.ru", "phone": "+70086122536"}
0005435177555	C9EA41	4974 161979	ELIZAVETA VASILEVA	{"email": "vasilevaelizaveta111974@postgrespro.ru", "phone": "+70869084066"}
0005435177556	6571C1	8485 804609	YURIY FEDOROV	{"phone": "+70511515146"}
0005435177557	6571C1	3925 542374	KAMILA NAZAROVA	{"phone": "+70638839734"}
0005435177558	25CB95	8224 862397	OKSANA MIRONOVA	{"email": "mironova-o-1980@postgrespro.ru", "phone": "+70908636666"}
0005435177559	BF1BF0	6255 750391	VIKTORIYA SOROKINA	{"phone": "+70283289757"}
0005435177560	D4A761	2656 016999	LYUDMILA POPOVA	{"email": "popoval1966@postgrespro.ru", "phone": "+70600993418"}
0005435177561	D4A761	7491 894965	ALEKSANDR POPOV	{"phone": "+70812057961"}
0005435177562	98AF9B	3159 302890	ALEKSANDR KUZNECOV	{"email": "akuznecov.26101976@postgrespro.ru", "phone": "+70081196023"}
0005435177563	ADEFBA	7807 163981	IGOR VASILEV	{"email": "vasilevigor_1967@postgrespro.ru", "phone": "+70621508685"}
0005435177564	310F30	8777 304130	NINA ANDREEVA	{"email": "nina.andreeva_13101979@postgrespro.ru", "phone": "+70985413543"}
0005435177565	A0CC40	8838 943056	ANNA FROLOVA	{"phone": "+70161347982"}
0005435177566	204DD2	4539 641343	ALENA IVANOVA	{"email": "alena_ivanova-1995@postgrespro.ru", "phone": "+70882112545"}
0005435177567	093FF8	5873 910193	NATALYA GORBUNOVA	{"phone": "+70775153906"}
0005435177568	093FF8	6428 650339	ELIZAVETA MIRONOVA	{"phone": "+70652657876"}
0005435177569	3A40D4	9390 370740	TIMUR RODIONOV	{"email": "rodionov_t.29071987@postgrespro.ru", "phone": "+70305571239"}
0005435177570	6FC1DC	6850 812709	VALENTINA OSIPOVA	{"phone": "+70432558605"}
0005435177571	6FC1DC	2235 634449	SERGEY BONDARENKO	{"email": "bondarenko-sergey1979@postgrespro.ru", "phone": "+70846702164"}
0005435177572	75A4CC	1469 609058	MARIYA ZAYCEVA	{"phone": "+70577395422"}
0005435177573	75A4CC	3257 845383	VYACHESLAV MAKAROV	{"email": "makarov-v_20101959@postgrespro.ru", "phone": "+70154813319"}
0005435177574	5FE7AC	0442 635138	TATYANA SCHERBAKOVA	{"phone": "+70588607111"}
0005435177575	DF7F72	8615 387544	NATALYA NIKOLAEVA	{"email": "natalya-nikolaeva-1978@postgrespro.ru", "phone": "+70663953362"}
0005435177576	EE8BEC	1494 664467	NINA GRISHINA	{"phone": "+70391412664"}
0005435177577	6086C4	0903 638141	MIKHAIL PETROV	{"email": "m-petrov.10071966@postgrespro.ru", "phone": "+70430727387"}
0005435177578	D9D55E	0605 179155	DMITRIY NIKITIN	{"phone": "+70026859677"}
0005435177579	D9D55E	7261 251812	ALEKSANDR GORBUNOV	{"phone": "+70178760282"}
0005435177580	D9D55E	2810 131227	NIKOLAY FILIPPOV	{"email": "nikolay_filippov1982@postgrespro.ru", "phone": "+70643615077"}
0005435177581	DD7E74	7145 887842	ALEKSANDR GORBUNOV	{"email": "agorbunov-111965@postgrespro.ru", "phone": "+70599239902"}
0005435177582	E4D44B	2058 600593	VLADIMIR KARPOV	{"email": "v_karpov_051971@postgrespro.ru", "phone": "+70000700119"}
0005435177583	A28BCA	5336 105149	SERGEY NIKITIN	{"email": "s-nikitin05061962@postgrespro.ru", "phone": "+70394616135"}
0005435177584	EDF8E4	3023 964310	ANDREY GRIGOREV	{"email": "grigorev-andrey_1967@postgrespro.ru", "phone": "+70755981282"}
0005435177585	8AF306	1876 947757	VALERIY VOLKOV	{"email": "v_volkov021979@postgrespro.ru", "phone": "+70417613063"}
0005435177586	8AF306	6296 554093	EKATERINA KALININA	{"phone": "+70252573103"}
0005435177587	B35EDC	4804 246461	OLGA NOVIKOVA	{"email": "novikova_olga_021972@postgrespro.ru", "phone": "+70445333972"}
0005435177588	43A543	8742 788338	ALLA KRASNOVA	{"phone": "+70769090307"}
0005435177589	DC0812	9302 941799	EVGENIY MIKHAYLOV	{"phone": "+70883638688"}
0005435177590	09555E	2908 299480	DAVID FROLOV	{"email": "frolovdavid071973@postgrespro.ru", "phone": "+70632349491"}
0005435177591	09555E	6893 907509	SERGEY STEPANOV	{"email": "stepanov_sergey30031965@postgrespro.ru", "phone": "+70247724231"}
0005435177592	BEFB50	0251 041117	MARIYA KOZLOVA	{"email": "mariya.kozlova-091974@postgrespro.ru", "phone": "+70752322756"}
0005435177593	016E4E	8461 231635	EGOR KARPOV	{"email": "karpov_e1968@postgrespro.ru", "phone": "+70543653980"}
0005435177594	016E4E	5245 305952	ELENA ORLOVA	{"email": "orlova.elena_061972@postgrespro.ru", "phone": "+70286735038"}
0005435177595	3E7047	1964 301816	MARIYA EGOROVA	{"phone": "+70451226209"}
0005435177596	33C563	9756 088826	EVGENIY GUSEV	{"phone": "+70593398987"}
0005435177597	F0F4CF	6358 306181	VLADIMIR SMIRNOV	{"email": "smirnov_vladimir06101967@postgrespro.ru", "phone": "+70658488966"}
0005435177598	C27F70	4061 919909	TAKHIR KUZNECOV	{"email": "kuznecovt071973@postgrespro.ru", "phone": "+70054733422"}
0005435177599	557758	5070 841213	NIKOLAY GERASIMOV	{"email": "ngerasimov.071965@postgrespro.ru", "phone": "+70572879791"}
0005435177600	84B1C5	6475 865879	RUSLAN IVANOV	{"email": "ivanov-ruslan101966@postgrespro.ru", "phone": "+70254621306"}
0005435177601	C5D24C	5346 172882	OLEG VOLKOV	{"email": "olegvolkov-1966@postgrespro.ru", "phone": "+70888331820"}
0005435177602	B943A9	3640 540603	TAMARA ANTONOVA	{"phone": "+70469314169"}
0005435177603	B943A9	3237 406247	ALEKSEY IVANOV	{"email": "ivanov.aleksey_021969@postgrespro.ru", "phone": "+70684837466"}
0005435177604	52926B	4794 783712	NIKOLAY VOROBEV	{"phone": "+70789537231"}
0005435177605	4A452C	2491 946168	NIKOLAY NOVIKOV	{"phone": "+70954927572"}
0005435177606	13B68D	4910 629676	BORIS YAKOVLEV	{"email": "yakovlev-boris28081966@postgrespro.ru", "phone": "+70526360257"}
0005435177607	13B68D	2717 122041	ALINA POPOVA	{"phone": "+70333012148"}
0005435177608	21DA6D	8998 720155	IRINA SEMENOVA	{"phone": "+70292435257"}
0005435177609	E7389D	9171 220587	OLGA MAKSIMOVA	{"phone": "+70927638131"}
0005435177610	99BC1C	7578 072584	VLADIMIR FROLOV	{"email": "frolov.vladimir.25021972@postgrespro.ru", "phone": "+70090715283"}
0005435177611	14F395	7615 443057	ANNA DENISOVA	{"phone": "+70784443512"}
0005435177612	7DF218	3984 076694	SVETLANA AFANASEVA	{"phone": "+70184589235"}
0005435177613	7DF218	4609 176168	POLINA SEMENOVA	{"phone": "+70305903627"}
0005435177614	7DF218	2308 729949	IRINA KOZLOVA	{"email": "kozlova-i-1977@postgrespro.ru", "phone": "+70964641243"}
0005435177615	D7C524	9577 401576	SERGEY KUZNECOV	{"phone": "+70248096027"}
0005435177616	4B15F7	5562 927788	MAKSIM PETROV	{"email": "petrov.maksim-03081963@postgrespro.ru", "phone": "+70147807610"}
0005435177617	4B15F7	9745 210259	NIKITA VOLKOV	{"phone": "+70401273807"}
0005435177618	97C13C	0643 936383	GRIGORIY MOROZOV	{"email": "morozov.grigoriy-091971@postgrespro.ru", "phone": "+70059639202"}
0005435177619	CC16D7	4639 843402	ANNA ALEKSANDROVA	{"email": "aleksandrova.a041963@postgrespro.ru", "phone": "+70110444517"}
0005435177620	CC16D7	5146 345077	ANNA ZAYCEVA	{"phone": "+70235961531"}
0005435177621	CE75C8	4648 456449	ANNA CHERNOVA	{"email": "chernova-anna031970@postgrespro.ru", "phone": "+70109607227"}
0005435177622	C848B0	9727 705703	GALINA FILIPPOVA	{"email": "galina_filippova.26011975@postgrespro.ru", "phone": "+70424355247"}
0005435177623	A3AF07	1799 537888	ALEKSEY NIKITIN	{"email": "a.nikitin111982@postgrespro.ru", "phone": "+70024257084"}
0005435177624	A3AF07	9145 078316	SERGEY IVANOV	{"phone": "+70513678502"}
0005435177625	18B895	2723 653518	SERGEY ZHURAVLEV	{"email": "zhuravlev.sergey1972@postgrespro.ru", "phone": "+70091123603"}
0005435177682	2DDAE3	7819 502217	LYUDMILA DMITRIEVA	{"phone": "+70671119189"}
0005435177626	C6A40C	7524 371672	ARTEM SOKOLOV	{"email": "sokolova_1975@postgrespro.ru", "phone": "+70820872861"}
0005435177627	C6A40C	8274 443530	VIKTORIYA KUZMINA	{"phone": "+70173115874"}
0005435177628	0EB0B3	0349 569643	SERGEY DAVYDOV	{"phone": "+70857379818"}
0005435177629	0F9CDE	6520 244565	TAMARA ANDREEVA	{"email": "andreeva.t.121981@postgrespro.ru", "phone": "+70979979249"}
0005435177630	0F9CDE	6008 080979	ELEONORA MEDVEDEVA	{"email": "medvedeva_eleonora-1972@postgrespro.ru", "phone": "+70436605908"}
0005435177631	DF24EE	8135 319392	OLEG PAVLOV	{"email": "o_pavlov_071984@postgrespro.ru", "phone": "+70663054475"}
0005435177632	DF24EE	7906 316867	ALINA KOVALEVA	{"phone": "+70715743458"}
0005435177633	76580C	8511 003470	DMITRIY KULIKOV	{"email": "kulikovdmitriy.051964@postgrespro.ru", "phone": "+70108831256"}
0005435177634	2B8F23	9629 964038	ANDREY VASILEV	{"email": "avasilev_03031970@postgrespro.ru", "phone": "+70522335412"}
0005435177635	2B8F23	7212 457147	EVGENIYA ZAKHAROVA	{"phone": "+70602941523"}
0005435177636	9A9744	5323 885155	MIKHAIL NIKITIN	{"phone": "+70955299966"}
0005435177637	A86D9D	0566 647747	LYUBOV KONOVALOVA	{"phone": "+70704385314"}
0005435177638	FD94C7	7332 100673	MAKSIM DENISOV	{"phone": "+70379535275"}
0005435177639	131E0B	0264 671375	ALEKSANDR SOKOLOV	{"email": "a_sokolov1966@postgrespro.ru", "phone": "+70139580853"}
0005435177640	9BE9CE	0810 043560	SEMEN MOROZOV	{"phone": "+70095006134"}
0005435177641	9BF1A6	1279 222266	ANTONINA IVANOVA	{"phone": "+70267160342"}
0005435177642	2E2DF2	9534 500389	SERGEY ILIN	{"phone": "+70332530340"}
0005435177643	2E2DF2	8773 034189	YULIYA KONOVALOVA	{"phone": "+70954748743"}
0005435177644	DD93C2	1515 089531	VALERIY DENISOV	{"phone": "+70966402384"}
0005435177645	090968	8450 913321	TATYANA BARANOVA	{"phone": "+70590865076"}
0005435177646	F68529	2786 541217	SVETLANA KOLESNIKOVA	{"email": "svetlana.kolesnikova.1964@postgrespro.ru", "phone": "+70322232390"}
0005435177647	AEF81A	3347 884505	ALINA FADEEVA	{"email": "fadeeva-alina-19111978@postgrespro.ru", "phone": "+70788781466"}
0005435177648	0DC695	5405 132049	ANDREY KULIKOV	{"email": "a.kulikov_091969@postgrespro.ru", "phone": "+70859142710"}
0005435177649	2EEB28	1549 659447	MARIYA ISAEVA	{"email": "isaeva-mariya.051966@postgrespro.ru", "phone": "+70323699096"}
0005435177650	1E807C	8042 245036	VIKTOR SMIRNOV	{"email": "smirnov.v06111980@postgrespro.ru", "phone": "+70780497356"}
0005435177651	1E807C	8961 445351	BORIS VOROBEV	{"phone": "+70192527024"}
0005435177652	1E807C	1340 430972	IRINA GAVRILOVA	{"phone": "+70558644655"}
0005435177653	8E296C	1428 889650	GALINA DMITRIEVA	{"email": "galinadmitrieva.07011978@postgrespro.ru", "phone": "+70202015012"}
0005435177654	3451ED	0204 611610	ELENA ZAKHAROVA	{"phone": "+70340122693"}
0005435177655	0E43FD	8187 346363	YURIY MIKHAYLOV	{"email": "mikhaylov-yuriy1975@postgrespro.ru", "phone": "+70922759154"}
0005435177656	0E43FD	4026 025721	VALENTINA KOMAROVA	{"phone": "+70967714833"}
0005435177657	BABD25	1468 937013	DENIS IVANOV	{"email": "ivanov.d.011971@postgrespro.ru", "phone": "+70385969007"}
0005435177658	BABD25	0835 364091	IGOR GUSEV	{"phone": "+70202789554"}
0005435177659	10BB83	9980 701860	EKATERINA MOROZOVA	{"email": "e_morozova-121981@postgrespro.ru", "phone": "+70721925206"}
0005435177660	142C57	5497 281406	MARIYA ZHURAVLEVA	{"phone": "+70003458380"}
0005435177661	BEB0A3	9543 600945	SERGEY BELOV	{"phone": "+70246549934"}
0005435177662	D91C7D	8738 434638	SVETLANA ERMAKOVA	{"email": "ermakova-s.28031976@postgrespro.ru", "phone": "+70912840830"}
0005435177663	565936	2775 212785	ALEKSEY POPOV	{"phone": "+70295609604"}
0005435177664	1741AB	3835 553706	SVETLANA MASLOVA	{"phone": "+70213812533"}
0005435177665	92F0D6	7175 249741	TAMARA PETROVA	{"phone": "+70307501271"}
0005435177666	92F0D6	7255 196844	OLGA KOLESNIKOVA	{"email": "olga_kolesnikova22041969@postgrespro.ru", "phone": "+70911493079"}
0005435177667	FE5FC9	4560 428957	ALEKSANDRA IVANOVA	{"email": "aleksandraivanova.24071974@postgrespro.ru", "phone": "+70076738404"}
0005435177668	FE5FC9	1959 301294	TAISIYA YUDINA	{"phone": "+70570078546"}
0005435177669	FE5FC9	0898 764277	YULIYA SERGEEVA	{"email": "sergeeva-y.1972@postgrespro.ru", "phone": "+70762611072"}
0005435177670	8C22A8	1643 386668	SERGEY IVANOV	{"phone": "+70979448438"}
0005435177671	92A45B	1435 605700	ALEKSEY TARASOV	{"phone": "+70343661835"}
0005435177672	722988	4885 954435	VLADIMIR FILIPPOV	{"phone": "+70060142773"}
0005435177673	722988	5993 616940	VERA ABRAMOVA	{"phone": "+70377088376"}
0005435177674	55E2E4	0516 756215	IRINA LUKYANOVA	{"phone": "+70621291711"}
0005435177675	14ECCE	9283 602702	SERGEY ROMANOV	{"email": "sergey_romanov-03021976@postgrespro.ru", "phone": "+70678235088"}
0005435177676	14ECCE	2276 737994	ANATOLIY RODIONOV	{"email": "a-rodionov-25061973@postgrespro.ru", "phone": "+70680208676"}
0005435177677	61192B	5819 165636	YULIYA MAKAROVA	{"email": "makarovayuliya_1964@postgrespro.ru", "phone": "+70985951472"}
0005435177678	115691	0769 554366	NATALIYA MASLOVA	{"email": "maslova_n.071973@postgrespro.ru", "phone": "+70328460564"}
0005435177679	7BF09B	4736 351617	NATALYA KOZLOVA	{"email": "natalya-kozlova_14111977@postgrespro.ru", "phone": "+70273850761"}
0005435177680	C52FBD	1939 217023	NIKOLAY TIMOFEEV	{"email": "n-timofeev.081977@postgrespro.ru", "phone": "+70871476722"}
0005435177681	97D63A	4504 628120	NIKOLAY CHERNOV	{"phone": "+70309512847"}
0005435177683	2DDAE3	0417 139158	SAMVEL NIKITIN	{"phone": "+70727342703"}
0005435177684	26A112	9661 649850	ALEKSANDR MARTYNOV	{"phone": "+70192304547"}
0005435177685	A0BFF5	8940 119624	ALEKSEY KOZLOV	{"email": "akozlov1976@postgrespro.ru", "phone": "+70333844342"}
0005435177686	12B4BB	8295 981664	ALEKSANDR SOKOLOV	{"email": "aleksandr.sokolov.09061964@postgrespro.ru", "phone": "+70262017268"}
0005435177687	12B4BB	5449 214264	SERGEY YAKOVLEV	{"phone": "+70327358039"}
0005435177688	12B4BB	2595 883209	ANASTASIYA SAVELEVA	{"email": "saveleva_a_061957@postgrespro.ru", "phone": "+70390973754"}
0005435177689	FDB185	2583 543594	LYUBOV BOGDANOVA	{"email": "bogdanova.lyubov-21041964@postgrespro.ru", "phone": "+70604146361"}
0005435177690	756C7C	2258 178091	MIKHAIL ZHURAVLEV	{"email": "m.zhuravlev.031982@postgrespro.ru", "phone": "+70918502349"}
0005435177691	1CB617	2239 611147	YULIYA NIKOLAEVA	{"phone": "+70359713115"}
0005435177692	548711	2308 039872	NINA NAZAROVA	{"email": "n.nazarova1962@postgrespro.ru", "phone": "+70478852772"}
0005435177693	548711	5569 188653	VALERIY RODIONOV	{"email": "v.rodionov.12091980@postgrespro.ru", "phone": "+70003748533"}
0005435177694	8B33AD	4282 201732	GALINA DENISOVA	{"email": "denisova.g.1968@postgrespro.ru", "phone": "+70970896693"}
0005435177695	5C57F5	6335 978254	NINEL ALEKSANDROVA	{"phone": "+70420068177"}
0005435177696	7E69C4	0050 337060	STANISLAV KUZNECOV	{"phone": "+70883283503"}
0005435177697	D8B132	0707 253618	TATYANA TARASOVA	{"email": "tarasova-t061976@postgrespro.ru", "phone": "+70167462460"}
0005435177698	AC6F64	2797 417756	EKATERINA KUZNECOVA	{"phone": "+70688668683"}
0005435177699	24A4DB	7437 461980	ARTEM SEMENOV	{"phone": "+70952741356"}
0005435177700	24A4DB	2854 650012	ILYA NIKOLAEV	{"phone": "+70177933730"}
0005435177701	453D77	2338 965013	KSENIYA NIKOLAEVA	{"phone": "+70004576026"}
0005435177702	5D8BF8	7687 402682	ROMAN SOKOLOV	{"email": "r.sokolov1974@postgrespro.ru", "phone": "+70651380227"}
0005435177703	0640BA	8588 666453	ANTON VOLKOV	{"email": "a_volkov-04081977@postgrespro.ru", "phone": "+70534104203"}
0005435177704	96B0C0	5635 506452	PETR SMIRNOV	{"phone": "+70373618424"}
0005435177705	A866ED	9672 919591	ANNA SIDOROVA	{"email": "a_sidorova.101982@postgrespro.ru", "phone": "+70060701451"}
0005435177706	758A7C	1965 362797	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.05021971@postgrespro.ru", "phone": "+70583123835"}
0005435177707	5E034C	6939 155912	IVAN FEDOROV	{"email": "fedorov-i_1958@postgrespro.ru", "phone": "+70184893664"}
0005435177708	5E034C	1136 756740	MIKHAIL EGOROV	{"email": "mikhail.egorov-1959@postgrespro.ru", "phone": "+70560491924"}
0005435177709	AEBE3E	4161 457919	INESSA POPOVA	{"email": "i_popova-1968@postgrespro.ru", "phone": "+70762120952"}
0005435177710	AEBE3E	8446 512264	YAN EGOROV	{"phone": "+70395841625"}
0005435177711	AEBE3E	9966 160033	ANATOLIY SOROKIN	{"phone": "+70017967072"}
0005435177712	AEBE3E	8716 328509	ALEKSANDRA DAVYDOVA	{"phone": "+70999942406"}
0005435177713	E5D6B5	2253 593963	YURIY IVANOV	{"phone": "+70508206919"}
0005435177714	E5D6B5	0124 889572	IVAN BARANOV	{"phone": "+70962473307"}
0005435177715	BD11A3	5361 031051	VIKTOR ALEKSEEV	{"email": "viktor.alekseev.061965@postgrespro.ru", "phone": "+70155097661"}
0005435177716	E7A8D3	7839 461305	VYACHESLAV PAVLOV	{"email": "v-pavlov-01101965@postgrespro.ru", "phone": "+70213955351"}
0005435177717	4E76DB	1506 537686	VLADIMIR FEDOTOV	{"email": "v.fedotov_091975@postgrespro.ru", "phone": "+70616246556"}
0005435177718	4E76DB	8043 786427	NINA TIKHONOVA	{"phone": "+70006748240"}
0005435177719	976055	8918 877532	ALEKSANDR OSIPOV	{"phone": "+70292490252"}
0005435177720	976055	2221 141689	DARYA ABRAMOVA	{"phone": "+70977648261"}
0005435177721	74E090	1147 710720	ALEKSEY ILIN	{"email": "ilina27011982@postgrespro.ru", "phone": "+70575377688"}
0005435177722	ADBE71	8516 277570	RAFIS KOZLOV	{"phone": "+70256670724"}
0005435177723	0357ED	4654 043758	VALERIYA FROLOVA	{"email": "frolova-v_27021966@postgrespro.ru", "phone": "+70710175641"}
0005435177724	0357ED	7899 121638	MARIYA BELOVA	{"phone": "+70453704051"}
0005435177725	5C65FE	4206 849933	SERGEY MOROZOV	{"phone": "+70835470118"}
0005435177726	7911BC	6355 244948	GALINA MOROZOVA	{"email": "morozova.g.021967@postgrespro.ru", "phone": "+70763560068"}
0005435177727	E3B9AB	1230 018972	OKSANA SEMENOVA	{"email": "semenova_oksana.1970@postgrespro.ru", "phone": "+70306528530"}
0005435177728	7E3CB3	6920 523863	ALIYA FOMINA	{"email": "a.fomina_051970@postgrespro.ru", "phone": "+70888119038"}
0005435177729	8378D3	3841 339847	MARINA SIDOROVA	{"phone": "+70488031995"}
0005435177730	84612D	0728 700104	OLEG FOMIN	{"email": "o_fomin_1960@postgrespro.ru", "phone": "+70886821475"}
0005435177731	ED32DE	4752 037402	TATYANA LOGINOVA	{"phone": "+70566683925"}
0005435177732	397828	3943 091364	DMITRIY MOISEEV	{"phone": "+70904703003"}
0005435177733	251ED5	2927 321873	NINA ANDREEVA	{"email": "andreeva-n1967@postgrespro.ru", "phone": "+70815856995"}
0005435177734	2F9B4A	6947 116865	ALEKSEY AFANASEV	{"phone": "+70726284228"}
0005435177735	2F9B4A	2298 937594	VALENTIN STEPANOV	{"email": "valentin-stepanov-01011963@postgrespro.ru", "phone": "+70649274202"}
0005435177736	6CF042	6651 560765	ANDREY SCHERBAKOV	{"email": "a_scherbakov_071967@postgrespro.ru", "phone": "+70884520523"}
0005435177737	B7BFAE	9881 926219	ARTEM MOISEEV	{"email": "moiseev.artem_1978@postgrespro.ru", "phone": "+70674674378"}
0005435177738	A8842B	1106 388417	NIKOLAY NOVIKOV	{"phone": "+70213204571"}
0005435177739	A8842B	1180 181643	VLADIMIR VOLKOV	{"email": "volkovvladimir1974@postgrespro.ru", "phone": "+70433875351"}
0005435177740	6BF948	4915 614184	ARTEM ZAKHAROV	{"email": "zakharov.artem.29081971@postgrespro.ru", "phone": "+70858300809"}
0005435177741	51302D	7276 238119	NATALYA FOMINA	{"phone": "+70122425349"}
0005435177742	51302D	3560 752447	NADEZHDA MELNIKOVA	{"email": "melnikova.n071974@postgrespro.ru", "phone": "+70063696815"}
0005435177743	AD56F6	4155 672334	VALENTINA VASILEVA	{"email": "vasileva.valentina.21021974@postgrespro.ru", "phone": "+70267473752"}
0005435177744	AD56F6	6511 356855	EKATERINA MEDVEDEVA	{"email": "medvedeva.e.05021966@postgrespro.ru", "phone": "+70005747687"}
0005435177745	DC9F20	1062 219430	ILYA KAZAKOV	{"email": "kazakov-ilya06021966@postgrespro.ru", "phone": "+70804606528"}
0005435177746	DC9F20	7707 227169	YULIYA LAZAREVA	{"email": "yuliya.lazareva_1973@postgrespro.ru", "phone": "+70573940711"}
0005435177747	6AFDE4	8350 282772	MIKHAIL DAVYDOV	{"email": "davydov-m071971@postgrespro.ru", "phone": "+70172472573"}
0005435177748	98C188	6367 066709	RAISA SOLOVEVA	{"email": "r.soloveva-1963@postgrespro.ru", "phone": "+70297707174"}
0005435177749	028437	9537 346180	VLADIMIR SMIRNOV	{"email": "vladimir_smirnov-071972@postgrespro.ru", "phone": "+70875814783"}
0005435177750	E07CB7	7741 651500	EVGENIY MOROZOV	{"phone": "+70651719116"}
0005435177751	E07CB7	3091 060457	ALINA NIKOLAEVA	{"phone": "+70425046910"}
0005435177752	D06A83	1175 557529	GEORGIY ZAKHAROV	{"phone": "+70147622832"}
0005435177753	5EB6ED	9779 088256	OLGA NIKIFOROVA	{"email": "nikiforova.o.1973@postgrespro.ru", "phone": "+70953841711"}
0005435177754	C3E122	0810 960568	ULYANA BORISOVA	{"phone": "+70123383227"}
0005435177755	552F07	9290 118683	ALEFTINA STEPANOVA	{"phone": "+70816763249"}
0005435177756	1BF03B	0602 560393	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr.101977@postgrespro.ru", "phone": "+70500566032"}
0005435177757	B991FE	6579 650286	LIDIYA SIDOROVA	{"phone": "+70472244734"}
0005435177758	B991FE	6578 310407	DENIS MIKHAYLOV	{"email": "d-mikhaylov1968@postgrespro.ru", "phone": "+70422192602"}
0005435177759	62661F	2029 840021	NADEZHDA ALEKSEEVA	{"phone": "+70776692052"}
0005435177760	EBA504	9854 024922	MIKHAIL ANDREEV	{"email": "andreev-mikhail1975@postgrespro.ru", "phone": "+70433846187"}
0005435177761	E984B8	9176 132981	LIDIYA DAVYDOVA	{"phone": "+70523708580"}
0005435177762	492C42	5025 269234	ANDREY BARANOV	{"email": "andrey_baranov-081966@postgrespro.ru", "phone": "+70307863464"}
0005435177763	492C42	3889 283935	LYUDMILA SEMENOVA	{"email": "lsemenova-1972@postgrespro.ru", "phone": "+70915008672"}
0005435177764	B93E9C	7398 866517	MARINA KUZNECOVA	{"email": "kuznecova.marina1966@postgrespro.ru", "phone": "+70366293697"}
0005435177765	57C79D	9418 940536	EVGENIY BORISOV	{"phone": "+70129387577"}
0005435177766	74791F	7953 938317	ALEKSEY MELNIKOV	{"email": "melnikov_aleksey-1959@postgrespro.ru", "phone": "+70989578348"}
0005435177767	C2EE55	0084 960489	GALINA ALEKSANDROVA	{"phone": "+70343702089"}
0005435177768	0A7637	1529 277801	DMITRIY FEDOTOV	{"phone": "+70673547466"}
0005435177769	5F17F4	8791 506862	IVAN GERASIMOV	{"email": "i-gerasimov-1963@postgrespro.ru", "phone": "+70318423964"}
0005435177770	5F17F4	2079 565013	MAKSIM ZHURAVLEV	{"phone": "+70700291503"}
0005435177771	199175	7775 027827	VALERIY SIDOROV	{"phone": "+70030050830"}
0005435177772	08EA55	6518 523848	OLGA PAVLOVA	{"email": "pavlova_o-1978@postgrespro.ru", "phone": "+70434012159"}
0005435177773	08EA55	3400 877422	ELENA KUZNECOVA	{"email": "e_kuznecova-07071975@postgrespro.ru", "phone": "+70368995889"}
0005435177774	CEA51A	9877 119095	NATALIYA DMITRIEVA	{"phone": "+70898099235"}
0005435177775	DDC1BC	2844 716297	VERA KONOVALOVA	{"phone": "+70754173672"}
0005435177776	9E5968	1694 945708	RUSLAN OSIPOV	{"phone": "+70310731870"}
0005435177777	598A1A	4481 223821	NIKOLAY ILIN	{"email": "ilin.n.121971@postgrespro.ru", "phone": "+70346541564"}
0005435177778	598A1A	5233 102128	PAVEL MELNIKOV	{"phone": "+70444725787"}
0005435177779	37F841	7968 574674	STANISLAV KAZAKOV	{"email": "kazakov_stanislav.1976@postgrespro.ru", "phone": "+70032967937"}
0005435177780	12F3F7	0569 743606	MAKSIM SEMENOV	{"phone": "+70270129290"}
0005435177781	4D9B7D	2862 334373	RUSLAN SAVELEV	{"phone": "+70977773209"}
0005435177782	5772E5	8311 455837	LYUDMILA SCHERBAKOVA	{"email": "lscherbakova1962@postgrespro.ru", "phone": "+70311635311"}
0005435177783	2B82F7	1783 934571	ALEKSANDR POPOV	{"email": "popova_121975@postgrespro.ru", "phone": "+70374203746"}
0005435177784	BE6B13	8440 315577	YURIY GORBUNOV	{"phone": "+70258279373"}
0005435177785	45C060	4606 976564	NIKOLAY SOLOVEV	{"phone": "+70790393807"}
0005435177786	DFD881	9636 028395	KLAVDIYA MAKSIMOVA	{"email": "maksimova.klavdiya-041969@postgrespro.ru", "phone": "+70245005303"}
0005435177787	DFD881	3405 733066	KONSTANTIN SMIRNOV	{"phone": "+70690286251"}
0005435177788	1395D1	5039 153471	MAKSIM SAVELEV	{"phone": "+70152367274"}
0005435177789	389661	4021 590145	ALEKSANDR YAKOVLEV	{"phone": "+70997063287"}
0005435177790	63F1D0	1832 734485	VLADISLAV MEDVEDEV	{"phone": "+70398660541"}
0005435177791	44C04A	7050 488441	SERGEY MELNIKOV	{"email": "smelnikov.031953@postgrespro.ru", "phone": "+70989636691"}
0005435177792	2153FA	1433 684160	SERGEY IVANOV	{"email": "s-ivanov_18121976@postgrespro.ru", "phone": "+70525603141"}
0005435177793	2153FA	0444 309471	IRINA IVANOVA	{"email": "ivanova-i_03031976@postgrespro.ru", "phone": "+70877717037"}
0005435177794	F56AF7	6859 500081	VALENTIN SMIRNOV	{"phone": "+70630639556"}
0005435177795	1F4DB8	7229 803873	ALEKSEY KARPOV	{"email": "akarpov1975@postgrespro.ru", "phone": "+70820816154"}
0005435177796	1F4DB8	0990 093654	DMITRIY SERGEEV	{"email": "sergeev.dmitriy.111966@postgrespro.ru", "phone": "+70141771013"}
0005435177797	988EE9	5333 395337	NIKOLAY NAZAROV	{"email": "nazarov_n1959@postgrespro.ru", "phone": "+70674865937"}
0005435177798	F5E9A5	4798 337302	ALEKSEY KRASNOV	{"phone": "+70238339263"}
0005435177799	529BCF	8801 782009	SERGEY AFANASEV	{"phone": "+70334843328"}
0005435177800	DEE070	5591 111785	NIKOLAY PAVLOV	{"email": "n.pavlov-111976@postgrespro.ru", "phone": "+70447960072"}
0005435177801	DEE070	9008 047015	VIKTORIYA KOZLOVA	{"phone": "+70478629459"}
0005435177802	68B4C1	4746 936388	YANINA GRISHINA	{"email": "y.grishina-111968@postgrespro.ru", "phone": "+70383687518"}
0005435177803	F93578	5186 409696	VYACHESLAV KRASNOV	{"phone": "+70626567993"}
0005435177804	ACDF07	4343 713071	LILIYA KRASNOVA	{"phone": "+70553525501"}
0005435177805	A64643	3053 541950	SERGEY MELNIKOV	{"email": "melnikov.s_1962@postgrespro.ru", "phone": "+70056511013"}
0005435177806	EA640A	3339 076155	LEONID FEDOTOV	{"email": "leonid-fedotov_25021975@postgrespro.ru", "phone": "+70894697865"}
0005435177807	AF4762	4839 303071	MAKSIM ZAKHAROV	{"email": "zakharov_m-19091976@postgrespro.ru", "phone": "+70994091544"}
0005435177808	3B925D	6269 698033	VYACHESLAV NOVIKOV	{"email": "v-novikov_111967@postgrespro.ru", "phone": "+70106394251"}
0005435177809	CD6512	4313 047082	MIKHAIL ZHURAVLEV	{"email": "m_zhuravlev.101973@postgrespro.ru", "phone": "+70099271065"}
0005435177810	CD6512	0077 524250	NATALYA KISELEVA	{"email": "kiseleva-natalya_1983@postgrespro.ru", "phone": "+70899009092"}
0005435177811	147E89	0004 071171	DENIS KARPOV	{"phone": "+70633564023"}
0005435177812	1A9030	0271 260171	ALEKSANDRA KUZNECOVA	{"phone": "+70914259302"}
0005435177813	9C4FF8	4628 967543	ANASTASIYA NIKITINA	{"email": "nikitinaanastasiya_081973@postgrespro.ru", "phone": "+70728167696"}
0005435177814	316A80	2498 779539	ANNA MALYSHEVA	{"email": "malyshevaanna.16121969@postgrespro.ru", "phone": "+70561839557"}
0005435177815	72904B	8568 255428	ANTONINA LOGINOVA	{"phone": "+70799430463"}
0005435177816	72904B	4496 411278	NATALIYA FILIPPOVA	{"email": "filippovan121960@postgrespro.ru", "phone": "+70257006974"}
0005435177817	E54E2B	8579 509498	VALENTINA DANILOVA	{"email": "v-danilova_041982@postgrespro.ru", "phone": "+70398383446"}
0005435177818	28676C	0768 000742	VYACHESLAV SERGEEV	{"email": "v.sergeev_1974@postgrespro.ru", "phone": "+70025508425"}
0005435177819	5D621F	4878 554318	DANIIL SOKOLOV	{"phone": "+70794086755"}
0005435177820	5D621F	9209 295037	VLADIMIR NIKITIN	{"phone": "+70733797236"}
0005435177821	FD11CB	0368 359907	NADEZHDA LEBEDEVA	{"email": "nlebedeva-1973@postgrespro.ru", "phone": "+70162952811"}
0005435177822	17D367	4516 949967	NADEZHDA ROMANOVA	{"email": "romanova-nadezhda-1974@postgrespro.ru", "phone": "+70330613643"}
0005435177823	4048DD	1689 971557	NIKOLAY PAVLOV	{"phone": "+70087137272"}
0005435177824	4048DD	3761 893661	ILYA BARANOV	{"email": "i-baranov.1968@postgrespro.ru", "phone": "+70556618809"}
0005435177825	ACE799	1870 043458	ANATOLIY SIDOROV	{"phone": "+70231863478"}
0005435177826	F7D194	5279 616876	SVETLANA FOMINA	{"phone": "+70524711949"}
0005435177827	349FD9	3900 456899	LYUDMILA FOMINA	{"email": "l.fomina04021972@postgrespro.ru", "phone": "+70409221022"}
0005435177828	349FD9	0179 220999	TATYANA MIRONOVA	{"phone": "+70743376248"}
0005435177829	43C92C	3274 797529	GALINA BOGDANOVA	{"phone": "+70346857222"}
0005435177830	03481E	6306 434487	ROZA STEPANOVA	{"phone": "+70698402430"}
0005435177831	EB5348	5582 562781	OLGA DANILOVA	{"phone": "+70545893822"}
0005435177832	4F7F42	5111 560452	EKATERINA EGOROVA	{"phone": "+70238248370"}
0005435177833	9BF3F0	1196 123223	ALEKSANDR GUSEV	{"email": "a_gusev-28061975@postgrespro.ru", "phone": "+70496444159"}
0005435177834	FD0B7E	9820 119315	POLINA ANTONOVA	{"email": "polina-antonova.1970@postgrespro.ru", "phone": "+70292076622"}
0005435177835	971197	8740 078241	EKATERINA SMIRNOVA	{"phone": "+70996249657"}
0005435177836	E0FA09	9782 175530	EVGENIY POPOV	{"phone": "+70078664603"}
0005435177837	E0FA09	2191 663184	NINA SOROKINA	{"email": "sorokina-n_27091981@postgrespro.ru", "phone": "+70662699551"}
0005435177838	C2DEA7	4317 122063	MARIYA RYABOVA	{"phone": "+70573643168"}
0005435177839	6D7FF5	8462 995499	VYACHESLAV DAVYDOV	{"email": "v-davydov.031961@postgrespro.ru", "phone": "+70777904497"}
0005435177840	217A18	2257 623997	KSENIYA SCHERBAKOVA	{"phone": "+70608883498"}
0005435177841	217A18	5237 489155	ALEKSEY ILIN	{"phone": "+70720419608"}
0005435177842	133223	9163 918833	VALENTINA ALEKSANDROVA	{"phone": "+70391817242"}
0005435177843	133223	2099 587396	NADEZHDA AFANASEVA	{"email": "n_afanaseva.22061979@postgrespro.ru", "phone": "+70360515037"}
0005435177844	157547	9968 112447	ALEKSEY ANDREEV	{"email": "aleksey-andreev-121966@postgrespro.ru", "phone": "+70976227296"}
0005435177845	07F00A	9074 099699	VIKTOR VASILEV	{"email": "vasilev-viktor1962@postgrespro.ru", "phone": "+70888595904"}
0005435177846	07F00A	0022 270737	VIKTOR DAVYDOV	{"email": "v_davydov_1980@postgrespro.ru", "phone": "+70274809198"}
0005435177847	47C8D6	6676 870489	ALLA SEMENOVA	{"phone": "+70969856008"}
0005435177848	47C8D6	8292 949226	ANTON KULIKOV	{"email": "kulikov-anton_1976@postgrespro.ru", "phone": "+70567018684"}
0005435177849	271522	0319 411580	DMITRIY MIRONOV	{"email": "mironovd_101974@postgrespro.ru", "phone": "+70546138799"}
0005435177850	51D5AB	0330 247774	NADEZHDA FROLOVA	{"email": "nfrolova011973@postgrespro.ru", "phone": "+70294039863"}
0005435177851	8EACC8	7158 769726	NINA ANISIMOVA	{"email": "anisimova-n.1961@postgrespro.ru", "phone": "+70730134399"}
0005435177852	09F77E	5383 140595	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova_anastasiya-1966@postgrespro.ru", "phone": "+70107107404"}
0005435177853	09F77E	2277 417270	ANDREY BELOV	{"email": "abelov-25091974@postgrespro.ru", "phone": "+70993099123"}
0005435177854	09F77E	2677 858444	LYUDMILA KOVALEVA	{"phone": "+70890835456"}
0005435177855	4A0E71	4549 369820	MAKSIM ANDREEV	{"phone": "+70398555144"}
0005435177856	A87411	4866 189169	KONSTANTIN KOZLOV	{"email": "konstantin.kozlov.10121973@postgrespro.ru", "phone": "+70482848353"}
0005435177857	3EC06D	5969 385747	MARINA MOISEEVA	{"email": "moiseeva.m-11101969@postgrespro.ru", "phone": "+70506793021"}
0005435177858	8FD9BB	1253 774648	VALENTIN VASILEV	{"email": "vasilev.v021969@postgrespro.ru", "phone": "+70285917360"}
0005435177859	A6EA85	6419 107584	PELAGEYA SCHERBAKOVA	{"phone": "+70066429894"}
0005435177860	3FE829	4608 301493	ANDREY KAZAKOV	{"phone": "+70460739722"}
0005435177861	97839F	4565 659252	OLGA OSIPOVA	{"email": "osipova_o031983@postgrespro.ru", "phone": "+70172144903"}
0005435177862	BF29AE	0716 921400	YULIYA ARKHIPOVA	{"phone": "+70168127164"}
0005435177863	BF29AE	1107 950588	ELENA NIKITINA	{"phone": "+70819387685"}
0005435177864	C535F1	2788 223260	RAVIL KOZLOV	{"email": "ravil-kozlov-031970@postgrespro.ru", "phone": "+70725470383"}
0005435177865	C535F1	4705 011989	ANNA BELYAEVA	{"email": "belyaevaanna_12021973@postgrespro.ru", "phone": "+70559614730"}
0005435177866	8F91D4	4341 961122	EVGENIY PETROV	{"email": "petrovevgeniy091971@postgrespro.ru", "phone": "+70682729870"}
0005435177867	8F91D4	2355 514567	RAIL GUSEV	{"email": "rgusev.121972@postgrespro.ru", "phone": "+70045826405"}
0005435177868	A6D57E	2467 103401	STANISLAV IVANOV	{"email": "stanislav-ivanov-071977@postgrespro.ru", "phone": "+70667792055"}
0005435177869	853B3B	6604 498781	VASILIY ALEKSANDROV	{"email": "aleksandrov-v-081976@postgrespro.ru", "phone": "+70263116265"}
0005435177870	337D03	7489 100166	GENNADIY IVANOV	{"email": "gennadiy.ivanov.25021974@postgrespro.ru", "phone": "+70858808787"}
0005435177871	337D03	9030 851046	RAISA SOROKINA	{"phone": "+70194658857"}
0005435177872	1A810D	8656 624469	ALEKSANDR BORISOV	{"phone": "+70658778775"}
0005435177873	C3DBC2	8747 732193	ALEKSEY MAKAROV	{"email": "makarovaleksey.041976@postgrespro.ru", "phone": "+70676930911"}
0005435177874	C3DBC2	1667 053711	DANILA MAKSIMOV	{"phone": "+70429624753"}
0005435177875	1274AC	1647 932142	NIKOLAY GORBUNOV	{"email": "gorbunovnikolay021963@postgrespro.ru", "phone": "+70193371733"}
0005435177876	60A931	9160 466384	YURIY ABRAMOV	{"email": "yuriyabramov-101975@postgrespro.ru", "phone": "+70695545792"}
0005435177877	C65199	2783 831144	OLGA KUZNECOVA	{"phone": "+70660207407"}
0005435177878	C65199	1945 241671	SERGEY TIKHONOV	{"email": "tikhonov-sergey-24031960@postgrespro.ru", "phone": "+70548035057"}
0005435177879	E27C5D	2777 621355	ALEVTINA IVANOVA	{"phone": "+70243624949"}
0005435177880	E27C5D	3134 886869	EKATERINA POLYAKOVA	{"email": "e_polyakova14091976@postgrespro.ru", "phone": "+70150194549"}
0005435178469	87A4E4	3272 540904	DENIS IVANOV	{"phone": "+70833357716"}
0005435178470	971CA0	1255 367646	VALERIY ALEKSEEV	{"phone": "+70801669118"}
0005435178471	456123	1643 569827	ANVAR ILIN	{"email": "ilin-a.14031978@postgrespro.ru", "phone": "+70063005800"}
0005435178472	3CB9E1	1598 899016	ALEKSANDR IVANOV	{"email": "a.ivanov_051970@postgrespro.ru", "phone": "+70010992432"}
0005435178473	4995D4	5929 764451	MARINA ORLOVA	{"email": "orlova.m01071958@postgrespro.ru", "phone": "+70604009932"}
0005435178474	B01B4D	4860 612470	OLGA SOROKINA	{"phone": "+70139962908"}
0005435178475	B01B4D	3173 096003	DENIS IVANOV	{"email": "divanov-25021967@postgrespro.ru", "phone": "+70805361777"}
0005435178476	8AC763	4256 890674	VITALIY VASILEV	{"email": "vasilev.v26081971@postgrespro.ru", "phone": "+70850911405"}
0005435178477	190CB6	9125 735626	YURIY SAVELEV	{"email": "savelev-y.25081975@postgrespro.ru", "phone": "+70046235163"}
0005435178478	66F9A7	0191 112861	LILIYA EFREMOVA	{"email": "liliya_efremova_101974@postgrespro.ru", "phone": "+70080502434"}
0005435178479	6F2D6A	2688 629561	ALEKSEY STEPANOV	{"phone": "+70717402485"}
0005435178480	DE6EFD	5373 580982	MARIYA KUZNECOVA	{"email": "mkuznecova25081982@postgrespro.ru", "phone": "+70386253017"}
0005435178481	EE290A	4459 700759	VALERIY GORBUNOV	{"phone": "+70171112051"}
0005435178482	38619D	7469 235068	TAISA TIMOFEEVA	{"email": "timofeeva-taisa_1966@postgrespro.ru", "phone": "+70270637070"}
0005435178483	A02838	0590 247906	YURIY KUZMIN	{"email": "kuzminy-05121968@postgrespro.ru", "phone": "+70960104977"}
0005435178484	1FAB1A	6047 045545	LYUBOV DENISOVA	{"phone": "+70296329219"}
0005435178485	D4FD59	2577 147451	ALEKSANDR KOZLOV	{"phone": "+70458356973"}
0005435178486	7D9C10	3518 522665	NINA KONOVALOVA	{"email": "ninakonovalova_1974@postgrespro.ru", "phone": "+70733458473"}
0005435178487	0F7134	1526 968043	EKATERINA MALYSHEVA	{"phone": "+70421485037"}
0005435178488	0F7134	9145 155452	VLADIMIR BELOV	{"email": "belov_v14081972@postgrespro.ru", "phone": "+70777801152"}
0005435178489	07FD0F	0848 322220	ELENA POLYAKOVA	{"phone": "+70210338545"}
0005435178490	F265BB	7795 527806	DIANA IVANOVA	{"phone": "+70618603045"}
0005435178491	F63E31	7205 182291	ALEKSANDR MOISEEV	{"phone": "+70626950079"}
0005435178492	F63E31	7902 386233	ANNA DMITRIEVA	{"phone": "+70426091879"}
0005435178493	AF6FCA	1295 470940	SOFIYA EGOROVA	{"phone": "+70680764555"}
0005435178494	ECB509	9763 702486	VIKTOR EGOROV	{"phone": "+70192333833"}
0005435178495	6F2483	8957 893082	SVETLANA TARASOVA	{"phone": "+70774856647"}
0005435178496	9567DC	2306 553692	ANDREY MEDVEDEV	{"phone": "+70422751740"}
0005435178497	9567DC	7669 688845	OLEG ZAYCEV	{"email": "o_zaycev1962@postgrespro.ru", "phone": "+70715293227"}
0005435178498	DFF6A3	3338 227856	VALENTINA SOLOVEVA	{"email": "soloveva.v1982@postgrespro.ru", "phone": "+70631635781"}
0005435178499	CC727C	4104 526964	SVETLANA MAKAROVA	{"email": "makarova_s_1966@postgrespro.ru", "phone": "+70754081671"}
0005435178500	34BE4F	6832 429395	ALEKSEY SIDOROV	{"email": "aleksey_sidorov-1985@postgrespro.ru", "phone": "+70093579499"}
0005435178501	43D037	3515 476641	IRINA KUZNECOVA	{"phone": "+70064298428"}
0005435178502	8192E3	8756 254449	MIKHAIL ALEKSANDROV	{"phone": "+70390863405"}
0005435178503	8192E3	6968 989691	VERONIKA VOLKOVA	{"email": "volkova_veronika_1969@postgrespro.ru", "phone": "+70755178942"}
0005435178504	AD4290	4410 261802	EKATERINA IVANOVA	{"phone": "+70173812025"}
0005435178505	69F8F7	6114 164314	MARINA BELOVA	{"email": "marina.belova_1969@postgrespro.ru", "phone": "+70385017011"}
0005435178506	F92432	0637 357082	VLADIMIR ZAYCEV	{"email": "zaycev.v23101972@postgrespro.ru", "phone": "+70293121983"}
0005435178507	DFCA03	5478 102583	NINA VOROBEVA	{"phone": "+70840802191"}
0005435178508	6A76D0	8017 213616	MARIYA KONDRATEVA	{"phone": "+70683151472"}
0005435178509	050671	8048 303924	ALEKSANDR KULIKOV	{"phone": "+70500987465"}
0005435178510	7AF423	4012 461196	NATALYA IVANOVA	{"phone": "+70119985239"}
0005435178511	B1118D	8993 314912	ANTONINA POPOVA	{"email": "popova-a-121979@postgrespro.ru", "phone": "+70394973489"}
0005435178512	C3300D	4463 973594	DMITRIY BORISOV	{"email": "borisov-d_1982@postgrespro.ru", "phone": "+70986156971"}
0005435178513	C3300D	4941 528939	ALEKSANDR IVANOV	{"email": "a_ivanov_1979@postgrespro.ru", "phone": "+70623601516"}
0005435178514	592361	5927 694579	BORIS IVANOV	{"phone": "+70240828724"}
0005435178515	5E9E14	6869 509195	ANNA PETROVA	{"phone": "+70811916567"}
0005435178516	BC8CC8	6013 276567	VLADISLAV BORISOV	{"email": "vborisov25101968@postgrespro.ru", "phone": "+70184900517"}
0005435178517	4E39E3	9166 513502	LYUBOV VOLKOVA	{"phone": "+70086925116"}
0005435178518	192A6A	9719 065517	ANNA EGOROVA	{"phone": "+70551973594"}
0005435178519	748EDF	3711 089213	ARTEM ZAYCEV	{"email": "artem.zaycev.041964@postgrespro.ru", "phone": "+70294845504"}
0005435178520	9E07DD	2594 535060	STANISLAV KUZNECOV	{"phone": "+70139219884"}
0005435178521	EBB639	4066 873613	MARAT MEDVEDEV	{"phone": "+70007043060"}
0005435178522	3D9695	9615 352302	VALENTINA NOVIKOVA	{"phone": "+70111502867"}
0005435178523	9B7FCD	9488 781836	LIDIYA KAZAKOVA	{"phone": "+70345783314"}
0005435178524	BC9D9C	2966 385230	ILYA YAKOVLEV	{"email": "yakovlev_i-16091984@postgrespro.ru", "phone": "+70435966136"}
0005435178525	113BCD	4630 467354	IVAN FOMIN	{"email": "ivanfomin.101977@postgrespro.ru", "phone": "+70048079191"}
0005435178526	33CA0E	9369 181996	NADEZHDA SIDOROVA	{"phone": "+70647299167"}
0005435178527	C4BA5A	9103 920135	IGOR CHERNOV	{"phone": "+70730300026"}
0005435178528	55D46D	0855 949493	SERGEY KONOVALOV	{"phone": "+70355502040"}
0005435178529	C7449A	2173 594580	SERGEY KULIKOV	{"email": "s_kulikov1970@postgrespro.ru", "phone": "+70278537084"}
0005435178530	C7449A	6020 541679	NATALYA YAKOVLEVA	{"phone": "+70593634396"}
0005435178531	390B79	0172 444393	LYUDMILA MAKAROVA	{"email": "lyudmila_makarova1974@postgrespro.ru", "phone": "+70911983847"}
0005435178532	390B79	2537 147777	GALINA MAKSIMOVA	{"email": "g-maksimova_1967@postgrespro.ru", "phone": "+70638780908"}
0005435178533	390B79	5968 076746	ANATOLIY MEDVEDEV	{"email": "medvedev.a1979@postgrespro.ru", "phone": "+70044250097"}
0005435178534	48D0DB	0980 348393	ROMAN AFANASEV	{"email": "rafanasev.28051975@postgrespro.ru", "phone": "+70098108225"}
0005435178535	48D0DB	9263 856655	OLGA ANTONOVA	{"phone": "+70259049782"}
0005435178536	C44A5B	7122 220419	ALEKSANDR FEDOROV	{"phone": "+70877807834"}
0005435178537	90C446	1657 313098	OLGA MASLOVA	{"phone": "+70459543924"}
0005435178538	B5BAC7	1410 049597	TAMARA BARANOVA	{"email": "baranovatamara-07101965@postgrespro.ru", "phone": "+70064588196"}
0005435178539	F311EC	3199 777929	ALEKSANDR VLASOV	{"phone": "+70332744719"}
0005435178540	064B97	7649 927457	LYUDMILA DENISOVA	{"email": "denisova-l-19041977@postgrespro.ru", "phone": "+70549696546"}
0005435178977	F246D1	2449 444253	ANNA TIMOFEEVA	{"email": "timofeeva.a1975@postgrespro.ru", "phone": "+70343906828"}
0005435178978	6535D5	5274 205147	VLADIMIR OSIPOV	{"email": "osipov_v_021968@postgrespro.ru", "phone": "+70932135413"}
0005435178979	88D74D	2285 203780	ELENA KRASNOVA	{"phone": "+70984275234"}
0005435178980	3CDF9A	1525 044325	OLGA KUZNECOVA	{"phone": "+70517650388"}
0005435178981	8E58C2	6019 141564	KRISTINA KUZNECOVA	{"phone": "+70516571170"}
0005435178982	8E58C2	3418 871957	FARIDA KUDRYASHOVA	{"email": "kudryashova-farida.1972@postgrespro.ru", "phone": "+70672445910"}
0005435178983	B798B7	1959 519951	MATVEY SEMENOV	{"email": "m-semenov-1969@postgrespro.ru", "phone": "+70098362656"}
0005435178984	B798B7	7633 106278	NINA MAKAROVA	{"phone": "+70608152649"}
0005435178985	CDCEAA	5891 075325	ARTEM ZAYCEV	{"phone": "+70307758543"}
0005435178986	1B937F	1859 612546	ANASTASIYA GORBUNOVA	{"email": "a-gorbunova.1973@postgrespro.ru", "phone": "+70430308686"}
0005435178987	5F5E8E	0380 267387	OLGA SOKOLOVA	{"email": "sokolova_olga-091979@postgrespro.ru", "phone": "+70536030813"}
0005435178988	5F5E8E	0094 534641	SERGEY IVANOV	{"phone": "+70343107684"}
0005435178989	488FF9	0981 335323	VLADISLAV SCHERBAKOV	{"email": "scherbakov-v011979@postgrespro.ru", "phone": "+70067727257"}
0005435178990	AB41C1	6997 596266	LYUBOV EGOROVA	{"email": "l.egorova011972@postgrespro.ru", "phone": "+70384296663"}
0005435178991	3FF4A4	4020 875946	SERGEY KUZMIN	{"email": "sergey_kuzmin.121964@postgrespro.ru", "phone": "+70483938384"}
0005435178992	C310BD	7284 943789	GALINA MAKAROVA	{"email": "g-makarova121979@postgrespro.ru", "phone": "+70425202351"}
0005435178993	DE9085	6547 560125	MARIYA VOLKOVA	{"email": "m_volkova1969@postgrespro.ru", "phone": "+70689888464"}
0005435178994	FB8AB2	4142 287811	SVETLANA OSIPOVA	{"email": "osipova_svetlana.081978@postgrespro.ru", "phone": "+70694425709"}
0005435178995	FB8AB2	3447 206341	VIKTORIYA MAKSIMOVA	{"email": "v_maksimova.031974@postgrespro.ru", "phone": "+70941897989"}
0005435178996	B8A79F	5747 323567	ANNA NOVIKOVA	{"email": "novikova.anna-1973@postgrespro.ru", "phone": "+70595984282"}
0005435178997	D043C7	7661 745224	LYUDMILA MAKAROVA	{"phone": "+70206390981"}
0005435178998	4BBADB	7174 917191	OLGA LAZAREVA	{"email": "lazareva-o1979@postgrespro.ru", "phone": "+70281266542"}
0005435178999	491395	5734 206812	ZINAIDA KALININA	{"phone": "+70205374444"}
0005435179000	1C4CB7	2716 149008	GENNADIY KOROLEV	{"phone": "+70074294343"}
0005435179001	1C4CB7	8478 142246	KSENIYA KOROLEVA	{"phone": "+70094986752"}
0005435179002	86B6B3	8422 665511	NINA GERASIMOVA	{"email": "gerasimovanina041967@postgrespro.ru", "phone": "+70096727279"}
0005435179003	6E2427	3723 696466	ARTEMIY FOMIN	{"email": "afomin091971@postgrespro.ru", "phone": "+70344000029"}
0005435179004	E7ECA0	8073 882592	INNA LUKYANOVA	{"phone": "+70009260536"}
0005435179005	7A24BB	0751 542960	VYACHESLAV MOISEEV	{"email": "moiseevv1989@postgrespro.ru", "phone": "+70352026055"}
0005435179006	1B012D	4746 970589	NIKOLAY DMITRIEV	{"email": "dmitriev_nikolay.17071973@postgrespro.ru", "phone": "+70829777796"}
0005435179007	0686F6	3200 109566	NIKOLAY BONDARENKO	{"email": "bondarenko_nikolay-011973@postgrespro.ru", "phone": "+70030218050"}
0005435179008	C598F7	5118 034332	PELAGEYA BELOVA	{"email": "pelageya_belova-111979@postgrespro.ru", "phone": "+70558741490"}
0005435179009	E9F1E7	0859 957581	IGOR SCHERBAKOV	{"email": "igorscherbakov_1967@postgrespro.ru", "phone": "+70633486594"}
0005435179010	B588CC	3170 856104	VLADIMIR NAZAROV	{"phone": "+70343284290"}
0005435179011	2A87BF	1006 021498	VLADIMIR MOROZOV	{"email": "morozov_vladimir.03021970@postgrespro.ru", "phone": "+70501151088"}
0005435179012	7359EB	4299 170970	TAMARA KALININA	{"email": "tamara-kalinina-02021974@postgrespro.ru", "phone": "+70368790690"}
0005435179013	39ADF2	2512 525724	KIRILL VLASOV	{"email": "vlasovkirill1979@postgrespro.ru", "phone": "+70426382073"}
0005435179014	39ADF2	8529 305485	VALERIY IVANOV	{"phone": "+70877336068"}
0005435179015	F933B5	7197 511186	NINA KISELEVA	{"phone": "+70798160428"}
0005435179016	F933B5	2461 093979	DARYA KOZLOVA	{"email": "kozlovad_02111971@postgrespro.ru", "phone": "+70155695537"}
0005435179017	D09B7B	7454 664516	ANNA ZHUKOVA	{"email": "a.zhukova.1982@postgrespro.ru", "phone": "+70299356618"}
0005435179018	D09B7B	9257 381041	GALINA KOROLEVA	{"phone": "+70137887098"}
0005435179019	0101A9	0042 750311	VYACHESLAV VOROBEV	{"phone": "+70639197366"}
0005435179020	0101A9	0954 335941	EMMA KUZMINA	{"email": "kuzmina.e_1967@postgrespro.ru", "phone": "+70095795077"}
0005435179021	FB44F7	5207 637378	YURIY SAVELEV	{"phone": "+70819119818"}
0005435179022	041EED	0666 947057	VALENTINA KONDRATEVA	{"email": "kondrateva.v101968@postgrespro.ru", "phone": "+70570343193"}
0005435179023	041EED	9617 908577	NAIL CHERNOV	{"phone": "+70709723873"}
0005435179383	DA86ED	0109 588462	VALERIY SOKOLOV	{"email": "sokolov_v-1972@postgrespro.ru", "phone": "+70447252803"}
0005435179384	DA86ED	3870 714191	TATYANA KUZNECOVA	{"phone": "+70907248163"}
0005435179385	42DC0C	5494 538853	KLAVDIYA VASILEVA	{"phone": "+70595864345"}
0005435179386	42DC0C	6456 730452	LIDIYA VLASOVA	{"email": "lidiya.vlasova_14041966@postgrespro.ru", "phone": "+70149284258"}
0005435179387	0E6475	0897 002878	TATYANA ANTONOVA	{"email": "t_antonova-091962@postgrespro.ru", "phone": "+70418382973"}
0005435179388	40CD0A	4197 816320	ALEKSEY SOKOLOV	{"email": "asokolov-1988@postgrespro.ru", "phone": "+70178618305"}
0005435179389	C8B71A	0398 463558	DMITRIY GERASIMOV	{"phone": "+70370257910"}
0005435179390	BC57E7	8818 537796	SERGEY MOROZOV	{"email": "s_morozov_06041967@postgrespro.ru", "phone": "+70653560071"}
0005435179391	74B4A3	0561 583676	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir11081977@postgrespro.ru", "phone": "+70701164952"}
0005435179392	CD4F19	9436 097139	VLADIMIR MIKHAYLOV	{"email": "vladimir-mikhaylov_1969@postgrespro.ru", "phone": "+70214314934"}
0005435179393	FD5FA1	4411 129802	ANASTASIYA PAVLOVA	{"email": "a_pavlova_1982@postgrespro.ru", "phone": "+70404565621"}
0005435179394	FD5FA1	6453 839357	MARINA DENISOVA	{"email": "denisova_marina_1969@postgrespro.ru", "phone": "+70872679106"}
0005435179395	C3B843	8097 169537	YAKOV KAZAKOV	{"email": "y-kazakov.051989@postgrespro.ru", "phone": "+70724336878"}
0005435179396	265314	8644 914272	EVGENIY MIKHAYLOV	{"phone": "+70264153074"}
0005435179397	7003C0	3616 362203	ANATOLIY OSIPOV	{"phone": "+70491456897"}
0005435179398	E8D7C0	8283 617521	EVGENIY KONOVALOV	{"email": "e-konovalov-11071974@postgrespro.ru", "phone": "+70170485577"}
0005435179399	3FBAB9	1500 711131	IGOR BONDARENKO	{"phone": "+70934708980"}
0005435179400	17DE3B	6551 804537	ELENA MELNIKOVA	{"email": "melnikova_elena13101981@postgrespro.ru", "phone": "+70196355656"}
0005435179401	17DE3B	2124 890373	ZOYA ISAEVA	{"email": "isaevazoya10061970@postgrespro.ru", "phone": "+70412227914"}
0005435179402	A13D08	2610 761816	YURIY TIKHONOV	{"email": "yuriytikhonov-22021963@postgrespro.ru", "phone": "+70786483599"}
0005435179403	B957AE	7112 559629	EVGENIY ZAKHAROV	{"email": "evgeniy-zakharov-02051985@postgrespro.ru", "phone": "+70187489917"}
0005435179404	4A174E	7873 337792	SERGEY FEDOTOV	{"email": "fedotovs_1977@postgrespro.ru", "phone": "+70480956609"}
0005435179405	EB9286	6964 128086	LYUBOV DANILOVA	{"phone": "+70630407888"}
0005435179406	8278D9	0107 123064	ZINAIDA DANILOVA	{"phone": "+70782584532"}
0005435179407	ECACFB	0862 240093	TATYANA KULIKOVA	{"phone": "+70340563535"}
0005435179408	DD67AD	0816 923903	NATALYA KUZNECOVA	{"phone": "+70085126213"}
0005435179409	7E62AE	6733 902026	SERGEY ANTONOV	{"phone": "+70896437318"}
0005435179410	8F8A3B	9573 362872	DANILA MIRONOV	{"phone": "+70047622473"}
0005435179411	8F8A3B	9519 066777	PAVEL DMITRIEV	{"email": "pavel.dmitriev.1969@postgrespro.ru", "phone": "+70817558652"}
0005435179412	3553FD	3740 448695	ALEKSANDRA AKIMOVA	{"phone": "+70643037644"}
0005435179413	E15468	1738 849571	SVETLANA PAVLOVA	{"email": "s_pavlova011982@postgrespro.ru", "phone": "+70954666221"}
0005435179414	9BC3DE	0093 554735	DARYA KOZLOVA	{"phone": "+70364639580"}
0005435179415	5D09A7	1409 584241	EKATERINA MIKHAYLOVA	{"phone": "+70432178564"}
0005435179416	5D09A7	2680 787916	KLAVDIYA MOROZOVA	{"phone": "+70056389100"}
0005435179417	B6926F	9230 019578	ANATOLIY MIRONOV	{"phone": "+70284001460"}
0005435179418	F195C3	0766 119013	VLADIMIR SOKOLOV	{"email": "vladimir_sokolov1976@postgrespro.ru", "phone": "+70209079363"}
0005435179419	A02FF9	8576 655185	SOFYA PAVLOVA	{"email": "sofyapavlova021971@postgrespro.ru", "phone": "+70836929600"}
0005435179420	3B0850	9445 586728	TATYANA NIKIFOROVA	{"phone": "+70511901022"}
0005435179421	3B0850	2876 698685	ALEKSANDR AFANASEV	{"email": "aleksandr.afanasev_111972@postgrespro.ru", "phone": "+70437518999"}
0005435179422	3B0850	6466 102779	ZOYA KONOVALOVA	{"email": "z.konovalova_1968@postgrespro.ru", "phone": "+70080950648"}
0005435179423	D43314	1596 912280	YULIYA TIKHONOVA	{"phone": "+70628149394"}
0005435179424	D43314	2875 368414	ANNA MASLOVA	{"phone": "+70241569490"}
0005435179425	6B76E4	1691 699556	LIDIYA SIDOROVA	{"phone": "+70439944764"}
0005435179426	9115F0	4730 668153	NATALYA SERGEEVA	{"phone": "+70503993003"}
0005435179427	9115F0	6446 625088	NADEZHDA ISAEVA	{"email": "isaeva-n_08031970@postgrespro.ru", "phone": "+70367154051"}
0005435179428	ECA33D	9670 046092	LIDIYA MARTYNOVA	{"email": "l_martynova-051976@postgrespro.ru", "phone": "+70384086549"}
0005435179686	4D0DFA	7113 744803	OLGA ALEKSANDROVA	{"email": "aleksandrova_o1971@postgrespro.ru", "phone": "+70095873980"}
0005435179687	4D0DFA	7589 223020	ELENA EGOROVA	{"email": "elenaegorova1972@postgrespro.ru", "phone": "+70200589588"}
0005435179688	665D43	2312 167764	VASILIY KRASNOV	{"phone": "+70539830429"}
0005435179689	C9B401	0036 547144	EVGENIYA DMITRIEVA	{"phone": "+70981823732"}
0005435179690	3AD70A	1052 503121	GALINA GRISHINA	{"email": "grishina_g-1975@postgrespro.ru", "phone": "+70236273739"}
0005435179691	C4EB0D	7324 816435	MIKHAIL NOVIKOV	{"email": "mikhailnovikov_1973@postgrespro.ru", "phone": "+70356420681"}
0005435179692	2A231F	5423 281876	KLAVDIYA POPOVA	{"email": "popova_k011979@postgrespro.ru", "phone": "+70173683598"}
0005435179693	A638D6	0299 812557	VLADIMIR TARASOV	{"email": "vtarasov_10121974@postgrespro.ru", "phone": "+70081239716"}
0005435179694	46CED5	9845 637547	MARIYA ALEKSEEVA	{"email": "m.alekseeva1966@postgrespro.ru", "phone": "+70097534708"}
0005435179695	46CED5	7633 843117	GALIYA ANISIMOVA	{"email": "anisimovagaliya1981@postgrespro.ru", "phone": "+70119749535"}
0005435179696	05887B	5479 755438	GALINA ROMANOVA	{"email": "romanova.g_1975@postgrespro.ru", "phone": "+70646622915"}
0005435179697	AA37B2	8198 133943	OLGA ZAKHAROVA	{"email": "zakharovao-011981@postgrespro.ru", "phone": "+70379542815"}
0005435179698	EE6999	0146 775963	MIKHAIL KAZAKOV	{"email": "m-kazakov_111978@postgrespro.ru", "phone": "+70220780106"}
0005435179699	95F47F	2758 912557	NATALYA AFANASEVA	{"phone": "+70091822855"}
0005435179700	5C1609	0451 418869	MARIYA GAVRILOVA	{"email": "mariya-gavrilova-011967@postgrespro.ru", "phone": "+70880323534"}
0005435179701	AD875F	4785 645516	ALEKSEY IVANOV	{"phone": "+70392700641"}
0005435179702	198EA9	7477 438409	ANDREY MEDVEDEV	{"email": "medvedevandrey_23051972@postgrespro.ru", "phone": "+70116341838"}
0005435179703	198EA9	9049 336315	YAROSLAVA NESTEROVA	{"email": "nesterova_yaroslava_1968@postgrespro.ru", "phone": "+70349659960"}
0005435179704	AE5182	7353 587503	ANATOLIY RODIONOV	{"phone": "+70835168499"}
0005435179705	8552BB	7762 591900	IGOR SEMENOV	{"phone": "+70416130655"}
0005435179706	F6FBAF	8627 449371	DANIIL BONDARENKO	{"email": "bondarenko-d1967@postgrespro.ru", "phone": "+70927199040"}
0005435179707	870436	4918 496626	NIKITA ISAEV	{"phone": "+70728225814"}
0005435179708	D56FD6	1210 997133	RINAT MARTYNOV	{"email": "rinat-martynov_1969@postgrespro.ru", "phone": "+70323490392"}
0005435179709	D56FD6	8709 749402	SERGEY VLASOV	{"email": "vlasov_s.29031970@postgrespro.ru", "phone": "+70216728509"}
0005435179710	7F73F6	0885 501478	DENIS ORLOV	{"email": "denis-orlov.11111971@postgrespro.ru", "phone": "+70043809006"}
0005435179711	10A1CB	2756 646223	ANTONINA NAZAROVA	{"phone": "+70760849864"}
0005435179712	10A1CB	0507 000379	ALEKSEY GORBUNOV	{"phone": "+70309678805"}
0005435179713	10A1CB	2247 942073	VITALIY NOVIKOV	{"phone": "+70222450517"}
0005435179714	FB78A3	3173 751047	ANDREY GRIGOREV	{"email": "andrey.grigorev_101972@postgrespro.ru", "phone": "+70473477474"}
0005435179715	649B26	4578 029407	IRINA TIKHONOVA	{"phone": "+70428187555"}
0005435179716	649B26	2964 448006	ELENA KUZMINA	{"email": "kuzmina.e_1962@postgrespro.ru", "phone": "+70218781540"}
0005435179717	2CC199	2815 137997	OLGA SOKOLOVA	{"email": "olga_sokolova_121970@postgrespro.ru", "phone": "+70720247530"}
0005435179718	2CC199	2516 847816	ALEKSANDR DAVYDOV	{"email": "a.davydov_081981@postgrespro.ru", "phone": "+70551431329"}
0005435179719	061B18	1730 996088	ELENA NAUMOVA	{"phone": "+70716131787"}
0005435179720	061B18	6908 784711	ALLA RODIONOVA	{"phone": "+70948235783"}
0005435212328	B81687	7440 038050	DARYA FROLOVA	{"email": "frolovad-1982@postgrespro.ru", "phone": "+70808676017"}
0005435212329	B81687	1126 142702	ANASTASIYA STEPANOVA	{"email": "astepanova_091971@postgrespro.ru", "phone": "+70046423496"}
0005435212330	B81687	4661 013523	VLADIMIR NIKITIN	{"email": "nikitin-v-021975@postgrespro.ru", "phone": "+70265788271"}
0005435212331	478B95	8878 673564	VIKTOR GAVRILOV	{"email": "v.gavrilov-121981@postgrespro.ru", "phone": "+70565421061"}
0005435212332	5FDBD4	7564 558625	ALEFTINA NESTEROVA	{"email": "a-nesterova.29121961@postgrespro.ru", "phone": "+70092932341"}
0005435212333	6F0BA0	3161 238567	TATYANA VOLKOVA	{"email": "t.volkova_121974@postgrespro.ru", "phone": "+70355327258"}
0005435212334	6F0BA0	0968 685378	ELENA BELOVA	{"phone": "+70376804847"}
0005435212335	6F0BA0	5917 022660	GENNADIY VOROBEV	{"phone": "+70489877343"}
0005435212336	A57FBE	9862 946810	NINA KALININA	{"phone": "+70887965092"}
0005435212337	A6AF1B	0961 201301	TATYANA TIKHONOVA	{"phone": "+70140672709"}
0005435212338	A6AF1B	3417 899236	ALISA KOROLEVA	{"email": "koroleva.a03061977@postgrespro.ru", "phone": "+70305399550"}
0005435212339	E953B3	8146 986634	SERGEY KOZLOV	{"phone": "+70512441597"}
0005435212340	DC74E3	4757 279063	LIDIYA ABRAMOVA	{"phone": "+70218535523"}
0005435212341	DC74E3	7676 395468	RUSHANIYA NIKOLAEVA	{"email": "rushaniyanikolaeva_081982@postgrespro.ru", "phone": "+70217977100"}
0005435212342	DC74E3	7476 347942	ALEKSANDR YAKOVLEV	{"email": "yakovlev_a-23121960@postgrespro.ru", "phone": "+70011760772"}
0005435212343	781391	7521 409713	VLADIMIR KUZNECOV	{"phone": "+70649553829"}
0005435212344	8B5A77	5992 493019	SERGEY DMITRIEV	{"email": "sdmitriev041971@postgrespro.ru", "phone": "+70614910021"}
0005435212345	9FE700	8271 155596	DMITRIY PETROV	{"email": "petrov.d041975@postgrespro.ru", "phone": "+70338720117"}
0005435212346	37AF12	2116 218489	GALINA KUZMINA	{"phone": "+70612559187"}
0005435212347	F280F6	3906 785076	NATALIYA TITOVA	{"phone": "+70101083129"}
0005435212348	6D7358	0689 777562	STANISLAV ABRAMOV	{"email": "stanislav-abramov.1967@postgrespro.ru", "phone": "+70218782247"}
0005435212349	008A31	5781 596406	DENIS FILIPPOV	{"email": "d-filippov_021974@postgrespro.ru", "phone": "+70348506211"}
0005435212350	008A31	4290 641774	ELENA SERGEEVA	{"email": "elena.sergeeva16091969@postgrespro.ru", "phone": "+70229454046"}
0005435212351	BEAA38	9933 118369	ELIZAVETA KULIKOVA	{"phone": "+70107471502"}
0005435212352	BEAA38	5202 933915	EVGENIYA EFIMOVA	{"phone": "+70587921834"}
0005435212353	FDFA5D	7686 554300	DMITRIY PAVLOV	{"phone": "+70837256617"}
0005435212354	3E81E4	3049 633005	VIOLETTA SIDOROVA	{"phone": "+70631420800"}
0005435212355	A5404E	3099 095176	TATYANA YAKOVLEVA	{"phone": "+70575565374"}
0005435212356	A5404E	5933 228339	ANDREY MAKAROV	{"phone": "+70454283452"}
0005435212357	7577B3	9333 855193	VERA MAKSIMOVA	{"phone": "+70886269798"}
0005435212358	7577B3	5563 025823	MARIYA PETROVA	{"phone": "+70438703477"}
0005435212359	E1301C	2812 737475	OLESYA RODIONOVA	{"email": "rodionovao_1981@postgrespro.ru", "phone": "+70801359768"}
0005435212360	E1301C	9404 021690	SERGEY FILIPPOV	{"email": "filippov_s.23091975@postgrespro.ru", "phone": "+70113219708"}
0005435212361	47635E	1284 366376	NIKOLAY IVANOV	{"phone": "+70084802931"}
0005435212362	9341CB	6131 885748	ARSENIY NIKOLAEV	{"email": "arseniy.nikolaev_031981@postgrespro.ru", "phone": "+70547497344"}
0005435212363	3114BB	1871 353112	VALERIY SCHERBAKOV	{"phone": "+70988588911"}
0005435212364	3114BB	9269 432188	VYACHESLAV PETROV	{"phone": "+70493320323"}
0005435212365	8104D2	3004 047357	PAVEL MIKHAYLOV	{"phone": "+70983500168"}
0005435212366	949E48	4079 769152	ANNA ORLOVA	{"email": "orlova.anna.1978@postgrespro.ru", "phone": "+70596145530"}
0005435212367	949E48	4819 398643	ELIZAVETA KOROLEVA	{"phone": "+70609911759"}
0005435212368	DCACA1	5332 118174	VALERIY YAKOVLEV	{"email": "yakovlev-valeriy.1974@postgrespro.ru", "phone": "+70870551955"}
0005435212369	3BD249	1379 703628	TAMARA MOISEEVA	{"phone": "+70255231165"}
0005435212370	4F64A5	0854 593724	ALEKSANDR MOROZOV	{"phone": "+70960551023"}
0005435212371	4F64A5	3013 287222	PELAGEYA SOROKINA	{"phone": "+70078722981"}
0005435212372	4F64A5	1753 235608	ALEKSANDR STEPANOV	{"email": "stepanov_a10121975@postgrespro.ru", "phone": "+70091843788"}
0005435212373	B3E42B	5446 183851	RAISA ANTONOVA	{"email": "r-antonova-1981@postgrespro.ru", "phone": "+70596851737"}
0005435212374	B3E42B	7439 263605	VERONIKA TARASOVA	{"phone": "+70372550663"}
0005435212375	8F76A2	3450 329850	ILYA KAZAKOV	{"email": "kazakov.ilya_29031970@postgrespro.ru", "phone": "+70219566335"}
0005435212376	3C293D	7397 047748	NIKOLAY ILIN	{"phone": "+70850846473"}
0005435212377	69DC82	1455 232412	TATYANA ROMANOVA	{"email": "romanovat011986@postgrespro.ru", "phone": "+70544690744"}
0005435212378	8E9373	8874 392443	DMITRIY ALEKSANDROV	{"phone": "+70802160047"}
0005435212379	8E9373	7200 541610	ALEKSANDR MAKSIMOV	{"phone": "+70122043275"}
0005435212380	86D03C	7638 938790	EVGENIY KULIKOV	{"email": "evgeniy-kulikov_101977@postgrespro.ru", "phone": "+70320570975"}
0005435212381	86D03C	6754 366923	ANDREY YAKOVLEV	{"email": "yakovlev.andrey.1971@postgrespro.ru", "phone": "+70407859971"}
0005435212382	7DE637	0711 615617	MIKHAIL VLASOV	{"phone": "+70702026741"}
0005435212383	7DE637	4674 433087	BORIS POPOV	{"email": "popovb1965@postgrespro.ru", "phone": "+70006358203"}
0005435212384	355320	4891 025980	OLGA RYABOVA	{"phone": "+70895239467"}
0005435212385	355320	9772 962189	IVAN PETROV	{"phone": "+70064042857"}
0005435212386	EBE41D	6788 033215	NIKOLAY KUZMIN	{"email": "kuzmin_n16121973@postgrespro.ru", "phone": "+70950697437"}
0005435212387	F648E7	7229 283510	NADEZHDA NOVIKOVA	{"phone": "+70431334857"}
0005435212388	F648E7	7396 224361	ANDREY KRASNOV	{"phone": "+70381905174"}
0005435212389	2FEE99	0162 791216	BORIS KISELEV	{"email": "b.kiselev_1967@postgrespro.ru", "phone": "+70887225636"}
0005435212390	76D427	9631 853639	YULIYA ALEKSEEVA	{"phone": "+70889775236"}
0005435212391	11197B	6352 512157	ROSTISLAV BELOV	{"phone": "+70594354558"}
0005435212392	11197B	9360 716917	OLGA MARTYNOVA	{"phone": "+70685561434"}
0005435212393	AFFE48	7262 363397	MIKHAIL NIKOLAEV	{"email": "nikolaev_mikhail041966@postgrespro.ru", "phone": "+70403247520"}
0005435212394	AFFE48	5337 881246	EKATERINA KUDRYASHOVA	{"email": "kudryashova-e.02121965@postgrespro.ru", "phone": "+70623513759"}
0005435212395	6D06E6	5490 132713	RAFIS AFANASEV	{"email": "rafis-afanasev.101977@postgrespro.ru", "phone": "+70404071523"}
0005435212396	959F20	8679 727676	KRISTINA YAKOVLEVA	{"email": "k.yakovleva-1973@postgrespro.ru", "phone": "+70197626035"}
0005435212397	6BDFEB	4861 672800	PETR ALEKSANDROV	{"email": "aleksandrov_p_1977@postgrespro.ru", "phone": "+70125642362"}
0005435212398	EA39E1	6235 935160	DMITRIY MAKAROV	{"phone": "+70068063785"}
0005435212399	3C55B1	9382 003132	YURIY MAKAROV	{"phone": "+70109807444"}
0005435212400	B0C9AA	4239 739938	ANATOLIY SEMENOV	{"phone": "+70195104915"}
0005435212401	B0C9AA	8960 308977	EKATERINA FEDOROVA	{"phone": "+70290147847"}
0005435212402	558289	0359 598438	KLAVDIYA ZHURAVLEVA	{"phone": "+70196341938"}
0005435212570	F1F183	5218 693367	ALEKSEY DAVYDOV	{"phone": "+70231866419"}
0005435212403	B97A7C	8451 967458	ALEKSANDR ISAEV	{"email": "aleksandr-isaev.28111978@postgrespro.ru", "phone": "+70962663330"}
0005435212404	B97A7C	5586 722576	ANATOLIY NAZAROV	{"email": "anatoliy.nazarov081975@postgrespro.ru", "phone": "+70225144391"}
0005435212405	3458CA	0181 849836	GALINA GORBUNOVA	{"phone": "+70939705136"}
0005435212406	C2192A	9912 662463	VALERIY CHERNOV	{"phone": "+70106055830"}
0005435212407	2E53B0	3549 398032	ELENA VLASOVA	{"phone": "+70765894525"}
0005435212408	385F9E	8127 976397	ALEKSEY VASILEV	{"email": "vasileva.071971@postgrespro.ru", "phone": "+70956392862"}
0005435212409	385F9E	0018 048899	MILANA DENISOVA	{"email": "m.denisova-1976@postgrespro.ru", "phone": "+70796691980"}
0005435212410	2655A0	3882 068674	NATALYA SMIRNOVA	{"phone": "+70257504685"}
0005435212411	157DE7	8528 550296	NADEZHDA IVANOVA	{"phone": "+70074838597"}
0005435212412	696874	2167 945147	ANASTASIYA KULIKOVA	{"phone": "+70776892576"}
0005435212413	696874	7437 514129	OLGA IVANOVA	{"phone": "+70121027859"}
0005435212414	696874	3175 187600	SVETLANA EGOROVA	{"email": "egorovasvetlana.061968@postgrespro.ru", "phone": "+70337631298"}
0005435212415	4A4458	9372 384557	PAVEL ANDREEV	{"email": "p.andreev061972@postgrespro.ru", "phone": "+70007115056"}
0005435212416	5F5F17	5921 567381	RAISA EGOROVA	{"phone": "+70245313636"}
0005435212417	736AED	2128 961179	LYUDMILA GORBUNOVA	{"email": "gorbunovalyudmila021974@postgrespro.ru", "phone": "+70286303274"}
0005435212418	3171A2	8688 464922	ELENA STEPANOVA	{"phone": "+70633044491"}
0005435212419	3171A2	5312 945145	VALERIYA KUZNECOVA	{"phone": "+70524230464"}
0005435212420	3171A2	9931 994292	ARTUR ZHUKOV	{"email": "zhukov_artur-25091973@postgrespro.ru", "phone": "+70646906443"}
0005435212421	7B787A	4587 726801	DARYA KULIKOVA	{"phone": "+70606504051"}
0005435212422	CAB91D	3532 575692	TATYANA LAZAREVA	{"phone": "+70901140917"}
0005435212423	5D9D95	0690 453349	MIKHAIL KISELEV	{"email": "m.kiselev071973@postgrespro.ru", "phone": "+70742631694"}
0005435212424	F46411	4484 697480	MAKSIM SAVELEV	{"email": "m.savelev.21071980@postgrespro.ru", "phone": "+70507828015"}
0005435212425	F46411	1735 673288	ELENA PETROVA	{"phone": "+70606532952"}
0005435212426	F46411	8268 761355	ARTEM KAZAKOV	{"phone": "+70021412113"}
0005435212427	587DAA	5647 870273	NINA KUZNECOVA	{"email": "kuznecovanina-041968@postgrespro.ru", "phone": "+70021174491"}
0005435212428	ADD9DA	9012 514341	IRINA KAZAKOVA	{"email": "irina-kazakova-27081976@postgrespro.ru", "phone": "+70573931958"}
0005435212429	D5C083	6995 096410	ANDREY ROMANOV	{"email": "romanovandrey.061970@postgrespro.ru", "phone": "+70535819009"}
0005435212430	A8714E	9162 025497	DMITRIY ZAYCEV	{"phone": "+70122088747"}
0005435212431	0313E9	4735 133514	LIDIYA KOROLEVA	{"email": "koroleva_lidiya_07051977@postgrespro.ru", "phone": "+70565965418"}
0005435212432	0313E9	3532 345269	ANDREY VOLKOV	{"phone": "+70822841246"}
0005435212433	A4ED33	1303 080943	TAMARA NIKOLAEVA	{"email": "nikolaeva_t1967@postgrespro.ru", "phone": "+70715490597"}
0005435212434	CAF1A0	3637 889448	IRINA NIKOLAEVA	{"email": "nikolaevai-1974@postgrespro.ru", "phone": "+70932743773"}
0005435212435	AD4E35	7698 945678	KLAVDIYA ROMANOVA	{"email": "klavdiya-romanova1970@postgrespro.ru", "phone": "+70832582666"}
0005435212436	AD4E35	7545 835750	ZHANNA NIKITINA	{"phone": "+70129029104"}
0005435212437	29B4C2	2988 597334	LYUDMILA DMITRIEVA	{"email": "dmitrieva_lyudmila061977@postgrespro.ru", "phone": "+70332348340"}
0005435212438	4AC78A	9221 286461	DARYA SEMENOVA	{"phone": "+70389287945"}
0005435212439	C6AECC	4388 525847	NIKOLAY PETROV	{"email": "n.petrov-15101964@postgrespro.ru", "phone": "+70058617630"}
0005435212440	F763D7	8344 380246	SERGEY ABRAMOV	{"email": "s.abramov_24061969@postgrespro.ru", "phone": "+70057788843"}
0005435212441	F763D7	8248 702198	ANNA KUZNECOVA	{"email": "anna_kuznecova1970@postgrespro.ru", "phone": "+70265769307"}
0005435212442	398583	3543 751726	SERGEY EGOROV	{"phone": "+70708138981"}
0005435212443	DEDF2A	0876 658961	DMITRIY TARASOV	{"email": "tarasov_d_1961@postgrespro.ru", "phone": "+70554548162"}
0005435212444	DEDF2A	0794 582826	LYUDMILA PETROVA	{"phone": "+70643627153"}
0005435212445	1E6A35	1581 466979	LARISA NIKIFOROVA	{"phone": "+70489002143"}
0005435212446	320847	2686 769886	DMITRIY SMIRNOV	{"phone": "+70460947332"}
0005435212447	EAB33F	1879 183797	TATYANA EGOROVA	{"phone": "+70105847822"}
0005435212448	CD9145	1964 646047	NADEZHDA ORLOVA	{"phone": "+70489164162"}
0005435212449	0650BC	9155 357285	SVETLANA NIKOLAEVA	{"phone": "+70081770926"}
0005435212450	0E0994	7335 238944	SVETLANA NAUMOVA	{"phone": "+70058246210"}
0005435212451	A58DB5	4870 368805	LYUBOV ZAKHAROVA	{"email": "lyubovzakharova.1963@postgrespro.ru", "phone": "+70985640188"}
0005435212452	A58DB5	6613 579316	KLAVDIYA KUZNECOVA	{"phone": "+70433521218"}
0005435212453	0ADC9A	5671 351380	VIKTOR KISELEV	{"phone": "+70285656879"}
0005435212454	3B22E3	4809 790145	ELENA BORISOVA	{"email": "borisova.e-011968@postgrespro.ru", "phone": "+70785719485"}
0005435212455	3B22E3	8890 493143	INNA CHERNOVA	{"email": "i.chernova-1980@postgrespro.ru", "phone": "+70855709136"}
0005435212456	01968D	6395 615228	VLADISLAV VASILEV	{"email": "v.vasilev_101965@postgrespro.ru", "phone": "+70546502562"}
0005435212457	71C665	1268 272471	KSENIYA KONDRATEVA	{"phone": "+70492424121"}
0005435212458	816F3B	0323 348524	ELENA PAVLOVA	{"email": "e_pavlova.1965@postgrespro.ru", "phone": "+70498496834"}
0005435212459	157D2B	9326 458424	GALINA SEMENOVA	{"email": "semenova.galina_021971@postgrespro.ru", "phone": "+70452358280"}
0005435212460	52BE55	6060 522684	ALEKSANDR NIKOLAEV	{"phone": "+70494655341"}
0005435212461	52BE55	7502 920714	ANATOLIY BONDARENKO	{"email": "bondarenko.a12091978@postgrespro.ru", "phone": "+70127010841"}
0005435212462	D61657	9148 015005	VLADIMIR YAKOVLEV	{"email": "vladimir_yakovlev_1964@postgrespro.ru", "phone": "+70545296977"}
0005435212463	D61657	4052 232540	SERGEY KUDRYASHOV	{"phone": "+70425013063"}
0005435212464	337474	4285 207557	DAMIR POPOV	{"email": "popov-d.031985@postgrespro.ru", "phone": "+70295920708"}
0005435212465	BE3CDD	1409 032410	BORIS BONDARENKO	{"email": "b_bondarenko-1974@postgrespro.ru", "phone": "+70468291544"}
0005435212466	BE3CDD	6465 140593	PETR SCHERBAKOV	{"email": "scherbakov-p_1977@postgrespro.ru", "phone": "+70714492801"}
0005435212467	B5ECAB	6839 518595	ANASTASIYA PAVLOVA	{"email": "pavlova.a.061977@postgrespro.ru", "phone": "+70378668268"}
0005435212468	019BAD	5121 930920	OLGA ARKHIPOVA	{"phone": "+70285676749"}
0005435212469	019BAD	6313 076249	NINA VASILEVA	{"phone": "+70810608548"}
0005435212470	C5CC27	6382 585390	ELIZAVETA IVANOVA	{"email": "elizaveta-ivanova.1969@postgrespro.ru", "phone": "+70235702903"}
0005435212471	C5CC27	4860 172346	IRINA GERASIMOVA	{"email": "i.gerasimova061962@postgrespro.ru", "phone": "+70758385749"}
0005435212472	018F81	2181 132624	ANTON STEPANOV	{"email": "stepanov.a.061973@postgrespro.ru", "phone": "+70493976975"}
0005435212473	C11872	1663 233476	POLINA AFANASEVA	{"email": "afanaseva_p.1966@postgrespro.ru", "phone": "+70749044169"}
0005435212474	C11872	2459 929466	IRINA ZAKHAROVA	{"phone": "+70711524442"}
0005435212475	AD2E9A	4948 795049	OLGA ZAKHAROVA	{"email": "olga-zakharova-25121971@postgrespro.ru", "phone": "+70349340191"}
0005435212476	87F729	9230 840811	TATYANA ZHUKOVA	{"phone": "+70990187316"}
0005435212477	FF5D33	1557 831936	MAKSIM KULIKOV	{"phone": "+70996346153"}
0005435212478	2217E4	2128 603202	LIDIYA TIMOFEEVA	{"email": "timofeeval-111968@postgrespro.ru", "phone": "+70130972347"}
0005435212479	090279	9657 150267	VLADISLAV NIKITIN	{"phone": "+70838305635"}
0005435212480	588FE3	5646 133986	ANDREY DMITRIEV	{"phone": "+70983631032"}
0005435212481	FC97FC	7898 670972	ALEKSANDR PETROV	{"phone": "+70242714872"}
0005435212482	FC97FC	1136 978657	NADEZHDA MEDVEDEVA	{"email": "medvedeva.n.22011971@postgrespro.ru", "phone": "+70012787595"}
0005435212483	FC97FC	9882 992455	ALEKSEY VOLKOV	{"phone": "+70214124345"}
0005435212484	1B06D8	0241 899598	NIKOLAY POPOV	{"email": "nikolaypopov_1978@postgrespro.ru", "phone": "+70493503360"}
0005435212485	947E30	5396 159836	OKSANA KUZNECOVA	{"phone": "+70633681872"}
0005435212486	947E30	7612 516278	NATALYA ZOTOVA	{"email": "zotovan-10111972@postgrespro.ru", "phone": "+70604321640"}
0005435212487	BE8BFA	7309 087741	GALINA AKIMOVA	{"phone": "+70715865536"}
0005435212488	2334AB	2286 877710	DMITRIY FEDOROV	{"email": "dmitriy_fedorov_071971@postgrespro.ru", "phone": "+70447329946"}
0005435212489	2334AB	0302 086300	EKATERINA KULIKOVA	{"email": "e_kulikova13121981@postgrespro.ru", "phone": "+70989736830"}
0005435212490	06B8BE	4830 822521	ANDREY NIKOLAEV	{"email": "nikolaev.andrey16031976@postgrespro.ru", "phone": "+70590050218"}
0005435212491	06B8BE	7466 253473	ANATOLIY BORISOV	{"phone": "+70564173439"}
0005435212492	41BEA9	5261 651758	VASILIY IVANOV	{"phone": "+70902411989"}
0005435212493	AE60C8	6950 077860	IVAN ZHUKOV	{"phone": "+70220984338"}
0005435212494	C17CC2	8680 486863	YULIYA ILINA	{"phone": "+70749368395"}
0005435212495	C17CC2	2488 367523	ANDREY VOLKOV	{"phone": "+70233988039"}
0005435212496	D88594	9647 422874	VALENTINA NESTEROVA	{"email": "valentina_nesterova-24081963@postgrespro.ru", "phone": "+70351695685"}
0005435212497	D88594	8847 904072	EVGENIY KUZMIN	{"phone": "+70328498132"}
0005435212498	83EF6D	9839 150153	SERGEY SOROKIN	{"email": "sergeysorokin_061968@postgrespro.ru", "phone": "+70865139743"}
0005435212499	507E71	2113 191452	NIKOLAY NIKOLAEV	{"email": "n-nikolaev091973@postgrespro.ru", "phone": "+70541603652"}
0005435212500	B126DE	7569 043631	VLADIMIR VOROBEV	{"phone": "+70056321299"}
0005435212501	B126DE	8548 533169	ANTONINA BOGDANOVA	{"email": "a_bogdanova-25011972@postgrespro.ru", "phone": "+70790298981"}
0005435212502	01952A	9546 073363	SVETLANA MARTYNOVA	{"email": "martynovasvetlana_051960@postgrespro.ru", "phone": "+70832575889"}
0005435212503	01952A	9147 365248	ELENA MAKAROVA	{"phone": "+70516790395"}
0005435212504	E7DD89	3236 044614	DENIS BARANOV	{"email": "denisbaranov101960@postgrespro.ru", "phone": "+70605446210"}
0005435212505	01AF4B	0864 980422	ROMAN YAKOVLEV	{"email": "ryakovlev_1972@postgrespro.ru", "phone": "+70647458120"}
0005435212506	77E490	1838 643594	EKATERINA MIKHAYLOVA	{"phone": "+70310885884"}
0005435212507	4B73C6	6847 735247	TATYANA FEDOROVA	{"phone": "+70957566600"}
0005435212508	DFE2C3	0538 703589	LIDIYA KOLESNIKOVA	{"email": "lidiya-kolesnikova_111963@postgrespro.ru", "phone": "+70846332882"}
0005435212509	DFE2C3	6205 690466	SERGEY KUZMIN	{"phone": "+70068716974"}
0005435212510	DFE2C3	6823 296663	IGOR CHERNOV	{"phone": "+70930015933"}
0005435212511	327897	7879 755368	ALEKSANDR VASILEV	{"email": "a-vasilev-011971@postgrespro.ru", "phone": "+70113360501"}
0005435212512	593173	0795 612628	TATYANA BORISOVA	{"email": "tatyanaborisova061984@postgrespro.ru", "phone": "+70043454411"}
0005435212513	593173	3377 629152	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_aleksandr_1976@postgrespro.ru", "phone": "+70840530187"}
0005435212571	DB0A07	0879 094325	ANNA SMIRNOVA	{"phone": "+70225570731"}
0005435212514	95ABA7	0685 426345	SERGEY VOLKOV	{"email": "sergey.volkov1973@postgrespro.ru", "phone": "+70349131595"}
0005435212515	735B90	3711 675882	ELENA GAVRILOVA	{"phone": "+70337620701"}
0005435212516	735B90	5827 339648	NINA EGOROVA	{"phone": "+70691167574"}
0005435212517	6CB568	4987 343015	ANASTASIYA ZOTOVA	{"email": "zotova.anastasiya.061970@postgrespro.ru", "phone": "+70104980425"}
0005435212518	AD909A	2198 942202	VIKTOR NIKOLAEV	{"phone": "+70115680077"}
0005435212519	AD909A	2052 404077	IGOR ZAKHAROV	{"email": "zakharovi_1978@postgrespro.ru", "phone": "+70292113776"}
0005435212520	F3F6DC	4487 241642	ALEKSANDR PETROV	{"phone": "+70540094677"}
0005435212521	F3F6DC	8230 946975	ANASTASIYA ORLOVA	{"phone": "+70347515600"}
0005435212522	F0D84D	1506 040650	OLGA MIKHAYLOVA	{"email": "mikhaylova.o_051978@postgrespro.ru", "phone": "+70911691900"}
0005435212523	0E7B4E	6052 976549	MADINA MARTYNOVA	{"email": "martynova-madina_101965@postgrespro.ru", "phone": "+70670920810"}
0005435212524	02BBEB	6582 459902	ALEKSANDRA NOVIKOVA	{"phone": "+70484124077"}
0005435212525	263124	6658 350571	VLADIMIR SMIRNOV	{"phone": "+70022557574"}
0005435212526	7D569D	8052 178384	NINA EFREMOVA	{"email": "n.efremova_12011966@postgrespro.ru", "phone": "+70798181550"}
0005435212527	501201	6375 833496	LARISA YAKOVLEVA	{"email": "yakovleva.l101964@postgrespro.ru", "phone": "+70884794432"}
0005435212528	22329A	1097 051890	VALERIYA VLASOVA	{"phone": "+70249157266"}
0005435212529	03BB66	9354 423762	VYACHESLAV PETROV	{"phone": "+70958713128"}
0005435212530	683AD3	0051 291133	DANILA SHEVCHENKO	{"phone": "+70803944395"}
0005435212531	683AD3	0813 600039	NINA KOLESNIKOVA	{"email": "nina-kolesnikova1975@postgrespro.ru", "phone": "+70497050203"}
0005435212532	C8A088	7530 802506	ELENA MAKSIMOVA	{"email": "emaksimova.28071970@postgrespro.ru", "phone": "+70223338328"}
0005435212533	AF5FC1	2825 193538	VALERIY ROMANOV	{"phone": "+70118720390"}
0005435212534	2105E6	4555 811840	MARGARITA KRASNOVA	{"email": "margarita_krasnova-091974@postgrespro.ru", "phone": "+70680567268"}
0005435212535	2105E6	4072 947053	ANDREY MAKSIMOV	{"phone": "+70071470145"}
0005435212536	638EA8	5280 632872	TATYANA ZAKHAROVA	{"email": "tatyanazakharova-06091977@postgrespro.ru", "phone": "+70574061259"}
0005435212537	638EA8	0149 749709	ALEKSANDR BORISOV	{"email": "a-borisov.30081972@postgrespro.ru", "phone": "+70054099982"}
0005435212538	36DF6C	2341 555362	PRASKOVYA SOKOLOVA	{"email": "praskovya.sokolova_12051965@postgrespro.ru", "phone": "+70695638650"}
0005435212539	9DD0AC	4906 836346	YANA NESTEROVA	{"email": "nesterovay25091967@postgrespro.ru", "phone": "+70010761274"}
0005435212540	551B2E	0623 302469	ANATOLIY SOROKIN	{"email": "sorokin.anatoliy-1964@postgrespro.ru", "phone": "+70396192765"}
0005435212541	551B2E	9641 920182	LYUDMILA MAKAROVA	{"phone": "+70425665036"}
0005435212542	551B2E	4668 644854	ELENA SERGEEVA	{"phone": "+70817091812"}
0005435212543	83B14F	5221 309870	ELENA KARPOVA	{"phone": "+70510129157"}
0005435212544	83B14F	3287 739412	NIKOLAY KOROLEV	{"email": "korolev.n09111969@postgrespro.ru", "phone": "+70610464267"}
0005435212545	D4FBC2	8317 142079	SERGEY POPOV	{"email": "popov_sergey-1974@postgrespro.ru", "phone": "+70912838409"}
0005435212546	D4FBC2	1485 488748	NINA TIKHONOVA	{"phone": "+70438008347"}
0005435212547	B0586D	4242 846858	ANASTASIYA VASILEVA	{"email": "anastasiyavasileva.021967@postgrespro.ru", "phone": "+70072352188"}
0005435212548	2AD896	9065 692329	VYACHESLAV ZHUKOV	{"phone": "+70306137745"}
0005435212549	5494D0	9685 959838	YURIY FEDOROV	{"phone": "+70940056881"}
0005435212550	B0D969	6421 136514	DENIS PETROV	{"phone": "+70745873796"}
0005435212551	BB460E	2453 763184	VALENTIN FROLOV	{"phone": "+70854174190"}
0005435212552	BB460E	5486 814433	ANTONINA DENISOVA	{"email": "denisova-antonina_19081974@postgrespro.ru", "phone": "+70841595999"}
0005435212553	E0881F	3335 441644	OKSANA KARPOVA	{"email": "o.karpova_121975@postgrespro.ru", "phone": "+70819930640"}
0005435212554	3ED7A8	7544 515164	LARISA KUZNECOVA	{"email": "kuznecova_larisa_111981@postgrespro.ru", "phone": "+70397833303"}
0005435212555	3ED7A8	0570 944356	ZINAIDA ARKHIPOVA	{"email": "z_arkhipova.1970@postgrespro.ru", "phone": "+70619752887"}
0005435212556	C3BD8E	2293 344659	MAKSIM NAZAROV	{"email": "nazarov.m.26061970@postgrespro.ru", "phone": "+70597539252"}
0005435212557	C3BD8E	9155 284644	VADIM NAUMOV	{"email": "v-naumov.18091984@postgrespro.ru", "phone": "+70585461849"}
0005435212558	85F279	2904 176351	ELENA AFANASEVA	{"phone": "+70421533679"}
0005435212559	835B89	0850 418656	ANDREY VLASOV	{"phone": "+70777389404"}
0005435212560	835B89	0911 624250	RIMMA MAKSIMOVA	{"email": "rimmamaksimova-1974@postgrespro.ru", "phone": "+70138366110"}
0005435212561	948A3A	6105 716131	LYUDMILA ZAKHAROVA	{"phone": "+70976862862"}
0005435212562	D7B8BC	4630 899770	SERGEY ILIN	{"email": "ilin_s.081970@postgrespro.ru", "phone": "+70063190387"}
0005435212563	D7B8BC	7845 656636	ALEKSANDR GRIGOREV	{"phone": "+70812876357"}
0005435212564	578216	3334 563983	ARTEM MAKSIMOV	{"phone": "+70561072236"}
0005435212565	AA4F4E	0062 111622	ALEKSEY KISELEV	{"email": "kiselev_aleksey_1970@postgrespro.ru", "phone": "+70393046951"}
0005435212566	A2621C	6591 874128	OLGA KAZAKOVA	{"phone": "+70578329475"}
0005435212567	A2621C	9969 116268	VLADIMIR MAKAROV	{"email": "vladimir_makarov-1976@postgrespro.ru", "phone": "+70580487940"}
0005435212568	124094	2547 420465	NATALYA MATVEEVA	{"email": "natalyamatveeva-1964@postgrespro.ru", "phone": "+70103551668"}
0005435212569	F1F183	8941 947676	ANASTASIYA ZAKHAROVA	{"phone": "+70959899024"}
0005435212572	E36751	5784 230871	YULIYA POPOVA	{"email": "yuliya.popova.081967@postgrespro.ru", "phone": "+70074920268"}
0005435212573	E36751	2646 800199	SERGEY NIKOLAEV	{"email": "s.nikolaev_011968@postgrespro.ru", "phone": "+70040658763"}
0005435212574	E36751	0909 606780	IRINA SOKOLOVA	{"email": "sokolova_i061977@postgrespro.ru", "phone": "+70027541325"}
0005435212575	E36751	5198 779824	LYUDMILA KUZMINA	{"phone": "+70498367340"}
0005435212576	634FB9	6133 153917	EKATERINA KUZMINA	{"phone": "+70392875719"}
0005435212577	C1ACE6	4481 706310	EGOR ANDREEV	{"phone": "+70125100615"}
0005435212578	D1B57F	4043 401759	SERGEY FEDOROV	{"email": "fedorov_sergey1981@postgrespro.ru", "phone": "+70743640796"}
0005435212579	CCA119	9772 809667	MIKHAIL VASILEV	{"email": "mikhail_vasilev_1978@postgrespro.ru", "phone": "+70236717664"}
0005435212580	CCA119	4879 799707	EVGENIY ZHURAVLEV	{"phone": "+70392896983"}
0005435212581	CCA119	3350 988294	VIKTOR STEPANOV	{"phone": "+70133515010"}
0005435212582	CCA119	9621 575477	ALENA KALININA	{"phone": "+70278575385"}
0005435212583	7784BF	0513 904079	YULIYA ANDREEVA	{"phone": "+70417667072"}
0005435212584	1C092B	0288 918005	IGOR SMIRNOV	{"phone": "+70584463670"}
0005435212585	AFF8AF	0994 647159	VYACHESLAV VOROBEV	{"phone": "+70685769703"}
0005435212586	BB640B	7245 952103	VADIM ZAKHAROV	{"email": "v_zakharov-081974@postgrespro.ru", "phone": "+70381807792"}
0005435212587	206456	4563 310459	NINA VOLKOVA	{"phone": "+70737187591"}
0005435212588	3A8DDA	3558 140827	OLEG IVANOV	{"phone": "+70961551158"}
0005435212589	442EA1	9812 928957	ILYA MAKSIMOV	{"email": "ilya-maksimov-1957@postgrespro.ru", "phone": "+70336599057"}
0005435212590	9A8EF6	3241 749856	OLGA IVANOVA	{"phone": "+70776931231"}
0005435212591	5F1D60	6059 158093	MAKSIM ANTONOV	{"phone": "+70851272347"}
0005435212592	7277DA	1056 835153	LIDIYA SOLOVEVA	{"phone": "+70748335471"}
0005435212593	881CCD	7903 447448	OLGA AKIMOVA	{"email": "olga-akimova101957@postgrespro.ru", "phone": "+70126390563"}
0005435212594	41B98D	3933 264763	ANNA SCHERBAKOVA	{"phone": "+70877800388"}
0005435212595	41B98D	0806 133214	ALEKSEY VASILEV	{"email": "vasilev-aleksey_30091963@postgrespro.ru", "phone": "+70991665432"}
0005435212596	9A273E	9707 999214	ALEKSANDR BELOV	{"phone": "+70743292418"}
0005435212597	9A273E	7586 325115	OLGA KONDRATEVA	{"email": "kondrateva_olga_061970@postgrespro.ru", "phone": "+70477669746"}
0005435212598	D1A70E	4071 674755	ALEKSANDR SOKOLOV	{"email": "a-sokolov_061966@postgrespro.ru", "phone": "+70216129003"}
0005435212599	D1A70E	2125 771689	NATALYA MAKAROVA	{"email": "makarovanatalya.051966@postgrespro.ru", "phone": "+70005313111"}
0005435212600	F367B9	3305 585416	ALEKSEY VOLKOV	{"phone": "+70179114339"}
0005435212601	F367B9	6700 866168	PELAGEYA ALEKSANDROVA	{"email": "p_aleksandrova_1985@postgrespro.ru", "phone": "+70627958199"}
0005435212602	F367B9	3445 829445	TATYANA SOROKINA	{"phone": "+70149872696"}
0005435212603	944475	9149 409791	ANATOLIY MIKHAYLOV	{"phone": "+70170813706"}
0005435212604	944475	7752 591448	SERGEY POPOV	{"phone": "+70494041421"}
0005435212605	944475	0988 497669	ALEKSEY ZHUKOV	{"email": "zhukovaleksey-21071976@postgrespro.ru", "phone": "+70158747598"}
0005435212606	4AB4C2	9968 084374	ANTONINA KUZNECOVA	{"email": "a.kuznecova031970@postgrespro.ru", "phone": "+70163967142"}
0005435212607	457439	7019 525576	YULIYA EGOROVA	{"phone": "+70425375191"}
0005435212608	1E4494	2256 581541	EGOR SMIRNOV	{"email": "egorsmirnov-1975@postgrespro.ru", "phone": "+70544232845"}
0005435212609	1A437B	8527 885825	ELENA ANDREEVA	{"phone": "+70577526821"}
0005435212610	2B90B3	1430 304781	VALERIY VASILEV	{"phone": "+70707881380"}
0005435212611	3CB1CA	4113 003877	TATYANA KARPOVA	{"phone": "+70170129936"}
0005435212612	51741A	8634 117124	DARYA IVANOVA	{"email": "darya_ivanova1975@postgrespro.ru", "phone": "+70981048665"}
0005435212613	FA259B	0214 092527	SERGEY IVANOV	{"phone": "+70651907735"}
0005435212614	FA259B	6801 700528	IRINA ISAEVA	{"email": "isaevai-011965@postgrespro.ru", "phone": "+70471563160"}
0005435212615	920AD9	8689 897084	YURIY MOROZOV	{"email": "y_morozov_081968@postgrespro.ru", "phone": "+70094198158"}
0005435212616	920AD9	9369 870738	SERGEY KOZLOV	{"email": "sergey.kozlov_1974@postgrespro.ru", "phone": "+70192853144"}
0005435212617	47EBE3	0415 322595	MIKHAIL SHEVCHENKO	{"email": "mikhail-shevchenko.1963@postgrespro.ru", "phone": "+70043279206"}
0005435212618	803029	2242 513210	TATYANA KOROLEVA	{"phone": "+70528760211"}
0005435212619	D906D9	6974 858747	NATALYA MIKHAYLOVA	{"email": "mikhaylova-n.1976@postgrespro.ru", "phone": "+70235500396"}
0005435212620	FB2B79	6482 242530	MIKHAIL MOROZOV	{"phone": "+70886892308"}
0005435212621	6B3B6B	0222 553312	VLADIMIR AFANASEV	{"phone": "+70908258462"}
0005435212622	64EFCF	9761 044830	ANDREY ORLOV	{"phone": "+70829182458"}
0005435212623	1AA29F	1985 336841	ROMAN SOROKIN	{"email": "roman_sorokin.22041960@postgrespro.ru", "phone": "+70680720136"}
0005435212624	F4304A	8584 417119	ASIYA ALEKSEEVA	{"email": "alekseeva-a-1970@postgrespro.ru", "phone": "+70495953926"}
0005435212625	5E8249	5283 953624	SERGEY SAVELEV	{"email": "s_savelev_061967@postgrespro.ru", "phone": "+70630538535"}
0005435212626	BA7390	3417 530950	VASILIY KUZNECOV	{"email": "kuznecov.v051966@postgrespro.ru", "phone": "+70351346058"}
0005435212627	BA7390	2918 202691	YULIYA SIDOROVA	{"email": "yuliya.sidorova-1973@postgrespro.ru", "phone": "+70587615890"}
0005435212628	D1F578	8985 447014	VALERIY TIMOFEEV	{"phone": "+70293806046"}
0005435212629	D1F578	3153 902210	VLADISLAV KUZNECOV	{"email": "vladislav.kuznecov.1975@postgrespro.ru", "phone": "+70342947911"}
0005435212630	D1F578	1180 134410	MARIYA NIKOLAEVA	{"email": "nikolaeva_m021977@postgrespro.ru", "phone": "+70756206173"}
0005435212631	91E5A3	9999 095703	BORIS KUZNECOV	{"phone": "+70909817336"}
0005435212632	91E5A3	2697 197188	YURIY SIDOROV	{"email": "sidorov-yuriy_12051961@postgrespro.ru", "phone": "+70572947672"}
0005435212633	B3DE71	8715 228099	DARYA IVANOVA	{"email": "ivanovadarya.121963@postgrespro.ru", "phone": "+70241728875"}
0005435212634	B3DE71	6409 344264	YULIYA SOLOVEVA	{"email": "solovevay.31011983@postgrespro.ru", "phone": "+70627919907"}
0005435212635	6692DF	0152 021301	IGOR NAUMOV	{"email": "naumov.igor.13101981@postgrespro.ru", "phone": "+70736076974"}
0005435212636	6692DF	1819 825399	SERGEY AFANASEV	{"phone": "+70136568781"}
0005435212637	863006	5135 665460	ANDREY KOZLOV	{"email": "kozlovandrey.101987@postgrespro.ru", "phone": "+70055735510"}
0005435212638	863006	8642 129898	LYUBOV IVANOVA	{"phone": "+70901581922"}
0005435212639	69DB93	4291 528674	MARIYA GORBUNOVA	{"email": "m-gorbunova.071973@postgrespro.ru", "phone": "+70783210431"}
0005435212640	69DB93	3027 142287	VIKTOR ANTONOV	{"phone": "+70827193742"}
0005435212641	DE1235	4892 658192	POLINA NESTEROVA	{"phone": "+70536652547"}
0005435212642	3891E7	5558 923720	OLEG IVANOV	{"email": "o-ivanov091967@postgrespro.ru", "phone": "+70465461841"}
0005435212643	8234BB	6647 539004	OKSANA ALEKSEEVA	{"phone": "+70295235039"}
0005435212644	9D7524	1761 164611	MARINA MOROZOVA	{"email": "morozova_m-1973@postgrespro.ru", "phone": "+70582423280"}
0005435212645	AD8B92	6382 225065	ALEKSANDR KOROLEV	{"email": "korolev.a-121968@postgrespro.ru", "phone": "+70018553570"}
0005435212646	DCDFFF	3360 048225	GALINA AKIMOVA	{"phone": "+70872112459"}
0005435212647	DCDFFF	4044 079940	ANZHELIKA MAKAROVA	{"phone": "+70554414928"}
0005435212648	88BC00	8405 932756	VIKTORIYA GAVRILOVA	{"phone": "+70314614026"}
0005435212649	88BC00	0570 573557	ALSU ZAKHAROVA	{"email": "zakharova_alsu.1975@postgrespro.ru", "phone": "+70239087450"}
0005435212650	2F7DB6	1670 548056	MIKHAIL KARPOV	{"email": "mikhailkarpov.12071961@postgrespro.ru", "phone": "+70330181598"}
0005435212651	7C62F3	1732 916930	VIKTORIYA ZHUKOVA	{"phone": "+70854484980"}
0005435212652	E37EE7	7774 850578	TIMUR ILIN	{"phone": "+70770337991"}
0005435212653	E37EE7	8326 568034	EMIL SOROKIN	{"phone": "+70777052186"}
0005435212654	174036	6284 708669	NADEZHDA ANTONOVA	{"phone": "+70354538122"}
0005435212655	5C1834	8094 142066	ROZA KOMAROVA	{"email": "r-komarova_1968@postgrespro.ru", "phone": "+70124253299"}
0005435212656	8672D9	7216 363164	VASILIY GORBUNOV	{"phone": "+70867126421"}
0005435212657	8672D9	9605 815690	GENNADIY MEDVEDEV	{"phone": "+70676446327"}
0005435212658	B719F9	9205 347154	VLADIMIR FROLOV	{"email": "frolov_v_10111979@postgrespro.ru", "phone": "+70480687607"}
0005435212659	9A411A	3446 891308	ALEKSANDR ZHURAVLEV	{"phone": "+70744574656"}
0005435212660	9A411A	8337 953743	TATYANA KOROLEVA	{"email": "koroleva-t31031972@postgrespro.ru", "phone": "+70885961086"}
0005435212661	89786B	0739 461601	IRINA STEPANOVA	{"phone": "+70373207694"}
0005435212662	DAD6D9	0354 557764	DENIS MAKSIMOV	{"phone": "+70394400725"}
0005435212663	DAD6D9	5342 056396	SERGEY MELNIKOV	{"email": "melnikov_sergey1972@postgrespro.ru", "phone": "+70129735364"}
0005435212664	9F1FCC	5213 052461	SAVELIY MATVEEV	{"email": "s.matveev-1975@postgrespro.ru", "phone": "+70174417777"}
0005435212665	57C990	2984 549186	ANATOLIY ILIN	{"email": "anatoliyilin.041973@postgrespro.ru", "phone": "+70015169893"}
0005435212666	6F98DD	5370 238630	ALEKSANDR ORLOV	{"phone": "+70710741652"}
0005435212667	199E06	3979 130664	VALERIY POPOV	{"phone": "+70588513991"}
0005435212668	ED9E2A	1856 795648	KAMIL KUZMIN	{"phone": "+70338799889"}
0005435212669	ED9E2A	9659 573957	NATALYA FROLOVA	{"email": "natalyafrolova.1971@postgrespro.ru", "phone": "+70519207603"}
0005435212670	93BBCF	5480 513518	MAKSIM KISELEV	{"phone": "+70630571060"}
0005435212671	0F6BBA	8164 090726	NATALIYA NOVIKOVA	{"email": "novikova.n.111984@postgrespro.ru", "phone": "+70818795946"}
0005435212672	52BA6C	4963 171201	ROMAN SCHERBAKOV	{"email": "scherbakov-roman.26061978@postgrespro.ru", "phone": "+70553962418"}
0005435212673	52BA6C	6370 290332	IGOR SEMENOV	{"email": "semenov-i.31101964@postgrespro.ru", "phone": "+70471320964"}
0005435212674	A41B2F	5742 748642	IRINA NESTEROVA	{"phone": "+70252343408"}
0005435212675	0EB69D	3065 376833	POLINA BORISOVA	{"email": "p.borisova011972@postgrespro.ru", "phone": "+70522070757"}
0005435212676	0EB69D	9157 521175	ALEKSEY POPOV	{"email": "a_popov.041970@postgrespro.ru", "phone": "+70327112638"}
0005435212677	BD6A6F	3565 992057	ARTEM MEDVEDEV	{"phone": "+70687652633"}
0005435212678	BD6A6F	4304 831033	NATALYA ZOTOVA	{"phone": "+70116861742"}
0005435212679	5E5B29	8650 364648	ALEKSEY VASILEV	{"email": "avasilev10061970@postgrespro.ru", "phone": "+70362471012"}
0005435212680	5E5B29	1358 700661	ALEKSANDR KUDRYASHOV	{"email": "kudryashov_a1971@postgrespro.ru", "phone": "+70287146332"}
0005435212681	875CDD	5996 572654	YURIY KAZAKOV	{"email": "kazakov_y_21081968@postgrespro.ru", "phone": "+70708311262"}
0005435212682	FBFFD3	3062 688373	OLEG MIKHAYLOV	{"email": "mikhaylov_o1967@postgrespro.ru", "phone": "+70556181069"}
0005435212683	143703	0300 189653	IRINA BARANOVA	{"phone": "+70583673875"}
0005435212684	143703	2780 947353	SERGEY IVANOV	{"email": "s-ivanov08081968@postgrespro.ru", "phone": "+70254661561"}
0005435212685	A378C1	5212 296431	ALEKSANDR SOROKIN	{"phone": "+70682141575"}
0005435212686	2C0DEF	4177 980642	NIKOLAY KOROLEV	{"email": "korolev_nikolay26011977@postgrespro.ru", "phone": "+70516191485"}
0005435212687	2C0DEF	7843 520955	VALENTINA DMITRIEVA	{"phone": "+70777104369"}
0005435212688	561E74	9516 729288	SERGEY SOROKIN	{"phone": "+70060808998"}
0005435212689	765A64	9899 209756	ANNA KARPOVA	{"phone": "+70248933884"}
0005435212690	60595C	6653 127459	DANILA KUZNECOV	{"phone": "+70348631840"}
0005435212691	50F180	3144 038117	PAVEL GRIGOREV	{"phone": "+70083398040"}
0005435212692	BF7B75	8445 710011	EVGENIY FROLOV	{"phone": "+70575272670"}
0005435212693	BF7B75	0313 477681	PETR BORISOV	{"email": "borisov.p-1966@postgrespro.ru", "phone": "+70055384255"}
0005435212694	7C3F32	5673 093351	ANASTASIYA KALININA	{"email": "kalininaanastasiya071973@postgrespro.ru", "phone": "+70450755031"}
0005435212695	534509	2854 685836	SERGEY NIKOLAEV	{"email": "nikolaev_s.1960@postgrespro.ru", "phone": "+70659311187"}
0005435212696	534509	3470 957081	ANTONINA ISAEVA	{"phone": "+70386727696"}
0005435212697	534509	1648 693042	SVETLANA VLASOVA	{"email": "vlasova-s.1969@postgrespro.ru", "phone": "+70946761363"}
0005435212698	6B208B	9847 156573	IRINA ANDREEVA	{"phone": "+70880125122"}
0005435212699	683A36	8448 764370	NADEZHDA ANTONOVA	{"email": "nadezhda-antonova061973@postgrespro.ru", "phone": "+70411276028"}
0005435212700	0079F6	5267 783491	OLGA PETROVA	{"email": "petrovaolga121971@postgrespro.ru", "phone": "+70778503712"}
0005435212701	4307AC	4907 669943	TAMARA KOROLEVA	{"email": "koroleva-t-091968@postgrespro.ru", "phone": "+70826883259"}
0005435212702	6F9820	1718 332762	ELENA ANTONOVA	{"phone": "+70812307332"}
0005435212703	DFF459	2164 306069	MARINA NAZAROVA	{"email": "m-nazarova_061978@postgrespro.ru", "phone": "+70811507577"}
0005435212704	DFF459	0671 813974	OKSANA SAVELEVA	{"email": "savelevao-14031984@postgrespro.ru", "phone": "+70506460686"}
0005435212705	E99FFA	2156 958952	NATALYA ARKHIPOVA	{"email": "arkhipova-n041987@postgrespro.ru", "phone": "+70745905863"}
0005435212706	E99FFA	2750 862978	NIKITA BELOV	{"email": "nikita.belov29051983@postgrespro.ru", "phone": "+70282735094"}
0005435212707	E99FFA	6423 413644	MAKSIM NIKITIN	{"email": "m_nikitin_14091978@postgrespro.ru", "phone": "+70782586919"}
0005435212708	0F9DC7	4876 056829	RUSLAN FEDOROV	{"email": "fedorovruslan.1968@postgrespro.ru", "phone": "+70213892197"}
0005435212709	0F9DC7	5492 607070	ANGELINA VLASOVA	{"email": "vlasova_angelina1964@postgrespro.ru", "phone": "+70968611027"}
0005435212710	3457F1	1670 070273	SERGEY KOZLOV	{"phone": "+70580340080"}
0005435212711	2680E6	3168 060907	DMITRIY TARASOV	{"phone": "+70708758893"}
0005435212712	2680E6	5455 235926	PETR FROLOV	{"phone": "+70084747866"}
0005435212713	2680E6	9727 093810	LILIYA KUZNECOVA	{"email": "kuznecova-liliya.1971@postgrespro.ru", "phone": "+70927027660"}
0005435212714	04AC69	4734 218761	RAFAIL KULIKOV	{"email": "rafail_kulikov.03081974@postgrespro.ru", "phone": "+70588228395"}
0005435212715	04AC69	2385 159061	VLADIMIR MATVEEV	{"phone": "+70605225044"}
0005435212716	3512AB	4113 945273	EVGENIY OSIPOV	{"email": "evgeniy-osipov_10101976@postgrespro.ru", "phone": "+70620960224"}
0005435212717	834952	7562 892248	ANDREY NOVIKOV	{"email": "andrey_novikov-24081970@postgrespro.ru", "phone": "+70386384153"}
0005435212718	CB2B9B	8373 808830	MAKSIM ANDREEV	{"phone": "+70399848082"}
0005435212719	FF1D84	4776 516410	ANASTASIYA MARTYNOVA	{"email": "martynova_a-10021976@postgrespro.ru", "phone": "+70710855500"}
0005435212720	763B32	4073 836234	ALEKSANDR MOISEEV	{"email": "moiseev.aleksandr.1961@postgrespro.ru", "phone": "+70099377505"}
0005435212721	763B32	9033 376311	VALERIY TARASOV	{"email": "tarasov-v-13051973@postgrespro.ru", "phone": "+70698520456"}
0005435212722	4397A0	7604 467879	TAMARA EGOROVA	{"email": "tamara.egorova.12031971@postgrespro.ru", "phone": "+70063745454"}
0005435212723	376801	6532 143525	ALEKSEY EGOROV	{"email": "egorov_aleksey031982@postgrespro.ru", "phone": "+70243900637"}
0005435212724	0E3466	2532 005310	OLGA VASILEVA	{"phone": "+70249239747"}
0005435212725	0E3466	7675 287422	LYUBOV FOMINA	{"email": "fomina_lyubov-031965@postgrespro.ru", "phone": "+70434259430"}
0005435212726	16E20F	5663 580286	ALEKSEY IVANOV	{"email": "aivanov041959@postgrespro.ru", "phone": "+70155856960"}
0005435212727	E76336	9366 039732	RAFAIL SIDOROV	{"email": "sidorovr_05051976@postgrespro.ru", "phone": "+70274509504"}
0005435212728	E76336	2930 600641	ANDREY VOLKOV	{"email": "volkov.a.18121972@postgrespro.ru", "phone": "+70151232203"}
0005435212729	B52EF4	4905 631052	TATYANA POPOVA	{"phone": "+70802108529"}
0005435212730	9C4FBA	9006 708406	ALEKSANDR KOZLOV	{"email": "akozlov-031986@postgrespro.ru", "phone": "+70410418901"}
0005435212731	DAC9AE	9801 999437	VALENTIN RODIONOV	{"email": "rodionov-valentin_031970@postgrespro.ru", "phone": "+70803169691"}
0005435212732	BC175D	6572 329669	IGOR FEDOROV	{"email": "i_fedorov.1968@postgrespro.ru", "phone": "+70427386606"}
0005435212733	BC175D	6985 782442	ALEKSEY TARASOV	{"email": "aleksey.tarasov_1971@postgrespro.ru", "phone": "+70805115595"}
0005435212734	95FA13	1156 090652	ANATOLIY DAVYDOV	{"phone": "+70438224335"}
0005435212735	8D3790	5776 183212	SERGEY KRASNOV	{"email": "krasnovs_1972@postgrespro.ru", "phone": "+70488852173"}
0005435212736	8D3790	1048 371243	ELENA RYABOVA	{"email": "eryabova.13021967@postgrespro.ru", "phone": "+70556646540"}
0005435212737	19222E	8818 169981	TATYANA IVANOVA	{"phone": "+70594681263"}
0005435212738	EF3A87	4050 865232	ANDREY KOZLOV	{"phone": "+70401838694"}
0005435212739	EF3A87	5943 709903	ANDREY EGOROV	{"email": "a_egorov27091986@postgrespro.ru", "phone": "+70820429369"}
0005435212740	EF3A87	6668 482191	IRINA BELOVA	{"email": "ibelova.17051983@postgrespro.ru", "phone": "+70841503366"}
0005435212741	BFDCB7	9191 554946	NATALYA VASILEVA	{"phone": "+70966135362"}
0005435212742	BFDCB7	1875 985812	LYUBOV NIKOLAEVA	{"email": "nikolaeva-lyubov_10111976@postgrespro.ru", "phone": "+70791576821"}
0005435212743	164619	0200 123416	GALINA BORISOVA	{"phone": "+70956286289"}
0005435212744	781D51	6835 415726	NATALYA FEDOROVA	{"phone": "+70343750939"}
0005435212745	781D51	0245 717194	ALEKSEY SAVELEV	{"email": "a.savelev-111978@postgrespro.ru", "phone": "+70724162737"}
0005435212746	C8A540	6982 110248	VALERIY FEDOROV	{"phone": "+70082755503"}
0005435212747	C8A540	0832 094659	TAISA VASILEVA	{"email": "vasileva_taisa-101965@postgrespro.ru", "phone": "+70205240817"}
0005435212748	F4D209	6679 682255	STANISLAV MATVEEV	{"email": "smatveev.1977@postgrespro.ru", "phone": "+70014533412"}
0005435212749	F4D209	8623 295459	IRINA FOMINA	{"email": "irina.fomina_23021974@postgrespro.ru", "phone": "+70218668146"}
0005435212750	FEF2EC	9899 528632	SVETLANA MATVEEVA	{"email": "matveevas061976@postgrespro.ru", "phone": "+70693574070"}
0005435212751	9891F1	4766 329525	VASILIY MATVEEV	{"phone": "+70361381860"}
0005435212752	3F3094	0116 481062	VALENTINA GAVRILOVA	{"phone": "+70120478321"}
0005435212753	A65BFC	6783 395369	VLADISLAV ANDREEV	{"email": "vladislav.andreev.30111971@postgrespro.ru", "phone": "+70420130689"}
0005435212754	F3D04F	3054 458068	MARINA ZHURAVLEVA	{"email": "m.zhuravleva_041973@postgrespro.ru", "phone": "+70027711455"}
0005435212755	F3D04F	3632 602555	YULIYA SAVELEVA	{"email": "saveleva_y08121969@postgrespro.ru", "phone": "+70928171434"}
0005435212756	F3D04F	0704 495046	ALEKSANDR MAKSIMOV	{"phone": "+70189678506"}
0005435212757	1745EC	9219 253897	KRISTINA SMIRNOVA	{"phone": "+70077378144"}
0005435212758	1745EC	3374 947255	DMITRIY KOZLOV	{"email": "kozlov.d_11111976@postgrespro.ru", "phone": "+70155128485"}
0005435212759	20AADF	3369 493488	VADIM SAVELEV	{"phone": "+70741348471"}
0005435212760	20AADF	3072 835636	DMITRIY MEDVEDEV	{"phone": "+70324179181"}
0005435212761	0C7163	8967 819280	GLEB KAZAKOV	{"phone": "+70687773973"}
0005435212762	C2C325	6859 946008	ALEKSEY SAVELEV	{"email": "savelev.aleksey-1965@postgrespro.ru", "phone": "+70740440655"}
0005435212763	8A81BA	0770 408515	GENNADIY TIMOFEEV	{"phone": "+70059576890"}
0005435212764	8A81BA	5233 103014	MARINA NIKOLAEVA	{"email": "mnikolaeva.121983@postgrespro.ru", "phone": "+70919390470"}
0005435212765	8A81BA	2583 737893	EDUARD CHERNOV	{"email": "eduard.chernov-28061978@postgrespro.ru", "phone": "+70795337938"}
0005435212766	5B9F8D	4952 846922	SERGEY NOVIKOV	{"phone": "+70327240475"}
0005435212767	EEFDD4	1091 185336	VLADIMIR RODIONOV	{"email": "v_rodionov.051977@postgrespro.ru", "phone": "+70508317970"}
0005435212768	EEFDD4	7304 216689	ALEKSANDR SOROKIN	{"email": "sorokin-a_01011970@postgrespro.ru", "phone": "+70702464236"}
0005435212769	F041E0	5895 011331	VITALIY SEMENOV	{"email": "v-semenov_25051977@postgrespro.ru", "phone": "+70907332698"}
0005435212770	F041E0	2644 824181	RUSLAN MARTYNOV	{"phone": "+70098253138"}
0005435212771	80A807	8496 770938	VALENTIN PETROV	{"email": "petrov_valentin_28071975@postgrespro.ru", "phone": "+70967193002"}
0005435212772	79B05B	7477 318714	EKATERINA NOVIKOVA	{"phone": "+70731012856"}
0005435212773	79B05B	3474 666747	MAYYA ZHURAVLEVA	{"email": "zhuravleva-mayya.1970@postgrespro.ru", "phone": "+70083546499"}
0005435212774	79B05B	5857 049382	NATALYA MAKAROVA	{"email": "makarova.n.1973@postgrespro.ru", "phone": "+70764063055"}
0005435212775	79B05B	1098 097025	DENIS NIKOLAEV	{"phone": "+70743445561"}
0005435212776	5621A4	1241 134781	VLADIMIR YAKOVLEV	{"email": "yakovlevv23081972@postgrespro.ru", "phone": "+70058835924"}
0005435212777	5621A4	0933 819664	EKATERINA SAVELEVA	{"email": "saveleva-e_08061968@postgrespro.ru", "phone": "+70472545167"}
0005435212778	9DFCFA	0970 567222	ANDREY ALEKSANDROV	{"phone": "+70662675064"}
0005435212779	072ABF	0775 575190	ANNA RODIONOVA	{"phone": "+70362908739"}
0005435212780	CB2BA8	7009 346229	ANNA VASILEVA	{"phone": "+70407051351"}
0005435212781	AA3047	8817 363150	SVETLANA ALEKSEEVA	{"email": "alekseevas121966@postgrespro.ru", "phone": "+70263801531"}
0005435212782	29521D	7235 465485	NIKOLAY KISELEV	{"phone": "+70597064934"}
0005435212783	542EFD	0581 114438	IRINA SAVELEVA	{"email": "saveleva.irina_031965@postgrespro.ru", "phone": "+70508487678"}
0005435212784	191D58	3465 368563	EGOR SERGEEV	{"email": "sergeev-egor-121984@postgrespro.ru", "phone": "+70829945879"}
0005435212785	0E56A3	2178 999930	ALEKSANDR MIRONOV	{"email": "amironov011976@postgrespro.ru", "phone": "+70944404519"}
0005435212786	0E56A3	4706 578677	NIKOLAY CHERNOV	{"email": "chernovnikolay.061969@postgrespro.ru", "phone": "+70234711059"}
0005435212787	0E56A3	7710 903835	YURIY SEMENOV	{"phone": "+70347074827"}
0005435212788	DAC2E3	9383 368216	VIKTORIYA BORISOVA	{"phone": "+70896799221"}
0005435212789	A27CCC	2449 735593	IRINA KOMAROVA	{"email": "irina_komarova05051979@postgrespro.ru", "phone": "+70760640720"}
0005435212790	5EE6F4	4768 565062	MAKSIM GUSEV	{"email": "gusev.maksim.28091971@postgrespro.ru", "phone": "+70856010961"}
0005435212791	825569	0876 920205	DANILA KAZAKOV	{"email": "kazakovd1967@postgrespro.ru", "phone": "+70733309223"}
0005435212792	825569	5745 148221	SVETLANA IVANOVA	{"email": "s.ivanova.101961@postgrespro.ru", "phone": "+70675515269"}
0005435212793	7D9AA3	9674 835553	LYUDMILA YUDINA	{"phone": "+70436368328"}
0005435212794	CA39CE	6458 688541	ANNA KUZNECOVA	{"phone": "+70719369516"}
0005435212851	77D2B7	3543 164098	NATALYA KOROLEVA	{"phone": "+70142759966"}
0005435212795	FA202E	2749 673798	IGOR FILIPPOV	{"email": "filippov-igor25091975@postgrespro.ru", "phone": "+70069339053"}
0005435212796	874868	7398 518845	ELENA SERGEEVA	{"email": "sergeeva-elena041970@postgrespro.ru", "phone": "+70424628274"}
0005435212797	AB7919	0847 909339	NATALYA SEMENOVA	{"phone": "+70033582992"}
0005435212798	C62F80	8115 541195	VERA VOROBEVA	{"email": "v-vorobeva_121979@postgrespro.ru", "phone": "+70079445498"}
0005435212799	C62F80	1937 695269	DARYA STEPANOVA	{"phone": "+70331027140"}
0005435212800	ED0B18	8382 358534	YURIY NOVIKOV	{"phone": "+70976669814"}
0005435212801	248893	0647 309843	NINA ANTONOVA	{"email": "nina_antonova26071985@postgrespro.ru", "phone": "+70828447557"}
0005435212802	964D06	4827 739959	NATALYA TIKHONOVA	{"email": "tikhonova.n1972@postgrespro.ru", "phone": "+70090482225"}
0005435212803	C0EE05	9633 806183	OKSANA POLYAKOVA	{"phone": "+70740655415"}
0005435212804	423DD7	9995 743486	OLEG ROMANOV	{"email": "romanov_o_1967@postgrespro.ru", "phone": "+70382544620"}
0005435212805	423DD7	4399 604573	OLGA KOZLOVA	{"phone": "+70367979630"}
0005435212806	0A2D33	5099 187993	ANNA TIMOFEEVA	{"email": "anna-timofeeva_041970@postgrespro.ru", "phone": "+70470462332"}
0005435212807	101585	3088 025192	NATALYA GUSEVA	{"phone": "+70734456686"}
0005435212808	101585	3393 226089	ANNA IVANOVA	{"email": "annaivanova.091987@postgrespro.ru", "phone": "+70120959806"}
0005435212809	069FB3	6829 921995	SVETLANA NESTEROVA	{"email": "s-nesterova.04061981@postgrespro.ru", "phone": "+70763835141"}
0005435212810	9E039A	3689 729163	SOFIYA LUKYANOVA	{"email": "s-lukyanova.031970@postgrespro.ru", "phone": "+70114011960"}
0005435212811	D651F6	9263 764015	ANNA PAVLOVA	{"phone": "+70106979248"}
0005435212812	1A0FA8	5740 414074	NATALYA TARASOVA	{"email": "natalyatarasova13111979@postgrespro.ru", "phone": "+70278000058"}
0005435212813	1A0FA8	1161 776062	VITALIY NIKITIN	{"email": "vitaliy.nikitin_1972@postgrespro.ru", "phone": "+70924185734"}
0005435212814	D57335	0831 505078	ARTEM SMIRNOV	{"phone": "+70598220844"}
0005435212815	272E82	6546 177034	ALEKSEY MATVEEV	{"phone": "+70425329216"}
0005435212816	6080AE	5767 002727	YULIYA VASILEVA	{"email": "vasilevayuliya-26011960@postgrespro.ru", "phone": "+70711887465"}
0005435212817	6080AE	6239 271305	YURIY CHERNOV	{"email": "chernov_yuriy19061982@postgrespro.ru", "phone": "+70603482548"}
0005435212818	68F093	2606 612071	OLGA ALEKSANDROVA	{"email": "aleksandrovaolga.21011961@postgrespro.ru", "phone": "+70274254020"}
0005435212819	68F093	2697 370526	LYUDMILA DMITRIEVA	{"phone": "+70676392553"}
0005435212820	7CEDF6	0691 410070	MIKHAIL AFANASEV	{"email": "afanasev_m101980@postgrespro.ru", "phone": "+70155354081"}
0005435212821	F82DB5	1033 850644	VIKTOR KONOVALOV	{"phone": "+70457336424"}
0005435212822	8C1657	1392 789118	SERGEY PETROV	{"email": "petrovsergey.051976@postgrespro.ru", "phone": "+70185672888"}
0005435212823	025E9C	0696 586808	SVETLANA MELNIKOVA	{"email": "svetlana-melnikova.071975@postgrespro.ru", "phone": "+70323478145"}
0005435212824	025E9C	0260 678260	RIMMA SOLOVEVA	{"phone": "+70662032209"}
0005435212825	772E3F	3771 344786	IGOR MIKHAYLOV	{"phone": "+70913406461"}
0005435212826	1775D0	9174 207607	KSENIYA NIKOLAEVA	{"phone": "+70948272048"}
0005435212827	BF2CC3	2003 877263	VASILIY GRIGOREV	{"email": "grigorevv.20081980@postgrespro.ru", "phone": "+70658284618"}
0005435212828	BF2CC3	4513 593050	VLADIMIR ABRAMOV	{"phone": "+70780090571"}
0005435212829	14F1FB	6044 920621	NINA FOMINA	{"phone": "+70684452747"}
0005435212830	427F05	4995 281138	DENIS STEPANOV	{"phone": "+70439892216"}
0005435212831	14D99A	4361 787189	NIKOLAY VASILEV	{"email": "nikolay-vasilev.20111970@postgrespro.ru", "phone": "+70831158989"}
0005435212832	14D99A	1563 940275	DMITRIY TIMOFEEV	{"phone": "+70960475277"}
0005435212833	EF91F7	7199 181343	VERA SERGEEVA	{"phone": "+70356876300"}
0005435212834	C21DB3	7505 533722	TATYANA SEMENOVA	{"email": "tatyana.semenova_111968@postgrespro.ru", "phone": "+70869458757"}
0005435212835	3AC56F	3273 797000	IRINA KUZNECOVA	{"email": "i-kuznecova-091963@postgrespro.ru", "phone": "+70504759048"}
0005435212836	52D51B	6759 589251	ALENA LUKYANOVA	{"phone": "+70218995632"}
0005435212837	52D51B	3974 888379	PAVEL KARPOV	{"phone": "+70097558549"}
0005435212838	D9D5FD	7337 078210	STANISLAV TARASOV	{"phone": "+70793646599"}
0005435212839	D9D5FD	1162 517467	VLADIMIR PETROV	{"phone": "+70448554742"}
0005435212840	D15C55	1536 560381	VERONIKA KULIKOVA	{"email": "v.kulikova-1969@postgrespro.ru", "phone": "+70161704695"}
0005435212841	30F9A2	7653 890255	ANTONINA DENISOVA	{"phone": "+70031044774"}
0005435212842	735F14	9658 805494	VLADIMIR VASILEV	{"email": "v_vasilev_061962@postgrespro.ru", "phone": "+70712725577"}
0005435212843	735F14	3332 918451	SVETLANA VASILEVA	{"email": "svasileva-011970@postgrespro.ru", "phone": "+70511730646"}
0005435212844	735F14	3556 992453	KLAVDIYA FADEEVA	{"phone": "+70028411104"}
0005435212845	735F14	0718 618507	VITALIY MAKAROV	{"phone": "+70148103424"}
0005435212846	CCE9F6	0088 562512	VASILIY MOISEEV	{"email": "vasiliy.moiseev.1974@postgrespro.ru", "phone": "+70061498841"}
0005435212847	49E8BC	4102 179680	EVGENIY SCHERBAKOV	{"phone": "+70562443724"}
0005435212848	B3B1CD	0747 448189	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov_28121972@postgrespro.ru", "phone": "+70772939741"}
0005435212849	B3B1CD	0882 017618	MARIYA ERMAKOVA	{"email": "ermakovam.121968@postgrespro.ru", "phone": "+70097888873"}
0005435212850	B3B1CD	4857 102149	MARINA MARTYNOVA	{"phone": "+70021078209"}
0005435212852	77D2B7	8635 568642	YURIY GUSEV	{"email": "gusevy.1964@postgrespro.ru", "phone": "+70996114838"}
0005435212853	59E759	0686 672316	IRINA ZAKHAROVA	{"email": "izakharova_21101970@postgrespro.ru", "phone": "+70607293601"}
0005435212854	0F51BA	2472 386395	MARINA FEDOROVA	{"phone": "+70523263376"}
0005435212855	0F51BA	4612 497522	IVAN VOLKOV	{"phone": "+70446039217"}
0005435212856	EF5841	5884 280029	YULIYA VOLKOVA	{"email": "y-volkova-08111984@postgrespro.ru", "phone": "+70508019865"}
0005435212857	FBBAA1	7291 992965	DMITRIY VOLKOV	{"phone": "+70480489215"}
0005435212858	7DBCD8	0415 357609	ELENA KUZNECOVA	{"email": "kuznecova.elena011974@postgrespro.ru", "phone": "+70342151828"}
0005435212859	7DBCD8	1099 935219	VALENTINA VOLKOVA	{"phone": "+70341202028"}
0005435212860	4C99F7	8550 331963	ANDREY ANTONOV	{"email": "andrey.antonov.1974@postgrespro.ru", "phone": "+70260083559"}
0005435212861	80FF44	4077 693508	SERGEY MELNIKOV	{"email": "sergeymelnikov-1975@postgrespro.ru", "phone": "+70939168053"}
0005435212862	FCAB11	7268 813883	LARISA MAKAROVA	{"email": "larisamakarova-1966@postgrespro.ru", "phone": "+70773671965"}
0005435212863	FCAB11	1871 769364	BORIS ABRAMOV	{"email": "abramovboris1972@postgrespro.ru", "phone": "+70360368926"}
0005435212864	44A794	1373 553621	BORIS SEMENOV	{"email": "semenov-boris.081976@postgrespro.ru", "phone": "+70828754651"}
0005435212865	44A794	8506 288893	STEPAN PAVLOV	{"phone": "+70104167430"}
0005435212866	B6D754	9910 558586	SERGEY NAZAROV	{"phone": "+70628096978"}
0005435212867	2A35B1	8714 876545	ALEKSANDR KUZNECOV	{"phone": "+70471257689"}
0005435212868	3EC52A	5144 929786	ALBINA AKIMOVA	{"email": "albina-akimova.02061969@postgrespro.ru", "phone": "+70071728702"}
0005435212869	E4BF84	0509 822142	LILIYA STEPANOVA	{"email": "stepanova.liliya.1970@postgrespro.ru", "phone": "+70038852956"}
0005435212870	E4BF84	7369 806710	LIDIYA SEMENOVA	{"email": "semenova_l.1972@postgrespro.ru", "phone": "+70348254407"}
0005435212871	E4BF84	5637 414598	VLADIMIR NIKOLAEV	{"phone": "+70638335781"}
0005435212872	E4BF84	5148 957983	ZAKHAR KOZLOV	{"phone": "+70782421499"}
0005435212873	E4BF84	5980 914729	ELVIRA ZOTOVA	{"phone": "+70903065387"}
0005435212874	658E51	6480 884343	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr.121969@postgrespro.ru", "phone": "+70325953984"}
0005435212875	CA2BDF	2033 945104	GALINA PETROVA	{"email": "petrova.galina27081977@postgrespro.ru", "phone": "+70569578775"}
0005435212876	7AB0CD	9837 700527	GALINA ANISIMOVA	{"phone": "+70692588204"}
0005435212877	CDEB62	7919 729630	VIKTOR KOROLEV	{"email": "v-korolev-1970@postgrespro.ru", "phone": "+70825105935"}
0005435212878	65775A	3021 151620	YULIYA LOGINOVA	{"email": "loginova_y061973@postgrespro.ru", "phone": "+70160729185"}
0005435212997	02984F	1681 973999	KONSTANTIN TIKHONOV	{"phone": "+70863212635"}
0005435212879	7E77E9	2725 657069	TATYANA TARASOVA	{"email": "tarasova.t031978@postgrespro.ru", "phone": "+70419848604"}
0005435212880	7E77E9	0400 329948	TATYANA MAKAROVA	{"phone": "+70552709752"}
0005435212881	A39337	8587 449745	VERA ANISIMOVA	{"email": "anisimova_v1965@postgrespro.ru", "phone": "+70971783373"}
0005435212882	96CA6F	3723 916728	NINA SERGEEVA	{"phone": "+70434012043"}
0005435212883	96CA6F	9414 167371	VYACHESLAV EGOROV	{"phone": "+70942185803"}
0005435212884	69AEB5	4495 956545	ALEKSANDR MIKHAYLOV	{"phone": "+70832674690"}
0005435212885	18EAB9	1895 122601	SERGEY KUZNECOV	{"email": "skuznecov14061980@postgrespro.ru", "phone": "+70641860537"}
0005435212886	C9849B	7405 081247	FEDOR POPOV	{"email": "fpopov-1967@postgrespro.ru", "phone": "+70816664432"}
0005435212887	E11A95	0531 565389	VALERIYA VASILEVA	{"email": "vasileva_v_061976@postgrespro.ru", "phone": "+70377650409"}
0005435212888	E11A95	3324 472868	MARINA FEDOROVA	{"phone": "+70484510742"}
0005435212889	CBEA28	1866 798346	EMIL PAVLOV	{"email": "emil_pavlov.061975@postgrespro.ru", "phone": "+70038868449"}
0005435212890	349B90	0665 087220	VLADIMIR ANDREEV	{"email": "andreev-vladimir_1985@postgrespro.ru", "phone": "+70451772600"}
0005435212891	349B90	8014 234997	LIDIYA TROFIMOVA	{"phone": "+70294978629"}
0005435212892	D03635	5898 187098	TATYANA NAZAROVA	{"email": "nazarova_tatyana1974@postgrespro.ru", "phone": "+70621668966"}
0005435212893	289C1E	9273 942504	ELENA KUZNECOVA	{"phone": "+70534172927"}
0005435212894	EBA125	5276 533883	VALENTINA OSIPOVA	{"email": "valentinaosipova081964@postgrespro.ru", "phone": "+70472194343"}
0005435212895	EBA125	1244 216665	SVETLANA MOISEEVA	{"phone": "+70258620243"}
0005435212896	463417	8065 048936	ALEKSANDRA OVCHINNIKOVA	{"phone": "+70574966973"}
0005435212897	AE14B8	9173 242055	NIKOLAY NIKITIN	{"email": "nikitin_n.14021976@postgrespro.ru", "phone": "+70270215968"}
0005435212898	AE14B8	9012 986050	ANTONINA AFANASEVA	{"email": "antoninaafanaseva-1984@postgrespro.ru", "phone": "+70482901559"}
0005435212899	51BAB7	8973 775468	NIKOLAY ISAEV	{"phone": "+70222721654"}
0005435212900	D020C0	1611 704423	NINA STEPANOVA	{"email": "stepanovanina.101974@postgrespro.ru", "phone": "+70417978015"}
0005435212901	D020C0	8667 116547	MARINA BORISOVA	{"phone": "+70237684506"}
0005435212902	1DCFA6	5674 042710	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr-09061974@postgrespro.ru", "phone": "+70844206941"}
0005435212903	00B920	2257 164784	ALBERT STEPANOV	{"phone": "+70882155676"}
0005435212904	00B920	8594 479958	NATALYA YAKOVLEVA	{"email": "yakovlevanatalya111967@postgrespro.ru", "phone": "+70768375071"}
0005435212905	00B920	2071 382400	TATYANA KOLESNIKOVA	{"email": "t_kolesnikova-06101979@postgrespro.ru", "phone": "+70729475993"}
0005435212906	2182E3	5335 952326	ELENA RYABOVA	{"phone": "+70187820202"}
0005435213020	E07050	1141 243498	ROMAN ABRAMOV	{"phone": "+70017550720"}
0005435212907	896D5F	0068 260015	LARISA KARPOVA	{"email": "karpoval19071962@postgrespro.ru", "phone": "+70070479931"}
0005435212908	896D5F	0464 919911	ALEVTINA VASILEVA	{"phone": "+70131209985"}
0005435212909	795C80	3797 312887	VLADIMIR DAVYDOV	{"phone": "+70057843859"}
0005435212910	795C80	6520 425771	ALEKSANDR SMIRNOV	{"email": "aleksandrsmirnov_031972@postgrespro.ru", "phone": "+70617401375"}
0005435212911	686054	2274 349170	MAKSIM BARANOV	{"email": "baranov_m.071982@postgrespro.ru", "phone": "+70378719975"}
0005435212912	686054	2102 341315	KAMILA OSIPOVA	{"phone": "+70686211276"}
0005435212913	3281E9	3767 724378	YURIY MARTYNOV	{"email": "y_martynov-20071973@postgrespro.ru", "phone": "+70631660162"}
0005435212914	3281E9	4686 536765	RIFAT BELOV	{"email": "belov-rifat_1973@postgrespro.ru", "phone": "+70060238027"}
0005435212915	086EC4	4577 179339	EGOR GORBUNOV	{"phone": "+70807637343"}
0005435212916	DBEA25	5351 524582	ELENA VLASOVA	{"email": "elena_vlasova_25081974@postgrespro.ru", "phone": "+70991815222"}
0005435212917	DBEA25	1167 925263	SERGEY KUZNECOV	{"phone": "+70432647244"}
0005435212918	68003C	8820 523128	OLGA KOROLEVA	{"email": "o_koroleva-03021957@postgrespro.ru", "phone": "+70333653535"}
0005435212919	68003C	9604 864502	ARTUR ZAKHAROV	{"phone": "+70195841529"}
0005435212920	5A8EFE	5921 072268	FILIPP GRIGOREV	{"phone": "+70915595654"}
0005435212921	5A8EFE	6654 940579	SERGEY KUZNECOV	{"phone": "+70113049894"}
0005435212922	4BBF95	9722 168578	TATYANA VOROBEVA	{"phone": "+70201594062"}
0005435212923	4BBF95	6406 144644	DANIYA EFIMOVA	{"email": "daniyaefimova.10021966@postgrespro.ru", "phone": "+70559386132"}
0005435212924	024A05	3078 549133	KIRILL FILIPPOV	{"email": "filippovkirill23051983@postgrespro.ru", "phone": "+70165199080"}
0005435212925	95A4F9	7152 608149	GLEB MIRONOV	{"phone": "+70518534416"}
0005435212926	95A4F9	9023 970439	ANATOLIY SEMENOV	{"phone": "+70632439517"}
0005435212927	DAD4DA	2367 360281	PETR NIKOLAEV	{"email": "p-nikolaev_29071970@postgrespro.ru", "phone": "+70470469716"}
0005435212928	DAD4DA	4802 601244	FEDOR VASILEV	{"phone": "+70358439414"}
0005435212929	EE97EC	4358 365801	VALENTINA KUZNECOVA	{"phone": "+70314745816"}
0005435212930	B633C9	1693 124212	SEMEN YAKOVLEV	{"email": "yakovlev_s.071965@postgrespro.ru", "phone": "+70181671004"}
0005435212931	D40F65	5437 506572	ALEKSEY ALEKSEEV	{"email": "alekseev.a.031979@postgrespro.ru", "phone": "+70331387968"}
0005435212932	52592B	9633 166556	SERGEY EGOROV	{"email": "s_egorov-091975@postgrespro.ru", "phone": "+70990061906"}
0005435212933	7B8517	9836 351725	OLGA OSIPOVA	{"email": "osipova_olga_21051972@postgrespro.ru", "phone": "+70483868875"}
0005435212934	9200ED	7311 703010	MAKSIM SERGEEV	{"phone": "+70573262731"}
0005435212935	9200ED	1886 868273	ALEKSANDR MOISEEV	{"phone": "+70521963866"}
0005435212936	3469AD	3980 148113	IRINA BORISOVA	{"email": "borisovairina111970@postgrespro.ru", "phone": "+70314583409"}
0005435212937	3469AD	9301 728486	SVETLANA MOROZOVA	{"phone": "+70532102055"}
0005435212998	C220E1	9126 580409	TATYANA SOLOVEVA	{"phone": "+70887950643"}
0005435212938	D08196	8615 960382	ALINA KUZMINA	{"email": "a_kuzmina_091983@postgrespro.ru", "phone": "+70505326474"}
0005435212939	A383B0	5661 475120	NIKOLAY PETROV	{"phone": "+70741538468"}
0005435212940	95CF91	7711 859827	OLGA KONOVALOVA	{"phone": "+70812855351"}
0005435212941	95CF91	3082 022092	OLEG ILIN	{"email": "ilin-o_011973@postgrespro.ru", "phone": "+70639226034"}
0005435212942	68DB9A	4051 631122	GRIGORIY IVANOV	{"email": "g-ivanov-23071976@postgrespro.ru", "phone": "+70208565260"}
0005435212943	68DB9A	3046 299249	VALERIY TARASOV	{"email": "tarasov.valeriy-19031966@postgrespro.ru", "phone": "+70990011647"}
0005435212944	26F5DA	4375 678332	EKATERINA SEMENOVA	{"email": "semenovae-011974@postgrespro.ru", "phone": "+70968972905"}
0005435212945	26F5DA	3489 303475	EKATERINA EGOROVA	{"email": "ekaterina-egorova_14121961@postgrespro.ru", "phone": "+70332076108"}
0005435212946	26F5DA	8101 091349	ALINA KUDRYASHOVA	{"phone": "+70860165622"}
0005435212947	EDEE53	9536 074054	LYUBOV TROFIMOVA	{"phone": "+70928279502"}
0005435212948	9D649A	5091 699615	KIRILL VOLKOV	{"email": "kvolkov_071956@postgrespro.ru", "phone": "+70815143386"}
0005435212949	9D649A	6726 294803	VLADIMIR KRASNOV	{"phone": "+70298208208"}
0005435212950	B0E033	1698 940626	SERGEY TIMOFEEV	{"phone": "+70223372764"}
0005435212951	B0E033	2295 767627	ALEKSEY GAVRILOV	{"phone": "+70241486365"}
0005435212952	91F43F	8806 130279	KAMILLA MASLOVA	{"email": "maslova-kamilla01091980@postgrespro.ru", "phone": "+70453036578"}
0005435212953	1CB883	0591 781670	RUSTAM NIKITIN	{"phone": "+70937355509"}
0005435212954	B0A383	1011 465984	EVGENIY EGOROV	{"email": "egorov.evgeniy_11051974@postgrespro.ru", "phone": "+70316103201"}
0005435212955	8F56CC	7756 914040	VALERIY ZHUKOV	{"email": "zhukov_valeriy-1961@postgrespro.ru", "phone": "+70132521465"}
0005435212956	1FB5C5	8960 545582	BOGDAN GORBUNOV	{"email": "gorbunov_bogdan25091980@postgrespro.ru", "phone": "+70443514167"}
0005435212957	50D10B	5893 296210	EKATERINA FOMINA	{"email": "e.fomina031972@postgrespro.ru", "phone": "+70526104752"}
0005435212958	6D5FA4	7811 057183	NIKOLAY YAKOVLEV	{"email": "nikolay.yakovlev.011983@postgrespro.ru", "phone": "+70160966697"}
0005435212959	6D5FA4	2247 910865	VIKTOR FEDOROV	{"email": "viktor_fedorov.1966@postgrespro.ru", "phone": "+70320310594"}
0005435212960	772111	8689 341306	MARIANNA VOLKOVA	{"email": "volkova-m05061961@postgrespro.ru", "phone": "+70561700125"}
0005435212961	C48982	4983 252963	NATALYA DMITRIEVA	{"phone": "+70021256780"}
0005435212962	0958C6	8838 607773	ALEKSANDR MARTYNOV	{"phone": "+70261465011"}
0005435212963	621A6D	2411 799680	DARYA EGOROVA	{"email": "egorovad.1977@postgrespro.ru", "phone": "+70992117050"}
0005435212964	7A1C96	8898 084462	SERGEY STEPANOV	{"phone": "+70378043952"}
0005435212965	7A1C96	5063 476824	VLADIMIR IVANOV	{"phone": "+70301836395"}
0005435212966	AE0A44	1973 506490	ANDREY ABRAMOV	{"email": "a-abramov_24011969@postgrespro.ru", "phone": "+70328440228"}
0005435212967	93CBFB	7750 858813	NADEZHDA GORBUNOVA	{"phone": "+70933327861"}
0005435212968	AC81A5	1090 393911	OKSANA FEDOROVA	{"email": "fedorova.o-24111964@postgrespro.ru", "phone": "+70745735482"}
0005435212969	88D425	0389 235653	DENIS MOROZOV	{"phone": "+70087876223"}
0005435212970	BA7518	1857 974881	ARTEM FEDOTOV	{"email": "a.fedotov27051968@postgrespro.ru", "phone": "+70669716946"}
0005435212971	BA7518	6290 804159	ALEKSANDR PETROV	{"email": "a_petrov-1974@postgrespro.ru", "phone": "+70062842638"}
0005435212972	EB8013	5705 396611	ALSU ALEKSANDROVA	{"email": "alsu-aleksandrova_1978@postgrespro.ru", "phone": "+70569704917"}
0005435212973	EB8013	6580 684980	FAINA KOZLOVA	{"email": "kozlovafaina_121977@postgrespro.ru", "phone": "+70615721653"}
0005435212974	47C695	5495 880312	TATYANA TIMOFEEVA	{"email": "t-timofeeva_111966@postgrespro.ru", "phone": "+70985482796"}
0005435212975	FAB6FD	4544 333122	PAVEL SOLOVEV	{"phone": "+70601750083"}
0005435212976	CD9DB7	3075 814776	EVGENIYA AFANASEVA	{"phone": "+70263426451"}
0005435212977	333405	3264 217301	NADEZHDA ALEKSEEVA	{"phone": "+70837521696"}
0005435212978	935C66	3106 926453	NATALYA KUZMINA	{"phone": "+70613551312"}
0005435212979	61E328	7452 549946	SERGEY NOVIKOV	{"phone": "+70727351480"}
0005435212980	AA3E82	0688 348836	MIKHAIL VASILEV	{"email": "mikhail.vasilev_1964@postgrespro.ru", "phone": "+70677598597"}
0005435212981	AA3E82	6939 982810	NATALIYA PAVLOVA	{"email": "pavlova_nataliya011981@postgrespro.ru", "phone": "+70420669345"}
0005435212982	AA3E82	0810 659730	VLADIMIR ILIN	{"email": "v.ilin_031982@postgrespro.ru", "phone": "+70594123614"}
0005435212983	14A310	3460 923118	NATALYA MEDVEDEVA	{"phone": "+70222436865"}
0005435212984	7ACC05	3078 415798	YURIY ANTONOV	{"phone": "+70672977601"}
0005435212985	A9DA36	6534 603833	SVETLANA STEPANOVA	{"phone": "+70211623627"}
0005435212986	3D5E39	3085 519898	RINAT SCHERBAKOV	{"email": "rinat.scherbakov011962@postgrespro.ru", "phone": "+70172879332"}
0005435212987	32D5F4	5885 921614	VERA ZAYCEVA	{"phone": "+70479204346"}
0005435212988	8564FE	9822 459836	ALEKSANDR ANDREEV	{"email": "andreev.aleksandr.09091972@postgrespro.ru", "phone": "+70565891040"}
0005435212989	E044DD	5461 385685	ALEKSEY DAVYDOV	{"email": "davydov-a29071976@postgrespro.ru", "phone": "+70946936465"}
0005435212990	E044DD	6766 987519	YURIY FROLOV	{"email": "frolov-y27021969@postgrespro.ru", "phone": "+70351167520"}
0005435212991	83344F	4937 693407	PAVEL MIKHAYLOV	{"phone": "+70971464306"}
0005435212992	0F3498	6064 130133	YURIY GAVRILOV	{"phone": "+70011150642"}
0005435212993	FD9E62	2918 049536	ALEKSEY TARASOV	{"email": "tarasovaleksey.21021973@postgrespro.ru", "phone": "+70746877927"}
0005435212994	FD9E62	3655 778186	ALEKSANDR KUDRYASHOV	{"email": "kudryashovaleksandr.011962@postgrespro.ru", "phone": "+70237892160"}
0005435212995	FD9E62	2414 778443	GYUZEL SIDOROVA	{"email": "sidorova.g_28091974@postgrespro.ru", "phone": "+70487520571"}
0005435212996	02984F	4754 506675	POLINA ROMANOVA	{"phone": "+70143781250"}
0005435212999	C220E1	6785 401943	VIKTORIYA GERASIMOVA	{"phone": "+70923449727"}
0005435213000	640AE9	6131 494100	VLADIMIR GORBUNOV	{"phone": "+70326523615"}
0005435213001	640AE9	9742 238643	ELLA NESTEROVA	{"phone": "+70328987448"}
0005435213002	569B8A	8571 614207	ALEKSEY SIDOROV	{"phone": "+70936463350"}
0005435213003	6A087A	8842 105281	SVETLANA ZHURAVLEVA	{"phone": "+70490112496"}
0005435213004	3CEB3E	9622 874753	DMITRIY SCHERBAKOV	{"phone": "+70909235968"}
0005435213005	DEE457	7204 839771	ANGELINA OVCHINNIKOVA	{"email": "ovchinnikova_angelina1975@postgrespro.ru", "phone": "+70980121588"}
0005435213006	5E78B3	2234 637248	YURIY MAKSIMOV	{"phone": "+70673721206"}
0005435213007	5E78B3	1673 395703	SERGEY MEDVEDEV	{"phone": "+70678388381"}
0005435213008	5E78B3	5946 705956	OLGA KUDRYASHOVA	{"phone": "+70461765457"}
0005435213009	42E3ED	3001 593612	NATALYA POPOVA	{"email": "popovanatalya-1966@postgrespro.ru", "phone": "+70374476785"}
0005435213010	83E8ED	3835 580019	YURIY AFANASEV	{"phone": "+70352797877"}
0005435213011	83E8ED	2032 764070	OLESYA SMIRNOVA	{"phone": "+70692727940"}
0005435213012	6DD3DC	1264 542582	ANDREY IVANOV	{"phone": "+70707416301"}
0005435213013	6DD3DC	0694 190698	SERGEY NOVIKOV	{"email": "sergey.novikov05011968@postgrespro.ru", "phone": "+70149752132"}
0005435213014	09B580	5705 681707	ELENA IVANOVA	{"email": "ivanovaelena.22051964@postgrespro.ru", "phone": "+70706206347"}
0005435213015	09B580	7204 548919	NIKOLAY NIKOLAEV	{"phone": "+70478067161"}
0005435213016	ED5793	6668 675836	ANGELINA VOLKOVA	{"phone": "+70683479055"}
0005435213017	ED5793	9312 299178	DMITRIY NOVIKOV	{"phone": "+70544856312"}
0005435213018	D04624	2545 033940	MARIYA BORISOVA	{"phone": "+70033160283"}
0005435213019	D04624	5276 444001	KLAVDIYA PAVLOVA	{"phone": "+70397938368"}
0005435213021	F538E4	2084 461797	SVETLANA KOROLEVA	{"email": "koroleva.s-22121976@postgrespro.ru", "phone": "+70068428325"}
0005435213022	8F2F70	2210 061831	DMITRIY ZHUKOV	{"phone": "+70813518753"}
0005435213023	CA99F9	4026 437807	TATYANA LEBEDEVA	{"email": "t_lebedeva29111971@postgrespro.ru", "phone": "+70413193585"}
0005435213024	CA99F9	2440 164061	TATYANA MIKHAYLOVA	{"email": "t-mikhaylova_081981@postgrespro.ru", "phone": "+70057582834"}
0005435213025	EC4FF9	1421 626708	OLGA BORISOVA	{"email": "o.borisova_14101970@postgrespro.ru", "phone": "+70592666061"}
0005435213026	BD0918	2078 143518	ELENA ILINA	{"email": "elena_ilina111968@postgrespro.ru", "phone": "+70899693310"}
0005435213027	C37CC4	2028 809659	DANIIL KUZNECOV	{"phone": "+70666978569"}
0005435213028	C37CC4	5688 100918	GENNADIY ALEKSANDROV	{"email": "aleksandrov-g-1969@postgrespro.ru", "phone": "+70849204925"}
0005435213029	2780B7	1860 092214	EKATERINA YAKOVLEVA	{"phone": "+70394423197"}
0005435213030	B31B59	0999 195776	YANA BELOVA	{"phone": "+70090170909"}
0005435213031	BEDAD7	7892 778893	MARIYA KOROLEVA	{"phone": "+70220407817"}
0005435213032	BEDAD7	4793 232139	VLADIMIR CHERNOV	{"email": "chernov_vladimir-041971@postgrespro.ru", "phone": "+70813828337"}
0005435213033	5BB458	0278 304996	GENNADIY KUZMIN	{"email": "gennadiy-kuzmin071966@postgrespro.ru", "phone": "+70968718365"}
0005435213034	760E02	5884 567678	EVGENIY GERASIMOV	{"email": "gerasimovevgeniy_1973@postgrespro.ru", "phone": "+70083668927"}
0005435213035	1B38AA	6611 242108	IVAN EGOROV	{"email": "iegorov_1974@postgrespro.ru", "phone": "+70213842162"}
0005435213036	D90E11	3663 059958	KLAVDIYA IVANOVA	{"phone": "+70472178934"}
0005435213037	4A32D7	1122 462237	DARYA ROMANOVA	{"phone": "+70677846478"}
0005435213038	4A32D7	8628 664451	EVGENIYA SOLOVEVA	{"email": "soloveva-evgeniya-1974@postgrespro.ru", "phone": "+70864032373"}
0005435213039	85691F	6848 470855	SOFIYA MIKHAYLOVA	{"phone": "+70363481292"}
0005435213040	84B798	7294 626264	EKATERINA SOKOLOVA	{"email": "sokolova.e.1970@postgrespro.ru", "phone": "+70389865623"}
0005435213041	84B798	8976 775694	EKATERINA ZAKHAROVA	{"phone": "+70139512636"}
0005435213042	14B3F4	3284 538970	SERGEY VASILEV	{"phone": "+70932336036"}
0005435213043	6897F6	0767 894994	EKATERINA SOLOVEVA	{"email": "soloveva-e1974@postgrespro.ru", "phone": "+70730627313"}
0005435213044	6897F6	0498 530679	OLGA SOROKINA	{"phone": "+70741072917"}
0005435213045	26FC38	0188 512080	NATALYA BELOVA	{"email": "nbelova-24031977@postgrespro.ru", "phone": "+70270521262"}
0005435213046	B79410	3042 707965	VYACHESLAV SERGEEV	{"phone": "+70608951070"}
0005435213047	B79410	5720 710041	DANIL MAKSIMOV	{"email": "d.maksimov-06011973@postgrespro.ru", "phone": "+70655814094"}
0005435213048	3F3688	2829 554496	DANIIL IVANOV	{"email": "ivanov_daniil1970@postgrespro.ru", "phone": "+70998441615"}
0005435213049	D9BE40	5873 865272	NIKOLAY KUDRYASHOV	{"email": "kudryashov.n.011976@postgrespro.ru", "phone": "+70293241863"}
0005435213050	AA71D4	1177 593414	INNA MELNIKOVA	{"email": "melnikova_i_18011972@postgrespro.ru", "phone": "+70143676486"}
0005435213051	9B91FD	8206 586310	GALINA KUZNECOVA	{"phone": "+70552181960"}
0005435213052	9B91FD	4111 779225	YULIYA ZAKHAROVA	{"email": "yuliya_zakharova-25031972@postgrespro.ru", "phone": "+70474999559"}
0005435213053	E3EE5A	4009 056953	ZINAIDA MOROZOVA	{"email": "morozova.zinaida.021965@postgrespro.ru", "phone": "+70827917181"}
0005435213054	302E5A	8395 566580	LIDIYA FOMINA	{"email": "fomina_lidiya.061983@postgrespro.ru", "phone": "+70157968380"}
0005435213055	AE589F	8329 841649	PAVEL SOLOVEV	{"phone": "+70441215773"}
0005435213056	AE6802	3222 298771	ALEKSANDR DAVYDOV	{"phone": "+70989429565"}
0005435213057	156562	5618 141756	EKATERINA KONDRATEVA	{"phone": "+70639256514"}
0005435213058	156562	5809 050877	ELENA FILIPPOVA	{"phone": "+70213375345"}
0005435213059	8DD781	1457 074502	LYUDMILA BARANOVA	{"email": "lyudmila.baranova-1979@postgrespro.ru", "phone": "+70755299489"}
0005435213060	735080	4190 642193	OLGA SCHERBAKOVA	{"email": "scherbakova.olga.20101976@postgrespro.ru", "phone": "+70460606051"}
0005435213061	A556CB	6781 124522	IVAN NIKITIN	{"phone": "+70295659400"}
0005435213062	A556CB	5769 811879	IRINA KUZMINA	{"phone": "+70558157821"}
0005435213063	5FD095	5686 694593	ANDREY ZHUKOV	{"email": "zhukov-a1967@postgrespro.ru", "phone": "+70788899945"}
0005435213064	C7D02F	3811 324037	VIKTOR IVANOV	{"email": "v_ivanov_091972@postgrespro.ru", "phone": "+70879120188"}
0005435213065	D385C1	7918 604529	ANDREY POPOV	{"phone": "+70033686790"}
0005435213066	DB8EFE	6883 768192	VYACHESLAV SAVELEV	{"phone": "+70792055999"}
0005435213067	BB4B16	9111 983752	ZINAIDA SOLOVEVA	{"email": "solovevazinaida.04061967@postgrespro.ru", "phone": "+70285449074"}
0005435213068	2F7589	4394 888047	GENNADIY KARPOV	{"email": "karpov-gennadiy04071972@postgrespro.ru", "phone": "+70941986725"}
0005435213069	09A0FE	6288 753122	ILYA BARANOV	{"email": "baranov.i-121970@postgrespro.ru", "phone": "+70844847473"}
0005435213070	2EA442	2089 510262	ELENA KOMAROVA	{"phone": "+70078182213"}
0005435213071	426C3B	3786 439716	NADEZHDA FILIPPOVA	{"phone": "+70832189644"}
0005435213072	BFCE47	0059 747572	LEONID TIMOFEEV	{"phone": "+70369268418"}
0005435213073	B7FB52	7662 559665	YANA KUZNECOVA	{"phone": "+70351707916"}
0005435213074	B78938	9205 659874	SERGEY MOROZOV	{"phone": "+70287009359"}
0005435213075	CBC269	1409 463046	OKSANA LEBEDEVA	{"email": "oksana_lebedeva-121964@postgrespro.ru", "phone": "+70456051847"}
0005435213076	CBC269	2200 333724	KONSTANTIN KUZNECOV	{"email": "k-kuznecov-1971@postgrespro.ru", "phone": "+70516119700"}
0005435213077	CBC269	0198 752344	VALENTINA KAZAKOVA	{"email": "v-kazakova1981@postgrespro.ru", "phone": "+70611942834"}
0005435213078	DE3CA0	9224 032955	ALEKSEY KRASNOV	{"email": "krasnova-1979@postgrespro.ru", "phone": "+70812205712"}
0005435213079	DE3CA0	8164 409592	SERGEY FEDOROV	{"email": "fedorov_s.031962@postgrespro.ru", "phone": "+70384527475"}
0005435213080	798531	4979 984105	NURLAN GUSEV	{"phone": "+70068141342"}
0005435213081	B6EC6F	5068 457061	DMITRIY BORISOV	{"phone": "+70835736060"}
0005435213082	B6EC6F	9503 007344	PETR PAVLOV	{"phone": "+70437351590"}
0005435213083	96FCD9	8350 911864	VLADIMIR KOZLOV	{"email": "v_kozlov_1970@postgrespro.ru", "phone": "+70536128983"}
0005435213084	96FCD9	3531 174552	LYUDMILA MARTYNOVA	{"phone": "+70429230300"}
0005435213085	2EA8C9	8376 687921	VYACHESLAV KARPOV	{"phone": "+70908474131"}
0005435213086	1296CC	3016 849795	OLGA ZAYCEVA	{"phone": "+70158783179"}
0005435213087	1296CC	6054 016333	SVETLANA KRASNOVA	{"email": "krasnova.s-021967@postgrespro.ru", "phone": "+70930721986"}
0005435213088	1296CC	9549 647236	VASILIY DENISOV	{"email": "v_denisov101987@postgrespro.ru", "phone": "+70357223653"}
0005435213089	DC8EAB	1578 690017	ALEKSANDR BARANOV	{"email": "a_baranov09061977@postgrespro.ru", "phone": "+70088842222"}
0005435213090	5BE5BE	1902 878277	OLGA DMITRIEVA	{"phone": "+70921920988"}
0005435213091	72AA7A	6154 943403	ARTEM GAVRILOV	{"phone": "+70281746342"}
0005435213092	0707F9	6264 635688	OLGA KUZMINA	{"email": "kuzmina-o_1970@postgrespro.ru", "phone": "+70902587113"}
0005435213093	0707F9	0796 002292	SERGEY BORISOV	{"phone": "+70366528987"}
0005435213094	778C77	2633 196849	TATYANA ZHURAVLEVA	{"phone": "+70196449649"}
0005435213095	BB41B1	2331 000191	DMITRIY ANDREEV	{"email": "dmitriy_andreev-071979@postgrespro.ru", "phone": "+70789817559"}
0005435213096	BB41B1	7446 180797	YULIYA ILINA	{"phone": "+70107106603"}
0005435213097	9E132F	8327 409912	VLADIMIR AFANASEV	{"email": "v.afanasev.041968@postgrespro.ru", "phone": "+70675659370"}
0005435213098	9E132F	9819 198153	MARIYA SOKOLOVA	{"email": "sokolovamariya-1975@postgrespro.ru", "phone": "+70748074173"}
0005435213099	6CB4AF	0159 223980	ELMIRA ILINA	{"phone": "+70397119875"}
0005435213100	B2042B	9971 267527	ALEKSEY MOROZOV	{"phone": "+70977490868"}
0005435213101	D5DEA0	1540 165716	MARIYA LEBEDEVA	{"email": "lebedeva_mariya_1973@postgrespro.ru", "phone": "+70062713768"}
0005435213102	E8080F	8969 275150	VALENTINA PAVLOVA	{"phone": "+70510964267"}
0005435213103	316904	5280 054710	ANDREY SIDOROV	{"phone": "+70901910758"}
0005435213104	A6669D	9245 924948	ELENA VLASOVA	{"email": "e-vlasova_29111962@postgrespro.ru", "phone": "+70659701802"}
0005435213105	6AB32D	0220 839064	MARIYA VOLKOVA	{"email": "volkovamariya29041981@postgrespro.ru", "phone": "+70272004139"}
0005435213106	F3727E	6679 133134	VLADIMIR MOROZOV	{"email": "v.morozov1969@postgrespro.ru", "phone": "+70204565839"}
0005435213107	BEC6C8	7216 019948	DANIYA IVANOVA	{"email": "ivanova_daniya.051987@postgrespro.ru", "phone": "+70035563470"}
0005435213108	BEC6C8	5149 432120	NATALYA VOLKOVA	{"email": "natalya_volkova29031968@postgrespro.ru", "phone": "+70416733343"}
0005435213109	FE7CB0	0334 526198	RUSLAN CHERNOV	{"phone": "+70801518745"}
0005435213110	FE7CB0	1324 548514	GRIGORIY CHERNOV	{"phone": "+70512051035"}
0005435213111	0B1675	1274 902284	ARINA STEPANOVA	{"email": "arina_stepanova.10111980@postgrespro.ru", "phone": "+70219116684"}
0005435213112	E088E0	8322 588780	LARISA SMIRNOVA	{"phone": "+70101781558"}
0005435213113	1D003B	7777 729589	NIKITA MOROZOV	{"email": "nikita-morozov-01031978@postgrespro.ru", "phone": "+70065962875"}
0005435213114	60E134	6759 351798	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov-1966@postgrespro.ru", "phone": "+70600344019"}
0005435213115	60E134	8757 412223	TATYANA NAUMOVA	{"phone": "+70597380555"}
0005435213116	A69D81	5454 737609	VLADISLAV SERGEEV	{"phone": "+70296798923"}
0005435213117	143297	8195 037815	ALEKSEY ABRAMOV	{"phone": "+70814458018"}
0005435213118	ED1703	9918 999471	DMITRIY GAVRILOV	{"email": "gavrilovdmitriy-03021984@postgrespro.ru", "phone": "+70122208151"}
0005435213119	4E57C7	7693 500313	SERGEY KAZAKOV	{"email": "s-kazakov_081961@postgrespro.ru", "phone": "+70864553250"}
0005435213120	2027A9	6146 949276	ELENA ALEKSEEVA	{"email": "alekseeva.elena-121962@postgrespro.ru", "phone": "+70318937505"}
0005435213121	2C986E	2095 543902	DMITRIY MOROZOV	{"phone": "+70373822434"}
0005435213122	2C986E	1689 845602	ELENA NIKITINA	{"phone": "+70755290509"}
0005435213123	C33111	8204 276548	ANASTASIYA POTAPOVA	{"email": "a-potapova01081972@postgrespro.ru", "phone": "+70637456865"}
0005435213124	C33111	8196 127447	ANNA IVANOVA	{"phone": "+70696984605"}
0005435213125	5F1E8F	3664 626936	STANISLAV BARANOV	{"email": "baranov.stanislav_021973@postgrespro.ru", "phone": "+70629130395"}
0005435213126	5F1E8F	7468 232858	VALERIY ZAYCEV	{"email": "zaycev.v011978@postgrespro.ru", "phone": "+70062330538"}
0005435213127	7CACA5	5275 965293	SERGEY FEDOROV	{"email": "fedorovs_081968@postgrespro.ru", "phone": "+70594520456"}
0005435213128	7CACA5	1541 756739	LYUBOV POPOVA	{"email": "lyubov.popova_041973@postgrespro.ru", "phone": "+70004103146"}
0005435213129	49527A	5984 682157	KIRILL SHEVCHENKO	{"email": "shevchenkokirill-091979@postgrespro.ru", "phone": "+70157371501"}
0005435213130	A0318A	5459 445834	TATYANA KUDRYASHOVA	{"phone": "+70299761698"}
0005435213131	37E20B	0618 768730	VALENTINA MOROZOVA	{"email": "v_morozova-101972@postgrespro.ru", "phone": "+70223909721"}
0005435213132	3D2CFD	9585 181087	NATALYA IVANOVA	{"phone": "+70630808961"}
0005435213133	90A079	5227 691477	ALEKSANDR VLASOV	{"phone": "+70621306706"}
0005435213134	0B0B6F	4348 840044	EVGENIYA TITOVA	{"email": "titovaevgeniya.1968@postgrespro.ru", "phone": "+70828995841"}
0005435213135	3FC168	3505 505182	MARIYA FROLOVA	{"email": "frolova_m_1966@postgrespro.ru", "phone": "+70377173924"}
0005435213136	3749DC	5619 137716	NIKOLAY VOLKOV	{"phone": "+70731066246"}
0005435213137	3749DC	9730 188106	ANTON TARASOV	{"email": "a.tarasov_101990@postgrespro.ru", "phone": "+70466379400"}
0005435213138	55575F	4768 453417	VLADISLAV PAVLOV	{"phone": "+70730098346"}
0005435213139	AF40CB	5652 445649	ALEKSANDR DMITRIEV	{"phone": "+70055496548"}
0005435213140	945E93	6555 262691	VALENTINA MOROZOVA	{"phone": "+70033244205"}
0005435213141	945E93	2810 776095	GALINA EGOROVA	{"email": "g_egorova.081978@postgrespro.ru", "phone": "+70020869546"}
0005435213142	945E93	6804 693966	ALENA DMITRIEVA	{"email": "dmitrievaalena-121965@postgrespro.ru", "phone": "+70583559724"}
0005435213143	EEC798	5713 201448	VERA DAVYDOVA	{"email": "davydova.v-23081969@postgrespro.ru", "phone": "+70923166268"}
0005435213144	CB6EDD	4675 601020	GALINA POTAPOVA	{"phone": "+70922260341"}
0005435213145	1EA3C5	9582 743041	ALEKSANDR BARANOV	{"email": "aleksandrbaranov02121983@postgrespro.ru", "phone": "+70652622269"}
0005435213146	6C7BC2	0426 012824	SVETLANA EFIMOVA	{"email": "s_efimova1973@postgrespro.ru", "phone": "+70551906927"}
0005435213147	6C7BC2	4422 591436	DMITRIY MATVEEV	{"phone": "+70632821818"}
0005435213148	D44ECC	4284 486115	EVGENIY TARASOV	{"email": "evgeniytarasov_081981@postgrespro.ru", "phone": "+70477277888"}
0005435213149	D44ECC	0155 727734	VITALIY ROMANOV	{"email": "romanovv1971@postgrespro.ru", "phone": "+70135098208"}
0005435213150	ABF614	9567 928067	SVETLANA KARPOVA	{"email": "karpova_svetlana.1986@postgrespro.ru", "phone": "+70491667251"}
0005435213151	F1AB81	4675 697153	ANNA KUZNECOVA	{"phone": "+70686657448"}
0005435213152	48CB88	6968 497078	ALEKSANDR KUDRYASHOV	{"email": "kudryashova.041973@postgrespro.ru", "phone": "+70260788755"}
0005435213153	48CB88	1445 792395	VALENTINA ALEKSEEVA	{"phone": "+70838406583"}
0005435213154	3EDECC	4887 501828	VIKTORIYA ALEKSANDROVA	{"email": "viktoriya-aleksandrova031958@postgrespro.ru", "phone": "+70923590756"}
0005435213155	3EDECC	1578 795754	YURIY SERGEEV	{"email": "sergeev-y_1966@postgrespro.ru", "phone": "+70695053572"}
0005435213156	3EDECC	2906 434072	SERGEY KUZNECOV	{"email": "kuznecov.sergey-1962@postgrespro.ru", "phone": "+70947455603"}
0005435213157	8EC5CE	9931 894948	LYAYSAN MIRONOVA	{"email": "mironova_lyaysan_1971@postgrespro.ru", "phone": "+70736964124"}
0005435213158	8AAC10	4753 535564	LARISA FROLOVA	{"phone": "+70241734688"}
0005435213159	4E46C9	1682 817182	VLADIMIR ISAEV	{"email": "isaev-v.28071970@postgrespro.ru", "phone": "+70640245060"}
0005435213160	4E46C9	0988 015859	MARINA MARTYNOVA	{"phone": "+70708863511"}
0005435213161	046628	7669 115376	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr_24091969@postgrespro.ru", "phone": "+70944293693"}
0005435213162	046628	7189 992963	YURIY MARTYNOV	{"phone": "+70106577357"}
0005435213163	F2E25D	2910 916163	ALEKSANDR DMITRIEV	{"email": "dmitriev-a.18031978@postgrespro.ru", "phone": "+70887918316"}
0005435213164	45A15E	0438 608698	VERONIKA NAUMOVA	{"email": "v_naumova02041976@postgrespro.ru", "phone": "+70846659132"}
0005435213165	45A15E	9397 039931	NIKITA FEDOTOV	{"email": "nikita.fedotov_1963@postgrespro.ru", "phone": "+70305023145"}
0005435213166	8640FC	8446 909235	OLGA ZHURAVLEVA	{"email": "olga-zhuravleva-15021975@postgrespro.ru", "phone": "+70779049507"}
0005435213167	8640FC	7976 347926	NATALYA ORLOVA	{"email": "orlova_n_13121970@postgrespro.ru", "phone": "+70400690211"}
0005435213168	931CF7	7791 492217	ZOYA NAZAROVA	{"phone": "+70233699605"}
0005435213169	C0C80F	4379 567311	ANDREY ILIN	{"email": "ilin-andrey-06031978@postgrespro.ru", "phone": "+70549198584"}
0005435213170	AA9286	3636 001315	RUSLAN ALEKSEEV	{"phone": "+70516583183"}
0005435213171	AA9286	9874 333293	IRINA FROLOVA	{"email": "i-frolova.1966@postgrespro.ru", "phone": "+70588351436"}
0005435213172	AA9286	2889 411962	KSENIYA STEPANOVA	{"email": "kseniyastepanova.061975@postgrespro.ru", "phone": "+70425957836"}
0005435213173	C1D157	5878 875153	ALEKSANDRA SMIRNOVA	{"email": "smirnova_aleksandra_101970@postgrespro.ru", "phone": "+70888446750"}
0005435213174	E8DEBD	9257 323012	IGOR RODIONOV	{"phone": "+70390237635"}
0005435213175	6D71FA	2959 630613	ILYA OSIPOV	{"email": "ilyaosipov091972@postgrespro.ru", "phone": "+70789488561"}
0005435213176	6D71FA	2609 922649	YULIYA ILINA	{"phone": "+70931085594"}
0005435213177	EDCA84	8930 363403	TAMARA MIKHAYLOVA	{"phone": "+70834018674"}
0005435213178	EDCA84	5885 615270	DMITRIY KOZLOV	{"phone": "+70087683130"}
0005435213179	355878	9704 149959	OLGA PAVLOVA	{"email": "pavlovao_1982@postgrespro.ru", "phone": "+70887631703"}
0005435213180	EBB998	1848 345038	LYUDMILA NIKIFOROVA	{"phone": "+70798470714"}
0005435213181	FDC07E	5127 783057	LYUDMILA LOGINOVA	{"email": "loginovalyudmila-121978@postgrespro.ru", "phone": "+70340087293"}
0005435213182	309751	2414 331845	VERA CHERNOVA	{"phone": "+70139462753"}
0005435213183	309751	9036 996034	NINA OSIPOVA	{"email": "osipova-n.19011971@postgrespro.ru", "phone": "+70784267474"}
0005435213184	D50D0A	0817 950664	ALEKSANDR KUZNECOV	{"email": "kuznecova_051982@postgrespro.ru", "phone": "+70004844844"}
0005435213185	EE9B05	6860 165176	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov_1958@postgrespro.ru", "phone": "+70330236788"}
0005435213186	EE9B05	4240 002113	YURIY PETROV	{"email": "yuriy.petrov_01061976@postgrespro.ru", "phone": "+70224735972"}
0005435213187	031CFA	7304 872066	LYUDMILA MELNIKOVA	{"phone": "+70052483103"}
0005435213188	031CFA	1594 786150	MARINA ROMANOVA	{"phone": "+70000805959"}
0005435213189	2BA918	5759 793247	NINA EFREMOVA	{"phone": "+70969066980"}
0005435213190	2BA918	3054 802662	ALEKSEY SCHERBAKOV	{"email": "scherbakov.a_17121979@postgrespro.ru", "phone": "+70077885389"}
0005435213191	1161F2	6484 870813	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga_1963@postgrespro.ru", "phone": "+70848595952"}
0005435213192	EC9301	4610 484863	MARIANNA STEPANOVA	{"phone": "+70170810683"}
0005435213193	BA01B2	5695 495289	ALEKSANDR NIKOLAEV	{"phone": "+70852706983"}
0005435213194	B27C57	0333 448891	VLADIMIR EGOROV	{"email": "vladimir.egorov-1971@postgrespro.ru", "phone": "+70829829643"}
0005435213195	D21E79	4674 635357	YULIYA LAZAREVA	{"phone": "+70062358411"}
0005435213196	D21E79	8001 708742	ANDREY PAVLOV	{"email": "a-pavlov.121976@postgrespro.ru", "phone": "+70673930500"}
0005435213197	D21E79	0335 970378	ANASTASIYA NIKOLAEVA	{"phone": "+70657844947"}
0005435213198	47C72B	7360 008969	SVETLANA STEPANOVA	{"email": "stepanova-svetlana.1979@postgrespro.ru", "phone": "+70132816723"}
0005435213199	798E43	7719 824285	EKATERINA KAZAKOVA	{"phone": "+70396648943"}
0005435213200	58F6D8	4852 418596	DMITRIY NAZAROV	{"email": "d_nazarov_09111972@postgrespro.ru", "phone": "+70018484690"}
0005435213201	7985C4	4382 712051	ELENA SEMENOVA	{"phone": "+70630153289"}
0005435213202	C68220	4113 093872	GALINA POPOVA	{"phone": "+70242127315"}
0005435213203	388DE7	0807 053312	OLEG ZAYCEV	{"email": "zaycev_o_28091963@postgrespro.ru", "phone": "+70225024855"}
0005435213204	66CAEB	3480 374805	FEDOR VOROBEV	{"email": "vorobev_f_21011975@postgrespro.ru", "phone": "+70199353888"}
0005435213205	03180E	4005 432439	PAVEL POPOV	{"phone": "+70355120902"}
0005435213206	E86C9B	4911 637817	GALINA KUZNECOVA	{"email": "galina.kuznecova1966@postgrespro.ru", "phone": "+70962783534"}
0005435213207	0A06B9	6039 363864	DMITRIY SCHERBAKOV	{"email": "scherbakov.d_1994@postgrespro.ru", "phone": "+70542396329"}
0005435213208	0A06B9	6139 677540	ELENA ABRAMOVA	{"phone": "+70188643967"}
0005435213209	B63C79	8471 365492	ALEKSANDRA MIRONOVA	{"email": "a-mironova_24061973@postgrespro.ru", "phone": "+70531211210"}
0005435213210	3B57C2	6053 355979	ANDREY POPOV	{"email": "popov_andrey_1972@postgrespro.ru", "phone": "+70131614090"}
0005435213211	944F80	6695 666039	RUSLAN KRASNOV	{"email": "krasnov.r-121978@postgrespro.ru", "phone": "+70919630648"}
0005435213212	944F80	3191 962691	VASILIY IVANOV	{"email": "ivanov-vasiliy051973@postgrespro.ru", "phone": "+70898816594"}
0005435213213	C27D3F	7886 061389	SVETLANA EGOROVA	{"email": "svetlana-egorova.13021963@postgrespro.ru", "phone": "+70396078001"}
0005435213214	9A0BD6	5421 594030	OLGA SERGEEVA	{"email": "sergeeva_o021981@postgrespro.ru", "phone": "+70277464901"}
0005435213215	A7ECB2	9497 860928	LEYLA FOMINA	{"email": "leyla_fomina_1970@postgrespro.ru", "phone": "+70074039256"}
0005435213216	A7ECB2	8637 113291	ALEKSANDR BONDARENKO	{"email": "aleksandr.bondarenko1981@postgrespro.ru", "phone": "+70571701380"}
0005435213217	A7ECB2	5141 158755	KHASAN ZHUKOV	{"phone": "+70200754366"}
0005435213218	EF524D	5602 925241	ALEKSANDR BORISOV	{"email": "borisov-aleksandr.081969@postgrespro.ru", "phone": "+70808849864"}
0005435213219	CAB461	4740 744349	VASILIY MELNIKOV	{"phone": "+70631349749"}
0005435213220	CAB461	3193 424239	YURIY VOROBEV	{"email": "vorobev-yuriy1967@postgrespro.ru", "phone": "+70889336687"}
0005435213221	CDCD42	1340 954784	VYACHESLAV MAKAROV	{"phone": "+70488444705"}
0005435213222	63632F	4641 719349	GALINA IVANOVA	{"phone": "+70481156609"}
0005435213223	B6C6CC	3478 842698	IRINA ANISIMOVA	{"email": "irina.anisimova1975@postgrespro.ru", "phone": "+70568145696"}
0005435213224	B6C6CC	0484 458222	YULIYA KRASNOVA	{"email": "krasnovay.081965@postgrespro.ru", "phone": "+70476155615"}
0005435213225	73AC30	2391 900739	SOFIYA OVCHINNIKOVA	{"email": "ovchinnikova.sofiya.16051975@postgrespro.ru", "phone": "+70288225583"}
0005435213226	BBEA20	0861 908574	SERGEY KUZNECOV	{"phone": "+70989111702"}
0005435213227	564A76	5798 906315	SERGEY VASILEV	{"phone": "+70460877134"}
0005435213228	564A76	0924 669874	ALEKSANDR ORLOV	{"email": "orlov_a-091973@postgrespro.ru", "phone": "+70861633833"}
0005435213229	564A76	7920 903895	YURIY SERGEEV	{"phone": "+70327341481"}
0005435213230	3A3D0C	4655 783665	VITALIY ABRAMOV	{"email": "abramov-v_29091981@postgrespro.ru", "phone": "+70818794038"}
0005435213231	3AAA4B	1170 462333	FLYURA DMITRIEVA	{"email": "flyura_dmitrieva.061976@postgrespro.ru", "phone": "+70864082285"}
0005435213232	718D2D	2254 788436	OLGA SAVELEVA	{"phone": "+70326749512"}
0005435213233	EBC346	7968 609416	ELENA TROFIMOVA	{"email": "elenatrofimova05101970@postgrespro.ru", "phone": "+70424671569"}
0005435213234	A91128	6478 463580	ANATOLIY ZAYCEV	{"email": "anatoliy_zaycev_1971@postgrespro.ru", "phone": "+70416040216"}
0005435213235	09EBFE	6141 724076	ALEKSEY MEDVEDEV	{"email": "a.medvedev051973@postgrespro.ru", "phone": "+70921303632"}
0005435213236	35AD37	5434 373639	ANDREY SEMENOV	{"email": "semenov_andrey.1973@postgrespro.ru", "phone": "+70235864318"}
0005435213237	35AD37	6773 769003	VLADIMIR KUZMIN	{"email": "kuzmin-v.05051976@postgrespro.ru", "phone": "+70558752218"}
0005435213238	75BAA5	1411 382398	SERGEY SEMENOV	{"phone": "+70574028432"}
0005435213239	151745	3554 228035	VLADIMIR ROMANOV	{"email": "romanovvladimir09111967@postgrespro.ru", "phone": "+70536081551"}
0005435213240	F29825	0033 783286	IRINA DMITRIEVA	{"phone": "+70797666898"}
0005435213241	6487A3	1463 114131	ELENA MOROZOVA	{"email": "e-morozova_01041977@postgrespro.ru", "phone": "+70550275723"}
0005435213242	6487A3	8067 556501	VALERIYA LOGINOVA	{"phone": "+70559123763"}
0005435213243	3FD32E	2670 944322	NINA SOLOVEVA	{"email": "n.soloveva.09051976@postgrespro.ru", "phone": "+70790118018"}
0005435213244	2E81B6	2750 051459	IVAN KOROLEV	{"email": "ikorolev1978@postgrespro.ru", "phone": "+70015184340"}
0005435213245	2E81B6	5532 344272	VLADIMIR BELOV	{"phone": "+70688903798"}
0005435213246	2E81B6	5574 902056	EVGENIYA FILATOVA	{"email": "evgeniya.filatova_12031965@postgrespro.ru", "phone": "+70748280353"}
0005435213247	E5685A	6037 447552	ALEKSANDR KUZNECOV	{"phone": "+70553879999"}
0005435213248	E5685A	8779 788313	ELIZAVETA NIKIFOROVA	{"email": "nikiforova_e091966@postgrespro.ru", "phone": "+70710750031"}
0005435213249	29934B	9079 756510	ALISA KOROLEVA	{"email": "koroleva_alisa_051978@postgrespro.ru", "phone": "+70369730812"}
0005435213250	92D3B9	1419 842700	ALEKSEY KARPOV	{"email": "karpov.aleksey1963@postgrespro.ru", "phone": "+70964222080"}
0005435213251	3582A1	8980 946135	VYACHESLAV KUZNECOV	{"phone": "+70036687756"}
0005435213252	3582A1	6630 765211	TATYANA ANDREEVA	{"email": "t_andreeva15081965@postgrespro.ru", "phone": "+70835547037"}
0005435213253	C1263C	1513 001165	ALIYA ISAEVA	{"phone": "+70319013815"}
0005435213254	266A8A	7192 022864	NADEZHDA MASLOVA	{"email": "maslova-nadezhda18071960@postgrespro.ru", "phone": "+70250036298"}
0005435213255	0FB322	0154 824620	ALEKSANDR MAKAROV	{"phone": "+70827971562"}
0005435213256	419B82	9120 864197	ALEKSANDR SAVELEV	{"email": "savelev.a-041963@postgrespro.ru", "phone": "+70849677874"}
0005435213257	E988BE	6039 307502	ZOYA MOROZOVA	{"email": "zoyamorozova.12031976@postgrespro.ru", "phone": "+70249644524"}
0005435213258	F83516	6751 181481	STEPAN SCHERBAKOV	{"phone": "+70994169194"}
0005435213259	F83516	8992 653667	ALBINA KOLESNIKOVA	{"email": "albina.kolesnikova.041966@postgrespro.ru", "phone": "+70503459710"}
0005435213260	18CD9C	5533 566919	ELIZAVETA KOROLEVA	{"phone": "+70813189511"}
0005435213261	8B23A4	9635 260791	PAVEL ANDREEV	{"phone": "+70899044627"}
0005435213262	8B23A4	8979 516162	NATALYA SERGEEVA	{"email": "sergeeva-natalya061970@postgrespro.ru", "phone": "+70311778655"}
0005435213263	483378	7159 217247	VASILIY YAKOVLEV	{"phone": "+70470630590"}
0005435213264	252777	3336 398100	MARIYA MATVEEVA	{"email": "matveevamariya1974@postgrespro.ru", "phone": "+70979155707"}
0005435213265	129C96	0101 307833	LILIYA MOROZOVA	{"phone": "+70870437427"}
0005435213266	F33CDE	2391 227573	SHAMIL STEPANOV	{"email": "stepanov_s-111968@postgrespro.ru", "phone": "+70912422010"}
0005435213267	C1A536	8021 303987	LYUDMILA KUZNECOVA	{"phone": "+70243287464"}
0005435213268	88F840	5141 756731	LYUDMILA MIRONOVA	{"email": "mironovalyudmila.11091974@postgrespro.ru", "phone": "+70016240669"}
0005435213269	88F840	0870 466958	VALENTINA GUSEVA	{"email": "v.guseva-07091972@postgrespro.ru", "phone": "+70020670153"}
0005435213270	88F840	5657 201239	ELENA KUZNECOVA	{"phone": "+70689200903"}
0005435213271	6BB965	3091 723329	OLESYA SMIRNOVA	{"email": "smirnova_o_15011976@postgrespro.ru", "phone": "+70252261579"}
0005435213272	6BB965	8185 839864	ANGELINA KOVALEVA	{"email": "angelinakovaleva22021972@postgrespro.ru", "phone": "+70910162171"}
0005435213273	8A599C	1439 595101	ALINA ILINA	{"email": "alina-ilina_03011976@postgrespro.ru", "phone": "+70850975534"}
0005435213274	E9B9A8	1681 119476	VLADIMIR ILIN	{"email": "ilin_v.21081978@postgrespro.ru", "phone": "+70536112913"}
0005435213275	39CAAA	4285 661949	EVGENIYA STEPANOVA	{"phone": "+70939692497"}
0005435213276	7F0D36	7273 265676	ANATOLIY BONDARENKO	{"email": "bondarenko_anatoliy14071968@postgrespro.ru", "phone": "+70099340878"}
0005435213277	A9A3E8	8433 852993	VALENTINA ZOTOVA	{"email": "zotova-v-16061969@postgrespro.ru", "phone": "+70728269786"}
0005435213278	AAA46B	1433 617059	RUSLAN KISELEV	{"email": "kiselev-ruslan011971@postgrespro.ru", "phone": "+70882115653"}
0005435213279	FC2197	5616 810307	EGOR ANDREEV	{"phone": "+70968456384"}
0005435213280	AEEB1C	0691 711051	LYUDMILA SCHERBAKOVA	{"email": "l_scherbakova.1975@postgrespro.ru", "phone": "+70939059964"}
0005435213281	14F85C	1924 492177	EVGENIY KARPOV	{"phone": "+70753970272"}
0005435213282	14F85C	1916 749931	VALENTINA FEDOROVA	{"phone": "+70492237479"}
0005435213283	198BB7	0582 138158	NINA SAVELEVA	{"email": "nina_saveleva031973@postgrespro.ru", "phone": "+70516907831"}
0005435213284	198BB7	2322 860067	KSENIYA ANTONOVA	{"phone": "+70223568298"}
0005435213285	5D8FB0	2670 516891	DMITRIY MEDVEDEV	{"phone": "+70414893933"}
0005435213286	10FA77	1004 958720	NIKOLAY MATVEEV	{"email": "nmatveev.111968@postgrespro.ru", "phone": "+70538695523"}
0005435213287	0DF9DF	1008 767077	LIDIYA YUDINA	{"phone": "+70167760304"}
0005435213288	41ED5E	7395 498110	VIKTOR MOROZOV	{"phone": "+70841336410"}
0005435213289	9EBD33	7580 731106	SERGEY EGOROV	{"phone": "+70774045847"}
0005435213290	4B74FB	9817 981547	ALEKSANDR KISELEV	{"email": "kiselev_a31081968@postgrespro.ru", "phone": "+70580972498"}
0005435213291	3EE12F	5394 236574	NATALYA NAZAROVA	{"phone": "+70244844489"}
0005435213292	167935	7867 006083	STANISLAV ANDREEV	{"email": "stanislav-andreev_1973@postgrespro.ru", "phone": "+70190431222"}
0005435213293	167935	8356 935255	NATALIYA SOKOLOVA	{"email": "nataliya-sokolova23011974@postgrespro.ru", "phone": "+70636979339"}
0005435213294	595113	8353 504776	NADEZHDA KOROLEVA	{"email": "koroleva.n041970@postgrespro.ru", "phone": "+70350069816"}
0005435213295	7C5751	2590 053033	LYUDMILA AFANASEVA	{"phone": "+70013874662"}
0005435213296	7C5751	5741 553128	ALEKSEY KAZAKOV	{"email": "a.kazakov-13071981@postgrespro.ru", "phone": "+70185629073"}
0005435213297	E91F2F	4360 936519	ANTON ANTONOV	{"phone": "+70544855423"}
0005435213298	824D03	1634 929581	NIKOLAY IVANOV	{"email": "nivanov-111976@postgrespro.ru", "phone": "+70360336691"}
0005435213299	4EC775	0733 413974	OKSANA IVANOVA	{"email": "oivanova.111978@postgrespro.ru", "phone": "+70417146878"}
0005435213300	346F67	1250 211335	VALENTINA BELYAEVA	{"email": "belyaeva-v081960@postgrespro.ru", "phone": "+70041136150"}
0005435213301	FED8ED	1252 057331	VIKTOR FROLOV	{"email": "viktor_frolov_081971@postgrespro.ru", "phone": "+70093888998"}
0005435213302	EC7D1B	7622 619028	IVAN KISELEV	{"email": "kiselev_i_1963@postgrespro.ru", "phone": "+70726860377"}
0005435213303	BAE8D7	7199 671415	ALEKSANDR BORISOV	{"email": "aborisov-1973@postgrespro.ru", "phone": "+70716954559"}
0005435213304	28780D	8660 835564	RAFIK IVANOV	{"phone": "+70793718265"}
0005435213305	0AE6CF	0312 207497	DANILA FILIPPOV	{"phone": "+70488006730"}
0005435213306	52FB82	5923 984641	VALENTINA TIMOFEEVA	{"phone": "+70936167903"}
0005435213307	C82430	6411 467214	NAZAR ABRAMOV	{"email": "nabramov-1973@postgrespro.ru", "phone": "+70607925234"}
0005435213308	927C35	8356 422433	ANATOLIY DENISOV	{"email": "a.denisov_021964@postgrespro.ru", "phone": "+70259705842"}
0005435213309	A7DB87	2682 453813	OLGA SEMENOVA	{"phone": "+70824978416"}
0005435213310	A7DB87	2146 828026	POLINA EGOROVA	{"email": "p_egorova071968@postgrespro.ru", "phone": "+70399296709"}
0005435213311	C01DD5	0082 297043	LIDIYA SEMENOVA	{"phone": "+70268929699"}
0005435213312	6B3874	0497 827538	VERONIKA CHERNOVA	{"phone": "+70662420537"}
0005435213313	52D603	7100 110300	ALLA YUDINA	{"phone": "+70502779606"}
0005435213314	E5DDEE	2729 218076	MARIYA KONOVALOVA	{"email": "konovalovamariya09101969@postgrespro.ru", "phone": "+70208557576"}
0005435213315	9B77A6	5574 150524	ALEKSANDR SCHERBAKOV	{"phone": "+70870287892"}
0005435213316	FD1ACB	9371 547621	VALENTINA FROLOVA	{"email": "valentinafrolova_071969@postgrespro.ru", "phone": "+70691220152"}
0005435213317	10C856	3705 509889	DMITRIY FROLOV	{"phone": "+70733881371"}
0005435213318	E96847	8587 238127	TATYANA BELOVA	{"email": "belova-t121959@postgrespro.ru", "phone": "+70136499942"}
0005435213319	8CA6FB	1486 982170	MARINA PAVLOVA	{"email": "pavlova.marina-1975@postgrespro.ru", "phone": "+70150140668"}
0005435213320	8CA6FB	2109 996299	VLADIMIR SERGEEV	{"email": "vladimir.sergeev_1963@postgrespro.ru", "phone": "+70139343470"}
0005435213321	C1E9FF	3667 793855	VLADIMIR KAZAKOV	{"phone": "+70649121429"}
0005435213322	CED3BB	2241 870922	SERGEY YAKOVLEV	{"phone": "+70304330990"}
0005435213323	A5251C	8021 254942	OLEG KUZMIN	{"email": "oleg_kuzmin_051965@postgrespro.ru", "phone": "+70144334702"}
0005435213324	054A58	0963 446289	MARIYA KOZLOVA	{"phone": "+70010118484"}
0005435213325	054A58	5363 988039	ALEKSEY ANDREEV	{"phone": "+70731590351"}
0005435213326	2EC50B	1893 206178	EVGENIY MOROZOV	{"phone": "+70620935042"}
0005435213327	0A843B	8502 477868	NELLI KULIKOVA	{"email": "kulikova-n.1964@postgrespro.ru", "phone": "+70241274795"}
0005435213328	0A843B	5019 418624	ILYA MAKAROV	{"phone": "+70329104471"}
0005435213329	0A843B	5366 502951	YANA ORLOVA	{"email": "orlova-y_18121974@postgrespro.ru", "phone": "+70375028838"}
0005435213330	A61598	2266 045409	GALIYA ERMAKOVA	{"phone": "+70178140456"}
0005435213331	A61598	9567 857209	GALINA ZAYCEVA	{"phone": "+70359173409"}
0005435213332	C00BE6	1019 840232	VARVARA KRASNOVA	{"phone": "+70357991777"}
0005435213333	C00BE6	2991 407087	TATYANA SCHERBAKOVA	{"email": "tatyana_scherbakova.121968@postgrespro.ru", "phone": "+70262114611"}
0005435213334	FDFFBC	5237 427164	EGOR KULIKOV	{"email": "egor_kulikov081972@postgrespro.ru", "phone": "+70955830090"}
0005435213335	D37BA4	2101 257719	IGOR IVANOV	{"phone": "+70955805951"}
0005435213336	D37BA4	6622 044799	KONSTANTIN GERASIMOV	{"phone": "+70543107187"}
0005435213337	8D28F3	2131 097083	EKATERINA KRASNOVA	{"email": "e-krasnova_011972@postgrespro.ru", "phone": "+70654539385"}
0005435213338	305704	8613 789392	ALEKSEY SEMENOV	{"phone": "+70832917461"}
0005435213339	EB48C9	3777 197688	ALEKSEY DAVYDOV	{"email": "davydovaleksey.021968@postgrespro.ru", "phone": "+70187052737"}
0005435213340	D38D1A	8978 025844	ALEKSEY DMITRIEV	{"email": "dmitriev-aleksey-13081974@postgrespro.ru", "phone": "+70172163014"}
0005435213341	19004E	6569 881897	VALENTINA SEMENOVA	{"phone": "+70225418589"}
0005435213342	6343C5	9606 717283	ANNA MOROZOVA	{"phone": "+70816940650"}
0005435213343	5AE44B	4721 216125	PETR PETROV	{"email": "p-petrov_01031967@postgrespro.ru", "phone": "+70238280786"}
0005435213344	5AE44B	9600 831649	IGOR POPOV	{"email": "popov_igor_13051968@postgrespro.ru", "phone": "+70419236394"}
0005435213345	81A22C	4601 661468	BORIS PETROV	{"phone": "+70808866751"}
0005435213346	81A22C	5569 586721	DMITRIY FROLOV	{"phone": "+70620230103"}
0005435213347	5309FB	4256 257273	SERGEY IVANOV	{"email": "s_ivanov.031970@postgrespro.ru", "phone": "+70536148179"}
0005435213348	F95C28	8241 231036	ELENA LEBEDEVA	{"email": "elebedeva.22081968@postgrespro.ru", "phone": "+70596401988"}
0005435213349	F95C28	6965 332671	BORIS ALEKSANDROV	{"phone": "+70906319053"}
0005435213350	48FCEE	4402 074680	LIDIYA YAKOVLEVA	{"phone": "+70865968079"}
0005435213351	6BA957	3457 655286	GENNADIY GERASIMOV	{"email": "gerasimov-gennadiy.24031977@postgrespro.ru", "phone": "+70449995405"}
0005435213352	6BA957	9862 177672	MARIYA STEPANOVA	{"email": "m_stepanova31081978@postgrespro.ru", "phone": "+70650054848"}
0005435213353	6C43EB	4162 592458	MARIYA KAZAKOVA	{"phone": "+70240356133"}
0005435213521	355BD8	7800 393411	ARTUR SMIRNOV	{"phone": "+70252979310"}
0005435213354	7D6DCB	0849 235639	NATALIYA POLYAKOVA	{"email": "n.polyakova28011974@postgrespro.ru", "phone": "+70863188044"}
0005435213355	7D6DCB	3034 435302	ALEKSEY RODIONOV	{"email": "aleksey-rodionov1966@postgrespro.ru", "phone": "+70385667050"}
0005435213356	5FF63F	9505 515796	LIDIYA FEDOROVA	{"phone": "+70431705581"}
0005435213357	5FF63F	3312 066162	NATALYA EFREMOVA	{"phone": "+70375528908"}
0005435213358	C8822F	5730 189147	ALEKSEY PETROV	{"phone": "+70994551060"}
0005435213359	C8822F	5498 645229	NATALIYA KONOVALOVA	{"phone": "+70695918903"}
0005435213360	08F450	6989 105270	YULIYA FEDOROVA	{"email": "fedorovayuliya-30081970@postgrespro.ru", "phone": "+70827165144"}
0005435213361	08F450	6274 587252	ELENA DMITRIEVA	{"phone": "+70209924439"}
0005435213362	A31000	3509 110493	MARINA AKIMOVA	{"email": "akimovam01061972@postgrespro.ru", "phone": "+70837037004"}
0005435213363	67755E	2872 096518	EKATERINA EFIMOVA	{"email": "ekaterina.efimova.16061973@postgrespro.ru", "phone": "+70109682900"}
0005435213364	F2A7EA	4395 000283	SERGEY BELOV	{"phone": "+70069346561"}
0005435213365	25B26E	9782 704604	ALEKSANDR SOLOVEV	{"email": "aleksandrsolovev1970@postgrespro.ru", "phone": "+70538429069"}
0005435213366	34874B	3354 756368	ALEKSEY GRIGOREV	{"email": "alekseygrigorev-041976@postgrespro.ru", "phone": "+70808657679"}
0005435213367	34874B	1556 877433	FEDOR KULIKOV	{"email": "kulikov-f.1958@postgrespro.ru", "phone": "+70896100526"}
0005435213368	7FF4EA	3119 064986	SVETLANA ILINA	{"email": "silina_25061973@postgrespro.ru", "phone": "+70725220395"}
0005435213369	7FF4EA	2122 944512	EKATERINA NESTEROVA	{"phone": "+70227694145"}
0005435213370	C61CF3	7261 918886	MIKHAIL MOROZOV	{"phone": "+70067300353"}
0005435213371	C61CF3	1979 198325	MIKHAIL NAZAROV	{"email": "nazarov.m_091969@postgrespro.ru", "phone": "+70525870543"}
0005435213372	65841C	0719 278314	NATALYA NIKITINA	{"phone": "+70287187431"}
0005435213373	65841C	2656 470069	VIKTOR KONOVALOV	{"email": "v.konovalov-27061965@postgrespro.ru", "phone": "+70728963864"}
0005435213374	419DA2	2664 197767	NIKOLAY ZAYCEV	{"phone": "+70182376738"}
0005435213375	D26308	2948 357632	ALEKSANDR EGOROV	{"email": "aleksandr_egorov-1973@postgrespro.ru", "phone": "+70098163485"}
0005435213376	68B30D	5197 666734	NATALYA AFANASEVA	{"email": "nafanaseva.1971@postgrespro.ru", "phone": "+70630548415"}
0005435213377	A809EB	8412 167782	SVETLANA GERASIMOVA	{"email": "svetlana_gerasimova.29051979@postgrespro.ru", "phone": "+70837021052"}
0005435213378	9BED56	7654 515742	LYUBOV ANISIMOVA	{"email": "anisimova-l-081972@postgrespro.ru", "phone": "+70518792919"}
0005435213379	63C22A	0410 608146	SVETLANA FOMINA	{"email": "fominas1977@postgrespro.ru", "phone": "+70765279999"}
0005435213380	AD88BB	9252 302768	OKSANA YUDINA	{"phone": "+70537489309"}
0005435213381	AD88BB	6371 620737	MIKHAIL IVANOV	{"phone": "+70159193353"}
0005435213382	F49A7B	9190 944869	LUIZA IVANOVA	{"email": "ivanovaluiza.1970@postgrespro.ru", "phone": "+70837649329"}
0005435213383	C6AB2A	6580 773574	EDUARD MATVEEV	{"email": "eduard_matveev1962@postgrespro.ru", "phone": "+70978740832"}
0005435213384	C6AB2A	0396 852814	ALEKSANDR GUSEV	{"email": "gusev.a-011982@postgrespro.ru", "phone": "+70938219051"}
0005435213385	7AF9C2	6454 799630	PETR SEMENOV	{"phone": "+70141242067"}
0005435213386	70A7A5	0087 258419	VALERIY FEDOTOV	{"phone": "+70983158129"}
0005435213387	70A7A5	3053 943232	MARIYA SMIRNOVA	{"email": "m.smirnova12111971@postgrespro.ru", "phone": "+70850862613"}
0005435213388	74D0CE	5588 018535	ALEKSEY DAVYDOV	{"phone": "+70295350637"}
0005435213389	2C3E89	5587 580686	MARIYA ALEKSANDROVA	{"email": "m_aleksandrova-091970@postgrespro.ru", "phone": "+70474230265"}
0005435213390	089A33	8425 196065	MARINA KUDRYASHOVA	{"email": "kudryashova-marina-081968@postgrespro.ru", "phone": "+70811822891"}
0005435213391	31E691	5781 374337	VLADIMIR IVANOV	{"phone": "+70353149635"}
0005435213392	B98A90	0100 580574	OLGA NIKITINA	{"email": "olga.nikitina.24011968@postgrespro.ru", "phone": "+70442594894"}
0005435213393	899A26	6533 727461	DMITRIY MAKSIMOV	{"email": "d_maksimov-011968@postgrespro.ru", "phone": "+70416080083"}
0005435213394	BA19B6	4685 078643	SVETLANA ISAEVA	{"email": "svetlana.isaeva-30061971@postgrespro.ru", "phone": "+70657942943"}
0005435213395	1E5A8F	0391 164633	NADEZHDA ILINA	{"email": "nadezhda_ilina-051989@postgrespro.ru", "phone": "+70579575057"}
0005435213396	560469	1734 607742	ANASTASIYA OVCHINNIKOVA	{"email": "ovchinnikovaanastasiya.21031963@postgrespro.ru", "phone": "+70312752738"}
0005435213397	648457	2369 502777	YULIYA MEDVEDEVA	{"email": "medvedeva.yuliya-051970@postgrespro.ru", "phone": "+70469668004"}
0005435213398	648457	4737 458833	NADEZHDA LAZAREVA	{"phone": "+70287561011"}
0005435213399	C52B04	3409 868111	EVGENIY SIDOROV	{"phone": "+70845638674"}
0005435213400	C52B04	8320 616527	SERGEY ZAKHAROV	{"phone": "+70056811360"}
0005435213401	9013B8	3612 096096	DANILA STEPANOV	{"email": "danilastepanov.1970@postgrespro.ru", "phone": "+70994504759"}
0005435213402	9013B8	4054 106092	IVAN KAZAKOV	{"email": "kazakov.ivan-1969@postgrespro.ru", "phone": "+70422590115"}
0005435213403	EAB074	0101 150135	KARINA POPOVA	{"phone": "+70774122214"}
0005435213404	8093FB	8919 572290	ANDREY MELNIKOV	{"email": "andreymelnikov011973@postgrespro.ru", "phone": "+70221312423"}
0005435213405	8093FB	6732 470715	VLADISLAV NIKOLAEV	{"phone": "+70145865066"}
0005435213406	496ACD	7709 163156	MARIYA GUSEVA	{"phone": "+70372138875"}
0005435213407	DBDFE5	9343 127272	VADIM KUZNECOV	{"phone": "+70462813699"}
0005435213408	DBDFE5	8256 324018	SERGEY VOROBEV	{"email": "vorobev_s.17121956@postgrespro.ru", "phone": "+70659874048"}
0005435213409	C3E755	4307 408944	SERGEY MOISEEV	{"email": "sergey.moiseev.071962@postgrespro.ru", "phone": "+70501099266"}
0005435213410	9D0AF5	0847 128262	TATYANA AKIMOVA	{"email": "tatyana.akimova-19051977@postgrespro.ru", "phone": "+70305921060"}
0005435213411	88AA1E	3289 464780	RINAT AFANASEV	{"email": "rinat.afanasev21111974@postgrespro.ru", "phone": "+70035589277"}
0005435213412	FEE11E	6695 611354	ELENA EFIMOVA	{"phone": "+70522090545"}
0005435213413	0B164F	7487 020796	IVAN OSIPOV	{"phone": "+70037492050"}
0005435213414	0B164F	9568 545363	OLEG MAKAROV	{"phone": "+70371765714"}
0005435213415	3AA2DA	4011 838605	RUSLAN MELNIKOV	{"email": "melnikov-ruslan-041984@postgrespro.ru", "phone": "+70422668990"}
0005435213416	03F7D8	4013 274028	NIKOLAY TIMOFEEV	{"phone": "+70095472706"}
0005435213417	595CDC	3546 607493	ALEKSANDR AFANASEV	{"phone": "+70764227776"}
0005435213418	595CDC	4594 887428	VITALIY MAKAROV	{"email": "v_makarov_01061962@postgrespro.ru", "phone": "+70476625470"}
0005435213419	EB8FB9	9266 502633	ILDAR KUDRYASHOV	{"email": "kudryashov_i.31051963@postgrespro.ru", "phone": "+70286020324"}
0005435213420	EB8FB9	0453 692854	SERGEY KOROLEV	{"phone": "+70573412602"}
0005435213421	0A49DB	0363 519235	VASILIY IVANOV	{"email": "ivanov-v.1979@postgrespro.ru", "phone": "+70527715205"}
0005435213422	0A49DB	6170 047996	OLGA MOROZOVA	{"phone": "+70897592883"}
0005435213423	07FA7D	6815 325546	ALENA TIKHONOVA	{"phone": "+70349692749"}
0005435213424	07FA7D	3717 125462	LARISA KULIKOVA	{"phone": "+70826078754"}
0005435213425	FD8443	8935 433377	ELENA KUDRYASHOVA	{"phone": "+70817823221"}
0005435213426	087756	5158 015929	DENIS NOVIKOV	{"phone": "+70336032609"}
0005435213427	087756	9792 662247	ALEKSEY VASILEV	{"email": "aleksey_vasilev-101977@postgrespro.ru", "phone": "+70300658292"}
0005435213428	D0959A	7783 931220	DENIS ZAYCEV	{"email": "zaycev-denis.031974@postgrespro.ru", "phone": "+70381838206"}
0005435213429	D0959A	3610 328360	SVETLANA ORLOVA	{"email": "sorlova011974@postgrespro.ru", "phone": "+70340079517"}
0005435213430	5A014E	6377 592782	TATYANA FILIPPOVA	{"email": "filippova-t.21071968@postgrespro.ru", "phone": "+70813506725"}
0005435213431	AC4B2B	4027 542227	ALEKSEY DMITRIEV	{"email": "aleksey-dmitriev11061970@postgrespro.ru", "phone": "+70180352063"}
0005435213432	AC4B2B	7761 707953	ARTEM YAKOVLEV	{"email": "yakovlev_a111972@postgrespro.ru", "phone": "+70070613621"}
0005435213433	EB053B	6992 044758	NATALYA STEPANOVA	{"phone": "+70649806068"}
0005435213434	E2C092	0636 220147	ZLATA SOKOLOVA	{"phone": "+70609772253"}
0005435213435	43599D	8621 568258	ALEKSANDRA IVANOVA	{"phone": "+70933233398"}
0005435213436	4EAAD1	2617 451564	IRINA MEDVEDEVA	{"email": "medvedeva_i.081967@postgrespro.ru", "phone": "+70753053678"}
0005435213437	CB99DE	0803 023074	KIRILL EGOROV	{"phone": "+70736247566"}
0005435213438	CB99DE	1642 325772	EMILIYA TIKHONOVA	{"email": "tikhonova.emiliya-071978@postgrespro.ru", "phone": "+70022938388"}
0005435213439	91FB7D	9172 976129	ELENA NESTEROVA	{"email": "e-nesterova-1973@postgrespro.ru", "phone": "+70356659995"}
0005435213440	457A24	4690 296205	NATALYA LUKYANOVA	{"email": "lukyanovanatalya-12091973@postgrespro.ru", "phone": "+70749795091"}
0005435213441	879C49	8319 230755	ANDREY VASILEV	{"phone": "+70484888218"}
0005435213442	55A222	9445 213058	NATALYA NIKOLAEVA	{"email": "nikolaeva-n14031974@postgrespro.ru", "phone": "+70761809638"}
0005435213443	04D091	1314 748966	VIKTOR STEPANOV	{"phone": "+70263509259"}
0005435213444	04D091	2765 839684	IVAN SIDOROV	{"email": "sidorovivan1962@postgrespro.ru", "phone": "+70652396040"}
0005435213445	3F385F	4080 367821	ANNA ZAYCEVA	{"phone": "+70675214622"}
0005435213446	3F385F	9666 065265	LYUDMILA DENISOVA	{"phone": "+70554313988"}
0005435213447	3F385F	4913 967771	VLADIMIR BORISOV	{"email": "borisov_vladimir.06071976@postgrespro.ru", "phone": "+70275772896"}
0005435213448	BA53DB	5669 909464	ILYA NAUMOV	{"email": "naumovi-12031981@postgrespro.ru", "phone": "+70477455953"}
0005435213449	F30E3F	0476 232310	ALEKSANDR ALEKSANDROV	{"email": "aleksandrova_1969@postgrespro.ru", "phone": "+70274628341"}
0005435213450	2E75CC	5028 092496	VIKTOR SEMENOV	{"email": "viktor_semenov08121972@postgrespro.ru", "phone": "+70529946769"}
0005435213451	68C72D	8770 631665	EVGENIY ANTONOV	{"phone": "+70588005525"}
0005435213452	8B9E80	3370 296574	ANATOLIY KOZLOV	{"email": "anatoliykozlov-091971@postgrespro.ru", "phone": "+70789797480"}
0005435213453	8B9E80	4607 680396	OLGA SERGEEVA	{"phone": "+70804260482"}
0005435213454	A72B55	4131 397984	ANASTASIYA KRASNOVA	{"email": "krasnova.anastasiya.1971@postgrespro.ru", "phone": "+70061809933"}
0005435213455	8F04D4	2265 237416	SERGEY ORLOV	{"phone": "+70841916572"}
0005435213456	82581B	2391 197003	VIKTOR VASILEV	{"email": "v_vasilev1978@postgrespro.ru", "phone": "+70768017552"}
0005435213457	04DCA1	2653 810352	SERGEY ANTONOV	{"phone": "+70717448068"}
0005435213458	04DCA1	2712 592432	YURIY KUZNECOV	{"phone": "+70879505013"}
0005435213459	04DCA1	1631 393054	LYUBOV SIDOROVA	{"phone": "+70137717896"}
0005435213460	5C1B0D	7335 543959	DMITRIY IVANOV	{"phone": "+70273186235"}
0005435213461	BD4F1D	4421 360956	NATALIYA MIRONOVA	{"email": "nataliyamironova_10041973@postgrespro.ru", "phone": "+70080286504"}
0005435213462	BD4F1D	8514 133280	ALEKSEY MOROZOV	{"email": "morozovaleksey21121966@postgrespro.ru", "phone": "+70263761971"}
0005435213463	AD3D27	0432 707533	NADEZHDA NIKITINA	{"email": "nikitina.nadezhda-02041981@postgrespro.ru", "phone": "+70088906181"}
0005435213464	AD3D27	3380 263603	ALEKSANDR GERASIMOV	{"email": "gerasimova.1977@postgrespro.ru", "phone": "+70288498340"}
0005435213465	A007D0	0017 305952	GENNADIY ZHUKOV	{"email": "zhukov.g.1977@postgrespro.ru", "phone": "+70263084753"}
0005435213466	E400D5	3721 614487	LIDIYA ZOTOVA	{"email": "zotova.l1970@postgrespro.ru", "phone": "+70926455328"}
0005435213467	343D7E	0705 588978	ELENA ANDREEVA	{"phone": "+70578770567"}
0005435213468	DC1131	0292 613722	VARVARA MOISEEVA	{"email": "v.moiseeva_1971@postgrespro.ru", "phone": "+70531599685"}
0005435213469	51847A	8665 337883	GALINA KOROLEVA	{"email": "koroleva-g1962@postgrespro.ru", "phone": "+70073740145"}
0005435213470	A13700	8121 024093	VASILIY STEPANOV	{"phone": "+70998078946"}
0005435213471	D82402	1152 143399	ANATOLIY SMIRNOV	{"phone": "+70119009838"}
0005435213472	D82402	4655 260537	MAKSIM NOVIKOV	{"phone": "+70139776256"}
0005435213473	0DA437	1431 738453	VALENTINA ABRAMOVA	{"phone": "+70927496772"}
0005435213474	CE06A1	3114 722733	EVGENIY OSIPOV	{"phone": "+70606370940"}
0005435213475	84B6AE	5267 017480	ALEKSEY NOVIKOV	{"email": "novikov_a.091970@postgrespro.ru", "phone": "+70558414536"}
0005435213476	B44FBD	2560 805571	PETR ANTONOV	{"phone": "+70277032240"}
0005435213477	0C26FE	8984 928623	EVGENIY SOKOLOV	{"phone": "+70440303446"}
0005435213478	1AFBA7	1909 998999	NIKITA TARASOV	{"phone": "+70627801178"}
0005435213479	9EDDCF	0074 043208	NADEZHDA GERASIMOVA	{"phone": "+70787266088"}
0005435213480	513B8E	9581 934236	IVAN KUZNECOV	{"email": "i.kuznecov-07081979@postgrespro.ru", "phone": "+70038729698"}
0005435213481	36C18B	3021 002103	ANDREY MEDVEDEV	{"email": "amedvedev081981@postgrespro.ru", "phone": "+70622869658"}
0005435213482	36C18B	6467 119758	ANNA VOLKOVA	{"email": "volkova-anna_081974@postgrespro.ru", "phone": "+70165730918"}
0005435213483	513982	6735 881243	GALINA VOROBEVA	{"phone": "+70572635760"}
0005435213484	35826E	4434 121066	OLGA ANISIMOVA	{"phone": "+70888631581"}
0005435213485	EABAC7	1576 966044	SERGEY OSIPOV	{"email": "s-osipov041982@postgrespro.ru", "phone": "+70483122964"}
0005435213486	744767	8155 853653	DMITRIY ILIN	{"phone": "+70790380626"}
0005435213487	DEEBC5	4417 547092	VLADISLAV ROMANOV	{"email": "v.romanov.031976@postgrespro.ru", "phone": "+70141449710"}
0005435213488	CEF7BB	6616 784501	EKATERINA KALININA	{"email": "e_kalinina-12081977@postgrespro.ru", "phone": "+70450300287"}
0005435213489	CEF7BB	6945 897013	PAVEL NOVIKOV	{"email": "novikov.p.1979@postgrespro.ru", "phone": "+70454301888"}
0005435213490	6AA2F0	0752 495690	VASILIY GORBUNOV	{"phone": "+70669261922"}
0005435213491	203A94	8870 161193	EVGENIYA SOKOLOVA	{"email": "sokolova.evgeniya.081973@postgrespro.ru", "phone": "+70610699355"}
0005435213492	203A94	6350 865552	LARISA SEMENOVA	{"email": "semenova.larisa-121972@postgrespro.ru", "phone": "+70224629703"}
0005435213493	D6F470	9387 694853	ANNA VASILEVA	{"phone": "+70801244879"}
0005435213494	6BCE8F	2831 406502	ELENA MATVEEVA	{"email": "elena_matveeva.021980@postgrespro.ru", "phone": "+70319595295"}
0005435213495	6BCE8F	8265 191407	SEMEN KULIKOV	{"phone": "+70322676268"}
0005435213496	72EACA	6959 439993	VLADIMIR DAVYDOV	{"email": "v-davydov.011970@postgrespro.ru", "phone": "+70480889567"}
0005435213497	72EACA	3328 010579	SERGEY ABRAMOV	{"email": "sabramov.09081980@postgrespro.ru", "phone": "+70694662153"}
0005435213498	0B0E63	3175 099020	SVETLANA KARPOVA	{"phone": "+70401850426"}
0005435213499	0B0E63	1774 200409	POLINA KUZNECOVA	{"email": "pkuznecova-041964@postgrespro.ru", "phone": "+70533209072"}
0005435213500	F2017A	5045 558113	VALERIY SCHERBAKOV	{"email": "scherbakov.valeriy.051966@postgrespro.ru", "phone": "+70534865742"}
0005435213501	F2017A	2071 378210	DARYA MAKAROVA	{"email": "d_makarova_021975@postgrespro.ru", "phone": "+70207935663"}
0005435213502	F2017A	2874 596873	ANTONINA SIDOROVA	{"email": "sidorovaantonina.17051979@postgrespro.ru", "phone": "+70634053342"}
0005435213503	449455	5202 324919	OLGA BOGDANOVA	{"email": "bogdanovao.101983@postgrespro.ru", "phone": "+70498263935"}
0005435213504	449455	1741 816811	KIRILL SEMENOV	{"phone": "+70527746185"}
0005435213505	30CD4D	1988 066856	VALENTINA ZHURAVLEVA	{"email": "vzhuravleva.101980@postgrespro.ru", "phone": "+70947772824"}
0005435213506	24E6F9	7483 723853	NIKOLAY SAVELEV	{"phone": "+70747321815"}
0005435213507	098BD7	2250 045791	ALEKSEY KARPOV	{"email": "a.karpov1956@postgrespro.ru", "phone": "+70016469819"}
0005435213508	8442A0	2865 337553	NIKITA POPOV	{"phone": "+70513623131"}
0005435213509	B012BC	0633 282162	VITALIY PAVLOV	{"phone": "+70637457903"}
0005435213510	8D847A	3382 632193	LYUBOV SAVELEVA	{"phone": "+70468174115"}
0005435213511	3A3B08	9753 710091	RAIL FEDOROV	{"email": "fedorovrail_051981@postgrespro.ru", "phone": "+70425369256"}
0005435213512	BD0645	1554 143710	ALEKSANDR KUZMIN	{"email": "kuzmin.aleksandr.1976@postgrespro.ru", "phone": "+70323370165"}
0005435213513	5B46AD	7892 446721	DMITRIY KOZLOV	{"email": "kozlov.d.1963@postgrespro.ru", "phone": "+70255078215"}
0005435213514	4B6FFF	9946 473632	ARSENIY BORISOV	{"phone": "+70313682899"}
0005435213515	4B6FFF	2587 799872	VALENTINA FILIPPOVA	{"phone": "+70258399962"}
0005435213516	5A416E	3686 689537	SERGEY SOROKIN	{"email": "sergeysorokin_1960@postgrespro.ru", "phone": "+70443917538"}
0005435213517	1C8B1F	0844 816860	SVETLANA EGOROVA	{"phone": "+70683533321"}
0005435213518	1C8B1F	9265 391406	VLADIMIR MAKAROV	{"email": "v_makarov-1984@postgrespro.ru", "phone": "+70418361227"}
0005435213519	CDF4A3	5781 274135	NINA KARPOVA	{"email": "ninakarpova-1979@postgrespro.ru", "phone": "+70101412816"}
0005435213520	2BBD8B	6564 644300	GENNADIY PAVLOV	{"phone": "+70716220101"}
0005435213522	31C194	6386 882587	VALENTINA KOZLOVA	{"email": "kozlovav111979@postgrespro.ru", "phone": "+70677868519"}
0005435213523	31C194	4077 189939	NADEZHDA KOMAROVA	{"phone": "+70312179772"}
0005435213524	532593	0173 716366	ZLATA ZHURAVLEVA	{"phone": "+70076925657"}
0005435213525	532593	1480 970424	ELENA OVCHINNIKOVA	{"email": "e_ovchinnikova_111970@postgrespro.ru", "phone": "+70594731557"}
0005435213526	78F5B2	9602 329653	TATYANA ZHUKOVA	{"email": "tzhukova31011983@postgrespro.ru", "phone": "+70310206769"}
0005435213527	78F5B2	9118 949602	ZULFIYA NESTEROVA	{"phone": "+70751260078"}
0005435213528	78F5B2	0281 357091	YURIY KOZLOV	{"email": "kozlovyuriy1969@postgrespro.ru", "phone": "+70271192733"}
0005435213529	68C2D4	6196 111360	DMITRIY OSIPOV	{"email": "osipovd19021973@postgrespro.ru", "phone": "+70795131137"}
0005435213530	1BF739	3751 784876	ANDREY KONOVALOV	{"phone": "+70758434331"}
0005435213531	248CCA	1283 822130	VIKTOR FILIPPOV	{"email": "filippov_viktor.011975@postgrespro.ru", "phone": "+70863402933"}
0005435213532	ADEC6E	4656 379071	ALEKSEY SMIRNOV	{"phone": "+70406052186"}
0005435213533	ADEC6E	0013 087117	YANA POPOVA	{"email": "yanapopova-111968@postgrespro.ru", "phone": "+70215339494"}
0005435213534	1535AE	1140 717291	OLGA GRISHINA	{"phone": "+70128755430"}
0005435213535	77996B	6367 368919	DARYA ANTONOVA	{"email": "antonova_d_101966@postgrespro.ru", "phone": "+70359737156"}
0005435213536	C6CAAF	3653 803398	RUSTAM MIRONOV	{"email": "r_mironov_1960@postgrespro.ru", "phone": "+70404177067"}
0005435213537	C6CAAF	6484 905393	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr1976@postgrespro.ru", "phone": "+70262459402"}
0005435213538	477964	4522 647540	VIKTOR TIMOFEEV	{"phone": "+70289109872"}
0005435213539	A31AD4	2275 056630	SERGEY PAVLOV	{"phone": "+70285737020"}
0005435213540	87043B	6934 529257	EVGENIY GRIGOREV	{"phone": "+70322693559"}
0005435213541	E11F16	8181 060453	DMITRIY POPOV	{"email": "dmitriy_popov_01051988@postgrespro.ru", "phone": "+70609157662"}
0005435213542	E11F16	8463 391636	VALENTINA YAKOVLEVA	{"email": "yakovleva-valentina_1983@postgrespro.ru", "phone": "+70676675500"}
0005435213543	DEE9C5	3223 598140	LYUDMILA ALEKSANDROVA	{"email": "laleksandrova_06021970@postgrespro.ru", "phone": "+70033779364"}
0005435213544	DEE9C5	9946 738242	VYACHESLAV POPOV	{"email": "popov.vyacheslav-021963@postgrespro.ru", "phone": "+70015195111"}
0005435213545	0CB0D1	5741 162883	RAUZA MIRONOVA	{"phone": "+70423333909"}
0005435213546	0CB0D1	7564 656415	ILYA ANDREEV	{"email": "ilyaandreev.18031965@postgrespro.ru", "phone": "+70131134148"}
0005435213547	0CB0D1	8998 818065	EKATERINA AFANASEVA	{"phone": "+70498979694"}
0005435213548	49E3AB	5175 271467	TATYANA TIKHONOVA	{"phone": "+70430867730"}
0005435213549	921BEA	7282 377191	LEYLA ARKHIPOVA	{"email": "larkhipova-1973@postgrespro.ru", "phone": "+70505067709"}
0005435213550	921BEA	5244 027028	OLEG GUSEV	{"email": "gusev_oleg.15021973@postgrespro.ru", "phone": "+70797209114"}
0005435213551	9C040E	2225 935800	NADEZHDA KUZMINA	{"phone": "+70209525528"}
0005435213552	9C040E	8472 717517	IGOR TARASOV	{"email": "igor_tarasov.021972@postgrespro.ru", "phone": "+70827554044"}
0005435213553	99A095	7633 451081	VALENTINA GAVRILOVA	{"email": "gavrilovavalentina-1968@postgrespro.ru", "phone": "+70738775485"}
0005435213554	99A095	4190 051166	OLGA BORISOVA	{"email": "olga-borisova_031979@postgrespro.ru", "phone": "+70966668169"}
0005435213555	99A095	2491 164981	ELENA SEMENOVA	{"phone": "+70076931048"}
0005435213556	99A095	4408 032498	NATALYA NOVIKOVA	{"email": "n-novikova061971@postgrespro.ru", "phone": "+70330154970"}
0005435213557	6C289E	7872 242979	LIDIYA PAVLOVA	{"email": "l-pavlova11051988@postgrespro.ru", "phone": "+70445180431"}
0005435213558	02DCF3	7075 216874	LYUDMILA NIKITINA	{"phone": "+70230108206"}
0005435213559	02DCF3	1989 221891	YULIYA SMIRNOVA	{"email": "y_smirnova-021969@postgrespro.ru", "phone": "+70702363916"}
0005435213560	1F8E83	8104 112410	VLADIMIR ROMANOV	{"phone": "+70104122577"}
0005435213561	8B434B	7891 378146	NATALYA TIKHONOVA	{"phone": "+70622069662"}
0005435213562	B8D966	9463 302220	TATYANA SIDOROVA	{"email": "sidorova-t01101968@postgrespro.ru", "phone": "+70955353356"}
0005435213563	B8D966	7660 430923	ANASTASIYA VOROBEVA	{"email": "anastasiya_vorobeva1964@postgrespro.ru", "phone": "+70521850768"}
0005435213564	AD5954	4918 286921	VALENTINA NOVIKOVA	{"email": "novikova.v.23101972@postgrespro.ru", "phone": "+70114426213"}
0005435213565	AD5954	4553 997437	ANDREY ABRAMOV	{"phone": "+70230816320"}
0005435213566	42DA3E	0182 643880	ELENA BORISOVA	{"email": "elena.borisova-29061971@postgrespro.ru", "phone": "+70597383473"}
0005435213567	F1ACD4	0671 540081	VITALIY SAVELEV	{"email": "v-savelev1969@postgrespro.ru", "phone": "+70694808837"}
0005435213568	263A44	7113 560011	OLGA KUZNECOVA	{"phone": "+70614666027"}
0005435213569	B660DB	7518 158598	VALERIY ABRAMOV	{"email": "abramov-v.011975@postgrespro.ru", "phone": "+70090742525"}
0005435213570	13C78E	5728 254161	VASILIY ABRAMOV	{"email": "abramov-vasiliy101977@postgrespro.ru", "phone": "+70130765685"}
0005435213571	13C78E	4455 495494	OLGA KISELEVA	{"phone": "+70749583971"}
0005435213572	B797CA	8645 030672	ELENA SOKOLOVA	{"email": "sokolovaelena.1972@postgrespro.ru", "phone": "+70766489795"}
0005435213573	B797CA	2291 344558	MAKAR ISAEV	{"email": "makar-isaev-071979@postgrespro.ru", "phone": "+70051327521"}
0005435213574	5F00A6	9291 075146	VERONIKA EFIMOVA	{"phone": "+70941116133"}
0005435213575	A75306	4149 678701	ROMAN DMITRIEV	{"email": "dmitriev_roman_1981@postgrespro.ru", "phone": "+70507384629"}
0005435213576	1083B8	3140 078345	FAIL VOROBEV	{"phone": "+70993523765"}
0005435213577	E138FB	5008 596919	NADEZHDA GRISHINA	{"phone": "+70818096768"}
0005435213578	211B9A	1562 275565	VIKTOR MAKAROV	{"phone": "+70696583708"}
0005435213579	201CD5	2092 009449	MARINA KOVALEVA	{"phone": "+70706483059"}
0005435213580	B7BA4E	7765 901121	MARINA VASILEVA	{"email": "vasileva.marina_111983@postgrespro.ru", "phone": "+70793187068"}
0005435213581	0DEABD	6359 190096	NATALYA POPOVA	{"phone": "+70549190096"}
0005435213582	A0022B	1141 597232	VIOLETTA KOZLOVA	{"phone": "+70722299232"}
0005435213583	29146B	4197 991198	YURIY MELNIKOV	{"email": "y-melnikov11031960@postgrespro.ru", "phone": "+70610454484"}
0005435213584	D72C68	7338 826338	ANASTASIYA DMITRIEVA	{"email": "a.dmitrieva-1966@postgrespro.ru", "phone": "+70480541533"}
0005435213585	D72C68	5894 403190	VASILIY ALEKSEEV	{"email": "v-alekseev20101976@postgrespro.ru", "phone": "+70988785609"}
0005435213586	D72C68	6106 026070	IVAN KOZLOV	{"phone": "+70931545010"}
0005435213587	55CB63	9497 914058	VERA NIKITINA	{"email": "v-nikitina.1974@postgrespro.ru", "phone": "+70378200336"}
0005435213588	066BF9	4665 429835	NATALYA KOLESNIKOVA	{"phone": "+70547623842"}
0005435213589	066BF9	7379 315084	OLGA GUSEVA	{"email": "olga_guseva1959@postgrespro.ru", "phone": "+70010191911"}
0005435213590	066BF9	1109 533475	ALENA PETROVA	{"phone": "+70462915163"}
0005435213591	223FF1	8771 385950	VLADIMIR SOROKIN	{"phone": "+70049919867"}
0005435213592	A4638B	3963 335017	TAGIR MOROZOV	{"email": "morozov.t.111965@postgrespro.ru", "phone": "+70194318933"}
0005435213593	A4638B	7392 017621	ELIZAVETA ROMANOVA	{"email": "e_romanova21111972@postgrespro.ru", "phone": "+70026830496"}
0005435213594	2C4CDA	6244 552355	VASILIY FROLOV	{"email": "vasiliy_frolov15021969@postgrespro.ru", "phone": "+70270783865"}
0005435213595	7E9D2D	2433 961750	VASILIY SERGEEV	{"phone": "+70222993897"}
0005435213596	7E9D2D	8409 869570	GALINA ALEKSEEVA	{"phone": "+70934803180"}
0005435213597	78262A	6780 893874	STANISLAV KUZMIN	{"email": "s.kuzmin.031966@postgrespro.ru", "phone": "+70918170691"}
0005435213598	04755E	1867 961397	VERA ANISIMOVA	{"email": "vanisimova1976@postgrespro.ru", "phone": "+70770962382"}
0005435213599	9C14D9	0174 277714	VLADIMIR GERASIMOV	{"email": "gerasimov_v_081973@postgrespro.ru", "phone": "+70597180430"}
0005435213600	9C14D9	0486 001834	VALENTIN KUZNECOV	{"email": "kuznecov-v-07051975@postgrespro.ru", "phone": "+70818814269"}
0005435213601	9C14D9	4851 756878	ANATOLIY SEMENOV	{"email": "a-semenov_28111969@postgrespro.ru", "phone": "+70730038904"}
0005435213602	51B3C4	2335 149670	OKSANA KOROLEVA	{"email": "koroleva_o_18041964@postgrespro.ru", "phone": "+70100509926"}
0005435213603	269ABA	9445 830655	LIDIYA TROFIMOVA	{"phone": "+70231966911"}
0005435213604	52F9D2	6603 084893	ALEKSEY YAKOVLEV	{"phone": "+70937521328"}
0005435213605	52F9D2	8309 759592	EVGENIY KUZNECOV	{"email": "kuznecov_e-1989@postgrespro.ru", "phone": "+70938608516"}
0005435213606	FC230F	7727 355729	ARTEM MOROZOV	{"phone": "+70527073730"}
0005435213607	C85290	3918 620364	OLGA KONOVALOVA	{"email": "konovalova-olga_1965@postgrespro.ru", "phone": "+70965966138"}
0005435213608	E9F513	1483 113817	SERGEY GUSEV	{"email": "sergey-gusev-1970@postgrespro.ru", "phone": "+70271771933"}
0005435213609	77CF6D	1996 796032	IVAN NOVIKOV	{"phone": "+70150113156"}
0005435213610	DA842A	8230 614216	GALINA MARTYNOVA	{"email": "gmartynova-09051975@postgrespro.ru", "phone": "+70484753865"}
0005435213611	D18173	9345 582006	ALEKSEY ANDREEV	{"email": "andreevaleksey.22101983@postgrespro.ru", "phone": "+70787281969"}
0005435213612	D155D0	5275 576968	VLADIMIR FEDOROV	{"phone": "+70489384588"}
0005435213613	A5B8E6	3218 707813	TATYANA KUDRYASHOVA	{"email": "tatyana-kudryashova_1971@postgrespro.ru", "phone": "+70072764251"}
0005435213614	9A5E1A	7227 930203	MARIYA BARANOVA	{"email": "baranova.m.1967@postgrespro.ru", "phone": "+70995833873"}
0005435213615	D97F75	1439 285495	EKATERINA FADEEVA	{"phone": "+70794880052"}
0005435213616	61D9EA	6682 780847	EVGENIY ORLOV	{"email": "orlove-01121981@postgrespro.ru", "phone": "+70579913739"}
0005435213617	1E3E3F	5988 416275	IVAN RODIONOV	{"email": "rodionov_ivan021970@postgrespro.ru", "phone": "+70325052976"}
0005435213618	BFD81E	2054 188791	ALSU GORBUNOVA	{"email": "a-gorbunova.1972@postgrespro.ru", "phone": "+70227050344"}
0005435213619	334ABE	0243 976811	VALENTINA YAKOVLEVA	{"phone": "+70370732251"}
0005435213620	7513C6	2064 981763	ELENA KOROLEVA	{"phone": "+70748476304"}
0005435213621	B389D4	1315 452894	SERGEY DMITRIEV	{"email": "s-dmitriev.041966@postgrespro.ru", "phone": "+70208145526"}
0005435213622	D305E5	2118 990556	ALINA NAUMOVA	{"email": "a_naumova.1959@postgrespro.ru", "phone": "+70944577201"}
0005435213623	D9B968	0604 457324	NIKOLAY GAVRILOV	{"email": "nikolaygavrilov-06091958@postgrespro.ru", "phone": "+70328877042"}
0005435213624	4A91DB	7351 216550	VLADIMIR DMITRIEV	{"email": "vladimir_dmitriev.111978@postgrespro.ru", "phone": "+70853018603"}
0005435213625	4A91DB	8985 430653	LIDIYA MAKSIMOVA	{"email": "maksimova_lidiya_25091970@postgrespro.ru", "phone": "+70093676446"}
0005435213626	B85343	8019 853068	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov_v25031972@postgrespro.ru", "phone": "+70970409427"}
0005435213627	B85343	4701 164747	DENIS SOLOVEV	{"email": "solovev.denis-041964@postgrespro.ru", "phone": "+70241552566"}
0005435213628	B85343	7739 052400	ELENA POPOVA	{"email": "popova_e_081974@postgrespro.ru", "phone": "+70546880931"}
0005435213629	B85343	1251 010448	NIKOLAY IVANOV	{"email": "n.ivanov01071981@postgrespro.ru", "phone": "+70971218725"}
0005435213630	F6C73B	9163 723071	NATALYA VASILEVA	{"phone": "+70805873410"}
0005435213631	F6C73B	6500 391306	ARTEM IVANOV	{"email": "ivanov-a11121971@postgrespro.ru", "phone": "+70430609902"}
0005435213632	D8FA41	3949 409366	NAILYA ZAYCEVA	{"email": "nailya_zayceva.31071964@postgrespro.ru", "phone": "+70541632115"}
0005435213633	2E57D0	4996 899134	PAVEL ANDREEV	{"email": "andreev_p1966@postgrespro.ru", "phone": "+70383326633"}
0005435213634	8802DC	8439 766482	ANATOLIY DENISOV	{"email": "anatoliy_denisov.021975@postgrespro.ru", "phone": "+70797875134"}
0005435213635	8802DC	0196 844576	VLADISLAV KUZMIN	{"phone": "+70345529862"}
0005435213636	F424B6	6693 451437	ANNA VOLKOVA	{"phone": "+70813364954"}
0005435213637	E04705	4739 904815	ALEKSANDR NAUMOV	{"email": "aleksandrnaumov1967@postgrespro.ru", "phone": "+70281176779"}
0005435213638	946536	3126 713473	DENIS KOZLOV	{"phone": "+70934889957"}
0005435213639	8CAFD9	4347 020464	VALERIY SOKOLOV	{"phone": "+70008948076"}
0005435213640	8CAFD9	1385 423739	OLGA TARASOVA	{"email": "olgatarasova021966@postgrespro.ru", "phone": "+70165111994"}
0005435213641	8F7C92	3859 450905	PAVEL NAUMOV	{"email": "naumov-pavel_1971@postgrespro.ru", "phone": "+70960455450"}
0005435213642	1B3EAB	1414 658796	ANGELINA KUZMINA	{"email": "kuzminaa.1961@postgrespro.ru", "phone": "+70782134037"}
0005435213643	9FEBF4	1729 715962	SVETLANA KOVALEVA	{"email": "kovaleva-svetlana-1968@postgrespro.ru", "phone": "+70326752175"}
0005435213644	9FEBF4	1527 865919	VALENTINA KUZNECOVA	{"phone": "+70725060795"}
0005435213645	B69FDA	9411 368213	VALENTINA ANISIMOVA	{"email": "valentina-anisimova-1972@postgrespro.ru", "phone": "+70048723451"}
0005435213646	882AF4	6285 876419	ANASTASIYA ANDREEVA	{"email": "a-andreeva.1983@postgrespro.ru", "phone": "+70868466130"}
0005435213647	602759	8158 746206	IGOR KUZNECOV	{"email": "i.kuznecov101981@postgrespro.ru", "phone": "+70803684910"}
0005435213648	602759	2860 915282	DENIS DENISOV	{"email": "denisov.denis-1969@postgrespro.ru", "phone": "+70281295986"}
0005435213649	602759	3299 597872	LYUBOV ZAYCEVA	{"phone": "+70861640994"}
0005435213650	269C18	1417 703613	RAISA MAKAROVA	{"phone": "+70267235416"}
0005435213651	5281BA	0173 736565	VLADIMIR FEDOROV	{"phone": "+70959451748"}
0005435213652	97867A	7948 929644	ANNA MIKHAYLOVA	{"email": "anna_mikhaylova.17051980@postgrespro.ru", "phone": "+70890931067"}
0005435213653	E87AC4	8916 676377	VIKTOR BONDARENKO	{"email": "bondarenko.viktor-1968@postgrespro.ru", "phone": "+70063859767"}
0005435213654	E87AC4	4002 996631	DANIL MELNIKOV	{"email": "danilmelnikov-031975@postgrespro.ru", "phone": "+70688459057"}
0005435213655	6D315A	2769 137862	TATYANA MAKAROVA	{"email": "t.makarova-111981@postgrespro.ru", "phone": "+70240094890"}
0005435213656	E96940	9990 693891	RENAT MEDVEDEV	{"email": "medvedev.renat.1975@postgrespro.ru", "phone": "+70297100872"}
0005435213657	CE9823	6472 627419	ALEKSANDRA FEDOROVA	{"phone": "+70355153233"}
0005435213658	3B906D	0516 700318	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov_23021968@postgrespro.ru", "phone": "+70871516114"}
0005435213659	2A8AB4	1382 123263	SERGEY NAZAROV	{"phone": "+70660179717"}
0005435213660	D74C99	3494 083473	IVAN RODIONOV	{"email": "rodionov_ivan111969@postgrespro.ru", "phone": "+70457563941"}
0005435213661	1B8263	8037 936298	ALEKSEY SEMENOV	{"email": "semenov_aleksey-1967@postgrespro.ru", "phone": "+70342862668"}
0005435213662	1B8263	7719 433545	IRINA NIKOLAEVA	{"phone": "+70819466716"}
0005435213663	8738D5	2099 415929	LEONID KUZNECOV	{"email": "l.kuznecov_21011962@postgrespro.ru", "phone": "+70614308446"}
0005435213664	A69711	0267 148986	ELENA GERASIMOVA	{"email": "e-gerasimova.30111973@postgrespro.ru", "phone": "+70801857372"}
0005435213665	ECA4C0	5615 762884	ALEKSANDR VLASOV	{"email": "vlasov_a_12041965@postgrespro.ru", "phone": "+70555424739"}
0005435213666	ECA4C0	8502 493026	TAISA BORISOVA	{"phone": "+70650475241"}
0005435213667	A72EF7	2808 668825	VIKTORIYA SAVELEVA	{"phone": "+70538365607"}
0005435213668	CB1232	0550 984617	NATALYA GRISHINA	{"email": "grishina_natalya_02041967@postgrespro.ru", "phone": "+70284058879"}
0005435213669	CB1232	5410 155379	EVGENIY ABRAMOV	{"email": "abramov-evgeniy081972@postgrespro.ru", "phone": "+70663433170"}
0005435213670	E7238E	1833 806882	ALEKSANDR KOZLOV	{"phone": "+70752189194"}
0005435213671	E7238E	3385 411561	ARTEM SERGEEV	{"phone": "+70639282172"}
0005435213672	17983C	9204 740793	KONSTANTIN GRIGOREV	{"phone": "+70350392557"}
0005435213673	0F1F53	6654 168162	ELENA ILINA	{"phone": "+70986273114"}
0005435213674	0F1F53	6107 784727	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov_041970@postgrespro.ru", "phone": "+70444158441"}
0005435213675	A8C050	2047 931505	VLADIMIR ILIN	{"phone": "+70489973160"}
0005435213676	A8C050	5949 660771	MARIYA NAUMOVA	{"email": "m-naumova10111977@postgrespro.ru", "phone": "+70242682519"}
0005435213677	A8C050	6780 889131	RAMIL PETROV	{"phone": "+70550163839"}
0005435213678	E9EAE1	1923 495851	IRINA POPOVA	{"email": "i-popova_071964@postgrespro.ru", "phone": "+70028078631"}
0005435213679	E9EAE1	3965 790224	YURIY BARANOV	{"phone": "+70273124377"}
0005435213680	AA66E9	3330 311921	TATYANA SOLOVEVA	{"phone": "+70876381856"}
0005435213681	5DA896	5783 159019	NINA ZAKHAROVA	{"email": "zakharova.nina_1972@postgrespro.ru", "phone": "+70497925053"}
0005435213682	78454E	7749 526037	SERGEY PAVLOV	{"email": "pavlov.s041965@postgrespro.ru", "phone": "+70282415803"}
0005435213683	FC06FC	4686 090675	DMITRIY KRASNOV	{"phone": "+70361903091"}
0005435213684	9DF99C	7930 123287	LYUBOV ZHUKOVA	{"email": "zhukovalyubov.20111981@postgrespro.ru", "phone": "+70188608090"}
0005435213685	9DF99C	3144 483201	VIKTOR SOROKIN	{"email": "viktorsorokin-1976@postgrespro.ru", "phone": "+70912938148"}
0005435213686	5512B1	4803 129662	LIDIYA NOVIKOVA	{"email": "lidiya.novikova1975@postgrespro.ru", "phone": "+70334926390"}
0005435213687	505581	0713 724645	VLADIMIR KOZLOV	{"email": "v.kozlov_091966@postgrespro.ru", "phone": "+70416711357"}
0005435213688	711685	0074 207719	KRISTINA SEMENOVA	{"phone": "+70477541546"}
0005435213689	711685	6410 171211	MIKHAIL GRIGOREV	{"phone": "+70502141670"}
0005435213690	E5BF23	2609 675093	SVETLANA AFANASEVA	{"phone": "+70331557519"}
0005435213691	90C5DE	2130 990349	GALINA FILIPPOVA	{"email": "g.filippova041964@postgrespro.ru", "phone": "+70980836500"}
0005435213692	90C5DE	5659 057864	MARGARITA PAVLOVA	{"phone": "+70733678512"}
0005435213693	48AB87	1971 158209	MARIYA ZAYCEVA	{"phone": "+70697603826"}
0005435213694	48AB87	1003 508256	ANDREY MIRONOV	{"phone": "+70901862551"}
0005435213695	48AB87	8012 934607	VLADIMIR DENISOV	{"email": "denisov.v-26051993@postgrespro.ru", "phone": "+70364759254"}
0005435213696	3A663E	1121 473570	DMITRIY ANDREEV	{"phone": "+70739170493"}
0005435213697	FB6C2E	2125 223705	ANDREY PETROV	{"email": "petrov_andrey_1980@postgrespro.ru", "phone": "+70709133168"}
0005435213698	50EF95	4179 416308	ANNA EGOROVA	{"phone": "+70419579713"}
0005435213699	50EF95	0060 676002	VASILIY FROLOV	{"phone": "+70007477551"}
0005435213700	F44BFA	1987 027324	ZOYA SOKOLOVA	{"email": "z.sokolova1966@postgrespro.ru", "phone": "+70897488370"}
0005435213701	7801C5	9011 275992	ANASTASIYA MOROZOVA	{"phone": "+70765599780"}
0005435213702	7801C5	3351 141767	EVGENIY KUZNECOV	{"phone": "+70904274124"}
0005435213703	8A6DBC	7575 623037	KRISTINA ARKHIPOVA	{"phone": "+70478658724"}
0005435213704	8A6DBC	1814 398294	OLGA PETROVA	{"email": "petrovaolga.17011960@postgrespro.ru", "phone": "+70567493546"}
0005435213705	8A6DBC	8272 122842	NATALYA ROMANOVA	{"email": "n-romanova23091973@postgrespro.ru", "phone": "+70050542599"}
0005435213706	D2DE8C	7086 266550	VERONIKA FROLOVA	{"email": "frolova-v-11101975@postgrespro.ru", "phone": "+70445361417"}
0005435213707	D2074C	6738 022480	VIKTORIYA KOZLOVA	{"email": "v_kozlova-08101956@postgrespro.ru", "phone": "+70878996671"}
0005435213708	D9B27B	0266 320551	EVGENIY SOKOLOV	{"email": "evgeniy.sokolov.121973@postgrespro.ru", "phone": "+70619767164"}
0005435213709	29E59E	2739 518443	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana-23021969@postgrespro.ru", "phone": "+70156594943"}
0005435213710	FB3901	6022 324896	LIDIYA FEDOROVA	{"email": "fedorova.lidiya_101965@postgrespro.ru", "phone": "+70415634268"}
0005435213711	0FD55F	2326 867528	TATYANA KUZMINA	{"email": "kuzmina_t-01061964@postgrespro.ru", "phone": "+70682657417"}
0005435213712	687AA3	7330 512385	EKATERINA BOGDANOVA	{"phone": "+70919152601"}
0005435213713	77DA6A	1419 369818	LILIYA NAUMOVA	{"email": "naumova-l-04081979@postgrespro.ru", "phone": "+70651492380"}
0005435213834	84B7B6	9943 444386	DMITRIY ALEKSANDROV	{"phone": "+70263037950"}
0005435213714	F898CB	5573 817629	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a-041964@postgrespro.ru", "phone": "+70642274365"}
0005435213715	BF29A6	0736 303608	ANNA POPOVA	{"email": "apopova_23061972@postgrespro.ru", "phone": "+70161778718"}
0005435213716	FFCAC1	0473 663613	ALEKSEY FILIPPOV	{"phone": "+70515953201"}
0005435213717	70149A	2365 945507	MARIYA SAVELEVA	{"phone": "+70897269283"}
0005435213718	91B3AB	2325 193418	NIKITA IVANOV	{"phone": "+70500600358"}
0005435213719	4CB9A5	8336 269630	ALLA SAVELEVA	{"email": "savelevaalla.1959@postgrespro.ru", "phone": "+70162949100"}
0005435213720	4CB9A5	6858 057882	OLEG FOMIN	{"email": "ofomin_081972@postgrespro.ru", "phone": "+70993126416"}
0005435213721	987ED8	5726 431254	KARINA ISAEVA	{"email": "karinaisaeva1971@postgrespro.ru", "phone": "+70592151618"}
0005435213722	987ED8	0861 423055	VLADIMIR KOZLOV	{"phone": "+70737503051"}
0005435213723	8074E1	1753 999795	ILYA IVANOV	{"email": "ivanov.ilya_1981@postgrespro.ru", "phone": "+70747491459"}
0005435213724	8074E1	6111 408162	DMITRIY FOMIN	{"phone": "+70855581833"}
0005435213725	F9B911	8707 665977	NINA CHERNOVA	{"phone": "+70861022258"}
0005435213726	B24554	0119 865519	PRASKOVYA KAZAKOVA	{"phone": "+70844894182"}
0005435213727	B24554	5273 279713	ELENA IVANOVA	{"email": "e_ivanova-11061969@postgrespro.ru", "phone": "+70667667215"}
0005435213728	523417	6666 146453	TAMARA GERASIMOVA	{"email": "tamara.gerasimova.15051963@postgrespro.ru", "phone": "+70663156602"}
0005435213729	523417	6679 131751	YURIY POPOV	{"email": "popov.yuriy_1976@postgrespro.ru", "phone": "+70893786082"}
0005435213730	6007F8	3685 032718	TATYANA DANILOVA	{"phone": "+70806553829"}
0005435213731	6007F8	6874 355102	TAMARA LAZAREVA	{"email": "tamaralazareva-08011970@postgrespro.ru", "phone": "+70450374163"}
0005435213732	6007F8	5827 318498	ALEKSANDR KOZLOV	{"email": "kozlov.a12081975@postgrespro.ru", "phone": "+70661600152"}
0005435213733	74D449	5941 897165	RENAT ZAYCEV	{"email": "renat-zaycev.1973@postgrespro.ru", "phone": "+70879595292"}
0005435213734	74D449	3634 006497	OKSANA SMIRNOVA	{"phone": "+70397640824"}
0005435213735	74D449	4634 453852	OLGA SOROKINA	{"email": "olga.sorokina_18081973@postgrespro.ru", "phone": "+70493752261"}
0005435213736	B5F8A9	0329 466416	NIKOLAY MAKAROV	{"phone": "+70387412045"}
0005435213737	65FB33	9982 529459	GENNADIY MEDVEDEV	{"email": "gennadiy-medvedev.041964@postgrespro.ru", "phone": "+70946835335"}
0005435213738	47DED8	3042 084531	OLEG FROLOV	{"phone": "+70213133046"}
0005435213739	858DE6	0429 900828	ZLATA PETROVA	{"phone": "+70037630220"}
0005435213740	A66F57	9086 716942	OLGA MELNIKOVA	{"email": "melnikova_o.18021972@postgrespro.ru", "phone": "+70364731211"}
0005435213741	4B0C71	0294 770723	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr1969@postgrespro.ru", "phone": "+70871046385"}
0005435213742	CBDE7B	7814 254530	NIKOLAY ILIN	{"phone": "+70336935506"}
0005435213743	0BF4B5	5315 349894	VIKTORIYA GORBUNOVA	{"phone": "+70320787312"}
0005435213744	DFD13A	3510 870907	ALEKSEY POPOV	{"email": "popov-aleksey021979@postgrespro.ru", "phone": "+70675812051"}
0005435213745	75500F	4560 669012	LYUDMILA IVANOVA	{"email": "lyudmila-ivanova.1970@postgrespro.ru", "phone": "+70350015162"}
0005435213746	75500F	3666 747689	NATALYA KOZLOVA	{"phone": "+70394701988"}
0005435213747	2939C6	4668 293672	DMITRIY NIKOLAEV	{"email": "nikolaev-d.20081975@postgrespro.ru", "phone": "+70284043245"}
0005435213748	2939C6	2681 129043	NINA MARTYNOVA	{"email": "martynova-nina.03111970@postgrespro.ru", "phone": "+70645865568"}
0005435213749	FA0EE6	6563 871857	VLADISLAV GAVRILOV	{"phone": "+70404639725"}
0005435213750	29105F	9655 033852	LYUDMILA LAZAREVA	{"email": "lyudmilalazareva.24081969@postgrespro.ru", "phone": "+70727297730"}
0005435213751	80713E	5100 258929	RUFIYA MAKAROVA	{"email": "rufiya_makarova_07091967@postgrespro.ru", "phone": "+70602058487"}
0005435213752	AAF3F2	7693 504860	RAFAIL MIKHAYLOV	{"phone": "+70037355390"}
0005435213753	98B503	4328 939379	DENIS YAKOVLEV	{"phone": "+70045967189"}
0005435213754	8D1CB8	6297 664667	DANIYA LEBEDEVA	{"email": "lebedeva_daniya.111968@postgrespro.ru", "phone": "+70128643392"}
0005435213755	16EE3E	3546 262525	ALEKSANDR BARANOV	{"phone": "+70694320135"}
0005435213756	16EE3E	6967 960525	VIKTORIYA RODIONOVA	{"email": "rodionova.viktoriya-13011969@postgrespro.ru", "phone": "+70498502681"}
0005435213757	FE8D1C	8709 111179	NATALYA MAKAROVA	{"email": "natalya_makarova_15101969@postgrespro.ru", "phone": "+70023377327"}
0005435213758	FE8D1C	1113 185335	OLGA PETROVA	{"email": "petrova_o021975@postgrespro.ru", "phone": "+70985848641"}
0005435213759	39270A	8479 484944	IREK VASILEV	{"phone": "+70243000460"}
0005435213760	030372	7283 071059	IVAN ANDREEV	{"email": "i_andreev1971@postgrespro.ru", "phone": "+70483342802"}
0005435213761	5D8423	2271 847483	MIKHAIL IVANOV	{"email": "m-ivanov_04061966@postgrespro.ru", "phone": "+70543139525"}
0005435213762	5D8423	3369 338968	ARTEM YAKOVLEV	{"phone": "+70101615564"}
0005435213763	63CB3C	0273 136592	MIKHAIL VOLKOV	{"email": "volkov_mikhail.111974@postgrespro.ru", "phone": "+70909807555"}
0005435213764	7C2B32	9085 386444	OLGA SIDOROVA	{"email": "sidorovao-24101978@postgrespro.ru", "phone": "+70723662498"}
0005435213765	C4E1C9	9761 822334	ANASTASIYA IVANOVA	{"phone": "+70793183510"}
0005435213766	63B2FE	1891 208134	YULIYA ANTONOVA	{"email": "antonova-y-021966@postgrespro.ru", "phone": "+70804457453"}
0005435213767	45724B	2151 724698	RAMIL STEPANOV	{"phone": "+70645346748"}
0005435213768	08FE44	3703 849341	SVETLANA IVANOVA	{"phone": "+70350204259"}
0005435213769	5C25D4	4408 291574	MARGARITA KOZLOVA	{"phone": "+70967672470"}
0005435213770	4FA365	4724 566820	VERONIKA SMIRNOVA	{"email": "smirnova_veronika_20101971@postgrespro.ru", "phone": "+70622947941"}
0005435213771	4FA365	5755 425845	TIMUR ALEKSEEV	{"phone": "+70398696971"}
0005435213772	4FA365	7916 874174	VLADIMIR KUZMIN	{"phone": "+70782284927"}
0005435213773	4FA365	8929 800399	ILGIZ SCHERBAKOV	{"phone": "+70100039058"}
0005435213774	63404D	4069 138324	RENATA BELOVA	{"email": "belova-renata1979@postgrespro.ru", "phone": "+70563963531"}
0005435213775	A05A73	2878 440690	ALEKSEY EGOROV	{"email": "egorov-aleksey_1963@postgrespro.ru", "phone": "+70832355760"}
0005435213776	A05A73	0845 777288	DMITRIY KUZMIN	{"phone": "+70371779011"}
0005435213777	A3BFB3	2094 646101	VADIM MAKSIMOV	{"phone": "+70110289524"}
0005435213778	A3BFB3	8850 822918	NIKITA STEPANOV	{"email": "nikita.stepanov101967@postgrespro.ru", "phone": "+70474593755"}
0005435213779	F8EA62	3726 259269	PETR GAVRILOV	{"phone": "+70969733827"}
0005435213780	B58EDA	7563 144376	VADIM MELNIKOV	{"email": "melnikov-vadim15041961@postgrespro.ru", "phone": "+70210874935"}
0005435213781	7B92F2	4486 926684	NINA ZOTOVA	{"email": "nina.zotova_091969@postgrespro.ru", "phone": "+70123091411"}
0005435213782	2341F4	6853 845742	VASILIY MIKHAYLOV	{"phone": "+70084862388"}
0005435213783	2341F4	3736 786119	VALENTINA NAZAROVA	{"email": "nazarovav1970@postgrespro.ru", "phone": "+70685396119"}
0005435213784	929113	1670 501460	VITALIY KUZMIN	{"email": "vitaliy-kuzmin_021989@postgrespro.ru", "phone": "+70887540526"}
0005435213785	929113	8612 713853	RAISA OVCHINNIKOVA	{"email": "ovchinnikova-raisa.071974@postgrespro.ru", "phone": "+70705757556"}
0005435213786	3081AC	3181 690636	SVETLANA NIKOLAEVA	{"phone": "+70243080105"}
0005435213787	17DCD4	9958 201059	OLGA VLASOVA	{"phone": "+70629164042"}
0005435213788	DE3569	8560 489497	VLADIMIR VOROBEV	{"email": "vorobev-v.111973@postgrespro.ru", "phone": "+70155530737"}
0005435213789	DE3569	6927 898202	VIKTOR SERGEEV	{"email": "v_sergeev09011973@postgrespro.ru", "phone": "+70479663375"}
0005435213790	B9B29A	6937 570231	LARISA BARANOVA	{"email": "baranova.l25021962@postgrespro.ru", "phone": "+70980819182"}
0005435213791	24E6C9	9250 428894	OLEG FEDOTOV	{"phone": "+70620301616"}
0005435213792	A19735	7043 103973	VLADISLAV BORISOV	{"phone": "+70671552774"}
0005435213793	A19735	6057 595672	MARIYA SERGEEVA	{"phone": "+70700013476"}
0005435213794	0E89B8	7297 326394	ANASTASIYA BORISOVA	{"email": "borisova_a-1969@postgrespro.ru", "phone": "+70400260457"}
0005435213795	0E89B8	4791 856393	ALEKSANDR CHERNOV	{"email": "a.chernov-101964@postgrespro.ru", "phone": "+70256568441"}
0005435213796	0E89B8	1791 099816	NAILYA KULIKOVA	{"phone": "+70497857665"}
0005435213797	DB9240	2044 033817	VITALIY ILIN	{"phone": "+70437148288"}
0005435213798	DB9240	7470 186331	NATALIYA LUKYANOVA	{"email": "lukyanova-n1968@postgrespro.ru", "phone": "+70574632452"}
0005435213799	50AE64	8731 282614	VLADIMIR KOROLEV	{"email": "v.korolev_011961@postgrespro.ru", "phone": "+70072103395"}
0005435213800	50AE64	1131 946625	IVAN FEDOROV	{"email": "fedorov-i_1972@postgrespro.ru", "phone": "+70721746203"}
0005435213801	6B6B4D	8189 328545	YULIYA ALEKSEEVA	{"email": "y-alekseeva.28051976@postgrespro.ru", "phone": "+70454708787"}
0005435213802	6B6B4D	1098 822115	VLADIMIR KOROLEV	{"phone": "+70858703856"}
0005435213803	EE1282	1151 960873	TIMOFEY VOLKOV	{"email": "timofeyvolkov1980@postgrespro.ru", "phone": "+70353442401"}
0005435213804	EE1282	3365 373712	SVETLANA PETROVA	{"phone": "+70698554188"}
0005435213805	7F2C51	1271 527720	GALINA YUDINA	{"email": "yudinag-23111968@postgrespro.ru", "phone": "+70012877141"}
0005435213806	371549	9483 898316	DMITRIY PETROV	{"email": "petrovdmitriy1968@postgrespro.ru", "phone": "+70465990818"}
0005435213807	371549	5844 369423	ALEKSANDRA ORLOVA	{"email": "a.orlova_1964@postgrespro.ru", "phone": "+70242721531"}
0005435213808	3857AD	5033 593142	DMITRIY NIKITIN	{"email": "dmitriy_nikitin-091970@postgrespro.ru", "phone": "+70285734219"}
0005435213809	01CFA9	8713 869112	ANDREY SOROKIN	{"phone": "+70061800193"}
0005435213810	ED6CE3	6338 816035	NATALYA EFREMOVA	{"phone": "+70214596164"}
0005435213811	77F1E6	4824 630648	GALINA KAZAKOVA	{"phone": "+70092431905"}
0005435213812	77F1E6	3660 417007	OKSANA ANTONOVA	{"email": "oksana.antonova-30121964@postgrespro.ru", "phone": "+70311152073"}
0005435213813	0C8726	9610 748037	ALLA ABRAMOVA	{"phone": "+70334290449"}
0005435213814	EA86C3	2163 078863	VALENTINA IVANOVA	{"phone": "+70588837970"}
0005435213815	DC40C2	3447 623699	EVGENIY KAZAKOV	{"email": "kazakov.e061974@postgrespro.ru", "phone": "+70730167194"}
0005435213816	DC40C2	8618 173251	ELENA FEDOROVA	{"email": "elenafedorova01071972@postgrespro.ru", "phone": "+70011220737"}
0005435213817	A15EB4	9359 983656	LYUDMILA POPOVA	{"email": "lyudmila.popova15101976@postgrespro.ru", "phone": "+70633052721"}
0005435213818	A15EB4	0652 452851	YURIY KUZNECOV	{"phone": "+70594838297"}
0005435213819	2DB661	7198 525181	SVETLANA FOMINA	{"phone": "+70246390880"}
0005435213820	377B30	6718 347817	ANDREY MEDVEDEV	{"phone": "+70440161027"}
0005435213821	C65D6D	2655 118175	SVETLANA VOLKOVA	{"phone": "+70052988656"}
0005435213822	622BEB	3763 096451	MARINA MOROZOVA	{"email": "morozova-marina-1965@postgrespro.ru", "phone": "+70375810538"}
0005435213823	FE423B	2135 521027	SOFYA PETROVA	{"email": "sofya_petrova_15111971@postgrespro.ru", "phone": "+70418382489"}
0005435213824	FE423B	0993 857520	DMITRIY SIDOROV	{"phone": "+70480120899"}
0005435213825	C98B6C	0972 481374	YURIY NOVIKOV	{"phone": "+70158940731"}
0005435213826	25B76A	8100 647056	TATYANA LEBEDEVA	{"phone": "+70466797605"}
0005435213827	25B76A	4701 207140	MIKHAIL ABRAMOV	{"email": "abramovm.121970@postgrespro.ru", "phone": "+70765662468"}
0005435213828	19C0E3	0150 257188	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov-1967@postgrespro.ru", "phone": "+70053526117"}
0005435213829	E3C946	5081 267941	MAKSIM KUZNECOV	{"phone": "+70791105938"}
0005435213830	241EE1	8783 773105	EKATERINA RYABOVA	{"email": "ryabova.e.13041955@postgrespro.ru", "phone": "+70925299423"}
0005435213831	241EE1	2914 706551	ROMAN PAVLOV	{"email": "roman_pavlov04111971@postgrespro.ru", "phone": "+70176253173"}
0005435213832	A86071	1746 142560	ELMIRA KULIKOVA	{"phone": "+70679188013"}
0005435213833	DD1696	9065 084728	MARAT KUZNECOV	{"phone": "+70857722373"}
0005435213835	51EE54	4257 843921	NADEZHDA BELOVA	{"email": "belova_nadezhda_051983@postgrespro.ru", "phone": "+70531746828"}
0005435213836	4EA794	6242 935074	VIKTOR MIKHAYLOV	{"phone": "+70069833518"}
0005435213837	4EA794	0957 774128	ALEKSEY STEPANOV	{"phone": "+70361323830"}
0005435213838	6C7DA9	9312 049484	TIMUR MEDVEDEV	{"email": "timur.medvedev101979@postgrespro.ru", "phone": "+70465462138"}
0005435213839	67EBAF	4956 731068	LYUDMILA VLASOVA	{"email": "lyudmila-vlasova27041969@postgrespro.ru", "phone": "+70812632223"}
0005435213840	958F22	8795 606668	YURIY ABRAMOV	{"email": "abramov.y.081974@postgrespro.ru", "phone": "+70882804690"}
0005435213841	E37BFE	4553 663349	ANATOLIY KRASNOV	{"email": "anatoliykrasnov-1968@postgrespro.ru", "phone": "+70563537372"}
0005435213842	14C20F	6153 441179	EVGENIYA KOZLOVA	{"email": "evgeniyakozlova.22061977@postgrespro.ru", "phone": "+70873579722"}
0005435213843	2092E3	2408 855710	NINA BORISOVA	{"email": "nina-borisova041967@postgrespro.ru", "phone": "+70761588846"}
0005435213844	4084D9	7282 737472	MARIYA VLASOVA	{"email": "vlasova-mariya-1977@postgrespro.ru", "phone": "+70852078662"}
0005435213845	5C3EFE	2210 788419	FEDOR MIRONOV	{"phone": "+70063185892"}
0005435213846	2D10FA	5928 073830	ALENA NESTEROVA	{"email": "nesterova_a_16081972@postgrespro.ru", "phone": "+70579543202"}
0005435213847	2D10FA	7814 448591	ELENA NESTEROVA	{"email": "nesterova-elena10051969@postgrespro.ru", "phone": "+70542944826"}
0005435213848	62A07B	0140 073881	LARISA MASLOVA	{"email": "maslova_larisa-29061978@postgrespro.ru", "phone": "+70488068400"}
0005435213849	0CC7F3	1371 438415	MARIYA ZAKHAROVA	{"email": "mariyazakharova-1990@postgrespro.ru", "phone": "+70651211907"}
0005435213850	3ACC21	1991 932939	ALEKSEY DMITRIEV	{"email": "dmitrievaleksey_15121970@postgrespro.ru", "phone": "+70911682435"}
0005435213851	462AA1	9117 717526	SVETLANA AFANASEVA	{"phone": "+70632155991"}
0005435213852	0C826A	9565 169078	ALEKSEY EGOROV	{"phone": "+70966430759"}
0005435213853	9E3319	5049 605535	YULIYA LUKYANOVA	{"phone": "+70871528355"}
0005435213854	B33942	0965 510129	ANNA MAKAROVA	{"phone": "+70591493843"}
0005435213855	B33942	7422 712898	LEONID RODIONOV	{"email": "leonid-rodionov_071964@postgrespro.ru", "phone": "+70750597706"}
0005435213856	559EF2	0473 115032	LILIYA VASILEVA	{"phone": "+70845703344"}
0005435213857	559EF2	6269 697796	ZOYA BELOVA	{"email": "zbelova-121977@postgrespro.ru", "phone": "+70590689321"}
0005435213858	8D1219	1309 286121	VALENTINA EFREMOVA	{"phone": "+70412151858"}
0005435213859	8D1219	2864 110312	NATALYA ALEKSANDROVA	{"email": "natalya-aleksandrova.1971@postgrespro.ru", "phone": "+70880199869"}
0005435213860	4DB035	4459 751487	EVGENIY SCHERBAKOV	{"phone": "+70600030196"}
0005435213861	90A7DD	7845 205794	ANDREY NAZAROV	{"phone": "+70032878539"}
0005435213862	90A7DD	4197 743789	ELENA TIKHONOVA	{"email": "tikhonova.elena_26051976@postgrespro.ru", "phone": "+70603184898"}
0005435213863	90A7DD	7399 301360	ALEKSANDR STEPANOV	{"phone": "+70960401514"}
0005435213864	89E992	7519 604487	NINA VOLKOVA	{"email": "nina_volkova_11081967@postgrespro.ru", "phone": "+70806385165"}
0005435213865	62DE75	8617 047641	VLADIMIR POPOV	{"email": "vladimir_popov-02081973@postgrespro.ru", "phone": "+70406779611"}
0005435213866	FF351F	4114 632295	NINA VOLKOVA	{"phone": "+70882779176"}
0005435213867	FF351F	9954 103173	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov-121971@postgrespro.ru", "phone": "+70273686397"}
0005435213868	12E99B	2721 890649	GRIGORIY EGOROV	{"phone": "+70111835433"}
0005435213869	12E99B	8734 879595	IVAN ZHURAVLEV	{"email": "ivanzhuravlev.031969@postgrespro.ru", "phone": "+70051617088"}
0005435213870	12E99B	0137 047304	ANDREY FEDOROV	{"phone": "+70229357707"}
0005435213871	A31797	0707 480131	ALEKSANDRA FEDOROVA	{"email": "fedorova.a111969@postgrespro.ru", "phone": "+70359615613"}
0005435213872	A31797	3424 782212	KLAVDIYA POTAPOVA	{"email": "potapova.k_011981@postgrespro.ru", "phone": "+70847471855"}
0005435213873	F2D6A6	4484 246386	VERA IVANOVA	{"phone": "+70223743450"}
0005435213874	4C76EC	4738 732590	ANASTASIYA POPOVA	{"email": "a-popova1969@postgrespro.ru", "phone": "+70483593886"}
0005435213875	4C76EC	4846 429671	MARIYA VASILEVA	{"email": "vasilevam_03101984@postgrespro.ru", "phone": "+70162399612"}
0005435213876	775A04	4603 438928	NATALYA ANISIMOVA	{"phone": "+70962817325"}
0005435213877	4FD10B	7589 149205	ALEKSANDR FOMIN	{"email": "aleksandr-fomin1977@postgrespro.ru", "phone": "+70271159296"}
0005435213878	8A7439	2844 066441	ALEKSEY KULIKOV	{"phone": "+70787926411"}
0005435213879	8A7439	6287 573669	VALENTINA NIKITINA	{"phone": "+70387051149"}
0005435213880	0943E0	0983 334224	VALENTINA FROLOVA	{"phone": "+70878501432"}
0005435213881	0943E0	1703 575753	ALEKSEY RODIONOV	{"email": "rodionov.a.051977@postgrespro.ru", "phone": "+70329731373"}
0005435213882	0943E0	3220 405823	VADIM MAKSIMOV	{"phone": "+70072605531"}
0005435213883	30CA45	2102 037134	ALEKSEY SIDOROV	{"phone": "+70932425165"}
0005435213884	EB77FE	3839 087687	ELENA FILIPPOVA	{"email": "filippovaelena071971@postgrespro.ru", "phone": "+70913258029"}
0005435213885	A39A89	7646 203271	ELENA ALEKSEEVA	{"phone": "+70587663631"}
0005435213886	B70891	3811 427587	VIKTOR MATVEEV	{"phone": "+70286797694"}
0005435213887	B52121	2643 970341	VITALIY DENISOV	{"email": "vitaliy_denisov_03061969@postgrespro.ru", "phone": "+70361615537"}
0005435213888	B52121	4066 697747	MARINA ZHUKOVA	{"email": "zhukova-m-08051965@postgrespro.ru", "phone": "+70976198016"}
0005435213889	9077B3	1863 458362	ARTEM FEDOTOV	{"email": "a.fedotov.071982@postgrespro.ru", "phone": "+70196033422"}
0005435213890	6E0CEE	0634 847641	GALINA MAKSIMOVA	{"phone": "+70446181731"}
0005435213891	641567	5722 215118	TATYANA GUSEVA	{"phone": "+70194712321"}
0005435213892	3B700D	5268 854026	VALENTINA IVANOVA	{"phone": "+70751619285"}
0005435213893	20B4B9	3135 881703	GRIGORIY MELNIKOV	{"phone": "+70561439753"}
0005435213894	135A2D	3652 202748	KLAVDIYA MAKAROVA	{"phone": "+70633209776"}
0005435213895	C90E2B	2895 450263	PETR ZHURAVLEV	{"phone": "+70929042172"}
0005435213896	DC7CFA	3116 562597	EVGENIY ISAEV	{"email": "evgeniy_isaev031968@postgrespro.ru", "phone": "+70241088973"}
0005435213897	19F4BC	6165 273756	PAVEL BELOV	{"email": "pavel.belov_101963@postgrespro.ru", "phone": "+70142292919"}
0005435213898	52A2DA	8737 801470	SERGEY KRASNOV	{"email": "s.krasnov-15121974@postgrespro.ru", "phone": "+70811693669"}
0005435213899	05C8CD	8891 551309	ARINA SERGEEVA	{"phone": "+70932179086"}
0005435213900	05C8CD	4132 915848	IRINA KOROLEVA	{"email": "koroleva_i.021966@postgrespro.ru", "phone": "+70213349093"}
0005435213901	668CAF	7566 015131	ALEKSANDR TARASOV	{"email": "aleksandr_tarasov121960@postgrespro.ru", "phone": "+70542098549"}
0005435213902	B30B4D	3272 337601	TIMOFEY IVANOV	{"phone": "+70922601403"}
0005435213903	90E482	4362 933081	SERGEY BORISOV	{"email": "borisovsergey-031971@postgrespro.ru", "phone": "+70430485366"}
0005435213904	52D0FF	9829 643393	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova07051969@postgrespro.ru", "phone": "+70655153289"}
0005435213905	B5D025	6857 375231	EKATERINA SMIRNOVA	{"email": "esmirnova-011975@postgrespro.ru", "phone": "+70429358591"}
0005435213906	74BCA2	5507 850192	NIKOLAY TIMOFEEV	{"email": "timofeevn.041982@postgrespro.ru", "phone": "+70862946533"}
0005435213907	887B75	4340 107118	VENERA ISAEVA	{"phone": "+70568031509"}
0005435213908	8FBB83	7660 740405	KLAVDIYA LEBEDEVA	{"email": "k-lebedeva_1967@postgrespro.ru", "phone": "+70894234718"}
0005435213909	8FBB83	2804 039179	NADEZHDA SOLOVEVA	{"phone": "+70766334275"}
0005435213910	982F95	8428 954879	ANATOLIY VOLKOV	{"email": "anatoliy_volkov.1965@postgrespro.ru", "phone": "+70734235497"}
0005435213911	31FAB6	2197 842897	YULIYA NESTEROVA	{"phone": "+70646512008"}
0005435213912	31FAB6	9753 520437	DENIS NOVIKOV	{"email": "denis-novikov.26011973@postgrespro.ru", "phone": "+70679921947"}
0005435213913	5A7301	8787 888320	POLINA DMITRIEVA	{"email": "dmitrieva-polina.1972@postgrespro.ru", "phone": "+70882798749"}
0005435213914	5A7301	2166 051256	NAZAR AFANASEV	{"phone": "+70076777685"}
0005435213915	5A7301	9147 712198	SERGEY KUZMIN	{"email": "sergey-kuzmin.081965@postgrespro.ru", "phone": "+70399771471"}
0005435213916	DAC907	5684 907673	LYUBOV SOROKINA	{"email": "lyubov.sorokina-1968@postgrespro.ru", "phone": "+70383931800"}
0005435213917	01B97B	9822 973556	DARYA EFREMOVA	{"phone": "+70056538718"}
0005435213918	B82DFD	9290 449401	VIKTOR NIKITIN	{"email": "nikitin_viktor_1977@postgrespro.ru", "phone": "+70435651355"}
0005435213919	E524F1	0699 134263	VLADIMIR PETROV	{"phone": "+70750486970"}
0005435213920	DB837C	5198 281224	RINAT ISAEV	{"email": "isaev.rinat.1974@postgrespro.ru", "phone": "+70321638325"}
0005435213921	ECFEAE	5669 467204	NINA NIKITINA	{"phone": "+70741842038"}
0005435213922	D25287	5536 272133	ANNA KOROLEVA	{"email": "annakoroleva_19121977@postgrespro.ru", "phone": "+70316085490"}
0005435213923	D25287	0177 768158	VLADIMIR YAKOVLEV	{"phone": "+70769045906"}
0005435213924	8CAD08	2046 540593	VASILIY IVANOV	{"email": "ivanov.vasiliy_29121960@postgrespro.ru", "phone": "+70527280892"}
0005435213925	8CAD08	4505 195702	VALERIY ALEKSANDROV	{"email": "aleksandrov_v081973@postgrespro.ru", "phone": "+70598698724"}
0005435213926	ECCA4B	5903 423772	NINA PAVLOVA	{"email": "n.pavlova_071972@postgrespro.ru", "phone": "+70219916135"}
0005435213927	ECCA4B	4937 476406	ARTEM FEDOROV	{"email": "fedorova071976@postgrespro.ru", "phone": "+70028384815"}
0005435213928	B42224	1609 597938	TATYANA MATVEEVA	{"phone": "+70605106244"}
0005435213929	C2067E	2585 154621	NIKOLAY SEMENOV	{"email": "semenovn.091974@postgrespro.ru", "phone": "+70674923374"}
0005435213930	595C2D	4793 656213	GENNADIY SOROKIN	{"email": "sorokin-gennadiy20101979@postgrespro.ru", "phone": "+70343988325"}
0005435213931	5ADEE9	7966 976139	DMITRIY STEPANOV	{"phone": "+70448645868"}
0005435213932	6639EC	9593 235945	DIANA SMIRNOVA	{"email": "smirnova_diana_05051968@postgrespro.ru", "phone": "+70737104205"}
0005435213933	6639EC	2470 854707	VITALIY GORBUNOV	{"phone": "+70890723389"}
0005435213934	563F51	7787 994000	ALEKSEY GUSEV	{"email": "gusevaleksey08051966@postgrespro.ru", "phone": "+70779955613"}
0005435213935	DC4B03	1801 979574	ANDREY KISELEV	{"email": "kiselev_a.091958@postgrespro.ru", "phone": "+70380902649"}
0005435213936	FA425B	2807 095288	GALINA VLASOVA	{"email": "vlasova.galina.1963@postgrespro.ru", "phone": "+70313882498"}
0005435213937	A2D0B0	6413 334641	VLADIMIR NOVIKOV	{"email": "vladimirnovikov.121956@postgrespro.ru", "phone": "+70151420021"}
0005435213938	A2D0B0	0324 797999	NADEZHDA NIKITINA	{"email": "nadezhdanikitina-24111969@postgrespro.ru", "phone": "+70178142080"}
0005435213939	5E0EFD	6438 750496	MARINA KUDRYASHOVA	{"email": "kudryashova_marina_1968@postgrespro.ru", "phone": "+70026821182"}
0005435213940	80F23E	0309 477638	ANATOLIY VASILEV	{"phone": "+70573260624"}
0005435213941	D8A0D9	6652 007428	ELENA AFANASEVA	{"phone": "+70982859069"}
0005435213942	D8A0D9	2949 558837	NADEZHDA VOLKOVA	{"phone": "+70401965093"}
0005435213943	BDFF22	8719 044991	IRINA DENISOVA	{"phone": "+70012480744"}
0005435213944	BDFF22	4553 044765	TAMARA BOGDANOVA	{"email": "bogdanova-tamara.1970@postgrespro.ru", "phone": "+70372711416"}
0005435213945	2BF96C	4690 990012	YULIYA AFANASEVA	{"phone": "+70822738845"}
0005435213946	2BF96C	2409 227683	ALEKSANDR DMITRIEV	{"phone": "+70929872680"}
0005435213947	2BF96C	9652 905606	KLARA ROMANOVA	{"email": "k.romanova1971@postgrespro.ru", "phone": "+70438449190"}
0005435213948	E7CBC6	8298 556080	MAKSIM POPOV	{"phone": "+70567436545"}
0005435213949	E7CBC6	0261 358876	ANNA ARKHIPOVA	{"phone": "+70453767553"}
0005435213950	A523F0	0417 799426	NATALIYA IVANOVA	{"email": "nataliya-ivanova_1983@postgrespro.ru", "phone": "+70891422837"}
0005435213951	5D8F93	4790 994324	VLADIMIR DENISOV	{"email": "v.denisov_13011982@postgrespro.ru", "phone": "+70908283515"}
0005435213952	2BA6CD	3281 400795	TATYANA NESTEROVA	{"phone": "+70358947461"}
0005435213953	A6FB52	5185 218437	NATALYA MOROZOVA	{"email": "natalya.morozova-1962@postgrespro.ru", "phone": "+70784079585"}
0005435213954	9EB0FA	6621 073787	VIKTOR BORISOV	{"phone": "+70888802061"}
0005435213955	9EB0FA	5623 736457	DENIS TARASOV	{"email": "d_tarasov-18051974@postgrespro.ru", "phone": "+70457613275"}
0005435213956	80DF74	2856 540318	MARIYA MEDVEDEVA	{"phone": "+70688591598"}
0005435213957	E44351	9039 124021	GALINA ANTONOVA	{"email": "g-antonova_1967@postgrespro.ru", "phone": "+70481674938"}
0005435213958	E44351	1475 004212	NIKOLAY IVANOV	{"email": "ivanov.n_021974@postgrespro.ru", "phone": "+70569344214"}
0005435213959	DFBE8C	4424 059315	ALEKSANDR GUSEV	{"phone": "+70154611206"}
0005435213960	D6A8F1	3619 305687	ELMIRA MOISEEVA	{"email": "moiseevaelmira051966@postgrespro.ru", "phone": "+70477616873"}
0005435213961	3F4DE5	2986 442400	ARTEM FROLOV	{"email": "frolov_artem081975@postgrespro.ru", "phone": "+70789754901"}
0005435213962	3F4DE5	6795 574569	NATALIYA POPOVA	{"email": "popova-nataliya_111967@postgrespro.ru", "phone": "+70216342539"}
0005435213963	30A873	8290 087027	LYUDMILA SCHERBAKOVA	{"email": "scherbakova_lyudmila31121971@postgrespro.ru", "phone": "+70485230108"}
0005435213964	0DFE65	4850 907560	ANNA STEPANOVA	{"phone": "+70434546327"}
0005435213965	2A26B6	4246 393082	NADEZHDA PAVLOVA	{"email": "pavlova-n_011975@postgrespro.ru", "phone": "+70134836410"}
0005435213966	6B1361	8016 086947	SEMEN KULIKOV	{"phone": "+70175145423"}
0005435213967	B17CED	6253 084614	IVAN GERASIMOV	{"phone": "+70699010246"}
0005435213968	2DAF20	1633 293962	MIKHAIL DAVYDOV	{"email": "davydovmikhail.06041963@postgrespro.ru", "phone": "+70732776192"}
0005435213969	2DAF20	9542 315999	TATYANA ALEKSEEVA	{"phone": "+70769392294"}
0005435213970	2DAF20	3988 065470	NATALYA BELYAEVA	{"email": "belyaeva.n-1976@postgrespro.ru", "phone": "+70133532916"}
0005435213971	393497	3914 175668	EGOR MAKAROV	{"phone": "+70782793547"}
0005435213972	EAC83E	7523 988495	ALEKSANDR KAZAKOV	{"email": "kazakovaleksandr-1967@postgrespro.ru", "phone": "+70922422395"}
0005435213973	EAC83E	2525 763500	EVGENIY MAKAROV	{"phone": "+70588252402"}
0005435213974	3B86EA	2031 569827	VLADIMIR KULIKOV	{"phone": "+70215656509"}
0005435213975	3B86EA	3089 158320	EKATERINA ZAKHAROVA	{"email": "ekaterina_zakharova-051969@postgrespro.ru", "phone": "+70266396312"}
0005435213976	40D834	8704 967257	EKATERINA STEPANOVA	{"phone": "+70017378202"}
0005435213977	9F0F73	0756 043526	YULIYA SMIRNOVA	{"phone": "+70568330873"}
0005435213978	480167	4304 643113	VITALIY MELNIKOV	{"email": "melnikov_vitaliy-1960@postgrespro.ru", "phone": "+70035314248"}
0005435213979	ADE4EA	4686 045570	MIKHAIL POPOV	{"phone": "+70212053661"}
0005435213980	4DB448	3821 967476	OLGA SAVELEVA	{"phone": "+70432956590"}
0005435213981	1C9A80	9899 174168	ALEKSANDR SMIRNOV	{"email": "smirnov_a_1973@postgrespro.ru", "phone": "+70532939183"}
0005435213982	BCCFF7	1080 544149	ALEKSANDR SHEVCHENKO	{"phone": "+70813641726"}
0005435213983	219DE0	5350 159364	ANNA SOLOVEVA	{"email": "anna_soloveva-1970@postgrespro.ru", "phone": "+70160656801"}
0005435213984	D5D4E0	5358 096059	ALEKSEY ZAKHAROV	{"email": "zakharov-a.04121963@postgrespro.ru", "phone": "+70573411464"}
0005435213985	4E15D9	1492 482562	ANDREY BARANOV	{"email": "a_baranov_26051977@postgrespro.ru", "phone": "+70947382763"}
0005435213986	816E91	1264 389063	NADEZHDA KOZLOVA	{"phone": "+70850120982"}
0005435213987	AF4192	4018 186837	KRISTINA PAVLOVA	{"phone": "+70482136560"}
0005435213988	AF4192	1967 289955	DMITRIY FEDOROV	{"email": "fedorov-d_09111973@postgrespro.ru", "phone": "+70410238189"}
0005435213989	40E4EF	2175 433036	GALINA TIMOFEEVA	{"email": "timofeevagalina.1977@postgrespro.ru", "phone": "+70410910196"}
0005435213990	A6418E	4532 265059	SERGEY KOROLEV	{"email": "korolev_s_21051974@postgrespro.ru", "phone": "+70610483200"}
0005435213991	6882C8	7424 470291	VALENTINA MATVEEVA	{"email": "matveeva.v-031969@postgrespro.ru", "phone": "+70249787005"}
0005435213992	CA725C	8908 497194	SEMEN VASILEV	{"email": "vasilev_semen.1982@postgrespro.ru", "phone": "+70046733149"}
0005435213993	7AF160	0050 219046	SVYATOSLAV TIKHONOV	{"phone": "+70300680390"}
0005435213994	5E2416	2796 787370	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_v1971@postgrespro.ru", "phone": "+70115947310"}
0005435213995	2C73AA	8818 533539	ALEKSANDRA ISAEVA	{"email": "isaeva.aleksandra011967@postgrespro.ru", "phone": "+70693106025"}
0005435213996	5140A9	3444 930088	ANZHELA SMIRNOVA	{"phone": "+70651522488"}
0005435213997	DACB90	3955 539663	MARINA KOVALEVA	{"phone": "+70264264559"}
0005435213998	7C17AE	8887 557151	RAVIL STEPANOV	{"email": "stepanov_r_071970@postgrespro.ru", "phone": "+70494389819"}
0005435213999	333AC6	9528 545761	EVGENIY PAVLOV	{"email": "evgeniy-pavlov.05051972@postgrespro.ru", "phone": "+70252185124"}
0005435214000	333AC6	6599 312690	VLADIMIR AFANASEV	{"email": "afanasev.vladimir09051967@postgrespro.ru", "phone": "+70422463860"}
0005435214001	E24977	7552 472379	DMITRIY KISELEV	{"email": "d.kiselev_1984@postgrespro.ru", "phone": "+70925781450"}
0005435214002	99BD3B	5061 984018	MARINA MEDVEDEVA	{"email": "m_medvedeva-26041960@postgrespro.ru", "phone": "+70824569861"}
0005435214003	53D278	9017 072708	ALINA IVANOVA	{"email": "aivanova-1982@postgrespro.ru", "phone": "+70532698109"}
0005435214004	AF18C8	2017 832964	MARIYA MOROZOVA	{"phone": "+70324330809"}
0005435214005	AF18C8	3760 833627	YULIYA KUZNECOVA	{"phone": "+70738466918"}
0005435214006	3A8FDB	5518 686074	OLGA PAVLOVA	{"email": "pavlova.olga-22101963@postgrespro.ru", "phone": "+70809649548"}
0005435214007	621979	4658 308469	VALENTINA AKIMOVA	{"email": "akimova.valentina061977@postgrespro.ru", "phone": "+70358593134"}
0005435214008	A63441	3483 715825	OKSANA VOROBEVA	{"email": "vorobevao091980@postgrespro.ru", "phone": "+70160476167"}
0005435214009	A63441	4719 990902	ELENA ALEKSEEVA	{"phone": "+70522868542"}
0005435214010	A4724C	1420 638157	EKATERINA SOKOLOVA	{"email": "sokolova_e-041989@postgrespro.ru", "phone": "+70322994791"}
0005435214011	AB829A	9129 147812	ALEKSANDR MOISEEV	{"email": "a_moiseev_1982@postgrespro.ru", "phone": "+70718350092"}
0005435214012	D8119E	8625 706497	ALEKSANDR SERGEEV	{"phone": "+70562573508"}
0005435214013	D8119E	6176 123769	FANIL RODIONOV	{"email": "frodionov1963@postgrespro.ru", "phone": "+70213304719"}
0005435214014	7BA305	1666 292859	ALEKSANDR RODIONOV	{"email": "a_rodionov_03081973@postgrespro.ru", "phone": "+70326055665"}
0005435214015	55B143	3345 518914	ANATOLIY KUDRYASHOV	{"phone": "+70906021447"}
0005435214016	55B143	8656 218249	VLADIMIR SEMENOV	{"email": "semenovvladimir1972@postgrespro.ru", "phone": "+70556615802"}
0005435214017	25CFB0	4566 053621	EVGENIY BELOV	{"email": "e-belov1986@postgrespro.ru", "phone": "+70252404144"}
0005435214018	CABFF1	8494 285472	VIKTOR FOMIN	{"phone": "+70410785474"}
0005435214019	348550	2487 371543	ALEKSEY TARASOV	{"phone": "+70674461843"}
0005435214020	CBF081	4166 111788	SERGEY FEDOROV	{"phone": "+70630941708"}
0005435214021	75E0EB	3458 727154	IRINA MAKAROVA	{"phone": "+70479467553"}
0005435214022	75E0EB	7158 226364	OLGA OSIPOVA	{"email": "osipova-o07051964@postgrespro.ru", "phone": "+70064659090"}
0005435214023	7F45F2	9456 017289	IRINA ORLOVA	{"phone": "+70138578256"}
0005435214024	F9BC45	8770 534139	IRINA KULIKOVA	{"phone": "+70171447817"}
0005435214025	1CFF3E	3267 938360	ANDREY STEPANOV	{"phone": "+70673830975"}
0005435214026	3895CE	2001 140802	MAKSIM FOMIN	{"phone": "+70802923856"}
0005435214027	F80A4C	9075 990697	ALEKSANDR DAVYDOV	{"phone": "+70008372012"}
0005435214028	F80A4C	4170 240935	MARINA KALININA	{"phone": "+70910072864"}
0005435214029	B46F9A	9310 373937	NIKOLAY FROLOV	{"email": "frolovn.15051973@postgrespro.ru", "phone": "+70174571804"}
0005435214030	B46F9A	4185 189133	FEDOR IVANOV	{"phone": "+70925868758"}
0005435214031	E2322B	6362 864207	SERGEY TIKHONOV	{"phone": "+70875684955"}
0005435214032	5CF139	3491 071493	NIKITA ANTONOV	{"phone": "+70273218021"}
0005435214033	5CF139	9100 691589	TATYANA AFANASEVA	{"email": "t_afanaseva_1969@postgrespro.ru", "phone": "+70279074674"}
0005435214034	B92B40	6613 945263	NATALYA FILIPPOVA	{"phone": "+70534746169"}
0005435214035	4A2AAF	8508 429265	MATVEY ROMANOV	{"phone": "+70523856659"}
0005435214036	4A2AAF	2700 514913	SVETLANA FROLOVA	{"phone": "+70887002443"}
0005435214037	E8241C	4886 304248	ELENA DENISOVA	{"phone": "+70555673091"}
0005435214038	E8241C	5713 264644	IGOR FOMIN	{"email": "fomin-i_01021969@postgrespro.ru", "phone": "+70418457164"}
0005435214039	81CD91	4020 558562	NATALYA GUSEVA	{"phone": "+70472473330"}
0005435214040	3EABC7	5411 728438	ALEKSANDRA DANILOVA	{"phone": "+70541069977"}
0005435214041	3EABC7	1598 086204	NIKOLAY ISAEV	{"phone": "+70594626967"}
0005435214042	B057FD	7761 430434	VENIAMIN ZAKHAROV	{"email": "zakharov-veniamin-1971@postgrespro.ru", "phone": "+70311867645"}
0005435214043	EE1B59	0173 587832	NATALYA KOROLEVA	{"email": "natalyakoroleva_1962@postgrespro.ru", "phone": "+70425916075"}
0005435214044	CFEE38	4757 819845	LIDIYA VLASOVA	{"phone": "+70046219753"}
0005435214045	3C964D	4262 416700	ANDREY BELOV	{"email": "a-belov-1976@postgrespro.ru", "phone": "+70298470194"}
0005435214046	DC723D	0040 170797	SVETLANA SMIRNOVA	{"phone": "+70952497547"}
0005435214047	F18C2A	0644 133571	NATALYA KALININA	{"email": "kalininan.121983@postgrespro.ru", "phone": "+70231519497"}
0005435214048	E273B5	8080 282271	MIKHAIL ZAYCEV	{"phone": "+70108875538"}
0005435214049	2FFA3B	6253 571961	ANDREY ANTONOV	{"email": "aantonov-08071979@postgrespro.ru", "phone": "+70398536390"}
0005435214050	282CD8	9244 894622	ALFIYA LAZAREVA	{"phone": "+70212622504"}
0005435214051	BAD01F	5258 031844	DENIS GORBUNOV	{"phone": "+70198180840"}
0005435214052	FE9E6C	8001 629163	LYUDMILA IVANOVA	{"phone": "+70852216910"}
0005435214053	9BDD57	2081 148668	YULIYA GAVRILOVA	{"email": "yuliyagavrilova1976@postgrespro.ru", "phone": "+70423110668"}
0005435214054	9BDD57	5222 406394	GENNADIY IVANOV	{"phone": "+70404551204"}
0005435214055	654788	0455 221714	ALEKSEY KUZNECOV	{"email": "kuznecova-111962@postgrespro.ru", "phone": "+70058819029"}
0005435214056	A41F2C	3002 491753	VALERIY GUSEV	{"email": "gusev-v.10121968@postgrespro.ru", "phone": "+70502142337"}
0005435214057	0324B3	0983 502856	KONSTANTIN KISELEV	{"email": "k-kiselev1964@postgrespro.ru", "phone": "+70451972375"}
0005435214058	0324B3	8748 785273	NADEZHDA SERGEEVA	{"phone": "+70489295578"}
0005435214059	7EFE42	3551 143786	VIKTORIYA EGOROVA	{"email": "v.egorova.11071981@postgrespro.ru", "phone": "+70624060946"}
0005435214060	A836D3	2736 603384	VITALIY IVANOV	{"phone": "+70390985547"}
0005435214061	7FD117	9194 193751	NATALYA VASILEVA	{"email": "vasilevanatalya-10051966@postgrespro.ru", "phone": "+70871210556"}
0005435214062	306894	3811 638177	RAIL TIKHONOV	{"phone": "+70671861963"}
0005435214063	34B91E	7250 487214	DMITRIY FROLOV	{"phone": "+70035722207"}
0005435214064	8F7504	3759 558743	VIKTOR NOVIKOV	{"email": "v.novikov-1963@postgrespro.ru", "phone": "+70822660729"}
0005435214065	40C58C	3439 617143	TATYANA VOLKOVA	{"phone": "+70890179633"}
0005435214066	B2B2C7	0000 792050	VITALIY ANDREEV	{"phone": "+70410552796"}
0005435214067	8F06F5	6309 357265	ANASTASIYA YUDINA	{"email": "anastasiyayudina-13041973@postgrespro.ru", "phone": "+70318012609"}
0005435214068	8F06F5	8335 189227	SERGEY FEDOROV	{"email": "fedorov-s-03081981@postgrespro.ru", "phone": "+70325454843"}
0005435214069	8F06F5	1510 210607	ALEKSANDR TIKHONOV	{"phone": "+70572048017"}
0005435214070	598BDE	1726 006119	NADEZHDA BOGDANOVA	{"phone": "+70189024712"}
0005435214071	0FBB6D	1261 869857	GALINA YAKOVLEVA	{"phone": "+70041914755"}
0005435214072	B14FE5	4108 196554	STEPAN GERASIMOV	{"phone": "+70046359815"}
0005435214073	B14FE5	0454 880023	ARTEM KONOVALOV	{"phone": "+70549696464"}
0005435214074	92FFE7	0505 461367	OLGA NAZAROVA	{"email": "nazarova.o_081969@postgrespro.ru", "phone": "+70146199443"}
0005435214075	4CEDBD	5820 950085	NINA ANTONOVA	{"email": "antonova_nina101971@postgrespro.ru", "phone": "+70408206743"}
0005435214076	0DEC16	1645 348595	LIDIYA BORISOVA	{"email": "borisova-l1970@postgrespro.ru", "phone": "+70033568971"}
0005435214077	0DEC16	3194 632235	VYACHESLAV MIRONOV	{"email": "mironovvyacheslav.081975@postgrespro.ru", "phone": "+70568776282"}
0005435214078	82ABBC	6391 366657	LYUDMILA MEDVEDEVA	{"phone": "+70205950470"}
0005435214079	82ABBC	4009 439925	ELENA ZOTOVA	{"email": "zotova_e_11081965@postgrespro.ru", "phone": "+70076651557"}
0005435214080	1E0438	3021 032036	YURIY ANDREEV	{"email": "andreev-y.12121984@postgrespro.ru", "phone": "+70749750488"}
0005435214081	1E0438	3619 310505	EVGENIYA POPOVA	{"email": "evgeniya-popova.25051970@postgrespro.ru", "phone": "+70085899488"}
0005435214082	BB79C5	3918 925493	NATALIYA MIRONOVA	{"email": "nmironova-111974@postgrespro.ru", "phone": "+70253323120"}
0005435214083	BB79C5	5339 430631	ANATOLIY AFANASEV	{"phone": "+70567540655"}
0005435214084	A26E58	9376 268769	IVAN NIKOLAEV	{"email": "i-nikolaev1982@postgrespro.ru", "phone": "+70045905241"}
0005435214085	FDFC46	9265 903416	LYUDMILA KOZLOVA	{"phone": "+70930427172"}
0005435214086	2DCA19	1886 638294	SVETLANA PETROVA	{"email": "svetlana-petrova-09051982@postgrespro.ru", "phone": "+70063904428"}
0005435214087	2DCA19	7418 968594	ELENA BOGDANOVA	{"email": "elena.bogdanova-1960@postgrespro.ru", "phone": "+70180733405"}
0005435214088	B7A306	7492 448891	ANATOLIY EGOROV	{"email": "anatoliyegorov08031974@postgrespro.ru", "phone": "+70312635421"}
0005435214089	58BDFC	1371 579047	SERGEY GRIGOREV	{"email": "s-grigorev_081981@postgrespro.ru", "phone": "+70357436434"}
0005435214090	58BDFC	8942 115540	ANDREY FROLOV	{"phone": "+70368699203"}
0005435214091	DF8C6E	7168 390993	PETR SOKOLOV	{"phone": "+70810366155"}
0005435214092	A96A20	3739 776853	ANASTASIYA SOROKINA	{"phone": "+70319355756"}
0005435214093	42BC7F	8293 320029	OKSANA KUZMINA	{"phone": "+70001375063"}
0005435214094	B6EC77	5097 677481	NIKOLAY BONDARENKO	{"phone": "+70793800974"}
0005435214095	9E9A9B	6593 376587	MARIYA FROLOVA	{"email": "mariya.frolova_1976@postgrespro.ru", "phone": "+70009070799"}
0005435214096	9E9A9B	9879 724695	MARIYA ROMANOVA	{"email": "romanova.m.23051970@postgrespro.ru", "phone": "+70967454832"}
0005435214097	D4D7A8	3739 883982	EVGENIY MELNIKOV	{"phone": "+70225264514"}
0005435214098	710982	4634 154876	SERGEY SOKOLOV	{"email": "sokolov-s.041972@postgrespro.ru", "phone": "+70405306993"}
0005435214099	7FDCE0	6251 517513	VALERIYA KULIKOVA	{"email": "v-kulikova.1975@postgrespro.ru", "phone": "+70995855544"}
0005435214100	3239DA	4823 395178	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana_101971@postgrespro.ru", "phone": "+70933509667"}
0005435214101	21659C	4546 568288	EVGENIY TIKHONOV	{"email": "tikhonove-12101982@postgrespro.ru", "phone": "+70136562645"}
0005435214102	2AFC8F	3842 955159	ANNA YAKOVLEVA	{"email": "ayakovleva.09121978@postgrespro.ru", "phone": "+70769459815"}
0005435214103	2AFC8F	6809 283666	ELENA ERMAKOVA	{"email": "ermakova_elena.1977@postgrespro.ru", "phone": "+70820622816"}
0005435214104	6A6002	1523 368778	EKATERINA MOISEEVA	{"email": "emoiseeva.26101976@postgrespro.ru", "phone": "+70982713635"}
0005435214105	C4EB9D	1211 439964	ROMAN ZAKHAROV	{"email": "zakharov_roman.061969@postgrespro.ru", "phone": "+70808643256"}
0005435214106	C4EB9D	2115 598723	ALEKSANDRA ZAKHAROVA	{"phone": "+70374118119"}
0005435214107	F7792A	9055 665019	GALINA PETROVA	{"email": "g_petrova-03031971@postgrespro.ru", "phone": "+70917933054"}
0005435214108	7BA48A	6674 766430	DIANA TIKHONOVA	{"email": "tikhonovadiana_1972@postgrespro.ru", "phone": "+70921822587"}
0005435214109	C98312	1635 334079	IVAN SOROKIN	{"phone": "+70353249475"}
0005435214110	C98312	5140 673171	EVGENIY KOROLEV	{"email": "e_korolev-011977@postgrespro.ru", "phone": "+70600373066"}
0005435214111	5BCE2D	9502 226411	ALEKSANDRA BELOVA	{"phone": "+70728348115"}
0005435214112	5BCE2D	5802 860540	OLEG FEDOTOV	{"phone": "+70702756209"}
0005435214113	5BCE2D	8861 516652	VLADIMIR MAKSIMOV	{"email": "v.maksimov-19021978@postgrespro.ru", "phone": "+70150372788"}
0005435214114	5BCE2D	0464 681964	VALERIY BORISOV	{"email": "borisov-valeriy_1966@postgrespro.ru", "phone": "+70156577287"}
0005435214115	310222	3867 938439	ELENA VASILEVA	{"email": "elena-vasileva-1967@postgrespro.ru", "phone": "+70048013225"}
0005435214116	B35EDA	1742 313291	KONSTANTIN SOKOLOV	{"email": "k_sokolov.27091960@postgrespro.ru", "phone": "+70311912588"}
0005435214117	4FF294	1364 723530	RAISA ABRAMOVA	{"email": "r-abramova-1962@postgrespro.ru", "phone": "+70332464588"}
0005435214118	06C36D	3754 344473	ALEKSANDR FOMIN	{"email": "fominaleksandr-1978@postgrespro.ru", "phone": "+70172636029"}
0005435214119	06C36D	4119 410349	MARIYA MAKSIMOVA	{"email": "maksimova_mariya08071976@postgrespro.ru", "phone": "+70380874827"}
0005435214120	106F0D	8481 665696	ARTEM KUZNECOV	{"phone": "+70498786633"}
0005435214121	6D1916	6861 348525	IRINA IVANOVA	{"email": "i.ivanova-25051974@postgrespro.ru", "phone": "+70141333871"}
0005435214122	6D1916	3280 432016	KIRILL ANDREEV	{"email": "andreev_kirill_1965@postgrespro.ru", "phone": "+70519941389"}
0005435214123	7D3359	4821 831108	VALENTINA SAVELEVA	{"email": "valentina_saveleva.29041967@postgrespro.ru", "phone": "+70148915254"}
0005435214124	7D3359	6065 852420	ALEKSANDR FEDOROV	{"email": "aleksandr-fedorov051952@postgrespro.ru", "phone": "+70524804033"}
0005435214125	16546D	3485 990357	ANDREY DAVYDOV	{"phone": "+70965560788"}
0005435214126	16546D	6897 233429	MIKHAIL BARANOV	{"phone": "+70389180848"}
0005435214127	D33EE2	5317 732785	YURIY NIKITIN	{"email": "nikitin.y_111967@postgrespro.ru", "phone": "+70119756098"}
0005435214128	8A74A0	9823 563488	GEORGIY SIDOROV	{"email": "g-sidorov1975@postgrespro.ru", "phone": "+70705426992"}
0005435214129	8A74A0	4819 746152	ALEKSEY SMIRNOV	{"phone": "+70249537344"}
0005435214130	0FF83C	6316 119549	EVGENIYA SERGEEVA	{"email": "sergeeva.evgeniya-16041984@postgrespro.ru", "phone": "+70057563387"}
0005435214192	41F246	2206 326813	NATALYA FEDOROVA	{"phone": "+70271122030"}
0005435214131	59BA32	4278 606788	ANDREY MATVEEV	{"email": "andreymatveev-08061975@postgrespro.ru", "phone": "+70652422655"}
0005435214132	927641	4472 337831	ANASTASIYA ROMANOVA	{"email": "anastasiya.romanova_041973@postgrespro.ru", "phone": "+70704491838"}
0005435214133	927641	2495 395309	VIKTOR NAUMOV	{"email": "naumov.v.011976@postgrespro.ru", "phone": "+70961720049"}
0005435214134	9497B7	7370 473168	NATALYA KULIKOVA	{"email": "kulikova_n111960@postgrespro.ru", "phone": "+70902176967"}
0005435214135	9497B7	8838 987662	OLGA MIRONOVA	{"email": "olga-mironova13111966@postgrespro.ru", "phone": "+70200931199"}
0005435214136	4B0FB4	1020 147048	LIDIYA MAKAROVA	{"email": "makarova-l.051984@postgrespro.ru", "phone": "+70412235088"}
0005435214137	4B0FB4	6336 377572	ZINAIDA DENISOVA	{"email": "denisova_zinaida05061965@postgrespro.ru", "phone": "+70493769378"}
0005435214138	4B0FB4	6817 220513	ALEKSANDR KUZNECOV	{"phone": "+70604335423"}
0005435214139	ADA1E6	8967 165278	VLADISLAV SIDOROV	{"email": "v_sidorov.17021962@postgrespro.ru", "phone": "+70536648788"}
0005435214140	AEBBEE	9426 980345	SERGEY FILIPPOV	{"phone": "+70547524641"}
0005435214141	DDF8B2	7972 436213	VIKTOR ABRAMOV	{"email": "viktor.abramov.021971@postgrespro.ru", "phone": "+70770346860"}
0005435214142	0B7C0E	0283 696358	SERGEY GERASIMOV	{"phone": "+70363889680"}
0005435214143	F15498	5866 351795	ILYA PAVLOV	{"phone": "+70314561976"}
0005435214144	F15498	9435 139746	NAILYA PAVLOVA	{"phone": "+70972422943"}
0005435214145	91CA36	1546 874605	KONSTANTIN DAVYDOV	{"phone": "+70230761083"}
0005435214146	238D91	7944 628924	DMITRIY SEMENOV	{"phone": "+70348924423"}
0005435214147	238D91	2187 573087	ALENA EFIMOVA	{"phone": "+70390928355"}
0005435214148	238D91	2224 052875	ALEKSANDR TIKHONOV	{"phone": "+70060925289"}
0005435214149	5936FF	7671 213278	ALEKSANDR MAKAROV	{"phone": "+70412389478"}
0005435214150	F18CD9	9958 595541	RUSTAM YAKOVLEV	{"email": "r_yakovlev_081974@postgrespro.ru", "phone": "+70752705274"}
0005435214151	AD6742	3934 710045	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-051980@postgrespro.ru", "phone": "+70478040660"}
0005435214152	26C01D	1213 707627	ALEKSANDR ZAYCEV	{"phone": "+70878934773"}
0005435214153	9DF791	9650 647326	ALINA NIKIFOROVA	{"phone": "+70677141777"}
0005435214154	9DF791	7633 023895	OLEG STEPANOV	{"email": "oleg-stepanov.1960@postgrespro.ru", "phone": "+70477871518"}
0005435214155	24EACF	2283 032487	ROZA MAKAROVA	{"email": "makarova-roza_031977@postgrespro.ru", "phone": "+70685124316"}
0005435214156	24EACF	1257 804119	NADEZHDA FOMINA	{"phone": "+70049167536"}
0005435214157	CDDCCB	5903 273098	EVGENIY OSIPOV	{"email": "osipove1985@postgrespro.ru", "phone": "+70066002939"}
0005435214158	CDDCCB	1964 443783	ROMAN SAVELEV	{"phone": "+70057272650"}
0005435214159	8B8530	6305 595143	IRINA VLASOVA	{"email": "ivlasova1972@postgrespro.ru", "phone": "+70020485816"}
0005435214160	8B8530	7769 585307	RASHIT PAVLOV	{"phone": "+70888346992"}
0005435214161	8B8530	3674 852754	ELENA BORISOVA	{"phone": "+70569993484"}
0005435214162	FB9B95	1457 218491	ILGIZ SIDOROV	{"email": "sidorovi-1972@postgrespro.ru", "phone": "+70282080324"}
0005435214163	E70A58	6059 470131	SERGEY ROMANOV	{"phone": "+70057180743"}
0005435214164	E70A58	7492 115125	VIKTOR KUZMIN	{"phone": "+70867311089"}
0005435214165	E70A58	8136 652309	VLADIMIR KUDRYASHOV	{"email": "kudryashovvladimir-28081967@postgrespro.ru", "phone": "+70436655090"}
0005435214166	274523	4866 459060	STANISLAV KUDRYASHOV	{"phone": "+70733246310"}
0005435214167	274523	6123 257449	ALEKSANDR DENISOV	{"email": "aleksandr-denisov-1970@postgrespro.ru", "phone": "+70417527963"}
0005435214168	C1C477	2396 649715	ANASTASIYA BORISOVA	{"email": "borisovaanastasiya.19071965@postgrespro.ru", "phone": "+70118922519"}
0005435214169	AD0BB3	3886 078299	DMITRIY VLASOV	{"phone": "+70582255879"}
0005435214170	04C08D	8239 020661	VIKTOR MOROZOV	{"phone": "+70122040071"}
0005435214171	048172	4720 326181	SERGEY ILIN	{"phone": "+70417087422"}
0005435214172	4F0A63	8240 563232	LIDIYA SMIRNOVA	{"email": "smirnoval_011975@postgrespro.ru", "phone": "+70727103890"}
0005435214173	4F0A63	0745 266179	ALEKSANDR KISELEV	{"email": "akiselev_021971@postgrespro.ru", "phone": "+70946716515"}
0005435214174	FFE6C7	4427 748135	LIDIYA MAKAROVA	{"email": "lmakarova08111965@postgrespro.ru", "phone": "+70961458355"}
0005435214175	FFE6C7	8119 894659	SERGEY SHEVCHENKO	{"phone": "+70827863491"}
0005435214176	E17D7D	2166 381551	SVETLANA MAKAROVA	{"email": "makarova.s_15101975@postgrespro.ru", "phone": "+70509702491"}
0005435214177	4606E9	3091 017404	VIKTOR MELNIKOV	{"phone": "+70871067723"}
0005435214178	B96DE6	6583 945154	VIKTOR KUZNECOV	{"phone": "+70058421777"}
0005435214179	E787BD	0925 654482	ANDREY ZAYCEV	{"phone": "+70552393056"}
0005435214180	E787BD	2697 404377	VALERIYA SCHERBAKOVA	{"phone": "+70474290394"}
0005435214181	E787BD	5675 269675	SERGEY VOLKOV	{"email": "volkov_s1986@postgrespro.ru", "phone": "+70618809261"}
0005435214182	A0F2D5	4169 806474	ANTONINA KUZNECOVA	{"phone": "+70374695034"}
0005435214183	A0F2D5	6147 549786	TIMOFEY KUDRYASHOV	{"phone": "+70667725914"}
0005435214184	562E1D	8758 076887	NATALYA KOROLEVA	{"email": "n.koroleva-081976@postgrespro.ru", "phone": "+70882409977"}
0005435214185	AF8FE5	2529 183081	SERGEY KUZNECOV	{"email": "kuznecov-s071977@postgrespro.ru", "phone": "+70346849279"}
0005435214186	DCAFCD	7793 017194	STANISLAV ALEKSEEV	{"email": "alekseev.stanislav.13121969@postgrespro.ru", "phone": "+70149861078"}
0005435214187	DCAFCD	2202 526084	VALENTINA BELOVA	{"email": "v-belova-011973@postgrespro.ru", "phone": "+70270684251"}
0005435214188	0F65F8	4412 447885	TATYANA GORBUNOVA	{"phone": "+70387270650"}
0005435214189	31676E	2713 877175	VLADISLAV NOVIKOV	{"phone": "+70345259704"}
0005435214190	C46D7F	5069 761389	MARIYA YUDINA	{"phone": "+70106947710"}
0005435214191	41F246	8454 348124	VIKTORIYA POLYAKOVA	{"email": "viktoriya-polyakova081959@postgrespro.ru", "phone": "+70905926788"}
0005435214193	43A355	1157 853061	SERGEY ABRAMOV	{"phone": "+70504432723"}
0005435214194	790A51	5899 261861	VALERIY NIKITIN	{"email": "nikitin.valeriy-1978@postgrespro.ru", "phone": "+70976691025"}
0005435214195	EC94B4	8423 740827	TAMARA ROMANOVA	{"phone": "+70149290310"}
0005435214196	BC7F92	2390 660921	LARISA ANISIMOVA	{"email": "anisimoval16041979@postgrespro.ru", "phone": "+70706347298"}
0005435214197	25D3E4	3834 696564	ELENA AKIMOVA	{"email": "elena_akimova.11101968@postgrespro.ru", "phone": "+70009255279"}
0005435214198	CCABA9	6826 516344	PETR FEDOTOV	{"phone": "+70513926845"}
0005435214199	88BC02	3509 770000	NIKITA MOROZOV	{"email": "n-morozov22011978@postgrespro.ru", "phone": "+70479973752"}
0005435214200	88BC02	5514 543465	SVETLANA ZHURAVLEVA	{"phone": "+70667532577"}
0005435214201	BC8D72	7616 198254	DARYA CHERNOVA	{"email": "d-chernova_19091981@postgrespro.ru", "phone": "+70535718105"}
0005435214202	34EC0C	2428 701763	EKATERINA AKIMOVA	{"phone": "+70693862747"}
0005435214203	34EC0C	9668 044478	GERMAN POPOV	{"email": "popovgerman.041979@postgrespro.ru", "phone": "+70746037611"}
0005435214204	80316A	8564 105669	TATYANA SOROKINA	{"phone": "+70886703624"}
0005435214205	80316A	7076 771142	GALINA NIKITINA	{"email": "gnikitina-111964@postgrespro.ru", "phone": "+70864762124"}
0005435214206	E023C3	0608 649014	ALEKSANDR KUZNECOV	{"phone": "+70487997697"}
0005435214207	A4078C	3170 337566	MAKSIM VASILEV	{"email": "vasilevm.25091973@postgrespro.ru", "phone": "+70622167026"}
0005435214208	421030	3335 050797	MARIYA ZHUKOVA	{"email": "mariya.zhukova-25121975@postgrespro.ru", "phone": "+70239419641"}
0005435214209	73397B	7769 541998	YULIYA MELNIKOVA	{"phone": "+70220225322"}
0005435214210	E5F37B	5309 251821	EKATERINA MAKAROVA	{"phone": "+70824961719"}
0005435214211	E5F37B	7694 256116	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr-31071984@postgrespro.ru", "phone": "+70075966677"}
0005435214212	F44E19	6501 064540	EKATERINA NIKOLAEVA	{"phone": "+70563711448"}
0005435214213	F44E19	0098 683715	OLGA KUZNECOVA	{"email": "kuznecova-olga30121972@postgrespro.ru", "phone": "+70082509777"}
0005435214214	F44E19	9391 786091	EKATERINA NIKIFOROVA	{"phone": "+70885555105"}
0005435214215	853841	1244 650652	YURIY BONDARENKO	{"email": "yuriy_bondarenko-12061981@postgrespro.ru", "phone": "+70967209703"}
0005435214216	01EDB1	9124 768532	OLESYA RODIONOVA	{"email": "rodionova-o1972@postgrespro.ru", "phone": "+70530371405"}
0005435214217	01EDB1	7185 857124	NIKOLAY IVANOV	{"phone": "+70736349440"}
0005435214218	295138	6122 298433	ILYA ALEKSEEV	{"email": "alekseev_i.061973@postgrespro.ru", "phone": "+70174672361"}
0005435214219	295138	1371 310986	LARISA ALEKSEEVA	{"phone": "+70690187639"}
0005435214220	D6C1CF	1483 263819	OLGA PETROVA	{"phone": "+70603133880"}
0005435214221	8E124F	5721 178930	VYACHESLAV ANDREEV	{"phone": "+70561636051"}
0005435214222	BA34D7	4317 262138	VASILIY BONDARENKO	{"email": "bondarenko.vasiliy_011989@postgrespro.ru", "phone": "+70574024444"}
0005435214223	2C1A07	5218 634811	ANTONINA DANILOVA	{"phone": "+70891931886"}
0005435214224	9B78B7	8084 814693	DMITRIY TARASOV	{"phone": "+70252761504"}
0005435214225	61CC96	2360 871660	MAKSIM STEPANOV	{"email": "stepanovm11061962@postgrespro.ru", "phone": "+70488364589"}
0005435214226	073CEF	6196 669081	YURIY ANTONOV	{"email": "antonov_yuriy.13121976@postgrespro.ru", "phone": "+70731615114"}
0005435214227	073CEF	4473 471745	TATYANA KONDRATEVA	{"phone": "+70891481586"}
0005435214228	D4C5E3	9829 477175	VALENTIN GAVRILOV	{"phone": "+70315201795"}
0005435214229	5685F5	9165 686835	MARIYA GAVRILOVA	{"email": "mariya_gavrilova-1957@postgrespro.ru", "phone": "+70943211135"}
0005435214230	67B421	1146 594473	ALEKSEY VASILEV	{"email": "vasilev-aleksey051965@postgrespro.ru", "phone": "+70750343478"}
0005435214231	5C8335	8960 880020	ALEKSANDR ROMANOV	{"phone": "+70968907450"}
0005435214232	17E009	2049 954388	MARIYA EGOROVA	{"email": "egorova-mariya_041972@postgrespro.ru", "phone": "+70088436459"}
0005435214233	17E009	8718 247564	YULIYA VASILEVA	{"phone": "+70601884183"}
0005435214234	E7069F	4310 962122	MARINA BELYAEVA	{"phone": "+70596920834"}
0005435214235	E7069F	7106 253160	NINA TROFIMOVA	{"phone": "+70675175815"}
0005435214236	2C4971	4168 288038	EVGENIY IVANOV	{"phone": "+70076830736"}
0005435214237	7D1A93	0654 311906	NINA NIKOLAEVA	{"phone": "+70267302981"}
0005435214238	1BE044	0382 753639	GLEB FEDOTOV	{"phone": "+70777328145"}
0005435214239	DC27DF	1996 840121	LYUBOV MAKSIMOVA	{"email": "lyubov_maksimova041963@postgrespro.ru", "phone": "+70460579248"}
0005435214240	349FDA	5328 017638	DARYA SMIRNOVA	{"email": "darya.smirnova_031965@postgrespro.ru", "phone": "+70282747423"}
0005435214241	349FDA	4867 687611	OLGA KRASNOVA	{"phone": "+70483095794"}
0005435214242	1D1DAE	9551 757008	YURIY VOLKOV	{"phone": "+70514108079"}
0005435214243	890774	0318 828952	ARTEM SCHERBAKOV	{"phone": "+70245313049"}
0005435214244	890774	2809 812294	NADEZHDA SOROKINA	{"email": "nadezhda.sorokina_1980@postgrespro.ru", "phone": "+70669264904"}
0005435214245	48F44E	2531 986063	IGOR NAUMOV	{"phone": "+70922561176"}
0005435214246	48F44E	1805 191976	SVETLANA OVCHINNIKOVA	{"email": "ovchinnikova_svetlana1967@postgrespro.ru", "phone": "+70837310068"}
0005435214247	D60E5E	3124 291566	VALERIYA TITOVA	{"phone": "+70407765316"}
0005435214248	6655A0	2221 192378	LYUDMILA BARANOVA	{"phone": "+70853584060"}
0005435214249	A788AA	0778 077489	YURIY AFANASEV	{"email": "yuriy.afanasev09021966@postgrespro.ru", "phone": "+70982517197"}
0005435214250	2DB020	9403 292328	IGOR VOLKOV	{"phone": "+70936310363"}
0005435214251	C5A323	3739 451569	VALERIY TIKHONOV	{"phone": "+70646640258"}
0005435214252	6686D8	4580 681845	IRINA TARASOVA	{"email": "irinatarasova_13031954@postgrespro.ru", "phone": "+70704199027"}
0005435214253	A793AA	7514 389335	EVGENIY NIKITIN	{"email": "e.nikitin_1952@postgrespro.ru", "phone": "+70826814243"}
0005435214254	9B425B	4074 309293	ANTON PETROV	{"phone": "+70626040537"}
0005435214255	9B425B	7462 293187	INNA POPOVA	{"phone": "+70616865670"}
0005435214256	B48E4D	9075 065442	ANTON SCHERBAKOV	{"email": "scherbakovanton28031973@postgrespro.ru", "phone": "+70006497274"}
0005435214257	B48E4D	3410 123562	PAVEL SOLOVEV	{"email": "pavel.solovev-16071967@postgrespro.ru", "phone": "+70040545602"}
0005435214258	3D75E5	9596 330924	NATALYA MATVEEVA	{"email": "n_matveeva_22041979@postgrespro.ru", "phone": "+70427967693"}
0005435214259	028AA1	7161 704293	VIKTORIYA STEPANOVA	{"email": "stepanovav.1969@postgrespro.ru", "phone": "+70362532460"}
0005435214260	028AA1	5403 385763	ANNA MOROZOVA	{"email": "morozova-anna-01091961@postgrespro.ru", "phone": "+70429338821"}
0005435214261	6716A7	1628 183830	NIKOLAY POPOV	{"phone": "+70460244958"}
0005435214262	0E3293	6693 783687	NIKOLAY VOLKOV	{"phone": "+70667924029"}
0005435214263	03505E	5054 252453	TATYANA SOROKINA	{"email": "sorokina-tatyana.1970@postgrespro.ru", "phone": "+70503558883"}
0005435214264	663966	1876 817163	SVETLANA GUSEVA	{"phone": "+70143686846"}
0005435214265	8942F6	5393 463182	VALENTINA NESTEROVA	{"phone": "+70952289801"}
0005435214266	8942F6	3269 605208	YANA FILATOVA	{"email": "yana-filatova-1965@postgrespro.ru", "phone": "+70321385056"}
0005435214267	8942F6	3330 196415	NIKOLAY RODIONOV	{"phone": "+70831595256"}
0005435214268	E16D91	0085 671017	ZHANNA ALEKSEEVA	{"email": "alekseeva_zhanna-1965@postgrespro.ru", "phone": "+70590216707"}
0005435214269	E16D91	0447 995642	MARIYA MOISEEVA	{"email": "moiseeva.m_06071978@postgrespro.ru", "phone": "+70837000767"}
0005435214270	A6BB9A	0037 615834	ALEKSANDRA SMIRNOVA	{"email": "aleksandra.smirnova_1978@postgrespro.ru", "phone": "+70152650068"}
0005435214271	367BF9	2886 430895	SERGEY MAKSIMOV	{"phone": "+70398677199"}
0005435214272	AF0FD7	0322 959205	VIKTOR SEMENOV	{"email": "viktor_semenov.1978@postgrespro.ru", "phone": "+70215379910"}
0005435214273	AF0FD7	6849 606300	ILYA MAKAROV	{"email": "i.makarov_05111959@postgrespro.ru", "phone": "+70318962752"}
0005435214274	4D5C97	2205 033402	VERA NIKITINA	{"phone": "+70005044254"}
0005435214275	A8844A	7457 849703	ANTONINA ANTONOVA	{"phone": "+70993204298"}
0005435214276	85376D	6642 434262	VERA ANDREEVA	{"phone": "+70708454513"}
0005435214277	85376D	9355 575896	ALEKSANDR YAKOVLEV	{"email": "yakovleva.01121970@postgrespro.ru", "phone": "+70359673828"}
0005435214278	B97B5B	4739 601040	EVGENIY MATVEEV	{"phone": "+70839665905"}
0005435214279	B97B5B	9618 680996	OLGA IVANOVA	{"email": "ivanova-o1984@postgrespro.ru", "phone": "+70244991833"}
0005435214280	FC4BE7	2152 843654	IRINA STEPANOVA	{"phone": "+70663292075"}
0005435214281	FC4BE7	4633 022952	SERGEY FROLOV	{"email": "frolov.sergey-061972@postgrespro.ru", "phone": "+70029679751"}
0005435214282	569A52	6783 700697	MILANA DMITRIEVA	{"phone": "+70853621667"}
0005435214283	569A52	1185 335334	SVETLANA SERGEEVA	{"email": "sergeeva.svetlana.1967@postgrespro.ru", "phone": "+70316859705"}
0005435214284	CCCC35	2546 575182	KSENIYA DANILOVA	{"phone": "+70113783240"}
0005435214285	0787E5	8317 609569	KONSTANTIN ZHUKOV	{"email": "konstantinzhukov-1983@postgrespro.ru", "phone": "+70954250127"}
0005435214286	0787E5	3915 166191	DMITRIY ALEKSEEV	{"phone": "+70857053294"}
0005435214287	0787E5	1070 438845	OLGA PAVLOVA	{"phone": "+70504845916"}
0005435214288	CEAB16	7309 859634	ULYANA TROFIMOVA	{"phone": "+70785701582"}
0005435214289	71B0BB	5848 149792	DARYA MAKAROVA	{"email": "d_makarova-041960@postgrespro.ru", "phone": "+70751008077"}
0005435214290	ACB614	0762 789371	EKATERINA NIKITINA	{"email": "nikitina-ekaterina_011978@postgrespro.ru", "phone": "+70737265671"}
0005435214291	ACB614	4648 965540	ANDREY KULIKOV	{"email": "kulikova_101975@postgrespro.ru", "phone": "+70691528872"}
0005435214292	74BF59	5032 921083	VERA KUZMINA	{"phone": "+70143717133"}
0005435214293	74BF59	1679 208378	ANNA ALEKSEEVA	{"email": "aalekseeva_23021982@postgrespro.ru", "phone": "+70612038340"}
0005435214294	6D2E81	0084 708455	ELENA KALININA	{"email": "elenakalinina_1977@postgrespro.ru", "phone": "+70295323321"}
0005435214295	6D2E81	0242 820997	ELENA NIKOLAEVA	{"phone": "+70655214440"}
0005435214296	1FE9BE	4278 892516	ALEKSEY GAVRILOV	{"phone": "+70502724020"}
0005435214297	1FE9BE	7444 751970	YURIY PETROV	{"phone": "+70551930768"}
0005435214298	212AA3	8344 568378	ANDREY KULIKOV	{"phone": "+70542109245"}
0005435214299	212AA3	3577 015897	RAISA FADEEVA	{"email": "fadeevaraisa_05051986@postgrespro.ru", "phone": "+70587102104"}
0005435214300	704DFB	9811 284318	NADEZHDA ZAYCEVA	{"email": "zayceva-nadezhda_26101971@postgrespro.ru", "phone": "+70569426515"}
0005435214301	5F61E0	6040 204282	FEDOR PETROV	{"email": "petrov.f.1976@postgrespro.ru", "phone": "+70846674297"}
0005435214302	3EA7E6	0464 415976	DENIS RODIONOV	{"email": "denisrodionov-17091965@postgrespro.ru", "phone": "+70438132801"}
0005435214303	683582	7487 029616	DANILA ALEKSANDROV	{"phone": "+70429306582"}
0005435214304	7D5D96	9086 773854	ANDREY GRIGOREV	{"phone": "+70917041345"}
0005435214305	49CBA1	8644 173539	SERGEY NIKITIN	{"email": "sergey_nikitin.1976@postgrespro.ru", "phone": "+70337936291"}
0005435214306	A3F1EE	0733 426155	ANASTASIYA TIMOFEEVA	{"phone": "+70726282305"}
0005435214307	661E61	0205 214291	STEPAN MEDVEDEV	{"phone": "+70606804748"}
0005435214308	5330CE	2099 757018	ALEKSEY ROMANOV	{"email": "aleksey.romanov-091975@postgrespro.ru", "phone": "+70684395654"}
0005435214309	E30390	2979 035481	LYUDMILA KOLESNIKOVA	{"email": "kolesnikova-lyudmila.011962@postgrespro.ru", "phone": "+70144385382"}
0005435214310	E30390	1334 896048	MIKHAIL ZAYCEV	{"phone": "+70641867703"}
0005435214311	8485AA	9558 704141	ALINA KUZMINA	{"email": "kuzminaa_13101979@postgrespro.ru", "phone": "+70504898173"}
0005435214312	89971D	2541 370912	OLGA NIKOLAEVA	{"phone": "+70846308160"}
0005435214313	89971D	4319 191517	ELENA ORLOVA	{"email": "elena-orlova_1963@postgrespro.ru", "phone": "+70473115738"}
0005435214314	DD153D	6075 763793	IRINA ANDREEVA	{"phone": "+70947408152"}
0005435214315	894500	3828 755677	VIKTOR BELOV	{"phone": "+70456908810"}
0005435214316	A67047	0655 771716	ANNA ZOTOVA	{"phone": "+70500346900"}
0005435214317	EC4A5C	8746 021178	SERGEY VLASOV	{"phone": "+70418094589"}
0005435214318	229F8F	4669 432858	IVAN KOZLOV	{"phone": "+70058681969"}
0005435214319	229F8F	6743 986548	ALEKSANDR STEPANOV	{"email": "a-stepanov08091970@postgrespro.ru", "phone": "+70924856661"}
0005435214320	6FF94E	4277 315061	VALENTINA BOGDANOVA	{"phone": "+70721853087"}
0005435214321	593B24	9252 899341	IRINA SEMENOVA	{"email": "irinasemenova.19051960@postgrespro.ru", "phone": "+70083005865"}
0005435214322	86C8CC	1980 779853	VALENTINA RYABOVA	{"phone": "+70626009868"}
0005435214323	05D00E	1838 574219	VLADIMIR PAVLOV	{"email": "vladimir-pavlov-021972@postgrespro.ru", "phone": "+70119979387"}
0005435214324	331739	7992 079721	ROMAN SCHERBAKOV	{"phone": "+70024765970"}
0005435214325	FDF46A	4380 208193	ALEKSEY STEPANOV	{"phone": "+70382440007"}
0005435214326	FDF46A	2810 151917	DANIIL DAVYDOV	{"email": "daniil_davydov-071966@postgrespro.ru", "phone": "+70590741890"}
0005435214327	D166F4	8505 190229	VIKTORIYA CHERNOVA	{"phone": "+70306038365"}
0005435214328	FF92A2	1799 860081	ALEKSANDR KOZLOV	{"phone": "+70933687084"}
0005435214329	FF92A2	1361 228270	SERGEY NIKITIN	{"phone": "+70875879444"}
0005435214330	551B67	5517 773270	EGOR MIRONOV	{"phone": "+70439688449"}
0005435214331	551B67	1422 238367	ELENA MEDVEDEVA	{"email": "elena_medvedeva.041983@postgrespro.ru", "phone": "+70760991059"}
0005435214332	D4A0C8	2467 358885	VADIM FOMIN	{"email": "vadim_fomin.20051980@postgrespro.ru", "phone": "+70526735293"}
0005435214333	D4A0C8	3095 347141	DMITRIY KISELEV	{"email": "kiselev.dmitriy.071972@postgrespro.ru", "phone": "+70203850698"}
0005435214334	D4A0C8	3279 903432	TATYANA SERGEEVA	{"email": "tatyana.sergeeva30121972@postgrespro.ru", "phone": "+70654844514"}
0005435214335	F8AB00	6890 733147	VLADISLAV TIKHONOV	{"phone": "+70104827001"}
0005435214336	F8AB00	1758 076283	VLADIMIR KISELEV	{"phone": "+70422314091"}
0005435214337	56334A	4042 974695	VIKTOR ZAYCEV	{"email": "viktor.zaycev101956@postgrespro.ru", "phone": "+70301457685"}
0005435214338	56334A	2188 934163	EVGENIY ALEKSANDROV	{"phone": "+70031569182"}
0005435214339	56334A	8365 832482	MARIYA KRASNOVA	{"phone": "+70042689986"}
0005435214340	46C234	0478 775446	VLADIMIR ZHUKOV	{"email": "zhukov.v11121971@postgrespro.ru", "phone": "+70272733371"}
0005435214341	C84F83	0804 373299	POLINA FROLOVA	{"phone": "+70225775398"}
0005435214342	37D843	3823 146233	LYUBOV RODIONOVA	{"phone": "+70227098257"}
0005435214343	C15376	8144 104114	EVGENIY GERASIMOV	{"phone": "+70256989617"}
0005435214344	C15376	7520 045905	DARYA NESTEROVA	{"phone": "+70964763566"}
0005435214345	C15376	7677 092457	VIKTOR FEDOROV	{"email": "viktor.fedorov_08101968@postgrespro.ru", "phone": "+70618929260"}
0005435214346	7BDD29	4193 403305	ANGELINA KOLESNIKOVA	{"phone": "+70223168298"}
0005435214347	6BA7C2	4872 795012	VALENTINA AKIMOVA	{"phone": "+70880092786"}
0005435214348	B5BE91	3457 724612	ELENA TARASOVA	{"phone": "+70790688503"}
0005435214349	625037	7424 251159	DMITRIY YAKOVLEV	{"phone": "+70838681968"}
0005435214350	3988FB	0347 421444	VIKTOR VOROBEV	{"email": "v_vorobev.05021965@postgrespro.ru", "phone": "+70900078271"}
0005435214351	C6BFBE	3787 132634	ANNA MOROZOVA	{"email": "annamorozova-12121975@postgrespro.ru", "phone": "+70701914403"}
0005435214352	C6BFBE	6366 590261	EKATERINA LEBEDEVA	{"email": "ekaterina_lebedeva.02101974@postgrespro.ru", "phone": "+70475270736"}
0005435214353	C6BFBE	3003 383174	TATYANA KOLESNIKOVA	{"email": "tatyana.kolesnikova.1974@postgrespro.ru", "phone": "+70353448221"}
0005435214354	174401	3472 244265	ANNA NIKOLAEVA	{"email": "annanikolaeva1977@postgrespro.ru", "phone": "+70609949986"}
0005435214355	502903	7875 747499	TATYANA MAKSIMOVA	{"email": "maksimovatatyana-051981@postgrespro.ru", "phone": "+70443424022"}
0005435214356	502903	0613 493562	OLGA MALYSHEVA	{"email": "malysheva.o.091980@postgrespro.ru", "phone": "+70144619520"}
0005435214357	C4CED4	9539 772543	VIKTOR NIKITIN	{"phone": "+70989664359"}
0005435214358	F1505D	1864 961217	MATVEY STEPANOV	{"phone": "+70635245905"}
0005435214359	F1505D	4166 968439	IGOR NIKITIN	{"phone": "+70549608599"}
0005435214360	41E57A	6941 970808	NURIYA FROLOVA	{"email": "frolova_nuriya_08121980@postgrespro.ru", "phone": "+70010094149"}
0005435214361	41E57A	7488 457424	VALENTINA MIKHAYLOVA	{"phone": "+70610145609"}
0005435214362	6DA056	1813 471004	NATALYA IVANOVA	{"email": "n-ivanova.1970@postgrespro.ru", "phone": "+70062488253"}
0005435214363	6DA056	7364 059654	TATYANA MASLOVA	{"email": "tatyana.maslova_091961@postgrespro.ru", "phone": "+70825737376"}
0005435214364	F03577	4920 292467	TATYANA SOLOVEVA	{"phone": "+70110341915"}
0005435214365	F03577	8161 560678	RAMIL PAVLOV	{"email": "ramilpavlov.041965@postgrespro.ru", "phone": "+70451126467"}
0005435214366	F11A89	0175 833377	DARYA YUDINA	{"phone": "+70593903394"}
0005435214367	9FA174	1387 800272	ANDREY ORLOV	{"email": "a.orlov.051985@postgrespro.ru", "phone": "+70995499981"}
0005435214368	2E70C7	7581 487188	INNA TARASOVA	{"email": "i_tarasova051974@postgrespro.ru", "phone": "+70431982831"}
0005435214369	936EB1	2396 665176	ANZHELA MAKSIMOVA	{"phone": "+70661767347"}
0005435214370	8CD889	5276 066018	OLEG ISAEV	{"email": "oisaev-01121965@postgrespro.ru", "phone": "+70569057527"}
0005435214371	C8566A	1214 505965	ALEKSANDR BARANOV	{"email": "baranov_a_081978@postgrespro.ru", "phone": "+70060058046"}
0005435214372	575C35	2607 917193	ALEKSEY KAZAKOV	{"email": "kazakov.aleksey.1960@postgrespro.ru", "phone": "+70382946217"}
0005435214373	15AFD3	6693 498547	NATALYA STEPANOVA	{"email": "n_stepanova_1963@postgrespro.ru", "phone": "+70378469212"}
0005435214374	4295B6	2644 655623	IRINA IVANOVA	{"phone": "+70390363010"}
0005435214375	C8AD6C	4669 047838	SERGEY KUZMIN	{"phone": "+70759675014"}
0005435214376	C8AD6C	7202 046103	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.1976@postgrespro.ru", "phone": "+70941386199"}
0005435214377	ACB224	5937 979422	TAMARA ABRAMOVA	{"email": "abramovat-26071978@postgrespro.ru", "phone": "+70389062596"}
0005435214378	56C757	8255 850099	SNEZHANA ROMANOVA	{"phone": "+70129738410"}
0005435214379	D0C264	0544 588477	ALEKSEY DAVYDOV	{"email": "adavydov_25011973@postgrespro.ru", "phone": "+70157010930"}
0005435214380	8688A1	9146 672021	PAVEL FEDOTOV	{"email": "pavel_fedotov_24071981@postgrespro.ru", "phone": "+70467198753"}
0005435214381	E2BD0C	2537 432095	VIKTOR NIKOLAEV	{"phone": "+70126652368"}
0005435214382	C9D9EE	2137 844972	VLADISLAV KUZNECOV	{"email": "v-kuznecov29061970@postgrespro.ru", "phone": "+70818599341"}
0005435214383	C9D9EE	6456 601417	MIKHAIL SHEVCHENKO	{"phone": "+70851968231"}
0005435214384	C9D9EE	8039 604775	LYUDMILA DAVYDOVA	{"email": "lyudmiladavydova.1969@postgrespro.ru", "phone": "+70057895470"}
0005435214385	815E74	3993 095703	ANATOLIY KUZNECOV	{"email": "kuznecov-anatoliy-031969@postgrespro.ru", "phone": "+70951761976"}
0005435214386	815E74	6412 762018	YULIYA BORISOVA	{"email": "yuliya.borisova-051957@postgrespro.ru", "phone": "+70491966573"}
0005435214387	8F2EEC	8676 011998	OLGA FILATOVA	{"email": "filatovao.13041970@postgrespro.ru", "phone": "+70384392526"}
0005435214388	13F0A4	5109 166615	VYACHESLAV KULIKOV	{"email": "kulikovvyacheslav_011973@postgrespro.ru", "phone": "+70527995729"}
0005435214389	6F148D	0800 783711	SERGEY STEPANOV	{"email": "sergey.stepanov13091960@postgrespro.ru", "phone": "+70912612733"}
0005435214390	EE6473	5331 008120	IRINA MOROZOVA	{"email": "morozova.irina1969@postgrespro.ru", "phone": "+70491777735"}
0005435214391	EE6473	1127 739227	MARIYA PAVLOVA	{"phone": "+70654938860"}
0005435214392	F12D23	7997 404039	MAKSIM DAVYDOV	{"email": "maksimdavydov-1980@postgrespro.ru", "phone": "+70221780423"}
0005435214393	5354CF	5782 014794	VALERIY NIKITIN	{"email": "nikitin-v_1982@postgrespro.ru", "phone": "+70991697180"}
0005435214394	DD707C	4594 756987	VIKTOR GUSEV	{"phone": "+70957213247"}
0005435214395	115A20	5182 711691	VERA KOROLEVA	{"email": "v.koroleva-03021976@postgrespro.ru", "phone": "+70936507040"}
0005435214396	A3A1F6	2101 885037	SERGEY MOROZOV	{"phone": "+70603965501"}
0005435214397	3935E0	9323 758058	VARVARA FEDOROVA	{"phone": "+70400834396"}
0005435214398	3935E0	1039 162027	DMITRIY OSIPOV	{"email": "osipov-d_13111976@postgrespro.ru", "phone": "+70438174546"}
0005435214399	9CC89A	7448 230031	SERGEY DMITRIEV	{"email": "dmitriev-sergey21031978@postgrespro.ru", "phone": "+70118097880"}
0005435214400	9CC89A	3275 170445	ALEKSEY SOROKIN	{"phone": "+70061395702"}
0005435214401	057089	8341 994988	RUSTAM KULIKOV	{"phone": "+70227206960"}
0005435214402	AB715C	9754 225526	TATYANA SAVELEVA	{"phone": "+70273586372"}
0005435214403	AB715C	0349 402413	GERMAN PETROV	{"phone": "+70070967485"}
0005435214404	A4F287	2702 827089	ILYA NOVIKOV	{"phone": "+70994265327"}
0005435214405	D65FAC	3997 855549	PAVEL SOLOVEV	{"email": "solovevpavel.20071976@postgrespro.ru", "phone": "+70885534247"}
0005435214406	D65FAC	2815 864440	MARIYA VLASOVA	{"phone": "+70431586569"}
0005435214407	972685	7018 129586	ELIZAVETA NIKOLAEVA	{"email": "enikolaeva-19091985@postgrespro.ru", "phone": "+70572114199"}
0005435214408	1A96B3	9895 896867	AYRAT DAVYDOV	{"phone": "+70651377956"}
0005435214409	FCAEE7	4851 632624	ANDREY GERASIMOV	{"phone": "+70336683140"}
0005435214410	93A615	2469 342366	MARIANNA FOMINA	{"email": "fomina_m_051969@postgrespro.ru", "phone": "+70665661790"}
0005435214411	20EA80	7687 474223	VLADIMIR DENISOV	{"email": "denisovvladimir041972@postgrespro.ru", "phone": "+70560148199"}
0005435214412	87EA86	7933 050690	OKSANA KUDRYASHOVA	{"email": "kudryashova_oksana.23111960@postgrespro.ru", "phone": "+70673647360"}
0005435214413	83B805	1507 366566	ALEKSANDR TIKHONOV	{"phone": "+70129537322"}
0005435214414	0A510A	3721 270939	OKSANA ZAYCEVA	{"email": "zayceva.oksana.28061950@postgrespro.ru", "phone": "+70932306381"}
0005435214415	200CAB	9449 881846	SERGEY ALEKSANDROV	{"phone": "+70330765356"}
0005435214416	042C2A	8201 589910	NADEZHDA KISELEVA	{"phone": "+70420298177"}
0005435214417	1F7A84	7465 799398	VLADIMIR EGOROV	{"email": "egorov_v-011975@postgrespro.ru", "phone": "+70962788744"}
0005435214418	EFF915	7652 890385	VALERIY SEMENOV	{"email": "semenov-valeriy-07021969@postgrespro.ru", "phone": "+70876662204"}
0005435214419	1D98B1	7192 552430	LARISA VASILEVA	{"phone": "+70679871773"}
0005435214420	1D98B1	9744 824241	KONSTANTIN RODIONOV	{"email": "konstantin.rodionov21051974@postgrespro.ru", "phone": "+70159020688"}
0005435214421	9A705F	7360 253193	VALERIYA TARASOVA	{"email": "tarasova-valeriya031978@postgrespro.ru", "phone": "+70372484932"}
0005435214422	B2427F	7364 844605	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir_18081981@postgrespro.ru", "phone": "+70879247148"}
0005435214423	A4A04A	3391 215367	NIKITA ORLOV	{"phone": "+70475830697"}
0005435214424	A4A04A	8881 318174	DAMIR MARTYNOV	{"phone": "+70398777396"}
0005435214425	BC08E7	4834 197774	NADEZHDA MOROZOVA	{"phone": "+70223298084"}
0005435214426	18E50C	6229 917109	VASILIY FROLOV	{"phone": "+70991096955"}
0005435214427	18E50C	1894 029694	ELENA MATVEEVA	{"email": "e.matveeva-29071974@postgrespro.ru", "phone": "+70142819977"}
0005435214428	D7F3BA	5346 611279	ALEKSANDR GAVRILOV	{"email": "a_gavrilov11121972@postgrespro.ru", "phone": "+70835854089"}
0005435214429	F22426	2173 291298	ALEKSANDR KUZNECOV	{"phone": "+70101092130"}
0005435214430	63893F	9651 640475	YURIY POPOV	{"email": "popov.y.121975@postgrespro.ru", "phone": "+70108964536"}
0005435214431	63893F	7401 001673	NIKITA KUZMIN	{"phone": "+70210484121"}
0005435214432	6CDCF1	2715 091722	YURIY ISAEV	{"email": "yuriy-isaev-041970@postgrespro.ru", "phone": "+70194064857"}
0005435214433	5AE070	3718 748580	OKSANA GRISHINA	{"email": "grishinaoksana.091981@postgrespro.ru", "phone": "+70709305015"}
0005435214494	ECE22C	2557 060619	RAVIL VASILEV	{"phone": "+70397252074"}
0005435214434	5AE070	7682 591267	TATYANA KOROLEVA	{"email": "tkoroleva-1969@postgrespro.ru", "phone": "+70311446288"}
0005435214435	5BDE33	2197 892049	ELENA VLASOVA	{"phone": "+70525757547"}
0005435214436	AC3242	6146 133093	OKSANA MOROZOVA	{"phone": "+70974753383"}
0005435214437	1E2C19	5473 925252	VLADIMIR MOISEEV	{"phone": "+70808845115"}
0005435214438	A259EA	7562 168278	VLADIMIR MATVEEV	{"phone": "+70943163405"}
0005435214439	A259EA	2816 195013	ANTONINA NAUMOVA	{"email": "a_naumova-021977@postgrespro.ru", "phone": "+70778313867"}
0005435214440	49ABA7	5584 980772	NAILYA ANDREEVA	{"email": "andreevanailya02021974@postgrespro.ru", "phone": "+70807037329"}
0005435214441	49EC6F	6053 417571	VLADISLAV KOZLOV	{"phone": "+70139444624"}
0005435214442	1B69C9	2564 969106	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-071971@postgrespro.ru", "phone": "+70474025268"}
0005435214443	96C8EF	6212 471855	VERA NIKITINA	{"email": "vnikitina26101975@postgrespro.ru", "phone": "+70864281214"}
0005435214444	DF5E90	8768 850604	EVGENIYA ZOTOVA	{"email": "evgeniya-zotova1980@postgrespro.ru", "phone": "+70692035257"}
0005435214445	DF5E90	1393 077850	SERGEY MOROZOV	{"email": "morozov.s.11041974@postgrespro.ru", "phone": "+70457273370"}
0005435214446	1017E4	2529 391959	VYACHESLAV FROLOV	{"email": "v-frolov1962@postgrespro.ru", "phone": "+70730801546"}
0005435214447	C936FE	6218 821762	NIKOLAY FROLOV	{"phone": "+70988686630"}
0005435214448	C936FE	7157 963254	VIKTOR IVANOV	{"email": "ivanov.v-19031976@postgrespro.ru", "phone": "+70076115473"}
0005435214449	A4070A	2454 116675	ANATOLIY NIKOLAEV	{"email": "anatoliy_nikolaev_1971@postgrespro.ru", "phone": "+70213275713"}
0005435214450	34E5C3	2706 446513	ARTEM KUZNECOV	{"email": "kuznecov.a_28051982@postgrespro.ru", "phone": "+70741468756"}
0005435214451	77D154	8988 542506	VIKTORIYA SERGEEVA	{"phone": "+70833156864"}
0005435214452	38EA6B	1767 055583	MARINA MATVEEVA	{"email": "m-matveeva_25041966@postgrespro.ru", "phone": "+70514608939"}
0005435214453	DBB02E	8917 625498	LARISA RYABOVA	{"email": "ryabova_l14041981@postgrespro.ru", "phone": "+70308863638"}
0005435214454	0FF2EB	3983 428500	DARYA FOMINA	{"phone": "+70524261333"}
0005435214455	0FF2EB	0820 512132	GALINA LOGINOVA	{"email": "galina-loginova.1969@postgrespro.ru", "phone": "+70401326842"}
0005435214456	891A06	0492 819406	TATYANA DANILOVA	{"phone": "+70758733520"}
0005435214457	E7FEB4	9324 988340	VLADIMIR KOZLOV	{"phone": "+70975469682"}
0005435214458	E7FEB4	2256 179157	NIKOLAY SAVELEV	{"phone": "+70739288510"}
0005435214459	9D8AD2	6896 817186	NADEZHDA LUKYANOVA	{"email": "lukyanovanadezhda_02031970@postgrespro.ru", "phone": "+70884264635"}
0005435214460	0B1C2C	7465 964311	NINA VOLKOVA	{"email": "ninavolkova_15101978@postgrespro.ru", "phone": "+70276330868"}
0005435214461	E7D67B	1977 020781	IRINA VOLKOVA	{"email": "irina.volkova1961@postgrespro.ru", "phone": "+70335347391"}
0005435214462	3B5325	2341 437889	RAMIL NIKITIN	{"phone": "+70693233391"}
0005435214463	72BBA2	8358 187559	OLGA TARASOVA	{"email": "o_tarasova011970@postgrespro.ru", "phone": "+70993703753"}
0005435214464	18E5B1	9894 399616	ULYANA ZAKHAROVA	{"phone": "+70480518820"}
0005435214465	E1C9EF	6158 874332	OLGA NAZAROVA	{"email": "nazarova.o.1974@postgrespro.ru", "phone": "+70718842634"}
0005435214466	F90A4C	7931 545294	NIKOLAY DAVYDOV	{"phone": "+70115687788"}
0005435214467	847E91	5235 197298	DMITRIY DENISOV	{"email": "denisov_d10031976@postgrespro.ru", "phone": "+70772155716"}
0005435214468	A8BB01	4162 064286	OLEG MAKSIMOV	{"email": "o-maksimov1971@postgrespro.ru", "phone": "+70497069831"}
0005435214469	AE3CD2	0028 239193	TATYANA KUZNECOVA	{"phone": "+70330165772"}
0005435214470	AE3CD2	3955 142541	YURIY SMIRNOV	{"email": "yuriy_smirnov1975@postgrespro.ru", "phone": "+70302274628"}
0005435214471	AE3CD2	4916 881443	ELENA ARKHIPOVA	{"phone": "+70746620948"}
0005435214472	92A4AE	4733 177900	MIKHAIL NAZAROV	{"email": "m_nazarov-28071973@postgrespro.ru", "phone": "+70591159737"}
0005435214473	92A4AE	4189 358005	GALINA SAVELEVA	{"phone": "+70964007202"}
0005435214474	C8D88F	1996 257478	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov_31101977@postgrespro.ru", "phone": "+70604174437"}
0005435214475	C8D88F	0629 414754	VALERIY ZAKHAROV	{"phone": "+70147417486"}
0005435214476	21565E	8484 043834	SERGEY NIKOLAEV	{"email": "nikolaevsergey_16051968@postgrespro.ru", "phone": "+70073142469"}
0005435214477	21565E	0868 307113	EVGENIY PAVLOV	{"phone": "+70781093420"}
0005435214478	000C2B	2537 377604	TATYANA VASILEVA	{"email": "vasileva_t.041955@postgrespro.ru", "phone": "+70603846469"}
0005435214479	195816	6431 213308	RUSTAM ORLOV	{"phone": "+70408087796"}
0005435214480	0790EF	1832 228695	VITALIY KISELEV	{"phone": "+70354577227"}
0005435214481	6CEDDB	3230 393714	NATALYA DAVYDOVA	{"email": "n.davydova-051975@postgrespro.ru", "phone": "+70893125525"}
0005435214482	1E9A01	3831 845484	TATYANA NAUMOVA	{"phone": "+70639037752"}
0005435214483	1E9A01	3796 452790	ELENA SOROKINA	{"email": "esorokina.111964@postgrespro.ru", "phone": "+70973342336"}
0005435214484	77F247	6309 955652	VALENTINA ZHURAVLEVA	{"email": "valentina-zhuravleva-1968@postgrespro.ru", "phone": "+70621555053"}
0005435214485	34DD94	2367 441345	NATALYA PETROVA	{"phone": "+70067875056"}
0005435214486	34DD94	4388 294184	INNA KUZNECOVA	{"phone": "+70792460720"}
0005435214487	77D363	6899 250971	NINA KISELEVA	{"phone": "+70248977328"}
0005435214488	B7419A	8538 999450	VERA GUSEVA	{"email": "vera-guseva_041972@postgrespro.ru", "phone": "+70865309664"}
0005435214489	DE5162	6506 457902	LYUDMILA FOMINA	{"email": "fomina.lyudmila.07071976@postgrespro.ru", "phone": "+70374218504"}
0005435214490	9BE915	4336 580991	VIKTOR DENISOV	{"email": "denisov_v_071961@postgrespro.ru", "phone": "+70033535192"}
0005435214491	1723B6	6867 416848	NELLI KARPOVA	{"phone": "+70536512191"}
0005435214492	ECE22C	9097 094594	LYUBOV FOMINA	{"phone": "+70594575473"}
0005435214493	ECE22C	6330 078163	NATALYA KUZMINA	{"phone": "+70601681270"}
0005435214495	1E3051	1263 879928	NATALYA KALININA	{"email": "kalinina_n18101968@postgrespro.ru", "phone": "+70927048017"}
0005435214496	8C6825	7967 934890	DMITRIY SEMENOV	{"phone": "+70093487189"}
0005435214497	5A4CAE	4391 271402	DMITRIY STEPANOV	{"phone": "+70231042369"}
0005435214498	D3C9CC	0138 214161	BORIS MARTYNOV	{"email": "boris-martynov.091973@postgrespro.ru", "phone": "+70618906352"}
0005435214499	45C5B6	3097 769910	IRINA VASILEVA	{"phone": "+70497832052"}
0005435214500	C23743	4370 705123	NIKOLAY PAVLOV	{"email": "pavlovn-081980@postgrespro.ru", "phone": "+70816658423"}
0005435214501	C01CC1	0190 277027	SERGEY EGOROV	{"email": "egorov_sergey.041973@postgrespro.ru", "phone": "+70019211862"}
0005435214502	FDF2DB	9656 970389	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr_20081965@postgrespro.ru", "phone": "+70537249088"}
0005435214503	1277AE	4537 846423	VERA BELOVA	{"email": "belovavera081972@postgrespro.ru", "phone": "+70823127245"}
0005435214504	1277AE	2660 854223	DMITRIY ALEKSEEV	{"phone": "+70881571645"}
0005435214505	94E3C8	4385 061551	ANDREY KOZLOV	{"email": "andrey_kozlov_01051972@postgrespro.ru", "phone": "+70023287871"}
0005435214506	2CBFB0	5466 995721	ELENA POPOVA	{"email": "elena_popova_101970@postgrespro.ru", "phone": "+70408018364"}
0005435214507	2CBFB0	9719 463947	NINA MIKHAYLOVA	{"email": "nmikhaylova-031979@postgrespro.ru", "phone": "+70024864448"}
0005435214508	B0FAD1	9305 758582	VLADIMIR MOISEEV	{"phone": "+70178891035"}
0005435214509	082331	4149 908017	ELENA POPOVA	{"email": "popova.elena_12021971@postgrespro.ru", "phone": "+70939326126"}
0005435214510	4E5748	2662 790012	MAYYA LEBEDEVA	{"email": "lebedeva_mayya.14011968@postgrespro.ru", "phone": "+70032846119"}
0005435214511	76532E	7520 536827	ANNA NIKOLAEVA	{"email": "nikolaevaa13021969@postgrespro.ru", "phone": "+70124470713"}
0005435214512	76532E	9863 953708	TATYANA BORISOVA	{"phone": "+70680245854"}
0005435214513	BF6809	7761 241145	VIKTOR ABRAMOV	{"email": "v.abramov111975@postgrespro.ru", "phone": "+70426980062"}
0005435214514	EB9367	3142 495548	VALENTINA ABRAMOVA	{"email": "abramova_valentina.01011976@postgrespro.ru", "phone": "+70792278990"}
0005435214515	EB9367	1364 642693	NIKOLAY DENISOV	{"email": "nikolay-denisov-1971@postgrespro.ru", "phone": "+70860664163"}
0005435214516	53CB7A	1535 524726	ANDREY KUZNECOV	{"email": "kuznecov-andrey22071977@postgrespro.ru", "phone": "+70213585373"}
0005435214517	E6BC4F	7950 310875	SOFYA DAVYDOVA	{"email": "davydova.s061963@postgrespro.ru", "phone": "+70863927521"}
0005435214518	E6BC4F	8389 123817	NATALYA KUZNECOVA	{"email": "kuznecova_n_1979@postgrespro.ru", "phone": "+70058075031"}
0005435214519	8E4A04	8667 946330	PETR NOVIKOV	{"phone": "+70119502473"}
0005435214520	8E4A04	1782 666660	OLGA VOROBEVA	{"email": "vorobevao_24111971@postgrespro.ru", "phone": "+70719613343"}
0005435214521	89A8BC	4328 670090	GENNADIY ILIN	{"email": "ilin-g.19101981@postgrespro.ru", "phone": "+70717694165"}
0005435214522	6EA0FB	2153 211788	LYUDMILA DENISOVA	{"phone": "+70197212279"}
0005435214523	A0474B	9287 907030	LYUDMILA AFANASEVA	{"email": "l-afanaseva_1966@postgrespro.ru", "phone": "+70340812844"}
0005435214524	4D21E4	6191 510244	ANATOLIY EGOROV	{"phone": "+70275503147"}
0005435214525	B266D6	6610 594453	VIKTOR RODIONOV	{"email": "viktorrodionov1966@postgrespro.ru", "phone": "+70269724351"}
0005435214526	B266D6	1968 308515	POLINA SEMENOVA	{"email": "semenova.p_20021966@postgrespro.ru", "phone": "+70520275380"}
0005435214527	BDF75C	1489 243891	NADEZHDA NESTEROVA	{"email": "nesterova.n_04031959@postgrespro.ru", "phone": "+70587109571"}
0005435214528	DB0587	7076 123530	ELVIRA NIKITINA	{"email": "e-nikitina-29051973@postgrespro.ru", "phone": "+70925801083"}
0005435214529	DB0587	2173 793841	EVGENIY IVANOV	{"email": "evgeniy.ivanov-29081968@postgrespro.ru", "phone": "+70486917923"}
0005435214530	E12982	4018 753689	ZHANNA MEDVEDEVA	{"email": "z-medvedeva101977@postgrespro.ru", "phone": "+70867634267"}
0005435214531	E12982	5846 063220	ALEKSEY PETROV	{"email": "apetrov101961@postgrespro.ru", "phone": "+70841884798"}
0005435214532	5A39C8	7335 546742	LILIYA IVANOVA	{"phone": "+70775256175"}
0005435214533	2FE262	7559 024979	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v101971@postgrespro.ru", "phone": "+70136577196"}
0005435214534	419A79	4761 901733	IGOR MIRONOV	{"email": "igor.mironov_08081959@postgrespro.ru", "phone": "+70881725785"}
0005435214535	47C3CA	9359 170248	ANASTASIYA MEDVEDEVA	{"phone": "+70415342775"}
0005435214536	401A16	5731 450301	LYUCIYA LOGINOVA	{"phone": "+70518399261"}
0005435214537	401A16	0560 143854	GALINA VASILEVA	{"phone": "+70914579453"}
0005435214538	21336E	0866 573793	OLGA POPOVA	{"email": "popovaolga.23111967@postgrespro.ru", "phone": "+70017631537"}
0005435214539	4C742F	6498 083746	VERA MARTYNOVA	{"email": "vera-martynova27021966@postgrespro.ru", "phone": "+70022105145"}
0005435214540	4C742F	5392 634800	OLGA SEMENOVA	{"email": "semenovao1967@postgrespro.ru", "phone": "+70420609652"}
0005435214541	F3E892	0655 297534	ZULFIYA PAVLOVA	{"phone": "+70640593385"}
0005435214542	D6F2D1	4563 458681	VASILIY GRIGOREV	{"email": "grigorev_v-19031974@postgrespro.ru", "phone": "+70230493263"}
0005435214543	18CCFD	6687 558737	YULIYA ZOTOVA	{"phone": "+70102640954"}
0005435214544	18CCFD	5294 273895	MARIYA TARASOVA	{"phone": "+70490091584"}
0005435214545	18CCFD	8526 213666	ANTONINA IVANOVA	{"phone": "+70244723199"}
0005435214546	E2B9A5	1451 631433	ANDREY PETROV	{"phone": "+70966778129"}
0005435214547	E2B9A5	7536 476376	NATALYA MOROZOVA	{"phone": "+70942940278"}
0005435214548	70FBA2	9312 898343	YULIYA FILIPPOVA	{"phone": "+70046178905"}
0005435214549	EB48ED	5228 345216	ULYANA ZAKHAROVA	{"email": "ulyana_zakharova_03071976@postgrespro.ru", "phone": "+70200155028"}
0005435214550	EB48ED	8652 521411	VYACHESLAV FROLOV	{"email": "vyacheslav-frolov.1979@postgrespro.ru", "phone": "+70443395387"}
0005435214551	61ACEB	5192 103637	YURIY SOROKIN	{"email": "yuriy_sorokin.1973@postgrespro.ru", "phone": "+70586821079"}
0005435214552	23FEA3	2367 868538	SERGEY VOLKOV	{"phone": "+70157058471"}
0005435214553	23FEA3	5857 527321	VALENTINA EFREMOVA	{"email": "efremova-v11121978@postgrespro.ru", "phone": "+70842399545"}
0005435214554	ED58E1	6735 750228	IVAN ZAKHAROV	{"email": "zakharovivan-1962@postgrespro.ru", "phone": "+70032242598"}
0005435214555	EA6A6D	6706 650947	NATALYA KRASNOVA	{"phone": "+70066561321"}
0005435214556	947C3B	5107 869606	MAKSIM PETROV	{"email": "maksim_petrov-23041980@postgrespro.ru", "phone": "+70102492307"}
0005435214557	7746E2	5002 492793	VIKTOR PAVLOV	{"email": "pavlov-viktor_031982@postgrespro.ru", "phone": "+70439570139"}
0005435214558	C7C964	3135 880559	VERA ORLOVA	{"email": "vorlova13051968@postgrespro.ru", "phone": "+70221766650"}
0005435214559	977602	5487 214585	IRINA KUZNECOVA	{"email": "kuznecova.i_1983@postgrespro.ru", "phone": "+70000964737"}
0005435214560	01CE45	0742 768712	OLGA PETROVA	{"email": "olgapetrova-121976@postgrespro.ru", "phone": "+70450486117"}
0005435214561	AD5991	1333 506388	OLGA NIKIFOROVA	{"email": "olga_nikiforova_1968@postgrespro.ru", "phone": "+70958595515"}
0005435214562	2689CF	6402 601437	IVAN FOMIN	{"phone": "+70149052468"}
0005435214563	A34D01	8601 514902	OLGA IVANOVA	{"phone": "+70466721298"}
0005435214564	A34D01	3558 002990	MIKHAIL ANDREEV	{"email": "mikhailandreev_101977@postgrespro.ru", "phone": "+70577191436"}
0005435214565	EEFAE6	2032 960840	VIKTOR KARPOV	{"phone": "+70582551959"}
0005435214566	F91BBA	7446 835675	YURIY GORBUNOV	{"phone": "+70103961798"}
0005435214567	2B9A47	7875 691890	VALERIY KUZMIN	{"phone": "+70889199977"}
0005435214568	94852A	9575 354474	ELENA IVANOVA	{"phone": "+70261227329"}
0005435214569	12A2B1	9896 365844	LIDIYA SOROKINA	{"email": "sorokinalidiya.1980@postgrespro.ru", "phone": "+70624251245"}
0005435214570	0C0D4E	7002 920637	DMITRIY KOZLOV	{"phone": "+70926461309"}
0005435214571	0C0D4E	0794 998961	YULIYA FILIPPOVA	{"phone": "+70579751200"}
0005435214572	4BBF41	8531 686742	VASILIY VOLKOV	{"phone": "+70864764211"}
0005435214573	D43368	0450 791443	LYUDMILA FILATOVA	{"email": "lyudmila_filatova12031963@postgrespro.ru", "phone": "+70882629565"}
0005435214574	BA9969	1706 942818	RAMILYA GERASIMOVA	{"email": "ramilyagerasimova051973@postgrespro.ru", "phone": "+70467253923"}
0005435214575	6C9532	1505 503517	ROMAN GRIGOREV	{"email": "grigorev-roman1970@postgrespro.ru", "phone": "+70442719757"}
0005435214576	E6A3CC	5782 211543	DANILA VASILEV	{"phone": "+70045507685"}
0005435214577	E6A3CC	3090 463853	ANNA FILATOVA	{"email": "a-filatova-02081986@postgrespro.ru", "phone": "+70804401575"}
0005435214578	D042EC	9435 447607	ANNA ANISIMOVA	{"email": "anisimova_anna_1971@postgrespro.ru", "phone": "+70714182266"}
0005435214579	7DF78E	4885 204889	ANDREY MOISEEV	{"phone": "+70893901851"}
0005435214580	ECEC99	9165 550428	KSENIYA GUSEVA	{"phone": "+70445340032"}
0005435214581	B97246	6648 882585	SERGEY GORBUNOV	{"email": "gorbunov_sergey-1969@postgrespro.ru", "phone": "+70188907103"}
0005435214582	B97246	8608 921720	VASILIY VASILEV	{"phone": "+70490273165"}
0005435214583	A19070	4124 679811	VLADISLAV POPOV	{"email": "popov_vladislav_1965@postgrespro.ru", "phone": "+70985033179"}
0005435214584	5320A1	5416 696152	SVETLANA SEMENOVA	{"phone": "+70940969749"}
0005435214585	884451	4794 331852	DARYA POTAPOVA	{"phone": "+70595024865"}
0005435214586	884451	8597 746410	NATALYA IVANOVA	{"email": "ivanova.natalya-011978@postgrespro.ru", "phone": "+70515132734"}
0005435214587	EEAC6D	8309 947801	NATALYA MIKHAYLOVA	{"email": "mikhaylovanatalya_19021971@postgrespro.ru", "phone": "+70561846223"}
0005435214588	EEAC6D	1436 046987	NATALYA FEDOROVA	{"email": "fedorova_n_081985@postgrespro.ru", "phone": "+70182980163"}
0005435214589	FD6ECC	2717 137380	ARTEM ILIN	{"email": "ilinartem-02091966@postgrespro.ru", "phone": "+70700704180"}
0005435214590	46FC7D	0532 760246	VALENTINA ERMAKOVA	{"phone": "+70108089454"}
0005435214591	46FC7D	2507 919595	ARTEM NAUMOV	{"phone": "+70597630463"}
0005435214592	46FC7D	6880 361199	OLEG KUDRYASHOV	{"email": "kudryashov_o28021969@postgrespro.ru", "phone": "+70677687261"}
0005435214593	05CAE4	9059 502036	TATYANA MIRONOVA	{"phone": "+70665128094"}
0005435214594	05CAE4	2086 589322	ANTON MARTYNOV	{"phone": "+70984891701"}
0005435214595	A50DCC	4558 523574	ALEKSANDR FROLOV	{"phone": "+70614626060"}
0005435214596	6A8186	6213 721673	LIDIYA POLYAKOVA	{"phone": "+70962175525"}
0005435214597	5AD57C	8187 615127	VALENTINA KARPOVA	{"email": "karpova_valentina.1975@postgrespro.ru", "phone": "+70799448331"}
0005435214598	043012	2206 954552	IRINA SCHERBAKOVA	{"phone": "+70737865319"}
0005435214599	043012	1840 807839	EVGENIYA GUSEVA	{"email": "guseva.evgeniya.1967@postgrespro.ru", "phone": "+70864145966"}
0005435214600	6EF801	9807 573758	NIKITA MATVEEV	{"phone": "+70144209288"}
0005435214601	C57025	3546 409357	MIKHAIL ABRAMOV	{"phone": "+70284006979"}
0005435214602	89CBC1	0450 552938	ELENA EFIMOVA	{"email": "efimovae_071972@postgrespro.ru", "phone": "+70237300808"}
0005435214603	89CBC1	6421 172822	SVETLANA ABRAMOVA	{"phone": "+70299577128"}
0005435214604	5034ED	1371 403127	DENIS MAKAROV	{"phone": "+70400088923"}
0005435214605	BC86C8	9388 564880	ANASTASIYA ABRAMOVA	{"email": "abramova.anastasiya-011979@postgrespro.ru", "phone": "+70779709863"}
0005435214606	6D5647	8395 565831	NATALYA ZAYCEVA	{"email": "natalya-zayceva.08041983@postgrespro.ru", "phone": "+70706207358"}
0005435214607	6D5647	5941 545344	VIKTOR TIMOFEEV	{"email": "timofeev-viktor1965@postgrespro.ru", "phone": "+70834510111"}
0005435214608	61352A	9544 811242	NADEZHDA GUSEVA	{"phone": "+70782622278"}
0005435214609	61352A	5546 221087	ANDREY MAKSIMOV	{"phone": "+70357602378"}
0005435214610	530D48	5770 046180	VLADISLAV NIKITIN	{"phone": "+70875469524"}
0005435214611	9ED63F	7063 687010	EVDOKIYA MAKAROVA	{"email": "makarovaevdokiya.1972@postgrespro.ru", "phone": "+70570193440"}
0005435214612	0EEB95	5619 821730	TAMARA VOROBEVA	{"phone": "+70220104735"}
0005435214613	0EEB95	8388 341375	OLGA VOLKOVA	{"phone": "+70441331101"}
0005435214614	76DA09	2373 925094	ANNA IVANOVA	{"phone": "+70987892602"}
0005435214615	768A7C	9102 189760	VADIM IVANOV	{"email": "ivanovv.011976@postgrespro.ru", "phone": "+70095295418"}
0005435214616	768A7C	9703 964666	ALEKSANDR KUZNECOV	{"phone": "+70877887712"}
0005435214617	7F49B1	9340 873954	VALERIY OSIPOV	{"email": "osipov-valeriy-071975@postgrespro.ru", "phone": "+70964669582"}
0005435214618	F61D4D	1730 956335	INNA OSIPOVA	{"email": "innaosipova1969@postgrespro.ru", "phone": "+70002794099"}
0005435214619	25272D	3099 409022	ELENA ZAKHAROVA	{"email": "zakharova.e.1963@postgrespro.ru", "phone": "+70478774030"}
0005435214620	8DD93E	8196 637613	MARIYA PAVLOVA	{"email": "pavlova_mariya-30111977@postgrespro.ru", "phone": "+70377526780"}
0005435214621	8DD93E	4028 165947	ARTEM IVANOV	{"email": "ivanov_artem.1974@postgrespro.ru", "phone": "+70415564915"}
0005435214622	453A1B	9159 172014	ELENA KARPOVA	{"email": "elenakarpova-041974@postgrespro.ru", "phone": "+70235327718"}
0005435214623	125B66	1776 012015	ELENA SERGEEVA	{"phone": "+70905110596"}
0005435214624	125B66	9343 503128	SVETLANA SAVELEVA	{"email": "savelevasvetlana.1974@postgrespro.ru", "phone": "+70127780510"}
0005435214625	62CE77	1826 687821	IRINA ROMANOVA	{"phone": "+70301669166"}
0005435214626	C3BA55	2523 080784	ZAKHAR ALEKSEEV	{"phone": "+70735289545"}
0005435214627	621C7C	2502 808985	SVETLANA NESTEROVA	{"email": "nesterova_s-071965@postgrespro.ru", "phone": "+70898814603"}
0005435214628	621C7C	5617 132456	SERGEY ZAYCEV	{"phone": "+70594845101"}
0005435214629	077C68	1046 489218	VALENTINA KAZAKOVA	{"phone": "+70319021584"}
0005435214630	C610F2	6629 900842	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr.06111979@postgrespro.ru", "phone": "+70165102688"}
0005435214631	1B8546	5511 009134	YULIYA SEMENOVA	{"phone": "+70596890430"}
0005435214632	1B8546	1406 836932	DARYA ANISIMOVA	{"email": "danisimova.1972@postgrespro.ru", "phone": "+70238608468"}
0005435214633	6E8509	0623 665232	VALENTINA SAVELEVA	{"phone": "+70459374729"}
0005435214634	81AA83	3821 512488	ANASTASIYA ZHUKOVA	{"email": "zhukova_a21081964@postgrespro.ru", "phone": "+70018730041"}
0005435214635	252D62	2966 858490	RENAT RODIONOV	{"phone": "+70471070676"}
0005435214636	15ECBB	2389 154261	ALEKSEY IVANOV	{"phone": "+70135744124"}
0005435214637	48F0A8	4312 979137	ALEKSANDR KUZMIN	{"email": "kuzmin.a15051983@postgrespro.ru", "phone": "+70993716098"}
0005435214638	38EE46	2757 224851	VLADIMIR SERGEEV	{"email": "sergeevv.19101974@postgrespro.ru", "phone": "+70245497156"}
0005435214639	7E0409	6833 226615	ALEKSEY MOROZOV	{"email": "aleksey-morozov22061964@postgrespro.ru", "phone": "+70231337515"}
0005435214640	95EFBF	3272 154925	VALENTINA VOLKOVA	{"email": "v_volkova_26011972@postgrespro.ru", "phone": "+70879872921"}
0005435214641	C9131C	3628 719336	ALEKSEY KUZNECOV	{"phone": "+70968558537"}
0005435214642	E8E2D2	2902 136443	LYUDMILA TIKHONOVA	{"email": "lyudmila.tikhonova_27051984@postgrespro.ru", "phone": "+70143519527"}
0005435214643	9866D7	1258 919301	IVAN MAKAROV	{"email": "makarov_ivan.021973@postgrespro.ru", "phone": "+70179996253"}
0005435214644	9866D7	8992 408553	ANDREY NOVIKOV	{"email": "novikov-andrey.1979@postgrespro.ru", "phone": "+70117161800"}
0005435214645	9FD421	2476 590414	ALEKSANDR GAVRILOV	{"email": "a.gavrilov_17011974@postgrespro.ru", "phone": "+70460767552"}
0005435214646	9FD421	1415 444607	ELENA RODIONOVA	{"phone": "+70194827520"}
0005435214647	FAD207	5833 851428	NIKITA ORLOV	{"phone": "+70173043824"}
0005435214648	92BCA7	8814 622634	SOFYA ARKHIPOVA	{"email": "sofya.arkhipova_1970@postgrespro.ru", "phone": "+70528113522"}
0005435214649	92BCA7	7180 977550	ALEKSEY SOROKIN	{"phone": "+70322329169"}
0005435214650	92BCA7	0988 120339	ANATOLIY IVANOV	{"email": "ivanov-anatoliy-1968@postgrespro.ru", "phone": "+70111753485"}
0005435214651	87459E	3739 089167	VALENTINA BELYAEVA	{"email": "belyaeva-v_081961@postgrespro.ru", "phone": "+70454761855"}
0005435214652	87459E	8187 248703	EVGENIY MOROZOV	{"phone": "+70986410221"}
0005435214653	3DAE70	5170 881762	ALEKSEY EGOROV	{"phone": "+70799885684"}
0005435214654	3DAE70	7290 343790	ANTON VLASOV	{"email": "vlasov-a_02011970@postgrespro.ru", "phone": "+70945689355"}
0005435214655	3DAE70	5044 723091	EKATERINA NESTEROVA	{"email": "nesterova-e.26081978@postgrespro.ru", "phone": "+70879671944"}
0005435214656	3C7F8D	5370 516284	NIKOLAY IVANOV	{"email": "nikolay_ivanov_111974@postgrespro.ru", "phone": "+70786035674"}
0005435214657	3C7F8D	9306 787624	SVETLANA MOISEEVA	{"email": "s_moiseeva.1975@postgrespro.ru", "phone": "+70092157092"}
0005435214658	B19BC2	8025 801795	SOFYA VLASOVA	{"email": "vlasovasofya.031987@postgrespro.ru", "phone": "+70856278786"}
0005435214659	B19BC2	5199 370725	DARYA GERASIMOVA	{"phone": "+70443461625"}
0005435214660	A45669	5614 448358	NIKITA MELNIKOV	{"phone": "+70164513103"}
0005435214661	A45669	7693 642827	VALENTINA KUZMINA	{"email": "v-kuzmina071963@postgrespro.ru", "phone": "+70742702841"}
0005435214662	88AA05	5632 166976	VADIM KISELEV	{"email": "kiselevv.02041961@postgrespro.ru", "phone": "+70507360136"}
0005435214663	E628C1	1874 215922	VLADIMIR ALEKSEEV	{"phone": "+70815066554"}
0005435214664	E628C1	5684 731938	ALEKSEY SCHERBAKOV	{"email": "scherbakov.aleksey.101971@postgrespro.ru", "phone": "+70999372611"}
0005435214665	F8B3B8	6075 095340	ALEKSANDR MAKAROV	{"phone": "+70554623342"}
0005435214666	41DB73	7239 228107	TATYANA SAVELEVA	{"phone": "+70365186801"}
0005435214667	8451EA	6243 212961	LYUBOV KUZNECOVA	{"phone": "+70670924070"}
0005435214668	8451EA	7198 476732	IVAN KONOVALOV	{"email": "ikonovalov.051979@postgrespro.ru", "phone": "+70869809185"}
0005435214669	F2ECBB	5739 267914	MARINA DANILOVA	{"email": "danilova_m_101964@postgrespro.ru", "phone": "+70315113607"}
0005435214670	5B9B7E	1680 060172	NADIYA ROMANOVA	{"email": "nadiya.romanova.1977@postgrespro.ru", "phone": "+70987230731"}
0005435214671	5B9B7E	2708 343395	ANTON SEMENOV	{"phone": "+70764792645"}
0005435214672	F5EEB8	6552 215254	SERGEY ZAKHAROV	{"phone": "+70216090517"}
0005435214673	4456D1	6785 278167	ANNA ALEKSANDROVA	{"phone": "+70052736568"}
0005435214674	A449E6	0041 063042	LYUBOV NAZAROVA	{"email": "nazarova-lyubov-051970@postgrespro.ru", "phone": "+70791243101"}
0005435214675	A449E6	0174 943679	ALEKSANDR PAVLOV	{"phone": "+70603122561"}
0005435214676	549091	6379 740165	TATYANA MEDVEDEVA	{"phone": "+70707577980"}
0005435214677	549091	3091 506167	ALEKSEY POPOV	{"email": "popov.a091971@postgrespro.ru", "phone": "+70111821273"}
0005435214678	012532	9802 336954	MARIYA ERMAKOVA	{"email": "m.ermakova_1967@postgrespro.ru", "phone": "+70056980040"}
0005435214679	012532	9744 532461	ALEKSANDRA KOZLOVA	{"email": "kozlova.a_011978@postgrespro.ru", "phone": "+70223925013"}
0005435214680	1590F2	9914 928458	ANDREY MAKSIMOV	{"email": "a_maksimov.20121974@postgrespro.ru", "phone": "+70946224388"}
0005435214681	DE90F6	8861 371712	VALERIY SOKOLOV	{"email": "sokolovvaleriy121968@postgrespro.ru", "phone": "+70396002979"}
0005435214682	DE90F6	8857 745127	IRINA ALEKSANDROVA	{"phone": "+70756243051"}
0005435214683	FAFC73	9046 341373	NATALYA NIKITINA	{"email": "natalya.nikitina27071962@postgrespro.ru", "phone": "+70738515930"}
0005435214684	F38FDF	9525 173565	EVGENIY KONOVALOV	{"phone": "+70712919192"}
0005435214685	F38FDF	7260 498628	KONSTANTIN KUZNECOV	{"phone": "+70813643567"}
0005435214686	4BD00E	0860 291149	NATALYA SEMENOVA	{"phone": "+70186351992"}
0005435214687	FE4954	1271 395974	ANASTASIYA KUZNECOVA	{"email": "kuznecova.a_07071972@postgrespro.ru", "phone": "+70423630972"}
0005435214688	A508DB	4429 040794	LYUBOV NIKIFOROVA	{"phone": "+70599307707"}
0005435214689	8E4F61	7530 105167	MARINA YAKOVLEVA	{"email": "yakovlevam1975@postgrespro.ru", "phone": "+70964859543"}
0005435214690	057A3B	1562 548512	VIKTOR FEDOROV	{"phone": "+70051460037"}
0005435214691	D9E9C0	4095 539187	GALINA MARTYNOVA	{"email": "martynova-g.041972@postgrespro.ru", "phone": "+70168834427"}
0005435214692	4206DC	2135 719285	ANGELINA ROMANOVA	{"email": "a.romanova_011969@postgrespro.ru", "phone": "+70109931034"}
0005435214693	BA7FAD	9946 807805	ALEKSANDR BELOV	{"phone": "+70593368764"}
0005435214694	BA7FAD	9603 532367	RUSLAN RODIONOV	{"email": "r-rodionov-1963@postgrespro.ru", "phone": "+70312630888"}
0005435214695	EF104E	3751 013130	TATYANA FADEEVA	{"email": "t-fadeeva.14091974@postgrespro.ru", "phone": "+70307076529"}
0005435214696	FEE918	7079 987029	ANTON NAZAROV	{"email": "antonnazarov_051980@postgrespro.ru", "phone": "+70024820197"}
0005435214697	FEE918	5540 065249	SERGEY ALEKSEEV	{"phone": "+70432001422"}
0005435214698	D67E83	3373 511943	NADEZHDA FEDOROVA	{"phone": "+70529157530"}
0005435214699	D67E83	4025 825972	VLADIMIR BORISOV	{"phone": "+70585170561"}
0005435214700	0301AF	0818 772255	IVAN KUZNECOV	{"phone": "+70734584578"}
0005435214701	0298CD	3899 465863	NATALIYA OSIPOVA	{"email": "n_osipova.021965@postgrespro.ru", "phone": "+70126805985"}
0005435214702	529CE6	6818 039088	ANASTASIYA GAVRILOVA	{"email": "a_gavrilova041967@postgrespro.ru", "phone": "+70366406532"}
0005435214703	ED5140	1783 451036	OLEG SOKOLOV	{"email": "sokolov_o-06101975@postgrespro.ru", "phone": "+70064691282"}
0005435214704	4ADD33	7817 158147	ANNA LUKYANOVA	{"phone": "+70478962535"}
0005435214705	4ADD33	5586 285150	DARYA DANILOVA	{"email": "danilova_darya_16031968@postgrespro.ru", "phone": "+70788428951"}
0005435214706	690BF5	4360 568396	TAMARA KUZNECOVA	{"phone": "+70674205250"}
0005435214707	690BF5	4692 647073	LYUBOV LEBEDEVA	{"phone": "+70428004373"}
0005435214708	FDF630	1963 170812	GENNADIY GRIGOREV	{"email": "grigorev.gennadiy-091972@postgrespro.ru", "phone": "+70335711767"}
0005435214709	FDF630	8334 676845	ELENA ABRAMOVA	{"email": "elenaabramova01071966@postgrespro.ru", "phone": "+70624856753"}
0005435214710	370C67	6093 312836	EVGENIYA MAKSIMOVA	{"email": "maksimova-evgeniya.091963@postgrespro.ru", "phone": "+70613886225"}
0005435214711	370C67	0575 481952	ANNA KONOVALOVA	{"phone": "+70643465238"}
0005435214712	8D0D0C	4541 781842	ALEKSANDR KAZAKOV	{"phone": "+70738748059"}
0005435214713	862697	1673 782839	VLADIMIR ZAKHAROV	{"email": "vladimir_zakharov-02081970@postgrespro.ru", "phone": "+70512102959"}
0005435214714	6A32FA	4410 536822	IRINA NAZAROVA	{"email": "nazarovairina-1964@postgrespro.ru", "phone": "+70185557435"}
0005435214715	54A73F	8372 386874	KSENIYA NOVIKOVA	{"phone": "+70217014209"}
0005435214716	55CBE2	9759 063897	KRISTINA ALEKSEEVA	{"phone": "+70003905356"}
0005435214717	0A4643	7764 961045	ALEKSANDR KOZLOV	{"email": "aleksandr_kozlov.111979@postgrespro.ru", "phone": "+70882577583"}
0005435214718	0A4643	9624 224481	TATYANA SERGEEVA	{"phone": "+70801740851"}
0005435214719	0A4643	5392 331685	EVGENIY GORBUNOV	{"phone": "+70730536241"}
0005435214720	428289	8069 228318	ELENA ANDREEVA	{"email": "andreeva-e071971@postgrespro.ru", "phone": "+70613731167"}
0005435214721	FC9572	6807 865582	LEONID TIKHONOV	{"phone": "+70876289223"}
0005435214722	01C89C	2876 419512	ALEKSANDR MAKAROV	{"phone": "+70694634699"}
0005435214723	C40E31	1864 271947	NATALYA KISELEVA	{"email": "natalya.kiseleva04101977@postgrespro.ru", "phone": "+70184024220"}
0005435214724	C22C1E	0146 304771	VALENTINA AKIMOVA	{"email": "akimova-valentina_101967@postgrespro.ru", "phone": "+70433479760"}
0005435214725	1FEF25	1268 422893	TATYANA PAVLOVA	{"phone": "+70671254058"}
0005435214726	641485	6383 864512	ANDREY SAVELEV	{"email": "a-savelev-1972@postgrespro.ru", "phone": "+70516906705"}
0005435214727	641485	9525 003544	KONSTANTIN GUSEV	{"phone": "+70870002485"}
0005435214728	8BEE1E	4343 828522	LARISA VLASOVA	{"phone": "+70034164206"}
0005435214729	19C5B0	7500 487395	ANASTASIYA LEBEDEVA	{"phone": "+70115894529"}
0005435214730	007407	3712 493703	VIKTORIYA IVANOVA	{"email": "viktoriya.ivanova-021970@postgrespro.ru", "phone": "+70303348520"}
0005435214731	6E1CC1	1349 336498	ALEKSEY ANDREEV	{"email": "aandreev27121965@postgrespro.ru", "phone": "+70129099545"}
0005435214732	557E7E	0477 026389	ELENA SIDOROVA	{"email": "sidorovaelena17031973@postgrespro.ru", "phone": "+70532590159"}
0005435214733	51B34B	3575 545987	DMITRIY MARTYNOV	{"phone": "+70517712585"}
0005435214734	51B34B	2474 478233	VERA TROFIMOVA	{"email": "trofimova_v1965@postgrespro.ru", "phone": "+70271847093"}
0005435214735	05FA54	0061 176750	GALINA MIKHAYLOVA	{"phone": "+70633861746"}
0005435214736	110A6F	4863 918842	VALENTINA SOLOVEVA	{"phone": "+70449276850"}
0005435214737	C9ADD1	5457 072553	EVGENIY PAVLOV	{"phone": "+70565954021"}
0005435214738	41B244	9919 457030	OLGA NIKOLAEVA	{"email": "nikolaeva.olga1966@postgrespro.ru", "phone": "+70578282236"}
0005435214739	41B244	3792 889486	ALEKSANDR VOROBEV	{"email": "vorobev_a061975@postgrespro.ru", "phone": "+70912810248"}
0005435214740	813433	5657 523246	ANTON ANDREEV	{"email": "andreev.a19031969@postgrespro.ru", "phone": "+70537386415"}
0005435214741	49A498	0451 796441	OLGA ANDREEVA	{"email": "olga_andreeva_1974@postgrespro.ru", "phone": "+70417738532"}
0005435214742	49A498	1272 953577	VALERIY TARASOV	{"email": "valeriy_tarasov-1966@postgrespro.ru", "phone": "+70389012753"}
0005435214743	43CB2D	6518 287329	LYUDMILA VASILEVA	{"phone": "+70249898823"}
0005435214744	77E5F6	6132 164412	MIKHAIL TARASOV	{"email": "mikhail_tarasov101971@postgrespro.ru", "phone": "+70510915432"}
0005435214745	05F82C	6106 445151	TATYANA SOROKINA	{"email": "tatyanasorokina_05101976@postgrespro.ru", "phone": "+70963619718"}
0005435214746	222A60	9848 113612	EKATERINA MAKAROVA	{"phone": "+70500039966"}
0005435214747	222A60	6969 530150	SERGEY VOROBEV	{"email": "svorobev19021975@postgrespro.ru", "phone": "+70225966014"}
0005435214748	36CF80	9845 716596	VLADIMIR ZAYCEV	{"phone": "+70604928839"}
0005435214749	0E1E9E	1024 715125	NADEZHDA VASILEVA	{"phone": "+70116908441"}
0005435214750	9105A1	0565 964699	VADIM SAVELEV	{"email": "vadim-savelev.1975@postgrespro.ru", "phone": "+70570720794"}
0005435214751	C09684	4564 528180	OKSANA GERASIMOVA	{"email": "gerasimova.oksana_021978@postgrespro.ru", "phone": "+70215702198"}
0005435214752	4B3DF6	3128 971063	OLGA SAVELEVA	{"phone": "+70268934715"}
0005435214753	9A2AE3	5396 679089	TAMARA GERASIMOVA	{"phone": "+70376405643"}
0005435214754	5348BB	9282 970141	GALIYA EGOROVA	{"phone": "+70903961923"}
0005435214755	AF047F	1672 684944	VALENTINA KOROLEVA	{"email": "koroleva_valentina_25121985@postgrespro.ru", "phone": "+70404965717"}
0005435214756	AF047F	3737 593925	VLADIMIR FILIPPOV	{"email": "filippov.v-1968@postgrespro.ru", "phone": "+70762205318"}
0005435214757	A05001	9361 798266	SVETLANA MAKSIMOVA	{"phone": "+70631051172"}
0005435214758	E42DA2	2939 933976	MIKHAIL TIKHONOV	{"email": "tikhonov-mikhail.1979@postgrespro.ru", "phone": "+70290514867"}
0005435214759	EFBE48	2561 303013	ARTEM ROMANOV	{"email": "a_romanov.1965@postgrespro.ru", "phone": "+70035020056"}
0005435214760	2EB7D9	6139 618453	SERGEY SERGEEV	{"phone": "+70321690946"}
0005435214761	5853B2	0359 896848	MIKHAIL KONOVALOV	{"email": "konovalov.m_031979@postgrespro.ru", "phone": "+70085906690"}
0005435214762	2B388C	3287 881390	OLGA BARANOVA	{"phone": "+70899324391"}
0005435214763	E0407A	0761 871811	VIKTOR ZAKHAROV	{"email": "zakharovviktor05011964@postgrespro.ru", "phone": "+70079232383"}
0005435214764	58F15F	4299 183927	EGOR MAKAROV	{"phone": "+70016559120"}
0005435214765	FC0102	1703 199293	TATYANA KUZNECOVA	{"phone": "+70228506156"}
0005435214766	127D24	7767 958058	IRINA TIKHONOVA	{"email": "itikhonova.121967@postgrespro.ru", "phone": "+70106016803"}
0005435214767	CAE1CE	6456 991082	NIKOLAY KUZMIN	{"phone": "+70020887586"}
0005435214768	03C94F	2268 934972	SERGEY KOROLEV	{"phone": "+70781310799"}
0005435214769	03C94F	7388 280923	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova_22041981@postgrespro.ru", "phone": "+70761741465"}
0005435214770	502060	6213 034219	EVGENIYA FILIPPOVA	{"email": "filippovaevgeniya-01021973@postgrespro.ru", "phone": "+70516838636"}
0005435214771	502060	2205 532192	SERGEY MOISEEV	{"email": "s_moiseev_111978@postgrespro.ru", "phone": "+70795889408"}
0005435214772	502060	8004 008901	VERA KONDRATEVA	{"email": "vera_kondrateva19071971@postgrespro.ru", "phone": "+70188253250"}
0005435214773	B60A7D	7290 921211	LYUBOV BORISOVA	{"phone": "+70892151188"}
0005435214774	10078B	7376 750016	RAFIK FILIPPOV	{"email": "rfilippov.27021973@postgrespro.ru", "phone": "+70596286276"}
0005435214775	BEE281	2955 634894	VLADISLAV PAVLOV	{"email": "pavlov-vladislav021992@postgrespro.ru", "phone": "+70279274351"}
0005435214776	3E762E	3382 908131	KSENIYA SOROKINA	{"email": "sorokinakseniya_1977@postgrespro.ru", "phone": "+70999142566"}
0005435214777	0FDD07	8403 258407	ANASTASIYA MOISEEVA	{"email": "moiseevaa021981@postgrespro.ru", "phone": "+70987050082"}
0005435214778	95A238	7438 684112	KONSTANTIN ZAKHAROV	{"email": "k.zakharov_01051968@postgrespro.ru", "phone": "+70341324077"}
0005435214779	D0AC32	3712 148980	GALINA STEPANOVA	{"email": "galina-stepanova1973@postgrespro.ru", "phone": "+70306231788"}
0005435214780	5EFB37	1841 618960	NATALYA ANTONOVA	{"phone": "+70575534020"}
0005435214781	77FF5D	7278 150796	SERGEY ANTONOV	{"phone": "+70525502269"}
0005435214782	3E1DC1	2746 507897	STEPAN ZAKHAROV	{"phone": "+70692108473"}
0005435214783	DF85D7	6606 352455	YURIY TIMOFEEV	{"email": "yuriy-timofeev-1984@postgrespro.ru", "phone": "+70037829663"}
0005435214784	DF85D7	5431 486325	YULIYA TITOVA	{"phone": "+70760441056"}
0005435214785	DF85D7	7538 917557	IRINA ROMANOVA	{"phone": "+70024994077"}
0005435214786	7896ED	9797 103754	FEDOR FROLOV	{"phone": "+70085777034"}
0005435214787	7896ED	0370 392968	ANATOLIY BORISOV	{"phone": "+70205085837"}
0005435214788	17B394	6268 714382	ROMAN VASILEV	{"phone": "+70761541919"}
0005435214789	F61FCF	0459 561103	VYACHESLAV TARASOV	{"phone": "+70357155066"}
0005435214790	8FD9A1	3479 648317	MAKSIM NAUMOV	{"email": "naumov.maksim1970@postgrespro.ru", "phone": "+70583826667"}
0005435214791	DBDF68	5035 571686	KRISTINA MEDVEDEVA	{"email": "kristina-medvedeva_22031985@postgrespro.ru", "phone": "+70487033690"}
0005435214792	DBDF68	8267 750510	DIANA MAKSIMOVA	{"phone": "+70406628736"}
0005435214793	4BCBFD	8829 619106	NINA GAVRILOVA	{"phone": "+70172565146"}
0005435214794	4BCBFD	0175 456659	IRINA NIKITINA	{"phone": "+70752139385"}
0005435214795	9BC3A8	7777 002035	ALEKSEY BONDARENKO	{"phone": "+70170979659"}
0005435214796	8584D1	9988 432912	VITALIY DAVYDOV	{"email": "davydov-v.14091969@postgrespro.ru", "phone": "+70031132107"}
0005435214797	EC8268	8039 898980	VLADIMIR ZHUKOV	{"email": "zhukovv.15091973@postgrespro.ru", "phone": "+70785357774"}
0005435214798	EC8268	0050 347699	VLADIMIR PETROV	{"phone": "+70348353971"}
0005435214799	E47F5A	0442 849335	GENNADIY VOROBEV	{"email": "vorobev_g-24071969@postgrespro.ru", "phone": "+70093781205"}
0005435214800	346470	2706 943832	KRISTINA ALEKSEEVA	{"phone": "+70971662815"}
0005435214801	9B4DCA	6706 335278	EDUARD NAZAROV	{"phone": "+70098746249"}
0005435214802	12F0EE	3794 347726	MIKHAIL KUZNECOV	{"email": "kuznecov.m.1962@postgrespro.ru", "phone": "+70489878633"}
0005435214803	1E589E	5301 005596	ANASTASIYA FILIPPOVA	{"email": "anastasiya_filippova091964@postgrespro.ru", "phone": "+70550486354"}
0005435214804	3A62EA	6426 285981	ANATOLIY BORISOV	{"email": "anatoliy-borisov-1968@postgrespro.ru", "phone": "+70908796161"}
0005435214805	8D72FC	5840 141417	NATALYA BELOVA	{"email": "natalyabelova1966@postgrespro.ru", "phone": "+70613587211"}
0005435214806	82BADE	3344 420478	VALENTINA FILIPPOVA	{"phone": "+70776287571"}
0005435214807	82BADE	3988 371709	VLADIMIR ABRAMOV	{"email": "abramov_v.021972@postgrespro.ru", "phone": "+70211573728"}
0005435214808	D42165	8672 175581	OLGA GERASIMOVA	{"phone": "+70917537875"}
0005435214809	3BE88B	7804 050620	VLADIMIR VASILEV	{"phone": "+70067292359"}
0005435214810	CBC818	4397 938858	EVGENIY VASILEV	{"phone": "+70459966303"}
0005435214811	C62E40	7419 656639	IRINA IVANOVA	{"phone": "+70785672499"}
0005435214812	F14FC1	7695 816675	ELENA LOGINOVA	{"email": "elenaloginova_101969@postgrespro.ru", "phone": "+70039821407"}
0005435214813	1664E9	3019 071677	VLADISLAV STEPANOV	{"email": "vladislavstepanov07091970@postgrespro.ru", "phone": "+70086535894"}
0005435214814	6C05B7	5400 430785	ALEKSANDR IVANOV	{"phone": "+70771694787"}
0005435214815	A2D7DA	9108 668196	YURIY KONOVALOV	{"email": "konovalov.yuriy-041980@postgrespro.ru", "phone": "+70365533275"}
0005435214816	A2D7DA	4117 445099	IVAN GRIGOREV	{"phone": "+70793466357"}
0005435214817	65F345	7340 416793	TATYANA MIKHAYLOVA	{"email": "mikhaylova-tatyana101981@postgrespro.ru", "phone": "+70704826844"}
0005435214818	DCB153	4581 765015	KIRILL SOLOVEV	{"phone": "+70530897356"}
0005435214819	DCB153	5310 187015	OLESYA ZAYCEVA	{"email": "zayceva-olesya05101974@postgrespro.ru", "phone": "+70545909361"}
0005435214820	DCB153	0693 212966	ARTUR KUZNECOV	{"email": "artur-kuznecov-1968@postgrespro.ru", "phone": "+70177805478"}
0005435214821	ABBF20	0913 471675	SERGEY POPOV	{"email": "s_popov_06091964@postgrespro.ru", "phone": "+70183696535"}
0005435214822	ABBF20	8101 904193	EVGENIY MIKHAYLOV	{"email": "mikhaylov.e.26011982@postgrespro.ru", "phone": "+70596148841"}
0005435214823	2BAF74	1980 828670	DIANA FROLOVA	{"phone": "+70441722863"}
0005435214824	941480	4245 659921	ALISA IVANOVA	{"email": "alisa_ivanova1968@postgrespro.ru", "phone": "+70846638970"}
0005435214825	B2A62D	7241 025821	EVGENIY PETROV	{"email": "e-petrov_25071970@postgrespro.ru", "phone": "+70847411097"}
0005435214826	B2A62D	4648 493649	ELENA VASILEVA	{"email": "elena_vasileva.061970@postgrespro.ru", "phone": "+70180510277"}
0005435214827	5A0ECC	9996 984065	ELENA IVANOVA	{"phone": "+70866330037"}
0005435214828	5A0ECC	0281 113551	VALERIYA IVANOVA	{"phone": "+70767644826"}
0005435214829	689A48	5517 462894	MAKSIM KOZLOV	{"email": "maksim-kozlov20061974@postgrespro.ru", "phone": "+70892354762"}
0005435214830	BB0D2E	2579 991308	NATALYA ZOTOVA	{"phone": "+70559405129"}
0005435214831	F535BA	5261 951554	YURIY ISAEV	{"email": "yuriy_isaev.081969@postgrespro.ru", "phone": "+70161963059"}
0005435214832	6A84BA	9042 117469	IVAN RODIONOV	{"email": "rodionov_i081971@postgrespro.ru", "phone": "+70014381928"}
0005435214833	6A84BA	7241 507368	VARVARA VOLKOVA	{"phone": "+70415840901"}
0005435214834	AEBD34	5217 198467	SERGEY RODIONOV	{"email": "s_rodionov25031971@postgrespro.ru", "phone": "+70097547898"}
0005435214835	DD1461	7792 716075	SERGEY SCHERBAKOV	{"email": "scherbakov_s-14051981@postgrespro.ru", "phone": "+70204128091"}
0005435214836	D74B9F	9135 536925	LYUBOV IVANOVA	{"phone": "+70273173343"}
0005435214837	3C3AE8	0159 263087	MAKSIM FOMIN	{"phone": "+70201461020"}
0005435214838	3C3AE8	9187 737356	EVGENIYA YUDINA	{"phone": "+70857524548"}
0005435214839	488A77	8262 160230	TATYANA TARASOVA	{"email": "tarasova-tatyana101972@postgrespro.ru", "phone": "+70242118171"}
0005435214840	BA5A60	7367 484753	SERGEY IVANOV	{"phone": "+70567001600"}
0005435214841	BA5A60	1749 915723	MIKHAIL IVANOV	{"phone": "+70086813762"}
0005435214842	BBA20D	2010 086897	NATALYA NIKITINA	{"email": "natalya.nikitina-1975@postgrespro.ru", "phone": "+70246065856"}
0005435214843	67F411	4178 810472	ALEKSANDR VOROBEV	{"email": "vorobevaleksandr-1966@postgrespro.ru", "phone": "+70895977722"}
0005435214844	10CAA7	2877 895865	SVETLANA NIKITINA	{"phone": "+70699545822"}
0005435214845	D90D76	6044 437439	TIMUR KUZMIN	{"email": "kuzmin.t-011976@postgrespro.ru", "phone": "+70198583397"}
0005435214846	006F16	8137 180131	VLADISLAV RODIONOV	{"email": "rodionov-v-07111974@postgrespro.ru", "phone": "+70491805598"}
0005435214847	EBC5D0	5498 845300	MAKSIM KUZMIN	{"phone": "+70245434229"}
0005435214848	6C0E76	1592 584536	ANNA SERGEEVA	{"phone": "+70406372334"}
0005435214849	3B0309	6654 667655	NATALYA ZHURAVLEVA	{"email": "zhuravleva_n.11101970@postgrespro.ru", "phone": "+70021538797"}
0005435214850	3B0309	0674 068161	VERONIKA NAZAROVA	{"phone": "+70403127885"}
0005435214851	3B0309	3740 992503	NATALIYA MELNIKOVA	{"email": "nataliya_melnikova-1955@postgrespro.ru", "phone": "+70763750886"}
0005435214852	B14A70	8158 143515	MARINA IVANOVA	{"email": "marina_ivanova_15121979@postgrespro.ru", "phone": "+70765521198"}
0005435214853	A87D11	6481 787809	ALEKSANDR GUSEV	{"phone": "+70417226756"}
0005435214854	07FCE3	7329 275490	LILIYA SIDOROVA	{"phone": "+70045556686"}
0005435214855	61B8D7	7390 021870	ANNA MARTYNOVA	{"email": "martynova_anna_091962@postgrespro.ru", "phone": "+70078694008"}
0005435214856	D776D5	7228 454377	LIDIYA TIKHONOVA	{"email": "tikhonovalidiya1971@postgrespro.ru", "phone": "+70083731861"}
0005435214857	D776D5	1080 746273	ANATOLIY VOROBEV	{"phone": "+70004756892"}
0005435214858	63B89C	9296 189015	NATALYA MATVEEVA	{"phone": "+70824622179"}
0005435214859	EFD261	2244 707137	ELVIRA FROLOVA	{"email": "elvirafrolova_1972@postgrespro.ru", "phone": "+70653329086"}
0005435214860	EFD261	5803 987961	MARK EGOROV	{"email": "egorov.mark_01081976@postgrespro.ru", "phone": "+70672062958"}
0005435214861	B97041	0397 256564	MARINA IVANOVA	{"phone": "+70439987960"}
0005435214862	B97041	3332 814542	ALEKSEY BORISOV	{"email": "aleksey.borisov1967@postgrespro.ru", "phone": "+70605232106"}
0005435214863	89D0A6	4538 201337	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr15091976@postgrespro.ru", "phone": "+70765883597"}
0005435214864	CA611F	0673 967135	ANDREY ALEKSEEV	{"phone": "+70631716531"}
0005435214865	CA611F	2415 827316	ALEKSANDR GORBUNOV	{"phone": "+70024425617"}
0005435214866	2ECB0D	2004 941554	VALENTINA FROLOVA	{"email": "valentina_frolova_101972@postgrespro.ru", "phone": "+70046903168"}
0005435214867	A868BD	1154 400075	SERGEY AFANASEV	{"email": "s-afanasev-1958@postgrespro.ru", "phone": "+70113362925"}
0005435214868	140CA5	1597 594738	EVGENIYA DANILOVA	{"email": "e.danilova_04081970@postgrespro.ru", "phone": "+70923864679"}
0005435214869	140CA5	2995 970080	VALERIY IVANOV	{"email": "v-ivanov021977@postgrespro.ru", "phone": "+70854847164"}
0005435214870	FC6578	8775 842405	LARISA MIRONOVA	{"email": "mironova_larisa011978@postgrespro.ru", "phone": "+70681525802"}
0005435214871	8C8339	6672 972141	MIKHAIL FOMIN	{"email": "mikhail-fomin.25061960@postgrespro.ru", "phone": "+70673011252"}
0005435214872	8C8339	4590 141866	ANDREY KRASNOV	{"email": "krasnov-andrey.081979@postgrespro.ru", "phone": "+70262387086"}
0005435214873	9FC1DD	8602 540720	MAKSIM KRASNOV	{"phone": "+70916182165"}
0005435214874	613C02	0466 304082	ARMEN KOZLOV	{"phone": "+70063214395"}
0005435214875	CBB265	9466 370144	DMITRIY TARASOV	{"email": "dmitriytarasov_061976@postgrespro.ru", "phone": "+70772553103"}
0005435214876	E38055	6168 308062	ANNA ALEKSEEVA	{"phone": "+70794614652"}
0005435214877	E38055	0627 565122	MIKHAIL SMIRNOV	{"phone": "+70576343356"}
0005435214878	AFDB36	1220 564157	ANASTASIYA BORISOVA	{"phone": "+70206120653"}
0005435214879	AFDB36	2110 058701	VASILIY NIKOLAEV	{"phone": "+70440651605"}
0005435214880	4EF0CE	5380 486895	YURIY POPOV	{"email": "yuriy-popov_08091975@postgrespro.ru", "phone": "+70420637770"}
0005435214881	0B3B85	2755 548369	VLADIMIR MOISEEV	{"email": "vladimir-moiseev_1970@postgrespro.ru", "phone": "+70716780161"}
0005435214882	0B3B85	0664 002212	ALBERT RODIONOV	{"phone": "+70729784146"}
0005435214883	22577A	8111 524465	ANNA BELOVA	{"email": "belova_anna_1970@postgrespro.ru", "phone": "+70972081952"}
0005435214884	918CC1	8775 429263	IRINA TIKHONOVA	{"phone": "+70482279348"}
0005435214885	0DDF88	3130 181216	LYUDMILA VOLKOVA	{"email": "volkoval1981@postgrespro.ru", "phone": "+70648225268"}
0005435214886	92FF01	0552 301443	ANATOLIY TARASOV	{"email": "tarasova.1964@postgrespro.ru", "phone": "+70894716411"}
0005435214887	2190E1	5238 980449	TATYANA FOMINA	{"phone": "+70182997900"}
0005435214888	1FDDDF	5426 711805	LYUBOV LUKYANOVA	{"email": "lukyanova-l_1981@postgrespro.ru", "phone": "+70332455674"}
0005435214889	1FDDDF	9713 926236	ANATOLIY IVANOV	{"email": "ivanovanatoliy.04091972@postgrespro.ru", "phone": "+70587594949"}
0005435214890	43D83A	6298 698789	LYUBOV POPOVA	{"phone": "+70559091990"}
0005435214891	43D83A	5459 125068	MIKHAIL SEMENOV	{"email": "semenov_m.1955@postgrespro.ru", "phone": "+70230487833"}
0005435214892	43D83A	4522 362263	ARINA VASILEVA	{"email": "arina_vasileva-071981@postgrespro.ru", "phone": "+70052968742"}
0005435214893	75E918	8928 071081	ANATOLIY VASILEV	{"email": "anatoliyvasilev_10121979@postgrespro.ru", "phone": "+70526246881"}
0005435214894	75E918	5107 304649	RAISA SOROKINA	{"email": "r.sorokina27121972@postgrespro.ru", "phone": "+70735642098"}
0005435214895	D27A7E	0862 019871	ALEKSEY CHERNOV	{"phone": "+70560400231"}
0005435214896	F5AA81	5212 130500	EVDOKIYA VLASOVA	{"email": "evdokiyavlasova1979@postgrespro.ru", "phone": "+70068078277"}
0005435214897	F5AA81	5952 538832	PETR POPOV	{"email": "popovpetr_111974@postgrespro.ru", "phone": "+70059665480"}
0005435214898	D1A0DC	7084 690636	ALEKSANDR ROMANOV	{"phone": "+70684738973"}
0005435214899	D1A0DC	4785 603538	VALENTINA VOROBEVA	{"email": "vorobeva.v-30041978@postgrespro.ru", "phone": "+70967059691"}
0005435214900	A48764	3478 517608	ALEKSANDR ZAKHAROV	{"phone": "+70635643034"}
0005435214901	874F65	1537 788683	DMITRIY POPOV	{"email": "popov-dmitriy.1976@postgrespro.ru", "phone": "+70572051973"}
0005435214902	874F65	1603 151486	RAFAEL MIKHAYLOV	{"phone": "+70806675982"}
0005435214903	12E819	9167 442612	IRINA KUZMINA	{"phone": "+70282461193"}
0005435214904	FF95AE	3639 049653	ANASTASIYA TIMOFEEVA	{"email": "anastasiyatimofeeva_091981@postgrespro.ru", "phone": "+70357626931"}
0005435214905	FF95AE	9284 397818	NATALYA MIKHAYLOVA	{"phone": "+70154784812"}
0005435214906	A9EE26	3607 783725	LYUBOV DANILOVA	{"phone": "+70763565918"}
0005435214907	9B2C3C	8359 789107	SERGEY FOMIN	{"phone": "+70252741910"}
0005435214908	820978	7242 152619	VADIM GAVRILOV	{"email": "vadimgavrilov-1974@postgrespro.ru", "phone": "+70222771552"}
0005435214909	820978	0632 504523	SVETLANA POPOVA	{"email": "popova_svetlana_101969@postgrespro.ru", "phone": "+70982025952"}
0005435214910	902B2D	1339 993377	TAMARA PAVLOVA	{"phone": "+70265015829"}
0005435214911	9097C6	6264 290314	ELENA MIRONOVA	{"phone": "+70052432126"}
0005435214912	9097C6	5384 570901	GALINA VOLKOVA	{"phone": "+70218660088"}
0005435214913	602F4C	3687 696853	EVGENIY DAVYDOV	{"email": "davydove_121957@postgrespro.ru", "phone": "+70046775505"}
0005435214914	6EAA35	7573 282335	MARIYA NAUMOVA	{"email": "mnaumova041976@postgrespro.ru", "phone": "+70497100225"}
0005435214915	6EAA35	4866 754146	VERA NIKOLAEVA	{"phone": "+70383432534"}
0005435214916	AED5F6	5992 945179	OLGA KONDRATEVA	{"email": "kondrateva-olga_28111975@postgrespro.ru", "phone": "+70800661879"}
0005435214917	AED5F6	7902 979191	ANDREY SOKOLOV	{"phone": "+70175822951"}
0005435214918	E5556A	9338 837512	TATYANA BELYAEVA	{"email": "belyaeva-t21111970@postgrespro.ru", "phone": "+70811623745"}
0005435214919	673ED0	0111 236576	SVETLANA ZAKHAROVA	{"phone": "+70652001581"}
0005435214920	DD537E	7101 046005	VYACHESLAV PETROV	{"phone": "+70883860534"}
0005435214921	71ADD2	5271 298752	TATYANA POPOVA	{"email": "tatyana.popova_111983@postgrespro.ru", "phone": "+70887305155"}
0005435214922	96562E	7620 401891	GALINA GERASIMOVA	{"phone": "+70477359056"}
0005435214923	96562E	3402 059292	LYUBOV ABRAMOVA	{"email": "l.abramova-091974@postgrespro.ru", "phone": "+70739148670"}
0005435214924	2A8CD9	8676 930736	VLADIMIR NOVIKOV	{"email": "v_novikov.16081967@postgrespro.ru", "phone": "+70653835568"}
0005435214925	FB9A55	9831 774146	IVAN KUZNECOV	{"phone": "+70877657804"}
0005435214926	E7B286	4545 890230	TIMUR EGOROV	{"email": "egorov_t_031968@postgrespro.ru", "phone": "+70506063619"}
0005435214927	3410FF	1198 490383	ELIZAVETA ROMANOVA	{"email": "romanova_elizaveta_111970@postgrespro.ru", "phone": "+70561359773"}
0005435214928	3410FF	3304 849821	VALERIY DENISOV	{"phone": "+70378227083"}
0005435214929	C86620	2566 294602	SERGEY ALEKSANDROV	{"email": "sergey-aleksandrov_1980@postgrespro.ru", "phone": "+70602154097"}
0005435214930	4FDFEE	3109 692951	POLINA KONOVALOVA	{"phone": "+70927199267"}
0005435214931	9D1E79	4159 118719	GRIGORIY POPOV	{"email": "g.popov.061964@postgrespro.ru", "phone": "+70112978414"}
0005435214932	9D1E79	7377 936454	ANASTASIYA SIDOROVA	{"email": "anastasiya_sidorova.1969@postgrespro.ru", "phone": "+70721466803"}
0005435214933	DB493C	5566 956260	ROSTISLAV KONOVALOV	{"phone": "+70541314343"}
0005435214934	762A1E	3520 410784	ARKADIY GERASIMOV	{"phone": "+70981629930"}
0005435214935	762A1E	9352 018286	DMITRIY ALEKSANDROV	{"phone": "+70007542636"}
0005435214936	23D17C	2642 172963	OLESYA KUDRYASHOVA	{"email": "olesyakudryashova-1988@postgrespro.ru", "phone": "+70616501090"}
0005435214937	FC1117	0159 332607	GALINA VASILEVA	{"phone": "+70625189245"}
0005435214938	C765C3	6245 608338	ALLA YAKOVLEVA	{"email": "yakovleva-a.1969@postgrespro.ru", "phone": "+70474501146"}
0005435214939	C765C3	8232 214014	ALEKSANDR GERASIMOV	{"phone": "+70330537755"}
0005435214940	C765C3	3478 700850	EKATERINA AFANASEVA	{"phone": "+70344126492"}
0005435214941	09FA85	6573 261193	YURIY KOZLOV	{"phone": "+70027618068"}
0005435214942	09FA85	4106 612260	ALEKSANDR KAZAKOV	{"email": "aleksandr-kazakov.23041971@postgrespro.ru", "phone": "+70782518226"}
0005435214943	09FA85	3177 328120	VALERIY SHEVCHENKO	{"phone": "+70372274511"}
0005435214944	F26597	9725 702426	VALENTINA ALEKSEEVA	{"email": "alekseeva.v-05111979@postgrespro.ru", "phone": "+70118040899"}
0005435214945	1BB654	3622 380353	ALINA POPOVA	{"email": "popova.a-04011996@postgrespro.ru", "phone": "+70511495646"}
0005435214946	613CEA	4877 014784	ELENA NIKITINA	{"phone": "+70040521147"}
0005435214947	613CEA	9108 407708	KSENIYA FADEEVA	{"email": "fadeeva-kseniya-26031975@postgrespro.ru", "phone": "+70346141947"}
0005435214948	3552E1	4435 566381	ALENA YAKOVLEVA	{"email": "yakovleva_a-071972@postgrespro.ru", "phone": "+70136091203"}
0005435214949	85428A	6133 962783	ANDREY IVANOV	{"email": "ivanova.10081962@postgrespro.ru", "phone": "+70059441560"}
0005435214950	4239FF	9377 564813	IRINA ABRAMOVA	{"email": "abramova_i.1958@postgrespro.ru", "phone": "+70977789507"}
0005435214951	C40254	3388 076552	OLGA DENISOVA	{"email": "olgadenisova-1967@postgrespro.ru", "phone": "+70801879662"}
0005435214952	DC82F3	8084 265522	VYACHESLAV PETROV	{"phone": "+70058684946"}
0005435214953	A0C99E	4960 860458	VLADIMIR KRASNOV	{"phone": "+70525727699"}
0005435214954	D31C03	4322 617205	KARINA MOISEEVA	{"email": "k-moiseeva_24081964@postgrespro.ru", "phone": "+70579822322"}
0005435214955	AB2438	7613 537871	YULIYA MEDVEDEVA	{"phone": "+70556918866"}
0005435214956	BFEC5D	1093 982029	LYUDMILA POPOVA	{"email": "l.popova081975@postgrespro.ru", "phone": "+70685057755"}
0005435214957	F494F1	0390 619189	LYUDMILA KONDRATEVA	{"phone": "+70451200004"}
0005435214958	F494F1	7763 681222	DIANA KUZMINA	{"phone": "+70641510679"}
0005435214959	07290C	9048 319044	NATALYA SAVELEVA	{"email": "nsaveleva-11051966@postgrespro.ru", "phone": "+70771216044"}
0005435214960	6A8536	2038 542802	EKATERINA SIDOROVA	{"phone": "+70392155345"}
0005435214961	58FA23	4997 580339	EKATERINA SOROKINA	{"email": "sorokina_e-071968@postgrespro.ru", "phone": "+70266153258"}
0005435214962	232AC0	3434 331856	LYUBOV ZAKHAROVA	{"email": "l-zakharova061967@postgrespro.ru", "phone": "+70776634585"}
0005435214963	C84EAD	3480 764299	OLEG ANDREEV	{"phone": "+70266003801"}
0005435214964	C84EAD	6945 902371	ARTEM ISAEV	{"email": "a.isaev_051975@postgrespro.ru", "phone": "+70496092989"}
0005435214965	14155D	2314 636184	PAVEL IVANOV	{"email": "ivanov-pavel.1971@postgrespro.ru", "phone": "+70961366570"}
0005435214966	7D1DF4	2939 589121	ELENA ALEKSEEVA	{"phone": "+70964133861"}
0005435214967	B3F8A0	6863 961624	SERGEY NOVIKOV	{"email": "sergey.novikov.081970@postgrespro.ru", "phone": "+70738163810"}
0005435214968	B41EA5	4264 774560	ELINA KUZMINA	{"phone": "+70772079857"}
0005435214969	BA4BF2	4900 146823	NATALYA MIKHAYLOVA	{"email": "nmikhaylova.1964@postgrespro.ru", "phone": "+70595292941"}
0005435214970	BA4BF2	1590 441776	YULIYA KOVALEVA	{"email": "kovalevayuliya.1976@postgrespro.ru", "phone": "+70727677841"}
0005435214971	8852DE	2654 376726	YULIYA MOROZOVA	{"email": "morozova-y08091964@postgrespro.ru", "phone": "+70889779309"}
0005435214972	24F156	0453 844058	ROMAN GUSEV	{"phone": "+70689153233"}
0005435214973	24F156	6048 382335	ELENA SERGEEVA	{"phone": "+70139579925"}
0005435214974	89FBF1	3288 399429	MARIYA MIKHAYLOVA	{"phone": "+70441314264"}
0005435214975	89FBF1	4547 093426	IGOR ALEKSEEV	{"email": "igor_alekseev_1974@postgrespro.ru", "phone": "+70040104200"}
0005435214976	12B6D5	8243 198199	OLEG NOVIKOV	{"email": "novikov.o-121959@postgrespro.ru", "phone": "+70886715741"}
0005435214977	12B6D5	9058 385901	VARVARA MAKAROVA	{"phone": "+70931054362"}
0005435214978	FF1C9A	4079 006971	SERGEY GRIGOREV	{"email": "s_grigorev_1978@postgrespro.ru", "phone": "+70465516483"}
0005435214979	FF1C9A	4743 889974	VIKTOR BARANOV	{"email": "v.baranov_1964@postgrespro.ru", "phone": "+70694280369"}
0005435214980	6A680B	0656 215973	NADEZHDA MEDVEDEVA	{"email": "nadezhda_medvedeva_1978@postgrespro.ru", "phone": "+70120019248"}
0005435214981	422508	9571 427667	ROMAN ZAYCEV	{"phone": "+70958801369"}
0005435214982	0D3888	3214 014568	ANTON KUDRYASHOV	{"phone": "+70777256552"}
0005435214983	0D3888	3021 084539	IRINA KOROLEVA	{"email": "korolevai16091981@postgrespro.ru", "phone": "+70009887007"}
0005435214984	98773F	1673 362252	ANNA EFREMOVA	{"phone": "+70350668946"}
0005435214985	98773F	2519 937312	TATYANA SOLOVEVA	{"phone": "+70943589159"}
0005435214986	314F42	5868 374154	ARTEMIY SMIRNOV	{"email": "smirnovartemiy-1985@postgrespro.ru", "phone": "+70549013115"}
0005435214987	248491	5837 315016	ALLA YAKOVLEVA	{"phone": "+70039481065"}
0005435214988	248491	4391 189091	TATYANA KAZAKOVA	{"email": "t.kazakova.101964@postgrespro.ru", "phone": "+70506381688"}
0005435214989	D3FC0A	5297 822491	VLADISLAV DENISOV	{"email": "denisov.vladislav.09111989@postgrespro.ru", "phone": "+70305219264"}
0005435214990	D3FC0A	3363 164748	MARINA BORISOVA	{"email": "marina_borisova.13071968@postgrespro.ru", "phone": "+70728403136"}
0005435214991	257292	9628 654962	ALEKSEY DENISOV	{"phone": "+70120174193"}
0005435214992	EEA14F	2889 789565	YULIYA SIDOROVA	{"phone": "+70475173903"}
0005435214993	E82537	9226 689184	ALEKSEY VASILEV	{"phone": "+70185256962"}
0005435214994	7D7AE3	1577 125294	GALINA ANTONOVA	{"phone": "+70285934958"}
0005435214995	D7A119	6397 863115	OLGA PAVLOVA	{"email": "olga.pavlova1984@postgrespro.ru", "phone": "+70011373390"}
0005435214996	D7A119	0348 589566	MAKSIM OSIPOV	{"email": "m.osipov-1976@postgrespro.ru", "phone": "+70086240349"}
0005435214997	2AAD34	1090 148179	DENIS GAVRILOV	{"email": "gavrilovd05021969@postgrespro.ru", "phone": "+70028962149"}
0005435214998	2AAD34	7175 541641	GALINA AKIMOVA	{"phone": "+70507018610"}
0005435214999	87373B	1416 963096	IRINA PETROVA	{"email": "irina.petrova-1961@postgrespro.ru", "phone": "+70070678653"}
0005435215000	CCBC28	8346 721844	PETR ORLOV	{"phone": "+70610636178"}
0005435215001	CCBC28	9402 710781	IRINA ANDREEVA	{"email": "iandreeva091961@postgrespro.ru", "phone": "+70672726818"}
0005435215002	5EB2F2	9663 944597	ALEKSANDR VLASOV	{"phone": "+70220399422"}
0005435215003	4A5E69	8838 482047	ANNA KUZNECOVA	{"phone": "+70778128925"}
0005435215004	4A5E69	7575 622978	ALEKSEY MARTYNOV	{"email": "aleksey-martynov.1973@postgrespro.ru", "phone": "+70071003779"}
0005435215005	4A5E69	5741 275831	MARGARITA KULIKOVA	{"phone": "+70170017272"}
0005435215006	6108C7	7986 851541	ANASTASIYA NAZAROVA	{"email": "a_nazarova16111973@postgrespro.ru", "phone": "+70101339818"}
0005435215007	6108C7	8960 868017	ALEKSANDR DENISOV	{"phone": "+70410820922"}
0005435215008	9A37EC	3675 087827	OLGA GAVRILOVA	{"phone": "+70733887825"}
0005435215009	558608	9689 737820	ALEKSEY SOLOVEV	{"email": "solovev_a_1965@postgrespro.ru", "phone": "+70785141747"}
0005435215010	B0F129	8343 073304	DMITRIY EGOROV	{"email": "degorov1974@postgrespro.ru", "phone": "+70889296393"}
0005435215011	B0F129	6284 094439	ELENA POTAPOVA	{"email": "potapova.elena_1967@postgrespro.ru", "phone": "+70126851391"}
0005435215012	5203E5	3148 671177	ANASTASIYA VOROBEVA	{"email": "anastasiya-vorobeva.1969@postgrespro.ru", "phone": "+70832786019"}
0005435215013	095AB7	8742 509819	KIRILL FOMIN	{"phone": "+70882618521"}
0005435215014	076AD3	9971 142819	ANATOLIY VOROBEV	{"email": "vorobev_a.18051970@postgrespro.ru", "phone": "+70090932769"}
0005435215015	FE48B2	4027 592030	TAMARA POLYAKOVA	{"phone": "+70823306875"}
0005435215016	FE48B2	2120 055383	YURIY IVANOV	{"phone": "+70087632848"}
0005435215017	FE49FD	2735 504264	NINA ORLOVA	{"email": "ninaorlova-031972@postgrespro.ru", "phone": "+70738362313"}
0005435215018	833563	2915 429414	OLGA NIKOLAEVA	{"email": "nikolaeva_olga10021974@postgrespro.ru", "phone": "+70704586945"}
0005435215019	55138E	2335 288447	LEONID DMITRIEV	{"phone": "+70018235960"}
0005435215020	6D2C45	8402 088468	RUSLAN FEDOROV	{"email": "r.fedorov04031967@postgrespro.ru", "phone": "+70855775238"}
0005435215021	C0271F	6550 024043	VIKTOR MOROZOV	{"phone": "+70303570855"}
0005435215022	5F147B	5402 548376	TAMARA AFANASEVA	{"phone": "+70590530257"}
0005435215023	5F147B	2808 091400	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr_14071988@postgrespro.ru", "phone": "+70186529225"}
0005435215024	E0193E	5982 505157	ILYA SERGEEV	{"phone": "+70232466380"}
0005435215025	65A25C	0530 495950	YURIY STEPANOV	{"email": "ystepanov1986@postgrespro.ru", "phone": "+70756201845"}
0005435215026	E08CEC	0924 922348	ALEKSEY NOVIKOV	{"phone": "+70132373335"}
0005435215027	E230E9	7656 796443	DENIS BORISOV	{"email": "denis.borisov1983@postgrespro.ru", "phone": "+70211755483"}
0005435215028	F6D456	1640 199274	KONSTANTIN VASILEV	{"phone": "+70500144810"}
0005435215029	F6D456	4109 059754	SERGEY GAVRILOV	{"phone": "+70384653902"}
0005435215030	613B38	6154 793883	SERGEY KARPOV	{"email": "karpovsergey_27021980@postgrespro.ru", "phone": "+70532563898"}
0005435215031	237970	4215 491228	VLADIMIR ORLOV	{"email": "vladimirorlov-02111963@postgrespro.ru", "phone": "+70544623014"}
0005435215032	466F44	2571 885591	LYUBOV TROFIMOVA	{"email": "trofimova-lyubov26091975@postgrespro.ru", "phone": "+70278798629"}
0005435215033	466F44	0192 776327	ELENA NAZAROVA	{"email": "elena.nazarova-21011972@postgrespro.ru", "phone": "+70503408301"}
0005435215034	FA0465	4977 728811	RAISA YAKOVLEVA	{"email": "yakovleva-r-041967@postgrespro.ru", "phone": "+70188755582"}
0005435215035	7571CD	8294 764131	ELENA RYABOVA	{"email": "ryabova.elena_031979@postgrespro.ru", "phone": "+70759115787"}
0005435215036	C6E8CC	7207 393049	TATYANA ZAKHAROVA	{"email": "tatyana_zakharova_1987@postgrespro.ru", "phone": "+70891367609"}
0005435215037	FC8454	9416 289735	ALEKSEY MATVEEV	{"email": "matveev-a_071972@postgrespro.ru", "phone": "+70485605776"}
0005435215038	85F18F	3788 203266	IRINA MAKSIMOVA	{"phone": "+70595293396"}
0005435215039	85F18F	4396 298502	YULIYA EFREMOVA	{"phone": "+70509535296"}
0005435215040	85F18F	3078 656311	IRINA KRASNOVA	{"email": "krasnovai_121978@postgrespro.ru", "phone": "+70352208212"}
0005435215041	847E3B	5787 872190	ALEKSANDR ALEKSANDROV	{"phone": "+70919870052"}
0005435215042	847E3B	6885 664898	ELENA LOGINOVA	{"email": "eloginova.1973@postgrespro.ru", "phone": "+70223103655"}
0005435215043	86283E	0084 845190	GALINA KOMAROVA	{"email": "komarova_g1970@postgrespro.ru", "phone": "+70302745218"}
0005435215044	2FAE23	1156 677771	ALEKSANDR PAVLOV	{"email": "aleksandr.pavlov30031974@postgrespro.ru", "phone": "+70982197469"}
0005435215045	EC05E2	1689 331373	LIDIYA MAKAROVA	{"phone": "+70326237078"}
0005435215046	B23494	9991 816712	IRINA EFIMOVA	{"email": "efimova-i_03011975@postgrespro.ru", "phone": "+70866321976"}
0005435215047	B23494	0666 628360	MARIYA KOZLOVA	{"phone": "+70314398489"}
0005435215048	D2B5D8	2191 774381	OLGA SIDOROVA	{"email": "o-sidorova-091976@postgrespro.ru", "phone": "+70690834312"}
0005435215049	3F3DEA	4446 066496	RAISA KOVALEVA	{"phone": "+70629915063"}
0005435215050	3C85DE	0926 773354	SHAVKAT SHEVCHENKO	{"phone": "+70927786711"}
0005435215051	E445A2	6053 824652	NADEZHDA MELNIKOVA	{"email": "nadezhdamelnikova.1975@postgrespro.ru", "phone": "+70624950542"}
0005435215052	E445A2	3864 745503	ANTON ILIN	{"email": "a-ilin1957@postgrespro.ru", "phone": "+70044731512"}
0005435215053	1476AA	4127 856124	ALEKSANDR POPOV	{"phone": "+70255668154"}
0005435215054	BEC5BE	5097 975432	MARGARITA VOROBEVA	{"phone": "+70082484021"}
0005435215055	BEC5BE	4311 621398	VITALIY SEMENOV	{"phone": "+70367525776"}
0005435215056	EBFE51	9350 183970	ANDREY MIRONOV	{"phone": "+70778106202"}
0005435215057	EBFE51	5759 651286	EVGENIY ILIN	{"email": "e_ilin-111971@postgrespro.ru", "phone": "+70146160743"}
0005435215058	4AE77D	2949 694328	NATALYA VASILEVA	{"phone": "+70846762642"}
0005435215059	4640AB	8707 468383	MARIYA MIKHAYLOVA	{"email": "mikhaylova-m_1970@postgrespro.ru", "phone": "+70719247116"}
0005435215060	A7EA2F	8872 936473	VASILIY STEPANOV	{"email": "stepanov-vasiliy-1969@postgrespro.ru", "phone": "+70466492439"}
0005435215061	A7EA2F	2333 457379	IVAN KRASNOV	{"email": "krasnov_ivan1977@postgrespro.ru", "phone": "+70581261925"}
0005435215062	16F3CA	3990 942248	VALENTINA NOVIKOVA	{"phone": "+70814778635"}
0005435215063	16F3CA	8470 777724	NATALYA FROLOVA	{"email": "n.frolova061979@postgrespro.ru", "phone": "+70543945708"}
0005435215064	16F3CA	0144 739246	KIRILL ILIN	{"email": "ilin-kirill_1981@postgrespro.ru", "phone": "+70389705419"}
0005435215065	C419F8	1083 370097	ALEKSANDR VOLKOV	{"email": "volkov-a_041977@postgrespro.ru", "phone": "+70524790564"}
0005435215066	AA7EDC	7542 204202	ALEKSANDR MARTYNOV	{"phone": "+70509135372"}
0005435215067	8E4C56	0118 204348	VLADIMIR ALEKSANDROV	{"phone": "+70496019370"}
0005435215068	769EF5	7407 764724	VALENTINA ISAEVA	{"phone": "+70304743982"}
0005435215069	3F7B78	1471 842026	SVETLANA ZHURAVLEVA	{"phone": "+70081919950"}
0005435215070	E257E4	5496 863175	PAVEL KUZNECOV	{"phone": "+70857721951"}
0005435215071	01906A	2411 014371	LYUDMILA OSIPOVA	{"phone": "+70573028506"}
0005435215072	7C9FED	0170 720940	NATALYA NESTEROVA	{"email": "nesterova-natalya_05111974@postgrespro.ru", "phone": "+70329564614"}
0005435215073	7C9FED	5066 665481	SVETLANA FOMINA	{"phone": "+70569727643"}
0005435215074	677B63	3431 419422	VITALIY KONOVALOV	{"email": "konovalov-v.111987@postgrespro.ru", "phone": "+70288000390"}
0005435215075	10D154	4754 516576	PETR PAVLOV	{"phone": "+70308609378"}
0005435215076	10D154	9874 889841	IGOR NIKOLAEV	{"phone": "+70053022169"}
0005435215077	10D154	3401 501758	MARIYA SOROKINA	{"email": "msorokina.041975@postgrespro.ru", "phone": "+70931048101"}
0005435215078	1276D6	6692 797466	DMITRIY MIKHAYLOV	{"email": "mikhaylov_dmitriy_1981@postgrespro.ru", "phone": "+70284413395"}
0005435215079	1276D6	3372 851998	ALEKSANDR GRIGOREV	{"email": "grigorev.a.081971@postgrespro.ru", "phone": "+70518516974"}
0005435215080	0A80FE	6119 364701	VLADIMIR SEMENOV	{"email": "semenovvladimir-1977@postgrespro.ru", "phone": "+70301684450"}
0005435215081	82EDC8	2884 149089	VLADIMIR FROLOV	{"phone": "+70077641305"}
0005435215082	030BD2	7477 195317	NIKITA KOZLOV	{"phone": "+70652903096"}
0005435215083	F1DF69	8159 999975	LILIYA PAVLOVA	{"email": "liliya.pavlova.031979@postgrespro.ru", "phone": "+70784735317"}
0005435215084	8E0BEB	7289 635613	NADEZHDA FEDOROVA	{"phone": "+70081511067"}
0005435215085	FE640E	9819 903402	DENIS CHERNOV	{"email": "chernov-denis.20041981@postgrespro.ru", "phone": "+70697697044"}
0005435215086	10D1D7	2177 865166	VALERIY KOZLOV	{"email": "kozlov.v.101966@postgrespro.ru", "phone": "+70233720956"}
0005435215087	16C1D2	3499 341605	SHAMIL KUZMIN	{"email": "kuzminshamil1971@postgrespro.ru", "phone": "+70653923766"}
0005435215088	19D17C	1417 765654	LILIYA DENISOVA	{"phone": "+70674895670"}
0005435215089	19D17C	8545 623793	DMITRIY NAUMOV	{"phone": "+70657484392"}
0005435215090	66E0E1	0979 791530	ELENA NOVIKOVA	{"phone": "+70665899982"}
0005435215091	54466C	6100 520540	VASILIY VASILEV	{"phone": "+70304101335"}
0005435215092	6201B1	3892 795001	VALENTINA ANDREEVA	{"email": "valentina_andreeva_1965@postgrespro.ru", "phone": "+70016182653"}
0005435215093	7E87D7	5027 930435	SVETLANA ABRAMOVA	{"phone": "+70114059899"}
0005435215094	7E87D7	8660 013422	TATYANA SMIRNOVA	{"phone": "+70747122537"}
0005435215095	D972C1	7908 314112	TAISA EGOROVA	{"email": "egorova_t_021974@postgrespro.ru", "phone": "+70256888861"}
0005435215096	0B23E6	1218 811364	RAISA MAKAROVA	{"email": "r_makarova_1971@postgrespro.ru", "phone": "+70725483526"}
0005435215097	AC1921	0845 218835	VLADIMIR DMITRIEV	{"email": "vladimir-dmitriev1970@postgrespro.ru", "phone": "+70420450194"}
0005435215098	439230	8745 444727	EVELINA AFANASEVA	{"phone": "+70327464603"}
0005435215099	439230	4408 278699	MARIYA ARKHIPOVA	{"email": "arkhipovamariya_25041974@postgrespro.ru", "phone": "+70672919025"}
0005435215100	81E229	7910 861184	NAILYA VOLKOVA	{"email": "nailya.volkova_1981@postgrespro.ru", "phone": "+70534806317"}
0005435215101	C7C283	1641 085834	DMITRIY PETROV	{"email": "d-petrov-25091968@postgrespro.ru", "phone": "+70000771159"}
0005435215102	D41E61	6242 689594	ALEKSANDRA ANDREEVA	{"email": "aleksandra_andreeva05101979@postgrespro.ru", "phone": "+70880619893"}
0005435215103	D41E61	2815 135395	NATALYA LAZAREVA	{"email": "lazarevanatalya081980@postgrespro.ru", "phone": "+70229513440"}
0005435215104	887F70	0196 403694	YULIYA KUZNECOVA	{"email": "yuliya.kuznecova-23081974@postgrespro.ru", "phone": "+70772712518"}
0005435215105	887F70	9542 906752	LYUDMILA TROFIMOVA	{"phone": "+70627734194"}
0005435215106	23A856	2732 683606	ANATOLIY MIKHAYLOV	{"email": "mikhaylovanatoliy1976@postgrespro.ru", "phone": "+70663749401"}
0005435215107	23A856	3995 299449	ALEKSANDR FOMIN	{"email": "aleksandrfomin_011979@postgrespro.ru", "phone": "+70872979260"}
0005435215108	C509C7	9032 090203	ANASTASIYA NAZAROVA	{"phone": "+70810780470"}
0005435215109	C509C7	4415 721851	SVETLANA CHERNOVA	{"email": "svetlanachernova_20071979@postgrespro.ru", "phone": "+70096869880"}
0005435215110	C509C7	9171 877845	MAKSIM KOZLOV	{"email": "maksimkozlov.121959@postgrespro.ru", "phone": "+70648802404"}
0005435215111	C509C7	3939 119438	LYUBOV BORISOVA	{"email": "l_borisova.24011977@postgrespro.ru", "phone": "+70674468647"}
0005435215112	6F8B10	9929 092780	ALEKSANDR BONDARENKO	{"phone": "+70808982713"}
0005435215113	6F8B10	9480 411795	YURIY MIKHAYLOV	{"email": "ymikhaylov.011962@postgrespro.ru", "phone": "+70705789985"}
0005435215114	B7B146	4438 119904	ALEKSANDR IVANOV	{"email": "a.ivanov-08111966@postgrespro.ru", "phone": "+70190879732"}
0005435215115	24DC04	2916 016938	SAMIRA KUZMINA	{"phone": "+70067085374"}
0005435215116	24DC04	2996 329061	ALEKSANDR IVANOV	{"email": "aleksandrivanov_051973@postgrespro.ru", "phone": "+70700460141"}
0005435215117	109BC2	0847 074701	ELVIRA KONOVALOVA	{"email": "konovalova_elvira_111968@postgrespro.ru", "phone": "+70781286288"}
0005435215118	109BC2	6914 555883	SERGEY KOROLEV	{"email": "s_korolev1978@postgrespro.ru", "phone": "+70531082619"}
0005435215119	E5C8B0	6796 544486	DILYARA SIDOROVA	{"email": "sidorovadilyara.041973@postgrespro.ru", "phone": "+70457905858"}
0005435215120	44E2A4	8562 570972	DMITRIY NIKOLAEV	{"email": "nikolaevd.051979@postgrespro.ru", "phone": "+70871617686"}
0005435215121	8B1AB2	5258 539415	ZINAIDA MOROZOVA	{"phone": "+70856219932"}
0005435215122	8B1AB2	6626 512294	SERGEY NIKOLAEV	{"email": "nikolaevsergey-19081979@postgrespro.ru", "phone": "+70799162849"}
0005435215123	AAA236	4693 998982	VLADIMIR NIKOLAEV	{"email": "nikolaev.v101977@postgrespro.ru", "phone": "+70698725791"}
0005435215124	AAA236	0482 464585	ANNA BELOVA	{"phone": "+70911726217"}
0005435215125	B1EBCE	3937 542867	ANATOLIY NIKITIN	{"email": "a.nikitin19021967@postgrespro.ru", "phone": "+70802755267"}
0005435215126	B1EBCE	9877 667055	VIKTOR KARPOV	{"phone": "+70490565404"}
0005435215127	422E53	9017 223439	DMITRIY RODIONOV	{"phone": "+70942256282"}
0005435215128	422E53	9772 144958	MIKHAIL MEDVEDEV	{"email": "medvedev-mikhail19011975@postgrespro.ru", "phone": "+70186737225"}
0005435215129	384301	5951 153090	VLADIMIR TIKHONOV	{"phone": "+70602005294"}
0005435215130	384301	5135 557165	MARIYA AFANASEVA	{"email": "afanasevam1971@postgrespro.ru", "phone": "+70670419343"}
0005435215131	225D22	7046 765358	YURIY FEDOTOV	{"email": "y_fedotov16071968@postgrespro.ru", "phone": "+70262440201"}
0005435215132	225D22	7775 932717	EKATERINA KUDRYASHOVA	{"email": "e.kudryashova.22051965@postgrespro.ru", "phone": "+70046508724"}
0005435215133	A7D0A6	0467 675512	ANTON OSIPOV	{"phone": "+70143570106"}
0005435215134	C94C08	7206 488706	MARINA SCHERBAKOVA	{"email": "m-scherbakova051974@postgrespro.ru", "phone": "+70183043714"}
0005435215135	761175	2526 998624	NATALYA PETROVA	{"phone": "+70229783765"}
0005435215136	761175	1261 322662	SVETLANA EGOROVA	{"phone": "+70870884120"}
0005435215137	7F22D3	5329 933920	BORIS KUDRYASHOV	{"phone": "+70509555737"}
0005435215138	CB13FF	4328 739305	VLADIMIR DENISOV	{"phone": "+70599916012"}
0005435215139	CB13FF	4373 849192	ANASTASIYA POTAPOVA	{"email": "potapova-a.1972@postgrespro.ru", "phone": "+70435296282"}
0005435215140	F5AB80	1330 126035	NATALYA GUSEVA	{"email": "guseva_natalya-011974@postgrespro.ru", "phone": "+70694311688"}
0005435215141	DDDA33	9645 940247	ALEKSANDR IVANOV	{"phone": "+70450374821"}
0005435215142	96FB72	2389 310287	ALEKSANDR ZHUKOV	{"phone": "+70280467600"}
0005435215143	8521F6	2042 615415	ALEKSANDR BARANOV	{"phone": "+70064797435"}
0005435215144	8521F6	0271 495916	VASILIY IVANOV	{"phone": "+70537274128"}
0005435215145	ECE2E7	9760 440518	ELENA POPOVA	{"phone": "+70201993909"}
0005435215146	49FDBA	6550 874812	LEONID MATVEEV	{"email": "lmatveev13021976@postgrespro.ru", "phone": "+70671506076"}
0005435215147	410DD7	7853 391098	VLADIMIR SEMENOV	{"email": "semenov.v-21121977@postgrespro.ru", "phone": "+70308675513"}
0005435215148	0A0623	0785 101917	DIANA POPOVA	{"phone": "+70447510783"}
0005435215149	B6C2B8	3254 805244	GALINA RYABOVA	{"phone": "+70174046342"}
0005435215150	6029F7	0914 842452	ELENA ANTONOVA	{"phone": "+70855953066"}
0005435215151	BB8E56	1675 130685	ANASTASIYA KAZAKOVA	{"phone": "+70058430002"}
0005435215393	71DE13	5029 508813	NADEZHDA GERASIMOVA	{"phone": "+70261058501"}
0005435215152	BB8E56	7262 140078	ROZALIYA FEDOROVA	{"email": "rozaliya_fedorova1961@postgrespro.ru", "phone": "+70032163005"}
0005435215153	52BCD8	6645 094034	IGOR FEDOROV	{"email": "ifedorov-051978@postgrespro.ru", "phone": "+70257440409"}
0005435215154	52BCD8	5626 800340	MARIYA KUZNECOVA	{"phone": "+70168919873"}
0005435215155	52BCD8	5300 730523	LYUBOV VASILEVA	{"phone": "+70631042412"}
0005435215156	0A7F4B	8565 890423	EKATERINA OSIPOVA	{"email": "ekaterina-osipova-061968@postgrespro.ru", "phone": "+70664717986"}
0005435215157	A54219	7840 292287	TATYANA GORBUNOVA	{"email": "gorbunova_t.1976@postgrespro.ru", "phone": "+70423711526"}
0005435215158	A54219	1214 072978	SVETLANA ZHURAVLEVA	{"email": "s_zhuravleva.1981@postgrespro.ru", "phone": "+70575714664"}
0005435215159	A7D50E	8668 091551	EVGENIY IVANOV	{"phone": "+70265473722"}
0005435215160	2FF8AB	1976 594223	ANATOLIY CHERNOV	{"email": "anatoliychernov_1970@postgrespro.ru", "phone": "+70365040713"}
0005435215161	2FF8AB	3230 989000	MARIYA VOLKOVA	{"email": "volkova-m_071975@postgrespro.ru", "phone": "+70128558650"}
0005435215162	71E667	6131 817785	ELENA KRASNOVA	{"email": "krasnova.e1979@postgrespro.ru", "phone": "+70757853347"}
0005435215163	25AC0A	5768 004183	ROMAN PAVLOV	{"email": "roman_pavlov-17041966@postgrespro.ru", "phone": "+70817962107"}
0005435215164	CA2393	8233 225069	ANASTASIYA NIKIFOROVA	{"email": "anastasiya_nikiforova-091980@postgrespro.ru", "phone": "+70611553936"}
0005435215165	CA2393	1067 811153	KIRILL RODIONOV	{"email": "kirill.rodionov11121969@postgrespro.ru", "phone": "+70617144595"}
0005435215166	A4C672	3350 622417	FARIDA POTAPOVA	{"phone": "+70648393105"}
0005435215167	A4C672	7232 726564	GALINA MAKSIMOVA	{"email": "galina_maksimova1967@postgrespro.ru", "phone": "+70909360080"}
0005435215168	A4C672	0700 642330	ZLATA RYABOVA	{"email": "ryabova.z_01091970@postgrespro.ru", "phone": "+70535155055"}
0005435215169	42DDEA	5126 730162	OLEG VOLKOV	{"email": "volkov-o28051976@postgrespro.ru", "phone": "+70796810057"}
0005435215170	42DDEA	8579 629454	VERA KUZNECOVA	{"email": "kuznecova-v-1965@postgrespro.ru", "phone": "+70654588426"}
0005435215171	BE5167	6249 332424	TAMARA KUZNECOVA	{"phone": "+70810740084"}
0005435215172	407575	7836 734478	ANTONINA PETROVA	{"phone": "+70729923220"}
0005435215173	407575	7451 047591	ANDREY MARTYNOV	{"phone": "+70998729499"}
0005435215174	AFE8D3	7028 032330	TAMARA FEDOROVA	{"phone": "+70401042114"}
0005435215175	CAA660	6951 205936	VLADIMIR MOROZOV	{"email": "v_morozov-011976@postgrespro.ru", "phone": "+70424791882"}
0005435215176	2D6A9B	8350 746953	DENIS NOVIKOV	{"phone": "+70117255440"}
0005435215177	F67E10	3155 190454	NIKOLAY PETROV	{"phone": "+70713572432"}
0005435215178	34BAE9	6204 479009	NINA TROFIMOVA	{"phone": "+70769879424"}
0005435215179	11737D	1097 509775	EVGENIY MIRONOV	{"email": "e-mironov_01091959@postgrespro.ru", "phone": "+70373674812"}
0005435215180	0C2D33	8222 773107	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov.26091972@postgrespro.ru", "phone": "+70734129833"}
0005435215181	4823DB	3286 730337	ELENA KUZNECOVA	{"phone": "+70622779029"}
0005435215182	2F2EEA	0341 478813	LIDIYA SEMENOVA	{"phone": "+70798941360"}
0005435215183	860BEB	5249 931779	TAMARA IVANOVA	{"phone": "+70071011712"}
0005435215184	439A61	3605 266905	VLADIMIR BARANOV	{"email": "baranovvladimir1971@postgrespro.ru", "phone": "+70934162786"}
0005435215185	439A61	1050 615765	YANA TROFIMOVA	{"phone": "+70091701706"}
0005435215186	439A61	3657 726593	GALINA KUZNECOVA	{"email": "g-kuznecova09031980@postgrespro.ru", "phone": "+70365685532"}
0005435215187	5E448A	1982 870323	EDUARD MELNIKOV	{"phone": "+70779734228"}
0005435215188	5E448A	9940 159405	ALEKSEY FROLOV	{"email": "frolov.a_23071972@postgrespro.ru", "phone": "+70596801014"}
0005435215189	A26091	3662 610713	VLADIMIR ISAEV	{"email": "vladimir-isaev_21071980@postgrespro.ru", "phone": "+70747376034"}
0005435215190	291AFB	3351 313962	DMITRIY ANDREEV	{"phone": "+70581634869"}
0005435215191	291AFB	5068 903921	YULIYA ANDREEVA	{"email": "andreeva-yuliya-1979@postgrespro.ru", "phone": "+70531264699"}
0005435215192	5BD9A0	8103 197471	MARINA KOZLOVA	{"email": "m.kozlova-051972@postgrespro.ru", "phone": "+70618963054"}
0005435215193	5BD9A0	8139 373818	SVETLANA ROMANOVA	{"email": "s.romanova021964@postgrespro.ru", "phone": "+70862431049"}
0005435215194	0F5091	5510 427881	PETR BORISOV	{"email": "borisovpetr1974@postgrespro.ru", "phone": "+70617624020"}
0005435215195	0F5091	2172 860496	RUSTYAM BORISOV	{"phone": "+70161488790"}
0005435215196	C1DB09	6010 792116	SERGEY MOISEEV	{"email": "sergey_moiseev.051979@postgrespro.ru", "phone": "+70366492100"}
0005435215197	73FEC2	1852 315930	VALENTIN FOMIN	{"email": "fomin_valentin25011968@postgrespro.ru", "phone": "+70649041354"}
0005435215198	73FEC2	3738 657003	MARIYA FROLOVA	{"phone": "+70059658664"}
0005435215199	647196	6176 289968	ANTON SOROKIN	{"email": "sorokina-24101987@postgrespro.ru", "phone": "+70109589258"}
0005435215200	647196	9869 474035	YAROSLAV TARASOV	{"email": "tarasov.yaroslav.27011975@postgrespro.ru", "phone": "+70740744880"}
0005435215201	647196	1766 967665	IRINA MAKAROVA	{"email": "irina-makarova011979@postgrespro.ru", "phone": "+70352886548"}
0005435215202	A81BB1	5962 623729	LIDIYA FILATOVA	{"phone": "+70493088537"}
0005435215203	630AAF	2893 611165	VASILIY SOROKIN	{"phone": "+70214361749"}
0005435215204	D4E334	4655 180345	NIKITA KUDRYASHOV	{"email": "kudryashov.n.19121972@postgrespro.ru", "phone": "+70836125951"}
0005435215205	8B8B87	2755 636609	MIKHAIL KUDRYASHOV	{"email": "m.kudryashov.1977@postgrespro.ru", "phone": "+70124140777"}
0005435215206	4316B0	0335 924418	POLINA GORBUNOVA	{"email": "gorbunova_polina15031964@postgrespro.ru", "phone": "+70459743309"}
0005435215207	F7B9CC	4898 556219	LYUDMILA OVCHINNIKOVA	{"phone": "+70286898222"}
0005435215208	1B204D	3015 808745	LYUBOV FADEEVA	{"phone": "+70355580156"}
0005435215209	1B204D	9547 585093	VLADIMIR SAVELEV	{"email": "vsavelev_101978@postgrespro.ru", "phone": "+70833389224"}
0005435215210	1B204D	0626 262470	ALEKSANDR EGOROV	{"email": "aleksandr-egorov_1970@postgrespro.ru", "phone": "+70011076690"}
0005435215211	5EB44D	2686 839920	ANATOLIY KUZNECOV	{"email": "kuznecovanatoliy_071972@postgrespro.ru", "phone": "+70882273002"}
0005435215212	912B7F	1938 550790	VIKTOR KUZNECOV	{"email": "kuznecov-viktor-1975@postgrespro.ru", "phone": "+70095713468"}
0005435215213	6B4873	6542 723179	VASILIY PAVLOV	{"email": "vasiliypavlov.1974@postgrespro.ru", "phone": "+70915439933"}
0005435215214	CD1FC1	2798 334738	DARYA KUZMINA	{"email": "daryakuzmina.1960@postgrespro.ru", "phone": "+70160618283"}
0005435215215	45FE00	8517 199443	SVETLANA MAKAROVA	{"phone": "+70108679260"}
0005435215216	E24BA8	5155 190068	ROMAN KAZAKOV	{"phone": "+70742395330"}
0005435215217	E24BA8	3679 077621	VIKTOR KUZMIN	{"phone": "+70850746812"}
0005435215218	A6EECF	6828 223596	OLGA NIKOLAEVA	{"phone": "+70379284743"}
0005435215219	E6D2F6	7016 282991	ANGELINA DMITRIEVA	{"email": "angelina_dmitrieva.1972@postgrespro.ru", "phone": "+70768242594"}
0005435215220	CD6947	5694 607109	IVAN NIKOLAEV	{"phone": "+70799050850"}
0005435215221	1C1FA5	5645 242590	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy_1979@postgrespro.ru", "phone": "+70780388021"}
0005435215222	4035FD	2478 150185	DMITRIY ZAKHAROV	{"phone": "+70477099909"}
0005435215223	4035FD	5910 726242	OLGA NIKOLAEVA	{"email": "onikolaeva.071973@postgrespro.ru", "phone": "+70683279247"}
0005435215224	8D004E	5278 423447	SERGEY GUSEV	{"email": "sergeygusev.20031985@postgrespro.ru", "phone": "+70275487906"}
0005435215225	8EE1E8	5607 975228	SERGEY ZAKHAROV	{"phone": "+70084214701"}
0005435215226	E396F0	3960 743659	SVETLANA KUZNECOVA	{"phone": "+70949361961"}
0005435215227	E396F0	8062 710413	VIKTORIYA MAKSIMOVA	{"email": "maksimova_viktoriya29051977@postgrespro.ru", "phone": "+70007259925"}
0005435215228	772FB1	7908 270250	MAKSIM ALEKSEEV	{"phone": "+70234472212"}
0005435215229	58958E	9783 197083	KLAVDIYA KUZNECOVA	{"phone": "+70878042661"}
0005435215230	58958E	6383 504478	VITALIY POPOV	{"phone": "+70549464466"}
0005435215231	693916	0988 306945	ROMAN STEPANOV	{"phone": "+70514185550"}
0005435215232	BF49B4	9713 846284	MAKSIM ISAEV	{"phone": "+70862325844"}
0005435215233	E59A1C	4363 173723	ALEKSEY SOKOLOV	{"phone": "+70532597675"}
0005435215234	557296	9726 812461	OLGA SIDOROVA	{"phone": "+70713569884"}
0005435215235	557296	6653 841379	ANDREY DENISOV	{"email": "andrey-denisov_15121969@postgrespro.ru", "phone": "+70874359365"}
0005435215236	BDEE07	5304 330884	DMITRIY MATVEEV	{"email": "matveev_d_1969@postgrespro.ru", "phone": "+70353344921"}
0005435215237	BDEE07	4296 825644	IGOR NIKITIN	{"email": "nikitin-i_071978@postgrespro.ru", "phone": "+70274134445"}
0005435215238	BDEE07	3181 420746	SERGEY IVANOV	{"email": "ivanov-s.011976@postgrespro.ru", "phone": "+70273724473"}
0005435215239	578414	9710 161934	SERGEY SHEVCHENKO	{"email": "shevchenko-sergey-23061968@postgrespro.ru", "phone": "+70022696196"}
0005435215240	578414	0530 314706	DARYA NIKITINA	{"email": "darya-nikitina051975@postgrespro.ru", "phone": "+70995251568"}
0005435215241	578414	4247 479516	EKATERINA TIMOFEEVA	{"phone": "+70505202666"}
0005435215242	8DD867	3218 626989	IRINA DAVYDOVA	{"phone": "+70619647494"}
0005435215243	8DD867	7592 059391	ALEKSEY SMIRNOV	{"phone": "+70562742259"}
0005435215244	8F27FE	3132 723639	VLADISLAV BORISOV	{"email": "borisov.vladislav_071965@postgrespro.ru", "phone": "+70418521115"}
0005435215245	870A2C	4595 849491	ANDREY PETROV	{"phone": "+70572620650"}
0005435215246	0E4FAE	8246 979489	TATYANA SERGEEVA	{"phone": "+70328721284"}
0005435215247	32B4B5	1894 741738	NATALYA ALEKSANDROVA	{"phone": "+70214738335"}
0005435215248	4D15E9	1217 121939	VITALIY MAKAROV	{"email": "makarov_vitaliy-051974@postgrespro.ru", "phone": "+70667996048"}
0005435215249	4D15E9	8361 742886	ALINA DENISOVA	{"email": "denisova_alina1972@postgrespro.ru", "phone": "+70738101767"}
0005435215250	5FF79A	6445 951921	DMITRIY VASILEV	{"phone": "+70832872285"}
0005435215251	6F50E1	8976 086694	TATYANA ABRAMOVA	{"email": "tatyana_abramova1957@postgrespro.ru", "phone": "+70632566352"}
0005435215252	6F50E1	2771 190431	SERGEY BORISOV	{"phone": "+70216859146"}
0005435215253	6F50E1	0674 057254	VLADIMIR IVANOV	{"phone": "+70000602085"}
0005435215254	71EA5F	0170 166164	NIKOLAY ANDREEV	{"email": "nikolayandreev.041982@postgrespro.ru", "phone": "+70598549915"}
0005435215255	71EA5F	2114 091933	NINA MAKSIMOVA	{"phone": "+70110537885"}
0005435215256	FC2FCA	8593 584064	TAMARA MELNIKOVA	{"phone": "+70805442384"}
0005435215257	FC2FCA	0384 144868	GALINA SAVELEVA	{"phone": "+70680053365"}
0005435215258	41AD27	2567 860398	SERGEY ISAEV	{"email": "isaevs.071960@postgrespro.ru", "phone": "+70790300671"}
0005435215259	41AD27	0513 904319	MARINA KRASNOVA	{"email": "marina.krasnova.1970@postgrespro.ru", "phone": "+70553784414"}
0005435215260	41AD27	2132 749616	ELENA FEDOROVA	{"email": "e.fedorova_1980@postgrespro.ru", "phone": "+70778830521"}
0005435215261	64C7A1	3150 236802	EKATERINA ZOTOVA	{"email": "ekaterina.zotova-1968@postgrespro.ru", "phone": "+70124413320"}
0005435215262	C52B3E	8901 194189	VALENTINA EFREMOVA	{"phone": "+70984950556"}
0005435215263	C79F62	2380 923707	DMITRIY SAVELEV	{"phone": "+70851938170"}
0005435215264	FC0889	0079 730346	IRINA VLASOVA	{"phone": "+70464730656"}
0005435215265	FC0889	3132 531581	VALERIY PAVLOV	{"phone": "+70643564006"}
0005435215266	1DD387	8845 517896	YULIYA ROMANOVA	{"email": "y_romanova_1963@postgrespro.ru", "phone": "+70272396904"}
0005435215267	4DFD11	0015 160031	VIKTOR POPOV	{"phone": "+70525402335"}
0005435215268	0E87EE	0792 114990	OLGA ROMANOVA	{"email": "romanova_olga_26031965@postgrespro.ru", "phone": "+70429062965"}
0005435215269	0E87EE	7178 368047	TAISIYA BARANOVA	{"phone": "+70460808766"}
0005435215270	81E340	3223 901113	VLADISLAV FOMIN	{"phone": "+70564459652"}
0005435215271	81E340	8937 016421	LYUBOV TIKHONOVA	{"phone": "+70430652090"}
0005435215272	81E340	1341 405477	VLADIMIR SEMENOV	{"phone": "+70795143750"}
0005435215273	2383A7	6412 660981	ALEKSEY ANDREEV	{"email": "andreev-aleksey20021969@postgrespro.ru", "phone": "+70390154447"}
0005435215274	612BA6	4104 329592	ZINAIDA ALEKSEEVA	{"email": "zinaida_alekseeva-1965@postgrespro.ru", "phone": "+70819329960"}
0005435215275	C4AD78	4293 742905	ZOYA MATVEEVA	{"email": "matveeva-zoya_101981@postgrespro.ru", "phone": "+70339376656"}
0005435215276	C4AD78	1283 654117	LYUDMILA MATVEEVA	{"email": "l.matveeva_101970@postgrespro.ru", "phone": "+70556200751"}
0005435215277	C4AD78	2926 317412	VENERA SIDOROVA	{"email": "sidorova.venera.22081970@postgrespro.ru", "phone": "+70184717942"}
0005435215278	1984F6	1284 347897	MIKHAIL SOROKIN	{"email": "sorokin-m_041979@postgrespro.ru", "phone": "+70210040033"}
0005435215279	531432	0228 364842	VLADIMIR NOVIKOV	{"phone": "+70079315689"}
0005435215280	531432	5380 875554	PAVEL ROMANOV	{"email": "promanov-041963@postgrespro.ru", "phone": "+70965084990"}
0005435215281	822EEB	8105 167686	NATALYA MOROZOVA	{"phone": "+70233280749"}
0005435215282	FF0C91	3486 594999	IVAN DAVYDOV	{"email": "davydov_ivan051973@postgrespro.ru", "phone": "+70080053289"}
0005435215283	2D356F	8853 613004	ALEKSANDRA STEPANOVA	{"email": "stepanova.aleksandra111961@postgrespro.ru", "phone": "+70125273523"}
0005435215284	2D356F	0375 162234	NATALYA KALININA	{"phone": "+70818774100"}
0005435215285	724984	4679 690376	ELIZAVETA BORISOVA	{"email": "borisova-elizaveta.21101969@postgrespro.ru", "phone": "+70549355444"}
0005435215286	724984	6903 728594	IRINA EFIMOVA	{"email": "i_efimova1968@postgrespro.ru", "phone": "+70296420348"}
0005435215287	442017	4476 264460	NATALYA TARASOVA	{"phone": "+70793584765"}
0005435215288	809BE3	0710 572530	MAKSIM YAKOVLEV	{"email": "maksim_yakovlev.111976@postgrespro.ru", "phone": "+70293900123"}
0005435215289	104622	0274 178199	OLGA LEBEDEVA	{"email": "olga-lebedeva-10071981@postgrespro.ru", "phone": "+70669337421"}
0005435215290	C886D8	1665 070374	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey-04101973@postgrespro.ru", "phone": "+70028922757"}
0005435215291	C886D8	6201 275776	EVGENIY DENISOV	{"phone": "+70545629438"}
0005435215292	C886D8	1671 380585	NIKOLAY SHEVCHENKO	{"phone": "+70482773792"}
0005435215293	8D22D5	7616 877395	TATYANA MATVEEVA	{"phone": "+70108833832"}
0005435215294	82FFF0	3104 249441	ALEKSANDR TIMOFEEV	{"email": "timofeev-aleksandr_051979@postgrespro.ru", "phone": "+70305995383"}
0005435215295	82FFF0	5415 515797	NIKOLAY BONDARENKO	{"email": "bondarenko.n041975@postgrespro.ru", "phone": "+70039095064"}
0005435215296	AEA9EE	2813 575985	VASILISA KALININA	{"email": "vasilisa.kalinina01101961@postgrespro.ru", "phone": "+70733359680"}
0005435215297	AEA9EE	7211 026320	VALERIY KUZNECOV	{"phone": "+70410024003"}
0005435215298	E27599	0393 856490	NADEZHDA MATVEEVA	{"email": "matveevan10121980@postgrespro.ru", "phone": "+70524780780"}
0005435215299	E27599	1240 417843	ALEKSEY RODIONOV	{"email": "alekseyrodionov061974@postgrespro.ru", "phone": "+70855915054"}
0005435215300	E27599	9978 121510	ANASTASIYA VOROBEVA	{"phone": "+70341733939"}
0005435215301	5A1722	7575 072601	EVGENIY POPOV	{"phone": "+70486416652"}
0005435215302	CD76A7	4902 084083	ILMIR NAUMOV	{"phone": "+70598619189"}
0005435215303	CD76A7	6073 619657	TATYANA KRASNOVA	{"phone": "+70623010854"}
0005435215304	3B0D9A	3488 139640	VIKTORIYA BORISOVA	{"phone": "+70386875035"}
0005435215305	5C1C6C	1824 306738	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr.011973@postgrespro.ru", "phone": "+70815284071"}
0005435215306	183510	7276 927247	IRINA MELNIKOVA	{"phone": "+70441281893"}
0005435215307	183510	7640 584497	NATALYA ILINA	{"phone": "+70788981257"}
0005435215308	AC27B1	6637 196891	ALEKSANDR TIKHONOV	{"phone": "+70476055131"}
0005435215309	AC27B1	5910 808308	ZINAIDA STEPANOVA	{"email": "zinaida_stepanova.1969@postgrespro.ru", "phone": "+70478907714"}
0005435215310	504675	4649 305771	OLGA LAZAREVA	{"email": "olgalazareva-06091968@postgrespro.ru", "phone": "+70591999536"}
0005435215311	CA2FD2	1320 452439	NATALYA SOLOVEVA	{"phone": "+70862696341"}
0005435215312	CA2FD2	8155 718075	ANDREY MOROZOV	{"phone": "+70525739025"}
0005435215313	CA2FD2	4034 564787	YURIY FEDOROV	{"phone": "+70782892170"}
0005435215314	CA2FD2	0807 215267	ANDREY PAVLOV	{"phone": "+70084408565"}
0005435215315	D44B64	3060 226748	TATYANA SOROKINA	{"email": "sorokina_tatyana_1980@postgrespro.ru", "phone": "+70817638744"}
0005435215316	D44B64	6090 017321	LIDIYA ERMAKOVA	{"email": "lidiya.ermakova-1965@postgrespro.ru", "phone": "+70201506660"}
0005435215317	03B1C7	4017 678944	ELENA NESTEROVA	{"email": "e-nesterova31121975@postgrespro.ru", "phone": "+70902178653"}
0005435215318	03B1C7	3637 637368	ELIZAVETA GORBUNOVA	{"email": "gorbunovae-1982@postgrespro.ru", "phone": "+70386222897"}
0005435215319	FE005E	2061 015132	SVETLANA ISAEVA	{"email": "svetlana_isaeva.03081978@postgrespro.ru", "phone": "+70939243883"}
0005435215320	38FC3E	2094 663355	ANATOLIY MIKHAYLOV	{"phone": "+70297798029"}
0005435215321	B22224	4998 342083	ELVIRA PETROVA	{"phone": "+70253404619"}
0005435215322	7326B5	4226 107084	KIRILL ALEKSEEV	{"email": "alekseev-kirill-031967@postgrespro.ru", "phone": "+70705521638"}
0005435215323	7326B5	0093 275743	MAKSIM SOROKIN	{"email": "msorokin-26071976@postgrespro.ru", "phone": "+70937026710"}
0005435215324	3AFC4A	1116 838203	SHAVKAT SERGEEV	{"email": "sergeevs.10081976@postgrespro.ru", "phone": "+70417122790"}
0005435215325	3AFC4A	9673 066888	ALEKSEY ABRAMOV	{"email": "abramov_aleksey-111975@postgrespro.ru", "phone": "+70056263566"}
0005435215326	3AFC4A	4961 697814	NATALIYA KOZLOVA	{"email": "nataliya_kozlova02061966@postgrespro.ru", "phone": "+70585751847"}
0005435215327	3AFC4A	3511 683169	NINA FROLOVA	{"phone": "+70715255183"}
0005435215328	60A6B2	5221 071792	SVETLANA MOROZOVA	{"email": "s-morozova.02041966@postgrespro.ru", "phone": "+70049917022"}
0005435215329	E6A991	1713 304433	OLESYA LUKYANOVA	{"phone": "+70850335474"}
0005435215330	FE401F	0797 059217	DARYA BORISOVA	{"phone": "+70615004520"}
0005435215331	247DAA	8340 074034	LYUBOV NESTEROVA	{"phone": "+70346504158"}
0005435215332	247DAA	3612 880808	VIKTOR ILIN	{"email": "ilin.v-23041974@postgrespro.ru", "phone": "+70703477319"}
0005435215333	247DAA	6726 925316	MIKHAIL SERGEEV	{"phone": "+70722779026"}
0005435215334	3B8D5E	5608 295373	SVETLANA SAVELEVA	{"phone": "+70728727329"}
0005435215335	D6A279	6625 039502	DENIS PETROV	{"phone": "+70361123591"}
0005435215336	F78CFF	8658 771170	FEDOR KUZNECOV	{"phone": "+70147520980"}
0005435215337	F78CFF	0645 523682	EKATERINA ANDREEVA	{"email": "ekaterina_andreeva_121967@postgrespro.ru", "phone": "+70150463361"}
0005435215338	612104	8894 456183	ELVIRA NIKOLAEVA	{"phone": "+70519314444"}
0005435215339	612104	9461 664597	ARTEM BELOV	{"email": "artem.belov25031976@postgrespro.ru", "phone": "+70895262122"}
0005435215340	4C3660	7563 517536	YULIYA ROMANOVA	{"phone": "+70706754430"}
0005435215341	4C3660	2909 429979	VLADIMIR MOISEEV	{"phone": "+70966195142"}
0005435215342	DF51DF	2960 707273	EKATERINA KISELEVA	{"phone": "+70907063166"}
0005435215343	F56D3C	5074 654209	NATALYA EGOROVA	{"phone": "+70895240221"}
0005435215344	503880	7296 788103	LYUBOV POTAPOVA	{"email": "lyubov.potapova-1977@postgrespro.ru", "phone": "+70493151919"}
0005435215345	11E627	5008 164838	VLADIMIR SOLOVEV	{"email": "v_solovev.23121966@postgrespro.ru", "phone": "+70961939593"}
0005435215346	29F9D4	3098 945134	VLADISLAV SIDOROV	{"phone": "+70198986713"}
0005435215347	5E41A0	7947 536602	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr_25041971@postgrespro.ru", "phone": "+70349398568"}
0005435215348	5E41A0	9670 203876	PETR EGOROV	{"email": "egorov-petr.1969@postgrespro.ru", "phone": "+70680375113"}
0005435215349	7889BB	4159 075821	NATALYA OSIPOVA	{"phone": "+70281482731"}
0005435215350	8B0236	3967 594898	GALINA MASLOVA	{"email": "maslova-g-12081984@postgrespro.ru", "phone": "+70799710630"}
0005435215351	8B0236	9090 488933	NATALYA ANISIMOVA	{"email": "anisimovan_021972@postgrespro.ru", "phone": "+70012487445"}
0005435215352	C8CA57	2586 032313	SVETLANA VLASOVA	{"email": "vlasova.svetlana1968@postgrespro.ru", "phone": "+70634955826"}
0005435215353	85FB1C	0187 717968	STANISLAV ZAYCEV	{"email": "s.zaycev_29101967@postgrespro.ru", "phone": "+70180050641"}
0005435215354	172BEA	2369 211092	ANTON ILIN	{"phone": "+70742494408"}
0005435215355	3CCDF8	0476 991342	NADEZHDA ERMAKOVA	{"phone": "+70274430461"}
0005435215356	8CAA5B	9429 155052	IRINA MEDVEDEVA	{"email": "irina_medvedeva-1970@postgrespro.ru", "phone": "+70087329511"}
0005435215357	8592B8	7344 953914	VLADIMIR GRIGOREV	{"phone": "+70860921334"}
0005435215358	97E3F6	5335 788604	SERGEY AFANASEV	{"email": "afanasev.s_1970@postgrespro.ru", "phone": "+70477823063"}
0005435215359	92C639	4625 952342	SERGEY KISELEV	{"email": "sergeykiselev_1972@postgrespro.ru", "phone": "+70222072547"}
0005435215360	FC2672	7891 754447	LYUDMILA EFREMOVA	{"email": "lyudmila-efremova_07011976@postgrespro.ru", "phone": "+70220314257"}
0005435215361	FC2672	0298 853511	OKSANA EGOROVA	{"email": "egorovaoksana.1971@postgrespro.ru", "phone": "+70394715972"}
0005435215362	5CF2B3	2007 975875	ZLATA BOGDANOVA	{"email": "z-bogdanova_081962@postgrespro.ru", "phone": "+70182430980"}
0005435215363	5CF2B3	3148 585593	MIKHAIL BELOV	{"email": "mbelov.121970@postgrespro.ru", "phone": "+70164716001"}
0005435215364	B45FCA	1926 113398	PAVEL KISELEV	{"email": "kiselev_p_1972@postgrespro.ru", "phone": "+70114821996"}
0005435215365	34E423	5319 413839	MAKSIM SCHERBAKOV	{"email": "scherbakov_m.1970@postgrespro.ru", "phone": "+70095206861"}
0005435215366	534EF9	8894 865217	VALERIY KOZLOV	{"phone": "+70365698082"}
0005435215367	BA7257	1143 644348	KIRILL NIKOLAEV	{"phone": "+70587728938"}
0005435215368	E27AC8	6535 696323	VALENTINA KOLESNIKOVA	{"email": "valentina.kolesnikova1970@postgrespro.ru", "phone": "+70566781564"}
0005435215369	E27AC8	4459 735378	VLADIMIR KAZAKOV	{"phone": "+70763590802"}
0005435215370	BAF683	1400 424822	LIDIYA KUZNECOVA	{"email": "l_kuznecova021979@postgrespro.ru", "phone": "+70139505517"}
0005435215371	ABCE71	8391 581665	ALEKSANDR TIKHONOV	{"phone": "+70778630250"}
0005435215372	ABCE71	4063 774745	GALINA FADEEVA	{"email": "fadeeva-g1964@postgrespro.ru", "phone": "+70508459257"}
0005435215373	0D5F16	9904 560264	ELIZAVETA VOLKOVA	{"phone": "+70010094244"}
0005435215374	F3E05C	2713 501166	VLADISLAV POPOV	{"phone": "+70483732554"}
0005435215375	57CBB3	9412 462126	SVETLANA KUDRYASHOVA	{"phone": "+70640359540"}
0005435215376	829C01	5656 280130	LILIYA ZHURAVLEVA	{"phone": "+70940952340"}
0005435215377	829C01	8295 926767	OLESYA OSIPOVA	{"phone": "+70911313420"}
0005435215378	094409	2143 076017	NADEZHDA ANISIMOVA	{"phone": "+70838088141"}
0005435215379	094409	6121 612620	NADEZHDA VASILEVA	{"phone": "+70413630316"}
0005435215380	746EE7	5077 334961	SERGEY POPOV	{"email": "popov_sergey.28011975@postgrespro.ru", "phone": "+70628521291"}
0005435215381	746EE7	4801 313530	IGOR BONDARENKO	{"phone": "+70707306418"}
0005435215382	291A9A	7481 848392	TATYANA PETROVA	{"phone": "+70345827289"}
0005435215383	291A9A	1428 840948	NIKOLAY KUZMIN	{"phone": "+70847814209"}
0005435215384	BE2404	0748 405871	VIKTOR TIKHONOV	{"email": "v_tikhonov-121973@postgrespro.ru", "phone": "+70921963975"}
0005435215385	BE2404	1195 784509	EVGENIYA KALININA	{"email": "kalinina-e-1970@postgrespro.ru", "phone": "+70128139170"}
0005435215386	804517	3155 917030	KSENIYA POLYAKOVA	{"phone": "+70841068884"}
0005435215387	73DBF3	3663 009211	YULIYA NESTEROVA	{"phone": "+70808194767"}
0005435215388	BB02D5	5487 538780	VIKTOR POPOV	{"phone": "+70293357521"}
0005435215389	CD85F2	1784 612602	RAISA KOROLEVA	{"email": "raisa.koroleva_21031978@postgrespro.ru", "phone": "+70277120533"}
0005435215390	25FD02	5033 416175	SERGEY KISELEV	{"email": "s_kiselev1971@postgrespro.ru", "phone": "+70087540954"}
0005435215391	25FD02	9571 197270	NIKITA GAVRILOV	{"email": "gavrilov.nikita_1973@postgrespro.ru", "phone": "+70014792311"}
0005435215392	642F39	1011 136640	SVETLANA ROMANOVA	{"phone": "+70832223416"}
0005435215394	71DE13	0032 098718	ARINA KUZNECOVA	{"phone": "+70851947316"}
0005435215395	5A54A2	1489 908074	VERA KOMAROVA	{"phone": "+70643939263"}
0005435215396	5A54A2	8984 875843	ALEKSANDR TARASOV	{"phone": "+70754128579"}
0005435215397	A4BA09	4646 431341	IRINA ZHUKOVA	{"phone": "+70425333470"}
0005435215398	A1E976	7258 971719	ANDREY FILIPPOV	{"email": "filippov-a051975@postgrespro.ru", "phone": "+70822318002"}
0005435215399	A1E976	5967 671303	VERA POPOVA	{"phone": "+70407673339"}
0005435215400	8FE03E	8911 997861	VLADIMIR KRASNOV	{"email": "krasnov_vladimir011970@postgrespro.ru", "phone": "+70665727041"}
0005435215401	8FE03E	7382 762756	NADEZHDA NESTEROVA	{"phone": "+70553411153"}
0005435215402	BD3DBA	9713 228776	DARYA EGOROVA	{"email": "daryaegorova.02021967@postgrespro.ru", "phone": "+70603835542"}
0005435215403	604EB2	0800 502824	YURIY NOVIKOV	{"phone": "+70274288141"}
0005435215404	7E9309	9889 253902	SARIYA EGOROVA	{"email": "sariya.egorova1976@postgrespro.ru", "phone": "+70846591059"}
0005435215405	3BAD74	7553 075456	OLGA ISAEVA	{"phone": "+70524882263"}
0005435215406	6433D4	4221 149194	KARINA KAZAKOVA	{"email": "karina-kazakova11071965@postgrespro.ru", "phone": "+70322588557"}
0005435215407	3B6A1C	1520 166266	SERGEY GUSEV	{"email": "gusev.sergey031979@postgrespro.ru", "phone": "+70890637730"}
0005435215408	F419F0	1356 521781	OKSANA IVANOVA	{"email": "ivanova.oksana.10011978@postgrespro.ru", "phone": "+70416607566"}
0005435215409	F419F0	8862 830496	VALENTINA EGOROVA	{"email": "egorovavalentina30091980@postgrespro.ru", "phone": "+70676496059"}
0005435215410	19FE50	8556 654775	NAZAR SAVELEV	{"email": "nazar.savelev26011976@postgrespro.ru", "phone": "+70514159510"}
0005435215411	19FE50	7665 867746	LIDIYA POLYAKOVA	{"phone": "+70989940630"}
0005435215412	E7DBCA	4356 698429	LIDIYA DAVYDOVA	{"phone": "+70161633261"}
0005435215413	4BE371	8008 336757	YURIY MAKAROV	{"phone": "+70510837245"}
0005435215414	68F5A8	5636 660035	VADIM SERGEEV	{"phone": "+70891061325"}
0005435215415	0B906A	7256 230664	SVETLANA MELNIKOVA	{"email": "melnikova-svetlana_31071972@postgrespro.ru", "phone": "+70798493054"}
0005435215416	0B906A	5767 624780	NADEZHDA AFANASEVA	{"email": "n.afanaseva_051972@postgrespro.ru", "phone": "+70844040120"}
0005435215417	C01273	6308 708777	ELENA VOLKOVA	{"email": "volkova_elena.1974@postgrespro.ru", "phone": "+70987194603"}
0005435215418	7C770E	0622 952525	YULIYA MAKSIMOVA	{"email": "y.maksimova09121965@postgrespro.ru", "phone": "+70429523836"}
0005435215419	7C770E	8715 789934	SVETLANA KOLESNIKOVA	{"email": "kolesnikovas.031970@postgrespro.ru", "phone": "+70833192215"}
0005435215420	D50D72	9172 848751	ALIYA KUZNECOVA	{"phone": "+70784669624"}
0005435215421	6EEB9D	3679 323088	OLGA MARTYNOVA	{"phone": "+70207312906"}
0005435215422	1D5246	5540 678439	ANATOLIY KUZNECOV	{"email": "a_kuznecov09041966@postgrespro.ru", "phone": "+70238719125"}
0005435215423	1D5246	7271 637960	ELENA ORLOVA	{"email": "orlova.elena051973@postgrespro.ru", "phone": "+70638955759"}
0005435215424	7D32C8	0883 833529	GALINA LEBEDEVA	{"phone": "+70278465664"}
0005435215425	3DDDB1	2587 183057	EKATERINA NIKOLAEVA	{"email": "ekaterina-nikolaeva1958@postgrespro.ru", "phone": "+70974565712"}
0005435215426	3DDDB1	2964 783366	ANASTASIYA DAVYDOVA	{"phone": "+70452743901"}
0005435215427	25B104	0435 482489	DMITRIY PETROV	{"email": "petrov_dmitriy-1973@postgrespro.ru", "phone": "+70250978459"}
0005435215428	EC3F28	1511 196230	GALINA KUZNECOVA	{"email": "g-kuznecova.1973@postgrespro.ru", "phone": "+70905685107"}
0005435215429	CBE8DF	1419 439140	OLGA LOGINOVA	{"phone": "+70391171875"}
0005435215430	1D780B	0729 141607	NATALYA TIKHONOVA	{"phone": "+70691673707"}
0005435215431	E283F1	7398 330364	MARINA NIKOLAEVA	{"email": "marina.nikolaeva_081975@postgrespro.ru", "phone": "+70895705800"}
0005435215432	A7405D	8853 361092	PAVEL RODIONOV	{"email": "pavel.rodionov_031970@postgrespro.ru", "phone": "+70953328486"}
0005435215433	62ED7B	6754 785187	MIKHAIL TIKHONOV	{"phone": "+70081851713"}
0005435215434	5A0A28	3065 066462	ALEKSEY FEDOTOV	{"email": "fedotov.a.28071962@postgrespro.ru", "phone": "+70963943674"}
0005435215435	A12772	4885 543999	DMITRIY SOLOVEV	{"email": "d-solovev.24021975@postgrespro.ru", "phone": "+70032407974"}
0005435215436	E3FE11	1386 094751	SERGEY NIKOLAEV	{"email": "sergey-nikolaev12041979@postgrespro.ru", "phone": "+70787976763"}
0005435215437	7951F3	1941 750608	IRINA KUZNECOVA	{"email": "kuznecova.i-01091969@postgrespro.ru", "phone": "+70266923745"}
0005435215438	E1F55F	6224 990649	IRAIDA EGOROVA	{"email": "iraida_egorova.041977@postgrespro.ru", "phone": "+70858268283"}
0005435215439	E48AB6	4773 177680	TAMARA KOZLOVA	{"phone": "+70985392747"}
0005435215440	14F0AD	8001 075276	ANDREY PAVLOV	{"email": "pavlovandrey_21041977@postgrespro.ru", "phone": "+70968559744"}
0005435215441	14F0AD	1596 110649	VERA NIKIFOROVA	{"phone": "+70083514534"}
0005435215442	1837DC	3297 331994	NADEZHDA ISAEVA	{"phone": "+70451358139"}
0005435215443	1837DC	3021 186102	ALEKSANDR DAVYDOV	{"email": "davydov.a_121975@postgrespro.ru", "phone": "+70465643479"}
0005435215444	9C6890	9035 275993	VALENTINA NIKOLAEVA	{"email": "vnikolaeva.031977@postgrespro.ru", "phone": "+70106864391"}
0005435215445	9C6890	8807 136183	TATYANA ALEKSANDROVA	{"email": "tatyana_aleksandrova_25041966@postgrespro.ru", "phone": "+70005056226"}
0005435215446	8BF5AF	9731 799242	DMITRIY MELNIKOV	{"phone": "+70738687893"}
0005435215447	8BF5AF	9474 527631	RAISA PETROVA	{"email": "petrova_raisa13051967@postgrespro.ru", "phone": "+70343498310"}
0005435215448	25FF55	3517 010858	VALENTINA MASLOVA	{"email": "v_maslova_09021973@postgrespro.ru", "phone": "+70012487693"}
0005435215449	FFC8DB	9620 560713	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr.051977@postgrespro.ru", "phone": "+70612731992"}
0005435215450	FFC8DB	9719 942889	VYACHESLAV VOLKOV	{"email": "volkov.vyacheslav_10091968@postgrespro.ru", "phone": "+70593076697"}
0005435215451	FFC8DB	2592 491885	ANNA MIRONOVA	{"email": "mironova.a.17101971@postgrespro.ru", "phone": "+70158121520"}
0005435215452	DB016A	0174 504729	NADEZHDA KRASNOVA	{"phone": "+70944861043"}
0005435215453	DB016A	7645 401674	MARINA ALEKSEEVA	{"phone": "+70588232683"}
0005435215454	F81791	8038 099472	VALENTINA MARTYNOVA	{"phone": "+70855541998"}
0005435215455	ED88BC	7399 660803	OLGA ZHURAVLEVA	{"phone": "+70568364728"}
0005435215456	7540DB	2512 308326	ELENA PAVLOVA	{"email": "pavlova-e.011978@postgrespro.ru", "phone": "+70226393656"}
0005435215457	73A9ED	7548 988090	OLGA KUZNECOVA	{"email": "kuznecova_o.1974@postgrespro.ru", "phone": "+70759483226"}
0005435215458	801F8E	6935 930062	VERA NESTEROVA	{"phone": "+70278520662"}
0005435215459	801F8E	9515 833012	ANNA TROFIMOVA	{"phone": "+70072804600"}
0005435215460	801F8E	8932 134549	NIKOLAY FEDOTOV	{"phone": "+70938910136"}
0005435215461	F9C4B8	3349 288234	KLARA DAVYDOVA	{"phone": "+70592937537"}
0005435215462	F9C4B8	9835 425742	MAKSIM MEDVEDEV	{"email": "maksim-medvedev-111980@postgrespro.ru", "phone": "+70153158133"}
0005435215463	E816B4	9791 158449	OLGA KUZNECOVA	{"email": "kuznecova-olga_1976@postgrespro.ru", "phone": "+70672722981"}
0005435215464	F3F16D	5377 630047	YULIYA DANILOVA	{"phone": "+70645382180"}
0005435215465	F3F16D	7993 236787	VALENTINA OSIPOVA	{"phone": "+70740724506"}
0005435215466	D5DE0D	7308 368510	LYUDMILA KARPOVA	{"email": "karpova.l1971@postgrespro.ru", "phone": "+70519877350"}
0005435215467	323A51	7447 274247	NATALYA TROFIMOVA	{"email": "trofimovan-091968@postgrespro.ru", "phone": "+70202702104"}
0005435215468	323A51	4658 000325	ALEKSEY ORLOV	{"phone": "+70514396982"}
0005435215469	27ED59	6889 816261	EVGENIYA MAKAROVA	{"phone": "+70816347614"}
0005435215470	27ED59	4326 401067	IGOR MAKAROV	{"phone": "+70437280161"}
0005435215471	8732D1	1120 823274	MIKHAIL POPOV	{"phone": "+70635774409"}
0005435215472	B9ED04	4054 144884	VALENTINA ORLOVA	{"phone": "+70113051722"}
0005435215473	55E382	4568 615059	NINA MAKSIMOVA	{"phone": "+70686608466"}
0005435215474	55E382	0860 961097	PETR SOROKIN	{"email": "sorokin_p-1985@postgrespro.ru", "phone": "+70847943644"}
0005435215475	C78B33	9774 070068	VLADIMIR IVANOV	{"email": "v-ivanov.091975@postgrespro.ru", "phone": "+70784982656"}
0005435215476	C78B33	3953 026559	KLAVDIYA SOKOLOVA	{"phone": "+70949772580"}
0005435215477	309401	2345 092003	NINA FILIPPOVA	{"phone": "+70113990017"}
0005435215478	F22589	3563 380486	IRINA DAVYDOVA	{"email": "davydovairina_031971@postgrespro.ru", "phone": "+70012914476"}
0005435215479	1A6F24	8995 652298	EVGENIY PAVLOV	{"email": "pavlov.e-22031979@postgrespro.ru", "phone": "+70363523226"}
0005435215480	03C4D7	8552 389429	NATALYA LOGINOVA	{"email": "loginova_natalya_04081973@postgrespro.ru", "phone": "+70785757561"}
0005435215481	995DB6	1719 878133	YURIY DMITRIEV	{"phone": "+70668450900"}
0005435215482	995DB6	5895 070606	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov_14101964@postgrespro.ru", "phone": "+70773869467"}
0005435215483	52B740	2311 570374	EKATERINA DAVYDOVA	{"phone": "+70710785679"}
0005435215484	F9D091	3898 612396	NATALYA POTAPOVA	{"phone": "+70848390340"}
0005435215485	A2ABB0	3052 093072	ELENA FILIPPOVA	{"email": "e-filippova_1968@postgrespro.ru", "phone": "+70355391061"}
0005435215486	A2ABB0	2856 353789	OLGA YUDINA	{"phone": "+70944683296"}
0005435215487	A2ABB0	1985 113897	NATALYA NIKOLAEVA	{"email": "nikolaeva_n-041962@postgrespro.ru", "phone": "+70911072103"}
0005435215488	1BD1C4	1455 793154	IRINA MATVEEVA	{"email": "imatveeva-081967@postgrespro.ru", "phone": "+70740493916"}
0005435215489	8820D3	2151 498637	VALERIY SERGEEV	{"email": "sergeevvaleriy.121966@postgrespro.ru", "phone": "+70023903482"}
0005435215490	8D5CA8	2931 558924	PETR SMIRNOV	{"phone": "+70481467000"}
0005435215491	550A40	6838 967752	ELIZAVETA MATVEEVA	{"phone": "+70400889975"}
0005435215492	FE2948	7660 976907	IRINA DENISOVA	{"email": "i.denisova_031965@postgrespro.ru", "phone": "+70031112840"}
0005435215493	0E546A	6253 048334	FANIS NAZAROV	{"email": "fnazarov_061969@postgrespro.ru", "phone": "+70740518411"}
0005435215494	AFA5F9	2372 130379	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev081974@postgrespro.ru", "phone": "+70369988176"}
0005435215495	5A96CD	4002 758149	YURIY TIKHONOV	{"phone": "+70132276280"}
0005435215496	6673BF	7522 638247	TAMARA GERASIMOVA	{"email": "gerasimovatamara-121979@postgrespro.ru", "phone": "+70818913120"}
0005435215497	BF4FD5	4783 545550	VLADIMIR ALEKSANDROV	{"phone": "+70789681794"}
0005435215498	3748EF	0746 704951	GALINA AFANASEVA	{"email": "afanasevagalina.1970@postgrespro.ru", "phone": "+70065104978"}
0005435215499	612262	7573 031057	ANNA ERMAKOVA	{"email": "ermakova-anna_031972@postgrespro.ru", "phone": "+70377763877"}
0005435215500	989E60	7796 778973	TATYANA ZHUKOVA	{"email": "tatyanazhukova-091974@postgrespro.ru", "phone": "+70700482246"}
0005435215501	989E60	7187 221823	SVETLANA KUZNECOVA	{"phone": "+70460815289"}
0005435215502	E0A035	0210 677086	ALEKSEY DAVYDOV	{"phone": "+70294500925"}
0005435215503	E0A035	8922 693747	ALBINA GRISHINA	{"email": "grishina_albina1976@postgrespro.ru", "phone": "+70232159353"}
0005435215504	E0A035	8727 825236	NIKOLAY PAVLOV	{"phone": "+70899004817"}
0005435215505	A10968	1788 982857	ALEKSANDRA SEMENOVA	{"phone": "+70505549517"}
0005435215506	A10968	9046 427899	VITALIY POPOV	{"phone": "+70429238179"}
0005435215507	D8AD48	9391 334682	ANATOLIY SOLOVEV	{"email": "asolovev.1965@postgrespro.ru", "phone": "+70462805218"}
0005435215508	D8AD48	3336 863564	RAISA POLYAKOVA	{"phone": "+70025415065"}
0005435215509	C86A6A	0896 396320	KONSTANTIN VOLKOV	{"phone": "+70747526004"}
0005435215510	EA1CFE	2597 614790	ANNA NOVIKOVA	{"phone": "+70777512565"}
0005435215511	EA1CFE	8995 291430	VIKTOR TIMOFEEV	{"email": "timofeev.viktor.21091974@postgrespro.ru", "phone": "+70518460158"}
0005435215512	EA1CFE	9570 824574	ROMAN FOMIN	{"email": "fomin_r091966@postgrespro.ru", "phone": "+70078165200"}
0005435215513	EA1CFE	7079 374290	OLGA YAKOVLEVA	{"phone": "+70389186247"}
0005435215514	645229	2392 822245	MARIYA RODIONOVA	{"email": "rodionova_mariya28031977@postgrespro.ru", "phone": "+70277251358"}
0005435215515	30E8DD	1596 990190	TAMARA BELOVA	{"phone": "+70892608774"}
0005435215516	2B5073	8628 310109	YULIYA SMIRNOVA	{"email": "smirnova-yuliya.1973@postgrespro.ru", "phone": "+70169992409"}
0005435215517	5CFA2C	1092 341586	TATYANA TIMOFEEVA	{"phone": "+70027789267"}
0005435215518	AC52E2	6035 416452	NATALYA KARPOVA	{"email": "natalyakarpova-18071977@postgrespro.ru", "phone": "+70404877525"}
0005435215519	5D4B12	4487 183985	NATALYA NIKITINA	{"phone": "+70880487804"}
0005435215520	5D4B12	7849 173840	ALEKSEY NOVIKOV	{"email": "anovikov_16011978@postgrespro.ru", "phone": "+70853614728"}
0005435215521	132088	6927 188467	NINA MAKAROVA	{"email": "makarova-n-25081976@postgrespro.ru", "phone": "+70519455798"}
0005435215522	132088	1785 172408	YURIY SERGEEV	{"email": "sergeev.yuriy1974@postgrespro.ru", "phone": "+70171422832"}
0005435215523	091B5B	6743 006085	IRINA NIKIFOROVA	{"email": "nikiforova.irina_11111965@postgrespro.ru", "phone": "+70994031410"}
0005435215524	4D34DD	0879 489764	DANIIL POPOV	{"email": "daniil_popov_19021970@postgrespro.ru", "phone": "+70812807181"}
0005435215525	79F526	2285 771900	IRINA DANILOVA	{"phone": "+70603249407"}
0005435215526	022139	3894 971002	NADEZHDA MIKHAYLOVA	{"email": "nadezhda-mikhaylova041968@postgrespro.ru", "phone": "+70299811094"}
0005435215527	022139	5209 592323	ANDREY MAKSIMOV	{"phone": "+70381711951"}
0005435215528	DCDE61	4707 498842	TATYANA IVANOVA	{"email": "tivanova_20051974@postgrespro.ru", "phone": "+70384243968"}
0005435215529	0CB858	6454 731821	OLGA BELYAEVA	{"email": "belyaevao18081963@postgrespro.ru", "phone": "+70436777668"}
0005435215530	3FF0D9	4181 468719	YULIYA GERASIMOVA	{"phone": "+70672586739"}
0005435215531	7C27B2	0636 117354	DMITRIY ANTONOV	{"phone": "+70382986504"}
0005435215532	7FB0D9	3347 711348	ANNA KISELEVA	{"phone": "+70883039071"}
0005435215533	A677C3	3551 853614	TATYANA GORBUNOVA	{"phone": "+70610919123"}
0005435215534	57D391	5451 930148	ELENA GORBUNOVA	{"phone": "+70569402930"}
0005435215535	3C3490	3440 560292	NIKOLAY FEDOROV	{"email": "fedorov-nikolay_14101963@postgrespro.ru", "phone": "+70541197732"}
0005435215536	D0A7FC	8853 909539	YULIYA EFREMOVA	{"phone": "+70486482770"}
0005435215537	D0A7FC	6518 936846	IRINA KISELEVA	{"email": "kiseleva.i.11121976@postgrespro.ru", "phone": "+70099856597"}
0005435216553	4E20FA	0057 593939	GEORGIY DAVYDOV	{"email": "davydovgeorgiy-041970@postgrespro.ru", "phone": "+70458599019"}
0005435216554	4E20FA	0147 405895	ALEKSEY KOZLOV	{"phone": "+70861158724"}
0005435216555	EB437D	0731 931484	DANILA FEDOROV	{"email": "fedorovd_031969@postgrespro.ru", "phone": "+70074624742"}
0005435216556	83E466	8564 245022	ALBERT TIMOFEEV	{"phone": "+70583595984"}
0005435216557	83E466	5582 256747	IRINA YAKOVLEVA	{"phone": "+70260304214"}
0005435216558	FF3F41	5171 215053	ANZHELIKA POPOVA	{"email": "anzhelika-popova_1968@postgrespro.ru", "phone": "+70234691612"}
0005435216559	77CEF9	3966 329367	DMITRIY ANDREEV	{"email": "d.andreev.1969@postgrespro.ru", "phone": "+70817613116"}
0005435216560	894E0B	1951 994841	VLADIMIR KULIKOV	{"email": "vladimir.kulikov.1964@postgrespro.ru", "phone": "+70799519619"}
0005435216561	1EB1D1	3936 215349	IVAN SOROKIN	{"email": "i_sorokin_101956@postgrespro.ru", "phone": "+70938489682"}
0005435216562	1EB1D1	7006 304658	IGOR NIKOLAEV	{"phone": "+70101205376"}
0005435216563	270467	6255 005391	OLGA BARANOVA	{"email": "obaranova_01041985@postgrespro.ru", "phone": "+70497373010"}
0005435216564	9C20B2	3906 378074	ANATOLIY KARPOV	{"phone": "+70621917507"}
0005435216565	08F150	1488 889310	DMITRIY IVANOV	{"phone": "+70562944961"}
0005435216566	08F150	7930 417652	ALEKSANDR DMITRIEV	{"phone": "+70524526538"}
0005435216567	FDD21F	7213 159478	PAVEL ZAYCEV	{"email": "pavel.zaycev_1981@postgrespro.ru", "phone": "+70769071469"}
0005435216568	C741CC	8139 867202	SVETLANA ZAKHAROVA	{"email": "s-zakharova_121968@postgrespro.ru", "phone": "+70475619886"}
0005435216569	2582FD	2163 780254	ANTON SCHERBAKOV	{"phone": "+70498878744"}
0005435216570	19C7C3	4845 797774	VALENTINA VOLKOVA	{"email": "volkovavalentina1971@postgrespro.ru", "phone": "+70968187026"}
0005435216571	F04E3C	4477 809554	KLAVDIYA MEDVEDEVA	{"phone": "+70757173453"}
0005435216572	B8B098	0974 615521	ARTEM POPOV	{"email": "popov_a25021972@postgrespro.ru", "phone": "+70137850837"}
0005435216573	B8B098	4550 914260	MARINA MOROZOVA	{"phone": "+70460823395"}
0005435216574	0862B5	2809 928348	NIKOLAY SOKOLOV	{"email": "sokolov.nikolay-24031969@postgrespro.ru", "phone": "+70837969273"}
0005435216575	7F73F1	1652 291657	MAKSIM NOVIKOV	{"email": "maksim_novikov_061972@postgrespro.ru", "phone": "+70102173177"}
0005435216576	A530A4	4825 699215	MIKHAIL KUZMIN	{"email": "kuzmin_m021971@postgrespro.ru", "phone": "+70412699581"}
0005435216577	A530A4	8818 995943	VADIM ZHURAVLEV	{"phone": "+70360312524"}
0005435216578	ECA6F5	2262 583004	NINA KUZNECOVA	{"email": "kuznecova-nina_1984@postgrespro.ru", "phone": "+70108948446"}
0005435216579	ECA6F5	1432 034869	KIRILL KRASNOV	{"phone": "+70211001784"}
0005435216580	23085F	9145 063868	ALENA KULIKOVA	{"phone": "+70647030765"}
0005435216581	23085F	2253 762163	YANA SMIRNOVA	{"email": "yana_smirnova101975@postgrespro.ru", "phone": "+70665216217"}
0005435216582	9F57B7	8528 218998	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov-1967@postgrespro.ru", "phone": "+70952536574"}
0005435216583	9F57B7	6544 068884	LYUBOV KUDRYASHOVA	{"email": "kudryashovalyubov1980@postgrespro.ru", "phone": "+70840283470"}
0005435216584	1BCDA6	2169 579244	IRINA KUZNECOVA	{"email": "ikuznecova_23051979@postgrespro.ru", "phone": "+70726050065"}
0005435216585	4E654B	3981 817439	SVETLANA KISELEVA	{"phone": "+70165636363"}
0005435216586	043486	5281 422968	NINA SIDOROVA	{"phone": "+70143874436"}
0005435216587	043486	5581 154134	ALEKSEY ANDREEV	{"email": "andreev-a-1967@postgrespro.ru", "phone": "+70463277171"}
0005435216588	845F36	9815 983892	OLGA MELNIKOVA	{"phone": "+70690193333"}
0005435216589	845F36	7042 550708	SEMEN NOVIKOV	{"phone": "+70915525749"}
0005435216590	FD8611	9449 703897	ALEKSANDR ISAEV	{"phone": "+70645434217"}
0005435216591	FD8611	9863 416400	VIKTOR IVANOV	{"email": "viktor.ivanov1962@postgrespro.ru", "phone": "+70431990469"}
0005435216592	73EA67	8339 412785	ANDREY ZAKHAROV	{"email": "zakharov-a19051967@postgrespro.ru", "phone": "+70820067655"}
0005435216593	325619	3902 275800	SERGEY IVANOV	{"email": "ivanov-sergey22041963@postgrespro.ru", "phone": "+70098477161"}
0005435216594	325619	1505 038817	NATALYA MOROZOVA	{"email": "morozova.n121974@postgrespro.ru", "phone": "+70046095837"}
0005435216595	7FFC17	5658 150088	SERGEY VOLKOV	{"email": "volkovs-01081970@postgrespro.ru", "phone": "+70759321854"}
0005435216596	45B1C9	9155 641995	VYACHESLAV KRASNOV	{"email": "vyacheslavkrasnov.08081956@postgrespro.ru", "phone": "+70493345967"}
0005435216597	193570	7995 949629	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr011979@postgrespro.ru", "phone": "+70387463224"}
0005435216598	7D6679	1135 066720	DARYA OSIPOVA	{"phone": "+70691692097"}
0005435216599	2E20C0	2069 673258	VLADIMIR AFANASEV	{"email": "v.afanasev-091970@postgrespro.ru", "phone": "+70804347935"}
0005435216600	4E994B	2287 913802	LYUBOV IVANOVA	{"phone": "+70447105601"}
0005435216601	4E994B	7564 711076	ALLA IVANOVA	{"email": "ivanovaalla081975@postgrespro.ru", "phone": "+70498710236"}
0005435216602	81AD2A	4151 418876	VYACHESLAV TARASOV	{"email": "vtarasov.091975@postgrespro.ru", "phone": "+70955899546"}
0005435216603	5BCC93	9811 546179	EVGENIY ZHUKOV	{"email": "zhukov_evgeniy_031980@postgrespro.ru", "phone": "+70780174445"}
0005435216604	5BCC93	7244 328589	ARTEM VLASOV	{"email": "artem-vlasov-121978@postgrespro.ru", "phone": "+70911952692"}
0005435216605	426167	9191 445861	ULYANA PETROVA	{"phone": "+70468421948"}
0005435216606	426167	9432 398649	VERA POTAPOVA	{"email": "v-potapova-061966@postgrespro.ru", "phone": "+70878118966"}
0005435216607	F88794	6378 063768	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a.08061986@postgrespro.ru", "phone": "+70160518313"}
0005435216608	67D523	2660 787133	VLADISLAV MAKAROV	{"phone": "+70731215939"}
0005435216609	67D523	2279 257281	ANTONINA MAKAROVA	{"phone": "+70475782520"}
0005435216610	F0E16F	4660 806276	NINA DAVYDOVA	{"phone": "+70849312466"}
0005435216611	44F662	5451 371899	IRINA ANDREEVA	{"phone": "+70179274932"}
0005435216612	9BD453	1008 578145	YURIY VASILEV	{"email": "yuriy_vasilev16091983@postgrespro.ru", "phone": "+70306987421"}
0005435216613	45E3FD	5873 479096	ALEKSEY SERGEEV	{"email": "a.sergeev_1965@postgrespro.ru", "phone": "+70424881218"}
0005435216614	C59309	6382 341475	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova1969@postgrespro.ru", "phone": "+70246098074"}
0005435216615	C5EC03	1902 487709	ANASTASIYA BORISOVA	{"email": "borisova_anastasiya09041963@postgrespro.ru", "phone": "+70908263327"}
0005435216616	C5EC03	9163 770046	YULIYA MATVEEVA	{"phone": "+70136182699"}
0005435216617	5B8C2B	9340 408863	NADEZHDA MOROZOVA	{"phone": "+70922648653"}
0005435216618	A432BD	1580 885661	ALEKSEY IVANOV	{"phone": "+70506900588"}
0005435216619	A432BD	0140 971549	ANTONIDA IVANOVA	{"phone": "+70282149547"}
0005435216620	CBE897	3882 688134	STEPAN MOROZOV	{"email": "stepan.morozov-18071965@postgrespro.ru", "phone": "+70535643598"}
0005435216621	D34CF5	7853 088074	SVETLANA NAZAROVA	{"email": "nazarova_svetlana081985@postgrespro.ru", "phone": "+70036742885"}
0005435216622	4998AC	5875 715383	YURIY FEDOTOV	{"phone": "+70329969522"}
0005435216623	4998AC	7130 719380	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr-22101968@postgrespro.ru", "phone": "+70704091326"}
0005435216624	2E31B6	9122 977838	VENIAMIN KUZNECOV	{"phone": "+70349354926"}
0005435216625	E41D6C	1205 747549	ANNA KONDRATEVA	{"email": "anna.kondrateva.27051990@postgrespro.ru", "phone": "+70085604586"}
0005435216626	E41D6C	0108 486934	SERGEY SOROKIN	{"email": "sorokins_1970@postgrespro.ru", "phone": "+70753119315"}
0005435216627	FC4762	8872 259592	DIANA AFANASEVA	{"email": "diana.afanaseva_051977@postgrespro.ru", "phone": "+70131665242"}
0005435216628	2592ED	6443 998944	NINA ABRAMOVA	{"phone": "+70982100193"}
0005435216629	9D0E53	0344 954386	MAKSIM KUZNECOV	{"email": "maksim-kuznecov_28091974@postgrespro.ru", "phone": "+70624650246"}
0005435216630	9D0E53	4591 486808	NIKOLAY NAUMOV	{"phone": "+70151365563"}
0005435216631	9B039F	3899 902513	LYUBOV POLYAKOVA	{"phone": "+70078988977"}
0005435216632	9B039F	3261 177956	VALERIY CHERNOV	{"email": "valeriy-chernov.1982@postgrespro.ru", "phone": "+70315778099"}
0005435216633	6D3521	0604 856321	DMITRIY KUZNECOV	{"email": "kuznecovd051975@postgrespro.ru", "phone": "+70733076962"}
0005435216634	BC7BA5	8677 178370	ANNA VLASOVA	{"email": "vlasova.a-03051969@postgrespro.ru", "phone": "+70858426916"}
0005435216635	BC7BA5	8568 505847	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr-021978@postgrespro.ru", "phone": "+70446528556"}
0005435216636	39E336	2925 328257	IRINA ILINA	{"email": "irina_ilina_041979@postgrespro.ru", "phone": "+70465019041"}
0005435216637	1A9C88	0385 936965	STEPAN TARASOV	{"phone": "+70085004789"}
0005435216638	6B4631	4926 121069	ALEKSANDR SERGEEV	{"phone": "+70952739696"}
0005435216639	4CF6C5	7017 418946	DANIIL NOVIKOV	{"email": "d_novikov.021972@postgrespro.ru", "phone": "+70795714375"}
0005435216640	2C1555	4983 437009	ALINA EFREMOVA	{"phone": "+70314054391"}
0005435216641	2C1555	7271 431868	NIKOLAY KUZNECOV	{"phone": "+70862239631"}
0005435216642	F4AD21	0927 046632	NIKOLAY ZHURAVLEV	{"phone": "+70372379062"}
0005435216643	F4AD21	1650 243315	EVGENIY ANDREEV	{"email": "andreevevgeniy-1970@postgrespro.ru", "phone": "+70910314128"}
0005435216644	F4AD21	0813 540683	VERA IVANOVA	{"phone": "+70833908492"}
0005435216645	58C4B0	3604 101621	NIKOLAY ZAKHAROV	{"phone": "+70371611187"}
0005435216646	6DCB53	5623 174967	OLGA ILINA	{"phone": "+70310120733"}
0005435216647	9ECF60	8385 109704	ANATOLIY MAKSIMOV	{"phone": "+70074683663"}
0005435216648	9ECF60	1981 163374	ALEKSEY SOLOVEV	{"email": "solovev-a041966@postgrespro.ru", "phone": "+70800884579"}
0005435216649	AF2F1D	5489 497169	NINA FADEEVA	{"email": "n_fadeeva-29081968@postgrespro.ru", "phone": "+70818710871"}
0005435216650	AF2F1D	2419 299323	YULIYA TIMOFEEVA	{"phone": "+70101806195"}
0005435216651	F0C8D6	0737 749811	ALEKSANDR ISAEV	{"email": "isaev.aleksandr-071968@postgrespro.ru", "phone": "+70317958498"}
0005435216652	F0C8D6	0813 072576	VALERIY POPOV	{"email": "popov-valeriy_051981@postgrespro.ru", "phone": "+70834770522"}
0005435216653	33DEE5	9580 590948	MARIYA GUSEVA	{"email": "guseva.m.1971@postgrespro.ru", "phone": "+70457453581"}
0005435216654	F0F13C	8171 611488	ALEKSANDR FILIPPOV	{"phone": "+70537510295"}
0005435216655	F0F13C	0043 910954	TATYANA KOROLEVA	{"phone": "+70724568481"}
0005435217676	50C23D	5638 475883	TATYANA SIDOROVA	{"email": "sidorova.tatyana-1968@postgrespro.ru", "phone": "+70135553019"}
0005435217677	48E498	1413 015356	VALERIY IVANOV	{"phone": "+70604236172"}
0005435217678	45922E	3258 624845	ALEKSEY ORLOV	{"email": "orlov.aleksey.09061969@postgrespro.ru", "phone": "+70363728580"}
0005435217679	4B13B0	9439 474479	ARTEM SCHERBAKOV	{"phone": "+70965351143"}
0005435217680	4B13B0	5993 588725	EVGENIYA PETROVA	{"email": "evgeniyapetrova1971@postgrespro.ru", "phone": "+70490223524"}
0005435217681	4B13B0	5297 920349	GYUZEL MEDVEDEVA	{"email": "gyuzel-medvedeva08021975@postgrespro.ru", "phone": "+70867865537"}
0005435217682	3929BE	4846 913137	VLADIMIR PETROV	{"email": "vladimir_petrov081960@postgrespro.ru", "phone": "+70523884131"}
0005435217683	0F07E1	2263 240617	FEDOR KRASNOV	{"email": "krasnovf071973@postgrespro.ru", "phone": "+70486091503"}
0005435217684	0F07E1	9621 563369	NINA CHERNOVA	{"email": "chernova.n_04081975@postgrespro.ru", "phone": "+70070049409"}
0005435217685	53E696	4525 131976	VITALIY VASILEV	{"email": "vitaliyvasilev1962@postgrespro.ru", "phone": "+70907214543"}
0005435217686	FBABB6	0355 154357	NINA OSIPOVA	{"phone": "+70234395912"}
0005435217687	FBABB6	7901 794388	VLADIMIR FILIPPOV	{"phone": "+70664893529"}
0005435217688	FF503B	0395 487156	ALEKSEY VLASOV	{"email": "vlasova.27011985@postgrespro.ru", "phone": "+70094510949"}
0005435217689	CB6509	9431 906916	ARTUR NAZAROV	{"email": "nazarov-artur-13031966@postgrespro.ru", "phone": "+70156018495"}
0005435217690	CB6509	1363 556194	RAISA ROMANOVA	{"phone": "+70512875193"}
0005435217691	108827	7486 721773	VLADIMIR TIMOFEEV	{"email": "vladimirtimofeev071973@postgrespro.ru", "phone": "+70728105832"}
0005435217692	108827	4803 092579	SVETLANA MIRONOVA	{"email": "svetlana.mironova-091968@postgrespro.ru", "phone": "+70710212386"}
0005435217693	985A92	6689 016935	FLYURA PAVLOVA	{"phone": "+70267400279"}
0005435217694	985A92	7771 460646	NELLI KOROLEVA	{"phone": "+70118824043"}
0005435217695	BE8CC6	8743 331877	VLADIMIR ABRAMOV	{"phone": "+70829158433"}
0005435217696	148795	5634 822091	ILYA NOVIKOV	{"phone": "+70368659305"}
0005435217697	148795	7289 921173	ALINA ZHUKOVA	{"phone": "+70329108536"}
0005435217698	148795	0805 305838	OLGA LOGINOVA	{"email": "o-loginova-121963@postgrespro.ru", "phone": "+70690645514"}
0005435217699	148795	3807 532564	ELENA RODIONOVA	{"phone": "+70263266932"}
0005435217700	284797	3294 476339	YURIY KOROLEV	{"phone": "+70114030683"}
0005435217701	9FFD6A	4050 317792	NINA DAVYDOVA	{"email": "n_davydova-1979@postgrespro.ru", "phone": "+70718097012"}
0005435217702	FC5C9C	8582 222381	SERGEY MIKHAYLOV	{"phone": "+70641033438"}
0005435217703	FC5C9C	9832 542699	MAKSIM PAVLOV	{"phone": "+70227209906"}
0005435217704	672CDA	3620 880672	SERGEY ROMANOV	{"phone": "+70695586987"}
0005435217705	DF3CF6	2268 877815	SABINA FILATOVA	{"email": "s.filatova.1973@postgrespro.ru", "phone": "+70016651898"}
0005435217706	FA0912	8123 124096	ARMEN NOVIKOV	{"email": "novikov_a-28011961@postgrespro.ru", "phone": "+70144770791"}
0005435217707	68AE89	4633 363524	SVETLANA SEMENOVA	{"phone": "+70137040203"}
0005435217708	94195E	9564 701260	LYUDMILA KUZNECOVA	{"email": "kuznecovalyudmila-1987@postgrespro.ru", "phone": "+70736039368"}
0005435217709	371BE5	2433 503248	OLEG BELOV	{"email": "oleg.belov-17101971@postgrespro.ru", "phone": "+70496049178"}
0005435217710	371BE5	5814 331724	RADIK KARPOV	{"phone": "+70486509138"}
0005435217711	C6764E	5783 135183	GALINA BELYAEVA	{"phone": "+70530777178"}
0005435217712	7D2270	9932 723224	SVETLANA KAZAKOVA	{"phone": "+70867249864"}
0005435217713	C7AA58	5675 955225	OLGA STEPANOVA	{"phone": "+70655812263"}
0005435217714	33B3E0	7035 858247	ALEKSANDRA NOVIKOVA	{"phone": "+70435801278"}
0005435217715	33B3E0	3187 684681	PETR ABRAMOV	{"email": "petr-abramov.1970@postgrespro.ru", "phone": "+70530444108"}
0005435217716	DB5D3A	7842 392003	KIRILL KAZAKOV	{"phone": "+70817547624"}
0005435217717	DB5D3A	6779 077760	ALEKSANDR SHEVCHENKO	{"phone": "+70031881592"}
0005435217718	CF62B3	0756 274226	VITALIY ABRAMOV	{"phone": "+70149335118"}
0005435217719	EE2E2F	2512 404367	TATYANA ANTONOVA	{"phone": "+70628116586"}
0005435217720	EE2E2F	1537 361005	ANDREY IVANOV	{"email": "andreyivanov.03041980@postgrespro.ru", "phone": "+70686261679"}
0005435217721	8010CE	1001 374914	ROMAN ANDREEV	{"email": "andreev-r_021983@postgrespro.ru", "phone": "+70106312417"}
0005435217722	B1EC03	7763 565701	EVGENIYA NAUMOVA	{"phone": "+70418676856"}
0005435217723	B1EC03	0108 794946	IGOR NOVIKOV	{"email": "i-novikov1976@postgrespro.ru", "phone": "+70904257309"}
0005435217724	717655	8492 115917	LIDIYA ORLOVA	{"email": "orlova.l111971@postgrespro.ru", "phone": "+70669612597"}
0005435217725	9C16D9	4743 072171	DMITRIY FROLOV	{"phone": "+70798500118"}
0005435217726	54F047	1280 144338	VIKTORIYA KOMAROVA	{"phone": "+70990596892"}
0005435217727	35E6CD	5949 663982	VLADIMIR DMITRIEV	{"email": "v-dmitriev-02041974@postgrespro.ru", "phone": "+70090692689"}
0005435217728	9A80B9	8044 881042	ELENA DMITRIEVA	{"phone": "+70848366774"}
0005435217729	678344	1768 755621	LYUBOV ZAYCEVA	{"phone": "+70094191183"}
0005435217730	678344	8117 536130	NINA ROMANOVA	{"phone": "+70618561509"}
0005435217731	4F33CE	5266 883847	ANNA KAZAKOVA	{"phone": "+70934161093"}
0005435217732	3FA5C1	2532 380527	ALEKSEY ZAKHAROV	{"phone": "+70207849614"}
0005435217733	3FA5C1	5763 460831	VLADIMIR VOLKOV	{"phone": "+70644020557"}
0005435217734	462735	8402 509105	ALEKSEY KUZNECOV	{"phone": "+70062575440"}
0005435217735	8015E3	7149 968964	ANTON FILIPPOV	{"phone": "+70424119953"}
0005435217736	8015E3	4575 176963	ANZHELA NAUMOVA	{"phone": "+70151543737"}
0005435217737	A943B1	2980 516524	MIKHAIL IVANOV	{"email": "ivanov_mikhail.011968@postgrespro.ru", "phone": "+70383960736"}
0005435217738	B47A34	1342 509700	YURIY IVANOV	{"email": "y.ivanov_1971@postgrespro.ru", "phone": "+70056487694"}
0005435217739	E526A8	5562 137421	ANDREY KUZMIN	{"email": "andreykuzmin07031966@postgrespro.ru", "phone": "+70570475517"}
0005435217740	90C0D2	6118 859120	NATALYA ANISIMOVA	{"email": "anisimovanatalya061977@postgrespro.ru", "phone": "+70039052868"}
0005435217741	BC5EDC	6214 225069	ANDREY ROMANOV	{"email": "romanova31081969@postgrespro.ru", "phone": "+70661617687"}
0005435217742	EDBEE0	4225 580451	DENIS SIDOROV	{"email": "sidorov-d_30031967@postgrespro.ru", "phone": "+70962849259"}
0005435217743	CAA0BB	5564 534078	SVETLANA GUSEVA	{"email": "guseva_s.1973@postgrespro.ru", "phone": "+70913632973"}
0005435217744	C3EA47	2302 281150	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova_111970@postgrespro.ru", "phone": "+70859122740"}
0005435217745	74FE0C	1072 241214	EVDOKIYA MOROZOVA	{"phone": "+70689788913"}
0005435217746	74FE0C	6174 089208	TATYANA POPOVA	{"email": "t.popova-19051974@postgrespro.ru", "phone": "+70740332831"}
0005435217747	8BF1BB	5533 555482	VLADIMIR SOROKIN	{"phone": "+70264926308"}
0005435217748	FB7B16	5783 203678	ANATOLIY CHERNOV	{"email": "chernov.anatoliy.1967@postgrespro.ru", "phone": "+70051000708"}
0005435217749	0BA77A	6424 997185	ALEKSANDR CHERNOV	{"email": "chernovaleksandr.29081961@postgrespro.ru", "phone": "+70213375575"}
0005435217750	1EAD6F	9463 557598	ANNA MOROZOVA	{"email": "morozova_a-08061973@postgrespro.ru", "phone": "+70501180901"}
0005435217751	F45ABE	1421 109353	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko-111982@postgrespro.ru", "phone": "+70005394286"}
0005435217752	6BB22A	9388 239804	VLADIMIR ZAKHAROV	{"phone": "+70292847824"}
0005435217753	31BEE4	0040 872242	VERA OVCHINNIKOVA	{"email": "ovchinnikovavera1974@postgrespro.ru", "phone": "+70207201471"}
0005435217754	106CEA	1994 102354	VITALIY POPOV	{"phone": "+70556096529"}
0005435217755	6E0450	7733 009730	ALEKSANDR FROLOV	{"phone": "+70525178197"}
0005435217756	6E0450	9640 309980	SERGEY BARANOV	{"phone": "+70150030802"}
0005435217757	6E0450	9893 107871	NIKOLAY DAVYDOV	{"phone": "+70901969621"}
0005435217758	EBEB36	6047 104018	SEMEN BARANOV	{"email": "sbaranov05101983@postgrespro.ru", "phone": "+70335805478"}
0005435217759	E2BD82	5730 095421	SERGEY ANTONOV	{"phone": "+70108044595"}
0005435217760	E2BD82	2397 641108	ALEKSANDR ZHUKOV	{"email": "a.zhukov_17111964@postgrespro.ru", "phone": "+70943246002"}
0005435217761	47546B	4205 649093	LYUBOV MATVEEVA	{"phone": "+70832468865"}
0005435217762	F674C0	3092 965579	MAKSIM MIRONOV	{"phone": "+70859999130"}
0005435217763	72DBA6	4634 634569	RASHIT ZAYCEV	{"email": "zaycev_rashit.27111972@postgrespro.ru", "phone": "+70559842580"}
0005435217764	9817C4	8018 755792	OKSANA VOROBEVA	{"email": "oksana_vorobeva-101971@postgrespro.ru", "phone": "+70901481198"}
0005435217765	FA5BD6	1152 775952	ARKADIY VLASOV	{"email": "vlasov_a-16111963@postgrespro.ru", "phone": "+70315930297"}
0005435217766	0C3A26	0925 452848	LYUDMILA KUZNECOVA	{"email": "kuznecova.lyudmila-07121962@postgrespro.ru", "phone": "+70654514903"}
0005435217767	0C3A26	1695 458671	ELIZAVETA CHERNOVA	{"phone": "+70344851282"}
0005435217768	2FCE5A	3677 833606	PAVEL BORISOV	{"phone": "+70576833373"}
0005435217769	2FCE5A	5592 704620	ANATOLIY KUZNECOV	{"phone": "+70889985322"}
0005435217770	5E7FC2	7544 381888	SERGEY ABRAMOV	{"email": "abramov-sergey1976@postgrespro.ru", "phone": "+70212153318"}
0005435217771	D8A3B1	5404 694079	TATYANA KUDRYASHOVA	{"phone": "+70756608370"}
0005435217772	98DA08	7847 619179	GALINA PETROVA	{"email": "petrova-g-071969@postgrespro.ru", "phone": "+70342684922"}
0005435217773	98DA08	4416 877406	ALEKSEY BELOV	{"phone": "+70749680746"}
0005435217774	CF807F	5894 585082	IRINA KUZNECOVA	{"phone": "+70679042665"}
0005435217775	84E74E	0441 636039	OLEG MIRONOV	{"email": "oleg_mironov.121979@postgrespro.ru", "phone": "+70242015795"}
0005435218099	A99753	5019 461410	MAKSIM KUZMIN	{"phone": "+70875581242"}
0005435218100	07961B	3124 010342	VYACHESLAV GAVRILOV	{"email": "v-gavrilov-031984@postgrespro.ru", "phone": "+70686494933"}
0005435218101	D96743	0506 386860	VASILIY SERGEEV	{"phone": "+70525318412"}
0005435218102	1BDB61	7421 919036	OKSANA FROLOVA	{"email": "frolovaoksana-071987@postgrespro.ru", "phone": "+70295107076"}
0005435218103	A07EF3	2649 609823	VLADIMIR IVANOV	{"email": "v.ivanov_111982@postgrespro.ru", "phone": "+70034898063"}
0005435218104	9FF5C1	1173 956679	POLINA FILATOVA	{"phone": "+70359635968"}
0005435218105	56AEBD	6763 319171	VASILIY KUZNECOV	{"phone": "+70330653587"}
0005435218106	56AEBD	2386 215739	YULIYA ZAYCEVA	{"email": "zayceva.y_121962@postgrespro.ru", "phone": "+70077710367"}
0005435218107	3BDBFF	5570 474257	ALEKSANDR GORBUNOV	{"phone": "+70535412367"}
0005435218108	E80CDB	4957 155894	VALENTINA GAVRILOVA	{"phone": "+70774394558"}
0005435218109	76606A	6788 109313	TATYANA KUZNECOVA	{"phone": "+70095443345"}
0005435218110	D7BE70	0862 421099	OLGA ALEKSEEVA	{"email": "alekseeva.olga_061976@postgrespro.ru", "phone": "+70543840013"}
0005435218111	D7BE70	5609 370069	NATALYA CHERNOVA	{"phone": "+70432145420"}
0005435218112	63EFBE	4173 111162	ZINAIDA SOROKINA	{"phone": "+70491744673"}
0005435218113	701873	9881 143952	NATALYA KRASNOVA	{"phone": "+70755402916"}
0005435218114	37B1E5	9678 984597	ALEKSANDRA SOKOLOVA	{"email": "sokolova.aleksandra.09061970@postgrespro.ru", "phone": "+70678281821"}
0005435218115	FA9535	8999 174076	GENNADIY SHEVCHENKO	{"email": "g_shevchenko17081972@postgrespro.ru", "phone": "+70636483292"}
0005435218116	A28529	8453 612724	IVAN MAKAROV	{"email": "ivanmakarov.1968@postgrespro.ru", "phone": "+70674009570"}
0005435218117	8CD07E	0358 027692	SERGEY TARASOV	{"phone": "+70125093157"}
0005435218118	FE333D	9907 004659	MAKSIM EGOROV	{"email": "egorov-m-1974@postgrespro.ru", "phone": "+70151817565"}
0005435218119	765D5F	2789 980644	NINA ZOTOVA	{"phone": "+70995081002"}
0005435218120	6CC2C3	2076 146033	ALEKSEY VLASOV	{"phone": "+70573746504"}
0005435218121	5ABC76	5491 284881	ANNA PAVLOVA	{"phone": "+70985335215"}
0005435218122	2DBE97	2705 317372	MARIYA VLASOVA	{"phone": "+70938817863"}
0005435218123	D53FA8	9326 346269	ANNA KOZLOVA	{"phone": "+70627227526"}
0005435218124	487F41	3002 134920	EVGENIY SEMENOV	{"email": "semenov.e-1977@postgrespro.ru", "phone": "+70585246871"}
0005435218125	487F41	1544 915909	IRINA KUZNECOVA	{"email": "ikuznecova.1972@postgrespro.ru", "phone": "+70660431072"}
0005435218126	55E0BA	1672 203461	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova-1971@postgrespro.ru", "phone": "+70903330268"}
0005435218127	55E0BA	1812 889092	MIKHAIL VLASOV	{"phone": "+70731180465"}
0005435218128	71AB4C	7812 452541	YURIY TIMOFEEV	{"email": "timofeev_y.27101971@postgrespro.ru", "phone": "+70815989928"}
0005435218129	7CD4DF	4709 289031	OLEG MARTYNOV	{"email": "o.martynov_08091978@postgrespro.ru", "phone": "+70151308431"}
0005435218130	0A5C58	2595 045178	VERA SERGEEVA	{"phone": "+70260987441"}
0005435218131	0A5C58	4241 444580	NINA MOROZOVA	{"email": "n.morozova_111973@postgrespro.ru", "phone": "+70766438973"}
0005435218132	D8FFBB	7073 243457	NATALYA ALEKSEEVA	{"phone": "+70980582934"}
0005435218133	2B7C5F	1165 428728	NADEZHDA OSIPOVA	{"email": "nadezhdaosipova.1973@postgrespro.ru", "phone": "+70001973404"}
0005435218134	FB5DD6	2513 735451	NINA POPOVA	{"email": "popovan05121972@postgrespro.ru", "phone": "+70410411691"}
0005435218135	FB5DD6	4531 557189	DENIS KONOVALOV	{"email": "deniskonovalov-091973@postgrespro.ru", "phone": "+70442647113"}
0005435218136	78990F	9724 252720	GALINA POPOVA	{"phone": "+70000480313"}
0005435218137	78990F	5061 433660	ALEKSEY SMIRNOV	{"phone": "+70466990192"}
0005435218138	218D1C	6426 963083	ELENA MATVEEVA	{"phone": "+70084819301"}
0005435218139	585F98	8088 399853	ANNA TROFIMOVA	{"phone": "+70282984315"}
0005435218140	585F98	3480 574880	VIKTORIYA ZAYCEVA	{"phone": "+70701687712"}
0005435218141	585F98	0588 622964	ELENA AKIMOVA	{"phone": "+70795160815"}
0005435218142	F000F3	9032 451376	VADIM NIKITIN	{"email": "nikitin.v-15101977@postgrespro.ru", "phone": "+70644134929"}
0005435218143	97DD43	2532 042984	OLGA RODIONOVA	{"email": "olga-rodionova-28031963@postgrespro.ru", "phone": "+70733907376"}
0005435218144	C822E4	0397 055884	BOGDAN FROLOV	{"email": "frolov.bogdan-14011973@postgrespro.ru", "phone": "+70156777365"}
0005435218145	43483F	3787 708194	IRINA FOMINA	{"phone": "+70449039575"}
0005435218146	35C7AC	9170 787100	NIKOLAY PETROV	{"email": "petrov_n.041960@postgrespro.ru", "phone": "+70162194103"}
0005435219165	FE33F3	6731 737788	VLADIMIR EGOROV	{"phone": "+70280969267"}
0005435219166	2DE3C5	4025 266440	VIKTOR GUSEV	{"phone": "+70643799995"}
0005435219167	B928EF	9324 703735	KONSTANTIN GUSEV	{"email": "gusev_konstantin.1977@postgrespro.ru", "phone": "+70927506696"}
0005435219168	5D8E83	7375 987085	VLADIMIR BELOV	{"email": "vladimirbelov.18071971@postgrespro.ru", "phone": "+70379320452"}
0005435219169	30BB3C	0120 202316	ALEKSEY KONOVALOV	{"email": "a.konovalov-04041970@postgrespro.ru", "phone": "+70266335401"}
0005435219170	664C29	7099 232627	KONSTANTIN ALEKSANDROV	{"email": "aleksandrov.k08061980@postgrespro.ru", "phone": "+70401564324"}
0005435219171	AC9FDF	8764 395727	ALEKSANDR KARPOV	{"phone": "+70128900132"}
0005435219172	AC9FDF	6070 228475	ANASTASIYA DMITRIEVA	{"email": "anastasiya_dmitrieva-1976@postgrespro.ru", "phone": "+70153733305"}
0005435219173	8F352D	9572 085682	GALINA IVANOVA	{"email": "g.ivanova-02051972@postgrespro.ru", "phone": "+70013993036"}
0005435219174	8B4FA7	0900 207689	LIDIYA KUZMINA	{"email": "l-kuzmina.051974@postgrespro.ru", "phone": "+70604731464"}
0005435219175	7B408A	3578 286975	MARINA KUZNECOVA	{"phone": "+70323479903"}
0005435219176	CA02B3	3824 604351	NATALYA OVCHINNIKOVA	{"phone": "+70460633085"}
0005435219177	1336F7	3838 200343	ILYA ANTONOV	{"phone": "+70560622572"}
0005435219178	BC77CB	0689 613862	MILANA FROLOVA	{"email": "m-frolova27051986@postgrespro.ru", "phone": "+70253629297"}
0005435219179	B301C4	1770 604751	OKSANA IVANOVA	{"phone": "+70743382303"}
0005435219180	F4E206	7530 838178	ALEKSANDR MIRONOV	{"phone": "+70546659663"}
0005435219181	F142FD	2037 496217	LYUDMILA BORISOVA	{"phone": "+70710454305"}
0005435219182	0C0524	9300 460532	OLGA SOROKINA	{"phone": "+70286076603"}
0005435219183	85839A	6898 495854	ANZHELIKA KONDRATEVA	{"email": "anzhelika_kondrateva.041963@postgrespro.ru", "phone": "+70745878534"}
0005435219184	AA8471	0122 813398	IVAN BORISOV	{"phone": "+70509331682"}
0005435219185	AA8471	6077 992276	ANNA SIDOROVA	{"email": "sidorova.anna.021969@postgrespro.ru", "phone": "+70619916811"}
0005435219186	AA8471	3250 271457	LYUDMILA GRISHINA	{"email": "l_grishina_011975@postgrespro.ru", "phone": "+70718014220"}
0005435219187	1811F2	9709 165651	OKSANA IVANOVA	{"email": "oivanova_07081970@postgrespro.ru", "phone": "+70128488032"}
0005435219188	16221D	1226 453252	IRINA PAVLOVA	{"email": "pavlova.i021972@postgrespro.ru", "phone": "+70219994081"}
0005435219189	EBB92A	0091 736794	ELENA ZAKHAROVA	{"email": "e.zakharova_081974@postgrespro.ru", "phone": "+70258950561"}
0005435219190	EBB92A	7379 708973	EVGENIY GORBUNOV	{"email": "gorbunov-e.1976@postgrespro.ru", "phone": "+70726500173"}
0005435219191	EBB92A	7038 840634	DMITRIY PAVLOV	{"email": "pavlov-d.1977@postgrespro.ru", "phone": "+70838592826"}
0005435219192	0F53D9	6966 376477	ELENA YUDINA	{"email": "elena_yudina-1966@postgrespro.ru", "phone": "+70636367385"}
0005435219193	898B2D	9292 071196	VYACHESLAV KARPOV	{"phone": "+70361264092"}
0005435219194	194DCA	7388 251938	NIKOLAY AFANASEV	{"email": "afanasev-nikolay_051976@postgrespro.ru", "phone": "+70898462288"}
0005435219195	194DCA	4637 233657	NATALYA IVANOVA	{"phone": "+70670826270"}
0005435219196	D2A329	0484 080155	YURIY SMIRNOV	{"email": "smirnov.yuriy-041977@postgrespro.ru", "phone": "+70479882472"}
0005435219197	1F96E9	9995 388971	IRINA ISAEVA	{"email": "isaeva.i-07051969@postgrespro.ru", "phone": "+70383876227"}
0005435219198	1F96E9	8872 656838	MIKHAIL FEDOROV	{"email": "fedorov.m-14021973@postgrespro.ru", "phone": "+70670932102"}
0005435219199	474784	9566 848347	ELENA KUZNECOVA	{"phone": "+70780386789"}
0005435219200	474784	6158 634288	IVAN MOISEEV	{"phone": "+70038668956"}
0005435219201	FF2C14	8567 833131	LILIYA IVANOVA	{"phone": "+70990164403"}
0005435219202	ADA66F	2346 580800	DENIS SAVELEV	{"email": "denis-savelev.1978@postgrespro.ru", "phone": "+70620439027"}
0005435219203	ADA66F	4107 991330	SVETLANA AKIMOVA	{"email": "svetlanaakimova1968@postgrespro.ru", "phone": "+70589341920"}
0005435219204	25336E	4052 568580	NADEZHDA KOROLEVA	{"phone": "+70330635845"}
0005435219205	F53114	9792 324309	OLEG SIDOROV	{"phone": "+70044190451"}
0005435219206	D14C3F	9577 207284	SERGEY FOMIN	{"email": "sergeyfomin_1979@postgrespro.ru", "phone": "+70107033433"}
0005435219207	D14C3F	7966 026098	OLGA SMIRNOVA	{"phone": "+70603475209"}
0005435219208	D14C3F	3053 760293	ZULFIYA LAZAREVA	{"email": "lazareva.zulfiya-091980@postgrespro.ru", "phone": "+70899337358"}
0005435219209	01F716	4082 886835	EVGENIY KRASNOV	{"email": "e.krasnov_041968@postgrespro.ru", "phone": "+70612835499"}
0005435219210	01F716	8458 858251	OLGA FADEEVA	{"phone": "+70031659556"}
0005435219211	6AD3C6	2857 243508	NATALYA SMIRNOVA	{"email": "nsmirnova-13021968@postgrespro.ru", "phone": "+70944268119"}
0005435219212	7B0284	1308 936629	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr-081970@postgrespro.ru", "phone": "+70836072901"}
0005435219213	C8CFEF	9857 246390	YULIYA MELNIKOVA	{"email": "y_melnikova.1972@postgrespro.ru", "phone": "+70963257690"}
0005435219214	159250	9309 715655	VLADIMIR ILIN	{"email": "vladimirilin-071979@postgrespro.ru", "phone": "+70586190679"}
0005435219215	159250	0309 312819	ANDREY MOROZOV	{"phone": "+70325394069"}
0005435219216	10A641	6789 749379	SERGEY MAKSIMOV	{"email": "s-maksimov1966@postgrespro.ru", "phone": "+70108492882"}
0005435219217	CFA280	2845 390145	TATYANA BORISOVA	{"email": "t.borisova1963@postgrespro.ru", "phone": "+70687441652"}
0005435219218	92725E	7050 396500	SVETLANA BORISOVA	{"email": "s-borisova_021979@postgrespro.ru", "phone": "+70063281061"}
0005435219219	C03688	4113 219712	NADEZHDA KONDRATEVA	{"email": "kondrateva-n-1973@postgrespro.ru", "phone": "+70147269882"}
0005435219220	C03688	7159 759610	SVETLANA VOROBEVA	{"phone": "+70057471069"}
0005435219221	47DB29	7054 422585	ALEKSEY MIRONOV	{"email": "mironovaleksey.121975@postgrespro.ru", "phone": "+70014307447"}
0005435219222	47DB29	5202 075561	LIDIYA EGOROVA	{"phone": "+70726838041"}
0005435219223	7EBCCC	2879 849351	GALINA MAKAROVA	{"email": "galina-makarova1979@postgrespro.ru", "phone": "+70259234340"}
0005435219224	2AD210	1978 046602	VIKTOR GRIGOREV	{"email": "viktor-grigorev20051979@postgrespro.ru", "phone": "+70656727892"}
0005435219225	6BFDEF	2615 615269	OLGA TIKHONOVA	{"email": "olga_tikhonova-1973@postgrespro.ru", "phone": "+70991534258"}
0005435219226	6BFDEF	9793 764252	EKATERINA POPOVA	{"email": "popova-e_1977@postgrespro.ru", "phone": "+70776878072"}
0005435219227	4B5E0E	5892 296375	VLADIMIR DENISOV	{"phone": "+70037741736"}
0005435219228	1AEAB6	1255 745035	LYUDMILA ZAKHAROVA	{"email": "zakharova-l.03091970@postgrespro.ru", "phone": "+70638357417"}
0005435219229	F4F678	2283 977086	SERGEY BELOV	{"phone": "+70388488441"}
0005435219230	91A094	7859 541207	NIKOLAY KUZNECOV	{"phone": "+70413090419"}
0005435219231	16B16E	8237 805295	SERGEY VASILEV	{"email": "s.vasilev-111981@postgrespro.ru", "phone": "+70425892132"}
0005435219232	867504	4723 449270	MARIYA SEMENOVA	{"phone": "+70491594394"}
0005435219233	3A7E14	4718 352752	OLGA SAVELEVA	{"email": "saveleva_olga_07011964@postgrespro.ru", "phone": "+70714142290"}
0005435219234	8C184E	7846 606184	OKSANA SOKOLOVA	{"phone": "+70486897357"}
0005435219235	8C184E	7897 129269	VARVARA SIDOROVA	{"email": "sidorova.v-1974@postgrespro.ru", "phone": "+70018400087"}
0005435219236	428800	7179 895180	ARTEM KARPOV	{"phone": "+70558943107"}
0005435219237	D5ACD5	0907 546593	DANIIL IVANOV	{"email": "ivanov_daniil-051980@postgrespro.ru", "phone": "+70106895853"}
0005435219238	493AB0	1085 705942	MAKSIM MATVEEV	{"email": "matveev.maksim_1969@postgrespro.ru", "phone": "+70737250266"}
0005435219239	73E9AC	4882 759030	ANNA KUZNECOVA	{"email": "anna-kuznecova101964@postgrespro.ru", "phone": "+70016126803"}
0005435219240	DAE06C	7341 970102	SVETLANA SIDOROVA	{"phone": "+70706570305"}
0005435219241	B6446C	1858 296126	SERGEY BORISOV	{"email": "borisovsergey-03031968@postgrespro.ru", "phone": "+70351724702"}
0005435219242	B6446C	4584 841273	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr-121971@postgrespro.ru", "phone": "+70838647863"}
0005435219243	B6446C	6867 528366	EKATERINA PETROVA	{"email": "petrova_ekaterina.1957@postgrespro.ru", "phone": "+70582949374"}
0005435219244	83817D	3173 348490	ANDREY SEMENOV	{"phone": "+70135849085"}
0005435219245	6832AD	9367 342464	YURIY ILIN	{"email": "y-ilin061968@postgrespro.ru", "phone": "+70937941769"}
0005435219246	0C7D6E	0592 576345	ANZHELA KOVALEVA	{"email": "kovaleva.anzhela_1975@postgrespro.ru", "phone": "+70991527497"}
0005435219247	373B4C	2592 408037	LYUBOV DMITRIEVA	{"phone": "+70472910764"}
0005435219248	1ED40B	8178 293600	KIRILL KOZLOV	{"phone": "+70010723382"}
0005435219249	529A41	9814 638934	ALEKSANDR ZAKHAROV	{"email": "a_zakharov_1978@postgrespro.ru", "phone": "+70573001344"}
0005435219250	529A41	7985 444688	ELENA VOLKOVA	{"email": "elenavolkova-091971@postgrespro.ru", "phone": "+70376793578"}
0005435219251	1AF529	4577 048814	VYACHESLAV PAVLOV	{"phone": "+70102751783"}
0005435219252	1AF529	1437 590194	YURIY KUZNECOV	{"phone": "+70351476685"}
0005435219253	AD0503	1349 434969	ALEKSANDR SMIRNOV	{"phone": "+70197799058"}
0005435219254	076874	9489 084504	ALEKSEY MOROZOV	{"phone": "+70749419502"}
0005435219255	076874	0776 513972	ANDREY MEDVEDEV	{"email": "medvedeva-051968@postgrespro.ru", "phone": "+70556391294"}
0005435219256	D8307E	4953 943805	IVAN VOROBEV	{"email": "vorobevivan.051973@postgrespro.ru", "phone": "+70258445678"}
0005435219257	B7EBAD	8176 013409	SEMEN MATVEEV	{"email": "s-matveev1970@postgrespro.ru", "phone": "+70936110361"}
0005435219258	596A4D	3344 970420	MARIYA MIRONOVA	{"phone": "+70478427340"}
0005435219259	E565AB	9263 025362	YULIYA ABRAMOVA	{"email": "yabramova-1972@postgrespro.ru", "phone": "+70244715894"}
0005435219260	DA1F3C	9794 447671	IGOR POPOV	{"email": "popovi-11021980@postgrespro.ru", "phone": "+70212429750"}
0005435219261	A66B7E	5314 329807	TATYANA MASLOVA	{"phone": "+70401818395"}
0005435219262	A66B7E	7855 375020	POLINA OSIPOVA	{"email": "p_osipova_02031960@postgrespro.ru", "phone": "+70469303348"}
0005435219263	5078DC	8819 127474	LIDIYA DAVYDOVA	{"phone": "+70943741268"}
0005435219264	5A77A7	6457 645243	NIKOLAY SOROKIN	{"phone": "+70170034652"}
0005435219265	D78CF6	3236 026325	ALEKSEY BELOV	{"email": "belova.121972@postgrespro.ru", "phone": "+70203129867"}
0005435220283	F9D408	7577 110398	RUSLAN ZHUKOV	{"phone": "+70152292313"}
0005435220284	76AC46	1068 240185	RUSLAN BELOV	{"email": "ruslanbelov_1981@postgrespro.ru", "phone": "+70975715907"}
0005435220285	9D9C72	1947 466354	ILONA NIKIFOROVA	{"phone": "+70231169627"}
0005435220286	6D1750	7113 748848	NADEZHDA MOROZOVA	{"email": "nadezhdamorozova041975@postgrespro.ru", "phone": "+70178878804"}
0005435220287	6D1750	7609 801518	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev031967@postgrespro.ru", "phone": "+70680071527"}
0005435220288	6D1750	7728 507894	SERGEY ZAKHAROV	{"phone": "+70668202135"}
0005435220289	925614	9724 472228	VLADISLAV ROMANOV	{"phone": "+70799710731"}
0005435220290	925614	6345 654734	DENIS KUZNECOV	{"email": "kuznecov-denis06051978@postgrespro.ru", "phone": "+70144846259"}
0005435220291	67C8A6	5925 984107	LYUDMILA DMITRIEVA	{"email": "dmitrieva-lyudmila-101970@postgrespro.ru", "phone": "+70162859390"}
0005435220292	67D09A	3758 000807	LIDIYA MAKAROVA	{"phone": "+70364641982"}
0005435220293	258FA9	6280 367254	NIKITA SMIRNOV	{"email": "smirnov_n-03091972@postgrespro.ru", "phone": "+70129970522"}
0005435220294	258FA9	6244 952053	VALENTINA IVANOVA	{"phone": "+70541099886"}
0005435220295	1699DA	6949 720830	ALEKSANDR KULIKOV	{"email": "akulikov-26041962@postgrespro.ru", "phone": "+70001274207"}
0005435220296	1C186D	8959 242900	EVGENIY KOZLOV	{"email": "evgeniy_kozlov_071969@postgrespro.ru", "phone": "+70610978810"}
0005435220297	7C0E1C	7932 441079	VALERIY KUZNECOV	{"email": "valeriykuznecov_051968@postgrespro.ru", "phone": "+70117460181"}
0005435220298	7C0E1C	8271 641955	EKATERINA VOROBEVA	{"phone": "+70902938270"}
0005435220299	7C0E1C	2935 652869	LARISA MALYSHEVA	{"phone": "+70083484586"}
0005435220300	7034F4	1317 508098	LARISA LOGINOVA	{"phone": "+70170753106"}
0005435220301	C4A743	8596 061157	MARAT SERGEEV	{"phone": "+70239701170"}
0005435220302	C4A743	8001 438398	LARISA ILINA	{"phone": "+70143065565"}
0005435220303	4868DF	7850 453873	IGOR GUSEV	{"phone": "+70884575043"}
0005435220304	C0639E	5971 013097	ANASTASIYA BELOVA	{"phone": "+70402759371"}
0005435220305	8EFD56	6750 932019	VASILIY VOROBEV	{"phone": "+70970696762"}
0005435220306	C68B86	9978 287491	VARVARA DENISOVA	{"phone": "+70509395094"}
0005435220307	48396D	8300 828377	VLADIMIR NOVIKOV	{"email": "novikovv_1966@postgrespro.ru", "phone": "+70231948541"}
0005435220308	A4C5C5	0552 332795	NIKITA VASILEV	{"email": "vasilev.n091975@postgrespro.ru", "phone": "+70104642306"}
0005435220309	A4C5C5	9450 644830	LYUDMILA SMIRNOVA	{"email": "smirnovalyudmila.1974@postgrespro.ru", "phone": "+70817821559"}
0005435220310	A4C5C5	6648 655774	ANTON GERASIMOV	{"phone": "+70602656326"}
0005435220311	0FD77A	8012 816938	IRINA ZAKHAROVA	{"email": "zakharova-irina-03051967@postgrespro.ru", "phone": "+70555054207"}
0005435220312	C1F652	0915 802221	SVETLANA ANISIMOVA	{"email": "s.anisimova-1966@postgrespro.ru", "phone": "+70048785697"}
0005435220313	8BD36A	7078 356211	PETR PETROV	{"phone": "+70299560333"}
0005435220314	69181A	3495 756076	GALINA MIKHAYLOVA	{"email": "mikhaylova.galina.061975@postgrespro.ru", "phone": "+70658074545"}
0005435220315	69181A	8028 036034	OLESYA DMITRIEVA	{"phone": "+70244232319"}
0005435220316	9BD302	8868 045653	ANATOLIY KUZMIN	{"email": "a-kuzmin.1957@postgrespro.ru", "phone": "+70047411235"}
0005435220317	A8E929	9405 539808	IRINA KONOVALOVA	{"email": "konovalovairina1979@postgrespro.ru", "phone": "+70447215236"}
0005435220318	E34C04	0483 732293	YULIYA MATVEEVA	{"phone": "+70844116793"}
0005435220319	4BD7EF	2510 915181	LYUDMILA LUKYANOVA	{"phone": "+70615846339"}
0005435220320	BF0C93	6792 065791	ANDREY POPOV	{"email": "a-popov-1962@postgrespro.ru", "phone": "+70809737627"}
0005435220321	BF0C93	4905 297707	MIKHAIL GRIGOREV	{"email": "grigorevm-1964@postgrespro.ru", "phone": "+70148523164"}
0005435220322	2096D4	0473 760241	LARISA OVCHINNIKOVA	{"phone": "+70080388794"}
0005435220323	EF68FE	4023 962253	MARINA PETROVA	{"phone": "+70277226314"}
0005435220324	D2B89A	3108 451243	LILIYA KULIKOVA	{"email": "liliyakulikova.1974@postgrespro.ru", "phone": "+70447542125"}
0005435220325	817129	4170 090897	VASILIY KOROLEV	{"phone": "+70085014415"}
0005435220326	F8DDEE	4349 739451	ALEKSEY FILIPPOV	{"phone": "+70713564925"}
0005435220327	F8DDEE	3444 017738	POLINA FEDOROVA	{"phone": "+70872825877"}
0005435220386	EE7839	3363 982994	MAKSIM SMIRNOV	{"email": "m-smirnov.06091965@postgrespro.ru", "phone": "+70448317087"}
0005435220328	871C81	0087 578494	ALEKSANDRA TARASOVA	{"email": "aleksandra_tarasova.29041970@postgrespro.ru", "phone": "+70163492888"}
0005435220329	0412F7	0234 693946	ANDREY VASILEV	{"email": "andrey_vasilev-20081976@postgrespro.ru", "phone": "+70464123330"}
0005435220330	4034D9	9023 336897	MIKHAIL NOVIKOV	{"phone": "+70326060048"}
0005435220331	8363BC	6543 700975	ALENA SIDOROVA	{"phone": "+70712935182"}
0005435220332	8363BC	4215 683022	ANNA PAVLOVA	{"email": "pavlova.anna.091964@postgrespro.ru", "phone": "+70841758904"}
0005435220333	AC4878	4167 214501	LYUBOV ZHUKOVA	{"email": "zhukova-l.05051966@postgrespro.ru", "phone": "+70664481834"}
0005435220334	9F242B	3867 235110	SERGEY MOROZOV	{"email": "sergey_morozov-1958@postgrespro.ru", "phone": "+70053073373"}
0005435220335	6F040D	0698 325180	VLADIMIR FEDOROV	{"phone": "+70904371007"}
0005435220336	69B136	4780 763911	BORIS FEDOROV	{"email": "fedorov.b1978@postgrespro.ru", "phone": "+70881269457"}
0005435220337	E8C44D	8297 047066	EKATERINA RYABOVA	{"email": "ekaterina-ryabova-031966@postgrespro.ru", "phone": "+70421228036"}
0005435220338	E8C44D	6671 906539	MARIYA DAVYDOVA	{"email": "mariya_davydova-081973@postgrespro.ru", "phone": "+70085888987"}
0005435220339	E8C44D	9544 352329	LYUBOV PETROVA	{"email": "petrova.lyubov041971@postgrespro.ru", "phone": "+70321886598"}
0005435220340	56B8FC	0362 260754	ALINA ILINA	{"email": "ailina-24091971@postgrespro.ru", "phone": "+70592214560"}
0005435220341	6E7F84	6810 793765	RAISA ABRAMOVA	{"phone": "+70331569551"}
0005435220342	CCCF4A	1159 968794	YURIY IVANOV	{"phone": "+70525984248"}
0005435220343	CCCF4A	4353 762384	NINA KUZNECOVA	{"phone": "+70945554124"}
0005435220344	CD4DEA	4171 382012	YULIYA ALEKSANDROVA	{"email": "aleksandrova-yuliya_20071972@postgrespro.ru", "phone": "+70707137966"}
0005435220345	62CBEC	7908 505283	VLADIMIR KOZLOV	{"email": "vladimir.kozlov-1975@postgrespro.ru", "phone": "+70051095231"}
0005435220346	3699AC	4918 951618	OLGA VOLKOVA	{"email": "volkova-o_27041976@postgrespro.ru", "phone": "+70535683236"}
0005435220347	3699AC	4025 787466	EKATERINA PETROVA	{"email": "petrova-ekaterina111966@postgrespro.ru", "phone": "+70212862343"}
0005435220348	3699AC	5210 550643	SERGEY EGOROV	{"email": "sergeyegorov_1958@postgrespro.ru", "phone": "+70874312259"}
0005435220349	1DCB51	5068 902340	NATALYA MIKHAYLOVA	{"phone": "+70988423807"}
0005435220350	4670AB	4440 913612	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov_18071976@postgrespro.ru", "phone": "+70038113042"}
0005435220351	4670AB	6052 319033	RAFIK GORBUNOV	{"phone": "+70666037995"}
0005435220352	4702A3	0593 066099	IRINA ZHUKOVA	{"email": "zhukovai_11121982@postgrespro.ru", "phone": "+70988877962"}
0005435220353	2E231A	6181 260976	ANATOLIY GRIGOREV	{"email": "anatoliy_grigorev_1976@postgrespro.ru", "phone": "+70649230512"}
0005435220354	4A561F	4817 898637	OLGA KAZAKOVA	{"email": "kazakova-o24101970@postgrespro.ru", "phone": "+70249317735"}
0005435220355	A28E10	6142 635790	RAFAIL KAZAKOV	{"phone": "+70686280174"}
0005435220356	A28E10	6947 122960	NATALYA ZHUKOVA	{"phone": "+70763904816"}
0005435220357	DC006F	0880 478139	MARIYA ZHUKOVA	{"phone": "+70525406440"}
0005435220358	764A95	8955 069578	ANTONINA ZHUKOVA	{"email": "antonina-zhukova14111980@postgrespro.ru", "phone": "+70459038621"}
0005435220359	8944A3	7380 247159	ALEKSEY MIRONOV	{"phone": "+70057991145"}
0005435220360	D7906E	8790 660647	VIKTOR YAKOVLEV	{"phone": "+70757762944"}
0005435220361	D7906E	9197 830101	LYUDMILA POPOVA	{"phone": "+70589587585"}
0005435220362	D7906E	9428 820939	ANATOLIY KUZNECOV	{"email": "anatoliy-kuznecov031983@postgrespro.ru", "phone": "+70047988576"}
0005435220363	4A3E1F	7174 822249	RAISA KOVALEVA	{"email": "kovaleva-r.121967@postgrespro.ru", "phone": "+70861233936"}
0005435220364	0E33FF	6623 312204	OLGA NOVIKOVA	{"email": "novikova-o-1976@postgrespro.ru", "phone": "+70245887768"}
0005435220365	0E33FF	8971 129362	NATALYA VOLKOVA	{"email": "volkova-n-1971@postgrespro.ru", "phone": "+70416398536"}
0005435220366	F608DB	0976 392155	OLGA TARASOVA	{"email": "o.tarasova_1966@postgrespro.ru", "phone": "+70720630651"}
0005435220367	777A9C	7451 460157	VLADIMIR RODIONOV	{"phone": "+70562101649"}
0005435220368	8F3C4C	6430 543884	OKSANA IVANOVA	{"phone": "+70436437157"}
0005435220369	8F3C4C	3001 173462	DENIS BORISOV	{"email": "borisov-denis-1979@postgrespro.ru", "phone": "+70909884470"}
0005435220370	93104A	7263 056545	YAN ILIN	{"email": "ilin.yan_1970@postgrespro.ru", "phone": "+70042312489"}
0005435220371	A7C4E2	7515 279190	OLESYA ANDREEVA	{"email": "o.andreeva-05061963@postgrespro.ru", "phone": "+70970163510"}
0005435220372	A7D640	3041 013555	EDUARD KARPOV	{"email": "e.karpov_101967@postgrespro.ru", "phone": "+70281132978"}
0005435220373	A7D640	5992 122085	RODION ROMANOV	{"email": "r-romanov.1967@postgrespro.ru", "phone": "+70379971147"}
0005435220374	4F8E9D	2301 914448	VADIM BONDARENKO	{"email": "bondarenko_vadim-1962@postgrespro.ru", "phone": "+70614126724"}
0005435220375	63A7CC	7856 233608	OLGA KOZLOVA	{"phone": "+70632299466"}
0005435220376	3901F8	7375 096212	ALINA ROMANOVA	{"email": "alina_romanova-18021970@postgrespro.ru", "phone": "+70552951147"}
0005435220377	8912E3	3201 941897	ANASTASIYA SIDOROVA	{"email": "sidorovaa.10041972@postgrespro.ru", "phone": "+70896699605"}
0005435220378	C2E68D	3821 263870	ROMAN BARANOV	{"phone": "+70527407397"}
0005435220379	EEE73B	6870 475008	DMITRIY GERASIMOV	{"phone": "+70168955043"}
0005435220380	EEE73B	8836 272093	ANDREY KRASNOV	{"phone": "+70516656368"}
0005435220381	89F45E	3060 985192	EVGENIY SERGEEV	{"email": "sergeev-e_121968@postgrespro.ru", "phone": "+70600523716"}
0005435220382	89F45E	6913 616087	MARINA AFANASEVA	{"email": "afanaseva_marina011969@postgrespro.ru", "phone": "+70635608633"}
0005435220383	EA460E	4477 470381	LYUBOV DMITRIEVA	{"email": "dmitrieva_l-071976@postgrespro.ru", "phone": "+70156558249"}
0005435220384	7C2122	2278 544620	NIKOLAY NIKITIN	{"phone": "+70423532844"}
0005435220385	7C2122	5309 911800	VALENTINA STEPANOVA	{"phone": "+70815419556"}
0005435220488	93B5D4	4089 662479	VLADIMIR PETROV	{"phone": "+70914479720"}
0005435220489	0328BE	6809 103935	LYUCIYA VLASOVA	{"phone": "+70879026034"}
0005435220490	82E108	9145 394842	VALENTIN IVANOV	{"email": "ivanov-v_22021973@postgrespro.ru", "phone": "+70693037747"}
0005435220491	8316BD	9997 088374	TATYANA FILATOVA	{"email": "t-filatova1969@postgrespro.ru", "phone": "+70182515013"}
0005435220492	DDCD6E	2071 398278	TAMARA ORLOVA	{"phone": "+70453353472"}
0005435220493	B52C0C	7471 449860	LYUDMILA VOLKOVA	{"email": "volkova_lyudmila.071971@postgrespro.ru", "phone": "+70327415258"}
0005435220494	153D3E	8140 995891	EVGENIY ALEKSEEV	{"phone": "+70709379810"}
0005435220495	FCBB39	9453 832257	VLADIMIR TARASOV	{"email": "tarasov_v-01061968@postgrespro.ru", "phone": "+70041215563"}
0005435220496	7BF87A	7599 730248	ALEKSANDR RODIONOV	{"phone": "+70199662305"}
0005435220497	13C539	6301 630472	OLESYA GORBUNOVA	{"email": "gorbunova_o.111974@postgrespro.ru", "phone": "+70832630119"}
0005435220498	D4CAAB	7551 989609	IRINA PAVLOVA	{"email": "pavlova.irina_1966@postgrespro.ru", "phone": "+70881788351"}
0005435220499	DD43C2	1494 457884	TATYANA YAKOVLEVA	{"email": "tatyana.yakovleva.031974@postgrespro.ru", "phone": "+70425883340"}
0005435220500	DD43C2	2824 326665	YURIY RODIONOV	{"phone": "+70573550951"}
0005435220501	C586F7	9583 305849	VALENTINA MEDVEDEVA	{"email": "v.medvedeva-15011961@postgrespro.ru", "phone": "+70142829968"}
0005435220502	C586F7	2322 735264	ALEKSANDR EGOROV	{"phone": "+70011973883"}
0005435220503	2FA7F7	6814 456992	GALINA FEDOROVA	{"email": "g-fedorova_26041977@postgrespro.ru", "phone": "+70362702449"}
0005435220504	2FA7F7	7985 278084	OLGA SEMENOVA	{"email": "o_semenova-20021973@postgrespro.ru", "phone": "+70476279495"}
0005435220505	EFA553	9621 096971	VALENTINA TROFIMOVA	{"email": "valentinatrofimova1962@postgrespro.ru", "phone": "+70497567322"}
0005435220506	F49B09	1195 244664	RINAT ANDREEV	{"email": "rinatandreev_20051969@postgrespro.ru", "phone": "+70585689985"}
0005435220507	F49B09	9704 558131	YULIYA BELYAEVA	{"email": "belyaeva-y-1975@postgrespro.ru", "phone": "+70554326522"}
0005435220508	F49B09	4271 157936	ALEKSANDR FEDOROV	{"phone": "+70233725416"}
0005435220509	39B604	1324 669465	NIKOLAY ROMANOV	{"email": "romanov_n_31011979@postgrespro.ru", "phone": "+70237693531"}
0005435220510	3D2B07	8190 948984	SERGEY KULIKOV	{"phone": "+70952553517"}
0005435220511	D3E450	4625 703353	SERGEY TIKHONOV	{"email": "sergey_tikhonov06021964@postgrespro.ru", "phone": "+70834203715"}
0005435220512	D3E450	5640 257203	LIDIYA SOKOLOVA	{"phone": "+70006252643"}
0005435220513	A59AA8	8926 172222	ALEKSEY SCHERBAKOV	{"phone": "+70750415812"}
0005435220514	92BC35	7522 579306	EVGENIY SHEVCHENKO	{"phone": "+70711457519"}
0005435220515	368613	2647 691857	YURIY FROLOV	{"phone": "+70124867239"}
0005435220516	368613	9448 161791	MARIYA PETROVA	{"email": "petrova-m02041978@postgrespro.ru", "phone": "+70263453275"}
0005435220517	BF2A5F	6202 426356	SVETLANA VLASOVA	{"email": "s.vlasova1972@postgrespro.ru", "phone": "+70900349623"}
0005435220518	BF2A5F	1722 299105	TATYANA EGOROVA	{"email": "tatyana_egorova-1965@postgrespro.ru", "phone": "+70352335788"}
0005435220519	03EC74	1328 359401	ELENA AKIMOVA	{"email": "e.akimova.20121963@postgrespro.ru", "phone": "+70737919419"}
0005435220520	13FF76	6077 376375	NINA KONOVALOVA	{"email": "n.konovalova-101963@postgrespro.ru", "phone": "+70208235183"}
0005435220521	13FF76	8426 779960	PAVEL FOMIN	{"email": "p-fomin1959@postgrespro.ru", "phone": "+70165000144"}
0005435220522	A7EA1A	8965 947368	ANDREY PETROV	{"email": "andrey-petrov_061972@postgrespro.ru", "phone": "+70887062547"}
0005435221035	84E45D	1399 489814	NATALYA ABRAMOVA	{"email": "natalya-abramova_1961@postgrespro.ru", "phone": "+70998787801"}
0005435221036	408E43	7050 126336	VLADIMIR KUZMIN	{"email": "v.kuzmin071969@postgrespro.ru", "phone": "+70023623697"}
0005435221037	EF8A35	8979 842142	OLGA TITOVA	{"phone": "+70708247606"}
0005435221038	E941C0	3710 412777	OKSANA KISELEVA	{"email": "kiseleva_oksana.071970@postgrespro.ru", "phone": "+70479722583"}
0005435221039	E941C0	5153 828039	PETR SMIRNOV	{"email": "smirnovp-1964@postgrespro.ru", "phone": "+70805242655"}
0005435221040	E941C0	5934 840858	NATALYA NESTEROVA	{"email": "natalya.nesterova12011987@postgrespro.ru", "phone": "+70061447225"}
0005435221041	FB0FE6	9234 528849	IVAN ROMANOV	{"email": "ivan-romanov1983@postgrespro.ru", "phone": "+70806359031"}
0005435221042	FB0FE6	0845 359940	MARK SCHERBAKOV	{"email": "mark.scherbakov09121964@postgrespro.ru", "phone": "+70382303195"}
0005435221043	FB0FE6	3376 779063	TATYANA BORISOVA	{"phone": "+70857511595"}
0005435221044	A2A91D	0592 152579	KIRILL TIMOFEEV	{"phone": "+70096772524"}
0005435221045	A2A91D	3220 442511	EKATERINA POPOVA	{"email": "popova_ekaterina1962@postgrespro.ru", "phone": "+70232950209"}
0005435221046	ED989A	8465 343874	DARYA ROMANOVA	{"email": "d.romanova091968@postgrespro.ru", "phone": "+70709071955"}
0005435221047	2B2765	8820 278810	VLADIMIR DENISOV	{"email": "denisov-vladimir_04111982@postgrespro.ru", "phone": "+70010688809"}
0005435221048	A9AA59	5665 660433	MAKSIM AFANASEV	{"phone": "+70611959661"}
0005435221049	A9AA59	9665 250931	LYUBOV KUZNECOVA	{"email": "lkuznecova-1977@postgrespro.ru", "phone": "+70187993260"}
0005435221050	AF4D8E	5360 132380	ALEKSANDR POPOV	{"phone": "+70931838936"}
0005435221051	AF4D8E	4618 797852	ANDREY AFANASEV	{"email": "afanasev.andrey_11021966@postgrespro.ru", "phone": "+70367342174"}
0005435221052	AA2325	5759 685722	OLGA KISELEVA	{"email": "olgakiseleva.051960@postgrespro.ru", "phone": "+70092977172"}
0005435221053	3A50C1	5350 644463	ALEKSANDR EGOROV	{"phone": "+70183150655"}
0005435221054	5DBE71	0771 488692	ANNA ILINA	{"email": "ilina-anna_1975@postgrespro.ru", "phone": "+70320971147"}
0005435221055	C831A8	7712 611703	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr_121965@postgrespro.ru", "phone": "+70641425523"}
0005435221056	C831A8	3556 025755	DMITRIY KONOVALOV	{"phone": "+70949394691"}
0005435225488	0B4C0F	8468 842336	ALEKSEY SAVELEV	{"phone": "+70606720407"}
0005435221057	E8BDF1	0150 183941	LYUDMILA ANTONOVA	{"email": "antonova-lyudmila.1970@postgrespro.ru", "phone": "+70280595843"}
0005435221058	91445B	7474 179971	IRINA KOMAROVA	{"phone": "+70671795032"}
0005435221059	91445B	2202 126340	ZINAIDA STEPANOVA	{"phone": "+70621785110"}
0005435221060	034143	0344 930270	PAVEL MOROZOV	{"phone": "+70484400714"}
0005435221061	CAD0C5	0285 317830	TATYANA ZAKHAROVA	{"phone": "+70526973599"}
0005435221062	62922B	3940 952203	LIDIYA LEBEDEVA	{"email": "lebedeval061967@postgrespro.ru", "phone": "+70739397476"}
0005435221063	62922B	8329 946186	NIKOLAY PETROV	{"email": "nikolay.petrov23041980@postgrespro.ru", "phone": "+70099902288"}
0005435221064	D7166F	9826 449254	YANA KALININA	{"email": "kalinina_y27091967@postgrespro.ru", "phone": "+70384928371"}
0005435221065	D7166F	3334 226689	VLADIMIR TIKHONOV	{"email": "tikhonovv26071973@postgrespro.ru", "phone": "+70398888780"}
0005435221066	0CDDFB	2176 505680	YULIYA SERGEEVA	{"phone": "+70153021201"}
0005435221067	4A0C01	0272 291354	NADEZHDA ZHURAVLEVA	{"email": "zhuravleva-n-031970@postgrespro.ru", "phone": "+70949517171"}
0005435221068	501BF8	8880 366539	LIDIYA ANTONOVA	{"email": "antonova.l_1975@postgrespro.ru", "phone": "+70706086760"}
0005435221069	951733	1409 659263	TATYANA MARTYNOVA	{"email": "tatyana-martynova-28011961@postgrespro.ru", "phone": "+70639472211"}
0005435221070	951733	3161 278635	YURIY MOROZOV	{"email": "yuriymorozov.1974@postgrespro.ru", "phone": "+70391900889"}
0005435221071	C5E6E9	1679 887735	VIKTOR AFANASEV	{"email": "afanasev-viktor_101980@postgrespro.ru", "phone": "+70741264933"}
0005435221072	28280A	2767 844397	ANDREY BARANOV	{"phone": "+70529661824"}
0005435221073	25BE3E	7848 546390	ELENA MELNIKOVA	{"phone": "+70980066261"}
0005435221074	25BE3E	5550 774585	VLADISLAV MATVEEV	{"email": "matveev-v.1959@postgrespro.ru", "phone": "+70415799917"}
0005435221075	124330	5590 833309	DARYA SERGEEVA	{"email": "sergeeva_darya-16101958@postgrespro.ru", "phone": "+70274288960"}
0005435221076	CE663B	8824 227113	MIKHAIL ZHUKOV	{"phone": "+70379933036"}
0005435221077	CE663B	6361 690883	KLAVDIYA VOROBEVA	{"phone": "+70033082933"}
0005435221078	6F18B0	8825 653547	EKATERINA NIKOLAEVA	{"email": "nikolaevae.1983@postgrespro.ru", "phone": "+70024471479"}
0005435221079	6F18B0	2952 958737	VALERIYA PETROVA	{"email": "petrova-v051964@postgrespro.ru", "phone": "+70739073273"}
0005435221080	4199C5	2147 466690	LIDIYA FEDOROVA	{"phone": "+70010183056"}
0005435221081	0BA52A	6746 044976	ANASTASIYA KONOVALOVA	{"phone": "+70083216670"}
0005435221082	0BA52A	6726 951999	NIKOLAY ANDREEV	{"phone": "+70610594536"}
0005435221497	62B9E4	7186 011682	VYACHESLAV SIDOROV	{"phone": "+70238537305"}
0005435221498	6D7676	4221 649813	VALENTINA RYABOVA	{"phone": "+70813810624"}
0005435221499	6D7676	0349 545220	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov-20051975@postgrespro.ru", "phone": "+70972522708"}
0005435221500	6D7676	7717 034758	ANTON CHERNOV	{"phone": "+70703376559"}
0005435221501	4CB3D5	7366 177502	ANDREY SEMENOV	{"phone": "+70750813447"}
0005435221502	4CB3D5	8888 315794	VYACHESLAV DENISOV	{"phone": "+70843199216"}
0005435221503	60A9D9	9171 646409	ALEKSANDR BELOV	{"phone": "+70397757957"}
0005435221504	3278F1	1329 425236	LYUDMILA LUKYANOVA	{"phone": "+70216269259"}
0005435221505	149A3C	1891 039587	LEONID MAKAROV	{"email": "makarovl_25081976@postgrespro.ru", "phone": "+70859777283"}
0005435221506	6EC073	8684 154174	ALEKSANDR MAKSIMOV	{"phone": "+70019412609"}
0005435221507	F4080F	0223 481733	ALEKSEY KUZNECOV	{"phone": "+70602546615"}
0005435221508	F4080F	3412 174408	GEORGIY BELOV	{"email": "georgiybelov-011973@postgrespro.ru", "phone": "+70219288229"}
0005435221509	0A018F	5259 162115	ANDREY PAVLOV	{"phone": "+70221379093"}
0005435221510	7DD6AB	2160 557944	ELENA NESTEROVA	{"email": "elenanesterova_1966@postgrespro.ru", "phone": "+70890357275"}
0005435221511	B9893B	9065 456624	SEMEN MIKHAYLOV	{"phone": "+70514658787"}
0005435221512	D419D3	9061 216388	ALEKSANDR MARTYNOV	{"phone": "+70031367412"}
0005435221513	26F430	6923 271810	YULIYA AKIMOVA	{"phone": "+70113198445"}
0005435221514	8555E3	4064 724086	ROBERT VOROBEV	{"email": "robert_vorobev041975@postgrespro.ru", "phone": "+70487043784"}
0005435221515	8555E3	4506 737845	VITALIY ALEKSANDROV	{"phone": "+70643356123"}
0005435221516	507E88	4033 367561	SERGEY FOMIN	{"email": "sergey_fomin_1964@postgrespro.ru", "phone": "+70593803451"}
0005435221517	E64945	3083 558234	OKSANA NIKOLAEVA	{"phone": "+70960393534"}
0005435221518	E64945	3697 780330	SERGEY KUZNECOV	{"phone": "+70056106008"}
0005435221519	3209CD	5941 312049	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev1975@postgrespro.ru", "phone": "+70206042999"}
0005435221520	05EF28	2216 125685	NATALIYA KONDRATEVA	{"phone": "+70515457315"}
0005435221521	E087F1	3360 233809	EVGENIY IVANOV	{"email": "evgeniyivanov_26061966@postgrespro.ru", "phone": "+70420845523"}
0005435221522	64679B	3350 817165	ELENA NESTEROVA	{"phone": "+70791749698"}
0005435221523	311A5C	7309 966563	VASILIY GERASIMOV	{"phone": "+70002631022"}
0005435221524	A86A28	0477 118062	SERGEY DAVYDOV	{"email": "davydovs_01071972@postgrespro.ru", "phone": "+70365027786"}
0005435221525	A86A28	0620 809937	MIKHAIL EGOROV	{"email": "m-egorov.06091968@postgrespro.ru", "phone": "+70074579980"}
0005435221526	EBEA51	9937 929488	PETR MEDVEDEV	{"phone": "+70790431063"}
0005435221527	EBEA51	4296 011080	SVETLANA PETROVA	{"phone": "+70133424425"}
0005435221528	3FA75E	5254 407596	VERA PETROVA	{"email": "v_petrova10051972@postgrespro.ru", "phone": "+70680407364"}
0005435221529	3FA75E	4128 504857	OLGA KULIKOVA	{"email": "kulikova-olga14011996@postgrespro.ru", "phone": "+70702874663"}
0005435221530	16F9D6	9293 027454	ANDREY KUZNECOV	{"email": "andrey_kuznecov1965@postgrespro.ru", "phone": "+70363087660"}
0005435221531	16F9D6	5344 798388	VADIM GAVRILOV	{"phone": "+70388378804"}
0005435221532	A839BF	6325 393563	OLGA BORISOVA	{"email": "olgaborisova121960@postgrespro.ru", "phone": "+70547047041"}
0005435221533	C00E7F	0304 216955	ALEKSANDR STEPANOV	{"email": "stepanov-a091977@postgrespro.ru", "phone": "+70236591259"}
0005435221534	C00E7F	4243 038873	GEORGIY VOLKOV	{"phone": "+70406189138"}
0005435221535	51BDE0	9405 959294	LYUDMILA YUDINA	{"email": "lyudmila-yudina.011961@postgrespro.ru", "phone": "+70310694058"}
0005435221547	3073A0	0711 534719	NIKITA TIKHONOV	{"phone": "+70629724368"}
0005435221548	9162CC	2505 247813	ANATOLIY ANTONOV	{"email": "anatoliy.antonov-011977@postgrespro.ru", "phone": "+70498421255"}
0005435221549	9162CC	7961 462414	ALEKSEY ILIN	{"phone": "+70526914910"}
0005435221550	E81751	4756 673981	VALENTINA IVANOVA	{"phone": "+70831453078"}
0005435221551	DA6B6F	4269 143613	VITALIY FEDOTOV	{"phone": "+70753616987"}
0005435221552	DA6B6F	4115 227403	SERGEY ABRAMOV	{"email": "abramov_sergey_17101980@postgrespro.ru", "phone": "+70137421834"}
0005435221553	F82C03	0419 768752	KIRILL SERGEEV	{"email": "k_sergeev.071979@postgrespro.ru", "phone": "+70118608348"}
0005435221554	48A3F3	6412 851284	ANATOLIY ANTONOV	{"phone": "+70248136899"}
0005435221555	48A3F3	3291 965124	ARTUR SAVELEV	{"phone": "+70397909452"}
0005435221556	741112	9990 604998	ANDREY MAKAROV	{"phone": "+70322229530"}
0005435225443	5CE846	9675 410866	SVETLANA LEBEDEVA	{"email": "s.lebedeva_12041987@postgrespro.ru", "phone": "+70946715268"}
0005435225444	97CAB9	6861 118833	SERGEY SMIRNOV	{"email": "sergey.smirnov031982@postgrespro.ru", "phone": "+70831667392"}
0005435225445	100B1C	6118 336218	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana_12071966@postgrespro.ru", "phone": "+70368944909"}
0005435225446	7616C2	6123 086112	NIKOLAY NAZAROV	{"email": "nazarov_n.1980@postgrespro.ru", "phone": "+70394773501"}
0005435225447	A7CB32	6923 352910	VALERIY EGOROV	{"email": "valeriy-egorov.111972@postgrespro.ru", "phone": "+70747434089"}
0005435225448	89E7E9	5403 146805	IRINA FILIPPOVA	{"phone": "+70552697270"}
0005435225449	6BB329	8363 224767	NIKOLAY BELOV	{"email": "belovn.031963@postgrespro.ru", "phone": "+70424474068"}
0005435225450	D98DF2	9617 130082	VLADIMIR POPOV	{"email": "vpopov_23111983@postgrespro.ru", "phone": "+70059761157"}
0005435225451	D98DF2	1180 370103	VALERIYA STEPANOVA	{"email": "stepanova_v_13091978@postgrespro.ru", "phone": "+70535457566"}
0005435225452	D5321D	7229 061456	LARISA SMIRNOVA	{"phone": "+70092826843"}
0005435225453	D5321D	4576 993092	ALEKSANDRA KRASNOVA	{"phone": "+70928011309"}
0005435225454	AC4D45	4006 456133	ARTEM NOVIKOV	{"email": "novikov_artem.07041975@postgrespro.ru", "phone": "+70849238239"}
0005435225455	AC4D45	4690 720512	MIKHAIL KISELEV	{"phone": "+70285409709"}
0005435225567	5FE54A	7482 118459	ANDREY SERGEEV	{"phone": "+70303982452"}
0005435225456	AC4D45	5527 878766	EVGENIYA MATVEEVA	{"email": "evgeniyamatveeva1975@postgrespro.ru", "phone": "+70986558432"}
0005435225457	BB6A12	5763 081956	MARIYA KOVALEVA	{"email": "mkovaleva_011974@postgrespro.ru", "phone": "+70873872498"}
0005435225458	ABA0AD	8949 559288	ELENA TITOVA	{"phone": "+70664319081"}
0005435225459	98A96E	8113 952874	NATALYA KUZMINA	{"email": "kuzmina_natalya-21091979@postgrespro.ru", "phone": "+70936321817"}
0005435225460	3029AB	1177 263586	TAMARA SOLOVEVA	{"phone": "+70242909804"}
0005435225461	3029AB	5812 609909	DANILA KOZLOV	{"phone": "+70891311110"}
0005435225462	2D11A3	2921 511830	OLGA KONDRATEVA	{"phone": "+70877500772"}
0005435225463	6F8655	8641 394468	VLADIMIR KULIKOV	{"phone": "+70237372274"}
0005435225464	EB02A9	1643 391672	VLADIMIR MEDVEDEV	{"phone": "+70961785573"}
0005435225465	7CAB1D	6627 654766	VALENTINA BORISOVA	{"email": "valentinaborisova1970@postgrespro.ru", "phone": "+70929655805"}
0005435225466	25B1C6	0719 185792	LARISA IVANOVA	{"phone": "+70433719829"}
0005435225467	655EC1	9581 265841	YULIYA DENISOVA	{"phone": "+70843902390"}
0005435225468	655EC1	4775 799227	MARINA PAVLOVA	{"email": "mpavlova-081963@postgrespro.ru", "phone": "+70561849358"}
0005435225469	8F20FE	3689 802798	NINA LEBEDEVA	{"email": "lebedeva_n.08051985@postgrespro.ru", "phone": "+70496771352"}
0005435225470	7EED4D	0766 404802	ALEKSANDR GUSEV	{"email": "a.gusev-081974@postgrespro.ru", "phone": "+70044401498"}
0005435225471	7EED4D	5029 383842	DMITRIY MOROZOV	{"phone": "+70329922250"}
0005435225472	7EED4D	1448 420679	LIDIYA NESTEROVA	{"phone": "+70141761445"}
0005435225473	CC649B	1826 616744	VALERIY TIKHONOV	{"phone": "+70427447234"}
0005435225474	CC649B	9705 675251	LEONID MIKHAYLOV	{"email": "leonidmikhaylov02121975@postgrespro.ru", "phone": "+70765909033"}
0005435225475	18A818	2984 795133	KONSTANTIN EGOROV	{"phone": "+70167265268"}
0005435225476	20D5A1	1036 766087	SERGEY VASILEV	{"email": "s.vasilev_05051964@postgrespro.ru", "phone": "+70982121701"}
0005435225477	7D0EA4	0833 380799	MIKHAIL MOROZOV	{"email": "morozov-mikhail-1973@postgrespro.ru", "phone": "+70434468346"}
0005435225478	03436D	8611 512089	ARTEM STEPANOV	{"phone": "+70402341293"}
0005435225479	A27AEE	1379 031874	VLADIMIR KUZMIN	{"phone": "+70324090168"}
0005435225480	008461	1827 117678	ELIZAVETA IVANOVA	{"email": "elizaveta_ivanova_1974@postgrespro.ru", "phone": "+70774881156"}
0005435225481	008461	6529 419083	SERGEY POPOV	{"email": "popov-s.06031972@postgrespro.ru", "phone": "+70736717695"}
0005435225482	742BFE	2116 511718	SVETLANA ZAKHAROVA	{"phone": "+70998009461"}
0005435225483	70AACD	3408 888132	EKATERINA POPOVA	{"email": "ekaterina.popova.1970@postgrespro.ru", "phone": "+70881469974"}
0005435225484	8FC9C3	8562 884233	POLINA GRISHINA	{"email": "p-grishina.09081976@postgrespro.ru", "phone": "+70541695259"}
0005435225485	44B3AB	1322 843358	VYACHESLAV IVANOV	{"email": "ivanovvyacheslav.12111967@postgrespro.ru", "phone": "+70501875501"}
0005435225486	44B3AB	0183 149702	TAMARA ZAKHAROVA	{"email": "zakharovatamara.1973@postgrespro.ru", "phone": "+70298275363"}
0005435225487	D079C4	8561 564704	GENNADIY KOROLEV	{"email": "korolev.g.051975@postgrespro.ru", "phone": "+70422812448"}
0005435225489	2DE92F	1267 851316	TATYANA GORBUNOVA	{"phone": "+70201677380"}
0005435225490	7D279B	7032 617444	KIRILL VASILEV	{"email": "k-vasilev-1975@postgrespro.ru", "phone": "+70228435350"}
0005435225491	888726	0751 612316	ANTONINA EFREMOVA	{"email": "efremova_a_1974@postgrespro.ru", "phone": "+70310258388"}
0005435225492	3ABD08	8932 495523	ILYA MOISEEV	{"phone": "+70794183448"}
0005435225493	7D5993	9338 248537	NIKOLAY SEMENOV	{"phone": "+70160206906"}
0005435225494	8C6695	1466 659172	OKSANA YAKOVLEVA	{"phone": "+70993838394"}
0005435225495	8C6695	4609 100855	ANNA TROFIMOVA	{"email": "annatrofimova_081969@postgrespro.ru", "phone": "+70895541571"}
0005435225496	540F0F	8811 277936	PAVEL FROLOV	{"phone": "+70764643390"}
0005435225497	2CB5C4	5899 120907	ELIZAVETA DAVYDOVA	{"phone": "+70722743262"}
0005435225498	222FB2	9863 130525	KARINA POLYAKOVA	{"email": "k.polyakova-041967@postgrespro.ru", "phone": "+70651580052"}
0005435225499	222FB2	9977 178121	VLADISLAV ROMANOV	{"email": "romanov.vladislav_29081987@postgrespro.ru", "phone": "+70064398371"}
0005435225500	38E69F	8706 138696	EVA KUZMINA	{"email": "e-kuzmina26021974@postgrespro.ru", "phone": "+70156838643"}
0005435225501	38E69F	7187 330644	IVAN GUSEV	{"email": "gusevivan_101979@postgrespro.ru", "phone": "+70334774905"}
0005435225502	6F5BFA	6144 125066	DMITRIY KUZNECOV	{"phone": "+70257658956"}
0005435225503	33C611	1952 057726	STANISLAV ORLOV	{"phone": "+70299064081"}
0005435225504	33C611	5320 010623	ILYA VOLKOV	{"email": "i.volkov_111981@postgrespro.ru", "phone": "+70455258640"}
0005435225505	695F7A	6150 705636	ILYA FILIPPOV	{"phone": "+70876235454"}
0005435225506	252E44	4520 747530	ALEKSANDR SCHERBAKOV	{"phone": "+70943756118"}
0005435225507	89C653	8006 491449	SVETLANA LEBEDEVA	{"email": "slebedeva1969@postgrespro.ru", "phone": "+70841183447"}
0005435225508	89C653	8395 611936	DMITRIY KUZNECOV	{"phone": "+70552374237"}
0005435225509	89C653	9425 348463	VLADIMIR VOROBEV	{"phone": "+70138781676"}
0005435225510	89C653	1203 549586	ALINA TIMOFEEVA	{"email": "alina.timofeeva-1968@postgrespro.ru", "phone": "+70284166721"}
0005435225511	51337D	0421 971756	YURIY KONOVALOV	{"email": "konovalovy.01051972@postgrespro.ru", "phone": "+70734069180"}
0005435225512	2215B2	6841 559669	EVGENIYA KUDRYASHOVA	{"email": "evgeniya.kudryashova23041969@postgrespro.ru", "phone": "+70523115347"}
0005435225513	338720	3419 372719	ANNA KUZNECOVA	{"phone": "+70332446324"}
0005435225514	C9811C	7846 215396	NATALYA POPOVA	{"email": "n_popova.1979@postgrespro.ru", "phone": "+70108156516"}
0005435225515	E70BFA	7221 297602	PETR KISELEV	{"email": "petr_kiselev.10031972@postgrespro.ru", "phone": "+70362274180"}
0005435225516	605433	6352 122166	NATALIYA KAZAKOVA	{"email": "kazakova.n.051978@postgrespro.ru", "phone": "+70119415930"}
0005435225517	605433	1869 338414	SOFYA KUZNECOVA	{"phone": "+70614545519"}
0005435225518	0F155A	8022 215517	IRINA MIRONOVA	{"email": "mironova-i1979@postgrespro.ru", "phone": "+70918993735"}
0005435225519	F85670	9459 060308	ALEKSEY ILIN	{"email": "a.ilin-071976@postgrespro.ru", "phone": "+70606758249"}
0005435225520	F85670	1022 666407	KSENIYA MAKAROVA	{"email": "k-makarova_10071970@postgrespro.ru", "phone": "+70332390163"}
0005435225521	F4C797	9684 088062	MARIYA KOROLEVA	{"phone": "+70494105547"}
0005435225522	0C6520	1484 736811	MIKHAIL MOISEEV	{"phone": "+70076735050"}
0005435225523	0C6520	8941 728023	NATALYA KOROLEVA	{"phone": "+70230756562"}
0005435225524	EBA571	3090 042273	ALEKSANDR SCHERBAKOV	{"phone": "+70875175322"}
0005435225525	568728	3450 915782	ANASTASIYA SOLOVEVA	{"email": "anastasiya_soloveva.14101962@postgrespro.ru", "phone": "+70053274730"}
0005435225526	568728	1016 746115	SAMVEL NAUMOV	{"email": "samvel_naumov.26081969@postgrespro.ru", "phone": "+70955005033"}
0005435225527	B471F5	9560 335012	VIKTOR FROLOV	{"email": "viktor.frolov1970@postgrespro.ru", "phone": "+70985554914"}
0005435225528	B471F5	6702 436244	ANNA BOGDANOVA	{"email": "a.bogdanova-1973@postgrespro.ru", "phone": "+70334747825"}
0005435225529	673245	5860 690225	ALEKSANDR GAVRILOV	{"email": "gavrilova-1964@postgrespro.ru", "phone": "+70218592450"}
0005435225530	ABDCE7	6974 007735	ANNA ALEKSANDROVA	{"email": "aleksandrova-anna-1964@postgrespro.ru", "phone": "+70781976894"}
0005435225531	ABDCE7	3928 457188	STANISLAV ZAYCEV	{"phone": "+70873155800"}
0005435225532	F473F9	5567 059476	VLADIMIR FROLOV	{"email": "frolovv.02101974@postgrespro.ru", "phone": "+70740953746"}
0005435225533	F473F9	7941 684127	MAKSIM KOROLEV	{"email": "m.korolev.1976@postgrespro.ru", "phone": "+70067905171"}
0005435225534	F473F9	0953 224633	NATALIYA TROFIMOVA	{"email": "trofimova-nataliya021982@postgrespro.ru", "phone": "+70669082039"}
0005435225535	55C4A8	6514 676558	NATALYA AFANASEVA	{"email": "natalya_afanaseva_011978@postgrespro.ru", "phone": "+70126653597"}
0005435225536	55C4A8	5953 616857	IRINA POPOVA	{"email": "popova-irina-1972@postgrespro.ru", "phone": "+70982197027"}
0005435225537	55C4A8	8924 992829	SOFYA BARANOVA	{"phone": "+70914624416"}
0005435225538	6E189E	4891 908688	ILSHAT DAVYDOV	{"email": "davydov_ilshat.081960@postgrespro.ru", "phone": "+70466328992"}
0005435225539	D2F839	9127 547506	ANTONINA VOROBEVA	{"email": "vorobeva-antonina-1973@postgrespro.ru", "phone": "+70496540985"}
0005435225540	D2F839	2744 551719	BOGDAN STEPANOV	{"email": "bogdanstepanov1958@postgrespro.ru", "phone": "+70064955749"}
0005435225541	4835C6	0527 258424	ALEKSANDR DMITRIEV	{"phone": "+70344275049"}
0005435225542	90BE2C	3425 652760	ELENA MATVEEVA	{"email": "matveeva-elena.1974@postgrespro.ru", "phone": "+70015820571"}
0005435225543	59B266	2815 161988	KONSTANTIN KAZAKOV	{"phone": "+70761042578"}
0005435225544	85898C	0160 466343	NIKOLAY NAUMOV	{"email": "nikolay_naumov.1968@postgrespro.ru", "phone": "+70081227711"}
0005435225545	D5908D	7499 642314	EVGENIY NIKITIN	{"phone": "+70281337867"}
0005435225546	8BD4E2	3018 561960	LIDIYA VLASOVA	{"phone": "+70094396793"}
0005435225547	DC3AC6	2272 743767	VERA BOGDANOVA	{"phone": "+70307968438"}
0005435225548	21280E	9535 398953	ALEKSANDR RODIONOV	{"phone": "+70478121151"}
0005435225549	21280E	7884 732748	ALEKSANDRA SAVELEVA	{"phone": "+70433659653"}
0005435225550	5567CF	4475 364461	VYACHESLAV STEPANOV	{"email": "stepanov-v1966@postgrespro.ru", "phone": "+70136065904"}
0005435225551	5567CF	2808 078873	VLADIMIR NAUMOV	{"email": "naumov.v-1962@postgrespro.ru", "phone": "+70738890756"}
0005435225552	036D3B	0437 374350	SOFIYA NIKITINA	{"phone": "+70025095099"}
0005435225553	F70B9D	6259 322909	DARYA VASILEVA	{"phone": "+70621227946"}
0005435225554	54FD75	9992 128517	ALEKSANDR VLASOV	{"email": "aleksandr_vlasov.081974@postgrespro.ru", "phone": "+70075640599"}
0005435225555	D3BA48	8433 875764	DMITRIY MIKHAYLOV	{"email": "mikhaylov.d20031972@postgrespro.ru", "phone": "+70009373566"}
0005435225556	EB36FF	7931 758295	ALBINA STEPANOVA	{"phone": "+70610690452"}
0005435225557	EB36FF	2033 194119	ALEKSANDR EGOROV	{"phone": "+70260457269"}
0005435225558	EB36FF	5741 042019	NIKOLAY KARPOV	{"email": "karpov.nikolay-1968@postgrespro.ru", "phone": "+70156062560"}
0005435225559	8FF697	7990 587485	RASIM NIKOLAEV	{"phone": "+70382779406"}
0005435225560	731EDE	6304 315193	RUSTAM FEDOTOV	{"phone": "+70742092893"}
0005435225561	C1C560	1825 399801	YANA KOZLOVA	{"email": "y_kozlova1963@postgrespro.ru", "phone": "+70287904721"}
0005435225562	EBA8EF	2687 131167	NIKOLAY PETROV	{"email": "petrov.n_061966@postgrespro.ru", "phone": "+70461043450"}
0005435225563	9D48BE	8814 192825	OLGA BELYAEVA	{"email": "olga-belyaeva1972@postgrespro.ru", "phone": "+70011292964"}
0005435225564	D1C1E4	8530 884570	ALEKSANDR NIKOLAEV	{"phone": "+70613947811"}
0005435225565	D1C1E4	0942 800550	YULIYA ANISIMOVA	{"email": "yuliya.anisimova-19061974@postgrespro.ru", "phone": "+70589923611"}
0005435225566	D1C1E4	6026 327323	ALEKSEY CHERNOV	{"email": "alekseychernov_1968@postgrespro.ru", "phone": "+70576897708"}
0005435225568	E6A84C	6053 266010	RAVIL STEPANOV	{"email": "stepanovr_011968@postgrespro.ru", "phone": "+70595167210"}
0005435225569	2103C1	6272 817979	NATALYA GRISHINA	{"email": "grishinan-1966@postgrespro.ru", "phone": "+70313581851"}
0005435225570	2103C1	4111 404958	ROSTISLAV SHEVCHENKO	{"email": "shevchenko-rostislav-101974@postgrespro.ru", "phone": "+70306181889"}
0005435225571	C4D185	6639 497555	NINA ZAKHAROVA	{"email": "nina-zakharova1967@postgrespro.ru", "phone": "+70580903685"}
0005435225572	C4D185	0309 599630	VALENTINA KAZAKOVA	{"email": "kazakova.valentina_1971@postgrespro.ru", "phone": "+70180752837"}
0005435225573	9CEB4C	3163 070335	ALEKSANDR AFANASEV	{"email": "afanaseva-20061968@postgrespro.ru", "phone": "+70405438755"}
0005435225574	735A82	6298 737424	YULIYA SIDOROVA	{"phone": "+70705784940"}
0005435225575	426FB3	1185 128687	INNA GRISHINA	{"phone": "+70906431731"}
0005435225576	C2744F	8582 873541	SVETLANA LOGINOVA	{"phone": "+70975568435"}
0005435225577	63DF56	6110 050301	RAISA VASILEVA	{"phone": "+70878316533"}
0005435225578	27126A	8338 634717	NADEZHDA MARTYNOVA	{"phone": "+70513352976"}
0005435225579	51923E	5578 809291	KHASAN KUDRYASHOV	{"email": "kudryashov_k1979@postgrespro.ru", "phone": "+70959830811"}
0005435225580	BE05F4	7854 791414	EKATERINA NIKITINA	{"email": "nikitina_ekaterina.03121959@postgrespro.ru", "phone": "+70438011600"}
0005435225581	840EFC	7023 536274	ARTEM PETROV	{"email": "artem_petrov08071968@postgrespro.ru", "phone": "+70677982277"}
0005435225582	4877A0	8912 780042	IGNAT ALEKSANDROV	{"phone": "+70835698684"}
0005435225583	A951A2	0581 140433	PAVEL KONOVALOV	{"phone": "+70439608090"}
0005435225584	A951A2	4234 480551	MARINA POLYAKOVA	{"phone": "+70519747068"}
0005435225585	EED946	8183 372167	SVETLANA RODIONOVA	{"email": "s.rodionova_1960@postgrespro.ru", "phone": "+70485300451"}
0005435225586	EEB784	8439 752961	IRINA DENISOVA	{"phone": "+70699653906"}
0005435225587	BA0B1E	2383 244229	ANDREY ALEKSEEV	{"phone": "+70999667189"}
0005435225588	214DA6	4499 014461	FEDOR CHERNOV	{"phone": "+70774080407"}
0005435225589	B0CB06	2031 929545	DMITRIY VOROBEV	{"email": "dmitriy_vorobev_06071963@postgrespro.ru", "phone": "+70669084828"}
0005435225590	846DF5	2181 464020	ANTON SHEVCHENKO	{"email": "ashevchenko04091980@postgrespro.ru", "phone": "+70989824364"}
0005435225591	62D36E	7877 612745	ELENA VASILEVA	{"phone": "+70405575651"}
0005435225592	62D36E	7039 755972	SVETLANA ABRAMOVA	{"email": "abramova.svetlana-111973@postgrespro.ru", "phone": "+70834322791"}
0005435225593	29D413	5805 049204	MARGARITA MATVEEVA	{"email": "margarita.matveeva.041973@postgrespro.ru", "phone": "+70880964180"}
0005435225594	CB9D0C	3661 307909	RAISA KUZNECOVA	{"email": "kuznecovar1963@postgrespro.ru", "phone": "+70600397858"}
0005435225595	CB9D0C	7779 072982	GENNADIY ANDREEV	{"email": "andreev_gennadiy_071966@postgrespro.ru", "phone": "+70087936406"}
0005435225596	4F465A	4914 696348	NIKOLAY FOMIN	{"phone": "+70900176141"}
0005435225597	7600CE	8069 376323	SERGEY IVANOV	{"email": "ivanov_sergey.15121974@postgrespro.ru", "phone": "+70397578326"}
0005435225598	7600CE	4384 672932	ANNA PAVLOVA	{"email": "pavlova-anna19071977@postgrespro.ru", "phone": "+70812367957"}
0005435225599	80F1F1	3708 265735	ANASTASIYA ALEKSEEVA	{"email": "anastasiya.alekseeva.011965@postgrespro.ru", "phone": "+70457934037"}
0005435225600	CE2837	8803 962769	IGOR STEPANOV	{"email": "stepanov_i_061976@postgrespro.ru", "phone": "+70521222170"}
0005435225601	C32C78	7541 438716	KRISTINA KUZNECOVA	{"email": "k_kuznecova.15051979@postgrespro.ru", "phone": "+70065954969"}
0005435225602	8FEE97	9304 935568	IRINA IVANOVA	{"phone": "+70145352293"}
0005435225603	8C9EE2	0795 498293	GENNADIY KUZNECOV	{"phone": "+70536683801"}
0005435225604	05E088	7271 842351	ANNA NESTEROVA	{"email": "nesterova_anna-051974@postgrespro.ru", "phone": "+70951989373"}
0005435225605	FEA116	8336 326077	LIDIYA NAZAROVA	{"email": "nazarova_lidiya_061976@postgrespro.ru", "phone": "+70348333495"}
0005435225606	1A3A73	4242 242939	NATALYA ZAYCEVA	{"email": "zaycevanatalya-1983@postgrespro.ru", "phone": "+70265178045"}
0005435225607	09C3E0	1400 367580	RAISA KOROLEVA	{"email": "koroleva_raisa.051982@postgrespro.ru", "phone": "+70502490455"}
0005435225608	974FDC	3264 766494	NIKOLAY MOISEEV	{"phone": "+70106054036"}
0005435225609	E85549	6015 041901	DMITRIY FROLOV	{"phone": "+70049925436"}
0005435225610	629987	7322 127389	RAISA NIKITINA	{"email": "raisa_nikitina-051971@postgrespro.ru", "phone": "+70028528001"}
0005435225611	629987	8608 922566	RASHID VOROBEV	{"email": "vorobev_r_111971@postgrespro.ru", "phone": "+70289305441"}
0005435225612	629987	9018 152832	PAVEL KOZLOV	{"email": "kozlov-pavel.1976@postgrespro.ru", "phone": "+70690171107"}
0005435225613	546308	3124 135916	SEMEN BELOV	{"email": "semen-belov_1980@postgrespro.ru", "phone": "+70610371573"}
0005435225614	546308	8654 841499	MARIYA MALYSHEVA	{"email": "m.malysheva1976@postgrespro.ru", "phone": "+70216561671"}
0005435225615	3F2EDA	2131 230566	MARINA EFIMOVA	{"email": "efimova-marina-1972@postgrespro.ru", "phone": "+70176358544"}
0005435225616	47E476	9685 369505	EKATERINA MATVEEVA	{"email": "ekaterina_matveeva_091972@postgrespro.ru", "phone": "+70507082399"}
0005435225617	CD8099	9619 273730	ALEKSEY ILIN	{"phone": "+70068869736"}
0005435225618	CD8099	0651 691864	EVGENIY FILIPPOV	{"phone": "+70259626639"}
0005435225619	C85F21	3072 207075	LYUBOV MELNIKOVA	{"email": "melnikova-l_081968@postgrespro.ru", "phone": "+70712183702"}
0005435225620	86E2C9	3070 488195	IRINA LUKYANOVA	{"email": "i-lukyanova.021981@postgrespro.ru", "phone": "+70491331383"}
0005435225621	86E2C9	6473 506123	ARTEM YAKOVLEV	{"phone": "+70199578005"}
0005435225622	374F19	6964 151673	NADEZHDA YUDINA	{"phone": "+70008185299"}
0005435225623	498A6B	8042 987241	VIKTOR RODIONOV	{"email": "rodionovviktor-011970@postgrespro.ru", "phone": "+70541358367"}
0005435225624	2D3EEB	3311 796774	MARIYA IVANOVA	{"email": "ivanovamariya.29051973@postgrespro.ru", "phone": "+70655386374"}
0005435225625	2D3EEB	5434 319112	ELENA TIKHONOVA	{"phone": "+70514655863"}
0005435225626	83548F	4858 218875	OKSANA NAZAROVA	{"email": "o_nazarova22101960@postgrespro.ru", "phone": "+70896641421"}
0005435225627	83548F	1476 851612	LYUDMILA SOLOVEVA	{"email": "soloveva_lyudmila_1985@postgrespro.ru", "phone": "+70436805453"}
0005435225628	83548F	7653 900096	ANDREY RODIONOV	{"email": "rodionov_andrey-1959@postgrespro.ru", "phone": "+70414814797"}
0005435225629	BEA104	0143 436440	LYUDMILA KOLESNIKOVA	{"phone": "+70846921735"}
0005435225630	E3F3F2	6015 312473	EVDOKIYA KOMAROVA	{"phone": "+70219583612"}
0005435225631	C0C447	9178 764525	NATALYA ANISIMOVA	{"phone": "+70623596493"}
0005435225632	C0C447	3042 512844	IRINA ALEKSEEVA	{"email": "ialekseeva-031976@postgrespro.ru", "phone": "+70495081375"}
0005435225633	DFE8B2	4996 563848	RINAT YAKOVLEV	{"phone": "+70291408847"}
0005435225634	080C9B	0222 228196	ANNA KUZNECOVA	{"email": "a.kuznecova.1981@postgrespro.ru", "phone": "+70890261866"}
0005435225635	95C19B	4976 012076	MARIYA VOROBEVA	{"phone": "+70090462467"}
0005435225636	95C19B	5363 011879	VLADISLAV MARTYNOV	{"phone": "+70054532049"}
0005435225637	2FA35A	6069 540067	DENIS SMIRNOV	{"email": "smirnovdenis.27031973@postgrespro.ru", "phone": "+70304592873"}
0005435225638	63729E	2140 876999	TATYANA ANDREEVA	{"phone": "+70340064425"}
0005435225639	EBC5F8	1557 327749	ALINA ROMANOVA	{"email": "alina.romanova06061965@postgrespro.ru", "phone": "+70724341586"}
0005435225640	55E4FA	2245 899834	VLADIMIR GUSEV	{"phone": "+70131181341"}
0005435225641	6B7FAF	8071 471765	DARYA NIKITINA	{"phone": "+70773017051"}
0005435225642	6B7FAF	2774 548677	NATALYA PAVLOVA	{"phone": "+70346856868"}
0005435225643	883583	1349 952560	VALENTINA ZHURAVLEVA	{"phone": "+70499704055"}
0005435225644	4A2FD0	5353 774873	ELENA ARKHIPOVA	{"email": "elenaarkhipova_27031970@postgrespro.ru", "phone": "+70757295908"}
0005435225645	4A2FD0	5434 780191	ZINAIDA SEMENOVA	{"email": "z.semenova-17031968@postgrespro.ru", "phone": "+70545410970"}
0005435225646	C274C0	6931 786944	MARINA POPOVA	{"email": "popova-marina-1974@postgrespro.ru", "phone": "+70818747769"}
0005435225647	D465EF	2644 046120	POLINA DAVYDOVA	{"phone": "+70016910897"}
0005435225648	E0F301	6487 004352	OLEG KRASNOV	{"email": "o_krasnov.1960@postgrespro.ru", "phone": "+70084300637"}
0005435225649	E0F301	5807 009148	SERAFIMA MIKHAYLOVA	{"phone": "+70533794854"}
0005435225650	9B8FE0	1000 343393	MARINA MALYSHEVA	{"email": "malysheva-marina_1979@postgrespro.ru", "phone": "+70425091159"}
0005435225651	D876C3	2942 881386	LYUDMILA LUKYANOVA	{"phone": "+70645683849"}
0005435225652	F188C5	4499 722613	VIKTOR YAKOVLEV	{"phone": "+70505816523"}
0005435225653	BEFBF5	9186 555829	GALINA MIRONOVA	{"phone": "+70270259177"}
0005435225654	46B657	2150 103127	YURIY STEPANOV	{"email": "y-stepanov.041968@postgrespro.ru", "phone": "+70801309133"}
0005435225655	46B657	4451 652230	ALFIYA EGOROVA	{"email": "aegorova-1983@postgrespro.ru", "phone": "+70164686162"}
0005435225656	6CFAA6	1330 550550	KIRA KALININA	{"phone": "+70532438779"}
0005435225657	65AD89	3220 381752	PETR KOROLEV	{"phone": "+70919864558"}
0005435225658	DA7446	8030 678801	EVGENIY ANTONOV	{"phone": "+70454686517"}
0005435225659	C62B7D	9795 741401	ALEKSANDR VLASOV	{"email": "vlasov_aleksandr18061973@postgrespro.ru", "phone": "+70019480687"}
0005435225660	AD08F1	7298 590381	VALERIY ROMANOV	{"phone": "+70124452969"}
0005435225661	BE48A9	8453 288465	VALERIYA MAKAROVA	{"email": "makarova_valeriya_021965@postgrespro.ru", "phone": "+70159591699"}
0005435225662	8F18C7	7654 118099	ALEKSANDRA MOROZOVA	{"email": "morozova_aleksandra-1979@postgrespro.ru", "phone": "+70848482588"}
0005435225663	8F18C7	5462 251664	OLEG NIKOLAEV	{"email": "nikolaev.oleg_1979@postgrespro.ru", "phone": "+70983060547"}
0005435225664	331FEF	8980 960507	IVAN KUZMIN	{"phone": "+70114003251"}
0005435225665	D37F92	9239 647527	ALEKSANDR MIKHAYLOV	{"phone": "+70895915754"}
0005435225666	D37F92	9990 778162	DENIS ILIN	{"phone": "+70465915271"}
0005435229333	A2C965	5507 519719	ALEKSANDR BONDARENKO	{"phone": "+70745471672"}
0005435225667	D2C28D	1909 279818	KONSTANTIN EGOROV	{"email": "konstantin_egorov.011969@postgrespro.ru", "phone": "+70382545700"}
0005435225668	D2C28D	8750 527042	TATYANA NIKITINA	{"email": "tatyananikitina1969@postgrespro.ru", "phone": "+70701770447"}
0005435225669	F9642D	7451 114729	EKATERINA MIRONOVA	{"phone": "+70928676606"}
0005435225670	F9642D	3624 120511	LIDIYA KAZAKOVA	{"email": "kazakova.l_03031964@postgrespro.ru", "phone": "+70434426717"}
0005435225671	5F37CD	2635 238200	NADEZHDA VOLKOVA	{"email": "nadezhdavolkova091971@postgrespro.ru", "phone": "+70745709596"}
0005435225672	F82D05	8235 113917	TAMARA VOROBEVA	{"email": "tamara-vorobeva_101974@postgrespro.ru", "phone": "+70757203706"}
0005435225673	F82D05	4189 804358	VALERIY MATVEEV	{"email": "matveev-valeriy.1980@postgrespro.ru", "phone": "+70306476062"}
0005435225674	56923E	5474 132169	VIKTOR DENISOV	{"email": "v.denisov.02071967@postgrespro.ru", "phone": "+70293249267"}
0005435225675	16182B	4594 035655	TATYANA NIKOLAEVA	{"phone": "+70612765557"}
0005435225676	6F4531	4660 355422	VERA KOZLOVA	{"email": "v_kozlova_21071976@postgrespro.ru", "phone": "+70784162161"}
0005435225677	6F4531	6566 708675	VALENTINA ROMANOVA	{"phone": "+70891864067"}
0005435225678	120DF2	2933 118215	TAMARA TARASOVA	{"phone": "+70700607353"}
0005435225679	120DF2	8121 521148	VERA MEDVEDEVA	{"email": "medvedevav021977@postgrespro.ru", "phone": "+70870744075"}
0005435225680	374877	5670 170217	ANDREY NOVIKOV	{"email": "andreynovikov-10041973@postgrespro.ru", "phone": "+70764006681"}
0005435225681	AFBF91	3880 116823	SVETLANA GAVRILOVA	{"email": "gavrilova_s071970@postgrespro.ru", "phone": "+70305645226"}
0005435225682	770315	4929 181038	ANNA AFANASEVA	{"email": "anna.afanaseva_081964@postgrespro.ru", "phone": "+70500931215"}
0005435225683	039808	8033 525555	SERGEY KUZMIN	{"email": "kuzmin_s1970@postgrespro.ru", "phone": "+70432582762"}
0005435225684	039808	1393 938980	ELENA YUDINA	{"phone": "+70443982084"}
0005435225685	02811B	0415 557959	OLGA SERGEEVA	{"email": "sergeeva_o.071965@postgrespro.ru", "phone": "+70684032979"}
0005435225686	02811B	7920 812747	DARYA ISAEVA	{"email": "d-isaeva_1963@postgrespro.ru", "phone": "+70680423558"}
0005435225687	86A74F	6534 809606	ZINAIDA AKIMOVA	{"phone": "+70532031555"}
0005435225688	86A74F	5921 459360	ELIZAVETA FOMINA	{"email": "elizavetafomina.1967@postgrespro.ru", "phone": "+70182995644"}
0005435225689	B2F0B3	9218 329383	MAKSIM SEMENOV	{"phone": "+70234862073"}
0005435225690	0E2DD4	1068 165467	SERGEY SIDOROV	{"phone": "+70701083468"}
0005435225691	70F2BC	5739 217848	IGOR SOROKIN	{"email": "igor_sorokin-071970@postgrespro.ru", "phone": "+70952193427"}
0005435225692	AFB374	3057 137710	NADEZHDA SOKOLOVA	{"phone": "+70029558424"}
0005435225693	AFB374	0936 336073	ALEKSANDR VLASOV	{"phone": "+70113947161"}
0005435225694	E626FA	2142 840852	VYACHESLAV FOMIN	{"email": "vyacheslav.fomin.1967@postgrespro.ru", "phone": "+70257454685"}
0005435225695	4186A8	3936 954622	YURIY GUSEV	{"email": "gusevyuriy-1977@postgrespro.ru", "phone": "+70555975951"}
0005435225696	18291E	8520 887659	EKATERINA KOMAROVA	{"phone": "+70876957550"}
0005435225697	16FA2F	6963 502083	DANILA GRIGOREV	{"email": "grigorev_d.1964@postgrespro.ru", "phone": "+70227581369"}
0005435225698	71B878	7615 499684	RISHAT GUSEV	{"phone": "+70481442080"}
0005435225699	139542	2696 000562	MIKHAIL ABRAMOV	{"phone": "+70243340221"}
0005435225700	139542	6235 769209	RAISA FROLOVA	{"email": "rfrolova_101970@postgrespro.ru", "phone": "+70494927845"}
0005435225701	139542	3204 049518	EKATERINA IVANOVA	{"phone": "+70149646937"}
0005435225702	4ACD5E	5241 345837	SERGEY MAKSIMOV	{"email": "s_maksimov_1974@postgrespro.ru", "phone": "+70163578477"}
0005435225703	4ACD5E	5739 681904	ALEKSANDR RODIONOV	{"email": "arodionov_1961@postgrespro.ru", "phone": "+70557389993"}
0005435225704	53B0C6	6621 994995	YULIYA GERASIMOVA	{"phone": "+70475383306"}
0005435225705	53B0C6	2468 914903	VASILIY ZHURAVLEV	{"email": "v.zhuravlev071979@postgrespro.ru", "phone": "+70337956571"}
0005435225706	4B1178	7805 026400	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov_041968@postgrespro.ru", "phone": "+70856093044"}
0005435225707	4B1178	3823 818498	OLGA DMITRIEVA	{"phone": "+70021085195"}
0005435225708	FDCA4A	1058 186507	RUFIYA POLYAKOVA	{"email": "r.polyakova-29121976@postgrespro.ru", "phone": "+70859877669"}
0005435225709	FDCA4A	7462 998568	SERGEY FEDOROV	{"phone": "+70765968334"}
0005435225710	FDCA4A	1930 413678	ANDREY VASILEV	{"phone": "+70024506249"}
0005435225711	D4BD9B	4220 156680	ANASTASIYA FILIPPOVA	{"email": "anastasiya-filippova_1980@postgrespro.ru", "phone": "+70281346644"}
0005435225712	D4BD9B	0641 001942	ANATOLIY TIMOFEEV	{"phone": "+70436210531"}
0005435225713	59B4BC	7115 573915	DANIIL NAZAROV	{"email": "d.nazarov18121973@postgrespro.ru", "phone": "+70124175906"}
0005435225714	08F77C	3728 897361	SERGEY FILIPPOV	{"phone": "+70925072040"}
0005435225715	FB00FC	3635 420533	YURIY FILIPPOV	{"email": "filippov.y_31051971@postgrespro.ru", "phone": "+70753838737"}
0005435225716	FB00FC	3359 544395	ALEKSEY GUSEV	{"phone": "+70005161419"}
0005435225717	6EECE3	6949 319580	GLEB MIRONOV	{"phone": "+70784529946"}
0005435225718	D796F6	7175 161778	NATALYA BARANOVA	{"phone": "+70047030965"}
0005435225719	D796F6	6932 038247	IRINA NAUMOVA	{"email": "i_naumova.17121974@postgrespro.ru", "phone": "+70670114897"}
0005435225720	0DE3F9	6381 576455	MARGARITA RODIONOVA	{"email": "rodionovam-10101968@postgrespro.ru", "phone": "+70084158673"}
0005435225721	15BCFD	6444 766480	VIKTOR FROLOV	{"email": "viktor-frolov1964@postgrespro.ru", "phone": "+70071981178"}
0005435225722	593943	7562 545906	SERGEY FILIPPOV	{"phone": "+70909305881"}
0005435225723	4E34F9	8959 826779	ELENA KUZNECOVA	{"email": "kuznecova_elena.09021982@postgrespro.ru", "phone": "+70902486689"}
0005435225724	4E34F9	7892 700120	MAKSIM NOVIKOV	{"email": "novikovmaksim_1972@postgrespro.ru", "phone": "+70031850607"}
0005435225725	A74227	3227 761484	YURIY SOKOLOV	{"email": "ysokolov_1973@postgrespro.ru", "phone": "+70993718281"}
0005435225726	C2F053	2185 502087	KLAVDIYA YAKOVLEVA	{"email": "yakovleva_k_20051971@postgrespro.ru", "phone": "+70479186933"}
0005435225727	FF859F	2839 265887	YAN ZAYCEV	{"phone": "+70363467746"}
0005435225728	FF859F	0439 457984	TATYANA POPOVA	{"phone": "+70932349578"}
0005435225729	FF859F	7348 000738	NIKOLAY KUZNECOV	{"email": "n-kuznecov_1967@postgrespro.ru", "phone": "+70486062334"}
0005435225730	D309DB	0373 879542	GEORGIY BARANOV	{"email": "gbaranov_22051970@postgrespro.ru", "phone": "+70965332954"}
0005435225731	D2CF31	4624 576981	VALENTIN VASILEV	{"email": "v_vasilev061982@postgrespro.ru", "phone": "+70845936548"}
0005435225732	D2CF31	8675 830305	ANDREY FILIPPOV	{"phone": "+70795378985"}
0005435225733	D2CF31	2642 124221	ALEKSANDRA EFIMOVA	{"email": "efimova.aleksandra-111974@postgrespro.ru", "phone": "+70228785605"}
0005435225734	54D28C	2860 528320	FARIT VOLKOV	{"phone": "+70197251498"}
0005435225735	54D28C	0074 530915	OKSANA MOROZOVA	{"email": "omorozova20081972@postgrespro.ru", "phone": "+70455823394"}
0005435225736	BA35CD	4001 612114	NADEZHDA FEDOROVA	{"email": "nadezhda.fedorova_071980@postgrespro.ru", "phone": "+70678303867"}
0005435225737	777EC0	4235 856498	NINA MAKAROVA	{"email": "makarova_nina_1967@postgrespro.ru", "phone": "+70044741767"}
0005435225738	777EC0	9227 814004	MARINA MATVEEVA	{"phone": "+70967276365"}
0005435225739	E2DA4E	9238 928339	RIMMA DAVYDOVA	{"email": "rimmadavydova.02121967@postgrespro.ru", "phone": "+70467936891"}
0005435225740	2531C0	2258 445989	OLEG MIKHAYLOV	{"phone": "+70310229180"}
0005435225741	AF6F29	6131 159341	NINA KARPOVA	{"email": "karpova_nina-1970@postgrespro.ru", "phone": "+70911879832"}
0005435225742	AF6F29	5346 980639	ALBERT ALEKSANDROV	{"phone": "+70351346803"}
0005435225743	63E119	1489 916147	LYUBOV MOROZOVA	{"email": "lmorozova121961@postgrespro.ru", "phone": "+70838899541"}
0005435225744	99CE5A	9367 695497	SERGEY RODIONOV	{"email": "s_rodionov-1969@postgrespro.ru", "phone": "+70161387139"}
0005435225745	793FD3	0198 267534	EVDOKIYA ANISIMOVA	{"email": "e_anisimova_081973@postgrespro.ru", "phone": "+70912155795"}
0005435225746	EB5109	3313 743652	VALENTINA FEDOROVA	{"phone": "+70566942031"}
0005435225747	EB5109	1005 957506	ANASTASIYA EGOROVA	{"email": "anastasiya.egorova_1975@postgrespro.ru", "phone": "+70927477917"}
0005435225748	D61A0C	3957 967385	ILYA KUZNECOV	{"email": "kuznecov-ilya.1972@postgrespro.ru", "phone": "+70548499963"}
0005435225749	D61A0C	9162 268575	ALEKSANDRA BOGDANOVA	{"phone": "+70161915229"}
0005435225750	180E53	7762 116576	VALENTINA BORISOVA	{"email": "valentina_borisova.111975@postgrespro.ru", "phone": "+70163792132"}
0005435225751	A99B7D	2436 766545	MARINA ANTONOVA	{"email": "marina.antonova14051983@postgrespro.ru", "phone": "+70433402671"}
0005435225752	DD9175	1989 149292	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov_19101966@postgrespro.ru", "phone": "+70371368054"}
0005435225753	DD9175	8965 826477	SVETLANA SIDOROVA	{"phone": "+70581270150"}
0005435225754	92BAE3	6261 707171	VYACHESLAV SERGEEV	{"phone": "+70032369333"}
0005435225755	92BAE3	0837 506465	IRINA KARPOVA	{"phone": "+70594164390"}
0005435225756	37302D	8630 287943	VADIM ANDREEV	{"email": "andreev.v-08041973@postgrespro.ru", "phone": "+70397091256"}
0005435225757	2BE727	4032 865088	TATYANA AFANASEVA	{"phone": "+70524134391"}
0005435225758	F362F9	0095 920629	SVETLANA IVANOVA	{"phone": "+70087554004"}
0005435225759	BD2C5A	3872 900709	DMITRIY NIKITIN	{"phone": "+70123651053"}
0005435225760	BD2C5A	6230 291873	VLADIMIR KISELEV	{"email": "vladimir_kiselev_061965@postgrespro.ru", "phone": "+70883088785"}
0005435225761	73C9E2	4741 869131	GALINA GRISHINA	{"phone": "+70273565176"}
0005435225762	73C9E2	7341 024189	KIRILL VASILEV	{"email": "k_vasilev-04051964@postgrespro.ru", "phone": "+70713479415"}
0005435225763	0DDD9A	6858 135748	ILDAR KISELEV	{"phone": "+70264016811"}
0005435225764	24D7F2	1659 822334	GENNADIY FEDOTOV	{"email": "gennadiy_fedotov.16031979@postgrespro.ru", "phone": "+70971508687"}
0005435225765	8468D4	9951 113373	ALEKSANDR KUZNECOV	{"phone": "+70123553387"}
0005435225766	8468D4	6470 865786	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov22011977@postgrespro.ru", "phone": "+70166528092"}
0005435225767	7DD0A9	9556 349367	ELENA CHERNOVA	{"email": "chernova-elena_18051969@postgrespro.ru", "phone": "+70541241453"}
0005435225768	71EA93	9885 112994	LYUDMILA FEDOROVA	{"email": "fedorova-l1968@postgrespro.ru", "phone": "+70894603059"}
0005435225769	71EA93	7683 247723	DANIL STEPANOV	{"email": "dstepanov_23081983@postgrespro.ru", "phone": "+70295973107"}
0005435225770	66B4AE	0802 270254	VASILIY IVANOV	{"phone": "+70022530837"}
0005435225771	A4425D	0255 507729	GALINA IVANOVA	{"phone": "+70269332387"}
0005435225772	050F3D	6950 269553	ALEKSANDRA ARKHIPOVA	{"phone": "+70192647699"}
0005435225773	BF02A8	1797 565645	ALINA ORLOVA	{"email": "alinaorlova.1975@postgrespro.ru", "phone": "+70315137014"}
0005435225774	A5C1C4	1519 592432	TATYANA MAKAROVA	{"phone": "+70522934581"}
0005435225775	9FB6BC	4596 310684	DENIS GAVRILOV	{"email": "gavrilov.d_17051966@postgrespro.ru", "phone": "+70991105939"}
0005435225776	9FB6BC	8512 818937	ALEKSEY KOZLOV	{"phone": "+70517592437"}
0005435225777	4780D0	2269 245538	ELENA KUZNECOVA	{"phone": "+70483060984"}
0005435225778	A2EE27	1748 663775	ALEKSANDR NOVIKOV	{"phone": "+70906871158"}
0005435225779	94BBAE	6687 973596	SOFYA PETROVA	{"email": "petrova_sofya_21021964@postgrespro.ru", "phone": "+70126071003"}
0005435225780	D8EA80	3512 128281	ALEKSANDR ZHUKOV	{"phone": "+70464133967"}
0005435225781	B98BE0	9191 000984	ANGELINA BORISOVA	{"phone": "+70654413141"}
0005435225782	7F6A85	8079 336975	EKATERINA AKIMOVA	{"phone": "+70568739062"}
0005435225783	29A898	4023 581531	LIDIYA IVANOVA	{"email": "l_ivanova_24041974@postgrespro.ru", "phone": "+70237768852"}
0005435225784	29A898	5623 668588	ANDREY DENISOV	{"phone": "+70533894885"}
0005435225785	05BED6	6189 130747	YURIY SERGEEV	{"phone": "+70018755221"}
0005435225786	5D7C07	4252 813956	RAFAIL KUZNECOV	{"email": "kuznecov.r-26121971@postgrespro.ru", "phone": "+70877597198"}
0005435225787	D91768	4156 053668	TATYANA NESTEROVA	{"phone": "+70296419661"}
0005435225788	EA7775	0145 982129	LYUDMILA LUKYANOVA	{"phone": "+70225005022"}
0005435225789	DC7380	7070 909667	ALEKSANDR MAKSIMOV	{"phone": "+70924080989"}
0005435225790	44AB26	3166 820518	ALEKSANDR BONDARENKO	{"email": "aleksandrbondarenko.1973@postgrespro.ru", "phone": "+70645961886"}
0005435225791	44AB26	1040 391082	EVGENIY KISELEV	{"phone": "+70090448140"}
0005435225792	44AB26	1516 093900	DANIIL ORLOV	{"email": "d_orlov_21051968@postgrespro.ru", "phone": "+70431103594"}
0005435225793	B15F37	1387 305895	EVGENIY VASILEV	{"phone": "+70505503615"}
0005435225794	07DE52	8852 986592	NINA KOZLOVA	{"phone": "+70109654714"}
0005435225795	220A68	9944 812911	PAVEL OSIPOV	{"phone": "+70259803033"}
0005435225796	B10396	1414 663635	VERA ZAKHAROVA	{"email": "verazakharova.1981@postgrespro.ru", "phone": "+70574338434"}
0005435225797	DFE362	3281 821974	VASILIY SAVELEV	{"phone": "+70304500687"}
0005435225798	DFE362	2234 223990	ALEKSEY PETROV	{"email": "petrov-aleksey_01081971@postgrespro.ru", "phone": "+70191862220"}
0005435225799	F2C59F	2727 050520	TATYANA ARKHIPOVA	{"phone": "+70161366771"}
0005435225800	A41687	2558 301370	VLADIMIR MATVEEV	{"email": "vladimir_matveev111968@postgrespro.ru", "phone": "+70585286589"}
0005435225801	1D9B8C	3647 246152	SERGEY FROLOV	{"phone": "+70985386358"}
0005435225802	4552BD	8173 875122	ALEKSEY BELOV	{"phone": "+70011661500"}
0005435225803	4443B2	7650 991025	VLADIMIR DMITRIEV	{"email": "v_dmitriev-20071970@postgrespro.ru", "phone": "+70261904879"}
0005435225804	DF7BA1	3103 613788	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr041988@postgrespro.ru", "phone": "+70155781127"}
0005435225805	222E13	8628 846466	ALEKSEY SMIRNOV	{"email": "smirnov-a.06021968@postgrespro.ru", "phone": "+70089674617"}
0005435225806	1539F7	4907 571038	IRINA VASILEVA	{"phone": "+70979587822"}
0005435225807	353F25	6781 470109	MAKSIM IVANOV	{"phone": "+70790350520"}
0005435225808	353F25	2459 856250	DMITRIY KULIKOV	{"email": "dmitriy_kulikov_12051969@postgrespro.ru", "phone": "+70000772670"}
0005435225809	DD6485	6606 809088	KONSTANTIN FEDOROV	{"email": "fedorov.konstantin_041964@postgrespro.ru", "phone": "+70930631576"}
0005435225810	DE2C59	6426 967240	ANNA MELNIKOVA	{"email": "anna_melnikova1965@postgrespro.ru", "phone": "+70725297752"}
0005435225811	41DD76	3223 041962	IGOR KONOVALOV	{"email": "konovalovigor11021970@postgrespro.ru", "phone": "+70382622058"}
0005435225812	4EE837	8117 164871	ANTON GUSEV	{"email": "anton-gusev.071974@postgrespro.ru", "phone": "+70528863809"}
0005435225813	4EE837	8891 026598	TATYANA NOVIKOVA	{"email": "tnovikova.1971@postgrespro.ru", "phone": "+70703546259"}
0005435229301	386523	2759 504660	VLADIMIR BELOV	{"phone": "+70148983611"}
0005435229302	386523	6430 330339	SERGEY RODIONOV	{"email": "s.rodionov-1975@postgrespro.ru", "phone": "+70612409417"}
0005435229303	2E357D	4321 570892	ELENA GORBUNOVA	{"phone": "+70710756773"}
0005435229304	78A431	7059 452361	MARIYA PAVLOVA	{"email": "pavlovam.31011973@postgrespro.ru", "phone": "+70351320142"}
0005435229305	9E9F24	4604 698030	YANA ERMAKOVA	{"phone": "+70121757040"}
0005435229306	1F82A5	9833 546749	VIKTOR FROLOV	{"phone": "+70413751487"}
0005435229307	B1E516	2360 667053	ANNA KOROLEVA	{"email": "akoroleva.27081977@postgrespro.ru", "phone": "+70724616247"}
0005435229308	BF6ABF	9632 521044	ANTONINA ILINA	{"email": "ilina.a071968@postgrespro.ru", "phone": "+70880464393"}
0005435229309	70C052	7830 717579	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr_1962@postgrespro.ru", "phone": "+70725546413"}
0005435229310	70C052	9484 616453	SVETLANA MAKSIMOVA	{"email": "svetlana_maksimova.17031971@postgrespro.ru", "phone": "+70600465579"}
0005435229311	F8BC21	7902 394767	ELENA ZHURAVLEVA	{"email": "zhuravleva-e.061971@postgrespro.ru", "phone": "+70616517575"}
0005435229312	01EB85	1596 553752	VALENTINA RODIONOVA	{"email": "rodionova.valentina-08081966@postgrespro.ru", "phone": "+70196405252"}
0005435229313	C18F5F	4418 137369	ALEKSEY FOMIN	{"phone": "+70856591408"}
0005435229314	BEE77D	6755 223612	VYACHESLAV PETROV	{"phone": "+70914042971"}
0005435229315	49FD2D	4945 899754	ALEKSANDR ILIN	{"email": "aleksandrilin061978@postgrespro.ru", "phone": "+70816874711"}
0005435229316	49FD2D	4892 440827	ALEKSANDR SERGEEV	{"email": "aleksandr-sergeev_101971@postgrespro.ru", "phone": "+70038247061"}
0005435229317	A909FA	8191 014954	OLGA POPOVA	{"email": "popova.olga.1983@postgrespro.ru", "phone": "+70013232336"}
0005435229318	03D3DA	7404 146923	OLGA POPOVA	{"email": "opopova.13071966@postgrespro.ru", "phone": "+70658665665"}
0005435229319	03D3DA	3171 830548	LYUDMILA IVANOVA	{"phone": "+70015669154"}
0005435229320	60F17C	6288 462195	YANA MIKHAYLOVA	{"phone": "+70371866218"}
0005435229321	6C0DB2	1265 068556	PAVEL ABRAMOV	{"phone": "+70195258575"}
0005435229322	B6A057	4032 664663	VIKTORIYA ZAKHAROVA	{"phone": "+70342201333"}
0005435229323	B6A057	1212 920973	RUSLAN BORISOV	{"email": "borisovr.061966@postgrespro.ru", "phone": "+70907432241"}
0005435229324	621A26	9600 187011	TAMARA SMIRNOVA	{"phone": "+70356406244"}
0005435229325	C55C58	8176 517999	VASILIY MOROZOV	{"email": "vmorozov_10011978@postgrespro.ru", "phone": "+70859903665"}
0005435229326	C55C58	8075 773808	GALINA YAKOVLEVA	{"email": "galinayakovleva1968@postgrespro.ru", "phone": "+70026780441"}
0005435229327	5AD778	3520 665575	YULIYA KOROLEVA	{"phone": "+70842403714"}
0005435229328	CE6C79	4967 666114	SOFIYA OVCHINNIKOVA	{"phone": "+70276822686"}
0005435229329	CE6C79	0253 798193	RAISA DANILOVA	{"phone": "+70701102482"}
0005435229330	825C79	7587 994959	IRINA TARASOVA	{"phone": "+70764055464"}
0005435229331	08F71A	5839 435921	EKATERINA MELNIKOVA	{"email": "e.melnikova10021981@postgrespro.ru", "phone": "+70748003559"}
0005435229332	3E05D5	3487 562953	ALEFTINA MARTYNOVA	{"email": "aleftina-martynova-1957@postgrespro.ru", "phone": "+70454305844"}
0005435229334	A2C965	3209 216789	EVGENIY MAKSIMOV	{"email": "e-maksimov.15081966@postgrespro.ru", "phone": "+70027488578"}
0005435229335	A2C965	9666 430357	NADEZHDA SOKOLOVA	{"email": "sokolova.nadezhda26011965@postgrespro.ru", "phone": "+70488262620"}
0005435229336	AC1F8B	1744 582968	PAVEL KUZNECOV	{"phone": "+70376112588"}
0005435229337	7CBAFE	8878 103651	ZINAIDA FILIPPOVA	{"phone": "+70502120187"}
0005435229338	7CBAFE	7839 997905	EKATERINA TIMOFEEVA	{"phone": "+70308402771"}
0005435229339	2FE4CF	9347 802503	ALEKSANDR SAVELEV	{"phone": "+70442554613"}
0005435229340	D15312	8624 126041	IGOR MEDVEDEV	{"phone": "+70050113696"}
0005435229341	29AFD0	9271 432534	VIKTORIYA ARKHIPOVA	{"email": "arkhipova_viktoriya_111959@postgrespro.ru", "phone": "+70443390466"}
0005435229342	EBDBC6	7933 261720	EVGENIY ZAYCEV	{"phone": "+70306521319"}
0005435229343	E4A5AD	0015 715535	SVETLANA MELNIKOVA	{"phone": "+70377830960"}
0005435229344	E4A5AD	1552 140933	POLINA BELOVA	{"email": "polina-belova.14061977@postgrespro.ru", "phone": "+70417547359"}
0005435229345	7309C2	4167 383226	EKATERINA GERASIMOVA	{"email": "ekaterina-gerasimova_041982@postgrespro.ru", "phone": "+70219491859"}
0005435229346	71A319	8434 932248	VADIM MOROZOV	{"email": "v.morozov_051973@postgrespro.ru", "phone": "+70312864257"}
0005435229347	E125D4	9894 172301	ALEKSANDR NIKITIN	{"email": "nikitinaleksandr011967@postgrespro.ru", "phone": "+70503920033"}
0005435229348	F0C6CA	2343 627558	LIDIYA KUZNECOVA	{"phone": "+70786360153"}
0005435229349	F0C6CA	5222 026557	MARIYA KOVALEVA	{"email": "kovaleva_mariya071969@postgrespro.ru", "phone": "+70472535277"}
0005435229350	42C21D	9082 197920	MARINA BELYAEVA	{"email": "marina_belyaeva_1970@postgrespro.ru", "phone": "+70110970538"}
0005435229351	A7614C	1497 405672	RAMIL PETROV	{"email": "petrov_r1977@postgrespro.ru", "phone": "+70885229030"}
0005435229352	26F59F	4229 518948	DANIIL ILIN	{"phone": "+70612213371"}
0005435229353	74DB16	7833 765257	ELENA DMITRIEVA	{"email": "e.dmitrieva_1976@postgrespro.ru", "phone": "+70015163432"}
0005435229354	97C1B9	1957 759755	ALEKSEY GERASIMOV	{"email": "gerasimova.22031988@postgrespro.ru", "phone": "+70244939727"}
0005435229355	97C1B9	1961 513498	GALINA NIKITINA	{"phone": "+70736518165"}
0005435229356	95996C	2299 708598	OLGA KONDRATEVA	{"email": "o_kondrateva-01081962@postgrespro.ru", "phone": "+70124872932"}
0005435229357	AB00FA	8844 233284	VALERIYA ANISIMOVA	{"email": "valeriya_anisimova_111973@postgrespro.ru", "phone": "+70963557279"}
0005435229358	AB00FA	9599 061449	SVETLANA SCHERBAKOVA	{"email": "scherbakova.s.18021970@postgrespro.ru", "phone": "+70859222080"}
0005435229359	D05D4B	8995 522461	OKSANA STEPANOVA	{"phone": "+70521296424"}
0005435229360	ED57A8	3677 347325	MARINA ZHURAVLEVA	{"phone": "+70970098889"}
0005435229361	ED57A8	0256 975157	ANDREY ABRAMOV	{"phone": "+70984882333"}
0005435229362	81B994	2980 189955	NINA VOLKOVA	{"email": "n_volkova_051961@postgrespro.ru", "phone": "+70493695450"}
0005435229363	81B994	2712 440872	PAVEL KUZMIN	{"email": "kuzmin_p14071974@postgrespro.ru", "phone": "+70179087828"}
0005435229364	A6CACD	5091 869402	MAKSIM SHEVCHENKO	{"phone": "+70578511556"}
0005435229365	9876A7	1809 808962	VERA PETROVA	{"phone": "+70112728225"}
0005435229366	9F5E4E	7055 899787	ALEKSANDR VASILEV	{"email": "a-vasilev.1978@postgrespro.ru", "phone": "+70358492494"}
0005435229367	9F5E4E	0798 518456	INNA ANDREEVA	{"phone": "+70477704807"}
0005435229368	24B8C9	2287 364151	NATALYA RODIONOVA	{"email": "rodionovan.1977@postgrespro.ru", "phone": "+70526820664"}
0005435229369	24B8C9	8292 027875	OKSANA SMIRNOVA	{"email": "smirnova.oksana_1984@postgrespro.ru", "phone": "+70500086171"}
0005435229370	CB0614	8813 432226	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova-071987@postgrespro.ru", "phone": "+70510655747"}
0005435229371	947AAB	9826 025217	NIKITA KUZNECOV	{"email": "n_kuznecov.22071978@postgrespro.ru", "phone": "+70940324144"}
0005435229372	947AAB	4462 423949	MIKHAIL TARASOV	{"email": "tarasov-mikhail_12011971@postgrespro.ru", "phone": "+70549648315"}
0005435229373	B21DA7	1162 730066	ANDREY BARANOV	{"phone": "+70745049494"}
0005435229374	20B7BB	5137 271722	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev_1970@postgrespro.ru", "phone": "+70677649408"}
0005435229375	69259D	6047 314529	ANNA FROLOVA	{"phone": "+70521455304"}
0005435229376	EF854F	1678 733414	NATALYA KOZLOVA	{"phone": "+70747590562"}
0005435229377	EF854F	4944 670469	NATALYA NIKITINA	{"email": "nikitina-natalya27081963@postgrespro.ru", "phone": "+70497048538"}
0005435229378	BC98BF	1651 597792	DMITRIY KAZAKOV	{"email": "kazakov.dmitriy_1972@postgrespro.ru", "phone": "+70808291954"}
0005435229379	7E83F9	8795 623184	ANATOLIY KISELEV	{"email": "kiselev.a101973@postgrespro.ru", "phone": "+70578905895"}
0005435229380	6D2BD4	2330 230071	ALEKSEY OSIPOV	{"phone": "+70065097476"}
0005435229381	DABC44	3092 808408	RUSLAN MIKHAYLOV	{"phone": "+70938304639"}
0005435229382	DABC44	9752 271174	ANASTASIYA EFREMOVA	{"email": "efremovaa-22091967@postgrespro.ru", "phone": "+70745231710"}
0005435229383	DABC44	7554 754384	LYUDMILA MIKHAYLOVA	{"phone": "+70164256359"}
0005435229384	3C00D3	9798 565017	NATALYA ZAYCEVA	{"email": "n_zayceva.12081985@postgrespro.ru", "phone": "+70559296511"}
0005435229385	1B6BAD	5424 046388	MARGARITA BORISOVA	{"email": "m_borisova.07021962@postgrespro.ru", "phone": "+70035526374"}
0005435229386	2C787A	1822 936870	MARIYA ALEKSEEVA	{"email": "alekseeva.mariya.1968@postgrespro.ru", "phone": "+70265881715"}
0005435229387	75E33F	6172 816141	NATALYA CHERNOVA	{"phone": "+70713605551"}
0005435229388	37791D	3003 344321	NATALYA SOLOVEVA	{"email": "soloveva_natalya.1970@postgrespro.ru", "phone": "+70008147507"}
0005435229389	37791D	6254 635194	ZOYA AKIMOVA	{"email": "z_akimova_1960@postgrespro.ru", "phone": "+70472138796"}
0005435229390	2D1E14	7705 665338	VALENTINA GORBUNOVA	{"email": "vgorbunova1974@postgrespro.ru", "phone": "+70240484044"}
0005435229391	92DF91	4676 129261	ALEKSANDR ZAKHAROV	{"email": "a-zakharov-031975@postgrespro.ru", "phone": "+70096069852"}
0005435229392	7A8007	2820 074154	NIKOLAY GRIGOREV	{"email": "nikolay-grigorev.1975@postgrespro.ru", "phone": "+70309256356"}
0005435229393	89E15C	7905 041306	ALEKSANDR FOMIN	{"email": "aleksandrfomin.17041964@postgrespro.ru", "phone": "+70570272335"}
0005435229394	9F4A4D	0755 832723	VLADA NAUMOVA	{"phone": "+70553175403"}
0005435229395	7D8B6E	5965 974011	ALEKSANDR DMITRIEV	{"email": "a_dmitriev.10081972@postgrespro.ru", "phone": "+70239808007"}
0005435229396	73F3EE	8415 592768	NATALYA KONOVALOVA	{"phone": "+70279095064"}
0005435229397	73F3EE	6677 451462	DMITRIY ANDREEV	{"phone": "+70054802028"}
0005435229398	1519E3	3986 823664	ANDREY ZAKHAROV	{"phone": "+70234973922"}
0005435229399	2B59F3	1362 197770	TATYANA DENISOVA	{"email": "tatyana.denisova_23121977@postgrespro.ru", "phone": "+70277795704"}
0005435229400	2B59F3	8123 951906	ARTEM SEMENOV	{"phone": "+70268879907"}
0005435229401	4B94C5	2781 901459	RAVIL NAUMOV	{"phone": "+70536021320"}
0005435229402	4B94C5	8123 928874	TATYANA KONOVALOVA	{"email": "konovalova_tatyana_02091971@postgrespro.ru", "phone": "+70092376739"}
0005435229403	4B94C5	8388 020078	VALERIY STEPANOV	{"phone": "+70070235372"}
0005435229404	ED7F0F	9068 007499	VIKTORIYA KUZNECOVA	{"email": "v_kuznecova.011974@postgrespro.ru", "phone": "+70635246706"}
0005435229405	ED7F0F	3985 491509	NATALYA TITOVA	{"phone": "+70834128969"}
0005435229406	ED7F0F	3066 523256	YURIY MATVEEV	{"phone": "+70061494158"}
0005435229407	AF97C3	9845 038799	ANTON ISAEV	{"phone": "+70493069222"}
0005435229408	829464	2814 803531	OLGA VASILEVA	{"phone": "+70406665539"}
0005435229409	829464	8596 974530	TAMARA KUZMINA	{"phone": "+70663431056"}
0005435229410	2E9E7D	6994 172836	ALLA GUSEVA	{"email": "alla_guseva_12051980@postgrespro.ru", "phone": "+70185874873"}
0005435229411	C5EE37	4682 001189	OLGA SOLOVEVA	{"phone": "+70516298110"}
0005435229412	9C5C37	3452 266235	RUSLAN GAVRILOV	{"email": "r_gavrilov-061970@postgrespro.ru", "phone": "+70871409119"}
0005435229413	FCD7DA	7076 326195	RUSTAM VASILEV	{"email": "rustamvasilev_06111975@postgrespro.ru", "phone": "+70084059508"}
0005435229414	FCD7DA	7545 608602	LARISA ALEKSEEVA	{"email": "alekseeva.l051970@postgrespro.ru", "phone": "+70261061956"}
0005435229415	4A7B3E	4059 924494	MARIYA TROFIMOVA	{"phone": "+70216762404"}
0005435229416	4A7B3E	0661 617145	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov.081963@postgrespro.ru", "phone": "+70007810633"}
0005435229417	4A7B3E	8808 100253	ALEKSANDR BORISOV	{"phone": "+70429900247"}
0005435229528	B5D094	2321 931029	DAMIR TIKHONOV	{"phone": "+70204829044"}
0005435229418	93E51B	6694 799037	YAROSLAV POPOV	{"email": "yaroslav.popov_1986@postgrespro.ru", "phone": "+70965745120"}
0005435229419	93E51B	6370 296515	VSEVOLOD TIKHONOV	{"email": "tikhonovvsevolod-1969@postgrespro.ru", "phone": "+70460634477"}
0005435229420	93E51B	6288 492535	ANTON SCHERBAKOV	{"email": "scherbakov-a02031958@postgrespro.ru", "phone": "+70821256028"}
0005435229421	A63FC0	8665 891946	TIMUR SERGEEV	{"phone": "+70171081546"}
0005435229422	7EBBBD	7187 951797	VLADIMIR BARANOV	{"phone": "+70458769052"}
0005435229423	7EBBBD	2880 847475	ANASTASIYA ORLOVA	{"email": "orlova-anastasiya19051980@postgrespro.ru", "phone": "+70918284058"}
0005435229424	844F18	9449 453234	EKATERINA LAZAREVA	{"phone": "+70361155998"}
0005435229425	D39D4F	4255 754452	DMITRIY ORLOV	{"email": "dmitriy_orlov.051977@postgrespro.ru", "phone": "+70422148023"}
0005435229426	D39D4F	4067 541359	ALBERT PAVLOV	{"email": "a-pavlov051961@postgrespro.ru", "phone": "+70218066457"}
0005435229427	570829	2055 053145	VIKTOR IVANOV	{"email": "viktorivanov121974@postgrespro.ru", "phone": "+70629246934"}
0005435229428	570829	3128 350045	NATALYA TARASOVA	{"email": "tarasova-natalya051980@postgrespro.ru", "phone": "+70940209455"}
0005435229429	6EBA79	4049 059379	MAKSIM CHERNOV	{"email": "m_chernov.1969@postgrespro.ru", "phone": "+70859825955"}
0005435229430	6E54B7	0836 980082	KIRILL CHERNOV	{"phone": "+70027009408"}
0005435229431	5887B5	9464 252341	LYUBOV DENISOVA	{"phone": "+70193305412"}
0005435229432	B65CCF	0158 510917	NINA SAVELEVA	{"email": "savelevanina23041976@postgrespro.ru", "phone": "+70777773830"}
0005435229433	25DCF7	2081 574100	ALEKSANDR MARTYNOV	{"email": "martynov.a091956@postgrespro.ru", "phone": "+70244432056"}
0005435229434	25DCF7	1651 593943	NIKOLAY IVANOV	{"email": "n.ivanov.1973@postgrespro.ru", "phone": "+70405597588"}
0005435229435	8E4887	7791 913800	VADIM FILIPPOV	{"email": "filippov-vadim16111969@postgrespro.ru", "phone": "+70703699192"}
0005435229436	31FB2E	8922 294157	ELENA ORLOVA	{"email": "eorlova071974@postgrespro.ru", "phone": "+70700897018"}
0005435229437	13B0E7	0302 293320	PAVEL BONDARENKO	{"phone": "+70340706509"}
0005435229438	13B0E7	0748 445580	ANATOLIY MATVEEV	{"phone": "+70303374431"}
0005435229439	4DFA59	0627 800307	ALEKSANDRA MAKSIMOVA	{"email": "a.maksimova.1973@postgrespro.ru", "phone": "+70279716480"}
0005435229440	5D9EBF	7154 185809	DARYA BELOVA	{"email": "belova-d.28061970@postgrespro.ru", "phone": "+70356544617"}
0005435229441	5D9EBF	0752 272633	VIKTOR GUSEV	{"phone": "+70585854421"}
0005435229442	5D9EBF	8450 178409	ELENA SOROKINA	{"email": "sorokinae.011957@postgrespro.ru", "phone": "+70649963072"}
0005435229443	E82461	5664 711921	ALEKSANDR SERGEEV	{"phone": "+70100483317"}
0005435229444	DAEB49	9407 053954	ELENA MELNIKOVA	{"email": "melnikovaelena081986@postgrespro.ru", "phone": "+70657477582"}
0005435229445	7A8814	3512 315880	VIKTOR YAKOVLEV	{"phone": "+70555456453"}
0005435229446	004FC8	4232 287581	YURIY VLASOV	{"email": "vlasov_y.1986@postgrespro.ru", "phone": "+70133297679"}
0005435229447	24372A	5024 205917	VALENTINA TIMOFEEVA	{"email": "vtimofeeva-121980@postgrespro.ru", "phone": "+70892802137"}
0005435229448	F8BAE4	4830 096434	NATALYA MIRONOVA	{"email": "mironova-natalya101973@postgrespro.ru", "phone": "+70167157905"}
0005435229449	F8BAE4	5798 787446	LIDIYA GERASIMOVA	{"phone": "+70281995932"}
0005435229450	35DDEF	3666 965299	VALENTINA FILATOVA	{"phone": "+70782065321"}
0005435229451	F8E08A	7880 197875	ANASTASIYA MAKSIMOVA	{"phone": "+70798167145"}
0005435229452	A39181	4041 707128	IRINA ALEKSEEVA	{"email": "i_alekseeva_1981@postgrespro.ru", "phone": "+70302325113"}
0005435229453	A39181	3008 850897	ANNA KUZNECOVA	{"email": "kuznecovaa.031976@postgrespro.ru", "phone": "+70622042460"}
0005435229454	A4E132	7690 191789	MARINA BELOVA	{"email": "belova_marina_111961@postgrespro.ru", "phone": "+70786249273"}
0005435229455	44425D	1964 991937	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov.12031962@postgrespro.ru", "phone": "+70566604261"}
0005435229456	44425D	1564 690206	ALEKSANDR SERGEEV	{"phone": "+70455416066"}
0005435229457	7577E2	9511 391214	ALEKSANDR TARASOV	{"email": "tarasov_aleksandr02101972@postgrespro.ru", "phone": "+70734979987"}
0005435229458	54F0D8	3477 403251	ELENA PAVLOVA	{"phone": "+70641176103"}
0005435229459	9297D8	2491 373257	SERGEY KRASNOV	{"phone": "+70986623227"}
0005435229460	9297D8	4236 024115	MIKHAIL ABRAMOV	{"phone": "+70361718449"}
0005435229461	15F39C	7521 771591	LARISA BARANOVA	{"email": "larisabaranova_01021976@postgrespro.ru", "phone": "+70922968013"}
0005435229462	70B882	1261 002183	ARSENIY MOROZOV	{"phone": "+70972126983"}
0005435229463	AD0065	5834 788945	VIKTORIYA SOLOVEVA	{"email": "v-soloveva_1976@postgrespro.ru", "phone": "+70515319588"}
0005435229464	887DC9	8224 355177	VIKTOR TARASOV	{"phone": "+70741125555"}
0005435229465	887DC9	6306 049432	IRINA ABRAMOVA	{"email": "irina.abramova.031978@postgrespro.ru", "phone": "+70688936275"}
0005435229466	3871F9	6331 442739	EVGENIY BONDARENKO	{"phone": "+70054690059"}
0005435229467	3871F9	4410 236686	ALEKSANDR EGOROV	{"email": "aleksandr_egorov.05031974@postgrespro.ru", "phone": "+70902651876"}
0005435229468	71F34C	9683 800737	SVETLANA BORISOVA	{"email": "borisovasvetlana_101966@postgrespro.ru", "phone": "+70234383202"}
0005435229469	274842	0565 729206	ANDREY IVANOV	{"phone": "+70541290292"}
0005435229470	DE2295	6213 627860	NINA KOROLEVA	{"email": "nina_koroleva.17051964@postgrespro.ru", "phone": "+70605369478"}
0005435229471	DE2295	7849 108009	MARIYA SCHERBAKOVA	{"email": "m-scherbakova03021977@postgrespro.ru", "phone": "+70301633269"}
0005435229472	DE2295	3694 517045	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov-1963@postgrespro.ru", "phone": "+70895734825"}
0005435229473	5C47AB	1462 614611	ANTONINA ANTONOVA	{"email": "antonova-antonina1981@postgrespro.ru", "phone": "+70769823864"}
0005435229474	0EAA9A	3142 325321	LYUBOV OSIPOVA	{"phone": "+70269560773"}
0005435229475	FAC6E5	5237 419189	GALINA KUDRYASHOVA	{"phone": "+70370710972"}
0005435229476	69DE08	7517 809985	GEORGIY KUZMIN	{"email": "georgiy.kuzmin_051965@postgrespro.ru", "phone": "+70322297982"}
0005435229477	D63229	5775 644472	VALENTINA KUZNECOVA	{"phone": "+70502488492"}
0005435229478	D63229	3550 025801	TATYANA MARTYNOVA	{"phone": "+70222162727"}
0005435229479	03E999	0292 312495	VLADIMIR KOROLEV	{"email": "vkorolev-10021975@postgrespro.ru", "phone": "+70735059941"}
0005435229480	544C2C	5069 490987	VIKTOR GORBUNOV	{"email": "viktor-gorbunov-1975@postgrespro.ru", "phone": "+70137407358"}
0005435229481	7E3192	2125 708810	VYACHESLAV MIRONOV	{"email": "mironov.vyacheslav091975@postgrespro.ru", "phone": "+70524648735"}
0005435229482	78626A	5785 144192	VLADISLAV BARANOV	{"phone": "+70376799058"}
0005435229483	78626A	8291 223791	MIKHAIL ZAYCEV	{"email": "zaycev.mikhail-071977@postgrespro.ru", "phone": "+70852954220"}
0005435229484	78626A	5651 659673	ALEKSANDR FEDOROV	{"phone": "+70027800547"}
0005435229485	328522	4394 907822	VITALIY FOMIN	{"email": "v.fomin-10031973@postgrespro.ru", "phone": "+70113476394"}
0005435229486	328522	7152 698641	IRINA NIKOLAEVA	{"phone": "+70085663520"}
0005435229487	AABD76	1477 467629	NADEZHDA POPOVA	{"email": "nadezhdapopova1962@postgrespro.ru", "phone": "+70280812876"}
0005435229488	8FB7F0	7645 240299	SERGEY KULIKOV	{"phone": "+70762697166"}
0005435229489	8FB7F0	2878 341167	VYACHESLAV FEDOTOV	{"email": "fedotov.vyacheslav_1967@postgrespro.ru", "phone": "+70097926781"}
0005435229490	8FB7F0	5354 550494	GALINA LUKYANOVA	{"phone": "+70874764382"}
0005435229491	346641	8806 034026	DMITRIY NOVIKOV	{"phone": "+70531939562"}
0005435229492	971663	0948 847338	EVGENIYA DMITRIEVA	{"phone": "+70523969936"}
0005435229493	AB004A	4527 275751	ILYA IVANOV	{"phone": "+70740692644"}
0005435229494	FFAD34	9289 370761	VALERIY ANDREEV	{"phone": "+70499014468"}
0005435229495	AF17C3	8650 624325	SVETLANA DMITRIEVA	{"email": "dmitrieva.svetlana-021967@postgrespro.ru", "phone": "+70522292382"}
0005435229496	4D0C6C	3501 629641	OLGA KARPOVA	{"email": "okarpova.071969@postgrespro.ru", "phone": "+70696444172"}
0005435229497	C576D5	7134 881806	LYUBOV ANISIMOVA	{"email": "anisimova.lyubov_07021976@postgrespro.ru", "phone": "+70064442998"}
0005435229498	164585	7411 551882	TAMARA EGOROVA	{"email": "egorova.t081977@postgrespro.ru", "phone": "+70534070107"}
0005435229499	E0FB89	8999 819369	TATYANA TITOVA	{"phone": "+70937100908"}
0005435229500	0FE0FB	0912 065599	VLADIMIR GUSEV	{"email": "gusevv-1973@postgrespro.ru", "phone": "+70614081040"}
0005435229501	AC0A44	2676 625773	VLADIMIR NOVIKOV	{"phone": "+70726951257"}
0005435229502	B8989D	5719 004461	IVAN KOROLEV	{"email": "ivan_korolev09121968@postgrespro.ru", "phone": "+70910250877"}
0005435229503	B6BEF9	5938 292018	ALEKSANDR TIMOFEEV	{"phone": "+70582570976"}
0005435229504	B6BEF9	7697 758483	VARVARA PAVLOVA	{"email": "v_pavlova-1976@postgrespro.ru", "phone": "+70732208669"}
0005435229505	F44853	6833 640886	NATALYA ANISIMOVA	{"email": "anisimova-n051971@postgrespro.ru", "phone": "+70388327542"}
0005435229506	227890	9146 218581	IGOR KUZMIN	{"email": "i_kuzmin.101977@postgrespro.ru", "phone": "+70440516082"}
0005435229507	227890	8301 741142	ANDREY IVANOV	{"email": "ivanov-a_24051976@postgrespro.ru", "phone": "+70059791797"}
0005435229508	28AD00	4482 455131	EVGENIY MELNIKOV	{"email": "melnikov_evgeniy1970@postgrespro.ru", "phone": "+70626000918"}
0005435229509	047037	9094 730581	OLESYA KARPOVA	{"email": "karpova-olesya-101976@postgrespro.ru", "phone": "+70521540126"}
0005435229510	047037	9086 776158	VLADIMIR BELOV	{"email": "belov_vladimir_031962@postgrespro.ru", "phone": "+70432045333"}
0005435229511	7C250A	8054 977973	SERGEY ALEKSANDROV	{"email": "saleksandrov_1985@postgrespro.ru", "phone": "+70867401617"}
0005435229512	775114	2094 140656	ANATOLIY KUDRYASHOV	{"email": "kudryashovanatoliy.041988@postgrespro.ru", "phone": "+70238244458"}
0005435229513	8B1FF5	2770 354926	VALENTINA BELOVA	{"email": "belovavalentina-021974@postgrespro.ru", "phone": "+70546201551"}
0005435229514	423489	8609 327079	ANGELINA NIKIFOROVA	{"email": "nikiforovaa.1956@postgrespro.ru", "phone": "+70113076141"}
0005435229515	F1D13F	3030 429468	DMITRIY KUZMIN	{"phone": "+70151621387"}
0005435229516	2E7CD9	9988 396848	DARYA KOROLEVA	{"email": "dkoroleva-16061972@postgrespro.ru", "phone": "+70285453867"}
0005435229517	F21A7F	1857 175717	ANDREY GAVRILOV	{"phone": "+70567244337"}
0005435229518	6882EE	0171 436166	ELIZAVETA SMIRNOVA	{"email": "elizaveta.smirnova-01021962@postgrespro.ru", "phone": "+70010727022"}
0005435229519	35F97A	6572 124122	IVAN MAKSIMOV	{"email": "maksimovivan-1970@postgrespro.ru", "phone": "+70477928376"}
0005435229520	771C62	2096 962936	TATYANA KUDRYASHOVA	{"phone": "+70949562817"}
0005435229521	771C62	1030 861333	ANASTASIYA BORISOVA	{"phone": "+70228843487"}
0005435229522	5477D9	1430 576001	ELVIRA FILIPPOVA	{"email": "elvira-filippova071970@postgrespro.ru", "phone": "+70479708649"}
0005435229523	5477D9	2348 509202	LIDIYA KOVALEVA	{"email": "kovaleva-l.111970@postgrespro.ru", "phone": "+70641915838"}
0005435229524	3CF98D	7687 639728	GALINA MOROZOVA	{"email": "galinamorozova101972@postgrespro.ru", "phone": "+70446501467"}
0005435229525	3CF98D	7273 675375	OKSANA BELOVA	{"phone": "+70448913186"}
0005435229526	913E31	6778 991965	NATALYA KOMAROVA	{"phone": "+70548617286"}
0005435229527	B5D094	8569 272019	KSENIYA EFIMOVA	{"phone": "+70751209545"}
0005435229529	56E2F0	8163 158764	ELENA KUZNECOVA	{"email": "elenakuznecova28081966@postgrespro.ru", "phone": "+70484234749"}
0005435229530	54248A	5782 982634	VLADIMIR CHERNOV	{"phone": "+70315265952"}
0005435229531	54248A	2676 681187	ALENA POLYAKOVA	{"phone": "+70217838273"}
0005435229532	1517F9	8931 355473	IRAIDA GAVRILOVA	{"phone": "+70493501195"}
0005435229533	824385	6109 075056	ANNA FADEEVA	{"email": "anna.fadeeva.1974@postgrespro.ru", "phone": "+70498380219"}
0005435229534	7EBDAB	2852 674038	ANATOLIY ZHURAVLEV	{"phone": "+70586141209"}
0005435229535	E7038E	8206 825581	EKATERINA NAZAROVA	{"phone": "+70801470087"}
0005435229536	6ABC91	3915 335852	VIKTOR DMITRIEV	{"email": "viktordmitriev-121976@postgrespro.ru", "phone": "+70326959665"}
0005435229537	D4D9E5	9035 121687	NATALYA FROLOVA	{"email": "nfrolova-051978@postgrespro.ru", "phone": "+70113844962"}
0005435229538	4E9710	9271 652211	IRINA VASILEVA	{"email": "vasilevai.1975@postgrespro.ru", "phone": "+70181610194"}
0005435229539	C0DF61	4050 660575	ARTEM GAVRILOV	{"phone": "+70589394986"}
0005435229540	74DEEF	4157 282123	LYUDMILA SMIRNOVA	{"phone": "+70418952485"}
0005435229541	74DEEF	4270 397348	VIKTOR MAKAROV	{"phone": "+70508399733"}
0005435229542	74DEEF	4632 374390	IRINA SEMENOVA	{"phone": "+70220721337"}
0005435229543	E4020F	5177 764589	DMITRIY FEDOROV	{"phone": "+70340172196"}
0005435229544	EA2801	6973 801941	OLEG MAKAROV	{"phone": "+70378373240"}
0005435229545	8E7C7C	9615 722204	NELLI MAKAROVA	{"phone": "+70252567178"}
0005435229546	DF06CF	9464 832735	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey.1976@postgrespro.ru", "phone": "+70310630571"}
0005435229547	DF06CF	5967 080277	IOSIF GUSEV	{"email": "gusev.iosif_04041980@postgrespro.ru", "phone": "+70381176029"}
0005435229548	18505C	6017 026279	ALEKSANDR MELNIKOV	{"email": "melnikov.a_1986@postgrespro.ru", "phone": "+70429178378"}
0005435229549	722BB0	8516 577760	VALERIY ANDREEV	{"phone": "+70987547908"}
0005435229550	722BB0	2940 118218	MARIYA CHERNOVA	{"email": "chernova_mariya1967@postgrespro.ru", "phone": "+70453007776"}
0005435229551	413209	3171 294491	OLGA SOROKINA	{"email": "sorokina_olga12051961@postgrespro.ru", "phone": "+70584724918"}
0005435229552	99F1B7	2363 657659	ANNA POLYAKOVA	{"email": "polyakova_anna12111974@postgrespro.ru", "phone": "+70468269512"}
0005435229553	7BAE40	6613 693542	NINA KISELEVA	{"email": "nina_kiseleva-05051965@postgrespro.ru", "phone": "+70857674744"}
0005435229554	23EA1D	5957 700426	EKATERINA KUZNECOVA	{"email": "e_kuznecova_01121972@postgrespro.ru", "phone": "+70107313354"}
0005435229555	4F641F	8119 561153	IOSIF BONDARENKO	{"phone": "+70746658483"}
0005435229556	4F641F	0633 420159	NATALYA SOROKINA	{"email": "sorokinan1977@postgrespro.ru", "phone": "+70141939884"}
0005435229557	11C7A7	4308 226234	IVAN YAKOVLEV	{"email": "i_yakovlev.1974@postgrespro.ru", "phone": "+70103892313"}
0005435229558	66C0BE	2584 228253	NIKOLAY VASILEV	{"phone": "+70631798203"}
0005435229559	66C0BE	1400 100526	TATYANA KALININA	{"phone": "+70714041153"}
0005435229560	2C5DC2	9006 723589	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy-021970@postgrespro.ru", "phone": "+70635425111"}
0005435229561	0F7F32	1448 492985	VLADIMIR KUZNECOV	{"phone": "+70199320230"}
0005435229562	2A137B	0880 462050	ALENA NIKITINA	{"email": "nikitinaalena-041981@postgrespro.ru", "phone": "+70530806076"}
0005435229563	2A137B	0022 610115	NAZAR KONOVALOV	{"email": "konovalov.n.23081982@postgrespro.ru", "phone": "+70657886559"}
0005435229564	BD7E40	9857 099240	ELENA NAZAROVA	{"email": "elenanazarova_14061980@postgrespro.ru", "phone": "+70380209716"}
0005435229565	BD7E40	3685 699493	SERGEY SEMENOV	{"phone": "+70718159414"}
0005435229566	BC0F23	8456 059104	STEPAN MAKAROV	{"phone": "+70753050242"}
0005435229567	5C153C	0804 690132	LYUBOV DENISOVA	{"email": "denisova_lyubov.1980@postgrespro.ru", "phone": "+70917034822"}
0005435229568	2B229A	2287 030052	VERA VOROBEVA	{"email": "vorobeva.v.1979@postgrespro.ru", "phone": "+70975972848"}
0005435229569	FB7568	5241 042024	SVETLANA BELOVA	{"phone": "+70109391833"}
0005435229570	18C4D2	9104 944123	EKATERINA NOVIKOVA	{"phone": "+70567144505"}
0005435229571	0C7D2A	7241 214416	OLEG SEMENOV	{"phone": "+70194370019"}
0005435229572	AFC350	4685 072757	ELENA GORBUNOVA	{"email": "e_gorbunova1975@postgrespro.ru", "phone": "+70074431432"}
0005435229573	A042BE	9094 368102	EVGENIY MELNIKOV	{"email": "melnikov_evgeniy_1973@postgrespro.ru", "phone": "+70647473132"}
0005435229574	62FE5F	5795 916028	ELIZAVETA FEDOROVA	{"email": "elizaveta.fedorova1971@postgrespro.ru", "phone": "+70823321002"}
0005435229575	5E2FBE	3163 760653	OLGA CHERNOVA	{"phone": "+70854998344"}
0005435229576	5E2FBE	1614 395798	ANDREY NIKITIN	{"phone": "+70282624490"}
0005435229577	51D816	7620 578454	VALERIY VLASOV	{"email": "valeriy-vlasov.121971@postgrespro.ru", "phone": "+70293960160"}
0005435229578	0D9752	1136 401926	YURIY KUDRYASHOV	{"email": "kudryashov.y.021965@postgrespro.ru", "phone": "+70787472808"}
0005435229579	0D9752	4433 197638	NATALYA YUDINA	{"email": "yudina_n091967@postgrespro.ru", "phone": "+70430671465"}
0005435229580	F622FB	7284 270672	OLGA AFANASEVA	{"email": "afanasevaolga.071983@postgrespro.ru", "phone": "+70969560294"}
0005435229581	2B9690	4319 324947	DENIS GRIGOREV	{"email": "denis.grigorev.1980@postgrespro.ru", "phone": "+70677039566"}
0005435229582	2B9690	8787 752833	PAVEL KUZNECOV	{"phone": "+70022496936"}
0005435229583	F9A2CE	4643 810568	SOFYA STEPANOVA	{"email": "stepanovasofya1975@postgrespro.ru", "phone": "+70193030603"}
0005435229584	5B105B	0916 200907	VERA KOMAROVA	{"email": "komarova-vera.07051970@postgrespro.ru", "phone": "+70503635052"}
0005435229585	AB359B	7836 396897	SERGEY IVANOV	{"phone": "+70832760292"}
0005435229586	AB359B	9383 312222	SERGEY DENISOV	{"email": "sergey-denisov-041969@postgrespro.ru", "phone": "+70948877618"}
0005435229587	5A8621	8038 087540	VYACHESLAV MARTYNOV	{"email": "martynov-vyacheslav_061972@postgrespro.ru", "phone": "+70695764374"}
0005435229588	5A8621	6786 621535	ANASTASIYA BELOVA	{"email": "belova_anastasiya_1971@postgrespro.ru", "phone": "+70663997806"}
0005435229589	5A8621	7513 620850	YURIY MATVEEV	{"email": "ymatveev-29101964@postgrespro.ru", "phone": "+70811557814"}
0005435229590	9581FE	3113 683196	VALENTINA PETROVA	{"email": "valentina_petrova1983@postgrespro.ru", "phone": "+70004096836"}
0005435229591	375CBF	4925 457249	ZINAIDA VASILEVA	{"phone": "+70219129644"}
0005435229592	375CBF	5968 576671	ROZA PAVLOVA	{"email": "pavlova_roza1971@postgrespro.ru", "phone": "+70665199591"}
0005435229593	C898AE	8586 229378	TIMOFEY EGOROV	{"phone": "+70170329986"}
0005435229594	C898AE	3532 496853	ANTONINA PETROVA	{"phone": "+70324137462"}
0005435229595	ECFECA	6266 720701	VLADIMIR ANDREEV	{"email": "andreev_v.051975@postgrespro.ru", "phone": "+70518061106"}
0005435229596	ECFECA	6417 036257	RUSTAM SAVELEV	{"phone": "+70927829444"}
0005435229597	ECFECA	0180 876803	ELENA PAVLOVA	{"phone": "+70880982883"}
0005435229598	92ECE5	7653 937709	VALERIY ZHUKOV	{"phone": "+70546028391"}
0005435229599	DF6DA4	9670 209763	RAISA NESTEROVA	{"email": "raisa-nesterova_091982@postgrespro.ru", "phone": "+70561290969"}
0005435229600	5C3A35	5385 658008	GALINA TIMOFEEVA	{"email": "gtimofeeva.10121969@postgrespro.ru", "phone": "+70543477177"}
0005435229601	14617B	0889 441471	ANTONINA POLYAKOVA	{"phone": "+70683845609"}
0005435229602	14617B	4784 843556	VALENTINA EGOROVA	{"phone": "+70689200140"}
0005435229603	96FF96	0653 438497	SVETLANA NAZAROVA	{"email": "svetlana_nazarova26111971@postgrespro.ru", "phone": "+70545550035"}
0005435229604	96FF96	6765 331209	ELENA SOROKINA	{"phone": "+70043553310"}
0005435229605	96FF96	2451 630702	TATYANA PAVLOVA	{"phone": "+70508159626"}
0005435229606	1C760D	1466 281332	OLGA NOVIKOVA	{"phone": "+70618109023"}
0005435229607	55DB88	2952 677842	DINARA KUZNECOVA	{"phone": "+70000682968"}
0005435229608	F8CD4D	9949 527283	NINA NESTEROVA	{"email": "n.nesterova-24121987@postgrespro.ru", "phone": "+70289559004"}
0005435229609	BC2EF8	5853 621909	EVGENIY SIDOROV	{"phone": "+70204251794"}
0005435229610	FDCD95	4902 338832	SERGEY MAKSIMOV	{"email": "s.maksimov.121979@postgrespro.ru", "phone": "+70912334514"}
0005435229611	96FF64	0598 514462	TATYANA NIKOLAEVA	{"email": "nikolaeva-tatyana1977@postgrespro.ru", "phone": "+70573768893"}
0005435229612	96FF64	7435 759012	VYACHESLAV SIDOROV	{"email": "vyacheslav.sidorov-1983@postgrespro.ru", "phone": "+70262248767"}
0005435229613	C8A177	6640 170747	NATALYA VLASOVA	{"email": "vlasovan111978@postgrespro.ru", "phone": "+70113508293"}
0005435229614	1DE058	2192 857397	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_101962@postgrespro.ru", "phone": "+70111691523"}
0005435229615	01B7E8	0191 293688	TATYANA ZAKHAROVA	{"email": "zakharova-t22081967@postgrespro.ru", "phone": "+70425983538"}
0005435229616	01B7E8	7279 895945	NATALYA ANDREEVA	{"email": "andreevanatalya.1972@postgrespro.ru", "phone": "+70541682075"}
0005435229617	3B2C15	9604 238621	IGOR SMIRNOV	{"phone": "+70520841010"}
0005435229618	6A88B5	1024 307924	DMITRIY KUZNECOV	{"phone": "+70571622542"}
0005435229619	6A88B5	9770 154623	EDUARD DENISOV	{"phone": "+70072760158"}
0005435229620	C83683	8048 122421	ANNA KUZMINA	{"phone": "+70160391040"}
0005435229621	23A3E6	2648 436694	NINA ANISIMOVA	{"phone": "+70330467115"}
0005435229622	18FBB2	5053 110654	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev-041977@postgrespro.ru", "phone": "+70130032282"}
0005435229623	7FD250	1978 361916	VLADIMIR ANDREEV	{"email": "vandreev.07011971@postgrespro.ru", "phone": "+70251477940"}
0005435229624	DBC7F6	5345 035394	VYACHESLAV YAKOVLEV	{"email": "yakovlev.v_09091980@postgrespro.ru", "phone": "+70878092619"}
0005435229625	DBC7F6	9808 647713	ELENA KOROLEVA	{"email": "e_koroleva_03101972@postgrespro.ru", "phone": "+70721303580"}
0005435229626	DBC7F6	6615 141258	TATYANA MATVEEVA	{"email": "matveeva_tatyana051976@postgrespro.ru", "phone": "+70189085844"}
0005435229627	4C18FB	1065 594754	ALEKSANDR TARASOV	{"phone": "+70578990166"}
0005435229628	4C18FB	4457 416212	TATYANA TITOVA	{"email": "tatyana_titova.071974@postgrespro.ru", "phone": "+70106162658"}
0005435242420	92A084	6803 505227	EKATERINA RODIONOVA	{"phone": "+70508947767"}
0005435229629	4C18FB	9220 131354	VLADIMIR FOMIN	{"email": "fomin-vladimir-021979@postgrespro.ru", "phone": "+70287387849"}
0005435229630	4C18FB	1302 802257	SVETLANA YAKOVLEVA	{"email": "svetlanayakovleva_19021965@postgrespro.ru", "phone": "+70358012962"}
0005435229631	37BAE3	7823 261397	ALINA LOGINOVA	{"email": "alinaloginova_1991@postgrespro.ru", "phone": "+70334172844"}
0005435229632	37BAE3	9037 170089	ALEKSANDR RODIONOV	{"email": "rodionov-a-1978@postgrespro.ru", "phone": "+70032518909"}
0005435229633	F30F38	3425 596692	VALERIY ALEKSANDROV	{"email": "v-aleksandrov.19061973@postgrespro.ru", "phone": "+70041606374"}
0005435229634	F30F38	6263 608864	DARYA FILIPPOVA	{"phone": "+70551573560"}
0005435229635	2BA818	5510 348288	ANNA NIKOLAEVA	{"phone": "+70718718540"}
0005435229636	2BA818	8445 806426	TATYANA IVANOVA	{"email": "t.ivanova_1977@postgrespro.ru", "phone": "+70068848446"}
0005435229637	2DCE1A	9396 865220	TAMARA KUZMINA	{"email": "kuzminatamara-1966@postgrespro.ru", "phone": "+70647687999"}
0005435229638	FCBCF7	7916 165001	OLGA PETROVA	{"email": "petrova_olga1983@postgrespro.ru", "phone": "+70328995705"}
0005435229639	FCBCF7	3388 933312	VALENTINA SMIRNOVA	{"phone": "+70754883672"}
0005435229640	627D2B	0994 418701	DMITRIY GERASIMOV	{"email": "gerasimov-dmitriy.21011974@postgrespro.ru", "phone": "+70629176177"}
0005435229641	627D2B	0922 234641	SERGEY KAZAKOV	{"email": "sergeykazakov-01071968@postgrespro.ru", "phone": "+70472816763"}
0005435229642	8D3019	1350 440752	ANNA KUZMINA	{"email": "a-kuzmina.28081970@postgrespro.ru", "phone": "+70356311736"}
0005435229643	8D3019	1295 409878	SERGEY VASILEV	{"email": "sergey-vasilev1973@postgrespro.ru", "phone": "+70313161315"}
0005435229650	0AC253	7045 063531	ELENA MATVEEVA	{"phone": "+70034462967"}
0005435229651	9FBACA	4448 534725	EVGENIY POPOV	{"phone": "+70249672142"}
0005435229652	761BD9	7738 908335	ELENA OVCHINNIKOVA	{"email": "ovchinnikova_elena06061982@postgrespro.ru", "phone": "+70721248123"}
0005435229653	761BD9	7223 106843	SVETLANA CHERNOVA	{"phone": "+70202155048"}
0005435229654	48F6F5	9325 680487	DANILA PETROV	{"email": "d.petrov.1969@postgrespro.ru", "phone": "+70667853429"}
0005435229655	48F6F5	8953 766791	SERGEY GERASIMOV	{"email": "gerasimov_s.1971@postgrespro.ru", "phone": "+70199676134"}
0005435229656	91BF1A	4651 354347	ELZA FILIPPOVA	{"email": "elzafilippova-1972@postgrespro.ru", "phone": "+70946934868"}
0005435229657	A8B222	0930 766878	VIKTOR ILIN	{"phone": "+70593893158"}
0005435229658	010885	2145 245301	SVETLANA ROMANOVA	{"phone": "+70979322227"}
0005435229659	010885	2166 197755	KONSTANTIN NOVIKOV	{"email": "konstantin.novikov-28081971@postgrespro.ru", "phone": "+70133837603"}
0005435242387	19077F	6949 618483	ANASTASIYA ZHURAVLEVA	{"email": "zhuravleva-a_03111954@postgrespro.ru", "phone": "+70324732394"}
0005435242388	11E52A	9391 022078	ZARINA KISELEVA	{"phone": "+70828365799"}
0005435242389	F81CC4	9214 514847	FEDOR SOROKIN	{"phone": "+70275370924"}
0005435242390	F81CC4	5702 788278	OLGA NIKITINA	{"email": "nikitinao.1965@postgrespro.ru", "phone": "+70355799229"}
0005435242391	4C0355	9351 551433	LEONID MOROZOV	{"email": "morozov-leonid09011959@postgrespro.ru", "phone": "+70613610480"}
0005435242392	4C0355	1826 806340	IGOR NIKITIN	{"phone": "+70236694261"}
0005435242393	112B60	3085 904335	SVETLANA FROLOVA	{"email": "frolova-s1972@postgrespro.ru", "phone": "+70138056044"}
0005435242394	D08BD2	8208 117919	ARTEM SOROKIN	{"phone": "+70518002714"}
0005435242395	073931	4400 648518	ALEKSANDR ANDREEV	{"email": "aleksandrandreev011970@postgrespro.ru", "phone": "+70923279396"}
0005435242396	A27BE2	7617 086898	ALEKSANDR ORLOV	{"email": "orlov_aleksandr13091968@postgrespro.ru", "phone": "+70328510809"}
0005435242397	A27BE2	8549 197826	NATALYA NAZAROVA	{"phone": "+70756990535"}
0005435242398	E8F459	9811 214374	IRINA ZAYCEVA	{"email": "i_zayceva-111971@postgrespro.ru", "phone": "+70285588922"}
0005435242399	D2DFCA	7700 972563	LYUBOV MARTYNOVA	{"email": "lyubovmartynova.26061969@postgrespro.ru", "phone": "+70952868958"}
0005435242400	F719F3	7023 937050	ANASTASIYA LUKYANOVA	{"email": "anastasiya.lukyanova23021970@postgrespro.ru", "phone": "+70956955749"}
0005435242401	F719F3	2393 734159	KRISTINA ZHUKOVA	{"email": "zhukova-k.051971@postgrespro.ru", "phone": "+70679078065"}
0005435242402	4E6495	8811 172252	SVETLANA STEPANOVA	{"phone": "+70166241290"}
0005435242403	BD728D	1008 741497	EKATERINA KUZNECOVA	{"email": "kuznecovaekaterina1971@postgrespro.ru", "phone": "+70478701152"}
0005435242404	452732	3601 343382	VALERIY DMITRIEV	{"email": "dmitriev-v_28011972@postgrespro.ru", "phone": "+70113951133"}
0005435242405	D0FE78	1865 262024	NIKOLAY NAZAROV	{"email": "nazarov-nikolay_08021975@postgrespro.ru", "phone": "+70727586903"}
0005435242406	DAC030	4277 190512	ALEKSANDR BARANOV	{"email": "a_baranov_1970@postgrespro.ru", "phone": "+70083054585"}
0005435242407	DAC030	7228 336517	MIKHAIL IVANOV	{"phone": "+70141798867"}
0005435242408	8BC742	5884 975562	YURIY FEDOROV	{"phone": "+70280228432"}
0005435242409	8BC742	1712 852763	ZOYA RODIONOVA	{"email": "rodionovaz09071973@postgrespro.ru", "phone": "+70600342763"}
0005435242410	8BC742	6008 523528	GALINA AKIMOVA	{"email": "gakimova_021975@postgrespro.ru", "phone": "+70541297021"}
0005435242411	7F31B2	6190 263852	SERGEY ROMANOV	{"phone": "+70094735464"}
0005435242412	90C3F7	5403 812181	GENNADIY KOZLOV	{"phone": "+70711339945"}
0005435242413	8B07B3	6923 127882	ARTEM PETROV	{"email": "artem_petrov-13011960@postgrespro.ru", "phone": "+70504610103"}
0005435242414	8B07B3	8522 173679	TATYANA NIKITINA	{"email": "nikitina_tatyana-111965@postgrespro.ru", "phone": "+70382251429"}
0005435242415	8B07B3	5090 623881	DARYA YUDINA	{"phone": "+70937572375"}
0005435242416	1CB8A5	8499 248994	EVGENIY YAKOVLEV	{"email": "evgeniyyakovlev_1980@postgrespro.ru", "phone": "+70198788008"}
0005435242417	A91796	9995 440326	GRIGORIY FOMIN	{"phone": "+70384331786"}
0005435242418	983214	1005 933590	LYUDMILA IVANOVA	{"phone": "+70323379148"}
0005435242419	92A084	0068 657387	VALERIY DAVYDOV	{"phone": "+70599141091"}
0005435242421	92A084	4472 803193	SERGEY ZHUKOV	{"phone": "+70701389338"}
0005435242422	20098F	6303 575937	VERONIKA KUZMINA	{"phone": "+70566706391"}
0005435242423	20098F	7919 419591	OKSANA PETROVA	{"email": "petrova_o22041969@postgrespro.ru", "phone": "+70737510598"}
0005435242424	963EDB	6746 004284	VALERIY FILIPPOV	{"email": "filippov.valeriy121980@postgrespro.ru", "phone": "+70806886536"}
0005435242425	34DAE8	9469 229087	DENIS SAVELEV	{"phone": "+70439958919"}
0005435242426	5B6B90	7269 533769	ZARINA MARTYNOVA	{"phone": "+70799307720"}
0005435242427	3F1AAF	9193 187747	VLADIMIR TIKHONOV	{"phone": "+70751323537"}
0005435242428	33F545	4502 630925	VIKTORIYA RODIONOVA	{"email": "rodionova_viktoriya.061980@postgrespro.ru", "phone": "+70276204224"}
0005435242429	27ED54	4261 488677	VIKTOR SMIRNOV	{"email": "smirnov_v-07121980@postgrespro.ru", "phone": "+70358420660"}
0005435242430	27ED54	6006 743633	EKATERINA IVANOVA	{"phone": "+70297590903"}
0005435242431	27ED54	2893 374054	ALIYA SOKOLOVA	{"email": "aliya.sokolova1983@postgrespro.ru", "phone": "+70751976343"}
0005435242432	27ED54	0503 326365	DMITRIY SERGEEV	{"phone": "+70346541159"}
0005435242433	A2634D	1697 590963	ELENA TIKHONOVA	{"phone": "+70394968491"}
0005435242490	489517	1940 701107	ALEKSANDR MAKAROV	{"phone": "+70350505709"}
0005435242434	B3A64F	1175 145599	VASILIY PAVLOV	{"email": "pavlov.v_21121966@postgrespro.ru", "phone": "+70144932439"}
0005435242435	2B8E12	8698 665822	LYUDMILA STEPANOVA	{"phone": "+70312550446"}
0005435242436	2B8E12	9347 186032	MIKHAIL STEPANOV	{"phone": "+70439939802"}
0005435242437	87B7CC	1891 078237	SERGEY MELNIKOV	{"email": "melnikov-s-08121972@postgrespro.ru", "phone": "+70111173786"}
0005435242438	84E031	6812 315169	OLEG FEDOROV	{"email": "olegfedorov-1968@postgrespro.ru", "phone": "+70666099289"}
0005435242439	E0A8CE	0110 925708	INNA MAKAROVA	{"phone": "+70731996325"}
0005435242440	667CAC	7738 744564	ALEKSEY PAVLOV	{"phone": "+70231880780"}
0005435242441	B15570	4762 241699	VERONIKA FROLOVA	{"email": "v_frolova_08051983@postgrespro.ru", "phone": "+70184084582"}
0005435242442	B15570	5163 097600	DMITRIY FILIPPOV	{"phone": "+70125396771"}
0005435242443	27C9E7	4836 101289	MARGARITA OVCHINNIKOVA	{"phone": "+70975037272"}
0005435242444	345B5B	0945 359482	ALEKSEY ZAYCEV	{"email": "zaycev_a_1977@postgrespro.ru", "phone": "+70660985578"}
0005435242445	345B5B	1407 813253	ALIYA NIKOLAEVA	{"email": "nikolaevaa_15041971@postgrespro.ru", "phone": "+70353778932"}
0005435242446	B46A74	6911 802389	LYUDMILA SOROKINA	{"email": "l.sorokina.121987@postgrespro.ru", "phone": "+70702234384"}
0005435242447	A42BF8	6045 801310	VLADISLAV GRIGOREV	{"phone": "+70665270914"}
0005435242448	641EBC	6196 192909	VERONIKA KUZMINA	{"email": "v_kuzmina.071967@postgrespro.ru", "phone": "+70016499335"}
0005435242449	FECF43	2074 230117	LYUDMILA ERMAKOVA	{"email": "lyudmila_ermakova_1980@postgrespro.ru", "phone": "+70386287110"}
0005435242450	6F6645	8584 039664	VLADIMIR KISELEV	{"email": "kiselev_v_1970@postgrespro.ru", "phone": "+70418092233"}
0005435242451	9F76CC	4654 491914	LYUDMILA ZHURAVLEVA	{"email": "zhuravleva-lyudmila-1964@postgrespro.ru", "phone": "+70697571262"}
0005435242452	74B433	2150 088798	LYUDMILA NESTEROVA	{"email": "l_nesterova_10071967@postgrespro.ru", "phone": "+70084254927"}
0005435242453	74B433	4539 152155	MARIYA BORISOVA	{"email": "m_borisova.021980@postgrespro.ru", "phone": "+70682688225"}
0005435242454	3BBF8E	2260 702321	MARINA SEMENOVA	{"phone": "+70484264859"}
0005435242455	7E54AA	9385 556005	ALEKSEY EGOROV	{"phone": "+70102250534"}
0005435242456	A905A8	9031 408725	SOFYA GUSEVA	{"email": "sguseva_14111986@postgrespro.ru", "phone": "+70837343422"}
0005435242457	A905A8	1304 259651	OLGA KUZNECOVA	{"phone": "+70755890000"}
0005435242458	51D298	1630 398147	SERGEY POPOV	{"phone": "+70324956455"}
0005435242459	4A24B2	1082 771227	NINA FEDOROVA	{"phone": "+70929207205"}
0005435242460	B389BF	8730 042691	PETR GORBUNOV	{"email": "pgorbunov-021969@postgrespro.ru", "phone": "+70919092580"}
0005435242461	B389BF	6590 224593	GALINA KRASNOVA	{"phone": "+70901743624"}
0005435242462	C83413	3388 199533	ANATOLIY KUZNECOV	{"phone": "+70243235793"}
0005435242463	C83413	1190 091508	EKATERINA TIMOFEEVA	{"email": "ekaterina.timofeeva101970@postgrespro.ru", "phone": "+70556719593"}
0005435242464	708C4A	5474 527397	EKATERINA GUSEVA	{"email": "eguseva.051962@postgrespro.ru", "phone": "+70977943107"}
0005435242465	A0F89E	6014 360676	YULIYA POPOVA	{"phone": "+70249501708"}
0005435242466	7FA34B	7228 133058	VLADIMIR AFANASEV	{"email": "v.afanasev-031967@postgrespro.ru", "phone": "+70730840285"}
0005435242467	7FA34B	6325 325782	OLEG VOROBEV	{"email": "ovorobev-1983@postgrespro.ru", "phone": "+70394210058"}
0005435242468	CE881B	0432 237934	ELENA KUZNECOVA	{"email": "e-kuznecova_021973@postgrespro.ru", "phone": "+70516355396"}
0005435242469	A06259	7946 582496	ANDREY DAVYDOV	{"phone": "+70949602230"}
0005435242470	FFF09A	0006 408195	EKATERINA KOZLOVA	{"phone": "+70118085263"}
0005435242471	67BC8D	7830 387337	MARGARITA ANISIMOVA	{"phone": "+70915585679"}
0005435242472	67BC8D	6290 969994	ILYA MOISEEV	{"phone": "+70689910962"}
0005435242473	5C8906	7093 442908	ANDREY MAKSIMOV	{"email": "maksimova_071976@postgrespro.ru", "phone": "+70735845687"}
0005435242474	5C8906	1940 335443	NADEZHDA AKIMOVA	{"phone": "+70612554478"}
0005435242475	628287	1726 820417	OLGA IVANOVA	{"phone": "+70896638860"}
0005435242476	628287	7846 924582	ROMAN KUDRYASHOV	{"email": "kudryashov.roman-1978@postgrespro.ru", "phone": "+70378158013"}
0005435242477	37FCCC	0964 157099	GALINA EFIMOVA	{"phone": "+70718518109"}
0005435242478	5FA48E	4268 465414	DARYA VASILEVA	{"email": "vasilevadarya-12031977@postgrespro.ru", "phone": "+70637324025"}
0005435242479	578BA8	7618 609864	IRINA KONDRATEVA	{"phone": "+70340778991"}
0005435242480	D0D196	5295 647697	ALEKSANDR CHERNOV	{"phone": "+70260211376"}
0005435242481	D0D196	5884 659087	OLGA SMIRNOVA	{"phone": "+70922530985"}
0005435242482	E3879F	7387 138120	SVETLANA SERGEEVA	{"email": "ssergeeva-25041984@postgrespro.ru", "phone": "+70370439433"}
0005435242483	EF2E7A	1596 225177	ALEKSANDR PETROV	{"phone": "+70213868375"}
0005435242484	40FBEA	8120 286777	EKATERINA NIKOLAEVA	{"email": "nikolaevaekaterina.121988@postgrespro.ru", "phone": "+70938495657"}
0005435242485	40FBEA	8393 623777	GENNADIY NIKITIN	{"email": "nikitin.g-1978@postgrespro.ru", "phone": "+70696801519"}
0005435242486	579095	1274 838907	VALENTINA MEDVEDEVA	{"phone": "+70026636430"}
0005435242487	579095	1627 192761	VASILIY ZAYCEV	{"email": "v_zaycev.101976@postgrespro.ru", "phone": "+70415065895"}
0005435242488	7E7035	9898 620730	ALINA MOISEEVA	{"email": "alina-moiseeva_30071967@postgrespro.ru", "phone": "+70403995001"}
0005435242489	489517	8379 484391	MAKSIM FILIPPOV	{"phone": "+70327744812"}
0005435242491	6E8A16	3752 510324	ANATOLIY ANDREEV	{"email": "anatoliyandreev-061969@postgrespro.ru", "phone": "+70716577491"}
0005435242492	6E8A16	8304 586999	LYUBOV PAVLOVA	{"email": "pavlova.lyubov-1972@postgrespro.ru", "phone": "+70722086865"}
0005435242493	46028B	8702 281994	BORIS KAZAKOV	{"phone": "+70224769618"}
0005435242494	D3F188	1464 446426	VLADIMIR VASILEV	{"phone": "+70981345958"}
0005435242495	D3F188	5358 534695	SERGEY NIKOLAEV	{"email": "nikolaev.sergey121977@postgrespro.ru", "phone": "+70267143729"}
0005435242496	D3B3F4	2029 824865	IRINA SEMENOVA	{"email": "irina-semenova.011972@postgrespro.ru", "phone": "+70827806715"}
0005435242497	402B0B	7557 710149	OLGA LOGINOVA	{"email": "loginova_o_091985@postgrespro.ru", "phone": "+70171208610"}
0005435242498	65E2D0	1750 236146	SOFIYA GUSEVA	{"phone": "+70038882823"}
0005435242499	13F243	7080 189564	MAKSIM SOROKIN	{"phone": "+70775097302"}
0005435242500	F54125	5013 703723	EKATERINA OVCHINNIKOVA	{"phone": "+70130389147"}
0005435242501	F54125	7201 942056	ALINA DAVYDOVA	{"email": "a.davydova-1967@postgrespro.ru", "phone": "+70223060690"}
0005435242502	57940F	8593 516733	VLADIMIR VOLKOV	{"phone": "+70478579646"}
0005435242503	0D133C	3806 511255	SERGEY GAVRILOV	{"phone": "+70021821702"}
0005435242504	0D133C	7614 044127	SVETLANA RODIONOVA	{"email": "rodionova-s.1970@postgrespro.ru", "phone": "+70810553187"}
0005435242505	980FF8	1483 714196	YURIY KRASNOV	{"phone": "+70460419313"}
0005435242506	DD5CE3	4735 058280	VLADIMIR KOZLOV	{"email": "kozlovvladimir-23091977@postgrespro.ru", "phone": "+70810946910"}
0005435242507	DD5CE3	2496 148434	NIKOLAY SOROKIN	{"email": "n-sorokin-1961@postgrespro.ru", "phone": "+70197709732"}
0005435242508	7E76B3	8714 677227	ELENA VOLKOVA	{"phone": "+70207398103"}
0005435242509	7E76B3	2850 183892	ALEKSEY BORISOV	{"phone": "+70421488185"}
0005435242510	610453	1420 099374	ARSENIY ZAYCEV	{"phone": "+70825971973"}
0005435242511	610453	1146 985471	ELENA KONOVALOVA	{"email": "konovalova-e_22071972@postgrespro.ru", "phone": "+70110950318"}
0005435242512	163EA8	5173 044493	ALEKSANDR VLASOV	{"phone": "+70457178267"}
0005435242513	47A292	5490 786669	NIKOLAY BORISOV	{"email": "nikolayborisov1966@postgrespro.ru", "phone": "+70419949199"}
0005435242514	5CBE38	9632 434459	LYUBOV NIKIFOROVA	{"email": "nikiforovalyubov-021969@postgrespro.ru", "phone": "+70290032699"}
0005435242515	8C0949	4480 393223	MARINA ILINA	{"phone": "+70847498636"}
0005435242516	2AD3FC	8483 596754	IRINA FILIPPOVA	{"phone": "+70255109351"}
0005435242517	87D02A	2151 764059	PAVEL VASILEV	{"phone": "+70962788380"}
0005435242518	A77E32	2221 740070	VERA STEPANOVA	{"phone": "+70708396551"}
0005435242519	2A3145	9267 020705	VALERIY SOLOVEV	{"phone": "+70122523614"}
0005435242520	E7485A	9091 515213	VERA FEDOROVA	{"phone": "+70302724853"}
0005435242521	2F9018	2112 141053	SVETLANA KISELEVA	{"phone": "+70913868080"}
0005435242522	A2F24E	6512 289338	ELLA KULIKOVA	{"phone": "+70361446111"}
0005435242523	A2F24E	6404 054266	VITALIY MIRONOV	{"phone": "+70145328713"}
0005435242524	A2F24E	4995 699399	ELENA POTAPOVA	{"phone": "+70488495747"}
0005435242525	4409BA	0313 063024	MARIYA YAKOVLEVA	{"phone": "+70836630280"}
0005435242526	4409BA	7722 248687	MAKSIM BORISOV	{"email": "borisov.m.1967@postgrespro.ru", "phone": "+70762789488"}
0005435242527	C6EF4B	7538 210329	ANNA TIMOFEEVA	{"phone": "+70695836407"}
0005435242528	0DC098	6489 716714	NADEZHDA KAZAKOVA	{"phone": "+70071191370"}
0005435242529	B69507	6740 994050	GRIGORIY VOLKOV	{"phone": "+70873525133"}
0005435242530	EDBC89	2303 004831	ALENA MIKHAYLOVA	{"phone": "+70258469721"}
0005435242531	8507FB	9886 366026	LILIYA VASILEVA	{"email": "liliyavasileva.081977@postgrespro.ru", "phone": "+70711937007"}
0005435242532	6B5DE9	1897 454542	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova_natalya_021975@postgrespro.ru", "phone": "+70355979288"}
0005435242533	0B6FC9	0254 990153	TATYANA EGOROVA	{"phone": "+70006713544"}
0005435242534	A337B3	2248 797277	YURIY DENISOV	{"email": "denisov.yuriy15011972@postgrespro.ru", "phone": "+70725745529"}
0005435242535	3D88B5	9370 452599	DMITRIY KUZNECOV	{"email": "dmitriy.kuznecov_041971@postgrespro.ru", "phone": "+70784326892"}
0005435242536	732711	5452 176261	PETR NIKOLAEV	{"email": "petr_nikolaev17041962@postgrespro.ru", "phone": "+70243796746"}
0005435242537	F4C9FD	2792 332920	NATALYA ZAKHAROVA	{"phone": "+70395561418"}
0005435242538	F4C9FD	0040 403503	ALEKSEY VASILEV	{"email": "a-vasilev-15081981@postgrespro.ru", "phone": "+70653692455"}
0005435242539	DF0CF9	0850 928600	ASKHAT KRASNOV	{"phone": "+70084697594"}
0005435242540	7B2C4D	0766 092227	IRINA KUZNECOVA	{"email": "kuznecova-i.1976@postgrespro.ru", "phone": "+70451486773"}
0005435242541	F1E58D	9817 572147	ANDREY IVANOV	{"email": "ivanov-andrey_071971@postgrespro.ru", "phone": "+70264173889"}
0005435242542	F1E58D	0665 946262	ANDREY IVANOV	{"phone": "+70096577532"}
0005435242543	58090F	6154 726728	ALEKSANDR IVANOV	{"email": "a_ivanov_1983@postgrespro.ru", "phone": "+70820656769"}
0005435242544	D05924	8538 464887	TATYANA FOMINA	{"email": "fomina_t-03081968@postgrespro.ru", "phone": "+70516274196"}
0005435242545	0D8E28	7404 284014	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov.031974@postgrespro.ru", "phone": "+70667903547"}
0005435242546	0D8E28	6334 654262	TAMARA EFREMOVA	{"phone": "+70808011979"}
0005435242547	3227B7	0861 009171	ALEKSEY DAVYDOV	{"email": "davydova-10081968@postgrespro.ru", "phone": "+70331580033"}
0005435242548	3227B7	3537 737103	ALEKSANDR FILIPPOV	{"phone": "+70270011721"}
0005435242549	21D622	6742 181191	TATYANA MARTYNOVA	{"email": "martynova_tatyana12031972@postgrespro.ru", "phone": "+70358351332"}
0005435242550	FDBD51	2881 999697	VALENTINA KULIKOVA	{"phone": "+70161630415"}
0005435242551	B7244B	5491 471693	TATYANA KOMAROVA	{"email": "tatyana.komarova_1966@postgrespro.ru", "phone": "+70383410439"}
0005435242552	6DF259	5025 254477	IVAN NIKITIN	{"phone": "+70052365981"}
0005435242553	6DF259	7991 706448	LARISA NIKOLAEVA	{"phone": "+70693302607"}
0005435242554	03ECA3	4117 017464	NINA IVANOVA	{"email": "ivanova_nina.10081969@postgrespro.ru", "phone": "+70016438513"}
0005435242555	EFCF3B	0777 686488	ALEKSANDR PETROV	{"phone": "+70261119322"}
0005435242556	9084B8	3433 575163	ALEKSEY BARANOV	{"email": "baranov_a-05041963@postgrespro.ru", "phone": "+70388349765"}
0005435242557	F2D935	0974 581570	DIANA POTAPOVA	{"phone": "+70730874712"}
0005435242558	60132A	6529 003315	VIKTOR KUZNECOV	{"email": "kuznecov_v_1989@postgrespro.ru", "phone": "+70911945494"}
0005435242559	2DB373	1407 181012	LYUBOV MASLOVA	{"phone": "+70064939426"}
0005435242560	E44000	3257 193502	VYACHESLAV KONOVALOV	{"email": "konovalov.vyacheslav_21071981@postgrespro.ru", "phone": "+70654711274"}
0005435242561	E44000	1737 833674	SVYATOSLAV TIMOFEEV	{"phone": "+70655157310"}
0005435242562	E44000	7010 410070	ALEKSEY DAVYDOV	{"email": "aleksey-davydov.071973@postgrespro.ru", "phone": "+70211667947"}
0005435242563	582B12	7375 573650	ARTEM VOLKOV	{"email": "avolkov.28071970@postgrespro.ru", "phone": "+70548204183"}
0005435242564	5F82FF	4019 333516	ELIZAVETA DAVYDOVA	{"email": "davydova_elizaveta-03071976@postgrespro.ru", "phone": "+70705158439"}
0005435242565	5F82FF	1780 260572	KLAVDIYA KRASNOVA	{"email": "klavdiya-krasnova_07091964@postgrespro.ru", "phone": "+70953803261"}
0005435242566	8D3788	8705 851279	ALEKSANDR KAZAKOV	{"email": "kazakovaleksandr.011977@postgrespro.ru", "phone": "+70445934386"}
0005435242567	B5BAD2	0718 381591	YURIY KUZMIN	{"email": "ykuzmin-1983@postgrespro.ru", "phone": "+70204458773"}
0005435242568	838DB4	7288 858115	PAVEL ZHURAVLEV	{"email": "zhuravlev-pavel.091973@postgrespro.ru", "phone": "+70507919461"}
0005435242569	838DB4	7115 899754	VYACHESLAV KUDRYASHOV	{"email": "v_kudryashov.1964@postgrespro.ru", "phone": "+70517462042"}
0005435242570	B1EF64	1610 724725	VLADIMIR MIRONOV	{"email": "vladimirmironov-23031971@postgrespro.ru", "phone": "+70993023447"}
0005435242571	C72EB0	6123 056844	ANASTASIYA KUZMINA	{"phone": "+70921221322"}
0005435242572	C72EB0	2955 820919	TATYANA ANTONOVA	{"email": "antonova.t101979@postgrespro.ru", "phone": "+70458264173"}
0005435242573	96C9C3	3784 829702	ALEKSEY MATVEEV	{"email": "amatveev-021972@postgrespro.ru", "phone": "+70651111949"}
0005435242574	73DAC3	8616 891374	VALENTINA NIKIFOROVA	{"phone": "+70591841218"}
0005435242575	67E859	8505 215452	YANA NAUMOVA	{"email": "yana_naumova.121971@postgrespro.ru", "phone": "+70038664584"}
0005435242576	67E859	2185 498668	ELENA DAVYDOVA	{"email": "elena.davydova091982@postgrespro.ru", "phone": "+70460076669"}
0005435242577	6EC1AC	3580 272795	LARISA MIRONOVA	{"phone": "+70422675330"}
0005435242578	56A1A4	8452 150026	LARISA KUZMINA	{"email": "kuzmina.l1964@postgrespro.ru", "phone": "+70763267057"}
0005435242579	21DBF4	7550 791665	LYUBOV KOROLEVA	{"phone": "+70513290215"}
0005435242580	2A5856	7212 388112	DMITRIY SOKOLOV	{"phone": "+70314813962"}
0005435242581	2A5856	9133 518342	TAMARA GERASIMOVA	{"email": "tamara.gerasimova.07101969@postgrespro.ru", "phone": "+70276159769"}
0005435242582	7071F1	0853 506966	DMITRIY CHERNOV	{"phone": "+70024312591"}
0005435242583	7071F1	9518 580375	ALEKSANDRA STEPANOVA	{"email": "stepanova_a-1984@postgrespro.ru", "phone": "+70283061498"}
0005435242584	B30093	5655 838153	KSENIYA ABRAMOVA	{"phone": "+70032201678"}
0005435242585	8788E8	9714 260966	TATYANA BORISOVA	{"phone": "+70591275593"}
0005435242586	8788E8	5145 001456	SERGEY KOZLOV	{"phone": "+70489519558"}
0005435242587	AD07DF	8887 637887	ALEKSEY MOISEEV	{"email": "moiseevaleksey.031966@postgrespro.ru", "phone": "+70812641108"}
0005435242588	AD07DF	1798 413263	OLESYA IVANOVA	{"email": "oivanova25051972@postgrespro.ru", "phone": "+70423892285"}
0005435242589	640A02	6606 115195	ALEKSANDR FEDOTOV	{"email": "aleksandr_fedotov-14021986@postgrespro.ru", "phone": "+70808549769"}
0005435242590	EF48E1	2970 442897	ANATOLIY PETROV	{"email": "anatoliy-petrov1972@postgrespro.ru", "phone": "+70195674740"}
0005435242591	52DDD1	8261 144483	YULIYA IVANOVA	{"email": "ivanova.yuliya_13011960@postgrespro.ru", "phone": "+70481910954"}
0005435242592	B88EAA	5186 779356	VALERIY KUZNECOV	{"phone": "+70485674220"}
0005435242593	B88EAA	2813 037454	ELENA MAKAROVA	{"email": "makarova-e_28091979@postgrespro.ru", "phone": "+70063642661"}
0005435242594	A37893	9104 139392	OLGA BARANOVA	{"phone": "+70579495277"}
0005435242595	8565FC	7028 459808	NIKOLAY EGOROV	{"email": "egorovn1975@postgrespro.ru", "phone": "+70567228336"}
0005435242596	992B73	4153 855566	DMITRIY ANTONOV	{"email": "d-antonov_111963@postgrespro.ru", "phone": "+70428371013"}
0005435242597	264079	3722 629226	EKATERINA PETROVA	{"phone": "+70842007563"}
0005435242598	5BCDAF	1280 688886	MARINA NAUMOVA	{"phone": "+70093195262"}
0005435242599	8FF586	7378 748655	ALEKSANDR IVANOV	{"phone": "+70203253658"}
0005435242600	8FF586	1454 791043	IGOR KUZNECOV	{"email": "i-kuznecov_011981@postgrespro.ru", "phone": "+70411511003"}
0005435242601	F8C3E2	3409 202555	VERA TITOVA	{"phone": "+70464964800"}
0005435242602	58AF1F	8582 782186	ILMIR MOROZOV	{"phone": "+70634244118"}
0005435242603	19B1DB	4795 902743	ELENA KOZLOVA	{"phone": "+70352566062"}
0005435242604	BBBD36	2006 178307	MAKSIM MOROZOV	{"email": "morozov_maksim.081969@postgrespro.ru", "phone": "+70838133539"}
0005435242605	BBBD36	7522 443159	TATYANA SIDOROVA	{"email": "sidorova_tatyana_20061967@postgrespro.ru", "phone": "+70326159279"}
0005435242606	589D82	0418 010292	MARINA KARPOVA	{"phone": "+70801729645"}
0005435242607	AA34C6	3683 820013	NINA SOROKINA	{"phone": "+70715889957"}
0005435242608	AA34C6	3811 419997	IRINA ZAYCEVA	{"email": "zayceva-irina-1970@postgrespro.ru", "phone": "+70672215614"}
0005435242609	AA34C6	4600 822588	ANASTASIYA TROFIMOVA	{"email": "anastasiya-trofimova-021992@postgrespro.ru", "phone": "+70794532108"}
0005435242610	AA34C6	3535 491608	INNA KUZNECOVA	{"email": "kuznecovai_04041974@postgrespro.ru", "phone": "+70244655725"}
0005435242611	FEA0E3	6153 742152	VALENTINA KOZLOVA	{"phone": "+70811857901"}
0005435242612	FEA0E3	5932 034045	VIKTOR FILIPPOV	{"phone": "+70000032126"}
0005435242613	FDA2B5	3886 825630	SERGEY SEMENOV	{"email": "semenov-s_09101980@postgrespro.ru", "phone": "+70091678313"}
0005435242614	07A898	5404 360765	ALINA VLASOVA	{"phone": "+70692822067"}
0005435242615	07A898	6844 431451	YURIY OSIPOV	{"email": "y-osipov1978@postgrespro.ru", "phone": "+70879932202"}
0005435242616	A7B16D	4732 634209	YURIY KUZNECOV	{"phone": "+70170064631"}
0005435242617	D2CABE	0638 998506	VERA ROMANOVA	{"email": "romanova-vera_041986@postgrespro.ru", "phone": "+70201730480"}
0005435242618	BE0CCD	6579 093525	EVGENIY BELOV	{"phone": "+70193139049"}
0005435242619	BE0CCD	2358 369307	SEMEN POPOV	{"email": "popov-s-121975@postgrespro.ru", "phone": "+70948197885"}
0005435242620	9649CA	6189 676806	VLADIMIR KARPOV	{"email": "vladimir_karpov13071969@postgrespro.ru", "phone": "+70225977134"}
0005435242621	8E5261	2198 442131	NATALYA VLASOVA	{"phone": "+70869215856"}
0005435242622	8E5261	2310 782628	IRINA OSIPOVA	{"phone": "+70712889671"}
0005435242623	80368F	0709 445211	GALINA ABRAMOVA	{"email": "abramova.galina28011982@postgrespro.ru", "phone": "+70525008407"}
0005435242624	886779	4383 511679	ANTONINA KAZAKOVA	{"phone": "+70364303715"}
0005435242625	F0F075	5866 741709	ELENA IVANOVA	{"email": "ivanova-e_031973@postgrespro.ru", "phone": "+70400948727"}
0005435242626	7FB25E	7470 196367	ALEKSANDR GRIGOREV	{"email": "grigorev-aleksandr_071984@postgrespro.ru", "phone": "+70093809156"}
0005435242627	E2B20E	8117 368336	VIKTORIYA OVCHINNIKOVA	{"email": "v-ovchinnikova-061977@postgrespro.ru", "phone": "+70932734903"}
0005435242628	D43A20	6503 047629	MARIYA FILIPPOVA	{"phone": "+70753368620"}
0005435242629	4F5975	8595 791710	VALENTINA VASILEVA	{"email": "v.vasileva_28031972@postgrespro.ru", "phone": "+70663292737"}
0005435242630	AA53DD	0666 821697	SOFIYA BORISOVA	{"email": "sofiya_borisova_061970@postgrespro.ru", "phone": "+70444153859"}
0005435242631	AA53DD	4788 838879	ELENA NAUMOVA	{"email": "e_naumova.1971@postgrespro.ru", "phone": "+70975989186"}
0005435242632	AA53DD	8841 286005	VITALIY MELNIKOV	{"email": "melnikovvitaliy_1971@postgrespro.ru", "phone": "+70216727277"}
0005435242633	1C0353	4117 017959	NATALYA NIKOLAEVA	{"phone": "+70537851685"}
0005435242634	1C0353	2745 423677	ELENA VASILEVA	{"email": "e_vasileva_28111966@postgrespro.ru", "phone": "+70901404892"}
0005435242635	AFEDE7	9023 852952	DANIIL BONDARENKO	{"email": "bondarenko_d_25091985@postgrespro.ru", "phone": "+70446419673"}
0005435242636	ED8358	8957 128233	SERGEY GAVRILOV	{"email": "s-gavrilov-04071968@postgrespro.ru", "phone": "+70085805052"}
0005435242637	73676C	0184 604778	BORIS DAVYDOV	{"phone": "+70705421016"}
0005435242638	A5AB9F	8811 346440	YULIYA RYABOVA	{"email": "ryabova_yuliya_031974@postgrespro.ru", "phone": "+70629371128"}
0005435242639	BFF854	6883 084700	TAMARA KAZAKOVA	{"phone": "+70497596684"}
0005435242640	BFF854	1362 575119	NATALYA ANDREEVA	{"phone": "+70528480516"}
0005435242641	74B876	6196 817553	SERGEY MIKHAYLOV	{"phone": "+70252025722"}
0005435242642	EF822C	6272 672740	ELENA DENISOVA	{"phone": "+70815770232"}
0005435242643	A9F265	7211 623371	SERGEY MAKAROV	{"phone": "+70483293943"}
0005435242644	18CFD7	0935 512263	ALEKSANDR GUSEV	{"email": "a-gusev.071972@postgrespro.ru", "phone": "+70745704525"}
0005435242645	18CFD7	3645 856600	VADIM PETROV	{"email": "petrov-v-11091972@postgrespro.ru", "phone": "+70529981964"}
0005435242646	18CFD7	1306 428462	ULYANA NOVIKOVA	{"phone": "+70124299679"}
0005435242647	18CFD7	5331 322346	ANTON SMIRNOV	{"phone": "+70605245235"}
0005435242648	007477	3882 401849	ANASTASIYA NESTEROVA	{"email": "anastasiyanesterova-27091966@postgrespro.ru", "phone": "+70424887820"}
0005435242649	9B3769	8369 457494	LYUDMILA ROMANOVA	{"phone": "+70858533011"}
0005435242650	4AF7E6	6218 247223	TIMOFEY TARASOV	{"email": "tarasov.timofey-1976@postgrespro.ru", "phone": "+70053409256"}
0005435242651	4AF7E6	2763 280992	ILYA MARTYNOV	{"phone": "+70906371084"}
0005435242652	0555B5	6624 701907	IRINA ALEKSEEVA	{"email": "alekseeva_i_071973@postgrespro.ru", "phone": "+70360345344"}
0005435242653	BE1F1D	5308 916758	ANNA NOVIKOVA	{"phone": "+70275370782"}
0005435242654	BE1F1D	2599 892557	ALEKSANDR FOMIN	{"phone": "+70575367053"}
0005435242655	6D38A1	4144 333231	ANNA KUZNECOVA	{"phone": "+70874441972"}
0005435242656	18E269	6505 522637	SERAFIMA ZAKHAROVA	{"email": "serafimazakharova.1983@postgrespro.ru", "phone": "+70398432493"}
0005435242657	653180	4233 818918	OLEG ALEKSEEV	{"email": "o_alekseev.15031977@postgrespro.ru", "phone": "+70373003895"}
0005435242658	653180	0952 327632	VIKTOR GAVRILOV	{"email": "v.gavrilov.1968@postgrespro.ru", "phone": "+70679152412"}
0005435242659	D6DDA4	6514 344996	TATYANA KOROLEVA	{"phone": "+70923290567"}
0005435242660	D6DDA4	0533 363216	NIKITA ZAKHAROV	{"phone": "+70522360228"}
0005435242661	654203	2916 252310	ANATOLIY MIRONOV	{"phone": "+70101165784"}
0005435242662	BE03D5	6498 040091	VALENTINA GAVRILOVA	{"email": "gavrilova-v071970@postgrespro.ru", "phone": "+70386473274"}
0005435242663	EFB2E2	6843 087982	ANDREY GORBUNOV	{"phone": "+70722641966"}
0005435242664	416150	4534 310012	SERGEY ANDREEV	{"email": "sergeyandreev_1969@postgrespro.ru", "phone": "+70988698006"}
0005435242665	14E42E	0903 545544	IGOR ZHUKOV	{"phone": "+70861542445"}
0005435242666	01B980	7331 007468	VARVARA KOROLEVA	{"email": "v-koroleva061984@postgrespro.ru", "phone": "+70388594580"}
0005435242667	55508A	2952 573688	VALERIYA ZOTOVA	{"phone": "+70028233256"}
0005435242668	55508A	2506 053455	EKATERINA IVANOVA	{"email": "ivanova-ekaterina-19041976@postgrespro.ru", "phone": "+70038717790"}
0005435242669	DCF716	7278 015580	ALIYA KUZMINA	{"email": "aliya.kuzmina.041965@postgrespro.ru", "phone": "+70748630147"}
0005435242670	3C63A2	8930 759595	ELENA VLASOVA	{"phone": "+70328384056"}
0005435242671	3C63A2	3965 015689	ELINA MIKHAYLOVA	{"email": "elinamikhaylova-1966@postgrespro.ru", "phone": "+70157414446"}
0005435242672	D72BB0	1568 238372	ALEKSANDR BONDARENKO	{"email": "bondarenko-aleksandr-03031977@postgrespro.ru", "phone": "+70970118114"}
0005435242673	C527D0	3393 568756	VIKTOR MIKHAYLOV	{"email": "mikhaylov-viktor-071975@postgrespro.ru", "phone": "+70176487834"}
0005435242674	4C3C00	5381 773830	VIKTORIYA NAZAROVA	{"phone": "+70611756000"}
0005435242675	110A73	1274 817793	GENNADIY NOVIKOV	{"email": "novikov_gennadiy-05061968@postgrespro.ru", "phone": "+70296029170"}
0005435242676	110A73	5384 470960	GEORGIY IVANOV	{"phone": "+70975374942"}
0005435242677	984236	0813 306037	DMITRIY MAKAROV	{"email": "d-makarov23091962@postgrespro.ru", "phone": "+70330609908"}
0005435242678	B23405	4308 505352	VALENTINA SIDOROVA	{"phone": "+70961394560"}
0005435242679	B23405	0368 411849	ALEKSANDR KUZNECOV	{"email": "kuznecov.a20061973@postgrespro.ru", "phone": "+70490216810"}
0005435242680	F2EB39	8791 473328	SERGEY TARASOV	{"email": "starasov20111982@postgrespro.ru", "phone": "+70068227097"}
0005435242681	B8B996	2642 407987	IRINA SOLOVEVA	{"phone": "+70371471277"}
0005435242682	77F0CD	9061 002603	MARIYA VLASOVA	{"phone": "+70355374433"}
0005435242683	77F0CD	9813 442721	ELIZAVETA DENISOVA	{"phone": "+70756083540"}
0005435242684	256965	1461 268112	MAKSIM IVANOV	{"phone": "+70007191478"}
0005435242685	256965	2688 626566	KAPITALINA FROLOVA	{"email": "frolova.k041963@postgrespro.ru", "phone": "+70723614466"}
0005435242686	8FCC4D	3946 936547	ALEKSANDR MOISEEV	{"email": "a.moiseev.18081962@postgrespro.ru", "phone": "+70178823276"}
0005435242687	8FCC4D	6145 365721	ANNA SCHERBAKOVA	{"email": "scherbakova_anna-021970@postgrespro.ru", "phone": "+70092307682"}
0005435242688	8FCC4D	3125 619894	VITALIY POPOV	{"email": "vitaliy.popov111969@postgrespro.ru", "phone": "+70674561704"}
0005435242689	B8930A	9435 671844	ANTONINA KUZNECOVA	{"email": "a.kuznecova-27011978@postgrespro.ru", "phone": "+70650807423"}
0005435242690	105FFA	7675 771004	LEV KULIKOV	{"email": "kulikov_l-1968@postgrespro.ru", "phone": "+70457155863"}
0005435242691	B47DB4	9522 979378	IRINA VASILEVA	{"phone": "+70033050440"}
0005435242692	7798C7	8644 473385	ANNA EGOROVA	{"phone": "+70160720914"}
0005435242693	7798C7	0695 645512	ELENA KAZAKOVA	{"email": "kazakovae-1968@postgrespro.ru", "phone": "+70920793649"}
0005435242694	EDE711	8861 142719	VALERIY KAZAKOV	{"phone": "+70068848492"}
0005435242695	726377	0190 321558	MARIYA VOLKOVA	{"phone": "+70021588866"}
0005435242696	726377	6084 676572	EKATERINA MAKAROVA	{"phone": "+70592203158"}
0005435242697	5FE2E8	3197 587963	ALLA KRASNOVA	{"phone": "+70701587691"}
0005435242698	5FE2E8	0402 403395	VITALIY PETROV	{"email": "petrov-vitaliy_06121972@postgrespro.ru", "phone": "+70382466851"}
0005435242699	99B6C9	6030 719742	IGOR ALEKSEEV	{"phone": "+70366759350"}
0005435242700	99B6C9	3216 193290	LARISA AKIMOVA	{"phone": "+70318349646"}
0005435242701	D07549	6164 798493	KIRILL TIKHONOV	{"email": "tikhonov_kirill_04111985@postgrespro.ru", "phone": "+70459513186"}
0005435242702	D07549	0103 877785	ANASTASIYA SERGEEVA	{"phone": "+70863447820"}
0005435242703	D07549	6165 250509	NADEZHDA VOROBEVA	{"email": "vorobeva.n051973@postgrespro.ru", "phone": "+70629954137"}
0005435242704	C250D5	7810 335078	MARIYA KOROLEVA	{"email": "m.koroleva081967@postgrespro.ru", "phone": "+70680400995"}
0005435242705	61BC24	9401 695898	SERGEY IVANOV	{"phone": "+70980052475"}
0005435242706	722CC5	6637 907900	ANDREY KARPOV	{"email": "akarpov.121964@postgrespro.ru", "phone": "+70546460540"}
0005435242707	599191	7333 357554	MIKHAIL DAVYDOV	{"phone": "+70623376863"}
0005435242708	A78936	2437 134684	IRINA NIKIFOROVA	{"email": "nikiforova_i_021979@postgrespro.ru", "phone": "+70301701319"}
0005435242709	A78936	6926 604779	YULIYA ORLOVA	{"email": "orlova_yuliya111967@postgrespro.ru", "phone": "+70093955936"}
0005435242710	F05F10	0596 076204	TATYANA POPOVA	{"email": "popova.tatyana.121972@postgrespro.ru", "phone": "+70322112851"}
0005435242711	DB742E	2970 830642	YURIY KUZMIN	{"phone": "+70971721679"}
0005435242712	30D521	0480 706572	MARGARITA GORBUNOVA	{"email": "gorbunovamargarita-1976@postgrespro.ru", "phone": "+70540360013"}
0005435242713	30D521	6881 159718	ELENA GUSEVA	{"phone": "+70320808666"}
0005435242714	30D521	6594 614684	LIDIYA ALEKSEEVA	{"email": "lalekseeva-051962@postgrespro.ru", "phone": "+70903559748"}
0005435242715	EAE545	2325 469772	LYUDMILA BELOVA	{"email": "belovalyudmila-08041977@postgrespro.ru", "phone": "+70119876245"}
0005435242716	8EC65C	1996 412974	IRINA ZAKHAROVA	{"phone": "+70755648793"}
0005435242717	83D582	1474 930758	KIRILL MOROZOV	{"email": "kirillmorozov071977@postgrespro.ru", "phone": "+70584481619"}
0005435242718	1BDBD5	1693 386640	YULIYA KAZAKOVA	{"phone": "+70822165651"}
0005435242719	2CCBF1	9843 557022	DMITRIY DMITRIEV	{"email": "d_dmitriev.1971@postgrespro.ru", "phone": "+70103386398"}
0005435242720	2C9E2B	0672 481213	GALINA KOZLOVA	{"phone": "+70314677924"}
0005435242721	2C9E2B	2558 448822	IRINA ROMANOVA	{"email": "romanova_i.27101977@postgrespro.ru", "phone": "+70472348674"}
0005435242722	41323A	0222 851034	ALEKSEY NOVIKOV	{"phone": "+70780009220"}
0005435242723	0BFCA1	2215 730544	ALEKSANDR IVANOV	{"phone": "+70473937095"}
0005435242724	3333D3	8278 079630	ANNA IVANOVA	{"phone": "+70561932707"}
0005435242725	25815B	7049 597271	LIDIYA PAVLOVA	{"phone": "+70113406138"}
0005435242726	25815B	3314 969165	VIKTOR GAVRILOV	{"email": "v_gavrilov-1980@postgrespro.ru", "phone": "+70583600903"}
0005435242727	82ED19	5002 556961	ALEKSANDR FOMIN	{"phone": "+70700122218"}
0005435242728	4B1CA4	6859 573861	MARGARITA BOGDANOVA	{"email": "m_bogdanova_031972@postgrespro.ru", "phone": "+70329641168"}
0005435242729	122F4C	4480 712876	ELVIRA SIDOROVA	{"phone": "+70536934031"}
0005435242730	994E16	0985 516252	ANDREY SCHERBAKOV	{"email": "scherbakov-a021968@postgrespro.ru", "phone": "+70213122491"}
0005435242731	95A0BB	8867 957342	NINA SEMENOVA	{"email": "n.semenova.02031969@postgrespro.ru", "phone": "+70849630442"}
0005435242732	D3D493	7983 664172	ALEVTINA POPOVA	{"phone": "+70245669456"}
0005435242733	D3D493	4387 590762	RINAT IVANOV	{"phone": "+70783800724"}
0005435242734	1F0BA8	7989 871377	NADEZHDA POPOVA	{"phone": "+70671420446"}
0005435242735	1F0BA8	3209 402520	ANGELINA SMIRNOVA	{"phone": "+70603216059"}
0005435242736	EA5F32	7096 558715	SERGEY EGOROV	{"phone": "+70882818288"}
0005435242737	C0698F	4697 605520	NIKOLAY VOLKOV	{"email": "nikolay-volkov_18071980@postgrespro.ru", "phone": "+70007293315"}
0005435242738	C0698F	2190 782378	MIKHAIL EGOROV	{"email": "mikhail-egorov-1972@postgrespro.ru", "phone": "+70109460295"}
0005435242739	A9E8D0	0281 602551	ANASTASIYA LUKYANOVA	{"phone": "+70444856969"}
0005435242740	A9E8D0	8097 189343	MARIYA ZAYCEVA	{"phone": "+70513027646"}
0005435242741	0073C5	8585 612881	SERGEY ALEKSANDROV	{"email": "s-aleksandrov-061967@postgrespro.ru", "phone": "+70287524336"}
0005435242742	5FEA9D	9345 577539	VIKTOR KUZMIN	{"phone": "+70461640397"}
0005435242743	5FEA9D	5694 468172	MARINA ISAEVA	{"email": "isaeva-m_061980@postgrespro.ru", "phone": "+70789225336"}
0005435242744	0BD6A9	4899 658399	FATIMA GUSEVA	{"phone": "+70764951957"}
0005435242745	3176B1	9591 065417	ALEKSANDR FROLOV	{"email": "a-frolov1974@postgrespro.ru", "phone": "+70789614631"}
0005435242746	3176B1	7661 928640	OLEG SEMENOV	{"phone": "+70536883411"}
0005435242747	BFC702	7264 936169	TAMARA SOKOLOVA	{"email": "tamarasokolova.121962@postgrespro.ru", "phone": "+70234586148"}
0005435242748	EF36A4	9391 486193	VERA EGOROVA	{"phone": "+70702594317"}
0005435242749	EF36A4	3662 843899	NINA KUZNECOVA	{"email": "n.kuznecova_1966@postgrespro.ru", "phone": "+70737306839"}
0005435242750	2514ED	5632 407977	ANNA ZHUKOVA	{"phone": "+70589549922"}
0005435242751	AA223C	5197 111955	ANASTASIYA RYABOVA	{"phone": "+70166910826"}
0005435242752	BBF5AB	1477 361479	ALEKSANDRA ILINA	{"phone": "+70347262830"}
0005435242753	EB4098	5865 588896	ANDREY FROLOV	{"phone": "+70021717896"}
0005435242754	EB4098	5154 496944	ANATOLIY ZAKHAROV	{"email": "zakharova-23121972@postgrespro.ru", "phone": "+70975552400"}
0005435242755	A01A3D	7107 232531	SOFIYA BELOVA	{"email": "sofiyabelova1978@postgrespro.ru", "phone": "+70640872671"}
0005435242756	244A01	4388 236970	NADEZHDA ROMANOVA	{"email": "nadezhda_romanova.1985@postgrespro.ru", "phone": "+70093659283"}
0005435242757	B1E1D6	6314 775380	DANIL ALEKSEEV	{"phone": "+70066960194"}
0005435242758	B1E1D6	4777 700211	ANASTASIYA MEDVEDEVA	{"email": "medvedeva.a-24041975@postgrespro.ru", "phone": "+70273074352"}
0005435242759	F6DC2D	5765 889468	ALEKSANDR PETROV	{"phone": "+70250263509"}
0005435242760	786C18	8998 628643	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov_14051977@postgrespro.ru", "phone": "+70151876608"}
0005435242761	BC7106	0330 404880	LYUDMILA BARANOVA	{"email": "l_baranova30011968@postgrespro.ru", "phone": "+70690052738"}
0005435242762	BC7106	6621 612030	STANISLAV VOROBEV	{"phone": "+70872401114"}
0005435242763	630142	2554 201600	TATYANA DANILOVA	{"email": "danilova-tatyana_091983@postgrespro.ru", "phone": "+70799450640"}
0005435242764	10842B	6262 858933	IRINA SMIRNOVA	{"phone": "+70616383877"}
0005435242765	A8B93B	4076 555916	DENIS NIKITIN	{"email": "nikitin-denis_24071981@postgrespro.ru", "phone": "+70614804795"}
0005435242766	A8B93B	5653 613543	ANTONINA MASLOVA	{"phone": "+70437795266"}
0005435242767	22AABE	5964 045391	TATYANA BELYAEVA	{"email": "t.belyaeva_19101969@postgrespro.ru", "phone": "+70371797904"}
0005435242768	7E9F4E	5886 127237	ANDREY MOROZOV	{"email": "morozov.andrey_1962@postgrespro.ru", "phone": "+70051232353"}
0005435242769	7E9F4E	6475 097787	GALINA DMITRIEVA	{"phone": "+70500045743"}
0005435242770	A371ED	2173 842222	ALEKSANDR BORISOV	{"email": "borisov.a-08021980@postgrespro.ru", "phone": "+70145984941"}
0005435242827	8B893F	0967 815772	IGOR KULIKOV	{"phone": "+70607367450"}
0005435242771	683B95	9898 281787	ANNA KOROLEVA	{"email": "koroleva.anna091971@postgrespro.ru", "phone": "+70819310452"}
0005435242772	1319AD	2674 894058	VALENTINA STEPANOVA	{"phone": "+70678996815"}
0005435242773	1319AD	7198 537124	SVETLANA POPOVA	{"phone": "+70240419119"}
0005435242774	203080	5622 456522	ALBINA FEDOROVA	{"phone": "+70920636207"}
0005435242775	0A1C18	9469 794946	ANDREY MOISEEV	{"email": "a-moiseev-101965@postgrespro.ru", "phone": "+70522724550"}
0005435242776	B8D8B2	9992 511713	ANZHELA MIKHAYLOVA	{"phone": "+70011170400"}
0005435242777	B8D8B2	1864 216427	RAISA MAKAROVA	{"email": "makarova_raisa071967@postgrespro.ru", "phone": "+70357715512"}
0005435242778	642739	8419 120987	VIKTORIYA FROLOVA	{"phone": "+70665251891"}
0005435242779	642739	0885 116016	YURIY STEPANOV	{"phone": "+70861215451"}
0005435242780	EC4F35	5837 973125	MIKHAIL OSIPOV	{"phone": "+70430945525"}
0005435242781	75704D	0134 196177	EVGENIYA MAKAROVA	{"email": "makarovaevgeniya-26021972@postgrespro.ru", "phone": "+70630260385"}
0005435242782	D44FBC	0799 030678	MILENA IVANOVA	{"email": "ivanova_milena_061971@postgrespro.ru", "phone": "+70444566397"}
0005435242783	363C24	7945 215510	ANDREY POPOV	{"phone": "+70217143107"}
0005435242784	363C24	3162 326279	YULIYA KOZLOVA	{"email": "yuliyakozlova_1978@postgrespro.ru", "phone": "+70287269715"}
0005435242785	80830C	1736 649406	VERA ILINA	{"email": "verailina.061970@postgrespro.ru", "phone": "+70958404874"}
0005435242786	80830C	4240 500555	VIKTOR STEPANOV	{"phone": "+70298209597"}
0005435242787	80830C	2686 190068	VIKTOR YAKOVLEV	{"phone": "+70014711986"}
0005435242788	6BA2B9	5921 472440	VLADIMIR ISAEV	{"email": "v.isaev-05061965@postgrespro.ru", "phone": "+70054220306"}
0005435242789	86112B	8869 783440	OLGA SMIRNOVA	{"email": "osmirnova.1977@postgrespro.ru", "phone": "+70210914624"}
0005435242790	86112B	4653 033070	KSENIYA LOGINOVA	{"phone": "+70442339172"}
0005435242791	44022B	6490 592513	SVETLANA KULIKOVA	{"email": "kulikova_svetlana_1969@postgrespro.ru", "phone": "+70571574733"}
0005435242792	44022B	4408 656235	NATALYA NESTEROVA	{"phone": "+70389968174"}
0005435242793	CEC24E	5736 497940	TATYANA KOVALEVA	{"phone": "+70118789243"}
0005435242794	CEC24E	4780 887822	DMITRIY BORISOV	{"email": "borisov-dmitriy.24051970@postgrespro.ru", "phone": "+70770213789"}
0005435242795	E12EBD	6041 987549	ANNA TARASOVA	{"phone": "+70570206716"}
0005435242796	E12EBD	9759 923746	IRINA BARANOVA	{"phone": "+70903433773"}
0005435242797	150B7C	2373 211335	YURIY SHEVCHENKO	{"email": "shevchenko-y27101966@postgrespro.ru", "phone": "+70368763590"}
0005435242798	150B7C	0598 645685	TATYANA ALEKSEEVA	{"email": "tatyana-alekseeva-021966@postgrespro.ru", "phone": "+70365489842"}
0005435242799	C49C04	4474 082623	PAVEL SERGEEV	{"email": "p_sergeev061976@postgrespro.ru", "phone": "+70846444974"}
0005435242800	19BA66	9224 089235	TATYANA KONOVALOVA	{"email": "konovalova.t_041957@postgrespro.ru", "phone": "+70023186310"}
0005435242801	A0DCBB	6156 890471	DARYA BELOVA	{"phone": "+70037042941"}
0005435242802	458B5D	3149 811739	LILIYA KOROLEVA	{"email": "lkoroleva.061978@postgrespro.ru", "phone": "+70435387041"}
0005435242803	8B6DE5	7822 094279	ANDREY ORLOV	{"phone": "+70702785311"}
0005435242804	8B9130	4840 682161	ELENA TITOVA	{"phone": "+70664031341"}
0005435242805	8B9130	6663 290355	NATALIYA POPOVA	{"phone": "+70637940128"}
0005435242806	1DB5BE	1685 378986	KONSTANTIN PETROV	{"email": "petrov_k.1973@postgrespro.ru", "phone": "+70598502033"}
0005435242807	763A91	4161 619567	MARIYA ORLOVA	{"phone": "+70554222321"}
0005435242808	DEDD73	8402 270847	FANIYA DENISOVA	{"email": "denisova.f_121977@postgrespro.ru", "phone": "+70765628019"}
0005435242809	3D5A9A	1597 594593	ANDREY NOVIKOV	{"phone": "+70566697441"}
0005435242810	3D5A9A	0213 628067	SERGEY SEMENOV	{"phone": "+70252198238"}
0005435242811	3D5A9A	5350 065236	ANATOLIY BORISOV	{"email": "anatoliy-borisov1978@postgrespro.ru", "phone": "+70501347726"}
0005435242812	E16A55	6692 801339	MATVEY EGOROV	{"phone": "+70037308735"}
0005435242813	5D709C	4270 926401	RAZIYA POPOVA	{"email": "raziya_popova_19121961@postgrespro.ru", "phone": "+70796745304"}
0005435242814	5D709C	0843 918714	EDGAR FEDOTOV	{"email": "fedotov-e_011976@postgrespro.ru", "phone": "+70128858136"}
0005435242815	6F71FD	6475 299078	ANNA FROLOVA	{"phone": "+70089484776"}
0005435242816	0FA68E	0067 730872	NIKITA KUDRYASHOV	{"email": "kudryashov.nikita.071979@postgrespro.ru", "phone": "+70709822795"}
0005435242817	EA927A	3402 157478	EDGAR GAVRILOV	{"email": "gavrilov.e.17111962@postgrespro.ru", "phone": "+70207235895"}
0005435242818	149148	8330 354694	ANTON KUZNECOV	{"email": "anton-kuznecov03101962@postgrespro.ru", "phone": "+70532677218"}
0005435242819	149148	9735 840003	IRINA RODIONOVA	{"email": "rodionova-irina_071969@postgrespro.ru", "phone": "+70498831546"}
0005435242820	218E61	9375 116567	LYUDMILA STEPANOVA	{"email": "lyudmilastepanova081969@postgrespro.ru", "phone": "+70280869443"}
0005435242821	46D803	6708 405991	TAISIYA KOZLOVA	{"email": "taisiya.kozlova-15121967@postgrespro.ru", "phone": "+70435885918"}
0005435242822	72C017	7235 186682	NIKOLAY FROLOV	{"email": "frolov-n_071969@postgrespro.ru", "phone": "+70249433100"}
0005435242823	72C017	7764 537901	MIKHAIL DAVYDOV	{"email": "mdavydov-1980@postgrespro.ru", "phone": "+70101128964"}
0005435242824	72C017	6159 425798	ELENA KRASNOVA	{"email": "elena-krasnova06081962@postgrespro.ru", "phone": "+70366240954"}
0005435242825	FC8983	2143 189730	DMITRIY FEDOROV	{"email": "dfedorov_30061968@postgrespro.ru", "phone": "+70427791801"}
0005435242826	8B893F	0404 651907	LYUBOV DMITRIEVA	{"email": "dmitrieval-26031974@postgrespro.ru", "phone": "+70657382902"}
0005435242828	8B893F	0079 943557	ANNA SERGEEVA	{"email": "anna.sergeeva1974@postgrespro.ru", "phone": "+70479211399"}
0005435242829	FC79ED	8215 213228	SVETLANA TARASOVA	{"phone": "+70897042756"}
0005435242830	FC79ED	5330 365871	EKATERINA ILINA	{"email": "ilinaekaterina.121972@postgrespro.ru", "phone": "+70330235988"}
0005435242831	81F47C	4189 199616	DENIS VOROBEV	{"email": "vorobev-d_1965@postgrespro.ru", "phone": "+70010713500"}
0005435242832	81F47C	6167 359633	YAROSLAV GAVRILOV	{"email": "yaroslavgavrilov18071981@postgrespro.ru", "phone": "+70816013233"}
0005435242833	B1937C	2237 970242	ALENA KONDRATEVA	{"email": "a-kondrateva_1971@postgrespro.ru", "phone": "+70185701390"}
0005435242834	B1937C	9155 046507	LYUBOV GAVRILOVA	{"email": "gavrilova_l.021974@postgrespro.ru", "phone": "+70421779999"}
0005435242835	F21840	3149 997763	IGOR NIKOLAEV	{"phone": "+70775075177"}
0005435242836	F21840	1903 378751	ARTUR KUZNECOV	{"email": "arturkuznecov_1973@postgrespro.ru", "phone": "+70196325913"}
0005435242837	A4B334	3929 850654	EVDOKIYA SEMENOVA	{"email": "evdokiya_semenova_1973@postgrespro.ru", "phone": "+70102801110"}
0005435242838	A4B334	9699 073882	EVGENIY FILIPPOV	{"phone": "+70887301312"}
0005435242839	A4B334	9048 919080	VLADIMIR VASILEV	{"phone": "+70111304917"}
0005435242840	7E90FF	9023 329021	NATALYA ILINA	{"phone": "+70709026126"}
0005435242841	644545	2256 862296	EKATERINA TIMOFEEVA	{"email": "timofeeva_e-121969@postgrespro.ru", "phone": "+70754781024"}
0005435242842	E8121D	1536 995878	IGOR VASILEV	{"email": "vasilev.i_1961@postgrespro.ru", "phone": "+70914991613"}
0005435242843	5AEE5E	6627 677191	SVETLANA NESTEROVA	{"email": "s-nesterova_1969@postgrespro.ru", "phone": "+70454614555"}
0005435242844	5AEE5E	8961 202024	MARINA KULIKOVA	{"email": "marina-kulikova02121967@postgrespro.ru", "phone": "+70042522810"}
0005435242845	3CBED9	2313 835098	PAVEL SEMENOV	{"email": "p_semenov.12081957@postgrespro.ru", "phone": "+70177333852"}
0005435242846	3CBED9	9048 986742	VALERIY STEPANOV	{"phone": "+70094311639"}
0005435242847	1B5F69	6109 737279	ZOYA SIDOROVA	{"email": "z_sidorova_1961@postgrespro.ru", "phone": "+70740857562"}
0005435242848	1D2AD7	1401 986858	ANATOLIY ZAKHAROV	{"email": "anatoliyzakharov.1966@postgrespro.ru", "phone": "+70295795618"}
0005435242849	AA20AA	9522 407530	VLADIMIR KISELEV	{"email": "v.kiselev_041974@postgrespro.ru", "phone": "+70033963886"}
0005435242850	B00B38	5687 965523	YULIYA ZAYCEVA	{"phone": "+70005228768"}
0005435242851	E9281D	8510 817775	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana1972@postgrespro.ru", "phone": "+70869467555"}
0005435242852	F98547	7751 217481	VYACHESLAV CHERNOV	{"phone": "+70798521567"}
0005435242853	F98547	5452 086438	ALEKSANDR FOMIN	{"email": "fomina1970@postgrespro.ru", "phone": "+70075720801"}
0005435242854	0337CF	7459 664493	LEONID MAKAROV	{"phone": "+70899958430"}
0005435242855	0337CF	8964 135997	YULIANA NIKITINA	{"phone": "+70373645123"}
0005435242856	0337CF	2458 374303	DMITRIY MAKSIMOV	{"email": "maksimov_dmitriy-021968@postgrespro.ru", "phone": "+70145588431"}
0005435242857	0337CF	0404 328634	SVETLANA KALININA	{"phone": "+70658561352"}
0005435242858	914ACD	9357 875475	SVETLANA MATVEEVA	{"phone": "+70575576814"}
0005435242859	914ACD	7741 838560	OLGA KUDRYASHOVA	{"phone": "+70410240189"}
0005435242860	914ACD	8291 952707	VIKTOR IVANOV	{"phone": "+70911513432"}
0005435242861	10A1C2	6105 948630	MIKHAIL SCHERBAKOV	{"email": "scherbakov-mikhail.1976@postgrespro.ru", "phone": "+70010135691"}
0005435242862	740E8F	9017 260574	ELENA MIKHAYLOVA	{"phone": "+70382236556"}
0005435242863	740E8F	4832 058640	ALEKSEY ZHURAVLEV	{"phone": "+70357674641"}
0005435242864	27AE54	4633 114312	POLINA KONDRATEVA	{"phone": "+70104599663"}
0005435242865	27AE54	4028 196434	GLEB MATVEEV	{"phone": "+70294256888"}
0005435242866	345302	5426 467896	ALEKSANDR KOZLOV	{"phone": "+70983521371"}
0005435242867	345302	6106 965911	TATYANA TIMOFEEVA	{"email": "tatyanatimofeeva_021963@postgrespro.ru", "phone": "+70500628160"}
0005435242868	0C7821	6763 723324	INGA SOKOLOVA	{"email": "sokolova.i031964@postgrespro.ru", "phone": "+70861438945"}
0005435242869	0C7821	7597 941344	YULIYA BORISOVA	{"phone": "+70338902960"}
0005435242870	0E830C	0085 530148	IGOR IVANOV	{"phone": "+70924942049"}
0005435242871	1006DC	6521 965653	VERA SERGEEVA	{"phone": "+70787895561"}
0005435242872	1006DC	4175 829236	TAISIYA OSIPOVA	{"phone": "+70978470243"}
0005435242873	3D202F	2037 155826	MARINA KUZMINA	{"phone": "+70142610488"}
0005435242874	CE658A	3927 307945	NIKOLAY NIKITIN	{"email": "nikolaynikitin.071970@postgrespro.ru", "phone": "+70654336075"}
0005435242875	CE658A	3659 574058	MIKHAIL IVANOV	{"email": "ivanovmikhail_11111972@postgrespro.ru", "phone": "+70412584377"}
0005435242876	3D43E5	9187 181295	GALINA DAVYDOVA	{"phone": "+70783002196"}
0005435242877	F20009	5828 724369	OLGA MAKSIMOVA	{"phone": "+70098839435"}
0005435242878	AC4C19	4362 031066	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov_1964@postgrespro.ru", "phone": "+70179969146"}
0005435242879	AC4C19	7377 537050	VIKTOR MELNIKOV	{"email": "v-melnikov061975@postgrespro.ru", "phone": "+70238393881"}
0005435242880	2A0BA1	2338 645174	EKATERINA SOLOVEVA	{"email": "e-soloveva_081984@postgrespro.ru", "phone": "+70206653322"}
0005435242881	2A0BA1	5906 951318	IGOR NIKOLAEV	{"phone": "+70215496279"}
0005435242882	93FDFC	2038 562978	SERGEY PETROV	{"email": "s-petrov_08061960@postgrespro.ru", "phone": "+70067879174"}
0005435242883	0F926F	0418 578015	RITA NIKOLAEVA	{"email": "r_nikolaeva30111980@postgrespro.ru", "phone": "+70837101529"}
0005435242884	0F926F	0128 621449	VLADIMIR NAZAROV	{"email": "nazarov.vladimir-1968@postgrespro.ru", "phone": "+70349635976"}
0005435242885	4C9379	9887 956923	ANGELINA TIKHONOVA	{"email": "a.tikhonova1972@postgrespro.ru", "phone": "+70921173933"}
0005435242886	82ACD1	1180 044947	EVGENIY MEDVEDEV	{"email": "medvedev.e-1963@postgrespro.ru", "phone": "+70038704584"}
0005435242887	4B73E9	0580 008844	YURIY KUZNECOV	{"email": "yuriy-kuznecov.16031971@postgrespro.ru", "phone": "+70024058385"}
0005435242888	4B73E9	6309 979793	NIKOLAY SEMENOV	{"email": "nikolay.semenov_011974@postgrespro.ru", "phone": "+70867137355"}
0005435242889	4B73E9	3235 967455	VITALIY POPOV	{"email": "popov.v-1964@postgrespro.ru", "phone": "+70902495306"}
0005435242890	15D39E	0796 823906	ALEVTINA KISELEVA	{"email": "a.kiseleva_1975@postgrespro.ru", "phone": "+70199292290"}
0005435242891	15D39E	3606 784341	EKATERINA GUSEVA	{"email": "guseva.ekaterina1971@postgrespro.ru", "phone": "+70528068678"}
0005435242892	8CBC66	9447 097892	KLAVDIYA POLYAKOVA	{"phone": "+70182078186"}
0005435242893	72D0E9	0665 901024	ANNA ZAYCEVA	{"phone": "+70507964380"}
0005435242894	22A1DF	0536 130857	LYUBOV MELNIKOVA	{"phone": "+70934444329"}
0005435242895	4EBBE9	9387 186408	EVGENIY MOISEEV	{"phone": "+70675887370"}
0005435242896	1F287A	4793 881041	VALERIY NIKITIN	{"email": "valeriy-nikitin31031974@postgrespro.ru", "phone": "+70617006077"}
0005435242897	1F287A	3742 624253	ALEKSANDRA EGOROVA	{"email": "egorova_aleksandra22121971@postgrespro.ru", "phone": "+70578467822"}
0005435242898	1F287A	6853 144219	GALINA IVANOVA	{"email": "galina-ivanova.021964@postgrespro.ru", "phone": "+70662587154"}
0005435242899	F28FFD	2298 983396	EVGENIY TARASOV	{"email": "evgeniytarasov1977@postgrespro.ru", "phone": "+70601236047"}
0005435242900	F28FFD	2833 247581	ALEKSANDR FEDOTOV	{"email": "aleksandrfedotov10041983@postgrespro.ru", "phone": "+70565538869"}
0005435242901	67FD85	7444 707449	VALENTINA NOVIKOVA	{"phone": "+70473554295"}
0005435242902	67FD85	3109 833857	NATALYA POPOVA	{"phone": "+70256333807"}
0005435242903	67FD85	3839 462689	GALINA MIKHAYLOVA	{"phone": "+70770419450"}
0005435242904	89D523	5331 483503	NINA NESTEROVA	{"email": "ninanesterova.1974@postgrespro.ru", "phone": "+70739351141"}
0005435242905	839C30	6434 011058	MARINA RODIONOVA	{"email": "m.rodionova-011965@postgrespro.ru", "phone": "+70936759772"}
0005435242906	929EFD	4266 390532	VIKTOR SOKOLOV	{"phone": "+70852382808"}
0005435242907	8BA449	8331 888764	VLADISLAV ANTONOV	{"email": "v_antonov051972@postgrespro.ru", "phone": "+70472025886"}
0005435242908	EC4A7E	9689 634291	EVGENIY ANDREEV	{"email": "andreevevgeniy-1978@postgrespro.ru", "phone": "+70204052480"}
0005435242909	EC4A7E	5770 841174	LIDIYA SMIRNOVA	{"phone": "+70623915571"}
0005435242910	EC4A7E	4371 524780	ZULFIYA MOISEEVA	{"email": "moiseeva-zulfiya_24061970@postgrespro.ru", "phone": "+70808998721"}
0005435242911	CA0BE9	0806 025895	SVETLANA LEBEDEVA	{"email": "lebedeva-svetlana.08091971@postgrespro.ru", "phone": "+70941850538"}
0005435242912	04EBFD	7543 487071	VADIM VASILEV	{"email": "vasilevvadim_1970@postgrespro.ru", "phone": "+70049382540"}
0005435242913	5C61AA	5960 915921	DMITRIY ANTONOV	{"email": "antonov.d_1973@postgrespro.ru", "phone": "+70835792099"}
0005435242914	F49324	0509 593115	ANDREY ZHUKOV	{"email": "azhukov_10091964@postgrespro.ru", "phone": "+70836365651"}
0005435242915	F53B84	4833 561188	ILYA POPOV	{"phone": "+70960249194"}
0005435242916	5C38F7	6707 729061	SERGEY BARANOV	{"email": "sergey-baranov.1979@postgrespro.ru", "phone": "+70618366143"}
0005435242917	5E7D14	9694 179382	ELENA VOLKOVA	{"email": "volkovae_12091971@postgrespro.ru", "phone": "+70274682765"}
0005435242918	5E7D14	3151 847614	TAMARA DAVYDOVA	{"phone": "+70178976421"}
0005435242919	385A60	2367 575040	ALEKSEY ILIN	{"phone": "+70797042634"}
0005435242920	1EF7FD	7811 100308	SERGEY VLASOV	{"email": "vlasovs_30121972@postgrespro.ru", "phone": "+70475728497"}
0005435242921	1EF7FD	6942 466346	SERGEY IVANOV	{"email": "ivanov-sergey-15081962@postgrespro.ru", "phone": "+70144309110"}
0005435242922	AA2D1B	9313 461004	SERGEY KAZAKOV	{"email": "s-kazakov_041965@postgrespro.ru", "phone": "+70673586975"}
0005435242923	AA2D1B	0716 084496	NADEZHDA BELOVA	{"email": "belova.nadezhda-1984@postgrespro.ru", "phone": "+70537790846"}
0005435242924	A30FEE	5284 302739	VIKTOR DMITRIEV	{"phone": "+70234512102"}
0005435242925	7F0B7D	2815 784102	ELENA FILATOVA	{"email": "elena-filatova.071966@postgrespro.ru", "phone": "+70655417135"}
0005435242926	7F0B7D	4408 037003	ANATOLIY KUZNECOV	{"email": "anatoliy.kuznecov.07011970@postgrespro.ru", "phone": "+70631448821"}
0005435242927	638C59	8263 495266	VLADISLAV SOLOVEV	{"phone": "+70524530681"}
0005435242928	229AFC	1075 155671	LYUDMILA STEPANOVA	{"email": "l-stepanova-12051977@postgrespro.ru", "phone": "+70477254168"}
0005435242929	229AFC	5417 951912	YURIY MIRONOV	{"phone": "+70904440449"}
0005435242930	229AFC	8975 206593	ALEKSEY YAKOVLEV	{"phone": "+70483762253"}
0005435242931	69B556	2381 344923	SERGEY MIKHAYLOV	{"email": "smikhaylov081966@postgrespro.ru", "phone": "+70986787147"}
0005435242932	69B556	7327 433172	ALEKSANDR MELNIKOV	{"phone": "+70504087079"}
0005435242933	B9E916	9527 043509	TATYANA ZOTOVA	{"phone": "+70444904793"}
0005435242934	38B663	7753 461592	ALEKSEY VASILEV	{"phone": "+70682477881"}
0005435242935	38B663	1298 708365	SVETLANA ROMANOVA	{"phone": "+70594503107"}
0005435242936	C9841C	6703 714884	ANTON MATVEEV	{"phone": "+70766141783"}
0005435242937	D0C64A	3009 557954	ALEKSANDR SCHERBAKOV	{"email": "a_scherbakov1965@postgrespro.ru", "phone": "+70786470057"}
0005435242938	B04D8D	2170 236550	VADIM MARTYNOV	{"email": "vadim_martynov_22101960@postgrespro.ru", "phone": "+70571693296"}
0005435242939	BECE71	8198 414018	LYUDMILA BOGDANOVA	{"phone": "+70113282783"}
0005435242940	C3959F	3474 984874	GENNADIY AFANASEV	{"phone": "+70971925963"}
0005435242941	C3959F	6661 721102	OLGA SOKOLOVA	{"email": "sokolovaolga-02031970@postgrespro.ru", "phone": "+70007998812"}
0005435242942	4FB23D	0773 247336	ZINAIDA SEMENOVA	{"email": "zinaida.semenova.01061975@postgrespro.ru", "phone": "+70029193946"}
0005435242943	125F81	7796 168857	NIKOLAY SCHERBAKOV	{"phone": "+70763412356"}
0005435242944	B454DC	5672 935677	NINA KULIKOVA	{"email": "kulikova.n17081969@postgrespro.ru", "phone": "+70137628651"}
0005435242945	DB02C3	8673 877101	ALEKSEY PAVLOV	{"email": "apavlov.18031971@postgrespro.ru", "phone": "+70917780701"}
0005435242946	044582	4837 897394	PAVEL VOLKOV	{"phone": "+70334183604"}
0005435242947	A396DD	6024 325623	NADEZHDA EGOROVA	{"phone": "+70522681776"}
0005435242948	6A92F6	7568 995695	PAVEL BONDARENKO	{"phone": "+70202119203"}
0005435242949	97E4E7	7074 388226	EKATERINA VLASOVA	{"email": "vlasova-ekaterina1972@postgrespro.ru", "phone": "+70908248892"}
0005435242950	97E4E7	4646 317622	YURIY AFANASEV	{"phone": "+70568960697"}
0005435242951	99AC5E	5229 495028	MARINA YAKOVLEVA	{"phone": "+70319038980"}
0005435242952	99AC5E	6784 992284	ANNA KOZLOVA	{"phone": "+70945808993"}
0005435242953	D960EA	1270 015415	OKSANA DENISOVA	{"email": "denisova.oksana_1980@postgrespro.ru", "phone": "+70494226663"}
0005435242954	BCE4BF	9373 965289	RAIL IVANOV	{"email": "rivanov.081971@postgrespro.ru", "phone": "+70388104273"}
0005435242955	BCE4BF	8044 531815	PAVEL TARASOV	{"email": "p-tarasov-1979@postgrespro.ru", "phone": "+70407834720"}
0005435242956	F7C0B5	2057 063949	OKSANA GUSEVA	{"email": "oksanaguseva-031977@postgrespro.ru", "phone": "+70126311751"}
0005435242957	0A7216	3717 117988	PETR MIKHAYLOV	{"email": "mikhaylovpetr051973@postgrespro.ru", "phone": "+70315614767"}
0005435242958	31077B	7830 355801	DARYA KUZMINA	{"email": "d.kuzmina_021968@postgrespro.ru", "phone": "+70754622616"}
0005435242959	0437BD	9303 983600	OKSANA NIKOLAEVA	{"phone": "+70896116215"}
0005435242960	B4483F	1243 291364	NATALIYA BELOVA	{"phone": "+70160192476"}
0005435242961	4CF9E2	2811 245104	DMITRIY OSIPOV	{"email": "osipov.d-121974@postgrespro.ru", "phone": "+70894030589"}
0005435242962	0AE98A	7302 812233	GENNADIY BORISOV	{"phone": "+70538810605"}
0005435242963	B763FD	9670 259339	LIDIYA OVCHINNIKOVA	{"phone": "+70857240041"}
0005435242964	70C4E0	9934 191253	ARTEM GAVRILOV	{"phone": "+70979129343"}
0005435242965	70C4E0	1698 947797	MARINA POTAPOVA	{"phone": "+70563115233"}
0005435242966	906677	2932 625006	ANDREY TIMOFEEV	{"phone": "+70615431364"}
0005435242967	5CC2D1	2369 102872	GENNADIY ILIN	{"email": "ilingennadiy_111968@postgrespro.ru", "phone": "+70102008684"}
0005435242968	648EBC	7918 748486	VALENTINA ALEKSEEVA	{"phone": "+70852496201"}
0005435242969	59B365	0767 988240	VALERIYA IVANOVA	{"phone": "+70126418509"}
0005435242970	59B365	8272 920462	GALINA BARANOVA	{"email": "baranova.galina1973@postgrespro.ru", "phone": "+70454435104"}
0005435242971	DA150C	0338 686184	GALINA STEPANOVA	{"email": "stepanovagalina.1972@postgrespro.ru", "phone": "+70314468840"}
0005435242972	94FB14	5858 924030	KIRILL SHEVCHENKO	{"email": "kirillshevchenko.1972@postgrespro.ru", "phone": "+70095907892"}
0005435242973	94FB14	2466 395076	VLADIMIR EGOROV	{"email": "vladimir_egorov-091975@postgrespro.ru", "phone": "+70360585937"}
0005435242974	94FB14	8168 759243	DARYA KARPOVA	{"email": "karpova.darya30101963@postgrespro.ru", "phone": "+70173466446"}
0005435242975	632FD7	3851 468238	NINA AFANASEVA	{"phone": "+70228201375"}
0005435242976	632FD7	3925 194724	ALEKSEY MAKSIMOV	{"phone": "+70160386675"}
0005435242977	C3DD5A	0210 890657	MIKHAIL ZHURAVLEV	{"email": "zhuravlev.m.08091968@postgrespro.ru", "phone": "+70907635556"}
0005435242978	C3DD5A	6567 785775	ANATOLIY DAVYDOV	{"email": "davydov.a-26021969@postgrespro.ru", "phone": "+70145261239"}
0005435242979	67FF17	9249 624052	ZINAIDA SERGEEVA	{"email": "sergeeva_z-31031975@postgrespro.ru", "phone": "+70972674832"}
0005435242980	D4CE90	5094 553626	SERGEY NOVIKOV	{"email": "s.novikov.12031969@postgrespro.ru", "phone": "+70600965578"}
0005435242981	D4CE90	6696 435458	KIRILL OSIPOV	{"phone": "+70511077408"}
0005435242982	6D6966	4597 957145	MARIYA MELNIKOVA	{"email": "melnikova.mariya-1972@postgrespro.ru", "phone": "+70139440807"}
0005435242983	5945BD	8188 192596	OLGA VOROBEVA	{"email": "ovorobeva05111977@postgrespro.ru", "phone": "+70465156771"}
0005435242984	9A4FFE	6942 802426	IGOR YAKOVLEV	{"phone": "+70424334570"}
0005435242985	CC1349	3020 525335	ALEVTINA FILIPPOVA	{"phone": "+70144198075"}
0005435242986	377B39	6398 534767	TATYANA MOISEEVA	{"phone": "+70736772812"}
0005435242987	377B39	0441 955270	IVAN NIKITIN	{"email": "nikitini.08031978@postgrespro.ru", "phone": "+70268531101"}
0005435242988	A698A0	5709 246994	NADEZHDA KARPOVA	{"email": "karpova_nadezhda.24061967@postgrespro.ru", "phone": "+70172437346"}
0005435242989	D55643	2346 463277	RINAT TARASOV	{"email": "tarasov-r1969@postgrespro.ru", "phone": "+70413199619"}
0005435242990	0C2F66	3515 812455	DARYA ZOTOVA	{"email": "zotova.darya.101984@postgrespro.ru", "phone": "+70244221922"}
0005435242991	C06DEB	0251 579448	ALEKSANDR MOROZOV	{"email": "aleksandr.morozov121976@postgrespro.ru", "phone": "+70343946755"}
0005435242992	FD943D	0080 168835	ALEKSANDR MIKHAYLOV	{"phone": "+70811808430"}
0005435242993	5BE42E	4706 497242	MARIYA MIRONOVA	{"email": "mironova-m.21071991@postgrespro.ru", "phone": "+70795625993"}
0005435242994	FBCC7F	5107 379768	LYUDMILA ROMANOVA	{"phone": "+70191281632"}
0005435242995	FBCC7F	5584 636440	ANATOLIY IVANOV	{"phone": "+70145446890"}
0005435242996	FBCC7F	6955 179080	DAVID IVANOV	{"phone": "+70355154122"}
0005435242997	A72218	0544 660130	VERA POPOVA	{"phone": "+70144888869"}
0005435242998	A72218	2832 759444	ELZA MOROZOVA	{"email": "morozovaelza12051980@postgrespro.ru", "phone": "+70201454354"}
0005435242999	30390A	3734 352308	LYUDMILA IVANOVA	{"email": "ivanova_lyudmila.061976@postgrespro.ru", "phone": "+70895872602"}
0005435243000	6D6B88	3174 365230	VIKTOR DENISOV	{"phone": "+70471432916"}
0005435243001	6D6B88	3706 770678	IRINA KOZLOVA	{"phone": "+70395473367"}
0005435243002	6D6B88	9696 064732	GALINA GORBUNOVA	{"phone": "+70568487084"}
0005435243003	7B4F9A	9713 756934	VIKTORIYA EGOROVA	{"email": "egorova.viktoriya.1967@postgrespro.ru", "phone": "+70436893675"}
0005435243004	7B4F9A	1455 609145	EKATERINA ORLOVA	{"phone": "+70630459182"}
0005435243005	C3DC5B	0302 214927	NINA FOMINA	{"email": "ninafomina-061973@postgrespro.ru", "phone": "+70249128969"}
0005435243006	AAAAF8	5483 492768	NINA VASILEVA	{"email": "vasileva.n091962@postgrespro.ru", "phone": "+70275507258"}
0005435243007	A7F80C	1708 690994	RIMMA YAKOVLEVA	{"phone": "+70328475688"}
0005435243008	A7F80C	5351 512067	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr051973@postgrespro.ru", "phone": "+70014785704"}
0005435243009	05D8E0	6151 705249	YULIYA ANDREEVA	{"phone": "+70462358854"}
0005435243010	05D8E0	8426 496319	VERA FROLOVA	{"email": "frolova.vera_1975@postgrespro.ru", "phone": "+70757620969"}
0005435243011	D4F824	9485 312701	VASILIY BONDARENKO	{"email": "vasiliy-bondarenko05081968@postgrespro.ru", "phone": "+70050533153"}
0005435243012	154993	5295 077277	EGOR SEMENOV	{"email": "egor-semenov28121967@postgrespro.ru", "phone": "+70238783099"}
0005435243013	4C6970	3937 080768	MARIYA FOMINA	{"email": "fomina-mariya_1977@postgrespro.ru", "phone": "+70136477152"}
0005435243014	6C7C22	0461 862147	MAKSIM IVANOV	{"phone": "+70488885723"}
0005435243015	6C7C22	3728 907996	ANDREY VOROBEV	{"email": "andrey_vorobev_1959@postgrespro.ru", "phone": "+70269050236"}
0005435243016	767AA4	3286 530762	VADIM IVANOV	{"email": "ivanov_vadim1967@postgrespro.ru", "phone": "+70567378622"}
0005435243017	0716FF	2909 367637	VIKTOR TARASOV	{"email": "v.tarasov.031983@postgrespro.ru", "phone": "+70997705334"}
0005435243018	0716FF	2317 747921	TATYANA MIRONOVA	{"email": "t-mironova.071966@postgrespro.ru", "phone": "+70415428836"}
0005435243019	BEB681	6653 788675	TATYANA MAKAROVA	{"phone": "+70499294069"}
0005435243020	B49386	4660 639516	ELENA ANISIMOVA	{"phone": "+70180442643"}
0005435243021	56AE78	1933 062301	NIKOLAY STEPANOV	{"phone": "+70772923970"}
0005435243022	56AE78	4604 633936	NINA STEPANOVA	{"email": "nstepanova-051971@postgrespro.ru", "phone": "+70331380120"}
0005435243023	BC77BE	5573 447131	MIKHAIL MIRONOV	{"phone": "+70640103909"}
0005435243024	E049E4	4553 824938	ANATOLIY GUSEV	{"phone": "+70419773030"}
0005435243025	E049E4	5480 442545	ANDREY EGOROV	{"email": "egorov-andrey.14071956@postgrespro.ru", "phone": "+70064265959"}
0005435243026	AC3A44	3783 908907	SVETLANA GRISHINA	{"phone": "+70969013816"}
0005435243027	AC3A44	3131 316084	VALERIYA TIMOFEEVA	{"email": "v.timofeeva_01051967@postgrespro.ru", "phone": "+70722422315"}
0005435243028	7B6E16	2283 090523	TATYANA BELOVA	{"phone": "+70933017991"}
0005435243029	2FF35A	2435 652673	NADEZHDA KOVALEVA	{"email": "kovaleva.nadezhda.15031953@postgrespro.ru", "phone": "+70507086008"}
0005435243030	802F24	5902 097589	ALEKSANDR SAVELEV	{"phone": "+70876552119"}
0005435243031	844545	5881 387825	MAKSIM BONDARENKO	{"email": "m_bondarenko.121974@postgrespro.ru", "phone": "+70214812360"}
0005435243032	099569	3340 313998	SERGEY SEMENOV	{"phone": "+70589485230"}
0005435243033	3CEE72	3190 162578	EGOR GORBUNOV	{"email": "gorbunovegor1985@postgrespro.ru", "phone": "+70212426145"}
0005435243034	3CEE72	1494 701966	DMITRIY MOROZOV	{"phone": "+70196644803"}
0005435243035	3AAB12	7910 909509	OKSANA SOKOLOVA	{"email": "osokolova06111966@postgrespro.ru", "phone": "+70337744257"}
0005435243036	3AAB12	2732 065036	DMITRIY ALEKSANDROV	{"email": "aleksandrovdmitriy_071971@postgrespro.ru", "phone": "+70403114896"}
0005435243037	614BA5	7302 335550	YULIYA MIKHAYLOVA	{"email": "mikhaylova-y1970@postgrespro.ru", "phone": "+70212856118"}
0005435243038	614BA5	7538 065685	VLADIMIR DENISOV	{"phone": "+70791522517"}
0005435243039	927DF7	1584 019374	ANDREY MAKSIMOV	{"phone": "+70712042952"}
0005435243040	927DF7	1886 456368	EVGENIY SERGEEV	{"email": "sergeev.evgeniy081986@postgrespro.ru", "phone": "+70306683326"}
0005435243041	0D51C4	0879 292802	IRINA YUDINA	{"phone": "+70538829367"}
0005435243042	0D51C4	2604 151953	EVGENIY TIMOFEEV	{"phone": "+70273542777"}
0005435243043	0662CB	6784 493694	ILYA SOKOLOV	{"email": "sokolov-i.1978@postgrespro.ru", "phone": "+70326697323"}
0005435243044	F646E9	7299 684016	DMITRIY FOMIN	{"email": "fomind.11061972@postgrespro.ru", "phone": "+70652790644"}
0005435243045	5AA8E1	4041 952199	ARTUR ANDREEV	{"phone": "+70273960661"}
0005435243046	2DBCCB	9802 296546	KARINA KONOVALOVA	{"phone": "+70116927862"}
0005435243047	6D1645	0870 744362	NATALYA POTAPOVA	{"email": "potapovanatalya.27101981@postgrespro.ru", "phone": "+70975098610"}
0005435243048	6D1645	9905 685132	KAMIL NIKOLAEV	{"email": "nikolaev.kamil031980@postgrespro.ru", "phone": "+70367240538"}
0005435243049	04958B	9238 319418	OLGA KAZAKOVA	{"email": "olga-kazakova1981@postgrespro.ru", "phone": "+70238182366"}
0005435243050	04958B	2041 803934	IRINA DAVYDOVA	{"phone": "+70810140393"}
0005435243051	546ABA	1051 535158	ANDREY KONOVALOV	{"email": "konovalov_andrey-1969@postgrespro.ru", "phone": "+70127144996"}
0005435243052	49995E	3867 132077	OLGA CHERNOVA	{"email": "chernova-olga051972@postgrespro.ru", "phone": "+70113146246"}
0005435243053	49995E	5326 583265	NIKITA IVANOV	{"phone": "+70633121102"}
0005435243054	49995E	2518 142504	VERA KAZAKOVA	{"email": "kazakova_vera1978@postgrespro.ru", "phone": "+70567690468"}
0005435243055	68DA80	7359 954240	KSENIYA NAZAROVA	{"phone": "+70951012575"}
0005435243056	68DA80	3038 937204	ELIZAVETA EFREMOVA	{"email": "e-efremova-1971@postgrespro.ru", "phone": "+70512293698"}
0005435243057	5A4484	8478 737400	VITALIY ZHUKOV	{"phone": "+70681815277"}
0005435243058	5A4484	3300 604101	MARINA ERMAKOVA	{"email": "marina_ermakova1960@postgrespro.ru", "phone": "+70665685448"}
0005435243059	5DA535	1805 767306	TATYANA BOGDANOVA	{"phone": "+70812391389"}
0005435243060	5DA535	2150 463461	KIRILL SAVELEV	{"phone": "+70313073199"}
0005435243061	5DA535	5276 890198	LYUDMILA MOROZOVA	{"email": "lyudmila_morozova18041970@postgrespro.ru", "phone": "+70589742028"}
0005435243062	35DCAB	5038 990641	RAFAEL MOISEEV	{"phone": "+70343221404"}
0005435243063	871DAB	9008 629612	ALEKSANDR SEMENOV	{"phone": "+70411542148"}
0005435243064	871DAB	7704 715973	ANTON RODIONOV	{"email": "rodionov_anton.20081982@postgrespro.ru", "phone": "+70032393748"}
0005435243065	BD0A94	9242 149080	EVGENIY FEDOROV	{"email": "e.fedorov.1966@postgrespro.ru", "phone": "+70382344498"}
0005435243066	BD0A94	6333 277378	VALENTINA GUSEVA	{"email": "valentinaguseva_1970@postgrespro.ru", "phone": "+70507636234"}
0005435243067	9CD2AD	1276 136826	ANDREY PETROV	{"email": "petrov-a071968@postgrespro.ru", "phone": "+70219457053"}
0005435243068	9CD2AD	0942 685469	DENIS ILIN	{"phone": "+70057635857"}
0005435243069	65FE7F	7049 290176	DMITRIY TIKHONOV	{"email": "d_tikhonov08081979@postgrespro.ru", "phone": "+70692647015"}
0005435243070	990CD1	1814 556595	ANNA ZAYCEVA	{"email": "a-zayceva-111986@postgrespro.ru", "phone": "+70893800368"}
0005435243071	990CD1	0652 371584	ZINAIDA SEMENOVA	{"email": "semenova_zinaida_05021973@postgrespro.ru", "phone": "+70668620036"}
0005435243072	910B2A	2206 084753	TAMARA STEPANOVA	{"phone": "+70444553839"}
0005435243073	5B95B8	1086 955557	VLADIMIR DENISOV	{"phone": "+70095547672"}
0005435243074	79BAF1	0571 724103	MIKHAIL SEMENOV	{"email": "semenov.mikhail_1974@postgrespro.ru", "phone": "+70181454911"}
0005435243075	926446	6607 736281	ANNA BELOVA	{"phone": "+70801125873"}
0005435243076	2B7112	1417 655806	ARSENIY KUZMIN	{"email": "arseniy_kuzmin-061978@postgrespro.ru", "phone": "+70895562678"}
0005435243077	150A8B	3547 267660	EKATERINA NIKOLAEVA	{"email": "nikolaeva.ekaterina.071986@postgrespro.ru", "phone": "+70738219215"}
0005435243078	42A283	3535 076160	TATYANA SEMENOVA	{"phone": "+70938765078"}
0005435243079	42A283	7373 804097	LYUDMILA MIRONOVA	{"phone": "+70788159939"}
0005435243080	38FAAE	7307 134969	ELENA SEMENOVA	{"phone": "+70763754821"}
0005435243081	3098DD	1928 616157	RENATA GAVRILOVA	{"email": "gavrilovar.1981@postgrespro.ru", "phone": "+70269390062"}
0005435243082	3098DD	0699 892752	ANATOLIY KOROLEV	{"email": "korolev-anatoliy091959@postgrespro.ru", "phone": "+70095334902"}
0005435243083	0A0C9E	4991 344147	INNA MAKAROVA	{"email": "inna-makarova011968@postgrespro.ru", "phone": "+70322773989"}
0005435243084	4758F3	8793 887158	EKATERINA KRASNOVA	{"phone": "+70267968979"}
0005435243085	EAB477	3649 246430	ALEKSANDR MIRONOV	{"email": "aleksandr-mironov091968@postgrespro.ru", "phone": "+70033356492"}
0005435243086	84AAE5	9777 546630	ANTONINA KUZMINA	{"email": "kuzminaantonina.061972@postgrespro.ru", "phone": "+70746520908"}
0005435243087	84AAE5	1271 591492	VLADIMIR EGOROV	{"phone": "+70227952838"}
0005435243088	84AAE5	0270 606765	ELENA YUDINA	{"phone": "+70065621063"}
0005435243089	6F1148	6209 255560	ELENA EGOROVA	{"email": "egorovae.121968@postgrespro.ru", "phone": "+70026384742"}
0005435243090	6F1148	3730 153143	VYACHESLAV BELOV	{"phone": "+70106103344"}
0005435243091	A1F88F	1017 827604	ELINA OVCHINNIKOVA	{"email": "e.ovchinnikova_1972@postgrespro.ru", "phone": "+70666881413"}
0005435243092	E09A95	0051 504282	RUSLAN GRIGOREV	{"email": "grigorevruslan.30081985@postgrespro.ru", "phone": "+70733585939"}
0005435243093	D0D80E	5635 268132	VALERIYA BORISOVA	{"email": "v.borisova.03011978@postgrespro.ru", "phone": "+70060466540"}
0005435243094	29B677	4830 310474	KRISTINA VASILEVA	{"phone": "+70046062445"}
0005435243095	401FD4	3457 522153	EVGENIYA DMITRIEVA	{"email": "edmitrieva111970@postgrespro.ru", "phone": "+70021994842"}
0005435243096	401FD4	2976 167889	SERGEY KUZNECOV	{"phone": "+70789925173"}
0005435243097	A98B23	7697 408134	NIKOLAY SIDOROV	{"phone": "+70188998403"}
0005435243098	0711EF	5428 961610	MARIYA KUZNECOVA	{"email": "kuznecovamariya-031962@postgrespro.ru", "phone": "+70606346113"}
0005435243099	D3C046	3170 641538	VLADIMIR ZHUKOV	{"email": "zhukov.v_121973@postgrespro.ru", "phone": "+70909400370"}
0005435243100	8A669F	0594 173051	SERGEY YAKOVLEV	{"email": "s_yakovlev.041967@postgrespro.ru", "phone": "+70634661432"}
0005435243101	7A8ED8	0307 086684	ALEKSANDR ORLOV	{"email": "orlov_aleksandr_1966@postgrespro.ru", "phone": "+70768100656"}
0005435243102	7A8ED8	0350 857779	KSENIYA CHERNOVA	{"phone": "+70798127209"}
0005435243103	FDFD82	3446 937901	SERGEY MARTYNOV	{"email": "sergeymartynov.061979@postgrespro.ru", "phone": "+70279439341"}
0005435243104	FDFD82	9169 621918	ANATOLIY KISELEV	{"phone": "+70248998856"}
0005435243105	FD5C4D	4461 434219	VIKTOR GUSEV	{"email": "v_gusev_21041981@postgrespro.ru", "phone": "+70889838177"}
0005435243162	B8CF80	4783 464991	DARYA FROLOVA	{"phone": "+70376035636"}
0005435243106	6958FB	8060 867626	DARYA KUZMINA	{"email": "kuzmina-d.20041966@postgrespro.ru", "phone": "+70143600613"}
0005435243107	E930B4	9409 724304	MIKHAIL SOROKIN	{"phone": "+70928824128"}
0005435243108	A95BE0	3034 123437	VERA RYABOVA	{"email": "veraryabova04121978@postgrespro.ru", "phone": "+70406543354"}
0005435243109	D95229	4169 253934	EVGENIY EGOROV	{"phone": "+70306839541"}
0005435243110	79A063	7285 048132	SERGEY YAKOVLEV	{"email": "yakovlevs_22101961@postgrespro.ru", "phone": "+70924687303"}
0005435243111	7E4829	0725 377842	DENIS BORISOV	{"email": "borisov-denis061972@postgrespro.ru", "phone": "+70129418184"}
0005435243112	7E4829	9049 932179	ALEKSANDRA PAVLOVA	{"email": "pavlova_a.1969@postgrespro.ru", "phone": "+70659902311"}
0005435243113	4F5578	1255 870439	ALEKSEY NIKOLAEV	{"email": "nikolaev-aleksey.111978@postgrespro.ru", "phone": "+70807787193"}
0005435243114	4F5578	2394 046340	RAISA RODIONOVA	{"email": "rodionova_r-20011980@postgrespro.ru", "phone": "+70148620765"}
0005435243115	4F5578	3436 235884	POLINA MELNIKOVA	{"email": "polinamelnikova.1972@postgrespro.ru", "phone": "+70119545978"}
0005435243116	37C59D	5846 625140	VYACHESLAV ALEKSEEV	{"phone": "+70835484191"}
0005435243117	AD50D0	7217 401752	DENIS ROMANOV	{"email": "dromanov16081979@postgrespro.ru", "phone": "+70836148534"}
0005435243118	AE099E	7709 353033	ALEKSANDR DAVYDOV	{"phone": "+70380139991"}
0005435243119	6B6C53	1050 019684	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov1979@postgrespro.ru", "phone": "+70044075349"}
0005435243120	85040F	8416 485619	TATYANA ZAYCEVA	{"email": "t.zayceva.13011976@postgrespro.ru", "phone": "+70868430380"}
0005435243121	50B870	5972 320902	YAROSLAVA MARTYNOVA	{"phone": "+70210471590"}
0005435243122	50B870	4826 185338	EVGENIY OSIPOV	{"phone": "+70185316609"}
0005435243123	0821B6	4083 944249	ELENA BELOVA	{"phone": "+70131199237"}
0005435243124	0821B6	1313 189321	ANZHELA FADEEVA	{"email": "anzhelafadeeva121973@postgrespro.ru", "phone": "+70592538762"}
0005435243125	B71015	5414 338046	YURIY SOKOLOV	{"email": "yuriy-sokolov_111970@postgrespro.ru", "phone": "+70005255345"}
0005435243126	EBCEBE	4114 709237	VARVARA GRISHINA	{"email": "grishina_varvara-1975@postgrespro.ru", "phone": "+70576505451"}
0005435243127	5A7A86	1150 960923	OLGA VOLKOVA	{"phone": "+70533622356"}
0005435243128	5A7A86	2254 207596	NURLAN ISAEV	{"email": "isaev.n.051975@postgrespro.ru", "phone": "+70054949479"}
0005435243129	879F78	8714 818341	SVETLANA RYABOVA	{"email": "ryabova_s_1966@postgrespro.ru", "phone": "+70047159755"}
0005435243130	C79094	8640 088403	SERGEY BORISOV	{"email": "sergey_borisov_26111973@postgrespro.ru", "phone": "+70011111360"}
0005435243131	09FF33	6824 200604	TATYANA IVANOVA	{"phone": "+70320134582"}
0005435243132	828739	7417 373011	TAMARA PAVLOVA	{"phone": "+70718051737"}
0005435243133	31B110	8084 339620	SERGEY VOLKOV	{"phone": "+70775431658"}
0005435243134	020159	6429 582141	VITALIY VOLKOV	{"email": "v-volkov1975@postgrespro.ru", "phone": "+70140658386"}
0005435243135	7CB57A	0713 739059	VLADIMIR GRIGOREV	{"email": "v_grigorev-31101963@postgrespro.ru", "phone": "+70016506174"}
0005435243136	7CB57A	3834 999312	OLEG KULIKOV	{"phone": "+70354830394"}
0005435243137	1472B0	9923 025935	ZINAIDA SCHERBAKOVA	{"phone": "+70799483219"}
0005435243138	1472B0	5748 865718	EDUARD VOLKOV	{"phone": "+70258430452"}
0005435243139	1472B0	8642 114409	ALEKSANDR MAKAROV	{"email": "makarov.aleksandr.30031978@postgrespro.ru", "phone": "+70043594239"}
0005435243140	66E19D	9782 660261	KONSTANTIN PETROV	{"email": "petrovkonstantin16011977@postgrespro.ru", "phone": "+70957900799"}
0005435243141	66E19D	2586 017597	EKATERINA PETROVA	{"email": "petrova_e_011975@postgrespro.ru", "phone": "+70155527253"}
0005435243142	66FD79	8284 436085	ANDREY SOLOVEV	{"phone": "+70455179474"}
0005435243143	66FD79	3141 160438	ANASTASIYA GUSEVA	{"phone": "+70873353636"}
0005435243144	149F1F	9929 597772	NINA ABRAMOVA	{"email": "ninaabramova.17111965@postgrespro.ru", "phone": "+70053044698"}
0005435243145	144845	3996 224236	LIDIYA NAZAROVA	{"phone": "+70887028760"}
0005435243146	144845	5134 006837	ELENA FILIPPOVA	{"phone": "+70702052371"}
0005435243147	30C0D3	9505 954680	PAVEL IVANOV	{"phone": "+70200254962"}
0005435243148	A2D23D	1552 645193	ARTEM NAZAROV	{"phone": "+70241293342"}
0005435243149	77ADBA	2843 384755	ANASTASIYA EFIMOVA	{"phone": "+70871050780"}
0005435243150	FFAA30	8077 090232	ANASTASIYA VOLKOVA	{"email": "a.volkova.24071972@postgrespro.ru", "phone": "+70136007068"}
0005435243151	485F39	9043 979910	VERA BORISOVA	{"phone": "+70564758160"}
0005435243152	485F39	3948 746909	ALEKSEY KONOVALOV	{"phone": "+70145142054"}
0005435243153	3FD3A4	1464 274490	MARINA IVANOVA	{"email": "ivanovam.1986@postgrespro.ru", "phone": "+70224053165"}
0005435243154	A0423C	8833 879688	ASKHAT KOZLOV	{"email": "a.kozlov.18091968@postgrespro.ru", "phone": "+70122454205"}
0005435243155	A0423C	7209 363839	ARINA ILINA	{"email": "a_ilina-111978@postgrespro.ru", "phone": "+70742196548"}
0005435243156	A6CED0	4426 932406	ROMAN SERGEEV	{"phone": "+70950707697"}
0005435243157	A6CED0	4633 104898	ARTEM VOROBEV	{"email": "a.vorobev-051970@postgrespro.ru", "phone": "+70763164460"}
0005435243158	003E4E	3315 169491	SERGEY POPOV	{"phone": "+70452737453"}
0005435243159	003E4E	4809 484070	OLEG SCHERBAKOV	{"phone": "+70748056973"}
0005435243160	848B56	7225 421670	VALENTINA BELYAEVA	{"phone": "+70203625461"}
0005435243161	848B56	8106 250555	ALEKSANDR STEPANOV	{"email": "aleksandr-stepanov.111981@postgrespro.ru", "phone": "+70782772370"}
0005435243163	133B0A	1811 051851	EKATERINA ZHURAVLEVA	{"email": "ekaterina-zhuravleva-02071981@postgrespro.ru", "phone": "+70419979911"}
0005435243164	F868A9	2087 018652	MIKHAIL NIKITIN	{"phone": "+70548278337"}
0005435243165	A3D733	7082 127226	SVETLANA SERGEEVA	{"phone": "+70338969665"}
0005435243166	D3E5D1	3297 578104	VALERIY IVANOV	{"phone": "+70121584613"}
0005435243167	87E20E	9523 996650	PAVEL KUZNECOV	{"email": "pavel.kuznecov-19021972@postgrespro.ru", "phone": "+70704956702"}
0005435243168	C412F7	7858 430634	LILIYA NOVIKOVA	{"phone": "+70446930986"}
0005435243169	C412F7	0699 460247	GALINA VOLKOVA	{"phone": "+70525175510"}
0005435243170	052C69	3780 887844	VERONIKA KARPOVA	{"email": "veronika-karpova.041969@postgrespro.ru", "phone": "+70698354561"}
0005435243171	052C69	1509 541788	VADIM MOISEEV	{"phone": "+70403467474"}
0005435243172	052C69	6472 165585	ALEKSEY SERGEEV	{"email": "a-sergeev_081986@postgrespro.ru", "phone": "+70949452602"}
0005435243173	498FB3	2958 235243	ALEKSANDR ISAEV	{"phone": "+70187819247"}
0005435243174	3BE864	3240 329232	DMITRIY KULIKOV	{"email": "kulikov.dmitriy091967@postgrespro.ru", "phone": "+70801367931"}
0005435243175	756346	4119 029156	ANATOLIY CHERNOV	{"phone": "+70853022786"}
0005435243176	756346	5985 429469	VALERIY IVANOV	{"email": "v_ivanov_1974@postgrespro.ru", "phone": "+70101166461"}
0005435243177	EF08D3	8359 967239	TATYANA PAVLOVA	{"email": "pavlovat.021964@postgrespro.ru", "phone": "+70219325633"}
0005435243178	98D0FC	4264 747629	OLGA MATVEEVA	{"phone": "+70149499494"}
0005435243179	98D0FC	4911 968151	MARIYA FADEEVA	{"phone": "+70781071103"}
0005435243180	F4C9C9	9740 949672	ROMAN SHEVCHENKO	{"phone": "+70315049017"}
0005435243181	D94E5F	8578 897985	GULNAZ PETROVA	{"phone": "+70471607894"}
0005435243182	999E55	9389 965020	YULIYA EGOROVA	{"email": "yuliya-egorova.101964@postgrespro.ru", "phone": "+70471503616"}
0005435243183	C0F0CF	2612 236348	OKSANA RODIONOVA	{"phone": "+70324029211"}
0005435243184	C0F0CF	7016 846022	OLEG FILIPPOV	{"email": "ofilippov-1969@postgrespro.ru", "phone": "+70017218911"}
0005435243185	965BA2	1327 348489	ALEKSANDR VOLKOV	{"email": "avolkov-021963@postgrespro.ru", "phone": "+70089798939"}
0005435243186	965BA2	1178 040493	ALEKSANDRA GUSEVA	{"email": "gusevaaleksandra_05081966@postgrespro.ru", "phone": "+70332850453"}
0005435243187	8CA9F7	9046 978043	NINA POPOVA	{"email": "popova.n.1959@postgrespro.ru", "phone": "+70845629613"}
0005435243188	8CA9F7	8886 935160	YURIY VASILEV	{"email": "vasilev_y-081973@postgrespro.ru", "phone": "+70805832349"}
0005435243189	6C69A1	5989 501498	OKSANA NOVIKOVA	{"phone": "+70591504898"}
0005435243190	C69F5F	5972 080978	ZOYA KOZLOVA	{"email": "kozlova-zoya-011980@postgrespro.ru", "phone": "+70499490089"}
0005435243191	2AD9A6	5520 066496	RAVIL IVANOV	{"phone": "+70916591863"}
0005435243192	2AD9A6	8360 435834	KSENIYA MOROZOVA	{"phone": "+70642127625"}
0005435243193	1E20EF	9490 118546	DMITRIY SERGEEV	{"email": "d_sergeev.111971@postgrespro.ru", "phone": "+70762413867"}
0005435243194	E38B13	5952 482623	MIKHAIL NAZAROV	{"phone": "+70116770235"}
0005435243195	FC9AEC	5942 572144	ZINAIDA MELNIKOVA	{"phone": "+70789515776"}
0005435243196	FC9AEC	2487 862158	VALENTIN BELOV	{"email": "valentin-belov-04081983@postgrespro.ru", "phone": "+70319926405"}
0005435243197	1A711A	9086 732222	MIKHAIL ZHURAVLEV	{"email": "m.zhuravlev12031988@postgrespro.ru", "phone": "+70780079239"}
0005435243198	1A711A	4847 367830	OLGA BELOVA	{"phone": "+70307017433"}
0005435243199	6CB8F3	8164 277601	ELENA KISELEVA	{"phone": "+70145249408"}
0005435243200	6CB8F3	4894 466478	NADEZHDA STEPANOVA	{"email": "n_stepanova05041967@postgrespro.ru", "phone": "+70341882954"}
0005435243201	5224E4	7129 624855	PELAGEYA MELNIKOVA	{"phone": "+70094151171"}
0005435243202	DD705C	6874 651291	OLEG KOZLOV	{"phone": "+70721050384"}
0005435243203	7910EE	0260 238085	EKATERINA ZAKHAROVA	{"email": "zakharovae.1972@postgrespro.ru", "phone": "+70199518291"}
0005435243204	7910EE	9620 093945	ANATOLIY STEPANOV	{"email": "anatoliy-stepanov.17121974@postgrespro.ru", "phone": "+70422392383"}
0005435243205	C2BE2F	7605 612525	PAVEL PAVLOV	{"email": "pavlov-p.021978@postgrespro.ru", "phone": "+70584737282"}
0005435243206	BDBD0C	3569 782136	EVGENIYA POLYAKOVA	{"email": "polyakovae.011973@postgrespro.ru", "phone": "+70826136917"}
0005435243207	EF8F90	4472 849519	VALENTINA IVANOVA	{"email": "valentinaivanova-111966@postgrespro.ru", "phone": "+70083418392"}
0005435243208	EF8F90	9549 285748	YURIY MATVEEV	{"email": "matveevyuriy.081982@postgrespro.ru", "phone": "+70578259180"}
0005435243209	802547	6487 874180	DAVID EGOROV	{"email": "egorov_david1975@postgrespro.ru", "phone": "+70914757344"}
0005435243210	BE5338	0490 229608	ELENA DANILOVA	{"email": "elena.danilova-111975@postgrespro.ru", "phone": "+70274754058"}
0005435243211	14D912	7258 295827	ALEKSANDR GAVRILOV	{"phone": "+70648983827"}
0005435243212	14D912	2268 190685	ANNA OSIPOVA	{"phone": "+70084525669"}
0005435243213	629B68	4027 164395	VIKTOR KUZMIN	{"phone": "+70583035621"}
0005435243214	8795DF	4419 668146	ANATOLIY ALEKSEEV	{"phone": "+70940355281"}
0005435243215	91F5BC	0011 100567	LYUDMILA DENISOVA	{"email": "denisova.lyudmila1978@postgrespro.ru", "phone": "+70876428771"}
0005435243216	14A5CF	4920 515735	ANASTASIYA POPOVA	{"phone": "+70829371407"}
0005435243217	3EEA2E	1550 093535	NINA FILATOVA	{"email": "n.filatova_20121964@postgrespro.ru", "phone": "+70696920540"}
0005435243218	3EEA2E	9946 021324	KAMIL GRIGOREV	{"email": "kamil-grigorev_091970@postgrespro.ru", "phone": "+70660154375"}
0005435243219	3EEA2E	6190 099841	LEV KUZNECOV	{"email": "l_kuznecov23031973@postgrespro.ru", "phone": "+70947283016"}
0005435243220	67DB4A	5137 790491	YURIY SOROKIN	{"phone": "+70791434657"}
0005435243221	754ACE	1339 714070	ANDREY FOMIN	{"email": "fomin-andrey_01101968@postgrespro.ru", "phone": "+70985024404"}
0005435243222	754ACE	9050 800821	ANTONINA ZOTOVA	{"email": "zotovaantonina-1964@postgrespro.ru", "phone": "+70657159791"}
0005435243223	790F94	6117 668856	YULIYA ZOTOVA	{"email": "yzotova061969@postgrespro.ru", "phone": "+70533663703"}
0005435243224	790F94	3943 499461	LILIYA NIKITINA	{"phone": "+70597807050"}
0005435243225	AAA409	1365 868288	VLADIMIR NIKITIN	{"phone": "+70522103699"}
0005435243226	AAA409	9747 654130	SERGEY KARPOV	{"email": "karpov_sergey-05021970@postgrespro.ru", "phone": "+70035906991"}
0005435243227	C5DB90	6886 628220	OLGA MIRONOVA	{"phone": "+70084679898"}
0005435243228	C5DB90	4222 006340	NADEZHDA TITOVA	{"phone": "+70046737794"}
0005435243229	594022	2937 203759	NINA BORISOVA	{"email": "borisova_nina021976@postgrespro.ru", "phone": "+70433835187"}
0005435243230	594022	6791 391181	VIKTORIYA SCHERBAKOVA	{"email": "v-scherbakova13081980@postgrespro.ru", "phone": "+70376709367"}
0005435243231	0091C5	7750 295839	YURIY DENISOV	{"email": "ydenisov28061978@postgrespro.ru", "phone": "+70167624085"}
0005435243232	BEB780	8652 362135	NIKITA MELNIKOV	{"phone": "+70648820460"}
0005435243233	BEB780	3274 564085	TATYANA PAVLOVA	{"email": "pavlova.t-091969@postgrespro.ru", "phone": "+70127628831"}
0005435243234	851B8F	7340 608409	ROZA BELOVA	{"email": "belova.r.1982@postgrespro.ru", "phone": "+70130251383"}
0005435243235	A34FD9	6595 824439	TATYANA AKIMOVA	{"email": "akimova-tatyana-1969@postgrespro.ru", "phone": "+70903041593"}
0005435243236	A34FD9	7431 122589	MIKHAIL VOLKOV	{"email": "volkov_mikhail051963@postgrespro.ru", "phone": "+70385778101"}
0005435243237	A34FD9	8386 314872	ALEKSANDR ALEKSEEV	{"phone": "+70658521079"}
0005435243238	94E365	2137 503089	EKATERINA SIDOROVA	{"email": "e.sidorova.18061970@postgrespro.ru", "phone": "+70649026009"}
0005435243239	D0859A	0830 902344	VLADIMIR ZAYCEV	{"email": "zaycevvladimir.011976@postgrespro.ru", "phone": "+70345820919"}
0005435243240	D7496C	0831 816891	NADEZHDA NESTEROVA	{"email": "nadezhda-nesterova-011984@postgrespro.ru", "phone": "+70600744344"}
0005435243241	D7496C	8151 116976	ARTEM GRIGOREV	{"email": "grigorev.a.03011970@postgrespro.ru", "phone": "+70035789080"}
0005435243242	D7496C	1335 344273	POLINA VOROBEVA	{"email": "polina.vorobeva_121976@postgrespro.ru", "phone": "+70875725342"}
0005435243243	47F654	9511 163130	MIKHAIL KISELEV	{"phone": "+70127850232"}
0005435243244	47F654	2251 992551	ZLATA NIKIFOROVA	{"phone": "+70530817753"}
0005435243245	9E9D56	7489 943998	VALENTINA NIKITINA	{"email": "valentina_nikitina1974@postgrespro.ru", "phone": "+70871119952"}
0005435243246	9E9D56	1799 988348	YURIY KOROLEV	{"email": "yuriy_korolev1966@postgrespro.ru", "phone": "+70947859572"}
0005435243247	420383	1197 146683	ALEKSANDR NAUMOV	{"email": "naumov.aleksandr.1974@postgrespro.ru", "phone": "+70397940897"}
0005435243248	8B0935	2401 415272	ELENA FILIPPOVA	{"email": "filippova.e.071979@postgrespro.ru", "phone": "+70238595641"}
0005435243249	74E529	2857 575720	VALENTINA MIRONOVA	{"phone": "+70451446624"}
0005435243250	74E529	2958 888342	LYUBOV VOROBEVA	{"phone": "+70434241295"}
0005435243251	74E529	4053 915535	NONNA ROMANOVA	{"phone": "+70754471617"}
0005435243252	7DBA13	3955 662344	NINA NIKOLAEVA	{"email": "nikolaeva-nina_1975@postgrespro.ru", "phone": "+70377601096"}
0005435243253	786197	7295 454451	SERGEY NIKITIN	{"phone": "+70379692528"}
0005435243254	71331E	4855 125535	OLGA FILATOVA	{"phone": "+70898075813"}
0005435243255	21F5D9	1078 958777	SVETLANA GRISHINA	{"email": "grishina-svetlana.041980@postgrespro.ru", "phone": "+70825257484"}
0005435243256	21F5D9	1645 652168	OLGA KUZNECOVA	{"email": "o_kuznecova.26051968@postgrespro.ru", "phone": "+70232671758"}
0005435243257	786D8A	3038 440162	ANTONINA VOLKOVA	{"email": "a_volkova-28111979@postgrespro.ru", "phone": "+70330496295"}
0005435243258	D33A16	9201 950258	IVAN ABRAMOV	{"email": "ivan.abramov_081978@postgrespro.ru", "phone": "+70855952665"}
0005435243259	3664EF	0943 313018	EKATERINA SERGEEVA	{"email": "sergeeva-ekaterina_021981@postgrespro.ru", "phone": "+70308124439"}
0005435243260	804127	6888 286623	SERGEY ANDREEV	{"email": "andreev_s_051960@postgrespro.ru", "phone": "+70407975190"}
0005435243261	6EF79E	4426 912170	YULIYA KOVALEVA	{"phone": "+70994877228"}
0005435243379	12E20F	0533 078432	EVGENIY IVANOV	{"phone": "+70584183129"}
0005435243262	B05BCE	6276 521914	NATALYA SMIRNOVA	{"email": "smirnova.natalya-1962@postgrespro.ru", "phone": "+70714241619"}
0005435243263	B05BCE	9889 003208	NATALYA KOLESNIKOVA	{"email": "natalya.kolesnikova_28081972@postgrespro.ru", "phone": "+70825247531"}
0005435243264	75B130	1061 326049	ARSENIY ANDREEV	{"email": "andreev_a_25051970@postgrespro.ru", "phone": "+70393425785"}
0005435243265	75B130	0266 515332	EGOR POPOV	{"phone": "+70520381527"}
0005435243266	87D212	8994 318273	YULIYA KOZLOVA	{"email": "y_kozlova-101968@postgrespro.ru", "phone": "+70440069742"}
0005435243267	D05760	3953 515679	VLADIMIR KAZAKOV	{"phone": "+70483142357"}
0005435243268	8280D9	5007 938518	VALERIYA MIRONOVA	{"email": "mironova-v_101978@postgrespro.ru", "phone": "+70035566113"}
0005435243269	814A37	6507 472763	ANTONINA KAZAKOVA	{"phone": "+70894949482"}
0005435243270	814A37	3581 074868	NADEZHDA SOLOVEVA	{"email": "n.soloveva.041973@postgrespro.ru", "phone": "+70586842553"}
0005435243271	C4572A	2360 248737	LYUDMILA TITOVA	{"email": "titovalyudmila.1977@postgrespro.ru", "phone": "+70837928881"}
0005435243272	0B5AB1	7391 911494	MARIYA RYABOVA	{"email": "mariya_ryabova26101960@postgrespro.ru", "phone": "+70551777772"}
0005435243384	95CBFB	1807 769320	VLADIMIR PETROV	{"phone": "+70669207005"}
0005435243273	434E4A	7198 251308	SAVELIY KUZNECOV	{"email": "kuznecov.s17011966@postgrespro.ru", "phone": "+70018515041"}
0005435243274	012D3D	4556 418626	GENNADIY GUSEV	{"email": "g.gusev.071978@postgrespro.ru", "phone": "+70677711093"}
0005435243275	22EFEF	3569 016213	LILIYA TARASOVA	{"phone": "+70291377464"}
0005435243276	22EFEF	6639 997923	NINA IVANOVA	{"email": "nina.ivanova.071972@postgrespro.ru", "phone": "+70373640329"}
0005435243277	208CAE	1317 352057	EVGENIY STEPANOV	{"email": "e_stepanov-09101979@postgrespro.ru", "phone": "+70986691377"}
0005435243278	2B75A4	2724 732130	SVETLANA PETROVA	{"phone": "+70060632824"}
0005435243279	2B75A4	7870 820059	OLGA SOLOVEVA	{"email": "olga_soloveva1981@postgrespro.ru", "phone": "+70178116831"}
0005435243280	C0B22A	1855 943018	MIKHAIL SOKOLOV	{"phone": "+70035448605"}
0005435243281	C0B22A	2767 090780	LIDIYA MALYSHEVA	{"phone": "+70010486221"}
0005435243282	83D70A	0401 635464	VYACHESLAV BARANOV	{"phone": "+70487625309"}
0005435243283	B1939C	1900 047569	NIKOLAY GAVRILOV	{"phone": "+70438688139"}
0005435243284	0E1D66	5026 359518	NINA TIKHONOVA	{"phone": "+70477518508"}
0005435243285	8C310E	1789 350497	SERGEY ALEKSEEV	{"email": "alekseev.sergey29111975@postgrespro.ru", "phone": "+70348995220"}
0005435243286	8DAE30	3737 635493	KSENIYA IVANOVA	{"phone": "+70205835421"}
0005435243287	0E15F9	9186 069254	DIANA MASLOVA	{"phone": "+70526593524"}
0005435243288	1B5360	0759 289902	ALEKSANDR BARANOV	{"phone": "+70351093744"}
0005435243289	C349B5	4303 154598	OLGA MIKHAYLOVA	{"email": "mikhaylova.o-21041978@postgrespro.ru", "phone": "+70048962296"}
0005435243290	4EB215	8616 326650	NADEZHDA YAKOVLEVA	{"email": "nadezhdayakovleva18081972@postgrespro.ru", "phone": "+70467973136"}
0005435243291	F727FD	0134 319049	ANASTASIYA POLYAKOVA	{"phone": "+70884443020"}
0005435243292	97D2FC	5123 597444	EKATERINA NIKOLAEVA	{"phone": "+70379563612"}
0005435243293	6FB215	0763 681114	ELENA GUSEVA	{"phone": "+70888384171"}
0005435243294	EB7580	5009 120097	ALEKSANDRA NESTEROVA	{"phone": "+70522741213"}
0005435243295	EB7580	3189 862840	MAKSIM VOLKOV	{"phone": "+70458667960"}
0005435243296	BEEAC0	6312 485197	VLADIMIR KUZNECOV	{"email": "kuznecovvladimir-1975@postgrespro.ru", "phone": "+70628551103"}
0005435243297	407BE0	3697 660627	ELENA ERMAKOVA	{"phone": "+70154191124"}
0005435243298	2DE5FF	0464 317137	IVAN IVANOV	{"email": "ivanovivan.041976@postgrespro.ru", "phone": "+70537956636"}
0005435243299	E9F90B	7915 247755	TATYANA PETROVA	{"email": "petrova_t.27031967@postgrespro.ru", "phone": "+70221053304"}
0005435243300	E9F90B	4759 489048	SNEZHANA GRISHINA	{"email": "grishina-s_27011967@postgrespro.ru", "phone": "+70910726793"}
0005435243301	E9F90B	9373 486737	ALEKSANDR ZAKHAROV	{"email": "zakharov.a-1969@postgrespro.ru", "phone": "+70691729215"}
0005435243302	5E9697	1882 033276	TATYANA ZHUKOVA	{"email": "zhukova_tatyana1962@postgrespro.ru", "phone": "+70333550459"}
0005435243303	5E9697	1042 246974	SERGEY OSIPOV	{"email": "osipovsergey_121967@postgrespro.ru", "phone": "+70200528810"}
0005435243304	A3DAC0	8523 098304	VLADIMIR SOKOLOV	{"phone": "+70911416144"}
0005435243305	A3DAC0	8960 091009	MIKHAIL SOLOVEV	{"phone": "+70682432593"}
0005435243306	9D6915	0727 552914	VADIM IVANOV	{"phone": "+70694708814"}
0005435243307	707930	0242 740887	TATYANA IVANOVA	{"phone": "+70201318963"}
0005435243308	03813E	0411 475270	IRINA BELYAEVA	{"email": "belyaeva_i.051974@postgrespro.ru", "phone": "+70281223810"}
0005435243309	2BD67B	4202 264029	ALEKSANDRA DMITRIEVA	{"phone": "+70283641700"}
0005435243310	DA5E46	6372 000757	ANNA MAKSIMOVA	{"phone": "+70819511437"}
0005435243311	DA5E46	2123 079603	VLADIMIR NIKOLAEV	{"phone": "+70569378699"}
0005435243312	D1C0AE	7716 107128	ELENA TIKHONOVA	{"email": "e.tikhonova.17081967@postgrespro.ru", "phone": "+70681848377"}
0005435243313	D1C0AE	7378 499820	NATALYA FILIPPOVA	{"phone": "+70755450301"}
0005435243314	E1CE85	2915 053232	SVETLANA NAUMOVA	{"email": "naumovasvetlana011965@postgrespro.ru", "phone": "+70824475887"}
0005435243315	B5C9C7	9092 824196	ALEKSEY NAZAROV	{"email": "nazarov.aleksey_1981@postgrespro.ru", "phone": "+70688964286"}
0005435243316	B5C9C7	7517 581255	OLGA GERASIMOVA	{"phone": "+70286558270"}
0005435243317	B5C9C7	5595 802998	GALINA SMIRNOVA	{"email": "g-smirnova1971@postgrespro.ru", "phone": "+70296124812"}
0005435243318	FDA975	5949 294427	TATYANA ANDREEVA	{"phone": "+70991220717"}
0005435243319	ABDB0B	7767 024450	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a.011982@postgrespro.ru", "phone": "+70274090564"}
0005435243320	ABDB0B	0822 198539	IGOR PETROV	{"phone": "+70802154033"}
0005435243321	ABDB0B	5294 719342	NADEZHDA DAVYDOVA	{"email": "davydova.nadezhda1979@postgrespro.ru", "phone": "+70726966121"}
0005435243322	A8E647	5080 715852	PAVEL SERGEEV	{"email": "pavel_sergeev.05121981@postgrespro.ru", "phone": "+70192809227"}
0005435243323	98209E	4697 922078	IGOR KOZLOV	{"email": "kozlov.igor13011974@postgrespro.ru", "phone": "+70390479010"}
0005435243324	98209E	5233 958333	VALERIY VOROBEV	{"phone": "+70455758464"}
0005435243325	8634AB	1564 444069	ALEKSANDR ZAKHAROV	{"email": "zakharovaleksandr.1970@postgrespro.ru", "phone": "+70539442790"}
0005435243326	90C64B	6803 293579	OLGA KUZMINA	{"email": "kuzmina_o.15041982@postgrespro.ru", "phone": "+70406180790"}
0005435243327	8784F2	6563 716012	SERGEY KISELEV	{"phone": "+70450404069"}
0005435243328	77FE8E	9517 612690	DARYA POTAPOVA	{"phone": "+70896076550"}
0005435243385	7EB461	0560 378073	MAKSIM SIDOROV	{"phone": "+70943341641"}
0005435243329	1E23BA	6617 751467	LYUDMILA LEBEDEVA	{"email": "lebedeva.l_02071978@postgrespro.ru", "phone": "+70041383434"}
0005435243330	70EACE	2937 043058	ALEKSEY SOLOVEV	{"email": "aleksey.solovev-1977@postgrespro.ru", "phone": "+70930701922"}
0005435243331	39C604	9513 715374	FARIT ABRAMOV	{"email": "faritabramov1972@postgrespro.ru", "phone": "+70978257347"}
0005435243332	C45F51	6293 774424	RAIS ANDREEV	{"email": "r-andreev_111986@postgrespro.ru", "phone": "+70779828311"}
0005435243333	C45F51	8744 962037	VASILIY MOISEEV	{"email": "moiseev.v_26091974@postgrespro.ru", "phone": "+70012465121"}
0005435243334	47E470	5844 989351	ANATOLIY NIKITIN	{"email": "nikitin.a-1973@postgrespro.ru", "phone": "+70361840958"}
0005435243335	1093CB	4795 572084	YULIYA YAKOVLEVA	{"email": "yuliya.yakovleva1977@postgrespro.ru", "phone": "+70612457086"}
0005435243336	D3596E	4648 650905	MIKHAIL CHERNOV	{"email": "chernov.mikhail031965@postgrespro.ru", "phone": "+70690433341"}
0005435243337	D3596E	5054 844107	VITALIY AFANASEV	{"phone": "+70408655413"}
0005435243338	7A00FC	6868 041270	PETR SOKOLOV	{"phone": "+70047994650"}
0005435243339	E1D31F	9274 427948	LIDIYA KUZNECOVA	{"email": "lidiya.kuznecova_06041969@postgrespro.ru", "phone": "+70685413323"}
0005435243340	1BAB16	6117 826345	MARIYA GRISHINA	{"phone": "+70240340456"}
0005435243341	1BAB16	1145 309570	LYUDMILA MARTYNOVA	{"email": "lyudmila.martynova1970@postgrespro.ru", "phone": "+70881062644"}
0005435243342	845F42	2234 326854	NINA ALEKSEEVA	{"phone": "+70505116114"}
0005435243343	845F42	3532 600683	VADIM ZHUKOV	{"email": "zhukovv_1976@postgrespro.ru", "phone": "+70403796251"}
0005435243344	7C466C	6748 114872	VLADIMIR AFANASEV	{"email": "afanasevv-28011966@postgrespro.ru", "phone": "+70867040520"}
0005435243345	F4EF5F	3529 603012	RIMMA IVANOVA	{"phone": "+70244701067"}
0005435243346	723C70	7244 094584	MAKSIM EGOROV	{"email": "egorov-maksim_05101972@postgrespro.ru", "phone": "+70348830081"}
0005435243347	376524	1875 585689	NATALYA KUZMINA	{"email": "n.kuzmina_16061976@postgrespro.ru", "phone": "+70230178404"}
0005435243348	9C2182	2065 193376	TAMARA SCHERBAKOVA	{"email": "scherbakova.t.14081976@postgrespro.ru", "phone": "+70802313084"}
0005435243349	9C2182	3769 591382	IVAN KAZAKOV	{"phone": "+70406646454"}
0005435243350	728357	2816 842469	NATALYA DAVYDOVA	{"email": "natalya-davydova_121959@postgrespro.ru", "phone": "+70610685491"}
0005435243351	A991D3	3643 718864	DANIIL IVANOV	{"email": "daniilivanov_01071987@postgrespro.ru", "phone": "+70054652502"}
0005435243352	A991D3	1801 945912	YULIYA NOVIKOVA	{"phone": "+70700729824"}
0005435243353	AA5DBA	5450 918054	NATALYA NESTEROVA	{"email": "nesterovanatalya_07031965@postgrespro.ru", "phone": "+70192666857"}
0005435243354	AA5DBA	4099 634921	NINA MASLOVA	{"phone": "+70400143121"}
0005435243355	AA5DBA	5053 134816	ANTONINA VLASOVA	{"phone": "+70989131848"}
0005435243356	7880A5	1393 038949	VITALIY GAVRILOV	{"email": "vgavrilov.1974@postgrespro.ru", "phone": "+70097317772"}
0005435243357	A22332	5337 252354	YURIY KULIKOV	{"email": "yuriy-kulikov-1976@postgrespro.ru", "phone": "+70969421988"}
0005435243358	FB8118	2719 444486	NIKOLAY GRIGOREV	{"email": "n.grigorev-1960@postgrespro.ru", "phone": "+70407922407"}
0005435243359	403E5A	3488 358318	SVETLANA AKIMOVA	{"phone": "+70422512439"}
0005435243360	403E5A	4789 235670	EVGENIY ZAKHAROV	{"email": "zakharov.evgeniy-1977@postgrespro.ru", "phone": "+70002248552"}
0005435243361	403E5A	8252 778004	NATALYA CHERNOVA	{"email": "natalya-chernova1989@postgrespro.ru", "phone": "+70422168279"}
0005435243362	7942C5	1291 366659	VYACHESLAV FEDOROV	{"email": "v.fedorov_041982@postgrespro.ru", "phone": "+70295765596"}
0005435243363	E5DC7F	1097 408426	RAZIYA MAKAROVA	{"email": "makarova-r_1964@postgrespro.ru", "phone": "+70584360239"}
0005435243364	855606	3934 451408	ILYA PAVLOV	{"email": "i_pavlov_051973@postgrespro.ru", "phone": "+70324838217"}
0005435243365	2621AC	7508 850550	ALEKSEY KULIKOV	{"phone": "+70742935963"}
0005435243366	2EA007	7897 549016	TATYANA SOROKINA	{"phone": "+70736496603"}
0005435243367	2EA007	3735 046973	YULIYA STEPANOVA	{"phone": "+70731188117"}
0005435243368	0B494D	7134 140989	LYUDMILA EFIMOVA	{"email": "lyudmila_efimova_1963@postgrespro.ru", "phone": "+70070935844"}
0005435243369	DDA37A	0803 597441	EVGENIY MOROZOV	{"email": "morozov.evgeniy071968@postgrespro.ru", "phone": "+70926430352"}
0005435243370	DB3CA2	5253 225377	ELENA KRASNOVA	{"phone": "+70519810133"}
0005435243371	DB3CA2	1133 661908	EKATERINA MARTYNOVA	{"phone": "+70011906147"}
0005435243372	C563F5	2638 509713	IRINA OSIPOVA	{"email": "irina-osipova01061969@postgrespro.ru", "phone": "+70637366530"}
0005435243373	C563F5	5173 673297	NATALYA KOVALEVA	{"email": "kovaleva-n24051970@postgrespro.ru", "phone": "+70199936267"}
0005435243374	FAA173	9480 134833	ANASTASIYA LEBEDEVA	{"phone": "+70870449010"}
0005435243375	FAA173	7207 269353	NATALYA ILINA	{"email": "natalya.ilina101971@postgrespro.ru", "phone": "+70967046820"}
0005435243376	FAA173	4224 579132	DMITRIY PETROV	{"email": "d_petrov061971@postgrespro.ru", "phone": "+70185756990"}
0005435243377	C6C781	3124 700808	MARINA LOGINOVA	{"phone": "+70200582718"}
0005435243378	45B693	7996 243722	ELENA KOLESNIKOVA	{"email": "elena-kolesnikova071976@postgrespro.ru", "phone": "+70357358299"}
0005435243380	12E20F	1744 000446	IVAN IVANOV	{"phone": "+70721828326"}
0005435243381	99162E	2613 240457	KIRILL MIKHAYLOV	{"phone": "+70745121594"}
0005435243382	5302F9	1361 287871	NADEZHDA KUZMINA	{"email": "kuzmina-nadezhda22111961@postgrespro.ru", "phone": "+70230242955"}
0005435243383	0F8AB3	0128 376450	ALEVTINA VASILEVA	{"email": "vasileva.alevtina.04071986@postgrespro.ru", "phone": "+70788951207"}
0005435243386	7EB461	1735 816430	TATYANA BELOVA	{"email": "belova_tatyana-021978@postgrespro.ru", "phone": "+70934700080"}
0005435243387	2D3E97	6033 919926	DMITRIY NAZAROV	{"email": "dmitriy.nazarov-09031972@postgrespro.ru", "phone": "+70401639419"}
0005435243388	2D3E97	5235 114959	LYUDMILA RYABOVA	{"phone": "+70944914597"}
0005435243389	2C4567	1840 446867	ELENA ANTONOVA	{"email": "elenaantonova_1975@postgrespro.ru", "phone": "+70853341876"}
0005435243390	48DBE2	6435 287879	YURIY ALEKSEEV	{"phone": "+70887335349"}
0005435243391	B8F634	8318 278865	GENNADIY TIKHONOV	{"phone": "+70086112315"}
0005435243392	E1A0F4	4322 891564	VIKTOR ROMANOV	{"email": "romanovv-28091968@postgrespro.ru", "phone": "+70791531822"}
0005435243393	E1A0F4	2354 788274	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr051979@postgrespro.ru", "phone": "+70006257318"}
0005435243394	4FC407	4173 308971	OLGA ZHUKOVA	{"email": "zhukova-o.1972@postgrespro.ru", "phone": "+70876406996"}
0005435243395	4FC407	3981 305042	VALENTINA VOLKOVA	{"email": "volkova-v_091973@postgrespro.ru", "phone": "+70067571852"}
0005435243396	298FD0	1738 723746	OLGA BELOVA	{"email": "belova.o021970@postgrespro.ru", "phone": "+70307459008"}
0005435243397	298FD0	2844 105734	ALEKSANDR ZAYCEV	{"phone": "+70700418484"}
0005435243398	DBF763	7393 570118	DARYA RYABOVA	{"email": "darya_ryabova-121977@postgrespro.ru", "phone": "+70528281620"}
0005435243399	8D136A	6799 159164	SOFIYA PETROVA	{"phone": "+70229708600"}
0005435243400	0B9100	0914 401095	LIDIYA MELNIKOVA	{"phone": "+70573751732"}
0005435243401	3B6D58	0396 985998	ANNA DENISOVA	{"email": "anna_denisova_111969@postgrespro.ru", "phone": "+70831383237"}
0005435243402	3B6D58	3324 587706	VIKTOR KUDRYASHOV	{"email": "kudryashov_viktor_111968@postgrespro.ru", "phone": "+70264934683"}
0005435243403	5EC0F7	5125 596603	RAISA NAZAROVA	{"phone": "+70322413571"}
0005435243404	5EC0F7	2670 431581	TATYANA SMIRNOVA	{"email": "tsmirnova_041981@postgrespro.ru", "phone": "+70437424182"}
0005435243405	C17E0F	1806 293615	VERA IVANOVA	{"email": "v.ivanova-061980@postgrespro.ru", "phone": "+70764838846"}
0005435243406	6E05C1	0428 925136	OKSANA ALEKSEEVA	{"email": "oksana-alekseeva_01091967@postgrespro.ru", "phone": "+70915107794"}
0005435243407	DAC9C8	8951 756835	ALEKSEY ANTONOV	{"phone": "+70574571492"}
0005435243408	DAC9C8	1240 937264	VALENTIN KUZNECOV	{"email": "valentin.kuznecov_1976@postgrespro.ru", "phone": "+70766083062"}
0005435243409	DAC9C8	2453 473060	KSENIYA KOZLOVA	{"phone": "+70577525221"}
0005435243410	A0A3D6	8964 755861	EVGENIY GORBUNOV	{"phone": "+70633162790"}
0005435243411	ACCB9F	8544 186482	OLESYA ZHUKOVA	{"email": "zhukovaolesya.1970@postgrespro.ru", "phone": "+70887454903"}
0005435243412	665109	3018 891752	MAKSIM ZHURAVLEV	{"email": "maksim-zhuravlev-1977@postgrespro.ru", "phone": "+70203553955"}
0005435243413	665109	0919 894460	ANDREY TIKHONOV	{"email": "tikhonova-041979@postgrespro.ru", "phone": "+70034716176"}
0005435243414	665109	4737 951687	SEMEN BONDARENKO	{"email": "s.bondarenko12091964@postgrespro.ru", "phone": "+70642630891"}
0005435243415	E814F3	1423 701622	VALENTINA STEPANOVA	{"phone": "+70607685402"}
0005435243416	E814F3	4254 863931	ANTONINA STEPANOVA	{"email": "antonina-stepanova.12081985@postgrespro.ru", "phone": "+70335892054"}
0005435243417	FBEFD2	0919 298680	VALENTINA EFREMOVA	{"email": "efremova_v1969@postgrespro.ru", "phone": "+70037029912"}
0005435243418	FE7ED8	5185 722835	IGOR KUZNECOV	{"phone": "+70296655285"}
0005435243419	EB527C	6839 515796	VERONIKA MEDVEDEVA	{"email": "medvedevav.041976@postgrespro.ru", "phone": "+70501456352"}
0005435243420	B0B9DD	1555 999395	VITALIY NAZAROV	{"phone": "+70360884130"}
0005435243421	7709D3	2862 653747	MARIYA KONDRATEVA	{"phone": "+70617706010"}
0005435243422	7709D3	2293 479655	DENIS SMIRNOV	{"email": "d_smirnov_1973@postgrespro.ru", "phone": "+70889451502"}
0005435243423	7709D3	5019 315275	SERGEY GERASIMOV	{"email": "s_gerasimov.071989@postgrespro.ru", "phone": "+70239634987"}
0005435243424	FC108E	5780 649504	ROMAN FROLOV	{"email": "r_frolov1974@postgrespro.ru", "phone": "+70420682868"}
0005435243425	97CC71	1440 479218	DMITRIY MATVEEV	{"phone": "+70978359058"}
0005435243426	7C6B4A	1872 398515	ALFIYA SEMENOVA	{"email": "semenova-alfiya.081969@postgrespro.ru", "phone": "+70652354533"}
0005435243427	7C6B4A	5844 535202	TAISIYA MEDVEDEVA	{"email": "t_medvedeva28081970@postgrespro.ru", "phone": "+70768699277"}
0005435243428	9277F0	4094 807584	ALEKSANDR MIKHAYLOV	{"email": "mikhaylovaleksandr.20011970@postgrespro.ru", "phone": "+70328086297"}
0005435243429	229B5A	8852 577569	VLADIMIR DAVYDOV	{"phone": "+70275427360"}
0005435243430	229B5A	7643 643662	OLGA CHERNOVA	{"email": "chernovao_101980@postgrespro.ru", "phone": "+70736707648"}
0005435243431	963263	5543 341200	ANDREY VOLKOV	{"email": "a_volkov1972@postgrespro.ru", "phone": "+70547785440"}
0005435243432	997688	9711 356889	LYUDMILA EFREMOVA	{"phone": "+70889165521"}
0005435243433	13B90F	3954 594342	LYUBOV ALEKSEEVA	{"phone": "+70039011357"}
0005435243434	DC7F62	2238 582393	VENERA SOKOLOVA	{"email": "sokolova_v_041967@postgrespro.ru", "phone": "+70022674457"}
0005435243435	DC7F62	6657 706314	ANTONINA MATVEEVA	{"phone": "+70085469778"}
0005435243436	28FD2C	1041 036939	NATALYA RYABOVA	{"phone": "+70706627905"}
0005435243437	DC97DE	4548 663139	ALEKSANDR STEPANOV	{"phone": "+70035157080"}
0005435243438	DC97DE	0095 563298	TATYANA GERASIMOVA	{"email": "tatyana-gerasimova_1970@postgrespro.ru", "phone": "+70976446569"}
0005435243439	DC97DE	9037 187710	YULIYA IVANOVA	{"email": "yivanova-1959@postgrespro.ru", "phone": "+70543613065"}
0005435243440	D0C373	8225 325020	SVETLANA NESTEROVA	{"phone": "+70316729538"}
0005435243441	D0C373	1271 844051	IVAN ANDREEV	{"email": "andreev.i-091951@postgrespro.ru", "phone": "+70869127702"}
0005435243442	A2166F	9123 071607	DANILA KISELEV	{"email": "kiselevd.11071960@postgrespro.ru", "phone": "+70890986774"}
0005435243443	B76853	1435 848504	VLADIMIR GRIGOREV	{"phone": "+70726461280"}
0005435243444	719DB9	1722 100171	OKSANA KARPOVA	{"email": "karpova.oksana.30011982@postgrespro.ru", "phone": "+70405345004"}
0005435243445	EA56FD	5097 870804	SERGEY MOROZOV	{"email": "s-morozov091976@postgrespro.ru", "phone": "+70880483956"}
0005435243446	69E6E9	2663 173704	ILYA ANDREEV	{"email": "andreevi17011974@postgrespro.ru", "phone": "+70006044862"}
0005435243447	69E6E9	6620 964981	ALEKSEY FEDOROV	{"email": "fedorov_a_1952@postgrespro.ru", "phone": "+70456115991"}
0005435243448	B83143	7224 073312	VERA POLYAKOVA	{"email": "polyakova_vera1964@postgrespro.ru", "phone": "+70802943508"}
0005435243449	B83143	2252 583866	GALINA ALEKSEEVA	{"phone": "+70920950255"}
0005435243450	51C392	9473 430264	VLADIMIR FEDOTOV	{"phone": "+70352975546"}
0005435243451	92566E	2711 382674	VLADIMIR KRASNOV	{"phone": "+70352149217"}
0005435243452	7A53BF	0094 069428	POLINA POPOVA	{"email": "p_popova13021973@postgrespro.ru", "phone": "+70840687711"}
0005435243453	7A53BF	8577 332202	ALEKSEY FEDOROV	{"email": "aleksey.fedorov.01021973@postgrespro.ru", "phone": "+70447643604"}
0005435243454	4C7D6C	4936 266245	MARINA GORBUNOVA	{"phone": "+70251824166"}
0005435243455	4C7D6C	3609 445165	OLGA BOGDANOVA	{"email": "bogdanova-o-1975@postgrespro.ru", "phone": "+70586214165"}
0005435243456	3F19D2	5767 032419	ALEKSEY KULIKOV	{"phone": "+70851496527"}
0005435243457	375BC4	9014 280752	ROMAN KULIKOV	{"email": "roman_kulikov_24061980@postgrespro.ru", "phone": "+70653494238"}
0005435243458	375BC4	3513 238857	ANNA KONOVALOVA	{"phone": "+70729852202"}
0005435243459	74F167	4055 292629	ARTEM BONDARENKO	{"email": "bondarenko.a-041965@postgrespro.ru", "phone": "+70500910484"}
0005435243460	74F167	6699 843072	KAMIL GERASIMOV	{"phone": "+70525525720"}
0005435243461	02DEF1	3143 019163	VLADIMIR SCHERBAKOV	{"phone": "+70896458411"}
0005435243462	02DEF1	7636 626105	IRINA LUKYANOVA	{"email": "lukyanovai.111976@postgrespro.ru", "phone": "+70392942969"}
0005435243463	5218FF	0450 202341	PAVEL STEPANOV	{"phone": "+70393652781"}
0005435243464	5218FF	5061 687543	TATYANA EGOROVA	{"email": "tatyana.egorova101975@postgrespro.ru", "phone": "+70543875700"}
0005435243465	4462ED	5565 374598	OLGA ZHUKOVA	{"phone": "+70726703447"}
0005435243466	4462ED	8168 787520	VALERIY MAKAROV	{"email": "valeriy-makarov_1965@postgrespro.ru", "phone": "+70954856181"}
0005435243467	FAAE42	1928 777080	MARIYA DMITRIEVA	{"email": "dmitrieva.m-101958@postgrespro.ru", "phone": "+70108554534"}
0005435243468	FAAE42	2620 988306	TAMARA OSIPOVA	{"email": "tosipova_1959@postgrespro.ru", "phone": "+70950946275"}
0005435243469	4ACCDE	6113 885259	TATYANA SMIRNOVA	{"phone": "+70690430846"}
0005435243470	4ACCDE	0420 432256	NATALYA ANDREEVA	{"email": "andreeva.natalya1969@postgrespro.ru", "phone": "+70952406234"}
0005435243471	4F25D4	3332 823515	VLADIMIR DMITRIEV	{"email": "dmitriev-vladimir.101981@postgrespro.ru", "phone": "+70069912455"}
0005435243472	4F25D4	8656 621560	MIKHAIL FEDOROV	{"phone": "+70574191096"}
0005435243473	41EE35	9125 310847	NATALYA NAUMOVA	{"email": "n.naumova.031973@postgrespro.ru", "phone": "+70916952743"}
0005435243474	41EE35	6394 699286	EKATERINA NESTEROVA	{"email": "ekaterina-nesterova101990@postgrespro.ru", "phone": "+70072947637"}
0005435243475	F1FDE0	6727 709366	EVA KOROLEVA	{"phone": "+70949402764"}
0005435243476	0B471C	7965 766083	MARINA GAVRILOVA	{"phone": "+70585541157"}
0005435243477	7A2A81	3739 522418	TATYANA DMITRIEVA	{"phone": "+70894614340"}
0005435243478	7A2A81	3726 198196	DIANA KRASNOVA	{"email": "dkrasnova-1976@postgrespro.ru", "phone": "+70520271703"}
0005435243479	7A2A81	4079 362443	POLINA TROFIMOVA	{"phone": "+70032371685"}
0005435243480	D348C1	1820 543159	ARTEM KOZLOV	{"phone": "+70370754358"}
0005435243481	FAF95C	7818 952163	TATYANA ZHUKOVA	{"phone": "+70912037249"}
0005435243482	3551D2	6845 498741	ELMIRA ILINA	{"phone": "+70090753458"}
0005435243483	3551D2	6920 652386	EVGENIY FEDOROV	{"phone": "+70479312035"}
0005435243484	0A43D2	4575 591530	RAFAEL GAVRILOV	{"phone": "+70809513768"}
0005435243485	8B3291	3415 337094	ANASTASIYA ZHUKOVA	{"phone": "+70654887680"}
0005435243486	DC206C	5948 181518	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-021972@postgrespro.ru", "phone": "+70706669590"}
0005435243487	DC206C	2805 617573	ANASTASIYA MAKAROVA	{"email": "a_makarova091966@postgrespro.ru", "phone": "+70356067045"}
0005435243488	408A80	7569 748031	MARIYA BELYAEVA	{"email": "m_belyaeva_1971@postgrespro.ru", "phone": "+70153038404"}
0005435243489	408A80	3252 461453	OLGA KUZMINA	{"phone": "+70182210142"}
0005435243490	408A80	1027 746907	ROMAN IVANOV	{"email": "r_ivanov-20061974@postgrespro.ru", "phone": "+70530014838"}
0005435243491	3A1620	3575 281245	MARIYA LOGINOVA	{"phone": "+70983411538"}
0005435243492	A6A5EF	1665 142050	VASILIY IVANOV	{"phone": "+70150681451"}
0005435243493	627A54	3872 899450	VALENTINA MAKSIMOVA	{"phone": "+70256681721"}
0005435243494	9FB6B0	4215 204691	NIKOLAY SHEVCHENKO	{"email": "shevchenkonikolay30101986@postgrespro.ru", "phone": "+70990071706"}
0005435243495	9FB6B0	5709 786000	MARIYA SEMENOVA	{"phone": "+70349307278"}
0005435243496	9FB6B0	4319 379046	VERA VOLKOVA	{"email": "v_volkova1976@postgrespro.ru", "phone": "+70239474064"}
0005435243610	0A486B	1265 657403	GENNADIY ISAEV	{"phone": "+70804989675"}
0005435243497	F6B9D4	1139 556530	SVETLANA OSIPOVA	{"email": "osipova_svetlana-1970@postgrespro.ru", "phone": "+70456645157"}
0005435243498	2C9728	9710 078407	MIKHAIL FEDOTOV	{"phone": "+70646770800"}
0005435243499	2C9728	5301 523880	ANNA ZAKHAROVA	{"email": "zakharova_anna1971@postgrespro.ru", "phone": "+70040322140"}
0005435243500	C81513	4084 798952	GALINA IVANOVA	{"phone": "+70775017991"}
0005435243501	C81513	5391 581258	VLADIMIR IVANOV	{"phone": "+70747840209"}
0005435243502	3D6BD9	7448 549150	ZHANNA GERASIMOVA	{"email": "gerasimova-zhanna.03011969@postgrespro.ru", "phone": "+70990981887"}
0005435243503	AEAFAF	9639 622098	MARINA EGOROVA	{"email": "m.egorova.18031970@postgrespro.ru", "phone": "+70935591813"}
0005435243504	11D65A	8143 272341	LYUBOV ZHUKOVA	{"email": "zhukova.l_08071965@postgrespro.ru", "phone": "+70221062826"}
0005435243505	FD3BFE	5127 334001	LYUBOV MAKAROVA	{"phone": "+70033157743"}
0005435243506	FD3BFE	6122 981588	SERGEY FILIPPOV	{"phone": "+70858745144"}
0005435243507	680D13	4362 599536	SVETLANA DAVYDOVA	{"phone": "+70801017317"}
0005435243508	82EE41	7967 236821	TIMOFEY CHERNOV	{"phone": "+70720772391"}
0005435243509	648FF4	8058 784385	SERGEY KUZNECOV	{"email": "sergey-kuznecov-11041972@postgrespro.ru", "phone": "+70177064439"}
0005435243510	648FF4	9194 171385	NATALYA KOZLOVA	{"email": "natalya.kozlova031963@postgrespro.ru", "phone": "+70333899689"}
0005435243511	0D2020	8325 981726	VALENTINA FILATOVA	{"phone": "+70179298443"}
0005435243512	0D2020	5985 185000	ANASTASIYA TIKHONOVA	{"email": "tikhonova_anastasiya-1981@postgrespro.ru", "phone": "+70727963612"}
0005435243513	8376C1	1780 966540	ALEKSANDR POPOV	{"phone": "+70728765929"}
0005435243514	8376C1	1476 654412	KIRILL ZHURAVLEV	{"phone": "+70276573877"}
0005435243515	6A2971	0920 483813	PETR SERGEEV	{"email": "petrsergeev-011975@postgrespro.ru", "phone": "+70485429360"}
0005435243516	6A2971	2072 948076	NIKOLAY SCHERBAKOV	{"phone": "+70389486548"}
0005435243517	F6B442	2649 689472	YURIY PETROV	{"phone": "+70810344018"}
0005435243518	F6B442	5774 143012	ALEKSANDR BORISOV	{"email": "borisov-aleksandr_18011966@postgrespro.ru", "phone": "+70587124264"}
0005435243519	EF3EA9	7103 223340	ELENA BELOVA	{"email": "ebelova-051981@postgrespro.ru", "phone": "+70497384423"}
0005435243520	EF3EA9	1787 014917	NIKOLAY MIKHAYLOV	{"phone": "+70819041950"}
0005435243521	7E62EC	1824 726283	NINA ABRAMOVA	{"phone": "+70421091743"}
0005435243522	6A1252	7411 196759	ANASTASIYA SEMENOVA	{"email": "semenova_a30011969@postgrespro.ru", "phone": "+70247934445"}
0005435243523	FE4ED3	0895 219102	ROMAN FEDOROV	{"phone": "+70883321579"}
0005435243524	FE4ED3	5532 141038	VIKTORIYA FILATOVA	{"phone": "+70699644060"}
0005435243525	A14C03	3407 344790	SOFYA ZAYCEVA	{"email": "zayceva-sofya_071971@postgrespro.ru", "phone": "+70432273189"}
0005435243526	A14C03	9869 119133	IVAN KOZLOV	{"email": "kozlov.ivan.15081972@postgrespro.ru", "phone": "+70999072071"}
0005435243527	012066	2848 299449	SVETLANA KUZNECOVA	{"phone": "+70340626082"}
0005435243528	012066	2279 433612	NATALYA SERGEEVA	{"email": "natalyasergeeva.071969@postgrespro.ru", "phone": "+70834557259"}
0005435243529	1C93BD	0015 719729	OKSANA MEDVEDEVA	{"phone": "+70773595802"}
0005435243530	1C93BD	2341 818985	FAINA ILINA	{"phone": "+70164969718"}
0005435243531	26969C	0389 749039	ANDREY MOISEEV	{"phone": "+70193607990"}
0005435243532	1D8C76	2450 756814	MARIYA NESTEROVA	{"phone": "+70752771348"}
0005435243533	2F9663	1306 310930	NATALYA MAKSIMOVA	{"phone": "+70261123160"}
0005435243534	AB2366	3792 800542	RIMMA KULIKOVA	{"phone": "+70828196182"}
0005435243535	598B93	8692 324790	NIKOLAY MIKHAYLOV	{"email": "mikhaylov-n121969@postgrespro.ru", "phone": "+70074168950"}
0005435243536	58C113	5277 455963	TATYANA KOLESNIKOVA	{"phone": "+70376540175"}
0005435243537	3C7A4C	1025 154937	VYACHESLAV BARANOV	{"phone": "+70259385040"}
0005435243538	3C7A4C	1644 574020	LYUDMILA MELNIKOVA	{"phone": "+70197113446"}
0005435243539	3C7A4C	0007 855044	GULNARA SAVELEVA	{"email": "saveleva.gulnara.1976@postgrespro.ru", "phone": "+70324165315"}
0005435243540	231E58	9004 650304	LYUBOV STEPANOVA	{"email": "l-stepanova_1986@postgrespro.ru", "phone": "+70630410885"}
0005435243541	231E58	6283 160531	VLADIMIR KISELEV	{"email": "kiselev.v03071975@postgrespro.ru", "phone": "+70151074705"}
0005435243542	C3C752	2902 210247	SERGEY GAVRILOV	{"phone": "+70304908356"}
0005435243543	C3C752	3761 719334	YURIY KISELEV	{"email": "kiselev-yuriy-06031959@postgrespro.ru", "phone": "+70616771586"}
0005435243544	A406DC	5020 611377	LYUBOV MARTYNOVA	{"email": "martynova_lyubov.24031975@postgrespro.ru", "phone": "+70126170628"}
0005435243545	3BBCC9	8193 733420	OLGA LUKYANOVA	{"phone": "+70354577250"}
0005435243546	254995	2334 545493	ALEKSANDR KUZMIN	{"email": "kuzmin-a-091981@postgrespro.ru", "phone": "+70283965352"}
0005435243547	11E11B	6993 908553	SOFYA KONDRATEVA	{"email": "skondrateva-23061961@postgrespro.ru", "phone": "+70761054856"}
0005435243548	D0E27E	2760 878065	ALEKSANDR ANDREEV	{"phone": "+70111880306"}
0005435243549	D0E27E	6397 203995	GENNADIY NOVIKOV	{"phone": "+70182494189"}
0005435243550	2C6475	4600 136825	ANASTASIYA MARTYNOVA	{"email": "a.martynova1977@postgrespro.ru", "phone": "+70691914910"}
0005435243551	2C6475	9393 554393	NATALIYA SMIRNOVA	{"email": "smirnova-nataliya1969@postgrespro.ru", "phone": "+70307082220"}
0005435243552	2C6475	3887 339131	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev_101978@postgrespro.ru", "phone": "+70875872216"}
0005435243553	F67B90	0877 269862	SERGEY DAVYDOV	{"email": "s-davydov_1984@postgrespro.ru", "phone": "+70331252920"}
0005435243554	211BC7	8013 837591	NADEZHDA LEBEDEVA	{"phone": "+70443157376"}
0005435243555	3D5CBC	6741 337548	VALERIYA FILIPPOVA	{"email": "filippovavaleriya-16101972@postgrespro.ru", "phone": "+70768516649"}
0005435243556	E47432	4247 062546	VALENTINA ZOTOVA	{"email": "zotova-valentina1976@postgrespro.ru", "phone": "+70814762438"}
0005435243557	7C4267	9342 612459	VERA FADEEVA	{"email": "fadeevavera.1961@postgrespro.ru", "phone": "+70930569322"}
0005435243558	194501	0847 915527	LYUBOV ALEKSEEVA	{"phone": "+70491626157"}
0005435243559	43CBCB	4017 042972	DANILA ZHUKOV	{"email": "zhukov_d1975@postgrespro.ru", "phone": "+70965693120"}
0005435252392	63F773	4918 564353	LARISA MIRONOVA	{"phone": "+70927363938"}
0005435243560	343BA1	2676 475737	ANDREY POPOV	{"email": "a_popov051964@postgrespro.ru", "phone": "+70869784625"}
0005435243561	F8713E	0466 295683	ALEKSANDR CHERNOV	{"email": "a_chernov-24061976@postgrespro.ru", "phone": "+70898943578"}
0005435243562	F8713E	0328 706840	YURIY SCHERBAKOV	{"phone": "+70433519162"}
0005435243563	F8713E	1844 730524	ELENA KOZLOVA	{"email": "ekozlova_091979@postgrespro.ru", "phone": "+70948259820"}
0005435243564	F8713E	3977 805076	VIKTOR KUZNECOV	{"phone": "+70280039607"}
0005435243565	777057	0882 056349	YURIY KUZNECOV	{"phone": "+70669870150"}
0005435243566	777057	7055 698311	MAKSIM ZHUKOV	{"phone": "+70432777701"}
0005435243567	777057	5448 970381	REGINA BORISOVA	{"email": "reginaborisova.1967@postgrespro.ru", "phone": "+70482835882"}
0005435243568	0F590E	3626 104640	VASILIY KUDRYASHOV	{"email": "kudryashov.v1965@postgrespro.ru", "phone": "+70999958581"}
0005435243569	075AB5	1498 486498	NATALYA VASILEVA	{"email": "vasilevan.1962@postgrespro.ru", "phone": "+70942838548"}
0005435243570	5E441C	1758 608525	LYUDMILA NESTEROVA	{"phone": "+70245645100"}
0005435243571	5E441C	6685 738621	VALENTINA ZAKHAROVA	{"email": "v.zakharova041959@postgrespro.ru", "phone": "+70505020321"}
0005435243572	2E2C05	6877 076045	DANIL KOZLOV	{"phone": "+70830930324"}
0005435243573	211BEE	1793 379859	ALIYA POPOVA	{"email": "a_popova.25051971@postgrespro.ru", "phone": "+70906506791"}
0005435243574	211BEE	9782 333115	NATALYA PETROVA	{"phone": "+70466129412"}
0005435243575	40914A	5663 654397	MIKHAIL VOROBEV	{"phone": "+70423103004"}
0005435243576	40914A	8158 281588	IRINA KUZNECOVA	{"phone": "+70396971726"}
0005435243577	0CE86B	8589 498438	ALEKSEY GAVRILOV	{"phone": "+70522022294"}
0005435243578	08B6E6	0062 514352	PAVEL KUZMIN	{"phone": "+70947012918"}
0005435243579	B80235	3844 661196	MAKSIM KUZMIN	{"phone": "+70847565158"}
0005435243580	B80235	4009 569686	VLADIMIR POPOV	{"phone": "+70036147001"}
0005435243581	7301CD	7357 472034	LYUBOV DANILOVA	{"phone": "+70113564317"}
0005435243582	82B54F	8892 875566	NADEZHDA KARPOVA	{"phone": "+70838185530"}
0005435243583	2BDF77	7557 275639	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko23071970@postgrespro.ru", "phone": "+70878523400"}
0005435243584	2BDF77	2786 433982	NIKOLAY PETROV	{"phone": "+70353994305"}
0005435243585	0A379F	5323 213939	ANATOLIY MEDVEDEV	{"phone": "+70243817457"}
0005435243586	90545A	2941 169497	NADEZHDA KOROLEVA	{"phone": "+70473216721"}
0005435243587	90545A	1382 227806	VIKTORIYA MOROZOVA	{"email": "morozovaviktoriya_1977@postgrespro.ru", "phone": "+70945639444"}
0005435243588	399804	0511 532549	SVETLANA NOVIKOVA	{"email": "svetlana-novikova-121962@postgrespro.ru", "phone": "+70167638802"}
0005435243589	22E1BC	2323 173813	VITALIY KUDRYASHOV	{"phone": "+70173709226"}
0005435243590	22E1BC	8082 912254	BORIS MAKAROV	{"phone": "+70836091522"}
0005435243591	BC9C9B	4398 730307	EKATERINA ALEKSEEVA	{"phone": "+70328544006"}
0005435243592	BC9C9B	8276 148782	MIKHAIL BELOV	{"phone": "+70916287072"}
0005435243593	DA0A8E	8218 913537	KRISTINA LEBEDEVA	{"phone": "+70109696412"}
0005435243594	DA0A8E	2807 536344	ANDREY NOVIKOV	{"email": "novikov-a1979@postgrespro.ru", "phone": "+70670154479"}
0005435243595	DA0A8E	0967 841709	VLADIMIR IVANOV	{"phone": "+70629860797"}
0005435243596	E299B1	8650 390316	EKATERINA ZAYCEVA	{"email": "ekaterina.zayceva_10031962@postgrespro.ru", "phone": "+70855018041"}
0005435243597	07664E	1770 187418	OLEG ALEKSANDROV	{"email": "oleg_aleksandrov101968@postgrespro.ru", "phone": "+70343315833"}
0005435243598	58F759	0905 140638	ALEKSANDR MIKHAYLOV	{"phone": "+70278047236"}
0005435243599	58F759	9626 953495	VALERIYA ZAKHAROVA	{"phone": "+70237211127"}
0005435243600	539265	6549 994857	OLGA DMITRIEVA	{"email": "dmitrievaolga021971@postgrespro.ru", "phone": "+70332489595"}
0005435243601	E23EB3	4174 199967	FATYMA FILIPPOVA	{"email": "ffilippova.1981@postgrespro.ru", "phone": "+70247225569"}
0005435243602	09C75A	5560 004291	DARYA SEMENOVA	{"email": "darya.semenova.1970@postgrespro.ru", "phone": "+70312830133"}
0005435243603	09C75A	9484 553213	AYRAT AFANASEV	{"phone": "+70132725229"}
0005435243604	E40301	8375 280829	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin_021964@postgrespro.ru", "phone": "+70959334688"}
0005435243605	E40301	6577 318373	VLADIMIR DENISOV	{"email": "denisov.v_1972@postgrespro.ru", "phone": "+70637899904"}
0005435243606	28EC1B	4280 552393	ANNA MIRONOVA	{"phone": "+70714901716"}
0005435243607	34DFFA	4751 542671	ALLA KONOVALOVA	{"phone": "+70978261917"}
0005435243608	E91523	9525 294381	LYUDMILA ANTONOVA	{"email": "antonova_lyudmila121971@postgrespro.ru", "phone": "+70204498403"}
0005435243609	E91523	4860 817424	IRINA GUSEVA	{"email": "i-guseva1959@postgrespro.ru", "phone": "+70430193862"}
0005435243611	72CC10	5732 863688	VLADIMIR KUZNECOV	{"phone": "+70470512767"}
0005435243612	8936A2	5738 798968	MARIYA STEPANOVA	{"phone": "+70591208622"}
0005435243613	5FDA2C	8426 632746	GENNADIY FOMIN	{"phone": "+70283436088"}
0005435243614	A502D0	6635 793426	NATALYA SEMENOVA	{"email": "semenova.n-12101965@postgrespro.ru", "phone": "+70303852634"}
0005435243615	B6256F	7880 693181	SOFIYA CHERNOVA	{"email": "chernovasofiya.031973@postgrespro.ru", "phone": "+70508452682"}
0005435243616	B6256F	5662 034574	GALINA SIDOROVA	{"email": "sidorova.galina-12071967@postgrespro.ru", "phone": "+70935991570"}
0005435243617	E3653D	8162 261798	TATYANA FILATOVA	{"phone": "+70137260445"}
0005435243618	870ED8	0010 419574	NATALYA POTAPOVA	{"email": "natalya-potapova-1985@postgrespro.ru", "phone": "+70270121056"}
0005435243619	48A649	4672 637226	OKSANA PAVLOVA	{"email": "pavlova.oksana.1979@postgrespro.ru", "phone": "+70346085219"}
0005435243620	A12623	5468 168137	LYUDMILA BELOVA	{"email": "belovalyudmila.121967@postgrespro.ru", "phone": "+70168478562"}
0005435243621	53E85D	6578 523455	ALINA YUDINA	{"phone": "+70054821902"}
0005435243622	D83AA8	2790 979503	YURIY SIDOROV	{"phone": "+70926071947"}
0005435243623	E338C3	0368 915881	LYUBOV GAVRILOVA	{"email": "gavrilova-lyubov-091973@postgrespro.ru", "phone": "+70295410000"}
0005435243624	EEE274	9607 751048	MIKHAIL KUZNECOV	{"phone": "+70396051711"}
0005435243625	66CD28	0075 919639	VLADISLAV GAVRILOV	{"phone": "+70830982871"}
0005435243626	44202B	4996 924587	PAVEL VOLKOV	{"phone": "+70369603422"}
0005435243627	B96D80	4675 763372	VALERIY MAKAROV	{"phone": "+70807637864"}
0005435243628	8DD386	2852 060316	OLEG FOMIN	{"email": "fomin.oleg1965@postgrespro.ru", "phone": "+70051802172"}
0005435243629	3B989A	8493 104361	YULIYA ILINA	{"email": "ilina_yuliya1974@postgrespro.ru", "phone": "+70231784527"}
0005435243630	A64DB9	0909 159700	DMITRIY POPOV	{"email": "dmitriypopov101975@postgrespro.ru", "phone": "+70876901914"}
0005435243631	BFDFB5	7917 573297	ELENA ALEKSEEVA	{"phone": "+70721584922"}
0005435243632	BFDFB5	0308 527838	IRINA DMITRIEVA	{"phone": "+70844899402"}
0005435243633	5F3E4F	5731 924906	ANDREY AFANASEV	{"phone": "+70161973669"}
0005435243634	541A44	5056 213285	EKATERINA FOMINA	{"email": "efomina.1963@postgrespro.ru", "phone": "+70557853889"}
0005435243635	0E2ABD	0058 413557	DENIS VASILEV	{"phone": "+70214774849"}
0005435243636	0E2ABD	5613 729467	TAMARA ARKHIPOVA	{"phone": "+70394842506"}
0005435243637	58A3CE	4547 785227	MARIYA ZAYCEVA	{"phone": "+70958768325"}
0005435243638	7DFF89	0631 881230	LYUDMILA MIKHAYLOVA	{"email": "l.mikhaylova_101975@postgrespro.ru", "phone": "+70835748841"}
0005435243639	EAB8B7	1483 784799	ALEKSANDRA PETROVA	{"email": "petrova_aleksandra.1966@postgrespro.ru", "phone": "+70536087625"}
0005435243640	5CAEF3	0590 670691	EVGENIY CHERNOV	{"phone": "+70603644283"}
0005435243641	70196F	1139 488836	NIKITA KUZNECOV	{"email": "n.kuznecov.13071968@postgrespro.ru", "phone": "+70999048542"}
0005435243642	70196F	6367 141792	MARTA ERMAKOVA	{"phone": "+70774884980"}
0005435243643	A45EBA	3636 221303	NADEZHDA KISELEVA	{"phone": "+70313777011"}
0005435243644	AF4C40	1445 599509	SERGEY KOROLEV	{"email": "sergey_korolev-1967@postgrespro.ru", "phone": "+70696816935"}
0005435243645	7769EA	7573 841327	TATYANA KISELEVA	{"phone": "+70722726324"}
0005435243646	2FA868	7672 108404	EKATERINA KONOVALOVA	{"phone": "+70583434933"}
0005435243647	2FA868	7557 961654	SOFYA GORBUNOVA	{"email": "gorbunova_s.1964@postgrespro.ru", "phone": "+70737842781"}
0005435243648	2FA868	8404 509497	ALEKSEY KARPOV	{"phone": "+70400509205"}
0005435243649	A558D2	8059 724271	OLGA KUZMINA	{"email": "o.kuzmina.29091978@postgrespro.ru", "phone": "+70291296181"}
0005435243650	A558D2	4816 719858	OKSANA KOZLOVA	{"phone": "+70904617329"}
0005435243651	850CFE	9428 658119	ANASTASIYA FEDOROVA	{"phone": "+70481667127"}
0005435243652	850CFE	9875 861061	NATALIYA EGOROVA	{"email": "egorova.n.111973@postgrespro.ru", "phone": "+70603603577"}
0005435243653	87AB17	5729 247107	VYACHESLAV BARANOV	{"phone": "+70089344529"}
0005435243654	87AB17	4102 052265	ROMAN OSIPOV	{"phone": "+70998655539"}
0005435243655	DF28AD	1563 302033	ALEKSANDR BELOV	{"email": "belov.aleksandr27021972@postgrespro.ru", "phone": "+70174034055"}
0005435243656	B5827F	0941 979238	SVETLANA PETROVA	{"email": "s-petrova071966@postgrespro.ru", "phone": "+70572371169"}
0005435243657	B5827F	9471 300023	LIDIYA MIKHAYLOVA	{"phone": "+70714778151"}
0005435243658	212C0F	7176 186559	DANIS MARTYNOV	{"phone": "+70273163760"}
0005435243659	270754	4282 595040	ALEKSANDRA OSIPOVA	{"email": "a_osipova_1973@postgrespro.ru", "phone": "+70228913177"}
0005435243660	0B0592	4296 124682	RAMIL YAKOVLEV	{"email": "yakovlevr-1973@postgrespro.ru", "phone": "+70106500064"}
0005435243661	EF34AE	6604 893764	DMITRIY SEMENOV	{"email": "dmitriy-semenov041964@postgrespro.ru", "phone": "+70468614105"}
0005435243662	EF34AE	7328 693089	ALEKSANDR BARANOV	{"phone": "+70260084647"}
0005435243663	97D443	5855 759837	VLADIMIR ALEKSANDROV	{"phone": "+70771724425"}
0005435243664	97D443	9144 488270	RISHAT BONDARENKO	{"email": "rishat-bondarenko.26031974@postgrespro.ru", "phone": "+70124266553"}
0005435243665	BAF6C9	4873 484928	VALENTINA YUDINA	{"phone": "+70504222996"}
0005435243666	BAF6C9	2426 850237	ALENA TITOVA	{"email": "titova-alena24111973@postgrespro.ru", "phone": "+70185045045"}
0005435243667	BE3F66	9792 678013	VLADIMIR FEDOROV	{"phone": "+70308304549"}
0005435243668	BE3F66	9298 583816	ANNA STEPANOVA	{"phone": "+70210791370"}
0005435243669	BE3F66	8276 056110	DENIS NOVIKOV	{"email": "novikov-d_13051968@postgrespro.ru", "phone": "+70591993785"}
0005435252378	B7F4BA	5878 230617	IGOR ABRAMOV	{"email": "abramov.i_04071967@postgrespro.ru", "phone": "+70921656474"}
0005435252379	62CE6E	7659 440042	OLGA FROLOVA	{"email": "olga-frolova_18041969@postgrespro.ru", "phone": "+70838975755"}
0005435252380	F91A8D	7483 342316	POLINA ZAYCEVA	{"email": "p-zayceva-1968@postgrespro.ru", "phone": "+70750645513"}
0005435252381	F91A8D	9209 850565	LYUDMILA KONDRATEVA	{"email": "kondrateva-lyudmila.18031975@postgrespro.ru", "phone": "+70083757754"}
0005435252382	F1A450	8685 063707	EVGENIY EGOROV	{"email": "egorov_evgeniy_1974@postgrespro.ru", "phone": "+70313053537"}
0005435252383	53B4FE	7566 720412	DANIL TARASOV	{"email": "daniltarasov-01081973@postgrespro.ru", "phone": "+70791348061"}
0005435252384	53B4FE	2179 290954	ANTON POPOV	{"email": "popovanton.081972@postgrespro.ru", "phone": "+70424772019"}
0005435252385	6CD474	0386 858148	VLADIMIR POPOV	{"email": "popov-vladimir.01021969@postgrespro.ru", "phone": "+70106047345"}
0005435252386	6CD474	5290 593375	RUDOLF VOROBEV	{"email": "vorobev-r.1965@postgrespro.ru", "phone": "+70052246985"}
0005435252387	6CD474	7101 249037	FEDOR IVANOV	{"phone": "+70050618878"}
0005435252388	5EB919	8318 696408	NATALYA GERASIMOVA	{"email": "ngerasimova-041970@postgrespro.ru", "phone": "+70100356442"}
0005435252389	6C5B33	5061 003105	VIKTOR IVANOV	{"phone": "+70195636834"}
0005435252390	6C5B33	3686 229113	ILYA KRASNOV	{"phone": "+70179982119"}
0005435252391	6C5B33	7728 354416	VIKTOR FEDOTOV	{"phone": "+70973188736"}
0005435252393	63F773	6752 221616	OLGA ILINA	{"phone": "+70412192735"}
0005435252394	63F773	4029 240949	SVETLANA SEMENOVA	{"phone": "+70397142339"}
0005435252395	63F773	2283 355212	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov.29101972@postgrespro.ru", "phone": "+70081725068"}
0005435252396	2B0BB1	2958 328759	TAMARA ZAYCEVA	{"email": "tamara-zayceva.1973@postgrespro.ru", "phone": "+70513244559"}
0005435252397	92DC44	9222 909375	VIKTOR KUZNECOV	{"phone": "+70613247439"}
0005435252398	92DC44	9771 134098	NADEZHDA NIKITINA	{"email": "n-nikitina081971@postgrespro.ru", "phone": "+70807547373"}
0005435252399	A42AB7	6942 756874	MARAT KAZAKOV	{"email": "kazakov.marat.121980@postgrespro.ru", "phone": "+70222338863"}
0005435252400	B11569	9740 766191	ARKADIY ZHUKOV	{"phone": "+70330212565"}
0005435252401	77DC66	1748 808210	ANDREY ANTONOV	{"email": "aantonov.011979@postgrespro.ru", "phone": "+70052506399"}
0005435252402	8BBD1D	2870 024600	NIKITA GAVRILOV	{"email": "gavrilov.n061966@postgrespro.ru", "phone": "+70910701740"}
0005435252403	6DD271	4924 592990	VARVARA SOKOLOVA	{"email": "varvarasokolova031968@postgrespro.ru", "phone": "+70186000792"}
0005435252404	3F50E2	1480 538907	PETR MEDVEDEV	{"email": "medvedev.p-1981@postgrespro.ru", "phone": "+70364646178"}
0005435252405	3F50E2	4231 096782	IRINA EGOROVA	{"phone": "+70608581145"}
0005435252406	D4E37F	6961 975166	NINA CHERNOVA	{"phone": "+70013291433"}
0005435252407	D4E37F	3432 014742	ALEKSANDR PETROV	{"phone": "+70724127736"}
0005435252408	018CAE	9001 308550	LYUDMILA LOGINOVA	{"phone": "+70881576614"}
0005435252409	38AF75	9411 884695	YURIY FEDOROV	{"email": "yuriy_fedorov_10121966@postgrespro.ru", "phone": "+70185046665"}
0005435252410	E5AD6F	4879 495198	ELMIRA POLYAKOVA	{"phone": "+70435919812"}
0005435252411	4940A8	8411 174735	NADEZHDA ROMANOVA	{"phone": "+70557812975"}
0005435252412	4940A8	9782 070186	ANATOLIY GAVRILOV	{"email": "agavrilov-1965@postgrespro.ru", "phone": "+70258208217"}
0005435252413	8BC2F2	1475 848673	ELENA ANDREEVA	{"phone": "+70544375363"}
0005435252414	4EB977	9441 686546	NIKOLAY ROMANOV	{"email": "romanov.nikolay_071972@postgrespro.ru", "phone": "+70911309536"}
0005435252415	E63156	9831 984104	SERGEY MOROZOV	{"email": "morozov-s-021967@postgrespro.ru", "phone": "+70582642925"}
0005435252416	E63156	5429 309570	VADIM ANTONOV	{"email": "antonov_vadim_091972@postgrespro.ru", "phone": "+70360413220"}
0005435252417	E63156	0666 239203	MIKHAIL EGOROV	{"email": "egorov-m_11071973@postgrespro.ru", "phone": "+70250322511"}
0005435252418	FB0DAF	3841 220050	MILANA OVCHINNIKOVA	{"email": "m_ovchinnikova.1973@postgrespro.ru", "phone": "+70495759393"}
0005435252419	C4AFBE	5980 055672	NATALYA KOROLEVA	{"email": "natalya_koroleva-14031965@postgrespro.ru", "phone": "+70038849175"}
0005435252420	36A2FF	7041 694336	VALENTINA KOVALEVA	{"email": "valentina.kovaleva011968@postgrespro.ru", "phone": "+70312393187"}
0005435252421	38CDA9	1256 198041	ELENA SOLOVEVA	{"phone": "+70599497674"}
0005435252422	350BCB	2638 483070	ALINA YAKOVLEVA	{"phone": "+70353692647"}
0005435252423	350BCB	9420 092295	TATYANA BELOVA	{"phone": "+70953073296"}
0005435252424	F5AA98	1313 076374	MARIYA POPOVA	{"phone": "+70077308323"}
0005435252425	E6E741	0142 866009	ALEKSEY ZAYCEV	{"phone": "+70189808172"}
0005435252426	0BCFC3	2860 964512	VALENTINA LAZAREVA	{"phone": "+70756790521"}
0005435252427	C039C6	2329 359443	EVGENIY KOROLEV	{"email": "korolev-e-05011973@postgrespro.ru", "phone": "+70376841669"}
0005435252428	E5C47F	0262 187991	LIDIYA KOZLOVA	{"email": "lkozlova29121966@postgrespro.ru", "phone": "+70745243159"}
0005435252429	6E37A9	3626 381585	DMITRIY SMIRNOV	{"phone": "+70140121716"}
0005435252430	6E37A9	9526 465685	VLADIMIR TIMOFEEV	{"phone": "+70200493695"}
0005435252431	6E37A9	3369 098222	VLADIMIR DMITRIEV	{"phone": "+70159854767"}
0005435252432	906ADC	7269 658357	VITALIY VOLKOV	{"email": "vitaliy-volkov.1973@postgrespro.ru", "phone": "+70293838685"}
0005435252433	719D61	9109 680766	ALFIYA BORISOVA	{"email": "borisovaa.021975@postgrespro.ru", "phone": "+70787874949"}
0005435252434	719D61	5055 460663	IRINA FILATOVA	{"email": "irina_filatova_1976@postgrespro.ru", "phone": "+70739430714"}
0005435252435	7F545A	2663 441854	ALEKSANDR CHERNOV	{"email": "chernov.aleksandr-1970@postgrespro.ru", "phone": "+70537825119"}
0005435252436	7F545A	0112 802764	ALEKSANDR NAZAROV	{"phone": "+70571758101"}
0005435252437	0A30A7	1695 686114	IVAN TARASOV	{"phone": "+70419584910"}
0005435252438	ED2732	2505 817005	TATYANA PAVLOVA	{"phone": "+70531734221"}
0005435252439	248BAB	2968 885681	ALEKSANDRA POLYAKOVA	{"email": "apolyakova-1975@postgrespro.ru", "phone": "+70878428944"}
0005435252440	9C0586	3594 420819	ANDREY VASILEV	{"email": "andrey.vasilev.31011968@postgrespro.ru", "phone": "+70272240588"}
0005435252441	50A2B0	4318 544942	IVAN KUZNECOV	{"email": "ivan_kuznecov1973@postgrespro.ru", "phone": "+70512187418"}
0005435252442	50A2B0	8712 272805	MAKSIM POPOV	{"phone": "+70945711094"}
0005435252443	907C07	2819 689103	NIKOLAY AFANASEV	{"phone": "+70827566319"}
0005435252444	CEF9DA	7110 488838	IRINA MOROZOVA	{"phone": "+70350051460"}
0005435252445	CEF9DA	3978 495165	DANIL ZAKHAROV	{"phone": "+70629911071"}
0005435252446	CA0195	5423 803692	OKSANA KOZLOVA	{"phone": "+70520687002"}
0005435252447	CA0195	6961 412813	BORIS KUZMIN	{"email": "kuzmin-boris_06061983@postgrespro.ru", "phone": "+70704510223"}
0005435252448	6E8B9C	3287 680500	ALEKSANDR BARANOV	{"phone": "+70892870902"}
0005435252449	8EC6B8	0305 335023	PETR KUZNECOV	{"phone": "+70641125691"}
0005435252450	0BF0ED	5821 640809	ANASTASIYA KUZNECOVA	{"email": "a-kuznecova_041966@postgrespro.ru", "phone": "+70908393549"}
0005435252451	EF5074	6922 320535	NADEZHDA BELOVA	{"phone": "+70380596002"}
0005435252452	1FA5F9	2541 020022	GALINA EGOROVA	{"email": "egorova-galina031973@postgrespro.ru", "phone": "+70068463567"}
0005435252453	95DFC4	8543 677347	OLESYA KUZMINA	{"phone": "+70517491504"}
0005435252454	95DFC4	7361 997981	INNA VOROBEVA	{"phone": "+70958883608"}
0005435252455	37473E	6899 504885	OLGA BELYAEVA	{"email": "olga_belyaeva-07091964@postgrespro.ru", "phone": "+70109165631"}
0005435252456	F3AD77	5362 930408	IVAN ROMANOV	{"email": "romanovi1986@postgrespro.ru", "phone": "+70047994806"}
0005435252457	0A1966	5100 670473	SERGEY DAVYDOV	{"phone": "+70409382288"}
0005435252458	644F9C	4922 174687	OLEG ISAEV	{"email": "isaev.oleg_1971@postgrespro.ru", "phone": "+70216919046"}
0005435252459	387327	3177 811397	VALERIY MELNIKOV	{"phone": "+70432777183"}
0005435252460	387327	3330 571251	EVGENIYA IVANOVA	{"email": "evgeniyaivanova.051971@postgrespro.ru", "phone": "+70408413106"}
0005435252461	ABD501	8158 862240	ANDREY SOKOLOV	{"phone": "+70058357916"}
0005435252462	B84789	5077 844455	VASILIY MATVEEV	{"email": "matveev.v071963@postgrespro.ru", "phone": "+70271054495"}
0005435252463	AA1B45	2038 275481	MIKHAIL MATVEEV	{"phone": "+70656213489"}
0005435252464	AA1B45	3722 407507	ANNA MARTYNOVA	{"email": "martynova_anna.14061979@postgrespro.ru", "phone": "+70535897281"}
0005435252465	23A874	9520 252203	ANNA SCHERBAKOVA	{"email": "anna.scherbakova_081973@postgrespro.ru", "phone": "+70473615515"}
0005435252466	23A874	1448 071017	DMITRIY NOVIKOV	{"email": "d.novikov-30111975@postgrespro.ru", "phone": "+70691521395"}
0005435252467	DC77F2	9244 761019	VIKTOR SMIRNOV	{"phone": "+70954630819"}
0005435252468	9682B2	4043 522115	RAFAIL KOZLOV	{"email": "rafail_kozlov1961@postgrespro.ru", "phone": "+70965269233"}
0005435252469	41A9BA	3206 301639	ANDREY BONDARENKO	{"email": "andreybondarenko.1968@postgrespro.ru", "phone": "+70708471633"}
0005435252470	CC7CBA	8347 519636	ALEKSANDR KULIKOV	{"email": "kulikov_aleksandr-1975@postgrespro.ru", "phone": "+70293969955"}
0005435252471	06EACD	7964 523623	LYUDMILA MIRONOVA	{"phone": "+70168687167"}
0005435252472	3CAAB3	2779 418840	EVGENIY GORBUNOV	{"phone": "+70102964119"}
0005435252473	16F2F0	9224 657325	GALINA SMIRNOVA	{"email": "galina.smirnova_11051967@postgrespro.ru", "phone": "+70926980573"}
0005435252474	16F2F0	1411 770227	ANATOLIY SCHERBAKOV	{"email": "scherbakov.a-011983@postgrespro.ru", "phone": "+70001816438"}
0005435252475	16F2F0	2670 502369	VITALIY GORBUNOV	{"phone": "+70839397901"}
0005435252476	29F89D	6275 355485	ARINA ILINA	{"email": "ilina-arina.22111977@postgrespro.ru", "phone": "+70210822145"}
0005435252477	ACDC6C	2857 580037	ANDREY STEPANOV	{"phone": "+70878771548"}
0005435252478	EF88AF	9558 343741	OLGA PETROVA	{"phone": "+70192523183"}
0005435252479	30F80C	6955 988580	KIRA POPOVA	{"phone": "+70253677580"}
0005435252480	30F80C	4630 594766	RAMIL MIKHAYLOV	{"phone": "+70309220852"}
0005435252481	E9F4A6	2685 780755	DMITRIY MARTYNOV	{"phone": "+70828014618"}
0005435252482	B878ED	5794 312328	GEVORG KISELEV	{"phone": "+70612604167"}
0005435252483	B878ED	4645 310863	TATYANA DENISOVA	{"phone": "+70842596996"}
0005435252484	B878ED	9047 667124	PAVEL KRASNOV	{"phone": "+70484344025"}
0005435252485	432C5A	6767 702151	ALEVTINA KAZAKOVA	{"email": "kazakovaa_051965@postgrespro.ru", "phone": "+70755611596"}
0005435252486	432C5A	4899 196625	IVAN GERASIMOV	{"phone": "+70881177319"}
0005435252487	BDAACC	1728 606648	SOFIYA EFREMOVA	{"phone": "+70148164231"}
0005435252488	9DDDEB	0221 116158	ALEKSANDRA MASLOVA	{"email": "maslova.a_051974@postgrespro.ru", "phone": "+70547890466"}
0005435252489	47E1AE	8646 054456	EVA ANDREEVA	{"phone": "+70789523660"}
0005435252490	47E1AE	8966 227882	ALEKSEY FROLOV	{"phone": "+70161583233"}
0005435252491	3DFBC2	7697 538320	IGOR BARANOV	{"email": "baranov_igor.1964@postgrespro.ru", "phone": "+70476475535"}
0005435252492	46F85A	8801 572553	ROMAN ZAKHAROV	{"email": "romanzakharov_27081983@postgrespro.ru", "phone": "+70760112037"}
0005435252493	31FDC5	0523 076253	ANASTASIYA TIKHONOVA	{"phone": "+70308857345"}
0005435252494	A59BC8	4764 211128	NINA TARASOVA	{"email": "tarasova_nina_13061978@postgrespro.ru", "phone": "+70656178512"}
0005435252495	DEA4AF	2082 473004	ANASTASIYA POTAPOVA	{"email": "potapovaa_1963@postgrespro.ru", "phone": "+70250079518"}
0005435252496	DEA4AF	9729 257019	ELENA KOROLEVA	{"email": "ekoroleva-20101976@postgrespro.ru", "phone": "+70785257737"}
0005435252497	DEA4AF	5415 788011	LYUDMILA BELOVA	{"phone": "+70577998162"}
0005435252498	4AFDE6	8726 324848	ELENA IVANOVA	{"phone": "+70961765689"}
0005435252499	4AFDE6	6498 544982	ALINA MALYSHEVA	{"phone": "+70788464692"}
0005435252500	36B90A	3789 721899	VYACHESLAV MIKHAYLOV	{"email": "v.mikhaylov01021976@postgrespro.ru", "phone": "+70448403546"}
0005435252501	36B90A	3203 157696	MAYYA OSIPOVA	{"email": "osipova.mayya031959@postgrespro.ru", "phone": "+70508137521"}
0005435252502	3AAF80	0192 934017	MARINA RODIONOVA	{"email": "rodionova-marina-051972@postgrespro.ru", "phone": "+70861199265"}
0005435252503	3AAF80	4991 950640	GENNADIY KARPOV	{"phone": "+70025797265"}
0005435252504	F885CF	0988 370411	STANISLAV GRIGOREV	{"phone": "+70253413068"}
0005435252505	F885CF	0424 999901	GALIYA POLYAKOVA	{"phone": "+70629759409"}
0005435252506	F885CF	2078 583817	TAMARA FEDOROVA	{"phone": "+70083022820"}
0005435252507	112032	5946 758717	ALEVTINA SCHERBAKOVA	{"email": "scherbakovaalevtina.1972@postgrespro.ru", "phone": "+70653185755"}
0005435252508	112032	0475 068117	ROMAN STEPANOV	{"phone": "+70055919059"}
0005435252509	362B59	8935 847056	ELENA MOROZOVA	{"email": "elena_morozova.1973@postgrespro.ru", "phone": "+70420410683"}
0005435252510	362B59	4745 995216	SERGEY GORBUNOV	{"phone": "+70356848735"}
0005435252511	60E4F8	6020 700222	ALEKSANDR VOLKOV	{"email": "a_volkov031974@postgrespro.ru", "phone": "+70961017341"}
0005435252512	FA3DEC	4391 893377	POLINA ORLOVA	{"phone": "+70172003879"}
0005435252513	951B8E	2861 322044	NIKITA VOROBEV	{"email": "n.vorobev_06081964@postgrespro.ru", "phone": "+70512673497"}
0005435252514	1205EC	2166 478642	LIDIYA OVCHINNIKOVA	{"email": "l_ovchinnikova.28091973@postgrespro.ru", "phone": "+70188027856"}
0005435252515	5A735F	1019 312676	VALERIY KOZLOV	{"email": "kozlov-valeriy_1982@postgrespro.ru", "phone": "+70116529937"}
0005435252516	AE7E14	0766 926202	VIKTOR GUSEV	{"email": "gusev.v.27121969@postgrespro.ru", "phone": "+70706979164"}
0005435252517	372FF3	0085 734616	ELENA ROMANOVA	{"email": "romanova_elena_25031962@postgrespro.ru", "phone": "+70079943663"}
0005435252518	B69357	3353 903334	TATYANA TIKHONOVA	{"email": "tikhonova_t.1966@postgrespro.ru", "phone": "+70720594440"}
0005435252519	B69357	5214 023949	ANNA NAZAROVA	{"email": "a_nazarova121969@postgrespro.ru", "phone": "+70016098351"}
0005435252520	B69357	4104 154741	ELENA KOROLEVA	{"email": "koroleva-e.031982@postgrespro.ru", "phone": "+70816118632"}
0005435252521	F8AE44	8315 038704	ANDREY AFANASEV	{"email": "a_afanasev1974@postgrespro.ru", "phone": "+70515839488"}
0005435252522	F8AE44	8725 730837	VALERIY KONOVALOV	{"phone": "+70321952373"}
0005435252523	ED77B3	5280 529043	ELENA ZAKHAROVA	{"phone": "+70531495181"}
0005435252524	ED77B3	0272 164975	MARIYA FADEEVA	{"phone": "+70907573111"}
0005435252525	9009BE	7017 785375	DMITRIY SOROKIN	{"phone": "+70919183977"}
0005435252526	10426E	2231 275687	VITALIY KARPOV	{"phone": "+70747738809"}
0005435252527	A9AC0B	3640 461471	OKSANA SOKOLOVA	{"phone": "+70431530998"}
0005435252528	A9AC0B	6063 657061	VERA ROMANOVA	{"phone": "+70952058054"}
0005435252529	0A0470	1873 020674	ARTEM POPOV	{"phone": "+70714610933"}
0005435252530	0A0470	2656 116692	SERGEY PAVLOV	{"email": "pavlov_sergey-1978@postgrespro.ru", "phone": "+70791836514"}
0005435252531	BA76CD	0695 830465	LIDIYA PETROVA	{"phone": "+70884785858"}
0005435252532	BA76CD	2009 742994	ANDREY TARASOV	{"phone": "+70932254275"}
0005435252533	1DCF17	4079 226886	VIKTORIYA KOROLEVA	{"phone": "+70703262711"}
0005435252534	8A7D63	1217 158817	ALEKSANDR GORBUNOV	{"phone": "+70440330589"}
0005435252535	8A7D63	9206 165801	ANDREY MATVEEV	{"phone": "+70147650880"}
0005435252536	F4F6DD	7593 644260	SVETLANA BORISOVA	{"email": "borisova.s27051965@postgrespro.ru", "phone": "+70233342618"}
0005435252537	CE4BE0	5172 143654	VITALIY KUZNECOV	{"phone": "+70961518609"}
0005435252538	CE4BE0	2871 778667	NADEZHDA IVANOVA	{"phone": "+70767905448"}
0005435252539	CE4BE0	5980 847942	VLADIMIR BORISOV	{"email": "vladimirborisov21111963@postgrespro.ru", "phone": "+70104708924"}
0005435252540	356241	5564 887484	NINA MIRONOVA	{"email": "mironova-n-23011963@postgrespro.ru", "phone": "+70427496001"}
0005435252541	C3560A	0447 710941	DARYA CHERNOVA	{"phone": "+70113648145"}
0005435252542	FB91F6	0971 076845	VASILIY NIKOLAEV	{"email": "nikolaev-vasiliy_011983@postgrespro.ru", "phone": "+70942186061"}
0005435252543	FB91F6	3587 928323	MARIYA BELOVA	{"phone": "+70470366616"}
0005435252544	8C37DB	1183 831212	ALEKSANDR NIKOLAEV	{"email": "nikolaeva-18021972@postgrespro.ru", "phone": "+70872488869"}
0005435252545	5DAA2C	3951 793601	OLGA BORISOVA	{"phone": "+70744744737"}
0005435252546	8B4940	1967 993258	YULIYA DANILOVA	{"phone": "+70240527639"}
0005435252547	8B4940	9430 379442	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-07101964@postgrespro.ru", "phone": "+70526991591"}
0005435252548	2EA1E2	8061 747599	ANNA YAKOVLEVA	{"email": "yakovleva-anna.1969@postgrespro.ru", "phone": "+70546169131"}
0005435252549	6676FA	8691 882962	ANNA VOROBEVA	{"phone": "+70427081244"}
0005435252550	A185D7	0275 650512	ALEKSEY MARTYNOV	{"email": "martynov_aleksey_101970@postgrespro.ru", "phone": "+70624406485"}
0005435252551	A185D7	7467 954015	MARIYA AKIMOVA	{"phone": "+70505926526"}
0005435252552	A48131	8408 683029	OLESYA NAUMOVA	{"email": "onaumova.1974@postgrespro.ru", "phone": "+70669308916"}
0005435252553	A48131	2042 798761	DMITRIY FROLOV	{"email": "frolovd17061967@postgrespro.ru", "phone": "+70707924328"}
0005435252554	1CB947	9600 519626	NIKOLAY GAVRILOV	{"email": "n.gavrilov-30081976@postgrespro.ru", "phone": "+70319513102"}
0005435252555	1CB947	6911 555506	GALINA NAUMOVA	{"phone": "+70304124617"}
0005435252556	305D73	6549 612827	KARINA BELYAEVA	{"email": "belyaeva-k.071972@postgrespro.ru", "phone": "+70858802182"}
0005435252557	3784FC	6165 275194	TATYANA ZHUKOVA	{"email": "zhukovat-1980@postgrespro.ru", "phone": "+70263589923"}
0005435252558	68656A	1977 304875	IVAN ROMANOV	{"email": "romanov_ivan30061974@postgrespro.ru", "phone": "+70750690770"}
0005435252559	68656A	1128 734942	VASILIY KAZAKOV	{"email": "vasiliy.kazakov.111984@postgrespro.ru", "phone": "+70152509844"}
0005435252560	AA15A2	3239 654574	NIKOLAY MARTYNOV	{"phone": "+70688514363"}
0005435252561	96253B	2938 041704	ANTON MARTYNOV	{"phone": "+70690375164"}
0005435252562	363507	1104 995687	ROMAN VOLKOV	{"email": "volkov-roman.1980@postgrespro.ru", "phone": "+70795218607"}
0005435252563	6594A4	9477 392951	ARTUR VASILEV	{"phone": "+70436161722"}
0005435252564	B4C0CD	7274 508491	PAVEL KUZNECOV	{"phone": "+70980010828"}
0005435252565	880455	4390 597619	MARINA SAVELEVA	{"email": "saveleva-marina-31081990@postgrespro.ru", "phone": "+70876195765"}
0005435252566	F08F1B	7190 421292	NINA KUZMINA	{"email": "ninakuzmina27041977@postgrespro.ru", "phone": "+70616015718"}
0005435252567	507061	0497 797944	EKATERINA KRASNOVA	{"phone": "+70353605836"}
0005435252568	507061	3363 155423	GALINA KRASNOVA	{"email": "g.krasnova1971@postgrespro.ru", "phone": "+70790031156"}
0005435252569	2BE4AE	8945 534018	SERGEY EGOROV	{"email": "egorov_sergey_13111963@postgrespro.ru", "phone": "+70518397839"}
0005435252570	29DA5A	6014 769725	DAMIR MIKHAYLOV	{"phone": "+70438398919"}
0005435252571	C84BC3	9685 806063	ALEKSANDR ZHURAVLEV	{"phone": "+70015644692"}
0005435252572	CC5086	4490 386614	ANNA NIKOLAEVA	{"email": "anna_nikolaeva-041962@postgrespro.ru", "phone": "+70392007224"}
0005435252573	7219E6	0577 950904	VITALIY ORLOV	{"email": "v_orlov-041979@postgrespro.ru", "phone": "+70828156117"}
0005435252574	F981A8	0327 115363	MAKSIM ZAKHAROV	{"email": "maksim-zakharov-1968@postgrespro.ru", "phone": "+70667580108"}
0005435252575	3CAFFD	0808 766609	ANASTASIYA GRISHINA	{"phone": "+70130414788"}
0005435252576	5C5342	2160 933613	IRINA FILIPPOVA	{"phone": "+70903315406"}
0005435252577	5C5342	2996 259578	EKATERINA KALININA	{"email": "ekaterina.kalinina09071974@postgrespro.ru", "phone": "+70992062971"}
0005435252578	04B23E	0998 897388	GULNARA TROFIMOVA	{"email": "g_trofimova-04111976@postgrespro.ru", "phone": "+70828504582"}
0005435252579	04B23E	8312 228967	MAKSIM FEDOROV	{"phone": "+70923416148"}
0005435252580	C76BCB	3536 344797	ANTONINA POLYAKOVA	{"phone": "+70261809501"}
0005435252581	1EF568	8690 436073	NINA MALYSHEVA	{"email": "nina.malysheva_05091980@postgrespro.ru", "phone": "+70580114929"}
0005435252582	1EF568	6777 243638	YULIYA SERGEEVA	{"phone": "+70027967545"}
0005435252583	27DF20	9587 095447	IVAN SOROKIN	{"email": "ivan_sorokin_1975@postgrespro.ru", "phone": "+70024936833"}
0005435252584	A20346	6247 518740	ANATOLIY ZAKHAROV	{"phone": "+70014108508"}
0005435252585	A20346	4901 605221	TAMARA GUSEVA	{"phone": "+70522400663"}
0005435252586	A20346	6999 862914	EMIL DAVYDOV	{"email": "emildavydov_03011986@postgrespro.ru", "phone": "+70640839550"}
0005435252587	FBA005	1169 902763	KSENIYA SMIRNOVA	{"phone": "+70879530133"}
0005435252588	65307D	1545 650750	FATIMA KALININA	{"phone": "+70684563576"}
0005435252589	65307D	6158 861566	VITALIY KOROLEV	{"email": "korolev_v1978@postgrespro.ru", "phone": "+70136744110"}
0005435252590	2DFDC6	9375 252329	ALEKSANDR SIDOROV	{"email": "sidorov_aleksandr-02101971@postgrespro.ru", "phone": "+70774939678"}
0005435252591	CBB26C	5513 651921	ALEKSANDR PETROV	{"phone": "+70031248767"}
0005435252592	D72EA6	4671 534416	LYUDMILA PAVLOVA	{"phone": "+70994256134"}
0005435252593	9D64AA	5017 349742	ALEKSANDR SERGEEV	{"email": "a.sergeev16071979@postgrespro.ru", "phone": "+70398849637"}
0005435252594	9D64AA	0877 637932	SERGEY ZAYCEV	{"phone": "+70782781652"}
0005435252595	54D481	0011 680423	ALEKSANDR BARANOV	{"phone": "+70118232566"}
0005435252596	2C1A75	2416 115417	ALEKSANDR ABRAMOV	{"phone": "+70345512081"}
0005435252597	2C1A75	1631 786845	ELENA MAKAROVA	{"phone": "+70696857397"}
0005435252598	F3CEE9	0448 514162	OKSANA DANILOVA	{"email": "danilova.oksana1968@postgrespro.ru", "phone": "+70513511751"}
0005435252599	17E065	8802 192456	ELENA IVANOVA	{"phone": "+70301023551"}
0005435252600	FE2F68	0230 110056	ALEKSANDR KOZLOV	{"phone": "+70883184272"}
0005435252601	A623AD	2569 039823	ANASTASIYA GORBUNOVA	{"email": "agorbunova11071965@postgrespro.ru", "phone": "+70746196085"}
0005435252602	BEC7F2	5981 307884	ALEKSEY VOROBEV	{"phone": "+70712530438"}
0005435252603	BEC7F2	4613 638290	ANASTASIYA MATVEEVA	{"phone": "+70297831555"}
0005435252604	87EB43	3089 745703	KIRILL YAKOVLEV	{"email": "yakovlev.kirill_041969@postgrespro.ru", "phone": "+70915809443"}
0005435252605	B1362E	2668 096417	ANTONINA MALYSHEVA	{"phone": "+70636002652"}
0005435252606	064BF3	4115 789955	ARKADIY FEDOTOV	{"phone": "+70989164671"}
0005435252607	B6192E	3121 241235	TATYANA ZHUKOVA	{"phone": "+70003335487"}
0005435252608	2B144D	9852 854496	VALENTINA TIKHONOVA	{"email": "tikhonova-v-021972@postgrespro.ru", "phone": "+70467737271"}
0005435252609	2B144D	5876 542625	ELMIRA NOVIKOVA	{"email": "enovikova-05091971@postgrespro.ru", "phone": "+70274902255"}
0005435252610	2B144D	5736 471885	OLGA SEMENOVA	{"email": "o-semenova-1971@postgrespro.ru", "phone": "+70483014298"}
0005435252611	4AA54A	5555 635057	NINA ARKHIPOVA	{"email": "nina.arkhipova-111972@postgrespro.ru", "phone": "+70047333904"}
0005435252612	8A4CFA	0936 541100	ALEKSANDRA NOVIKOVA	{"email": "aleksandranovikova_031974@postgrespro.ru", "phone": "+70388364262"}
0005435252613	AAECF8	1151 379446	VALENTINA DAVYDOVA	{"phone": "+70103086109"}
0005435252614	187B07	7057 468435	YANA CHERNOVA	{"email": "yana-chernova_041978@postgrespro.ru", "phone": "+70385616459"}
0005435252615	ECA862	4524 253640	VYACHESLAV MARTYNOV	{"phone": "+70889879023"}
0005435252616	AE5226	2468 542656	ALFIYA MOROZOVA	{"email": "morozova-a.111974@postgrespro.ru", "phone": "+70407192607"}
0005435252617	331433	2784 617684	OLGA ISAEVA	{"email": "isaevao_15011978@postgrespro.ru", "phone": "+70645019360"}
0005435252618	331433	4502 095317	MARIYA FROLOVA	{"email": "frolova-m031973@postgrespro.ru", "phone": "+70849862567"}
0005435252619	036699	2192 837108	ZOYA KUZMINA	{"phone": "+70557455388"}
0005435252620	370359	5690 731429	SERGEY PETROV	{"email": "s_petrov-21111974@postgrespro.ru", "phone": "+70613424451"}
0005435252621	387673	5192 310860	ALEKSANDR BORISOV	{"email": "aleksandr_borisov091975@postgrespro.ru", "phone": "+70027464636"}
0005435252622	7B79A2	6310 296867	SERGEY GORBUNOV	{"email": "gorbunov-sergey-20051963@postgrespro.ru", "phone": "+70724406048"}
0005435252623	968347	5423 552308	GULFIYA KOZLOVA	{"email": "kozlova.g1961@postgrespro.ru", "phone": "+70030393711"}
0005435252624	CFB8F1	2021 641589	VLADIMIR SEMENOV	{"phone": "+70014961623"}
0005435252625	CDFBCF	5604 103436	KLAVDIYA SERGEEVA	{"phone": "+70735533927"}
0005435252626	5FB363	4776 178084	ALEKSANDR KUZMIN	{"phone": "+70952889561"}
0005435252627	B1E4EC	3690 176681	NADEZHDA VASILEVA	{"email": "vasileva-n.11091974@postgrespro.ru", "phone": "+70974546983"}
0005435252628	FD5EDE	7664 218161	NATALYA VASILEVA	{"email": "vasileva-natalya_091970@postgrespro.ru", "phone": "+70524071402"}
0005435252629	FD5EDE	6922 413334	VIKTOR SIDOROV	{"email": "v.sidorov.031982@postgrespro.ru", "phone": "+70318901035"}
0005435252630	A76A7F	0342 722173	BOGDAN PAVLOV	{"phone": "+70358017365"}
0005435252631	A76A7F	4347 241778	POLINA POPOVA	{"email": "popova.polina-27111963@postgrespro.ru", "phone": "+70720105706"}
0005435252632	A79432	1619 197421	ZOYA VASILEVA	{"phone": "+70242700388"}
0005435252633	482F48	8906 455780	TATYANA MOROZOVA	{"phone": "+70541493508"}
0005435252634	A687C3	3258 518430	ANDREY GRIGOREV	{"email": "a.grigorev_111961@postgrespro.ru", "phone": "+70415739453"}
0005435252635	A687C3	1436 314468	MARIYA SOKOLOVA	{"phone": "+70163439680"}
0005435252636	3ADD8B	3586 334298	EKATERINA MATVEEVA	{"email": "e-matveeva-14091960@postgrespro.ru", "phone": "+70367053212"}
0005435252637	96E013	5830 351918	ELENA ALEKSANDROVA	{"email": "aleksandrovaelena_061970@postgrespro.ru", "phone": "+70155214366"}
0005435252638	96E013	1228 687537	OLGA KAZAKOVA	{"phone": "+70322018695"}
0005435252639	2BB201	6745 612346	VERA MARTYNOVA	{"email": "v.martynova-041972@postgrespro.ru", "phone": "+70556133872"}
0005435252640	2BB201	3977 496145	YURIY SAVELEV	{"email": "savelev.yuriy20101971@postgrespro.ru", "phone": "+70378141633"}
0005435252641	2BB201	1512 435152	DMITRIY TARASOV	{"email": "d-tarasov21021969@postgrespro.ru", "phone": "+70365712118"}
0005435252642	876395	6621 234365	VLADIMIR VASILEV	{"phone": "+70831438564"}
0005435252643	C3BA40	1641 588613	ALEKSANDR TARASOV	{"email": "tarasov-a.1983@postgrespro.ru", "phone": "+70769045881"}
0005435252644	62AFA3	2312 939990	TATYANA VASILEVA	{"email": "vasileva.t-08091972@postgrespro.ru", "phone": "+70298025826"}
0005435252645	D59826	7499 732106	ELENA ZAKHAROVA	{"phone": "+70566798069"}
0005435252646	D59826	9573 634206	ANASTASIYA IVANOVA	{"email": "anastasiyaivanova021974@postgrespro.ru", "phone": "+70616093445"}
0005435252647	64AEB0	7827 840286	ALEKSEY PETROV	{"phone": "+70660468614"}
0005435252648	64AEB0	4244 134072	VALERIY SHEVCHENKO	{"email": "valeriy-shevchenko-12091966@postgrespro.ru", "phone": "+70906715579"}
0005435252649	64AEB0	3887 842374	SVETLANA SCHERBAKOVA	{"phone": "+70196587895"}
0005435252650	290B8A	7518 996636	ALISA SAVELEVA	{"phone": "+70356773561"}
0005435252651	4C0B5D	0979 176174	NATALYA FROLOVA	{"email": "frolova_n.031978@postgrespro.ru", "phone": "+70794956901"}
0005435252652	4C0B5D	2499 376817	YURIY GERASIMOV	{"email": "yuriy_gerasimov-1968@postgrespro.ru", "phone": "+70038707290"}
0005435252653	957A7C	1356 794053	YAROSLAV IVANOV	{"phone": "+70011642097"}
0005435252654	7544D8	8635 137951	LIDIYA VOROBEVA	{"phone": "+70938477096"}
0005435252655	C871A9	2979 407273	TATYANA GAVRILOVA	{"email": "gavrilova_tatyana28121982@postgrespro.ru", "phone": "+70381847434"}
0005435252656	56F6CA	5261 980692	NADEZHDA MOISEEVA	{"email": "moiseeva_nadezhda031962@postgrespro.ru", "phone": "+70594356278"}
0005435252657	248F27	3059 038307	GENNADIY POPOV	{"email": "popovg_1971@postgrespro.ru", "phone": "+70725117775"}
0005435252658	248F27	7056 274382	ALEKSANDR ABRAMOV	{"email": "aleksandr_abramov-071971@postgrespro.ru", "phone": "+70745031114"}
0005435252659	5352D8	7299 776913	GALINA MOISEEVA	{"phone": "+70736706481"}
0005435252660	E514FC	7710 345561	LARISA ZHUKOVA	{"phone": "+70639810080"}
0005435252661	02CE80	5013 221657	ANDREY NAUMOV	{"phone": "+70804895570"}
0005435252662	02CE80	9267 358604	LIDIYA NAUMOVA	{"email": "l-naumova03051978@postgrespro.ru", "phone": "+70820459851"}
0005435252663	B19AD0	1607 151388	NIKITA ROMANOV	{"email": "romanovn_1976@postgrespro.ru", "phone": "+70131113298"}
0005435252664	D6037E	0550 349141	OLGA EFREMOVA	{"email": "efremova_olga_1976@postgrespro.ru", "phone": "+70426563318"}
0005435252665	D6037E	1153 954210	DANILA IVANOV	{"phone": "+70032464520"}
0005435252666	624AD6	5989 185178	GALINA ANDREEVA	{"phone": "+70178963912"}
0005435252667	4320BC	7989 485938	VASILIY TIMOFEEV	{"email": "vasiliy.timofeev20081964@postgrespro.ru", "phone": "+70300137033"}
0005435252668	931F51	5256 705745	NELLI KRASNOVA	{"email": "n.krasnova_1967@postgrespro.ru", "phone": "+70227987034"}
0005435252669	91D07B	4325 140166	LIDIYA KAZAKOVA	{"email": "l.kazakova.1965@postgrespro.ru", "phone": "+70346066287"}
0005435252670	87A241	2544 533329	YURIY BELOV	{"email": "belov_y-1966@postgrespro.ru", "phone": "+70007146716"}
0005435252671	AED74E	5458 721086	NIKOLAY KUZNECOV	{"phone": "+70280177167"}
0005435252672	1B63BB	2139 487859	ALEKSEY EGOROV	{"phone": "+70918907828"}
0005435252673	542590	8565 820036	ELENA ERMAKOVA	{"phone": "+70516009941"}
0005435252674	D32911	8834 715629	NADEZHDA VASILEVA	{"phone": "+70167355730"}
0005435252675	506F16	9697 738740	SERGEY ALEKSANDROV	{"phone": "+70527679425"}
0005435252676	8C08A8	9333 636665	MIKHAIL FILIPPOV	{"phone": "+70789675933"}
0005435252677	564AD5	3967 726179	VLADIMIR BORISOV	{"email": "vladimirborisov_061974@postgrespro.ru", "phone": "+70849305360"}
0005435252678	564AD5	8186 527102	ANASTASIYA PAVLOVA	{"phone": "+70591785190"}
0005435252679	7A7856	7487 087334	MARIYA NIKOLAEVA	{"email": "mariya_nikolaeva_30071964@postgrespro.ru", "phone": "+70694258888"}
0005435252680	B28533	9244 758602	ALEKSANDR ZAYCEV	{"email": "a.zaycev30111968@postgrespro.ru", "phone": "+70495811916"}
0005435252681	1577B9	7804 361647	VLADIMIR KUZMIN	{"phone": "+70205036813"}
0005435252682	EAD7D9	7583 291103	DARYA EGOROVA	{"phone": "+70768957583"}
0005435252683	1EF1F3	5852 383378	LIDIYA IVANOVA	{"phone": "+70504771542"}
0005435252684	2CCB2D	5788 926552	LYUDMILA OVCHINNIKOVA	{"email": "ovchinnikoval.021964@postgrespro.ru", "phone": "+70147789844"}
0005435252685	79AFE5	0456 339662	IOSIF ZAKHAROV	{"email": "iosifzakharov_051972@postgrespro.ru", "phone": "+70183439926"}
0005435252686	79AFE5	7640 318576	NIKITA BONDARENKO	{"email": "bondarenko_nikita17091967@postgrespro.ru", "phone": "+70896785540"}
0005435252687	BE2440	8294 716438	SERGEY IVANOV	{"phone": "+70579011012"}
0005435252688	890E64	5404 663769	DMITRIY KAZAKOV	{"email": "dmitriykazakov_1965@postgrespro.ru", "phone": "+70902260289"}
0005435252689	00A947	1884 925945	LYUDMILA DENISOVA	{"email": "lyudmila.denisova_1968@postgrespro.ru", "phone": "+70013627392"}
0005435252690	00A947	8900 416785	ANDREY BORISOV	{"phone": "+70874896856"}
0005435252691	BBC9B7	5782 036600	IVAN SOKOLOV	{"phone": "+70599783212"}
0005435252692	091EE4	4775 240433	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov.121970@postgrespro.ru", "phone": "+70114831483"}
0005435252693	B00106	5884 830693	BORIS SIDOROV	{"email": "borissidorov_101969@postgrespro.ru", "phone": "+70114184213"}
0005435252694	B00106	5796 060267	EKATERINA FOMINA	{"email": "fominae25091985@postgrespro.ru", "phone": "+70579625115"}
0005435252695	388445	8558 179703	VIKTOR FEDOTOV	{"email": "v-fedotov_26071966@postgrespro.ru", "phone": "+70330818485"}
0005435252696	87654D	6968 487436	ALEKSEY ANDREEV	{"email": "alekseyandreev01091962@postgrespro.ru", "phone": "+70902702045"}
0005435252697	87654D	7896 693406	NIKOLAY MOROZOV	{"email": "morozov.n.021978@postgrespro.ru", "phone": "+70830148787"}
0005435252698	7ECC72	7485 457901	LYUBOV GUSEVA	{"phone": "+70496837195"}
0005435252699	85E4B7	0116 069760	RAISA BOGDANOVA	{"phone": "+70059065451"}
0005435252700	85E4B7	9937 816017	NIKOLAY BELOV	{"email": "nikolay.belov_24121969@postgrespro.ru", "phone": "+70423905287"}
0005435252701	85E4B7	2799 613716	TATYANA KONOVALOVA	{"email": "konovalova.t-05111963@postgrespro.ru", "phone": "+70609909173"}
0005435252702	35BC21	9839 023769	VLADIMIR MAKAROV	{"email": "v_makarov_051962@postgrespro.ru", "phone": "+70777883600"}
0005435252703	76D7F8	3023 505134	TATYANA ROMANOVA	{"email": "t_romanova31011963@postgrespro.ru", "phone": "+70442486490"}
0005435252704	6AB0FB	5328 249235	NATALYA MOROZOVA	{"email": "morozova-natalya.081974@postgrespro.ru", "phone": "+70265516297"}
0005435252705	D8D1D8	9960 577377	VIKTOR NIKOLAEV	{"phone": "+70279506954"}
0005435252706	D8D1D8	8209 290080	ARINA NIKOLAEVA	{"email": "nikolaevaarina1981@postgrespro.ru", "phone": "+70899800591"}
0005435252707	93AB9E	8236 732533	IVAN MOISEEV	{"phone": "+70144751527"}
0005435252708	CDD755	7833 673903	ANDREY ROMANOV	{"email": "romanovandrey_16091978@postgrespro.ru", "phone": "+70387880852"}
0005435252709	CDD755	9457 869547	ELENA FADEEVA	{"email": "e_fadeeva091976@postgrespro.ru", "phone": "+70227997771"}
0005435252710	73ECD6	7236 246077	VLADIMIR ZHURAVLEV	{"phone": "+70676011535"}
0005435252711	73ECD6	7518 754551	KLAVDIYA NAZAROVA	{"email": "k_nazarova1964@postgrespro.ru", "phone": "+70952144657"}
0005435252712	942B1D	4816 962579	LYUBOV LUKYANOVA	{"email": "lyubovlukyanova.061968@postgrespro.ru", "phone": "+70963035306"}
0005435252713	942B1D	8180 271136	VADIM NIKITIN	{"phone": "+70510840783"}
0005435252714	6F7CB8	8063 748923	ELENA ZAKHAROVA	{"email": "elena-zakharova-1973@postgrespro.ru", "phone": "+70440556296"}
0005435252715	6F7CB8	7956 739123	ALEKSANDR GUSEV	{"email": "a-gusev-071970@postgrespro.ru", "phone": "+70655495181"}
0005435252716	C70DEA	4592 531569	ANDREY OSIPOV	{"phone": "+70720150690"}
0005435252717	8064DF	5578 266503	ALEKSANDR FEDOROV	{"email": "fedorovaleksandr-18041971@postgrespro.ru", "phone": "+70995216554"}
0005435252718	D0D647	4400 026306	SERGEY IVANOV	{"email": "s.ivanov.1984@postgrespro.ru", "phone": "+70498807162"}
0005435252719	61A18E	8532 350190	SVETLANA SMIRNOVA	{"email": "svetlana_smirnova.1978@postgrespro.ru", "phone": "+70288962021"}
0005435252720	61A18E	1913 565671	TATYANA MATVEEVA	{"phone": "+70124565695"}
0005435252721	AE8018	7663 862540	NAIL ROMANOV	{"phone": "+70842358401"}
0005435252722	AE8018	9799 969175	VALERIY SOROKIN	{"phone": "+70666936175"}
0005435252723	339F67	5799 789619	SVETLANA FILATOVA	{"email": "filatova_s091970@postgrespro.ru", "phone": "+70598178305"}
0005435252724	367DB5	7265 706401	ALEKSEY ROMANOV	{"phone": "+70852426640"}
0005435252725	367DB5	5006 431992	VIKTORIYA FOMINA	{"phone": "+70147546993"}
0005435252726	367DB5	4455 034002	VIKTORIYA NIKOLAEVA	{"email": "nikolaeva_v-1970@postgrespro.ru", "phone": "+70642667510"}
0005435252727	95E8B0	7797 457376	ANDREY GUSEV	{"email": "gusev-a_1980@postgrespro.ru", "phone": "+70023445307"}
0005435252728	914021	8664 871057	VLADIMIR NAUMOV	{"email": "naumov-vladimir.091969@postgrespro.ru", "phone": "+70867365562"}
0005435252729	238F01	7673 303590	ELENA GORBUNOVA	{"email": "e-gorbunova.17011958@postgrespro.ru", "phone": "+70529219588"}
0005435252730	238F01	7945 069850	ELENA MASLOVA	{"phone": "+70207898561"}
0005435252731	9D7B9B	6483 944919	SVETLANA NIKOLAEVA	{"email": "snikolaeva121972@postgrespro.ru", "phone": "+70707114154"}
0005435252732	8B07A0	3318 984624	NATALYA KOMAROVA	{"phone": "+70799507353"}
0005435252733	8B07A0	6228 724635	ROMAN KONOVALOV	{"phone": "+70324439347"}
0005435252734	FEC21C	8385 989149	DANILA MIRONOV	{"phone": "+70451577574"}
0005435252735	FEC21C	8700 503709	ANATOLIY PETROV	{"phone": "+70627377776"}
0005435252736	1FA2E5	3771 650438	VLADIMIR KUZNECOV	{"phone": "+70228956490"}
0005435252737	0C0C34	4695 093646	GALINA PAVLOVA	{"email": "galina-pavlova.021970@postgrespro.ru", "phone": "+70196178027"}
0005435252738	A07637	6898 570228	PAVEL DAVYDOV	{"email": "pavel-davydov1962@postgrespro.ru", "phone": "+70065946195"}
0005435252739	84AE10	7090 794836	RAISA BELYAEVA	{"phone": "+70323942575"}
0005435252740	8534E8	1162 547466	KRISTINA SEMENOVA	{"email": "semenova.kristina_1989@postgrespro.ru", "phone": "+70642929299"}
0005435252741	8534E8	2843 895461	VLADIMIR PAVLOV	{"phone": "+70427598264"}
0005435252742	DDC3B4	3705 097272	INNA TITOVA	{"phone": "+70848051861"}
0005435252743	FE4E19	9571 098541	NATALYA VOLKOVA	{"phone": "+70919818121"}
0005435252744	FE4E19	4057 988077	MARIYA TARASOVA	{"phone": "+70028648104"}
0005435252745	DA8A6E	2795 073346	GALINA NESTEROVA	{"phone": "+70130125367"}
0005435252746	DA8A6E	3315 605184	DARYA ZHURAVLEVA	{"email": "dzhuravleva-061974@postgrespro.ru", "phone": "+70102053599"}
0005435252747	EE53AC	5975 415294	NIKOLAY KUZNECOV	{"email": "n_kuznecov-1965@postgrespro.ru", "phone": "+70239820434"}
0005435252748	EE53AC	7181 607746	GALINA YAKOVLEVA	{"phone": "+70277184995"}
0005435252749	BC6A7B	2729 993866	OKSANA KUZNECOVA	{"phone": "+70106573881"}
0005435252750	BC6A7B	3370 594442	OLGA MIKHAYLOVA	{"phone": "+70404361490"}
0005435252751	F3AB71	9856 747490	RIFAT DAVYDOV	{"email": "davydov.rifat.1974@postgrespro.ru", "phone": "+70427253993"}
0005435252752	9E6CA3	3323 713859	ALEKSANDRA POPOVA	{"email": "popova-aleksandra-1971@postgrespro.ru", "phone": "+70279107582"}
0005435252753	9E6CA3	8928 585541	NATALYA NAUMOVA	{"phone": "+70177716278"}
0005435252754	9E6CA3	1816 402959	SERGEY NOVIKOV	{"email": "sergey-novikov-1971@postgrespro.ru", "phone": "+70959279835"}
0005435252755	3B1309	1023 221817	IRINA KONOVALOVA	{"phone": "+70770695737"}
0005435252756	B92630	2193 133255	KONSTANTIN IVANOV	{"phone": "+70409791540"}
0005435252757	3E8E08	1681 097310	ALEKSANDR SOKOLOV	{"phone": "+70990606604"}
0005435252758	3C5BF3	1834 345857	ALEKSANDR ZHUKOV	{"email": "aleksandr.zhukov_13081976@postgrespro.ru", "phone": "+70246773630"}
0005435252759	82ACC3	2184 776629	MARIYA ALEKSANDROVA	{"email": "aleksandrova_m021966@postgrespro.ru", "phone": "+70283722585"}
0005435252760	82ACC3	2296 985028	VASILISA MAKAROVA	{"phone": "+70082092089"}
0005435252761	69ADA6	0361 190228	ANDREY NOVIKOV	{"email": "novikov-a_1977@postgrespro.ru", "phone": "+70982705153"}
0005435252762	152240	9811 098217	ALIYA CHERNOVA	{"phone": "+70211168012"}
0005435252763	41BDC5	7083 011326	NADEZHDA TIMOFEEVA	{"email": "nadezhda.timofeeva081967@postgrespro.ru", "phone": "+70463529488"}
0005435252764	EE866D	1732 632240	NIKOLAY MELNIKOV	{"email": "melnikovnikolay121968@postgrespro.ru", "phone": "+70672354655"}
0005435252765	402D2E	1562 933966	DINARA NAUMOVA	{"email": "d-naumova_021976@postgrespro.ru", "phone": "+70597353135"}
0005435252766	895F08	3117 373386	VITALIY ALEKSANDROV	{"email": "vitaliy.aleksandrov1973@postgrespro.ru", "phone": "+70209021611"}
0005435252767	895F08	9480 137713	ILYA KISELEV	{"phone": "+70987893876"}
0005435252768	1AD9BC	3070 392340	VIKTORIYA MAKAROVA	{"email": "vmakarova-10031970@postgrespro.ru", "phone": "+70657962690"}
0005435252769	EB65FC	9521 622039	DMITRIY SEMENOV	{"email": "semenov_dmitriy-021975@postgrespro.ru", "phone": "+70785576022"}
0005435252770	EB65FC	7757 281689	NINA IVANOVA	{"email": "n-ivanova.1971@postgrespro.ru", "phone": "+70971077237"}
0005435252771	B04C5B	3427 535067	ALEKSEY KOZLOV	{"email": "kozlovaleksey_09121978@postgrespro.ru", "phone": "+70584731403"}
0005435252772	DAD268	7790 958170	LYUDMILA ANTONOVA	{"phone": "+70453431924"}
0005435252773	4786A3	7967 825997	VLADIMIR ZHUKOV	{"phone": "+70046204776"}
0005435252774	C5F875	8986 251242	VALERIY KONOVALOV	{"email": "konovalov-valeriy_1971@postgrespro.ru", "phone": "+70430637483"}
0005435252775	C4E9F3	6158 751921	VYACHESLAV SERGEEV	{"email": "sergeev_v-1974@postgrespro.ru", "phone": "+70897465657"}
0005435252776	515EE5	2202 949340	RUSLAN KOROLEV	{"email": "rkorolev.061977@postgrespro.ru", "phone": "+70055512993"}
0005435252777	E67069	3230 684565	VLADIMIR ROMANOV	{"phone": "+70066883500"}
0005435252778	B318BE	7225 639281	NAILYA POPOVA	{"email": "popova_nailya1972@postgrespro.ru", "phone": "+70854188399"}
0005435252779	C410B7	8474 787407	ANNA CHERNOVA	{"email": "chernova_a_1959@postgrespro.ru", "phone": "+70285755357"}
0005435252780	C410B7	0838 603781	ALEKSEY BORISOV	{"phone": "+70885869836"}
0005435252781	EE3344	4055 942713	ALEKSEY ROMANOV	{"email": "aleksey-romanov1964@postgrespro.ru", "phone": "+70555841031"}
0005435252782	FE5E79	3598 283029	IVAN FEDOROV	{"phone": "+70613609446"}
0005435252783	FE5E79	6449 264998	OLEG BARANOV	{"phone": "+70689110689"}
0005435252784	B13D39	1237 373032	NATALYA ARKHIPOVA	{"phone": "+70128280386"}
0005435252785	20BBFB	2716 712000	OLGA IVANOVA	{"email": "oivanova-071964@postgrespro.ru", "phone": "+70462305879"}
0005435252786	F540E5	9431 410318	DANILA SERGEEV	{"email": "danilasergeev.1971@postgrespro.ru", "phone": "+70116723352"}
0005435252787	552018	4776 536765	LILIYA RODIONOVA	{"phone": "+70265913078"}
0005435252788	9B7EA7	0979 545900	ILMIR EGOROV	{"email": "egorov.i_1974@postgrespro.ru", "phone": "+70744453232"}
0005435252789	9B7EA7	1206 785699	TIKHON NIKOLAEV	{"phone": "+70500159357"}
0005435252790	F91DFD	7628 893300	SERGEY MIKHAYLOV	{"email": "s.mikhaylov-24091973@postgrespro.ru", "phone": "+70035004238"}
0005435252791	F91DFD	5438 521858	NIKOLAY KUZNECOV	{"phone": "+70913725085"}
0005435252792	05671C	8676 257922	ANASTASIYA NIKOLAEVA	{"phone": "+70527766733"}
0005435252793	0AFCCB	8246 579686	ANTONINA NESTEROVA	{"phone": "+70627769906"}
0005435252794	53A140	1171 229001	SERGEY NIKOLAEV	{"phone": "+70687778730"}
0005435252795	31E90C	7028 015360	ELENA POPOVA	{"email": "elena_popova.28081979@postgrespro.ru", "phone": "+70144139879"}
0005435252796	31E90C	7164 655074	TATYANA SERGEEVA	{"phone": "+70899815865"}
0005435252797	812019	0864 249581	ANDREY SERGEEV	{"email": "andrey.sergeev021963@postgrespro.ru", "phone": "+70910713105"}
0005435252798	1E2170	1187 218992	LYUDMILA NAUMOVA	{"email": "naumova_l031976@postgrespro.ru", "phone": "+70560371992"}
0005435252799	37FB15	6003 125963	PELAGEYA SOROKINA	{"email": "sorokina-pelageya-121964@postgrespro.ru", "phone": "+70720022952"}
0005435252800	37FB15	6264 967386	ANDREY OSIPOV	{"email": "osipov-a-22041981@postgrespro.ru", "phone": "+70036859675"}
0005435252801	BDCAD9	9818 180389	VLADIMIR IVANOV	{"email": "vivanov_1980@postgrespro.ru", "phone": "+70584957517"}
0005435252802	BDCAD9	4400 730124	ANDREY NIKOLAEV	{"phone": "+70106064891"}
0005435252803	355BAE	1837 616363	TATYANA SCHERBAKOVA	{"phone": "+70622420585"}
0005435252804	8D3D96	2679 725397	KLAVDIYA ANTONOVA	{"email": "antonova_klavdiya.121978@postgrespro.ru", "phone": "+70872869911"}
0005435252805	0185EA	8292 797973	GALINA VASILEVA	{"email": "vasileva.galina.28071970@postgrespro.ru", "phone": "+70547582785"}
0005435252806	FC28F2	9990 057453	LYUDMILA KUZMINA	{"email": "lyudmila_kuzmina.101970@postgrespro.ru", "phone": "+70784448713"}
0005435252807	D4B39D	7481 074564	YULIYA IVANOVA	{"phone": "+70249204475"}
0005435252808	99FB8B	8118 135413	VADIM GRIGOREV	{"email": "vgrigorev_031978@postgrespro.ru", "phone": "+70843242934"}
0005435252809	8D379A	0689 585743	ZOYA BORISOVA	{"email": "borisovaz.091972@postgrespro.ru", "phone": "+70212206497"}
0005435252810	8D379A	3909 089717	ELENA MALYSHEVA	{"email": "e.malysheva24121974@postgrespro.ru", "phone": "+70277778347"}
0005435252811	6A4F39	4634 300894	IGOR VOROBEV	{"email": "vorobevi.1970@postgrespro.ru", "phone": "+70235309082"}
0005435252812	9ABC5E	2723 427124	VLADISLAV FOMIN	{"phone": "+70515618686"}
0005435252813	D1C0F9	7821 931979	GALINA SIDOROVA	{"phone": "+70408594800"}
0005435252814	ECC8F3	8495 754317	NADEZHDA IVANOVA	{"email": "n.ivanova-06041977@postgrespro.ru", "phone": "+70956094136"}
0005435252815	2AC4BA	1178 782550	VERA AKIMOVA	{"phone": "+70697725831"}
0005435252816	2AC4BA	1642 951555	NINA POLYAKOVA	{"phone": "+70575331863"}
0005435253040	DFF6EF	1545 781030	YAKOV BORISOV	{"phone": "+70682577122"}
0005435252817	C71C9C	7015 151351	VYACHESLAV SEMENOV	{"email": "vyacheslav-semenov_30041973@postgrespro.ru", "phone": "+70141833952"}
0005435252818	F2C078	2424 361155	TAISIYA KOZLOVA	{"email": "t_kozlova10031973@postgrespro.ru", "phone": "+70243357613"}
0005435252819	A40B26	8192 162111	IVAN FROLOV	{"phone": "+70465652966"}
0005435252820	A40B26	2037 640677	YULIYA EFIMOVA	{"phone": "+70570717652"}
0005435252821	BB624E	7658 458703	ANASTASIYA KOMAROVA	{"email": "komarova_anastasiya121963@postgrespro.ru", "phone": "+70772609365"}
0005435252822	9B7F06	6005 452623	OLGA KONDRATEVA	{"email": "olga.kondrateva-1968@postgrespro.ru", "phone": "+70389299981"}
0005435252823	9B7F06	6063 791133	VALERIY MEDVEDEV	{"phone": "+70761484738"}
0005435252824	9B7F06	9600 554411	VALERIY VOROBEV	{"phone": "+70541539292"}
0005435252825	152E95	5664 326135	ALEKSANDR SAVELEV	{"email": "aleksandr.savelev.091972@postgrespro.ru", "phone": "+70951051543"}
0005435252826	05F77D	8861 371723	ANATOLIY FILIPPOV	{"email": "filippov-anatoliy.081985@postgrespro.ru", "phone": "+70216420935"}
0005435252827	086F1E	8681 143283	TATYANA ANDREEVA	{"phone": "+70579414089"}
0005435252828	D9D31F	5385 662836	SERGEY FOMIN	{"email": "sergey_fomin091970@postgrespro.ru", "phone": "+70820358194"}
0005435252829	D9D31F	3665 974770	LIDIYA GORBUNOVA	{"phone": "+70108949105"}
0005435252830	8165A5	3546 858961	YULIYA GAVRILOVA	{"email": "gavrilova-y18071974@postgrespro.ru", "phone": "+70321969833"}
0005435252831	6B3EEF	2657 626743	DMITRIY ZAKHAROV	{"email": "zakharov_dmitriy12081976@postgrespro.ru", "phone": "+70285605312"}
0005435252832	1CCDAB	2639 837598	TATYANA MALYSHEVA	{"email": "tatyanamalysheva.031974@postgrespro.ru", "phone": "+70482625649"}
0005435252833	100580	9703 917519	ELENA SAVELEVA	{"email": "saveleva_elena_02111976@postgrespro.ru", "phone": "+70031688164"}
0005435252834	8E86AA	8963 828956	IRINA MASLOVA	{"email": "irina.maslova03121966@postgrespro.ru", "phone": "+70709396953"}
0005435252835	943107	1836 418190	ALEKSANDRA TITOVA	{"phone": "+70443022314"}
0005435252836	2CA6AB	5657 184498	VALENTIN MAKAROV	{"phone": "+70241684018"}
0005435252837	943E42	9606 744833	GRIGORIY MATVEEV	{"email": "matveevg.20011967@postgrespro.ru", "phone": "+70631249465"}
0005435252838	943E42	0700 516084	GENNADIY BORISOV	{"phone": "+70947507430"}
0005435252839	F05D5A	3205 094969	ILYA KUZMIN	{"phone": "+70973691983"}
0005435252840	429770	0960 825877	SERGEY KUDRYASHOV	{"email": "kudryashov_sergey.22011979@postgrespro.ru", "phone": "+70077682459"}
0005435252841	429770	0464 863841	TATYANA KUZNECOVA	{"email": "tatyanakuznecova011968@postgrespro.ru", "phone": "+70979241337"}
0005435252842	2EFFA7	7129 349886	YULIYA KUZNECOVA	{"email": "yuliya_kuznecova-13011960@postgrespro.ru", "phone": "+70254503376"}
0005435252843	376036	2902 650175	VLADIMIR MIRONOV	{"email": "mironov-v-051983@postgrespro.ru", "phone": "+70607674737"}
0005435252844	376036	5318 215830	NIKOLAY ALEKSANDROV	{"email": "aleksandrovn_28091967@postgrespro.ru", "phone": "+70509007641"}
0005435252845	8B48BD	4380 896995	VERA STEPANOVA	{"phone": "+70608948196"}
0005435252846	C997BC	9105 925507	EVGENIY GERASIMOV	{"phone": "+70369285936"}
0005435252847	7A8EF9	3277 640489	ANNA MIKHAYLOVA	{"phone": "+70723319600"}
0005435252848	1A08D6	9252 011656	MIKHAIL FEDOTOV	{"email": "fedotov-mikhail.1976@postgrespro.ru", "phone": "+70468857062"}
0005435252849	1A08D6	1969 187782	IRINA OSIPOVA	{"phone": "+70853061085"}
0005435252850	86FF0F	3112 264568	EGOR MAKAROV	{"phone": "+70236900567"}
0005435252851	86FF0F	8491 417093	ALENA KAZAKOVA	{"email": "kazakova-a_1972@postgrespro.ru", "phone": "+70106417047"}
0005435252852	776C8E	6764 514802	DENIS NOVIKOV	{"email": "novikov.d041962@postgrespro.ru", "phone": "+70650674341"}
0005435252853	DB0AB1	2177 876635	KSENIYA SEMENOVA	{"email": "semenova-kseniya.04081969@postgrespro.ru", "phone": "+70810271385"}
0005435252854	08A87C	1196 409753	IRINA RYABOVA	{"email": "ryabova-i_14061979@postgrespro.ru", "phone": "+70733299995"}
0005435252855	08A87C	9550 009580	SERGEY KUZNECOV	{"email": "s.kuznecov051973@postgrespro.ru", "phone": "+70796853425"}
0005435252856	79FCFA	0314 030592	EGOR MOROZOV	{"phone": "+70918548983"}
0005435252857	79FCFA	1958 331630	LYUDMILA ILINA	{"phone": "+70342408511"}
0005435252858	79FCFA	1586 070005	LYUBOV RODIONOVA	{"email": "rodionoval04031975@postgrespro.ru", "phone": "+70018492410"}
0005435252859	B39240	3377 770122	NAIL EGOROV	{"email": "n.egorov04021960@postgrespro.ru", "phone": "+70320779491"}
0005435252860	33DEF3	6891 577389	NELLYA ZAKHAROVA	{"email": "nellya_zakharova1965@postgrespro.ru", "phone": "+70410175649"}
0005435252861	9A0B37	2897 684494	ALEKSEY KISELEV	{"phone": "+70340501506"}
0005435252862	0BA329	4343 044634	MIKHAIL KUZNECOV	{"phone": "+70873317642"}
0005435252863	0BA329	7995 459661	TATYANA LOGINOVA	{"phone": "+70444484371"}
0005435252864	41407D	0915 527360	TATYANA LOGINOVA	{"email": "loginova_tatyana.15031965@postgrespro.ru", "phone": "+70233439338"}
0005435252865	41407D	9149 122814	MAKSIM KUZNECOV	{"email": "maksim-kuznecov101964@postgrespro.ru", "phone": "+70087197654"}
0005435252866	9ACC74	0049 733089	TATYANA OSIPOVA	{"phone": "+70700712060"}
0005435252867	881913	9559 043585	ALEKSANDR MAKAROV	{"phone": "+70328962007"}
0005435252868	90E379	7253 747642	ANATOLIY MIRONOV	{"email": "anatoliymironov-1965@postgrespro.ru", "phone": "+70766287379"}
0005435252869	ED1281	3999 612003	TAMARA FILIPPOVA	{"email": "tamara_filippova091975@postgrespro.ru", "phone": "+70732459716"}
0005435252870	BC3237	2992 737950	NIKOLAY SMIRNOV	{"phone": "+70014177804"}
0005435252871	EB1702	5188 269046	VIKTOR FILIPPOV	{"email": "filippov_viktor27101961@postgrespro.ru", "phone": "+70788685221"}
0005435252872	EB1702	4944 471477	ELVIRA DAVYDOVA	{"email": "davydova_e-121984@postgrespro.ru", "phone": "+70057299257"}
0005435252873	044DB9	3752 598623	IRINA IVANOVA	{"phone": "+70226834829"}
0005435252874	F99A51	1059 805580	ELENA YUDINA	{"phone": "+70323331299"}
0005435252875	F3089D	9328 116377	SERGEY ZAYCEV	{"phone": "+70492998149"}
0005435252876	F3089D	8835 421339	ELENA BARANOVA	{"email": "baranova_e.1975@postgrespro.ru", "phone": "+70041391999"}
0005435252877	6010F2	1052 274392	NATALIYA SEMENOVA	{"email": "nsemenova-1978@postgrespro.ru", "phone": "+70419950559"}
0005435252878	09A24E	2887 493171	EKATERINA NAUMOVA	{"phone": "+70605289064"}
0005435252879	3A3385	2457 159957	ANASTASIYA FADEEVA	{"phone": "+70354425179"}
0005435252880	979D9A	4733 788570	ZOYA PETROVA	{"phone": "+70902608557"}
0005435252881	410B99	3010 634080	OLGA SEMENOVA	{"phone": "+70681463899"}
0005435252882	16ED04	8502 065585	PAVEL KUZMIN	{"phone": "+70205385825"}
0005435252883	F0DA8A	8897 813367	RODION RODIONOV	{"phone": "+70144916126"}
0005435252884	7E9FD5	5829 512830	TAMARA KONOVALOVA	{"phone": "+70176374163"}
0005435252885	A1E080	1689 873027	IVAN SCHERBAKOV	{"phone": "+70671937866"}
0005435252886	605589	6491 139828	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-051972@postgrespro.ru", "phone": "+70938477909"}
0005435252887	3B370E	8730 026381	ALINA SERGEEVA	{"email": "alina-sergeeva.25121981@postgrespro.ru", "phone": "+70341051916"}
0005435252888	3B370E	6142 962017	VLADIMIR TIMOFEEV	{"email": "vladimir.timofeev.16051974@postgrespro.ru", "phone": "+70577083919"}
0005435252889	1C28F8	9985 876655	LARISA EFIMOVA	{"email": "larisa_efimova22031971@postgrespro.ru", "phone": "+70971390979"}
0005435252890	4280E2	5895 795234	TATYANA NOVIKOVA	{"email": "tatyananovikova_051971@postgrespro.ru", "phone": "+70096087517"}
0005435252891	734014	2689 216487	IRINA GUSEVA	{"phone": "+70236684578"}
0005435252892	734014	6907 020535	MARIYA FEDOROVA	{"phone": "+70635651607"}
0005435252893	5821D1	5665 133433	ELENA PETROVA	{"email": "petrova-e.08101958@postgrespro.ru", "phone": "+70640427886"}
0005435252894	0C54D5	1573 517002	NINA IVANOVA	{"phone": "+70501500953"}
0005435252895	0C54D5	2870 044728	EKATERINA BOGDANOVA	{"email": "ebogdanova.01011976@postgrespro.ru", "phone": "+70878019955"}
0005435252896	5ACC1F	4851 013267	ALEKSANDR VOLKOV	{"email": "a.volkov-06011988@postgrespro.ru", "phone": "+70941165604"}
0005435252897	8EF369	7012 638947	NATALYA PETROVA	{"email": "natalya_petrova.081982@postgrespro.ru", "phone": "+70356674968"}
0005435252898	69E51C	3425 003269	VLADIMIR AFANASEV	{"email": "v.afanasev-1972@postgrespro.ru", "phone": "+70517363146"}
0005435252899	0DD5B7	5723 107039	YURIY POPOV	{"email": "y_popov.03111969@postgrespro.ru", "phone": "+70408261029"}
0005435252900	81EB0E	6903 460811	LYUDMILA DANILOVA	{"email": "danilova.lyudmila.1970@postgrespro.ru", "phone": "+70194629412"}
0005435252901	3C37DB	3187 821566	SVETLANA SEMENOVA	{"email": "semenova.svetlana_031982@postgrespro.ru", "phone": "+70519773104"}
0005435252902	3C37DB	4119 295791	SERGEY KUZNECOV	{"email": "sergey_kuznecov-081968@postgrespro.ru", "phone": "+70195568312"}
0005435252903	11F94A	7895 969970	LILIYA IVANOVA	{"phone": "+70304391866"}
0005435252904	92CC07	6211 333231	TATYANA VASILEVA	{"phone": "+70605860020"}
0005435252905	E72F3C	3342 973567	TATYANA EGOROVA	{"phone": "+70341502939"}
0005435252906	9D68EF	8529 750840	PAVEL ANTONOV	{"phone": "+70965921542"}
0005435252907	3109EA	7933 614121	SVETLANA MOISEEVA	{"phone": "+70993133069"}
0005435252908	636DB6	3209 330792	DARYA BOGDANOVA	{"phone": "+70996027845"}
0005435252909	636DB6	1792 136255	SERGEY MIKHAYLOV	{"email": "mikhaylov.s.22111974@postgrespro.ru", "phone": "+70288200018"}
0005435252910	5B375C	6599 273213	OLGA OSIPOVA	{"phone": "+70090835668"}
0005435252911	BC00F7	8973 387603	PETR NIKITIN	{"email": "pnikitin-18111978@postgrespro.ru", "phone": "+70510171688"}
0005435252912	BC00F7	1310 828648	ZOYA ISAEVA	{"email": "zoya.isaeva-1972@postgrespro.ru", "phone": "+70371479498"}
0005435252913	DAFA72	2640 969065	LYUBOV RODIONOVA	{"phone": "+70078675860"}
0005435252914	CA170D	5223 969272	SERGEY BONDARENKO	{"phone": "+70731026728"}
0005435252915	CA170D	1017 409081	ELENA BOGDANOVA	{"email": "bogdanova.e.16041978@postgrespro.ru", "phone": "+70335296385"}
0005435252916	42A22B	2687 215631	ANASTASIYA NIKOLAEVA	{"email": "nikolaevaa_071961@postgrespro.ru", "phone": "+70285403801"}
0005435252917	16CBF7	1569 538465	REGINA NOVIKOVA	{"email": "novikovar-021979@postgrespro.ru", "phone": "+70433794956"}
0005435252918	E49838	3117 294077	TAMARA AKIMOVA	{"email": "tamara-akimova_31011973@postgrespro.ru", "phone": "+70915460569"}
0005435252919	63EF66	4173 665994	ELIZAVETA VASILEVA	{"phone": "+70873267252"}
0005435252920	63EF66	8506 472947	ELENA LOGINOVA	{"phone": "+70093371944"}
0005435252921	3281AE	4578 932859	DARYA NIKITINA	{"email": "darya_nikitina.1973@postgrespro.ru", "phone": "+70095194059"}
0005435252922	3281AE	2291 368320	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov_20031975@postgrespro.ru", "phone": "+70246959611"}
0005435252923	C268EB	8487 470221	SVETLANA ABRAMOVA	{"email": "abramovas1983@postgrespro.ru", "phone": "+70017759413"}
0005435252924	C268EB	8403 278728	NATALYA NAUMOVA	{"phone": "+70040510918"}
0005435252925	53BEEE	7466 147610	IGOR SMIRNOV	{"phone": "+70828422910"}
0005435252926	FC024C	0166 194570	ELENA FEDOROVA	{"phone": "+70014720238"}
0005435252927	FC024C	8763 852094	ALEKSANDR ZAKHAROV	{"phone": "+70019587014"}
0005435252928	31B288	4252 211812	ROMAN ROMANOV	{"phone": "+70469990786"}
0005435252929	31B288	4574 844521	TATYANA ALEKSANDROVA	{"email": "tatyana_aleksandrova_06031982@postgrespro.ru", "phone": "+70689534720"}
0005435252930	32C773	6577 422155	SERGEY CHERNOV	{"email": "schernov_011966@postgrespro.ru", "phone": "+70836652354"}
0005435252931	32C773	0005 771221	OLGA YUDINA	{"phone": "+70315272577"}
0005435252932	E594A2	7422 383010	NINA MELNIKOVA	{"email": "n_melnikova-051963@postgrespro.ru", "phone": "+70800892886"}
0005435252933	1C4DC3	5758 496329	VERA MOROZOVA	{"email": "morozova-vera_091973@postgrespro.ru", "phone": "+70443409967"}
0005435252934	AA929A	7488 773258	ARTEM MIRONOV	{"email": "mironov.a-1970@postgrespro.ru", "phone": "+70809801671"}
0005435252935	624B98	9002 392963	ELVINA KULIKOVA	{"email": "e-kulikova_1982@postgrespro.ru", "phone": "+70735765543"}
0005435252936	624B98	9652 916787	FEDOR SAVELEV	{"email": "savelev_f_101979@postgrespro.ru", "phone": "+70718275628"}
0005435252937	A1E922	3782 870928	ALEKSANDR EGOROV	{"phone": "+70976563524"}
0005435252938	B12CE8	0040 508808	VALERIY KUZNECOV	{"email": "vkuznecov_27061974@postgrespro.ru", "phone": "+70311012538"}
0005435252939	B12CE8	4830 978819	MARINA MELNIKOVA	{"phone": "+70179094247"}
0005435252940	629105	4228 552506	INGA MASLOVA	{"phone": "+70629520853"}
0005435252941	521082	0183 094631	OLEG TARASOV	{"email": "tarasov.oleg_021971@postgrespro.ru", "phone": "+70250745906"}
0005435252942	6A7797	7072 495516	TATYANA ROMANOVA	{"email": "romanova_tatyana011977@postgrespro.ru", "phone": "+70433987581"}
0005435252943	6A7797	6037 523281	SERGEY ALEKSEEV	{"phone": "+70056628885"}
0005435252944	9DDFB9	7819 492730	OLEG EGOROV	{"phone": "+70805911115"}
0005435252945	E22BED	9201 493639	MIKHAIL KOZLOV	{"email": "kozlov_m.081984@postgrespro.ru", "phone": "+70788858683"}
0005435252946	E22BED	1610 996485	NINEL NIKOLAEVA	{"email": "nnikolaeva-1977@postgrespro.ru", "phone": "+70198678913"}
0005435252947	847BC4	6362 870986	LARISA SMIRNOVA	{"phone": "+70950120521"}
0005435252948	847BC4	8878 488217	SERGEY MAKSIMOV	{"email": "maksimov_s-15121973@postgrespro.ru", "phone": "+70460225897"}
0005435252949	847BC4	3181 459683	ANASTASIYA AKIMOVA	{"phone": "+70705862569"}
0005435252950	85019B	2339 021597	OLGA KULIKOVA	{"email": "olga_kulikova-14011966@postgrespro.ru", "phone": "+70727930402"}
0005435252951	E9D72B	4624 508564	OLESYA MOROZOVA	{"phone": "+70105736083"}
0005435252952	879CAA	7734 525571	SERGEY SMIRNOV	{"phone": "+70112044977"}
0005435252953	1EAC17	9448 795941	TAISIYA STEPANOVA	{"phone": "+70178298123"}
0005435252954	D6DA24	8961 938632	OLGA VOROBEVA	{"email": "vorobeva_o.091972@postgrespro.ru", "phone": "+70943116629"}
0005435252955	D6DA24	9079 813884	IVAN PAVLOV	{"email": "ipavlov011976@postgrespro.ru", "phone": "+70146796986"}
0005435252956	6B10FE	2504 902713	IGOR KULIKOV	{"email": "kulikov_igor_1967@postgrespro.ru", "phone": "+70032197114"}
0005435252957	B459D8	6580 306746	IVAN IVANOV	{"phone": "+70395788371"}
0005435252958	4F7EFD	4083 748699	ELIZAVETA LOGINOVA	{"email": "loginova_e041968@postgrespro.ru", "phone": "+70021074597"}
0005435252959	4F7EFD	7144 500922	MARGARITA NAUMOVA	{"email": "naumova.margarita.31101964@postgrespro.ru", "phone": "+70928000825"}
0005435252960	36C7C7	1464 700343	LYUBOV NIKIFOROVA	{"phone": "+70293787243"}
0005435252961	66A32C	1312 928491	VITALIY DMITRIEV	{"email": "dmitriev-v-1965@postgrespro.ru", "phone": "+70592128003"}
0005435252962	C61E5E	9032 709135	ZINAIDA NIKIFOROVA	{"phone": "+70453639055"}
0005435252963	428134	1219 134361	TAISIYA BORISOVA	{"email": "borisova_t-1978@postgrespro.ru", "phone": "+70226662703"}
0005435252964	98D70C	5984 114866	EVGENIY POPOV	{"email": "e-popov.101967@postgrespro.ru", "phone": "+70869055165"}
0005435252965	98D70C	2344 106715	OKSANA CHERNOVA	{"email": "chernova-oksana081973@postgrespro.ru", "phone": "+70984678855"}
0005435252966	A842F1	1245 698239	EKATERINA DANILOVA	{"phone": "+70093686039"}
0005435252967	1C450F	3490 621937	GALINA VASILEVA	{"phone": "+70337722210"}
0005435252968	8E09C9	5172 597403	DANILA GUSEV	{"email": "gusevdanila-14071969@postgrespro.ru", "phone": "+70334208803"}
0005435252969	2D55E7	3428 783271	VLADIMIR VOLKOV	{"phone": "+70918290495"}
0005435252970	7857A7	7033 482058	ANASTASIYA ALEKSEEVA	{"email": "a.alekseeva1970@postgrespro.ru", "phone": "+70201097152"}
0005435252971	7857A7	5214 832051	ALEKSEY NIKOLAEV	{"phone": "+70112883955"}
0005435252972	203F19	4217 167243	VIKTOR GORBUNOV	{"email": "viktorgorbunov03081968@postgrespro.ru", "phone": "+70113078558"}
0005435252973	BE8EAB	8278 613943	MILANA POLYAKOVA	{"phone": "+70866184797"}
0005435252974	BE8EAB	0041 028105	IGOR CHERNOV	{"phone": "+70733037908"}
0005435252975	DE56B6	2296 807811	SAVELIY SOKOLOV	{"email": "s-sokolov-06031982@postgrespro.ru", "phone": "+70958300351"}
0005435252976	DE56B6	7674 601054	ALBERT NAZAROV	{"email": "albertnazarov051970@postgrespro.ru", "phone": "+70116036266"}
0005435252977	DE56B6	8465 850158	VYACHESLAV SOLOVEV	{"phone": "+70765374697"}
0005435252978	42BCDA	0719 479374	RAISA MOROZOVA	{"email": "raisa.morozova-1990@postgrespro.ru", "phone": "+70495038092"}
0005435252979	E3825E	9340 651130	SERGEY VASILEV	{"email": "sergey-vasilev-1954@postgrespro.ru", "phone": "+70716792521"}
0005435252980	E3100A	2703 566300	ARTEM EGOROV	{"email": "egorov.artem-1972@postgrespro.ru", "phone": "+70023098143"}
0005435252981	E3100A	2301 729397	MARINA ZAYCEVA	{"phone": "+70742657501"}
0005435252982	02621A	7028 899879	ELENA TIKHONOVA	{"email": "tikhonova-e21071986@postgrespro.ru", "phone": "+70384079712"}
0005435252983	536A72	5506 469084	ELENA ROMANOVA	{"phone": "+70403849933"}
0005435252984	6CA27D	1947 278885	MAKSIM KUZNECOV	{"email": "kuznecov_maksim1976@postgrespro.ru", "phone": "+70220044746"}
0005435252985	6CA27D	1959 173114	ELENA MELNIKOVA	{"email": "melnikova.elena_1973@postgrespro.ru", "phone": "+70977096763"}
0005435252986	0E915B	9299 395185	SVETLANA POPOVA	{"phone": "+70209206369"}
0005435252987	91E321	1133 902499	ANTON KRASNOV	{"email": "krasnov.a-29031969@postgrespro.ru", "phone": "+70421327562"}
0005435252988	408A9D	7629 933260	VALERIY SAVELEV	{"phone": "+70670988718"}
0005435252989	7A71BE	5302 778586	DMITRIY ZAYCEV	{"phone": "+70914619350"}
0005435252990	7A71BE	9744 581474	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr.111971@postgrespro.ru", "phone": "+70816343135"}
0005435252991	391608	0009 445997	TATYANA BELOVA	{"phone": "+70918795049"}
0005435252992	4369FB	8751 932555	ANATOLIY VOROBEV	{"email": "a_vorobev.28051980@postgrespro.ru", "phone": "+70952039876"}
0005435252993	4369FB	2798 559338	EVGENIY KAZAKOV	{"email": "ekazakov-081975@postgrespro.ru", "phone": "+70177771434"}
0005435252994	6FC390	0401 323790	ALINA ZAKHAROVA	{"email": "zakharova-alina.101978@postgrespro.ru", "phone": "+70440905049"}
0005435252995	A12C92	9517 702252	ALEKSANDR VLASOV	{"email": "aleksandrvlasov_021967@postgrespro.ru", "phone": "+70227166585"}
0005435252996	C8099E	9218 312920	OLGA AKIMOVA	{"email": "olga.akimova041980@postgrespro.ru", "phone": "+70608556653"}
0005435252997	32AA4D	0585 111249	LYUDMILA FOMINA	{"email": "fomina.lyudmila1971@postgrespro.ru", "phone": "+70157984538"}
0005435252998	19E20F	4327 176708	LARISA ZAYCEVA	{"email": "zayceval.11031967@postgrespro.ru", "phone": "+70258383240"}
0005435252999	19E20F	9458 597502	ZULFIYA NAUMOVA	{"email": "naumovaz-1959@postgrespro.ru", "phone": "+70531909073"}
0005435253000	16A349	5987 746767	MIKHAIL SEMENOV	{"phone": "+70317013673"}
0005435253001	EF5468	2605 581352	ANDREY KUZMIN	{"phone": "+70385858988"}
0005435253002	1BCFF0	7079 295481	MAKSIM VOLKOV	{"email": "volkov.maksim_29071965@postgrespro.ru", "phone": "+70118002880"}
0005435253003	FE1078	5098 159572	DENIS SOROKIN	{"email": "sorokin.denis1974@postgrespro.ru", "phone": "+70600056525"}
0005435253004	DB34A1	0166 671318	MARIYA LEBEDEVA	{"phone": "+70967086115"}
0005435253005	DD04C7	1964 059163	DMITRIY KUZNECOV	{"email": "kuznecovd.19121972@postgrespro.ru", "phone": "+70563482999"}
0005435253006	F44BCB	9949 058364	GRIGORIY TIMOFEEV	{"phone": "+70342968660"}
0005435253007	F482F2	2669 925667	NAIL STEPANOV	{"phone": "+70988474226"}
0005435253008	6EDF25	1131 799695	LYUDMILA AFANASEVA	{"phone": "+70036899046"}
0005435253009	6EDF25	3950 163505	OLGA AKIMOVA	{"email": "olgaakimova1965@postgrespro.ru", "phone": "+70161759390"}
0005435253010	3C2188	4421 591019	GENNADIY KULIKOV	{"email": "kulikov-g-1968@postgrespro.ru", "phone": "+70128288705"}
0005435253011	14BB97	9562 937995	MARIYA VOLKOVA	{"email": "m-volkova-1977@postgrespro.ru", "phone": "+70547479212"}
0005435253012	14BB97	0389 878037	VLADIMIR NAZAROV	{"email": "nazarov_v.031966@postgrespro.ru", "phone": "+70472123869"}
0005435253013	890750	3919 226726	FARIT STEPANOV	{"phone": "+70736658995"}
0005435253014	F62B21	8122 662510	TATYANA VOLKOVA	{"email": "t.volkova21051964@postgrespro.ru", "phone": "+70781548150"}
0005435253015	6E1C90	2114 425641	ANASTASIYA MARTYNOVA	{"email": "martynovaa_24031974@postgrespro.ru", "phone": "+70779455692"}
0005435253016	86D2A0	8686 729447	ELENA KUZMINA	{"phone": "+70916649325"}
0005435253017	86D2A0	7712 876029	OLGA BOGDANOVA	{"phone": "+70057369897"}
0005435253018	3CEF9E	6666 182167	DARYA KUZNECOVA	{"email": "kuznecova.darya_061974@postgrespro.ru", "phone": "+70851251022"}
0005435253019	396EDC	2963 816540	ELENA SOLOVEVA	{"phone": "+70070959232"}
0005435253020	4E655E	1703 791359	EVGENIYA GAVRILOVA	{"email": "gavrilova.evgeniya-13061979@postgrespro.ru", "phone": "+70661295188"}
0005435253021	113C28	8236 327419	SERGEY ZAKHAROV	{"phone": "+70075015183"}
0005435253022	113C28	3493 798327	MAKSIM AFANASEV	{"email": "m-afanasev_31121979@postgrespro.ru", "phone": "+70385311362"}
0005435253023	C45C13	3220 173658	LIDIYA NIKITINA	{"phone": "+70216460974"}
0005435253024	BE8C4C	9811 966641	TATYANA CHERNOVA	{"phone": "+70440327976"}
0005435253025	BE8C4C	6180 499153	EVGENIY MEDVEDEV	{"phone": "+70642191343"}
0005435253026	1080BD	4367 632756	ELENA ALEKSANDROVA	{"email": "elena.aleksandrova-081965@postgrespro.ru", "phone": "+70112469639"}
0005435253027	1080BD	9977 573163	NATALYA MAKSIMOVA	{"phone": "+70417110883"}
0005435253028	0BB0BA	1139 473074	VASILIY SCHERBAKOV	{"email": "v.scherbakov.17011965@postgrespro.ru", "phone": "+70005140704"}
0005435253029	0BB0BA	9942 035202	MIKHAIL NIKOLAEV	{"email": "nikolaev.mikhail_031985@postgrespro.ru", "phone": "+70978402841"}
0005435253030	D2DA6D	4381 398461	LYUDMILA POPOVA	{"email": "popova_l.071980@postgrespro.ru", "phone": "+70285581447"}
0005435253031	6D2434	7178 555055	OLGA NIKITINA	{"email": "olga_nikitina-29021968@postgrespro.ru", "phone": "+70928361240"}
0005435253032	9D50E0	1030 734573	TAMARA BORISOVA	{"phone": "+70707246888"}
0005435253033	860668	9042 893611	NINA MARTYNOVA	{"email": "nina-martynova_1960@postgrespro.ru", "phone": "+70805545020"}
0005435253034	DA7661	0980 006860	ANTONINA NIKITINA	{"email": "nikitina-a.021974@postgrespro.ru", "phone": "+70865786883"}
0005435253035	AE80FF	8063 894701	MAKSIM GAVRILOV	{"phone": "+70991640512"}
0005435253036	AE80FF	1582 941569	DENIS KUZNECOV	{"phone": "+70265226368"}
0005435253037	190D66	7477 546151	MARIYA ZAKHAROVA	{"phone": "+70101919419"}
0005435253038	C482F5	2294 961924	VLADIMIR FILIPPOV	{"email": "vladimir_filippov121977@postgrespro.ru", "phone": "+70905899427"}
0005435253039	DFF6EF	8589 331709	ANATOLIY BORISOV	{"email": "borisova.051978@postgrespro.ru", "phone": "+70584918189"}
0005435253041	DFF6EF	7858 487731	DMITRIY DMITRIEV	{"phone": "+70823593679"}
0005435253042	2523D9	5722 785598	LIDIYA SOROKINA	{"phone": "+70136978376"}
0005435253043	98B9A4	3100 173016	LIDIYA RYABOVA	{"phone": "+70019969960"}
0005435253044	98B9A4	0651 355254	EKATERINA BORISOVA	{"phone": "+70563139871"}
0005435253045	C49673	2077 061122	VLADIMIR YAKOVLEV	{"email": "yakovlev-vladimir.1976@postgrespro.ru", "phone": "+70643100174"}
0005435253046	5FED23	8235 407782	SERGEY ILIN	{"email": "s-ilin_13081973@postgrespro.ru", "phone": "+70700267852"}
0005435253047	B626A5	1355 394791	EVGENIY ZAKHAROV	{"email": "ezakharov.051970@postgrespro.ru", "phone": "+70181791975"}
0005435253048	B626A5	9367 654089	ALEKSEY POPOV	{"email": "popov_a_15051980@postgrespro.ru", "phone": "+70834192261"}
0005435253049	B626A5	7532 683760	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir_11031980@postgrespro.ru", "phone": "+70026844081"}
0005435253050	76C686	4374 050469	ANDREY STEPANOV	{"email": "stepanov-a-111973@postgrespro.ru", "phone": "+70751037124"}
0005435253051	1E6E06	0949 992608	REGINA TIKHONOVA	{"email": "reginatikhonova.011977@postgrespro.ru", "phone": "+70230605345"}
0005435253052	1E6E06	7945 889926	ALEKSANDR KUZMIN	{"phone": "+70457098974"}
0005435253053	1E6E06	6761 081409	ALBERT MOISEEV	{"phone": "+70972981295"}
0005435253054	6D07D1	9669 673775	KSENIYA MATVEEVA	{"email": "k_matveeva.051969@postgrespro.ru", "phone": "+70149433517"}
0005435253055	F7B7A9	9888 731260	FAINA POPOVA	{"email": "popovaf.20061971@postgrespro.ru", "phone": "+70134175594"}
0005435253056	84A822	9216 383957	EKATERINA IVANOVA	{"phone": "+70416331625"}
0005435253057	9AFBAD	7946 064141	ELENA SMIRNOVA	{"phone": "+70681407091"}
0005435253058	9AFBAD	6359 805565	ALEKSEY KUZNECOV	{"email": "kuznecov-a.1963@postgrespro.ru", "phone": "+70057481908"}
0005435253059	9AFBAD	4889 345766	ALENA AFANASEVA	{"phone": "+70325060355"}
0005435253060	CE9350	2985 315870	NAIL ORLOV	{"phone": "+70727626824"}
0005435253061	CE9350	0700 938499	OLGA BOGDANOVA	{"phone": "+70682877052"}
0005435253062	F37C49	8330 561451	YURIY ILIN	{"email": "iliny-1967@postgrespro.ru", "phone": "+70078108739"}
0005435253063	DB1C2C	1913 306230	ANDREY ZAKHAROV	{"email": "zakharovandrey22031981@postgrespro.ru", "phone": "+70088147027"}
0005435253064	53AE44	1848 259977	ANNA KONOVALOVA	{"phone": "+70426032277"}
0005435253065	87CE6A	7954 415129	EVGENIY GORBUNOV	{"phone": "+70818123505"}
0005435253066	024B03	7921 863794	NATALYA SEMENOVA	{"email": "n.semenova091976@postgrespro.ru", "phone": "+70891751050"}
0005435253067	AEA696	0066 912770	SEMEN SOROKIN	{"email": "sorokin.semen.05051974@postgrespro.ru", "phone": "+70944011467"}
0005435253068	4D885E	6958 229740	OLEG SIDOROV	{"email": "sidorovo29081967@postgrespro.ru", "phone": "+70432377822"}
0005435253069	4D885E	1403 531457	SVETLANA MOROZOVA	{"email": "morozovas-1972@postgrespro.ru", "phone": "+70526456034"}
0005435253070	587451	5335 837645	STEPAN MAKSIMOV	{"phone": "+70144929849"}
0005435253071	716961	6261 460590	VALERIY KUZNECOV	{"phone": "+70443045533"}
0005435253072	716961	9126 340330	OLEG SOKOLOV	{"email": "osokolov1970@postgrespro.ru", "phone": "+70392533051"}
0005435253073	8C581C	4974 933691	VYACHESLAV SOKOLOV	{"email": "sokolov.vyacheslav_1974@postgrespro.ru", "phone": "+70567601461"}
0005435253074	0765BE	7326 382186	OLGA ANDREEVA	{"email": "olga-andreeva_111975@postgrespro.ru", "phone": "+70747310233"}
0005435253075	0765BE	2937 531604	EVGENIY ZAYCEV	{"phone": "+70031070242"}
0005435253076	0765BE	7616 657315	EKATERINA PETROVA	{"email": "petrova_ekaterina_1986@postgrespro.ru", "phone": "+70899016401"}
0005435253077	0765BE	9759 728756	ALEKSANDR DENISOV	{"phone": "+70194811989"}
0005435253078	A31D12	3633 768760	LILIYA ARKHIPOVA	{"email": "arkhipova-liliya_1968@postgrespro.ru", "phone": "+70726037614"}
0005435253079	A31D12	6032 253635	NIKOLAY SEMENOV	{"phone": "+70292606749"}
0005435253080	C03EDD	2231 261762	RAISA ANISIMOVA	{"email": "anisimovaraisa19081976@postgrespro.ru", "phone": "+70202423269"}
0005435253081	F89FF8	7205 516407	MIKHAIL YAKOVLEV	{"phone": "+70252084000"}
0005435253082	1967D8	8006 833026	OLGA SOKOLOVA	{"email": "sokolovao_061984@postgrespro.ru", "phone": "+70599680568"}
0005435253083	5E775F	8110 221274	TATYANA BELYAEVA	{"email": "belyaeva_t_10071964@postgrespro.ru", "phone": "+70701585457"}
0005435253084	EE80C9	1012 812875	NIKOLAY SERGEEV	{"email": "sergeevnikolay1984@postgrespro.ru", "phone": "+70863595797"}
0005435253085	6CC5B1	3458 601468	SEMEN ZAYCEV	{"phone": "+70399970422"}
0005435253086	5556E3	6920 565905	SVETLANA KONDRATEVA	{"email": "s_kondrateva1971@postgrespro.ru", "phone": "+70005460407"}
0005435253087	5556E3	3849 822749	ANZHELIKA EGOROVA	{"phone": "+70218860299"}
0005435253088	1C61E9	5309 533147	LARISA NAZAROVA	{"email": "larisa-nazarova041975@postgrespro.ru", "phone": "+70982477897"}
0005435253089	FAFF7F	9664 545528	MARGARITA KONDRATEVA	{"phone": "+70639308664"}
0005435253090	76E79D	5589 371095	OKSANA ALEKSEEVA	{"phone": "+70373341480"}
0005435253091	76E79D	0270 574974	SERGEY KOZLOV	{"phone": "+70469545990"}
0005435253092	CFE4B2	1007 808778	SERGEY NAUMOV	{"phone": "+70610335360"}
0005435253093	C2E41F	9992 409581	VLADIMIR FROLOV	{"email": "vladimir-frolov10051967@postgrespro.ru", "phone": "+70313495186"}
0005435253094	A5FCAC	0298 183441	OLGA NIKOLAEVA	{"email": "olga_nikolaeva-071972@postgrespro.ru", "phone": "+70537739382"}
0005435253095	B29867	4593 484945	VALERIY ZHUKOV	{"email": "valeriyzhukov_1965@postgrespro.ru", "phone": "+70486871592"}
0005435253096	3ED7DC	9116 974020	LYUDMILA KUDRYASHOVA	{"phone": "+70940856531"}
0005435253097	3ED7DC	4728 535945	RAISA TIMOFEEVA	{"phone": "+70675935593"}
0005435253098	1092A9	3454 833068	DAMIR SOROKIN	{"phone": "+70755845217"}
0005435253099	1A1BDF	3556 272532	YURIY TARASOV	{"phone": "+70003849448"}
0005435253100	524716	5562 679510	ANNA KONDRATEVA	{"phone": "+70719953992"}
0005435253101	C25381	9222 235464	DANILA BARANOV	{"email": "danila.baranov_1978@postgrespro.ru", "phone": "+70204299389"}
0005435253102	9C6530	8207 467518	ELENA DAVYDOVA	{"phone": "+70352869561"}
0005435253103	3FB9F4	1932 003097	ANATOLIY MAKAROV	{"phone": "+70389751181"}
0005435253104	3FB9F4	0142 413544	VIKTORIYA MAKSIMOVA	{"email": "maksimovaviktoriya-24101972@postgrespro.ru", "phone": "+70234897434"}
0005435253105	D000B8	4840 795214	RAISA MATVEEVA	{"phone": "+70990398429"}
0005435253106	73CE06	3890 961314	ANNA NESTEROVA	{"email": "annanesterova_061962@postgrespro.ru", "phone": "+70478168453"}
0005435253107	EFA180	6797 538014	NINA DAVYDOVA	{"phone": "+70236580978"}
0005435253108	EFA180	8977 803119	NATALIYA KOROLEVA	{"email": "korolevanataliya-25101966@postgrespro.ru", "phone": "+70625688804"}
0005435253109	EFA180	7146 938583	OLGA NIKIFOROVA	{"email": "o-nikiforova.071963@postgrespro.ru", "phone": "+70405228316"}
0005435253110	8E37BB	2024 672434	REGINA BARANOVA	{"email": "baranova-regina1961@postgrespro.ru", "phone": "+70932318841"}
0005435253111	8E37BB	9773 674436	EDUARD BELOV	{"phone": "+70954723421"}
0005435253112	8E37BB	8593 917205	VALENTINA BORISOVA	{"phone": "+70690000091"}
0005435253113	D12F85	8632 816446	EVGENIY BORISOV	{"email": "borisov_e.011986@postgrespro.ru", "phone": "+70446549357"}
0005435253114	D46265	7969 183680	ANNA KALININA	{"phone": "+70488844580"}
0005435253115	D46265	3650 876719	OLGA ANISIMOVA	{"phone": "+70351083234"}
0005435253116	D46265	8800 478649	ELENA LUKYANOVA	{"email": "e.lukyanova.1961@postgrespro.ru", "phone": "+70843421554"}
0005435253117	12C1ED	6673 055083	ALEKSANDR FEDOROV	{"phone": "+70557621490"}
0005435253118	CB574B	6049 634498	KIRILL GORBUNOV	{"email": "gorbunov.k_16041969@postgrespro.ru", "phone": "+70341610817"}
0005435253119	BE79B4	9102 226509	GALINA KUZNECOVA	{"email": "kuznecova_galina_1965@postgrespro.ru", "phone": "+70606143411"}
0005435253120	E9B66D	9562 010532	ALEKSANDR ILIN	{"phone": "+70965205960"}
0005435253121	E9B66D	8217 254655	ANATOLIY MOISEEV	{"email": "a_moiseev_28091974@postgrespro.ru", "phone": "+70099447201"}
0005435253122	AE98B6	6644 877192	MIKHAIL SHEVCHENKO	{"phone": "+70924008553"}
0005435253123	26B28A	6636 680994	SERGEY VOLKOV	{"phone": "+70859102031"}
0005435253124	E1F0B9	4743 082208	NADEZHDA FILATOVA	{"email": "filatova.n061970@postgrespro.ru", "phone": "+70108077581"}
0005435253125	7262E4	8092 790475	MIKHAIL SOKOLOV	{"email": "mikhail-sokolov-1962@postgrespro.ru", "phone": "+70973682392"}
0005435253126	2642BB	6843 377759	PAVEL PETROV	{"email": "p.petrov-1971@postgrespro.ru", "phone": "+70903870325"}
0005435253127	9348AA	3007 083815	ALEKSANDR KUZNECOV	{"email": "kuznecova_111984@postgrespro.ru", "phone": "+70278976982"}
0005435253128	10146C	5108 801301	NADEZHDA FILATOVA	{"phone": "+70113504947"}
0005435253129	C37170	4509 032175	VALERIY ZAYCEV	{"phone": "+70091503467"}
0005435253130	C37170	4003 924548	LEV PAVLOV	{"phone": "+70123747390"}
0005435253131	075ABB	8571 971621	OLGA VASILEVA	{"email": "vasileva.olga_30041973@postgrespro.ru", "phone": "+70085691646"}
0005435253132	EFA49C	3430 770713	ALIYA DANILOVA	{"email": "danilova-aliya091965@postgrespro.ru", "phone": "+70398619014"}
0005435253133	FD608F	7691 484783	VALENTINA SEMENOVA	{"email": "semenovavalentina.1980@postgrespro.ru", "phone": "+70716046553"}
0005435253134	550DC9	6403 190898	ANDREY KOZLOV	{"email": "andreykozlov081973@postgrespro.ru", "phone": "+70849595633"}
0005435253135	E83992	6298 171855	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr_04061966@postgrespro.ru", "phone": "+70407086392"}
0005435253136	E83992	1861 698763	LYUBOV KARPOVA	{"email": "lyubov.karpova_30061970@postgrespro.ru", "phone": "+70052020723"}
0005435253137	97347C	0122 941342	LYUBOV GERASIMOVA	{"phone": "+70317503191"}
0005435253138	FBB5A6	1050 553988	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a-1964@postgrespro.ru", "phone": "+70322658898"}
0005435253139	14C665	1719 313951	ALEKSEY GRIGOREV	{"email": "aleksey_grigorev_04041975@postgrespro.ru", "phone": "+70397427427"}
0005435253140	14C665	6637 354529	OLGA POPOVA	{"email": "popova_olga_121977@postgrespro.ru", "phone": "+70331338618"}
0005435253141	15E286	3377 933743	IGOR MIKHAYLOV	{"phone": "+70767126317"}
0005435253142	5C178B	8052 646871	ANNA IVANOVA	{"email": "ivanova.anna.031967@postgrespro.ru", "phone": "+70725303585"}
0005435253143	5C178B	1002 871501	ALEKSANDR FILIPPOV	{"phone": "+70155280462"}
0005435253144	B6D4E9	1926 069429	NIKITA TARASOV	{"phone": "+70427335711"}
0005435253145	B6D4E9	0794 814383	ALEKSANDR NAUMOV	{"email": "naumovaleksandr_071973@postgrespro.ru", "phone": "+70000634589"}
0005435253146	EE3170	7543 446727	ALEKSANDR FILIPPOV	{"phone": "+70713544937"}
0005435253147	458A23	8609 647171	NIKITA VASILEV	{"email": "n_vasilev1963@postgrespro.ru", "phone": "+70582146684"}
0005435253148	8E1DFE	0006 880708	DENIS MIRONOV	{"email": "mironov.denis_1979@postgrespro.ru", "phone": "+70378118471"}
0005435253149	8E1DFE	3289 797526	LYUBOV POTAPOVA	{"email": "potapova-l_1980@postgrespro.ru", "phone": "+70939431648"}
0005435253150	E3F7D7	8423 751100	VERA KALININA	{"phone": "+70756595678"}
0005435253151	E3F7D7	7948 195062	VALENTINA BOGDANOVA	{"email": "valentina.bogdanova-23061966@postgrespro.ru", "phone": "+70082574469"}
0005435253152	E95C7B	5040 884177	VALENTINA LEBEDEVA	{"email": "lebedevav.061980@postgrespro.ru", "phone": "+70851476400"}
0005435253153	015B3B	1788 464248	ANNA IVANOVA	{"phone": "+70273327498"}
0005435253154	015B3B	6856 081558	OLGA POPOVA	{"email": "o_popova-121974@postgrespro.ru", "phone": "+70869266473"}
0005435253155	015B3B	0161 303964	VALENTINA POTAPOVA	{"phone": "+70298414553"}
0005435253156	3FA005	7316 414448	NATALYA MAKAROVA	{"phone": "+70491818898"}
0005435253157	3FA005	6646 464613	NADEZHDA KUZNECOVA	{"email": "nadezhda.kuznecova.1971@postgrespro.ru", "phone": "+70711030864"}
0005435253158	190C98	3533 125534	MIKHAIL MATVEEV	{"email": "mikhail_matveev.1973@postgrespro.ru", "phone": "+70081659813"}
0005435253159	8A2736	4886 660674	ALEVTINA KONDRATEVA	{"email": "akondrateva.06011981@postgrespro.ru", "phone": "+70167323685"}
0005435253160	BBE653	3409 536730	TAMARA LEBEDEVA	{"email": "lebedeva.tamara.20111974@postgrespro.ru", "phone": "+70586381371"}
0005435253161	BBE653	3554 706794	KSENIYA ROMANOVA	{"email": "romanovakseniya17071970@postgrespro.ru", "phone": "+70926678264"}
0005435253162	F3C794	7636 549115	MILANA KARPOVA	{"phone": "+70673742279"}
0005435253163	884170	3817 655945	TAMARA PAVLOVA	{"email": "pavlova-tamara-1973@postgrespro.ru", "phone": "+70454326057"}
0005435253164	DED27D	5371 725459	GLEB POPOV	{"phone": "+70688614001"}
0005435253165	CC0407	3394 933684	ANNA KUZNECOVA	{"phone": "+70609587867"}
0005435253166	B56FF7	6338 560249	ANDREY MOISEEV	{"email": "a_moiseev10041973@postgrespro.ru", "phone": "+70286513916"}
0005435253167	C96843	4913 625586	SVETLANA KUZNECOVA	{"email": "s.kuznecova061986@postgrespro.ru", "phone": "+70679826152"}
0005435253168	C919FB	1962 467682	ALEKSANDR FROLOV	{"phone": "+70385954610"}
0005435253169	C919FB	0940 203758	ALEVTINA MAKAROVA	{"email": "makarova_a.091972@postgrespro.ru", "phone": "+70938868781"}
0005435253170	726CD3	0409 360491	SVETLANA ROMANOVA	{"email": "romanova.s_1976@postgrespro.ru", "phone": "+70626026876"}
0005435253171	8FF80B	9383 433105	RIMMA RYABOVA	{"phone": "+70339930835"}
0005435253172	8FF80B	0391 049513	LILIYA LOGINOVA	{"email": "liliya-loginova1983@postgrespro.ru", "phone": "+70582917105"}
0005435253173	6F4635	0522 351004	TATYANA IVANOVA	{"phone": "+70294394378"}
0005435253174	3DFE83	8978 242015	ALEKSEY KULIKOV	{"email": "kulikov_aleksey13071961@postgrespro.ru", "phone": "+70957423632"}
0005435253175	028C7F	3304 878711	ALEKSANDRA KALININA	{"email": "kalininaa_011964@postgrespro.ru", "phone": "+70432535946"}
0005435253176	8FCF7B	9913 095040	ALEKSANDR NIKOLAEV	{"email": "nikolaevaleksandr.051976@postgrespro.ru", "phone": "+70318090027"}
0005435253177	ACC65D	4967 949876	YURIY VOROBEV	{"email": "vorobev_yuriy-061975@postgrespro.ru", "phone": "+70619265077"}
0005435253178	3918CD	4670 141954	ELENA SERGEEVA	{"phone": "+70152157642"}
0005435253179	3918CD	3582 374233	DMITRIY DAVYDOV	{"email": "davydovdmitriy1965@postgrespro.ru", "phone": "+70786472306"}
0005435253180	FAA731	8013 578257	OLEG SCHERBAKOV	{"email": "oscherbakov.12031987@postgrespro.ru", "phone": "+70176596916"}
0005435253181	906BCD	4016 965383	ELVINA SMIRNOVA	{"email": "smirnovae_081963@postgrespro.ru", "phone": "+70607864684"}
0005435253182	955524	1568 791239	ANASTASIYA GORBUNOVA	{"email": "gorbunova.a02071969@postgrespro.ru", "phone": "+70018808612"}
0005435253183	AF1D20	0798 710200	ANATOLIY IVANOV	{"email": "a.ivanov05041976@postgrespro.ru", "phone": "+70240595207"}
0005435253184	AF1D20	0243 332619	GALINA MATVEEVA	{"phone": "+70475186590"}
0005435253185	C87623	6145 075086	NATALYA SIDOROVA	{"email": "natalya-sidorova.1977@postgrespro.ru", "phone": "+70990346081"}
0005435253186	C87623	0536 862524	ZINAIDA BORISOVA	{"phone": "+70649261710"}
0005435253187	C87623	8257 281864	YULIYA STEPANOVA	{"phone": "+70265282275"}
0005435253188	EE83A9	1798 342252	TATYANA KOROLEVA	{"email": "koroleva_tatyana_29101981@postgrespro.ru", "phone": "+70092350072"}
0005435253189	EE83A9	9131 284093	DMITRIY ROMANOV	{"phone": "+70209896598"}
0005435253190	39C8B1	1116 574670	ANATOLIY ZAKHAROV	{"email": "a-zakharov-101981@postgrespro.ru", "phone": "+70227850311"}
0005435253191	F8D62B	7898 535309	ELENA SEMENOVA	{"phone": "+70621034467"}
0005435253192	0398FE	3030 886499	FEDOR SIDOROV	{"phone": "+70773020644"}
0005435253193	0398FE	4404 571529	ANDREY ZAKHAROV	{"email": "andrey.zakharov-1961@postgrespro.ru", "phone": "+70241141402"}
0005435253194	D50979	4546 402587	VLADIMIR DAVYDOV	{"email": "vdavydov_041971@postgrespro.ru", "phone": "+70887133892"}
0005435253195	827579	8533 162305	ALEKSEY ANDREEV	{"email": "andreev.a-1973@postgrespro.ru", "phone": "+70729668283"}
0005435253196	827579	3874 234511	NATALIYA NIKITINA	{"email": "nikitina_nataliya1970@postgrespro.ru", "phone": "+70770423972"}
0005435253197	F1B260	6614 397388	SERGEY KUZMIN	{"email": "kuzmin.sergey_011976@postgrespro.ru", "phone": "+70545494448"}
0005435253198	85EEF9	9387 108233	SOFYA PETROVA	{"email": "s.petrova_1966@postgrespro.ru", "phone": "+70728704246"}
0005435253199	8DA690	8511 565690	ANNA GERASIMOVA	{"email": "gerasimova.anna.1963@postgrespro.ru", "phone": "+70900695422"}
0005435253200	8CFB3D	7021 690486	PAVEL ZAKHAROV	{"phone": "+70750108770"}
0005435253201	79E005	0826 546911	ELENA ALEKSEEVA	{"phone": "+70336239134"}
0005435253202	79E005	7823 783383	OKSANA TITOVA	{"email": "oksana_titova-1969@postgrespro.ru", "phone": "+70687983538"}
0005435253203	2F0E72	8374 879646	NADEZHDA KUZNECOVA	{"email": "kuznecova-n061978@postgrespro.ru", "phone": "+70275497627"}
0005435253204	C048B9	2990 232738	ALEKSANDR SIDOROV	{"email": "sidorov-a051977@postgrespro.ru", "phone": "+70386843021"}
0005435253205	8A2DBF	9667 149968	GULNARA KAZAKOVA	{"email": "gulnara.kazakova_1969@postgrespro.ru", "phone": "+70313123772"}
0005435253206	8A2DBF	7589 866438	INNA OVCHINNIKOVA	{"phone": "+70564637504"}
0005435253207	8A2DBF	8048 152107	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov.04021974@postgrespro.ru", "phone": "+70775251185"}
0005435253208	6A494A	5025 499734	LARISA ABRAMOVA	{"phone": "+70447262450"}
0005435253209	858867	1257 492302	MARINA KUZNECOVA	{"phone": "+70966786713"}
0005435253210	A907B0	8828 329680	VLADIMIR ANTONOV	{"phone": "+70459871108"}
0005435253211	9994B0	3519 050232	VALENTINA NOVIKOVA	{"email": "valentinanovikova_10121974@postgrespro.ru", "phone": "+70541713811"}
0005435253212	7B89F8	1627 886013	VLADIMIR PETROV	{"phone": "+70007580452"}
0005435253213	8FA093	0670 903939	YURIY BORISOV	{"email": "yuriy_borisov_31011979@postgrespro.ru", "phone": "+70689612412"}
0005435253214	8FA093	0452 735207	ALEKSANDRA MIKHAYLOVA	{"phone": "+70099372654"}
0005435253215	1C8932	1492 626246	SAVELIY KUZMIN	{"email": "kuzmin-s_1970@postgrespro.ru", "phone": "+70955267212"}
0005435253216	1C8932	4437 277945	ALBINA NESTEROVA	{"phone": "+70631995405"}
0005435253217	8A7645	3696 387280	VALERIYA ZHUKOVA	{"phone": "+70766088067"}
0005435253218	8A7645	6665 481347	VIKTORIYA IVANOVA	{"email": "ivanova-viktoriya-1971@postgrespro.ru", "phone": "+70363148376"}
0005435253219	08515D	3563 791378	ALEKSEY FROLOV	{"phone": "+70404889875"}
0005435253220	F69B5B	7781 111793	GALINA POTAPOVA	{"phone": "+70639306801"}
0005435253221	FE08C8	8336 212947	VALENTINA KRASNOVA	{"email": "krasnova-v-06041978@postgrespro.ru", "phone": "+70601246052"}
0005435253222	FE08C8	9258 297971	YULIYA MATVEEVA	{"phone": "+70186379663"}
0005435254429	B7345B	0089 804987	NIKITA TARASOV	{"phone": "+70641018760"}
0005435254430	B7345B	4830 020477	ANASTASIYA NIKOLAEVA	{"email": "a-nikolaeva.1979@postgrespro.ru", "phone": "+70708245080"}
0005435254431	090782	4522 094304	GENNADIY BARANOV	{"email": "g_baranov.27091974@postgrespro.ru", "phone": "+70164373540"}
0005435254432	090782	5037 130055	VIKTOR SMIRNOV	{"email": "smirnovviktor-1966@postgrespro.ru", "phone": "+70642125712"}
0005435254433	7B1C06	2594 361693	PAVEL ZAKHAROV	{"phone": "+70904469697"}
0005435254434	1E3488	3049 650934	IRINA LOGINOVA	{"phone": "+70828203480"}
0005435254435	8151FA	0897 004299	NATALYA MOROZOVA	{"email": "morozova_n101964@postgrespro.ru", "phone": "+70248218221"}
0005435254436	8151FA	3295 340239	EKATERINA NIKITINA	{"email": "ekaterina_nikitina_1973@postgrespro.ru", "phone": "+70297748937"}
0005435254437	7714C8	6142 943789	TATYANA KOZLOVA	{"email": "tatyana.kozlova1968@postgrespro.ru", "phone": "+70852147540"}
0005435254438	B1A1DA	5740 918503	SERGEY EGOROV	{"phone": "+70581790041"}
0005435254439	B1A1DA	5651 910980	ANASTASIYA DENISOVA	{"email": "denisova_a-1975@postgrespro.ru", "phone": "+70799611807"}
0005435254440	7548A0	4622 397189	ANASTASIYA GRISHINA	{"email": "agrishina1969@postgrespro.ru", "phone": "+70481977726"}
0005435254441	27A920	3830 084595	ALEKSANDR YAKOVLEV	{"email": "yakovlev-aleksandr.011979@postgrespro.ru", "phone": "+70517363825"}
0005435254442	364461	4449 847077	NINA RODIONOVA	{"phone": "+70389463747"}
0005435254443	13A19A	9493 207374	NATALYA KUZNECOVA	{"email": "natalya_kuznecova_1972@postgrespro.ru", "phone": "+70235621984"}
0005435254444	13A19A	8308 061579	ELENA MAKAROVA	{"email": "makarova-e.1970@postgrespro.ru", "phone": "+70612777702"}
0005435254445	48C58B	6726 678743	VADIM KUZNECOV	{"phone": "+70434979246"}
0005435254446	48C58B	2904 229475	VALENTINA VASILEVA	{"email": "valentinavasileva_021968@postgrespro.ru", "phone": "+70854051665"}
0005435254447	C98A02	4227 797327	ELENA NIKITINA	{"phone": "+70861114185"}
0005435254448	43BB46	4809 311691	ARSENIY POPOV	{"phone": "+70985252933"}
0005435254449	43BB46	2472 542121	NIKOLAY OSIPOV	{"phone": "+70968147028"}
0005435254450	297F65	2883 107762	IRINA NESTEROVA	{"phone": "+70685138784"}
0005435254451	6BA4BE	0427 940539	DENIS SIDOROV	{"phone": "+70452507423"}
0005435254452	6BA4BE	7442 382498	ALEKSANDR KUZNECOV	{"email": "a.kuznecov17101966@postgrespro.ru", "phone": "+70139401456"}
0005435254453	207853	8345 557805	ILYA KAZAKOV	{"email": "ilya_kazakov_15011971@postgrespro.ru", "phone": "+70017168094"}
0005435254454	977668	4862 581758	DMITRIY KUZNECOV	{"phone": "+70040968991"}
0005435254455	92FDC2	4949 038572	ELENA SERGEEVA	{"phone": "+70486312220"}
0005435254456	6B3367	2617 159525	ARTEM NAUMOV	{"email": "naumovartem-1985@postgrespro.ru", "phone": "+70639424037"}
0005435254457	6F18BC	2006 684784	ALENA PETROVA	{"phone": "+70218744767"}
0005435254458	6F18BC	2601 871132	LYUBOV BARANOVA	{"email": "baranova_l.011969@postgrespro.ru", "phone": "+70032029732"}
0005435254459	0270DA	1819 797867	OKSANA ABRAMOVA	{"phone": "+70355640271"}
0005435254460	0270DA	8639 797937	PAVEL MOROZOV	{"email": "morozov_pavel.05101971@postgrespro.ru", "phone": "+70371420488"}
0005435254461	0270DA	1128 352361	ANNA KUDRYASHOVA	{"email": "kudryashova_a.101981@postgrespro.ru", "phone": "+70865370735"}
0005435254462	0DD94A	1335 076831	NIKOLAY IVANOV	{"phone": "+70210179301"}
0005435254463	DECF65	0754 547887	OLEG MELNIKOV	{"phone": "+70344783988"}
0005435254464	DECF65	4045 971308	IGOR KOZLOV	{"email": "igor_kozlov-021974@postgrespro.ru", "phone": "+70476578481"}
0005435254465	B1B3EB	2044 393506	ROMAN MAKAROV	{"phone": "+70928273338"}
0005435254466	09DB50	0089 902300	ALEKSEY SMIRNOV	{"phone": "+70132426500"}
0005435254467	09DB50	8298 279773	EVGENIYA SAVELEVA	{"email": "evgeniyasaveleva_051955@postgrespro.ru", "phone": "+70933031757"}
0005435254468	3D6935	0866 547825	ALEKSEY FEDOROV	{"email": "fedorov_a071969@postgrespro.ru", "phone": "+70824089923"}
0005435254469	2FDCA4	0529 131656	VADIM NIKOLAEV	{"email": "nikolaevvadim14011958@postgrespro.ru", "phone": "+70300619161"}
0005435254470	2FDCA4	7696 892378	NINA KOROLEVA	{"phone": "+70803038341"}
0005435254471	AB8FB6	2595 751167	VALERIYA KOVALEVA	{"email": "kovaleva-v.111964@postgrespro.ru", "phone": "+70000764817"}
0005435254472	AB8FB6	9452 374685	ALINA OSIPOVA	{"phone": "+70013219894"}
0005435254473	6DB1A2	2359 121442	ZOYA TITOVA	{"phone": "+70686348840"}
0005435254474	6DB1A2	6781 718409	DMITRIY MAKAROV	{"email": "makarov_d-091972@postgrespro.ru", "phone": "+70209452874"}
0005435254475	574E2C	6601 110612	YURIY FEDOTOV	{"phone": "+70871738220"}
0005435254476	0F5ED6	0439 970285	OKSANA AKIMOVA	{"email": "akimova.o.1964@postgrespro.ru", "phone": "+70294526308"}
0005435254477	0F5ED6	2425 148667	IVAN KULIKOV	{"phone": "+70298981634"}
0005435254478	3A83FF	6088 277521	ALEKSANDR VLASOV	{"email": "a_vlasov.1976@postgrespro.ru", "phone": "+70853418428"}
0005435254479	57EA99	9589 272885	ALEKSANDRA GAVRILOVA	{"email": "gavrilova_a.03111977@postgrespro.ru", "phone": "+70693508983"}
0005435254480	4A51F7	0571 478907	DMITRIY VOLKOV	{"phone": "+70874890034"}
0005435254481	4A51F7	3414 331360	IRINA KUZNECOVA	{"phone": "+70878913626"}
0005435254482	4A51F7	8631 963564	DMITRIY MAKSIMOV	{"phone": "+70288937738"}
0005435254483	20B06E	1476 973057	LIDIYA SERGEEVA	{"email": "lidiya-sergeeva10061973@postgrespro.ru", "phone": "+70911820730"}
0005435254484	CD6D60	4841 861071	KLAVDIYA FILIPPOVA	{"phone": "+70347843596"}
0005435254485	A1C006	1420 908869	IRINA POTAPOVA	{"email": "potapovai-06111972@postgrespro.ru", "phone": "+70702221907"}
0005435254486	BC0B52	2395 901129	LARISA POTAPOVA	{"phone": "+70710096372"}
0005435254487	BC0B52	2613 616582	ROMAN ZHUKOV	{"phone": "+70329648197"}
0005435254488	49B1B9	0584 083747	VIKTOR GRIGOREV	{"phone": "+70363171809"}
0005435254489	D7AA8F	6951 480731	ALEKSANDRA ROMANOVA	{"email": "romanova.aleksandra-051970@postgrespro.ru", "phone": "+70249822468"}
0005435254490	D9193D	3983 248663	ALEKSANDR PETROV	{"phone": "+70017691693"}
0005435254491	122B4A	4338 366933	TATYANA KOLESNIKOVA	{"phone": "+70681092312"}
0005435254492	122B4A	6454 369254	VYACHESLAV PETROV	{"email": "vyacheslav_petrov.1978@postgrespro.ru", "phone": "+70004336511"}
0005435254493	BFAC8B	9800 756059	NINA STEPANOVA	{"phone": "+70531828881"}
0005435254494	C5A78D	8664 454692	MARIYA SEMENOVA	{"phone": "+70629933765"}
0005435254495	C5A78D	5272 593478	ANATOLIY ZAKHAROV	{"email": "a.zakharov_30071972@postgrespro.ru", "phone": "+70401244489"}
0005435254496	C5A78D	2852 750003	GALINA ZAKHAROVA	{"phone": "+70477543495"}
0005435254497	4E427A	2923 344324	TATYANA EGOROVA	{"email": "egorovat.031977@postgrespro.ru", "phone": "+70617160758"}
0005435254498	4E427A	9792 305507	ALINA KISELEVA	{"email": "alina_kiseleva.30091973@postgrespro.ru", "phone": "+70454494599"}
0005435254499	CE6FE8	3524 473957	SERGEY NAUMOV	{"email": "sergey-naumov24091969@postgrespro.ru", "phone": "+70351704544"}
0005435254500	59A4CA	0397 584643	LILIYA SOROKINA	{"email": "sorokina_liliya071958@postgrespro.ru", "phone": "+70605828312"}
0005435254501	59A4CA	6221 036812	VLADIMIR MEDVEDEV	{"email": "v_medvedev.17101963@postgrespro.ru", "phone": "+70741342917"}
0005435254502	E491B5	2687 341107	ALEKSEY KUZMIN	{"email": "kuzmina.031982@postgrespro.ru", "phone": "+70457679772"}
0005435254503	46806E	6602 545698	DMITRIY ZAYCEV	{"email": "zaycev_d.071970@postgrespro.ru", "phone": "+70923793519"}
0005435254504	752667	2161 760818	RAFAIL NAZAROV	{"phone": "+70494695620"}
0005435254505	3B3952	0333 588150	GALINA GUSEVA	{"phone": "+70063856339"}
0005435254506	3B3952	7277 471993	SERGEY SHEVCHENKO	{"phone": "+70742308750"}
0005435254507	76188A	5329 674756	ELENA VOLKOVA	{"phone": "+70861119348"}
0005435254508	76188A	8491 610719	VLADIMIR KONOVALOV	{"phone": "+70308164534"}
0005435254509	B1967B	6801 666647	OKSANA MOISEEVA	{"phone": "+70289712321"}
0005435254510	826CFD	6000 488667	VALENTINA POPOVA	{"email": "v.popova-051977@postgrespro.ru", "phone": "+70422652435"}
0005435254511	826CFD	7959 407587	ALEKSEY NOVIKOV	{"phone": "+70197637935"}
0005435254512	EF8998	9274 045512	NATALYA ANTONOVA	{"phone": "+70787057902"}
0005435254513	EF8998	1419 156078	VERA BELOVA	{"email": "belova.vera1962@postgrespro.ru", "phone": "+70039532690"}
0005435254514	AA011F	8986 632635	TATYANA KUZMINA	{"phone": "+70586714696"}
0005435254515	A10882	6498 675008	MARINA FILIPPOVA	{"phone": "+70467429768"}
0005435254516	0CBCE4	4542 019686	VLADIMIR NOVIKOV	{"email": "novikov_vladimir_29041960@postgrespro.ru", "phone": "+70078432851"}
0005435254517	0CBCE4	1512 100238	TATYANA ROMANOVA	{"email": "romanova-t_1967@postgrespro.ru", "phone": "+70354288277"}
0005435254518	F59CE3	6116 335681	YANA SOROKINA	{"phone": "+70995540641"}
0005435254519	02CD0B	7884 255709	TATYANA NIKOLAEVA	{"phone": "+70560051775"}
0005435254520	6C1918	7673 724759	VERA ZHURAVLEVA	{"phone": "+70595607079"}
0005435254521	CB82BA	9236 874581	IGOR MIRONOV	{"phone": "+70263132728"}
0005435254522	91827C	1984 516028	ALEKSANDR SAVELEV	{"email": "aleksandr-savelev_061982@postgrespro.ru", "phone": "+70724903783"}
0005435254523	1F3852	9501 910209	IVAN FROLOV	{"email": "i_frolov12051979@postgrespro.ru", "phone": "+70986774529"}
0005435254524	5C42CE	4855 106014	ZINAIDA SMIRNOVA	{"email": "smirnova_zinaida_121982@postgrespro.ru", "phone": "+70957230408"}
0005435254525	9C909D	9402 551869	OLEG KONOVALOV	{"phone": "+70603201632"}
0005435254526	48F8DB	8957 948055	ALEKSANDRA SERGEEVA	{"email": "sergeeva.aleksandra1963@postgrespro.ru", "phone": "+70742264981"}
0005435254527	DF89C3	6015 109770	LARISA SMIRNOVA	{"email": "l-smirnova011969@postgrespro.ru", "phone": "+70149439602"}
0005435254528	DF89C3	7860 969745	OLGA MELNIKOVA	{"email": "o-melnikova.111972@postgrespro.ru", "phone": "+70075938161"}
0005435254529	308482	9154 191392	VALENTINA BARANOVA	{"phone": "+70596188522"}
0005435254530	31A6CA	4659 065928	ANDREY MAKAROV	{"phone": "+70276670695"}
0005435254531	F7AD0C	8499 044150	TIGRAN POPOV	{"phone": "+70674056034"}
0005435254532	F7AD0C	1454 355362	POLINA KUZNECOVA	{"phone": "+70930635986"}
0005435254533	F7A7A0	4213 139399	NAIL KAZAKOV	{"phone": "+70505029435"}
0005435254534	CC4804	8054 712174	ILYA DMITRIEV	{"email": "dmitrievi.1976@postgrespro.ru", "phone": "+70868611460"}
0005435254535	CC4804	0400 946003	VALERIY IVANOV	{"email": "v_ivanov_1980@postgrespro.ru", "phone": "+70115300171"}
0005435254536	000836	5293 187295	EVGENIY BORISOV	{"email": "borisov.e_14031965@postgrespro.ru", "phone": "+70384044053"}
0005435254537	DD20C8	8150 842033	MIKHAIL GORBUNOV	{"phone": "+70805560130"}
0005435254538	FF10E0	5333 520557	MIKHAIL SCHERBAKOV	{"email": "m.scherbakov.17011974@postgrespro.ru", "phone": "+70530328058"}
0005435254539	FF10E0	7857 707026	SERGEY MAKAROV	{"email": "makarov-s_031975@postgrespro.ru", "phone": "+70864463479"}
0005435254540	FF10E0	9596 327908	NIKOLAY DENISOV	{"phone": "+70751763903"}
0005435254541	FD19A0	2722 140145	TATYANA KULIKOVA	{"email": "kulikova.tatyana.26091969@postgrespro.ru", "phone": "+70275927413"}
0005435254542	FD19A0	4372 307511	SERGEY KONOVALOV	{"email": "konovalov.s_1966@postgrespro.ru", "phone": "+70346235712"}
0005435254543	FD19A0	2633 261139	KSENIYA SERGEEVA	{"email": "sergeevakseniya_1965@postgrespro.ru", "phone": "+70263454990"}
0005435257143	24F721	2528 573289	ANNA KUZMINA	{"phone": "+70887978327"}
0005435257144	2DE63C	4285 661424	ANNA MAKSIMOVA	{"email": "anna.maksimova111984@postgrespro.ru", "phone": "+70730933891"}
0005435257145	0BF3F8	9053 138620	ANDREY FILIPPOV	{"email": "a.filippov-12091977@postgrespro.ru", "phone": "+70338197984"}
0005435257146	027837	0104 034747	VALENTINA MALYSHEVA	{"phone": "+70882089955"}
0005435257147	027837	6758 599431	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov_11031982@postgrespro.ru", "phone": "+70264363683"}
0005435257148	027837	3506 012558	SERGEY MIKHAYLOV	{"phone": "+70941860106"}
0005435257149	914777	1289 688488	GALINA VASILEVA	{"email": "g_vasileva_10041968@postgrespro.ru", "phone": "+70865045216"}
0005435257150	770836	0406 466543	ANNA VOLKOVA	{"email": "anna_volkova-071969@postgrespro.ru", "phone": "+70921361032"}
0005435257151	5AC3BD	9016 070518	LIDIYA LEBEDEVA	{"email": "lidiya_lebedeva.081974@postgrespro.ru", "phone": "+70664468523"}
0005435257152	DF9ADB	8667 169293	NATALYA KULIKOVA	{"phone": "+70178286899"}
0005435257153	80C9E8	9367 147293	SVETLANA SOROKINA	{"email": "sorokinasvetlana_22011971@postgrespro.ru", "phone": "+70981499316"}
0005435257154	80C9E8	7946 360665	ILYA ILIN	{"phone": "+70312052998"}
0005435257155	C49430	0426 643778	PAVEL FILIPPOV	{"email": "filippov_p_12111975@postgrespro.ru", "phone": "+70057253363"}
0005435257156	C49430	3722 012965	ANDREY MATVEEV	{"email": "a.matveev_1983@postgrespro.ru", "phone": "+70693516980"}
0005435257157	68027C	4007 446539	TAMARA NIKITINA	{"email": "tamara_nikitina1985@postgrespro.ru", "phone": "+70403339321"}
0005435257158	51A0EF	7749 217266	ALISA ANDREEVA	{"email": "andreeva_a.23061961@postgrespro.ru", "phone": "+70544214463"}
0005435257159	51A0EF	1499 138406	NADEZHDA NIKIFOROVA	{"email": "nadezhdanikiforova-1969@postgrespro.ru", "phone": "+70494075935"}
0005435257160	E5480F	4450 967917	VLADIMIR MAKAROV	{"email": "makarov-v041971@postgrespro.ru", "phone": "+70727823116"}
0005435257161	E5480F	3514 478640	VALERIYA ALEKSANDROVA	{"phone": "+70974818773"}
0005435257162	910B10	9521 714608	IRINA KOLESNIKOVA	{"email": "kolesnikova_irina-1968@postgrespro.ru", "phone": "+70396890645"}
0005435257163	910B10	4830 081856	ALEKSEY ALEKSEEV	{"phone": "+70065071261"}
0005435257164	870034	7350 421751	YANA BELOVA	{"email": "yana_belova.081978@postgrespro.ru", "phone": "+70373123808"}
0005435257165	870034	1583 236065	SERGEY BELOV	{"email": "sergey-belov13121979@postgrespro.ru", "phone": "+70696655996"}
0005435257166	E36524	1974 848351	ANATOLIY KOZLOV	{"email": "akozlov_121971@postgrespro.ru", "phone": "+70871369306"}
0005435257167	E36524	3401 016153	EGOR RODIONOV	{"email": "e.rodionov.22031976@postgrespro.ru", "phone": "+70282821327"}
0005435257168	835B3F	6338 324100	VITALIY FEDOROV	{"email": "fedorov_v.04111968@postgrespro.ru", "phone": "+70812712642"}
0005435257169	951D36	8741 880178	VASILIY MAKAROV	{"phone": "+70936050298"}
0005435257170	951D36	1794 246669	YULIYA ANDREEVA	{"phone": "+70274877506"}
0005435257171	15912F	2474 904525	IVAN TARASOV	{"phone": "+70156170357"}
0005435257172	15912F	9351 866802	NADEZHDA ABRAMOVA	{"email": "nabramova.041962@postgrespro.ru", "phone": "+70993570784"}
0005435257173	15912F	5216 763671	VERA GAVRILOVA	{"phone": "+70371579078"}
0005435257174	D5065D	2096 614317	SVETLANA KOZLOVA	{"email": "s.kozlova-24121979@postgrespro.ru", "phone": "+70288379633"}
0005435257175	AA5208	5802 323013	VITALIY GUSEV	{"email": "vitaliy-gusev-11121977@postgrespro.ru", "phone": "+70006726947"}
0005435257176	EEF79A	8754 470168	ANNA NIKIFOROVA	{"phone": "+70268153861"}
0005435257177	41CB12	0024 066428	ANATOLIY VASILEV	{"phone": "+70126679705"}
0005435257178	41CB12	0974 403300	SERGEY DMITRIEV	{"email": "sergey.dmitriev.1982@postgrespro.ru", "phone": "+70405376530"}
0005435257179	ADF662	8047 471064	TATYANA ANDREEVA	{"email": "andreeva_t_10021967@postgrespro.ru", "phone": "+70496861922"}
0005435257180	ADF662	3331 233537	GENNADIY EGOROV	{"phone": "+70136211090"}
0005435257181	ADF662	2183 897877	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev23051972@postgrespro.ru", "phone": "+70130489714"}
0005435257182	813C67	3858 263297	ALEKSEY MEDVEDEV	{"phone": "+70230563734"}
0005435257183	813C67	0390 712531	RAMILYA IVANOVA	{"email": "r_ivanova.09041968@postgrespro.ru", "phone": "+70491435714"}
0005435257184	83796E	4959 382766	TAISIYA DAVYDOVA	{"email": "taisiyadavydova13051980@postgrespro.ru", "phone": "+70760160370"}
0005435257185	1FA81E	3724 917404	VLADISLAV GRIGOREV	{"phone": "+70876685239"}
0005435257186	0FE8FA	2921 972182	PETR BARANOV	{"email": "baranov.petr.031967@postgrespro.ru", "phone": "+70602500796"}
0005435257187	04061C	1657 514791	ALEKSANDR KUZNECOV	{"phone": "+70628075603"}
0005435257188	04061C	8078 029527	VLADIMIR KRASNOV	{"email": "krasnov_vladimir101969@postgrespro.ru", "phone": "+70031808250"}
0005435257189	AE3896	1451 209666	TAMARA KARPOVA	{"email": "karpova-t.21011970@postgrespro.ru", "phone": "+70463753113"}
0005435257190	8BCB4E	4041 531162	SERGEY SEMENOV	{"phone": "+70947595425"}
0005435257191	89404D	0410 379922	KIRILL ZAKHAROV	{"phone": "+70112839099"}
0005435257192	89404D	2106 719457	VITALIY SOROKIN	{"email": "sorokin.v1969@postgrespro.ru", "phone": "+70299723893"}
0005435257193	F3846D	6463 325941	DARYA TARASOVA	{"phone": "+70499949589"}
0005435257194	286FA9	2471 444887	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana-041972@postgrespro.ru", "phone": "+70474484557"}
0005435257195	81690A	6067 116075	NADEZHDA KOROLEVA	{"email": "n_koroleva091967@postgrespro.ru", "phone": "+70605648103"}
0005435257196	81690A	5928 199946	TATYANA NAUMOVA	{"phone": "+70954690425"}
0005435257197	C7B4C4	0113 758089	OLGA FILIPPOVA	{"phone": "+70741749649"}
0005435257198	C7B4C4	2450 618012	TATYANA DAVYDOVA	{"phone": "+70235716737"}
0005435257199	6542BE	8359 223102	TATYANA KISELEVA	{"phone": "+70638927649"}
0005435257200	6542BE	5075 726892	ALINA ABRAMOVA	{"phone": "+70718831278"}
0005435257201	AE8366	6316 735506	VERA MASLOVA	{"email": "maslova.v_061985@postgrespro.ru", "phone": "+70495220687"}
0005435257202	6D5945	5986 062069	MARIYA DMITRIEVA	{"email": "mariya_dmitrieva-1989@postgrespro.ru", "phone": "+70728578398"}
0005435257203	70A637	3568 637158	MIKHAIL FEDOROV	{"email": "fedorov.mikhail_1964@postgrespro.ru", "phone": "+70490820249"}
0005435257204	70A637	4758 178702	NIKITA ANTONOV	{"email": "n_antonov-12021968@postgrespro.ru", "phone": "+70607996405"}
0005435257205	D64A38	5434 987921	ANASTASIYA YAKOVLEVA	{"phone": "+70843989520"}
0005435257206	A7F85B	9516 325448	MARINA SMIRNOVA	{"email": "marinasmirnova-26031977@postgrespro.ru", "phone": "+70910829653"}
0005435257207	A7F85B	1292 487296	GENNADIY IVANOV	{"phone": "+70285347524"}
0005435257208	8BB7FF	3283 360057	EVGENIYA GAVRILOVA	{"phone": "+70133726125"}
0005435257209	39DA85	3984 346384	GERMAN MIKHAYLOV	{"email": "gmikhaylov.1976@postgrespro.ru", "phone": "+70477819117"}
0005435257210	F07AF1	9223 713918	LYUBOV SOROKINA	{"email": "sorokina.l-041967@postgrespro.ru", "phone": "+70379964130"}
0005435257211	6CD311	4577 474010	ROZA NIKITINA	{"email": "nikitina_r-101975@postgrespro.ru", "phone": "+70075335572"}
0005435257212	E0516F	0988 166843	ALEKSANDR RODIONOV	{"email": "rodionov.aleksandr_13121969@postgrespro.ru", "phone": "+70243007648"}
0005435257213	0CA8DD	0960 567479	VERA NOVIKOVA	{"phone": "+70687497181"}
0005435257214	AA9A15	2523 842504	VYACHESLAV NAUMOV	{"email": "naumov_v_07011971@postgrespro.ru", "phone": "+70543976674"}
0005435257215	AA9A15	7029 955064	ALEKSEY ANTONOV	{"phone": "+70338683290"}
0005435257216	4BA686	2242 882723	NINA VASILEVA	{"phone": "+70260211900"}
0005435257217	D643DD	1241 988605	YURIY ABRAMOV	{"email": "yabramov_1975@postgrespro.ru", "phone": "+70219036266"}
0005435257218	D643DD	5849 059191	SERGEY SERGEEV	{"email": "sergeevs_14031960@postgrespro.ru", "phone": "+70831281898"}
0005435257219	1D6526	2984 735273	ANATOLIY SMIRNOV	{"email": "anatoliy_smirnov_121975@postgrespro.ru", "phone": "+70419292868"}
0005435257220	1D6526	0408 667036	PETR IVANOV	{"phone": "+70657366274"}
0005435257221	1D6526	6312 893807	MARGARITA SEMENOVA	{"phone": "+70077871783"}
0005435257222	BF7F3B	9679 484976	MARIYA YUDINA	{"phone": "+70988597550"}
0005435257223	5F3873	9612 207134	NATALIYA KARPOVA	{"email": "karpova_n-101968@postgrespro.ru", "phone": "+70168148752"}
0005435257224	5F3873	1370 751671	ALESYA EGOROVA	{"phone": "+70623208069"}
0005435257225	C01243	9414 520166	NATALYA VOLKOVA	{"phone": "+70290021930"}
0005435257226	D0F776	9330 561939	OKSANA EFIMOVA	{"email": "efimova_o_1969@postgrespro.ru", "phone": "+70918225273"}
0005435257227	4AF116	1629 336502	NINA KOMAROVA	{"email": "komarova_nina_1973@postgrespro.ru", "phone": "+70112520065"}
0005435257228	4AF116	0926 915700	ALEKSEY ZAYCEV	{"phone": "+70706471802"}
0005435257229	FAC2AB	1729 040511	SVETLANA BORISOVA	{"phone": "+70020894851"}
0005435257230	029898	0362 324140	VIKTOR MEDVEDEV	{"email": "v_medvedev071978@postgrespro.ru", "phone": "+70175661285"}
0005435257231	029898	3286 033100	PELAGEYA NESTEROVA	{"phone": "+70831344612"}
0005435257232	C7B794	8523 687520	VYACHESLAV SMIRNOV	{"email": "smirnovvyacheslav_1971@postgrespro.ru", "phone": "+70124556389"}
0005435257233	9BD237	9563 049037	ALEKSANDR ZHURAVLEV	{"email": "aleksandrzhuravlev_101971@postgrespro.ru", "phone": "+70911787715"}
0005435257234	9BD237	9169 507473	VALERIY BELOV	{"email": "vbelov_05101963@postgrespro.ru", "phone": "+70654867367"}
0005435257235	9BD237	4895 706001	MIKHAIL KRASNOV	{"email": "mikhail-krasnov08051979@postgrespro.ru", "phone": "+70743676900"}
0005435257236	DCCE50	2849 298030	MAKSIM KOZLOV	{"email": "maksimkozlov.061981@postgrespro.ru", "phone": "+70122804635"}
0005435257237	FB3BE9	1013 912927	OLGA KOZLOVA	{"phone": "+70375625979"}
0005435257238	91EDBC	9454 856018	YULIYA NIKOLAEVA	{"email": "nikolaevayuliya.021969@postgrespro.ru", "phone": "+70571489525"}
0005435257239	91EDBC	1343 673421	MARIYA ANDREEVA	{"phone": "+70297626874"}
0005435257240	CEC3A8	1506 714426	ALEFTINA IVANOVA	{"phone": "+70502726097"}
0005435257241	CEC3A8	6913 629834	ALEKSANDR SHEVCHENKO	{"email": "a-shevchenko1956@postgrespro.ru", "phone": "+70221611449"}
0005435257242	CEC3A8	9208 006378	ELINA VASILEVA	{"phone": "+70819504712"}
0005435257243	472754	9273 659149	ELENA EFREMOVA	{"phone": "+70516836722"}
0005435257244	472754	4837 954727	MAKSIM MIKHAYLOV	{"email": "maksim_mikhaylov29041975@postgrespro.ru", "phone": "+70767816703"}
0005435257245	5A2B10	5738 677171	VYACHESLAV KUZMIN	{"phone": "+70665179342"}
0005435257246	B1C2D1	0689 742104	ARSENIY MOROZOV	{"phone": "+70158974194"}
0005435257247	6645A6	2004 178329	SERGEY ANDREEV	{"email": "andreev-sergey.05011963@postgrespro.ru", "phone": "+70435959637"}
0005435257248	A085B1	3198 450645	LARISA TIMOFEEVA	{"phone": "+70759160035"}
0005435257249	DC4B43	7642 308794	ANNA KUZNECOVA	{"email": "a.kuznecova_24061977@postgrespro.ru", "phone": "+70571244676"}
0005435257250	FCC9AB	8394 512218	ZLATA ALEKSEEVA	{"email": "z_alekseeva28031979@postgrespro.ru", "phone": "+70361753222"}
0005435257251	67C642	2111 762180	ELENA PETROVA	{"email": "elena_petrova.13101971@postgrespro.ru", "phone": "+70206701481"}
0005435257252	67C642	5468 678675	ANZHELA MELNIKOVA	{"email": "anzhelamelnikova_19121976@postgrespro.ru", "phone": "+70118984334"}
0005435257253	0A90C6	4270 911976	GENNADIY GRIGOREV	{"email": "ggrigorev011967@postgrespro.ru", "phone": "+70572680254"}
0005435257254	1D7DA6	0683 604189	IGOR TARASOV	{"phone": "+70748642003"}
0005435257255	9833AD	2614 227296	VLADIMIR EGOROV	{"email": "v_egorov-29071983@postgrespro.ru", "phone": "+70515066440"}
0005435257256	A9215A	3105 984731	ELENA KALININA	{"email": "e_kalinina_101974@postgrespro.ru", "phone": "+70136702080"}
0005435257257	23FED7	8598 613890	EKATERINA FEDOROVA	{"email": "fedorovaekaterina-1963@postgrespro.ru", "phone": "+70887632502"}
0005435257258	630A6D	8280 514222	VALERIY VASILEV	{"phone": "+70526837451"}
0005435257259	2C69CC	0778 125481	ELENA KUZNECOVA	{"phone": "+70746005549"}
0005435257260	E45C29	2351 309504	ANDREY FEDOROV	{"email": "fedorov.andrey.1974@postgrespro.ru", "phone": "+70122363113"}
0005435257261	E45C29	4417 243100	ALEKSANDR ALEKSANDROV	{"email": "aleksandr.aleksandrov.1965@postgrespro.ru", "phone": "+70095603752"}
0005435257262	32CD8D	9968 986213	SNEZHANA ANDREEVA	{"phone": "+70751520475"}
0005435257263	C302E3	7610 840044	TATYANA BARANOVA	{"phone": "+70131175615"}
0005435257264	1EB23F	1604 278531	ALINA NIKITINA	{"phone": "+70161938095"}
0005435257265	1349B9	1419 994504	OLESYA TIMOFEEVA	{"phone": "+70531079447"}
0005435257266	AE2402	0792 905945	VIKTOR VOROBEV	{"phone": "+70782671820"}
0005435257267	ACAACD	6250 267472	MATVEY TIKHONOV	{"email": "matvey.tikhonov29031972@postgrespro.ru", "phone": "+70912235412"}
0005435257268	404D36	1402 520519	ANNA FEDOROVA	{"email": "fedorova_a-24111973@postgrespro.ru", "phone": "+70281895904"}
0005435257269	404D36	1806 764225	ROMAN KUZNECOV	{"email": "romankuznecov.1967@postgrespro.ru", "phone": "+70130998684"}
0005435257270	404D36	9415 081427	YULIYA SMIRNOVA	{"email": "yuliya-smirnova1971@postgrespro.ru", "phone": "+70946542291"}
0005435257271	E2CB6A	0799 925850	OLGA GAVRILOVA	{"email": "olga.gavrilova.101973@postgrespro.ru", "phone": "+70550319332"}
0005435257272	F4D1CE	8774 672267	MARINA OVCHINNIKOVA	{"email": "m-ovchinnikova04101971@postgrespro.ru", "phone": "+70671149589"}
0005435257273	F4D1CE	0337 463388	ALBINA BELYAEVA	{"email": "belyaeva.a.25111974@postgrespro.ru", "phone": "+70239448896"}
0005435257274	EF42C3	3050 240855	OKSANA MARTYNOVA	{"phone": "+70369156641"}
0005435257275	0A5BA7	1642 022027	EKATERINA IVANOVA	{"phone": "+70574703228"}
0005435257276	6E5FA2	6456 243406	VERA FROLOVA	{"phone": "+70284625931"}
0005435257277	8BCB43	4633 491206	EDUARD NOVIKOV	{"phone": "+70184347460"}
0005435257278	8BCB43	2446 227787	VIKTORIYA VOLKOVA	{"email": "volkovaviktoriya1975@postgrespro.ru", "phone": "+70067779550"}
0005435257279	197ECD	1040 379586	NADEZHDA SEMENOVA	{"email": "nadezhda.semenova-09021963@postgrespro.ru", "phone": "+70382076364"}
0005435257280	C55C9E	1499 371099	NINA KISELEVA	{"phone": "+70125185624"}
0005435257281	71016F	2148 786039	RUFINA KOZLOVA	{"email": "r_kozlova_1984@postgrespro.ru", "phone": "+70982420417"}
0005435257282	71016F	2596 195121	DMITRIY PAVLOV	{"phone": "+70829798954"}
0005435257283	765C4D	3033 063725	ANNA ORLOVA	{"phone": "+70637551778"}
0005435257284	A8688D	7258 632909	LIDIYA ZAKHAROVA	{"phone": "+70627296594"}
0005435257285	A8688D	8115 910882	ALEKSANDR ZAKHAROV	{"email": "zakharov.a1978@postgrespro.ru", "phone": "+70657476720"}
0005435257286	F048D9	2855 978825	VALENTINA IVANOVA	{"phone": "+70147313352"}
0005435257287	4D1066	8389 854977	ELENA ERMAKOVA	{"email": "elenaermakova-19021975@postgrespro.ru", "phone": "+70946444787"}
0005435257288	C2EFF2	4183 187195	OLEG GUSEV	{"email": "oleg_gusev.051982@postgrespro.ru", "phone": "+70453224552"}
0005435257289	C2EFF2	6154 600573	MAKSIM IVANOV	{"phone": "+70763065124"}
0005435257290	69FEA9	6912 190204	FEDOR SOROKIN	{"phone": "+70465357195"}
0005435257291	1000BB	8840 917900	SERGEY KOZLOV	{"email": "kozlov-s.22101971@postgrespro.ru", "phone": "+70374333441"}
0005435257292	B53B2B	8250 881064	MARINA SMIRNOVA	{"email": "marina_smirnova-13011972@postgrespro.ru", "phone": "+70370388811"}
0005435257293	7DA5FE	6863 589932	VLADISLAV GAVRILOV	{"email": "vladislav-gavrilov_1970@postgrespro.ru", "phone": "+70705514265"}
0005435257294	7DA5FE	5984 594007	LYUDMILA MELNIKOVA	{"email": "melnikova.l_1974@postgrespro.ru", "phone": "+70769208437"}
0005435257295	2B7320	1327 324511	ELENA DENISOVA	{"email": "elenadenisova.03021979@postgrespro.ru", "phone": "+70855775080"}
0005435257296	E7525D	5426 252895	DMITRIY KUZNECOV	{"email": "d_kuznecov.1958@postgrespro.ru", "phone": "+70452055008"}
0005435257297	85A88E	7996 052660	ANNA DANILOVA	{"email": "annadanilova.1983@postgrespro.ru", "phone": "+70913904162"}
0005435257298	484933	2476 562589	IRINA LOGINOVA	{"phone": "+70011228525"}
0005435257299	7B50F9	0838 920214	IRINA SMIRNOVA	{"email": "smirnovairina_22011967@postgrespro.ru", "phone": "+70548849241"}
0005435257300	AD2B42	4944 588993	ALEKSEY SCHERBAKOV	{"email": "a.scherbakov091971@postgrespro.ru", "phone": "+70518280372"}
0005435257301	AD2B42	8764 068217	NAZIYA IVANOVA	{"phone": "+70985444897"}
0005435257302	172560	1515 823904	MARGARITA DAVYDOVA	{"phone": "+70196326309"}
0005435257303	24B842	5395 269641	SVETLANA POPOVA	{"email": "svetlanapopova1962@postgrespro.ru", "phone": "+70642419032"}
0005435257304	4BE77B	6356 848999	PAVEL ZAYCEV	{"phone": "+70365835560"}
0005435257305	4D24DE	9167 877432	ANDREY KISELEV	{"phone": "+70947342126"}
0005435257306	61FC72	0706 188411	ROMAN ZHURAVLEV	{"email": "roman_zhuravlev_1981@postgrespro.ru", "phone": "+70915488110"}
0005435257307	9099DC	3398 075171	NATALIYA GORBUNOVA	{"phone": "+70198902327"}
0005435257308	9099DC	6908 029367	NIKOLAY FEDOROV	{"phone": "+70842320997"}
0005435257309	9099DC	1776 238173	IRINA MATVEEVA	{"email": "irinamatveeva021968@postgrespro.ru", "phone": "+70930435601"}
0005435257310	4F451D	8395 046620	VITALIY TIKHONOV	{"email": "tikhonovvitaliy041956@postgrespro.ru", "phone": "+70127280476"}
0005435257311	4F451D	5640 439338	RUSTAM SIDOROV	{"phone": "+70269903814"}
0005435257312	6EC088	6096 851721	TAMARA FOMINA	{"email": "t.fomina_1971@postgrespro.ru", "phone": "+70991749197"}
0005435257313	B70DD4	2463 776150	ROMAN OSIPOV	{"phone": "+70829671346"}
0005435257314	B70DD4	2728 610042	VALENTINA ISAEVA	{"phone": "+70430774508"}
0005435257315	B70DD4	6906 697341	BORIS SHEVCHENKO	{"email": "boris_shevchenko25041978@postgrespro.ru", "phone": "+70441236922"}
0005435257316	E23AB6	0335 970237	OLESYA SOKOLOVA	{"email": "sokolova-o24111980@postgrespro.ru", "phone": "+70893882304"}
0005435257317	4B84FB	3735 544216	RAFAIL SOKOLOV	{"email": "sokolov.rafail.011973@postgrespro.ru", "phone": "+70430442258"}
0005435257318	FFFBC7	4608 093384	YULIYA OVCHINNIKOVA	{"email": "ovchinnikova-y.17081969@postgrespro.ru", "phone": "+70052645876"}
0005435257319	FFFBC7	8480 069211	TATYANA SEMENOVA	{"phone": "+70693757713"}
0005435257320	7E40CA	3300 289164	VYACHESLAV DAVYDOV	{"phone": "+70825164732"}
0005435257321	5EF610	1793 279851	OLGA MAKSIMOVA	{"email": "o-maksimova-23121977@postgrespro.ru", "phone": "+70389852628"}
0005435257322	A527FA	8270 520388	OLEG ALEKSEEV	{"phone": "+70700923471"}
0005435257323	2C0A84	9863 947360	EVGENIY FROLOV	{"phone": "+70799310504"}
0005435257324	660FA8	0884 358904	DMITRIY FEDOROV	{"email": "fedorov.dmitriy101975@postgrespro.ru", "phone": "+70671824549"}
0005435257325	19FAF4	8572 576045	NATALYA TARASOVA	{"email": "tarasova-natalya.091994@postgrespro.ru", "phone": "+70669916964"}
0005435257326	19FAF4	7001 356286	ILYAS SIDOROV	{"email": "ilyas.sidorov.03091968@postgrespro.ru", "phone": "+70266977948"}
0005435257327	48FF59	8350 492871	YULIYA ZAKHAROVA	{"email": "y-zakharova-06031980@postgrespro.ru", "phone": "+70630435825"}
0005435257328	89BD85	7752 595954	TATYANA EFIMOVA	{"phone": "+70892288829"}
0005435257329	89BD85	3869 703628	VALENTINA FOMINA	{"phone": "+70578315733"}
0005435257330	EBAF54	8195 858717	EVDOKIYA EGOROVA	{"phone": "+70864204831"}
0005435257331	49E674	3567 131545	IRINA KOVALEVA	{"phone": "+70355619421"}
0005435257332	708437	6621 738253	VLADIMIR IVANOV	{"email": "v_ivanov_11061973@postgrespro.ru", "phone": "+70531346860"}
0005435257333	708437	7128 169148	SERGEY KAZAKOV	{"phone": "+70600090559"}
0005435257334	CEE925	4856 647554	NATALYA MOROZOVA	{"phone": "+70685092027"}
0005435257335	CEE925	1445 623262	ALEKSANDR KRASNOV	{"phone": "+70764155632"}
0005435257336	CEE925	2279 413306	VALENTINA DANILOVA	{"phone": "+70703458620"}
0005435257337	B14F81	5747 065596	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov091962@postgrespro.ru", "phone": "+70575903987"}
0005435257338	309A74	1257 697031	NONNA KOZLOVA	{"phone": "+70358009484"}
0005435257339	F64827	0684 242531	ANDREY PAVLOV	{"email": "a-pavlov_30081978@postgrespro.ru", "phone": "+70401664201"}
0005435257340	BA9857	3060 675826	ARTEM KRASNOV	{"email": "krasnov.a111973@postgrespro.ru", "phone": "+70883319940"}
0005435257341	BA9857	1750 953187	ANDREY KUZNECOV	{"email": "kuznecov-a021988@postgrespro.ru", "phone": "+70886589021"}
0005435257342	32D805	1140 721914	DENIS DENISOV	{"phone": "+70035600617"}
0005435257343	32D805	4740 778093	SOFIYA MAKAROVA	{"email": "smakarova.051974@postgrespro.ru", "phone": "+70847808323"}
0005435257344	32D805	8055 000695	VLADIMIR KONOVALOV	{"phone": "+70296897676"}
0005435257345	EEF5CC	3352 747110	VLADISLAV GUSEV	{"phone": "+70864844717"}
0005435257346	EEF5CC	2800 011927	NATALYA KOROLEVA	{"email": "koroleva.n.101977@postgrespro.ru", "phone": "+70064016419"}
0005435257347	93A284	3698 941695	MARTA KOMAROVA	{"email": "m_komarova-1980@postgrespro.ru", "phone": "+70185082715"}
0005435257348	B9530D	2783 407553	DMITRIY PETROV	{"phone": "+70126631513"}
0005435257349	07CBB4	8464 812038	PAVEL ALEKSANDROV	{"email": "aleksandrovpavel_03031969@postgrespro.ru", "phone": "+70663420962"}
0005435257350	77D95E	9443 066868	ALEKSEY VASILEV	{"phone": "+70291912792"}
0005435257351	77D95E	7172 654635	YANA SOKOLOVA	{"phone": "+70130101272"}
0005435257352	1B7CE3	1282 834993	NIKOLAY VLASOV	{"phone": "+70985002778"}
0005435257353	1B7CE3	2577 394640	VLADIMIR SCHERBAKOV	{"phone": "+70450988615"}
0005435257354	B825A7	2932 616878	TATYANA FEDOROVA	{"phone": "+70326793072"}
0005435257355	78FCD6	0658 345259	VALENTINA ZHURAVLEVA	{"email": "zhuravleva-v20031976@postgrespro.ru", "phone": "+70618774116"}
0005435257356	78FCD6	3171 321210	ILGIZ PAVLOV	{"email": "pavlov-ilgiz-1970@postgrespro.ru", "phone": "+70003718371"}
0005435257357	90D1E4	4907 810702	DMITRIY FEDOROV	{"phone": "+70742206925"}
0005435257358	8362BE	5058 697678	ROMAN NIKOLAEV	{"email": "nikolaev.r_011971@postgrespro.ru", "phone": "+70900254643"}
0005435257359	0FA50F	7019 448681	VLADIMIR VASILEV	{"phone": "+70932440114"}
0005435257360	0FA50F	2497 146259	NATALYA TROFIMOVA	{"email": "trofimovanatalya-30061967@postgrespro.ru", "phone": "+70632383034"}
0005435257361	0FA50F	3885 877561	EKATERINA FEDOROVA	{"email": "fedorovaekaterina_011967@postgrespro.ru", "phone": "+70031514497"}
0005435257362	0FA50F	3305 356680	ALEKSEY FOMIN	{"email": "fomin-aleksey-051973@postgrespro.ru", "phone": "+70939822952"}
0005435257363	0CB066	2217 190713	VALENTINA MALYSHEVA	{"email": "malysheva-v.1978@postgrespro.ru", "phone": "+70807901094"}
0005435257364	0CB066	2860 368336	SERGEY KRASNOV	{"email": "skrasnov.02071967@postgrespro.ru", "phone": "+70037812555"}
0005435257365	2FE25F	5855 769988	YULIYA KOZLOVA	{"phone": "+70541902135"}
0005435257366	8EC8D5	4918 361664	EKATERINA POPOVA	{"phone": "+70506421450"}
0005435257367	2C4CD7	5201 341593	DIANA ANDREEVA	{"email": "dandreeva1966@postgrespro.ru", "phone": "+70403465521"}
0005435257368	2C4CD7	2819 723243	ANNA BARANOVA	{"phone": "+70517718196"}
0005435257369	57FE36	9925 664607	ALEKSEY MIKHAYLOV	{"phone": "+70394902527"}
0005435257370	3CD940	9697 148641	PAVEL OSIPOV	{"phone": "+70016883942"}
0005435257371	3CD940	3721 494409	ZHANNA SOKOLOVA	{"email": "sokolova-z.091962@postgrespro.ru", "phone": "+70215748076"}
0005435257372	E6CA20	6903 372454	RUSLAN FEDOROV	{"phone": "+70458753996"}
0005435257373	9B10B3	0434 214124	IVAN IVANOV	{"email": "i.ivanov1981@postgrespro.ru", "phone": "+70614268734"}
0005435257374	24247B	6834 368667	GENNADIY SERGEEV	{"phone": "+70741045113"}
0005435257375	76A040	2293 846467	ALEKSEY KOROLEV	{"phone": "+70315590513"}
0005435257376	95F39F	7951 491221	GLEB PETROV	{"email": "petrov-gleb-1966@postgrespro.ru", "phone": "+70261774486"}
0005435257377	810295	1390 325351	NINA EGOROVA	{"phone": "+70766140394"}
0005435257378	CA14BA	3808 928617	IGOR BONDARENKO	{"phone": "+70751998208"}
0005435257379	CA14BA	5894 029858	EKATERINA BELOVA	{"email": "belova-e-091963@postgrespro.ru", "phone": "+70573967604"}
0005435257380	243F63	4426 068603	VLADIMIR KUZMIN	{"phone": "+70869119110"}
0005435257381	1179EE	3446 496725	LIDIYA GERASIMOVA	{"phone": "+70314758307"}
0005435257382	443A47	5089 232927	MARIYA EGOROVA	{"email": "egorova_mariya.1958@postgrespro.ru", "phone": "+70749574751"}
0005435257383	443A47	3065 081120	VYACHESLAV IVANOV	{"email": "vyacheslav_ivanov_03041976@postgrespro.ru", "phone": "+70784646361"}
0005435257384	443A47	2114 089860	RUSLAN YAKOVLEV	{"phone": "+70996100745"}
0005435257385	2180F4	8614 726544	MARIYA KULIKOVA	{"phone": "+70423606960"}
0005435257386	3D247F	4068 956308	ALEKSANDR ABRAMOV	{"email": "abramov_a-27081974@postgrespro.ru", "phone": "+70172724144"}
0005435257387	54BBAC	0133 507832	LYUDMILA POPOVA	{"phone": "+70084256611"}
0005435257388	54BBAC	8367 433374	SERGEY POPOV	{"email": "sergeypopov13091974@postgrespro.ru", "phone": "+70166748074"}
0005435257389	54BBAC	4309 099901	GALINA SAVELEVA	{"phone": "+70675557883"}
0005435257390	DDF03B	2772 165741	SERGEY MELNIKOV	{"phone": "+70255210291"}
0005435257391	DADA51	9455 938780	NATALYA POTAPOVA	{"email": "potapovan_111979@postgrespro.ru", "phone": "+70956098186"}
0005435257504	577F98	2720 547346	DMITRIY MELNIKOV	{"phone": "+70535607920"}
0005435257392	DADA51	7460 136587	ALEKSEY SOKOLOV	{"email": "asokolov.121970@postgrespro.ru", "phone": "+70611601219"}
0005435257393	C8B3FF	6734 586849	VLADIMIR IVANOV	{"email": "v.ivanov091980@postgrespro.ru", "phone": "+70837833089"}
0005435257394	0437BE	3291 232845	IRINA TARASOVA	{"phone": "+70845932196"}
0005435257395	0437BE	0102 178531	ANTON GRIGOREV	{"email": "anton_grigorev-111973@postgrespro.ru", "phone": "+70509995949"}
0005435257396	4297EC	1598 841724	ELENA KOZLOVA	{"email": "ekozlova_1975@postgrespro.ru", "phone": "+70438641337"}
0005435257397	7160B4	4287 580228	KSENIYA KRASNOVA	{"phone": "+70566850020"}
0005435257398	9653E4	9966 253573	NATALIYA MALYSHEVA	{"phone": "+70463501046"}
0005435257399	EAC23D	0785 230668	ANATOLIY ALEKSANDROV	{"email": "a.aleksandrov.28071964@postgrespro.ru", "phone": "+70315451452"}
0005435257400	EAC23D	9573 860546	ANDREY NIKITIN	{"email": "nikitin.andrey23121965@postgrespro.ru", "phone": "+70860307729"}
0005435257401	EAC23D	4874 235649	SERGEY POPOV	{"phone": "+70862011863"}
0005435257402	D14841	6585 187763	LYUBOV LEBEDEVA	{"phone": "+70394871716"}
0005435257403	E92929	8445 019682	DMITRIY SCHERBAKOV	{"email": "scherbakov-d_1967@postgrespro.ru", "phone": "+70337612470"}
0005435257404	66DC2C	4443 894177	OLGA RYABOVA	{"email": "ryabova.o.06051981@postgrespro.ru", "phone": "+70400379064"}
0005435257405	1675F2	9906 307773	ALENA KARPOVA	{"phone": "+70464881413"}
0005435257406	1675F2	7908 914100	VALENTINA POPOVA	{"phone": "+70862572728"}
0005435257407	E39020	6034 192114	NATALYA POPOVA	{"phone": "+70167799528"}
0005435257408	719F99	8442 370930	MARIYA KAZAKOVA	{"phone": "+70361128293"}
0005435257409	B5AC53	9187 651399	OLGA OVCHINNIKOVA	{"phone": "+70339080545"}
0005435257410	B5AC53	8637 314140	ALEKSANDR PAVLOV	{"email": "pavlova.061976@postgrespro.ru", "phone": "+70703578035"}
0005435257411	ABA326	8741 378932	RITA KUZNECOVA	{"phone": "+70729217619"}
0005435257412	C32A4C	8654 305868	NADEZHDA KUZNECOVA	{"phone": "+70490172450"}
0005435257413	4169C1	9898 448537	NINEL GUSEVA	{"email": "guseva_n_12051973@postgrespro.ru", "phone": "+70466220903"}
0005435257414	ACDADB	9870 472189	ALEKSEY KOZLOV	{"email": "kozlov_aleksey.1977@postgrespro.ru", "phone": "+70194956248"}
0005435257415	8C86F0	6970 466549	GALINA EGOROVA	{"phone": "+70624460357"}
0005435257416	0C14AE	1899 210565	ANTONINA IVANOVA	{"email": "a_ivanova-10011973@postgrespro.ru", "phone": "+70710022298"}
0005435257417	B59ED3	2309 808009	ROMAN NIKITIN	{"phone": "+70360098268"}
0005435257418	B59ED3	8111 453480	VALENTINA AKIMOVA	{"phone": "+70457295013"}
0005435257419	440B65	9550 771523	VIKTORIYA DANILOVA	{"phone": "+70051138383"}
0005435257420	7A2D51	6685 358861	KHASAN MAKAROV	{"email": "makarov.k-30071972@postgrespro.ru", "phone": "+70652342734"}
0005435257421	7A2D51	8291 291169	LIDIYA NIKITINA	{"phone": "+70938997960"}
0005435257422	3BBCD1	4024 479119	SVETLANA KULIKOVA	{"phone": "+70613263812"}
0005435257423	14A895	7384 964734	LYUDMILA MAKAROVA	{"email": "makarova-lyudmila31071982@postgrespro.ru", "phone": "+70922377591"}
0005435257424	35DDE4	9557 152988	ALEKSANDR KUZNECOV	{"email": "akuznecov-081977@postgrespro.ru", "phone": "+70031901132"}
0005435257425	0F6879	8640 791532	ZULFIYA TIKHONOVA	{"email": "tikhonova_z-071971@postgrespro.ru", "phone": "+70834249335"}
0005435257426	3A695B	8990 876415	VYACHESLAV ZHURAVLEV	{"phone": "+70676531665"}
0005435257427	F8A6E9	0135 967740	EVGENIY ROMANOV	{"email": "romanov_evgeniy1978@postgrespro.ru", "phone": "+70768414596"}
0005435257428	55C569	4572 654894	EVGENIYA DAVYDOVA	{"phone": "+70855280740"}
0005435257429	D94124	2625 694693	EKATERINA MOISEEVA	{"phone": "+70896335599"}
0005435257430	075539	2343 194636	OLGA KRASNOVA	{"email": "krasnova.olga_1973@postgrespro.ru", "phone": "+70892679940"}
0005435257431	CBC676	9116 006653	VENIAMIN ROMANOV	{"phone": "+70526181770"}
0005435257432	5BE377	0636 483149	ALEKSANDR KISELEV	{"email": "kiselev_aleksandr_021978@postgrespro.ru", "phone": "+70059403626"}
0005435257433	7492C5	4259 306724	VADIM ANTONOV	{"phone": "+70200395912"}
0005435257434	7492C5	8998 818815	ALEKSANDR IVANOV	{"phone": "+70759674515"}
0005435257435	F8BBC2	0110 336968	NATALYA KALININA	{"email": "natalya.kalinina-15041974@postgrespro.ru", "phone": "+70717866710"}
0005435257436	F8BBC2	7045 749238	SVETLANA STEPANOVA	{"email": "s-stepanova-01041974@postgrespro.ru", "phone": "+70200381280"}
0005435257437	917595	8551 518838	ANNA MALYSHEVA	{"phone": "+70502545739"}
0005435257438	917595	5894 538585	SVETLANA ZHURAVLEVA	{"email": "zhuravleva-s_03061977@postgrespro.ru", "phone": "+70489928815"}
0005435257439	2F53D0	4845 798885	GALINA NESTEROVA	{"phone": "+70329885205"}
0005435257440	923F5B	9085 848408	ANATOLIY ZAKHAROV	{"email": "azakharov_26071970@postgrespro.ru", "phone": "+70372413123"}
0005435257441	923F5B	7093 744078	EGOR ORLOV	{"phone": "+70561219243"}
0005435257442	472EB9	1896 378151	LARISA VOLKOVA	{"phone": "+70550062051"}
0005435257443	472EB9	1609 437417	YULIYA KRASNOVA	{"phone": "+70563132716"}
0005435257444	BAD4C1	3883 748911	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova_nadezhda.1978@postgrespro.ru", "phone": "+70301519825"}
0005435257445	BAD4C1	3948 641534	MIKHAIL MARTYNOV	{"email": "mmartynov_23011965@postgrespro.ru", "phone": "+70216876173"}
0005435257446	623F3D	6135 063630	ELENA DMITRIEVA	{"email": "dmitrieva.e_17061974@postgrespro.ru", "phone": "+70672297788"}
0005435257447	88A150	7663 081166	MIKHAIL ALEKSANDROV	{"email": "mikhail-aleksandrov-111972@postgrespro.ru", "phone": "+70686593950"}
0005435257448	FB144B	8203 590104	TATYANA SMIRNOVA	{"email": "t.smirnova.071969@postgrespro.ru", "phone": "+70615506602"}
0005435257449	FB144B	0144 492215	DENIS KUZNECOV	{"phone": "+70190159780"}
0005435257450	FB144B	6730 483949	ILYA ANDREEV	{"phone": "+70725739827"}
0005435257451	ED8EFA	3849 424158	ARTEM PAVLOV	{"email": "pavlov-artem.061974@postgrespro.ru", "phone": "+70337897785"}
0005435257452	7C6066	7643 052670	SERGEY SAVELEV	{"email": "savelev.sergey-081961@postgrespro.ru", "phone": "+70376082566"}
0005435257453	FAD2C6	7837 592060	ALEKSANDRA DANILOVA	{"phone": "+70444746498"}
0005435257454	BC65DF	3477 148629	VLADIMIR MELNIKOV	{"email": "v_melnikov091965@postgrespro.ru", "phone": "+70953903380"}
0005435257455	E4005A	2351 178100	KSENIYA ILINA	{"phone": "+70586561801"}
0005435257456	9A81AB	2242 423961	LYUBOV VASILEVA	{"phone": "+70277354560"}
0005435257457	9A81AB	7879 040204	LARISA BARANOVA	{"email": "l.baranova.051959@postgrespro.ru", "phone": "+70426731975"}
0005435257458	DC2736	7557 469046	ARTEM TIKHONOV	{"email": "a.tikhonov-02041964@postgrespro.ru", "phone": "+70158376212"}
0005435257520	070D98	7191 649187	ROMAN KOROLEV	{"phone": "+70172669967"}
0005435257459	897248	9383 493062	VLADIMIR ABRAMOV	{"email": "vladimir.abramov.08041966@postgrespro.ru", "phone": "+70701787387"}
0005435257460	B51FAD	4752 992048	VLADIMIR ANDREEV	{"phone": "+70074173415"}
0005435257461	B51FAD	3460 513909	ALENA KOLESNIKOVA	{"email": "a_kolesnikova1958@postgrespro.ru", "phone": "+70578540873"}
0005435257462	5CD61F	4279 341143	EKATERINA KOLESNIKOVA	{"phone": "+70455091147"}
0005435257463	5CD61F	8227 295791	DMITRIY OSIPOV	{"email": "osipov-dmitriy_1971@postgrespro.ru", "phone": "+70982777669"}
0005435257464	5CD61F	6985 135787	ELENA MIKHAYLOVA	{"email": "elenamikhaylova12021970@postgrespro.ru", "phone": "+70737050007"}
0005435257465	5CD61F	3633 571711	SVETLANA FADEEVA	{"phone": "+70746850478"}
0005435257466	9580C5	6075 441371	ARTEM MOROZOV	{"phone": "+70793945338"}
0005435257467	3DA089	2971 782347	EKATERINA TROFIMOVA	{"phone": "+70851910617"}
0005435257468	8A89DF	4450 544698	SERGEY MAKAROV	{"email": "s_makarov.111970@postgrespro.ru", "phone": "+70561975526"}
0005435257469	8A89DF	1747 289480	ZINAIDA NIKITINA	{"email": "z-nikitina.1962@postgrespro.ru", "phone": "+70284322549"}
0005435257470	3EE9F2	5323 354563	ALEVTINA IVANOVA	{"phone": "+70365126173"}
0005435257471	971F89	5354 272771	LYUDMILA BOGDANOVA	{"email": "bogdanovalyudmila-1976@postgrespro.ru", "phone": "+70125925014"}
0005435257472	971F89	7223 938366	LYUDMILA ORLOVA	{"phone": "+70767393695"}
0005435257473	702C38	0729 263026	OKSANA SERGEEVA	{"phone": "+70831715327"}
0005435257474	210878	2212 270261	NATALYA STEPANOVA	{"email": "n-stepanova-1970@postgrespro.ru", "phone": "+70089917487"}
0005435257475	393CFE	5148 156344	ALENA MOISEEVA	{"phone": "+70838637775"}
0005435257476	393CFE	4231 261678	IRINA FOMINA	{"email": "fominairina.011974@postgrespro.ru", "phone": "+70263126226"}
0005435257477	356D08	5957 223267	YULIYA ANDREEVA	{"phone": "+70355853896"}
0005435257478	356D08	6196 013844	VALENTINA SOKOLOVA	{"phone": "+70520057877"}
0005435257479	356D08	1865 103677	VALERIY ALEKSEEV	{"phone": "+70500767185"}
0005435257480	750E92	1693 599522	ZINAIDA ZAYCEVA	{"phone": "+70005258779"}
0005435257481	750E92	1048 305103	LYUDMILA ANISIMOVA	{"phone": "+70680674573"}
0005435257482	CB01EB	7251 097119	VALENTINA MIKHAYLOVA	{"phone": "+70912286340"}
0005435257483	88B4CF	7501 293943	YURIY AFANASEV	{"email": "y.afanasev_111965@postgrespro.ru", "phone": "+70124891609"}
0005435257484	BB9785	8334 622187	GALINA CHERNOVA	{"email": "galina_chernova_061964@postgrespro.ru", "phone": "+70254039953"}
0005435257485	BB9785	4222 662029	VITALIY KUZNECOV	{"phone": "+70913572804"}
0005435257486	66F3B6	0021 499012	TATYANA MOROZOVA	{"email": "morozova-tatyana_081964@postgrespro.ru", "phone": "+70324905983"}
0005435257487	66F3B6	5403 228550	YAKOV ORLOV	{"phone": "+70547221845"}
0005435257488	071347	9637 178278	ELENA SEMENOVA	{"phone": "+70964065007"}
0005435257489	039A3C	7566 521995	ALEKSEY KUDRYASHOV	{"phone": "+70982754575"}
0005435257490	289513	9442 198135	ILDAR AFANASEV	{"phone": "+70655868213"}
0005435257491	3B2FB2	3530 331356	VLADIMIR MATVEEV	{"phone": "+70977221220"}
0005435257492	0F3404	6848 084732	OLGA KOLESNIKOVA	{"email": "olga-kolesnikova-20021974@postgrespro.ru", "phone": "+70406116767"}
0005435257493	9FF0CE	1538 744404	ILYA KUZNECOV	{"email": "kuznecov.i.011976@postgrespro.ru", "phone": "+70171505914"}
0005435257494	9FF0CE	0030 076708	EVGENIYA GUSEVA	{"email": "guseva.e_1977@postgrespro.ru", "phone": "+70395913085"}
0005435257495	55735F	2668 192075	KRISTINA POLYAKOVA	{"email": "kpolyakova_1972@postgrespro.ru", "phone": "+70033164135"}
0005435257496	4AF0ED	5259 316115	KLAVDIYA ILINA	{"email": "ilina-k-081978@postgrespro.ru", "phone": "+70641329750"}
0005435257497	4686CB	8583 791778	NINA STEPANOVA	{"email": "n-stepanova_02011977@postgrespro.ru", "phone": "+70737294561"}
0005435257498	4686CB	5830 431472	GALINA ILINA	{"email": "g-ilina-1987@postgrespro.ru", "phone": "+70902638200"}
0005435257499	0396F0	4286 595848	ELENA BORISOVA	{"email": "borisova_elena-1966@postgrespro.ru", "phone": "+70736427952"}
0005435257500	0396F0	5086 909483	SERGEY VOROBEV	{"phone": "+70327659450"}
0005435257501	B12856	7195 201270	LYUDMILA SEMENOVA	{"email": "semenoval08081962@postgrespro.ru", "phone": "+70506228780"}
0005435257502	9BB57B	0667 875743	EKATERINA MOISEEVA	{"phone": "+70633638363"}
0005435257503	E3267F	7833 240304	YAKOV MELNIKOV	{"email": "melnikovyakov_1982@postgrespro.ru", "phone": "+70971385443"}
0005435257505	B4466F	4383 702129	LYUDMILA RYABOVA	{"email": "lryabova.071970@postgrespro.ru", "phone": "+70103777554"}
0005435257506	26FE49	2692 176890	EVGENIY MIKHAYLOV	{"email": "evgeniy-mikhaylov-031976@postgrespro.ru", "phone": "+70602231360"}
0005435257507	91FE67	4124 932416	ELENA KALININA	{"email": "kalinina_elena-051975@postgrespro.ru", "phone": "+70499762520"}
0005435257508	2B336B	3760 689570	ALEKSANDR MEDVEDEV	{"email": "a-medvedev_101976@postgrespro.ru", "phone": "+70425356633"}
0005435257509	2B336B	9544 376688	VADIM IVANOV	{"phone": "+70966225323"}
0005435257510	B8A50F	1668 760987	TATYANA MELNIKOVA	{"phone": "+70932609093"}
0005435257511	B8A50F	2996 868347	ALEKSEY MAKAROV	{"email": "makarov_a_16101974@postgrespro.ru", "phone": "+70449247896"}
0005435257512	068F42	2070 261539	MARIYA KOMAROVA	{"phone": "+70862371772"}
0005435257513	FB304C	1407 408497	TATYANA KUZNECOVA	{"phone": "+70672574160"}
0005435257514	FB304C	7668 353425	TAMARA POLYAKOVA	{"phone": "+70729606084"}
0005435257515	FB304C	3412 591489	MARIYA CHERNOVA	{"email": "m_chernova-24061965@postgrespro.ru", "phone": "+70398337518"}
0005435257516	E14D44	8131 065566	DENIS MIRONOV	{"email": "d.mironov-1971@postgrespro.ru", "phone": "+70019764364"}
0005435257517	F139BA	5102 414425	DMITRIY SMIRNOV	{"email": "d.smirnov1974@postgrespro.ru", "phone": "+70070051862"}
0005435257518	5DEB08	4726 900078	EVGENIY SOKOLOV	{"email": "e_sokolov_011977@postgrespro.ru", "phone": "+70085576497"}
0005435257519	5DEB08	0347 781990	DANIL TIMOFEEV	{"email": "timofeev-d-1975@postgrespro.ru", "phone": "+70271234509"}
0005435257521	FE7480	7273 119743	VLADIMIR KRASNOV	{"phone": "+70522989534"}
0005435257522	2BC3A9	7857 241792	NATALYA BOGDANOVA	{"email": "nbogdanova22031967@postgrespro.ru", "phone": "+70014230825"}
0005435257523	2BC3A9	1075 313978	SVETLANA MOROZOVA	{"email": "morozovasvetlana-1980@postgrespro.ru", "phone": "+70310437721"}
0005435257524	2BC3A9	1165 308969	ELENA ROMANOVA	{"email": "elena-romanova06081965@postgrespro.ru", "phone": "+70529264935"}
0005435257525	4A77BE	8669 371827	ALEKSANDR ZAKHAROV	{"email": "a.zakharov_25081974@postgrespro.ru", "phone": "+70262198413"}
0005435257526	790992	0492 080480	IRINA TARASOVA	{"email": "irina_tarasova.1965@postgrespro.ru", "phone": "+70209650622"}
0005435257527	F5003B	4502 863035	ALEKSANDR BORISOV	{"phone": "+70495783710"}
0005435257528	B75612	0768 689206	GENNADIY MAKAROV	{"email": "gmakarov-041960@postgrespro.ru", "phone": "+70647504791"}
0005435257529	B75612	4466 507378	ALEKSEY KOROLEV	{"email": "korolev.aleksey1973@postgrespro.ru", "phone": "+70557423127"}
0005435257530	0336E0	3402 672298	TARAS DENISOV	{"phone": "+70315940600"}
0005435257531	9B9CAB	5738 969486	ALINA EGOROVA	{"phone": "+70526832593"}
0005435257532	9B9CAB	5773 104664	NINA FEDOROVA	{"phone": "+70050410857"}
0005435257533	F69800	6319 679512	NIKOLAY SOLOVEV	{"email": "solovev.nikolay_17021974@postgrespro.ru", "phone": "+70339646909"}
0005435257534	6190A8	7987 194643	ROMAN VOLKOV	{"phone": "+70004135926"}
0005435257535	0D5440	3821 967664	TAGIR TIKHONOV	{"phone": "+70067514894"}
0005435257536	F6E02F	9854 783094	ULYANA IVANOVA	{"email": "uivanova031970@postgrespro.ru", "phone": "+70009162217"}
0005435257537	215B2E	8631 727084	OLGA PAVLOVA	{"phone": "+70377926866"}
0005435257538	D0F2B0	5812 123564	AMIR ZAYCEV	{"phone": "+70133907580"}
0005435257539	CE83DF	1591 142804	GALINA KARPOVA	{"phone": "+70575411132"}
0005435257540	EB15BB	3355 651201	IVAN NIKITIN	{"email": "nikitin_i-21071977@postgrespro.ru", "phone": "+70782946922"}
0005435257541	635E70	6959 077739	ALEKSEY SCHERBAKOV	{"phone": "+70858998428"}
0005435257542	1003D5	5651 737756	ANATOLIY FILIPPOV	{"email": "filippov.a_19071969@postgrespro.ru", "phone": "+70749772683"}
0005435257543	1003D5	4833 019860	EVGENIY KUZNECOV	{"email": "evgeniykuznecov101987@postgrespro.ru", "phone": "+70278629719"}
0005435257544	47801B	8443 085255	LYUDMILA VASILEVA	{"email": "l_vasileva_23031961@postgrespro.ru", "phone": "+70523088110"}
0005435257545	CA3D0D	7070 556584	IRINA ROMANOVA	{"phone": "+70971331396"}
0005435257546	036398	5577 237693	EVGENIY IVANOV	{"phone": "+70377126952"}
0005435257547	036398	2919 344839	ELENA ABRAMOVA	{"phone": "+70574860404"}
0005435259678	7BDE69	5730 605852	EVGENIY POPOV	{"phone": "+70613539428"}
0005435259679	90144D	9570 237184	VERA DENISOVA	{"phone": "+70726287506"}
0005435259680	0B5075	0622 099842	MIKHAIL KOROLEV	{"phone": "+70644482299"}
0005435259681	8724B7	7350 677039	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov-031972@postgrespro.ru", "phone": "+70398793227"}
0005435259682	89DE55	8336 184233	LYUDMILA MARTYNOVA	{"email": "lyudmila_martynova_1961@postgrespro.ru", "phone": "+70737027600"}
0005435259683	CDFF68	1030 720570	LARISA TITOVA	{"phone": "+70202815202"}
0005435259684	764B0B	3390 623059	KONSTANTIN SOROKIN	{"email": "sorokin.konstantin-25081976@postgrespro.ru", "phone": "+70438475755"}
0005435259685	745305	1631 218291	ANDREY KUZNECOV	{"phone": "+70935743888"}
0005435259686	745305	6629 609808	ARINA SAVELEVA	{"phone": "+70906739256"}
0005435259687	745305	6604 268647	VIKTOR SMIRNOV	{"email": "smirnov_viktor031977@postgrespro.ru", "phone": "+70277798865"}
0005435259688	202FBB	4197 265921	PAVEL PAVLOV	{"email": "pavlov.pavel-111964@postgrespro.ru", "phone": "+70449506245"}
0005435259689	665D46	1182 239085	YULIYA ALEKSEEVA	{"email": "yuliya-alekseeva-051982@postgrespro.ru", "phone": "+70080908542"}
0005435259690	665D46	4108 513073	DINA FILIPPOVA	{"email": "filippova.dina04111982@postgrespro.ru", "phone": "+70094807586"}
0005435259691	9046EB	0452 648085	VALERIY KUZNECOV	{"phone": "+70524513382"}
0005435259692	2A47D5	6173 325191	MAKSIM NAZAROV	{"phone": "+70046099408"}
0005435259693	2A47D5	9130 549875	EKATERINA POPOVA	{"email": "popova-e-02011969@postgrespro.ru", "phone": "+70870182639"}
0005435259694	6F744A	8750 793060	TATYANA NAZAROVA	{"email": "tatyana-nazarova-11021986@postgrespro.ru", "phone": "+70346129349"}
0005435259695	C6F947	6736 169077	OLEG ZHURAVLEV	{"email": "o_zhuravlev_1969@postgrespro.ru", "phone": "+70992430844"}
0005435259696	139465	7487 733180	OLGA KUDRYASHOVA	{"phone": "+70852036533"}
0005435259697	F408FC	1119 723152	ELENA VOLKOVA	{"email": "volkova_e1977@postgrespro.ru", "phone": "+70598716143"}
0005435259698	C5ACF8	4433 753601	ANNA SOROKINA	{"email": "asorokina_071980@postgrespro.ru", "phone": "+70618703884"}
0005435259699	C5ACF8	8176 183129	DINARA KUZNECOVA	{"email": "kuznecova.d-02071964@postgrespro.ru", "phone": "+70076259430"}
0005435259700	C5ACF8	0685 069337	SVETLANA LAZAREVA	{"phone": "+70623074718"}
0005435259701	7AC8CE	9651 356992	NINA KUZNECOVA	{"phone": "+70417584582"}
0005435259702	9D7B83	5780 721832	TATYANA PAVLOVA	{"email": "t_pavlova-071980@postgrespro.ru", "phone": "+70556860759"}
0005435259703	9D7B83	0329 499715	ELIZAVETA MELNIKOVA	{"email": "elizaveta_melnikova1969@postgrespro.ru", "phone": "+70565316139"}
0005435259704	7AB124	1492 666450	IRINA PETROVA	{"phone": "+70906245318"}
0005435259705	7AB124	6788 759932	SOFYA TARASOVA	{"phone": "+70193933953"}
0005435259706	17624F	9268 839326	ALEKSANDR NAZAROV	{"email": "nazarov_a_011964@postgrespro.ru", "phone": "+70209750870"}
0005435259707	17624F	3447 046170	ELENA GUSEVA	{"phone": "+70836863753"}
0005435259708	17624F	5788 108491	SVETLANA SERGEEVA	{"phone": "+70266930209"}
0005435259709	E00529	6604 130782	MARIANNA ARKHIPOVA	{"email": "mariannaarkhipova_1964@postgrespro.ru", "phone": "+70593287874"}
0005435259710	0A1575	5478 016905	TATYANA SAVELEVA	{"phone": "+70957652239"}
0005435263664	713F22	6848 448190	LYUDMILA NOVIKOVA	{"phone": "+70623447609"}
0005435259711	0A1575	5271 158545	NATALYA GUSEVA	{"email": "gusevanatalya.29061983@postgrespro.ru", "phone": "+70846171145"}
0005435259712	0A1575	3300 008064	IVAN FEDOTOV	{"phone": "+70530424504"}
0005435259713	2DA47A	1859 432442	VIKTORIYA SERGEEVA	{"phone": "+70278218799"}
0005435259714	C81BC3	8193 013130	SANIYA OVCHINNIKOVA	{"phone": "+70595883567"}
0005435259715	2A343E	8384 850956	MAKSIM SCHERBAKOV	{"phone": "+70623228350"}
0005435259716	49F1B6	3037 410082	EVGENIY CHERNOV	{"phone": "+70228028539"}
0005435259717	F7E94F	8023 314534	ALENA LEBEDEVA	{"email": "lebedeva.alena06091981@postgrespro.ru", "phone": "+70497469888"}
0005435259718	5AB51E	1169 218714	SVETLANA ZAKHAROVA	{"phone": "+70658140865"}
0005435259719	5AB51E	0394 803677	ELENA PAVLOVA	{"phone": "+70386543811"}
0005435259720	B79784	2814 131854	STEPAN FEDOROV	{"phone": "+70314741594"}
0005435259721	2624F3	5445 784162	NIKOLAY ANDREEV	{"phone": "+70663168668"}
0005435259722	A82D70	9400 870739	VENIAMIN GORBUNOV	{"phone": "+70834146510"}
0005435259723	A82D70	6541 412052	VYACHESLAV MATVEEV	{"email": "matveev-vyacheslav-08101982@postgrespro.ru", "phone": "+70136212452"}
0005435259724	F21CF8	1543 217342	ALBERT SEMENOV	{"phone": "+70239275412"}
0005435259725	F21CF8	0435 111182	YULIYA POPOVA	{"phone": "+70591290927"}
0005435259726	A28746	3769 573564	ELENA SERGEEVA	{"phone": "+70803704173"}
0005435259727	A28746	0365 603454	YURIY ZHUKOV	{"email": "zhukovy.13031959@postgrespro.ru", "phone": "+70447057341"}
0005435259728	340B82	8507 406407	LIDIYA LOGINOVA	{"phone": "+70039740132"}
0005435259729	D0B480	2235 286874	EKATERINA VOLKOVA	{"phone": "+70586023599"}
0005435259730	D0B480	0727 976844	SERGEY FOMIN	{"email": "fomin_sergey_1964@postgrespro.ru", "phone": "+70002940257"}
0005435259731	18F0EF	3958 246439	SVETLANA NIKOLAEVA	{"email": "s_nikolaeva-061979@postgrespro.ru", "phone": "+70644793809"}
0005435259732	39679C	1544 563532	ALEKSEY MEDVEDEV	{"email": "a-medvedev1964@postgrespro.ru", "phone": "+70505411431"}
0005435259733	C4DAF7	3139 199070	VADIM ZAKHAROV	{"phone": "+70807714618"}
0005435259734	2077B1	4648 182974	SERGEY KUZNECOV	{"email": "s-kuznecov10091988@postgrespro.ru", "phone": "+70649957214"}
0005435259735	D0BCDA	2700 246516	ELENA KUZNECOVA	{"phone": "+70046832853"}
0005435259736	D0BCDA	7513 986063	SERGEY POPOV	{"phone": "+70027810509"}
0005435259849	D12110	8594 726953	PAVEL ZAKHAROV	{"phone": "+70952782568"}
0005435259737	C72771	4466 971200	ALEKSANDR CHERNOV	{"email": "chernov_a-051965@postgrespro.ru", "phone": "+70163674098"}
0005435259738	8A766C	3686 656377	SVETLANA SOLOVEVA	{"email": "soloveva_svetlana.121976@postgrespro.ru", "phone": "+70059937486"}
0005435259739	1E604A	0343 048906	GALINA STEPANOVA	{"email": "g_stepanova.111980@postgrespro.ru", "phone": "+70608006745"}
0005435259740	18580A	0119 300534	EVGENIY MARTYNOV	{"email": "evgeniy_martynov_01071968@postgrespro.ru", "phone": "+70935976706"}
0005435259741	E00715	9172 065586	VALENTINA POLYAKOVA	{"phone": "+70033370267"}
0005435259742	B184E2	6449 526154	ANTONINA ABRAMOVA	{"email": "abramovaa121973@postgrespro.ru", "phone": "+70834116314"}
0005435259743	0E2240	4416 289221	VALENTINA KUZNECOVA	{"phone": "+70923609095"}
0005435259744	4B2485	8452 955742	NINA VOROBEVA	{"email": "n-vorobeva08121968@postgrespro.ru", "phone": "+70811645997"}
0005435259745	4B2485	6763 863572	VYACHESLAV KOROLEV	{"email": "korolev.vyacheslav-1978@postgrespro.ru", "phone": "+70531143638"}
0005435259746	5EA48A	2785 629469	VALENTINA POTAPOVA	{"email": "valentina_potapova_1974@postgrespro.ru", "phone": "+70785713552"}
0005435259747	C5AAC1	6225 957314	ANASTASIYA TARASOVA	{"email": "a_tarasova_021981@postgrespro.ru", "phone": "+70289418590"}
0005435259748	01B53D	3542 707168	ALBINA VOLKOVA	{"phone": "+70428541132"}
0005435259749	9BCFA9	0225 043169	RAISA NIKOLAEVA	{"phone": "+70928330060"}
0005435259750	7B49DE	8774 582954	ALENA MEDVEDEVA	{"phone": "+70986392445"}
0005435259751	BCCD79	1786 516918	OLGA AFANASEVA	{"email": "olgaafanaseva-011963@postgrespro.ru", "phone": "+70162969437"}
0005435259752	BCCD79	8972 527080	NIKOLAY NIKOLAEV	{"email": "nnikolaev_101979@postgrespro.ru", "phone": "+70248554857"}
0005435259753	BCCD79	9452 127510	RUDOLF YAKOVLEV	{"email": "r_yakovlev_11021978@postgrespro.ru", "phone": "+70121852980"}
0005435259754	D1591D	8983 543799	DMITRIY SOLOVEV	{"phone": "+70648470294"}
0005435259755	B7E186	2320 563205	VLADISLAV IVANOV	{"email": "vivanov.1977@postgrespro.ru", "phone": "+70738524103"}
0005435259756	B7E186	8220 202323	ELENA IVANOVA	{"email": "ivanovaelena.111966@postgrespro.ru", "phone": "+70305510190"}
0005435259757	7C4FD2	0881 456809	NIKOLAY KOZLOV	{"email": "kozlovn.25061971@postgrespro.ru", "phone": "+70765889484"}
0005435259758	7C4FD2	8156 798360	ARTEM STEPANOV	{"email": "stepanov.a_30041971@postgrespro.ru", "phone": "+70821914806"}
0005435259759	B5EA77	0236 812292	DMITRIY SAVELEV	{"email": "dmitriy.savelev1975@postgrespro.ru", "phone": "+70076996119"}
0005435259760	B5EA77	5883 875925	SVETLANA EFIMOVA	{"email": "efimovasvetlana.17081962@postgrespro.ru", "phone": "+70606530434"}
0005435259761	F26A32	8833 189801	SERGEY STEPANOV	{"email": "sergey_stepanov_1976@postgrespro.ru", "phone": "+70736867568"}
0005435259762	137490	4447 628334	LYUDMILA AKIMOVA	{"phone": "+70505380568"}
0005435259763	137490	4674 961497	VALENTINA YAKOVLEVA	{"email": "yakovlevav.1973@postgrespro.ru", "phone": "+70057616022"}
0005435259764	06EB9E	3305 039414	ALENA DANILOVA	{"phone": "+70908357813"}
0005435259765	06EB9E	4457 599689	SERGEY MATVEEV	{"email": "sergey_matveev.1971@postgrespro.ru", "phone": "+70426691374"}
0005435259766	09563C	1005 843273	LYUDMILA ZHUKOVA	{"phone": "+70514551341"}
0005435259767	7BAD31	8110 666515	NADEZHDA LUKYANOVA	{"email": "nadezhda.lukyanova_1970@postgrespro.ru", "phone": "+70228537689"}
0005435259768	B48B0E	3222 436204	ARSENIY KISELEV	{"email": "akiselev_1980@postgrespro.ru", "phone": "+70142397811"}
0005435259769	B48B0E	4684 015364	NATALYA ALEKSEEVA	{"phone": "+70200060116"}
0005435259770	CF2FD3	8005 969327	VIOLETTA FEDOROVA	{"email": "violetta.fedorova_12081958@postgrespro.ru", "phone": "+70367609452"}
0005435259771	220CE3	5547 615112	VLADIMIR TIKHONOV	{"phone": "+70604049900"}
0005435259772	2CD848	9555 588405	SERGEY MIKHAYLOV	{"phone": "+70824456516"}
0005435259773	603178	2687 506395	FAINA KRASNOVA	{"phone": "+70585822454"}
0005435259774	B323C6	3080 271142	ELIZAVETA PETROVA	{"email": "petrova_e-22031969@postgrespro.ru", "phone": "+70717837186"}
0005435259775	B323C6	7838 597876	LARISA GUSEVA	{"phone": "+70341576427"}
0005435259776	B323C6	8045 219311	YURIY KUZMIN	{"phone": "+70858373990"}
0005435259777	00FA77	7943 390879	VLADISLAV MOROZOV	{"email": "morozov_v-071969@postgrespro.ru", "phone": "+70159780822"}
0005435259778	E81BC6	5041 139605	MARIYA BORISOVA	{"phone": "+70125253745"}
0005435259779	3967A9	4887 273100	ANDREY SIDOROV	{"phone": "+70477379265"}
0005435259780	3967A9	2454 675518	ANASTASIYA VOROBEVA	{"phone": "+70069359939"}
0005435259781	ACEF23	3552 153628	NIKOLAY KISELEV	{"email": "kiselev-nikolay.041977@postgrespro.ru", "phone": "+70421544029"}
0005435259782	082611	5649 239396	VYACHESLAV NOVIKOV	{"phone": "+70099769586"}
0005435259783	8E953A	0705 534334	RAISA IVANOVA	{"email": "r.ivanova08121977@postgrespro.ru", "phone": "+70631385670"}
0005435259784	8E953A	2276 141759	LARISA BELOVA	{"phone": "+70454000642"}
0005435259785	D8FB45	7797 404516	OLEG CHERNOV	{"phone": "+70072949476"}
0005435259786	1F96B1	5328 362286	SERGEY ROMANOV	{"phone": "+70411152177"}
0005435259787	B84183	7879 853918	SVETLANA VOROBEVA	{"email": "svetlanavorobeva081959@postgrespro.ru", "phone": "+70621415866"}
0005435259788	F2B71F	6841 393080	NATALYA MIKHAYLOVA	{"email": "n.mikhaylova.091966@postgrespro.ru", "phone": "+70765353597"}
0005435259789	515FAA	2636 508872	MARINA FILATOVA	{"email": "marina.filatova-111980@postgrespro.ru", "phone": "+70729525467"}
0005435259790	515FAA	3767 723226	SVETLANA ZAKHAROVA	{"email": "svetlanazakharova051976@postgrespro.ru", "phone": "+70034491244"}
0005435259791	F2C65E	7359 601071	ZINAIDA KOZLOVA	{"phone": "+70338828123"}
0005435259792	F2C65E	2801 946613	TATYANA LEBEDEVA	{"email": "tatyana.lebedeva_18121973@postgrespro.ru", "phone": "+70543966013"}
0005435259793	D41379	0192 700609	NINA PAVLOVA	{"phone": "+70916875142"}
0005435259794	7C8129	2309 356895	VLADIMIR SMIRNOV	{"phone": "+70969896964"}
0005435259795	AE659E	3460 129096	ZINAIDA IVANOVA	{"email": "zinaida_ivanova_1978@postgrespro.ru", "phone": "+70888720596"}
0005435259796	F04096	4472 622563	VALENTINA TIMOFEEVA	{"phone": "+70643761079"}
0005435259797	321B2C	7008 351403	IVAN ALEKSEEV	{"email": "ivan.alekseev-23071983@postgrespro.ru", "phone": "+70378011614"}
0005435259798	2489D8	6514 709104	ELENA PETROVA	{"phone": "+70551229437"}
0005435259799	2D8AE6	7274 183319	TATYANA GAVRILOVA	{"email": "tatyana-gavrilova-071959@postgrespro.ru", "phone": "+70649117923"}
0005435259800	73CB0E	3643 672936	IVAN NAZAROV	{"phone": "+70777166928"}
0005435259801	73CB0E	5297 423318	DENIS KAZAKOV	{"phone": "+70136431124"}
0005435259802	A141C6	1364 461052	ANDREY GAVRILOV	{"email": "gavrilov.andrey071960@postgrespro.ru", "phone": "+70811034142"}
0005435259803	251623	9579 184187	VLADISLAV FROLOV	{"phone": "+70206624282"}
0005435259804	0CAAC4	8142 701567	SERGEY NIKOLAEV	{"email": "nikolaevsergey_021971@postgrespro.ru", "phone": "+70176871913"}
0005435259805	0CAAC4	9461 926349	DANIL IVANOV	{"phone": "+70998611891"}
0005435259806	61CDA9	6352 174562	EVGENIY KULIKOV	{"phone": "+70618475567"}
0005435259807	FDFA60	5706 001989	RAISA RYABOVA	{"email": "raisa_ryabova.1960@postgrespro.ru", "phone": "+70632613647"}
0005435259808	62BE16	3851 336934	ILYA KONOVALOV	{"email": "konovalov.ilya1964@postgrespro.ru", "phone": "+70637722924"}
0005435259809	62BE16	1703 097147	ANTONINA PETROVA	{"email": "petrova-a_1978@postgrespro.ru", "phone": "+70528557826"}
0005435259810	62BE16	8177 574471	TATYANA VASILEVA	{"phone": "+70416517071"}
0005435259811	1BD0C9	0438 352026	DMITRIY KUZNECOV	{"email": "kuznecov.d-1966@postgrespro.ru", "phone": "+70497789652"}
0005435259812	1BD0C9	5085 474054	NATALYA SIDOROVA	{"phone": "+70608936041"}
0005435259813	C267B7	6564 942794	KONSTANTIN VOROBEV	{"phone": "+70308451899"}
0005435259814	EE8582	6891 955908	IRINA KOZLOVA	{"phone": "+70643394579"}
0005435259815	B524FD	2833 371090	REGINA KULIKOVA	{"phone": "+70223315784"}
0005435259816	B524FD	9028 474255	ANNA STEPANOVA	{"email": "stepanovaa-041982@postgrespro.ru", "phone": "+70829675145"}
0005435259817	96DFBA	1943 451597	PAVEL ZHUKOV	{"email": "p.zhukov1977@postgrespro.ru", "phone": "+70388467329"}
0005435259818	A7CC32	9616 837320	RUZALIYA IVANOVA	{"phone": "+70938373996"}
0005435259819	9110C0	8045 783116	ZINAIDA MAKAROVA	{"phone": "+70954876248"}
0005435259820	9110C0	2981 719914	DANIIL FEDOROV	{"email": "fedorov-d_101977@postgrespro.ru", "phone": "+70506983014"}
0005435259821	C43077	3634 465525	VLADIMIR PETROV	{"phone": "+70667437704"}
0005435259822	C43077	1807 615554	VLADIMIR CHERNOV	{"email": "vchernov.061975@postgrespro.ru", "phone": "+70312494651"}
0005435259823	2C6A21	7994 406490	VIKTOR NAUMOV	{"email": "naumovviktor101976@postgrespro.ru", "phone": "+70532697024"}
0005435259824	52F33C	6994 868568	DENIS BARANOV	{"phone": "+70894363018"}
0005435259825	725283	6789 628150	VITALIY FILIPPOV	{"phone": "+70803518105"}
0005435259826	725283	3352 448933	EKATERINA MELNIKOVA	{"phone": "+70050307625"}
0005435259827	A212CA	9137 650548	SERGEY CHERNOV	{"phone": "+70957862960"}
0005435259828	A212CA	8975 012278	LEONID ALEKSEEV	{"email": "alekseev.l-21121972@postgrespro.ru", "phone": "+70338989416"}
0005435259829	A212CA	5954 186874	MARIYA KONOVALOVA	{"phone": "+70318237859"}
0005435259830	EA91AA	1003 150638	TATYANA KOZLOVA	{"phone": "+70150919093"}
0005435259831	EA91AA	1966 293345	LYUDMILA ANTONOVA	{"email": "antonova.l-1964@postgrespro.ru", "phone": "+70602934974"}
0005435259832	DA9BC4	2478 162771	RINAT ZHUKOV	{"phone": "+70661318991"}
0005435259833	681DE1	3265 445630	YULIYA VOLKOVA	{"email": "volkova.y011967@postgrespro.ru", "phone": "+70944723697"}
0005435259834	7D03AA	3977 662903	RAMIL FILIPPOV	{"email": "filippovr.12051985@postgrespro.ru", "phone": "+70550032727"}
0005435259835	7D03AA	7231 193227	GALINA SCHERBAKOVA	{"phone": "+70865613227"}
0005435259836	01FE64	1424 812712	NIKOLAY ORLOV	{"email": "nikolay_orlov-28121961@postgrespro.ru", "phone": "+70473062746"}
0005435259837	4AB0C2	3306 965909	ARTEM BELOV	{"email": "belov_artem.1961@postgrespro.ru", "phone": "+70404979155"}
0005435259838	4AB0C2	2223 463819	VERA TIKHONOVA	{"email": "tikhonova-vera.081984@postgrespro.ru", "phone": "+70604366765"}
0005435259839	4340CD	3061 593748	SERGEY PAVLOV	{"phone": "+70262404942"}
0005435259840	4340CD	3904 099503	LYUDMILA FILIPPOVA	{"phone": "+70807516593"}
0005435259841	31D5D7	6280 572976	EVDOKIYA FILIPPOVA	{"phone": "+70154619752"}
0005435259842	5D19D3	2290 788015	TATYANA FEDOROVA	{"email": "tfedorova.071978@postgrespro.ru", "phone": "+70583034906"}
0005435259843	5D19D3	0143 739825	ROMAN IVANOV	{"email": "roman-ivanov_1983@postgrespro.ru", "phone": "+70576621109"}
0005435259844	1672C2	5877 703158	BOGDAN GORBUNOV	{"phone": "+70476169871"}
0005435259845	3444D5	0429 009049	NATALYA PAVLOVA	{"phone": "+70149341867"}
0005435259846	F430D1	6164 681301	EKATERINA YAKOVLEVA	{"email": "yakovlevaekaterina.041970@postgrespro.ru", "phone": "+70216919852"}
0005435259847	F430D1	9942 598378	MIKHAIL SAVELEV	{"phone": "+70748158947"}
0005435259848	D70C48	3210 244120	EVGENIY PAVLOV	{"phone": "+70728679217"}
0005435259850	678C61	0416 885765	IGOR ALEKSANDROV	{"email": "aleksandrov.igor_081983@postgrespro.ru", "phone": "+70849625999"}
0005435259851	B49FB3	5869 258066	NINA GERASIMOVA	{"phone": "+70432327849"}
0005435259852	B49FB3	5396 747146	SERGEY ANTONOV	{"email": "s-antonov-28091977@postgrespro.ru", "phone": "+70835638025"}
0005435259853	B49FB3	2414 243127	OLGA BORISOVA	{"email": "borisovaolga-1976@postgrespro.ru", "phone": "+70204586977"}
0005435259854	770BF4	4013 016231	DARYA ZAKHAROVA	{"email": "zakharova-darya031977@postgrespro.ru", "phone": "+70470880972"}
0005435259855	50B0C8	9296 478273	GRIGORIY MELNIKOV	{"phone": "+70232878823"}
0005435259856	50B0C8	1506 205635	ELEONORA TIMOFEEVA	{"email": "timofeeva_e-07081978@postgrespro.ru", "phone": "+70143621581"}
0005435259857	C8B0B4	9524 901390	DMITRIY MAKAROV	{"email": "makarov_d09111967@postgrespro.ru", "phone": "+70431534577"}
0005435259858	C8B0B4	3380 686090	ILDAR VLASOV	{"email": "ildar.vlasov10011959@postgrespro.ru", "phone": "+70061959451"}
0005435259859	DF0B12	3910 211510	VLADIMIR SOKOLOV	{"email": "sokolov_v.07071969@postgrespro.ru", "phone": "+70827235336"}
0005435259860	DF0B12	2085 762578	GENNADIY FOMIN	{"email": "fomin_gennadiy-061976@postgrespro.ru", "phone": "+70373966779"}
0005435259861	1110F9	3817 756632	SOFYA GRISHINA	{"email": "grishina_s-011978@postgrespro.ru", "phone": "+70670561913"}
0005435259862	0B2BD4	7253 324098	EVGENIY IVANOV	{"email": "evgeniyivanov-071983@postgrespro.ru", "phone": "+70357565272"}
0005435259863	0ABDB5	5367 132593	VLADIMIR CHERNOV	{"phone": "+70754452615"}
0005435259864	C38E21	9258 631676	SERGEY FILIPPOV	{"email": "s-filippov.111973@postgrespro.ru", "phone": "+70671972322"}
0005435259865	BC96F7	4436 267107	SERGEY SCHERBAKOV	{"email": "scherbakov-s_27111970@postgrespro.ru", "phone": "+70671490480"}
0005435259866	CAD559	7230 786492	OLGA EGOROVA	{"phone": "+70805693018"}
0005435259867	FBAE7A	6254 250951	YULIYA KUZNECOVA	{"email": "yuliya.kuznecova.051968@postgrespro.ru", "phone": "+70104282833"}
0005435259868	FBAE7A	4975 379296	ANDREY SMIRNOV	{"phone": "+70547607163"}
0005435259869	791F78	8123 393789	KRISTINA MAKSIMOVA	{"phone": "+70443943823"}
0005435259870	791F78	8222 447698	RUSLAN POPOV	{"email": "popov-ruslan_041973@postgrespro.ru", "phone": "+70919087976"}
0005435259871	873F51	6444 478839	ALEKSANDR GAVRILOV	{"phone": "+70987978482"}
0005435259872	19B1C4	5897 225962	MARIYA LUKYANOVA	{"phone": "+70053976766"}
0005435259873	CB90C5	7080 308368	VASILIY ILIN	{"email": "ilinv_051974@postgrespro.ru", "phone": "+70861664406"}
0005435259874	833819	4340 827323	IGOR GERASIMOV	{"email": "igor.gerasimov.08101982@postgrespro.ru", "phone": "+70679896754"}
0005435259875	EB8089	7362 584402	GLEB SERGEEV	{"email": "g-sergeev1963@postgrespro.ru", "phone": "+70879087415"}
0005435259876	956BC9	7891 860554	LYUDMILA SEMENOVA	{"phone": "+70422252560"}
0005435259877	96A746	9023 604761	IGOR NIKITIN	{"email": "nikitin.igor_091987@postgrespro.ru", "phone": "+70055607187"}
0005435259878	153975	8346 516217	VLADIMIR MIRONOV	{"email": "mironovvladimir_101962@postgrespro.ru", "phone": "+70297134331"}
0005435259879	153975	6553 744726	EKATERINA AKIMOVA	{"phone": "+70845331313"}
0005435259880	C3B9DB	9946 492752	VLADIMIR YAKOVLEV	{"email": "yakovlev-vladimir-1962@postgrespro.ru", "phone": "+70685041378"}
0005435259881	19B6E3	0254 292568	NATALYA RODIONOVA	{"phone": "+70053101838"}
0005435259882	19B6E3	0965 080305	NATALYA MAKAROVA	{"email": "makarova-n_1980@postgrespro.ru", "phone": "+70460353920"}
0005435259883	614F75	8875 603996	GALINA ARKHIPOVA	{"email": "galinaarkhipova1974@postgrespro.ru", "phone": "+70359210949"}
0005435259884	31B809	0916 060380	VALERIYA MASLOVA	{"email": "maslova.valeriya_081973@postgrespro.ru", "phone": "+70965762298"}
0005435259885	B9C716	3929 921788	ALEKSEY MELNIKOV	{"phone": "+70030813874"}
0005435259886	1C4393	4989 375408	INNA DANILOVA	{"phone": "+70298765435"}
0005435259887	2F18B6	9818 645505	NIKOLAY DMITRIEV	{"phone": "+70225473480"}
0005435263528	60E79B	4871 450513	ALEKSEY DMITRIEV	{"phone": "+70833124530"}
0005435263479	F3E4F9	8989 102132	VLADIMIR MARTYNOV	{"email": "vladimirmartynov_101974@postgrespro.ru", "phone": "+70257043404"}
0005435263480	F3E4F9	9290 537364	NATALYA KUDRYASHOVA	{"phone": "+70047726076"}
0005435263481	A0A0CE	8062 589908	ALEKSANDR RODIONOV	{"phone": "+70691744903"}
0005435263482	A0A0CE	9131 391028	GALINA NESTEROVA	{"phone": "+70826414825"}
0005435263483	D53037	7201 249211	OLGA KUZNECOVA	{"email": "kuznecova-o08021967@postgrespro.ru", "phone": "+70328970712"}
0005435263484	EA7193	6448 986009	ALEKSEY GUSEV	{"email": "a.gusev.051975@postgrespro.ru", "phone": "+70880872523"}
0005435263485	EA7193	1663 002228	MARINA ZHUKOVA	{"phone": "+70286449806"}
0005435263486	A7A217	0175 441021	YULIYA AFANASEVA	{"email": "yafanaseva.1970@postgrespro.ru", "phone": "+70832710724"}
0005435263487	A7A217	6171 199562	IGOR MAKSIMOV	{"phone": "+70936579184"}
0005435263488	A7A217	3937 622727	VASILIY SERGEEV	{"email": "vasiliy_sergeev03051974@postgrespro.ru", "phone": "+70355980861"}
0005435263489	4525D4	9133 858635	GALINA SOROKINA	{"phone": "+70561380978"}
0005435263490	41E36A	8943 600541	ANNA MOROZOVA	{"email": "morozova_a1983@postgrespro.ru", "phone": "+70634535402"}
0005435263491	41E36A	3096 214308	OLGA ZAKHAROVA	{"email": "o_zakharova_111969@postgrespro.ru", "phone": "+70797065379"}
0005435263492	7F2E89	3491 747377	NATALYA PETROVA	{"email": "petrova_n.121970@postgrespro.ru", "phone": "+70854409313"}
0005435263493	F6EA3B	7800 522478	ALEKSANDR PETROV	{"phone": "+70742235738"}
0005435263494	F6EA3B	1297 481447	TATYANA ISAEVA	{"email": "tatyana_isaeva_1969@postgrespro.ru", "phone": "+70048729104"}
0005435263495	93CC02	4268 342464	GUZEL PAVLOVA	{"phone": "+70812085862"}
0005435263496	93CC02	7685 250846	TAISIYA SOKOLOVA	{"phone": "+70016802620"}
0005435263497	86AFBD	2957 047860	VLADISLAV KOZLOV	{"email": "kozlovv.1969@postgrespro.ru", "phone": "+70750520644"}
0005435263498	B602E9	1392 394076	EVGENIY SCHERBAKOV	{"phone": "+70078460765"}
0005435263499	4A9D78	9536 801641	VIKTOR BORISOV	{"email": "borisov_viktor18011978@postgrespro.ru", "phone": "+70275598342"}
0005435263500	83CB80	4444 075070	ELIZAVETA FROLOVA	{"phone": "+70102849003"}
0005435263501	83CB80	9516 216733	DMITRIY ALEKSEEV	{"email": "d-alekseev.041977@postgrespro.ru", "phone": "+70603845210"}
0005435263502	83CB80	1509 786464	ALEKSANDR KULIKOV	{"phone": "+70448974794"}
0005435263503	E5E14B	4651 651324	ROMAN ZAKHAROV	{"email": "r.zakharov.17091970@postgrespro.ru", "phone": "+70118488323"}
0005435263504	E5E14B	3820 395019	MIKHAIL OSIPOV	{"email": "osipov-mikhail-031978@postgrespro.ru", "phone": "+70072898449"}
0005435263505	4E287C	7329 048076	VALERIY PETROV	{"email": "v_petrov06091969@postgrespro.ru", "phone": "+70584884503"}
0005435263506	9F6200	7462 637661	VLADIMIR BELOV	{"email": "vladimir-belov.29091961@postgrespro.ru", "phone": "+70258227677"}
0005435263507	D1EEB4	2817 589356	ALEKSANDR EGOROV	{"email": "aleksandr_egorov.051983@postgrespro.ru", "phone": "+70855319229"}
0005435263508	055EFE	6907 840967	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov_1967@postgrespro.ru", "phone": "+70092339206"}
0005435263509	E44825	4738 925737	EVGENIY PETROV	{"phone": "+70348177615"}
0005435263510	3B2721	5059 395244	ELENA NAZAROVA	{"phone": "+70525144230"}
0005435263511	38A2C9	6666 099635	GALINA IVANOVA	{"email": "ivanova-galina-081955@postgrespro.ru", "phone": "+70774002065"}
0005435263512	68F7DD	0202 838935	OLGA ALEKSEEVA	{"phone": "+70430906365"}
0005435263513	9D6B10	8474 540417	ROZA ANDREEVA	{"phone": "+70097936178"}
0005435263514	9D6B10	2553 745501	VIKTOR ANTONOV	{"phone": "+70260400335"}
0005435263515	73C1E3	0472 713469	OLGA KUZNECOVA	{"phone": "+70692653863"}
0005435263516	B6FE74	1260 513756	LARISA ZAYCEVA	{"phone": "+70100794903"}
0005435263517	B6FE74	3258 855277	OLGA ZAYCEVA	{"email": "olga_zayceva081982@postgrespro.ru", "phone": "+70461076513"}
0005435263518	F91D5E	9532 914809	TATYANA FILIPPOVA	{"phone": "+70594116311"}
0005435263519	F91D5E	8562 074422	NIKOLAY ALEKSEEV	{"email": "n-alekseev1975@postgrespro.ru", "phone": "+70641041620"}
0005435263520	F91D5E	0429 294638	YULIYA SOKOLOVA	{"email": "sokolovayuliya.091963@postgrespro.ru", "phone": "+70952136317"}
0005435263521	63E778	7619 226246	ALEKSANDR BORISOV	{"email": "borisova.101977@postgrespro.ru", "phone": "+70365777288"}
0005435263522	63E778	0726 899614	ALEKSANDRA NESTEROVA	{"phone": "+70337707159"}
0005435263523	A3AACF	6205 637600	SVETLANA LOGINOVA	{"phone": "+70870844757"}
0005435263524	2F34A9	7266 026648	YURIY SHEVCHENKO	{"email": "yuriy.shevchenko-051969@postgrespro.ru", "phone": "+70390653036"}
0005435263525	F38D6F	7237 255527	ANNA EFREMOVA	{"email": "anna.efremova_1974@postgrespro.ru", "phone": "+70217366817"}
0005435263526	F38D6F	5180 676004	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir.1967@postgrespro.ru", "phone": "+70684711431"}
0005435263527	3008E4	8442 467468	OLEG ZHUKOV	{"phone": "+70745521690"}
0005435263529	9A34FA	5628 969336	ALEKSEY ABRAMOV	{"phone": "+70367237536"}
0005435263530	9A34FA	5600 190740	OLGA ANISIMOVA	{"email": "anisimova.o_1966@postgrespro.ru", "phone": "+70916594592"}
0005435263531	83BBA1	8549 815685	VALENTINA KOLESNIKOVA	{"phone": "+70545698655"}
0005435263532	9550C4	7893 052861	EVGENIY ZAYCEV	{"email": "zaycev.evgeniy_121973@postgrespro.ru", "phone": "+70608383843"}
0005435263533	DFBFFD	9343 867457	SERGEY MAKSIMOV	{"phone": "+70814949075"}
0005435263534	1B2C9C	6092 658322	ALEKSANDR GRIGOREV	{"email": "aleksandr_grigorev1970@postgrespro.ru", "phone": "+70755319929"}
0005435263535	97423F	8709 260265	PAVEL KUDRYASHOV	{"phone": "+70002267920"}
0005435263536	FE65A0	5003 881335	ANNA ZAKHAROVA	{"email": "anna-zakharova.1966@postgrespro.ru", "phone": "+70811260221"}
0005435263537	21325D	9948 490871	VERA SEMENOVA	{"email": "vera.semenova31081971@postgrespro.ru", "phone": "+70982846892"}
0005435263538	1E767E	0995 063666	NIKOLAY AFANASEV	{"phone": "+70791839199"}
0005435263539	E2BF67	1956 090007	ANDREY GERASIMOV	{"email": "andrey-gerasimov-1969@postgrespro.ru", "phone": "+70598494860"}
0005435263540	8C01C0	6892 051596	NATALYA MAKAROVA	{"email": "natalya.makarova-08111969@postgrespro.ru", "phone": "+70869855611"}
0005435263541	95ADB4	6993 817249	ELENA PAVLOVA	{"phone": "+70624728873"}
0005435263542	A3E160	2937 675743	LYUBOV OVCHINNIKOVA	{"email": "ovchinnikova_l_041971@postgrespro.ru", "phone": "+70497160470"}
0005435263543	1E618E	9227 042905	EVGENIY FROLOV	{"email": "efrolov_041976@postgrespro.ru", "phone": "+70627843961"}
0005435263544	1E618E	5537 622574	SERGEY NAUMOV	{"email": "sergey-naumov-09031963@postgrespro.ru", "phone": "+70150463809"}
0005435263545	9DEC66	3522 554522	POLINA MAKAROVA	{"phone": "+70072795019"}
0005435263546	9DEC66	7151 350757	YURIY KOROLEV	{"email": "korolev.y.29081970@postgrespro.ru", "phone": "+70725234588"}
0005435263547	65378E	4538 151608	PAVEL TARASOV	{"phone": "+70871639599"}
0005435263548	65378E	0924 945008	ZHANNA KUZNECOVA	{"email": "kuznecova.z.07071967@postgrespro.ru", "phone": "+70376714378"}
0005435263549	65378E	4129 508307	DANIIL DENISOV	{"phone": "+70782827232"}
0005435263550	6B7662	6570 712718	ARTEM ZAYCEV	{"phone": "+70242563146"}
0005435263551	6F3803	7013 804217	ALEKSEY FEDOTOV	{"email": "aleksey.fedotov.17081974@postgrespro.ru", "phone": "+70139448926"}
0005435263552	FE6E42	9500 606217	MARIYA CHERNOVA	{"email": "chernova_mariya.24071986@postgrespro.ru", "phone": "+70873942830"}
0005435263553	FE1BAD	3735 378219	ILYA YAKOVLEV	{"phone": "+70673267736"}
0005435263554	FE1BAD	4415 387289	GALIYA KONOVALOVA	{"email": "konovalova-g_01021967@postgrespro.ru", "phone": "+70072217818"}
0005435263555	2C713D	1623 748942	PAVEL IVANOV	{"phone": "+70329361975"}
0005435263556	0E0B87	4445 475042	DMITRIY OSIPOV	{"email": "osipovdmitriy-1979@postgrespro.ru", "phone": "+70096711121"}
0005435263557	0E0B87	3202 915196	VASILIY SERGEEV	{"phone": "+70339908603"}
0005435263558	991C0F	1069 818897	NINA IVANOVA	{"email": "ivanova-n1990@postgrespro.ru", "phone": "+70829395221"}
0005435263559	F4299F	8209 122457	VALERIYA POLYAKOVA	{"email": "polyakova-v.29051980@postgrespro.ru", "phone": "+70235151789"}
0005435263560	A9464F	3823 697036	VASILIY NAZAROV	{"phone": "+70590954768"}
0005435263561	A9464F	2682 919734	ANTONINA TIMOFEEVA	{"email": "a.timofeeva-03061976@postgrespro.ru", "phone": "+70805221926"}
0005435263562	A9BB0D	6631 264492	ALEKSEY DMITRIEV	{"email": "dmitriev_a041974@postgrespro.ru", "phone": "+70823089797"}
0005435263563	A9BB0D	2400 182130	ALEKSANDR VOLKOV	{"email": "a.volkov031975@postgrespro.ru", "phone": "+70917891537"}
0005435263564	61DC86	4898 117726	VASILIY AFANASEV	{"email": "v_afanasev071974@postgrespro.ru", "phone": "+70219333232"}
0005435263565	5C3F83	5831 007748	ANDREY OSIPOV	{"email": "osipov.andrey27061980@postgrespro.ru", "phone": "+70298238665"}
0005435263566	36203E	1598 150780	NATALYA KARPOVA	{"phone": "+70660274516"}
0005435263567	B820B7	5000 892754	GENNADIY NAUMOV	{"phone": "+70380826488"}
0005435263568	0F0F50	6567 002479	EKATERINA BARANOVA	{"email": "baranova_ekaterina-1967@postgrespro.ru", "phone": "+70300328451"}
0005435263569	3637BF	2231 742150	MIKHAIL KUZNECOV	{"phone": "+70883089409"}
0005435263570	74D0BC	2095 765076	VLADIMIR MARTYNOV	{"phone": "+70276373713"}
0005435263571	74D0BC	9789 339395	EVDOKIYA EFIMOVA	{"email": "evdokiya.efimova_081976@postgrespro.ru", "phone": "+70267541377"}
0005435263572	F0F866	1777 536646	OLGA RYABOVA	{"email": "ryabova_olga_071975@postgrespro.ru", "phone": "+70920581755"}
0005435263573	F0F866	6339 707410	ALEKSEY PETROV	{"phone": "+70729765641"}
0005435263574	61FD87	1345 449057	VLADISLAV ZAKHAROV	{"phone": "+70047740092"}
0005435263575	AC0890	7254 880458	VALERIY POPOV	{"email": "v_popov.1969@postgrespro.ru", "phone": "+70445606439"}
0005435263576	AC0890	9814 610011	NADEZHDA SEMENOVA	{"email": "nadezhdasemenova-01021969@postgrespro.ru", "phone": "+70783868293"}
0005435263577	1AD12F	3346 823193	ELIZAVETA FILIPPOVA	{"email": "elizaveta-filippova-021967@postgrespro.ru", "phone": "+70858991579"}
0005435263578	1AD12F	3655 164988	OLEG FEDOROV	{"phone": "+70281004369"}
0005435263579	1AD12F	4974 246204	MARIYA SOKOLOVA	{"phone": "+70914510649"}
0005435263580	CE1EF2	9534 698433	SERGEY KUZNECOV	{"phone": "+70146888091"}
0005435263581	8A10F9	5074 911243	VASILIY OSIPOV	{"phone": "+70545484769"}
0005435263582	A59A9F	5744 527584	VLADIMIR ILIN	{"phone": "+70252339459"}
0005435263583	C33912	2446 388054	VIKTOR NOVIKOV	{"phone": "+70474675726"}
0005435263584	C33912	7698 411411	SVETLANA PAVLOVA	{"email": "pavlova.s_1979@postgrespro.ru", "phone": "+70692212221"}
0005435263585	1779C1	6033 512866	MIKHAIL BARANOV	{"email": "m.baranov-1973@postgrespro.ru", "phone": "+70962378351"}
0005435263586	1779C1	2135 179713	VASILIY EGOROV	{"phone": "+70990413273"}
0005435263587	C79518	0213 291812	SERGEY SERGEEV	{"email": "ssergeev_13091966@postgrespro.ru", "phone": "+70203954151"}
0005435263588	E84D3D	7557 827132	ALEKSEY CHERNOV	{"phone": "+70024746028"}
0005435263589	95E45A	8526 132986	SERGEY EGOROV	{"phone": "+70436167993"}
0005435263590	EDFD14	5225 083179	MIKHAIL FROLOV	{"email": "mikhail-frolov.14061985@postgrespro.ru", "phone": "+70207021362"}
0005435263591	C94CFF	3023 014142	ALEKSANDR KONOVALOV	{"email": "konovalova_04041973@postgrespro.ru", "phone": "+70367817582"}
0005435263592	C94CFF	5192 943492	MATVEY EGOROV	{"email": "egorov.m1964@postgrespro.ru", "phone": "+70195517981"}
0005435263593	00D882	0249 215426	ANNA MALYSHEVA	{"phone": "+70637525159"}
0005435263594	B72411	7321 454812	VITALIY SMIRNOV	{"phone": "+70657541065"}
0005435263595	5CDE35	1647 259097	ALEKSEY AFANASEV	{"phone": "+70299031395"}
0005435263596	5DECAA	7555 078205	MIKHAIL TIKHONOV	{"email": "tikhonov_m081982@postgrespro.ru", "phone": "+70948730880"}
0005435263597	2EF8F5	5135 882379	ALISHER EGOROV	{"phone": "+70656500290"}
0005435263598	FEF346	2037 883613	ANNA SMIRNOVA	{"email": "smirnova-anna-051977@postgrespro.ru", "phone": "+70532472679"}
0005435263599	FEF346	2739 918839	ULYANA ZHUKOVA	{"phone": "+70126404310"}
0005435263600	FEF346	3621 975604	OLGA ZAKHAROVA	{"phone": "+70220811571"}
0005435263601	0FB7F9	1368 760632	NATALYA SCHERBAKOVA	{"phone": "+70130814119"}
0005435263602	396276	8154 144828	ALEKSEY MATVEEV	{"phone": "+70878473037"}
0005435263603	C2A67E	0229 409736	VERA KUZNECOVA	{"phone": "+70045180391"}
0005435263604	6BA9A7	9068 066046	KIRILL ZAKHAROV	{"email": "kirill-zakharov.1972@postgrespro.ru", "phone": "+70922730429"}
0005435263605	6BA9A7	5503 642651	SERGEY KONOVALOV	{"email": "s.konovalov-1985@postgrespro.ru", "phone": "+70700684877"}
0005435263606	653A70	2879 768849	SVETLANA ISAEVA	{"phone": "+70237456444"}
0005435263607	812B69	1880 366855	TATYANA FEDOROVA	{"phone": "+70720676200"}
0005435263608	812B69	7746 624910	SERGEY FILIPPOV	{"email": "sergey.filippov.091961@postgrespro.ru", "phone": "+70250535499"}
0005435263609	140210	7451 509081	OKSANA KISELEVA	{"phone": "+70483714908"}
0005435263610	BA858D	6326 331493	LYUDMILA SOKOLOVA	{"email": "l.sokolova01051972@postgrespro.ru", "phone": "+70628272327"}
0005435263611	BA79AF	5955 397467	LYUBOV DMITRIEVA	{"email": "l.dmitrieva_041973@postgrespro.ru", "phone": "+70305821405"}
0005435263612	20A48D	9582 133565	VITALIY FROLOV	{"email": "frolov_v041980@postgrespro.ru", "phone": "+70488583063"}
0005435263613	409C06	5688 521698	ALEKSANDRA BOGDANOVA	{"email": "a-bogdanova_071980@postgrespro.ru", "phone": "+70698565698"}
0005435263614	0DA354	5537 874061	TAMARA ROMANOVA	{"email": "romanova.t-17041977@postgrespro.ru", "phone": "+70917637092"}
0005435263615	4CECC0	8667 782019	MARIYA KOMAROVA	{"phone": "+70212923718"}
0005435263616	3D4DAC	5481 104962	NIKITA ALEKSANDROV	{"phone": "+70818258991"}
0005435263617	319418	3131 492862	VLADIMIR PETROV	{"email": "petrov_v21071964@postgrespro.ru", "phone": "+70761777986"}
0005435263618	319418	7575 206180	VLADIMIR ZAYCEV	{"phone": "+70674391935"}
0005435263619	5D9F9C	1478 442975	YULIYA KOVALEVA	{"phone": "+70576276569"}
0005435263620	DE749D	6714 607713	MAKSIM MOROZOV	{"phone": "+70738424377"}
0005435263621	DE749D	6881 393435	YANA RODIONOVA	{"phone": "+70637743642"}
0005435263622	6DB1CF	3202 039919	OKSANA ISAEVA	{"email": "isaeva-o_21121963@postgrespro.ru", "phone": "+70836660993"}
0005435263623	658E2A	6374 523756	DANIIL KUDRYASHOV	{"phone": "+70743512160"}
0005435263624	658E2A	1147 914264	ILYA MAKAROV	{"phone": "+70635822783"}
0005435263625	A40B9F	4290 604889	ALISA PETROVA	{"phone": "+70190493379"}
0005435263626	A936D2	5275 149491	IGOR KUDRYASHOV	{"email": "igor.kudryashov-12121972@postgrespro.ru", "phone": "+70119573266"}
0005435263627	1E7020	0673 234780	SVETLANA TITOVA	{"email": "titovas.17101969@postgrespro.ru", "phone": "+70321730376"}
0005435263628	1E7020	7918 247486	LARISA MIKHAYLOVA	{"email": "larisa_mikhaylova_1978@postgrespro.ru", "phone": "+70257585159"}
0005435263629	66A84B	2264 939734	ANDREY SCHERBAKOV	{"phone": "+70879186287"}
0005435263630	66A84B	3619 101219	ANDREY ZAKHAROV	{"email": "zakharov.a.101967@postgrespro.ru", "phone": "+70797944221"}
0005435263631	A74AA3	0024 541672	SVETLANA TIKHONOVA	{"email": "tikhonova-svetlana-021971@postgrespro.ru", "phone": "+70485767234"}
0005435263632	61AF3A	7921 749548	VASILIY KUZMIN	{"email": "kuzmin.v_061974@postgrespro.ru", "phone": "+70726369732"}
0005435263633	BB858B	1631 421625	SVETLANA ZAYCEVA	{"phone": "+70411921866"}
0005435263634	44A986	3087 794206	NURLAN ANTONOV	{"email": "nantonov1973@postgrespro.ru", "phone": "+70864464321"}
0005435263635	AF540E	6936 156148	ALEKSANDR IVANOV	{"phone": "+70569202656"}
0005435263636	FA1522	9328 520910	DMITRIY KUZNECOV	{"phone": "+70101216264"}
0005435263637	472193	4588 565808	VYACHESLAV BELOV	{"phone": "+70625665629"}
0005435263638	472193	9967 536770	ELENA ZAKHAROVA	{"phone": "+70195793305"}
0005435263639	A5F4AB	9225 192504	DARYA KULIKOVA	{"email": "d-kulikova.041974@postgrespro.ru", "phone": "+70201805811"}
0005435263640	9DB83C	0397 483021	ANDREY SEMENOV	{"email": "a.semenov-04091969@postgrespro.ru", "phone": "+70204744513"}
0005435263752	2F7BB0	0195 814880	MAKSIM AFANASEV	{"phone": "+70843830028"}
0005435263641	9DB83C	6216 839130	YURIY DENISOV	{"email": "denisovyuriy-1973@postgrespro.ru", "phone": "+70916957864"}
0005435263642	0612F2	6596 374569	KONSTANTIN MATVEEV	{"phone": "+70011845669"}
0005435263643	EA300F	2081 576377	ANDREY VOLKOV	{"email": "volkov_andrey.091968@postgrespro.ru", "phone": "+70130720399"}
0005435263644	EA300F	1130 933199	ROMAN IVANOV	{"email": "romanivanov-1978@postgrespro.ru", "phone": "+70757228554"}
0005435263645	EA300F	0163 550599	POLINA MAKSIMOVA	{"phone": "+70563527114"}
0005435263646	06A31A	3896 487985	MARIYA SEMENOVA	{"phone": "+70708151813"}
0005435263647	E9DB41	1312 703455	NINA ANDREEVA	{"email": "andreevanina-22091969@postgrespro.ru", "phone": "+70775700128"}
0005435263648	E88D1B	5006 515637	SVETLANA SEMENOVA	{"phone": "+70704818127"}
0005435263649	166F30	1815 262904	SVETLANA TIKHONOVA	{"phone": "+70694691305"}
0005435263650	61CC66	8925 804439	VERONIKA KULIKOVA	{"email": "kulikova_veronika-10071965@postgrespro.ru", "phone": "+70918337849"}
0005435263651	61CC66	1636 875617	KSENIYA POPOVA	{"email": "popovak.081965@postgrespro.ru", "phone": "+70644068365"}
0005435263652	1384AB	5534 382100	VIKTORIYA KUZMINA	{"phone": "+70481252223"}
0005435263653	A8B6C7	4071 579492	VIKTOR MELNIKOV	{"phone": "+70458230946"}
0005435263654	A8B6C7	8319 495954	ANNA OVCHINNIKOVA	{"email": "ovchinnikova.anna_031960@postgrespro.ru", "phone": "+70660910602"}
0005435263655	E6EE85	9565 947783	ANNA MAKSIMOVA	{"phone": "+70483765681"}
0005435263656	E6EE85	1936 724815	NATALYA ROMANOVA	{"phone": "+70621874589"}
0005435263657	804FE1	4714 541934	BORIS PETROV	{"phone": "+70065744487"}
0005435263658	804FE1	0604 909320	TARAS KUZMIN	{"email": "kuzmin-taras-19091970@postgrespro.ru", "phone": "+70954873600"}
0005435263659	DA0DF0	0406 151813	NIKOLAY STEPANOV	{"phone": "+70359456597"}
0005435263660	F73DC1	9497 586739	ANATOLIY KUZNECOV	{"email": "kuznecov_a-17041979@postgrespro.ru", "phone": "+70909020404"}
0005435263661	5B3DBF	8211 412040	ALEKSANDR SHEVCHENKO	{"email": "aleksandr-shevchenko021971@postgrespro.ru", "phone": "+70765788221"}
0005435263662	872340	5464 580729	ALEKSEY IVANOV	{"phone": "+70726705629"}
0005435263663	872340	7201 787169	ALEKSEY EGOROV	{"email": "aleksey-egorov.04111964@postgrespro.ru", "phone": "+70645644684"}
0005435263665	713F22	0996 823710	ILYA NIKOLAEV	{"email": "nikolaevilya1969@postgrespro.ru", "phone": "+70843846598"}
0005435263666	AED6C7	5003 106977	OKSANA POPOVA	{"email": "o_popova_071981@postgrespro.ru", "phone": "+70474257073"}
0005435263667	CE3F90	4245 780334	LEYLA NAZAROVA	{"phone": "+70311268338"}
0005435263668	DCC445	6073 829775	MARIYA SIDOROVA	{"email": "m-sidorova_15081971@postgrespro.ru", "phone": "+70986984006"}
0005435263669	1FC1B8	1563 972754	ANDREY ANDREEV	{"phone": "+70196925765"}
0005435263670	1FC1B8	0327 346293	NATALIYA PETROVA	{"phone": "+70862701651"}
0005435263671	8A4486	9012 976658	ILYA KOROLEV	{"email": "ilya.korolev.1968@postgrespro.ru", "phone": "+70053028481"}
0005435263672	D71877	3379 597006	VLADISLAV FILIPPOV	{"email": "filippovvladislav_07011973@postgrespro.ru", "phone": "+70283726210"}
0005435263673	D71877	3620 198173	ANTONINA MASLOVA	{"phone": "+70292723334"}
0005435263674	F43FFC	0123 664387	ALEKSEY STEPANOV	{"email": "a_stepanov.1975@postgrespro.ru", "phone": "+70877459404"}
0005435263675	12EDBD	9313 808587	YURIY NAZAROV	{"email": "nazarov-y-101983@postgrespro.ru", "phone": "+70029190236"}
0005435263676	859398	5444 857354	MARIYA NOVIKOVA	{"email": "novikovam021980@postgrespro.ru", "phone": "+70844286163"}
0005435263677	859398	4634 949329	LIDIYA SERGEEVA	{"phone": "+70302426201"}
0005435263678	C275CD	2616 988826	EKATERINA SERGEEVA	{"email": "e-sergeeva.091978@postgrespro.ru", "phone": "+70367968088"}
0005435263679	8B67B8	5514 352678	NATALYA POPOVA	{"email": "natalyapopova121975@postgrespro.ru", "phone": "+70966608901"}
0005435263680	8B67B8	8208 756922	MARIYA EGOROVA	{"phone": "+70118641951"}
0005435263681	B4A99C	2289 302708	GALINA KRASNOVA	{"email": "g.krasnova_1973@postgrespro.ru", "phone": "+70376881328"}
0005435263682	CFA1B6	5853 861928	VASILIY BONDARENKO	{"email": "bondarenko_vasiliy.18021980@postgrespro.ru", "phone": "+70542156985"}
0005435263683	CFA1B6	9054 653741	EVGENIY AFANASEV	{"phone": "+70429107131"}
0005435263684	10AEFD	4824 858656	LYUDMILA TIKHONOVA	{"phone": "+70122391871"}
0005435263685	04A5FD	2412 224657	ROMAN ABRAMOV	{"email": "abramov-r09071962@postgrespro.ru", "phone": "+70546039177"}
0005435263686	A8E0D0	6946 988599	VALERIYA POLYAKOVA	{"email": "valeriya.polyakova_1970@postgrespro.ru", "phone": "+70581870447"}
0005435263687	A8E0D0	9329 704867	OLGA BORISOVA	{"phone": "+70860904752"}
0005435263688	644D70	3484 447026	YULIYA KOZLOVA	{"phone": "+70402958269"}
0005435263689	361890	4895 091440	ANTON MARTYNOV	{"email": "martynov_a-03101981@postgrespro.ru", "phone": "+70910976091"}
0005435263690	B998C1	5276 695118	MAKSIM TARASOV	{"phone": "+70677416114"}
0005435263691	ED35EF	5798 444815	IRINA SIDOROVA	{"phone": "+70841364535"}
0005435263692	FDB2F8	1258 643370	TAISIYA FILIPPOVA	{"phone": "+70936498220"}
0005435263693	590FD6	1461 069649	DARYA TIKHONOVA	{"phone": "+70549318448"}
0005435263694	7D5EC0	1922 859448	ALEKSEY SCHERBAKOV	{"email": "scherbakov_a061973@postgrespro.ru", "phone": "+70275473912"}
0005435263695	022D04	5287 819940	ELENA OSIPOVA	{"phone": "+70665812973"}
0005435263696	7DBBE1	0620 875906	ANASTASIYA KOROLEVA	{"phone": "+70821287235"}
0005435263697	967A5F	4509 271502	MARIYA MELNIKOVA	{"email": "m.melnikova-06011978@postgrespro.ru", "phone": "+70729561736"}
0005435263698	31A2E9	2917 746843	EGOR KISELEV	{"email": "e-kiselev121962@postgrespro.ru", "phone": "+70318921465"}
0005435263699	31A2E9	8780 522635	STANISLAV KUZNECOV	{"email": "kuznecov_stanislav_121966@postgrespro.ru", "phone": "+70078216081"}
0005435263700	650FFC	6336 334380	NIKOLAY NIKOLAEV	{"email": "nikolay_nikolaev_1973@postgrespro.ru", "phone": "+70049620442"}
0005435263701	27D212	0902 814228	LARISA ZHUKOVA	{"email": "lzhukova.101974@postgrespro.ru", "phone": "+70933013724"}
0005435263702	01968B	0461 794608	DILYARA FADEEVA	{"email": "fadeeva.dilyara.081967@postgrespro.ru", "phone": "+70160502708"}
0005435263703	01968B	2806 595577	ANGELINA IVANOVA	{"email": "ivanovaangelina121977@postgrespro.ru", "phone": "+70500124670"}
0005435263704	DC1EB0	4566 349777	GLEB BORISOV	{"email": "glebborisov_20011974@postgrespro.ru", "phone": "+70960901185"}
0005435263705	C84749	5773 695036	DMITRIY IVANOV	{"email": "ivanov.d_061974@postgrespro.ru", "phone": "+70868854259"}
0005435263706	C84749	6941 095674	SERGEY PAVLOV	{"email": "pavlov_s.1964@postgrespro.ru", "phone": "+70855748695"}
0005435263707	49C0B8	5201 366701	NATALYA SEMENOVA	{"phone": "+70487522524"}
0005435263708	E5C50D	0614 276611	SVETLANA BELYAEVA	{"email": "sbelyaeva1965@postgrespro.ru", "phone": "+70591973740"}
0005435263709	CED999	0466 427704	MAKSIM GUSEV	{"email": "gusevm1974@postgrespro.ru", "phone": "+70624856041"}
0005435263710	23D8EA	5751 990709	ALEKSANDR KUZMIN	{"phone": "+70850373750"}
0005435263711	604931	3732 117994	DAMIR MARTYNOV	{"phone": "+70848601806"}
0005435263712	D36EA8	5749 958973	SERGEY IVANOV	{"email": "ivanov_sergey.031983@postgrespro.ru", "phone": "+70861722270"}
0005435263713	D36EA8	2093 082144	DMITRIY IVANOV	{"email": "d.ivanov.17021976@postgrespro.ru", "phone": "+70437715695"}
0005435263714	7E52CD	4649 748358	VERONIKA ORLOVA	{"phone": "+70179411347"}
0005435263715	7E52CD	2048 440019	YULIYA ZAYCEVA	{"email": "yzayceva_021972@postgrespro.ru", "phone": "+70441361931"}
0005435263716	8CCD19	7040 232654	GALINA NOVIKOVA	{"email": "novikova.galina-22031977@postgrespro.ru", "phone": "+70938319237"}
0005435263717	303350	4011 265197	ALEKSANDR IVANOV	{"email": "aivanov-10011977@postgrespro.ru", "phone": "+70692023427"}
0005435263718	303350	5733 278395	ALEKSANDR KOROLEV	{"phone": "+70761442774"}
0005435263719	BE0B12	6910 583449	NATALYA MIKHAYLOVA	{"phone": "+70669519454"}
0005435263720	90AE5C	1349 178657	DINARA MARTYNOVA	{"email": "martynova_dinara_121974@postgrespro.ru", "phone": "+70413739953"}
0005435263721	90AE5C	3071 716305	ANATOLIY ALEKSEEV	{"phone": "+70077956899"}
0005435263722	955DFA	0531 312081	KSENIYA ERMAKOVA	{"email": "ermakova_kseniya_1975@postgrespro.ru", "phone": "+70125348046"}
0005435263723	A0DECA	9657 718272	DARYA TROFIMOVA	{"email": "d_trofimova_1957@postgrespro.ru", "phone": "+70889449569"}
0005435263724	ED5F0B	7808 997222	NIKOLAY GAVRILOV	{"phone": "+70947678396"}
0005435263725	157825	4182 384316	SERGEY PAVLOV	{"phone": "+70065743423"}
0005435263726	2A9E2F	7786 247921	ANATOLIY IVANOV	{"email": "anatoliy-ivanov.03071978@postgrespro.ru", "phone": "+70118864211"}
0005435263727	B40B9F	5722 864764	NATALYA NAUMOVA	{"email": "n-naumova07011962@postgrespro.ru", "phone": "+70335163393"}
0005435263728	B40B9F	4898 338794	ANDREY NIKITIN	{"email": "nikitinandrey09121975@postgrespro.ru", "phone": "+70566742704"}
0005435263729	D7AF2A	7178 624659	KIRILL VASILEV	{"email": "vasilev-k.27041967@postgrespro.ru", "phone": "+70247049665"}
0005435263730	D7AF2A	4264 511257	ALEKSEY BARANOV	{"phone": "+70581887134"}
0005435263731	77E60F	0512 995360	ELENA BELOVA	{"email": "belova-e-09031965@postgrespro.ru", "phone": "+70268733065"}
0005435263732	560980	4663 832016	NATALYA ANDREEVA	{"phone": "+70747139264"}
0005435263733	560980	2010 628829	SHAMIL KULIKOV	{"email": "kulikov_shamil121972@postgrespro.ru", "phone": "+70093411661"}
0005435263734	B6502B	2573 688427	SVETLANA ZAYCEVA	{"phone": "+70471572280"}
0005435263735	47E5FF	1732 835914	TATYANA NAUMOVA	{"phone": "+70527875270"}
0005435263736	47E5FF	1917 773726	RUSLAN ZHUKOV	{"email": "zhukov-r-1972@postgrespro.ru", "phone": "+70187156220"}
0005435263737	60A361	3417 837922	YULIYA PAVLOVA	{"phone": "+70570566294"}
0005435263738	60A361	2340 207008	NIKOLAY SAVELEV	{"phone": "+70691757324"}
0005435263739	0DCF27	1503 840652	ANNA BOGDANOVA	{"phone": "+70565204164"}
0005435263740	0DCF27	7136 106867	VLADIMIR BORISOV	{"email": "v-borisov_051967@postgrespro.ru", "phone": "+70763157833"}
0005435263741	509379	8620 733768	TATYANA DMITRIEVA	{"phone": "+70722914972"}
0005435263742	646336	5274 069933	NADEZHDA KOZLOVA	{"email": "n_kozlova.051976@postgrespro.ru", "phone": "+70413523757"}
0005435263743	01E168	2326 461421	LYUBOV TARASOVA	{"phone": "+70168125337"}
0005435263744	01E168	0770 673952	VASILIY FROLOV	{"phone": "+70884103956"}
0005435263745	01E168	0415 203885	EVGENIY MOISEEV	{"phone": "+70677711987"}
0005435263746	755722	4511 406221	VLADIMIR FROLOV	{"phone": "+70179471327"}
0005435263747	792AAD	0511 414898	SERGEY STEPANOV	{"email": "s-stepanov_121969@postgrespro.ru", "phone": "+70337216563"}
0005435263748	792AAD	9403 418905	SVETLANA MIKHAYLOVA	{"email": "svetlanamikhaylova-07031970@postgrespro.ru", "phone": "+70752365296"}
0005435263749	792AAD	7101 063154	ALEVTINA IVANOVA	{"email": "alevtina-ivanova.01011975@postgrespro.ru", "phone": "+70014059073"}
0005435263750	8F4B26	3905 277797	NATALYA IVANOVA	{"email": "n-ivanova_081963@postgrespro.ru", "phone": "+70267387189"}
0005435263751	8F4B26	3083 365932	DIANA BARANOVA	{"phone": "+70429028813"}
0005435263753	2F7BB0	1703 771623	GEORGIY FOMIN	{"email": "g_fomin_011977@postgrespro.ru", "phone": "+70164239596"}
0005435263754	963BA6	7541 625172	ELENA NIKITINA	{"email": "elenanikitina-1969@postgrespro.ru", "phone": "+70009423710"}
0005435263755	FDCD81	1879 181098	NIKOLAY ANTONOV	{"email": "antonov.nikolay_1962@postgrespro.ru", "phone": "+70258475958"}
0005435263756	8837E5	2242 395850	ALEKSANDRA SOKOLOVA	{"email": "a_sokolova.011974@postgrespro.ru", "phone": "+70090136194"}
0005435263757	1CBDA3	8973 602077	ALEKSANDR KONOVALOV	{"email": "konovalov_a20111972@postgrespro.ru", "phone": "+70003605141"}
0005435263758	C88E81	9948 926526	OLGA BOGDANOVA	{"phone": "+70729100760"}
0005435263759	C88E81	3114 493417	STEPAN VASILEV	{"email": "stepan.vasilev1969@postgrespro.ru", "phone": "+70315329803"}
0005435263760	4A6D32	0529 975601	SERGEY SHEVCHENKO	{"email": "shevchenko.sergey23051976@postgrespro.ru", "phone": "+70986122632"}
0005435263761	4A6D32	9119 671052	DANILA ABRAMOV	{"phone": "+70628397921"}
0005435263762	4A6D32	9699 512190	RAISA NIKITINA	{"phone": "+70699729695"}
0005435263763	F9EAFA	2456 430680	NELLYA KOZLOVA	{"email": "kozlova-nellya-1961@postgrespro.ru", "phone": "+70429280816"}
0005435263764	F9EAFA	2452 067564	ANDREY GUSEV	{"email": "a.gusev18111963@postgrespro.ru", "phone": "+70555441455"}
0005435263765	53C585	5766 854007	NATALYA MELNIKOVA	{"phone": "+70885042260"}
0005435263766	49BCE9	3290 176689	TIMUR ANDREEV	{"email": "andreev.t-28021983@postgrespro.ru", "phone": "+70324257493"}
0005435263767	E73B7E	4839 603628	ANATOLIY SMIRNOV	{"phone": "+70048391428"}
0005435263768	B67E9E	5212 520344	KIRA BARANOVA	{"email": "kira.baranova_30031968@postgrespro.ru", "phone": "+70097573633"}
0005435263769	B67E9E	9787 489035	VLADIMIR MIKHAYLOV	{"email": "vladimir.mikhaylov-1972@postgrespro.ru", "phone": "+70804789909"}
0005435263770	A1667D	4796 675592	ALEKSANDR IVANOV	{"phone": "+70986605065"}
0005435263771	59E853	4427 888616	ANNA KUZNECOVA	{"phone": "+70903441331"}
0005435263772	E8FA89	7484 497167	NATALYA KULIKOVA	{"phone": "+70350085713"}
0005435263773	E8FA89	0560 163504	ALENA KONOVALOVA	{"phone": "+70076325881"}
0005435263774	82DCBC	2820 884944	ARTEM DMITRIEV	{"phone": "+70056784994"}
0005435263775	CAA2E0	0862 916788	KRISTINA SOROKINA	{"phone": "+70468877960"}
0005435263776	6D91B1	5658 034418	OLGA KULIKOVA	{"email": "kulikova_olga_18041982@postgrespro.ru", "phone": "+70869183338"}
0005435263777	321D2C	6270 535542	VALERIY SOKOLOV	{"email": "sokolov.v_1959@postgrespro.ru", "phone": "+70948281471"}
0005435263778	224935	7226 074544	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr_1987@postgrespro.ru", "phone": "+70885092178"}
0005435263779	224935	1352 469153	NADEZHDA MATVEEVA	{"email": "n_matveeva_121976@postgrespro.ru", "phone": "+70843863416"}
0005435263780	8C47D9	6358 812249	GALINA FILATOVA	{"phone": "+70084974590"}
0005435263781	8C47D9	4726 032115	RAISA BELOVA	{"email": "r-belova_27091967@postgrespro.ru", "phone": "+70679223250"}
0005435263782	9810EF	1706 305941	ANTONINA IVANOVA	{"phone": "+70908613737"}
0005435263783	9810EF	4847 616617	ALEKSANDR GERASIMOV	{"phone": "+70541275724"}
0005435263784	9810EF	1877 544049	MARIYA ISAEVA	{"email": "isaevam.1968@postgrespro.ru", "phone": "+70203565758"}
0005435263785	66C00A	9217 685270	MARIYA IVANOVA	{"phone": "+70475490757"}
0005435263786	9EFA4F	2267 955719	ELZA NOVIKOVA	{"phone": "+70683304249"}
0005435263787	3242A2	1973 722444	GALINA NIKITINA	{"email": "galinanikitina1981@postgrespro.ru", "phone": "+70948514178"}
0005435263788	D33B95	8868 840204	KIRILL PETROV	{"phone": "+70223271901"}
0005435263789	D33B95	9835 492476	DENIS KOZLOV	{"email": "kozlov_d_011961@postgrespro.ru", "phone": "+70771120630"}
0005435263790	29C25D	6196 459255	SVETLANA FROLOVA	{"email": "frolova-svetlana-1971@postgrespro.ru", "phone": "+70610096591"}
0005435263791	0B7D49	7372 968037	LYUDMILA VASILEVA	{"phone": "+70676151763"}
0005435263792	0B7D49	7744 471554	LEV ORLOV	{"email": "levorlov_24101965@postgrespro.ru", "phone": "+70734335625"}
0005435263793	995192	2010 631530	ALEKSANDR STEPANOV	{"phone": "+70761009651"}
0005435263794	188E50	8918 378770	DAVID VASILEV	{"phone": "+70289170899"}
0005435263795	4D8D04	7413 146728	YULIYA KUZNECOVA	{"email": "yuliya_kuznecova1976@postgrespro.ru", "phone": "+70218898538"}
0005435263796	072B56	1831 195775	ALEKSANDR PAVLOV	{"email": "pavlov-aleksandr.18011971@postgrespro.ru", "phone": "+70458116346"}
0005435263797	F1CBCF	9056 451931	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr011962@postgrespro.ru", "phone": "+70526931890"}
0005435263798	E9C5BB	4825 035800	GALINA VLASOVA	{"email": "vlasovagalina_1975@postgrespro.ru", "phone": "+70198208888"}
0005435263799	E9C5BB	6568 710406	VIKTOR GERASIMOV	{"email": "viktor-gerasimov_09071969@postgrespro.ru", "phone": "+70484103561"}
0005435263800	0E9568	5051 216077	LYUBOV TROFIMOVA	{"email": "l.trofimova_041973@postgrespro.ru", "phone": "+70011501825"}
0005435263801	F9B22B	2133 009338	SERGEY IVANOV	{"phone": "+70786841798"}
0005435263802	805D79	5691 423860	DMITRIY KULIKOV	{"phone": "+70091441264"}
0005435263803	8642BC	5240 634528	GEORGIY STEPANOV	{"phone": "+70289903336"}
0005435263804	AA9C77	8884 082190	IVAN GERASIMOV	{"phone": "+70862015989"}
0005435263805	9A5519	7921 360166	GULFIYA MIKHAYLOVA	{"email": "g.mikhaylova_03101973@postgrespro.ru", "phone": "+70791092717"}
0005435263806	76CB11	1997 774572	KONSTANTIN MAKAROV	{"email": "konstantin_makarov_011963@postgrespro.ru", "phone": "+70877915797"}
0005435263807	76CB11	6230 186084	STANISLAV SIDOROV	{"phone": "+70398843292"}
0005435263808	E29A5C	6579 173625	LILIYA GORBUNOVA	{"phone": "+70177436209"}
0005435263809	51596B	4684 288645	ALEKSEY ZAKHAROV	{"email": "azakharov-18071969@postgrespro.ru", "phone": "+70881293438"}
0005435263810	51596B	9996 301798	STEPAN SIDOROV	{"phone": "+70122126961"}
0005435263811	51596B	7046 646113	DIANA SERGEEVA	{"phone": "+70966080493"}
0005435263812	8D385B	7229 804311	TATYANA NIKOLAEVA	{"phone": "+70881923157"}
0005435263813	9C3F79	5071 985845	MARIYA ORLOVA	{"email": "orlovamariya.081954@postgrespro.ru", "phone": "+70987323364"}
0005435263814	F4C780	4014 884908	MIKHAIL OSIPOV	{"email": "m-osipov111980@postgrespro.ru", "phone": "+70068970459"}
0005435263815	F4C780	1642 700864	EGOR MATVEEV	{"phone": "+70666252499"}
0005435263816	95CFC2	2579 824953	ALEVTINA VOROBEVA	{"email": "vorobevaalevtina-101978@postgrespro.ru", "phone": "+70281685007"}
0005435263817	84A8DA	5746 649124	OLGA VOROBEVA	{"phone": "+70716909774"}
0005435263818	C665CA	2322 297885	ELENA TITOVA	{"email": "titova-e-15101978@postgrespro.ru", "phone": "+70904919796"}
0005435263819	8879CC	2549 463989	OLGA SOKOLOVA	{"phone": "+70071121424"}
0005435263820	F92A36	1437 913856	GENNADIY ZAKHAROV	{"email": "zakharov.g_1979@postgrespro.ru", "phone": "+70479650974"}
0005435263821	09F6C8	8235 018768	VALENTIN IVANOV	{"phone": "+70424108374"}
0005435263822	108E29	1231 960263	ALEKSANDR POPOV	{"email": "popov_aleksandr_09041979@postgrespro.ru", "phone": "+70135854908"}
0005435263823	0AEC6B	7573 989630	ALEKSEY KUZNECOV	{"phone": "+70971318086"}
0005435263824	E6BCC9	2977 667895	DMITRIY MATVEEV	{"email": "matveev.dmitriy.1962@postgrespro.ru", "phone": "+70701936967"}
0005435263825	AE60BC	9218 910569	ALEKSANDR IVANOV	{"email": "aivanov.101968@postgrespro.ru", "phone": "+70355576643"}
0005435263826	AE60BC	1081 606721	MARIYA POPOVA	{"email": "mariya-popova_051979@postgrespro.ru", "phone": "+70303148065"}
0005435263827	21E864	8097 635997	KONSTANTIN KUZNECOV	{"email": "kuznecov_k-06111979@postgrespro.ru", "phone": "+70754204718"}
0005435263828	869689	1184 549959	VLADIMIR NIKOLAEV	{"email": "nikolaevvladimir1972@postgrespro.ru", "phone": "+70557675604"}
0005435263829	869689	5075 746759	NIKOLAY BARANOV	{"phone": "+70933956288"}
0005435263830	20EB14	5423 130690	NIKITA POPOV	{"email": "nikita.popov_1969@postgrespro.ru", "phone": "+70186714017"}
0005435263831	20EB14	4415 070940	ELVIRA ANTONOVA	{"phone": "+70088559390"}
0005435263832	89CECB	9243 462941	LEV NIKOLAEV	{"email": "nikolaevlev_1973@postgrespro.ru", "phone": "+70923746841"}
0005435263833	89CECB	2071 836900	ELENA OVCHINNIKOVA	{"email": "ovchinnikovaelena.091978@postgrespro.ru", "phone": "+70696734595"}
0005435263834	438283	0845 682800	TATYANA KUZMINA	{"phone": "+70759021607"}
0005435263835	F6080A	5308 243793	ELENA VASILEVA	{"email": "vasileva_e_20081977@postgrespro.ru", "phone": "+70786117355"}
0005435263836	7D9DAF	4986 126439	SVETLANA SOROKINA	{"email": "s_sorokina-07071979@postgrespro.ru", "phone": "+70044633432"}
0005435263837	7D9DAF	4667 621535	SERGEY BORISOV	{"email": "borisovsergey_1958@postgrespro.ru", "phone": "+70840587816"}
0005435263838	0EAA2F	1146 925739	RAISA SCHERBAKOVA	{"email": "r_scherbakova08061987@postgrespro.ru", "phone": "+70133422260"}
0005435263839	0EAA2F	6758 328051	OLGA ROMANOVA	{"phone": "+70008363178"}
0005435263840	6D39D2	2847 532279	PAVEL BARANOV	{"email": "p_baranov011965@postgrespro.ru", "phone": "+70282968806"}
0005435266074	202839	0467 901993	MARIYA KOZLOVA	{"email": "m.kozlova_1971@postgrespro.ru", "phone": "+70638346199"}
0005435266075	9C1AEA	8941 814526	DARYA SERGEEVA	{"phone": "+70061219493"}
0005435266076	4E5648	9859 634323	NIKOLAY OSIPOV	{"email": "nikolay_osipov_1968@postgrespro.ru", "phone": "+70846922365"}
0005435266077	4E5648	1767 432110	ALEKSANDR KUZNECOV	{"phone": "+70771260315"}
0005435266078	6D09A4	4814 411375	ALEKSANDRA ALEKSANDROVA	{"email": "aleksandra_aleksandrova_29061964@postgrespro.ru", "phone": "+70743570652"}
0005435266079	32FB17	9306 347528	DARYA IVANOVA	{"email": "daryaivanova-1972@postgrespro.ru", "phone": "+70428364993"}
0005435266080	587065	4106 450526	GALINA IVANOVA	{"email": "galina_ivanova-1972@postgrespro.ru", "phone": "+70451104073"}
0005435266081	217CE0	3544 905449	VIKTORIYA ORLOVA	{"email": "orlovav1978@postgrespro.ru", "phone": "+70388206808"}
0005435266082	F93977	9371 868872	TATYANA ISAEVA	{"phone": "+70729751390"}
0005435266083	F93977	7891 064466	MARIYA GORBUNOVA	{"phone": "+70039796340"}
0005435266084	F93977	9094 904606	ELENA YUDINA	{"email": "elena.yudina.03061976@postgrespro.ru", "phone": "+70071103353"}
0005435266085	F337EC	7355 254585	KLARA VLASOVA	{"phone": "+70241033235"}
0005435266086	7AD36A	2145 272170	ANTON VOROBEV	{"phone": "+70500707356"}
0005435266087	7AD36A	7709 753036	ALLA GERASIMOVA	{"phone": "+70948689971"}
0005435266088	6C6E99	2354 567223	ANASTASIYA MIKHAYLOVA	{"email": "anastasiyamikhaylova.07071977@postgrespro.ru", "phone": "+70405377848"}
0005435266089	CD64B0	3962 759387	DARYA NOVIKOVA	{"email": "darya_novikova.011967@postgrespro.ru", "phone": "+70001191674"}
0005435266090	8CD2C3	2567 716855	VALERIY VOLKOV	{"phone": "+70487664161"}
0005435266091	8CD2C3	7854 922061	ARTEMIY BELOV	{"email": "a_belov_111961@postgrespro.ru", "phone": "+70861813853"}
0005435266092	A86391	5172 000739	VIKTORIYA MOISEEVA	{"email": "moiseeva.viktoriya_111975@postgrespro.ru", "phone": "+70162561169"}
0005435266093	91B2DC	7317 896972	ALEKSEY NOVIKOV	{"phone": "+70115566706"}
0005435266094	A3206D	1677 522472	SVETLANA POTAPOVA	{"email": "s_potapova_30091981@postgrespro.ru", "phone": "+70094474781"}
0005435266095	DED13A	1479 019866	ELENA NOVIKOVA	{"phone": "+70366396936"}
0005435266096	5D4D52	3360 775333	IVAN FEDOTOV	{"email": "fedotov-i-23051959@postgrespro.ru", "phone": "+70365932912"}
0005435266097	385601	0155 936004	LIDIYA MAKAROVA	{"phone": "+70768467954"}
0005435266098	77B37F	4557 626933	NATALYA AFANASEVA	{"email": "nafanaseva071977@postgrespro.ru", "phone": "+70734837446"}
0005435266099	029C1A	8832 112766	ANDREY PETROV	{"email": "andrey.petrov-1966@postgrespro.ru", "phone": "+70039766494"}
0005435266100	029C1A	6691 112980	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-071962@postgrespro.ru", "phone": "+70603839943"}
0005435266101	327A5B	1058 906071	DARYA KARPOVA	{"phone": "+70760178344"}
0005435266102	93356C	3849 841583	NADEZHDA DAVYDOVA	{"email": "ndavydova14111976@postgrespro.ru", "phone": "+70161268953"}
0005435266103	A27DF2	0608 370879	ALEKSANDRA NIKOLAEVA	{"email": "a-nikolaeva.111971@postgrespro.ru", "phone": "+70147426145"}
0005435266104	A27DF2	6700 309068	LYUBOV DENISOVA	{"phone": "+70925139594"}
0005435266105	AC1535	4996 847060	ARTEM MOISEEV	{"email": "artem-moiseev_1964@postgrespro.ru", "phone": "+70810217852"}
0005435266106	7F6F3D	4427 675996	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov.01121971@postgrespro.ru", "phone": "+70231834128"}
0005435266107	7F6F3D	9204 654519	ANNA POPOVA	{"phone": "+70628506374"}
0005435266108	7F6F3D	3382 453363	EGOR MEDVEDEV	{"email": "medvedev-e.1965@postgrespro.ru", "phone": "+70013587923"}
0005435266109	8D8DC4	1076 587654	MIKHAIL SERGEEV	{"email": "sergeevmikhail-13021971@postgrespro.ru", "phone": "+70657906824"}
0005435266110	C14F95	5359 857232	LIDIYA NOVIKOVA	{"phone": "+70769411276"}
0005435266111	6EB0A2	2633 693799	NADEZHDA OSIPOVA	{"email": "nosipova1979@postgrespro.ru", "phone": "+70580821043"}
0005435266112	66539A	1773 885712	SERGEY ANTONOV	{"email": "sergey_antonov071970@postgrespro.ru", "phone": "+70561528691"}
0005435266113	5403C3	6900 252148	ALEKSANDR NIKITIN	{"email": "nikitin_a_08061964@postgrespro.ru", "phone": "+70984879544"}
0005435266114	5403C3	5407 269085	MAKSIM TARASOV	{"phone": "+70099247959"}
0005435266115	5403C3	1873 200429	TATYANA VLASOVA	{"email": "vlasova-t_18051969@postgrespro.ru", "phone": "+70594795064"}
0005435266116	5C8A56	7213 682299	IGOR KAZAKOV	{"phone": "+70299847391"}
0005435266117	B88850	6229 824219	NINA DANILOVA	{"phone": "+70419149511"}
0005435266118	A0C7E8	6282 757895	SERGEY SEMENOV	{"email": "ssemenov-011965@postgrespro.ru", "phone": "+70505465913"}
0005435266119	A7128B	5028 968530	ANDREY MOISEEV	{"email": "moiseev-andrey-121959@postgrespro.ru", "phone": "+70749148073"}
0005435266120	A7128B	0003 728339	TATYANA FILIPPOVA	{"phone": "+70223143694"}
0005435266121	7FB2B8	0774 036205	MIKHAIL ZHUKOV	{"phone": "+70709419100"}
0005435266122	CF9C44	9522 789276	VLADISLAV SEMENOV	{"email": "vladislav.semenov-1965@postgrespro.ru", "phone": "+70307647790"}
0005435266123	CF9C44	3078 775921	MIKHAIL KUZNECOV	{"phone": "+70988272851"}
0005435266124	B3B09C	7087 223629	EKATERINA YAKOVLEVA	{"phone": "+70561631615"}
0005435266125	4B25D2	1380 355602	NADEZHDA AFANASEVA	{"email": "afanaseva.n.1969@postgrespro.ru", "phone": "+70220732072"}
0005435266126	4B25D2	1809 533220	ANNA BORISOVA	{"phone": "+70329495128"}
0005435266127	C71231	8578 035878	ANATOLIY ILIN	{"phone": "+70938790670"}
0005435266128	44426F	4170 833669	LIDIYA NOVIKOVA	{"phone": "+70554922656"}
0005435266129	44426F	5409 235072	SVETLANA SOROKINA	{"email": "sorokina-s011972@postgrespro.ru", "phone": "+70050317280"}
0005435266130	C7F766	8309 899415	OLGA MELNIKOVA	{"phone": "+70520290108"}
0005435266131	BE96B8	3449 624543	SERGEY GORBUNOV	{"email": "s-gorbunov01051977@postgrespro.ru", "phone": "+70275163771"}
0005435266132	663E28	3257 150314	EVGENIYA OSIPOVA	{"email": "osipova-e-19091975@postgrespro.ru", "phone": "+70584070154"}
0005435266133	663E28	4362 039901	LYUDMILA NIKOLAEVA	{"phone": "+70819131326"}
0005435266134	62C164	0633 077639	NATALYA VASILEVA	{"phone": "+70608421653"}
0005435266135	62C164	4602 989885	ANATOLIY SEMENOV	{"phone": "+70552295258"}
0005435266136	B3A74E	1468 842241	NATALYA ZOTOVA	{"phone": "+70992496761"}
0005435266137	957C9A	7999 332528	LYUDMILA KUZNECOVA	{"email": "l.kuznecova-121966@postgrespro.ru", "phone": "+70261570231"}
0005435266138	957C9A	6401 023749	OLGA SAVELEVA	{"phone": "+70948582785"}
0005435266139	52ECE7	0277 679316	ALEKSANDR MAKAROV	{"phone": "+70283355992"}
0005435266140	F7831A	3179 173955	INNA POPOVA	{"email": "popova.inna_061975@postgrespro.ru", "phone": "+70812871025"}
0005435266141	C14221	9118 140756	ALEKSEY FROLOV	{"phone": "+70805629312"}
0005435266142	9AC99E	3652 373073	EVGENIY ALEKSANDROV	{"phone": "+70368206644"}
0005435266143	A84D28	8848 575443	MARIYA KOROLEVA	{"email": "mariyakoroleva_24041960@postgrespro.ru", "phone": "+70917793906"}
0005435266144	355B43	1852 020389	EGOR STEPANOV	{"email": "stepanov.e-12081958@postgrespro.ru", "phone": "+70936971662"}
0005435266145	355B43	9134 852285	VARVARA VASILEVA	{"email": "vasileva-v_111969@postgrespro.ru", "phone": "+70588690832"}
0005435266146	86E13A	5040 226798	LARISA DAVYDOVA	{"email": "larisadavydova.1970@postgrespro.ru", "phone": "+70164134289"}
0005435266147	ADBDAB	7068 679823	BOGDAN PETROV	{"phone": "+70159088741"}
0005435266148	D172CF	9039 080464	ANNA MIRONOVA	{"email": "a_mironova061975@postgrespro.ru", "phone": "+70576955586"}
0005435266149	EFF87D	5660 035345	VALERIYA BELOVA	{"phone": "+70262375336"}
0005435266150	12363F	1292 822159	NATALIYA VASILEVA	{"email": "vasileva-n-021981@postgrespro.ru", "phone": "+70722168673"}
0005435266151	50493B	5855 354269	TATYANA ANTONOVA	{"email": "antonova.tatyana041974@postgrespro.ru", "phone": "+70988018893"}
0005435266152	70A991	1612 257472	SVETLANA FOMINA	{"email": "svetlana.fomina01101961@postgrespro.ru", "phone": "+70518420137"}
0005435266153	E52904	8240 722693	MARINA DMITRIEVA	{"email": "dmitrieva-marina16051968@postgrespro.ru", "phone": "+70809182993"}
0005435266154	1CFE6F	5075 415806	PETR BORISOV	{"email": "borisov-p.1973@postgrespro.ru", "phone": "+70256629835"}
0005435266155	7E064F	3508 392326	ARINA RODIONOVA	{"phone": "+70087909549"}
0005435266156	7E064F	9781 378088	ALEKSANDR SERGEEV	{"email": "a_sergeev.041971@postgrespro.ru", "phone": "+70454765875"}
0005435266157	67B072	2393 049149	LIDIYA MAKSIMOVA	{"phone": "+70843460451"}
0005435266158	CA12CE	8357 649595	OLGA NAZAROVA	{"phone": "+70851377400"}
0005435266159	BB3A74	4813 429867	VALERIY CHERNOV	{"email": "vchernov.06081968@postgrespro.ru", "phone": "+70023300813"}
0005435266160	BB3A74	5349 901051	NINA KULIKOVA	{"email": "kulikova-nina_031973@postgrespro.ru", "phone": "+70699346029"}
0005435266161	20D6D6	0558 301480	ALEKSANDR FROLOV	{"phone": "+70004794594"}
0005435266162	59F2C1	7335 893550	MARIYA MEDVEDEVA	{"email": "mariya-medvedeva.051976@postgrespro.ru", "phone": "+70498705805"}
0005435266163	59F2C1	9535 359986	GALINA KOROLEVA	{"phone": "+70681368647"}
0005435266164	5FF64F	7350 393068	DMITRIY BORISOV	{"email": "borisov-dmitriy.15021974@postgrespro.ru", "phone": "+70243089517"}
0005435266165	96668D	6449 556410	ALEKSEY MARTYNOV	{"email": "martynov.a_1976@postgrespro.ru", "phone": "+70190908128"}
0005435266166	E362A8	1732 941899	ANTON KOZLOV	{"email": "kozlov.anton1979@postgrespro.ru", "phone": "+70039006071"}
0005435266167	121ECD	7000 620079	SERGEY SHEVCHENKO	{"email": "sergey-shevchenko1967@postgrespro.ru", "phone": "+70845286522"}
0005435266168	203779	0003 242753	ANNA MASLOVA	{"email": "maslovaa_121977@postgrespro.ru", "phone": "+70327119334"}
0005435266169	9FF40A	0565 787708	IVAN ZAYCEV	{"email": "i-zaycev091977@postgrespro.ru", "phone": "+70082588069"}
0005435266170	9FF40A	6032 380886	LIDIYA MAKAROVA	{"phone": "+70386440802"}
0005435266171	C9FF08	5272 742334	ALEKSANDR PETROV	{"phone": "+70796546295"}
0005435266172	C9FF08	0729 912873	NIKITA CHERNOV	{"phone": "+70618453726"}
0005435266173	D5DD28	9962 590883	LIDIYA ALEKSEEVA	{"phone": "+70709202132"}
0005435266174	D5DD28	9301 011480	TATYANA MARTYNOVA	{"phone": "+70945083121"}
0005435266175	E8182C	3954 226855	VALERIY NOVIKOV	{"phone": "+70159932564"}
0005435266176	1CE62D	4909 185634	VLADIMIR POPOV	{"phone": "+70887526469"}
0005435266177	E933DA	7585 764692	MARINA IVANOVA	{"phone": "+70429035139"}
0005435266178	8ECE2C	8462 611945	VADIM MOROZOV	{"email": "morozov-v_081972@postgrespro.ru", "phone": "+70950357748"}
0005435266179	8ECE2C	7082 380408	KLAVDIYA KISELEVA	{"phone": "+70385399366"}
0005435266180	CF89CD	4050 752946	ILYA GUSEV	{"email": "gusev_i.061978@postgrespro.ru", "phone": "+70049231018"}
0005435266181	1325FE	7730 330797	EVGENIY VOROBEV	{"email": "e.vorobev19011969@postgrespro.ru", "phone": "+70012034746"}
0005435266182	325668	5748 912573	LYUDMILA SERGEEVA	{"phone": "+70506055064"}
0005435266183	F40A31	5217 182916	ALEKSANDR IVANOV	{"phone": "+70590278520"}
0005435266184	F40A31	2435 981185	EVGENIY ZAYCEV	{"email": "e-zaycev_31081973@postgrespro.ru", "phone": "+70106725847"}
0005435266185	B86DA4	3424 300316	NIKITA IVANOV	{"email": "ivanov.n.041978@postgrespro.ru", "phone": "+70346674272"}
0005435266186	307BDC	7972 056737	ANAIT FILATOVA	{"phone": "+70811098694"}
0005435266187	5BEE30	0388 269927	VYACHESLAV IVANOV	{"phone": "+70289378759"}
0005435266188	5BEE30	5187 894686	MIKHAIL KUZMIN	{"phone": "+70810819337"}
0005435266189	B319B6	0469 504970	OKSANA IVANOVA	{"phone": "+70410340353"}
0005435266190	A0F82F	9676 741893	ANATOLIY MOROZOV	{"email": "anatoliymorozov_30061965@postgrespro.ru", "phone": "+70594416438"}
0005435266191	A0F82F	3771 681745	VENERA BARANOVA	{"phone": "+70371541491"}
0005435266192	FE9C59	0126 434504	ANASTASIYA SOKOLOVA	{"phone": "+70778547767"}
0005435266193	01F79E	3276 008496	NIKOLAY SEMENOV	{"email": "semenov_nikolay-1979@postgrespro.ru", "phone": "+70162581296"}
0005435266194	1FCD46	5483 543965	DMITRIY NAZAROV	{"phone": "+70110014703"}
0005435266195	E473C6	7853 227413	ZINAIDA SMIRNOVA	{"email": "z-smirnova_08011984@postgrespro.ru", "phone": "+70528719308"}
0005435266196	B8D2C5	3671 238611	DMITRIY MIKHAYLOV	{"phone": "+70518728229"}
0005435266197	B8D2C5	2239 194779	VALERIY POPOV	{"email": "popov-valeriy-10041983@postgrespro.ru", "phone": "+70925173033"}
0005435266198	83DD7E	0838 004315	VALENTINA DMITRIEVA	{"phone": "+70406876935"}
0005435266199	4113FB	8961 076936	NATALYA IVANOVA	{"email": "ivanova.natalya1973@postgrespro.ru", "phone": "+70556960348"}
0005435266200	F434C4	8246 977845	EVGENIY MAKAROV	{"phone": "+70607478186"}
0005435266201	430B0D	8057 595037	DENIS ANDREEV	{"phone": "+70671562942"}
0005435266202	430B0D	1511 936084	OLGA KOLESNIKOVA	{"email": "kolesnikova-o.081978@postgrespro.ru", "phone": "+70822758339"}
0005435266203	430B0D	7005 259141	ALEVTINA BELOVA	{"email": "belova_alevtina.09101984@postgrespro.ru", "phone": "+70283568447"}
0005435266204	B69E78	9409 338621	DIANA STEPANOVA	{"email": "d_stepanova111979@postgrespro.ru", "phone": "+70189068899"}
0005435266205	B69E78	5784 416156	INNA DANILOVA	{"email": "danilova.i.011975@postgrespro.ru", "phone": "+70713642079"}
0005435266206	5D6CDA	9777 483603	VALENTIN KARPOV	{"phone": "+70542993167"}
0005435266207	5D6CDA	0785 136682	NINA POPOVA	{"email": "n-popova_08121973@postgrespro.ru", "phone": "+70954503800"}
0005435266208	542B88	0322 072095	VERONIKA LOGINOVA	{"email": "loginova.veronika.101969@postgrespro.ru", "phone": "+70191664818"}
0005435266209	BF9A3A	8137 119078	ANNA KOROLEVA	{"email": "koroleva-anna_121979@postgrespro.ru", "phone": "+70044895854"}
0005435266210	BF9A3A	0151 447403	OLGA ZAKHAROVA	{"email": "o_zakharova10021967@postgrespro.ru", "phone": "+70410556567"}
0005435266211	CC68A3	1134 710185	ALEKSANDR FEDOROV	{"phone": "+70899961284"}
0005435266212	415251	0743 204678	GENNADIY KRASNOV	{"email": "krasnov.gennadiy_1973@postgrespro.ru", "phone": "+70839652769"}
0005435266213	415251	5485 813161	DARYA SOROKINA	{"email": "d_sorokina-091984@postgrespro.ru", "phone": "+70187822716"}
0005435266214	0FBF9E	2315 676075	VLADIMIR FEDOTOV	{"email": "fedotov_v02101974@postgrespro.ru", "phone": "+70848271028"}
0005435266215	B4B641	5678 461341	MILENA KOZLOVA	{"email": "kozlova_m1979@postgrespro.ru", "phone": "+70912119236"}
0005435266216	EE0006	9702 586323	IRINA POLYAKOVA	{"phone": "+70024127504"}
0005435266217	EE0006	2805 025306	YULIYA SCHERBAKOVA	{"email": "y_scherbakova-061975@postgrespro.ru", "phone": "+70778480165"}
0005435266218	5A9BEB	7331 654441	VASILIY MOROZOV	{"email": "morozovvasiliy_1964@postgrespro.ru", "phone": "+70243864234"}
0005435266219	64199F	1820 356072	SERGEY FILIPPOV	{"email": "filippov-s.111971@postgrespro.ru", "phone": "+70076604409"}
0005435266220	8FC164	5904 229002	NIKOLAY GERASIMOV	{"email": "gerasimov_n-24051972@postgrespro.ru", "phone": "+70499108679"}
0005435266221	8FC164	9371 437936	EKATERINA SAVELEVA	{"email": "saveleva.ekaterina.1967@postgrespro.ru", "phone": "+70095215881"}
0005435266222	3BD752	4400 994192	NATALYA MAKAROVA	{"phone": "+70677556988"}
0005435266223	D8CEEF	0015 962782	IVAN NAUMOV	{"phone": "+70557346592"}
0005435266224	D8CEEF	0201 833541	PAVEL SOKOLOV	{"phone": "+70816631910"}
0005435266225	D8CEEF	6159 823965	MARINA PAVLOVA	{"phone": "+70389988392"}
0005435266226	8505B9	4518 094774	YULIYA KUZMINA	{"email": "yuliya_kuzmina-17061976@postgrespro.ru", "phone": "+70099333560"}
0005435266227	48AC03	1183 718211	NINA MALYSHEVA	{"email": "malysheva.nina_1972@postgrespro.ru", "phone": "+70226800056"}
0005435266228	E57A7A	0530 715005	NINA VOROBEVA	{"phone": "+70263646383"}
0005435266229	E57A7A	0694 900075	ALEKSEY VASILEV	{"email": "vasileva-30111973@postgrespro.ru", "phone": "+70227664293"}
0005435266230	735310	9572 164032	DMITRIY FEDOTOV	{"email": "fedotov.dmitriy-16051979@postgrespro.ru", "phone": "+70981519323"}
0005435266231	7D1604	3243 509783	RINAT NOVIKOV	{"phone": "+70442775522"}
0005435266232	581186	0033 900152	ARINA MARTYNOVA	{"email": "martynova-a-1976@postgrespro.ru", "phone": "+70995303296"}
0005435266233	36AD15	2620 134573	DMITRIY GERASIMOV	{"email": "gerasimov_d-1985@postgrespro.ru", "phone": "+70572325075"}
0005435266234	561AC0	6935 417961	NIKOLAY EGOROV	{"email": "n_egorov.02011983@postgrespro.ru", "phone": "+70276707648"}
0005435266235	85AB95	9912 007721	VLADIMIR SEMENOV	{"email": "v-semenov_07081967@postgrespro.ru", "phone": "+70743130439"}
0005435266236	543631	6649 552008	LIDIYA IVANOVA	{"phone": "+70855859924"}
0005435266237	FE744A	8123 652217	MAKSIM ALEKSANDROV	{"email": "m-aleksandrov.011974@postgrespro.ru", "phone": "+70898985087"}
0005435266238	476E35	3693 475186	NINA RYABOVA	{"phone": "+70485288683"}
0005435266239	476E35	5651 844583	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr_08061969@postgrespro.ru", "phone": "+70076802390"}
0005435266240	476E35	6312 495603	LARISA TIMOFEEVA	{"email": "larisa-timofeeva031976@postgrespro.ru", "phone": "+70344314629"}
0005435266241	164AA9	6495 664323	VLADIMIR IVANOV	{"phone": "+70098248235"}
0005435266242	164AA9	3375 831424	GALINA ANDREEVA	{"phone": "+70792038615"}
0005435266243	3479F8	6449 187029	EGOR SMIRNOV	{"email": "e-smirnov-17041977@postgrespro.ru", "phone": "+70768059318"}
0005435266244	023C0C	4486 004367	VALENTINA SERGEEVA	{"email": "valentina-sergeeva-081976@postgrespro.ru", "phone": "+70805163718"}
0005435266245	F2EA8A	8629 256427	ALEKSANDRA ANDREEVA	{"phone": "+70251302622"}
0005435266246	F2EA8A	3083 065723	SERGEY SOROKIN	{"email": "s-sorokin_1975@postgrespro.ru", "phone": "+70544743928"}
0005435266247	0B91D9	3900 126232	VLADIMIR VLASOV	{"phone": "+70995433665"}
0005435266248	7BBD27	2992 089401	NIKOLAY IVANOV	{"phone": "+70292320892"}
0005435266249	446255	1815 886861	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail_1966@postgrespro.ru", "phone": "+70626560804"}
0005435266250	DB75E1	0636 831154	RAVIL ANTONOV	{"phone": "+70869970115"}
0005435266251	DE0AB7	0531 727280	LYUBOV KUZNECOVA	{"phone": "+70028811444"}
0005435266252	87DB0E	8515 391457	NIKOLAY VOROBEV	{"phone": "+70309058132"}
0005435266253	87DB0E	0600 520772	RAISA ARKHIPOVA	{"email": "arkhipova.r1977@postgrespro.ru", "phone": "+70450589284"}
0005435266254	6C2D97	8401 373169	KAMILLA MIRONOVA	{"email": "kamilla-mironova.1972@postgrespro.ru", "phone": "+70384928487"}
0005435266255	6C2D97	3659 535862	PETR VASILEV	{"email": "petr_vasilev.1973@postgrespro.ru", "phone": "+70642139290"}
0005435266256	53A932	1553 174635	ANDREY KOZLOV	{"phone": "+70013978015"}
0005435266257	83AD69	9668 383644	ELENA ZAYCEVA	{"phone": "+70799885003"}
0005435266258	9A0A21	1216 232244	KSENIYA MELNIKOVA	{"phone": "+70923605854"}
0005435266259	9A0A21	2564 047541	ZINAIDA PAVLOVA	{"email": "pavlovazinaida.051966@postgrespro.ru", "phone": "+70891808964"}
0005435266260	73C9A7	3487 263127	KIRILL KULIKOV	{"phone": "+70909495556"}
0005435266261	73C9A7	8340 580072	RAISA STEPANOVA	{"phone": "+70723091015"}
0005435266262	968237	1329 643785	VADIM IVANOV	{"email": "vadim-ivanov091977@postgrespro.ru", "phone": "+70709029954"}
0005435266263	D90C59	0349 933422	RUMIYA ZAKHAROVA	{"email": "zakharovar_03021965@postgrespro.ru", "phone": "+70264456515"}
0005435266264	D90C59	8243 248326	ALENA POPOVA	{"email": "popova_alena021985@postgrespro.ru", "phone": "+70118610901"}
0005435266265	6D3467	3741 957260	YAROSLAVA POPOVA	{"phone": "+70922670461"}
0005435266266	EDE683	6408 903405	PAVEL VASILEV	{"phone": "+70758719020"}
0005435266267	86725F	7858 858775	ANATOLIY ABRAMOV	{"email": "abramov_a04051976@postgrespro.ru", "phone": "+70398781209"}
0005435266268	FCBE89	7920 079562	PETR SOKOLOV	{"email": "sokolov_petr14061972@postgrespro.ru", "phone": "+70116907346"}
0005435266269	FCBE89	1061 805080	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev-20111962@postgrespro.ru", "phone": "+70011524889"}
0005435266270	1FC594	3961 491994	ALEKSANDR KULIKOV	{"phone": "+70517570190"}
0005435266271	1FC594	9802 744826	ALEKSANDR AFANASEV	{"email": "afanasevaleksandr061974@postgrespro.ru", "phone": "+70517117040"}
0005435266272	EAB631	2926 293315	SERGEY BARANOV	{"email": "sergey-baranov-1962@postgrespro.ru", "phone": "+70472809303"}
0005435266273	A392BF	9028 840043	EDUARD SAVELEV	{"email": "eduard.savelev.1962@postgrespro.ru", "phone": "+70855905355"}
0005435266274	5AF662	1230 290946	SERGEY VASILEV	{"email": "vasilevsergey051981@postgrespro.ru", "phone": "+70993568783"}
0005435266275	5AF662	4349 231213	ANASTASIYA ZAKHAROVA	{"email": "a.zakharova.1969@postgrespro.ru", "phone": "+70322558616"}
0005435266276	CEDEBF	2869 035486	ALLA POPOVA	{"phone": "+70910943615"}
0005435266277	CEDEBF	5470 328399	YULIYA VOLKOVA	{"email": "volkovay17111977@postgrespro.ru", "phone": "+70191485192"}
0005435266278	21E530	5975 857990	ALEKSANDR NOVIKOV	{"email": "novikova_111960@postgrespro.ru", "phone": "+70781505443"}
0005435266279	21E530	2937 533976	GULNAZ NAUMOVA	{"email": "naumovag.1972@postgrespro.ru", "phone": "+70982029979"}
0005435266280	9F5B4D	6507 499422	OLGA ANTONOVA	{"phone": "+70906168260"}
0005435266281	080C31	5930 261510	OKSANA ZAKHAROVA	{"phone": "+70059646972"}
0005435266282	080C31	5092 459684	ALEKSEY MAKAROV	{"email": "makarov.aleksey.17051975@postgrespro.ru", "phone": "+70708990859"}
0005435266283	1A02B3	1923 295876	OKSANA LUKYANOVA	{"phone": "+70330780103"}
0005435266284	1A02B3	1628 311884	SVETLANA ILINA	{"phone": "+70444845905"}
0005435266285	C31140	2626 605521	MIKHAIL VASILEV	{"email": "mikhail.vasilev_041969@postgrespro.ru", "phone": "+70411704561"}
0005435266286	484940	6482 049686	LYUBOV KUZNECOVA	{"phone": "+70597750185"}
0005435266287	CDBC4C	3116 214993	IGOR GUSEV	{"email": "gusev.igor051970@postgrespro.ru", "phone": "+70349773581"}
0005435266288	9C7C04	3665 283804	DMITRIY MAKAROV	{"email": "dmakarov_021979@postgrespro.ru", "phone": "+70952992382"}
0005435266289	654C2A	3962 729866	EVGENIYA KAZAKOVA	{"email": "evgeniya-kazakova_031975@postgrespro.ru", "phone": "+70415342055"}
0005435266290	654C2A	3341 114168	EVGENIY TIMOFEEV	{"phone": "+70744923817"}
0005435266291	2CECE9	2800 900160	MARIYA AKIMOVA	{"phone": "+70487327862"}
0005435266292	75E16E	5725 062698	ANDREY VLASOV	{"email": "andrey_vlasov_1971@postgrespro.ru", "phone": "+70769377743"}
0005435266293	FFA4AC	8099 612079	OLEG DAVYDOV	{"phone": "+70220030135"}
0005435266294	DA5FD7	2899 356726	EVGENIYA IVANOVA	{"phone": "+70479995703"}
0005435266295	DA5FD7	1192 120239	ALEKSANDR FOMIN	{"email": "fomina.1982@postgrespro.ru", "phone": "+70049956922"}
0005435266296	AA87F5	6770 524060	GALINA MIRONOVA	{"email": "mironova.galina19121966@postgrespro.ru", "phone": "+70539544115"}
0005435266297	64196B	9041 256356	SOFYA KOZLOVA	{"email": "kozlova-s-071970@postgrespro.ru", "phone": "+70222102040"}
0005435266298	64196B	2496 193365	ELENA ORLOVA	{"email": "elena.orlova31121974@postgrespro.ru", "phone": "+70514068342"}
0005435266299	CD89DB	6756 538108	NIKITA MELNIKOV	{"phone": "+70634293005"}
0005435266300	CD89DB	4253 810290	VERA ANDREEVA	{"phone": "+70787414691"}
0005435266301	E896F5	3899 700321	TATYANA YAKOVLEVA	{"email": "yakovlevatatyana111964@postgrespro.ru", "phone": "+70956502455"}
0005435266302	309EEA	6531 348313	GALINA NAZAROVA	{"phone": "+70003213459"}
0005435266303	70D820	2708 007577	OLGA KUZNECOVA	{"email": "kuznecova_olga-1972@postgrespro.ru", "phone": "+70985588154"}
0005435266304	606251	0133 544011	NATALYA KALININA	{"phone": "+70227451950"}
0005435266305	F7FADC	0271 688324	ROMAN PETROV	{"email": "roman_petrov_26051971@postgrespro.ru", "phone": "+70326008240"}
0005435266306	F7FADC	8944 648163	ALEKSEY KISELEV	{"email": "kiselev-a101978@postgrespro.ru", "phone": "+70300028559"}
0005435266307	924FEE	6245 700258	SERGEY KUZNECOV	{"email": "sergeykuznecov17111976@postgrespro.ru", "phone": "+70268862305"}
0005435266308	491341	1034 868169	ALEKSEY ISAEV	{"email": "aleksey_isaev_09071963@postgrespro.ru", "phone": "+70442614577"}
0005435266309	491341	8959 536951	MAKSIM SAVELEV	{"email": "savelev.maksim.1973@postgrespro.ru", "phone": "+70436454373"}
0005435266310	BFAFCD	9732 528372	VALENTINA KUZMINA	{"email": "v.kuzmina.021975@postgrespro.ru", "phone": "+70421766272"}
0005435266311	A88E76	0530 795268	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay-10011972@postgrespro.ru", "phone": "+70122777199"}
0005435266312	25DF03	9259 129132	MARIYA VOLKOVA	{"email": "volkova-m.1971@postgrespro.ru", "phone": "+70026248028"}
0005435266313	821836	4730 329251	NATALYA LAZAREVA	{"email": "n.lazareva-041957@postgrespro.ru", "phone": "+70279400643"}
0005435266314	FEABBF	2699 773649	VALENTIN SHEVCHENKO	{"email": "valentin.shevchenko111974@postgrespro.ru", "phone": "+70270335289"}
0005435266315	83D60F	9973 566234	PETR BORISOV	{"phone": "+70836292741"}
0005435266316	83D60F	8496 989434	TATYANA MOROZOVA	{"phone": "+70342891713"}
0005435266317	83D60F	0479 958195	MARINA TROFIMOVA	{"email": "marina_trofimova-31051983@postgrespro.ru", "phone": "+70887501717"}
0005435266318	804D81	4961 094059	OLESYA BELOVA	{"email": "belovaolesya07061976@postgrespro.ru", "phone": "+70363926004"}
0005435266319	DE457C	6898 242925	INGA KUZNECOVA	{"email": "kuznecovainga-29091978@postgrespro.ru", "phone": "+70199010991"}
0005435266320	542C8B	2707 930028	DMITRIY PETROV	{"email": "d.petrov_14091973@postgrespro.ru", "phone": "+70439947841"}
0005435266321	9B8D78	5404 282318	GALINA LUKYANOVA	{"phone": "+70594986951"}
0005435266322	00DC87	4033 224505	ANDREY IVANOV	{"phone": "+70224511662"}
0005435266323	00DC87	3128 182692	RAMIL TIKHONOV	{"email": "r_tikhonov.19051954@postgrespro.ru", "phone": "+70469463402"}
0005435266324	63DA98	7859 861400	MARIYA KUZMINA	{"phone": "+70263945613"}
0005435266325	E61C56	5411 974925	KRISTINA MIRONOVA	{"phone": "+70628700874"}
0005435266326	5526E9	5931 997374	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr-1967@postgrespro.ru", "phone": "+70438498353"}
0005435266327	5526E9	1946 606422	ELENA DANILOVA	{"phone": "+70274704918"}
0005435266328	A8801B	5567 647108	ARTEM SERGEEV	{"phone": "+70758377250"}
0005435266329	3A53BF	8481 398169	ALEKSANDR KUDRYASHOV	{"email": "kudryashova.05031970@postgrespro.ru", "phone": "+70121197834"}
0005435266330	75D2DC	5155 094771	ANASTASIYA GUSEVA	{"email": "guseva-a.1987@postgrespro.ru", "phone": "+70198823085"}
0005435266331	B6BD30	5854 777190	VYACHESLAV MELNIKOV	{"email": "vmelnikov-28091973@postgrespro.ru", "phone": "+70946954076"}
0005435266332	B4397D	8693 910620	VLADISLAV EGOROV	{"phone": "+70062954290"}
0005435266333	EE0EEE	6530 053626	VALENTINA ERMAKOVA	{"email": "ermakovav_19071969@postgrespro.ru", "phone": "+70509267441"}
0005435266334	866C3B	9769 060346	EKATERINA BORISOVA	{"email": "borisova.e-1968@postgrespro.ru", "phone": "+70097762697"}
0005435266335	5D93C6	1495 041766	YURIY ORLOV	{"email": "y_orlov30111968@postgrespro.ru", "phone": "+70811186717"}
0005435266336	D16DE2	3840 779254	NINA AFANASEVA	{"phone": "+70834471281"}
0005435266337	E864E1	1060 888640	EVGENIY SIDOROV	{"email": "evgeniy_sidorov031970@postgrespro.ru", "phone": "+70009829578"}
0005435266338	EE4C29	6478 335634	VLADIMIR ANTONOV	{"phone": "+70275458862"}
0005435266339	86A03C	4076 488625	NIKOLAY MAKAROV	{"email": "nmakarov.071977@postgrespro.ru", "phone": "+70965408273"}
0005435266340	25FBC8	9940 060226	ELENA DANILOVA	{"email": "e_danilova-1979@postgrespro.ru", "phone": "+70645877458"}
0005435266341	9ADF67	2418 306750	LIDIYA BORISOVA	{"email": "lidiya_borisova.041976@postgrespro.ru", "phone": "+70892890532"}
0005435266342	9ADF67	8135 157572	IGOR AFANASEV	{"email": "igor-afanasev-1977@postgrespro.ru", "phone": "+70169624206"}
0005435266343	F87E33	6510 637492	ALEKSANDR TIKHONOV	{"email": "a-tikhonov_26041973@postgrespro.ru", "phone": "+70852156575"}
0005435266344	D9FC3B	1004 622111	TAMARA ZAKHAROVA	{"phone": "+70211580965"}
0005435266345	D9FC3B	0626 476694	MAKSIM ANTONOV	{"email": "maksim_antonov-17031981@postgrespro.ru", "phone": "+70835627812"}
0005435266346	4D9A06	2654 101412	LILIYA POLYAKOVA	{"phone": "+70627214099"}
0005435266347	67DDF1	9331 414425	ANDREY MIKHAYLOV	{"phone": "+70005460074"}
0005435266348	67DDF1	1844 013869	RINAT PETROV	{"phone": "+70348328705"}
0005435269621	456B2E	9192 872542	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov-1971@postgrespro.ru", "phone": "+70167881823"}
0005435269622	FCDBE5	7250 646135	ALEKSANDR SOROKIN	{"email": "sorokinaleksandr_121972@postgrespro.ru", "phone": "+70720899692"}
0005435269623	CAFD5E	6318 348881	GEORGIY VASILEV	{"phone": "+70422353124"}
0005435269624	CAFD5E	4683 649671	MAKSIM SERGEEV	{"email": "sergeev-maksim.111982@postgrespro.ru", "phone": "+70140061330"}
0005435269625	F6FFBD	4018 599021	MURAD ILIN	{"phone": "+70757165984"}
0005435269626	F6FFBD	5121 522167	VALENTINA GERASIMOVA	{"email": "v.gerasimova_1972@postgrespro.ru", "phone": "+70865731790"}
0005435269627	96A8D4	1627 404151	SAMIRA KOLESNIKOVA	{"email": "kolesnikova-samira-1972@postgrespro.ru", "phone": "+70078075942"}
0005435269628	E10208	9101 694027	SVETLANA VOROBEVA	{"email": "vorobeva-s04101960@postgrespro.ru", "phone": "+70762076199"}
0005435269629	E10208	3911 676002	LARISA ZAYCEVA	{"email": "zayceva_larisa111971@postgrespro.ru", "phone": "+70513046052"}
0005435269630	225191	4119 399876	POLINA BARANOVA	{"email": "pbaranova_1977@postgrespro.ru", "phone": "+70489078272"}
0005435269631	C2D9F6	9639 420059	ELENA SERGEEVA	{"phone": "+70024015164"}
0005435269632	C38878	9989 315501	ROMAN SOKOLOV	{"email": "r.sokolov1967@postgrespro.ru", "phone": "+70211455488"}
0005435269633	33C924	2496 491110	PRASKOVYA NIKOLAEVA	{"email": "nikolaevap27031971@postgrespro.ru", "phone": "+70045736139"}
0005435269634	F17838	8787 803288	LYUDMILA MOROZOVA	{"phone": "+70807875966"}
0005435269635	F17838	3394 781698	ELENA ORLOVA	{"phone": "+70207472595"}
0005435269636	F17838	6048 621657	NATALYA VLASOVA	{"phone": "+70043246894"}
0005435269637	1DD5B0	4206 477661	GENNADIY SIDOROV	{"email": "gsidorov_10121979@postgrespro.ru", "phone": "+70102189969"}
0005435269638	1DD5B0	3483 989930	VIKTOR IVANOV	{"phone": "+70884194139"}
0005435269639	38AA4C	0687 517632	ARTEM BORISOV	{"email": "borisov.artem1978@postgrespro.ru", "phone": "+70586530747"}
0005435269640	3EEE03	5306 249274	ALEKSEY MIRONOV	{"phone": "+70602108715"}
0005435269641	292364	1599 865199	ELENA FILATOVA	{"email": "efilatova-061975@postgrespro.ru", "phone": "+70345158864"}
0005435269642	292364	0066 443523	MAKSIM MELNIKOV	{"phone": "+70692881468"}
0005435269643	AF46B2	4349 061418	ELENA GERASIMOVA	{"phone": "+70914291998"}
0005435269644	1B7B0F	7149 994573	ALEKSEY ABRAMOV	{"phone": "+70585365082"}
0005435269645	1C3706	9240 371525	VASILIY FROLOV	{"email": "vasiliy_frolov061970@postgrespro.ru", "phone": "+70369588045"}
0005435269646	1C3706	4827 199563	RAISA EFIMOVA	{"email": "raisaefimova-1970@postgrespro.ru", "phone": "+70377504328"}
0005435269647	A2F99C	3713 608772	LIDIYA KAZAKOVA	{"phone": "+70686874181"}
0005435269648	2D6B2F	1811 712370	MIKHAIL IVANOV	{"email": "ivanov_mikhail111970@postgrespro.ru", "phone": "+70635146169"}
0005435269649	2D6B2F	3418 991255	PETR IVANOV	{"phone": "+70388417848"}
0005435269650	2E2821	5139 467624	POLINA ABRAMOVA	{"email": "p_abramova_051984@postgrespro.ru", "phone": "+70756589429"}
0005435269651	2E2821	2338 550417	ZINAIDA EFIMOVA	{"email": "efimova.z_1971@postgrespro.ru", "phone": "+70578628303"}
0005435269652	473010	4810 199229	OLGA NIKOLAEVA	{"email": "olga.nikolaeva_091976@postgrespro.ru", "phone": "+70686205286"}
0005435269653	0F8830	5124 464572	NATALYA KUZNECOVA	{"email": "kuznecova-natalya1965@postgrespro.ru", "phone": "+70210505264"}
0005435269654	A85829	6495 018307	MARIYA ILINA	{"email": "ilina.m08061967@postgrespro.ru", "phone": "+70930834078"}
0005435269655	A85829	3879 985880	OLEG FILIPPOV	{"phone": "+70475578935"}
0005435269656	895C44	5680 477585	DMITRIY EGOROV	{"email": "egorovdmitriy.081970@postgrespro.ru", "phone": "+70163970991"}
0005435269657	DC4F9B	3102 604039	IGOR IVANOV	{"email": "ivanov_i_1969@postgrespro.ru", "phone": "+70268357548"}
0005435269658	5AA2F6	2597 519447	EKATERINA VOLKOVA	{"email": "ekaterinavolkova_22011968@postgrespro.ru", "phone": "+70510566235"}
0005435269659	4DA33B	4489 072057	MIKHAIL FEDOROV	{"email": "fedorovmikhail1966@postgrespro.ru", "phone": "+70767176029"}
0005435269660	4DA33B	2839 486796	TATYANA KARPOVA	{"phone": "+70224624776"}
0005435269661	6B5224	2578 149650	YULIYA SEMENOVA	{"email": "yuliyasemenova-091962@postgrespro.ru", "phone": "+70531754373"}
0005435269662	6B5224	6596 939030	YULIYA KONOVALOVA	{"phone": "+70458353783"}
0005435269663	341C2F	1850 027223	NATALYA POPOVA	{"email": "popova.n-01051973@postgrespro.ru", "phone": "+70879622013"}
0005435269664	4028F9	3159 706812	ANNA PAVLOVA	{"email": "pavlovaanna_011975@postgrespro.ru", "phone": "+70879161924"}
0005435269665	3CF80F	5941 574151	NIKOLAY SERGEEV	{"phone": "+70678269662"}
0005435269666	3CF80F	1348 843584	ANNA SOROKINA	{"email": "anna.sorokina021964@postgrespro.ru", "phone": "+70970116108"}
0005435269667	AB7CED	4268 405001	MIKHAIL NIKOLAEV	{"email": "nikolaevmikhail-04051969@postgrespro.ru", "phone": "+70570191274"}
0005435269668	AB7CED	8159 808215	MAKSIM SEMENOV	{"phone": "+70642450468"}
0005435269669	121B3E	4377 740701	NIKOLAY IVANOV	{"phone": "+70986002685"}
0005435269670	121B3E	6524 813023	ARTUR ISAEV	{"phone": "+70979034178"}
0005435269671	3816A1	7704 149679	PAVEL ZAYCEV	{"email": "zaycev-p05081981@postgrespro.ru", "phone": "+70339313986"}
0005435269672	311EF2	4510 618584	ANATOLIY GORBUNOV	{"email": "gorbunov-anatoliy04101976@postgrespro.ru", "phone": "+70038426580"}
0005435269673	311EF2	9637 866612	IGOR TIMOFEEV	{"email": "timofeev.i_121977@postgrespro.ru", "phone": "+70096579155"}
0005435269674	762FB5	8420 303547	VIKTOR IVANOV	{"email": "v.ivanov.02051967@postgrespro.ru", "phone": "+70855490846"}
0005435269675	586C5A	3084 940578	VLADIMIR STEPANOV	{"email": "v-stepanov.1974@postgrespro.ru", "phone": "+70978361643"}
0005435269676	586C5A	2359 764725	VLADIMIR KUZMIN	{"email": "vladimir.kuzmin.22071976@postgrespro.ru", "phone": "+70926225369"}
0005435269677	3752F1	9110 376341	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.t011977@postgrespro.ru", "phone": "+70069655442"}
0005435269678	B38E0A	3820 104467	NATALYA ANDREEVA	{"email": "natalya_andreeva.18101969@postgrespro.ru", "phone": "+70867055373"}
0005435269679	0CD2D6	1556 994360	EKATERINA MARTYNOVA	{"email": "martynova-ekaterina-021985@postgrespro.ru", "phone": "+70085658424"}
0005435269680	50E18C	5979 430087	POLINA MIRONOVA	{"email": "polinamironova091971@postgrespro.ru", "phone": "+70955279045"}
0005435269681	50E18C	6023 473991	ANDREY ALEKSEEV	{"email": "alekseevandrey-1978@postgrespro.ru", "phone": "+70865067584"}
0005435269682	50E18C	2070 749727	ALEKSANDR RODIONOV	{"phone": "+70327667743"}
0005435269683	D7C58B	4827 986152	SERGEY PETROV	{"email": "sergey.petrov_081964@postgrespro.ru", "phone": "+70513205259"}
0005435269684	8F00E0	5516 214104	ANTON AFANASEV	{"email": "afanaseva.091969@postgrespro.ru", "phone": "+70442602742"}
0005435269685	042B06	9353 632369	ELENA ALEKSEEVA	{"phone": "+70143874315"}
0005435269686	5C1C62	0339 860924	OLGA KUZMINA	{"phone": "+70344999007"}
0005435269687	69D9E8	4966 840825	SERGEY ZAYCEV	{"phone": "+70381088873"}
0005435269688	0EAC3E	3324 011839	SVETLANA KUZNECOVA	{"phone": "+70078445883"}
0005435269689	A564C1	5527 551918	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr101968@postgrespro.ru", "phone": "+70512807909"}
0005435269690	1397A3	4285 846657	YURIY KAZAKOV	{"email": "ykazakov021980@postgrespro.ru", "phone": "+70388948265"}
0005435269691	5AD0BF	6294 749614	SVETLANA SAVELEVA	{"email": "svetlana.saveleva.061976@postgrespro.ru", "phone": "+70192355536"}
0005435269692	B24B2A	5572 398123	ALEKSANDR BORISOV	{"email": "aleksandr.borisov.22031970@postgrespro.ru", "phone": "+70963197138"}
0005435269693	A6152C	0766 828757	OLGA POTAPOVA	{"phone": "+70236391871"}
0005435269694	B977F6	2938 273390	NATALYA IVANOVA	{"phone": "+70717495833"}
0005435269695	078B67	4947 287260	EVGENIY KUDRYASHOV	{"email": "evgeniy-kudryashov.1978@postgrespro.ru", "phone": "+70395743542"}
0005435269696	CE2D89	2528 947157	VERA LEBEDEVA	{"email": "lebedevav.07111966@postgrespro.ru", "phone": "+70894696976"}
0005435269697	CE2D89	1051 853869	EVDOKIYA BELOVA	{"email": "e_belova_1974@postgrespro.ru", "phone": "+70354637759"}
0005435269698	69A454	9505 561460	SVETLANA DAVYDOVA	{"email": "svetlana-davydova.1973@postgrespro.ru", "phone": "+70305973326"}
0005435269699	789FC7	8769 926374	EKATERINA KAZAKOVA	{"email": "kazakova_e1981@postgrespro.ru", "phone": "+70828607573"}
0005435269878	1DB744	5982 249149	ALEKSANDR STEPANOV	{"phone": "+70779658651"}
0005435269700	789FC7	8769 343247	FEDOR GUSEV	{"email": "gusev_f.05101975@postgrespro.ru", "phone": "+70393878373"}
0005435269701	8E931E	1361 379924	MARINA ISAEVA	{"email": "isaevamarina031973@postgrespro.ru", "phone": "+70501585531"}
0005435269702	835945	2627 695767	ARTEM ZAYCEV	{"email": "zaycev_a.071973@postgrespro.ru", "phone": "+70067821793"}
0005435269703	C81F98	7501 856561	VIKTOR PETROV	{"email": "petrov.v_18081965@postgrespro.ru", "phone": "+70735060068"}
0005435269704	76F37B	7598 516669	IGOR IVANOV	{"email": "i-ivanov-101968@postgrespro.ru", "phone": "+70253869126"}
0005435269705	76F37B	0227 920185	KSENIYA YAKOVLEVA	{"phone": "+70179103655"}
0005435269706	F0747F	8439 614153	MAKSIM RODIONOV	{"email": "rodionov-m03061968@postgrespro.ru", "phone": "+70880241238"}
0005435269707	56410A	7859 964207	LYUBOV ANDREEVA	{"phone": "+70686635311"}
0005435269708	56410A	3156 251351	IGOR SCHERBAKOV	{"phone": "+70517669870"}
0005435269709	56410A	6188 215856	ALEKSANDRA SMIRNOVA	{"phone": "+70480861936"}
0005435269710	C8590F	8637 901742	VERA PETROVA	{"phone": "+70050878778"}
0005435269711	C8590F	7885 561193	EKATERINA KISELEVA	{"phone": "+70425987748"}
0005435269712	C8590F	3416 149149	MIKHAIL PAVLOV	{"phone": "+70934689165"}
0005435269713	87101D	9105 480822	ALEKSEY POPOV	{"phone": "+70821220824"}
0005435269714	C8F56D	1727 951754	ELENA POLYAKOVA	{"email": "elenapolyakova1976@postgrespro.ru", "phone": "+70636585508"}
0005435269715	C8F56D	8358 927407	NIKOLAY RODIONOV	{"email": "nrodionov_03021971@postgrespro.ru", "phone": "+70015797941"}
0005435269716	6269E6	6956 424427	GALINA NIKIFOROVA	{"email": "nikiforovag1962@postgrespro.ru", "phone": "+70252597910"}
0005435269717	6269E6	9218 256408	ELENA FOMINA	{"phone": "+70428921248"}
0005435269718	4E5DCB	1276 590547	GENNADIY NAUMOV	{"email": "g-naumov021969@postgrespro.ru", "phone": "+70457573222"}
0005435269719	4E5DCB	0226 174696	TATYANA ABRAMOVA	{"email": "abramovatatyana-111980@postgrespro.ru", "phone": "+70858539358"}
0005435269720	0DE66D	5881 204037	YANA EGOROVA	{"phone": "+70075588373"}
0005435269721	0DE66D	1199 248047	IRINA ALEKSANDROVA	{"email": "i_aleksandrova.061973@postgrespro.ru", "phone": "+70390017953"}
0005435269722	DFC4E3	7094 087981	KONSTANTIN BONDARENKO	{"email": "bondarenko_konstantin.02081977@postgrespro.ru", "phone": "+70887045798"}
0005435269723	1B01B5	3709 378337	LYUBOV FILATOVA	{"email": "filatova-l-13091979@postgrespro.ru", "phone": "+70354852907"}
0005435269724	1B01B5	8484 564332	GENNADIY SHEVCHENKO	{"phone": "+70851027583"}
0005435269725	44E222	2455 685169	EVGENIY SIDOROV	{"email": "sidorov.evgeniy.121967@postgrespro.ru", "phone": "+70336519787"}
0005435269726	3CD727	5824 184538	GALINA KOROLEVA	{"phone": "+70043614406"}
0005435269727	5E3B50	2835 536685	SERGEY ANDREEV	{"email": "andreev-s1981@postgrespro.ru", "phone": "+70015233853"}
0005435269728	E6EB94	8108 053976	ALEKSANDR FOMIN	{"phone": "+70690225257"}
0005435269729	E6EB94	1891 721023	TAMARA BOGDANOVA	{"email": "bogdanova.t.1965@postgrespro.ru", "phone": "+70190161809"}
0005435269730	DFC980	5293 880817	NIKOLAY NOVIKOV	{"email": "novikovn1966@postgrespro.ru", "phone": "+70693813857"}
0005435269731	5B8F00	1596 610934	INNA LUKYANOVA	{"phone": "+70422814368"}
0005435269732	5B8F00	5038 398777	ALEKSEY VASILEV	{"phone": "+70698824503"}
0005435269733	6B8F35	6691 104640	ANDREY IVANOV	{"email": "aivanov091982@postgrespro.ru", "phone": "+70971342491"}
0005435269734	D45F8B	1550 814391	ELENA NIKOLAEVA	{"email": "elena_nikolaeva.28111971@postgrespro.ru", "phone": "+70233742539"}
0005435269735	D45F8B	4678 022837	TATYANA KOROLEVA	{"email": "koroleva-tatyana.30101964@postgrespro.ru", "phone": "+70276553999"}
0005435269736	9D1812	5660 748079	TATYANA SMIRNOVA	{"email": "tatyana.smirnova_1980@postgrespro.ru", "phone": "+70671545760"}
0005435269737	9D1812	6510 830591	ALEKSANDR FROLOV	{"email": "frolov_aleksandr.09061978@postgrespro.ru", "phone": "+70643916701"}
0005435269738	9D1812	9176 284027	VERA POPOVA	{"email": "popova_vera.14111979@postgrespro.ru", "phone": "+70109528322"}
0005435269739	2B145C	7636 168022	ELENA BELYAEVA	{"phone": "+70188978897"}
0005435269740	09D9FF	5879 479503	ANATOLIY MAKSIMOV	{"phone": "+70558136556"}
0005435269741	D73158	2200 818396	SVETLANA GAVRILOVA	{"email": "svetlanagavrilova-1967@postgrespro.ru", "phone": "+70052315096"}
0005435269742	D73158	6482 896382	BOGDAN SOKOLOV	{"email": "sokolov.bogdan1972@postgrespro.ru", "phone": "+70187804312"}
0005435269743	5FD9BF	6288 972936	ILMIRA PAVLOVA	{"email": "pavlova_ilmira04071974@postgrespro.ru", "phone": "+70993930238"}
0005435269744	817384	1850 136088	NIKOLAY VOROBEV	{"phone": "+70688510581"}
0005435269745	3D64CD	0337 073116	VLADIMIR DMITRIEV	{"phone": "+70895640107"}
0005435269746	B3FEF3	8782 394336	EVGENIY SOLOVEV	{"phone": "+70542978773"}
0005435269747	B3FEF3	7959 421646	VASILIY KUZNECOV	{"phone": "+70239546888"}
0005435269748	D85072	4851 582146	ANASTASIYA POPOVA	{"email": "popova.anastasiya-101970@postgrespro.ru", "phone": "+70543141773"}
0005435269749	BA06C7	2461 691426	YULIYA IVANOVA	{"email": "ivanova-y.1970@postgrespro.ru", "phone": "+70698524755"}
0005435269750	BA06C7	3644 892172	LIDIYA RYABOVA	{"email": "ryabovalidiya16101969@postgrespro.ru", "phone": "+70408711091"}
0005435269751	146778	9282 764743	VITALIY ALEKSANDROV	{"email": "vitaliyaleksandrov091972@postgrespro.ru", "phone": "+70519312800"}
0005435269752	595A44	4853 990453	ANATOLIY FEDOROV	{"email": "fedorova_121972@postgrespro.ru", "phone": "+70627934338"}
0005435269753	7569FA	9670 654988	VLADISLAV TIMOFEEV	{"email": "vladislavtimofeev-111963@postgrespro.ru", "phone": "+70726873585"}
0005435269754	302CD1	2207 220189	ELENA GORBUNOVA	{"phone": "+70735522472"}
0005435269755	48D5B6	8309 884602	LYUDMILA ERMAKOVA	{"email": "l-ermakova-1969@postgrespro.ru", "phone": "+70231608939"}
0005435269756	48D5B6	6050 920498	SERGEY SERGEEV	{"phone": "+70792274435"}
0005435269757	B32E28	7035 062616	ARTEM KOROLEV	{"email": "artemkorolev-041974@postgrespro.ru", "phone": "+70035335122"}
0005435269758	B32E28	5571 581609	EVGENIY SMIRNOV	{"phone": "+70014999900"}
0005435269759	6B76BE	4721 751253	TATYANA DANILOVA	{"email": "tatyanadanilova.041977@postgrespro.ru", "phone": "+70876442117"}
0005435269760	0FA926	6048 096084	SERGEY DMITRIEV	{"phone": "+70501085166"}
0005435269761	D930C5	8818 658035	OLGA ROMANOVA	{"email": "romanova_o1972@postgrespro.ru", "phone": "+70436268011"}
0005435269762	D930C5	6759 738217	NIKOLAY SERGEEV	{"phone": "+70131625315"}
0005435269763	C57CC7	4922 949420	NINA VASILEVA	{"phone": "+70068895608"}
0005435269764	C57CC7	8280 436832	ALEKSANDRA NOVIKOVA	{"phone": "+70363687611"}
0005435269765	FAD7DC	1785 862705	VALENTIN MARTYNOV	{"phone": "+70182411536"}
0005435269766	A99063	5179 360285	NATALYA FEDOROVA	{"phone": "+70868770210"}
0005435269767	5193F3	9500 950242	VIKTOR SIDOROV	{"email": "sidorovviktor.27011979@postgrespro.ru", "phone": "+70053281557"}
0005435269768	5193F3	7469 424031	ARTEMIY KUZNECOV	{"email": "artemiy.kuznecov_1977@postgrespro.ru", "phone": "+70790271432"}
0005435269769	5193F3	1553 617731	LYUBOV EGOROVA	{"email": "egorova.l_10031969@postgrespro.ru", "phone": "+70664103163"}
0005435269770	729378	7524 429675	VYACHESLAV VOLKOV	{"phone": "+70681009850"}
0005435269771	0424FA	8312 629176	ELENA TARASOVA	{"phone": "+70475762222"}
0005435269772	0424FA	8379 634521	NATALYA POPOVA	{"phone": "+70706654663"}
0005435269884	D7B6DD	8043 398433	VALENTINA TROFIMOVA	{"phone": "+70943131757"}
0005435269773	702B04	7272 499680	OLGA NOVIKOVA	{"email": "o.novikova_24091971@postgrespro.ru", "phone": "+70745108886"}
0005435269774	683102	8102 783716	ARTEM EGOROV	{"phone": "+70955639503"}
0005435269775	683102	2293 889175	RINAT GRIGOREV	{"phone": "+70162045108"}
0005435269776	4E6C7F	0264 346014	RINAT POPOV	{"email": "popovrinat1973@postgrespro.ru", "phone": "+70440451856"}
0005435269777	A8046B	5276 202748	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr.1970@postgrespro.ru", "phone": "+70968693003"}
0005435269778	A8046B	0053 611253	ALEKSANDRA KUZNECOVA	{"email": "kuznecova_a-011971@postgrespro.ru", "phone": "+70651092101"}
0005435269779	5013FE	6716 430542	ALEKSANDR MELNIKOV	{"phone": "+70394371972"}
0005435269780	129272	7427 232429	RUMIYA DAVYDOVA	{"phone": "+70283359450"}
0005435269781	49CB74	2408 506428	ANASTASIYA SEMENOVA	{"email": "semenova_a-25111971@postgrespro.ru", "phone": "+70009830842"}
0005435269782	49CB74	9385 494804	ALEKSEY POPOV	{"phone": "+70010563331"}
0005435269783	2012E9	3650 991544	VASILIY BARANOV	{"email": "baranov_vasiliy1968@postgrespro.ru", "phone": "+70818711212"}
0005435269784	167482	9024 875971	IRINA NAUMOVA	{"email": "i-naumova.10071975@postgrespro.ru", "phone": "+70129958873"}
0005435269785	167482	1672 077278	NIKOLAY MAKSIMOV	{"phone": "+70714743774"}
0005435269786	DDB3A1	2095 444134	SVETLANA SERGEEVA	{"email": "svetlana-sergeeva1965@postgrespro.ru", "phone": "+70964901867"}
0005435269787	DDB3A1	8566 343200	MARIYA EGOROVA	{"phone": "+70726576424"}
0005435269788	EFE8C1	3767 720214	IGOR VLASOV	{"email": "vlasov.igor.16091971@postgrespro.ru", "phone": "+70257710702"}
0005435269789	A7D113	9239 480562	VYACHESLAV VASILEV	{"phone": "+70141297503"}
0005435269790	87A980	5997 471300	MARIYA DENISOVA	{"email": "mariya-denisova-18051969@postgrespro.ru", "phone": "+70677610159"}
0005435269791	934995	9683 964657	LIDIYA KONOVALOVA	{"phone": "+70264587099"}
0005435269792	934995	7913 948486	VLADIMIR MIKHAYLOV	{"email": "mikhaylov.v29121966@postgrespro.ru", "phone": "+70584945332"}
0005435269793	6A0359	9144 412488	VLADIMIR KOZLOV	{"email": "vladimir_kozlov_29051969@postgrespro.ru", "phone": "+70271380487"}
0005435269794	6A0359	3146 133395	EVGENIY PAVLOV	{"phone": "+70341366831"}
0005435269795	1DA3AD	0724 640985	PAVEL OSIPOV	{"email": "osipov_pavel-1979@postgrespro.ru", "phone": "+70812261150"}
0005435269796	806DD2	7447 892984	YULIYA KULIKOVA	{"email": "kulikova_yuliya.25031972@postgrespro.ru", "phone": "+70752095457"}
0005435269797	FCF108	6738 063504	MIKHAIL ZAKHAROV	{"email": "zakharov-mikhail1985@postgrespro.ru", "phone": "+70144721051"}
0005435269798	FCF108	4028 201162	TATYANA LAZAREVA	{"phone": "+70457516024"}
0005435269799	0AC213	1783 818273	SERGEY YAKOVLEV	{"email": "s.yakovlev_1971@postgrespro.ru", "phone": "+70310917570"}
0005435269800	C78C44	4099 877938	ELENA SOKOLOVA	{"phone": "+70826883317"}
0005435269801	A1D7FD	6148 702564	RUSHANIYA BELOVA	{"phone": "+70079331790"}
0005435269802	697408	0936 013391	NATALYA ILINA	{"email": "n-ilina_1972@postgrespro.ru", "phone": "+70898252386"}
0005435269803	697408	4333 582078	DMITRIY PAVLOV	{"phone": "+70875720904"}
0005435269804	F67426	2321 149825	SVETLANA KRASNOVA	{"phone": "+70709169639"}
0005435269805	CB9191	3233 281266	NADEZHDA KONOVALOVA	{"phone": "+70914783661"}
0005435269806	CB9191	5425 696180	IVAN IVANOV	{"email": "ivanov_i1969@postgrespro.ru", "phone": "+70328582404"}
0005435269807	0A18E2	1687 295479	VLADIMIR MAKAROV	{"phone": "+70055897727"}
0005435269808	117322	5745 378224	SERGEY SOKOLOV	{"email": "sergey-sokolov.26011978@postgrespro.ru", "phone": "+70624730612"}
0005435269809	D8F9E6	6014 842636	VALERIYA KOZLOVA	{"email": "v.kozlova-071980@postgrespro.ru", "phone": "+70020610702"}
0005435269810	D8F9E6	5181 477969	TATYANA YUDINA	{"phone": "+70905950554"}
0005435269811	A59F25	3093 430675	VLADISLAV ORLOV	{"phone": "+70072614708"}
0005435269812	480613	2020 671906	SVETLANA GERASIMOVA	{"phone": "+70261711983"}
0005435269813	85517C	6837 547953	SERGEY BARANOV	{"email": "sergey.baranov-1964@postgrespro.ru", "phone": "+70027130412"}
0005435269814	85517C	2888 215150	MARIYA EGOROVA	{"phone": "+70777073394"}
0005435269815	F82C49	2695 374296	VLADIMIR MEDVEDEV	{"phone": "+70381905973"}
0005435269816	F82C49	0296 052500	ALEKSANDR MOROZOV	{"phone": "+70911082031"}
0005435269817	879B59	4415 126141	ALEKSANDRA KARPOVA	{"phone": "+70715510522"}
0005435269818	B83503	6927 877645	LILIYA ABRAMOVA	{"email": "liliya_abramova04091976@postgrespro.ru", "phone": "+70471215800"}
0005435269819	F3EC38	1560 474977	DENIS PETROV	{"email": "dpetrov24081973@postgrespro.ru", "phone": "+70242564337"}
0005435269820	EE801A	6607 086246	TAISA POPOVA	{"email": "t_popova_011973@postgrespro.ru", "phone": "+70258555872"}
0005435269821	EE801A	3148 270321	ALEKSANDR NIKITIN	{"phone": "+70359185106"}
0005435269822	EE801A	8230 448156	OLGA KOLESNIKOVA	{"phone": "+70367151907"}
0005435269823	E5D2CF	7892 391679	YURIY POPOV	{"phone": "+70449267608"}
0005435269824	FFF637	1461 950684	IVAN ILIN	{"email": "i_ilin06031972@postgrespro.ru", "phone": "+70015175251"}
0005435269825	FFF637	0680 425804	VALENTINA KOZLOVA	{"email": "kozlova-v-04071977@postgrespro.ru", "phone": "+70676594489"}
0005435269826	35264A	9149 196306	OLGA LOGINOVA	{"email": "loginova.olga_051967@postgrespro.ru", "phone": "+70403621549"}
0005435269827	7C3BD3	0695 907277	LARISA MOROZOVA	{"phone": "+70016760992"}
0005435269828	B4838D	4300 989919	ALEKSEY DMITRIEV	{"phone": "+70755807403"}
0005435269829	B4838D	1656 162827	NIKOLAY RODIONOV	{"email": "rodionovn_021973@postgrespro.ru", "phone": "+70982231367"}
0005435269830	4F83F2	1720 391811	YURIY DENISOV	{"email": "y.denisov.1969@postgrespro.ru", "phone": "+70993353141"}
0005435269831	4F83F2	3643 762552	ILYA GERASIMOV	{"email": "i_gerasimov1971@postgrespro.ru", "phone": "+70903573323"}
0005435269832	E1967F	9076 124136	NIKOLAY ROMANOV	{"email": "romanov_n-1966@postgrespro.ru", "phone": "+70956437873"}
0005435269833	E1967F	1706 088996	VALENTINA BARANOVA	{"email": "v.baranova_1966@postgrespro.ru", "phone": "+70230825162"}
0005435269834	A92C69	3332 174940	YULIYA ABRAMOVA	{"email": "yuliya_abramova-1960@postgrespro.ru", "phone": "+70294270638"}
0005435269835	A92C69	2510 056471	MIKHAIL ALEKSEEV	{"email": "alekseev.m061967@postgrespro.ru", "phone": "+70951980344"}
0005435269836	2787C0	7148 081007	KONSTANTIN BONDARENKO	{"email": "bondarenko.k_021978@postgrespro.ru", "phone": "+70905588594"}
0005435269837	770D5F	4683 414360	LYUDMILA IVANOVA	{"phone": "+70763771553"}
0005435269838	F28599	1934 183662	ANASTASIYA DAVYDOVA	{"email": "anastasiya_davydova.031968@postgrespro.ru", "phone": "+70109790148"}
0005435269839	AD3961	6018 072177	ALEKSEY VLASOV	{"phone": "+70650675228"}
0005435269840	8CB282	1032 122055	VYACHESLAV POPOV	{"phone": "+70932786470"}
0005435269841	7BB265	7348 288120	ANATOLIY FOMIN	{"phone": "+70688636725"}
0005435269842	F545C7	1633 941320	ANTONINA AKIMOVA	{"email": "antonina_akimova-1979@postgrespro.ru", "phone": "+70338780985"}
0005435269843	F4EF1F	0449 013871	SERGEY FROLOV	{"email": "frolov.s-1982@postgrespro.ru", "phone": "+70834578808"}
0005435269844	D0E9FE	9016 280389	VLADISLAV ORLOV	{"phone": "+70451274652"}
0005435269845	9D0C20	6077 833772	EGOR EGOROV	{"email": "egorovegor-011973@postgrespro.ru", "phone": "+70198186999"}
0005435269846	BABF84	4175 457491	YURIY CHERNOV	{"email": "chernov.yuriy_1975@postgrespro.ru", "phone": "+70937898063"}
0005435269847	BABF84	8957 005947	ANATOLIY ALEKSANDROV	{"phone": "+70395983751"}
0005435269848	0594B0	9265 858723	VIKTORIYA MEDVEDEVA	{"email": "v-medvedeva19081965@postgrespro.ru", "phone": "+70096202901"}
0005435269849	21D3FA	7178 968279	TATYANA ANDREEVA	{"email": "t.andreeva-091958@postgrespro.ru", "phone": "+70365656676"}
0005435269850	8AA50F	2677 175578	VALENTINA TIKHONOVA	{"phone": "+70066529359"}
0005435269851	AE4E16	7092 831950	ELENA IVANOVA	{"phone": "+70864721345"}
0005435269852	148791	0148 319635	RAISA CHERNOVA	{"email": "raisachernova.28071975@postgrespro.ru", "phone": "+70004308423"}
0005435269853	148791	5775 877063	EVGENIYA SAVELEVA	{"email": "saveleva_evgeniya021968@postgrespro.ru", "phone": "+70381358639"}
0005435269854	A3111F	4081 356765	ALEKSANDR IVANOV	{"phone": "+70349738950"}
0005435269855	06956E	9487 080935	ANTONINA MIRONOVA	{"email": "antonina_mironova_1973@postgrespro.ru", "phone": "+70013382519"}
0005435269856	7B4EBE	1173 887048	IVAN SHEVCHENKO	{"phone": "+70477678352"}
0005435269857	7B4EBE	7315 663533	NADEZHDA GUSEVA	{"email": "gusevan-01051973@postgrespro.ru", "phone": "+70714518311"}
0005435269858	E1D615	0364 492043	ANASTASIYA PAVLOVA	{"email": "pavlovaanastasiya-1971@postgrespro.ru", "phone": "+70990753846"}
0005435269859	E1D615	5930 153172	GALINA LUKYANOVA	{"phone": "+70423311422"}
0005435269860	67C421	8819 835212	NATALYA FILIPPOVA	{"email": "natalya-filippova_1978@postgrespro.ru", "phone": "+70970541985"}
0005435269861	67C421	9169 383378	ARTUR EGOROV	{"email": "egorov-a_01021976@postgrespro.ru", "phone": "+70960636242"}
0005435269862	B17898	9425 526821	ANASTASIYA KRASNOVA	{"email": "krasnova-a.27021978@postgrespro.ru", "phone": "+70794608850"}
0005435269863	B17898	8697 535053	OLGA DAVYDOVA	{"phone": "+70517724673"}
0005435269864	F158D8	0861 037015	VERA MARTYNOVA	{"email": "martynova-vera_02121960@postgrespro.ru", "phone": "+70698353636"}
0005435269865	89918F	9915 852345	YULIYA OSIPOVA	{"phone": "+70394461450"}
0005435269866	19AFEF	2404 199889	LYUBOV PETROVA	{"email": "lpetrova-1961@postgrespro.ru", "phone": "+70889427555"}
0005435269867	94CB95	2708 143673	AYRAT SOROKIN	{"email": "a-sorokin_071973@postgrespro.ru", "phone": "+70135413501"}
0005435269868	94CB95	5045 910861	VLADIMIR SERGEEV	{"phone": "+70676314970"}
0005435269869	B84F47	8893 430862	SERGEY VASILEV	{"email": "s_vasilev_07041964@postgrespro.ru", "phone": "+70661411203"}
0005435269870	B84F47	3542 405632	ELVINA LUKYANOVA	{"phone": "+70646716443"}
0005435269871	5978B7	3261 607414	ANASTASIYA IVANOVA	{"phone": "+70871655498"}
0005435269872	EE3667	1169 969920	VYACHESLAV BELOV	{"phone": "+70260031255"}
0005435269873	8F5D7F	2648 723835	NIKOLAY MAKAROV	{"email": "makarov_nikolay_051975@postgrespro.ru", "phone": "+70300153324"}
0005435269874	A5C211	9030 227319	EKATERINA EGOROVA	{"email": "egorova-ekaterina_27121975@postgrespro.ru", "phone": "+70526310912"}
0005435269875	5E339E	6750 802091	ILYA BORISOV	{"phone": "+70535061281"}
0005435269876	EF11CF	1246 912615	TATYANA OSIPOVA	{"email": "t.osipova.15051964@postgrespro.ru", "phone": "+70654760386"}
0005435269877	EF11CF	2277 358349	DMITRIY TIMOFEEV	{"phone": "+70692961178"}
0005435269879	BAB390	1938 640105	TIMUR FILIPPOV	{"email": "filippov-timur_30111962@postgrespro.ru", "phone": "+70976650251"}
0005435269880	F63313	2065 181034	ALEKSANDR MATVEEV	{"email": "matveev.aleksandr.031974@postgrespro.ru", "phone": "+70546573586"}
0005435269881	F63313	2380 108457	VLADIMIR ROMANOV	{"phone": "+70917110678"}
0005435269882	451586	4555 277453	MARGARITA MIKHAYLOVA	{"email": "mikhaylova.m.021981@postgrespro.ru", "phone": "+70568021552"}
0005435269883	43A63C	6450 754524	ANDREY ZHURAVLEV	{"email": "zhuravlevandrey_1973@postgrespro.ru", "phone": "+70177978517"}
0005435269885	F70402	5437 381222	ELENA PAVLOVA	{"email": "pavlova-elena1972@postgrespro.ru", "phone": "+70419171018"}
0005435269886	F70402	8846 056892	LEONID IVANOV	{"email": "l-ivanov-22091970@postgrespro.ru", "phone": "+70756890192"}
0005435269887	DEAC40	0511 831361	VALENTINA KUDRYASHOVA	{"email": "kudryashovav-1983@postgrespro.ru", "phone": "+70281720938"}
0005435269888	DEAC40	4878 222669	YULIYA SEMENOVA	{"email": "y.semenova.27041970@postgrespro.ru", "phone": "+70331462813"}
0005435269889	162929	1455 495427	PETR KULIKOV	{"email": "kulikov.petr-011980@postgrespro.ru", "phone": "+70942071144"}
0005435269890	162929	3725 757691	KRISTINA NAUMOVA	{"email": "kristina_naumova.1990@postgrespro.ru", "phone": "+70556276776"}
0005435269891	BE69D6	6677 048200	ARSEN BELOV	{"email": "arsen.belov.1960@postgrespro.ru", "phone": "+70909551041"}
0005435269892	BE69D6	1754 492076	YURIY NOVIKOV	{"email": "y-novikov-25071977@postgrespro.ru", "phone": "+70110320228"}
0005435269893	061F5A	1663 690072	ALEKSANDR KISELEV	{"phone": "+70028034811"}
0005435269894	061F5A	5993 674161	NIKOLAY SAVELEV	{"email": "nikolay-savelev.1969@postgrespro.ru", "phone": "+70707387317"}
0005435269895	DE2F6D	2038 078519	NATALYA EFREMOVA	{"email": "n.efremova1974@postgrespro.ru", "phone": "+70511006880"}
0005435269896	DE2F6D	8532 375651	DMITRIY MOROZOV	{"phone": "+70588226095"}
0005435269897	673BBD	4356 516757	ALEKSANDR GRIGOREV	{"email": "grigorev_aleksandr-121974@postgrespro.ru", "phone": "+70439979012"}
0005435269898	AFFDB9	1540 926820	NADEZHDA CHERNOVA	{"email": "nadezhda.chernova-1973@postgrespro.ru", "phone": "+70101368770"}
0005435269899	37AD46	0675 001049	GALINA SIDOROVA	{"email": "galina-sidorova091975@postgrespro.ru", "phone": "+70000595189"}
0005435269900	37AD46	9850 657053	YURIY VASILEV	{"phone": "+70505744603"}
0005435269901	CE0A8B	4904 609247	KRISTINA KONOVALOVA	{"phone": "+70605331620"}
0005435269902	A59870	8874 683861	VADIM EGOROV	{"email": "vadim.egorov-24021968@postgrespro.ru", "phone": "+70414689714"}
0005435269903	DD9F59	2543 339463	ALEKSANDR ZHUKOV	{"email": "azhukov-15051971@postgrespro.ru", "phone": "+70964863433"}
0005435269904	6F951F	7568 661306	ALEKSANDR GORBUNOV	{"phone": "+70773413058"}
0005435269905	00A676	5833 370765	VALENTINA SOROKINA	{"email": "sorokina-valentina_16091971@postgrespro.ru", "phone": "+70255322902"}
0005435269906	E548C7	0985 806408	ANNA NESTEROVA	{"phone": "+70515143668"}
0005435269907	9E5839	8714 035063	YURIY SEMENOV	{"phone": "+70911049113"}
0005435269908	747DAC	2884 721833	KARINA STEPANOVA	{"phone": "+70881205621"}
0005435269909	EDC9FE	4338 417979	VARVARA POPOVA	{"email": "popova-v_21081966@postgrespro.ru", "phone": "+70315769847"}
0005435269910	8EBB50	9148 685024	MARIYA NOVIKOVA	{"email": "novikova-m_1965@postgrespro.ru", "phone": "+70290472173"}
0005435269911	8EBB50	2032 033730	NIKOLAY FROLOV	{"email": "n-frolov_1959@postgrespro.ru", "phone": "+70599649368"}
0005435269912	CCA9D8	8685 551828	TATYANA NIKOLAEVA	{"phone": "+70632817348"}
0005435269913	F86F79	3315 190595	SERGEY KUZMIN	{"phone": "+70565162343"}
0005435269914	A284E3	5138 332942	IRINA IVANOVA	{"phone": "+70909201380"}
0005435269915	A284E3	5363 723760	MARIYA IVANOVA	{"phone": "+70754452791"}
0005435269916	5DDEB3	6161 614643	NIKOLAY RODIONOV	{"email": "rodionov_n16011968@postgrespro.ru", "phone": "+70282272202"}
0005435269917	5DDEB3	4682 469667	VYACHESLAV BONDARENKO	{"phone": "+70990613278"}
0005435269918	3B199F	2145 092366	TATYANA KUZNECOVA	{"phone": "+70496553941"}
0005435269919	1E7599	9012 774968	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-1992@postgrespro.ru", "phone": "+70966627759"}
0005435269920	054D4E	6930 655750	ALEKSANDR MELNIKOV	{"phone": "+70573744253"}
0005435269921	054D4E	6188 882679	OLGA SOLOVEVA	{"email": "o_soloveva-13021966@postgrespro.ru", "phone": "+70331724126"}
0005435269922	18CD13	0009 995449	GALINA TROFIMOVA	{"email": "trofimova.galina041969@postgrespro.ru", "phone": "+70060967154"}
0005435269923	18CD13	8342 236787	NATALYA STEPANOVA	{"email": "stepanova.natalya-051973@postgrespro.ru", "phone": "+70611124078"}
0005435269924	18CD13	7066 771873	MAKSIM MOROZOV	{"phone": "+70753630276"}
0005435269925	DCB4E4	6962 456231	VIKTOR KUZNECOV	{"phone": "+70798727200"}
0005435269926	71A278	9304 929207	VLADIMIR GRIGOREV	{"email": "vladimir-grigorev.051966@postgrespro.ru", "phone": "+70576448003"}
0005435269927	AE3307	9474 211717	OLGA ILINA	{"email": "ilina_o.101974@postgrespro.ru", "phone": "+70298331986"}
0005435269928	085FA3	0768 476990	VASILIY CHERNOV	{"email": "chernov-v.21121970@postgrespro.ru", "phone": "+70820288791"}
0005435269929	0A9AD3	9674 876488	ALEVTINA MASLOVA	{"phone": "+70798885859"}
0005435269930	0A9AD3	3849 389745	VIKTORIYA PAVLOVA	{"phone": "+70843694291"}
0005435269931	3BCA57	1837 839041	ALEKSANDR KUZMIN	{"email": "a.kuzmin03021977@postgrespro.ru", "phone": "+70163691298"}
0005435269932	3BCA57	6004 354139	VLADIMIR TIKHONOV	{"phone": "+70114850232"}
0005435269933	1C9842	8104 370398	OLGA SOROKINA	{"email": "o-sorokina1986@postgrespro.ru", "phone": "+70706993117"}
0005435269934	F1BE90	3579 282522	SVETLANA MAKAROVA	{"phone": "+70365402762"}
0005435269935	2F0F20	9564 574427	VYACHESLAV NIKOLAEV	{"phone": "+70517611472"}
0005435269936	89AAC8	1826 942490	LYUBOV MIKHAYLOVA	{"email": "l_mikhaylova_15111983@postgrespro.ru", "phone": "+70938648359"}
0005435269937	4E89CC	9430 289804	NELLI DENISOVA	{"email": "denisova.nelli_021976@postgrespro.ru", "phone": "+70467082024"}
0005435269938	40DD75	5536 980282	VYACHESLAV NIKITIN	{"email": "vyacheslav-nikitin.09031968@postgrespro.ru", "phone": "+70424820637"}
0005435269939	B2275A	8864 105818	VALENTINA SOROKINA	{"email": "sorokina-valentina.1965@postgrespro.ru", "phone": "+70086861178"}
0005435269940	AC945E	5077 099872	VLADIMIR FEDOTOV	{"phone": "+70542256605"}
0005435269941	AC945E	6727 706229	YURIY ALEKSEEV	{"email": "alekseevyuriy-1968@postgrespro.ru", "phone": "+70326856504"}
0005435269942	65650E	6456 979716	EVGENIY POPOV	{"email": "popov_evgeniy15091976@postgrespro.ru", "phone": "+70047693108"}
0005435269943	65650E	9004 366935	TATYANA LEBEDEVA	{"email": "tlebedeva_08011976@postgrespro.ru", "phone": "+70692687842"}
0005435269944	AD893B	4816 810925	LYUDMILA ANTONOVA	{"email": "antonoval_091972@postgrespro.ru", "phone": "+70242049997"}
0005435269945	C0620B	2277 485418	NATALYA PETROVA	{"phone": "+70847924445"}
0005435269946	27FA60	4767 194984	GALINA POPOVA	{"email": "popova_g_1964@postgrespro.ru", "phone": "+70690861837"}
0005435269947	2C5F33	3951 587835	LYUBOV KULIKOVA	{"email": "lkulikova.091978@postgrespro.ru", "phone": "+70108979790"}
0005435269948	4CA41A	8923 594039	LIDIYA SEMENOVA	{"phone": "+70119998752"}
0005435269949	E82837	4472 873492	MAKSIM ZAKHAROV	{"email": "zakharov_maksim.091970@postgrespro.ru", "phone": "+70551056028"}
0005435269950	AE69C0	2481 126202	MARIYA RYABOVA	{"phone": "+70926473041"}
0005435269951	AE69C0	3943 449713	ANNA KUZNECOVA	{"phone": "+70576344399"}
0005435269952	DC4842	9998 086792	NINA IVANOVA	{"phone": "+70510109228"}
0005435269953	C5ADD8	1333 791183	VALERIY MAKSIMOV	{"email": "maksimov-valeriy_1971@postgrespro.ru", "phone": "+70643147685"}
0005435269954	C5ADD8	3044 262281	ALEKSEY ZAKHAROV	{"phone": "+70261775668"}
0005435269955	140068	2404 197326	VALERIY FOMIN	{"email": "fomin_v121966@postgrespro.ru", "phone": "+70506948772"}
0005435269956	140068	6983 667763	OLGA POTAPOVA	{"email": "o.potapova.091960@postgrespro.ru", "phone": "+70835177520"}
0005435269957	DDC6F6	6001 283714	ELENA NAZAROVA	{"email": "nazarova_elena.1958@postgrespro.ru", "phone": "+70228871880"}
0005435269958	DDC6F6	0109 164498	VALERIYA SAVELEVA	{"email": "saveleva_valeriya-1970@postgrespro.ru", "phone": "+70918180213"}
0005435269959	55B822	1340 610588	SERGEY GAVRILOV	{"phone": "+70010638151"}
0005435269960	C097AF	6338 924591	IRINA POLYAKOVA	{"email": "ipolyakova_1979@postgrespro.ru", "phone": "+70536601232"}
0005435269961	2C2525	2736 921701	LIDIYA KRASNOVA	{"phone": "+70679171454"}
0005435269962	0D480E	2638 709441	ALEKSEY FEDOROV	{"email": "fedorov-a-1968@postgrespro.ru", "phone": "+70586940067"}
0005435269963	0D480E	8912 786300	OKSANA ZAYCEVA	{"email": "zayceva_oksana1981@postgrespro.ru", "phone": "+70353162892"}
0005435269964	E1B0AD	1507 473477	ANDREY KUDRYASHOV	{"email": "kudryashov.andrey031969@postgrespro.ru", "phone": "+70769154701"}
0005435269965	0A7F78	4038 219510	ZOYA SOROKINA	{"phone": "+70150932588"}
0005435269966	FFA89F	8488 477091	ANDREY GUSEV	{"email": "gusevandrey-061967@postgrespro.ru", "phone": "+70474022046"}
0005435269967	B06A85	4324 186191	MIKHAIL ILIN	{"email": "ilin_m1975@postgrespro.ru", "phone": "+70598112183"}
0005435269968	B06A85	4651 269546	EKATERINA ARKHIPOVA	{"phone": "+70429823538"}
0005435269969	B06A85	5786 738115	TAMARA KALININA	{"phone": "+70857029063"}
0005435269970	08B12A	3987 834992	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr_021974@postgrespro.ru", "phone": "+70101131468"}
0005435269971	08B12A	8075 055881	SVETLANA KUZNECOVA	{"phone": "+70357371427"}
0005435269972	3279F2	0716 432988	ELENA NAUMOVA	{"email": "naumova_elena-1971@postgrespro.ru", "phone": "+70563896284"}
0005435269973	B31D32	8101 209224	ALEKSEY KUZNECOV	{"email": "a_kuznecov.28111970@postgrespro.ru", "phone": "+70133773142"}
0005435269974	B31D32	3836 035368	MAKSIM IVANOV	{"phone": "+70969238734"}
0005435269975	7A7E6E	8575 630941	VIKTORIYA AFANASEVA	{"email": "vafanaseva_091967@postgrespro.ru", "phone": "+70925167641"}
0005435269976	DC8708	0686 973988	VIKTOR KUZNECOV	{"phone": "+70156333148"}
0005435269977	FC2933	3862 049699	RAISA FILIPPOVA	{"phone": "+70535186657"}
0005435269978	F39F88	5595 159848	NATALYA VASILEVA	{"phone": "+70787657031"}
0005435269979	FB8120	2404 377579	SVETLANA NESTEROVA	{"phone": "+70436841640"}
0005435269980	8970DF	0625 717985	ILGIZ ALEKSEEV	{"email": "i_alekseev_07061985@postgrespro.ru", "phone": "+70335446334"}
0005435269981	2AD9F3	6673 060409	LIDIYA MELNIKOVA	{"phone": "+70593651519"}
0005435269982	2AD9F3	7841 772365	OLEG SEMENOV	{"email": "semenov-o1975@postgrespro.ru", "phone": "+70222126923"}
0005435269983	5E3C82	8435 844344	VIKTOR ALEKSEEV	{"email": "viktor-alekseev101968@postgrespro.ru", "phone": "+70288072854"}
0005435269984	C5E2CF	5633 999007	OLGA KOROLEVA	{"phone": "+70210689321"}
0005435269985	0C2D95	8873 581167	TATYANA KISELEVA	{"phone": "+70048374342"}
0005435269986	14AC96	9003 836308	STANISLAV FROLOV	{"phone": "+70475586010"}
0005435269987	025185	4925 271747	ALEKSANDRA MIRONOVA	{"phone": "+70438234613"}
0005435269988	E9F39F	6955 858659	NIKOLAY BONDARENKO	{"email": "bondarenko-n071969@postgrespro.ru", "phone": "+70735566257"}
0005435269989	4C7DB1	8237 914515	NADEZHDA MELNIKOVA	{"phone": "+70427889466"}
0005435269990	415814	2986 336795	MARIYA KARPOVA	{"phone": "+70438798571"}
0005435269991	C1FAD1	7571 704743	MARGARITA POPOVA	{"phone": "+70352288176"}
0005435269992	C1FAD1	5410 046841	RAISA NOVIKOVA	{"email": "raisanovikova.1972@postgrespro.ru", "phone": "+70820240018"}
0005435269993	C1FAD1	9955 316422	IRINA MAKAROVA	{"phone": "+70387842643"}
0005435269994	D89D8D	3421 495594	NIKITA VLASOV	{"email": "vlasov-n061970@postgrespro.ru", "phone": "+70458436801"}
0005435269995	CD4983	7967 994147	SERGEY BONDARENKO	{"email": "bondarenko.s19051983@postgrespro.ru", "phone": "+70101987656"}
0005435269996	CD4983	5209 308721	OLESYA ERMAKOVA	{"phone": "+70264533860"}
0005435269997	B209C6	1045 022477	GENNADIY BONDARENKO	{"phone": "+70381217569"}
0005435269998	83F8E4	3226 327546	NATALYA SOKOLOVA	{"email": "n.sokolova.19111973@postgrespro.ru", "phone": "+70116910054"}
0005435269999	83F8E4	4952 814622	IRINA MEDVEDEVA	{"email": "medvedeva.i.02111973@postgrespro.ru", "phone": "+70695838846"}
0005435270000	103B32	3101 084479	DARYA NOVIKOVA	{"email": "novikovadarya-30061974@postgrespro.ru", "phone": "+70763625422"}
0005435270001	0DB8E8	2875 191894	DMITRIY MELNIKOV	{"phone": "+70211056230"}
0005435270002	4C13C1	5620 794426	LYUBOV MATVEEVA	{"phone": "+70175100635"}
0005435270003	4C13C1	8325 223557	GALINA EFIMOVA	{"email": "efimova.galina1971@postgrespro.ru", "phone": "+70330534182"}
0005435270004	6945F3	0480 337510	ELMIRA PAVLOVA	{"email": "pavlova-e-1979@postgrespro.ru", "phone": "+70992468332"}
0005435270005	1E02DA	5158 324546	VALENTINA DMITRIEVA	{"phone": "+70490655746"}
0005435270006	1E02DA	0936 118376	ILDAR SCHERBAKOV	{"phone": "+70252734990"}
0005435270007	C4C2DF	4505 422383	ALEKSANDR ZAYCEV	{"email": "a-zaycev041967@postgrespro.ru", "phone": "+70110415263"}
0005435270008	500360	6275 745973	VALERIY KAZAKOV	{"phone": "+70656378991"}
0005435270009	500360	0638 900593	VIKTOR FEDOTOV	{"phone": "+70456097302"}
0005435270010	2DE172	2360 843136	DMITRIY IVANOV	{"email": "ivanov.dmitriy.16041957@postgrespro.ru", "phone": "+70198539554"}
0005435270011	2DE172	6175 330242	ALEKSEY ZAYCEV	{"email": "a_zaycev_27051967@postgrespro.ru", "phone": "+70405846349"}
0005435270012	2C6C6A	6762 075321	ANDREY ZAKHAROV	{"email": "a_zakharov.071972@postgrespro.ru", "phone": "+70837798258"}
0005435270013	9AE695	4392 858221	IRINA SERGEEVA	{"email": "sergeevairina1974@postgrespro.ru", "phone": "+70163158101"}
0005435270014	9AE695	4907 265872	ANDREY NIKOLAEV	{"email": "andrey.nikolaev111967@postgrespro.ru", "phone": "+70528259516"}
0005435270015	9AE695	5641 672683	SERGEY SERGEEV	{"email": "sergeev.sergey_23021966@postgrespro.ru", "phone": "+70500690385"}
0005435270016	F3ED09	9007 127429	PRASKOVYA ZOTOVA	{"phone": "+70113394986"}
0005435270017	BE6CF1	9217 043038	TAMARA OSIPOVA	{"email": "tamara.osipova.1974@postgrespro.ru", "phone": "+70111226468"}
0005435270018	76EA9A	6131 044252	ALEKSANDR SEMENOV	{"phone": "+70024993045"}
0005435270019	C1A939	7552 071077	DMITRIY GUSEV	{"phone": "+70023736966"}
0005435270020	C1A939	7795 815697	PETR GRIGOREV	{"email": "grigorev.petr28011955@postgrespro.ru", "phone": "+70766408078"}
0005435270021	C1A939	8983 341187	OLGA RODIONOVA	{"phone": "+70109251378"}
0005435270022	28E6F1	8277 123784	NADEZHDA KUDRYASHOVA	{"email": "kudryashovan-111981@postgrespro.ru", "phone": "+70122510915"}
0005435270023	6BA5F0	6817 626482	VIKTORIYA KOZLOVA	{"phone": "+70281290621"}
0005435270024	4C010F	0871 831062	VLADIMIR KONOVALOV	{"email": "v-konovalov-061980@postgrespro.ru", "phone": "+70700424231"}
0005435270025	584973	0375 353301	VIKTORIYA EGOROVA	{"phone": "+70563897889"}
0005435270026	57F28B	1823 683448	ANASTASIYA GUSEVA	{"email": "gusevaanastasiya-081976@postgrespro.ru", "phone": "+70429929671"}
0005435270027	57F28B	3368 173132	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev_19051973@postgrespro.ru", "phone": "+70143511754"}
0005435270028	50A4DE	7759 704736	ELENA VOLKOVA	{"email": "elena-volkova_01021968@postgrespro.ru", "phone": "+70523543079"}
0005435270029	EBABDE	6498 493932	ANASTASIYA ORLOVA	{"email": "orlovaanastasiya_061976@postgrespro.ru", "phone": "+70155571792"}
0005435270030	20EC74	0803 806125	SVETLANA FROLOVA	{"email": "frolova_svetlana_1968@postgrespro.ru", "phone": "+70032232070"}
0005435270031	3B38EB	2279 267662	ALEKSANDR ANDREEV	{"email": "a-andreev31011973@postgrespro.ru", "phone": "+70535740446"}
0005435270032	9B43CE	8484 162398	NINA LOGINOVA	{"phone": "+70235571805"}
0005435270033	9B43CE	8698 146663	IVAN MAKSIMOV	{"email": "maksimovi-041974@postgrespro.ru", "phone": "+70160460784"}
0005435270034	9B43CE	5011 014251	PAVEL SOKOLOV	{"phone": "+70000375857"}
0005435270035	290BAD	4309 348678	YULIYA TIKHONOVA	{"email": "y_tikhonova04101972@postgrespro.ru", "phone": "+70745227734"}
0005435270036	290BAD	7534 990115	EKATERINA ERMAKOVA	{"email": "e_ermakova_1968@postgrespro.ru", "phone": "+70298359962"}
0005435270037	F7A652	3571 134603	YANA ZAKHAROVA	{"phone": "+70148220309"}
0005435270038	6C37F5	4342 396012	MAKSIM MIKHAYLOV	{"email": "m-mikhaylov_121984@postgrespro.ru", "phone": "+70646623288"}
0005435270039	F16864	6320 550130	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa031985@postgrespro.ru", "phone": "+70345761944"}
0005435270040	F16864	8772 956780	EVGENIY KISELEV	{"email": "kiselev.evgeniy_1988@postgrespro.ru", "phone": "+70521680677"}
0005435270041	A4485B	3134 394804	DENIS ANDREEV	{"email": "andreev_d101970@postgrespro.ru", "phone": "+70766019106"}
0005435270042	38B3F1	1719 594737	SOFYA MIKHAYLOVA	{"email": "mikhaylova-sofya_121977@postgrespro.ru", "phone": "+70086538727"}
0005435270043	838A3C	2138 476524	VERA KARPOVA	{"phone": "+70604485353"}
0005435270044	070274	4916 698804	STANISLAV ANDREEV	{"phone": "+70570159560"}
0005435270045	9B924B	8287 650759	GALINA SERGEEVA	{"email": "g-sergeeva-1977@postgrespro.ru", "phone": "+70200569234"}
0005435270046	F1FFD7	9734 851023	VLADIMIR PETROV	{"phone": "+70127656779"}
0005435270047	F1FFD7	4708 435975	NATALYA PAVLOVA	{"phone": "+70781932338"}
0005435270048	2DD7AB	9735 379554	TAMARA EFREMOVA	{"phone": "+70903272583"}
0005435270049	F28A15	3027 722364	ARKADIY NAZAROV	{"phone": "+70380076179"}
0005435270050	75CFC7	3409 167555	ALEKSANDR POPOV	{"phone": "+70774179202"}
0005435270219	6E1095	0821 543222	YURIY TIKHONOV	{"phone": "+70149975188"}
0005435270051	4DEFCF	4999 375981	GALINA POLYAKOVA	{"email": "polyakova-galina19051975@postgrespro.ru", "phone": "+70555852623"}
0005435270052	8EB0C9	3496 438609	NATALYA KARPOVA	{"phone": "+70858712003"}
0005435270053	8EB0C9	5920 406812	MARIYA KONOVALOVA	{"email": "mariya-konovalova.081977@postgrespro.ru", "phone": "+70182011676"}
0005435270054	703295	9007 797862	ELENA GAVRILOVA	{"email": "gavrilova.elena.041971@postgrespro.ru", "phone": "+70706943560"}
0005435270055	703295	5291 278846	ANASTASIYA AFANASEVA	{"phone": "+70685808765"}
0005435270056	32F18B	3102 485267	ARTEM NIKITIN	{"email": "nikitin-a.031971@postgrespro.ru", "phone": "+70795621490"}
0005435270057	EB7DB9	8524 445685	NATALYA KOLESNIKOVA	{"email": "natalya-kolesnikova_1974@postgrespro.ru", "phone": "+70861292492"}
0005435270058	EB7DB9	1316 580839	DMITRIY SERGEEV	{"email": "dmitriy-sergeev.07091977@postgrespro.ru", "phone": "+70274098948"}
0005435270059	F1ABCD	1848 329682	GALINA MASLOVA	{"email": "g_maslova071967@postgrespro.ru", "phone": "+70474873776"}
0005435270060	445394	2596 508316	EKATERINA NIKITINA	{"phone": "+70616107336"}
0005435270061	DA0B6E	1905 628729	NIKOLAY VOLKOV	{"email": "volkovn_18071978@postgrespro.ru", "phone": "+70147008058"}
0005435270062	585780	9533 761818	PETR MELNIKOV	{"phone": "+70083602373"}
0005435270063	BEBDDB	3717 362520	NATALYA IVANOVA	{"phone": "+70841601216"}
0005435270064	2DC136	7770 622623	YULIYA KOZLOVA	{"phone": "+70691207857"}
0005435270065	B76A37	1421 184095	SERGEY DAVYDOV	{"email": "davydov_sergey-1968@postgrespro.ru", "phone": "+70217693699"}
0005435270066	CA678B	8661 508535	YAROSLAV MIKHAYLOV	{"phone": "+70375742948"}
0005435270067	CA678B	1229 630824	NADEZHDA EGOROVA	{"email": "egorova.n_111988@postgrespro.ru", "phone": "+70787809020"}
0005435270068	948421	4483 073029	VLADIMIR KUZNECOV	{"email": "kuznecov_v.09111968@postgrespro.ru", "phone": "+70200654904"}
0005435270069	9F059B	1721 384154	TATYANA DENISOVA	{"email": "denisova-tatyana.1971@postgrespro.ru", "phone": "+70781088925"}
0005435270070	9F059B	0047 451925	NELYA POPOVA	{"phone": "+70314576762"}
0005435270071	7F090A	5949 975201	ANASTASIYA EGOROVA	{"email": "anastasiya.egorova-121972@postgrespro.ru", "phone": "+70965715982"}
0005435270072	3ED4D4	0920 599943	EVGENIY MIRONOV	{"email": "evgeniy-mironov_1972@postgrespro.ru", "phone": "+70346026511"}
0005435270073	3ED4D4	4648 958966	ALEKSANDR PETROV	{"email": "petrova_061967@postgrespro.ru", "phone": "+70369367818"}
0005435270074	27A90D	6652 718270	DANILA SCHERBAKOV	{"email": "dscherbakov-1962@postgrespro.ru", "phone": "+70101790172"}
0005435270075	45AD43	7826 305315	VLADISLAV ORLOV	{"phone": "+70908453186"}
0005435270076	BF51A4	2969 114923	DARYA POLYAKOVA	{"email": "d_polyakova.13041966@postgrespro.ru", "phone": "+70443600853"}
0005435270077	4464B8	1219 789291	LYUDMILA RYABOVA	{"email": "ryabova_lyudmila.16071975@postgrespro.ru", "phone": "+70988015219"}
0005435270078	72F629	4331 440805	POLINA GAVRILOVA	{"email": "polinagavrilova.091963@postgrespro.ru", "phone": "+70364422034"}
0005435270079	72F629	5049 381630	SERGEY GORBUNOV	{"email": "sergey-gorbunov.1985@postgrespro.ru", "phone": "+70698441501"}
0005435270080	C08EA3	0574 934562	OLEG FEDOROV	{"email": "fedorov_o_22011977@postgrespro.ru", "phone": "+70997657924"}
0005435270081	C08EA3	6783 685747	VIKTOR ZAKHAROV	{"phone": "+70181909771"}
0005435270082	C08EA3	6951 906229	YURIY DENISOV	{"email": "denisovyuriy-101977@postgrespro.ru", "phone": "+70355006018"}
0005435270083	A6B6AD	5885 056393	KSENIYA NOVIKOVA	{"phone": "+70167757642"}
0005435270084	A6B6AD	1119 990241	ZOYA POPOVA	{"phone": "+70034411681"}
0005435270085	7632CD	1511 860237	DARYA SCHERBAKOVA	{"phone": "+70265599313"}
0005435270086	7632CD	6466 585164	PAVEL MIKHAYLOV	{"phone": "+70308778306"}
0005435270087	3FB35D	0821 769976	NATALYA BELYAEVA	{"phone": "+70849187299"}
0005435270088	06818F	3193 208934	NIKOLAY BELOV	{"email": "belov.nikolay1978@postgrespro.ru", "phone": "+70278315735"}
0005435270089	D9C0E0	1555 741265	EKATERINA ANISIMOVA	{"email": "anisimova-ekaterina_1967@postgrespro.ru", "phone": "+70333621688"}
0005435270090	D9C0E0	2699 330163	PAVEL DENISOV	{"phone": "+70015587035"}
0005435270091	717382	7332 840433	IGOR KISELEV	{"phone": "+70801593321"}
0005435270092	361491	5053 256403	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov1973@postgrespro.ru", "phone": "+70162397741"}
0005435270093	361491	7581 060825	BOGDAN NIKOLAEV	{"email": "nikolaev_b.061971@postgrespro.ru", "phone": "+70421217840"}
0005435270094	361491	7752 309504	ARTEM ALEKSEEV	{"phone": "+70804150367"}
0005435270095	5EA937	0018 235286	IRINA ZAYCEVA	{"email": "i_zayceva.081970@postgrespro.ru", "phone": "+70584378688"}
0005435270096	58914B	7351 164264	NIKOLAY SAVELEV	{"email": "nikolay-savelev.031967@postgrespro.ru", "phone": "+70288998433"}
0005435270097	F0CC36	5004 028497	SVETLANA ARKHIPOVA	{"email": "arkhipova-s1972@postgrespro.ru", "phone": "+70023015820"}
0005435270098	F0CC36	1673 707130	YURIY ABRAMOV	{"email": "y.abramov.17081974@postgrespro.ru", "phone": "+70977712117"}
0005435270099	C884D0	1284 976867	GALINA EGOROVA	{"email": "egorova_g021980@postgrespro.ru", "phone": "+70476550153"}
0005435270100	C884D0	0297 569088	ANNA ALEKSANDROVA	{"email": "aleksandrova.anna08061973@postgrespro.ru", "phone": "+70405127656"}
0005435270101	3B6B16	0882 017764	ALEKSEY ZHUKOV	{"email": "zhukov.a.081971@postgrespro.ru", "phone": "+70338197449"}
0005435270102	AEBFAC	6643 517923	VALERIY ORLOV	{"email": "valeriyorlov-1957@postgrespro.ru", "phone": "+70294010484"}
0005435270103	AEBFAC	6793 771022	ALEKSANDR MAKAROV	{"email": "makarov-a.23061968@postgrespro.ru", "phone": "+70682997359"}
0005435270104	BFF091	3931 822489	OLGA IVANOVA	{"phone": "+70151290843"}
0005435270105	421011	8417 870478	TATYANA NIKITINA	{"email": "nikitina-tatyana111964@postgrespro.ru", "phone": "+70292811487"}
0005435270106	81104C	6742 566646	IRINA RYABOVA	{"email": "ryabova_irina-27021975@postgrespro.ru", "phone": "+70507109625"}
0005435270107	BA1B0D	0950 431854	NIKOLAY PAVLOV	{"phone": "+70599796618"}
0005435270108	48BB39	0592 862113	ELENA YAKOVLEVA	{"phone": "+70727519490"}
0005435270109	EF31CA	6573 341202	NATALYA POPOVA	{"email": "popova-natalya.1972@postgrespro.ru", "phone": "+70674533148"}
0005435270110	6F7134	2764 573154	OKSANA LUKYANOVA	{"phone": "+70165826011"}
0005435270111	79C8FA	5288 767824	OLGA KOLESNIKOVA	{"email": "olgakolesnikova_1982@postgrespro.ru", "phone": "+70639623775"}
0005435270112	03CA2A	1558 097973	ANZHELIKA MAKSIMOVA	{"phone": "+70771931964"}
0005435270113	B41A7D	1417 709999	MARIYA ZAKHAROVA	{"phone": "+70483659211"}
0005435270114	419043	5554 129943	OLGA POLYAKOVA	{"email": "polyakovao.29081965@postgrespro.ru", "phone": "+70922949723"}
0005435270115	419043	9171 536785	MARINA MIKHAYLOVA	{"phone": "+70526364260"}
0005435270116	CC0DBC	0838 971457	ALEKSANDR ANDREEV	{"email": "a.andreev1976@postgrespro.ru", "phone": "+70792044338"}
0005435270117	CC0DBC	0025 065459	VLADIMIR BORISOV	{"email": "v_borisov25111962@postgrespro.ru", "phone": "+70418529687"}
0005435270118	434504	1935 882717	NIKOLAY AFANASEV	{"phone": "+70847520603"}
0005435270119	CB8704	7622 111175	VLADIMIR IVANOV	{"phone": "+70446666924"}
0005435270120	1D5EF4	6035 871335	TATYANA SMIRNOVA	{"email": "tatyana-smirnova.081997@postgrespro.ru", "phone": "+70138980845"}
0005435270121	1D5EF4	7183 656686	MIKHAIL POPOV	{"email": "popov.mikhail.30051978@postgrespro.ru", "phone": "+70664171017"}
0005435270122	1FD6E9	6181 752465	OLGA SMIRNOVA	{"phone": "+70924442848"}
0005435270123	F22582	7108 719286	YURIY SOROKIN	{"phone": "+70177250976"}
0005435270124	287982	4563 434333	OLEG SOLOVEV	{"phone": "+70467306752"}
0005435270125	5CD8F4	8073 179542	VIKTOR MIRONOV	{"phone": "+70564330266"}
0005435270126	79D58E	5204 654108	MADINA KOZLOVA	{"phone": "+70941937573"}
0005435270127	79D58E	3575 787502	VERA NOVIKOVA	{"phone": "+70337572809"}
0005435270128	B9844C	2235 884370	VALERIY EGOROV	{"phone": "+70079320175"}
0005435270129	C06105	3768 736729	OLGA NESTEROVA	{"phone": "+70217904830"}
0005435270130	1C23CA	4915 710372	ANDREY ANDREEV	{"phone": "+70359148646"}
0005435270131	11E617	5691 994290	ANATOLIY FROLOV	{"phone": "+70774741556"}
0005435270132	11E617	0410 086727	BORIS GAVRILOV	{"phone": "+70703177895"}
0005435270133	6316B0	8751 717382	VIKTORIYA KUZNECOVA	{"phone": "+70225643437"}
0005435270134	C0B7EF	2718 747379	ANDREY EGOROV	{"phone": "+70173284969"}
0005435270135	C0B7EF	8473 017735	PETR ZAYCEV	{"phone": "+70978670316"}
0005435270136	565C2D	3366 553985	PAVEL FEDOROV	{"phone": "+70271658164"}
0005435270137	565C2D	0208 952368	ANNA ISAEVA	{"email": "isaeva_a-111957@postgrespro.ru", "phone": "+70628067345"}
0005435270138	565C2D	1211 891205	IVAN ANDREEV	{"phone": "+70177454195"}
0005435270139	25EB0C	3492 093045	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr.16041985@postgrespro.ru", "phone": "+70812463203"}
0005435270140	25EB0C	0470 033458	ELENA ZAKHAROVA	{"phone": "+70950727764"}
0005435270141	25EB0C	9427 946060	SVETLANA POTAPOVA	{"phone": "+70358237520"}
0005435270142	3CF9A2	8456 389289	DMITRIY KOZLOV	{"email": "kozlov_dmitriy-011968@postgrespro.ru", "phone": "+70294462628"}
0005435270143	3CF9A2	7777 639785	VITALIY ALEKSEEV	{"email": "valekseev091972@postgrespro.ru", "phone": "+70448465303"}
0005435270144	AB6172	3422 699823	SVETLANA PETROVA	{"phone": "+70859888411"}
0005435270145	AB6172	4012 139767	ANTON VASILEV	{"email": "vasilev_anton.1977@postgrespro.ru", "phone": "+70545917530"}
0005435270146	0DA80A	0654 626124	ALENA KISELEVA	{"phone": "+70732261482"}
0005435270147	358A29	3902 100310	ELENA IVANOVA	{"email": "ivanovaelena.1963@postgrespro.ru", "phone": "+70965191425"}
0005435270148	8269D0	8348 500313	OLGA ZOTOVA	{"email": "olga-zotova1960@postgrespro.ru", "phone": "+70272087063"}
0005435270149	8269D0	6440 874806	KSENIYA FILATOVA	{"email": "kseniya.filatova.17111975@postgrespro.ru", "phone": "+70481372082"}
0005435270150	C63075	8749 743686	ALEKSEY NOVIKOV	{"email": "novikov.a_1981@postgrespro.ru", "phone": "+70313008779"}
0005435270151	CCB248	1075 687841	VIKTOR FOMIN	{"email": "fomin.viktor_19071966@postgrespro.ru", "phone": "+70697220458"}
0005435270152	CCB248	8267 580520	VYACHESLAV SEMENOV	{"phone": "+70931193177"}
0005435270153	EB34F1	7954 296895	LARISA NIKOLAEVA	{"phone": "+70369194285"}
0005435270154	72541D	0933 856506	ANDREY GUSEV	{"email": "a_gusev.09071969@postgrespro.ru", "phone": "+70063552763"}
0005435270155	D5C1B8	5259 225708	PAVEL NIKITIN	{"email": "pavel_nikitin-1975@postgrespro.ru", "phone": "+70436427211"}
0005435270156	177369	6144 541813	YURIY BARANOV	{"email": "yuriy-baranov.031984@postgrespro.ru", "phone": "+70296963008"}
0005435270157	177369	3466 898546	VLADIMIR MOROZOV	{"phone": "+70371797181"}
0005435270158	EFC885	6582 681528	ANASTASIYA GORBUNOVA	{"email": "gorbunova_anastasiya_13011966@postgrespro.ru", "phone": "+70827913873"}
0005435270159	015753	6358 224897	TAMARA MOISEEVA	{"email": "moiseeva-t011965@postgrespro.ru", "phone": "+70454246978"}
0005435270160	A55530	1657 839908	GEORGIY DAVYDOV	{"email": "georgiydavydov.041985@postgrespro.ru", "phone": "+70188973005"}
0005435270161	022AEB	7838 599593	KIRILL KAZAKOV	{"phone": "+70965926099"}
0005435270162	E24DE7	1472 973001	ALEKSANDR KARPOV	{"email": "aleksandr.karpov051966@postgrespro.ru", "phone": "+70596649032"}
0005435270163	E24DE7	9330 967488	RIMMA IVANOVA	{"email": "rimma.ivanova-1962@postgrespro.ru", "phone": "+70374222926"}
0005435270164	1E6B36	6694 622527	LYUDMILA ROMANOVA	{"phone": "+70776948507"}
0005435270165	868BEA	7968 778793	YULIYA ZAYCEVA	{"phone": "+70533775024"}
0005435270166	D0B73C	9061 233341	ALEKSEY BONDARENKO	{"email": "bondarenko-aleksey-26111973@postgrespro.ru", "phone": "+70062317397"}
0005435270167	02964F	9246 054223	ANTON FEDOROV	{"phone": "+70699757262"}
0005435270168	02964F	5244 044052	VYACHESLAV DAVYDOV	{"phone": "+70180681294"}
0005435270169	CD85A1	0560 504312	EVGENIY TIKHONOV	{"phone": "+70706578752"}
0005435270170	E5A194	1455 408634	VASILIY ISAEV	{"email": "vasiliy.isaev101969@postgrespro.ru", "phone": "+70489568167"}
0005435270171	E5A194	5874 050304	EKATERINA OSIPOVA	{"email": "e-osipova.121972@postgrespro.ru", "phone": "+70051436661"}
0005435270172	0A5FB2	5255 575102	YANA CHERNOVA	{"phone": "+70425805246"}
0005435270173	A68E2C	7631 403125	KONSTANTIN FILIPPOV	{"email": "filippov_k-07091975@postgrespro.ru", "phone": "+70111132282"}
0005435270174	8969FB	0523 774815	NATALYA SMIRNOVA	{"phone": "+70510319852"}
0005435270175	CD74A0	8631 601317	KONSTANTIN KOZLOV	{"email": "k.kozlov_23021975@postgrespro.ru", "phone": "+70696831327"}
0005435270176	CD74A0	7808 340474	VYACHESLAV FEDOTOV	{"email": "v_fedotov_091988@postgrespro.ru", "phone": "+70087526004"}
0005435270177	319621	0330 477381	IVAN TIKHONOV	{"email": "i_tikhonov_091974@postgrespro.ru", "phone": "+70611241588"}
0005435270178	E5C5CD	3936 632034	KONSTANTIN STEPANOV	{"phone": "+70852299093"}
0005435270179	E5C5CD	9474 891160	ANNA MOROZOVA	{"email": "annamorozova_17091978@postgrespro.ru", "phone": "+70052548801"}
0005435270180	3C4BF7	3164 118236	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-23031972@postgrespro.ru", "phone": "+70285455323"}
0005435270181	3C4BF7	0938 454957	ALEKSANDR VASILEV	{"email": "a.vasilev-121974@postgrespro.ru", "phone": "+70509754282"}
0005435270182	EB75AE	6317 562743	ILMIRA FADEEVA	{"email": "fadeevailmira041966@postgrespro.ru", "phone": "+70242997236"}
0005435270183	358502	6346 104844	VALENTINA SERGEEVA	{"email": "v-sergeeva_011984@postgrespro.ru", "phone": "+70012598119"}
0005435270184	358502	5385 286933	SERGEY VOROBEV	{"email": "sergeyvorobev.1972@postgrespro.ru", "phone": "+70650647705"}
0005435270185	7C794A	3449 892688	ILYA BARANOV	{"phone": "+70252019316"}
0005435270186	CD341C	4950 214226	ANNA ZHUKOVA	{"email": "anna.zhukova_18021975@postgrespro.ru", "phone": "+70640765245"}
0005435270187	C972F1	9058 225156	ALEKSEY ROMANOV	{"phone": "+70627537822"}
0005435270188	A6DE47	9224 036970	NINA GUSEVA	{"email": "gusevanina_1993@postgrespro.ru", "phone": "+70766396431"}
0005435270189	A6DE47	9190 929642	NATALYA ORLOVA	{"email": "orlovan.121968@postgrespro.ru", "phone": "+70173405046"}
0005435270190	A6DE47	7843 608097	ANATOLIY PETROV	{"phone": "+70348980348"}
0005435270191	CB2B5B	2546 003146	FEDOR POPOV	{"phone": "+70082548413"}
0005435270192	CB2B5B	7779 554197	VALENTINA VOLKOVA	{"email": "volkova.valentina.1960@postgrespro.ru", "phone": "+70073115286"}
0005435270193	AF907A	4578 023204	SERGEY KRASNOV	{"phone": "+70234846248"}
0005435270194	4A38B6	2577 061760	DMITRIY ZHUKOV	{"email": "zhukov-dmitriy-24111969@postgrespro.ru", "phone": "+70001275737"}
0005435270195	4A38B6	5384 736753	IVAN KUZMIN	{"phone": "+70423963301"}
0005435270196	BA38B8	1931 869073	ANDREY SERGEEV	{"phone": "+70754051697"}
0005435270197	EF5F09	9698 307198	EVGENIYA GRISHINA	{"email": "evgeniya.grishina.061978@postgrespro.ru", "phone": "+70613639259"}
0005435270198	EF5F09	4105 778039	IRINA LEBEDEVA	{"phone": "+70127049547"}
0005435270199	F8F947	6774 691962	ZOYA MIRONOVA	{"email": "zoya-mironova.02121985@postgrespro.ru", "phone": "+70535748101"}
0005435270200	6792C3	8923 844669	ANNA ANDREEVA	{"phone": "+70137419468"}
0005435270201	10F265	9381 790630	VIKTORIYA EGOROVA	{"phone": "+70296128028"}
0005435270202	34A433	3724 492150	ALEKSEY SOROKIN	{"email": "aleksey.sorokin-101964@postgrespro.ru", "phone": "+70491926344"}
0005435270203	34A433	2656 088840	PAVEL ZHURAVLEV	{"phone": "+70959527251"}
0005435270204	F5634F	2491 156653	ELENA SIDOROVA	{"phone": "+70647553622"}
0005435270205	E2E7DE	3610 350315	VLADIMIR KISELEV	{"phone": "+70284232493"}
0005435270206	E2E7DE	2051 207960	NATALYA POLYAKOVA	{"email": "npolyakova_1964@postgrespro.ru", "phone": "+70040405070"}
0005435270207	CA6514	1060 655077	ALEKSANDR ROMANOV	{"email": "a-romanov-081964@postgrespro.ru", "phone": "+70904170202"}
0005435270208	132FC2	1442 769489	LYUDMILA ANISIMOVA	{"phone": "+70565959912"}
0005435270209	132FC2	5565 337040	MIKHAIL VLASOV	{"phone": "+70681860172"}
0005435270210	EFF589	8411 433622	ARTEM POPOV	{"email": "a_popov05041969@postgrespro.ru", "phone": "+70795617941"}
0005435270211	3582C7	9048 625639	YURIY TIKHONOV	{"email": "y-tikhonov.111974@postgrespro.ru", "phone": "+70782852337"}
0005435270212	3582C7	3285 672860	ALEVTINA DANILOVA	{"phone": "+70399024526"}
0005435270213	04F78D	1596 344674	NIKOLAY SCHERBAKOV	{"phone": "+70465576648"}
0005435270214	ACE593	5124 657532	ANASTASIYA SMIRNOVA	{"email": "smirnovaanastasiya10091968@postgrespro.ru", "phone": "+70055573203"}
0005435270215	074E48	4870 010417	VITALIY OSIPOV	{"email": "osipov_v_30111981@postgrespro.ru", "phone": "+70181279586"}
0005435270216	074E48	1195 133598	VIKTORIYA GORBUNOVA	{"phone": "+70450624703"}
0005435270217	5E0F03	4012 010369	LYUDMILA ISAEVA	{"email": "isaeva-l.1975@postgrespro.ru", "phone": "+70527400375"}
0005435270218	7E23D4	3630 244770	TATYANA SOKOLOVA	{"email": "sokolovat-03071973@postgrespro.ru", "phone": "+70076822119"}
0005435270220	BB071E	0740 704111	NATALYA BELYAEVA	{"phone": "+70102794338"}
0005435270221	BB071E	7592 124388	NIKOLAY VASILEV	{"email": "vasilev.n-071975@postgrespro.ru", "phone": "+70296077329"}
0005435270222	618926	8606 618353	MIKHAIL PAVLOV	{"phone": "+70390003382"}
0005435270223	EBF92E	4332 349803	NINA VOLKOVA	{"phone": "+70490502948"}
0005435270224	41EDE7	5501 597726	ANISA SERGEEVA	{"phone": "+70464338018"}
0005435270225	41EDE7	2902 122144	MARINA STEPANOVA	{"phone": "+70301909463"}
0005435270226	41EDE7	2908 066532	ALEKSANDR KUZNECOV	{"phone": "+70723851323"}
0005435270227	352638	5963 725010	VARVARA IVANOVA	{"email": "vivanova-20081968@postgrespro.ru", "phone": "+70866085182"}
0005435270228	352638	1337 729458	ARTEM KARPOV	{"phone": "+70305265798"}
0005435270229	352638	7410 725789	NIKOLAY MARTYNOV	{"phone": "+70592646867"}
0005435282232	21428F	3101 264434	KLAVDIYA VASILEVA	{"phone": "+70679275129"}
0005435282049	D9151E	9160 311755	VLADIMIR MARTYNOV	{"phone": "+70373954327"}
0005435282050	1EA161	9779 786003	EVGENIY FEDOTOV	{"email": "e.fedotov.021984@postgrespro.ru", "phone": "+70927281365"}
0005435282051	E77F26	9288 098765	ROMAN NIKITIN	{"email": "nikitinroman.21101970@postgrespro.ru", "phone": "+70560730614"}
0005435282052	0B7B6F	2731 572802	OKSANA MIRONOVA	{"email": "oksana.mironova071976@postgrespro.ru", "phone": "+70022246932"}
0005435282053	A91D57	9945 128987	NINA PETROVA	{"phone": "+70313988289"}
0005435282054	20DE8E	9082 251809	DARYA SAVELEVA	{"phone": "+70954677402"}
0005435282055	6E32A3	8384 187380	NIKOLAY VASILEV	{"phone": "+70718966910"}
0005435282056	6E32A3	9272 593860	KIRILL ZAYCEV	{"phone": "+70594469387"}
0005435282057	EE0425	6830 490472	YURIY KRASNOV	{"phone": "+70771748726"}
0005435282058	EE0425	3353 503366	NATALYA NAUMOVA	{"phone": "+70136457152"}
0005435282059	02709C	3999 696551	ALEKSANDR PAVLOV	{"email": "pavlova.111964@postgrespro.ru", "phone": "+70128493838"}
0005435282060	02709C	4639 863478	SVETLANA KALININA	{"email": "s_kalinina_1968@postgrespro.ru", "phone": "+70626683679"}
0005435282061	02709C	1125 915258	OLEG KONOVALOV	{"phone": "+70514554346"}
0005435282062	C42F17	6864 698721	SERGEY SHEVCHENKO	{"phone": "+70648546823"}
0005435282063	C42F17	1858 829711	EVGENIYA MARTYNOVA	{"email": "martynovaevgeniya-1979@postgrespro.ru", "phone": "+70707965931"}
0005435282064	5AE99F	2027 197945	NINA EGOROVA	{"email": "egorova_nina091973@postgrespro.ru", "phone": "+70436931756"}
0005435282065	1F2AD9	7339 237087	VLADISLAV KUZNECOV	{"email": "kuznecov-v.1984@postgrespro.ru", "phone": "+70058812296"}
0005435282066	A1AC34	0642 266194	LIDIYA KISELEVA	{"email": "kiseleva_l-17021976@postgrespro.ru", "phone": "+70067415549"}
0005435282067	36FDF4	9557 067566	EVGENIYA OVCHINNIKOVA	{"email": "ovchinnikova.e_101969@postgrespro.ru", "phone": "+70332384824"}
0005435282068	295F5A	9459 453760	TATYANA BARANOVA	{"phone": "+70380224298"}
0005435282069	EBAC84	9023 940029	NIKOLAY KUDRYASHOV	{"email": "n_kudryashov021961@postgrespro.ru", "phone": "+70549901249"}
0005435282070	90F704	9749 568226	TATYANA TITOVA	{"phone": "+70360130671"}
0005435282071	937DF7	7300 057068	ELENA NESTEROVA	{"phone": "+70068962613"}
0005435282072	EF2EEB	5417 307470	ALEKSANDR STEPANOV	{"email": "astepanov.26051969@postgrespro.ru", "phone": "+70702848927"}
0005435282073	1B40BB	2299 024422	GALINA ABRAMOVA	{"email": "g.abramova061979@postgrespro.ru", "phone": "+70296882017"}
0005435282074	1B40BB	4395 680406	MARIYA ALEKSANDROVA	{"email": "aleksandrova_mariya-061971@postgrespro.ru", "phone": "+70857340295"}
0005435282075	2E5552	0514 624014	ALEKSANDR FEDOTOV	{"phone": "+70927177545"}
0005435282076	1EBF22	2798 504843	LYUBOV NESTEROVA	{"email": "l.nesterova091981@postgrespro.ru", "phone": "+70491868971"}
0005435282077	1EBF22	2534 059231	DMITRIY BELOV	{"email": "dmitriy_belov-121975@postgrespro.ru", "phone": "+70159045183"}
0005435282078	67780D	7375 340097	DMITRIY NOVIKOV	{"email": "novikovdmitriy.11041987@postgrespro.ru", "phone": "+70061188164"}
0005435282079	B939A3	5170 575503	ANDREY FEDOROV	{"email": "a.fedorov-31081980@postgrespro.ru", "phone": "+70327224805"}
0005435282080	5546F7	0195 651189	DARYA PETROVA	{"phone": "+70913184748"}
0005435282081	5546F7	1978 260929	DMITRIY GERASIMOV	{"email": "gerasimov.dmitriy_01011968@postgrespro.ru", "phone": "+70396521880"}
0005435282082	AA0FAC	9912 553160	EKATERINA KUZMINA	{"email": "kuzmina_ekaterina-1960@postgrespro.ru", "phone": "+70198784240"}
0005435282083	16AFF3	3130 054571	EKATERINA RYABOVA	{"email": "ekaterina_ryabova_26101971@postgrespro.ru", "phone": "+70836918668"}
0005435282084	C67B58	8081 232563	ALEKSANDRA SCHERBAKOVA	{"email": "scherbakovaaleksandra_1967@postgrespro.ru", "phone": "+70092525282"}
0005435282085	C67B58	8673 819151	NATALYA NESTEROVA	{"email": "nesterovanatalya-29061981@postgrespro.ru", "phone": "+70506263686"}
0005435282086	EC2FD6	2640 897431	DMITRIY NAUMOV	{"phone": "+70087142860"}
0005435282087	3DF1B8	2466 889911	YURIY SERGEEV	{"email": "sergeev.yuriy.101978@postgrespro.ru", "phone": "+70430748411"}
0005435282088	3DF1B8	6083 534236	SERGEY MAKAROV	{"email": "s_makarov_011978@postgrespro.ru", "phone": "+70692538557"}
0005435282089	96CB75	8314 505323	ANTON NIKOLAEV	{"email": "anton.nikolaev.17051971@postgrespro.ru", "phone": "+70256037292"}
0005435282090	CFC200	4735 342301	BOGDAN AFANASEV	{"email": "bafanasev-14041963@postgrespro.ru", "phone": "+70737350822"}
0005435282091	A28AB3	2371 726186	MARGARITA FEDOROVA	{"email": "fedorova_m.07121975@postgrespro.ru", "phone": "+70893658238"}
0005435282092	A28AB3	4956 676802	ALEKSANDR SEMENOV	{"email": "aleksandrsemenov.1972@postgrespro.ru", "phone": "+70206253758"}
0005435282093	BAE5B3	0216 959504	EVGENIY GORBUNOV	{"email": "evgeniy_gorbunov.1963@postgrespro.ru", "phone": "+70534158689"}
0005435282094	FE7E18	3887 462721	VLADIMIR FEDOROV	{"phone": "+70447144241"}
0005435282095	FE7E18	8915 142110	VALERIYA ZAKHAROVA	{"email": "zakharova_valeriya-1974@postgrespro.ru", "phone": "+70332972119"}
0005435282096	004BC5	3419 536285	SVETLANA LEBEDEVA	{"email": "svetlana-lebedeva1972@postgrespro.ru", "phone": "+70778236352"}
0005435282097	D205C7	8166 585982	MAKSIM SIDOROV	{"email": "msidorov.081978@postgrespro.ru", "phone": "+70696824282"}
0005435282098	575036	9145 374694	MAKSIM ORLOV	{"email": "orlov_m.121985@postgrespro.ru", "phone": "+70031233347"}
0005435282099	575036	7300 432334	ELENA YUDINA	{"phone": "+70616264313"}
0005435282100	575036	3960 772195	STEPAN NAUMOV	{"email": "naumov.stepan-15071991@postgrespro.ru", "phone": "+70951935678"}
0005435282101	F153CA	3551 311263	ALEKSANDR BORISOV	{"email": "borisov-aleksandr051974@postgrespro.ru", "phone": "+70210383670"}
0005435282102	CD907D	9368 853639	NATALYA MOROZOVA	{"email": "natalya_morozova_1986@postgrespro.ru", "phone": "+70457433643"}
0005435282103	F4C527	4766 640478	AMIR DENISOV	{"phone": "+70282352047"}
0005435282104	25E722	8634 282827	ALIYA NESTEROVA	{"email": "a_nesterova081982@postgrespro.ru", "phone": "+70838529241"}
0005435282105	F38E96	6479 305920	GENNADIY MATVEEV	{"email": "g.matveev_26021973@postgrespro.ru", "phone": "+70677223673"}
0005435282106	F38E96	9064 314512	TATYANA RYABOVA	{"email": "ryabova-t-14031965@postgrespro.ru", "phone": "+70458301686"}
0005435282107	9881D8	7822 310189	YULIYA MASLOVA	{"phone": "+70660591529"}
0005435282108	4A6D6A	9690 462965	VIKTOR IVANOV	{"phone": "+70180265598"}
0005435282109	455F73	1042 650234	IVAN FEDOROV	{"email": "ivan.fedorov_1966@postgrespro.ru", "phone": "+70262516040"}
0005435282110	455F73	4012 681725	LILIYA KRASNOVA	{"email": "krasnovaliliya1963@postgrespro.ru", "phone": "+70211473583"}
0005435282111	2AE99F	4968 693042	SERGEY GAVRILOV	{"email": "gavrilov_s-1975@postgrespro.ru", "phone": "+70580817435"}
0005435282112	185714	0428 985754	SERGEY NAZAROV	{"email": "snazarov_111973@postgrespro.ru", "phone": "+70962666001"}
0005435282113	185714	5824 047485	ILYA ZHURAVLEV	{"phone": "+70600010838"}
0005435282114	780BD4	4121 322313	EVDOKIYA CHERNOVA	{"phone": "+70878532941"}
0005435282115	582663	0733 570222	VYACHESLAV GRIGOREV	{"phone": "+70777487630"}
0005435282116	083F4F	0979 541587	DMITRIY MOISEEV	{"email": "moiseev.d.051963@postgrespro.ru", "phone": "+70632087100"}
0005435282117	25EB36	3338 495518	MIKHAIL IVANOV	{"phone": "+70691154025"}
0005435282118	E26628	2879 244359	GALINA ZAKHAROVA	{"email": "galina-zakharova-01081979@postgrespro.ru", "phone": "+70601425704"}
0005435282119	282EA4	5152 302480	VALENTINA VASILEVA	{"email": "v-vasileva081961@postgrespro.ru", "phone": "+70417846503"}
0005435282120	B856F2	1657 899275	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov27061963@postgrespro.ru", "phone": "+70615195407"}
0005435282121	1C25D5	1825 982992	NIKOLAY PETROV	{"phone": "+70761558198"}
0005435282122	846276	9825 864712	IRINA MALYSHEVA	{"phone": "+70844437080"}
0005435282123	CAB87A	8771 866082	VASILIY IVANOV	{"phone": "+70199127855"}
0005435282124	3865A9	8156 074000	MARINA EGOROVA	{"email": "marina-egorova071974@postgrespro.ru", "phone": "+70435073366"}
0005435282125	E89414	9561 233395	OLGA ROMANOVA	{"email": "romanovaolga-1974@postgrespro.ru", "phone": "+70268178402"}
0005435282126	E89414	9917 452791	OLGA NESTEROVA	{"phone": "+70262051265"}
0005435282127	7C833E	9681 055253	NIKOLAY RODIONOV	{"phone": "+70946829813"}
0005435282128	60DA6F	6435 091101	VALERIYA BELOVA	{"email": "belova.v01101978@postgrespro.ru", "phone": "+70867411263"}
0005435282129	60DA6F	4873 582866	OLGA SAVELEVA	{"phone": "+70877198271"}
0005435282130	9CC7B3	8426 707522	LYUDMILA ZAYCEVA	{"email": "zayceva_lyudmila.1971@postgrespro.ru", "phone": "+70633757054"}
0005435282131	84A983	1075 706710	NATALYA LEBEDEVA	{"email": "lebedeva.n_1982@postgrespro.ru", "phone": "+70276686394"}
0005435282132	BBA180	4562 114236	ALEKSEY ALEKSANDROV	{"phone": "+70273567480"}
0005435282133	FB32F3	0884 318808	VYACHESLAV MAKSIMOV	{"email": "maksimovvyacheslav041976@postgrespro.ru", "phone": "+70103548278"}
0005435282134	FB32F3	9111 424102	FEDOR FOMIN	{"email": "fedor.fomin-28061968@postgrespro.ru", "phone": "+70347677559"}
0005435282135	9B9058	1552 007644	GALINA KULIKOVA	{"email": "g_kulikova_011986@postgrespro.ru", "phone": "+70582566147"}
0005435282136	9B9058	3571 351751	LYUBOV BELYAEVA	{"phone": "+70474004677"}
0005435282137	9B9058	5095 621889	IRINA BARANOVA	{"phone": "+70359268384"}
0005435282138	3DBD78	0968 917717	MATVEY KISELEV	{"email": "mkiselev13091971@postgrespro.ru", "phone": "+70405085186"}
0005435282139	46BAB1	8537 026571	LILIYA STEPANOVA	{"phone": "+70828112463"}
0005435282140	9324B4	2110 753622	LYUDMILA EFREMOVA	{"phone": "+70944707714"}
0005435282141	9324B4	5858 215110	ANNA OVCHINNIKOVA	{"email": "ovchinnikova.a.061963@postgrespro.ru", "phone": "+70533192137"}
0005435282142	15FB62	9700 778524	RUSTEM ROMANOV	{"email": "romanov-rustem_1972@postgrespro.ru", "phone": "+70380648497"}
0005435282143	1F9E02	4486 296307	NIKOLAY ZHURAVLEV	{"email": "nikolay-zhuravlev_111963@postgrespro.ru", "phone": "+70712143097"}
0005435282144	BB82DF	3358 596585	NADEZHDA ISAEVA	{"email": "isaevanadezhda1972@postgrespro.ru", "phone": "+70628064301"}
0005435282145	BB82DF	5839 952476	NADEZHDA KISELEVA	{"email": "kiseleva_nadezhda_1971@postgrespro.ru", "phone": "+70501350441"}
0005435282146	BB82DF	1641 537080	ALEKSEY KAZAKOV	{"phone": "+70203398580"}
0005435282147	D8BAA6	2725 627934	VASILIY VASILEV	{"phone": "+70256487259"}
0005435282148	1B4A75	6478 343752	OLGA KARPOVA	{"phone": "+70670246835"}
0005435282149	CBE566	0122 685061	TATYANA OSIPOVA	{"phone": "+70741035156"}
0005435282150	4DF472	1191 032505	GEORGIY MELNIKOV	{"phone": "+70753348390"}
0005435282151	738D45	3936 999261	ANASTASIYA YUDINA	{"email": "anastasiya.yudina_041979@postgrespro.ru", "phone": "+70300477254"}
0005435282152	E79CF3	7448 508152	EVGENIY SMIRNOV	{"phone": "+70034366683"}
0005435282153	412445	6169 325554	NIKOLAY KISELEV	{"email": "kiselev-nikolay_1963@postgrespro.ru", "phone": "+70279483509"}
0005435282154	00DF13	0594 353137	SERGEY ALEKSEEV	{"phone": "+70686577779"}
0005435282155	CB8A5A	2200 729952	SVETLANA NESTEROVA	{"phone": "+70839217783"}
0005435282156	CB8A5A	0503 042931	TIMUR FILIPPOV	{"email": "filippov_t-12011970@postgrespro.ru", "phone": "+70797187671"}
0005435282157	491B09	1028 075357	NINA EFREMOVA	{"email": "efremova_n.111977@postgrespro.ru", "phone": "+70879654364"}
0005435282158	491B09	7105 023386	ALEKSEY IVANOV	{"email": "alekseyivanov.021974@postgrespro.ru", "phone": "+70975017832"}
0005435282159	491B09	9058 073287	NIKOLAY IVANOV	{"phone": "+70438521659"}
0005435282160	491B09	5303 856016	MARIYA MALYSHEVA	{"phone": "+70603315656"}
0005435282161	9831B3	3084 265598	IVAN BONDARENKO	{"email": "ivan_bondarenko_031968@postgrespro.ru", "phone": "+70378596136"}
0005435282162	693585	7299 487642	DMITRIY BONDARENKO	{"phone": "+70156814549"}
0005435282163	C5FF08	7727 328143	VIKTORIYA KOROLEVA	{"email": "v-koroleva-021965@postgrespro.ru", "phone": "+70207708430"}
0005435282164	E950CB	7867 354833	TATYANA FROLOVA	{"email": "tatyana.frolova-28011972@postgrespro.ru", "phone": "+70805315774"}
0005435282165	CA5D04	7410 349771	NATALYA KAZAKOVA	{"email": "kazakova.n.09031964@postgrespro.ru", "phone": "+70205453651"}
0005435282166	CA5D04	1091 877983	VALENTINA SMIRNOVA	{"email": "v_smirnova-1964@postgrespro.ru", "phone": "+70735231984"}
0005435282167	BD246A	3529 099483	ALEKSEY PAVLOV	{"phone": "+70359260165"}
0005435282168	686B1F	2148 478783	VERA ZHUKOVA	{"phone": "+70273081455"}
0005435282169	686B1F	3169 533518	TATYANA BORISOVA	{"phone": "+70790675615"}
0005435282170	D940FD	9369 285771	NATALIYA ZAKHAROVA	{"phone": "+70005123602"}
0005435282171	D940FD	0790 697347	IRINA SOKOLOVA	{"phone": "+70658964361"}
0005435282172	D940FD	3314 959123	VALERIY ABRAMOV	{"phone": "+70641780720"}
0005435282173	3BE051	9827 964933	NATALYA OSIPOVA	{"phone": "+70027855465"}
0005435282174	578802	7204 822631	TATYANA KONDRATEVA	{"phone": "+70950751634"}
0005435282175	572D75	2726 678767	ELENA ZAYCEVA	{"email": "zayceva.elena-30061972@postgrespro.ru", "phone": "+70366411808"}
0005435282176	572D75	2716 044069	VERA SIDOROVA	{"email": "v.sidorova-071977@postgrespro.ru", "phone": "+70223721890"}
0005435282177	214FC9	4086 414942	MATVEY MIRONOV	{"email": "matvey_mironov021977@postgrespro.ru", "phone": "+70268938928"}
0005435282178	214FC9	1175 055519	ANZHELIKA MOROZOVA	{"phone": "+70782680037"}
0005435282179	7B506C	9074 928833	LYUBOV NIKOLAEVA	{"phone": "+70347695984"}
0005435282180	4C51DD	1564 057741	NIKOLAY NIKITIN	{"phone": "+70479188168"}
0005435282181	4A394E	9330 466573	DENIS PETROV	{"email": "petrovdenis-061966@postgrespro.ru", "phone": "+70153773058"}
0005435282182	0A04E6	9172 664006	ROMAN VOROBEV	{"email": "r_vorobev-051969@postgrespro.ru", "phone": "+70059102113"}
0005435282183	153B33	0538 585756	VLADISLAV SMIRNOV	{"email": "vsmirnov-111977@postgrespro.ru", "phone": "+70653281814"}
0005435282184	CC1879	3194 027849	VLADISLAV OSIPOV	{"email": "vladislavosipov-14101975@postgrespro.ru", "phone": "+70112293128"}
0005435282185	CC1879	9452 913116	ELIZAVETA ALEKSEEVA	{"phone": "+70858230597"}
0005435282186	1DE127	2979 007408	LILIYA OVCHINNIKOVA	{"phone": "+70134389703"}
0005435282187	1DE127	0097 450207	MARK SHEVCHENKO	{"email": "shevchenko.m011974@postgrespro.ru", "phone": "+70737356551"}
0005435282188	E204D8	9326 488094	ALEKSANDR ANDREEV	{"phone": "+70246377241"}
0005435282189	E204D8	0377 896952	SERGEY NAUMOV	{"email": "s_naumov_07041968@postgrespro.ru", "phone": "+70756576321"}
0005435282190	2CFE6E	8507 190256	ALEKSEY KUZNECOV	{"phone": "+70455443587"}
0005435282191	2CFE6E	4327 538685	DARYA KOVALEVA	{"phone": "+70904508519"}
0005435282192	EE6BBB	0934 161357	YURIY FOMIN	{"email": "fomin_yuriy.02111957@postgrespro.ru", "phone": "+70312550805"}
0005435282193	FCF3C4	0787 914313	EVGENIYA BOGDANOVA	{"phone": "+70463184011"}
0005435282194	EF1014	4197 931701	ELENA ANISIMOVA	{"email": "anisimovaelena-05041963@postgrespro.ru", "phone": "+70670938832"}
0005435282195	EF1014	9826 585391	DENIS BARANOV	{"phone": "+70373236193"}
0005435282196	AB86DD	1428 777708	VITALIY IVANOV	{"email": "v-ivanov.26021977@postgrespro.ru", "phone": "+70588519725"}
0005435282197	AB86DD	6671 658578	DZHAMILYA NIKITINA	{"phone": "+70013841582"}
0005435282198	38DA7C	6649 309493	VLADIMIR FEDOROV	{"email": "v_fedorov_26071965@postgrespro.ru", "phone": "+70478951740"}
0005435282199	38DA7C	9278 748432	MARIYA NIKITINA	{"email": "mariya-nikitina_1982@postgrespro.ru", "phone": "+70516342273"}
0005435282200	D0026F	6649 729991	GALINA ANDREEVA	{"phone": "+70061057481"}
0005435282201	F9CF43	1454 101643	NATALYA KOVALEVA	{"email": "natalya-kovaleva.021976@postgrespro.ru", "phone": "+70975170770"}
0005435282202	8B1CB8	6960 434762	EVGENIY KARPOV	{"phone": "+70669874321"}
0005435282203	8B1CB8	5018 187630	KONSTANTIN ZAYCEV	{"phone": "+70672695779"}
0005435282204	9CF6AA	4268 358156	ANTONINA LOGINOVA	{"email": "loginova_a.1975@postgrespro.ru", "phone": "+70995758095"}
0005435282205	9CF6AA	6149 086625	TAMARA KULIKOVA	{"email": "tkulikova091969@postgrespro.ru", "phone": "+70190567762"}
0005435282206	11F23E	0360 713980	LILIYA FILIPPOVA	{"email": "l-filippova.091970@postgrespro.ru", "phone": "+70281208541"}
0005435282207	11F23E	5191 054885	ANTONINA DMITRIEVA	{"phone": "+70434147083"}
0005435282208	DAA5FA	0803 446719	KSENIYA ZAKHAROVA	{"email": "k-zakharova1962@postgrespro.ru", "phone": "+70200653589"}
0005435282209	491E8B	4630 481739	DENIS GUSEV	{"email": "denisgusev_1973@postgrespro.ru", "phone": "+70433907755"}
0005435282210	491E8B	4099 086842	NATALYA SAVELEVA	{"email": "saveleva.n_1963@postgrespro.ru", "phone": "+70009910364"}
0005435282211	BDBE04	3503 250865	DMITRIY IVANOV	{"phone": "+70780529136"}
0005435282212	B58B8F	7821 603821	TATYANA NOVIKOVA	{"email": "t_novikova_1969@postgrespro.ru", "phone": "+70435205527"}
0005435282213	3FD6E9	7437 041552	ELENA YUDINA	{"email": "elena.yudina_1966@postgrespro.ru", "phone": "+70525282037"}
0005435282214	09CB98	5290 659601	EVGENIYA EFREMOVA	{"email": "efremova-evgeniya_03091968@postgrespro.ru", "phone": "+70876182977"}
0005435282215	191575	3105 247780	OLGA VOLKOVA	{"email": "o.volkova-1957@postgrespro.ru", "phone": "+70503828700"}
0005435282216	191575	1790 559421	MARIYA MELNIKOVA	{"phone": "+70034679938"}
0005435282217	191575	4070 695587	VITALIY ZAYCEV	{"phone": "+70237630791"}
0005435282218	579AEC	3984 678255	EKATERINA ILINA	{"phone": "+70429519662"}
0005435282219	28DE18	0707 713464	IVAN NIKITIN	{"phone": "+70534554958"}
0005435282220	28DE18	0445 728445	TATYANA SAVELEVA	{"email": "t.saveleva1973@postgrespro.ru", "phone": "+70113520028"}
0005435282221	1EC3AA	9184 446201	ANDREY SOKOLOV	{"email": "sokolov_andrey18061966@postgrespro.ru", "phone": "+70845653408"}
0005435282222	1EC3AA	0974 220977	VASILIY NIKOLAEV	{"phone": "+70173872588"}
0005435282223	1EC3AA	2467 828505	NIKOLAY KOROLEV	{"email": "n.korolev26111965@postgrespro.ru", "phone": "+70996734888"}
0005435282224	1EC3AA	2216 177720	VLADIMIR ANTONOV	{"phone": "+70356713376"}
0005435282225	CA98F2	3836 196994	MIKHAIL MOROZOV	{"phone": "+70042945395"}
0005435282226	CA98F2	8423 910469	LIDIYA NESTEROVA	{"phone": "+70791527215"}
0005435282227	E210C4	4848 427729	VIKTOR SIDOROV	{"phone": "+70074451401"}
0005435282228	DF978F	2400 816386	DARYA LOGINOVA	{"email": "loginova_d.1979@postgrespro.ru", "phone": "+70526365240"}
0005435282229	A47D2F	8808 080879	DENIS ROMANOV	{"phone": "+70180780433"}
0005435282230	A47D2F	5850 030793	ELENA ZAYCEVA	{"email": "zayceva-e.1981@postgrespro.ru", "phone": "+70804327518"}
0005435282231	2CA752	1298 676812	ZULFIYA KAZAKOVA	{"email": "kazakovaz.021969@postgrespro.ru", "phone": "+70032003534"}
0005435282233	21428F	3655 732613	SERGEY FILIPPOV	{"email": "filippov_sergey28101961@postgrespro.ru", "phone": "+70311939567"}
0005435282234	D7BECE	7804 044401	SVETLANA SERGEEVA	{"phone": "+70168098149"}
0005435282235	48330D	6683 406957	NIKOLAY TIKHONOV	{"phone": "+70641799476"}
0005435282236	448544	9513 892162	EKATERINA KUZNECOVA	{"phone": "+70313989294"}
0005435282237	11CCEF	2763 180563	PETR GRIGOREV	{"email": "grigorev_p-1981@postgrespro.ru", "phone": "+70699332209"}
0005435282238	EFA229	0196 159525	EVGENIY STEPANOV	{"email": "e-stepanov17031971@postgrespro.ru", "phone": "+70708121886"}
0005435282239	9A3C32	4897 940001	VALENTINA SIDOROVA	{"email": "sidorova_valentina.111973@postgrespro.ru", "phone": "+70664436749"}
0005435282240	9A3C32	2906 873717	KLAVDIYA DAVYDOVA	{"phone": "+70858333426"}
0005435282241	296506	9185 691702	SERGEY ISAEV	{"phone": "+70132654902"}
0005435282242	FB9128	7506 992453	ALEKSANDR KULIKOV	{"phone": "+70445448784"}
0005435282243	7BB176	9223 636141	PETR MOISEEV	{"phone": "+70644452860"}
0005435282244	7BB176	3076 131898	VIKTOR FEDOROV	{"phone": "+70204189971"}
0005435282245	63CFB2	4335 996234	VLADIMIR DENISOV	{"email": "denisov-v031963@postgrespro.ru", "phone": "+70315520692"}
0005435282246	899484	8292 126324	OLGA SAVELEVA	{"phone": "+70182014142"}
0005435282247	92C08D	4620 669712	VALENTINA FILIPPOVA	{"phone": "+70902418907"}
0005435282248	A19C23	6415 234062	SERGEY IVANOV	{"email": "ivanov-sergey_111969@postgrespro.ru", "phone": "+70782067502"}
0005435282249	EE9BC6	8284 858430	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.09071978@postgrespro.ru", "phone": "+70614251307"}
0005435282250	EE9BC6	4775 562674	SOFYA RODIONOVA	{"phone": "+70527331982"}
0005435282251	2A7838	9049 300399	ALEKSANDR KUZNECOV	{"phone": "+70378455215"}
0005435282252	2A7838	1074 719378	ANTONINA NOVIKOVA	{"phone": "+70220074679"}
0005435282253	D3567F	1305 933149	NATALYA CHERNOVA	{"phone": "+70952873811"}
0005435282254	1F97AF	3237 236195	ZINAIDA OSIPOVA	{"email": "zinaidaosipova_30041975@postgrespro.ru", "phone": "+70335379205"}
0005435282255	5DC735	0881 151275	ALEKSEY MOISEEV	{"phone": "+70922680562"}
0005435282256	6EA272	5400 840269	NATALYA LOGINOVA	{"phone": "+70443819409"}
0005435282257	6EA272	9739 889288	MARINA TIKHONOVA	{"phone": "+70921277037"}
0005435282258	6EA272	4533 698518	EVGENIY FOMIN	{"email": "e.fomin02111986@postgrespro.ru", "phone": "+70614737120"}
0005435282259	896FE2	3581 152610	IGOR FOMIN	{"phone": "+70063372530"}
0005435282260	896FE2	4475 603346	VLADIMIR IVANOV	{"phone": "+70044972821"}
0005435282261	5110D9	2667 879839	DANILA POPOV	{"email": "popovd.03051974@postgrespro.ru", "phone": "+70146173144"}
0005435282262	290550	2269 801241	ANASTASIYA TIMOFEEVA	{"email": "timofeeva-anastasiya_051979@postgrespro.ru", "phone": "+70991705997"}
0005435282263	1C6424	9970 488469	LYUDMILA POLYAKOVA	{"phone": "+70978381807"}
0005435282264	1C6424	7999 328617	GALINA GUSEVA	{"email": "g-guseva-26031974@postgrespro.ru", "phone": "+70179490437"}
0005435282265	280059	2627 832111	NIKOLAY KUZMIN	{"phone": "+70710135842"}
0005435282266	018018	7000 067984	OLGA NAZAROVA	{"email": "olga.nazarova_21011975@postgrespro.ru", "phone": "+70112205213"}
0005435282267	018018	8505 777011	NINA KONOVALOVA	{"phone": "+70432790935"}
0005435282268	FF9983	0295 962490	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.a04011977@postgrespro.ru", "phone": "+70959168465"}
0005435282269	6A858F	4176 831704	OLGA KALININA	{"email": "kalinina-o-1967@postgrespro.ru", "phone": "+70504616355"}
0005435282270	6A858F	7515 038891	MARINA KOZLOVA	{"email": "kozlovam_19021974@postgrespro.ru", "phone": "+70133698563"}
0005435282271	BA62AC	3019 976869	DMITRIY MELNIKOV	{"phone": "+70060383104"}
0005435282272	63282D	9603 003545	MARIYA FILATOVA	{"phone": "+70789420118"}
0005435282273	63282D	9923 564064	VIKTOR MATVEEV	{"phone": "+70639710229"}
0005435282274	936DC1	8114 242257	LYUBOV VOLKOVA	{"email": "volkova-lyubov_101963@postgrespro.ru", "phone": "+70944211426"}
0005435282275	7A0535	0404 285027	IRINA PETROVA	{"email": "petrova-irina-06041973@postgrespro.ru", "phone": "+70633976621"}
0005435282276	8BA7D2	7353 222149	SERGEY KULIKOV	{"email": "kulikov-sergey01021973@postgrespro.ru", "phone": "+70417823942"}
0005435282277	E05C86	5074 331329	NATALYA DANILOVA	{"phone": "+70438250625"}
0005435282278	8E4BDC	4150 517466	ELENA CHERNOVA	{"phone": "+70205507860"}
0005435282279	E98FF6	2918 471751	ANZHELIKA RYABOVA	{"phone": "+70080233042"}
0005435282280	28BF0C	0398 471820	VIKTOR NIKITIN	{"email": "nikitinv_111973@postgrespro.ru", "phone": "+70275505775"}
0005435282281	28BF0C	2241 711905	SVETLANA POPOVA	{"phone": "+70247192532"}
0005435282282	284A0F	4291 370226	VIKTORIYA GRISHINA	{"email": "grishina-viktoriya_1968@postgrespro.ru", "phone": "+70818211410"}
0005435282283	284A0F	1283 874844	NINA KRASNOVA	{"phone": "+70946052858"}
0005435282284	AD2BE0	4143 934305	YURIY GERASIMOV	{"phone": "+70777767764"}
0005435282285	9921AB	2100 297096	STANISLAV ABRAMOV	{"email": "abramov-s-1962@postgrespro.ru", "phone": "+70139106241"}
0005435282286	00BC84	5951 436244	LYUDMILA ANTONOVA	{"phone": "+70874203669"}
0005435282287	083E74	5100 229071	GENNADIY SHEVCHENKO	{"phone": "+70264498266"}
0005435282288	803F41	6366 697703	TATYANA SERGEEVA	{"phone": "+70686001375"}
0005435282289	2C4055	1353 991526	BORIS VOLKOV	{"email": "volkov.b051971@postgrespro.ru", "phone": "+70399772186"}
0005435282290	2C4055	5435 458837	TAMARA NESTEROVA	{"email": "nesterovat17051965@postgrespro.ru", "phone": "+70000567459"}
0005435282291	03460D	2082 392691	SVETLANA LEBEDEVA	{"phone": "+70978345891"}
0005435282292	8DCF41	4628 129981	VIKTOR BELOV	{"phone": "+70076845947"}
0005435282293	04816B	8926 553033	VASILIY POPOV	{"email": "vasiliypopov_1963@postgrespro.ru", "phone": "+70731727705"}
0005435282294	92FD79	3378 444078	ANDREY ZAKHAROV	{"email": "zakharovandrey_061971@postgrespro.ru", "phone": "+70983559991"}
0005435282295	92FD79	1226 695601	EVGENIY KUZNECOV	{"phone": "+70802754572"}
0005435282356	0858F1	4243 817583	ANNA MOISEEVA	{"phone": "+70968047743"}
0005435282296	82AE53	9995 554031	MIKHAIL VOLKOV	{"email": "mikhailvolkov-25041973@postgrespro.ru", "phone": "+70579981415"}
0005435282297	FFF2E9	1809 076306	ALEKSANDR NAZAROV	{"phone": "+70716381143"}
0005435282298	21F165	9478 111461	TAMARA ANTONOVA	{"phone": "+70398831402"}
0005435282299	C16B20	1185 531884	ANNA KUZNECOVA	{"email": "kuznecova.a-22101978@postgrespro.ru", "phone": "+70554285721"}
0005435282300	C16B20	1609 272498	VIKTOR IVANOV	{"email": "v.ivanov01091963@postgrespro.ru", "phone": "+70169602873"}
0005435282301	E30EB5	1037 950939	TATYANA NIKITINA	{"email": "t.nikitina_13041970@postgrespro.ru", "phone": "+70262705454"}
0005435282302	4C315A	3009 875086	TATYANA ROMANOVA	{"email": "t_romanova-1974@postgrespro.ru", "phone": "+70091115701"}
0005435282303	4C315A	6184 863209	KIRILL BORISOV	{"email": "k_borisov_061971@postgrespro.ru", "phone": "+70832399284"}
0005435282304	456349	5031 691313	GLEB DMITRIEV	{"email": "dmitrievgleb041973@postgrespro.ru", "phone": "+70391375922"}
0005435282305	456349	6456 811903	ANNA VOLKOVA	{"phone": "+70331432149"}
0005435282306	456349	9452 505582	GRIGORIY POPOV	{"phone": "+70117751760"}
0005435282307	1343E2	7133 211000	ALEKSEY VASILEV	{"email": "aleksey.vasilev.1976@postgrespro.ru", "phone": "+70266694876"}
0005435282308	1343E2	1147 750963	ELENA KALININA	{"phone": "+70740848011"}
0005435282309	D96C6F	5588 106712	ILYA TIKHONOV	{"phone": "+70349113331"}
0005435282310	DC2962	2889 070287	ILYA RODIONOV	{"phone": "+70942549848"}
0005435282311	393820	8001 344765	ANASTASIYA YUDINA	{"email": "yudinaanastasiya.18011977@postgrespro.ru", "phone": "+70405221961"}
0005435282312	67B8CD	0900 476204	ALEKSEY PETROV	{"phone": "+70942774479"}
0005435282313	EF1074	8011 441248	YURIY SOKOLOV	{"email": "y.sokolov_20091968@postgrespro.ru", "phone": "+70128582214"}
0005435282314	C2B5AA	6355 556504	OLEG VASILEV	{"phone": "+70765048528"}
0005435282315	C2B5AA	4020 700241	DMITRIY IVANOV	{"email": "ivanov-d-1969@postgrespro.ru", "phone": "+70978101989"}
0005435282316	A9BF8D	6109 173686	VIKTORIYA LAZAREVA	{"email": "lazareva-viktoriya121966@postgrespro.ru", "phone": "+70297249653"}
0005435282317	C0B03D	0509 372809	VYACHESLAV VOROBEV	{"phone": "+70972821407"}
0005435282318	FCF591	1162 711899	ARTUR POPOV	{"phone": "+70511788241"}
0005435282319	FCF591	8829 075246	ALEKSANDR KOZLOV	{"phone": "+70584732565"}
0005435282320	FCF591	4114 841999	VLADIMIR SOLOVEV	{"email": "v_solovev_031966@postgrespro.ru", "phone": "+70857989524"}
0005435282321	AC019B	1951 023563	NIKOLAY MAKAROV	{"email": "n_makarov.31051971@postgrespro.ru", "phone": "+70375065835"}
0005435282322	C71837	9173 201430	ALEKSEY BONDARENKO	{"email": "a_bondarenko1971@postgrespro.ru", "phone": "+70785934008"}
0005435282323	C71837	4187 756425	ALEKSEY POPOV	{"email": "alekseypopov101978@postgrespro.ru", "phone": "+70560702061"}
0005435282324	9498FA	1279 633682	LEONID KUZNECOV	{"email": "kuznecov.leonid.011977@postgrespro.ru", "phone": "+70190060557"}
0005435282325	9498FA	1716 281643	PAVEL TIKHONOV	{"email": "tikhonov-p18081978@postgrespro.ru", "phone": "+70543782906"}
0005435282326	2F96E6	6662 911059	ALEKSANDR BORISOV	{"email": "aleksandr_borisov_20121975@postgrespro.ru", "phone": "+70190128530"}
0005435282327	D32154	0468 385650	RUSTAM SEMENOV	{"phone": "+70302231333"}
0005435282328	CE06F3	9846 680631	ALEKSANDR EGOROV	{"phone": "+70666381541"}
0005435282329	29BEE3	9544 161045	IGOR VOROBEV	{"email": "igor_vorobev011978@postgrespro.ru", "phone": "+70949666947"}
0005435282330	003610	2102 751436	OLGA KARPOVA	{"phone": "+70075091281"}
0005435282331	003610	2905 413501	ALEKSANDRA KULIKOVA	{"email": "kulikovaaleksandra.1957@postgrespro.ru", "phone": "+70404242794"}
0005435282332	003610	2711 847800	ELENA KULIKOVA	{"phone": "+70623102565"}
0005435282333	ECC8E7	5940 794370	MARIYA KOLESNIKOVA	{"phone": "+70349163402"}
0005435282334	812C3D	8460 239161	ALEKSANDR SEMENOV	{"phone": "+70252780755"}
0005435282335	F1A7B1	8960 101881	VALENTINA YUDINA	{"phone": "+70720284679"}
0005435282336	F1A7B1	7029 571920	IGOR VOLKOV	{"phone": "+70364985665"}
0005435282337	2EC6DA	2487 715951	ALEKSEY VASILEV	{"phone": "+70951106264"}
0005435282338	569046	8394 251401	TATYANA KOVALEVA	{"email": "t.kovaleva28111981@postgrespro.ru", "phone": "+70882748597"}
0005435282339	9FA24B	8426 251297	ALEKSANDRA MAKAROVA	{"phone": "+70141057891"}
0005435282340	A5E59D	4743 701549	VERA DMITRIEVA	{"email": "dmitrievavera1980@postgrespro.ru", "phone": "+70398562282"}
0005435282341	0CF963	7926 124548	VLADIMIR SIDOROV	{"phone": "+70666688938"}
0005435282342	18EA2B	9267 721012	ANNA YAKOVLEVA	{"phone": "+70390778318"}
0005435282343	23E3EC	4012 136124	OLGA NIKOLAEVA	{"email": "nikolaeva_o-08081973@postgrespro.ru", "phone": "+70044678646"}
0005435282344	23E3EC	9515 380326	RAISA ROMANOVA	{"email": "romanova-raisa031956@postgrespro.ru", "phone": "+70338720590"}
0005435282345	F0F68F	1208 834337	DANILA STEPANOV	{"email": "danila-stepanov_20121969@postgrespro.ru", "phone": "+70431362161"}
0005435282346	9499FB	1216 783970	NIKITA ANDREEV	{"phone": "+70391630772"}
0005435282347	9499FB	1901 465709	ANASTASIYA ANISIMOVA	{"email": "anisimovaanastasiya091967@postgrespro.ru", "phone": "+70810117812"}
0005435282348	C2513E	2122 135212	YULIYA YUDINA	{"phone": "+70017771492"}
0005435282349	5E69BC	4426 107415	SERGEY YAKOVLEV	{"phone": "+70916821410"}
0005435282350	D3B5C2	8285 769055	LYUBOV YAKOVLEVA	{"phone": "+70898895095"}
0005435282351	6F2E21	1901 476115	SVETLANA RYABOVA	{"phone": "+70919276982"}
0005435282352	081684	3150 470560	NIKOLAY GERASIMOV	{"email": "n_gerasimov-031969@postgrespro.ru", "phone": "+70320977425"}
0005435282353	F385E1	8782 546565	RAISA KOLESNIKOVA	{"email": "rkolesnikova.07091967@postgrespro.ru", "phone": "+70493365034"}
0005435282354	0858F1	0108 698995	VITALIY ALEKSEEV	{"email": "v_alekseev1967@postgrespro.ru", "phone": "+70715406241"}
0005435282355	0858F1	7520 056687	RAISA KAZAKOVA	{"email": "r_kazakova10111982@postgrespro.ru", "phone": "+70176936745"}
0005435282357	96B7FE	5309 523004	IVAN KAZAKOV	{"email": "kazakov_ivan-081982@postgrespro.ru", "phone": "+70828284647"}
0005435282358	610B98	7446 499423	MARAT NOVIKOV	{"email": "novikov-marat.041972@postgrespro.ru", "phone": "+70230392152"}
0005435282359	54FB36	8146 503546	SERGEY IVANOV	{"phone": "+70976913557"}
0005435282360	54FB36	4311 395923	ALEKSANDR ALEKSEEV	{"email": "alekseev.a071971@postgrespro.ru", "phone": "+70712947259"}
0005435282361	593069	6266 496931	IGOR SCHERBAKOV	{"phone": "+70875471043"}
0005435282362	593069	0642 292450	NADEZHDA IVANOVA	{"phone": "+70318228227"}
0005435282363	9D196E	0340 854578	ALSU TIKHONOVA	{"email": "tikhonova.a-021975@postgrespro.ru", "phone": "+70450148872"}
0005435282364	5C6F2C	5977 176631	STANISLAV ZHURAVLEV	{"phone": "+70077064107"}
0005435282365	6CD48C	7942 855953	DMITRIY KOZLOV	{"phone": "+70752406580"}
0005435282366	6CD48C	9742 443544	LARISA KOLESNIKOVA	{"email": "kolesnikoval_1972@postgrespro.ru", "phone": "+70023957493"}
0005435282367	6CD48C	7131 289365	OLGA EFIMOVA	{"phone": "+70508011702"}
0005435282368	33F745	5184 894926	LARISA MEDVEDEVA	{"email": "medvedevalarisa03071972@postgrespro.ru", "phone": "+70725234335"}
0005435282369	96B678	2626 575820	ALEKSANDR NIKOLAEV	{"phone": "+70566217081"}
0005435282370	96B678	4541 243570	ROZA KISELEVA	{"email": "rozakiseleva-25121965@postgrespro.ru", "phone": "+70820077562"}
0005435282371	E76792	0810 423804	IGOR GRIGOREV	{"email": "igor_grigorev.14051971@postgrespro.ru", "phone": "+70692200445"}
0005435282372	2D7297	5016 467565	YURIY SOKOLOV	{"phone": "+70013138242"}
0005435282373	5FE046	6331 131874	VIKTOR BELOV	{"email": "v-belov-30081978@postgrespro.ru", "phone": "+70398186891"}
0005435282374	83419C	9257 812640	SERGEY BELOV	{"email": "belov.sergey22121958@postgrespro.ru", "phone": "+70253204909"}
0005435282375	02D6FE	3482 830781	SVETLANA VASILEVA	{"email": "vasileva.svetlana-21011963@postgrespro.ru", "phone": "+70049557737"}
0005435282376	02D6FE	0484 241313	ALEKSANDR VOROBEV	{"email": "vorobev.aleksandr111974@postgrespro.ru", "phone": "+70188273304"}
0005435282377	EDE8D5	6543 915705	SERGEY MOROZOV	{"email": "s_morozov_101974@postgrespro.ru", "phone": "+70569200368"}
0005435282378	EB4CAC	0214 803815	VALERIY SAVELEV	{"phone": "+70755476356"}
0005435282379	534D52	1880 018616	NATALYA MATVEEVA	{"email": "natalya-matveeva-011972@postgrespro.ru", "phone": "+70324841965"}
0005435282380	BA0436	2810 748185	NIKOLAY ZAYCEV	{"phone": "+70208597721"}
0005435282381	77B921	9212 397769	YULIYA SOKOLOVA	{"email": "y.sokolova091971@postgrespro.ru", "phone": "+70917075155"}
0005435282382	82B518	2218 035040	ALEKSANDR MARTYNOV	{"phone": "+70174158323"}
0005435282383	388CE3	5832 949885	VLADISLAV BORISOV	{"email": "vladislavborisov_31121981@postgrespro.ru", "phone": "+70558800563"}
0005435282384	48D54E	9575 006012	SERGEY KOZLOV	{"email": "s_kozlov_101971@postgrespro.ru", "phone": "+70598511823"}
0005435282385	48D54E	6907 514920	NIKITA ANDREEV	{"phone": "+70737907464"}
0005435282386	60E993	7658 504650	ELENA KUZNECOVA	{"phone": "+70726062238"}
0005435282387	124E4E	3635 390019	SVETLANA FILIPPOVA	{"email": "filippova.s.071971@postgrespro.ru", "phone": "+70907330927"}
0005435282388	0EA3D2	4578 697422	ALEKSANDR KOROLEV	{"email": "korolevaleksandr_051977@postgrespro.ru", "phone": "+70249938352"}
0005435282389	1E8AC5	1997 204864	ELENA DMITRIEVA	{"phone": "+70848103780"}
0005435282390	9860C3	8133 212610	TATYANA KOLESNIKOVA	{"phone": "+70271681609"}
0005435282391	B076D9	9884 501959	TATYANA EGOROVA	{"email": "tatyana_egorova1967@postgrespro.ru", "phone": "+70574719843"}
0005435282392	B076D9	8698 354505	LEONID POPOV	{"phone": "+70182263369"}
0005435282393	635CA3	5800 335657	VALENTIN SHEVCHENKO	{"email": "valentin-shevchenko091964@postgrespro.ru", "phone": "+70171756326"}
0005435282394	BCCEA7	8257 968435	OLGA GUSEVA	{"phone": "+70037577028"}
0005435282395	BCCEA7	6807 297525	GALINA YAKOVLEVA	{"email": "yakovlevagalina.05051975@postgrespro.ru", "phone": "+70576481336"}
0005435282396	BCCEA7	3743 443111	ALEKSEY KISELEV	{"phone": "+70134763985"}
0005435282397	9CD565	6035 024388	MARIYA ILINA	{"email": "mariya_ilina-04011983@postgrespro.ru", "phone": "+70943346645"}
0005435282398	8375B5	0480 055308	EVGENIYA KOROLEVA	{"phone": "+70849127223"}
0005435282399	E09200	7925 417174	OLGA LAZAREVA	{"email": "olga_lazareva091975@postgrespro.ru", "phone": "+70979702875"}
0005435282400	444608	7083 484446	MAKAR BORISOV	{"phone": "+70429285595"}
0005435282401	444608	9918 032186	NADEZHDA OVCHINNIKOVA	{"email": "n_ovchinnikova16031971@postgrespro.ru", "phone": "+70908651335"}
0005435282402	B393E2	4545 013558	NATALYA SMIRNOVA	{"email": "smirnova.n_1979@postgrespro.ru", "phone": "+70527072395"}
0005435282403	86E1E9	7887 081477	YURIY VASILEV	{"email": "vasilev_yuriy101966@postgrespro.ru", "phone": "+70973628283"}
0005435282404	FB11E5	4580 922719	ALEKSANDR NIKOLAEV	{"email": "nikolaev-aleksandr-101971@postgrespro.ru", "phone": "+70464860874"}
0005435282405	FB11E5	7615 900494	ANASTASIYA KULIKOVA	{"phone": "+70113896996"}
0005435282406	23C8E6	3557 679878	EKATERINA VOROBEVA	{"phone": "+70953471038"}
0005435282407	70571A	6808 717151	ANDREY KARPOV	{"phone": "+70287104645"}
0005435282408	0FED8F	2496 525836	TATYANA ANISIMOVA	{"email": "tatyana-anisimova-16051977@postgrespro.ru", "phone": "+70354579213"}
0005435282409	E91EB9	4709 646614	LYUDMILA NESTEROVA	{"email": "nesterova_lyudmila_121967@postgrespro.ru", "phone": "+70936364245"}
0005435282410	7BFD53	4143 301804	ROMAN KUZNECOV	{"phone": "+70055388466"}
0005435282411	7BFD53	1713 193703	ALEKSANDR MOROZOV	{"email": "morozov-a.1977@postgrespro.ru", "phone": "+70545517691"}
0005435282412	7BFD53	0724 773433	EVGENIYA SERGEEVA	{"email": "sergeevaevgeniya.18051977@postgrespro.ru", "phone": "+70477288172"}
0005435282413	28CED8	0154 334458	GALINA DMITRIEVA	{"email": "galina-dmitrieva_1969@postgrespro.ru", "phone": "+70161649520"}
0005435282414	28CED8	0720 858160	MARGARITA SAVELEVA	{"phone": "+70785800598"}
0005435282593	1E9CAD	1443 651582	MARINA STEPANOVA	{"phone": "+70859611903"}
0005435282415	81172A	8717 574568	GALINA AFANASEVA	{"email": "galina.afanaseva091963@postgrespro.ru", "phone": "+70116401534"}
0005435282416	81172A	5393 319438	IGNAT TARASOV	{"phone": "+70196898926"}
0005435282417	93FE8C	0881 900353	TATYANA KUZNECOVA	{"phone": "+70738202932"}
0005435282418	FE4064	3244 774661	TAMARA ZAYCEVA	{"email": "tamara_zayceva_1974@postgrespro.ru", "phone": "+70356187475"}
0005435282419	6263B7	7790 423812	KLAVDIYA NIKITINA	{"email": "klavdiya.nikitina.1968@postgrespro.ru", "phone": "+70040128290"}
0005435282420	CAE88D	4613 113712	NIKOLAY KUZMIN	{"phone": "+70149795203"}
0005435282421	50B5B1	0397 567267	ANDREY POPOV	{"phone": "+70898219754"}
0005435282422	224E64	0492 161259	NADEZHDA SEMENOVA	{"email": "semenovanadezhda.1979@postgrespro.ru", "phone": "+70915029512"}
0005435282423	224E64	1248 172602	ANDREY NOVIKOV	{"email": "a.novikov-1962@postgrespro.ru", "phone": "+70261207296"}
0005435282424	9563E6	0968 626527	STANISLAV KUZNECOV	{"email": "kuznecov.s.091972@postgrespro.ru", "phone": "+70051420968"}
0005435282425	9563E6	9945 775245	NIKOLAY ZAKHAROV	{"phone": "+70768045115"}
0005435282426	788D82	3006 223417	YURIY GORBUNOV	{"phone": "+70677566781"}
0005435282427	788D82	7580 115306	OLEG POPOV	{"phone": "+70511165386"}
0005435282428	9D15A7	7291 106077	NINA POPOVA	{"phone": "+70112182515"}
0005435282429	9D15A7	5413 934881	PELAGEYA KOZLOVA	{"phone": "+70637171156"}
0005435282430	08CBA1	6206 882573	YULIYA TARASOVA	{"email": "tarasovayuliya-1977@postgrespro.ru", "phone": "+70129004707"}
0005435282431	40DE2F	4410 956331	VALERIY DMITRIEV	{"email": "valeriydmitriev-1968@postgrespro.ru", "phone": "+70177180106"}
0005435282432	DF28C1	3250 187239	TATYANA MAKSIMOVA	{"phone": "+70175830035"}
0005435282433	2F3263	9228 942784	OLEG NOVIKOV	{"phone": "+70541870825"}
0005435282434	105A3D	6406 701260	TATYANA DENISOVA	{"phone": "+70812802954"}
0005435282435	050591	7940 930726	OLEG AFANASEV	{"email": "afanasev-oleg06041970@postgrespro.ru", "phone": "+70757789339"}
0005435282436	B6380A	7960 322688	TAMARA IVANOVA	{"phone": "+70048286434"}
0005435282437	1177C9	0460 554992	NINA ANDREEVA	{"phone": "+70826132592"}
0005435282438	655164	4901 130056	ALINA NESTEROVA	{"phone": "+70720955172"}
0005435282439	655164	4349 605629	OLESYA KUZNECOVA	{"email": "kuznecova-olesya_011969@postgrespro.ru", "phone": "+70545830051"}
0005435282440	CAF791	6576 416011	VALENTINA KUZNECOVA	{"phone": "+70329172891"}
0005435282441	55E3DD	8132 644926	ALEKSANDR MOROZOV	{"phone": "+70701887873"}
0005435282442	6BDB57	5020 120328	ANASTASIYA IVANOVA	{"email": "anastasiya_ivanova-061972@postgrespro.ru", "phone": "+70702468250"}
0005435282443	D33920	2999 425481	TATYANA MAKAROVA	{"email": "makarovat_1975@postgrespro.ru", "phone": "+70857230858"}
0005435282444	065500	3078 576341	SERGEY TIKHONOV	{"phone": "+70775044039"}
0005435282445	DC7015	4234 782057	ELENA MELNIKOVA	{"email": "emelnikova041971@postgrespro.ru", "phone": "+70058119039"}
0005435282446	AAE3E3	6118 802767	ALEKSANDR NIKOLAEV	{"phone": "+70455717784"}
0005435282447	C68894	4938 601095	ALEKSANDR SERGEEV	{"phone": "+70030858263"}
0005435282448	C68894	8553 750229	IVAN MAKAROV	{"email": "makarov_ivan-101965@postgrespro.ru", "phone": "+70395288665"}
0005435282449	E41688	6040 475163	TATYANA MIRONOVA	{"email": "tatyanamironova.1971@postgrespro.ru", "phone": "+70540627283"}
0005435282450	2668A5	3317 370349	GULNAZ ZAYCEVA	{"email": "zayceva-g-15081971@postgrespro.ru", "phone": "+70918670716"}
0005435282451	5F3A29	8969 325021	ELENA GORBUNOVA	{"email": "gorbunova_e-031983@postgrespro.ru", "phone": "+70305019480"}
0005435282452	5F3A29	5401 786884	ALEKSEY SMIRNOV	{"phone": "+70456159919"}
0005435282453	40DC0D	7707 539861	YULIYA OSIPOVA	{"phone": "+70037994251"}
0005435282454	864BF2	8620 290122	ANNA SIDOROVA	{"email": "anna_sidorova-111965@postgrespro.ru", "phone": "+70622228898"}
0005435282455	5582FB	3386 400914	VLADISLAV RODIONOV	{"email": "rodionov_v.20061970@postgrespro.ru", "phone": "+70266758982"}
0005435282456	06F752	5740 526961	VALENTINA MEDVEDEVA	{"phone": "+70436061596"}
0005435282457	06F752	5882 611277	ELMIRA KAZAKOVA	{"email": "elmirakazakova_1976@postgrespro.ru", "phone": "+70505657364"}
0005435282458	AF8355	3751 222628	IRINA KUZMINA	{"email": "kuzmina.irina-1977@postgrespro.ru", "phone": "+70018370634"}
0005435282459	2C50B8	3766 264326	SVETLANA NIKOLAEVA	{"email": "svetlananikolaeva_24061975@postgrespro.ru", "phone": "+70672031677"}
0005435282460	2C50B8	5792 111930	OLGA MOROZOVA	{"phone": "+70738779458"}
0005435282461	7B97B8	3991 585602	ELENA BORISOVA	{"email": "elena.borisova_1978@postgrespro.ru", "phone": "+70771922073"}
0005435282462	7B97B8	5673 435776	VIKTOR MOROZOV	{"phone": "+70695239766"}
0005435282463	142DF1	5234 147957	LYUDMILA NESTEROVA	{"email": "l_nesterova-121966@postgrespro.ru", "phone": "+70142994336"}
0005435282464	8373A7	8244 232469	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova-nadezhda-1988@postgrespro.ru", "phone": "+70630872160"}
0005435282465	8373A7	3870 075843	VALENTINA FADEEVA	{"phone": "+70558956023"}
0005435282466	F8A50B	1523 944891	ILDAR KUZNECOV	{"email": "ikuznecov-19011976@postgrespro.ru", "phone": "+70473385780"}
0005435282467	F8A50B	7874 478142	ANDREY GAVRILOV	{"phone": "+70109438789"}
0005435282468	F98743	4075 601080	DENIS ZHUKOV	{"phone": "+70638819498"}
0005435282469	28BB1E	6013 882263	EKATERINA KONDRATEVA	{"phone": "+70032813607"}
0005435282470	0BEAC8	8371 084086	ALENA MAKAROVA	{"email": "makarova.alena20031983@postgrespro.ru", "phone": "+70292555159"}
0005435282471	0BEAC8	4357 295707	TAMARA KOROLEVA	{"phone": "+70036114283"}
0005435282472	8E160A	5369 330939	VARVARA MOISEEVA	{"email": "moiseeva_varvara_13101984@postgrespro.ru", "phone": "+70274722076"}
0005435282473	8E160A	6838 994880	VALERIY KUZNECOV	{"phone": "+70892504530"}
0005435282474	6869FD	6467 615454	EKATERINA GAVRILOVA	{"email": "gavrilovaekaterina1978@postgrespro.ru", "phone": "+70239359731"}
0005435282712	A70FD5	4363 809683	NIKOLAY DAVYDOV	{"phone": "+70307728395"}
0005435282475	2A4742	9694 814574	LYUDMILA SOROKINA	{"email": "sorokina_l.1968@postgrespro.ru", "phone": "+70882364571"}
0005435282476	2A4742	7412 951781	NINA FILATOVA	{"phone": "+70951155259"}
0005435282477	2A4742	4834 274188	OLGA TARASOVA	{"phone": "+70187170515"}
0005435282478	4EDFAF	4771 770691	DAMIR IVANOV	{"phone": "+70642625546"}
0005435282479	4EDFAF	4034 369586	EKATERINA ANDREEVA	{"email": "ekaterinaandreeva-091976@postgrespro.ru", "phone": "+70954737254"}
0005435282480	45E0E5	9345 122565	VALENTINA POPOVA	{"email": "popovavalentina-1972@postgrespro.ru", "phone": "+70207520131"}
0005435282481	AAEFEE	0979 540365	MARINA POTAPOVA	{"email": "potapova-marina_1981@postgrespro.ru", "phone": "+70173441387"}
0005435282482	0BD993	9090 599085	NINA KOZLOVA	{"phone": "+70943855480"}
0005435282483	0BD993	5685 567057	NADEZHDA KUZMINA	{"email": "n-kuzmina.051964@postgrespro.ru", "phone": "+70269198434"}
0005435282484	ED6065	8775 910893	MARINA ORLOVA	{"email": "orlova-m.31051963@postgrespro.ru", "phone": "+70718607890"}
0005435282485	A6B763	3450 023054	ANATOLIY YAKOVLEV	{"email": "anatoliy-yakovlev-28021962@postgrespro.ru", "phone": "+70456668892"}
0005435282486	A6B763	5874 803866	EVGENIY ANDREEV	{"email": "evgeniy_andreev.1971@postgrespro.ru", "phone": "+70922410094"}
0005435282487	FCB069	6785 955489	NINA SERGEEVA	{"email": "sergeeva.n011962@postgrespro.ru", "phone": "+70728039215"}
0005435282488	FCB069	2328 116625	ALEKSEY YAKOVLEV	{"phone": "+70962838444"}
0005435282489	32754D	7949 490420	VLADIMIR MIKHAYLOV	{"phone": "+70437755684"}
0005435282490	7165C0	1017 998183	KLAVDIYA KOLESNIKOVA	{"email": "kolesnikova_klavdiya-04121965@postgrespro.ru", "phone": "+70435135611"}
0005435282491	519E48	2318 910871	EVGENIY RODIONOV	{"email": "evgeniy.rodionov.05031967@postgrespro.ru", "phone": "+70132499437"}
0005435282492	985465	4688 098516	ANTONINA OSIPOVA	{"email": "antonina-osipova_041985@postgrespro.ru", "phone": "+70713182363"}
0005435282493	985465	0910 093087	ALEKSEY MATVEEV	{"email": "alekseymatveev-021981@postgrespro.ru", "phone": "+70109677983"}
0005435282494	97AB04	8584 842233	ALEKSEY ALEKSEEV	{"phone": "+70373997169"}
0005435282495	97AB04	4289 637451	VALERIYA KONOVALOVA	{"email": "vkonovalova.081969@postgrespro.ru", "phone": "+70787498040"}
0005435282496	DFBA45	7363 457305	NIKOLAY ANTONOV	{"email": "antonov_nikolay_1976@postgrespro.ru", "phone": "+70551469937"}
0005435282497	DFBA45	4808 760754	GENNADIY ANDREEV	{"phone": "+70330010381"}
0005435282498	8B6471	2079 901186	ANASTASIYA MALYSHEVA	{"phone": "+70206672537"}
0005435282499	4E5F37	7438 541101	LYUBOV PETROVA	{"phone": "+70306336182"}
0005435282500	0FE2BC	4877 592565	LYUBOV MIRONOVA	{"email": "mironoval17011971@postgrespro.ru", "phone": "+70117003493"}
0005435282501	226103	0693 450918	VALENTIN FEDOROV	{"email": "fedorov.valentin_1978@postgrespro.ru", "phone": "+70977295987"}
0005435282502	226103	5739 673083	RINAT IVANOV	{"email": "ivanov-rinat1974@postgrespro.ru", "phone": "+70215469892"}
0005435282503	810E2C	1850 330341	VIKTOR ANDREEV	{"phone": "+70245719335"}
0005435282504	C52E43	4091 935596	OKSANA DENISOVA	{"phone": "+70428174955"}
0005435282505	425638	3247 273646	TATYANA NIKOLAEVA	{"phone": "+70090976117"}
0005435282506	430192	2371 887978	ARTEM BORISOV	{"email": "artem.borisov-20071975@postgrespro.ru", "phone": "+70704878263"}
0005435282507	430192	5796 195379	SERGEY DENISOV	{"phone": "+70772078358"}
0005435282508	B6A7AD	7286 448791	VALENTINA MELNIKOVA	{"phone": "+70474549616"}
0005435282509	D356DB	8721 873712	GALINA NIKIFOROVA	{"phone": "+70004226677"}
0005435282510	0CABDD	3070 003488	SERGEY RODIONOV	{"email": "rodionov_sergey-111980@postgrespro.ru", "phone": "+70426163702"}
0005435282511	F8C196	8462 741703	YURIY YAKOVLEV	{"email": "yakovlev_yuriy_061963@postgrespro.ru", "phone": "+70864747397"}
0005435282512	0220A8	1643 068270	ALSU ANDREEVA	{"email": "a.andreeva.121964@postgrespro.ru", "phone": "+70965158974"}
0005435282513	CCA9CB	1044 199497	RAUF FROLOV	{"email": "frolovrauf1986@postgrespro.ru", "phone": "+70358717814"}
0005435282514	5E5F18	3651 555939	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev15021970@postgrespro.ru", "phone": "+70399575646"}
0005435282515	89302B	1713 620288	SERGEY MAKSIMOV	{"phone": "+70511840761"}
0005435282516	E9F4A0	9691 429846	LEONID KOROLEV	{"phone": "+70799306503"}
0005435282517	0109C2	9387 952789	ELENA NIKOLAEVA	{"email": "nikolaeva-e_071974@postgrespro.ru", "phone": "+70226715950"}
0005435282518	8E98C9	5815 204662	ALEKSANDR SOKOLOV	{"phone": "+70048958516"}
0005435282519	FE498E	1756 323288	NADEZHDA IVANOVA	{"email": "ivanova.nadezhda-071972@postgrespro.ru", "phone": "+70943177784"}
0005435282520	AF1F80	4323 898719	ALEKSEY BELOV	{"email": "alekseybelov.20101979@postgrespro.ru", "phone": "+70406715752"}
0005435282521	3A1002	4162 971556	SOFYA BELYAEVA	{"email": "sofyabelyaeva.071973@postgrespro.ru", "phone": "+70742661059"}
0005435282522	90205E	3539 898271	NIKOLAY BELOV	{"email": "nbelov_021970@postgrespro.ru", "phone": "+70171045420"}
0005435282523	90205E	9730 533318	SVETLANA TROFIMOVA	{"phone": "+70271117622"}
0005435282524	42AD1E	0628 569248	LYUBOV GUSEVA	{"email": "guseva_l_1975@postgrespro.ru", "phone": "+70118638663"}
0005435282525	42AD1E	8136 506903	MAKSIM VASILEV	{"phone": "+70974652724"}
0005435282526	EFD280	4039 310708	OLGA VLASOVA	{"email": "olga_vlasova.1957@postgrespro.ru", "phone": "+70442250795"}
0005435282527	CBF038	1224 917500	VALENTINA ANDREEVA	{"email": "valentina-andreeva.07081960@postgrespro.ru", "phone": "+70074372659"}
0005435282528	CBF038	9782 733737	NADEZHDA STEPANOVA	{"phone": "+70448358174"}
0005435282529	99B46F	3553 596899	DMITRIY VOROBEV	{"email": "vorobev_dmitriy-27051970@postgrespro.ru", "phone": "+70356816127"}
0005435282530	99B46F	1860 929449	EVGENIYA IVANOVA	{"phone": "+70703307779"}
0005435282531	99B46F	2980 112843	SERGEY ZHUKOV	{"email": "s.zhukov061981@postgrespro.ru", "phone": "+70401629669"}
0005435282532	6D2D8C	1034 656399	VLADIMIR ABRAMOV	{"phone": "+70330234664"}
0005435282533	6D2D8C	9400 778823	LIDIYA ZOTOVA	{"phone": "+70669042072"}
0005435282534	1FB336	5173 965402	ELENA NOVIKOVA	{"email": "novikova.e.1960@postgrespro.ru", "phone": "+70893600603"}
0005435282535	FA76C1	2354 358098	ARTEM IVANOV	{"phone": "+70067834934"}
0005435282536	9DDFF3	8836 729629	PAVEL PAVLOV	{"email": "pavlov_pavel101959@postgrespro.ru", "phone": "+70303869151"}
0005435282537	9DDFF3	2803 040033	ELENA KISELEVA	{"phone": "+70349229408"}
0005435282538	95F3C2	4895 029511	VIKTOR BELOV	{"phone": "+70038403632"}
0005435282539	7EDA9D	6903 426531	ROMAN SCHERBAKOV	{"phone": "+70786829969"}
0005435282540	7EDA9D	1342 911940	MARIYA LEBEDEVA	{"phone": "+70639231748"}
0005435282541	6C9F00	3143 644742	ANNA TITOVA	{"email": "titova-anna-23121963@postgrespro.ru", "phone": "+70316341507"}
0005435282542	6C9F00	7754 186035	NIKOLAY SHEVCHENKO	{"email": "shevchenko_n_1965@postgrespro.ru", "phone": "+70268885011"}
0005435282543	AFD6A4	8003 819330	VALENTINA TIMOFEEVA	{"email": "timofeeva.v_10031990@postgrespro.ru", "phone": "+70670768210"}
0005435282544	8758F7	0389 702555	VLADIMIR VASILEV	{"phone": "+70675484824"}
0005435282545	8758F7	4333 666162	ANASTASIYA SOROKINA	{"phone": "+70621486548"}
0005435282546	3BEE14	9129 307542	ANATOLIY KOROLEV	{"email": "anatoliy-korolev-22011976@postgrespro.ru", "phone": "+70558987203"}
0005435282547	595871	8817 811511	EKATERINA OSIPOVA	{"email": "ekaterinaosipova.26081969@postgrespro.ru", "phone": "+70225903763"}
0005435282548	595871	3225 732781	LILIYA ORLOVA	{"phone": "+70799293417"}
0005435282549	595871	1946 344234	DMITRIY MOROZOV	{"phone": "+70868399596"}
0005435282550	5EFD55	1075 127497	LILIYA MAKAROVA	{"email": "l-makarova.1962@postgrespro.ru", "phone": "+70199538113"}
0005435282551	5EFD55	8882 287996	LYUDMILA RODIONOVA	{"email": "rodionova_l-1970@postgrespro.ru", "phone": "+70581323332"}
0005435282552	DC9F67	1511 917852	PETR FEDOTOV	{"phone": "+70742613121"}
0005435282553	DC9F67	9999 894116	ROMAN NAZAROV	{"phone": "+70643244435"}
0005435282554	532FA4	0437 969618	NIKOLAY MELNIKOV	{"email": "n-melnikov_071969@postgrespro.ru", "phone": "+70309501069"}
0005435282555	532FA4	9910 077019	YULIYA NIKOLAEVA	{"phone": "+70639227668"}
0005435282556	532FA4	3405 754956	LARISA MOISEEVA	{"email": "moiseeva-l-071965@postgrespro.ru", "phone": "+70244272132"}
0005435282557	2685AD	4682 405961	NIKOLAY CHERNOV	{"phone": "+70325955555"}
0005435282558	3E4A81	0326 624505	RUSTEM KUZMIN	{"email": "r_kuzmin111972@postgrespro.ru", "phone": "+70864383306"}
0005435282559	3E4A81	7215 471163	ANNA MASLOVA	{"email": "a.maslova-1971@postgrespro.ru", "phone": "+70778263565"}
0005435282560	3E4A81	9002 413792	SERGEY BELOV	{"phone": "+70387528342"}
0005435282561	1D286F	4024 261451	ZHANNA IVANOVA	{"phone": "+70769431097"}
0005435282562	BCEBD3	3070 902749	KSENIYA TARASOVA	{"phone": "+70803786201"}
0005435282563	A0C6DB	7969 858544	RAISA LOGINOVA	{"phone": "+70955832591"}
0005435282564	124E71	2635 788533	LARISA TROFIMOVA	{"phone": "+70306287901"}
0005435282565	412765	8082 691257	NATALYA PETROVA	{"phone": "+70641133806"}
0005435282566	51298F	0045 408946	ARSEN SHEVCHENKO	{"email": "arsenshevchenko_13031976@postgrespro.ru", "phone": "+70418100144"}
0005435282567	DD6474	5891 771653	DMITRIY KOZLOV	{"email": "dmitriy_kozlov-1973@postgrespro.ru", "phone": "+70868767152"}
0005435282568	0497D3	9785 356297	EVGENIY SERGEEV	{"email": "esergeev_111977@postgrespro.ru", "phone": "+70375517974"}
0005435282569	0497D3	5488 649689	TAMARA STEPANOVA	{"phone": "+70061524436"}
0005435282570	AB8234	2332 408633	RUSTAM KUZMIN	{"email": "kuzmin.r_1964@postgrespro.ru", "phone": "+70836149180"}
0005435282571	AB8234	0497 141804	DMITRIY IVANOV	{"phone": "+70983074575"}
0005435282572	299BAB	6227 898167	RUSTAM SERGEEV	{"phone": "+70217329632"}
0005435282573	299BAB	5647 400992	VITALIY POPOV	{"email": "vitaliy_popov.1971@postgrespro.ru", "phone": "+70365679038"}
0005435282574	9EFC24	6503 700476	ARTEM ROMANOV	{"email": "artem.romanov31101974@postgrespro.ru", "phone": "+70779351614"}
0005435282575	9EFC24	0411 358655	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga29101977@postgrespro.ru", "phone": "+70874234412"}
0005435282576	4E6ECF	5248 927439	ELENA GERASIMOVA	{"email": "gerasimova_elena.08111980@postgrespro.ru", "phone": "+70018993087"}
0005435282577	C2B97F	9861 136347	SERGEY FROLOV	{"email": "sergeyfrolov.081978@postgrespro.ru", "phone": "+70968646077"}
0005435282578	C2B97F	0724 316731	LYUBOV BOGDANOVA	{"email": "lyubov_bogdanova_21051964@postgrespro.ru", "phone": "+70793746520"}
0005435282579	759C6D	1224 857585	EKATERINA KOROLEVA	{"email": "ekaterina-koroleva011971@postgrespro.ru", "phone": "+70350428926"}
0005435282580	759C6D	2360 980031	SERGEY NOVIKOV	{"email": "novikovsergey_17091965@postgrespro.ru", "phone": "+70935237207"}
0005435282581	EBA46F	3161 665045	TATYANA ISAEVA	{"email": "isaeva.tatyana-1963@postgrespro.ru", "phone": "+70543474513"}
0005435282582	64004D	3448 085170	RUFIYA NIKOLAEVA	{"email": "nikolaeva_rufiya_121976@postgrespro.ru", "phone": "+70849484012"}
0005435282583	5621A9	2445 073004	NATALYA PETROVA	{"email": "petrovan_031974@postgrespro.ru", "phone": "+70753163841"}
0005435282584	7D3BEF	8859 099120	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr19101977@postgrespro.ru", "phone": "+70758122207"}
0005435282585	7D3BEF	3769 105381	VLADIMIR KRASNOV	{"email": "krasnov-vladimir1971@postgrespro.ru", "phone": "+70129970969"}
0005435282586	053C04	8232 045199	OLGA FROLOVA	{"email": "olga-frolova.1980@postgrespro.ru", "phone": "+70147567555"}
0005435282587	053C04	9506 688751	OLGA KUZNECOVA	{"email": "olgakuznecova.24081966@postgrespro.ru", "phone": "+70319801224"}
0005435282588	053C04	9626 334734	VIKTOR GERASIMOV	{"email": "gerasimov.v_1984@postgrespro.ru", "phone": "+70516487660"}
0005435282589	705085	4334 178915	LYUDMILA FILIPPOVA	{"email": "lyudmilafilippova.011990@postgrespro.ru", "phone": "+70228714178"}
0005435282590	E1B4EC	6269 481789	TATYANA IVANOVA	{"phone": "+70514577629"}
0005435282591	E1B4EC	1613 868629	IVAN SERGEEV	{"phone": "+70599638366"}
0005435282592	BD967C	8520 296257	ALFIYA ISAEVA	{"phone": "+70955671505"}
0005435282594	AC8D5D	6346 181381	ALEKSEY SEMENOV	{"email": "semenov_aleksey.101971@postgrespro.ru", "phone": "+70658854167"}
0005435282595	B40F91	8329 683994	ALEKSANDR KUZMIN	{"email": "kuzmin.a011985@postgrespro.ru", "phone": "+70283505439"}
0005435282596	3E8352	4092 767338	GALINA NAZAROVA	{"email": "nazarova_galina_1971@postgrespro.ru", "phone": "+70132800560"}
0005435282597	8A260C	9179 887913	ANASTASIYA MELNIKOVA	{"phone": "+70056793193"}
0005435282598	E8A90E	8229 467729	DENIS FEDOTOV	{"email": "fedotov-d_1979@postgrespro.ru", "phone": "+70101769150"}
0005435282599	E8A90E	6958 738140	ANDREY ZHURAVLEV	{"email": "zhuravlev.andrey.1973@postgrespro.ru", "phone": "+70371473228"}
0005435282600	42921B	6622 088078	ELENA ARKHIPOVA	{"email": "e-arkhipova-1978@postgrespro.ru", "phone": "+70002572598"}
0005435282601	1FF902	9418 481533	ELENA ANDREEVA	{"email": "andreeva_e1978@postgrespro.ru", "phone": "+70801214906"}
0005435282602	088DB7	0659 814561	SERGEY IVANOV	{"email": "s-ivanov_111974@postgrespro.ru", "phone": "+70805191169"}
0005435282603	088DB7	2753 493850	ALEKSEY MEDVEDEV	{"phone": "+70555228038"}
0005435282604	93E3EB	8366 925516	ROMAN IVANOV	{"email": "r_ivanov091974@postgrespro.ru", "phone": "+70947279767"}
0005435282605	1E6C3E	7876 996978	VADIM SCHERBAKOV	{"phone": "+70849226556"}
0005435282606	1E6C3E	4403 167175	IGOR KONOVALOV	{"phone": "+70188650607"}
0005435282607	757386	0318 650165	DENIS SOLOVEV	{"email": "denis_solovev26091972@postgrespro.ru", "phone": "+70306124116"}
0005435282608	B3FA7E	4176 984069	ALEKSEY SHEVCHENKO	{"phone": "+70010310647"}
0005435282609	B3FA7E	4544 036717	OLESYA FOMINA	{"phone": "+70255338770"}
0005435282610	3F37C6	4802 787849	ANNA IVANOVA	{"email": "ivanova-a14071972@postgrespro.ru", "phone": "+70922444144"}
0005435282611	754DA2	8114 029276	ALEKSANDRA FEDOROVA	{"email": "fedorova.aleksandra_1960@postgrespro.ru", "phone": "+70819341382"}
0005435282612	F4E0A1	4833 420997	NIKOLAY KUZMIN	{"phone": "+70871421196"}
0005435282613	F4E0A1	2226 173941	NIKOLAY IVANOV	{"phone": "+70531182555"}
0005435282614	AE925F	2495 934314	VLADIMIR ROMANOV	{"email": "vladimir.romanov051971@postgrespro.ru", "phone": "+70158422565"}
0005435282615	F0C8A0	7091 081459	ELENA NESTEROVA	{"email": "elena_nesterova.05041967@postgrespro.ru", "phone": "+70968424828"}
0005435282616	F0C8A0	0497 160578	TATYANA KUZNECOVA	{"phone": "+70390345692"}
0005435282617	2A33B8	9487 095136	OLEG PETROV	{"email": "petrovo_011970@postgrespro.ru", "phone": "+70214118700"}
0005435282618	8EC4BE	4897 362466	YURIY FOMIN	{"email": "fominyuriy031977@postgrespro.ru", "phone": "+70305422265"}
0005435282619	77B3D0	5853 795375	ANATOLIY MATVEEV	{"phone": "+70846015831"}
0005435282620	77B3D0	5550 557492	DMITRIY ALEKSANDROV	{"phone": "+70373438862"}
0005435282621	7DB5AD	9492 693909	GALINA OSIPOVA	{"email": "osipova_galina-041985@postgrespro.ru", "phone": "+70771782140"}
0005435282622	7DB5AD	0415 078232	VASILIY ANTONOV	{"email": "vasiliy_antonov06061963@postgrespro.ru", "phone": "+70998286616"}
0005435282623	FDF4F0	5099 594069	TAMARA NIKOLAEVA	{"email": "t.nikolaeva.24101973@postgrespro.ru", "phone": "+70522304163"}
0005435282624	3A693B	6964 814112	RIMMA MATVEEVA	{"email": "rimma_matveeva-21111972@postgrespro.ru", "phone": "+70182662513"}
0005435282625	3A693B	3575 937225	DANIYA KISELEVA	{"phone": "+70260675805"}
0005435282626	DBA57F	4974 035187	PAVEL MELNIKOV	{"email": "melnikov-pavel081979@postgrespro.ru", "phone": "+70301016536"}
0005435282627	DBA57F	5202 702988	TATYANA KOLESNIKOVA	{"email": "kolesnikovatatyana_1962@postgrespro.ru", "phone": "+70760543477"}
0005435282628	359F0E	9179 923459	ANTON PAVLOV	{"phone": "+70424663191"}
0005435282629	1D1219	4969 208828	MARGARITA BORISOVA	{"email": "borisova_margarita-1968@postgrespro.ru", "phone": "+70700741658"}
0005435282630	1D1219	5485 993462	MARIYA KONDRATEVA	{"phone": "+70031479457"}
0005435282631	C59564	5983 587503	PAVEL TIKHONOV	{"phone": "+70278473028"}
0005435282632	C59564	4807 204359	NATALYA TARASOVA	{"email": "natalya.tarasova-1974@postgrespro.ru", "phone": "+70084580938"}
0005435282633	701EF5	8966 373682	NATALYA OSIPOVA	{"email": "natalyaosipova.111969@postgrespro.ru", "phone": "+70591689918"}
0005435282634	7062F1	1204 269737	ANNA CHERNOVA	{"email": "a-chernova.111967@postgrespro.ru", "phone": "+70036805355"}
0005435282635	7062F1	1737 249402	TATYANA NAZAROVA	{"email": "tnazarova-1967@postgrespro.ru", "phone": "+70952231769"}
0005435282636	B56D76	8121 191170	ELENA STEPANOVA	{"email": "elenastepanova071968@postgrespro.ru", "phone": "+70690142830"}
0005435282637	4C7F68	1558 367538	NIKOLAY FEDOROV	{"email": "fedorovn_101974@postgrespro.ru", "phone": "+70858315841"}
0005435282638	F09D6E	8103 815833	ROMAN FEDOROV	{"phone": "+70819963865"}
0005435282639	F09D6E	8018 630158	OLEG KULIKOV	{"email": "okulikov-30031977@postgrespro.ru", "phone": "+70762358395"}
0005435282640	596A9E	7924 093297	SVETLANA VASILEVA	{"email": "svetlana_vasileva_021961@postgrespro.ru", "phone": "+70282371481"}
0005435282641	7C41A3	7520 884985	ANDREY SIDOROV	{"phone": "+70083526441"}
0005435282642	58F679	4307 056825	IGOR VOLKOV	{"phone": "+70197374115"}
0005435282643	B31430	5226 847129	YURIY SEMENOV	{"phone": "+70256566429"}
0005435282644	2F8C1F	6522 999755	YURIY FOMIN	{"email": "fomin_y1974@postgrespro.ru", "phone": "+70587988511"}
0005435282645	90A477	5267 651438	ALEKSANDR MOISEEV	{"phone": "+70894097049"}
0005435282646	0A8FC0	2704 895710	MAKSIM KOZLOV	{"email": "kozlov_m.091972@postgrespro.ru", "phone": "+70712810134"}
0005435282647	0A8FC0	4475 392078	ALEKSANDR ALEKSEEV	{"email": "a.alekseev_091974@postgrespro.ru", "phone": "+70348401649"}
0005435282648	0A8FC0	6456 610342	MARINA SMIRNOVA	{"email": "smirnova.m.091975@postgrespro.ru", "phone": "+70736086375"}
0005435282649	07CE1B	7752 790349	DMITRIY KUZNECOV	{"email": "d.kuznecov-1956@postgrespro.ru", "phone": "+70349790334"}
0005435282650	07CE1B	3978 603627	OLGA KOZLOVA	{"email": "kozlova_o-081978@postgrespro.ru", "phone": "+70955898587"}
0005435282651	485A1B	6790 555170	ANASTASIYA MAKAROVA	{"email": "makarova.anastasiya.101979@postgrespro.ru", "phone": "+70181816239"}
0005435282652	8229B1	2673 877729	OLGA STEPANOVA	{"email": "o-stepanova-30081970@postgrespro.ru", "phone": "+70672205248"}
0005435282653	E28F16	6392 420681	ANDREY BELOV	{"email": "belov.a-1963@postgrespro.ru", "phone": "+70747687458"}
0005435282654	E28F16	9880 881880	VIKTOR SEMENOV	{"email": "viktor_semenov071971@postgrespro.ru", "phone": "+70611714021"}
0005435282655	E90F18	8228 674576	VLADIMIR SCHERBAKOV	{"email": "scherbakovv.08021970@postgrespro.ru", "phone": "+70035095337"}
0005435282656	9EA5AA	9000 316584	YULIYA ALEKSEEVA	{"email": "yuliya.alekseeva-101963@postgrespro.ru", "phone": "+70374363957"}
0005435282657	F07596	0492 767586	EKATERINA KUDRYASHOVA	{"email": "e.kudryashova.31011972@postgrespro.ru", "phone": "+70847987861"}
0005435282658	54447C	0423 659097	LYUDMILA RYABOVA	{"phone": "+70816048101"}
0005435282659	0EE870	6658 696172	MADINA BELOVA	{"email": "belova-m.011975@postgrespro.ru", "phone": "+70523512064"}
0005435282660	59EB37	4477 578876	ALEKSANDR MAKSIMOV	{"email": "a.maksimov_1990@postgrespro.ru", "phone": "+70070143036"}
0005435282661	850F9A	4105 335101	PRASKOVYA MASLOVA	{"phone": "+70665645964"}
0005435282662	97E882	7426 060212	SERGEY IVANOV	{"email": "sergey_ivanov_28121970@postgrespro.ru", "phone": "+70110315031"}
0005435282663	97E882	9705 034282	LYUDMILA GERASIMOVA	{"phone": "+70466324073"}
0005435282664	3A9781	2072 196923	NADEZHDA AKIMOVA	{"phone": "+70164249051"}
0005435282665	3A9781	5658 677080	ANASTASIYA RYABOVA	{"phone": "+70691253254"}
0005435282666	2BBE91	4113 678227	SVETLANA VOLKOVA	{"email": "volkova-s_081962@postgrespro.ru", "phone": "+70701597674"}
0005435282667	98E927	2231 222441	VLADIMIR RODIONOV	{"email": "v_rodionov011970@postgrespro.ru", "phone": "+70010605658"}
0005435282668	75C719	9499 986598	ARTEM EGOROV	{"email": "a.egorov.021974@postgrespro.ru", "phone": "+70579455466"}
0005435282669	BAAC40	0727 417485	ELENA KOMAROVA	{"email": "komarova_elena_1964@postgrespro.ru", "phone": "+70198988572"}
0005435282670	6FCAF3	1480 379735	IVAN GERASIMOV	{"phone": "+70429971049"}
0005435282671	3A2054	2936 387898	MARIYA TIKHONOVA	{"email": "mariya.tikhonova.1972@postgrespro.ru", "phone": "+70376974265"}
0005435282672	429EA2	3957 300972	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila_02041982@postgrespro.ru", "phone": "+70091842249"}
0005435282673	9ACE09	1058 305790	NIKOLAY OSIPOV	{"phone": "+70010499980"}
0005435282674	9ACE09	8564 134621	ALEKSANDR KULIKOV	{"email": "a_kulikov-12051979@postgrespro.ru", "phone": "+70160331663"}
0005435282675	9ACE09	7150 890242	ZOYA BORISOVA	{"phone": "+70845095257"}
0005435282676	EA0866	1259 232023	VIKTOR GRIGOREV	{"phone": "+70923311303"}
0005435282677	797488	7839 080116	PAVEL ZHURAVLEV	{"email": "p-zhuravlev-24121984@postgrespro.ru", "phone": "+70157233587"}
0005435282678	2CF795	6570 219148	VADIM ILIN	{"phone": "+70601461788"}
0005435282679	2CF795	4597 114541	FANIS DAVYDOV	{"phone": "+70481687932"}
0005435282680	D3AE00	7314 495378	YULIYA KOROLEVA	{"email": "koroleva.yuliya.15101968@postgrespro.ru", "phone": "+70788052842"}
0005435282681	BC3809	1676 838914	OLGA ERMAKOVA	{"phone": "+70847121087"}
0005435282682	BC3809	7129 533026	ALEKSANDR DENISOV	{"email": "aleksandr.denisov_26101966@postgrespro.ru", "phone": "+70355876436"}
0005435282683	FE2810	0116 049415	VALENTINA NESTEROVA	{"phone": "+70029303547"}
0005435282684	D2ED74	7547 380475	MIKHAIL NIKOLAEV	{"phone": "+70933360966"}
0005435282685	E42558	9537 356470	VERA GRISHINA	{"phone": "+70540686494"}
0005435282686	BB709D	2444 534817	MIKHAIL SAVELEV	{"phone": "+70764449401"}
0005435282687	6F73C9	4659 636529	GENNADIY BARANOV	{"email": "baranov-g_061959@postgrespro.ru", "phone": "+70959722547"}
0005435282688	799761	8072 662485	ALEKSANDR FROLOV	{"phone": "+70831743630"}
0005435282689	799761	9256 191322	GENNADIY MOROZOV	{"email": "morozov.gennadiy-111972@postgrespro.ru", "phone": "+70108355095"}
0005435282690	799761	4404 238063	NIKOLAY SIDOROV	{"phone": "+70604264720"}
0005435282691	748707	2941 303528	GENNADIY MOISEEV	{"phone": "+70342751059"}
0005435282692	B5B7EF	2579 540084	ELENA SOKOLOVA	{"email": "elena-sokolova-25011968@postgrespro.ru", "phone": "+70118257034"}
0005435282693	B5B7EF	2966 095970	SERGEY GAVRILOV	{"email": "gavrilov_s-15051980@postgrespro.ru", "phone": "+70174397278"}
0005435282694	8008C2	4234 432199	VALENTINA CHERNOVA	{"phone": "+70390118360"}
0005435282695	8008C2	5097 159615	ALEKSEY KUZMIN	{"email": "aleksey_kuzmin-29031971@postgrespro.ru", "phone": "+70906526852"}
0005435282696	E8A230	0158 631775	FEDOR KONOVALOV	{"email": "f-konovalov.1967@postgrespro.ru", "phone": "+70746474037"}
0005435282697	E8A230	9180 933180	SVETLANA IVANOVA	{"email": "svetlana.ivanova11111954@postgrespro.ru", "phone": "+70475123293"}
0005435282698	E8A230	4416 940182	ELIZAVETA NIKOLAEVA	{"phone": "+70891887400"}
0005435282699	474E95	6466 456876	VLADIMIR FOMIN	{"email": "vladimir.fomin121972@postgrespro.ru", "phone": "+70138246402"}
0005435282700	474E95	5323 454706	GUZEL SAVELEVA	{"email": "saveleva_guzel-1975@postgrespro.ru", "phone": "+70019230153"}
0005435282701	6D7523	0094 098704	VALENTIN ALEKSANDROV	{"email": "valentinaleksandrov-1969@postgrespro.ru", "phone": "+70077266199"}
0005435282702	6D7523	1970 862551	NIKOLAY GUSEV	{"phone": "+70336807143"}
0005435282703	915746	9134 785060	OLGA SEMENOVA	{"email": "o_semenova.091969@postgrespro.ru", "phone": "+70704024541"}
0005435282704	915746	3548 671964	TATYANA ROMANOVA	{"phone": "+70399383846"}
0005435282705	DC78F9	9820 327376	LEONID KARPOV	{"phone": "+70544929138"}
0005435282706	DC78F9	9409 640305	VIKTOR EGOROV	{"email": "egorovviktor19061966@postgrespro.ru", "phone": "+70687446738"}
0005435282707	DD01C6	0758 553927	ALEKSANDR PAVLOV	{"phone": "+70722514409"}
0005435282708	A15910	5455 361327	VADIM YAKOVLEV	{"phone": "+70807485290"}
0005435282709	0FED49	2689 233830	TAMARA ROMANOVA	{"phone": "+70446183545"}
0005435282710	0FED49	3010 394155	STANISLAV MOISEEV	{"phone": "+70318157250"}
0005435282711	A70FD5	4136 435070	NINA STEPANOVA	{"email": "n.stepanova-02011979@postgrespro.ru", "phone": "+70882861515"}
0005435282713	E5D0B7	0607 518878	VLADIMIR ZAYCEV	{"phone": "+70054299406"}
0005435282714	5A2B22	6170 538748	KRISTINA ZAKHAROVA	{"email": "zakharova_kristina.11081973@postgrespro.ru", "phone": "+70848235324"}
0005435282715	923558	5797 906759	EKATERINA ILINA	{"email": "ilina-ekaterina.1973@postgrespro.ru", "phone": "+70229714905"}
0005435282716	450994	8515 347519	PAVEL FEDOTOV	{"phone": "+70731313164"}
0005435282717	72678E	0011 535283	GLEB KAZAKOV	{"email": "gleb_kazakov-091986@postgrespro.ru", "phone": "+70170925884"}
0005435282718	E84CC7	1859 990849	VIKTOR MAKSIMOV	{"email": "viktor.maksimov_1974@postgrespro.ru", "phone": "+70105926583"}
0005435282719	7F05C3	5757 446761	TAMARA DAVYDOVA	{"email": "tamara.davydova.27051974@postgrespro.ru", "phone": "+70444599454"}
0005435282720	12A7AC	1393 983424	MAKSIM MEDVEDEV	{"email": "m_medvedev-31051974@postgrespro.ru", "phone": "+70105505569"}
0005435282721	712F32	9082 417067	VLADIMIR BELOV	{"phone": "+70423285768"}
0005435282722	BB7506	6350 705644	VALENTINA SOROKINA	{"email": "sorokinav-21121967@postgrespro.ru", "phone": "+70198077163"}
0005435282723	BB7506	7289 430531	IGOR VOLKOV	{"email": "volkov-igor.08021968@postgrespro.ru", "phone": "+70465870402"}
0005435282724	3EA207	4549 665934	MARINA MIKHAYLOVA	{"phone": "+70035343489"}
0005435282725	3EA207	1557 623510	LYUBOV KISELEVA	{"email": "kiselevalyubov-021969@postgrespro.ru", "phone": "+70838375607"}
0005435282726	ACA5A9	2380 440906	NIKOLAY POPOV	{"email": "nikolay_popov.14021969@postgrespro.ru", "phone": "+70790849355"}
0005435282727	7C86F1	5185 865833	DMITRIY PETROV	{"email": "petrov_dmitriy.1982@postgrespro.ru", "phone": "+70717592872"}
0005435282728	DB1E47	2378 579083	ELENA TIMOFEEVA	{"phone": "+70346944307"}
0005435282729	DB1E47	4226 427809	ALINA KOROLEVA	{"email": "koroleva-alina_1967@postgrespro.ru", "phone": "+70553666383"}
0005435282730	DB1E47	4979 241765	VYACHESLAV MIKHAYLOV	{"phone": "+70087418023"}
0005435282731	DB1E47	9133 335402	FARID KAZAKOV	{"phone": "+70963772212"}
0005435282732	66EECC	3924 400708	EKATERINA NIKIFOROVA	{"email": "ekaterina.nikiforova-1973@postgrespro.ru", "phone": "+70954845047"}
0005435282733	66EECC	8988 949750	NATALYA MAKAROVA	{"email": "natalya.makarova.22021976@postgrespro.ru", "phone": "+70596246419"}
0005435282734	D0EDBB	5478 265543	VASILIY MEDVEDEV	{"email": "medvedevv-1986@postgrespro.ru", "phone": "+70166617825"}
0005435282735	03E2FB	3264 812583	LYUDMILA BORISOVA	{"phone": "+70911350046"}
0005435282736	182D42	0049 014082	LYUBOV ZAKHAROVA	{"email": "lyubov_zakharova.24111983@postgrespro.ru", "phone": "+70355049045"}
0005435282737	2D4822	1189 494536	ALEKSEY EGOROV	{"email": "egorovaleksey.29061973@postgrespro.ru", "phone": "+70688220966"}
0005435282738	5CE674	1186 988312	GALINA ZAKHAROVA	{"email": "g_zakharova_23041979@postgrespro.ru", "phone": "+70336630276"}
0005435282739	5CE674	4661 321157	EKATERINA GORBUNOVA	{"phone": "+70734091149"}
0005435282740	87864A	7845 961951	MARINA NESTEROVA	{"phone": "+70116465891"}
0005435282741	87864A	9275 814899	ALEKSEY VLASOV	{"email": "avlasov-18011987@postgrespro.ru", "phone": "+70821171204"}
0005435282742	105653	8604 940933	OLGA KOZLOVA	{"phone": "+70671882960"}
0005435282743	49842C	0973 113806	OLGA TITOVA	{"email": "olga_titova-051967@postgrespro.ru", "phone": "+70142666881"}
0005435282744	522A54	3196 041830	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova-121971@postgrespro.ru", "phone": "+70856429277"}
0005435282745	6E9022	6608 904420	DMITRIY YAKOVLEV	{"email": "yakovlevdmitriy.031975@postgrespro.ru", "phone": "+70965827329"}
0005435282746	985118	3428 112476	PRASKOVYA BORISOVA	{"phone": "+70798900036"}
0005435282747	A556F8	3654 449700	ILYA NIKOLAEV	{"email": "ilya-nikolaev22111972@postgrespro.ru", "phone": "+70020536920"}
0005435282748	A556F8	2899 531185	DAVID KUZNECOV	{"email": "david_kuznecov_051976@postgrespro.ru", "phone": "+70419185491"}
0005435282749	837838	5021 602291	ROMAN RODIONOV	{"phone": "+70111567689"}
0005435282750	837838	1780 946322	SVETLANA MIKHAYLOVA	{"email": "mikhaylova-s-15101962@postgrespro.ru", "phone": "+70099864040"}
0005435282751	837838	2904 627374	ANTONIDA ZOTOVA	{"phone": "+70525553784"}
0005435282752	6D0FFA	5753 152596	MARIYA VASILEVA	{"phone": "+70507734224"}
0005435282753	576E41	0878 915805	ALEKSEY ANTONOV	{"phone": "+70093274256"}
0005435282754	2E0FBC	8947 163412	ALEKSEY FILIPPOV	{"email": "aleksey_filippov11071978@postgrespro.ru", "phone": "+70872498484"}
0005435282755	773858	0345 337288	NIKOLAY MOROZOV	{"email": "morozov-nikolay-1977@postgrespro.ru", "phone": "+70247633630"}
0005435282756	CEAC81	6790 572926	VITALIY KARPOV	{"email": "karpov-vitaliy_26111973@postgrespro.ru", "phone": "+70568052327"}
0005435282757	CEAC81	6481 823947	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana111980@postgrespro.ru", "phone": "+70829512231"}
0005435282758	D7B649	3757 102301	VALERIY MAKAROV	{"phone": "+70382935133"}
0005435282759	D7B649	4489 520888	IGOR FROLOV	{"email": "frolov-igor03121974@postgrespro.ru", "phone": "+70562574096"}
0005435282760	D7B649	8997 506343	OLESYA LOGINOVA	{"email": "loginovaolesya21031968@postgrespro.ru", "phone": "+70980267309"}
0005435282761	1B0BF2	4430 553424	NATALYA NESTEROVA	{"email": "natalya-nesterova071976@postgrespro.ru", "phone": "+70103852445"}
0005435282762	1B0BF2	2487 042365	ALENA DANILOVA	{"email": "alenadanilova_061980@postgrespro.ru", "phone": "+70141367640"}
0005435282763	BC2802	4743 437292	TAGIR BARANOV	{"email": "baranov.t011982@postgrespro.ru", "phone": "+70991152610"}
0005435282764	BC2802	8821 708759	OLGA MOROZOVA	{"phone": "+70460019551"}
0005435282765	406DC4	9751 603898	MATVEY MOROZOV	{"email": "morozov.m-24101972@postgrespro.ru", "phone": "+70795942476"}
0005435282766	779951	3035 186820	SERGEY MOROZOV	{"email": "s-morozov_101971@postgrespro.ru", "phone": "+70946425561"}
0005435282767	9E8BF9	1122 390498	ANATOLIY SIDOROV	{"email": "sidorovanatoliy-091977@postgrespro.ru", "phone": "+70411936253"}
0005435282768	FDAA5C	3530 926234	DENIS MOROZOV	{"email": "morozovdenis-1969@postgrespro.ru", "phone": "+70622012590"}
0005435282829	0712CE	3845 413538	ANNA ALEKSANDROVA	{"phone": "+70672088808"}
0005435282769	28095A	4987 992576	ZOYA GERASIMOVA	{"email": "z.gerasimova-041975@postgrespro.ru", "phone": "+70885195672"}
0005435282770	6E159A	5767 037406	VASILIY DAVYDOV	{"email": "v-davydov.1973@postgrespro.ru", "phone": "+70688938281"}
0005435282771	61BB95	9363 924117	NINA KUZNECOVA	{"phone": "+70019615997"}
0005435282772	E66908	9184 448273	VLADIMIR STEPANOV	{"phone": "+70077675946"}
0005435282773	63D4A6	9895 632608	GALINA IVANOVA	{"email": "ivanova-g.1965@postgrespro.ru", "phone": "+70384275213"}
0005435282774	40BC8D	1014 422464	ARINA NIKOLAEVA	{"email": "nikolaeva.arina30041972@postgrespro.ru", "phone": "+70477186029"}
0005435282775	BA7733	0258 860438	ALEKSANDR GRIGOREV	{"email": "grigorev-aleksandr-08121965@postgrespro.ru", "phone": "+70663276499"}
0005435282776	BA7733	8997 796368	ANDREY ANTONOV	{"email": "antonov.andrey.1971@postgrespro.ru", "phone": "+70823113794"}
0005435282777	5890C5	1363 932478	LIDIYA BOGDANOVA	{"phone": "+70142250136"}
0005435282778	8BABC0	1230 301788	IVAN PAVLOV	{"phone": "+70402374971"}
0005435282779	8BABC0	0838 521416	VLADIMIR MAKAROV	{"email": "vladimir.makarov-1973@postgrespro.ru", "phone": "+70491622647"}
0005435282780	266A15	5495 511972	LYUDMILA GAVRILOVA	{"email": "lyudmila.gavrilova_08041969@postgrespro.ru", "phone": "+70530667498"}
0005435282781	266A15	0935 477724	EVGENIY KUZNECOV	{"email": "ekuznecov-1976@postgrespro.ru", "phone": "+70390275414"}
0005435282782	B8A182	9009 133087	IRINA EGOROVA	{"email": "egorovairina051981@postgrespro.ru", "phone": "+70582094386"}
0005435282783	6EA006	4029 143551	YULIYA KONOVALOVA	{"phone": "+70057744214"}
0005435282784	6EA006	3123 811065	VLADIMIR FROLOV	{"email": "frolov.vladimir-06031987@postgrespro.ru", "phone": "+70970408986"}
0005435282785	378A52	1104 395030	LARISA FROLOVA	{"email": "larisa_frolova-031970@postgrespro.ru", "phone": "+70013492973"}
0005435282786	107EF3	8462 949527	INESSA SEMENOVA	{"email": "inessa_semenova_111980@postgrespro.ru", "phone": "+70630001058"}
0005435282787	1A7200	0599 433452	VLADIMIR MOROZOV	{"phone": "+70328126714"}
0005435282788	49C78E	4860 759904	YANINA FILIPPOVA	{"phone": "+70753411946"}
0005435282789	49C78E	8179 698831	KRISTINA SAVELEVA	{"phone": "+70176082520"}
0005435282790	B6FB07	9170 087007	KLAVDIYA ZOTOVA	{"phone": "+70024483519"}
0005435282791	9207DF	6458 253900	NIKOLAY PETROV	{"email": "nikolaypetrov.031971@postgrespro.ru", "phone": "+70881416233"}
0005435282792	561500	8653 908575	GULFIYA MOROZOVA	{"email": "gulfiyamorozova101964@postgrespro.ru", "phone": "+70803317393"}
0005435282793	04DBEF	1929 612631	ANNA RYABOVA	{"email": "anna.ryabova.1981@postgrespro.ru", "phone": "+70964298770"}
0005435282794	B83117	7222 858260	MARIYA GUSEVA	{"phone": "+70993934060"}
0005435282795	DD0F25	7631 158656	ANNA KISELEVA	{"phone": "+70075190150"}
0005435282796	DD0F25	8297 439012	VLADISLAV FROLOV	{"email": "v_frolov_1973@postgrespro.ru", "phone": "+70394752315"}
0005435282797	81F228	9258 082571	SERGEY DMITRIEV	{"email": "dmitriev_s-1967@postgrespro.ru", "phone": "+70719836562"}
0005435282798	E37874	6417 130590	DANILA ISAEV	{"phone": "+70304773158"}
0005435282799	606E5E	7841 647723	VYACHESLAV KUZNECOV	{"email": "kuznecov-vyacheslav_091973@postgrespro.ru", "phone": "+70248362643"}
0005435282800	F8F045	2389 872462	SVETLANA ZOTOVA	{"email": "zotovas25101979@postgrespro.ru", "phone": "+70953243231"}
0005435282801	B9424D	9757 795433	DMITRIY OSIPOV	{"phone": "+70163914558"}
0005435282802	0D3F5D	7151 330739	IRINA KALININA	{"email": "irina-kalinina_1972@postgrespro.ru", "phone": "+70221443555"}
0005435282803	0D3F5D	9992 343349	ANASTASIYA ZAKHAROVA	{"email": "anastasiyazakharova-09121975@postgrespro.ru", "phone": "+70958063542"}
0005435282804	5EF48A	0379 744885	IGOR MOROZOV	{"email": "i.morozov.111966@postgrespro.ru", "phone": "+70640405332"}
0005435282805	5EF48A	6119 236123	NINA SEMENOVA	{"phone": "+70234259007"}
0005435282806	5EF48A	5853 667939	ELIZAVETA ANISIMOVA	{"phone": "+70164628162"}
0005435282807	6A2ACF	7750 565900	OLEG SCHERBAKOV	{"email": "scherbakov.oleg1972@postgrespro.ru", "phone": "+70909379986"}
0005435282808	6A2ACF	8495 714251	VIKTOR PAVLOV	{"email": "viktorpavlov081978@postgrespro.ru", "phone": "+70389027168"}
0005435282809	67898A	6271 786128	ELENA ARKHIPOVA	{"email": "earkhipova_13111979@postgrespro.ru", "phone": "+70096947056"}
0005435282810	67898A	2312 258242	YULIYA YAKOVLEVA	{"email": "yakovleva.y_11021971@postgrespro.ru", "phone": "+70182378400"}
0005435282811	EADA15	1402 958525	SVETLANA ILINA	{"phone": "+70338062813"}
0005435282812	09C248	9580 526349	NATALYA NIKOLAEVA	{"email": "nikolaevan.10071983@postgrespro.ru", "phone": "+70243381824"}
0005435282813	952759	0090 151763	SERGEY CHERNOV	{"phone": "+70884271482"}
0005435282814	952759	7390 005357	ANDREY DENISOV	{"phone": "+70533763907"}
0005435282815	B3F3E9	4871 173989	ANNA VOLKOVA	{"phone": "+70209939187"}
0005435282816	B3F3E9	6291 011920	GENNADIY GERASIMOV	{"phone": "+70001026016"}
0005435282817	543500	4377 918258	ALEKSEY SCHERBAKOV	{"phone": "+70172451370"}
0005435282818	7032F7	4494 692168	EVDOKIYA IVANOVA	{"phone": "+70272754829"}
0005435282819	7032F7	2267 797102	TATYANA LEBEDEVA	{"email": "t_lebedeva-1965@postgrespro.ru", "phone": "+70546069411"}
0005435282820	978813	8408 109374	ANDREY KOZLOV	{"phone": "+70110776917"}
0005435282821	3CB918	0055 773818	LYUDMILA KOZLOVA	{"phone": "+70333415496"}
0005435282822	778CB4	6482 381924	MIKHAIL ZHUKOV	{"email": "m-zhukov1977@postgrespro.ru", "phone": "+70291404269"}
0005435282823	954222	3162 832615	SVETLANA LEBEDEVA	{"phone": "+70718194924"}
0005435282824	FBE1A0	2566 972425	RUSLAN KUZNECOV	{"phone": "+70043357365"}
0005435282825	FBE1A0	3633 905686	RASHIT STEPANOV	{"email": "stepanov-rashit_071963@postgrespro.ru", "phone": "+70813807692"}
0005435282826	3AF75C	7335 402809	GULNAZ MELNIKOVA	{"phone": "+70671216347"}
0005435282827	8A65EB	6931 278941	ALEKSANDR YAKOVLEV	{"phone": "+70353007076"}
0005435282828	D076F9	7709 555694	ALEKSEY KUDRYASHOV	{"phone": "+70073613796"}
0005435282830	EF4034	3183 175239	RAISA TITOVA	{"email": "raisa.titova06121978@postgrespro.ru", "phone": "+70485499539"}
0005435282831	C122B3	2197 084446	ALEKSEY IVANOV	{"email": "a.ivanov-25061953@postgrespro.ru", "phone": "+70979423539"}
0005435282832	C122B3	2331 601121	LYUBOV NIKITINA	{"email": "lnikitina031961@postgrespro.ru", "phone": "+70288385331"}
0005435282833	C122B3	4183 035166	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr.041975@postgrespro.ru", "phone": "+70551777536"}
0005435282834	DC9C5C	5097 223920	SVETLANA PETROVA	{"email": "s_petrova-1958@postgrespro.ru", "phone": "+70219330846"}
0005435282835	B10F59	8252 832763	NINA MIKHAYLOVA	{"email": "mikhaylova.n-011975@postgrespro.ru", "phone": "+70111107233"}
0005435282836	B10F59	9787 413424	TAMARA ZHURAVLEVA	{"email": "zhuravlevat_1964@postgrespro.ru", "phone": "+70652833215"}
0005435282837	484EA4	4517 523774	VALENTINA FOMINA	{"email": "v_fomina071973@postgrespro.ru", "phone": "+70698777040"}
0005435282838	484EA4	6720 450752	VIKTORIYA GUSEVA	{"email": "guseva-viktoriya.1971@postgrespro.ru", "phone": "+70478611091"}
0005435282839	484EA4	4342 056583	ZOYA SIDOROVA	{"phone": "+70608025922"}
0005435282840	46DE1D	9928 799324	SVETLANA MAKAROVA	{"phone": "+70554809350"}
0005435282841	46DE1D	4766 040238	TIMUR VOLKOV	{"phone": "+70829923928"}
0005435282842	CA9AB2	0264 921509	ALEKSANDR PETROV	{"email": "petrovaleksandr_07041966@postgrespro.ru", "phone": "+70773212539"}
0005435282843	CA9AB2	2726 234376	TATYANA ILINA	{"phone": "+70247075513"}
0005435282844	CA9AB2	6716 865078	ANASTASIYA KARPOVA	{"email": "a_karpova-07021986@postgrespro.ru", "phone": "+70145933948"}
0005435282845	58BB06	4188 370191	KSENIYA YAKOVLEVA	{"phone": "+70188957196"}
0005435282846	9A360E	8539 403768	VLADIMIR NAZAROV	{"phone": "+70178067140"}
0005435282847	5CA0D0	2087 019748	BOGDAN FROLOV	{"phone": "+70459451178"}
0005435282848	163E74	9468 170459	ANZHELA CHERNOVA	{"email": "chernova_anzhela031959@postgrespro.ru", "phone": "+70284568814"}
0005435282849	65AF16	0644 111411	NATALYA IVANOVA	{"email": "n-ivanova_10081964@postgrespro.ru", "phone": "+70292181754"}
0005435282850	EF3A9E	0233 703481	VIKTOR ABRAMOV	{"email": "v-abramov.1963@postgrespro.ru", "phone": "+70230670495"}
0005435282851	EF3A9E	8682 062136	VALENTIN MAKSIMOV	{"email": "valentin-maksimov_1983@postgrespro.ru", "phone": "+70868045389"}
0005435282852	EF3A9E	5786 658515	EKATERINA TARASOVA	{"phone": "+70637393329"}
0005435282853	A94F5F	2951 064099	MARGARITA ZOTOVA	{"email": "zotovamargarita1961@postgrespro.ru", "phone": "+70451560213"}
0005435282854	2F3A5F	3655 110868	ELENA KOROLEVA	{"email": "elena_koroleva_121977@postgrespro.ru", "phone": "+70734899959"}
0005435282855	2F3A5F	7541 039709	ALEKSEY KUZMIN	{"phone": "+70770219111"}
0005435282856	76C7F7	7949 358478	IRINA MAKAROVA	{"email": "irina_makarova_28031976@postgrespro.ru", "phone": "+70991334429"}
0005435282857	63EBA9	4119 180833	ALINA NESTEROVA	{"email": "nesterovaa.061971@postgrespro.ru", "phone": "+70567533043"}
0005435282858	BCFDC7	3419 789416	RAISA MOISEEVA	{"phone": "+70991907615"}
0005435282859	BCFDC7	3537 931832	RAISA SAVELEVA	{"phone": "+70879295902"}
0005435282860	390D90	6303 799758	ALEKSANDR SMIRNOV	{"email": "a_smirnov1977@postgrespro.ru", "phone": "+70290441935"}
0005435282861	390D90	3326 289245	VADIM OSIPOV	{"email": "osipovvadim.041976@postgrespro.ru", "phone": "+70939992760"}
0005435282862	390D90	2292 144090	ALEKSEY KULIKOV	{"email": "akulikov-26061967@postgrespro.ru", "phone": "+70703581625"}
0005435282863	625A57	6180 718325	ALEKSANDR FEDOROV	{"phone": "+70388413976"}
0005435282864	625A57	8424 517877	ALEKSANDR ILIN	{"phone": "+70710809957"}
0005435282865	072847	1587 068194	YULIYA KISELEVA	{"phone": "+70257245426"}
0005435282866	072847	1353 098080	ALEKSANDR MAKSIMOV	{"phone": "+70483058706"}
0005435282867	D2DBA0	4459 520541	YURIY KUZNECOV	{"email": "yuriykuznecov_22021969@postgrespro.ru", "phone": "+70703120262"}
0005435282868	2F14E5	0548 704762	TATYANA KUDRYASHOVA	{"email": "kudryashova.tatyana.081962@postgrespro.ru", "phone": "+70418037536"}
0005435282869	2F14E5	3060 696459	IRINA IVANOVA	{"phone": "+70253574996"}
0005435282870	2F14E5	6018 549854	DMITRIY OSIPOV	{"email": "d_osipov.18061967@postgrespro.ru", "phone": "+70521984702"}
0005435282871	FFE129	0614 934040	DMITRIY ALEKSEEV	{"phone": "+70616394733"}
0005435282872	820120	2475 100409	MAKSIM PETROV	{"email": "petrov.maksim.31121979@postgrespro.ru", "phone": "+70521341941"}
0005435282873	97ABA2	9342 308970	GULNARA VOLKOVA	{"email": "volkovag091978@postgrespro.ru", "phone": "+70802699739"}
0005435282874	C10955	0837 167703	NINA KUZNECOVA	{"email": "kuznecovan.10051977@postgrespro.ru", "phone": "+70929896888"}
0005435282875	C10955	7854 920826	TAISIYA SCHERBAKOVA	{"email": "taisiyascherbakova03111963@postgrespro.ru", "phone": "+70066057455"}
0005435282876	085229	0451 942413	TATYANA RODIONOVA	{"phone": "+70866771301"}
0005435282877	085229	6365 587140	SERGEY VASILEV	{"email": "sergey.vasilev_041976@postgrespro.ru", "phone": "+70440804764"}
0005435282878	085229	8985 025830	ANASTASIYA KUZNECOVA	{"phone": "+70774622529"}
0005435282879	A295CD	8851 135264	POLINA KOMAROVA	{"phone": "+70287530842"}
0005435282880	2B5BC9	0942 384063	MIKHAIL POPOV	{"email": "mikhail_popov-05111972@postgrespro.ru", "phone": "+70330092578"}
0005435282881	2B5BC9	7252 640246	VLADIMIR ROMANOV	{"phone": "+70620229344"}
0005435282882	38E933	6231 871453	IRINA MIRONOVA	{"phone": "+70214549741"}
0005435282883	D46069	3466 400504	DMITRIY MIKHAYLOV	{"phone": "+70447854624"}
0005435282884	854936	6708 234324	MARIYA LAZAREVA	{"email": "lazareva-m-031963@postgrespro.ru", "phone": "+70708968892"}
0005435282885	352931	0312 282928	DMITRIY MIKHAYLOV	{"phone": "+70492158687"}
0005435282886	CFB470	5288 949586	DARYA ARKHIPOVA	{"email": "arkhipovadarya_1967@postgrespro.ru", "phone": "+70888229649"}
0005435282887	D55A44	2242 842675	ILYA ALEKSEEV	{"phone": "+70966117427"}
0005435282888	D55A44	7944 456826	OLGA NOVIKOVA	{"phone": "+70012758051"}
0005435282889	E696C3	9458 081145	YULIYA VLASOVA	{"email": "yuliyavlasova1971@postgrespro.ru", "phone": "+70761062311"}
0005435282890	96EFCB	6064 224687	ALEKSANDR ABRAMOV	{"phone": "+70778071720"}
0005435282891	96EFCB	0338 806076	YAN KUZMIN	{"email": "yan_kuzmin021964@postgrespro.ru", "phone": "+70458799072"}
0005435282892	593474	9861 845913	ZOYA MELNIKOVA	{"email": "zmelnikova-03081975@postgrespro.ru", "phone": "+70308744620"}
0005435282893	772E8A	9923 812432	DARYA POTAPOVA	{"phone": "+70777093196"}
0005435282894	61105C	5063 128862	GALINA KULIKOVA	{"phone": "+70744974279"}
0005435282895	890AB8	9028 021143	ZHANNA MEDVEDEVA	{"phone": "+70343075750"}
0005435282896	890AB8	3119 359710	OLGA SOKOLOVA	{"email": "sokolova.o101969@postgrespro.ru", "phone": "+70366070664"}
0005435282897	C17880	2276 820140	MIKHAIL EGOROV	{"phone": "+70345291098"}
0005435282898	C17880	5347 313229	IVAN FOMIN	{"email": "fomin-ivan_1982@postgrespro.ru", "phone": "+70051608426"}
0005435282899	CA4FE3	9830 642917	ELENA NAZAROVA	{"email": "nazarova-elena14111973@postgrespro.ru", "phone": "+70856438068"}
0005435282900	37F8CF	3596 947602	ANTON MOISEEV	{"phone": "+70956942651"}
0005435282901	60EA86	6393 651816	ANDREY ANDREEV	{"email": "andrey.andreev.1976@postgrespro.ru", "phone": "+70127510041"}
0005435282902	67730A	2112 277993	EKATERINA RYABOVA	{"email": "e_ryabova_1970@postgrespro.ru", "phone": "+70232981777"}
0005435282903	F35F6C	3270 135475	VYACHESLAV ROMANOV	{"phone": "+70494369118"}
0005435282904	DD35E9	7981 819903	SERGEY MAKSIMOV	{"phone": "+70761140569"}
0005435282905	DD35E9	6738 939191	MAKSIM KUZNECOV	{"email": "kuznecov.maksim.051964@postgrespro.ru", "phone": "+70265568289"}
0005435282906	E5C810	7062 437393	KRISTINA NAZAROVA	{"email": "nazarovakristina.1969@postgrespro.ru", "phone": "+70748620836"}
0005435282907	5B5C3E	0164 112638	TATYANA EFIMOVA	{"email": "tefimova.101965@postgrespro.ru", "phone": "+70806671166"}
0005435282908	CE3480	4226 508525	VLADIMIR IVANOV	{"phone": "+70774559277"}
0005435282909	CE3480	3637 410445	IRINA DENISOVA	{"phone": "+70157101921"}
0005435282910	499FBE	0563 357252	NINA ABRAMOVA	{"email": "abramova_nina1976@postgrespro.ru", "phone": "+70721716709"}
0005435282911	DE594B	0066 932614	OKSANA KOROLEVA	{"phone": "+70385065327"}
0005435282912	DE594B	1948 625537	ANASTASIYA MOROZOVA	{"email": "morozova_anastasiya-10021974@postgrespro.ru", "phone": "+70297908252"}
0005435282913	8F6BDE	7902 809333	NATALYA ARKHIPOVA	{"phone": "+70775731128"}
0005435282914	8F6BDE	4231 067350	ALENA FILATOVA	{"phone": "+70998667411"}
0005435282915	544767	6694 476348	LYUBOV IVANOVA	{"email": "lyubov_ivanova18121968@postgrespro.ru", "phone": "+70597219563"}
0005435282916	AED317	2248 437916	NATALYA KALININA	{"phone": "+70119303520"}
0005435282917	EEE94A	8581 311850	VLADIMIR SOKOLOV	{"email": "sokolov-v.1968@postgrespro.ru", "phone": "+70239354437"}
0005435282918	EEE94A	3608 337425	OLESYA LUKYANOVA	{"email": "lukyanovao24061977@postgrespro.ru", "phone": "+70041091268"}
0005435282919	1C7A78	6783 671518	OLGA MOROZOVA	{"email": "o.morozova_1971@postgrespro.ru", "phone": "+70810878462"}
0005435282920	1C7A78	3844 230949	RAIS GUSEV	{"email": "rais.gusev_24121966@postgrespro.ru", "phone": "+70870601256"}
0005435282921	002EED	9556 627867	ROZA VASILEVA	{"email": "r_vasileva.1975@postgrespro.ru", "phone": "+70948671153"}
0005435282922	002EED	4397 401841	SERGEY DAVYDOV	{"email": "davydov-s22081984@postgrespro.ru", "phone": "+70016889942"}
0005435282923	E79EEE	5651 881395	IRINA KUZNECOVA	{"email": "ikuznecova051975@postgrespro.ru", "phone": "+70346271280"}
0005435282924	93579D	7769 773633	ANDREY IVANOV	{"phone": "+70353746734"}
0005435282925	65024B	4734 459409	ALEKSEY MIKHAYLOV	{"phone": "+70472671315"}
0005435282926	65024B	5066 154584	NADEZHDA POLYAKOVA	{"phone": "+70652809956"}
0005435282927	7EF1FA	0167 040867	GULSINA MIKHAYLOVA	{"email": "mikhaylova_gulsina101969@postgrespro.ru", "phone": "+70263539458"}
0005435282928	24CD82	0885 374580	MIKHAIL IVANOV	{"phone": "+70208530713"}
0005435282929	EA472D	2401 653134	ALEKSEY FOMIN	{"email": "fomin.a26111976@postgrespro.ru", "phone": "+70380480434"}
0005435282930	0C3128	3198 642163	ALEKSANDRA VASILEVA	{"email": "aleksandravasileva_031968@postgrespro.ru", "phone": "+70660456043"}
0005435282931	1DEA7E	0710 746866	SERGEY ANTONOV	{"email": "s_antonov_17061971@postgrespro.ru", "phone": "+70690758953"}
0005435282932	6459A0	3935 275754	YURIY NIKOLAEV	{"phone": "+70027887924"}
0005435282933	DC51B5	4058 464174	MIKHAIL MOROZOV	{"phone": "+70388749700"}
0005435282934	DC51B5	5779 321537	ELENA IVANOVA	{"phone": "+70235899283"}
0005435282935	2E5D56	5908 772345	SERGEY MELNIKOV	{"phone": "+70877973997"}
0005435282936	B5F39E	1773 499568	MAKSIM VOLKOV	{"email": "m-volkov.1976@postgrespro.ru", "phone": "+70557663799"}
0005435282937	B5F39E	5048 071227	VLADIMIR YAKOVLEV	{"email": "v.yakovlev.28041976@postgrespro.ru", "phone": "+70478341351"}
0005435282938	B5F39E	4203 259644	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov_061972@postgrespro.ru", "phone": "+70349314540"}
0005435282939	844509	6181 982897	TATYANA DENISOVA	{"phone": "+70314575410"}
0005435282940	4E91DE	5061 779032	PAVEL SHEVCHENKO	{"phone": "+70203186805"}
0005435282941	4E91DE	8616 945877	OLGA KONOVALOVA	{"email": "olga-konovalova-25111978@postgrespro.ru", "phone": "+70537014941"}
0005435282942	4E91DE	7784 297060	VALENTIN ILIN	{"phone": "+70306688397"}
0005435282943	4FA821	6977 779809	MARINA PAVLOVA	{"email": "marina.pavlova-03031978@postgrespro.ru", "phone": "+70403422957"}
0005435282944	9C09E5	8071 900890	SVETLANA BORISOVA	{"email": "borisova_svetlana_1978@postgrespro.ru", "phone": "+70575865940"}
0005435282945	08896A	3682 568141	TATYANA ERMAKOVA	{"email": "tatyana.ermakova14081967@postgrespro.ru", "phone": "+70873728613"}
0005435282946	92392D	6560 954671	ANTONINA MALYSHEVA	{"email": "amalysheva041984@postgrespro.ru", "phone": "+70147888237"}
0005435282947	E1EAB2	7746 935336	ALEKSANDR OSIPOV	{"phone": "+70568560396"}
0005435282948	2FBDE1	6105 075357	SVETLANA SCHERBAKOVA	{"phone": "+70627105084"}
0005435282949	2FBDE1	6082 774296	OLEG MATVEEV	{"email": "matveev_oleg-1986@postgrespro.ru", "phone": "+70408845280"}
0005435282950	25FC87	6863 397294	VITALIY SOROKIN	{"email": "v_sorokin-051969@postgrespro.ru", "phone": "+70001557634"}
0005435282951	25FC87	5732 875050	ALBINA CHERNOVA	{"email": "a-chernova08051973@postgrespro.ru", "phone": "+70141227917"}
0005435282952	4133E1	8190 985415	SERGEY ABRAMOV	{"email": "s.abramov19041968@postgrespro.ru", "phone": "+70884257979"}
0005435282953	4133E1	2398 828702	EKATERINA KOROLEVA	{"email": "ekaterina_koroleva.06041965@postgrespro.ru", "phone": "+70250629731"}
0005435282954	FCEF5F	8887 798698	NINA PETROVA	{"email": "petrovanina16101967@postgrespro.ru", "phone": "+70852786715"}
0005435282955	6CE7A7	4791 594574	EGOR ANTONOV	{"phone": "+70353756691"}
0005435282956	F341C6	4683 865310	EVGENIY NAZAROV	{"email": "evgeniy_nazarov011964@postgrespro.ru", "phone": "+70437272807"}
0005435282957	F341C6	3920 256072	VALENTINA DMITRIEVA	{"email": "dmitrieva.valentina-1974@postgrespro.ru", "phone": "+70267209039"}
0005435282958	984D03	2388 414633	ALEKSANDRA TARASOVA	{"email": "tarasova.a1982@postgrespro.ru", "phone": "+70946953282"}
0005435282959	BA4EF7	1298 362516	VYACHESLAV OSIPOV	{"phone": "+70975643735"}
0005435282960	BA4EF7	8815 942299	GALINA NOVIKOVA	{"phone": "+70431330487"}
0005435282961	6814D3	4982 327121	KRISTINA SOKOLOVA	{"email": "sokolovak.021968@postgrespro.ru", "phone": "+70284219326"}
0005435282962	6814D3	8881 793974	ELENA ROMANOVA	{"phone": "+70333430427"}
0005435282963	A19AC0	3481 686013	YULIYA KOLESNIKOVA	{"email": "y_kolesnikova.1975@postgrespro.ru", "phone": "+70199655939"}
0005435282964	D57CB0	2839 636415	ELENA KISELEVA	{"phone": "+70940929961"}
0005435282965	CE6BD9	4202 614446	MARIYA KALININA	{"email": "mariyakalinina_111976@postgrespro.ru", "phone": "+70447193660"}
0005435282966	CE6BD9	0487 228366	OLGA ANDREEVA	{"phone": "+70009826597"}
0005435282967	4D16FB	3320 655170	SVETLANA SEMENOVA	{"phone": "+70433317264"}
0005435282968	4D16FB	6796 166583	VLADIMIR VOLKOV	{"email": "volkov_v-26011983@postgrespro.ru", "phone": "+70561697560"}
0005435282969	3603F2	3728 484445	YURIY GERASIMOV	{"email": "gerasimov_y03081974@postgrespro.ru", "phone": "+70489103345"}
0005435282970	3603F2	8297 071386	EVGENIY BORISOV	{"email": "borisov_evgeniy_1959@postgrespro.ru", "phone": "+70391120756"}
0005435282971	3603F2	0019 184923	ANTON ORLOV	{"phone": "+70816474963"}
0005435282972	6D20A6	7537 295483	LYUDMILA VASILEVA	{"email": "vasilevalyudmila-1972@postgrespro.ru", "phone": "+70624490934"}
0005435282973	6D20A6	4955 674845	YULIYA MAKAROVA	{"phone": "+70069882486"}
0005435282974	0884C8	0371 983172	ANDREY SMIRNOV	{"email": "smirnov-andrey-071972@postgrespro.ru", "phone": "+70932062278"}
0005435282975	CEE17A	0780 446741	NATALYA BELYAEVA	{"phone": "+70958370257"}
0005435282976	C287EB	8292 707863	BOGDAN FEDOROV	{"email": "b-fedorov-051975@postgrespro.ru", "phone": "+70679698079"}
0005435282977	EB5A49	0432 757494	ALIYA SAVELEVA	{"email": "aliya.saveleva_29061971@postgrespro.ru", "phone": "+70693884449"}
0005435282978	EB5A49	4494 641703	ANNA DAVYDOVA	{"phone": "+70811794763"}
0005435282979	6D8E64	0896 175170	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr.31011962@postgrespro.ru", "phone": "+70804158947"}
0005435282980	6D8E64	2666 685848	NELLYA EGOROVA	{"phone": "+70495165680"}
0005435282981	69D9CD	5576 440839	SOFYA SOKOLOVA	{"email": "sofyasokolova-041971@postgrespro.ru", "phone": "+70386022207"}
0005435282982	DF646D	2952 877193	TAISIYA VLASOVA	{"email": "taisiya.vlasova.14111964@postgrespro.ru", "phone": "+70054269177"}
0005435282983	8DF7E8	0694 140035	SVETLANA FEDOROVA	{"email": "s.fedorova111962@postgrespro.ru", "phone": "+70732419231"}
0005435282984	FF60CA	9405 608680	ANTONINA ARKHIPOVA	{"phone": "+70685121703"}
0005435282985	DBA391	5729 337410	TATYANA AFANASEVA	{"phone": "+70200606901"}
0005435282986	8B99B2	9326 850449	VASILIY KISELEV	{"email": "vasiliykiselev_101970@postgrespro.ru", "phone": "+70208708237"}
0005435282987	8B99B2	8754 992968	MIKHAIL BORISOV	{"phone": "+70835330559"}
0005435282988	B31EE4	6074 300239	VLADIMIR ZAYCEV	{"email": "zaycev-v_1968@postgrespro.ru", "phone": "+70319752967"}
0005435282989	B31EE4	2714 634960	TATYANA DANILOVA	{"email": "danilova.t_071951@postgrespro.ru", "phone": "+70125057964"}
0005435282990	D4C621	1772 000454	ILYA PETROV	{"phone": "+70757969207"}
0005435282991	3FE38C	6683 453830	MILANA STEPANOVA	{"email": "stepanova_milana-23021968@postgrespro.ru", "phone": "+70231645502"}
0005435282992	3FE38C	1747 242495	OLGA ALEKSEEVA	{"email": "alekseevaolga.071972@postgrespro.ru", "phone": "+70465090112"}
0005435282993	BB6A9B	1061 453608	EKATERINA KUZNECOVA	{"email": "kuznecovaekaterina_08011964@postgrespro.ru", "phone": "+70787169545"}
0005435282994	D87D3C	0803 158269	RUFIYA CHERNOVA	{"phone": "+70984721505"}
0005435282995	D87D3C	3477 823216	VASILIY DENISOV	{"email": "denisov.vasiliy041976@postgrespro.ru", "phone": "+70703878723"}
0005435282996	65AD23	8363 818413	NIKOLAY BONDARENKO	{"email": "nikolaybondarenko-06091962@postgrespro.ru", "phone": "+70442075287"}
0005435282997	5993E7	9289 956932	OLESYA DENISOVA	{"phone": "+70608228050"}
0005435282998	5993E7	4352 006438	YULIYA MIKHAYLOVA	{"email": "mikhaylova-yuliya.1980@postgrespro.ru", "phone": "+70311544805"}
0005435282999	9DF1AE	5523 203219	ELENA VLASOVA	{"email": "vlasovaelena1970@postgrespro.ru", "phone": "+70033266594"}
0005435283000	5834D9	3726 092731	ZINAIDA DANILOVA	{"email": "zinaida.danilova.03061971@postgrespro.ru", "phone": "+70654808634"}
0005435283001	CC98FC	6897 671492	PAVEL MIRONOV	{"email": "pavelmironov.1972@postgrespro.ru", "phone": "+70113167423"}
0005435283002	CC98FC	9492 203086	RUSLAN MELNIKOV	{"email": "melnikov_ruslan_111978@postgrespro.ru", "phone": "+70837747578"}
0005435283003	97E6A7	1877 083549	YULIYA VASILEVA	{"phone": "+70395025000"}
0005435283004	7BF279	9127 338659	ALBERT NIKITIN	{"phone": "+70721417688"}
0005435283005	7BF279	7597 415036	MARINA KISELEVA	{"email": "kiseleva-marina_15071965@postgrespro.ru", "phone": "+70907671091"}
0005435283006	FB936D	0734 963606	VLADIMIR MAKAROV	{"email": "makarov.v14061974@postgrespro.ru", "phone": "+70024973510"}
0005435283007	FB936D	0737 329707	TATYANA MATVEEVA	{"email": "matveeva.t_1967@postgrespro.ru", "phone": "+70568734609"}
0005435283008	3E16E9	8370 771093	MIKHAIL FILIPPOV	{"phone": "+70694768255"}
0005435283009	E9E5A6	0241 356622	ROZA YUDINA	{"email": "yudina-roza.28021973@postgrespro.ru", "phone": "+70159919410"}
0005435283010	E9E5A6	1200 838284	VALERIY SERGEEV	{"phone": "+70999808117"}
0005435283011	D700E5	7601 480569	VYACHESLAV KRASNOV	{"email": "vkrasnov_12111975@postgrespro.ru", "phone": "+70356712017"}
0005435283012	D700E5	1895 116063	VIKTOR SERGEEV	{"phone": "+70176444257"}
0005435283013	D700E5	5573 178127	GALINA SEMENOVA	{"email": "galinasemenova-10091969@postgrespro.ru", "phone": "+70693071825"}
0005435283014	5C7BEB	1184 031374	ALEKSANDR KUZNECOV	{"phone": "+70915925364"}
0005435283015	7D0D65	5916 405730	VLADIMIR RODIONOV	{"phone": "+70050967488"}
0005435283016	4B6701	0990 820796	TATYANA MEDVEDEVA	{"phone": "+70073118103"}
0005435283017	4B6701	7911 918489	NIKOLAY SAVELEV	{"email": "nikolay_savelev21101982@postgrespro.ru", "phone": "+70805644290"}
0005435283018	7BF0F2	5957 423366	MIKHAIL SOKOLOV	{"email": "sokolov-m_1973@postgrespro.ru", "phone": "+70388251378"}
0005435283019	FA37D1	1024 556401	YURIY ALEKSEEV	{"email": "yuriyalekseev_13091965@postgrespro.ru", "phone": "+70762640751"}
0005435283020	FA37D1	5474 167042	KSENIYA FROLOVA	{"phone": "+70575671841"}
0005435283021	D46F7D	4589 447303	NATALYA IVANOVA	{"email": "ivanova.n_27041967@postgrespro.ru", "phone": "+70903686136"}
0005435283022	D46F7D	6013 697719	NIKOLAY ANTONOV	{"phone": "+70977251428"}
0005435283023	D46F7D	9658 528047	NATALIYA MELNIKOVA	{"phone": "+70506449803"}
0005435283024	A1A1EC	4343 639700	IVAN PETROV	{"phone": "+70941428047"}
0005435283025	0486D0	6652 952073	VALERIY KUZNECOV	{"phone": "+70353472209"}
0005435283026	EC1925	4609 371691	OLGA POPOVA	{"phone": "+70928199417"}
0005435283027	0230C0	7764 391711	NATALYA KUDRYASHOVA	{"phone": "+70342172464"}
0005435283028	754872	6372 748169	DMITRIY SMIRNOV	{"email": "dmitriy_smirnov_031986@postgrespro.ru", "phone": "+70626636354"}
0005435283029	754872	2541 494958	ALEKSANDR KAZAKOV	{"email": "kazakov.aleksandr061985@postgrespro.ru", "phone": "+70423439852"}
0005435283030	BD4666	5695 875675	ALEKSEY SEMENOV	{"phone": "+70887478310"}
0005435283031	BD4666	8235 184714	MARIYA ROMANOVA	{"email": "romanova.mariya.021969@postgrespro.ru", "phone": "+70532147375"}
0005435283032	AF28DE	9101 608495	EVGENIY RODIONOV	{"phone": "+70794957067"}
0005435283033	AF28DE	6964 688719	ARTEM MIRONOV	{"phone": "+70664387008"}
0005435283034	763ED2	0192 937208	VIKTORIYA TIKHONOVA	{"phone": "+70423842424"}
0005435283035	92A2B1	1366 786659	ALEKSEY STEPANOV	{"phone": "+70875238310"}
0005435283036	92A2B1	1386 682257	IGOR MOROZOV	{"phone": "+70989796236"}
0005435283037	DA0C00	6553 322572	MIKHAIL ABRAMOV	{"email": "mikhail.abramov_17011981@postgrespro.ru", "phone": "+70308685482"}
0005435283038	F5419D	3678 457005	ALEKSEY POPOV	{"phone": "+70830524879"}
0005435283039	C5AA69	1900 909616	VIKTORIYA FILATOVA	{"phone": "+70013896297"}
0005435283040	6A04A8	9817 428982	RUSLAN ALEKSEEV	{"email": "alekseev_r09111973@postgrespro.ru", "phone": "+70505884379"}
0005435283041	017EB4	6003 461337	VITALIY KOROLEV	{"email": "v-korolev_28031972@postgrespro.ru", "phone": "+70113021806"}
0005435283042	10AED3	0817 117239	IVAN SOKOLOV	{"phone": "+70139370557"}
0005435283043	D47F86	8439 796830	ELENA LUKYANOVA	{"email": "lukyanova-e101974@postgrespro.ru", "phone": "+70057400505"}
0005435283044	D47F86	8446 112898	OKSANA KAZAKOVA	{"email": "o_kazakova-061956@postgrespro.ru", "phone": "+70618363132"}
0005435283045	0EAEBE	6367 760808	MAKSIM ABRAMOV	{"phone": "+70979583691"}
0005435283046	E5F6E9	7028 261144	ALEKSEY MAKAROV	{"email": "a_makarov031991@postgrespro.ru", "phone": "+70145585296"}
0005435283047	CF26A8	0511 974707	VIKTOR KUZMIN	{"email": "v_kuzmin-1964@postgrespro.ru", "phone": "+70278530319"}
0005435283048	CF26A8	7195 716500	TATYANA GRISHINA	{"phone": "+70011305116"}
0005435283049	28A7EF	9718 965384	SERGEY ZAKHAROV	{"phone": "+70418563818"}
0005435283050	7CC18D	1660 584853	SVETLANA LEBEDEVA	{"phone": "+70410356717"}
0005435283051	F07E15	7627 542907	MARIYA YUDINA	{"phone": "+70153081071"}
0005435283052	E37C52	7698 638216	NATALYA SEMENOVA	{"email": "natalya-semenova.1971@postgrespro.ru", "phone": "+70287689178"}
0005435283053	E37C52	3027 906746	ROMAN ABRAMOV	{"phone": "+70886084507"}
0005435283054	A6A625	9912 490501	VALENTIN NIKITIN	{"email": "nikitin-v.021974@postgrespro.ru", "phone": "+70060755166"}
0005435283055	F47802	1965 368397	OKSANA SEMENOVA	{"phone": "+70524278696"}
0005435283056	F47802	2191 919357	NATALYA GRISHINA	{"email": "grishina-n.1968@postgrespro.ru", "phone": "+70411184077"}
0005435283057	F47802	7493 917910	OLGA BOGDANOVA	{"phone": "+70658984363"}
0005435283058	A90DC6	0615 387967	VLADIMIR PAVLOV	{"phone": "+70172161758"}
0005435283059	A90DC6	0732 177061	OLEG KONOVALOV	{"email": "konovalov.o_041978@postgrespro.ru", "phone": "+70706398155"}
0005435283060	A90DC6	9048 247889	IRINA TIMOFEEVA	{"phone": "+70442318541"}
0005435283061	519157	9740 314332	DANIIL ZAYCEV	{"phone": "+70592105894"}
0005435283062	519157	6197 640343	LIDIYA LAZAREVA	{"phone": "+70009895275"}
0005435283063	366696	0784 505032	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana.08071955@postgrespro.ru", "phone": "+70601464807"}
0005435283064	366696	1968 672493	NIKITA MATVEEV	{"email": "matveev-nikita_20031981@postgrespro.ru", "phone": "+70484461047"}
0005435283065	C61274	5682 417035	VIOLETTA GORBUNOVA	{"email": "violettagorbunova.1974@postgrespro.ru", "phone": "+70336325057"}
0005435283066	C61274	5997 314006	VIKTORIYA POPOVA	{"phone": "+70554089536"}
0005435283067	81D89F	6785 951217	ANDREY STEPANOV	{"email": "andrey-stepanov_02121966@postgrespro.ru", "phone": "+70520822800"}
0005435283068	567090	1476 163482	ELENA BORISOVA	{"email": "elenaborisova.1983@postgrespro.ru", "phone": "+70059388865"}
0005435283069	567090	6554 043108	VLADIMIR MOROZOV	{"email": "vladimirmorozov-061975@postgrespro.ru", "phone": "+70624198514"}
0005435283070	E61016	9974 778061	GALINA AFANASEVA	{"email": "galina_afanaseva-09021972@postgrespro.ru", "phone": "+70741719173"}
0005435283071	E61016	0334 944660	ALEVTINA TIMOFEEVA	{"phone": "+70762423285"}
0005435283072	94738E	6839 580612	VLADISLAV DENISOV	{"phone": "+70566335795"}
0005435283073	24C4B9	4382 588063	TATYANA KUZNECOVA	{"email": "kuznecova-t-1966@postgrespro.ru", "phone": "+70976585279"}
0005435283074	501447	5561 104757	TAMARA VOROBEVA	{"email": "vorobevatamara-1973@postgrespro.ru", "phone": "+70669841828"}
0005435283075	CA37C9	4620 188820	EVGENIY EGOROV	{"email": "e-egorov.12031965@postgrespro.ru", "phone": "+70755224224"}
0005435283076	CA37C9	3149 109584	NINA ABRAMOVA	{"phone": "+70551208048"}
0005435283077	6CAC7A	5876 609136	TATYANA MOROZOVA	{"phone": "+70804337625"}
0005435283078	6CAC7A	2849 348208	SERGEY NOVIKOV	{"email": "snovikov-1970@postgrespro.ru", "phone": "+70613859158"}
0005435283079	7151A0	8532 281486	VALENTINA SIDOROVA	{"phone": "+70266133640"}
0005435283080	7151A0	0600 520167	ELIZAVETA BORISOVA	{"phone": "+70015667784"}
0005435283081	DA38CD	9522 970357	ALEKSANDR CHERNOV	{"phone": "+70866147644"}
0005435283082	4BBDA8	7756 357238	ALEKSANDR KOROLEV	{"email": "aleksandr.korolev-061967@postgrespro.ru", "phone": "+70501818656"}
0005435283083	233053	0783 913594	IGOR KUZNECOV	{"email": "i_kuznecov061980@postgrespro.ru", "phone": "+70109234928"}
0005435283084	233053	4839 093310	ELENA GERASIMOVA	{"email": "gerasimovae-06091969@postgrespro.ru", "phone": "+70313914978"}
0005435283085	53A1F8	5237 812068	OKSANA ALEKSEEVA	{"phone": "+70993188064"}
0005435283086	B9D17F	0688 084766	ANZHELIKA NESTEROVA	{"email": "nesterova_anzhelika.121980@postgrespro.ru", "phone": "+70782018241"}
0005435283087	B18C27	2203 846110	TATYANA KUZMINA	{"email": "kuzmina_tatyana_19081971@postgrespro.ru", "phone": "+70772537220"}
0005435283088	27CCB8	9023 147303	LEONID MOROZOV	{"email": "leonidmorozov.051975@postgrespro.ru", "phone": "+70078718628"}
0005435283089	4E7F4D	3249 658158	SEMEN KARPOV	{"email": "skarpov.061975@postgrespro.ru", "phone": "+70438338379"}
0005435283090	BA5A44	2872 099651	ALBINA KAZAKOVA	{"email": "kazakova_a_21051966@postgrespro.ru", "phone": "+70191498391"}
0005435283091	BA5A44	7037 067647	MIKHAIL MAKAROV	{"email": "m_makarov1976@postgrespro.ru", "phone": "+70748792912"}
0005435283092	C988D0	3003 547878	VALERIY MEDVEDEV	{"email": "v_medvedev_1983@postgrespro.ru", "phone": "+70265630876"}
0005435283093	DA7579	5447 945226	ANASTASIYA STEPANOVA	{"phone": "+70241543083"}
0005435283094	DA7579	3429 463384	GALINA IVANOVA	{"email": "ivanova-g.1973@postgrespro.ru", "phone": "+70314731907"}
0005435283095	EFFB57	9048 753068	DMITRIY SOKOLOV	{"phone": "+70080059940"}
0005435283096	EFFB57	0178 465476	ANNA GUSEVA	{"email": "guseva_anna-091966@postgrespro.ru", "phone": "+70487553328"}
0005435283097	EFFB57	2144 529237	IRINA ZAYCEVA	{"email": "zayceva-irina_031975@postgrespro.ru", "phone": "+70035202580"}
0005435283098	5669EF	9375 182077	RAVIL FOMIN	{"email": "fominr-18101975@postgrespro.ru", "phone": "+70165270927"}
0005435283099	12D84D	3637 617370	TATYANA EGOROVA	{"email": "tatyana_egorova_13051969@postgrespro.ru", "phone": "+70001990056"}
0005435283100	12D84D	4116 195502	ALEKSEY GRIGOREV	{"email": "a_grigorev.1973@postgrespro.ru", "phone": "+70206677873"}
0005435283101	9A1D95	5708 508508	ANNA KISELEVA	{"email": "a-kiseleva_121968@postgrespro.ru", "phone": "+70145422276"}
0005435283102	CC67E9	8492 497169	ELENA SERGEEVA	{"email": "sergeevaelena061969@postgrespro.ru", "phone": "+70823040570"}
0005435283103	FB0720	3210 986027	KLAVDIYA NIKOLAEVA	{"phone": "+70827016088"}
0005435283104	FB0720	3496 151048	VITALIY POPOV	{"email": "popovvitaliy.05081979@postgrespro.ru", "phone": "+70998874743"}
0005435283105	4B3913	0419 435607	ALEKSEY KISELEV	{"phone": "+70735361066"}
0005435283106	BACA11	4005 843332	ALEKSEY MOISEEV	{"email": "moiseev-aleksey061960@postgrespro.ru", "phone": "+70695966773"}
0005435283107	9CA760	7343 616617	NATALYA KOMAROVA	{"email": "komarova_natalya_011968@postgrespro.ru", "phone": "+70403807587"}
0005435283108	9CA760	9179 289838	VALERIY ILIN	{"email": "ilinv.06041975@postgrespro.ru", "phone": "+70880672508"}
0005435283109	4A9149	8463 650493	YURIY MELNIKOV	{"email": "y.melnikov1971@postgrespro.ru", "phone": "+70918892744"}
0005435283110	4A9149	6315 900002	ALEKSEY SERGEEV	{"phone": "+70985789208"}
0005435283111	C76BC0	6374 418193	VASILIY KUZNECOV	{"phone": "+70512892070"}
0005435283112	D1B945	9057 337055	ALEKSANDR IVANOV	{"phone": "+70179104696"}
0005435283113	562D79	4566 807117	DMITRIY PETROV	{"phone": "+70175971358"}
0005435283114	562D79	9092 278513	ALEKSANDR FEDOROV	{"phone": "+70644008097"}
0005435283115	1B1930	2414 043868	LYUBOV ABRAMOVA	{"email": "lyubov_abramova1977@postgrespro.ru", "phone": "+70135258641"}
0005435283116	19367D	6065 399291	YULIYA ALEKSANDROVA	{"phone": "+70707107909"}
0005435283117	E2AFFE	7004 971824	KIRILL KULIKOV	{"phone": "+70818223327"}
0005435283118	5EE965	2106 765426	LYUDMILA KUZNECOVA	{"email": "kuznecova_l_26061975@postgrespro.ru", "phone": "+70156154535"}
0005435283119	5EE965	8868 442069	OKSANA SMIRNOVA	{"phone": "+70122386389"}
0005435283120	E2258D	4465 292683	ELENA BOGDANOVA	{"phone": "+70135863405"}
0005435283121	E2258D	1860 240026	ANDREY KISELEV	{"email": "a.kiselev-24101970@postgrespro.ru", "phone": "+70312541848"}
0005435283122	4DF013	6603 444338	MARINA YAKOVLEVA	{"email": "m_yakovleva-29031989@postgrespro.ru", "phone": "+70410442512"}
0005435283123	E76E2D	9828 683247	ANNA MOROZOVA	{"phone": "+70517169072"}
0005435283124	E76E2D	1633 132864	ALEKSANDR ZAKHAROV	{"email": "zakharov-a_09031976@postgrespro.ru", "phone": "+70613409902"}
0005435283125	C312FB	0225 814813	SERGEY SIDOROV	{"phone": "+70493392685"}
0005435283126	C312FB	1018 419773	LARISA IVANOVA	{"email": "l-ivanova-14041973@postgrespro.ru", "phone": "+70663943716"}
0005435283127	40FF55	8304 556009	SVETLANA TROFIMOVA	{"phone": "+70044598607"}
0005435283128	40FF55	8260 922023	VLADIMIR MIKHAYLOV	{"phone": "+70950918517"}
0005435283129	41E62D	4414 199877	OLGA POPOVA	{"email": "o_popova.19071963@postgrespro.ru", "phone": "+70795610134"}
0005435283130	41E62D	1231 120520	IRINA BARANOVA	{"phone": "+70364877276"}
0005435283131	41E62D	3793 555053	MARAT ORLOV	{"email": "orlov_m17061977@postgrespro.ru", "phone": "+70095073510"}
0005435283132	DB1E96	5611 826810	ANASTASIYA PETROVA	{"email": "petrova_anastasiya-1973@postgrespro.ru", "phone": "+70626766151"}
0005435283133	072595	3031 258902	IVAN MOISEEV	{"phone": "+70391264712"}
0005435283134	17DBA0	9724 603413	ALEKSANDR KUZNECOV	{"phone": "+70558177467"}
0005435283135	E8686C	0267 697633	ANDREY STEPANOV	{"email": "stepanov.a_021974@postgrespro.ru", "phone": "+70021418373"}
0005435283136	E8686C	6317 399253	GALINA KONOVALOVA	{"email": "konovalova_g_14031974@postgrespro.ru", "phone": "+70409885644"}
0005435283137	EFF538	4043 592145	IVAN KONOVALOV	{"phone": "+70564569301"}
0005435283138	A24705	1434 263834	VLADIMIR FEDOROV	{"email": "fedorov.vladimir1968@postgrespro.ru", "phone": "+70953988900"}
0005435283139	A24705	9198 497561	NATALYA RODIONOVA	{"phone": "+70573524690"}
0005435283140	D98465	6962 295231	MARIYA SERGEEVA	{"phone": "+70399729319"}
0005435283141	D98465	1807 167954	NINA TARASOVA	{"phone": "+70159773973"}
0005435283142	61222E	2982 015728	VASILIY KUZNECOV	{"phone": "+70098523239"}
0005435283143	0D2B15	7578 764214	LIDIYA KOZLOVA	{"phone": "+70067126070"}
0005435283144	E58368	5105 947161	GALINA BELOVA	{"phone": "+70767858824"}
0005435283145	47B423	3215 356191	EKATERINA DMITRIEVA	{"email": "ekaterinadmitrieva_28021978@postgrespro.ru", "phone": "+70055823913"}
0005435283146	47B423	9934 731214	MARINA POPOVA	{"phone": "+70478327435"}
0005435283147	BE2FA1	6415 313292	ALSU MAKSIMOVA	{"phone": "+70206780531"}
0005435283148	88CF49	1880 919419	OLEG RODIONOV	{"email": "olegrodionov1980@postgrespro.ru", "phone": "+70161413637"}
0005435283149	020BEF	8140 537171	MAKSIM KOZLOV	{"phone": "+70096029804"}
0005435283150	3289D5	7218 216065	IRINA VLASOVA	{"phone": "+70484036738"}
0005435283151	3629DA	6869 674038	FARID MAKSIMOV	{"email": "faridmaksimov_10031986@postgrespro.ru", "phone": "+70613539214"}
0005435283152	771B3F	9537 448432	MIKHAIL KOZLOV	{"email": "kozlov.m1975@postgrespro.ru", "phone": "+70339439267"}
0005435283153	771B3F	1582 519315	NIKOLAY PAVLOV	{"email": "pavlov-nikolay-1966@postgrespro.ru", "phone": "+70832558586"}
0005435283154	72E730	7280 264195	VITALIY GUSEV	{"phone": "+70661820045"}
0005435283155	72E730	6647 985548	NATALYA KONDRATEVA	{"email": "kondrateva-n_17081966@postgrespro.ru", "phone": "+70183514095"}
0005435283156	72E730	6697 998803	SERGEY DENISOV	{"email": "denisov-sergey_061969@postgrespro.ru", "phone": "+70715302649"}
0005435283157	59FAF4	8342 745594	VALENTINA ZAKHAROVA	{"email": "v-zakharova.1970@postgrespro.ru", "phone": "+70564128334"}
0005435283158	C78B7B	0210 968402	IRINA KONDRATEVA	{"phone": "+70773212672"}
0005435283159	46B484	9010 966273	KRISTINA TIMOFEEVA	{"email": "timofeevak.081975@postgrespro.ru", "phone": "+70113503520"}
0005435283160	4FC18B	6669 347460	OLEG MIRONOV	{"phone": "+70105381805"}
0005435283161	5C02DF	5168 134040	ALEKSEY ORLOV	{"phone": "+70684581591"}
0005435283162	5C02DF	0184 518371	ANDREY AFANASEV	{"email": "afanasevandrey_101972@postgrespro.ru", "phone": "+70868847826"}
0005435283163	F2A1AD	0391 191854	YULIYA POPOVA	{"email": "y.popova1973@postgrespro.ru", "phone": "+70680835163"}
0005435283164	7A299C	7719 497773	NATALYA MAKAROVA	{"phone": "+70476591399"}
0005435283165	7A299C	3309 246470	NIKOLAY SEMENOV	{"email": "nikolay.semenov_16121976@postgrespro.ru", "phone": "+70753948706"}
0005435283166	FDB22F	3795 266409	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov-1974@postgrespro.ru", "phone": "+70007684220"}
0005435283167	1B3A9D	4052 630636	NIKITA NAUMOV	{"email": "naumov.nikita-1968@postgrespro.ru", "phone": "+70299612343"}
0005435283168	007F94	4203 025883	DENIS STEPANOV	{"phone": "+70642542081"}
0005435283169	15611A	6742 048278	VIKTORIYA ABRAMOVA	{"phone": "+70506169639"}
0005435283170	15611A	8573 126873	LEONID IVANOV	{"phone": "+70992841826"}
0005435283171	8A6849	8846 157142	MARIYA FEDOROVA	{"phone": "+70732527028"}
0005435283172	C50EAC	9747 576846	NIKOLAY KAZAKOV	{"phone": "+70901815645"}
0005435283173	279D2F	6353 413657	ANDREY KAZAKOV	{"phone": "+70555736135"}
0005435283174	8A4A1E	9654 574797	SVETLANA SEMENOVA	{"phone": "+70295966241"}
0005435283175	3B9593	2401 886929	OLGA MAKSIMOVA	{"phone": "+70620848860"}
0005435283176	0E0BD1	8601 069716	ANASTASIYA VASILEVA	{"email": "a-vasileva20121981@postgrespro.ru", "phone": "+70630960140"}
0005435283177	0E0BD1	8044 101518	TAMARA NESTEROVA	{"email": "tamaranesterova_08041976@postgrespro.ru", "phone": "+70017253311"}
0005435283178	CDCBD5	3461 334707	ALEKSEY BELOV	{"phone": "+70597986915"}
0005435283179	CDCBD5	1381 501585	LIDIYA PAVLOVA	{"phone": "+70324821176"}
0005435283180	CDCBD5	9269 347563	SERGEY IVANOV	{"email": "ivanov_sergey_1977@postgrespro.ru", "phone": "+70366162690"}
0005435283181	5B4E45	3626 847961	ELENA AFANASEVA	{"phone": "+70657131922"}
0005435283182	5B4E45	0483 975694	FILIPP AFANASEV	{"email": "afanasev_filipp.031976@postgrespro.ru", "phone": "+70976148562"}
0005435283183	1A7CAD	0420 670457	RITA VOROBEVA	{"email": "vorobeva.rita-27121973@postgrespro.ru", "phone": "+70953363524"}
0005435283184	994B1A	6866 828751	EKATERINA KUZMINA	{"phone": "+70845408006"}
0005435283185	50C650	3847 287607	GENNADIY NAZAROV	{"phone": "+70212478102"}
0005435283186	AAB04A	6195 213853	SERGEY POPOV	{"email": "popovsergey.121974@postgrespro.ru", "phone": "+70297031485"}
0005435283187	BBA612	9079 394729	ALEKSANDR NIKOLAEV	{"email": "nikolaeva.05101980@postgrespro.ru", "phone": "+70724835558"}
0005435283188	BBA612	0258 673163	NATALYA AFANASEVA	{"email": "natalya_afanaseva19061967@postgrespro.ru", "phone": "+70051097043"}
0005435283189	0780E4	8713 170696	IGOR TARASOV	{"phone": "+70260351896"}
0005435283190	D42B2D	7724 067543	ANNA ALEKSANDROVA	{"phone": "+70927452335"}
0005435283191	2C2951	3070 801670	EGOR EGOROV	{"email": "egorovegor.26021971@postgrespro.ru", "phone": "+70999107099"}
0005435283192	A418A5	3621 401878	ALEKSANDR VASILEV	{"phone": "+70365265314"}
0005435283193	65BE63	5198 027845	ANATOLIY DMITRIEV	{"phone": "+70364926220"}
0005435283194	8781E0	4121 411684	DMITRIY ZAKHAROV	{"email": "zakharov-dmitriy-051975@postgrespro.ru", "phone": "+70725151261"}
0005435283195	8781E0	3484 824990	VLADIMIR MARTYNOV	{"phone": "+70024112968"}
0005435283196	4CE9EF	2320 439475	ALEKSANDRA LEBEDEVA	{"phone": "+70915810882"}
0005435283197	4CE9EF	0274 501853	DMITRIY KOZLOV	{"email": "d-kozlov101980@postgrespro.ru", "phone": "+70062233093"}
0005435283198	80A42B	0225 713855	IRINA SMIRNOVA	{"email": "smirnovai-1978@postgrespro.ru", "phone": "+70509551526"}
0005435283199	01E9CA	3835 269395	VENERA GRISHINA	{"email": "venera_grishina_1972@postgrespro.ru", "phone": "+70241051429"}
0005435283200	13AF46	9188 359147	SERGEY IVANOV	{"email": "ivanov.s-17111970@postgrespro.ru", "phone": "+70333824313"}
0005435283201	13AF46	6417 081954	ANATOLIY FILIPPOV	{"email": "anatoliy-filippov_10011979@postgrespro.ru", "phone": "+70509647385"}
0005435283202	17F64F	6599 310396	VLADIMIR POPOV	{"email": "v.popov-02091967@postgrespro.ru", "phone": "+70592536441"}
0005435283203	3B0B9E	6062 073224	ALEKSANDR FOMIN	{"phone": "+70845357761"}
0005435283204	E529C1	1736 766933	LILIYA ANDREEVA	{"phone": "+70786336081"}
0005435283205	0BE770	3051 734793	VLADIMIR SMIRNOV	{"phone": "+70774230215"}
0005435283206	C08D21	4894 927231	MARINA KUZNECOVA	{"phone": "+70321814487"}
0005435283207	C08D21	0692 591957	ALEKSANDR DENISOV	{"phone": "+70417086236"}
0005435283208	505CEF	8485 811498	ILYA YAKOVLEV	{"phone": "+70509707542"}
0005435283209	B82118	6685 171902	RAFAIL SOKOLOV	{"email": "sokolov_r.091970@postgrespro.ru", "phone": "+70683307624"}
0005435283210	159725	2650 664350	ARINA ZAYCEVA	{"phone": "+70825781296"}
0005435283211	5638A1	1323 175921	EVGENIY IVANOV	{"email": "evgeniy.ivanov.31101963@postgrespro.ru", "phone": "+70444155796"}
0005435283212	142491	7815 749150	ANDREY KOZLOV	{"email": "akozlov-061981@postgrespro.ru", "phone": "+70395880517"}
0005435283213	E6BD4F	2338 459842	ANNA KONOVALOVA	{"phone": "+70701468552"}
0005435283214	5C18EF	6452 214729	MAKAR SCHERBAKOV	{"email": "scherbakov.m01011966@postgrespro.ru", "phone": "+70434120289"}
0005435283215	78C2BC	5104 680480	ANATOLIY KRASNOV	{"phone": "+70407888420"}
0005435283216	CA0F95	3180 543876	VALERIYA ZAKHAROVA	{"email": "valeriya.zakharova18111962@postgrespro.ru", "phone": "+70893838955"}
0005435283217	6B9C94	4336 529128	ALEKSEY MAKAROV	{"email": "aleksey_makarov.25061969@postgrespro.ru", "phone": "+70986929083"}
0005435283218	AAB473	6445 157979	NIKOLAY KONOVALOV	{"email": "nikolaykonovalov031972@postgrespro.ru", "phone": "+70835528440"}
0005435283219	1C6011	5589 320716	VLADIMIR TIMOFEEV	{"phone": "+70231901749"}
0005435283220	D504E4	0430 591448	ZOYA VOROBEVA	{"phone": "+70330976982"}
0005435283221	D504E4	1365 182368	SVETLANA MEDVEDEVA	{"phone": "+70627663281"}
0005435283222	A923F3	1507 257790	RAFAIL BORISOV	{"email": "rafail_borisov.111967@postgrespro.ru", "phone": "+70069450879"}
0005435283223	A923F3	0123 743612	VERA VOROBEVA	{"email": "veravorobeva.02121975@postgrespro.ru", "phone": "+70975735368"}
0005435283224	95B308	0338 760222	ALEKSANDR BARANOV	{"phone": "+70609848881"}
0005435283225	BE9E7B	6509 862138	DMITRIY MIRONOV	{"phone": "+70576917678"}
0005435283226	B72EC3	5001 205747	VASILIY VOROBEV	{"phone": "+70359443173"}
0005435283227	A7F5B6	5242 277815	IRINA ANDREEVA	{"phone": "+70037013560"}
0005435283228	A7F5B6	6059 181502	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev121985@postgrespro.ru", "phone": "+70195511071"}
0005435283229	6A738F	7472 129995	VALERIY MIKHAYLOV	{"phone": "+70079531724"}
0005435283230	3C05EE	6093 696965	FAINA MAKSIMOVA	{"email": "f.maksimova_1969@postgrespro.ru", "phone": "+70195726982"}
0005435283231	3C05EE	8196 776421	ARTEM DENISOV	{"email": "denisovartem.011970@postgrespro.ru", "phone": "+70821166390"}
0005435283232	E6E02E	2791 203559	YULIYA BORISOVA	{"email": "y_borisova.1966@postgrespro.ru", "phone": "+70595791398"}
0005435283233	83FFFC	7444 172441	SEMEN FROLOV	{"email": "frolov_s_071976@postgrespro.ru", "phone": "+70358831980"}
0005435283234	CE164C	7109 400720	IRINA KOVALEVA	{"phone": "+70122474932"}
0005435283235	CE164C	3141 443439	NATALIYA POPOVA	{"email": "popovan.051971@postgrespro.ru", "phone": "+70524013255"}
0005435283236	11BB52	3467 712741	VIKTOR NIKITIN	{"email": "viktor.nikitin-17041985@postgrespro.ru", "phone": "+70290215227"}
0005435283237	11BB52	7346 630509	YULIYA ABRAMOVA	{"email": "abramova-y.1968@postgrespro.ru", "phone": "+70319044173"}
0005435283238	BC5EE0	0846 129343	IRINA ARKHIPOVA	{"email": "iarkhipova_111976@postgrespro.ru", "phone": "+70789638288"}
0005435283239	CB74ED	3404 041978	KIRILL DENISOV	{"phone": "+70304499707"}
0005435283240	EC18C9	3208 092492	SERGEY KOZLOV	{"email": "sergey.kozlov-081981@postgrespro.ru", "phone": "+70919451662"}
0005435283241	52C1F0	9646 383843	VLADIMIR POPOV	{"email": "v_popov.1983@postgrespro.ru", "phone": "+70405085039"}
0005435283242	52C1F0	2069 068955	SERGEY KONOVALOV	{"email": "konovalovsergey_11081974@postgrespro.ru", "phone": "+70747372387"}
0005435283243	52C1F0	9163 024026	LIDIYA TIKHONOVA	{"phone": "+70057314269"}
0005435283244	72F041	5953 510385	NIKOLAY ISAEV	{"phone": "+70538231602"}
0005435283245	123D47	7803 920463	RIMMA AFANASEVA	{"email": "afanasevar-29091964@postgrespro.ru", "phone": "+70218824719"}
0005435283246	123D47	3596 604538	ARTEM KUZNECOV	{"phone": "+70798039949"}
0005435283247	1541C7	9130 312303	LILIYA SERGEEVA	{"phone": "+70929780082"}
0005435283248	982F1E	5743 029516	RAISA FROLOVA	{"email": "frolova_raisa_11071952@postgrespro.ru", "phone": "+70071218442"}
0005435283249	982F1E	4261 913672	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova031964@postgrespro.ru", "phone": "+70252327827"}
0005435283250	0367F7	6933 385033	NADEZHDA CHERNOVA	{"email": "n-chernova-1972@postgrespro.ru", "phone": "+70815259623"}
0005435283251	B2C4FF	8926 159757	VLADIMIR SCHERBAKOV	{"phone": "+70682057777"}
0005435283252	5E37CB	1329 287958	ALFIYA SOKOLOVA	{"phone": "+70598584269"}
0005435283253	5E37CB	6143 474168	TATYANA ISAEVA	{"email": "tatyana_isaeva26041973@postgrespro.ru", "phone": "+70407344380"}
0005435283254	2AE93D	4469 532111	VLADIMIR GORBUNOV	{"phone": "+70506980638"}
0005435283408	1270DB	4285 707637	VIKTOR SOLOVEV	{"phone": "+70105362758"}
0005435283409	2D8CC3	8467 743691	OLGA SOROKINA	{"email": "sorokina-olga_09031963@postgrespro.ru", "phone": "+70700295019"}
0005435283410	2D8CC3	7323 907266	SVETLANA ROMANOVA	{"phone": "+70977468906"}
0005435283411	6F559E	9918 606269	NIKITA VOLKOV	{"phone": "+70373820912"}
0005435283412	ED0223	6600 294624	NADEZHDA MASLOVA	{"email": "maslova-nadezhda.1961@postgrespro.ru", "phone": "+70507880110"}
0005435283413	35569B	6760 825081	ZOYA ORLOVA	{"phone": "+70448181091"}
0005435283414	D0EFB0	8292 606579	MARIYA AFANASEVA	{"email": "m_afanaseva_041969@postgrespro.ru", "phone": "+70816507330"}
0005435283415	39462F	2130 186148	OLGA BORISOVA	{"email": "olga-borisova_04091967@postgrespro.ru", "phone": "+70949426635"}
0005435283416	7A19B2	7154 663705	MARAT SCHERBAKOV	{"email": "marat_scherbakov1971@postgrespro.ru", "phone": "+70838830574"}
0005435283417	7A19B2	9184 105143	NADEZHDA IVANOVA	{"email": "ivanova_nadezhda-1972@postgrespro.ru", "phone": "+70893772333"}
0005435283418	62B6F1	4453 138521	ROZA SERGEEVA	{"phone": "+70930812363"}
0005435283419	C8D2C9	8957 572639	VALERIY SIDOROV	{"phone": "+70652581713"}
0005435283420	889085	8653 059644	NIKOLAY MIRONOV	{"phone": "+70782983540"}
0005435283421	889085	5353 555121	ELENA FILIPPOVA	{"email": "filippova-elena041973@postgrespro.ru", "phone": "+70108180432"}
0005435283422	91FF17	4872 867529	EVGENIY MOROZOV	{"phone": "+70568913333"}
0005435283423	1CB514	8872 885400	TATYANA VOLKOVA	{"email": "tatyanavolkova1976@postgrespro.ru", "phone": "+70064001280"}
0005435283424	1CB514	3585 825038	RAISA FEDOROVA	{"phone": "+70901930571"}
0005435283425	1CB514	5872 555878	EVGENIY KONOVALOV	{"email": "konovalov_evgeniy-021969@postgrespro.ru", "phone": "+70360949942"}
0005435283426	DCA78D	1489 685855	ANASTASIYA VASILEVA	{"email": "anastasiya-vasileva-041968@postgrespro.ru", "phone": "+70231820549"}
0005435283427	79F0CA	8478 661538	ALEKSANDR NIKOLAEV	{"phone": "+70072775987"}
0005435283428	79F0CA	1040 843888	TATYANA BORISOVA	{"email": "tborisova1974@postgrespro.ru", "phone": "+70973159541"}
0005435283429	79F0CA	4555 879598	DENIS ALEKSEEV	{"email": "d_alekseev21061967@postgrespro.ru", "phone": "+70120629474"}
0005435283430	013A9C	3046 757031	DANIIL IVANOV	{"email": "ivanov_d.02041968@postgrespro.ru", "phone": "+70650758033"}
0005435283431	013A9C	6969 346418	ARTEM IVANOV	{"email": "artemivanov.1966@postgrespro.ru", "phone": "+70613786663"}
0005435283432	732255	4376 362205	ROMAN ROMANOV	{"phone": "+70311012572"}
0005435283433	E5436D	5466 056386	MIKHAIL SOLOVEV	{"email": "mikhail.solovev-1978@postgrespro.ru", "phone": "+70316402427"}
0005435283434	6ACA67	0335 455564	MIKHAIL SEMENOV	{"email": "semenov.mikhail30071981@postgrespro.ru", "phone": "+70895460665"}
0005435283435	3D129C	6871 797750	LYUDMILA YUDINA	{"phone": "+70258640488"}
0005435283436	5535C2	9867 602066	SERGEY SIDOROV	{"email": "ssidorov1977@postgrespro.ru", "phone": "+70612668648"}
0005435283437	5535C2	0285 075473	SERGEY NAZAROV	{"email": "nazarov-s-1970@postgrespro.ru", "phone": "+70866524018"}
0005435283438	196F91	7993 134471	TATYANA LAZAREVA	{"email": "lazareva-tatyana081978@postgrespro.ru", "phone": "+70429350006"}
0005435283439	196F91	9100 030168	VERA EGOROVA	{"phone": "+70833218443"}
0005435283440	FECBCC	6572 651614	LYUBOV EFIMOVA	{"phone": "+70497935963"}
0005435283441	50DA71	6010 814512	NIKOLAY KISELEV	{"phone": "+70359488374"}
0005435283442	50DA71	0089 676907	NARIMAN IVANOV	{"phone": "+70279114885"}
0005435283443	50DA71	6919 058439	VERA ZAKHAROVA	{"phone": "+70970445892"}
0005435283444	C42BD2	8425 556995	VERA VASILEVA	{"email": "vasilevav-10021973@postgrespro.ru", "phone": "+70894896506"}
0005435283445	EBF21C	5295 098326	LIDIYA KARPOVA	{"email": "lidiya.karpova14071984@postgrespro.ru", "phone": "+70266359978"}
0005435283446	EBF21C	8231 576989	NATALYA ZHUKOVA	{"phone": "+70926613040"}
0005435283447	6081B6	5222 680273	KIRILL PAVLOV	{"email": "pavlov.kirill.011974@postgrespro.ru", "phone": "+70596037304"}
0005435283448	6081B6	5218 396637	SERGEY MEDVEDEV	{"phone": "+70967830851"}
0005435283449	4C53B3	1290 536236	GALINA MAKAROVA	{"phone": "+70919490522"}
0005435283450	148CBA	4836 796705	DMITRIY GERASIMOV	{"email": "dmitriy_gerasimov1963@postgrespro.ru", "phone": "+70751447928"}
0005435283451	0CF0F1	4057 200091	EVGENIY EGOROV	{"phone": "+70307934088"}
0005435283452	0CF0F1	7188 196342	NADEZHDA ALEKSANDROVA	{"email": "aleksandrovanadezhda.10021973@postgrespro.ru", "phone": "+70381213447"}
0005435283453	22EB4B	2351 958138	LIDIYA KARPOVA	{"phone": "+70962451874"}
0005435283454	4A3BEC	2264 056329	TAMARA KOZLOVA	{"email": "kozlova_tamara.1976@postgrespro.ru", "phone": "+70795219609"}
0005435283455	10A011	4171 079146	NATALYA ANISIMOVA	{"phone": "+70851791462"}
0005435283456	E91B1F	7795 834892	NADEZHDA SAVELEVA	{"email": "n_saveleva_07071960@postgrespro.ru", "phone": "+70370067233"}
0005435283457	A286AE	1393 265489	NATALYA MOISEEVA	{"phone": "+70158591667"}
0005435283458	BED3A7	5095 095391	NIKOLAY SAVELEV	{"email": "n-savelev.27081974@postgrespro.ru", "phone": "+70983192963"}
0005435283459	1D3C40	1433 073782	SERGEY IVANOV	{"phone": "+70615621938"}
0005435283460	1D3C40	6141 730654	EKATERINA ANTONOVA	{"email": "ekaterinaantonova-18111968@postgrespro.ru", "phone": "+70887327758"}
0005435283461	11AC5F	0086 511156	LARISA SEMENOVA	{"phone": "+70582778751"}
0005435283462	6E44C7	9978 929716	RIMMA TARASOVA	{"email": "tarasova-rimma_30061966@postgrespro.ru", "phone": "+70432914587"}
0005435283463	6E44C7	5256 650213	MIKHAIL MAKSIMOV	{"email": "maksimov_m11091967@postgrespro.ru", "phone": "+70847277474"}
0005435283464	493575	9837 321151	KONSTANTIN KUZMIN	{"phone": "+70325763271"}
0005435283465	92AE13	0016 075295	VERONIKA BOGDANOVA	{"email": "bogdanova_v.07051966@postgrespro.ru", "phone": "+70407088680"}
0005435283466	92AE13	1908 714224	RITA MELNIKOVA	{"email": "rita.melnikova-101970@postgrespro.ru", "phone": "+70899597187"}
0005435283467	92AE13	7153 973695	MARIYA MIKHAYLOVA	{"email": "mariya.mikhaylova-21071977@postgrespro.ru", "phone": "+70815843458"}
0005435283468	690B81	0443 128052	ELENA ABRAMOVA	{"email": "abramovae.30071974@postgrespro.ru", "phone": "+70020834307"}
0005435283469	13DC69	7665 899582	OLGA KOZLOVA	{"email": "kozlovao031963@postgrespro.ru", "phone": "+70015878679"}
0005435283470	A60F56	8890 877678	ILYA SEMENOV	{"email": "semenov_i_07091964@postgrespro.ru", "phone": "+70912368756"}
0005435283471	A60F56	3866 110914	GLEB EGOROV	{"email": "egorov-gleb_101974@postgrespro.ru", "phone": "+70340616371"}
0005435283472	0FD3C9	3298 795713	MARINA BELYAEVA	{"phone": "+70902392107"}
0005435283473	0FD3C9	1136 956193	ANATOLIY FOMIN	{"phone": "+70400177886"}
0005435283474	F95C8B	9467 554115	INNA PETROVA	{"email": "i_petrova_081970@postgrespro.ru", "phone": "+70146496865"}
0005435283475	4EB292	3261 083106	OLGA POPOVA	{"phone": "+70896623639"}
0005435283476	39ED29	4082 735271	ANASTASIYA ZOTOVA	{"email": "anastasiya-zotova-1978@postgrespro.ru", "phone": "+70325285687"}
0005435283477	39ED29	3210 143537	ELENA RYABOVA	{"phone": "+70746083569"}
0005435283478	39ED29	3191 195427	LYUDMILA FILATOVA	{"phone": "+70179097350"}
0005435283479	08E5BF	1357 719253	SERGEY KONOVALOV	{"phone": "+70451535649"}
0005435283480	08E5BF	6312 900654	ALEKSEY FEDOTOV	{"phone": "+70574476564"}
0005435283481	0911ED	6157 071976	ROMAN MOROZOV	{"email": "r-morozov-1972@postgrespro.ru", "phone": "+70753510978"}
0005435283482	56B93B	0825 436106	NINA KUZNECOVA	{"phone": "+70900271797"}
0005435283483	56B93B	0565 402709	VALENTINA POPOVA	{"phone": "+70778106108"}
0005435283484	E32BB5	0839 064508	ELENA MATVEEVA	{"email": "elena-matveeva20031964@postgrespro.ru", "phone": "+70729529722"}
0005435283485	680CF0	1905 830579	YURIY BELOV	{"email": "belov.yuriy-1964@postgrespro.ru", "phone": "+70916709358"}
0005435283486	3AEE52	3506 937194	VLADISLAV KUDRYASHOV	{"email": "vladislavkudryashov.061969@postgrespro.ru", "phone": "+70039306822"}
0005435283487	6D6D9E	5678 708439	DARYA ALEKSEEVA	{"phone": "+70535841132"}
0005435283488	0D6DDD	1410 678698	VALENTINA BARANOVA	{"email": "baranova.v_1973@postgrespro.ru", "phone": "+70250945649"}
0005435283489	0D6DDD	7323 293540	ALEVTINA LAZAREVA	{"phone": "+70706785025"}
0005435283490	13CBD6	7843 204488	ANDREY SOLOVEV	{"phone": "+70009215266"}
0005435283491	13CBD6	0124 933456	VLADIMIR FILIPPOV	{"email": "v_filippov_071974@postgrespro.ru", "phone": "+70626721119"}
0005435283492	C6F864	0204 446661	LYUBOV FROLOVA	{"phone": "+70618083017"}
0005435283493	C6F864	9973 361907	OLGA SERGEEVA	{"email": "sergeevaolga_1971@postgrespro.ru", "phone": "+70507242547"}
0005435283494	26043D	7507 594118	VLADISLAV ILIN	{"phone": "+70228114833"}
0005435283495	30D512	0993 713577	VIKTOR STEPANOV	{"phone": "+70385538381"}
0005435283496	DB4F5C	5695 800042	VALENTINA ZAYCEVA	{"phone": "+70620837598"}
0005435283497	EE00F8	5246 108838	PRASKOVYA KUZMINA	{"email": "p.kuzmina_1976@postgrespro.ru", "phone": "+70352655007"}
0005435283498	E0CDFC	0112 150564	SERGEY EGOROV	{"email": "egorov_sergey061960@postgrespro.ru", "phone": "+70025674196"}
0005435283499	E6D6BF	9550 350983	OLGA ROMANOVA	{"phone": "+70822247096"}
0005435283500	D3428A	8261 616992	SERGEY NIKOLAEV	{"email": "snikolaev-04031963@postgrespro.ru", "phone": "+70985965910"}
0005435283501	582C4C	0350 260320	ALEKSEY TARASOV	{"phone": "+70145269938"}
0005435283502	B2BF06	4922 866697	NIKOLAY DENISOV	{"email": "denisov-nikolay-15071967@postgrespro.ru", "phone": "+70954944026"}
0005435283503	236480	5376 482492	LYUBOV GAVRILOVA	{"email": "gavriloval-14041970@postgrespro.ru", "phone": "+70916599581"}
0005435283504	903433	8532 906498	ALEKSANDR KAZAKOV	{"phone": "+70418466062"}
0005435283505	CEEECC	8924 158489	ILYA KISELEV	{"email": "kiselev_i.041967@postgrespro.ru", "phone": "+70045814804"}
0005435283506	CEEECC	0148 657949	EDUARD BONDARENKO	{"email": "e_bondarenko_011971@postgrespro.ru", "phone": "+70290489388"}
0005435283507	F8C3F2	3439 463313	ALEKSEY FOMIN	{"phone": "+70516145956"}
0005435283508	DA9120	8733 853851	ALEKSANDR TIMOFEEV	{"phone": "+70231487365"}
0005435283509	894EC0	4446 060688	ALEKSEY MAKAROV	{"email": "a_makarov071983@postgrespro.ru", "phone": "+70321028542"}
0005435283510	F5A9DA	4982 076691	VLADIMIR ZAYCEV	{"email": "vzaycev_051978@postgrespro.ru", "phone": "+70043450414"}
0005435283511	59A4D8	9740 266359	ANATOLIY MAKAROV	{"email": "makarov_a-08011981@postgrespro.ru", "phone": "+70827187330"}
0005435283512	59A4D8	0049 776611	VASILIY BORISOV	{"phone": "+70273177393"}
0005435283513	28D227	4296 239750	LUIZA VLASOVA	{"phone": "+70286026183"}
0005435283514	28D227	7955 811308	EKATERINA VASILEVA	{"email": "ekaterinavasileva.22041976@postgrespro.ru", "phone": "+70182740797"}
0005435283515	D96327	9447 328088	EVGENIY KUZNECOV	{"email": "e.kuznecov-011963@postgrespro.ru", "phone": "+70038932452"}
0005435283516	65882D	0361 994785	NATALYA ANDREEVA	{"email": "andreeva.natalya.031980@postgrespro.ru", "phone": "+70199927819"}
0005435283517	65882D	0352 229640	NATALYA LUKYANOVA	{"email": "n-lukyanova02121967@postgrespro.ru", "phone": "+70288472430"}
0005435283518	246786	9226 386539	IGOR KUZNECOV	{"email": "igor-kuznecov.1972@postgrespro.ru", "phone": "+70355243969"}
0005435283519	CD353F	9448 198048	LYUDMILA AKIMOVA	{"phone": "+70168477384"}
0005435283520	CD353F	3701 101336	KSENIYA LOGINOVA	{"phone": "+70177665063"}
0005435283521	115CDD	8128 126070	YURIY NIKITIN	{"phone": "+70839197314"}
0005435283522	115CDD	2885 715792	ANTONINA BOGDANOVA	{"email": "bogdanovaantonina.061965@postgrespro.ru", "phone": "+70303008429"}
0005435283523	115CDD	0653 815080	ANTONINA SERGEEVA	{"email": "sergeevaantonina.1964@postgrespro.ru", "phone": "+70067202997"}
0005435283524	5AD673	3850 461148	ELIZAVETA FADEEVA	{"email": "fadeeva.e20081962@postgrespro.ru", "phone": "+70174772990"}
0005435283525	5AD673	9107 663628	ALEKSANDR SAVELEV	{"phone": "+70590045516"}
0005435283526	1CB238	6814 258685	DARYA NIKOLAEVA	{"phone": "+70253281850"}
0005435283527	D348D7	6953 135236	PETR PETROV	{"phone": "+70176909980"}
0005435283528	C35239	9797 639644	SERGEY IVANOV	{"phone": "+70724302090"}
0005435283529	C35239	7866 850743	DARYA NAZAROVA	{"email": "nazarova.darya_13061976@postgrespro.ru", "phone": "+70349318958"}
0005435283530	EFE821	5227 152149	ZOYA ROMANOVA	{"phone": "+70176423507"}
0005435283531	88A0F6	2046 792160	ANZHELIKA POPOVA	{"phone": "+70774764015"}
0005435283532	BADF09	8216 204541	VIKTOR IVANOV	{"email": "ivanov-v101973@postgrespro.ru", "phone": "+70357371213"}
0005435283533	DB0B1D	3427 567267	OLGA VASILEVA	{"phone": "+70366459669"}
0005435283534	DB0B1D	5561 388044	ALEKSEY PAVLOV	{"phone": "+70560845649"}
0005435283535	883A12	3343 370861	ZHANNA MARTYNOVA	{"phone": "+70884006628"}
0005435283536	F590C7	7503 296136	EVDOKIYA ZOTOVA	{"email": "zotova-evdokiya.1965@postgrespro.ru", "phone": "+70954280263"}
0005435283537	F590C7	1307 123202	YURIY KARPOV	{"phone": "+70935006162"}
0005435283538	14BD8F	1568 088824	VLADIMIR ORLOV	{"email": "orlov.v_1979@postgrespro.ru", "phone": "+70988856673"}
0005435283539	14BD8F	6599 844619	ANDREY IVANOV	{"email": "aivanov.07111965@postgrespro.ru", "phone": "+70127735028"}
0005435283540	3344BA	0803 610014	ELENA LAZAREVA	{"phone": "+70458597470"}
0005435283541	D3F0A0	1503 639945	SERGEY NOVIKOV	{"phone": "+70656086024"}
0005435283542	D3F0A0	8983 263046	ANTON TIMOFEEV	{"email": "timofeev_a_051973@postgrespro.ru", "phone": "+70359068602"}
0005435283543	30DC0F	9482 658990	YANA MATVEEVA	{"phone": "+70922492063"}
0005435283544	E1BA3B	8590 274956	TAMARA SOROKINA	{"phone": "+70241802354"}
0005435283545	E1BA3B	6590 022129	ANDREY KUZNECOV	{"email": "andrey-kuznecov111973@postgrespro.ru", "phone": "+70532494609"}
0005435283546	E1BA3B	5765 895061	TAISIYA ORLOVA	{"email": "taisiya.orlova.24111976@postgrespro.ru", "phone": "+70294247818"}
0005435283547	370281	7505 181156	ARTUR ANDREEV	{"email": "andreev.a061976@postgrespro.ru", "phone": "+70047294620"}
0005435283548	370281	4056 987548	OLGA IVANOVA	{"phone": "+70411315179"}
0005435283549	370281	2154 899325	RASHIT SHEVCHENKO	{"email": "rashit.shevchenko16091972@postgrespro.ru", "phone": "+70178180201"}
0005435283550	5FD4AB	6162 936780	SERGEY GERASIMOV	{"email": "sergey_gerasimov-1962@postgrespro.ru", "phone": "+70808215511"}
0005435283551	E60E3D	3941 447573	YURIY SOKOLOV	{"email": "sokolov_yuriy_081972@postgrespro.ru", "phone": "+70586832182"}
0005435283552	00C278	6186 425563	DMITRIY EGOROV	{"phone": "+70804434537"}
0005435283553	00D4A9	7014 850256	POLINA KONOVALOVA	{"email": "konovalova_polina-21051964@postgrespro.ru", "phone": "+70084711912"}
0005435283554	00D4A9	0169 398104	ALEKSANDR DAVYDOV	{"phone": "+70604932019"}
0005435283555	61E5F4	0111 134964	SERGEY MAKAROV	{"email": "sergey.makarov_1960@postgrespro.ru", "phone": "+70751842152"}
0005435283556	808E69	0071 902296	IVAN MAKSIMOV	{"email": "maksimovivan-1982@postgrespro.ru", "phone": "+70258055987"}
0005435283557	808E69	8880 792017	GENNADIY MOROZOV	{"email": "g_morozov-13071964@postgrespro.ru", "phone": "+70789759913"}
0005435283558	B8ADD0	4260 266693	EDUARD SOLOVEV	{"email": "solovev-e1963@postgrespro.ru", "phone": "+70767668541"}
0005435283559	728873	6981 725825	IRINA SMIRNOVA	{"email": "irinasmirnova-111978@postgrespro.ru", "phone": "+70449334750"}
0005435283560	728873	1728 621105	MIKHAIL POPOV	{"phone": "+70668675110"}
0005435283561	C2C9C3	3700 068153	NADEZHDA FROLOVA	{"email": "frolova-n28121971@postgrespro.ru", "phone": "+70782942287"}
0005435283562	C2C9C3	8127 291060	SERGEY SAVELEV	{"email": "savelev-s.05071969@postgrespro.ru", "phone": "+70590007115"}
0005435283563	7B3E74	9194 281591	SAVELIY RODIONOV	{"phone": "+70049031317"}
0005435283564	7B3E74	2316 316364	RAISA BORISOVA	{"email": "raisa.borisova-17121975@postgrespro.ru", "phone": "+70581174681"}
0005435283565	C0AA02	7042 877136	STEPAN VOLKOV	{"email": "s.volkov-1969@postgrespro.ru", "phone": "+70341194967"}
0005435283566	C0AA02	4542 220569	VALENTINA FOMINA	{"email": "fominavalentina111982@postgrespro.ru", "phone": "+70983506894"}
0005435283567	FB0379	8092 424272	NIKOLAY KUZMIN	{"email": "nikolay-kuzmin.19101967@postgrespro.ru", "phone": "+70710071445"}
0005435283568	F63933	5000 221420	NADEZHDA MEDVEDEVA	{"email": "nadezhda_medvedeva-101968@postgrespro.ru", "phone": "+70558852704"}
0005435283569	061834	1633 133110	TATYANA MOROZOVA	{"email": "tatyanamorozova.02021982@postgrespro.ru", "phone": "+70247628209"}
0005435283570	061834	7560 016158	MARINA VASILEVA	{"email": "vasileva_marina07061975@postgrespro.ru", "phone": "+70518921925"}
0005435283571	E26082	4979 054951	NIKOLAY RODIONOV	{"email": "rodionov-n1966@postgrespro.ru", "phone": "+70113594730"}
0005435283572	E26082	1139 935413	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov.091975@postgrespro.ru", "phone": "+70446223783"}
0005435283573	C43CCA	7061 826211	MIKHAIL MAKAROV	{"email": "makarov.m.1969@postgrespro.ru", "phone": "+70825087706"}
0005435283574	429249	9485 210674	DMITRIY FROLOV	{"email": "d_frolov.02061975@postgrespro.ru", "phone": "+70541844920"}
0005435283575	2E07EC	1309 349738	SVETLANA LUKYANOVA	{"phone": "+70283890544"}
0005435283576	97357F	2725 008311	MARINA SMIRNOVA	{"email": "smirnova.m_28101972@postgrespro.ru", "phone": "+70403325797"}
0005435283577	D229F9	3839 209882	DENIS KUZMIN	{"phone": "+70067179723"}
0005435283578	D229F9	0234 275872	VIKTOR FEDOROV	{"phone": "+70942759286"}
0005435283579	CFD7EA	1541 365808	MARIYA KONOVALOVA	{"email": "konovalova.mariya1973@postgrespro.ru", "phone": "+70303401898"}
0005435283580	BD6BC6	8835 233280	TATYANA ANTONOVA	{"phone": "+70612977300"}
0005435283581	BD6BC6	6878 095708	ANNA ILINA	{"phone": "+70645590017"}
0005435283582	21885E	2258 833005	MIKHAIL PETROV	{"phone": "+70766661992"}
0005435283583	21885E	9614 667107	MIKHAIL ANDREEV	{"email": "m-andreev_081980@postgrespro.ru", "phone": "+70843438892"}
0005435283584	21885E	9973 446001	ELENA SIDOROVA	{"email": "sidorova_elena-1966@postgrespro.ru", "phone": "+70566683679"}
0005435283585	2625A0	3362 280331	MARGARITA STEPANOVA	{"email": "m_stepanova.18051971@postgrespro.ru", "phone": "+70430669086"}
0005435283586	2625A0	5732 213847	IVAN POPOV	{"email": "popov.ivan_1971@postgrespro.ru", "phone": "+70219863128"}
0005435283587	02E7AF	8240 973530	SERGEY SEMENOV	{"phone": "+70632537911"}
0005435283588	7B2ED7	5776 441964	OLGA CHERNOVA	{"email": "olgachernova_1958@postgrespro.ru", "phone": "+70778981793"}
0005435283589	7B2ED7	9893 865230	SERGEY FILIPPOV	{"email": "filippov-s.081967@postgrespro.ru", "phone": "+70895727880"}
0005435283590	7B2ED7	3222 699541	VALERIY YAKOVLEV	{"phone": "+70121503087"}
0005435283591	425225	3011 872826	TATYANA SOLOVEVA	{"email": "t_soloveva-1973@postgrespro.ru", "phone": "+70126796305"}
0005435283592	3364F4	5448 161244	ALINA KUZNECOVA	{"phone": "+70613163953"}
0005435283593	3364F4	8743 402727	IVAN KUZNECOV	{"email": "ivan-kuznecov-18111980@postgrespro.ru", "phone": "+70166811608"}
0005435283594	6D4E23	7877 290784	GRIGORIY STEPANOV	{"phone": "+70342198632"}
0005435283595	5DCB4C	4253 741580	STANISLAV KONOVALOV	{"email": "konovalovs_1985@postgrespro.ru", "phone": "+70060265839"}
0005435283596	4740D3	1363 481766	VLADIMIR TIKHONOV	{"phone": "+70199720705"}
0005435283597	5D650F	2177 338935	RADIK BONDARENKO	{"email": "bondarenko_radik.031977@postgrespro.ru", "phone": "+70076624222"}
0005435286538	CC78EE	1893 780031	NINA LAZAREVA	{"phone": "+70764446299"}
0005435286539	05AD86	0835 889553	ALEVTINA BELOVA	{"phone": "+70006137666"}
0005435286540	FA7B29	9158 629059	LARISA SOLOVEVA	{"phone": "+70917562797"}
0005435286541	FA7B29	2713 288851	SERGEY ZAKHAROV	{"email": "sergeyzakharov051970@postgrespro.ru", "phone": "+70096041804"}
0005435286542	3E8CF7	5319 006171	MARAT GUSEV	{"email": "gusev.m111971@postgrespro.ru", "phone": "+70797785441"}
0005435286543	3E8CF7	0646 038898	VALENTINA VOLKOVA	{"email": "volkova_v_081970@postgrespro.ru", "phone": "+70650251025"}
0005435286544	2716C2	2933 270969	LIDIYA YAKOVLEVA	{"phone": "+70343207596"}
0005435286545	CF34F5	8982 528796	EVGENIY VOROBEV	{"email": "vorobevevgeniy-091970@postgrespro.ru", "phone": "+70503141205"}
0005435286546	CF34F5	7316 011720	SERGEY ANTONOV	{"phone": "+70491903842"}
0005435286547	56107C	4813 382322	KONSTANTIN GORBUNOV	{"email": "gorbunov-k.08111973@postgrespro.ru", "phone": "+70630018194"}
0005435286548	56107C	8719 181536	ANDREY IVANOV	{"email": "andrey_ivanov-09081978@postgrespro.ru", "phone": "+70678906552"}
0005435286549	7869AF	2188 760304	PAVEL KISELEV	{"phone": "+70279096891"}
0005435286550	745347	6688 476259	GALINA ZOTOVA	{"phone": "+70598463491"}
0005435286551	AF65C4	0083 991642	ANNA ABRAMOVA	{"email": "abramova_a.22061977@postgrespro.ru", "phone": "+70068167454"}
0005435286552	7FDAC7	2090 116688	MAKSIM VOLKOV	{"email": "volkov.m.061979@postgrespro.ru", "phone": "+70931138595"}
0005435286553	9A29B0	9783 681817	MARINA GRISHINA	{"phone": "+70673906045"}
0005435286554	5A1F1C	0237 225475	VLADIMIR SCHERBAKOV	{"phone": "+70578747747"}
0005435286555	EF0F1E	9903 644162	TATYANA MEDVEDEVA	{"email": "tmedvedeva.06021968@postgrespro.ru", "phone": "+70072740231"}
0005435286556	27164E	2459 593149	ANZHELA VASILEVA	{"phone": "+70758581422"}
0005435286557	4AF26D	5615 044797	MARINA KULIKOVA	{"email": "m.kulikova-23021967@postgrespro.ru", "phone": "+70700774369"}
0005435286558	86341B	5648 582524	ANATOLIY ZAYCEV	{"email": "anatoliy.zaycev-1973@postgrespro.ru", "phone": "+70717569333"}
0005435286559	86341B	2378 576033	IRINA LAZAREVA	{"email": "lazareva-irina08091967@postgrespro.ru", "phone": "+70542323767"}
0005435286560	4E6C6F	6671 010596	MIKHAIL POPOV	{"email": "popov-mikhail_061975@postgrespro.ru", "phone": "+70441526272"}
0005435286561	BD38F0	4532 376159	ANTON AFANASEV	{"email": "antonafanasev_1959@postgrespro.ru", "phone": "+70137050384"}
0005435286562	CF3028	9449 942050	ANNA KOZLOVA	{"phone": "+70279822845"}
0005435286563	96EA5F	1050 165152	ELENA KUZNECOVA	{"phone": "+70948253467"}
0005435286564	3E231A	8737 934073	ALBINA SCHERBAKOVA	{"email": "albina_scherbakova-031961@postgrespro.ru", "phone": "+70589115589"}
0005435286565	3E231A	6920 537468	GALINA NIKOLAEVA	{"email": "nikolaeva-galina_1976@postgrespro.ru", "phone": "+70590047477"}
0005435286566	BE5235	8016 673820	SERGEY PETROV	{"phone": "+70804610660"}
0005435286567	BE5235	8621 144604	GALINA OSIPOVA	{"email": "osipova-galina_23081979@postgrespro.ru", "phone": "+70791220671"}
0005435286568	F117B2	1853 916440	VLADIMIR MIRONOV	{"email": "mironov-v-06101970@postgrespro.ru", "phone": "+70375331526"}
0005435286569	70D9E3	7059 813275	YULIYA ZAYCEVA	{"phone": "+70951829870"}
0005435286570	234F9C	7368 264969	ELIZAVETA PAVLOVA	{"email": "elizaveta_pavlova_1973@postgrespro.ru", "phone": "+70348623632"}
0005435286571	88A66D	1940 135370	EKATERINA SOLOVEVA	{"phone": "+70667499051"}
0005435286572	AF3B49	3871 718011	EKATERINA PETROVA	{"phone": "+70659225122"}
0005435286573	4C33D2	9655 819862	ALEKSANDR ILIN	{"phone": "+70620787556"}
0005435286574	0C5FCC	6595 160627	VLADIMIR POPOV	{"email": "popov-vladimir_28041974@postgrespro.ru", "phone": "+70964510593"}
0005435286575	C69559	5537 404348	TATYANA MIRONOVA	{"phone": "+70442004333"}
0005435286576	C69559	2761 349431	OLGA ZAKHAROVA	{"phone": "+70623668902"}
0005435286577	72C59B	4152 867469	SERGEY CHERNOV	{"email": "chernov-sergey.121974@postgrespro.ru", "phone": "+70196447545"}
0005435286578	398A15	0587 034986	ANDREY TIMOFEEV	{"email": "andrey.timofeev06121969@postgrespro.ru", "phone": "+70774660326"}
0005435286579	ACC70C	8586 214222	NADEZHDA LEBEDEVA	{"phone": "+70796398892"}
0005435286580	ACC70C	8609 948114	ANTON GRIGOREV	{"email": "anton.grigorev-041973@postgrespro.ru", "phone": "+70341960536"}
0005435286581	C21FEA	1624 481084	VALENTINA NAZAROVA	{"phone": "+70625463065"}
0005435286582	8692A6	4683 908131	DMITRIY ABRAMOV	{"email": "dmitriyabramov-111973@postgrespro.ru", "phone": "+70049649832"}
0005435286583	2FE85E	3719 055341	SERGEY MAKSIMOV	{"phone": "+70642443784"}
0005435286584	08A0CE	3441 537969	VERA FROLOVA	{"phone": "+70261109762"}
0005435286585	643409	7502 615979	ANTONINA SCHERBAKOVA	{"phone": "+70868618056"}
0005435286586	E476C6	9252 318388	YANA VASILEVA	{"email": "y.vasileva.101960@postgrespro.ru", "phone": "+70324717833"}
0005435286587	E1410E	5717 490269	EKATERINA MELNIKOVA	{"email": "ekaterina-melnikova.04101969@postgrespro.ru", "phone": "+70428033529"}
0005435286588	4C95B1	8776 319994	EVDOKIYA MELNIKOVA	{"email": "emelnikova-111975@postgrespro.ru", "phone": "+70959903227"}
0005435286589	C3E80A	0690 216512	TATYANA ZAYCEVA	{"phone": "+70195196003"}
0005435286590	087641	4867 787459	ANATOLIY KONOVALOV	{"email": "konovalov.a.081972@postgrespro.ru", "phone": "+70305927212"}
0005435286591	003241	7014 085353	ANDREY NOVIKOV	{"phone": "+70699789582"}
0005435286592	6D00D4	5966 716324	LYUBOV MIRONOVA	{"phone": "+70797744542"}
0005435286593	4AF7CD	5504 070643	OLEG PAVLOV	{"phone": "+70423835579"}
0005435286594	4AF7CD	8875 213106	IVAN POPOV	{"email": "ivanpopov051968@postgrespro.ru", "phone": "+70511138200"}
0005435286595	C2965C	7918 553539	ANDREY SEMENOV	{"email": "semenov.andrey-1981@postgrespro.ru", "phone": "+70784157816"}
0005435286596	CC79AA	2931 154820	ANASTASIYA NESTEROVA	{"email": "nesterova.a-051964@postgrespro.ru", "phone": "+70269208361"}
0005435286597	6D7DAE	9167 845235	TAISIYA ANTONOVA	{"phone": "+70058754864"}
0005435286598	563A52	3612 810488	NATALYA SOKOLOVA	{"phone": "+70452510956"}
0005435286599	1C99A1	2017 342252	SERGEY GRIGOREV	{"email": "grigorevs_1960@postgrespro.ru", "phone": "+70713260207"}
0005435286600	1C99A1	0602 608133	NIKOLAY FEDOROV	{"phone": "+70203175515"}
0005435286601	251E50	9481 616937	EVELINA VASILEVA	{"phone": "+70035601326"}
0005435286602	251E50	4861 243437	VALERIY SMIRNOV	{"email": "valeriy_smirnov1975@postgrespro.ru", "phone": "+70018142054"}
0005435286603	251E50	0298 439320	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.081973@postgrespro.ru", "phone": "+70066302761"}
0005435286604	915EF0	5549 053226	MARIYA ZAYCEVA	{"email": "mariyazayceva-081970@postgrespro.ru", "phone": "+70759691859"}
0005435286605	F42C1F	0940 427097	YURIY FEDOROV	{"phone": "+70213898339"}
0005435286606	A877C9	6918 904882	GALINA KOROLEVA	{"email": "g_koroleva-1965@postgrespro.ru", "phone": "+70677085235"}
0005435286607	EE2C76	2996 182795	SERGEY BONDARENKO	{"phone": "+70613397035"}
0005435286608	EE2C76	8089 212514	MIKHAIL SAVELEV	{"email": "m.savelev1955@postgrespro.ru", "phone": "+70857246941"}
0005435286609	3DC7B4	3426 128963	IRINA DMITRIEVA	{"email": "i_dmitrieva-021970@postgrespro.ru", "phone": "+70003604759"}
0005435286610	76D6AC	4561 316581	LYUDMILA RODIONOVA	{"email": "rodionova_l24051977@postgrespro.ru", "phone": "+70913671439"}
0005435286611	76D6AC	6802 612369	LARISA SIDOROVA	{"email": "sidorova-larisa-12101969@postgrespro.ru", "phone": "+70635728961"}
0005435286612	9F4359	7408 415331	ALEKSEY DAVYDOV	{"email": "aleksey-davydov.081976@postgrespro.ru", "phone": "+70955987979"}
0005435286613	0C5AF9	8910 087427	IVAN KULIKOV	{"phone": "+70400468206"}
0005435286614	0C5AF9	4674 475557	ELENA SERGEEVA	{"email": "e.sergeeva_24101967@postgrespro.ru", "phone": "+70764109195"}
0005435286615	E62A48	6963 933719	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr-1966@postgrespro.ru", "phone": "+70617954912"}
0005435286616	C195A3	0682 392019	KIRILL MIKHAYLOV	{"phone": "+70296058902"}
0005435286617	ECAB11	8502 763932	LYUBOV BORISOVA	{"email": "l_borisova.1966@postgrespro.ru", "phone": "+70239790092"}
0005435286618	366808	8316 403520	VALENTIN KUZMIN	{"phone": "+70819933247"}
0005435286619	9775AD	3278 466845	SERGEY IVANOV	{"phone": "+70769135064"}
0005435286620	C3A06F	2858 606414	VITALIY NAZAROV	{"email": "v_nazarov.011973@postgrespro.ru", "phone": "+70299394733"}
0005435286621	1F2FB6	5840 823467	ANNA NIKOLAEVA	{"phone": "+70905006401"}
0005435286622	645ADA	1564 968609	ROMAN MAKSIMOV	{"email": "maksimov-r.111972@postgrespro.ru", "phone": "+70107865899"}
0005435286623	645ADA	4991 539327	VALERIY MIKHAYLOV	{"phone": "+70031823638"}
0005435286624	4F610B	8639 006328	VYACHESLAV SOROKIN	{"phone": "+70181828294"}
0005435286625	4F610B	8902 065041	LIDIYA EFIMOVA	{"phone": "+70685402054"}
0005435286626	7640AD	8451 168129	OLGA STEPANOVA	{"phone": "+70669006532"}
0005435286627	B4F161	9694 174913	IVAN KOZLOV	{"phone": "+70316139186"}
0005435286628	54A5D8	1999 705844	YURIY BORISOV	{"phone": "+70811626136"}
0005435286629	54A5D8	8175 031949	VLADIMIR POPOV	{"email": "vladimir.popov1976@postgrespro.ru", "phone": "+70184648089"}
0005435286630	54A5D8	8903 040049	SERGEY NOVIKOV	{"email": "s_novikov.12021984@postgrespro.ru", "phone": "+70302121350"}
0005435286631	97F60F	7267 350909	DMITRIY KONOVALOV	{"email": "dmitriy_konovalov_121978@postgrespro.ru", "phone": "+70537951336"}
0005435286632	4859EE	4854 491728	LARISA ISAEVA	{"phone": "+70605355271"}
0005435286633	4859EE	2579 609052	PRASKOVYA KOZLOVA	{"phone": "+70991208062"}
0005435286634	F60C63	1017 821983	ARTEM SOKOLOV	{"phone": "+70356062405"}
0005435286635	7BD6CF	1294 241905	OLGA SOROKINA	{"phone": "+70754271180"}
0005435286636	91F41C	5786 010553	KIRILL BELOV	{"email": "kbelov-19011979@postgrespro.ru", "phone": "+70751288657"}
0005435286637	91F41C	3704 955996	NINA EFREMOVA	{"phone": "+70472509455"}
0005435286638	128FAE	9350 833756	IVAN EGOROV	{"email": "i_egorov_24121969@postgrespro.ru", "phone": "+70373833200"}
0005435286639	885609	3100 782063	VALENTINA ZAKHAROVA	{"email": "zakharova-v.1968@postgrespro.ru", "phone": "+70537416032"}
0005435286640	92A5C3	1424 304393	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr-02011975@postgrespro.ru", "phone": "+70169040791"}
0005435286641	E40D14	3053 728808	VIKTOR SERGEEV	{"email": "sergeevviktor.21011980@postgrespro.ru", "phone": "+70410388977"}
0005435286642	29E277	5369 357294	SERGEY FROLOV	{"email": "frolov.sergey09011959@postgrespro.ru", "phone": "+70219959119"}
0005435286643	1A748C	2735 884231	NINA ZHURAVLEVA	{"phone": "+70578793072"}
0005435286644	0D1692	4592 482314	VLADIMIR EGOROV	{"email": "egorov-v.21061973@postgrespro.ru", "phone": "+70578164627"}
0005435286645	443BD1	9099 644073	ELIZAVETA KALININA	{"email": "kalinina_elizaveta_14121986@postgrespro.ru", "phone": "+70377480692"}
0005435286646	443BD1	8766 612953	EVGENIYA NESTEROVA	{"email": "nesterova.evgeniya1972@postgrespro.ru", "phone": "+70972805651"}
0005435286647	92D532	6031 601319	OLGA KUZNECOVA	{"phone": "+70967549367"}
0005435286648	A4C32D	4528 270582	OLGA ZHUKOVA	{"phone": "+70091838535"}
0005435286649	378D6F	9759 567307	NIKOLAY ALEKSANDROV	{"phone": "+70326868840"}
0005435286650	AF1422	8189 254634	SVETLANA DANILOVA	{"email": "s_danilova_061980@postgrespro.ru", "phone": "+70982903690"}
0005435286651	AF1422	4481 235711	OLGA SEMENOVA	{"phone": "+70155975191"}
0005435286652	5EBB4D	6900 705684	OLGA TROFIMOVA	{"email": "trofimova.o-21101973@postgrespro.ru", "phone": "+70480962769"}
0005435286653	5EBB4D	8885 194760	ANDREY ANDREEV	{"phone": "+70593741218"}
0005435286654	DF864A	4726 234693	OLEG NIKITIN	{"email": "nikitino-02031967@postgrespro.ru", "phone": "+70235752649"}
0005435286655	0E7E59	6814 386430	VLADISLAV IVANOV	{"email": "vladislav.ivanov-011962@postgrespro.ru", "phone": "+70616700789"}
0005435286656	0E7E59	3364 369574	YULIYA ANDREEVA	{"email": "yuliya_andreeva_22091978@postgrespro.ru", "phone": "+70896247661"}
0005435286657	F2A619	3049 207016	NIKITA FROLOV	{"email": "frolovnikita-1962@postgrespro.ru", "phone": "+70528235566"}
0005435286658	11A86F	6106 443579	IRINA IVANOVA	{"email": "ivanova.irina-23101976@postgrespro.ru", "phone": "+70105626971"}
0005435286659	FE52D4	9738 414242	DARINA TIMOFEEVA	{"email": "timofeeva.darina-081975@postgrespro.ru", "phone": "+70105468037"}
0005435286660	E5BD28	9781 305389	NIKOLAY ANTONOV	{"phone": "+70697469570"}
0005435286661	041A14	5593 281386	GALINA SEMENOVA	{"phone": "+70090438352"}
0005435286662	4BB699	6135 802154	OLGA VASILEVA	{"email": "vasileva-o_011975@postgrespro.ru", "phone": "+70825216780"}
0005435286663	1FD2BD	0337 795664	DMITRIY OSIPOV	{"phone": "+70997292186"}
0005435286664	1FD2BD	0247 381029	NATALYA LAZAREVA	{"email": "lazareva.n_12051968@postgrespro.ru", "phone": "+70511755914"}
0005435286665	F72F23	9581 525253	GENNADIY KUZNECOV	{"email": "kuznecov.gennadiy10111978@postgrespro.ru", "phone": "+70729432387"}
0005435286666	A85624	2342 493184	GALINA ALEKSANDROVA	{"phone": "+70851363804"}
0005435286667	FF0DD5	8960 138853	STEPAN KUZNECOV	{"email": "kuznecovs1962@postgrespro.ru", "phone": "+70619998784"}
0005435286668	6B2692	0756 341453	ANDREY VASILEV	{"email": "andreyvasilev.1965@postgrespro.ru", "phone": "+70846924715"}
0005435286669	6B2692	6798 685544	EGOR SOKOLOV	{"email": "egor_sokolov1981@postgrespro.ru", "phone": "+70391679108"}
0005435286670	DADCBA	6643 818875	IRINA AFANASEVA	{"phone": "+70987275394"}
0005435286671	235F7A	6217 840562	ANDREY SOROKIN	{"email": "sorokin.andrey.041976@postgrespro.ru", "phone": "+70343399930"}
0005435286672	AE99A7	0077 350821	ALEKSANDR KAZAKOV	{"phone": "+70022400564"}
0005435286673	C05A9D	3467 455179	YULIYA KALININA	{"email": "yuliya_kalinina_29101973@postgrespro.ru", "phone": "+70580017492"}
0005435286674	0A2573	1225 787432	TAISIYA ZAYCEVA	{"email": "taisiya.zayceva_071960@postgrespro.ru", "phone": "+70233050283"}
0005435286675	A15366	6044 562590	VALENTINA SOKOLOVA	{"phone": "+70213391732"}
0005435286676	A04564	1389 405279	KIRILL PETROV	{"email": "k-petrov-1975@postgrespro.ru", "phone": "+70248083688"}
0005435286677	4EBED6	0250 589735	TATYANA SEMENOVA	{"email": "tatyana-semenova_31071964@postgrespro.ru", "phone": "+70406701732"}
0005435286678	B807A9	3808 797360	ANTON ROMANOV	{"email": "romanov-anton061977@postgrespro.ru", "phone": "+70654008257"}
0005435286679	392F46	5574 498231	RUSLAN PETROV	{"phone": "+70475231643"}
0005435286680	6D8DE9	7237 876639	NATALYA ARKHIPOVA	{"email": "natalya.arkhipova_1982@postgrespro.ru", "phone": "+70473645308"}
0005435286681	70E20D	5297 638823	NADEZHDA MASLOVA	{"phone": "+70113225475"}
0005435286682	88CC21	3042 022287	DMITRIY SIDOROV	{"email": "dmitriy-sidorov1965@postgrespro.ru", "phone": "+70959363194"}
0005435286683	F6EB66	3721 745315	YANA KUZNECOVA	{"phone": "+70681007435"}
0005435286684	DD62F5	4570 277196	ANDREY KRASNOV	{"phone": "+70604409598"}
0005435286685	DD62F5	6698 792988	EDGAR MOROZOV	{"email": "e.morozov.1974@postgrespro.ru", "phone": "+70352695353"}
0005435286686	6CBE9A	5490 812583	PAVEL KUZNECOV	{"phone": "+70375833753"}
0005435286687	405940	6489 374884	LIDIYA IVANOVA	{"phone": "+70585888942"}
0005435286688	7ABEFF	0038 705649	VERA MOISEEVA	{"phone": "+70423760248"}
0005435286689	480351	3391 753861	ROMAN ILIN	{"phone": "+70690617200"}
0005435286690	355B55	9790 841623	OLGA GUSEVA	{"phone": "+70194296755"}
0005435286691	83C56C	9254 120144	ANDREY NOVIKOV	{"email": "novikov_andrey-05021977@postgrespro.ru", "phone": "+70119845427"}
0005435286692	B57EE0	6288 891777	NIKOLAY NOVIKOV	{"email": "nikolay.novikov.10031966@postgrespro.ru", "phone": "+70672701265"}
0005435286693	B57EE0	4980 371051	ALEKSEY DAVYDOV	{"email": "davydov-aleksey.041980@postgrespro.ru", "phone": "+70686612954"}
0005435286694	0AB278	2423 023706	TATYANA ROMANOVA	{"email": "romanova.t_10121968@postgrespro.ru", "phone": "+70020768856"}
0005435286695	4AF9EC	5070 402652	ALEKSANDR SOKOLOV	{"email": "sokolov_aleksandr01091975@postgrespro.ru", "phone": "+70722593004"}
0005435286696	0004B0	1894 779083	ALEKSANDR FILIPPOV	{"phone": "+70921874037"}
0005435286697	834BF0	4853 697427	PETR AFANASEV	{"phone": "+70198806975"}
0005435286760	F7BC50	1930 226783	SERGEY SCHERBAKOV	{"phone": "+70983940748"}
0005435286698	834BF0	4409 952468	GALINA FROLOVA	{"email": "gfrolova.22061974@postgrespro.ru", "phone": "+70034304182"}
0005435286699	8DADB3	7673 183758	ARTEM FEDOROV	{"email": "a.fedorov01101965@postgrespro.ru", "phone": "+70959446331"}
0005435286700	71E93E	0265 058807	ANDREY KARPOV	{"email": "karpov.andrey03101974@postgrespro.ru", "phone": "+70130270115"}
0005435286701	9156C5	7884 378050	ANNA SOKOLOVA	{"phone": "+70242923245"}
0005435286702	6271D8	6533 985677	EVGENIY KARPOV	{"phone": "+70912318162"}
0005435286703	E76497	9061 871271	ELENA IVANOVA	{"phone": "+70140307553"}
0005435286704	18EE87	8784 541835	VERA ANTONOVA	{"phone": "+70600775108"}
0005435286705	24234F	3107 661022	NATALIYA AFANASEVA	{"phone": "+70298096083"}
0005435286706	24234F	1018 443770	LIDIYA ZHURAVLEVA	{"phone": "+70402156096"}
0005435286707	0A6CBF	3385 029757	ELENA SEMENOVA	{"phone": "+70498106961"}
0005435286708	52D0B6	0537 355455	VERONIKA GUSEVA	{"email": "veronika.guseva.1974@postgrespro.ru", "phone": "+70863880155"}
0005435286709	BEA976	5509 126715	IVAN KAZAKOV	{"email": "i_kazakov-091979@postgrespro.ru", "phone": "+70708425976"}
0005435286710	B25EEF	9035 192939	EVGENIY SIDOROV	{"phone": "+70134065068"}
0005435286711	B25EEF	1677 212548	GALINA BORISOVA	{"email": "galina.borisova1959@postgrespro.ru", "phone": "+70638712897"}
0005435286712	1FF7B5	5467 067699	YURIY ZHUKOV	{"phone": "+70329702123"}
0005435286713	8144E6	7299 172932	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev07051962@postgrespro.ru", "phone": "+70675805651"}
0005435286714	67BFBC	8482 271108	NIKOLAY PETROV	{"phone": "+70729790186"}
0005435286715	E0F65A	8799 383359	TAMARA GERASIMOVA	{"email": "gerasimovat.071963@postgrespro.ru", "phone": "+70659570081"}
0005435286716	E03C27	0600 513273	MIKHAIL FILIPPOV	{"email": "filippovm051965@postgrespro.ru", "phone": "+70533163350"}
0005435286717	FEF3D0	9395 661651	VALENTINA ZAKHAROVA	{"phone": "+70858883466"}
0005435286718	07DB62	3146 538046	NIKOLAY MIKHAYLOV	{"phone": "+70667192246"}
0005435286719	07DB62	1455 162558	SVETLANA ZAYCEVA	{"phone": "+70630416149"}
0005435286720	D25764	9380 432920	VIKTOR GUSEV	{"phone": "+70614537394"}
0005435286721	A2C650	4050 126724	MARIYA VASILEVA	{"email": "mariya.vasileva-1989@postgrespro.ru", "phone": "+70969162682"}
0005435286722	A2C650	5937 087889	RUMIYA KOLESNIKOVA	{"email": "kolesnikova.r.101969@postgrespro.ru", "phone": "+70366951932"}
0005435286723	4BAB2C	3329 609032	EKATERINA KAZAKOVA	{"phone": "+70204583020"}
0005435286724	4BAB2C	3577 826177	KSENIYA NAUMOVA	{"phone": "+70424954788"}
0005435286725	0A0067	9781 088061	VALERIYA MEDVEDEVA	{"phone": "+70429893811"}
0005435286726	0A0067	2745 362266	MIKHAIL PAVLOV	{"phone": "+70026506864"}
0005435286727	BDCB02	9340 853197	PELAGEYA MAKSIMOVA	{"phone": "+70494697783"}
0005435286728	7C98C7	4871 745443	IRINA ANTONOVA	{"email": "antonova-i-021966@postgrespro.ru", "phone": "+70760951521"}
0005435286729	7C98C7	5510 558360	DMITRIY GORBUNOV	{"phone": "+70214607433"}
0005435286730	7C98C7	2855 759307	ALEKSANDR POPOV	{"phone": "+70273782183"}
0005435286731	3488A3	4530 429013	MARINA SIDOROVA	{"phone": "+70128371217"}
0005435286732	44B970	1521 731567	NIKOLAY MIKHAYLOV	{"email": "nikolaymikhaylov_1967@postgrespro.ru", "phone": "+70222203400"}
0005435286733	C81E68	4524 536777	ANDREY FOMIN	{"email": "fominandrey-1974@postgrespro.ru", "phone": "+70267038379"}
0005435286734	C81E68	7535 940614	YAROSLAV FEDOTOV	{"phone": "+70732204957"}
0005435286735	8484D5	1465 119716	MIKHAIL MIKHAYLOV	{"email": "mikhaylov_m_11071970@postgrespro.ru", "phone": "+70931779617"}
0005435286736	A990A8	5764 392424	VALENTINA VOLKOVA	{"phone": "+70882109043"}
0005435286737	36222A	1379 465492	LYUBOV ARKHIPOVA	{"phone": "+70928129112"}
0005435286738	36222A	0952 852869	OLGA NAZAROVA	{"email": "nazarova.o.021978@postgrespro.ru", "phone": "+70877211252"}
0005435286739	36222A	1140 222568	SVETLANA IVANOVA	{"phone": "+70723058570"}
0005435286740	3E55FA	0175 154118	LIDIYA ALEKSEEVA	{"phone": "+70720399373"}
0005435286741	3E55FA	3766 584660	DMITRIY PETROV	{"email": "petrov-dmitriy_071969@postgrespro.ru", "phone": "+70233111617"}
0005435286742	3E55FA	1471 857534	ALEKSEY IVANOV	{"email": "aivanov_16091966@postgrespro.ru", "phone": "+70389091788"}
0005435286743	F3C913	3414 920356	EVELINA NOVIKOVA	{"email": "novikova-evelina-101976@postgrespro.ru", "phone": "+70296290184"}
0005435286744	A8874C	3183 668038	MARIYA MOROZOVA	{"email": "morozova-mariya_111979@postgrespro.ru", "phone": "+70403648185"}
0005435286745	A8874C	8993 789805	LIDIYA IVANOVA	{"phone": "+70106594961"}
0005435286746	118B78	3074 534118	ALEKSEY MOROZOV	{"email": "amorozov29091963@postgrespro.ru", "phone": "+70798844257"}
0005435286747	118B78	3825 660067	MIKHAIL MOROZOV	{"email": "morozov_mikhail_1967@postgrespro.ru", "phone": "+70181422863"}
0005435286748	118B78	2884 816783	MIKHAIL OSIPOV	{"email": "m-osipov_121980@postgrespro.ru", "phone": "+70502574203"}
0005435286749	F11B31	9234 664414	VASILIY KOZLOV	{"phone": "+70284535484"}
0005435286750	EB9C79	9847 244454	VIKTOR GORBUNOV	{"email": "v_gorbunov_09121972@postgrespro.ru", "phone": "+70430472628"}
0005435286751	EB9C79	1161 948874	RAISA KOZLOVA	{"email": "r.kozlova15051961@postgrespro.ru", "phone": "+70367509638"}
0005435286752	6408B1	1554 263174	NIKITA POPOV	{"phone": "+70751927111"}
0005435286753	CEB88D	7862 297377	EKATERINA ZAYCEVA	{"email": "e-zayceva.05111977@postgrespro.ru", "phone": "+70515393824"}
0005435286754	B2FBD7	0994 043887	TATYANA NOVIKOVA	{"phone": "+70338999105"}
0005435286755	6E9C5A	5546 676205	ELENA OVCHINNIKOVA	{"email": "ovchinnikovae-21071973@postgrespro.ru", "phone": "+70091409221"}
0005435286756	D04E1A	9134 224934	NIKOLAY KUZNECOV	{"phone": "+70598062901"}
0005435286757	FA326A	5004 047544	ELENA ABRAMOVA	{"phone": "+70982218364"}
0005435286758	35E883	2770 848520	KLAVDIYA NIKOLAEVA	{"phone": "+70892241483"}
0005435286759	82CA5F	6936 921487	OLGA MAKAROVA	{"email": "olga_makarova-22111974@postgrespro.ru", "phone": "+70004343201"}
0005435286761	D0A3A5	1858 043868	PAVEL IVANOV	{"phone": "+70975614859"}
0005435286762	44BF61	7082 475605	VLADIMIR IVANOV	{"email": "vladimir_ivanov_101980@postgrespro.ru", "phone": "+70496027848"}
0005435286763	8A9A47	5758 279093	ELENA ILINA	{"phone": "+70538871935"}
0005435286764	FF3476	3453 964578	ALEKSEY MAKSIMOV	{"email": "alekseymaksimov1976@postgrespro.ru", "phone": "+70138083007"}
0005435286765	FF3476	8580 345323	MIKHAIL FROLOV	{"phone": "+70331210557"}
0005435286766	FF3476	0437 889477	VLADISLAV MOROZOV	{"phone": "+70929775833"}
0005435286767	97C12F	0043 968099	ANATOLIY GUSEV	{"phone": "+70537808855"}
0005435286768	5FBA38	9775 466950	SVETLANA BELYAEVA	{"phone": "+70585644615"}
0005435286769	5FBA38	3316 618769	NIKOLAY NIKITIN	{"phone": "+70229908049"}
0005435286770	5FBA38	0870 304770	OLGA NIKOLAEVA	{"phone": "+70619225048"}
0005435286771	1C7A5D	6127 155586	SVETLANA PAVLOVA	{"email": "pavlova.svetlana-101967@postgrespro.ru", "phone": "+70105364203"}
0005435286772	1C7A5D	4072 709258	NIKOLAY EGOROV	{"email": "n_egorov-1974@postgrespro.ru", "phone": "+70784651491"}
0005435286773	944175	4200 208754	ANATOLIY PETROV	{"email": "petrov_anatoliy_021975@postgrespro.ru", "phone": "+70595015945"}
0005435286774	52064C	8227 429887	NINA KOROLEVA	{"phone": "+70022419446"}
0005435286775	EC1571	8932 122637	ANDREY VOLKOV	{"email": "andreyvolkov_04061967@postgrespro.ru", "phone": "+70389530676"}
0005435286776	EC1571	1824 340041	ELENA OSIPOVA	{"phone": "+70104213249"}
0005435286777	00DAE4	9344 742399	LYUBOV KOZLOVA	{"phone": "+70067378039"}
0005435286778	00DAE4	9678 482795	LYUDMILA RODIONOVA	{"email": "lyudmilarodionova.031972@postgrespro.ru", "phone": "+70633276374"}
0005435286779	22F460	0997 324538	RAISA MOROZOVA	{"email": "raisa-morozova-1969@postgrespro.ru", "phone": "+70207426489"}
0005435286780	D6383C	5809 887322	ANNA AKIMOVA	{"phone": "+70364800805"}
0005435286781	D6383C	6546 798141	YURIY NAZAROV	{"email": "ynazarov_101970@postgrespro.ru", "phone": "+70068074841"}
0005435286782	B6250A	9873 136622	SERGEY ZAYCEV	{"email": "s-zaycev-1973@postgrespro.ru", "phone": "+70101320242"}
0005435286783	C75982	5216 925252	ANTON VOLKOV	{"phone": "+70272248873"}
0005435286784	C75982	1712 328185	SERGEY ZAKHAROV	{"phone": "+70716055705"}
0005435286785	52E8F0	0656 375184	NIKOLAY SERGEEV	{"email": "sergeev.nikolay-17031957@postgrespro.ru", "phone": "+70257673668"}
0005435286786	52E8F0	7894 207459	ELENA DMITRIEVA	{"email": "e.dmitrieva-18061961@postgrespro.ru", "phone": "+70284409818"}
0005435286787	A3912E	9297 308333	GEVORG KOROLEV	{"email": "gevorg.korolev_101980@postgrespro.ru", "phone": "+70242515931"}
0005435286788	5F33AB	7647 830108	VLADIMIR ILIN	{"phone": "+70040903142"}
0005435286789	6B9BF0	7114 139565	TATYANA ZHURAVLEVA	{"phone": "+70463930955"}
0005435286790	A63502	4513 773884	VLADIMIR KUZMIN	{"phone": "+70271672899"}
0005435286791	38D7EB	2082 707429	STEPAN BONDARENKO	{"email": "sbondarenko_011977@postgrespro.ru", "phone": "+70940974680"}
0005435286792	38D7EB	7073 217673	LIDIYA AFANASEVA	{"email": "afanaseva-lidiya_1971@postgrespro.ru", "phone": "+70571886937"}
0005435286793	884E08	6297 414321	SVETLANA POPOVA	{"email": "svetlana-popova-1960@postgrespro.ru", "phone": "+70489040873"}
0005435286794	A2B555	1695 885960	NIKOLAY KUZNECOV	{"phone": "+70893503957"}
0005435286795	A2B555	3858 319134	ALEKSANDR OSIPOV	{"email": "a.osipov_1965@postgrespro.ru", "phone": "+70925012222"}
0005435286796	8B15AA	9349 102004	GALINA SIDOROVA	{"email": "sidorovagalina_03061973@postgrespro.ru", "phone": "+70399617022"}
0005435286797	94B743	1402 719231	VYACHESLAV FROLOV	{"phone": "+70332307252"}
0005435286798	270C1F	3192 582903	NADEZHDA IVANOVA	{"email": "ivanovanadezhda1973@postgrespro.ru", "phone": "+70579498015"}
0005435286799	270C1F	3502 247830	ELENA POLYAKOVA	{"phone": "+70102197771"}
0005435286800	7F141A	4146 567060	ELENA EGOROVA	{"phone": "+70972507789"}
0005435286801	2A7F03	3974 383879	YURIY GUSEV	{"email": "gusevyuriy_041972@postgrespro.ru", "phone": "+70635542304"}
0005435286802	2A7F03	8417 816690	LYUDMILA ZAYCEVA	{"email": "lyudmila-zayceva01071968@postgrespro.ru", "phone": "+70795249548"}
0005435286803	2A7F03	5136 159337	NATALYA KUZNECOVA	{"phone": "+70763986482"}
0005435286804	AB76B9	6050 982746	ANDREY MOISEEV	{"email": "a-moiseev.071973@postgrespro.ru", "phone": "+70398025562"}
0005435286805	9804A4	8939 028235	ANDREY ZHURAVLEV	{"email": "zhuravlev_andrey-02121977@postgrespro.ru", "phone": "+70060392993"}
0005435286806	AD4E2E	1073 647240	TIMOFEY KRASNOV	{"email": "timofey-krasnov_1967@postgrespro.ru", "phone": "+70044438268"}
0005435286807	AD4E2E	9165 677930	OLEG PETROV	{"email": "o.petrov_07041968@postgrespro.ru", "phone": "+70784038644"}
0005435286808	4445F7	2281 931465	EVGENIY SCHERBAKOV	{"phone": "+70501677179"}
0005435286809	4445F7	0968 488576	ALEKSANDRA NESTEROVA	{"email": "a_nesterova-041971@postgrespro.ru", "phone": "+70816703477"}
0005435286810	7F87B4	9669 004135	IGOR ANDREEV	{"phone": "+70074883095"}
0005435286811	DF0C7A	3845 827902	MARINA POLYAKOVA	{"phone": "+70643679502"}
0005435286812	050AF6	8530 738500	VADIM GRIGOREV	{"email": "v_grigorev-041967@postgrespro.ru", "phone": "+70236308982"}
0005435286813	F24490	0510 398254	ANDREY OSIPOV	{"email": "osipov_andrey-1973@postgrespro.ru", "phone": "+70036878043"}
0005435286814	286FA2	3825 819353	NURLAN DAVYDOV	{"email": "n_davydov.021968@postgrespro.ru", "phone": "+70518922893"}
0005435286815	286FA2	1962 543465	SERGEY KULIKOV	{"email": "s-kulikov.1978@postgrespro.ru", "phone": "+70969112771"}
0005435286816	2B7BF3	7280 847985	RUSTAM MIKHAYLOV	{"email": "mikhaylov_rustam.15041975@postgrespro.ru", "phone": "+70641552165"}
0005435286817	DD4EAD	1936 369213	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya_mikhaylova-1972@postgrespro.ru", "phone": "+70336021598"}
0005435286818	E9C405	5042 071132	PAVEL TIKHONOV	{"email": "paveltikhonov1981@postgrespro.ru", "phone": "+70349419998"}
0005435286819	BA0878	3822 290740	ANTONINA VOLKOVA	{"phone": "+70095498087"}
0005435286820	163661	8832 057494	POLINA SOROKINA	{"email": "sorokina.p1968@postgrespro.ru", "phone": "+70708929900"}
0005435286821	2624CB	8536 465050	SVETLANA FEDOROVA	{"email": "fedorovasvetlana091961@postgrespro.ru", "phone": "+70681658616"}
0005435286822	ABD73C	9725 434825	ARTEM ALEKSANDROV	{"phone": "+70559447783"}
0005435286823	ABD73C	1901 344483	ANDREY MELNIKOV	{"phone": "+70718999645"}
0005435286824	CAEFB1	9239 728821	GALINA SOKOLOVA	{"email": "galinasokolova_1976@postgrespro.ru", "phone": "+70891727392"}
0005435286825	CAEFB1	3347 105751	TATYANA SMIRNOVA	{"phone": "+70638112477"}
0005435286826	7AEA3C	2709 665399	SERGEY STEPANOV	{"email": "stepanov-sergey.121981@postgrespro.ru", "phone": "+70068696960"}
0005435286827	7AEA3C	0376 413437	NADEZHDA PAVLOVA	{"phone": "+70291017750"}
0005435286828	06158B	3724 965192	ELIZAVETA ANISIMOVA	{"email": "anisimova.elizaveta-1975@postgrespro.ru", "phone": "+70290421544"}
0005435286829	06158B	8284 094832	ELENA KOZLOVA	{"phone": "+70680179082"}
0005435286830	D3D3E2	7459 510466	ALEKSEY MAKSIMOV	{"email": "alekseymaksimov.1968@postgrespro.ru", "phone": "+70270824546"}
0005435286831	D3D3E2	2292 718480	ANASTASIYA ORLOVA	{"email": "orlova-a_071969@postgrespro.ru", "phone": "+70339011915"}
0005435286832	D3D3E2	5801 527181	ELENA MALYSHEVA	{"email": "elenamalysheva21091975@postgrespro.ru", "phone": "+70276798478"}
0005435286833	2DF268	5462 060072	VERONIKA EGOROVA	{"email": "veronikaegorova_1970@postgrespro.ru", "phone": "+70243072726"}
0005435286834	CB0007	6919 231074	SERGEY NAUMOV	{"email": "naumovs-071975@postgrespro.ru", "phone": "+70650979804"}
0005435286835	CB0007	1356 657275	SVETLANA EGOROVA	{"email": "s.egorova_29111968@postgrespro.ru", "phone": "+70119641583"}
0005435286836	CB0007	1983 826638	TAMARA ANISIMOVA	{"phone": "+70139377291"}
0005435286837	4A95DA	7630 860930	VASILIY NAUMOV	{"email": "v_naumov-021960@postgrespro.ru", "phone": "+70576527502"}
0005435286838	295722	1034 399371	TAMARA EGOROVA	{"email": "tamara-egorova-1967@postgrespro.ru", "phone": "+70279876865"}
0005435286839	295722	1512 182478	ELIZAVETA ANTONOVA	{"email": "e_antonova.081987@postgrespro.ru", "phone": "+70417490033"}
0005435286840	119AE5	4960 623309	MIKHAIL SOROKIN	{"email": "m.sorokin.121968@postgrespro.ru", "phone": "+70517206232"}
0005435286841	119AE5	2841 104395	ANASTASIYA BELOVA	{"email": "belova_anastasiya_041975@postgrespro.ru", "phone": "+70958407267"}
0005435286842	119AE5	1324 971463	LARISA TARASOVA	{"email": "tarasova_larisa091971@postgrespro.ru", "phone": "+70857240479"}
0005435286843	6AE610	7009 925420	YULIYA SOROKINA	{"email": "sorokina.y_1975@postgrespro.ru", "phone": "+70906603554"}
0005435286844	0F9522	4960 651647	OLGA VOLKOVA	{"email": "volkova-o-22051977@postgrespro.ru", "phone": "+70516997681"}
0005435286845	420556	8259 900002	ALBERT POPOV	{"email": "popov_a-07091966@postgrespro.ru", "phone": "+70347409059"}
0005435286846	420556	7501 867126	VIKTORIYA AKIMOVA	{"phone": "+70197077987"}
0005435286847	420556	0990 160504	NATALIYA ANISIMOVA	{"email": "nataliya-anisimova-081972@postgrespro.ru", "phone": "+70476045140"}
0005435286848	947FEC	0045 621243	ALEKSANDR EGOROV	{"phone": "+70524804200"}
0005435286849	8E9FB0	8938 807983	IVAN ANDREEV	{"email": "andreevivan_1967@postgrespro.ru", "phone": "+70705769573"}
0005435286850	BDC0AA	3380 049931	VADIM IVANOV	{"email": "ivanov.vadim_25091970@postgrespro.ru", "phone": "+70104613842"}
0005435286851	E7B68D	8352 191887	KONSTANTIN KONOVALOV	{"email": "konovalovkonstantin-121973@postgrespro.ru", "phone": "+70298531321"}
0005435286852	E7B68D	4053 684496	VIKTORIYA KUZNECOVA	{"email": "vkuznecova.18031969@postgrespro.ru", "phone": "+70343135985"}
0005435286853	FBDA2E	3785 891696	ALEKSEY ZAYCEV	{"email": "a.zaycev_28101973@postgrespro.ru", "phone": "+70059934706"}
0005435286854	C95A10	1009 966877	GALINA KAZAKOVA	{"email": "kazakova_galina_1976@postgrespro.ru", "phone": "+70600477018"}
0005435286855	C95A10	9988 392318	ALEKSEY IVANOV	{"phone": "+70619075751"}
0005435286856	C95A10	6124 978552	SVETLANA IVANOVA	{"phone": "+70569790176"}
0005435286857	D26EC4	8626 485618	ANDREY IVANOV	{"phone": "+70452347222"}
0005435286858	D3A708	8441 828904	DENIS KUZNECOV	{"phone": "+70838622453"}
0005435286859	4A90AE	1038 108851	EGOR ZHURAVLEV	{"email": "zhuravlev-egor_08021979@postgrespro.ru", "phone": "+70496814400"}
0005435286860	A884B1	3877 723523	DMITRIY MATVEEV	{"email": "matveev-dmitriy-1964@postgrespro.ru", "phone": "+70851256433"}
0005435286861	5AD261	5967 046682	MARSEL POPOV	{"email": "popovm_061976@postgrespro.ru", "phone": "+70945141866"}
0005435286862	C42EA7	4552 217323	PAVEL ILIN	{"email": "ilin_pavel051973@postgrespro.ru", "phone": "+70821353660"}
0005435286863	DD3F58	0905 018130	DMITRIY ROMANOV	{"phone": "+70425557878"}
0005435286864	D0DD7F	0027 959822	MARGARITA ISAEVA	{"email": "isaeva.m.1966@postgrespro.ru", "phone": "+70308256304"}
0005435286865	D0DD7F	2430 764696	VIKTOR KUZMIN	{"email": "viktor_kuzmin-1962@postgrespro.ru", "phone": "+70253099075"}
0005435286866	B4E8F4	6799 663047	VLADIMIR VOLKOV	{"email": "vladimir.volkov-29011966@postgrespro.ru", "phone": "+70557529115"}
0005435286867	B4E8F4	0476 756963	VLADISLAV GORBUNOV	{"phone": "+70834180145"}
0005435286868	63509B	7331 500022	NADEZHDA GAVRILOVA	{"phone": "+70779171029"}
0005435286869	9ABCF6	6245 378264	ALINA KUZMINA	{"email": "kuzmina.alina-1967@postgrespro.ru", "phone": "+70506026725"}
0005435286870	6176C7	9846 846410	NADEZHDA SMIRNOVA	{"email": "nadezhda.smirnova_1967@postgrespro.ru", "phone": "+70696676248"}
0005435286871	6176C7	2238 514483	OLESYA NOVIKOVA	{"email": "olesya-novikova.08061966@postgrespro.ru", "phone": "+70886156949"}
0005435286872	177320	3332 530554	ELENA KALININA	{"email": "ekalinina01091970@postgrespro.ru", "phone": "+70919989388"}
0005435286873	177320	0032 372649	MIKHAIL MOROZOV	{"email": "mikhailmorozov_1960@postgrespro.ru", "phone": "+70224316387"}
0005435286874	47C44C	3187 389532	GALINA GAVRILOVA	{"email": "gavrilova_galina_02101967@postgrespro.ru", "phone": "+70055483870"}
0005435286875	2B80EF	7434 793778	DARYA MATVEEVA	{"phone": "+70794811365"}
0005435286876	2B80EF	4415 149836	ANNA SEMENOVA	{"email": "semenovaanna_05121971@postgrespro.ru", "phone": "+70835340762"}
0005435286877	C7DABB	5991 047015	MAKSIM TIKHONOV	{"email": "mtikhonov1971@postgrespro.ru", "phone": "+70734399621"}
0005435286878	46EE58	0790 080767	IGOR NIKITIN	{"email": "i.nikitin_1969@postgrespro.ru", "phone": "+70103042126"}
0005435286879	EA7ABA	3217 862797	VALENTIN ZAYCEV	{"phone": "+70831907882"}
0005435286880	97B03F	4032 791498	ANDREY BARANOV	{"email": "andreybaranov.1965@postgrespro.ru", "phone": "+70180786298"}
0005435286881	97B03F	8710 523159	ARTEM SEMENOV	{"email": "semenovartem_111972@postgrespro.ru", "phone": "+70998544676"}
0005435286882	FF1D68	4250 703176	LYUBOV SAVELEVA	{"phone": "+70295470185"}
0005435286883	83272F	7404 475122	OLGA MIRONOVA	{"phone": "+70969431178"}
0005435286884	83272F	8350 292804	YULIYA IVANOVA	{"email": "yuliya-ivanova_071974@postgrespro.ru", "phone": "+70734337492"}
0005435286885	0EBD03	4546 398999	VLADISLAV MOISEEV	{"phone": "+70187749237"}
0005435286886	401BDB	3086 816368	ALEKSEY VASILEV	{"email": "vasilevaleksey_13041975@postgrespro.ru", "phone": "+70771871314"}
0005435286887	401BDB	3455 940445	BULAT KUDRYASHOV	{"phone": "+70087573350"}
0005435286888	B751B9	8959 925297	SERGEY ZAYCEV	{"email": "sergey_zaycev.081970@postgrespro.ru", "phone": "+70347899752"}
0005435286889	B128F3	4426 698165	ANTONINA DAVYDOVA	{"email": "a_davydova_101979@postgrespro.ru", "phone": "+70918284992"}
0005435286890	5DF283	8165 283371	VITALIY FEDOTOV	{"phone": "+70385705606"}
0005435286891	5DF283	4123 775062	TATYANA MALYSHEVA	{"email": "malysheva-tatyana.1970@postgrespro.ru", "phone": "+70701783280"}
0005435286892	55164A	7562 759618	IRINA CHERNOVA	{"phone": "+70901861293"}
0005435286893	0821AF	4514 674287	DMITRIY YAKOVLEV	{"email": "yakovlev.d-1979@postgrespro.ru", "phone": "+70488920157"}
0005435286894	0821AF	9372 406428	NIKOLAY KOROLEV	{"phone": "+70237045017"}
0005435286895	0821AF	2146 950345	VASILIY KARPOV	{"email": "karpov.vasiliy-091980@postgrespro.ru", "phone": "+70960502209"}
0005435286896	A06E98	3683 489903	ANASTASIYA DENISOVA	{"email": "denisova.anastasiya_1956@postgrespro.ru", "phone": "+70648356893"}
0005435286897	F83FBF	2904 719137	YANA SOLOVEVA	{"phone": "+70500637689"}
0005435286898	B759EA	2869 622046	LYUDMILA VASILEVA	{"email": "vasileva_l1974@postgrespro.ru", "phone": "+70070378244"}
0005435286899	1AB19B	4276 189465	RAFIK ILIN	{"email": "ilin-r.27051975@postgrespro.ru", "phone": "+70944599284"}
0005435286900	03A0A7	5391 059477	VIKTOR SOROKIN	{"phone": "+70775843957"}
0005435286901	07EC65	5646 688151	YULIYA VOLKOVA	{"email": "volkovayuliya_01091969@postgrespro.ru", "phone": "+70712875572"}
0005435286902	AD5A8C	2694 628048	ANASTASIYA GAVRILOVA	{"phone": "+70724662584"}
0005435286903	EA0942	9243 424505	VALENTINA BELOVA	{"email": "vbelova021976@postgrespro.ru", "phone": "+70649624312"}
0005435286904	EA0942	4466 336705	OLGA ERMAKOVA	{"email": "o-ermakova_031988@postgrespro.ru", "phone": "+70011333331"}
0005435286905	79FEE3	4153 848937	ANTONINA IVANOVA	{"phone": "+70171422608"}
0005435286906	A062E5	0374 198001	PAVEL KISELEV	{"email": "kiselev_pavel-20011972@postgrespro.ru", "phone": "+70164923946"}
0005435286907	C65D1C	7559 104455	OLGA TIKHONOVA	{"phone": "+70895170552"}
0005435286908	C65D1C	3394 108082	ANTON ZHURAVLEV	{"phone": "+70235665007"}
0005435286909	A8846D	1205 703920	MARIYA OSIPOVA	{"phone": "+70857584891"}
0005435286910	2FDB76	5044 471248	LILIYA IVANOVA	{"phone": "+70710154554"}
0005435286911	2FDB76	9465 866845	VALERIYA KONOVALOVA	{"phone": "+70523481112"}
0005435286912	F73FE8	7633 330651	KONSTANTIN KUDRYASHOV	{"phone": "+70210039423"}
0005435286913	F73FE8	1476 356900	SERGEY VLASOV	{"email": "vlasov.s.11121975@postgrespro.ru", "phone": "+70855758193"}
0005435286914	FF562A	5394 483048	ANNA GUSEVA	{"phone": "+70472515016"}
0005435286915	7509A0	6594 933246	DENIS EGOROV	{"phone": "+70801163489"}
0005435286916	7509A0	1926 209497	ELENA DENISOVA	{"phone": "+70016351214"}
0005435286917	F00B8C	2317 926742	KSENIYA SMIRNOVA	{"email": "smirnova_kseniya_061960@postgrespro.ru", "phone": "+70467162520"}
0005435286918	F00B8C	4543 882652	MARIYA BOGDANOVA	{"phone": "+70539218316"}
0005435286919	F00B8C	1555 126735	ELIZAVETA IVANOVA	{"phone": "+70373889871"}
0005435286920	FCE4D8	2698 050512	VIKTOR STEPANOV	{"phone": "+70110198490"}
0005435286921	FCE4D8	6785 787820	NATALYA NIKITINA	{"email": "nikitina-n.10081975@postgrespro.ru", "phone": "+70886316626"}
0005435286922	3BEFD0	7596 302833	NIKOLAY MOROZOV	{"email": "nikolay-morozov1960@postgrespro.ru", "phone": "+70829228856"}
0005435286923	3BEFD0	2798 069634	ELENA SOKOLOVA	{"email": "esokolova_051973@postgrespro.ru", "phone": "+70061562703"}
0005435286924	A0256D	0196 571544	MARINA KOROLEVA	{"email": "koroleva-m.061966@postgrespro.ru", "phone": "+70379007662"}
0005435286925	A0256D	6483 469625	IGOR MOROZOV	{"phone": "+70151217913"}
0005435286926	522F22	3774 990049	ANTONINA IVANOVA	{"phone": "+70927554839"}
0005435286927	9D2E6D	4925 517433	VLADIMIR KUZNECOV	{"email": "v.kuznecov.10011973@postgrespro.ru", "phone": "+70081151517"}
0005435286928	9D2E6D	2442 913737	ANATOLIY SOKOLOV	{"email": "anatoliy-sokolov_15111963@postgrespro.ru", "phone": "+70533240532"}
0005435286929	9D2E6D	4614 520798	BORIS POPOV	{"email": "popov.boris-1976@postgrespro.ru", "phone": "+70200362902"}
0005435286930	9D2E6D	2548 195625	TATYANA POPOVA	{"phone": "+70954896985"}
0005435286931	842E12	2174 990546	OKSANA EGOROVA	{"email": "oksanaegorova.26021976@postgrespro.ru", "phone": "+70468536912"}
0005435286932	A064DE	8607 678163	VALENTINA PETROVA	{"email": "petrova_v_031966@postgrespro.ru", "phone": "+70186902856"}
0005435286933	5D4193	7633 939463	OLEG SIDOROV	{"phone": "+70122503487"}
0005435286934	5D4193	0411 869450	VALERIYA KOROLEVA	{"phone": "+70929800777"}
0005435286935	E466DB	4552 322742	GULNAZ PAVLOVA	{"email": "pavlova.g24041967@postgrespro.ru", "phone": "+70756288246"}
0005435286996	14DE26	8107 252911	TAISIYA KUZMINA	{"phone": "+70522986687"}
0005435286936	B6E6C8	8504 479150	MIKHAIL ANDREEV	{"email": "m_andreev011974@postgrespro.ru", "phone": "+70116690006"}
0005435286937	789670	1197 220256	ALEKSANDR SOKOLOV	{"phone": "+70767438150"}
0005435286938	3E7B17	7456 892355	NIKITA AFANASEV	{"phone": "+70951647743"}
0005435286939	3E7B17	0079 324802	MARINA MIRONOVA	{"phone": "+70861575595"}
0005435286940	6D7451	9037 114337	EVGENIY KOROLEV	{"email": "koroleve.1972@postgrespro.ru", "phone": "+70993187757"}
0005435286941	6D7451	7703 846181	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr24041977@postgrespro.ru", "phone": "+70574529381"}
0005435286942	93B9F2	7894 267831	NINA OSIPOVA	{"phone": "+70364602045"}
0005435286943	EC9E01	0262 973589	MARINA GRISHINA	{"email": "grishina-m07031973@postgrespro.ru", "phone": "+70995652448"}
0005435286944	B0ED0D	9993 342644	SVETLANA FADEEVA	{"email": "fadeevasvetlana.031964@postgrespro.ru", "phone": "+70136740717"}
0005435286945	FC8CA7	4879 395869	LYUBOV POPOVA	{"phone": "+70363535023"}
0005435286946	AEF5C2	5104 641150	VASILIY EGOROV	{"email": "egorov.vasiliy_30041972@postgrespro.ru", "phone": "+70553806931"}
0005435286947	BC9FD4	4561 880868	LYUDMILA AKIMOVA	{"phone": "+70957558119"}
0005435286948	28B564	4221 447552	KIRILL DMITRIEV	{"phone": "+70700148057"}
0005435286949	5B386A	2879 051735	ALEKSEY STEPANOV	{"email": "stepanov.a-1962@postgrespro.ru", "phone": "+70189153433"}
0005435286950	5B6301	9764 565841	ALEKSEY NIKITIN	{"phone": "+70045279558"}
0005435286951	5B6301	7249 640322	VLADIMIR VOLKOV	{"email": "vvolkov101980@postgrespro.ru", "phone": "+70960172683"}
0005435286952	BB110B	5543 584878	YAROSLAV ZAKHAROV	{"phone": "+70663288667"}
0005435286953	224A20	3100 184949	OKSANA YAKOVLEVA	{"email": "yakovleva-oksana-091976@postgrespro.ru", "phone": "+70469193030"}
0005435286954	791047	7086 828931	ARTEM STEPANOV	{"phone": "+70007436900"}
0005435286955	0389A5	6839 819019	DANILA ALEKSEEV	{"email": "dalekseev-121967@postgrespro.ru", "phone": "+70626598431"}
0005435286956	720D88	8378 290983	NIKOLAY MIKHAYLOV	{"email": "mikhaylov.n121983@postgrespro.ru", "phone": "+70646049830"}
0005435286957	720D88	4278 681293	LYUBOV ALEKSEEVA	{"phone": "+70780478986"}
0005435286958	720D88	4451 496986	ROMAN GERASIMOV	{"email": "gerasimov-roman-011970@postgrespro.ru", "phone": "+70585637495"}
0005435286959	7B40BF	0555 045844	NINA ROMANOVA	{"phone": "+70435954633"}
0005435286960	2AB3F4	3705 766740	LYUBOV MARTYNOVA	{"phone": "+70551008232"}
0005435286961	2AB3F4	1327 767720	NATALIYA SCHERBAKOVA	{"phone": "+70339915880"}
0005435286962	3482E3	2734 049080	PELAGEYA NIKITINA	{"phone": "+70994825640"}
0005435286963	3482E3	6017 559611	SVETLANA ANTONOVA	{"email": "antonovasvetlana_071971@postgrespro.ru", "phone": "+70182675704"}
0005435286964	3482E3	2716 455037	GEORGIY AFANASEV	{"email": "georgiy-afanasev_041967@postgrespro.ru", "phone": "+70773771111"}
0005435286965	FA55BD	0333 389843	ARINA OSIPOVA	{"email": "osipova.arina.051975@postgrespro.ru", "phone": "+70356750255"}
0005435286966	EB811B	2797 265474	SERGEY POPOV	{"phone": "+70995936410"}
0005435286967	8DC173	5869 244172	ARTUR KRASNOV	{"email": "krasnovartur-081972@postgrespro.ru", "phone": "+70156424091"}
0005435286968	8DC173	6305 528915	VLADIMIR EGOROV	{"email": "vegorov-071979@postgrespro.ru", "phone": "+70760379441"}
0005435286969	75D8F0	1757 697032	VASILIY ZAYCEV	{"email": "zaycevvasiliy-1973@postgrespro.ru", "phone": "+70114302443"}
0005435286970	9F42CE	4693 906691	ELENA KRASNOVA	{"phone": "+70276502897"}
0005435286971	9F42CE	7158 298158	VLADIMIR GAVRILOV	{"phone": "+70492689153"}
0005435286972	485048	8630 921731	IVAN RODIONOV	{"phone": "+70643163836"}
0005435286973	90ABF7	7249 136484	EVGENIYA OVCHINNIKOVA	{"phone": "+70664642222"}
0005435286974	90ABF7	5013 779169	DMITRIY GRIGOREV	{"phone": "+70060963607"}
0005435286975	D09077	7697 771142	RAIS NAZAROV	{"email": "r_nazarov26081979@postgrespro.ru", "phone": "+70906650799"}
0005435286976	E1B0E6	8679 319899	LYUDMILA TIKHONOVA	{"email": "l_tikhonova.1968@postgrespro.ru", "phone": "+70504758493"}
0005435286977	E1B0E6	0548 915316	NIKOLAY GORBUNOV	{"email": "nikolay_gorbunov_091981@postgrespro.ru", "phone": "+70324138329"}
0005435286978	70DE4F	1822 663902	EVDOKIYA PAVLOVA	{"email": "pavlova-e-081968@postgrespro.ru", "phone": "+70589325675"}
0005435286979	70DE4F	9766 129297	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr-31011967@postgrespro.ru", "phone": "+70072724784"}
0005435286980	5C169C	7988 282931	ANNA VASILEVA	{"email": "vasileva_anna.031975@postgrespro.ru", "phone": "+70100977313"}
0005435286981	5C169C	9633 034481	NATALYA ROMANOVA	{"phone": "+70058840048"}
0005435286982	240AF9	9519 605661	ANDREY DENISOV	{"email": "denisov-andrey_1969@postgrespro.ru", "phone": "+70738068629"}
0005435286983	BE70FA	1681 127663	NINA POTAPOVA	{"phone": "+70241404364"}
0005435286984	12ACAF	3930 717612	TATYANA EGOROVA	{"email": "tatyana_egorova_1975@postgrespro.ru", "phone": "+70289334843"}
0005435286985	62288C	9520 379809	ALEKSANDR FILIPPOV	{"phone": "+70946219529"}
0005435286986	62288C	4288 716540	IGOR DENISOV	{"phone": "+70895707005"}
0005435286987	F1B599	4168 958571	BOGDAN KRASNOV	{"phone": "+70233137073"}
0005435286988	FE1965	0657 438154	ANNA TROFIMOVA	{"phone": "+70816095146"}
0005435286989	830AAF	7979 560040	VALENTINA EFIMOVA	{"phone": "+70701581204"}
0005435286990	772C0C	3276 866069	GENNADIY MIRONOV	{"email": "gennadiy-mironov-051968@postgrespro.ru", "phone": "+70866337665"}
0005435286991	52F1C7	6938 888303	YURIY SOROKIN	{"email": "y.sorokin.081971@postgrespro.ru", "phone": "+70757653589"}
0005435286992	49D97C	3313 982845	VALENTINA BORISOVA	{"email": "valentina.borisova_1969@postgrespro.ru", "phone": "+70655981477"}
0005435286993	49D97C	7175 316158	EKATERINA KUZNECOVA	{"phone": "+70622472449"}
0005435286994	14DE26	1451 174024	SERGEY BORISOV	{"email": "borisovsergey111974@postgrespro.ru", "phone": "+70880382172"}
0005435286995	14DE26	4165 780862	GEORGIY KUZNECOV	{"phone": "+70666422325"}
0005435286997	117EB5	1441 334125	GALINA GAVRILOVA	{"phone": "+70964630762"}
0005435286998	E38A89	8815 840960	LYUDMILA SOLOVEVA	{"phone": "+70422309172"}
0005435286999	E38A89	1795 758561	ALINA POPOVA	{"email": "popova_alina-1966@postgrespro.ru", "phone": "+70599450340"}
0005435287000	DDB381	8970 546154	IRINA MASLOVA	{"email": "maslova.irina09111972@postgrespro.ru", "phone": "+70535478456"}
0005435287001	DDB381	7169 501400	VERONIKA SMIRNOVA	{"phone": "+70463999207"}
0005435287002	DDB381	7776 853895	ALEKSANDR SHEVCHENKO	{"email": "aleksandrshevchenko04061957@postgrespro.ru", "phone": "+70553368987"}
0005435287003	0E2CBA	0713 994928	TATYANA IVANOVA	{"email": "t-ivanova28111965@postgrespro.ru", "phone": "+70230314490"}
0005435287004	5AD38D	7257 608148	POLINA VASILEVA	{"phone": "+70609223254"}
0005435287005	0AAAC3	3700 564868	ALFIYA MEDVEDEVA	{"email": "medvedevaalfiya-15081975@postgrespro.ru", "phone": "+70329439807"}
0005435287006	0AAAC3	7326 136302	MIKHAIL ANTONOV	{"email": "mikhail-antonov-111981@postgrespro.ru", "phone": "+70864509215"}
0005435287007	48FCA6	4366 156682	VLADIMIR SOKOLOV	{"email": "sokolovvladimir-071981@postgrespro.ru", "phone": "+70780850311"}
0005435287008	55DB97	6997 000416	VLADIMIR GAVRILOV	{"email": "vgavrilov061978@postgrespro.ru", "phone": "+70266298951"}
0005435287009	AB236B	9329 308540	LYUBOV ZAKHAROVA	{"email": "lyubov.zakharova06051960@postgrespro.ru", "phone": "+70871519973"}
0005435287010	AB236B	6790 763212	DMITRIY MOISEEV	{"phone": "+70069037085"}
0005435287011	F72771	9589 823351	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov_17071968@postgrespro.ru", "phone": "+70448094883"}
0005435287012	F72771	7817 374685	VIKTOR PETROV	{"email": "petrovviktor-061964@postgrespro.ru", "phone": "+70695802644"}
0005435287013	93B72D	1576 083893	VITALIY BELOV	{"email": "belov.vitaliy-111974@postgrespro.ru", "phone": "+70750396363"}
0005435287014	58CFE2	9976 389920	DANILA MATVEEV	{"email": "danila.matveev19091982@postgrespro.ru", "phone": "+70987703025"}
0005435287015	58CFE2	2309 095176	SVETLANA VOROBEVA	{"email": "svorobeva.121966@postgrespro.ru", "phone": "+70918177634"}
0005435287016	58CFE2	8648 642150	VALERIY MELNIKOV	{"phone": "+70673645145"}
0005435287017	C3E577	5371 790354	NADEZHDA MATVEEVA	{"phone": "+70593610360"}
0005435287018	09A635	7746 140310	VLADISLAV KUZNECOV	{"phone": "+70315593093"}
0005435287019	09A635	3660 614709	VALENTINA FROLOVA	{"phone": "+70476014666"}
0005435287020	D2094A	4893 992602	ALEKSANDR MOROZOV	{"email": "a.morozov-101968@postgrespro.ru", "phone": "+70914624614"}
0005435287021	D2094A	4962 483224	ARTEM NAZAROV	{"email": "a_nazarov20011967@postgrespro.ru", "phone": "+70365074571"}
0005435287022	2034A2	5863 868208	EVGENIY ZHURAVLEV	{"phone": "+70374465272"}
0005435287023	379A96	3608 005586	ANNA RYABOVA	{"phone": "+70389815485"}
0005435287024	A290BF	8197 824389	VYACHESLAV MAKAROV	{"email": "vyacheslav-makarov-1965@postgrespro.ru", "phone": "+70975266006"}
0005435287025	84CE46	3852 542206	KAMIL ILIN	{"email": "ilink_111972@postgrespro.ru", "phone": "+70219930028"}
0005435287026	D3867E	4410 983919	NADEZHDA POPOVA	{"phone": "+70164259484"}
0005435287027	D3867E	9152 157720	OLGA FILIPPOVA	{"phone": "+70383002605"}
0005435287028	D3867E	8444 303245	GALINA POPOVA	{"phone": "+70810620334"}
0005435287029	0496E7	8886 823455	TAISIYA DMITRIEVA	{"phone": "+70382499998"}
0005435287030	0496E7	5426 989523	ILYA VOROBEV	{"phone": "+70075699871"}
0005435287031	E97F13	9162 862016	KSENIYA PAVLOVA	{"email": "pavlova_kseniya1966@postgrespro.ru", "phone": "+70019973321"}
0005435287032	D8E78D	8271 825602	NIKOLAY NAZAROV	{"email": "nikolay-nazarov.22101977@postgrespro.ru", "phone": "+70218064662"}
0005435287033	C4662C	2745 953634	ALEKSANDR ANTONOV	{"phone": "+70658891406"}
0005435287034	C4662C	7161 985626	NIKOLAY MOISEEV	{"email": "nmoiseev_051980@postgrespro.ru", "phone": "+70536175399"}
0005435287035	2BDF43	7724 626902	NADEZHDA KONOVALOVA	{"phone": "+70975613771"}
0005435287036	E3F338	5033 998008	NINA ZHURAVLEVA	{"email": "zhuravleva_nina-081969@postgrespro.ru", "phone": "+70083744793"}
0005435287037	E3F338	3931 709094	OLESYA MATVEEVA	{"email": "matveeva-o.10041969@postgrespro.ru", "phone": "+70216676205"}
0005435287038	DD9205	5619 324120	DMITRIY FOMIN	{"email": "fomin.dmitriy1982@postgrespro.ru", "phone": "+70827180632"}
0005435287039	DD9205	4539 637383	BORIS KOZLOV	{"phone": "+70243159017"}
0005435287040	FDC275	6788 599579	ARTEM KUZNECOV	{"phone": "+70014419207"}
0005435287041	FA4B5A	2167 764933	VIKTOR KUDRYASHOV	{"email": "vkudryashov031972@postgrespro.ru", "phone": "+70627552586"}
0005435287042	7A1CCE	9291 940615	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_1981@postgrespro.ru", "phone": "+70986720117"}
0005435287043	ED6882	4924 136677	MIKHAIL ANDREEV	{"email": "mikhail_andreev28101968@postgrespro.ru", "phone": "+70910693648"}
0005435287044	ED6882	9906 907696	VIKTOR MOISEEV	{"phone": "+70224517632"}
0005435287045	B33295	3448 234126	ALLA PETROVA	{"email": "petrova_alla.1976@postgrespro.ru", "phone": "+70490099698"}
0005435287046	B33295	3218 521903	NATALYA ALEKSANDROVA	{"email": "aleksandrova_natalya-021965@postgrespro.ru", "phone": "+70976217845"}
0005435287047	B33295	0785 085501	ALEKSEY KARPOV	{"email": "alekseykarpov091971@postgrespro.ru", "phone": "+70741811694"}
0005435287048	F1ABA1	5092 321629	RUSLAN SEMENOV	{"email": "semenov-ruslan29051973@postgrespro.ru", "phone": "+70724864490"}
0005435287049	F1ABA1	3324 163154	ALEKSANDR ZAKHAROV	{"phone": "+70029772619"}
0005435287050	693B8F	4850 005471	LYUDMILA ANDREEVA	{"email": "andreeva_l.27101974@postgrespro.ru", "phone": "+70513261771"}
0005435287051	D5BA9A	5994 512443	VLADIMIR ROMANOV	{"email": "vromanov_04031973@postgrespro.ru", "phone": "+70535841139"}
0005435287052	8E6A5D	0192 206838	FARID KUZMIN	{"phone": "+70725326640"}
0005435287053	3D05AA	5328 635046	OLGA MELNIKOVA	{"phone": "+70068561545"}
0005435287054	D617C8	2473 105544	SVETLANA NIKITINA	{"email": "svetlana_nikitina-02091982@postgrespro.ru", "phone": "+70104729820"}
0005435287055	559374	8340 496361	VLADIMIR IVANOV	{"phone": "+70931917377"}
0005435287056	559374	8506 748377	VYACHESLAV SHEVCHENKO	{"email": "v.shevchenko-05121977@postgrespro.ru", "phone": "+70064893255"}
0005435287057	EEF085	2580 657763	POLINA KOVALEVA	{"email": "kovaleva.polina_111966@postgrespro.ru", "phone": "+70734071509"}
0005435287058	20D25E	5513 109795	LYUDMILA ARKHIPOVA	{"phone": "+70256196484"}
0005435293045	46B547	5839 614481	VIKTOR FEDOTOV	{"phone": "+70843616882"}
0005435293046	7C50B2	3693 625857	ALEKSEY VOLKOV	{"phone": "+70116156423"}
0005435293047	7C50B2	3764 816442	MARGARITA SOKOLOVA	{"email": "margarita-sokolova1969@postgrespro.ru", "phone": "+70458197801"}
0005435293048	9E77BD	6650 521880	GALINA ABRAMOVA	{"email": "g-abramova071979@postgrespro.ru", "phone": "+70650957083"}
0005435293049	B9B8BD	0634 589583	ALEKSANDR VOROBEV	{"phone": "+70213791667"}
0005435293050	411BEC	0512 829141	GALINA BORISOVA	{"phone": "+70454280259"}
0005435293051	DAC572	6376 398824	ANZHELIKA TROFIMOVA	{"phone": "+70964319799"}
0005435293052	DAC572	3079 743443	LYUDMILA KUZMINA	{"email": "lyudmila_kuzmina.1979@postgrespro.ru", "phone": "+70546310979"}
0005435293053	DAC572	2273 383443	EVGENIY ABRAMOV	{"email": "eabramov_1964@postgrespro.ru", "phone": "+70955472423"}
0005435293054	0D719E	3330 138911	LIDIYA SOROKINA	{"email": "lidiyasorokina-29011970@postgrespro.ru", "phone": "+70096143980"}
0005435293055	0D719E	4975 511379	TAMARA KUZNECOVA	{"phone": "+70282385594"}
0005435293056	0D719E	0523 548402	VALENTINA KOMAROVA	{"email": "vkomarova_1980@postgrespro.ru", "phone": "+70083535358"}
0005435293057	946821	8354 483600	VIKTOR YAKOVLEV	{"email": "yakovlev-viktor.101967@postgrespro.ru", "phone": "+70469015608"}
0005435293058	F7DF6E	0848 479474	OKSANA FROLOVA	{"phone": "+70423280714"}
0005435293059	F7DF6E	1815 877438	FARIT ORLOV	{"phone": "+70296800339"}
0005435293060	304C8D	5953 716903	NADEZHDA EGOROVA	{"email": "egorova.nadezhda.011972@postgrespro.ru", "phone": "+70282318427"}
0005435293061	9CF82F	3189 730027	VERA LAZAREVA	{"phone": "+70210421005"}
0005435293062	AED471	2495 041872	DMITRIY POPOV	{"phone": "+70942074787"}
0005435293063	D3B17C	8145 881680	NIKOLAY MOISEEV	{"phone": "+70405468842"}
0005435293064	464271	4334 072369	PETR DMITRIEV	{"phone": "+70753701513"}
0005435293065	464271	2919 283469	OKSANA FADEEVA	{"email": "o.fadeeva_1957@postgrespro.ru", "phone": "+70031769939"}
0005435293066	5B945C	3936 598568	ANASTASIYA ZHURAVLEVA	{"phone": "+70209737912"}
0005435293067	5B945C	7629 371668	SERGEY ZAYCEV	{"phone": "+70289923010"}
0005435293068	936337	3081 671420	NIKOLAY MOROZOV	{"email": "nmorozov_04051965@postgrespro.ru", "phone": "+70437035423"}
0005435293069	0D30B1	9787 149158	ANATOLIY BONDARENKO	{"email": "abondarenko_16091971@postgrespro.ru", "phone": "+70622021551"}
0005435293070	0D30B1	6807 028148	ALINA IVANOVA	{"phone": "+70725736713"}
0005435293071	980BDE	2342 945972	VARVARA ALEKSEEVA	{"phone": "+70741727228"}
0005435293072	980BDE	8210 426645	VERA ORLOVA	{"email": "orlovav.1970@postgrespro.ru", "phone": "+70111474794"}
0005435293073	ABC433	4211 436447	ALEKSEY MIRONOV	{"email": "mironov.a.11061980@postgrespro.ru", "phone": "+70820562036"}
0005435293074	117304	4143 655244	NINA IVANOVA	{"email": "ivanova-n_25121967@postgrespro.ru", "phone": "+70492987367"}
0005435293075	117304	7229 880709	LYUBOV STEPANOVA	{"email": "lyubov.stepanova-1987@postgrespro.ru", "phone": "+70451831634"}
0005435293076	117304	2267 489951	SVETLANA POPOVA	{"phone": "+70071906841"}
0005435293077	205923	1627 915872	ALEKSANDRA LEBEDEVA	{"phone": "+70818175199"}
0005435293078	37C9C0	7307 269098	LYUDMILA SCHERBAKOVA	{"email": "lyudmila-scherbakova_01111970@postgrespro.ru", "phone": "+70970755181"}
0005435293079	FF3253	9123 723234	TATYANA SOKOLOVA	{"email": "tatyana-sokolova_041974@postgrespro.ru", "phone": "+70344299002"}
0005435293080	FF3253	7437 820903	ILDAR BORISOV	{"email": "borisovi.28011970@postgrespro.ru", "phone": "+70090236855"}
0005435293081	12DFE5	9854 441246	ALEKSEY NOVIKOV	{"email": "novikova_10011979@postgrespro.ru", "phone": "+70520547735"}
0005435293082	43C001	2963 140158	VALERIY ZAYCEV	{"phone": "+70234665603"}
0005435293083	ED8909	1192 496596	RAFAEL SCHERBAKOV	{"phone": "+70515601063"}
0005435293084	ED8909	6111 151398	ANASTASIYA IVANOVA	{"email": "ivanova.a.29051966@postgrespro.ru", "phone": "+70233830743"}
0005435293085	99EF52	8179 116850	MAKSIM OSIPOV	{"phone": "+70117107386"}
0005435293086	859CA1	4773 018679	EVGENIYA ALEKSEEVA	{"email": "alekseeva_e-071967@postgrespro.ru", "phone": "+70885152445"}
0005435293087	B1F7FE	7112 771854	NIKITA MIKHAYLOV	{"email": "mikhaylovn111969@postgrespro.ru", "phone": "+70066058036"}
0005435293088	B1F7FE	5005 498348	NINA DAVYDOVA	{"phone": "+70519355438"}
0005435293089	F9D81C	6783 729930	VERA IVANOVA	{"email": "ivanova_v121975@postgrespro.ru", "phone": "+70016662208"}
0005435293090	0F7EB1	9649 092890	ANNA KISELEVA	{"email": "kiseleva.a-23031980@postgrespro.ru", "phone": "+70093686029"}
0005435293091	0F7EB1	6724 073920	OLGA EFREMOVA	{"email": "efremova-olga061986@postgrespro.ru", "phone": "+70398880868"}
0005435293092	97FA25	8137 466151	DARYA ILINA	{"email": "ilina_d_101965@postgrespro.ru", "phone": "+70503431330"}
0005435293093	2C0DE9	3746 575295	ARTEM TIMOFEEV	{"email": "atimofeev.03121977@postgrespro.ru", "phone": "+70167915380"}
0005435293094	2C0DE9	7161 622970	TATYANA SEMENOVA	{"email": "semenova-tatyana-24081968@postgrespro.ru", "phone": "+70576309030"}
0005435293095	1A7C81	7617 698419	MILANA IVANOVA	{"email": "milana.ivanova.1981@postgrespro.ru", "phone": "+70321988864"}
0005435293096	2E634D	1021 091147	DENIS MELNIKOV	{"email": "dmelnikov_1971@postgrespro.ru", "phone": "+70378394637"}
0005435293097	0A3EBA	6763 267641	SERGEY CHERNOV	{"email": "sergey.chernov.041978@postgrespro.ru", "phone": "+70501918821"}
0005435293098	0A3EBA	2294 693821	ILYA SERGEEV	{"email": "sergeev.ilya-1965@postgrespro.ru", "phone": "+70453356012"}
0005435293099	D797E2	1171 338235	ANTONINA SAVELEVA	{"phone": "+70195082342"}
0005435293100	DE0FB4	8928 432948	GALINA SOKOLOVA	{"phone": "+70383054730"}
0005435293101	DE0FB4	4489 258890	SERGEY ORLOV	{"email": "orlovs.1966@postgrespro.ru", "phone": "+70037464923"}
0005435293102	39C8E8	2675 685819	VALERIY KUDRYASHOV	{"email": "kudryashov-valeriy_071966@postgrespro.ru", "phone": "+70525367601"}
0005435293103	7F85CC	0378 080924	GALINA VOLKOVA	{"phone": "+70980658275"}
0005435293104	01C9B6	8883 639102	DMITRIY SOROKIN	{"email": "dsorokin29061967@postgrespro.ru", "phone": "+70635313355"}
0005435293105	6EA4A0	7945 162142	IGOR SCHERBAKOV	{"phone": "+70918470868"}
0005435293106	AE291A	5220 925807	DMITRIY GRIGOREV	{"email": "d-grigorev.1985@postgrespro.ru", "phone": "+70234164438"}
0005435293107	AE291A	4966 999275	SERGEY ISAEV	{"email": "s-isaev_021963@postgrespro.ru", "phone": "+70944039675"}
0005435293108	2D4A66	5009 416040	SERGEY ROMANOV	{"email": "sergey_romanov_121970@postgrespro.ru", "phone": "+70393912757"}
0005435293109	5E8D97	6410 595157	DMITRIY VOROBEV	{"email": "dmitriy_vorobev_021972@postgrespro.ru", "phone": "+70095421038"}
0005435293110	5E8D97	3472 160234	IRINA KUZNECOVA	{"phone": "+70650769293"}
0005435293111	018288	8385 966665	MARGARITA OSIPOVA	{"phone": "+70037887774"}
0005435293112	563FF4	5992 805781	ALEKSEY BORISOV	{"phone": "+70476811974"}
0005435293113	82BE6D	2669 521071	NADEZHDA MARTYNOVA	{"phone": "+70170891878"}
0005435293114	583292	1849 784784	ANTONINA GUSEVA	{"email": "guseva_a1962@postgrespro.ru", "phone": "+70942590574"}
0005435293115	0E7F55	2859 607362	LYUDMILA VOLKOVA	{"email": "volkova-l_041958@postgrespro.ru", "phone": "+70388962715"}
0005435293116	0E7F55	9830 172650	KIRILL VOLKOV	{"email": "kirill.volkov-05071974@postgrespro.ru", "phone": "+70980802025"}
0005435293117	5D03C5	8976 281051	LYUDMILA TROFIMOVA	{"email": "l_trofimova_111973@postgrespro.ru", "phone": "+70999507865"}
0005435293118	472FEB	5182 710244	LARISA MAKSIMOVA	{"email": "larisa-maksimova-1962@postgrespro.ru", "phone": "+70722206987"}
0005435293119	A5012E	9234 768674	DMITRIY IVANOV	{"email": "d_ivanov.101978@postgrespro.ru", "phone": "+70875965475"}
0005435293120	D63A3B	9162 892020	KIRILL KUZMIN	{"phone": "+70378651401"}
0005435293121	D02998	7954 782839	NADEZHDA VOROBEVA	{"email": "n-vorobeva1969@postgrespro.ru", "phone": "+70918315098"}
0005435293122	D02998	4566 982543	LYUDMILA IVANOVA	{"phone": "+70046766524"}
0005435293123	D716C0	5235 749582	YAROSLAV GAVRILOV	{"email": "yaroslav-gavrilov.041980@postgrespro.ru", "phone": "+70253780638"}
0005435293124	D716C0	5686 330038	ANNA ERMAKOVA	{"phone": "+70339370777"}
0005435293125	BFB8B6	2111 002215	ALEKSANDR TARASOV	{"email": "a.tarasov28011970@postgrespro.ru", "phone": "+70097444313"}
0005435293126	4B0780	6737 004704	NINA ZOTOVA	{"email": "zotova_n_071970@postgrespro.ru", "phone": "+70674113539"}
0005435293127	4B0780	4579 334555	DENIS VOLKOV	{"phone": "+70123501434"}
0005435293128	3F008E	2397 572502	SVETLANA GRISHINA	{"phone": "+70236701750"}
0005435293129	43B31B	0433 312655	RASHIT GAVRILOV	{"email": "gavrilov-r-051972@postgrespro.ru", "phone": "+70959376007"}
0005435293130	63568F	1724 012495	SERGEY IVANOV	{"phone": "+70956718151"}
0005435293131	67890E	0658 760164	LYUDMILA NIKOLAEVA	{"email": "lyudmila.nikolaeva25081974@postgrespro.ru", "phone": "+70209185046"}
0005435293132	2D1274	2812 875988	NADEZHDA MIKHAYLOVA	{"email": "mikhaylovanadezhda_1975@postgrespro.ru", "phone": "+70277752067"}
0005435293133	2D1274	2493 974208	SVETLANA ABRAMOVA	{"phone": "+70909077061"}
0005435293134	02E35C	7877 423779	SOFIYA SERGEEVA	{"email": "sergeeva_s_1960@postgrespro.ru", "phone": "+70408522891"}
0005435293135	2FCB5A	1464 337239	ELENA GUSEVA	{"phone": "+70245329960"}
0005435293136	2E2BF4	5117 190981	VALENTINA DANILOVA	{"email": "valentina-danilova_1974@postgrespro.ru", "phone": "+70819129925"}
0005435293137	2E2BF4	6844 457417	TAMARA KOZLOVA	{"email": "kozlova_t1976@postgrespro.ru", "phone": "+70066920398"}
0005435293138	CFDB5F	4187 194639	SVETLANA SCHERBAKOVA	{"phone": "+70606948482"}
0005435293139	CFDB5F	2150 580226	VLADIMIR KUZNECOV	{"email": "v.kuznecov021962@postgrespro.ru", "phone": "+70788596529"}
0005435293140	DF5185	5988 642244	EVGENIY PETROV	{"phone": "+70389435598"}
0005435293141	DF5185	1898 878371	SERGEY DENISOV	{"email": "sergeydenisov-091967@postgrespro.ru", "phone": "+70954411577"}
0005435293142	93AAC6	8985 647304	RAFIK MAKSIMOV	{"email": "rafik.maksimov.1972@postgrespro.ru", "phone": "+70009668318"}
0005435293143	47B21F	4814 356964	VERONIKA NIKITINA	{"email": "nikitina.veronika1963@postgrespro.ru", "phone": "+70371731409"}
0005435293144	F129C9	5860 690616	MARIYA NOVIKOVA	{"email": "novikovamariya.18011970@postgrespro.ru", "phone": "+70796135207"}
0005435293145	D6B791	8014 494566	NADEZHDA FEDOROVA	{"email": "fedorova.nadezhda081982@postgrespro.ru", "phone": "+70018194284"}
0005435293146	D6B791	7143 548967	ULYANA EGOROVA	{"phone": "+70433992986"}
0005435293147	2206D7	6077 880196	VALERIY SERGEEV	{"email": "sergeev-v011967@postgrespro.ru", "phone": "+70983527054"}
0005435293148	449752	8873 322212	KONSTANTIN ZAKHAROV	{"phone": "+70496124169"}
0005435293149	449752	1550 397636	VITALIY BARANOV	{"phone": "+70588106623"}
0005435293150	285A9D	1089 225946	IGOR KONOVALOV	{"phone": "+70880847821"}
0005435293151	97BD41	9127 199050	TATYANA GERASIMOVA	{"email": "t.gerasimova_28051971@postgrespro.ru", "phone": "+70314686040"}
0005435293152	C4A076	1102 197165	ALEKSEY KOZLOV	{"phone": "+70932600671"}
0005435293153	849757	6912 834306	NATALYA KUZMINA	{"email": "kuzmina_n-06081973@postgrespro.ru", "phone": "+70532676820"}
0005435293154	7BDB92	7665 985087	TATYANA ROMANOVA	{"email": "romanova.t_071961@postgrespro.ru", "phone": "+70435150880"}
0005435293155	187BA8	9177 835062	EVELINA MIKHAYLOVA	{"email": "mikhaylovaevelina1955@postgrespro.ru", "phone": "+70145536190"}
0005435293156	641271	0391 185125	EGOR ZAYCEV	{"email": "e-zaycev_111973@postgrespro.ru", "phone": "+70415562471"}
0005435293157	6914B0	9847 829132	FATIMA KRASNOVA	{"phone": "+70911453801"}
0005435293158	CD49AB	1415 644892	VIKTOR NIKITIN	{"phone": "+70923542607"}
0005435293159	CD49AB	9873 037019	SVETLANA RODIONOVA	{"email": "rodionova_s_1981@postgrespro.ru", "phone": "+70579779879"}
0005435293160	FA4303	7181 718247	ANDREY DMITRIEV	{"email": "andrey-dmitriev-09061968@postgrespro.ru", "phone": "+70749454452"}
0005435293161	FA4303	8099 583707	LIDIYA EGOROVA	{"email": "l_egorova.081976@postgrespro.ru", "phone": "+70598956213"}
0005435293162	9FE362	8187 297645	ELENA VASILEVA	{"email": "elena.vasileva-1966@postgrespro.ru", "phone": "+70576703041"}
0005435293163	446DFB	5800 848250	IRINA NIKITINA	{"email": "irina.nikitina-18011980@postgrespro.ru", "phone": "+70032561972"}
0005435293164	83A256	8235 108487	GALINA TIMOFEEVA	{"phone": "+70282056238"}
0005435293165	83A256	8238 406562	OKSANA FILIPPOVA	{"phone": "+70205521176"}
0005435293166	89D68D	6968 121585	TAISIYA ORLOVA	{"email": "orlova.taisiya.28051975@postgrespro.ru", "phone": "+70306010367"}
0005435293167	5C7B6D	0078 015937	OLGA NOVIKOVA	{"phone": "+70890765066"}
0005435293168	F8832F	0675 548745	PAVEL FEDOROV	{"email": "fedorovpavel.041977@postgrespro.ru", "phone": "+70087993814"}
0005435293169	F8832F	6188 116330	NAIL RODIONOV	{"phone": "+70720789311"}
0005435293170	8C4D56	9335 834298	AMINA VASILEVA	{"email": "amina_vasileva-1978@postgrespro.ru", "phone": "+70288120857"}
0005435293171	2A93A9	9407 048826	YULIYA AFANASEVA	{"phone": "+70934561530"}
0005435293172	2A93A9	3308 960607	NADEZHDA FADEEVA	{"phone": "+70751633545"}
0005435293173	CE2921	7715 876541	VADIM ALEKSANDROV	{"phone": "+70684246510"}
0005435293174	7D8A4E	0490 261236	NIKOLAY MIKHAYLOV	{"email": "mikhaylovn04101985@postgrespro.ru", "phone": "+70325814925"}
0005435293175	1B0EC0	8302 217844	MARGARITA ZAYCEVA	{"email": "mzayceva_26111970@postgrespro.ru", "phone": "+70223057143"}
0005435293176	35F5DE	3538 639920	DMITRIY SEMENOV	{"email": "semenov-d_07071967@postgrespro.ru", "phone": "+70599561906"}
0005435293177	744094	0574 303312	ANTON VASILEV	{"email": "a_vasilev-26121963@postgrespro.ru", "phone": "+70869939805"}
0005435293178	060FC5	8204 062847	YULIYA ZAKHAROVA	{"phone": "+70976106284"}
0005435293179	D13831	7625 282400	ALEKSANDR NIKITIN	{"phone": "+70445091827"}
0005435293180	512844	0487 645039	NIKOLAY KRASNOV	{"phone": "+70842480953"}
0005435293181	512844	1640 362489	TAMARA ANISIMOVA	{"phone": "+70080976282"}
0005435293182	B67FAA	9205 425971	VLADIMIR FROLOV	{"phone": "+70045445201"}
0005435293183	B67FAA	5944 168645	ANDREY KUZNECOV	{"email": "andreykuznecov_091965@postgrespro.ru", "phone": "+70216122520"}
0005435293184	B67FAA	7955 117417	VLADIMIR NIKITIN	{"phone": "+70579799513"}
0005435293185	6CD8D1	6986 569726	LYUBOV SOROKINA	{"email": "sorokinalyubov.04091964@postgrespro.ru", "phone": "+70606146392"}
0005435293186	4A8839	3084 429155	ALEKSEY KARPOV	{"email": "karpov.aleksey-1974@postgrespro.ru", "phone": "+70443590903"}
0005435293187	4A8839	2302 161452	DANIIL ROMANOV	{"phone": "+70382848201"}
0005435293188	3F3FB3	1132 355762	YULIYA STEPANOVA	{"email": "stepanova_y-23121981@postgrespro.ru", "phone": "+70994627186"}
0005435293189	3F3FB3	8462 561001	VIKTOR IVANOV	{"email": "v.ivanov-021965@postgrespro.ru", "phone": "+70740137258"}
0005435293190	24BF19	9862 995552	VALENTINA NAZAROVA	{"email": "nazarova.valentina-021969@postgrespro.ru", "phone": "+70887473591"}
0005435293191	07A899	3565 567482	SERGEY TIKHONOV	{"email": "s_tikhonov.1964@postgrespro.ru", "phone": "+70725566460"}
0005435293192	0E2C78	8606 296057	VALERIY ZHUKOV	{"email": "zhukov_valeriy_02101989@postgrespro.ru", "phone": "+70302602447"}
0005435293193	57CA46	4882 923341	VIKTORIYA KOMAROVA	{"email": "komarova-v081962@postgrespro.ru", "phone": "+70923222729"}
0005435293194	3DDB4E	6706 023790	ROMAN MOROZOV	{"email": "morozovroman1966@postgrespro.ru", "phone": "+70974401507"}
0005435293195	F2C574	2647 980506	OLESYA KUZNECOVA	{"phone": "+70490399528"}
0005435293196	F2C574	9301 580064	ILYA BARANOV	{"phone": "+70901173700"}
0005435293197	453A6D	0886 089742	VYACHESLAV ROMANOV	{"email": "romanovvyacheslav-051973@postgrespro.ru", "phone": "+70975569676"}
0005435293198	EE6C04	2196 499621	ANDREY MAKAROV	{"phone": "+70952388981"}
0005435293199	3A1007	5358 593126	VITALIY IVANOV	{"phone": "+70858707910"}
0005435293200	3A1007	5096 456028	VALERIY ZHUKOV	{"phone": "+70507670144"}
0005435293201	3A1007	9088 357035	VASILIY OSIPOV	{"email": "osipovvasiliy1978@postgrespro.ru", "phone": "+70924861915"}
0005435293202	9C2856	1443 578412	ARINA KUZNECOVA	{"phone": "+70918083126"}
0005435293203	C03741	9864 737793	VLADIMIR ALEKSEEV	{"email": "alekseev.vladimir_17031963@postgrespro.ru", "phone": "+70051654872"}
0005435293204	A38F70	7541 035034	ALEKSEY POPOV	{"email": "popova.111978@postgrespro.ru", "phone": "+70686255784"}
0005435293205	A38F70	1073 385700	ALINA MAKSIMOVA	{"phone": "+70465302931"}
0005435293206	0158AF	7724 148962	VALERIY ANDREEV	{"email": "andreev-valeriy06011977@postgrespro.ru", "phone": "+70451263454"}
0005435293207	0158AF	1559 159465	GALINA KONDRATEVA	{"phone": "+70716780314"}
0005435293208	174F23	4470 449878	VIKTOR DMITRIEV	{"email": "dmitriev.v-041968@postgrespro.ru", "phone": "+70629747094"}
0005435293209	155937	8177 066038	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov_1969@postgrespro.ru", "phone": "+70057425469"}
0005435293210	F26F64	8732 469625	ALEKSANDR FOMIN	{"email": "a_fomin-1967@postgrespro.ru", "phone": "+70762967114"}
0005435293211	F26F64	1512 522024	NINA OSIPOVA	{"phone": "+70316661652"}
0005435293212	E4FBA6	4032 300482	EVGENIY ISAEV	{"phone": "+70580550109"}
0005435293213	699723	0623 624680	NINA BELOVA	{"phone": "+70612835561"}
0005435293214	E58857	1425 015135	NELLI OSIPOVA	{"phone": "+70863455393"}
0005435293215	E58857	9548 564544	IGOR POPOV	{"phone": "+70169048049"}
0005435293216	3CC087	5964 825410	VLADIMIR IVANOV	{"phone": "+70908672968"}
0005435293217	3CC087	0983 767059	LEONID BARANOV	{"email": "leonidbaranov.1981@postgrespro.ru", "phone": "+70892343975"}
0005435293218	610CD9	6852 263029	VIKTORIYA ABRAMOVA	{"phone": "+70644828668"}
0005435293219	610CD9	2140 232424	DARYA IVANOVA	{"phone": "+70678687816"}
0005435293220	610CD9	2300 575368	ALEKSANDR MAKAROV	{"phone": "+70650804804"}
0005435293221	610CD9	9621 070999	ELENA BORISOVA	{"phone": "+70785663072"}
0005435293222	157007	1370 306077	KLAVDIYA PETROVA	{"email": "petrova-klavdiya1977@postgrespro.ru", "phone": "+70343401098"}
0005435293223	E7272E	4585 947601	VADIM DMITRIEV	{"email": "vadimdmitriev-1973@postgrespro.ru", "phone": "+70646778717"}
0005435293224	009624	7174 069525	OLGA KONOVALOVA	{"phone": "+70931707359"}
0005435293498	2F7DB4	9251 746440	DENIS SAVELEV	{"phone": "+70121863664"}
0005435293225	009624	3308 016513	ANATOLIY SOROKIN	{"email": "anatoliy_sorokin_1967@postgrespro.ru", "phone": "+70452837948"}
0005435293226	03828A	7180 171844	NATALYA DMITRIEVA	{"email": "n_dmitrieva_1974@postgrespro.ru", "phone": "+70141202629"}
0005435293227	03828A	0802 708213	OLGA SAVELEVA	{"phone": "+70042491807"}
0005435293228	BEFC74	8057 875274	DMITRIY BORISOV	{"email": "borisov.d-18071977@postgrespro.ru", "phone": "+70750831619"}
0005435293229	BEFC74	2166 881488	ALEKSANDRA KUDRYASHOVA	{"phone": "+70175217705"}
0005435293230	358C72	6687 472102	DANIIL MAKAROV	{"email": "makarovd_09061969@postgrespro.ru", "phone": "+70591856377"}
0005435293231	358C72	0446 556763	IRINA KOLESNIKOVA	{"phone": "+70698923215"}
0005435293232	CD433E	4675 653451	MARGARITA IVANOVA	{"email": "ivanova.m.1968@postgrespro.ru", "phone": "+70667773863"}
0005435293233	96C8A7	6011 681406	ALEKSANDR NIKITIN	{"phone": "+70504274648"}
0005435293234	96C8A7	3349 854775	SERGEY KUZNECOV	{"email": "kuznecov.s-17061965@postgrespro.ru", "phone": "+70370546008"}
0005435293235	E8A5A4	2988 443292	VIKTOR NOVIKOV	{"email": "v_novikov.12051972@postgrespro.ru", "phone": "+70846523923"}
0005435293236	B2B8DB	1389 280651	EVDOKIYA FADEEVA	{"email": "fadeeva-evdokiya04081964@postgrespro.ru", "phone": "+70944405402"}
0005435293237	B2B8DB	7759 814667	ALEKSEY ZHURAVLEV	{"phone": "+70515454797"}
0005435293238	F3DB83	4227 595716	LYUDMILA KOROLEVA	{"email": "koroleva.lyudmila-24031972@postgrespro.ru", "phone": "+70515759501"}
0005435293239	C4AC40	6699 010432	OLGA IVANOVA	{"email": "ivanova_olga_031967@postgrespro.ru", "phone": "+70887894707"}
0005435293240	DD7C20	9224 607757	ZINAIDA MARTYNOVA	{"phone": "+70800300023"}
0005435293241	DD7C20	0159 922587	GALINA SEMENOVA	{"email": "galina_semenova-1959@postgrespro.ru", "phone": "+70139380695"}
0005435293242	5E1E0B	5427 645056	ANTON KAZAKOV	{"email": "kazakov.a-021978@postgrespro.ru", "phone": "+70687664372"}
0005435293243	FF7294	8739 094138	RAISA SERGEEVA	{"email": "sergeeva_raisa_1967@postgrespro.ru", "phone": "+70062597012"}
0005435293244	FF7294	5830 885995	YURIY PAVLOV	{"email": "yuriy-pavlov_28051979@postgrespro.ru", "phone": "+70341705941"}
0005435293245	FF7294	7263 595214	OLGA DMITRIEVA	{"phone": "+70729237701"}
0005435293246	3DAB1B	2408 609836	EVGENIYA SMIRNOVA	{"phone": "+70791796986"}
0005435293247	150928	5647 431385	LARISA MELNIKOVA	{"email": "larisa.melnikova-091974@postgrespro.ru", "phone": "+70009267186"}
0005435293248	69E4F4	9463 781338	IVAN POPOV	{"email": "i.popov1966@postgrespro.ru", "phone": "+70649585048"}
0005435293249	CDEE31	5085 505503	ALEKSANDRA ZAYCEVA	{"phone": "+70942622415"}
0005435293250	562DE9	6545 228220	GALINA FEDOROVA	{"email": "g_fedorova_051967@postgrespro.ru", "phone": "+70410509779"}
0005435293251	0A35B9	5128 791852	ELENA GRISHINA	{"email": "e_grishina_1978@postgrespro.ru", "phone": "+70417719978"}
0005435293252	7B5CAD	8221 918702	VIKTORIYA SOROKINA	{"phone": "+70438596354"}
0005435293253	085763	8729 311300	MAKSIM KUZNECOV	{"email": "kuznecovm_12071975@postgrespro.ru", "phone": "+70155820960"}
0005435293254	085763	5375 736075	VASILIY FILIPPOV	{"email": "filippov-v-1966@postgrespro.ru", "phone": "+70146537398"}
0005435293255	085763	2257 185239	IGOR POPOV	{"email": "igor-popov-111974@postgrespro.ru", "phone": "+70181940107"}
0005435293256	5A95B9	3285 503115	ANDREY MIKHAYLOV	{"email": "mikhaylovandrey.021972@postgrespro.ru", "phone": "+70411240489"}
0005435293257	0C9FDE	1215 232684	MARYAM KUZNECOVA	{"email": "kuznecova.m1969@postgrespro.ru", "phone": "+70392458838"}
0005435293258	B7FE53	5546 609631	VIKTOR YAKOVLEV	{"email": "yakovlev_viktor26121970@postgrespro.ru", "phone": "+70289310763"}
0005435293259	B7FE53	7917 443082	ASIYA DENISOVA	{"email": "asiya.denisova_061973@postgrespro.ru", "phone": "+70324165495"}
0005435293260	10575C	5552 957762	IGOR FEDOROV	{"phone": "+70406068201"}
0005435293261	10575C	0571 196524	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev061958@postgrespro.ru", "phone": "+70775254514"}
0005435293262	5622FB	5428 813794	SERGEY SHEVCHENKO	{"phone": "+70204890077"}
0005435293263	5622FB	0933 724905	ANNA MOROZOVA	{"email": "a-morozova_27031987@postgrespro.ru", "phone": "+70969880146"}
0005435293264	7D95A5	8368 731637	NATALYA IVANOVA	{"phone": "+70596727355"}
0005435293265	DDE216	3092 466770	VALERIY KOZLOV	{"email": "kozlov-valeriy_1965@postgrespro.ru", "phone": "+70724039496"}
0005435293266	82B064	7831 086336	VERA CHERNOVA	{"email": "chernova-v-10071976@postgrespro.ru", "phone": "+70668500759"}
0005435293267	82B064	6381 160392	VLADIMIR ALEKSANDROV	{"phone": "+70060658672"}
0005435293268	323E7B	0500 556421	IRINA KUZNECOVA	{"email": "kuznecova.irina_22031966@postgrespro.ru", "phone": "+70914398840"}
0005435293269	33FF5B	0507 641369	ALEKSANDR GUSEV	{"phone": "+70566852546"}
0005435293270	168CAB	6089 736129	MIKHAIL KRASNOV	{"email": "m.krasnov121962@postgrespro.ru", "phone": "+70675359216"}
0005435293271	FDE0F1	3122 094929	GALINA MIRONOVA	{"email": "mironova-g_07091960@postgrespro.ru", "phone": "+70143199545"}
0005435293272	FDE0F1	7450 494753	NIKOLAY KISELEV	{"email": "n-kiselev.29071969@postgrespro.ru", "phone": "+70883281655"}
0005435293273	FDE0F1	2386 645787	ANNA LUKYANOVA	{"email": "lukyanova-anna1970@postgrespro.ru", "phone": "+70338430421"}
0005435293274	BE6D7A	1562 440968	ROZA STEPANOVA	{"phone": "+70377985506"}
0005435293275	BE6D7A	0799 716941	ELENA EFIMOVA	{"phone": "+70709552508"}
0005435293570	05DF27	4289 950343	ELENA IVANOVA	{"phone": "+70365416282"}
0005435293276	67F6E6	3395 849083	NINA ROMANOVA	{"email": "nina_romanova-061974@postgrespro.ru", "phone": "+70763591216"}
0005435293277	67F6E6	2421 912627	ANDREY GORBUNOV	{"email": "gorbunov.a_20091967@postgrespro.ru", "phone": "+70832924413"}
0005435293278	313735	8376 761182	VALERIY VASILEV	{"phone": "+70601132748"}
0005435293555	D5C581	7483 801479	IRINA NIKOLAEVA	{"phone": "+70619343445"}
0005435293279	D94D17	8888 857524	ANNA MIKHAYLOVA	{"email": "a_mikhaylova_08041979@postgrespro.ru", "phone": "+70948210734"}
0005435293280	D07427	5374 907748	VLADIMIR ISAEV	{"email": "vladimir_isaev-23121964@postgrespro.ru", "phone": "+70065625909"}
0005435293281	354E38	5996 627607	ANASTASIYA VOLKOVA	{"phone": "+70733442039"}
0005435293282	354E38	4170 337491	LIDIYA POPOVA	{"email": "popova-lidiya-1982@postgrespro.ru", "phone": "+70789631417"}
0005435293283	AA06FD	3355 878043	LYUBOV FADEEVA	{"email": "fadeeva.l-1982@postgrespro.ru", "phone": "+70786463018"}
0005435293284	D46EB0	9122 126984	ANASTASIYA CHERNOVA	{"phone": "+70428250471"}
0005435293285	D46EB0	1800 400503	DMITRIY ZAKHAROV	{"email": "dzakharov101970@postgrespro.ru", "phone": "+70316747589"}
0005435293286	066B30	6403 170613	ILYA VASILEV	{"email": "ilya_vasilev-15071970@postgrespro.ru", "phone": "+70706890822"}
0005435293287	5A40F5	7359 115125	ELENA ARKHIPOVA	{"email": "earkhipova.1974@postgrespro.ru", "phone": "+70931888422"}
0005435293288	F17CDD	3800 569029	VALENTINA ROMANOVA	{"email": "romanovavalentina1987@postgrespro.ru", "phone": "+70924466165"}
0005435293289	93AB7F	7973 148705	ULYANA ALEKSEEVA	{"phone": "+70419872678"}
0005435293290	93AB7F	3717 932707	SVETLANA MAKAROVA	{"email": "makarova-svetlana_1972@postgrespro.ru", "phone": "+70858875133"}
0005435293291	CFCD8D	0538 477586	ELENA GAVRILOVA	{"email": "gavrilova.elena04091976@postgrespro.ru", "phone": "+70128427555"}
0005435293292	F9EBFF	4459 636918	ELINA MELNIKOVA	{"phone": "+70268859435"}
0005435293293	F9EBFF	7412 381870	OLESYA ZAKHAROVA	{"phone": "+70063249289"}
0005435293294	96D057	5577 857927	YURIY ORLOV	{"phone": "+70813611864"}
0005435293295	C02093	1444 078963	TATYANA TARASOVA	{"email": "ttarasova-051971@postgrespro.ru", "phone": "+70264086546"}
0005435293296	562AE5	8668 573754	VIKTORIYA KRASNOVA	{"phone": "+70647889887"}
0005435293297	562AE5	8895 000405	TATYANA POPOVA	{"phone": "+70493493096"}
0005435293298	D28756	9756 316934	VLADIMIR IVANOV	{"email": "vladimirivanov1971@postgrespro.ru", "phone": "+70444068290"}
0005435293299	D28756	8667 695587	VLADIMIR MAKAROV	{"phone": "+70086267348"}
0005435293300	546D32	0009 659903	VALENTIN IVANOV	{"email": "v_ivanov.27031967@postgrespro.ru", "phone": "+70149819226"}
0005435293301	546D32	6148 909159	SERGEY PETROV	{"email": "petrovsergey_051976@postgrespro.ru", "phone": "+70045532511"}
0005435293302	421F41	9641 764932	EVGENIY IVANOV	{"phone": "+70766993730"}
0005435293303	0E9260	0687 391713	TATYANA TROFIMOVA	{"email": "tatyanatrofimova.031965@postgrespro.ru", "phone": "+70729989114"}
0005435293304	B700E9	6124 822596	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_aleksandr01011969@postgrespro.ru", "phone": "+70846948863"}
0005435293305	103D5F	0236 739042	ANDREY BELOV	{"email": "belov_andrey-24081976@postgrespro.ru", "phone": "+70399356982"}
0005435293306	103D5F	9436 054212	ELENA ISAEVA	{"email": "elena_isaeva_1974@postgrespro.ru", "phone": "+70241432051"}
0005435293307	3BCBB1	4544 004479	ANFISA KUZMINA	{"phone": "+70060379101"}
0005435293308	8FC133	5998 755873	FEDOR FROLOV	{"phone": "+70295392785"}
0005435293309	6D442F	8625 226666	SERGEY SCHERBAKOV	{"email": "scherbakovs.1974@postgrespro.ru", "phone": "+70196062968"}
0005435293310	01B550	9020 355673	MIKHAIL NIKITIN	{"email": "mikhail-nikitin091979@postgrespro.ru", "phone": "+70697688749"}
0005435293311	01B550	4354 328383	NADEZHDA EGOROVA	{"email": "egorova-n-081978@postgrespro.ru", "phone": "+70466381838"}
0005435293312	CB4054	9129 414667	VASILIY SHEVCHENKO	{"email": "shevchenko.vasiliy-23081966@postgrespro.ru", "phone": "+70519619667"}
0005435293313	89E976	0786 374779	NATALYA MAKSIMOVA	{"email": "n-maksimova_1972@postgrespro.ru", "phone": "+70932545222"}
0005435293314	AD7246	2518 208228	ANNA VLASOVA	{"email": "vlasova.a_031962@postgrespro.ru", "phone": "+70290410737"}
0005435293315	2C4E5D	9615 628479	GALINA BORISOVA	{"email": "borisova.g.26091976@postgrespro.ru", "phone": "+70545577575"}
0005435293316	2C4E5D	0728 723684	LIDIYA KALININA	{"phone": "+70476180824"}
0005435293317	932281	7511 020593	ALEKSANDR ZAKHAROV	{"email": "zakharov.aleksandr_111966@postgrespro.ru", "phone": "+70914485461"}
0005435293318	61FD1A	3438 111830	VASILIY VASILEV	{"email": "vasilev-vasiliy.091980@postgrespro.ru", "phone": "+70924373150"}
0005435293319	61FD1A	3657 184479	ALEKSANDR POPOV	{"email": "popov.aleksandr_081976@postgrespro.ru", "phone": "+70439108807"}
0005435293320	425ADA	3179 210677	NINA MAKAROVA	{"email": "makarova.nina-1971@postgrespro.ru", "phone": "+70864014229"}
0005435293321	425ADA	5711 294660	GULIYA SERGEEVA	{"email": "sergeevaguliya-1987@postgrespro.ru", "phone": "+70924381835"}
0005435293322	F850F8	5782 598413	LYUBOV NESTEROVA	{"email": "nesterova.lyubov.1970@postgrespro.ru", "phone": "+70282207366"}
0005435293323	D74373	0357 024813	MARAT MIKHAYLOV	{"phone": "+70459930788"}
0005435293324	D74373	2370 199863	ELENA BELOVA	{"email": "e.belova-19071983@postgrespro.ru", "phone": "+70802512258"}
0005435293325	471AF4	8646 681287	VASILIY ABRAMOV	{"phone": "+70883273636"}
0005435293326	471AF4	6872 687480	EKATERINA GRISHINA	{"phone": "+70671563552"}
0005435293327	7A532B	8621 246445	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov.041970@postgrespro.ru", "phone": "+70167622307"}
0005435293328	C01E7F	6100 228039	VLADIMIR GUSEV	{"phone": "+70772453032"}
0005435293329	C01E7F	9059 348543	LIDIYA KUZNECOVA	{"phone": "+70343282046"}
0005435293330	BE0D08	5146 655727	VIKTORIYA SEMENOVA	{"email": "semenova-v-15021980@postgrespro.ru", "phone": "+70257503724"}
0005435293331	BE0D08	0308 762220	SERGEY KUZNECOV	{"email": "skuznecov-011978@postgrespro.ru", "phone": "+70664270284"}
0005435293332	4CFF30	4450 339432	ALSU KOZLOVA	{"email": "kozlovaa-03011969@postgrespro.ru", "phone": "+70919697610"}
0005435293611	ECA657	2035 775635	ANATOLIY SERGEEV	{"phone": "+70557844250"}
0005435293333	31B7F6	7902 882966	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova23061963@postgrespro.ru", "phone": "+70119936944"}
0005435293334	0FFE25	8508 003221	ALEKSEY STEPANOV	{"phone": "+70927327654"}
0005435293335	D9E52F	7248 659302	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr101964@postgrespro.ru", "phone": "+70524112737"}
0005435293336	D9E52F	4352 564657	EKATERINA SOLOVEVA	{"email": "ekaterina.soloveva_051971@postgrespro.ru", "phone": "+70972602452"}
0005435293337	F5754B	2455 835407	MARIYA ZAYCEVA	{"email": "zaycevamariya-17121961@postgrespro.ru", "phone": "+70443311219"}
0005435293338	8B3EAD	0346 006704	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov02071971@postgrespro.ru", "phone": "+70517378444"}
0005435293339	8B3EAD	3848 079923	ANDREY NOVIKOV	{"email": "anovikov-091979@postgrespro.ru", "phone": "+70078076201"}
0005435293340	9E71EE	5555 337428	ANASTASIYA NIKOLAEVA	{"email": "anikolaeva-091959@postgrespro.ru", "phone": "+70309357678"}
0005435293341	1A1BD9	4914 102383	ZARINA TIKHONOVA	{"email": "z.tikhonova-1983@postgrespro.ru", "phone": "+70273970963"}
0005435293342	1A1BD9	0477 148706	IVAN TIMOFEEV	{"email": "i-timofeev25111973@postgrespro.ru", "phone": "+70843739698"}
0005435293343	8BDF19	6750 335758	VALERIY STEPANOV	{"phone": "+70733808092"}
0005435293344	8BDF19	3369 123487	VLADIMIR POPOV	{"phone": "+70092511708"}
0005435293345	8BDF19	0362 733311	ANNA TIMOFEEVA	{"email": "timofeeva.anna-16061982@postgrespro.ru", "phone": "+70759350790"}
0005435293346	566491	5029 070258	KRISTINA AKIMOVA	{"phone": "+70446744704"}
0005435293347	566491	4592 012209	VLADIMIR GORBUNOV	{"email": "v_gorbunov_08071972@postgrespro.ru", "phone": "+70764562362"}
0005435293348	1E71A1	8178 813883	ANASTASIYA MASLOVA	{"phone": "+70328824292"}
0005435293349	B57FC1	5676 786342	OLESYA EGOROVA	{"phone": "+70497799119"}
0005435293350	8276C4	5008 832513	RAFAIL VASILEV	{"phone": "+70329314479"}
0005435293351	888E11	1995 848444	DMITRIY TARASOV	{"phone": "+70824160559"}
0005435293352	F2BB02	4373 131091	VLADIMIR BORISOV	{"email": "borisovvladimir.1965@postgrespro.ru", "phone": "+70562953437"}
0005435293353	3EE4C3	8193 143740	DMITRIY AFANASEV	{"phone": "+70755667735"}
0005435293354	3EE4C3	6034 444057	LYUDMILA SEMENOVA	{"phone": "+70783035391"}
0005435293355	97D46A	9741 037529	EKATERINA ISAEVA	{"email": "eisaeva-1967@postgrespro.ru", "phone": "+70411732815"}
0005435293356	AA1778	6291 469870	ADELINA ERMAKOVA	{"phone": "+70023151297"}
0005435293357	AA1778	6199 651370	EKATERINA LEBEDEVA	{"phone": "+70338161737"}
0005435293358	D5713C	7080 087647	OLGA ANISIMOVA	{"email": "anisimova_o_16041970@postgrespro.ru", "phone": "+70875993252"}
0005435293359	15D431	7917 225677	MAKSIM DENISOV	{"email": "denisov_m-1973@postgrespro.ru", "phone": "+70048773830"}
0005435293360	C849C1	9494 461832	YULIYA PAVLOVA	{"phone": "+70980880853"}
0005435293361	C849C1	2261 149483	ARKADIY PETROV	{"email": "apetrov.05091971@postgrespro.ru", "phone": "+70708979899"}
0005435293362	96C827	4696 682845	EVGENIYA DAVYDOVA	{"phone": "+70590491231"}
0005435293363	7F85A3	1905 073397	ANNA KUZNECOVA	{"phone": "+70924172083"}
0005435293364	0702F6	5389 196338	VLADIMIR IVANOV	{"email": "ivanov.vladimir28041981@postgrespro.ru", "phone": "+70254746337"}
0005435293365	828210	6067 379998	ALEKSANDR SIDOROV	{"phone": "+70163938833"}
0005435293366	065B87	3919 221041	VALENTINA KONOVALOVA	{"email": "konovalova_v.1978@postgrespro.ru", "phone": "+70690558820"}
0005435293367	065B87	0632 359846	NATALYA STEPANOVA	{"phone": "+70759459382"}
0005435293368	286B4E	2187 587989	TALGAT IVANOV	{"email": "talgativanov.101978@postgrespro.ru", "phone": "+70743991390"}
0005435293369	7D6E17	3328 169080	SERGEY NOVIKOV	{"phone": "+70490584388"}
0005435293370	1F7596	5154 795327	MARIYA MOISEEVA	{"phone": "+70102345324"}
0005435293371	1F7596	0339 043646	ALEKSEY VLASOV	{"email": "a-vlasov_1966@postgrespro.ru", "phone": "+70394298226"}
0005435293372	C336CF	9844 507317	NATALYA MARTYNOVA	{"phone": "+70262885877"}
0005435293373	C336CF	5869 766638	NIKOLAY ALEKSEEV	{"phone": "+70966945359"}
0005435293374	BFB1F7	9920 776852	OLGA ZAKHAROVA	{"phone": "+70449569801"}
0005435293375	31C6F7	4030 132560	MIKHAIL BONDARENKO	{"email": "bondarenko-m081967@postgrespro.ru", "phone": "+70147151682"}
0005435293376	31C6F7	4981 916354	EKATERINA DMITRIEVA	{"phone": "+70633089360"}
0005435293377	A33B80	4792 950374	MARINA KUDRYASHOVA	{"phone": "+70997530363"}
0005435293378	A33B80	8921 510867	ALEKSANDR GRIGOREV	{"phone": "+70142016509"}
0005435293379	8C9CED	7810 396884	VALENTIN MAKAROV	{"phone": "+70236089942"}
0005435293380	0093E2	3531 556358	RAVIL SEMENOV	{"email": "r_semenov1965@postgrespro.ru", "phone": "+70452417461"}
0005435293381	A697E5	2447 988146	VITALIY VLASOV	{"email": "vvlasov-15091969@postgrespro.ru", "phone": "+70121611410"}
0005435293382	EBB24A	3723 304060	NATALYA KOVALEVA	{"email": "kovaleva.n-041980@postgrespro.ru", "phone": "+70952742076"}
0005435293383	EBB24A	0387 076158	ILYA PETROV	{"email": "petrov_ilya1959@postgrespro.ru", "phone": "+70833141981"}
0005435293384	7F3EE0	6265 329630	VLADISLAV KAZAKOV	{"email": "vladislav_kazakov-1956@postgrespro.ru", "phone": "+70951254143"}
0005435293385	B16B75	8774 251502	TATYANA MELNIKOVA	{"phone": "+70218179939"}
0005435293386	B16B75	4087 801532	ANDREY GRIGOREV	{"phone": "+70443859745"}
0005435293387	314C5B	9601 227405	ALEKSANDR PETROV	{"email": "petrovaleksandr_1963@postgrespro.ru", "phone": "+70530471956"}
0005435293388	40E1C3	8044 847406	GALINA KAZAKOVA	{"email": "galina-kazakova-081965@postgrespro.ru", "phone": "+70430754107"}
0005435293389	628302	3785 920388	ALEKSEY CHERNOV	{"email": "aleksey_chernov.1969@postgrespro.ru", "phone": "+70140518319"}
0005435293390	628302	5950 238758	EKATERINA SMIRNOVA	{"email": "smirnova_ekaterina_1971@postgrespro.ru", "phone": "+70363100618"}
0005435293391	2DEFC5	4951 745379	GENNADIY NAZAROV	{"email": "g.nazarov1964@postgrespro.ru", "phone": "+70363606931"}
0005435293392	8A3284	8186 653722	ELIZAVETA TARASOVA	{"email": "etarasova.1977@postgrespro.ru", "phone": "+70055368243"}
0005435293393	B0CFD3	7645 605483	ALEKSANDR OSIPOV	{"phone": "+70113040018"}
0005435293394	2FCC43	3376 720968	TATYANA KOLESNIKOVA	{"email": "kolesnikovat_16041969@postgrespro.ru", "phone": "+70212594159"}
0005435293395	2FCC43	9597 962921	LYUDMILA KONDRATEVA	{"email": "lyudmilakondrateva.30011966@postgrespro.ru", "phone": "+70552215457"}
0005435293396	CF3B97	4674 547436	NADEZHDA MOISEEVA	{"phone": "+70206525406"}
0005435293397	8EAD88	0413 100075	VLADIMIR KARPOV	{"phone": "+70723595328"}
0005435293398	D510A1	6003 122670	YURIY GORBUNOV	{"phone": "+70344048501"}
0005435293399	D510A1	9270 101855	ALEVTINA KONOVALOVA	{"phone": "+70725355464"}
0005435293400	C1EF44	8442 352115	ANASTASIYA MOROZOVA	{"email": "anastasiyamorozova061994@postgrespro.ru", "phone": "+70434622365"}
0005435293401	B2B4F8	7674 071647	NADEZHDA SOKOLOVA	{"email": "nadezhdasokolova.07041969@postgrespro.ru", "phone": "+70992972215"}
0005435293402	C4134F	3062 505279	VYACHESLAV VASILEV	{"phone": "+70667383070"}
0005435293403	433DD1	6561 206672	ANNA DANILOVA	{"email": "danilova_anna-1969@postgrespro.ru", "phone": "+70608937933"}
0005435293404	A28E47	7688 746266	VLADIMIR BELOV	{"email": "vbelov_101980@postgrespro.ru", "phone": "+70244800081"}
0005435293405	A28E47	1882 349541	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay.041980@postgrespro.ru", "phone": "+70138000951"}
0005435293406	D1EA02	4297 062537	MARIYA ILINA	{"email": "mariya-ilina-15121963@postgrespro.ru", "phone": "+70177317065"}
0005435293407	D1EA02	7811 739768	SERGEY YAKOVLEV	{"phone": "+70740709442"}
0005435293408	B10AE2	2757 444601	ZOYA KRASNOVA	{"email": "krasnova_zoya031978@postgrespro.ru", "phone": "+70021172552"}
0005435293409	B10AE2	5755 450769	OLGA ISAEVA	{"email": "isaeva-olga-17111966@postgrespro.ru", "phone": "+70502917094"}
0005435293410	B10AE2	9919 282539	SVETLANA DENISOVA	{"email": "denisova_svetlana_13111981@postgrespro.ru", "phone": "+70589946648"}
0005435293411	775936	4893 862606	ELENA NIKIFOROVA	{"phone": "+70685026469"}
0005435293412	F85E71	7969 123401	GALINA ISAEVA	{"email": "isaevagalina-101979@postgrespro.ru", "phone": "+70659078111"}
0005435293413	F85E71	7690 659726	NIKITA VOROBEV	{"phone": "+70268607001"}
0005435293414	2CDB63	3184 098323	VERA MOISEEVA	{"email": "moiseevavera.101982@postgrespro.ru", "phone": "+70809813560"}
0005435293415	2CDB63	0179 276700	VLADIMIR KARPOV	{"email": "karpov.vladimir1966@postgrespro.ru", "phone": "+70570949366"}
0005435293416	A4793F	1099 076618	ARTEM ZHURAVLEV	{"email": "artem.zhuravlev18111966@postgrespro.ru", "phone": "+70750417794"}
0005435293417	A4793F	2055 886745	MAKSIM ZHUKOV	{"phone": "+70869367214"}
0005435293418	D64707	9974 500599	NIKOLAY ISAEV	{"phone": "+70956222421"}
0005435293419	D64707	1654 067882	PELAGEYA KUZNECOVA	{"email": "kuznecova_p.1983@postgrespro.ru", "phone": "+70009424783"}
0005435293420	45C76E	0147 928117	VITALIY TIKHONOV	{"email": "v.tikhonov_061975@postgrespro.ru", "phone": "+70769856884"}
0005435293421	45C76E	3944 399460	DINA ILINA	{"email": "ilina-dina-1962@postgrespro.ru", "phone": "+70230394491"}
0005435293422	066B3D	3798 942887	NADEZHDA MOROZOVA	{"email": "morozova-nadezhda_111972@postgrespro.ru", "phone": "+70013717049"}
0005435293423	76DF4C	2471 834372	ANDREY VLASOV	{"email": "avlasov_101984@postgrespro.ru", "phone": "+70916891823"}
0005435293424	76DF4C	9102 618686	NATALYA BELOVA	{"email": "belovanatalya.27021978@postgrespro.ru", "phone": "+70238013380"}
0005435293425	C87272	0437 905620	EVGENIY KAZAKOV	{"phone": "+70654520129"}
0005435293426	843B0E	1126 933609	EDUARD KUDRYASHOV	{"phone": "+70437679011"}
0005435293427	8F7BC5	2904 836098	LYUDMILA KOZLOVA	{"email": "l-kozlova_1971@postgrespro.ru", "phone": "+70092827677"}
0005435293428	4B6FDE	5147 801418	NIKOLAY ISAEV	{"phone": "+70133893664"}
0005435293429	4B6FDE	3450 135529	GALINA BOGDANOVA	{"phone": "+70782857359"}
0005435293430	95D70A	1051 319051	GALINA ANTONOVA	{"phone": "+70929288366"}
0005435293431	063860	0974 105104	ANNA ORLOVA	{"phone": "+70640459172"}
0005435293432	255BE7	2533 335227	ANNA POLYAKOVA	{"email": "a.polyakova081973@postgrespro.ru", "phone": "+70488542436"}
0005435293433	946B86	9645 859498	VASILISA SEMENOVA	{"email": "semenova_vasilisa_14101973@postgrespro.ru", "phone": "+70603909382"}
0005435293434	946B86	0579 313936	VLADIMIR GERASIMOV	{"email": "vladimir-gerasimov.1972@postgrespro.ru", "phone": "+70062260548"}
0005435293435	67B947	8025 601735	VLADISLAV ANTONOV	{"email": "antonovv.10051977@postgrespro.ru", "phone": "+70637782319"}
0005435293436	987D6D	8644 780410	KSENIYA ARKHIPOVA	{"email": "arkhipova.kseniya-1976@postgrespro.ru", "phone": "+70752249330"}
0005435293437	D0C58A	1583 642926	PAVEL MAKSIMOV	{"email": "pavel.maksimov16081981@postgrespro.ru", "phone": "+70500151739"}
0005435293438	526EFB	8137 758534	STANISLAV MIKHAYLOV	{"email": "s.mikhaylov_031987@postgrespro.ru", "phone": "+70898494514"}
0005435293439	A8BF54	3743 184322	VIKTOR KAZAKOV	{"email": "kazakovviktor.1973@postgrespro.ru", "phone": "+70020007558"}
0005435293440	85ECFE	8665 671437	TATYANA TITOVA	{"phone": "+70858371142"}
0005435293441	735DA2	8248 340219	ARSENIY NIKOLAEV	{"phone": "+70616737046"}
0005435293442	608DCD	1135 849367	LYUDMILA SIDOROVA	{"email": "lyudmilasidorova_021972@postgrespro.ru", "phone": "+70816406028"}
0005435293443	608DCD	9439 912757	YURIY SEMENOV	{"email": "y_semenov.15071973@postgrespro.ru", "phone": "+70339606853"}
0005435293444	098B10	6844 567298	NATALYA EGOROVA	{"phone": "+70908935163"}
0005435293445	098B10	2100 968158	LYUDMILA SMIRNOVA	{"email": "smirnova_lyudmila.091974@postgrespro.ru", "phone": "+70192953537"}
0005435293446	D7FDD8	7152 113986	ELENA ROMANOVA	{"phone": "+70841619710"}
0005435293447	73C002	7374 802133	VITALIY MIKHAYLOV	{"phone": "+70698817344"}
0005435293448	A16AA7	8822 909942	ALEKSEY IVANOV	{"email": "aivanov_03021968@postgrespro.ru", "phone": "+70368640400"}
0005435293449	463466	6144 851261	VERA SOROKINA	{"email": "vera-sorokina-021972@postgrespro.ru", "phone": "+70018472636"}
0005435293450	5F8A10	4011 018690	MARINA MIRONOVA	{"email": "marina-mironova1981@postgrespro.ru", "phone": "+70982069009"}
0005435293451	5F8A10	2335 712344	ANATOLIY TARASOV	{"email": "anatoliy.tarasov_1967@postgrespro.ru", "phone": "+70630184326"}
0005435293452	5F8A10	0227 094391	SVETLANA NIKOLAEVA	{"email": "nikolaevasvetlana.021978@postgrespro.ru", "phone": "+70696873458"}
0005435293453	F26ED6	2915 749774	ELENA ISAEVA	{"phone": "+70515100021"}
0005435293454	627076	1615 174573	NIKOLAY SMIRNOV	{"phone": "+70972652064"}
0005435293455	01788F	7816 204592	MAKSIM VOLKOV	{"phone": "+70439746652"}
0005435293456	01788F	6045 683262	ALEKSANDR VASILEV	{"email": "vasilev_a_081974@postgrespro.ru", "phone": "+70462152978"}
0005435293457	F9A793	9475 558828	NIKOLAY KUZNECOV	{"email": "nikolay.kuznecov_091979@postgrespro.ru", "phone": "+70593005541"}
0005435293458	F9A793	2431 998309	NIKOLAY FEDOTOV	{"phone": "+70391225045"}
0005435293459	F9A793	6925 862979	ALEKSANDR MOISEEV	{"email": "a-moiseev101974@postgrespro.ru", "phone": "+70916706306"}
0005435293460	6D6DBF	9554 792065	REGINA MELNIKOVA	{"email": "reginamelnikova_1971@postgrespro.ru", "phone": "+70660676620"}
0005435293461	6D6DBF	8140 864967	ALEKSEY KUZNECOV	{"email": "aleksey_kuznecov-1962@postgrespro.ru", "phone": "+70594044340"}
0005435293462	6D6DBF	1501 052895	MAKSIM ALEKSANDROV	{"phone": "+70090302560"}
0005435293463	500D55	1327 332499	VALENTINA AKIMOVA	{"email": "akimova_v-02121976@postgrespro.ru", "phone": "+70404057201"}
0005435293464	500D55	6884 754609	ALEKSANDR ILIN	{"email": "ilin-a_09061977@postgrespro.ru", "phone": "+70675351334"}
0005435293465	3FFE12	6990 632983	NATALYA KISELEVA	{"phone": "+70519218974"}
0005435293466	3FFE12	7278 445170	DANIL SCHERBAKOV	{"phone": "+70913773123"}
0005435293467	6B351D	4553 286555	ANATOLIY SEMENOV	{"email": "anatoliy-semenov.071975@postgrespro.ru", "phone": "+70327528519"}
0005435293468	6B351D	5019 316619	ANTON ALEKSANDROV	{"phone": "+70402404954"}
0005435293469	0F391C	7495 517535	PAVEL SMIRNOV	{"email": "p.smirnov03091963@postgrespro.ru", "phone": "+70737680458"}
0005435293470	174A17	5510 116433	PETR DAVYDOV	{"phone": "+70131594407"}
0005435293471	1A0D8A	0656 523324	VADIM VASILEV	{"phone": "+70856864663"}
0005435293472	DBC77B	9678 746423	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-25091973@postgrespro.ru", "phone": "+70618034165"}
0005435293473	7ABE68	1524 524584	KONSTANTIN FROLOV	{"phone": "+70552074831"}
0005435293474	431252	9633 399674	KSENIYA GRISHINA	{"email": "kseniya.grishina_1986@postgrespro.ru", "phone": "+70437998399"}
0005435293475	3519DC	1226 853324	ANNA SAVELEVA	{"email": "saveleva-anna.07071969@postgrespro.ru", "phone": "+70988225262"}
0005435293476	8C8E47	3803 842185	LYUBOV IVANOVA	{"phone": "+70293184692"}
0005435293477	F7BBD4	7299 190355	KSENIYA ALEKSEEVA	{"email": "alekseeva_kseniya-1975@postgrespro.ru", "phone": "+70339990861"}
0005435293478	C202FB	4911 395402	VLADIMIR SAVELEV	{"phone": "+70077815362"}
0005435293479	363D41	6251 571963	DARYA KISELEVA	{"email": "d.kiseleva.1970@postgrespro.ru", "phone": "+70229076908"}
0005435293480	363D41	5292 944162	ROMAN ZAKHAROV	{"phone": "+70224340699"}
0005435293481	A564B7	6677 300631	ANTONINA KAZAKOVA	{"email": "kazakovaa.1973@postgrespro.ru", "phone": "+70175489605"}
0005435293482	A564B7	1038 129231	DANIIL KUZNECOV	{"email": "kuznecov-d17021969@postgrespro.ru", "phone": "+70297986955"}
0005435293483	ED8D17	2683 947375	ANATOLIY IVANOV	{"email": "ivanov-a_12041970@postgrespro.ru", "phone": "+70140705612"}
0005435293484	1372DC	7914 347463	ANNA IVANOVA	{"email": "ivanovaa-121977@postgrespro.ru", "phone": "+70248123102"}
0005435293485	1372DC	6765 342795	ANASTASIYA FROLOVA	{"phone": "+70236838072"}
0005435293486	B780D8	2798 243314	NATALYA ANDREEVA	{"phone": "+70250997900"}
0005435293487	E4757B	6248 234554	ARKADIY VASILEV	{"email": "vasilev.a1982@postgrespro.ru", "phone": "+70576337443"}
0005435293488	D70ABF	2439 617345	DMITRIY VLASOV	{"phone": "+70259354711"}
0005435293489	D70ABF	4164 993232	NATALIYA VOROBEVA	{"email": "vorobeva.n-021971@postgrespro.ru", "phone": "+70148475414"}
0005435293490	7543FD	3968 490725	MIKHAIL EGOROV	{"email": "egorov_mikhail1969@postgrespro.ru", "phone": "+70352197632"}
0005435293491	77CAA0	8633 835007	ARINA TITOVA	{"email": "a_titova05081965@postgrespro.ru", "phone": "+70412186626"}
0005435293492	25E223	9441 606883	ANASTASIYA FROLOVA	{"email": "afrolova_15091961@postgrespro.ru", "phone": "+70217545771"}
0005435293493	E17A4A	7667 723314	VLADIMIR NOVIKOV	{"phone": "+70851798984"}
0005435293494	E17A4A	9106 686398	ILDAR IVANOV	{"email": "ivanovi-081969@postgrespro.ru", "phone": "+70077995779"}
0005435293495	13E943	6064 422367	NAIL MOROZOV	{"email": "morozov-n1972@postgrespro.ru", "phone": "+70610483876"}
0005435293496	13E943	9357 123114	ANATOLIY VOROBEV	{"email": "anatoliy.vorobev30071980@postgrespro.ru", "phone": "+70486993160"}
0005435293497	13E943	2428 252702	PRASKOVYA ZHURAVLEVA	{"phone": "+70342493750"}
0005435293499	F56D89	0944 793242	MARGARITA KOROLEVA	{"email": "korolevam071976@postgrespro.ru", "phone": "+70007471911"}
0005435293500	1959AF	9741 476243	OKSANA KUZMINA	{"phone": "+70280693482"}
0005435293501	1959AF	6757 534604	ALEKSEY SERGEEV	{"email": "sergeevaleksey-30081970@postgrespro.ru", "phone": "+70170020005"}
0005435293502	D7D2EF	0410 257988	RAMZIYA ALEKSANDROVA	{"email": "aleksandrova.r-1968@postgrespro.ru", "phone": "+70188748356"}
0005435293503	D7D2EF	6271 665759	MARINA NOVIKOVA	{"phone": "+70995018490"}
0005435293504	D7D2EF	2291 911510	MIKHAIL SOROKIN	{"phone": "+70548257471"}
0005435293505	E30C2A	8956 009296	EVGENIY KAZAKOV	{"phone": "+70822890480"}
0005435293506	E30C2A	9887 254683	EVGENIY ILIN	{"email": "ilinevgeniy-031973@postgrespro.ru", "phone": "+70211679198"}
0005435293507	86396B	4311 122279	NINA ALEKSEEVA	{"phone": "+70838294719"}
0005435293508	665030	6007 294670	SERGEY SCHERBAKOV	{"phone": "+70975483704"}
0005435293509	E43CB1	9457 409687	LYUDMILA KOROLEVA	{"email": "koroleva-lyudmila-08091974@postgrespro.ru", "phone": "+70948177248"}
0005435293510	2D4242	1626 458332	OLGA TITOVA	{"phone": "+70812689701"}
0005435293511	2D4242	0081 437215	SERGEY VOLKOV	{"phone": "+70415920904"}
0005435293512	C93C4F	5777 660438	IGOR EGOROV	{"phone": "+70870743511"}
0005435293513	C93C4F	1553 213991	TATYANA MAKAROVA	{"phone": "+70057570259"}
0005435293514	CC58EE	8521 378146	ALEKSANDR KONOVALOV	{"phone": "+70373215722"}
0005435293515	3D1911	5322 273243	ELENA VASILEVA	{"phone": "+70135035689"}
0005435293516	9AB4FA	5716 256209	NINA KOROLEVA	{"phone": "+70046318127"}
0005435293517	5F5862	1380 396879	VALERIYA POLYAKOVA	{"phone": "+70648741259"}
0005435293518	E0DE4B	1329 174385	MIKHAIL ALEKSEEV	{"email": "mikhail.alekseev-1967@postgrespro.ru", "phone": "+70867873430"}
0005435293519	AD77FC	0384 500832	ALEKSANDRA POPOVA	{"email": "popovaaleksandra25081983@postgrespro.ru", "phone": "+70385414243"}
0005435293520	AD77FC	6839 160880	MARINA TARASOVA	{"phone": "+70084639874"}
0005435293521	494358	8123 452358	MIKHAIL YAKOVLEV	{"email": "yakovlev.m.1966@postgrespro.ru", "phone": "+70913669214"}
0005435293522	494358	8489 429488	ZOYA YAKOVLEVA	{"phone": "+70914057964"}
0005435293523	FEA7BE	6493 570418	ANATOLIY ILIN	{"email": "a.ilin_15101951@postgrespro.ru", "phone": "+70927008398"}
0005435293524	8C0F09	5802 406177	NATALYA OSIPOVA	{"phone": "+70880872378"}
0005435293525	292B21	0671 655212	EVGENIY VLASOV	{"email": "evgeniy-vlasov_111974@postgrespro.ru", "phone": "+70958796098"}
0005435293526	03FA7A	4388 940054	SVETLANA FEDOROVA	{"email": "fedorova_s-1982@postgrespro.ru", "phone": "+70468691164"}
0005435293527	290706	3995 192914	ALEKSANDR SIDOROV	{"email": "asidorov_111972@postgrespro.ru", "phone": "+70129411731"}
0005435293528	290706	6220 070944	TATYANA SMIRNOVA	{"email": "smirnova.t-09081961@postgrespro.ru", "phone": "+70633995151"}
0005435293529	06C608	8897 019453	LYUBOV KUZNECOVA	{"email": "kuznecova-l-061985@postgrespro.ru", "phone": "+70614796455"}
0005435293530	06C608	9259 903962	MIKHAIL ZAYCEV	{"phone": "+70280868972"}
0005435293531	807587	7881 985069	VADIM ZAKHAROV	{"email": "zakharovv.051976@postgrespro.ru", "phone": "+70884914900"}
0005435293532	807587	4949 037503	ANDREY OSIPOV	{"phone": "+70118700207"}
0005435293533	807587	9198 671935	ANASTASIYA GORBUNOVA	{"phone": "+70882927164"}
0005435293534	807587	1475 079631	LEONID TIMOFEEV	{"phone": "+70500879947"}
0005435293535	C2A33F	5967 445084	ALEKSEY ANDREEV	{"phone": "+70958391664"}
0005435293536	C2A33F	7982 527973	NADEZHDA TARASOVA	{"email": "tarasova-nadezhda-061961@postgrespro.ru", "phone": "+70603118597"}
0005435293537	A96CAB	4452 411082	SEMEN VOLKOV	{"phone": "+70686023730"}
0005435293538	A96CAB	8065 601046	ANTON DAVYDOV	{"phone": "+70093407377"}
0005435293539	10036D	9221 900398	NATALYA MIRONOVA	{"email": "mironova.natalya-13061987@postgrespro.ru", "phone": "+70431537248"}
0005435293540	10036D	1054 927921	SERGEY KUZNECOV	{"email": "kuznecovsergey081976@postgrespro.ru", "phone": "+70548381302"}
0005435293541	0CB748	7956 372064	IVAN STEPANOV	{"email": "ivan.stepanov-1982@postgrespro.ru", "phone": "+70448436943"}
0005435293542	0CB748	0734 794054	SERGEY GRIGOREV	{"email": "grigorev-s_061971@postgrespro.ru", "phone": "+70684117683"}
0005435293543	C8B946	7043 472923	PETR FILIPPOV	{"email": "pfilippov011959@postgrespro.ru", "phone": "+70729445967"}
0005435293544	552735	8846 597732	DANIIL ORLOV	{"email": "d_orlov.18081970@postgrespro.ru", "phone": "+70251759454"}
0005435293545	086624	3608 518091	TAISIYA KAZAKOVA	{"phone": "+70818144793"}
0005435293546	086624	1515 780751	ILYA NIKOLAEV	{"phone": "+70930657664"}
0005435293547	A96EEA	3084 251985	KLAVDIYA FEDOROVA	{"phone": "+70522517055"}
0005435293548	A96EEA	7208 640027	ALEKSEY GERASIMOV	{"email": "gerasimov_a.24061975@postgrespro.ru", "phone": "+70350561110"}
0005435293549	EB3AC0	0826 981139	ANTONINA KUZNECOVA	{"phone": "+70345593274"}
0005435293550	57499D	5862 329157	LYUBOV LAZAREVA	{"email": "l-lazareva.061967@postgrespro.ru", "phone": "+70796253591"}
0005435293551	70450D	5984 743285	KONSTANTIN PETROV	{"phone": "+70431874051"}
0005435293552	64D7AE	3586 386943	DMITRIY KARPOV	{"phone": "+70049714762"}
0005435293553	CE0846	1888 640538	KONSTANTIN SOROKIN	{"email": "sorokinkonstantin_09091952@postgrespro.ru", "phone": "+70269310599"}
0005435293554	1964C6	6917 492144	OKSANA SOKOLOVA	{"email": "sokolovaoksana_051969@postgrespro.ru", "phone": "+70538011932"}
0005435293556	6EEA90	5958 442647	TATYANA MOROZOVA	{"email": "morozova-t.091974@postgrespro.ru", "phone": "+70316011904"}
0005435293557	4F85D7	4469 038600	EKATERINA VOLKOVA	{"email": "ekaterina-volkova-28011975@postgrespro.ru", "phone": "+70932246953"}
0005435293558	68DE4F	7559 095994	VLADIMIR MEDVEDEV	{"phone": "+70500941727"}
0005435293559	68DE4F	8394 980369	DENIS FOMIN	{"email": "denisfomin1979@postgrespro.ru", "phone": "+70973405945"}
0005435293560	C3DFC7	5366 820794	VLADIMIR FILIPPOV	{"phone": "+70051919051"}
0005435293561	F415E4	3044 899810	MARIYA RYABOVA	{"email": "ryabova-mariya1967@postgrespro.ru", "phone": "+70711118172"}
0005435293562	F415E4	2905 065549	ELENA ANTONOVA	{"email": "antonova-elena_091988@postgrespro.ru", "phone": "+70735358214"}
0005435293563	977C16	2327 096826	PETR BONDARENKO	{"email": "petr.bondarenko021979@postgrespro.ru", "phone": "+70798630509"}
0005435293564	6FAE15	8350 563707	DENIS MAKSIMOV	{"phone": "+70279916550"}
0005435293565	0AB411	0184 694200	SERGEY SOROKIN	{"email": "sorokin_sergey-081974@postgrespro.ru", "phone": "+70955728775"}
0005435293566	2BA655	4444 320046	OLGA EFIMOVA	{"email": "efimova.olga.1972@postgrespro.ru", "phone": "+70547038032"}
0005435293567	ACBA3D	3203 141065	ALEKSEY FROLOV	{"email": "frolov.aleksey1974@postgrespro.ru", "phone": "+70417212388"}
0005435293568	55FC51	5856 596473	KLIM ABRAMOV	{"email": "abramov_klim30081968@postgrespro.ru", "phone": "+70634463648"}
0005435293569	55FC51	9629 186061	GALINA SOLOVEVA	{"email": "soloveva-galina12121968@postgrespro.ru", "phone": "+70860368574"}
0005435293571	05DF27	0040 496925	ANATOLIY MELNIKOV	{"phone": "+70251618073"}
0005435293572	8E3C35	5416 901009	NIKITA NOVIKOV	{"phone": "+70990321220"}
0005435293573	8E3C35	1635 487100	MARINA OSIPOVA	{"email": "m-osipova.11061976@postgrespro.ru", "phone": "+70094683784"}
0005435293574	CBA544	3708 144239	YULIYA EGOROVA	{"phone": "+70244238404"}
0005435293575	CBA544	1545 113573	IGOR PAVLOV	{"phone": "+70637088523"}
0005435293576	610240	3490 387307	VLADIMIR MOROZOV	{"email": "vladimirmorozov.111968@postgrespro.ru", "phone": "+70442116441"}
0005435293577	50040D	4410 479703	GALINA KAZAKOVA	{"phone": "+70899060305"}
0005435293578	50040D	4393 499290	IVAN AFANASEV	{"email": "ivan-afanasev.1972@postgrespro.ru", "phone": "+70980428166"}
0005435293579	0F45EE	5635 255069	ANDREY MAKSIMOV	{"phone": "+70868239401"}
0005435293580	200695	7458 501100	ANASTASIYA FEDOROVA	{"phone": "+70566796856"}
0005435293581	88DDBA	0395 268871	ALEKSANDR NOVIKOV	{"phone": "+70930168171"}
0005435293582	88DDBA	2998 034175	DMITRIY MOISEEV	{"phone": "+70601644112"}
0005435293583	314D6F	4414 335437	DANILA KUZNECOV	{"email": "kuznecovd-111970@postgrespro.ru", "phone": "+70248321829"}
0005435293584	314D6F	7141 330714	IRINA POTAPOVA	{"phone": "+70284298402"}
0005435293585	CFAFEE	8207 002422	NADEZHDA ZAYCEVA	{"email": "n.zayceva_18011974@postgrespro.ru", "phone": "+70173787790"}
0005435293586	0251AD	1909 708626	VIKTOR ALEKSEEV	{"email": "alekseev-v1977@postgrespro.ru", "phone": "+70596060327"}
0005435293587	0251AD	5321 723181	TATYANA TIMOFEEVA	{"email": "timofeeva_tatyana25061966@postgrespro.ru", "phone": "+70901073536"}
0005435293588	56B2F6	8546 312755	ALEKSEY GAVRILOV	{"email": "agavrilov-091976@postgrespro.ru", "phone": "+70123234545"}
0005435293589	56B2F6	7033 976763	MIKHAIL IVANOV	{"email": "ivanovmikhail.111959@postgrespro.ru", "phone": "+70869847766"}
0005435293590	38805B	1110 915777	MIKHAIL EGOROV	{"email": "mikhail_egorov-23111973@postgrespro.ru", "phone": "+70882914500"}
0005435293591	38805B	4705 326499	LYUBOV MAKAROVA	{"phone": "+70437028068"}
0005435293592	7E1F55	6026 054458	OKSANA KUZMINA	{"phone": "+70760373495"}
0005435293593	16FF16	9297 750126	ELENA ANISIMOVA	{"phone": "+70820156867"}
0005435293594	16FF16	1994 763099	TATYANA ANTONOVA	{"phone": "+70294089945"}
0005435293595	53030F	4812 750483	NIKOLAY SERGEEV	{"email": "sergeevn_071982@postgrespro.ru", "phone": "+70602156922"}
0005435293596	07372E	0984 143114	SERGEY ZHURAVLEV	{"email": "sergey_zhuravlev_1991@postgrespro.ru", "phone": "+70642635505"}
0005435293597	24D349	9658 252054	VIKTORIYA SMIRNOVA	{"email": "smirnova-viktoriya-061975@postgrespro.ru", "phone": "+70778116882"}
0005435293598	03EDE4	0842 324183	NATALYA NIKOLAEVA	{"email": "nikolaeva.n_28071978@postgrespro.ru", "phone": "+70224330051"}
0005435293599	03EDE4	6256 927725	TATYANA NIKOLAEVA	{"email": "tatyananikolaeva18051975@postgrespro.ru", "phone": "+70967134933"}
0005435293600	613463	9439 760070	ALEKSEY FEDOROV	{"email": "a-fedorov.031970@postgrespro.ru", "phone": "+70188173706"}
0005435293601	31849F	9513 899289	OLGA KONDRATEVA	{"email": "okondrateva-011984@postgrespro.ru", "phone": "+70934609785"}
0005435293602	EF2DD9	9927 939450	VARVARA NESTEROVA	{"email": "vnesterova_071979@postgrespro.ru", "phone": "+70992414985"}
0005435293603	EF2DD9	0111 834138	NIKOLAY ZHUKOV	{"phone": "+70186019835"}
0005435293604	E316A3	5404 328493	NIKOLAY CHERNOV	{"email": "chernov-n-071976@postgrespro.ru", "phone": "+70150592714"}
0005435293605	96614E	4381 153959	DMITRIY GAVRILOV	{"phone": "+70557115607"}
0005435293606	7F733E	1988 167292	NADEZHDA YUDINA	{"phone": "+70109315024"}
0005435293607	69DA7A	9255 501300	OLGA LEBEDEVA	{"email": "lebedeva_olga.06071967@postgrespro.ru", "phone": "+70036203970"}
0005435293608	69DA7A	1422 381427	EKATERINA SEMENOVA	{"phone": "+70957512251"}
0005435293609	D88B96	8788 857211	YULIYA SERGEEVA	{"email": "yuliya-sergeeva_021973@postgrespro.ru", "phone": "+70609143251"}
0005435293610	32F45A	9752 075919	NADEZHDA AFANASEVA	{"email": "nadezhda-afanaseva-091976@postgrespro.ru", "phone": "+70844719802"}
0005435293612	ECA657	8552 053793	DANIIL KARPOV	{"email": "d-karpov_061976@postgrespro.ru", "phone": "+70020576092"}
0005435293613	E05778	9836 905965	OLEG PAVLOV	{"phone": "+70378253548"}
0005435293614	2FA829	3341 046612	VLADIMIR VOROBEV	{"phone": "+70103823008"}
0005435293615	2FA829	5894 968088	DENIS BONDARENKO	{"email": "denis-bondarenko06091979@postgrespro.ru", "phone": "+70300421740"}
0005435293616	858A45	4093 868706	DINA STEPANOVA	{"phone": "+70630320748"}
0005435293617	417E28	8720 369174	TAMARA ALEKSEEVA	{"email": "tamara.alekseeva_11051975@postgrespro.ru", "phone": "+70248271964"}
0005435293618	7785B5	4993 750295	GALINA BELYAEVA	{"email": "g_belyaeva.09031978@postgrespro.ru", "phone": "+70886453927"}
0005435293619	E6854A	6339 198548	MARIYA BELOVA	{"phone": "+70345349504"}
0005435293620	B71156	1141 596111	NATALIYA ROMANOVA	{"phone": "+70347376412"}
0005435293621	013110	1811 734763	ALEKSEY GRIGOREV	{"email": "grigorev_aleksey-28081974@postgrespro.ru", "phone": "+70779945302"}
0005435293622	DEEACC	1024 776164	ALINA FROLOVA	{"phone": "+70505300227"}
0005435293623	FE7328	1965 773143	ELENA KUZMINA	{"email": "e-kuzmina-15061980@postgrespro.ru", "phone": "+70771065956"}
0005435293624	F6B100	0581 796810	MARINA NAZAROVA	{"email": "nazarova_marina.1958@postgrespro.ru", "phone": "+70748330287"}
0005435293625	F6B100	1582 495335	ALEKSANDR TARASOV	{"phone": "+70681191954"}
0005435293626	02FDEA	0065 028905	TATYANA STEPANOVA	{"email": "tatyana-stepanova10111969@postgrespro.ru", "phone": "+70492154446"}
0005435293627	0BFCB4	2680 474248	NADEZHDA SAVELEVA	{"email": "n-saveleva-1982@postgrespro.ru", "phone": "+70080151355"}
0005435293628	0BFCB4	6089 504033	ZINAIDA ZAYCEVA	{"email": "zayceva-zinaida-1967@postgrespro.ru", "phone": "+70541729881"}
0005435296938	353CCC	0887 216737	ELENA ZAKHAROVA	{"phone": "+70565834667"}
0005435296939	89C081	5780 373001	ZINAIDA POPOVA	{"email": "popova-zinaida-20021977@postgrespro.ru", "phone": "+70314034893"}
0005435296940	89C081	8585 699265	MARIYA MAKAROVA	{"phone": "+70417719364"}
0005435296941	D3EA73	8752 534472	NATALYA DAVYDOVA	{"email": "natalya.davydova_1975@postgrespro.ru", "phone": "+70075232275"}
0005435296942	0CC7E5	1695 492428	MARIYA ILINA	{"email": "ilina_m1972@postgrespro.ru", "phone": "+70339498694"}
0005435296943	90D59C	9335 234425	VITALIY OSIPOV	{"phone": "+70353123079"}
0005435296944	9A373C	5262 994488	ALEKSEY ANTONOV	{"email": "a.antonov.12111969@postgrespro.ru", "phone": "+70924304760"}
0005435296945	82FEDD	6930 849286	OLEG KARPOV	{"phone": "+70811894214"}
0005435296946	F8D1E2	7700 134693	SERGEY EGOROV	{"phone": "+70808636408"}
0005435296947	4B4C11	9561 255424	VLADISLAV GRIGOREV	{"phone": "+70039712208"}
0005435296948	7D30F9	2649 761808	EVGENIY MAKAROV	{"email": "makarov-e.1970@postgrespro.ru", "phone": "+70494202270"}
0005435296949	0F7383	3372 583454	LILIYA KOLESNIKOVA	{"email": "kolesnikova_liliya1977@postgrespro.ru", "phone": "+70358185110"}
0005435296950	0F7383	6080 930464	ANDREY FOMIN	{"phone": "+70660822604"}
0005435296951	3E9FCE	7971 967851	OLGA IVANOVA	{"email": "ivanovao-20121969@postgrespro.ru", "phone": "+70720284426"}
0005435296952	993D85	2005 511528	EVGENIY MIRONOV	{"phone": "+70483967553"}
0005435296953	3B7A60	2169 556031	EKATERINA RODIONOVA	{"email": "ekaterinarodionova_1969@postgrespro.ru", "phone": "+70258153586"}
0005435296954	09A27E	1739 283390	ANASTASIYA ROMANOVA	{"phone": "+70887675387"}
0005435296955	4A21A9	5897 303821	ALLA KISELEVA	{"email": "a_kiseleva.28011981@postgrespro.ru", "phone": "+70749098803"}
0005435296956	4A21A9	6991 356445	RAISA NIKOLAEVA	{"phone": "+70588876478"}
0005435296957	041D8A	7607 857593	TATYANA STEPANOVA	{"phone": "+70484237394"}
0005435296958	AF3279	6958 481324	VERA EFIMOVA	{"email": "efimova-v.041969@postgrespro.ru", "phone": "+70941072039"}
0005435296959	181FE6	7311 295498	VYACHESLAV SMIRNOV	{"phone": "+70930562050"}
0005435296960	6083C8	1325 165990	ANDREY ZAKHAROV	{"email": "andreyzakharov.1979@postgrespro.ru", "phone": "+70080621884"}
0005435296961	CF5421	9590 376647	SVETLANA KONDRATEVA	{"phone": "+70323771896"}
0005435296962	2B331C	3703 492967	BOGDAN KOZLOV	{"email": "kozlovbogdan04011982@postgrespro.ru", "phone": "+70666725611"}
0005435296963	2B331C	4785 043847	OLGA MALYSHEVA	{"email": "malysheva_olga.18091991@postgrespro.ru", "phone": "+70038445461"}
0005435296964	2B331C	4209 263044	LYUDMILA SMIRNOVA	{"email": "smirnova.lyudmila.1975@postgrespro.ru", "phone": "+70892087761"}
0005435296965	677845	5541 598312	NINA KUZMINA	{"phone": "+70114942573"}
0005435296966	677845	2709 752487	NAIL NOVIKOV	{"email": "novikovnail_30011972@postgrespro.ru", "phone": "+70640769101"}
0005435296967	74984D	6092 783792	SERGEY VOLKOV	{"email": "volkov_s_1972@postgrespro.ru", "phone": "+70730521230"}
0005435296968	E46719	0953 428356	MIKHAIL MARTYNOV	{"email": "mmartynov-111976@postgrespro.ru", "phone": "+70150918678"}
0005435296969	E46719	9910 837276	MIROSLAV KUZNECOV	{"phone": "+70227359554"}
0005435296970	441BC7	0094 525204	ANNA ERMAKOVA	{"email": "ermakova.anna-111971@postgrespro.ru", "phone": "+70920590503"}
0005435296971	441BC7	4670 953243	ALEKSANDR TARASOV	{"phone": "+70443310678"}
0005435296972	F61091	1746 011580	ANASTASIYA TITOVA	{"email": "anastasiya-titova031969@postgrespro.ru", "phone": "+70589019730"}
0005435296973	7B18A5	2043 814148	MARIYA KOROLEVA	{"phone": "+70250247808"}
0005435296974	7B18A5	3951 690361	ELVIRA LEBEDEVA	{"phone": "+70624648934"}
0005435296975	5BFB0D	2269 652781	ANDREY GORBUNOV	{"email": "andrey-gorbunov.03061976@postgrespro.ru", "phone": "+70177920752"}
0005435296976	CA1365	7995 792347	YULIYA ZOTOVA	{"phone": "+70937726937"}
0005435296977	056402	2841 022244	ANDREY MIKHAYLOV	{"phone": "+70385721015"}
0005435296978	056402	6757 649968	VIKTORIYA OSIPOVA	{"phone": "+70241093116"}
0005435296979	C6E11C	8381 609582	VASILIY MOISEEV	{"phone": "+70420717248"}
0005435296980	90617E	5234 397893	VADIM KUZNECOV	{"email": "v_kuznecov-22031975@postgrespro.ru", "phone": "+70115175503"}
0005435296981	27133B	7791 754431	ALEKSANDR BORISOV	{"phone": "+70100936988"}
0005435296982	27133B	1715 105896	IRINA KOZLOVA	{"phone": "+70580575315"}
0005435296983	6EA39A	1328 021793	NIKOLAY FEDOROV	{"phone": "+70249879754"}
0005435296984	C01E1E	3009 215047	ALEKSEY GERASIMOV	{"phone": "+70437896322"}
0005435296985	C9D5B6	7606 680377	DANIIL MOROZOV	{"email": "daniilmorozov06041985@postgrespro.ru", "phone": "+70506921091"}
0005435296986	C9D5B6	4038 097934	ILYA IVANOV	{"email": "i-ivanov-101981@postgrespro.ru", "phone": "+70304026914"}
0005435296987	101D45	0703 356076	ANTON ZHURAVLEV	{"email": "anton_zhuravlev-1979@postgrespro.ru", "phone": "+70559652647"}
0005435296988	1D95AE	4149 840268	ANATOLIY KULIKOV	{"phone": "+70138107878"}
0005435296989	1D95AE	8532 573229	ANASTASIYA ROMANOVA	{"email": "a-romanova.1974@postgrespro.ru", "phone": "+70452930009"}
0005435296990	1E8AF7	8141 258612	DENIS PAVLOV	{"email": "denis_pavlov-1970@postgrespro.ru", "phone": "+70526895462"}
0005435296991	1E8AF7	4493 162295	ALINA VASILEVA	{"phone": "+70319856078"}
0005435296992	5E38DE	9704 311850	RUMIYA ILINA	{"phone": "+70628304340"}
0005435296993	094D6D	6525 924583	DMITRIY KULIKOV	{"email": "d-kulikov-041970@postgrespro.ru", "phone": "+70328596823"}
0005435296994	EB1100	9561 162714	LARISA ANTONOVA	{"email": "antonova.larisa-11101978@postgrespro.ru", "phone": "+70798336578"}
0005435296995	CD8024	0851 473334	VALENTIN AFANASEV	{"phone": "+70824309598"}
0005435296996	CD8024	9093 994912	OLGA TARASOVA	{"email": "tarasovaolga.1968@postgrespro.ru", "phone": "+70562534653"}
0005435296997	C8BE3F	7375 335718	SERGEY VLASOV	{"phone": "+70831965691"}
0005435296998	CA94D5	2688 687004	STANISLAV DENISOV	{"email": "stanislav.denisov_23051975@postgrespro.ru", "phone": "+70183959548"}
0005435296999	7F5C13	3558 265032	SVETLANA MIRONOVA	{"phone": "+70124271872"}
0005435297000	A7314E	0137 379775	SERGEY IVANOV	{"email": "ivanov.sergey20051984@postgrespro.ru", "phone": "+70745951183"}
0005435297001	3CC05F	8720 415846	GENNADIY NAZAROV	{"email": "gnazarov_081973@postgrespro.ru", "phone": "+70053403619"}
0005435297002	B93CEA	4139 192618	MARIYA PAVLOVA	{"phone": "+70100403060"}
0005435297003	B93CEA	9979 821318	EKATERINA RODIONOVA	{"email": "ekaterina-rodionova_13011985@postgrespro.ru", "phone": "+70253534450"}
0005435297004	0FB835	6410 513705	VALERIYA KOLESNIKOVA	{"email": "kolesnikovav.1959@postgrespro.ru", "phone": "+70096923306"}
0005435297005	0FB835	4300 300147	TAISIYA OVCHINNIKOVA	{"phone": "+70303426269"}
0005435297006	28419F	3116 213527	EVGENIY SMIRNOV	{"email": "e_smirnov05111971@postgrespro.ru", "phone": "+70692224708"}
0005435297007	EBDE04	7904 309886	ALEKSANDR MIRONOV	{"phone": "+70003350272"}
0005435297008	87347C	6134 494421	ALEKSEY ZHUKOV	{"phone": "+70880974464"}
0005435297009	5BD787	2441 174108	ANDREY OSIPOV	{"email": "osipov_a-1966@postgrespro.ru", "phone": "+70354013555"}
0005435297010	EB3474	0214 086928	ALEKSANDR FILIPPOV	{"email": "filippova.03071969@postgrespro.ru", "phone": "+70974487701"}
0005435297011	EB3474	1227 096423	IVAN KUZNECOV	{"email": "kuznecov-ivan1973@postgrespro.ru", "phone": "+70986759978"}
0005435297012	FACD26	0303 161085	ALEKSEY ROMANOV	{"phone": "+70136885274"}
0005435297013	2301BE	6228 040119	RAISA ERMAKOVA	{"phone": "+70462195560"}
0005435297014	2301BE	6132 075209	SVETLANA POLYAKOVA	{"email": "polyakova_s-11011971@postgrespro.ru", "phone": "+70898951211"}
0005435297015	2301BE	2528 516502	NINA IVANOVA	{"phone": "+70048212124"}
0005435297016	2301BE	7693 189696	ZINAIDA TIMOFEEVA	{"phone": "+70110629937"}
0005435297017	121EFC	8959 953779	LIDIYA FEDOROVA	{"email": "fedorova-l.15091979@postgrespro.ru", "phone": "+70491211655"}
0005435297018	011603	1699 640909	ELENA TROFIMOVA	{"phone": "+70481306741"}
0005435297019	D81EE8	3566 119628	NINA YUDINA	{"phone": "+70485355938"}
0005435297020	3A4A86	4055 554371	ANDREY KUZNECOV	{"email": "kuznecov-andrey.1972@postgrespro.ru", "phone": "+70769189177"}
0005435297021	BDBD52	8178 308722	ARTEM OSIPOV	{"phone": "+70874784394"}
0005435297022	BDBD52	2715 885162	VIKTOR MOROZOV	{"phone": "+70934980324"}
0005435297023	3004A2	4079 895463	ALEKSEY ZHURAVLEV	{"email": "zhuravlev-a_041972@postgrespro.ru", "phone": "+70398092296"}
0005435297024	CFFE94	5365 186777	EKATERINA ERMAKOVA	{"phone": "+70484215974"}
0005435297025	CFFE94	3844 656282	VERA MIKHAYLOVA	{"phone": "+70531103630"}
0005435297026	591C6D	8211 325463	VERONIKA SOLOVEVA	{"phone": "+70922089051"}
0005435297027	39184F	9581 930260	EKATERINA BELOVA	{"email": "e-belova-111965@postgrespro.ru", "phone": "+70399737444"}
0005435297028	39184F	8030 281606	IRINA MOROZOVA	{"email": "i.morozova_081969@postgrespro.ru", "phone": "+70878457464"}
0005435297029	3A8C5C	6422 705149	DANIIL VOLKOV	{"phone": "+70540614852"}
0005435297030	3A8C5C	2437 747695	SERGEY MIKHAYLOV	{"phone": "+70002379116"}
0005435297031	48B435	0977 539872	DMITRIY SHEVCHENKO	{"phone": "+70451413998"}
0005435297032	47576E	3605 247025	VADIM BORISOV	{"phone": "+70877704651"}
0005435297033	47576E	9299 599164	TAMARA NESTEROVA	{"email": "nesterova_tamara111987@postgrespro.ru", "phone": "+70485198760"}
0005435297034	47576E	1794 264874	SERGEY KARPOV	{"phone": "+70452839093"}
0005435297035	77D3CD	5581 805180	RAISA VOROBEVA	{"phone": "+70568799186"}
0005435297036	481524	8842 908353	NIKOLAY PETROV	{"email": "petrov_nikolay08071961@postgrespro.ru", "phone": "+70281511205"}
0005435297037	F2A979	0896 424617	NARIMAN KUZNECOV	{"email": "kuznecovnariman.02061968@postgrespro.ru", "phone": "+70248362718"}
0005435297038	9AF511	5946 849601	VALENTINA MAKSIMOVA	{"email": "maksimova-valentina-051961@postgrespro.ru", "phone": "+70960289139"}
0005435297039	9AF511	6583 263577	VIKTORIYA ZHURAVLEVA	{"phone": "+70232998777"}
0005435297040	9EC3CD	9864 023688	IVAN VOROBEV	{"email": "vorobev-i_1971@postgrespro.ru", "phone": "+70585111666"}
0005435297041	84E600	7214 799605	OKSANA FROLOVA	{"phone": "+70404936171"}
0005435297042	84E600	4702 585052	GALINA ORLOVA	{"phone": "+70772565653"}
0005435297043	1D9CED	8072 003404	SVETLANA MARTYNOVA	{"email": "martynovasvetlana1976@postgrespro.ru", "phone": "+70677148751"}
0005435297044	10A3C9	4894 103749	SVETLANA FILIPPOVA	{"email": "filippova-svetlana.021967@postgrespro.ru", "phone": "+70106421657"}
0005435297045	10A3C9	3823 628133	ANATOLIY BORISOV	{"phone": "+70820799899"}
0005435297046	545E23	9380 243574	IRINA SCHERBAKOVA	{"email": "i_scherbakova.1964@postgrespro.ru", "phone": "+70780494602"}
0005435297047	967225	9525 407908	DMITRIY NOVIKOV	{"phone": "+70742339418"}
0005435297048	11A817	5199 376655	ANDREY MAKAROV	{"phone": "+70126830098"}
0005435297049	8166E8	7308 962925	ALEKSEY PETROV	{"email": "petrov_a_071978@postgrespro.ru", "phone": "+70449721302"}
0005435297050	BB9C90	0163 388237	MARIYA MIKHAYLOVA	{"phone": "+70911165488"}
0005435297051	3767C6	5086 484148	LARISA DENISOVA	{"email": "denisova_larisa.1964@postgrespro.ru", "phone": "+70379569386"}
0005435297052	1A54E6	1866 431641	NATALYA SOROKINA	{"email": "natalya-sorokina.15091966@postgrespro.ru", "phone": "+70790515834"}
0005435297053	1A54E6	7581 448297	ALEKSANDR SIDOROV	{"email": "aleksandr_sidorov20091985@postgrespro.ru", "phone": "+70259979648"}
0005435297054	C2D432	5833 556445	MAKSIM MEDVEDEV	{"phone": "+70585453830"}
0005435297055	8D4273	2575 775680	VALERIY KUDRYASHOV	{"email": "valeriy-kudryashov.1978@postgrespro.ru", "phone": "+70778954659"}
0005435297056	F88C83	1279 019986	LYUDMILA DENISOVA	{"email": "denisova_l.021964@postgrespro.ru", "phone": "+70477252279"}
0005435297057	5228D9	2528 197818	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-26011972@postgrespro.ru", "phone": "+70947436737"}
0005435297058	1F601D	5508 873953	ANASTASIYA EGOROVA	{"phone": "+70748951528"}
0005435297059	1F601D	3156 492236	EKATERINA SAVELEVA	{"email": "saveleva_e-091970@postgrespro.ru", "phone": "+70134275823"}
0005435297060	5F4595	2616 767839	NIKOLAY VASILEV	{"phone": "+70948666504"}
0005435297061	89ABC2	3775 203672	ARINA NESTEROVA	{"phone": "+70048556226"}
0005435297062	89ABC2	5758 706526	DAMIR ZAKHAROV	{"phone": "+70141023505"}
0005435297063	245295	7059 320246	ELENA ZAKHAROVA	{"email": "zakharova_e.10091978@postgrespro.ru", "phone": "+70058597481"}
0005435297064	014144	3922 523134	EKATERINA RYABOVA	{"email": "e-ryabova.111966@postgrespro.ru", "phone": "+70752293602"}
0005435297065	0D3F58	8036 091651	VASILIY KUZNECOV	{"email": "kuznecov.vasiliy_1984@postgrespro.ru", "phone": "+70383318086"}
0005435297066	B3F974	2334 511479	INNA TROFIMOVA	{"email": "trofimova_i-1956@postgrespro.ru", "phone": "+70118328896"}
0005435297067	4E78F7	5413 307229	ALEKSANDR KISELEV	{"email": "aleksandr.kiselev.16051969@postgrespro.ru", "phone": "+70503226546"}
0005435297068	3E34B1	9163 855732	DANIIL BARANOV	{"phone": "+70622245667"}
0005435297069	8BF1D0	1784 563452	VERA SOLOVEVA	{"phone": "+70006829503"}
0005435297070	6C755C	1127 181395	ALEKSANDR DAVYDOV	{"phone": "+70351226590"}
0005435297071	6C755C	5511 445608	OLGA AFANASEVA	{"email": "afanaseva.o31031965@postgrespro.ru", "phone": "+70524691351"}
0005435297072	9DA89D	3920 255775	DANIIL ILIN	{"email": "dilin121968@postgrespro.ru", "phone": "+70314948699"}
0005435297073	B0F7D4	4238 893145	NADEZHDA KUZNECOVA	{"phone": "+70349670661"}
0005435297074	B0F7D4	6996 834305	NADEZHDA KUZNECOVA	{"phone": "+70143636475"}
0005435297075	1CE9B1	0159 936390	IVAN OSIPOV	{"phone": "+70381830063"}
0005435297076	1CE9B1	2969 240779	MARINA DENISOVA	{"phone": "+70067458923"}
0005435297077	ED19D7	9033 999357	ALLA VASILEVA	{"phone": "+70855662832"}
0005435297078	AB5A10	2285 786083	VIKTOR ANTONOV	{"phone": "+70855650692"}
0005435297079	AB5A10	4365 701203	LARISA BORISOVA	{"email": "borisova-larisa10091964@postgrespro.ru", "phone": "+70521078802"}
0005435297080	AB5A10	4093 871324	VALERIY NOVIKOV	{"phone": "+70307978517"}
0005435297081	BF3BCC	0644 577595	VERA EGOROVA	{"phone": "+70875828964"}
0005435297082	BF3BCC	6725 630883	IRINA VASILEVA	{"email": "vasileva-irina_011969@postgrespro.ru", "phone": "+70252752601"}
0005435297083	9C970A	6769 372466	SERGEY FEDOROV	{"phone": "+70794197215"}
0005435297084	9C970A	5780 586830	POLINA POPOVA	{"phone": "+70714220376"}
0005435297085	23B2F1	0882 188431	IRINA SOLOVEVA	{"email": "irina_soloveva_1958@postgrespro.ru", "phone": "+70739164012"}
0005435297086	23B2F1	0203 836601	IVAN FROLOV	{"email": "i.frolov_27011971@postgrespro.ru", "phone": "+70502660267"}
0005435297087	ED0833	9812 726721	NATALYA ARKHIPOVA	{"phone": "+70635465719"}
0005435297088	0BE883	9988 999971	NINA MOROZOVA	{"email": "morozova-n-31081980@postgrespro.ru", "phone": "+70011965785"}
0005435297089	E8A113	5224 437187	VADIM VLASOV	{"phone": "+70036362584"}
0005435297090	98816D	0736 189996	ANDREY EGOROV	{"phone": "+70738979438"}
0005435297091	CFF77A	7148 043964	SERGEY KISELEV	{"email": "skiselev.011965@postgrespro.ru", "phone": "+70164428087"}
0005435297092	993B54	5181 304752	LYUDMILA KUZNECOVA	{"phone": "+70505458254"}
0005435297093	A2DEFE	9999 886031	NATALYA MARTYNOVA	{"email": "n_martynova051967@postgrespro.ru", "phone": "+70673220612"}
0005435297094	4CF430	4426 026559	OLEG ALEKSANDROV	{"email": "oaleksandrov051973@postgrespro.ru", "phone": "+70594310495"}
0005435297095	4CF430	4193 401740	ALEKSANDRA AKIMOVA	{"email": "akimova-aleksandra_071979@postgrespro.ru", "phone": "+70409469836"}
0005435297096	4CF430	3279 046341	ALEKSEY MAKSIMOV	{"email": "maksimov-a081972@postgrespro.ru", "phone": "+70061464225"}
0005435297097	258EB9	7063 426926	SERGEY KRASNOV	{"email": "krasnovs071962@postgrespro.ru", "phone": "+70592921017"}
0005435297098	E1E38E	4074 283207	ANDREY KONOVALOV	{"phone": "+70956385213"}
0005435297099	EB4120	7335 281157	ANASTASIYA EGOROVA	{"email": "egorova.anastasiya1977@postgrespro.ru", "phone": "+70631704710"}
0005435297100	EB4120	0072 002891	TIMOFEY VOLKOV	{"phone": "+70314546446"}
0005435297101	80A84B	1760 009400	ALEKSANDR PETROV	{"phone": "+70967116971"}
0005435297102	402594	6308 152916	VLADIMIR SIDOROV	{"email": "vladimir.sidorov-19031980@postgrespro.ru", "phone": "+70040185008"}
0005435297103	6B84C7	2563 308922	SVETLANA MEDVEDEVA	{"email": "s_medvedeva071971@postgrespro.ru", "phone": "+70415029237"}
0005435297104	C196EB	0202 036011	ALEKSEY KUDRYASHOV	{"email": "akudryashov_101968@postgrespro.ru", "phone": "+70407477226"}
0005435297105	C71C24	7598 662523	ALEKSANDR NAZAROV	{"phone": "+70192247828"}
0005435297106	C71C24	6656 124646	VLADIMIR IVANOV	{"phone": "+70126701343"}
0005435297107	A95E93	6465 106260	LIDIYA IVANOVA	{"email": "ivanovalidiya-08121975@postgrespro.ru", "phone": "+70540470626"}
0005435297108	BC1124	3172 093242	VLADISLAV MATVEEV	{"phone": "+70184229129"}
0005435297109	BC1124	4856 060504	ALEKSANDR TIKHONOV	{"email": "tikhonov_aleksandr_29101984@postgrespro.ru", "phone": "+70943605074"}
0005435297110	AABB2B	5657 264646	DMITRIY SCHERBAKOV	{"phone": "+70270379142"}
0005435297111	AABB2B	7565 716710	RINAT ALEKSEEV	{"email": "r_alekseev-111969@postgrespro.ru", "phone": "+70843407064"}
0005435297112	876455	8721 557751	NAILYA LUKYANOVA	{"email": "nailya.lukyanova_041970@postgrespro.ru", "phone": "+70046965861"}
0005435297113	6F9D31	6317 841479	NIKITA GORBUNOV	{"email": "gorbunov_n.031972@postgrespro.ru", "phone": "+70080518511"}
0005435297114	6F9D31	6318 573005	VIKTOR KUZNECOV	{"phone": "+70705424089"}
0005435297115	99DD35	0813 509911	GERMAN MAKAROV	{"phone": "+70215748708"}
0005435297116	99DD35	6291 962055	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov_01061968@postgrespro.ru", "phone": "+70443362279"}
0005435297117	99DD35	3371 280563	DMITRIY TIMOFEEV	{"email": "dmitriy.timofeev1974@postgrespro.ru", "phone": "+70295674583"}
0005435297118	10968F	6618 841396	MARINA AFANASEVA	{"phone": "+70217738540"}
0005435297119	7BA0D2	9036 278028	ALENA NIKOLAEVA	{"email": "alenanikolaeva-15081970@postgrespro.ru", "phone": "+70486853825"}
0005435297120	7BA0D2	2000 511914	IRINA VOLKOVA	{"email": "irina_volkova-071980@postgrespro.ru", "phone": "+70364902708"}
0005435297121	131CAE	1829 647202	ANDREY SOKOLOV	{"phone": "+70740738419"}
0005435297122	2C694A	3472 127039	ANATOLIY MAKAROV	{"email": "makarovanatoliy1972@postgrespro.ru", "phone": "+70778754447"}
0005435297123	2C694A	3832 216462	MIKHAIL SOLOVEV	{"email": "solovev_mikhail101969@postgrespro.ru", "phone": "+70287791331"}
0005435297124	4E6EE7	8324 402307	SVETLANA KUZNECOVA	{"email": "svetlanakuznecova.1980@postgrespro.ru", "phone": "+70054958779"}
0005435297125	7D18AF	4612 117959	SERGEY SMIRNOV	{"email": "sergey.smirnov1968@postgrespro.ru", "phone": "+70731242805"}
0005435297126	7D18AF	2908 418673	BORIS EGOROV	{"email": "boris.egorov1972@postgrespro.ru", "phone": "+70581561178"}
0005435297127	C3641D	0944 553742	GALINA IVANOVA	{"phone": "+70093660246"}
0005435297128	C2FEE8	7385 174600	VALENTINA STEPANOVA	{"email": "stepanova.v-11111982@postgrespro.ru", "phone": "+70546438245"}
0005435297129	19DF91	8984 547822	EVGENIY SEMENOV	{"email": "e-semenov_1986@postgrespro.ru", "phone": "+70134766916"}
0005435297130	030493	1606 522774	OKSANA IVANOVA	{"phone": "+70779828237"}
0005435297131	030493	4267 842195	ZOYA MAKAROVA	{"phone": "+70070649337"}
0005435297132	030493	4434 970279	ANATOLIY CHERNOV	{"email": "chernov.anatoliy-08111965@postgrespro.ru", "phone": "+70575845753"}
0005435297133	A44A0A	3284 118387	SERGEY GAVRILOV	{"phone": "+70057120016"}
0005435297134	A44A0A	4615 539057	ELENA MALYSHEVA	{"phone": "+70055204400"}
0005435297135	CCC451	4543 920556	VLADIMIR MOISEEV	{"phone": "+70017676977"}
0005435297136	8EAFC7	6690 212744	ALEKSANDR SOROKIN	{"phone": "+70891339261"}
0005435297137	08655D	7914 751292	ZOYA MOROZOVA	{"email": "morozova_zoya.051984@postgrespro.ru", "phone": "+70761933444"}
0005435297138	08655D	2054 223628	SERGEY KISELEV	{"email": "kiselev-s.28061972@postgrespro.ru", "phone": "+70726160672"}
0005435297139	D58D0B	2654 023322	VLADIMIR SIDOROV	{"phone": "+70765413527"}
0005435297140	D58D0B	8466 356881	OKSANA POPOVA	{"phone": "+70803604576"}
0005435297141	47F1D2	0523 862723	ILYA MOISEEV	{"phone": "+70116714718"}
0005435297142	9C2DCC	5256 482407	LYUBOV MIKHAYLOVA	{"phone": "+70038874330"}
0005435297143	4AEC54	1461 567883	VIKTORIYA AFANASEVA	{"phone": "+70302945050"}
0005435297144	E0E54A	1498 715487	VIKTOR GORBUNOV	{"email": "gorbunovviktor_17071956@postgrespro.ru", "phone": "+70475733870"}
0005435297145	E0E54A	5827 896371	IRINA FILIPPOVA	{"phone": "+70645160652"}
0005435297146	65284F	9394 421966	ZHANNA ANDREEVA	{"phone": "+70625293110"}
0005435297147	A9189F	0722 099144	ALEKSANDR POPOV	{"phone": "+70337185053"}
0005435297148	A9189F	8893 230176	VITALIY IVANOV	{"phone": "+70508081679"}
0005435297149	4885DC	2982 353771	SERGEY PETROV	{"email": "sergey.petrov_19111973@postgrespro.ru", "phone": "+70308003378"}
0005435297150	B7B48A	3710 570990	ALESYA NAUMOVA	{"email": "naumova_a01011972@postgrespro.ru", "phone": "+70570061706"}
0005435297151	9975E5	3285 239703	OLGA IVANOVA	{"email": "oivanova-1965@postgrespro.ru", "phone": "+70211657681"}
0005435297152	19FD12	1302 250999	OLGA STEPANOVA	{"phone": "+70510239857"}
0005435297153	19FD12	2754 895970	STANISLAV ZHUKOV	{"phone": "+70563071146"}
0005435297154	3C0CE4	4632 467322	NATALYA DAVYDOVA	{"email": "davydovanatalya-15051987@postgrespro.ru", "phone": "+70130741545"}
0005435297155	BFDF7D	4731 323621	VIKTOR GRIGOREV	{"email": "vgrigorev.031961@postgrespro.ru", "phone": "+70731759865"}
0005435297156	AFF4C5	3502 937328	IGOR GUSEV	{"email": "i.gusev14111969@postgrespro.ru", "phone": "+70474532961"}
0005435297157	AFF4C5	5117 943603	VERONIKA MARTYNOVA	{"phone": "+70675503098"}
0005435297158	424611	9592 757454	ILYA STEPANOV	{"phone": "+70481788011"}
0005435297159	F81623	6922 855971	OLEG SCHERBAKOV	{"email": "scherbakovoleg-1977@postgrespro.ru", "phone": "+70981948109"}
0005435297160	C77691	3306 454318	TATYANA NIKOLAEVA	{"email": "t_nikolaeva-24031972@postgrespro.ru", "phone": "+70464017820"}
0005435297161	C77691	8757 546070	FARID SMIRNOV	{"phone": "+70850028962"}
0005435297162	C77691	3003 670433	ELDAR DENISOV	{"phone": "+70345045545"}
0005435297163	DDA1FB	5233 267240	MIKHAIL MIKHAYLOV	{"email": "mikhaylov_mikhail-28081967@postgrespro.ru", "phone": "+70494166067"}
0005435297164	AEABD3	6587 126655	DENIS ANTONOV	{"phone": "+70569742766"}
0005435297165	AEABD3	9440 858744	TATYANA ANTONOVA	{"phone": "+70279050212"}
0005435297166	6B3DAD	6160 063322	ALEKSEY NIKITIN	{"email": "nikitin_aleksey071981@postgrespro.ru", "phone": "+70354120332"}
0005435297167	6B3DAD	4153 497016	ALEVTINA TARASOVA	{"email": "tarasova_alevtina.061968@postgrespro.ru", "phone": "+70553382172"}
0005435297168	F64356	6793 823639	VLADIMIR POPOV	{"email": "vladimir-popov-03021976@postgrespro.ru", "phone": "+70772810080"}
0005435297169	A5FB8A	5046 008677	ELENA EFREMOVA	{"email": "efremovae-021966@postgrespro.ru", "phone": "+70812979470"}
0005435297170	02732B	5129 025785	MAKSIM KUZMIN	{"email": "kuzmin.maksim081968@postgrespro.ru", "phone": "+70840365232"}
0005435297171	44A76A	7739 146373	ANATOLIY CHERNOV	{"email": "chernov-anatoliy_15011970@postgrespro.ru", "phone": "+70642198491"}
0005435297172	0B96A1	3324 557822	KRISTINA ORLOVA	{"phone": "+70049813657"}
0005435297173	9FD2F2	7032 871478	OKSANA OSIPOVA	{"phone": "+70983834981"}
0005435297174	9FD2F2	5971 733712	ZOYA GERASIMOVA	{"phone": "+70682423673"}
0005435297175	F0DAEE	0721 080183	AMINA KARPOVA	{"phone": "+70349737700"}
0005435297176	F0DAEE	1422 081912	VLADIMIR ABRAMOV	{"phone": "+70185049302"}
0005435297177	105FBD	8376 591829	NATALYA ANISIMOVA	{"email": "anisimovanatalya041969@postgrespro.ru", "phone": "+70364029752"}
0005435297178	BD8322	0548 184444	ALEKSANDR SEMENOV	{"phone": "+70372706181"}
0005435297179	BD8322	8712 727424	YURIY BELOV	{"email": "y.belov-16031978@postgrespro.ru", "phone": "+70609724328"}
0005435297180	8857B1	5325 245417	TATYANA TIMOFEEVA	{"phone": "+70977328938"}
0005435297181	3FF3A8	4967 553562	SOFYA MAKAROVA	{"phone": "+70585473340"}
0005435297182	041B89	0269 148575	LIDIYA YAKOVLEVA	{"phone": "+70200069970"}
0005435297183	826BCD	1282 549353	GENNADIY DMITRIEV	{"phone": "+70011926798"}
0005435297184	CD8470	9049 147553	YAKOV KAZAKOV	{"phone": "+70656104934"}
0005435297185	E286C1	6983 035883	SVETLANA ROMANOVA	{"phone": "+70009238024"}
0005435297186	13C27A	6439 071221	ELENA AKIMOVA	{"email": "akimova_e-1960@postgrespro.ru", "phone": "+70630248929"}
0005435297187	E4380A	3867 285585	VIKTORIYA ROMANOVA	{"phone": "+70241373168"}
0005435297188	B9EA81	5817 632462	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay_1965@postgrespro.ru", "phone": "+70607745422"}
0005435297189	B9EA81	5805 109984	NATALYA ZAYCEVA	{"phone": "+70862657089"}
0005435297190	5A604B	1534 537179	NIKOLAY STEPANOV	{"email": "nikolay-stepanov-24101966@postgrespro.ru", "phone": "+70822580064"}
0005435297191	589D95	8258 358004	ALEKSANDR SCHERBAKOV	{"phone": "+70770186797"}
0005435297192	9441BA	1563 550700	OLGA TROFIMOVA	{"email": "o-trofimova091976@postgrespro.ru", "phone": "+70011214028"}
0005435297193	EAF2A8	2448 228026	SVETLANA KAZAKOVA	{"phone": "+70877361774"}
0005435297194	035429	2375 982538	ALEKSANDR DAVYDOV	{"phone": "+70970943808"}
0005435297195	967DB4	3392 826711	IVAN DMITRIEV	{"email": "dmitriev-i071966@postgrespro.ru", "phone": "+70351902285"}
0005435297196	967DB4	9779 349799	VALERIYA NIKOLAEVA	{"phone": "+70724559441"}
0005435297197	ED3190	4508 223923	MARIYA MATVEEVA	{"email": "matveeva-mariya_031969@postgrespro.ru", "phone": "+70569486413"}
0005435297198	D5BA06	1019 525743	MARGARITA YAKOVLEVA	{"email": "m.yakovleva011961@postgrespro.ru", "phone": "+70429808243"}
0005435297199	35C9F6	1660 148757	ARTEM KUZNECOV	{"email": "artem-kuznecov_29091973@postgrespro.ru", "phone": "+70786955825"}
0005435297200	CA9B74	1512 543574	ROZA NOVIKOVA	{"phone": "+70441563999"}
0005435297201	C623C1	3961 037632	PLATON MARTYNOV	{"email": "pmartynov-22101964@postgrespro.ru", "phone": "+70209407776"}
0005435297202	4E724F	6005 492737	PETR DMITRIEV	{"email": "dmitriev-petr15091976@postgrespro.ru", "phone": "+70036914471"}
0005435297203	C40420	7307 994901	ALEKSANDR EGOROV	{"email": "egorov.aleksandr.24081974@postgrespro.ru", "phone": "+70591375827"}
0005435297204	32D986	6893 468852	ALLA KUZMINA	{"phone": "+70685754465"}
0005435297205	F5B6F6	9058 081699	VLADIMIR IVANOV	{"email": "v.ivanov_25061974@postgrespro.ru", "phone": "+70749352335"}
0005435297206	745A2B	1868 881730	RAISA KISELEVA	{"email": "r.kiseleva.1971@postgrespro.ru", "phone": "+70573570511"}
0005435297207	5253FF	9111 191783	TATYANA IVANOVA	{"email": "tivanova_23111974@postgrespro.ru", "phone": "+70286854133"}
0005435297208	1EE544	8173 682104	KSENIYA FILIPPOVA	{"email": "kseniya.filippova.1977@postgrespro.ru", "phone": "+70497521401"}
0005435297209	DC99E9	1045 282810	ANNA KAZAKOVA	{"email": "kazakovaanna-1972@postgrespro.ru", "phone": "+70378221909"}
0005435297210	E4C1D2	6689 616335	KSENIYA KULIKOVA	{"email": "kulikovak_1977@postgrespro.ru", "phone": "+70038157794"}
0005435297211	B671E1	5397 403373	SERGEY FROLOV	{"email": "sergey.frolov_26111976@postgrespro.ru", "phone": "+70849700686"}
0005435297212	328BF5	1162 098801	ELENA ANTONOVA	{"phone": "+70085974191"}
0005435297213	328BF5	7683 858210	ZOYA TIMOFEEVA	{"email": "z.timofeeva-011974@postgrespro.ru", "phone": "+70886675356"}
0005435297214	2481A3	7996 107577	DENIS ILIN	{"phone": "+70847898703"}
0005435297215	A38419	6439 896335	ANASTASIYA VLASOVA	{"email": "vlasova_a_1969@postgrespro.ru", "phone": "+70883282281"}
0005435297216	B5796D	1094 209526	YANA PETROVA	{"phone": "+70444089263"}
0005435297217	05C15B	3480 492854	OKSANA GRISHINA	{"phone": "+70175384871"}
0005435297218	3AF0FD	0510 814841	TAMARA ZHUKOVA	{"email": "tamara_zhukova_081978@postgrespro.ru", "phone": "+70710744382"}
0005435297219	51FFB8	7441 062692	DMITRIY KUZMIN	{"phone": "+70600514769"}
0005435297220	73BE0A	1065 065793	DENIS ANDREEV	{"email": "denis_andreev1964@postgrespro.ru", "phone": "+70788870350"}
0005435297221	8F1218	6327 484883	EKATERINA TIMOFEEVA	{"phone": "+70559825402"}
0005435297222	9385DF	3912 765480	YAROSLAV MEDVEDEV	{"email": "medvedev_yaroslav-1969@postgrespro.ru", "phone": "+70939726983"}
0005435297223	427B5E	1528 014865	ANNA NIKIFOROVA	{"email": "a.nikiforova-19071976@postgrespro.ru", "phone": "+70993967896"}
0005435297224	427B5E	3019 681171	YANA ABRAMOVA	{"email": "abramova.y021981@postgrespro.ru", "phone": "+70280367395"}
0005435297225	427B5E	8312 830561	MAKSIM DENISOV	{"phone": "+70673514332"}
0005435297226	EF0B0C	3306 119424	ANDREY KARPOV	{"phone": "+70980209017"}
0005435297227	939C8E	8956 310903	TATYANA BELYAEVA	{"email": "t-belyaeva.1978@postgrespro.ru", "phone": "+70954887366"}
0005435297228	EEC2BE	2667 605275	ANTONINA VLASOVA	{"email": "vlasovaa.20111981@postgrespro.ru", "phone": "+70582862719"}
0005435297229	2E5402	3768 538712	IVAN POPOV	{"email": "ipopov_051969@postgrespro.ru", "phone": "+70280682102"}
0005435297230	2E5402	6196 017424	TATYANA MAKAROVA	{"phone": "+70743500956"}
0005435297231	286385	8388 526287	LYUBOV IVANOVA	{"email": "ivanova-lyubov.1972@postgrespro.ru", "phone": "+70815027357"}
0005435297232	A9032D	7924 933872	YURIY SOROKIN	{"email": "sorokin_yuriy_081966@postgrespro.ru", "phone": "+70811671618"}
0005435297233	C5185E	6596 770797	NIKOLAY KOROLEV	{"email": "nikolay_korolev-011972@postgrespro.ru", "phone": "+70934718695"}
0005435297234	5979B9	8804 422917	ELENA KUZNECOVA	{"email": "elena_kuznecova_28071957@postgrespro.ru", "phone": "+70297199505"}
0005435297235	5979B9	8975 659364	IRINA FILATOVA	{"email": "irina_filatova.051976@postgrespro.ru", "phone": "+70663367353"}
0005435297236	3F84B5	0990 597376	VYACHESLAV DAVYDOV	{"phone": "+70715974386"}
0005435297237	3F84B5	5936 644605	GENNADIY DMITRIEV	{"phone": "+70457360973"}
0005435297238	FB83C7	4359 206526	DMITRIY IVANOV	{"email": "ivanov_d-12071955@postgrespro.ru", "phone": "+70680237683"}
0005435297239	1D17A7	7026 705712	LIDIYA DAVYDOVA	{"phone": "+70302351759"}
0005435297240	065C78	6377 606038	OLGA KONDRATEVA	{"phone": "+70646018547"}
0005435297241	A34268	9522 569045	SVETLANA POTAPOVA	{"email": "potapova_svetlana.061965@postgrespro.ru", "phone": "+70872173972"}
0005435297242	A34268	1640 633458	IVAN SERGEEV	{"phone": "+70990717377"}
0005435297243	B1D9FE	2260 783852	ALEKSANDR NAUMOV	{"phone": "+70838109647"}
0005435297244	BDFA09	9281 815046	ANASTASIYA KUZNECOVA	{"email": "kuznecova-a_09031962@postgrespro.ru", "phone": "+70409774495"}
0005435297245	51E84D	5047 810993	SVETLANA MOISEEVA	{"email": "s-moiseeva-04101966@postgrespro.ru", "phone": "+70091316571"}
0005435297246	A58659	4516 605146	VIKTOR MELNIKOV	{"phone": "+70679066380"}
0005435297247	26985C	3666 387790	NIKOLAY EGOROV	{"email": "egorov-nikolay.16101978@postgrespro.ru", "phone": "+70971813457"}
0005435297248	26985C	3994 078939	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov-051974@postgrespro.ru", "phone": "+70352000266"}
0005435297249	26985C	8672 727876	ALEKSANDR KUZMIN	{"phone": "+70369321838"}
0005435297250	47568F	9796 021759	ALEKSEY TARASOV	{"phone": "+70087975011"}
0005435297251	47568F	2158 240677	ALEKSEY BELOV	{"email": "belov_aleksey_16041977@postgrespro.ru", "phone": "+70635865157"}
0005435297252	EB67AC	5412 575064	EKATERINA SOLOVEVA	{"email": "ekaterina.soloveva.19111976@postgrespro.ru", "phone": "+70772249013"}
0005435297253	AFBC96	3126 430722	EVGENIY KARPOV	{"phone": "+70517425637"}
0005435297254	AFBC96	4830 213653	ANASTASIYA IVANOVA	{"email": "ivanovaa111977@postgrespro.ru", "phone": "+70978586089"}
0005435297255	AFBC96	8958 734746	VALENTINA TIMOFEEVA	{"email": "timofeeva.v.1976@postgrespro.ru", "phone": "+70422583321"}
0005435297256	D735A7	6280 718924	EVGENIY MAKAROV	{"email": "makarov.e.1975@postgrespro.ru", "phone": "+70502407107"}
0005435297257	412FDE	7017 828230	ANDREY NAZAROV	{"phone": "+70930135972"}
0005435297258	D86077	3859 252281	NADEZHDA FROLOVA	{"email": "frolova.nadezhda.111977@postgrespro.ru", "phone": "+70374981171"}
0005435297259	270356	3368 240861	LARISA MOROZOVA	{"email": "larisa-morozova29041975@postgrespro.ru", "phone": "+70790048046"}
0005435297260	270356	0905 310849	EVGENIY VASILEV	{"email": "evgeniyvasilev-1969@postgrespro.ru", "phone": "+70279214415"}
0005435297261	BFC3DA	6361 346237	LYUBOV FEDOROVA	{"email": "lyubovfedorova_011959@postgrespro.ru", "phone": "+70001548499"}
0005435297262	BFC3DA	6047 184918	NINA NIKITINA	{"email": "nikitina.nina031969@postgrespro.ru", "phone": "+70097336115"}
0005435297263	0A0555	0066 024788	ANASTASIYA SERGEEVA	{"phone": "+70620426768"}
0005435297264	0A0555	4885 785989	VIKTOR TIMOFEEV	{"phone": "+70107549171"}
0005435297265	41E6CD	0288 440618	ALEKSANDRA NESTEROVA	{"phone": "+70078935634"}
0005435297266	41E6CD	6649 598588	DMITRIY FEDOROV	{"phone": "+70592489257"}
0005435297267	DD7FD5	5556 160365	ARTEM EGOROV	{"phone": "+70673384304"}
0005435297350	52FF7C	9579 318340	RINAT KISELEV	{"phone": "+70483019059"}
0005435297351	CB310B	4015 182487	ALEKSEY KOZLOV	{"email": "kozlovaleksey_1966@postgrespro.ru", "phone": "+70374516147"}
0005435297352	7C8245	5682 326241	TAMARA ANTONOVA	{"email": "t.antonova.1979@postgrespro.ru", "phone": "+70520079026"}
0005435297353	7C8245	6054 492395	GERMAN YAKOVLEV	{"email": "yakovlev-german1975@postgrespro.ru", "phone": "+70414318386"}
0005435297354	FAA855	5391 653190	VALERIY KISELEV	{"phone": "+70589399506"}
0005435297355	E1870B	6059 661260	EKATERINA MELNIKOVA	{"phone": "+70697317637"}
0005435297356	E1870B	1755 936665	ALINA GERASIMOVA	{"phone": "+70244317997"}
0005435297357	AECAB9	0400 273466	YURIY KUZMIN	{"email": "yuriy-kuzmin.021985@postgrespro.ru", "phone": "+70252121435"}
0005435297358	AECAB9	3523 133314	VALERIYA MOISEEVA	{"phone": "+70106844099"}
0005435297359	47F823	4685 861147	OLGA GAVRILOVA	{"email": "gavrilova.olga09071963@postgrespro.ru", "phone": "+70263805547"}
0005435297360	47F823	2424 976780	TATYANA KUDRYASHOVA	{"email": "t.kudryashova.1977@postgrespro.ru", "phone": "+70291985459"}
0005435297361	EA5F7A	7027 279780	NADEZHDA DENISOVA	{"email": "denisovan-1970@postgrespro.ru", "phone": "+70162903378"}
0005435297362	5C96BC	7797 937345	MIKHAIL ROMANOV	{"phone": "+70697371997"}
0005435297363	C12CD5	1482 855404	EVGENIY KARPOV	{"email": "karpove1966@postgrespro.ru", "phone": "+70555814439"}
0005435297364	4EF519	1125 244821	EKATERINA KAZAKOVA	{"email": "kazakova-ekaterina_031957@postgrespro.ru", "phone": "+70500895685"}
0005435297365	C36F33	1947 283858	TAMARA MAKAROVA	{"email": "makarovat-121957@postgrespro.ru", "phone": "+70616729497"}
0005435297366	78CD53	4000 337579	EVGENIY IVANOV	{"phone": "+70312922451"}
0005435297367	BA860C	2999 841015	DENIS RODIONOV	{"email": "rodionov.denis.09121977@postgrespro.ru", "phone": "+70559317679"}
0005435297368	FE613A	0821 456802	NIKOLAY CHERNOV	{"email": "nikolay.chernov-24051972@postgrespro.ru", "phone": "+70600176596"}
0005435297369	480881	6211 730151	ANASTASIYA ROMANOVA	{"phone": "+70439708950"}
0005435297370	480881	6051 502920	IGOR SMIRNOV	{"email": "igor_smirnov_1963@postgrespro.ru", "phone": "+70794908329"}
0005435297371	82FFA9	2092 467052	ALLA VOLKOVA	{"phone": "+70497827735"}
0005435297372	82FFA9	8032 727120	KIRILL NAUMOV	{"email": "naumov.kirill_111966@postgrespro.ru", "phone": "+70238113617"}
0005435297373	4C71CE	7713 488705	SERGEY KULIKOV	{"email": "kulikov-s081985@postgrespro.ru", "phone": "+70405449617"}
0005435297374	4C71CE	6427 544693	VLADIMIR ZAKHAROV	{"email": "v-zakharov_081972@postgrespro.ru", "phone": "+70749879223"}
0005435297375	3A1F02	6550 329638	NINA POTAPOVA	{"email": "potapova_n1965@postgrespro.ru", "phone": "+70558596487"}
0005435297376	81853A	2790 812651	ANNA VLASOVA	{"email": "a.vlasova_071977@postgrespro.ru", "phone": "+70162574424"}
0005435297377	370E22	0461 906835	VLADIMIR VOLKOV	{"phone": "+70554251730"}
0005435297378	EBCF43	5412 263533	LYUDMILA ERMAKOVA	{"email": "l-ermakova.071972@postgrespro.ru", "phone": "+70979042314"}
0005435297379	2A91FE	6211 045678	YULIYA PAVLOVA	{"phone": "+70320727562"}
0005435297380	D740A9	5838 803312	VLADIMIR MARTYNOV	{"phone": "+70771977513"}
0005435297381	1AEA14	7439 512916	LYUDMILA LUKYANOVA	{"phone": "+70974489271"}
0005435297382	B57CC3	5434 719289	DARYA ANTONOVA	{"phone": "+70088706559"}
0005435297383	6F24ED	8387 049674	NIKOLAY TIMOFEEV	{"email": "n.timofeev_29081975@postgrespro.ru", "phone": "+70872371641"}
0005435297384	6F24ED	4626 277932	GALINA SOROKINA	{"email": "sorokina_galina_11091964@postgrespro.ru", "phone": "+70737172925"}
0005435297385	EC5213	4739 816310	ANDREY IVANOV	{"email": "andrey_ivanov121972@postgrespro.ru", "phone": "+70527515395"}
0005435297386	EC5213	4657 303214	NADEZHDA MARTYNOVA	{"email": "martynova_n-031962@postgrespro.ru", "phone": "+70868937057"}
0005435297387	3B105C	0945 124363	ALEKSANDRA MEDVEDEVA	{"phone": "+70047400647"}
0005435297388	AC1BD8	9426 249246	KONSTANTIN SOKOLOV	{"phone": "+70099826985"}
0005435297389	BF2475	4162 915465	MARIYA KAZAKOVA	{"phone": "+70589751669"}
0005435297390	43078E	6083 870895	TATYANA DAVYDOVA	{"email": "tatyana_davydova01031974@postgrespro.ru", "phone": "+70190429379"}
0005435297391	2630D0	0397 334829	VITALIY NAZAROV	{"phone": "+70915376725"}
0005435297392	783510	4239 750267	EVGENIY PAVLOV	{"phone": "+70875969865"}
0005435297393	C60303	5514 167696	IRINA SMIRNOVA	{"email": "smirnovai-041955@postgrespro.ru", "phone": "+70939886896"}
0005435297394	474AE9	7785 764770	IVAN NAZAROV	{"email": "ivan-nazarov-1982@postgrespro.ru", "phone": "+70080282197"}
0005435297395	4A9728	9875 898398	ANDREY IVANOV	{"email": "a.ivanov.041983@postgrespro.ru", "phone": "+70345247489"}
0005435297396	4A9728	8293 946238	FEDOR EGOROV	{"email": "f_egorov081976@postgrespro.ru", "phone": "+70161619588"}
0005435297397	E39439	1692 868109	ANDREY STEPANOV	{"phone": "+70889076206"}
0005435297398	68547D	5581 059822	ALEKSANDRA NESTEROVA	{"phone": "+70334811460"}
0005435297399	0666C6	7141 220019	ROMAN MATVEEV	{"phone": "+70646002473"}
0005435297400	0666C6	6535 062122	ALENA SMIRNOVA	{"email": "smirnova.a-1977@postgrespro.ru", "phone": "+70890350221"}
0005435297401	C9F5AF	2576 947394	ALEKSANDR TIMOFEEV	{"email": "timofeev-aleksandr_101965@postgrespro.ru", "phone": "+70222880718"}
0005435297402	025B39	4625 243097	SVETLANA MIRONOVA	{"email": "s-mironova1971@postgrespro.ru", "phone": "+70570723190"}
0005435299696	D9386A	4168 644139	MARIYA POLYAKOVA	{"phone": "+70170731923"}
0005435299697	E5B351	0843 702742	ALEKSANDR KISELEV	{"email": "kiselev.a091978@postgrespro.ru", "phone": "+70229589972"}
0005435299698	F4F469	2283 884044	ANASTASIYA FEDOROVA	{"phone": "+70766476049"}
0005435299699	179851	8546 954030	OLGA IVANOVA	{"phone": "+70734677589"}
0005435299700	15B695	8944 857804	TATYANA BELYAEVA	{"phone": "+70264024744"}
0005435299701	15B695	0546 725254	YULIYA BOGDANOVA	{"phone": "+70906190940"}
0005435299702	C6D6E8	8844 935501	IGOR KUZNECOV	{"phone": "+70241759831"}
0005435299703	3ECE0B	9268 307043	VALERIY POPOV	{"email": "popov-v.071967@postgrespro.ru", "phone": "+70453338281"}
0005435299704	39C02C	2343 311510	ELLA PETROVA	{"phone": "+70387933892"}
0005435299705	B0C76A	1302 900053	ANATOLIY BONDARENKO	{"email": "bondarenko-anatoliy.061970@postgrespro.ru", "phone": "+70303674583"}
0005435299706	1A19E6	7536 268812	ALEKSEY ANDREEV	{"phone": "+70358747459"}
0005435299707	3FC630	3135 882053	ANDREY POPOV	{"phone": "+70765549193"}
0005435299708	D649F1	0118 775203	IVAN MOISEEV	{"email": "ivan_moiseev.1978@postgrespro.ru", "phone": "+70114895750"}
0005435299709	D649F1	2332 383217	VLADIMIR ANDREEV	{"phone": "+70813221493"}
0005435299710	9C38E0	5595 089587	LIDIYA LUKYANOVA	{"email": "lukyanova_l.22101982@postgrespro.ru", "phone": "+70040754406"}
0005435299711	785B9F	9385 406555	NATALYA BORISOVA	{"email": "borisova_n_051988@postgrespro.ru", "phone": "+70021029049"}
0005435299712	34808A	0136 993221	SVETLANA YUDINA	{"email": "yudina-s20121971@postgrespro.ru", "phone": "+70298135719"}
0005435299713	34808A	3433 986272	ALEKSANDRA VASILEVA	{"email": "vasileva.a.1969@postgrespro.ru", "phone": "+70448138916"}
0005435299714	34808A	2138 485570	EVGENIYA ANTONOVA	{"phone": "+70651680991"}
0005435299715	CC6460	4145 016396	ALEKSANDR NIKITIN	{"phone": "+70674270259"}
0005435299716	C0F9C5	1792 220316	OLGA KUDRYASHOVA	{"phone": "+70005585471"}
0005435299717	9F6E37	7815 584728	VASILIY FEDOROV	{"phone": "+70379204325"}
0005435299718	AFFA8C	6288 760991	VIKTOR GERASIMOV	{"phone": "+70341846490"}
0005435299719	AFFA8C	3543 060284	EKATERINA KUDRYASHOVA	{"email": "ekaterina-kudryashova.1973@postgrespro.ru", "phone": "+70956639939"}
0005435299720	66AB33	4025 301697	YURIY PETROV	{"email": "ypetrov091982@postgrespro.ru", "phone": "+70092365874"}
0005435299721	BDB83B	2841 589403	LIDIYA NOVIKOVA	{"phone": "+70232722488"}
0005435299722	3B7753	9457 445342	LYUBOV ANDREEVA	{"phone": "+70564317781"}
0005435299723	DA57B4	6148 750109	VLADIMIR ZAKHAROV	{"phone": "+70770862195"}
0005435299724	DA57B4	8372 047655	MARIYA SERGEEVA	{"email": "sergeevam.27081968@postgrespro.ru", "phone": "+70679205233"}
0005435299725	A269A5	4398 664071	ALEKSEY MOROZOV	{"phone": "+70835803490"}
0005435299726	657192	3994 045352	ANNA ERMAKOVA	{"email": "aermakova_021971@postgrespro.ru", "phone": "+70958431639"}
0005435299727	DB4CD9	2300 944100	VASILIY KUZMIN	{"phone": "+70344645331"}
0005435299728	DB4CD9	4211 753685	ALINA MAKAROVA	{"phone": "+70722440233"}
0005435299729	C20054	0984 738152	SVETLANA MOISEEVA	{"phone": "+70960471658"}
0005435299730	79B761	6125 519538	SERGEY SMIRNOV	{"phone": "+70320955412"}
0005435299731	31665E	6779 705907	OLGA KRASNOVA	{"email": "olga_krasnova_061969@postgrespro.ru", "phone": "+70285644605"}
0005435299732	A15FD8	1597 150656	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir06081974@postgrespro.ru", "phone": "+70299508308"}
0005435299733	FD8806	2392 401516	MARINA NIKITINA	{"phone": "+70726108733"}
0005435299734	3FE2EC	5111 665647	ELINA TIKHONOVA	{"email": "e.tikhonova-041970@postgrespro.ru", "phone": "+70957071677"}
0005435299735	FF8034	6119 863559	ANTON KOZLOV	{"email": "akozlov-1967@postgrespro.ru", "phone": "+70570981531"}
0005435299736	9D353F	8190 194570	GALINA POTAPOVA	{"email": "potapova.g-1964@postgrespro.ru", "phone": "+70685917177"}
0005435299737	A6D2F6	2504 776297	ELENA TIMOFEEVA	{"phone": "+70164825953"}
0005435299738	ED5AAC	6720 193137	ALEKSEY MIKHAYLOV	{"email": "a_mikhaylov_061976@postgrespro.ru", "phone": "+70920618202"}
0005435299739	6B583B	4842 036278	RUSTAM KUDRYASHOV	{"email": "r_kudryashov-071972@postgrespro.ru", "phone": "+70782168913"}
0005435299740	2DC6BE	7041 826316	ROMAN RODIONOV	{"phone": "+70754759786"}
0005435299741	2DC6BE	1579 886952	DENIS RODIONOV	{"email": "denis.rodionov-26091981@postgrespro.ru", "phone": "+70888882619"}
0005435299742	2DC6BE	3862 529528	SERGEY KARPOV	{"phone": "+70653249468"}
0005435299743	93ABA9	5514 802573	ILYA ZHUKOV	{"email": "i_zhukov_07091968@postgrespro.ru", "phone": "+70018017211"}
0005435299744	CE349D	9819 112855	OLEG NOVIKOV	{"email": "novikov-oleg-30071972@postgrespro.ru", "phone": "+70147505626"}
0005435299745	CE349D	9176 240460	IVAN BONDARENKO	{"email": "i-bondarenko101974@postgrespro.ru", "phone": "+70684208378"}
0005435299746	B10D15	4928 456295	DMITRIY DENISOV	{"email": "ddenisov.1982@postgrespro.ru", "phone": "+70692100624"}
0005435299747	561BA7	5201 781135	DENIS NIKITIN	{"phone": "+70861543075"}
0005435299748	561BA7	7108 012625	LARISA TITOVA	{"phone": "+70806698866"}
0005435299749	561BA7	6590 918219	ELENA ROMANOVA	{"email": "romanova.e-26011981@postgrespro.ru", "phone": "+70942440825"}
0005435299750	FD32BD	7566 204937	NATALYA MATVEEVA	{"phone": "+70536364818"}
0005435299751	67884D	4080 675153	ALEKSANDR BELOV	{"email": "belov-aleksandr1963@postgrespro.ru", "phone": "+70436041823"}
0005435299752	67884D	0205 970265	ALINA SCHERBAKOVA	{"email": "a_scherbakova.19031973@postgrespro.ru", "phone": "+70663145438"}
0005435299753	5D2E6C	5372 277700	ANNA PAVLOVA	{"email": "a_pavlova.021960@postgrespro.ru", "phone": "+70019463399"}
0005435299754	92002E	6849 928748	MIKHAIL VOLKOV	{"email": "mikhail_volkov_13061970@postgrespro.ru", "phone": "+70994795459"}
0005435299755	92002E	9739 141028	OKSANA VOROBEVA	{"email": "oksanavorobeva-04061986@postgrespro.ru", "phone": "+70737181202"}
0005435299756	0BC366	6247 926327	ALLA FILATOVA	{"email": "a_filatova10041974@postgrespro.ru", "phone": "+70742856903"}
0005435299757	0BC366	0213 200523	NIKITA PETROV	{"email": "nikita-petrov.08051981@postgrespro.ru", "phone": "+70551817791"}
0005435299758	D6EE57	1302 873907	LARISA BARANOVA	{"phone": "+70688536971"}
0005435299759	383FFF	8646 209122	MIKHAIL VOLKOV	{"email": "mvolkov-101970@postgrespro.ru", "phone": "+70372707385"}
0005435299760	383FFF	7753 570541	VASILIY KULIKOV	{"phone": "+70163694253"}
0005435299761	25F94C	1707 123330	MARGARITA KOVALEVA	{"email": "kovaleva_m.081969@postgrespro.ru", "phone": "+70348522274"}
0005435299762	BBE3EE	4024 296619	SVETLANA ZHUKOVA	{"phone": "+70430759942"}
0005435299763	21E6E7	2939 763045	YURIY TIMOFEEV	{"phone": "+70314692799"}
0005435299764	566193	7259 308930	MARIYA ZHURAVLEVA	{"phone": "+70734875310"}
0005435299765	566193	1510 412571	ALEKSANDR ALEKSANDROV	{"phone": "+70013329356"}
0005435299766	B157FF	0864 424420	VIKTORIYA ALEKSEEVA	{"email": "alekseeva-viktoriya_071963@postgrespro.ru", "phone": "+70135176569"}
0005435299767	B157FF	5017 921167	MAKSIM SHEVCHENKO	{"email": "m-shevchenko_1983@postgrespro.ru", "phone": "+70177759255"}
0005435299768	002746	9464 174777	VALENTINA KRASNOVA	{"email": "vkrasnova_1966@postgrespro.ru", "phone": "+70088619673"}
0005435299769	002746	3588 409345	VIKTOR ROMANOV	{"email": "romanov_viktor051972@postgrespro.ru", "phone": "+70906965030"}
0005435299770	F45468	2704 311374	MAKSIM OSIPOV	{"email": "m.osipov-071985@postgrespro.ru", "phone": "+70364522756"}
0005435299771	F45468	4930 332948	ELIZAVETA SEMENOVA	{"phone": "+70970788154"}
0005435299772	DB961C	0833 124607	IRINA TIKHONOVA	{"email": "itikhonova061977@postgrespro.ru", "phone": "+70185525557"}
0005435299773	DB961C	2906 885108	NINA KOMAROVA	{"email": "komarova.n-15011974@postgrespro.ru", "phone": "+70498667109"}
0005435299774	8400A0	5398 881902	ELENA YUDINA	{"email": "yudina.e_1965@postgrespro.ru", "phone": "+70398196835"}
0005435299775	27C219	0122 260543	VIKTOR KUZNECOV	{"email": "kuznecov.viktor-1983@postgrespro.ru", "phone": "+70405520588"}
0005435299776	27C219	3568 563221	DMITRIY ALEKSEEV	{"email": "d-alekseev_021978@postgrespro.ru", "phone": "+70020132039"}
0005435299777	AFA562	4431 058608	VALERIYA MAKAROVA	{"email": "makarovavaleriya.1973@postgrespro.ru", "phone": "+70045178204"}
0005435299778	351273	3729 462478	GENNADIY KAZAKOV	{"phone": "+70102406658"}
0005435299779	351273	1145 277500	SERGEY ANDREEV	{"phone": "+70154462091"}
0005435299780	C2C747	0335 089868	NADEZHDA VOROBEVA	{"email": "nadezhda_vorobeva051964@postgrespro.ru", "phone": "+70855609128"}
0005435299781	D9D68A	5325 849946	MARIYA ROMANOVA	{"email": "romanovam.27051971@postgrespro.ru", "phone": "+70112629292"}
0005435299782	844DFD	5706 926680	ANASTASIYA DAVYDOVA	{"email": "anastasiya_davydova_11061970@postgrespro.ru", "phone": "+70974364977"}
0005435299783	305FAD	0976 295416	SVETLANA EGOROVA	{"phone": "+70768004042"}
0005435299784	9463A9	4375 003992	GENNADIY PAVLOV	{"email": "gennadiypavlov-1973@postgrespro.ru", "phone": "+70582339702"}
0005435299785	BEBC33	0838 257102	IVAN VASILEV	{"phone": "+70180023176"}
0005435299786	54F246	5895 755837	FARIDA GAVRILOVA	{"phone": "+70145331125"}
0005435299787	54F246	3287 690893	SERGEY TIKHONOV	{"phone": "+70617610757"}
0005435299788	87BA73	5902 567988	VLADIMIR MIKHAYLOV	{"phone": "+70489431101"}
0005435299789	183465	0360 125085	NATALYA ANTONOVA	{"email": "antonova.n-1976@postgrespro.ru", "phone": "+70539121404"}
0005435299790	61DA70	6270 418504	VASILISA NIKITINA	{"phone": "+70825095901"}
0005435299791	60D981	7080 050226	ALEVTINA ZAYCEVA	{"phone": "+70381031222"}
0005435299792	74FF04	0949 101056	DMITRIY ANTONOV	{"email": "antonov-d_1968@postgrespro.ru", "phone": "+70027454998"}
0005435299793	4A71F5	3735 785294	TAMARA MATVEEVA	{"phone": "+70207573176"}
0005435299794	4A71F5	0408 088555	LYUBOV FROLOVA	{"phone": "+70346614235"}
0005435299795	7803C2	0380 801115	YURIY DAVYDOV	{"email": "yuriy.davydov-011967@postgrespro.ru", "phone": "+70476530890"}
0005435299796	09F6D7	2996 168654	IVAN KUZNECOV	{"email": "ivan_kuznecov-011977@postgrespro.ru", "phone": "+70436152075"}
0005435299797	09F6D7	6301 229853	TIMUR IVANOV	{"phone": "+70195282562"}
0005435299798	09F6D7	5575 387356	ANASTASIYA AKIMOVA	{"email": "aakimova_05021965@postgrespro.ru", "phone": "+70446858875"}
0005435299799	04FCFC	9508 923431	RUSLAN BELOV	{"phone": "+70103977708"}
0005435299800	04FCFC	3552 595534	ANDREY TIKHONOV	{"phone": "+70314296113"}
0005435299801	A8087A	2509 353350	RAFAIL YAKOVLEV	{"email": "yakovlev.r051966@postgrespro.ru", "phone": "+70625045588"}
0005435299802	FE708E	8922 890925	NATALYA VOLKOVA	{"phone": "+70917399226"}
0005435299803	770B43	8358 072825	ANDREY EGOROV	{"email": "egorov.andrey-091983@postgrespro.ru", "phone": "+70550449925"}
0005435299804	2FE90A	3154 973558	KIRILL YAKOVLEV	{"email": "kirill-yakovlev18031960@postgrespro.ru", "phone": "+70670288898"}
0005435299805	5B82EB	9248 083990	TATYANA TIKHONOVA	{"phone": "+70035181495"}
0005435299806	BEA8F9	6519 698057	ROMAN VLASOV	{"phone": "+70765478530"}
0005435299807	7595D3	0483 838470	ANATOLIY TIKHONOV	{"email": "tikhonov_a121964@postgrespro.ru", "phone": "+70979084182"}
0005435299808	7595D3	8339 234483	SVETLANA SMIRNOVA	{"email": "smirnova_s1972@postgrespro.ru", "phone": "+70593891488"}
0005435299809	863B02	0004 464074	ANNA BELYAEVA	{"email": "a-belyaeva1967@postgrespro.ru", "phone": "+70415027164"}
0005435299810	B56442	4705 665228	SAMIRA EFIMOVA	{"phone": "+70835994164"}
0005435299811	11A9FE	5060 052509	ANNA IVANOVA	{"phone": "+70965943941"}
0005435299812	AD7D5F	2180 241815	OKSANA KRASNOVA	{"phone": "+70866541347"}
0005435299813	95E77C	8415 865591	SERGEY EGOROV	{"phone": "+70226551070"}
0005435299814	AA8DC8	1390 616269	TATYANA FADEEVA	{"phone": "+70605037003"}
0005435299815	AA8DC8	9897 513822	YURIY FILIPPOV	{"email": "filippov_yuriy_15071975@postgrespro.ru", "phone": "+70293341906"}
0005435299816	DB72B6	5058 709615	ANNA KONOVALOVA	{"phone": "+70695492326"}
0005435299817	409BF5	0224 425415	VALENTINA POPOVA	{"email": "valentina.popova-14071963@postgrespro.ru", "phone": "+70569234419"}
0005435299818	E8A1F1	8695 739404	ILYA KAZAKOV	{"phone": "+70528925316"}
0005435299819	C3015D	4626 573750	VLADIMIR SHEVCHENKO	{"phone": "+70523476325"}
0005435299820	C3015D	2834 117306	ANASTASIYA MELNIKOVA	{"phone": "+70397752358"}
0005435299821	924AEE	5099 417490	EKATERINA NOVIKOVA	{"email": "novikova-ekaterina081975@postgrespro.ru", "phone": "+70540166195"}
0005435299822	E44640	2441 389898	OLGA LAZAREVA	{"email": "olga-lazareva-26051990@postgrespro.ru", "phone": "+70617091189"}
0005435299823	88BEF3	9661 756890	NIKOLAY KOZLOV	{"phone": "+70843379601"}
0005435299824	88BEF3	3502 229817	VALENTIN GERASIMOV	{"phone": "+70373065974"}
0005435299825	88BEF3	5631 011404	SERGEY SERGEEV	{"email": "sergeysergeev021981@postgrespro.ru", "phone": "+70615297005"}
0005435299826	061281	7342 915255	EVGENIY FEDOROV	{"phone": "+70710821327"}
0005435299827	2F5147	3767 999853	ALEKSANDR ILIN	{"email": "ilin.aleksandr_011981@postgrespro.ru", "phone": "+70162733121"}
0005435299828	2F5147	2097 379726	LIDIYA SERGEEVA	{"phone": "+70758245021"}
0005435299829	DEF891	1170 042040	VALENTINA TIMOFEEVA	{"email": "valentina-timofeeva.111981@postgrespro.ru", "phone": "+70714429012"}
0005435299830	9B2B0C	3900 379993	SERGEY ZAYCEV	{"phone": "+70943917197"}
0005435299831	9B2B0C	6282 510137	DENIS SIDOROV	{"phone": "+70055489141"}
0005435299832	85048D	6881 958761	ALEKSANDR ABRAMOV	{"phone": "+70352906377"}
0005435299833	85048D	6394 112948	VITALIY BONDARENKO	{"email": "vitaliybondarenko-051976@postgrespro.ru", "phone": "+70853671413"}
0005435299834	596794	3929 017872	ILYA MOROZOV	{"phone": "+70054837654"}
0005435299835	095819	6463 382301	LYUBOV KARPOVA	{"phone": "+70572005673"}
0005435299836	BE2356	0129 191394	ANATOLIY KAZAKOV	{"email": "kazakov_anatoliy.22011971@postgrespro.ru", "phone": "+70681011800"}
0005435299837	DF4A40	6299 185574	IVAN GUSEV	{"email": "ivan_gusev101969@postgrespro.ru", "phone": "+70955786666"}
0005435299838	20F171	9371 409383	EGOR NIKOLAEV	{"phone": "+70101370498"}
0005435299839	803AB6	4456 300614	BORIS NIKITIN	{"phone": "+70532599156"}
0005435299840	803AB6	2772 949101	LYUBOV ILINA	{"email": "ilinal-111970@postgrespro.ru", "phone": "+70411880989"}
0005435299841	DDF293	5353 893450	ILYA TARASOV	{"email": "i_tarasov_14081974@postgrespro.ru", "phone": "+70096199529"}
0005435299842	DDF293	8578 716116	ALEKSANDR SMIRNOV	{"email": "smirnov-a051964@postgrespro.ru", "phone": "+70433380878"}
0005435299843	494418	2616 602757	MAKSIM ZAKHAROV	{"email": "zakharov-maksim_1962@postgrespro.ru", "phone": "+70624884195"}
0005435299844	494418	0477 194212	NATALYA DANILOVA	{"email": "natalya-danilova-061974@postgrespro.ru", "phone": "+70738228548"}
0005435299845	494418	5523 352264	PAVEL KUZNECOV	{"email": "kuznecovpavel101972@postgrespro.ru", "phone": "+70275415722"}
0005435299846	416E7A	1682 974871	BORIS TIKHONOV	{"phone": "+70928323066"}
0005435299847	394F74	0945 804613	STANISLAV PAVLOV	{"phone": "+70858858509"}
0005435299848	394F74	1792 046956	VLADISLAV MATVEEV	{"email": "vladislav_matveev_12021978@postgrespro.ru", "phone": "+70256997630"}
0005435299849	E496FD	4341 292818	DMITRIY KARPOV	{"phone": "+70762658304"}
0005435299850	EE5C9D	3094 929278	MARINA KUZNECOVA	{"phone": "+70419793914"}
0005435299851	C3FD2F	9828 260276	NIKOLAY GRIGOREV	{"email": "nikolay-grigorev_051966@postgrespro.ru", "phone": "+70503736758"}
0005435299852	7124CD	5195 331386	ANTON DAVYDOV	{"email": "a_davydov09091982@postgrespro.ru", "phone": "+70084088734"}
0005435299853	E071E5	3010 070420	VLADIMIR KUZNECOV	{"email": "vladimir.kuznecov121971@postgrespro.ru", "phone": "+70082435604"}
0005435299854	E071E5	6807 017928	ANNA ISAEVA	{"email": "anna-isaeva-29111975@postgrespro.ru", "phone": "+70496168937"}
0005435299855	3F7A46	0290 764479	GENNADIY KOZLOV	{"phone": "+70463080729"}
0005435299856	24AD21	9934 285184	ELENA MAKAROVA	{"email": "emakarova11011966@postgrespro.ru", "phone": "+70156907666"}
0005435299857	60885B	5925 098721	EKATERINA DENISOVA	{"email": "denisova-ekaterina091967@postgrespro.ru", "phone": "+70568434457"}
0005435299858	60885B	5134 697327	SERGEY ZAKHAROV	{"email": "szakharov1965@postgrespro.ru", "phone": "+70700196860"}
0005435299859	246081	6870 424265	KSENIYA ZAKHAROVA	{"email": "zakharova.kseniya_021976@postgrespro.ru", "phone": "+70837440587"}
0005435299860	ABD40B	7543 485418	LYUDMILA MOROZOVA	{"email": "lyudmila.morozova.1968@postgrespro.ru", "phone": "+70972576743"}
0005435299861	ABD40B	4435 172921	ALEKSANDR KUZMIN	{"phone": "+70378058661"}
0005435299862	98E88C	5035 753796	MIKHAIL ZAYCEV	{"phone": "+70491747795"}
0005435299863	98E88C	3927 175919	NINA BOGDANOVA	{"email": "nina-bogdanova.24031973@postgrespro.ru", "phone": "+70175677285"}
0005435299864	756BBF	8109 493566	MIKHAIL KULIKOV	{"phone": "+70319715022"}
0005435299865	C6776D	5472 683161	TAMARA TIKHONOVA	{"email": "tamara.tikhonova-29111965@postgrespro.ru", "phone": "+70679000659"}
0005435299866	C6776D	0038 088786	IGOR FROLOV	{"email": "frolovigor-05041978@postgrespro.ru", "phone": "+70213774336"}
0005435299867	482985	8680 282205	VALENTINA IVANOVA	{"phone": "+70734025903"}
0005435299868	583A97	5865 866758	KONSTANTIN BONDARENKO	{"phone": "+70965771436"}
0005435299869	8C1638	5732 880583	ANTONINA KOLESNIKOVA	{"phone": "+70095405834"}
0005435299870	8C1638	2750 200849	NATALYA VASILEVA	{"email": "natalya_vasileva20031979@postgrespro.ru", "phone": "+70335331940"}
0005435299871	5E855E	2124 312619	ANNA KUDRYASHOVA	{"phone": "+70037400663"}
0005435299872	EF00FC	4294 537524	ALEKSANDR GORBUNOV	{"email": "gorbunov.a_21011965@postgrespro.ru", "phone": "+70174256221"}
0005435299873	13C67D	5064 198863	YULIYA SOLOVEVA	{"phone": "+70053265391"}
0005435299874	13C67D	9540 053129	SERGEY NOVIKOV	{"phone": "+70552325461"}
0005435299875	E138EB	6337 590300	NIKOLAY SEMENOV	{"phone": "+70839702385"}
0005435299876	B8EDB2	8802 228721	RAISA SIDOROVA	{"email": "sidorova_raisa.06071969@postgrespro.ru", "phone": "+70722555766"}
0005435299877	E5E52F	1473 751054	ILYA KUZNECOV	{"email": "kuznecovi_091972@postgrespro.ru", "phone": "+70144344609"}
0005435299878	712F43	8179 651806	NATALIYA ANTONOVA	{"email": "antonovan_1967@postgrespro.ru", "phone": "+70928490375"}
0005435299879	3BA71B	2101 261221	SERGEY BORISOV	{"email": "borisov-s-081979@postgrespro.ru", "phone": "+70088963059"}
0005435299880	3BA71B	6164 579244	EKATERINA ANDREEVA	{"phone": "+70764307284"}
0005435299881	2AC71F	6279 945604	ALEKSANDR MAKAROV	{"phone": "+70447129581"}
0005435299882	5438A8	8919 570231	EKATERINA ORLOVA	{"phone": "+70949632766"}
0005435299883	F88CD2	9534 863871	GALINA NAZAROVA	{"email": "nazarova.galina-091974@postgrespro.ru", "phone": "+70244040031"}
0005435299884	50FB4A	5471 442724	NATALYA LOGINOVA	{"phone": "+70142448753"}
0005435299885	466D61	3590 305411	VALERIY VOLKOV	{"phone": "+70788607564"}
0005435299886	422224	0231 106082	VLADIMIR MAKSIMOV	{"phone": "+70549950165"}
0005435299887	3EEF9B	4396 457093	IGOR SAVELEV	{"email": "igor-savelev1976@postgrespro.ru", "phone": "+70904610212"}
0005435299888	95E36E	7444 289292	LIDIYA DAVYDOVA	{"phone": "+70310769822"}
0005435299889	C075F7	5688 515276	ALEKSANDR KONOVALOV	{"phone": "+70328016012"}
0005435299890	F0F74F	6933 440820	TATYANA DAVYDOVA	{"phone": "+70121660615"}
0005435299891	F0F74F	0700 094511	NADEZHDA KOVALEVA	{"email": "kovaleva_n-1981@postgrespro.ru", "phone": "+70154980206"}
0005435299892	AC5FA1	4350 396749	PAVEL NAZAROV	{"phone": "+70914594921"}
0005435299893	8EC110	4004 886127	DARYA ANISIMOVA	{"phone": "+70546488297"}
0005435299894	15779F	0361 661470	DMITRIY SHEVCHENKO	{"phone": "+70339929225"}
0005435299895	685FEE	7622 643642	IVAN KRASNOV	{"phone": "+70203323791"}
0005435299896	685FEE	1463 320333	VALERIY SOKOLOV	{"email": "v-sokolov15041976@postgrespro.ru", "phone": "+70919208630"}
0005435299897	2295C2	8272 106205	ELINA NIKOLAEVA	{"email": "nikolaeva.elina.16121959@postgrespro.ru", "phone": "+70346725611"}
0005435299898	2295C2	2134 344524	ALEKSEY PETROV	{"email": "petrovaleksey.1970@postgrespro.ru", "phone": "+70538469813"}
0005435299899	AA20AB	8103 737047	ELENA NIKITINA	{"email": "nikitinae_111966@postgrespro.ru", "phone": "+70429835611"}
0005435299900	AA20AB	4421 523971	IVAN ORLOV	{"email": "i-orlov.1980@postgrespro.ru", "phone": "+70446425271"}
0005435299901	BC6294	9218 799624	ANNA KUZNECOVA	{"email": "a-kuznecova-111979@postgrespro.ru", "phone": "+70989375763"}
0005435299902	DA28E3	5003 545542	OLGA PAVLOVA	{"phone": "+70103145136"}
0005435299903	DA28E3	0609 017693	NADEZHDA KOMAROVA	{"phone": "+70706384105"}
0005435299904	09F939	7601 273041	POLINA SMIRNOVA	{"email": "smirnova-polina.04061970@postgrespro.ru", "phone": "+70405733448"}
0005435299905	09F939	6684 405660	ANDREY NIKITIN	{"phone": "+70382182605"}
0005435299906	D4E20B	5279 365331	MARIYA DANILOVA	{"phone": "+70228404853"}
0005435299907	C898A4	3152 056841	TATYANA PETROVA	{"email": "t_petrova-09081980@postgrespro.ru", "phone": "+70639211720"}
0005435299908	C898A4	9716 060148	PAVEL KUZMIN	{"email": "kuzminp.1974@postgrespro.ru", "phone": "+70282673019"}
0005435299909	C898A4	1805 532066	IRINA SERGEEVA	{"phone": "+70308463672"}
0005435299910	C898A4	4419 690687	TAMARA TIMOFEEVA	{"email": "t-timofeeva29041976@postgrespro.ru", "phone": "+70429734040"}
0005435299911	4352EF	6577 306185	VALERIYA KOVALEVA	{"email": "kovaleva.valeriya-04031975@postgrespro.ru", "phone": "+70862598164"}
0005435299912	6B5ABC	8695 959706	MARIYA PETROVA	{"email": "petrova.m_1975@postgrespro.ru", "phone": "+70510311569"}
0005435299913	879934	0284 195549	GALINA ANDREEVA	{"email": "andreeva.g_07091972@postgrespro.ru", "phone": "+70535037330"}
0005435299914	D3E106	3976 544478	VIKTOR DENISOV	{"email": "v-denisov_23111969@postgrespro.ru", "phone": "+70823711973"}
0005435299915	D3E106	0671 303567	VALERIY MAKAROV	{"email": "v-makarov-1959@postgrespro.ru", "phone": "+70494103450"}
0005435299916	A980D3	0433 029820	ULYANA STEPANOVA	{"email": "stepanovaulyana_1968@postgrespro.ru", "phone": "+70638747387"}
0005435299917	A980D3	5942 088597	LYUDMILA NESTEROVA	{"email": "lyudmila.nesterova-1970@postgrespro.ru", "phone": "+70020377694"}
0005435299918	3F4CA1	2185 110917	ANNA SAVELEVA	{"phone": "+70061617640"}
0005435299919	3F4CA1	3308 046678	OLGA NAZAROVA	{"phone": "+70893937991"}
0005435299920	560C2C	8167 378080	VALENTIN KOROLEV	{"email": "korolev_v101981@postgrespro.ru", "phone": "+70310630723"}
0005435299921	441C3A	6205 757096	EKATERINA CHERNOVA	{"email": "chernova.e_061964@postgrespro.ru", "phone": "+70818154237"}
0005435299922	441C3A	1409 384037	MARIYA BORISOVA	{"email": "mariya-borisova.091980@postgrespro.ru", "phone": "+70149820856"}
0005435299923	0AC7E5	5168 256294	IRINA BORISOVA	{"email": "borisovairina.20091968@postgrespro.ru", "phone": "+70634900265"}
0005435302119	E0019C	9214 176041	MATVEY KUZNECOV	{"phone": "+70131110227"}
0005435302120	8825E0	2328 771556	IRINA STEPANOVA	{"phone": "+70703041640"}
0005435302121	7A5BF7	9914 299759	EVGENIY ABRAMOV	{"phone": "+70541911125"}
0005435302122	340ADC	2572 267919	GALINA NAUMOVA	{"email": "g_naumova_1975@postgrespro.ru", "phone": "+70347575335"}
0005435302123	340ADC	2203 830890	ALEKSANDR FEDOTOV	{"phone": "+70249611918"}
0005435302124	CD8848	7592 365062	YURIY SMIRNOV	{"phone": "+70962258722"}
0005435302125	CD8848	0506 553396	EVGENIY SOKOLOV	{"phone": "+70925551529"}
0005435302126	6908A1	5607 615020	MARINA FROLOVA	{"email": "frolova-m_1959@postgrespro.ru", "phone": "+70125528553"}
0005435302127	6908A1	7317 934963	MARINA LAZAREVA	{"email": "lazareva-m-19041965@postgrespro.ru", "phone": "+70433138941"}
0005435302128	F60280	4331 216293	SAMVEL PAVLOV	{"email": "pavlov-s-1972@postgrespro.ru", "phone": "+70175689205"}
0005435302129	F60280	2587 993004	VALENTINA KUZNECOVA	{"phone": "+70261973430"}
0005435302130	C5A7D9	5031 033319	VERA NIKOLAEVA	{"phone": "+70405686507"}
0005435302131	3B9B1F	1602 765164	VALENTINA GORBUNOVA	{"phone": "+70654839910"}
0005435302132	3B9B1F	2064 285345	SVETLANA EFREMOVA	{"email": "efremova.svetlana.1973@postgrespro.ru", "phone": "+70029659860"}
0005435302133	C1E7A0	1094 364761	EVGENIY POPOV	{"phone": "+70218729806"}
0005435302134	527E1A	0297 664624	SVETLANA VOLKOVA	{"email": "volkovas_121974@postgrespro.ru", "phone": "+70583336474"}
0005435302135	527E1A	4143 147364	SEMEN KRASNOV	{"email": "s-krasnov_061971@postgrespro.ru", "phone": "+70450745377"}
0005435302136	A302E8	7932 922835	EKATERINA SMIRNOVA	{"phone": "+70086892753"}
0005435302137	17E40D	1527 721087	VIKTOR ORLOV	{"phone": "+70414210763"}
0005435302138	BD7A3B	7943 020048	DIANA KOVALEVA	{"email": "kovaleva_d_1972@postgrespro.ru", "phone": "+70509665630"}
0005435302139	A36F70	8100 980972	IRINA GERASIMOVA	{"phone": "+70884028366"}
0005435302140	88814D	4429 810051	DANIIL MIRONOV	{"email": "daniilmironov.061983@postgrespro.ru", "phone": "+70671231366"}
0005435302141	88814D	7739 284327	ANTONINA BOGDANOVA	{"phone": "+70799385585"}
0005435302142	FE3301	2867 364674	ELENA TIMOFEEVA	{"phone": "+70821195940"}
0005435302143	FE3301	4566 613876	SOFYA PAVLOVA	{"email": "sofya.pavlova-1975@postgrespro.ru", "phone": "+70975001796"}
0005435302144	346CEE	6885 558872	BORIS SIDOROV	{"phone": "+70551795202"}
0005435302145	E4348C	8666 640526	IVAN KOZLOV	{"phone": "+70787568046"}
0005435302146	847172	7425 162167	ZINAIDA GERASIMOVA	{"phone": "+70143243217"}
0005435302147	22F256	2368 000228	YURIY SMIRNOV	{"phone": "+70931796424"}
0005435302148	22F256	3551 792145	LYUBOV SOKOLOVA	{"phone": "+70921527461"}
0005435302149	DF96C2	9130 847745	NIKOLAY KUZNECOV	{"email": "kuznecovn31101967@postgrespro.ru", "phone": "+70723013550"}
0005435302150	30E625	6799 898040	ELIZAVETA SMIRNOVA	{"email": "smirnova_e_1964@postgrespro.ru", "phone": "+70747727682"}
0005435302151	30E625	9077 628945	ILYA NIKITIN	{"phone": "+70719245544"}
0005435302152	440047	1867 882069	GENNADIY DENISOV	{"phone": "+70109762862"}
0005435302153	01C763	8525 716094	NATALYA DANILOVA	{"email": "danilova_natalya.1968@postgrespro.ru", "phone": "+70753577763"}
0005435302154	01C763	3519 546880	KRISTINA KOVALEVA	{"email": "kkovaleva.1965@postgrespro.ru", "phone": "+70100751401"}
0005435302155	381C38	5885 087535	VYACHESLAV MAKAROV	{"email": "vyacheslavmakarov_31071964@postgrespro.ru", "phone": "+70951489781"}
0005435302156	381C38	7162 321401	SERGEY SEMENOV	{"email": "s_semenov-1967@postgrespro.ru", "phone": "+70177124121"}
0005435302157	31C10F	1565 650726	ALEKSEY ORLOV	{"phone": "+70571595441"}
0005435302158	C22023	7894 116456	LIDIYA NOVIKOVA	{"phone": "+70240405657"}
0005435302159	921CE6	1306 105807	VASILIY NIKITIN	{"email": "vasiliy.nikitin.11091974@postgrespro.ru", "phone": "+70890735764"}
0005435302160	749507	9382 453634	LARISA STEPANOVA	{"email": "stepanovalarisa.1965@postgrespro.ru", "phone": "+70017993092"}
0005435302161	761B92	2443 840426	GALINA BOGDANOVA	{"email": "galina.bogdanova.1972@postgrespro.ru", "phone": "+70705207676"}
0005435302162	761B92	1380 731490	ANNA FOMINA	{"phone": "+70795476420"}
0005435302163	761B92	0650 708780	VIKTOR DENISOV	{"email": "viktor.denisov1960@postgrespro.ru", "phone": "+70536054037"}
0005435302164	5564D4	0632 501187	ELENA NAZAROVA	{"email": "enazarova011979@postgrespro.ru", "phone": "+70160484454"}
0005435302165	108286	4189 797445	EKATERINA NIKOLAEVA	{"phone": "+70730377054"}
0005435302166	108286	8933 765409	ALEKSANDR MIKHAYLOV	{"email": "aleksandr-mikhaylov_17031984@postgrespro.ru", "phone": "+70717102933"}
0005435302167	BE5C8B	0153 252695	YANA BORISOVA	{"email": "borisovayana.101970@postgrespro.ru", "phone": "+70959612916"}
0005435302168	A1577E	5817 654686	TATYANA VASILEVA	{"phone": "+70766581040"}
0005435302169	2FD351	6566 848682	ELENA MELNIKOVA	{"email": "elena.melnikova071974@postgrespro.ru", "phone": "+70784262359"}
0005435302170	0DB480	4383 993284	NADEZHDA FILIPPOVA	{"email": "n-filippova_1978@postgrespro.ru", "phone": "+70826910002"}
0005435302171	0DB480	4355 703276	ALEVTINA EFREMOVA	{"phone": "+70048491837"}
0005435302172	5B3F1A	8394 112967	LYUDMILA GUSEVA	{"phone": "+70656095814"}
0005435302173	D3D422	7525 594321	ZINAIDA PAVLOVA	{"phone": "+70184601466"}
0005435302174	DE3AC6	8297 793399	OLGA FILATOVA	{"phone": "+70093058887"}
0005435302175	DE3AC6	4725 945817	OLEG MAKAROV	{"phone": "+70100016508"}
0005435302176	4F360F	1193 280207	EVGENIY ZAYCEV	{"email": "evgeniy_zaycev-1969@postgrespro.ru", "phone": "+70102795666"}
0005435302177	3AA5B7	3981 576827	MARIYA RYABOVA	{"phone": "+70712958848"}
0005435302178	3AA5B7	2990 466831	ANNA KUZNECOVA	{"email": "akuznecova.17061975@postgrespro.ru", "phone": "+70821803885"}
0005435302179	0F1065	6237 413816	KRISTINA DMITRIEVA	{"phone": "+70994554288"}
0005435302180	159997	7538 084786	ANGELINA BORISOVA	{"email": "angelina.borisova-14121975@postgrespro.ru", "phone": "+70734747117"}
0005435302181	159997	7111 958502	ANVAR ROMANOV	{"email": "romanovanvar.1981@postgrespro.ru", "phone": "+70626908591"}
0005435302182	B8AC88	7305 010499	ANATOLIY PETROV	{"email": "petrovanatoliy-1964@postgrespro.ru", "phone": "+70062761246"}
0005435302183	B8AC88	5277 441227	OLGA ZAKHAROVA	{"email": "zakharova.o1967@postgrespro.ru", "phone": "+70734712316"}
0005435302184	B8AC88	4388 533708	ANDREY KOROLEV	{"phone": "+70806591203"}
0005435302185	6DE249	2987 598797	SVETLANA OSIPOVA	{"phone": "+70459720915"}
0005435302186	6DE249	6269 845164	IRINA ANDREEVA	{"email": "i-andreeva-1970@postgrespro.ru", "phone": "+70729568361"}
0005435302187	3BF474	9425 148112	OLGA PETROVA	{"email": "petrova.o1964@postgrespro.ru", "phone": "+70674346438"}
0005435302188	3BF474	4732 925065	VITALIY SIDOROV	{"phone": "+70299471443"}
0005435302189	299747	4909 403875	ELENA FEDOROVA	{"phone": "+70508898198"}
0005435302190	540D99	4824 510192	ARTUR SEMENOV	{"phone": "+70311878976"}
0005435302191	B38459	2613 090702	OLGA FOMINA	{"email": "o_fomina.061968@postgrespro.ru", "phone": "+70293251045"}
0005435302192	B38459	2352 683005	GALINA MAKAROVA	{"email": "makarova-g_05031948@postgrespro.ru", "phone": "+70975592233"}
0005435302193	B38459	9798 315626	ALEKSANDR SHEVCHENKO	{"email": "shevchenko.aleksandr_071969@postgrespro.ru", "phone": "+70682841838"}
0005435302194	3B01B7	3983 516894	ANDREY PETROV	{"email": "andrey_petrov31101980@postgrespro.ru", "phone": "+70570515505"}
0005435302195	9EDE3B	6972 239224	OLEG CHERNOV	{"email": "chernov_oleg28011962@postgrespro.ru", "phone": "+70116772051"}
0005435302196	9EDE3B	6502 300165	VALENTINA EGOROVA	{"email": "vegorova.111979@postgrespro.ru", "phone": "+70892755816"}
0005435302197	B4B9A4	4700 198292	NATALYA KOZLOVA	{"email": "kozlova.n.1967@postgrespro.ru", "phone": "+70508966180"}
0005435302198	B4B9A4	3734 847894	IRINA IVANOVA	{"phone": "+70212674885"}
0005435302199	CA705E	7685 529098	KSENIYA VASILEVA	{"phone": "+70056802510"}
0005435302200	CA705E	5295 305050	ALEKSANDR ANDREEV	{"email": "andreevaleksandr.10071968@postgrespro.ru", "phone": "+70171375546"}
0005435302201	CA705E	9181 739455	SERGEY ANDREEV	{"phone": "+70861530753"}
0005435302202	C485E2	4487 761706	YURIY ANTONOV	{"email": "antonov.y-1971@postgrespro.ru", "phone": "+70981509916"}
0005435302203	C485E2	7225 664335	ILYA SHEVCHENKO	{"phone": "+70882659663"}
0005435302204	B1016F	7793 259260	YULIYA ISAEVA	{"phone": "+70519779014"}
0005435302205	7A1B44	9411 967268	NIKOLAY NAUMOV	{"phone": "+70718283599"}
0005435302206	7D3E83	8238 346255	ALINA SIDOROVA	{"phone": "+70620171419"}
0005435302207	7D3E83	0597 619939	EKATERINA SEMENOVA	{"phone": "+70162639574"}
0005435302208	5B4AEB	9107 470358	LIDIYA KUZNECOVA	{"email": "kuznecova_l_071968@postgrespro.ru", "phone": "+70922535970"}
0005435302209	C3EE2B	9130 916571	VASILIY FROLOV	{"email": "frolov.v30051971@postgrespro.ru", "phone": "+70724785113"}
0005435302210	AE2604	1738 078514	OLGA BORISOVA	{"email": "o_borisova-1973@postgrespro.ru", "phone": "+70647816270"}
0005435302211	B77D8D	7951 350253	TATYANA EFIMOVA	{"phone": "+70269356224"}
0005435302212	3E89A6	8501 328045	NIKOLAY IVANOV	{"email": "ivanov_n-06061981@postgrespro.ru", "phone": "+70620382814"}
0005435302213	24B483	2760 303145	GALINA ZOTOVA	{"email": "zotovagalina.1966@postgrespro.ru", "phone": "+70951292721"}
0005435302214	BA5326	4069 803283	ILDAR MIRONOV	{"email": "ildar-mironov_1952@postgrespro.ru", "phone": "+70956701348"}
0005435302215	BA5326	7105 124159	VLADIMIR OSIPOV	{"phone": "+70020740803"}
0005435302216	F67D3C	4072 674625	NIKITA MIRONOV	{"phone": "+70301779934"}
0005435302217	7D170A	1736 978588	SVETLANA MEDVEDEVA	{"phone": "+70181595384"}
0005435302218	D09C95	0689 763778	LIDIYA DAVYDOVA	{"email": "lidiya.davydova-1978@postgrespro.ru", "phone": "+70554817772"}
0005435302219	01ADEA	3252 866976	ANASTASIYA GERASIMOVA	{"phone": "+70379792818"}
0005435302220	685F87	0788 686494	VLADIMIR FEDOTOV	{"phone": "+70409755435"}
0005435302221	B2A27E	9516 871624	DMITRIY NAUMOV	{"phone": "+70620072031"}
0005435302222	B2A27E	2756 265166	YURIY OSIPOV	{"phone": "+70588157386"}
0005435302223	12B250	2028 472309	LYUBOV YAKOVLEVA	{"phone": "+70174281918"}
0005435302224	F6772C	7424 687669	MIKHAIL MAKAROV	{"email": "m-makarov021971@postgrespro.ru", "phone": "+70634105970"}
0005435302225	767AF9	5004 804343	ALENA GUSEVA	{"phone": "+70604744977"}
0005435302226	6EB5E5	4980 538263	ALEKSEY MAKAROV	{"email": "aleksey-makarov1967@postgrespro.ru", "phone": "+70125738993"}
0005435302227	031412	2126 941950	ELENA ALEKSEEVA	{"email": "alekseeva-elena-1974@postgrespro.ru", "phone": "+70463249530"}
0005435302228	031412	3966 044325	KLAVDIYA PAVLOVA	{"phone": "+70726264916"}
0005435302229	9A73DE	0385 910133	SERGEY ZHUKOV	{"phone": "+70301266727"}
0005435302230	DC2F11	1375 319739	ROMAN SHEVCHENKO	{"email": "r_shevchenko_20031966@postgrespro.ru", "phone": "+70300311513"}
0005435302231	D122D0	8177 021688	VERONIKA YAKOVLEVA	{"phone": "+70144488276"}
0005435302232	564ED7	3554 516224	TATYANA ZHURAVLEVA	{"email": "t.zhuravleva_051995@postgrespro.ru", "phone": "+70983266046"}
0005435302233	564ED7	4345 764538	YURIY IVANOV	{"email": "y_ivanov-13111975@postgrespro.ru", "phone": "+70421457285"}
0005435302234	564ED7	8150 496802	YURIY MAKSIMOV	{"phone": "+70988451675"}
0005435302235	5B51DB	1468 158374	VLADIMIR KUZMIN	{"email": "v_kuzmin_25111974@postgrespro.ru", "phone": "+70194899539"}
0005435302236	EBB083	4417 655676	ANNA FILATOVA	{"email": "a.filatova-1965@postgrespro.ru", "phone": "+70007872009"}
0005435302237	7A781A	4498 007362	NADEZHDA KUZNECOVA	{"phone": "+70866299837"}
0005435302238	7A781A	0074 232934	KARINA NIKOLAEVA	{"phone": "+70926470436"}
0005435302239	6F5A24	5265 363421	ANDREY PETROV	{"email": "petrov-a.1977@postgrespro.ru", "phone": "+70243129773"}
0005435302240	6F5A24	0053 060987	YURIY MOROZOV	{"email": "morozovy-1974@postgrespro.ru", "phone": "+70678357484"}
0005435302241	7E04C9	2805 714376	OLEG POPOV	{"email": "olegpopov.031972@postgrespro.ru", "phone": "+70848675828"}
0005435302242	7C181C	9999 979738	NATALYA KUZNECOVA	{"email": "kuznecova.natalya-011972@postgrespro.ru", "phone": "+70097742996"}
0005435302243	7C181C	8618 098557	ALEKSANDR IVANOV	{"phone": "+70817652774"}
0005435302244	7C181C	8319 298084	VALENTINA CHERNOVA	{"phone": "+70048187117"}
0005435302245	EF743B	8843 385167	NATALYA KISELEVA	{"phone": "+70957551843"}
0005435302246	896C0D	9270 936598	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov_1963@postgrespro.ru", "phone": "+70454664509"}
0005435302247	896C0D	3383 833393	ELENA KONOVALOVA	{"email": "elena-konovalova-1966@postgrespro.ru", "phone": "+70072887434"}
0005435302248	14793B	5807 328013	LILIYA MIKHAYLOVA	{"email": "mikhaylova-l-17061967@postgrespro.ru", "phone": "+70470485169"}
0005435302249	962976	7328 105370	VALENTINA MAKSIMOVA	{"email": "valentina-maksimova061973@postgrespro.ru", "phone": "+70768074462"}
0005435302250	63F960	6515 736706	SERGEY NIKITIN	{"email": "s_nikitin091974@postgrespro.ru", "phone": "+70153092115"}
0005435302251	63F960	6757 206961	MARINA VASILEVA	{"phone": "+70471005314"}
0005435302252	63F960	7829 870974	VALENTINA GERASIMOVA	{"phone": "+70355798780"}
0005435302253	C8DC94	2693 940369	NAIL SEMENOV	{"email": "n.semenov_16101974@postgrespro.ru", "phone": "+70368696696"}
0005435302254	E32B5F	5974 561294	ALEKSANDRA DAVYDOVA	{"email": "adavydova-29101969@postgrespro.ru", "phone": "+70525864132"}
0005435302255	E32B5F	9751 851332	RINAT RODIONOV	{"email": "rodionov-rinat-1958@postgrespro.ru", "phone": "+70584216177"}
0005435302256	5F3330	7384 787831	VLADIMIR MEDVEDEV	{"email": "v-medvedev-121975@postgrespro.ru", "phone": "+70193157364"}
0005435302257	5F3330	8408 159731	LYUDMILA IVANOVA	{"phone": "+70795171763"}
0005435302258	7582FD	6661 401508	ELENA VASILEVA	{"email": "vasileva_elena.1964@postgrespro.ru", "phone": "+70245997640"}
0005435302259	C0D51F	6117 642639	ANNA MALYSHEVA	{"email": "malyshevaanna-17051974@postgrespro.ru", "phone": "+70658938637"}
0005435302260	ADB9B5	2263 232986	KIRILL ZAKHAROV	{"email": "zakharov.k-121979@postgrespro.ru", "phone": "+70448026664"}
0005435302261	8C013D	1901 390330	EVGENIY MAKSIMOV	{"email": "evgeniymaksimov-07041973@postgrespro.ru", "phone": "+70771986369"}
0005435302262	8C013D	7928 716456	KLAVDIYA MELNIKOVA	{"email": "k_melnikova.1982@postgrespro.ru", "phone": "+70933540362"}
0005435302263	D12C4E	5573 245269	YULIYA KOLESNIKOVA	{"email": "ykolesnikova.1971@postgrespro.ru", "phone": "+70405644274"}
0005435302264	D12C4E	5883 313586	VYACHESLAV GRIGOREV	{"email": "grigorev_v1973@postgrespro.ru", "phone": "+70522331722"}
0005435302265	96D0E5	6248 709460	VLADISLAV SCHERBAKOV	{"phone": "+70155787113"}
0005435302266	32BEED	7236 930818	ARTEM YAKOVLEV	{"email": "yakovlev.a-04121971@postgrespro.ru", "phone": "+70691989455"}
0005435302267	0F07BB	6847 938723	LILIYA BELOVA	{"email": "belova.liliya.18011980@postgrespro.ru", "phone": "+70361826719"}
0005435302268	D333DA	3974 313385	LYUDMILA DMITRIEVA	{"phone": "+70592748776"}
0005435302269	19490F	8448 539279	VALENTINA ORLOVA	{"email": "valentinaorlova-111961@postgrespro.ru", "phone": "+70351805591"}
0005435302270	19490F	4069 152160	VLADISLAV FROLOV	{"phone": "+70753005247"}
0005435302271	FA4BD7	9320 703276	LYUBOV MARTYNOVA	{"email": "lyubovmartynova20021978@postgrespro.ru", "phone": "+70404963837"}
0005435302272	FA4BD7	4851 665980	NADEZHDA FROLOVA	{"email": "nadezhda_frolova_061970@postgrespro.ru", "phone": "+70360813320"}
0005435302273	C1E1AA	5514 349542	OLGA ZAKHAROVA	{"phone": "+70497523303"}
0005435302274	33E44F	4577 882756	KSENIYA KOMAROVA	{"email": "kseniya.komarova121982@postgrespro.ru", "phone": "+70153750482"}
0005435302275	88F050	8421 678765	LYUDMILA KONDRATEVA	{"phone": "+70835715146"}
0005435302276	88F050	3551 187553	NINA ABRAMOVA	{"phone": "+70157397051"}
0005435302277	88F050	5932 442927	OLGA KARPOVA	{"phone": "+70033651999"}
0005435302278	DE451F	5074 645560	ALEKSANDR KUZNECOV	{"phone": "+70808172210"}
0005435302279	BC0BF0	4390 411261	ALEKSANDR MOROZOV	{"email": "morozov_a19071962@postgrespro.ru", "phone": "+70051577746"}
0005435302280	24A5CC	5024 145094	VIKTOR VLASOV	{"email": "vlasov_v-07011966@postgrespro.ru", "phone": "+70361050481"}
0005435302281	24A5CC	6800 972577	VADIM ZAYCEV	{"phone": "+70531872770"}
0005435302282	4E3144	6808 954874	SVETLANA IVANOVA	{"phone": "+70986267426"}
0005435302283	D3FC6C	4119 239070	LIDIYA DMITRIEVA	{"email": "l-dmitrieva04021976@postgrespro.ru", "phone": "+70337570192"}
0005435302284	D3FC6C	1679 667293	LYUDMILA FILIPPOVA	{"email": "filippova.lyudmila-1969@postgrespro.ru", "phone": "+70679391394"}
0005435302285	D3FC6C	0778 379731	OKSANA OVCHINNIKOVA	{"phone": "+70739427557"}
0005435302286	E65641	9705 984054	NIKOLAY EGOROV	{"phone": "+70316174232"}
0005435302287	E65641	9793 274439	SVETLANA ANTONOVA	{"phone": "+70618598857"}
0005435302288	D4DCCB	3419 626909	ZINAIDA GORBUNOVA	{"email": "gorbunova-zinaida-121962@postgrespro.ru", "phone": "+70473315594"}
0005435302289	751736	9045 998838	YULIYA CHERNOVA	{"email": "chernovayuliya.31071979@postgrespro.ru", "phone": "+70581363895"}
0005435302290	AC1D8B	0931 000067	KRISTINA ANDREEVA	{"email": "kandreeva-04101963@postgrespro.ru", "phone": "+70656105003"}
0005435302291	E6B5B8	8497 970648	NADEZHDA KUZMINA	{"phone": "+70060244899"}
0005435302292	4256EF	5537 113307	EVGENIY ANTONOV	{"phone": "+70357590039"}
0005435302293	065523	4914 956188	ANASTASIYA SIDOROVA	{"email": "a_sidorova-1974@postgrespro.ru", "phone": "+70053833116"}
0005435302294	8BA9F2	4453 610315	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova.tamara_1970@postgrespro.ru", "phone": "+70859162196"}
0005435302295	8BA9F2	3636 323144	GALIYA IVANOVA	{"phone": "+70830852587"}
0005435302296	EF99E0	9179 176777	TALGAT FROLOV	{"email": "talgat-frolov05101968@postgrespro.ru", "phone": "+70104937237"}
0005435302297	EF99E0	1269 456155	ALEKSANDR ORLOV	{"email": "orlovaleksandr_091969@postgrespro.ru", "phone": "+70472814072"}
0005435302298	018C3B	2458 910208	VERA SMIRNOVA	{"email": "v.smirnova_1981@postgrespro.ru", "phone": "+70993973966"}
0005435302299	6C1A47	7653 714630	MARIYA DAVYDOVA	{"email": "davydova.mariya-1971@postgrespro.ru", "phone": "+70580519900"}
0005435302300	883EE2	6020 923394	NIKOLAY GERASIMOV	{"email": "nikolay.gerasimov-1973@postgrespro.ru", "phone": "+70676446453"}
0005435302301	ACB048	6796 815031	SERGEY FROLOV	{"email": "frolov.s.1970@postgrespro.ru", "phone": "+70044017953"}
0005435302302	CC7C89	1117 722688	PETR MELNIKOV	{"email": "p-melnikov-1979@postgrespro.ru", "phone": "+70128267272"}
0005435302303	55FADD	5007 630287	ELENA ANISIMOVA	{"email": "anisimova-e-051980@postgrespro.ru", "phone": "+70959679063"}
0005435302304	55FADD	8601 727444	ANASTASIYA KALININA	{"phone": "+70615214212"}
0005435302305	A7F967	6448 737261	ELENA KOROLEVA	{"email": "koroleva-elena1967@postgrespro.ru", "phone": "+70412341889"}
0005435302306	7E3776	4065 618773	YULIYA NAZAROVA	{"phone": "+70478644779"}
0005435302307	A62999	3559 173760	VYACHESLAV IVANOV	{"email": "vyacheslav-ivanov.1977@postgrespro.ru", "phone": "+70039103743"}
0005435302308	C9373E	2110 467660	VERA SAVELEVA	{"email": "saveleva_vera_061975@postgrespro.ru", "phone": "+70332022577"}
0005435302309	291D3D	7903 108959	VIKTOR PETROV	{"email": "viktor_petrov011983@postgrespro.ru", "phone": "+70755291500"}
0005435302310	D267B8	0560 973881	SVETLANA NAZAROVA	{"email": "nazarova.svetlana_091974@postgrespro.ru", "phone": "+70184672737"}
0005435302311	688DA5	3664 685913	SERGEY MAKSIMOV	{"email": "smaksimov_10051967@postgrespro.ru", "phone": "+70253261372"}
0005435302312	0FBFFE	8838 690774	NATALIYA FILATOVA	{"email": "nfilatova19071976@postgrespro.ru", "phone": "+70137334564"}
0005435302313	5D4245	4306 891990	ELIZAVETA DAVYDOVA	{"phone": "+70833677008"}
0005435302314	5D4245	3766 448293	YURIY VOROBEV	{"email": "vorobev-y.101971@postgrespro.ru", "phone": "+70716163332"}
0005435302315	BDF708	7465 496662	ALEKSANDR ROMANOV	{"phone": "+70010842346"}
0005435302316	2863D4	7318 404138	ELENA KOROLEVA	{"email": "elena-koroleva.1973@postgrespro.ru", "phone": "+70955258690"}
0005435302317	7FD6C9	4328 888604	VIKTORIYA TARASOVA	{"email": "v-tarasova061976@postgrespro.ru", "phone": "+70777058938"}
0005435302318	7FD6C9	5329 763268	ALINA KOVALEVA	{"phone": "+70738647047"}
0005435302319	72B43B	1422 866450	NATALYA KUZMINA	{"email": "natalya_kuzmina_11011964@postgrespro.ru", "phone": "+70830040271"}
0005435302320	72B43B	4376 926488	ANTONINA ZHUKOVA	{"email": "zhukova-antonina_08111964@postgrespro.ru", "phone": "+70719947478"}
0005435302321	9FB1CE	4343 509993	DAMIR YAKOVLEV	{"phone": "+70368812354"}
0005435302322	0B8DDD	5783 331099	LYUDMILA RODIONOVA	{"phone": "+70911190263"}
0005435302323	D43E38	6364 450741	TAMARA IVANOVA	{"email": "t.ivanova071965@postgrespro.ru", "phone": "+70458471785"}
0005435302324	53713C	4159 099853	ALEKSANDR BARANOV	{"phone": "+70765766827"}
0005435302325	8A8015	3398 494201	MIKHAIL PETROV	{"phone": "+70540712836"}
0005435302326	8A8015	4868 521264	ANDREY SCHERBAKOV	{"phone": "+70926273448"}
0005435302327	D911D1	8490 073755	NIKITA ABRAMOV	{"email": "abramovn-101969@postgrespro.ru", "phone": "+70659734645"}
0005435302328	82C13A	0711 025248	VALENTINA KOMAROVA	{"email": "v-komarova121973@postgrespro.ru", "phone": "+70171797154"}
0005435302329	82C13A	3623 871876	VALERIY TARASOV	{"phone": "+70020401127"}
0005435302330	4306E5	6267 662632	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov-03121967@postgrespro.ru", "phone": "+70623326329"}
0005435302331	4306E5	6568 381092	TIMOFEY FEDOROV	{"phone": "+70010693801"}
0005435302332	4306E5	4563 543133	SOFYA NIKOLAEVA	{"phone": "+70701544295"}
0005435302333	3679C3	5237 080353	FATIMA KARPOVA	{"email": "karpova-f-1966@postgrespro.ru", "phone": "+70844525225"}
0005435302334	FE3E5F	8547 586173	VERA STEPANOVA	{"phone": "+70540553736"}
0005435302335	09D681	2408 119396	KLAVDIYA EGOROVA	{"email": "egorova.k16051959@postgrespro.ru", "phone": "+70692950352"}
0005435302336	474281	7832 221306	ALEKSANDR GERASIMOV	{"email": "gerasimov-aleksandr16061983@postgrespro.ru", "phone": "+70094153581"}
0005435302337	5CA34F	3989 716292	GENNADIY RODIONOV	{"phone": "+70479112460"}
0005435304092	F98086	2727 154711	ANDREY KAZAKOV	{"email": "andrey_kazakov.23011974@postgrespro.ru", "phone": "+70336481258"}
0005435304093	F48039	1618 001257	VALERIY ANDREEV	{"email": "andreev_v-13091974@postgrespro.ru", "phone": "+70200156432"}
0005435304094	F48039	1503 316670	OLGA IVANOVA	{"phone": "+70750986682"}
0005435304095	450B21	6481 973170	VIKTOR ABRAMOV	{"phone": "+70233945928"}
0005435304096	DF99F9	8660 052474	SERGEY KISELEV	{"phone": "+70145033788"}
0005435304097	26A8D7	4483 081121	YURIY TIKHONOV	{"email": "tikhonov-y091973@postgrespro.ru", "phone": "+70932345230"}
0005435304098	28F654	9125 080518	ANDREY KOZLOV	{"email": "kozlov-a1961@postgrespro.ru", "phone": "+70482410414"}
0005435304099	1BE097	7708 641460	PETR KUZMIN	{"phone": "+70096011240"}
0005435304100	1BE097	8125 522827	VITALIY GRIGOREV	{"phone": "+70741053439"}
0005435304101	23B4FA	5565 172349	DANIIL SERGEEV	{"email": "d_sergeev.10071971@postgrespro.ru", "phone": "+70896545361"}
0005435304102	23B4FA	7642 871251	ARSENIY BORISOV	{"email": "borisov.arseniy-17111962@postgrespro.ru", "phone": "+70057862717"}
0005435304103	828025	0569 397460	SERGEY ALEKSANDROV	{"phone": "+70167933296"}
0005435304104	9E57AD	4573 794101	ELENA KONDRATEVA	{"email": "kondrateva.elena_22011973@postgrespro.ru", "phone": "+70970145021"}
0005435304105	93BD94	0666 237392	IRINA BARANOVA	{"phone": "+70153580065"}
0005435304106	93BD94	3938 262485	MIKHAIL CHERNOV	{"email": "mikhailchernov_091978@postgrespro.ru", "phone": "+70248923768"}
0005435304107	563A18	3518 193883	VITALIY BELOV	{"email": "v_belov-09011985@postgrespro.ru", "phone": "+70948829768"}
0005435304108	8CB10B	8118 754777	MAKSIM POPOV	{"phone": "+70365910889"}
0005435304109	458F57	9326 126259	OLEG FROLOV	{"phone": "+70408424902"}
0005435304110	458F57	6170 435874	VLADIMIR ABRAMOV	{"phone": "+70512954516"}
0005435304111	90C073	2014 666846	LIDIYA ILINA	{"phone": "+70811290835"}
0005435304112	5C9FF8	7760 055670	TATYANA MIKHAYLOVA	{"phone": "+70979241368"}
0005435304113	1527DC	9697 266205	VALERIYA BELOVA	{"phone": "+70347340215"}
0005435304114	1527DC	0509 028043	EVGENIY POPOV	{"email": "evgeniy-popov.1971@postgrespro.ru", "phone": "+70037835809"}
0005435304115	40ADA0	6046 935406	ELIZAVETA FEDOROVA	{"email": "e_fedorova-27071979@postgrespro.ru", "phone": "+70669099987"}
0005435304116	A2C3C9	7122 655772	FILIPP KUZNECOV	{"phone": "+70600512867"}
0005435304117	6F462F	2857 500152	OLGA ALEKSEEVA	{"phone": "+70595073286"}
0005435304118	BE3256	5633 451836	SERGEY AFANASEV	{"phone": "+70064007465"}
0005435304119	F47246	2383 037652	DMITRIY ORLOV	{"email": "orlov_dmitriy_1981@postgrespro.ru", "phone": "+70357087823"}
0005435304120	237D51	4463 858623	TATYANA AKIMOVA	{"phone": "+70301605813"}
0005435304121	237D51	4379 850145	NINA SEMENOVA	{"phone": "+70751690278"}
0005435304122	77AFC5	6895 049365	SERGEY SMIRNOV	{"phone": "+70369242602"}
0005435304123	77AFC5	3979 659026	ANATOLIY ALEKSEEV	{"phone": "+70678315902"}
0005435304124	F5A4B6	6827 975345	ALEKSEY SIDOROV	{"phone": "+70534575039"}
0005435304125	F5A4B6	9333 767587	VALENTINA EFREMOVA	{"phone": "+70071298315"}
0005435304126	7B71D6	2717 354838	KIRA MAKSIMOVA	{"email": "kira-maksimova071967@postgrespro.ru", "phone": "+70957068862"}
0005435304127	C7A78D	1339 539257	DMITRIY NAUMOV	{"email": "naumov-dmitriy17031973@postgrespro.ru", "phone": "+70148067625"}
0005435304128	DD3840	3236 151723	VERA ALEKSEEVA	{"email": "vera-alekseeva_1977@postgrespro.ru", "phone": "+70872523574"}
0005435304129	DD3840	4265 603641	EKATERINA NOVIKOVA	{"email": "novikova_ekaterina-29011976@postgrespro.ru", "phone": "+70466417259"}
0005435304130	196187	6546 727058	RENAT SOROKIN	{"phone": "+70113514689"}
0005435304131	40B25E	1738 773518	TATYANA NIKITINA	{"email": "tatyananikitina1962@postgrespro.ru", "phone": "+70154556125"}
0005435304132	F2128D	5378 103940	MIKHAIL SOROKIN	{"email": "m.sorokin1970@postgrespro.ru", "phone": "+70603290652"}
0005435304133	040F91	8495 390282	ALEKSEY VASILEV	{"phone": "+70192429226"}
0005435304134	B02E2D	0704 665435	DMITRIY ANDREEV	{"phone": "+70122234167"}
0005435304135	FA2FA4	5527 754377	SVETLANA DAVYDOVA	{"email": "davydova-s_13091976@postgrespro.ru", "phone": "+70428835175"}
0005435304136	FA2FA4	6338 636147	YURIY KAZAKOV	{"email": "kazakov-yuriy-24101980@postgrespro.ru", "phone": "+70011311062"}
0005435304137	8C14FC	5438 021805	ANATOLIY BORISOV	{"email": "borisov_anatoliy-1975@postgrespro.ru", "phone": "+70468114846"}
0005435304138	8C14FC	3302 516416	SERGEY SAVELEV	{"email": "sergey-savelev_1972@postgrespro.ru", "phone": "+70888848721"}
0005435304139	9F5FB2	5666 506594	SVETLANA SMIRNOVA	{"email": "smirnovasvetlana_11021970@postgrespro.ru", "phone": "+70961668336"}
0005435304140	9F5FB2	3587 114309	FEDOR MELNIKOV	{"phone": "+70789603093"}
0005435304141	9F5FB2	6236 008003	ZINAIDA ALEKSANDROVA	{"email": "z-aleksandrova17091979@postgrespro.ru", "phone": "+70708783278"}
0005435304142	E2CDDE	9273 732356	ELENA GAVRILOVA	{"email": "gavrilova_e051978@postgrespro.ru", "phone": "+70144652748"}
0005435304143	4327A9	6826 711174	MAKSIM PAVLOV	{"phone": "+70080541050"}
0005435304144	4327A9	1137 784874	FATIMA NIKIFOROVA	{"email": "nikiforova_fatima1979@postgrespro.ru", "phone": "+70519332145"}
0005435304145	02E446	1619 640617	LYUBOV NAZAROVA	{"email": "nazaroval_071977@postgrespro.ru", "phone": "+70813409456"}
0005435304146	A513E9	1333 691898	ANDREY TIKHONOV	{"email": "tikhonovandrey.12051970@postgrespro.ru", "phone": "+70846786975"}
0005435304147	A513E9	8852 091851	ANDREY POPOV	{"email": "andrey.popov_08011972@postgrespro.ru", "phone": "+70362551825"}
0005435304148	EDA5E1	8859 416265	ALEKSANDR SAVELEV	{"email": "savelev.a16091971@postgrespro.ru", "phone": "+70301245787"}
0005435304149	F83577	8022 685220	EVGENIY NOVIKOV	{"email": "e.novikov.111961@postgrespro.ru", "phone": "+70799185850"}
0005435304150	555FDE	9479 553803	VIKTORIYA BELOVA	{"email": "vbelova1970@postgrespro.ru", "phone": "+70360930388"}
0005435304151	824F2D	8733 546847	VLADIMIR KARPOV	{"phone": "+70327898984"}
0005435304152	0738B3	4283 692874	ALEKSEY AFANASEV	{"email": "a-afanasev-20021958@postgrespro.ru", "phone": "+70169653375"}
0005435304153	0738B3	2419 923484	IRINA IVANOVA	{"phone": "+70285238801"}
0005435304154	0738B3	0060 358313	EVGENIYA SEMENOVA	{"email": "e.semenova_031968@postgrespro.ru", "phone": "+70426662706"}
0005435304155	01BA30	9325 770340	ANDREY KUZMIN	{"phone": "+70339265744"}
0005435304156	01BA30	2260 510040	POLINA IVANOVA	{"email": "polina-ivanova_1971@postgrespro.ru", "phone": "+70414607257"}
0005435304157	45E38E	0897 878079	MARAT POPOV	{"phone": "+70027521643"}
0005435304158	77580E	0312 951362	SVETLANA IVANOVA	{"phone": "+70836104327"}
0005435304159	8A3306	2859 106055	SERGEY KONOVALOV	{"email": "konovalovsergey_15051978@postgrespro.ru", "phone": "+70811807121"}
0005435304160	10132A	0252 010442	SHAMIL KULIKOV	{"phone": "+70032756165"}
0005435304161	EFB0B5	2806 311247	YULIYA YUDINA	{"phone": "+70436098595"}
0005435304162	8886B3	1488 497974	SERGEY GRIGOREV	{"email": "grigorevs_1963@postgrespro.ru", "phone": "+70543657673"}
0005435304163	8886B3	7394 045082	DMITRIY TIKHONOV	{"phone": "+70996848253"}
0005435304164	7183E7	6852 783612	OLGA PAVLOVA	{"email": "pavlova-o_27101976@postgrespro.ru", "phone": "+70554816264"}
0005435304165	30C026	8806 887582	TATYANA ZAKHAROVA	{"phone": "+70767236162"}
0005435304166	30C026	8051 586137	VALERIY NIKOLAEV	{"email": "nikolaev_v_011975@postgrespro.ru", "phone": "+70654058568"}
0005435304167	0DD52D	4644 107459	DIANA DAVYDOVA	{"phone": "+70271661232"}
0005435304168	3FD543	6638 944453	ALEKSANDRA KOMAROVA	{"email": "a_komarova-071976@postgrespro.ru", "phone": "+70530175206"}
0005435304169	3FD543	1157 395936	ALEKSANDRA ZAKHAROVA	{"phone": "+70227410817"}
0005435304170	5F8084	2953 813503	VIKTORIYA TIMOFEEVA	{"phone": "+70654058072"}
0005435304171	5F8084	1710 009794	ALEKSANDR MAKSIMOV	{"phone": "+70502192060"}
0005435304172	5BAC25	4294 450355	OLGA ROMANOVA	{"email": "romanovaolga22041969@postgrespro.ru", "phone": "+70330817351"}
0005435304173	5BAC25	8486 646564	ALEKSANDRA ANTONOVA	{"phone": "+70955653967"}
0005435304174	A071E4	5932 324758	IGOR ISAEV	{"email": "i.isaev-17031976@postgrespro.ru", "phone": "+70830196408"}
0005435304175	A071E4	0576 958817	ARTEM DAVYDOV	{"email": "davydov_artem_1961@postgrespro.ru", "phone": "+70662050439"}
0005435304176	E45953	8840 480222	IGOR MAKAROV	{"email": "makarov-igor.01111970@postgrespro.ru", "phone": "+70881528973"}
0005435304177	E485A5	5756 080710	DENIS BORISOV	{"email": "borisovd_10061969@postgrespro.ru", "phone": "+70058053725"}
0005435304178	E485A5	9911 732244	EKATERINA KARPOVA	{"email": "ekaterina_karpova-15011975@postgrespro.ru", "phone": "+70592605182"}
0005435304179	EA3531	8517 497732	ALEKSANDR GERASIMOV	{"email": "gerasimov_a011967@postgrespro.ru", "phone": "+70740809230"}
0005435304180	EA3531	6596 249545	OLGA KONOVALOVA	{"email": "o-konovalova_101970@postgrespro.ru", "phone": "+70249627505"}
0005435304181	AE1BFC	6360 285078	OLGA KUDRYASHOVA	{"email": "olgakudryashova121972@postgrespro.ru", "phone": "+70347105795"}
0005435304182	187E00	0781 847526	DENIS BONDARENKO	{"email": "bondarenkodenis.28121982@postgrespro.ru", "phone": "+70184921793"}
0005435304183	187E00	2800 018900	TAMARA CHERNOVA	{"phone": "+70386227862"}
0005435304184	651103	5100 528897	NATALYA ALEKSANDROVA	{"email": "n-aleksandrova.1980@postgrespro.ru", "phone": "+70415949072"}
0005435304185	050578	0891 365724	ELENA BORISOVA	{"phone": "+70744757167"}
0005435304186	BFF10E	9423 089342	SERGEY KOROLEV	{"phone": "+70830330062"}
0005435304187	CCB9D6	3456 720047	IGOR NIKITIN	{"email": "nikitinigor_1973@postgrespro.ru", "phone": "+70589503199"}
0005435304188	E75532	6325 616184	OLGA KOROLEVA	{"email": "o_koroleva-04091975@postgrespro.ru", "phone": "+70059293776"}
0005435304189	E75532	5412 083232	ALEKSANDRA SOROKINA	{"email": "sorokina.aleksandra-111972@postgrespro.ru", "phone": "+70738482354"}
0005435304190	4FFA64	6145 106636	MARIYA ROMANOVA	{"email": "romanova_mariya-28111960@postgrespro.ru", "phone": "+70476566152"}
0005435304191	89D31B	6737 034551	ANATOLIY ZAKHAROV	{"phone": "+70491299621"}
0005435304192	9A25B2	1355 321368	VALENTINA ISAEVA	{"email": "isaevavalentina_1974@postgrespro.ru", "phone": "+70200316127"}
0005435304193	822AAF	6896 333848	PAVEL ZHURAVLEV	{"email": "zhuravlev.pavel-1976@postgrespro.ru", "phone": "+70435407307"}
0005435304194	3B8E57	6839 114794	ANASTASIYA MAKAROVA	{"email": "makarovaanastasiya_071983@postgrespro.ru", "phone": "+70822297619"}
0005435304195	3B8E57	9784 500285	OLEG MEDVEDEV	{"email": "medvedev.o_1981@postgrespro.ru", "phone": "+70438604746"}
0005435304196	16AE69	7634 419361	ANDREY STEPANOV	{"email": "andrey-stepanov29011979@postgrespro.ru", "phone": "+70752771380"}
0005435304197	16AE69	8782 761513	SERGEY SOLOVEV	{"email": "sergey-solovev-1970@postgrespro.ru", "phone": "+70623360504"}
0005435304198	75009D	0590 237818	ILYA STEPANOV	{"phone": "+70634486771"}
0005435304199	C32758	8460 965410	IGOR IVANOV	{"email": "ivanovigor.041975@postgrespro.ru", "phone": "+70921639850"}
0005435304200	11032E	6113 320771	ANGELINA KULIKOVA	{"email": "angelina.kulikova_1976@postgrespro.ru", "phone": "+70624114279"}
0005435304201	11032E	7731 215885	LIDIYA ALEKSEEVA	{"phone": "+70362369106"}
0005435304202	11032E	5068 239386	OLESYA SIDOROVA	{"email": "olesyasidorova.1978@postgrespro.ru", "phone": "+70881265436"}
0005435304203	AE95A3	1663 008755	MARINA PAVLOVA	{"email": "pavlova-m_1966@postgrespro.ru", "phone": "+70397220111"}
0005435304204	AE95A3	7744 782003	ALEKSANDRA BELOVA	{"email": "belova_a1980@postgrespro.ru", "phone": "+70587657467"}
0005435304205	AE95A3	0424 927458	GRIGORIY KULIKOV	{"phone": "+70764820920"}
0005435304206	D5679D	5878 069724	NADEZHDA KUZNECOVA	{"email": "nadezhda-kuznecova-05031970@postgrespro.ru", "phone": "+70611477378"}
0005435304207	986FB2	5780 712066	LYUBOV AKIMOVA	{"phone": "+70661098840"}
0005435304208	986FB2	0271 842793	VERA KUZNECOVA	{"email": "kuznecovavera.05041971@postgrespro.ru", "phone": "+70438920727"}
0005435304209	3C3C87	8787 655243	OLGA ZAKHAROVA	{"email": "ozakharova.21121967@postgrespro.ru", "phone": "+70585538028"}
0005435304210	23FCA0	3703 768329	ALEKSANDR BELOV	{"email": "belov.a_25021974@postgrespro.ru", "phone": "+70659827107"}
0005435304211	998046	2131 539608	NIKOLAY BORISOV	{"email": "nikolay-borisov17021977@postgrespro.ru", "phone": "+70662494393"}
0005435304212	A13869	3768 609083	SERGEY DMITRIEV	{"phone": "+70234961287"}
0005435304213	A13869	8944 876684	ALEKSANDR ALEKSANDROV	{"phone": "+70056177360"}
0005435304214	A13869	8635 336502	VLADIMIR ALEKSANDROV	{"phone": "+70433801512"}
0005435304215	BA5ABA	5258 879602	TATYANA KALININA	{"phone": "+70502204861"}
0005435304216	BA5ABA	6807 232227	VALENTINA ARKHIPOVA	{"email": "valentinaarkhipova071976@postgrespro.ru", "phone": "+70338170399"}
0005435304217	36C15C	3546 485325	GALINA KISELEVA	{"phone": "+70457236384"}
0005435304218	E0CCC2	5611 269066	ANASTASIYA SEMENOVA	{"email": "asemenova_1959@postgrespro.ru", "phone": "+70206657145"}
0005435304219	E0CCC2	0725 086167	ALFIYA ZAKHAROVA	{"email": "zakharova.alfiya011973@postgrespro.ru", "phone": "+70515342449"}
0005435304220	BB27F2	5148 417612	TAMARA SOKOLOVA	{"email": "sokolova-tamara.1973@postgrespro.ru", "phone": "+70393579932"}
0005435304221	BB27F2	4244 540672	GENNADIY PETROV	{"phone": "+70467233476"}
0005435304222	EDFD78	5105 360892	NINA KARPOVA	{"email": "karpovanina.31071978@postgrespro.ru", "phone": "+70756171628"}
0005435304223	37CA52	0126 794023	SERGEY ALEKSEEV	{"email": "s.alekseev081962@postgrespro.ru", "phone": "+70077731565"}
0005435304224	78482D	6173 164027	TATYANA FADEEVA	{"phone": "+70374218710"}
0005435304225	73B54E	8618 324176	PAVEL BARANOV	{"phone": "+70313486897"}
0005435304226	8A6B47	4192 659957	IRINA KUZMINA	{"email": "kuzmina.i071983@postgrespro.ru", "phone": "+70520111724"}
0005435304227	22D9D5	8452 649850	GULNARA IVANOVA	{"email": "ivanova_gulnara1972@postgrespro.ru", "phone": "+70323897053"}
0005435304228	22D9D5	8999 018065	TATYANA ALEKSANDROVA	{"email": "aleksandrova.t_1976@postgrespro.ru", "phone": "+70869293513"}
0005435304229	58939F	1629 955030	LYUDMILA VOLKOVA	{"email": "volkoval1974@postgrespro.ru", "phone": "+70108990765"}
0005435304230	58939F	7723 995087	ALEKSANDR VASILEV	{"email": "vasilev_a_101977@postgrespro.ru", "phone": "+70098206120"}
0005435304231	58939F	0261 258775	VALENTINA KOVALEVA	{"email": "vkovaleva_081980@postgrespro.ru", "phone": "+70098497376"}
0005435304232	CE15E6	1826 446501	YURIY MIRONOV	{"phone": "+70675843310"}
0005435304233	CD8E23	6767 113233	ANASTASIYA FILATOVA	{"phone": "+70790163717"}
0005435304234	CD8E23	4219 075261	SERGEY MELNIKOV	{"email": "melnikov.sergey071968@postgrespro.ru", "phone": "+70414051621"}
0005435304235	116F44	4307 584308	FAIL KRASNOV	{"phone": "+70380273825"}
0005435304236	116F44	6972 808998	LARISA MIRONOVA	{"phone": "+70200345559"}
0005435304237	FA6E6F	0259 787725	MARIYA ORLOVA	{"email": "mariya_orlova-02071968@postgrespro.ru", "phone": "+70329372886"}
0005435304238	64A3A5	3937 521608	ALEKSEY MARTYNOV	{"email": "martynov_a-081971@postgrespro.ru", "phone": "+70072609334"}
0005435304239	64A3A5	2687 074418	NIKOLAY FILIPPOV	{"phone": "+70049868531"}
0005435304240	AFB5E6	8055 647621	LYUBOV KISELEVA	{"email": "lyubov.kiseleva.061968@postgrespro.ru", "phone": "+70006379886"}
0005435304241	AFB5E6	4237 255690	DMITRIY SMIRNOV	{"phone": "+70500145119"}
0005435304242	B59166	6990 822247	YAN DAVYDOV	{"email": "y_davydov.111979@postgrespro.ru", "phone": "+70434113133"}
0005435304243	14966D	0833 697363	MIKHAIL BELOV	{"email": "mbelov111973@postgrespro.ru", "phone": "+70014083224"}
0005435304244	14966D	4953 493905	ALEKSEY BARANOV	{"email": "alekseybaranov_1968@postgrespro.ru", "phone": "+70615188409"}
0005435304245	225F35	0270 120517	IVAN FILIPPOV	{"email": "filippovi-1986@postgrespro.ru", "phone": "+70039794997"}
0005435304246	051769	3864 710289	ANASTASIYA KOROLEVA	{"email": "anastasiyakoroleva.1963@postgrespro.ru", "phone": "+70555272409"}
0005435304247	051769	4374 814355	OLGA FILIPPOVA	{"phone": "+70788881504"}
0005435304248	3E6038	8096 973910	YURIY ANTONOV	{"phone": "+70629727108"}
0005435304249	88452D	1365 193255	SVETLANA ROMANOVA	{"email": "romanova.s.021972@postgrespro.ru", "phone": "+70209942245"}
0005435304250	FAD443	9869 632866	MARIYA MIRONOVA	{"email": "mariya_mironova-19111970@postgrespro.ru", "phone": "+70225068590"}
0005435304251	8A14D7	4556 764964	YURIY MAKSIMOV	{"phone": "+70115866582"}
0005435304252	BC19C6	0573 787637	ALINA ILINA	{"email": "ilina_a_1960@postgrespro.ru", "phone": "+70292289602"}
0005435304253	BCD843	4164 868220	VERA ALEKSANDROVA	{"email": "veraaleksandrova-05031965@postgrespro.ru", "phone": "+70947751686"}
0005435304254	0105FA	6055 456001	SERGEY DAVYDOV	{"phone": "+70391018943"}
0005435304255	053B04	5626 741907	VIKTOR FEDOROV	{"email": "viktorfedorov.04021963@postgrespro.ru", "phone": "+70967709380"}
0005435304256	816FFB	5170 107407	VERA POLYAKOVA	{"phone": "+70006792325"}
0005435304257	3FC376	2410 848481	ANTONINA NIKITINA	{"email": "antonina_nikitina.1965@postgrespro.ru", "phone": "+70109883336"}
0005435304258	169151	8920 948751	MIKHAIL DAVYDOV	{"email": "davydov_m.04121969@postgrespro.ru", "phone": "+70841152388"}
0005435304259	5F81CF	7708 585815	MAKSIM KOZLOV	{"phone": "+70344638605"}
0005435304260	262FE7	6032 618409	SABINA SAVELEVA	{"email": "saveleva-s.08031972@postgrespro.ru", "phone": "+70781522154"}
0005435304261	80D5F9	1585 627236	OLGA SOROKINA	{"email": "sorokina_o.25121970@postgrespro.ru", "phone": "+70960609950"}
0005435304262	80D5F9	8294 765286	OLEG SMIRNOV	{"email": "oleg_smirnov_1982@postgrespro.ru", "phone": "+70161200175"}
0005435304263	6AF5E3	1292 101110	TATYANA MALYSHEVA	{"phone": "+70949218482"}
0005435304264	6AF5E3	4125 894362	IVAN NIKOLAEV	{"email": "nikolaev.ivan_1978@postgrespro.ru", "phone": "+70076241564"}
0005435304265	D95686	8804 571661	ANDREY NIKOLAEV	{"email": "a-nikolaev_061967@postgrespro.ru", "phone": "+70475076360"}
0005435304266	A1E8FB	5250 789691	EVGENIY NAZAROV	{"phone": "+70876074016"}
0005435304267	35B3D2	2679 701356	MAKSIM ROMANOV	{"phone": "+70179881838"}
0005435304268	469E5F	3574 716102	ELENA MOROZOVA	{"phone": "+70133275801"}
0005435304269	07CB6B	5310 635474	VIKTOR KUZNECOV	{"email": "kuznecov.viktor1974@postgrespro.ru", "phone": "+70113762040"}
0005435304270	54F7BF	1259 391902	KHALIDA IVANOVA	{"phone": "+70067447127"}
0005435304271	80B379	6695 990117	MARINA KUDRYASHOVA	{"email": "kudryashova-m.1977@postgrespro.ru", "phone": "+70357095415"}
0005435304272	208B86	5425 539999	ILYA ALEKSEEV	{"email": "ilya_alekseev-20081967@postgrespro.ru", "phone": "+70553560341"}
0005435304273	2DEEA2	2597 530550	DMITRIY NOVIKOV	{"phone": "+70869882273"}
0005435304274	6CBC85	4623 896322	NINA PETROVA	{"phone": "+70549980592"}
0005435304275	6CBC85	5183 434041	NIKOLAY ZHURAVLEV	{"phone": "+70211761464"}
0005435304276	8CEAE7	1951 330944	YULIYA ILINA	{"phone": "+70066823782"}
0005435304989	46DECC	2106 596658	ROMAN NIKOLAEV	{"phone": "+70950760641"}
0005435304990	876741	0767 925150	ROMAN SEMENOV	{"email": "semenov-roman-071968@postgrespro.ru", "phone": "+70509666990"}
0005435304991	876741	3314 472568	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a_1983@postgrespro.ru", "phone": "+70726820773"}
0005435310979	C9ED10	4278 945706	ALEKSANDRA GRISHINA	{"phone": "+70423050488"}
0005435304992	B871E1	0147 797653	IVAN BARANOV	{"email": "ibaranov111973@postgrespro.ru", "phone": "+70754960853"}
0005435304993	C36D22	8021 280103	ANATOLIY BONDARENKO	{"email": "a-bondarenko1985@postgrespro.ru", "phone": "+70941283091"}
0005435304994	C36D22	2518 141092	SVETLANA SMIRNOVA	{"phone": "+70124507447"}
0005435304995	EAD005	2333 642238	DENIS SOLOVEV	{"email": "solovevdenis.091972@postgrespro.ru", "phone": "+70831102359"}
0005435304996	3CCF79	6126 043567	VIKTOR GUSEV	{"phone": "+70004207841"}
0005435304997	979147	6500 668239	DMITRIY KRASNOV	{"email": "d.krasnov-24021979@postgrespro.ru", "phone": "+70814414544"}
0005435304998	627B4C	0315 167745	ALEKSANDR DENISOV	{"phone": "+70601869787"}
0005435304999	627B4C	3880 804905	ELENA DANILOVA	{"email": "elena-danilova.061975@postgrespro.ru", "phone": "+70242888818"}
0005435305000	B4089A	2444 674588	SERGEY IVANOV	{"phone": "+70931546152"}
0005435305001	E55183	6260 129992	SVETLANA ILINA	{"phone": "+70990178248"}
0005435305002	E55183	2804 077307	ALINA POPOVA	{"email": "popovaalina_121973@postgrespro.ru", "phone": "+70794870747"}
0005435305003	2E0BE1	9202 212739	GALINA MOISEEVA	{"email": "moiseeva_g.1976@postgrespro.ru", "phone": "+70769207054"}
0005435305004	2E0BE1	4483 336671	VALENTINA KOVALEVA	{"phone": "+70472560005"}
0005435305005	DB352A	3784 707676	ALEKSANDRA ALEKSEEVA	{"email": "aleksandra_alekseeva.061960@postgrespro.ru", "phone": "+70784773323"}
0005435305006	DB352A	8750 093570	LIDIYA ERMAKOVA	{"email": "lidiya.ermakova.10081987@postgrespro.ru", "phone": "+70705550375"}
0005435305007	78B4E2	8177 327994	IRINA POTAPOVA	{"email": "irinapotapova.1985@postgrespro.ru", "phone": "+70930356869"}
0005435305008	9CC1AA	0194 027668	RAISA POPOVA	{"email": "popova_raisa_101966@postgrespro.ru", "phone": "+70740732757"}
0005435305009	9CC1AA	2165 983241	ZINAIDA NESTEROVA	{"phone": "+70160951928"}
0005435305010	B8F557	7783 153024	ELENA SIDOROVA	{"email": "esidorova-111964@postgrespro.ru", "phone": "+70960702298"}
0005435305011	B8F557	3140 279721	TATYANA KOZLOVA	{"email": "kozlova-t-14091980@postgrespro.ru", "phone": "+70226544953"}
0005435305012	10E686	5253 189068	IVAN BELOV	{"email": "belov_ivan-011973@postgrespro.ru", "phone": "+70413866823"}
0005435305013	7F11D5	1501 028432	SERGEY SOKOLOV	{"email": "s.sokolov.26031971@postgrespro.ru", "phone": "+70710813681"}
0005435305014	CE8273	0325 770165	STANISLAV STEPANOV	{"email": "stanislav_stepanov.071983@postgrespro.ru", "phone": "+70245029168"}
0005435305015	CE8273	3142 898258	KLAVDIYA ZHURAVLEVA	{"email": "zhuravlevaklavdiya_031977@postgrespro.ru", "phone": "+70748405877"}
0005435305016	835675	3114 651309	IVAN PAVLOV	{"email": "pavlovi30121974@postgrespro.ru", "phone": "+70616615460"}
0005435305017	AD12C8	8324 462001	VLADIMIR KOROLEV	{"phone": "+70596269249"}
0005435305018	654118	1504 456429	RIMMA ZAKHAROVA	{"email": "zakharovar1970@postgrespro.ru", "phone": "+70807247377"}
0005435305019	722753	2089 524650	VLADIMIR NAZAROV	{"email": "nazarov_v_15121957@postgrespro.ru", "phone": "+70364917736"}
0005435305020	A8B6F4	2094 446013	EVGENIY NIKOLAEV	{"email": "nikolaev-evgeniy.041983@postgrespro.ru", "phone": "+70286911235"}
0005435305021	D1E8A2	6175 577550	ALEKSEY KOZLOV	{"phone": "+70228194969"}
0005435305022	D1E8A2	4911 830253	TATYANA KUZNECOVA	{"phone": "+70075391863"}
0005435305023	521206	7330 318908	SANIYA POPOVA	{"email": "popova-s.1972@postgrespro.ru", "phone": "+70876150266"}
0005435305024	521206	8038 610216	SVETLANA SIDOROVA	{"email": "svetlana_sidorova_26071967@postgrespro.ru", "phone": "+70481809605"}
0005435305025	BC7632	0700 219719	VLADIMIR BELOV	{"phone": "+70486710139"}
0005435305026	9B4E11	9146 570773	OLGA MOISEEVA	{"phone": "+70019576130"}
0005435305027	D406C1	3744 253868	DARYA KOVALEVA	{"email": "darya-kovaleva1970@postgrespro.ru", "phone": "+70739454314"}
0005435305028	D7CF7F	2493 836924	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov_1958@postgrespro.ru", "phone": "+70794780631"}
0005435305029	BB87E2	6624 301403	VLADIMIR VOLKOV	{"phone": "+70925035687"}
0005435305030	BB87E2	6877 384287	ANATOLIY MIRONOV	{"phone": "+70863355283"}
0005435305031	810506	8725 343510	ARTUR MARTYNOV	{"phone": "+70065266608"}
0005435305032	D4BF20	3329 742523	ALLA EGOROVA	{"email": "egorova-a121969@postgrespro.ru", "phone": "+70080210156"}
0005435305033	9F96D8	0930 611362	YURIY POPOV	{"email": "y.popov03111969@postgrespro.ru", "phone": "+70872958168"}
0005435305034	78AB26	3965 242868	ALENA KONOVALOVA	{"phone": "+70902337130"}
0005435305035	55AC61	4058 428213	EGOR KUZNECOV	{"email": "kuznecove011977@postgrespro.ru", "phone": "+70517282183"}
0005435305036	3B8D27	1363 115688	PAVEL PETROV	{"email": "petrov.pavel-011956@postgrespro.ru", "phone": "+70136736076"}
0005435305037	3B8D27	9296 623076	SERGEY OSIPOV	{"email": "sergey-osipov-111984@postgrespro.ru", "phone": "+70415766413"}
0005435305038	7C6CCF	0358 424153	ALEKSANDRA KOROLEVA	{"email": "a-koroleva_091976@postgrespro.ru", "phone": "+70284040393"}
0005435305039	7C6CCF	8867 674003	YULIYA MATVEEVA	{"phone": "+70748004816"}
0005435305040	7C8F27	5070 736418	KIRILL YAKOVLEV	{"phone": "+70344973262"}
0005435305041	424C69	3421 170949	ELENA ILINA	{"email": "ilina.elena.07081964@postgrespro.ru", "phone": "+70683336439"}
0005435305042	926D47	6901 285448	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr051973@postgrespro.ru", "phone": "+70354635570"}
0005435305043	440A0B	6268 761659	ROMAN PETROV	{"email": "r_petrov.18101973@postgrespro.ru", "phone": "+70028766467"}
0005435305044	A9F7AA	9547 903406	OLGA AFANASEVA	{"email": "afanasevao-1976@postgrespro.ru", "phone": "+70809430840"}
0005435305045	01B959	5987 015562	VLADISLAV VOLKOV	{"email": "vladislav-volkov_30081975@postgrespro.ru", "phone": "+70381975989"}
0005435305046	01B959	1132 784112	ALEKSEY ISAEV	{"phone": "+70825104457"}
0005435305047	01B959	3531 475260	VALENTINA NIKOLAEVA	{"email": "vnikolaeva-041970@postgrespro.ru", "phone": "+70971693858"}
0005435305048	BA0E1F	7204 614376	VASILIY TARASOV	{"phone": "+70117673814"}
0005435305049	724344	3306 576612	SERAFIM GRIGOREV	{"email": "grigorev.serafim121969@postgrespro.ru", "phone": "+70396791583"}
0005435305050	724344	4262 417833	MIKHAIL VOROBEV	{"email": "m.vorobev-07011968@postgrespro.ru", "phone": "+70769492510"}
0005435305051	B36C75	1018 146697	MIKHAIL YAKOVLEV	{"phone": "+70818357133"}
0005435305052	F6BCFC	3492 867946	GRIGORIY KOZLOV	{"email": "kozlov.grigoriy_071963@postgrespro.ru", "phone": "+70989952045"}
0005435305053	F6BCFC	7731 314444	ANDREY KAZAKOV	{"phone": "+70720419240"}
0005435305054	C01849	5642 686978	VERA ISAEVA	{"email": "v_isaeva-08021977@postgrespro.ru", "phone": "+70728043383"}
0005435305055	C8ED96	1305 803524	VALENTINA GERASIMOVA	{"email": "valentinagerasimova-06041977@postgrespro.ru", "phone": "+70223332879"}
0005435305056	1C2D89	5558 816112	VLADIMIR NIKOLAEV	{"phone": "+70254861563"}
0005435305057	1C2D89	1409 548747	IGOR VASILEV	{"email": "i_vasilev_21111957@postgrespro.ru", "phone": "+70376491179"}
0005435305058	DFF556	7726 922705	MARIYA GAVRILOVA	{"phone": "+70940356240"}
0005435305059	E63A69	1515 295284	DIANA IVANOVA	{"phone": "+70455209665"}
0005435305060	10C789	1688 567170	OLGA SOROKINA	{"email": "o_sorokina15031967@postgrespro.ru", "phone": "+70995717681"}
0005435305061	AC8D59	9253 707027	DMITRIY VASILEV	{"email": "vasilevdmitriy-031958@postgrespro.ru", "phone": "+70719028605"}
0005435305062	BF3DA1	2168 774126	LYUDMILA MIKHAYLOVA	{"phone": "+70605408525"}
0005435305063	47B199	8736 939837	NIKITA NOVIKOV	{"email": "n-novikov121977@postgrespro.ru", "phone": "+70390382468"}
0005435305064	2FACDC	1594 099159	LYUDMILA KONOVALOVA	{"email": "lyudmila-konovalova.18021970@postgrespro.ru", "phone": "+70088969174"}
0005435305065	0FDDD2	6866 908556	OLGA MIKHAYLOVA	{"email": "mikhaylova-o.09021964@postgrespro.ru", "phone": "+70032707188"}
0005435305066	8C8C7A	2995 901563	NINA KULIKOVA	{"email": "kulikova_n101976@postgrespro.ru", "phone": "+70745384711"}
0005435305067	8C8C7A	9667 500930	VERA ROMANOVA	{"email": "veraromanova.15021968@postgrespro.ru", "phone": "+70813378427"}
0005435305068	79A7B8	2641 292539	VIKTOR VOLKOV	{"email": "vvolkov-1966@postgrespro.ru", "phone": "+70992509247"}
0005435305069	9DEEC2	4300 915337	ALEKSEY GAVRILOV	{"email": "a-gavrilov-13061980@postgrespro.ru", "phone": "+70069515842"}
0005435305070	D126B7	6395 587503	VALENTINA MOROZOVA	{"phone": "+70558838780"}
0005435305071	D307D0	2300 646164	TATYANA KUZNECOVA	{"email": "t_kuznecova05021969@postgrespro.ru", "phone": "+70083150291"}
0005435305072	D307D0	6084 826588	NATALYA KUDRYASHOVA	{"email": "kudryashovan-11081969@postgrespro.ru", "phone": "+70562495251"}
0005435305073	114426	6618 152041	VASILIY MARTYNOV	{"phone": "+70134929609"}
0005435305074	4A2384	6903 410143	VLADLEN KUZNECOV	{"phone": "+70273066904"}
0005435305075	04DA95	3627 328303	MAKSIM MOISEEV	{"phone": "+70392197826"}
0005435305076	04DA95	3807 444290	VALERIYA EFREMOVA	{"phone": "+70320943280"}
0005435305077	70EFEC	9956 686902	SVETLANA MASLOVA	{"phone": "+70665660123"}
0005435305078	70EFEC	6222 753221	SVETLANA KULIKOVA	{"phone": "+70390946991"}
0005435305079	CE973E	5918 153539	SERGEY SOKOLOV	{"email": "sokolov.s.13031984@postgrespro.ru", "phone": "+70771476781"}
0005435305080	CE973E	2397 409084	IREK FOMIN	{"email": "fomin_irek.03071980@postgrespro.ru", "phone": "+70069254172"}
0005435305081	DB6761	8981 020999	ALEKSANDR NIKOLAEV	{"email": "aleksandr-nikolaev_021980@postgrespro.ru", "phone": "+70426848034"}
0005435310836	73F41B	7101 830528	KSENIYA SIDOROVA	{"email": "ksidorova.1982@postgrespro.ru", "phone": "+70976378576"}
0005435310837	24B9C3	9801 115503	MARIYA KUZMINA	{"phone": "+70514113537"}
0005435310838	20139C	4037 125989	MARGARITA MAKAROVA	{"phone": "+70671575235"}
0005435310839	E2C568	6943 805945	NIKOLAY KUZNECOV	{"email": "n-kuznecov-04121977@postgrespro.ru", "phone": "+70721500132"}
0005435310840	7C6129	3949 781450	NADEZHDA SOLOVEVA	{"email": "n-soloveva-091965@postgrespro.ru", "phone": "+70371250067"}
0005435310841	7B0182	1823 526701	ALEKSANDR GRIGOREV	{"phone": "+70445216282"}
0005435310842	7B0182	2204 464313	ALEKSEY BARANOV	{"email": "baranov_a091963@postgrespro.ru", "phone": "+70970370753"}
0005435310843	3F8D3A	7150 305844	VIKTORIYA VLASOVA	{"email": "vlasova-viktoriya-21041971@postgrespro.ru", "phone": "+70754797379"}
0005435310844	3F8D3A	5980 907719	SERGEY SERGEEV	{"phone": "+70688181289"}
0005435310845	A6157F	8017 106487	SVETLANA DANILOVA	{"email": "danilovas.05021973@postgrespro.ru", "phone": "+70745454556"}
0005435310846	8175C8	5702 909146	VLADIMIR NIKOLAEV	{"email": "nikolaev_v15091969@postgrespro.ru", "phone": "+70314890681"}
0005435310847	A50A4C	6953 203738	NATALYA EGOROVA	{"email": "egorova_n-061974@postgrespro.ru", "phone": "+70978709900"}
0005435310848	C827FD	2825 765801	SOFIYA KOZLOVA	{"email": "sofiya.kozlova.1964@postgrespro.ru", "phone": "+70193728871"}
0005435310849	C827FD	2296 177847	OLGA SAVELEVA	{"email": "olga_saveleva-101971@postgrespro.ru", "phone": "+70757127288"}
0005435310850	B0F791	7845 477596	ANDREY ISAEV	{"email": "andrey_isaev.13111981@postgrespro.ru", "phone": "+70202479659"}
0005435310851	B0F791	8137 407581	LIDIYA AFANASEVA	{"email": "lidiya-afanaseva12071962@postgrespro.ru", "phone": "+70910767368"}
0005435310852	D5A90E	3987 312717	DMITRIY IVANOV	{"email": "ivanovdmitriy.1984@postgrespro.ru", "phone": "+70190125230"}
0005435310853	529945	0060 492766	EKATERINA SOKOLOVA	{"phone": "+70213112056"}
0005435310854	A04089	6544 434216	ALEKSANDR FEDOTOV	{"email": "fedotovaleksandr_24121979@postgrespro.ru", "phone": "+70464719128"}
0005435310855	6BE4A6	9004 514482	NIKOLAY KISELEV	{"email": "n.kiselev-071958@postgrespro.ru", "phone": "+70378158761"}
0005435310856	D14094	6384 069624	ALEKSANDRA KOLESNIKOVA	{"email": "kolesnikova.aleksandra04121965@postgrespro.ru", "phone": "+70417274826"}
0005435310857	F1C8E7	3692 182731	YULIYA SIDOROVA	{"email": "sidorova.yuliya.1964@postgrespro.ru", "phone": "+70287626729"}
0005435310858	F1C8E7	6017 196321	GALINA VASILEVA	{"email": "vasilevag03071969@postgrespro.ru", "phone": "+70550297520"}
0005435310859	FF8519	7256 634815	RODION IVANOV	{"phone": "+70263007145"}
0005435310860	FF8519	2324 743255	RAMZIYA NOVIKOVA	{"email": "novikova-r.031969@postgrespro.ru", "phone": "+70352272885"}
0005435310861	FF8519	7785 773292	NATALYA ANDREEVA	{"email": "n_andreeva_071971@postgrespro.ru", "phone": "+70815175800"}
0005435310862	FA7BBE	6990 124084	VALENTINA SOROKINA	{"email": "v_sorokina.081963@postgrespro.ru", "phone": "+70825765837"}
0005435310863	FA7BBE	6934 731787	TATYANA POPOVA	{"phone": "+70947647631"}
0005435310864	A7F562	2449 214193	SVETLANA MAKAROVA	{"email": "smakarova1968@postgrespro.ru", "phone": "+70132015247"}
0005435310865	A7F562	5925 853607	ANATOLIY NIKITIN	{"email": "nikitin_anatoliy_091979@postgrespro.ru", "phone": "+70938395060"}
0005435310866	EE7F80	9567 571324	LYUDMILA MOROZOVA	{"phone": "+70637996471"}
0005435310867	CA4068	9739 981534	ELENA NESTEROVA	{"phone": "+70627277513"}
0005435310868	B29EFF	5334 082901	ZINAIDA KOZLOVA	{"email": "kozlova_zinaida-1992@postgrespro.ru", "phone": "+70447183134"}
0005435310869	065562	9231 240670	MIKHAIL ROMANOV	{"email": "romanovmikhail-28091969@postgrespro.ru", "phone": "+70203858532"}
0005435310870	0F805F	4585 353576	TAMARA MOROZOVA	{"phone": "+70827246982"}
0005435310871	0F805F	9045 543747	RAISA FILIPPOVA	{"phone": "+70969837983"}
0005435310872	73327F	6585 144787	LYUDMILA CHERNOVA	{"phone": "+70295381414"}
0005435310873	73327F	3478 609881	TATYANA IVANOVA	{"phone": "+70804340686"}
0005435310874	8A5B17	2557 905930	VIKTOR ABRAMOV	{"phone": "+70004861600"}
0005435310875	8A5B17	2848 731073	ELENA SMIRNOVA	{"email": "smirnovaelena-021970@postgrespro.ru", "phone": "+70071802811"}
0005435310876	1A2307	6470 328450	OLGA CHERNOVA	{"phone": "+70780327254"}
0005435310877	885972	4320 564894	ELIZAVETA ZHURAVLEVA	{"email": "zhuravleva-elizaveta.04121971@postgrespro.ru", "phone": "+70066231650"}
0005435310878	466E64	6778 652441	ANNA KUZMINA	{"email": "kuzminaa-12031976@postgrespro.ru", "phone": "+70270029627"}
0005435310879	466E64	6169 765057	NINA IVANOVA	{"phone": "+70335352136"}
0005435310880	66C08A	7174 330473	ALEKSANDR DENISOV	{"phone": "+70326691991"}
0005435310881	66C08A	4803 319580	SERGEY SCHERBAKOV	{"phone": "+70505761246"}
0005435310882	8CBF45	0524 715209	EKATERINA POPOVA	{"phone": "+70775828123"}
0005435310883	CA6360	7487 584647	IRINA EFIMOVA	{"email": "iefimova_121969@postgrespro.ru", "phone": "+70860053964"}
0005435310884	03F0ED	8294 019006	VENERA YAKOVLEVA	{"email": "yakovleva_v-1970@postgrespro.ru", "phone": "+70019898393"}
0005435310885	03F0ED	3555 456587	VLADIMIR TIKHONOV	{"email": "tikhonov.vladimir1964@postgrespro.ru", "phone": "+70706693168"}
0005435310886	899420	7960 790271	LIDIYA SEMENOVA	{"email": "semenova-lidiya_1966@postgrespro.ru", "phone": "+70963238885"}
0005435310887	FAF831	1710 740449	ALEKSANDRA ANTONOVA	{"phone": "+70389749499"}
0005435310888	2C6D57	3976 677130	DMITRIY FROLOV	{"phone": "+70236052881"}
0005435310889	9FF577	5926 340768	MARIYA ZHUKOVA	{"phone": "+70977164770"}
0005435310890	D43C6B	5008 028863	VLADIMIR SEMENOV	{"phone": "+70599651424"}
0005435310891	909861	9222 545466	LYUDMILA RODIONOVA	{"email": "lyudmila-rodionova-1963@postgrespro.ru", "phone": "+70629642080"}
0005435310892	909861	0808 944190	MATVEY BONDARENKO	{"email": "matvey-bondarenko06091984@postgrespro.ru", "phone": "+70446604972"}
0005435310893	5743D6	4550 743895	OLGA STEPANOVA	{"phone": "+70574296162"}
0005435310894	40DC5D	5317 375401	ELENA MOISEEVA	{"email": "emoiseeva1964@postgrespro.ru", "phone": "+70693504190"}
0005435310895	F9774E	8178 490862	YURIY KUZMIN	{"phone": "+70084128060"}
0005435310896	C3923A	9911 514730	ALEKSANDR PAVLOV	{"phone": "+70127663030"}
0005435310897	C3923A	4012 514023	VALENTINA ZAYCEVA	{"email": "zaycevavalentina.06061964@postgrespro.ru", "phone": "+70433803383"}
0005435310898	C3923A	2492 255360	NADEZHDA MATVEEVA	{"email": "matveeva_nadezhda.061967@postgrespro.ru", "phone": "+70441499532"}
0005435310899	B354A3	1497 949225	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova_1973@postgrespro.ru", "phone": "+70676696260"}
0005435310900	773265	5106 062619	ELENA KUZMINA	{"email": "elenakuzmina-09111987@postgrespro.ru", "phone": "+70371662678"}
0005435310901	2135EA	1856 251403	ILYAS GRIGOREV	{"phone": "+70550029024"}
0005435310902	8CBEA0	8305 538055	ELENA PETROVA	{"email": "elena-petrova_081969@postgrespro.ru", "phone": "+70822439802"}
0005435310903	8CBEA0	5653 789545	VLADIMIR KUDRYASHOV	{"email": "vladimir.kudryashov_031969@postgrespro.ru", "phone": "+70789713628"}
0005435310904	8CBEA0	7793 271873	VYACHESLAV ISAEV	{"email": "isaev_v19011970@postgrespro.ru", "phone": "+70719791027"}
0005435310905	C48943	2944 981357	ANATOLIY ZAYCEV	{"phone": "+70792219215"}
0005435310906	D05BDC	2779 093256	ANDREY IVANOV	{"email": "ivanov_andrey.1974@postgrespro.ru", "phone": "+70922265489"}
0005435310907	791DD2	2455 994919	VALENTINA ILINA	{"phone": "+70772591014"}
0005435310908	D416FB	1378 668915	GALINA CHERNOVA	{"email": "chernova.galina-041962@postgrespro.ru", "phone": "+70693915722"}
0005435310909	124E93	4574 794150	OLEG STEPANOV	{"phone": "+70423435910"}
0005435310910	124E93	0165 268647	ALEKSANDR DAVYDOV	{"phone": "+70692946798"}
0005435310911	E9AF5A	0726 806730	ALEKSEY SEMENOV	{"email": "semenov.aleksey.20061960@postgrespro.ru", "phone": "+70601339607"}
0005435310912	E9AF5A	7476 054771	ROMAN MIKHAYLOV	{"email": "mikhaylov.roman_22031970@postgrespro.ru", "phone": "+70495191609"}
0005435310913	E9AF5A	4087 268677	LYUBOV ISAEVA	{"email": "isaeva.l_051975@postgrespro.ru", "phone": "+70199522896"}
0005435310914	C91E2D	3792 121077	VIKTOR MAKAROV	{"email": "v.makarov011968@postgrespro.ru", "phone": "+70370137632"}
0005435310915	139695	7269 252565	GENNADIY BELOV	{"email": "g-belov_1962@postgrespro.ru", "phone": "+70496228715"}
0005435310916	139695	9365 915519	ANDREY PAVLOV	{"email": "pavlov_a-1975@postgrespro.ru", "phone": "+70849482882"}
0005435310917	71D0C3	3484 018582	ALEKSANDR VOLKOV	{"email": "volkov-a_021976@postgrespro.ru", "phone": "+70294641692"}
0005435310918	02D0D0	0510 457357	ANDREY RODIONOV	{"email": "andrey.rodionov_1967@postgrespro.ru", "phone": "+70524257642"}
0005435310919	9B751C	8925 798472	YURIY YAKOVLEV	{"email": "yakovlev-yuriy_051980@postgrespro.ru", "phone": "+70447715394"}
0005435310920	D39F5A	7927 107287	MAKSIM MIRONOV	{"email": "mironovmaksim.19031969@postgrespro.ru", "phone": "+70058771951"}
0005435310921	D39F5A	1072 704896	ELENA FOMINA	{"phone": "+70813624501"}
0005435310922	F8C6AB	2930 511948	ELIZAVETA KUZNECOVA	{"phone": "+70141286350"}
0005435310923	C520B2	6480 116433	EKATERINA MAKSIMOVA	{"email": "maksimova-e091985@postgrespro.ru", "phone": "+70194799754"}
0005435310924	43DB95	1295 688681	ZOYA ZAKHAROVA	{"phone": "+70338595451"}
0005435310925	850D9A	0341 089004	LYUBOV NAZAROVA	{"email": "nazarova.lyubov-04051980@postgrespro.ru", "phone": "+70656403712"}
0005435310926	0C22DF	8095 871440	VALENTINA BORISOVA	{"phone": "+70027780220"}
0005435310927	0C22DF	4262 977866	ALEKSEY KARPOV	{"email": "karpov_a-02031974@postgrespro.ru", "phone": "+70638673184"}
0005435310928	0C22DF	8409 154430	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a_29111979@postgrespro.ru", "phone": "+70447756251"}
0005435310929	24DCD2	1376 419835	VALENTINA GRISHINA	{"phone": "+70201687788"}
0005435310930	5833C6	5955 304271	EKATERINA KUZNECOVA	{"email": "ekuznecova.011979@postgrespro.ru", "phone": "+70619371912"}
0005435310931	5A7F36	3926 841445	SERGEY MAKAROV	{"phone": "+70505605588"}
0005435310932	3F12FA	7413 710524	SVETLANA DMITRIEVA	{"phone": "+70594558605"}
0005435310933	3F12FA	3860 916313	VYACHESLAV FROLOV	{"phone": "+70509752868"}
0005435310934	3F12FA	5729 886379	ANTON NAUMOV	{"phone": "+70496694598"}
0005435310935	5F004D	5846 763471	MAKSIM ZHURAVLEV	{"email": "zhuravlevmaksim_25121985@postgrespro.ru", "phone": "+70029440803"}
0005435310936	01313D	9513 862490	RAUF ZAKHAROV	{"phone": "+70232958085"}
0005435310937	938780	6814 197736	ANNA SOLOVEVA	{"phone": "+70644127337"}
0005435310938	7144AA	4503 342538	ANATOLIY IVANOV	{"email": "ivanov.anatoliy_1967@postgrespro.ru", "phone": "+70359184623"}
0005435310939	86B558	9147 334354	OLGA ANTONOVA	{"phone": "+70654890452"}
0005435310940	86B558	4579 340376	VALERIY ALEKSEEV	{"phone": "+70897391986"}
0005435310941	3E294C	0535 760154	ASKAR SCHERBAKOV	{"email": "askar-scherbakov.14021969@postgrespro.ru", "phone": "+70702586121"}
0005435310942	9CB449	7967 230272	VERA PETROVA	{"phone": "+70498418980"}
0005435310943	1C5A2E	3542 129891	SVETLANA KOROLEVA	{"phone": "+70072084265"}
0005435310944	BD4212	7233 668550	ANDREY GERASIMOV	{"email": "gerasimov.andrey_30011975@postgrespro.ru", "phone": "+70844133891"}
0005435310945	382C2F	3035 346375	IVAN IVANOV	{"phone": "+70275672842"}
0005435310946	92F346	7375 058809	LIYA SIDOROVA	{"email": "liyasidorova-121976@postgrespro.ru", "phone": "+70386232567"}
0005435310947	5332AB	1427 845580	ANNA KUZMINA	{"phone": "+70854980616"}
0005435310948	933283	8157 093214	TATYANA SEMENOVA	{"email": "tsemenova15031980@postgrespro.ru", "phone": "+70534408544"}
0005435310949	CE08C3	7088 349253	LYUBOV FEDOROVA	{"phone": "+70257590644"}
0005435310950	873F6C	1980 668052	ANDREY MOISEEV	{"email": "a-moiseev.1964@postgrespro.ru", "phone": "+70552743125"}
0005435310951	AC92AE	5431 816333	ALEKSANDR FOMIN	{"email": "afomin.04121976@postgrespro.ru", "phone": "+70183360456"}
0005435310952	5B0B0E	5946 030789	ILYA KUZNECOV	{"email": "ilya.kuznecov-1968@postgrespro.ru", "phone": "+70783919512"}
0005435310953	17D309	4713 349929	VALERIY VLASOV	{"email": "valeriy.vlasov09091970@postgrespro.ru", "phone": "+70805684620"}
0005435310954	17D309	7368 135617	VALERIY TIKHONOV	{"email": "tikhonov.valeriy.12041970@postgrespro.ru", "phone": "+70541528127"}
0005435310955	17D309	7690 879578	VALENTINA BARANOVA	{"phone": "+70405599365"}
0005435310956	9A77C3	2881 445124	VLADIMIR KUZNECOV	{"phone": "+70104174698"}
0005435310957	CD276D	6604 071073	GALINA GAVRILOVA	{"email": "ggavrilova011986@postgrespro.ru", "phone": "+70035253291"}
0005435310958	77697A	6667 524688	SERGEY NIKITIN	{"email": "s.nikitin_121961@postgrespro.ru", "phone": "+70574397872"}
0005435310959	77697A	4661 226534	SVETLANA KUZNECOVA	{"email": "s-kuznecova1972@postgrespro.ru", "phone": "+70567443371"}
0005435310960	3B51BD	8142 104289	EVGENIY DAVYDOV	{"email": "e_davydov-1972@postgrespro.ru", "phone": "+70431188408"}
0005435310961	C705E2	7932 290155	ANDREY MOISEEV	{"phone": "+70821566166"}
0005435310962	C705E2	4365 309398	NATALYA KUZNECOVA	{"email": "kuznecovan121967@postgrespro.ru", "phone": "+70476797895"}
0005435310963	F34318	7356 992908	DENIS DMITRIEV	{"email": "d.dmitriev_101967@postgrespro.ru", "phone": "+70105926709"}
0005435310964	E40281	6344 894468	SERGEY KUZNECOV	{"email": "sergey-kuznecov.091973@postgrespro.ru", "phone": "+70452866627"}
0005435310965	E40281	9324 656611	VALENTINA MAKSIMOVA	{"email": "maksimova-v.1991@postgrespro.ru", "phone": "+70832155604"}
0005435310966	C60CF4	1437 339618	VALERIY GORBUNOV	{"email": "gorbunov_v.021963@postgrespro.ru", "phone": "+70639731007"}
0005435310967	9E7BBA	2167 175287	ALLA TROFIMOVA	{"email": "alla-trofimova_121974@postgrespro.ru", "phone": "+70249339425"}
0005435310968	2419E2	4910 463769	YULIYA YAKOVLEVA	{"email": "yakovleva-yuliya_1968@postgrespro.ru", "phone": "+70310100080"}
0005435310969	DB5E4B	5932 523500	NATALYA SERGEEVA	{"phone": "+70300405735"}
0005435310970	B874FA	4872 317764	EVGENIY TIKHONOV	{"email": "evgeniy.tikhonov111971@postgrespro.ru", "phone": "+70281741229"}
0005435310971	B44BCA	1862 551156	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr_031970@postgrespro.ru", "phone": "+70246319528"}
0005435310972	4B6353	3348 510518	ANDREY KOROLEV	{"email": "andrey.korolev02121970@postgrespro.ru", "phone": "+70028713143"}
0005435310973	4B6353	9155 122867	OLGA MEDVEDEVA	{"email": "medvedeva-o011980@postgrespro.ru", "phone": "+70930829021"}
0005435310974	0F6981	9602 525617	LYUDMILA BELYAEVA	{"email": "belyaeval.02081961@postgrespro.ru", "phone": "+70195737298"}
0005435310975	0F6981	9870 458750	VIKTOR MAKAROV	{"phone": "+70824085616"}
0005435310976	63DECA	5834 948197	ARTUR DMITRIEV	{"phone": "+70371596053"}
0005435310977	63DECA	8917 077011	OKSANA NAUMOVA	{"phone": "+70581718746"}
0005435310978	F00C0C	9499 879112	TATYANA FILATOVA	{"phone": "+70803411747"}
0005435310980	22D32A	9813 389731	OLGA PETROVA	{"phone": "+70357149941"}
0005435310981	5D0164	7323 682425	ALEKSEY DMITRIEV	{"phone": "+70735146780"}
0005435310982	76763D	5844 018986	NATALYA MEDVEDEVA	{"email": "n_medvedeva-091963@postgrespro.ru", "phone": "+70592097579"}
0005435310983	76763D	8599 268572	LYUBOV ILINA	{"phone": "+70668282187"}
0005435310984	0CCF7C	6903 875395	TATYANA NIKITINA	{"email": "t.nikitina.031962@postgrespro.ru", "phone": "+70444498382"}
0005435310985	5E78C5	8156 284688	ALEKSEY BELOV	{"phone": "+70839238919"}
0005435310986	3C58D1	3794 538981	VLADISLAV DMITRIEV	{"phone": "+70852274255"}
0005435310987	3C58D1	7532 497723	MATVEY SAVELEV	{"email": "m-savelev-051975@postgrespro.ru", "phone": "+70015057311"}
0005435310988	CB9EC0	2708 272122	SERGEY ORLOV	{"email": "orlov-sergey-1989@postgrespro.ru", "phone": "+70877330526"}
0005435310989	C9D420	2242 153574	ANDREY ANDREEV	{"phone": "+70043091628"}
0005435310990	C9D420	4400 506274	ILYA SERGEEV	{"email": "sergeev.ilya.111974@postgrespro.ru", "phone": "+70419264833"}
0005435310991	6BD71A	9537 249649	SERGEY EGOROV	{"email": "egorov-sergey.091967@postgrespro.ru", "phone": "+70111091853"}
0005435310992	76DF65	7231 102925	TATYANA IVANOVA	{"phone": "+70212236578"}
0005435310993	76DF65	2618 820203	NIKOLAY MEDVEDEV	{"email": "medvedev.n31011953@postgrespro.ru", "phone": "+70714816187"}
0005435310994	B60BF8	7426 677022	DMITRIY ZAKHAROV	{"email": "dmitriyzakharov_31071977@postgrespro.ru", "phone": "+70228082692"}
0005435310995	B60BF8	5559 755204	NINA OVCHINNIKOVA	{"email": "ovchinnikova_n-03051968@postgrespro.ru", "phone": "+70491849695"}
0005435310996	FF90CB	7888 887087	VERA POTAPOVA	{"email": "v_potapova_1978@postgrespro.ru", "phone": "+70130410514"}
0005435310997	B620A0	2646 179172	ALEKSEY SOROKIN	{"phone": "+70172659592"}
0005435310998	76B550	8416 977479	VYACHESLAV KUZNECOV	{"email": "vyacheslav-kuznecov1977@postgrespro.ru", "phone": "+70657846119"}
0005435310999	6EA0B1	8853 719680	EKATERINA NOVIKOVA	{"email": "novikova_e_31121969@postgrespro.ru", "phone": "+70547589506"}
0005435311000	626B3D	7153 225278	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d061981@postgrespro.ru", "phone": "+70487269664"}
0005435311001	BFEFC4	8019 360191	OLEG SOLOVEV	{"email": "o_solovev.1974@postgrespro.ru", "phone": "+70478690376"}
0005435311002	BFEFC4	7917 315644	ANNA ARKHIPOVA	{"email": "anna_arkhipova_18101960@postgrespro.ru", "phone": "+70600221939"}
0005435311003	10785C	2579 097544	EKATERINA GUSEVA	{"email": "ekaterina_guseva_1968@postgrespro.ru", "phone": "+70299662038"}
0005435311004	8C1A72	7398 022591	GALINA KUZMINA	{"email": "kuzmina_g.111971@postgrespro.ru", "phone": "+70232129864"}
0005435311005	82B041	9770 342235	IVAN NAUMOV	{"phone": "+70087147692"}
0005435311006	90D00B	5359 614433	ANATOLIY KAZAKOV	{"email": "kazakova-20051976@postgrespro.ru", "phone": "+70440105276"}
0005435311007	559417	3823 734498	OLGA PAVLOVA	{"email": "pavlova.olga1962@postgrespro.ru", "phone": "+70039956144"}
0005435311008	D2B277	0909 243476	IRINA EFIMOVA	{"email": "efimova-i-061978@postgrespro.ru", "phone": "+70701182831"}
0005435311009	203B1A	7399 716548	OLGA MOROZOVA	{"phone": "+70338894816"}
0005435311010	118B64	1536 953620	TAMARA DAVYDOVA	{"email": "tamaradavydova_1974@postgrespro.ru", "phone": "+70602261786"}
0005435311011	7B1C2A	5048 363663	MARINA SOROKINA	{"email": "m-sorokina.031976@postgrespro.ru", "phone": "+70897710844"}
0005435311012	7B1C2A	6542 157740	ANDREY YAKOVLEV	{"phone": "+70001812345"}
0005435311013	B2F829	7558 102271	ANDREY VOLKOV	{"email": "a-volkov.021980@postgrespro.ru", "phone": "+70703119435"}
0005435311014	6C1824	2321 994738	ANNA BELYAEVA	{"email": "belyaeva.anna_081963@postgrespro.ru", "phone": "+70476752000"}
0005435311015	11C821	7415 020842	MAKSIM YAKOVLEV	{"phone": "+70260653699"}
0005435311016	FD72C1	3157 576537	NATALYA LEBEDEVA	{"phone": "+70528163769"}
0005435311017	FD72C1	0406 718670	GALINA LOGINOVA	{"phone": "+70282964248"}
0005435311018	EDFD9F	7176 646723	VALENTINA SERGEEVA	{"phone": "+70900106779"}
0005435311019	EDFD9F	1444 985323	DMITRIY SERGEEV	{"phone": "+70629298073"}
0005435311020	E1B798	0206 877406	VITALIY KRASNOV	{"phone": "+70262741151"}
0005435311021	E1B798	9049 259241	TATYANA ALEKSANDROVA	{"email": "t-aleksandrova.071972@postgrespro.ru", "phone": "+70226781160"}
0005435311022	A86264	3736 504898	MARINA KOROLEVA	{"email": "m_koroleva-1979@postgrespro.ru", "phone": "+70535148796"}
0005435311023	79EB45	6430 165070	SVETLANA KUZNECOVA	{"phone": "+70269385800"}
0005435311024	6A8982	2089 326658	SERGEY VASILEV	{"email": "vasilev-s_10071959@postgrespro.ru", "phone": "+70129962206"}
0005435311025	6A8982	3153 788552	MARIYA MATVEEVA	{"phone": "+70780989353"}
0005435311026	A24F5C	3091 800968	ALEKSANDR KISELEV	{"phone": "+70941296995"}
0005435311027	800347	6799 474747	RUSLAN ORLOV	{"email": "ruslan.orlov.031977@postgrespro.ru", "phone": "+70864811587"}
0005435311028	800347	8883 434201	OKSANA KUZNECOVA	{"phone": "+70304565620"}
0005435311029	E2D9FA	5873 189757	DMITRIY ILIN	{"phone": "+70268695446"}
0005435311030	859190	0336 411293	DANILA STEPANOV	{"email": "danila.stepanov-10081976@postgrespro.ru", "phone": "+70314900786"}
0005435311031	859190	3633 237065	PETR NIKOLAEV	{"email": "nikolaev_petr_121966@postgrespro.ru", "phone": "+70910619450"}
0005435311032	E6CC8F	2574 556823	STANISLAV SEMENOV	{"email": "s-semenov.19071980@postgrespro.ru", "phone": "+70524051241"}
0005435311033	3FC69E	3867 794001	VALENTINA NAUMOVA	{"phone": "+70461222874"}
0005435311034	3FC69E	9792 022647	ALEKSEY PETROV	{"phone": "+70255939079"}
0005435311035	BDB298	0903 411943	NIKITA AFANASEV	{"phone": "+70458097598"}
0005435311036	226388	3048 289503	VLADIMIR FOMIN	{"phone": "+70902076591"}
0005435311037	F8A1C0	5104 932080	RAISA MIRONOVA	{"email": "raisa.mironova_06111973@postgrespro.ru", "phone": "+70811796352"}
0005435311038	F94C1B	1893 082348	SOFYA ILINA	{"email": "ilina.sofya_1981@postgrespro.ru", "phone": "+70898433145"}
0005435311039	A90959	0946 278072	VALENTINA POPOVA	{"phone": "+70765722697"}
0005435311040	A90959	1834 650725	NADEZHDA EFIMOVA	{"email": "n_efimova_21111966@postgrespro.ru", "phone": "+70179980704"}
0005435311041	F02DB8	3282 347072	SVETLANA ALEKSEEVA	{"phone": "+70062495399"}
0005435311042	F02DB8	4200 542176	INNA IVANOVA	{"email": "i-ivanova_1959@postgrespro.ru", "phone": "+70461938581"}
0005435311043	CC5EE4	8292 000840	RAISA POLYAKOVA	{"phone": "+70382225817"}
0005435311044	CC5EE4	9103 144368	DANILA ROMANOV	{"email": "romanov.danila-20041973@postgrespro.ru", "phone": "+70756647659"}
0005435311045	1967D3	6896 399825	OLEG GAVRILOV	{"email": "o_gavrilov.09121978@postgrespro.ru", "phone": "+70228993756"}
0005435311046	0D04C3	1473 212351	ALEKSEY KUDRYASHOV	{"phone": "+70465996916"}
0005435311047	0D04C3	7946 829868	ALEKSANDR MELNIKOV	{"email": "melnikov.aleksandr1975@postgrespro.ru", "phone": "+70577744107"}
0005435311048	45314A	7830 989113	NIKOLAY ORLOV	{"phone": "+70984732070"}
0005435311049	74A4D9	7904 769111	ELENA MAKAROVA	{"phone": "+70307227146"}
0005435311050	74A4D9	0538 975790	LYUDMILA ALEKSANDROVA	{"email": "aleksandrova_l.1969@postgrespro.ru", "phone": "+70659688099"}
0005435311051	65080D	0208 170006	FLYURA MAKAROVA	{"email": "f.makarova-1970@postgrespro.ru", "phone": "+70023938532"}
0005435311052	65A751	8012 118783	MIKHAIL ZAKHAROV	{"phone": "+70060884952"}
0005435311053	55D145	0027 883421	OLEG IVANOV	{"phone": "+70717264366"}
0005435311054	0BE3CD	8488 513158	ANATOLIY SEMENOV	{"email": "semenov_a.16121972@postgrespro.ru", "phone": "+70714727577"}
0005435311055	7910F5	9299 946033	ROMAN KISELEV	{"email": "kiselevroman_1968@postgrespro.ru", "phone": "+70211662319"}
0005435311056	91FE7A	6522 902620	MARIYA NESTEROVA	{"email": "mariya_nesterova1976@postgrespro.ru", "phone": "+70052870314"}
0005435311057	91FE7A	5658 398925	VALENTINA KULIKOVA	{"phone": "+70469444986"}
0005435311058	203BEC	1547 110620	SERGEY TARASOV	{"phone": "+70815126005"}
0005435311059	10C4BD	8827 447334	TATYANA MALYSHEVA	{"phone": "+70172303142"}
0005435311060	67ED85	9546 539451	SERGEY NAUMOV	{"phone": "+70973334175"}
0005435311061	375056	6036 482521	ALEKSEY ORLOV	{"email": "alekseyorlov24011978@postgrespro.ru", "phone": "+70325084801"}
0005435311062	3B9C42	9737 966374	VALENTINA ROMANOVA	{"email": "valentinaromanova061976@postgrespro.ru", "phone": "+70393451674"}
0005435311063	7F71F6	0301 602556	OLGA DENISOVA	{"email": "olga_denisova1968@postgrespro.ru", "phone": "+70984483909"}
0005435311064	6FCEF8	0934 982682	LIDIYA ZOTOVA	{"email": "l-zotova.1968@postgrespro.ru", "phone": "+70045246116"}
0005435311065	7FB407	9876 262744	ANNA LUKYANOVA	{"email": "anna-lukyanova-1978@postgrespro.ru", "phone": "+70876487480"}
0005435311066	EF1369	4236 376458	EVGENIY DENISOV	{"email": "evgeniy-denisov011974@postgrespro.ru", "phone": "+70306409540"}
0005435311067	EF1369	3197 521092	ROZA STEPANOVA	{"phone": "+70539301522"}
0005435311068	1FE275	8792 945683	YURIY CHERNOV	{"phone": "+70169144773"}
0005435311069	F5A75F	3503 264530	VALENTINA FEDOROVA	{"phone": "+70776295264"}
0005435311070	2152B1	0274 883943	ILYAS ORLOV	{"email": "orlov_ilyas.1977@postgrespro.ru", "phone": "+70565587930"}
0005435311071	5AB236	7902 292629	VASILIY MARTYNOV	{"phone": "+70669052777"}
0005435311072	5AB236	3565 958586	LYUDMILA MAKSIMOVA	{"phone": "+70427912796"}
0005435311073	EBE1F9	3341 692784	NINA GAVRILOVA	{"email": "nina.gavrilova13111973@postgrespro.ru", "phone": "+70027245486"}
0005435311074	B36E1B	6974 771982	ALEKSEY MELNIKOV	{"phone": "+70401598780"}
0005435311075	FAF3A5	5622 125062	VIKTOR MEDVEDEV	{"phone": "+70019283386"}
0005435311076	FAF3A5	8329 618480	ANTONINA ZAKHAROVA	{"phone": "+70733404259"}
0005435311077	8AD6C9	2395 968812	VLADIMIR ALEKSANDROV	{"phone": "+70271750353"}
0005435311078	175824	7406 749773	ANNA PAVLOVA	{"phone": "+70599148476"}
0005435311079	175824	6142 040331	YULIYA NIKOLAEVA	{"phone": "+70277617389"}
0005435311080	175824	9580 108715	VYACHESLAV SOKOLOV	{"phone": "+70576013838"}
0005435311081	71FB4A	7925 454587	VERA LOGINOVA	{"phone": "+70159001214"}
0005435311082	71FB4A	7712 858367	ALEKSANDR PETROV	{"phone": "+70647652208"}
0005435311083	A400B1	9269 325067	ANDREY ILIN	{"email": "ilin.a-1961@postgrespro.ru", "phone": "+70361628110"}
0005435311084	9590F9	4712 014088	KLAVDIYA BARANOVA	{"email": "baranova_klavdiya18101963@postgrespro.ru", "phone": "+70412912858"}
0005435311085	9D9237	5070 788821	ALEKSEY TIKHONOV	{"phone": "+70860725723"}
0005435311086	263D65	5092 537737	ARINA ANDREEVA	{"email": "andreevaarina.26011974@postgrespro.ru", "phone": "+70454103129"}
0005435311087	200014	4194 671999	MARK BORISOV	{"email": "mark-borisov.011974@postgrespro.ru", "phone": "+70138527248"}
0005435311088	666389	5331 771663	VERA FILATOVA	{"email": "filatova_v.1970@postgrespro.ru", "phone": "+70267608944"}
0005435311089	D680B2	8284 283655	OLGA IVANOVA	{"phone": "+70869671606"}
0005435311090	D680B2	3671 994214	ELEONORA GAVRILOVA	{"phone": "+70490459385"}
0005435311091	718F6F	5091 657465	INESSA ERMAKOVA	{"email": "iermakova_1965@postgrespro.ru", "phone": "+70400960141"}
0005435311092	718F6F	9748 203264	LYUDMILA DAVYDOVA	{"phone": "+70158823760"}
0005435311093	927625	7631 731597	VLADIMIR GAVRILOV	{"phone": "+70078589367"}
0005435311094	CDCF38	0534 273193	VALENTINA BELOVA	{"email": "belova_v22101981@postgrespro.ru", "phone": "+70964855520"}
0005435311095	CDCF38	2523 175830	EVGENIY SOKOLOV	{"email": "sokolov_e_1969@postgrespro.ru", "phone": "+70922038582"}
0005435311096	2C4EFC	9022 403497	VLADIMIR MEDVEDEV	{"phone": "+70623831732"}
0005435311097	D2B40F	1327 375089	IGOR KUZNECOV	{"phone": "+70122474237"}
0005435311098	D2B40F	2337 410372	ANASTASIYA FILIPPOVA	{"email": "filippova-a-18071970@postgrespro.ru", "phone": "+70230300098"}
0005435311099	25994C	8233 081566	PETR SOKOLOV	{"phone": "+70157873505"}
0005435311100	148CBF	0911 075381	VLADIMIR VASILEV	{"phone": "+70042278237"}
0005435311101	148CBF	7975 303715	GALINA EGOROVA	{"phone": "+70945112511"}
0005435311102	148CBF	3011 633470	ANTON AFANASEV	{"email": "anton_afanasev-021967@postgrespro.ru", "phone": "+70729870783"}
0005435311103	EA7C9B	2763 584631	VIKTOR KONOVALOV	{"email": "konovalovv1973@postgrespro.ru", "phone": "+70370007874"}
0005435311104	EA7C9B	7219 420018	SERGEY ANDREEV	{"email": "andreev.sergey1967@postgrespro.ru", "phone": "+70115772036"}
0005435311105	E8AF67	2399 799477	VALENTINA SOLOVEVA	{"email": "solovevavalentina.1974@postgrespro.ru", "phone": "+70521169750"}
0005435311106	F5CD47	3489 840442	TATYANA VOLKOVA	{"email": "volkovat_011972@postgrespro.ru", "phone": "+70110807578"}
0005435311107	F5CD47	3627 171000	VLADIMIR GAVRILOV	{"email": "vladimir_gavrilov-1979@postgrespro.ru", "phone": "+70932973189"}
0005435311108	F5CD47	3369 322777	NATALIYA PETROVA	{"email": "petrova.n-111974@postgrespro.ru", "phone": "+70637791182"}
0005435311109	AD85A3	0214 798608	ANNA TITOVA	{"phone": "+70505605088"}
0005435311110	6AE3C8	8748 349484	NAIL MELNIKOV	{"email": "melnikov-nail.1972@postgrespro.ru", "phone": "+70273561260"}
0005435311111	6AE3C8	5056 653796	NADEZHDA ZAYCEVA	{"phone": "+70218022426"}
0005435311112	06D5B2	1122 033833	EVGENIY KUZNECOV	{"phone": "+70483823452"}
0005435311113	06D5B2	6418 585253	YURIY BORISOV	{"email": "yuriy.borisov1970@postgrespro.ru", "phone": "+70292375891"}
0005435311114	ABF6D8	1110 075981	ANATOLIY KUZNECOV	{"email": "kuznecov_anatoliy-08061971@postgrespro.ru", "phone": "+70189254457"}
0005435311115	1C2959	4665 203243	RAMIL GRIGOREV	{"phone": "+70563397758"}
0005435311116	1C2959	4272 489322	MARIYA ERMAKOVA	{"email": "ermakova_m-17071980@postgrespro.ru", "phone": "+70534550482"}
0005435311117	C145D9	9960 843442	SERGEY KUZNECOV	{"phone": "+70617758453"}
0005435311118	C145D9	2549 928322	DENIS ZHURAVLEV	{"phone": "+70697963734"}
0005435311119	26B5F6	5540 208020	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey_041974@postgrespro.ru", "phone": "+70480598249"}
0005435311120	76E96F	8373 013706	EKATERINA NAZAROVA	{"phone": "+70478369944"}
0005435311121	35D363	2058 051843	PAVEL SOROKIN	{"email": "sorokinpavel-16081976@postgrespro.ru", "phone": "+70091303421"}
0005435311122	0781B5	7120 108573	NIKOLAY KISELEV	{"email": "kiselevn.1960@postgrespro.ru", "phone": "+70588106634"}
0005435311123	2AA6B3	9562 833533	GALINA EGOROVA	{"phone": "+70627349648"}
0005435311124	F3298D	9533 117884	ANASTASIYA RODIONOVA	{"email": "rodionova.a_13051969@postgrespro.ru", "phone": "+70227169679"}
0005435311125	F3298D	1586 395562	VLADIMIR YAKOVLEV	{"phone": "+70434200967"}
0005435311126	47F984	6766 482107	MARIYA MELNIKOVA	{"email": "melnikova.mariya.051981@postgrespro.ru", "phone": "+70095537049"}
0005435311127	68FE1D	3930 164836	LEONID NIKITIN	{"phone": "+70747050173"}
0005435311128	866CDE	6071 884424	YAROSLAV ABRAMOV	{"email": "abramov.yaroslav.051974@postgrespro.ru", "phone": "+70514196973"}
0005435311129	D9FDF3	9970 939480	LIDIYA PETROVA	{"email": "petrova-lidiya.1968@postgrespro.ru", "phone": "+70332661940"}
0005435311130	ED0822	5376 756460	DMITRIY DAVYDOV	{"phone": "+70786523487"}
0005435311131	B91D16	6668 309093	DMITRIY KAZAKOV	{"phone": "+70400003897"}
0005435311132	B91D16	8545 757044	TATYANA EFREMOVA	{"email": "efremova_tatyana_091975@postgrespro.ru", "phone": "+70611125674"}
0005435311133	339411	8893 998207	TAMARA NIKITINA	{"phone": "+70486625729"}
0005435311134	339411	0171 879513	ELENA KUZMINA	{"email": "kuzmina.e.1971@postgrespro.ru", "phone": "+70608441516"}
0005435311135	86795B	9051 853542	OLGA NOVIKOVA	{"email": "onovikova101982@postgrespro.ru", "phone": "+70170736232"}
0005435311136	86795B	5707 526913	NIKOLAY KUZMIN	{"phone": "+70746823207"}
0005435311137	914B7A	8075 966573	VYACHESLAV KUZNECOV	{"phone": "+70705268791"}
0005435311138	B106FD	7407 526080	MARINA IVANOVA	{"email": "m.ivanova_07011978@postgrespro.ru", "phone": "+70979032058"}
0005435311139	75B61E	3193 122876	DANILA PETROV	{"email": "danilapetrov-17111969@postgrespro.ru", "phone": "+70531461406"}
0005435311140	75B61E	7254 680528	VLADIMIR ZAKHAROV	{"phone": "+70937224281"}
0005435311141	6BF54D	4028 701826	PAVEL TIMOFEEV	{"phone": "+70877938312"}
0005435311142	6BF54D	1910 462526	GALINA KOROLEVA	{"email": "korolevagalina-091980@postgrespro.ru", "phone": "+70488663860"}
0005435311143	74AE0D	6945 993721	VIKTOR ANTONOV	{"phone": "+70952394294"}
0005435311144	EAAE7D	3125 412623	VALERIY KUZMIN	{"email": "kuzmin_valeriy.021973@postgrespro.ru", "phone": "+70053912782"}
0005435311145	EAAE7D	6995 944175	NIKOLAY NIKOLAEV	{"email": "nnikolaev24091970@postgrespro.ru", "phone": "+70399270629"}
0005435311146	D35588	0548 301191	MARIYA STEPANOVA	{"phone": "+70986586718"}
0005435311147	1A0F0E	0501 835246	VASILIY TARASOV	{"phone": "+70097902594"}
0005435311148	1A0F0E	8828 754152	RAFAEL ORLOV	{"phone": "+70459283321"}
0005435311149	706B01	3988 992082	POLINA OSIPOVA	{"email": "polina_osipova1976@postgrespro.ru", "phone": "+70512189480"}
0005435311150	FA35C7	4864 685300	KIRILL KARPOV	{"phone": "+70032627994"}
0005435311151	168E0A	3144 655206	NINA PETROVA	{"phone": "+70449503922"}
0005435311152	05955D	7330 372210	EVGENIYA GRISHINA	{"phone": "+70218448498"}
0005435311153	DD2175	7216 541227	ALEKSANDR BELOV	{"phone": "+70059377422"}
0005435311154	6A57F4	5315 976910	ARTEM ROMANOV	{"email": "aromanov_011962@postgrespro.ru", "phone": "+70666823054"}
0005435311155	6A57F4	8535 667121	ANATOLIY ZAYCEV	{"email": "anatoliy-zaycev-041979@postgrespro.ru", "phone": "+70687965476"}
0005435311156	3E5659	9697 495685	GUZEL VLASOVA	{"phone": "+70966866420"}
0005435311157	E3C60A	2294 172180	NATALYA OVCHINNIKOVA	{"email": "ovchinnikova_n-05031975@postgrespro.ru", "phone": "+70374759295"}
0005435311158	E3C60A	0085 891114	ZUKHRA KUZNECOVA	{"email": "kuznecova-zukhra_16101964@postgrespro.ru", "phone": "+70502613897"}
0005435311159	438564	8608 777588	RIMMA VOROBEVA	{"email": "vorobeva.rimma061976@postgrespro.ru", "phone": "+70544407928"}
0005435311160	91A0FF	0348 042123	OKSANA VOLKOVA	{"phone": "+70037452197"}
0005435311161	125893	1768 318690	VERA SOKOLOVA	{"email": "vera_sokolova.011973@postgrespro.ru", "phone": "+70849285323"}
0005435311162	E7C9B8	3305 405281	ANNA MELNIKOVA	{"email": "anna-melnikova.081973@postgrespro.ru", "phone": "+70335066072"}
0005435311163	8F8A9B	6806 599855	DMITRIY NIKOLAEV	{"phone": "+70424592351"}
0005435311164	8F8A9B	7410 470366	DANIIL ROMANOV	{"email": "romanov.d1978@postgrespro.ru", "phone": "+70281508483"}
0005435311165	8F8A9B	3339 945282	ANATOLIY MAKAROV	{"email": "anatoliy-makarov.16121960@postgrespro.ru", "phone": "+70125297527"}
0005435311166	648B88	7879 360678	ALEKSEY KULIKOV	{"email": "a-kulikov.081981@postgrespro.ru", "phone": "+70694553431"}
0005435311167	648B88	5120 529231	ALEKSANDR SERGEEV	{"phone": "+70383322187"}
0005435311168	648B88	5470 168550	OLGA YAKOVLEVA	{"email": "o.yakovleva1974@postgrespro.ru", "phone": "+70629782755"}
0005435311169	18B440	4776 058570	PAVEL SOLOVEV	{"phone": "+70204159185"}
0005435311170	E3823D	1054 349628	ANDREY IVANOV	{"email": "andrey.ivanov1962@postgrespro.ru", "phone": "+70164369224"}
0005435311171	B704FA	9301 987790	ZOYA ROMANOVA	{"phone": "+70230083698"}
0005435311172	53445B	0458 663773	KLAVDIYA MIRONOVA	{"email": "k-mironova-111967@postgrespro.ru", "phone": "+70698771088"}
0005435311173	53445B	0921 289028	VIKTOR IVANOV	{"phone": "+70605136563"}
0005435311174	74A7BB	6311 177405	ANATOLIY FOMIN	{"email": "fomin_anatoliy.1969@postgrespro.ru", "phone": "+70921176881"}
0005435311175	97C3D0	4491 261793	LYUDMILA KAZAKOVA	{"email": "kazakova.l_13011959@postgrespro.ru", "phone": "+70699238898"}
0005435311176	97C3D0	1487 187974	ANASTASIYA KALININA	{"phone": "+70553468140"}
0005435311177	128638	1239 233019	ANNA OSIPOVA	{"email": "a.osipova_1960@postgrespro.ru", "phone": "+70926899581"}
0005435311178	F17163	5869 576166	LYUDMILA KUZNECOVA	{"phone": "+70202383677"}
0005435311179	F17163	6293 925654	NATALYA AFANASEVA	{"email": "afanaseva.natalya_111973@postgrespro.ru", "phone": "+70531639288"}
0005435311180	AF1C90	1873 264374	NATALYA ANDREEVA	{"email": "n-andreeva-1970@postgrespro.ru", "phone": "+70214017192"}
0005435311181	02888B	4618 254805	TATYANA ZHURAVLEVA	{"email": "tatyana.zhuravleva_081966@postgrespro.ru", "phone": "+70163432573"}
0005435311182	673588	1566 403507	ANTONINA MATVEEVA	{"email": "matveevaantonina.30071971@postgrespro.ru", "phone": "+70052636286"}
0005435311183	0E0CCE	1317 078215	VYACHESLAV PETROV	{"phone": "+70107680627"}
0005435311184	2CE311	5956 948691	OLGA MAKSIMOVA	{"email": "maksimova-olga_051979@postgrespro.ru", "phone": "+70541162519"}
0005435311185	2CE311	7249 222617	ELENA SOROKINA	{"phone": "+70146488933"}
0005435311186	23F78C	2105 297619	RAIS ALEKSANDROV	{"email": "aleksandrovrais.041972@postgrespro.ru", "phone": "+70806526854"}
0005435311187	C87B86	5749 562688	SVETLANA PAVLOVA	{"email": "spavlova-17061970@postgrespro.ru", "phone": "+70522572464"}
0005435311188	E95A63	6930 286723	EDUARD SOLOVEV	{"email": "e.solovev1968@postgrespro.ru", "phone": "+70078797719"}
0005435311189	E95A63	9404 467697	ARINA NIKITINA	{"email": "nikitina-a_011974@postgrespro.ru", "phone": "+70895995959"}
0005435311190	C01768	1587 430985	MARIYA VASILEVA	{"phone": "+70252853422"}
0005435311191	461061	3344 987438	TAMARA ALEKSANDROVA	{"phone": "+70303100425"}
0005435311192	461061	7647 172588	LIDIYA IVANOVA	{"phone": "+70878353506"}
0005435311193	8CF9DB	2309 748590	IVAN EGOROV	{"phone": "+70265914483"}
0005435311194	172363	3438 475286	ALEKSANDR KAZAKOV	{"phone": "+70272794760"}
0005435311195	172363	2874 040279	TAMARA ILINA	{"email": "ilina.t_09111963@postgrespro.ru", "phone": "+70271502692"}
0005435311196	7646FA	7199 273885	ALEKSANDR BORISOV	{"email": "borisov.aleksandr.18021972@postgrespro.ru", "phone": "+70315824342"}
0005435311197	5B65F1	1205 906924	MARINA IVANOVA	{"email": "mivanova1985@postgrespro.ru", "phone": "+70616057852"}
0005435311198	5B65F1	0372 799083	LYUDMILA MIRONOVA	{"phone": "+70996188079"}
0005435311199	BD621D	7528 401669	SVETLANA ZAKHAROVA	{"email": "zakharovas_091963@postgrespro.ru", "phone": "+70758218955"}
0005435311200	A83738	0901 542520	MIKHAIL NOVIKOV	{"email": "m_novikov_07081975@postgrespro.ru", "phone": "+70059068236"}
0005435311201	A83738	0022 463873	NIKOLAY MATVEEV	{"email": "n-matveev-121976@postgrespro.ru", "phone": "+70714230050"}
0005435311202	6A19B3	7544 731424	OKSANA ZAKHAROVA	{"email": "zakharova.oksana.071978@postgrespro.ru", "phone": "+70642888886"}
0005435311203	61B704	9594 849942	ALEKSANDR ALEKSEEV	{"phone": "+70846260918"}
0005435311204	D08B28	3685 350429	DENIS IVANOV	{"email": "denisivanov-1973@postgrespro.ru", "phone": "+70256599382"}
0005435311205	D08B28	0196 340685	ROBERT DMITRIEV	{"phone": "+70388668625"}
0005435311206	227B1B	0422 165923	ALEKSANDR TARASOV	{"phone": "+70792547134"}
0005435311207	227B1B	9770 483533	VADIM KAZAKOV	{"email": "vkazakov-1972@postgrespro.ru", "phone": "+70321428546"}
0005435311208	2381E4	6442 272510	YURIY SIDOROV	{"phone": "+70435729669"}
0005435311209	BF83EC	6179 027614	ARTUR VOROBEV	{"email": "vorobeva_26111965@postgrespro.ru", "phone": "+70430081114"}
0005435311210	E45836	8048 396178	VIKTOR TIKHONOV	{"phone": "+70872424729"}
0005435311211	E45836	1356 258859	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov_30051969@postgrespro.ru", "phone": "+70027742809"}
0005435311212	9B0715	8415 445723	YULIYA SOKOLOVA	{"email": "yuliyasokolova19071985@postgrespro.ru", "phone": "+70642711217"}
0005435311213	501BA5	6341 984141	ALEKSANDR SEMENOV	{"phone": "+70750539342"}
0005435311214	14BA5F	0538 585704	PAVEL IVANOV	{"phone": "+70289735341"}
0005435311215	14BA5F	4958 013959	VIKTOR SMIRNOV	{"email": "smirnov_v_20051971@postgrespro.ru", "phone": "+70300166576"}
0005435311216	CC12AA	1410 090448	VALERIY NOVIKOV	{"phone": "+70119686880"}
0005435311217	CC12AA	2916 739640	YURIY EGOROV	{"phone": "+70061214365"}
0005435311218	913CC9	3180 928941	NATALYA ANTONOVA	{"email": "antonovanatalya18061972@postgrespro.ru", "phone": "+70237908900"}
0005435311219	913CC9	7835 829884	ALEKSANDR FROLOV	{"email": "a_frolov.071976@postgrespro.ru", "phone": "+70980401247"}
0005435311220	04D602	7720 693893	VIKTOR IVANOV	{"email": "viktor.ivanov.021979@postgrespro.ru", "phone": "+70377436088"}
0005435311221	B5E620	9815 983834	SERGEY KUZNECOV	{"email": "sergey-kuznecov.071985@postgrespro.ru", "phone": "+70208429680"}
0005435311222	4FBAD6	4768 370990	FEDOR ANDREEV	{"email": "andreevf_14121970@postgrespro.ru", "phone": "+70594550640"}
0005435311223	4FBAD6	3199 851920	VYACHESLAV CHERNOV	{"phone": "+70875003872"}
0005435311224	4FBAD6	7239 103714	LYUDMILA TARASOVA	{"email": "tarasova_lyudmila_19081979@postgrespro.ru", "phone": "+70487697723"}
0005435311225	3E1AF9	7195 007281	MARIYA DANILOVA	{"phone": "+70684680502"}
0005435311226	541AEB	3327 904083	DENIS SERGEEV	{"phone": "+70187384930"}
0005435311227	541AEB	3789 373953	YURIY MAKSIMOV	{"phone": "+70619388126"}
0005435311228	007DBF	1802 870999	VALENTIN IVANOV	{"phone": "+70874281901"}
0005435311229	F75EA8	9485 549676	ELIZAVETA ANDREEVA	{"email": "elizaveta.andreeva_1983@postgrespro.ru", "phone": "+70180135385"}
0005435311230	6CB735	7865 229923	MARIYA NAZAROVA	{"phone": "+70362336303"}
0005435311231	6CB735	4058 158487	ALEKSANDR IVANOV	{"phone": "+70873761216"}
0005435311232	517AC4	7416 296379	EGOR PETROV	{"phone": "+70115553728"}
0005435311233	517AC4	7518 016242	TATYANA NAZAROVA	{"email": "t_nazarova101971@postgrespro.ru", "phone": "+70677365662"}
0005435311234	1BE843	5239 062354	VALERIY OSIPOV	{"phone": "+70169274610"}
0005435311235	1BE843	3781 447171	ILYA YAKOVLEV	{"phone": "+70926313156"}
0005435311236	75E785	8762 768726	GALINA RYABOVA	{"email": "galina.ryabova20021975@postgrespro.ru", "phone": "+70100572149"}
0005435311237	E300AC	7508 548544	GALINA MELNIKOVA	{"email": "g.melnikova01081961@postgrespro.ru", "phone": "+70123894465"}
0005435311238	623127	8867 589161	ALI BONDARENKO	{"email": "ali.bondarenko_121972@postgrespro.ru", "phone": "+70718888460"}
0005435311239	7475CB	0532 530191	IRINA STEPANOVA	{"email": "irina_stepanova-1962@postgrespro.ru", "phone": "+70777710863"}
0005435311240	7D2783	9920 614856	ALEKSANDR RODIONOV	{"phone": "+70726563575"}
0005435311241	34FA94	0778 452075	LYUBOV ORLOVA	{"email": "l.orlova_121966@postgrespro.ru", "phone": "+70680250546"}
0005435311242	33DBAB	4586 905522	IRINA FROLOVA	{"phone": "+70247697365"}
0005435311243	D95185	8415 606298	OKSANA DAVYDOVA	{"email": "oksana-davydova1982@postgrespro.ru", "phone": "+70302717852"}
0005435311244	4DA29B	7494 403162	ALEKSANDR SOROKIN	{"phone": "+70636636640"}
0005435311245	8091ED	1557 839020	NATALYA POPOVA	{"email": "popova_natalya_01051959@postgrespro.ru", "phone": "+70350344720"}
0005435311246	1F652E	1562 849922	ELENA KUZNECOVA	{"email": "elenakuznecova-051980@postgrespro.ru", "phone": "+70887373281"}
0005435311247	1F652E	9016 121442	IRINA VASILEVA	{"email": "vasilevairina.111975@postgrespro.ru", "phone": "+70960110674"}
0005435311248	22267B	4873 832325	ANDREY NIKOLAEV	{"phone": "+70674527445"}
0005435311249	47B61E	9560 724008	YURIY PETROV	{"email": "petrovy-041974@postgrespro.ru", "phone": "+70679482362"}
0005435311250	A747FE	9864 003717	TATYANA GRISHINA	{"email": "tatyana_grishina-1977@postgrespro.ru", "phone": "+70280700763"}
0005435311251	77FABD	8217 852078	KSENIYA VASILEVA	{"email": "kseniya-vasileva.1983@postgrespro.ru", "phone": "+70898537678"}
0005435311252	92A62E	5579 516479	NADEZHDA MIRONOVA	{"phone": "+70537281556"}
0005435311253	F8AB3E	8586 924750	VERA OSIPOVA	{"email": "osipova_v-06011976@postgrespro.ru", "phone": "+70926855836"}
0005435311254	F8AB3E	5057 117019	LYUDMILA KOMAROVA	{"email": "komarova_l-1975@postgrespro.ru", "phone": "+70746445573"}
0005435311255	C0ED88	8035 592158	ELENA VASILEVA	{"phone": "+70727520642"}
0005435311256	C57051	1770 024520	VERA ALEKSEEVA	{"email": "alekseeva_v.031969@postgrespro.ru", "phone": "+70016452277"}
0005435311257	E776E9	2148 864595	LIDIYA ALEKSANDROVA	{"email": "aleksandrova.l051973@postgrespro.ru", "phone": "+70827375690"}
0005435311258	E776E9	4637 282963	ELENA NIKOLAEVA	{"phone": "+70109198383"}
0005435311259	E766E0	8462 985693	TATYANA NAZAROVA	{"phone": "+70720739099"}
0005435311260	4023C8	1913 535367	GENNADIY MAKSIMOV	{"phone": "+70355978641"}
0005435311261	4023C8	4191 234812	ANNA KUDRYASHOVA	{"email": "a_kudryashova_1979@postgrespro.ru", "phone": "+70299950038"}
0005435311262	4FBF5C	4452 443885	ANDREY VOROBEV	{"email": "vorobev-a-28041967@postgrespro.ru", "phone": "+70681749838"}
0005435311263	E6D645	1696 918036	OLGA NESTEROVA	{"phone": "+70491138674"}
0005435311264	E6D645	5779 478402	VLADIMIR IVANOV	{"email": "vladimir_ivanov-17061966@postgrespro.ru", "phone": "+70235477277"}
0005435311265	4E4389	4065 411700	VLADIMIR ROMANOV	{"email": "romanov_v.091985@postgrespro.ru", "phone": "+70231645845"}
0005435311266	5EE920	2408 409543	ALEKSANDR KUZMIN	{"phone": "+70832317399"}
0005435311267	5EE920	4354 890370	KONSTANTIN KRASNOV	{"phone": "+70296105563"}
0005435311268	D53C7C	1204 822004	IVAN ALEKSEEV	{"email": "ialekseev-22041977@postgrespro.ru", "phone": "+70249454603"}
0005435311269	FFEE90	9722 418844	IRINA NIKOLAEVA	{"email": "nikolaeva_i-16051965@postgrespro.ru", "phone": "+70781447426"}
0005435311270	FFEE90	1018 392955	SERGEY KOROLEV	{"email": "korolev.s.22101969@postgrespro.ru", "phone": "+70271264088"}
0005435311271	97AAE3	9157 199252	ALEKSANDR SOKOLOV	{"phone": "+70918674016"}
0005435311272	8A5A1F	2906 745244	ARTEM OSIPOV	{"email": "artemosipov101961@postgrespro.ru", "phone": "+70589706055"}
0005435311273	B53B3C	5077 282974	NADEZHDA KOZLOVA	{"email": "nadezhda_kozlova-111965@postgrespro.ru", "phone": "+70515233517"}
0005435311274	17BCEC	6222 002688	ALEKSANDR PETROV	{"email": "petrov-aleksandr.05081987@postgrespro.ru", "phone": "+70751867050"}
0005435311275	4AB7C7	4518 771217	ALEKSANDR ISAEV	{"phone": "+70354321787"}
0005435311276	70D86A	7760 698051	ALIYA MIRONOVA	{"phone": "+70905349108"}
0005435311277	0066BE	0990 190719	VASILIY BELOV	{"phone": "+70227447973"}
0005435311278	332D45	6757 252959	IGOR VOROBEV	{"email": "igorvorobev111970@postgrespro.ru", "phone": "+70806724690"}
0005435311279	332D45	5346 528211	VALENTINA EFIMOVA	{"phone": "+70914178679"}
0005435311280	D75F3F	9043 503026	IVAN ROMANOV	{"phone": "+70250479072"}
0005435311281	D3D488	7611 947737	ALESYA VLASOVA	{"phone": "+70005213378"}
0005435311282	7350F2	8661 385940	ANTONINA FOMINA	{"email": "fomina.a-06031981@postgrespro.ru", "phone": "+70697517301"}
0005435311283	7350F2	4974 238578	MARINA GAVRILOVA	{"phone": "+70139064231"}
0005435311284	F46064	9070 954625	TATYANA ROMANOVA	{"email": "tatyana-romanova.1975@postgrespro.ru", "phone": "+70612330950"}
0005435311285	F46064	0012 127012	VALERIY SMIRNOV	{"email": "valeriy-smirnov071972@postgrespro.ru", "phone": "+70806631398"}
0005435311286	AC5AE3	0406 399950	IRINA FADEEVA	{"email": "irinafadeeva051969@postgrespro.ru", "phone": "+70475601232"}
0005435311287	3B52AB	2259 685769	LYUDMILA ANISIMOVA	{"email": "lyudmila.anisimova_1970@postgrespro.ru", "phone": "+70885436036"}
0005435311288	F8B04A	4397 600049	NATALYA MAKAROVA	{"email": "natalyamakarova.051980@postgrespro.ru", "phone": "+70552838630"}
0005435311289	F00F9F	2399 374975	NINA ROMANOVA	{"email": "n_romanova_091966@postgrespro.ru", "phone": "+70143516789"}
0005435311290	2C6113	3985 322912	MARIYA SEMENOVA	{"email": "semenovam.13081974@postgrespro.ru", "phone": "+70630347392"}
0005435311291	2C6113	1933 816050	OLGA NIKOLAEVA	{"email": "nikolaeva-o-30091981@postgrespro.ru", "phone": "+70770666999"}
0005435311292	5A186D	2528 779423	DMITRIY AFANASEV	{"email": "d-afanasev-1972@postgrespro.ru", "phone": "+70382747191"}
0005435311293	D73B6C	9467 939932	ALEKSEY PETROV	{"phone": "+70744827755"}
0005435311294	D3D000	8894 802148	MIKHAIL ABRAMOV	{"phone": "+70217198313"}
0005435311295	64F519	6018 543819	MAKSIM IVANOV	{"email": "ivanov-maksim-1969@postgrespro.ru", "phone": "+70223067469"}
0005435311296	4ECA76	9735 989767	ROMAN GAVRILOV	{"phone": "+70104030619"}
0005435311297	C68E54	7645 952553	TATYANA FILIPPOVA	{"phone": "+70351869686"}
0005435311298	569C52	5494 612787	FEDOR DENISOV	{"phone": "+70130851155"}
0005435311299	E431CC	5369 183530	DMITRIY NOVIKOV	{"email": "novikovdmitriy.13041976@postgrespro.ru", "phone": "+70975910152"}
0005435311300	9772DA	1277 290260	VLADIMIR VASILEV	{"phone": "+70683487922"}
0005435311301	C0854E	4872 478224	RUSLAN SOLOVEV	{"email": "r.solovev.111968@postgrespro.ru", "phone": "+70904807956"}
0005435311302	9262C8	3515 005030	ALINA SIDOROVA	{"phone": "+70150093166"}
0005435311303	A80F0F	8173 456002	VADIM MOROZOV	{"email": "vadimmorozov-1974@postgrespro.ru", "phone": "+70416372419"}
0005435311304	A80F0F	1834 052298	RUSLAN KUZMIN	{"phone": "+70753268978"}
0005435311305	CA21AD	3443 155850	SOFYA LEBEDEVA	{"email": "sofya.lebedeva1985@postgrespro.ru", "phone": "+70167899462"}
0005435311306	B35CD0	7020 337097	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov-1973@postgrespro.ru", "phone": "+70644974521"}
0005435311307	44522D	7013 133599	OLGA ALEKSEEVA	{"email": "olga-alekseeva-21021974@postgrespro.ru", "phone": "+70978833278"}
0005435311308	64D56C	6217 448410	EVGENIY VLASOV	{"email": "vlasove.1959@postgrespro.ru", "phone": "+70188563244"}
0005435311309	64D56C	7351 298116	VASILIY VASILEV	{"phone": "+70592418982"}
0005435311310	73CE10	6145 067075	YULIYA TARASOVA	{"phone": "+70396913060"}
0005435311311	73CE10	5019 556745	LYUBOV BORISOVA	{"email": "lyubovborisova_071984@postgrespro.ru", "phone": "+70469502945"}
0005435311312	135596	4320 664905	OKSANA GAVRILOVA	{"phone": "+70598333647"}
0005435311313	B4E3F5	7257 622876	YULIYA ALEKSANDROVA	{"phone": "+70670919796"}
0005435311314	701A5E	4508 478559	TATYANA KUZNECOVA	{"email": "kuznecova.t-17041965@postgrespro.ru", "phone": "+70459780483"}
0005435311315	0B73BB	8288 038565	ANNA STEPANOVA	{"email": "a.stepanova.1974@postgrespro.ru", "phone": "+70736585631"}
0005435311316	E9B52F	2345 726537	VASILIY MOROZOV	{"email": "morozov_v-10121971@postgrespro.ru", "phone": "+70490734006"}
0005435311317	E9B52F	4020 575921	SVETLANA MIKHAYLOVA	{"email": "mikhaylovasvetlana_09041977@postgrespro.ru", "phone": "+70483377140"}
0005435311318	1B7574	4397 599656	SERGEY ALEKSEEV	{"phone": "+70538372980"}
0005435311319	1B7574	0080 942329	VLADIMIR RODIONOV	{"email": "rodionov.vladimir.1978@postgrespro.ru", "phone": "+70551347773"}
0005435311320	D5649B	7979 558297	ALEKSANDR IVANOV	{"phone": "+70566133425"}
0005435311321	54DCFC	0158 775508	NATALYA ROMANOVA	{"phone": "+70798511224"}
0005435311322	B69E24	6986 781276	EGOR ABRAMOV	{"email": "abramovegor-091977@postgrespro.ru", "phone": "+70587710094"}
0005435311323	91D1AF	5631 245564	TAMARA OSIPOVA	{"phone": "+70946120574"}
0005435311324	96F234	1460 574954	ALEKSANDRA NIKOLAEVA	{"phone": "+70833827508"}
0005435311325	96F234	8166 589587	VALERIYA KUZNECOVA	{"phone": "+70098178614"}
0005435311326	D50C52	9559 118442	ELIZAVETA SAVELEVA	{"phone": "+70551141808"}
0005435311327	F5C7A0	0218 361851	MARIYA FEDOROVA	{"email": "fedorovam.1972@postgrespro.ru", "phone": "+70214222280"}
0005435311328	8940B2	5585 964038	ALEKSANDR SOKOLOV	{"email": "a_sokolov-20111972@postgrespro.ru", "phone": "+70886099347"}
0005435311329	C04246	2069 669517	IRINA KOZLOVA	{"phone": "+70648683618"}
0005435311330	47F9FF	9013 624241	LYUBOV TROFIMOVA	{"phone": "+70904731073"}
0005435311331	DD47BF	9898 678428	TATYANA OSIPOVA	{"email": "t_osipova_11051981@postgrespro.ru", "phone": "+70788531989"}
0005435311332	DD47BF	1501 692865	ELENA KUZNECOVA	{"email": "elena.kuznecova-23031971@postgrespro.ru", "phone": "+70681095502"}
0005435311333	DD47BF	2476 192563	MAKSIM DMITRIEV	{"email": "dmitriev_maksim_081976@postgrespro.ru", "phone": "+70201381036"}
0005435311334	CB4CC2	1579 061525	SVETLANA DMITRIEVA	{"email": "sdmitrieva.17031971@postgrespro.ru", "phone": "+70588442136"}
0005435311335	4B8D7D	3892 741164	LEONID KUZNECOV	{"email": "kuznecovl_1972@postgrespro.ru", "phone": "+70419638972"}
0005435311336	BA74A1	7084 891710	IRINA STEPANOVA	{"phone": "+70906694815"}
0005435311337	E22324	3052 574022	ANDREY KISELEV	{"email": "kiselev.a061977@postgrespro.ru", "phone": "+70642415163"}
0005435311338	E22324	0735 247413	ALEKSANDR ANTONOV	{"email": "aleksandrantonov.101974@postgrespro.ru", "phone": "+70580534245"}
0005435311339	E215C3	0250 168157	IGOR NIKOLAEV	{"phone": "+70209729659"}
0005435311340	FDAB06	7629 242277	IRINA NESTEROVA	{"email": "i.nesterova021970@postgrespro.ru", "phone": "+70180594797"}
0005435311341	6655DA	4178 769508	ANDREY FILIPPOV	{"phone": "+70508849590"}
0005435311342	6655DA	1319 687287	DMITRIY KONOVALOV	{"email": "d.konovalov031975@postgrespro.ru", "phone": "+70728011013"}
0005435311343	91C772	2115 124186	RAFAIL KUZMIN	{"phone": "+70533498520"}
0005435311344	D980D3	2193 983785	ANDREY FEDOROV	{"email": "fedorov.a08031967@postgrespro.ru", "phone": "+70722858226"}
0005435311345	D980D3	1742 479708	TATYANA FEDOROVA	{"phone": "+70126513306"}
0005435311346	98A15B	5407 844018	SERGEY IVANOV	{"phone": "+70224457425"}
0005435311347	999548	9594 165063	OLGA FADEEVA	{"phone": "+70275275009"}
0005435311348	999548	8070 272782	MARIYA TARASOVA	{"phone": "+70934512467"}
0005435311349	999548	6057 541387	STANISLAV KOZLOV	{"email": "kozlov_s30061958@postgrespro.ru", "phone": "+70472669588"}
0005435311350	DEF5A3	0259 570393	SERGEY KUZMIN	{"phone": "+70117778909"}
0005435311351	DEF5A3	0164 862118	OLEG KOZLOV	{"phone": "+70229889967"}
0005435311352	5CEA2F	8070 091382	VLADIMIR VASILEV	{"email": "vasilevvladimir1967@postgrespro.ru", "phone": "+70504713817"}
0005435311353	5CEA2F	3966 850204	IGOR SCHERBAKOV	{"email": "scherbakov_igor_1961@postgrespro.ru", "phone": "+70071367058"}
0005435311354	5CEA2F	0620 710904	NADEZHDA SOROKINA	{"email": "sorokina.n13041968@postgrespro.ru", "phone": "+70909553337"}
0005435311355	71B50F	9800 980979	YURIY VASILEV	{"phone": "+70585632969"}
0005435311356	1CAC4A	6515 005678	LYUDMILA EGOROVA	{"email": "egorova_lyudmila_021975@postgrespro.ru", "phone": "+70941388281"}
0005435311357	EB756E	7958 672152	ANNA ISAEVA	{"phone": "+70144417991"}
0005435311358	6DE6DB	6040 189893	GALINA SOLOVEVA	{"phone": "+70909640074"}
0005435311359	DD427A	0473 804796	LEONID VLASOV	{"email": "vlasovl_061979@postgrespro.ru", "phone": "+70263322859"}
0005435311360	BE7EEC	8736 782771	ANASTASIYA ALEKSEEVA	{"email": "aalekseeva.111973@postgrespro.ru", "phone": "+70280439745"}
0005435311361	BE7EEC	5761 199784	OLGA RODIONOVA	{"email": "rodionova_o.101972@postgrespro.ru", "phone": "+70150995396"}
0005435311362	963919	3256 897843	DANIIL FROLOV	{"phone": "+70272167547"}
0005435311363	724950	1186 442487	TATYANA PETROVA	{"phone": "+70579021664"}
0005435311364	F836A8	9587 825344	OLGA FROLOVA	{"phone": "+70973907754"}
0005435311365	CAFAB5	2989 214982	ANTON KISELEV	{"email": "kiselev.a.1965@postgrespro.ru", "phone": "+70992275675"}
0005435311366	DF2F10	1489 446557	VITALIY ILIN	{"email": "ilin-v101986@postgrespro.ru", "phone": "+70716377722"}
0005435311367	19D3B3	2012 262789	NIKOLAY IVANOV	{"email": "nikolay-ivanov_091976@postgrespro.ru", "phone": "+70966729913"}
0005435311368	1D5A67	3410 549692	DARYA BORISOVA	{"phone": "+70409704492"}
0005435311369	1CAF56	4342 042731	ANATOLIY FROLOV	{"phone": "+70292885346"}
0005435311370	1CAF56	1608 008334	DMITRIY ABRAMOV	{"email": "dabramov_11121959@postgrespro.ru", "phone": "+70539363740"}
0005435311371	1CAF56	7057 112032	ALEKSANDR FEDOROV	{"phone": "+70288621333"}
0005435311372	55D7A7	4533 154137	VLADIMIR NAZAROV	{"email": "v_nazarov.05101977@postgrespro.ru", "phone": "+70511753060"}
0005435311373	55D7A7	2028 119179	TATYANA KUDRYASHOVA	{"phone": "+70245391780"}
0005435311374	31EF4E	9249 106308	ANNA YAKOVLEVA	{"email": "yakovlevaa_17031981@postgrespro.ru", "phone": "+70568580034"}
0005435311375	0695D6	9015 493604	LIDIYA KRASNOVA	{"email": "lidiyakrasnova-29011971@postgrespro.ru", "phone": "+70144142344"}
0005435311376	C898E6	4426 714013	SVETLANA ZAYCEVA	{"phone": "+70782461360"}
0005435311377	E144DF	4584 199663	SERGEY POPOV	{"phone": "+70744538434"}
0005435311378	E144DF	5827 485818	NATALYA ZAKHAROVA	{"email": "natalya.zakharova.31101966@postgrespro.ru", "phone": "+70568288996"}
0005435311379	47D86D	5469 668024	OLESYA BELYAEVA	{"email": "olesya-belyaeva.101969@postgrespro.ru", "phone": "+70208533206"}
0005435311380	D5C838	3860 376380	OLGA NAZAROVA	{"email": "nazarovao-1965@postgrespro.ru", "phone": "+70242694311"}
0005435311381	EAF1E2	8686 870803	ANDREY GERASIMOV	{"phone": "+70811112314"}
0005435311382	EAF1E2	3449 468173	VLADIMIR SIDOROV	{"email": "vsidorov_061963@postgrespro.ru", "phone": "+70949529296"}
0005435311383	854902	7557 314457	ELENA ANDREEVA	{"phone": "+70343845460"}
0005435311384	BD5995	1384 786467	SNEZHANA KOZLOVA	{"email": "snezhana-kozlova-27011967@postgrespro.ru", "phone": "+70319793470"}
0005435311385	BD5995	9402 582282	OLEG FOMIN	{"email": "fomin_o.17101973@postgrespro.ru", "phone": "+70267206790"}
0005435311386	39DB16	9786 925467	ANDREY IVANOV	{"email": "ivanov_a_121974@postgrespro.ru", "phone": "+70789035126"}
0005435311387	4EEBB9	2352 792711	LYUDMILA YAKOVLEVA	{"phone": "+70064661438"}
0005435311388	B13D19	2966 337254	YURIY SHEVCHENKO	{"phone": "+70651791627"}
0005435311389	3D2244	4364 871506	LYUDMILA SEMENOVA	{"phone": "+70932206595"}
0005435311390	0E90D8	8204 526753	YURIY BORISOV	{"phone": "+70584706766"}
0005435311391	7D991E	6263 618823	ALEKSEY ANTONOV	{"phone": "+70252345117"}
0005435311392	555E1E	8684 693842	YULIYA PAVLOVA	{"phone": "+70300090421"}
0005435311393	555E1E	4283 683803	NINEL PETROVA	{"phone": "+70628210005"}
0005435311394	71901D	1885 962318	DMITRIY KUZNECOV	{"phone": "+70338641132"}
0005435311395	7CEF4C	5401 639976	RUSLAN ZAYCEV	{"email": "ruslanzaycev-041969@postgrespro.ru", "phone": "+70774173777"}
0005435311396	7CEF4C	9240 523843	VLADIMIR KUZMIN	{"email": "v-kuzmin.1968@postgrespro.ru", "phone": "+70604509837"}
0005435311397	409D52	8289 639732	VALENTINA KULIKOVA	{"email": "v-kulikova.021975@postgrespro.ru", "phone": "+70257067734"}
0005435311398	409D52	3579 214030	GALINA KRASNOVA	{"email": "galinakrasnova_1966@postgrespro.ru", "phone": "+70144771021"}
0005435311399	E5A080	5975 344893	NATALYA MAKAROVA	{"email": "makarova-n_1978@postgrespro.ru", "phone": "+70510331016"}
0005435311400	FEDCD6	9633 603140	ALEKSANDR CHERNOV	{"phone": "+70240855992"}
0005435311401	54EDB8	6099 219347	ANNA ILINA	{"email": "anna.ilina1967@postgrespro.ru", "phone": "+70092673884"}
0005435311402	54EDB8	0282 831562	EDUARD KOROLEV	{"phone": "+70027423995"}
0005435311403	54EDB8	0467 331636	YURIY SMIRNOV	{"phone": "+70067403534"}
0005435311404	B6D251	3861 649449	DANIIL STEPANOV	{"email": "daniil-stepanov.1984@postgrespro.ru", "phone": "+70576027869"}
0005435311516	08B73F	6216 970253	ALEKSANDRA KRASNOVA	{"phone": "+70319944360"}
0005435311405	49879E	9842 662318	ALEKSANDRA PETROVA	{"email": "a.petrova-1963@postgrespro.ru", "phone": "+70897869539"}
0005435311406	7CA29C	9077 528455	NATALYA GERASIMOVA	{"email": "gerasimova.n101970@postgrespro.ru", "phone": "+70143657695"}
0005435311407	BAFBA3	9976 017101	ZOYA MOISEEVA	{"email": "moiseeva-zoya-051977@postgrespro.ru", "phone": "+70039997240"}
0005435311408	B74967	6925 807700	ALEKSANDR ILIN	{"email": "aleksandr.ilin_041977@postgrespro.ru", "phone": "+70890835268"}
0005435311409	182D82	1138 256918	NATALYA POTAPOVA	{"email": "potapovanatalya091975@postgrespro.ru", "phone": "+70258139786"}
0005435311410	182D82	6407 339302	EKATERINA SIDOROVA	{"phone": "+70643995116"}
0005435311411	0CF35E	1802 782875	SERGEY ISAEV	{"phone": "+70735154420"}
0005435311412	A0C2DE	8183 454011	ANASTASIYA GERASIMOVA	{"phone": "+70941841265"}
0005435311413	A0C2DE	2575 164138	ALEKSANDR MAKAROV	{"email": "makarov-aleksandr.06081977@postgrespro.ru", "phone": "+70525718860"}
0005435311414	12CA9C	6478 199014	VYACHESLAV NIKITIN	{"email": "nikitin-v041969@postgrespro.ru", "phone": "+70086025047"}
0005435311415	12CA9C	1987 778688	NATALYA KALININA	{"email": "kalininanatalya1976@postgrespro.ru", "phone": "+70860687073"}
0005435311416	B29F53	4103 706587	VLADIMIR STEPANOV	{"email": "stepanov-vladimir.1972@postgrespro.ru", "phone": "+70119811075"}
0005435311417	100FBD	4596 695061	VASILIY VOLKOV	{"phone": "+70078862835"}
0005435311418	100FBD	8883 205385	EKATERINA MARTYNOVA	{"phone": "+70232730353"}
0005435311419	D1F0F6	6836 603903	TATYANA KONDRATEVA	{"email": "kondratevat-15051974@postgrespro.ru", "phone": "+70567246362"}
0005435311420	2490CA	6022 073072	ALEKSANDR BELOV	{"phone": "+70612518000"}
0005435311421	622385	8299 122030	IRINA TARASOVA	{"email": "tarasova-i_13081970@postgrespro.ru", "phone": "+70082140991"}
0005435311422	EE74FC	1535 747686	IVAN TARASOV	{"phone": "+70918963916"}
0005435311423	52C275	7390 847158	ANTONINA KRASNOVA	{"email": "krasnova.antonina.04051977@postgrespro.ru", "phone": "+70820105702"}
0005435311424	F834E3	1648 000215	ALEKSANDR MELNIKOV	{"email": "a_melnikov05041967@postgrespro.ru", "phone": "+70036293875"}
0005435311425	F834E3	5494 192428	OLGA BELOVA	{"phone": "+70456784910"}
0005435311426	F834E3	4612 244659	POLINA NAZAROVA	{"phone": "+70502093318"}
0005435311427	F834E3	3546 854611	OLGA MIKHAYLOVA	{"email": "mikhaylova-olga.121976@postgrespro.ru", "phone": "+70197970148"}
0005435311428	C2ED33	1505 491882	DMITRIY KUDRYASHOV	{"email": "dkudryashov.18061979@postgrespro.ru", "phone": "+70960874391"}
0005435311429	5FC277	9390 990801	ANATOLIY SHEVCHENKO	{"email": "ashevchenko_1953@postgrespro.ru", "phone": "+70635824946"}
0005435311430	40F8BD	7708 799278	ANTON KUZMIN	{"phone": "+70641306926"}
0005435311431	63FA55	9737 449047	NIKITA SMIRNOV	{"phone": "+70463148552"}
0005435311432	CFBE0E	7421 038351	ROZA OVCHINNIKOVA	{"email": "ovchinnikovaroza.051973@postgrespro.ru", "phone": "+70725690689"}
0005435311433	71FC8C	8739 174663	RAFAIL VOLKOV	{"email": "volkov.r_31071986@postgrespro.ru", "phone": "+70593805870"}
0005435311434	71FC8C	2615 989925	ELENA ROMANOVA	{"email": "romanovaelena.031976@postgrespro.ru", "phone": "+70246150236"}
0005435311435	813D73	9799 383526	PETR NIKITIN	{"email": "petr-nikitin_091976@postgrespro.ru", "phone": "+70507554846"}
0005435311436	6B1199	5647 045127	OLGA KUZNECOVA	{"email": "olgakuznecova_05051978@postgrespro.ru", "phone": "+70780739411"}
0005435311437	729463	3364 628834	MARIYA VASILEVA	{"email": "vasileva_mariya_051980@postgrespro.ru", "phone": "+70171426208"}
0005435311438	3615BB	6815 522710	VLADIMIR ZHURAVLEV	{"phone": "+70364373303"}
0005435311439	A9D2FC	5231 792660	NIKITA KUZNECOV	{"phone": "+70914471613"}
0005435311440	A9D2FC	7829 782169	NINA NAZAROVA	{"email": "nazarova_n121968@postgrespro.ru", "phone": "+70874749166"}
0005435311441	D0D96F	5213 258799	ELIZAVETA GAVRILOVA	{"email": "egavrilova101981@postgrespro.ru", "phone": "+70317714425"}
0005435311442	D79C19	7862 312140	ALEKSANDR KUDRYASHOV	{"email": "a_kudryashov_12091964@postgrespro.ru", "phone": "+70287794801"}
0005435311443	D79C19	6777 096083	ARTEM BARANOV	{"phone": "+70647269040"}
0005435311444	B92A0C	7826 257284	MARINA TROFIMOVA	{"phone": "+70476220285"}
0005435311445	7F056E	2865 149225	DARYA ROMANOVA	{"phone": "+70540464824"}
0005435311446	7F056E	7599 919291	YURIY BORISOV	{"phone": "+70581692674"}
0005435311447	CF7264	1145 579044	NATALYA PAVLOVA	{"phone": "+70645523148"}
0005435311448	3B2238	5179 045363	LIDIYA OSIPOVA	{"email": "l_osipova.09071971@postgrespro.ru", "phone": "+70758556411"}
0005435311449	6BF91A	9804 733499	NATALYA MOISEEVA	{"email": "natalyamoiseeva-1957@postgrespro.ru", "phone": "+70878230303"}
0005435311450	DC5549	0643 091762	VALENTINA TITOVA	{"phone": "+70082530663"}
0005435311451	DC5549	2406 426775	NINA SEMENOVA	{"phone": "+70935670466"}
0005435311452	4D0E73	8845 705115	NADEZHDA NIKIFOROVA	{"email": "nadezhda_nikiforova-101968@postgrespro.ru", "phone": "+70659646253"}
0005435311453	14AE5C	3239 703547	VIKTOR KISELEV	{"email": "kiselev.viktor-1971@postgrespro.ru", "phone": "+70330139040"}
0005435311454	2493D5	2088 291164	MARIYA RODIONOVA	{"phone": "+70402527541"}
0005435311455	2493D5	2462 587085	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_v.30081983@postgrespro.ru", "phone": "+70632155828"}
0005435311456	542658	0757 705664	OKSANA ALEKSANDROVA	{"phone": "+70336403517"}
0005435311457	542658	4964 372104	ANNA KULIKOVA	{"phone": "+70448934559"}
0005435311458	58F6EE	5139 333477	SERGEY MIKHAYLOV	{"phone": "+70603268509"}
0005435311459	58F6EE	4514 643722	VASILIY NIKOLAEV	{"phone": "+70403502762"}
0005435311460	AA7065	9490 766598	TATYANA CHERNOVA	{"email": "tatyana.chernova_1972@postgrespro.ru", "phone": "+70094636788"}
0005435311461	EF3A26	6765 352906	KLAVDIYA KULIKOVA	{"phone": "+70608951331"}
0005435311462	A720DD	6051 755331	OLEG BORISOV	{"email": "oleg_borisov.15051978@postgrespro.ru", "phone": "+70987990464"}
0005435311463	D9DB10	9562 288501	ANNA SAVELEVA	{"email": "anna_saveleva-021977@postgrespro.ru", "phone": "+70399154713"}
0005435311464	3681BB	6161 880265	GENNADIY PAVLOV	{"email": "gennadiy_pavlov.101975@postgrespro.ru", "phone": "+70272007963"}
0005435311465	9F153D	8936 992159	VYACHESLAV IVANOV	{"phone": "+70037000863"}
0005435311466	9F153D	8965 740173	DANIIL ANTONOV	{"phone": "+70124203295"}
0005435311467	9BB228	3324 156997	OLEG PETROV	{"phone": "+70788312644"}
0005435311468	33EE51	2038 509787	EVGENIY SOROKIN	{"email": "sorokin.e-30011974@postgrespro.ru", "phone": "+70615895042"}
0005435311469	9BC0E2	6500 985763	ILYA FROLOV	{"email": "frolovi.1961@postgrespro.ru", "phone": "+70159080022"}
0005435311470	829021	8879 836743	ELENA ORLOVA	{"phone": "+70634965598"}
0005435311471	E6C7F7	6971 621793	LYUBOV SEMENOVA	{"email": "semenoval12121977@postgrespro.ru", "phone": "+70106503701"}
0005435311472	E6C7F7	1502 596416	SEMEN OSIPOV	{"phone": "+70463018940"}
0005435311473	E6C7F7	0952 686950	OLEG SCHERBAKOV	{"email": "oscherbakov.071975@postgrespro.ru", "phone": "+70688062357"}
0005435311474	1007B3	4566 841506	ALEKSANDR DMITRIEV	{"email": "dmitriev_a041973@postgrespro.ru", "phone": "+70434800705"}
0005435311475	CB2D07	8322 780398	MARIYA KUZNECOVA	{"phone": "+70997421752"}
0005435311476	DAE6C8	3203 009030	LYUBOV KONOVALOVA	{"email": "l.konovalova_121975@postgrespro.ru", "phone": "+70612627285"}
0005435311477	AAEBFE	9037 089700	TATYANA ARKHIPOVA	{"phone": "+70787497387"}
0005435311478	D154FC	0526 831877	IRINA PAVLOVA	{"phone": "+70620976341"}
0005435311479	D154FC	9184 953533	VLADIMIR NAZAROV	{"phone": "+70415489154"}
0005435311480	8FDDCA	2079 556638	VYACHESLAV BELOV	{"phone": "+70650927024"}
0005435311481	E0D482	1628 178561	GALINA ARKHIPOVA	{"email": "arkhipova-galina031967@postgrespro.ru", "phone": "+70122430058"}
0005435311482	BE69D3	1813 789071	ALEKSANDR KUZMIN	{"phone": "+70200327046"}
0005435311483	694C47	3933 879635	OLGA IVANOVA	{"phone": "+70613885993"}
0005435311484	694C47	7908 841507	GALINA NESTEROVA	{"email": "galina_nesterova.1973@postgrespro.ru", "phone": "+70322358520"}
0005435311485	ECE7B0	4820 509478	ROMAN SOLOVEV	{"phone": "+70078236186"}
0005435311486	ECE7B0	0103 312687	ELENA TROFIMOVA	{"email": "e.trofimova-021975@postgrespro.ru", "phone": "+70063325105"}
0005435311487	ECE7B0	2482 472563	TATYANA ARKHIPOVA	{"email": "tatyanaarkhipova-061973@postgrespro.ru", "phone": "+70437284823"}
0005435311488	DEC7D4	6488 815706	NIKOLAY BELOV	{"phone": "+70185955630"}
0005435311489	0A7947	5756 665470	VLADIMIR ROMANOV	{"email": "vladimirromanov14081965@postgrespro.ru", "phone": "+70609466843"}
0005435311490	0A7947	3063 398864	ARTEM MAKAROV	{"email": "artem-makarov_26011967@postgrespro.ru", "phone": "+70535507444"}
0005435311491	8BD8B7	7556 845917	RUSLAN PAVLOV	{"phone": "+70277143167"}
0005435311492	8BD8B7	6818 007762	TATYANA ALEKSANDROVA	{"email": "aleksandrovat051968@postgrespro.ru", "phone": "+70277928218"}
0005435311493	D749D5	0647 599266	ANDREY MARTYNOV	{"email": "martynov_a-09051969@postgrespro.ru", "phone": "+70911388743"}
0005435311494	D749D5	5434 806176	DMITRIY NIKOLAEV	{"phone": "+70129186797"}
0005435311495	D6C953	8120 920660	ZINAIDA BARANOVA	{"email": "baranova-z121971@postgrespro.ru", "phone": "+70409405300"}
0005435311496	5B565C	1650 882170	OLGA KULIKOVA	{"email": "olga.kulikova.1970@postgrespro.ru", "phone": "+70012091961"}
0005435311497	9195E3	0088 316175	KONSTANTIN MATVEEV	{"email": "k.matveev.1969@postgrespro.ru", "phone": "+70486467036"}
0005435311498	3351D5	1599 954478	ALEKSANDRA RODIONOVA	{"email": "rodionovaa_121977@postgrespro.ru", "phone": "+70941097241"}
0005435311499	832D95	6435 478511	VERA IVANOVA	{"phone": "+70467773043"}
0005435311500	832D95	4366 386686	ELENA NESTEROVA	{"email": "nesterova.elena_17101977@postgrespro.ru", "phone": "+70149562337"}
0005435311501	A8D9E3	0185 675081	ANDREY VOLKOV	{"phone": "+70678498652"}
0005435311502	A8D9E3	3777 246634	ALEKSANDR GAVRILOV	{"email": "gavrilova-101985@postgrespro.ru", "phone": "+70187307175"}
0005435311503	E34888	9545 310087	MARINA KUZNECOVA	{"email": "m_kuznecova_061973@postgrespro.ru", "phone": "+70489660893"}
0005435311504	0836EA	1140 613737	YURIY TARASOV	{"phone": "+70236727071"}
0005435311505	0836EA	6937 406765	LIDIYA GRISHINA	{"email": "l.grishina_1965@postgrespro.ru", "phone": "+70087942332"}
0005435311506	B0276C	4798 838731	TATYANA IVANOVA	{"phone": "+70856860768"}
0005435311507	7CD8E2	8556 076109	ALEKSANDR KUZMIN	{"email": "a-kuzmin-031969@postgrespro.ru", "phone": "+70767124346"}
0005435311508	7CD8E2	6716 242130	NIKOLAY SMIRNOV	{"email": "n_smirnov_101980@postgrespro.ru", "phone": "+70258604308"}
0005435311509	7CD8E2	2252 299801	IGOR MEDVEDEV	{"phone": "+70271745552"}
0005435311510	452316	1272 222979	ALEKSANDR KARPOV	{"email": "akarpov-26071971@postgrespro.ru", "phone": "+70254150438"}
0005435311511	452316	1650 897568	ELINA ZAKHAROVA	{"phone": "+70745907228"}
0005435311512	5CBDE8	4614 357263	ANNA TARASOVA	{"email": "tarasova_anna_17031974@postgrespro.ru", "phone": "+70284211397"}
0005435311513	5CBDE8	1617 787754	ALEKSANDR SERGEEV	{"phone": "+70627136201"}
0005435311514	5CBDE8	0755 704004	ILYA BORISOV	{"email": "i_borisov_1976@postgrespro.ru", "phone": "+70244767840"}
0005435311515	EF3B94	6692 777992	YULIYA FILATOVA	{"phone": "+70009704088"}
0005435311517	08B73F	4466 060660	ALEKSANDR EGOROV	{"email": "a_egorov.1979@postgrespro.ru", "phone": "+70522510431"}
0005435311518	A69EFA	9124 869619	ALINA TARASOVA	{"phone": "+70687857570"}
0005435311519	A69EFA	2015 218590	TATYANA TIMOFEEVA	{"email": "tatyanatimofeeva-29031977@postgrespro.ru", "phone": "+70270617730"}
0005435311520	E9989F	6716 300772	VLADIMIR ALEKSEEV	{"phone": "+70790848535"}
0005435311521	162E0A	5183 976771	VIKTOR NOVIKOV	{"phone": "+70825441999"}
0005435311522	1249F3	6219 581217	LYUDMILA NESTEROVA	{"email": "nesterova_lyudmila1977@postgrespro.ru", "phone": "+70788196321"}
0005435311523	1249F3	3657 173951	YURIY MEDVEDEV	{"email": "yuriymedvedev10111970@postgrespro.ru", "phone": "+70539217425"}
0005435311524	69906B	4131 948822	OLGA SOROKINA	{"phone": "+70326121927"}
0005435311525	AA035B	4031 536119	MARIYA SIDOROVA	{"phone": "+70763866891"}
0005435311526	AA035B	2434 167623	ALEKSANDR GAVRILOV	{"email": "gavrilovaleksandr1967@postgrespro.ru", "phone": "+70198420336"}
0005435311527	A05217	1310 672737	LIDIYA MIKHAYLOVA	{"phone": "+70596432907"}
0005435311528	C73432	0471 247775	DANILA IVANOV	{"email": "ivanov_d_051975@postgrespro.ru", "phone": "+70476412140"}
0005435311529	BA02C8	8116 765979	ALEKSANDR BONDARENKO	{"phone": "+70368795722"}
0005435311530	BA02C8	4715 690985	ANDREY TIMOFEEV	{"phone": "+70062662409"}
0005435311531	6DF186	8596 960185	YURIY ANTONOV	{"email": "yuriy_antonov.1958@postgrespro.ru", "phone": "+70557869436"}
0005435311532	93F9AD	5369 527361	RUSTEM MATVEEV	{"email": "rustem-matveev_1967@postgrespro.ru", "phone": "+70694636820"}
0005435311533	5F127D	7662 724754	IRINA IVANOVA	{"phone": "+70862142250"}
0005435311534	58C1AD	3824 826830	NINA KISELEVA	{"phone": "+70659631963"}
0005435311535	58C1AD	9791 067924	ELENA KUZNECOVA	{"email": "elena-kuznecova_121978@postgrespro.ru", "phone": "+70782071796"}
0005435311536	E8531F	4765 550486	ELENA GERASIMOVA	{"phone": "+70307401897"}
0005435311537	B9E13A	3932 004406	LARISA ERMAKOVA	{"phone": "+70810764699"}
0005435311538	A64FDE	2213 758553	DANIL KOZLOV	{"email": "d.kozlov1959@postgrespro.ru", "phone": "+70375811917"}
0005435311539	A64FDE	2932 957312	ROMAN SCHERBAKOV	{"phone": "+70923343113"}
0005435311540	254EE5	9875 796800	MARINA NIKITINA	{"phone": "+70945168795"}
0005435311541	254EE5	7972 721362	TATYANA POPOVA	{"email": "popova_tatyana.10051981@postgrespro.ru", "phone": "+70474178346"}
0005435311542	254EE5	4367 612261	VALERIY ORLOV	{"email": "orlov-v-1971@postgrespro.ru", "phone": "+70935269329"}
0005435311543	713C4A	8643 920470	LYUBOV LUKYANOVA	{"phone": "+70761633487"}
0005435311544	0FF45D	4529 039604	MIKHAIL VOLKOV	{"email": "volkov_m.061967@postgrespro.ru", "phone": "+70456813401"}
0005435311545	D6C499	1288 893322	LIDIYA FILIPPOVA	{"email": "filippova_lidiya-1967@postgrespro.ru", "phone": "+70547513497"}
0005435311546	D6C499	8498 048246	ARTEM ISAEV	{"email": "isaev_artem-11061973@postgrespro.ru", "phone": "+70597058288"}
0005435311547	0E6810	5987 114502	YURIY VASILEV	{"phone": "+70980339051"}
0005435311548	0E6810	2312 032513	ALEKSANDR ZAYCEV	{"email": "aleksandr_zaycev.121982@postgrespro.ru", "phone": "+70164132116"}
0005435311549	FE6EE7	1692 384128	OLGA FEDOROVA	{"phone": "+70851333374"}
0005435311550	55DE46	8706 166274	DMITRIY CHERNOV	{"phone": "+70583317871"}
0005435311551	C7D837	9894 771339	DMITRIY MIRONOV	{"email": "mironov_d.081963@postgrespro.ru", "phone": "+70400242481"}
0005435311552	C7D837	5527 123034	VITALIY FOMIN	{"email": "v-fomin.13121975@postgrespro.ru", "phone": "+70462494904"}
0005435311553	D9BDC7	4429 223406	ANDREY SMIRNOV	{"email": "smirnov_andrey1964@postgrespro.ru", "phone": "+70945510055"}
0005435311554	6E2793	4826 061158	KIRILL KAZAKOV	{"phone": "+70196909844"}
0005435311555	6E2793	0514 861597	RINAT KOZLOV	{"email": "rinat.kozlov_031977@postgrespro.ru", "phone": "+70932578227"}
0005435311556	2F9DE6	4263 345363	VLADIMIR ALEKSEEV	{"email": "vladimir_alekseev-051975@postgrespro.ru", "phone": "+70396984807"}
0005435311557	4622D1	7714 695667	ALEKSANDR SIDOROV	{"email": "sidorov_a_121982@postgrespro.ru", "phone": "+70648277484"}
0005435311558	4622D1	9898 039746	ANTONINA VLASOVA	{"phone": "+70616183115"}
0005435311559	776607	5012 063693	MARGARITA ALEKSEEVA	{"email": "alekseeva-margarita_1978@postgrespro.ru", "phone": "+70559685098"}
0005435311560	DACF6D	2731 226727	LIDIYA RYABOVA	{"email": "lidiya.ryabova_12111977@postgrespro.ru", "phone": "+70933895835"}
0005435311561	DACF6D	3579 856074	ANDREY MOISEEV	{"phone": "+70834116304"}
0005435311562	DACF6D	7893 593102	NATALIYA KOZLOVA	{"email": "kozlovan.031974@postgrespro.ru", "phone": "+70703869313"}
0005435311563	FB43D4	7524 763224	KARINA NESTEROVA	{"phone": "+70715601236"}
0005435311564	28FE83	6030 057132	FATIMA MOISEEVA	{"email": "fatima-moiseeva-21071961@postgrespro.ru", "phone": "+70622266038"}
0005435311565	AF132A	3747 885694	YAN MOROZOV	{"email": "yan-morozov.28121964@postgrespro.ru", "phone": "+70600680491"}
0005435311566	EECBA1	6956 293151	MARINA DMITRIEVA	{"email": "dmitrieva.marina04071976@postgrespro.ru", "phone": "+70699600722"}
0005435311567	A1B683	4223 444989	MARIYA BELOVA	{"phone": "+70329587304"}
0005435312764	88F072	3598 456947	VLADIMIR SERGEEV	{"phone": "+70939603755"}
0005435312765	1DEBC0	5329 516549	ELENA EFIMOVA	{"phone": "+70985771368"}
0005435312766	ED0B3F	9404 715227	VALENTINA VOLKOVA	{"phone": "+70746293148"}
0005435312767	631D10	0061 900035	ALEKSANDR MOISEEV	{"phone": "+70548281248"}
0005435312768	631D10	5900 092285	MARINA KOMAROVA	{"email": "komarova-marina_19091972@postgrespro.ru", "phone": "+70553256745"}
0005435312769	5709BD	8116 539922	NIKOLAY NOVIKOV	{"phone": "+70578929148"}
0005435312770	22A7CC	0618 380550	SERGEY IVANOV	{"email": "sergey_ivanov_1975@postgrespro.ru", "phone": "+70907362788"}
0005435312771	2FFACB	5278 010016	ALEKSANDR PETROV	{"email": "petrov_aleksandr.22071960@postgrespro.ru", "phone": "+70458549010"}
0005435312772	AE1AA1	1119 356488	MARK ANDREEV	{"phone": "+70270883697"}
0005435312773	BE184E	5941 064466	LYUBOV NIKITINA	{"phone": "+70189667615"}
0005435312774	5C801F	2235 933329	ELENA KOMAROVA	{"email": "elenakomarova.15061971@postgrespro.ru", "phone": "+70258415729"}
0005435312775	1C27C5	3441 713098	SERGEY IVANOV	{"phone": "+70038761189"}
0005435312776	D966E2	6317 728033	VALENTINA SMIRNOVA	{"email": "valentina.smirnova121954@postgrespro.ru", "phone": "+70711657401"}
0005435312777	A5EC3F	4442 629047	ANDREY GUSEV	{"email": "a-gusev_081984@postgrespro.ru", "phone": "+70686964057"}
0005435312778	51084E	9922 068358	DMITRIY ZAKHAROV	{"email": "d.zakharov-1967@postgrespro.ru", "phone": "+70433397533"}
0005435312779	51084E	7807 887304	ALEKSANDR BONDARENKO	{"email": "aleksandr-bondarenko051968@postgrespro.ru", "phone": "+70443392810"}
0005435312780	EE0DE9	2736 985140	NATALYA DMITRIEVA	{"email": "dmitrievan_1968@postgrespro.ru", "phone": "+70809620199"}
0005435312781	EE0DE9	0704 264851	ANDREY SOLOVEV	{"phone": "+70929490552"}
0005435312782	EE0DE9	8912 549354	ALEKSEY KUZNECOV	{"phone": "+70275330304"}
0005435312783	7D2F45	8682 875161	GALINA BARANOVA	{"phone": "+70682891632"}
0005435312784	7D2F45	0004 172977	LYUBOV RYABOVA	{"email": "lyubov-ryabova_09101975@postgrespro.ru", "phone": "+70102699110"}
0005435312785	7D2F45	3227 846713	VIKTOR NAUMOV	{"phone": "+70468107791"}
0005435312786	8F4DAD	8615 865430	ANATOLIY OSIPOV	{"email": "a.osipov.17101970@postgrespro.ru", "phone": "+70790813625"}
0005435312787	8F4DAD	9261 195965	ALEKSANDR MELNIKOV	{"phone": "+70245201054"}
0005435312788	454D09	1730 445839	VASILIY KOZLOV	{"phone": "+70040022672"}
0005435312789	1CEF80	1337 776372	NIKOLAY AFANASEV	{"email": "afanasevn.111983@postgrespro.ru", "phone": "+70633753289"}
0005435312790	AA5379	0029 222822	VARVARA SMIRNOVA	{"phone": "+70718886818"}
0005435312791	AA5379	0165 633009	TATYANA KUZMINA	{"phone": "+70962110808"}
0005435312792	D4D285	6513 387918	YULIYA LOGINOVA	{"email": "y-loginova.061985@postgrespro.ru", "phone": "+70877890659"}
0005435312793	D4D285	7518 694211	OKSANA MIRONOVA	{"email": "mironova-oksana.1974@postgrespro.ru", "phone": "+70530195954"}
0005435312794	97A337	8742 257321	OLEG BARANOV	{"email": "oleg-baranov_1986@postgrespro.ru", "phone": "+70602164952"}
0005435312795	B8CCA3	5245 820723	SERGEY SOROKIN	{"phone": "+70064104234"}
0005435312796	B8CCA3	4736 618119	ALEKSEY SEMENOV	{"phone": "+70057665984"}
0005435312797	9F4CDA	2430 960699	NADEZHDA DAVYDOVA	{"phone": "+70939822371"}
0005435312798	9F4CDA	7603 316839	KRISTINA SAVELEVA	{"email": "saveleva_kristina-011978@postgrespro.ru", "phone": "+70792070884"}
0005435312799	F55C0B	5343 009947	YULIYA ANISIMOVA	{"phone": "+70527115383"}
0005435312800	645290	9489 424713	EVGENIY PAVLOV	{"phone": "+70078222750"}
0005435312801	04474F	6792 255022	ROMAN MOISEEV	{"email": "rmoiseev.1977@postgrespro.ru", "phone": "+70744933363"}
0005435312802	04474F	4612 870976	VLADIMIR KISELEV	{"email": "vladimir-kiselev.071977@postgrespro.ru", "phone": "+70262567007"}
0005435312803	CDBF0B	0541 284863	ANTON SERGEEV	{"email": "sergeev-a_05061964@postgrespro.ru", "phone": "+70609089911"}
0005435312804	7B7BA5	9233 188254	VITALIY BORISOV	{"phone": "+70724922897"}
0005435312805	4DAE46	0582 235066	MARINA NIKITINA	{"email": "m.nikitina071981@postgrespro.ru", "phone": "+70675572577"}
0005435312806	4DAE46	9366 614802	YURIY NAUMOV	{"phone": "+70090845674"}
0005435312807	CF02E4	9903 474886	EVGENIY ZAYCEV	{"phone": "+70162415220"}
0005435312808	CF02E4	2301 470852	VALENTINA GUSEVA	{"phone": "+70843489226"}
0005435312809	536FE7	8272 258465	ALINA MOROZOVA	{"email": "a-morozova_1972@postgrespro.ru", "phone": "+70322276606"}
0005435312810	536FE7	7352 327775	ALEKSEY ROMANOV	{"phone": "+70203761421"}
0005435312811	536FE7	8419 647048	YURIY MOROZOV	{"email": "morozov.yuriy_111968@postgrespro.ru", "phone": "+70907886701"}
0005435312812	3D2786	4491 891274	NIKOLAY GAVRILOV	{"email": "gavrilov.n-121975@postgrespro.ru", "phone": "+70512388720"}
0005435312813	DFAE43	1972 988040	POLINA EGOROVA	{"phone": "+70076184530"}
0005435312814	819E77	4100 679212	TIMOFEY PETROV	{"email": "petrovtimofey-101978@postgrespro.ru", "phone": "+70442959304"}
0005435312815	0ADD00	3979 376667	RIMMA NIKITINA	{"email": "nikitina-rimma_1976@postgrespro.ru", "phone": "+70375611714"}
0005435312816	0ADD00	1945 830053	OLEG POPOV	{"phone": "+70417767702"}
0005435312817	6C6DBB	1808 067744	NINA KRASNOVA	{"phone": "+70869328489"}
0005435312818	C9933B	9087 708033	VASILIY CHERNOV	{"phone": "+70265871731"}
0005435312819	B0F713	4830 710444	IRINA SERGEEVA	{"email": "irina_sergeeva.1980@postgrespro.ru", "phone": "+70258533445"}
0005435312820	16FAD9	3450 002121	ROMAN BARANOV	{"email": "r-baranov.13061961@postgrespro.ru", "phone": "+70187422898"}
0005435312821	1D9AD0	1767 804194	OLGA DMITRIEVA	{"phone": "+70013466816"}
0005435312822	D030A8	6622 616611	NADEZHDA GAVRILOVA	{"email": "gavrilovanadezhda_12121962@postgrespro.ru", "phone": "+70611723307"}
0005435312823	254074	8995 284571	SVETLANA MAKAROVA	{"phone": "+70931831643"}
0005435312824	50F352	4824 461582	VALENTINA SCHERBAKOVA	{"phone": "+70030082393"}
0005435312825	B3C4F2	5788 559550	YURIY KUZMIN	{"phone": "+70789543571"}
0005435312826	B3C4F2	9646 703823	VIKTOR KOZLOV	{"email": "kozlov.v.18071979@postgrespro.ru", "phone": "+70804546594"}
0005435312827	18A04D	2530 227123	SVETLANA NESTEROVA	{"phone": "+70615185234"}
0005435312828	1BA7C2	8406 938454	NIKOLAY SOLOVEV	{"email": "n_solovev-19011957@postgrespro.ru", "phone": "+70484213796"}
0005435312829	4C81EF	9167 136388	DANIIL MAKSIMOV	{"phone": "+70612838566"}
0005435312830	6E6F3B	1721 974172	NATALIYA RYABOVA	{"phone": "+70007349819"}
0005435312831	DA4637	0741 892829	RAMIL DMITRIEV	{"phone": "+70185935491"}
0005435312832	C11DB5	6750 884651	DMITRIY DMITRIEV	{"phone": "+70962536584"}
0005435312833	C11DB5	9231 730774	ALEKSEY FOMIN	{"email": "alekseyfomin_1978@postgrespro.ru", "phone": "+70557017444"}
0005435312834	FDF038	4538 795161	DMITRIY ISAEV	{"email": "d_isaev_091976@postgrespro.ru", "phone": "+70123411680"}
0005435312835	FDF038	4169 804388	OLGA ROMANOVA	{"email": "romanova-olga-1967@postgrespro.ru", "phone": "+70127876508"}
0005435312836	6280A6	8493 391115	GALINA RYABOVA	{"email": "ryabova.galina.051976@postgrespro.ru", "phone": "+70410800540"}
0005435312837	05EF9A	5884 473192	MARIYA SEMENOVA	{"email": "m.semenova081974@postgrespro.ru", "phone": "+70057325855"}
0005435312838	78DD98	0173 004374	LUIZA KUZNECOVA	{"email": "l_kuznecova25091985@postgrespro.ru", "phone": "+70154309631"}
0005435312839	78DD98	5855 438743	GALINA POTAPOVA	{"email": "potapovag.24051978@postgrespro.ru", "phone": "+70902024044"}
0005435312840	1A612C	8494 127663	ALEKSANDR VASILEV	{"email": "aleksandr-vasilev10071976@postgrespro.ru", "phone": "+70309964828"}
0005435312841	1A612C	7062 047792	MARIYA TITOVA	{"email": "titova-mariya_041986@postgrespro.ru", "phone": "+70176219683"}
0005435312842	9DDBEE	3663 624102	OLGA MOISEEVA	{"phone": "+70317547952"}
0005435312843	086A52	4892 494999	VALENTIN SCHERBAKOV	{"email": "scherbakov_valentin1992@postgrespro.ru", "phone": "+70179583886"}
0005435312844	086A52	0307 602900	LYUBOV KOLESNIKOVA	{"email": "lyubovkolesnikova_011977@postgrespro.ru", "phone": "+70558956996"}
0005435312845	9D66B1	4503 510085	KONSTANTIN KOZLOV	{"phone": "+70346446186"}
0005435312846	F71C2A	5265 813875	ARTEM FROLOV	{"phone": "+70787860404"}
0005435312847	13E1B7	4053 426872	NATALYA STEPANOVA	{"phone": "+70831282352"}
0005435312848	025EB0	8605 755497	ARTUR KISELEV	{"email": "artur.kiselev1974@postgrespro.ru", "phone": "+70304190330"}
0005435312849	E79B2F	9878 634504	MAKSIM KUZNECOV	{"phone": "+70336434549"}
0005435312850	0CD90F	9774 329395	STEPAN POPOV	{"email": "popov-stepan_10091968@postgrespro.ru", "phone": "+70803132340"}
0005435312851	0CD90F	2263 412836	ELENA ZOTOVA	{"phone": "+70467631199"}
0005435312852	0D526D	8522 754199	VIKTORIYA SEMENOVA	{"email": "vsemenova_06101973@postgrespro.ru", "phone": "+70857777605"}
0005435312853	0D526D	0120 856708	ALEKSANDR ALEKSANDROV	{"phone": "+70742500192"}
0005435312854	D505AF	3902 257264	ELENA SOLOVEVA	{"phone": "+70876610451"}
0005435312855	D505AF	5966 143694	ALBERT MAKAROV	{"email": "makarov.albert_15091982@postgrespro.ru", "phone": "+70232050845"}
0005435312856	711DA4	5278 822925	VALENTINA VASILEVA	{"phone": "+70436090043"}
0005435312857	711DA4	2550 438757	ARSENIY MOISEEV	{"email": "arseniy-moiseev_1971@postgrespro.ru", "phone": "+70842720631"}
0005435312858	954D22	4602 007899	DMITRIY SOKOLOV	{"email": "d-sokolov-041974@postgrespro.ru", "phone": "+70812169381"}
0005435312859	98F0DE	5650 578862	ANASTASIYA ORLOVA	{"phone": "+70322429579"}
0005435312860	1C9EA3	4435 482322	DANIIL ZAKHAROV	{"email": "d-zakharov.091979@postgrespro.ru", "phone": "+70998139839"}
0005435312861	A0582E	9910 668820	LYUBOV SOROKINA	{"email": "sorokina_lyubov-1961@postgrespro.ru", "phone": "+70376177657"}
0005435312862	5C2979	2805 106650	VADIM EGOROV	{"email": "egorovvadim.17011967@postgrespro.ru", "phone": "+70475727690"}
0005435312863	632DE9	6621 730113	MARIYA IVANOVA	{"phone": "+70785900364"}
0005435312864	6EED3A	5431 961880	VERA KAZAKOVA	{"phone": "+70169583603"}
0005435312865	38C179	9582 113064	MAKSIM MELNIKOV	{"phone": "+70281915276"}
0005435312866	B77087	8024 213355	ANDREY KARPOV	{"email": "karpov.andrey_031968@postgrespro.ru", "phone": "+70382312953"}
0005435312867	5D5C94	4681 852049	NATALYA NESTEROVA	{"phone": "+70662445374"}
0005435312868	5482BE	2409 579082	SERGEY VASILEV	{"email": "vasilevsergey.11111982@postgrespro.ru", "phone": "+70349374352"}
0005435312869	710693	5094 103376	VLADIMIR MAKAROV	{"email": "makarov_vladimir_101967@postgrespro.ru", "phone": "+70793155078"}
0005435312870	710693	5433 760801	IGOR NIKITIN	{"phone": "+70516683520"}
0005435312871	7C2231	2806 495226	GEORGIY FEDOROV	{"email": "fedorov-georgiy.021962@postgrespro.ru", "phone": "+70892802268"}
0005435312872	A54665	6707 854985	VLADIMIR TIKHONOV	{"phone": "+70244388325"}
0005435312873	A54665	7577 557062	ANDREY SMIRNOV	{"email": "andreysmirnov.27041971@postgrespro.ru", "phone": "+70935403841"}
0005435312874	4C0921	7489 499813	DMITRIY KUZNECOV	{"email": "d_kuznecov10051972@postgrespro.ru", "phone": "+70997666936"}
0005435312875	2C219F	2358 441472	IRINA ROMANOVA	{"phone": "+70685889151"}
0005435312876	E56E86	0480 612007	DMITRIY ROMANOV	{"email": "romanov_d-02081971@postgrespro.ru", "phone": "+70968301625"}
0005435312877	E56E86	9002 646892	MIKHAIL KULIKOV	{"phone": "+70411421116"}
0005435312878	953033	7605 687477	SERAFIMA POPOVA	{"email": "serafima-popova-1974@postgrespro.ru", "phone": "+70639991101"}
0005435312879	0F3AF0	5372 573057	ELIZAVETA MAKAROVA	{"email": "makarovae22091980@postgrespro.ru", "phone": "+70856264311"}
0005435312880	C0537C	8461 876656	SERGEY STEPANOV	{"phone": "+70204353463"}
0005435312881	C0537C	3987 764711	IVAN ALEKSEEV	{"email": "ivan_alekseev1977@postgrespro.ru", "phone": "+70132959795"}
0005435312882	A92BD7	8752 065918	VLADIMIR MOISEEV	{"email": "moiseev.v_121969@postgrespro.ru", "phone": "+70422733634"}
0005435312883	72C004	8316 715007	ROMAN KARPOV	{"phone": "+70885811876"}
0005435312884	A4681E	0534 635557	VLADIMIR ZAKHAROV	{"phone": "+70096444549"}
0005435312885	A4681E	0360 502474	ALEKSANDR ZHURAVLEV	{"phone": "+70152904386"}
0005435312886	8BA97C	9070 078231	NATALYA AFANASEVA	{"email": "n_afanaseva_19091956@postgrespro.ru", "phone": "+70246736971"}
0005435312887	8BA97C	7587 244458	IRINA BORISOVA	{"phone": "+70567711523"}
0005435312888	0229BD	0424 472164	ELENA PETROVA	{"email": "petrovaelena061976@postgrespro.ru", "phone": "+70291248671"}
0005435312889	0229BD	7698 234642	VLADIMIR MOROZOV	{"email": "vladimir.morozov_09101967@postgrespro.ru", "phone": "+70073778170"}
0005435312895	3586AD	3039 301196	KLAVDIYA POLYAKOVA	{"email": "polyakovak-011964@postgrespro.ru", "phone": "+70326427809"}
0005435312896	F0CCC8	0552 651816	PAVEL VOLKOV	{"email": "pavel-volkov-061965@postgrespro.ru", "phone": "+70379958038"}
0005435312897	2F6C65	7960 292459	MARIYA MIRONOVA	{"email": "m.mironova.1965@postgrespro.ru", "phone": "+70109030281"}
0005435312898	23098A	4100 975395	NATALYA ANDREEVA	{"phone": "+70328681771"}
0005435312899	EE12E4	6412 638803	DANIS CHERNOV	{"email": "chernovdanis_011963@postgrespro.ru", "phone": "+70174802407"}
0005435312900	15B58D	8411 499332	LYUBOV KRASNOVA	{"email": "krasnova-lyubov.31011967@postgrespro.ru", "phone": "+70522122939"}
0005435312901	A665D3	9360 017991	ALEKSEY KUZNECOV	{"email": "kuznecov_aleksey.021972@postgrespro.ru", "phone": "+70084728543"}
0005435312902	6B4F0F	2618 706505	ALEKSANDR YAKOVLEV	{"email": "yakovlev_a_111983@postgrespro.ru", "phone": "+70792864162"}
0005435312903	42A49B	2848 839200	MIKHAIL FEDOROV	{"phone": "+70506423259"}
0005435312904	0E0364	3813 655970	OLGA ILINA	{"email": "ilina.olga-18041975@postgrespro.ru", "phone": "+70939079798"}
0005435312905	0E0364	9204 678520	YURIY GUSEV	{"email": "gusevy-05031975@postgrespro.ru", "phone": "+70399767024"}
0005435312906	267312	6692 565400	ALEKSEY AFANASEV	{"phone": "+70475041368"}
0005435312907	267312	4914 152910	NATALYA SERGEEVA	{"email": "sergeeva.n_08111976@postgrespro.ru", "phone": "+70382494392"}
0005435312908	F92B6A	0731 579925	YULIYA TARASOVA	{"phone": "+70906849739"}
0005435312909	4941CC	9568 679188	ALEKSANDR FEDOROV	{"phone": "+70457873773"}
0005435312910	3C4BAF	7620 228153	DANIIL KISELEV	{"email": "daniil.kiselev011972@postgrespro.ru", "phone": "+70538763313"}
0005435312911	1C83EB	6659 059039	RAFAEL NIKITIN	{"phone": "+70173244617"}
0005435312912	1C83EB	2600 449581	OKSANA LAZAREVA	{"email": "oksana.lazareva-18031975@postgrespro.ru", "phone": "+70638605149"}
0005435312913	C80828	3780 861775	SERGEY TIKHONOV	{"email": "tikhonov_s.11081973@postgrespro.ru", "phone": "+70068167730"}
0005435312914	C80828	5486 602434	ANZHELIKA OVCHINNIKOVA	{"email": "anzhelikaovchinnikova.1974@postgrespro.ru", "phone": "+70620144430"}
0005435314767	23D8ED	4891 228887	ANNA TIKHONOVA	{"phone": "+70899262265"}
0005435314768	23D8ED	9949 162036	OLGA ROMANOVA	{"email": "oromanova.061974@postgrespro.ru", "phone": "+70470207165"}
0005435314769	9CD578	4970 485979	TATYANA IVANOVA	{"email": "ivanovat091959@postgrespro.ru", "phone": "+70074336743"}
0005435314770	9CD578	6933 848428	LARISA STEPANOVA	{"phone": "+70857104622"}
0005435314771	F41C8F	2771 639517	VALENTINA KUZNECOVA	{"email": "v.kuznecova.1982@postgrespro.ru", "phone": "+70259860169"}
0005435314772	EFD43D	3368 210940	KIRILL RODIONOV	{"email": "krodionov-1967@postgrespro.ru", "phone": "+70532958141"}
0005435314773	E29C53	0911 027005	ANDREY PETROV	{"phone": "+70283299076"}
0005435314774	F392F8	7685 967691	ANASTASIYA KRASNOVA	{"email": "a.krasnova11031974@postgrespro.ru", "phone": "+70757003286"}
0005435314775	91E38E	7363 728599	YAN NOVIKOV	{"phone": "+70843670914"}
0005435314776	91E38E	3696 998607	SVETLANA LOGINOVA	{"email": "s_loginova1968@postgrespro.ru", "phone": "+70789848620"}
0005435314777	32D1B0	1405 567043	VLADIMIR BONDARENKO	{"email": "vladimir.bondarenko.1978@postgrespro.ru", "phone": "+70627442932"}
0005435314778	949F16	7670 573951	YULIYA VOLKOVA	{"phone": "+70201555155"}
0005435314779	9E8AD0	3308 227607	ARTEM KUZNECOV	{"email": "a-kuznecov-22101974@postgrespro.ru", "phone": "+70631855011"}
0005435314780	F22786	7892 139496	DMITRIY VOLKOV	{"phone": "+70977099755"}
0005435314781	F22786	2930 304492	MARINA POPOVA	{"email": "m.popova16011977@postgrespro.ru", "phone": "+70394949958"}
0005435314782	83E2B2	9055 263766	GALINA ALEKSEEVA	{"phone": "+70430999998"}
0005435314783	62307A	7253 755913	ANASTASIYA VOROBEVA	{"phone": "+70519926525"}
0005435314784	95B3D4	3924 493990	ALEKSANDR BELOV	{"email": "a.belov-03081982@postgrespro.ru", "phone": "+70561741952"}
0005435314785	630FA1	5076 257645	TAMARA ZHUKOVA	{"email": "t_zhukova_1969@postgrespro.ru", "phone": "+70829161120"}
0005435314786	CAB7D6	3678 527370	YURIY SAVELEV	{"phone": "+70130546826"}
0005435314787	EF7A25	6574 058201	SERGEY BORISOV	{"email": "sergey.borisov041972@postgrespro.ru", "phone": "+70942541280"}
0005435314788	384898	1920 124605	EGOR KUZNECOV	{"phone": "+70447828131"}
0005435314789	384898	8713 815064	VALENTINA KOZLOVA	{"email": "valentinakozlova_28011983@postgrespro.ru", "phone": "+70878645568"}
0005435314790	1998C7	8583 769699	ALEKSANDR ALEKSEEV	{"phone": "+70857787403"}
0005435314791	1998C7	5989 278214	ALEKSANDR FILIPPOV	{"phone": "+70953706073"}
0005435314792	4CC56A	7317 722920	DENIS IVANOV	{"phone": "+70727841720"}
0005435314793	C77243	0211 472962	ALEKSANDRA SOLOVEVA	{"email": "aleksandra_soloveva_1969@postgrespro.ru", "phone": "+70611174034"}
0005435314794	58EE28	6832 954929	VLADIMIR YAKOVLEV	{"email": "yakovlev.vladimir-1956@postgrespro.ru", "phone": "+70987341636"}
0005435314795	58EE28	5999 510255	NIKOLAY ZHURAVLEV	{"email": "zhuravlev.nikolay1973@postgrespro.ru", "phone": "+70627049067"}
0005435314796	8DC93D	2173 203036	GALINA DAVYDOVA	{"email": "g.davydova-1976@postgrespro.ru", "phone": "+70516141189"}
0005435314797	8DC93D	6960 345752	GAGIK IVANOV	{"phone": "+70746261391"}
0005435314798	4A87D5	0655 895692	EVGENIY ILIN	{"phone": "+70803433926"}
0005435314799	4A87D5	2889 408240	VLADIMIR FEDOROV	{"email": "fedorovvladimir_011961@postgrespro.ru", "phone": "+70154463688"}
0005435314800	77F50D	3174 419546	VYACHESLAV RODIONOV	{"phone": "+70676294298"}
0005435314801	77F50D	5327 079518	ALEKSEY BONDARENKO	{"phone": "+70492597313"}
0005435314802	24887F	8501 454236	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir-1970@postgrespro.ru", "phone": "+70544044989"}
0005435314803	F0AA93	2372 675828	ANASTASIYA GRISHINA	{"phone": "+70649508774"}
0005435314804	F0AA93	3372 228093	VALENTIN KUZNECOV	{"email": "vkuznecov-061966@postgrespro.ru", "phone": "+70376553810"}
0005435314805	BD7719	5076 818523	IRINA SIDOROVA	{"phone": "+70583084022"}
0005435314806	ABD0A2	0528 402202	ALENA KULIKOVA	{"email": "alena-kulikova.011975@postgrespro.ru", "phone": "+70065299549"}
0005435314807	80FFAD	9955 241870	VALENTINA PAVLOVA	{"email": "pavlova_valentina23101984@postgrespro.ru", "phone": "+70810085395"}
0005435314808	865B5B	3517 379776	LEONID ZAKHAROV	{"email": "zakharovl_1972@postgrespro.ru", "phone": "+70321568549"}
0005435314809	865B5B	6067 674765	VLADIMIR MIKHAYLOV	{"phone": "+70676186302"}
0005435314810	3C2085	9568 254774	DENIS GORBUNOV	{"email": "denisgorbunov.011967@postgrespro.ru", "phone": "+70322086302"}
0005435314811	3C2085	8041 129203	OLEG KUZNECOV	{"email": "oleg-kuznecov-041978@postgrespro.ru", "phone": "+70300740104"}
0005435314812	3CF731	7404 954221	NAIL ZAYCEV	{"email": "zaycevnail.1972@postgrespro.ru", "phone": "+70993623228"}
0005435314813	8C163F	9189 853681	IRINA ZAKHAROVA	{"phone": "+70049708915"}
0005435314814	5F5D1E	5478 102056	PAVEL ABRAMOV	{"phone": "+70396395850"}
0005435314815	4C4258	7864 854863	OLGA RYABOVA	{"phone": "+70658609310"}
0005435314816	575344	6501 637806	VLADIMIR SMIRNOV	{"email": "v_smirnov.26111976@postgrespro.ru", "phone": "+70718022480"}
0005435314817	4C9B9B	2519 072401	VALENTINA TIMOFEEVA	{"email": "timofeeva_valentina021978@postgrespro.ru", "phone": "+70038044942"}
0005435314818	A299B2	2966 927796	ALEKSEY SOKOLOV	{"email": "sokolov.aleksey-041985@postgrespro.ru", "phone": "+70274373209"}
0005435314819	A299B2	6861 195511	EVGENIY FEDOROV	{"email": "fedorovevgeniy_1966@postgrespro.ru", "phone": "+70577917726"}
0005435314820	C77A83	5395 816582	VLADIMIR SMIRNOV	{"phone": "+70472627380"}
0005435314821	5C5DBC	5353 366270	LYUBOV MOROZOVA	{"email": "morozoval-06021966@postgrespro.ru", "phone": "+70689186753"}
0005435314822	00EC9F	9016 051001	LYUDMILA NESTEROVA	{"phone": "+70242462547"}
0005435314823	00EC9F	0451 294832	VALENTINA BORISOVA	{"email": "borisova-valentina_08101971@postgrespro.ru", "phone": "+70558181476"}
0005435314824	B56C9D	7587 218230	NADEZHDA LAZAREVA	{"email": "lazareva_nadezhda_15021977@postgrespro.ru", "phone": "+70037992047"}
0005435314825	26764B	2060 597119	SERGEY TIKHONOV	{"phone": "+70516539040"}
0005435314826	26764B	1231 427762	MIKHAIL ALEKSANDROV	{"email": "aleksandrov_m-051976@postgrespro.ru", "phone": "+70426593765"}
0005435314827	26764B	1828 918405	VLADIMIR KAZAKOV	{"email": "kazakov-v-18091964@postgrespro.ru", "phone": "+70573543260"}
0005435314828	B843A7	4554 235694	IGOR FEDOTOV	{"email": "i.fedotov-111973@postgrespro.ru", "phone": "+70454492675"}
0005435314829	22BCBF	8289 027037	ALEKSEY POPOV	{"email": "popov.aleksey.081971@postgrespro.ru", "phone": "+70158967107"}
0005435314830	1BB0DF	5321 627832	ARTUR MAKSIMOV	{"phone": "+70955266265"}
0005435314831	026BD3	2207 261684	OKSANA TARASOVA	{"phone": "+70350432582"}
0005435314832	C29EA3	9733 159952	OLGA LOGINOVA	{"phone": "+70725380715"}
0005435314833	3EC083	8011 249852	IRINA ISAEVA	{"phone": "+70716170109"}
0005435314834	8B381D	7808 124631	OKSANA MOROZOVA	{"phone": "+70905873045"}
0005435314835	8B381D	5608 351016	OLESYA VLASOVA	{"email": "vlasova.o.041963@postgrespro.ru", "phone": "+70637720956"}
0005435314836	E85762	2531 590666	ALEKSANDR OSIPOV	{"email": "aleksandr_osipov.091967@postgrespro.ru", "phone": "+70610595591"}
0005435314837	E85762	0170 645444	ARTEM GAVRILOV	{"phone": "+70088710814"}
0005435314838	DB5D82	4049 749522	ALBERT MIKHAYLOV	{"phone": "+70910711009"}
0005435314839	A76194	4317 460653	VALERIY KONOVALOV	{"phone": "+70747617600"}
0005435314840	81CA52	9889 118274	NATALYA SAVELEVA	{"email": "natalyasaveleva_10111972@postgrespro.ru", "phone": "+70898274587"}
0005435314841	3BE7C4	7836 115807	ALEKSANDR ANTONOV	{"email": "aleksandr.antonov-1984@postgrespro.ru", "phone": "+70869238423"}
0005435314842	7A74D2	3722 984482	ALEKSEY GAVRILOV	{"phone": "+70757213448"}
0005435314843	E612D3	9538 089851	ELIZAVETA SOKOLOVA	{"email": "sokolova.elizaveta-21091980@postgrespro.ru", "phone": "+70297803922"}
0005435314844	ABE51D	3898 650298	YURIY TIMOFEEV	{"email": "yuriy-timofeev.1979@postgrespro.ru", "phone": "+70728628252"}
0005435314845	ABE51D	2822 200670	OLEG SOROKIN	{"email": "o.sorokin-24121976@postgrespro.ru", "phone": "+70246277698"}
0005435314846	7C5EEB	7255 984370	MIKHAIL ALEKSANDROV	{"phone": "+70388458398"}
0005435314847	964729	6714 337177	VIKTOR FILIPPOV	{"email": "filippov_viktor.071966@postgrespro.ru", "phone": "+70831562594"}
0005435314848	964729	7679 939578	ELENA KAZAKOVA	{"phone": "+70413235380"}
0005435314849	E0B95F	6140 620813	ANDREY KULIKOV	{"email": "akulikov-14031967@postgrespro.ru", "phone": "+70116955640"}
0005435314850	E0B95F	4452 041267	MARAT ALEKSEEV	{"email": "m_alekseev.29091975@postgrespro.ru", "phone": "+70624262621"}
0005435314851	0328CF	9096 124783	ANASTASIYA VLASOVA	{"phone": "+70910349998"}
0005435314852	6E1C0A	6373 173270	ANNA CHERNOVA	{"email": "chernova_a091973@postgrespro.ru", "phone": "+70624613385"}
0005435314853	7414F8	7240 245927	VALENTIN PAVLOV	{"phone": "+70213984778"}
0005435314854	C22A5C	3594 405197	OLEG ZAKHAROV	{"phone": "+70835941845"}
0005435314855	C22A5C	0092 400885	ELENA ZOTOVA	{"phone": "+70010282327"}
0005435314856	C22A5C	8447 078990	YURIY NAZAROV	{"phone": "+70356922846"}
0005435314857	5D695A	1834 107948	SERGEY MIRONOV	{"phone": "+70060814586"}
0005435314858	5D695A	9147 227437	VALERIYA DANILOVA	{"email": "valeriya_danilova.25081982@postgrespro.ru", "phone": "+70890773972"}
0005435314859	3A995E	1980 158590	ALEKSANDR SAVELEV	{"phone": "+70492525254"}
0005435314860	EEB310	5460 160037	VALENTINA ABRAMOVA	{"email": "v_abramova.1978@postgrespro.ru", "phone": "+70678316123"}
0005435314861	EEB310	6402 928428	ILYA SHEVCHENKO	{"phone": "+70673902496"}
0005435314862	EEB310	9047 724892	ASIYA ZHURAVLEVA	{"phone": "+70893548026"}
0005435314863	EA3E21	3457 976435	MAKSIM DMITRIEV	{"email": "dmitriev-m.05061974@postgrespro.ru", "phone": "+70344347668"}
0005435314864	EA3E21	4201 545083	NATALYA KULIKOVA	{"email": "n_kulikova.121975@postgrespro.ru", "phone": "+70319264494"}
0005435314865	72B592	1352 369640	ALEKSANDR MOROZOV	{"phone": "+70022600515"}
0005435314866	72B592	7423 513031	EVGENIY SHEVCHENKO	{"email": "e-shevchenko-111971@postgrespro.ru", "phone": "+70247266510"}
0005435314867	49D78D	3565 963149	VLADIMIR NAUMOV	{"phone": "+70330115956"}
0005435314868	B5F763	5668 195325	EVGENIY ILIN	{"email": "e.ilin.111970@postgrespro.ru", "phone": "+70466864714"}
0005435314869	D293D7	4235 186521	NINA BELYAEVA	{"phone": "+70174732140"}
0005435314870	D293D7	7184 010160	VALERIY MAKSIMOV	{"email": "maksimov_valeriy-09081971@postgrespro.ru", "phone": "+70077304475"}
0005435314871	EA219D	5475 954720	VIKTOR BARANOV	{"email": "baranov_viktor.13061967@postgrespro.ru", "phone": "+70868834668"}
0005435314872	35C1DC	4137 305268	SERGEY DAVYDOV	{"email": "davydov-sergey071974@postgrespro.ru", "phone": "+70821421581"}
0005435314873	80B317	0994 500601	VALENTINA EFIMOVA	{"email": "valentina_efimova-091961@postgrespro.ru", "phone": "+70127982000"}
0005435314874	D9DC62	8610 614513	ANASTASIYA ZAKHAROVA	{"email": "azakharova121970@postgrespro.ru", "phone": "+70635172515"}
0005435314875	D9DC62	6663 404930	MATVEY ISAEV	{"phone": "+70361630448"}
0005435314876	470C2E	0253 120812	VYACHESLAV NIKITIN	{"email": "v_nikitin30051960@postgrespro.ru", "phone": "+70286332689"}
0005435314877	D838DA	0517 639248	IRINA IVANOVA	{"phone": "+70472377610"}
0005435314878	D838DA	5737 666660	MARINA SOLOVEVA	{"email": "soloveva.marina-1969@postgrespro.ru", "phone": "+70801277954"}
0005435314879	D838DA	3043 036089	ANTONINA GERASIMOVA	{"email": "gerasimova.antonina_31071978@postgrespro.ru", "phone": "+70600660726"}
0005435314880	4332CD	0145 265669	MARIYA MAKAROVA	{"phone": "+70693911575"}
0005435314881	858CD9	4092 128262	ANNA SERGEEVA	{"email": "annasergeeva1969@postgrespro.ru", "phone": "+70078431945"}
0005435314882	FAAE76	2105 883227	OLGA SERGEEVA	{"phone": "+70424207556"}
0005435314883	BD1ADA	0680 947820	MIKHAIL NOVIKOV	{"phone": "+70284585838"}
0005435314884	21C9A4	0821 168011	ALEKSANDR KARPOV	{"email": "aleksandrkarpov.22101974@postgrespro.ru", "phone": "+70390951618"}
0005435314885	799C62	4607 175980	VITALIY TIKHONOV	{"phone": "+70336211364"}
0005435314886	799C62	9678 838227	EVDOKIYA IVANOVA	{"phone": "+70777300873"}
0005435314887	F875EF	0513 602231	VALENTINA EGOROVA	{"email": "egorova-v16071966@postgrespro.ru", "phone": "+70356204653"}
0005435314888	387248	5707 514485	LYUBOV TARASOVA	{"email": "tarasova_lyubov-051974@postgrespro.ru", "phone": "+70517712240"}
0005435314889	54EAF7	0885 447128	DMITRIY MELNIKOV	{"email": "dmitriy_melnikov071988@postgrespro.ru", "phone": "+70399611287"}
0005435314890	31F80C	2048 672643	MAKSIM DENISOV	{"email": "maksim-denisov-21061967@postgrespro.ru", "phone": "+70108733406"}
0005435314891	F6BC1C	9993 683065	TATYANA NIKIFOROVA	{"phone": "+70593801527"}
0005435314892	F6BC1C	4127 775972	FEDOR FILIPPOV	{"email": "filippov_fedor_1969@postgrespro.ru", "phone": "+70170033953"}
0005435314893	8B0690	3529 052498	YURIY KUZNECOV	{"email": "kuznecov-yuriy.1977@postgrespro.ru", "phone": "+70929068714"}
0005435314894	58CFDF	0336 231482	IRINA KALININA	{"phone": "+70818297256"}
0005435314895	0A5A18	9270 558068	GALINA KOVALEVA	{"email": "kovaleva_galina_101974@postgrespro.ru", "phone": "+70032480252"}
0005435314896	A5C8DC	9398 995862	NATALYA IVANOVA	{"email": "natalya.ivanova031972@postgrespro.ru", "phone": "+70519074852"}
0005435314897	E6D306	2722 179920	EKATERINA KONDRATEVA	{"email": "ekaterina.kondrateva1968@postgrespro.ru", "phone": "+70255121213"}
0005435314898	692903	7841 470560	OLGA KOZLOVA	{"email": "kozlovao.17121981@postgrespro.ru", "phone": "+70917600784"}
0005435314899	1C31E9	2016 914173	NATALIYA KONDRATEVA	{"phone": "+70844275964"}
0005435314900	8D0470	8340 296144	NINA MELNIKOVA	{"phone": "+70293045152"}
0005435314901	742246	5375 348852	ANATOLIY SMIRNOV	{"email": "smirnov_a-071982@postgrespro.ru", "phone": "+70610053745"}
0005435314902	C61D81	9498 599065	GALINA DAVYDOVA	{"email": "davydova.galina041957@postgrespro.ru", "phone": "+70508761314"}
0005435314903	B78F19	3777 610748	IRINA KISELEVA	{"phone": "+70072762186"}
0005435314904	B78F19	2925 803469	NADEZHDA FROLOVA	{"phone": "+70748878254"}
0005435314905	A4967E	7958 405110	VALENTINA PETROVA	{"phone": "+70752331905"}
0005435314906	B79271	1189 292407	VALERIY VASILEV	{"email": "v_vasilev_19071970@postgrespro.ru", "phone": "+70914513795"}
0005435314907	DC2CD0	5799 603357	EVGENIYA PAVLOVA	{"phone": "+70695918419"}
0005435314908	DC2CD0	7606 774664	ANATOLIY TARASOV	{"email": "anatoliy_tarasov-1975@postgrespro.ru", "phone": "+70939321078"}
0005435314909	2FBAB5	2101 469424	LARISA KOVALEVA	{"email": "kovaleva-larisa.21021965@postgrespro.ru", "phone": "+70078823129"}
0005435314910	2A91B8	4619 628111	EVGENIY KUZMIN	{"email": "e.kuzmin.15051974@postgrespro.ru", "phone": "+70783137159"}
0005435314911	2A91B8	0257 404075	ALEKSANDRA SIDOROVA	{"phone": "+70334762786"}
0005435314912	62ACDD	8240 497468	TATYANA MALYSHEVA	{"phone": "+70641360343"}
0005435314913	7B3A98	6742 328378	TATYANA PETROVA	{"phone": "+70523289687"}
0005435314914	6BC3EB	2089 384349	MAKSIM ANDREEV	{"email": "andreev.maksim-17041969@postgrespro.ru", "phone": "+70356913609"}
0005435314915	0CF9CE	8656 945969	YULIYA BELOVA	{"email": "y.belova-23121967@postgrespro.ru", "phone": "+70279001833"}
0005435314916	9E13F2	3112 148142	DMITRIY ANDREEV	{"phone": "+70983883229"}
0005435314917	9E13F2	9911 368226	EVGENIY YAKOVLEV	{"email": "yakovlev_evgeniy-1960@postgrespro.ru", "phone": "+70009031694"}
0005435314918	FC174F	9199 528788	YANA CHERNOVA	{"phone": "+70635264695"}
0005435314919	087A01	0418 797539	ALEKSANDR BORISOV	{"email": "borisov.aleksandr_1957@postgrespro.ru", "phone": "+70888189529"}
0005435314920	087A01	9635 828117	ALEKSEY TARASOV	{"phone": "+70391098310"}
0005435314921	043CEA	5099 449802	MIKHAIL IVANOV	{"phone": "+70891079102"}
0005435314922	043CEA	1484 097628	OKSANA ROMANOVA	{"email": "o-romanova.1974@postgrespro.ru", "phone": "+70925009170"}
0005435314923	043CEA	6900 581006	MARIYA KOZLOVA	{"email": "mariya_kozlova071977@postgrespro.ru", "phone": "+70475854246"}
0005435314924	247882	4622 530347	PAVEL ILIN	{"email": "pilin071971@postgrespro.ru", "phone": "+70623216484"}
0005435314925	C49A79	5073 056919	ANNA ZHURAVLEVA	{"phone": "+70581902924"}
0005435314926	C49A79	9597 334329	NATALYA ANTONOVA	{"phone": "+70801339512"}
0005435314927	DD0927	2724 383045	NIKOLAY ZAKHAROV	{"email": "zakharov_n1984@postgrespro.ru", "phone": "+70848246935"}
0005435314928	75BBEB	1942 889533	NIKOLAY GRIGOREV	{"phone": "+70557768828"}
0005435314929	052DD6	2395 660848	OLGA IVANOVA	{"phone": "+70276931804"}
0005435314930	052DD6	3725 623411	GULFIYA DENISOVA	{"phone": "+70885863553"}
0005435314931	4D44E0	1623 891391	SERGEY ANDREEV	{"email": "andreevsergey_011976@postgrespro.ru", "phone": "+70029788445"}
0005435314932	0E482D	1166 057508	ELIZAVETA KARPOVA	{"email": "ekarpova_011977@postgrespro.ru", "phone": "+70260284686"}
0005435314933	0E482D	7025 574779	ANDREY NIKITIN	{"email": "andrey.nikitin17071963@postgrespro.ru", "phone": "+70237681104"}
0005435314934	99471E	4785 308094	TATYANA ZAYCEVA	{"email": "zayceva_t-1967@postgrespro.ru", "phone": "+70480622767"}
0005435314935	6C0F8F	4387 006260	ALLA VASILEVA	{"phone": "+70957957195"}
0005435314936	6C0F8F	0605 342646	MIKHAIL MIKHAYLOV	{"email": "mikhail.mikhaylov061963@postgrespro.ru", "phone": "+70914099441"}
0005435314937	8CD6D1	9383 892440	VALERIYA MATVEEVA	{"email": "matveevavaleriya-121975@postgrespro.ru", "phone": "+70706064198"}
0005435314938	8CD6D1	7821 869503	VERONIKA KISELEVA	{"email": "v_kiseleva-1968@postgrespro.ru", "phone": "+70809901124"}
0005435314939	8D074D	1335 211709	ANATOLIY ZAYCEV	{"email": "zaycevanatoliy_041966@postgrespro.ru", "phone": "+70271114368"}
0005435314940	8D074D	4984 101609	ALEKSEY ILIN	{"email": "a_ilin091969@postgrespro.ru", "phone": "+70590571941"}
0005435314941	1B7243	0320 191615	LEV SAVELEV	{"email": "savelev_lev_031977@postgrespro.ru", "phone": "+70170402355"}
0005435314942	4EEBA7	5335 983319	LARISA OSIPOVA	{"phone": "+70488207242"}
0005435314943	1031F9	7127 310485	VASILIY STEPANOV	{"email": "v_stepanov.1970@postgrespro.ru", "phone": "+70341986836"}
0005435314944	1031F9	0739 903877	VALENTINA AFANASEVA	{"phone": "+70742642861"}
0005435314945	DD716C	4813 888190	INNA KISELEVA	{"email": "kiselevai.091964@postgrespro.ru", "phone": "+70238373517"}
0005435314946	1536CD	7437 323445	ALEKSEY IVANOV	{"phone": "+70008374502"}
0005435314947	1536CD	0316 245952	EKATERINA KUZNECOVA	{"email": "kuznecova-ekaterina_09061972@postgrespro.ru", "phone": "+70878147127"}
0005435314948	95EC63	4574 640535	MIKHAIL NIKOLAEV	{"phone": "+70651479436"}
0005435314949	B54E71	8932 817990	ELENA GUSEVA	{"email": "guseva_e.031965@postgrespro.ru", "phone": "+70873613322"}
0005435314950	898359	5846 823637	MARAT MAKAROV	{"phone": "+70987619346"}
0005435314951	D46230	5033 982953	NATALYA POLYAKOVA	{"email": "n-polyakova_10071977@postgrespro.ru", "phone": "+70510834969"}
0005435314952	D46230	3102 822872	OKSANA RODIONOVA	{"phone": "+70959384876"}
0005435314953	2E4AEB	1557 610659	VITALIY STEPANOV	{"email": "v_stepanov-01101974@postgrespro.ru", "phone": "+70523486004"}
0005435314954	DF4644	2424 362025	EKATERINA VLASOVA	{"phone": "+70427308554"}
0005435314955	5A0CDE	7385 618437	ANASTASIYA LEBEDEVA	{"phone": "+70260438463"}
0005435314956	85F655	7544 993161	ELENA DANILOVA	{"phone": "+70338109654"}
0005435314957	027E14	9626 515550	FEDOR NIKITIN	{"email": "nikitin.fedor.04061967@postgrespro.ru", "phone": "+70473194800"}
0005435314958	C3514C	6510 608714	NATALYA NESTEROVA	{"phone": "+70271569517"}
0005435314959	C3514C	3641 807842	MARGARITA MAKAROVA	{"phone": "+70487097081"}
0005435314960	A055AF	1194 778894	VIKTOR MOISEEV	{"email": "viktor_moiseev-06121972@postgrespro.ru", "phone": "+70215355896"}
0005435314961	5C9519	1942 514294	NADEZHDA YUDINA	{"phone": "+70103565013"}
0005435314962	0FE958	0031 772035	NADEZHDA NIKOLAEVA	{"email": "nnikolaeva.1967@postgrespro.ru", "phone": "+70843277085"}
0005435314963	0FE958	9200 122056	LYUBOV NIKOLAEVA	{"email": "lyubovnikolaeva.01121984@postgrespro.ru", "phone": "+70763930156"}
0005435314964	F03252	3042 371355	MIKHAIL GAVRILOV	{"phone": "+70382831682"}
0005435314965	CBCB53	2038 829652	ANDREY MAKAROV	{"email": "makarov-andrey-10121988@postgrespro.ru", "phone": "+70487614885"}
0005435314966	DD5E13	3240 310686	YAROSLAV PETROV	{"email": "petrov.yaroslav_091967@postgrespro.ru", "phone": "+70056783724"}
0005435314967	F7380B	2137 537198	MIKHAIL TARASOV	{"phone": "+70436413163"}
0005435314968	F7380B	8809 791200	EVGENIY ZHURAVLEV	{"email": "zhuravlev.evgeniy_041974@postgrespro.ru", "phone": "+70978310949"}
0005435314969	4686FF	8468 538230	ARTUR KUZNECOV	{"email": "artur_kuznecov-15051971@postgrespro.ru", "phone": "+70866419075"}
0005435314970	C535C5	6108 547010	ALEKSANDR KOZLOV	{"phone": "+70669650778"}
0005435314971	7C358B	0763 546107	DANILA TARASOV	{"email": "d.tarasov14051958@postgrespro.ru", "phone": "+70767252859"}
0005435314972	596470	6072 583373	IVAN FEDOROV	{"phone": "+70809714160"}
0005435314973	FC16B3	7910 876609	MARINA BORISOVA	{"email": "borisovamarina_1984@postgrespro.ru", "phone": "+70489360346"}
0005435314974	C00ECB	5050 510601	DMITRIY ABRAMOV	{"email": "abramov-d.21091970@postgrespro.ru", "phone": "+70965419241"}
0005435314975	B813E8	1299 275378	VLADIMIR GAVRILOV	{"phone": "+70575868513"}
0005435314976	EBFFF3	8791 354854	ZINAIDA POPOVA	{"phone": "+70814324306"}
0005435314977	98BA43	8466 101848	SVETLANA ZHUKOVA	{"email": "zhukova-s.031982@postgrespro.ru", "phone": "+70796015629"}
0005435315034	261F6C	1389 450177	NINA ZAYCEVA	{"phone": "+70048258536"}
0005435314978	98BA43	1399 301360	ROMAN ALEKSANDROV	{"email": "roman-aleksandrov081970@postgrespro.ru", "phone": "+70105945770"}
0005435314979	2BAA6E	0913 326380	SOFIYA IVANOVA	{"email": "ivanovasofiya-041972@postgrespro.ru", "phone": "+70639083863"}
0005435314980	B18DFE	1236 425303	NINA EGOROVA	{"email": "egorova_n071976@postgrespro.ru", "phone": "+70665924354"}
0005435314981	CBA017	4717 021379	ALEKSANDR SERGEEV	{"phone": "+70925805292"}
0005435314982	545B3B	2016 518208	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev-21111967@postgrespro.ru", "phone": "+70696849437"}
0005435314983	545B3B	8973 651997	KONSTANTIN KUZNECOV	{"phone": "+70080811252"}
0005435314984	36829B	4874 862717	YULIYA POTAPOVA	{"email": "yuliya.potapova011977@postgrespro.ru", "phone": "+70881072545"}
0005435314985	36829B	7111 185558	EVGENIY SMIRNOV	{"phone": "+70599256108"}
0005435314986	07134B	0499 191022	LYUDMILA POPOVA	{"phone": "+70150361719"}
0005435314987	07134B	4934 655857	NIKOLAY KUZNECOV	{"phone": "+70248882587"}
0005435314988	B67E98	8704 947543	PAVEL KUZNECOV	{"phone": "+70238875195"}
0005435314989	B67E98	4336 623947	ALEKSANDRA SOLOVEVA	{"phone": "+70203233490"}
0005435314990	E50E5F	0575 354099	NADEZHDA KULIKOVA	{"email": "nadezhda.kulikova_13121974@postgrespro.ru", "phone": "+70029340431"}
0005435314991	E50E5F	3062 872271	VALENTINA DANILOVA	{"phone": "+70701010797"}
0005435314992	E50E5F	8513 324793	ALEKSANDR MOROZOV	{"phone": "+70184883327"}
0005435314993	76BAC1	6194 160509	IGOR MOROZOV	{"email": "morozov_i_031967@postgrespro.ru", "phone": "+70367807052"}
0005435314994	76BAC1	5187 768508	ASKHAT NAZAROV	{"email": "askhat-nazarov1973@postgrespro.ru", "phone": "+70075582527"}
0005435314995	DDDCB0	4137 957101	SERGEY FROLOV	{"email": "frolov_sergey1961@postgrespro.ru", "phone": "+70331883408"}
0005435314996	C7570D	3611 125156	EKATERINA SEMENOVA	{"phone": "+70605520636"}
0005435314997	05FBBA	7348 184473	ELENA KAZAKOVA	{"email": "e-kazakova.22031981@postgrespro.ru", "phone": "+70558891658"}
0005435314998	7B9F6D	2749 959798	NADEZHDA DAVYDOVA	{"email": "nadezhda_davydova_1973@postgrespro.ru", "phone": "+70792227555"}
0005435314999	C8E637	1611 181859	OLGA ISAEVA	{"email": "o-isaeva_1973@postgrespro.ru", "phone": "+70444046637"}
0005435315000	9A9B73	6777 478907	VLADIMIR BELOV	{"email": "v.belov_011978@postgrespro.ru", "phone": "+70205924551"}
0005435315001	4EE717	0229 171239	NATALYA OSIPOVA	{"email": "natalya_osipova081964@postgrespro.ru", "phone": "+70066413180"}
0005435315002	F5CC22	3165 820419	LYUDMILA ANDREEVA	{"email": "l-andreeva15101976@postgrespro.ru", "phone": "+70709432755"}
0005435315003	F5CC22	6688 261874	OLEG FEDOTOV	{"email": "o_fedotov1972@postgrespro.ru", "phone": "+70233932960"}
0005435315004	F5CC22	8972 050243	VENIAMIN KUZNECOV	{"email": "veniamin.kuznecov_1989@postgrespro.ru", "phone": "+70737351347"}
0005435315005	3DF7E2	8638 965480	NADEZHDA OSIPOVA	{"phone": "+70296650960"}
0005435315006	5494F9	9471 210371	VLADIMIR NOVIKOV	{"email": "vnovikov091973@postgrespro.ru", "phone": "+70236380749"}
0005435315007	5494F9	6892 637362	POLINA SIDOROVA	{"email": "polinasidorova21081968@postgrespro.ru", "phone": "+70368080503"}
0005435315008	E317CC	8447 446837	VALERIY GERASIMOV	{"phone": "+70496058709"}
0005435315009	E317CC	4235 111557	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa-18041971@postgrespro.ru", "phone": "+70758843503"}
0005435315010	1F97F1	8422 591473	EKATERINA GUSEVA	{"phone": "+70773518781"}
0005435315011	1F97F1	2180 706751	OLEG ZHUKOV	{"email": "zhukov_o.111978@postgrespro.ru", "phone": "+70677603144"}
0005435315012	98E116	7127 564031	EDUARD PAVLOV	{"email": "pavlov.eduard-23011967@postgrespro.ru", "phone": "+70393738370"}
0005435315013	F9A6E7	2724 973654	YULIYA MELNIKOVA	{"phone": "+70236071877"}
0005435315014	D7F580	6728 803552	NADEZHDA SOKOLOVA	{"email": "n_sokolova-09031971@postgrespro.ru", "phone": "+70980353443"}
0005435315015	D7F580	1522 193199	VASILIY KONOVALOV	{"phone": "+70715466116"}
0005435315016	145086	7789 968271	ALEKSANDR OSIPOV	{"email": "aleksandrosipov_1962@postgrespro.ru", "phone": "+70848097833"}
0005435315017	145086	1861 474115	SVETLANA ERMAKOVA	{"phone": "+70890430437"}
0005435315018	2E919F	8140 332308	DMITRIY TARASOV	{"phone": "+70783175044"}
0005435315019	D27418	1034 653717	TATYANA NAUMOVA	{"phone": "+70363759984"}
0005435315020	5F93B0	1221 737059	KIRILL ALEKSANDROV	{"phone": "+70550357206"}
0005435315021	B936CF	1014 896682	PAVEL KOZLOV	{"phone": "+70080723880"}
0005435315022	4CD0AB	4890 837065	EVGENIY ZHUKOV	{"email": "zhukovevgeniy07061972@postgrespro.ru", "phone": "+70738951328"}
0005435315023	574C57	9139 080664	EGOR ANDREEV	{"phone": "+70385488461"}
0005435315024	B3DB44	1753 893927	VLADIMIR SCHERBAKOV	{"email": "scherbakov-v.061978@postgrespro.ru", "phone": "+70302086271"}
0005435315025	B3DB44	1277 870174	YANA KUDRYASHOVA	{"phone": "+70990953437"}
0005435315026	859B46	4951 499795	VLADIMIR FILIPPOV	{"email": "v_filippov.081960@postgrespro.ru", "phone": "+70594689885"}
0005435315027	859B46	4900 958314	OLGA SEMENOVA	{"email": "semenovao-1965@postgrespro.ru", "phone": "+70790231329"}
0005435315028	451888	8504 905708	RAISA VOROBEVA	{"phone": "+70417906942"}
0005435315029	451888	2104 131999	MARIYA MARTYNOVA	{"email": "m.martynova16041975@postgrespro.ru", "phone": "+70808081523"}
0005435315030	5F7A5B	6386 866998	NIKOLAY NAZAROV	{"email": "nazarov_n.121963@postgrespro.ru", "phone": "+70487485588"}
0005435315031	5F7A5B	4312 564775	ALEKSANDR KUZNECOV	{"phone": "+70675661419"}
0005435315032	D6DF8B	8256 456450	NADEZHDA EFIMOVA	{"phone": "+70819142835"}
0005435315033	D6DF8B	2923 045659	OLEG ROMANOV	{"phone": "+70427665115"}
0005435315035	7C5D94	3375 360081	EKATERINA KOROLEVA	{"email": "e-koroleva1980@postgrespro.ru", "phone": "+70472632715"}
0005435315036	7C5D94	6287 712985	OLGA OSIPOVA	{"email": "osipova.olga-1967@postgrespro.ru", "phone": "+70237674366"}
0005435315037	7C5D94	6662 423864	VASILIY OSIPOV	{"email": "vosipov-1965@postgrespro.ru", "phone": "+70087492780"}
0005435315038	0ECB7B	0254 131238	ELENA ALEKSANDROVA	{"phone": "+70501366873"}
0005435315039	563B71	6197 545220	IGOR MOROZOV	{"email": "morozov.i1983@postgrespro.ru", "phone": "+70815712491"}
0005435315040	563B71	1476 288644	NIKOLAY GAVRILOV	{"phone": "+70036675153"}
0005435315041	7A4930	8849 345533	ALINA CHERNOVA	{"email": "chernovaalina_1986@postgrespro.ru", "phone": "+70647397061"}
0005435315042	DF6C4F	3830 436443	VLADIMIR NIKITIN	{"phone": "+70796499263"}
0005435315043	37361B	0698 428210	VLADIMIR NIKOLAEV	{"phone": "+70120608632"}
0005435315044	7E35C0	3857 582882	EVGENIY ANTONOV	{"phone": "+70489819296"}
0005435315045	160A9F	7446 168454	KARINA AKIMOVA	{"email": "akimova.k_121976@postgrespro.ru", "phone": "+70788450561"}
0005435315046	160A9F	7405 041857	SERGEY KISELEV	{"phone": "+70627641325"}
0005435315047	94CC05	8523 238996	ERIK EGOROV	{"phone": "+70141893393"}
0005435315048	94CC05	6736 978315	VITALIY ZHURAVLEV	{"phone": "+70148057034"}
0005435315049	747474	5660 970157	YURIY SEMENOV	{"phone": "+70824903617"}
0005435315050	019392	2106 738164	RUSLAN SAVELEV	{"phone": "+70790946056"}
0005435315051	019392	3794 879893	LYUBOV KULIKOVA	{"email": "kulikova.lyubov-051969@postgrespro.ru", "phone": "+70850205657"}
0005435315052	FB614F	1198 948947	ALEKSANDR POPOV	{"email": "popov-a-121972@postgrespro.ru", "phone": "+70294014865"}
0005435315053	F0EC22	1103 517836	YURIY BARANOV	{"email": "yuriybaranov30011962@postgrespro.ru", "phone": "+70133469145"}
0005435315054	5546CB	8802 725513	DMITRIY CHERNOV	{"phone": "+70609014084"}
0005435315055	5546CB	3043 818974	ILDUS SERGEEV	{"email": "ildus.sergeev1976@postgrespro.ru", "phone": "+70084431103"}
0005435315056	1E627F	8725 863447	ANDREY IVANOV	{"phone": "+70981699975"}
0005435315057	D2458D	7132 799381	IGOR ABRAMOV	{"phone": "+70494017421"}
0005435315058	E07402	6282 768127	ELENA BORISOVA	{"email": "elena.borisova.1979@postgrespro.ru", "phone": "+70654258175"}
0005435315059	12737A	2491 201001	MARFA IVANOVA	{"email": "ivanova-marfa_071967@postgrespro.ru", "phone": "+70267288856"}
0005435315060	12737A	2237 015043	SERGEY EGOROV	{"phone": "+70385025205"}
0005435315061	820C45	3231 906935	VALENTIN KULIKOV	{"email": "kulikov.v.041967@postgrespro.ru", "phone": "+70914817823"}
0005435315062	BC12E6	8062 232421	EDUARD ROMANOV	{"email": "eduard_romanov02121973@postgrespro.ru", "phone": "+70215745505"}
0005435315063	D8BEFD	7041 660091	OLEG STEPANOV	{"phone": "+70500941958"}
0005435315064	E65E7F	6511 610565	OLGA ZAYCEVA	{"phone": "+70026627610"}
0005435315065	856726	2564 675556	ALBINA RODIONOVA	{"phone": "+70998242021"}
0005435315066	684BED	4366 171090	OKSANA VOLKOVA	{"email": "oksana_volkova_1976@postgrespro.ru", "phone": "+70129416124"}
0005435315067	B8BFED	0712 349239	MARINA SERGEEVA	{"phone": "+70235588206"}
0005435315068	063545	2945 173971	LYUDMILA KONDRATEVA	{"phone": "+70141578115"}
0005435315069	482D20	3334 186451	EKATERINA OSIPOVA	{"phone": "+70082799926"}
0005435315070	ADBFC2	9696 390150	TATYANA NOVIKOVA	{"email": "novikovatatyana.19031965@postgrespro.ru", "phone": "+70760653096"}
0005435315071	66F2B0	2115 931989	EKATERINA BORISOVA	{"phone": "+70468436972"}
0005435315072	79160A	6764 183782	NATALYA ORLOVA	{"email": "orlova-natalya_1967@postgrespro.ru", "phone": "+70981268997"}
0005435315073	2D0127	5532 323262	ANNA POPOVA	{"email": "popova_anna28081967@postgrespro.ru", "phone": "+70166326382"}
0005435315074	017352	8740 949894	YAN NIKOLAEV	{"phone": "+70270060876"}
0005435315075	F36B3C	2700 016490	YURIY NIKOLAEV	{"phone": "+70096469514"}
0005435315076	B6C244	9355 254973	ALEKSANDR FEDOTOV	{"phone": "+70296328907"}
0005435315077	3A4D02	8712 083842	ALEKSANDR PETROV	{"email": "a_petrov-07031971@postgrespro.ru", "phone": "+70831554206"}
0005435315078	563CE4	0163 105791	GENNADIY IVANOV	{"email": "givanov_051970@postgrespro.ru", "phone": "+70273498978"}
0005435315079	563CE4	3221 347055	EVGENIY VOROBEV	{"phone": "+70054054985"}
0005435315080	41E93C	7259 305457	GALINA TARASOVA	{"phone": "+70333216846"}
0005435315081	A78E66	3404 763304	OLEG MIRONOV	{"email": "olegmironov-1978@postgrespro.ru", "phone": "+70102434962"}
0005435315082	A78E66	6887 078754	SVETLANA ZAYCEVA	{"phone": "+70816384275"}
0005435315083	65DF19	0372 879825	ALEKSANDR VOLKOV	{"email": "avolkov-071960@postgrespro.ru", "phone": "+70170006716"}
0005435315084	BCDB70	4338 488366	EKATERINA LAZAREVA	{"phone": "+70129006071"}
0005435315085	BCDB70	7961 081195	SVETLANA VOROBEVA	{"phone": "+70509052514"}
0005435315086	43A055	1215 762039	EVGENIY VLASOV	{"phone": "+70179494525"}
0005435315087	4DA404	5111 339720	GLEB NIKITIN	{"phone": "+70901714096"}
0005435315088	D82EF7	9688 149687	ANATOLIY SCHERBAKOV	{"email": "anatoliyscherbakov.1976@postgrespro.ru", "phone": "+70358979581"}
0005435315089	106FA9	4054 283845	SERGEY MIRONOV	{"email": "sergeymironov.10051964@postgrespro.ru", "phone": "+70675587666"}
0005435315090	106FA9	7070 192075	LARISA SIDOROVA	{"email": "sidorova_larisa-25011964@postgrespro.ru", "phone": "+70211940768"}
0005435315091	52E19E	9506 611571	NIKOLAY BORISOV	{"email": "borisov_n.22061976@postgrespro.ru", "phone": "+70140494332"}
0005435315092	52E19E	3914 989864	DMITRIY GERASIMOV	{"email": "gerasimov.d.1975@postgrespro.ru", "phone": "+70993311559"}
0005435315093	3CF25E	5865 650780	MARIYA BELOVA	{"phone": "+70707511302"}
0005435315094	FB2029	0544 158927	GEORGIY KARPOV	{"phone": "+70351423945"}
0005435315095	F707CF	7582 075124	IRINA NAUMOVA	{"email": "naumova.irina.081977@postgrespro.ru", "phone": "+70794624539"}
0005435315096	F707CF	9439 520385	MARIYA SOROKINA	{"phone": "+70376464627"}
0005435315097	F707CF	1816 062599	DENIS TARASOV	{"phone": "+70604042861"}
0005435315098	9CA62C	6045 322930	MAKSIM RODIONOV	{"email": "m.rodionov1971@postgrespro.ru", "phone": "+70790433026"}
0005435315099	CAA343	1816 385648	SERGEY PETROV	{"email": "s.petrov121962@postgrespro.ru", "phone": "+70439335824"}
0005435315100	6D01F9	3960 889907	SVETLANA KOROLEVA	{"phone": "+70285111810"}
0005435315101	6D01F9	9021 849659	IVAN KARPOV	{"phone": "+70951525067"}
0005435315102	6D01F9	3455 003199	RENAT MIKHAYLOV	{"phone": "+70956244980"}
0005435315103	A5543C	3623 448357	SVETLANA OSIPOVA	{"email": "svetlana-osipova-1974@postgrespro.ru", "phone": "+70610990017"}
0005435315104	DD85B0	0068 960260	TATYANA IVANOVA	{"phone": "+70369149053"}
0005435315105	DD85B0	3590 532485	ARMEN BORISOV	{"email": "borisovarmen1983@postgrespro.ru", "phone": "+70061179521"}
0005435315106	9FB7E5	9964 181053	KSENIYA PAVLOVA	{"email": "pavlova_k-091971@postgrespro.ru", "phone": "+70845405517"}
0005435315107	C91B88	7463 824831	KONSTANTIN FROLOV	{"phone": "+70462039846"}
0005435315108	C91B88	3380 840653	NIKOLAY VOLKOV	{"email": "nikolayvolkov041975@postgrespro.ru", "phone": "+70476271044"}
0005435315109	6F3681	7587 728922	LARISA NAUMOVA	{"phone": "+70915045351"}
0005435315110	6F3681	3024 220302	KIRILL MARTYNOV	{"phone": "+70586120268"}
0005435315111	55BEAE	7451 095363	ALEKSEY NOVIKOV	{"phone": "+70220490411"}
0005435315112	55BEAE	1994 353337	GALINA NIKOLAEVA	{"phone": "+70152676844"}
0005435315113	82679B	7034 622336	ALEKSANDR SMIRNOV	{"email": "smirnov-a-041969@postgrespro.ru", "phone": "+70922160574"}
0005435315114	82679B	4816 146207	TATYANA PAVLOVA	{"phone": "+70334153860"}
0005435315115	1554CE	6234 975546	SERGEY SMIRNOV	{"email": "s_smirnov_121971@postgrespro.ru", "phone": "+70305786733"}
0005435315116	58EA1C	5424 730157	EVA KOVALEVA	{"email": "eva-kovaleva_05121971@postgrespro.ru", "phone": "+70243618536"}
0005435315117	58EA1C	9984 566288	PETR KULIKOV	{"phone": "+70439952163"}
0005435315118	58EA1C	8977 787106	MAKSIM MAKAROV	{"email": "makarov_maksim-081965@postgrespro.ru", "phone": "+70667446232"}
0005435315119	F3698B	9153 304504	OLGA DAVYDOVA	{"phone": "+70301531000"}
0005435315120	F3698B	3326 890652	OLEG IVANOV	{"email": "ivanov.oleg_1971@postgrespro.ru", "phone": "+70028530552"}
0005435315121	2A276C	5482 590697	GEORGIY IVANOV	{"email": "g.ivanov_041971@postgrespro.ru", "phone": "+70435653086"}
0005435315122	C20FED	6121 764682	MARIYA ANDREEVA	{"email": "mariyaandreeva-1972@postgrespro.ru", "phone": "+70436228575"}
0005435315123	9787F3	6962 250662	ANTON VLASOV	{"email": "vlasov-anton_1970@postgrespro.ru", "phone": "+70706028011"}
0005435315124	9787F3	9527 089188	ANATOLIY FOMIN	{"phone": "+70570177123"}
0005435315125	4BAF5B	9067 754883	ALEKSEY ANDREEV	{"phone": "+70624129720"}
0005435315126	55AE19	1935 866113	SVETLANA DENISOVA	{"phone": "+70647965773"}
0005435315127	55AE19	9358 991301	VIKTOR POPOV	{"email": "viktor-popov061981@postgrespro.ru", "phone": "+70030728605"}
0005435315128	40962C	4137 023754	DARINA KUZMINA	{"phone": "+70473873571"}
0005435315129	A78CB6	1940 331748	IVAN MEDVEDEV	{"phone": "+70253286251"}
0005435315130	42003B	3412 261993	TATYANA YUDINA	{"phone": "+70994642353"}
0005435315131	42003B	7893 810694	DARYA ANDREEVA	{"email": "andreeva.darya-1975@postgrespro.ru", "phone": "+70776666717"}
0005435315132	42003B	6878 899756	SVETLANA KUZMINA	{"phone": "+70850555258"}
0005435315133	FDA8FD	6925 702861	ANDREY POPOV	{"email": "apopov_1963@postgrespro.ru", "phone": "+70033619419"}
0005435315134	B680FA	0650 592936	LYUBOV KOLESNIKOVA	{"email": "lyubov-kolesnikova_09071965@postgrespro.ru", "phone": "+70540347496"}
0005435315135	B680FA	4081 168624	IGOR ZAKHAROV	{"phone": "+70018187695"}
0005435315136	927147	2460 526181	KRISTINA PETROVA	{"email": "kristinapetrova_07041966@postgrespro.ru", "phone": "+70366320079"}
0005435315137	8E06E6	1151 940368	VLADISLAV EGOROV	{"email": "vladislav-egorov101967@postgrespro.ru", "phone": "+70110298145"}
0005435315138	8E06E6	2395 278073	SVETLANA KUZMINA	{"phone": "+70099326753"}
0005435315139	E248BA	8928 657697	ALEKSEY VOLKOV	{"email": "volkov.aleksey_24091976@postgrespro.ru", "phone": "+70857145464"}
0005435315140	711D16	1079 542215	TATYANA GORBUNOVA	{"email": "gorbunova_tatyana16041972@postgrespro.ru", "phone": "+70824653179"}
0005435315141	711D16	4510 881582	GALINA KOZLOVA	{"email": "kozlovag_051969@postgrespro.ru", "phone": "+70055079184"}
0005435315142	C51074	0654 927341	VENERA SOKOLOVA	{"email": "venera.sokolova1963@postgrespro.ru", "phone": "+70818716183"}
0005435315143	C51074	4882 401857	POLINA IVANOVA	{"phone": "+70952034909"}
0005435315144	BECE32	9217 758804	VIKTOR PETROV	{"email": "viktor-petrov_031976@postgrespro.ru", "phone": "+70158956458"}
0005435315145	B6F1DF	3593 272982	SERGEY KISELEV	{"email": "s_kiselev041976@postgrespro.ru", "phone": "+70299899253"}
0005435315146	B6F1DF	7747 793801	EVGENIY PETROV	{"phone": "+70876834898"}
0005435315147	C18AD5	1972 648256	ALINA KOZLOVA	{"email": "a.kozlova_111981@postgrespro.ru", "phone": "+70727424871"}
0005435319423	E3EFD9	7246 611108	ALEKSANDR VLASOV	{"phone": "+70184674188"}
0005435319424	C838CE	1724 072578	VENERA MAKAROVA	{"phone": "+70475273288"}
0005435319425	C838CE	9452 145386	SERGEY ALEKSANDROV	{"email": "saleksandrov_071966@postgrespro.ru", "phone": "+70515931788"}
0005435319426	E94F22	0290 859299	TAMARA NIKITINA	{"phone": "+70705883737"}
0005435319427	AA4DE3	5371 714176	ALLA KULIKOVA	{"phone": "+70887928302"}
0005435319428	EF785A	3702 877841	LYUDMILA KISELEVA	{"email": "l_kiseleva-12091977@postgrespro.ru", "phone": "+70458299309"}
0005435319429	EF785A	5131 086484	EKATERINA NESTEROVA	{"email": "ekaterina_nesterova1971@postgrespro.ru", "phone": "+70924142860"}
0005435319430	5171A3	4650 653585	DENIS FROLOV	{"email": "frolovdenis.23111973@postgrespro.ru", "phone": "+70287056580"}
0005435319431	5171A3	0048 138709	LYUDMILA NIKIFOROVA	{"phone": "+70834698518"}
0005435319432	7DDF4F	0728 094196	DMITRIY MIRONOV	{"phone": "+70628829158"}
0005435319433	B7CB3D	6516 842614	IRINA KARPOVA	{"email": "karpova-i-111958@postgrespro.ru", "phone": "+70983941346"}
0005435319434	B7CB3D	9915 824323	ANATOLIY MAKAROV	{"email": "anatoliy_makarov.011981@postgrespro.ru", "phone": "+70830921835"}
0005435319435	25D023	1526 698898	ANDREY SEMENOV	{"phone": "+70045471271"}
0005435319436	D5D845	8991 619053	ELENA KOLESNIKOVA	{"email": "e-kolesnikova_02101976@postgrespro.ru", "phone": "+70713293983"}
0005435319437	D5D845	6426 092992	LEONID NOVIKOV	{"phone": "+70272027003"}
0005435319438	CA9D21	1054 975251	LYUDMILA ZAKHAROVA	{"phone": "+70701212551"}
0005435319439	F5E016	7065 028779	OLESYA KUZNECOVA	{"email": "olesya.kuznecova081970@postgrespro.ru", "phone": "+70759393874"}
0005435319440	F5E016	9826 103111	ANNA KRASNOVA	{"phone": "+70268275159"}
0005435319441	BDC8D4	6461 496778	PETR CHERNOV	{"phone": "+70195373332"}
0005435319442	5B9CAE	0365 595002	VYACHESLAV GUSEV	{"phone": "+70041243312"}
0005435319443	5B9CAE	6883 948076	ILYA MAKAROV	{"phone": "+70964550695"}
0005435319444	33CB20	7451 890646	ALEKSEY GERASIMOV	{"phone": "+70249135107"}
0005435319445	51C8D8	8971 979244	ALEKSANDR KOZLOV	{"phone": "+70940351359"}
0005435319446	4B0AEB	6927 524821	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev.10111975@postgrespro.ru", "phone": "+70839085829"}
0005435319447	52354A	6312 450801	OLGA TIMOFEEVA	{"phone": "+70782584937"}
0005435319569	923108	8099 439716	VALENTINA DMITRIEVA	{"phone": "+70589823440"}
0005435319448	52354A	4193 887227	VERA KISELEVA	{"email": "kiseleva.vera-031980@postgrespro.ru", "phone": "+70917077387"}
0005435319449	CB56C6	8803 834359	IGOR FEDOROV	{"email": "i.fedorov-1985@postgrespro.ru", "phone": "+70454411837"}
0005435319450	483B13	8880 728427	OLGA TROFIMOVA	{"phone": "+70072593959"}
0005435319451	004EDA	0287 484765	OLGA BORISOVA	{"phone": "+70868512945"}
0005435319452	004EDA	0625 838521	NATALYA KULIKOVA	{"phone": "+70763340573"}
0005435319453	131AA7	3068 321709	LARISA ZAYCEVA	{"email": "larisa-zayceva-011982@postgrespro.ru", "phone": "+70401198936"}
0005435319454	D8C867	5699 702291	VLADIMIR EGOROV	{"email": "vladimiregorov081973@postgrespro.ru", "phone": "+70308920300"}
0005435319455	038D43	6284 281763	TATYANA TARASOVA	{"email": "t.tarasova_1981@postgrespro.ru", "phone": "+70973524199"}
0005435319456	052415	0376 869689	NIKOLAY SHEVCHENKO	{"email": "shevchenkonikolay-101978@postgrespro.ru", "phone": "+70299593468"}
0005435319457	1D4DB5	2901 233303	SVETLANA KUZNECOVA	{"phone": "+70606937652"}
0005435319458	67BDE3	5974 086200	SHAMIL KUZNECOV	{"phone": "+70945295393"}
0005435319459	67BDE3	0077 292176	GENNADIY PAVLOV	{"email": "gennadiy.pavlov.07071965@postgrespro.ru", "phone": "+70476448612"}
0005435319460	436DBD	2342 358695	OLGA MOISEEVA	{"email": "o_moiseeva_081966@postgrespro.ru", "phone": "+70413654062"}
0005435319461	A33D36	0567 343294	OLEG SEMENOV	{"phone": "+70373419181"}
0005435319462	2262DB	7639 692800	NADEZHDA TIKHONOVA	{"phone": "+70506651005"}
0005435319463	377074	4240 548698	NIKITA MELNIKOV	{"phone": "+70159690833"}
0005435319464	377074	7408 675450	NIKOLAY DMITRIEV	{"phone": "+70610446096"}
0005435319465	0E629A	2243 589862	LYUBOV MELNIKOVA	{"email": "melnikoval.101974@postgrespro.ru", "phone": "+70828598398"}
0005435319466	C63FF4	3298 151528	EVGENIY ABRAMOV	{"email": "abramov-evgeniy_1966@postgrespro.ru", "phone": "+70294909845"}
0005435319467	9DC544	7680 349830	IREK POPOV	{"phone": "+70128348432"}
0005435319468	37DCCE	3355 487396	ALEKSANDR FEDOROV	{"email": "a.fedorov.11111982@postgrespro.ru", "phone": "+70751124154"}
0005435319469	F67148	9564 355846	ALEKSEY BONDARENKO	{"email": "aleksey_bondarenko1963@postgrespro.ru", "phone": "+70588440850"}
0005435319470	75DB0F	3910 595199	NIKITA NIKITIN	{"email": "nikita-nikitin_081979@postgrespro.ru", "phone": "+70438084589"}
0005435319471	55368A	7489 623197	NIKITA POPOV	{"phone": "+70667945873"}
0005435319472	784547	6953 084579	EKATERINA ALEKSANDROVA	{"email": "aleksandrova.ekaterina09011971@postgrespro.ru", "phone": "+70270960841"}
0005435319473	784547	8471 750149	BOGDAN MATVEEV	{"email": "matveev_bogdan091984@postgrespro.ru", "phone": "+70959399158"}
0005435319474	232BC9	4316 166267	ELENA ABRAMOVA	{"phone": "+70471721961"}
0005435319475	08B7E6	2942 050815	VALENTINA SERGEEVA	{"phone": "+70305822110"}
0005435319476	26E23D	6571 877794	IGOR NIKOLAEV	{"email": "i_nikolaev-1962@postgrespro.ru", "phone": "+70247919977"}
0005435319477	26E23D	6921 110908	SERGEY GRIGOREV	{"phone": "+70037984439"}
0005435319478	82FFE4	4701 288561	IRINA DMITRIEVA	{"email": "dmitrievairina.01091969@postgrespro.ru", "phone": "+70731201982"}
0005435319479	AE50FB	0478 384842	SERGEY FROLOV	{"phone": "+70272144433"}
0005435319480	AE50FB	9394 656034	ALEKSANDR OSIPOV	{"phone": "+70422083597"}
0005435319481	B29C07	8300 162592	NINA ANDREEVA	{"phone": "+70221893773"}
0005435319482	B5A9E9	4111 889740	ANNA LAZAREVA	{"phone": "+70847798656"}
0005435319483	B5A9E9	5914 625142	DARYA VOROBEVA	{"email": "darya-vorobeva-031964@postgrespro.ru", "phone": "+70686735669"}
0005435319484	FE79D8	7671 525800	DANILA DENISOV	{"phone": "+70318559339"}
0005435319485	019FE5	6587 590615	YULIYA ALEKSANDROVA	{"email": "y-aleksandrova27091960@postgrespro.ru", "phone": "+70306461172"}
0005435319486	019FE5	7278 065467	MARINA MIKHAYLOVA	{"email": "mmikhaylova.21121960@postgrespro.ru", "phone": "+70639612457"}
0005435319487	838A69	9941 715083	NADEZHDA KULIKOVA	{"phone": "+70810897658"}
0005435319488	838A69	5737 442527	VLADISLAV FOMIN	{"phone": "+70080504321"}
0005435319489	821E04	9724 422954	TATYANA LUKYANOVA	{"email": "lukyanova.t111970@postgrespro.ru", "phone": "+70615276865"}
0005435319490	188D07	7592 013816	TATYANA OSIPOVA	{"phone": "+70242385716"}
0005435319491	63B463	6124 173414	ANNA BELOVA	{"email": "a.belova_1977@postgrespro.ru", "phone": "+70837358932"}
0005435319492	63B463	1920 954872	DENIS DENISOV	{"phone": "+70832284157"}
0005435319493	63B463	3131 306622	NADEZHDA DANILOVA	{"phone": "+70843704178"}
0005435319494	5DF2C0	9406 320389	LIDIYA LEBEDEVA	{"phone": "+70105134299"}
0005435319495	25C414	9227 876865	OLGA IVANOVA	{"phone": "+70680605420"}
0005435319496	25C414	4641 410625	LYUBOV GRISHINA	{"phone": "+70526573175"}
0005435319497	7B9C2A	8561 128530	ALEKSANDR TIKHONOV	{"email": "a-tikhonov-091970@postgrespro.ru", "phone": "+70180310317"}
0005435319498	7B9C2A	3747 367470	YULIYA ARKHIPOVA	{"email": "arkhipova-y.111979@postgrespro.ru", "phone": "+70214988504"}
0005435319499	4CD2D6	5589 534134	TATYANA NAZAROVA	{"email": "nazarova.tatyana-10011970@postgrespro.ru", "phone": "+70671688161"}
0005435319500	4CD2D6	7128 716947	NATALYA LEBEDEVA	{"phone": "+70340009846"}
0005435319501	9F7AE8	8496 889985	ZHANNA RODIONOVA	{"email": "rodionova.z_1968@postgrespro.ru", "phone": "+70550650635"}
0005435319502	703A67	0806 062590	VALERIY VOROBEV	{"phone": "+70786639165"}
0005435319503	F8B6EA	3709 073102	DILYARA FILATOVA	{"email": "filatova_dilyara_06101981@postgrespro.ru", "phone": "+70815634373"}
0005435319504	44D0E9	6274 877752	TATYANA VOLKOVA	{"email": "t_volkova101972@postgrespro.ru", "phone": "+70184575976"}
0005435319505	44D0E9	8128 621070	YULIYA RODIONOVA	{"phone": "+70252064118"}
0005435319506	CCE3AF	5483 510986	RUSLAN MOROZOV	{"email": "morozov_r.1978@postgrespro.ru", "phone": "+70428479469"}
0005435319507	D9DB15	0119 089569	MARIYA ANDREEVA	{"phone": "+70965160601"}
0005435319508	F8F0F7	1985 298945	ANGELINA KUZNECOVA	{"email": "kuznecova.angelina-051973@postgrespro.ru", "phone": "+70395067488"}
0005435319509	B817B3	5596 748241	VIKTOR ANDREEV	{"email": "andreevviktor_11041965@postgrespro.ru", "phone": "+70515973471"}
0005435319510	B817B3	1841 297956	SVETLANA NIKITINA	{"phone": "+70090975396"}
0005435319511	D7A130	4323 289751	TAMARA SERGEEVA	{"email": "sergeeva.t-021979@postgrespro.ru", "phone": "+70355454248"}
0005435319512	D7A130	8194 680819	VARVARA POTAPOVA	{"email": "varvara_potapova031970@postgrespro.ru", "phone": "+70001957559"}
0005435319513	1D06D9	0795 560328	MIKHAIL EGOROV	{"phone": "+70498784795"}
0005435319514	5CB1F3	7436 683817	OLGA ROMANOVA	{"phone": "+70572353182"}
0005435319515	A72B66	6216 167643	NATALYA EGOROVA	{"email": "egorova.n-30101970@postgrespro.ru", "phone": "+70734575614"}
0005435319516	4FC140	6052 032100	ALEKSEY SEMENOV	{"email": "semenov_aleksey-18071968@postgrespro.ru", "phone": "+70347398020"}
0005435319517	4FC140	2409 399195	ALEKSANDR KOZLOV	{"email": "a-kozlov20111978@postgrespro.ru", "phone": "+70776509648"}
0005435319518	6C6E14	4591 782380	VALENTINA KUZMINA	{"email": "v_kuzmina_05051969@postgrespro.ru", "phone": "+70170754999"}
0005435319519	989BFE	8288 725536	EVGENIY MATVEEV	{"email": "evgeniymatveev_1980@postgrespro.ru", "phone": "+70483260582"}
0005435319520	9AB2B3	0420 146746	RASIM IVANOV	{"phone": "+70681894290"}
0005435319521	C0CFDC	1802 117668	VYACHESLAV FROLOV	{"email": "vyacheslav_frolov_1949@postgrespro.ru", "phone": "+70939980513"}
0005435319522	C0CFDC	0413 220579	ANNA ERMAKOVA	{"phone": "+70254916409"}
0005435319523	C0CFDC	4454 921368	RAISA KAZAKOVA	{"email": "r_kazakova-08081974@postgrespro.ru", "phone": "+70247972605"}
0005435319524	2DE8EC	4893 011288	ALEKSANDR NAZAROV	{"phone": "+70793832533"}
0005435319525	12CAFD	1316 051974	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin-18081975@postgrespro.ru", "phone": "+70137198720"}
0005435319526	90E313	6441 873303	VASILIY AFANASEV	{"email": "v_afanasev-19021972@postgrespro.ru", "phone": "+70336324256"}
0005435319527	64B0EC	9440 767227	MAKSIM AFANASEV	{"email": "m-afanasev-061973@postgrespro.ru", "phone": "+70634889762"}
0005435319528	AF0BF0	0421 541613	ANTON OSIPOV	{"email": "osipov.anton_1958@postgrespro.ru", "phone": "+70894999963"}
0005435319529	5C3309	7906 685273	NIKOLAY KRASNOV	{"phone": "+70742973926"}
0005435319530	75E64A	2535 155263	NATALYA ZOTOVA	{"phone": "+70481317970"}
0005435319531	75E64A	2281 205808	ALEKSEY MIKHAYLOV	{"email": "mikhaylov_a17071982@postgrespro.ru", "phone": "+70162716591"}
0005435319532	38371B	8303 982993	VLADIMIR TARASOV	{"phone": "+70941124804"}
0005435319533	38371B	5604 268286	IGOR VASILEV	{"email": "ivasilev-041968@postgrespro.ru", "phone": "+70671203871"}
0005435319534	E6CCF5	0368 988905	ALEKSANDR KONOVALOV	{"email": "aleksandrkonovalov-24121973@postgrespro.ru", "phone": "+70608710776"}
0005435319535	E6CCF5	5230 364725	SERGEY OSIPOV	{"phone": "+70805576111"}
0005435319536	9CCF35	0399 162589	LIDIYA VOLKOVA	{"email": "lidiyavolkova-101978@postgrespro.ru", "phone": "+70267197644"}
0005435319537	9CCF35	6070 279457	ILYA ZAYCEV	{"email": "i.zaycev_021982@postgrespro.ru", "phone": "+70334563601"}
0005435319538	25E928	7552 235232	YULIYA FILIPPOVA	{"email": "y_filippova-1973@postgrespro.ru", "phone": "+70470843428"}
0005435319539	25E928	7162 254858	ALEKSEY MOROZOV	{"email": "a.morozov081979@postgrespro.ru", "phone": "+70170565487"}
0005435319540	25E928	7374 369364	VITALIY SOROKIN	{"phone": "+70709826435"}
0005435319541	3EF9A8	4123 446692	PAVEL KUZMIN	{"phone": "+70741793088"}
0005435319542	3EF9A8	0058 657202	IVAN ANTONOV	{"email": "antonov_i-12071976@postgrespro.ru", "phone": "+70301006812"}
0005435319543	FDC9E2	3732 346492	STANISLAV KUZNECOV	{"phone": "+70708215354"}
0005435319544	ABA9B2	3732 108340	DMITRIY KUZNECOV	{"phone": "+70692442280"}
0005435319545	EA17FA	2329 287894	VERA KOROLEVA	{"email": "v_koroleva-021972@postgrespro.ru", "phone": "+70631538093"}
0005435319546	49307B	6627 595487	EVGENIY FOMIN	{"phone": "+70068262877"}
0005435319547	FE35BF	5143 472311	ALEKSANDR DMITRIEV	{"phone": "+70264600659"}
0005435319548	FE35BF	3186 030820	RUSLAN DMITRIEV	{"email": "dmitrievr17101972@postgrespro.ru", "phone": "+70429140394"}
0005435319549	0B358B	8726 998228	DMITRIY ROMANOV	{"phone": "+70282226162"}
0005435319550	CA1B5D	8403 338942	VLADIMIR ANDREEV	{"email": "andreevv-28091976@postgrespro.ru", "phone": "+70426668520"}
0005435319551	874292	4107 073822	OLESYA GORBUNOVA	{"email": "gorbunova.olesya_111969@postgrespro.ru", "phone": "+70250590613"}
0005435319552	874292	5349 370601	MAKSIM SAVELEV	{"phone": "+70591945487"}
0005435319553	00EE44	5230 912532	LEONID ANTONOV	{"phone": "+70483439505"}
0005435319554	00EE44	1792 391468	DENIS KULIKOV	{"phone": "+70031421754"}
0005435319555	00EE44	5615 742158	OKSANA KISELEVA	{"email": "kiseleva.oksana1984@postgrespro.ru", "phone": "+70208316110"}
0005435319556	033537	1941 158964	VENIAMIN MARTYNOV	{"phone": "+70761755322"}
0005435319557	338B11	1002 378503	VALENTINA BELOVA	{"phone": "+70635826709"}
0005435319558	338B11	0236 928974	ALBINA SIDOROVA	{"email": "sidorova_a22121981@postgrespro.ru", "phone": "+70725330519"}
0005435319559	7C4FD7	0799 466331	OLEG ILIN	{"email": "oleg_ilin.30011965@postgrespro.ru", "phone": "+70927673021"}
0005435319560	7C4FD7	1563 170473	VLADIMIR GRIGOREV	{"email": "vladimir_grigorev.071978@postgrespro.ru", "phone": "+70267729236"}
0005435319561	3D7485	4413 042202	EVGENIY IVANOV	{"email": "e_ivanov091976@postgrespro.ru", "phone": "+70636313348"}
0005435319562	3D7485	3987 637502	MARIYA ZOTOVA	{"phone": "+70100099652"}
0005435319563	BE75E7	1895 709167	IVAN MEDVEDEV	{"phone": "+70418624350"}
0005435319564	DCD27C	3595 782326	ALEKSANDR PAVLOV	{"phone": "+70155870542"}
0005435319565	DCD27C	0160 261251	ELENA KONOVALOVA	{"phone": "+70022777304"}
0005435319566	FB67DE	1695 877737	IRINA FILIPPOVA	{"email": "irina-filippova_20121977@postgrespro.ru", "phone": "+70008616363"}
0005435319567	FB67DE	5257 365223	DANILA GAVRILOV	{"phone": "+70348582024"}
0005435319568	E09945	7003 883751	ELENA SERGEEVA	{"email": "sergeevaelena-30121966@postgrespro.ru", "phone": "+70734451660"}
0005435319570	923108	9307 777926	LYUDMILA MARTYNOVA	{"phone": "+70332243855"}
0005435319571	CB2EE8	6275 188202	VALENTINA KISELEVA	{"email": "valentinakiseleva_041984@postgrespro.ru", "phone": "+70654970887"}
0005435319572	49896D	3131 371801	VIKTORIYA VOROBEVA	{"phone": "+70594303701"}
0005435319573	F861BC	8697 222664	OLGA LUKYANOVA	{"email": "lukyanovaolga-011974@postgrespro.ru", "phone": "+70853076484"}
0005435319574	124A94	5405 832545	IRINA POTAPOVA	{"email": "irinapotapova.06071973@postgrespro.ru", "phone": "+70512528319"}
0005435319575	BC18D5	2656 220724	ELENA KAZAKOVA	{"phone": "+70062693238"}
0005435319576	C6BCBF	1980 644960	RAFIK MAKSIMOV	{"phone": "+70504211791"}
0005435319577	C8A72B	9570 849248	OLGA IVANOVA	{"email": "ivanovao_1970@postgrespro.ru", "phone": "+70957444530"}
0005435319578	C8A72B	1652 243762	TATYANA LUKYANOVA	{"email": "lukyanova-t25031957@postgrespro.ru", "phone": "+70684289238"}
0005435319579	80DB65	5584 515043	PAVEL PAVLOV	{"phone": "+70552441452"}
0005435319580	7A6AB9	0347 813898	ALEKSANDR BONDARENKO	{"email": "bondarenko_aleksandr-29031973@postgrespro.ru", "phone": "+70766018166"}
0005435319581	7A6AB9	4199 449421	LIDIYA FILIPPOVA	{"phone": "+70882647345"}
0005435319582	7A6AB9	7878 864260	VLADIMIR ZAYCEV	{"email": "v-zaycev_22121969@postgrespro.ru", "phone": "+70884315853"}
0005435319583	DBBCF1	2492 166121	YURIY NAZAROV	{"phone": "+70679259017"}
0005435319584	DBBCF1	5113 848497	EGOR SOROKIN	{"email": "sorokin_e.031982@postgrespro.ru", "phone": "+70053579309"}
0005435319585	55D039	8633 229896	NIKOLAY DAVYDOV	{"phone": "+70775984248"}
0005435319586	AB32F9	3072 997366	SNEZHANA NESTEROVA	{"email": "s_nesterova.081977@postgrespro.ru", "phone": "+70495281268"}
0005435319587	4021DD	1960 755761	NATALYA AFANASEVA	{"email": "natalyaafanaseva_1984@postgrespro.ru", "phone": "+70099944356"}
0005435319588	4021DD	7783 733610	TATYANA RODIONOVA	{"phone": "+70424621296"}
0005435319589	A5F37A	6115 874715	VLADIMIR KISELEV	{"email": "kiselev_vladimir-30081972@postgrespro.ru", "phone": "+70519562413"}
0005435319590	DBA56B	3608 262008	GALINA KUDRYASHOVA	{"email": "kudryashova-galina.031965@postgrespro.ru", "phone": "+70011643064"}
0005435319591	085107	4943 646483	RAIL ALEKSEEV	{"email": "r_alekseev.101968@postgrespro.ru", "phone": "+70035334286"}
0005435319592	490F0F	1150 912900	LYUBOV KUZNECOVA	{"email": "kuznecoval.051976@postgrespro.ru", "phone": "+70553675273"}
0005435319593	37114C	8237 235277	SVETLANA SOLOVEVA	{"phone": "+70869139413"}
0005435319594	091D80	0453 234472	TATYANA NIKITINA	{"phone": "+70115036402"}
0005435319595	38D2FF	2235 516029	ALEKSANDR ILIN	{"email": "a-ilin.30101968@postgrespro.ru", "phone": "+70857327989"}
0005435319596	4424B7	0246 346082	TATYANA ROMANOVA	{"phone": "+70174916491"}
0005435319597	45B330	1824 303894	VLADIMIR MOROZOV	{"phone": "+70364227793"}
0005435319598	6AF48E	3901 331170	VALENTINA NIKITINA	{"phone": "+70448758246"}
0005435319599	9603D3	9093 654422	VADIM ANTONOV	{"phone": "+70623037843"}
0005435319600	A7E262	5275 997757	VERA ZOTOVA	{"phone": "+70816628915"}
0005435319601	A7E262	8647 587449	NATALYA BELOVA	{"email": "natalya_belova1972@postgrespro.ru", "phone": "+70111883312"}
0005435319602	93571D	0001 969438	ZINAIDA NESTEROVA	{"email": "z_nesterova1972@postgrespro.ru", "phone": "+70302675706"}
0005435319603	E87307	5556 964165	TIMOFEY GRIGOREV	{"phone": "+70440368276"}
0005435319604	66C66A	0841 826758	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1963@postgrespro.ru", "phone": "+70649622798"}
0005435319605	9A61D2	0788 925266	OKSANA KUZMINA	{"phone": "+70070941263"}
0005435319606	E492A3	4475 903281	OLGA ABRAMOVA	{"email": "abramova-olga-1965@postgrespro.ru", "phone": "+70331637141"}
0005435319607	6B534C	8367 352269	MARIYA KUZNECOVA	{"email": "mariyakuznecova_091970@postgrespro.ru", "phone": "+70027627933"}
0005435319608	0F33FF	6459 083793	TIMOFEY NIKOLAEV	{"phone": "+70964949690"}
0005435319609	0F33FF	1033 073052	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l_1974@postgrespro.ru", "phone": "+70127618511"}
0005435319610	8FF764	6014 832198	ELENA MARTYNOVA	{"email": "emartynova.1980@postgrespro.ru", "phone": "+70036234624"}
0005435319611	A619BC	5059 664238	LYUBOV MOROZOVA	{"email": "morozova-lyubov031974@postgrespro.ru", "phone": "+70564680808"}
0005435319612	A619BC	5207 141974	YAROSLAVA PETROVA	{"email": "yaroslava-petrova_101973@postgrespro.ru", "phone": "+70540367705"}
0005435319613	E76A52	2020 907246	ANDREY ANDREEV	{"phone": "+70401536479"}
0005435319614	E76A52	6172 093513	RAISA NOVIKOVA	{"email": "raisanovikova.1965@postgrespro.ru", "phone": "+70741069854"}
0005435319615	21F0F6	9720 395309	SVETLANA ZAYCEVA	{"email": "zayceva_s23071977@postgrespro.ru", "phone": "+70732313707"}
0005435319616	E3A025	9522 147621	KONSTANTIN VASILEV	{"phone": "+70538866752"}
0005435319617	E3A025	9173 509336	ANATOLIY GRIGOREV	{"email": "grigorev.a_02081969@postgrespro.ru", "phone": "+70926522656"}
0005435319618	49E3D6	8901 591698	TAMARA SMIRNOVA	{"email": "t_smirnova_29081976@postgrespro.ru", "phone": "+70741886676"}
0005435319619	960295	4136 973421	VITALIY SEMENOV	{"phone": "+70051510512"}
0005435319620	960295	0455 424494	MARIYA AKIMOVA	{"phone": "+70321721287"}
0005435319621	78D47C	3065 232656	NIKOLAY SEMENOV	{"email": "semenovnikolay.16071981@postgrespro.ru", "phone": "+70364587779"}
0005435319622	269B5D	1560 985234	VLADIMIR SERGEEV	{"phone": "+70899411467"}
0005435319623	DBAD26	5044 628410	VLADIMIR ZAKHAROV	{"email": "vzakharov.01101969@postgrespro.ru", "phone": "+70864334374"}
0005435319624	DBAD26	0422 661028	SERGEY MEDVEDEV	{"email": "medvedev_sergey_17041972@postgrespro.ru", "phone": "+70714430087"}
0005435319625	831354	3485 055250	POLINA VOROBEVA	{"email": "polina-vorobeva_02071974@postgrespro.ru", "phone": "+70129466774"}
0005435319626	A8BABA	7280 072711	YURIY GORBUNOV	{"phone": "+70031942859"}
0005435319627	0C7CF9	0392 904595	DENIS KOROLEV	{"phone": "+70419683148"}
0005435319628	0C7CF9	9857 813365	NATALYA EFIMOVA	{"email": "natalyaefimova-1988@postgrespro.ru", "phone": "+70043007993"}
0005435319629	9C8267	5623 677895	FARIDA DMITRIEVA	{"phone": "+70893432394"}
0005435319630	18674B	0200 743864	VLADIMIR IVANOV	{"phone": "+70681846136"}
0005435319631	3E01FA	9253 807151	SERGEY SERGEEV	{"email": "sergeev-sergey.29031966@postgrespro.ru", "phone": "+70968560170"}
0005435319632	445A33	7043 475670	TATYANA NOVIKOVA	{"phone": "+70872210271"}
0005435319633	445A33	0914 234198	ILYA GAVRILOV	{"email": "gavrilovilya_021968@postgrespro.ru", "phone": "+70075109975"}
0005435319634	445A33	7572 946864	VIKTOR VOROBEV	{"email": "viktor-vorobev25081968@postgrespro.ru", "phone": "+70855120539"}
0005435319635	B71785	0580 080855	ALEKSEY NOVIKOV	{"email": "novikov-aleksey_12051974@postgrespro.ru", "phone": "+70987740140"}
0005435319636	B71785	3194 235521	GULFIYA NOVIKOVA	{"phone": "+70687563683"}
0005435319637	B71785	6127 877941	BORIS FROLOV	{"email": "borisfrolov-061968@postgrespro.ru", "phone": "+70738473946"}
0005435319638	731886	1251 365106	MAKSIM GUSEV	{"phone": "+70020717223"}
0005435319639	3420E7	5826 415807	MARAT GORBUNOV	{"phone": "+70581576760"}
0005435319640	3420E7	7905 059772	OLGA ERMAKOVA	{"email": "olgaermakova22041975@postgrespro.ru", "phone": "+70531082042"}
0005435319641	3420E7	8948 883735	ARTUR VASILEV	{"email": "vasilevartur.1972@postgrespro.ru", "phone": "+70048150587"}
0005435319642	3420E7	5264 151244	SERGEY KUDRYASHOV	{"phone": "+70485340336"}
0005435319643	06069B	9818 194877	LYUBOV KOLESNIKOVA	{"phone": "+70304020732"}
0005435319644	06069B	1341 685150	ALEKSANDR SHEVCHENKO	{"email": "a_shevchenko_061972@postgrespro.ru", "phone": "+70641943445"}
0005435319645	06069B	6189 580859	EVDOKIYA NAZAROVA	{"email": "nazarova.e_1975@postgrespro.ru", "phone": "+70124747552"}
0005435319646	FE93B0	7211 734121	TAMARA NAZAROVA	{"email": "t_nazarova051978@postgrespro.ru", "phone": "+70599303520"}
0005435319647	5CA363	9387 094761	VALENTIN BELOV	{"email": "belov_valentin19011976@postgrespro.ru", "phone": "+70472322565"}
0005435319648	5CA363	7513 524781	LARISA NIKOLAEVA	{"email": "nikolaeva_l1977@postgrespro.ru", "phone": "+70808243570"}
0005435319649	61270B	0455 500920	NATALYA NIKOLAEVA	{"phone": "+70562618840"}
0005435319650	4A4DF8	8277 162163	LYUDMILA VLASOVA	{"email": "vlasova-lyudmila021976@postgrespro.ru", "phone": "+70883225515"}
0005435319651	4A4DF8	2021 132801	KSENIYA ANTONOVA	{"phone": "+70030131059"}
0005435319652	A3042F	4724 761739	ANASTASIYA POPOVA	{"email": "popova.anastasiya_28011973@postgrespro.ru", "phone": "+70476548591"}
0005435319653	43E32B	8234 903946	ANTON STEPANOV	{"phone": "+70404926496"}
0005435319654	7AFF91	1826 550942	DMITRIY BONDARENKO	{"phone": "+70356968169"}
0005435319655	29C0C1	6799 425119	YULIYA KOMAROVA	{"phone": "+70716122584"}
0005435319656	3030D2	7282 665312	OLEG PETROV	{"email": "olegpetrov-06111973@postgrespro.ru", "phone": "+70558586354"}
0005435319657	F834C0	2542 016621	NADEZHDA KUZNECOVA	{"email": "kuznecova.nadezhda.1976@postgrespro.ru", "phone": "+70642323035"}
0005435319658	B0DE8B	1357 367292	SERGEY TIKHONOV	{"email": "tikhonov.sergey-101969@postgrespro.ru", "phone": "+70492058321"}
0005435319659	B0DE8B	5690 297067	GALINA ZAKHAROVA	{"email": "gzakharova071976@postgrespro.ru", "phone": "+70079072905"}
0005435319660	C97A84	1054 058473	ALEKSEY POPOV	{"phone": "+70922226906"}
0005435319661	C97A84	1649 093592	NATALYA FOMINA	{"email": "n-fomina.021967@postgrespro.ru", "phone": "+70622011443"}
0005435319662	F0AF67	7247 199095	KLAVDIYA IVANOVA	{"phone": "+70296995193"}
0005435319663	F0AF67	4910 185439	EVGENIY SMIRNOV	{"phone": "+70849194090"}
0005435319664	10925D	9304 275653	EVGENIY KAZAKOV	{"email": "kazakov_evgeniy.1974@postgrespro.ru", "phone": "+70802840833"}
0005435319665	A05919	2723 638932	OLGA IVANOVA	{"email": "olga_ivanova1970@postgrespro.ru", "phone": "+70957960210"}
0005435319666	D418D8	9509 305570	NADEZHDA STEPANOVA	{"email": "n.stepanova_1972@postgrespro.ru", "phone": "+70372351516"}
0005435319667	D418D8	7347 011124	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov_1972@postgrespro.ru", "phone": "+70739521263"}
0005435319668	0DC1EA	7785 150418	VLADIMIR ALEKSEEV	{"email": "alekseevvladimir16081968@postgrespro.ru", "phone": "+70191376818"}
0005435319669	39F5E5	9150 718132	VALENTINA KUZNECOVA	{"email": "v.kuznecova021971@postgrespro.ru", "phone": "+70984887268"}
0005435319670	39F5E5	2242 544150	YULIYA FADEEVA	{"email": "fadeeva.y_01101979@postgrespro.ru", "phone": "+70765926096"}
0005435319671	05A682	8614 991580	VALENTINA KISELEVA	{"phone": "+70077142541"}
0005435319672	05A682	4022 548073	OLGA EFIMOVA	{"phone": "+70326817709"}
0005435319673	AC1C46	6913 141935	ALEKSEY MAKAROV	{"email": "makarov.aleksey-101978@postgrespro.ru", "phone": "+70413804980"}
0005435319674	D9E895	0640 593544	SVETLANA SOLOVEVA	{"email": "s-soloveva.13021966@postgrespro.ru", "phone": "+70519241400"}
0005435319675	860124	0405 602622	TATYANA PETROVA	{"phone": "+70576609107"}
0005435319676	186333	1511 489565	NADEZHDA ZHUKOVA	{"phone": "+70477005143"}
0005435319677	2929D4	5941 378335	NINA SOKOLOVA	{"phone": "+70582035186"}
0005435319678	BC6C39	4573 617381	ANASTASIYA PAVLOVA	{"phone": "+70124514843"}
0005435319679	B2EE4D	0251 853995	ALEKSANDR ALEKSEEV	{"phone": "+70441280373"}
0005435319680	D80A95	1426 207211	DMITRIY SEMENOV	{"email": "dmitriy.semenov-041962@postgrespro.ru", "phone": "+70182224455"}
0005435319681	CB41F3	8940 649449	ALEKSANDR ZAKHAROV	{"phone": "+70905971094"}
0005435319682	CB41F3	1355 203398	MIKHAIL KUZNECOV	{"phone": "+70224848392"}
0005435319683	320A9D	7678 443567	DMITRIY SMIRNOV	{"email": "smirnov_dmitriy_01111968@postgrespro.ru", "phone": "+70312146587"}
0005435319684	CFEAE2	6342 074822	IRINA TIKHONOVA	{"phone": "+70586257745"}
0005435319685	544080	1603 379168	VITALIY ZAYCEV	{"phone": "+70708177432"}
0005435319686	B84998	9393 527357	VSEVOLOD ZHURAVLEV	{"phone": "+70595593665"}
0005435319687	B84998	4447 165687	NATALYA VOLKOVA	{"email": "natalya_volkova-061962@postgrespro.ru", "phone": "+70404464981"}
0005435319688	FAA64A	7137 184862	MIKHAIL KUZMIN	{"phone": "+70050313248"}
0005435319689	6C5F2A	5488 041409	TATYANA ANDREEVA	{"phone": "+70263686627"}
0005435319690	6C5F2A	1523 969135	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.1982@postgrespro.ru", "phone": "+70434197730"}
0005435319691	793E30	1141 014052	OLGA NAUMOVA	{"phone": "+70240237850"}
0005435319692	6C3240	8452 385219	IRINA DAVYDOVA	{"email": "idavydova-011969@postgrespro.ru", "phone": "+70772911517"}
0005435319693	28E195	4971 728649	ANDREY FEDOROV	{"email": "afedorov25111980@postgrespro.ru", "phone": "+70608047240"}
0005435319694	859199	1963 877632	VYACHESLAV POPOV	{"email": "vyacheslav_popov.1966@postgrespro.ru", "phone": "+70030821413"}
0005435319695	859199	7652 295148	VALENTINA KUZNECOVA	{"email": "valentina_kuznecova.1966@postgrespro.ru", "phone": "+70793632721"}
0005435319696	7B9274	4996 041184	DMITRIY ANTONOV	{"phone": "+70846365359"}
0005435319697	7A03F7	8514 120888	DARYA DMITRIEVA	{"email": "dmitrieva.d.1977@postgrespro.ru", "phone": "+70943416411"}
0005435319698	EFBF05	2754 667825	OLGA STEPANOVA	{"phone": "+70257916759"}
0005435319699	9E8E99	3924 579653	IVAN VLASOV	{"email": "i.vlasov_28031976@postgrespro.ru", "phone": "+70116592989"}
0005435319700	94C226	4618 973803	SERGEY VASILEV	{"phone": "+70830126467"}
0005435319701	B7F0AB	7467 193885	VYACHESLAV KULIKOV	{"email": "kulikov-vyacheslav.08061966@postgrespro.ru", "phone": "+70059705685"}
0005435319702	D6ABB4	2409 287013	MARINA VOROBEVA	{"phone": "+70441625540"}
0005435319703	1DF6BD	3580 338372	ALEVTINA ALEKSEEVA	{"email": "alekseeva.a17071968@postgrespro.ru", "phone": "+70140378864"}
0005435319704	6B5C29	1353 126721	OKSANA MAKAROVA	{"email": "omakarova_101961@postgrespro.ru", "phone": "+70833986497"}
0005435319705	6B5C29	3867 017712	GALINA SAVELEVA	{"email": "galina_saveleva.08091964@postgrespro.ru", "phone": "+70657854536"}
0005435319706	39F3E5	2769 338050	ANDREY IVANOV	{"email": "ivanov.andrey_011980@postgrespro.ru", "phone": "+70281487683"}
0005435319707	61E596	0349 424180	VLADIMIR ZAKHAROV	{"email": "zakharov-vladimir1983@postgrespro.ru", "phone": "+70350410577"}
0005435319708	58E76D	2804 248304	MIKHAIL VLASOV	{"phone": "+70977394551"}
0005435319709	58E76D	2423 132997	ANASTASIYA MAKAROVA	{"email": "makarova.anastasiya.02081963@postgrespro.ru", "phone": "+70092458159"}
0005435319710	A542E1	4898 231934	MARIYA YAKOVLEVA	{"email": "m-yakovleva-021970@postgrespro.ru", "phone": "+70497326136"}
0005435319711	A542E1	2980 437861	MAKSIM ISAEV	{"phone": "+70156053130"}
0005435319712	F838B5	8540 387505	TAMARA SCHERBAKOVA	{"email": "scherbakova_t-1979@postgrespro.ru", "phone": "+70863302412"}
0005435319713	F838B5	4849 637879	VALENTINA TIKHONOVA	{"email": "v.tikhonova-1978@postgrespro.ru", "phone": "+70722238665"}
0005435319714	C429AD	7281 531248	NATALYA KULIKOVA	{"phone": "+70676596503"}
0005435319715	755D62	4008 767581	DMITRIY VOLKOV	{"email": "volkov.dmitriy_02101975@postgrespro.ru", "phone": "+70539696019"}
0005435319716	423909	0062 583883	ALEKSEY PETROV	{"phone": "+70151851713"}
0005435319717	423909	9102 607042	KIRILL EGOROV	{"phone": "+70686831578"}
0005435319718	18BC93	4086 918751	KIRA POPOVA	{"phone": "+70978414768"}
0005435319719	18BC93	3541 989008	NINA BOGDANOVA	{"phone": "+70986276580"}
0005435319720	18BC93	2086 175142	TATYANA NAZAROVA	{"email": "nazarovat-071960@postgrespro.ru", "phone": "+70266478708"}
0005435319721	5A7AEC	0986 899370	ALEKSEY STEPANOV	{"email": "stepanova_111977@postgrespro.ru", "phone": "+70812658274"}
0005435319722	5A7AEC	5648 998432	PELAGEYA POPOVA	{"email": "popova-pelageya.1971@postgrespro.ru", "phone": "+70783102880"}
0005435319723	CCDBC7	5289 733079	VLADIMIR KONOVALOV	{"phone": "+70636063939"}
0005435319724	CCDBC7	5741 523227	GALINA NOVIKOVA	{"phone": "+70251965860"}
0005435319725	6592E0	8071 326238	STEPAN KULIKOV	{"phone": "+70038757364"}
0005435319726	DDFEB2	4094 352732	ELENA NIKITINA	{"email": "nikitinaelena_1982@postgrespro.ru", "phone": "+70844274637"}
0005435319727	6E2325	1539 147198	VLADIMIR ORLOV	{"email": "orlov.vladimir.28051971@postgrespro.ru", "phone": "+70833046251"}
0005435319728	6E2325	0884 140793	LYUBOV SERGEEVA	{"email": "sergeeva_lyubov-1973@postgrespro.ru", "phone": "+70732028045"}
0005435319729	E62BA0	6596 442569	NATALYA KOROLEVA	{"email": "korolevan-081970@postgrespro.ru", "phone": "+70286541623"}
0005435319730	E62BA0	6956 899948	ASIYA SIDOROVA	{"phone": "+70341112869"}
0005435319731	45FC77	3101 939655	SERGEY SOKOLOV	{"email": "sokolov_sergey-081975@postgrespro.ru", "phone": "+70580209344"}
0005435319732	9A3993	2084 668461	VARVARA NESTEROVA	{"phone": "+70111991276"}
0005435319733	DE1AB5	4411 131270	VIKTORIYA ALEKSEEVA	{"email": "alekseeva-v-15111981@postgrespro.ru", "phone": "+70631914845"}
0005435319734	14174D	5718 982727	ELENA SMIRNOVA	{"phone": "+70691880680"}
0005435319735	14174D	1289 431743	TATYANA ANDREEVA	{"phone": "+70982856290"}
0005435319736	14174D	6439 178516	ROMAN GERASIMOV	{"email": "gerasimov-roman_19011971@postgrespro.ru", "phone": "+70466429226"}
0005435319737	2FA041	9926 288284	DENIS PETROV	{"email": "d_petrov06091965@postgrespro.ru", "phone": "+70840155210"}
0005435319738	ADE018	0899 864333	ALEKSANDR POPOV	{"email": "popov-a21061983@postgrespro.ru", "phone": "+70446261111"}
0005435319739	33F567	7233 743814	ALEKSEY DENISOV	{"email": "alekseydenisov-091976@postgrespro.ru", "phone": "+70766993186"}
0005435319740	40A49A	8068 892754	ALLA DANILOVA	{"phone": "+70097717349"}
0005435319741	B73620	8908 884664	YULIYA KOVALEVA	{"phone": "+70188268293"}
0005435319742	B73620	6537 745913	NIKOLAY KUZMIN	{"phone": "+70254185135"}
0005435319743	EE867A	0835 803529	NIKOLAY KULIKOV	{"email": "nikolaykulikov.1976@postgrespro.ru", "phone": "+70997459271"}
0005435319744	D757A8	6420 922636	ALBERT MAKSIMOV	{"phone": "+70376741659"}
0005435319745	D55C3A	1425 151952	ALEKSANDR KUZNECOV	{"phone": "+70374102195"}
0005435319746	FDB1EC	5560 470771	EVGENIY KUZNECOV	{"email": "kuznecov_evgeniy.18011979@postgrespro.ru", "phone": "+70452898019"}
0005435319747	FDB1EC	8501 390981	ELENA STEPANOVA	{"email": "estepanova_071967@postgrespro.ru", "phone": "+70652057995"}
0005435319748	FDB1EC	2014 578302	NINA PETROVA	{"phone": "+70029247345"}
0005435319749	2AFB49	2507 007020	IRINA TARASOVA	{"email": "tarasova_irina-29061963@postgrespro.ru", "phone": "+70678953533"}
0005435319750	9BFE25	9534 412247	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev1964@postgrespro.ru", "phone": "+70838241951"}
0005435319751	4178E2	9837 987529	ELENA TROFIMOVA	{"email": "e.trofimova.031974@postgrespro.ru", "phone": "+70215753830"}
0005435319752	4178E2	0620 547272	ALEKSANDR VOROBEV	{"phone": "+70598336560"}
0005435319753	5FDE15	7851 131465	VIKTOR NOVIKOV	{"phone": "+70834249969"}
0005435319754	CEC6B8	8709 988537	VLADIMIR FILIPPOV	{"email": "vladimirfilippov.14011969@postgrespro.ru", "phone": "+70549226326"}
0005435319755	C0A0EA	0098 038069	GALINA VASILEVA	{"email": "vasileva-g26111963@postgrespro.ru", "phone": "+70694191554"}
0005435319756	C0A0EA	1521 837528	VALENTINA MAKSIMOVA	{"email": "valentina.maksimova_20081958@postgrespro.ru", "phone": "+70669128353"}
0005435319757	515872	4462 035407	OLGA ERMAKOVA	{"phone": "+70025253244"}
0005435319758	70D0B6	6542 498244	DMITRIY BARANOV	{"phone": "+70015369513"}
0005435319759	6695B5	8444 312616	OKSANA IVANOVA	{"phone": "+70517044767"}
0005435319760	C5994C	1560 784470	MIKHAIL BONDARENKO	{"phone": "+70228863464"}
0005435319761	C5994C	8136 987068	GALINA GAVRILOVA	{"phone": "+70712927974"}
0005435319762	165F1D	0014 353711	ALEKSANDR KUZMIN	{"email": "kuzmin.a16031974@postgrespro.ru", "phone": "+70338146912"}
0005435319763	F6E630	8725 808019	ALINA CHERNOVA	{"email": "chernova_alina.121967@postgrespro.ru", "phone": "+70636841121"}
0005435319764	F6E630	7597 372267	DMITRIY KUZNECOV	{"phone": "+70379638699"}
0005435319765	E462BA	5928 383926	YULIYA SEMENOVA	{"phone": "+70293578616"}
0005435319766	E462BA	3449 114248	PRASKOVYA EGOROVA	{"phone": "+70492240074"}
0005435319767	782C8B	7085 905290	ANNA MOROZOVA	{"phone": "+70149044779"}
0005435319768	782C8B	7851 657126	IGOR OSIPOV	{"phone": "+70169179324"}
0005435319769	782C8B	7676 358041	MIKHAIL SERGEEV	{"phone": "+70825610758"}
0005435319770	A567AF	0576 150858	NATALYA BELOVA	{"email": "natalya-belova1968@postgrespro.ru", "phone": "+70042460105"}
0005435319771	1FCDBC	8410 740624	SVETLANA ANTONOVA	{"email": "svetlanaantonova-1969@postgrespro.ru", "phone": "+70760408041"}
0005435319772	1FCDBC	1535 782490	LYUBOV PETROVA	{"phone": "+70724088207"}
0005435319773	A38D96	8478 588944	NADEZHDA DMITRIEVA	{"phone": "+70443006056"}
0005435319774	B5E87C	7724 585466	ANNA SOROKINA	{"email": "asorokina-091978@postgrespro.ru", "phone": "+70665854708"}
0005435319775	CA742F	8371 855293	NADEZHDA VOROBEVA	{"email": "vorobevan-1981@postgrespro.ru", "phone": "+70559093819"}
0005435319776	A4D037	1280 976953	ELENA DENISOVA	{"phone": "+70036620931"}
0005435319777	3838A7	2776 344992	ANASTASIYA TROFIMOVA	{"email": "trofimovaa1966@postgrespro.ru", "phone": "+70216734609"}
0005435319778	3838A7	5919 986396	ALEKSANDR VOLKOV	{"phone": "+70531812791"}
0005435319779	6463A7	5645 109833	ANDREY GORBUNOV	{"phone": "+70762300793"}
0005435319780	6463A7	3840 045515	VALENTINA ANDREEVA	{"phone": "+70156619778"}
0005435319781	DE5464	0306 362714	ALEKSANDR MAKSIMOV	{"email": "aleksandr_maksimov_1974@postgrespro.ru", "phone": "+70109287490"}
0005435319782	DE5464	6917 869475	RADIK TIMOFEEV	{"phone": "+70481889860"}
0005435319783	112518	4941 551129	VLADIMIR VLASOV	{"phone": "+70627896949"}
0005435319784	A51107	0685 631758	ANNA TIKHONOVA	{"phone": "+70332266745"}
0005435319785	A51107	9850 450086	VERA NAZAROVA	{"email": "nazarova_v.1977@postgrespro.ru", "phone": "+70410903675"}
0005435319786	14BD73	9572 214050	MARIYA AFANASEVA	{"email": "mafanaseva_1980@postgrespro.ru", "phone": "+70266725049"}
0005435319787	091CCF	4225 227640	LYUDMILA ZAKHAROVA	{"phone": "+70823149273"}
0005435319788	091CCF	8960 023771	MARIYA PETROVA	{"phone": "+70987860271"}
0005435319789	D56510	1513 897319	KSENIYA TARASOVA	{"email": "tarasova.kseniya.1973@postgrespro.ru", "phone": "+70837976367"}
0005435319790	D56510	3746 677062	NADEZHDA MARTYNOVA	{"email": "nadezhda_martynova_1972@postgrespro.ru", "phone": "+70219226526"}
0005435319791	F975DB	3742 630658	VLADIMIR ROMANOV	{"email": "vladimirromanov.26061971@postgrespro.ru", "phone": "+70475889012"}
0005435319792	C9903E	6535 401373	ANATOLIY ANDREEV	{"email": "anatoliyandreev_06041968@postgrespro.ru", "phone": "+70026098786"}
0005435319793	937321	5034 206613	MARIYA POPOVA	{"email": "mariyapopova031958@postgrespro.ru", "phone": "+70830871766"}
0005435319794	7AC4A6	5849 271492	SVETLANA NESTEROVA	{"phone": "+70983464776"}
0005435319795	7AC4A6	4600 060514	VADIM VASILEV	{"email": "vasilev_vadim021962@postgrespro.ru", "phone": "+70143799707"}
0005435319796	E020C7	1924 869820	IVAN TIMOFEEV	{"email": "i.timofeev021967@postgrespro.ru", "phone": "+70493870131"}
0005435319797	0DEECD	7316 657647	ELENA KOROLEVA	{"phone": "+70190724775"}
0005435319798	1235FA	5574 219925	DARYA KOVALEVA	{"phone": "+70187634336"}
0005435319799	5CB338	3923 976596	ALEKSANDR NAZAROV	{"phone": "+70741086374"}
0005435319800	F74A05	0039 514085	ANATOLIY SCHERBAKOV	{"email": "anatoliy.scherbakov.061963@postgrespro.ru", "phone": "+70305243587"}
0005435319801	F74A05	0255 588967	EKATERINA TROFIMOVA	{"email": "e-trofimova.18111987@postgrespro.ru", "phone": "+70806224487"}
0005435319802	673CD7	1032 706981	SERGEY ROMANOV	{"phone": "+70701285582"}
0005435319803	CDFF8F	6296 183415	VLADIMIR ROMANOV	{"email": "v_romanov1974@postgrespro.ru", "phone": "+70790321078"}
0005435319804	0F31EE	1888 869059	YURIY KUDRYASHOV	{"email": "y-kudryashov.011970@postgrespro.ru", "phone": "+70226355130"}
0005435319805	0F31EE	0243 555551	OLGA IVANOVA	{"phone": "+70926478937"}
0005435319806	BF0DB9	9753 299636	ALEKSEY VASILEV	{"phone": "+70384529473"}
0005435319807	BF0DB9	8041 245875	FLYURA POPOVA	{"email": "flyura.popova.021978@postgrespro.ru", "phone": "+70965944691"}
0005435319808	BF0DB9	3563 719015	VASILIY IVANOV	{"email": "ivanov.vasiliy.1967@postgrespro.ru", "phone": "+70261092283"}
0005435319809	35EC48	7889 621845	NATALIYA DENISOVA	{"phone": "+70809640359"}
0005435319810	0451D9	7689 539280	ALEKSANDR FEDOROV	{"email": "fedorov_aleksandr-111965@postgrespro.ru", "phone": "+70979924722"}
0005435319811	0451D9	5071 566630	ANNA POPOVA	{"email": "popova.a-29061969@postgrespro.ru", "phone": "+70357406382"}
0005435319812	225D11	2958 390694	ELENA SMIRNOVA	{"email": "smirnova.e.061970@postgrespro.ru", "phone": "+70136703773"}
0005435319813	225D11	7160 366826	ROMAN MEDVEDEV	{"phone": "+70466878438"}
0005435319814	15CDA7	8439 943438	EDUARD SCHERBAKOV	{"phone": "+70803586950"}
0005435319815	15CDA7	2247 838315	ALEKSANDR MELNIKOV	{"phone": "+70339976818"}
0005435319816	15CDA7	9566 278344	ZINAIDA ZHUKOVA	{"phone": "+70566285245"}
0005435319817	273E0E	0197 054831	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova-t_071973@postgrespro.ru", "phone": "+70791303643"}
0005435319818	AFA746	3840 518305	DARYA DANILOVA	{"phone": "+70246612284"}
0005435319819	FE0058	5210 518017	OLGA ZHURAVLEVA	{"email": "olga_zhuravleva.1967@postgrespro.ru", "phone": "+70443002324"}
0005435319820	9E665D	8831 200533	NINA FEDOROVA	{"email": "n_fedorova121978@postgrespro.ru", "phone": "+70976195291"}
0005435319821	0E3B23	4341 360805	RADIK VLASOV	{"phone": "+70834737411"}
0005435319822	B198A0	4042 355268	NIKOLAY DMITRIEV	{"email": "n-dmitriev.091969@postgrespro.ru", "phone": "+70168140574"}
0005435319823	F77726	0423 638091	SVETLANA KOMAROVA	{"phone": "+70503213798"}
0005435319824	F77726	2803 928693	VIKTOR NIKITIN	{"phone": "+70530373652"}
0005435319825	FB46DC	0191 760640	ELENA ALEKSANDROVA	{"email": "elena-aleksandrova_1972@postgrespro.ru", "phone": "+70294230374"}
0005435319826	F39211	2440 810953	VALENTINA MOROZOVA	{"phone": "+70202628215"}
0005435319827	299417	5523 430591	YURIY FOMIN	{"email": "yfomin-051980@postgrespro.ru", "phone": "+70050354989"}
0005435319828	83C81E	4681 131056	TATYANA FROLOVA	{"phone": "+70391168583"}
0005435319829	5DD044	1373 414418	ANNA SERGEEVA	{"email": "annasergeeva-05041968@postgrespro.ru", "phone": "+70222535956"}
0005435326497	B0F3B6	3366 993730	YURIY SOLOVEV	{"email": "solovevy.021974@postgrespro.ru", "phone": "+70238974755"}
0005435326498	999898	3300 350868	OLGA DAVYDOVA	{"phone": "+70458528903"}
0005435326499	FD013E	4833 012781	ALEKSEY KISELEV	{"phone": "+70149948945"}
0005435326500	BC26F7	8773 775347	OLGA SOLOVEVA	{"phone": "+70109785943"}
0005435326501	BC26F7	7135 142498	KLAVDIYA PAVLOVA	{"email": "klavdiya-pavlova-1976@postgrespro.ru", "phone": "+70815856063"}
0005435326502	BC26F7	4029 300175	TATYANA TIMOFEEVA	{"phone": "+70924640120"}
0005435326503	ED7D62	1865 257864	ANNA NESTEROVA	{"phone": "+70931615267"}
0005435326504	ED7D62	9531 057757	VLADIMIR KISELEV	{"phone": "+70812402680"}
0005435326505	CF2226	9217 939402	OLGA FILIPPOVA	{"email": "o.filippova_081969@postgrespro.ru", "phone": "+70537915964"}
0005435326506	BB1B66	8047 436485	OLGA MOROZOVA	{"email": "olga.morozova.1970@postgrespro.ru", "phone": "+70559199533"}
0005435326507	BB1B66	9942 711560	KLAVDIYA ILINA	{"email": "klavdiya_ilina.1958@postgrespro.ru", "phone": "+70606303106"}
0005435326508	C9278E	9981 533641	VLADIMIR FEDOTOV	{"phone": "+70227110059"}
0005435326509	CDBD3A	8413 516407	GALINA FEDOROVA	{"phone": "+70496628618"}
0005435326510	F99582	8126 927857	TAMARA EGOROVA	{"phone": "+70737542207"}
0005435326511	F99582	5379 995107	OLEG ZAKHAROV	{"phone": "+70995556781"}
0005435326512	DAEBEE	6635 926157	OLGA TROFIMOVA	{"phone": "+70083237888"}
0005435326513	09A785	2530 605823	SERGEY SOROKIN	{"email": "sergey-sorokin-041973@postgrespro.ru", "phone": "+70796162938"}
0005435326514	09A785	5490 379438	ALEKSANDR MATVEEV	{"phone": "+70933566448"}
0005435326515	51D548	6057 308610	GENNADIY TARASOV	{"phone": "+70346687247"}
0005435326516	51D548	6662 287947	LYUBOV BORISOVA	{"email": "borisova_lyubov011973@postgrespro.ru", "phone": "+70705699826"}
0005435326517	51D548	4166 964978	KSENIYA BARANOVA	{"email": "kseniyabaranova.29071977@postgrespro.ru", "phone": "+70576899210"}
0005435326518	A8F957	7761 485150	DMITRIY ZAKHAROV	{"phone": "+70783546104"}
0005435326519	B927FB	3083 246955	VERA FILATOVA	{"phone": "+70044154451"}
0005435326520	B927FB	8301 175057	EVGENIY TARASOV	{"email": "evgeniy_tarasov011975@postgrespro.ru", "phone": "+70382009682"}
0005435326521	A06F05	9099 878539	VERONIKA VASILEVA	{"email": "vasilevav_011972@postgrespro.ru", "phone": "+70462036636"}
0005435326522	728EBE	1251 784040	ELENA KUZNECOVA	{"email": "elenakuznecova.011976@postgrespro.ru", "phone": "+70557585698"}
0005435326523	0B8988	4985 064105	VERA ORLOVA	{"phone": "+70157572508"}
0005435326524	0B8988	9956 560983	MARINA MALYSHEVA	{"email": "marina-malysheva_1966@postgrespro.ru", "phone": "+70616773595"}
0005435326525	F50FD2	4810 266422	MIKHAIL FOMIN	{"email": "mfomin.13091974@postgrespro.ru", "phone": "+70977316196"}
0005435326526	F50FD2	3838 359492	VIKTORIYA BORISOVA	{"phone": "+70368231819"}
0005435326527	9D0CF6	6631 312184	GALINA ALEKSEEVA	{"phone": "+70552554950"}
0005435326528	91A688	3151 266591	MARINA SIDOROVA	{"phone": "+70315695158"}
0005435326529	9DBC1A	4729 912544	ANATOLIY STEPANOV	{"email": "stepanov-anatoliy.03091972@postgrespro.ru", "phone": "+70527512160"}
0005435326530	235493	1162 694302	DMITRIY VASILEV	{"email": "vasilev.dmitriy.041968@postgrespro.ru", "phone": "+70259464684"}
0005435326531	235493	4611 629176	PAVEL ZAYCEV	{"phone": "+70485109134"}
0005435326532	CB2B39	6671 878637	VLADIMIR VLASOV	{"phone": "+70198253054"}
0005435326533	85D093	3400 864925	GALINA EGOROVA	{"phone": "+70441866832"}
0005435326534	85D093	8381 061471	MARINA AFANASEVA	{"phone": "+70608246581"}
0005435326535	D6CDD9	5773 287213	MILANA SMIRNOVA	{"email": "milanasmirnova_071976@postgrespro.ru", "phone": "+70622308273"}
0005435326536	0B9EF1	1304 110348	ILSHAT KOZLOV	{"email": "kozlov.ilshat28061972@postgrespro.ru", "phone": "+70780805220"}
0005435326537	7F5596	8021 507899	EKATERINA YAKOVLEVA	{"email": "yakovlevaekaterina-091965@postgrespro.ru", "phone": "+70390796918"}
0005435326538	7F5596	7610 129479	ELIZAVETA NIKITINA	{"phone": "+70999538208"}
0005435326539	CD430A	3884 314545	EVGENIYA MIRONOVA	{"email": "e.mironova_111970@postgrespro.ru", "phone": "+70149345877"}
0005435326540	CD430A	0214 987948	ROMAN KAZAKOV	{"email": "kazakov.roman10051978@postgrespro.ru", "phone": "+70776094442"}
0005435326541	E45181	0239 083061	NATALYA BELYAEVA	{"email": "belyaeva_n.30031960@postgrespro.ru", "phone": "+70699577293"}
0005435326542	DF9FE9	3983 379851	ELIZAVETA KOZLOVA	{"phone": "+70359502102"}
0005435326543	3791BD	9372 479160	MIKHAIL VOROBEV	{"email": "vorobev_mikhail.1972@postgrespro.ru", "phone": "+70525393926"}
0005435326544	3791BD	0607 066706	DMITRIY MOROZOV	{"phone": "+70113984262"}
0005435326545	484C59	9715 598513	VIKTOR KUZNECOV	{"phone": "+70880674406"}
0005435326546	484C59	3505 644381	ALENA SOKOLOVA	{"phone": "+70621716355"}
0005435326547	FE2278	2132 450766	MARIYA NAUMOVA	{"phone": "+70656400830"}
0005435326548	FE2278	3337 032466	IRINA POLYAKOVA	{"email": "polyakovai_19111960@postgrespro.ru", "phone": "+70911880194"}
0005435326549	D57BBA	2915 245948	NATALIYA KUZMINA	{"phone": "+70094110550"}
0005435326550	512530	2858 945071	ALEKSANDR FEDOROV	{"phone": "+70822559049"}
0005435326551	CBF0CB	4207 814577	SVETLANA ANDREEVA	{"email": "sandreeva_1969@postgrespro.ru", "phone": "+70835839176"}
0005435326552	CBF0CB	2034 365801	VALENTINA MARTYNOVA	{"phone": "+70682407686"}
0005435326553	6C8B42	4151 807891	ZOYA KUDRYASHOVA	{"email": "kudryashova-z18011968@postgrespro.ru", "phone": "+70605785657"}
0005435326554	36D6DE	0832 551436	ANTONINA EGOROVA	{"phone": "+70328836659"}
0005435326555	D2C5FC	7969 470676	YURIY NIKITIN	{"phone": "+70032966611"}
0005435326556	E12427	5259 158553	MAKSIM PETROV	{"email": "petrovmaksim.081962@postgrespro.ru", "phone": "+70275275154"}
0005435326557	5D0BB5	7307 938843	NADEZHDA BORISOVA	{"phone": "+70640389399"}
0005435326558	5D0BB5	5973 645060	PAVEL KULIKOV	{"email": "pkulikov12021977@postgrespro.ru", "phone": "+70111647093"}
0005435326559	A00E6B	3358 616354	DMITRIY SOKOLOV	{"email": "sokolovdmitriy_1964@postgrespro.ru", "phone": "+70458264082"}
0005435326560	FB145E	6662 101320	OLGA KONDRATEVA	{"email": "kondratevaolga-1962@postgrespro.ru", "phone": "+70414549855"}
0005435326561	FB145E	8245 483147	OLGA MOISEEVA	{"email": "moiseeva.o_02041970@postgrespro.ru", "phone": "+70221686213"}
0005435326562	53C024	9457 466187	VADIM SOROKIN	{"phone": "+70693415293"}
0005435326563	5910A4	8508 789031	ALEKSANDR FROLOV	{"email": "aleksandrfrolov-1975@postgrespro.ru", "phone": "+70621041776"}
0005435326564	5910A4	6926 669597	VALENTIN VASILEV	{"phone": "+70077859450"}
0005435326565	899ED5	1813 686667	ALEKSEY GORBUNOV	{"email": "alekseygorbunov14111967@postgrespro.ru", "phone": "+70054873586"}
0005435326566	899ED5	6286 870663	SERGEY SIDOROV	{"email": "sidorovsergey121979@postgrespro.ru", "phone": "+70017459740"}
0005435326567	AA93AC	7763 375348	ALEKSEY GORBUNOV	{"email": "gorbunova12081970@postgrespro.ru", "phone": "+70197446137"}
0005435326568	64805B	2656 248190	OLGA YAKOVLEVA	{"email": "oyakovleva.1973@postgrespro.ru", "phone": "+70618463148"}
0005435326569	64805B	8682 648484	ALEKSANDR ZHURAVLEV	{"email": "aleksandr-zhuravlev.1973@postgrespro.ru", "phone": "+70871459032"}
0005435326570	F05FFC	7821 768794	ANTON KUZNECOV	{"email": "kuznecov-a_07091968@postgrespro.ru", "phone": "+70507780858"}
0005435326571	F05FFC	9205 870645	VASILIY KOZLOV	{"phone": "+70001383214"}
0005435326572	82360B	5470 616231	GALINA MAKSIMOVA	{"phone": "+70636811994"}
0005435326573	FAA32A	7461 333122	VASILIY PETROV	{"phone": "+70647640940"}
0005435326574	FAA32A	4205 061279	EVDOKIYA MEDVEDEVA	{"email": "e.medvedeva1971@postgrespro.ru", "phone": "+70140675490"}
0005435326575	E1E790	8417 783291	NIKOLAY ROMANOV	{"email": "romanov_n19011977@postgrespro.ru", "phone": "+70892656725"}
0005435326576	A29497	6958 347471	VLADIMIR ISAEV	{"phone": "+70228951710"}
0005435326577	A29497	0691 954408	DMITRIY EGOROV	{"phone": "+70115264855"}
0005435326578	930355	0219 881128	EVGENIY CHERNOV	{"phone": "+70223361010"}
0005435326579	930355	7042 322228	SERGEY VASILEV	{"phone": "+70163087037"}
0005435326580	F1B0A5	1737 471988	SERGEY SAVELEV	{"email": "savelev.s.25031963@postgrespro.ru", "phone": "+70911718194"}
0005435326581	F1B0A5	1941 078350	SERGEY MAKAROV	{"phone": "+70235878379"}
0005435326582	714716	4194 968272	VIKTOR KUZNECOV	{"email": "viktor-kuznecov05091966@postgrespro.ru", "phone": "+70956884780"}
0005435326583	0D9BDD	8863 506719	VLADIMIR MATVEEV	{"email": "vmatveev.1976@postgrespro.ru", "phone": "+70587754902"}
0005435326584	0D9BDD	4753 221442	ALEKSANDR KOZLOV	{"email": "akozlov061978@postgrespro.ru", "phone": "+70809130180"}
0005435326585	1293CE	8945 191982	YULIYA POLYAKOVA	{"email": "polyakovay.1961@postgrespro.ru", "phone": "+70309573193"}
0005435326586	E2DD8B	8396 436859	ELENA POPOVA	{"email": "popova_elena_31031975@postgrespro.ru", "phone": "+70966796240"}
0005435326587	E2DD8B	3216 907906	NIKOLAY MIRONOV	{"phone": "+70019835415"}
0005435326588	BEDA49	2329 202888	TATYANA ALEKSANDROVA	{"email": "tatyana_aleksandrova_101963@postgrespro.ru", "phone": "+70020133198"}
0005435326589	AAA2A8	4262 209747	RUSLAN NIKOLAEV	{"email": "nikolaev-r-02091969@postgrespro.ru", "phone": "+70840078718"}
0005435326590	64AB04	9421 211511	IRINA MOROZOVA	{"email": "irina_morozova-1977@postgrespro.ru", "phone": "+70328856351"}
0005435326591	64AB04	0333 207654	NADEZHDA NOVIKOVA	{"phone": "+70674479534"}
0005435326592	2A3A81	1524 306176	OLEG ZAKHAROV	{"phone": "+70420688466"}
0005435326593	2A3A81	8488 781179	OLGA KULIKOVA	{"phone": "+70161306194"}
0005435326594	9315F7	1316 801201	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay_021963@postgrespro.ru", "phone": "+70427029574"}
0005435326595	DB10F1	1508 042734	VALENTINA TROFIMOVA	{"phone": "+70648484896"}
0005435326596	DB10F1	2316 329968	ANATOLIY IVANOV	{"phone": "+70354457003"}
0005435326597	DB10F1	4318 113811	KONSTANTIN KUZNECOV	{"phone": "+70127910501"}
0005435326598	8C7444	0993 764347	VERONIKA MASLOVA	{"email": "maslovaveronika_1978@postgrespro.ru", "phone": "+70092282325"}
0005435326599	BD1ABB	9607 561861	VALENTINA NIKITINA	{"email": "valentinanikitina091973@postgrespro.ru", "phone": "+70005579240"}
0005435326600	EE344D	7144 365431	OKSANA DAVYDOVA	{"email": "odavydova_081965@postgrespro.ru", "phone": "+70263325408"}
0005435326601	EE344D	5937 105886	OLGA NIKIFOROVA	{"phone": "+70148474471"}
0005435326602	EE344D	7552 104831	NATALYA SAVELEVA	{"email": "natalya-saveleva-04031963@postgrespro.ru", "phone": "+70897803420"}
0005435326603	F3CBB6	5464 453360	LYUBOV BORISOVA	{"phone": "+70418293570"}
0005435326604	8D610C	1191 437008	NATALYA FOMINA	{"phone": "+70098986741"}
0005435326605	C22DE5	3895 006129	ALEKSANDR DENISOV	{"phone": "+70262766719"}
0005435326606	D2C451	5971 097986	ALEKSANDR SEMENOV	{"email": "semenov-a.29111979@postgrespro.ru", "phone": "+70553776157"}
0005435326607	D2C451	3718 886741	MARINA NESTEROVA	{"phone": "+70982354317"}
0005435326608	D9214C	5727 008171	RAISA KOLESNIKOVA	{"email": "raisa_kolesnikova.021978@postgrespro.ru", "phone": "+70160339607"}
0005435326609	756A37	6335 083657	NADEZHDA ORLOVA	{"email": "nadezhda-orlova_121973@postgrespro.ru", "phone": "+70906385943"}
0005435326610	D264E9	6306 484262	OLGA NOVIKOVA	{"email": "novikova.o.18101975@postgrespro.ru", "phone": "+70494051159"}
0005435326611	5DD3CE	0808 070541	LYUBOV MAKSIMOVA	{"email": "maksimovalyubov.05041965@postgrespro.ru", "phone": "+70432580674"}
0005435326612	672309	1278 678986	ANNA FROLOVA	{"email": "frolova_a-071971@postgrespro.ru", "phone": "+70040048090"}
0005435326613	672309	3615 237954	EVGENIY RODIONOV	{"email": "rodionov.e16051970@postgrespro.ru", "phone": "+70159799978"}
0005435326614	B0E140	0783 906660	YULIYA OVCHINNIKOVA	{"email": "y-ovchinnikova_19061965@postgrespro.ru", "phone": "+70774300578"}
0005435326615	AF0472	8391 551437	ANASTASIYA PAVLOVA	{"phone": "+70185674463"}
0005435326616	AF0472	3142 972751	SERGEY NIKOLAEV	{"email": "sergey_nikolaev011963@postgrespro.ru", "phone": "+70918355471"}
0005435326617	250D82	2622 861620	VALENTINA KUZNECOVA	{"email": "kuznecovavalentina111967@postgrespro.ru", "phone": "+70774302798"}
0005435326618	460413	8535 782663	DMITRIY PETROV	{"phone": "+70569272430"}
0005435326619	460413	9210 761140	VASILIY FOMIN	{"phone": "+70817017997"}
0005435326620	DFFD82	1052 993089	EVGENIYA NAUMOVA	{"email": "naumova-e-041975@postgrespro.ru", "phone": "+70396000603"}
0005435326621	DFFD82	3806 649635	SVETLANA POLYAKOVA	{"email": "svetlana-polyakova_1970@postgrespro.ru", "phone": "+70464873596"}
0005435326622	38E9AB	9775 595948	ANNA ORLOVA	{"phone": "+70133053202"}
0005435326623	C9B813	3744 482668	ANDREY VOLKOV	{"email": "volkova081977@postgrespro.ru", "phone": "+70189738597"}
0005435326624	CFC9A7	2161 527895	NIKITA BARANOV	{"email": "nbaranov14121970@postgrespro.ru", "phone": "+70224938867"}
0005435326625	D5E602	1549 591111	ALEKSEY SMIRNOV	{"phone": "+70530604393"}
0005435326626	D5E602	4004 607430	SERGEY SAVELEV	{"email": "sergey_savelev1973@postgrespro.ru", "phone": "+70525487095"}
0005435326627	94B80B	7125 599062	VALENTINA ERMAKOVA	{"email": "ermakova-v_041975@postgrespro.ru", "phone": "+70923196172"}
0005435326628	94B80B	0536 388708	VALERIY SOROKIN	{"phone": "+70988969942"}
0005435326629	94B80B	7142 398511	LILIYA MIKHAYLOVA	{"phone": "+70969150232"}
0005435326630	3F4BA8	6783 293258	MIKHAIL KUZNECOV	{"email": "mikhailkuznecov.1974@postgrespro.ru", "phone": "+70842263766"}
0005435326631	3F4BA8	1636 231774	SVETLANA NIKIFOROVA	{"email": "nikiforova_s.21101975@postgrespro.ru", "phone": "+70580486943"}
0005435326632	A835DC	4724 832395	VALERIY FILIPPOV	{"phone": "+70883715751"}
0005435326633	A835DC	0885 442932	LIDIYA KISELEVA	{"email": "kiseleva_lidiya-121969@postgrespro.ru", "phone": "+70406063729"}
0005435326634	4F29B4	9574 776575	ROZA ORLOVA	{"email": "r-orlova25041975@postgrespro.ru", "phone": "+70181942641"}
0005435326635	4F29B4	0770 103701	PETR MELNIKOV	{"email": "melnikov.petr041962@postgrespro.ru", "phone": "+70015523465"}
0005435326636	74F483	6842 863705	DARYA PETROVA	{"email": "dpetrova-1971@postgrespro.ru", "phone": "+70302055864"}
0005435326637	74F483	6092 452968	ALEKSANDR SOROKIN	{"phone": "+70459826400"}
0005435326638	7AA033	0663 099486	ARTEM TIKHONOV	{"phone": "+70991921196"}
0005435326639	7AA033	0621 418514	NIKOLAY ABRAMOV	{"email": "nabramov021974@postgrespro.ru", "phone": "+70140057591"}
0005435326640	290013	6893 927039	MIKHAIL FROLOV	{"email": "mikhail.frolov.04021972@postgrespro.ru", "phone": "+70993042477"}
0005435326641	0EFF15	7354 747925	OLGA FROLOVA	{"phone": "+70689711455"}
0005435326642	0EFF15	4720 743673	ELENA VLASOVA	{"email": "vlasova_e.041970@postgrespro.ru", "phone": "+70007684319"}
0005435326643	0EFF15	9959 016573	SERGEY KUZNECOV	{"email": "sergey-kuznecov.02051977@postgrespro.ru", "phone": "+70599864907"}
0005435326644	30B89C	7375 779149	ANASTASIYA IVANOVA	{"email": "a.ivanova-101970@postgrespro.ru", "phone": "+70304157628"}
0005435326645	9CFBE6	1549 450098	MAKSIM YAKOVLEV	{"email": "m-yakovlev.1975@postgrespro.ru", "phone": "+70741639187"}
0005435326646	9CFBE6	5532 373526	ELENA IVANOVA	{"email": "elena.ivanova041968@postgrespro.ru", "phone": "+70815707581"}
0005435326647	0A4FB2	5170 319569	YANA ALEKSEEVA	{"email": "alekseevay-1958@postgrespro.ru", "phone": "+70207129296"}
0005435326648	85947A	1216 449797	ALEKSEY NOVIKOV	{"phone": "+70895163948"}
0005435326649	85947A	7229 985328	ALEKSEY NOVIKOV	{"phone": "+70726558616"}
0005435326650	685647	3577 845223	OLGA TARASOVA	{"phone": "+70842909214"}
0005435326651	685647	3962 326237	ANTON KUZNECOV	{"email": "kuznecov_anton1962@postgrespro.ru", "phone": "+70432836138"}
0005435326652	14417B	0094 367076	DMITRIY MEDVEDEV	{"email": "medvedevdmitriy21041975@postgrespro.ru", "phone": "+70850729107"}
0005435326653	14417B	3063 269186	ALEKSANDR FEDOTOV	{"email": "fedotova-111975@postgrespro.ru", "phone": "+70873329862"}
0005435326654	424914	5243 868068	ALEKSANDR NAZAROV	{"phone": "+70858269751"}
0005435326655	927096	2788 721726	ILYA ANTONOV	{"email": "iantonov.011969@postgrespro.ru", "phone": "+70791724107"}
0005435326656	927096	2329 265689	NIKOLAY TARASOV	{"phone": "+70559777755"}
0005435326657	108D56	1608 886490	NIKITA IVANOV	{"email": "n-ivanov.1979@postgrespro.ru", "phone": "+70966461156"}
0005435326658	AD0D06	1662 528709	YURIY SEMENOV	{"phone": "+70865466273"}
0005435326659	F52417	4784 922337	NATALYA KOROLEVA	{"email": "nkoroleva.1984@postgrespro.ru", "phone": "+70144723167"}
0005435326660	B853AF	2276 859956	KSENIYA MALYSHEVA	{"phone": "+70862663924"}
0005435326661	90083E	5040 693181	ANNA KUZMINA	{"email": "akuzmina-041968@postgrespro.ru", "phone": "+70337249595"}
0005435326662	0115C7	7825 603041	EKATERINA POPOVA	{"phone": "+70335530245"}
0005435326663	81B7C0	1758 652806	MAKSIM STEPANOV	{"email": "m_stepanov1965@postgrespro.ru", "phone": "+70936150318"}
0005435326664	4A2DAE	2202 639864	NATALYA MOROZOVA	{"phone": "+70719288453"}
0005435326665	B085E8	4292 876433	EVGENIY SCHERBAKOV	{"email": "scherbakov-evgeniy1967@postgrespro.ru", "phone": "+70223294566"}
0005435326666	D46FFB	8817 914140	VLADIMIR BORISOV	{"phone": "+70277039947"}
0005435326667	782577	8305 937766	NIKITA OSIPOV	{"email": "osipovn07051973@postgrespro.ru", "phone": "+70065383936"}
0005435326668	782577	9093 524632	ILNAR IVANOV	{"email": "ilnar_ivanov-041981@postgrespro.ru", "phone": "+70960081983"}
0005435326669	A2DE3E	8548 281502	VERA GAVRILOVA	{"phone": "+70453561910"}
0005435326670	A2DE3E	5484 898401	YULIYA ERMAKOVA	{"email": "yuliya-ermakova1962@postgrespro.ru", "phone": "+70221821072"}
0005435326671	A2DE3E	5720 954059	NINA DMITRIEVA	{"phone": "+70909261954"}
0005435326672	61ADA0	8428 155257	VLADIMIR KUZMIN	{"phone": "+70874028579"}
0005435326673	61ADA0	1489 356958	IVAN GUSEV	{"phone": "+70159526466"}
0005435326674	FF6955	7345 442413	VALENTINA SEMENOVA	{"phone": "+70876373868"}
0005435326675	E49263	4773 525730	EVGENIY KARPOV	{"phone": "+70684040382"}
0005435326676	E49263	7715 371795	VITALIY PAVLOV	{"email": "pavlov.v-1975@postgrespro.ru", "phone": "+70223891011"}
0005435326677	B36829	4781 021573	VLADIMIR ALEKSANDROV	{"phone": "+70070296938"}
0005435326678	86F909	5294 480709	ARTUR FEDOROV	{"phone": "+70392341004"}
0005435326679	9BB615	5855 345736	NINA TROFIMOVA	{"email": "nina-trofimova28051965@postgrespro.ru", "phone": "+70133341036"}
0005435326680	9BB615	5679 341623	LIDIYA AFANASEVA	{"email": "afanaseva.l_15071975@postgrespro.ru", "phone": "+70696150117"}
0005435326681	AFADF7	6825 179623	ALEKSANDR TIKHONOV	{"email": "tikhonova_111970@postgrespro.ru", "phone": "+70591007561"}
0005435326682	962C0A	6858 022066	VERA KUZNECOVA	{"email": "vera.kuznecova22011973@postgrespro.ru", "phone": "+70104813812"}
0005435326683	D9883E	6514 254909	ALEKSANDRA TROFIMOVA	{"email": "a-trofimova-21031973@postgrespro.ru", "phone": "+70153439967"}
0005435326684	D9883E	4915 363409	VYACHESLAV MELNIKOV	{"email": "melnikovv-081974@postgrespro.ru", "phone": "+70169836821"}
0005435326685	09BE6A	3741 651507	VLADIMIR TIMOFEEV	{"email": "v_timofeev.14111968@postgrespro.ru", "phone": "+70008943770"}
0005435326686	F16BA7	5746 061609	ELENA SOROKINA	{"phone": "+70570548625"}
0005435326687	0FB8D5	0180 743344	SERGEY GAVRILOV	{"phone": "+70743192523"}
0005435326688	40A3CD	1156 860974	ROMAN POPOV	{"phone": "+70569208006"}
0005435326689	40A3CD	3414 334633	IRINA OSIPOVA	{"email": "osipova_irina_25011976@postgrespro.ru", "phone": "+70489513458"}
0005435326690	13BD6A	8817 076315	VLADIMIR KULIKOV	{"phone": "+70156953153"}
0005435326691	FE5C45	3420 345556	ILYA KUZMIN	{"email": "kuzminilya_1978@postgrespro.ru", "phone": "+70872213803"}
0005435326692	9CD4E5	6723 152431	IVAN IVANOV	{"email": "ivan_ivanov-091959@postgrespro.ru", "phone": "+70180883534"}
0005435326693	9CD4E5	4028 737104	VLADISLAV SCHERBAKOV	{"email": "scherbakov-vladislav061978@postgrespro.ru", "phone": "+70025129857"}
0005435326694	557775	6567 115439	ALEKSANDR SMIRNOV	{"phone": "+70808520372"}
0005435326695	557775	1525 033376	KIRILL IVANOV	{"phone": "+70979409636"}
0005435326696	22C9A6	3915 967759	YURIY ZAYCEV	{"email": "yzaycev-05011974@postgrespro.ru", "phone": "+70487732385"}
0005435326697	22C9A6	9418 904163	RUSLAN DENISOV	{"phone": "+70116393284"}
0005435326698	667895	2135 876006	NIKOLAY NIKOLAEV	{"email": "nikolaev_n_1968@postgrespro.ru", "phone": "+70343884748"}
0005435326699	667895	3704 774728	TATYANA SCHERBAKOVA	{"email": "tatyana-scherbakova-1966@postgrespro.ru", "phone": "+70134199251"}
0005435326700	CA6D79	2942 212881	DANIIL ANTONOV	{"phone": "+70333165888"}
0005435326701	76C737	3180 663293	SVETLANA ANDREEVA	{"email": "s_andreeva.27091959@postgrespro.ru", "phone": "+70643445558"}
0005435326702	793E56	4415 337461	YULIYA KISELEVA	{"phone": "+70387507458"}
0005435326703	F06EFB	4094 706809	YURIY VOLKOV	{"phone": "+70945530284"}
0005435326704	F06EFB	5417 230856	GEORGIY MIKHAYLOV	{"phone": "+70658185518"}
0005435326705	A7B828	0797 916457	ALINA MOROZOVA	{"phone": "+70065746720"}
0005435326706	51415B	1136 713973	NIKOLAY SERGEEV	{"phone": "+70305864403"}
0005435326707	CD67A9	3628 457855	ZINAIDA DENISOVA	{"phone": "+70918252197"}
0005435326708	F99735	9256 232038	MARIYA KOROLEVA	{"email": "m_koroleva.081978@postgrespro.ru", "phone": "+70156600949"}
0005435326709	6726BB	4352 827099	MARINA IVANOVA	{"phone": "+70506466055"}
0005435326710	6726BB	2253 769965	SVETLANA NOVIKOVA	{"email": "svetlana.novikova-081969@postgrespro.ru", "phone": "+70411056378"}
0005435326711	7E7105	6868 225000	MARGARITA SAVELEVA	{"email": "saveleva_margarita-041978@postgrespro.ru", "phone": "+70253218483"}
0005435326712	FFD7AF	5888 835553	DMITRIY CHERNOV	{"email": "chernov.dmitriy_061974@postgrespro.ru", "phone": "+70610212258"}
0005435326713	D6EF24	2412 344633	LYUDMILA POPOVA	{"email": "lyudmila.popova_18021979@postgrespro.ru", "phone": "+70658050218"}
0005435326714	D6EF24	7580 546059	STANISLAV KUZNECOV	{"phone": "+70756855551"}
0005435326715	EBDD47	1227 601788	NIKOLAY ROMANOV	{"email": "romanovn_25011973@postgrespro.ru", "phone": "+70689704494"}
0005435326716	EBDD47	2903 510434	YURIY IVANOV	{"phone": "+70770905112"}
0005435326717	07A52F	8442 274036	ALEKSANDR PAVLOV	{"email": "a-pavlov-061965@postgrespro.ru", "phone": "+70404499161"}
0005435326718	9F832A	9018 344866	TATYANA NIKOLAEVA	{"email": "t_nikolaeva-061970@postgrespro.ru", "phone": "+70057387284"}
0005435326719	9F832A	5973 172904	VLADISLAV STEPANOV	{"email": "vladislavstepanov121977@postgrespro.ru", "phone": "+70095899256"}
0005435326720	789DE5	5069 823147	ALEKSEY KOROLEV	{"phone": "+70576145346"}
0005435326721	789DE5	8335 673516	ANDREY BORISOV	{"phone": "+70035718523"}
0005435326722	A52D0F	9832 285683	ANDREY YAKOVLEV	{"phone": "+70711590108"}
0005435326723	B28992	5141 967060	SVETLANA PETROVA	{"phone": "+70462658378"}
0005435326724	5C51D3	1969 923573	ELENA NOVIKOVA	{"phone": "+70099158719"}
0005435326725	5C51D3	0620 270038	ALEKSEY POPOV	{"phone": "+70284133015"}
0005435326726	5C51D3	0843 299825	EVGENIY PAVLOV	{"email": "pavlov_e-111971@postgrespro.ru", "phone": "+70780103591"}
0005435326727	2D2F26	3851 863602	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_1975@postgrespro.ru", "phone": "+70967665783"}
0005435326728	2D2F26	5261 986492	VALENTINA KOROLEVA	{"phone": "+70467160782"}
0005435326729	2EC987	6106 881408	NATALYA BORISOVA	{"phone": "+70194295264"}
0005435326730	1AE0A5	5623 357353	NADEZHDA ARKHIPOVA	{"phone": "+70177539884"}
0005435326731	753F74	5700 265666	SERGEY ROMANOV	{"email": "sromanov_1971@postgrespro.ru", "phone": "+70543514748"}
0005435326732	8CC154	0805 028956	RUSLAN STEPANOV	{"email": "stepanov_ruslan03121972@postgrespro.ru", "phone": "+70963668243"}
0005435326733	5A8EB3	6195 165367	SERGEY FILIPPOV	{"email": "filippov.sergey_021977@postgrespro.ru", "phone": "+70688053169"}
0005435326734	281BF1	7513 208082	LYUBOV FROLOVA	{"phone": "+70664279634"}
0005435326735	905207	9142 148411	ELENA ANISIMOVA	{"email": "e.anisimova-091977@postgrespro.ru", "phone": "+70815313697"}
0005435326736	280813	9517 937555	VALENTINA LAZAREVA	{"email": "lazareva_v.31081978@postgrespro.ru", "phone": "+70644571823"}
0005435326737	280813	5927 517797	ELENA SMIRNOVA	{"email": "smirnova_elena-1966@postgrespro.ru", "phone": "+70942023482"}
0005435326738	2D4EF3	2344 106679	LYUBOV FEDOROVA	{"email": "fedorova-l1971@postgrespro.ru", "phone": "+70870417767"}
0005435326739	FC7986	1176 355249	SOFIYA POPOVA	{"email": "popova.sofiya081972@postgrespro.ru", "phone": "+70760083456"}
0005435326740	FC7986	2554 571324	SEMEN KISELEV	{"email": "semenkiselev_021980@postgrespro.ru", "phone": "+70339346857"}
0005435326741	C15896	1645 438502	YURIY PAVLOV	{"email": "pavlovyuriy.1973@postgrespro.ru", "phone": "+70915883467"}
0005435326742	C15896	7289 844995	PAVEL KOROLEV	{"phone": "+70805412631"}
0005435326743	730A5F	5758 967714	ELENA NAZAROVA	{"email": "nazarova-e-081975@postgrespro.ru", "phone": "+70064721711"}
0005435326744	B078AC	6035 813164	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila_081973@postgrespro.ru", "phone": "+70946255804"}
0005435326745	AE6175	2213 054785	ALEKSANDR NIKOLAEV	{"email": "aleksandr.nikolaev_20061970@postgrespro.ru", "phone": "+70470025626"}
0005435326746	AE6175	0621 113175	MIKHAIL GAVRILOV	{"email": "m_gavrilov.1978@postgrespro.ru", "phone": "+70200400404"}
0005435326747	C5C929	9543 054056	ILYA KONOVALOV	{"email": "i_konovalov-11031984@postgrespro.ru", "phone": "+70060445767"}
0005435326748	D84CCD	2742 309382	ALEKSEY OSIPOV	{"email": "osipova-091964@postgrespro.ru", "phone": "+70739380551"}
0005435326749	D84CCD	1125 904147	GALINA MELNIKOVA	{"email": "melnikova.galina-1968@postgrespro.ru", "phone": "+70751325984"}
0005435326750	A3D488	9361 986873	VLADIMIR FROLOV	{"phone": "+70820263337"}
0005435326751	4AC979	3582 164069	OLGA MOROZOVA	{"phone": "+70609200354"}
0005435326752	5FE58E	8803 746544	ANATOLIY SHEVCHENKO	{"phone": "+70671200520"}
0005435326753	269FCE	8760 807698	TATYANA PAVLOVA	{"email": "pavlova_tatyana1977@postgrespro.ru", "phone": "+70877621915"}
0005435326754	A28B6B	3395 729520	RAISA ARKHIPOVA	{"phone": "+70146850949"}
0005435326755	7689F3	2462 798445	LYUBOV NAUMOVA	{"email": "l-naumova1970@postgrespro.ru", "phone": "+70554147690"}
0005435326756	E2BA8A	4359 166322	TATYANA BELOVA	{"phone": "+70707915819"}
0005435326757	E2BA8A	4433 942606	SERGEY SOLOVEV	{"email": "solovev-s-1982@postgrespro.ru", "phone": "+70743223355"}
0005435326758	E2BA8A	1492 597671	ANDREY POPOV	{"phone": "+70444310857"}
0005435326759	B04E2C	7765 835004	LILIYA DMITRIEVA	{"email": "dmitrieva_liliya-31081970@postgrespro.ru", "phone": "+70166212406"}
0005435326760	12AB40	6252 280089	LYUDMILA ROMANOVA	{"email": "l-romanova-1987@postgrespro.ru", "phone": "+70310234345"}
0005435326761	3D3C90	1105 859935	ANDREY SOKOLOV	{"email": "sokolovandrey_1984@postgrespro.ru", "phone": "+70087510824"}
0005435326762	619D4A	4142 108648	ALEKSEY DMITRIEV	{"phone": "+70480282409"}
0005435326763	619D4A	0235 176773	LYUBOV KRASNOVA	{"phone": "+70689695979"}
0005435326764	A97328	2207 030536	ANDREY ZAYCEV	{"phone": "+70205296921"}
0005435326765	73656D	8409 553781	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov_021969@postgrespro.ru", "phone": "+70912702288"}
0005435326766	DEF74F	4640 883399	NIKOLAY RODIONOV	{"phone": "+70025875328"}
0005435326767	DEF74F	1089 380531	SERAFIMA NAUMOVA	{"phone": "+70548348755"}
0005435326768	A36864	3951 738577	IRINA BELYAEVA	{"email": "irina-belyaeva-011969@postgrespro.ru", "phone": "+70173322637"}
0005435326769	571524	1319 644225	EKATERINA ANISIMOVA	{"email": "anisimova.e1982@postgrespro.ru", "phone": "+70496032174"}
0005435326770	2DD54A	9593 410452	POLINA ZHURAVLEVA	{"email": "polina-zhuravleva-31051976@postgrespro.ru", "phone": "+70930987350"}
0005435326771	BD98F8	5028 530897	MIKHAIL MAKAROV	{"phone": "+70385717538"}
0005435326772	B757CF	6501 466744	YULIYA NIKOLAEVA	{"phone": "+70272009695"}
0005435326773	DA9FE1	7239 115089	OLGA NIKOLAEVA	{"email": "o.nikolaeva-23031971@postgrespro.ru", "phone": "+70176314327"}
0005435326774	DA9FE1	0765 586444	FANIL KUZMIN	{"phone": "+70772568846"}
0005435326892	5084CD	3688 715527	NADEZHDA ROMANOVA	{"phone": "+70380645873"}
0005435326775	5F7853	9670 206192	DMITRIY BONDARENKO	{"email": "dmitriybondarenko031962@postgrespro.ru", "phone": "+70390678990"}
0005435326776	1DE155	7396 660517	ALEKSEY KRASNOV	{"phone": "+70941641719"}
0005435326777	23653E	2601 948421	EKATERINA KONDRATEVA	{"phone": "+70957819648"}
0005435326778	B7B3DE	4804 067691	LYUBOV SIDOROVA	{"email": "lyubov_sidorova021961@postgrespro.ru", "phone": "+70719479304"}
0005435326779	B7B3DE	2332 330109	NIKOLAY EGOROV	{"phone": "+70901088138"}
0005435326780	793290	5754 273736	ANNA ZHURAVLEVA	{"email": "a.zhuravleva-1969@postgrespro.ru", "phone": "+70808992202"}
0005435326781	E14CCD	3683 243825	DANILA GRIGOREV	{"phone": "+70500273136"}
0005435326782	47ED2C	7630 825529	ANATOLIY CHERNOV	{"email": "chernov_anatoliy12011973@postgrespro.ru", "phone": "+70436544931"}
0005435326783	E344C1	0539 575331	TATYANA IVANOVA	{"email": "ivanova.t051970@postgrespro.ru", "phone": "+70348702561"}
0005435326784	E344C1	8624 331829	DENIS SOLOVEV	{"phone": "+70160119515"}
0005435326785	88DBB1	2375 573338	ANATOLIY VOLKOV	{"email": "anatoliy-volkov-1967@postgrespro.ru", "phone": "+70272747498"}
0005435326786	88DBB1	7367 049047	VERONIKA KOVALEVA	{"phone": "+70548479735"}
0005435326787	88DBB1	9437 691229	GALINA DENISOVA	{"email": "g_denisova.18111972@postgrespro.ru", "phone": "+70111247416"}
0005435326788	88DBB1	7083 378121	SOFYA KISELEVA	{"email": "skiseleva_061974@postgrespro.ru", "phone": "+70945497085"}
0005435326789	833148	1098 664806	SVETLANA IVANOVA	{"phone": "+70727977558"}
0005435326790	4E6003	3417 440033	ANASTASIYA ZHURAVLEVA	{"phone": "+70984140586"}
0005435326791	4E6003	6826 158774	ANASTASIYA ANDREEVA	{"email": "andreeva-a.1978@postgrespro.ru", "phone": "+70682563817"}
0005435326792	363FE7	5488 153768	TAMARA DANILOVA	{"phone": "+70708983730"}
0005435326793	50AB0C	9650 279197	EGOR ROMANOV	{"email": "egor.romanov-071965@postgrespro.ru", "phone": "+70228333046"}
0005435326794	DDDC81	4483 480545	VIKTOR PETROV	{"phone": "+70266852892"}
0005435326795	3C7DDC	4780 891379	GENNADIY FILIPPOV	{"phone": "+70169977203"}
0005435326796	F4C629	0527 222281	MAKSIM VOLKOV	{"phone": "+70164777453"}
0005435326797	F4C629	2320 260754	DENIS SERGEEV	{"email": "sergeev.denis.1966@postgrespro.ru", "phone": "+70072185019"}
0005435326798	F54940	7277 911062	DARYA NAZAROVA	{"phone": "+70156518301"}
0005435326799	F54940	4105 415364	EKATERINA ORLOVA	{"phone": "+70810666172"}
0005435326800	EFE756	1009 426435	DMITRIY BORISOV	{"phone": "+70358663414"}
0005435326801	221692	3588 703531	ALEKSANDR POPOV	{"email": "popovaleksandr_111969@postgrespro.ru", "phone": "+70639200919"}
0005435326802	221692	6664 277220	DARYA SOLOVEVA	{"email": "darya_soloveva-121972@postgrespro.ru", "phone": "+70273479686"}
0005435326803	77CDF4	2543 689501	NATALYA ABRAMOVA	{"phone": "+70289989845"}
0005435326804	77CDF4	9114 902497	PAVEL BORISOV	{"phone": "+70666923961"}
0005435326805	83D234	6038 326532	VLADIMIR CHERNOV	{"email": "chernovvladimir-121972@postgrespro.ru", "phone": "+70742250259"}
0005435326806	83D234	4581 319824	VLADLEN MATVEEV	{"phone": "+70657773191"}
0005435326807	83D234	7661 707979	VALERIYA MIRONOVA	{"phone": "+70913598379"}
0005435326808	4528D6	3911 319902	OLGA VOLKOVA	{"email": "volkova_o.1965@postgrespro.ru", "phone": "+70959366045"}
0005435326809	4335E4	0725 246658	IRINA ZAKHAROVA	{"phone": "+70908134996"}
0005435326810	4335E4	3194 792577	MARINA VASILEVA	{"email": "vasileva.marina_091970@postgrespro.ru", "phone": "+70425764298"}
0005435326811	3EB600	1619 903110	VLADIMIR STEPANOV	{"phone": "+70439576749"}
0005435326812	4F48BE	9684 077932	LYUBOV FEDOROVA	{"phone": "+70216541292"}
0005435326813	4F48BE	9874 690509	ALEKSANDR SOKOLOV	{"phone": "+70623362069"}
0005435326814	4F48BE	5677 590902	VLADIMIR SERGEEV	{"email": "sergeevv-19121978@postgrespro.ru", "phone": "+70783883491"}
0005435326815	D01BF1	1126 161648	SERGEY YAKOVLEV	{"email": "sergey_yakovlev_14111985@postgrespro.ru", "phone": "+70108167607"}
0005435326816	D01BF1	4541 136942	OLESYA NIKOLAEVA	{"email": "nikolaevaolesya.1970@postgrespro.ru", "phone": "+70957569836"}
0005435326817	D01BF1	2246 235524	SERGEY OSIPOV	{"email": "osipov-s-121969@postgrespro.ru", "phone": "+70129592670"}
0005435326818	95C29C	0246 531046	SVETLANA YUDINA	{"email": "yudina-s-29091970@postgrespro.ru", "phone": "+70240174403"}
0005435326819	908BB9	7751 645212	NINA IVANOVA	{"phone": "+70552782822"}
0005435326820	C4CC0C	4011 393477	OLGA ROMANOVA	{"phone": "+70340381580"}
0005435326821	D21EC2	9709 899721	NIKOLAY TIKHONOV	{"phone": "+70425246131"}
0005435326822	5F9430	5292 590949	SVETLANA MAKAROVA	{"email": "makarovasvetlana_22091971@postgrespro.ru", "phone": "+70524809344"}
0005435326823	A33754	6014 947968	EMIL FOMIN	{"email": "fomin_emil_1963@postgrespro.ru", "phone": "+70134384068"}
0005435326824	075C03	7888 304883	EKATERINA LAZAREVA	{"email": "ekaterina-lazareva27061961@postgrespro.ru", "phone": "+70820197441"}
0005435326825	E596F6	9898 915963	VYACHESLAV MOISEEV	{"phone": "+70544261799"}
0005435326826	F991B0	7110 307536	ANTON PETROV	{"phone": "+70283594147"}
0005435326827	401A9B	9588 505175	VIKTOR ORLOV	{"email": "orlov_v.1974@postgrespro.ru", "phone": "+70069705582"}
0005435326828	DFB89D	4151 876636	VIKTORIYA SCHERBAKOVA	{"email": "scherbakova_v111966@postgrespro.ru", "phone": "+70980082478"}
0005435326829	F9522D	3309 898656	VLADIMIR KAZAKOV	{"phone": "+70938028822"}
0005435326830	E22B2C	6155 842457	ALEKSANDR VASILEV	{"email": "aleksandr_vasilev_1969@postgrespro.ru", "phone": "+70390182624"}
0005435326831	79BE59	8259 747988	KRISTINA IVANOVA	{"email": "k_ivanova011975@postgrespro.ru", "phone": "+70890743393"}
0005435326832	79BE59	4279 218476	VLADIMIR OSIPOV	{"email": "vladimirosipov_041977@postgrespro.ru", "phone": "+70601797904"}
0005435326833	3A3601	4246 195267	DMITRIY VOROBEV	{"email": "dmitriyvorobev.24061957@postgrespro.ru", "phone": "+70504542258"}
0005435326834	3A3601	8121 400235	SERGEY DENISOV	{"phone": "+70837428531"}
0005435326893	5084CD	5495 694770	ANNA VASILEVA	{"phone": "+70318368669"}
0005435326835	3A3601	5267 829743	NIKOLAY MARTYNOV	{"email": "nmartynov_1965@postgrespro.ru", "phone": "+70378937651"}
0005435326836	7C8166	5216 623113	VALERIY ISAEV	{"phone": "+70645678578"}
0005435326837	7C8166	1202 065942	NATALYA PAVLOVA	{"email": "n-pavlova071974@postgrespro.ru", "phone": "+70320169125"}
0005435326838	A9E970	9267 751890	POLINA MAKAROVA	{"email": "polina_makarova-1966@postgrespro.ru", "phone": "+70077585405"}
0005435326839	A9E970	6740 042432	MARINA ALEKSEEVA	{"email": "alekseeva-marina_1973@postgrespro.ru", "phone": "+70374562862"}
0005435326840	627D9A	3834 531700	EVGENIY FROLOV	{"phone": "+70394688410"}
0005435326841	627D9A	6324 114485	NATALYA KOROLEVA	{"email": "n_koroleva_1975@postgrespro.ru", "phone": "+70762667033"}
0005435326842	68EEBC	9764 266380	ELENA KAZAKOVA	{"email": "kazakova.e.111965@postgrespro.ru", "phone": "+70625669414"}
0005435326843	F55E93	8250 415927	MARINA MELNIKOVA	{"email": "marina_melnikova.11101962@postgrespro.ru", "phone": "+70780857541"}
0005435326844	A04756	6253 994675	MAKSIM SCHERBAKOV	{"email": "maksim_scherbakov.09111965@postgrespro.ru", "phone": "+70019760137"}
0005435326845	A04756	8649 744794	ANNA VOLKOVA	{"phone": "+70913124631"}
0005435326846	B3E58D	8010 557266	VALENTINA SERGEEVA	{"email": "sergeeva_valentina1968@postgrespro.ru", "phone": "+70959619667"}
0005435326847	4B7578	3740 630312	VADIM SCHERBAKOV	{"email": "vadim-scherbakov_27081972@postgrespro.ru", "phone": "+70760482879"}
0005435326848	B05884	5760 002394	NADEZHDA TROFIMOVA	{"email": "nadezhdatrofimova_14071974@postgrespro.ru", "phone": "+70712856783"}
0005435326849	B05884	2628 931429	EKATERINA LEBEDEVA	{"phone": "+70552728758"}
0005435326850	B05884	0728 964934	GLEB STEPANOV	{"email": "gleb_stepanov_1964@postgrespro.ru", "phone": "+70964517303"}
0005435326851	328ECE	1478 306764	IRINA MIKHAYLOVA	{"email": "mikhaylova_irina_101982@postgrespro.ru", "phone": "+70091603895"}
0005435326852	328ECE	4185 366900	NIKITA IVANOV	{"email": "nivanov-19111964@postgrespro.ru", "phone": "+70291685953"}
0005435326853	DB1BC9	2844 761693	VALERIY ZHURAVLEV	{"email": "zhuravlev-v-121964@postgrespro.ru", "phone": "+70614597836"}
0005435326854	DB1BC9	2700 840896	ANATOLIY POPOV	{"email": "popova.26021972@postgrespro.ru", "phone": "+70708140582"}
0005435326855	9C8819	0299 381655	SVETLANA ERMAKOVA	{"email": "ermakova-svetlana-14061978@postgrespro.ru", "phone": "+70194708582"}
0005435326856	A36798	1030 927524	PAVEL KONOVALOV	{"phone": "+70525511094"}
0005435326857	9B643F	4491 657989	EKATERINA BORISOVA	{"email": "e.borisova_25111953@postgrespro.ru", "phone": "+70227398128"}
0005435326858	E6CDDB	7588 155726	EKATERINA BARANOVA	{"phone": "+70448689371"}
0005435326859	E6CDDB	2376 402584	ARTEM NIKOLAEV	{"email": "nikolaev-artem1979@postgrespro.ru", "phone": "+70696444411"}
0005435326860	4CD6CF	1893 418496	INESSA SMIRNOVA	{"phone": "+70542274403"}
0005435326861	5A4449	3331 161872	ALINA FEDOROVA	{"phone": "+70518736268"}
0005435326862	3A374E	9296 846935	MARIYA SIDOROVA	{"email": "mariya-sidorova.27061982@postgrespro.ru", "phone": "+70519160666"}
0005435326863	19B88B	8560 711838	ALEKSANDR ZAKHAROV	{"phone": "+70449956478"}
0005435326864	A4D1F0	4178 200576	OLGA GUSEVA	{"email": "guseva-o-111972@postgrespro.ru", "phone": "+70115616223"}
0005435326865	84EDF7	5816 053073	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a.10121961@postgrespro.ru", "phone": "+70227921565"}
0005435326866	3F40EF	0171 938423	LYUDMILA NIKOLAEVA	{"phone": "+70789844146"}
0005435326867	8D1A6E	2589 460060	IVAN TIMOFEEV	{"email": "timofeev_ivan1977@postgrespro.ru", "phone": "+70660046023"}
0005435326868	8D1A6E	6398 366906	ANDREY VASILEV	{"phone": "+70383890822"}
0005435326869	C9D4CC	4621 169571	MARIYA KOLESNIKOVA	{"email": "m-kolesnikova-20111980@postgrespro.ru", "phone": "+70424020632"}
0005435326870	EBB16D	9118 448352	ANDREY GORBUNOV	{"email": "a-gorbunov061979@postgrespro.ru", "phone": "+70634356255"}
0005435326871	9ADBA1	3989 662520	VLADIMIR STEPANOV	{"email": "vladimir_stepanov_1984@postgrespro.ru", "phone": "+70365959399"}
0005435326872	9ADBA1	2124 812883	LYUDMILA TIKHONOVA	{"phone": "+70837637927"}
0005435326873	9ADBA1	1178 753503	VIKTOR FILIPPOV	{"phone": "+70110356667"}
0005435326874	5AA4F9	3748 004444	SVETLANA NOVIKOVA	{"email": "novikova-s.1978@postgrespro.ru", "phone": "+70712820569"}
0005435326875	B6030E	5774 832919	LYUBOV MALYSHEVA	{"email": "lmalysheva_051963@postgrespro.ru", "phone": "+70493140223"}
0005435326876	B6030E	8392 844318	ALEKSANDR MIRONOV	{"email": "a_mironov_24101965@postgrespro.ru", "phone": "+70532439559"}
0005435326877	BD5FF0	5103 220229	ANNA NESTEROVA	{"phone": "+70142028896"}
0005435326878	BD5FF0	3524 432633	NATALYA NIKOLAEVA	{"phone": "+70181510760"}
0005435326879	BD5FF0	9516 708074	ANASTASIYA KONOVALOVA	{"phone": "+70191503377"}
0005435326880	687EE6	1038 215864	YURIY STEPANOV	{"phone": "+70200604846"}
0005435326881	687EE6	5787 307217	REGINA VOROBEVA	{"email": "reginavorobeva_111965@postgrespro.ru", "phone": "+70920294623"}
0005435326882	CD2466	1021 278209	NADEZHDA IVANOVA	{"phone": "+70297236983"}
0005435326883	CD2466	7247 057276	OLGA ROMANOVA	{"email": "o-romanova17041973@postgrespro.ru", "phone": "+70567379660"}
0005435326884	0BCE6F	4530 060016	EVGENIY DENISOV	{"email": "e_denisov_061983@postgrespro.ru", "phone": "+70602396682"}
0005435326885	965548	8576 534830	ELENA POLYAKOVA	{"email": "elena-polyakova101971@postgrespro.ru", "phone": "+70814426400"}
0005435326886	965548	1811 593339	DMITRIY KUZNECOV	{"phone": "+70142185672"}
0005435326887	C97469	8085 386402	PAVEL ALEKSEEV	{"email": "p-alekseev-09091967@postgrespro.ru", "phone": "+70278931586"}
0005435326888	C97469	5818 215379	ALEKSEY IVANOV	{"phone": "+70274022413"}
0005435326889	F6CF7B	5445 689539	VERONIKA ZHUKOVA	{"email": "veronika-zhukova_081973@postgrespro.ru", "phone": "+70157149423"}
0005435326890	301ADA	3264 495314	VERA KOVALEVA	{"email": "kovalevav-25121965@postgrespro.ru", "phone": "+70636735058"}
0005435326891	FBD41C	4661 190736	NINA SMIRNOVA	{"email": "nsmirnova.19091959@postgrespro.ru", "phone": "+70646050259"}
0005435326894	E5434B	1601 983361	VLADIMIR ZAYCEV	{"phone": "+70192195388"}
0005435326895	E5434B	3571 258371	KIRILL STEPANOV	{"email": "stepanovkirill_01021963@postgrespro.ru", "phone": "+70695041413"}
0005435326896	18D160	8572 468504	ALEKSANDR BARANOV	{"phone": "+70937892521"}
0005435326897	18D160	6968 519148	ANTON SERGEEV	{"email": "anton.sergeev-21091971@postgrespro.ru", "phone": "+70877996158"}
0005435326898	D917B4	7080 358893	OKSANA NIKOLAEVA	{"phone": "+70268408892"}
0005435326899	D917B4	4146 499751	NINA ORLOVA	{"phone": "+70874405720"}
0005435326900	D917B4	7727 660462	IRINA PETROVA	{"email": "i_petrova-1970@postgrespro.ru", "phone": "+70908742209"}
0005435326901	C61485	4888 079398	GALINA IVANOVA	{"email": "ivanova_g.101970@postgrespro.ru", "phone": "+70470419085"}
0005435326902	F1C560	7722 797085	TIMUR YAKOVLEV	{"email": "timur.yakovlev-1969@postgrespro.ru", "phone": "+70033035548"}
0005435326903	F1C560	9704 937114	VALERIY PETROV	{"email": "petrov.v.061983@postgrespro.ru", "phone": "+70918539020"}
0005435326904	BB0677	2525 276434	LYUDMILA KUZNECOVA	{"phone": "+70506021691"}
0005435326905	8EDD92	9099 441351	ELENA MIRONOVA	{"phone": "+70562842678"}
0005435326906	A9F12B	9258 705601	VLADIMIR MAKSIMOV	{"email": "v.maksimov21091965@postgrespro.ru", "phone": "+70222271489"}
0005435326907	E9DC61	1680 007625	LEONID NIKITIN	{"email": "l.nikitin.1970@postgrespro.ru", "phone": "+70725809837"}
0005435326908	BA68EC	3129 812205	VERA LAZAREVA	{"phone": "+70083626891"}
0005435326909	D169EC	2786 229705	ANTONINA IVANOVA	{"email": "ivanovaantonina-30051969@postgrespro.ru", "phone": "+70412029468"}
0005435326910	FEA349	8962 161363	NIKOLAY FROLOV	{"phone": "+70777190647"}
0005435326911	FEA349	1372 152048	SVETLANA POPOVA	{"phone": "+70169478864"}
0005435326912	FEA349	3633 505932	DMITRIY KULIKOV	{"email": "dmitriy_kulikov.21091964@postgrespro.ru", "phone": "+70545050540"}
0005435326913	24B7CE	3274 956482	IGOR FEDOROV	{"phone": "+70033759159"}
0005435326914	D725F3	0661 434094	DMITRIY DENISOV	{"email": "denisovdmitriy-1981@postgrespro.ru", "phone": "+70122299895"}
0005435326915	FBB259	4616 658942	LIDIYA MOISEEVA	{"email": "moiseeva_lidiya_1973@postgrespro.ru", "phone": "+70023691599"}
0005435326916	337E93	5577 249184	PAVEL ILIN	{"email": "p-ilin-011978@postgrespro.ru", "phone": "+70184082369"}
0005435326917	0980E4	6943 895443	ELENA AFANASEVA	{"email": "elena-afanaseva1981@postgrespro.ru", "phone": "+70439540125"}
0005435326918	42DE6D	7272 972511	SVETLANA GAVRILOVA	{"phone": "+70418988400"}
0005435326919	42DE6D	9384 454295	NIKITA POPOV	{"email": "npopov.021976@postgrespro.ru", "phone": "+70226694315"}
0005435326920	353CD5	8017 250312	YURIY SEMENOV	{"email": "yuriy-semenov121972@postgrespro.ru", "phone": "+70164477149"}
0005435326921	19EF22	8621 898552	SERGEY OSIPOV	{"email": "sergey-osipov.071971@postgrespro.ru", "phone": "+70298011055"}
0005435326922	0376C3	0497 378440	LYUDMILA POPOVA	{"phone": "+70717160849"}
0005435326923	0376C3	8217 575619	IGOR IVANOV	{"phone": "+70169422737"}
0005435326924	9031BC	7216 215907	SVETLANA MARTYNOVA	{"phone": "+70597102945"}
0005435326925	68A1E3	5762 367818	EGOR SAVELEV	{"phone": "+70581737212"}
0005435326926	6DEF76	1000 567752	LYUDMILA NAZAROVA	{"email": "l-nazarova-14091972@postgrespro.ru", "phone": "+70323732530"}
0005435326927	6DEF76	9534 706742	MIKHAIL MELNIKOV	{"phone": "+70836567071"}
0005435326928	B78D5C	0206 412749	ALEKSEY BORISOV	{"email": "borisova111978@postgrespro.ru", "phone": "+70023198242"}
0005435326929	B78D5C	6604 172060	NATALYA KOROLEVA	{"phone": "+70219301485"}
0005435326930	03D310	3525 093299	OLEG NIKITIN	{"phone": "+70848900992"}
0005435326931	03D310	5770 983683	NIKOLAY KONOVALOV	{"email": "n_konovalov031979@postgrespro.ru", "phone": "+70629881989"}
0005435326932	72C807	3820 153279	VIKTOR FOMIN	{"email": "fomin-viktor_1969@postgrespro.ru", "phone": "+70178193327"}
0005435326933	D193E9	6221 728111	NIKOLAY ABRAMOV	{"phone": "+70914848809"}
0005435326934	175D8F	0100 103652	IVAN ZAKHAROV	{"phone": "+70286125700"}
0005435326935	175D8F	0244 377815	ELENA FOMINA	{"email": "elena-fomina1966@postgrespro.ru", "phone": "+70692202316"}
0005435326936	5405B9	2104 722273	EGOR KUZNECOV	{"email": "kuznecov_e-1972@postgrespro.ru", "phone": "+70109529966"}
0005435326937	5405B9	0368 401314	LYUDMILA NIKOLAEVA	{"phone": "+70372423560"}
0005435326938	9034B2	4167 208752	ALEKSANDRA MEDVEDEVA	{"phone": "+70520697021"}
0005435326939	9034B2	7575 230791	LYUDMILA LOGINOVA	{"phone": "+70108674077"}
0005435326940	5CD01B	3171 207540	EKATERINA OVCHINNIKOVA	{"phone": "+70178754298"}
0005435326941	A4E0E8	7367 071819	RAISA STEPANOVA	{"phone": "+70657276312"}
0005435326942	55093D	4019 284927	VYACHESLAV ISAEV	{"email": "isaev-vyacheslav-1971@postgrespro.ru", "phone": "+70830531690"}
0005435326943	DE5F41	2674 117695	INNA LAZAREVA	{"phone": "+70188208249"}
0005435326944	20D55B	7212 385769	NIKOLAY BORISOV	{"phone": "+70984856883"}
0005435326945	136151	6255 236197	DARYA MATVEEVA	{"email": "matveeva_darya.07051969@postgrespro.ru", "phone": "+70211385983"}
0005435326946	136151	0043 116925	VYACHESLAV FROLOV	{"phone": "+70309902599"}
0005435326947	597A75	7966 306338	YULIYA DAVYDOVA	{"email": "yuliya_davydova-01121971@postgrespro.ru", "phone": "+70896300006"}
0005435326948	B57592	5160 089629	PETR GERASIMOV	{"phone": "+70457105552"}
0005435326949	03A79B	1603 719005	POLINA ANDREEVA	{"email": "andreeva_p.031968@postgrespro.ru", "phone": "+70232729968"}
0005435326950	03A79B	1782 907570	VALENTINA KOMAROVA	{"phone": "+70961781307"}
0005435326951	03A79B	5489 187538	ELENA FILIPPOVA	{"email": "elena.filippova12071975@postgrespro.ru", "phone": "+70054086057"}
0005435326952	E799A0	6245 629593	YURIY KUZNECOV	{"email": "y_kuznecov_021963@postgrespro.ru", "phone": "+70274759318"}
0005435326953	E799A0	5107 870433	VLADIMIR RODIONOV	{"email": "vrodionov111962@postgrespro.ru", "phone": "+70328445535"}
0005435326954	BF94E3	1518 082249	OLGA NAZAROVA	{"email": "olga.nazarova.14021968@postgrespro.ru", "phone": "+70844886962"}
0005435326955	BF94E3	3048 912632	OKSANA KRASNOVA	{"phone": "+70887505279"}
0005435326956	57F43A	2017 971346	PETR KUZNECOV	{"email": "kuznecovp_071972@postgrespro.ru", "phone": "+70600806328"}
0005435326957	885D1A	9805 679460	EKATERINA VASILEVA	{"email": "e-vasileva-071978@postgrespro.ru", "phone": "+70646327816"}
0005435326958	E49BED	4439 994980	PETR MIRONOV	{"email": "p_mironov-091981@postgrespro.ru", "phone": "+70797552862"}
0005435326959	3AB0D3	5078 063917	OLGA VASILEVA	{"phone": "+70084774990"}
0005435326960	253263	4093 026970	TIKHON SAVELEV	{"email": "savelevtikhon.011975@postgrespro.ru", "phone": "+70184431762"}
0005435326961	9AAA7D	8073 344510	DMITRIY YAKOVLEV	{"email": "yakovlev-dmitriy_061976@postgrespro.ru", "phone": "+70120551037"}
0005435326962	AB22F8	0171 578765	ARTEM ROMANOV	{"phone": "+70164301419"}
0005435326963	0F0268	1732 626670	TATYANA CHERNOVA	{"email": "tatyana.chernova_05121982@postgrespro.ru", "phone": "+70090372629"}
0005435326964	EEF991	8513 990246	ALEKSANDR GUSEV	{"phone": "+70014890174"}
0005435326965	B7F97B	0898 894161	NADEZHDA MOROZOVA	{"email": "nadezhda-morozova041979@postgrespro.ru", "phone": "+70610539360"}
0005435326966	37CF2F	0161 469735	ELENA IVANOVA	{"phone": "+70982109262"}
0005435326967	E3251E	9942 869990	ELENA PETROVA	{"email": "e.petrova28121960@postgrespro.ru", "phone": "+70979839359"}
0005435326968	E3251E	3203 640212	SVETLANA GERASIMOVA	{"email": "svetlana.gerasimova-081973@postgrespro.ru", "phone": "+70178955163"}
0005435326969	2A8967	0434 901044	LYUBOV GUSEVA	{"phone": "+70043581338"}
0005435326970	395FCC	5176 531514	NADEZHDA MOISEEVA	{"email": "nadezhda-moiseeva_01061972@postgrespro.ru", "phone": "+70341954362"}
0005435326971	395FCC	3590 554593	KSENIYA KUZNECOVA	{"email": "k-kuznecova_1973@postgrespro.ru", "phone": "+70385538451"}
0005435326972	395FCC	9569 598829	SERGEY SEMENOV	{"phone": "+70081895334"}
0005435326973	99F884	0320 946962	GALINA MELNIKOVA	{"phone": "+70763457820"}
0005435326974	9DA85F	4807 262445	LYUBOV MAKAROVA	{"email": "makaroval_19111974@postgrespro.ru", "phone": "+70991034220"}
0005435326975	208C26	8895 731471	ALEKSANDR ZHURAVLEV	{"phone": "+70385155730"}
0005435326976	208C26	3252 997845	ANTON FILIPPOV	{"email": "a.filippov-101976@postgrespro.ru", "phone": "+70890455468"}
0005435326977	B85CB6	0029 801868	VERA GERASIMOVA	{"phone": "+70028235810"}
0005435326978	183145	1748 380845	LUIZA POPOVA	{"phone": "+70838533906"}
0005435326979	02C588	1683 095966	OLGA ISAEVA	{"phone": "+70584218540"}
0005435326980	859C27	2044 346281	ANDREY OSIPOV	{"email": "andrey-osipov_09021982@postgrespro.ru", "phone": "+70575784335"}
0005435326981	05254B	8288 406537	ANDREY IVANOV	{"email": "andreyivanov031966@postgrespro.ru", "phone": "+70136557594"}
0005435326982	0E3443	6310 837269	LYUDMILA RYABOVA	{"phone": "+70631122212"}
0005435326983	8369EE	0261 431943	ELVIRA DENISOVA	{"email": "elvira.denisova_24111972@postgrespro.ru", "phone": "+70576352440"}
0005435326984	8369EE	8070 833528	ANASTASIYA ZHUKOVA	{"phone": "+70786334666"}
0005435326985	8369EE	8606 873117	YULIYA SEMENOVA	{"email": "semenovay.071967@postgrespro.ru", "phone": "+70334742476"}
0005435326986	46523C	2066 174238	ELDAR ANDREEV	{"email": "eldarandreev031975@postgrespro.ru", "phone": "+70875640650"}
0005435326987	D697BF	0499 915303	TATYANA CHERNOVA	{"email": "chernova_t_1970@postgrespro.ru", "phone": "+70053034354"}
0005435326988	D697BF	8106 171862	YURIY FROLOV	{"email": "frolov_y_101967@postgrespro.ru", "phone": "+70206875157"}
0005435326989	0C854C	7776 090207	NIKITA MAKAROV	{"phone": "+70912612648"}
0005435326990	508934	9280 200992	IGOR KOROLEV	{"email": "igor_korolev-1982@postgrespro.ru", "phone": "+70560681197"}
0005435326991	508934	5031 599884	OLGA ROMANOVA	{"email": "olga_romanova-29041981@postgrespro.ru", "phone": "+70984690716"}
0005435326992	35E969	7244 859820	ARTEM BORISOV	{"phone": "+70937985213"}
0005435326993	B03613	7390 635686	ALEKSANDR POPOV	{"phone": "+70943326162"}
0005435326994	DC47CB	6473 039450	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin_12071979@postgrespro.ru", "phone": "+70438302198"}
0005435326995	3B6416	5549 049266	ILYAS ROMANOV	{"email": "ilyasromanov_091973@postgrespro.ru", "phone": "+70148245044"}
0005435326996	57A661	6071 846337	GLEB SERGEEV	{"phone": "+70716909190"}
0005435326997	EC3725	5504 299729	NATALIYA VOROBEVA	{"email": "vorobeva-n-091973@postgrespro.ru", "phone": "+70667582723"}
0005435326998	EC3725	9069 162383	NATALYA VOLKOVA	{"email": "natalya_volkova_1957@postgrespro.ru", "phone": "+70273124841"}
0005435326999	5384E6	4138 873173	RAFIK BORISOV	{"email": "rafik.borisov1978@postgrespro.ru", "phone": "+70326893235"}
0005435327000	5384E6	3955 523314	ALEKSANDRA POPOVA	{"phone": "+70646195409"}
0005435327001	DCAF2D	5094 096251	TATYANA MARTYNOVA	{"phone": "+70406310555"}
0005435327002	5EF68A	4427 225031	YULIYA YAKOVLEVA	{"phone": "+70040522520"}
0005435327003	5EF68A	0591 621609	ALINA MAKSIMOVA	{"phone": "+70227777027"}
0005435327004	944274	7055 244409	VALENTIN KARPOV	{"email": "v.karpov.04011976@postgrespro.ru", "phone": "+70735162490"}
0005435327005	944274	4407 654079	IRINA ZHUKOVA	{"email": "zhukova_i_1970@postgrespro.ru", "phone": "+70343068742"}
0005435327006	B764D5	2906 380757	MARAT KOZLOV	{"email": "kozlovm.1966@postgrespro.ru", "phone": "+70678008356"}
0005435327007	B97663	7387 220412	NADEZHDA FADEEVA	{"email": "fadeevanadezhda-18011981@postgrespro.ru", "phone": "+70788689448"}
0005435327008	B97663	7771 866488	KLAVDIYA KULIKOVA	{"email": "klavdiya.kulikova_21121969@postgrespro.ru", "phone": "+70824189021"}
0005435327009	05C85E	4925 775596	GENNADIY FEDOROV	{"phone": "+70039956830"}
0005435327010	05C85E	2361 628038	ALEKSANDR SIDOROV	{"phone": "+70602845101"}
0005435327011	2125E5	8545 076714	IVAN KULIKOV	{"email": "ivan.kulikov.061970@postgrespro.ru", "phone": "+70153181365"}
0005435327012	2125E5	2301 895152	IRINA ZAKHAROVA	{"email": "zakharova.i_1976@postgrespro.ru", "phone": "+70249036689"}
0005435327013	2125E5	3418 750383	MAKSIM FEDOTOV	{"email": "maksimfedotov-031977@postgrespro.ru", "phone": "+70895169817"}
0005435327014	0804DA	9723 970900	YURIY KARPOV	{"email": "y_karpov.1974@postgrespro.ru", "phone": "+70747082323"}
0005435327015	653BF1	3373 676728	NATALYA NIKOLAEVA	{"phone": "+70337129653"}
0005435327016	653BF1	0132 034516	MARINA SOKOLOVA	{"email": "sokolova_marina_23091970@postgrespro.ru", "phone": "+70127811054"}
0005435327017	DA4236	2437 470753	IRINA KOZLOVA	{"email": "irina-kozlova091972@postgrespro.ru", "phone": "+70159020306"}
0005435327018	2B1F78	4546 470814	ROMAN SMIRNOV	{"email": "r_smirnov1965@postgrespro.ru", "phone": "+70453098236"}
0005435327019	2B1F78	7833 498776	MARINA MAKAROVA	{"email": "makarovam.21091975@postgrespro.ru", "phone": "+70254873702"}
0005435327020	69B735	3200 425333	YANA KOMAROVA	{"email": "komarova_yana.24121964@postgrespro.ru", "phone": "+70975548401"}
0005435327021	69B735	4078 423034	SERGEY POPOV	{"email": "popov.s1976@postgrespro.ru", "phone": "+70466656326"}
0005435327022	EA3281	5412 529134	ALEKSEY ALEKSEEV	{"phone": "+70873610875"}
0005435327023	EA3281	8168 413403	LEONID VASILEV	{"email": "l-vasilev.1966@postgrespro.ru", "phone": "+70222573036"}
0005435327024	A29E8B	5717 262132	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e.031964@postgrespro.ru", "phone": "+70574260368"}
0005435327025	B8EEDB	2806 783406	TATYANA VASILEVA	{"phone": "+70427674757"}
0005435327026	9F9C69	8102 507972	VIKTOR KULIKOV	{"phone": "+70699658393"}
0005435327027	9F9C69	8451 604284	VALERIY SAVELEV	{"email": "savelev_valeriy.031973@postgrespro.ru", "phone": "+70938723014"}
0005435327028	8FB11F	3711 450772	EKATERINA ORLOVA	{"phone": "+70946252193"}
0005435327029	E7E9CA	7303 434353	EKATERINA SERGEEVA	{"email": "e_sergeeva_09051971@postgrespro.ru", "phone": "+70637294201"}
0005435327030	52D7A4	7506 584404	OLEG GAVRILOV	{"email": "gavrilov_o-1981@postgrespro.ru", "phone": "+70287717463"}
0005435327031	2DF7D2	6678 964053	TATYANA ZHURAVLEVA	{"email": "zhuravleva_tatyana.071972@postgrespro.ru", "phone": "+70866927223"}
0005435327032	083F9D	8187 662832	SERGEY MOISEEV	{"phone": "+70911387393"}
0005435327033	083F9D	1436 448474	ALEKSEY ALEKSEEV	{"phone": "+70310178697"}
0005435327034	083F9D	2129 670091	ILDAR GUSEV	{"email": "gusev-i_121975@postgrespro.ru", "phone": "+70280851512"}
0005435327035	DB9B5D	9131 654464	NINA MOISEEVA	{"email": "moiseeva.n.11031971@postgrespro.ru", "phone": "+70111317574"}
0005435327036	94507A	5421 407271	EKATERINA VASILEVA	{"phone": "+70306929276"}
0005435327037	DB2CB4	7324 508652	ELENA ARKHIPOVA	{"email": "arkhipovae.1974@postgrespro.ru", "phone": "+70436050823"}
0005435327038	B78A58	2225 151275	ARTEM NIKOLAEV	{"email": "artemnikolaev-1972@postgrespro.ru", "phone": "+70274673813"}
0005435327039	B78A58	4185 515787	MIKHAIL POPOV	{"email": "popov-m_021963@postgrespro.ru", "phone": "+70451864292"}
0005435327040	70F415	7609 581242	BORIS VASILEV	{"email": "b_vasilev071984@postgrespro.ru", "phone": "+70888710664"}
0005435327041	363F71	1873 358162	YULIYA MOISEEVA	{"email": "yuliya-moiseeva1971@postgrespro.ru", "phone": "+70040903067"}
0005435327042	363F71	6126 393360	NATALYA KALININA	{"email": "n_kalinina.041975@postgrespro.ru", "phone": "+70345444803"}
0005435327043	750FFE	9261 211195	YAKOV ZAKHAROV	{"phone": "+70020760826"}
0005435327044	750FFE	7115 020294	IRINA CHERNOVA	{"phone": "+70546139904"}
0005435327045	595971	5917 124639	MAKSIM NIKOLAEV	{"phone": "+70695268508"}
0005435327046	595971	2517 322634	KONSTANTIN MATVEEV	{"email": "k-matveev.021965@postgrespro.ru", "phone": "+70391628168"}
0005435327047	309CA4	7941 312967	SERGEY YAKOVLEV	{"phone": "+70375574409"}
0005435327048	1CF04A	2768 109756	KRISTINA KOVALEVA	{"email": "kkovaleva.28061986@postgrespro.ru", "phone": "+70544657985"}
0005435327049	994DF9	6635 845371	NIKOLAY GAVRILOV	{"phone": "+70877795039"}
0005435327050	BD1756	5355 504330	ELENA NAZAROVA	{"phone": "+70064392315"}
0005435327051	30D8F8	6694 419291	TATYANA KOLESNIKOVA	{"email": "kolesnikova.tatyana_061965@postgrespro.ru", "phone": "+70653957201"}
0005435327052	AD379E	9443 762443	ANASTASIYA FROLOVA	{"email": "frolova-anastasiya-24121955@postgrespro.ru", "phone": "+70615010298"}
0005435327053	D3F3BC	0146 217484	NINA NOVIKOVA	{"email": "n_novikova-1972@postgrespro.ru", "phone": "+70541090042"}
0005435327054	DB4679	2540 281311	OLEG NIKOLAEV	{"email": "nikolaevoleg091980@postgrespro.ru", "phone": "+70339547711"}
0005435327055	10C144	4505 073349	ALEKSANDRA FOMINA	{"phone": "+70058080922"}
0005435327056	10C144	7385 892566	YURIY DMITRIEV	{"phone": "+70130769478"}
0005435327057	BEB877	2645 214354	IVAN EGOROV	{"email": "egorov_ivan1973@postgrespro.ru", "phone": "+70459546374"}
0005435327058	BEB877	9875 766639	ALEKSANDR POPOV	{"email": "popovaleksandr_1965@postgrespro.ru", "phone": "+70976651165"}
0005435327059	19D336	1793 000704	IGOR AFANASEV	{"phone": "+70737693789"}
0005435327060	8A5410	9212 499725	MAKSIM IVANOV	{"phone": "+70581369687"}
0005435327061	C7187D	9903 582698	ALEKSEY MAKAROV	{"email": "aleksey-makarov_16051973@postgrespro.ru", "phone": "+70789293084"}
0005435327062	C7187D	3171 053892	GALINA DANILOVA	{"email": "danilova.galina26021978@postgrespro.ru", "phone": "+70412633766"}
0005435327063	BCF53F	4709 481052	VLADIMIR ALEKSEEV	{"email": "v_alekseev-1962@postgrespro.ru", "phone": "+70495238271"}
0005435327064	BCF53F	6089 400043	ARSENIY DAVYDOV	{"phone": "+70267924270"}
0005435327065	226677	9928 024860	TATYANA TARASOVA	{"email": "t_tarasova011970@postgrespro.ru", "phone": "+70914439702"}
0005435327066	C8987F	9161 932371	YAROSLAV MAKAROV	{"phone": "+70304940952"}
0005435327067	FDFB1A	6197 376964	ELENA SOKOLOVA	{"phone": "+70983294651"}
0005435327068	A85C97	9796 579327	VADIM KULIKOV	{"email": "kulikov_vadim1972@postgrespro.ru", "phone": "+70214028738"}
0005435327069	B7CE20	6913 906667	ELENA MIRONOVA	{"email": "e-mironova_011969@postgrespro.ru", "phone": "+70571758478"}
0005435327070	FF3924	5685 861158	MIKHAIL ISAEV	{"phone": "+70886669257"}
0005435327071	5AB2DD	2195 321342	NIKOLAY BORISOV	{"email": "borisovnikolay02101973@postgrespro.ru", "phone": "+70276479655"}
0005435327072	A2E09E	6443 523427	ROMAN NIKITIN	{"phone": "+70968938949"}
0005435327073	A2E09E	6652 988067	YULIYA ZHUKOVA	{"phone": "+70259431347"}
0005435327074	CDAB2C	4875 513650	LYUDMILA SOROKINA	{"phone": "+70802561021"}
0005435327075	CCD098	3800 600542	TATYANA DAVYDOVA	{"phone": "+70959523374"}
0005435327076	A371C8	7321 812085	VLADIMIR EGOROV	{"email": "v-egorov30101967@postgrespro.ru", "phone": "+70149988273"}
0005435327077	A371C8	6124 722278	ANDREY FEDOROV	{"phone": "+70239491440"}
0005435327078	AAEAE4	5679 705395	ALBERT ZAKHAROV	{"phone": "+70919212833"}
0005435327079	AAEAE4	4113 696973	EVGENIY EGOROV	{"email": "e.egorov_04101974@postgrespro.ru", "phone": "+70018065966"}
0005435327080	1A977C	8344 589812	VIKTORIYA FROLOVA	{"email": "frolova.viktoriya22091978@postgrespro.ru", "phone": "+70087740293"}
0005435327081	196088	1580 850724	ALEKSEY KAZAKOV	{"email": "a-kazakov-1968@postgrespro.ru", "phone": "+70437009339"}
0005435327082	37C637	3596 036833	NADEZHDA ZAYCEVA	{"email": "n_zayceva_16101981@postgrespro.ru", "phone": "+70205231676"}
0005435327083	11CFC6	7700 497233	DIANA POPOVA	{"email": "dpopova.25111967@postgrespro.ru", "phone": "+70092381811"}
0005435327084	D0FCBC	6260 864606	NATALYA SOROKINA	{"phone": "+70751444984"}
0005435327085	D0FCBC	7945 341420	DARYA GAVRILOVA	{"phone": "+70949854316"}
0005435327086	C2425F	4664 169568	EKATERINA KUZNECOVA	{"phone": "+70349403481"}
0005435327087	91099B	2980 459183	EKATERINA TIMOFEEVA	{"email": "timofeeva.e041966@postgrespro.ru", "phone": "+70832357820"}
0005435327088	6B18D0	5708 396589	SVETLANA KOVALEVA	{"email": "skovaleva_19051978@postgrespro.ru", "phone": "+70094072536"}
0005435327089	F22A03	9509 733220	ELENA KUZMINA	{"phone": "+70437656010"}
0005435327090	90BD6E	1719 635014	ALEKSANDR ALEKSANDROV	{"email": "aleksandr-aleksandrov.1983@postgrespro.ru", "phone": "+70221144596"}
0005435327091	7294E7	9418 744196	ANASTASIYA TARASOVA	{"email": "anastasiyatarasova1968@postgrespro.ru", "phone": "+70971156866"}
0005435327092	7294E7	3195 281618	TAMARA MOISEEVA	{"phone": "+70105156727"}
0005435327093	8E5BBC	7690 893718	GALIYA KISELEVA	{"email": "kiseleva.g_111974@postgrespro.ru", "phone": "+70380805567"}
0005435327094	0B6410	8915 626484	VLADIMIR KOZLOV	{"email": "kozlov_v_021968@postgrespro.ru", "phone": "+70119616501"}
0005435327095	7839DF	4587 812426	GALINA TARASOVA	{"phone": "+70304314723"}
0005435327096	7839DF	0664 628306	MAKSIM RODIONOV	{"email": "mrodionov-11041967@postgrespro.ru", "phone": "+70734617678"}
0005435327097	4D0DB1	5951 048554	NATALYA IVANOVA	{"phone": "+70583768040"}
0005435327098	74C877	4401 615707	GALINA BELYAEVA	{"email": "belyaeva.g15111969@postgrespro.ru", "phone": "+70515951931"}
0005435327099	03013E	9828 754788	ANDREY MATVEEV	{"phone": "+70785964541"}
0005435327100	199262	0135 740421	LYUBOV ILINA	{"phone": "+70578009930"}
0005435327101	FC4E26	5491 328687	LYUDMILA VASILEVA	{"phone": "+70364448184"}
0005435327102	6C7AAB	2732 448507	OKSANA NIKITINA	{"email": "o.nikitina_1981@postgrespro.ru", "phone": "+70460247895"}
0005435327103	B70651	2491 451339	ANDREY IVANOV	{"email": "a.ivanov.19091969@postgrespro.ru", "phone": "+70416980279"}
0005435327104	B70651	5115 188960	ANASTASIYA MIRONOVA	{"email": "anastasiya-mironova-1965@postgrespro.ru", "phone": "+70918770022"}
0005435327105	B70651	2957 824999	PAVEL MIKHAYLOV	{"email": "pavel_mikhaylov.15011964@postgrespro.ru", "phone": "+70576951533"}
0005435327106	BD5169	6315 849248	MAKSIM NIKOLAEV	{"phone": "+70332691285"}
0005435327107	BD5169	5634 998114	SOFYA MELNIKOVA	{"email": "melnikova-sofya_121974@postgrespro.ru", "phone": "+70413971544"}
0005435327108	8C3F5F	5593 797579	EKATERINA LEBEDEVA	{"phone": "+70945998477"}
0005435327109	8C3F5F	1249 779755	TATYANA IVANOVA	{"phone": "+70689023822"}
0005435327110	8C3F5F	8677 170861	ALEVTINA TIKHONOVA	{"phone": "+70774401121"}
0005435327111	2330EE	9507 390561	NAILYA FEDOROVA	{"phone": "+70259974890"}
0005435327112	90AFF4	1859 879960	VLADIMIR SOROKIN	{"phone": "+70687915817"}
0005435327113	4102A1	0205 648657	OLGA PAVLOVA	{"phone": "+70687137155"}
0005435327114	4AE428	1346 240427	ALEKSANDR VLASOV	{"phone": "+70282446414"}
0005435327115	661F1F	7266 696118	DARYA KUZNECOVA	{"email": "kuznecova-darya-20111974@postgrespro.ru", "phone": "+70519352426"}
0005435327116	661F1F	8608 449184	PAVEL VOLKOV	{"email": "pavel_volkov_1968@postgrespro.ru", "phone": "+70205288396"}
0005435327117	6353F6	1139 313653	YULIYA DANILOVA	{"phone": "+70155120846"}
0005435327118	8274C6	2461 366122	GALINA SERGEEVA	{"email": "g.sergeeva_1975@postgrespro.ru", "phone": "+70449148818"}
0005435327119	8274C6	1314 146007	VADIM NIKOLAEV	{"phone": "+70923778826"}
0005435327120	70441F	7367 665514	KIRILL BONDARENKO	{"email": "bondarenkok_1979@postgrespro.ru", "phone": "+70003137526"}
0005435327121	70441F	5368 285484	ALEKSEY MELNIKOV	{"phone": "+70763356423"}
0005435327122	B70D76	6165 225050	IVAN KAZAKOV	{"phone": "+70370625361"}
0005435327123	E57644	8106 397036	YURIY POPOV	{"phone": "+70271216059"}
0005435327124	28EA5D	4638 626503	KAMIL MATVEEV	{"email": "matveevkamil-1977@postgrespro.ru", "phone": "+70165583245"}
0005435327125	381F81	8507 205724	ANNA KONOVALOVA	{"email": "anna_konovalova_041973@postgrespro.ru", "phone": "+70300324225"}
0005435327126	8A502B	4399 880494	GEORGIY SEMENOV	{"email": "georgiysemenov.101962@postgrespro.ru", "phone": "+70409212927"}
0005435327127	F40201	3220 330985	ALBINA SAVELEVA	{"phone": "+70313718470"}
0005435327128	AB4638	4671 276374	VLADIMIR ISAEV	{"email": "v_isaev-1967@postgrespro.ru", "phone": "+70492792871"}
0005435327129	AC5438	7607 206581	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova22031980@postgrespro.ru", "phone": "+70090128676"}
0005435327130	CAD2B4	1646 095573	ELVIRA MAKAROVA	{"phone": "+70745268661"}
0005435327131	F89349	8096 837299	ANASTASIYA EGOROVA	{"email": "anastasiyaegorova1974@postgrespro.ru", "phone": "+70577132998"}
0005435327132	4308EB	8718 332304	VERA SAVELEVA	{"phone": "+70160433006"}
0005435327133	E55ACA	3142 153770	MATVEY NIKITIN	{"email": "nikitinmatvey1971@postgrespro.ru", "phone": "+70346390469"}
0005435327134	4E27E2	3577 403470	ELENA OVCHINNIKOVA	{"email": "e-ovchinnikova_1969@postgrespro.ru", "phone": "+70127651437"}
0005435327135	F4FD84	2342 459346	RUSTYAM KONOVALOV	{"phone": "+70381270892"}
0005435327136	F4FD84	9320 381773	MAKSIM ISAEV	{"phone": "+70024790895"}
0005435327137	B52778	1200 134687	MAKSIM KAZAKOV	{"phone": "+70864439069"}
0005435327138	E827A8	8874 530380	EKATERINA GORBUNOVA	{"email": "ekaterina_gorbunova_1972@postgrespro.ru", "phone": "+70267163624"}
0005435327139	87E72A	3387 631331	EVGENIY GRIGOREV	{"phone": "+70970021343"}
0005435327140	87E72A	6744 068182	SERGEY FROLOV	{"phone": "+70930430538"}
0005435327141	6A4FB6	3409 259949	TATYANA PAVLOVA	{"email": "pavlova-t121969@postgrespro.ru", "phone": "+70071200292"}
0005435332146	3EEECB	1507 788999	MARINA KRASNOVA	{"phone": "+70594882572"}
0005435332147	90F896	4492 108552	MAKSIM STEPANOV	{"email": "stepanov_m-1968@postgrespro.ru", "phone": "+70520470155"}
0005435332148	90F896	5335 810649	MARGARITA LAZAREVA	{"email": "lazareva.margarita081977@postgrespro.ru", "phone": "+70385330643"}
0005435332149	7CA713	9868 737256	ALEKSEY KUZNECOV	{"email": "a.kuznecov-19071966@postgrespro.ru", "phone": "+70282435197"}
0005435332150	8A7AB4	6885 633888	DMITRIY KOROLEV	{"email": "korolev-d-1981@postgrespro.ru", "phone": "+70109868115"}
0005435332151	CEF066	6233 943503	ELINA KONOVALOVA	{"email": "konovalova-e03041964@postgrespro.ru", "phone": "+70953165548"}
0005435332152	CEF066	5186 700792	ALEKSANDR PETROV	{"email": "a_petrov.29071962@postgrespro.ru", "phone": "+70906557019"}
0005435332153	82D568	0097 783929	VLADIMIR AFANASEV	{"email": "afanasev-vladimir-1972@postgrespro.ru", "phone": "+70865962396"}
0005435332154	DEC7C4	7074 909030	NINA KOZLOVA	{"phone": "+70582011199"}
0005435332155	9C6E04	5895 295538	ANASTASIYA RODIONOVA	{"phone": "+70734214245"}
0005435332156	44DC94	6341 584722	SERGEY KUZNECOV	{"email": "kuznecov_s31101958@postgrespro.ru", "phone": "+70367191207"}
0005435332157	9DB6E6	7541 921306	LYUBOV KOMAROVA	{"phone": "+70495993663"}
0005435332158	9DB6E6	8758 699436	VLADIMIR PETROV	{"phone": "+70678158928"}
0005435332159	982E31	1228 187030	DANIYA KONDRATEVA	{"email": "d_kondrateva06081976@postgrespro.ru", "phone": "+70839985138"}
0005435332160	10F590	9828 776577	SERGEY FOMIN	{"email": "sergeyfomin.29041977@postgrespro.ru", "phone": "+70893549427"}
0005435332161	23B631	0120 756584	RAIS TARASOV	{"email": "tarasov_rais_011981@postgrespro.ru", "phone": "+70970306240"}
0005435332162	23B631	5018 908139	SERGEY VOLKOV	{"email": "sergeyvolkov-021974@postgrespro.ru", "phone": "+70878163491"}
0005435332163	23B631	2212 552458	TAMARA MARTYNOVA	{"email": "martynova-tamara.051968@postgrespro.ru", "phone": "+70542469457"}
0005435332164	234611	7463 543070	ELENA ZAKHAROVA	{"phone": "+70923919804"}
0005435332165	234611	8552 063841	VASILIY ROMANOV	{"phone": "+70874243499"}
0005435332166	15D65A	2875 216171	GALINA ZAKHAROVA	{"phone": "+70939619983"}
0005435332167	15D65A	7988 955348	SOFYA SCHERBAKOVA	{"email": "sofya_scherbakova111969@postgrespro.ru", "phone": "+70408369052"}
0005435332168	E06CF6	5252 181875	ALEKSANDR ANTONOV	{"phone": "+70874051498"}
0005435332169	656FE5	6638 136989	NIKOLAY FILIPPOV	{"email": "filippov_nikolay.121972@postgrespro.ru", "phone": "+70119062360"}
0005435332170	D4162F	3693 801168	SVETLANA DAVYDOVA	{"phone": "+70382781097"}
0005435332171	D4162F	3466 793636	NATALYA ROMANOVA	{"email": "natalya-romanova_1973@postgrespro.ru", "phone": "+70457984263"}
0005435332172	31C7F9	7008 761942	ZOYA LUKYANOVA	{"email": "lukyanova-zoya-28051968@postgrespro.ru", "phone": "+70692597319"}
0005435332173	31C7F9	9680 848437	TATYANA NESTEROVA	{"email": "nesterova_t26101982@postgrespro.ru", "phone": "+70933105526"}
0005435332174	6ED5D4	3578 812976	RAVIL MIKHAYLOV	{"phone": "+70867400152"}
0005435332175	6ED5D4	1324 931903	NADEZHDA KAZAKOVA	{"email": "kazakova_nadezhda_18011979@postgrespro.ru", "phone": "+70807172953"}
0005435332176	9BB35A	4012 727230	VALERIY SOROKIN	{"phone": "+70112647819"}
0005435332177	094EF7	3024 859879	TATYANA PAVLOVA	{"phone": "+70444402320"}
0005435332178	03196A	3590 616220	ANDREY NIKOLAEV	{"email": "nikolaev.andrey.1981@postgrespro.ru", "phone": "+70242743026"}
0005435332179	196158	6525 635382	ANNA MOISEEVA	{"email": "moiseeva.a-14111984@postgrespro.ru", "phone": "+70193868403"}
0005435332180	196158	6521 186399	ZOYA KONOVALOVA	{"email": "konovalovaz.06121974@postgrespro.ru", "phone": "+70823507266"}
0005435332181	4CE63D	7009 531737	DENIS KULIKOV	{"phone": "+70874569398"}
0005435332182	E83172	3529 098793	BORIS NOVIKOV	{"email": "novikov.boris16071976@postgrespro.ru", "phone": "+70015093891"}
0005435332183	491897	0724 518059	VLADIMIR ANTONOV	{"phone": "+70203184851"}
0005435332184	1C1AB2	7085 322576	DMITRIY NIKITIN	{"email": "nikitin-d_14021975@postgrespro.ru", "phone": "+70775898963"}
0005435332185	9AD121	5007 022154	VLADIMIR VOLKOV	{"phone": "+70605209702"}
0005435332186	9AD121	9631 414117	YULIYA MOROZOVA	{"phone": "+70689133514"}
0005435332187	166D38	1857 436156	TAMARA TARASOVA	{"phone": "+70734988092"}
0005435332188	D4A784	3319 345529	YULIYA NIKOLAEVA	{"email": "nikolaeva.y1970@postgrespro.ru", "phone": "+70849830619"}
0005435332189	C969F0	2742 614329	ALEKSANDR BARANOV	{"phone": "+70485111071"}
0005435332190	C969F0	8489 741662	TATYANA VOLKOVA	{"email": "tvolkova25101974@postgrespro.ru", "phone": "+70615623211"}
0005435332191	278F5E	1523 584024	ANTON CHERNOV	{"phone": "+70621388512"}
0005435332192	FC999B	0331 671509	VIKTOR KUZMIN	{"phone": "+70382976119"}
0005435332193	6F694E	6193 700565	NIKOLAY TIMOFEEV	{"email": "timofeevnikolay-18031959@postgrespro.ru", "phone": "+70773236905"}
0005435332194	6F694E	4275 600917	MIKHAIL KAZAKOV	{"email": "kazakov_mikhail101970@postgrespro.ru", "phone": "+70016790755"}
0005435332195	C8E92B	9507 596639	ANDREY FROLOV	{"phone": "+70973617200"}
0005435332196	3450A7	0585 425221	GEORGIY GORBUNOV	{"email": "gorbunov.g_071980@postgrespro.ru", "phone": "+70493618454"}
0005435332197	AB1C0A	0672 617456	ZINAIDA ANISIMOVA	{"email": "anisimova.z11051972@postgrespro.ru", "phone": "+70679207793"}
0005435332198	AB1C0A	3472 686358	GALINA IVANOVA	{"phone": "+70621180213"}
0005435332199	89C917	8949 039033	DMITRIY KUZNECOV	{"phone": "+70013036459"}
0005435332200	183ACB	4055 115653	ELENA ANDREEVA	{"email": "andreeva.elena-1979@postgrespro.ru", "phone": "+70927665472"}
0005435332201	42819F	4291 807767	ALEKSANDR EGOROV	{"email": "egorov.a-061965@postgrespro.ru", "phone": "+70869686024"}
0005435332202	0D18A6	2508 563412	DENIS KUZNECOV	{"email": "denis-kuznecov_16051960@postgrespro.ru", "phone": "+70109490343"}
0005435332203	0D18A6	1635 794273	IRINA KRASNOVA	{"email": "i-krasnova-031981@postgrespro.ru", "phone": "+70096645246"}
0005435332204	4ED192	6324 976918	YURIY KUZMIN	{"email": "kuzmin-yuriy_02091972@postgrespro.ru", "phone": "+70725995388"}
0005435332205	FC9663	3941 369326	ZINAIDA SOKOLOVA	{"email": "sokolova-zinaida.121973@postgrespro.ru", "phone": "+70673286787"}
0005435332206	619896	6491 551480	VLADIMIR SMIRNOV	{"phone": "+70383914814"}
0005435332207	619896	0936 278343	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr1978@postgrespro.ru", "phone": "+70266463504"}
0005435332208	97ED10	0779 211957	NINA KOVALEVA	{"email": "kovaleva.nina13041966@postgrespro.ru", "phone": "+70425497648"}
0005435332209	DB4B18	1369 191622	ALEKSANDR SOKOLOV	{"email": "sokolovaleksandr071971@postgrespro.ru", "phone": "+70091926884"}
0005435332210	B77D87	9443 160674	SERGEY DMITRIEV	{"email": "dmitriev-s-1972@postgrespro.ru", "phone": "+70083013818"}
0005435332211	521EC6	0739 516323	VLADIMIR PETROV	{"phone": "+70378763773"}
0005435332212	38A9CC	4736 876978	ALEKSANDR NOVIKOV	{"email": "a.novikov-28081973@postgrespro.ru", "phone": "+70927257480"}
0005435332213	38A9CC	9724 230297	ANNA TITOVA	{"email": "a.titova_051973@postgrespro.ru", "phone": "+70347985021"}
0005435332214	B98389	1709 617553	YURIY NAZAROV	{"phone": "+70144006597"}
0005435332215	B98389	3639 388866	IRINA ORLOVA	{"email": "irinaorlova.121981@postgrespro.ru", "phone": "+70350995108"}
0005435332216	718BEF	6096 287065	MIKHAIL VLASOV	{"phone": "+70699822865"}
0005435332217	718BEF	5342 372399	VITALIY MOISEEV	{"email": "moiseev.vitaliy-22021975@postgrespro.ru", "phone": "+70130008226"}
0005435332218	2D124B	1443 380223	SERGEY KUZNECOV	{"phone": "+70808515625"}
0005435332219	3FC5B2	7946 609081	ELENA KOROLEVA	{"email": "elena.koroleva1969@postgrespro.ru", "phone": "+70759457621"}
0005435332220	376395	9860 814773	DMITRIY OSIPOV	{"phone": "+70960479162"}
0005435332221	166EA3	2377 445100	ZHANNA SAVELEVA	{"phone": "+70083507393"}
0005435332222	979837	3810 670205	NINA NAZAROVA	{"phone": "+70465722014"}
0005435332223	979837	9838 823779	RIMMA ARKHIPOVA	{"email": "arkhipovarimma.08061972@postgrespro.ru", "phone": "+70199555397"}
0005435332224	3D27FA	1722 677767	VIKTORIYA NIKOLAEVA	{"phone": "+70599193825"}
0005435332225	1E5D89	8848 750370	GRIGORIY PAVLOV	{"email": "pavlov.g101984@postgrespro.ru", "phone": "+70360963669"}
0005435332226	D47152	1772 699454	YURIY EGOROV	{"email": "yuriyegorov1969@postgrespro.ru", "phone": "+70991399809"}
0005435332227	B7C315	9636 966646	ELENA MARTYNOVA	{"email": "martynova.elena.1979@postgrespro.ru", "phone": "+70158501034"}
0005435332228	882880	5471 073496	PELAGEYA TIKHONOVA	{"phone": "+70890458300"}
0005435332229	DBA4AB	9294 438157	ALEKSANDR KUZMIN	{"email": "kuzmin_aleksandr-031973@postgrespro.ru", "phone": "+70408823988"}
0005435332230	65863B	6716 397851	SVETLANA FROLOVA	{"email": "s-frolova-121980@postgrespro.ru", "phone": "+70309076959"}
0005435332231	6718C2	3032 700082	ARTEM FOMIN	{"phone": "+70100457553"}
0005435332232	7B4760	6538 776222	PRASKOVYA SAVELEVA	{"email": "saveleva_praskovya.031971@postgrespro.ru", "phone": "+70867624851"}
0005435332233	6121FD	5329 415518	MARIYA MEDVEDEVA	{"email": "mariya.medvedeva1965@postgrespro.ru", "phone": "+70749519351"}
0005435332234	54172E	2047 486197	VALERIYA MAKSIMOVA	{"email": "valeriyamaksimova.041980@postgrespro.ru", "phone": "+70839867727"}
0005435332235	4D427E	8319 408787	ALEKSEY PETROV	{"phone": "+70874396854"}
0005435332236	27356E	3285 993672	MARIYA MOISEEVA	{"phone": "+70550883894"}
0005435332237	27356E	9889 828511	VERONIKA ZAKHAROVA	{"email": "zakharova-veronika091977@postgrespro.ru", "phone": "+70945710526"}
0005435332238	14A943	2909 980282	VLADIMIR MARTYNOV	{"email": "v_martynov26031982@postgrespro.ru", "phone": "+70831642969"}
0005435332239	14A943	7942 550032	ROMAN AFANASEV	{"email": "romanafanasev_021975@postgrespro.ru", "phone": "+70561311418"}
0005435332240	294D68	9527 291001	ANATOLIY EGOROV	{"email": "a_egorov-06111965@postgrespro.ru", "phone": "+70002320247"}
0005435332241	4B3E3B	6785 784216	ALEKSANDR NOVIKOV	{"phone": "+70985541925"}
0005435332242	53BB19	4523 902521	RAFIK NAZAROV	{"email": "nazarov.rafik_011969@postgrespro.ru", "phone": "+70927098320"}
0005435332243	53BB19	8591 374359	VYACHESLAV SOKOLOV	{"phone": "+70605641645"}
0005435332244	54438A	5200 149316	INNA NAUMOVA	{"phone": "+70217231851"}
0005435332245	331BDB	8541 070457	ANDREY BORISOV	{"phone": "+70879013546"}
0005435332246	966A0B	0382 868464	VASILIY BORISOV	{"email": "v.borisov-051977@postgrespro.ru", "phone": "+70311279262"}
0005435332247	966A0B	4587 390890	SOFYA NIKIFOROVA	{"phone": "+70415455005"}
0005435332248	B59AB4	0964 388518	EMILIYA MASLOVA	{"email": "emiliya_maslova_1985@postgrespro.ru", "phone": "+70521409092"}
0005435332249	18AAC3	6185 716664	ALEKSEY KOROLEV	{"email": "a-korolev011967@postgrespro.ru", "phone": "+70322722005"}
0005435332250	18AAC3	6097 871736	SEMEN MELNIKOV	{"email": "melnikov.s_121963@postgrespro.ru", "phone": "+70775810219"}
0005435332251	18AAC3	8536 596927	ALEKSEY VLASOV	{"phone": "+70213203872"}
0005435332252	A7624A	3044 524653	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin_12091963@postgrespro.ru", "phone": "+70654812207"}
0005435332253	A7624A	5476 880234	VIKTOR FILIPPOV	{"email": "filippov_viktor-1971@postgrespro.ru", "phone": "+70556391525"}
0005435332254	A1624E	3523 933777	VALERIY MAKAROV	{"email": "v_makarov031973@postgrespro.ru", "phone": "+70620221097"}
0005435332255	EDF1FD	4240 958846	GALINA KOZLOVA	{"email": "galina_kozlova.24081966@postgrespro.ru", "phone": "+70411762006"}
0005435332256	967242	2326 724787	KLAVDIYA KRASNOVA	{"phone": "+70206774248"}
0005435332257	B5C825	3163 867716	EKATERINA MAKAROVA	{"email": "ekaterina.makarova-07121976@postgrespro.ru", "phone": "+70906704165"}
0005435332258	B5C825	4596 919084	RIMMA ABRAMOVA	{"phone": "+70483316935"}
0005435332259	47D099	0837 173272	DARYA IVANOVA	{"phone": "+70671345505"}
0005435332260	25E346	9209 747967	VERA KUZNECOVA	{"email": "vera.kuznecova.02091967@postgrespro.ru", "phone": "+70025257165"}
0005435332261	A059A6	2093 173180	ANGELINA NIKIFOROVA	{"phone": "+70541599890"}
0005435332262	233717	2463 960968	OKSANA ANTONOVA	{"phone": "+70951623047"}
0005435332263	233717	7607 806359	NIKOLAY NIKOLAEV	{"email": "nikolaevnikolay_04021970@postgrespro.ru", "phone": "+70852271555"}
0005435332264	ABA2A2	5136 706978	TATYANA LOGINOVA	{"email": "loginova_tatyana081971@postgrespro.ru", "phone": "+70272269232"}
0005435332265	ABA2A2	5633 315718	VLADIMIR FILIPPOV	{"phone": "+70556073945"}
0005435332266	2923BE	4214 445182	MARIYA SIDOROVA	{"email": "sidorova-m011961@postgrespro.ru", "phone": "+70303093473"}
0005435332267	0D0E9F	9255 524278	LYUDMILA RODIONOVA	{"phone": "+70714906105"}
0005435332268	07EB9C	6246 581009	SERGEY DMITRIEV	{"email": "s-dmitriev021968@postgrespro.ru", "phone": "+70267182751"}
0005435332269	E8869D	0273 575125	MARINA NIKIFOROVA	{"phone": "+70482673445"}
0005435332270	E8869D	8926 415493	RAISA NIKOLAEVA	{"email": "r-nikolaeva-1965@postgrespro.ru", "phone": "+70564618193"}
0005435332271	E8869D	7518 522472	ELENA ROMANOVA	{"phone": "+70467732036"}
0005435332272	10C528	8699 534254	NATALYA ZAYCEVA	{"phone": "+70200924683"}
0005435332273	10C528	1944 046613	ANDREY SIDOROV	{"phone": "+70048634754"}
0005435332274	8702E6	0441 307348	ANDREY ABRAMOV	{"phone": "+70550629568"}
0005435332275	8702E6	0084 042005	VIKTOR POPOV	{"email": "viktor-popov101964@postgrespro.ru", "phone": "+70177184192"}
0005435332276	9CED96	4965 806163	ALEVTINA LUKYANOVA	{"phone": "+70945196884"}
0005435332277	9CED96	7669 352314	NATALYA STEPANOVA	{"email": "stepanova_n-1969@postgrespro.ru", "phone": "+70769563810"}
0005435332278	4C5DE1	1442 757318	NATALYA YUDINA	{"email": "yudina_n-1978@postgrespro.ru", "phone": "+70596685761"}
0005435332279	327182	3195 301397	EVGENIY MIRONOV	{"email": "e_mironov_1975@postgrespro.ru", "phone": "+70533055517"}
0005435332280	327182	8799 860028	ALBERT KISELEV	{"phone": "+70716330547"}
0005435332281	B554C7	4828 457149	OLGA POPOVA	{"email": "popova-olga_1974@postgrespro.ru", "phone": "+70592410273"}
0005435332282	B554C7	3460 621330	ELENA POPOVA	{"phone": "+70956797987"}
0005435332283	DC3EF0	3446 831507	NADEZHDA LAZAREVA	{"phone": "+70740536751"}
0005435332284	F39527	8719 043458	VALENTINA MAKAROVA	{"email": "valentina_makarova_07011975@postgrespro.ru", "phone": "+70956047693"}
0005435332285	0D089C	3538 476540	ANAIT TITOVA	{"phone": "+70125575528"}
0005435332286	55CD0A	4748 141572	ELENA RYABOVA	{"phone": "+70971716436"}
0005435332287	2B58A3	9298 029651	VITALIY VLASOV	{"email": "vitaliy_vlasov.1978@postgrespro.ru", "phone": "+70303921002"}
0005435332288	2B58A3	8765 285036	MARIYA SERGEEVA	{"phone": "+70231514321"}
0005435332289	094FB5	9853 632690	ALENA ANDREEVA	{"phone": "+70496844263"}
0005435332290	344EBC	6880 452271	SVETLANA MAKSIMOVA	{"phone": "+70273872485"}
0005435332291	40DE12	9134 409807	MIKHAIL IVANOV	{"email": "mikhail-ivanov_14061979@postgrespro.ru", "phone": "+70154869561"}
0005435332292	40DE12	6491 717190	EVGENIY DENISOV	{"email": "e-denisov-051970@postgrespro.ru", "phone": "+70505487310"}
0005435332293	37E15E	9940 449254	KIRILL SOROKIN	{"email": "ksorokin111978@postgrespro.ru", "phone": "+70532833764"}
0005435332294	37E15E	1718 986626	VLADIMIR FEDOROV	{"phone": "+70332506827"}
0005435332295	2C350E	9233 949755	MATVEY VASILEV	{"phone": "+70393312648"}
0005435332296	DF2456	7004 945189	IVAN KUZNECOV	{"email": "kuznecov_ivan-16101984@postgrespro.ru", "phone": "+70441242588"}
0005435332297	02D30F	8422 680816	ANDREY SEMENOV	{"phone": "+70729918392"}
0005435332298	02D30F	5153 598615	GALINA KALININA	{"phone": "+70850522484"}
0005435332299	9151C7	7403 052773	PETR IVANOV	{"phone": "+70276913542"}
0005435332300	2BFDBE	0085 517352	GEVORG MARTYNOV	{"phone": "+70677241934"}
0005435332301	2FA62F	8897 030191	NINA ZAKHAROVA	{"email": "n_zakharova07011977@postgrespro.ru", "phone": "+70513007274"}
0005435332302	D2528E	7490 364878	IRINA GERASIMOVA	{"phone": "+70459094144"}
0005435332303	C2B374	7731 524437	VLADIMIR NOVIKOV	{"phone": "+70038378268"}
0005435332304	C2B374	5498 426802	VIKTOR KARPOV	{"phone": "+70488668539"}
0005435332305	840D81	9241 131108	EKATERINA TITOVA	{"email": "titova_ekaterina061968@postgrespro.ru", "phone": "+70389579770"}
0005435332306	840D81	0718 385125	ALEKSEY TIMOFEEV	{"email": "timofeev-a_29111973@postgrespro.ru", "phone": "+70793039705"}
0005435332307	ED509F	3335 589273	ANDREY DAVYDOV	{"phone": "+70669695054"}
0005435332308	ED509F	4005 177335	FARIT PETROV	{"email": "petrov-f_20111984@postgrespro.ru", "phone": "+70669395077"}
0005435332309	FC0C57	2095 182164	ANASTASIYA FOMINA	{"email": "fomina-a_111972@postgrespro.ru", "phone": "+70539178894"}
0005435332310	FC0C57	5337 153128	ANDREY MIKHAYLOV	{"email": "mikhaylov.andrey111969@postgrespro.ru", "phone": "+70752413195"}
0005435332311	5AB1C1	1748 284584	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr071979@postgrespro.ru", "phone": "+70075155869"}
0005435332312	5AB1C1	5445 491123	OLGA GERASIMOVA	{"phone": "+70955943172"}
0005435332313	5AB1C1	0912 862654	IVAN ZHUKOV	{"phone": "+70601625627"}
0005435332314	B75549	8725 180110	VYACHESLAV VOLKOV	{"email": "v_volkov-24061979@postgrespro.ru", "phone": "+70398496465"}
0005435332315	B75549	7695 410721	FILIPP ANTONOV	{"phone": "+70643484327"}
0005435332316	D73CA6	9165 695738	ALEKSANDR PETROV	{"phone": "+70175752511"}
0005435332317	D73CA6	8110 233679	VIKTOR ABRAMOV	{"phone": "+70561095308"}
0005435332318	CD6EDB	3639 637515	SERGEY KUZNECOV	{"email": "kuznecovs_031975@postgrespro.ru", "phone": "+70866495223"}
0005435332319	CD6EDB	4740 442049	NATALYA SOLOVEVA	{"email": "soloveva-natalya-21021973@postgrespro.ru", "phone": "+70426091110"}
0005435332320	EF8621	1816 312840	ALEKSANDR KUZNECOV	{"email": "aleksandr-kuznecov.101974@postgrespro.ru", "phone": "+70564593058"}
0005435332321	EF8621	3534 614139	ANASTASIYA PETROVA	{"email": "anastasiya.petrova_041976@postgrespro.ru", "phone": "+70698737179"}
0005435332322	101B68	9112 662001	ALEKSEY NAZAROV	{"phone": "+70482521297"}
0005435332323	BC67A0	6727 690820	ELENA MARTYNOVA	{"phone": "+70600796956"}
0005435332324	3A6B79	8368 541161	TATYANA IVANOVA	{"phone": "+70201992163"}
0005435332325	D167D0	1737 099748	IVAN KUZNECOV	{"email": "kuznecov-ivan041974@postgrespro.ru", "phone": "+70188918710"}
0005435332326	22A60D	7409 373030	MIKHAIL KAZAKOV	{"email": "mikhail-kazakov-1973@postgrespro.ru", "phone": "+70010182307"}
0005435332327	22A60D	4290 286666	VASILIY ILIN	{"email": "vilin.081975@postgrespro.ru", "phone": "+70734466601"}
0005435332328	88E230	7477 938792	GEORGIY NAUMOV	{"phone": "+70360298458"}
0005435332329	99BE5C	6789 058895	VLADIMIR OSIPOV	{"email": "osipov-vladimir-041969@postgrespro.ru", "phone": "+70725941086"}
0005435332330	A9F5C2	7342 849750	STANISLAV MELNIKOV	{"phone": "+70851514268"}
0005435332331	E04651	2072 029084	EKATERINA TIMOFEEVA	{"email": "timofeeva_ekaterina1979@postgrespro.ru", "phone": "+70448143923"}
0005435332332	83CA20	8230 485356	IRINA STEPANOVA	{"phone": "+70755095797"}
0005435332333	9696AF	5331 932847	VYACHESLAV VOLKOV	{"email": "volkovvyacheslav-021973@postgrespro.ru", "phone": "+70727440648"}
0005435332334	9696AF	4292 269681	IRINA PAVLOVA	{"email": "pavlovai_071969@postgrespro.ru", "phone": "+70984179244"}
0005435332335	BA6B84	1690 793502	NINA ZHURAVLEVA	{"phone": "+70029863187"}
0005435332336	BA6B84	3298 953731	LYUDMILA NIKITINA	{"phone": "+70108099250"}
0005435332337	E51582	4076 591693	NATALYA DAVYDOVA	{"phone": "+70083946940"}
0005435332338	E51582	7655 248203	NIKOLAY KOZLOV	{"email": "nikolay_kozlov-14021971@postgrespro.ru", "phone": "+70076766843"}
0005435332339	2CE07A	6393 186745	NATALYA SCHERBAKOVA	{"phone": "+70125479106"}
0005435332340	5BE0A3	1900 934266	EVGENIY MAKAROV	{"phone": "+70099107790"}
0005435332341	5BE0A3	2250 509528	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova-1977@postgrespro.ru", "phone": "+70715873158"}
0005435332342	793062	6501 451351	TATYANA KONOVALOVA	{"email": "konovalova-t.081986@postgrespro.ru", "phone": "+70691108615"}
0005435332343	793062	9954 977027	LYUBOV TIKHONOVA	{"email": "ltikhonova-071974@postgrespro.ru", "phone": "+70750772627"}
0005435332344	793062	3239 007593	NIKOLAY KISELEV	{"email": "nikolay.kiselev.1974@postgrespro.ru", "phone": "+70353670875"}
0005435332345	D65207	9645 564881	IRINA BELYAEVA	{"email": "belyaevairina_1973@postgrespro.ru", "phone": "+70772314600"}
0005435332346	B59D85	2105 657014	MIKHAIL KUZMIN	{"email": "kuzminm.03061974@postgrespro.ru", "phone": "+70437996365"}
0005435332347	608267	8228 218751	ZOYA SOROKINA	{"phone": "+70258804886"}
0005435332348	2AEF18	5386 800849	NIKOLAY PAVLOV	{"phone": "+70892741637"}
0005435332349	B314E8	4452 116117	MIKHAIL PETROV	{"phone": "+70152896659"}
0005435332350	B314E8	1470 479182	NINA ZHUKOVA	{"email": "n_zhukova.081975@postgrespro.ru", "phone": "+70657296900"}
0005435332351	448E0E	5064 033520	ALEKSEY GUSEV	{"phone": "+70529386826"}
0005435332352	AEEA51	4622 873332	SERGEY MAKSIMOV	{"email": "s.maksimov-121976@postgrespro.ru", "phone": "+70801496194"}
0005435332353	AEEA51	5238 231969	NIKOLAY MOISEEV	{"email": "moiseevnikolay121972@postgrespro.ru", "phone": "+70428291426"}
0005435332354	C99982	6903 732133	EVGENIY ALEKSEEV	{"phone": "+70263341672"}
0005435332355	B3C8D6	8048 635119	NIKOLAY FILIPPOV	{"phone": "+70749735547"}
0005435332356	43A92A	0437 474932	YULIYA VLASOVA	{"phone": "+70991773552"}
0005435332357	43A92A	1905 413302	NATALYA PAVLOVA	{"email": "pavlova-natalya_1980@postgrespro.ru", "phone": "+70720704976"}
0005435332358	966297	5749 469613	ANASTASIYA YAKOVLEVA	{"email": "yakovlevaa-18021974@postgrespro.ru", "phone": "+70002602676"}
0005435332359	DED3A6	6107 321790	EKATERINA DENISOVA	{"email": "edenisova_091983@postgrespro.ru", "phone": "+70132038672"}
0005435332360	E27641	9425 827611	RUSLAN SMIRNOV	{"email": "smirnov_ruslan.1983@postgrespro.ru", "phone": "+70251242539"}
0005435332361	E27641	3820 492845	TAMARA NESTEROVA	{"phone": "+70884133828"}
0005435332362	C3A93B	2078 542526	IGOR BARANOV	{"phone": "+70860464353"}
0005435332363	E4C2C2	4653 422109	ELENA MALYSHEVA	{"phone": "+70819891475"}
0005435332364	E4C2C2	7219 045172	ALEKSEY VOLKOV	{"phone": "+70134271962"}
0005435332365	91DC41	6973 516123	OKSANA KOROLEVA	{"email": "koroleva.o101981@postgrespro.ru", "phone": "+70035378876"}
0005435332366	F0701F	5796 274504	IRINA MAKAROVA	{"email": "i.makarova.081971@postgrespro.ru", "phone": "+70553166675"}
0005435332367	4A0E14	8580 283314	GALINA GAVRILOVA	{"email": "gavrilova_galina27051963@postgrespro.ru", "phone": "+70586486713"}
0005435332368	4F3FC1	9008 595314	ILONA ZAYCEVA	{"email": "zayceva-i15091978@postgrespro.ru", "phone": "+70015589660"}
0005435332369	4F3FC1	2526 750781	RUSLAN NIKITIN	{"phone": "+70897002699"}
0005435332370	B9A5AB	1941 537446	ANTON GUSEV	{"email": "anton.gusev1988@postgrespro.ru", "phone": "+70409614881"}
0005435332371	481DDA	1987 483276	ARTEM BARANOV	{"email": "baranov.a_101973@postgrespro.ru", "phone": "+70878143376"}
0005435332372	481DDA	7196 248849	GULNAZ NESTEROVA	{"email": "nesterova.g-1979@postgrespro.ru", "phone": "+70282059833"}
0005435332373	481DDA	9545 935034	ANASTASIYA OSIPOVA	{"phone": "+70226120492"}
0005435332374	88E88B	1360 348883	OLGA FILATOVA	{"phone": "+70161625633"}
0005435332375	88E88B	7626 605746	IGOR TIKHONOV	{"email": "tikhonov-igor1973@postgrespro.ru", "phone": "+70469897689"}
0005435332376	FBE709	9040 864662	ALEKSEY SIDOROV	{"phone": "+70473973420"}
0005435332377	FBE709	8325 790147	OLGA TARASOVA	{"email": "tarasovao071978@postgrespro.ru", "phone": "+70445380731"}
0005435332378	276D58	3247 648431	IVAN VASILEV	{"email": "vasilev-ivan.22111974@postgrespro.ru", "phone": "+70259227398"}
0005435332379	276D58	8398 684243	ANNA YUDINA	{"phone": "+70673579188"}
0005435332380	276D58	7366 027671	SERGEY VASILEV	{"phone": "+70487154766"}
0005435332381	F6DB00	8168 731568	ELENA POPOVA	{"email": "popova-elena13081969@postgrespro.ru", "phone": "+70871047750"}
0005435332382	F6DB00	9088 505643	SERGEY FEDOROV	{"email": "sergey.fedorov10081969@postgrespro.ru", "phone": "+70812087261"}
0005435332383	85AB2F	0986 039541	TATYANA IVANOVA	{"phone": "+70228576603"}
0005435332384	85AB2F	3288 250294	LYUBOV KULIKOVA	{"email": "lyubov_kulikova_021968@postgrespro.ru", "phone": "+70613268702"}
0005435332385	EDE402	1569 162246	MARIYA NESTEROVA	{"email": "nesterovamariya.13021969@postgrespro.ru", "phone": "+70168714653"}
0005435332386	EDE402	9542 874897	MAKSIM NAUMOV	{"email": "maksim.naumov_1974@postgrespro.ru", "phone": "+70815055345"}
0005435332387	92B24A	8269 546002	ALEKSEY BORISOV	{"email": "borisovaleksey_01041985@postgrespro.ru", "phone": "+70458749253"}
0005435332388	ACE8A4	6823 533963	IRINA SEMENOVA	{"email": "semenova-irina-22041970@postgrespro.ru", "phone": "+70676141428"}
0005435332389	597636	7101 856117	TATYANA KOLESNIKOVA	{"phone": "+70968132670"}
0005435332390	597636	7837 653872	MAKSIM KOZLOV	{"phone": "+70480003021"}
0005435332391	89E672	6961 518451	TAMARA VASILEVA	{"email": "tamaravasileva-1972@postgrespro.ru", "phone": "+70694010685"}
0005435332392	FCE525	3336 214760	EGOR IVANOV	{"email": "ivanov-e_071974@postgrespro.ru", "phone": "+70545095318"}
0005435332393	FCE525	0090 702859	EVGENIY SOKOLOV	{"email": "e-sokolov_091968@postgrespro.ru", "phone": "+70162426648"}
0005435332394	67CE64	0707 849492	MARIYA PAVLOVA	{"phone": "+70989199984"}
0005435332395	735D32	3478 523724	NADEZHDA SEMENOVA	{"phone": "+70032083446"}
0005435332396	735D32	0575 386868	ELENA VOROBEVA	{"email": "elenavorobeva-121972@postgrespro.ru", "phone": "+70023769766"}
0005435332397	77D0D2	1869 648555	EVGENIY KARPOV	{"phone": "+70414699604"}
0005435332398	1EC550	8295 120149	EKATERINA POPOVA	{"phone": "+70735771489"}
0005435332399	978419	7791 708421	ROMAN NOVIKOV	{"phone": "+70857510535"}
0005435332400	6D2D1B	4704 141574	KONSTANTIN ZAKHAROV	{"phone": "+70233331323"}
0005435332401	8A48BC	3326 413749	MAKSIM NIKOLAEV	{"email": "nikolaevm_29051982@postgrespro.ru", "phone": "+70580956152"}
0005435332402	8A48BC	9476 728882	NATALYA SEMENOVA	{"phone": "+70905556057"}
0005435332403	AB6198	7087 944148	DMITRIY KAZAKOV	{"phone": "+70182597743"}
0005435332404	F1B30F	1480 683974	MARYAM LEBEDEVA	{"phone": "+70874136054"}
0005435332405	0EE897	5900 829620	NADEZHDA KALININA	{"phone": "+70883428694"}
0005435332406	0F7648	9724 331196	LIDIYA KUZMINA	{"phone": "+70624957195"}
0005435332407	F42944	5693 080467	GEORGIY KOROLEV	{"phone": "+70939520483"}
0005435332408	C047BE	7969 501604	RIFAT BELOV	{"email": "belov.rifat_13061974@postgrespro.ru", "phone": "+70918891688"}
0005435332409	ED798C	2289 838657	VIKTOR ORLOV	{"email": "orlovv061962@postgrespro.ru", "phone": "+70123307198"}
0005435332410	770139	7773 120714	SERGEY PETROV	{"email": "petrov.sergey-1959@postgrespro.ru", "phone": "+70327813786"}
0005435332411	770139	7122 213470	RAFAEL TARASOV	{"email": "r-tarasov-051975@postgrespro.ru", "phone": "+70981529654"}
0005435332412	B51E40	9285 400939	LIDIYA SEMENOVA	{"email": "semenovalidiya09121972@postgrespro.ru", "phone": "+70110985874"}
0005435332413	578C6A	1362 087641	VLADISLAV KUZNECOV	{"phone": "+70098810704"}
0005435332414	9250F1	0410 756368	TATYANA KUZMINA	{"email": "kuzmina_t-05101969@postgrespro.ru", "phone": "+70942752846"}
0005435332415	9250F1	6103 510730	VASILIY DENISOV	{"email": "denisov-vasiliy.091958@postgrespro.ru", "phone": "+70582126454"}
0005435332416	98D67E	1755 428888	ALEKSEY POPOV	{"phone": "+70386598130"}
0005435332417	98D67E	9572 353562	LYUBOV GERASIMOVA	{"email": "lyubovgerasimova031970@postgrespro.ru", "phone": "+70707204430"}
0005435332418	C82306	5364 525343	TATYANA NAUMOVA	{"email": "naumovat_1975@postgrespro.ru", "phone": "+70868519375"}
0005435332419	A5016F	8723 201998	BORIS SMIRNOV	{"email": "boris_smirnov.121970@postgrespro.ru", "phone": "+70190414810"}
0005435332420	44BE97	8365 523832	GENNADIY KRASNOV	{"phone": "+70497585672"}
0005435332421	E9C173	7589 888487	OLGA EFIMOVA	{"phone": "+70095670237"}
0005435332422	42FDD6	9859 795160	VYACHESLAV GORBUNOV	{"phone": "+70206846940"}
0005435332423	42FDD6	3432 573303	VALENTINA NIKOLAEVA	{"email": "vnikolaeva_1957@postgrespro.ru", "phone": "+70845694280"}
0005435332424	E1D7AE	0311 178620	ANATOLIY ANDREEV	{"phone": "+70891105742"}
0005435332425	465551	1662 067515	SVETLANA ZAKHAROVA	{"phone": "+70971136249"}
0005435332426	9F2B2B	3348 246787	VALENTINA KOZLOVA	{"phone": "+70329315518"}
0005435332427	30978B	1347 492156	LYUBOV KUZNECOVA	{"email": "lyubov_kuznecova21051967@postgrespro.ru", "phone": "+70173977891"}
0005435332428	890D3B	6231 051457	VLADIMIR MAKSIMOV	{"phone": "+70561816625"}
0005435332429	890D3B	6803 612152	VLADIMIR FEDOROV	{"email": "fedorov.vladimir-02071980@postgrespro.ru", "phone": "+70543867644"}
0005435332430	80EC64	9369 438858	DANIIL NIKOLAEV	{"email": "d_nikolaev_1974@postgrespro.ru", "phone": "+70816659687"}
0005435332431	73A054	7057 895959	ANATOLIY POPOV	{"phone": "+70740263935"}
0005435332432	F4A26A	4176 104461	ANTONINA SOKOLOVA	{"email": "sokolova-a_26051975@postgrespro.ru", "phone": "+70439760524"}
0005435332433	5C4F1B	4757 947542	GULNAZ ANDREEVA	{"phone": "+70050381394"}
0005435332434	5C4F1B	5602 385982	OLEG FILIPPOV	{"email": "oleg_filippov.1965@postgrespro.ru", "phone": "+70786721006"}
0005435332435	D4D2BD	6539 993017	TATYANA SEMENOVA	{"phone": "+70685707448"}
0005435332436	0AD608	1004 159734	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-081983@postgrespro.ru", "phone": "+70453648665"}
0005435332437	0AD608	2302 164204	SVETLANA IVANOVA	{"email": "s.ivanova02031976@postgrespro.ru", "phone": "+70797379346"}
0005435332438	56AA85	0767 074143	ELENA POPOVA	{"phone": "+70379806566"}
0005435332439	7518FA	6364 943292	LYUBOV KUZNECOVA	{"phone": "+70954836717"}
0005435332440	1B6119	8843 135129	SOFIYA BARANOVA	{"email": "baranova-s09021970@postgrespro.ru", "phone": "+70293189560"}
0005435332441	10E99B	9846 826652	VERA FEDOROVA	{"email": "vfedorova111984@postgrespro.ru", "phone": "+70897255124"}
0005435332442	28A2F7	6135 376768	DANIS CHERNOV	{"email": "d_chernov.03091977@postgrespro.ru", "phone": "+70218860720"}
0005435332443	AA6F12	4542 766517	SVETLANA FROLOVA	{"phone": "+70785740299"}
0005435332444	AA6F12	1669 599843	VLADIMIR IVANOV	{"email": "ivanov.vladimir-081977@postgrespro.ru", "phone": "+70705631326"}
0005435332445	3ABDDB	8596 872094	RAISA KRASNOVA	{"email": "raisa-krasnova.28021965@postgrespro.ru", "phone": "+70724421743"}
0005435332446	3ABDDB	5061 802608	ALEKSANDR KUZNECOV	{"phone": "+70636645866"}
0005435332447	51916F	6023 467119	ANNA BORISOVA	{"email": "a-borisova_1962@postgrespro.ru", "phone": "+70278496466"}
0005435332448	6BBDCC	3800 651123	KIRILL ANTONOV	{"phone": "+70707935200"}
0005435332449	F6C26A	7502 386567	LIDIYA KARPOVA	{"email": "l.karpova-1982@postgrespro.ru", "phone": "+70673909683"}
0005435332450	F6C26A	0784 938903	ANATOLIY SEMENOV	{"email": "semenov-a-1960@postgrespro.ru", "phone": "+70411076109"}
0005435332451	E57C27	6197 433958	SVETLANA KARPOVA	{"phone": "+70683799429"}
0005435332452	E57C27	8281 706937	IVAN KUZMIN	{"phone": "+70787471479"}
0005435332453	4559DD	7033 529752	IRINA MASLOVA	{"phone": "+70491632317"}
0005435332454	4559DD	0934 608368	VERONIKA SEMENOVA	{"email": "veronika.semenova.061988@postgrespro.ru", "phone": "+70578448986"}
0005435332455	B467FD	1337 542176	NIKITA STEPANOV	{"email": "n_stepanov-06021973@postgrespro.ru", "phone": "+70372634002"}
0005435332456	291A08	2834 625374	ANDREY DENISOV	{"phone": "+70531400487"}
0005435332457	291A08	8004 873174	ALEKSANDRA KULIKOVA	{"phone": "+70163563091"}
0005435332458	D2FA00	3748 761668	ANDREY EGOROV	{"email": "egorov.a26071966@postgrespro.ru", "phone": "+70792409905"}
0005435332459	00F555	1353 337681	NIKOLAY MAKAROV	{"phone": "+70936819978"}
0005435332460	00F555	1593 763981	STEPAN ROMANOV	{"phone": "+70968818834"}
0005435332461	F7E5A1	6908 375942	VERA RYABOVA	{"phone": "+70625659130"}
0005435332462	DEDD39	5908 256391	IRINA PETROVA	{"email": "irinapetrova_1976@postgrespro.ru", "phone": "+70125935945"}
0005435332463	0DCA69	0252 797481	SERGEY PETROV	{"phone": "+70362107921"}
0005435332464	CF4E5D	0653 599385	NATALYA SEMENOVA	{"email": "semenova.n_01031974@postgrespro.ru", "phone": "+70346298506"}
0005435332465	5D1D6E	3433 162208	ANNA BELOVA	{"phone": "+70272129990"}
0005435332466	118661	0332 589264	ALEVTINA ZHUKOVA	{"email": "zhukova_a1971@postgrespro.ru", "phone": "+70791476816"}
0005435332467	3758FA	5255 347488	NATALYA MIKHAYLOVA	{"phone": "+70195162726"}
0005435332468	40D700	0238 237813	SERGEY KUZNECOV	{"email": "kuznecovsergey26021961@postgrespro.ru", "phone": "+70972015629"}
0005435332469	40D700	2546 882751	ALEKSEY SCHERBAKOV	{"email": "aleksey.scherbakov-26111977@postgrespro.ru", "phone": "+70363600422"}
0005435332470	D310CF	2214 210185	VERA IVANOVA	{"email": "ivanova.vera13011962@postgrespro.ru", "phone": "+70213255434"}
0005435332471	D310CF	6752 216994	VIKTORIYA SMIRNOVA	{"email": "viktoriya.smirnova.09051972@postgrespro.ru", "phone": "+70278141814"}
0005435332472	58357E	1743 124955	SVETLANA SMIRNOVA	{"phone": "+70098504911"}
0005435332473	D37B29	1914 887058	ANNA IVANOVA	{"phone": "+70139003051"}
0005435332474	D37B29	1292 387242	TATYANA AKIMOVA	{"phone": "+70298174879"}
0005435332475	D37B29	7922 929674	EVGENIY KRASNOV	{"email": "evgeniy.krasnov_12011977@postgrespro.ru", "phone": "+70903194267"}
0005435332476	108DF4	7220 246873	KSENIYA ANDREEVA	{"phone": "+70156027994"}
0005435332477	325EE2	8930 757405	LYUDMILA ANDREEVA	{"email": "l_andreeva_1975@postgrespro.ru", "phone": "+70972415801"}
0005435332478	325EE2	8813 710725	IVAN SOROKIN	{"email": "sorokin.ivan_15091963@postgrespro.ru", "phone": "+70600492098"}
0005435332479	C7F0C6	7006 139027	ELLA FILIPPOVA	{"phone": "+70249930902"}
0005435332480	C7F0C6	6279 514121	MARIYA ABRAMOVA	{"phone": "+70012921530"}
0005435332481	B179EA	6914 835080	BULAT ZAKHAROV	{"phone": "+70006622936"}
0005435332482	225817	6707 329116	ANATOLIY ZAYCEV	{"email": "zaycevanatoliy-1971@postgrespro.ru", "phone": "+70571065581"}
0005435332483	225817	1108 216932	RAISA ANISIMOVA	{"phone": "+70389738070"}
0005435332484	634660	5422 267148	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-011970@postgrespro.ru", "phone": "+70165263836"}
0005435332485	634660	3830 374024	SEMEN MAKAROV	{"phone": "+70832214250"}
0005435332486	193700	2324 925100	NATALYA PAVLOVA	{"email": "pavlova.natalya.091985@postgrespro.ru", "phone": "+70393337757"}
0005435332487	92732F	0536 016512	ANNA IVANOVA	{"phone": "+70153948285"}
0005435332488	9133AE	7665 707464	VLADIMIR IVANOV	{"email": "vivanov.121971@postgrespro.ru", "phone": "+70841132186"}
0005435332489	9133AE	2879 155227	MIKHAIL NIKITIN	{"phone": "+70854848033"}
0005435332490	68FD85	3731 710888	GALINA ALEKSEEVA	{"phone": "+70732335471"}
0005435332491	68FD85	5271 539316	ALEKSANDR ROMANOV	{"phone": "+70724332877"}
0005435332492	68FD85	2644 468175	EVGENIY ZHUKOV	{"email": "zhukov_e.071965@postgrespro.ru", "phone": "+70458290550"}
0005435332493	68FD85	8305 607586	IVAN KAZAKOV	{"phone": "+70829132970"}
0005435332494	07621B	1257 839490	TATYANA VASILEVA	{"phone": "+70868753568"}
0005435332495	8F058C	6388 799577	EKATERINA ANDREEVA	{"email": "andreeva_e.1978@postgrespro.ru", "phone": "+70350790436"}
0005435332496	89C3A3	1599 523767	ZOYA KARPOVA	{"email": "karpovazoya-1971@postgrespro.ru", "phone": "+70644479748"}
0005435332497	408E9C	8522 453179	ANTONINA RYABOVA	{"email": "ryabova.antonina_14031974@postgrespro.ru", "phone": "+70468544277"}
0005435332498	292319	2021 759068	INNA YUDINA	{"email": "yudina_i-1979@postgrespro.ru", "phone": "+70307344425"}
0005435332499	ED5616	6120 052845	ELENA FROLOVA	{"phone": "+70060046989"}
0005435332500	4B053F	6545 499744	ARTEM TIKHONOV	{"phone": "+70762940306"}
0005435332501	4B053F	5874 741795	OLGA FILATOVA	{"email": "filatova.o04031983@postgrespro.ru", "phone": "+70013791861"}
0005435332502	4E63F3	6259 085367	ALLA SIDOROVA	{"email": "sidorova.a-081972@postgrespro.ru", "phone": "+70406082750"}
0005435332503	4E63F3	5551 031224	ANDREY PAVLOV	{"phone": "+70291780614"}
0005435332504	5D5112	7898 400289	VLADIMIR TARASOV	{"email": "tarasov.v.041971@postgrespro.ru", "phone": "+70793334656"}
0005435332505	5D5112	8037 314110	SERGEY SIDOROV	{"email": "s.sidorov-1968@postgrespro.ru", "phone": "+70136587042"}
0005435332506	D1C73D	5654 270206	ALEKSEY ISAEV	{"phone": "+70315087079"}
0005435332507	5A5474	3648 731664	LARISA ANDREEVA	{"email": "l_andreeva.1974@postgrespro.ru", "phone": "+70182763561"}
0005435332508	9EAB1C	2819 728922	YULIYA MELNIKOVA	{"phone": "+70563523131"}
0005435332509	9EAB1C	3414 899259	VLADISLAV BONDARENKO	{"phone": "+70132845338"}
0005435332510	9EAB1C	8237 251977	VALENTINA LUKYANOVA	{"phone": "+70075198951"}
0005435332511	AEFE33	1597 588467	EVGENIY PAVLOV	{"phone": "+70300947375"}
0005435332512	09B077	8383 575045	VALENTINA SIDOROVA	{"phone": "+70238923712"}
0005435332513	09B077	4522 021584	ANNA POPOVA	{"email": "anna.popova29061966@postgrespro.ru", "phone": "+70195816762"}
0005435332514	09B077	8124 537691	SERGEY SCHERBAKOV	{"phone": "+70989295605"}
0005435332515	55DFBD	1966 863443	VIKTOR KUZMIN	{"phone": "+70935521450"}
0005435332516	B937C6	9919 026678	DMITRIY GUSEV	{"phone": "+70138780696"}
0005435332517	270452	7583 510678	VLADIMIR SCHERBAKOV	{"phone": "+70139186765"}
0005435332518	8A020C	1706 767075	SERGEY DMITRIEV	{"phone": "+70455568228"}
0005435332519	3A0420	0495 503119	IRINA LOGINOVA	{"phone": "+70486122857"}
0005435332520	3A0420	0033 850175	ALEKSANDRA FADEEVA	{"phone": "+70093942629"}
0005435332521	3A0420	4686 663720	DARYA PETROVA	{"phone": "+70496994311"}
0005435332522	A50788	7192 606517	DENIS ZHUKOV	{"phone": "+70557475220"}
0005435332523	A50788	9229 667738	EVGENIY ZAYCEV	{"phone": "+70666466466"}
0005435332524	8640D0	2754 982156	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr_061969@postgrespro.ru", "phone": "+70514216761"}
0005435332525	8640D0	6903 615942	MAKSIM ANTONOV	{"phone": "+70038743820"}
0005435332526	BB7663	2760 174377	KRISTINA KUZNECOVA	{"phone": "+70579698915"}
0005435332527	E8BE42	1271 487220	ANATOLIY MAKAROV	{"phone": "+70449372745"}
0005435332528	E6C038	9249 237415	MAKSIM KRASNOV	{"phone": "+70800533374"}
0005435332529	A67BFC	0602 282741	ALENA MAKAROVA	{"email": "makarova.alena-021966@postgrespro.ru", "phone": "+70384293511"}
0005435332530	A67BFC	6274 455563	ANATOLIY KAZAKOV	{"phone": "+70523471151"}
0005435332531	387652	8144 450178	SERGEY SOROKIN	{"email": "sorokin.s031965@postgrespro.ru", "phone": "+70030665458"}
0005435332532	803077	7944 674323	OLEG KUZNECOV	{"email": "kuznecov_oleg111963@postgrespro.ru", "phone": "+70726176427"}
0005435332533	803077	3296 860589	IVAN PETROV	{"phone": "+70642310731"}
0005435332534	803077	7298 397503	RAISA TROFIMOVA	{"email": "rtrofimova1976@postgrespro.ru", "phone": "+70771277247"}
0005435332535	488A0B	5838 593896	ANDREY ISAEV	{"email": "a.isaev.061975@postgrespro.ru", "phone": "+70711346971"}
0005435332536	4CC9CA	7667 100149	MARIYA FEDOROVA	{"email": "fedorova.m1978@postgrespro.ru", "phone": "+70373661105"}
0005435332537	047523	3030 107547	OLGA BOGDANOVA	{"phone": "+70525597666"}
0005435332538	283006	9040 812596	VALENTIN ZAYCEV	{"email": "zaycevv1971@postgrespro.ru", "phone": "+70447461789"}
0005435332539	F64C46	4933 140034	ANDREY IVANOV	{"phone": "+70587381341"}
0005435332540	F64C46	5358 694259	ANNA KISELEVA	{"phone": "+70831921752"}
0005435332541	66ADE2	5295 760318	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.1970@postgrespro.ru", "phone": "+70559778617"}
0005435332542	43EF25	0387 191021	LYUDMILA MOROZOVA	{"phone": "+70071635403"}
0005435332543	43EF25	8600 223859	ALEKSANDR VOLKOV	{"phone": "+70170150975"}
0005435332544	09F84A	6219 262557	VASILIY NOVIKOV	{"phone": "+70655570470"}
0005435332545	68623A	4560 874779	MAKSIM MOISEEV	{"email": "maksim-moiseev-1976@postgrespro.ru", "phone": "+70840350673"}
0005435332546	85E85E	8250 243269	YANA KISELEVA	{"email": "y.kiseleva.121976@postgrespro.ru", "phone": "+70616413124"}
0005435332547	55D4E7	5675 673364	SVETLANA BELOVA	{"phone": "+70215590347"}
0005435332548	55D4E7	8968 749563	LYUDMILA MIRONOVA	{"phone": "+70488906443"}
0005435332549	471173	4713 667487	EVGENIY MELNIKOV	{"email": "melnikov.evgeniy-15121968@postgrespro.ru", "phone": "+70500001924"}
0005435332550	D9C1BE	8116 295542	VLADIMIR VOROBEV	{"phone": "+70807808273"}
0005435332551	F0A1C7	5552 975778	SVETLANA FILIPPOVA	{"email": "filippova.s1971@postgrespro.ru", "phone": "+70373223093"}
0005435332552	2FBCDD	7423 335259	GULNARA IVANOVA	{"phone": "+70097708080"}
0005435332553	23E209	5408 524095	VLADIMIR VASILEV	{"phone": "+70067984198"}
0005435332554	23E209	6044 773951	VALENTINA ZOTOVA	{"email": "valentinazotova.1971@postgrespro.ru", "phone": "+70625818175"}
0005435332555	5AEC95	6804 017503	ALEKSANDR ZAYCEV	{"phone": "+70144170803"}
0005435332556	288BE0	6837 319046	ALBINA SOKOLOVA	{"email": "albina_sokolova_1975@postgrespro.ru", "phone": "+70179338201"}
0005435332557	484642	4513 853069	ELENA SCHERBAKOVA	{"phone": "+70280439534"}
0005435332558	F0BC15	3861 050979	VASILIY MOROZOV	{"email": "morozov_v1973@postgrespro.ru", "phone": "+70731995234"}
0005435332559	8894FE	4273 329399	SVETLANA IVANOVA	{"phone": "+70477601343"}
0005435332560	A8BB94	4452 170620	VERONIKA SAVELEVA	{"email": "savelevav_17081972@postgrespro.ru", "phone": "+70612726892"}
0005435332561	A8BB94	0029 861795	ALEKSEY GUSEV	{"email": "a_gusev31051965@postgrespro.ru", "phone": "+70665113554"}
0005435332562	B733B0	9372 422961	ELIZAVETA KOZLOVA	{"phone": "+70527071195"}
0005435332563	B733B0	9928 237555	KSENIYA AFANASEVA	{"email": "afanaseva-kseniya121970@postgrespro.ru", "phone": "+70724608228"}
0005435332564	031C6B	2018 226972	IRINA PAVLOVA	{"email": "pavlova-i_1982@postgrespro.ru", "phone": "+70875633279"}
0005435332565	031C6B	8866 505080	SERGEY STEPANOV	{"email": "stepanovs27071980@postgrespro.ru", "phone": "+70048663543"}
0005435332566	031C6B	0471 759242	GALINA NIKOLAEVA	{"phone": "+70028334577"}
0005435332567	031C6B	0055 733785	ALEKSANDR BARANOV	{"email": "baranov-a1964@postgrespro.ru", "phone": "+70155117161"}
0005435332568	46FDFC	6406 488347	ELENA BORISOVA	{"phone": "+70026606486"}
0005435332569	EB053A	4731 704191	EKATERINA ISAEVA	{"email": "e_isaeva.28081960@postgrespro.ru", "phone": "+70953025189"}
0005435332570	EB053A	6505 874489	ANASTASIYA SMIRNOVA	{"email": "a-smirnova.25021963@postgrespro.ru", "phone": "+70643883890"}
0005435332571	182465	2601 650831	MAKSIM KUZNECOV	{"phone": "+70173041735"}
0005435332572	95C549	9840 823453	VYACHESLAV SEMENOV	{"email": "semenov-vyacheslav_1975@postgrespro.ru", "phone": "+70454709165"}
0005435332573	95C549	1785 533673	EKATERINA FROLOVA	{"email": "ekaterinafrolova_041981@postgrespro.ru", "phone": "+70637132068"}
0005435332574	E99046	5256 588012	MARINA BORISOVA	{"phone": "+70703208825"}
0005435332575	BEB6C6	2144 611715	RAISA ZAYCEVA	{"email": "zayceva.raisa_1968@postgrespro.ru", "phone": "+70899232651"}
0005435332576	BEB6C6	7272 375979	LYUDMILA GUSEVA	{"email": "gusevalyudmila1971@postgrespro.ru", "phone": "+70677881882"}
0005435332577	BEB6C6	6823 035674	LYUBOV ANDREEVA	{"email": "andreeva.lyubov_091974@postgrespro.ru", "phone": "+70822522028"}
0005435332578	075AAB	0021 182592	ALESYA LEBEDEVA	{"phone": "+70456942081"}
0005435332579	075AAB	9058 106622	ANDREY TIKHONOV	{"email": "andreytikhonov1977@postgrespro.ru", "phone": "+70865096772"}
0005435332580	CD6B04	8096 055586	VIKTOR MEDVEDEV	{"phone": "+70991136331"}
0005435332581	CD6B04	0863 265402	ALEKSANDR SIDOROV	{"phone": "+70928702733"}
0005435332582	5FDFBA	1836 737299	MIKHAIL ZAKHAROV	{"email": "mikhail-zakharov.061975@postgrespro.ru", "phone": "+70775749405"}
0005435332583	5FDFBA	9209 931140	VALENTINA RYABOVA	{"email": "vryabova1975@postgrespro.ru", "phone": "+70846595746"}
0005435332584	5FDFBA	5021 192179	RUSLAN MARTYNOV	{"email": "martynov_ruslan17121968@postgrespro.ru", "phone": "+70114314058"}
0005435332585	709921	5838 869943	ELENA SERGEEVA	{"email": "sergeevaelena-15081971@postgrespro.ru", "phone": "+70948301029"}
0005435332586	2FB2A4	9670 346518	VERA VOLKOVA	{"email": "volkova.vera1979@postgrespro.ru", "phone": "+70447968477"}
0005435332587	CD67B4	6528 049937	RUSLAN ZAKHAROV	{"email": "zakharovr_081967@postgrespro.ru", "phone": "+70460629554"}
0005435332588	CD67B4	0084 130773	ANNA SERGEEVA	{"phone": "+70602832237"}
0005435332589	CD67B4	4154 579303	TATYANA KUZNECOVA	{"phone": "+70518001525"}
0005435332590	498046	2091 154044	DMITRIY ANTONOV	{"phone": "+70738848453"}
0005435332591	59B97F	0179 224092	ALENA MAKAROVA	{"email": "makarova.alena.1968@postgrespro.ru", "phone": "+70651624868"}
0005435332592	59B97F	6105 641618	MIKHAIL IVANOV	{"email": "ivanovmikhail15081981@postgrespro.ru", "phone": "+70230531628"}
0005435332593	22026A	1088 059260	EVGENIYA KUZNECOVA	{"phone": "+70048434259"}
0005435332594	A872D5	8355 546872	EVGENIY KULIKOV	{"email": "evgeniykulikov.04011961@postgrespro.ru", "phone": "+70825425412"}
0005435332595	A872D5	3380 624635	MAKAR MAKSIMOV	{"email": "maksimov-m031967@postgrespro.ru", "phone": "+70789622782"}
0005435332596	61BF9C	5826 534944	EKATERINA ANDREEVA	{"email": "e.andreeva.121971@postgrespro.ru", "phone": "+70754868775"}
0005435332597	61BF9C	1405 000610	VALENTINA NESTEROVA	{"phone": "+70665451341"}
0005435332598	46CEF8	9358 454938	DMITRIY NAUMOV	{"phone": "+70245628906"}
0005435332599	8D6DB7	7013 458366	PAVEL NIKOLAEV	{"phone": "+70072944233"}
0005435332600	BC2697	9537 105003	LYUDMILA KUZNECOVA	{"email": "lyudmila.kuznecova.101975@postgrespro.ru", "phone": "+70937143088"}
0005435332601	BC2697	2761 626264	PETR IVANOV	{"phone": "+70876944764"}
0005435332602	F574D8	5429 245804	NATALYA SCHERBAKOVA	{"phone": "+70851994039"}
0005435332603	F574D8	2529 957330	NINA VLASOVA	{"phone": "+70418015181"}
0005435332604	F574D8	9157 728759	KLAVDIYA DANILOVA	{"phone": "+70450084713"}
0005435332605	F5A1F9	3026 757766	ALEKSANDR RODIONOV	{"email": "rodionovaleksandr_22071967@postgrespro.ru", "phone": "+70217721265"}
0005435332606	F5A1F9	3317 219455	NIKOLAY GERASIMOV	{"phone": "+70991247576"}
0005435332607	64FF28	7385 708662	TATYANA NIKOLAEVA	{"phone": "+70609373767"}
0005435332608	FDCFFA	6503 867525	EVGENIY BARANOV	{"phone": "+70167275291"}
0005435332609	A01125	1644 484221	ANDREY SOLOVEV	{"email": "solovevandrey_29041977@postgrespro.ru", "phone": "+70155595094"}
0005435332610	4D2A31	3733 798929	YURIY MIRONOV	{"email": "mironovyuriy-1978@postgrespro.ru", "phone": "+70889853638"}
0005435332611	4D2A31	8587 407242	ANASTASIYA GERASIMOVA	{"phone": "+70245569583"}
0005435332612	FB4148	8503 401941	EVGENIY SAVELEV	{"phone": "+70662881387"}
0005435332613	FB4148	0526 503614	ANDREY BARANOV	{"phone": "+70260461102"}
0005435332614	C62F47	6906 884951	ELENA RYABOVA	{"phone": "+70739602607"}
0005435332615	7A4AA6	1447 183902	ANNA POPOVA	{"email": "popovaa.1964@postgrespro.ru", "phone": "+70892936098"}
0005435332616	E1491C	0464 075395	VYACHESLAV ZHURAVLEV	{"email": "zhuravlev-v-1977@postgrespro.ru", "phone": "+70026237681"}
0005435332617	1CEF1E	9865 844008	IRINA NESTEROVA	{"email": "nesterova_i.081966@postgrespro.ru", "phone": "+70910006395"}
0005435332618	B695D4	7648 544946	YURIY KUZNECOV	{"phone": "+70537330306"}
0005435332619	E860DE	3797 971160	ALEKSEY MOROZOV	{"email": "a_morozov-091980@postgrespro.ru", "phone": "+70798560096"}
0005435332620	1F8280	7125 446243	ALEKSANDR AFANASEV	{"phone": "+70517478576"}
0005435332621	1F8280	6045 830831	VIKTOR MAKSIMOV	{"email": "v_maksimov.101974@postgrespro.ru", "phone": "+70918235535"}
0005435332622	0D9EDD	7559 849844	VLADIMIR BORISOV	{"email": "borisov.vladimir.10121967@postgrespro.ru", "phone": "+70260616149"}
0005435332623	9FD901	6446 012356	IGOR PAVLOV	{"phone": "+70469252590"}
0005435332624	C1FDEC	3607 656196	SERGEY ROMANOV	{"email": "sergey-romanov091983@postgrespro.ru", "phone": "+70994139144"}
0005435332625	C1FDEC	2204 866155	SVETLANA GAVRILOVA	{"email": "svetlanagavrilova051971@postgrespro.ru", "phone": "+70227202661"}
0005435332626	8B350C	7785 897690	OLEG ZHURAVLEV	{"phone": "+70227020506"}
0005435332627	8B350C	0108 155041	ANDREY KULIKOV	{"phone": "+70836677072"}
0005435332628	B64733	0885 435043	VLADIMIR OSIPOV	{"phone": "+70087383091"}
0005435332629	A9157D	9481 741290	OKSANA IVANOVA	{"phone": "+70153865065"}
0005435332630	A9157D	0563 212329	ALEKSANDR MAKSIMOV	{"email": "maksimova13101974@postgrespro.ru", "phone": "+70443136175"}
0005435332631	8DDA8D	5486 113929	ALEKSEY KRASNOV	{"phone": "+70147565473"}
0005435332632	36614C	4225 514166	OLGA KOMAROVA	{"email": "komarova.o_10091975@postgrespro.ru", "phone": "+70806418843"}
0005435332633	147356	2812 965122	NADEZHDA TARASOVA	{"phone": "+70002757533"}
0005435332634	147356	4976 549852	KONSTANTIN AFANASEV	{"phone": "+70440514620"}
0005435332635	786D08	8234 025788	ALEKSANDR MAKAROV	{"email": "aleksandr.makarov081971@postgrespro.ru", "phone": "+70136559841"}
0005435332636	92812D	1920 036422	POLINA EFIMOVA	{"email": "p.efimova02051978@postgrespro.ru", "phone": "+70317384691"}
0005435332637	92812D	0159 076780	YULIYA KOROLEVA	{"phone": "+70255253060"}
0005435332638	23EC72	2900 612725	NATALYA NESTEROVA	{"email": "nesterovan-041979@postgrespro.ru", "phone": "+70266747799"}
0005435332639	58554D	3213 855867	YULIYA MAKAROVA	{"phone": "+70472105426"}
0005435332640	51EA4F	2529 873934	SVETLANA NESTEROVA	{"phone": "+70681478683"}
0005435332641	51EA4F	6783 012940	ALEKSEY NIKOLAEV	{"email": "nikolaevaleksey_121980@postgrespro.ru", "phone": "+70450882860"}
0005435332642	6BD4BC	5200 764496	OLGA TIKHONOVA	{"phone": "+70635287988"}
0005435332643	DE78F2	4578 964023	TATYANA GAVRILOVA	{"phone": "+70333864847"}
0005435332644	599629	8821 474453	ELENA KRASNOVA	{"phone": "+70845294541"}
0005435332645	599629	3768 098765	VALENTINA ZAKHAROVA	{"email": "vzakharova011965@postgrespro.ru", "phone": "+70573707017"}
0005435339989	981D69	7350 203236	ELENA BELYAEVA	{"email": "belyaevae_21091973@postgrespro.ru", "phone": "+70713560341"}
0005435339990	5E5C0D	0879 280257	ANDREY POPOV	{"phone": "+70068148057"}
0005435339991	5E5C0D	6090 863212	DANIL ALEKSEEV	{"email": "alekseevdanil.1977@postgrespro.ru", "phone": "+70679524240"}
0005435339992	5E5C0D	9454 839625	ALEKSANDR ISAEV	{"phone": "+70325665887"}
0005435339993	9DF92D	3720 709617	LARISA ANDREEVA	{"email": "larisa.andreeva_1966@postgrespro.ru", "phone": "+70841812870"}
0005435339994	9DF92D	9533 084789	TATYANA NIKOLAEVA	{"phone": "+70227804234"}
0005435339995	9A0A70	4433 853856	VADIM KISELEV	{"phone": "+70093037396"}
0005435339996	460899	8107 214345	NIKOLAY MAKSIMOV	{"phone": "+70148965229"}
0005435339997	8A1796	4967 234701	DENIS ANTONOV	{"phone": "+70542045569"}
0005435339998	E5E620	0525 688328	VALENTINA BARANOVA	{"email": "v_baranova-051977@postgrespro.ru", "phone": "+70531906555"}
0005435339999	E5E620	4940 503644	EVGENIY KRASNOV	{"phone": "+70739746997"}
0005435340000	FC48E5	3942 769871	ANASTASIYA VLASOVA	{"phone": "+70539354739"}
0005435340001	D0E768	5444 161039	NIKOLAY IVANOV	{"email": "ivanov.nikolay.15111971@postgrespro.ru", "phone": "+70689238665"}
0005435340002	DA7124	4398 705536	SVETLANA VOROBEVA	{"phone": "+70275947359"}
0005435340003	DA7124	8597 338846	LYUBOV GAVRILOVA	{"email": "lyubovgavrilova09101972@postgrespro.ru", "phone": "+70172826839"}
0005435340004	370853	9600 972804	ANDREY SIDOROV	{"phone": "+70261542884"}
0005435340005	7C4E02	5434 189277	NATALYA KARPOVA	{"email": "karpovan_11011969@postgrespro.ru", "phone": "+70705201889"}
0005435340006	42BA06	0528 717404	ANNA MIRONOVA	{"email": "anna-mironova12011976@postgrespro.ru", "phone": "+70195100044"}
0005435340007	CD5AD2	3328 569797	EVGENIYA LUKYANOVA	{"email": "lukyanova_evgeniya.1976@postgrespro.ru", "phone": "+70697319434"}
0005435340008	CD5AD2	0083 846767	EVGENIYA ANTONOVA	{"phone": "+70793890974"}
0005435340009	6A43C4	8561 318378	EVGENIY ANTONOV	{"phone": "+70144995224"}
0005435340010	E6D501	4384 988471	TAGIR TIMOFEEV	{"phone": "+70313198479"}
0005435340011	E6D501	9297 134150	ALEKSANDR BARANOV	{"phone": "+70029256888"}
0005435340012	E6D501	2523 393451	VALENTINA SCHERBAKOVA	{"email": "v-scherbakova.26011979@postgrespro.ru", "phone": "+70384344586"}
0005435340013	71C87C	3925 643322	GALINA OSIPOVA	{"email": "galina_osipova-011964@postgrespro.ru", "phone": "+70562700386"}
0005435340014	5D57F4	4574 458022	IVAN FEDOTOV	{"phone": "+70208001523"}
0005435340015	5D57F4	7167 720243	KSENIYA SERGEEVA	{"email": "sergeevak-17101965@postgrespro.ru", "phone": "+70443616247"}
0005435340016	05CD63	7585 231529	TIMUR TIKHONOV	{"email": "tikhonov.t_03041962@postgrespro.ru", "phone": "+70200067053"}
0005435340017	F507CD	0874 532221	YULIYA KISELEVA	{"email": "kiseleva-yuliya01061962@postgrespro.ru", "phone": "+70530908305"}
0005435340018	1A33BF	8493 450041	SVETLANA ZAKHAROVA	{"email": "s.zakharova021977@postgrespro.ru", "phone": "+70699105315"}
0005435340019	05AA46	5019 875887	ALEKSANDR VLASOV	{"email": "a-vlasov-051968@postgrespro.ru", "phone": "+70081931554"}
0005435340020	3A15E5	4156 068740	VALENTINA ZAYCEVA	{"email": "zayceva-valentina.1971@postgrespro.ru", "phone": "+70337312613"}
0005435340021	FAC469	7612 497727	LYUBOV MAKAROVA	{"email": "makaroval-24121966@postgrespro.ru", "phone": "+70438538157"}
0005435340022	FAC469	3367 792910	SERGEY ABRAMOV	{"email": "sergey.abramov_21111972@postgrespro.ru", "phone": "+70303029608"}
0005435340023	7423A7	3641 035848	VIKTOR MAKAROV	{"phone": "+70382584068"}
0005435340024	4D0F95	8543 242382	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov24021974@postgrespro.ru", "phone": "+70678545988"}
0005435340025	9162AB	7075 847287	PETR DENISOV	{"phone": "+70028464333"}
0005435340026	9162AB	3056 039757	EKATERINA ANDREEVA	{"email": "e.andreeva121967@postgrespro.ru", "phone": "+70996071433"}
0005435340027	1FD330	8468 331290	NATALYA MAKSIMOVA	{"phone": "+70565849691"}
0005435340028	4E7616	7200 237275	ALEKSANDR GERASIMOV	{"phone": "+70986258357"}
0005435340029	1DE002	9068 160119	VLADIMIR ABRAMOV	{"phone": "+70784300083"}
0005435340030	1DBA5F	4107 085557	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov061967@postgrespro.ru", "phone": "+70235566881"}
0005435340031	1DBA5F	4312 461556	DANIIL STEPANOV	{"phone": "+70188229963"}
0005435340032	1DBA5F	3071 623893	VITALIY KULIKOV	{"phone": "+70790301304"}
0005435340033	1D7890	9206 096365	VALENTINA NESTEROVA	{"phone": "+70729922784"}
0005435340034	1D7890	0190 666740	DMITRIY SAVELEV	{"phone": "+70237877880"}
0005435340035	628035	7913 237320	ANATOLIY SEMENOV	{"phone": "+70931912318"}
0005435340036	30209C	5958 329460	OLGA KUZNECOVA	{"email": "o_kuznecova1973@postgrespro.ru", "phone": "+70232777639"}
0005435340037	30209C	7791 754844	VERA ZAKHAROVA	{"phone": "+70560618897"}
0005435340038	00B241	8159 409291	MARINA IVANOVA	{"phone": "+70454701615"}
0005435340039	00B241	1810 108227	TATYANA BARANOVA	{"phone": "+70560701093"}
0005435340040	A99B45	5971 058632	ALEKSANDRA ZAKHAROVA	{"phone": "+70200402958"}
0005435340041	A99B45	0545 455528	NATALYA KUZNECOVA	{"email": "kuznecovanatalya_1971@postgrespro.ru", "phone": "+70454788770"}
0005435340042	A99B45	8601 940996	ALEKSEY TARASOV	{"email": "tarasov.aleksey.1981@postgrespro.ru", "phone": "+70881528486"}
0005435340043	A99B45	4250 335881	MAKSIM BONDARENKO	{"email": "maksimbondarenko1965@postgrespro.ru", "phone": "+70058559757"}
0005435340044	466B4C	9236 838855	ALEKSEY SEMENOV	{"phone": "+70976040525"}
0005435340045	20136B	3213 533448	VLADIMIR SMIRNOV	{"email": "v_smirnov_071961@postgrespro.ru", "phone": "+70558939565"}
0005435340046	DA24FF	6275 363189	ROMAN FEDOTOV	{"email": "r.fedotov_10081973@postgrespro.ru", "phone": "+70431621480"}
0005435340047	842342	5100 277547	SERGEY STEPANOV	{"email": "stepanov-sergey.13071967@postgrespro.ru", "phone": "+70359217785"}
0005435340048	170F34	7758 809865	VASILIY ANTONOV	{"phone": "+70808947367"}
0005435340049	170F34	1308 739532	MAKSIM POPOV	{"phone": "+70979454914"}
0005435340050	170F34	2472 053970	PAVEL MIRONOV	{"phone": "+70119934185"}
0005435340051	569AA8	4594 459160	LYUBOV MELNIKOVA	{"phone": "+70681660899"}
0005435340052	523E5C	4369 052062	ALEKSANDRA MIRONOVA	{"phone": "+70922470294"}
0005435340053	C1E5EC	6832 763935	ARTUR ANTONOV	{"email": "antonova101975@postgrespro.ru", "phone": "+70403675123"}
0005435340054	435B21	8842 882176	ILYA NAZAROV	{"email": "inazarov091970@postgrespro.ru", "phone": "+70834372345"}
0005435340055	285B7E	4447 045941	NIKOLAY ALEKSANDROV	{"email": "aleksandrov.n_17061979@postgrespro.ru", "phone": "+70360546298"}
0005435340056	1A0390	3147 525613	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva04111965@postgrespro.ru", "phone": "+70643935965"}
0005435340057	1A0390	8956 137841	VLADIMIR VASILEV	{"email": "vladimir-vasilev011966@postgrespro.ru", "phone": "+70691379492"}
0005435340058	1A0390	0744 163174	ZAKHAR SMIRNOV	{"email": "zakhar.smirnov-02051964@postgrespro.ru", "phone": "+70846700920"}
0005435340059	B358BA	0780 072759	ANZHELA KUZNECOVA	{"email": "kuznecova.a_101975@postgrespro.ru", "phone": "+70177305795"}
0005435340060	96DA8E	3917 122330	GALINA FROLOVA	{"email": "frolovagalina_081983@postgrespro.ru", "phone": "+70044860949"}
0005435340061	96DA8E	5900 995485	GERMAN MAKAROV	{"phone": "+70912073591"}
0005435340062	4D3752	8087 683863	OLGA POLYAKOVA	{"email": "polyakovao-011964@postgrespro.ru", "phone": "+70315084959"}
0005435340063	B47CD1	7319 116329	OLGA PETROVA	{"phone": "+70135266274"}
0005435340064	9EF43B	2866 111393	ROMAN TIMOFEEV	{"phone": "+70046398985"}
0005435340065	478CA1	8438 768542	NIKITA ZHUKOV	{"phone": "+70137416257"}
0005435340066	880FE4	4092 815370	NURIYA MAKAROVA	{"email": "makarovanuriya.031966@postgrespro.ru", "phone": "+70081635725"}
0005435340067	5ECD5D	2432 426276	ALEKSEY TIMOFEEV	{"email": "timofeeva05101961@postgrespro.ru", "phone": "+70316998320"}
0005435340068	5ECD5D	9127 127578	PETR KUZNECOV	{"email": "petrkuznecov_1980@postgrespro.ru", "phone": "+70724360191"}
0005435340069	5ECD5D	0442 189667	VLADIMIR FEDOROV	{"phone": "+70359973909"}
0005435340070	3555B6	4310 933034	NINA ISAEVA	{"email": "isaeva_n121974@postgrespro.ru", "phone": "+70983583536"}
0005435340071	75525B	8738 182891	VIKTORIYA YAKOVLEVA	{"email": "yakovleva-viktoriya.29111968@postgrespro.ru", "phone": "+70188283128"}
0005435340072	C990C5	0422 072072	MARIYA NESTEROVA	{"email": "nesterova-mariya_16101976@postgrespro.ru", "phone": "+70226865169"}
0005435340073	C990C5	1679 378696	NIKITA IVANOV	{"email": "nikita.ivanov-21121965@postgrespro.ru", "phone": "+70500764102"}
0005435340074	CA7A8A	6721 996632	DMITRIY IVANOV	{"email": "dmitriy.ivanov121977@postgrespro.ru", "phone": "+70958241377"}
0005435340075	132FE6	3424 976546	DMITRIY ABRAMOV	{"phone": "+70801085315"}
0005435340076	1BB4CD	8172 866924	EKATERINA MAKSIMOVA	{"email": "ekaterinamaksimova.1968@postgrespro.ru", "phone": "+70087846882"}
0005435340077	FA1B94	4850 320835	LYUDMILA GORBUNOVA	{"phone": "+70494846178"}
0005435340078	688445	4156 735651	ALLA ZOTOVA	{"email": "alla-zotova_26011974@postgrespro.ru", "phone": "+70685759660"}
0005435340079	305251	0928 411808	OLEG ZAYCEV	{"email": "zaycev_o051960@postgrespro.ru", "phone": "+70998031046"}
0005435340080	3DD6E6	2785 373680	SERGEY ALEKSEEV	{"email": "sergey-alekseev101967@postgrespro.ru", "phone": "+70312722861"}
0005435340081	3DD6E6	6250 737130	ANATOLIY KISELEV	{"phone": "+70434933741"}
0005435340082	999C55	9658 138252	VLADISLAV ZHUKOV	{"phone": "+70599116439"}
0005435340083	C8F4D0	3110 255100	VALERIY SIDOROV	{"phone": "+70811636244"}
0005435340084	147095	0166 498272	ARTEM ZAYCEV	{"phone": "+70876851613"}
0005435340085	147095	1018 855729	SERGEY FOMIN	{"phone": "+70884182652"}
0005435340086	A07213	6224 802993	ALEKSANDR BELOV	{"email": "belov_a-041970@postgrespro.ru", "phone": "+70497514292"}
0005435340087	FA90D2	5797 301319	NATALYA SMIRNOVA	{"email": "smirnova_natalya_17071966@postgrespro.ru", "phone": "+70115546920"}
0005435340088	029D3F	5347 240710	ANASTASIYA OSIPOVA	{"email": "osipova-a1974@postgrespro.ru", "phone": "+70824263122"}
0005435340089	A68A62	3500 032101	GALINA YUDINA	{"phone": "+70582141201"}
0005435340090	5863A8	5795 314090	YURIY ANDREEV	{"phone": "+70291558832"}
0005435340091	5863A8	2847 765863	MARIYA KONOVALOVA	{"email": "m-konovalova_051984@postgrespro.ru", "phone": "+70558438544"}
0005435340092	FBF4E0	5284 470643	DINARA LAZAREVA	{"email": "lazareva.d011966@postgrespro.ru", "phone": "+70707802487"}
0005435340093	49639B	3231 878189	KHALIDA DAVYDOVA	{"email": "davydova-khalida.13041971@postgrespro.ru", "phone": "+70595589121"}
0005435340094	92711B	9127 393974	LYUBOV MAKSIMOVA	{"email": "maksimoval22021966@postgrespro.ru", "phone": "+70128865305"}
0005435340095	92711B	4443 701957	OLEG SERGEEV	{"email": "osergeev_1974@postgrespro.ru", "phone": "+70376681372"}
0005435340096	F873B8	2710 009091	ALEKSANDR TARASOV	{"email": "aleksandr-tarasov.1973@postgrespro.ru", "phone": "+70091149054"}
0005435340097	A36478	2676 426864	TATYANA SOKOLOVA	{"phone": "+70983389310"}
0005435340098	A36478	9048 568295	GALINA POPOVA	{"email": "popova-g.061971@postgrespro.ru", "phone": "+70182815511"}
0005435340099	12458D	9603 494832	VIKTOR IVANOV	{"email": "viktor_ivanov_021975@postgrespro.ru", "phone": "+70899337880"}
0005435340100	D94EBC	9600 806419	VLADIMIR SMIRNOV	{"email": "smirnov-v_071975@postgrespro.ru", "phone": "+70909772889"}
0005435340101	3CA2AD	2500 168978	TAMARA GAVRILOVA	{"email": "tgavrilova.011975@postgrespro.ru", "phone": "+70201729644"}
0005435340102	0F1D8C	9164 498399	VADIM KUZNECOV	{"email": "v_kuznecov.011980@postgrespro.ru", "phone": "+70530293477"}
0005435340103	D05188	9345 926533	LARISA ANDREEVA	{"phone": "+70674353176"}
0005435340104	D05188	7480 740828	VIOLETTA SOKOLOVA	{"phone": "+70881749928"}
0005435340105	30F1FD	6139 829830	MARIYA VOLKOVA	{"email": "mariya.volkova_1979@postgrespro.ru", "phone": "+70160658290"}
0005435340106	30F1FD	7278 833851	OLESYA ROMANOVA	{"phone": "+70231855074"}
0005435340107	9276D3	7056 938781	TAISIYA BELOVA	{"email": "taisiya.belova.091960@postgrespro.ru", "phone": "+70878640683"}
0005435340108	9276D3	0768 194722	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova.071977@postgrespro.ru", "phone": "+70495395318"}
0005435340109	44FA32	0869 274311	NINA DANILOVA	{"email": "nina.danilova-1960@postgrespro.ru", "phone": "+70563289173"}
0005435340110	44FA32	3477 687944	VLADIMIR PAVLOV	{"email": "pavlov-v.031971@postgrespro.ru", "phone": "+70612738680"}
0005435340111	F5B0E8	6952 725611	DARYA KISELEVA	{"phone": "+70638162194"}
0005435340112	F5B0E8	2242 724363	LEONID NAZAROV	{"phone": "+70917391602"}
0005435340113	1D671A	9143 267804	TATYANA MARTYNOVA	{"email": "martynova-tatyana_05091973@postgrespro.ru", "phone": "+70983578357"}
0005435340114	56D34A	9313 847270	VALENTINA ZAKHAROVA	{"email": "v-zakharova071981@postgrespro.ru", "phone": "+70336289124"}
0005435340115	AF4322	4280 665037	SERGEY KARPOV	{"email": "sergey-karpov_07061971@postgrespro.ru", "phone": "+70758370223"}
0005435340116	5C86C6	3437 540913	ANASTASIYA ANTONOVA	{"phone": "+70813472537"}
0005435340117	0A3DF4	6599 507615	MARIYA NIKOLAEVA	{"email": "mnikolaeva.111977@postgrespro.ru", "phone": "+70431549067"}
0005435340118	93AE4D	6586 415816	VLADIMIR SOROKIN	{"phone": "+70223078925"}
0005435340119	F60A0C	7777 133421	EKATERINA VOLKOVA	{"email": "volkova.ekaterina-011963@postgrespro.ru", "phone": "+70796061028"}
0005435340120	779D81	7377 714563	OLGA SAVELEVA	{"email": "o-saveleva_14031976@postgrespro.ru", "phone": "+70958925956"}
0005435340121	746323	1571 145317	VLADIMIR NOVIKOV	{"email": "novikovv-1981@postgrespro.ru", "phone": "+70365359960"}
0005435340122	746323	7007 814911	OLEG PAVLOV	{"phone": "+70072849676"}
0005435340123	BF09F6	7104 397883	NIKOLAY NOVIKOV	{"email": "novikovn_27061973@postgrespro.ru", "phone": "+70252136828"}
0005435340124	6B7C98	7903 998181	ALEKSANDRA MOROZOVA	{"phone": "+70056021075"}
0005435340125	6B7C98	4297 710588	VLADIMIR MATVEEV	{"email": "matveev.v.09111972@postgrespro.ru", "phone": "+70492962814"}
0005435340126	F991C0	4521 580290	ALEKSANDR FOMIN	{"email": "fominaleksandr1970@postgrespro.ru", "phone": "+70849936317"}
0005435340127	EC0021	7779 552649	ALENA KUZNECOVA	{"phone": "+70951572653"}
0005435340128	FE3424	3625 893056	NATALYA KRASNOVA	{"phone": "+70707343954"}
0005435340129	DF135B	3317 639779	ANASTASIYA KULIKOVA	{"phone": "+70524602777"}
0005435340130	DF135B	8431 034524	VASILIY GORBUNOV	{"phone": "+70800523227"}
0005435340131	EEFE4A	7274 915625	EVGENIY ZAKHAROV	{"phone": "+70339041830"}
0005435340132	EEFE4A	2416 933459	YURIY NIKITIN	{"phone": "+70128039172"}
0005435340133	8647B9	5843 352393	YULIYA BELOVA	{"phone": "+70501819444"}
0005435340134	8647B9	9110 904187	TATYANA EFREMOVA	{"email": "efremova-t1968@postgrespro.ru", "phone": "+70173163500"}
0005435340135	E25BBB	1619 358798	ALENA PETROVA	{"email": "petrova.alena_071964@postgrespro.ru", "phone": "+70148846947"}
0005435340136	1CA96C	9473 603532	ILMIR FROLOV	{"email": "ifrolov_091969@postgrespro.ru", "phone": "+70691822428"}
0005435340137	7F66DE	3469 132338	IVAN STEPANOV	{"phone": "+70266906146"}
0005435340138	C05913	7309 988521	PAVEL SOLOVEV	{"phone": "+70809089351"}
0005435340139	E2EA06	6506 912360	MARGARITA KUDRYASHOVA	{"phone": "+70527253710"}
0005435340140	5A71A3	5697 803218	IGOR PETROV	{"email": "i_petrov.1978@postgrespro.ru", "phone": "+70455859599"}
0005435340141	D1BF54	3776 507152	SERGEY KRASNOV	{"phone": "+70471747885"}
0005435340142	D1BF54	3932 125029	ZINAIDA KUZNECOVA	{"email": "kuznecova-z.121974@postgrespro.ru", "phone": "+70325827471"}
0005435340143	0DCA19	3714 134537	PAVEL SCHERBAKOV	{"email": "scherbakov.pavel_051964@postgrespro.ru", "phone": "+70513891255"}
0005435340267	AE21C2	8080 966894	GALINA NIKOLAEVA	{"phone": "+70572764834"}
0005435340144	49761C	3171 473796	SVETLANA MOROZOVA	{"email": "morozova_s.05061968@postgrespro.ru", "phone": "+70080197658"}
0005435340145	216AE9	5893 566303	ELENA BARANOVA	{"phone": "+70194428671"}
0005435340146	59FBBE	8600 437448	ANTONINA ORLOVA	{"email": "aorlova011983@postgrespro.ru", "phone": "+70299115372"}
0005435340147	30D4FE	7656 463904	VIKTOR VASILEV	{"email": "v.vasilev_15011972@postgrespro.ru", "phone": "+70326109016"}
0005435340148	F4E5C5	5086 617908	VALENTINA SOKOLOVA	{"phone": "+70750349931"}
0005435340149	4554BC	2573 720221	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev.091968@postgrespro.ru", "phone": "+70985216512"}
0005435340150	98AFC7	4376 360332	YULIYA BORISOVA	{"email": "borisovay-1987@postgrespro.ru", "phone": "+70768597822"}
0005435340151	98AFC7	6380 278253	ANDREY POPOV	{"email": "andrey.popov_07111974@postgrespro.ru", "phone": "+70258293546"}
0005435340152	D62883	6181 360122	ASIYA ANDREEVA	{"email": "andreevaasiya.1968@postgrespro.ru", "phone": "+70927863274"}
0005435340153	7CEA2C	3206 269369	VLADIMIR SOKOLOV	{"email": "sokolov.vladimir-1966@postgrespro.ru", "phone": "+70639938895"}
0005435340154	43F981	4956 889496	YURIY MOROZOV	{"phone": "+70274069573"}
0005435340155	6363C3	5157 091332	NIKOLAY MIKHAYLOV	{"phone": "+70376607752"}
0005435340156	6363C3	6323 094802	NIKOLAY ROMANOV	{"email": "romanovnikolay.021967@postgrespro.ru", "phone": "+70948475251"}
0005435340157	6363C3	8238 490424	VLADIMIR ISAEV	{"phone": "+70893675073"}
0005435340158	E35401	3408 551357	SERGEY NAUMOV	{"email": "snaumov.091971@postgrespro.ru", "phone": "+70552751339"}
0005435340159	5E2E7B	2577 589169	FEDOR SOKOLOV	{"email": "fedorsokolov.1981@postgrespro.ru", "phone": "+70428476381"}
0005435340160	90EF5A	3179 995217	DENIS SEMENOV	{"email": "semenov_denis1972@postgrespro.ru", "phone": "+70055921315"}
0005435340161	729B4E	5339 915852	OLGA ROMANOVA	{"email": "romanovao.1976@postgrespro.ru", "phone": "+70652608442"}
0005435340162	61F9C7	5889 203665	TATYANA IVANOVA	{"phone": "+70889970805"}
0005435340163	61F9C7	2787 204390	DINA NOVIKOVA	{"phone": "+70947198640"}
0005435340164	333390	4781 782114	ALEKSEY KULIKOV	{"email": "aleksey-kulikov071981@postgrespro.ru", "phone": "+70036475046"}
0005435340165	E70457	6361 743886	ELENA NESTEROVA	{"email": "nesterova-e-29041966@postgrespro.ru", "phone": "+70633011954"}
0005435340166	E4878C	4353 532188	VALENTINA SERGEEVA	{"phone": "+70871613472"}
0005435340167	764864	5641 806354	VASILIY KONOVALOV	{"phone": "+70179110092"}
0005435340168	A9E766	3288 180377	TATYANA SOKOLOVA	{"phone": "+70232620425"}
0005435340169	032B99	3472 065598	ALEKSANDR FOMIN	{"email": "a.fomin26041970@postgrespro.ru", "phone": "+70637879348"}
0005435340170	E01778	9517 050154	ANNA MAKAROVA	{"phone": "+70704343993"}
0005435340171	C59C1D	9087 723674	SERGEY MELNIKOV	{"phone": "+70746739186"}
0005435340172	A1ABD5	2883 398233	NADEZHDA KAZAKOVA	{"phone": "+70683670610"}
0005435340173	4F798E	3392 201477	EKATERINA PETROVA	{"email": "ekaterina_petrova091965@postgrespro.ru", "phone": "+70241910719"}
0005435340174	4F798E	2047 256868	ELENA PAVLOVA	{"email": "e-pavlova.09111964@postgrespro.ru", "phone": "+70889935910"}
0005435340175	571EF0	0173 958760	MIKHAIL ZAKHAROV	{"email": "zakharov.m-121974@postgrespro.ru", "phone": "+70616925795"}
0005435340176	55954A	6668 246112	MARIYA NIKITINA	{"email": "nikitinam.30091973@postgrespro.ru", "phone": "+70044691811"}
0005435340177	8D24FA	1218 969754	VALENTINA KRASNOVA	{"email": "krasnovavalentina.011977@postgrespro.ru", "phone": "+70953520236"}
0005435340178	E979C9	1919 407286	VITALIY OSIPOV	{"phone": "+70381340547"}
0005435340179	E979C9	8026 687518	VASILIY SOKOLOV	{"phone": "+70672402256"}
0005435340180	055772	4029 799825	OLGA VLASOVA	{"phone": "+70807276846"}
0005435340181	FDF516	8599 452626	GENNADIY ALEKSEEV	{"phone": "+70313382843"}
0005435340182	58C677	3201 406491	ARTEM VASILEV	{"email": "artemvasilev-04021978@postgrespro.ru", "phone": "+70545965712"}
0005435340183	593E88	4716 753375	RAFAIL GAVRILOV	{"email": "r_gavrilov_02121967@postgrespro.ru", "phone": "+70219159371"}
0005435340184	593E88	1013 273972	YULIYA TARASOVA	{"email": "tarasova.y-1972@postgrespro.ru", "phone": "+70959196650"}
0005435340185	F94080	5896 330061	MARIYA ZAKHAROVA	{"phone": "+70100729891"}
0005435340186	8511F8	0102 343276	ALEKSANDR FROLOV	{"phone": "+70830614053"}
0005435340187	7A6427	8628 286659	ALENA ANISIMOVA	{"email": "anisimova_alena-1985@postgrespro.ru", "phone": "+70113284483"}
0005435340188	BB83AF	0635 552123	VITALIY BONDARENKO	{"email": "vitaliy-bondarenko-02021974@postgrespro.ru", "phone": "+70918140807"}
0005435340189	B58C51	9087 710603	SERGEY ROMANOV	{"phone": "+70849831519"}
0005435340190	C69604	4359 218771	SERGEY ZAYCEV	{"phone": "+70312124831"}
0005435340191	C69604	2481 908167	GALINA ROMANOVA	{"phone": "+70917411771"}
0005435340192	EC4341	2032 799663	EKATERINA DANILOVA	{"phone": "+70893364708"}
0005435340193	CC0EDE	4590 203690	ANTONINA RODIONOVA	{"email": "antonina-rodionova_10051973@postgrespro.ru", "phone": "+70765302440"}
0005435340194	D5B4B2	3337 305668	NATALYA IVANOVA	{"phone": "+70995569831"}
0005435340195	9D7C62	3806 674659	VALENTINA IVANOVA	{"phone": "+70422301518"}
0005435340196	9C014C	4024 607025	DANILA STEPANOV	{"phone": "+70729909385"}
0005435340197	15BE0E	5490 551184	ELENA IVANOVA	{"phone": "+70218837907"}
0005435340198	43A9E7	0922 762935	TATYANA PAVLOVA	{"phone": "+70384061969"}
0005435340199	43A9E7	4672 571713	VIKTOR CHERNOV	{"phone": "+70162370507"}
0005435340200	0784E8	1192 560612	OLGA ZHURAVLEVA	{"phone": "+70010726031"}
0005435340201	5257F3	5384 683135	ALEKSEY VLASOV	{"phone": "+70590770000"}
0005435340202	33D881	9702 173620	KRISTINA MOROZOVA	{"email": "morozova-k-19091972@postgrespro.ru", "phone": "+70703118712"}
0005435340203	2C54EA	6653 232173	GEORGIY MIKHAYLOV	{"email": "gmikhaylov-021957@postgrespro.ru", "phone": "+70696675829"}
0005435340204	2C54EA	4116 419831	TAMARA ALEKSEEVA	{"email": "alekseeva.tamara-071974@postgrespro.ru", "phone": "+70180888940"}
0005435340205	B4BF7B	6614 230165	TATYANA KRASNOVA	{"email": "krasnova.t-17091964@postgrespro.ru", "phone": "+70876177342"}
0005435340206	80D089	4224 391962	ELENA TROFIMOVA	{"phone": "+70463269654"}
0005435340207	60FB7E	0699 524451	NATALYA ABRAMOVA	{"phone": "+70311425100"}
0005435340208	F25198	4354 693958	ANTON FROLOV	{"email": "afrolov06011963@postgrespro.ru", "phone": "+70836736396"}
0005435340209	F25198	9428 803767	ANASTASIYA VOLKOVA	{"phone": "+70627266802"}
0005435340210	A5057A	0447 455188	MAKSIM STEPANOV	{"phone": "+70748462697"}
0005435340211	868BA1	5768 887997	SERGEY BORISOV	{"email": "borisov_s_27091967@postgrespro.ru", "phone": "+70978550178"}
0005435340212	CB761C	8920 163575	NIKOLAY MEDVEDEV	{"phone": "+70313114918"}
0005435340213	54E729	7123 804536	GALINA PAVLOVA	{"email": "pavlova-galina_121984@postgrespro.ru", "phone": "+70146228232"}
0005435340214	42437A	1873 762638	LYUBOV ROMANOVA	{"phone": "+70799186768"}
0005435340215	334793	4140 292018	VITALIY VOROBEV	{"phone": "+70255760223"}
0005435340216	6397F3	6271 928013	ALEKSANDR GAVRILOV	{"phone": "+70435448580"}
0005435340217	BFBF05	6304 414179	OLEG MAKAROV	{"phone": "+70825252268"}
0005435340218	A121BF	8641 880959	TATYANA CHERNOVA	{"email": "t.chernova.041978@postgrespro.ru", "phone": "+70663679530"}
0005435340219	5E7382	2297 532225	VALERIYA TIMOFEEVA	{"email": "timofeeva-valeriya.24051962@postgrespro.ru", "phone": "+70627713212"}
0005435340220	E47C83	1352 393332	IRINA SCHERBAKOVA	{"phone": "+70765224454"}
0005435340221	1F5B3A	2782 711159	NELYA GRISHINA	{"email": "grishina.nelya-121974@postgrespro.ru", "phone": "+70550936255"}
0005435340222	1F5B3A	2664 750675	VADIM VLASOV	{"email": "vadimvlasov-30041971@postgrespro.ru", "phone": "+70356472440"}
0005435340223	1BA189	1941 400387	LILIYA KUZNECOVA	{"phone": "+70240626314"}
0005435340224	1BA189	7745 491421	ARINA MIKHAYLOVA	{"email": "mikhaylovaa_11021969@postgrespro.ru", "phone": "+70366692201"}
0005435340225	A629ED	2829 170994	NADEZHDA GRISHINA	{"phone": "+70226376806"}
0005435340226	C2D030	3515 956438	NADEZHDA BOGDANOVA	{"email": "bogdanova.nadezhda_13101970@postgrespro.ru", "phone": "+70473139379"}
0005435340227	744B20	8365 006204	NADEZHDA GUSEVA	{"phone": "+70844496546"}
0005435340228	CF152C	0811 382829	MAKSIM FROLOV	{"email": "frolov_m-1965@postgrespro.ru", "phone": "+70216332074"}
0005435340229	CF152C	7774 803976	ROMAN POPOV	{"email": "roman_popov-111968@postgrespro.ru", "phone": "+70707534683"}
0005435340230	C58713	4657 660207	VLADISLAV ZAKHAROV	{"phone": "+70573889398"}
0005435340231	8EC6C1	6730 753611	DMITRIY ZAKHAROV	{"phone": "+70240146699"}
0005435340232	8EC6C1	9160 798984	VALERIY ABRAMOV	{"phone": "+70155373669"}
0005435340233	70A1BB	6872 319727	ANNA ORLOVA	{"email": "a_orlova_24061982@postgrespro.ru", "phone": "+70850946838"}
0005435340234	98CCD2	4237 699703	IGOR IVANOV	{"email": "i_ivanov-18051964@postgrespro.ru", "phone": "+70749113737"}
0005435340235	98CCD2	7885 760593	VALERIY KUZMIN	{"phone": "+70072352612"}
0005435340236	98CCD2	3918 515931	LYUBOV NESTEROVA	{"phone": "+70970004306"}
0005435340237	83E57A	8118 329765	NATALYA KUZNECOVA	{"email": "natalya.kuznecova1966@postgrespro.ru", "phone": "+70514670189"}
0005435340238	4D1D7A	2917 308297	VALENTINA OVCHINNIKOVA	{"phone": "+70862776924"}
0005435340239	4D1D7A	0583 183771	SERGEY EGOROV	{"email": "s_egorov051984@postgrespro.ru", "phone": "+70952207922"}
0005435340240	C55623	2623 379012	ELENA KUZNECOVA	{"phone": "+70742064586"}
0005435340241	3881C6	1466 769027	OLEG IVANOV	{"phone": "+70774014253"}
0005435340242	048E02	5609 073168	OLGA VOLKOVA	{"email": "volkovao-081965@postgrespro.ru", "phone": "+70545833451"}
0005435340243	048E02	9040 271066	IRINA MAKAROVA	{"phone": "+70712236944"}
0005435340244	CE0FAA	0451 636847	FARID PAVLOV	{"phone": "+70388559515"}
0005435340245	CE0FAA	1678 139551	YULIYA SCHERBAKOVA	{"phone": "+70676736996"}
0005435340246	650496	0263 025536	OLGA SMIRNOVA	{"email": "smirnova-o-121972@postgrespro.ru", "phone": "+70457519925"}
0005435340247	049C8F	1198 449340	VIKTORIYA MOROZOVA	{"email": "viktoriya_morozova111967@postgrespro.ru", "phone": "+70195196554"}
0005435340248	882096	7884 432633	VADIM SOLOVEV	{"email": "solovev-vadim031983@postgrespro.ru", "phone": "+70405861173"}
0005435340249	882096	2601 172751	RUFINA MOROZOVA	{"email": "morozova.r1985@postgrespro.ru", "phone": "+70052023137"}
0005435340250	BA2BC1	3989 213557	ANNA NIKOLAEVA	{"email": "nikolaeva_anna.101973@postgrespro.ru", "phone": "+70429418752"}
0005435340251	BA2BC1	7956 461993	ALEKSANDR FEDOROV	{"email": "a_fedorov.061976@postgrespro.ru", "phone": "+70811893240"}
0005435340252	BA2BC1	9896 467386	TATYANA VOLKOVA	{"phone": "+70093366275"}
0005435340253	DD05ED	1739 174313	VASILIY NIKITIN	{"email": "v-nikitin.081968@postgrespro.ru", "phone": "+70564598842"}
0005435340254	22A999	6676 943960	IRINA GAVRILOVA	{"phone": "+70797885914"}
0005435340255	2B58A0	8481 373489	NADEZHDA TARASOVA	{"email": "n.tarasova.17021959@postgrespro.ru", "phone": "+70410439651"}
0005435340256	A54AF2	3697 722920	VALENTINA TITOVA	{"email": "titova-valentina.071978@postgrespro.ru", "phone": "+70549670680"}
0005435340257	CB1615	2752 849031	VIKTORIYA ZHURAVLEVA	{"phone": "+70006186992"}
0005435340258	CB1615	2719 364983	ILDAR ZAYCEV	{"email": "i-zaycev121976@postgrespro.ru", "phone": "+70341448022"}
0005435340259	FAE9CA	6437 804510	ANATOLIY DENISOV	{"phone": "+70578855052"}
0005435340260	BA36C6	0356 963447	DENIS SMIRNOV	{"phone": "+70031866074"}
0005435340261	93981C	4128 480770	OLGA NIKITINA	{"email": "o.nikitina_01071968@postgrespro.ru", "phone": "+70060761126"}
0005435340262	ABCF89	8315 737048	ANDREY ROMANOV	{"phone": "+70063059391"}
0005435340263	F6B432	6959 250915	GALINA FEDOROVA	{"phone": "+70172972054"}
0005435340264	FB879E	1032 336030	ANDREY DENISOV	{"phone": "+70153850725"}
0005435340265	C887C4	1269 288023	ALEKSANDR TARASOV	{"phone": "+70948261412"}
0005435340266	BC5BDD	6630 220225	VALENTINA TIKHONOVA	{"email": "valentinatikhonova_1973@postgrespro.ru", "phone": "+70514193695"}
0005435340268	AE21C2	2308 316933	YURIY IVANOV	{"email": "yuriy.ivanov-02091962@postgrespro.ru", "phone": "+70105736280"}
0005435340269	AE21C2	8545 983431	VIKTOR BELOV	{"email": "viktor_belov.03011980@postgrespro.ru", "phone": "+70720627333"}
0005435340270	E8877D	1623 845487	ALEKSEY MIKHAYLOV	{"phone": "+70618122389"}
0005435340271	ACBFF3	9607 815207	VLADISLAV EGOROV	{"email": "egorov_vladislav_1973@postgrespro.ru", "phone": "+70004883453"}
0005435340272	ACBFF3	5281 237036	SVETLANA KAZAKOVA	{"email": "kazakova_svetlana_091973@postgrespro.ru", "phone": "+70619198673"}
0005435340273	5216D2	4029 940938	ANNA POPOVA	{"phone": "+70985292984"}
0005435340274	17A4D2	5762 505995	IVAN FROLOV	{"email": "frolov_ivan.101970@postgrespro.ru", "phone": "+70411782344"}
0005435340275	FF1C9B	9835 571955	ALEKSANDR BELOV	{"email": "belov-a-1966@postgrespro.ru", "phone": "+70650934170"}
0005435340276	11C293	6700 871981	ILDUS ISAEV	{"email": "ildus.isaev_1974@postgrespro.ru", "phone": "+70975854409"}
0005435340277	55BEAC	3625 469449	IRINA ZHUKOVA	{"email": "zhukovairina.10031978@postgrespro.ru", "phone": "+70483172418"}
0005435340278	A99810	4204 420380	ROBERT ZAKHAROV	{"phone": "+70759910980"}
0005435340279	2BC752	5030 993643	SVETLANA ZAKHAROVA	{"phone": "+70727227557"}
0005435340280	EEAFFF	2432 500092	ALEKSEY EGOROV	{"phone": "+70665736104"}
0005435340281	EEAFFF	8325 921802	IGOR MELNIKOV	{"email": "melnikovi_13081960@postgrespro.ru", "phone": "+70224263823"}
0005435340282	92B1BD	9425 691777	VYACHESLAV MOROZOV	{"email": "morozov.vyacheslav121981@postgrespro.ru", "phone": "+70198761547"}
0005435340283	7FC5E5	1233 260245	OLEG GERASIMOV	{"phone": "+70991739690"}
0005435340284	D502ED	9284 887735	GALINA NOVIKOVA	{"email": "novikovagalina1968@postgrespro.ru", "phone": "+70181524290"}
0005435340285	D502ED	2496 561325	IVAN GUSEV	{"email": "igusev_03081985@postgrespro.ru", "phone": "+70993010477"}
0005435340286	D502ED	1161 399595	SERGEY IVANOV	{"phone": "+70470174967"}
0005435340287	050426	6568 334442	VIKTOR KUZMIN	{"phone": "+70573101924"}
0005435340288	DEE995	4447 499228	KSENIYA MAKAROVA	{"phone": "+70686327904"}
0005435340289	93C50D	8932 629728	DANIIL PETROV	{"email": "petrov_d-1978@postgrespro.ru", "phone": "+70515732693"}
0005435340290	93C50D	3584 264328	NATALYA NIKITINA	{"email": "natalyanikitina_1968@postgrespro.ru", "phone": "+70636699378"}
0005435340291	4BD1DE	1971 005658	ANTON MARTYNOV	{"email": "anton.martynov-021968@postgrespro.ru", "phone": "+70472549299"}
0005435340292	FF34C6	2645 393737	ASKHAT OSIPOV	{"phone": "+70921242169"}
0005435340293	AF7F45	1155 037143	ALEKSANDR KUZNECOV	{"phone": "+70016222615"}
0005435340294	7A24F7	8687 778902	VIKTORIYA ORLOVA	{"phone": "+70219488121"}
0005435340295	7A24F7	2521 041479	LYUDMILA KOVALEVA	{"phone": "+70774746776"}
0005435340296	D72421	7816 349972	SVETLANA GRISHINA	{"email": "sgrishina-1973@postgrespro.ru", "phone": "+70237350940"}
0005435340297	F07605	0890 572395	ANTON IVANOV	{"phone": "+70200628595"}
0005435340298	E6406C	6011 242384	NINA GUSEVA	{"email": "nina-guseva_03121969@postgrespro.ru", "phone": "+70952172730"}
0005435340299	5C1B2D	9161 555501	EKATERINA SMIRNOVA	{"email": "ekaterina.smirnova-07021972@postgrespro.ru", "phone": "+70583600537"}
0005435340300	49B063	0454 589797	ILYA MIKHAYLOV	{"phone": "+70197364915"}
0005435340301	49B063	3747 273047	ALEKSEY ANDREEV	{"email": "a_andreev_22071966@postgrespro.ru", "phone": "+70136889928"}
0005435340302	A9A224	7522 123738	EKATERINA SOKOLOVA	{"phone": "+70348598821"}
0005435340303	34EFA6	0848 577143	ANATOLIY POPOV	{"phone": "+70001877563"}
0005435340304	34EFA6	9932 377699	SERGEY YAKOVLEV	{"email": "syakovlev19121970@postgrespro.ru", "phone": "+70748385393"}
0005435340305	508172	2017 185184	SERGEY PAVLOV	{"phone": "+70276422108"}
0005435340306	ADB97A	2748 924486	TAMARA FADEEVA	{"email": "fadeeva.t.091978@postgrespro.ru", "phone": "+70938738548"}
0005435340307	ADB97A	9688 318994	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin.1976@postgrespro.ru", "phone": "+70367878096"}
0005435340308	1D0208	6815 855490	IVAN NAUMOV	{"email": "naumovivan.041977@postgrespro.ru", "phone": "+70271101614"}
0005435340309	1D0208	5404 587478	DANILA KUZNECOV	{"email": "kuznecov_danila1977@postgrespro.ru", "phone": "+70308622911"}
0005435340310	1D0208	0223 448482	ANATOLIY POPOV	{"phone": "+70766648076"}
0005435340311	699CAD	0682 933784	NADEZHDA MAKSIMOVA	{"phone": "+70275508055"}
0005435340312	2DAFE0	2434 008328	OLEG MAKAROV	{"email": "makarov_o-21021968@postgrespro.ru", "phone": "+70335476872"}
0005435340313	2DAFE0	9417 597845	ALEKSANDR SOROKIN	{"email": "sorokin_aleksandr061985@postgrespro.ru", "phone": "+70153965582"}
0005435340314	CD380A	5149 354102	IRINA IVANOVA	{"email": "irina.ivanova-01121969@postgrespro.ru", "phone": "+70110042333"}
0005435340315	CD380A	0413 254712	TATYANA MAKSIMOVA	{"email": "maksimova_tatyana.021966@postgrespro.ru", "phone": "+70588897799"}
0005435340316	AF8440	0890 385881	MARGARITA MOROZOVA	{"phone": "+70376215616"}
0005435340317	40CD08	7558 656782	TATYANA DMITRIEVA	{"phone": "+70473890608"}
0005435340318	86DE4B	3547 120619	OKSANA MIRONOVA	{"phone": "+70609481617"}
0005435340319	13E9AF	9880 784662	IVAN MIRONOV	{"email": "imironov101962@postgrespro.ru", "phone": "+70698017541"}
0005435340320	13E9AF	1785 876114	MARIYA KUZNECOVA	{"phone": "+70647746165"}
0005435340321	D3AAC4	5133 232394	VYACHESLAV BARANOV	{"phone": "+70862606412"}
0005435340322	98A880	5676 638286	VIKTOR NIKOLAEV	{"email": "nikolaev_v.1974@postgrespro.ru", "phone": "+70718526814"}
0005435340323	98A880	6676 567051	ALSU MIKHAYLOVA	{"phone": "+70960007187"}
0005435340324	E62A6F	8857 258507	VASILIY BORISOV	{"email": "vasiliy_borisov_05041967@postgrespro.ru", "phone": "+70515810989"}
0005435340325	2C73CD	8248 637893	SERGEY VASILEV	{"email": "vasilev.sergey.20061977@postgrespro.ru", "phone": "+70168777601"}
0005435340326	A02C8D	7341 150091	VLADIMIR MEDVEDEV	{"email": "v.medvedev.041973@postgrespro.ru", "phone": "+70262952286"}
0005435340327	4FF449	0967 740940	SVETLANA DANILOVA	{"phone": "+70918639614"}
0005435340328	4FF449	2294 865893	ELENA FOMINA	{"phone": "+70261438404"}
0005435340329	C824AF	0721 297903	VALERIYA MEDVEDEVA	{"phone": "+70779346390"}
0005435340330	C824AF	0031 368198	ALINA LUKYANOVA	{"email": "lukyanova-a-1981@postgrespro.ru", "phone": "+70270518829"}
0005435340331	C824AF	8688 589520	LYUDMILA MOROZOVA	{"email": "lyudmila_morozova-1964@postgrespro.ru", "phone": "+70379548707"}
0005435340332	C824AF	7425 767299	EKATERINA SOLOVEVA	{"phone": "+70382752221"}
0005435340333	DB3FE7	8988 146117	GENNADIY ZAYCEV	{"phone": "+70199599219"}
0005435340334	D6CD84	9190 493963	SERGEY AFANASEV	{"email": "s-afanasev.01071978@postgrespro.ru", "phone": "+70195062364"}
0005435340335	D6CD84	9153 576814	SERGEY VASILEV	{"email": "vasilevsergey.121957@postgrespro.ru", "phone": "+70951644974"}
0005435340336	3C0378	1831 274597	ALENA NIKITINA	{"email": "nikitina_a.15031975@postgrespro.ru", "phone": "+70353516340"}
0005435340337	7FD5D8	6744 456401	SERGEY SOROKIN	{"email": "sorokin_sergey_1970@postgrespro.ru", "phone": "+70548170255"}
0005435340338	A98967	7793 700034	ELENA ZAKHAROVA	{"email": "zakharova_elena_1960@postgrespro.ru", "phone": "+70927111803"}
0005435340339	A98967	0024 108815	NIKITA RODIONOV	{"phone": "+70942702861"}
0005435340340	3BDCF7	9561 073584	LIDIYA GUSEVA	{"phone": "+70980503849"}
0005435340341	21B44D	5810 735774	ANDREY MOISEEV	{"email": "moiseevandrey13051974@postgrespro.ru", "phone": "+70083166158"}
0005435340342	843E96	9832 440814	OLESYA IVANOVA	{"phone": "+70395030741"}
0005435340343	0C5043	1257 807034	ELVIRA ZOTOVA	{"email": "zotova_e_071968@postgrespro.ru", "phone": "+70827639504"}
0005435340344	0C5043	3420 397248	LYUBOV SOKOLOVA	{"email": "lyubov.sokolova-28051964@postgrespro.ru", "phone": "+70312728463"}
0005435340345	5CC038	2004 877888	DMITRIY DENISOV	{"phone": "+70754256484"}
0005435340346	B5D905	3443 228146	VIKTORIYA SEMENOVA	{"phone": "+70757369755"}
0005435340347	B5D905	9464 955346	VLADIMIR FROLOV	{"email": "vfrolov.091984@postgrespro.ru", "phone": "+70726266441"}
0005435340348	6D9FA9	1137 447771	PAVEL KAZAKOV	{"email": "kazakovp_121965@postgrespro.ru", "phone": "+70710818326"}
0005435340349	D882B7	5052 228575	VYACHESLAV NOVIKOV	{"email": "novikovvyacheslav-1972@postgrespro.ru", "phone": "+70252394898"}
0005435340350	225E78	0548 495395	NATALYA IVANOVA	{"email": "nivanova.051976@postgrespro.ru", "phone": "+70384962612"}
0005435340351	184BC4	2799 937908	MARIYA DAVYDOVA	{"phone": "+70617060625"}
0005435340352	10727B	9782 444488	OLGA DAVYDOVA	{"email": "o-davydova_1968@postgrespro.ru", "phone": "+70508867380"}
0005435340353	6781B0	7741 014248	LYUDMILA NESTEROVA	{"phone": "+70536156318"}
0005435340354	863174	4715 393179	IRINA KISELEVA	{"email": "kiseleva-i_1970@postgrespro.ru", "phone": "+70385058604"}
0005435340355	18229B	3659 826937	NATALYA VLASOVA	{"phone": "+70545618342"}
0005435340356	E9C76B	6691 141051	IGOR DAVYDOV	{"email": "idavydov-01051971@postgrespro.ru", "phone": "+70977952693"}
0005435340357	E9C76B	9186 431351	VIKTOR DMITRIEV	{"email": "v-dmitriev.29081975@postgrespro.ru", "phone": "+70144137942"}
0005435340358	BA3EFF	4535 890642	VIKTOR KULIKOV	{"email": "kulikov_viktor_1976@postgrespro.ru", "phone": "+70441906202"}
0005435340359	9D3649	1819 251372	VLADIMIR NIKOLAEV	{"phone": "+70296560623"}
0005435340360	9D3649	8475 309729	ALEKSEY DMITRIEV	{"phone": "+70418958821"}
0005435340361	C90D2E	9077 677427	VLADIMIR GUSEV	{"phone": "+70074616203"}
0005435340362	C90D2E	5892 921313	VYACHESLAV NIKITIN	{"email": "nikitin-v_11081968@postgrespro.ru", "phone": "+70884377809"}
0005435340363	E627FB	0696 027421	SERGEY FILIPPOV	{"email": "filippov_s011982@postgrespro.ru", "phone": "+70756990202"}
0005435340364	ED414C	3095 496999	YURIY TARASOV	{"email": "tarasov-yuriy.19071973@postgrespro.ru", "phone": "+70310768806"}
0005435340365	08495B	4625 310929	VLADIMIR SEMENOV	{"email": "semenov_v.071973@postgrespro.ru", "phone": "+70245178623"}
0005435340366	441C35	1263 915841	TATYANA YUDINA	{"phone": "+70602619889"}
0005435340367	441C35	4869 833613	ALEKSANDR NOVIKOV	{"phone": "+70921280145"}
0005435340368	B0F8EA	2280 434970	SVETLANA VOROBEVA	{"email": "vorobeva-svetlana.1972@postgrespro.ru", "phone": "+70959476656"}
0005435340369	B4F770	0123 974351	VALERIY SMIRNOV	{"email": "valeriy_smirnov-041961@postgrespro.ru", "phone": "+70454795690"}
0005435340370	515FD2	9660 420731	SERGEY MARTYNOV	{"phone": "+70198334535"}
0005435340371	389370	2881 902976	VLADIMIR ZAYCEV	{"phone": "+70200350605"}
0005435340372	1C7E8F	2350 912983	ALEKSANDR FILIPPOV	{"phone": "+70335503139"}
0005435340373	1C7E8F	0951 895213	VLADIMIR KONOVALOV	{"phone": "+70929666559"}
0005435340374	792BA9	3200 560256	VADIM GORBUNOV	{"email": "gorbunov_v091965@postgrespro.ru", "phone": "+70273304102"}
0005435340375	53B021	2393 578842	ZINAIDA PAVLOVA	{"email": "pavlova-z-10101977@postgrespro.ru", "phone": "+70661344922"}
0005435340376	A4ACF3	4178 501470	RASIM BARANOV	{"phone": "+70182844470"}
0005435340377	B9BB65	7789 950356	DARYA EGOROVA	{"email": "d.egorova-051962@postgrespro.ru", "phone": "+70881793160"}
0005435340378	12FBA9	9317 004886	VASILIY IVANOV	{"phone": "+70105272608"}
0005435340379	3813FB	9140 043703	MIKHAIL KUZMIN	{"email": "mkuzmin071966@postgrespro.ru", "phone": "+70660882278"}
0005435340380	9D87B6	4146 402695	OLEG SOLOVEV	{"phone": "+70697321587"}
0005435340381	7A5898	7746 390121	MATVEY FILIPPOV	{"phone": "+70708878876"}
0005435340382	B552F5	5816 413102	ILYA SCHERBAKOV	{"email": "i_scherbakov_01121974@postgrespro.ru", "phone": "+70537124798"}
0005435340383	85DF45	9040 040483	IRINA ZAYCEVA	{"email": "zayceva.irina_1966@postgrespro.ru", "phone": "+70521694830"}
0005435340384	A6C446	2228 363308	TAMARA EFIMOVA	{"phone": "+70780721177"}
0005435340385	A6C446	5731 386218	VLADIMIR KUZNECOV	{"phone": "+70807597825"}
0005435340386	16C0F6	5482 200489	TATYANA BELOVA	{"email": "t.belova1981@postgrespro.ru", "phone": "+70060971081"}
0005435340387	A1F7A6	9369 619467	TAISIYA SERGEEVA	{"phone": "+70012218205"}
0005435340388	77F8F8	1564 628571	RASIM MATVEEV	{"phone": "+70093370315"}
0005435340389	C986EA	1087 370692	DAVID NIKITIN	{"email": "nikitin_david-1975@postgrespro.ru", "phone": "+70240816640"}
0005435340390	FC63E4	2998 434437	ANTONINA PAVLOVA	{"email": "pavlova.a_1975@postgrespro.ru", "phone": "+70629487520"}
0005435340391	2D1F5F	0004 049441	LIDIYA POPOVA	{"email": "lidiya.popova_091951@postgrespro.ru", "phone": "+70945503582"}
0005435340392	AFAA64	3512 358161	YULIYA POPOVA	{"phone": "+70396715655"}
0005435340393	AFAA64	3189 217081	IRINA KONOVALOVA	{"phone": "+70665978483"}
0005435340394	AFAA64	7106 746605	SERGEY FROLOV	{"email": "s-frolov081967@postgrespro.ru", "phone": "+70513332918"}
0005435340395	F97FA8	5060 569638	MARIYA EGOROVA	{"email": "m-egorova28071973@postgrespro.ru", "phone": "+70199654155"}
0005435340396	917BA5	5110 254084	GALINA ANDREEVA	{"phone": "+70413280281"}
0005435340397	917BA5	3934 660093	VERA KOROLEVA	{"email": "koroleva-v-15021975@postgrespro.ru", "phone": "+70512481092"}
0005435340398	1BB3ED	7780 644445	VERA BELOVA	{"phone": "+70562886643"}
0005435340399	595232	7784 804700	ROZA MATVEEVA	{"phone": "+70567596947"}
0005435340400	83AAD2	4740 247910	ANTON NIKOLAEV	{"email": "nikolaev.a.11091967@postgrespro.ru", "phone": "+70829802720"}
0005435340401	908BAC	2112 133788	ALEKSANDR KOROLEV	{"phone": "+70821625279"}
0005435340402	56B8C8	4946 320502	OLGA ABRAMOVA	{"email": "abramova.o-06041986@postgrespro.ru", "phone": "+70578192670"}
0005435340403	56B8C8	5917 708144	ANDREY BORISOV	{"email": "andreyborisov.1967@postgrespro.ru", "phone": "+70553446918"}
0005435340404	B4284F	6699 747847	DENIS VASILEV	{"phone": "+70258336992"}
0005435340405	B4284F	7710 983281	NIKITA ZHURAVLEV	{"phone": "+70046616542"}
0005435340406	A1F152	1614 053915	MARK VOROBEV	{"email": "vorobev.mark-091965@postgrespro.ru", "phone": "+70757804273"}
0005435340407	A1F152	3121 324384	VIKTOR RODIONOV	{"phone": "+70194662220"}
0005435340408	D8EA54	5560 273048	VIKTORIYA NAZAROVA	{"email": "nazarova-v061975@postgrespro.ru", "phone": "+70037936641"}
0005435340409	13CB5A	7626 651698	ANASTASIYA IVANOVA	{"email": "anastasiya.ivanova-11011969@postgrespro.ru", "phone": "+70687605046"}
0005435340410	14E479	1557 351759	VALENTINA KOROLEVA	{"email": "valentina-koroleva081969@postgrespro.ru", "phone": "+70797861166"}
0005435340411	14E479	3247 883035	NADEZHDA MELNIKOVA	{"email": "melnikovanadezhda011981@postgrespro.ru", "phone": "+70121164878"}
0005435340412	14E479	1462 593357	ALISA KOROLEVA	{"phone": "+70438460916"}
0005435340413	5C370B	7604 313170	ALEKSEY MIKHAYLOV	{"phone": "+70166787442"}
0005435340414	5C370B	0643 613864	IRINA GAVRILOVA	{"phone": "+70992522585"}
0005435340415	07768C	2948 710642	EVDOKIYA ILINA	{"email": "ilina_evdokiya081965@postgrespro.ru", "phone": "+70565021180"}
0005435340416	07768C	2948 640369	VALENTINA PAVLOVA	{"email": "pavlova-v_24101981@postgrespro.ru", "phone": "+70400681418"}
0005435340417	CDF1CA	2316 395957	VLADIMIR ANDREEV	{"email": "andreev-v_04071969@postgrespro.ru", "phone": "+70103377879"}
0005435340418	CDF1CA	5110 971841	SERGEY NAZAROV	{"phone": "+70672822710"}
0005435340419	DDF548	5411 653646	NATALYA ANDREEVA	{"email": "andreeva.n07011973@postgrespro.ru", "phone": "+70924689669"}
0005435340420	DDF548	3448 071384	EGOR MELNIKOV	{"email": "emelnikov.011981@postgrespro.ru", "phone": "+70629377652"}
0005435340421	DDF548	3980 318587	NADEZHDA POPOVA	{"email": "nadezhdapopova.1970@postgrespro.ru", "phone": "+70773531935"}
0005435340422	3267C3	7333 463459	YURIY BORISOV	{"phone": "+70848329338"}
0005435340423	D20122	6489 051305	KLAVDIYA DANILOVA	{"phone": "+70121366060"}
0005435340424	A3EED1	0055 140440	NADEZHDA PETROVA	{"phone": "+70355550096"}
0005435340425	F4669F	3636 352771	SVETLANA PETROVA	{"email": "s-petrova.31101981@postgrespro.ru", "phone": "+70894342764"}
0005435340426	CBC1CE	2936 402901	ALEKSANDR GORBUNOV	{"email": "gorbunova28041974@postgrespro.ru", "phone": "+70981602265"}
0005435340427	CBC1CE	3849 001532	VIKTORIYA KONDRATEVA	{"phone": "+70126237780"}
0005435340428	CCA562	1028 118059	ANATOLIY KUZNECOV	{"phone": "+70823912168"}
0005435340429	0E1BC1	7524 389954	SERGEY SIDOROV	{"phone": "+70445557125"}
0005435340430	0E1BC1	0704 409599	ALEVTINA ILINA	{"phone": "+70021920187"}
0005435340431	0E1BC1	0763 254054	OLGA ROMANOVA	{"email": "romanovaolga_1973@postgrespro.ru", "phone": "+70156919511"}
0005435340432	0E1BC1	4890 676466	YULIYA SCHERBAKOVA	{"phone": "+70670811427"}
0005435340433	B7983B	2013 075137	ANNA ABRAMOVA	{"email": "abramovaanna-1970@postgrespro.ru", "phone": "+70397426971"}
0005435340434	170EB4	8969 931495	VERA DANILOVA	{"phone": "+70855562424"}
0005435340435	2B75C5	9546 320995	VASILIY ANTONOV	{"email": "antonov-v.16071978@postgrespro.ru", "phone": "+70983852807"}
0005435340436	2B75C5	7156 407036	ALEFTINA EGOROVA	{"email": "aleftina-egorova-1964@postgrespro.ru", "phone": "+70944647820"}
0005435340437	906302	6592 844000	ALEKSEY FILIPPOV	{"email": "filippov_a_26041968@postgrespro.ru", "phone": "+70066441796"}
0005435340438	906302	0681 953362	VIKTOR BORISOV	{"phone": "+70182222461"}
0005435340439	C185E1	9990 088289	VIKTOR STEPANOV	{"phone": "+70407833735"}
0005435340440	C185E1	6954 391462	TATYANA TROFIMOVA	{"phone": "+70451780001"}
0005435340441	C185E1	7924 220628	OLESYA CHERNOVA	{"email": "olesya-chernova1988@postgrespro.ru", "phone": "+70152969056"}
0005435340442	ED6EFD	5090 600234	LIDIYA TARASOVA	{"phone": "+70594339551"}
0005435340443	ECC5E5	7994 917763	NINA ROMANOVA	{"phone": "+70349535170"}
0005435340444	5602F4	0511 966343	SERGEY MAKAROV	{"email": "s.makarov_1976@postgrespro.ru", "phone": "+70619334556"}
0005435340445	245E40	3974 591223	IVAN KUZNECOV	{"phone": "+70907049492"}
0005435340446	207E46	8335 343731	MIKHAIL SOKOLOV	{"email": "sokolovm-031978@postgrespro.ru", "phone": "+70687834897"}
0005435340447	207E46	9732 947047	NINA FROLOVA	{"email": "frolova-nina.1970@postgrespro.ru", "phone": "+70339899902"}
0005435340448	207E46	8972 153123	KIRILL ZHUKOV	{"email": "zhukov_kirill.1963@postgrespro.ru", "phone": "+70318191971"}
0005435340449	65BF44	9621 305441	VALERIY IVANOV	{"phone": "+70337114270"}
0005435340450	8D2A2A	1766 784018	YURIY SIDOROV	{"phone": "+70956572890"}
0005435340451	8D2A2A	1182 897139	ROMAN KONOVALOV	{"email": "konovalov-roman-051975@postgrespro.ru", "phone": "+70777411660"}
0005435340452	0A4D58	1978 190273	MARINA IVANOVA	{"phone": "+70687021589"}
0005435340453	99CDB4	0292 259530	ALEKSANDR KUZNECOV	{"phone": "+70641847264"}
0005435340454	8ED137	8733 392868	ANASTASIYA KUZNECOVA	{"email": "anastasiya.kuznecova29061971@postgrespro.ru", "phone": "+70991435453"}
0005435340455	0DFC21	1469 174723	OLGA KUZNECOVA	{"email": "kuznecovao_25041983@postgrespro.ru", "phone": "+70144748993"}
0005435340456	7DD415	7835 666826	MARIYA KONDRATEVA	{"email": "m_kondrateva.1973@postgrespro.ru", "phone": "+70497647132"}
0005435340457	6CD210	4778 685916	RAISA GERASIMOVA	{"email": "raisagerasimova_1950@postgrespro.ru", "phone": "+70953463994"}
0005435340458	6CD210	8091 796543	ANNA KUZNECOVA	{"email": "a_kuznecova_101957@postgrespro.ru", "phone": "+70974815291"}
0005435340459	364B7B	9595 855849	GALINA TIMOFEEVA	{"email": "galina.timofeeva-111966@postgrespro.ru", "phone": "+70691133065"}
0005435340460	364B7B	8220 212455	KONSTANTIN VASILEV	{"email": "k.vasilev_071979@postgrespro.ru", "phone": "+70936143219"}
0005435340461	0C53C9	6556 147735	VLADIMIR EGOROV	{"email": "egorovvladimir_061971@postgrespro.ru", "phone": "+70907218003"}
0005435340462	C86305	1058 364583	EKATERINA MAKAROVA	{"email": "makarova_ekaterina20091966@postgrespro.ru", "phone": "+70633135984"}
0005435340463	DFF98F	2337 133637	ALEKSEY SIDOROV	{"phone": "+70476407250"}
0005435340464	7ABC42	7177 224411	VERA SMIRNOVA	{"email": "v.smirnova.25071963@postgrespro.ru", "phone": "+70209383763"}
0005435340465	EE28C7	3652 161200	SERGEY FEDOROV	{"email": "sergey.fedorov1972@postgrespro.ru", "phone": "+70487930485"}
0005435340466	242E2C	5772 253010	GALINA FROLOVA	{"email": "galina.frolova1959@postgrespro.ru", "phone": "+70502497467"}
0005435340467	2599D3	4075 767500	EKATERINA ORLOVA	{"email": "ekaterinaorlova-25051976@postgrespro.ru", "phone": "+70996757176"}
0005435340468	903ACF	2291 706639	KRISTINA IVANOVA	{"phone": "+70737192766"}
0005435340469	D5E1F2	6187 777918	VALENTINA BARANOVA	{"email": "baranova_valentina_20121970@postgrespro.ru", "phone": "+70427267719"}
0005435340470	D5E1F2	4222 812395	NINA KUZNECOVA	{"email": "n-kuznecova-03051969@postgrespro.ru", "phone": "+70328861286"}
0005435340471	D5E1F2	6680 222321	EKATERINA KUZNECOVA	{"phone": "+70609147604"}
0005435340472	717097	0289 476104	NATALYA FILIPPOVA	{"email": "nfilippova.011978@postgrespro.ru", "phone": "+70003523476"}
0005435340473	717097	2363 566330	NADEZHDA MOROZOVA	{"phone": "+70628261775"}
0005435340474	51E59E	9455 250120	SERGEY VLASOV	{"phone": "+70783090300"}
0005435340475	C11D1A	6705 199614	RUSLAN ABRAMOV	{"email": "abramovr1989@postgrespro.ru", "phone": "+70588200692"}
0005435340476	C11D1A	3344 692655	RASIM RODIONOV	{"email": "rodionov_rasim_1970@postgrespro.ru", "phone": "+70041634085"}
0005435340477	C11D1A	6494 945862	ANASTASIYA EGOROVA	{"phone": "+70270099979"}
0005435340478	E16C0E	8640 967694	VITALIY ILIN	{"phone": "+70350098798"}
0005435340479	B44A7F	1395 897466	ROMAN SOROKIN	{"email": "sorokin-r.1976@postgrespro.ru", "phone": "+70189157460"}
0005435340480	BDB2C3	7094 821702	ANDREY KAZAKOV	{"email": "a.kazakov.22031979@postgrespro.ru", "phone": "+70819005294"}
0005435340481	39F045	4853 870881	NATALYA CHERNOVA	{"email": "chernova.n051978@postgrespro.ru", "phone": "+70739796663"}
0005435340482	39F045	2345 844638	ANDREY FILIPPOV	{"email": "andreyfilippov_1971@postgrespro.ru", "phone": "+70133699399"}
0005435340483	00E8D6	8896 407318	ANTON MARTYNOV	{"phone": "+70536485540"}
0005435340484	31BE81	5495 774522	IGOR IVANOV	{"phone": "+70441060991"}
0005435340485	CDCF3E	7360 814935	OLESYA EFREMOVA	{"phone": "+70601466589"}
0005435340486	EDDA4D	2202 407639	GULNARA CHERNOVA	{"phone": "+70515716180"}
0005435340487	EDDA4D	4856 561637	VLADISLAV DMITRIEV	{"email": "vladislav-dmitriev-12021973@postgrespro.ru", "phone": "+70451822186"}
0005435340488	2F19AA	0093 390260	ALEKSANDR TIMOFEEV	{"email": "timofeev_aleksandr18061969@postgrespro.ru", "phone": "+70103449411"}
0005435340489	FF18CC	2633 232727	DANIIL ISAEV	{"phone": "+70522927760"}
0005435340490	2A922C	5094 125938	YURIY ROMANOV	{"phone": "+70093769764"}
0005435340491	167D96	1160 971341	ALEKSANDR VLASOV	{"email": "avlasov.1961@postgrespro.ru", "phone": "+70220543353"}
0005435340492	C21CDA	5010 142439	NINA SAVELEVA	{"email": "saveleva-n-011961@postgrespro.ru", "phone": "+70506284822"}
0005435340493	31D47B	0513 758403	GALINA EFIMOVA	{"email": "gefimova.02101970@postgrespro.ru", "phone": "+70417501457"}
0005435340494	E5C194	8712 177433	NADEZHDA FROLOVA	{"email": "nadezhdafrolova_041983@postgrespro.ru", "phone": "+70069343943"}
0005435340495	0B32E6	5699 734956	ANDREY PAVLOV	{"email": "pavlovandrey_061978@postgrespro.ru", "phone": "+70356380614"}
0005435340496	0B32E6	9968 164874	NINA NIKOLAEVA	{"email": "nikolaevanina19111967@postgrespro.ru", "phone": "+70153405695"}
0005435340497	DF5479	0506 555759	EKATERINA KAZAKOVA	{"email": "kazakova.ekaterina.1979@postgrespro.ru", "phone": "+70988579936"}
0005435340498	ABF97E	6992 809606	IGOR KAZAKOV	{"email": "kazakovigor.041974@postgrespro.ru", "phone": "+70814672731"}
0005435340499	285488	3264 086300	OLEG MELNIKOV	{"phone": "+70033292461"}
0005435340500	3F923E	6138 114845	SHAMIL KRASNOV	{"email": "krasnov.shamil.04031979@postgrespro.ru", "phone": "+70750203349"}
0005435340501	2A4D3F	5761 942411	YANINA DENISOVA	{"email": "yanina_denisova31011979@postgrespro.ru", "phone": "+70614704988"}
0005435340502	D5C48C	1181 500336	ARTEM KUDRYASHOV	{"email": "akudryashov.1965@postgrespro.ru", "phone": "+70668511479"}
0005435340503	62EEEF	5713 199803	ALEKSEY FROLOV	{"email": "frolovaleksey_121974@postgrespro.ru", "phone": "+70402978751"}
0005435340504	62EEEF	8331 870264	MARIYA ABRAMOVA	{"email": "mariya-abramova-021972@postgrespro.ru", "phone": "+70937091111"}
0005435340505	D43F22	4405 478179	ANASTASIYA LUKYANOVA	{"email": "lukyanovaa1973@postgrespro.ru", "phone": "+70908020748"}
0005435340506	A8F5DA	7036 178566	DMITRIY ANDREEV	{"phone": "+70662707248"}
0005435340507	859136	9477 103347	NIKOLAY SOROKIN	{"email": "nikolaysorokin.081969@postgrespro.ru", "phone": "+70624756217"}
0005435340508	808BAB	9692 059060	ELEONORA FOMINA	{"email": "eleonora_fomina.091970@postgrespro.ru", "phone": "+70338101247"}
0005435340509	808BAB	4707 525602	NATALYA IVANOVA	{"email": "ivanovanatalya-021972@postgrespro.ru", "phone": "+70574354732"}
0005435340510	C16F73	3349 692936	OLGA NAZAROVA	{"email": "nazarovaolga_28111967@postgrespro.ru", "phone": "+70721642750"}
0005435340511	EDFB55	7968 767607	VALENTINA KOROLEVA	{"email": "v.koroleva_21061977@postgrespro.ru", "phone": "+70293408704"}
0005435340512	DBB92C	2469 426614	LEONID BARANOV	{"phone": "+70098127993"}
0005435340513	37C4C6	2445 720508	NINA ROMANOVA	{"phone": "+70411486208"}
0005435340514	37C4C6	5008 859677	ANASTASIYA KOZLOVA	{"email": "anastasiya_kozlova26061985@postgrespro.ru", "phone": "+70117383435"}
0005435340515	DEA491	8799 411045	ELIZAVETA MIKHAYLOVA	{"email": "mikhaylovaelizaveta-111965@postgrespro.ru", "phone": "+70976429839"}
0005435340516	52317C	9555 001230	SERGEY DMITRIEV	{"email": "sergey.dmitriev-19061977@postgrespro.ru", "phone": "+70154140409"}
0005435340517	52317C	2894 089982	PAVEL BELOV	{"phone": "+70848595211"}
0005435340518	52317C	1925 492945	ANASTASIYA STEPANOVA	{"email": "a_stepanova_1983@postgrespro.ru", "phone": "+70927600987"}
0005435340519	6F85FE	2728 421784	OLEG AFANASEV	{"phone": "+70677354978"}
0005435340520	43377F	2689 264928	LYUDMILA PAVLOVA	{"email": "pavlova.lyudmila_041972@postgrespro.ru", "phone": "+70606600123"}
0005435340521	43377F	0643 325858	ALEKSANDR STEPANOV	{"phone": "+70302248458"}
0005435340522	4B865C	4255 109621	NIKOLAY SEMENOV	{"phone": "+70842853613"}
0005435340523	DE9ACA	4517 628119	ALLA VOLKOVA	{"phone": "+70048265022"}
0005435340524	0F37A8	5327 881186	ALEKSANDRA MATVEEVA	{"phone": "+70815642157"}
0005435340525	405A27	1767 288013	NINA MAKAROVA	{"phone": "+70863097038"}
0005435340526	68CE91	2225 791106	ALEKSEY DMITRIEV	{"phone": "+70337834085"}
0005435340527	900779	3062 607942	DMITRIY NIKOLAEV	{"phone": "+70074244174"}
0005435340528	9722B5	8766 583107	VYACHESLAV SERGEEV	{"phone": "+70401558459"}
0005435340529	AEEB7C	8283 364054	SERGEY MOISEEV	{"phone": "+70141934322"}
0005435340530	093D21	6904 134972	VIKTORIYA FADEEVA	{"email": "viktoriya.fadeeva.1976@postgrespro.ru", "phone": "+70825150753"}
0005435340531	9108A1	3820 994541	DMITRIY ZAYCEV	{"email": "d.zaycev_17091969@postgrespro.ru", "phone": "+70943499083"}
0005435340532	9108A1	7506 843120	VARVARA ZHURAVLEVA	{"email": "zhuravlevavarvara_21011969@postgrespro.ru", "phone": "+70158871363"}
0005435340533	1D0F42	5818 129008	LYUBOV ZHURAVLEVA	{"email": "zhuravleva-l.1970@postgrespro.ru", "phone": "+70743173641"}
0005435340534	76314C	5264 277480	ALEKSANDRA MIKHAYLOVA	{"email": "mikhaylova.aleksandra23081960@postgrespro.ru", "phone": "+70524204570"}
0005435340535	665660	6341 647711	BORIS KULIKOV	{"phone": "+70068477721"}
0005435340536	665660	5463 870541	ALEKSANDR GUSEV	{"phone": "+70232371592"}
0005435340537	6DA896	0074 115129	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev.1970@postgrespro.ru", "phone": "+70169874226"}
0005435340538	7B5CDF	1367 797106	STANISLAV POPOV	{"phone": "+70553715796"}
0005435340539	275DB4	5159 371084	RUSLAN TIKHONOV	{"phone": "+70382406548"}
0005435340540	F3BEB2	6143 245162	RIMMA EFIMOVA	{"email": "efimovar.051975@postgrespro.ru", "phone": "+70311290639"}
0005435340541	D560A1	5236 673777	VLADIMIR OSIPOV	{"phone": "+70323800632"}
0005435340542	940DBF	8838 406666	ZARINA NIKOLAEVA	{"email": "nikolaeva_z-1980@postgrespro.ru", "phone": "+70323687350"}
0005435340543	B828AD	4499 496597	RAISA POPOVA	{"email": "popova_raisa071967@postgrespro.ru", "phone": "+70825785433"}
0005435340544	B828AD	2027 557852	VIKTORIYA ISAEVA	{"phone": "+70402319062"}
0005435340545	2CEA09	8341 187200	SERGEY TARASOV	{"phone": "+70693910763"}
0005435340546	4578F6	1471 175384	FANIYA VASILEVA	{"email": "vasileva_faniya-111967@postgrespro.ru", "phone": "+70772256024"}
0005435340547	C417CE	9577 461655	VLADIMIR SHEVCHENKO	{"phone": "+70076070223"}
0005435340548	C417CE	6194 739006	DIANA SAVELEVA	{"phone": "+70352926038"}
0005435340549	C417CE	4192 570922	DMITRIY KUZMIN	{"email": "kuzmin_d.04111969@postgrespro.ru", "phone": "+70999869937"}
0005435340550	C417CE	5529 069940	TATYANA ALEKSANDROVA	{"phone": "+70583081540"}
0005435340551	B43216	6778 523108	VIKTOR ISAEV	{"email": "isaev.v021981@postgrespro.ru", "phone": "+70990067366"}
0005435340552	B43216	3952 993608	NATALYA SOKOLOVA	{"email": "natalya_sokolova-1979@postgrespro.ru", "phone": "+70708138924"}
0005435340553	E8D25B	6261 922149	ALENA NOVIKOVA	{"phone": "+70241448609"}
0005435340554	6B8D54	9507 291549	ELENA MALYSHEVA	{"email": "malyshevae-101984@postgrespro.ru", "phone": "+70268568610"}
0005435340555	6B8D54	9062 295622	OLEG EGOROV	{"email": "oleg-egorov1975@postgrespro.ru", "phone": "+70218093619"}
0005435340556	812D5B	1795 767928	ALEKSANDR ILIN	{"phone": "+70812241989"}
0005435340557	B4D40F	8623 074696	OLEG ABRAMOV	{"phone": "+70505881314"}
0005435340558	3CE5E7	1288 808017	ANDREY MIKHAYLOV	{"email": "andrey_mikhaylov04111961@postgrespro.ru", "phone": "+70690978412"}
0005435340559	51FCF2	2424 796515	VLADISLAV KUZNECOV	{"phone": "+70280224747"}
0005435340560	61025A	6692 603388	VALERIY DAVYDOV	{"phone": "+70860348486"}
0005435340561	3EE67E	6954 626018	ANATOLIY ZHUKOV	{"email": "anatoliyzhukov-081966@postgrespro.ru", "phone": "+70959780086"}
0005435340562	F3011F	3867 113154	DMITRIY BARANOV	{"email": "baranov_dmitriy.051972@postgrespro.ru", "phone": "+70171461547"}
0005435340563	741747	0553 693296	SERGEY ALEKSANDROV	{"email": "saleksandrov1965@postgrespro.ru", "phone": "+70998163404"}
0005435340564	7095EF	0280 699046	IRINA MAKAROVA	{"email": "irinamakarova_03091975@postgrespro.ru", "phone": "+70318436174"}
0005435340565	7095EF	9282 716377	IVAN ZHUKOV	{"phone": "+70664081405"}
0005435340566	D83641	1762 197849	NADEZHDA KUZNECOVA	{"phone": "+70972896594"}
0005435340567	3103DD	7225 564507	VALENTINA FEDOROVA	{"phone": "+70677011090"}
0005435340568	3103DD	3833 614370	DAMIR NAUMOV	{"email": "damir_naumov-1968@postgrespro.ru", "phone": "+70521438769"}
0005435340569	353578	6379 498492	SERGEY MAKAROV	{"phone": "+70860654516"}
0005435340570	10D3C8	2782 258514	LYUDMILA LAZAREVA	{"email": "l-lazareva_031965@postgrespro.ru", "phone": "+70441973575"}
0005435340571	10D3C8	6659 454312	ALEKSEY MIKHAYLOV	{"phone": "+70670551785"}
0005435340572	F23B2C	0429 014081	ROMAN ZAKHAROV	{"phone": "+70715178142"}
0005435340573	2BD198	5060 901701	ANNA FROLOVA	{"email": "frolova.a_26061971@postgrespro.ru", "phone": "+70518058086"}
0005435340574	2BD198	3007 115120	LARISA IVANOVA	{"phone": "+70137751446"}
0005435340575	30DC19	9169 027399	EVGENIY OSIPOV	{"email": "evgeniy-osipov_1965@postgrespro.ru", "phone": "+70308308607"}
0005435340576	CE9038	9766 790043	ELENA MOROZOVA	{"phone": "+70811115936"}
0005435340577	CE9038	3789 035732	SVETLANA LEBEDEVA	{"phone": "+70191774967"}
0005435340578	CE9038	9021 160466	ALEKSEY MIRONOV	{"email": "amironov_19071979@postgrespro.ru", "phone": "+70904207403"}
0005435340579	D60C75	3233 484770	VIKTOR GRIGOREV	{"email": "grigorev_v1974@postgrespro.ru", "phone": "+70112686064"}
0005435340580	D60C75	8155 326177	NADEZHDA GUSEVA	{"email": "guseva-nadezhda.111975@postgrespro.ru", "phone": "+70423528341"}
0005435340581	8EDEC7	5625 294519	RISHAT MAKSIMOV	{"email": "maksimov_r.1986@postgrespro.ru", "phone": "+70971350807"}
0005435340582	350CD0	3664 654066	ALEVTINA KOMAROVA	{"phone": "+70834909155"}
0005435340583	350CD0	1073 518395	ALEKSANDRA ABRAMOVA	{"phone": "+70774119948"}
0005435340584	5807C5	6153 480119	ALEKSANDR KOZLOV	{"phone": "+70185007585"}
0005435340585	A80A7E	0496 140360	SERGEY SERGEEV	{"phone": "+70776446309"}
0005435340586	98ACC7	6988 829581	LYUBOV VLASOVA	{"phone": "+70721299936"}
0005435340587	98ACC7	6955 537483	SVETLANA LAZAREVA	{"email": "s_lazareva-04091969@postgrespro.ru", "phone": "+70928706570"}
0005435340588	6CD045	5795 041219	NINA MELNIKOVA	{"email": "melnikova_n-12051974@postgrespro.ru", "phone": "+70643178966"}
0005435340589	F07695	2505 714188	ANDREY DAVYDOV	{"email": "davydov.andrey_20051968@postgrespro.ru", "phone": "+70015066540"}
0005435340590	FA8813	6143 802528	RIM MAKSIMOV	{"email": "maksimov.rim.041978@postgrespro.ru", "phone": "+70226496943"}
0005435340591	012641	6185 556202	SERGEY ZHUKOV	{"phone": "+70308899332"}
0005435340592	012641	4468 111232	MARIYA SOKOLOVA	{"phone": "+70442564955"}
0005435340593	7703BC	8056 051891	MAKSIM VLASOV	{"email": "vlasov-maksim18021969@postgrespro.ru", "phone": "+70596402889"}
0005435340594	7703BC	2479 586615	YURIY STEPANOV	{"phone": "+70986678901"}
0005435340595	3F8D10	1345 697720	VALENTINA VOLKOVA	{"phone": "+70566679813"}
0005435340596	5419C9	5091 387181	EKATERINA DENISOVA	{"phone": "+70417442046"}
0005435340597	389D28	3800 972260	MARIYA KUZMINA	{"phone": "+70725931872"}
0005435340598	03369D	9059 124710	VALENTINA SOLOVEVA	{"email": "solovevavalentina.011978@postgrespro.ru", "phone": "+70992836027"}
0005435340599	796013	9257 252619	OKSANA GAVRILOVA	{"email": "gavrilova.o_1967@postgrespro.ru", "phone": "+70543270748"}
0005435340600	497BD1	0269 115917	VLADIMIR POPOV	{"phone": "+70136443706"}
0005435340601	497BD1	7056 483708	NIKITA BELOV	{"phone": "+70165032658"}
0005435340602	155CFC	6081 539355	ALEKSANDR ZHUKOV	{"email": "a.zhukov_051976@postgrespro.ru", "phone": "+70620574297"}
0005435340603	B027D3	0380 869104	KSENIYA SIDOROVA	{"phone": "+70828842375"}
0005435340604	27FFB3	1518 717155	YULIYA AKIMOVA	{"phone": "+70100032887"}
0005435340605	B92B76	8614 847711	DANIIL SCHERBAKOV	{"phone": "+70452622287"}
0005435340606	14A54C	9898 544455	ALEKSANDR BONDARENKO	{"email": "aleksandr_bondarenko19081970@postgrespro.ru", "phone": "+70620024564"}
0005435340607	4829D9	5651 490070	YULIYA DMITRIEVA	{"phone": "+70433561418"}
0005435340608	A56403	6200 964483	SERGEY ILIN	{"email": "ilin.s_1966@postgrespro.ru", "phone": "+70222592725"}
0005435340609	0A0979	5370 708252	VIKTOR VLASOV	{"email": "v_vlasov.021978@postgrespro.ru", "phone": "+70333314202"}
0005435340610	8B1906	6708 302598	VIKTOR KUZNECOV	{"email": "viktor.kuznecov.071975@postgrespro.ru", "phone": "+70717234440"}
0005435340611	1F95D1	9586 309502	NINA KUZNECOVA	{"email": "nkuznecova_1961@postgrespro.ru", "phone": "+70161626639"}
0005435340612	1F95D1	3775 839399	LYUBOV SERGEEVA	{"phone": "+70160721823"}
0005435340613	0F05BC	9507 392411	ALEKSANDR ZAYCEV	{"email": "azaycev08051972@postgrespro.ru", "phone": "+70930808290"}
0005435340614	0F05BC	4600 978083	RAMIS KRASNOV	{"phone": "+70736308643"}
0005435340615	F186AC	7056 580426	VITALIY GAVRILOV	{"phone": "+70188526625"}
0005435340616	9F1CDD	8174 036041	EKATERINA EFREMOVA	{"email": "efremova_e021963@postgrespro.ru", "phone": "+70028769858"}
0005435340617	B59BD0	8946 416485	ARTEM BORISOV	{"email": "borisov.artem.13061978@postgrespro.ru", "phone": "+70160675016"}
0005435340618	3BBC68	3334 147418	KSENIYA FILIPPOVA	{"email": "filippova.kseniya_19021961@postgrespro.ru", "phone": "+70332010110"}
0005435340619	9A4578	2317 483515	PAVEL ISAEV	{"email": "isaevp-061964@postgrespro.ru", "phone": "+70584505058"}
0005435340620	575DEC	4574 466422	ELENA MATVEEVA	{"phone": "+70222493537"}
0005435340621	575DEC	2208 004272	ANATOLIY KUZNECOV	{"phone": "+70833222538"}
0005435340622	10FD04	0703 015844	ANNA MATVEEVA	{"email": "a-matveeva051973@postgrespro.ru", "phone": "+70520098537"}
0005435340623	10FD04	0127 330257	IVAN STEPANOV	{"phone": "+70405755533"}
0005435340624	B81F92	3770 717766	VIKTORIYA ZAKHAROVA	{"email": "zakharova_viktoriya_1965@postgrespro.ru", "phone": "+70416047331"}
0005435340625	B81F92	0695 471301	FILIPP BORISOV	{"phone": "+70826551395"}
0005435340626	832E4E	5978 736116	GALINA KRASNOVA	{"phone": "+70569207774"}
0005435340627	E8094A	2535 358864	SERGEY MAKAROV	{"phone": "+70650162706"}
0005435340628	4220AA	3120 370666	DMITRIY VASILEV	{"email": "vasilev-dmitriy15081967@postgrespro.ru", "phone": "+70306783192"}
0005435340629	DCD383	0744 070899	TATYANA ALEKSANDROVA	{"email": "t.aleksandrova-051976@postgrespro.ru", "phone": "+70207324457"}
0005435340630	1CDEFC	7686 246798	ELENA BELYAEVA	{"phone": "+70932204922"}
0005435340631	0DBCB0	0938 736569	ALSU ZHUKOVA	{"email": "zhukova.alsu.101976@postgrespro.ru", "phone": "+70679031936"}
0005435340632	5069D6	7142 913750	SERGEY GRIGOREV	{"email": "s_grigorev.1975@postgrespro.ru", "phone": "+70811061831"}
0005435340633	7B2AEE	5953 505756	ANATOLIY MAKAROV	{"phone": "+70605015985"}
0005435340634	7B2AEE	2208 222572	LYUDMILA KISELEVA	{"email": "kiseleva_lyudmila1966@postgrespro.ru", "phone": "+70982896152"}
0005435340635	7B2AEE	5924 682447	TATYANA TIKHONOVA	{"phone": "+70971051347"}
0005435340636	6A7ADF	9321 156561	ANZHELIKA KOZLOVA	{"phone": "+70875849395"}
0005435340637	2FAF6A	3058 559106	ANNA KISELEVA	{"phone": "+70538512021"}
0005435340638	9BCE0C	0241 015552	EVGENIYA FOMINA	{"phone": "+70507800693"}
0005435340639	780364	0574 000038	MARGARITA PETROVA	{"phone": "+70860384409"}
0005435340640	780364	5220 912495	ANDREY IVANOV	{"phone": "+70718787024"}
0005435340641	59C7A5	8685 888567	DMITRIY VASILEV	{"phone": "+70656536013"}
0005435340642	5CA95C	5122 941197	LIDIYA FEDOROVA	{"email": "l.fedorova_121975@postgrespro.ru", "phone": "+70410355425"}
0005435340643	F7FB89	9748 864403	ELIZAVETA EFREMOVA	{"phone": "+70960606387"}
0005435340644	A39BFC	9285 214803	PAVEL NIKITIN	{"email": "p_nikitin1973@postgrespro.ru", "phone": "+70587419235"}
0005435340645	A39BFC	3035 297269	OKSANA FOMINA	{"email": "ofomina-1968@postgrespro.ru", "phone": "+70232551685"}
0005435340646	EAD8A6	1484 969484	NAILYA KUZNECOVA	{"phone": "+70809734476"}
0005435340647	517046	9495 997863	KSENIYA MIKHAYLOVA	{"email": "k-mikhaylova-10011974@postgrespro.ru", "phone": "+70704331111"}
0005435340648	2D6231	3835 147395	ANASTASIYA ZHURAVLEVA	{"phone": "+70173932423"}
0005435340649	A69F7D	5954 043802	VERA VLASOVA	{"email": "vera_vlasova_11051968@postgrespro.ru", "phone": "+70572312834"}
0005435340650	FD0323	5592 936985	NADEZHDA ALEKSANDROVA	{"phone": "+70568204689"}
0005435340651	256FD8	4814 144715	VLADISLAV KONOVALOV	{"email": "konovalovvladislav-16111976@postgrespro.ru", "phone": "+70964369371"}
0005435340652	256FD8	1049 519507	GENNADIY EGOROV	{"phone": "+70257248573"}
0005435340653	9990A4	1388 864674	ALEKSANDR FEDOTOV	{"email": "fedotova.1977@postgrespro.ru", "phone": "+70237162007"}
0005435340654	9990A4	6204 979334	BOGDAN MARTYNOV	{"phone": "+70464125769"}
0005435340655	37A99D	8408 518193	ANNA SMIRNOVA	{"email": "anna_smirnova-091973@postgrespro.ru", "phone": "+70528843988"}
0005435340656	37A99D	9386 114891	VALENTINA VLASOVA	{"email": "vvlasova051975@postgrespro.ru", "phone": "+70418152656"}
0005435340657	F72250	2976 203508	EVGENIY KOZLOV	{"email": "kozlov.e1977@postgrespro.ru", "phone": "+70393898708"}
0005435340658	F72250	8432 217090	ALEKSEY PETROV	{"email": "petrov_aleksey06021980@postgrespro.ru", "phone": "+70635561425"}
0005435340659	D18FA6	5221 766654	VALENTINA GAVRILOVA	{"phone": "+70510441447"}
0005435340660	06C8BC	6393 377028	ANATOLIY KUZMIN	{"phone": "+70852807085"}
0005435340661	78214C	0076 076527	VALERIY GRIGOREV	{"phone": "+70367894343"}
0005435340662	3ACA04	8341 960126	SVETLANA KOZLOVA	{"email": "kozlova-s101982@postgrespro.ru", "phone": "+70432147009"}
0005435340663	3ACA04	7695 024472	ALEKSANDR OSIPOV	{"phone": "+70231532798"}
0005435340664	277B63	7796 659066	ALEKSANDR TIKHONOV	{"email": "tikhonov_a.061972@postgrespro.ru", "phone": "+70446796275"}
0005435340665	03314E	2919 538978	IRINA GORBUNOVA	{"email": "irinagorbunova101970@postgrespro.ru", "phone": "+70675614383"}
0005435340666	03314E	8847 142233	ANNA MOISEEVA	{"email": "moiseevaa1982@postgrespro.ru", "phone": "+70369851476"}
0005435340667	03314E	1662 095197	ALEKSANDRA SOKOLOVA	{"email": "aleksandra-sokolova.1970@postgrespro.ru", "phone": "+70809492496"}
0005435340668	463774	6146 669795	GRIGORIY FROLOV	{"phone": "+70784442028"}
0005435340669	463774	8602 675321	LYUDMILA PETROVA	{"email": "l_petrova.29091982@postgrespro.ru", "phone": "+70294749871"}
0005435340670	510FF3	6608 213131	NADEZHDA CHERNOVA	{"email": "n_chernova_1976@postgrespro.ru", "phone": "+70635087274"}
0005435340671	F3A385	1822 502482	LEONID MOROZOV	{"email": "leonidmorozov021975@postgrespro.ru", "phone": "+70643879061"}
0005435340672	F3A385	3305 360822	NINA POLYAKOVA	{"phone": "+70771144554"}
0005435340673	C01C52	1057 180664	TATYANA TITOVA	{"phone": "+70477330503"}
0005435340674	7673FF	9213 444241	ANDREY MAKSIMOV	{"phone": "+70840986966"}
0005435340675	D30F53	8938 146512	ALEKSANDR KOZLOV	{"phone": "+70817673534"}
0005435340676	4CECBB	2050 645712	DMITRIY MELNIKOV	{"phone": "+70530816983"}
0005435340677	61ADFC	7950 840005	MIKHAIL KUZMIN	{"email": "kuzmin_m-081972@postgrespro.ru", "phone": "+70913034925"}
0005435340678	A7CF5E	6535 617455	YURIY MOISEEV	{"email": "moiseev-y-1973@postgrespro.ru", "phone": "+70149911016"}
0005435340679	A40375	3815 912317	ALI ALEKSEEV	{"email": "alekseevali_28121973@postgrespro.ru", "phone": "+70168075430"}
0005435340680	B69C9F	4810 857740	GALINA PAVLOVA	{"email": "galina.pavlova_081980@postgrespro.ru", "phone": "+70322843304"}
0005435340681	D199B4	5119 048605	NIKOLAY IVANOV	{"email": "nikolay-ivanov_1963@postgrespro.ru", "phone": "+70516303620"}
0005435340682	45CA18	9265 471233	ALEKSANDR FEDOROV	{"phone": "+70439891498"}
0005435340683	3F38D7	5775 343033	OLGA POPOVA	{"email": "popova.o-24051983@postgrespro.ru", "phone": "+70353915453"}
0005435340684	3F38D7	3845 616068	ANATOLIY BELOV	{"phone": "+70143753325"}
0005435340685	604E4E	9784 248218	ANTONINA NOVIKOVA	{"phone": "+70851514966"}
0005435340686	604E4E	9964 345491	VLADISLAV BONDARENKO	{"email": "bondarenko.v_1969@postgrespro.ru", "phone": "+70615913923"}
0005435340687	DDBB12	0323 933784	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov.a.051964@postgrespro.ru", "phone": "+70909797561"}
0005435340688	DDBB12	7230 314553	FARIDA KOVALEVA	{"phone": "+70316298714"}
0005435340689	F21CBA	6668 846534	ELENA BORISOVA	{"email": "e_borisova.1962@postgrespro.ru", "phone": "+70254095003"}
0005435340690	F21CBA	2891 254790	VERONIKA ISAEVA	{"email": "isaevav-03121972@postgrespro.ru", "phone": "+70122761871"}
0005435340691	966B13	9272 484266	GALINA YAKOVLEVA	{"phone": "+70818745831"}
0005435340692	966B13	1702 302137	YURIY IVANOV	{"email": "ivanov_y-24101985@postgrespro.ru", "phone": "+70135300457"}
0005435340693	BC2461	1780 756037	ANATOLIY ALEKSEEV	{"email": "alekseev-a.1965@postgrespro.ru", "phone": "+70647360511"}
0005435340694	F420A0	4159 378176	OLEG IVANOV	{"email": "ivanov.o-12121971@postgrespro.ru", "phone": "+70497780355"}
0005435340695	831D6C	0710 973103	ANDREY GERASIMOV	{"phone": "+70785257564"}
0005435340696	831D6C	2498 175287	IGOR MELNIKOV	{"phone": "+70758075789"}
0005435340697	9F8983	4224 265684	ELENA ERMAKOVA	{"email": "elena.ermakova-1976@postgrespro.ru", "phone": "+70286319030"}
0005435340698	02BBDA	1975 549947	VALERIY SCHERBAKOV	{"phone": "+70788054988"}
0005435340699	523A0F	7558 154579	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr1975@postgrespro.ru", "phone": "+70116799999"}
0005435340700	523A0F	1691 186914	OLGA EFIMOVA	{"email": "olga_efimova-041973@postgrespro.ru", "phone": "+70481623650"}
0005435340701	36D0E1	6956 067880	ANATOLIY MARTYNOV	{"email": "a.martynov1978@postgrespro.ru", "phone": "+70315039412"}
0005435340702	36D0E1	3053 083024	RUSLAN SHEVCHENKO	{"phone": "+70916011680"}
0005435340703	DD7A96	8355 101932	ILYA ANDREEV	{"phone": "+70276571473"}
0005435340704	DC471D	3798 383328	VIKTORIYA ZAKHAROVA	{"phone": "+70333102956"}
0005435340705	DC471D	2122 620297	NATALYA KOVALEVA	{"phone": "+70831159279"}
0005435340706	D6C90F	7530 859875	ALEKSANDRA SERGEEVA	{"email": "sergeevaaleksandra031954@postgrespro.ru", "phone": "+70810993713"}
0005435340707	D6C90F	2014 707358	ALISA GUSEVA	{"email": "alisa-guseva.11011967@postgrespro.ru", "phone": "+70572807487"}
0005435340708	8E1781	1042 757919	VLADIMIR VOROBEV	{"phone": "+70805139749"}
0005435340709	AB5BC2	3223 672235	KRISTINA SOKOLOVA	{"phone": "+70300747980"}
0005435372094	298802	5349 975563	ANDREY FOMIN	{"phone": "+70010464091"}
0005435372095	E9236E	4059 542265	ANNA FROLOVA	{"phone": "+70789709708"}
0005435372096	D57D21	9632 708701	ARTUR KISELEV	{"phone": "+70146517754"}
0005435372097	D57D21	9292 774784	TAMARA MAKAROVA	{"phone": "+70233025124"}
0005435372098	0DE37C	9786 551070	ELENA EFREMOVA	{"phone": "+70147197458"}
0005435372099	E286FB	9000 583328	TATYANA RODIONOVA	{"phone": "+70621169748"}
0005435372100	4F146B	9178 962468	OLGA ALEKSEEVA	{"email": "alekseeva-o-1974@postgrespro.ru", "phone": "+70030630665"}
0005435372101	B3D2D0	4867 803771	VERA MATVEEVA	{"email": "v.matveeva_19081977@postgrespro.ru", "phone": "+70397030688"}
0005435372102	7BB89D	2883 869870	NATALYA KARPOVA	{"phone": "+70958046661"}
0005435372103	7BB89D	4375 800945	NADEZHDA NIKITINA	{"phone": "+70667458710"}
0005435372104	7BB89D	6039 433042	ANASTASIYA IVANOVA	{"phone": "+70422150349"}
0005435372105	7BEA89	6458 657438	IVAN SIDOROV	{"phone": "+70591793299"}
0005435372106	3CC367	5213 094301	OLGA VOLKOVA	{"phone": "+70898620782"}
0005435372107	3CC367	9552 074118	VALENTINA NAZAROVA	{"email": "valentina.nazarova.101965@postgrespro.ru", "phone": "+70233280869"}
0005435372108	979A34	0324 797742	VALENTINA ROMANOVA	{"email": "valentinaromanova.021975@postgrespro.ru", "phone": "+70708088706"}
0005435372109	979A34	1353 361808	EGOR PAVLOV	{"phone": "+70403592024"}
0005435372110	0007FC	5719 481983	FAINA BELOVA	{"phone": "+70201198819"}
0005435372111	346F78	6761 787201	VYACHESLAV IVANOV	{"email": "ivanov.vyacheslav-081955@postgrespro.ru", "phone": "+70291068000"}
0005435372112	9EEA8A	2038 914039	NINA POLYAKOVA	{"email": "polyakova_n021961@postgrespro.ru", "phone": "+70799298678"}
0005435372113	3CBC87	9122 559885	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov_1972@postgrespro.ru", "phone": "+70674188262"}
0005435372114	102FE4	0744 768142	NIKOLAY FILIPPOV	{"email": "filippov.n.111981@postgrespro.ru", "phone": "+70646167189"}
0005435372115	7FF990	2412 294386	EGOR ZAKHAROV	{"email": "egor_zakharov15071968@postgrespro.ru", "phone": "+70387934134"}
0005435372116	7FF990	4304 116296	ANDREY PAVLOV	{"email": "a.pavlov-101971@postgrespro.ru", "phone": "+70042284565"}
0005435372117	4BDEB2	1427 265617	LILIYA ZAKHAROVA	{"phone": "+70913629351"}
0005435372118	4BDEB2	6204 955795	VASILIY SOLOVEV	{"email": "v.solovev-101969@postgrespro.ru", "phone": "+70149741981"}
0005435372119	E0B27B	5145 061639	PAVEL DMITRIEV	{"phone": "+70214052861"}
0005435372120	E0B27B	1719 805833	IVAN POPOV	{"phone": "+70763986164"}
0005435372121	E0B27B	1206 400697	ZINAIDA ISAEVA	{"email": "zinaidaisaeva-1975@postgrespro.ru", "phone": "+70882944517"}
0005435372122	7FB315	5620 279571	ELENA KOROLEVA	{"phone": "+70698050856"}
0005435372123	75BA45	2802 659142	DMITRIY VASILEV	{"email": "vasilev.dmitriy_021976@postgrespro.ru", "phone": "+70167825937"}
0005435372124	75BA45	3322 310059	TATYANA NAZAROVA	{"email": "tatyana-nazarova1975@postgrespro.ru", "phone": "+70746781851"}
0005435372125	AE9D2F	5411 377529	KRISTINA IVANOVA	{"phone": "+70136954918"}
0005435372126	AE9D2F	3295 867977	OLESYA FROLOVA	{"email": "frolovaolesya-091974@postgrespro.ru", "phone": "+70477164862"}
0005435372127	D68969	2622 305182	OLEG KUZNECOV	{"phone": "+70112000427"}
0005435372128	9D9E4D	3646 790313	NATALYA NIKOLAEVA	{"phone": "+70402865488"}
0005435372129	7FB525	7518 191258	NADEZHDA KUDRYASHOVA	{"email": "nadezhdakudryashova.1969@postgrespro.ru", "phone": "+70812808918"}
0005435372130	7FB525	2388 441536	ANASTASIYA KOZLOVA	{"email": "kozlova_anastasiya.23051971@postgrespro.ru", "phone": "+70406604381"}
0005435372131	817170	2242 794631	VASILIY KUZNECOV	{"phone": "+70040808999"}
0005435372132	817170	3412 729102	ALEKSANDR VASILEV	{"phone": "+70660450896"}
0005435372133	4D86B2	4252 317376	YULIYA CHERNOVA	{"email": "chernova.yuliya02091967@postgrespro.ru", "phone": "+70564353171"}
0005435372134	4D86B2	1492 132154	DANILA VOROBEV	{"email": "vorobev_d-1973@postgrespro.ru", "phone": "+70288839908"}
0005435372135	1A62F8	6275 280595	ALEKSANDR KRASNOV	{"email": "krasnova-061971@postgrespro.ru", "phone": "+70424131878"}
0005435372136	48E935	6123 918437	VASILIY ANDREEV	{"phone": "+70765518185"}
0005435372137	4F2B67	4935 752830	NADEZHDA SMIRNOVA	{"phone": "+70768476474"}
0005435372138	4F2B67	1137 174669	NADEZHDA FILIPPOVA	{"email": "nfilippova_08011970@postgrespro.ru", "phone": "+70725260020"}
0005435372139	0F85D6	4246 300935	MARINA MATVEEVA	{"email": "mmatveeva041975@postgrespro.ru", "phone": "+70144964527"}
0005435372140	28E154	6584 402587	IVAN SERGEEV	{"phone": "+70767842653"}
0005435372141	D49DB7	9134 337785	NIKOLAY SEMENOV	{"phone": "+70849880619"}
0005435372142	33E86B	6666 730615	PAVEL MOISEEV	{"email": "moiseev.pavel.081965@postgrespro.ru", "phone": "+70251038836"}
0005435372143	9C3554	6008 134431	VLADIMIR GORBUNOV	{"email": "vladimir-gorbunov.08021981@postgrespro.ru", "phone": "+70620513735"}
0005435372144	9C3554	8852 301348	ALEKSEY KOZLOV	{"email": "aleksey_kozlov23051978@postgrespro.ru", "phone": "+70639742919"}
0005435372145	047837	0190 189264	ALINA MAKAROVA	{"phone": "+70467344007"}
0005435372146	047837	5270 724146	ELENA MAKAROVA	{"phone": "+70746694338"}
0005435372147	7B5438	1740 711657	NIKOLAY SEMENOV	{"phone": "+70066161487"}
0005435372148	28FF0E	7730 432268	IGOR ROMANOV	{"email": "i_romanov_011964@postgrespro.ru", "phone": "+70323324297"}
0005435372149	5B1E11	6140 472440	ROZA NESTEROVA	{"email": "nesterova-r_1977@postgrespro.ru", "phone": "+70938831714"}
0005435372150	A0EFBF	6318 732863	VIKTORIYA GERASIMOVA	{"email": "gerasimova.v_1969@postgrespro.ru", "phone": "+70955393252"}
0005435372151	4ABC6D	2885 604607	NATALYA NIKOLAEVA	{"email": "natalya-nikolaeva-1975@postgrespro.ru", "phone": "+70063818153"}
0005435372152	89C603	1538 107732	DMITRIY ANTONOV	{"email": "d-antonov25091962@postgrespro.ru", "phone": "+70132391437"}
0005435372153	C605B4	4186 391068	SOFYA NIKIFOROVA	{"phone": "+70101525973"}
0005435372154	C605B4	7683 503605	VIKTOR KRASNOV	{"email": "krasnov_viktor081969@postgrespro.ru", "phone": "+70908133256"}
0005435372155	A347E2	8633 338927	NIKOLAY MIKHAYLOV	{"email": "mikhaylovnikolay_05091973@postgrespro.ru", "phone": "+70055657324"}
0005435372156	A347E2	8209 130047	SOFYA EFREMOVA	{"phone": "+70369967931"}
0005435372157	A347E2	5705 536120	ELENA STEPANOVA	{"email": "stepanovaelena_11091969@postgrespro.ru", "phone": "+70887593276"}
0005435372158	D24D9C	7493 256082	NADEZHDA RODIONOVA	{"email": "rodionova_n_1969@postgrespro.ru", "phone": "+70200120629"}
0005435372159	34BAB3	4801 300459	VALENTINA FROLOVA	{"email": "v-frolova-041970@postgrespro.ru", "phone": "+70726270182"}
0005435372160	279215	5061 057976	NIKOLAY GAVRILOV	{"phone": "+70954182302"}
0005435372161	54F2A8	4954 293290	SERGEY NIKOLAEV	{"email": "sergey_nikolaev-25021974@postgrespro.ru", "phone": "+70579390197"}
0005435372162	F09F50	7654 972860	ALEKSANDR VOLKOV	{"email": "a_volkov.07101976@postgrespro.ru", "phone": "+70023499598"}
0005435372163	576937	2310 125314	ALEKSANDR KUZNECOV	{"phone": "+70453951639"}
0005435372164	9C3444	4575 557775	NIKOLAY ZAYCEV	{"phone": "+70841975049"}
0005435372165	2CC306	8604 114897	OLGA FOMINA	{"phone": "+70122634799"}
0005435372166	340E95	5533 409833	INESSA GRISHINA	{"phone": "+70174797928"}
0005435372167	1C8DFE	2798 686750	SERGEY ALEKSANDROV	{"phone": "+70227151187"}
0005435372168	1C8DFE	5841 795422	ALEKSEY KULIKOV	{"phone": "+70938339265"}
0005435372169	C92B7D	8046 918782	SVETLANA AFANASEVA	{"email": "svetlanaafanaseva16121960@postgrespro.ru", "phone": "+70368796634"}
0005435372170	B38229	5198 448255	MARAT FEDOTOV	{"phone": "+70855724891"}
0005435372171	CEE82C	4801 268324	NADEZHDA NESTEROVA	{"email": "n_nesterova031974@postgrespro.ru", "phone": "+70068844057"}
0005435372172	CEE82C	4679 985633	MIKHAIL ZHURAVLEV	{"email": "zhuravlev-mikhail.01091958@postgrespro.ru", "phone": "+70402444594"}
0005435372173	0C2C88	1627 327946	VASILIY GUSEV	{"phone": "+70843345152"}
0005435372174	2DC91D	7621 331542	VIKTORIYA MOROZOVA	{"email": "morozova_viktoriya06081970@postgrespro.ru", "phone": "+70789673999"}
0005435372175	2DC91D	7197 516523	SERGEY MAKAROV	{"phone": "+70840250031"}
0005435372176	59F339	1217 567907	ARTEM POPOV	{"phone": "+70824724824"}
0005435372177	59F339	5804 054802	VIKTOR AFANASEV	{"email": "viktor-afanasev.1963@postgrespro.ru", "phone": "+70331849228"}
0005435372178	8924E9	1776 036647	MAKSIM MARTYNOV	{"email": "maksim-martynov18051971@postgrespro.ru", "phone": "+70349858072"}
0005435372179	8924E9	9970 561606	EVGENIY PAVLOV	{"phone": "+70988802441"}
0005435372180	8924E9	5990 329478	FANIYA RODIONOVA	{"phone": "+70319946430"}
0005435372181	9A88B5	8017 667355	NATALYA SOROKINA	{"phone": "+70235006197"}
0005435372182	DB12C6	9699 820783	ELENA TIKHONOVA	{"phone": "+70889082111"}
0005435372183	487CC2	9005 720257	ANNA CHERNOVA	{"phone": "+70381079817"}
0005435372184	487CC2	0007 456333	KHALIDA ABRAMOVA	{"email": "abramova-k_06091977@postgrespro.ru", "phone": "+70998029904"}
0005435372185	2F4C2B	0295 926944	NATALYA VOLKOVA	{"phone": "+70540550239"}
0005435372186	96D6E3	1243 864045	VIKTOR FEDOTOV	{"email": "fedotov-viktor_08081977@postgrespro.ru", "phone": "+70369089184"}
0005435372187	594B79	5293 298005	IVAN VOLKOV	{"email": "volkovivan_23111973@postgrespro.ru", "phone": "+70121498312"}
0005435372188	594B79	3406 226319	LARISA KRASNOVA	{"email": "krasnova.l_1970@postgrespro.ru", "phone": "+70105978749"}
0005435372189	3C0BC9	1574 281607	NADEZHDA EFREMOVA	{"phone": "+70755578763"}
0005435372190	29147D	8908 274168	MIKHAIL BORISOV	{"email": "mborisov_17121986@postgrespro.ru", "phone": "+70845329585"}
0005435372191	4F7058	3508 416566	ALEKSEY KUZNECOV	{"email": "a_kuznecov-06051971@postgrespro.ru", "phone": "+70407173684"}
0005435372192	4F7058	4512 318956	ARTEM POPOV	{"email": "apopov23031970@postgrespro.ru", "phone": "+70420875301"}
0005435372193	4F7058	8982 308500	IRINA NESTEROVA	{"phone": "+70950808567"}
0005435372194	4F7058	4407 515329	VALERIYA IVANOVA	{"email": "ivanova-v.02011981@postgrespro.ru", "phone": "+70744523485"}
0005435372195	DD78C1	3367 863433	LILIYA ZAKHAROVA	{"email": "zakharova.liliya.04101986@postgrespro.ru", "phone": "+70829654513"}
0005435372196	DD78C1	3551 769465	TAMARA PETROVA	{"phone": "+70320321746"}
0005435372197	818454	8354 823323	OLGA KUZNECOVA	{"email": "kuznecova_olga_1967@postgrespro.ru", "phone": "+70759842641"}
0005435372198	DC28F7	7332 812652	NADEZHDA KUZNECOVA	{"phone": "+70466442179"}
0005435372199	DC28F7	0393 001913	ALEKSANDR POPOV	{"email": "apopov.051974@postgrespro.ru", "phone": "+70510436932"}
0005435372200	DC28F7	3603 760400	TATYANA DENISOVA	{"email": "tatyana.denisova-091956@postgrespro.ru", "phone": "+70827258618"}
0005435372201	8EB0D9	2438 570490	TAMARA KRASNOVA	{"email": "tamara_krasnova1968@postgrespro.ru", "phone": "+70991434574"}
0005435372202	8EB0D9	0078 536117	DANIIL GUSEV	{"phone": "+70179326435"}
0005435372203	772CA2	9022 888724	VALENTINA ILINA	{"email": "v-ilina_011965@postgrespro.ru", "phone": "+70651193590"}
0005435372204	772CA2	8489 426455	OLGA MELNIKOVA	{"phone": "+70797384011"}
0005435372205	45AAD5	2312 626492	NINA TARASOVA	{"email": "ntarasova-031975@postgrespro.ru", "phone": "+70178846250"}
0005435372206	F4FE22	7655 310030	VALENTINA KUZNECOVA	{"phone": "+70750091836"}
0005435372207	1C0E65	4286 974587	LYUBOV VLASOVA	{"phone": "+70831205104"}
0005435372208	1C0E65	3059 434546	ZINAIDA VOLKOVA	{"email": "z-volkova_041968@postgrespro.ru", "phone": "+70005189838"}
0005435372209	568FBF	8237 548332	VASILIY BORISOV	{"email": "v-borisov_101967@postgrespro.ru", "phone": "+70317707171"}
0005435372210	8B46C4	7419 433666	PAVEL KRASNOV	{"email": "p-krasnov_071982@postgrespro.ru", "phone": "+70165931053"}
0005435372211	1F6DF4	3497 644573	VALERIY EGOROV	{"email": "egorov_valeriy-27111965@postgrespro.ru", "phone": "+70522078042"}
0005435372212	1F6DF4	4835 054444	TATYANA MAKAROVA	{"email": "t_makarova.041975@postgrespro.ru", "phone": "+70311577444"}
0005435372213	0593AD	9191 155241	OLGA KUZMINA	{"email": "kuzmina-olga031986@postgrespro.ru", "phone": "+70803562111"}
0005435372214	C078CD	7679 812090	ALEKSANDR FOMIN	{"email": "a.fomin30081974@postgrespro.ru", "phone": "+70204983712"}
0005435372215	EC8DBF	9976 596395	MIKHAIL ORLOV	{"email": "mikhail.orlov-101959@postgrespro.ru", "phone": "+70009157361"}
0005435372216	EC8DBF	1056 662664	IGOR ALEKSANDROV	{"email": "aleksandrov-igor_071972@postgrespro.ru", "phone": "+70652978036"}
0005435372217	6130E4	2718 223283	LYUDMILA KUZMINA	{"phone": "+70330134976"}
0005435372218	6130E4	7892 594271	ALEKSEY VLASOV	{"email": "vlasovaleksey-27081977@postgrespro.ru", "phone": "+70298021592"}
0005435372219	B7280C	8448 867835	EVA PETROVA	{"phone": "+70616246225"}
0005435372220	E98978	6770 659494	OLGA GORBUNOVA	{"email": "o_gorbunova1968@postgrespro.ru", "phone": "+70684995450"}
0005435372221	E98978	8534 335944	OLGA MEDVEDEVA	{"email": "omedvedeva.09081966@postgrespro.ru", "phone": "+70092790370"}
0005435372222	171592	5083 118850	LIDIYA EFREMOVA	{"email": "efremova_l.051977@postgrespro.ru", "phone": "+70449867037"}
0005435372223	171592	8106 729885	YURIY ZAYCEV	{"phone": "+70875588516"}
0005435372224	B559AF	4671 279595	IRINA GRISHINA	{"email": "grishina_irina.1964@postgrespro.ru", "phone": "+70276873966"}
0005435372225	EE0B37	3190 480262	SVETLANA PAVLOVA	{"phone": "+70943092356"}
0005435372226	4840B6	4573 506457	VLADIMIR OSIPOV	{"email": "osipov.vladimir.21111961@postgrespro.ru", "phone": "+70406201727"}
0005435372227	E7469E	3414 628684	MAKSIM FROLOV	{"email": "m.frolov_081967@postgrespro.ru", "phone": "+70365336821"}
0005435372228	E7469E	7859 214200	IRINA KOLESNIKOVA	{"email": "irinakolesnikova-091972@postgrespro.ru", "phone": "+70750691306"}
0005435372229	677C55	0405 437834	DARYA TARASOVA	{"email": "tarasova.d12021965@postgrespro.ru", "phone": "+70096158171"}
0005435372230	677C55	3288 493785	VITALIY KONOVALOV	{"phone": "+70709848370"}
0005435372231	2FA85B	9216 278402	ALEKSANDR BORISOV	{"phone": "+70774065292"}
0005435372232	BA0C6B	4832 060725	VLADIMIR NIKITIN	{"phone": "+70467235942"}
0005435372233	BA0C6B	5536 035076	ALEKSEY STEPANOV	{"email": "stepanov-aleksey_011974@postgrespro.ru", "phone": "+70468950566"}
0005435372234	5BBB7C	3007 322908	KAMIL VOLKOV	{"phone": "+70716319350"}
0005435372235	5BBB7C	7307 108405	YURIY ABRAMOV	{"phone": "+70211249581"}
0005435372236	4DF169	1934 367276	ANASTASIYA PETROVA	{"phone": "+70968422463"}
0005435372237	45C1AB	3464 292508	ALEKSEY FEDOTOV	{"email": "afedotov.06021968@postgrespro.ru", "phone": "+70190058592"}
0005435372238	45C1AB	4984 937609	ALEKSEY ALEKSANDROV	{"phone": "+70022166594"}
0005435372239	C497D5	8150 879475	SERGEY ZHUKOV	{"phone": "+70854513479"}
0005435372240	2CD1C3	0483 313120	SERGEY DAVYDOV	{"email": "davydovsergey-1970@postgrespro.ru", "phone": "+70381714051"}
0005435372241	4AFC3E	8742 128644	YURIY IVANOV	{"email": "ivanovy.19051976@postgrespro.ru", "phone": "+70010411422"}
0005435372242	C0E446	6193 542294	VALERIY KRASNOV	{"phone": "+70784293650"}
0005435372243	BDC3BC	8646 398629	VITALIY DAVYDOV	{"email": "davydov_vitaliy_081965@postgrespro.ru", "phone": "+70401218927"}
0005435372244	976B66	3804 392222	YURIY MIKHAYLOV	{"email": "y.mikhaylov-101970@postgrespro.ru", "phone": "+70967961246"}
0005435372245	976B66	1045 534351	OLGA BORISOVA	{"email": "borisova.o031981@postgrespro.ru", "phone": "+70397056990"}
0005435372246	86F9BD	8350 967693	ANDREY SOLOVEV	{"email": "a-solovev_25071972@postgrespro.ru", "phone": "+70585384523"}
0005435372247	5AB79F	6598 531673	ALEKSANDR KUZNECOV	{"email": "kuznecova_04031974@postgrespro.ru", "phone": "+70423872120"}
0005435372248	FA6CFC	7933 307885	VALENTINA SCHERBAKOVA	{"email": "valentina.scherbakova_1965@postgrespro.ru", "phone": "+70473227649"}
0005435372249	7D86F1	5100 932504	MARINA FILATOVA	{"phone": "+70277542273"}
0005435372250	7D86F1	5687 513751	NATALIYA MAKAROVA	{"email": "n-makarova.27101974@postgrespro.ru", "phone": "+70078983281"}
0005435372251	DC5958	8784 376769	IVAN NIKOLAEV	{"email": "nikolaevivan111973@postgrespro.ru", "phone": "+70050338982"}
0005435372252	20D274	1897 631980	IRINA NIKITINA	{"email": "nikitina-irina-26031977@postgrespro.ru", "phone": "+70992438797"}
0005435372253	CBF96D	6541 408129	VERA SERGEEVA	{"email": "verasergeeva1975@postgrespro.ru", "phone": "+70756585569"}
0005435372254	4267CF	8385 762316	NADEZHDA MOISEEVA	{"email": "moiseeva-nadezhda_1980@postgrespro.ru", "phone": "+70696366961"}
0005435372255	FBC09E	4825 553883	TATYANA EGOROVA	{"email": "tatyanaegorova1967@postgrespro.ru", "phone": "+70897480747"}
0005435372256	FBC09E	2860 081555	YULIYA MIKHAYLOVA	{"phone": "+70240677549"}
0005435372257	23F47E	9794 121905	VLADIMIR IVANOV	{"email": "vivanov.041975@postgrespro.ru", "phone": "+70299959954"}
0005435372258	23F47E	3249 143690	TATYANA KUZNECOVA	{"phone": "+70490335996"}
0005435372259	536F01	9114 638335	ANTONINA NAZAROVA	{"email": "nazarova.a.1970@postgrespro.ru", "phone": "+70864997024"}
0005435372260	68558B	5224 815470	ANDREY SOKOLOV	{"phone": "+70527591854"}
0005435372261	68558B	8832 424715	VLADIMIR BELOV	{"phone": "+70061922134"}
0005435372262	0394FA	8661 408541	IGOR KUZNECOV	{"email": "i.kuznecov.23061974@postgrespro.ru", "phone": "+70162249112"}
0005435372263	51117A	9358 610607	SVETLANA TARASOVA	{"phone": "+70195724398"}
0005435372264	9DBFB3	9478 646651	EVGENIY FEDOTOV	{"email": "fedotov_e-081957@postgrespro.ru", "phone": "+70096385936"}
0005435372265	279E5C	4957 294989	EKATERINA SEMENOVA	{"phone": "+70784968740"}
0005435372266	9EEC76	6157 517382	ULYANA FILIPPOVA	{"email": "u-filippova021977@postgrespro.ru", "phone": "+70823603140"}
0005435372267	9EEC76	3380 071044	NADEZHDA ANDREEVA	{"email": "andreeva.n-31011969@postgrespro.ru", "phone": "+70737345335"}
0005435372268	1391A1	1216 454838	SVETLANA ANDREEVA	{"email": "andreeva-s10081967@postgrespro.ru", "phone": "+70835488221"}
0005435372269	161ABA	7930 838302	ANDREY VOLKOV	{"email": "avolkov-03091968@postgrespro.ru", "phone": "+70619085112"}
0005435372270	F9698F	4724 316043	ANTON MARTYNOV	{"email": "antonmartynov-15011960@postgrespro.ru", "phone": "+70242852459"}
0005435372271	833872	5301 445128	PETR FEDOROV	{"phone": "+70657626602"}
0005435372272	833872	0693 845795	TAMARA MAKAROVA	{"email": "tamara-makarova-1981@postgrespro.ru", "phone": "+70146793363"}
0005435372273	BC171E	9306 465641	IVAN GUSEV	{"phone": "+70700468730"}
0005435372274	BC171E	3755 116768	NINA ZHURAVLEVA	{"email": "zhuravleva.nina.051969@postgrespro.ru", "phone": "+70433597531"}
0005435372275	A27A62	4861 340432	NIKITA VLASOV	{"email": "vlasovn_1984@postgrespro.ru", "phone": "+70785755856"}
0005435372276	A27A62	4033 299083	ELENA NESTEROVA	{"phone": "+70333290838"}
0005435372277	2F85F2	6928 698027	MIKHAIL POPOV	{"phone": "+70125865707"}
0005435372278	2F85F2	1614 156320	EVGENIY MIKHAYLOV	{"phone": "+70376043523"}
0005435372279	18002B	2736 404362	VALERIY NOVIKOV	{"phone": "+70012187911"}
0005435372280	18002B	0335 658881	LIDIYA TROFIMOVA	{"phone": "+70963820234"}
0005435372281	18002B	9328 501519	ALEKSEY KOZLOV	{"email": "alekseykozlov_11121977@postgrespro.ru", "phone": "+70358573902"}
0005435372282	887F1A	7590 540010	NATALYA ILINA	{"email": "ilina.n-1976@postgrespro.ru", "phone": "+70275247807"}
0005435372283	6026D1	4563 273660	ROMAN NIKITIN	{"phone": "+70345452721"}
0005435372284	BF3975	5872 114344	VIKTOR KOZLOV	{"email": "v.kozlov-111978@postgrespro.ru", "phone": "+70666507183"}
0005435372285	54913E	0328 331385	OLEG KUZMIN	{"phone": "+70789273040"}
0005435372286	54913E	4833 707126	ALEKSANDR IVANOV	{"phone": "+70925073030"}
0005435372287	D40D53	3524 790324	RIMMA TIKHONOVA	{"phone": "+70155314240"}
0005435372288	980A73	4713 352872	RUSLAN ALEKSEEV	{"email": "r_alekseev_011969@postgrespro.ru", "phone": "+70318985090"}
0005435372289	980A73	4436 512946	SOFIYA NAUMOVA	{"email": "naumova-sofiya-25091968@postgrespro.ru", "phone": "+70221964241"}
0005435372290	F428AB	7279 692121	ALEKSANDR ZAKHAROV	{"email": "a.zakharov_061972@postgrespro.ru", "phone": "+70222387256"}
0005435372291	3D6BDC	2732 453490	ZOYA SOKOLOVA	{"email": "sokolova_zoya_30011967@postgrespro.ru", "phone": "+70669526841"}
0005435372292	568C32	8708 744330	IVAN ILIN	{"phone": "+70493874202"}
0005435372293	FB5090	2094 099825	LIDIYA ZOTOVA	{"phone": "+70497093761"}
0005435372294	FB5090	5180 233049	IGOR ZHUKOV	{"phone": "+70571894419"}
0005435372295	F9C094	2824 919105	ALEKSEY TIKHONOV	{"phone": "+70376614065"}
0005435372296	AD1101	9238 146980	OLGA EGOROVA	{"email": "egorova_olga_051965@postgrespro.ru", "phone": "+70770464904"}
0005435372297	A392A2	5451 538730	DMITRIY KARPOV	{"email": "karpovdmitriy.1973@postgrespro.ru", "phone": "+70919270036"}
0005435372298	A392A2	7857 904932	LILIYA MOROZOVA	{"email": "morozova-l1974@postgrespro.ru", "phone": "+70988961917"}
0005435372299	AACE4B	0343 695116	NATALYA NAUMOVA	{"email": "naumova_natalya01031976@postgrespro.ru", "phone": "+70784038667"}
0005435372300	C44D7D	6277 770238	VLADIMIR FROLOV	{"phone": "+70568173912"}
0005435372301	764E0B	5040 971881	YULIYA PETROVA	{"email": "petrovayuliya051981@postgrespro.ru", "phone": "+70722251159"}
0005435372302	C5D631	5068 479221	NIKOLAY ANDREEV	{"phone": "+70843222361"}
0005435372303	210258	6381 941231	PETR KONOVALOV	{"phone": "+70035496709"}
0005435372304	DA2B31	7777 455001	OLGA AKIMOVA	{"phone": "+70002549751"}
0005435372305	DA2B31	4123 447326	IRINA BELYAEVA	{"email": "belyaeva.irina-22011973@postgrespro.ru", "phone": "+70945113688"}
0005435372306	4DA7DA	7110 481699	VLADIMIR VASILEV	{"phone": "+70380034308"}
0005435372307	4DA7DA	4673 103785	ALEKSANDR ZAYCEV	{"phone": "+70599839082"}
0005435372308	8B1298	5443 663993	ALEKSEY SAVELEV	{"email": "alekseysavelev06101965@postgrespro.ru", "phone": "+70666154952"}
0005435372309	8B1298	3850 661521	OLGA ARKHIPOVA	{"phone": "+70733230022"}
0005435372310	8B1298	4520 296177	YULIYA KOROLEVA	{"phone": "+70592939273"}
0005435372311	A4CB03	1120 222928	ALEKSEY VOLKOV	{"email": "volkov-aleksey_1968@postgrespro.ru", "phone": "+70225396992"}
0005435372312	887998	9540 706012	NATALYA CHERNOVA	{"phone": "+70349938189"}
0005435372313	E4AADD	9904 469478	VITALIY EGOROV	{"email": "vegorov-1972@postgrespro.ru", "phone": "+70848238474"}
0005435372314	2057CF	9781 147144	ALEKSEY KULIKOV	{"phone": "+70052759159"}
0005435372315	2057CF	3595 540567	EKATERINA BARANOVA	{"phone": "+70657549343"}
0005435372316	585DE4	6916 476936	IGOR MAKAROV	{"phone": "+70553744998"}
0005435372317	F7B2B0	2968 865443	GLEB MEDVEDEV	{"email": "g_medvedev1974@postgrespro.ru", "phone": "+70790228024"}
0005435372318	3B01D8	6671 365501	OLGA YAKOVLEVA	{"email": "yakovleva-olga.1976@postgrespro.ru", "phone": "+70506276833"}
0005435372319	53AB17	0213 941006	IRINA IVANOVA	{"email": "ivanova_i1960@postgrespro.ru", "phone": "+70644608860"}
0005435372320	53AB17	9658 262392	TATYANA FOMINA	{"phone": "+70594681531"}
0005435372321	C7B7B7	0458 972570	ALENA VOROBEVA	{"email": "a_vorobeva1959@postgrespro.ru", "phone": "+70976463434"}
0005435372322	359D26	8830 126483	SVETLANA POPOVA	{"phone": "+70787720712"}
0005435372323	005EBE	2443 445254	ROMAN KUDRYASHOV	{"phone": "+70429391869"}
0005435372324	005EBE	3857 259428	NIKOLAY DMITRIEV	{"phone": "+70021783846"}
0005435372325	16088A	1623 055409	RAFIK TIMOFEEV	{"email": "timofeev.rafik-011966@postgrespro.ru", "phone": "+70689064186"}
0005435372326	7C42A5	8032 366664	YURIY VLASOV	{"email": "vlasov.y18101982@postgrespro.ru", "phone": "+70972101929"}
0005435372327	8C0BCC	3812 279661	AMINA AFANASEVA	{"email": "afanaseva.amina.06011971@postgrespro.ru", "phone": "+70021749655"}
0005435372328	8C0BCC	0736 025042	OLEG MOROZOV	{"email": "morozov-oleg_021972@postgrespro.ru", "phone": "+70781318961"}
0005435372329	044E65	8322 442262	PETR BORISOV	{"phone": "+70338405563"}
0005435372330	044E65	8309 611696	ALEKSANDRA SEMENOVA	{"email": "asemenova-20101964@postgrespro.ru", "phone": "+70493451282"}
0005435372331	24B8BE	2772 184102	NATALYA ROMANOVA	{"email": "n_romanova03021973@postgrespro.ru", "phone": "+70565229495"}
0005435372332	24B8BE	7449 843950	DMITRIY FEDOTOV	{"phone": "+70119741864"}
0005435372333	3AC758	4287 017247	ELENA PETROVA	{"email": "petrova.elena_1973@postgrespro.ru", "phone": "+70744616528"}
0005435372334	D98976	5009 267700	MARIYA NAZAROVA	{"email": "nazarovamariya_061972@postgrespro.ru", "phone": "+70527096242"}
0005435372335	20D255	8325 099004	TATYANA MAKAROVA	{"phone": "+70930917326"}
0005435372336	828510	2545 447270	ANDREY TIKHONOV	{"email": "andrey.tikhonov.081975@postgrespro.ru", "phone": "+70952385514"}
0005435372337	55D178	3456 276018	VALENTINA DAVYDOVA	{"phone": "+70993119535"}
0005435372338	55D178	5377 970021	ELVIRA GERASIMOVA	{"email": "gerasimova-elvira-071970@postgrespro.ru", "phone": "+70106083076"}
0005435372339	4752D8	5596 743722	NATALYA BARANOVA	{"email": "baranova.natalya-08071972@postgrespro.ru", "phone": "+70579044775"}
0005435372340	4752D8	2826 061103	IRINA NIKITINA	{"email": "i.nikitina.051983@postgrespro.ru", "phone": "+70527634646"}
0005435372341	E2FED3	9082 773627	LYUBOV TROFIMOVA	{"email": "trofimova.l-021984@postgrespro.ru", "phone": "+70219378317"}
0005435372342	1E2961	2252 770220	NIKOLAY BELOV	{"email": "nikolay_belov-1968@postgrespro.ru", "phone": "+70481678222"}
0005435372343	1E2961	2613 617534	VALERIY SOKOLOV	{"phone": "+70932819950"}
0005435372344	AC247F	5752 272892	ELIZAVETA BELYAEVA	{"email": "belyaeva_e-06111977@postgrespro.ru", "phone": "+70106340410"}
0005435372345	AC247F	5198 703322	YAROSLAV SHEVCHENKO	{"email": "y.shevchenko-1974@postgrespro.ru", "phone": "+70210660832"}
0005435372346	AC247F	4919 686127	ANASTASIYA DANILOVA	{"email": "danilova_a.02111971@postgrespro.ru", "phone": "+70829772217"}
0005435372347	3C5621	1658 497173	ARTUR MIRONOV	{"email": "amironov-081975@postgrespro.ru", "phone": "+70530716202"}
0005435372348	017CCE	5387 553069	IRINA PAVLOVA	{"email": "irinapavlova.1971@postgrespro.ru", "phone": "+70231695605"}
0005435372349	017CCE	3074 814286	YULIYA NIKOLAEVA	{"phone": "+70125470745"}
0005435372350	05647C	2950 070851	SVETLANA NOVIKOVA	{"email": "s_novikova.09011963@postgrespro.ru", "phone": "+70219486893"}
0005435372351	37ED0A	1893 664235	VALERIY POPOV	{"phone": "+70613975166"}
0005435372352	37ED0A	8469 377842	ALEKSEY MEDVEDEV	{"email": "aleksey.medvedev-26011975@postgrespro.ru", "phone": "+70768777901"}
0005435372353	C4DCAA	3287 124168	ALEKSEY ILIN	{"email": "ilin-a-091979@postgrespro.ru", "phone": "+70334705115"}
0005435372354	DF47DB	4043 674319	MIKHAIL YAKOVLEV	{"phone": "+70536223558"}
0005435372355	86CF2D	8077 560245	ILYAS BORISOV	{"email": "borisov.ilyas_1978@postgrespro.ru", "phone": "+70883194001"}
0005435372356	DC88B3	5746 952246	VITALIY BONDARENKO	{"phone": "+70520972837"}
0005435372357	DC88B3	4929 416046	MARIYA DMITRIEVA	{"phone": "+70744235717"}
0005435372358	AA317A	8261 789819	SERGEY MIRONOV	{"email": "smironov-091972@postgrespro.ru", "phone": "+70763052107"}
0005435372359	3A9E77	6473 810060	LEV GORBUNOV	{"email": "l-gorbunov.19041974@postgrespro.ru", "phone": "+70502336059"}
0005435372360	3A9E77	9939 132541	LYUDMILA BARANOVA	{"phone": "+70543848010"}
0005435372361	C69A87	9741 757518	VERA KUZNECOVA	{"phone": "+70461682886"}
0005435372362	C69A87	1282 012362	ALSU YAKOVLEVA	{"phone": "+70032900830"}
0005435372363	38E76E	1537 487943	NATALYA ANDREEVA	{"phone": "+70493422984"}
0005435372364	2D7DD3	4879 861843	ANDREY KULIKOV	{"phone": "+70880611368"}
0005435372365	D88BE4	3967 871963	GALINA ZOTOVA	{"email": "g.zotova_18041977@postgrespro.ru", "phone": "+70746758259"}
0005435372366	BC8819	5415 981222	SERGEY ZAYCEV	{"email": "zaycev-s_27021966@postgrespro.ru", "phone": "+70032874458"}
0005435372367	BC8819	0747 130407	KAMIL OSIPOV	{"email": "kamil.osipov17101972@postgrespro.ru", "phone": "+70092354316"}
0005435372368	3F3963	7699 911972	IRINA EFREMOVA	{"phone": "+70404034780"}
0005435372369	AEDC43	3858 969380	EKATERINA VASILEVA	{"phone": "+70410847423"}
0005435372370	8C7F68	8485 955819	OLGA LAZAREVA	{"phone": "+70137639878"}
0005435372371	A027E9	5464 472742	SERGEY EGOROV	{"phone": "+70410395120"}
0005435372372	A027E9	5632 396569	EVGENIY AFANASEV	{"phone": "+70525993447"}
0005435372373	A027E9	1211 785616	NIKOLAY ZHUKOV	{"phone": "+70684119419"}
0005435372374	BC664E	1785 869695	ALEKSANDR MOROZOV	{"email": "morozovaleksandr061979@postgrespro.ru", "phone": "+70714801354"}
0005435372375	A23A26	3499 006402	IVAN FOMIN	{"email": "fomin-i.1982@postgrespro.ru", "phone": "+70361069064"}
0005435372376	48FF44	1355 652729	ALEKSEY BORISOV	{"phone": "+70474145420"}
0005435372377	48FF44	2382 256400	VASILIY NAZAROV	{"email": "v_nazarov-071978@postgrespro.ru", "phone": "+70681186806"}
0005435372378	48FF44	5367 565641	LYUDMILA NIKOLAEVA	{"phone": "+70795818861"}
0005435372379	119F88	8736 694810	IGOR KUZMIN	{"phone": "+70979737403"}
0005435372380	119F88	2587 528940	LYUDMILA MIKHAYLOVA	{"email": "lyudmila-mikhaylova13101973@postgrespro.ru", "phone": "+70899849124"}
0005435372381	4E5E6B	6062 041275	LYUBOV MELNIKOVA	{"phone": "+70345422405"}
0005435372382	DEDB6D	0947 453100	VLADISLAV VOLKOV	{"email": "volkovv22031971@postgrespro.ru", "phone": "+70084915380"}
0005435372383	383C27	9581 648299	VERA ALEKSEEVA	{"phone": "+70083624142"}
0005435372384	4677A7	7258 482448	VALERIY NOVIKOV	{"email": "valeriy-novikov.17021967@postgrespro.ru", "phone": "+70772139562"}
0005435372385	4677A7	8908 262183	TATYANA AKIMOVA	{"phone": "+70187765742"}
0005435372386	CB47E2	2468 894240	NINA IVANOVA	{"email": "ivanova.n101967@postgrespro.ru", "phone": "+70149572722"}
0005435372387	A08027	3096 339488	DMITRIY NAUMOV	{"email": "naumovdmitriy_121982@postgrespro.ru", "phone": "+70037028654"}
0005435372388	A08027	2097 366030	TATYANA SCHERBAKOVA	{"phone": "+70110930239"}
0005435372389	7E170E	4359 523544	FEDOR KUZMIN	{"email": "fkuzmin1979@postgrespro.ru", "phone": "+70799233173"}
0005435372390	56FBB3	2535 329270	LYUBOV FILIPPOVA	{"email": "lfilippova31011980@postgrespro.ru", "phone": "+70208869989"}
0005435372391	5C4FB4	2552 109110	ANDREY FILIPPOV	{"email": "filippov-andrey-101973@postgrespro.ru", "phone": "+70673705334"}
0005435372392	64EE40	1637 183195	NATALYA ISAEVA	{"email": "isaevan_031977@postgrespro.ru", "phone": "+70929735686"}
0005435372393	64EE40	3287 690328	TATYANA DANILOVA	{"email": "tatyana.danilova_061962@postgrespro.ru", "phone": "+70792452567"}
0005435372394	69336A	2942 321504	NATALYA DENISOVA	{"phone": "+70384675136"}
0005435372395	888843	9550 088138	VIKTOR FROLOV	{"phone": "+70397659993"}
0005435372396	888843	9936 984096	VENIAMIN ANDREEV	{"phone": "+70766979683"}
0005435372397	317A35	0758 411375	NATALYA SMIRNOVA	{"email": "n-smirnova081972@postgrespro.ru", "phone": "+70530710074"}
0005435372398	B9D9EB	5709 839993	ELENA FOMINA	{"email": "fomina_elena031978@postgrespro.ru", "phone": "+70017574826"}
0005435372399	F3654D	3730 786290	SERGEY KRASNOV	{"phone": "+70713911177"}
0005435372400	8D4811	1424 436211	NIKOLAY PETROV	{"email": "nikolay-petrov.1989@postgrespro.ru", "phone": "+70206055371"}
0005435372401	42B340	1674 443659	ANDREY STEPANOV	{"phone": "+70483408301"}
0005435372402	D404A6	9783 131315	SERGEY KUZNECOV	{"phone": "+70381466777"}
0005435372403	D404A6	2303 200171	LEYLA VOLKOVA	{"phone": "+70914938382"}
0005435372404	8296B2	1726 706612	IVAN ZAKHAROV	{"phone": "+70539129459"}
0005435372405	8296B2	1653 429370	ALEKSANDR MARTYNOV	{"phone": "+70453368211"}
0005435372406	597C72	8050 812117	MAKSIM KRASNOV	{"phone": "+70582659806"}
0005435372407	597C72	6761 742742	ARTEM SEMENOV	{"phone": "+70577876953"}
0005435372408	D005C2	3954 854490	EVGENIY SCHERBAKOV	{"email": "e.scherbakov.17041970@postgrespro.ru", "phone": "+70689943962"}
0005435372409	862B8B	4022 626239	OLGA ARKHIPOVA	{"phone": "+70881906358"}
0005435372410	BC2BAB	0475 391604	OLGA KUZNECOVA	{"phone": "+70728742984"}
0005435372411	BC2BAB	7434 558701	EKATERINA KUZNECOVA	{"phone": "+70833653137"}
0005435372412	A93C56	8355 061696	LYUBOV MOISEEVA	{"email": "l.moiseeva-1966@postgrespro.ru", "phone": "+70627545198"}
0005435372413	A93C56	3014 991766	EKATERINA DMITRIEVA	{"phone": "+70624172854"}
0005435372414	A93C56	6677 590748	NINA GAVRILOVA	{"phone": "+70388847991"}
0005435372415	5A55FE	4290 867321	OLEG BELOV	{"phone": "+70851037389"}
0005435372416	E74D7F	1680 560055	ANDREY NIKOLAEV	{"phone": "+70251987785"}
0005435372417	0B2CF4	7579 201344	YULIYA VASILEVA	{"email": "vasilevay.02071966@postgrespro.ru", "phone": "+70537703074"}
0005435372418	0B2CF4	8278 602188	IRINA MELNIKOVA	{"email": "i-melnikova.18041983@postgrespro.ru", "phone": "+70801222447"}
0005435372419	98EC19	2345 472083	VYACHESLAV MELNIKOV	{"email": "melnikov_vyacheslav_091968@postgrespro.ru", "phone": "+70718355271"}
0005435372420	98EC19	4254 650394	SVETLANA GERASIMOVA	{"phone": "+70825051964"}
0005435372421	98EC19	7496 416350	ANASTASIYA YAKOVLEVA	{"phone": "+70942347687"}
0005435372422	8A485D	9886 254600	ALEKSEY VOLKOV	{"email": "volkovaleksey.1975@postgrespro.ru", "phone": "+70553568094"}
0005435372423	3B0D7B	7169 454499	GENNADIY BORISOV	{"phone": "+70223161814"}
0005435372424	59F882	9687 153991	ALEKSANDR PAVLOV	{"email": "apavlov.081969@postgrespro.ru", "phone": "+70223270234"}
0005435372425	59F882	6460 429500	PETR KUZNECOV	{"email": "petr.kuznecov_26101976@postgrespro.ru", "phone": "+70593631230"}
0005435372426	71FEA9	5700 291075	ANDREY VOROBEV	{"email": "andrey_vorobev_081975@postgrespro.ru", "phone": "+70327856563"}
0005435372427	5C5C25	6302 763328	LYUBOV ZHUKOVA	{"phone": "+70119404520"}
0005435372428	5C5C25	3659 639433	OLESYA ZOTOVA	{"email": "zotova-olesya.1961@postgrespro.ru", "phone": "+70137241172"}
0005435372429	0ACEF6	9513 067393	IRINA ZAKHAROVA	{"phone": "+70902848114"}
0005435372430	885E05	0234 965390	SERGEY KUZNECOV	{"phone": "+70940609749"}
0005435372431	885E05	6988 257116	VIKTOR ANDREEV	{"phone": "+70181031808"}
0005435372432	C2F0D4	1625 851750	ALEKSANDR ORLOV	{"phone": "+70228797577"}
0005435372433	C2F0D4	3302 179342	VYACHESLAV MIRONOV	{"phone": "+70003186470"}
0005435372434	36C9D6	5155 326431	ANTON KONOVALOV	{"phone": "+70048637982"}
0005435372435	9CFA42	2212 262700	SVETLANA FOMINA	{"email": "svetlanafomina_1978@postgrespro.ru", "phone": "+70109423489"}
0005435372436	8CFA94	5285 611574	ELENA FILIPPOVA	{"email": "elenafilippova.121971@postgrespro.ru", "phone": "+70673404494"}
0005435372437	8CFA94	7524 958006	EVGENIYA NIKOLAEVA	{"phone": "+70732896567"}
0005435372438	73B074	8180 291081	VALENTINA DENISOVA	{"email": "denisova_v.081965@postgrespro.ru", "phone": "+70063463166"}
0005435372439	AAB469	9780 606438	NINA MAKAROVA	{"phone": "+70216586304"}
0005435372440	34144D	5786 852465	ANNA GERASIMOVA	{"phone": "+70690873169"}
0005435372441	CE106C	9747 634570	AMINA SMIRNOVA	{"phone": "+70165996104"}
0005435372442	2D3344	2792 796280	NATALYA LUKYANOVA	{"email": "lukyanova_n.1971@postgrespro.ru", "phone": "+70251355646"}
0005435372443	AE12FE	1251 444948	FEDOR KUZNECOV	{"email": "f.kuznecov-04031969@postgrespro.ru", "phone": "+70382907862"}
0005435372444	B46E09	9595 953897	SERGEY ZAKHAROV	{"email": "zakharov_sergey_08011977@postgrespro.ru", "phone": "+70671150209"}
0005435372445	819A17	9189 564617	NINA FEDOROVA	{"phone": "+70438515557"}
0005435372446	819A17	3128 675433	VADIM GUSEV	{"phone": "+70145171967"}
0005435372447	E44FF7	2273 197878	ALLA GERASIMOVA	{"email": "allagerasimova.1983@postgrespro.ru", "phone": "+70404926247"}
0005435372448	E44FF7	3484 180203	MARINA DANILOVA	{"email": "danilova_marina-1969@postgrespro.ru", "phone": "+70892402483"}
0005435372449	743344	3348 123087	ALEKSEY VLASOV	{"phone": "+70219392640"}
0005435372450	80609E	6326 883801	VASILIY MAKSIMOV	{"phone": "+70667334795"}
0005435372451	80609E	3401 935480	DENIS ORLOV	{"email": "orlovdenis-011973@postgrespro.ru", "phone": "+70303130699"}
0005435372452	AB74C7	8611 239797	TAMARA ALEKSEEVA	{"email": "tamara_alekseeva.28071976@postgrespro.ru", "phone": "+70586551266"}
0005435372453	3A019E	3449 950374	RUSLAN OSIPOV	{"phone": "+70224543028"}
0005435372454	7D91D9	0395 893849	SERGEY NIKOLAEV	{"email": "snikolaev_15111969@postgrespro.ru", "phone": "+70288902716"}
0005435372455	7D91D9	6732 276077	ANATOLIY SERGEEV	{"email": "anatoliy-sergeev_15021972@postgrespro.ru", "phone": "+70354111323"}
0005435372456	712D13	2113 634174	ARTEM ILIN	{"phone": "+70595329152"}
0005435372457	712D13	2269 791029	YULIYA KUZNECOVA	{"phone": "+70090035443"}
0005435372458	0AEC67	9323 314389	YURIY YAKOVLEV	{"email": "yakovlev.yuriy_041973@postgrespro.ru", "phone": "+70335523995"}
0005435372459	0AEC67	7849 211347	ALEKSANDR BELOV	{"phone": "+70026289457"}
0005435372460	064529	6046 882350	LARISA STEPANOVA	{"phone": "+70567789397"}
0005435372461	B0A727	4982 407074	ALEKSANDR SOLOVEV	{"email": "solovevaleksandr_121970@postgrespro.ru", "phone": "+70378555719"}
0005435372462	B0A727	9606 934606	TATYANA MOROZOVA	{"email": "morozova_tatyana-071977@postgrespro.ru", "phone": "+70261881805"}
0005435372463	2875AD	4363 292744	RUSLAN ROMANOV	{"email": "ruslanromanov_031989@postgrespro.ru", "phone": "+70794953854"}
0005435372464	0FF769	6565 857774	VYACHESLAV VOLKOV	{"email": "volkov-vyacheslav27111948@postgrespro.ru", "phone": "+70102646804"}
0005435372465	F4D735	1126 143536	NINA MARTYNOVA	{"email": "nina-martynova1978@postgrespro.ru", "phone": "+70563552533"}
0005435372466	6579D7	3709 879215	VIKTOR SIDOROV	{"phone": "+70871573221"}
0005435372467	6579D7	3124 836372	SVETLANA SIDOROVA	{"phone": "+70566641377"}
0005435372468	6E3EC5	2837 667414	GALINA DENISOVA	{"email": "galinadenisova_1983@postgrespro.ru", "phone": "+70341565780"}
0005435372469	6E3EC5	3365 538706	TATYANA KUZNECOVA	{"phone": "+70458175829"}
0005435372470	3020EE	3405 777565	VIKTORIYA KUZNECOVA	{"phone": "+70307100298"}
0005435372471	3020EE	2395 204408	ELIZAVETA KOZLOVA	{"email": "e-kozlova-23091965@postgrespro.ru", "phone": "+70137617379"}
0005435372472	3020EE	5699 137335	YULIYA ZHUKOVA	{"email": "yuliyazhukova_071980@postgrespro.ru", "phone": "+70423239237"}
0005435372473	AC3980	6926 074194	EKATERINA TARASOVA	{"email": "e-tarasova091971@postgrespro.ru", "phone": "+70294480166"}
0005435372474	BBC47F	7300 270610	DINARA TIKHONOVA	{"email": "tikhonova.d.1981@postgrespro.ru", "phone": "+70704538543"}
0005435372475	A75209	6053 556941	SOFYA GRISHINA	{"email": "s-grishina_1971@postgrespro.ru", "phone": "+70863796032"}
0005435372476	5EDF06	8528 427164	VARVARA KULIKOVA	{"email": "kulikovavarvara_091968@postgrespro.ru", "phone": "+70697591858"}
0005435372477	5EDF06	9716 202710	YANA SOROKINA	{"phone": "+70599616468"}
0005435372478	5EDF06	2332 622313	SVETLANA PAVLOVA	{"phone": "+70333098598"}
0005435372479	5E9F3D	5682 805192	EKATERINA SMIRNOVA	{"email": "e_smirnova_11051966@postgrespro.ru", "phone": "+70159292404"}
0005435372480	5E9F3D	8703 181144	VIKTOR ROMANOV	{"email": "romanov.v-31051976@postgrespro.ru", "phone": "+70129205985"}
0005435372481	D200A0	0110 769103	ANASTASIYA EFIMOVA	{"phone": "+70205712084"}
0005435372482	D200A0	2575 166311	VALERIY PETROV	{"phone": "+70568949805"}
0005435372483	E5D4D3	9819 836972	SVETLANA DMITRIEVA	{"phone": "+70914361146"}
0005435372484	67CB48	1084 090014	ANDREY ALEKSEEV	{"email": "alekseevandrey_041991@postgrespro.ru", "phone": "+70077716888"}
0005435372485	4109FD	4232 497171	VLADIMIR VLASOV	{"phone": "+70186221258"}
0005435372486	2F4305	3764 160855	SERGEY GAVRILOV	{"phone": "+70169915184"}
0005435372487	7E0A61	8596 521783	ZLATA ABRAMOVA	{"phone": "+70875069348"}
0005435372488	7E0A61	4614 439275	ANDREY VASILEV	{"phone": "+70017435722"}
0005435372489	15E999	1984 286366	EVGENIY GERASIMOV	{"phone": "+70907154983"}
0005435372490	98BD3E	7290 305678	ALLA DANILOVA	{"phone": "+70449698194"}
0005435372491	CADFB9	3673 844225	VIKTOR FEDOROV	{"email": "viktor.fedorov_1973@postgrespro.ru", "phone": "+70385389291"}
0005435372492	C66E60	6612 892605	ALEKSEY BELOV	{"phone": "+70774765235"}
0005435372493	C66E60	7108 576294	DMITRIY STEPANOV	{"email": "dstepanov-1979@postgrespro.ru", "phone": "+70032541775"}
0005435372494	80DDCF	7499 520740	MARIYA CHERNOVA	{"phone": "+70621217732"}
0005435372495	80DDCF	5283 426713	OLGA MARTYNOVA	{"phone": "+70887559210"}
0005435372496	666F8B	9949 715661	SERGEY TIMOFEEV	{"email": "timofeev_s-24091962@postgrespro.ru", "phone": "+70392182361"}
0005435372497	666F8B	7730 395118	NIKOLAY PETROV	{"email": "petrov-n-091968@postgrespro.ru", "phone": "+70638626454"}
0005435372498	1E0DA0	4884 511233	NIKOLAY KUZMIN	{"phone": "+70505857593"}
0005435372499	7DB94B	4354 943736	ANDREY MAKAROV	{"email": "andreymakarov111978@postgrespro.ru", "phone": "+70179533386"}
0005435372500	7DB94B	6505 913278	MIKHAIL KUZNECOV	{"email": "kuznecovm1976@postgrespro.ru", "phone": "+70128908352"}
0005435372501	3F6BF2	0828 348858	MARIYA KOVALEVA	{"email": "mariyakovaleva-1978@postgrespro.ru", "phone": "+70917569143"}
0005435372502	08A103	4122 669980	NADIYA YAKOVLEVA	{"phone": "+70011307753"}
0005435372503	08A103	6487 521351	ANATOLIY KARPOV	{"email": "anatoliy-karpov-19041960@postgrespro.ru", "phone": "+70394360578"}
0005435372504	94DAC9	6547 110418	KIRILL STEPANOV	{"email": "k-stepanov10051967@postgrespro.ru", "phone": "+70582025077"}
0005435372505	F1F276	1088 319424	VLADIMIR SMIRNOV	{"email": "smirnovvladimir_1985@postgrespro.ru", "phone": "+70671343905"}
0005435372506	F1F276	8676 527470	INNA STEPANOVA	{"phone": "+70876735461"}
0005435372507	F14CC9	4306 399601	TATYANA LUKYANOVA	{"phone": "+70798841585"}
0005435372508	F14CC9	1147 676837	GENNADIY TARASOV	{"phone": "+70416705087"}
0005435372509	0F34F4	5676 792133	INGA LOGINOVA	{"phone": "+70008866762"}
0005435372510	7CEA67	7561 646684	LYUDMILA KISELEVA	{"phone": "+70227694939"}
0005435372511	9B5D5B	9082 639814	NATALYA CHERNOVA	{"email": "natalyachernova-071976@postgrespro.ru", "phone": "+70629844745"}
0005435372512	9B5D5B	5069 366335	VYACHESLAV KUZNECOV	{"email": "kuznecovv06021966@postgrespro.ru", "phone": "+70997712245"}
0005435372513	08710E	3695 770586	VLADIMIR NAZAROV	{"phone": "+70248195764"}
0005435372514	F80608	0364 330357	SERGEY ANDREEV	{"email": "s.andreev.04041974@postgrespro.ru", "phone": "+70385892233"}
0005435372515	3B1B60	9725 417851	EDUARD YAKOVLEV	{"email": "yakovlev-e101983@postgrespro.ru", "phone": "+70818817959"}
0005435372516	4C9505	3480 476312	VLADIMIR SEMENOV	{"phone": "+70431735399"}
0005435372517	4C9505	5492 285001	ELENA BELYAEVA	{"email": "belyaeva.elena.021976@postgrespro.ru", "phone": "+70459706403"}
0005435372518	66197C	7566 971396	NAILYA GAVRILOVA	{"phone": "+70798028153"}
0005435372519	CC1D1A	2713 951415	ANNA NIKOLAEVA	{"email": "anikolaeva.1963@postgrespro.ru", "phone": "+70986097155"}
0005435372520	A4601D	6751 277426	MIKHAIL TIKHONOV	{"phone": "+70966194487"}
0005435372521	A4601D	7839 680468	GALINA ZHUKOVA	{"email": "zhukova_g_041982@postgrespro.ru", "phone": "+70867169551"}
0005435372522	D3000C	2345 684185	LYUDMILA VOLKOVA	{"email": "lvolkova_1974@postgrespro.ru", "phone": "+70330773694"}
0005435372523	AAB33C	3647 007301	RUSLAN STEPANOV	{"phone": "+70229812954"}
0005435372524	963D70	6421 284875	ALEKSEY KUZNECOV	{"email": "kuznecov-a_23021977@postgrespro.ru", "phone": "+70123541419"}
0005435372525	242B64	0760 826878	ALEKSANDR SCHERBAKOV	{"phone": "+70877229542"}
0005435372526	15183C	4584 096902	LEONID SCHERBAKOV	{"phone": "+70481510099"}
0005435372527	0DE6E6	1228 121814	ROZA ANTONOVA	{"email": "rozaantonova_021965@postgrespro.ru", "phone": "+70134702446"}
0005435372528	28AC98	1223 183988	VLADIMIR KARPOV	{"email": "vkarpov_03121973@postgrespro.ru", "phone": "+70364940655"}
0005435372529	770C57	5750 609301	SERGEY RODIONOV	{"phone": "+70489435969"}
0005435372530	A158DE	6557 191697	OLEG OSIPOV	{"email": "o_osipov1977@postgrespro.ru", "phone": "+70660269781"}
0005435372531	B357AD	7191 152506	MARIYA STEPANOVA	{"phone": "+70162037715"}
0005435372532	1829F9	4274 694382	VASILISA AKIMOVA	{"email": "akimova.vasilisa-10081986@postgrespro.ru", "phone": "+70288960616"}
0005435372533	385D36	0243 627314	DANIL ANTONOV	{"phone": "+70954549573"}
0005435372534	54970E	5692 664248	ARTEM ISAEV	{"email": "isaev_artem_1964@postgrespro.ru", "phone": "+70412052999"}
0005435372535	49F8A1	3405 999254	MIKHAIL EGOROV	{"email": "m_egorov1976@postgrespro.ru", "phone": "+70077613939"}
0005435372536	49F8A1	4602 671369	NIKOLAY KONOVALOV	{"phone": "+70100835870"}
0005435372537	529DDD	9727 331294	SERGEY YAKOVLEV	{"phone": "+70335111677"}
0005435372538	9174DA	6502 944549	ANNA VASILEVA	{"email": "avasileva-041980@postgrespro.ru", "phone": "+70357993552"}
0005435372539	35B58A	8851 411876	ROMAN SCHERBAKOV	{"phone": "+70988848334"}
0005435372540	35B58A	2659 358172	MAKSIM MEDVEDEV	{"email": "m_medvedev.101973@postgrespro.ru", "phone": "+70950800507"}
0005435372541	3CDC7A	7353 166349	MIKHAIL KAZAKOV	{"phone": "+70519010778"}
0005435372542	2F0ADA	7096 521162	TATYANA SMIRNOVA	{"phone": "+70441028939"}
0005435372543	2F0ADA	6502 732437	VLADIMIR NOVIKOV	{"phone": "+70284473291"}
0005435372544	0127B2	0760 317072	NIKOLAY RODIONOV	{"phone": "+70628200046"}
0005435372545	2D378C	3629 802918	SANIYA ZAKHAROVA	{"phone": "+70437367356"}
0005435372546	6CA9C1	3261 022829	ILDAR MIKHAYLOV	{"email": "mikhaylov.ildar27061980@postgrespro.ru", "phone": "+70036954777"}
0005435372547	BE95C8	5938 728168	TATYANA LAZAREVA	{"phone": "+70392689086"}
0005435372548	11AB8E	2712 427177	NATALYA KUZNECOVA	{"phone": "+70832962213"}
0005435372549	798761	0122 660045	EVGENIYA MIRONOVA	{"email": "mironova_evgeniya07091974@postgrespro.ru", "phone": "+70846096378"}
0005435372550	798761	5070 170969	VIKTOR TIKHONOV	{"phone": "+70139545831"}
0005435372551	19E55F	8998 427718	VALENTINA KRASNOVA	{"phone": "+70396084002"}
0005435372552	0F9601	5091 997025	ANASTASIYA POPOVA	{"email": "a.popova-011977@postgrespro.ru", "phone": "+70266053153"}
0005435372553	0F9601	5089 677781	ALENA ANDREEVA	{"email": "aandreeva-1973@postgrespro.ru", "phone": "+70241982441"}
0005435372554	320071	5880 794284	ANTONINA SOROKINA	{"phone": "+70967269592"}
0005435372555	640102	3154 031597	ALEKSANDR FEDOTOV	{"phone": "+70793470621"}
0005435372556	5A88E7	5293 299998	ANDREY KUZNECOV	{"email": "kuznecova_26061987@postgrespro.ru", "phone": "+70287072895"}
0005435372557	A256CF	8574 075890	VADIM FEDOROV	{"email": "vadimfedorov-30041973@postgrespro.ru", "phone": "+70346396066"}
0005435372558	25330F	5731 660001	KLAVDIYA VASILEVA	{"phone": "+70134113453"}
0005435372559	D9C6C1	8394 635564	POLINA KOMAROVA	{"email": "polina.komarova.081980@postgrespro.ru", "phone": "+70106887591"}
0005435372560	D57F61	6690 010289	ALEKSANDR DMITRIEV	{"phone": "+70834206823"}
0005435372561	D57F61	9549 970082	VALENTIN EGOROV	{"phone": "+70673053474"}
0005435372562	421308	6863 417442	NATALYA KUZMINA	{"email": "n-kuzmina.29061975@postgrespro.ru", "phone": "+70952675239"}
0005435372563	B1609B	6482 382499	SERGEY SOROKIN	{"phone": "+70423813286"}
0005435372564	91177D	0977 389167	ANATOLIY FEDOTOV	{"phone": "+70243711452"}
0005435372565	C00477	2324 815420	EKATERINA ANDREEVA	{"email": "andreevae021976@postgrespro.ru", "phone": "+70032325678"}
0005435372566	C00477	4177 504619	LYUDMILA KOROLEVA	{"email": "l.koroleva09111957@postgrespro.ru", "phone": "+70709997812"}
0005435372567	F4B8D7	0724 489033	ANASTASIYA ZAKHAROVA	{"phone": "+70254289415"}
0005435372568	F4B8D7	8187 078181	GEORGIY ABRAMOV	{"phone": "+70712968695"}
0005435372569	261226	9501 823780	VASILIY IVANOV	{"email": "v_ivanov_1976@postgrespro.ru", "phone": "+70474049218"}
0005435372570	261226	3347 340557	SERGEY KONOVALOV	{"phone": "+70075483602"}
0005435372571	6E00AA	2003 774589	GALINA IVANOVA	{"phone": "+70831497284"}
0005435372572	6E00AA	7392 865109	KONSTANTIN ALEKSANDROV	{"phone": "+70714959587"}
0005435372573	6EA996	8693 887095	KSENIYA AFANASEVA	{"email": "kseniya.afanaseva_11071973@postgrespro.ru", "phone": "+70552543353"}
0005435372574	ED7790	3364 538255	ELENA FADEEVA	{"phone": "+70721303331"}
0005435372575	AFE9F6	6226 341185	PETR BONDARENKO	{"email": "petr-bondarenko-30111975@postgrespro.ru", "phone": "+70046266159"}
0005435372576	862444	4831 206898	VALENTINA ANDREEVA	{"phone": "+70078130647"}
0005435372577	04779A	1481 955984	SVETLANA GUSEVA	{"email": "s_guseva_1973@postgrespro.ru", "phone": "+70016479467"}
0005435372578	C949C9	5014 673889	VERONIKA GORBUNOVA	{"email": "veronika-gorbunova_021965@postgrespro.ru", "phone": "+70868409649"}
0005435372579	12820C	4079 585823	KAPITALINA ANDREEVA	{"phone": "+70430205694"}
0005435372580	C5E0A6	9711 371405	MIKHAIL PETROV	{"email": "mikhail.petrov.07061970@postgrespro.ru", "phone": "+70945920361"}
0005435372581	958AD3	4568 105391	TATYANA VASILEVA	{"email": "vasileva-t_071966@postgrespro.ru", "phone": "+70123962193"}
0005435372582	958AD3	1101 482159	YURIY VOROBEV	{"phone": "+70352939075"}
0005435372583	1A49D0	2010 120039	YURIY SEMENOV	{"phone": "+70016946036"}
0005435372584	9FF3B0	2051 042218	ANNA KOROLEVA	{"email": "koroleva.anna051984@postgrespro.ru", "phone": "+70427826534"}
0005435372585	B52B3C	6881 670397	ELENA SCHERBAKOVA	{"email": "scherbakovae-06081966@postgrespro.ru", "phone": "+70756068456"}
0005435372586	B52B3C	0404 610525	ANNA ALEKSANDROVA	{"phone": "+70409545403"}
0005435372587	12AB12	0310 573868	ANDREY BONDARENKO	{"phone": "+70319129705"}
0005435372588	DAAE00	3746 826438	SVETLANA KUZMINA	{"phone": "+70024789651"}
0005435372589	284714	1442 019611	ANASTASIYA KULIKOVA	{"email": "kulikovaa-061975@postgrespro.ru", "phone": "+70894107046"}
0005435372590	284714	9504 435827	KLAVDIYA SOLOVEVA	{"email": "solovevaklavdiya.1970@postgrespro.ru", "phone": "+70714714149"}
0005435372591	8AD07C	6430 821363	EKATERINA ZHURAVLEVA	{"phone": "+70673758933"}
0005435372592	262D84	4478 297653	KONSTANTIN VASILEV	{"phone": "+70846058393"}
0005435372593	262D84	2619 024336	GALINA ILINA	{"phone": "+70700668997"}
0005435372594	1C01A6	0823 119799	NINA BORISOVA	{"email": "ninaborisova.1976@postgrespro.ru", "phone": "+70471283123"}
0005435372595	E4445C	5923 419025	ANNA CHERNOVA	{"phone": "+70212071848"}
0005435372596	D1BB95	0586 061287	YULIYA ZAYCEVA	{"phone": "+70930759943"}
0005435372597	1D63F7	3089 352587	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr041968@postgrespro.ru", "phone": "+70077730307"}
0005435372598	1D63F7	1300 353058	GAGIK EGOROV	{"phone": "+70871485952"}
0005435372599	7EA727	3582 388625	VLADIMIR TIKHONOV	{"email": "tikhonovv011979@postgrespro.ru", "phone": "+70759489412"}
0005435372600	7EA727	6499 831207	OLEG SEMENOV	{"email": "o.semenov121961@postgrespro.ru", "phone": "+70262182527"}
0005435372601	C326F4	0039 047223	EKATERINA RYABOVA	{"email": "ekaterina_ryabova1974@postgrespro.ru", "phone": "+70682346058"}
0005435372602	0029C1	9067 698162	GALINA ROMANOVA	{"phone": "+70049098830"}
0005435372603	EBFBD2	9976 840814	EKATERINA KUZMINA	{"phone": "+70493858459"}
0005435372604	AE2E76	3891 765376	ALEKSEY POPOV	{"phone": "+70218112117"}
0005435372605	AE2E76	7908 006514	NADEZHDA BELYAEVA	{"phone": "+70263365091"}
0005435372606	95FF69	7901 216230	NIKOLAY KUZNECOV	{"phone": "+70346422456"}
0005435372607	7AD953	8558 051586	ALEKSANDR MOISEEV	{"email": "a.moiseev.31051978@postgrespro.ru", "phone": "+70661160782"}
0005435372608	D0257D	6448 985913	SERGEY SAVELEV	{"phone": "+70027408447"}
0005435372609	D0257D	8692 473947	YULIYA SIDOROVA	{"phone": "+70727041742"}
0005435372610	F4EAAE	9807 524500	VLADIMIR FOMIN	{"email": "fomin-v_061967@postgrespro.ru", "phone": "+70593368897"}
0005435372611	F4EAAE	1057 506492	TAMARA VOLKOVA	{"phone": "+70478814237"}
0005435372612	29C658	8393 288045	EVGENIY MOROZOV	{"phone": "+70574391660"}
0005435372613	22A3A0	9733 306656	NATALYA LEBEDEVA	{"phone": "+70952531728"}
0005435372614	39E21B	3852 330063	ANNA VASILEVA	{"phone": "+70066362420"}
0005435372615	BBD13D	1589 465697	IGOR MAKAROV	{"phone": "+70251566739"}
0005435372616	27D402	1355 117471	ALBINA KONOVALOVA	{"email": "konovalova-albina_1965@postgrespro.ru", "phone": "+70719656410"}
0005435372617	4F773E	6691 469701	SERGEY ANTONOV	{"phone": "+70317138038"}
0005435372618	A9A2AC	0331 625557	VALERIY IVANOV	{"email": "valeriy-ivanov_101971@postgrespro.ru", "phone": "+70247857535"}
0005435372619	A0E5B8	7462 736458	ALEKSANDR POPOV	{"phone": "+70329941114"}
0005435372620	6D4081	6868 276295	OLEG ALEKSEEV	{"email": "alekseev.o011980@postgrespro.ru", "phone": "+70432509870"}
0005435372621	586348	1895 068561	EVGENIY ZAKHAROV	{"email": "evgeniy-zakharov_1969@postgrespro.ru", "phone": "+70331525816"}
0005435372622	3D911C	9358 508659	GEORGIY BORISOV	{"email": "borisovg1956@postgrespro.ru", "phone": "+70887621287"}
0005435372623	3D911C	9316 674389	MARIYA PAVLOVA	{"email": "pavlova-mariya.16081976@postgrespro.ru", "phone": "+70527957905"}
0005435372624	0B426A	8256 096227	NIKOLAY SCHERBAKOV	{"phone": "+70165411878"}
0005435372625	0B426A	7163 556444	NATALYA POTAPOVA	{"email": "natalyapotapova.071984@postgrespro.ru", "phone": "+70691761977"}
0005435372626	D1A9F4	8133 317564	NINA TIMOFEEVA	{"phone": "+70259658882"}
0005435372627	01F253	7139 949284	ANASTASIYA VOROBEVA	{"email": "a.vorobeva.121968@postgrespro.ru", "phone": "+70773745006"}
0005435372628	915008	5813 765361	IVAN NAZAROV	{"phone": "+70496231666"}
0005435372629	7734E4	4801 402880	LYUDMILA FOMINA	{"phone": "+70189040265"}
0005435372630	C221E8	7746 218785	ANDREY VLASOV	{"email": "andrey.vlasov1978@postgrespro.ru", "phone": "+70863990093"}
0005435372631	BD6E81	6502 215701	ALEKSANDR MELNIKOV	{"phone": "+70312822702"}
0005435372632	BD6E81	1426 288480	RAISA KISELEVA	{"email": "kiseleva-r061972@postgrespro.ru", "phone": "+70065976798"}
0005435372633	DD58F5	8091 479897	ALEKSANDR MAKAROV	{"email": "a-makarov-1967@postgrespro.ru", "phone": "+70017613100"}
0005435372634	DD58F5	3779 810769	VLADIMIR BARANOV	{"phone": "+70279297726"}
0005435372635	9A88BF	8123 072998	VALENTINA SEMENOVA	{"phone": "+70316254032"}
0005435372636	9A88BF	2474 857329	IVAN DENISOV	{"phone": "+70376058071"}
0005435372637	B2D784	6753 957400	VLADIMIR ANDREEV	{"phone": "+70617881753"}
0005435372638	B2D784	6546 433293	SVETLANA ZAYCEVA	{"email": "svetlana-zayceva1975@postgrespro.ru", "phone": "+70994979988"}
0005435372639	49E251	1064 537236	OLGA SMIRNOVA	{"phone": "+70726558140"}
0005435372640	49E251	3826 171086	ANNA POTAPOVA	{"email": "potapova-anna_101963@postgrespro.ru", "phone": "+70793995503"}
0005435372641	702DF7	2483 887336	ALEKSANDR OSIPOV	{"email": "osipov_aleksandr-051968@postgrespro.ru", "phone": "+70130979641"}
0005435372642	BEAEFF	4188 598945	NINA ZAKHAROVA	{"phone": "+70986265984"}
0005435372643	381924	8106 791579	VALERIY SMIRNOV	{"email": "smirnov_valeriy_25111972@postgrespro.ru", "phone": "+70697832866"}
0005435372644	381924	4681 463872	KIRILL NAUMOV	{"phone": "+70621539982"}
0005435372645	CA8471	8102 836934	VLADIMIR BONDARENKO	{"email": "vladimirbondarenko_02061962@postgrespro.ru", "phone": "+70054246229"}
0005435372646	CA8471	8491 779289	ALENA KUZMINA	{"phone": "+70760291296"}
0005435372647	4E105D	6216 783335	RAILYA VASILEVA	{"phone": "+70666790179"}
0005435372648	7FC7A1	8398 622472	NADEZHDA LEBEDEVA	{"phone": "+70412425669"}
0005435372649	046BB5	7989 322801	OLGA NIKITINA	{"phone": "+70180793809"}
0005435372650	BFE86B	8608 465246	EKATERINA NIKOLAEVA	{"email": "ekaterina.nikolaeva-1974@postgrespro.ru", "phone": "+70872145142"}
0005435372651	C4151C	2088 215556	VLADIMIR FOMIN	{"phone": "+70038022162"}
0005435372652	C4151C	9169 223501	ALEKSEY VOLKOV	{"email": "aleksey.volkov.26061985@postgrespro.ru", "phone": "+70134884236"}
0005435372653	776951	0309 207858	PAVEL IVANOV	{"email": "p_ivanov-021977@postgrespro.ru", "phone": "+70404772264"}
0005435372654	3F5A14	0201 009334	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov.27031977@postgrespro.ru", "phone": "+70917170627"}
0005435372655	50F831	2053 117838	SVETLANA FROLOVA	{"phone": "+70081236301"}
0005435372656	574AF5	3836 419603	NINA KOMAROVA	{"phone": "+70727226324"}
0005435372657	778BC8	9128 959084	SVETLANA FOMINA	{"phone": "+70083050327"}
0005435372658	778BC8	8626 025240	NATALYA MOROZOVA	{"phone": "+70818796180"}
0005435372659	509E50	5161 573053	YULIYA AKIMOVA	{"email": "yuliyaakimova-1970@postgrespro.ru", "phone": "+70107574011"}
0005435372660	509E50	6022 566997	FEDOR PAVLOV	{"phone": "+70821712190"}
0005435372661	D24601	9913 314046	EKATERINA NOVIKOVA	{"email": "novikova-ekaterina25041971@postgrespro.ru", "phone": "+70938410777"}
0005435372662	D24601	0306 562413	DMITRIY KUZNECOV	{"phone": "+70754051036"}
0005435372663	33DE88	1257 853497	ILYA STEPANOV	{"phone": "+70222092275"}
0005435372664	FF8285	5558 991030	SERGEY MEDVEDEV	{"email": "sergey-medvedev_1973@postgrespro.ru", "phone": "+70538647303"}
0005435372665	1EFE5A	4562 764504	SERGEY KONOVALOV	{"email": "skonovalov_14011977@postgrespro.ru", "phone": "+70116514215"}
0005435372666	5F4BFE	0028 748619	ANNA KUDRYASHOVA	{"email": "akudryashova.30101968@postgrespro.ru", "phone": "+70190493289"}
0005435372667	D40C38	9519 640553	RAIL MAKSIMOV	{"email": "maksimov.r-1967@postgrespro.ru", "phone": "+70181408314"}
0005435372668	B1C94E	6329 749353	VIKTOR PETROV	{"phone": "+70705189226"}
0005435372669	855C2D	5200 717565	IGOR SOKOLOV	{"email": "i_sokolov-1966@postgrespro.ru", "phone": "+70412416743"}
0005435372670	ABF16E	7061 877465	EKATERINA KOMAROVA	{"email": "komarova-ekaterina.15021960@postgrespro.ru", "phone": "+70218643907"}
0005435372671	0B6AC5	2473 780829	TAKHIR KUDRYASHOV	{"phone": "+70264209033"}
0005435372672	0B6AC5	3696 381224	VLADIMIR NAUMOV	{"email": "naumov-vladimir031981@postgrespro.ru", "phone": "+70311123849"}
0005435372673	97CABB	5893 162369	VALENTINA PETROVA	{"email": "petrova.v-1980@postgrespro.ru", "phone": "+70397792230"}
0005435372674	97CABB	3679 023205	PETR KONOVALOV	{"phone": "+70654612705"}
0005435372675	705E6E	0166 083019	ELENA ISAEVA	{"email": "isaeva-e061968@postgrespro.ru", "phone": "+70179809611"}
0005435372676	29826C	2761 881087	ELIZAVETA FILATOVA	{"phone": "+70628149862"}
0005435372677	3336AA	6457 396929	MARIYA LEBEDEVA	{"email": "lebedeva_mariya-091972@postgrespro.ru", "phone": "+70890214177"}
0005435372678	088CB0	9767 219713	MARIYA SEMENOVA	{"phone": "+70097080403"}
0005435372679	088CB0	8131 679491	ALEKSANDRA ZHURAVLEVA	{"phone": "+70467520439"}
0005435372680	7937B3	1807 282294	NATALYA RODIONOVA	{"phone": "+70626943807"}
0005435372681	7937B3	5375 253082	GALINA GAVRILOVA	{"email": "galinagavrilova-23031971@postgrespro.ru", "phone": "+70916209767"}
0005435372682	7937B3	6883 180795	GEORGIY POPOV	{"phone": "+70931244250"}
0005435372683	7EF194	4979 855122	YULIYA ISAEVA	{"email": "yuliya.isaeva121973@postgrespro.ru", "phone": "+70642139317"}
0005435372684	9C091A	7332 037775	LYUDMILA SERGEEVA	{"email": "sergeeva.lyudmila1968@postgrespro.ru", "phone": "+70429899957"}
0005435372685	BDA3A3	3098 288380	ALEKSANDR ORLOV	{"phone": "+70796129031"}
0005435372686	BDA3A3	8442 765865	IRINA FILIPPOVA	{"phone": "+70275388937"}
0005435372687	0C3CFD	2044 350797	LARISA ZHURAVLEVA	{"phone": "+70168784906"}
0005435372688	6F549F	8718 338786	SERGEY KONOVALOV	{"email": "konovalov.s_1974@postgrespro.ru", "phone": "+70026658499"}
0005435372689	D4A37C	8115 890253	MAKSIM FEDOROV	{"phone": "+70798579017"}
0005435372690	9572F2	1437 146907	ALEKSEY BONDARENKO	{"phone": "+70489496818"}
0005435372691	22C9C4	6754 596761	TATYANA GRISHINA	{"email": "grishinat.1963@postgrespro.ru", "phone": "+70741430653"}
0005435372692	22C9C4	6646 246215	IGOR IVANOV	{"phone": "+70139212283"}
0005435372693	22C9C4	8618 809868	MIKHAIL MAKAROV	{"email": "mikhail-makarov-081971@postgrespro.ru", "phone": "+70655971986"}
0005435372694	C5B4D5	5650 541994	ANATOLIY GAVRILOV	{"phone": "+70563466140"}
0005435372695	C5B4D5	2569 986771	ALEKSANDR ZAKHAROV	{"phone": "+70114378015"}
0005435372696	19E64B	3188 466737	SVETLANA PETROVA	{"email": "petrova-svetlana-03071966@postgrespro.ru", "phone": "+70281669746"}
0005435372697	CD0FD9	3789 094078	YURIY ABRAMOV	{"phone": "+70653000840"}
0005435372698	081036	4635 739293	ANTONINA EFIMOVA	{"phone": "+70600677838"}
0005435372699	5AED15	2086 821497	ALEKSEY SOKOLOV	{"phone": "+70094025176"}
0005435372700	152F61	8729 648933	DARYA CHERNOVA	{"phone": "+70279138991"}
0005435372701	1B8F6B	2966 733943	OLGA KARPOVA	{"email": "karpova.o.07051970@postgrespro.ru", "phone": "+70274474172"}
0005435372702	E68C5C	6608 566829	NIKOLAY OSIPOV	{"email": "osipovn_071976@postgrespro.ru", "phone": "+70996613278"}
0005435372703	DD5097	7772 344939	SERGEY SOLOVEV	{"email": "solovev-s.1971@postgrespro.ru", "phone": "+70151204553"}
0005435372704	DD5097	1759 239342	POLINA YAKOVLEVA	{"email": "p-yakovleva.1973@postgrespro.ru", "phone": "+70571393232"}
0005435372705	DD5097	2267 990385	VALENTINA ZOTOVA	{"email": "zotova_v.22051962@postgrespro.ru", "phone": "+70218846693"}
0005435372706	223528	1021 086259	ANTONINA KUZNECOVA	{"email": "antoninakuznecova.11081969@postgrespro.ru", "phone": "+70918025391"}
0005435372707	223528	6261 810605	VASILIY FROLOV	{"email": "vasiliy_frolov-121977@postgrespro.ru", "phone": "+70584966776"}
0005435372708	223528	4249 714787	DENIS FILIPPOV	{"email": "filippovdenis.1964@postgrespro.ru", "phone": "+70673573675"}
0005435372709	8B0393	4299 508054	NATALYA POPOVA	{"phone": "+70883671748"}
0005435372710	18C551	4645 291933	SERGEY SOLOVEV	{"email": "solovev_sergey27021968@postgrespro.ru", "phone": "+70420994822"}
0005435372711	18C551	0095 320239	TATYANA SAVELEVA	{"phone": "+70070875539"}
0005435372712	E11BBF	5122 750125	IVAN MOROZOV	{"phone": "+70711939492"}
0005435372713	FC0F23	2461 551916	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov_081972@postgrespro.ru", "phone": "+70876784448"}
0005435372714	798503	7642 109004	ANNA GUSEVA	{"email": "guseva_a021963@postgrespro.ru", "phone": "+70397560789"}
0005435372715	798503	2382 051874	ALEKSANDR SERGEEV	{"phone": "+70807639728"}
0005435372716	7E143E	0325 191119	LYUBOV ZAYCEVA	{"email": "zayceva_lyubov-1972@postgrespro.ru", "phone": "+70999897711"}
0005435372717	08DC71	2328 882475	VLADIMIR FROLOV	{"email": "frolov_vladimir011976@postgrespro.ru", "phone": "+70097887362"}
0005435372718	11DD3B	1634 501153	SERGEY MATVEEV	{"email": "s.matveev-071968@postgrespro.ru", "phone": "+70468730362"}
0005435372719	11DD3B	9584 643607	SERGEY ISAEV	{"email": "isaev-sergey-041978@postgrespro.ru", "phone": "+70419694348"}
0005435372720	11DD3B	5950 629577	ZINAIDA FROLOVA	{"phone": "+70466335092"}
0005435372721	3A96E2	5925 944943	LIDIYA KARPOVA	{"phone": "+70176661716"}
0005435372722	824C59	4355 902290	ALEKSEY IVANOV	{"phone": "+70363595470"}
0005435372723	4F19CF	9808 603392	RAISA SAVELEVA	{"phone": "+70006613137"}
0005435372724	23C10A	2420 408780	VLADISLAV ROMANOV	{"phone": "+70813489985"}
0005435372725	7AA900	2512 084613	VYACHESLAV PETROV	{"email": "petrov.v.23051975@postgrespro.ru", "phone": "+70646553606"}
0005435372726	325998	8547 723559	YAROSLAV MIKHAYLOV	{"phone": "+70131838369"}
0005435372727	6F61B0	1196 651905	NIKOLAY KUZNECOV	{"phone": "+70004554771"}
0005435372728	6F61B0	9370 555376	TATYANA KUZNECOVA	{"email": "kuznecova.t-23101969@postgrespro.ru", "phone": "+70377017450"}
0005435372729	99F098	8767 063967	ELENA VASILEVA	{"phone": "+70766799620"}
0005435372730	99F098	9589 776959	VLADIMIR TIMOFEEV	{"phone": "+70375365521"}
0005435372731	04D825	3655 944919	OLGA CHERNOVA	{"email": "o-chernova01101974@postgrespro.ru", "phone": "+70836527792"}
0005435372732	55A56B	0809 309677	GALINA FILATOVA	{"email": "galina.filatova08061983@postgrespro.ru", "phone": "+70531533978"}
0005435372733	9D9D3A	2486 642534	VLADIMIR FOMIN	{"email": "v_fomin_081967@postgrespro.ru", "phone": "+70668198292"}
0005435372734	C2964C	8518 999655	SVETLANA DENISOVA	{"email": "sdenisova28111957@postgrespro.ru", "phone": "+70457806955"}
0005435372735	94D86F	5239 023885	ALEKSANDR PETROV	{"email": "a.petrov-031972@postgrespro.ru", "phone": "+70382434230"}
0005435372736	94D86F	4771 905589	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr.21021960@postgrespro.ru", "phone": "+70568038614"}
0005435372737	7BBA26	2350 927596	GALIYA LEBEDEVA	{"email": "lebedeva_galiya.1974@postgrespro.ru", "phone": "+70695586086"}
0005435372738	CF00F1	3468 678418	ALEKSANDR ALEKSEEV	{"phone": "+70205275990"}
0005435372739	1E7E2E	2251 994197	LYUDMILA KULIKOVA	{"email": "l_kulikova1982@postgrespro.ru", "phone": "+70547138326"}
0005435372740	309C41	2243 011844	ALEKSANDR FROLOV	{"phone": "+70281473068"}
0005435372741	44D771	0296 153240	RUSLAN PETROV	{"email": "r_petrov1960@postgrespro.ru", "phone": "+70067374034"}
0005435372742	F566CB	2136 586085	ALEVTINA ANDREEVA	{"phone": "+70999531035"}
0005435372743	F566CB	0202 038684	ALEKSANDR IVANOV	{"email": "ivanova23071973@postgrespro.ru", "phone": "+70886903883"}
0005435372744	B02DB5	7810 086193	YULIYA BORISOVA	{"email": "yuliya_borisova_31101972@postgrespro.ru", "phone": "+70012595364"}
0005435372745	B02DB5	8070 860886	ANDREY MOROZOV	{"email": "morozov.a071974@postgrespro.ru", "phone": "+70435570541"}
0005435372746	60AA61	3780 148103	MARGARITA KAZAKOVA	{"phone": "+70222534083"}
0005435372747	60AA61	1510 693019	SERGEY MIKHAYLOV	{"phone": "+70985255736"}
0005435372748	60AA61	0986 576388	YURIY ISAEV	{"email": "isaevyuriy.24041977@postgrespro.ru", "phone": "+70459504443"}
0005435372749	71C030	5062 704966	IRINA NIKITINA	{"email": "nikitina_i_1971@postgrespro.ru", "phone": "+70113913420"}
0005435372750	71C030	2566 860087	EDUARD KRASNOV	{"email": "krasnov.e-14031974@postgrespro.ru", "phone": "+70765274007"}
0005435372751	373418	6540 551854	ALEKSANDR KUZNECOV	{"phone": "+70174590001"}
0005435372752	EDE716	2711 610485	ARINA LAZAREVA	{"email": "lazarevaa1969@postgrespro.ru", "phone": "+70306639437"}
0005435372753	EDE716	3116 787633	DMITRIY MELNIKOV	{"email": "d_melnikov1976@postgrespro.ru", "phone": "+70008892601"}
0005435372754	EDE716	1629 605367	TAMARA ANTONOVA	{"phone": "+70335817626"}
0005435372755	A5FDCF	0257 866677	ELENA MATVEEVA	{"email": "e_matveeva.1956@postgrespro.ru", "phone": "+70987525852"}
0005435372756	F2CE6B	4113 268477	ANATOLIY IVANOV	{"email": "anatoliy_ivanov061971@postgrespro.ru", "phone": "+70131973321"}
0005435372757	397CA0	0305 923941	TATYANA GRISHINA	{"phone": "+70664430360"}
0005435372758	2BDFE9	6312 723127	LIDIYA KRASNOVA	{"email": "lidiya_krasnova_1973@postgrespro.ru", "phone": "+70314451700"}
0005435372759	4AE0B8	0096 192810	ALINA KUZMINA	{"phone": "+70900546252"}
0005435372760	5B4953	2017 240573	ALEKSEY PETROV	{"email": "petrovaleksey_1962@postgrespro.ru", "phone": "+70800207431"}
0005435372761	5B4953	3377 271356	ANASTASIYA BARANOVA	{"phone": "+70557649778"}
0005435372762	7CA262	6442 494844	ANATOLIY NAZAROV	{"phone": "+70718326770"}
0005435372763	4156DE	4138 936955	ALEKSEY ALEKSEEV	{"email": "a.alekseev_061981@postgrespro.ru", "phone": "+70883818594"}
0005435372764	99A3E0	6363 319079	ALEKSANDR KAZAKOV	{"phone": "+70453509502"}
0005435372765	0393EB	8320 651601	ALEKSEY ZAYCEV	{"email": "zaycev.aleksey.111975@postgrespro.ru", "phone": "+70102609353"}
0005435372766	8CA2F1	1189 151336	EGOR KOROLEV	{"email": "korolevegor_17021957@postgrespro.ru", "phone": "+70799056025"}
0005435372767	483284	5408 855908	ARTEM PETROV	{"phone": "+70860797016"}
0005435372768	483284	8933 133520	LYUDMILA KOROLEVA	{"phone": "+70426397420"}
0005435372769	B582CC	8545 739793	SNEZHANA MIKHAYLOVA	{"phone": "+70867075012"}
0005435372770	CDDEB0	0549 205821	EVGENIY SAVELEV	{"phone": "+70750711832"}
0005435372771	3B3123	0027 086520	NIKOLAY MAKAROV	{"email": "makarovnikolay-25091972@postgrespro.ru", "phone": "+70325356342"}
0005435372772	31A164	9602 580692	ALEKSANDRA NOVIKOVA	{"phone": "+70909003092"}
0005435372773	C4EF85	9861 335510	GENNADIY ALEKSEEV	{"email": "gennadiyalekseev_15051979@postgrespro.ru", "phone": "+70645027391"}
0005435372774	838E68	6961 306179	PAVEL DENISOV	{"phone": "+70687606549"}
0005435372775	838E68	6399 120960	SANIYA GORBUNOVA	{"phone": "+70585289053"}
0005435372776	838E68	8205 925660	PAVEL IVANOV	{"phone": "+70179683471"}
0005435372777	6A9312	4639 403620	ANASTASIYA BORISOVA	{"phone": "+70700990811"}
0005435372778	EAD364	5561 737348	VALERIY FEDOTOV	{"email": "valeriy.fedotov.1969@postgrespro.ru", "phone": "+70099651041"}
0005435372779	EAD364	7702 644994	TATYANA SAVELEVA	{"phone": "+70375871328"}
0005435372780	EAD364	7561 177391	TATYANA SMIRNOVA	{"phone": "+70500703027"}
0005435372781	B338C2	8921 697326	MARINA KOMAROVA	{"email": "komarovamarina.04091970@postgrespro.ru", "phone": "+70500712929"}
0005435372782	79C530	5678 518168	OLGA LEBEDEVA	{"phone": "+70413200682"}
0005435372783	EA4C44	4760 198782	DIANA BARANOVA	{"email": "diana-baranova_1962@postgrespro.ru", "phone": "+70788634297"}
0005435372784	EA4C44	2066 498880	LIDIYA FEDOROVA	{"email": "l-fedorova091961@postgrespro.ru", "phone": "+70083974653"}
0005435372785	E369CE	2572 135960	ALENA GUSEVA	{"email": "a.guseva.15081964@postgrespro.ru", "phone": "+70659300128"}
0005435372786	762372	0413 287689	EKATERINA MIKHAYLOVA	{"email": "mikhaylova_e-08081969@postgrespro.ru", "phone": "+70085677178"}
0005435372787	7DC4F5	7504 664277	ELENA NIKOLAEVA	{"phone": "+70405365412"}
0005435372788	EEAF8F	1815 746102	SVETLANA PAVLOVA	{"email": "s.pavlova.15121969@postgrespro.ru", "phone": "+70309429841"}
0005435372789	DB89ED	6731 537352	ILDAR KUDRYASHOV	{"email": "ildar_kudryashov_24071957@postgrespro.ru", "phone": "+70524637292"}
0005435372790	B02BE7	7774 773420	SERGEY ZAKHAROV	{"email": "sergey-zakharov10031973@postgrespro.ru", "phone": "+70591473474"}
0005435372791	B02BE7	7735 293238	NIKOLAY KRASNOV	{"email": "krasnov.n-011974@postgrespro.ru", "phone": "+70621841389"}
0005435372792	250FF0	5336 766192	RAVILYA VOROBEVA	{"email": "vorobeva.ravilya-23121958@postgrespro.ru", "phone": "+70985995031"}
0005435372793	BA8B60	8274 520668	ZHANNA MIKHAYLOVA	{"email": "zhanna_mikhaylova24121974@postgrespro.ru", "phone": "+70746759400"}
0005435372794	BA8B60	0965 085509	TATYANA ANTONOVA	{"email": "antonova_tatyana06061984@postgrespro.ru", "phone": "+70559301510"}
0005435372795	423524	6107 114219	PAVEL KUZNECOV	{"email": "pavelkuznecov1980@postgrespro.ru", "phone": "+70280260066"}
0005435372796	423524	9944 960893	TATYANA ARKHIPOVA	{"email": "tatyanaarkhipova1977@postgrespro.ru", "phone": "+70865239813"}
0005435372797	84A346	5052 296295	IVAN CHERNOV	{"phone": "+70687128058"}
0005435372798	FE26F3	0118 399517	LYUBOV NIKIFOROVA	{"email": "lyubov.nikiforova051987@postgrespro.ru", "phone": "+70337353334"}
0005435372799	FE26F3	4758 123525	OLGA YUDINA	{"email": "yudina_olga-101967@postgrespro.ru", "phone": "+70646133424"}
0005435372800	593E9B	6092 965647	NIKOLAY MAKAROV	{"email": "makarov_n25031969@postgrespro.ru", "phone": "+70950188109"}
0005435372801	E2A9B5	2364 440140	OLEG FEDOROV	{"email": "fedorov_oleg-07041965@postgrespro.ru", "phone": "+70969851897"}
0005435372802	B196B6	3042 633576	MARINA VLASOVA	{"email": "m_vlasova-20061965@postgrespro.ru", "phone": "+70022860758"}
0005435372803	AC8570	7582 231850	LIDIYA VOLKOVA	{"email": "lvolkova061974@postgrespro.ru", "phone": "+70992787221"}
0005435372804	AC8570	6412 089163	KRISTINA KOROLEVA	{"email": "k-koroleva-081972@postgrespro.ru", "phone": "+70781670152"}
0005435372805	49F449	6395 310105	DMITRIY MIRONOV	{"phone": "+70556228930"}
0005435372806	49F449	8043 018839	ALEKSEY KOZLOV	{"email": "kozlova1973@postgrespro.ru", "phone": "+70516983296"}
0005435372807	49F449	3861 830189	MIKHAIL FILIPPOV	{"phone": "+70057067562"}
0005435372808	94F5F3	8692 433704	ANATOLIY KUZMIN	{"email": "kuzminanatoliy1967@postgrespro.ru", "phone": "+70817448390"}
0005435372809	94F5F3	1090 373235	ALEKSANDR ANTONOV	{"phone": "+70668068971"}
0005435372810	4B7715	6368 256649	SERGEY KONOVALOV	{"phone": "+70295821027"}
0005435372811	E16B47	4553 313558	ILYA SOROKIN	{"phone": "+70168490204"}
0005435372812	3A32A5	1089 443370	NIKITA KRASNOV	{"email": "krasnov_nikita26121962@postgrespro.ru", "phone": "+70338715674"}
0005435372813	7F34C5	9576 991560	LYUDMILA MAKAROVA	{"phone": "+70278900898"}
0005435372814	7F34C5	7732 160385	ALEKSANDR MELNIKOV	{"email": "melnikovaleksandr_051972@postgrespro.ru", "phone": "+70243424423"}
0005435372815	08B862	5173 867414	OLEG PETROV	{"phone": "+70552554334"}
0005435372816	2DE67D	2930 732278	MAKSIM VLASOV	{"email": "vlasov.m_1977@postgrespro.ru", "phone": "+70798239267"}
0005435372817	634EF8	3472 397245	GLEB EGOROV	{"phone": "+70567057508"}
0005435372818	634EF8	6104 343927	TATYANA NIKOLAEVA	{"phone": "+70521051854"}
0005435372819	5FE6A5	7914 307347	LIDIYA KOLESNIKOVA	{"email": "kolesnikova_lidiya_091966@postgrespro.ru", "phone": "+70694507088"}
0005435372820	AE0ACF	7893 794939	IVAN ZAKHAROV	{"phone": "+70975873277"}
0005435372821	FDBE7C	1496 515300	EVGENIY NAZAROV	{"email": "e.nazarov1967@postgrespro.ru", "phone": "+70066987676"}
0005435372822	FDBE7C	1230 105035	NADEZHDA ROMANOVA	{"email": "nadezhdaromanova_1964@postgrespro.ru", "phone": "+70283154469"}
0005435372823	0C2AAB	4180 317878	ALEKSEY ZAKHAROV	{"phone": "+70991416001"}
0005435372824	525434	9450 525665	ALEKSANDR FROLOV	{"phone": "+70402280844"}
0005435372825	525434	3228 097957	MARINA RYABOVA	{"email": "ryabova_marina-1981@postgrespro.ru", "phone": "+70018249324"}
0005435372826	525434	2208 752463	ANTON GUSEV	{"email": "agusev.21051960@postgrespro.ru", "phone": "+70128713080"}
0005435372827	650488	1238 160291	SOFYA ERMAKOVA	{"email": "ermakova_sofya1973@postgrespro.ru", "phone": "+70094122618"}
0005435372828	6F8C98	5650 850240	VALENTINA ROMANOVA	{"phone": "+70628478057"}
0005435372829	6F8C98	0908 502346	GALINA EFIMOVA	{"email": "efimovagalina_1973@postgrespro.ru", "phone": "+70236740946"}
0005435372830	6F8C98	6050 379445	ELENA OVCHINNIKOVA	{"phone": "+70026672616"}
0005435372831	4A55A5	1582 138035	OLGA PAVLOVA	{"phone": "+70847026809"}
0005435372832	02C718	4700 954587	MARINA VASILEVA	{"email": "vasileva_m26071976@postgrespro.ru", "phone": "+70774471919"}
0005435372833	07C067	9307 848705	LYUBOV POPOVA	{"email": "lpopova_1972@postgrespro.ru", "phone": "+70606608955"}
0005435372834	9FC40A	9651 545806	MARIYA YAKOVLEVA	{"email": "mariya-yakovleva_28121962@postgrespro.ru", "phone": "+70073625131"}
0005435372835	C9B3FA	1184 681437	VLADIMIR BELOV	{"phone": "+70753602920"}
0005435372836	3E76A3	6067 925212	SERGEY ANTONOV	{"email": "antonov_sergey.27121965@postgrespro.ru", "phone": "+70724389998"}
0005435372837	D80A1E	1832 335114	KSENIYA KRASNOVA	{"email": "krasnova-kseniya-051974@postgrespro.ru", "phone": "+70976342805"}
0005435372838	83F295	4865 093290	SVETLANA KOROLEVA	{"email": "svetlanakoroleva_28051965@postgrespro.ru", "phone": "+70097281490"}
0005435372839	83F295	2115 177003	ALEKSEY ROMANOV	{"phone": "+70997019636"}
0005435372840	9814EE	3320 494595	INESSA NOVIKOVA	{"email": "novikova_inessa.121970@postgrespro.ru", "phone": "+70131903378"}
0005435372841	9814EE	2203 854696	ALEKSANDR SOKOLOV	{"phone": "+70275346816"}
0005435372842	9814EE	3906 124740	ALEKSANDR TIMOFEEV	{"phone": "+70745405912"}
0005435372843	EF14A4	7332 412723	MAKSIM NIKOLAEV	{"email": "maksim-nikolaev.031976@postgrespro.ru", "phone": "+70034095243"}
0005435372844	11A4A2	3661 170746	PAVEL MAKSIMOV	{"email": "maksimov.p-15021964@postgrespro.ru", "phone": "+70462083149"}
0005435372845	53A565	5635 785377	SNEZHANA TIMOFEEVA	{"phone": "+70050631920"}
0005435372846	FE1DC5	6891 243787	ALEKSEY VOROBEV	{"phone": "+70307846499"}
0005435372847	09A0C1	5391 840350	MIKHAIL NIKOLAEV	{"phone": "+70791549801"}
0005435372848	09A0C1	9779 992634	EKATERINA LAZAREVA	{"email": "ekaterinalazareva12061967@postgrespro.ru", "phone": "+70510613027"}
0005435372849	650FCE	8346 662828	MARINA NIKIFOROVA	{"phone": "+70500834736"}
0005435372850	CFB40A	0602 525548	SERGEY ALEKSEEV	{"phone": "+70460080151"}
0005435372851	0B605E	3020 759340	YULIYA AFANASEVA	{"email": "y_afanaseva-27071963@postgrespro.ru", "phone": "+70601541876"}
0005435372852	132B62	7704 129401	NINA MATVEEVA	{"phone": "+70120195299"}
0005435372853	132B62	4937 237084	SERAFIMA TIMOFEEVA	{"phone": "+70086898696"}
0005435372854	6B872F	4722 025896	IVAN NIKOLAEV	{"phone": "+70391546006"}
0005435372855	9BEDA8	5826 115950	VALERIYA FILIPPOVA	{"phone": "+70038886858"}
0005435372856	375CE8	5684 965896	OLGA ABRAMOVA	{"phone": "+70903472713"}
0005435372857	BF3AE5	7679 515360	LYUCIYA ALEKSEEVA	{"phone": "+70044014423"}
0005435372858	BF3AE5	3342 795029	IGOR NAZAROV	{"phone": "+70213614091"}
0005435372859	9A3DCD	6937 625683	ALEKSEY TIKHONOV	{"phone": "+70056372004"}
0005435372860	1FC387	4413 166239	PETR SOLOVEV	{"email": "solovevp-1974@postgrespro.ru", "phone": "+70391916727"}
0005435372861	6CBDBC	1283 364703	NATALYA FEDOROVA	{"phone": "+70633331254"}
0005435372862	7CF535	0811 091582	VLADISLAV MOISEEV	{"email": "v_moiseev.031971@postgrespro.ru", "phone": "+70300290910"}
0005435372863	E0E00F	8993 092367	OLESYA MASLOVA	{"email": "o.maslova19121955@postgrespro.ru", "phone": "+70935906274"}
0005435372864	F4DEDE	3356 646579	VIKTOR KRASNOV	{"email": "krasnov-v.111977@postgrespro.ru", "phone": "+70568142243"}
0005435372865	40AC9C	6601 719599	ROMAN KARPOV	{"phone": "+70821137645"}
0005435372866	40AC9C	6973 762986	RUSLAN MIRONOV	{"email": "ruslanmironov-1975@postgrespro.ru", "phone": "+70119289621"}
0005435372867	469048	7815 161747	YURIY BONDARENKO	{"phone": "+70445789365"}
0005435372868	5F772D	3884 306409	NIKOLAY FILIPPOV	{"phone": "+70752564792"}
0005435372869	5F772D	7164 365436	NADEZHDA NESTEROVA	{"email": "nesterova.nadezhda01011982@postgrespro.ru", "phone": "+70136580163"}
0005435372870	1AC81F	2188 199317	ALEKSEY EGOROV	{"email": "egorov-a061962@postgrespro.ru", "phone": "+70475524453"}
0005435372871	1AC81F	7963 586233	VADIM VLASOV	{"phone": "+70862646716"}
0005435372872	ECF541	0034 082774	LYUBOV KOROLEVA	{"phone": "+70392747234"}
0005435372873	ECF541	5181 975047	ALEKSEY ROMANOV	{"phone": "+70711932694"}
0005435372874	ECF541	6910 278437	IVAN SHEVCHENKO	{"email": "ivan_shevchenko19021971@postgrespro.ru", "phone": "+70110473161"}
0005435372875	F648C4	5647 053216	LYUBOV EGOROVA	{"email": "egoroval-02031976@postgrespro.ru", "phone": "+70471176748"}
0005435372876	1E0DE9	3979 962199	TATYANA KOROLEVA	{"phone": "+70271096152"}
0005435372877	01093F	6164 123563	NADEZHDA GAVRILOVA	{"email": "gavrilova_nadezhda_01021986@postgrespro.ru", "phone": "+70672381079"}
0005435372878	885137	4834 131746	LYUBOV SIDOROVA	{"phone": "+70008181272"}
0005435372879	885137	3687 339113	VITALIY MIRONOV	{"phone": "+70319551242"}
0005435372880	C09BE1	7350 943588	VYACHESLAV VLASOV	{"email": "vlasovv.121980@postgrespro.ru", "phone": "+70227511009"}
0005435372881	48829B	1503 395014	ANDREY NIKOLAEV	{"email": "nikolaev.a011987@postgrespro.ru", "phone": "+70473987714"}
0005435372882	D61196	6284 927295	GALINA VASILEVA	{"phone": "+70198419048"}
0005435372883	75BEA7	5420 777130	ELENA POPOVA	{"phone": "+70110032749"}
0005435372884	7141AF	3502 183389	MIKHAIL STEPANOV	{"phone": "+70599552685"}
0005435372885	81EBC0	6182 917844	NINA VOLKOVA	{"phone": "+70286434767"}
0005435372886	F80E4C	2337 354094	NIKOLAY GRIGOREV	{"email": "n.grigorev-10121973@postgrespro.ru", "phone": "+70817957350"}
0005435372887	F80E4C	7130 290061	NATALYA SIDOROVA	{"email": "sidorova-natalya1985@postgrespro.ru", "phone": "+70872125489"}
0005435372888	ABCCA7	9858 269949	VLADIMIR FOMIN	{"phone": "+70035757291"}
0005435372889	C18DCD	2062 695367	VALERIY VASILEV	{"email": "vasilevvaleriy_24111976@postgrespro.ru", "phone": "+70658491222"}
0005435372890	EA0D8A	5771 745970	OLGA ARKHIPOVA	{"email": "o_arkhipova1971@postgrespro.ru", "phone": "+70947285931"}
0005435372891	F81CE7	4967 088899	VLADISLAV KUZNECOV	{"email": "kuznecov-v-071963@postgrespro.ru", "phone": "+70209259626"}
0005435373004	58A97A	5166 499631	NINA LUKYANOVA	{"phone": "+70374480579"}
0005435372892	5AADAE	2715 771681	TATYANA MIRONOVA	{"email": "tatyana-mironova_03011973@postgrespro.ru", "phone": "+70707629252"}
0005435372893	047BC0	5077 988736	MATVEY ROMANOV	{"phone": "+70492725691"}
0005435372894	047BC0	8955 687906	DENIS MEDVEDEV	{"email": "medvedev.d031982@postgrespro.ru", "phone": "+70476738991"}
0005435372895	049DF8	8391 842160	VLADIMIR YAKOVLEV	{"phone": "+70272971341"}
0005435372896	0CF11B	6718 988104	ALEKSANDR ILIN	{"email": "ilin.aleksandr_1970@postgrespro.ru", "phone": "+70998312217"}
0005435372897	4C8EF1	5872 168538	ALEKSEY PAVLOV	{"phone": "+70746401371"}
0005435372898	4C8EF1	0846 860249	MAKSIM ANTONOV	{"phone": "+70871885911"}
0005435372899	4C8EF1	0214 328170	GALINA OSIPOVA	{"phone": "+70467327010"}
0005435372900	7F3A39	6109 410703	YULIYA FROLOVA	{"email": "frolova_yuliya-121975@postgrespro.ru", "phone": "+70402826094"}
0005435372901	7F3A39	1615 895519	VLADIMIR KUZMIN	{"phone": "+70162681568"}
0005435372902	0B829D	0265 670067	GALINA NOVIKOVA	{"email": "galinanovikova_10011975@postgrespro.ru", "phone": "+70383555435"}
0005435372903	FAE1B7	5190 538351	NATALIYA PAVLOVA	{"email": "pavlova_nataliya15021969@postgrespro.ru", "phone": "+70006274207"}
0005435372904	4EBD78	8508 635905	ALEKSANDR SOKOLOV	{"email": "sokolova-1980@postgrespro.ru", "phone": "+70603819284"}
0005435372905	9C837A	4158 218547	ALEKSANDR GERASIMOV	{"phone": "+70514026680"}
0005435372906	33269C	4934 822351	ANASTASIYA MAKSIMOVA	{"phone": "+70000462177"}
0005435372907	33269C	0146 974157	OLGA SERGEEVA	{"phone": "+70298263679"}
0005435372908	33269C	5558 041969	EVGENIY SOKOLOV	{"phone": "+70383565575"}
0005435372909	534D2B	0233 733497	STEPAN GERASIMOV	{"phone": "+70615501416"}
0005435372910	137BF4	4692 286919	KONSTANTIN SOKOLOV	{"email": "sokolov.konstantin.021965@postgrespro.ru", "phone": "+70481576784"}
0005435372911	137BF4	8562 232988	DMITRIY BORISOV	{"email": "borisov_dmitriy_21031971@postgrespro.ru", "phone": "+70662205592"}
0005435372912	499A69	8667 747696	PAVEL MOROZOV	{"email": "p_morozov.091964@postgrespro.ru", "phone": "+70277681305"}
0005435372913	F1700F	2214 734659	ELENA IVANOVA	{"email": "elena-ivanova-1972@postgrespro.ru", "phone": "+70457617625"}
0005435372914	03A6DA	0651 850438	ARTEM SOLOVEV	{"email": "solovev_artem.10071973@postgrespro.ru", "phone": "+70453033257"}
0005435372915	A8D5E1	7077 208966	STANISLAV IVANOV	{"phone": "+70383170419"}
0005435372916	6A9353	7492 177804	NINA CHERNOVA	{"email": "chernova-n-111967@postgrespro.ru", "phone": "+70469434896"}
0005435372917	BAC68A	2978 314994	ARTEM KOZLOV	{"email": "akozlov.19041969@postgrespro.ru", "phone": "+70683541374"}
0005435372918	419E1E	6552 346175	EVGENIYA KUZMINA	{"phone": "+70596539681"}
0005435372919	419E1E	4962 918971	MARINA IVANOVA	{"email": "ivanovam061971@postgrespro.ru", "phone": "+70958052729"}
0005435372920	A3C55C	0742 562135	DMITRIY ZAKHAROV	{"phone": "+70537752522"}
0005435372921	A3C55C	6303 635226	MIKHAIL GORBUNOV	{"phone": "+70649160263"}
0005435372922	7E03CC	9861 316422	YURIY OSIPOV	{"email": "osipov-y.031975@postgrespro.ru", "phone": "+70398943024"}
0005435372923	7E03CC	9605 708201	OLESYA YAKOVLEVA	{"phone": "+70207270058"}
0005435372924	A542FF	1171 751629	ELENA IVANOVA	{"phone": "+70963148733"}
0005435372925	154D1F	4058 820878	VIKTOR BELOV	{"email": "vbelov-1969@postgrespro.ru", "phone": "+70443466090"}
0005435372926	FC8E8B	2958 786715	LYUBOV NESTEROVA	{"email": "nesterova-lyubov_1970@postgrespro.ru", "phone": "+70036619887"}
0005435372927	4143D5	4276 622413	IVAN KUZMIN	{"email": "i_kuzmin-1970@postgrespro.ru", "phone": "+70693997386"}
0005435372928	AAA58C	3821 266969	OLEG VOLKOV	{"phone": "+70973779926"}
0005435372929	FD208A	1089 299742	MARIANNA GORBUNOVA	{"phone": "+70496181766"}
0005435372930	AFF06A	8165 969295	ALEKSANDR POPOV	{"email": "a_popov.07051971@postgrespro.ru", "phone": "+70362155815"}
0005435372931	AFF06A	1477 515786	VALERIY SHEVCHENKO	{"email": "shevchenko-valeriy_101976@postgrespro.ru", "phone": "+70084695013"}
0005435372932	F23085	2086 891502	LYUDMILA SOLOVEVA	{"email": "soloveval031972@postgrespro.ru", "phone": "+70403752053"}
0005435372933	78611E	3083 731892	ELENA KOZLOVA	{"email": "elena.kozlova_1966@postgrespro.ru", "phone": "+70760531304"}
0005435372934	78611E	5414 103923	TATYANA CHERNOVA	{"email": "chernova_tatyana.16041974@postgrespro.ru", "phone": "+70385013310"}
0005435372935	A8E6FF	0754 049116	ALEKSANDR ZAKHAROV	{"phone": "+70153366594"}
0005435372936	A8E6FF	0127 338512	ANDREY FROLOV	{"phone": "+70831321979"}
0005435372937	9C1ABE	7046 605827	KONSTANTIN SCHERBAKOV	{"email": "k_scherbakov.121980@postgrespro.ru", "phone": "+70864725759"}
0005435372938	5A931C	2636 212189	PAVEL ZHURAVLEV	{"email": "zhuravlevp.1977@postgrespro.ru", "phone": "+70314848202"}
0005435372939	06169B	8693 895871	NIKOLAY BELOV	{"email": "n_belov.05081974@postgrespro.ru", "phone": "+70242051724"}
0005435372940	62F9AA	1573 076835	ANDREY ABRAMOV	{"phone": "+70026221883"}
0005435372941	D45098	8913 389833	NADEZHDA SCHERBAKOVA	{"phone": "+70920579182"}
0005435372942	D45098	9278 230661	SVETLANA RYABOVA	{"phone": "+70724961273"}
0005435372943	D45098	1502 586393	RAISA OVCHINNIKOVA	{"phone": "+70783523063"}
0005435372944	07B90A	7183 640392	NATALYA SERGEEVA	{"phone": "+70747080625"}
0005435372945	944CB6	1710 511593	ANASTASIYA KUZNECOVA	{"email": "anastasiya-kuznecova011967@postgrespro.ru", "phone": "+70923389115"}
0005435372946	944CB6	8375 946944	LARISA MASLOVA	{"email": "l_maslova1962@postgrespro.ru", "phone": "+70287280079"}
0005435372947	8FBF78	7505 008202	PAVEL ANTONOV	{"phone": "+70832061555"}
0005435372948	7DB193	5282 011795	SERGEY MAKSIMOV	{"email": "maksimov-s1966@postgrespro.ru", "phone": "+70959030694"}
0005435372949	06BCFA	9872 450660	EKATERINA BORISOVA	{"phone": "+70033818848"}
0005435372950	06BCFA	7026 968013	ELENA DANILOVA	{"phone": "+70453044563"}
0005435372951	17E546	1903 369307	VLADIMIR TARASOV	{"phone": "+70511803055"}
0005435372952	47BC01	2550 909645	VARVARA ARKHIPOVA	{"phone": "+70702764260"}
0005435372953	6B11B9	8334 848331	YURIY ZAKHAROV	{"email": "zakharov_yuriy-28021981@postgrespro.ru", "phone": "+70926300985"}
0005435372954	6166CF	1101 226527	VIKTOR TIMOFEEV	{"email": "timofeevviktor.031968@postgrespro.ru", "phone": "+70961991193"}
0005435372955	6166CF	6937 640547	ALEKSANDR SCHERBAKOV	{"phone": "+70809167984"}
0005435372956	F7D650	8172 869211	OLEG MEDVEDEV	{"email": "o.medvedev_081969@postgrespro.ru", "phone": "+70116642412"}
0005435372957	1AE7AE	1546 818548	VLADISLAV SERGEEV	{"email": "v-sergeev1967@postgrespro.ru", "phone": "+70842130213"}
0005435372958	D9BE9A	2935 237425	NADEZHDA FEDOROVA	{"phone": "+70425563175"}
0005435372959	EC982E	1884 327475	OLGA RYABOVA	{"phone": "+70325118538"}
0005435372960	879EE7	6157 229522	ALEKSANDR IVANOV	{"phone": "+70101229203"}
0005435372961	059E32	8087 536134	ALEKSANDR SERGEEV	{"email": "a.sergeev.081973@postgrespro.ru", "phone": "+70112560154"}
0005435372962	83F1FF	7960 616731	NATALYA MAKAROVA	{"phone": "+70627072072"}
0005435372963	782DD6	6456 361934	DENIS ZAKHAROV	{"phone": "+70825054745"}
0005435372964	1CC5AA	7443 772215	VIKTOR GORBUNOV	{"email": "v-gorbunov.1975@postgrespro.ru", "phone": "+70966389384"}
0005435372965	9DAFE7	6002 213477	RAISA ABRAMOVA	{"phone": "+70494860281"}
0005435372966	4D189F	5627 332517	INNA KULIKOVA	{"email": "kulikovainna_1966@postgrespro.ru", "phone": "+70486277704"}
0005435372967	A808D5	0652 510141	SERGEY MAKAROV	{"phone": "+70171814789"}
0005435372968	A808D5	6304 333730	PAVEL NOVIKOV	{"phone": "+70935276998"}
0005435372969	8BAB02	4427 312452	NIKOLAY MEDVEDEV	{"phone": "+70347139236"}
0005435372970	20F1F4	9533 969724	ELENA MAKSIMOVA	{"email": "emaksimova-16041972@postgrespro.ru", "phone": "+70289951172"}
0005435372971	20F1F4	8836 774295	YULIYA ANTONOVA	{"phone": "+70027164198"}
0005435372972	2C8AE6	6994 446094	NINA KRASNOVA	{"email": "nina_krasnova.021971@postgrespro.ru", "phone": "+70335382221"}
0005435372973	EDDA88	0127 493447	SERGEY SEMENOV	{"email": "sergey-semenov_1989@postgrespro.ru", "phone": "+70362035146"}
0005435372974	EDDA88	4408 543916	VALENTINA PETROVA	{"email": "valentinapetrova1971@postgrespro.ru", "phone": "+70840624389"}
0005435372975	355983	4280 725989	VIKTOR AFANASEV	{"phone": "+70718833471"}
0005435372976	B260A9	6726 965999	ILYA KUZNECOV	{"phone": "+70066022153"}
0005435372977	B260A9	6881 459676	ARTEM KULIKOV	{"phone": "+70674882168"}
0005435372978	D7B85C	8411 217843	VYACHESLAV BONDARENKO	{"phone": "+70847226534"}
0005435372979	D7B85C	9054 643314	SVETLANA GERASIMOVA	{"email": "svetlana_gerasimova-1980@postgrespro.ru", "phone": "+70977783154"}
0005435372980	3EE625	8815 506541	NATALIYA DAVYDOVA	{"phone": "+70542253117"}
0005435372981	3EE625	6792 991972	OLGA MELNIKOVA	{"email": "olga.melnikova121974@postgrespro.ru", "phone": "+70969175942"}
0005435372982	6CA6CA	9288 082677	DMITRIY KOZLOV	{"email": "kozlovd.12081968@postgrespro.ru", "phone": "+70607166425"}
0005435372983	2C85E2	8777 348814	ALEKSEY PETROV	{"email": "alekseypetrov-1968@postgrespro.ru", "phone": "+70713643033"}
0005435372984	ED52DC	7536 923784	VARVARA NIKIFOROVA	{"email": "vnikiforova_02111968@postgrespro.ru", "phone": "+70996611762"}
0005435372985	6FD754	5326 306987	EVGENIY FOMIN	{"email": "evgeniy.fomin.07121964@postgrespro.ru", "phone": "+70964320659"}
0005435372986	6FD754	3473 480153	EVGENIYA GORBUNOVA	{"phone": "+70739400678"}
0005435372987	C3CD44	3247 257052	VLADISLAV MAKAROV	{"phone": "+70668459346"}
0005435372988	C3CD44	0660 823468	ARSENIY ZAYCEV	{"email": "zaycev.arseniy-30041972@postgrespro.ru", "phone": "+70103335583"}
0005435372989	E4CAD8	5628 808916	VALENTINA KONOVALOVA	{"phone": "+70051657439"}
0005435372990	992DAE	9443 421642	VALENTINA FROLOVA	{"phone": "+70582533682"}
0005435372991	992DAE	3226 138467	EVGENIY TIKHONOV	{"email": "tikhonov-e.07011982@postgrespro.ru", "phone": "+70166176365"}
0005435372992	4445DD	9187 969778	MARIYA ILINA	{"email": "milina-1979@postgrespro.ru", "phone": "+70780276667"}
0005435372993	0F81C0	2110 179685	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov1975@postgrespro.ru", "phone": "+70851175177"}
0005435372994	2D1EDF	2477 109699	MARINA MEDVEDEVA	{"email": "m-medvedeva-041964@postgrespro.ru", "phone": "+70332497665"}
0005435372995	1447BC	3362 992902	ANNA SAVELEVA	{"phone": "+70337779599"}
0005435372996	1447BC	4491 400116	ALEKSEY BONDARENKO	{"email": "a-bondarenko_121964@postgrespro.ru", "phone": "+70120048422"}
0005435372997	D7AAB6	7635 688462	ALIYA NOVIKOVA	{"phone": "+70534476839"}
0005435372998	BF45EC	0602 142594	DARYA KUZNECOVA	{"email": "kuznecovadarya.091980@postgrespro.ru", "phone": "+70133664572"}
0005435372999	8F742E	3418 014696	ILYA PAVLOV	{"email": "ilya_pavlov.08041972@postgrespro.ru", "phone": "+70568149872"}
0005435373000	B10101	6776 043342	MARIYA MATVEEVA	{"email": "mariya_matveeva-041979@postgrespro.ru", "phone": "+70987209096"}
0005435373001	B10101	1215 321664	NATALYA MATVEEVA	{"phone": "+70973754636"}
0005435373002	CBF9F6	4649 151559	YULIYA KULIKOVA	{"phone": "+70105322591"}
0005435373003	30DE9E	6817 048020	MIKHAIL MATVEEV	{"phone": "+70699469513"}
0005435373005	AD68CE	1235 988838	TAMARA SOROKINA	{"email": "sorokina.tamara15051973@postgrespro.ru", "phone": "+70523877634"}
0005435373006	F812EF	1558 191916	ANNA EGOROVA	{"email": "egorova.a_05101964@postgrespro.ru", "phone": "+70128273111"}
0005435373007	16A5A5	3893 984271	GALINA TROFIMOVA	{"email": "galina-trofimova.1971@postgrespro.ru", "phone": "+70861589934"}
0005435373008	48F099	6093 111427	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr1968@postgrespro.ru", "phone": "+70810527480"}
0005435373009	9D2179	3633 310387	ELENA KONOVALOVA	{"phone": "+70162747057"}
0005435373010	5DAE1D	6517 249445	SERGEY KAZAKOV	{"phone": "+70269589493"}
0005435373011	5DAE1D	3053 625279	RADIK YAKOVLEV	{"phone": "+70104002376"}
0005435373012	8F491E	9544 099915	YURIY MIRONOV	{"phone": "+70876687869"}
0005435373013	8F491E	1753 050583	VLADIMIR RODIONOV	{"phone": "+70986544247"}
0005435373014	0D3270	6593 548357	ALEKSEY KONOVALOV	{"email": "konovalov.a031971@postgrespro.ru", "phone": "+70248185810"}
0005435373015	2527F6	0606 083965	VLADIMIR NIKITIN	{"phone": "+70346100556"}
0005435373016	2527F6	3471 447425	MARINA POLYAKOVA	{"email": "marina.polyakova.09021977@postgrespro.ru", "phone": "+70621961978"}
0005435373017	7C5379	4643 055365	DMITRIY KUZNECOV	{"phone": "+70184346140"}
0005435373018	7C5379	6403 676558	ANTONINA ORLOVA	{"email": "antonina-orlova091970@postgrespro.ru", "phone": "+70552867918"}
0005435373019	531A54	4495 694558	VITALIY ABRAMOV	{"email": "v_abramov14071986@postgrespro.ru", "phone": "+70251822038"}
0005435373020	761C1A	6290 138083	KONSTANTIN KUZNECOV	{"email": "konstantin_kuznecov111979@postgrespro.ru", "phone": "+70227865978"}
0005435373021	30BF72	5844 555498	YURIY OSIPOV	{"phone": "+70107399823"}
0005435373022	A6271E	3645 987251	TATYANA IVANOVA	{"phone": "+70047960849"}
0005435373023	020379	8489 719773	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-1978@postgrespro.ru", "phone": "+70355989034"}
0005435373024	3D20A7	9585 547164	TIMOFEY POPOV	{"phone": "+70212773195"}
0005435373025	3D20A7	5550 146257	ALEKSANDR NIKITIN	{"phone": "+70796925267"}
0005435373026	437042	1398 603563	GALINA KOROLEVA	{"email": "g.koroleva02091977@postgrespro.ru", "phone": "+70559725300"}
0005435373027	CD2762	8749 783684	ALFIYA EFIMOVA	{"phone": "+70096572577"}
0005435373028	AEFE67	0395 276852	ANATOLIY OSIPOV	{"email": "osipov_a_21061965@postgrespro.ru", "phone": "+70914970874"}
0005435373029	DB30E9	8635 174002	ZINAIDA VOLKOVA	{"phone": "+70512448425"}
0005435373030	DB30E9	1544 567090	NINA SMIRNOVA	{"email": "n-smirnova_021976@postgrespro.ru", "phone": "+70150682025"}
0005435373031	3759B0	2819 319684	GENNADIY BONDARENKO	{"phone": "+70546817163"}
0005435373032	E1D428	3060 511371	IRINA EGOROVA	{"email": "egorova-irina.051975@postgrespro.ru", "phone": "+70757876302"}
0005435373033	1BAC4E	7425 289108	VALENTINA ORLOVA	{"email": "orlova.valentina-1970@postgrespro.ru", "phone": "+70382388489"}
0005435373034	A62830	1018 475858	SVETLANA GAVRILOVA	{"email": "gavrilova_s1978@postgrespro.ru", "phone": "+70164635784"}
0005435373035	8E5C3A	6569 106331	LILIYA KISELEVA	{"phone": "+70658648616"}
0005435373036	C655D8	1585 740918	NIKOLAY ROMANOV	{"email": "romanov-nikolay_27011975@postgrespro.ru", "phone": "+70278463405"}
0005435373037	C655D8	6414 663568	LARISA YAKOVLEVA	{"phone": "+70296473055"}
0005435373038	E954DF	4632 220558	LARISA NIKOLAEVA	{"email": "l.nikolaeva-011986@postgrespro.ru", "phone": "+70640946094"}
0005435373039	E954DF	4218 625923	IVAN ANDREEV	{"phone": "+70319704207"}
0005435373040	EF7A9A	2070 413348	ELENA MELNIKOVA	{"phone": "+70317195695"}
0005435373041	A75C6A	9344 490060	ALEKSANDR SIDOROV	{"phone": "+70241642877"}
0005435373042	519DE3	5822 977850	LIDIYA MIKHAYLOVA	{"email": "mikhaylova-lidiya.011969@postgrespro.ru", "phone": "+70055236228"}
0005435373043	5B55B3	0256 005913	VERA IVANOVA	{"phone": "+70377180994"}
0005435373044	E49908	9605 357097	YURIY ANDREEV	{"phone": "+70928241500"}
0005435373045	E49908	9542 566840	ROMAN DMITRIEV	{"email": "dmitrievr.1984@postgrespro.ru", "phone": "+70043488873"}
0005435373046	BC7747	2396 110409	ROMAN IVANOV	{"phone": "+70307244224"}
0005435373047	BC7747	8786 076338	SERGEY ZAKHAROV	{"email": "sergeyzakharov.121963@postgrespro.ru", "phone": "+70721987642"}
0005435373048	C80CB3	9982 923026	ELIZAVETA ROMANOVA	{"phone": "+70191585565"}
0005435373049	23E907	3100 863654	POLINA LUKYANOVA	{"email": "polina_lukyanova_021969@postgrespro.ru", "phone": "+70325402084"}
0005435373050	14741F	6028 212202	TAMARA MELNIKOVA	{"email": "tamara-melnikova.18011978@postgrespro.ru", "phone": "+70194630353"}
0005435373051	CD324B	0914 907366	LYUDMILA SIDOROVA	{"phone": "+70598891931"}
0005435373052	222F03	5489 357478	TATYANA EFIMOVA	{"email": "efimova.tatyana.23011982@postgrespro.ru", "phone": "+70016854698"}
0005435373053	710026	6074 269879	ANNA NIKIFOROVA	{"email": "nikiforovaanna_101990@postgrespro.ru", "phone": "+70719681193"}
0005435373054	B2D6DC	9623 433051	DMITRIY NIKITIN	{"email": "dmitriynikitin.19021960@postgrespro.ru", "phone": "+70471540314"}
0005435373055	AB1FD0	9490 409215	IGOR IVANOV	{"email": "ivanov.i-23111958@postgrespro.ru", "phone": "+70800355194"}
0005435373056	354DDA	2729 315917	DENIS BONDARENKO	{"email": "bondarenko.d1963@postgrespro.ru", "phone": "+70357258569"}
0005435373057	CF1790	8853 520165	ALEKSEY VASILEV	{"email": "a_vasilev.26081972@postgrespro.ru", "phone": "+70574953123"}
0005435373058	CF1790	4795 999359	VALERIY BELOV	{"phone": "+70472188832"}
0005435373059	0140AD	2673 022971	DANIIL TARASOV	{"phone": "+70505987529"}
0005435373060	33ADD8	6157 993857	LIDIYA EFIMOVA	{"phone": "+70276403495"}
0005435373061	3EE586	6648 466517	ILYA NAZAROV	{"email": "nazarov-i_29101973@postgrespro.ru", "phone": "+70986686820"}
0005435373062	B77A82	6233 601331	DIANA MATVEEVA	{"phone": "+70523955539"}
0005435373063	252130	6863 176686	YURIY SOKOLOV	{"phone": "+70730063379"}
0005435373064	C50656	8057 226964	OLEG AFANASEV	{"email": "afanasev.o-21101976@postgrespro.ru", "phone": "+70783161441"}
0005435373065	10DCC7	3332 518543	TIMOFEY VASILEV	{"phone": "+70037159168"}
0005435373066	CE803A	5829 312787	OLEG SERGEEV	{"phone": "+70467927995"}
0005435373067	8ED7D5	0166 316635	GALINA AFANASEVA	{"email": "galina_afanaseva_28111966@postgrespro.ru", "phone": "+70332674867"}
0005435373068	8ED7D5	7970 521873	KHALIDA SOROKINA	{"email": "sorokina-k_121980@postgrespro.ru", "phone": "+70893408685"}
0005435373069	23D2BB	6256 740797	ELMIRA KOROLEVA	{"email": "e.koroleva.091974@postgrespro.ru", "phone": "+70723808993"}
0005435373070	00E8BF	6841 475656	LYUDMILA SAVELEVA	{"phone": "+70674727749"}
0005435373071	6B85A6	4033 842077	ANNA NIKITINA	{"email": "annanikitina.101971@postgrespro.ru", "phone": "+70468766837"}
0005435373072	C83A18	8917 095348	YULIYA LEBEDEVA	{"phone": "+70627180331"}
0005435373073	11A3D3	3522 005021	ILYA KARPOV	{"email": "karpov-ilya091971@postgrespro.ru", "phone": "+70589724566"}
0005435373074	398340	8199 822215	VITALIY KUZMIN	{"phone": "+70772614242"}
0005435373075	007621	6301 516572	ELENA DENISOVA	{"phone": "+70752923311"}
0005435373076	F6627C	5725 323525	ROZA ZOTOVA	{"phone": "+70950853136"}
0005435373077	F6627C	6836 612513	VALENTINA GORBUNOVA	{"email": "v_gorbunova-29011964@postgrespro.ru", "phone": "+70795026001"}
0005435373078	1F7643	0482 820053	ALEKSANDR KUZNECOV	{"email": "kuznecov.a-08121974@postgrespro.ru", "phone": "+70356413866"}
0005435373079	1F7643	8393 398814	ANASTASIYA FOMINA	{"email": "a-fomina.071974@postgrespro.ru", "phone": "+70711926072"}
0005435373080	98B9E9	8247 818284	SERGEY FOMIN	{"email": "fomin_sergey22011967@postgrespro.ru", "phone": "+70762395308"}
0005435373081	5D34AA	1938 484251	LARISA TROFIMOVA	{"email": "larisa-trofimova121972@postgrespro.ru", "phone": "+70649429300"}
0005435373082	8D8860	8642 654503	MARIANNA YUDINA	{"email": "yudina-m-111968@postgrespro.ru", "phone": "+70598338575"}
0005435373083	C78BE7	9746 937266	DENIS SOKOLOV	{"email": "denis-sokolov-15121965@postgrespro.ru", "phone": "+70594504643"}
0005435373084	C78BE7	8739 636981	ALEKSEY SOLOVEV	{"email": "solovev.a1959@postgrespro.ru", "phone": "+70773205849"}
0005435373085	EE6438	0752 293862	LYUBOV KUDRYASHOVA	{"email": "lyubov-kudryashova-061969@postgrespro.ru", "phone": "+70843221706"}
0005435373086	EE6438	3231 134073	GALINA AKIMOVA	{"phone": "+70655846450"}
0005435373087	0F132C	6176 768131	ANDREY SMIRNOV	{"email": "smirnov.a_041962@postgrespro.ru", "phone": "+70698747262"}
0005435373088	3E2A43	1639 794877	LARISA POTAPOVA	{"phone": "+70583586708"}
0005435373089	3E2A43	4546 529672	ANDREY MAKAROV	{"phone": "+70852055026"}
0005435373090	54FBFD	8651 502395	ANATOLIY POPOV	{"phone": "+70960281534"}
0005435373091	5FA771	6876 154715	MARIYA MAKAROVA	{"email": "m_makarova_071973@postgrespro.ru", "phone": "+70657559442"}
0005435373092	A417E7	8797 111535	LYUDMILA DAVYDOVA	{"phone": "+70192200663"}
0005435373093	A417E7	8965 846978	ELENA MOISEEVA	{"email": "moiseeva.elena_17121973@postgrespro.ru", "phone": "+70696818440"}
0005435373094	A417E7	9359 384033	EVGENIYA MASLOVA	{"phone": "+70274079105"}
0005435373095	A40360	6898 063512	SVETLANA KONOVALOVA	{"email": "svetlana_konovalova.041980@postgrespro.ru", "phone": "+70020339048"}
0005435373096	8A745F	9936 566722	KONSTANTIN PAVLOV	{"email": "k-pavlov.08101969@postgrespro.ru", "phone": "+70512157252"}
0005435373097	92E65E	3467 040358	MARIYA MEDVEDEVA	{"email": "medvedeva-mariya14071974@postgrespro.ru", "phone": "+70082966829"}
0005435373098	3D8306	2350 024247	VLADISLAV ZAKHAROV	{"phone": "+70526599746"}
0005435373099	3D8306	4980 668713	YURIY ANTONOV	{"email": "yuriyantonov1965@postgrespro.ru", "phone": "+70377699474"}
0005435373100	5CFEC8	9593 761263	VALENTINA POLYAKOVA	{"phone": "+70806972872"}
0005435373101	5CFEC8	6779 826471	RENAT KRASNOV	{"phone": "+70062530307"}
0005435373102	5CFEC8	7313 845600	ANDREY MAKAROV	{"email": "makarov_a_111959@postgrespro.ru", "phone": "+70621319643"}
0005435373103	D0D3D7	7987 606693	ANNA YAKOVLEVA	{"email": "yakovleva-a-101969@postgrespro.ru", "phone": "+70073094076"}
0005435373104	EBC11B	6046 291468	SERGEY MELNIKOV	{"email": "melnikovsergey_1971@postgrespro.ru", "phone": "+70564661618"}
0005435373105	182941	7780 895303	VLADIMIR MELNIKOV	{"phone": "+70098795310"}
0005435373106	182941	6640 341484	SVETLANA KOZLOVA	{"email": "kozlova_s.1976@postgrespro.ru", "phone": "+70640358220"}
0005435373107	D242F4	1304 514124	ELENA ABRAMOVA	{"phone": "+70044770543"}
0005435373108	621AE3	1133 254850	EKATERINA TIKHONOVA	{"email": "ekaterina.tikhonova_091968@postgrespro.ru", "phone": "+70476503572"}
0005435373109	621AE3	7554 588761	ALEKSEY MARTYNOV	{"email": "aleksey.martynov1973@postgrespro.ru", "phone": "+70498057667"}
0005435373110	621AE3	3709 961516	ANTONINA KUZMINA	{"phone": "+70846918008"}
0005435373111	1971EE	5020 718090	IGOR VLASOV	{"phone": "+70928523543"}
0005435373112	FB28C7	4364 274816	TAMARA SEMENOVA	{"phone": "+70093615270"}
0005435373113	61FC87	9413 892038	ILYAS GAVRILOV	{"email": "gavrilov_ilyas_18051972@postgrespro.ru", "phone": "+70528735197"}
0005435373114	7F7F02	3827 408512	LIDIYA ZOTOVA	{"email": "lidiya-zotova.1977@postgrespro.ru", "phone": "+70607053233"}
0005435373115	F53C88	5338 163730	LYUBOV MIKHAYLOVA	{"email": "mikhaylovalyubov_1977@postgrespro.ru", "phone": "+70322941988"}
0005435373116	95B70F	5865 326511	ELEONORA TARASOVA	{"phone": "+70008627161"}
0005435373117	00970F	6228 240129	DAMIR BARANOV	{"phone": "+70073369888"}
0005435373118	E8CCEC	3141 068083	SVETLANA DENISOVA	{"email": "svetlana_denisova_1968@postgrespro.ru", "phone": "+70063793028"}
0005435373119	E8CCEC	2351 597956	ILYA KOZLOV	{"email": "kozlovi1975@postgrespro.ru", "phone": "+70858815776"}
0005435373120	6C3D49	7314 118451	OKSANA KOROLEVA	{"phone": "+70803004503"}
0005435373121	B56373	2283 298545	VIKTORIYA ANDREEVA	{"email": "viktoriya.andreeva_021966@postgrespro.ru", "phone": "+70748148283"}
0005435373122	6C6C1E	4039 390107	ROMAN NIKITIN	{"email": "nikitinr_011960@postgrespro.ru", "phone": "+70085401204"}
0005435373123	3474C8	8455 992631	IVAN ZAKHAROV	{"email": "i.zakharov.1969@postgrespro.ru", "phone": "+70844181358"}
0005435373124	4D8C8A	9229 499758	ANZHELIKA VOROBEVA	{"phone": "+70091364113"}
0005435373125	3015EE	4574 634914	MARIYA PAVLOVA	{"email": "mariya-pavlova-1976@postgrespro.ru", "phone": "+70081784727"}
0005435373126	9A908D	0966 867348	NADEZHDA PETROVA	{"email": "petrova-nadezhda-24051985@postgrespro.ru", "phone": "+70376255457"}
0005435373127	9A908D	3572 798899	GALINA NESTEROVA	{"phone": "+70347100160"}
0005435373128	9A908D	4474 505825	ALEKSANDR AFANASEV	{"email": "afanasev_aleksandr.1980@postgrespro.ru", "phone": "+70292700803"}
0005435373129	D9A714	9251 655482	SERGEY ILIN	{"email": "sergeyilin051973@postgrespro.ru", "phone": "+70171449713"}
0005435373130	D9A714	6343 547125	NIKOLAY MIRONOV	{"email": "mironov-n.1967@postgrespro.ru", "phone": "+70099390492"}
0005435373131	031F5A	6219 521064	NATALYA OSIPOVA	{"email": "osipova.n-061981@postgrespro.ru", "phone": "+70599443411"}
0005435373132	031F5A	2660 493391	TAMARA AFANASEVA	{"email": "tamara-afanaseva.14091974@postgrespro.ru", "phone": "+70853738148"}
0005435373133	D68FD4	8175 263290	NADEZHDA VASILEVA	{"email": "nadezhda_vasileva-1979@postgrespro.ru", "phone": "+70640233162"}
0005435373134	D916BB	0546 789370	VALENTINA NIKITINA	{"email": "nikitinavalentina_101971@postgrespro.ru", "phone": "+70526096377"}
0005435373135	D916BB	4999 947716	EKATERINA ZHURAVLEVA	{"phone": "+70403232200"}
0005435373136	C32BAA	1233 842350	NIKOLAY DAVYDOV	{"email": "davydovn_1966@postgrespro.ru", "phone": "+70168602191"}
0005435373137	E29381	7962 998237	NIKITA GERASIMOV	{"phone": "+70618388392"}
0005435373138	E29381	4664 163057	EVGENIY TIKHONOV	{"phone": "+70406835147"}
0005435373139	54B910	0639 764083	TATYANA KOLESNIKOVA	{"phone": "+70596956177"}
0005435373140	54B910	4825 298828	MARIYA MIKHAYLOVA	{"phone": "+70502204677"}
0005435373141	D8A5DF	5482 435993	VIKTOR MAKAROV	{"phone": "+70969030695"}
0005435373142	2BD3D0	4585 465119	LYUDMILA ROMANOVA	{"email": "l-romanova-1972@postgrespro.ru", "phone": "+70936214550"}
0005435373143	2BD3D0	3437 764602	DMITRIY VASILEV	{"phone": "+70892197668"}
0005435373144	24BC21	3117 138415	IGOR KISELEV	{"phone": "+70907036324"}
0005435373145	195B48	9817 922116	VERA SOKOLOVA	{"email": "sokolova.v1964@postgrespro.ru", "phone": "+70905729654"}
0005435373146	69EB2D	5162 378398	VALERIYA ALEKSEEVA	{"email": "v_alekseeva.021980@postgrespro.ru", "phone": "+70673268683"}
0005435373147	8E26D1	1402 545641	YURIY SERGEEV	{"phone": "+70563703534"}
0005435373148	F5C204	9183 540344	LIDIYA POPOVA	{"phone": "+70171277306"}
0005435373149	2339EB	2330 856501	DANIL MIKHAYLOV	{"email": "d-mikhaylov-09011969@postgrespro.ru", "phone": "+70217049670"}
0005435373150	2339EB	9545 162855	ANATOLIY ZAKHAROV	{"email": "zakharov-anatoliy.08041969@postgrespro.ru", "phone": "+70096839037"}
0005435373151	F244D3	0210 521592	SVETLANA KOLESNIKOVA	{"phone": "+70099234473"}
0005435373152	F4BA1C	3295 565577	IRINA ZHURAVLEVA	{"phone": "+70885063973"}
0005435373153	6330EE	0854 478995	OLGA BORISOVA	{"phone": "+70147156177"}
0005435373154	9B3EC9	2111 692431	IVAN AFANASEV	{"phone": "+70471050058"}
0005435373155	540E4C	6187 147918	OLGA RYABOVA	{"email": "ryabova_o.091975@postgrespro.ru", "phone": "+70681946784"}
0005435373156	F43753	2227 932738	ALISA KONDRATEVA	{"phone": "+70975519524"}
0005435373157	F43753	2724 765680	IRINA ANISIMOVA	{"phone": "+70582925248"}
0005435373158	F43753	0919 560404	TATYANA SOKOLOVA	{"phone": "+70031347394"}
0005435373159	63EC11	7013 161709	ANATOLIY KONOVALOV	{"phone": "+70753763153"}
0005435373160	BB772B	8605 263021	IRINA BELOVA	{"email": "belovai1968@postgrespro.ru", "phone": "+70818092985"}
0005435373161	BB772B	0144 345323	ANDREY IVANOV	{"phone": "+70524045187"}
0005435373162	FC7042	5228 683135	TATYANA ALEKSANDROVA	{"email": "t_aleksandrova_25071971@postgrespro.ru", "phone": "+70633296594"}
0005435373163	0EA27C	4730 615876	ANDREY POPOV	{"email": "andrey-popov.12091973@postgrespro.ru", "phone": "+70632585722"}
0005435373164	6F8924	9868 430626	KSENIYA MALYSHEVA	{"phone": "+70679716002"}
0005435373165	6F8924	8849 464770	YULIYA NOVIKOVA	{"phone": "+70990066815"}
0005435373166	E9A31B	8815 022271	NATALYA KONDRATEVA	{"phone": "+70150243726"}
0005435373167	E9A31B	3744 577492	ANDREY OSIPOV	{"phone": "+70592338175"}
0005435373168	87F3AC	6677 226528	VALERIY BORISOV	{"email": "borisov_v.1977@postgrespro.ru", "phone": "+70343670450"}
0005435373169	0A25A4	9396 750599	FEDOR VOLKOV	{"email": "volkov.f.04081966@postgrespro.ru", "phone": "+70224572482"}
0005435373170	0A25A4	1984 589326	OLGA IVANOVA	{"email": "ivanova_olga.16061980@postgrespro.ru", "phone": "+70755352061"}
0005435373171	0A25A4	0638 821852	VIKTOR VOLKOV	{"email": "vvolkov-11061976@postgrespro.ru", "phone": "+70485125421"}
0005435373172	A848AF	5331 175265	PAVEL KUZNECOV	{"email": "pavel_kuznecov111975@postgrespro.ru", "phone": "+70344793434"}
0005435373173	97C503	3032 174969	MARIYA KOZLOVA	{"email": "m.kozlova13091974@postgrespro.ru", "phone": "+70110704015"}
0005435373174	97C503	9196 386900	ELENA MOROZOVA	{"email": "elena_morozova-10111983@postgrespro.ru", "phone": "+70814147914"}
0005435373175	97C503	7472 157273	ROZA CHERNOVA	{"email": "roza-chernova.1967@postgrespro.ru", "phone": "+70263573773"}
0005435373176	BC41D5	6886 428575	ANDREY GUSEV	{"email": "gusevandrey.041981@postgrespro.ru", "phone": "+70503720326"}
0005435373177	BC41D5	0431 744071	VERA ROMANOVA	{"email": "romanovav061983@postgrespro.ru", "phone": "+70995683709"}
0005435373178	30C7FD	7890 256269	IRINA KAZAKOVA	{"email": "irina.kazakova-081986@postgrespro.ru", "phone": "+70561594464"}
0005435373179	671932	0323 385353	SERGEY BELOV	{"email": "sergey-belov1975@postgrespro.ru", "phone": "+70348649622"}
0005435373180	07F111	9696 553965	DARYA NIKOLAEVA	{"phone": "+70768186570"}
0005435373181	331791	3145 412460	NAIL MEDVEDEV	{"email": "medvedev.n1967@postgrespro.ru", "phone": "+70754812280"}
0005435373182	635E1F	0025 828955	SERGEY VASILEV	{"email": "vasilev-sergey011973@postgrespro.ru", "phone": "+70488367730"}
0005435373183	E4C0B5	3079 775930	NIKITA SOKOLOV	{"email": "sokolov.n1969@postgrespro.ru", "phone": "+70634225151"}
0005435373184	FD6D3A	3174 820135	ALISA BELOVA	{"phone": "+70679563571"}
0005435373185	F4A973	1919 000630	BOGDAN MELNIKOV	{"email": "melnikov-b061967@postgrespro.ru", "phone": "+70118939155"}
0005435373186	B14A0B	3162 508924	ELENA SOROKINA	{"phone": "+70438576888"}
0005435373187	2F9C28	8613 544942	NATALYA EGOROVA	{"email": "n-egorova.081974@postgrespro.ru", "phone": "+70074522452"}
0005435373188	A199D2	0482 890174	GALINA TIMOFEEVA	{"phone": "+70298021706"}
0005435373189	23B5B3	2266 924173	SERGEY SCHERBAKOV	{"email": "scherbakov_s_29071971@postgrespro.ru", "phone": "+70926773279"}
0005435373190	32C52C	9089 125634	ANGELINA NAZAROVA	{"phone": "+70702839005"}
0005435373191	32C52C	8290 576389	TATYANA TITOVA	{"email": "titovat_061988@postgrespro.ru", "phone": "+70516814765"}
0005435373192	1B9299	4946 966684	MARAT ANTONOV	{"email": "antonov-m.31121971@postgrespro.ru", "phone": "+70433416504"}
0005435373193	9E3309	9996 616710	SOFIYA GORBUNOVA	{"phone": "+70018913613"}
0005435373194	D32EC6	7334 719202	IRINA STEPANOVA	{"phone": "+70294288636"}
0005435373195	24824D	8825 067019	ALEKSEY GORBUNOV	{"phone": "+70676480174"}
0005435373196	C4BF48	0271 046182	NIKITA OSIPOV	{"email": "osipov_nikita-19091966@postgrespro.ru", "phone": "+70642100476"}
0005435373197	752CF1	5151 059687	NIKOLAY PAVLOV	{"email": "pavlov_n081968@postgrespro.ru", "phone": "+70766542931"}
0005435373198	A78CBD	3096 162510	NIKITA ABRAMOV	{"email": "nikita_abramov_10101967@postgrespro.ru", "phone": "+70142328999"}
0005435373199	B66E0C	2426 959920	ANTONINA GERASIMOVA	{"email": "antonina.gerasimova.20071974@postgrespro.ru", "phone": "+70563853168"}
0005435373200	80B33D	6381 991933	MARIYA BOGDANOVA	{"email": "mariya_bogdanova-1984@postgrespro.ru", "phone": "+70058456211"}
0005435373201	80B33D	8870 452679	NIKOLAY KUZNECOV	{"phone": "+70209218206"}
0005435373202	5B98AB	8638 090911	DMITRIY DENISOV	{"phone": "+70867971178"}
0005435373203	279BE0	0355 046829	IRINA LUKYANOVA	{"phone": "+70902264019"}
0005435373204	7F6BC2	0266 537364	MIKHAIL RODIONOV	{"email": "rodionov_m_10041963@postgrespro.ru", "phone": "+70656711450"}
0005435373205	C8ECA9	4374 973182	ALEKSANDR SEMENOV	{"phone": "+70832180084"}
0005435373206	F6045A	1079 704070	MILENA MIKHAYLOVA	{"email": "m_mikhaylova.06061968@postgrespro.ru", "phone": "+70597456425"}
0005435373207	298397	9360 653608	ELENA MOISEEVA	{"email": "moiseeva-elena19111968@postgrespro.ru", "phone": "+70964758894"}
0005435373208	8E2D74	5707 222215	TATYANA EGOROVA	{"phone": "+70115696598"}
0005435373209	5D1C2F	1423 506943	YULIYA SERGEEVA	{"phone": "+70830839859"}
0005435373210	5D1C2F	8439 421360	ALBINA ISAEVA	{"phone": "+70851838912"}
0005435373211	7C5201	3011 553405	LILIYA VLASOVA	{"phone": "+70317777587"}
0005435373212	C5611B	4667 611607	ANDREY TARASOV	{"phone": "+70464315529"}
0005435373213	C5611B	4666 360443	SVETLANA MEDVEDEVA	{"phone": "+70515655080"}
0005435373214	C5611B	1452 188421	NIKOLAY MIKHAYLOV	{"phone": "+70379642085"}
0005435373215	C5611B	0824 138943	EVGENIY MELNIKOV	{"phone": "+70209948779"}
0005435373216	78E6C6	2582 951735	MARIYA PETROVA	{"phone": "+70960451074"}
0005435373217	C194C1	9539 935117	MARINA IVANOVA	{"phone": "+70787144281"}
0005435373218	E00D68	7531 617702	MARIYA FILIPPOVA	{"email": "mariyafilippova_121979@postgrespro.ru", "phone": "+70232878003"}
0005435373219	34B9F4	2826 560931	ALEKSANDR SOKOLOV	{"email": "a_sokolov.26061974@postgrespro.ru", "phone": "+70849202483"}
0005435373220	0E498C	3666 137047	ALEKSANDR VASILEV	{"email": "a_vasilev-14061974@postgrespro.ru", "phone": "+70482856459"}
0005435373221	7183BB	5216 468185	ALEKSEY SCHERBAKOV	{"phone": "+70469500635"}
0005435373222	78753C	5981 462825	GALINA KOROLEVA	{"email": "koroleva.g_1981@postgrespro.ru", "phone": "+70668339150"}
0005435373223	78753C	1036 088495	ALEKSEY NIKITIN	{"email": "anikitin.1973@postgrespro.ru", "phone": "+70491425913"}
0005435373224	76BC7D	6373 574637	OLGA SEMENOVA	{"phone": "+70613886323"}
0005435373225	94E106	4464 354067	YURIY GORBUNOV	{"phone": "+70793477149"}
0005435373226	F91256	5214 367042	SVETLANA ANDREEVA	{"email": "s-andreeva-1976@postgrespro.ru", "phone": "+70479081988"}
0005435373227	F91256	1173 336020	DMITRIY STEPANOV	{"email": "stepanovd031964@postgrespro.ru", "phone": "+70053409549"}
0005435373228	311337	7246 470559	DMITRIY KAZAKOV	{"phone": "+70521594184"}
0005435373229	BBA07D	2376 875108	YURIY KUZNECOV	{"email": "y-kuznecov.17021972@postgrespro.ru", "phone": "+70008895814"}
0005435373230	BBA07D	9860 571075	EKATERINA ANISIMOVA	{"phone": "+70953671164"}
0005435373231	B00C74	9143 879862	SERGEY POPOV	{"email": "popov.s101969@postgrespro.ru", "phone": "+70997337756"}
0005435373232	646775	0184 399888	NATALYA MOISEEVA	{"phone": "+70493345416"}
0005435373233	646775	8192 863032	VALENTINA ANISIMOVA	{"phone": "+70605772598"}
0005435373234	FF6F61	0023 575045	SERGEY PETROV	{"phone": "+70167982551"}
0005435373235	230077	4782 218500	IVAN SHEVCHENKO	{"email": "shevchenko_ivan_091967@postgrespro.ru", "phone": "+70209142295"}
0005435373236	62BD54	5978 450414	LYUDMILA OSIPOVA	{"email": "osipova.lyudmila-26041963@postgrespro.ru", "phone": "+70703482511"}
0005435373237	4536F6	9472 141266	VYACHESLAV TIMOFEEV	{"email": "timofeevv-19091977@postgrespro.ru", "phone": "+70665061979"}
0005435373238	4536F6	5213 636048	NIKOLAY MATVEEV	{"phone": "+70033635563"}
0005435373239	723608	2022 146389	IRINA SOROKINA	{"email": "irinasorokina_30071966@postgrespro.ru", "phone": "+70629687047"}
0005435373240	71BE8D	9553 410801	NIKITA FILIPPOV	{"phone": "+70845910108"}
0005435373241	C38386	1981 863017	NIKOLAY BARANOV	{"email": "nikolay.baranov-091971@postgrespro.ru", "phone": "+70423386241"}
0005435373242	7F00C3	7248 188014	ANASTASIYA NAZAROVA	{"phone": "+70852915755"}
0005435373243	7F00C3	9216 083643	ANDREY ABRAMOV	{"phone": "+70991843263"}
0005435373244	DD1661	0651 603987	DARYA OVCHINNIKOVA	{"phone": "+70962154155"}
0005435373245	E706C5	7380 718523	SVETLANA ILINA	{"phone": "+70995581810"}
0005435373246	E706C5	7869 083024	IVAN NIKITIN	{"phone": "+70164248144"}
0005435373247	A56823	8121 927800	SERGEY MIKHAYLOV	{"phone": "+70868461124"}
0005435373248	787156	4829 684492	VALENTINA POPOVA	{"email": "valentinapopova.101969@postgrespro.ru", "phone": "+70947281611"}
0005435373249	AE5694	7064 711036	OLGA KOROLEVA	{"email": "olga_koroleva-01051966@postgrespro.ru", "phone": "+70922719577"}
0005435373250	A2525F	8423 130218	ALEKSANDR ZHUKOV	{"phone": "+70648932650"}
0005435373251	A2525F	7582 538814	NATALYA OSIPOVA	{"email": "n.osipova.18031974@postgrespro.ru", "phone": "+70128537038"}
0005435373252	CE2BE7	5372 740156	KONSTANTIN GAVRILOV	{"email": "konstantingavrilov.08111984@postgrespro.ru", "phone": "+70629682514"}
0005435373253	CE2BE7	8125 219532	ANDREY GUSEV	{"phone": "+70493414550"}
0005435373254	8D676F	5064 668059	NADEZHDA KOROLEVA	{"phone": "+70421870933"}
0005435373255	7BE435	6166 762355	GALINA KALININA	{"email": "kalinina-galina-1966@postgrespro.ru", "phone": "+70010646175"}
0005435373256	359147	0601 545711	VYACHESLAV VASILEV	{"email": "vyacheslav_vasilev17061969@postgrespro.ru", "phone": "+70255787009"}
0005435373257	359147	6890 017957	ANDREY ZAKHAROV	{"email": "azakharov_27081969@postgrespro.ru", "phone": "+70790686398"}
0005435373258	F015A4	6999 627217	VALENTINA FROLOVA	{"phone": "+70411504176"}
0005435373259	805B4D	3704 491111	ALEKSANDRA MATVEEVA	{"phone": "+70762288287"}
0005435373260	E95291	8187 899234	SERGEY KRASNOV	{"email": "sergey-krasnov1974@postgrespro.ru", "phone": "+70070206326"}
0005435373261	E95291	3488 630149	LYUDMILA EFIMOVA	{"phone": "+70529070794"}
0005435373262	31B105	1763 088228	MAYYA MAKAROVA	{"phone": "+70212224298"}
0005435373263	261A0D	6302 215655	VERA ARKHIPOVA	{"phone": "+70079391750"}
0005435373264	A4F075	5231 738173	VIKTOR PETROV	{"phone": "+70568553708"}
0005435373265	A4F075	4375 871710	SERGEY TIKHONOV	{"email": "s.tikhonov_21081966@postgrespro.ru", "phone": "+70769833366"}
0005435373266	5FD43B	5889 034195	IRINA DANILOVA	{"email": "danilova-irina091987@postgrespro.ru", "phone": "+70371076322"}
0005435373267	4E12FA	7148 264488	ANNA FROLOVA	{"email": "frolova_a.1968@postgrespro.ru", "phone": "+70822991812"}
0005435373268	DFB71F	4466 637399	EVGENIY FILIPPOV	{"email": "e_filippov.1964@postgrespro.ru", "phone": "+70049018584"}
0005435373269	F47359	4437 516269	NATALYA NESTEROVA	{"email": "nesterovan-021979@postgrespro.ru", "phone": "+70344954229"}
0005435373270	F47359	3564 286287	GALINA KUZMINA	{"email": "kuzmina_g.061964@postgrespro.ru", "phone": "+70350702165"}
0005435373271	1B0D3C	9252 672629	ANTONINA KRASNOVA	{"email": "krasnovaantonina_03091966@postgrespro.ru", "phone": "+70225682750"}
0005435373272	1B0D3C	2074 571389	KRISTINA KUDRYASHOVA	{"phone": "+70214877680"}
0005435373273	A6A916	2966 343755	ALEKSANDR STEPANOV	{"email": "a.stepanov.03041967@postgrespro.ru", "phone": "+70291765193"}
0005435373274	A6A916	9964 549394	OLGA DAVYDOVA	{"email": "davydova-olga1974@postgrespro.ru", "phone": "+70055088414"}
0005435373275	A46139	8559 327044	EKATERINA NIKITINA	{"phone": "+70037989229"}
0005435373276	633831	9591 188821	GENNADIY MOROZOV	{"phone": "+70962752497"}
0005435373277	FE3F14	5560 384293	MIKHAIL EGOROV	{"phone": "+70255721458"}
0005435373278	FFC211	6321 738963	VASILIY KRASNOV	{"phone": "+70591281192"}
0005435373279	A194ED	6038 976634	ANATOLIY ANTONOV	{"email": "antonov_anatoliy_061974@postgrespro.ru", "phone": "+70883501297"}
0005435373280	59B4DE	0942 699071	VYACHESLAV STEPANOV	{"phone": "+70099831038"}
0005435373281	7DB7BB	1378 746943	RUSLAN NOVIKOV	{"email": "novikov-ruslan08051972@postgrespro.ru", "phone": "+70519591383"}
0005435373282	A09792	8962 864789	ARTEM IVANOV	{"email": "a_ivanov_1962@postgrespro.ru", "phone": "+70159019287"}
0005435373283	A09792	2119 932479	TAMARA SCHERBAKOVA	{"email": "t.scherbakova-1973@postgrespro.ru", "phone": "+70797970799"}
0005435373284	F97706	6143 666152	ALEKSANDR VOLKOV	{"email": "volkov.a_04101985@postgrespro.ru", "phone": "+70760896008"}
0005435373285	F97706	2683 845601	ANNA NESTEROVA	{"phone": "+70244335257"}
0005435373286	F97706	6481 728281	LYUDMILA KALININA	{"email": "lyudmilakalinina.021987@postgrespro.ru", "phone": "+70066513333"}
0005435373287	F97706	4748 398609	ALEKSANDR VASILEV	{"email": "vasilev-a021971@postgrespro.ru", "phone": "+70964915260"}
0005435373288	CFB4C0	7586 493739	VASILIY ZHUKOV	{"email": "zhukov-v21031968@postgrespro.ru", "phone": "+70843296830"}
0005435373289	AB03DA	3505 743814	EKATERINA PAVLOVA	{"email": "pavlova-e081978@postgrespro.ru", "phone": "+70264494682"}
0005435373290	9D638A	4050 722549	VLADIMIR ALEKSANDROV	{"phone": "+70966403022"}
0005435373291	9D638A	9364 928006	NINA IVANOVA	{"phone": "+70502036467"}
0005435373292	684E86	3340 482054	POLINA KUZNECOVA	{"phone": "+70985206316"}
0005435373293	684E86	9001 641168	EKATERINA ALEKSANDROVA	{"phone": "+70234657395"}
0005435373294	A70786	5552 451106	ARTEM FROLOV	{"email": "frolov.a.051973@postgrespro.ru", "phone": "+70751803283"}
0005435373295	8B94F3	3923 639681	EVGENIY KOROLEV	{"phone": "+70177886087"}
0005435373296	8B94F3	4527 527396	OLGA ROMANOVA	{"email": "romanova.olga-111971@postgrespro.ru", "phone": "+70344740831"}
0005435373297	53F0B2	3476 458837	ALEKSANDRA BOGDANOVA	{"email": "bogdanovaa_20081970@postgrespro.ru", "phone": "+70674185691"}
0005435373298	5CB2EF	0320 295993	EVGENIYA KOVALEVA	{"email": "kovaleva.e011971@postgrespro.ru", "phone": "+70792207745"}
0005435373299	D06343	8764 679658	ALENA KAZAKOVA	{"email": "kazakova_a.1971@postgrespro.ru", "phone": "+70864997139"}
0005435373300	A42878	0240 341877	EKATERINA SEMENOVA	{"email": "e-semenova_031972@postgrespro.ru", "phone": "+70302790231"}
0005435373301	925899	1335 517520	ALINA FEDOROVA	{"email": "a-fedorova_1981@postgrespro.ru", "phone": "+70640024626"}
0005435373302	D63931	9087 875422	ELENA FEDOROVA	{"email": "fedorova-e121990@postgrespro.ru", "phone": "+70852039624"}
0005435373303	2D2201	7992 654440	RUSLAN EGOROV	{"phone": "+70527563405"}
0005435373304	BC3259	3414 299666	ALEKSEY SAVELEV	{"email": "aleksey-savelev.101963@postgrespro.ru", "phone": "+70254000267"}
0005435373305	BC3259	3957 497203	NATALYA MOROZOVA	{"phone": "+70226021950"}
0005435373306	49F30A	8639 465321	SERGEY SERGEEV	{"email": "sergeevsergey24041971@postgrespro.ru", "phone": "+70172101421"}
0005435373307	D70850	6607 006417	MARIYA ZHUKOVA	{"phone": "+70501791074"}
0005435373308	1E817A	7472 670356	RAISA MAKAROVA	{"email": "makarova_r.021975@postgrespro.ru", "phone": "+70204103369"}
0005435373309	1E817A	6000 213010	OLGA OVCHINNIKOVA	{"email": "ovchinnikova_o_111969@postgrespro.ru", "phone": "+70926192611"}
0005435373310	55F552	4677 678262	IRINA MASLOVA	{"phone": "+70938768345"}
0005435373311	BAB6B8	0172 930339	SVETLANA RODIONOVA	{"email": "s.rodionova_08061973@postgrespro.ru", "phone": "+70827896017"}
0005435373312	8161EC	0122 466859	ANDREY VLASOV	{"phone": "+70995000843"}
0005435373313	2FD9E6	0279 880045	VLADIMIR VOROBEV	{"email": "v_vorobev-021971@postgrespro.ru", "phone": "+70865624182"}
0005435373314	2FD9E6	6565 252360	VIKTORIYA LAZAREVA	{"phone": "+70317347948"}
0005435373315	37EC65	2445 601076	VLADIMIR VOLKOV	{"phone": "+70983634659"}
0005435373316	3DA519	3176 509229	VIKTOR TIKHONOV	{"phone": "+70151737165"}
0005435373317	2994C0	7743 182045	IRINA NAZAROVA	{"email": "irinanazarova-1978@postgrespro.ru", "phone": "+70873075066"}
0005435373318	2994C0	6351 704933	SVETLANA BORISOVA	{"phone": "+70246798541"}
0005435373319	90B465	7628 213179	IRINA STEPANOVA	{"email": "istepanova-10061978@postgrespro.ru", "phone": "+70188387811"}
0005435373320	90B465	5368 556119	ANASTASIYA FOMINA	{"email": "fomina_a.1970@postgrespro.ru", "phone": "+70397727436"}
0005435373321	5B118A	1512 290118	MIKHAIL KULIKOV	{"email": "kulikov.mikhail_1973@postgrespro.ru", "phone": "+70526389923"}
0005435373322	570426	3133 932009	VYACHESLAV KARPOV	{"email": "vyacheslav.karpov1971@postgrespro.ru", "phone": "+70127673278"}
0005435373323	710A00	7054 055211	LILIYA PETROVA	{"phone": "+70280776144"}
0005435373324	710A00	0135 766467	GALINA KUZMINA	{"phone": "+70692066390"}
0005435373325	8E93ED	1167 011402	SVETLANA ZHUKOVA	{"email": "zhukovas1971@postgrespro.ru", "phone": "+70706487834"}
0005435373326	6EB550	1136 169277	SVETLANA POPOVA	{"email": "popova_s-21121974@postgrespro.ru", "phone": "+70001595558"}
0005435373327	1B39C3	9662 097900	DMITRIY KULIKOV	{"phone": "+70983108510"}
0005435373328	A7B28B	8092 757946	VADIM ZHUKOV	{"email": "zhukovvadim_21071977@postgrespro.ru", "phone": "+70831698263"}
0005435373329	59B936	5349 011735	ZINAIDA SIDOROVA	{"phone": "+70704793840"}
0005435373330	36A7CA	6272 693124	RUSHANIYA ANTONOVA	{"email": "r-antonova-091975@postgrespro.ru", "phone": "+70589654064"}
0005435373331	D2D8B5	3781 092921	LILIYA BELOVA	{"email": "l.belova.18051978@postgrespro.ru", "phone": "+70996650361"}
0005435373332	2295CA	4931 867642	GALINA SEMENOVA	{"email": "semenova_galina21031971@postgrespro.ru", "phone": "+70072655113"}
0005435373333	2295CA	2063 581942	DMITRIY GUSEV	{"email": "gusev_d_031979@postgrespro.ru", "phone": "+70784648361"}
0005435373334	245596	8176 493374	ANNA KUZNECOVA	{"phone": "+70430337681"}
0005435373335	C3663C	6981 063159	ILYA SCHERBAKOV	{"phone": "+70788911043"}
0005435373336	C3663C	7154 175680	ELENA KUZNECOVA	{"phone": "+70644573087"}
0005435373337	8976CA	2651 801543	EVGENIY SEMENOV	{"phone": "+70773618321"}
0005435373338	5BE5D5	3845 447224	ALEKSEY SOKOLOV	{"email": "sokolov_aleksey26031972@postgrespro.ru", "phone": "+70744777139"}
0005435373339	F6AC43	4902 938020	NINA NAUMOVA	{"email": "n_naumova_09031976@postgrespro.ru", "phone": "+70190627779"}
0005435373340	650398	4904 687226	DENIS NAUMOV	{"email": "naumov.d_1971@postgrespro.ru", "phone": "+70300081232"}
0005435373341	9DB183	1261 689007	GALINA ARKHIPOVA	{"email": "g-arkhipova101977@postgrespro.ru", "phone": "+70198110840"}
0005435373342	44714A	5392 304981	VLADIMIR ZAYCEV	{"phone": "+70810832408"}
0005435373343	56DB77	2815 836004	MARIYA STEPANOVA	{"email": "stepanova-mariya-12061975@postgrespro.ru", "phone": "+70776468258"}
0005435373344	332ED6	5802 136090	IRINA ANDREEVA	{"email": "irina-andreeva22121973@postgrespro.ru", "phone": "+70052002926"}
0005435373345	38EE8D	0081 517747	NINA BOGDANOVA	{"email": "n.bogdanova_061969@postgrespro.ru", "phone": "+70677458705"}
0005435373346	38EE8D	4427 671523	VASILIY KRASNOV	{"email": "krasnov.v-13051980@postgrespro.ru", "phone": "+70938477929"}
0005435373347	22F97F	9925 248620	EVGENIY MELNIKOV	{"email": "emelnikov.1971@postgrespro.ru", "phone": "+70415343071"}
0005435373348	79B1C1	1998 913437	TATYANA KOROLEVA	{"phone": "+70478961939"}
0005435373349	4564E8	8425 837518	SERGEY SOLOVEV	{"phone": "+70172416162"}
0005435373350	4564E8	4251 976647	LIDIYA ANTONOVA	{"phone": "+70803546747"}
0005435373351	0219C0	0695 574083	EKATERINA BOGDANOVA	{"email": "bogdanova-e.1977@postgrespro.ru", "phone": "+70379703329"}
0005435373352	4FBC3E	8690 706119	ZAKHAR FEDOROV	{"email": "z-fedorov1981@postgrespro.ru", "phone": "+70403463320"}
0005435373353	4FBC3E	5958 941526	ALEKSANDR FROLOV	{"email": "frolovaleksandr_15051977@postgrespro.ru", "phone": "+70873446034"}
0005435373354	B18511	0794 854903	NINA MELNIKOVA	{"email": "ninamelnikova-17111984@postgrespro.ru", "phone": "+70848293006"}
0005435373355	B18511	6597 462661	TATYANA EFIMOVA	{"email": "efimova-t_30061969@postgrespro.ru", "phone": "+70034467747"}
0005435373356	66CEFE	6139 330624	ANTON SEMENOV	{"phone": "+70712463214"}
0005435373357	FC08C7	4146 303108	EVGENIYA ILINA	{"email": "ilinae.21031969@postgrespro.ru", "phone": "+70223090400"}
0005435373358	361509	4618 933965	SERGEY NOVIKOV	{"email": "snovikov_26121974@postgrespro.ru", "phone": "+70054313406"}
0005435373359	361509	7518 914046	VALENTINA MAKSIMOVA	{"email": "maksimovav.121969@postgrespro.ru", "phone": "+70499645674"}
0005435373360	2EB7F3	3087 703267	ANNA STEPANOVA	{"phone": "+70857593312"}
0005435373361	935335	0699 040673	OLEG RODIONOV	{"phone": "+70288353096"}
0005435373362	935335	0428 764478	ANDREY MOISEEV	{"email": "moiseev-andrey_1969@postgrespro.ru", "phone": "+70236109302"}
0005435373363	E13AE0	0577 579119	TATYANA ROMANOVA	{"email": "romanovatatyana.031974@postgrespro.ru", "phone": "+70732751245"}
0005435373364	E13AE0	7499 134849	SVETLANA LUKYANOVA	{"phone": "+70099553751"}
0005435373365	40011A	7299 825827	TATYANA MOROZOVA	{"email": "morozova.t1977@postgrespro.ru", "phone": "+70130793596"}
0005435373366	B4E27F	7779 449035	TATYANA MOROZOVA	{"email": "t_morozova.1968@postgrespro.ru", "phone": "+70446541313"}
0005435373367	3E4F4B	9248 475844	TIMOFEY KRASNOV	{"phone": "+70424387844"}
0005435373368	FAD978	1588 335325	GRIGORIY AFANASEV	{"phone": "+70593888857"}
0005435373369	FAD978	5215 588486	EVA KUZNECOVA	{"phone": "+70861835669"}
0005435373370	B3224C	0391 602826	ALINA MELNIKOVA	{"phone": "+70900586252"}
0005435373371	B3224C	3321 770746	VIKTOR IVANOV	{"phone": "+70936749234"}
0005435373372	0DEA48	5079 117920	ANATOLIY POPOV	{"email": "anatoliy-popov18071980@postgrespro.ru", "phone": "+70699148256"}
0005435373373	0DEA48	4402 111229	TATYANA NIKIFOROVA	{"phone": "+70562699899"}
0005435373374	0DEA48	8725 464760	NATALYA NIKOLAEVA	{"phone": "+70942144333"}
0005435373375	29D449	8658 136312	VYACHESLAV GUSEV	{"phone": "+70269418423"}
0005435373376	8FE10D	3171 871023	NADEZHDA YUDINA	{"email": "yudina_n-1968@postgrespro.ru", "phone": "+70430054729"}
0005435373377	8FE10D	9537 424240	ALEKSANDR STEPANOV	{"phone": "+70144217328"}
0005435373378	587208	0892 936440	DAMIR STEPANOV	{"phone": "+70884343395"}
0005435373379	73E4BE	3686 434257	NAILYA KONOVALOVA	{"phone": "+70921212772"}
0005435373380	73E4BE	9785 417984	ELENA SIDOROVA	{"phone": "+70738383260"}
0005435373381	73E4BE	0642 076145	ALEKSANDR ZHURAVLEV	{"email": "aleksandr.zhuravlev-16071967@postgrespro.ru", "phone": "+70210019930"}
0005435373382	577F3F	0096 975048	SVETLANA BOGDANOVA	{"phone": "+70994363556"}
0005435373383	C029F0	1583 284978	ANNA GRISHINA	{"email": "a-grishina-111976@postgrespro.ru", "phone": "+70227311475"}
0005435373384	45D49A	5933 345449	MIKHAIL KRASNOV	{"phone": "+70908445362"}
0005435373385	CD349F	5606 930716	VLADIMIR KULIKOV	{"email": "v.kulikov.011968@postgrespro.ru", "phone": "+70835177986"}
0005435373386	F586BF	1261 251093	IGOR SMIRNOV	{"email": "i_smirnov-081979@postgrespro.ru", "phone": "+70941899568"}
0005435373387	908FBA	3752 421275	ELENA SERGEEVA	{"email": "elenasergeeva-1977@postgrespro.ru", "phone": "+70269391764"}
0005435373388	908FBA	2704 496787	ALENA TITOVA	{"email": "a_titova-01091969@postgrespro.ru", "phone": "+70402789981"}
0005435373389	B17B8F	9478 847209	DMITRIY NAUMOV	{"phone": "+70478777183"}
0005435373390	B17B8F	5539 267196	TATYANA DAVYDOVA	{"email": "davydova.t.01091983@postgrespro.ru", "phone": "+70054215280"}
0005435373391	5E09B7	7900 632735	OLGA NIKITINA	{"phone": "+70811392272"}
0005435373392	C5D36C	0497 080478	VLADIMIR KUZNECOV	{"phone": "+70924026422"}
0005435373393	4E3142	0720 192810	GRIGORIY OSIPOV	{"phone": "+70336559245"}
0005435373394	565024	3055 930772	MARINA KOLESNIKOVA	{"email": "kolesnikova_m091973@postgrespro.ru", "phone": "+70141616590"}
0005435373395	3F7686	5121 217090	GENNADIY YAKOVLEV	{"phone": "+70819870596"}
0005435373396	3F7686	8712 981500	NIKOLAY ZAYCEV	{"email": "n_zaycev.071967@postgrespro.ru", "phone": "+70811257798"}
0005435373397	3F7686	5034 907455	DMITRIY GUSEV	{"phone": "+70473003639"}
0005435373398	38586C	2552 151109	NATALYA SOROKINA	{"phone": "+70623362261"}
0005435373399	D34262	8827 759735	IRINA RYABOVA	{"email": "ryabova-irina-1980@postgrespro.ru", "phone": "+70418448219"}
0005435373400	D34262	9915 145452	ALEKSANDR ROMANOV	{"email": "aromanov031961@postgrespro.ru", "phone": "+70814496289"}
0005435373401	2045AC	7076 879442	SERGEY MAKAROV	{"phone": "+70993069952"}
0005435373402	2045AC	3394 935295	NIKOLAY SMIRNOV	{"email": "n-smirnov_27111982@postgrespro.ru", "phone": "+70231092625"}
0005435373403	F42C30	0286 394572	MARIYA LUKYANOVA	{"phone": "+70535211147"}
0005435373404	FBB877	2351 560867	ANASTASIYA ZAYCEVA	{"email": "zaycevaanastasiya.061970@postgrespro.ru", "phone": "+70882461051"}
0005435373405	FBB877	1027 513156	SEMEN VOLKOV	{"phone": "+70197218725"}
0005435373406	BB2FDF	5416 737867	VASILIY DENISOV	{"phone": "+70346086611"}
0005435373407	BB2FDF	1154 896757	VALENTINA BORISOVA	{"email": "borisovav.121970@postgrespro.ru", "phone": "+70081633099"}
0005435373408	6530B6	3818 805741	ANASTASIYA ZOTOVA	{"phone": "+70362388196"}
0005435373409	386DF0	8289 125564	FATYMA OSIPOVA	{"phone": "+70942586259"}
0005435373410	94CE4A	7187 888620	IRINA ZOTOVA	{"phone": "+70496933253"}
0005435373411	94CE4A	6580 809903	OLGA KAZAKOVA	{"email": "kazakova-o.13091979@postgrespro.ru", "phone": "+70422148069"}
0005435373412	AD31C6	8463 939006	MATVEY GERASIMOV	{"email": "m.gerasimov_061983@postgrespro.ru", "phone": "+70832262063"}
0005435373413	AD31C6	5519 268697	MILANA MOROZOVA	{"email": "milana-morozova091975@postgrespro.ru", "phone": "+70246911480"}
0005435373414	707571	5026 188630	MARIYA ISAEVA	{"email": "mariya-isaeva1967@postgrespro.ru", "phone": "+70344318282"}
0005435373415	485D83	4003 585670	MARINA ANDREEVA	{"phone": "+70106832398"}
0005435373416	CC0F8A	5494 967309	MARINA KOROLEVA	{"email": "marina.koroleva-15101970@postgrespro.ru", "phone": "+70598311391"}
0005435373417	A5876C	1476 714761	OLGA NIKOLAEVA	{"email": "olga_nikolaeva.13011967@postgrespro.ru", "phone": "+70959978443"}
0005435373418	A5876C	9789 936093	YULIYA KOMAROVA	{"phone": "+70889196238"}
0005435373419	F8E8FB	5915 990747	OKSANA MIKHAYLOVA	{"phone": "+70990527186"}
0005435373420	21BB62	0274 420031	ANASTASIYA VOLKOVA	{"phone": "+70694121216"}
0005435373421	C10662	2852 908681	MIKHAIL TIKHONOV	{"phone": "+70714332138"}
0005435373422	C10662	3956 824266	PAVEL TIKHONOV	{"phone": "+70232748121"}
0005435373423	C5D434	9640 161077	GALINA SIDOROVA	{"email": "sidorova.galina_1981@postgrespro.ru", "phone": "+70133268247"}
0005435373424	C4A2AF	9039 491606	OLGA SEMENOVA	{"email": "o_semenova051966@postgrespro.ru", "phone": "+70899632477"}
0005435373425	C4A2AF	1926 195184	KONSTANTIN MAKAROV	{"email": "makarovkonstantin.1971@postgrespro.ru", "phone": "+70232757041"}
0005435373426	7E5F24	5339 347308	ANDREY SERGEEV	{"phone": "+70444890140"}
0005435373427	7AB7B4	2267 341125	DARYA FADEEVA	{"phone": "+70479327323"}
0005435373428	3ACD29	6285 697595	TATYANA OSIPOVA	{"phone": "+70939796932"}
0005435373429	3ACD29	1344 137559	ALEKSANDR KOZLOV	{"email": "a.kozlov_101965@postgrespro.ru", "phone": "+70154535998"}
0005435373430	249DF6	3156 551695	OLGA VOLKOVA	{"phone": "+70193454195"}
0005435373431	647D86	5328 010425	ANASTASIYA MARTYNOVA	{"phone": "+70347664891"}
0005435373432	046E31	1474 904177	NINA GERASIMOVA	{"email": "nina-gerasimova-101967@postgrespro.ru", "phone": "+70371831663"}
0005435373433	046E31	5081 257830	ALEKSEY MARTYNOV	{"email": "martynov_aleksey-011976@postgrespro.ru", "phone": "+70994758517"}
0005435373434	3C610C	1877 230484	YURIY KUDRYASHOV	{"email": "y_kudryashov_1979@postgrespro.ru", "phone": "+70088582055"}
0005435373435	2A8BA4	4598 736179	LYUBOV IVANOVA	{"email": "lyubov_ivanova1979@postgrespro.ru", "phone": "+70223488326"}
0005435373436	2A8BA4	7029 405700	MARIYA ZAKHAROVA	{"email": "m_zakharova.081977@postgrespro.ru", "phone": "+70216789134"}
0005435373437	52534A	0987 408621	OLEG NIKOLAEV	{"email": "nikolaevo-13111964@postgrespro.ru", "phone": "+70945691491"}
0005435373438	C38C62	0049 681606	GALINA AFANASEVA	{"phone": "+70978334913"}
0005435373439	AD7A39	2898 613779	VYACHESLAV PETROV	{"phone": "+70644275033"}
0005435373440	FABB8F	7563 507817	NIKOLAY VASILEV	{"email": "vasilev_n.101981@postgrespro.ru", "phone": "+70733817588"}
0005435373441	528F4D	0295 344080	NINA FROLOVA	{"email": "frolova_nina-12071965@postgrespro.ru", "phone": "+70444532263"}
0005435373442	F47E22	5882 412444	DENIS GERASIMOV	{"email": "d_gerasimov1970@postgrespro.ru", "phone": "+70659827259"}
0005435373443	F47E22	9294 290341	TIMUR CHERNOV	{"email": "chernov.timur_26111982@postgrespro.ru", "phone": "+70265032483"}
0005435373444	99F0EF	0356 749216	VALENTINA NOVIKOVA	{"email": "v_novikova-121972@postgrespro.ru", "phone": "+70253313269"}
0005435373445	C2D433	7261 038872	ALEKSANDR DENISOV	{"email": "denisov_aleksandr_061977@postgrespro.ru", "phone": "+70198847372"}
0005435373446	B0AA0D	0575 300956	ALEKSANDR VOLKOV	{"phone": "+70262248899"}
0005435373447	D3918F	6701 492396	YURIY VOLKOV	{"phone": "+70051777366"}
0005435373448	B17A37	1386 603294	NINA ROMANOVA	{"phone": "+70921353411"}
0005435373449	F3A30A	8116 990824	SERGEY SIDOROV	{"email": "sidorov-s_26081972@postgrespro.ru", "phone": "+70019056149"}
0005435373450	5FB7C5	6963 290964	PAVEL CHERNOV	{"phone": "+70888422514"}
0005435373451	9616F4	0679 066314	ANNA EGOROVA	{"phone": "+70276489780"}
0005435373452	551DE7	9202 971618	YULIYA OVCHINNIKOVA	{"email": "ovchinnikovay111966@postgrespro.ru", "phone": "+70064375762"}
0005435373453	551DE7	1625 480880	EVGENIY KUZNECOV	{"email": "kuznecovevgeniy_1971@postgrespro.ru", "phone": "+70039144512"}
0005435373454	673605	4596 898783	ALEKSANDR FEDOTOV	{"phone": "+70970595110"}
0005435373455	3851C1	5335 519980	VIKTOR NAUMOV	{"email": "naumov_v-08031961@postgrespro.ru", "phone": "+70572146760"}
0005435373456	BB015B	5579 374311	VYACHESLAV SERGEEV	{"email": "v_sergeev.1963@postgrespro.ru", "phone": "+70352093234"}
0005435373578	3832B0	4443 363497	NADEZHDA EFREMOVA	{"phone": "+70480786424"}
0005435373457	D65313	9794 378850	ANTON SEMENOV	{"email": "a_semenov_31101966@postgrespro.ru", "phone": "+70847424615"}
0005435373458	D65313	9505 822255	OLEG ANDREEV	{"phone": "+70266854459"}
0005435373459	D65313	6324 121790	LYUDMILA DMITRIEVA	{"phone": "+70353913693"}
0005435373460	D8419F	2811 158804	DMITRIY ILIN	{"email": "dmitriy.ilin.121965@postgrespro.ru", "phone": "+70445822958"}
0005435373461	D8419F	7733 470011	VASILIY NOVIKOV	{"email": "vnovikov-1977@postgrespro.ru", "phone": "+70381668962"}
0005435373462	D8419F	4669 658672	TATYANA MAKAROVA	{"phone": "+70374064159"}
0005435373463	1B28A3	2452 482087	EVGENIYA ZAKHAROVA	{"email": "zakharova-e_03011976@postgrespro.ru", "phone": "+70544032594"}
0005435373464	1B28A3	9264 159573	IRINA NIKITINA	{"phone": "+70100242632"}
0005435373465	20B617	1295 407849	TATYANA KUZNECOVA	{"email": "tatyana-kuznecova-041977@postgrespro.ru", "phone": "+70573805207"}
0005435373466	99F726	2923 499395	MARIYA ALEKSEEVA	{"email": "alekseeva.mariya_1976@postgrespro.ru", "phone": "+70827609966"}
0005435373467	99F726	0400 584416	VLADIMIR BORISOV	{"phone": "+70453351557"}
0005435373468	B4B372	2304 995913	OLGA FEDOROVA	{"email": "fedorovao021968@postgrespro.ru", "phone": "+70378561631"}
0005435373469	DA37CB	8084 557232	GALINA KOROLEVA	{"phone": "+70222688910"}
0005435373470	DA37CB	5391 263547	ANNA ROMANOVA	{"phone": "+70638367686"}
0005435373471	B0AA9D	3473 105067	ARINA DAVYDOVA	{"phone": "+70502474210"}
0005435373472	BEB1A6	8930 849821	ALEKSEY FEDOROV	{"phone": "+70049205788"}
0005435373473	62AB6D	5896 013561	YURIY NIKOLAEV	{"phone": "+70471051470"}
0005435373474	62AB6D	7279 695373	MARSEL CHERNOV	{"email": "marsel_chernov-051984@postgrespro.ru", "phone": "+70345179811"}
0005435373475	56B994	3985 809646	PETR KOROLEV	{"phone": "+70033569331"}
0005435373476	56B994	7064 165193	VLADIMIR MAKSIMOV	{"email": "maksimov.v1973@postgrespro.ru", "phone": "+70305468136"}
0005435373477	955B2B	0564 459772	ELENA TARASOVA	{"email": "e_tarasova.24081961@postgrespro.ru", "phone": "+70751822972"}
0005435373478	F6BF6D	3579 873006	VIKTORIYA SMIRNOVA	{"phone": "+70819892195"}
0005435373479	1DFC93	4772 308653	VITALIY MOROZOV	{"email": "morozov-vitaliy-101967@postgrespro.ru", "phone": "+70851814182"}
0005435373480	0665B3	5941 722980	VLADIMIR KOZLOV	{"phone": "+70735297162"}
0005435373481	0665B3	5769 422765	LYUDMILA FROLOVA	{"email": "l_frolova06121973@postgrespro.ru", "phone": "+70242674729"}
0005435373482	0665B3	3679 291201	NADEZHDA FEDOROVA	{"phone": "+70778076068"}
0005435373483	D051B2	7904 007981	VALENTINA SMIRNOVA	{"phone": "+70002132593"}
0005435373484	353B59	1560 515964	SOFYA STEPANOVA	{"phone": "+70789770594"}
0005435373485	7751E4	2632 123059	RAFAEL IVANOV	{"phone": "+70533996342"}
0005435373486	DBC0E4	2476 282831	PRASKOVYA SOLOVEVA	{"phone": "+70518265970"}
0005435373487	DBC0E4	6225 334139	ELIZAVETA ZOTOVA	{"email": "zotova.elizaveta.05041982@postgrespro.ru", "phone": "+70403251155"}
0005435373488	4D7AEC	9700 782897	SVETLANA KUZNECOVA	{"phone": "+70540083727"}
0005435373489	5FF675	6965 230935	KIRILL ZAYCEV	{"phone": "+70125701648"}
0005435373490	9B06AF	0233 594128	ARSENIY STEPANOV	{"email": "stepanov-a_22061973@postgrespro.ru", "phone": "+70418015668"}
0005435373491	7039A6	5075 784008	RAISA KISELEVA	{"phone": "+70250012926"}
0005435373492	7039A6	4130 373375	NIKITA DAVYDOV	{"phone": "+70739772166"}
0005435373493	DF58EB	6688 325719	VLADISLAV SCHERBAKOV	{"email": "vscherbakov_02121972@postgrespro.ru", "phone": "+70888472579"}
0005435373494	A26175	2543 575048	SERGEY SAVELEV	{"phone": "+70072101533"}
0005435373495	1393D0	0777 768984	IRAIDA NIKITINA	{"email": "inikitina1970@postgrespro.ru", "phone": "+70782532056"}
0005435373496	86016D	7853 929394	EVGENIY BORISOV	{"email": "borisov.e16111961@postgrespro.ru", "phone": "+70332579626"}
0005435373497	ED5F0E	7870 346126	PETR STEPANOV	{"phone": "+70695828619"}
0005435373498	ED5F0E	1897 450169	NIKOLAY VASILEV	{"phone": "+70193197746"}
0005435373499	E4993C	5833 764687	IGOR MOROZOV	{"email": "morozov_i_011977@postgrespro.ru", "phone": "+70621866891"}
0005435373500	485ED5	5378 152624	ROZA SAVELEVA	{"email": "roza-saveleva_021967@postgrespro.ru", "phone": "+70839068177"}
0005435373501	D0D8D6	7680 513377	OLGA NOVIKOVA	{"email": "novikova.olga_17011963@postgrespro.ru", "phone": "+70829440379"}
0005435373502	A8C2B8	1152 908378	SVETLANA MELNIKOVA	{"email": "s-melnikova1961@postgrespro.ru", "phone": "+70569022110"}
0005435373503	A8C2B8	8415 574780	IRINA KUZNECOVA	{"phone": "+70562224730"}
0005435373504	3164FC	8856 140571	PETR KRASNOV	{"email": "p_krasnov_1957@postgrespro.ru", "phone": "+70837434080"}
0005435373505	3CC581	1516 003137	OLGA FROLOVA	{"email": "o.frolova061970@postgrespro.ru", "phone": "+70627397041"}
0005435373506	9A445D	3038 604812	IRINA MELNIKOVA	{"phone": "+70715050427"}
0005435373563	0B88ED	9876 810583	YANA ISAEVA	{"phone": "+70898580657"}
0005435373507	9A445D	7369 151207	EVDOKIYA NOVIKOVA	{"email": "novikovae_1964@postgrespro.ru", "phone": "+70966372186"}
0005435373508	E0256B	0488 899640	DARYA MIKHAYLOVA	{"email": "mikhaylova.d.031977@postgrespro.ru", "phone": "+70482351501"}
0005435373509	E0256B	3499 638676	ANASTASIYA KUZMINA	{"phone": "+70903658262"}
0005435373510	1A8682	4126 418163	ZHANNA BORISOVA	{"phone": "+70076806630"}
0005435373511	1A8682	9284 938931	GALINA MIKHAYLOVA	{"phone": "+70532725963"}
0005435373512	70AE73	2734 186355	VLADISLAV SERGEEV	{"email": "sergeev_v15111975@postgrespro.ru", "phone": "+70112248134"}
0005435373513	6190B2	1822 392116	ALEVTINA SIDOROVA	{"phone": "+70745461082"}
0005435373514	9CBFEE	6197 145840	NADEZHDA TIMOFEEVA	{"phone": "+70327754152"}
0005435373515	1D6714	8856 562704	ANGELINA NAUMOVA	{"email": "angelina_naumova_19101974@postgrespro.ru", "phone": "+70059086376"}
0005435373516	9D9A75	3631 487275	MARIYA POPOVA	{"phone": "+70336201926"}
0005435373517	9D9A75	8486 234178	VALENTINA SEMENOVA	{"phone": "+70328971634"}
0005435373518	9D9A75	6362 266629	PAVEL BONDARENKO	{"email": "bondarenkop_051966@postgrespro.ru", "phone": "+70799157223"}
0005435373519	A9736C	9070 039535	VLADIMIR MEDVEDEV	{"email": "v-medvedev_021968@postgrespro.ru", "phone": "+70240251620"}
0005435373520	5C2D0D	1645 438866	SERGEY POPOV	{"email": "popov-s-091980@postgrespro.ru", "phone": "+70504780872"}
0005435373521	5C2D0D	3973 386793	ALEKSANDRA KISELEVA	{"phone": "+70475079832"}
0005435373522	5C2D0D	8776 326847	MARINA VOLKOVA	{"email": "m-volkova.081973@postgrespro.ru", "phone": "+70730590933"}
0005435373523	DD7DC1	7995 766810	NIKOLAY GERASIMOV	{"phone": "+70440409479"}
0005435373524	21C7F8	8243 797967	ANDREY FROLOV	{"email": "andreyfrolov_07111982@postgrespro.ru", "phone": "+70363171934"}
0005435373525	B58942	4900 947118	ALEKSANDR SAVELEV	{"email": "savelev.aleksandr.24121978@postgrespro.ru", "phone": "+70960834567"}
0005435373526	B58942	5489 860337	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva.27051966@postgrespro.ru", "phone": "+70032749210"}
0005435373527	3EEA97	0748 341392	ANATOLIY ZHURAVLEV	{"phone": "+70598842976"}
0005435373528	E6A6EF	1432 960700	GALINA ZHURAVLEVA	{"email": "galina_zhuravleva-20061967@postgrespro.ru", "phone": "+70720229409"}
0005435373529	62FCF8	7240 643101	IGOR SERGEEV	{"email": "igor-sergeev_091967@postgrespro.ru", "phone": "+70135235683"}
0005435373530	12275C	1337 092909	TATYANA BOGDANOVA	{"phone": "+70030820463"}
0005435373531	742AA8	7192 652009	MAKSIM DMITRIEV	{"phone": "+70089690336"}
0005435373532	742AA8	1543 557410	ANTON GRIGOREV	{"phone": "+70989628470"}
0005435373533	1F2E65	2864 091447	ANDREY GERASIMOV	{"email": "gerasimov.a.26031976@postgrespro.ru", "phone": "+70955901888"}
0005435373534	1F2E65	8945 907960	NATALYA YAKOVLEVA	{"email": "yakovleva-natalya_1969@postgrespro.ru", "phone": "+70160515911"}
0005435373535	DC2648	9682 203720	VYACHESLAV DAVYDOV	{"email": "vyacheslavdavydov.1963@postgrespro.ru", "phone": "+70912580133"}
0005435373536	DC2648	2965 047869	VITALIY GAVRILOV	{"phone": "+70153874757"}
0005435373537	42EF22	2687 345164	SVETLANA ILINA	{"phone": "+70631995932"}
0005435373538	EF6089	4565 191672	DMITRIY MELNIKOV	{"phone": "+70102664742"}
0005435373539	8240F1	9774 590698	OLGA SOROKINA	{"phone": "+70290131517"}
0005435373540	0D2801	9829 946882	NINA KOZLOVA	{"phone": "+70670903946"}
0005435373541	2E05E3	4753 620634	ARTEM KISELEV	{"email": "artem_kiselev-05051972@postgrespro.ru", "phone": "+70163482225"}
0005435373542	2E05E3	1220 010756	YURIY FEDOTOV	{"email": "y-fedotov.071978@postgrespro.ru", "phone": "+70777429124"}
0005435373543	0BEC24	2095 500316	MIKHAIL MIKHAYLOV	{"email": "mikhaylov-m-28111969@postgrespro.ru", "phone": "+70969136378"}
0005435373544	ADF1EE	6216 958234	MARGARITA KUZMINA	{"email": "mkuzmina1988@postgrespro.ru", "phone": "+70263096498"}
0005435373545	04EE0B	9544 177482	MARINA FILIPPOVA	{"phone": "+70175513032"}
0005435373546	04EE0B	4830 104673	DARYA MAKAROVA	{"phone": "+70846190029"}
0005435373547	C27CC7	9262 966239	OLGA ABRAMOVA	{"email": "olga.abramova.14071966@postgrespro.ru", "phone": "+70633310624"}
0005435373548	8B02D7	6816 585480	RUSLAN MIRONOV	{"email": "ruslan_mironov.101982@postgrespro.ru", "phone": "+70214723242"}
0005435373549	BE7867	4046 168792	VALENTIN KARPOV	{"email": "valentinkarpov-091981@postgrespro.ru", "phone": "+70247479481"}
0005435373550	5DEDF7	0710 162980	MARGARITA SOKOLOVA	{"phone": "+70483243943"}
0005435373551	4A8946	3230 113272	SERGEY KISELEV	{"email": "kiselev.s07051972@postgrespro.ru", "phone": "+70037878927"}
0005435373552	212559	4091 542465	KONSTANTIN FEDOROV	{"phone": "+70800524062"}
0005435373553	D5D9CE	4822 089777	VALENTINA KISELEVA	{"phone": "+70050866901"}
0005435373554	DAC615	5369 619166	NATALIYA SOROKINA	{"phone": "+70458733243"}
0005435373555	720FC9	6166 280223	ALEKSEY KARPOV	{"email": "karpov_aleksey_101972@postgrespro.ru", "phone": "+70881000512"}
0005435373556	720FC9	9331 396535	NIKOLAY EGOROV	{"email": "nikolay-egorov-051982@postgrespro.ru", "phone": "+70986011354"}
0005435373557	158617	9337 426292	ANTON ZAKHAROV	{"phone": "+70800474168"}
0005435373558	158617	4848 191164	ALEKSANDR KUZMIN	{"phone": "+70494988544"}
0005435373559	EBD7CE	4285 156146	GENNADIY ROMANOV	{"email": "romanov-g_081971@postgrespro.ru", "phone": "+70527431661"}
0005435373560	F81494	3000 929819	FARIT KRASNOV	{"phone": "+70248985657"}
0005435373561	F81494	9129 338561	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov101963@postgrespro.ru", "phone": "+70767145065"}
0005435373562	F81494	9159 613517	ANNA LAZAREVA	{"email": "alazareva_1967@postgrespro.ru", "phone": "+70742101967"}
0005435373564	50A462	3444 929339	DMITRIY KUZNECOV	{"email": "kuznecov-dmitriy-1970@postgrespro.ru", "phone": "+70624883852"}
0005435373565	0A6EDB	5115 128319	MARIYA LAZAREVA	{"phone": "+70920915480"}
0005435373566	BC3BF0	3032 206958	NATALYA ZAKHAROVA	{"email": "nzakharova.1975@postgrespro.ru", "phone": "+70249951050"}
0005435373567	F9715C	2558 867319	LIDIYA ZAYCEVA	{"email": "zayceval_051958@postgrespro.ru", "phone": "+70727682387"}
0005435373568	F9715C	5142 089279	NIKOLAY SIDOROV	{"phone": "+70789128433"}
0005435373569	EEAAC1	6468 601128	ALEKSEY ILIN	{"email": "a-ilin_06021978@postgrespro.ru", "phone": "+70021606856"}
0005435373570	EEAAC1	4849 535523	NINA NIKOLAEVA	{"phone": "+70014214310"}
0005435373571	51004B	3939 520725	ANNA BOGDANOVA	{"email": "bogdanova.anna.121965@postgrespro.ru", "phone": "+70614738317"}
0005435373572	2205E6	7315 577772	TATYANA BELOVA	{"email": "tatyana.belova_081969@postgrespro.ru", "phone": "+70305436789"}
0005435373573	7D38D3	4210 746490	TATYANA KUZNECOVA	{"phone": "+70355609264"}
0005435373574	37CA15	6128 768462	ALEKSANDR ZAKHAROV	{"phone": "+70762157186"}
0005435373575	37CA15	2485 207357	SERGEY BORISOV	{"email": "borisovs05031967@postgrespro.ru", "phone": "+70774304510"}
0005435373576	DFF587	1224 059838	ALEKSANDRA SERGEEVA	{"phone": "+70438770211"}
0005435373577	B76809	8023 033081	NIKOLAY TIMOFEEV	{"email": "timofeev-n_18121971@postgrespro.ru", "phone": "+70603271657"}
0005435373579	3832B0	5573 441268	MARINA MEDVEDEVA	{"phone": "+70729279153"}
0005435373580	776ABC	5723 457525	ANATOLIY ALEKSANDROV	{"email": "aleksandrov-anatoliy.27091963@postgrespro.ru", "phone": "+70504013716"}
0005435373581	61646E	5481 134467	DENIS ZAKHAROV	{"phone": "+70205299862"}
0005435373582	61646E	6826 624039	YAROSLAV ZHUKOV	{"email": "zhukovy_081980@postgrespro.ru", "phone": "+70164697645"}
0005435373583	BA4B54	7863 950744	TATYANA BELOVA	{"phone": "+70128217256"}
0005435373584	3E01AE	1488 631979	ELENA EFIMOVA	{"phone": "+70525608281"}
0005435373585	06C733	7850 928893	LYUBOV KUZNECOVA	{"phone": "+70940014654"}
0005435373586	C3FF32	4584 374895	SERGEY SOROKIN	{"email": "sorokinsergey091974@postgrespro.ru", "phone": "+70346084969"}
0005435373587	C3FF32	5275 870833	ALEKSEY MATVEEV	{"email": "matveevaleksey-07031969@postgrespro.ru", "phone": "+70910750644"}
0005435373588	F3D879	3533 296987	SERGEY IVANOV	{"email": "sergey.ivanov_11101969@postgrespro.ru", "phone": "+70372976099"}
0005435373589	F3D879	1215 296149	VASILIY MOISEEV	{"phone": "+70761813148"}
0005435373590	702CB7	2604 542393	NIKOLAY ANTONOV	{"email": "antonovn_1981@postgrespro.ru", "phone": "+70564131792"}
0005435373591	702CB7	4490 482560	VALENTINA NESTEROVA	{"email": "v_nesterova.051966@postgrespro.ru", "phone": "+70433345886"}
0005435373592	702CB7	4532 516887	PETR SOLOVEV	{"phone": "+70257205689"}
0005435373593	44BCD3	4015 058621	LIDIYA MAKAROVA	{"email": "makarovalidiya.1981@postgrespro.ru", "phone": "+70940286888"}
0005435373594	FBA20A	7355 161941	DMITRIY TIKHONOV	{"phone": "+70328326017"}
0005435373595	D427A5	7882 898149	ALEKSANDR MELNIKOV	{"email": "melnikov_a11011969@postgrespro.ru", "phone": "+70011314516"}
0005435373596	1923CC	5154 343045	ANDREY FOMIN	{"phone": "+70519229629"}
0005435373597	381B74	0148 130419	ALLA LOGINOVA	{"phone": "+70660311175"}
0005435373598	1E4F63	0374 596144	MARINA FILATOVA	{"email": "m-filatova071976@postgrespro.ru", "phone": "+70980170899"}
0005435373599	482C17	2941 104776	DANIIL FROLOV	{"phone": "+70071472513"}
0005435373600	94FFF1	3248 890080	MARINA FADEEVA	{"email": "marina-fadeeva-061957@postgrespro.ru", "phone": "+70530787566"}
0005435373601	6D6C6A	8351 538090	NATALYA FEDOROVA	{"email": "n_fedorova02011986@postgrespro.ru", "phone": "+70565416081"}
0005435373602	6D6C6A	6067 273036	VASILIY ZAYCEV	{"email": "vasiliyzaycev-1983@postgrespro.ru", "phone": "+70947959128"}
0005435373603	53083A	3980 724339	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr_101971@postgrespro.ru", "phone": "+70077779214"}
0005435373604	D427AB	3331 530313	EVGENIY ILIN	{"email": "e.ilin.29091976@postgrespro.ru", "phone": "+70812208622"}
0005435373605	D427AB	8666 004280	ALEKSANDR SHEVCHENKO	{"phone": "+70763833068"}
0005435373606	8529AD	9153 245661	OLGA LAZAREVA	{"phone": "+70705985273"}
0005435373607	CB59DD	3211 965500	LYUDMILA ZAYCEVA	{"phone": "+70133342839"}
0005435373608	CB59DD	4592 936945	OLEG ALEKSANDROV	{"email": "oleg_aleksandrov1969@postgrespro.ru", "phone": "+70071029399"}
0005435373609	5C61EC	0415 568137	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov-031963@postgrespro.ru", "phone": "+70982677627"}
0005435373610	80FB86	1741 802817	EVGENIY VOROBEV	{"email": "e.vorobev_08091979@postgrespro.ru", "phone": "+70699992626"}
0005435373611	304D41	6391 972673	NADEZHDA KISELEVA	{"phone": "+70934118838"}
0005435373612	43ACF8	4240 991667	EGOR PETROV	{"phone": "+70757118093"}
0005435373613	6C6B9D	3397 361807	TAMARA STEPANOVA	{"email": "stepanovatamara-1974@postgrespro.ru", "phone": "+70120985498"}
0005435373614	01C0CA	2749 663840	IVAN VASILEV	{"phone": "+70072936571"}
0005435373615	01C0CA	5757 742248	MARIYA TIKHONOVA	{"email": "m.tikhonova071966@postgrespro.ru", "phone": "+70530062907"}
0005435373616	CEDE4E	3520 539978	FANIYA DENISOVA	{"email": "denisova-faniya_1973@postgrespro.ru", "phone": "+70814590936"}
0005435373617	C8B977	2301 684189	ALEKSEY AFANASEV	{"email": "afanasev-a.10101973@postgrespro.ru", "phone": "+70102465657"}
0005435373618	AEA77B	3473 770531	PETR PETROV	{"email": "petrov-petr-1971@postgrespro.ru", "phone": "+70419623920"}
0005435373619	F3AA0A	9589 554241	YANA KUZMINA	{"email": "yana_kuzmina_1969@postgrespro.ru", "phone": "+70322056369"}
0005435373620	7A0B0C	6346 704862	YULIYA YAKOVLEVA	{"phone": "+70293522196"}
0005435373621	7A0B0C	2261 321886	OKSANA FOMINA	{"phone": "+70377900351"}
0005435373622	E1098E	1391 095483	GALINA BELOVA	{"phone": "+70083617476"}
0005435373623	15EA37	2794 132346	SERGEY GAVRILOV	{"email": "gavrilovs_14101982@postgrespro.ru", "phone": "+70426776293"}
0005435373624	90E769	3595 403928	NINA KOMAROVA	{"phone": "+70372834917"}
0005435373625	3526A1	4134 438791	ALEKSEY NOVIKOV	{"email": "novikov-a.041974@postgrespro.ru", "phone": "+70194408680"}
0005435373626	6FAD22	2171 492495	ANDREY MAKAROV	{"email": "makarov_andrey1972@postgrespro.ru", "phone": "+70088751228"}
0005435373627	B9E283	1967 909435	ARTEM RODIONOV	{"phone": "+70191173911"}
0005435373628	A33DB6	0951 617338	KONSTANTIN SOROKIN	{"email": "sorokinkonstantin.03121979@postgrespro.ru", "phone": "+70758577916"}
0005435373629	A33DB6	9204 032162	VLADIMIR ANDREEV	{"phone": "+70918888873"}
0005435373630	A87E5C	9442 157218	ALEKSANDR VASILEV	{"email": "vasilev-a.1972@postgrespro.ru", "phone": "+70538231486"}
0005435373631	3A8A5B	0946 729666	LIDIYA SMIRNOVA	{"email": "smirnoval-091970@postgrespro.ru", "phone": "+70941383874"}
0005435373632	790399	1326 253479	LYUBOV NAZAROVA	{"phone": "+70033845106"}
0005435373633	790399	8629 431955	ALEKSEY NOVIKOV	{"phone": "+70687982124"}
0005435373634	ED77B6	7283 161218	VALENTINA KALININA	{"email": "valentina_kalinina-02111979@postgrespro.ru", "phone": "+70351737090"}
0005435373635	ED77B6	4767 872960	EVGENIY SEMENOV	{"email": "semenov_evgeniy.021968@postgrespro.ru", "phone": "+70324255267"}
0005435373636	E88501	4207 602556	EVGENIY GAVRILOV	{"email": "evgeniy-gavrilov_031965@postgrespro.ru", "phone": "+70878960923"}
0005435373637	3E41DC	5347 356526	MIKHAIL BORISOV	{"email": "borisovmikhail_1966@postgrespro.ru", "phone": "+70249323629"}
0005435373638	8920C3	3268 454823	ALEKSANDR VOLKOV	{"phone": "+70393978524"}
0005435373639	6A636D	8939 488122	TATYANA SIDOROVA	{"email": "tatyana.sidorova-1965@postgrespro.ru", "phone": "+70666568651"}
0005435373640	2FC761	2192 454992	YURIY MIRONOV	{"phone": "+70952122570"}
0005435373641	9CDE9A	7947 027396	TATYANA EGOROVA	{"email": "egorova-t-051968@postgrespro.ru", "phone": "+70463697483"}
0005435373642	9CDE9A	3432 298200	MAKSIM MAKAROV	{"phone": "+70923420646"}
0005435373643	9CDE9A	7315 910464	VLADIMIR BELOV	{"phone": "+70603321145"}
0005435373644	E7F381	3289 258512	MAKSIM OSIPOV	{"email": "maksimosipov18071968@postgrespro.ru", "phone": "+70738109737"}
0005435373645	D65A68	1186 258895	EVGENIYA SOKOLOVA	{"email": "sokolovaevgeniya.06041969@postgrespro.ru", "phone": "+70507438414"}
0005435373646	0A8F74	0463 889308	OLGA ZHURAVLEVA	{"email": "olga.zhuravleva.061979@postgrespro.ru", "phone": "+70565858440"}
0005435373647	6A08B2	1826 092307	NADEZHDA MAKSIMOVA	{"email": "maksimovanadezhda1964@postgrespro.ru", "phone": "+70979539691"}
0005435373648	D370C6	0797 141239	NAZAR SOKOLOV	{"email": "sokolovnazar.1971@postgrespro.ru", "phone": "+70095604236"}
0005435373649	44A7F2	9193 839952	MARIYA IVANOVA	{"email": "mariya.ivanova-1974@postgrespro.ru", "phone": "+70655606903"}
0005435373650	4A7B27	6150 220221	ANTON SCHERBAKOV	{"phone": "+70142628257"}
0005435373651	CBFA03	9505 153333	NIKITA YAKOVLEV	{"email": "yakovlevnikita.061980@postgrespro.ru", "phone": "+70934245771"}
0005435373652	DB16F6	0268 283531	ZINAIDA PAVLOVA	{"email": "pavlova_z_1972@postgrespro.ru", "phone": "+70228120939"}
0005435373653	DB16F6	4495 209895	DMITRIY FEDOROV	{"phone": "+70551817542"}
0005435373654	C12C73	3493 843263	ANDREY ALEKSEEV	{"phone": "+70818203935"}
0005435373655	E69C0C	4872 138935	NINA EGOROVA	{"email": "n-egorova1972@postgrespro.ru", "phone": "+70967919083"}
0005435373656	E69C0C	9721 892463	VYACHESLAV NIKITIN	{"email": "v_nikitin.1958@postgrespro.ru", "phone": "+70937192873"}
0005435373657	8B464C	4274 999030	ARTEM FROLOV	{"phone": "+70512032298"}
0005435373658	8B3539	3031 952934	VIKTORIYA PETROVA	{"email": "vpetrova-1970@postgrespro.ru", "phone": "+70420584670"}
0005435373659	8B3539	4045 726430	ANNA RODIONOVA	{"phone": "+70047569728"}
0005435373660	52146D	6405 231521	ANNA KRASNOVA	{"email": "anna-krasnova17121970@postgrespro.ru", "phone": "+70316187584"}
0005435373661	D2DE5F	0526 942637	IRINA BELOVA	{"phone": "+70691542595"}
0005435373662	D2DE5F	8548 397544	VLADIMIR TARASOV	{"email": "vladimir_tarasov031974@postgrespro.ru", "phone": "+70160018160"}
0005435373663	A5A1E6	9048 412525	VITALIY NIKOLAEV	{"phone": "+70359332715"}
0005435373664	536724	5803 569769	GALINA NESTEROVA	{"email": "nesterovagalina-05081978@postgrespro.ru", "phone": "+70024652572"}
0005435373665	F79FE3	8823 971665	RAILYA MIKHAYLOVA	{"email": "mikhaylovar061968@postgrespro.ru", "phone": "+70228329917"}
0005435373666	97F6E5	9902 762801	SERGEY ZAYCEV	{"phone": "+70188818894"}
0005435373667	8EF187	0313 251751	NADEZHDA GERASIMOVA	{"email": "n-gerasimova051979@postgrespro.ru", "phone": "+70117451765"}
0005435373668	48195F	9831 297684	YULIYA MALYSHEVA	{"phone": "+70292078091"}
0005435373669	627009	3024 577041	VIKTOR VOROBEV	{"email": "vvorobev.071982@postgrespro.ru", "phone": "+70392436585"}
0005435373670	1F9DA8	2555 183360	VALENTINA VASILEVA	{"email": "vasilevavalentina.1976@postgrespro.ru", "phone": "+70865253062"}
0005435373671	00B2D0	5574 804610	VALERIYA GAVRILOVA	{"phone": "+70505136712"}
0005435373672	00B2D0	3661 147113	NIKOLAY MOISEEV	{"phone": "+70728194135"}
0005435373673	7AA0A1	6742 114099	EKATERINA LAZAREVA	{"phone": "+70008243992"}
0005435373674	7AA0A1	9212 818304	ALEKSEY OSIPOV	{"email": "osipov_aleksey_03101967@postgrespro.ru", "phone": "+70262147760"}
0005435373675	AA7A20	5908 874688	LEONID ORLOV	{"email": "l.orlov_1963@postgrespro.ru", "phone": "+70681853642"}
0005435373676	8BF383	5731 949108	ALEKSANDR NIKOLAEV	{"phone": "+70929181615"}
0005435373677	15C0D6	7052 923902	IGOR MAKAROV	{"phone": "+70258444237"}
0005435373678	15C0D6	3489 031729	LIDIYA SEMENOVA	{"email": "l_semenova.1969@postgrespro.ru", "phone": "+70026062708"}
0005435373679	0392BF	1179 864619	ARSENIY EGOROV	{"email": "a.egorov061972@postgrespro.ru", "phone": "+70007669721"}
0005435373680	0392BF	0897 124959	LYUDMILA MASLOVA	{"phone": "+70929036288"}
0005435373681	DC2F54	4687 309124	ANNA GORBUNOVA	{"phone": "+70511383038"}
0005435373682	DC2F54	2865 943858	DARYA GUSEVA	{"email": "guseva-d16111978@postgrespro.ru", "phone": "+70571965718"}
0005435373683	267589	9984 245626	ELENA NIKITINA	{"email": "e.nikitina_121960@postgrespro.ru", "phone": "+70907574478"}
0005435373684	3649FF	5816 173046	LYUDMILA VOROBEVA	{"phone": "+70881382406"}
0005435373685	FF97A1	6594 184354	BORIS RODIONOV	{"phone": "+70029310243"}
0005435373686	47A9F4	0920 288315	OLEG FILIPPOV	{"email": "filippov-o.11111974@postgrespro.ru", "phone": "+70877654484"}
0005435373687	47A9F4	1952 399455	VLADIMIR VOLKOV	{"phone": "+70620847426"}
0005435373688	47A9F4	6990 577060	TATYANA ALEKSEEVA	{"email": "tatyana_alekseeva.051972@postgrespro.ru", "phone": "+70962985523"}
0005435373689	63C822	4892 524899	SERGEY KUZNECOV	{"phone": "+70980318738"}
0005435373690	2BE7FC	9743 174893	ANATOLIY ALEKSEEV	{"phone": "+70057017370"}
0005435373691	4CF6D3	1763 998851	PAVEL VOLKOV	{"phone": "+70593172722"}
0005435373692	727701	9495 157078	VIKTOR POPOV	{"email": "popov_v-18121968@postgrespro.ru", "phone": "+70664930685"}
0005435373693	871265	5581 711000	VADIM ABRAMOV	{"email": "vadimabramov_06041974@postgrespro.ru", "phone": "+70990879233"}
0005435373694	85F5E7	8643 826805	IRINA BORISOVA	{"email": "i_borisova_06051967@postgrespro.ru", "phone": "+70806123845"}
0005435373695	2480A4	6847 212330	EKATERINA SOROKINA	{"phone": "+70654816582"}
0005435373696	1EE3D2	4422 204540	KARINA KULIKOVA	{"phone": "+70887962564"}
0005435373697	E84E3E	8307 390556	RITA ZAKHAROVA	{"phone": "+70422430500"}
0005435373698	1DEA82	0034 989071	ALEKSANDR SIDOROV	{"phone": "+70305676462"}
0005435373699	63B48B	2049 712706	VASILIY OSIPOV	{"email": "vosipov.011964@postgrespro.ru", "phone": "+70271648797"}
0005435373700	63B48B	5813 066985	ROZA SIDOROVA	{"phone": "+70355841392"}
0005435373701	263AFC	7179 712859	MARGARITA KOROLEVA	{"email": "koroleva_margarita.19031973@postgrespro.ru", "phone": "+70843027182"}
0005435373702	F066FA	8902 553150	VIKTOR ANDREEV	{"email": "viktorandreev091981@postgrespro.ru", "phone": "+70437189066"}
0005435373703	F8A822	5336 429302	ELENA ZHURAVLEVA	{"email": "zhuravlevae.051971@postgrespro.ru", "phone": "+70717647330"}
0005435373704	F8A822	1841 504640	ALEKSEY MELNIKOV	{"email": "alekseymelnikov_111971@postgrespro.ru", "phone": "+70611494139"}
0005435373705	96BAC8	8522 854817	TATYANA FADEEVA	{"email": "fadeevat_091967@postgrespro.ru", "phone": "+70326568424"}
0005435373706	86D936	8124 442319	IVAN BORISOV	{"email": "borisov_ivan-051991@postgrespro.ru", "phone": "+70250273888"}
0005435373707	E863C8	3271 820517	EVGENIY SMIRNOV	{"phone": "+70968536985"}
0005435373708	46E2CA	8889 292264	STEPAN KUZNECOV	{"phone": "+70495851878"}
0005435373709	FCA26B	0097 104642	ANDREY PETROV	{"email": "petrovandrey1970@postgrespro.ru", "phone": "+70390341922"}
0005435373710	87A308	2008 865693	ANDREY SHEVCHENKO	{"email": "shevchenko-a_1976@postgrespro.ru", "phone": "+70922472044"}
0005435373711	B88ABE	4016 560735	ANDREY MIRONOV	{"email": "mironovandrey-09091970@postgrespro.ru", "phone": "+70559738720"}
0005435373712	8A6155	5819 315357	MARIYA KUZMINA	{"phone": "+70567786994"}
0005435373713	5E55A1	5254 526302	GALINA KUZNECOVA	{"email": "kuznecovag_031979@postgrespro.ru", "phone": "+70153146899"}
0005435373714	AE65A0	4509 765266	IVAN BORISOV	{"phone": "+70448543423"}
0005435373715	AFD6E0	0036 124663	VALENTINA MIKHAYLOVA	{"email": "mikhaylova-v_21121970@postgrespro.ru", "phone": "+70770856857"}
0005435373716	0A7B69	6811 333765	EVGENIYA SOLOVEVA	{"email": "esoloveva.081959@postgrespro.ru", "phone": "+70478507709"}
0005435373717	D7E78B	3804 160596	VYACHESLAV DENISOV	{"phone": "+70870327479"}
0005435373718	3F062F	8584 416903	DARYA KONOVALOVA	{"email": "konovalova.d-081968@postgrespro.ru", "phone": "+70564894992"}
0005435373719	4C8EBB	5644 742037	OLGA ROMANOVA	{"email": "oromanova-051977@postgrespro.ru", "phone": "+70702605748"}
0005435373720	7F90C8	1452 363548	SVETLANA SERGEEVA	{"email": "s_sergeeva_051979@postgrespro.ru", "phone": "+70502597528"}
0005435373721	7F90C8	4179 700688	TATYANA GRISHINA	{"phone": "+70136977545"}
0005435373722	7F90C8	5247 188689	LYUDMILA POLYAKOVA	{"email": "polyakova.lyudmila_14071973@postgrespro.ru", "phone": "+70068720283"}
0005435373723	0C8FC5	9045 576005	ALEKSANDR ROMANOV	{"email": "romanov.a10061971@postgrespro.ru", "phone": "+70124802372"}
0005435373724	CB491B	8096 354958	YURIY BONDARENKO	{"email": "yuriy_bondarenko.21041978@postgrespro.ru", "phone": "+70526650867"}
0005435373725	71D26A	6530 308428	SVETLANA BOGDANOVA	{"phone": "+70898697727"}
0005435373726	BBE675	5914 383794	TAMARA ZOTOVA	{"phone": "+70262477110"}
0005435373727	BFF3B4	5405 743619	DARYA MASLOVA	{"phone": "+70988797899"}
0005435373728	BFF3B4	2161 681922	LYUDMILA KONDRATEVA	{"email": "kondrateva-l.051956@postgrespro.ru", "phone": "+70530273449"}
0005435373729	51BB3B	6464 764056	GENNADIY BORISOV	{"email": "gennadiy.borisov-22101979@postgrespro.ru", "phone": "+70882735496"}
0005435373730	51BB3B	6284 660060	ANNA SOKOLOVA	{"email": "sokolova_a-23071963@postgrespro.ru", "phone": "+70440540563"}
0005435373731	3378EE	1903 952501	LEONID YAKOVLEV	{"phone": "+70137362146"}
0005435373732	3378EE	9530 780507	LYUDMILA TARASOVA	{"email": "tarasova.l-09091980@postgrespro.ru", "phone": "+70721454616"}
0005435373733	D27C42	2032 914631	TIMUR ZHUKOV	{"phone": "+70489191213"}
0005435373734	590737	6974 638566	ZOYA MOROZOVA	{"phone": "+70852499814"}
0005435373735	E97C60	8777 631124	RAISA ANDREEVA	{"phone": "+70142511317"}
0005435373736	647ED3	6463 031870	ARTEM BARANOV	{"email": "artem-baranov1966@postgrespro.ru", "phone": "+70791621190"}
0005435373737	A91E55	0158 632170	ALEKSANDR PAVLOV	{"phone": "+70861417474"}
0005435373738	9A05FD	6114 112065	MIKHAIL MIKHAYLOV	{"email": "mikhailmikhaylov-1975@postgrespro.ru", "phone": "+70466650245"}
0005435373739	58FFA4	1204 974708	VIKTOR ORLOV	{"email": "orlov.v011979@postgrespro.ru", "phone": "+70193007397"}
0005435373740	58FFA4	1614 227555	ANDREY MOISEEV	{"phone": "+70321871104"}
0005435373741	7AC309	9178 462166	IGOR ANDREEV	{"email": "i.andreev-061972@postgrespro.ru", "phone": "+70164192929"}
0005435373742	7AC309	7700 405945	NIKOLAY SAVELEV	{"email": "n_savelev.10081972@postgrespro.ru", "phone": "+70353170784"}
0005435373743	5D0FCD	8134 293158	SERGEY DMITRIEV	{"phone": "+70379743283"}
0005435373744	5D0FCD	1304 009590	OLGA POPOVA	{"phone": "+70242674169"}
0005435373745	1A8E9D	3394 753106	ALLA VOLKOVA	{"phone": "+70880519870"}
0005435373746	1AEA9C	5252 479096	SVETLANA BOGDANOVA	{"phone": "+70291386939"}
0005435373747	B347C6	8551 900266	DMITRIY ZAYCEV	{"phone": "+70535500279"}
0005435373748	B347C6	8603 613713	NADEZHDA PETROVA	{"phone": "+70983435826"}
0005435373749	79807B	2741 786288	ALEKSANDR POPOV	{"phone": "+70381958455"}
0005435373750	79807B	1218 827098	NINA BOGDANOVA	{"phone": "+70152412738"}
0005435373751	9274D1	0989 055435	ALEKSEY PETROV	{"email": "petrov-aleksey_071992@postgrespro.ru", "phone": "+70447604302"}
0005435373752	C38166	0290 623911	LYUBOV ZAYCEVA	{"email": "zaycevalyubov-091977@postgrespro.ru", "phone": "+70456170764"}
0005435373753	D1C70D	9819 868234	VASILIY AFANASEV	{"email": "afanasevv.10061982@postgrespro.ru", "phone": "+70767071216"}
0005435373754	D1C70D	5843 053004	VIKTORIYA IVANOVA	{"phone": "+70026621928"}
0005435373755	B96FEB	0429 790717	TATYANA TARASOVA	{"email": "tarasova-tatyana.051977@postgrespro.ru", "phone": "+70903929397"}
0005435373756	B96FEB	3293 994874	SERGEY VOLKOV	{"phone": "+70559281509"}
0005435373757	00EF8A	3951 118354	SERGEY KARPOV	{"email": "karpov.sergey-18091969@postgrespro.ru", "phone": "+70082372792"}
0005435373758	7A294E	5914 946209	NATALYA MOROZOVA	{"phone": "+70225851568"}
0005435373759	7A294E	4534 221221	IRINA CHERNOVA	{"email": "i_chernova_091974@postgrespro.ru", "phone": "+70144581988"}
0005435373760	E04C39	3217 142614	EKATERINA KUZMINA	{"phone": "+70688638606"}
0005435373761	63C06D	5859 514049	IRINA MATVEEVA	{"email": "imatveeva1973@postgrespro.ru", "phone": "+70381705743"}
0005435373762	63C06D	6536 493494	VIKTOR FOMIN	{"phone": "+70021771885"}
0005435373763	3489D3	6836 444857	ALEKSEY KULIKOV	{"email": "kulikov_aleksey.011980@postgrespro.ru", "phone": "+70197472537"}
0005435373764	907291	0093 837449	ELENA YAKOVLEVA	{"email": "eyakovleva.25061969@postgrespro.ru", "phone": "+70653915298"}
0005435373765	907291	0333 690206	ANATOLIY MIKHAYLOV	{"phone": "+70290880633"}
0005435373766	6C6199	1004 855026	ANATOLIY KISELEV	{"email": "kiselev.a_1954@postgrespro.ru", "phone": "+70337498121"}
0005435373767	A3E217	3039 888036	ANDREY POPOV	{"email": "andreypopov-1962@postgrespro.ru", "phone": "+70291322140"}
0005435373768	F54DEF	2857 297667	YAKOV ALEKSEEV	{"email": "alekseev_y.1964@postgrespro.ru", "phone": "+70193696435"}
0005435373769	F54DEF	3772 714130	RAMIL GAVRILOV	{"phone": "+70413476200"}
0005435373770	F54DEF	7160 927443	ELENA ZAYCEVA	{"phone": "+70942891911"}
0005435373771	1E00EE	2119 002226	EVGENIY YAKOVLEV	{"phone": "+70912254373"}
0005435373772	1E00EE	5432 773639	ROZA EGOROVA	{"email": "egorovaroza-1963@postgrespro.ru", "phone": "+70534322913"}
0005435373773	36EE34	7352 345318	VLADIMIR SAVELEV	{"email": "savelev-vladimir_011971@postgrespro.ru", "phone": "+70924460042"}
0005435373774	96AD67	4104 256635	ALEKSEY IVANOV	{"email": "ivanov.aleksey121973@postgrespro.ru", "phone": "+70712319965"}
0005435373775	769D83	6600 010543	IVAN KOROLEV	{"email": "korolev-i101979@postgrespro.ru", "phone": "+70088966136"}
0005435373776	CE3EA9	3352 069295	IRINA NAZAROVA	{"phone": "+70837923743"}
0005435373777	CE3EA9	2269 671036	VERA LUKYANOVA	{"phone": "+70774464275"}
0005435373778	351075	6973 638300	LARISA KUZNECOVA	{"phone": "+70046253459"}
0005435373779	0C9F01	4424 634064	KONSTANTIN SOROKIN	{"phone": "+70570199156"}
0005435373780	0C9F01	7005 972008	NINA ERMAKOVA	{"phone": "+70867032928"}
0005435373781	D956DB	1503 283789	NATALYA SEMENOVA	{"phone": "+70114609813"}
0005435373782	D0FFB1	8253 394652	ELIZAVETA MIRONOVA	{"email": "mironova.elizaveta_121978@postgrespro.ru", "phone": "+70133046528"}
0005435373783	D0FFB1	9050 172053	TATYANA POTAPOVA	{"phone": "+70374729993"}
0005435373784	43E61D	9364 887430	OLEG FEDOROV	{"phone": "+70658741397"}
0005435373785	0ECD8C	8458 667410	DARYA GORBUNOVA	{"phone": "+70075519078"}
0005435373786	D69408	6955 520373	ARTEM AFANASEV	{"email": "afanasev.artem_1977@postgrespro.ru", "phone": "+70616235081"}
0005435373787	1030AE	7343 497253	IRINA BORISOVA	{"email": "borisova.irina-01121968@postgrespro.ru", "phone": "+70140988135"}
0005435373788	CC5341	8433 389588	TATYANA DANILOVA	{"email": "tdanilova.12101966@postgrespro.ru", "phone": "+70695757654"}
0005435373789	DB58FA	2671 097353	VYACHESLAV ISAEV	{"phone": "+70364376125"}
0005435373790	DB58FA	2274 224528	VIKTOR KONOVALOV	{"email": "konovalov-viktor_071976@postgrespro.ru", "phone": "+70759749619"}
0005435373791	97A05D	1809 475298	ANDREY KUZMIN	{"email": "akuzmin-041967@postgrespro.ru", "phone": "+70817914053"}
0005435373792	97A05D	7246 671747	TATYANA SMIRNOVA	{"phone": "+70447218945"}
0005435373793	4E9220	3394 156902	VLADISLAV OSIPOV	{"email": "osipov-vladislav.1971@postgrespro.ru", "phone": "+70177785273"}
0005435373794	4E9220	4053 414816	NATALYA BOGDANOVA	{"email": "bogdanova_n19031969@postgrespro.ru", "phone": "+70222282695"}
0005435373795	E2D012	4894 399222	ALEKSEY MOROZOV	{"phone": "+70059035929"}
0005435373796	7F7104	0331 361425	YURIY ABRAMOV	{"email": "abramov-yuriy15071981@postgrespro.ru", "phone": "+70187788749"}
0005435373797	C46C75	5190 877085	MARINA FILIPPOVA	{"email": "filippovamarina-051972@postgrespro.ru", "phone": "+70970520804"}
0005435373798	C46C75	5259 246859	IRINA KOLESNIKOVA	{"phone": "+70247137352"}
0005435373799	025E50	3569 213483	SERGEY MARTYNOV	{"email": "s_martynov10031969@postgrespro.ru", "phone": "+70750544300"}
0005435373800	CE1A7A	4475 134685	SERGEY SEMENOV	{"email": "semenovsergey-03051972@postgrespro.ru", "phone": "+70972804917"}
0005435373801	7D8A60	4361 540660	YULIYA VOROBEVA	{"email": "yuliyavorobeva_1957@postgrespro.ru", "phone": "+70181349564"}
0005435373802	7D8A60	3092 465025	VALENTINA ERMAKOVA	{"email": "vermakova-031974@postgrespro.ru", "phone": "+70016960888"}
0005435373803	FC9E8F	5531 150957	GALINA KAZAKOVA	{"email": "kazakovag.1969@postgrespro.ru", "phone": "+70717963010"}
0005435373804	2063F0	1362 533690	NADEZHDA MAKSIMOVA	{"phone": "+70224548434"}
0005435373805	2063F0	5158 422797	VYACHESLAV POPOV	{"email": "popovv.101964@postgrespro.ru", "phone": "+70006422923"}
0005435373806	C0EA8C	5602 014341	VALENTIN ZHURAVLEV	{"phone": "+70573027465"}
0005435373807	B90468	5760 393723	TATYANA POLYAKOVA	{"email": "tpolyakova071981@postgrespro.ru", "phone": "+70424812298"}
0005435373808	E72EA2	8923 534564	VYACHESLAV KUZNECOV	{"phone": "+70674209702"}
0005435373809	1AE93C	2736 418844	ANDREY ZHURAVLEV	{"email": "a.zhuravlev1975@postgrespro.ru", "phone": "+70355906157"}
0005435373810	1AE93C	7491 255659	VITALIY DENISOV	{"email": "denisov-v-10121964@postgrespro.ru", "phone": "+70450196048"}
0005435373811	DCFE0C	7792 970327	BORIS FOMIN	{"phone": "+70694553429"}
0005435373812	FED3B7	7754 596083	IGOR ILIN	{"phone": "+70951088655"}
0005435373813	292ACD	2405 414241	TATYANA MATVEEVA	{"email": "matveevatatyana.14111964@postgrespro.ru", "phone": "+70676719507"}
0005435373814	8CD69C	3074 827215	OLGA KUZNECOVA	{"email": "kuznecova-olga041968@postgrespro.ru", "phone": "+70101556208"}
0005435373815	F4FAF2	2673 987496	ALEKSANDRA SOROKINA	{"email": "aleksandrasorokina1957@postgrespro.ru", "phone": "+70749489296"}
0005435373816	83771C	4982 200588	STEPAN TIKHONOV	{"email": "tikhonov-stepan1975@postgrespro.ru", "phone": "+70891632109"}
0005435373817	FCE7AD	3292 041803	YURIY TIKHONOV	{"email": "tikhonovyuriy11041968@postgrespro.ru", "phone": "+70677407367"}
0005435373818	FCE7AD	9964 871768	VADIM TIMOFEEV	{"phone": "+70031170140"}
0005435373819	305ECF	4717 988145	TATYANA IVANOVA	{"phone": "+70647244606"}
0005435373820	7A25E3	3333 438473	EKATERINA FOMINA	{"phone": "+70531887913"}
0005435373821	7A25E3	6454 939050	VALENTIN ZAYCEV	{"phone": "+70941435376"}
0005435373822	7F4BDD	1964 606114	MARIYA OSIPOVA	{"email": "osipova-mariya081962@postgrespro.ru", "phone": "+70132366399"}
0005435373823	7F4BDD	4154 788441	ANTONINA KOMAROVA	{"email": "a_komarova02091972@postgrespro.ru", "phone": "+70874896076"}
0005435373824	DBE70D	6334 179774	ELENA KUZMINA	{"email": "e_kuzmina.121956@postgrespro.ru", "phone": "+70958157768"}
0005435373825	DBE70D	9245 906783	RAMIL VLASOV	{"email": "ramil-vlasov.05121964@postgrespro.ru", "phone": "+70304639181"}
0005435373826	8E13FC	9079 959688	OLGA BELYAEVA	{"email": "olgabelyaeva-1966@postgrespro.ru", "phone": "+70327985225"}
0005435373827	2FC5C5	3381 738205	ANDREY YAKOVLEV	{"email": "a_yakovlev_27031983@postgrespro.ru", "phone": "+70334930136"}
0005435373828	2FC5C5	2704 389119	EKATERINA KUZNECOVA	{"email": "e_kuznecova_14051990@postgrespro.ru", "phone": "+70974808510"}
0005435373829	2FC5C5	3641 542032	ZHANNA KONOVALOVA	{"phone": "+70802046101"}
0005435373830	0E16B8	6091 612154	MIKHAIL ZHUKOV	{"email": "zhukovmikhail-26121970@postgrespro.ru", "phone": "+70664657691"}
0005435373831	ADD2D9	4035 614414	ANATOLIY MIRONOV	{"phone": "+70549520371"}
0005435373832	ADD2D9	3500 472255	ALEKSANDR POPOV	{"phone": "+70365172262"}
0005435373833	759154	4424 613209	DENIS ISAEV	{"phone": "+70670910718"}
0005435373834	759154	5813 834617	ANDREY IVANOV	{"email": "andrey.ivanov.121978@postgrespro.ru", "phone": "+70829664551"}
0005435373835	89A882	6701 260297	VALENTINA KOZLOVA	{"phone": "+70691437928"}
0005435373836	89A882	8667 660144	OLEG IVANOV	{"email": "ivanovo-24041963@postgrespro.ru", "phone": "+70693786323"}
0005435373837	745326	2952 235009	SERGEY IVANOV	{"email": "s.ivanov29071973@postgrespro.ru", "phone": "+70739537441"}
0005435373838	745326	9677 260385	GALINA SOROKINA	{"email": "galina-sorokina-101970@postgrespro.ru", "phone": "+70393175880"}
0005435373839	C2C229	8642 347945	ALEKSANDRA VOLKOVA	{"email": "avolkova-02081980@postgrespro.ru", "phone": "+70419445672"}
0005435373840	62A7A2	7250 535703	GALINA MAKSIMOVA	{"phone": "+70616142982"}
0005435373841	A721A1	2342 972523	DARYA SMIRNOVA	{"email": "d-smirnova-11041968@postgrespro.ru", "phone": "+70795679598"}
0005435373842	D6CEB0	1969 292459	OKSANA MELNIKOVA	{"phone": "+70855904966"}
0005435373843	80158B	0546 759348	ANATOLIY EGOROV	{"email": "anatoliy.egorov121975@postgrespro.ru", "phone": "+70007424452"}
0005435373844	D05224	0260 750782	DMITRIY KOZLOV	{"email": "kozlovd18071964@postgrespro.ru", "phone": "+70379076978"}
0005435373845	586C5C	7315 768939	NIKOLAY IVANOV	{"phone": "+70716831590"}
0005435373846	93039C	0893 310494	NATALYA PAVLOVA	{"email": "n-pavlova-1969@postgrespro.ru", "phone": "+70436680252"}
0005435373847	74CAA8	8641 844108	TAISIYA ZHUKOVA	{"email": "zhukova-t101974@postgrespro.ru", "phone": "+70930257487"}
0005435373848	582822	2919 658459	VASILIY FEDOROV	{"email": "v-fedorov.02041970@postgrespro.ru", "phone": "+70567047634"}
0005435373849	582822	2609 052770	ANTON GRIGOREV	{"phone": "+70180937112"}
0005435373850	927C10	4540 965755	OLGA MARTYNOVA	{"phone": "+70345424221"}
0005435373851	652FEC	9981 795448	VYACHESLAV MAKAROV	{"phone": "+70647350215"}
0005435373852	652FEC	2580 801465	DENIS GORBUNOV	{"phone": "+70891925286"}
0005435373853	C3B4A1	5999 166189	VLADIMIR FROLOV	{"email": "v.frolov-011970@postgrespro.ru", "phone": "+70052541844"}
0005435373854	A2985F	1789 470265	MIKHAIL MEDVEDEV	{"phone": "+70626165294"}
0005435373855	E26D2B	4595 264777	VALENTINA KOLESNIKOVA	{"email": "v_kolesnikova-121960@postgrespro.ru", "phone": "+70753419233"}
0005435373856	6CC66B	3093 758973	IRINA PAVLOVA	{"email": "pavlova-i.08101970@postgrespro.ru", "phone": "+70616340227"}
0005435373857	6CC66B	8781 620737	ALEKSANDRA ALEKSEEVA	{"phone": "+70477242771"}
0005435373858	8F6E35	2225 321097	NIKOLAY ZAKHAROV	{"email": "nikolay_zakharov_111971@postgrespro.ru", "phone": "+70061050863"}
0005435373859	8F6E35	9695 173718	ANATOLIY ZHUKOV	{"email": "zhukov-anatoliy-101981@postgrespro.ru", "phone": "+70034906529"}
0005435373860	E32712	4470 338862	NATALYA FOMINA	{"phone": "+70118727984"}
0005435373861	E32712	1124 445046	GALINA SEMENOVA	{"email": "semenova_galina1976@postgrespro.ru", "phone": "+70812731598"}
0005435373862	A78BEE	8931 871413	YULIYA ZHURAVLEVA	{"email": "zhuravleva-y_101971@postgrespro.ru", "phone": "+70586896525"}
0005435373863	73335B	7797 655172	ALEKSEY SOROKIN	{"email": "sorokin.a.101975@postgrespro.ru", "phone": "+70545079717"}
0005435373864	73335B	5966 968015	ANATOLIY POPOV	{"phone": "+70079801055"}
0005435373865	5E5C84	7252 286241	ANTON TIMOFEEV	{"phone": "+70779075996"}
0005435373866	5E5C84	1147 048652	EVGENIYA TARASOVA	{"email": "etarasova.1981@postgrespro.ru", "phone": "+70986212513"}
0005435373867	C248C8	6971 020120	ALEKSANDR GRIGOREV	{"email": "grigorev-a-09021974@postgrespro.ru", "phone": "+70137815931"}
0005435373868	0A1A39	9452 294135	VIKTORIYA TIKHONOVA	{"phone": "+70333195930"}
0005435373869	0A1A39	3811 081789	LIDIYA KOROLEVA	{"email": "lidiya.koroleva1975@postgrespro.ru", "phone": "+70130052214"}
0005435373870	535499	8615 486636	VLADIMIR BARANOV	{"email": "vladimir.baranov.09121969@postgrespro.ru", "phone": "+70042542849"}
0005435373871	198A29	6071 079267	LYUDMILA SOKOLOVA	{"phone": "+70696803645"}
0005435373872	8309AF	9462 593911	EVGENIY ZAYCEV	{"email": "zaycev.e1984@postgrespro.ru", "phone": "+70944172587"}
0005435373873	0537E9	4139 271719	ROZA VASILEVA	{"email": "rvasileva-021975@postgrespro.ru", "phone": "+70663909114"}
0005435373874	5F935F	7785 821935	LEONID TIKHONOV	{"email": "leonid-tikhonov19081977@postgrespro.ru", "phone": "+70937296632"}
0005435373875	5343C6	7214 178870	OKSANA NOVIKOVA	{"phone": "+70293322730"}
0005435373876	590E40	3337 786858	KIRILL KOROLEV	{"email": "kirill_korolev-061979@postgrespro.ru", "phone": "+70886297180"}
0005435373877	6669CD	6911 909381	DANIIL CHERNOV	{"phone": "+70889561864"}
0005435373878	6669CD	7892 961342	ALBERT TARASOV	{"phone": "+70036177828"}
0005435373879	D32FD5	4271 891109	BORIS IVANOV	{"email": "ivanov-boris15041979@postgrespro.ru", "phone": "+70355505487"}
0005435373880	D32FD5	0868 801834	VALERIYA YUDINA	{"email": "yudina_valeriya-081978@postgrespro.ru", "phone": "+70416470827"}
0005435373881	FD7467	4879 213392	EGOR KUZNECOV	{"email": "egorkuznecov.14071963@postgrespro.ru", "phone": "+70784710115"}
0005435373882	C9580C	9818 672927	VASILIY FILIPPOV	{"phone": "+70586885369"}
0005435373883	C9580C	6697 441665	VERA EGOROVA	{"phone": "+70627888228"}
0005435373884	BB22DD	2143 517717	ALLA MAKSIMOVA	{"email": "alla.maksimova_27051972@postgrespro.ru", "phone": "+70744387890"}
0005435373885	5FA877	2416 033777	DAMIR KUZNECOV	{"email": "kuznecov-damir-1975@postgrespro.ru", "phone": "+70201237555"}
0005435373886	5FA877	0944 166978	OLGA MALYSHEVA	{"phone": "+70575866949"}
0005435373887	5FA877	6245 063253	SERGEY ROMANOV	{"phone": "+70126315779"}
0005435373888	ACDEAF	2746 880013	VIKTOR FILIPPOV	{"phone": "+70566787569"}
0005435373889	ACDEAF	7166 112100	NIKOLAY ZHURAVLEV	{"email": "nikolay_zhuravlev.071967@postgrespro.ru", "phone": "+70012330349"}
0005435373890	35C7CC	6018 908728	GALINA ORLOVA	{"phone": "+70043853724"}
0005435373891	DFE124	4601 773734	IRINA SEMENOVA	{"email": "semenovairina-19111977@postgrespro.ru", "phone": "+70645975701"}
0005435373892	7CCDF1	1732 396376	FEDOR ALEKSEEV	{"email": "alekseevfedor_1959@postgrespro.ru", "phone": "+70092876585"}
0005435373893	7CCDF1	2405 413321	ANGELINA MIKHAYLOVA	{"phone": "+70957192698"}
0005435373894	974F71	7231 604666	ANDREY GERASIMOV	{"email": "gerasimov.andrey031967@postgrespro.ru", "phone": "+70730809419"}
0005435373895	974F71	4211 181892	GULFIYA GORBUNOVA	{"phone": "+70037326059"}
0005435373896	C7903C	7435 854520	AMIR KOROLEV	{"email": "akorolev.061975@postgrespro.ru", "phone": "+70650038005"}
0005435373897	B625BB	2192 688146	ALENA BARANOVA	{"email": "a-baranova-1965@postgrespro.ru", "phone": "+70262506926"}
0005435373898	F93A0B	6598 054345	GALINA SEMENOVA	{"phone": "+70313822004"}
0005435373899	F93A0B	6052 821161	ANGELINA FILIPPOVA	{"phone": "+70613438120"}
0005435373900	DBC98B	7523 575137	KRISTINA IVANOVA	{"phone": "+70406078288"}
0005435373901	682D7F	7135 280831	ANTON BORISOV	{"email": "borisov_a-01031971@postgrespro.ru", "phone": "+70078254195"}
0005435373902	72FFEF	5141 739980	ANATOLIY TIKHONOV	{"phone": "+70080998757"}
0005435373903	8BCB1C	1373 011870	ANASTASIYA CHERNOVA	{"email": "chernova-a-041969@postgrespro.ru", "phone": "+70925398135"}
0005435373904	8BCB1C	3173 126233	PAVEL VOROBEV	{"phone": "+70026267003"}
0005435373905	212731	2169 691728	SERGEY ALEKSANDROV	{"phone": "+70674226430"}
0005435373906	D110CC	2905 297970	SERGEY CHERNOV	{"email": "sergeychernov_08121975@postgrespro.ru", "phone": "+70033802702"}
0005435373907	D110CC	9157 124266	SVETLANA TIKHONOVA	{"phone": "+70361961889"}
0005435373908	D3633E	6092 588338	TATYANA MOROZOVA	{"email": "morozova_t_23111971@postgrespro.ru", "phone": "+70104952868"}
0005435373909	B8C2B0	8987 455675	ALEKSEY FOMIN	{"phone": "+70057555609"}
0005435373910	B8C2B0	6209 319573	ULYANA NIKITINA	{"email": "unikitina.1973@postgrespro.ru", "phone": "+70575490050"}
0005435373911	B8C2B0	9036 368806	VLADIMIR KISELEV	{"phone": "+70184995808"}
0005435373912	D2F875	5365 744285	NATALYA KOROLEVA	{"email": "korolevanatalya_041962@postgrespro.ru", "phone": "+70370330044"}
0005435373913	D2F875	4573 285233	YURIY BORISOV	{"phone": "+70060680652"}
0005435373914	662D43	8905 665081	ALEKSANDR SIDOROV	{"email": "a.sidorov.15111979@postgrespro.ru", "phone": "+70632528407"}
0005435373915	EF41A8	7321 985384	SERGEY NAZAROV	{"email": "s-nazarov-25041970@postgrespro.ru", "phone": "+70733332805"}
0005435373916	EF41A8	8175 542107	NIKITA SCHERBAKOV	{"phone": "+70548359727"}
0005435373917	16DFC0	5392 232344	ELENA GRISHINA	{"email": "e-grishina-121971@postgrespro.ru", "phone": "+70560973856"}
0005435373918	5AC0D9	6937 889728	SERGEY PAVLOV	{"phone": "+70347418604"}
0005435373919	36ACBF	9660 733174	VLADIMIR YAKOVLEV	{"email": "vladimiryakovlev_01011975@postgrespro.ru", "phone": "+70508773910"}
0005435373920	0A5F15	3035 037022	ANATOLIY ANTONOV	{"email": "antonov_anatoliy07091972@postgrespro.ru", "phone": "+70500986998"}
0005435373921	6F8F4C	7494 564354	ANDREY ALEKSEEV	{"phone": "+70418959889"}
0005435373922	400CC9	7922 714324	LYUDMILA MIRONOVA	{"email": "lyudmila.mironova.011981@postgrespro.ru", "phone": "+70676470481"}
0005435373923	400CC9	8228 801762	MARIYA SOLOVEVA	{"email": "mariya_soloveva_1977@postgrespro.ru", "phone": "+70252403429"}
0005435373924	0D391D	6724 915812	SERGEY FEDOTOV	{"phone": "+70124919248"}
0005435373925	0D391D	9588 398275	ALEKSEY FROLOV	{"email": "frolov-aleksey-101968@postgrespro.ru", "phone": "+70048098384"}
0005435373926	D84B83	5481 201823	EKATERINA MALYSHEVA	{"phone": "+70561438766"}
0005435373927	4F6E05	5191 546146	OKSANA SOLOVEVA	{"email": "oksanasoloveva-1968@postgrespro.ru", "phone": "+70655619945"}
0005435373928	1370D9	0669 103641	VADIM ILIN	{"email": "vadim-ilin.03121972@postgrespro.ru", "phone": "+70094097095"}
0005435373929	1370D9	6710 365770	MIKHAIL ZHURAVLEV	{"phone": "+70069582089"}
0005435373930	6E3670	0943 869587	OKSANA IVANOVA	{"email": "oksana.ivanova1974@postgrespro.ru", "phone": "+70548872956"}
0005435373931	245B21	9648 526410	DMITRIY SOKOLOV	{"email": "dsokolov-1970@postgrespro.ru", "phone": "+70028284427"}
0005435373932	1D443B	1540 497610	LYUDMILA ZHUKOVA	{"email": "lzhukova_13031962@postgrespro.ru", "phone": "+70401095259"}
0005435373933	AAD073	4510 892277	MIKHAIL MIRONOV	{"phone": "+70297102258"}
0005435373934	01177C	6529 186657	OLGA ANTONOVA	{"phone": "+70689548477"}
0005435373935	E2B152	6145 906191	SERGEY KUDRYASHOV	{"phone": "+70505909037"}
0005435373936	E2B152	9305 405160	VLADIMIR VOLKOV	{"email": "volkov-v_051975@postgrespro.ru", "phone": "+70557034102"}
0005435373937	E23151	4029 122191	VALENTINA MELNIKOVA	{"phone": "+70123646251"}
0005435373938	4CB812	5699 264934	RAMIL MARTYNOV	{"email": "martynov.r1969@postgrespro.ru", "phone": "+70567666908"}
0005435373939	4CB812	0634 732443	ANDREY KUZNECOV	{"email": "kuznecov-a071972@postgrespro.ru", "phone": "+70361250127"}
0005435373940	C21537	5428 898954	ELENA MEDVEDEVA	{"email": "medvedeva-e.1969@postgrespro.ru", "phone": "+70204651090"}
0005435373941	C21537	3914 120990	VALENTINA ZHUKOVA	{"phone": "+70051329117"}
0005435373942	04CF5C	2145 223153	OLGA GAVRILOVA	{"email": "olga_gavrilova.061971@postgrespro.ru", "phone": "+70942941489"}
0005435373943	04CF5C	1434 379943	NADEZHDA KONOVALOVA	{"email": "konovalova_nadezhda.13081976@postgrespro.ru", "phone": "+70115499704"}
0005435373944	FB8B21	7669 665745	ALEKSANDRA OSIPOVA	{"phone": "+70452093654"}
0005435373945	FB8B21	6912 160567	IRINA DMITRIEVA	{"phone": "+70758114124"}
0005435373946	95645E	6312 116143	ANATOLIY SOKOLOV	{"phone": "+70421312822"}
0005435373947	95645E	3649 072378	SVETLANA BORISOVA	{"phone": "+70634848319"}
0005435373948	EDE5D1	1829 462153	ELIZAVETA KONDRATEVA	{"phone": "+70218668403"}
0005435373949	EDE5D1	7914 270367	OLESYA SERGEEVA	{"email": "olesya.sergeeva_29071972@postgrespro.ru", "phone": "+70635364950"}
0005435373950	1E36B5	3714 871263	ALEKSANDR RODIONOV	{"phone": "+70466752744"}
0005435373951	1E36B5	8076 803784	ANDREY NOVIKOV	{"phone": "+70650337512"}
0005435373952	1E36B5	2286 234633	DENIS VOLKOV	{"email": "volkovdenis_021987@postgrespro.ru", "phone": "+70332170964"}
0005435373953	F500D6	6051 043263	MARGARITA YAKOVLEVA	{"email": "yakovleva-margarita121973@postgrespro.ru", "phone": "+70324993919"}
0005435373954	F500D6	5046 512747	NIKOLAY ABRAMOV	{"phone": "+70908860393"}
0005435373955	F36BE1	9861 690486	KIRILL PETROV	{"phone": "+70176133351"}
0005435373956	C3486A	4141 180839	ANDREY NAZAROV	{"phone": "+70676715180"}
0005435373957	C3486A	9760 101795	IRINA FEDOROVA	{"email": "fedorovai-18071972@postgrespro.ru", "phone": "+70950163072"}
0005435373958	004A9F	3286 687234	SVETLANA MIKHAYLOVA	{"email": "s-mikhaylova041990@postgrespro.ru", "phone": "+70011547947"}
0005435373959	420770	1015 220778	ANATOLIY BARANOV	{"phone": "+70243475862"}
0005435373960	7F63C4	7302 854294	LYUBOV ARKHIPOVA	{"email": "l_arkhipova.081968@postgrespro.ru", "phone": "+70407714680"}
0005435373961	7F63C4	2687 254279	GALINA PAVLOVA	{"email": "galina_pavlova1974@postgrespro.ru", "phone": "+70645625649"}
0005435373962	CFE2DD	2360 848880	KSENIYA DMITRIEVA	{"phone": "+70115836555"}
0005435373963	CFE2DD	1536 035897	MARINA KUZNECOVA	{"phone": "+70865402349"}
0005435373964	CFE2DD	0839 155402	NIKOLAY FROLOV	{"phone": "+70439729197"}
0005435373965	4B6CF3	1781 929633	NIKOLAY ILIN	{"phone": "+70498857370"}
0005435373966	E5A8FD	1386 631791	OLEG RODIONOV	{"phone": "+70474961362"}
0005435373967	86FDB6	9912 488408	VLADIMIR MARTYNOV	{"email": "v-martynov081965@postgrespro.ru", "phone": "+70401931012"}
0005435373968	86FDB6	2827 744228	EVDOKIYA YUDINA	{"phone": "+70804728427"}
0005435373969	2DAD88	1027 220464	ANNA PAVLOVA	{"email": "anna.pavlova_06121961@postgrespro.ru", "phone": "+70205892913"}
0005435373970	2DAD88	4940 631231	IRINA ROMANOVA	{"phone": "+70157120658"}
0005435373971	3D3E77	5176 160524	ALEKSANDR KULIKOV	{"phone": "+70572498724"}
0005435373972	3DE1E6	7922 496274	ALEKSANDR FROLOV	{"email": "a_frolov1968@postgrespro.ru", "phone": "+70298772753"}
0005435373973	760799	1525 582365	NATALYA ROMANOVA	{"phone": "+70821828166"}
0005435373974	D01914	4684 338398	TATYANA GAVRILOVA	{"email": "t.gavrilova111973@postgrespro.ru", "phone": "+70687237463"}
0005435373975	FDD03D	5809 839907	GEORGIY ZHURAVLEV	{"email": "zhuravlev.georgiy04121977@postgrespro.ru", "phone": "+70468825534"}
0005435373976	6AE817	6025 182739	VERA VASILEVA	{"phone": "+70719825477"}
0005435373977	6AE817	3530 795215	SERGEY FOMIN	{"phone": "+70078063129"}
0005435373978	6AE817	7615 316597	MATVEY ORLOV	{"phone": "+70443341515"}
0005435373979	0A0D66	3053 867952	EVGENIY ZHURAVLEV	{"email": "ezhuravlev.1961@postgrespro.ru", "phone": "+70541338850"}
0005435373980	205428	6729 049534	ALEKSANDR NIKITIN	{"email": "a-nikitin.03101980@postgrespro.ru", "phone": "+70956882746"}
0005435373981	6717DC	7049 494052	MAKSIM ZAKHAROV	{"email": "maksimzakharov.1960@postgrespro.ru", "phone": "+70086554568"}
0005435373982	1F25C1	1214 523906	VLADIMIR KARPOV	{"email": "karpov_v_1971@postgrespro.ru", "phone": "+70384412279"}
0005435373983	634107	9846 535057	ANDREY ILIN	{"phone": "+70836679003"}
0005435373984	D452B4	6044 365532	DENIS CHERNOV	{"email": "chernov-d.021965@postgrespro.ru", "phone": "+70664161014"}
0005435373985	6432B1	4610 950074	VERA DAVYDOVA	{"email": "davydova-vera121971@postgrespro.ru", "phone": "+70959223431"}
0005435373986	FBC0F1	0137 493172	YURIY KONOVALOV	{"email": "konovalovy.08101973@postgrespro.ru", "phone": "+70861410490"}
0005435373987	C3C6E6	2311 458397	DMITRIY NAZAROV	{"email": "nazarov.d-1963@postgrespro.ru", "phone": "+70284024414"}
0005435373988	62A2C3	4962 326464	KIRILL GAVRILOV	{"email": "gavrilov.k_1971@postgrespro.ru", "phone": "+70180031093"}
0005435373989	B6130C	4400 338823	ALEKSANDR IVANOV	{"email": "aleksandrivanov-15111976@postgrespro.ru", "phone": "+70162112354"}
0005435373990	466CED	5520 611215	SVETLANA KOROLEVA	{"email": "koroleva_svetlana_031971@postgrespro.ru", "phone": "+70110952461"}
0005435373991	466CED	7853 712911	MARINA CHERNOVA	{"email": "chernova.marina-051980@postgrespro.ru", "phone": "+70274849372"}
0005435373992	F41B7D	4862 291920	NADEZHDA GUSEVA	{"phone": "+70735508195"}
0005435373993	BC963F	2130 561193	NADEZHDA MAKAROVA	{"phone": "+70987216106"}
0005435373994	BC963F	1935 794954	NIKOLAY MAKAROV	{"phone": "+70118600022"}
0005435373995	00625D	5802 602452	ROMAN SMIRNOV	{"email": "smirnov.roman25011975@postgrespro.ru", "phone": "+70273423038"}
0005435373996	90B500	7898 920533	ELENA DENISOVA	{"phone": "+70296863987"}
0005435373997	166797	6220 030444	ILDAR NAZAROV	{"email": "nazarovi.031976@postgrespro.ru", "phone": "+70126485334"}
0005435373998	166797	6083 865820	SEMEN KUZNECOV	{"phone": "+70768410269"}
0005435373999	4FF608	1782 835865	TATYANA EFIMOVA	{"email": "tatyanaefimova.091980@postgrespro.ru", "phone": "+70297177464"}
0005435374000	74CADB	9252 191134	NIKOLAY SOLOVEV	{"email": "nsolovev_071970@postgrespro.ru", "phone": "+70658541270"}
0005435374001	74CADB	8591 995503	TAMARA SOLOVEVA	{"email": "solovevat.121970@postgrespro.ru", "phone": "+70030374777"}
0005435374002	A9DB82	3859 604932	ALIYA DENISOVA	{"email": "aliya-denisova.1975@postgrespro.ru", "phone": "+70649591393"}
0005435374003	8FC3CE	3173 568971	LIDIYA MEDVEDEVA	{"email": "lidiya.medvedeva.1967@postgrespro.ru", "phone": "+70703457125"}
0005435374004	8FC3CE	4662 789637	ANDREY SOROKIN	{"email": "andrey.sorokin_1974@postgrespro.ru", "phone": "+70402312465"}
0005435374005	9634E9	1546 683696	ALENA NIKOLAEVA	{"phone": "+70368604390"}
0005435374006	64424A	1877 213711	OLGA FROLOVA	{"email": "olga-frolova_28051974@postgrespro.ru", "phone": "+70349550805"}
0005435374007	0F5778	2266 203473	ELENA FROLOVA	{"phone": "+70115533303"}
0005435374008	E2AAC7	5096 428868	TATYANA ROMANOVA	{"phone": "+70700948037"}
0005435374009	B7AC6C	4723 682973	ILMIR KULIKOV	{"email": "kulikovi1968@postgrespro.ru", "phone": "+70277776719"}
0005435374010	406270	9961 863670	ANNA SEMENOVA	{"email": "semenovaanna_1968@postgrespro.ru", "phone": "+70610822854"}
0005435374011	25687A	4398 397255	VASILIY BORISOV	{"phone": "+70925500837"}
0005435374012	9B9D4D	5264 830223	DANILA NIKOLAEV	{"phone": "+70789001808"}
0005435374013	C7EDAD	8721 747371	OLEG KRASNOV	{"phone": "+70570106109"}
0005435374014	C7EDAD	1873 960970	YURIY FROLOV	{"email": "yuriyfrolov1980@postgrespro.ru", "phone": "+70524075036"}
0005435374015	C7EDAD	4337 691586	VYACHESLAV IVANOV	{"phone": "+70196319256"}
0005435374016	573B93	5535 369186	YULIYA KALININA	{"phone": "+70960157110"}
0005435374017	1902D4	9641 159846	VYACHESLAV SAVELEV	{"email": "savelev.vyacheslav03101977@postgrespro.ru", "phone": "+70991742957"}
0005435374018	C584DD	3755 507980	NINEL KAZAKOVA	{"email": "kazakova.n-1975@postgrespro.ru", "phone": "+70490329177"}
0005435374019	76AC84	4932 089043	GALINA STEPANOVA	{"email": "gstepanova051980@postgrespro.ru", "phone": "+70232311574"}
0005435374020	C93A23	4166 636984	PAVEL MOROZOV	{"phone": "+70530248400"}
0005435374021	A425B5	6974 448585	KONSTANTIN MELNIKOV	{"phone": "+70218027103"}
0005435374022	B0B6F4	3998 790565	ALEKSEY SOKOLOV	{"email": "sokolova_1976@postgrespro.ru", "phone": "+70596191877"}
0005435374023	02D5F6	8284 319429	VLADIMIR MOROZOV	{"email": "morozovv_121973@postgrespro.ru", "phone": "+70743967086"}
0005435374024	DC178E	0986 885120	VIKTOR CHERNOV	{"email": "chernov-v-031976@postgrespro.ru", "phone": "+70481156094"}
0005435374025	DC178E	6913 448242	ALEKSANDR MAKSIMOV	{"email": "maksimov.a_24021982@postgrespro.ru", "phone": "+70617254053"}
0005435374026	46B7FB	9274 746868	ALEKSANDR SOLOVEV	{"phone": "+70840865033"}
0005435374027	46B7FB	4437 334183	VLADIMIR MELNIKOV	{"phone": "+70036807753"}
0005435374028	3B9406	8205 221448	GENNADIY GAVRILOV	{"email": "gavrilov_g21061971@postgrespro.ru", "phone": "+70487956433"}
0005435374029	1FA4F8	4848 083925	ALEKSANDR FILIPPOV	{"phone": "+70553823803"}
0005435374030	1FA4F8	7761 736570	KLAVDIYA MELNIKOVA	{"phone": "+70488749923"}
0005435374031	1FA4F8	3281 033891	ALEKSANDR ROMANOV	{"phone": "+70318544444"}
0005435374032	55F01E	6865 603553	TAISIYA MOROZOVA	{"phone": "+70482337872"}
0005435374033	62738F	0119 924259	TAMARA GORBUNOVA	{"email": "tamara_gorbunova_25021966@postgrespro.ru", "phone": "+70988381311"}
0005435374034	D0CA1F	0763 624597	ELENA SOROKINA	{"email": "esorokina.031964@postgrespro.ru", "phone": "+70396528057"}
0005435374035	D0CA1F	4046 367988	YURIY SERGEEV	{"email": "y.sergeev1969@postgrespro.ru", "phone": "+70354685447"}
0005435374036	96E70B	8006 930959	ALEVTINA NAUMOVA	{"email": "naumova_a_071975@postgrespro.ru", "phone": "+70854596724"}
0005435374037	CC48D9	2925 960206	VIKTORIYA POPOVA	{"phone": "+70566086896"}
0005435374038	CC48D9	9675 380953	ANZHELIKA PETROVA	{"phone": "+70233052720"}
0005435374039	CC48D9	8808 053654	ANNA AFANASEVA	{"email": "aafanaseva-061977@postgrespro.ru", "phone": "+70702797883"}
0005435374040	7C8AD1	2590 936172	ALEKSEY ZHURAVLEV	{"phone": "+70936921077"}
0005435374041	F58A5F	7318 295065	LILIYA SIDOROVA	{"email": "liliya_sidorova.26121960@postgrespro.ru", "phone": "+70205524176"}
0005435374042	E471EF	5886 012184	OLGA ABRAMOVA	{"phone": "+70075543593"}
0005435374043	F09CB2	4634 836911	OLGA FROLOVA	{"email": "frolovaolga.14011958@postgrespro.ru", "phone": "+70544240329"}
0005435374044	00C738	1240 403001	SERGEY KUZNECOV	{"email": "kuznecov-sergey_031979@postgrespro.ru", "phone": "+70269998293"}
0005435374045	38C552	0843 867748	TIMOFEY BORISOV	{"phone": "+70405893085"}
0005435374046	38C552	7230 769687	ANASTASIYA ZAKHAROVA	{"phone": "+70144969137"}
0005435374047	8E341E	9141 616270	NATALYA KRASNOVA	{"phone": "+70192226418"}
0005435374048	0AF3FB	9628 798339	VERONIKA KONOVALOVA	{"phone": "+70714822124"}
0005435374049	0AF3FB	2713 294044	NIKOLAY KOZLOV	{"email": "n_kozlov.071979@postgrespro.ru", "phone": "+70577929860"}
0005435374050	0AF3FB	0891 249193	ALEKSANDR SEMENOV	{"email": "semenovaleksandr-29101955@postgrespro.ru", "phone": "+70193492939"}
0005435374051	C54768	2566 177857	TATYANA DMITRIEVA	{"email": "tatyana_dmitrieva_06101973@postgrespro.ru", "phone": "+70905651629"}
0005435374052	C54768	7372 733214	MIKHAIL TARASOV	{"phone": "+70646321550"}
0005435374053	817100	3274 899782	DMITRIY FILIPPOV	{"phone": "+70437381656"}
0005435374054	B8CEED	3897 343763	VLADIMIR IVANOV	{"phone": "+70605499743"}
0005435374055	2B6CEA	1231 797883	VADIM IVANOV	{"phone": "+70600061763"}
0005435374115	E13A4C	0802 790060	VALENTINA SOKOLOVA	{"phone": "+70080622854"}
0005435374056	9FB393	7553 839617	ANNA PAVLOVA	{"email": "a-pavlova.021973@postgrespro.ru", "phone": "+70198578349"}
0005435374057	9FB393	3323 709020	VALENTIN ZHUKOV	{"phone": "+70846009673"}
0005435374058	06B65E	5282 039433	IVAN ZHUKOV	{"phone": "+70586113791"}
0005435374059	06B65E	7361 252324	KONSTANTIN KARPOV	{"email": "karpov-konstantin.031967@postgrespro.ru", "phone": "+70750508758"}
0005435374060	06B65E	3639 592689	VALENTINA KUZNECOVA	{"phone": "+70484716050"}
0005435374061	42AC9F	1381 119016	GALINA KULIKOVA	{"phone": "+70866947609"}
0005435374062	F4530C	8503 833154	VLADIMIR ZAKHAROV	{"email": "vladimir.zakharov-17081960@postgrespro.ru", "phone": "+70172335808"}
0005435374063	F4530C	5376 355669	MARIYA MOISEEVA	{"phone": "+70231086616"}
0005435374064	F4530C	9937 601436	DIANA KARPOVA	{"phone": "+70769287953"}
0005435374065	DE8929	1032 866036	DMITRIY SOLOVEV	{"email": "solovev-d26031969@postgrespro.ru", "phone": "+70715240700"}
0005435374066	CAA4C4	9114 928635	ALEKSANDR SHEVCHENKO	{"phone": "+70992077245"}
0005435374067	5BD2DF	6880 586625	TATYANA IVANOVA	{"email": "ivanova-t-07051965@postgrespro.ru", "phone": "+70060062717"}
0005435374068	C77C94	8206 214717	LIDIYA ALEKSEEVA	{"email": "alekseeva_lidiya_26021978@postgrespro.ru", "phone": "+70303158135"}
0005435374069	720F65	0292 898396	NATALYA MIRONOVA	{"email": "natalya.mironova.121972@postgrespro.ru", "phone": "+70691364682"}
0005435374070	720F65	8249 095408	SERGEY NIKITIN	{"email": "nikitin_sergey_1983@postgrespro.ru", "phone": "+70856796621"}
0005435374071	BAAF66	8875 066686	VLADIMIR NIKOLAEV	{"email": "nikolaev.vladimir-1967@postgrespro.ru", "phone": "+70034598617"}
0005435374072	0ED5F3	1828 757381	TATYANA ANTONOVA	{"phone": "+70937862277"}
0005435374073	B0006F	4694 248929	SERGEY MOROZOV	{"phone": "+70494208823"}
0005435374074	B34FEA	3157 405160	PAVEL POPOV	{"email": "p_popov-121975@postgrespro.ru", "phone": "+70394685468"}
0005435374075	B34FEA	5960 271372	ALEKSEY VOLKOV	{"phone": "+70562816621"}
0005435374076	B34FEA	3982 795399	TATYANA FADEEVA	{"phone": "+70394263310"}
0005435374077	B34FEA	5993 160906	OLGA NESTEROVA	{"email": "nesterova-o-041978@postgrespro.ru", "phone": "+70684674864"}
0005435374078	535A88	2064 663441	TATYANA RODIONOVA	{"phone": "+70589745699"}
0005435374079	EDEB6B	2413 865212	ELENA KAZAKOVA	{"email": "ekazakova14081978@postgrespro.ru", "phone": "+70680266971"}
0005435374080	A03C6E	6893 202452	OKSANA POTAPOVA	{"email": "potapova-oksana.23081972@postgrespro.ru", "phone": "+70787443944"}
0005435374081	FC79E5	7316 169879	GENNADIY MOROZOV	{"email": "gennadiy_morozov.1981@postgrespro.ru", "phone": "+70929012173"}
0005435374082	FC79E5	0767 659500	IVAN FILIPPOV	{"email": "filippov_ivan_1969@postgrespro.ru", "phone": "+70972074384"}
0005435374083	780381	6665 955850	PETR SEMENOV	{"phone": "+70220769843"}
0005435374084	780381	8146 570647	IRINA FROLOVA	{"phone": "+70716859618"}
0005435374085	C23083	5082 539780	VALENTINA TITOVA	{"phone": "+70799174495"}
0005435374086	3C7B2D	2390 029780	SERGEY GORBUNOV	{"phone": "+70784871482"}
0005435374087	AD21A6	4375 376987	VALERIY MAKAROV	{"phone": "+70271845045"}
0005435374088	AD21A6	5161 890444	MARIYA IVANOVA	{"email": "m-ivanova-08081964@postgrespro.ru", "phone": "+70330830982"}
0005435374089	2DFFE8	1094 431347	LYUBOV MOROZOVA	{"email": "lmorozova-041965@postgrespro.ru", "phone": "+70569503622"}
0005435374090	2DFFE8	8388 518121	SVETLANA SMIRNOVA	{"email": "s-smirnova.07101965@postgrespro.ru", "phone": "+70000373313"}
0005435374091	8E7396	3083 919362	VLADIMIR PETROV	{"email": "vladimirpetrov05091968@postgrespro.ru", "phone": "+70698978154"}
0005435374092	28A0BD	5701 474992	VLADIMIR SCHERBAKOV	{"email": "scherbakovv021977@postgrespro.ru", "phone": "+70545929110"}
0005435374093	E20E86	3497 400471	GALINA ILINA	{"email": "galina_ilina_13101960@postgrespro.ru", "phone": "+70093361352"}
0005435374094	E7199E	7040 274320	LEONID ZHUKOV	{"email": "zhukov_l.1968@postgrespro.ru", "phone": "+70706349573"}
0005435374095	BA6F83	6426 017961	LARISA MATVEEVA	{"email": "lmatveeva1973@postgrespro.ru", "phone": "+70663189351"}
0005435374096	BA6F83	9709 090732	LYUDMILA FOMINA	{"phone": "+70382553752"}
0005435374097	BA6F83	8147 236181	EVGENIYA NAUMOVA	{"email": "naumovae-10071970@postgrespro.ru", "phone": "+70012016860"}
0005435374098	760B2A	5805 675748	VALENTINA ABRAMOVA	{"email": "vabramova_1966@postgrespro.ru", "phone": "+70406630738"}
0005435374099	D463BD	7229 788585	IRINA MIRONOVA	{"email": "i.mironova.071980@postgrespro.ru", "phone": "+70364783874"}
0005435374100	1D98CC	1074 644171	MAKSIM YAKOVLEV	{"phone": "+70429382687"}
0005435374101	1D98CC	5800 869146	IGOR ZHUKOV	{"phone": "+70718411013"}
0005435374102	D32B20	5538 946177	VLADIMIR MARTYNOV	{"email": "martynov-vladimir-25011975@postgrespro.ru", "phone": "+70584170378"}
0005435374103	7BB4FD	5113 864691	ANNA KULIKOVA	{"email": "anna-kulikova-16081969@postgrespro.ru", "phone": "+70127070863"}
0005435374104	1A14E6	4781 245477	MAKSIM SCHERBAKOV	{"email": "scherbakov.maksim.18041978@postgrespro.ru", "phone": "+70699417514"}
0005435374105	B4C8AC	1170 787952	MIKHAIL OSIPOV	{"phone": "+70275786157"}
0005435374106	EB28F0	8885 137147	ELLA ALEKSEEVA	{"email": "ealekseeva1977@postgrespro.ru", "phone": "+70463942452"}
0005435374107	C4C0C9	0874 598376	GULSINA FEDOROVA	{"email": "gulsinafedorova-07071965@postgrespro.ru", "phone": "+70188811475"}
0005435374108	C4C0C9	7285 028416	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-a.1980@postgrespro.ru", "phone": "+70278640137"}
0005435374109	CAB572	3913 467431	IVAN SIDOROV	{"phone": "+70376184815"}
0005435374110	13E969	3709 675760	VIKTOR VOROBEV	{"email": "vorobev.v_03071973@postgrespro.ru", "phone": "+70798529517"}
0005435374111	13E969	2922 898226	ILDUS MAKAROV	{"phone": "+70387579673"}
0005435374112	98AFB9	8547 186280	VLADIMIR SCHERBAKOV	{"phone": "+70339817211"}
0005435374113	BAF9B3	2131 254354	EKATERINA BORISOVA	{"email": "e.borisova-061970@postgrespro.ru", "phone": "+70004607318"}
0005435374114	BAF9B3	4128 213599	SVETLANA NIKITINA	{"phone": "+70155487561"}
0005435374116	E13A4C	7873 979338	SVETLANA KUZNECOVA	{"email": "kuznecova_svetlana-011970@postgrespro.ru", "phone": "+70458771064"}
0005435374117	92524E	9944 973845	NINA TITOVA	{"email": "titova_nina_121964@postgrespro.ru", "phone": "+70162371215"}
0005435374118	92524E	8189 488101	OLGA VOLKOVA	{"email": "volkova-o17061962@postgrespro.ru", "phone": "+70009931507"}
0005435374119	E0DD66	6825 869159	VLADIMIR ZAKHAROV	{"phone": "+70801906728"}
0005435374120	E0DD66	2798 875991	MIKHAIL MELNIKOV	{"phone": "+70561675446"}
0005435374121	E0DD66	8039 828695	LYUBOV TROFIMOVA	{"email": "l-trofimova.1962@postgrespro.ru", "phone": "+70977670068"}
0005435374122	2B924B	9069 040712	VALERIYA SAVELEVA	{"phone": "+70875855725"}
0005435374123	38FD90	2362 072361	NIKOLAY MARTYNOV	{"phone": "+70790344758"}
0005435374124	38FD90	5322 800674	VENERA VASILEVA	{"email": "venera.vasileva-29071970@postgrespro.ru", "phone": "+70576424020"}
0005435374125	4C2801	2509 387249	VLADISLAV KISELEV	{"phone": "+70469534656"}
0005435374126	377A19	2968 175597	VIKTOR KONOVALOV	{"email": "konovalov_v111974@postgrespro.ru", "phone": "+70037463450"}
0005435374127	93D723	0550 063464	NATALYA VASILEVA	{"email": "vasilevan1965@postgrespro.ru", "phone": "+70460471571"}
0005435374128	190A06	0488 650543	NADEZHDA GERASIMOVA	{"email": "nadezhda_gerasimova091974@postgrespro.ru", "phone": "+70354724560"}
0005435374129	49E1AE	9632 029168	YULIYA POPOVA	{"phone": "+70978542778"}
0005435374130	49E1AE	5832 920417	VALERIY SHEVCHENKO	{"email": "shevchenko.valeriy.27011975@postgrespro.ru", "phone": "+70614644172"}
0005435374131	49E1AE	8751 291429	VIKTORIYA PETROVA	{"phone": "+70431235669"}
0005435374132	AA0020	6465 486469	DMITRIY FEDOTOV	{"phone": "+70027612197"}
0005435374133	83B018	0604 204056	ANNA VOLKOVA	{"phone": "+70103428635"}
0005435374134	0C5B7A	9778 835692	VLADIMIR KUZMIN	{"phone": "+70746424720"}
0005435374135	0C5B7A	4844 427040	SERGEY VOLKOV	{"email": "sergey_volkov-081968@postgrespro.ru", "phone": "+70788660348"}
0005435374136	0C5B7A	7864 916249	YURIY ALEKSEEV	{"email": "alekseev_yuriy-12091964@postgrespro.ru", "phone": "+70293572444"}
0005435374137	A45DCC	3477 811899	MARAT CHERNOV	{"email": "chernovmarat1964@postgrespro.ru", "phone": "+70328462326"}
0005435374138	2C855D	6358 526816	IRINA MEDVEDEVA	{"email": "medvedeva-i.121974@postgrespro.ru", "phone": "+70749614298"}
0005435374139	2C855D	7533 917751	IRINA PETROVA	{"phone": "+70569754248"}
0005435374140	72F1F4	7618 041871	VYACHESLAV ORLOV	{"email": "v-orlov23071965@postgrespro.ru", "phone": "+70765012512"}
0005435374141	5CE92A	8355 714379	GENNADIY FOMIN	{"email": "g-fomin-08051973@postgrespro.ru", "phone": "+70803068023"}
0005435374142	F41F61	8257 641534	ANATOLIY ILIN	{"email": "anatoliy_ilin.25071969@postgrespro.ru", "phone": "+70871512232"}
0005435374143	F41F61	7965 006053	VYACHESLAV ALEKSANDROV	{"email": "aleksandrov_v_1981@postgrespro.ru", "phone": "+70121327666"}
0005435374144	60BD51	7860 433020	VALENTINA KUZMINA	{"email": "valentina_kuzmina-1979@postgrespro.ru", "phone": "+70069454567"}
0005435374145	4A736E	1835 882311	YURIY MATVEEV	{"phone": "+70932791783"}
0005435374146	CECAB5	8855 275830	RAISA IVANOVA	{"phone": "+70847984026"}
0005435374147	46D5BF	1758 437965	YULIYA VOLKOVA	{"email": "yuliya-volkova-1964@postgrespro.ru", "phone": "+70310121070"}
0005435374148	04419B	7355 445845	NIKOLAY KRASNOV	{"phone": "+70146312131"}
0005435374149	0D39AA	9148 673865	DMITRIY SERGEEV	{"email": "sergeev-d091977@postgrespro.ru", "phone": "+70172179081"}
0005435374150	CCC9C5	4715 183788	POLINA LOGINOVA	{"phone": "+70586077256"}
0005435374151	CCC9C5	0683 341385	VIKTOR KOZLOV	{"email": "viktor.kozlov_1978@postgrespro.ru", "phone": "+70712464403"}
0005435374152	769279	9165 180085	SERGEY KRASNOV	{"email": "krasnov-sergey_22091974@postgrespro.ru", "phone": "+70704500435"}
0005435374153	C76684	6323 665749	VLADIMIR ZHUKOV	{"phone": "+70584420110"}
0005435374154	05C5CC	4745 131931	MAKSIM NIKITIN	{"phone": "+70820217095"}
0005435374155	05C5CC	2772 354351	ANDREY AFANASEV	{"phone": "+70875196668"}
0005435374156	DCB560	7370 624407	OLEG SOKOLOV	{"phone": "+70616873594"}
0005435374157	DCB560	6316 349355	OLESYA BORISOVA	{"email": "borisovao101975@postgrespro.ru", "phone": "+70308448072"}
0005435374158	B765F6	5199 852622	MARAT MARTYNOV	{"email": "maratmartynov-1970@postgrespro.ru", "phone": "+70057343013"}
0005435374159	B765F6	9220 559489	LEV ROMANOV	{"phone": "+70806683144"}
0005435374160	C873AD	2352 553132	OLEG ISAEV	{"email": "o_isaev.20011975@postgrespro.ru", "phone": "+70532331973"}
0005435374161	C873AD	6658 008651	FEDOR NIKOLAEV	{"phone": "+70447476447"}
0005435374162	A92E96	6023 259579	EKATERINA KISELEVA	{"phone": "+70707279520"}
0005435374163	E1024A	2612 492280	GALINA GORBUNOVA	{"email": "g_gorbunova.111970@postgrespro.ru", "phone": "+70774074855"}
0005435374164	DB8715	2457 142318	ELENA YUDINA	{"email": "yudina.elena-1977@postgrespro.ru", "phone": "+70960443493"}
0005435374165	D0C2DF	8057 123119	NADEZHDA KULIKOVA	{"phone": "+70862280063"}
0005435374166	35E667	7015 231568	MARIYA SERGEEVA	{"phone": "+70868116187"}
0005435374167	CF56A8	1906 549395	ALEKSANDR TIKHONOV	{"email": "tikhonov-a.091977@postgrespro.ru", "phone": "+70286092548"}
0005435374168	CF56A8	7947 488022	SERGEY VOLKOV	{"phone": "+70239281442"}
0005435374169	96444B	7888 772055	NATALIYA SOROKINA	{"phone": "+70029080622"}
0005435374170	068088	3605 723761	OLEG FEDOROV	{"email": "o-fedorov121966@postgrespro.ru", "phone": "+70439497727"}
0005435374171	32C61C	5805 003529	IGOR NOVIKOV	{"email": "igor-novikov.12101980@postgrespro.ru", "phone": "+70099038027"}
0005435374172	32C61C	1738 669409	VLADIMIR NAZAROV	{"phone": "+70701257404"}
0005435374173	99F5D8	3699 196372	SERGEY MEDVEDEV	{"email": "medvedevs.1971@postgrespro.ru", "phone": "+70258360206"}
0005435374174	7DAAD2	4803 722730	GALINA KUZMINA	{"email": "g-kuzmina.09051966@postgrespro.ru", "phone": "+70273851646"}
0005435374175	DE3F4D	9247 172343	LYUBOV FROLOVA	{"phone": "+70027272786"}
0005435374176	DE3F4D	5441 267980	ANNA IVANOVA	{"email": "a-ivanova01051966@postgrespro.ru", "phone": "+70007154039"}
0005435374177	26B5EF	5102 652282	MARIYA LOGINOVA	{"email": "mariyaloginova_30101967@postgrespro.ru", "phone": "+70467940701"}
0005435374178	26B5EF	6075 591114	IRINA MAKAROVA	{"email": "makarova-i091979@postgrespro.ru", "phone": "+70046850179"}
0005435374179	281C73	0357 024932	TATYANA VOROBEVA	{"email": "vorobeva-t-29071978@postgrespro.ru", "phone": "+70874860734"}
0005435374180	F46F22	2672 748097	NATALIYA NIKITINA	{"phone": "+70797679016"}
0005435374181	EFDF22	9155 963856	SVETLANA IVANOVA	{"email": "svetlanaivanova1977@postgrespro.ru", "phone": "+70886435436"}
0005435374182	49BE1F	2299 307202	ALEKSEY NIKITIN	{"email": "aleksey.nikitin1969@postgrespro.ru", "phone": "+70199866802"}
0005435374183	A57431	3054 706443	NIKOLAY KUDRYASHOV	{"email": "n-kudryashov1962@postgrespro.ru", "phone": "+70862617297"}
0005435374184	335994	4216 941374	ALEKSANDR SIDOROV	{"email": "sidorova_101974@postgrespro.ru", "phone": "+70830495106"}
0005435374185	BB7EA2	7889 286490	VIKTOR ZAYCEV	{"phone": "+70983904130"}
0005435374186	BB7EA2	1716 412795	RIM ABRAMOV	{"email": "abramov-rim.1967@postgrespro.ru", "phone": "+70895322891"}
0005435374187	FCE804	9188 727534	TATYANA KULIKOVA	{"email": "tatyana_kulikova.1974@postgrespro.ru", "phone": "+70209630770"}
0005435374188	E5C44B	6044 466993	NATALYA OVCHINNIKOVA	{"phone": "+70296662974"}
0005435374189	E5C44B	3814 052381	OLEG DMITRIEV	{"email": "dmitriev-oleg.111977@postgrespro.ru", "phone": "+70656584183"}
0005435374190	6C73B9	4457 830385	VLADIMIR SMIRNOV	{"phone": "+70758014194"}
0005435374191	D16220	4475 092267	DARYA ZOTOVA	{"email": "zotovad09031973@postgrespro.ru", "phone": "+70691257625"}
0005435374192	0793E9	4291 302876	INNA SERGEEVA	{"email": "sergeevainna111972@postgrespro.ru", "phone": "+70627711938"}
0005435374193	0793E9	2686 603903	VIKTORIYA LUKYANOVA	{"email": "viktoriya_lukyanova.03011984@postgrespro.ru", "phone": "+70159045026"}
0005435374194	B601EF	3247 072191	SERGEY FEDOTOV	{"phone": "+70543085292"}
0005435374195	1A5201	4319 900231	ALEKSANDR GRIGOREV	{"phone": "+70759856505"}
0005435374196	D47699	1008 130414	OLEG AFANASEV	{"phone": "+70458036961"}
0005435374197	D47699	5440 834769	LYUDMILA ZHURAVLEVA	{"email": "l_zhuravleva06021977@postgrespro.ru", "phone": "+70511020926"}
0005435374198	D47699	9344 994174	ALEKSANDR NIKITIN	{"phone": "+70777155799"}
0005435374199	E0A9D2	4420 893322	OLGA MAKAROVA	{"email": "o_makarova_031980@postgrespro.ru", "phone": "+70653187432"}
0005435374200	4D4592	4224 783482	ANASTASIYA GRISHINA	{"email": "anastasiya_grishina_061972@postgrespro.ru", "phone": "+70172414196"}
0005435374201	4D4592	9509 674502	EVGENIY SCHERBAKOV	{"phone": "+70849734212"}
0005435374202	8C222A	3233 718469	ELENA PETROVA	{"phone": "+70563785393"}
0005435374203	8C222A	1229 451399	NATALYA KOLESNIKOVA	{"phone": "+70897025997"}
0005435374204	8C222A	6047 209150	LYUBOV FEDOROVA	{"phone": "+70251920848"}
0005435374205	16E35D	6376 439819	RUSLAN POPOV	{"email": "ruslan.popov.22051976@postgrespro.ru", "phone": "+70884376473"}
0005435374206	8FB8C3	7402 424038	VITALIY CHERNOV	{"phone": "+70238588919"}
0005435374207	F7C2E8	6095 863490	EVGENIY SOKOLOV	{"phone": "+70940530808"}
0005435374208	3187BD	3088 289422	NATALIYA EGOROVA	{"phone": "+70228322766"}
0005435374209	3187BD	8310 510028	ARINA TIKHONOVA	{"phone": "+70048128013"}
0005435374210	C1C8DF	9037 299973	GALINA LOGINOVA	{"email": "loginovag.1961@postgrespro.ru", "phone": "+70362264087"}
0005435374211	C1C8DF	3722 813394	MIKHAIL SAVELEV	{"email": "savelev-m_29011969@postgrespro.ru", "phone": "+70620504709"}
0005435374212	4772C6	5752 409732	ILONA SAVELEVA	{"email": "ilona-saveleva.091974@postgrespro.ru", "phone": "+70503692264"}
0005435374213	4772C6	8335 976576	OLGA VOLKOVA	{"email": "volkova_o.081974@postgrespro.ru", "phone": "+70604722481"}
0005435374214	545988	8968 635967	MIKHAIL SOKOLOV	{"email": "sokolov.mikhail-1976@postgrespro.ru", "phone": "+70960221593"}
0005435374215	545988	1987 767549	ALENA DANILOVA	{"phone": "+70489827302"}
0005435374216	385687	9865 887829	ANASTASIYA KONDRATEVA	{"email": "kondratevaa_011980@postgrespro.ru", "phone": "+70868966010"}
0005435374217	385687	2601 299743	MARINA VOLKOVA	{"email": "marina-volkova-1965@postgrespro.ru", "phone": "+70315556914"}
0005435374218	385687	2019 468565	VIKTOR KULIKOV	{"email": "kulikov-viktor.29111978@postgrespro.ru", "phone": "+70674993231"}
0005435374219	385687	0418 502313	EVGENIY FILIPPOV	{"email": "filippov-e1977@postgrespro.ru", "phone": "+70567861907"}
0005435374220	9FE33F	4789 980602	VALENTINA FILIPPOVA	{"email": "valentina-filippova_1987@postgrespro.ru", "phone": "+70706895679"}
0005435374221	03DF7D	3402 857637	MIKHAIL CHERNOV	{"email": "chernov.mikhail-071967@postgrespro.ru", "phone": "+70020996951"}
0005435374222	03DF7D	3681 675616	TAMARA IVANOVA	{"phone": "+70597600702"}
0005435374223	B658EC	1851 228312	DMITRIY ILIN	{"email": "ilin-d-01051973@postgrespro.ru", "phone": "+70809751390"}
0005435374224	B658EC	2336 771116	VALERIY KUZNECOV	{"phone": "+70794505052"}
0005435374225	75CE51	8165 570950	ALEKSANDR FOMIN	{"email": "aleksandrfomin.11051971@postgrespro.ru", "phone": "+70246836564"}
0005435374226	75CE51	9602 380117	ANDREY MIKHAYLOV	{"email": "andrey_mikhaylov.1961@postgrespro.ru", "phone": "+70424666321"}
0005435374227	0D4808	8495 629629	VALENTIN ISAEV	{"email": "valentinisaev_17081975@postgrespro.ru", "phone": "+70813531946"}
0005435374228	0D4808	2749 778475	LIDIYA SEMENOVA	{"phone": "+70817416000"}
0005435374229	0D4808	8360 974361	ANDREY STEPANOV	{"email": "stepanov.andrey091975@postgrespro.ru", "phone": "+70347362073"}
0005435374230	0D4808	6378 263631	VALENTINA GAVRILOVA	{"email": "v.gavrilova_071980@postgrespro.ru", "phone": "+70459526217"}
0005435374231	B44F28	5538 221502	ANATOLIY ROMANOV	{"phone": "+70372244443"}
0005435374232	3A92AD	3475 506760	VALENTINA DENISOVA	{"email": "denisova.valentina.1963@postgrespro.ru", "phone": "+70265967843"}
0005435374233	3A92AD	4214 476991	DMITRIY FOMIN	{"phone": "+70833371139"}
0005435374234	3A92AD	5200 251356	VIKTOR GAVRILOV	{"email": "vgavrilov-1971@postgrespro.ru", "phone": "+70650387003"}
0005435374235	F711A9	8166 840300	ALBERT IVANOV	{"email": "albert_ivanov.021978@postgrespro.ru", "phone": "+70502252836"}
0005435374236	8EF51B	7535 466178	BORIS VOLKOV	{"phone": "+70947532766"}
0005435374237	E593CC	5898 675550	NADEZHDA SIDOROVA	{"email": "nadezhdasidorova-06051974@postgrespro.ru", "phone": "+70693417448"}
0005435374238	77759E	4107 866977	VLADIMIR KULIKOV	{"email": "kulikovvladimir-11081969@postgrespro.ru", "phone": "+70154589211"}
0005435374239	C2B0F3	5291 092002	SERGEY FOMIN	{"email": "sergey-fomin-01051963@postgrespro.ru", "phone": "+70505427166"}
0005435374240	7459CF	5361 201107	NADEZHDA EFIMOVA	{"phone": "+70795803882"}
0005435374241	1ADA1D	2840 781137	NATALYA BELOVA	{"phone": "+70821766715"}
0005435374242	D82EC3	2824 494245	NAIL DAVYDOV	{"email": "davydov-nail10031966@postgrespro.ru", "phone": "+70783748318"}
0005435374243	1A92C2	4863 514441	MAKSIM BONDARENKO	{"phone": "+70442992495"}
0005435374244	1A92C2	7762 782520	LIDIYA VOLKOVA	{"phone": "+70408766939"}
0005435374245	4B9036	8459 564051	MARIYA KUZMINA	{"email": "m.kuzmina121967@postgrespro.ru", "phone": "+70143299285"}
0005435374246	583DD2	6977 990785	ALEKSANDR DMITRIEV	{"email": "aleksandr.dmitriev.011985@postgrespro.ru", "phone": "+70862091395"}
0005435374247	29D796	3159 807701	VIKTORIYA IVANOVA	{"email": "ivanova-v-031977@postgrespro.ru", "phone": "+70963574695"}
0005435374248	29D796	9165 926015	RASHIT MOROZOV	{"email": "morozov_r-1978@postgrespro.ru", "phone": "+70228857003"}
0005435374249	3409B7	4610 351712	SVETLANA ANISIMOVA	{"email": "sanisimova_1967@postgrespro.ru", "phone": "+70036621036"}
0005435374250	3409B7	2663 207660	OLEG TARASOV	{"email": "tarasov-oleg_24081971@postgrespro.ru", "phone": "+70295676410"}
0005435374251	22BD67	2347 934367	MARIYA CHERNOVA	{"email": "m-chernova_1967@postgrespro.ru", "phone": "+70476273054"}
0005435374252	9F8A7A	6780 653399	ALEKSANDR MELNIKOV	{"email": "a.melnikov_26011964@postgrespro.ru", "phone": "+70151930525"}
0005435374253	9F8A7A	5784 286197	ILYA STEPANOV	{"phone": "+70304326357"}
0005435374254	35E54A	8898 745485	SERGEY ANDREEV	{"phone": "+70553299388"}
0005435374255	CDD35B	4598 302257	SOFYA EGOROVA	{"email": "sofya_egorova-1977@postgrespro.ru", "phone": "+70131779187"}
0005435374256	CDD35B	2507 125366	ANNA POTAPOVA	{"email": "potapova-anna_011983@postgrespro.ru", "phone": "+70492161377"}
0005435374257	2F1F33	1779 539283	OLEG PETROV	{"email": "o.petrov121970@postgrespro.ru", "phone": "+70687989137"}
0005435374258	2F1F33	6941 983114	SERGEY SERGEEV	{"phone": "+70901380749"}
0005435374259	1162AF	5465 907159	VLADIMIR EGOROV	{"email": "egorov.v031984@postgrespro.ru", "phone": "+70402998179"}
0005435374260	1162AF	4425 678905	MIKHAIL DAVYDOV	{"email": "mikhail.davydov011975@postgrespro.ru", "phone": "+70982160875"}
0005435374261	97970B	6607 811241	VLADIMIR NIKOLAEV	{"phone": "+70173070732"}
0005435374262	05C2D1	5851 427563	YULIYA LUKYANOVA	{"email": "ylukyanova-12011968@postgrespro.ru", "phone": "+70052095720"}
0005435374263	19956F	8565 536686	RADIK SOROKIN	{"email": "sorokin_radik1981@postgrespro.ru", "phone": "+70669900618"}
0005435374264	5D871C	1073 497996	RUSLAN POPOV	{"phone": "+70911706015"}
0005435374265	E69997	3498 936633	KSENIYA BARANOVA	{"email": "k.baranova-081974@postgrespro.ru", "phone": "+70346430777"}
0005435374266	E69997	1144 136082	YURIY MIKHAYLOV	{"phone": "+70362602888"}
0005435374267	71B3BE	6048 049937	KONSTANTIN YAKOVLEV	{"email": "yakovlev_k1970@postgrespro.ru", "phone": "+70846139091"}
0005435374268	72EBD9	8519 737081	VERA DAVYDOVA	{"phone": "+70478860634"}
0005435374269	72EBD9	1614 480033	SERGEY NOVIKOV	{"email": "novikov.sergey1960@postgrespro.ru", "phone": "+70434208661"}
0005435374270	2A3380	4003 283040	NADEZHDA POPOVA	{"phone": "+70399097454"}
0005435374271	FD2D26	4286 370527	DENIS MAKSIMOV	{"phone": "+70789127455"}
0005435374272	FD2D26	8882 296417	ANNA SIDOROVA	{"phone": "+70168099519"}
0005435374273	A48C92	0813 691916	VALENTINA SEMENOVA	{"phone": "+70931323143"}
0005435374274	A48C92	5986 153626	NIKOLAY GRIGOREV	{"phone": "+70430899157"}
0005435374275	FC161F	6292 666114	IRINA NIKOLAEVA	{"phone": "+70778404191"}
0005435374276	A88216	3386 417889	ARTEM GERASIMOV	{"email": "gerasimov-artem_1978@postgrespro.ru", "phone": "+70331759711"}
0005435374277	A88216	0113 830995	KIRILL VOLKOV	{"email": "volkov-kirill.1968@postgrespro.ru", "phone": "+70605355261"}
0005435374278	08D066	1067 294473	ALEKSEY KUZNECOV	{"email": "kuznecov.aleksey_1971@postgrespro.ru", "phone": "+70950674351"}
0005435374279	F45887	4934 324722	ARTEM KUZNECOV	{"phone": "+70318552428"}
0005435374280	F45887	3004 319546	VALENTINA ALEKSEEVA	{"phone": "+70579575349"}
0005435374281	873FB8	4727 509342	OLEG SERGEEV	{"phone": "+70243127616"}
0005435374282	83BB8C	3228 869938	ZOYA DMITRIEVA	{"phone": "+70374148163"}
0005435374283	7B5525	1938 989654	ANNA VASILEVA	{"email": "vasilevaanna_111967@postgrespro.ru", "phone": "+70308107761"}
0005435374284	D0BAAD	1186 185221	VERA TITOVA	{"phone": "+70717083500"}
0005435374285	D3E92B	8214 877304	VASILIY SIDOROV	{"phone": "+70531679145"}
0005435374286	88D282	9137 911213	ELENA BOGDANOVA	{"email": "elenabogdanova06051970@postgrespro.ru", "phone": "+70533588418"}
0005435374287	54B2F6	8074 641877	ILDAR MAKSIMOV	{"phone": "+70685788384"}
0005435374288	DE8BB1	2313 186930	POLINA RYABOVA	{"email": "polina_ryabova-1981@postgrespro.ru", "phone": "+70698417869"}
0005435374289	9E6BB0	7243 729510	ANASTASIYA ALEKSEEVA	{"phone": "+70123246106"}
0005435374290	9E6BB0	2340 820382	SERGEY SCHERBAKOV	{"phone": "+70801557993"}
0005435374291	0657B6	4232 965287	ANNA BORISOVA	{"phone": "+70879176376"}
0005435374292	B34ACC	1425 545857	TIMUR ANTONOV	{"email": "antonov-t111980@postgrespro.ru", "phone": "+70177790038"}
0005435374293	B34ACC	6566 339334	SOFYA KUDRYASHOVA	{"email": "skudryashova_1965@postgrespro.ru", "phone": "+70632351478"}
0005435374294	7DDF64	0832 656370	YULIYA GERASIMOVA	{"phone": "+70515559476"}
0005435374295	7DDF64	4009 823267	ALEKSANDR KRASNOV	{"email": "krasnov.a_25011981@postgrespro.ru", "phone": "+70680076780"}
0005435374296	4E66F9	7308 412985	ANDREY KAZAKOV	{"phone": "+70106595033"}
0005435374297	197F11	9019 878388	ANATOLIY TARASOV	{"email": "a-tarasov_11031974@postgrespro.ru", "phone": "+70049850786"}
0005435374298	197F11	8166 779677	VIKTOR IVANOV	{"email": "v-ivanov_081974@postgrespro.ru", "phone": "+70922512039"}
0005435374299	3DD202	5585 081730	YURIY ROMANOV	{"phone": "+70175176748"}
0005435374300	3DD202	1540 212055	IGOR POPOV	{"phone": "+70348466034"}
0005435374301	9F3B71	8006 884645	ALEKSANDR POPOV	{"email": "a.popov_27091972@postgrespro.ru", "phone": "+70411329220"}
0005435374302	A8F63D	1035 359917	ELENA KOZLOVA	{"phone": "+70458728279"}
0005435374303	A8F63D	3248 761450	ANDREY POPOV	{"email": "popov.a-041967@postgrespro.ru", "phone": "+70624753255"}
0005435374304	EC2F55	1678 929126	MAKSIM KONOVALOV	{"phone": "+70145184473"}
0005435374305	8E9988	2529 196833	SERGEY KUZMIN	{"email": "sergey_kuzmin_02051967@postgrespro.ru", "phone": "+70285096740"}
0005435374306	0CF2BB	0172 459185	SVETLANA SERGEEVA	{"email": "sergeeva_s_011986@postgrespro.ru", "phone": "+70204984411"}
0005435374307	0CF2BB	1976 869623	ANDREY KUZMIN	{"email": "kuzmin_andrey-011968@postgrespro.ru", "phone": "+70618760575"}
0005435374308	0CF2BB	1266 661593	VLADIMIR FROLOV	{"phone": "+70649989568"}
0005435374309	6937BA	5469 679733	LYUBOV BORISOVA	{"phone": "+70759501524"}
0005435374310	92EF3B	7639 082583	NADEZHDA KOLESNIKOVA	{"phone": "+70487684028"}
0005435374311	B4A621	6563 659580	LYUDMILA IVANOVA	{"email": "l-ivanova08111970@postgrespro.ru", "phone": "+70206864925"}
0005435374312	28D00E	7738 639800	VERA FOMINA	{"phone": "+70477057735"}
0005435374313	EBA9E0	1201 887257	LYUDMILA ANDREEVA	{"email": "andreeva_lyudmila-15101968@postgrespro.ru", "phone": "+70684777106"}
0005435374314	104AD2	0252 631960	TATYANA MOROZOVA	{"email": "tmorozova_1977@postgrespro.ru", "phone": "+70291679246"}
0005435374315	104AD2	7731 009523	NINA MAKAROVA	{"email": "nmakarova.071974@postgrespro.ru", "phone": "+70975751264"}
0005435374316	8DA9CC	2616 657526	VASILIY ORLOV	{"phone": "+70635611156"}
0005435374317	F68E6B	3249 400234	LYUDMILA VASILEVA	{"email": "vasileva_l.1972@postgrespro.ru", "phone": "+70510413654"}
0005435374318	D8A958	1037 858869	ANATOLIY VASILEV	{"phone": "+70209692084"}
0005435374319	D8A958	3867 475304	VYACHESLAV SCHERBAKOV	{"email": "scherbakov_v.111965@postgrespro.ru", "phone": "+70073496284"}
0005435374320	38CECD	4740 919513	NATALYA MALYSHEVA	{"phone": "+70073827117"}
0005435374321	1769D9	2220 251025	MARIYA KALININA	{"phone": "+70693667885"}
0005435374322	400F2B	4500 773617	IRINA SEMENOVA	{"email": "semenova_irina10081972@postgrespro.ru", "phone": "+70389573812"}
0005435374323	43A4BC	4831 139322	VERA FILIPPOVA	{"email": "v.filippova-06031957@postgrespro.ru", "phone": "+70697460751"}
0005435374324	10107F	6471 658233	ANASTASIYA ROMANOVA	{"email": "anastasiya-romanova.041989@postgrespro.ru", "phone": "+70208058707"}
0005435374325	10107F	1217 738539	OLEG DAVYDOV	{"phone": "+70250338300"}
0005435374326	08AE2C	0065 490257	EVGENIYA IVANOVA	{"phone": "+70085853418"}
0005435374327	6DBDC2	0692 403861	YULIYA EGOROVA	{"phone": "+70148843381"}
0005435374328	E8ECF1	1129 445199	EKATERINA MIKHAYLOVA	{"email": "mikhaylova-e.20091978@postgrespro.ru", "phone": "+70196538437"}
0005435374329	064AF5	0919 304076	ELENA BORISOVA	{"phone": "+70472854862"}
0005435374330	82FAB9	0332 492216	DANILA SIDOROV	{"email": "danila.sidorov_1980@postgrespro.ru", "phone": "+70035325558"}
0005435374331	B2CAF9	2230 577442	EDGAR MAKSIMOV	{"email": "maksimov_e-16101987@postgrespro.ru", "phone": "+70871378060"}
0005435374332	155B97	3106 277132	SERGEY PAVLOV	{"email": "sergey_pavlov_1971@postgrespro.ru", "phone": "+70268429894"}
0005435374333	3F0B2B	4941 367951	SERGEY ZAKHAROV	{"email": "s-zakharov1968@postgrespro.ru", "phone": "+70443577378"}
0005435374334	3F0B2B	3563 132326	VIKTORIYA TIKHONOVA	{"phone": "+70832067775"}
0005435374335	3F0B2B	1448 546331	TATYANA PETROVA	{"email": "petrova-tatyana.06051971@postgrespro.ru", "phone": "+70715822457"}
0005435374336	272D12	6096 810288	ELIZAVETA OSIPOVA	{"email": "osipova.e-15091986@postgrespro.ru", "phone": "+70490712370"}
0005435374337	272D12	1084 972255	ILYA SERGEEV	{"email": "ilyasergeev-02101969@postgrespro.ru", "phone": "+70543401554"}
0005435374338	7DAAF7	7923 375503	OLGA IVANOVA	{"email": "ivanova_olga28021967@postgrespro.ru", "phone": "+70094612885"}
0005435374339	0D0279	0400 202882	SERGEY MOROZOV	{"phone": "+70093630415"}
0005435374340	0D0279	2544 970250	LILIYA ANDREEVA	{"phone": "+70945002615"}
0005435374341	B3A424	3035 157432	ZAKHAR DENISOV	{"email": "denisovzakhar041972@postgrespro.ru", "phone": "+70294621265"}
0005435374342	B3A424	5861 886403	LILIYA FEDOROVA	{"phone": "+70388921533"}
0005435374343	4A8959	3477 873982	GALINA RYABOVA	{"phone": "+70410596799"}
0005435374344	4A8959	5891 492301	ANNA KUZMINA	{"email": "a-kuzmina1990@postgrespro.ru", "phone": "+70873695088"}
0005435374345	71B12F	2760 858133	MARINA NIKIFOROVA	{"phone": "+70478982265"}
0005435374346	FC5122	6867 294580	NIKOLAY SHEVCHENKO	{"phone": "+70941805935"}
0005435374347	41453C	9743 769552	TATYANA STEPANOVA	{"phone": "+70654942790"}
0005435374348	383B69	7652 724699	VALENTINA VASILEVA	{"phone": "+70442142825"}
0005435374349	383B69	9082 173111	OLGA FROLOVA	{"email": "o_frolova1966@postgrespro.ru", "phone": "+70488034128"}
0005435374350	2A47FC	6384 732477	ELENA POTAPOVA	{"phone": "+70323155416"}
0005435374351	2A47FC	9580 683851	ALEKSANDRA PETROVA	{"phone": "+70345546204"}
0005435374352	70EDA7	9192 586106	MARIYA SAVELEVA	{"email": "saveleva-m-1978@postgrespro.ru", "phone": "+70312091834"}
0005435374353	683BE2	7843 060716	ALEKSANDR NIKITIN	{"email": "a.nikitin_1978@postgrespro.ru", "phone": "+70795014794"}
0005435374354	683BE2	1373 518819	TATYANA POPOVA	{"email": "tatyana_popova_031960@postgrespro.ru", "phone": "+70592815971"}
0005435374355	3D050D	5038 797183	KRISTINA NIKOLAEVA	{"email": "kristina.nikolaeva25101968@postgrespro.ru", "phone": "+70399095624"}
0005435374356	3D050D	5895 263746	VITALIY NOVIKOV	{"email": "novikov-vitaliy.1971@postgrespro.ru", "phone": "+70250928747"}
0005435374357	3D050D	2351 410816	MARIYA KOROLEVA	{"phone": "+70437435314"}
0005435374358	9E9F29	6724 785182	RUSLAN ROMANOV	{"email": "ruslan.romanov_051974@postgrespro.ru", "phone": "+70193714640"}
0005435374359	518F9F	9723 795389	TATYANA KAZAKOVA	{"phone": "+70600604296"}
0005435374360	9EBA07	9914 269090	LYUDMILA FEDOROVA	{"phone": "+70629340244"}
0005435374361	9EBA07	9069 508369	OKSANA RODIONOVA	{"email": "rodionova-oksana10021969@postgrespro.ru", "phone": "+70053929871"}
0005435374362	9EBA07	9127 290925	FILIPP GORBUNOV	{"phone": "+70356516503"}
0005435374363	D37491	8119 850414	IRINA SMIRNOVA	{"email": "smirnovai-23071978@postgrespro.ru", "phone": "+70458964327"}
0005435374364	D37491	8402 530487	ALEKSANDRA KUZNECOVA	{"phone": "+70730525580"}
0005435374365	FE8A58	8691 274545	LYUBOV DANILOVA	{"email": "danilova-l_051981@postgrespro.ru", "phone": "+70515759233"}
0005435374366	FE8A58	4302 841985	ALEKSANDR MIKHAYLOV	{"email": "mikhaylova.06081965@postgrespro.ru", "phone": "+70310358269"}
0005435374367	3AFC26	4563 785634	VALENTINA ROMANOVA	{"phone": "+70697930355"}
0005435374368	3AFC26	1758 358866	LYUDMILA LAZAREVA	{"email": "lyudmila-lazareva.1969@postgrespro.ru", "phone": "+70761334594"}
0005435374369	D4A55C	0799 458642	ALEKSANDR KULIKOV	{"phone": "+70763485645"}
0005435374370	6B14FB	9216 474637	IVAN MEDVEDEV	{"email": "ivan.medvedev-15111977@postgrespro.ru", "phone": "+70346063260"}
0005435374371	9B3A96	1311 495419	NADEZHDA KOROLEVA	{"email": "n-koroleva-10041979@postgrespro.ru", "phone": "+70147653103"}
0005435374372	9B3A96	4652 476623	ROZA PAVLOVA	{"email": "pavlovaroza05061975@postgrespro.ru", "phone": "+70553954944"}
0005435374373	AB1AFC	7600 738174	ANTONINA IVANOVA	{"phone": "+70603659737"}
0005435374374	AB1AFC	2779 183103	MARINA EGOROVA	{"email": "egorova.m1974@postgrespro.ru", "phone": "+70785917426"}
0005435374375	AB1AFC	6404 042372	ALEKSEY ORLOV	{"email": "aleksey-orlov.1976@postgrespro.ru", "phone": "+70796976783"}
0005435374376	BD23D4	9158 826261	EVGENIY ILIN	{"email": "ilin_e-1975@postgrespro.ru", "phone": "+70543295341"}
0005435374377	4FB98F	9142 146006	NADEZHDA LEBEDEVA	{"email": "nadezhda.lebedeva-01041968@postgrespro.ru", "phone": "+70502358686"}
0005435374378	38CB56	1361 416790	NELLI SEMENOVA	{"email": "n_semenova061964@postgrespro.ru", "phone": "+70505790595"}
0005435374379	B3BC27	0380 228107	LYUBOV SEMENOVA	{"email": "lyubov.semenova_031968@postgrespro.ru", "phone": "+70318540763"}
0005435374380	A4F52B	0224 030858	VLADISLAV DAVYDOV	{"phone": "+70055742162"}
0005435374381	628B80	1270 252304	VITALIY BARANOV	{"phone": "+70020789843"}
0005435374382	3D5B32	9153 952335	ALEKSEY CHERNOV	{"email": "a-chernov-30061973@postgrespro.ru", "phone": "+70812463187"}
0005435374383	1618C5	7022 974026	ALEKSANDR FEDOROV	{"phone": "+70840182655"}
0005435374384	8389DD	3508 981734	NIKOLAY RODIONOV	{"phone": "+70064595097"}
0005435374385	1385EB	2101 310131	ILYA BORISOV	{"email": "ilya_borisov-13011964@postgrespro.ru", "phone": "+70637713673"}
0005435374386	1385EB	6774 458794	ELDAR KONOVALOV	{"email": "eldar_konovalov-22091969@postgrespro.ru", "phone": "+70877983669"}
0005435374387	92BBF8	2834 512865	IGOR SIDOROV	{"phone": "+70309502829"}
0005435374388	92BBF8	9192 048430	VASILIY FROLOV	{"email": "frolov-v041974@postgrespro.ru", "phone": "+70445832540"}
0005435374389	DA571E	0918 057694	VLADIMIR SEMENOV	{"phone": "+70410494715"}
0005435374390	DA571E	0673 425326	ELENA VASILEVA	{"email": "elena_vasileva.30101978@postgrespro.ru", "phone": "+70574641146"}
0005435374391	33893A	9410 158539	ALINA MAKAROVA	{"email": "a_makarova18061977@postgrespro.ru", "phone": "+70065505587"}
0005435374392	65BECA	4759 162171	ELENA ALEKSEEVA	{"phone": "+70846096963"}
0005435374393	81BF65	5465 979570	LARISA GUSEVA	{"phone": "+70684583414"}
0005435374394	BCC0DB	9672 720186	YULIYA MOISEEVA	{"email": "moiseeva-y.101961@postgrespro.ru", "phone": "+70756806704"}
0005435374395	9960C9	8178 339074	LYUDMILA MOROZOVA	{"phone": "+70319521920"}
0005435374396	9960C9	0496 379730	VLADIMIR KUDRYASHOV	{"phone": "+70231955776"}
0005435374397	36FD1B	4135 024043	ANTONINA PAVLOVA	{"phone": "+70548387944"}
0005435374398	443773	6207 704558	TATYANA STEPANOVA	{"email": "stepanova_tatyana_111974@postgrespro.ru", "phone": "+70882761485"}
0005435374399	32CA21	1971 698761	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov-111969@postgrespro.ru", "phone": "+70449463278"}
0005435374676	477496	1255 828969	SERGEY TIMOFEEV	{"phone": "+70592769317"}
0005435374400	32CA21	4746 230523	ANDREY SMIRNOV	{"email": "andrey_smirnov.10121977@postgrespro.ru", "phone": "+70312040690"}
0005435374401	B653A6	2984 384499	ALEKSANDR GORBUNOV	{"email": "a.gorbunov17071970@postgrespro.ru", "phone": "+70921608761"}
0005435374402	BF074F	7549 680118	EVGENIY ZAYCEV	{"phone": "+70830022431"}
0005435374403	70F2C6	4661 087255	IVAN TIKHONOV	{"phone": "+70216453267"}
0005435374404	DEC0E3	1255 963210	STEPAN DMITRIEV	{"email": "dmitriev-s-21071972@postgrespro.ru", "phone": "+70159311267"}
0005435374405	AEAD40	4853 815903	SABINA GAVRILOVA	{"phone": "+70276769101"}
0005435374406	AEAD40	1837 038988	KLAVDIYA KALININA	{"email": "k-kalinina_04061974@postgrespro.ru", "phone": "+70105203905"}
0005435374407	AEAD40	9499 267354	DENIS SMIRNOV	{"email": "denissmirnov-1969@postgrespro.ru", "phone": "+70595780863"}
0005435374408	FC2713	3840 204816	NINA SAVELEVA	{"phone": "+70556540380"}
0005435374409	7B7850	7105 690872	ALEKSANDR SEMENOV	{"phone": "+70424750396"}
0005435374410	29AA4E	6307 852582	ALEKSANDRA MARTYNOVA	{"phone": "+70611840180"}
0005435374411	0406D4	5347 006674	VLADIMIR ROMANOV	{"email": "v_romanov.081967@postgrespro.ru", "phone": "+70985560615"}
0005435374412	34B138	8087 985808	ELENA MOROZOVA	{"email": "morozova_elena_051974@postgrespro.ru", "phone": "+70553632223"}
0005435374413	89EB76	8159 370171	LARISA NIKOLAEVA	{"email": "larisanikolaeva.1987@postgrespro.ru", "phone": "+70047679738"}
0005435374414	89EB76	5630 847085	ALEKSANDR ROMANOV	{"email": "a_romanov.091974@postgrespro.ru", "phone": "+70217979003"}
0005435374415	89EB76	2704 155978	NIKOLAY SOROKIN	{"phone": "+70346950899"}
0005435374416	10D6FA	2622 219687	SERGEY GUSEV	{"email": "sergey-gusev_30101977@postgrespro.ru", "phone": "+70646618770"}
0005435374417	10D6FA	9657 799386	OLGA NOVIKOVA	{"email": "o_novikova-071973@postgrespro.ru", "phone": "+70103366424"}
0005435374418	10D6FA	2224 064566	VLADIMIR KUDRYASHOV	{"phone": "+70190045235"}
0005435374419	4055BF	8591 570215	MAKSIM PETROV	{"email": "petrov.maksim_1968@postgrespro.ru", "phone": "+70776876604"}
0005435374420	4055BF	0169 310859	OLGA KUZNECOVA	{"phone": "+70309346124"}
0005435374421	E969DC	1308 053841	PETR KOZLOV	{"email": "kozlovpetr_1974@postgrespro.ru", "phone": "+70168206845"}
0005435374422	E969DC	0029 777493	VLADIMIR SCHERBAKOV	{"phone": "+70694265408"}
0005435374423	11ABB4	6569 844211	TATYANA GUSEVA	{"phone": "+70959128690"}
0005435374424	8D4FA8	9715 640947	ANDREY SCHERBAKOV	{"phone": "+70473861720"}
0005435374425	0DE129	4112 407275	EKATERINA IVANOVA	{"phone": "+70401736786"}
0005435374426	E14D9D	2475 085306	TATYANA ABRAMOVA	{"email": "abramova.tatyana11041979@postgrespro.ru", "phone": "+70428903912"}
0005435374427	E14D9D	5599 324582	NATALYA AFANASEVA	{"email": "afanaseva_natalya021965@postgrespro.ru", "phone": "+70976347690"}
0005435374428	0B1D5C	3090 967056	DIANA KOZLOVA	{"email": "kozlova_d_1982@postgrespro.ru", "phone": "+70223953493"}
0005435374429	874BEF	9036 570944	NATALIYA NESTEROVA	{"email": "n.nesterova1972@postgrespro.ru", "phone": "+70287060290"}
0005435374430	874BEF	8480 880907	IVAN NAZAROV	{"phone": "+70576493470"}
0005435374431	D24258	0046 084537	VALENTINA TIMOFEEVA	{"phone": "+70913261235"}
0005435374432	B1E88A	7485 181119	INNA KUZNECOVA	{"phone": "+70851230271"}
0005435374433	92D4C8	1804 334275	GALINA BELOVA	{"phone": "+70481885028"}
0005435374434	92D4C8	1782 318235	VIKTOR ORLOV	{"email": "viktor-orlov26051984@postgrespro.ru", "phone": "+70835083271"}
0005435374435	A67262	6815 189025	ANDREY SCHERBAKOV	{"email": "scherbakov-andrey-1960@postgrespro.ru", "phone": "+70655890260"}
0005435374436	5BFFEC	8430 988318	MIKHAIL ZAYCEV	{"email": "m_zaycev121964@postgrespro.ru", "phone": "+70306165078"}
0005435374437	5BFFEC	1172 872937	TATYANA POPOVA	{"phone": "+70796264091"}
0005435374438	499A7C	1659 516657	IRINA OSIPOVA	{"email": "osipovai.1967@postgrespro.ru", "phone": "+70729977305"}
0005435374439	4AFB12	8808 426563	SERGEY NIKITIN	{"phone": "+70217419254"}
0005435374440	4AFB12	3796 245513	ELENA AKIMOVA	{"email": "elena_akimova.14041969@postgrespro.ru", "phone": "+70804131654"}
0005435374441	7906D5	8919 371307	VADIM SMIRNOV	{"phone": "+70627409097"}
0005435374442	38996C	1810 770436	LYUDMILA KISELEVA	{"email": "kiselevalyudmila23071969@postgrespro.ru", "phone": "+70356400010"}
0005435374443	A33B8F	2962 720954	MARIYA MARTYNOVA	{"email": "martynova.mariya29061965@postgrespro.ru", "phone": "+70958387397"}
0005435374444	C5CA83	8904 383274	PETR BONDARENKO	{"phone": "+70363321344"}
0005435374445	05A472	7399 225088	GALINA LUKYANOVA	{"email": "g-lukyanova.07101973@postgrespro.ru", "phone": "+70030289161"}
0005435374446	05A472	3524 258349	NATALYA SOROKINA	{"email": "natalya.sorokina1984@postgrespro.ru", "phone": "+70535550840"}
0005435374447	325D06	7469 142802	TATYANA KUZMINA	{"email": "tatyana-kuzmina.22121965@postgrespro.ru", "phone": "+70409903298"}
0005435374448	325D06	8167 469400	ANDREY KONOVALOV	{"email": "a-konovalov.06061956@postgrespro.ru", "phone": "+70111169931"}
0005435374449	D7E345	3007 859638	ALEKSANDRA MATVEEVA	{"email": "aleksandra.matveeva011981@postgrespro.ru", "phone": "+70116651064"}
0005435374450	7D2105	1805 586323	IGOR SCHERBAKOV	{"phone": "+70764429946"}
0005435374451	7A0E57	0288 553495	EVGENIY SMIRNOV	{"email": "e_smirnov-091978@postgrespro.ru", "phone": "+70155557163"}
0005435374452	65FF6B	8902 644370	OLGA TIKHONOVA	{"phone": "+70136191908"}
0005435374453	65FF6B	2432 780085	VERA ROMANOVA	{"email": "v.romanova_12081967@postgrespro.ru", "phone": "+70101548104"}
0005435374454	11BA79	2114 353187	RINAT DMITRIEV	{"phone": "+70941739411"}
0005435374734	5B6601	8884 631877	KIRILL PETROV	{"phone": "+70569314852"}
0005435374455	3472CC	3314 368984	VLADIMIR SAVELEV	{"email": "vladimir-savelev081971@postgrespro.ru", "phone": "+70361640777"}
0005435374456	AD3505	7807 003717	NATALYA NIKITINA	{"email": "natalya-nikitina041969@postgrespro.ru", "phone": "+70213336289"}
0005435374457	09B0AD	1538 073124	SERGEY IVANOV	{"phone": "+70742004982"}
0005435374458	98BD8B	4231 374155	OKSANA KOROLEVA	{"email": "o.koroleva_111976@postgrespro.ru", "phone": "+70301711561"}
0005435374459	027ABB	9734 643185	OLGA LUKYANOVA	{"email": "o.lukyanova091970@postgrespro.ru", "phone": "+70653870377"}
0005435374460	DEF9BC	0673 655567	NATALYA NESTEROVA	{"phone": "+70061012377"}
0005435374461	585D70	4265 178827	LYUDMILA NIKIFOROVA	{"phone": "+70202166707"}
0005435374462	75038F	8877 725962	VLADIMIR ORLOV	{"email": "v_orlov-061973@postgrespro.ru", "phone": "+70070536413"}
0005435374463	48C877	7257 412196	DARYA KOLESNIKOVA	{"email": "d-kolesnikova.14121971@postgrespro.ru", "phone": "+70373108511"}
0005435374464	69DCC8	2575 914343	POLINA BELOVA	{"phone": "+70200317977"}
0005435374465	F81A46	8502 875765	ALEKSANDR NIKITIN	{"email": "a_nikitin05111972@postgrespro.ru", "phone": "+70711715469"}
0005435374466	F81A46	5642 337116	EVGENIYA KAZAKOVA	{"email": "e-kazakova.111978@postgrespro.ru", "phone": "+70803403397"}
0005435374467	72602F	2567 011378	SERGEY BARANOV	{"phone": "+70165500132"}
0005435374468	72602F	2222 917655	VALENTINA PAVLOVA	{"email": "pavlova.valentina_1980@postgrespro.ru", "phone": "+70575526427"}
0005435374469	380FE2	5058 615867	DANILA ANTONOV	{"email": "antonovd.061966@postgrespro.ru", "phone": "+70052491909"}
0005435374470	2C5B9B	9590 032927	LEONID OSIPOV	{"email": "losipov-1976@postgrespro.ru", "phone": "+70816604387"}
0005435374471	2C5B9B	7463 607236	SALAVAT SOKOLOV	{"phone": "+70100743963"}
0005435374472	81EA24	6952 216431	NINA YUDINA	{"phone": "+70255301041"}
0005435374473	81EA24	7354 158999	SOFIYA MASLOVA	{"email": "sofiya_maslova-11051977@postgrespro.ru", "phone": "+70857617038"}
0005435374474	B8E5F0	2092 768939	ILYA NAUMOV	{"phone": "+70300310123"}
0005435374475	F87A1B	2680 928299	TATYANA SOLOVEVA	{"email": "solovevatatyana-22101966@postgrespro.ru", "phone": "+70640525888"}
0005435374476	F87A1B	3870 614071	YULIYA IVANOVA	{"email": "ivanova_y_1969@postgrespro.ru", "phone": "+70008273581"}
0005435374477	5CD45F	8662 218261	ANDREY PAVLOV	{"email": "a-pavlov-031972@postgrespro.ru", "phone": "+70952344909"}
0005435374478	5CD45F	9761 503058	VASILIY MIRONOV	{"email": "mironov.vasiliy.1976@postgrespro.ru", "phone": "+70476614233"}
0005435374479	7F7ACD	1760 663839	IGOR POPOV	{"email": "popov_i_19061970@postgrespro.ru", "phone": "+70309681585"}
0005435374480	CADD97	4360 630501	GALINA BELYAEVA	{"phone": "+70393271787"}
0005435374481	089D87	6962 354382	OLGA FADEEVA	{"email": "fadeeva-o_1963@postgrespro.ru", "phone": "+70418784465"}
0005435374482	F4E5F8	0719 600446	ANDREY SOROKIN	{"email": "a.sorokin23021975@postgrespro.ru", "phone": "+70490668674"}
0005435374483	8AE7B3	0691 321473	YURIY ANTONOV	{"email": "antonov-yuriy061978@postgrespro.ru", "phone": "+70150899688"}
0005435374484	642138	4362 267743	STEPAN DENISOV	{"email": "stepan_denisov-1972@postgrespro.ru", "phone": "+70242208219"}
0005435374485	8478AA	5864 013653	IRINA ZHUKOVA	{"phone": "+70147378117"}
0005435374486	8478AA	5292 758336	KAMILA OSIPOVA	{"phone": "+70315655799"}
0005435374487	4E8F36	0281 829968	LYUDMILA SCHERBAKOVA	{"phone": "+70636399227"}
0005435374488	4E8F36	4922 748966	NIKOLAY NIKOLAEV	{"phone": "+70168051611"}
0005435374489	F3F30A	8411 310516	ALLA ISAEVA	{"phone": "+70784120374"}
0005435374490	9E467A	2722 649505	VALENTINA FEDOROVA	{"email": "fedorova.valentina_06041965@postgrespro.ru", "phone": "+70623705740"}
0005435374491	9CECEA	2470 413151	EVGENIY MEDVEDEV	{"phone": "+70138329062"}
0005435374492	9CECEA	6476 617613	SERGEY POPOV	{"phone": "+70981945034"}
0005435374493	0B64FF	5456 031593	ALEKSEY SOROKIN	{"email": "aleksey.sorokin_29031970@postgrespro.ru", "phone": "+70916115620"}
0005435374494	68392B	9662 616962	VERA KUDRYASHOVA	{"phone": "+70702143059"}
0005435374495	390414	5015 658250	ALEKSANDR GORBUNOV	{"email": "gorbunov_aleksandr_051974@postgrespro.ru", "phone": "+70704418632"}
0005435374496	38B50E	8891 475605	EVGENIY NIKITIN	{"email": "enikitin.111973@postgrespro.ru", "phone": "+70339943989"}
0005435374497	7A161B	9262 653860	ELIZAVETA KONOVALOVA	{"phone": "+70059376313"}
0005435374498	7A161B	6918 432216	IVAN MOROZOV	{"phone": "+70547572043"}
0005435374499	5FAC54	9589 856353	ALEKSEY VASILEV	{"email": "aleksey.vasilev041968@postgrespro.ru", "phone": "+70272948440"}
0005435374500	F3C2C8	1353 951367	SERGEY IVANOV	{"email": "ivanov_sergey-091974@postgrespro.ru", "phone": "+70003855693"}
0005435374501	F3C2C8	4794 613633	DENIS NIKITIN	{"phone": "+70080461485"}
0005435374502	2CB47D	7299 758500	VIKTOR TIKHONOV	{"email": "tikhonov.viktor14041960@postgrespro.ru", "phone": "+70625267095"}
0005435374503	1A3541	1032 588864	LYUBOV KOROLEVA	{"email": "koroleva-lyubov-11101974@postgrespro.ru", "phone": "+70666625260"}
0005435374504	6D2ECE	7607 878112	ALEKSANDR GRIGOREV	{"phone": "+70145532120"}
0005435374505	846BE6	3957 053417	NIKITA SOROKIN	{"email": "sorokin-n.1970@postgrespro.ru", "phone": "+70011105601"}
0005435374506	846BE6	4617 072495	AYRAT NIKOLAEV	{"phone": "+70263121835"}
0005435374507	3DF499	5107 010289	MIKHAIL RODIONOV	{"email": "m_rodionov.1970@postgrespro.ru", "phone": "+70106954345"}
0005435374508	95C49D	3562 018940	ANDREY BARANOV	{"phone": "+70703311244"}
0005435374509	AA2732	1639 640703	IRINA MASLOVA	{"email": "maslova.i_1968@postgrespro.ru", "phone": "+70947482097"}
0005435374510	B1B9BC	7949 637730	LYUBOV DMITRIEVA	{"phone": "+70280662053"}
0005435374511	B1B9BC	4641 567019	ANGELINA KUZMINA	{"email": "kuzminaa101977@postgrespro.ru", "phone": "+70400218124"}
0005435374512	306411	4981 364750	NIKOLAY YAKOVLEV	{"email": "n-yakovlev.091967@postgrespro.ru", "phone": "+70012719474"}
0005435374513	EF4194	0904 252596	OKSANA KULIKOVA	{"email": "kulikova.oksana.071978@postgrespro.ru", "phone": "+70020177531"}
0005435374514	DC18E7	9067 807617	PETR FROLOV	{"phone": "+70301732019"}
0005435374515	3428D0	1012 716753	GALINA BORISOVA	{"email": "gborisova12011978@postgrespro.ru", "phone": "+70646583730"}
0005435374516	426DB5	2412 523021	EGOR GORBUNOV	{"email": "e_gorbunov.22091971@postgrespro.ru", "phone": "+70643420983"}
0005435374517	80F9A6	3220 462950	VIKTOR BORISOV	{"email": "borisov_viktor_091974@postgrespro.ru", "phone": "+70361545249"}
0005435374518	73B13D	3707 318399	ANTON TIMOFEEV	{"phone": "+70078063787"}
0005435374519	4C98F4	0154 463683	ANNA IVANOVA	{"email": "anna-ivanova-021964@postgrespro.ru", "phone": "+70807458969"}
0005435374520	600792	2747 597622	ELENA KISELEVA	{"email": "kiselevae081978@postgrespro.ru", "phone": "+70814941058"}
0005435374521	EE5324	8256 180417	TATYANA EFIMOVA	{"phone": "+70167546897"}
0005435374522	EE5324	3966 174018	DANILA MIKHAYLOV	{"email": "danila.mikhaylov051978@postgrespro.ru", "phone": "+70674516029"}
0005435374523	9A874F	0075 236754	FANIYA KOZLOVA	{"phone": "+70151951682"}
0005435374524	690AC2	3656 375657	MURAD IVANOV	{"phone": "+70204519377"}
0005435374525	690AC2	5772 158102	KIRA ANTONOVA	{"email": "kira_antonova041977@postgrespro.ru", "phone": "+70916910699"}
0005435374526	2BB834	8431 130085	VLADIMIR BELOV	{"phone": "+70607207704"}
0005435374527	D9C173	9122 559458	KSENIYA BORISOVA	{"email": "borisova_k1981@postgrespro.ru", "phone": "+70355377999"}
0005435374528	9C8D6E	4060 620564	LYUBOV IVANOVA	{"email": "ivanova_lyubov_031963@postgrespro.ru", "phone": "+70741050021"}
0005435374529	FF0E44	4361 803568	ANATOLIY PETROV	{"phone": "+70233103426"}
0005435374530	DA2E31	2142 297635	EVGENIY MAKAROV	{"email": "makarov_evgeniy.1965@postgrespro.ru", "phone": "+70296509912"}
0005435374531	DA2E31	7386 498658	MARIYA LEBEDEVA	{"email": "lebedeva_mariya_1981@postgrespro.ru", "phone": "+70792988840"}
0005435374532	FB4E5A	1477 674692	IVAN SOKOLOV	{"email": "sokolov.i-05111968@postgrespro.ru", "phone": "+70467286664"}
0005435374533	FB4E5A	7237 036415	MARIYA GORBUNOVA	{"email": "mariya_gorbunova.061978@postgrespro.ru", "phone": "+70293775571"}
0005435374534	FB4E5A	3109 307013	VLADIMIR ROMANOV	{"email": "vladimir-romanov.08121976@postgrespro.ru", "phone": "+70152116662"}
0005435374535	BBF646	3222 387463	EVGENIYA KUZNECOVA	{"email": "kuznecova_e061972@postgrespro.ru", "phone": "+70664863040"}
0005435374536	BBF646	8609 690527	PAVEL KUDRYASHOV	{"email": "pkudryashov1978@postgrespro.ru", "phone": "+70816205496"}
0005435374537	736250	3810 166453	LIDIYA CHERNOVA	{"phone": "+70995200421"}
0005435374538	736250	2838 927291	DILYARA ZAYCEVA	{"email": "dilyara-zayceva_12011965@postgrespro.ru", "phone": "+70009797763"}
0005435374539	7CB59A	1412 674759	GALINA KUZNECOVA	{"email": "kuznecovagalina121972@postgrespro.ru", "phone": "+70206253201"}
0005435374540	74F857	6999 745566	LEONID VOLKOV	{"phone": "+70460918050"}
0005435374541	3D6235	6126 669346	GALINA TIKHONOVA	{"email": "tikhonova.g_071978@postgrespro.ru", "phone": "+70045771911"}
0005435374542	557E11	1264 060504	ARTEM BORISOV	{"phone": "+70969605707"}
0005435374543	26BDC6	0208 888051	ALEKSANDR ZAKHAROV	{"email": "aleksandr_zakharov.1982@postgrespro.ru", "phone": "+70470950812"}
0005435374544	08B69F	0697 181122	NADEZHDA MEDVEDEVA	{"phone": "+70309723384"}
0005435374545	B71347	2899 457296	OLGA MOISEEVA	{"email": "moiseevaolga-03011974@postgrespro.ru", "phone": "+70837329409"}
0005435374546	3A13A0	9439 566545	VLADIMIR FEDOROV	{"email": "fedorovv-041967@postgrespro.ru", "phone": "+70347579808"}
0005435374547	B782AC	5468 342333	NURLAN IVANOV	{"email": "nurlan-ivanov.17121968@postgrespro.ru", "phone": "+70594534618"}
0005435374548	B782AC	6592 371893	MARINA FEDOROVA	{"email": "marina-fedorova_06021960@postgrespro.ru", "phone": "+70177225338"}
0005435374549	2B5A1A	8945 822296	LIDIYA MAKSIMOVA	{"email": "lidiya.maksimova.20041970@postgrespro.ru", "phone": "+70279048262"}
0005435374550	836D1E	2686 712332	LIDIYA DENISOVA	{"phone": "+70054948775"}
0005435374551	0345F9	8777 430126	VITALIY DENISOV	{"email": "vitaliy_denisov.04071968@postgrespro.ru", "phone": "+70127610970"}
0005435374552	50C090	5699 028578	ANTON KAZAKOV	{"phone": "+70603575902"}
0005435374553	70683B	0569 687807	YULIYA KOZLOVA	{"email": "kozlova.yuliya09041963@postgrespro.ru", "phone": "+70049370553"}
0005435374554	769C00	2118 990643	ALEKSANDR POPOV	{"email": "aleksandr_popov-17121958@postgrespro.ru", "phone": "+70471987488"}
0005435374555	0ABF70	5784 556107	ANDREY STEPANOV	{"phone": "+70496109106"}
0005435374556	846862	1142 307089	IRINA GORBUNOVA	{"phone": "+70356746567"}
0005435374557	846862	9414 993990	NIKITA EGOROV	{"email": "n.egorov_07101967@postgrespro.ru", "phone": "+70379270609"}
0005435374558	0D851D	8387 228315	VLADIMIR KOROLEV	{"phone": "+70809166090"}
0005435374559	297925	5918 141347	ANTON MIRONOV	{"phone": "+70360128606"}
0005435374560	297925	2049 367009	MARINA TARASOVA	{"email": "tarasova_marina10061960@postgrespro.ru", "phone": "+70475323423"}
0005435374561	67879B	5339 447011	VLADIMIR SAVELEV	{"email": "savelevvladimir_041971@postgrespro.ru", "phone": "+70863055582"}
0005435374562	FCFFFD	7466 176801	OLGA LEBEDEVA	{"email": "lebedeva_o.021974@postgrespro.ru", "phone": "+70973264471"}
0005435374563	40903F	9590 426492	SERGEY STEPANOV	{"phone": "+70896996911"}
0005435374564	922381	6888 379631	ALEKSANDR PAVLOV	{"phone": "+70916148588"}
0005435374565	5C29BE	1084 053765	NIKOLAY ZAYCEV	{"phone": "+70487681209"}
0005435374566	5B9E2E	8282 149908	EVGENIY ZHURAVLEV	{"email": "zhuravleve.121973@postgrespro.ru", "phone": "+70194401235"}
0005435374567	5B9E2E	2388 107379	LYUDMILA SOROKINA	{"email": "lyudmila.sorokina_1971@postgrespro.ru", "phone": "+70573669005"}
0005435374568	67A70D	1356 139393	ALISA GRISHINA	{"email": "a.grishina-06071973@postgrespro.ru", "phone": "+70569165784"}
0005435374569	CA4BA6	6230 048147	NIKOLAY FEDOROV	{"phone": "+70835260336"}
0005435374570	CA4BA6	7702 132084	EVGENIY VOLKOV	{"phone": "+70979376340"}
0005435374571	CA4BA6	2558 998226	VLADIMIR FILIPPOV	{"phone": "+70268938402"}
0005435374572	BFAE59	4990 298344	KLAVDIYA IVANOVA	{"email": "ivanova_k.1973@postgrespro.ru", "phone": "+70679590120"}
0005435374573	413245	0864 281876	ANDREY MAKSIMOV	{"email": "maksimova081971@postgrespro.ru", "phone": "+70942053670"}
0005435374574	413245	6951 032249	VALENTINA KULIKOVA	{"phone": "+70022441478"}
0005435374575	D1553F	5955 971937	IVAN IVANOV	{"email": "ivanovi-061974@postgrespro.ru", "phone": "+70294988247"}
0005435374576	910BBB	7985 152622	VLADIMIR SEMENOV	{"phone": "+70974328462"}
0005435374577	E61E8F	2852 742139	IVAN BARANOV	{"phone": "+70993987625"}
0005435374578	C7EC0F	4869 001982	IRINA RYABOVA	{"email": "irinaryabova15021976@postgrespro.ru", "phone": "+70206451398"}
0005435374579	C7EC0F	7702 238431	ARINA VOLKOVA	{"phone": "+70831592483"}
0005435374580	641207	8862 598583	NINA CHERNOVA	{"email": "n_chernova01071977@postgrespro.ru", "phone": "+70164079824"}
0005435374581	9A7524	1958 843613	GALINA FILATOVA	{"email": "g.filatova_1976@postgrespro.ru", "phone": "+70070583462"}
0005435374582	3B6663	0249 080453	VYACHESLAV YAKOVLEV	{"email": "v-yakovlev.111970@postgrespro.ru", "phone": "+70001868668"}
0005435374583	3B6663	0842 868709	VITALIY FEDOTOV	{"phone": "+70673024141"}
0005435374584	3B6663	1502 714725	ELENA PAVLOVA	{"email": "elena_pavlova-031970@postgrespro.ru", "phone": "+70284798736"}
0005435374585	5C80E5	4501 608955	SVETLANA DANILOVA	{"email": "danilova_s.08101973@postgrespro.ru", "phone": "+70582411856"}
0005435374586	5C80E5	0244 794066	YAKOV ALEKSEEV	{"phone": "+70643183381"}
0005435374587	C2C0DF	6143 537046	YAROSLAV MIKHAYLOV	{"phone": "+70334345425"}
0005435374588	3B07EB	9357 097788	PAVEL SOLOVEV	{"email": "pavel_solovev-1967@postgrespro.ru", "phone": "+70420647262"}
0005435374589	1329A2	7374 056590	NINA STEPANOVA	{"email": "stepanova_nina.1973@postgrespro.ru", "phone": "+70462253865"}
0005435374590	597985	0133 762948	ALEKSANDR KUZNECOV	{"phone": "+70823731616"}
0005435374591	597985	6591 228891	EVGENIYA ANTONOVA	{"email": "evgeniya_antonova1968@postgrespro.ru", "phone": "+70896055331"}
0005435374592	636C72	2031 712934	TATYANA BELOVA	{"phone": "+70921720368"}
0005435374593	636C72	4358 156185	TATYANA RODIONOVA	{"phone": "+70663300636"}
0005435374594	79CEE1	2314 447210	POLINA VOROBEVA	{"email": "polina.vorobeva1968@postgrespro.ru", "phone": "+70208944999"}
0005435374595	79CEE1	9397 753765	EKATERINA IVANOVA	{"phone": "+70507910811"}
0005435374596	79CEE1	3305 566502	VIKTOR GRIGOREV	{"email": "v.grigorev-16121967@postgrespro.ru", "phone": "+70429566910"}
0005435374597	AD8881	9570 732341	LYUDMILA DAVYDOVA	{"email": "davydova.lyudmila.04121966@postgrespro.ru", "phone": "+70394939830"}
0005435374598	AD8881	8212 699517	IVAN KONOVALOV	{"email": "i.konovalov_101964@postgrespro.ru", "phone": "+70597410897"}
0005435374599	625B15	1532 031783	TALGAT ANTONOV	{"email": "antonov.talgat09071977@postgrespro.ru", "phone": "+70049643138"}
0005435374600	9F2FE6	7106 937136	EVGENIY IVANOV	{"email": "e-ivanov_121973@postgrespro.ru", "phone": "+70111363267"}
0005435374601	9F2FE6	0636 956196	YANA ANISIMOVA	{"phone": "+70801497481"}
0005435374602	2FE5A3	9927 302363	PAVEL PETROV	{"email": "pavelpetrov.08011969@postgrespro.ru", "phone": "+70162537701"}
0005435374603	2FE5A3	6480 908123	SERAFIM MELNIKOV	{"email": "melnikov-s-1962@postgrespro.ru", "phone": "+70959600306"}
0005435374604	8BBFDC	4495 860869	LYUDMILA YAKOVLEVA	{"email": "yakovleval.061973@postgrespro.ru", "phone": "+70725332617"}
0005435374605	8BBFDC	8975 181685	VIOLETTA KUZNECOVA	{"email": "kuznecova-violetta031973@postgrespro.ru", "phone": "+70539828682"}
0005435374606	583747	6512 962454	ILYA BONDARENKO	{"email": "bondarenko_i.1978@postgrespro.ru", "phone": "+70519178366"}
0005435374607	2D1400	8339 377612	VADIM VASILEV	{"email": "vadimvasilev.091976@postgrespro.ru", "phone": "+70486632958"}
0005435374608	D28EF3	1334 133223	LILIYA LEBEDEVA	{"email": "liliya.lebedeva.011973@postgrespro.ru", "phone": "+70486334477"}
0005435374609	D28EF3	0799 624086	DMITRIY ANTONOV	{"phone": "+70791038292"}
0005435374610	4C3942	6151 241278	MARIYA SOROKINA	{"email": "sorokinam.021974@postgrespro.ru", "phone": "+70877133894"}
0005435374611	4C3942	3877 363466	ANNA ANISIMOVA	{"phone": "+70426165557"}
0005435374612	4A51C1	1267 887838	ELENA VOLKOVA	{"email": "elena.volkova_20121966@postgrespro.ru", "phone": "+70828092434"}
0005435374613	151AA5	6253 496465	ELENA EFREMOVA	{"phone": "+70103147271"}
0005435374614	421AAD	9944 736126	NIKITA FOMIN	{"email": "nikitafomin_03071976@postgrespro.ru", "phone": "+70600352633"}
0005435374615	421AAD	3243 100560	IVAN VASILEV	{"phone": "+70090102444"}
0005435374616	763F49	0065 725166	TATYANA BORISOVA	{"phone": "+70898239515"}
0005435374617	7EAA4C	0743 322181	TATYANA CHERNOVA	{"phone": "+70526801777"}
0005435374618	161542	4766 709499	VALERIY DAVYDOV	{"email": "davydovv_011969@postgrespro.ru", "phone": "+70806906413"}
0005435374619	E1E199	4767 580787	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov-27071969@postgrespro.ru", "phone": "+70903522274"}
0005435374620	6F9A0A	6209 197444	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov1957@postgrespro.ru", "phone": "+70270226030"}
0005435374621	5AB03A	6609 995757	KLAVDIYA PAVLOVA	{"email": "klavdiya-pavlova06091971@postgrespro.ru", "phone": "+70045558572"}
0005435374622	5AB03A	7704 798946	SERGEY SEMENOV	{"phone": "+70788322213"}
0005435374623	26443A	1797 311641	KSENIYA KOZLOVA	{"email": "kozlova-kseniya.101962@postgrespro.ru", "phone": "+70859590970"}
0005435374624	26443A	5805 542703	IVAN NIKOLAEV	{"phone": "+70789968265"}
0005435374625	26443A	6764 731466	STEPAN SOKOLOV	{"email": "ssokolov111963@postgrespro.ru", "phone": "+70933489061"}
0005435374626	A0A262	4582 750088	GENNADIY SIDOROV	{"email": "g.sidorov-09051976@postgrespro.ru", "phone": "+70103100060"}
0005435374627	D1BB49	6092 561683	VERONIKA ALEKSANDROVA	{"phone": "+70880140396"}
0005435374628	815FE8	2893 265810	IGOR KUZNECOV	{"phone": "+70601875932"}
0005435374629	C79DFC	6529 148539	DENIS BONDARENKO	{"email": "denis_bondarenko_081965@postgrespro.ru", "phone": "+70434690494"}
0005435374630	CD9D02	7655 139869	OLEG SERGEEV	{"email": "sergeev.o.081969@postgrespro.ru", "phone": "+70481455574"}
0005435374631	19796E	5024 154450	VALENTINA KALININA	{"email": "kalinina.valentina_17011967@postgrespro.ru", "phone": "+70501967850"}
0005435374632	19796E	4357 346801	NINA VLASOVA	{"email": "vlasova.n-121971@postgrespro.ru", "phone": "+70589360465"}
0005435374633	BCA631	0843 765672	ANDREY KULIKOV	{"email": "kulikovandrey.061975@postgrespro.ru", "phone": "+70889244890"}
0005435374634	BCA631	8982 746673	ALESYA IVANOVA	{"email": "alesya_ivanova27021977@postgrespro.ru", "phone": "+70710965405"}
0005435374635	BCA631	9610 765323	SVETLANA NIKIFOROVA	{"phone": "+70685949180"}
0005435374636	05005F	9050 284110	ANNA SAVELEVA	{"email": "a_saveleva_13051973@postgrespro.ru", "phone": "+70915935765"}
0005435374637	172044	7884 401645	ANATOLIY FILIPPOV	{"email": "anatoliy_filippov18041968@postgrespro.ru", "phone": "+70043844296"}
0005435374638	16591A	3887 380296	ALEKSANDRA ZOTOVA	{"phone": "+70761783790"}
0005435374639	16591A	1203 461901	VADIM VOLKOV	{"phone": "+70136301656"}
0005435374640	E09F15	8616 004055	MARIYA OVCHINNIKOVA	{"email": "m.ovchinnikova_051957@postgrespro.ru", "phone": "+70152970806"}
0005435374641	C5C118	9350 334615	ZULFIYA ZAKHAROVA	{"email": "zzakharova1975@postgrespro.ru", "phone": "+70454176013"}
0005435374642	D9C5FE	1846 114812	ELENA MAKAROVA	{"email": "makarova-elena.1966@postgrespro.ru", "phone": "+70250790861"}
0005435374643	227CD7	1661 580465	DMITRIY NIKOLAEV	{"phone": "+70640597244"}
0005435374644	CB10D5	3030 964914	ALEKSANDR MARTYNOV	{"phone": "+70787409847"}
0005435374645	CB10D5	9728 839954	VALERIY FILIPPOV	{"phone": "+70829112067"}
0005435374646	CAD5E6	3376 111634	MIKHAIL SEMENOV	{"email": "m.semenov23091959@postgrespro.ru", "phone": "+70716170020"}
0005435374647	CAD5E6	0363 361502	TAMARA LAZAREVA	{"phone": "+70372474386"}
0005435374648	1C41BC	1316 764569	VLADIMIR SIDOROV	{"email": "sidorovv-081987@postgrespro.ru", "phone": "+70424688289"}
0005435374649	6EC695	6449 391580	ARKADIY GUSEV	{"email": "gusev.a.071968@postgrespro.ru", "phone": "+70929756616"}
0005435374650	14D8D7	1920 839393	VALENTINA FROLOVA	{"phone": "+70701522001"}
0005435374651	6BDE91	6340 033287	MARINA IVANOVA	{"email": "m-ivanova071973@postgrespro.ru", "phone": "+70196349368"}
0005435374652	144D78	2446 441529	YULIYA ISAEVA	{"phone": "+70244480890"}
0005435374653	523BBC	2569 276750	ARTEM KUZNECOV	{"email": "akuznecov_13121973@postgrespro.ru", "phone": "+70295008693"}
0005435374654	1EDBB8	4928 041591	VENERA ANISIMOVA	{"phone": "+70761611628"}
0005435374655	1EDBB8	4141 989067	RUSLAN KONOVALOV	{"phone": "+70004398600"}
0005435374656	662483	4670 610810	MARIYA SIDOROVA	{"phone": "+70884953834"}
0005435374657	A88CCA	5043 854762	IRINA SAVELEVA	{"email": "savelevai.16051971@postgrespro.ru", "phone": "+70364286526"}
0005435374658	A88CCA	0341 215091	NADEZHDA SMIRNOVA	{"phone": "+70037713572"}
0005435374659	6A5B83	0074 188121	RINAT MOROZOV	{"email": "morozovr.051982@postgrespro.ru", "phone": "+70923439708"}
0005435374660	57F317	0947 054222	VALENTIN SMIRNOV	{"phone": "+70294602487"}
0005435374661	FC4BEF	7360 508951	ARTEM SMIRNOV	{"phone": "+70801112851"}
0005435374662	FC4BEF	4195 490838	VLADIMIR SIDOROV	{"phone": "+70721807802"}
0005435374663	4546B2	3786 444231	VALENTINA AFANASEVA	{"phone": "+70958437475"}
0005435374664	EEC9FC	4632 099946	KONSTANTIN KUZNECOV	{"email": "kuznecov_k-1970@postgrespro.ru", "phone": "+70068818122"}
0005435374665	EEC9FC	8100 408805	IRINA ARKHIPOVA	{"email": "irina-arkhipova_081966@postgrespro.ru", "phone": "+70081555493"}
0005435374666	46CF5C	4767 243946	IRINA KONOVALOVA	{"email": "konovalova.i04031971@postgrespro.ru", "phone": "+70281209568"}
0005435374667	235E1A	0685 113748	ALEKSANDR BORISOV	{"email": "borisov-aleksandr.02041969@postgrespro.ru", "phone": "+70007056084"}
0005435374668	7BE49C	0368 248099	ANASTASIYA KOZLOVA	{"phone": "+70148910763"}
0005435374669	187EAC	2867 635436	ROMAN MOROZOV	{"phone": "+70780136293"}
0005435374670	187EAC	9815 789749	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov.1983@postgrespro.ru", "phone": "+70426972487"}
0005435374671	98B32B	8280 118577	VALENTINA MIKHAYLOVA	{"email": "valentina-mikhaylova-021968@postgrespro.ru", "phone": "+70403318198"}
0005435374672	98B32B	3597 772005	OKSANA CHERNOVA	{"email": "oksanachernova-21061975@postgrespro.ru", "phone": "+70032192694"}
0005435374673	7F458F	8773 143862	ALEKSANDR SEMENOV	{"email": "a-semenov081977@postgrespro.ru", "phone": "+70027961687"}
0005435374674	0A5DA2	4581 368416	ALLA SOLOVEVA	{"phone": "+70001314376"}
0005435374675	BF723D	4541 794505	VLADIMIR CHERNOV	{"email": "vchernov_031972@postgrespro.ru", "phone": "+70034817026"}
0005435374677	B9A85C	6236 882604	ANTON BELOV	{"email": "belov_a1973@postgrespro.ru", "phone": "+70199851065"}
0005435374678	B9A85C	9791 928206	ANASTASIYA BORISOVA	{"phone": "+70339636140"}
0005435374679	8AE355	5533 091277	LYUBOV GUSEVA	{"email": "gusevalyubov.1961@postgrespro.ru", "phone": "+70630184254"}
0005435374680	8AE355	7397 904883	VALENTINA AFANASEVA	{"email": "afanasevav011969@postgrespro.ru", "phone": "+70201153201"}
0005435374681	5747DF	9669 976455	DARYA KUZNECOVA	{"phone": "+70428827550"}
0005435374682	34892E	0316 712254	VIKTOR MAKSIMOV	{"email": "maksimovv_1971@postgrespro.ru", "phone": "+70389021364"}
0005435374683	D4173F	2414 016504	ARTEM PAVLOV	{"email": "pavlov_a_031968@postgrespro.ru", "phone": "+70131930729"}
0005435374684	D4173F	6570 200076	ELENA KUZNECOVA	{"phone": "+70099596506"}
0005435374685	FE5602	1694 709595	SVETLANA POPOVA	{"email": "popova.s_08011981@postgrespro.ru", "phone": "+70895778224"}
0005435374686	DA5242	4212 403731	ANATOLIY SOKOLOV	{"phone": "+70455913397"}
0005435374687	43799D	4340 199792	YURIY ISAEV	{"phone": "+70091956299"}
0005435374688	43799D	7517 905544	ANNA SEMENOVA	{"email": "a.semenova1970@postgrespro.ru", "phone": "+70178908899"}
0005435374689	6D39DE	7456 187056	ILYA KUZMIN	{"phone": "+70305749038"}
0005435374690	A17BF1	2367 375152	POLINA BORISOVA	{"phone": "+70576119848"}
0005435374691	524E84	8696 341464	EVGENIY MOISEEV	{"email": "moiseev-e-29091973@postgrespro.ru", "phone": "+70318206772"}
0005435374692	73B341	8462 209291	NADEZHDA ANTONOVA	{"email": "antonova.n.021980@postgrespro.ru", "phone": "+70726828523"}
0005435374693	70FD52	2809 202923	ELENA FILIPPOVA	{"phone": "+70332445319"}
0005435374694	70FD52	7709 239019	NIKOLAY FOMIN	{"email": "fomin.nikolay1969@postgrespro.ru", "phone": "+70790244101"}
0005435374695	ACB284	3793 402649	ANATOLIY BELOV	{"email": "belovanatoliy-22021973@postgrespro.ru", "phone": "+70116323459"}
0005435374696	17ED25	6813 252993	ELENA SERGEEVA	{"phone": "+70487258948"}
0005435374697	5F1DB3	6256 763650	DANIIL AFANASEV	{"phone": "+70300622497"}
0005435374698	399A16	1031 256489	SERGEY IVANOV	{"email": "s_ivanov041972@postgrespro.ru", "phone": "+70316179799"}
0005435374699	65AB54	5066 901944	TIMUR NIKOLAEV	{"email": "nikolaevt-03051975@postgrespro.ru", "phone": "+70726788623"}
0005435374700	65AB54	5886 638136	YULIYA EGOROVA	{"email": "egorova-yuliya.28081976@postgrespro.ru", "phone": "+70603123915"}
0005435374701	78BCF1	4418 090265	ELENA DENISOVA	{"email": "elenadenisova_1977@postgrespro.ru", "phone": "+70154163865"}
0005435374702	78BCF1	8812 952359	ELENA PAVLOVA	{"email": "epavlova-081957@postgrespro.ru", "phone": "+70038764994"}
0005435374703	AD08EE	6125 238430	ALEKSANDR ZAYCEV	{"email": "a-zaycev1957@postgrespro.ru", "phone": "+70174323564"}
0005435374704	AD08EE	0381 375861	DENIS KOROLEV	{"email": "korolev_denis25111960@postgrespro.ru", "phone": "+70492919894"}
0005435374768	882448	7657 657285	TAMARA ZAYCEVA	{"phone": "+70133447777"}
0005435374705	4D60EE	0216 246966	ANNA SOROKINA	{"email": "anna-sorokina.25101975@postgrespro.ru", "phone": "+70636984022"}
0005435374706	4D60EE	8886 830192	SERGEY MIKHAYLOV	{"phone": "+70793775941"}
0005435374707	BD0EDE	0923 457694	STEPAN SOKOLOV	{"phone": "+70348269005"}
0005435374708	03C7BD	0414 861883	SVETLANA FOMINA	{"phone": "+70980830317"}
0005435374709	9B6547	3669 367634	DAMIR IVANOV	{"email": "d_ivanov_1974@postgrespro.ru", "phone": "+70478349649"}
0005435374710	BD486F	6180 788604	MARIYA NAZAROVA	{"email": "mariya_nazarova061983@postgrespro.ru", "phone": "+70732778741"}
0005435374711	1392A2	9647 944433	MARINA KUZNECOVA	{"phone": "+70228416786"}
0005435374712	A5CC5F	1568 309217	MARAT ALEKSEEV	{"phone": "+70523425953"}
0005435374713	A5CC5F	4697 494537	OLESYA FROLOVA	{"phone": "+70005238811"}
0005435374714	C85173	4716 049841	GENNADIY ZAYCEV	{"email": "gennadiy-zaycev.05021986@postgrespro.ru", "phone": "+70651864716"}
0005435374715	834722	4064 473735	ANATOLIY MAKSIMOV	{"email": "maksimovanatoliy.061975@postgrespro.ru", "phone": "+70747742630"}
0005435374716	E36A59	9588 959506	OKSANA SOLOVEVA	{"phone": "+70930798191"}
0005435374717	E36A59	8396 319459	ANASTASIYA KRASNOVA	{"email": "krasnovaa111966@postgrespro.ru", "phone": "+70841815481"}
0005435374718	E86F7B	9511 075069	OLGA BORISOVA	{"phone": "+70832962477"}
0005435374719	45C4DA	6044 726439	YURIY SEMENOV	{"email": "semenov-yuriy16081980@postgrespro.ru", "phone": "+70406438387"}
0005435374720	F08653	9951 404282	VERA GRISHINA	{"phone": "+70109985853"}
0005435374721	F08653	6214 925510	MIKHAIL KOROLEV	{"email": "korolevm.1967@postgrespro.ru", "phone": "+70160064884"}
0005435374722	C20BF8	7700 023873	EVGENIY CHERNOV	{"phone": "+70867931686"}
0005435374723	C20BF8	1933 771569	SVETLANA BELYAEVA	{"email": "sbelyaeva_1965@postgrespro.ru", "phone": "+70946989458"}
0005435374724	9151C6	7937 249714	SVETLANA ANISIMOVA	{"phone": "+70298333488"}
0005435374725	9151C6	1573 362541	REGINA KUDRYASHOVA	{"phone": "+70058082210"}
0005435374726	9151C6	0088 520305	NADEZHDA OVCHINNIKOVA	{"phone": "+70367924215"}
0005435374727	62A756	6218 903227	DARYA KOZLOVA	{"phone": "+70105466475"}
0005435374728	398D95	4529 864944	TAISA MOISEEVA	{"email": "tmoiseeva_1973@postgrespro.ru", "phone": "+70555472319"}
0005435374729	398D95	5665 617934	VLADIMIR BELOV	{"phone": "+70075355625"}
0005435374730	4DF77F	3741 479699	GALINA AFANASEVA	{"phone": "+70288551596"}
0005435374731	2C5A0C	8461 338135	DINA PETROVA	{"phone": "+70199264602"}
0005435374732	2C5A0C	2834 087092	GALINA SMIRNOVA	{"phone": "+70526846097"}
0005435374733	5B6601	0547 416068	ANDREY GERASIMOV	{"email": "gerasimov.andrey-061970@postgrespro.ru", "phone": "+70048649976"}
0005435374735	8C3921	7963 248802	ELENA SOLOVEVA	{"phone": "+70533604991"}
0005435374736	8C3921	3349 733551	PETR IVANOV	{"email": "p_ivanov1972@postgrespro.ru", "phone": "+70705372764"}
0005435374737	8C3921	1989 576987	VENERA STEPANOVA	{"email": "venera.stepanova.061966@postgrespro.ru", "phone": "+70212823324"}
0005435374738	4CE197	0981 830993	SERGEY ILIN	{"email": "sergeyilin1977@postgrespro.ru", "phone": "+70578061793"}
0005435374739	4CE197	3691 200001	GULSHAT ZAKHAROVA	{"phone": "+70124504064"}
0005435374740	4CE197	8734 665183	ROMAN DENISOV	{"phone": "+70781975338"}
0005435374741	8EC301	1117 554340	LYUDMILA MASLOVA	{"email": "maslova_lyudmila021970@postgrespro.ru", "phone": "+70796841497"}
0005435374742	5DC5CC	4783 683552	VADIM MAKSIMOV	{"email": "maksimovv-1975@postgrespro.ru", "phone": "+70257639313"}
0005435374743	1C44D9	7985 222224	ANNA POTAPOVA	{"email": "potapovaa.071976@postgrespro.ru", "phone": "+70113082768"}
0005435374744	FBD94F	6111 218210	VALERIYA ZAKHAROVA	{"phone": "+70733678556"}
0005435374745	FC227B	3379 293554	VALERIY PAVLOV	{"phone": "+70174190828"}
0005435374746	89E846	1551 196352	VIKTOR DAVYDOV	{"email": "davydov-v_061977@postgrespro.ru", "phone": "+70359723838"}
0005435374747	BBA6D7	6711 678605	EKATERINA MATVEEVA	{"phone": "+70851013177"}
0005435374748	BBA6D7	1714 044538	DMITRIY BORISOV	{"phone": "+70663714984"}
0005435374749	E4E18F	7920 939092	VYACHESLAV KARPOV	{"email": "v.karpov.22081969@postgrespro.ru", "phone": "+70565846535"}
0005435374750	0C79BD	1659 978830	ELENA NAUMOVA	{"email": "elena_naumova_13061974@postgrespro.ru", "phone": "+70409962987"}
0005435374751	0C79BD	0347 753401	NIKOLAY NAZAROV	{"email": "nikolay-nazarov_04051967@postgrespro.ru", "phone": "+70962047044"}
0005435374752	9BB726	3318 274282	SERGEY FILIPPOV	{"phone": "+70102299018"}
0005435374753	43AB19	7317 147117	VERA BORISOVA	{"phone": "+70394992394"}
0005435374754	43AB19	0766 289038	YURIY VASILEV	{"phone": "+70955790277"}
0005435374755	C93FDE	8246 306041	KONSTANTIN ISAEV	{"email": "isaev-k_02101970@postgrespro.ru", "phone": "+70056822671"}
0005435374756	66BC18	6612 450677	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev.30111971@postgrespro.ru", "phone": "+70605459802"}
0005435374757	237E48	4149 748646	NIKITA ZHUKOV	{"phone": "+70630262152"}
0005435374758	0AA6B3	5913 607578	PETR POPOV	{"phone": "+70028851253"}
0005435374759	0AA6B3	1895 650824	NADEZHDA STEPANOVA	{"email": "n_stepanova07041975@postgrespro.ru", "phone": "+70856833331"}
0005435374760	EDC2A5	9211 506054	ULYANA ANDREEVA	{"phone": "+70598169630"}
0005435374761	D3C582	3223 323524	GALINA VASILEVA	{"email": "galina_vasileva-111984@postgrespro.ru", "phone": "+70669713423"}
0005435374762	F323BA	0031 663461	RINAT KUZNECOV	{"email": "r.kuznecov.061989@postgrespro.ru", "phone": "+70893939538"}
0005435374763	F323BA	7982 610117	ALEKSANDR EGOROV	{"phone": "+70098080637"}
0005435374764	C361C8	6518 442017	EVGENIYA SOROKINA	{"phone": "+70497346606"}
0005435374765	74EF31	9277 268727	DINA ZHUKOVA	{"email": "dinazhukova.1961@postgrespro.ru", "phone": "+70875271012"}
0005435374766	97AF18	9500 240716	MAKSIM SEMENOV	{"email": "semenovmaksim.26021964@postgrespro.ru", "phone": "+70648001318"}
0005435374767	9C10E8	7542 617125	MIKHAIL CHERNOV	{"phone": "+70493724427"}
0005435374769	882448	4367 521598	NINA DENISOVA	{"email": "denisova.nina_1968@postgrespro.ru", "phone": "+70781605699"}
0005435374770	8F9F60	6687 156420	IGOR BELOV	{"phone": "+70933520594"}
0005435374771	190063	2536 170654	AZAT KUZNECOV	{"email": "azat_kuznecov031961@postgrespro.ru", "phone": "+70675467365"}
0005435374772	218825	7747 983508	NATALYA ZAKHAROVA	{"phone": "+70632659633"}
0005435374773	4E9A44	4281 444717	NIKITA MATVEEV	{"phone": "+70277575400"}
0005435374774	7A46C7	0632 362363	MIKHAIL PETROV	{"email": "mikhail-petrov.08081969@postgrespro.ru", "phone": "+70620699374"}
0005435374775	7A46C7	1640 503922	MAYYA KUZNECOVA	{"email": "kuznecova-m_051966@postgrespro.ru", "phone": "+70902198990"}
0005435374776	9EDEF6	5869 378696	ANDREY POPOV	{"email": "andrey_popov.1970@postgrespro.ru", "phone": "+70549608856"}
0005435374777	E3D9E4	3632 342932	VYACHESLAV MIKHAYLOV	{"phone": "+70156456242"}
0005435374778	BA1729	7961 380006	VIKTORIYA SOLOVEVA	{"email": "viktoriya-soloveva-1965@postgrespro.ru", "phone": "+70857196199"}
0005435374779	DF5170	4458 010133	NIKOLAY MIRONOV	{"phone": "+70287930664"}
0005435374780	DF5170	1917 062037	ANTON IVANOV	{"email": "anton_ivanov_18091970@postgrespro.ru", "phone": "+70815626500"}
0005435374781	2CA647	5507 421318	NAIL POPOV	{"email": "nailpopov-1966@postgrespro.ru", "phone": "+70058193602"}
0005435374782	2CA647	9106 464675	NATALYA SAVELEVA	{"email": "saveleva_natalya.111979@postgrespro.ru", "phone": "+70276072828"}
0005435374783	AEE54D	7165 484287	TATYANA PETROVA	{"email": "t-petrova.1970@postgrespro.ru", "phone": "+70930224245"}
0005435374784	2043FD	6136 720649	EKATERINA EFREMOVA	{"phone": "+70817748318"}
0005435374785	4E01EC	0417 226638	SERGEY FOMIN	{"phone": "+70199077548"}
0005435374786	011793	8597 633361	NINA SERGEEVA	{"email": "nina-sergeeva_1963@postgrespro.ru", "phone": "+70417447528"}
0005435374787	9EFABD	1855 254609	VLADIMIR IVANOV	{"phone": "+70349706112"}
0005435374788	8C62C4	3634 084181	ANDREY FEDOTOV	{"email": "fedotov-andrey_081971@postgrespro.ru", "phone": "+70602167921"}
0005435374789	664B74	1637 167120	VALENTINA PETROVA	{"phone": "+70159251359"}
0005435374790	23A1D7	8092 815822	IGOR VOLKOV	{"phone": "+70126791160"}
0005435374791	6AB3D3	5487 174327	MIKHAIL PETROV	{"email": "petrovm-1966@postgrespro.ru", "phone": "+70802138191"}
0005435374792	A5FF57	9605 161401	LYUDMILA EGOROVA	{"email": "egorova-lyudmila101969@postgrespro.ru", "phone": "+70482936288"}
0005435374793	A5FF57	4100 320406	EVDOKIYA DMITRIEVA	{"email": "e_dmitrieva_18041965@postgrespro.ru", "phone": "+70393062851"}
0005435374794	E1C57C	1340 288336	OLGA ZAKHAROVA	{"phone": "+70323431731"}
0005435374795	E1C57C	0081 004223	IRINA BELYAEVA	{"email": "i_belyaeva26011989@postgrespro.ru", "phone": "+70785010634"}
0005435374796	9170AD	5159 768190	VLADIMIR VOROBEV	{"phone": "+70274958415"}
0005435374797	47CB14	4490 563562	YURIY TARASOV	{"phone": "+70207272629"}
0005435374798	192D92	7505 318196	EVGENIY TIKHONOV	{"phone": "+70440221171"}
0005435374799	359B68	5978 088780	KSENIYA ANISIMOVA	{"email": "kanisimova_12011968@postgrespro.ru", "phone": "+70574527058"}
0005435374800	359B68	2383 114804	IRAIDA ROMANOVA	{"email": "iraida-romanova10081966@postgrespro.ru", "phone": "+70769149560"}
0005435374801	66A31F	1571 190513	FEDOR KARPOV	{"email": "f.karpov.1982@postgrespro.ru", "phone": "+70966776236"}
0005435374802	66A31F	1537 287557	LYUDMILA SOLOVEVA	{"phone": "+70043345981"}
0005435374803	66A31F	2101 170300	EVGENIYA KUZMINA	{"phone": "+70651682130"}
0005435374804	66A31F	8378 844445	MIKHAIL ILIN	{"email": "mikhail_ilin.01061972@postgrespro.ru", "phone": "+70550378008"}
0005435374805	684BBB	2903 656838	VLADISLAV NIKOLAEV	{"phone": "+70346814651"}
0005435374806	C9779D	9292 950877	TAMARA MIRONOVA	{"email": "t-mironova.18041980@postgrespro.ru", "phone": "+70622137231"}
0005435374807	CD1365	3988 183200	SVETLANA MASLOVA	{"phone": "+70504378290"}
0005435374808	CD1365	3832 441895	VALERIY ORLOV	{"phone": "+70948464020"}
0005435374809	F6F327	8806 041732	LYUBOV FOMINA	{"phone": "+70209844615"}
0005435374810	871823	4158 210054	EVGENIY IVANOV	{"phone": "+70810340752"}
0005435374811	B256EF	4779 750688	ELENA FEDOROVA	{"phone": "+70368254218"}
0005435374812	8CBD05	6107 291025	ALEKSANDR SERGEEV	{"email": "sergeev-a.27021968@postgrespro.ru", "phone": "+70708571353"}
0005435374813	A7741E	4797 133777	MARINA POTAPOVA	{"phone": "+70309641159"}
0005435374814	A7741E	0160 318461	MARIYA NIKIFOROVA	{"email": "mariya_nikiforova_18031974@postgrespro.ru", "phone": "+70742941602"}
0005435374815	E051D9	5874 092815	TATYANA SCHERBAKOVA	{"email": "tscherbakova-30041983@postgrespro.ru", "phone": "+70984121754"}
0005435374816	E051D9	4485 669910	VERA KOVALEVA	{"email": "kovaleva-vera_1964@postgrespro.ru", "phone": "+70673109442"}
0005435374817	83FC61	2870 317500	NATALYA VASILEVA	{"email": "vasileva.natalya.29081978@postgrespro.ru", "phone": "+70737526674"}
0005435374818	83FC61	9471 907306	YULIYA ISAEVA	{"phone": "+70728219870"}
0005435374819	FF9618	3948 177087	VYACHESLAV BORISOV	{"phone": "+70421687674"}
0005435374820	7E52B1	6615 442766	MARIYA MAKSIMOVA	{"email": "mariya-maksimova_091977@postgrespro.ru", "phone": "+70324442282"}
0005435374821	7E52B1	9453 640053	ANTON KOZLOV	{"phone": "+70245830630"}
0005435374822	48613A	3780 884922	SERGEY KUZNECOV	{"phone": "+70221900859"}
0005435374823	48613A	1772 551603	KLAVDIYA ROMANOVA	{"phone": "+70060098482"}
0005435374824	3A1D63	7996 297165	PETR KISELEV	{"email": "kiselev_petr-071968@postgrespro.ru", "phone": "+70353936368"}
0005435374825	81EFC4	5993 873796	ALEKSEY NAZAROV	{"email": "aleksey-nazarov29101975@postgrespro.ru", "phone": "+70387635325"}
0005435374826	81EFC4	5759 565652	ANDREY FOMIN	{"phone": "+70769199838"}
0005435374827	E3AAAC	0338 231544	ALEKSANDR MELNIKOV	{"email": "aleksandr-melnikov_10081969@postgrespro.ru", "phone": "+70473155289"}
0005435374828	8FFC7B	8723 472054	LYUDMILA ZAKHAROVA	{"phone": "+70925601539"}
0005435374829	4D99DA	6593 551382	ELENA NESTEROVA	{"email": "nesterova-e01091970@postgrespro.ru", "phone": "+70233971322"}
0005435374830	E1FAD6	3534 136473	YULIYA KRASNOVA	{"phone": "+70572103752"}
0005435374831	E1FAD6	7964 759294	NATALYA VASILEVA	{"phone": "+70570080979"}
0005435374832	A41C7A	8179 701842	DMITRIY KRASNOV	{"email": "krasnov-dmitriy.16111972@postgrespro.ru", "phone": "+70365400010"}
0005435374833	2F0437	4907 001334	VIKTORIYA GORBUNOVA	{"email": "viktoriya-gorbunova-1966@postgrespro.ru", "phone": "+70683417649"}
0005435374834	A8534B	5124 885164	PETR IVANOV	{"email": "ivanov.petr_23011973@postgrespro.ru", "phone": "+70065171870"}
0005435374835	F5AE18	3301 740716	TATYANA ABRAMOVA	{"phone": "+70634708756"}
0005435374836	594386	8163 959063	YULIYA GERASIMOVA	{"email": "gerasimovayuliya.071972@postgrespro.ru", "phone": "+70078944894"}
0005435374837	5C4182	5598 577225	POLINA KARPOVA	{"phone": "+70836166922"}
0005435374838	8E5353	0332 064115	SVETLANA SERGEEVA	{"phone": "+70767254094"}
0005435374839	144B17	3448 496149	IVAN BARANOV	{"email": "ivan_baranov101966@postgrespro.ru", "phone": "+70570330360"}
0005435374840	144B17	2237 207046	ANASTASIYA TARASOVA	{"phone": "+70558358153"}
0005435374841	144B17	2093 289231	VLADIMIR ISAEV	{"email": "isaev-v.20071974@postgrespro.ru", "phone": "+70545068151"}
0005435374842	C3A183	3950 720442	EKATERINA KOROLEVA	{"phone": "+70604646141"}
0005435374843	C3A183	8213 886946	VERA OVCHINNIKOVA	{"phone": "+70719636268"}
0005435374844	1F0378	0290 027990	DENIS TARASOV	{"phone": "+70662151502"}
0005435374845	9E0DE8	4204 213364	VASILIY MOROZOV	{"email": "morozov.vasiliy11011976@postgrespro.ru", "phone": "+70346685266"}
0005435374846	D087DD	8726 485457	MARIYA VOLKOVA	{"phone": "+70699147218"}
0005435374847	FCE918	2710 636201	VERA NESTEROVA	{"email": "vera.nesterova_1971@postgrespro.ru", "phone": "+70752055475"}
0005435374848	85C3B2	1435 523863	ANASTASIYA SCHERBAKOVA	{"phone": "+70331736592"}
0005435374849	8CCD85	8494 229811	VLADIMIR MOROZOV	{"email": "vladimir_morozov.071971@postgrespro.ru", "phone": "+70840555112"}
0005435374850	939B5E	7427 906594	ROMAN BORISOV	{"phone": "+70798956618"}
0005435374851	254007	8528 683730	ARTEM SCHERBAKOV	{"email": "scherbakov_artem08021973@postgrespro.ru", "phone": "+70989129275"}
0005435374852	774F5C	0204 782086	DMITRIY VASILEV	{"phone": "+70122042594"}
0005435374853	560508	9359 722253	KONSTANTIN MOROZOV	{"email": "morozov_konstantin_121982@postgrespro.ru", "phone": "+70669147359"}
0005435374854	75D421	6508 375952	EVGENIY ZAYCEV	{"phone": "+70173892717"}
0005435374855	E908F2	4281 244150	TATYANA MEDVEDEVA	{"phone": "+70544793583"}
0005435374856	E908F2	6356 922290	ARTEM TIMOFEEV	{"email": "timofeevartem_1982@postgrespro.ru", "phone": "+70438209791"}
0005435374857	4A0FFD	1772 002679	MARIANNA DANILOVA	{"email": "danilovam-1977@postgrespro.ru", "phone": "+70723350203"}
0005435374858	4A0FFD	0225 769759	MARINA ANISIMOVA	{"phone": "+70839701465"}
0005435374859	4A0FFD	2997 320252	ELENA YAKOVLEVA	{"phone": "+70974936804"}
0005435374860	B5022B	4763 844311	ALEKSEY MOISEEV	{"phone": "+70713531210"}
0005435374861	BD7E60	4543 935298	VASILIY CHERNOV	{"email": "chernov_v1977@postgrespro.ru", "phone": "+70910985499"}
0005435374862	BD7E60	9901 348164	ELVIRA KUZNECOVA	{"email": "kuznecovae.10091967@postgrespro.ru", "phone": "+70515780991"}
0005435374863	AA8D5F	4394 992874	LYUDMILA TARASOVA	{"phone": "+70129998618"}
0005435374864	92EE66	0565 883137	LYUDMILA IVANOVA	{"email": "ivanoval_111966@postgrespro.ru", "phone": "+70935804102"}
0005435374865	8FFDA6	9071 209298	ANASTASIYA GAVRILOVA	{"phone": "+70184787631"}
0005435374866	E1BF44	5654 987263	OLGA AFANASEVA	{"email": "oafanaseva.1966@postgrespro.ru", "phone": "+70679096189"}
0005435374867	08DDEC	7006 009655	ANDREY KOROLEV	{"phone": "+70580986462"}
0005435374868	5831A5	7361 043276	ALEKSANDR OSIPOV	{"email": "osipov.a_04081973@postgrespro.ru", "phone": "+70013348541"}
0005435374869	5831A5	3866 229192	MIKHAIL EGOROV	{"email": "egorovmikhail06041984@postgrespro.ru", "phone": "+70061179271"}
0005435374870	401809	0589 390305	IGOR MARTYNOV	{"email": "igor.martynov10081969@postgrespro.ru", "phone": "+70200474205"}
0005435374871	401809	6777 884287	VLADIMIR SERGEEV	{"phone": "+70498066627"}
0005435374872	E0D5FE	3675 781989	BORIS DAVYDOV	{"email": "boris-davydov-061961@postgrespro.ru", "phone": "+70910094484"}
0005435374873	B14D1C	8335 629054	GENNADIY VOLKOV	{"phone": "+70921469379"}
0005435374874	E55770	3805 696296	ARTUR NAUMOV	{"email": "naumov-artur021974@postgrespro.ru", "phone": "+70734552836"}
0005435374875	9FBFE7	1672 616732	DARYA KUZNECOVA	{"email": "kuznecova.d-1972@postgrespro.ru", "phone": "+70757325026"}
0005435374876	9FBFE7	1060 188190	LIDIYA TIKHONOVA	{"email": "lidiya_tikhonova.081968@postgrespro.ru", "phone": "+70636895203"}
0005435374877	836857	8528 575188	ISLAM VOROBEV	{"email": "vorobev_i10121967@postgrespro.ru", "phone": "+70621748304"}
0005435374878	C8556B	8629 851139	KARINA BOGDANOVA	{"email": "bogdanova_k-091976@postgrespro.ru", "phone": "+70746830314"}
0005435374879	0E5066	1099 241106	NATALIYA KUZNECOVA	{"email": "kuznecovanataliya.1968@postgrespro.ru", "phone": "+70387825832"}
0005435374880	6B1652	1825 033633	DANIIL FEDOROV	{"phone": "+70404075939"}
0005435374881	183FAD	2367 244794	RUFINA FILIPPOVA	{"email": "r-filippova-1983@postgrespro.ru", "phone": "+70133933080"}
0005435374882	1E5A1D	0958 537211	ANNA ABRAMOVA	{"email": "abramovaa_1975@postgrespro.ru", "phone": "+70997809321"}
0005435374883	27CE1A	1464 968185	VALENTINA SMIRNOVA	{"email": "smirnova.valentina071968@postgrespro.ru", "phone": "+70738987841"}
0005435374884	F1E89C	8461 921935	ALSU ARKHIPOVA	{"email": "arkhipova_alsu-031975@postgrespro.ru", "phone": "+70820362804"}
0005435374885	11DFE8	2494 177880	NATALYA KOROLEVA	{"email": "koroleva.n.1968@postgrespro.ru", "phone": "+70035084990"}
0005435374886	443491	9112 446462	ALEKSEY MAKAROV	{"phone": "+70605480064"}
0005435374887	F0600F	7862 913021	RENATA BARANOVA	{"email": "baranova.renata-27121968@postgrespro.ru", "phone": "+70635043848"}
0005435374888	A6378C	5627 626468	LIDIYA FROLOVA	{"phone": "+70095320259"}
0005435374889	A6378C	8502 376634	MAKSIM SMIRNOV	{"email": "maksimsmirnov_041972@postgrespro.ru", "phone": "+70278337677"}
0005435374890	F29EFB	4258 790084	TATYANA PAVLOVA	{"phone": "+70165188232"}
0005435374891	C453C3	5403 223365	GENNADIY KUZMIN	{"phone": "+70840463878"}
0005435374892	99F0B1	0280 265808	NADEZHDA GRISHINA	{"email": "nadezhda.grishina.1977@postgrespro.ru", "phone": "+70853989589"}
0005435374893	5FE2D2	2925 869902	DENIS NIKOLAEV	{"phone": "+70643080514"}
0005435374894	5FE2D2	2920 537755	LIDIYA ALEKSANDROVA	{"email": "aleksandrova-lidiya.061969@postgrespro.ru", "phone": "+70277077660"}
0005435374895	C7160F	7652 894726	VYACHESLAV MOROZOV	{"email": "morozov-v.25071987@postgrespro.ru", "phone": "+70093563222"}
0005435374896	FA0622	7092 071796	EVGENIY KUDRYASHOV	{"phone": "+70778110545"}
0005435374897	4A11DD	4438 120770	EVGENIY KOZLOV	{"email": "kozlov-e_1964@postgrespro.ru", "phone": "+70256592479"}
0005435374898	690456	5248 933932	RIMMA IVANOVA	{"email": "ivanovar101963@postgrespro.ru", "phone": "+70935787065"}
0005435374899	690456	8894 981505	MARIYA ANDREEVA	{"phone": "+70010430938"}
0005435374900	690456	9300 097765	ANNA VASILEVA	{"email": "avasileva-051984@postgrespro.ru", "phone": "+70117717388"}
0005435374901	493863	7101 929619	BORIS ZHUKOV	{"email": "bzhukov071970@postgrespro.ru", "phone": "+70164553619"}
0005435374902	493863	3494 937106	NAZIYA ZAYCEVA	{"email": "n_zayceva_1970@postgrespro.ru", "phone": "+70001134524"}
0005435374903	591D2C	1285 269196	ALEKSANDR FOMIN	{"phone": "+70344501996"}
0005435374904	CE90A5	3530 532461	VALENTINA KAZAKOVA	{"phone": "+70321014394"}
0005435374905	CE90A5	5938 892455	RUSLAN KOROLEV	{"phone": "+70817229365"}
0005435374906	0F8638	8690 190177	ALEKSEY ANTONOV	{"phone": "+70060610335"}
0005435374907	F967FB	2178 508278	PAVEL BONDARENKO	{"phone": "+70156044573"}
0005435374908	30A940	1423 255510	GENNADIY ANTONOV	{"email": "antonov.gennadiy061976@postgrespro.ru", "phone": "+70660394788"}
0005435374909	99455B	0797 292162	GALINA KUZMINA	{"phone": "+70557156651"}
0005435374910	7396B6	0065 682363	VLADIMIR KOZLOV	{"email": "kozlov-v011974@postgrespro.ru", "phone": "+70262434297"}
0005435374911	A49BCA	5436 457451	ANASTASIYA IVANOVA	{"phone": "+70741157713"}
0005435374912	A49BCA	7999 592412	TAMARA MASLOVA	{"email": "t_maslova.1971@postgrespro.ru", "phone": "+70802387820"}
0005435374913	2DA276	4832 054678	IVAN VOLKOV	{"email": "volkov-ivan.29061984@postgrespro.ru", "phone": "+70952958706"}
0005435374914	8DA1A5	3753 569833	ANATOLIY VLASOV	{"email": "anatoliy_vlasov.061973@postgrespro.ru", "phone": "+70762048185"}
0005435374915	C96A89	7863 869247	NIKOLAY SOKOLOV	{"email": "nikolay-sokolov_061985@postgrespro.ru", "phone": "+70386170000"}
0005435374916	3F4945	9063 726052	NADEZHDA BORISOVA	{"email": "nadezhda_borisova051978@postgrespro.ru", "phone": "+70352022213"}
0005435374917	53035B	4216 010797	DMITRIY PAVLOV	{"email": "pavlov-d.21071971@postgrespro.ru", "phone": "+70220035367"}
0005435374918	53035B	8676 690132	VLADIMIR SHEVCHENKO	{"phone": "+70916984052"}
0005435374919	53035B	6397 447224	KIRILL FEDOTOV	{"email": "fedotovk_1966@postgrespro.ru", "phone": "+70648689008"}
0005435374920	88C367	0997 523123	ANATOLIY KRASNOV	{"phone": "+70804762387"}
0005435374921	CF2808	2067 870447	VALENTIN VLASOV	{"email": "vlasovv_101976@postgrespro.ru", "phone": "+70365798401"}
0005435374922	4A6372	7602 315069	VLADIMIR FEDOTOV	{"phone": "+70793787692"}
0005435374923	6874A0	5192 217995	VIKTOR OSIPOV	{"email": "viktor-osipov_111967@postgrespro.ru", "phone": "+70084757164"}
0005435374924	6874A0	8085 234424	GALIYA TITOVA	{"email": "titova.galiya.29071972@postgrespro.ru", "phone": "+70850625779"}
0005435374925	D7ED56	1960 068883	YURIY IVANOV	{"email": "ivanov.yuriy-30091966@postgrespro.ru", "phone": "+70229901597"}
0005435374926	5CF6B3	8938 025470	YULIYA EGOROVA	{"phone": "+70212307575"}
0005435374927	5CF6B3	2865 452627	MARIYA GUSEVA	{"email": "mariya_guseva.1967@postgrespro.ru", "phone": "+70706691812"}
0005435374928	419892	1527 741006	EGOR KAZAKOV	{"phone": "+70544232413"}
0005435374929	347716	8140 114911	NIKITA ZAYCEV	{"email": "nikita_zaycev.021974@postgrespro.ru", "phone": "+70668720661"}
0005435374930	431AFF	7060 113517	DMITRIY POPOV	{"email": "popovd_30101965@postgrespro.ru", "phone": "+70123500637"}
0005435374931	48E774	3835 295099	NIKOLAY VASILEV	{"email": "n.vasilev-15101963@postgrespro.ru", "phone": "+70758151140"}
0005435374932	7AD27C	2398 801338	GALINA KOMAROVA	{"email": "galina-komarova.1959@postgrespro.ru", "phone": "+70219212827"}
0005435374933	7AD27C	2951 915372	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.a-1963@postgrespro.ru", "phone": "+70732898107"}
0005435374934	9C647C	5030 671534	GALINA ZAYCEVA	{"phone": "+70438264824"}
0005435374935	8154BD	6201 391540	POLINA KONOVALOVA	{"phone": "+70462067404"}
0005435374936	8154BD	6221 972656	ELENA YUDINA	{"phone": "+70695733393"}
0005435374937	803276	7964 239906	EVGENIYA IVANOVA	{"phone": "+70736210627"}
0005435374938	ED35CC	4395 389184	GALINA ZHURAVLEVA	{"phone": "+70761102034"}
0005435374939	B8A8AC	4980 299142	ALEKSANDR KUZNECOV	{"phone": "+70676523368"}
0005435374940	BFCD7C	8777 750434	SERGEY KONOVALOV	{"phone": "+70955932100"}
0005435374941	BFCD7C	9268 593546	ANDREY PAVLOV	{"phone": "+70153312604"}
0005435374942	8CB39D	7536 152614	SEMEN RODIONOV	{"email": "semen_rodionov-1969@postgrespro.ru", "phone": "+70657372508"}
0005435374943	A22C20	2418 057799	OKSANA MALYSHEVA	{"email": "malysheva-oksana20031965@postgrespro.ru", "phone": "+70134084572"}
0005435374944	A22C20	5593 247765	ULYANA TIKHONOVA	{"phone": "+70218063807"}
0005435374945	20BAD6	9499 931770	EGOR VOLKOV	{"phone": "+70864270163"}
0005435374946	20BAD6	2174 638567	OLEG GRIGOREV	{"email": "oleg_grigorev061981@postgrespro.ru", "phone": "+70836309903"}
0005435374947	1931DB	9160 181887	YULIYA MELNIKOVA	{"phone": "+70637849552"}
0005435374948	1931DB	1518 520531	MARIYA IVANOVA	{"phone": "+70899361450"}
0005435374949	FE8913	5822 955130	DMITRIY IVANOV	{"email": "d.ivanov.041967@postgrespro.ru", "phone": "+70542327555"}
0005435374950	807D92	5364 168094	KIRILL SOKOLOV	{"phone": "+70837634286"}
0005435374951	3C064D	9414 438729	IRINA SOROKINA	{"email": "sorokinai.22011973@postgrespro.ru", "phone": "+70540505621"}
0005435374952	1867F8	7232 774099	SERGEY ANTONOV	{"email": "santonov-19041967@postgrespro.ru", "phone": "+70850975234"}
0005435374953	4F76A1	9816 371238	DMITRIY KUZNECOV	{"phone": "+70421576074"}
0005435374954	6F8458	5622 238919	VIKTOR ZAKHAROV	{"phone": "+70527413185"}
0005435374955	6F8458	4697 946456	ALEKSEY MAKAROV	{"phone": "+70949138714"}
0005435374956	E01877	0568 840785	DANILA POPOV	{"email": "popovdanila.1977@postgrespro.ru", "phone": "+70855162320"}
0005435374957	541702	0937 070143	ANDREY KUDRYASHOV	{"email": "andreykudryashov15041971@postgrespro.ru", "phone": "+70355531874"}
0005435375013	661408	8388 306360	LYUDMILA SOKOLOVA	{"phone": "+70157038893"}
0005435374958	541702	8600 933775	VASILIY GERASIMOV	{"email": "gerasimov_v121969@postgrespro.ru", "phone": "+70451611556"}
0005435374959	ED3D5B	9190 104172	EKATERINA KUZNECOVA	{"phone": "+70087501566"}
0005435374960	ED3D5B	4713 127088	SALAVAT ILIN	{"email": "ilin-s.091969@postgrespro.ru", "phone": "+70507739346"}
0005435374961	1270D0	1195 249750	LILIYA KISELEVA	{"email": "l-kiseleva-101980@postgrespro.ru", "phone": "+70332055013"}
0005435374962	946BCD	3894 528703	NADEZHDA PAVLOVA	{"phone": "+70006420796"}
0005435374963	4953B9	4962 474324	NIKITA DAVYDOV	{"phone": "+70224097773"}
0005435374964	A9FEC0	0670 974629	LIDIYA NIKITINA	{"email": "lidiya.nikitina_1968@postgrespro.ru", "phone": "+70806148782"}
0005435374965	BBE276	4885 660305	LYUDMILA DAVYDOVA	{"email": "davydova-lyudmila1972@postgrespro.ru", "phone": "+70766324169"}
0005435374966	3D44FB	8298 177166	EVDOKIYA LEBEDEVA	{"email": "e-lebedeva.24121979@postgrespro.ru", "phone": "+70118672709"}
0005435374967	4453D1	5509 504773	IRINA MAKAROVA	{"email": "irina.makarova13071980@postgrespro.ru", "phone": "+70661366731"}
0005435374968	361461	1701 188597	IRINA GERASIMOVA	{"phone": "+70514920634"}
0005435374969	5CEAC7	6087 776918	SERGEY SCHERBAKOV	{"email": "s.scherbakov.1973@postgrespro.ru", "phone": "+70279601404"}
0005435374970	DEBFD9	5309 096970	IRINA KOROLEVA	{"phone": "+70901704455"}
0005435374971	E6AAEC	1043 598417	KSENIYA MEDVEDEVA	{"phone": "+70547856919"}
0005435374972	E6AAEC	9359 154600	LYUBOV KOROLEVA	{"phone": "+70096082446"}
0005435374973	3C37DF	4983 662693	EKATERINA MAKAROVA	{"email": "makarova.ekaterina-26021965@postgrespro.ru", "phone": "+70558155987"}
0005435374974	1EFED0	7212 490785	ANNA KOROLEVA	{"email": "korolevaanna_12011977@postgrespro.ru", "phone": "+70137868421"}
0005435374975	F21EAE	2082 500146	PETR ABRAMOV	{"email": "abramov-petr.24011966@postgrespro.ru", "phone": "+70778378031"}
0005435374976	F21EAE	4246 060878	ELENA IVANOVA	{"email": "e_ivanova.021969@postgrespro.ru", "phone": "+70022359769"}
0005435374977	39E4A5	2740 765311	OLGA KRASNOVA	{"phone": "+70556009609"}
0005435374978	3CF998	8969 442511	ANATOLIY TARASOV	{"email": "anatoliy_tarasov22091971@postgrespro.ru", "phone": "+70295899182"}
0005435374979	64D026	0618 159615	ANASTASIYA KOZLOVA	{"phone": "+70866656676"}
0005435374980	64D026	5033 127299	NATALYA DAVYDOVA	{"phone": "+70193497310"}
0005435374981	228F83	3329 573113	NATALYA PAVLOVA	{"phone": "+70846850043"}
0005435374982	09FFDB	0684 086079	ALEKSANDR POPOV	{"phone": "+70590141206"}
0005435374983	FDC935	5084 388447	ALEKSANDRA VOROBEVA	{"email": "a_vorobeva.031973@postgrespro.ru", "phone": "+70637704636"}
0005435374984	376BD7	0293 578315	POLINA IVANOVA	{"phone": "+70653122232"}
0005435374985	376BD7	4375 075235	NELLYA SCHERBAKOVA	{"phone": "+70797917559"}
0005435374986	44CBFF	0457 403880	EKATERINA SCHERBAKOVA	{"phone": "+70839466682"}
0005435374987	44CBFF	1246 950991	ANNA MARTYNOVA	{"email": "martynovaa-121969@postgrespro.ru", "phone": "+70788054582"}
0005435374988	C97BA2	5878 250764	VLADIMIR SEMENOV	{"email": "semenov_vladimir.041966@postgrespro.ru", "phone": "+70300440517"}
0005435374989	C97BA2	8582 685433	ALEKSANDR ANDREEV	{"phone": "+70479954032"}
0005435374990	9404E7	5787 237342	VLADIMIR EGOROV	{"email": "egorovv-1977@postgrespro.ru", "phone": "+70485743241"}
0005435374991	63167B	9898 634307	MAYYA VOROBEVA	{"email": "vorobeva_mayya.011974@postgrespro.ru", "phone": "+70101361326"}
0005435374992	3CCBAA	1197 276212	SVETLANA ANTONOVA	{"phone": "+70455722239"}
0005435374993	52340A	5573 333177	NATALYA ILINA	{"phone": "+70191913565"}
0005435374994	D706FF	3366 829333	VYACHESLAV YAKOVLEV	{"email": "yakovlevvyacheslav.04101962@postgrespro.ru", "phone": "+70471056453"}
0005435374995	27FAD8	2800 596094	DANIIL BARANOV	{"email": "d_baranov_1965@postgrespro.ru", "phone": "+70405564106"}
0005435374996	27FAD8	8243 926398	SVETLANA SMIRNOVA	{"email": "ssmirnova_18081974@postgrespro.ru", "phone": "+70979506671"}
0005435374997	DE30A2	1216 629491	VLADIMIR ZAYCEV	{"email": "zaycev_v.10101973@postgrespro.ru", "phone": "+70510631911"}
0005435374998	DE30A2	6263 316226	OLGA BORISOVA	{"phone": "+70216661055"}
0005435374999	4E2DCB	7083 432496	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.041970@postgrespro.ru", "phone": "+70476793439"}
0005435375000	4E2DCB	5508 321651	SERGEY ZAKHAROV	{"email": "szakharov.111976@postgrespro.ru", "phone": "+70059600786"}
0005435375001	E19C04	7312 215005	SERGEY SCHERBAKOV	{"email": "scherbakovs-10101975@postgrespro.ru", "phone": "+70503337952"}
0005435375002	5119C4	7539 438035	NATALYA KOZLOVA	{"email": "natalya_kozlova_03011963@postgrespro.ru", "phone": "+70888635733"}
0005435375003	AA3501	4605 421815	YURIY ZHURAVLEV	{"email": "y-zhuravlev-021967@postgrespro.ru", "phone": "+70699978779"}
0005435375004	551660	9021 804005	ANNA NIKIFOROVA	{"email": "nikiforova-anna_071957@postgrespro.ru", "phone": "+70054118720"}
0005435375005	652327	8560 081915	VLADIMIR DENISOV	{"email": "v.denisov_071955@postgrespro.ru", "phone": "+70862365959"}
0005435375065	D30C78	1536 907132	NATALYA ZHUKOVA	{"phone": "+70276071274"}
0005435375006	652327	9167 996194	NIKOLAY ZHUKOV	{"email": "n_zhukov111977@postgrespro.ru", "phone": "+70145791926"}
0005435375007	D440A6	3217 673950	VALENTINA FADEEVA	{"phone": "+70815946279"}
0005435375008	6748E5	0145 364308	EVGENIYA KUZNECOVA	{"email": "evgeniya_kuznecova1971@postgrespro.ru", "phone": "+70628284164"}
0005435375009	6748E5	2894 065287	LARISA IVANOVA	{"email": "l_ivanova.091979@postgrespro.ru", "phone": "+70680801441"}
0005435375010	A85BEE	5000 669163	VIKTOR SMIRNOV	{"email": "smirnov-viktor1971@postgrespro.ru", "phone": "+70651270003"}
0005435375011	17A61A	9836 440344	LYUBOV ANTONOVA	{"phone": "+70734301932"}
0005435375012	B026B8	5605 547513	NATALIYA ANDREEVA	{"phone": "+70541607245"}
0005435375014	CA20A3	0813 589929	VENERA GORBUNOVA	{"phone": "+70499700486"}
0005435375015	4DE89D	7403 878167	RUSLAN STEPANOV	{"email": "ruslan_stepanov121972@postgrespro.ru", "phone": "+70311736809"}
0005435375016	3B78FF	1204 525896	EDUARD ALEKSANDROV	{"email": "aleksandroveduard_1973@postgrespro.ru", "phone": "+70091272221"}
0005435375017	3B78FF	9759 629736	EKATERINA SEMENOVA	{"email": "ekaterina_semenova1976@postgrespro.ru", "phone": "+70887965464"}
0005435375018	248FB0	3309 398483	GALINA BARANOVA	{"phone": "+70277307834"}
0005435375019	546CB1	2122 090967	ALEKSEY ANDREEV	{"email": "andreeva.16101966@postgrespro.ru", "phone": "+70289490356"}
0005435375020	546CB1	2109 275767	OLEG KUZNECOV	{"email": "kuznecov-oleg11061978@postgrespro.ru", "phone": "+70545337589"}
0005435375021	31D29C	0818 891667	SVETLANA IVANOVA	{"email": "s.ivanova.081961@postgrespro.ru", "phone": "+70059270525"}
0005435375022	63743B	2944 899470	RAIL MARTYNOV	{"email": "rail_martynov_06011974@postgrespro.ru", "phone": "+70032336379"}
0005435375023	D0712D	2724 278294	GALINA KONOVALOVA	{"email": "g-konovalova.28011978@postgrespro.ru", "phone": "+70347164492"}
0005435375024	D178BA	3357 244444	VIKTOR RODIONOV	{"phone": "+70945441297"}
0005435375025	D178BA	6222 276900	LILIYA ORLOVA	{"phone": "+70867638390"}
0005435375026	C4605F	8971 252816	ALEKSANDR POPOV	{"phone": "+70798175024"}
0005435375027	7EED5B	5932 449821	ELENA KAZAKOVA	{"email": "kazakova-elena_111970@postgrespro.ru", "phone": "+70373229405"}
0005435375028	B44642	9706 552810	OKSANA IVANOVA	{"email": "ivanovaoksana_051970@postgrespro.ru", "phone": "+70641392497"}
0005435375029	A4CE35	3336 635400	ALEKSANDR PETROV	{"email": "petrov_a-23031964@postgrespro.ru", "phone": "+70155130113"}
0005435375030	A4CE35	1060 942786	ROSTISLAV POPOV	{"email": "popov_r-061978@postgrespro.ru", "phone": "+70324626940"}
0005435375031	A4CE35	2787 488323	SERGEY GERASIMOV	{"phone": "+70500538108"}
0005435375032	8DF5CD	9204 447505	ANNA KUZNECOVA	{"email": "kuznecova-anna_16121981@postgrespro.ru", "phone": "+70909983099"}
0005435375033	8DF5CD	8992 472854	MARINA OVCHINNIKOVA	{"email": "m-ovchinnikova-1971@postgrespro.ru", "phone": "+70272037352"}
0005435375034	01AB0A	4019 023022	LARISA KUZNECOVA	{"email": "kuznecova_larisa_29091971@postgrespro.ru", "phone": "+70011477788"}
0005435375035	01AB0A	5053 754999	ALEKSEY TIMOFEEV	{"email": "timofeevaleksey_091973@postgrespro.ru", "phone": "+70045884339"}
0005435375036	01AB0A	7317 137377	DMITRIY ZAKHAROV	{"email": "dmitriy-zakharov_061974@postgrespro.ru", "phone": "+70275395449"}
0005435375037	09DBD9	8334 825879	EVGENIYA VASILEVA	{"email": "vasileva-evgeniya1977@postgrespro.ru", "phone": "+70574490377"}
0005435375038	2805BD	8421 635795	IGOR NIKITIN	{"phone": "+70882140259"}
0005435375039	4265DA	7587 511430	VALENTINA POPOVA	{"email": "valentina-popova1969@postgrespro.ru", "phone": "+70681962047"}
0005435375040	4265DA	7166 745184	EVGENIY ALEKSANDROV	{"phone": "+70873673264"}
0005435375041	0A6119	2436 019983	ELENA YUDINA	{"email": "yudina.e21031966@postgrespro.ru", "phone": "+70265935513"}
0005435375042	0A6119	5709 816093	SERGEY DAVYDOV	{"email": "sergey-davydov041963@postgrespro.ru", "phone": "+70157345816"}
0005435375043	0A6119	6660 029425	DENIS KARPOV	{"email": "d_karpov_011973@postgrespro.ru", "phone": "+70785139621"}
0005435375044	0A6119	8179 433815	NINA FADEEVA	{"phone": "+70866028732"}
0005435375045	0D1E94	6184 288528	SVETLANA FILIPPOVA	{"phone": "+70556214434"}
0005435375046	7B038F	7542 313812	LYUBOV ANISIMOVA	{"email": "anisimova-l29061979@postgrespro.ru", "phone": "+70921280862"}
0005435375047	B85877	2042 536633	NATALYA POLYAKOVA	{"phone": "+70428920123"}
0005435375048	B85877	4496 480458	TAMARA KONOVALOVA	{"phone": "+70099675393"}
0005435375049	01021B	6695 006807	LIDIYA KUZMINA	{"phone": "+70096380795"}
0005435375050	01021B	7095 468069	VERONIKA NIKOLAEVA	{"phone": "+70265027768"}
0005435375051	01021B	3703 951075	ANNA KULIKOVA	{"email": "annakulikova.101967@postgrespro.ru", "phone": "+70506167748"}
0005435375052	4849AD	2513 055354	ELENA RODIONOVA	{"email": "rodionova.e17101958@postgrespro.ru", "phone": "+70919580175"}
0005435375053	59190D	1569 323182	IGOR GERASIMOV	{"email": "gerasimov.igor031964@postgrespro.ru", "phone": "+70226866747"}
0005435375054	25EC8E	8894 918812	ROBERT ZAKHAROV	{"phone": "+70882702113"}
0005435375055	B500B8	7404 811507	TATYANA NIKIFOROVA	{"phone": "+70209092405"}
0005435375056	277925	5936 162197	ROMAN ZAKHAROV	{"email": "rzakharov1964@postgrespro.ru", "phone": "+70232226275"}
0005435375057	277925	5417 999368	ANASTASIYA FOMINA	{"phone": "+70094425265"}
0005435375058	00107C	4309 997574	YULIYA KUDRYASHOVA	{"phone": "+70237513571"}
0005435375059	731361	3944 334888	OLGA KULIKOVA	{"phone": "+70304601235"}
0005435375060	6CD9CB	1327 445810	VALERIY KUZMIN	{"email": "kuzmin.valeriy04041969@postgrespro.ru", "phone": "+70904646984"}
0005435375061	6CD9CB	9114 033654	DENIS SMIRNOV	{"phone": "+70875110044"}
0005435375062	6CD9CB	9571 726221	ALEKSEY SMIRNOV	{"email": "a.smirnov-22011963@postgrespro.ru", "phone": "+70169843337"}
0005435375063	D30C78	2188 006098	ALEKSANDR ALEKSEEV	{"email": "alekseev.a-11051978@postgrespro.ru", "phone": "+70068027181"}
0005435375064	D30C78	6359 162743	ALEKSANDR POPOV	{"email": "aleksandr_popov12051973@postgrespro.ru", "phone": "+70808849289"}
0005435375066	4EB898	7332 280884	ALEKSANDR SIDOROV	{"phone": "+70034067415"}
0005435375067	285E54	5615 744456	MARIYA OSIPOVA	{"phone": "+70134553184"}
0005435375068	285E54	2841 619387	ELIZAVETA KONOVALOVA	{"phone": "+70843249434"}
0005435375181	1BBCD7	6608 192286	OLEG BORISOV	{"phone": "+70882850602"}
0005435375069	E33D06	6867 772168	TATYANA TIKHONOVA	{"email": "tikhonova.tatyana-031971@postgrespro.ru", "phone": "+70417065025"}
0005435375070	D73D2A	8697 461719	MIKHAIL MARTYNOV	{"phone": "+70138268972"}
0005435375071	7AB333	8980 248364	SERGEY CHERNOV	{"email": "chernovs-24091973@postgrespro.ru", "phone": "+70542706032"}
0005435375072	7EC7D2	9668 526918	PELAGEYA MARTYNOVA	{"email": "p-martynova_1979@postgrespro.ru", "phone": "+70563902025"}
0005435375073	CEA8F0	1368 438713	DIANA MAKAROVA	{"phone": "+70489780764"}
0005435375074	0FDB1D	9098 654149	DANIIL MAKAROV	{"email": "makarov_daniil-06021966@postgrespro.ru", "phone": "+70466028170"}
0005435375075	0FDB1D	9317 021706	EKATERINA ZAYCEVA	{"email": "ezayceva1969@postgrespro.ru", "phone": "+70810783058"}
0005435375076	DB1B45	7716 132309	ANASTASIYA BOGDANOVA	{"phone": "+70228649296"}
0005435375077	DB1B45	3795 212990	GALINA CHERNOVA	{"phone": "+70749818937"}
0005435375078	69C56D	5487 835194	ALEKSANDR MOISEEV	{"email": "a.moiseev14061985@postgrespro.ru", "phone": "+70697166452"}
0005435375079	C4D9FA	6364 543681	NIKOLAY GERASIMOV	{"phone": "+70406146350"}
0005435375080	E93CBC	5286 226181	MARIYA TARASOVA	{"email": "tarasovamariya1961@postgrespro.ru", "phone": "+70685532006"}
0005435375081	54EBF4	5346 284239	MARIYA DMITRIEVA	{"email": "dmitrieva.mariya.05011967@postgrespro.ru", "phone": "+70394852036"}
0005435375082	8724B4	7259 556760	ARTEM MATVEEV	{"phone": "+70029295664"}
0005435375083	75C6F7	8675 220935	MARINA SCHERBAKOVA	{"email": "scherbakovam-1979@postgrespro.ru", "phone": "+70841818513"}
0005435375084	75C6F7	5635 347617	ROMAN IVANOV	{"phone": "+70822079635"}
0005435375085	75C6F7	0635 617830	NINA POPOVA	{"phone": "+70536378823"}
0005435375086	6455C0	3807 205121	ALEKSANDR SIDOROV	{"email": "sidorov_a25011972@postgrespro.ru", "phone": "+70301668301"}
0005435375087	83F960	7260 277937	IVAN ABRAMOV	{"phone": "+70348048155"}
0005435375088	83F960	8441 098108	OLEG BORISOV	{"phone": "+70415053348"}
0005435375089	021940	4013 933439	VLADIMIR NIKITIN	{"email": "vladimir-nikitin.1972@postgrespro.ru", "phone": "+70167251609"}
0005435375090	AC2F2E	9142 617126	YURIY SERGEEV	{"email": "ysergeev-24021979@postgrespro.ru", "phone": "+70954350426"}
0005435375091	12D2E5	5435 975769	ALEKSANDR NIKITIN	{"phone": "+70283548257"}
0005435375092	E97632	8794 326953	NATALYA STEPANOVA	{"phone": "+70719104912"}
0005435375093	EBBDE0	3634 625943	MAKSIM POPOV	{"email": "popov.maksim_1974@postgrespro.ru", "phone": "+70677837911"}
0005435375094	EB4EEE	3604 753047	GALIYA ILINA	{"phone": "+70877444177"}
0005435375095	F4751A	3509 622099	LYUDMILA MELNIKOVA	{"phone": "+70252414043"}
0005435375096	83F780	9569 593495	VLADIMIR ANDREEV	{"email": "vladimir_andreev-11031981@postgrespro.ru", "phone": "+70580569247"}
0005435375097	83F780	7536 191123	LYUDMILA MARTYNOVA	{"email": "l_martynova_011973@postgrespro.ru", "phone": "+70629258282"}
0005435375098	83F780	3443 254773	LIDIYA SMIRNOVA	{"email": "lidiya_smirnova1981@postgrespro.ru", "phone": "+70532650421"}
0005435375099	342528	9926 212668	VENERA NESTEROVA	{"email": "nesterova-v29111965@postgrespro.ru", "phone": "+70355845902"}
0005435375100	7B9F8E	0051 195164	DENIS MAKAROV	{"email": "makarovdenis.021970@postgrespro.ru", "phone": "+70181513630"}
0005435375101	DC2B09	5174 957663	VIKTOR KUZNECOV	{"email": "viktor-kuznecov-07121967@postgrespro.ru", "phone": "+70968480628"}
0005435375102	8804A1	7081 728811	VYACHESLAV NOVIKOV	{"email": "novikov_vyacheslav.021975@postgrespro.ru", "phone": "+70724946084"}
0005435375103	1D75AF	8637 920232	TATYANA TITOVA	{"email": "titova-t.05011982@postgrespro.ru", "phone": "+70409126739"}
0005435375104	754EF4	0782 771520	ALEKSEY TIKHONOV	{"phone": "+70084199081"}
0005435375105	754EF4	2791 162877	ILYA FILIPPOV	{"email": "filippov.ilya_021993@postgrespro.ru", "phone": "+70146679900"}
0005435375106	354572	3180 574261	DENIS VOROBEV	{"phone": "+70806777903"}
0005435375107	E2AF46	8736 539670	SVETLANA SEMENOVA	{"phone": "+70348714330"}
0005435375108	0BF151	3387 252771	SVETLANA KOZLOVA	{"email": "svetlanakozlova031980@postgrespro.ru", "phone": "+70368374184"}
0005435375109	BBCB5E	4761 685245	NIKOLAY SEMENOV	{"email": "nikolay-semenov.041967@postgrespro.ru", "phone": "+70887411765"}
0005435375110	9FBB5F	6356 956037	OLEG EGOROV	{"email": "egorov-oleg.21021983@postgrespro.ru", "phone": "+70616907374"}
0005435375111	FD0C7B	5618 993328	NATALYA VASILEVA	{"email": "nvasileva03101973@postgrespro.ru", "phone": "+70902771493"}
0005435375112	FD0C7B	9423 815100	VALENTINA IVANOVA	{"phone": "+70873989473"}
0005435375113	26BFB7	4922 801996	LIDIYA ANTONOVA	{"email": "l_antonova.111964@postgrespro.ru", "phone": "+70633552950"}
0005435375114	74309D	9644 355028	ELENA SOROKINA	{"phone": "+70178936496"}
0005435375115	6D2087	2929 797122	ELENA LOGINOVA	{"email": "loginova.elena.1976@postgrespro.ru", "phone": "+70643879625"}
0005435375116	6D2087	6337 965593	NIKOLAY ROMANOV	{"phone": "+70647130623"}
0005435375117	C51D05	7214 248137	ILYA SOKOLOV	{"phone": "+70191443775"}
0005435375118	C51D05	1300 368090	KIRILL VASILEV	{"phone": "+70132005057"}
0005435375119	C51D05	9219 431576	LYUBOV KUZNECOVA	{"email": "kuznecova.lyubov.1974@postgrespro.ru", "phone": "+70789981905"}
0005435375120	991F83	4966 786014	TATYANA KOVALEVA	{"email": "kovaleva_t.1974@postgrespro.ru", "phone": "+70360741179"}
0005435375121	4220F7	3054 210373	NADEZHDA SMIRNOVA	{"email": "smirnovan.1961@postgrespro.ru", "phone": "+70058672200"}
0005435375122	4220F7	7396 545601	VITALIY BORISOV	{"phone": "+70045913844"}
0005435375123	46781D	8072 977498	NATALYA POLYAKOVA	{"phone": "+70890348360"}
0005435376371	96A5E6	0931 582508	ALEKSANDR TARASOV	{"phone": "+70490315561"}
0005435375124	5A0297	8567 816465	OLGA SOLOVEVA	{"email": "olga_soloveva_1973@postgrespro.ru", "phone": "+70784450130"}
0005435375125	5A0297	6077 768214	ANGELINA KOZLOVA	{"email": "angelina.kozlova.1963@postgrespro.ru", "phone": "+70643167197"}
0005435375126	03DBAC	0690 507825	MIKHAIL GAVRILOV	{"phone": "+70433119727"}
0005435375127	03DBAC	8325 742548	EVGENIY NIKOLAEV	{"phone": "+70958311589"}
0005435375128	1E82E0	1165 954835	LYUBOV IVANOVA	{"email": "ivanova-l_1981@postgrespro.ru", "phone": "+70825463647"}
0005435375129	063D38	9163 948177	DMITRIY MAKAROV	{"email": "makarov_d-27041974@postgrespro.ru", "phone": "+70194099258"}
0005435375130	063D38	5595 101510	VIKTOR NAUMOV	{"email": "v_naumov_1963@postgrespro.ru", "phone": "+70983287045"}
0005435375131	063D38	0995 216423	ANNA ROMANOVA	{"email": "a-romanova.091972@postgrespro.ru", "phone": "+70307063124"}
0005435375132	3B0660	9181 620796	EVGENIYA SOROKINA	{"email": "evgeniya-sorokina-15061967@postgrespro.ru", "phone": "+70061721850"}
0005435375133	176880	2714 340991	ALEKSANDR SERGEEV	{"phone": "+70242349139"}
0005435375134	4724DB	2976 782039	EKATERINA LEBEDEVA	{"phone": "+70736747703"}
0005435375135	8A60D7	7655 492371	ANASTASIYA ISAEVA	{"phone": "+70448893967"}
0005435375136	0DFAE3	2549 411754	ALEKSANDR ILIN	{"email": "ilin-aleksandr_01111977@postgrespro.ru", "phone": "+70023866902"}
0005435375137	D767AC	8465 650208	DMITRIY KUZNECOV	{"phone": "+70880625521"}
0005435375138	B78A40	6726 196343	ALEKSANDR GORBUNOV	{"email": "a.gorbunov061961@postgrespro.ru", "phone": "+70949942210"}
0005435375139	183326	0650 543770	EVGENIY KUDRYASHOV	{"email": "evgeniykudryashov_091967@postgrespro.ru", "phone": "+70694145940"}
0005435375140	CE7B0A	3010 233835	VALERIY MIRONOV	{"phone": "+70207737307"}
0005435375141	F6D124	3337 667581	DENIS KUZNECOV	{"phone": "+70921689767"}
0005435375142	187F26	7401 593771	ANASTASIYA PETROVA	{"phone": "+70170213285"}
0005435375143	43B439	4430 098803	MARINA STEPANOVA	{"phone": "+70795408669"}
0005435375144	F23E23	9735 988071	ANASTASIYA PAVLOVA	{"phone": "+70587750467"}
0005435375145	F23E23	6907 304559	VALENTINA ALEKSANDROVA	{"email": "v_aleksandrova.1984@postgrespro.ru", "phone": "+70960408835"}
0005435375146	23D4E9	4805 750545	ILDAR KULIKOV	{"phone": "+70507884996"}
0005435375147	A99C5D	3347 081157	IGOR ILIN	{"phone": "+70654660163"}
0005435375148	19BD19	1971 116134	VERA KOROLEVA	{"phone": "+70967772539"}
0005435375149	19BD19	1811 491726	ANATOLIY DMITRIEV	{"email": "anatoliy.dmitriev-16121981@postgrespro.ru", "phone": "+70019007211"}
0005435375150	F3EDF3	1394 076662	NIKOLAY ORLOV	{"phone": "+70822465546"}
0005435375151	196480	5024 368974	SVETLANA TIMOFEEVA	{"phone": "+70675055245"}
0005435375152	629FB3	8098 850608	MIKHAIL BELOV	{"email": "m-belov_061975@postgrespro.ru", "phone": "+70704466958"}
0005435375153	03A235	2320 558859	EVGENIYA DENISOVA	{"phone": "+70405035138"}
0005435375154	03A235	0325 801736	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov.101977@postgrespro.ru", "phone": "+70924505759"}
0005435375155	E4DA5C	0852 470493	EVGENIY TIMOFEEV	{"email": "timofeev-e.04051962@postgrespro.ru", "phone": "+70101810398"}
0005435375156	E4DA5C	6927 482787	MARIYA SOLOVEVA	{"email": "m-soloveva.17091960@postgrespro.ru", "phone": "+70455356304"}
0005435375157	872C0B	7791 507091	DANIYA SOKOLOVA	{"phone": "+70421261429"}
0005435375158	872C0B	5954 396884	DINARA IVANOVA	{"email": "ivanova.dinara_1975@postgrespro.ru", "phone": "+70900830542"}
0005435375159	872C0B	7506 539008	TATYANA NOVIKOVA	{"email": "novikova_t.1977@postgrespro.ru", "phone": "+70753824613"}
0005435375160	C2DB59	9646 713547	DMITRIY BONDARENKO	{"email": "dmitriy.bondarenko-09061969@postgrespro.ru", "phone": "+70484556679"}
0005435375161	C2DB59	6671 399755	ELENA KOVALEVA	{"phone": "+70516607532"}
0005435375162	79CDE5	3637 521621	LYUDMILA VASILEVA	{"email": "lyudmila_vasileva_22021973@postgrespro.ru", "phone": "+70066638265"}
0005435375163	7B4F38	2290 328610	ALEKSEY KULIKOV	{"email": "kulikov-a.13081969@postgrespro.ru", "phone": "+70208138398"}
0005435375164	0E0EC4	9336 665981	MARIYA ZHUKOVA	{"email": "mariya.zhukova-03021963@postgrespro.ru", "phone": "+70306630145"}
0005435375165	8D04F1	5039 677168	ALENA ROMANOVA	{"email": "romanova-a.25031975@postgrespro.ru", "phone": "+70443505797"}
0005435375166	8D04F1	9610 391670	NINA ORLOVA	{"email": "n-orlova-1970@postgrespro.ru", "phone": "+70457579165"}
0005435375167	6D24B6	6564 636987	YULIYA GERASIMOVA	{"email": "yuliya.gerasimova_1973@postgrespro.ru", "phone": "+70138403498"}
0005435375168	BBC995	2521 976810	VLADIMIR SOKOLOV	{"phone": "+70011956282"}
0005435375169	BBC995	1162 422790	SERGEY IVANOV	{"email": "sergey.ivanov061971@postgrespro.ru", "phone": "+70971062675"}
0005435375170	480310	4636 392374	ALEKSANDR YAKOVLEV	{"phone": "+70674901542"}
0005435375171	480310	7293 467889	ILMIRA MAKAROVA	{"email": "makarova.ilmira_26071972@postgrespro.ru", "phone": "+70505516976"}
0005435375172	480310	4702 924429	SVETLANA NAZAROVA	{"phone": "+70493607931"}
0005435375173	5500B6	6221 442168	OLGA ALEKSEEVA	{"phone": "+70552208970"}
0005435375174	B26D07	3413 786779	SVETLANA EFREMOVA	{"phone": "+70786598105"}
0005435375175	999340	6969 162514	VERA ZHUKOVA	{"email": "v-zhukova.071968@postgrespro.ru", "phone": "+70976837672"}
0005435375176	999340	4587 935147	ILYA SMIRNOV	{"phone": "+70272066330"}
0005435375177	999340	2119 120120	RUSLAN IVANOV	{"phone": "+70104887027"}
0005435375178	291443	0310 083591	KSENIYA SCHERBAKOVA	{"phone": "+70497110574"}
0005435375179	BDA65F	5175 084165	ALEKSANDR KRASNOV	{"email": "krasnov_aleksandr051964@postgrespro.ru", "phone": "+70622723706"}
0005435375180	4F9175	1621 205676	ALEKSEY IVANOV	{"phone": "+70941884567"}
0005435375182	1BBCD7	7073 247057	ANASTASIYA VOLKOVA	{"phone": "+70741372232"}
0005435376312	73E94B	9553 715802	PAVEL IVANOV	{"phone": "+70243764042"}
0005435376313	1F1DF4	2635 521486	PETR PETROV	{"email": "petrov_p_24091975@postgrespro.ru", "phone": "+70835731677"}
0005435376314	92724D	6689 696995	ALEKSANDR VLASOV	{"email": "a_vlasov091965@postgrespro.ru", "phone": "+70738540605"}
0005435376315	B5841C	9981 922756	ANDREY YAKOVLEV	{"phone": "+70654070217"}
0005435376316	673E4E	0843 810496	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr-081972@postgrespro.ru", "phone": "+70679902489"}
0005435376317	673E4E	9854 426282	KAMIL OSIPOV	{"phone": "+70007868449"}
0005435376318	1CC07B	6784 199072	LIDIYA MARTYNOVA	{"email": "martynova_l-15021976@postgrespro.ru", "phone": "+70487560645"}
0005435376319	C8D628	4736 016309	ELENA MAKAROVA	{"phone": "+70292451705"}
0005435376320	AC6C21	8683 868535	OLGA MAKSIMOVA	{"phone": "+70492606401"}
0005435376321	7A1D0D	4268 833827	VALENTINA SIDOROVA	{"phone": "+70095330634"}
0005435376322	16171C	4266 595648	TAMARA NESTEROVA	{"email": "t-nesterova.091976@postgrespro.ru", "phone": "+70125678414"}
0005435376323	1E1C93	4680 526483	ALEKSANDR BONDARENKO	{"email": "bondarenko_a_121975@postgrespro.ru", "phone": "+70189731763"}
0005435376324	1E1C93	6055 988586	ALEKSANDR NAUMOV	{"email": "aleksandr.naumov_061974@postgrespro.ru", "phone": "+70403574883"}
0005435376325	78F0FF	6482 370025	ANNA FEDOROVA	{"email": "a_fedorova.1971@postgrespro.ru", "phone": "+70752340073"}
0005435376326	D8EBB4	8832 909664	RADIK PETROV	{"email": "petrovradik.1983@postgrespro.ru", "phone": "+70856378849"}
0005435376327	D8EBB4	4170 190194	IVAN FOMIN	{"phone": "+70541691984"}
0005435376328	0FC847	4288 431739	SERAFIMA KUZNECOVA	{"phone": "+70930519049"}
0005435376329	FD1E53	9079 596162	NIKITA GERASIMOV	{"email": "n.gerasimov_041979@postgrespro.ru", "phone": "+70446804346"}
0005435376330	B005C5	5913 270920	ALISA MATVEEVA	{"phone": "+70919449518"}
0005435376331	EC30CF	9236 832693	TATYANA FEDOROVA	{"phone": "+70112821723"}
0005435376332	EC30CF	6588 409486	ZULFIYA VASILEVA	{"phone": "+70956924485"}
0005435376333	FF5447	0375 280649	LARISA BELYAEVA	{"email": "larisabelyaeva.071971@postgrespro.ru", "phone": "+70681433479"}
0005435376334	FF5447	2580 709697	ELIZAVETA IVANOVA	{"email": "eivanova.1969@postgrespro.ru", "phone": "+70542962759"}
0005435376335	AFF39E	4504 056718	DARYA MIKHAYLOVA	{"phone": "+70442631793"}
0005435376336	4C4339	7744 689558	ALEKSANDRA OSIPOVA	{"email": "aleksandra_osipova-1972@postgrespro.ru", "phone": "+70438112972"}
0005435376337	AD722B	4390 170885	YULIYA EFIMOVA	{"email": "efimova_yuliya29071973@postgrespro.ru", "phone": "+70146039474"}
0005435376338	AD722B	9909 352459	NINA GERASIMOVA	{"email": "gerasimovanina011968@postgrespro.ru", "phone": "+70832269202"}
0005435376339	AD722B	9971 661002	TATYANA EGOROVA	{"email": "tatyana.egorova_19031966@postgrespro.ru", "phone": "+70803807202"}
0005435376340	310F4A	9312 361353	VALENTINA BORISOVA	{"email": "valentina_borisova-021963@postgrespro.ru", "phone": "+70375901127"}
0005435376341	634C74	9655 356613	DANIIL KRASNOV	{"phone": "+70890996869"}
0005435376342	634C74	8430 942668	ALEKSANDR BARANOV	{"email": "baranov.aleksandr13071958@postgrespro.ru", "phone": "+70230131602"}
0005435376343	DB12AE	6566 937740	VIKTOR KOROLEV	{"email": "korolev_v17111979@postgrespro.ru", "phone": "+70427878292"}
0005435376344	DB12AE	7573 273442	OLGA KOMAROVA	{"phone": "+70897401108"}
0005435376345	DB12AE	9489 081119	ROMAN MAKSIMOV	{"email": "maksimov-roman.1991@postgrespro.ru", "phone": "+70149744579"}
0005435376346	234664	5227 901212	DAVID SEMENOV	{"phone": "+70627685363"}
0005435376347	234664	2769 589406	YULIYA AFANASEVA	{"email": "afanaseva_yuliya_1968@postgrespro.ru", "phone": "+70503587757"}
0005435376348	11AEE7	4092 251555	OLGA SERGEEVA	{"email": "osergeeva-27061976@postgrespro.ru", "phone": "+70520328790"}
0005435376349	682415	6082 440701	GALINA GORBUNOVA	{"phone": "+70938616383"}
0005435376350	9F38DB	8301 475383	ANTON KRASNOV	{"email": "krasnov-a.041971@postgrespro.ru", "phone": "+70448208256"}
0005435376351	D37D25	7019 023618	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr_111981@postgrespro.ru", "phone": "+70672762702"}
0005435376352	D37D25	6732 742421	MAKSIM MIKHAYLOV	{"phone": "+70205790101"}
0005435376353	E06E88	2732 758786	DMITRIY KAZAKOV	{"email": "kazakovdmitriy_081972@postgrespro.ru", "phone": "+70636495207"}
0005435376354	E06E88	1215 840502	IGOR SOKOLOV	{"email": "igor-sokolov111955@postgrespro.ru", "phone": "+70732935663"}
0005435376355	0C72EB	3157 681790	ALLA EGOROVA	{"email": "egorova_alla_1977@postgrespro.ru", "phone": "+70671431904"}
0005435376356	0C72EB	2858 095005	ELENA KOZLOVA	{"email": "kozlova_e_051978@postgrespro.ru", "phone": "+70302650551"}
0005435376357	971752	0944 072267	NATALYA POPOVA	{"email": "popova_n.091980@postgrespro.ru", "phone": "+70926931522"}
0005435376358	D86B54	6715 358733	MARIYA TIKHONOVA	{"email": "mariya_tikhonova-23051966@postgrespro.ru", "phone": "+70079049652"}
0005435376359	C40055	3330 720104	YULIYA ALEKSANDROVA	{"phone": "+70064879080"}
0005435376360	C40055	8518 989389	YULIYA SCHERBAKOVA	{"email": "y.scherbakova.1977@postgrespro.ru", "phone": "+70586729111"}
0005435376361	6E5447	6823 965332	REGINA KOROLEVA	{"phone": "+70595080447"}
0005435376362	175832	4355 123440	VIKTOR MOISEEV	{"email": "moiseevviktor.27041976@postgrespro.ru", "phone": "+70875855467"}
0005435376363	D3B5DE	7888 441799	VLADISLAV ZHUKOV	{"email": "vladislav.zhukov_27091975@postgrespro.ru", "phone": "+70476865942"}
0005435376364	E1A540	5994 192845	TAISIYA MIRONOVA	{"email": "mironova-taisiya.1956@postgrespro.ru", "phone": "+70212547320"}
0005435376365	21D391	4167 065140	TATYANA FROLOVA	{"email": "frolova-t06021980@postgrespro.ru", "phone": "+70274694229"}
0005435376366	BC698A	1118 236593	MAKSIM POPOV	{"email": "popov_maksim-24021971@postgrespro.ru", "phone": "+70829512815"}
0005435376367	BC698A	9620 951007	BORIS POPOV	{"phone": "+70035162026"}
0005435376368	2474D0	6438 555602	ANDREY KUZNECOV	{"email": "kuznecov_a.17071981@postgrespro.ru", "phone": "+70984255503"}
0005435376369	546526	7833 231919	TATYANA KOLESNIKOVA	{"phone": "+70663206164"}
0005435376370	301316	5575 960605	NIKOLAY AFANASEV	{"email": "afanasev_nikolay.041975@postgrespro.ru", "phone": "+70454016017"}
0005435376372	7A69A0	3617 970403	VALENTINA KUZMINA	{"email": "v.kuzmina.1968@postgrespro.ru", "phone": "+70746598331"}
0005435376373	12C74F	1885 259701	ANNA VLASOVA	{"phone": "+70874093342"}
0005435376374	1110C2	6476 210254	RAISA ALEKSEEVA	{"email": "ralekseeva.07041963@postgrespro.ru", "phone": "+70735065556"}
0005435376375	8AFE83	3431 655864	INNA DANILOVA	{"email": "idanilova1981@postgrespro.ru", "phone": "+70481094773"}
0005435376376	EDEB77	7521 402919	NADEZHDA RODIONOVA	{"email": "rodionova-n-061971@postgrespro.ru", "phone": "+70751781573"}
0005435376377	EDEB77	0736 555575	ALEKSEY IVANOV	{"phone": "+70212152637"}
0005435376378	88E217	0545 345791	VALENTINA KOMAROVA	{"phone": "+70197100191"}
0005435376379	4E9707	2739 066835	ULYANA TARASOVA	{"phone": "+70720346371"}
0005435376380	15CE2F	2878 824137	VLADIMIR KARPOV	{"email": "karpov-v_13071972@postgrespro.ru", "phone": "+70759757851"}
0005435376381	7CFA58	2102 486791	NATALYA ZOTOVA	{"phone": "+70150873523"}
0005435376382	7CFA58	6156 867511	TATYANA ISAEVA	{"email": "t-isaeva.061973@postgrespro.ru", "phone": "+70087606875"}
0005435376383	7F4D95	4626 268202	VLADIMIR MOROZOV	{"phone": "+70264847315"}
0005435376384	D9D6D0	1169 673285	NATALYA PETROVA	{"email": "natalya_petrova_1969@postgrespro.ru", "phone": "+70494962046"}
0005435376385	86BB6E	5368 968078	NIKOLAY SCHERBAKOV	{"email": "scherbakov-nikolay_041968@postgrespro.ru", "phone": "+70509261067"}
0005435376386	9F6D07	0948 547415	NIKOLAY FILIPPOV	{"email": "nikolay_filippov121965@postgrespro.ru", "phone": "+70300350420"}
0005435376387	9F6D07	6873 418129	TATYANA KUZMINA	{"phone": "+70224742261"}
0005435376388	AD7DFB	2062 458393	LYUDMILA MELNIKOVA	{"email": "lyudmila-melnikova_1976@postgrespro.ru", "phone": "+70113674688"}
0005435376389	AD7DFB	6415 163651	VALERIYA GORBUNOVA	{"phone": "+70860044122"}
0005435376390	A7A658	8409 150081	ALFIYA SEMENOVA	{"phone": "+70692755815"}
0005435376391	A7A658	2797 079600	GALINA FROLOVA	{"email": "frolova_g_1964@postgrespro.ru", "phone": "+70868508709"}
0005435376392	EE9BA5	1938 094741	GENNADIY PAVLOV	{"phone": "+70675839455"}
0005435376393	0D63DA	2183 866867	SERGEY KUZNECOV	{"email": "s.kuznecov_15101975@postgrespro.ru", "phone": "+70787041550"}
0005435376394	0D63DA	1879 722941	VLADIMIR IVANOV	{"phone": "+70623804459"}
0005435376395	98D737	1248 611181	IRINA ISAEVA	{"email": "isaeva_i_1968@postgrespro.ru", "phone": "+70675781265"}
0005435376396	ED237B	0290 324595	ELENA ZHURAVLEVA	{"email": "elena_zhuravleva_1972@postgrespro.ru", "phone": "+70338746918"}
0005435376397	D3EBB0	5738 124426	NIKITA IVANOV	{"email": "ivanov_nikita1971@postgrespro.ru", "phone": "+70998757601"}
0005435376398	FE239F	6838 541375	VARVARA NIKOLAEVA	{"email": "varvara-nikolaeva1975@postgrespro.ru", "phone": "+70513873949"}
0005435376399	2EDCEC	2340 285262	NIKOLAY KAZAKOV	{"phone": "+70716520685"}
0005435376400	FA4000	2800 630380	NAIL DMITRIEV	{"email": "naildmitriev_30101964@postgrespro.ru", "phone": "+70359516854"}
0005435376401	FA4000	9097 886007	RIMA ALEKSANDROVA	{"phone": "+70527236474"}
0005435376402	E202BB	8785 340869	OLEG VASILEV	{"email": "o_vasilev.1969@postgrespro.ru", "phone": "+70940682548"}
0005435376403	4B5130	6754 815763	ELENA FOMINA	{"phone": "+70445109801"}
0005435376404	4B5130	3495 397967	OLGA KARPOVA	{"phone": "+70674041638"}
0005435376405	2231E9	3045 278826	ARTUR KUZMIN	{"email": "kuzminartur081971@postgrespro.ru", "phone": "+70228995159"}
0005435376406	2231E9	7666 330027	VALERIY KUZNECOV	{"email": "kuznecovv.27031968@postgrespro.ru", "phone": "+70106193758"}
0005435376407	72DEF3	2324 577385	ALEKSEY KUZNECOV	{"phone": "+70830260629"}
0005435376408	ECE56F	2845 782852	YURIY POPOV	{"email": "popov_yuriy-07121969@postgrespro.ru", "phone": "+70852374089"}
0005435376409	ECE56F	6552 311269	GENNADIY KUZNECOV	{"email": "kuznecov-gennadiy-1980@postgrespro.ru", "phone": "+70351572666"}
0005435376410	018F0F	6325 316761	NIKITA VASILEV	{"email": "vasilev-n-021969@postgrespro.ru", "phone": "+70974891494"}
0005435376411	8B0A85	2051 703655	IVAN PETROV	{"phone": "+70700789237"}
0005435376412	88E038	3928 484790	TATYANA KULIKOVA	{"email": "tkulikova-30081971@postgrespro.ru", "phone": "+70742925414"}
0005435376413	B78A76	4959 647583	ALEKSANDR IVANOV	{"phone": "+70094633207"}
0005435376414	25041C	3359 208487	ANDREY SCHERBAKOV	{"email": "andrey-scherbakov.031966@postgrespro.ru", "phone": "+70723438912"}
0005435376415	B9E622	3052 445707	RUSLAN GAVRILOV	{"email": "r.gavrilov31031970@postgrespro.ru", "phone": "+70684949646"}
0005435376416	64810D	0898 940304	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev.13121982@postgrespro.ru", "phone": "+70605107839"}
0005435376417	3D4254	8014 734359	KAPITALINA MATVEEVA	{"email": "kapitalinamatveeva22061967@postgrespro.ru", "phone": "+70426887324"}
0005435376418	15763D	3155 747155	IVAN PAVLOV	{"email": "pavlovivan-1964@postgrespro.ru", "phone": "+70650184164"}
0005435376419	D72A19	7892 645100	ALEKSEY SCHERBAKOV	{"phone": "+70515369059"}
0005435376420	6B8C14	6050 832874	LYUDMILA MARTYNOVA	{"phone": "+70024604675"}
0005435376421	6B8C14	8890 279686	ANDREY FOMIN	{"email": "a-fomin-1978@postgrespro.ru", "phone": "+70042187645"}
0005435376422	D1F440	0032 795831	KIRILL SMIRNOV	{"email": "k_smirnov.30111970@postgrespro.ru", "phone": "+70789222382"}
0005435376423	A320F9	2237 877475	ALEKSANDR KUDRYASHOV	{"email": "kudryashov.aleksandr-17111969@postgrespro.ru", "phone": "+70989560499"}
0005435376424	F0F96C	5767 824517	YULIYA SERGEEVA	{"phone": "+70821575021"}
0005435376425	00CA37	4697 105288	TATYANA RODIONOVA	{"email": "trodionova-1965@postgrespro.ru", "phone": "+70229000866"}
0005435376426	00CA37	2858 577270	SERGEY MOROZOV	{"email": "sergey-morozov.12051974@postgrespro.ru", "phone": "+70759961553"}
0005435376427	00CA37	1874 370959	ANATOLIY GORBUNOV	{"email": "gorbunov-anatoliy.071979@postgrespro.ru", "phone": "+70906282384"}
0005435376428	240DC0	7073 311482	KRISTINA KUZMINA	{"email": "kuzminakristina-1969@postgrespro.ru", "phone": "+70028942824"}
0005435376429	A1842B	5732 777589	KRISTINA KUZNECOVA	{"phone": "+70590382253"}
0005435376430	B951CB	3770 715461	VALENTINA TARASOVA	{"email": "v_tarasova091957@postgrespro.ru", "phone": "+70399360099"}
0005435376431	B0B17D	8988 327657	VADIM ILIN	{"phone": "+70551681152"}
0005435376432	99EEA0	3100 828997	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-11091975@postgrespro.ru", "phone": "+70118676235"}
0005435377537	443CC9	1225 165394	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov021970@postgrespro.ru", "phone": "+70076888341"}
0005435377538	65E9F0	6529 468442	BORIS BONDARENKO	{"email": "boris_bondarenko20021965@postgrespro.ru", "phone": "+70409863050"}
0005435377539	CD3BF6	5109 963679	ELENA NOVIKOVA	{"phone": "+70892095900"}
0005435377540	CD3BF6	2947 486572	ANDREY KISELEV	{"email": "kiselev-andrey_051966@postgrespro.ru", "phone": "+70573729166"}
0005435377541	4659B5	5980 327076	YULIYA LUKYANOVA	{"email": "lukyanovay-1966@postgrespro.ru", "phone": "+70901500834"}
0005435377542	4659B5	5754 196366	MARIYA BELYAEVA	{"email": "belyaeva-m.121958@postgrespro.ru", "phone": "+70729016503"}
0005435377543	07AFC7	2227 895754	PAVEL PETROV	{"phone": "+70858753757"}
0005435377544	8472FE	4272 958981	DMITRIY POPOV	{"email": "popovdmitriy101986@postgrespro.ru", "phone": "+70600298522"}
0005435377545	363353	3651 557958	VITALIY DAVYDOV	{"email": "davydov-vitaliy_111976@postgrespro.ru", "phone": "+70853585477"}
0005435377546	0C9A86	6015 796793	NADEZHDA CHERNOVA	{"email": "n_chernova111963@postgrespro.ru", "phone": "+70360321717"}
0005435377547	F47CDC	5077 845854	OLEG KUZNECOV	{"phone": "+70206985028"}
0005435377548	F47CDC	0451 420391	VALERIY SMIRNOV	{"phone": "+70389469005"}
0005435377549	F47CDC	6460 189879	PETR BARANOV	{"phone": "+70565592037"}
0005435377550	D6517D	0970 509484	ALEKSEY GAVRILOV	{"email": "gavrilov-aleksey.1965@postgrespro.ru", "phone": "+70551959644"}
0005435377551	870711	6360 609379	ROZA KARPOVA	{"phone": "+70828957946"}
0005435377552	870711	7966 654969	KLAVDIYA ZOTOVA	{"email": "klavdiya.zotova1971@postgrespro.ru", "phone": "+70409798836"}
0005435377553	1CF8B0	5006 650709	IGOR NAZAROV	{"phone": "+70425935704"}
0005435377554	A38D0E	3807 560785	NADEZHDA KOMAROVA	{"email": "nadezhda_komarova_1962@postgrespro.ru", "phone": "+70190569078"}
0005435377555	35C70A	8214 199920	VALENTINA VOROBEVA	{"email": "valentina.vorobeva_1980@postgrespro.ru", "phone": "+70577264600"}
0005435377556	68AC68	8403 854533	ANDREY GUSEV	{"phone": "+70669550631"}
0005435377557	774109	4492 391814	IVAN VOLKOV	{"phone": "+70007959638"}
0005435377558	774109	2505 476675	GENNADIY CHERNOV	{"phone": "+70198606182"}
0005435377559	774109	5696 117413	DAVID FEDOROV	{"email": "fedorov-d-121971@postgrespro.ru", "phone": "+70276980784"}
0005435377560	774109	3574 090138	VALENTINA LUKYANOVA	{"phone": "+70519114914"}
0005435377561	D22D82	8069 907137	LEONID SEMENOV	{"phone": "+70905056333"}
0005435377562	0C1C7F	2239 357015	TATYANA GERASIMOVA	{"email": "t-gerasimova_031982@postgrespro.ru", "phone": "+70780050565"}
0005435377563	0C26FB	6099 417273	IDA GAVRILOVA	{"phone": "+70428419660"}
0005435377564	0C26FB	4182 203748	KSENIYA ZHURAVLEVA	{"email": "zhuravleva-k-051976@postgrespro.ru", "phone": "+70976049580"}
0005435377565	0C26FB	4575 659766	SERGEY GRIGOREV	{"phone": "+70364969604"}
0005435377566	A69863	8277 710619	YULIYA ANTONOVA	{"email": "antonova.yuliya24051984@postgrespro.ru", "phone": "+70277639978"}
0005435377567	A69863	9513 886004	ANTONINA ANISIMOVA	{"email": "a.anisimova-1986@postgrespro.ru", "phone": "+70652095026"}
0005435377568	E01284	2741 220047	SERGEY SERGEEV	{"email": "sergeev_sergey_10091975@postgrespro.ru", "phone": "+70276502854"}
0005435377569	E01284	0802 724421	VLADIMIR SAVELEV	{"email": "v-savelev-1963@postgrespro.ru", "phone": "+70147219351"}
0005435377570	0F2086	5462 469075	TATYANA AFANASEVA	{"email": "afanaseva.tatyana1964@postgrespro.ru", "phone": "+70752461262"}
0005435377571	0F2086	4029 864127	ALEKSEY SMIRNOV	{"phone": "+70788434243"}
0005435377572	D32548	8865 921130	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov_061979@postgrespro.ru", "phone": "+70811001426"}
0005435377573	670B7B	0790 525266	VLADIMIR KULIKOV	{"phone": "+70370671311"}
0005435377574	6A7ED2	6475 500906	NINA LAZAREVA	{"phone": "+70477020841"}
0005435377575	6A7ED2	7657 384146	ALEKSANDR EGOROV	{"phone": "+70803705528"}
0005435377576	F87B84	8768 097623	ARTEM PAVLOV	{"phone": "+70016228713"}
0005435377577	3CB641	4307 325256	GALINA FROLOVA	{"phone": "+70670951256"}
0005435377578	624D66	5617 530219	ALEKSANDR SAVELEV	{"phone": "+70767719502"}
0005435377579	8AE317	9425 903446	OLGA GAVRILOVA	{"email": "o-gavrilova.19101967@postgrespro.ru", "phone": "+70028700715"}
0005435377580	70D8B4	3876 975135	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay.26081969@postgrespro.ru", "phone": "+70786393922"}
0005435377581	AD009E	4626 379258	OLEG SERGEEV	{"email": "sergeev_o.25101968@postgrespro.ru", "phone": "+70412711264"}
0005435377582	7B632F	2114 744731	VLADIMIR ROMANOV	{"email": "romanov.v_1974@postgrespro.ru", "phone": "+70355439257"}
0005435377583	7B632F	1581 774556	PAVEL PETROV	{"email": "petrov-pavel.23041966@postgrespro.ru", "phone": "+70316990134"}
0005435377584	57255C	9427 100236	ZINAIDA KULIKOVA	{"email": "z-kulikova-1960@postgrespro.ru", "phone": "+70885227974"}
0005435377585	890378	2501 868514	KONSTANTIN NOVIKOV	{"phone": "+70714563265"}
0005435377586	890378	4813 573780	SAMVEL VASILEV	{"phone": "+70252400107"}
0005435377587	389B03	2783 367882	SERGEY SERGEEV	{"email": "sergeysergeev_1981@postgrespro.ru", "phone": "+70192846466"}
0005435377588	3FF684	3339 427500	OLGA KUZNECOVA	{"email": "kuznecova-o071968@postgrespro.ru", "phone": "+70591959441"}
0005435377589	451216	6457 562071	VLADIMIR MIRONOV	{"phone": "+70289743384"}
0005435377590	C11229	5491 366652	ANNA OSIPOVA	{"email": "a-osipova-1972@postgrespro.ru", "phone": "+70001315443"}
0005435377591	BAE935	2014 049247	OLGA STEPANOVA	{"phone": "+70326929145"}
0005435377592	B0D265	0004 889722	VIKTORIYA MAKAROVA	{"email": "makarova-viktoriya-1963@postgrespro.ru", "phone": "+70786563242"}
0005435377593	736E61	3501 676183	EKATERINA SAVELEVA	{"phone": "+70608951613"}
0005435377594	736E61	2821 025465	TATYANA MEDVEDEVA	{"email": "t.medvedeva-1976@postgrespro.ru", "phone": "+70136419675"}
0005435377595	736E61	9875 686700	ELENA FEDOROVA	{"email": "elena.fedorova17051966@postgrespro.ru", "phone": "+70018070648"}
0005435377596	DF5036	4504 309465	GALINA ROMANOVA	{"email": "gromanova22071973@postgrespro.ru", "phone": "+70384335442"}
0005435377597	DF5036	1452 286171	NIKOLAY SHEVCHENKO	{"phone": "+70592282925"}
0005435377598	92F0DA	5765 673408	LYUBOV KOLESNIKOVA	{"email": "kolesnikoval091967@postgrespro.ru", "phone": "+70313336500"}
0005435377599	C494AC	4591 769327	VALENTINA VOLKOVA	{"email": "volkova-v_051964@postgrespro.ru", "phone": "+70626702442"}
0005435377600	C494AC	9602 918690	VLADIMIR GORBUNOV	{"phone": "+70963221197"}
0005435377601	D1E94F	1436 735062	YULIYA SOLOVEVA	{"phone": "+70262571496"}
0005435377602	9A0757	9588 319872	TATYANA MALYSHEVA	{"phone": "+70045059202"}
0005435377603	53B011	0677 596811	OLGA SMIRNOVA	{"email": "olgasmirnova-061964@postgrespro.ru", "phone": "+70201398694"}
0005435377604	53B011	6031 023051	SERGEY SERGEEV	{"email": "sergeysergeev.06101969@postgrespro.ru", "phone": "+70518923864"}
0005435377605	3D8C38	9911 143528	SERGEY DMITRIEV	{"email": "s.dmitriev1968@postgrespro.ru", "phone": "+70769199864"}
0005435377606	3D8C38	8209 686545	IGOR EGOROV	{"email": "igoregorov_031970@postgrespro.ru", "phone": "+70839151169"}
0005435377607	BDF191	0232 006221	MARAT PETROV	{"phone": "+70750568865"}
0005435377608	DFAA86	3946 698936	SERGEY BARANOV	{"email": "baranov-sergey_1977@postgrespro.ru", "phone": "+70907535594"}
0005435377609	9DF431	4775 142224	LARISA KOROLEVA	{"email": "larisakoroleva1973@postgrespro.ru", "phone": "+70319006805"}
0005435377610	9DF431	6384 707543	LYUDMILA MAKAROVA	{"phone": "+70314465515"}
0005435377611	029B8E	0245 448239	VIKTOR ISAEV	{"email": "visaev-021969@postgrespro.ru", "phone": "+70112508210"}
0005435377612	6EC0B0	6721 925532	VALERIY MIKHAYLOV	{"phone": "+70692958058"}
0005435377613	6EC0B0	9632 098773	RAISA KUZNECOVA	{"phone": "+70434226596"}
0005435377614	6EC0B0	3958 323902	NIKOLAY ALEKSEEV	{"phone": "+70420369493"}
0005435377615	6EC0B0	7396 891795	NIKITA PAVLOV	{"phone": "+70058835056"}
0005435377616	D6C8FE	7118 983867	ALEKSANDR FEDOROV	{"email": "a.fedorov08081969@postgrespro.ru", "phone": "+70058873050"}
0005435377617	D6C8FE	9251 273319	OKSANA KUZMINA	{"email": "oksanakuzmina14071974@postgrespro.ru", "phone": "+70459918679"}
0005435377618	D6C8FE	9767 756782	TATYANA KUZNECOVA	{"email": "tkuznecova-091978@postgrespro.ru", "phone": "+70906917818"}
0005435377619	9522D6	0537 076117	OKSANA ARKHIPOVA	{"email": "arkhipova.o.1971@postgrespro.ru", "phone": "+70964892414"}
0005435377620	0B38C6	2685 545891	OLEG ROMANOV	{"email": "romanov.o.13011978@postgrespro.ru", "phone": "+70562371286"}
0005435377621	341235	7740 843389	ALEKSEY PAVLOV	{"phone": "+70041019359"}
0005435377622	944877	2630 236492	KIRILL KUZMIN	{"email": "kirill_kuzmin.1976@postgrespro.ru", "phone": "+70997116418"}
0005435377623	6B6E65	1987 673903	VLADIMIR KOROLEV	{"phone": "+70575568106"}
0005435377624	60D966	7593 722781	VADIM SEMENOV	{"phone": "+70018211088"}
0005435377625	EFA879	6366 957937	ANDREY NAZAROV	{"email": "nazarov.andrey.091979@postgrespro.ru", "phone": "+70358761372"}
0005435377626	EFA879	4028 178271	KRISTINA GUSEVA	{"phone": "+70359022428"}
0005435377627	1411A5	7203 328176	SERGEY MEDVEDEV	{"email": "sergeymedvedev_17081976@postgrespro.ru", "phone": "+70885724865"}
0005435377628	1411A5	8006 202309	RINAT GORBUNOV	{"email": "rinat_gorbunov.1967@postgrespro.ru", "phone": "+70971071781"}
0005435377629	DC842D	6472 928499	ELENA NIKITINA	{"email": "elena_nikitina-1976@postgrespro.ru", "phone": "+70044723587"}
0005435377630	DC842D	9615 180334	KIRILL OSIPOV	{"email": "osipov-k.011975@postgrespro.ru", "phone": "+70023238254"}
0005435377631	939F90	2031 148358	IGOR ANDREEV	{"email": "andreevigor_24091968@postgrespro.ru", "phone": "+70503579025"}
0005435377632	939F90	9798 381879	LYUBOV SERGEEVA	{"phone": "+70423793296"}
0005435377633	5574F8	6354 836129	EVGENIY KOZLOV	{"phone": "+70017285838"}
0005435377634	5574F8	0767 583983	LYUDMILA DAVYDOVA	{"email": "lyudmila-davydova121963@postgrespro.ru", "phone": "+70687177515"}
0005435377635	5EC971	5099 577501	MIKHAIL IVANOV	{"phone": "+70799984326"}
0005435377636	19EBC1	3613 866573	ILYA SMIRNOV	{"phone": "+70146748540"}
0005435377637	77B0FD	4924 378585	LYUDMILA SOKOLOVA	{"phone": "+70308943253"}
0005435377638	77B0FD	0981 197568	TATYANA PAVLOVA	{"email": "tatyanapavlova_19101979@postgrespro.ru", "phone": "+70989520579"}
0005435377639	5E3728	4612 784801	IVAN MIRONOV	{"phone": "+70570667433"}
0005435377640	EEAFDF	8195 538668	ANDREY MELNIKOV	{"email": "a_melnikov.041967@postgrespro.ru", "phone": "+70134983295"}
0005435377641	6A4580	6228 215687	EVGENIYA MOISEEVA	{"email": "e_moiseeva_041979@postgrespro.ru", "phone": "+70428524281"}
0005435377642	6A4580	1579 006054	ALINA NOVIKOVA	{"email": "novikova_alina_101978@postgrespro.ru", "phone": "+70579517270"}
0005435377643	062E4F	5388 892012	VLADIMIR ILIN	{"phone": "+70613925062"}
0005435377644	7752C4	6850 406100	ALEKSANDR SAVELEV	{"email": "aleksandrsavelev-011979@postgrespro.ru", "phone": "+70335581663"}
0005435377645	7752C4	4452 726732	IRINA DENISOVA	{"phone": "+70952427820"}
0005435377900	8EB0CC	2131 223713	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_aleksandr-22101981@postgrespro.ru", "phone": "+70108467743"}
0005435377901	89F53B	8269 684551	YURIY SERGEEV	{"phone": "+70902064656"}
0005435377902	89F53B	6617 547201	DMITRIY KULIKOV	{"email": "dmitriykulikov.061975@postgrespro.ru", "phone": "+70876558264"}
0005435377903	89F53B	3012 991720	ALEKSANDR VOLKOV	{"email": "volkov_a_05071974@postgrespro.ru", "phone": "+70262089967"}
0005435377904	4B5700	0317 841617	BORIS DAVYDOV	{"email": "boris_davydov.1973@postgrespro.ru", "phone": "+70179752728"}
0005435377905	D9127F	4468 047555	NATALYA SOLOVEVA	{"email": "soloveva-natalya_041968@postgrespro.ru", "phone": "+70740546200"}
0005435377906	064357	4312 037387	ALEKSEY SEMENOV	{"email": "a_semenov.111958@postgrespro.ru", "phone": "+70402108376"}
0005435377907	064357	7208 407039	TAMARA ZAYCEVA	{"phone": "+70493204538"}
0005435377908	06C763	1101 722428	VALERIY DAVYDOV	{"phone": "+70150922279"}
0005435377909	06C763	8393 804011	IGOR ISAEV	{"phone": "+70378817158"}
0005435377910	92FB92	6180 202850	ALEKSANDR MAKSIMOV	{"phone": "+70484801184"}
0005435377911	FFF160	2618 664039	MIKHAIL TARASOV	{"email": "mikhail_tarasov-051962@postgrespro.ru", "phone": "+70532225298"}
0005435377912	8DBB67	6146 673094	ANASTASIYA KOVALEVA	{"email": "a-kovaleva1968@postgrespro.ru", "phone": "+70197137750"}
0005435377913	38A6D7	8022 377643	NIKOLAY ROMANOV	{"email": "romanovnikolay_111972@postgrespro.ru", "phone": "+70112173388"}
0005435377914	AF91BC	4498 459300	VALENTINA VOLKOVA	{"phone": "+70123786397"}
0005435377915	13C5AA	5040 696072	ANTONINA BORISOVA	{"email": "antonina.borisova-1958@postgrespro.ru", "phone": "+70314314447"}
0005435377916	6A1895	6637 822897	ALEKSANDR ALEKSEEV	{"phone": "+70447597242"}
0005435377917	518553	1253 892321	NATALYA TROFIMOVA	{"phone": "+70683264127"}
0005435377918	91B044	5525 307067	OLEG POPOV	{"email": "popov_oleg_1973@postgrespro.ru", "phone": "+70288514433"}
0005435377919	085E9E	5679 878203	VERA SIDOROVA	{"email": "sidorova-v.051962@postgrespro.ru", "phone": "+70654224989"}
0005435377920	000F7D	7063 130275	TIMUR VASILEV	{"email": "t.vasilev.011979@postgrespro.ru", "phone": "+70573384392"}
0005435377921	7F633E	1396 856571	YURIY VOLKOV	{"phone": "+70281482608"}
0005435377922	BF64A5	6482 725462	ALEKSANDR ZHURAVLEV	{"phone": "+70059773178"}
0005435377923	D56B8C	1652 366640	VIKTORIYA KRASNOVA	{"phone": "+70018924766"}
0005435377924	D56B8C	0455 949380	ELENA PETROVA	{"email": "e_petrova.1958@postgrespro.ru", "phone": "+70802070626"}
0005435377925	D56B8C	9769 183075	VIKTORIYA ANDREEVA	{"phone": "+70745771642"}
0005435377926	2CC515	4457 263556	EVGENIY ZAYCEV	{"phone": "+70366365748"}
0005435377927	2CC515	0475 898938	SVETLANA VOROBEVA	{"phone": "+70692079119"}
0005435377928	2CC515	8606 832501	ANTONINA MEDVEDEVA	{"email": "medvedeva.antonina.011964@postgrespro.ru", "phone": "+70859643249"}
0005435377929	21AF2A	3503 724476	YURIY SOLOVEV	{"email": "solovev-y1976@postgrespro.ru", "phone": "+70321214831"}
0005435377930	EBBEC2	7265 542727	TATYANA ANDREEVA	{"email": "tatyana-andreeva_011974@postgrespro.ru", "phone": "+70688134322"}
0005435377931	B88AE2	9828 576216	NINA PAVLOVA	{"phone": "+70228052833"}
0005435377932	B88AE2	6342 675206	SERGEY BARANOV	{"email": "baranovsergey.061982@postgrespro.ru", "phone": "+70277362842"}
0005435377933	3E85FF	7592 486952	VIKTOR MIRONOV	{"email": "v-mironov061979@postgrespro.ru", "phone": "+70300952266"}
0005435377934	3E85FF	0271 317788	SERGEY GORBUNOV	{"email": "sergeygorbunov.1977@postgrespro.ru", "phone": "+70681370180"}
0005435377935	FFE638	9789 959936	ALEKSANDR PETROV	{"email": "petrov.a051982@postgrespro.ru", "phone": "+70202673720"}
0005435377936	C168C9	8317 926294	MAKSIM KUZMIN	{"email": "kuzminm1962@postgrespro.ru", "phone": "+70890364287"}
0005435377937	C168C9	1154 121507	VALENTINA ZAKHAROVA	{"email": "v.zakharova-061985@postgrespro.ru", "phone": "+70149404209"}
0005435377938	CECBCB	0988 836503	KLAVDIYA BOGDANOVA	{"email": "bogdanovak-111975@postgrespro.ru", "phone": "+70489605126"}
0005435377939	ED9651	1456 391123	PETR FEDOTOV	{"email": "fedotov_petr_011970@postgrespro.ru", "phone": "+70492644382"}
0005435377940	162A9D	9408 081811	RAFAIL IVANOV	{"email": "r-ivanov.1958@postgrespro.ru", "phone": "+70984921358"}
0005435377941	19A447	6777 502464	MARIYA KAZAKOVA	{"phone": "+70350853048"}
0005435377942	19A447	5894 695997	TAMARA MOROZOVA	{"email": "tmorozova_031979@postgrespro.ru", "phone": "+70888469682"}
0005435377943	01D24E	2836 372677	ALEKSANDR MARTYNOV	{"email": "aleksandr.martynov.111974@postgrespro.ru", "phone": "+70049553782"}
0005435377944	54838D	3166 879447	MIKHAIL MELNIKOV	{"email": "mikhail.melnikov.14021969@postgrespro.ru", "phone": "+70293456993"}
0005435377945	F3522E	4831 616510	FAINA POTAPOVA	{"phone": "+70063187943"}
0005435377946	F3522E	2868 169220	MARIYA IVANOVA	{"phone": "+70820469558"}
0005435377947	65E7E8	4130 259570	DMITRIY KUZNECOV	{"email": "d-kuznecov101988@postgrespro.ru", "phone": "+70055753614"}
0005435377948	F8EA66	7343 669007	TATYANA VLASOVA	{"email": "tatyana_vlasova-05091973@postgrespro.ru", "phone": "+70303514798"}
0005435377949	F8EA66	3751 217297	SERGEY EGOROV	{"email": "sergey_egorov-1983@postgrespro.ru", "phone": "+70809359578"}
0005435377950	D0BD53	0322 779072	IRINA KOROLEVA	{"email": "irina.koroleva-1964@postgrespro.ru", "phone": "+70853960491"}
0005435377951	D0BD53	0807 101988	VADIM MAKAROV	{"email": "vadim_makarov_1970@postgrespro.ru", "phone": "+70905044707"}
0005435377952	473339	5059 125016	BORIS ZHUKOV	{"email": "bzhukov_121980@postgrespro.ru", "phone": "+70099506813"}
0005435377953	65B9D4	7416 839535	EVGENIY VOROBEV	{"email": "vorobev_evgeniy1973@postgrespro.ru", "phone": "+70754555668"}
0005435377954	7F1B10	9286 761297	GALINA IVANOVA	{"email": "ivanova.galina-021978@postgrespro.ru", "phone": "+70257202408"}
0005435377955	7F1B10	7261 259476	LARISA ZHUKOVA	{"email": "l_zhukova.041977@postgrespro.ru", "phone": "+70519855188"}
0005435377956	7B667D	7551 532126	PAVEL TIMOFEEV	{"phone": "+70605442821"}
0005435377957	4698DB	0548 153452	STANISLAV FILIPPOV	{"email": "stanislavfilippov-061979@postgrespro.ru", "phone": "+70874266617"}
0005435377958	4698DB	2522 776369	ELENA ZAKHAROVA	{"phone": "+70150534279"}
0005435377959	54B2B4	1025 892209	DAMIR POPOV	{"email": "popovdamir1982@postgrespro.ru", "phone": "+70196426273"}
0005435377960	CF335A	2029 923227	MIKHAIL MAKAROV	{"phone": "+70529208272"}
0005435377961	B221DE	3054 272176	VITALIY ZHUKOV	{"phone": "+70621422755"}
0005435377962	B221DE	9928 987451	ALEKSANDR MATVEEV	{"email": "aleksandr.matveev19121961@postgrespro.ru", "phone": "+70178811098"}
0005435377963	AD0077	3123 993419	TATYANA FADEEVA	{"email": "fadeevat-1966@postgrespro.ru", "phone": "+70408389331"}
0005435377964	26A7BB	7724 073089	KIRILL PETROV	{"email": "kirillpetrov.1966@postgrespro.ru", "phone": "+70083082070"}
0005435377965	4D79E6	9767 493065	LIDIYA KUDRYASHOVA	{"phone": "+70187210855"}
0005435377966	F2499E	8504 469604	VITALIY VOLKOV	{"phone": "+70571379526"}
0005435377967	F2499E	7198 707623	NINA DAVYDOVA	{"email": "davydovanina1973@postgrespro.ru", "phone": "+70816051565"}
0005435377968	12824A	2868 044677	LYUDMILA ERMAKOVA	{"email": "ermakova.lyudmila-1976@postgrespro.ru", "phone": "+70399021319"}
0005435377969	99A372	3038 883235	OLGA SOROKINA	{"phone": "+70065397630"}
0005435377970	99A372	4271 428815	SOFYA PAVLOVA	{"email": "pavlova_sofya_1973@postgrespro.ru", "phone": "+70395661001"}
0005435377971	603D60	0096 040646	ALEKSEY GRIGOREV	{"phone": "+70570559742"}
0005435377972	43FB55	0053 240204	ELENA IVANOVA	{"phone": "+70820161337"}
0005435377973	13F247	0881 500139	GALINA NOVIKOVA	{"phone": "+70786388778"}
0005435377974	13F247	6845 920852	RUSTAM STEPANOV	{"phone": "+70040620246"}
0005435377975	13F247	4011 699592	VLADIMIR KOROLEV	{"phone": "+70597926066"}
0005435377976	A97C63	6435 667495	VALENTIN KUDRYASHOV	{"email": "kudryashov_v.061970@postgrespro.ru", "phone": "+70578930243"}
0005435377977	A97C63	2025 852199	VLADIMIR MAKAROV	{"phone": "+70275830649"}
0005435377978	E8F6D1	5170 778589	VALENTINA NAUMOVA	{"phone": "+70828052610"}
0005435377979	E8F6D1	5177 660822	ANTON FEDOTOV	{"email": "fedotova.031972@postgrespro.ru", "phone": "+70200764196"}
0005435377980	E8F6D1	1185 387440	VIKTOR KAZAKOV	{"email": "kazakov-v_1971@postgrespro.ru", "phone": "+70246702356"}
0005435377981	D6FD86	5066 644528	NIKOLAY VASILEV	{"email": "vasilev-n28091965@postgrespro.ru", "phone": "+70661733648"}
0005435377982	DE4393	1399 817134	IRINA DMITRIEVA	{"email": "dmitrieva_i_1962@postgrespro.ru", "phone": "+70698867410"}
0005435377983	DE4393	3647 576653	RAISA MARTYNOVA	{"email": "r_martynova-1973@postgrespro.ru", "phone": "+70078643148"}
0005435377984	DE4393	8859 245842	VLADIMIR IVANOV	{"email": "ivanovvladimir_1968@postgrespro.ru", "phone": "+70104728666"}
0005435377985	84AF30	0045 876888	OLGA LUKYANOVA	{"phone": "+70519041261"}
0005435377986	8DC48D	3374 639200	MARIYA IVANOVA	{"email": "mariyaivanova_1979@postgrespro.ru", "phone": "+70000180947"}
0005435377987	8DC48D	6655 976067	ANDREY VOLKOV	{"email": "volkov-andrey081971@postgrespro.ru", "phone": "+70651959182"}
0005435377988	6322BF	3861 722669	SERGEY NIKOLAEV	{"email": "nikolaev_sergey.12101971@postgrespro.ru", "phone": "+70931631167"}
0005435377989	87FC2A	6239 355070	OLGA MIKHAYLOVA	{"phone": "+70324926749"}
0005435377990	397EAA	4481 344606	NINA BORISOVA	{"phone": "+70433198175"}
0005435377991	A853C6	9854 530953	MARIYA IVANOVA	{"email": "ivanova-m-25021980@postgrespro.ru", "phone": "+70807125319"}
0005435377992	A853C6	6270 363312	BORIS FILIPPOV	{"email": "filippov.b.1979@postgrespro.ru", "phone": "+70252112933"}
0005435377993	C0F8A0	2681 398328	NINA SIDOROVA	{"email": "n_sidorova031972@postgrespro.ru", "phone": "+70412707829"}
0005435380224	313051	9292 823661	TATYANA VASILEVA	{"email": "tatyanavasileva_1979@postgrespro.ru", "phone": "+70957354879"}
0005435380225	313051	4331 724952	TATYANA KONDRATEVA	{"phone": "+70317996731"}
0005435380226	8C96A7	1537 177980	ALEKSEY FOMIN	{"email": "alekseyfomin_09121975@postgrespro.ru", "phone": "+70311337376"}
0005435380227	DDE79D	6583 046466	IRINA KARPOVA	{"phone": "+70324630366"}
0005435380228	2DC58F	3486 827513	VLADIMIR TIMOFEEV	{"email": "vtimofeev_12011966@postgrespro.ru", "phone": "+70699323773"}
0005435380229	812037	6659 516581	ANDREY BELOV	{"email": "belov.a.09121978@postgrespro.ru", "phone": "+70512490254"}
0005435380230	A13B36	2854 808079	DANIIL BELOV	{"phone": "+70724534058"}
0005435380231	92B5CC	2304 207240	ELEONORA KUZMINA	{"phone": "+70954795432"}
0005435380232	814546	2821 630564	MARIYA MIRONOVA	{"phone": "+70584696927"}
0005435380233	814546	9501 076936	VIKTOR SHEVCHENKO	{"email": "viktorshevchenko-1967@postgrespro.ru", "phone": "+70097896519"}
0005435380234	814546	9562 781204	ANATOLIY MIRONOV	{"phone": "+70319032508"}
0005435380235	96963B	0602 525510	RAZIYA KUZNECOVA	{"email": "r_kuznecova-041972@postgrespro.ru", "phone": "+70731490006"}
0005435380236	96963B	7339 428533	VASILIY ILIN	{"phone": "+70050028006"}
0005435380237	4CCDBA	9785 378854	OLGA IVANOVA	{"email": "ivanova.olga091973@postgrespro.ru", "phone": "+70410542318"}
0005435380238	EA428C	9588 112221	IRINA KUZNECOVA	{"email": "kuznecova_irina_121966@postgrespro.ru", "phone": "+70377242168"}
0005435380239	A75234	6021 731933	YURIY KOROLEV	{"email": "korolevy22031974@postgrespro.ru", "phone": "+70416152430"}
0005435380240	F8F629	9139 543436	ALEKSANDR FOMIN	{"email": "a.fomin1971@postgrespro.ru", "phone": "+70583474505"}
0005435380241	F8F629	2163 734554	ANATOLIY NIKITIN	{"email": "anatoliynikitin_1972@postgrespro.ru", "phone": "+70138236886"}
0005435380242	E2309F	9079 798705	SERGEY EGOROV	{"email": "egorov_s-14061967@postgrespro.ru", "phone": "+70826428814"}
0005435380243	69F5DF	6197 094133	EVGENIY NIKOLAEV	{"phone": "+70076223098"}
0005435380244	69F5DF	6173 076895	NIKOLAY YAKOVLEV	{"email": "yakovlev_nikolay05101963@postgrespro.ru", "phone": "+70433109817"}
0005435380245	356B9A	3380 880382	VLADIMIR NOVIKOV	{"email": "v.novikov_031973@postgrespro.ru", "phone": "+70301693429"}
0005435380246	356B9A	1358 396960	ALEKSANDRA EGOROVA	{"email": "egorova.aleksandra-19081978@postgrespro.ru", "phone": "+70777032964"}
0005435380247	410D88	8992 849701	SHAMIL ANDREEV	{"email": "sandreev_25051963@postgrespro.ru", "phone": "+70513289410"}
0005435380248	7B241A	5510 068191	VLADIMIR NIKOLAEV	{"phone": "+70380681790"}
0005435380249	7B241A	8155 811592	GALINA DAVYDOVA	{"phone": "+70911486884"}
0005435380250	7A972A	9678 921190	LYUDMILA KULIKOVA	{"phone": "+70023608011"}
0005435380251	D7F579	2861 432279	SERGEY NIKITIN	{"email": "nikitin-s1969@postgrespro.ru", "phone": "+70970047274"}
0005435380252	4CCA6E	3183 681689	ANDREY KAZAKOV	{"phone": "+70769224362"}
0005435380253	4CCA6E	0820 468202	ALEKSEY ZHUKOV	{"email": "alekseyzhukov_061989@postgrespro.ru", "phone": "+70462933980"}
0005435380254	E01DCD	8754 746648	NIKOLAY KUZNECOV	{"email": "n.kuznecov.1967@postgrespro.ru", "phone": "+70006443877"}
0005435380255	7493CF	1561 584685	SVETLANA PAVLOVA	{"phone": "+70501500746"}
0005435380256	7493CF	7000 694851	OKSANA BELOVA	{"email": "belova-o-1966@postgrespro.ru", "phone": "+70028127483"}
0005435380257	088B1F	4489 539837	MIKHAIL GUSEV	{"phone": "+70144717226"}
0005435380258	088B1F	7261 200366	NINA NOVIKOVA	{"phone": "+70922035007"}
0005435380259	088B1F	6277 813735	TATYANA POPOVA	{"phone": "+70715857887"}
0005435380260	2657E6	7221 187858	LEONID FOMIN	{"email": "leonid-fomin_1975@postgrespro.ru", "phone": "+70025391593"}
0005435380261	4617E1	3349 776253	ALEKSANDR DAVYDOV	{"phone": "+70852185247"}
0005435380262	4617E1	9166 700399	OLGA EGOROVA	{"phone": "+70514235689"}
0005435380263	8C4C68	5788 560149	VYACHESLAV FOMIN	{"phone": "+70136253190"}
0005435380264	E87640	8120 260466	ARINA NIKIFOROVA	{"phone": "+70324080860"}
0005435380265	E87640	2939 081158	SVETLANA VASILEVA	{"email": "vasilevasvetlana_101973@postgrespro.ru", "phone": "+70162163344"}
0005435380266	2828F9	2688 727892	MARGARITA FADEEVA	{"phone": "+70618020087"}
0005435380267	2828F9	3230 950155	VALERIYA GAVRILOVA	{"phone": "+70613327666"}
0005435380268	5D75AA	6226 576404	ZINAIDA ZHURAVLEVA	{"email": "zinaidazhuravleva121963@postgrespro.ru", "phone": "+70735033895"}
0005435380269	CE2D50	0889 657651	ELENA ANDREEVA	{"email": "eandreeva_031965@postgrespro.ru", "phone": "+70702564092"}
0005435380270	42783A	7749 322676	NIKITA FROLOV	{"phone": "+70272321147"}
0005435380271	4EF44B	9195 497505	OLGA LEBEDEVA	{"email": "olga-lebedeva_15091983@postgrespro.ru", "phone": "+70245875235"}
0005435380272	6F596D	2959 453025	VALENTINA TITOVA	{"email": "titova.v_1965@postgrespro.ru", "phone": "+70223600583"}
0005435380273	F04D80	3862 372861	TATYANA SEMENOVA	{"email": "semenova-tatyana101972@postgrespro.ru", "phone": "+70452123772"}
0005435380274	F04D80	8433 931781	SERGEY CHERNOV	{"email": "s_chernov1971@postgrespro.ru", "phone": "+70630541019"}
0005435380275	BE6BA0	4695 163783	IGOR SIDOROV	{"email": "igorsidorov_1968@postgrespro.ru", "phone": "+70663784040"}
0005435380276	BE6BA0	5043 700158	YURIY KUZNECOV	{"phone": "+70374550136"}
0005435380277	330B79	9920 057804	NATALYA ZAKHAROVA	{"email": "zakharovan041968@postgrespro.ru", "phone": "+70097177759"}
0005435380278	330B79	1587 546068	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov051977@postgrespro.ru", "phone": "+70685953849"}
0005435380279	330B79	6122 814517	GALINA SIDOROVA	{"phone": "+70786087301"}
0005435380280	330B79	0001 987981	LARISA NIKIFOROVA	{"phone": "+70850984837"}
0005435380281	CDAF61	8764 862811	IRINA ALEKSANDROVA	{"email": "aleksandrova-irina-05091968@postgrespro.ru", "phone": "+70241947358"}
0005435380282	CDAF61	0366 080954	ALEKSANDR PAVLOV	{"email": "pavlovaleksandr-081971@postgrespro.ru", "phone": "+70972599811"}
0005435380283	937A21	5327 202938	SVETLANA FOMINA	{"phone": "+70329357701"}
0005435380284	A771B5	5646 542615	MARIYA CHERNOVA	{"email": "mariya_chernova_1979@postgrespro.ru", "phone": "+70688941069"}
0005435380285	58078E	2315 523140	PETR SERGEEV	{"email": "sergeev.petr1962@postgrespro.ru", "phone": "+70455196223"}
0005435380286	F5D935	4132 540427	YULIYA YAKOVLEVA	{"email": "yakovleva-yuliya_1975@postgrespro.ru", "phone": "+70970617345"}
0005435380287	F5D935	5401 605842	VASILIY MARTYNOV	{"phone": "+70377214991"}
0005435380288	2713C3	2116 553672	ELENA MEDVEDEVA	{"email": "elena.medvedeva1965@postgrespro.ru", "phone": "+70148450266"}
0005435380289	3381B5	5434 125090	SAVELIY SMIRNOV	{"email": "smirnov.saveliy06031970@postgrespro.ru", "phone": "+70317460443"}
0005435380290	3381B5	6000 770214	ARINA SMIRNOVA	{"email": "smirnova_arina-1975@postgrespro.ru", "phone": "+70552187304"}
0005435380291	3381B5	7607 236138	LYUBOV TITOVA	{"email": "ltitova-1976@postgrespro.ru", "phone": "+70696689332"}
0005435380292	3381B5	7735 115395	NIKOLAY NOVIKOV	{"email": "n.novikov.051970@postgrespro.ru", "phone": "+70512378102"}
0005435380293	AC9201	2453 821796	ELIZAVETA CHERNOVA	{"phone": "+70068637183"}
0005435380294	D7E06D	4104 136984	NATALYA FROLOVA	{"email": "n-frolova.1967@postgrespro.ru", "phone": "+70585646156"}
0005435380295	7478BF	4902 100146	KSENIYA GAVRILOVA	{"phone": "+70522285412"}
0005435380296	7478BF	7176 804729	NINA VOROBEVA	{"phone": "+70703537800"}
0005435380297	7478BF	4344 998007	SERGEY ZAYCEV	{"phone": "+70805076831"}
0005435380298	337489	8189 832667	IRINA KUZMINA	{"email": "i_kuzmina-06081971@postgrespro.ru", "phone": "+70541386736"}
0005435380299	5D6528	5752 365038	NINA KUZMINA	{"phone": "+70841810017"}
0005435380300	28DE1E	9716 363371	SERGEY YAKOVLEV	{"email": "syakovlev.071969@postgrespro.ru", "phone": "+70226041695"}
0005435380301	07CABE	6931 741764	ANASTASIYA PAVLOVA	{"email": "pavlova_a.14101972@postgrespro.ru", "phone": "+70561196940"}
0005435380302	07CABE	0375 221334	DMITRIY DENISOV	{"phone": "+70248257248"}
0005435380303	8D2502	1718 949896	ALFIYA VOLKOVA	{"email": "volkova-a-21031972@postgrespro.ru", "phone": "+70841850785"}
0005435380304	8D2502	1809 506119	ROMAN FROLOV	{"email": "rfrolov111979@postgrespro.ru", "phone": "+70682062154"}
0005435380305	A30D2B	3458 948628	OLGA GRISHINA	{"email": "o_grishina-1973@postgrespro.ru", "phone": "+70777145302"}
0005435380306	B037F9	4345 278952	ANASTASIYA KARPOVA	{"email": "karpova_a-051975@postgrespro.ru", "phone": "+70090903486"}
0005435380307	9C153D	2784 164316	OLEG SERGEEV	{"email": "o.sergeev031968@postgrespro.ru", "phone": "+70811090192"}
0005435380308	9C153D	6938 454967	GULNARA ILINA	{"phone": "+70566376587"}
0005435380309	EA7EBB	4764 760633	ALEKSANDRA SERGEEVA	{"email": "sergeeva-a061966@postgrespro.ru", "phone": "+70658293326"}
0005435380310	A93344	3437 435072	PRASKOVYA BORISOVA	{"phone": "+70745973524"}
0005435380311	E7FA0E	0984 186883	IRINA ZHUKOVA	{"email": "irina-zhukova.031961@postgrespro.ru", "phone": "+70713047375"}
0005435380312	D605E3	3513 686423	NATALYA ALEKSEEVA	{"email": "nalekseeva1974@postgrespro.ru", "phone": "+70085106933"}
0005435380313	D605E3	3638 516213	KONSTANTIN KOROLEV	{"phone": "+70682114583"}
0005435380314	483269	4544 180964	TIMOFEY VLASOV	{"phone": "+70121858976"}
0005435380315	2DE78F	9926 486451	MAKSIM GERASIMOV	{"email": "gerasimov_maksim_111970@postgrespro.ru", "phone": "+70695438627"}
0005435380316	CA7364	2405 409889	OLGA LAZAREVA	{"email": "lazarevaolga.18121980@postgrespro.ru", "phone": "+70276650936"}
0005435380317	F5658F	8175 540106	RAISA ISAEVA	{"email": "risaeva.061968@postgrespro.ru", "phone": "+70548953507"}
0005435380318	22CD54	9797 809811	OKSANA GAVRILOVA	{"email": "ogavrilova_051967@postgrespro.ru", "phone": "+70565161817"}
0005435380319	E1202D	1518 467085	OLGA ALEKSEEVA	{"email": "alekseevao.101975@postgrespro.ru", "phone": "+70086623383"}
0005435380320	99E3B2	2995 565537	YULIYA MIRONOVA	{"phone": "+70633703396"}
0005435380321	1615BC	1395 068602	ROMAN ALEKSANDROV	{"phone": "+70877600853"}
0005435380322	1615BC	4580 731430	ELENA NOVIKOVA	{"email": "elena.novikova_1964@postgrespro.ru", "phone": "+70136470751"}
0005435380323	7009B0	0259 599935	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr061973@postgrespro.ru", "phone": "+70714382059"}
0005435380324	7009B0	5423 780067	DENIS PETROV	{"phone": "+70323916736"}
0005435380325	9B99EA	6911 696636	SERGEY MIKHAYLOV	{"phone": "+70124506697"}
0005435380326	FC7F26	4862 805635	ANATOLIY NAUMOV	{"email": "a.naumov-1977@postgrespro.ru", "phone": "+70414882379"}
0005435380327	4E83B5	7413 545162	ANDREY PETROV	{"phone": "+70955023494"}
0005435380328	028718	9845 742669	LYUDMILA SOKOLOVA	{"phone": "+70733363508"}
0005435380329	672547	9968 415275	NIKITA KONOVALOV	{"email": "konovalov-n_02031972@postgrespro.ru", "phone": "+70359228168"}
0005435380330	930BF3	6300 896405	OLEG DMITRIEV	{"phone": "+70565246574"}
0005435380331	930BF3	8867 865353	NATALIYA ROMANOVA	{"phone": "+70607212460"}
0005435380332	14A350	6376 654357	MAKSIM MOISEEV	{"email": "moiseev_maksim16051970@postgrespro.ru", "phone": "+70807947222"}
0005435380333	66208D	8070 852887	RUSLAN GERASIMOV	{"email": "r-gerasimov111979@postgrespro.ru", "phone": "+70138027944"}
0005435380334	3B1090	9105 313475	ALEKSANDR KONOVALOV	{"email": "konovalova_20101971@postgrespro.ru", "phone": "+70585318510"}
0005435380335	6AD3F3	4630 655180	EVGENIY BORISOV	{"phone": "+70846641638"}
0005435380336	6AD3F3	3126 662004	IRINA PAVLOVA	{"phone": "+70874994416"}
0005435380337	051CE5	1714 424664	YURIY NOVIKOV	{"phone": "+70424378626"}
0005435380338	CB478B	8927 460455	KSENIYA MOROZOVA	{"phone": "+70137001399"}
0005435380339	0C7BEE	2041 930211	ALIYA FEDOROVA	{"phone": "+70684375397"}
0005435380340	83254F	6431 201700	EGOR BORISOV	{"email": "borisove1977@postgrespro.ru", "phone": "+70211958653"}
0005435380341	C8C251	6663 779103	ALEKSEY TIKHONOV	{"phone": "+70752675235"}
0005435380342	D65AD3	8832 902627	VIKTOR DMITRIEV	{"phone": "+70111893406"}
0005435380343	64C8CF	0402 409368	ROMAN KULIKOV	{"email": "roman-kulikov.23071970@postgrespro.ru", "phone": "+70314566620"}
0005435380344	64C8CF	9079 944225	LYUDMILA KULIKOVA	{"email": "kulikova-lyudmila-1970@postgrespro.ru", "phone": "+70542906128"}
0005435380345	E6EF66	6430 215888	VLADIMIR GRIGOREV	{"phone": "+70007830343"}
0005435380346	FF4D1A	8401 656212	OLGA MOROZOVA	{"phone": "+70570756192"}
0005435380347	052A09	9750 615715	PETR MEDVEDEV	{"phone": "+70312473171"}
0005435380348	A27AFB	5646 446378	ALEKSANDR KOZLOV	{"phone": "+70809043369"}
0005435380349	A27AFB	2501 006449	LYUDMILA NESTEROVA	{"phone": "+70161424681"}
0005435380350	6D60F2	6460 124605	NATALYA KULIKOVA	{"email": "kulikova-n_08121978@postgrespro.ru", "phone": "+70140857388"}
0005435380351	6D60F2	4495 814215	TAISIYA POLYAKOVA	{"email": "polyakovat1975@postgrespro.ru", "phone": "+70383783746"}
0005435380352	337BDA	6025 280276	ELENA YAKOVLEVA	{"email": "yakovleva-elena011966@postgrespro.ru", "phone": "+70630376523"}
0005435380353	61C3A9	0313 696385	ALEKSANDRA SERGEEVA	{"phone": "+70246490189"}
0005435380354	C62DEE	9361 666203	RIMMA LAZAREVA	{"phone": "+70439496446"}
0005435380355	854576	1622 667733	STEPAN ROMANOV	{"email": "romanovs_15051962@postgrespro.ru", "phone": "+70033595482"}
0005435380356	DDAD0F	0045 478281	NIKOLAY KUZMIN	{"email": "kuzmin_nikolay-121975@postgrespro.ru", "phone": "+70036308722"}
0005435380357	DDAD0F	0034 618562	MAKSIM STEPANOV	{"phone": "+70453947961"}
0005435380358	4D6C35	9616 217360	VALERIY IVANOV	{"phone": "+70640007211"}
0005435380359	7B6DE1	6391 624818	IRINA FROLOVA	{"phone": "+70988494300"}
0005435380360	7B6DE1	1647 921161	ANTONINA DENISOVA	{"email": "antonina-denisova.1982@postgrespro.ru", "phone": "+70852203181"}
0005435380361	49FC38	6294 490401	NIKOLAY IVANOV	{"phone": "+70769473523"}
0005435380362	8F7383	4336 123344	YURIY TIKHONOV	{"phone": "+70650367219"}
0005435380363	CB8C9B	9142 838924	BORIS ALEKSEEV	{"phone": "+70541066652"}
0005435380364	86148F	5977 649033	VITALIY ZHUKOV	{"phone": "+70728563694"}
0005435380365	DAFA4A	9847 089290	ARTUR MAKAROV	{"email": "a_makarov.091971@postgrespro.ru", "phone": "+70835048107"}
0005435380366	C87DFD	6039 657606	DANILA KONOVALOV	{"phone": "+70883337602"}
0005435380367	4D013C	2295 551227	LIDIYA ERMAKOVA	{"phone": "+70750364944"}
0005435380368	5C7502	9122 704226	YANA LOGINOVA	{"email": "y-loginova-07061976@postgrespro.ru", "phone": "+70037264481"}
0005435380369	5C7502	2114 423506	ELENA PETROVA	{"email": "epetrova03011983@postgrespro.ru", "phone": "+70392957426"}
0005435380370	5E7F79	2059 689853	OLGA ANTONOVA	{"email": "olgaantonova11041967@postgrespro.ru", "phone": "+70797742622"}
0005435380371	5E7F79	8779 214711	VLADIMIR BELOV	{"email": "vladimirbelov_011961@postgrespro.ru", "phone": "+70169960116"}
0005435380372	FCCA40	7308 970132	GALINA KUZNECOVA	{"email": "kuznecova-g04111975@postgrespro.ru", "phone": "+70764243810"}
0005435380373	FD2E4A	0329 433336	VIKTORIYA NIKOLAEVA	{"phone": "+70180841682"}
0005435380374	6A50A1	2332 941334	NIKOLAY NIKITIN	{"email": "nikitin_n-051980@postgrespro.ru", "phone": "+70989094604"}
0005435380375	A76794	9924 636173	TATYANA FOMINA	{"email": "fomina_tatyana-06051976@postgrespro.ru", "phone": "+70447403975"}
0005435380376	2873A6	7832 134341	ARTEM ZHURAVLEV	{"email": "artem_zhuravlev04041985@postgrespro.ru", "phone": "+70469205255"}
0005435380377	28BE0B	2593 580343	MARIYA ILINA	{"email": "m.ilina_1972@postgrespro.ru", "phone": "+70755355191"}
0005435380378	28BE0B	2981 932116	ALEKSANDRA KONOVALOVA	{"email": "aleksandra_konovalova.021950@postgrespro.ru", "phone": "+70147312381"}
0005435380379	09524B	6369 261554	EKATERINA MASLOVA	{"email": "maslova.e011979@postgrespro.ru", "phone": "+70697671682"}
0005435380380	EAEF58	7114 087961	ELIZAVETA VOLKOVA	{"email": "e-volkova.1967@postgrespro.ru", "phone": "+70224698547"}
0005435380381	EAEF58	2157 668869	NATALYA MOROZOVA	{"email": "n_morozova-031979@postgrespro.ru", "phone": "+70002501419"}
0005435380382	2C75C1	8346 491404	TATYANA SOLOVEVA	{"phone": "+70431772743"}
0005435380383	2C75C1	3824 342936	ALEKSEY POPOV	{"phone": "+70208304799"}
0005435380384	C2690E	4802 199678	OLEG MARTYNOV	{"email": "martynov-oleg.04021974@postgrespro.ru", "phone": "+70717780800"}
0005435380385	3065C9	2645 440523	ALEKSANDR MEDVEDEV	{"email": "medvedeva_1968@postgrespro.ru", "phone": "+70605455189"}
0005435380386	DF361F	7917 836983	ANNA KOMAROVA	{"email": "anna.komarova-18051952@postgrespro.ru", "phone": "+70352404058"}
0005435380387	DF361F	9328 239837	ALEKSANDR TARASOV	{"phone": "+70975761793"}
0005435380388	AC177C	4437 642448	NIKOLAY POPOV	{"phone": "+70629950378"}
0005435380389	7F773F	2902 312036	LILIYA POPOVA	{"phone": "+70140311504"}
0005435380390	93DF72	3548 951106	ALINA POTAPOVA	{"email": "a-potapova-081966@postgrespro.ru", "phone": "+70930653106"}
0005435380391	93DF72	4219 806974	OLGA IVANOVA	{"email": "o-ivanova.09091980@postgrespro.ru", "phone": "+70615217267"}
0005435380392	4CCBE7	5882 869258	ANASTASIYA NAZAROVA	{"email": "nazarova-anastasiya.07031968@postgrespro.ru", "phone": "+70513531539"}
0005435380393	42E36F	0569 101916	MIKHAIL ALEKSEEV	{"email": "mikhail.alekseev.23031976@postgrespro.ru", "phone": "+70670762781"}
0005435380394	C6EA6F	2125 603948	EKATERINA PAVLOVA	{"email": "pavlova_ekaterina121978@postgrespro.ru", "phone": "+70010042951"}
0005435380395	9FEC20	1627 023128	LYUDMILA FADEEVA	{"email": "fadeeva.l28121970@postgrespro.ru", "phone": "+70962232377"}
0005435380396	CA3557	4615 618664	VALERIY BELOV	{"email": "belov_valeriy.091964@postgrespro.ru", "phone": "+70403925705"}
0005435380397	18866A	5795 781821	TAMARA SIDOROVA	{"email": "sidorova-tamara-071971@postgrespro.ru", "phone": "+70454498135"}
0005435380398	6F232F	9833 214146	VLADIMIR MIRONOV	{"email": "mironovv.051973@postgrespro.ru", "phone": "+70212588517"}
0005435380399	6F232F	6286 525366	LYUBOV NESTEROVA	{"email": "nesterova.lyubov_1973@postgrespro.ru", "phone": "+70948134048"}
0005435380400	B31E39	8931 549181	NADEZHDA FEDOROVA	{"email": "n-fedorova-041979@postgrespro.ru", "phone": "+70566499372"}
0005435380401	AAD25D	2137 058336	SVETLANA KULIKOVA	{"phone": "+70426387190"}
0005435380402	A86363	5168 438926	ALEKSANDR SMIRNOV	{"email": "smirnov.aleksandr-111967@postgrespro.ru", "phone": "+70235753367"}
0005435380403	0364C5	2613 660797	EKATERINA EGOROVA	{"email": "eegorova02021967@postgrespro.ru", "phone": "+70028957291"}
0005435380404	5E0F43	8504 501353	NINA BORISOVA	{"phone": "+70494695073"}
0005435380405	310914	3734 689883	IRINA VASILEVA	{"phone": "+70850037736"}
0005435380406	ECA5EE	1836 955766	ANNA ORLOVA	{"email": "anna_orlova-06091963@postgrespro.ru", "phone": "+70773314483"}
0005435380407	F3CFA2	5653 704484	NADEZHDA MAKAROVA	{"phone": "+70827195676"}
0005435380408	F3CFA2	7257 489814	MARIYA SAVELEVA	{"phone": "+70212816709"}
0005435380409	576730	9669 379395	ANNA PAVLOVA	{"email": "pavlova_anna1975@postgrespro.ru", "phone": "+70873993941"}
0005435380410	54F5F6	8294 735510	ANNA ZHURAVLEVA	{"email": "zhuravleva.a_071950@postgrespro.ru", "phone": "+70387936635"}
0005435380411	54F5F6	2380 728474	EVGENIY MAKAROV	{"email": "evgeniy_makarov-11051973@postgrespro.ru", "phone": "+70945094470"}
0005435380412	E29F83	7400 562670	RINAT VOROBEV	{"email": "rinat.vorobev.13091970@postgrespro.ru", "phone": "+70655191903"}
0005435380413	E29F83	6044 762041	VALENTINA SOROKINA	{"email": "valentina.sorokina-11101966@postgrespro.ru", "phone": "+70804643148"}
0005435380414	454CB7	0615 302139	NELLI DENISOVA	{"email": "denisovanelli.18041974@postgrespro.ru", "phone": "+70566896346"}
0005435380415	707BF4	2284 388081	YURIY SCHERBAKOV	{"email": "yuriy-scherbakov-08061978@postgrespro.ru", "phone": "+70282540121"}
0005435380416	707BF4	1402 682518	ALEKSEY TARASOV	{"phone": "+70385550734"}
0005435380417	B90FD8	4018 068672	SERGEY SERGEEV	{"email": "s_sergeev_22051988@postgrespro.ru", "phone": "+70440818485"}
0005435380418	72758F	9813 309136	MARINA STEPANOVA	{"email": "stepanova-m_1971@postgrespro.ru", "phone": "+70737898400"}
0005435380419	125BB7	5969 670917	VLADISLAV SIDOROV	{"phone": "+70266244200"}
0005435380420	F9C55A	2453 254619	TATYANA ZAKHAROVA	{"phone": "+70795522999"}
0005435380421	237CAE	8195 395931	TATYANA ZHURAVLEVA	{"email": "tatyana-zhuravleva_031976@postgrespro.ru", "phone": "+70753659109"}
0005435380422	237CAE	2317 416107	IRINA IVANOVA	{"phone": "+70162175326"}
0005435380423	FF02BF	0445 055375	ALEKSANDR GORBUNOV	{"email": "gorbunovaleksandr_31071957@postgrespro.ru", "phone": "+70681782683"}
0005435380424	FF02BF	5177 989581	RAISA ALEKSEEVA	{"phone": "+70848725292"}
0005435380425	FF02BF	3543 720267	ARTEM KRASNOV	{"email": "artem-krasnov.031969@postgrespro.ru", "phone": "+70664180242"}
0005435380426	17B432	7392 039194	ALEKSANDR ALEKSEEV	{"email": "alekseeva011975@postgrespro.ru", "phone": "+70422509513"}
0005435380427	17B432	6234 563376	SERGEY GERASIMOV	{"phone": "+70204960411"}
0005435380428	10FC93	4317 050078	VALERIY CHERNOV	{"email": "chernovvaleriy_071977@postgrespro.ru", "phone": "+70511715955"}
0005435380429	A27CB9	6568 790492	ANATOLIY ZAKHAROV	{"phone": "+70582968126"}
0005435380430	CD86F7	9027 931854	YULIYA ILINA	{"email": "y-ilina_04091979@postgrespro.ru", "phone": "+70424326235"}
0005435380431	6C2554	8528 846525	VIKTORIYA MAKAROVA	{"phone": "+70227318764"}
0005435380432	6C2554	6360 001352	MARINA DANILOVA	{"email": "marina-danilova121967@postgrespro.ru", "phone": "+70934881758"}
0005435380433	81C492	8708 556301	VERA SERGEEVA	{"email": "v.sergeeva.031980@postgrespro.ru", "phone": "+70675762532"}
0005435380434	0E7B7C	0919 768476	VERA BELYAEVA	{"phone": "+70919396138"}
0005435380435	0E7B7C	2420 571648	ELENA GRISHINA	{"email": "elena-grishina.10041961@postgrespro.ru", "phone": "+70396839362"}
0005435380436	3D995E	3931 356691	VERA BELYAEVA	{"email": "verabelyaeva-051979@postgrespro.ru", "phone": "+70267210981"}
0005435380437	5D716B	3449 513221	DMITRIY KOZLOV	{"phone": "+70538602519"}
0005435380438	5D716B	4344 018140	ANATOLIY YAKOVLEV	{"phone": "+70916018502"}
0005435380439	5D716B	0895 654030	ALEKSANDR STEPANOV	{"phone": "+70252498298"}
0005435380440	E33C50	5916 111731	ALEKSANDR ANDREEV	{"email": "andreev.a-1974@postgrespro.ru", "phone": "+70764439424"}
0005435380441	24FA57	1016 216000	SERGEY PAVLOV	{"phone": "+70594102953"}
0005435380442	6806ED	2365 182082	SERGEY ZHURAVLEV	{"phone": "+70188910769"}
0005435380443	97E254	6787 601614	VLADIMIR GRIGOREV	{"email": "grigorevv.1982@postgrespro.ru", "phone": "+70808554106"}
0005435380444	B93C94	1584 199501	TATYANA MARTYNOVA	{"email": "martynova_tatyana-1966@postgrespro.ru", "phone": "+70257872073"}
0005435383055	336DA4	2647 212325	ZOYA SOKOLOVA	{"email": "sokolova.z-041972@postgrespro.ru", "phone": "+70059688753"}
0005435383056	336DA4	9725 363370	VLADIMIR ANDREEV	{"email": "andreev-vladimir22071977@postgrespro.ru", "phone": "+70375575982"}
0005435383057	BEE150	8196 255330	TAMARA PAVLOVA	{"phone": "+70993301622"}
0005435383058	1BECD6	4444 476561	BORIS KOZLOV	{"email": "boris.kozlov_19091968@postgrespro.ru", "phone": "+70686011807"}
0005435383059	1BECD6	5510 333997	YURIY EGOROV	{"phone": "+70943465302"}
0005435383060	6D4AA8	7298 027785	GENNADIY ROMANOV	{"email": "g.romanov041976@postgrespro.ru", "phone": "+70498450218"}
0005435383061	C246C2	7018 904185	OLGA VLASOVA	{"email": "olga.vlasova071969@postgrespro.ru", "phone": "+70255426305"}
0005435383062	C246C2	5234 818953	ALEKSANDR SMIRNOV	{"phone": "+70084397024"}
0005435383063	C246C2	4138 402290	ELLA MEDVEDEVA	{"email": "medvedeva_ella-1978@postgrespro.ru", "phone": "+70369345596"}
0005435383064	A515D6	4163 102420	SVETLANA KUZNECOVA	{"phone": "+70596809396"}
0005435383065	A515D6	3382 707635	GALINA KOMAROVA	{"phone": "+70520885264"}
0005435383066	A515D6	1285 137933	MILANA OSIPOVA	{"phone": "+70817319038"}
0005435383067	6FCD72	8475 412771	ALLA KOLESNIKOVA	{"email": "a.kolesnikova25061981@postgrespro.ru", "phone": "+70996887338"}
0005435383068	CE583F	8423 362358	MARINA ANDREEVA	{"phone": "+70329506323"}
0005435383069	CE583F	2277 957092	OLGA KOVALEVA	{"email": "kovaleva_o1977@postgrespro.ru", "phone": "+70798850783"}
0005435383070	CE583F	4632 965273	SERGEY SHEVCHENKO	{"email": "sergey_shevchenko.23041971@postgrespro.ru", "phone": "+70016398555"}
0005435383071	CEAEB8	0723 279598	VALERIY BONDARENKO	{"email": "bondarenko-valeriy1972@postgrespro.ru", "phone": "+70396047919"}
0005435383072	35F5B8	4691 908900	MARIYA EGOROVA	{"email": "egorova_m.061972@postgrespro.ru", "phone": "+70446171887"}
0005435383073	EAA2C1	9770 253373	SVETLANA KISELEVA	{"phone": "+70181076411"}
0005435383074	FC56E0	2418 640182	ALEKSEY GUSEV	{"phone": "+70336464741"}
0005435383075	F716D3	7292 980256	EVGENIY IVANOV	{"phone": "+70444915233"}
0005435383076	D8DD32	9938 586568	ANNA MAKAROVA	{"phone": "+70607167513"}
0005435383077	D8A74E	4586 624799	MARINA NIKOLAEVA	{"email": "m.nikolaeva-011965@postgrespro.ru", "phone": "+70386789368"}
0005435383078	D8A74E	1795 206880	VADIM KUDRYASHOV	{"phone": "+70965989155"}
0005435383079	C7D5CD	7828 300043	OLGA MAKSIMOVA	{"email": "o-maksimova_21031959@postgrespro.ru", "phone": "+70489221234"}
0005435383080	C7D5CD	7142 065610	OLGA ZAYCEVA	{"phone": "+70065894879"}
0005435383081	C7D5CD	3704 985355	MIKHAIL KRASNOV	{"email": "mkrasnov-1970@postgrespro.ru", "phone": "+70582993217"}
0005435383082	E5A7B8	0227 038569	PAVEL ZAKHAROV	{"phone": "+70999037750"}
0005435383083	E5A7B8	4121 680259	LIDIYA KOLESNIKOVA	{"phone": "+70916356930"}
0005435383084	D96A98	7212 546786	ALLA RODIONOVA	{"email": "alla.rodionova-101965@postgrespro.ru", "phone": "+70509046941"}
0005435383085	21F73B	1647 197438	ANASTASIYA ARKHIPOVA	{"phone": "+70840225659"}
0005435383086	21F73B	0546 447230	VLADIMIR EGOROV	{"email": "egorov-vladimir061975@postgrespro.ru", "phone": "+70064668097"}
0005435383087	21F73B	5695 642216	ANNA DENISOVA	{"phone": "+70569101421"}
0005435383088	0B393B	7936 672876	NATALYA NIKITINA	{"email": "nikitina.n061978@postgrespro.ru", "phone": "+70691293694"}
0005435383089	748C21	4850 025932	LYUBOV IVANOVA	{"email": "lyubov.ivanova_1975@postgrespro.ru", "phone": "+70633290697"}
0005435383090	797748	7943 032604	ANASTASIYA FILATOVA	{"email": "filatova-a-101981@postgrespro.ru", "phone": "+70151938362"}
0005435383091	6436B7	5105 814831	OLEG CHERNOV	{"email": "chernov.o.061985@postgrespro.ru", "phone": "+70968141967"}
0005435383092	6436B7	8979 427491	VIKTORIYA VASILEVA	{"email": "v.vasileva.1973@postgrespro.ru", "phone": "+70649998944"}
0005435383093	686A1D	9636 197032	ANDREY MEDVEDEV	{"email": "andrey-medvedev_071962@postgrespro.ru", "phone": "+70350940474"}
0005435383094	80302A	4806 785523	ELMIRA DAVYDOVA	{"phone": "+70886882244"}
0005435383095	80302A	0642 035731	NATALYA KUZMINA	{"phone": "+70949298876"}
0005435383096	574DE0	3497 895965	ELENA ANDREEVA	{"phone": "+70622181871"}
0005435383097	EDAA78	8693 969624	VERONIKA PAVLOVA	{"email": "veronika-pavlova-101976@postgrespro.ru", "phone": "+70911938759"}
0005435383098	EDAA78	2679 460102	ELIZAVETA KISELEVA	{"email": "kiseleva.e-1961@postgrespro.ru", "phone": "+70696033637"}
0005435383099	30D155	7378 628573	LYUBOV ANDREEVA	{"email": "andreeval-27111964@postgrespro.ru", "phone": "+70472235144"}
0005435383100	B97B96	7140 737225	VALENTINA POTAPOVA	{"phone": "+70464287812"}
0005435383101	B97B96	9093 572830	ALEKSANDR NOVIKOV	{"phone": "+70801765060"}
0005435383102	5C05E4	2747 233050	EKATERINA NOVIKOVA	{"phone": "+70233245317"}
0005435383103	D0E75C	5426 642714	LIDIYA SEMENOVA	{"email": "l_semenova-1971@postgrespro.ru", "phone": "+70750366335"}
0005435383104	0E93A7	1159 021748	EVDOKIYA FEDOROVA	{"phone": "+70403417706"}
0005435383105	317BC0	8308 951192	VENIAMIN SOROKIN	{"email": "veniaminsorokin1971@postgrespro.ru", "phone": "+70143581203"}
0005435383106	83208F	8175 592787	EKATERINA SMIRNOVA	{"phone": "+70965900560"}
0005435383107	83208F	6515 642233	ROMAN ZAKHAROV	{"phone": "+70695404475"}
0005435383108	2CD36A	3720 839325	LYUBOV GUSEVA	{"email": "lyubov-guseva-061974@postgrespro.ru", "phone": "+70502369512"}
0005435383109	2CD36A	7811 849837	ALEKSANDR MELNIKOV	{"phone": "+70301139055"}
0005435383110	4AA554	3192 896141	DENIS FOMIN	{"phone": "+70487723224"}
0005435383111	2A32EF	8306 734788	TAISIYA SOLOVEVA	{"email": "tsoloveva-20071968@postgrespro.ru", "phone": "+70079558836"}
0005435383112	2A32EF	5041 202150	VALERIYA KUZNECOVA	{"phone": "+70367192182"}
0005435383113	62DC50	8090 225358	SERGEY VOLKOV	{"phone": "+70982491302"}
0005435383114	B74865	1049 001615	KSENIYA ORLOVA	{"phone": "+70040468315"}
0005435383115	F444F5	6384 192169	ROMAN DENISOV	{"email": "denisovr.051964@postgrespro.ru", "phone": "+70216857533"}
0005435383116	F444F5	1851 441145	ELENA KOVALEVA	{"email": "kovaleva-e-27071979@postgrespro.ru", "phone": "+70386751045"}
0005435383117	8F0565	6719 634696	VLADIMIR IVANOV	{"email": "ivanov.v-061970@postgrespro.ru", "phone": "+70990043615"}
0005435383118	2B83FE	5807 328055	OLESYA ANISIMOVA	{"email": "anisimova-o1972@postgrespro.ru", "phone": "+70849654577"}
0005435383119	8758AA	6747 972314	TATYANA FEDOROVA	{"email": "t_fedorova.1969@postgrespro.ru", "phone": "+70001368868"}
0005435383120	A93297	1369 233679	DMITRIY ISAEV	{"phone": "+70654737283"}
0005435383121	B72E87	0313 959781	TATYANA BELYAEVA	{"email": "belyaeva_tatyana.011969@postgrespro.ru", "phone": "+70323690985"}
0005435383122	B20AE7	5251 590616	OLGA MAKAROVA	{"email": "o-makarova29041978@postgrespro.ru", "phone": "+70413955854"}
0005435383123	B20AE7	3448 161542	TATYANA VOROBEVA	{"email": "tatyana.vorobeva_14041973@postgrespro.ru", "phone": "+70780088071"}
0005435383124	1BE2A9	6903 808914	TATYANA ROMANOVA	{"phone": "+70080002548"}
0005435383125	1BE2A9	4041 405372	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev1965@postgrespro.ru", "phone": "+70023259939"}
0005435383126	8AEAA8	6463 004964	EKATERINA DAVYDOVA	{"phone": "+70510530712"}
0005435383127	8AEAA8	2663 678523	NADEZHDA PAVLOVA	{"email": "nadezhda.pavlova1977@postgrespro.ru", "phone": "+70277557684"}
0005435383128	342158	6015 120115	IVAN KUZNECOV	{"phone": "+70114712919"}
0005435383129	1E6D1B	5371 021482	TATYANA ANISIMOVA	{"phone": "+70764868594"}
0005435383130	48F6A6	4018 677053	NIKOLAY IVANOV	{"email": "nikolay.ivanov.1985@postgrespro.ru", "phone": "+70533449554"}
0005435383131	424F3D	6027 445110	IRINA GUSEVA	{"phone": "+70965855940"}
0005435383132	BB8E1A	5298 629137	OKSANA ZHURAVLEVA	{"phone": "+70956408237"}
0005435383133	CEC191	4432 355053	ALEKSANDR VASILEV	{"email": "vasilev.a-02061986@postgrespro.ru", "phone": "+70264650541"}
0005435383134	CEC191	5705 224690	ALEKSANDR KAZAKOV	{"phone": "+70186056535"}
0005435383135	AA1E88	9783 445922	MARINA NIKOLAEVA	{"email": "nikolaeva.marina1975@postgrespro.ru", "phone": "+70798387248"}
0005435383136	F38599	5856 143384	VALENTINA NIKITINA	{"phone": "+70510356620"}
0005435383137	B59B57	6543 544654	ANATOLIY KULIKOV	{"email": "anatoliy-kulikov1985@postgrespro.ru", "phone": "+70738777156"}
0005435383138	B59B57	0172 013162	ALEKSANDR GUSEV	{"email": "gusev_aleksandr.021972@postgrespro.ru", "phone": "+70333626822"}
0005435383139	2464C9	1774 472162	VALERIY FROLOV	{"email": "frolov-valeriy.16011973@postgrespro.ru", "phone": "+70790269716"}
0005435383140	ED5BA2	0120 553787	EKATERINA IVANOVA	{"email": "ekaterinaivanova.071978@postgrespro.ru", "phone": "+70674995417"}
0005435383141	BAA93D	6055 627035	ALEKSANDR ROMANOV	{"phone": "+70447971142"}
0005435383142	BAA93D	0341 595914	SERGEY DAVYDOV	{"phone": "+70270844175"}
0005435383143	E68479	4006 161055	PELAGEYA EGOROVA	{"phone": "+70616559353"}
0005435383144	D4A6A1	0301 198075	ALINA ZHURAVLEVA	{"phone": "+70595848912"}
0005435383145	D4A6A1	2904 948103	ANTON GERASIMOV	{"email": "gerasimov-a051964@postgrespro.ru", "phone": "+70914385064"}
0005435383146	234D74	2022 294522	ALEKSANDR ISAEV	{"email": "aisaev.1981@postgrespro.ru", "phone": "+70095777016"}
0005435383147	234D74	4429 895104	EVGENIYA KUDRYASHOVA	{"phone": "+70971723274"}
0005435383148	D2D189	0793 874830	EGOR SHEVCHENKO	{"email": "shevchenkoegor1974@postgrespro.ru", "phone": "+70379774676"}
0005435383149	D2D189	1009 848775	ALEKSEY POPOV	{"phone": "+70718228341"}
0005435383150	7FE936	9929 267145	YURIY MAKAROV	{"email": "makarov-y.071960@postgrespro.ru", "phone": "+70123526676"}
0005435383151	45BFD2	4276 402812	RAFIS VOLKOV	{"phone": "+70496229267"}
0005435383152	45BFD2	2489 351592	NAILYA VOLKOVA	{"phone": "+70477347511"}
0005435383153	C37A97	2556 073122	MARINA GAVRILOVA	{"phone": "+70479235614"}
0005435383154	B8939D	7545 475758	LYUDMILA KOVALEVA	{"email": "kovalevalyudmila_16041971@postgrespro.ru", "phone": "+70040635588"}
0005435383155	74FC8D	4543 496426	ALEKSANDR ZHUKOV	{"phone": "+70365979105"}
0005435383156	74FC8D	0555 192377	OLEG MAKSIMOV	{"email": "maksimov_oleg-1967@postgrespro.ru", "phone": "+70714032486"}
0005435383157	74FC8D	0317 950980	VALENTINA MASLOVA	{"phone": "+70105192239"}
0005435383158	99CF98	6759 056155	OKSANA KUZNECOVA	{"email": "okuznecova.20081973@postgrespro.ru", "phone": "+70655470765"}
0005435383159	5B4EFC	2366 117109	LYUBOV STEPANOVA	{"phone": "+70936602076"}
0005435383160	2F2FEF	4632 786714	OLEG ISAEV	{"email": "isaev-oleg1984@postgrespro.ru", "phone": "+70474051726"}
0005435383161	2F2FEF	2309 539712	LYUDMILA SMIRNOVA	{"phone": "+70187304028"}
0005435383162	C5008F	7660 986551	ANTON DENISOV	{"email": "adenisov061973@postgrespro.ru", "phone": "+70810947460"}
0005435383163	C5008F	3734 692040	PAVEL ZAKHAROV	{"phone": "+70937119087"}
0005435383164	CBC2A4	1192 404988	ALEKSANDR KUZNECOV	{"phone": "+70965070700"}
0005435383165	283E03	1647 630015	NATALYA FOMINA	{"phone": "+70751371535"}
0005435383166	553557	4842 154150	ALEKSANDR TARASOV	{"email": "aleksandrtarasov_031964@postgrespro.ru", "phone": "+70238330187"}
0005435383167	5FBC03	7097 821114	SERGEY ALEKSANDROV	{"phone": "+70880316300"}
0005435383168	5FBC03	8102 088747	OLGA IVANOVA	{"email": "ivanova-olga.1971@postgrespro.ru", "phone": "+70600811065"}
0005435383169	B7A9B6	2977 886971	ANNA IVANOVA	{"email": "anna_ivanova.25101976@postgrespro.ru", "phone": "+70130431766"}
0005435383170	44921A	3291 428107	VALERIY GAVRILOV	{"email": "gavrilovv-15081966@postgrespro.ru", "phone": "+70619873032"}
0005435383171	B228C2	5073 012789	IVAN BELOV	{"phone": "+70715558866"}
0005435383172	6BAA85	8756 457352	LYUBOV OSIPOVA	{"email": "osipovalyubov1951@postgrespro.ru", "phone": "+70815179447"}
0005435383173	6BAA85	2459 045371	VALENTINA BELOVA	{"email": "belova.valentina081977@postgrespro.ru", "phone": "+70482076727"}
0005435383174	BBC789	7625 595814	ZHANNA SEMENOVA	{"email": "z.semenova061983@postgrespro.ru", "phone": "+70575600465"}
0005435383175	BBC789	6658 192341	KRISTINA NESTEROVA	{"email": "nesterova_k.1968@postgrespro.ru", "phone": "+70054007781"}
0005435383176	285FA9	4956 164913	VYACHESLAV KUZNECOV	{"email": "vyacheslav-kuznecov.15071971@postgrespro.ru", "phone": "+70408832813"}
0005435383177	55C131	8729 357945	MAKSIM MELNIKOV	{"email": "maksim_melnikov1972@postgrespro.ru", "phone": "+70694146556"}
0005435383178	085C20	4659 938883	ANDREY ROMANOV	{"phone": "+70449909347"}
0005435383179	085C20	4838 597176	VLADIMIR EGOROV	{"phone": "+70182445976"}
0005435383180	085C20	0003 152589	EKATERINA KAZAKOVA	{"phone": "+70700683197"}
0005435383181	F1D887	5416 387667	ANASTASIYA ANISIMOVA	{"phone": "+70112291217"}
0005435383182	F1D887	5050 040725	LYUDMILA STEPANOVA	{"email": "stepanova.lyudmila-08031973@postgrespro.ru", "phone": "+70836762551"}
0005435383183	08AA44	2333 358336	TAMARA LUKYANOVA	{"phone": "+70147408114"}
0005435383184	08AA44	0357 677494	ELENA PAVLOVA	{"email": "elena_pavlova.101978@postgrespro.ru", "phone": "+70431885914"}
0005435383185	C2E144	5514 190306	TATYANA MELNIKOVA	{"phone": "+70102706842"}
0005435383186	526D9F	1605 819404	ELENA ROMANOVA	{"phone": "+70432595276"}
0005435383187	AADC0D	9558 003835	ARTUR NIKOLAEV	{"phone": "+70444934223"}
0005435383188	FF5E6A	3911 446046	VLADIMIR GERASIMOV	{"phone": "+70903518244"}
0005435383189	FF5E6A	6880 646515	ALEKSANDR MIRONOV	{"phone": "+70592471124"}
0005435383190	4DC662	5921 729530	DENIS KAZAKOV	{"email": "kazakov-d011974@postgrespro.ru", "phone": "+70638850142"}
0005435383191	59C802	9927 039800	MARIYA ANDREEVA	{"email": "andreeva-mariya.1980@postgrespro.ru", "phone": "+70467643264"}
0005435383192	59C802	9406 624495	SERGEY SCHERBAKOV	{"phone": "+70034493804"}
0005435383193	9CA3BF	5506 476932	OLGA ANDREEVA	{"email": "andreevaolga1964@postgrespro.ru", "phone": "+70437340061"}
0005435383194	9CA3BF	5133 571809	SERGEY MOROZOV	{"email": "morozov.s-1979@postgrespro.ru", "phone": "+70890305763"}
0005435383195	9CA3BF	5714 557446	MARIYA ZAKHAROVA	{"email": "zakharova.m-081971@postgrespro.ru", "phone": "+70000132513"}
0005435383196	B30971	7164 059511	VSEVOLOD KUZMIN	{"email": "v.kuzmin-1968@postgrespro.ru", "phone": "+70549158662"}
0005435383197	B416E3	9246 512834	LYUDMILA PETROVA	{"phone": "+70945730176"}
0005435383198	B416E3	2430 010931	SERGEY OSIPOV	{"email": "s_osipov_1970@postgrespro.ru", "phone": "+70172540081"}
0005435383199	24631E	3916 487254	NATALYA ARKHIPOVA	{"email": "arkhipova-natalya091978@postgrespro.ru", "phone": "+70380924662"}
0005435383200	D9D4D8	1039 210179	MIROSLAV NOVIKOV	{"email": "m_novikov31071975@postgrespro.ru", "phone": "+70019306007"}
0005435383201	D9D4D8	2648 644904	ARTEM ZAKHAROV	{"phone": "+70415404363"}
0005435383202	E5A12A	9050 639581	LYUDMILA KISELEVA	{"email": "lkiseleva1958@postgrespro.ru", "phone": "+70893187097"}
0005435383203	E5A12A	5910 174428	DMITRIY VOROBEV	{"email": "vorobev.d.1983@postgrespro.ru", "phone": "+70414557980"}
0005435383204	B4E891	7775 513724	ANASTASIYA FILIPPOVA	{"phone": "+70603108636"}
0005435383205	9B7FE6	7857 040082	YURIY MATVEEV	{"email": "y.matveev-18081976@postgrespro.ru", "phone": "+70792332646"}
0005435383206	E85E55	5827 108180	NIKOLAY ISAEV	{"email": "nisaev1971@postgrespro.ru", "phone": "+70648873732"}
0005435383207	9F20DD	1606 293640	EKATERINA POPOVA	{"email": "e-popova.24021968@postgrespro.ru", "phone": "+70502950729"}
0005435383208	9F20DD	5917 391163	VLADIMIR MOROZOV	{"phone": "+70804250892"}
0005435383209	E6F49A	5808 734597	YANA KOVALEVA	{"phone": "+70400730429"}
0005435383210	E6F49A	0713 166652	NIKOLAY ALEKSEEV	{"phone": "+70204827913"}
0005435383211	2BD9CA	3923 476966	KSENIYA IVANOVA	{"email": "ivanova_kseniya071970@postgrespro.ru", "phone": "+70889878987"}
0005435383212	7CA42C	7240 170668	VALERIY CHERNOV	{"phone": "+70308818721"}
0005435383213	C7113A	7291 338632	MARINA BELOVA	{"phone": "+70158727221"}
0005435383214	C7113A	2655 083062	TAISIYA BORISOVA	{"email": "borisova.taisiya_1970@postgrespro.ru", "phone": "+70410143410"}
0005435383215	B44ACE	7758 777342	ALEKSEY POPOV	{"phone": "+70048735647"}
0005435383216	B44ACE	5768 402419	OLGA MELNIKOVA	{"phone": "+70132873841"}
0005435383217	3ECE09	9625 626980	GULNARA IVANOVA	{"email": "gulnara_ivanova1958@postgrespro.ru", "phone": "+70496290334"}
0005435383218	3ECE09	8872 474391	OLESYA TITOVA	{"phone": "+70915466496"}
0005435383219	B78AD6	0285 409994	LYUDMILA IVANOVA	{"phone": "+70417913919"}
0005435383220	0599F7	0872 248019	DMITRIY MELNIKOV	{"phone": "+70221102525"}
0005435386486	D67C29	5753 876976	SALAVAT SOLOVEV	{"phone": "+70343169240"}
0005435383221	002F5F	8037 622944	ROMAN KONOVALOV	{"email": "konovalov-r_121989@postgrespro.ru", "phone": "+70730980880"}
0005435383222	002F5F	7719 335281	GALINA KULIKOVA	{"email": "galinakulikova_1974@postgrespro.ru", "phone": "+70422968659"}
0005435383223	C1552B	3662 013658	ARTEM ABRAMOV	{"email": "a.abramov_101972@postgrespro.ru", "phone": "+70209829095"}
0005435383224	76AE65	1092 234618	ELENA NIKOLAEVA	{"phone": "+70463015925"}
0005435383225	28EE59	7874 165329	DANIS ALEKSEEV	{"email": "alekseev-danis_1967@postgrespro.ru", "phone": "+70899546918"}
0005435383226	28EE59	4063 018445	VALENTINA NAZAROVA	{"phone": "+70208164138"}
0005435383227	D24CAF	1415 810092	OLEG VLASOV	{"email": "olegvlasov_101974@postgrespro.ru", "phone": "+70995401193"}
0005435383228	E85E4B	3956 907389	OLGA ALEKSEEVA	{"phone": "+70875187076"}
0005435383229	C4BF55	2595 881027	MARINA KOVALEVA	{"email": "m_kovaleva-15041961@postgrespro.ru", "phone": "+70360358430"}
0005435383230	C4BF55	9237 670024	TATYANA NIKITINA	{"phone": "+70266205141"}
0005435383231	C4BF55	5653 338801	ALEKSANDR NAZAROV	{"email": "a_nazarov_1965@postgrespro.ru", "phone": "+70258568889"}
0005435383232	620999	0964 542483	ANNA MAKAROVA	{"email": "anna.makarova.081980@postgrespro.ru", "phone": "+70149847198"}
0005435383233	267538	5927 221011	NINA SCHERBAKOVA	{"email": "n.scherbakova.13101978@postgrespro.ru", "phone": "+70030402459"}
0005435383234	277DF2	0407 493714	ALEKSANDR SOROKIN	{"phone": "+70540206691"}
0005435383235	277DF2	0861 928907	IGOR BARANOV	{"email": "i.baranov_25071978@postgrespro.ru", "phone": "+70743504083"}
0005435383236	A9836B	4667 235749	VYACHESLAV BONDARENKO	{"phone": "+70673399487"}
0005435383237	4F2DCC	1823 420191	TAISIYA PAVLOVA	{"phone": "+70335916662"}
0005435383238	396DE5	7791 421398	LYUBOV ZAKHAROVA	{"phone": "+70232236281"}
0005435383239	01BB10	0128 565918	ALEKSANDR ANDREEV	{"email": "a.andreev.121964@postgrespro.ru", "phone": "+70567411512"}
0005435383240	2D3C44	9097 958726	EKATERINA KOVALEVA	{"phone": "+70537177326"}
0005435383241	2D3C44	6835 860114	RAMIL ANDREEV	{"email": "andreevramil.17091962@postgrespro.ru", "phone": "+70136440689"}
0005435383242	D8CAEA	8649 996510	VLADIMIR ROMANOV	{"email": "vromanov_071972@postgrespro.ru", "phone": "+70699301734"}
0005435383243	D4C7DB	3468 723168	VITALIY SOKOLOV	{"phone": "+70519118194"}
0005435383244	0888C1	4783 164934	ILYA KUZMIN	{"phone": "+70588543358"}
0005435383245	0888C1	9308 571707	SERGEY FEDOTOV	{"phone": "+70079748445"}
0005435383246	53A250	2123 849376	GALINA GERASIMOVA	{"phone": "+70501506879"}
0005435383247	53A250	1152 529744	MARINA ALEKSANDROVA	{"email": "marinaaleksandrova.1967@postgrespro.ru", "phone": "+70059145136"}
0005435383248	3F2A1D	9324 423028	MARAT MAKAROV	{"email": "makarovmarat-011970@postgrespro.ru", "phone": "+70408224975"}
0005435383249	3F2A1D	2388 220391	SERGEY ILIN	{"email": "ilin.sergey.121966@postgrespro.ru", "phone": "+70108972561"}
0005435383250	31E61A	4506 175059	ELENA FEDOROVA	{"phone": "+70242896056"}
0005435383251	31E61A	8472 257310	VIKTOR VASILEV	{"phone": "+70419884700"}
0005435383252	346A82	4672 523921	IVAN ROMANOV	{"email": "i_romanov-04121963@postgrespro.ru", "phone": "+70157285658"}
0005435383253	38C743	7692 183219	VLADIMIR MIRONOV	{"email": "mironov-vladimir24051963@postgrespro.ru", "phone": "+70547020936"}
0005435383254	38C743	9570 484302	IRINA VOLKOVA	{"phone": "+70650014217"}
0005435383255	BA7ED2	8089 912880	LEONID KISELEV	{"email": "kiselev_l14121964@postgrespro.ru", "phone": "+70717099127"}
0005435383256	BA7ED2	7711 196632	NIKOLAY KUZNECOV	{"email": "kuznecov-nikolay.1961@postgrespro.ru", "phone": "+70085882833"}
0005435383257	EC799A	6147 383618	LYUDMILA PETROVA	{"phone": "+70572565482"}
0005435383258	2C6161	6025 469403	GALINA POPOVA	{"email": "popovagalina30041964@postgrespro.ru", "phone": "+70834870862"}
0005435383259	9CA66B	1759 297109	GENNADIY KAZAKOV	{"phone": "+70932581093"}
0005435383260	9CA66B	1757 591972	VERA SAVELEVA	{"email": "saveleva-vera_101978@postgrespro.ru", "phone": "+70102266013"}
0005435383261	283EEB	4925 902242	LYUDMILA SIDOROVA	{"email": "lsidorova07041975@postgrespro.ru", "phone": "+70649111849"}
0005435383262	40E036	0503 274296	MARINA FILIPPOVA	{"email": "filippova-marina-031968@postgrespro.ru", "phone": "+70445116314"}
0005435383263	40E036	2157 893808	SERGEY KULIKOV	{"email": "kulikovsergey.29031973@postgrespro.ru", "phone": "+70803643465"}
0005435383264	AA867D	5689 320067	ANNA KOZLOVA	{"email": "kozlovaanna-091980@postgrespro.ru", "phone": "+70676781383"}
0005435383265	EF669F	5566 610584	ALEKSANDRA MOROZOVA	{"phone": "+70923206877"}
0005435383266	853968	8155 049451	ARTEM MAKSIMOV	{"email": "maksimov-a-101958@postgrespro.ru", "phone": "+70266357105"}
0005435383267	A1D2F1	6920 705688	SERGEY RODIONOV	{"email": "s.rodionov.28061964@postgrespro.ru", "phone": "+70692125197"}
0005435383268	EC132D	1545 638117	ANDREY SIDOROV	{"phone": "+70828249311"}
0005435383269	9D1C73	5441 826468	TAISIYA STEPANOVA	{"phone": "+70923754191"}
0005435383270	4E5B32	8635 698910	MARINA ZHURAVLEVA	{"email": "m-zhuravleva_1973@postgrespro.ru", "phone": "+70907742526"}
0005435383271	584630	2283 492145	SVETLANA AKIMOVA	{"phone": "+70991770384"}
0005435383272	4A8DC6	7635 297088	MIKHAIL VOROBEV	{"phone": "+70860837896"}
0005435383273	4A8DC6	6398 006552	OLGA PETROVA	{"email": "olga-petrova.1972@postgrespro.ru", "phone": "+70969647220"}
0005435383274	6CBF77	9688 364679	YULIYA SIDOROVA	{"phone": "+70722746735"}
0005435383275	1501F2	7273 417042	ALEKSANDR ZAYCEV	{"phone": "+70219650257"}
0005435383276	25F359	9554 446573	VASILIY TARASOV	{"email": "vtarasov061966@postgrespro.ru", "phone": "+70382098588"}
0005435383277	99740B	0198 763673	OLGA KOZLOVA	{"email": "o.kozlova.26111967@postgrespro.ru", "phone": "+70970716943"}
0005435383278	99740B	0535 994247	LILIYA ILINA	{"phone": "+70653621649"}
0005435383279	99740B	0342 867883	PAVEL ABRAMOV	{"phone": "+70823073460"}
0005435383280	16E071	5742 481247	MARINA LAZAREVA	{"email": "marinalazareva01081976@postgrespro.ru", "phone": "+70353284087"}
0005435383281	16E071	6912 997379	ELIZAVETA VASILEVA	{"email": "elizavetavasileva021965@postgrespro.ru", "phone": "+70694437761"}
0005435383282	F2D8BE	7933 759806	DANIIL MELNIKOV	{"email": "daniil.melnikov_23011976@postgrespro.ru", "phone": "+70184624849"}
0005435383283	0DC5DC	8964 884431	YANA ILINA	{"email": "ilinay_021980@postgrespro.ru", "phone": "+70197883563"}
0005435383284	710FBC	3424 278238	MARIYA MAKAROVA	{"email": "makarova-mariya_011974@postgrespro.ru", "phone": "+70487811956"}
0005435383285	6E887D	6557 886649	ARTUR MAKAROV	{"phone": "+70992639335"}
0005435383286	6E887D	2744 786854	GEORGIY ZHURAVLEV	{"email": "georgiy.zhuravlev-121967@postgrespro.ru", "phone": "+70904906453"}
0005435383287	6E887D	8907 205911	DENIS POPOV	{"phone": "+70941251431"}
0005435383288	7483E2	4168 976473	IRAIDA KUZNECOVA	{"email": "i.kuznecova1969@postgrespro.ru", "phone": "+70291681534"}
0005435383289	7483E2	1531 505757	MAYYA MAKAROVA	{"phone": "+70609016700"}
0005435383290	B1FCD9	2123 350056	ELVIRA BOGDANOVA	{"email": "elvira_bogdanova011980@postgrespro.ru", "phone": "+70402814779"}
0005435383291	009FD3	7153 936387	RUSLAN KRASNOV	{"email": "r.krasnov15051968@postgrespro.ru", "phone": "+70690164082"}
0005435383292	6A2504	3827 829970	OLGA ANISIMOVA	{"phone": "+70612455796"}
0005435383293	6A2504	9835 594366	ANNA STEPANOVA	{"phone": "+70033240021"}
0005435383294	2A1DE6	7666 448957	DILYARA KARPOVA	{"phone": "+70506181900"}
0005435383295	E18ED3	3284 908155	DARYA FADEEVA	{"email": "darya-fadeeva_13031973@postgrespro.ru", "phone": "+70528754478"}
0005435383296	FDF8DE	2066 602186	ANDREY POPOV	{"phone": "+70148575829"}
0005435383297	63CA3C	7927 289434	RAISA SIDOROVA	{"email": "raisa_sidorova1969@postgrespro.ru", "phone": "+70860123396"}
0005435383298	4CDFAA	7383 692009	VLADIMIR ANTONOV	{"email": "v-antonov_18021976@postgrespro.ru", "phone": "+70983487936"}
0005435383299	2C7444	5052 889705	EGOR SOKOLOV	{"email": "sokolove1966@postgrespro.ru", "phone": "+70099854351"}
0005435383300	2C7444	8877 250707	ANASTASIYA BELOVA	{"phone": "+70513862501"}
0005435383301	535244	0041 316122	RIMMA PETROVA	{"email": "petrova_r-06111973@postgrespro.ru", "phone": "+70335574117"}
0005435383302	535244	9577 489123	ALEKSANDR KARPOV	{"phone": "+70232853987"}
0005435383303	EB92BA	2305 551473	MARINA KOLESNIKOVA	{"email": "kolesnikova-m1974@postgrespro.ru", "phone": "+70645439330"}
0005435383304	EB92BA	9789 463322	NINA ILINA	{"phone": "+70739558528"}
0005435383305	CF0838	0998 753016	EKATERINA ANDREEVA	{"email": "andreevae_13081965@postgrespro.ru", "phone": "+70587866221"}
0005435383306	14A5E6	9533 758558	ALEKSANDR SOKOLOV	{"email": "asokolov21091978@postgrespro.ru", "phone": "+70310962693"}
0005435383307	D58C31	5294 626174	LYUDMILA VOLKOVA	{"email": "volkova.lyudmila_15121958@postgrespro.ru", "phone": "+70196595463"}
0005435383308	D58C31	9758 063963	ZLATA DANILOVA	{"phone": "+70239750661"}
0005435386623	E1816E	9311 279598	VALENTINA SMIRNOVA	{"phone": "+70022022678"}
0005435386454	BA3E0B	7743 469151	ALEKSEY KUZNECOV	{"phone": "+70799287662"}
0005435386455	E3F076	2715 833286	VALERIY EGOROV	{"email": "egorov_v.091979@postgrespro.ru", "phone": "+70681805852"}
0005435386456	C95DE2	0274 911016	RAISA ANTONOVA	{"email": "antonova.r-1972@postgrespro.ru", "phone": "+70074146453"}
0005435386457	C95DE2	1933 319852	FEDOR KAZAKOV	{"phone": "+70683501124"}
0005435386458	7AF02A	8937 674310	PETR MAKAROV	{"phone": "+70765633749"}
0005435386459	7AF02A	8380 376523	DMITRIY SERGEEV	{"email": "dmitriysergeev-27051970@postgrespro.ru", "phone": "+70707593545"}
0005435386460	7AF02A	4164 718298	GENNADIY SCHERBAKOV	{"phone": "+70021702707"}
0005435386461	CDCCAD	5398 337759	VLADISLAV KOROLEV	{"phone": "+70570475175"}
0005435386462	CDCCAD	1550 645658	TATYANA KAZAKOVA	{"email": "kazakovatatyana-1976@postgrespro.ru", "phone": "+70698570338"}
0005435386463	21A4FA	3292 154843	DMITRIY MEDVEDEV	{"email": "dmitriymedvedev-111966@postgrespro.ru", "phone": "+70995080466"}
0005435386464	72BCF4	8162 718297	SERGEY ISAEV	{"phone": "+70590403539"}
0005435386465	F2ADE6	4436 215229	SERGEY ROMANOV	{"phone": "+70691760955"}
0005435386466	DEA7F2	0636 821745	ELENA KISELEVA	{"phone": "+70393023920"}
0005435386467	DEA7F2	2142 812242	DMITRIY MATVEEV	{"email": "matveev-dmitriy_1976@postgrespro.ru", "phone": "+70991928360"}
0005435386468	058E80	3656 702367	RAMIL MEDVEDEV	{"phone": "+70396449474"}
0005435386469	2994E5	2095 047551	VLADIMIR KUZNECOV	{"phone": "+70226590481"}
0005435386470	7830CB	4010 392631	MARIYA PAVLOVA	{"email": "pavlova.mariya-1968@postgrespro.ru", "phone": "+70369371467"}
0005435386471	7830CB	6007 134704	DMITRIY SOROKIN	{"phone": "+70263634837"}
0005435386472	9B8FE1	4479 528314	ALEKSEY OSIPOV	{"email": "osipov-a011979@postgrespro.ru", "phone": "+70071147206"}
0005435386473	E1F027	7261 017370	TATYANA POPOVA	{"phone": "+70321999296"}
0005435386474	5B040B	7706 174877	OLGA KAZAKOVA	{"email": "kazakovao_18081967@postgrespro.ru", "phone": "+70353500679"}
0005435386475	DA1BBD	3196 079184	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr011990@postgrespro.ru", "phone": "+70152330763"}
0005435386476	7588B3	0695 292726	VASILIY PETROV	{"phone": "+70210402691"}
0005435386477	7588B3	9551 396767	DANIIL DMITRIEV	{"email": "d_dmitriev_24011980@postgrespro.ru", "phone": "+70767748431"}
0005435386478	92C364	0662 327649	YANA NAZAROVA	{"phone": "+70469526795"}
0005435386479	E79FAC	4567 717799	YURIY KAZAKOV	{"email": "kazakov.y.121970@postgrespro.ru", "phone": "+70323163015"}
0005435386480	E79FAC	5380 371727	NIKOLAY DENISOV	{"email": "denisov-n-30031991@postgrespro.ru", "phone": "+70840886168"}
0005435386481	BAAF07	7697 238817	DARYA FILIPPOVA	{"phone": "+70785739129"}
0005435386482	C772E4	3508 644537	OLEG YAKOVLEV	{"phone": "+70973566059"}
0005435386483	9F5CBC	5337 699106	NIKOLAY ZAKHAROV	{"phone": "+70305380386"}
0005435386484	2CB30D	1491 078661	TATYANA PETROVA	{"phone": "+70787323548"}
0005435386485	238044	6636 281437	DANIL MARTYNOV	{"phone": "+70264005071"}
0005435386487	74EB4B	6136 664783	VALENTINA SAVELEVA	{"email": "vsaveleva-02091978@postgrespro.ru", "phone": "+70055349750"}
0005435386488	2B7E02	5105 548008	NINA MIRONOVA	{"phone": "+70519883816"}
0005435386489	074294	4063 943698	OLGA SERGEEVA	{"phone": "+70599878378"}
0005435386490	7492C3	2157 227736	ALEKSANDRA KUZNECOVA	{"email": "a.kuznecova-14051964@postgrespro.ru", "phone": "+70881149333"}
0005435386491	7492C3	8050 891210	NADEZHDA MOISEEVA	{"email": "n.moiseeva051971@postgrespro.ru", "phone": "+70900841755"}
0005435386492	A4C744	8458 407166	RAISA FROLOVA	{"phone": "+70190867560"}
0005435386493	A4C744	7603 328335	OLGA ANDREEVA	{"phone": "+70261466561"}
0005435386494	EC6F24	0565 579047	VLADIMIR ZHURAVLEV	{"email": "zhuravlevvladimir-07081966@postgrespro.ru", "phone": "+70145243137"}
0005435386495	EC6F24	1728 202028	OLEG BARANOV	{"email": "baranovo101970@postgrespro.ru", "phone": "+70164276279"}
0005435386496	EC6F24	9624 210055	IRINA MAKSIMOVA	{"phone": "+70157948223"}
0005435386497	EC6F24	6087 555617	SVYATOSLAV KUZNECOV	{"email": "kuznecovs_1977@postgrespro.ru", "phone": "+70705139440"}
0005435386498	955F58	1518 223467	TATYANA MIRONOVA	{"email": "mironova_t041983@postgrespro.ru", "phone": "+70199606831"}
0005435386499	DA1723	3484 574052	SVETLANA EGOROVA	{"phone": "+70964209851"}
0005435386500	A9EC89	0011 419435	GALINA KALININA	{"email": "gkalinina_1984@postgrespro.ru", "phone": "+70930155245"}
0005435386501	A9EC89	3945 887930	EVGENIY YAKOVLEV	{"phone": "+70463610661"}
0005435386502	52C512	4226 717761	EVGENIYA GORBUNOVA	{"phone": "+70291996163"}
0005435386503	52C512	1640 044615	ALEKSANDR NAZAROV	{"email": "nazarovaleksandr.1979@postgrespro.ru", "phone": "+70649278532"}
0005435386504	47C224	0612 440766	ALEKSANDR SMIRNOV	{"email": "a-smirnov-29061986@postgrespro.ru", "phone": "+70074600844"}
0005435386505	5248CC	1722 360377	LEONID VOROBEV	{"phone": "+70197404673"}
0005435386506	7AD671	8638 964381	TATYANA ANISIMOVA	{"phone": "+70120283832"}
0005435386507	7AD671	2167 873943	MARIYA OSIPOVA	{"phone": "+70030791439"}
0005435386508	F26273	9762 743032	ANNA ALEKSEEVA	{"phone": "+70956909983"}
0005435386509	F26273	0937 491045	VADIM ZHURAVLEV	{"email": "zhuravlevv.1972@postgrespro.ru", "phone": "+70569937421"}
0005435386510	F6D071	9182 124358	ROMAN SOROKIN	{"phone": "+70904632212"}
0005435386511	436D6B	8273 751087	VIKTOR ZAKHAROV	{"phone": "+70215375592"}
0005435386512	436D6B	6843 315270	DANIL PAVLOV	{"email": "danil_pavlov.101980@postgrespro.ru", "phone": "+70191811664"}
0005435386513	E3DD32	4861 826696	ZULFIYA KULIKOVA	{"phone": "+70155657949"}
0005435386514	5A3BA2	1083 942291	KIRILL EGOROV	{"email": "egorov.kirill041966@postgrespro.ru", "phone": "+70280955473"}
0005435386515	5A3BA2	8763 247326	NIKOLAY VASILEV	{"email": "vasilev.n.1975@postgrespro.ru", "phone": "+70848476062"}
0005435386516	E90BF1	6851 487773	TAMARA ANDREEVA	{"email": "tamaraandreeva_14041978@postgrespro.ru", "phone": "+70354253565"}
0005435386517	E90BF1	1313 427371	MIKHAIL PETROV	{"phone": "+70423217635"}
0005435386518	98FD71	7856 827507	ELENA FILATOVA	{"phone": "+70410935222"}
0005435386519	1E42D6	6060 420041	ARTEM SMIRNOV	{"phone": "+70555253441"}
0005435386520	D46094	7878 057705	TAISIYA DMITRIEVA	{"email": "dmitrieva.taisiya-12051976@postgrespro.ru", "phone": "+70925131339"}
0005435386521	D46094	4267 535713	YANA PETROVA	{"phone": "+70926475782"}
0005435386522	AC518F	6446 342168	NINA KOVALEVA	{"email": "n_kovaleva.101963@postgrespro.ru", "phone": "+70553973578"}
0005435386523	F6A7DD	8687 311146	KIRILL GERASIMOV	{"phone": "+70054342412"}
0005435386524	F6A7DD	8208 334560	RAISA VOLKOVA	{"email": "r.volkova.1978@postgrespro.ru", "phone": "+70246255650"}
0005435386525	63AA13	6720 272331	SERGEY ALEKSEEV	{"email": "sergeyalekseev.16051969@postgrespro.ru", "phone": "+70068293885"}
0005435386526	30DAD0	9833 285675	VALENTINA KALININA	{"phone": "+70398302340"}
0005435386527	AF34DC	4947 136051	VALENTINA MIKHAYLOVA	{"email": "valentinamikhaylova-111978@postgrespro.ru", "phone": "+70597259501"}
0005435386528	D7D316	7873 056545	NADEZHDA KUZNECOVA	{"email": "kuznecovanadezhda.051981@postgrespro.ru", "phone": "+70078265002"}
0005435386529	935326	2954 842660	ELENA BELYAEVA	{"phone": "+70929793795"}
0005435386530	E10144	1915 479314	ANNA ANDREEVA	{"phone": "+70525686398"}
0005435386531	3D42D7	0298 746985	MARINA ANDREEVA	{"email": "mandreeva08071974@postgrespro.ru", "phone": "+70767349299"}
0005435386532	E6C4AA	4010 794380	ALEKSANDR MAKAROV	{"phone": "+70032384414"}
0005435386533	8F5B40	9231 394447	NIKOLAY PETROV	{"phone": "+70643801577"}
0005435386534	80F114	6957 713164	MARIYA MASLOVA	{"email": "maslova_m.1977@postgrespro.ru", "phone": "+70777839692"}
0005435386535	02194A	6467 343602	NIKOLAY SIDOROV	{"email": "nikolay-sidorov.13031987@postgrespro.ru", "phone": "+70459506554"}
0005435386536	72575B	5690 400435	VITALIY KOZLOV	{"phone": "+70700075765"}
0005435386537	3E8CAE	1601 336853	PAVEL STEPANOV	{"email": "stepanov.pavel_26081973@postgrespro.ru", "phone": "+70383165739"}
0005435386538	3E8CAE	5042 163154	EKATERINA AFANASEVA	{"email": "e-afanaseva_27031974@postgrespro.ru", "phone": "+70516965898"}
0005435386539	A30EEE	6899 208672	MARINA KONOVALOVA	{"email": "m.konovalova05091968@postgrespro.ru", "phone": "+70047159209"}
0005435386540	A30EEE	2356 887008	VALERIYA BELOVA	{"phone": "+70386340772"}
0005435386541	14BF19	1207 330390	DANIIL TIMOFEEV	{"phone": "+70937634687"}
0005435386542	7DE237	4689 711959	ROMAN MIKHAYLOV	{"email": "rmikhaylov101964@postgrespro.ru", "phone": "+70868312025"}
0005435386543	F490D4	1761 914326	ANTONINA IVANOVA	{"email": "ivanova.antonina-1971@postgrespro.ru", "phone": "+70243865937"}
0005435386544	2BF603	8406 613586	ANTON NAUMOV	{"phone": "+70140235163"}
0005435386545	C085CA	1261 705216	IRINA KOMAROVA	{"email": "komarova.i021969@postgrespro.ru", "phone": "+70256573828"}
0005435386546	D065C1	5961 542863	IRINA ILINA	{"phone": "+70516794138"}
0005435386547	32F35E	9667 077346	VIKTOR VOLKOV	{"email": "v.volkov.19031979@postgrespro.ru", "phone": "+70415064445"}
0005435386548	784E8F	1062 343948	ANDREY KISELEV	{"email": "andrey-kiselev-15021966@postgrespro.ru", "phone": "+70984180615"}
0005435386549	109E93	3631 364847	BOGDAN MAKAROV	{"phone": "+70394547021"}
0005435386550	0B2A6C	1585 681083	VALENTINA STEPANOVA	{"email": "valentina.stepanova18101962@postgrespro.ru", "phone": "+70708151332"}
0005435386551	0B2A6C	5518 963630	NIKOLAY FOMIN	{"phone": "+70279497647"}
0005435386552	E882AF	7633 458333	NATALYA FROLOVA	{"phone": "+70977674669"}
0005435386553	F3269C	5115 532631	MARIYA ZAKHAROVA	{"phone": "+70729555230"}
0005435386554	1A6234	0395 206485	YULIYA BELYAEVA	{"email": "yuliya-belyaeva_21021972@postgrespro.ru", "phone": "+70656733229"}
0005435386555	78229B	0575 013053	EKATERINA MAKAROVA	{"email": "makarova-ekaterina101971@postgrespro.ru", "phone": "+70679152854"}
0005435386556	08503E	0035 828184	MAKSIM ILIN	{"email": "m-ilin.22091963@postgrespro.ru", "phone": "+70780091347"}
0005435386557	0748F3	7683 700196	VALERIY VASILEV	{"email": "vasilev.v.11101970@postgrespro.ru", "phone": "+70640476763"}
0005435386558	0748F3	9766 288358	VLADIMIR IVANOV	{"email": "vladimir_ivanov_1968@postgrespro.ru", "phone": "+70285586512"}
0005435386559	0748F3	6596 553900	VYACHESLAV FEDOROV	{"email": "fedorov-vyacheslav.1977@postgrespro.ru", "phone": "+70789469743"}
0005435386560	A5E04C	7256 545416	DANIIL EGOROV	{"phone": "+70302970305"}
0005435386561	E99A35	3511 831827	VITALIY OSIPOV	{"phone": "+70170118642"}
0005435386562	4EDBDF	7416 023910	TATYANA YAKOVLEVA	{"email": "yakovleva.t31051966@postgrespro.ru", "phone": "+70660967575"}
0005435386563	4EDBDF	5109 869951	VERA NIKITINA	{"phone": "+70306503938"}
0005435386564	70A5B4	2913 157445	KIRILL SAVELEV	{"email": "k-savelev.04081980@postgrespro.ru", "phone": "+70417982182"}
0005435386565	FBF69C	9261 584834	NATALYA KAZAKOVA	{"phone": "+70297058281"}
0005435386566	EFD828	3145 212019	VYACHESLAV MATVEEV	{"email": "matveev.v.25071973@postgrespro.ru", "phone": "+70012018648"}
0005435386567	A48572	5266 757303	DMITRIY VOLKOV	{"email": "volkov-dmitriy_21111967@postgrespro.ru", "phone": "+70338631703"}
0005435386568	22C725	3991 898914	YULIYA LAZAREVA	{"phone": "+70584059411"}
0005435386569	22C725	6471 006425	NATALYA KUZNECOVA	{"phone": "+70149743995"}
0005435386570	458735	7852 370469	ELENA ANISIMOVA	{"phone": "+70621222965"}
0005435386571	458735	7944 849383	EKATERINA VOROBEVA	{"email": "vorobeva_e06011975@postgrespro.ru", "phone": "+70450632737"}
0005435386572	9A1EFA	0256 717783	ANDREY SMIRNOV	{"phone": "+70249308219"}
0005435386573	61410D	7182 555790	ALEKSANDR VOLKOV	{"phone": "+70309866462"}
0005435386574	A7F9B6	7215 464948	ALEKSANDR VASILEV	{"phone": "+70493136137"}
0005435386575	7735A1	8840 228749	BULAT KUZNECOV	{"email": "kuznecovbulat-1964@postgrespro.ru", "phone": "+70202555268"}
0005435386576	6E602B	7653 367605	ALEKSEY MAKAROV	{"phone": "+70512499242"}
0005435386577	6E602B	4807 544601	ELENA DMITRIEVA	{"email": "e.dmitrieva.31031977@postgrespro.ru", "phone": "+70594484054"}
0005435386578	4F9DEB	8273 237276	VIKTOR KARPOV	{"email": "karpov.viktor-21071970@postgrespro.ru", "phone": "+70737607688"}
0005435386579	AB1019	9107 155827	IRINA DMITRIEVA	{"email": "dmitrieva_irina-1980@postgrespro.ru", "phone": "+70672700613"}
0005435386580	0829D5	9451 529787	PETR FOMIN	{"phone": "+70708884405"}
0005435386581	8D41F5	2143 198488	ANTON SMIRNOV	{"email": "a.smirnov-111963@postgrespro.ru", "phone": "+70996314421"}
0005435386582	8D41F5	2714 155741	DMITRIY MIKHAYLOV	{"email": "mikhaylov-dmitriy.1963@postgrespro.ru", "phone": "+70520146118"}
0005435386583	DD7553	6180 502013	SEMEN IVANOV	{"phone": "+70280534883"}
0005435386584	E0CF3D	9159 076343	EKATERINA ANDREEVA	{"email": "eandreeva_051992@postgrespro.ru", "phone": "+70159030815"}
0005435386585	E0CF3D	4642 610718	VLADIMIR FROLOV	{"email": "frolov-vladimir-1968@postgrespro.ru", "phone": "+70009741337"}
0005435386586	E0CF3D	4083 261231	YURIY SOROKIN	{"email": "y_sorokin.1972@postgrespro.ru", "phone": "+70346211912"}
0005435386587	3043BA	9952 885540	NIKOLAY MARTYNOV	{"phone": "+70426674366"}
0005435386588	3043BA	9266 907577	MARIYA FILIPPOVA	{"phone": "+70401560471"}
0005435386589	EC3C21	7707 081391	ARTEM ABRAMOV	{"phone": "+70535425386"}
0005435386590	EC3C21	0506 509398	ELENA KONDRATEVA	{"email": "kondrateva-e.15021969@postgrespro.ru", "phone": "+70172066712"}
0005435386591	45CD44	3502 805972	GALINA ZOTOVA	{"email": "g_zotova_111971@postgrespro.ru", "phone": "+70543800941"}
0005435386592	64E437	8296 267371	DMITRIY KULIKOV	{"phone": "+70886760516"}
0005435386593	86BF63	9612 138553	SOFIYA SAVELEVA	{"email": "sofiya-saveleva.071978@postgrespro.ru", "phone": "+70032859348"}
0005435386594	BF52C5	2541 296047	VLADIMIR ZHUKOV	{"phone": "+70613950271"}
0005435386595	3E56B4	6750 019212	ANATOLIY NAZAROV	{"email": "nazarov-anatoliy_1967@postgrespro.ru", "phone": "+70541483271"}
0005435386596	BD95A9	9533 928931	MATVEY KOROLEV	{"phone": "+70829315216"}
0005435386597	BD95A9	1614 473916	VALERIY SEMENOV	{"phone": "+70020652721"}
0005435386598	493554	1478 871383	VIKTOR ISAEV	{"phone": "+70670150674"}
0005435386599	43AE30	5450 408585	NAILYA ALEKSEEVA	{"phone": "+70458661101"}
0005435386600	43AE30	7413 906228	IVAN VOLKOV	{"phone": "+70751060123"}
0005435386601	254837	2339 080685	KRISTINA EGOROVA	{"phone": "+70286877119"}
0005435386602	B66115	1065 898331	ALEKSEY KRASNOV	{"email": "krasnov-a-071983@postgrespro.ru", "phone": "+70691333863"}
0005435386603	B66115	2876 640082	VALENTINA NAUMOVA	{"email": "vnaumova_081971@postgrespro.ru", "phone": "+70811835343"}
0005435386604	B66115	3076 395750	ANATOLIY MATVEEV	{"email": "amatveev.031976@postgrespro.ru", "phone": "+70280945613"}
0005435386605	68FAC1	8829 319190	OLEG VOROBEV	{"email": "vorobev-o031975@postgrespro.ru", "phone": "+70856154595"}
0005435386606	ECE307	2885 968274	ILMIR PETROV	{"email": "petrov_i20071967@postgrespro.ru", "phone": "+70973132689"}
0005435386607	7AB433	9098 123309	IVAN MAKSIMOV	{"email": "maksimov_i111988@postgrespro.ru", "phone": "+70242777274"}
0005435386608	7AB433	9999 287132	OLGA ROMANOVA	{"email": "romanova-olga101979@postgrespro.ru", "phone": "+70997999041"}
0005435386609	4BC974	6702 458583	ELENA GUSEVA	{"email": "gusevae_1965@postgrespro.ru", "phone": "+70541613539"}
0005435386610	2C6BFF	3012 176669	NATALYA ANTONOVA	{"email": "n-antonova_03121977@postgrespro.ru", "phone": "+70177716045"}
0005435386611	12B742	1119 713854	DIANA SERGEEVA	{"email": "sergeeva-diana-031975@postgrespro.ru", "phone": "+70427527275"}
0005435386612	12B742	3020 244982	LEONID GRIGOREV	{"email": "leonid_grigorev_021978@postgrespro.ru", "phone": "+70721493603"}
0005435386613	4FF7F6	4833 515083	IGOR SEMENOV	{"phone": "+70494326038"}
0005435386614	893C1C	6294 300932	ELENA BORISOVA	{"phone": "+70752271411"}
0005435386615	1EBA71	2394 741703	ZINAIDA ZHUKOVA	{"email": "zhukova.zinaida.11091966@postgrespro.ru", "phone": "+70178896674"}
0005435386616	96BE2B	8253 618400	NIKOLAY POPOV	{"phone": "+70920499594"}
0005435386617	83145B	0165 163643	KLAVDIYA ZAKHAROVA	{"phone": "+70273988265"}
0005435386618	B4C729	4998 316702	ANTON YAKOVLEV	{"email": "ayakovlev_121975@postgrespro.ru", "phone": "+70178967105"}
0005435386619	EE9121	0742 302849	SERGEY SCHERBAKOV	{"phone": "+70132121038"}
0005435386620	EE9121	3565 884492	TATYANA PAVLOVA	{"email": "tatyana_pavlova-16051975@postgrespro.ru", "phone": "+70568964089"}
0005435386621	AD6745	2516 870647	DINA KALININA	{"phone": "+70007175118"}
0005435386622	C4F8F2	7412 981441	VALERIY KULIKOV	{"email": "v-kulikov.1962@postgrespro.ru", "phone": "+70592160427"}
0005435386624	0E4B3C	8204 122999	ANTON GRIGOREV	{"phone": "+70904782190"}
0005435386625	0E4B3C	5182 138028	MAKSIM NAZAROV	{"email": "nazarovmaksim-1969@postgrespro.ru", "phone": "+70777848130"}
0005435386626	DF50A1	1416 519013	NIKOLAY BORISOV	{"phone": "+70998217075"}
0005435386627	F4CAF6	3420 338599	ALEKSEY IVANOV	{"email": "aleksey.ivanov-031969@postgrespro.ru", "phone": "+70885024093"}
0005435386628	F4CAF6	3472 951931	EGOR SMIRNOV	{"phone": "+70299006950"}
0005435386629	F4CAF6	3066 642399	OLGA NOVIKOVA	{"email": "olga.novikova-091967@postgrespro.ru", "phone": "+70653902369"}
0005435386630	3FB38E	9152 291617	MARIYA KOZLOVA	{"email": "mkozlova_041971@postgrespro.ru", "phone": "+70611866792"}
0005435386631	329340	3590 892388	ALEKSANDR IVANOV	{"email": "ivanovaleksandr-1962@postgrespro.ru", "phone": "+70586403620"}
0005435386632	329340	5097 991965	SVETLANA AFANASEVA	{"email": "afanaseva_svetlana.1971@postgrespro.ru", "phone": "+70072991743"}
0005435386633	8F92F4	5801 975708	DANIS KUZNECOV	{"email": "kuznecovdanis1971@postgrespro.ru", "phone": "+70615874978"}
0005435386634	04D398	4967 426078	ARTEM SAVELEV	{"phone": "+70913233846"}
0005435386635	01B68B	7920 291325	LIDIYA ZAKHAROVA	{"email": "lidiyazakharova-28041966@postgrespro.ru", "phone": "+70643548665"}
0005435386636	FD29B2	8138 955988	MARIYA GERASIMOVA	{"email": "gerasimova_m041972@postgrespro.ru", "phone": "+70365713614"}
0005435386637	922BDB	0804 422925	ALEKSANDRA SAVELEVA	{"phone": "+70516245623"}
0005435386638	922BDB	1656 169237	ANDREY EGOROV	{"email": "a.egorov.18031974@postgrespro.ru", "phone": "+70598724644"}
0005435386639	B108F7	5645 389328	VLADIMIR NAUMOV	{"email": "naumovvladimir21031977@postgrespro.ru", "phone": "+70167150702"}
0005435386640	A0BF4F	7181 052058	VIKTOR VOLKOV	{"email": "volkovviktor1971@postgrespro.ru", "phone": "+70922101956"}
0005435386641	A00083	4898 424166	ELENA ANTONOVA	{"phone": "+70095239995"}
0005435386642	698430	0972 571847	SERGEY SOKOLOV	{"email": "sokolov_s021969@postgrespro.ru", "phone": "+70636555402"}
0005435386643	975ED1	1516 180801	AMINA CHERNOVA	{"phone": "+70989460093"}
0005435386644	2B925B	7598 955775	KRISTINA BORISOVA	{"email": "kristina.borisova_041976@postgrespro.ru", "phone": "+70080136535"}
0005435386645	07FB4F	2631 390657	GLEB VOLKOV	{"phone": "+70208391123"}
0005435386646	B6EB5E	8373 046586	ALEKSANDR SERGEEV	{"phone": "+70666311976"}
0005435386647	FD2750	6806 124427	VYACHESLAV BARANOV	{"email": "baranov.v.08111971@postgrespro.ru", "phone": "+70625538438"}
0005435386648	9951E5	9846 501646	YURIY ILIN	{"phone": "+70870376813"}
0005435386649	170B38	9341 803115	SVETLANA SCHERBAKOVA	{"email": "scherbakova-svetlana.1967@postgrespro.ru", "phone": "+70672673226"}
0005435386650	B76E1C	5669 955925	YANA BELYAEVA	{"email": "belyaevayana_091978@postgrespro.ru", "phone": "+70639867286"}
0005435386651	6733DF	8748 323873	IRINA ALEKSEEVA	{"phone": "+70383609983"}
0005435386652	6733DF	4443 461807	EVGENIYA SAVELEVA	{"phone": "+70372930321"}
0005435386653	62775C	1131 792791	PAVEL FROLOV	{"phone": "+70826470418"}
0005435386654	62775C	2420 837724	GALINA DAVYDOVA	{"phone": "+70537448173"}
0005435386655	EEE821	0577 991527	ALEKSEY FROLOV	{"email": "a_frolov.051974@postgrespro.ru", "phone": "+70966478206"}
0005435386656	9D07FA	5476 849710	ARTUR GRIGOREV	{"phone": "+70363898783"}
0005435386657	E8B5FD	4271 033963	ELENA BORISOVA	{"phone": "+70404063091"}
0005435386658	E8B5FD	4305 723765	MARIYA MAKSIMOVA	{"phone": "+70989524325"}
0005435386659	889D11	6790 587985	ELENA EGOROVA	{"phone": "+70554755622"}
0005435386660	181D4C	6770 911418	PAVEL ABRAMOV	{"phone": "+70486984961"}
0005435386661	181D4C	3922 585156	LYUDMILA ROMANOVA	{"email": "l.romanova071978@postgrespro.ru", "phone": "+70116364334"}
0005435386662	181D4C	5675 149505	LIDIYA FADEEVA	{"email": "lidiya_fadeeva_1960@postgrespro.ru", "phone": "+70455815063"}
0005435386663	BD8EC3	2331 052339	DANIIL MIKHAYLOV	{"phone": "+70662194293"}
0005435386664	C989FE	6488 553963	LIDIYA FOMINA	{"email": "lidiya_fomina_05121969@postgrespro.ru", "phone": "+70474724341"}
0005435386665	33B2A3	9503 341320	DMITRIY VOLKOV	{"phone": "+70288276651"}
0005435386666	33B2A3	3650 906595	ANTON VOLKOV	{"phone": "+70356363913"}
0005435386667	204E74	6941 248712	DANILA FROLOV	{"email": "d.frolov03111968@postgrespro.ru", "phone": "+70588778552"}
0005435386668	9C2224	8458 103477	MIKHAIL MELNIKOV	{"phone": "+70223021131"}
0005435386669	9C2224	3907 295081	ELENA KOROLEVA	{"email": "koroleva.e021972@postgrespro.ru", "phone": "+70665226469"}
0005435386670	9C2224	5417 683448	OLGA MASLOVA	{"email": "maslova-o-1977@postgrespro.ru", "phone": "+70176768680"}
0005435386671	D8CBC1	9556 474178	OLGA SERGEEVA	{"email": "sergeevao-27071968@postgrespro.ru", "phone": "+70862181254"}
0005435386672	31125D	8380 489345	EVGENIY MEDVEDEV	{"email": "emedvedev-24041969@postgrespro.ru", "phone": "+70360798496"}
0005435386673	31125D	2617 429501	ALEKSEY SOLOVEV	{"phone": "+70475735503"}
0005435386674	0494A0	2169 518066	NINA SOLOVEVA	{"email": "soloveva-nina_111967@postgrespro.ru", "phone": "+70839283155"}
0005435386675	855BB5	9205 916392	MARIYA BORISOVA	{"phone": "+70109418076"}
0005435386676	164DED	0876 276192	LARISA NIKOLAEVA	{"phone": "+70267251411"}
0005435386677	164DED	5072 115991	LYUDMILA NOVIKOVA	{"phone": "+70569139744"}
0005435386678	164DED	1841 921491	NATALYA ZHUKOVA	{"phone": "+70277009813"}
0005435386679	665D52	6888 791298	ANATOLIY ANTONOV	{"email": "antonov-anatoliy-071975@postgrespro.ru", "phone": "+70614817489"}
0005435386680	665D52	9739 663269	ANATOLIY PAVLOV	{"email": "anatoliypavlov_28061966@postgrespro.ru", "phone": "+70334634209"}
0005435386681	A3461B	8760 102789	EKATERINA GUSEVA	{"email": "ekaterina-guseva-22101975@postgrespro.ru", "phone": "+70411176230"}
0005435386682	6E4766	1476 043257	OLGA NIKITINA	{"phone": "+70061796765"}
0005435386683	B5B4F9	7110 638925	OLEG MOROZOV	{"phone": "+70639463217"}
0005435386684	4738AA	0567 277583	ALEKSANDR KOROLEV	{"email": "korolev-a_30111981@postgrespro.ru", "phone": "+70476646696"}
0005435386685	498311	0409 195375	SERGEY NIKOLAEV	{"email": "nikolaev-sergey011974@postgrespro.ru", "phone": "+70412181788"}
0005435386686	61AF1B	2140 737186	VIKTOR NOVIKOV	{"phone": "+70689876899"}
0005435386687	7C4849	4768 776655	ALEKSANDR SEMENOV	{"phone": "+70205857348"}
0005435386688	B5C1D0	2208 685879	VASILIY TARASOV	{"email": "tarasov.vasiliy_1971@postgrespro.ru", "phone": "+70180255897"}
0005435386689	E64A62	7559 211345	OLGA FEDOROVA	{"email": "o.fedorova_1986@postgrespro.ru", "phone": "+70407319247"}
0005435386690	E366E3	5293 992987	ALEKSANDRA ANTONOVA	{"phone": "+70774524746"}
0005435386691	6ABE7D	5001 436698	ALEKSANDR SMIRNOV	{"phone": "+70800559466"}
0005435386692	B593F1	7099 274960	SERGEY VOLKOV	{"email": "volkov-sergey-28031972@postgrespro.ru", "phone": "+70080950838"}
0005435386693	B4941C	0650 013497	MARIYA IVANOVA	{"email": "mariya-ivanova011966@postgrespro.ru", "phone": "+70113627072"}
0005435386694	B4941C	4432 867201	NINA SAVELEVA	{"email": "saveleva-nina071974@postgrespro.ru", "phone": "+70155470929"}
0005435386695	191CAA	5789 279751	MARINA LEBEDEVA	{"phone": "+70214470381"}
0005435386696	2B7735	7477 971475	RAISA ZHUKOVA	{"phone": "+70529969952"}
0005435386697	053BA6	8030 311311	ANNA IVANOVA	{"phone": "+70837143328"}
0005435386698	053BA6	7721 468418	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey-051968@postgrespro.ru", "phone": "+70003100630"}
0005435386699	354A83	4504 367121	OLGA PETROVA	{"phone": "+70378392053"}
0005435386700	20674F	5017 765320	TIMUR AFANASEV	{"email": "t_afanasev1980@postgrespro.ru", "phone": "+70205683711"}
0005435386701	20674F	3565 357568	DENIS ZAYCEV	{"email": "zaycevd-1973@postgrespro.ru", "phone": "+70444990672"}
0005435386702	8265CD	8153 894125	GALINA YUDINA	{"phone": "+70591333486"}
0005435386703	20665D	4404 088604	SERGEY GORBUNOV	{"phone": "+70458157246"}
0005435386704	20665D	3830 673285	MIKHAIL SIDOROV	{"email": "mikhail-sidorov11081970@postgrespro.ru", "phone": "+70706790341"}
0005435386705	73DCD3	5128 977370	TATYANA NIKITINA	{"phone": "+70698730578"}
0005435386706	A30353	7058 846660	ANASTASIYA VOROBEVA	{"email": "vorobeva.a.1968@postgrespro.ru", "phone": "+70959722293"}
0005435386707	A0AEA6	2084 402533	ALEKSANDR BONDARENKO	{"phone": "+70217491851"}
0005435386708	72333E	4896 351134	ANATOLIY KARPOV	{"email": "karpova.091969@postgrespro.ru", "phone": "+70937326331"}
0005435386709	72333E	4563 167105	MAKSIM SCHERBAKOV	{"email": "m_scherbakov_15121959@postgrespro.ru", "phone": "+70435685008"}
0005435386710	72333E	5646 508723	VALENTINA IVANOVA	{"phone": "+70358355922"}
0005435386711	311F26	9670 449329	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev-31051971@postgrespro.ru", "phone": "+70750231026"}
0005435386712	ACA672	7632 575561	VASILIY STEPANOV	{"email": "stepanov-vasiliy091975@postgrespro.ru", "phone": "+70528713217"}
0005435386713	45814B	4817 743355	VLADIMIR BELOV	{"email": "belov-v-071974@postgrespro.ru", "phone": "+70775193325"}
0005435386714	FFFE47	7459 208835	ALEKSANDR DENISOV	{"email": "a_denisov-08091962@postgrespro.ru", "phone": "+70764119387"}
0005435386715	FFFE47	0485 382980	NINA ZHURAVLEVA	{"email": "n_zhuravleva.09101965@postgrespro.ru", "phone": "+70143083738"}
0005435386716	92E062	5400 434391	KARINA KOVALEVA	{"email": "karinakovaleva_1977@postgrespro.ru", "phone": "+70688193394"}
0005435386717	92E062	6712 074414	TATYANA GUSEVA	{"email": "gusevat-091964@postgrespro.ru", "phone": "+70421707631"}
0005435386718	87A315	0151 887410	GENNADIY ABRAMOV	{"email": "abramov_g_061967@postgrespro.ru", "phone": "+70022422606"}
0005435386719	BA145A	6760 161508	MARIYA TARASOVA	{"phone": "+70490066744"}
0005435386720	CCE4FD	7550 217257	GALINA DENISOVA	{"phone": "+70942228652"}
0005435386721	DA5331	3192 423114	VLADIMIR KOZLOV	{"email": "v_kozlov_041973@postgrespro.ru", "phone": "+70865194795"}
0005435386722	5BDDF2	2562 822795	ALLA NIKIFOROVA	{"email": "alla_nikiforova_29101979@postgrespro.ru", "phone": "+70578496929"}
0005435386723	CD2745	6634 968943	EVDOKIYA MOROZOVA	{"phone": "+70869693914"}
0005435386724	F6CC60	2065 942547	NIKOLAY ZHUKOV	{"email": "zhukov-n.1966@postgrespro.ru", "phone": "+70592288896"}
0005435386725	D17F04	7461 277396	TATYANA KRASNOVA	{"phone": "+70027389329"}
0005435386726	461F3F	3457 525461	KONSTANTIN ZHUKOV	{"phone": "+70654124525"}
0005435386727	461F3F	5759 813311	IRINA MASLOVA	{"email": "irinamaslova091970@postgrespro.ru", "phone": "+70649113913"}
0005435386728	4F90F8	6604 143407	ANDREY SIDOROV	{"email": "sidorov-andrey_021967@postgrespro.ru", "phone": "+70360652155"}
0005435386729	4F90F8	1531 075068	DINARA SOLOVEVA	{"email": "soloveva.d.1966@postgrespro.ru", "phone": "+70496666734"}
0005435386730	4F90F8	4568 625197	SVETLANA GUSEVA	{"phone": "+70960746435"}
0005435386731	4A1E81	0884 777491	VERA TARASOVA	{"phone": "+70339990685"}
0005435386732	A8CAD5	0193 545855	ELIZAVETA YUDINA	{"email": "yudinaelizaveta-1974@postgrespro.ru", "phone": "+70344858295"}
0005435386733	D5638D	6314 489918	DMITRIY TIKHONOV	{"email": "dtikhonov.11031973@postgrespro.ru", "phone": "+70976386004"}
0005435386734	D5638D	0065 460601	YULIYA YAKOVLEVA	{"phone": "+70447241943"}
0005435386735	1F9A18	1819 799049	TATYANA TARASOVA	{"email": "tarasova-tatyana_061973@postgrespro.ru", "phone": "+70213681949"}
0005435386736	1F9A18	7907 144826	MAKSIM DENISOV	{"email": "denisov.maksim101978@postgrespro.ru", "phone": "+70753912000"}
0005435386737	745519	2814 022663	KIRA PETROVA	{"email": "petrova_kira-15011973@postgrespro.ru", "phone": "+70842468631"}
0005435386738	BAAF20	8312 035031	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr-091968@postgrespro.ru", "phone": "+70267220701"}
0005435386739	0E5B9E	6616 622286	ANTONINA FEDOROVA	{"email": "a_fedorova.17021976@postgrespro.ru", "phone": "+70574966946"}
0005435386740	0E5B9E	0536 984381	ULYANA ABRAMOVA	{"phone": "+70153145705"}
0005435386741	625EB6	6640 512095	MIKHAIL MAKAROV	{"phone": "+70187410393"}
0005435386742	C02B2B	1553 895470	TATYANA KUZMINA	{"phone": "+70221732617"}
0005435386743	D9828F	4455 870139	NATALIYA KOVALEVA	{"email": "kovaleva-n_29051967@postgrespro.ru", "phone": "+70813084028"}
0005435386744	D9828F	4605 546746	LARISA KISELEVA	{"email": "larisa_kiseleva_071971@postgrespro.ru", "phone": "+70095271925"}
0005435386745	C2CE8C	4790 319511	VITALIY ISAEV	{"phone": "+70870511061"}
0005435386746	C04EDD	5061 777993	IRINA KAZAKOVA	{"phone": "+70250242539"}
0005435386747	63B2E2	6845 998276	SERGEY KUZNECOV	{"phone": "+70984872316"}
0005435386748	7A3458	4199 538302	TATYANA MIKHAYLOVA	{"phone": "+70428915660"}
0005435386749	7A3458	0068 963813	ELENA IVANOVA	{"phone": "+70451637284"}
0005435386750	DACD30	3262 831035	POLINA ZAKHAROVA	{"email": "p_zakharova1964@postgrespro.ru", "phone": "+70141307199"}
0005435386751	DACD30	9528 427564	VALERIY FEDOROV	{"email": "valeriy-fedorov25101976@postgrespro.ru", "phone": "+70382523223"}
0005435386752	02E3B8	4597 841481	ALEKSEY FROLOV	{"phone": "+70710311020"}
0005435386753	CCA5D0	4514 954753	ELENA FADEEVA	{"email": "efadeeva.091974@postgrespro.ru", "phone": "+70335426650"}
0005435386754	0F0381	9509 801089	DANILA MELNIKOV	{"email": "danila-melnikov-02121983@postgrespro.ru", "phone": "+70219525719"}
0005435386755	3C9BC0	7224 031467	ANNA NESTEROVA	{"email": "anna_nesterova_19021979@postgrespro.ru", "phone": "+70578564375"}
0005435386756	3C9BC0	2772 222018	MAKSIM ILIN	{"email": "ilinm.01081970@postgrespro.ru", "phone": "+70275666653"}
0005435386757	3C9BC0	2797 992625	VALENTINA GORBUNOVA	{"email": "v_gorbunova_1970@postgrespro.ru", "phone": "+70273108874"}
0005435386758	0F0CA1	2857 480008	YURIY VOLKOV	{"email": "volkovy1968@postgrespro.ru", "phone": "+70207553175"}
0005435386759	C5A69F	9730 155358	MAKSIM IVANOV	{"phone": "+70816400232"}
0005435386760	C5A69F	3991 631595	DENIS POPOV	{"email": "popov_denis.22101968@postgrespro.ru", "phone": "+70911314440"}
0005435386761	C5A69F	2410 379024	ALEKSANDRA BELOVA	{"phone": "+70872035646"}
0005435386762	C5A69F	5803 475593	RAISA SAVELEVA	{"phone": "+70938077027"}
0005435386763	77C25D	9370 340923	ELENA KONDRATEVA	{"email": "ekondrateva_1962@postgrespro.ru", "phone": "+70520489150"}
0005435386764	77C25D	0615 807644	OLGA VASILEVA	{"email": "o.vasileva.1961@postgrespro.ru", "phone": "+70600849072"}
0005435390116	0C8C8F	3365 059916	YURIY IVANOV	{"phone": "+70583590496"}
0005435390117	9E1482	9313 649825	SERGEY VASILEV	{"email": "s-vasilev_1975@postgrespro.ru", "phone": "+70564536229"}
0005435390118	96E95C	1212 464844	VERA ANDREEVA	{"phone": "+70128915660"}
0005435390119	5BC0E4	5836 722139	ALEKSANDRA EFREMOVA	{"phone": "+70032179317"}
0005435390120	5BC0E4	0085 281221	ANNA GORBUNOVA	{"phone": "+70999279453"}
0005435390121	5BC0E4	3630 656073	RAISA KOLESNIKOVA	{"phone": "+70671538228"}
0005435390122	CF63FF	9650 045805	LYUDMILA SMIRNOVA	{"phone": "+70465876361"}
0005435390123	AB544F	7133 988798	DMITRIY KOZLOV	{"email": "dmitriy_kozlov_071971@postgrespro.ru", "phone": "+70986322935"}
0005435390124	F0F3BF	2180 549430	ZULFIYA SERGEEVA	{"phone": "+70804853030"}
0005435390125	F0F3BF	6479 272844	ALEKSANDRA STEPANOVA	{"phone": "+70640491592"}
0005435390126	C2A7A9	2647 225583	ALEKSANDR SHEVCHENKO	{"email": "shevchenko-a-16041969@postgrespro.ru", "phone": "+70554381928"}
0005435390127	C2A7A9	8646 864917	IVAN PAVLOV	{"phone": "+70210677578"}
0005435390128	8F67C0	8760 935009	ROMAN DENISOV	{"phone": "+70677361461"}
0005435390129	A03BFE	2654 156769	OLGA BORISOVA	{"email": "oborisova_061968@postgrespro.ru", "phone": "+70727748779"}
0005435390130	A03BFE	3064 727602	YAKOV ZHURAVLEV	{"phone": "+70285566847"}
0005435390131	8CBFCF	3892 376480	SERGEY SIDOROV	{"email": "sidorov-sergey_07121974@postgrespro.ru", "phone": "+70669408045"}
0005435390132	3BC91C	6984 713604	NINA STEPANOVA	{"phone": "+70582377868"}
0005435390133	45A2A2	0669 432513	EKATERINA ARKHIPOVA	{"phone": "+70856439811"}
0005435390134	BEF473	1204 915071	TATYANA DAVYDOVA	{"phone": "+70091393801"}
0005435390135	09ADCE	1291 844461	IRINA MAKAROVA	{"phone": "+70142605549"}
0005435390136	CE7489	2256 123799	ALEKSANDR ROMANOV	{"email": "a.romanov-17101965@postgrespro.ru", "phone": "+70057704878"}
0005435390137	655941	4156 618727	VLADIMIR MEDVEDEV	{"phone": "+70489454084"}
0005435390138	655941	9575 696807	VALERIY FOMIN	{"phone": "+70474409062"}
0005435390139	C0E34A	8011 784225	NINA MELNIKOVA	{"email": "n.melnikova31051966@postgrespro.ru", "phone": "+70952492053"}
0005435390140	C0E34A	9817 126777	NIKOLAY MIKHAYLOV	{"email": "mikhaylov-nikolay_1968@postgrespro.ru", "phone": "+70935305545"}
0005435390141	048501	4297 112244	TATYANA OSIPOVA	{"phone": "+70001129241"}
0005435390142	2FEE26	6356 040867	VLADIMIR KUZMIN	{"phone": "+70513476027"}
0005435390143	0A50BB	8522 001318	SERGEY ANDREEV	{"phone": "+70730915506"}
0005435390144	27061F	3410 624453	ALEKSANDR GRIGOREV	{"phone": "+70874247995"}
0005435390145	48C5BE	2640 773669	LARISA POPOVA	{"email": "larisa-popova_20121980@postgrespro.ru", "phone": "+70137386561"}
0005435390146	244445	3090 037936	ANASTASIYA FADEEVA	{"email": "a_fadeeva091976@postgrespro.ru", "phone": "+70279385792"}
0005435390147	244445	2050 883914	NIKITA MELNIKOV	{"email": "melnikov-nikita10101969@postgrespro.ru", "phone": "+70613492021"}
0005435390148	FC8126	8304 657569	ALEKSANDR EGOROV	{"phone": "+70723027228"}
0005435390149	EBD1AC	9962 424036	PAVEL KOZLOV	{"email": "pavel_kozlov021979@postgrespro.ru", "phone": "+70959832213"}
0005435390150	EBD1AC	6851 575607	NATALYA BOGDANOVA	{"phone": "+70796945749"}
0005435390151	9C39F5	9731 551136	VYACHESLAV KUZNECOV	{"email": "vkuznecov1966@postgrespro.ru", "phone": "+70830508799"}
0005435390152	9C39F5	6953 595941	ANATOLIY SERGEEV	{"email": "sergeev.a-02071969@postgrespro.ru", "phone": "+70173683141"}
0005435390153	155119	9118 716654	ANTONINA KOROLEVA	{"phone": "+70381915842"}
0005435390154	E9E39D	3515 371957	MAKSIM KUZNECOV	{"phone": "+70809152842"}
0005435390155	F1E60D	4810 034775	SERGEY KUZNECOV	{"phone": "+70077251198"}
0005435390156	002F9D	7061 064851	SERGEY SIDOROV	{"email": "sergeysidorov11101974@postgrespro.ru", "phone": "+70152292990"}
0005435390157	6B82C8	6031 531762	VASILIY ALEKSEEV	{"email": "alekseev_vasiliy121978@postgrespro.ru", "phone": "+70849953305"}
0005435390158	6864F6	5966 156403	NIKOLAY MIRONOV	{"email": "n.mironov.121978@postgrespro.ru", "phone": "+70458043440"}
0005435390159	6864F6	7139 475236	TATYANA KUZMINA	{"phone": "+70877924739"}
0005435390160	216FA6	5498 504155	ROMAN FEDOTOV	{"email": "r.fedotov-051973@postgrespro.ru", "phone": "+70560389737"}
0005435390161	216FA6	0185 431674	ALEKSEY ROMANOV	{"phone": "+70099118568"}
0005435390162	5D17A1	7889 905071	MIKHAIL KOZLOV	{"phone": "+70970354582"}
0005435390163	5D17A1	9321 439375	LYUBOV IVANOVA	{"email": "lyubov.ivanova-021974@postgrespro.ru", "phone": "+70942818186"}
0005435390164	BB10B9	6341 575918	VERA NESTEROVA	{"phone": "+70799446944"}
0005435390165	C87916	5443 277172	SERGEY MATVEEV	{"email": "matveev-sergey.1962@postgrespro.ru", "phone": "+70291396000"}
0005435390166	C87916	5748 530339	PAVEL GUSEV	{"phone": "+70347728340"}
0005435390167	611210	7191 690282	NADEZHDA EGOROVA	{"phone": "+70512661764"}
0005435390168	723F43	6826 304297	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov071974@postgrespro.ru", "phone": "+70054668601"}
0005435390169	723F43	0997 290473	VIKTOR KUZNECOV	{"email": "kuznecov-v-27041971@postgrespro.ru", "phone": "+70140187193"}
0005435390170	723F43	9216 469419	KIRILL BELOV	{"email": "kirill_belov1971@postgrespro.ru", "phone": "+70781856955"}
0005435390171	2AF5AA	7999 123436	YULIYA VOLKOVA	{"phone": "+70025346535"}
0005435390172	DA5FEB	2218 843465	ALEKSANDR MOROZOV	{"email": "a.morozov.111965@postgrespro.ru", "phone": "+70112750949"}
0005435390173	43BBA1	9537 497497	STANISLAV SMIRNOV	{"email": "smirnov_s_15101965@postgrespro.ru", "phone": "+70409116975"}
0005435390174	43BBA1	0533 633878	PAVEL KOZLOV	{"phone": "+70414049833"}
0005435390175	76453F	2227 703912	STEPAN POPOV	{"phone": "+70971409038"}
0005435390176	975B65	1316 287258	OLGA ALEKSEEVA	{"email": "alekseeva.olga_28021969@postgrespro.ru", "phone": "+70455830646"}
0005435390177	975B65	8346 768206	VLADIMIR ZAYCEV	{"email": "zaycev-v_011966@postgrespro.ru", "phone": "+70882058798"}
0005435390178	8F9A61	2917 305594	VLADIMIR MOROZOV	{"phone": "+70172417209"}
0005435390179	E29C63	4502 354671	LIDIYA MELNIKOVA	{"email": "l.melnikova-111961@postgrespro.ru", "phone": "+70710123240"}
0005435390180	64103C	3799 252469	SEMEN BARANOV	{"phone": "+70943011539"}
0005435390181	64103C	3447 375985	OLESYA MAKAROVA	{"email": "makarova_olesya.08101976@postgrespro.ru", "phone": "+70021240969"}
0005435390182	66DF6E	5787 373924	SVETLANA BARANOVA	{"phone": "+70609629881"}
0005435390183	8F21A9	9485 802090	PETR ZAKHAROV	{"phone": "+70904614001"}
0005435390184	7100BB	5938 111386	ALEKSANDR MELNIKOV	{"email": "aleksandr.melnikov_041976@postgrespro.ru", "phone": "+70477950609"}
0005435390185	12F0AE	7664 371857	LYUDMILA KUZMINA	{"phone": "+70798648040"}
0005435390186	D2F3AC	2283 821327	LYUDMILA EFIMOVA	{"phone": "+70966245272"}
0005435390187	AF4003	9144 789897	TAMARA TIKHONOVA	{"email": "tikhonova-t_11011970@postgrespro.ru", "phone": "+70235624755"}
0005435390188	AF4003	7297 027649	ALEKSEY MATVEEV	{"phone": "+70942131649"}
0005435390189	4BE353	2383 708872	ALEKSANDR KUZNECOV	{"email": "a-kuznecov-20121972@postgrespro.ru", "phone": "+70293041302"}
0005435390190	1A2EFC	0810 729739	NIKOLAY MEDVEDEV	{"phone": "+70593092782"}
0005435390191	DF49A1	3063 080149	EGOR KONOVALOV	{"email": "konovalov_e041979@postgrespro.ru", "phone": "+70936097882"}
0005435390192	DF49A1	8226 620087	SVETLANA TARASOVA	{"phone": "+70660487767"}
0005435390193	1F2927	6715 836454	ALEKSANDR MIRONOV	{"phone": "+70756072011"}
0005435390194	7EECBF	3077 432017	VLADIMIR IVANOV	{"email": "ivanovvladimir19071971@postgrespro.ru", "phone": "+70727453791"}
0005435390195	7EECBF	4759 021152	GENNADIY FROLOV	{"email": "frolov_g-20031973@postgrespro.ru", "phone": "+70588922816"}
0005435390196	75B44A	5640 692937	SVETLANA IVANOVA	{"email": "ivanovasvetlana18051979@postgrespro.ru", "phone": "+70497688893"}
0005435390197	F593CD	0935 983146	ALEKSANDR GERASIMOV	{"email": "a-gerasimov101971@postgrespro.ru", "phone": "+70504811136"}
0005435390198	6BCBEA	6500 899865	TATYANA MAKAROVA	{"phone": "+70334318485"}
0005435390199	F10CC3	3791 902644	ANASTASIYA KULIKOVA	{"phone": "+70033102326"}
0005435390200	DEF109	0923 539416	NIKOLAY DMITRIEV	{"phone": "+70187104991"}
0005435390201	C73BB7	8430 164161	SERGEY ANTONOV	{"phone": "+70511782371"}
0005435390202	482617	9556 545029	VALENTINA RYABOVA	{"phone": "+70341294330"}
0005435390203	375984	9555 542788	VALENTINA KAZAKOVA	{"phone": "+70098509241"}
0005435390204	D81740	8540 422560	OLGA ROMANOVA	{"email": "romanova_o_061986@postgrespro.ru", "phone": "+70346800258"}
0005435390205	A88A7B	6352 747680	NIKOLAY OSIPOV	{"phone": "+70360401772"}
0005435390206	A88A7B	2695 250604	TATYANA KRASNOVA	{"phone": "+70561397106"}
0005435390207	9921D3	1113 205332	DMITRIY MIKHAYLOV	{"phone": "+70682634813"}
0005435390208	B0BE27	0645 812730	SVETLANA KOMAROVA	{"email": "komarovasvetlana.26051970@postgrespro.ru", "phone": "+70974960309"}
0005435390209	670797	3306 584264	RUSLAN STEPANOV	{"email": "stepanov.ruslan.26081980@postgrespro.ru", "phone": "+70327058405"}
0005435390210	E2F866	4015 562897	ROMAN MIKHAYLOV	{"email": "romanmikhaylov_26101960@postgrespro.ru", "phone": "+70412450675"}
0005435390211	52B260	1857 664433	IGOR CHERNOV	{"email": "chernovigor.091967@postgrespro.ru", "phone": "+70336383483"}
0005435390212	391D7B	9145 701509	NATALYA KOROLEVA	{"email": "n.koroleva_1980@postgrespro.ru", "phone": "+70382040780"}
0005435390213	912658	2197 294903	RAZIYA SIDOROVA	{"phone": "+70071926955"}
0005435390214	14838F	0319 087196	MAKAR ORLOV	{"phone": "+70942296162"}
0005435390215	BB213D	6958 200112	VERA BOGDANOVA	{"email": "vera_bogdanova.111969@postgrespro.ru", "phone": "+70038947604"}
0005435390216	5A3E23	6975 110157	IVAN FEDOROV	{"phone": "+70128490187"}
0005435390217	5A3E23	6168 362909	OLGA NAUMOVA	{"phone": "+70122106105"}
0005435390218	4F6DAA	3295 489675	EKATERINA SOKOLOVA	{"email": "e.sokolova-09041972@postgrespro.ru", "phone": "+70832984926"}
0005435390219	0C8CAF	2802 935966	VLADISLAV AFANASEV	{"phone": "+70849690098"}
0005435390220	B07C16	8279 918910	GULNARA GORBUNOVA	{"email": "gorbunova.g.091959@postgrespro.ru", "phone": "+70518321713"}
0005435390221	CB70B7	9265 047558	RASHID PAVLOV	{"email": "pavlovrashid-091974@postgrespro.ru", "phone": "+70075009659"}
0005435390222	CB70B7	7281 141067	MIKHAIL PETROV	{"email": "petrovm-15071978@postgrespro.ru", "phone": "+70319619656"}
0005435390223	770F2D	4741 655803	AYRAT MOISEEV	{"email": "moiseevayrat_121966@postgrespro.ru", "phone": "+70836696132"}
0005435390224	3C5228	6630 900595	ANATOLIY IVANOV	{"phone": "+70560345733"}
0005435390225	86678C	9199 573684	OLEG FEDOTOV	{"phone": "+70636889396"}
0005435390226	93D7FB	9918 460320	EKATERINA ANDREEVA	{"email": "andreeva.e.09061972@postgrespro.ru", "phone": "+70600499231"}
0005435390227	93D7FB	4334 007889	ALEKSANDR ORLOV	{"email": "aorlov-24041969@postgrespro.ru", "phone": "+70986539965"}
0005435390228	4186C9	7650 090452	MARINA KUZMINA	{"phone": "+70099280776"}
0005435390229	A9A8D8	5861 801304	VYACHESLAV IVANOV	{"email": "vyacheslavivanov.14091964@postgrespro.ru", "phone": "+70873015169"}
0005435390230	065639	2955 944022	ELDAR KARPOV	{"email": "karpov.e.1967@postgrespro.ru", "phone": "+70612814348"}
0005435390231	482DA5	4435 927839	POLINA MIKHAYLOVA	{"email": "mikhaylovapolina101968@postgrespro.ru", "phone": "+70717333098"}
0005435390232	8C1431	2979 861689	SERGEY KAZAKOV	{"phone": "+70251366601"}
0005435390233	F306C9	0865 440317	YURIY KULIKOV	{"phone": "+70036417142"}
0005435390234	D0EC89	8778 466566	VLADISLAV ALEKSANDROV	{"phone": "+70934005587"}
0005435390235	40F7FA	2111 814435	NATALYA OVCHINNIKOVA	{"phone": "+70510652911"}
0005435390236	40F7FA	2703 726965	TAMARA FEDOROVA	{"email": "fedorova_t.021971@postgrespro.ru", "phone": "+70643131082"}
0005435390237	40F7FA	5044 292902	MIKHAIL KUZMIN	{"phone": "+70216124954"}
0005435390238	6216A7	1440 726998	VIKTOR MAKAROV	{"email": "viktor.makarov_1958@postgrespro.ru", "phone": "+70098193029"}
0005435390239	6216A7	9568 141327	VASILIY ORLOV	{"phone": "+70152991911"}
0005435390240	1F3D6A	1566 434022	NATALIYA SERGEEVA	{"phone": "+70497261724"}
0005435390241	936CDD	8310 313278	EKATERINA NOVIKOVA	{"email": "novikova.ekaterina091970@postgrespro.ru", "phone": "+70256886275"}
0005435390242	9CA2DA	8075 261260	IRINA SERGEEVA	{"phone": "+70600116672"}
0005435390243	432D57	6005 728148	VLADIMIR DENISOV	{"email": "denisov-vladimir-10011967@postgrespro.ru", "phone": "+70467988328"}
0005435390244	432D57	0391 606003	ELENA LOGINOVA	{"phone": "+70358228774"}
0005435390245	4D07A8	8938 923155	EKATERINA OSIPOVA	{"email": "e.osipova021979@postgrespro.ru", "phone": "+70980314299"}
0005435390246	802CA5	2023 652500	ELENA MOISEEVA	{"phone": "+70401975232"}
0005435390247	A8BF09	8302 899872	PAVEL FEDOROV	{"email": "fedorovpavel-101969@postgrespro.ru", "phone": "+70419716026"}
0005435390248	1D204F	6154 426711	ELENA DMITRIEVA	{"email": "elena-dmitrieva25121974@postgrespro.ru", "phone": "+70327633337"}
0005435390249	1D204F	5178 937606	ELENA DENISOVA	{"email": "edenisova021970@postgrespro.ru", "phone": "+70103153328"}
0005435390250	0D2F46	8620 056164	MIKHAIL DENISOV	{"email": "denisovmikhail.27091976@postgrespro.ru", "phone": "+70410531318"}
0005435390251	0D2F46	7109 282110	ALEKSEY KOZLOV	{"phone": "+70062248436"}
0005435390252	FE9438	8109 844610	NINA KONOVALOVA	{"email": "konovalova-n-091972@postgrespro.ru", "phone": "+70401291779"}
0005435390253	B127A5	5011 011836	MAKSIM EGOROV	{"email": "egorov_m091966@postgrespro.ru", "phone": "+70230983497"}
0005435390254	B127A5	2439 260225	KLAVDIYA POTAPOVA	{"phone": "+70445364747"}
0005435390255	66F9CA	4951 058704	YULIYA PAVLOVA	{"phone": "+70488851780"}
0005435390256	316A5D	0318 942926	NATALYA MATVEEVA	{"email": "nmatveeva.1969@postgrespro.ru", "phone": "+70495165016"}
0005435390257	316A5D	6190 906758	NINA MIRONOVA	{"email": "n-mironova_011987@postgrespro.ru", "phone": "+70812400155"}
0005435390258	D0B835	5723 089675	FEDOR SCHERBAKOV	{"email": "fedor_scherbakov.1971@postgrespro.ru", "phone": "+70055729967"}
0005435390259	62C9A8	0178 932318	DMITRIY KOZLOV	{"phone": "+70314487230"}
0005435390260	CC67B1	6545 948834	ANTON TARASOV	{"phone": "+70209101365"}
0005435390261	CC67B1	4290 479511	ANGELINA MATVEEVA	{"phone": "+70893667291"}
0005435390262	397DB7	5437 992332	ANNA ALEKSEEVA	{"phone": "+70635513539"}
0005435390263	397DB7	7109 896270	VASILIY KUDRYASHOV	{"phone": "+70882598940"}
0005435390264	06490C	0102 021692	VALERIY ZAKHAROV	{"email": "vzakharov23121962@postgrespro.ru", "phone": "+70486656204"}
0005435390265	06490C	2105 666625	LILIYA AFANASEVA	{"phone": "+70401243710"}
0005435390266	84843E	3548 469869	ALINA IVANOVA	{"phone": "+70648649344"}
0005435390267	84843E	8960 146875	TATYANA POLYAKOVA	{"phone": "+70767200643"}
0005435390268	8FE4AA	8086 884483	ALEKSANDR IVANOV	{"email": "ivanov_a-111978@postgrespro.ru", "phone": "+70784149227"}
0005435390269	75A4B4	5790 905325	RAISA MELNIKOVA	{"email": "melnikova-r_1965@postgrespro.ru", "phone": "+70430563594"}
0005435390270	75A4B4	2587 351775	NINA ILINA	{"email": "n.ilina_1980@postgrespro.ru", "phone": "+70129059954"}
0005435390271	048A79	6919 945069	ARKADIY FROLOV	{"phone": "+70364714090"}
0005435390272	A80298	3745 335273	MARINA POPOVA	{"email": "marina.popova_1978@postgrespro.ru", "phone": "+70885822414"}
0005435390273	A80298	0995 033196	VLADIMIR SCHERBAKOV	{"email": "scherbakov_v_12061974@postgrespro.ru", "phone": "+70396086618"}
0005435390274	A80298	8193 279469	ALEKSANDR VOROBEV	{"email": "a_vorobev13011963@postgrespro.ru", "phone": "+70908418522"}
0005435390275	F3229A	6541 150653	VLADIMIR MOISEEV	{"email": "v_moiseev_22041964@postgrespro.ru", "phone": "+70051445128"}
0005435390276	565482	9378 633590	DMITRIY ORLOV	{"phone": "+70815321600"}
0005435390277	3BC4EB	9895 020318	ELENA SMIRNOVA	{"phone": "+70036691635"}
0005435390278	3BC4EB	9436 641197	ALEKSEY AFANASEV	{"phone": "+70733181310"}
0005435390279	CCD788	4381 037315	EVGENIYA PETROVA	{"phone": "+70090044019"}
0005435390280	C9D591	7075 533582	DMITRIY SOLOVEV	{"email": "d-solovev19031974@postgrespro.ru", "phone": "+70546562631"}
0005435390281	8605B8	3425 446349	ALEKSANDR SCHERBAKOV	{"email": "scherbakov_a-08051977@postgrespro.ru", "phone": "+70445267649"}
0005435390282	508BC5	2143 481279	PETR NOVIKOV	{"email": "novikov-p.29121969@postgrespro.ru", "phone": "+70777014805"}
0005435390283	3D0499	0497 117864	DMITRIY ZAYCEV	{"phone": "+70770804872"}
0005435390284	3D0499	9897 391263	EKATERINA RYABOVA	{"phone": "+70658471958"}
0005435390285	B9B6E6	2511 744915	VLADIMIR STEPANOV	{"email": "vladimir-stepanov-31081959@postgrespro.ru", "phone": "+70946529892"}
0005435390286	B9B6E6	5115 124211	YURIY SHEVCHENKO	{"email": "y.shevchenko_111982@postgrespro.ru", "phone": "+70052404191"}
0005435390287	B0017C	5173 233856	TAMARA VASILEVA	{"email": "vasileva.tamara.1976@postgrespro.ru", "phone": "+70982275145"}
0005435390288	B0017C	9236 576880	ILYA EGOROV	{"phone": "+70847099875"}
0005435390289	E40E3D	0189 795686	SERGEY ANDREEV	{"phone": "+70932113347"}
0005435390290	81A965	8325 228056	ANTONINA FILATOVA	{"email": "antonina_filatova.051989@postgrespro.ru", "phone": "+70209978335"}
0005435390291	81A965	2250 481891	ALENA ORLOVA	{"phone": "+70278854445"}
0005435390292	81A965	2884 533792	YULIYA FILIPPOVA	{"email": "y-filippova-061975@postgrespro.ru", "phone": "+70303674883"}
0005435390293	F4726D	4072 242939	ELEONORA SCHERBAKOVA	{"email": "eleonora-scherbakova1978@postgrespro.ru", "phone": "+70944131481"}
0005435390294	0982C5	0849 566735	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr011979@postgrespro.ru", "phone": "+70272509601"}
0005435390295	6F5E1C	9872 567969	VALERIY ROMANOV	{"email": "romanov_valeriy.121976@postgrespro.ru", "phone": "+70163290129"}
0005435390296	6F5E1C	0179 258877	NIKITA SAVELEV	{"phone": "+70658812940"}
0005435390297	2719D9	8625 229951	ANDREY ZAYCEV	{"email": "andrey_zaycev.1959@postgrespro.ru", "phone": "+70247375758"}
0005435390298	ACDDF7	9828 912886	GALINA KOROLEVA	{"phone": "+70037521289"}
0005435390299	ACDDF7	4438 518007	ALEKSANDR MAKAROV	{"phone": "+70986220318"}
0005435390300	8BE9CB	2893 733014	EKATERINA NIKOLAEVA	{"phone": "+70996530911"}
0005435390301	29FAD8	1000 218222	NIKOLAY FOMIN	{"phone": "+70256287792"}
0005435390302	72F254	6349 314816	EKATERINA KOMAROVA	{"email": "komarovae.061970@postgrespro.ru", "phone": "+70874870928"}
0005435390303	72F254	4714 019221	YURIY ILIN	{"phone": "+70517821870"}
0005435390304	72F254	5551 868372	VALENTINA ANTONOVA	{"email": "antonova.valentina-071976@postgrespro.ru", "phone": "+70864304672"}
0005435390305	E72C3B	8869 169737	SERGEY MAKSIMOV	{"email": "s_maksimov_1971@postgrespro.ru", "phone": "+70530114761"}
0005435390306	E72C3B	5290 030406	VLADIMIR RODIONOV	{"email": "vrodionov-1972@postgrespro.ru", "phone": "+70476330430"}
0005435390307	A07947	1298 688145	SERGEY BONDARENKO	{"email": "bondarenko_s1977@postgrespro.ru", "phone": "+70803789133"}
0005435390308	BA290B	0283 547140	ALEKSANDR DMITRIEV	{"phone": "+70013883081"}
0005435390309	BA290B	1989 322775	NATALYA MAKAROVA	{"phone": "+70810655913"}
0005435390310	998328	7101 070037	NADEZHDA NIKOLAEVA	{"email": "nnikolaeva_29041971@postgrespro.ru", "phone": "+70830784539"}
0005435390311	998328	3206 191521	ANDREY OSIPOV	{"email": "osipov_a_30121974@postgrespro.ru", "phone": "+70878823179"}
0005435390312	998328	2547 744413	OLEG FEDOTOV	{"email": "o.fedotov-24031971@postgrespro.ru", "phone": "+70433458331"}
0005435390313	C8FB77	5538 657102	ALEKSEY MIRONOV	{"email": "mironovaleksey10051975@postgrespro.ru", "phone": "+70650375699"}
0005435390314	C8FB77	7911 649128	ZOYA AFANASEVA	{"email": "z-afanaseva_18071975@postgrespro.ru", "phone": "+70681335922"}
0005435390315	15C813	4529 556008	LYUBOV DENISOVA	{"phone": "+70554561994"}
0005435390316	059731	0063 465724	NATALYA GAVRILOVA	{"email": "ngavrilova_24061976@postgrespro.ru", "phone": "+70331135601"}
0005435390317	97A367	3546 537754	STANISLAV IVANOV	{"email": "s.ivanov_1975@postgrespro.ru", "phone": "+70991698103"}
0005435390318	97A367	9994 414166	ELENA MAKAROVA	{"phone": "+70402159550"}
0005435390319	95EE22	9663 584571	NATALYA NIKITINA	{"email": "natalya.nikitina-02051972@postgrespro.ru", "phone": "+70944826291"}
0005435390320	E5B016	1064 258821	VALENTINA KOMAROVA	{"email": "valentinakomarova.1985@postgrespro.ru", "phone": "+70174014393"}
0005435390321	D71AB3	8021 763369	SERGEY AFANASEV	{"email": "afanasevsergey.1980@postgrespro.ru", "phone": "+70187982533"}
0005435390322	68A485	0357 408518	GENNADIY KOZLOV	{"email": "kozlov.g.1964@postgrespro.ru", "phone": "+70123223459"}
0005435390323	D218F5	5637 389224	ELENA ANDREEVA	{"email": "andreeva-elena-061977@postgrespro.ru", "phone": "+70580949385"}
0005435390324	0C118B	1442 686772	MARAT ZAKHAROV	{"email": "zakharov.m_021987@postgrespro.ru", "phone": "+70651887770"}
0005435390325	4CC7EB	9700 435114	TATYANA VASILEVA	{"phone": "+70875561648"}
0005435390326	4CC7EB	6048 588343	TATYANA BELOVA	{"email": "belova-t07021972@postgrespro.ru", "phone": "+70768586279"}
0005435390327	C1F353	1702 968275	NATALYA MOROZOVA	{"email": "morozova_natalya-02111972@postgrespro.ru", "phone": "+70027697247"}
0005435390328	C1F353	1773 233381	ALEKSANDR NAZAROV	{"email": "aleksandr_nazarov_1965@postgrespro.ru", "phone": "+70037314479"}
0005435390329	C1F353	8196 346080	TATYANA YUDINA	{"phone": "+70170075119"}
0005435390330	7BBD3F	2219 855747	NIKITA MIRONOV	{"email": "n.mironov-1970@postgrespro.ru", "phone": "+70325444061"}
0005435390331	DB5E34	7888 962505	MAKSIM ALEKSEEV	{"phone": "+70528742506"}
0005435390332	F589C4	7599 502109	NIKOLAY CHERNOV	{"email": "nikolay_chernov-29031969@postgrespro.ru", "phone": "+70840761479"}
0005435390333	F589C4	0713 650106	EVGENIY MAKAROV	{"phone": "+70708639370"}
0005435390334	E836B0	2727 819798	ANASTASIYA KUDRYASHOVA	{"email": "kudryashova.a-17061974@postgrespro.ru", "phone": "+70952374995"}
0005435390335	B16847	0044 260148	LEONID IVANOV	{"phone": "+70684057910"}
0005435390336	B16847	0658 180296	VLADIMIR ZHUKOV	{"phone": "+70949218035"}
0005435390337	4B5FE4	3079 111574	EVGENIY MOISEEV	{"phone": "+70467117001"}
0005435390338	B88FBD	9690 612909	NATALYA ZOTOVA	{"phone": "+70647389712"}
0005435390339	7789F8	9373 732769	MIKHAIL MARTYNOV	{"email": "martynov.mikhail_021973@postgrespro.ru", "phone": "+70663900284"}
0005435390340	7789F8	7659 971670	FANIL BORISOV	{"email": "borisov.f-08111969@postgrespro.ru", "phone": "+70584022347"}
0005435390341	12BA09	5815 413463	ANZHELA MARTYNOVA	{"email": "a_martynova.1970@postgrespro.ru", "phone": "+70477045038"}
0005435390342	5FD7FB	8982 612028	YANA ANTONOVA	{"email": "antonova-yana_1973@postgrespro.ru", "phone": "+70846835888"}
0005435390343	0319D9	2774 842857	TATYANA CHERNOVA	{"email": "chernovat.081976@postgrespro.ru", "phone": "+70264434403"}
0005435390344	861B03	7751 680838	VIKTORIYA BELYAEVA	{"email": "vbelyaeva-1984@postgrespro.ru", "phone": "+70780594066"}
0005435390345	6EB584	6226 224678	LYUDMILA NESTEROVA	{"email": "nesterova_l-011986@postgrespro.ru", "phone": "+70948119150"}
0005435390346	5B3EAF	1861 568651	ALEKSEY ZHURAVLEV	{"email": "aleksey_zhuravlev04091969@postgrespro.ru", "phone": "+70795119152"}
0005435390347	D3BE3B	8567 717814	ILYA MOISEEV	{"phone": "+70091398002"}
0005435390348	D71D99	9927 715630	NATALIYA EFIMOVA	{"email": "nataliya.efimova.25061969@postgrespro.ru", "phone": "+70016038923"}
0005435390349	72B753	6706 696851	ANTONIDA NESTEROVA	{"email": "nesterova.a_111974@postgrespro.ru", "phone": "+70788355763"}
0005435390350	EE745E	5656 182043	NATALYA PAVLOVA	{"phone": "+70847791824"}
0005435390351	EE745E	9461 930232	RAFAIL POPOV	{"email": "r-popov_08101971@postgrespro.ru", "phone": "+70217071543"}
0005435390352	20821E	3847 125746	SERGEY MATVEEV	{"phone": "+70978893066"}
0005435390353	20821E	4413 571752	TATYANA TARASOVA	{"email": "tarasova_t-101977@postgrespro.ru", "phone": "+70079008530"}
0005435390354	B0D7ED	7388 206515	OLGA KOZLOVA	{"email": "o_kozlova-07111962@postgrespro.ru", "phone": "+70691949472"}
0005435390355	48E751	9372 524823	SVETLANA FILIPPOVA	{"email": "s.filippova_05071977@postgrespro.ru", "phone": "+70485165120"}
0005435390356	7744AA	1600 491727	ALEKSANDR IVANOV	{"phone": "+70756010200"}
0005435390357	03FF0D	1021 168905	ALEKSANDRA KOZLOVA	{"email": "kozlova.aleksandra_19031958@postgrespro.ru", "phone": "+70046869520"}
0005435390358	03FF0D	6090 795604	VALERIY MELNIKOV	{"email": "v.melnikov.011981@postgrespro.ru", "phone": "+70828847129"}
0005435390359	BAB891	1158 059845	IRINA KRASNOVA	{"email": "krasnova.irina_011979@postgrespro.ru", "phone": "+70957012752"}
0005435390360	0B7954	2213 016437	VYACHESLAV FILIPPOV	{"email": "filippov_v-1988@postgrespro.ru", "phone": "+70401317922"}
0005435390361	1CF0C2	7052 827524	ELENA MIKHAYLOVA	{"phone": "+70950316889"}
0005435390362	0CB80D	3542 286655	MIKHAIL MOISEEV	{"email": "moiseev_mikhail-31071981@postgrespro.ru", "phone": "+70953830760"}
0005435390363	265FDC	0930 780542	ALEKSEY OSIPOV	{"email": "osipov_aleksey_1967@postgrespro.ru", "phone": "+70522094922"}
0005435390364	265FDC	6033 318935	ALEKSEY AFANASEV	{"email": "afanasev.aleksey011976@postgrespro.ru", "phone": "+70966500250"}
0005435390365	2BD6C5	5302 606123	ELENA GAVRILOVA	{"phone": "+70514114475"}
0005435390366	2BD6C5	5593 410614	SERGEY KOZLOV	{"phone": "+70495210568"}
0005435390367	05213C	4992 252450	VALERIY KUZMIN	{"email": "kuzmin.v-18051962@postgrespro.ru", "phone": "+70807768847"}
0005435390368	8483D4	5429 637060	FEDOR VLASOV	{"email": "f-vlasov_28091970@postgrespro.ru", "phone": "+70416368356"}
0005435390369	8483D4	6547 888921	EVGENIY ZAKHAROV	{"email": "e.zakharov_1956@postgrespro.ru", "phone": "+70781298285"}
0005435390370	B33026	4834 357843	ELENA ZAKHAROVA	{"phone": "+70944237601"}
0005435390371	F7AA96	5503 549945	PAVEL PETROV	{"email": "petrov.pavel-05021957@postgrespro.ru", "phone": "+70664178331"}
0005435390372	F7AA96	9542 118372	SERGEY NAUMOV	{"phone": "+70697094843"}
0005435390373	F62DB2	4811 367883	NINA KAZAKOVA	{"phone": "+70492034892"}
0005435390374	F62DB2	5329 250791	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov_051975@postgrespro.ru", "phone": "+70354706214"}
0005435390375	41388D	6855 633541	GALINA KARPOVA	{"phone": "+70449397747"}
0005435390376	B1573D	5223 013624	ANDREY SOKOLOV	{"email": "sokolov.andrey-011963@postgrespro.ru", "phone": "+70109583470"}
0005435390377	B1573D	2697 976617	SERGEY STEPANOV	{"email": "sstepanov-1973@postgrespro.ru", "phone": "+70751041620"}
0005435390378	B1573D	3495 188036	NATALYA FOMINA	{"email": "fominanatalya-1968@postgrespro.ru", "phone": "+70303280785"}
0005435390379	2BD437	5882 732429	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr.1974@postgrespro.ru", "phone": "+70466920061"}
0005435390380	2BD437	7742 477742	MIKHAIL NAZAROV	{"phone": "+70127404042"}
0005435390381	B15A01	5033 649085	IGOR SERGEEV	{"phone": "+70161453174"}
0005435390382	85A634	7069 843092	OLGA KONOVALOVA	{"email": "konovalovao-25011963@postgrespro.ru", "phone": "+70281948349"}
0005435390383	1E2669	0383 964753	YULIYA VOLKOVA	{"phone": "+70438674127"}
0005435390384	1E2669	0161 285853	ZOYA VOLKOVA	{"email": "zoya-volkova_041964@postgrespro.ru", "phone": "+70942999825"}
0005435390385	D4DE51	8106 051728	YULIYA SOLOVEVA	{"phone": "+70818396999"}
0005435390386	D4DE51	5820 631408	GALINA ILINA	{"email": "ilinagalina061962@postgrespro.ru", "phone": "+70292215195"}
0005435390387	4469BB	3230 888944	ALENA VASILEVA	{"email": "vasilevaalena.1963@postgrespro.ru", "phone": "+70847960911"}
0005435390388	C717CF	8003 272796	LYUBOV ZAYCEVA	{"email": "zayceva.l_02041969@postgrespro.ru", "phone": "+70696397215"}
0005435390389	C45D33	4876 979502	KONSTANTIN KUZMIN	{"email": "kuzmink-061977@postgrespro.ru", "phone": "+70659836662"}
0005435390390	9CD1FB	8950 259578	ANDREY KONOVALOV	{"phone": "+70452522696"}
0005435390391	D9414C	6812 952030	VLADA LUKYANOVA	{"email": "lukyanova_v_18021978@postgrespro.ru", "phone": "+70167246404"}
0005435390392	49525B	0930 935557	VERA NESTEROVA	{"phone": "+70056172427"}
0005435390393	46B64B	0403 114779	OKSANA SERGEEVA	{"phone": "+70954094996"}
0005435390394	76A8B1	8446 864066	OLGA ZHURAVLEVA	{"email": "zhuravlevao011966@postgrespro.ru", "phone": "+70012329964"}
0005435390395	118875	9515 107700	ELENA SIDOROVA	{"phone": "+70672357359"}
0005435390396	118875	4627 460366	NIKOLAY MATVEEV	{"email": "matveev-n.15111978@postgrespro.ru", "phone": "+70318252513"}
0005435390397	30B72B	1634 303887	DMITRIY ALEKSEEV	{"email": "d.alekseev.051965@postgrespro.ru", "phone": "+70804171239"}
0005435390398	30B72B	7492 793314	ELENA POPOVA	{"email": "elena.popova-1984@postgrespro.ru", "phone": "+70332200968"}
0005435390399	883075	4049 717913	ANASTASIYA IVANOVA	{"phone": "+70552249613"}
0005435390400	D22B3A	3876 749785	DENIS ZHUKOV	{"phone": "+70592690339"}
0005435390401	561960	3659 232664	SOFIYA VASILEVA	{"email": "vasileva.sofiya.1979@postgrespro.ru", "phone": "+70074954871"}
0005435390402	561960	1244 408835	MARIYA ROMANOVA	{"phone": "+70893157994"}
0005435390403	BD60D9	8367 408563	DMITRIY NIKOLAEV	{"phone": "+70019336803"}
0005435390404	482026	8920 590877	OLEG CHERNOV	{"email": "chernovo_071974@postgrespro.ru", "phone": "+70445522000"}
0005435390405	5A491D	5274 032571	OKSANA PETROVA	{"email": "petrova_oksana011966@postgrespro.ru", "phone": "+70270757903"}
0005435390406	48D98E	8364 026305	ALEKSEY GORBUNOV	{"email": "gorbunov-a_18011982@postgrespro.ru", "phone": "+70131459941"}
0005435390407	4B69DB	9428 537221	OLGA VASILEVA	{"email": "vasileva.olga.081981@postgrespro.ru", "phone": "+70001049870"}
0005435390408	27B422	1105 289941	LYUBOV YAKOVLEVA	{"email": "lyubov_yakovleva15061980@postgrespro.ru", "phone": "+70400915233"}
0005435390409	C2F2CB	4271 052520	YULIYA KAZAKOVA	{"phone": "+70523728961"}
0005435390410	C2F2CB	0366 215309	ALEKSANDR FROLOV	{"phone": "+70124310721"}
0005435390411	A9E0BD	5317 841973	DANIL KAZAKOV	{"phone": "+70288773588"}
0005435390412	E2E535	9173 289008	LARISA VASILEVA	{"email": "larisa-vasileva_04041985@postgrespro.ru", "phone": "+70466617974"}
0005435390413	85A692	5911 001100	DMITRIY MIKHAYLOV	{"phone": "+70399285009"}
0005435390414	CB1B49	5261 334722	LYUDMILA VLASOVA	{"phone": "+70466594792"}
0005435390415	C8697A	9768 352540	OLGA FROLOVA	{"phone": "+70927953571"}
0005435390416	CE6444	6099 869389	ALEKSANDR NIKITIN	{"email": "nikitin-aleksandr.25041971@postgrespro.ru", "phone": "+70895248069"}
0005435390417	CE6444	0878 486936	VLADIMIR ZAKHAROV	{"phone": "+70079525285"}
0005435390418	7F9BC3	9756 934550	VLADIMIR SEMENOV	{"email": "vladimir_semenov.101966@postgrespro.ru", "phone": "+70971421844"}
0005435390419	35834E	6264 670304	ELEONORA FILATOVA	{"email": "e.filatova23021969@postgrespro.ru", "phone": "+70712561813"}
0005435390420	62AA3A	3046 388117	ANATOLIY KOROLEV	{"email": "a.korolev1961@postgrespro.ru", "phone": "+70413725651"}
0005435390421	62AA3A	3256 013060	DARYA MALYSHEVA	{"email": "darya.malysheva_011980@postgrespro.ru", "phone": "+70389632981"}
0005435390422	9D381D	8821 860443	ALEKSANDRA TARASOVA	{"phone": "+70556732042"}
0005435390423	D6BB2A	8490 360967	TAMARA DMITRIEVA	{"email": "tamara-dmitrieva-1974@postgrespro.ru", "phone": "+70393432710"}
0005435390424	D6BB2A	3119 922715	MIKHAIL NIKOLAEV	{"email": "nikolaev.mikhail-1974@postgrespro.ru", "phone": "+70249537708"}
0005435390425	E90893	2523 530695	EKATERINA PETROVA	{"phone": "+70688948083"}
0005435390426	096B36	0931 614006	TATYANA FROLOVA	{"email": "tatyanafrolova_21111974@postgrespro.ru", "phone": "+70622718002"}
0005435390427	45EB12	3822 007422	EVGENIY NIKOLAEV	{"email": "e.nikolaev_1965@postgrespro.ru", "phone": "+70788782598"}
0005435390428	E5441D	6735 436034	VLADIMIR OSIPOV	{"phone": "+70344015401"}
0005435390429	E5441D	7801 435567	RINAT NAZAROV	{"phone": "+70665648802"}
0005435390430	1BE484	9202 619689	ALEKSANDR GRIGOREV	{"phone": "+70342006482"}
0005435390431	1BE484	3235 284709	VALENTINA POPOVA	{"email": "popova_valentina-26061974@postgrespro.ru", "phone": "+70610954504"}
0005435390432	CFB0F6	5428 368180	ALIYA GAVRILOVA	{"email": "gavrilova-a-12011971@postgrespro.ru", "phone": "+70395706870"}
0005435390433	CFB0F6	6824 728566	GALINA SOROKINA	{"phone": "+70402456356"}
0005435390434	CFB0F6	1692 236208	NELLI VLASOVA	{"email": "vlasovanelli-12091957@postgrespro.ru", "phone": "+70932941803"}
0005435390435	1D4F14	3340 536527	ARTUR SOROKIN	{"email": "asorokin_11071975@postgrespro.ru", "phone": "+70054941279"}
0005435390436	72530F	2832 480195	YAN MOISEEV	{"phone": "+70141928353"}
0005435390437	72530F	8462 017154	ALEKSANDR KOZLOV	{"phone": "+70516281946"}
0005435390438	B1D758	8758 829896	NINA ISAEVA	{"email": "isaeva_n10121978@postgrespro.ru", "phone": "+70158431743"}
0005435390439	26203C	5528 177429	ROMAN ISAEV	{"phone": "+70461007033"}
0005435390440	2EDFE1	9854 335635	IGOR SIDOROV	{"phone": "+70065408636"}
0005435390441	4B616A	4463 689461	ANDREY POPOV	{"phone": "+70094332666"}
0005435423575	B387EC	3165 982142	ALEKSANDRA FEDOROVA	{"phone": "+70064157376"}
0005435423576	F5916C	9094 230341	NATALYA MOROZOVA	{"email": "n.morozova.1969@postgrespro.ru", "phone": "+70762272369"}
0005435423577	8C67D7	0839 871634	NINA TITOVA	{"email": "titova.nina.1970@postgrespro.ru", "phone": "+70451005912"}
0005435423578	A45398	6656 671328	EVDOKIYA MAKSIMOVA	{"email": "emaksimova-081978@postgrespro.ru", "phone": "+70768257416"}
0005435423579	A45398	4214 966105	YULIYA SIDOROVA	{"phone": "+70544697511"}
0005435423580	A45398	3547 662426	ILYA GORBUNOV	{"phone": "+70222165367"}
0005435423581	EE6537	7915 164059	NINA MAKAROVA	{"email": "makarova.nina.061970@postgrespro.ru", "phone": "+70178349150"}
0005435423582	1D03D2	2184 697512	MARIYA ERMAKOVA	{"phone": "+70401925643"}
0005435423583	47E195	4693 609083	ANASTASIYA ZHURAVLEVA	{"email": "anastasiyazhuravleva_111975@postgrespro.ru", "phone": "+70400631979"}
0005435423584	674639	3320 854126	ANTON CHERNOV	{"phone": "+70722189874"}
0005435423585	674639	0123 499836	MARIYA KUZNECOVA	{"email": "m_kuznecova.101968@postgrespro.ru", "phone": "+70420117425"}
0005435423586	C65DD9	2720 822927	ANASTASIYA ZHURAVLEVA	{"email": "anastasiya-zhuravleva.101967@postgrespro.ru", "phone": "+70259755303"}
0005435423587	9A90FF	0261 638587	VLADISLAV MARTYNOV	{"email": "martynov_v_1965@postgrespro.ru", "phone": "+70625935847"}
0005435423588	9A90FF	3428 179737	SERGEY MIRONOV	{"email": "s.mironov121977@postgrespro.ru", "phone": "+70900787853"}
0005435423589	9A90FF	7717 484730	ANNA NESTEROVA	{"email": "anesterova-12011974@postgrespro.ru", "phone": "+70451474846"}
0005435423590	9C9320	2817 552692	ALEKSANDR GERASIMOV	{"email": "gerasimovaleksandr-03011974@postgrespro.ru", "phone": "+70208514429"}
0005435423591	045F00	8823 938196	PAVEL FEDOROV	{"email": "fedorov_pavel_29081968@postgrespro.ru", "phone": "+70551640586"}
0005435423592	4C74AF	9004 427766	ALBERT NIKOLAEV	{"phone": "+70609080814"}
0005435423593	78A6F4	6131 719205	MIKHAIL SMIRNOV	{"email": "smirnov_mikhail_26041967@postgrespro.ru", "phone": "+70713416632"}
0005435423594	29D488	7559 727774	GENNADIY FEDOTOV	{"phone": "+70178525925"}
0005435423595	E95A16	8762 610137	ANATOLIY SEMENOV	{"phone": "+70062433473"}
0005435423596	2DF05D	9775 057311	ZINAIDA LOGINOVA	{"email": "zinaidaloginova28071967@postgrespro.ru", "phone": "+70219186290"}
0005435423597	F2D9AF	4265 379212	NIKOLAY ORLOV	{"email": "orlov.nikolay_09051973@postgrespro.ru", "phone": "+70571584035"}
0005435423598	9417B4	6945 393247	LYUDMILA VOLKOVA	{"phone": "+70417591670"}
0005435423599	9417B4	6337 944623	IRINA ZHUKOVA	{"email": "irinazhukova101965@postgrespro.ru", "phone": "+70255746824"}
0005435423600	290C92	0133 767151	VALENTINA KULIKOVA	{"phone": "+70392532203"}
0005435423601	208392	6516 803701	YURIY ROMANOV	{"email": "y-romanov_1966@postgrespro.ru", "phone": "+70372743675"}
0005435423602	38CEEE	8487 180653	NADEZHDA AKIMOVA	{"phone": "+70777750901"}
0005435423603	38CEEE	6859 262745	SERGEY NIKOLAEV	{"email": "s.nikolaev.27021976@postgrespro.ru", "phone": "+70346414206"}
0005435423604	0DB9A9	0544 491291	NIKOLAY GERASIMOV	{"email": "gerasimov_nikolay_041974@postgrespro.ru", "phone": "+70314516043"}
0005435423605	0DB9A9	9994 563101	YULIYA KOROLEVA	{"email": "y_koroleva24021976@postgrespro.ru", "phone": "+70877151594"}
0005435423606	B024EE	2184 409959	ELMIRA FROLOVA	{"email": "frolova_e1970@postgrespro.ru", "phone": "+70780952410"}
0005435423607	C19572	1480 702250	EVGENIYA ZAYCEVA	{"email": "e-zayceva041971@postgrespro.ru", "phone": "+70721880802"}
0005435423608	9BCC0D	5098 866873	VIKTOR RODIONOV	{"phone": "+70617402124"}
0005435423609	9BCC0D	1961 508963	VALERIYA EFREMOVA	{"email": "efremova_valeriya.101978@postgrespro.ru", "phone": "+70921251470"}
0005435423610	FD8896	8691 216695	NADEZHDA MELNIKOVA	{"email": "nadezhdamelnikova10041980@postgrespro.ru", "phone": "+70692177059"}
0005435423611	FD8896	7726 045358	ELENA ALEKSANDROVA	{"email": "elena_aleksandrova-07071963@postgrespro.ru", "phone": "+70190796560"}
0005435423612	C30D10	1338 022358	ELENA POPOVA	{"email": "elena_popova111971@postgrespro.ru", "phone": "+70287560467"}
0005435423613	C767AB	4708 967682	LARISA GORBUNOVA	{"email": "gorbunova.l_011971@postgrespro.ru", "phone": "+70500018011"}
0005435423614	52C7C6	0805 404302	ANDREY SCHERBAKOV	{"email": "andreyscherbakov071983@postgrespro.ru", "phone": "+70677062040"}
0005435423615	492161	4045 893557	VYACHESLAV OSIPOV	{"email": "osipov_vyacheslav_121974@postgrespro.ru", "phone": "+70428053203"}
0005435423616	6BD497	2043 585560	NADEZHDA ANTONOVA	{"phone": "+70501198473"}
0005435423617	D40140	5499 897224	VIKTORIYA KONOVALOVA	{"phone": "+70900906379"}
0005435423618	D40140	1749 451913	LYUBOV LEBEDEVA	{"email": "lebedeva-lyubov121970@postgrespro.ru", "phone": "+70971931580"}
0005435423619	3CD586	5522 186908	STANISLAV TARASOV	{"phone": "+70059686389"}
0005435423620	4C1E82	7882 517563	NIKOLAY YAKOVLEV	{"email": "yakovlevnikolay051978@postgrespro.ru", "phone": "+70308621755"}
0005435423621	F996BD	2487 783557	DMITRIY SAVELEV	{"email": "savelev.d041984@postgrespro.ru", "phone": "+70810155238"}
0005435423622	4A6498	3286 597441	ANATOLIY PAVLOV	{"email": "anatoliy-pavlov1977@postgrespro.ru", "phone": "+70761942458"}
0005435423623	231F61	7769 607811	TATYANA IVANOVA	{"phone": "+70042438578"}
0005435423624	78BA50	4851 520197	TATYANA EFIMOVA	{"email": "tefimova.1979@postgrespro.ru", "phone": "+70708828485"}
0005435423625	6AB2FC	1100 847960	ALEKSANDRA POPOVA	{"email": "a_popova_031976@postgrespro.ru", "phone": "+70820638319"}
0005435423626	4FF24F	4138 133436	NIKOLAY PETROV	{"phone": "+70481642123"}
0005435423627	4FF24F	7688 106037	KIRILL SOROKIN	{"phone": "+70175630208"}
0005435423628	890A35	1998 618207	ELENA GAVRILOVA	{"phone": "+70121943605"}
0005435423629	0B378C	0615 668809	NADEZHDA PETROVA	{"email": "petrovan_1976@postgrespro.ru", "phone": "+70259114133"}
0005435423630	3E8DBB	4220 419758	ILSHAT ZAYCEV	{"email": "i-zaycev.09081961@postgrespro.ru", "phone": "+70102481543"}
0005435423631	DA4BEF	0779 824120	DANIIL OSIPOV	{"phone": "+70771657813"}
0005435423632	0E34E5	7145 404555	NINA BORISOVA	{"email": "nina-borisova-25041971@postgrespro.ru", "phone": "+70873367415"}
0005435423633	D2A5EB	6333 799413	ELENA NAZAROVA	{"email": "nazarovae_101973@postgrespro.ru", "phone": "+70397865075"}
0005435423634	F34013	3338 376020	SERGEY IVANOV	{"phone": "+70666878684"}
0005435423635	370497	9941 597895	DMITRIY SMIRNOV	{"email": "smirnovdmitriy-15121968@postgrespro.ru", "phone": "+70361039521"}
0005435423636	370497	3702 512404	VLADIMIR ZAKHAROV	{"phone": "+70554021442"}
0005435423637	A4A3DE	8886 915159	ALEKSEY NOVIKOV	{"phone": "+70994721189"}
0005435423638	A4A3DE	8631 035353	LYUDMILA VASILEVA	{"phone": "+70220780792"}
0005435423639	CC12A6	5771 386447	LIDIYA NESTEROVA	{"email": "nesterova-l.051968@postgrespro.ru", "phone": "+70018674348"}
0005435423640	BC5AA1	8852 230575	ALEKSANDR NIKITIN	{"phone": "+70025528559"}
0005435423641	BC5AA1	9024 610882	GALINA MIRONOVA	{"email": "g.mironova111972@postgrespro.ru", "phone": "+70422739469"}
0005435423642	91A062	8374 149730	ANATOLIY SHEVCHENKO	{"phone": "+70224940658"}
0005435423643	35B582	8640 332564	MARINA TIKHONOVA	{"email": "marina-tikhonova_12101980@postgrespro.ru", "phone": "+70140909773"}
0005435423644	D6C128	4383 771828	BOGDAN IVANOV	{"email": "ivanov.bogdan.13051961@postgrespro.ru", "phone": "+70008715613"}
0005435423645	D6C128	2876 592010	TAMARA LAZAREVA	{"email": "lazareva_t_1976@postgrespro.ru", "phone": "+70724282687"}
0005435423646	2486E8	6450 736257	EVGENIY MAKAROV	{"email": "e_makarov22021977@postgrespro.ru", "phone": "+70479720609"}
0005435423647	6D3FEC	4240 205349	ANZHELA EGOROVA	{"email": "a_egorova1961@postgrespro.ru", "phone": "+70443253447"}
0005435423648	795F21	6279 983879	EKATERINA SERGEEVA	{"email": "e.sergeeva-081975@postgrespro.ru", "phone": "+70339620722"}
0005435423649	795F21	3108 006740	NATALYA SOROKINA	{"email": "sorokina-natalya-15071973@postgrespro.ru", "phone": "+70681390487"}
0005435423650	2B26F1	3193 231005	LILIYA ROMANOVA	{"phone": "+70043069700"}
0005435423651	7A07FF	4844 862940	OKSANA AKIMOVA	{"email": "oksana_akimova.041970@postgrespro.ru", "phone": "+70505793580"}
0005435423652	7A07FF	3804 172881	ALIYA STEPANOVA	{"phone": "+70835400319"}
0005435423653	A891C7	6006 900176	ANATOLIY NAZAROV	{"phone": "+70431219639"}
0005435423654	1AABF4	8162 769250	ROMAN ABRAMOV	{"email": "abramov.r_12091981@postgrespro.ru", "phone": "+70282595110"}
0005435423655	593F98	0433 191808	ALEKSANDR ZAKHAROV	{"phone": "+70220662275"}
0005435423656	0056B0	9291 880761	LEONID ZAYCEV	{"phone": "+70947870752"}
0005435423657	938DCE	2109 923176	SERGEY TARASOV	{"email": "tarasov_s-051970@postgrespro.ru", "phone": "+70908175148"}
0005435423658	938DCE	3173 048165	ALEKSANDR GRIGOREV	{"email": "aleksandr.grigorev_041971@postgrespro.ru", "phone": "+70525289809"}
0005435423659	0492A1	9988 775180	NINA NESTEROVA	{"email": "n-nesterova-11091960@postgrespro.ru", "phone": "+70563582241"}
0005435423660	0492A1	7983 630076	LYUBOV ZHUKOVA	{"email": "lzhukova.17021974@postgrespro.ru", "phone": "+70318734867"}
0005435423661	D5EF2A	9497 294562	DARYA SOROKINA	{"email": "d_sorokina_1974@postgrespro.ru", "phone": "+70298131316"}
0005435423662	0DB66F	6804 954252	NIKOLAY PAVLOV	{"phone": "+70159697205"}
0005435423663	59A9F9	9869 258139	EKATERINA ZAKHAROVA	{"email": "zakharovae.031980@postgrespro.ru", "phone": "+70145702658"}
0005435423664	C1881C	2048 017253	MIKHAIL NIKOLAEV	{"email": "nikolaev-mikhail-1964@postgrespro.ru", "phone": "+70130258393"}
0005435423665	EF74C0	9885 184719	ILYA ANDREEV	{"email": "andreev.ilya.1982@postgrespro.ru", "phone": "+70361856883"}
0005435423666	98C0A8	1073 198645	NATALYA BELYAEVA	{"email": "belyaevanatalya_1976@postgrespro.ru", "phone": "+70510077744"}
0005435423667	169831	3516 908279	IVAN ISAEV	{"phone": "+70144093352"}
0005435423668	169831	2120 062710	VERA ROMANOVA	{"phone": "+70053921115"}
0005435423669	169831	8001 947607	DENIS EGOROV	{"email": "d.egorov101967@postgrespro.ru", "phone": "+70183654944"}
0005435423670	C5E7AD	4951 411093	SERGEY GORBUNOV	{"email": "gorbunov_sergey-03041971@postgrespro.ru", "phone": "+70151802702"}
0005435423671	860D06	4415 205316	PETR ALEKSANDROV	{"email": "aleksandrov_p.1959@postgrespro.ru", "phone": "+70403416550"}
0005435423672	A1A5F5	8775 479518	NIKITA MOROZOV	{"email": "morozov.nikita1980@postgrespro.ru", "phone": "+70983631428"}
0005435423673	2BCBE4	1035 405944	VALERIY SEMENOV	{"phone": "+70967851657"}
0005435423674	2BCBE4	0527 401005	VLADIMIR KARPOV	{"phone": "+70034339181"}
0005435423675	7D2787	1845 513774	NIKITA ANTONOV	{"phone": "+70902774417"}
0005435423676	913D12	7721 439474	LYUBOV KONOVALOVA	{"phone": "+70533402001"}
0005435423677	F8E2A3	4870 631358	ILYA SCHERBAKOV	{"phone": "+70572319991"}
0005435423678	CC6925	6441 408269	YURIY MIRONOV	{"email": "y-mironov_1972@postgrespro.ru", "phone": "+70223754482"}
0005435423679	56FF83	2325 310641	IGOR POPOV	{"email": "popov_i_1976@postgrespro.ru", "phone": "+70806767751"}
0005435423680	68DD66	4165 695089	EVGENIY SOLOVEV	{"phone": "+70057679176"}
0005435423681	ADF311	9219 134286	NINA ILINA	{"email": "nina.ilina1968@postgrespro.ru", "phone": "+70470149431"}
0005435423682	E36F16	7002 339415	TATYANA KOVALEVA	{"phone": "+70657178675"}
0005435423683	B7216C	5905 355143	NATALIYA FADEEVA	{"email": "n.fadeeva.1967@postgrespro.ru", "phone": "+70204636452"}
0005435423684	B7216C	0521 269937	ALENA KOROLEVA	{"email": "a_koroleva-1969@postgrespro.ru", "phone": "+70938676319"}
0005435423685	4C334B	2986 330250	SVETLANA SAVELEVA	{"phone": "+70375475775"}
0005435423686	5C4667	2157 820280	OLGA IVANOVA	{"email": "ivanova-olga-16021963@postgrespro.ru", "phone": "+70540358579"}
0005435423687	5C4667	9767 427565	VLADIMIR YAKOVLEV	{"phone": "+70121353389"}
0005435423688	F1C9E5	9107 800483	ALEKSANDR MAKAROV	{"phone": "+70584343563"}
0005435423689	22ECBA	4010 707209	ALENA IVANOVA	{"phone": "+70023325374"}
0005435423690	AD38E9	0323 789221	LYUDMILA PETROVA	{"phone": "+70816741334"}
0005435423691	913DB9	5982 894171	SOFYA KOLESNIKOVA	{"email": "kolesnikova.s25031971@postgrespro.ru", "phone": "+70986745820"}
0005435423692	923447	7257 531092	LARISA SOROKINA	{"phone": "+70149976544"}
0005435423693	E0F71A	4073 427229	IRINA KUDRYASHOVA	{"phone": "+70311531431"}
0005435423694	62C536	2953 235789	VLADISLAV KRASNOV	{"phone": "+70390224426"}
0005435423695	991A0D	2964 082809	ALEKSANDR MAKSIMOV	{"email": "aleksandr-maksimov.04101973@postgrespro.ru", "phone": "+70350559849"}
0005435423696	FEE0B7	2128 674446	YURIY EGOROV	{"phone": "+70750420092"}
0005435423697	9C1872	3696 880111	NATALYA GERASIMOVA	{"phone": "+70112486124"}
0005435423698	786506	0255 730556	TATYANA GAVRILOVA	{"email": "gavrilova-t.1978@postgrespro.ru", "phone": "+70798042518"}
0005435423699	786506	3986 752301	DARYA ABRAMOVA	{"email": "abramova_darya05051976@postgrespro.ru", "phone": "+70517684129"}
0005435423700	0005E7	5087 329973	ILYA MOROZOV	{"email": "morozov_i011981@postgrespro.ru", "phone": "+70309996690"}
0005435423701	27D156	6618 003872	ALLA MAKAROVA	{"email": "allamakarova1967@postgrespro.ru", "phone": "+70606141461"}
0005435423702	27D156	2598 729482	ALEKSANDR KONOVALOV	{"email": "a-konovalov-05071967@postgrespro.ru", "phone": "+70222694780"}
0005435423703	8402D7	8150 379741	OKSANA NIKOLAEVA	{"email": "nikolaeva_oksana-1964@postgrespro.ru", "phone": "+70019017777"}
0005435423704	7F9E00	7633 428001	EVGENIY TIMOFEEV	{"email": "evgeniy.timofeev_28011974@postgrespro.ru", "phone": "+70827989736"}
0005435423705	7F9E00	0121 417853	EKATERINA KULIKOVA	{"email": "kulikova.ekaterina.1961@postgrespro.ru", "phone": "+70190288700"}
0005435423706	141E1E	1654 127306	TATYANA GORBUNOVA	{"email": "t_gorbunova-1969@postgrespro.ru", "phone": "+70827983904"}
0005435423707	2CD697	9542 169869	YURIY KUZNECOV	{"email": "kuznecovyuriy.29031968@postgrespro.ru", "phone": "+70156826284"}
0005435423708	FD3D6C	3266 522046	YAROSLAV ZAYCEV	{"email": "yaroslav-zaycev_1967@postgrespro.ru", "phone": "+70358921556"}
0005435423709	FD3D6C	5797 663387	IVAN OSIPOV	{"email": "ivan-osipov_1980@postgrespro.ru", "phone": "+70563837926"}
0005435423710	108A80	1102 473754	NIKITA MIKHAYLOV	{"phone": "+70455299183"}
0005435423711	F00180	9725 465850	LYUDMILA KUZMINA	{"phone": "+70580654159"}
0005435423712	F00180	1528 625700	ALEKSANDR KUZMIN	{"phone": "+70543178853"}
0005435423713	DC41EB	0339 544960	NIKITA SOROKIN	{"phone": "+70436632099"}
0005435423714	98D422	6454 057116	NADEZHDA ZAYCEVA	{"phone": "+70080290534"}
0005435423715	1D2F1F	7195 368635	FARIT OSIPOV	{"phone": "+70215619303"}
0005435423716	B10026	8875 026375	KSENIYA KARPOVA	{"phone": "+70996154071"}
0005435423717	DCA637	5303 248654	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov.021972@postgrespro.ru", "phone": "+70754047952"}
0005435423718	508B71	6062 596501	LIDIYA GORBUNOVA	{"email": "gorbunova_lidiya.20031976@postgrespro.ru", "phone": "+70378024673"}
0005435423719	4D1FF8	7254 900803	SERGEY KULIKOV	{"email": "kulikov.s_111976@postgrespro.ru", "phone": "+70375809261"}
0005435423720	4D1FF8	0782 365307	TATYANA ISAEVA	{"email": "isaevat_26101981@postgrespro.ru", "phone": "+70753189301"}
0005435423721	EAD5FE	0764 034511	SERGEY MATVEEV	{"phone": "+70205763325"}
0005435423722	EAD5FE	2820 492109	GALINA NAZAROVA	{"phone": "+70179195813"}
0005435423723	64AED8	7336 520287	ANDREY GERASIMOV	{"email": "andreygerasimov.1973@postgrespro.ru", "phone": "+70713620563"}
0005435423724	DF2FA5	3339 432165	SERGEY KUZMIN	{"email": "sergey-kuzmin.03021966@postgrespro.ru", "phone": "+70900883278"}
0005435423725	60401B	0495 532926	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr-081965@postgrespro.ru", "phone": "+70796832174"}
0005435423726	E0A473	5641 447170	ANASTASIYA MATVEEVA	{"email": "matveeva-a_071969@postgrespro.ru", "phone": "+70736638273"}
0005435423727	33DAE5	7103 854296	LARISA NIKITINA	{"phone": "+70734334963"}
0005435423728	479EC4	3958 697393	YULIYA KAZAKOVA	{"phone": "+70397030143"}
0005435423729	5A55A4	6862 765206	VASILIY PETROV	{"phone": "+70180862397"}
0005435423730	80B6AE	8856 308451	IGOR TIMOFEEV	{"phone": "+70970344394"}
0005435423731	080516	5401 837747	MATVEY ZAKHAROV	{"email": "mzakharov-041974@postgrespro.ru", "phone": "+70401687507"}
0005435423732	080516	7191 928898	VLADIMIR NIKOLAEV	{"phone": "+70898184165"}
0005435423733	2D5879	4583 492847	NATALIYA RYABOVA	{"phone": "+70329940101"}
0005435423734	231773	4450 163102	KAMILLA SIDOROVA	{"email": "kamilla_sidorova_10081976@postgrespro.ru", "phone": "+70244129313"}
0005435423735	231773	4781 717803	GENNADIY VLASOV	{"phone": "+70459374499"}
0005435423736	1B1DEA	9655 970929	TATYANA BELOVA	{"phone": "+70622835954"}
0005435423737	47EE90	1095 305534	ALEKSANDR DAVYDOV	{"email": "davydov.aleksandr-11041966@postgrespro.ru", "phone": "+70616124990"}
0005435423738	9C643C	0114 755105	OKSANA YUDINA	{"email": "oksana-yudina.071980@postgrespro.ru", "phone": "+70785278391"}
0005435423739	EBF3CF	2257 485424	NINA POTAPOVA	{"phone": "+70192657816"}
0005435423740	586023	2172 490015	RAISA BORISOVA	{"phone": "+70334597400"}
0005435423741	5DAF77	9973 585420	TAMARA ERMAKOVA	{"email": "ermakova.t_031963@postgrespro.ru", "phone": "+70058067572"}
0005435423742	AB0BB1	7084 007029	VALENTINA OSIPOVA	{"phone": "+70742296739"}
0005435423743	AB0BB1	1030 828194	DMITRIY ZAKHAROV	{"email": "dmitriy-zakharov-30101970@postgrespro.ru", "phone": "+70598950089"}
0005435423744	47C5FD	2523 821308	SVETLANA ZHUKOVA	{"phone": "+70372248697"}
0005435423805	F4A52B	7665 497687	NIKITA KUZMIN	{"phone": "+70113041706"}
0005435423745	47C5FD	4788 737625	NIKOLAY VASILEV	{"email": "vasilevn08071965@postgrespro.ru", "phone": "+70905339380"}
0005435423746	3456BC	4971 840035	LIDIYA SEMENOVA	{"phone": "+70575073080"}
0005435423747	3456BC	2487 838047	ALEKSEY PAVLOV	{"email": "aleksey-pavlov-1972@postgrespro.ru", "phone": "+70269101174"}
0005435423748	4D4CDA	8327 309574	ANASTASIYA AFANASEVA	{"phone": "+70819746859"}
0005435423749	4D4CDA	6428 972234	IVAN ANDREEV	{"phone": "+70726899626"}
0005435423750	0D5A28	5910 084387	TAMARA MIKHAYLOVA	{"phone": "+70754960819"}
0005435423751	0D5A28	7580 844396	STANISLAV KOZLOV	{"email": "stanislavkozlov1962@postgrespro.ru", "phone": "+70019069981"}
0005435423752	309BB3	2435 475665	DMITRIY MATVEEV	{"phone": "+70208183633"}
0005435423753	CD30B9	6546 485213	ALEKSANDRA MELNIKOVA	{"phone": "+70709513908"}
0005435423754	CD30B9	2959 351357	VLADIMIR PAVLOV	{"phone": "+70360263789"}
0005435423755	019EE0	7006 547983	NIKOLAY AFANASEV	{"phone": "+70449184874"}
0005435423756	019EE0	4420 322174	OLGA KUZNECOVA	{"phone": "+70354967032"}
0005435423757	CE6087	8494 870289	VIKTOR SOKOLOV	{"email": "sokolovviktor22031969@postgrespro.ru", "phone": "+70867972540"}
0005435423758	CE6087	9899 049122	SVETLANA MOROZOVA	{"phone": "+70649765015"}
0005435423759	044F5C	5753 358178	VALERIY KARPOV	{"phone": "+70862102313"}
0005435423760	37CFF8	1800 395734	NIKOLAY ALEKSANDROV	{"email": "aleksandrov_n.1971@postgrespro.ru", "phone": "+70446406151"}
0005435423761	7083FE	0399 723705	AMIR STEPANOV	{"email": "astepanov26011974@postgrespro.ru", "phone": "+70993354244"}
0005435423762	B892D2	3717 411009	TATYANA FROLOVA	{"phone": "+70233809196"}
0005435423763	B892D2	8093 792256	VADIM RODIONOV	{"email": "rodionov_v-11111957@postgrespro.ru", "phone": "+70203291239"}
0005435423764	C853F8	3658 184540	LIDIYA GERASIMOVA	{"phone": "+70033055363"}
0005435423765	7F0A07	2169 070334	YURIY ZAKHAROV	{"phone": "+70393710243"}
0005435423766	A853B8	8553 861665	VADIM KARPOV	{"phone": "+70175918053"}
0005435423767	81C4DD	8740 376531	MIKHAIL SERGEEV	{"email": "msergeev1974@postgrespro.ru", "phone": "+70014925568"}
0005435423768	81C4DD	4850 639347	ALINA MOISEEVA	{"email": "moiseeva_alina-1985@postgrespro.ru", "phone": "+70814579481"}
0005435423769	81C4DD	7248 375872	ALEKSANDR GRIGOREV	{"phone": "+70509908443"}
0005435423770	3B8F09	3666 096356	VIKTOR GRIGOREV	{"email": "grigorev_viktor_1981@postgrespro.ru", "phone": "+70784136501"}
0005435423771	1FCED5	7987 975033	NATALYA KONDRATEVA	{"email": "natalya.kondrateva-25081971@postgrespro.ru", "phone": "+70040511835"}
0005435423772	1FCED5	1098 615803	ANDREY NAUMOV	{"email": "naumov.a.111971@postgrespro.ru", "phone": "+70069403533"}
0005435423773	A7CB76	9458 080693	GENNADIY IVANOV	{"phone": "+70040104514"}
0005435423774	6DD113	7228 607770	VASILIY SOKOLOV	{"email": "vasiliy-sokolov.12061966@postgrespro.ru", "phone": "+70956196917"}
0005435423775	6DD113	6317 275484	ALINA NOVIKOVA	{"email": "alinanovikova121963@postgrespro.ru", "phone": "+70321809823"}
0005435423776	03A624	7076 920507	ANDREY TIMOFEEV	{"email": "timofeev.andrey.09031972@postgrespro.ru", "phone": "+70783162265"}
0005435423777	9A540F	4205 618203	OLGA NAUMOVA	{"phone": "+70354534286"}
0005435423778	166E78	4725 735775	RAFIK KUZMIN	{"email": "kuzminr_09011981@postgrespro.ru", "phone": "+70410572661"}
0005435423779	166E78	7745 342003	SVETLANA KUZNECOVA	{"email": "kuznecovasvetlana30101966@postgrespro.ru", "phone": "+70198922329"}
0005435423780	4F5C93	0328 131981	ALEKSEY IVANOV	{"email": "a-ivanov_10111974@postgrespro.ru", "phone": "+70651089814"}
0005435423781	4F5C93	8417 966903	ALISA KUZNECOVA	{"phone": "+70192467424"}
0005435423782	B9D14C	5017 206110	TATYANA SIDOROVA	{"email": "tsidorova-051968@postgrespro.ru", "phone": "+70238071933"}
0005435423783	E699DB	1008 248885	ILYA MAKAROV	{"email": "imakarov_061970@postgrespro.ru", "phone": "+70008615656"}
0005435423784	E699DB	5366 243906	PETR ILIN	{"email": "ilin-petr011965@postgrespro.ru", "phone": "+70746543176"}
0005435423785	71C346	1805 266186	NATALYA POPOVA	{"phone": "+70359184076"}
0005435423786	71C346	2691 783524	YAKOV ISAEV	{"email": "isaevyakov_091980@postgrespro.ru", "phone": "+70846329815"}
0005435423787	5D1FF3	8605 417398	GENNADIY KUZNECOV	{"email": "kuznecov_g-1973@postgrespro.ru", "phone": "+70921628518"}
0005435423788	4FC22E	3553 043202	DMITRIY ROMANOV	{"email": "d.romanov.101971@postgrespro.ru", "phone": "+70259029161"}
0005435423789	F60A54	6266 411154	VALERIYA MOISEEVA	{"phone": "+70439763201"}
0005435423790	5EAF6F	9060 960706	MIKHAIL MATVEEV	{"phone": "+70339000416"}
0005435423791	5EAF6F	7446 578313	OLGA ALEKSANDROVA	{"email": "olgaaleksandrova071968@postgrespro.ru", "phone": "+70937194938"}
0005435423792	826F76	2189 357920	VIKTOR POPOV	{"email": "popov_viktor1960@postgrespro.ru", "phone": "+70619003067"}
0005435423793	9C29E3	3333 879173	NIKITA FEDOROV	{"email": "nikita_fedorov-061978@postgrespro.ru", "phone": "+70131475763"}
0005435423794	9C29E3	6557 371302	RAISA SMIRNOVA	{"phone": "+70158178100"}
0005435423795	2E91DD	2108 464885	ANNA TROFIMOVA	{"email": "trofimova_anna.011975@postgrespro.ru", "phone": "+70853974584"}
0005435423796	1A0AA4	1206 900689	SERGEY POPOV	{"phone": "+70140784962"}
0005435423797	1291B8	5083 783537	VALERIY IVANOV	{"email": "ivanov-valeriy_09121969@postgrespro.ru", "phone": "+70784405350"}
0005435423798	1291B8	7737 922467	EVDOKIYA KUZNECOVA	{"phone": "+70009578237"}
0005435423799	2790C6	5881 674528	ZHANNA EFIMOVA	{"email": "efimova.z.091981@postgrespro.ru", "phone": "+70894957421"}
0005435423800	7E249F	4932 384297	ZINAIDA KUZMINA	{"phone": "+70461229380"}
0005435423801	08D5DB	5049 900001	NADEZHDA TIKHONOVA	{"email": "tikhonova-nadezhda-101963@postgrespro.ru", "phone": "+70781137425"}
0005435423802	08D5DB	3795 614825	TATYANA SOKOLOVA	{"phone": "+70150943215"}
0005435423803	42B874	8883 838128	MARIYA FILIPPOVA	{"email": "m_filippova_071965@postgrespro.ru", "phone": "+70609377682"}
0005435423804	42B874	2268 919012	LIDIYA MELNIKOVA	{"phone": "+70787657257"}
0005435423806	5F1BF7	5722 680606	RUSLAN KUZNECOV	{"phone": "+70204133847"}
0005435423807	5F1BF7	4090 389537	IVAN STEPANOV	{"phone": "+70162040244"}
0005435423808	8F48AB	6394 620803	ELENA LUKYANOVA	{"email": "e_lukyanova-04041975@postgrespro.ru", "phone": "+70726546395"}
0005435423809	8F48AB	7817 309119	GALINA KOROLEVA	{"email": "galinakoroleva31071971@postgrespro.ru", "phone": "+70662300464"}
0005435423810	2C6125	8496 696510	IVAN SAVELEV	{"email": "i.savelev1977@postgrespro.ru", "phone": "+70051419025"}
0005435423811	2C6125	9987 537931	VIKTORIYA ANDREEVA	{"phone": "+70758752964"}
0005435423812	9EB283	9395 706586	VLADISLAV FROLOV	{"email": "frolov-v-18061973@postgrespro.ru", "phone": "+70791712093"}
0005435423813	9EB283	5875 427747	ALEKSEY NAZAROV	{"phone": "+70035844267"}
0005435423814	DCAF43	2455 756214	MAKSIM VOLKOV	{"email": "mvolkov.1972@postgrespro.ru", "phone": "+70857464492"}
0005435423815	DCAF43	6154 098942	YURIY POPOV	{"email": "popov.y.07041969@postgrespro.ru", "phone": "+70653800761"}
0005435423816	09ECB7	2728 064394	VALENTINA YAKOVLEVA	{"phone": "+70149930664"}
0005435423817	09ECB7	2470 577981	GEORGIY ZAKHAROV	{"phone": "+70640923008"}
0005435423818	CEC1E4	0162 206097	VLADIMIR ILIN	{"phone": "+70369665960"}
0005435423819	CEC1E4	6651 843566	KONSTANTIN NIKITIN	{"email": "nikitin.k-1968@postgrespro.ru", "phone": "+70974127841"}
0005435423820	87B9D6	8223 312385	ALEKSANDR SCHERBAKOV	{"phone": "+70989204792"}
0005435423821	87B9D6	8442 701936	VALENTINA VOROBEVA	{"email": "vorobeva_valentina.02031976@postgrespro.ru", "phone": "+70723726137"}
0005435423822	39068C	4925 976047	NINA SOROKINA	{"email": "nina-sorokina.23121979@postgrespro.ru", "phone": "+70228662459"}
0005435423823	5FB038	2812 831556	EVGENIY POPOV	{"email": "evgeniypopov-061962@postgrespro.ru", "phone": "+70982552714"}
0005435423824	5FB038	3999 046672	ELENA GORBUNOVA	{"email": "egorbunova-1975@postgrespro.ru", "phone": "+70213989349"}
0005435423825	0A06B8	0482 590416	YULIYA LEBEDEVA	{"phone": "+70636669633"}
0005435423826	0A06B8	5709 401750	SVETLANA KISELEVA	{"email": "kiselevasvetlana-121978@postgrespro.ru", "phone": "+70050295604"}
0005435423827	D38E8A	4621 829345	LIDIYA OVCHINNIKOVA	{"email": "ovchinnikova.l.22031969@postgrespro.ru", "phone": "+70616855103"}
0005435423828	D38E8A	2295 879547	VIKTOR ZAKHAROV	{"phone": "+70940732028"}
0005435423829	4B4A0E	2699 172323	ANTONINA KUZNECOVA	{"phone": "+70095995521"}
0005435423830	310ED0	3143 123575	ALEKSANDR FOMIN	{"phone": "+70351216314"}
0005435423831	310ED0	8377 448844	YURIY BORISOV	{"email": "borisov-yuriy.06011984@postgrespro.ru", "phone": "+70237548330"}
0005435423832	1BEFB9	6643 546224	YURIY VOLKOV	{"phone": "+70562987786"}
0005435423833	CBF8DF	0480 204377	OLGA DAVYDOVA	{"email": "odavydova-031976@postgrespro.ru", "phone": "+70563901060"}
0005435423834	CBF8DF	8488 320893	MARINA ALEKSANDROVA	{"email": "marina-aleksandrova-1974@postgrespro.ru", "phone": "+70784923986"}
0005435423835	39F784	3291 365604	DMITRIY KUZNECOV	{"phone": "+70311756812"}
0005435423836	39F784	6538 091264	SERGEY FROLOV	{"email": "s.frolov07101971@postgrespro.ru", "phone": "+70711741071"}
0005435423837	0D21D8	6215 362751	OKSANA SIDOROVA	{"email": "o.sidorova081959@postgrespro.ru", "phone": "+70527009281"}
0005435423838	DDC24B	1021 409156	SVETLANA POPOVA	{"phone": "+70753972159"}
0005435423839	C9A059	4082 661084	MARIYA FADEEVA	{"email": "m.fadeeva.091962@postgrespro.ru", "phone": "+70575575795"}
0005435423840	C9A059	8431 052382	TAMARA GRISHINA	{"phone": "+70123986884"}
0005435423841	078DDF	3472 969882	ALEKSEY NIKOLAEV	{"phone": "+70880983902"}
0005435423842	078DDF	9162 063088	SVETLANA FOMINA	{"phone": "+70511988827"}
0005435423843	90F749	2639 117263	MIKHAIL KISELEV	{"email": "kiselev_mikhail-1979@postgrespro.ru", "phone": "+70962977978"}
0005435423844	90F749	1271 250365	BOGDAN YAKOVLEV	{"phone": "+70913661858"}
0005435423845	17CA32	3106 800312	OLEG AFANASEV	{"email": "oafanasev021966@postgrespro.ru", "phone": "+70236294213"}
0005435423846	17CA32	8992 663072	ROMAN DAVYDOV	{"email": "davydovroman29071977@postgrespro.ru", "phone": "+70125526026"}
0005435423847	996723	7395 528156	VLADIMIR ZHUKOV	{"phone": "+70210165292"}
0005435423848	996723	0410 022480	NIKITA ZAKHAROV	{"phone": "+70461254345"}
0005435423849	CCF846	3898 407132	IGOR PAVLOV	{"phone": "+70456437599"}
0005435423850	CCF846	0403 724031	NIKITA FEDOTOV	{"phone": "+70984287431"}
0005435423851	CCF846	9212 191002	SERGEY POPOV	{"phone": "+70878848106"}
0005435423852	72D4BA	9163 362645	SERGEY SOROKIN	{"phone": "+70262735382"}
0005435423853	72D4BA	9455 087602	ROMAN AFANASEV	{"phone": "+70132234602"}
0005435423854	72D4BA	8234 338201	ARTEM KUZNECOV	{"phone": "+70411245822"}
0005435423855	8E883F	5664 797305	VALENTINA ORLOVA	{"email": "orlova.v101970@postgrespro.ru", "phone": "+70880170802"}
0005435423856	F22AAA	0722 962060	NATALYA IVANOVA	{"phone": "+70442768552"}
0005435423857	F22AAA	1263 334904	SERGEY VOLKOV	{"phone": "+70969619148"}
0005435423858	8C4C81	9698 725911	ALEKSANDR NAUMOV	{"email": "naumov-aleksandr_17091972@postgrespro.ru", "phone": "+70100428712"}
0005435423859	8C4C81	2578 795276	VLADIMIR PETROV	{"email": "petrov.vladimir-031972@postgrespro.ru", "phone": "+70147524280"}
0005435423860	D3344D	5492 292206	TATYANA TARASOVA	{"email": "tarasovatatyana_101978@postgrespro.ru", "phone": "+70320996715"}
0005435423861	11DCA8	2063 928314	MAKSIM BELOV	{"email": "belov.maksim.1967@postgrespro.ru", "phone": "+70675099777"}
0005435423862	70719A	6929 581298	YURIY MIKHAYLOV	{"email": "mikhaylovy-031966@postgrespro.ru", "phone": "+70037886011"}
0005435423863	9FE988	5180 348299	PETR NAUMOV	{"phone": "+70148194462"}
0005435423864	664C34	0858 181575	SERGEY CHERNOV	{"phone": "+70650439870"}
0005435423865	D7DC32	7274 862286	YULIYA KOZLOVA	{"phone": "+70378904738"}
0005435423866	82046A	1881 970496	YULIYA KISELEVA	{"email": "y_kiseleva-1977@postgrespro.ru", "phone": "+70455332170"}
0005435423867	7B1D9F	9133 533326	GALINA BELOVA	{"phone": "+70644331102"}
0005435423868	7B1D9F	2289 788209	ALEKSANDR KOZLOV	{"email": "kozlov_a.051973@postgrespro.ru", "phone": "+70253640993"}
0005435423869	7B1D9F	6335 061244	LIDIYA KULIKOVA	{"email": "kulikova.lidiya21021969@postgrespro.ru", "phone": "+70797430353"}
0005435423870	6EE573	2158 574785	SERGEY VASILEV	{"email": "sergeyvasilev.081974@postgrespro.ru", "phone": "+70340936995"}
0005435423871	46CD45	3929 473486	NADEZHDA MIKHAYLOVA	{"email": "mikhaylova_n.14111966@postgrespro.ru", "phone": "+70832331889"}
0005435423872	4555E5	4959 645362	VLADIMIR OSIPOV	{"email": "v_osipov-051981@postgrespro.ru", "phone": "+70421512452"}
0005435423873	4555E5	8497 044207	SVETLANA ALEKSEEVA	{"phone": "+70655488452"}
0005435423874	A2EBCA	1840 372964	YULIYA KONOVALOVA	{"email": "konovalova.yuliya-1964@postgrespro.ru", "phone": "+70979624248"}
0005435423875	173958	5381 966783	LILIYA EGOROVA	{"email": "egorovaliliya_05071972@postgrespro.ru", "phone": "+70351218173"}
0005435423876	173958	1194 666333	VENERA GRISHINA	{"phone": "+70480134664"}
0005435423877	B538C6	6246 678653	LYUDMILA ARKHIPOVA	{"phone": "+70509995410"}
0005435423878	1C9A7B	8121 832190	TATYANA IVANOVA	{"phone": "+70010789372"}
0005435423879	26296F	5241 237177	SERGEY SIDOROV	{"phone": "+70113587777"}
0005435423880	FFAD76	1682 375733	VYACHESLAV VOLKOV	{"phone": "+70344169656"}
0005435423881	306AB4	9565 973865	ARTEM FOMIN	{"email": "artem.fomin_041969@postgrespro.ru", "phone": "+70504273887"}
0005435423882	306AB4	3335 753564	YURIY VOROBEV	{"phone": "+70087889351"}
0005435423883	8A18AE	6155 031097	ZINAIDA KONOVALOVA	{"email": "konovalovazinaida1970@postgrespro.ru", "phone": "+70848354192"}
0005435423884	8A18AE	1713 473213	NATALYA NIKITINA	{"phone": "+70227278820"}
0005435423885	ECAB44	7105 447254	NIKOLAY NOVIKOV	{"phone": "+70071434244"}
0005435423886	FCE9D8	5367 830397	ELENA ZOTOVA	{"email": "elena.zotova_03011971@postgrespro.ru", "phone": "+70002025844"}
0005435423887	FCE9D8	3308 207047	MAKSIM GORBUNOV	{"phone": "+70359188025"}
0005435423888	4C2C27	7879 742502	ANDREY VOLKOV	{"email": "andreyvolkov-091976@postgrespro.ru", "phone": "+70721362364"}
0005435423889	4C2C27	9303 666362	EKATERINA ZAYCEVA	{"email": "ekaterinazayceva081969@postgrespro.ru", "phone": "+70380435872"}
0005435423890	B473F5	6275 627031	MARIYA MAKAROVA	{"email": "m.makarova_17121961@postgrespro.ru", "phone": "+70603940357"}
0005435423891	00F159	9294 629936	IRINA MAKAROVA	{"email": "makarovai_01091979@postgrespro.ru", "phone": "+70690606234"}
0005435423892	00F159	8094 591619	ALEVTINA KAZAKOVA	{"email": "akazakova.1969@postgrespro.ru", "phone": "+70966718086"}
0005435423893	4BEF97	1768 137093	LYUBOV POLYAKOVA	{"email": "l-polyakova.1973@postgrespro.ru", "phone": "+70200546081"}
0005435423894	D74125	9693 425200	NATALIYA ORLOVA	{"email": "orlova-nataliya_29111977@postgrespro.ru", "phone": "+70611209180"}
0005435423895	D74125	0636 067901	ALEKSANDR NAUMOV	{"email": "naumov_a.14021966@postgrespro.ru", "phone": "+70891471141"}
0005435423896	39F109	2675 095756	OLEG SHEVCHENKO	{"phone": "+70129537295"}
0005435423897	100C21	4380 013761	NIKOLAY KOZLOV	{"email": "nkozlov_121961@postgrespro.ru", "phone": "+70232817866"}
0005435423898	BFBA9F	1604 373130	ANATOLIY ISAEV	{"email": "isaev_a.01091976@postgrespro.ru", "phone": "+70545370189"}
0005435423899	2A1884	5004 181439	VALENTIN AFANASEV	{"email": "afanasev.valentin.1966@postgrespro.ru", "phone": "+70743479075"}
0005435423900	59A1E9	6790 729168	KSENIYA LUKYANOVA	{"phone": "+70567278628"}
0005435423901	B88E04	1654 155119	VALERIY NIKITIN	{"email": "nikitin.v-1981@postgrespro.ru", "phone": "+70195905273"}
0005435423902	B88E04	4392 245777	NIKOLAY KUZMIN	{"email": "kuzmin_nikolay15121965@postgrespro.ru", "phone": "+70849147662"}
0005435423903	D87D23	7879 356122	EVGENIY SAVELEV	{"email": "savelev_e16101978@postgrespro.ru", "phone": "+70197237128"}
0005435423904	D87D23	5342 366959	LYUDMILA NOVIKOVA	{"email": "lyudmila.novikova.051981@postgrespro.ru", "phone": "+70924133387"}
0005435423905	E1245E	6377 008597	MARIYA POPOVA	{"phone": "+70227879652"}
0005435423906	E1245E	9747 740385	VYACHESLAV TIMOFEEV	{"email": "timofeev.vyacheslav1982@postgrespro.ru", "phone": "+70501511265"}
0005435423907	0EB4EC	6063 215338	VASILIY AFANASEV	{"email": "afanasev-vasiliy101978@postgrespro.ru", "phone": "+70192802662"}
0005435423908	489F9A	1198 946293	ALEKSEY IVANOV	{"email": "ivanova-29031977@postgrespro.ru", "phone": "+70972031145"}
0005435423909	80378E	0373 176712	IRINA NIKOLAEVA	{"email": "nikolaeva_i_05121981@postgrespro.ru", "phone": "+70292568212"}
0005435423910	36694A	7764 492364	MARIYA EGOROVA	{"phone": "+70546988555"}
0005435423911	94D727	3805 277159	ALEKSANDR NIKOLAEV	{"phone": "+70254164021"}
0005435423912	BDFFE4	6314 247080	BORIS VOLKOV	{"email": "boris.volkov1986@postgrespro.ru", "phone": "+70590363921"}
0005435423913	67CB17	3997 488615	MIKHAIL ANTONOV	{"email": "m.antonov.021968@postgrespro.ru", "phone": "+70739622800"}
0005435423914	67CB17	3440 656718	OLGA MATVEEVA	{"phone": "+70024223270"}
0005435423915	559B7D	6009 977353	ANASTASIYA LUKYANOVA	{"email": "a.lukyanova.1981@postgrespro.ru", "phone": "+70560379968"}
0005435423916	5441C3	1825 590664	VIKTORIYA KOROLEVA	{"email": "korolevaviktoriya-1977@postgrespro.ru", "phone": "+70285175168"}
0005435423917	F67ECD	9784 883554	NATALYA KUZNECOVA	{"phone": "+70283770143"}
0005435423918	F8E78A	5119 001161	ROBERT GRIGOREV	{"phone": "+70921529060"}
0005435423919	0A111D	8095 618403	DANIL MAKAROV	{"email": "dmakarov-071973@postgrespro.ru", "phone": "+70416547889"}
0005435423920	0A111D	4895 240936	YULIYA LOGINOVA	{"phone": "+70501388787"}
0005435423921	0A111D	4511 545510	LARISA KOLESNIKOVA	{"email": "kolesnikova_larisa_16111965@postgrespro.ru", "phone": "+70660994304"}
0005435423922	C327E6	9063 480635	ILYA NIKOLAEV	{"phone": "+70326047547"}
0005435423923	C327E6	2663 490325	ANASTASIYA SOKOLOVA	{"email": "anastasiya-sokolova.121979@postgrespro.ru", "phone": "+70395636757"}
0005435423924	007C7D	0001 712735	VALERIY ORLOV	{"phone": "+70239805607"}
0005435424044	9EFEEC	5753 618609	SVETLANA KARPOVA	{"phone": "+70728315072"}
0005435423925	007C7D	9379 894250	VALERIY NOVIKOV	{"email": "novikov.valeriy1961@postgrespro.ru", "phone": "+70339807119"}
0005435423926	213E69	0646 166711	ILYA KUZMIN	{"phone": "+70071006108"}
0005435423927	CE1ABD	5044 682066	MADINA POLYAKOVA	{"phone": "+70741127513"}
0005435423928	F76249	8159 783164	TATYANA PETROVA	{"email": "petrovat_14081971@postgrespro.ru", "phone": "+70724176972"}
0005435423929	86B7C9	1983 291077	VLADIMIR TIMOFEEV	{"phone": "+70247961032"}
0005435423930	57A914	7340 897668	SERGEY VOLKOV	{"email": "volkov-sergey1978@postgrespro.ru", "phone": "+70428706546"}
0005435423931	2B0EB9	1792 748610	VALENTINA GAVRILOVA	{"email": "gavrilova-valentina18091967@postgrespro.ru", "phone": "+70834471319"}
0005435423932	F24F46	4136 780087	VALENTINA DENISOVA	{"email": "valentina-denisova-07031966@postgrespro.ru", "phone": "+70041493628"}
0005435424046	BD7B16	9036 419558	SERAFIMA ISAEVA	{"phone": "+70325781812"}
0005435423933	C1673D	6818 720959	SVETLANA POPOVA	{"email": "s_popova.021967@postgrespro.ru", "phone": "+70528942926"}
0005435423934	C1673D	1121 445664	NATALYA ABRAMOVA	{"phone": "+70391945169"}
0005435423935	17FBEB	2863 410423	ANASTASIYA MARTYNOVA	{"email": "martynova_a_091972@postgrespro.ru", "phone": "+70338116141"}
0005435423936	17FBEB	8250 138962	ELMIRA BELOVA	{"phone": "+70882780804"}
0005435423937	17FBEB	2136 286786	ALEKSEY EGOROV	{"email": "alekseyegorov_13111989@postgrespro.ru", "phone": "+70097414310"}
0005435423938	20E1BB	3332 816989	ALEKSANDRA MAKSIMOVA	{"email": "maksimova.aleksandra.26071986@postgrespro.ru", "phone": "+70538107935"}
0005435423939	5B643C	3777 668707	SERGEY ORLOV	{"email": "s-orlov_051965@postgrespro.ru", "phone": "+70590784683"}
0005435423940	5B643C	4831 156475	STANISLAV BORISOV	{"email": "stanislav.borisov10121976@postgrespro.ru", "phone": "+70524259603"}
0005435423941	0701DF	6011 058729	ALEKSANDR KUZNECOV	{"email": "kuznecova-071966@postgrespro.ru", "phone": "+70953698104"}
0005435423942	6D13D3	8068 727242	VYACHESLAV MELNIKOV	{"email": "vyacheslav_melnikov061966@postgrespro.ru", "phone": "+70852063913"}
0005435423943	100078	4087 268154	TATYANA GORBUNOVA	{"email": "t.gorbunova-071985@postgrespro.ru", "phone": "+70794561135"}
0005435423944	2AC736	8904 275925	KLAVDIYA NIKITINA	{"phone": "+70469809220"}
0005435423945	18DEB3	4525 586710	IRINA KOROLEVA	{"phone": "+70135461205"}
0005435423946	18DEB3	0573 025969	PAVEL STEPANOV	{"phone": "+70627716338"}
0005435423947	8786ED	4283 706242	INNA ILINA	{"email": "ilina-i.27011973@postgrespro.ru", "phone": "+70815520958"}
0005435423948	8786ED	6298 453812	NIKOLAY GAVRILOV	{"phone": "+70495322623"}
0005435423949	31D8F5	4212 478076	OLEG RODIONOV	{"phone": "+70344210780"}
0005435423950	4612A1	7952 727457	VERA TROFIMOVA	{"phone": "+70884334942"}
0005435423951	1B984C	1977 931989	SERGEY NIKOLAEV	{"email": "sergey_nikolaev_101977@postgrespro.ru", "phone": "+70114934805"}
0005435423952	1B984C	7094 360820	NIKOLAY IVANOV	{"email": "nikolayivanov_03041981@postgrespro.ru", "phone": "+70404390633"}
0005435423953	563807	7813 229332	ELENA SCHERBAKOVA	{"email": "scherbakovaelena.1974@postgrespro.ru", "phone": "+70111498421"}
0005435423954	401311	7298 597585	ALEKSANDR GORBUNOV	{"phone": "+70883683273"}
0005435423955	2281FA	7710 888413	MAKSIM NAZAROV	{"email": "nazarovm-041976@postgrespro.ru", "phone": "+70550250382"}
0005435423956	9F75B0	6002 246882	VALENTIN VOLKOV	{"email": "volkov_valentin071969@postgrespro.ru", "phone": "+70874023450"}
0005435423957	2CDE9F	6765 126199	ELENA MIKHAYLOVA	{"phone": "+70128213284"}
0005435423958	2CDE9F	1602 269238	TATYANA KOROLEVA	{"phone": "+70354111313"}
0005435423959	A1CE0D	3707 605736	YURIY DMITRIEV	{"phone": "+70056703555"}
0005435423960	AFF16F	5428 116816	GALINA KAZAKOVA	{"email": "galinakazakova.12081972@postgrespro.ru", "phone": "+70243060519"}
0005435423961	6043A8	7592 735981	IRINA VLASOVA	{"phone": "+70345962961"}
0005435423962	6043A8	4538 187532	ANNA GRISHINA	{"phone": "+70765111964"}
0005435423963	FB63C9	5673 040927	ARTEM KULIKOV	{"phone": "+70119750696"}
0005435423964	475AC1	4572 418413	ANATOLIY FEDOTOV	{"email": "fedotov_anatoliy1972@postgrespro.ru", "phone": "+70310446071"}
0005435423965	399DE8	3554 299882	LIDIYA SOLOVEVA	{"phone": "+70326316979"}
0005435423966	7E7B67	6093 476820	GALINA DANILOVA	{"email": "gdanilova_24061973@postgrespro.ru", "phone": "+70442065197"}
0005435423967	7E7B67	9653 149461	LYUDMILA ISAEVA	{"email": "isaeval_121975@postgrespro.ru", "phone": "+70064564695"}
0005435423968	7E7B67	7931 025146	NATALYA ZAYCEVA	{"email": "zayceva_natalya_041979@postgrespro.ru", "phone": "+70412356439"}
0005435423969	559D26	7731 903688	ALEKSANDR KULIKOV	{"phone": "+70930533291"}
0005435423970	05B379	6231 648826	ALEKSANDR BORISOV	{"phone": "+70455603879"}
0005435423971	05B379	7688 941457	GAGIK BARANOV	{"email": "gagik_baranov_1980@postgrespro.ru", "phone": "+70293143977"}
0005435423972	55389F	0163 434556	IVAN POPOV	{"email": "popov_ivan051975@postgrespro.ru", "phone": "+70759656329"}
0005435423973	55389F	8340 457948	IVAN SIDOROV	{"email": "isidorov_1982@postgrespro.ru", "phone": "+70687050209"}
0005435423974	44998F	7517 859809	GENNADIY KOZLOV	{"email": "kozlovgennadiy1965@postgrespro.ru", "phone": "+70849704394"}
0005435423975	E62B95	0954 720699	NADEZHDA GUSEVA	{"phone": "+70881137274"}
0005435423976	E62B95	2099 300508	ELENA ZAKHAROVA	{"email": "elena-zakharova_1967@postgrespro.ru", "phone": "+70365570647"}
0005435423977	9BBB9A	6862 943432	ANATOLIY KONOVALOV	{"phone": "+70557645310"}
0005435423978	9BBB9A	6796 330499	YULIYA VOLKOVA	{"email": "volkova_yuliya_061967@postgrespro.ru", "phone": "+70488070170"}
0005435423979	C64AB5	3288 276694	GALINA MAKAROVA	{"email": "galinamakarova1981@postgrespro.ru", "phone": "+70701681364"}
0005435423980	C64AB5	2553 272499	MAKSIM NAZAROV	{"phone": "+70598423533"}
0005435423981	C64AB5	2631 534056	ALEKSANDR SIDOROV	{"phone": "+70245180305"}
0005435423982	A65246	3445 202964	EKATERINA YAKOVLEVA	{"phone": "+70870750779"}
0005435423983	A2B4DA	3799 132287	ELENA BELOVA	{"email": "belova-elena1981@postgrespro.ru", "phone": "+70875224939"}
0005435423984	A2B4DA	2881 425159	GRIGORIY MOISEEV	{"phone": "+70112390411"}
0005435423985	2C880B	6852 579051	KONSTANTIN SOROKIN	{"phone": "+70152650999"}
0005435423986	807FAA	1484 816443	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d03121962@postgrespro.ru", "phone": "+70511556507"}
0005435423987	919ED1	4300 481310	VASILIY VLASOV	{"email": "vvlasov_1987@postgrespro.ru", "phone": "+70680788036"}
0005435423988	919ED1	7320 019237	DARYA POPOVA	{"phone": "+70594035227"}
0005435423989	665B57	7300 299338	VYACHESLAV MOISEEV	{"email": "v.moiseev-21051974@postgrespro.ru", "phone": "+70224412146"}
0005435423990	8394EB	9759 022044	DENIS VOLKOV	{"email": "volkov.denis-1961@postgrespro.ru", "phone": "+70106990978"}
0005435423991	8394EB	7449 988682	ANTONINA GERASIMOVA	{"phone": "+70254379688"}
0005435423992	495E8E	0940 818172	ANASTASIYA LOGINOVA	{"phone": "+70099829955"}
0005435423993	DE388E	6782 561074	OLGA TIKHONOVA	{"email": "olga_tikhonova-021971@postgrespro.ru", "phone": "+70569882820"}
0005435423994	DE388E	6137 481340	IRINA ABRAMOVA	{"email": "abramova-i-091980@postgrespro.ru", "phone": "+70646900537"}
0005435423995	346FA4	6515 542053	LYUDMILA STEPANOVA	{"email": "stepanovalyudmila.101974@postgrespro.ru", "phone": "+70861396550"}
0005435423996	B9231E	0930 790009	ANATOLIY OSIPOV	{"phone": "+70170461157"}
0005435423997	1E5F51	8707 929748	EKATERINA OVCHINNIKOVA	{"email": "ekaterina-ovchinnikova-051956@postgrespro.ru", "phone": "+70478854657"}
0005435423998	18B636	1020 387090	SERGEY TIKHONOV	{"phone": "+70540401768"}
0005435423999	18B636	7401 118164	MARIYA KOROLEVA	{"email": "koroleva.mariya-091973@postgrespro.ru", "phone": "+70014783453"}
0005435424000	DF93A4	0707 785959	IRINA MOISEEVA	{"email": "i.moiseeva031977@postgrespro.ru", "phone": "+70444218588"}
0005435424001	BF5C15	8235 763560	NINA KOMAROVA	{"phone": "+70174334644"}
0005435424002	4FF079	2443 704343	ALEKSEY MIKHAYLOV	{"email": "mikhaylova.121976@postgrespro.ru", "phone": "+70491286540"}
0005435424003	4FF079	1738 534911	GALINA PETROVA	{"phone": "+70476265333"}
0005435424004	4FF079	2405 351177	NATALYA YAKOVLEVA	{"email": "n-yakovleva-121976@postgrespro.ru", "phone": "+70754039006"}
0005435424005	8970BB	1707 784543	VASILIY ALEKSEEV	{"email": "v.alekseev-08021968@postgrespro.ru", "phone": "+70887063236"}
0005435424006	530BFF	6387 906379	ELENA ZHURAVLEVA	{"phone": "+70666569803"}
0005435424007	530BFF	5060 759979	KONSTANTIN KISELEV	{"phone": "+70865292531"}
0005435424008	A341BE	9025 526644	SVETLANA EFREMOVA	{"email": "s-efremova-15121977@postgrespro.ru", "phone": "+70384090729"}
0005435424009	48EFA5	8870 738462	ANASTASIYA MOROZOVA	{"phone": "+70520087605"}
0005435424010	48EFA5	4977 700756	GENNADIY GORBUNOV	{"phone": "+70277165289"}
0005435424011	54C53D	2885 392539	IVAN NIKITIN	{"email": "i.nikitin.041962@postgrespro.ru", "phone": "+70657345405"}
0005435424012	54C53D	3890 711648	VALERIYA NAUMOVA	{"email": "naumova_valeriya061979@postgrespro.ru", "phone": "+70075357979"}
0005435424013	EFA8E6	8237 672228	ALEKSEY BARANOV	{"phone": "+70383377534"}
0005435424014	CE0898	5910 917558	DMITRIY FOMIN	{"phone": "+70718432714"}
0005435424015	CE0898	9718 381123	ARTEM EGOROV	{"phone": "+70697131973"}
0005435424016	76C3E9	2093 337230	VALENTINA BELOVA	{"email": "v_belova.1985@postgrespro.ru", "phone": "+70605643701"}
0005435424017	8662B1	1493 190526	YANA ERMAKOVA	{"email": "yana_ermakova-1978@postgrespro.ru", "phone": "+70485978525"}
0005435424018	8A27F7	3560 559440	TATYANA TITOVA	{"email": "ttitova_031976@postgrespro.ru", "phone": "+70871650165"}
0005435424019	5F0643	9474 532003	SVETLANA SMIRNOVA	{"phone": "+70688395031"}
0005435424020	5F0643	6451 593385	STANISLAV GRIGOREV	{"phone": "+70285152678"}
0005435424021	5F0643	8826 690498	AMIR TIMOFEEV	{"email": "timofeev_amir1965@postgrespro.ru", "phone": "+70312330444"}
0005435424022	0D5D56	9228 503229	IRINA EGOROVA	{"phone": "+70263825694"}
0005435424023	0D5D56	8324 756940	ELENA NIKOLAEVA	{"phone": "+70725450700"}
0005435424024	B4AECE	4204 119480	ALEKSANDR DAVYDOV	{"phone": "+70479518534"}
0005435424025	49F6CB	0718 557212	ARTEM SERGEEV	{"email": "sergeev_artem.011975@postgrespro.ru", "phone": "+70891642089"}
0005435424026	49F6CB	0134 449043	ELENA POPOVA	{"email": "e.popova.1961@postgrespro.ru", "phone": "+70934654889"}
0005435424027	FD21D5	6278 979969	IRINA DMITRIEVA	{"phone": "+70905657904"}
0005435424028	FD21D5	0981 775855	VLADIMIR GRIGOREV	{"phone": "+70477980844"}
0005435424029	A6D543	2360 124435	LYUDMILA KRASNOVA	{"phone": "+70088735664"}
0005435424030	1E077A	3520 394798	ALEKSANDR DAVYDOV	{"phone": "+70275498309"}
0005435424031	1E077A	5854 033503	VLADIMIR PAVLOV	{"phone": "+70318833601"}
0005435424032	990EEB	6368 619550	MIKHAIL SEMENOV	{"phone": "+70385449074"}
0005435424033	6F544E	5497 857309	YULIYA IVANOVA	{"phone": "+70506488196"}
0005435424034	2E3E4A	0781 770422	OLGA LAZAREVA	{"email": "lazareva-olga.011967@postgrespro.ru", "phone": "+70181710135"}
0005435424035	2E3E4A	8656 025651	VLADIMIR SOKOLOV	{"phone": "+70028780010"}
0005435424036	7EBA09	7564 844973	LYUDMILA PETROVA	{"email": "petrova.l_071975@postgrespro.ru", "phone": "+70659333727"}
0005435424037	FA6D5E	9017 185760	LIDIYA NIKIFOROVA	{"email": "nikiforova_l-24041982@postgrespro.ru", "phone": "+70161866067"}
0005435424038	15E26E	9146 482251	LIDIYA ERMAKOVA	{"phone": "+70352288036"}
0005435424039	15E26E	4815 420233	VYACHESLAV ILIN	{"email": "vyacheslavilin_121963@postgrespro.ru", "phone": "+70233453287"}
0005435424040	15E26E	8677 795856	LYUDMILA YAKOVLEVA	{"email": "lyudmilayakovleva_051970@postgrespro.ru", "phone": "+70565710768"}
0005435424041	91902A	7976 928691	GALINA ILINA	{"email": "g.ilina.1971@postgrespro.ru", "phone": "+70448782187"}
0005435424042	91902A	4618 504478	LYUBOV MAKAROVA	{"email": "lyubov.makarova_041972@postgrespro.ru", "phone": "+70639176903"}
0005435424043	B6228B	5483 629360	SVETLANA STEPANOVA	{"phone": "+70831631580"}
0005435424045	BD7B16	3340 063288	NIKITA FEDOTOV	{"phone": "+70828582382"}
0005435424047	F7B095	6512 360505	ALEKSANDR PAVLOV	{"email": "pavlov.aleksandr-051969@postgrespro.ru", "phone": "+70786878474"}
0005435424048	F61278	4252 531442	VLADIMIR IVANOV	{"email": "v-ivanov.06091966@postgrespro.ru", "phone": "+70361085899"}
0005435424049	F61278	8286 857037	SVETLANA LUKYANOVA	{"email": "lukyanova_s_16011972@postgrespro.ru", "phone": "+70204872133"}
0005435424050	F61278	0952 437205	NATALYA GUSEVA	{"email": "n.guseva-29061978@postgrespro.ru", "phone": "+70579328879"}
0005435424051	19682C	9836 141368	TATYANA ZAKHAROVA	{"phone": "+70168280154"}
0005435424052	EF3552	1685 016966	NADEZHDA LAZAREVA	{"email": "n.lazareva_23121976@postgrespro.ru", "phone": "+70971285553"}
0005435424053	EF3552	2568 158029	VYACHESLAV VOROBEV	{"phone": "+70857895193"}
0005435424054	EF3552	6742 417738	LEONID MELNIKOV	{"phone": "+70125947983"}
0005435424055	55C044	2646 032304	SOFYA SOKOLOVA	{"email": "s_sokolova_05011966@postgrespro.ru", "phone": "+70009450051"}
0005435424056	83FF4A	3108 575861	VYACHESLAV AFANASEV	{"email": "v.afanasev.1961@postgrespro.ru", "phone": "+70119040089"}
0005435424057	83FF4A	2743 593509	NATALYA SOLOVEVA	{"phone": "+70140328062"}
0005435424058	E24B74	1828 852691	ALEKSEY PETROV	{"phone": "+70634741041"}
0005435424059	E24B74	0121 534043	VALERIYA MALYSHEVA	{"email": "valeriya-malysheva021970@postgrespro.ru", "phone": "+70415668580"}
0005435424060	816417	3962 668122	ZINAIDA MASLOVA	{"phone": "+70152171210"}
0005435424061	F8AEB8	3153 123892	NINA TIMOFEEVA	{"email": "timofeeva.nina_1982@postgrespro.ru", "phone": "+70965427851"}
0005435424062	72AF32	2995 730266	PAVEL ZAKHAROV	{"email": "p_zakharov-081962@postgrespro.ru", "phone": "+70231651565"}
0005435424063	72AF32	0234 318014	SERGEY CHERNOV	{"email": "chernov.s_091975@postgrespro.ru", "phone": "+70007861756"}
0005435424064	715BEF	9857 753627	PAVEL ZAKHAROV	{"phone": "+70455141440"}
0005435424065	7BEDFE	8857 530831	OLGA PAVLOVA	{"email": "olgapavlova05091965@postgrespro.ru", "phone": "+70673049355"}
0005435424066	0B34CF	5294 269946	VASILIY IVANOV	{"email": "ivanov-vasiliy011968@postgrespro.ru", "phone": "+70657858927"}
0005435424067	F4F2B9	8118 333461	ALEKSANDR SOROKIN	{"email": "a_sorokin.1978@postgrespro.ru", "phone": "+70446344909"}
0005435424068	322AA6	0274 805007	PETR SEMENOV	{"phone": "+70736795705"}
0005435424069	04B674	2635 802613	FANIYA NIKOLAEVA	{"email": "faniya_nikolaeva.1960@postgrespro.ru", "phone": "+70165216580"}
0005435424070	0A9380	7007 079119	NATALYA SIDOROVA	{"phone": "+70327614613"}
0005435424071	5DC2BC	0869 904175	ANASTASIYA PAVLOVA	{"phone": "+70697756125"}
0005435424072	5DC2BC	8428 919676	ZINAIDA VASILEVA	{"phone": "+70647632711"}
0005435424073	2846AD	6211 698279	VALENTINA PAVLOVA	{"phone": "+70990485063"}
0005435424074	E72137	0180 054600	SOFYA POTAPOVA	{"email": "sofyapotapova1967@postgrespro.ru", "phone": "+70261791238"}
0005435424075	E72137	5159 093098	TATYANA YAKOVLEVA	{"phone": "+70048408313"}
0005435424076	E72137	5470 118677	VYACHESLAV BELOV	{"email": "vyacheslav-belov.1976@postgrespro.ru", "phone": "+70007815157"}
0005435424077	D83780	3626 232895	KRISTINA GAVRILOVA	{"email": "k-gavrilova_031963@postgrespro.ru", "phone": "+70396578534"}
0005435424078	AB73FE	4045 536655	NINA NIKITINA	{"email": "ninanikitina_1975@postgrespro.ru", "phone": "+70395082128"}
0005435424079	E916F1	1339 637007	ALEKSANDR CHERNOV	{"phone": "+70273576083"}
0005435424080	7E4332	9006 843067	SVETLANA ANDREEVA	{"phone": "+70563766942"}
0005435424081	D54344	5433 031501	TATYANA VOLKOVA	{"phone": "+70951961858"}
0005435424082	D54344	9093 411704	MIKHAIL NOVIKOV	{"email": "m-novikov.061956@postgrespro.ru", "phone": "+70277299238"}
0005435424083	582C29	4330 978366	VADIM FOMIN	{"email": "vfomin-13041976@postgrespro.ru", "phone": "+70637086008"}
0005435424084	582C29	4408 012981	PETR MOROZOV	{"email": "petr-morozov071974@postgrespro.ru", "phone": "+70104329679"}
0005435424085	EEF029	3346 267973	VLADIMIR FROLOV	{"email": "frolov-v.041971@postgrespro.ru", "phone": "+70834022322"}
0005435424086	943E49	4621 265508	NIKOLAY KUZNECOV	{"phone": "+70704517359"}
0005435424087	3D9388	4182 176309	ANASTASIYA TITOVA	{"phone": "+70842399192"}
0005435424088	B1C93A	3868 717469	RUSLAN BONDARENKO	{"email": "r_bondarenko.1967@postgrespro.ru", "phone": "+70223944507"}
0005435424089	90C796	8790 951120	MARIYA FEDOROVA	{"email": "mariyafedorova-20091973@postgrespro.ru", "phone": "+70733349421"}
0005435424090	CAFE46	6204 677337	NINA KARPOVA	{"email": "nina.karpova011970@postgrespro.ru", "phone": "+70297016632"}
0005435424091	9FE371	0335 037442	ALEKSANDR MOROZOV	{"email": "a.morozov-041975@postgrespro.ru", "phone": "+70156558071"}
0005435424092	9FE371	4190 204496	ANNA KUZMINA	{"phone": "+70588315729"}
0005435424093	9FE371	1867 676262	VLADISLAV SCHERBAKOV	{"email": "scherbakov_vladislav22051978@postgrespro.ru", "phone": "+70150819928"}
0005435424094	B9EAED	5747 404069	KARINA KALININA	{"email": "karinakalinina031975@postgrespro.ru", "phone": "+70684086402"}
0005435424095	7635AE	3842 575191	ELENA ANTONOVA	{"email": "e-antonova_30061976@postgrespro.ru", "phone": "+70749234723"}
0005435424096	7635AE	5318 703740	LYUDMILA KOVALEVA	{"email": "kovaleva.lyudmila-061974@postgrespro.ru", "phone": "+70711200257"}
0005435424097	B14D01	6999 345662	ANASTASIYA VOLKOVA	{"email": "volkova_anastasiya-1978@postgrespro.ru", "phone": "+70961586620"}
0005435424098	B14D01	3051 744960	VALENTINA NESTEROVA	{"phone": "+70214463532"}
0005435424099	67177F	9715 663691	ALEKSANDRA POLYAKOVA	{"email": "a_polyakova_23031975@postgrespro.ru", "phone": "+70206269323"}
0005435424100	A4B141	2869 682840	VASILIY NOVIKOV	{"email": "novikov.v-17091974@postgrespro.ru", "phone": "+70493491044"}
0005435424101	A4B141	0244 278153	ANATOLIY POPOV	{"email": "popov-a.101960@postgrespro.ru", "phone": "+70420147455"}
0005435424102	CC9D3C	4140 358848	EKATERINA DAVYDOVA	{"phone": "+70269041077"}
0005435424103	75A554	8113 855659	MAKSIM VASILEV	{"phone": "+70167736316"}
0005435424104	87FD80	3299 089734	VALENTINA SIDOROVA	{"phone": "+70463176582"}
0005435424105	3A8759	6806 670681	VITALIY KOZLOV	{"email": "kozlov_vitaliy.1968@postgrespro.ru", "phone": "+70255016041"}
0005435424106	3A8759	1578 369658	MARINA ROMANOVA	{"email": "m-romanova.16081966@postgrespro.ru", "phone": "+70058808244"}
0005435424107	E46F5E	0924 474967	VLADIMIR IVANOV	{"phone": "+70255969854"}
0005435424108	E46F5E	8999 221449	LIDIYA VOROBEVA	{"phone": "+70913685244"}
0005435424109	5126A1	1934 786399	VLADIMIR STEPANOV	{"phone": "+70780010030"}
0005435424110	D5B1F9	3548 908662	DANIIL SEMENOV	{"phone": "+70813589710"}
0005435424111	B40089	7620 614470	SVETLANA KOLESNIKOVA	{"phone": "+70344128322"}
0005435424112	B40089	9716 583508	VIKTOR NAZAROV	{"phone": "+70560446213"}
0005435424113	D12FD3	1475 795453	DMITRIY ABRAMOV	{"email": "d-abramov.17091973@postgrespro.ru", "phone": "+70586326164"}
0005435424114	14329B	3743 579087	BORIS MAKAROV	{"phone": "+70128767821"}
0005435424115	07EBEE	0619 060057	VERA NOVIKOVA	{"email": "novikova-vera.1977@postgrespro.ru", "phone": "+70369880885"}
0005435424116	F8214A	8151 484029	ELENA OSIPOVA	{"email": "elena.osipova-01101966@postgrespro.ru", "phone": "+70610150593"}
0005435424117	F8214A	7499 430709	MIKHAIL SEMENOV	{"email": "semenov.m031977@postgrespro.ru", "phone": "+70368181187"}
0005435424118	EF5D68	6831 420632	MARINA STEPANOVA	{"phone": "+70609385968"}
0005435424119	2FFD4A	6076 967900	NATALYA LUKYANOVA	{"phone": "+70222238200"}
0005435424120	5BFE90	5290 899559	VALERIYA ANDREEVA	{"email": "valeriya_andreeva.1974@postgrespro.ru", "phone": "+70374588821"}
0005435424121	AD98C9	7277 162778	EVGENIY KUZNECOV	{"email": "kuznecov-e-051976@postgrespro.ru", "phone": "+70025882269"}
0005435424122	AD98C9	9773 593581	ALEKSANDRA NAZAROVA	{"email": "nazarova_aleksandra_1973@postgrespro.ru", "phone": "+70084592404"}
0005435424123	972B0A	3585 616199	EVGENIY ANDREEV	{"email": "e_andreev_1952@postgrespro.ru", "phone": "+70473280698"}
0005435424124	972B0A	1106 833680	ELENA SERGEEVA	{"email": "sergeevae_1977@postgrespro.ru", "phone": "+70850189203"}
0005435424125	134593	4502 861944	VALERIY BONDARENKO	{"phone": "+70508594026"}
0005435424126	B79B5F	7154 277439	LARISA ABRAMOVA	{"phone": "+70949782554"}
0005435424127	B79B5F	9150 676336	YURIY IVANOV	{"email": "y.ivanov_09071960@postgrespro.ru", "phone": "+70541783738"}
0005435424128	A7CC82	2982 729416	ARINA MALYSHEVA	{"phone": "+70394227873"}
0005435424129	A7CC82	2893 746475	ROMAN PAVLOV	{"email": "roman_pavlov_081985@postgrespro.ru", "phone": "+70771172531"}
0005435424130	8D4796	9815 502660	NADEZHDA NIKOLAEVA	{"phone": "+70450220071"}
0005435424131	923FD7	8120 887145	SERGEY FEDOROV	{"phone": "+70075294853"}
0005435424132	923FD7	1347 290191	MARIYA MIKHAYLOVA	{"email": "mariya.mikhaylova.1975@postgrespro.ru", "phone": "+70719247858"}
0005435424133	8D0959	4137 035449	PETR SCHERBAKOV	{"phone": "+70406722166"}
0005435424134	18B8E3	1744 449428	OLGA IVANOVA	{"phone": "+70397797682"}
0005435424135	09A0BE	0067 947835	TATYANA FILIPPOVA	{"phone": "+70901774873"}
0005435424136	C84490	7457 063009	SERGEY MOROZOV	{"phone": "+70953945234"}
0005435424137	519058	0541 490229	VALERIY GRIGOREV	{"email": "grigorev-v.21081977@postgrespro.ru", "phone": "+70327446064"}
0005435424138	5EC418	3713 404728	ELENA NOVIKOVA	{"phone": "+70343020294"}
0005435424139	4F2A56	1261 762952	ALEKSANDR BARANOV	{"email": "abaranov09111970@postgrespro.ru", "phone": "+70754719023"}
0005435424140	42C5FE	9410 930315	VIKTOR ALEKSEEV	{"email": "alekseev_viktor-1979@postgrespro.ru", "phone": "+70148851433"}
0005435424141	488CF0	5742 830799	ANASTASIYA NOVIKOVA	{"phone": "+70454823429"}
0005435424142	488CF0	1628 100676	ELENA IVANOVA	{"phone": "+70257772928"}
0005435424143	D9D1B5	7665 225137	GALINA NESTEROVA	{"phone": "+70020470782"}
0005435424144	B88584	4023 218827	YULIYA POPOVA	{"phone": "+70648365980"}
0005435424145	C6F1EB	8045 961574	ANTON FEDOTOV	{"email": "anton-fedotov12021972@postgrespro.ru", "phone": "+70794214434"}
0005435424146	C6F1EB	0354 521476	SVETLANA NAZAROVA	{"phone": "+70500518347"}
0005435424147	97A0AF	5229 763446	LYUBOV VOROBEVA	{"phone": "+70932077716"}
0005435424148	97A0AF	1845 088549	MAKSIM ZAYCEV	{"phone": "+70314505709"}
0005435424149	CEA885	8058 584606	OLGA SMIRNOVA	{"email": "osmirnova-1975@postgrespro.ru", "phone": "+70543369160"}
0005435424150	797055	7588 275691	ELENA LAZAREVA	{"email": "lazareva_elena.1977@postgrespro.ru", "phone": "+70474825436"}
0005435424151	835282	1233 280004	ARKADIY KOZLOV	{"phone": "+70475829072"}
0005435424152	EDB816	3476 645047	MARIYA KAZAKOVA	{"phone": "+70447108637"}
0005435424153	85B0AC	1536 742212	IRINA ROMANOVA	{"phone": "+70069556824"}
0005435424154	36740E	7464 063143	ALEKSANDR ANDREEV	{"email": "aandreev_25061969@postgrespro.ru", "phone": "+70450042357"}
0005435424155	36740E	0839 233494	ALEKSANDRA POPOVA	{"email": "aleksandra_popova1968@postgrespro.ru", "phone": "+70492209192"}
0005435424156	8AE622	1017 326778	VIKTOR ORLOV	{"email": "orlov-viktor30111967@postgrespro.ru", "phone": "+70589778473"}
0005435424157	C9ECEB	3725 619368	NIKITA MEDVEDEV	{"email": "medvedevn-071976@postgrespro.ru", "phone": "+70537022742"}
0005435424158	FE135D	0141 191687	RUSLAN SOLOVEV	{"email": "solovev_r1983@postgrespro.ru", "phone": "+70086934306"}
0005435424159	FE135D	6631 498904	ALBERT MOISEEV	{"phone": "+70564123458"}
0005435424160	D192A4	5077 270958	VALERIY DMITRIEV	{"phone": "+70233581470"}
0005435424161	D192A4	2102 354779	GENNADIY FILIPPOV	{"phone": "+70357631420"}
0005435424162	2CA2A4	6952 881469	SVETLANA MEDVEDEVA	{"phone": "+70212841407"}
0005435424163	A67F17	0781 815968	ANATOLIY VOLKOV	{"phone": "+70306202794"}
0005435424164	C3AD16	0016 726753	ZINAIDA SOLOVEVA	{"email": "z-soloveva-1977@postgrespro.ru", "phone": "+70515188947"}
0005435424165	C3AD16	2966 288685	STANISLAV KUZNECOV	{"phone": "+70377619270"}
0005435424166	F552BB	7871 668518	IRINA NOVIKOVA	{"email": "irina-novikova_1964@postgrespro.ru", "phone": "+70438353369"}
0005435424167	9B94BE	7908 184025	TATYANA ROMANOVA	{"email": "t-romanova1976@postgrespro.ru", "phone": "+70245654100"}
0005435424168	707B02	9624 000681	ARTEM ZHURAVLEV	{"phone": "+70216690230"}
0005435424169	0739C1	7829 526487	YULIYA DAVYDOVA	{"email": "davydovayuliya_051968@postgrespro.ru", "phone": "+70340582603"}
0005435424170	20615E	9907 522650	NATALYA NAZAROVA	{"phone": "+70935928269"}
0005435424171	20615E	7872 530081	SERGEY DMITRIEV	{"phone": "+70048460914"}
0005435424172	F46F8C	0617 438621	SERGEY EGOROV	{"phone": "+70484742084"}
0005435424173	6E4437	5156 060583	VALERIY DMITRIEV	{"email": "dmitrievv-071982@postgrespro.ru", "phone": "+70322031185"}
0005435424174	6E4437	5003 476093	MARIYA NOVIKOVA	{"email": "novikovamariya031973@postgrespro.ru", "phone": "+70682987357"}
0005435424175	EBBAB4	2821 043170	LARISA DANILOVA	{"email": "ldanilova031970@postgrespro.ru", "phone": "+70337424652"}
0005435424176	EBBAB4	1909 411760	GALINA BARANOVA	{"phone": "+70988621491"}
0005435424177	9BA302	4741 548479	ANGELINA KRASNOVA	{"email": "krasnovaangelina_021971@postgrespro.ru", "phone": "+70213581835"}
0005435424178	9BA302	0793 147810	DMITRIY DENISOV	{"email": "ddenisov-1957@postgrespro.ru", "phone": "+70940775102"}
0005435424179	8D804B	9460 625548	SERGEY DMITRIEV	{"email": "dmitriev_s071968@postgrespro.ru", "phone": "+70182913142"}
0005435424180	AEDA68	6111 404063	ANASTASIYA DMITRIEVA	{"email": "dmitrieva_anastasiya.031971@postgrespro.ru", "phone": "+70334931512"}
0005435424181	B8EBEE	7389 133810	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov-25051973@postgrespro.ru", "phone": "+70181047612"}
0005435424182	AE15E3	3542 358620	MARIYA PAVLOVA	{"phone": "+70749440340"}
0005435424183	AE15E3	1833 624147	LILIYA SIDOROVA	{"email": "liliyasidorova1965@postgrespro.ru", "phone": "+70832098772"}
0005435424184	058954	3818 950830	NIKOLAY KUZNECOV	{"email": "n.kuznecov041976@postgrespro.ru", "phone": "+70660237959"}
0005435424185	53747F	7185 101525	ALENA TARASOVA	{"email": "alena.tarasova-021974@postgrespro.ru", "phone": "+70919881313"}
0005435424186	41255B	7385 878693	VASILIY VOLKOV	{"phone": "+70499395009"}
0005435424187	41255B	1048 010909	ALEKSANDR VOLKOV	{"email": "aleksandr-volkov29011970@postgrespro.ru", "phone": "+70648676112"}
0005435424188	DF4170	6286 746345	NADEZHDA ROMANOVA	{"phone": "+70009247294"}
0005435424189	DF4170	9279 748591	VALENTIN SCHERBAKOV	{"email": "v_scherbakov04021965@postgrespro.ru", "phone": "+70647530785"}
0005435424190	62819D	7803 733975	VADIM KAZAKOV	{"phone": "+70044187249"}
0005435424191	62819D	9891 349106	EKATERINA MAKAROVA	{"phone": "+70284335449"}
0005435424192	A3C05E	1866 882063	VIKTOR GRIGOREV	{"email": "grigorev-v-01091981@postgrespro.ru", "phone": "+70181993443"}
0005435424193	EF0D3B	7564 420156	VALENTINA RODIONOVA	{"phone": "+70538972917"}
0005435424194	EF0D3B	6577 039137	VASILIY MEDVEDEV	{"phone": "+70810932786"}
0005435424195	A70814	3916 796011	NATALYA IVANOVA	{"phone": "+70911902811"}
0005435424196	53F083	9683 901663	VLADIMIR NOVIKOV	{"email": "v.novikov.06101981@postgrespro.ru", "phone": "+70715001344"}
0005435424197	7591D1	8243 508495	MARINA LOGINOVA	{"email": "loginova.marina-04071971@postgrespro.ru", "phone": "+70514953890"}
0005435424198	2BD919	1745 354588	DENIS ANDREEV	{"phone": "+70396376390"}
0005435424199	2BD919	2328 222320	SVETLANA MOROZOVA	{"phone": "+70392257319"}
0005435424200	3E11D2	6675 111650	SERGEY GERASIMOV	{"phone": "+70361554213"}
0005435424201	3E11D2	3008 024476	MARIYA STEPANOVA	{"phone": "+70849782680"}
0005435424202	220ECA	3855 708529	SERGEY KOROLEV	{"phone": "+70472195585"}
0005435424203	25B84C	3622 550754	VLADIMIR GERASIMOV	{"phone": "+70881224099"}
0005435424204	25B84C	9845 601486	VLADIMIR KUDRYASHOV	{"phone": "+70306001445"}
0005435424205	1D46D7	1103 618128	ZHANNA MAKAROVA	{"email": "zhanna-makarova051961@postgrespro.ru", "phone": "+70235313042"}
0005435424206	1D46D7	0901 485938	ANTON BORISOV	{"email": "anton-borisov1972@postgrespro.ru", "phone": "+70848007386"}
0005435424207	A48B3B	9851 458472	OLGA FILIPPOVA	{"phone": "+70340810310"}
0005435424208	F8F90F	3561 543763	NATALYA SOLOVEVA	{"phone": "+70926186962"}
0005435424209	F8F90F	2887 052851	KIRILL GERASIMOV	{"email": "kirillgerasimov11031969@postgrespro.ru", "phone": "+70662841301"}
0005435424210	64E11B	1694 569248	SVETLANA KOROLEVA	{"email": "koroleva.s.22071976@postgrespro.ru", "phone": "+70321256635"}
0005435424211	71EF4C	5869 628393	ALEKSANDRA BELOVA	{"email": "a_belova_041970@postgrespro.ru", "phone": "+70565546389"}
0005435424212	D662F7	1686 395303	OLGA SOKOLOVA	{"email": "sokolova-olga-13051972@postgrespro.ru", "phone": "+70340289872"}
0005435424213	FDD1DC	5435 027825	ROBERT KOROLEV	{"email": "rkorolev.09101964@postgrespro.ru", "phone": "+70075559628"}
0005435424214	B3540A	0115 682153	ANTON FEDOTOV	{"email": "antonfedotov_011969@postgrespro.ru", "phone": "+70142025349"}
0005435424215	B6D665	3300 552552	VLADIMIR KRASNOV	{"email": "krasnov-v.1962@postgrespro.ru", "phone": "+70472903060"}
0005435424216	57F9CB	9610 557506	ALEKSANDR SEMENOV	{"email": "semenov-aleksandr.11061977@postgrespro.ru", "phone": "+70540961706"}
0005435424217	6B3D54	9648 147600	EVGENIY BONDARENKO	{"email": "bondarenko-e.1984@postgrespro.ru", "phone": "+70891693120"}
0005435424218	6B3D54	4978 451140	ANFISA OVCHINNIKOVA	{"email": "anfisa_ovchinnikova13071968@postgrespro.ru", "phone": "+70162768688"}
0005435424219	2669D2	0009 364861	ANNA EGOROVA	{"email": "aegorova.28011976@postgrespro.ru", "phone": "+70394264136"}
0005435424220	2669D2	3389 876954	MARIYA ARKHIPOVA	{"phone": "+70377681837"}
0005435424221	53F2B2	4272 854688	VASILIY VLASOV	{"phone": "+70572455382"}
0005435424222	59DE38	4360 694509	ALEKSANDRA NOVIKOVA	{"phone": "+70779590143"}
0005435424223	C567F7	9461 836637	VASILIY OSIPOV	{"email": "vasiliy-osipov22081967@postgrespro.ru", "phone": "+70784916287"}
0005435424224	031726	2174 876556	EMIL DENISOV	{"email": "denisov-e24071977@postgrespro.ru", "phone": "+70916391548"}
0005435424225	0C61AE	3552 424443	VYACHESLAV SIDOROV	{"phone": "+70082412667"}
0005435424226	CA5035	1193 581145	ALEKSEY RODIONOV	{"email": "a_rodionov.1966@postgrespro.ru", "phone": "+70143835504"}
0005435424227	E056AE	6938 439897	SERGEY IVANOV	{"email": "ivanovs-26121972@postgrespro.ru", "phone": "+70847312729"}
0005435424228	78071E	3508 304952	VALERIY SEMENOV	{"phone": "+70005024014"}
0005435424229	576874	3279 186554	OLGA MIRONOVA	{"phone": "+70223868852"}
0005435424230	6A9BBD	0726 554856	RAISA KOROLEVA	{"phone": "+70661468639"}
0005435424231	8D200C	4839 576604	YURIY MATVEEV	{"email": "yuriymatveev.12021975@postgrespro.ru", "phone": "+70318207421"}
0005435424232	8D200C	3234 282384	ALEKSANDR ZHURAVLEV	{"email": "a.zhuravlev-091983@postgrespro.ru", "phone": "+70920579001"}
0005435424233	E70233	5344 175613	IGOR ALEKSANDROV	{"phone": "+70271462503"}
0005435424234	972852	2834 263433	ANTON AFANASEV	{"phone": "+70930918183"}
0005435424235	29EA04	3503 377877	VLADIMIR VOLKOV	{"email": "v-volkov.07081985@postgrespro.ru", "phone": "+70343093492"}
0005435424236	1E178D	5554 923031	EKATERINA GUSEVA	{"phone": "+70692954096"}
0005435424237	1E178D	4829 866923	ZLATA MOISEEVA	{"phone": "+70237506982"}
0005435424238	708190	5771 470526	ANDREY MIKHAYLOV	{"email": "mikhaylov.andrey.021973@postgrespro.ru", "phone": "+70490180263"}
0005435424239	D71C8E	1027 098113	MARIYA PETROVA	{"phone": "+70592270264"}
0005435424240	D71C8E	4127 378665	VLADIMIR SAVELEV	{"email": "v-savelev.111971@postgrespro.ru", "phone": "+70539998645"}
0005435424241	F416F9	6707 368965	VLADIMIR MOROZOV	{"email": "morozov.v091958@postgrespro.ru", "phone": "+70007875732"}
0005435424242	F416F9	7744 007470	OLGA VOLKOVA	{"phone": "+70593763043"}
0005435424243	578554	0179 918300	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr091977@postgrespro.ru", "phone": "+70980367686"}
0005435424244	CC4F37	6037 724031	LYUDMILA NOVIKOVA	{"phone": "+70323921517"}
0005435424245	52EA1D	3394 998599	PETR ILIN	{"email": "ilinp.091970@postgrespro.ru", "phone": "+70364834982"}
0005435424246	52EA1D	0085 374891	SERGEY SCHERBAKOV	{"email": "scherbakov-sergey15021962@postgrespro.ru", "phone": "+70117678050"}
0005435424247	F045EE	2499 410278	EVGENIY SEMENOV	{"phone": "+70079194349"}
0005435424248	3F24F8	9690 619173	MATVEY MAKSIMOV	{"phone": "+70792889441"}
0005435424249	737D95	8999 236116	EVGENIYA STEPANOVA	{"email": "stepanova.evgeniya-011980@postgrespro.ru", "phone": "+70818959721"}
0005435424250	EC1023	2322 107740	LARISA BOGDANOVA	{"phone": "+70801292927"}
0005435424251	C31019	1343 387496	DMITRIY RODIONOV	{"phone": "+70274925781"}
0005435424252	C31019	4145 808081	ALEKSEY DENISOV	{"phone": "+70412125438"}
0005435424253	C31019	4810 423464	ELENA KOROLEVA	{"email": "e_koroleva.17041979@postgrespro.ru", "phone": "+70197356892"}
0005435424254	018A71	8174 314717	NATALIYA NOVIKOVA	{"email": "n_novikova-30111976@postgrespro.ru", "phone": "+70739548579"}
0005435424255	95B520	7954 491203	VALERIY SCHERBAKOV	{"email": "scherbakov_valeriy_011973@postgrespro.ru", "phone": "+70015729623"}
0005435424256	95B520	7723 352339	SVETLANA YAKOVLEVA	{"email": "yakovleva_s041962@postgrespro.ru", "phone": "+70623452083"}
0005435424257	7E5831	0641 948276	EVGENIY YAKOVLEV	{"email": "yakovlevevgeniy_12041967@postgrespro.ru", "phone": "+70045215774"}
0005435424258	7E5831	9771 881237	SERGEY FROLOV	{"phone": "+70104711266"}
0005435424259	6099B2	5195 819915	VLADIMIR PETROV	{"phone": "+70267113695"}
0005435424260	ADA234	8361 501880	GENNADIY FROLOV	{"phone": "+70611919415"}
0005435424261	ADA234	0796 874723	IVAN SAVELEV	{"email": "savelevivan.021981@postgrespro.ru", "phone": "+70053858359"}
0005435424262	F3EDD8	7620 356754	PAVEL NIKOLAEV	{"email": "pavel-nikolaev.121961@postgrespro.ru", "phone": "+70530396986"}
0005435424263	1646AD	8016 844207	VLADIMIR ANTONOV	{"phone": "+70768156732"}
0005435424264	C39F3E	3404 797449	SVETLANA BELOVA	{"email": "belova-svetlana_18041970@postgrespro.ru", "phone": "+70127550080"}
0005435424265	8E14C8	7377 903532	POLINA IVANOVA	{"email": "ivanova.polina_1963@postgrespro.ru", "phone": "+70487103232"}
0005435424266	C3B35A	4476 582978	STANISLAV STEPANOV	{"email": "stanislavstepanov_101972@postgrespro.ru", "phone": "+70544350845"}
0005435424267	C3B35A	9996 496215	RUSLAN GORBUNOV	{"phone": "+70756025718"}
0005435424268	C3B35A	8157 084119	NATALYA ORLOVA	{"email": "orlova.n-17101955@postgrespro.ru", "phone": "+70293559700"}
0005435424269	B36706	3202 653839	VLADIMIR MATVEEV	{"email": "vmatveev-07031978@postgrespro.ru", "phone": "+70864331227"}
0005435424270	DE2DDC	8753 569386	ALEVTINA RODIONOVA	{"email": "rodionovaa-1971@postgrespro.ru", "phone": "+70685334680"}
0005435424271	50F14F	8964 914182	GALINA DAVYDOVA	{"email": "g-davydova05041974@postgrespro.ru", "phone": "+70762498984"}
0005435424272	596396	6157 719915	RUSTAM ALEKSANDROV	{"email": "aleksandrovrustam.1970@postgrespro.ru", "phone": "+70847367856"}
0005435424273	681071	4183 981384	PAVEL ISAEV	{"phone": "+70080515570"}
0005435424274	1E1578	0930 646523	ALEKSANDR SOLOVEV	{"phone": "+70565751421"}
0005435424275	CD4E94	5330 718713	ALINA AFANASEVA	{"phone": "+70944259462"}
0005435424276	E841B1	3857 803571	VITALIY OSIPOV	{"email": "vitaliy-osipov1969@postgrespro.ru", "phone": "+70836479662"}
0005435424277	E841B1	2445 519726	IGOR ZHUKOV	{"phone": "+70194500929"}
0005435424278	F8339E	3435 840923	ELIZAVETA POTAPOVA	{"email": "e.potapova.071962@postgrespro.ru", "phone": "+70439550732"}
0005435424279	065CEF	4536 635065	ANASTASIYA LUKYANOVA	{"email": "anastasiya_lukyanova.1972@postgrespro.ru", "phone": "+70523384833"}
0005435424280	3E81B8	6968 466856	GENNADIY VASILEV	{"phone": "+70675630359"}
0005435424281	727491	2523 781753	LIDIYA IVANOVA	{"phone": "+70534425002"}
0005435424282	727491	8229 772990	OLGA KUZNECOVA	{"email": "kuznecova.olga-031968@postgrespro.ru", "phone": "+70727528465"}
0005435424283	7A65FC	2960 687061	SHAMIL GRIGOREV	{"phone": "+70219506767"}
0005435424284	8A8663	3109 751121	EVGENIY KUDRYASHOV	{"email": "evgeniy.kudryashov_011977@postgrespro.ru", "phone": "+70569438751"}
0005435424285	9CD12E	3082 882082	ANGELINA DENISOVA	{"phone": "+70224055562"}
0005435424286	22E9A3	0056 371704	OLGA KOZLOVA	{"phone": "+70651331572"}
0005435424287	E82C8C	6508 402442	IVAN ROMANOV	{"email": "romanov_i.101972@postgrespro.ru", "phone": "+70159642579"}
0005435424288	028455	3299 510885	YURIY SOKOLOV	{"email": "sokolov_yuriy27021981@postgrespro.ru", "phone": "+70728620573"}
0005435424289	F254B0	1527 068555	VIKTOR FOMIN	{"phone": "+70416707806"}
0005435424290	F254B0	7653 973168	MAKSIM PAVLOV	{"email": "m.pavlov-01051975@postgrespro.ru", "phone": "+70344041792"}
0005435424291	8A8E67	9659 095621	PETR SAVELEV	{"email": "petr_savelev.1971@postgrespro.ru", "phone": "+70259791058"}
0005435424292	17B981	7875 330503	SERGEY TARASOV	{"email": "tarasov.sergey.25091965@postgrespro.ru", "phone": "+70561790928"}
0005435424293	8EE291	8109 389892	NATALYA EGOROVA	{"email": "egorovanatalya.091966@postgrespro.ru", "phone": "+70420399034"}
0005435424294	940245	7143 047728	ALEKSANDR ALEKSEEV	{"email": "alekseeva1983@postgrespro.ru", "phone": "+70265474710"}
0005435424295	940245	6853 743580	NIKOLAY MAKSIMOV	{"phone": "+70604548058"}
0005435424296	940245	6053 458953	DIANA NOVIKOVA	{"phone": "+70929581272"}
0005435424297	1D88AB	7580 117575	NELLI NIKIFOROVA	{"email": "nikiforova_nelli-1964@postgrespro.ru", "phone": "+70984974509"}
0005435424298	0B9944	8499 008445	TATYANA FILIPPOVA	{"email": "tatyana-filippova-1959@postgrespro.ru", "phone": "+70782231909"}
0005435424299	3724CF	7593 362314	VLADIMIR KONOVALOV	{"email": "vladimir.konovalov_1973@postgrespro.ru", "phone": "+70607311229"}
0005435424300	3724CF	1739 742068	KSENIYA KOLESNIKOVA	{"phone": "+70430276765"}
0005435424301	3724CF	2327 072005	VIKTOR CHERNOV	{"email": "chernovv041972@postgrespro.ru", "phone": "+70810616446"}
0005435424302	290103	8599 661801	VERONIKA EGOROVA	{"email": "egorova-v_1962@postgrespro.ru", "phone": "+70485172012"}
0005435424303	290103	6530 021028	TATYANA NIKOLAEVA	{"email": "nikolaevatatyana-121980@postgrespro.ru", "phone": "+70999463038"}
0005435424304	9CBB7C	4915 230635	DMITRIY IVANOV	{"email": "ivanov_dmitriy031977@postgrespro.ru", "phone": "+70371021147"}
0005435424305	9CBB7C	6933 755344	LILIYA SMIRNOVA	{"phone": "+70101166605"}
0005435424306	760CEC	0639 509399	NATALYA BOGDANOVA	{"email": "n-bogdanova_1973@postgrespro.ru", "phone": "+70970938504"}
0005435424307	2662DE	0269 806997	LARISA PETROVA	{"email": "larisapetrova_121973@postgrespro.ru", "phone": "+70055133756"}
0005435424308	229C3D	8487 556353	NIKOLAY FILIPPOV	{"phone": "+70847443016"}
0005435424309	8524B8	0468 888229	OLGA KUZNECOVA	{"email": "o.kuznecova-16111972@postgrespro.ru", "phone": "+70595415939"}
0005435424310	4EF9CC	4658 109739	VIKTORIYA KOZLOVA	{"email": "v_kozlova_091975@postgrespro.ru", "phone": "+70779624107"}
0005435424311	4EF9CC	7861 843049	NIKOLAY POPOV	{"phone": "+70067212534"}
0005435424312	E27E08	3087 170643	YURIY TIMOFEEV	{"email": "timofeev.yuriy02051972@postgrespro.ru", "phone": "+70767449998"}
0005435424313	4F5796	2923 222278	YAROSLAV AFANASEV	{"email": "yaroslav_afanasev051974@postgrespro.ru", "phone": "+70509659320"}
0005435424314	C98859	7034 421993	SVETLANA ALEKSEEVA	{"email": "alekseeva-svetlana-1975@postgrespro.ru", "phone": "+70486738962"}
0005435424315	C98859	8307 694758	OKSANA VASILEVA	{"email": "oksana.vasileva-09041975@postgrespro.ru", "phone": "+70407361510"}
0005435424316	13D08B	4397 709643	SVETLANA ANDREEVA	{"email": "andreeva.svetlana_1972@postgrespro.ru", "phone": "+70001849155"}
0005435424317	A88CA8	7243 499504	VLADIMIR IVANOV	{"phone": "+70661426758"}
0005435424318	1D2137	1966 160978	EVGENIY MEDVEDEV	{"phone": "+70769282639"}
0005435424319	1D2137	8500 503629	ANATOLIY PETROV	{"phone": "+70424313948"}
0005435424320	673C65	9481 241670	NIKOLAY PAVLOV	{"email": "nikolay-pavlov.07071975@postgrespro.ru", "phone": "+70513295769"}
0005435424321	673C65	5454 836712	ALEKSANDRA KONOVALOVA	{"phone": "+70012220959"}
0005435424322	468252	8295 360816	ALEKSANDRA ANDREEVA	{"email": "andreevaa_1979@postgrespro.ru", "phone": "+70831292529"}
0005435424323	B0B1F2	4049 963111	ELENA NESTEROVA	{"email": "nesterova_e-26061967@postgrespro.ru", "phone": "+70419105152"}
0005435424324	41DA4E	6454 189220	NATALIYA ROMANOVA	{"phone": "+70822754816"}
0005435424325	41DA4E	4685 624590	IVAN MOISEEV	{"phone": "+70716116987"}
0005435424326	06064E	1520 047699	NATALYA KONOVALOVA	{"phone": "+70134745664"}
0005435424327	30EBF3	7564 180387	ALEKSANDR CHERNOV	{"email": "chernov_aleksandr091967@postgrespro.ru", "phone": "+70538111562"}
0005435424328	1C7ECA	1416 967771	VLADIMIR IVANOV	{"phone": "+70922544054"}
0005435424329	7F7126	5304 069477	ELENA VOLKOVA	{"email": "evolkova08041982@postgrespro.ru", "phone": "+70886975938"}
0005435424330	07CDE7	9673 129325	VYACHESLAV KAZAKOV	{"phone": "+70342663984"}
0005435424331	07CDE7	8806 084232	NATALYA IVANOVA	{"email": "ivanova.natalya1967@postgrespro.ru", "phone": "+70311705570"}
0005435424332	782C4A	0619 204398	VLADIMIR SEMENOV	{"phone": "+70843519945"}
0005435424333	E74F1A	2274 888080	VALERIY ZHURAVLEV	{"phone": "+70876751796"}
0005435424334	E74F1A	8972 850943	DANIIL GORBUNOV	{"email": "gorbunovd11111979@postgrespro.ru", "phone": "+70726805349"}
0005435424335	E74F1A	2271 140972	ALBINA KOROLEVA	{"email": "koroleva-albina_071970@postgrespro.ru", "phone": "+70461978103"}
0005435424336	D680A5	6119 603093	NADEZHDA MIRONOVA	{"phone": "+70863864519"}
0005435424337	65471B	4710 884435	ALENA KUZNECOVA	{"phone": "+70790480254"}
0005435424338	0FF171	4833 418548	VALENTINA BOGDANOVA	{"phone": "+70123869854"}
0005435424339	860355	6426 999428	TATYANA NESTEROVA	{"email": "nesterova-t1967@postgrespro.ru", "phone": "+70902814718"}
0005435424340	E691FF	0134 458386	MARINA ISAEVA	{"email": "m.isaeva041975@postgrespro.ru", "phone": "+70288307376"}
0005435424341	E691FF	3362 421441	VALENTIN SCHERBAKOV	{"phone": "+70770166005"}
0005435424342	E691FF	3016 339486	GRIGORIY GORBUNOV	{"phone": "+70889123999"}
0005435424343	F20B6F	8965 159060	OKSANA GERASIMOVA	{"phone": "+70043411930"}
0005435424344	34CEB1	1434 132980	STANISLAV SAVELEV	{"email": "savelevstanislav_051956@postgrespro.ru", "phone": "+70383116463"}
0005435424345	5854FD	5962 976096	ALEKSANDR KULIKOV	{"email": "kulikov-aleksandr_031975@postgrespro.ru", "phone": "+70736746280"}
0005435424346	5854FD	1959 770985	SERGEY KUZMIN	{"email": "kuzmin_sergey-1977@postgrespro.ru", "phone": "+70892470011"}
0005435424347	6ABD78	0757 333416	TATYANA NESTEROVA	{"phone": "+70308611129"}
0005435424348	9FEF8A	7881 120642	PETR POPOV	{"email": "popovpetr011960@postgrespro.ru", "phone": "+70429118011"}
0005435424349	9FEF8A	5454 047520	NINA ZHURAVLEVA	{"phone": "+70186308143"}
0005435424350	479ECA	0782 828453	ANATOLIY KUZNECOV	{"email": "kuznecov-anatoliy-081974@postgrespro.ru", "phone": "+70912714706"}
0005435424351	9E96DD	0689 822515	PAVEL FEDOROV	{"phone": "+70585208419"}
0005435424352	9E96DD	6425 847289	ANATOLIY GAVRILOV	{"email": "anatoliy-gavrilov_07111973@postgrespro.ru", "phone": "+70919840206"}
0005435424353	B2EA48	5991 923395	LEONID KULIKOV	{"email": "kulikov_l_1969@postgrespro.ru", "phone": "+70307725227"}
0005435424354	7FEB4D	3472 985838	NATALYA ANTONOVA	{"email": "antonova.natalya-08021966@postgrespro.ru", "phone": "+70084386087"}
0005435424355	7FEB4D	7638 982409	TATYANA IVANOVA	{"phone": "+70382693661"}
0005435424356	A15169	5115 975635	VERA POPOVA	{"phone": "+70878529462"}
0005435424357	A15169	8001 721507	VLADIMIR OSIPOV	{"email": "vladimir-osipov-1974@postgrespro.ru", "phone": "+70818277154"}
0005435424358	68474D	2857 756046	MAKSIM OSIPOV	{"email": "maksim-osipov.09021977@postgrespro.ru", "phone": "+70902917365"}
0005435424359	68474D	9527 137924	VLADIMIR ZHURAVLEV	{"email": "vladimirzhuravlev_1968@postgrespro.ru", "phone": "+70336249440"}
0005435424360	3862BB	0377 847574	ALINA SMIRNOVA	{"phone": "+70560385318"}
0005435424361	2204C3	7917 625216	IRINA GORBUNOVA	{"email": "gorbunova.i_1973@postgrespro.ru", "phone": "+70698295248"}
0005435424362	C2ED56	2243 083387	IRINA ZAKHAROVA	{"email": "zakharova-irina.061971@postgrespro.ru", "phone": "+70932014397"}
0005435424363	2B7A2C	3346 821907	VALERIY SOROKIN	{"phone": "+70030619165"}
0005435424364	87E530	5001 164903	VLADIMIR ZAKHAROV	{"email": "vladimir-zakharov-02101978@postgrespro.ru", "phone": "+70327512243"}
0005435424365	ADDD11	9534 721922	ELENA ZAYCEVA	{"phone": "+70215044811"}
0005435424366	ADDD11	2546 703403	SVETLANA ERMAKOVA	{"email": "ermakova-s-1974@postgrespro.ru", "phone": "+70093526786"}
0005435424367	ADDD11	5259 118049	VLADIMIR KRASNOV	{"email": "vladimir.krasnov1966@postgrespro.ru", "phone": "+70613275406"}
0005435424368	CDA97C	6743 835672	LYUBOV ZAYCEVA	{"phone": "+70804554048"}
0005435424369	0992C3	5520 858377	EVGENIY NIKITIN	{"email": "nikitin_evgeniy.01021974@postgrespro.ru", "phone": "+70148850851"}
0005435424370	A1364B	2698 356210	ANNA KUZNECOVA	{"email": "akuznecova.01041965@postgrespro.ru", "phone": "+70255327416"}
0005435424371	A1364B	5027 862339	GALINA MIKHAYLOVA	{"email": "galinamikhaylova_1980@postgrespro.ru", "phone": "+70231906003"}
0005435424372	900458	1381 579352	LILIYA MEDVEDEVA	{"email": "medvedeva_liliya-13101963@postgrespro.ru", "phone": "+70410068533"}
0005435424373	082C2F	9049 488131	KRISTINA LOGINOVA	{"email": "k.loginova1976@postgrespro.ru", "phone": "+70436407203"}
0005435424374	082C2F	4985 436293	ANZHELIKA MIRONOVA	{"email": "anzhelika-mironova-041966@postgrespro.ru", "phone": "+70294618762"}
0005435424375	02CE9C	3976 729788	ANASTASIYA PETROVA	{"email": "anastasiyapetrova.13111969@postgrespro.ru", "phone": "+70113206756"}
0005435424376	C6D1F2	0749 446846	ALEKSEY FROLOV	{"phone": "+70401832248"}
0005435424377	831735	7942 852217	NATALYA NIKITINA	{"email": "natalya_nikitina_061966@postgrespro.ru", "phone": "+70536771603"}
0005435424378	71C62F	6804 781150	MARAT GUSEV	{"email": "marat_gusev_27111973@postgrespro.ru", "phone": "+70597045556"}
0005435424379	99B59B	9336 360206	SERGEY KONOVALOV	{"email": "konovalov_s.1966@postgrespro.ru", "phone": "+70563481099"}
0005435424380	1FA621	7316 918916	ELENA SOKOLOVA	{"email": "sokolova-elena.021973@postgrespro.ru", "phone": "+70106833198"}
0005435424381	8AEFAC	6136 295529	EKATERINA SOKOLOVA	{"phone": "+70417071603"}
0005435424382	4E319E	2580 791028	LYUBOV KOROLEVA	{"email": "korolevalyubov021973@postgrespro.ru", "phone": "+70186794424"}
0005435424383	4E319E	2542 297625	ANNA ZAKHAROVA	{"phone": "+70591401436"}
0005435424384	FC21E3	0738 284573	ANTON VOLKOV	{"email": "a-volkov121975@postgrespro.ru", "phone": "+70934260407"}
0005435424385	9C7BEE	3481 075263	YULIYA SIDOROVA	{"email": "sidorovayuliya_26081975@postgrespro.ru", "phone": "+70992386905"}
0005435424386	95959D	5843 861302	NADEZHDA GRISHINA	{"email": "grishina.n_1975@postgrespro.ru", "phone": "+70783733262"}
0005435424387	371235	1409 310897	VALENTINA PETROVA	{"email": "petrova-valentina27091974@postgrespro.ru", "phone": "+70967428354"}
0005435424388	91FF6A	1609 970364	BORIS MAKSIMOV	{"phone": "+70316848999"}
0005435424389	4024CE	6065 912227	ELENA PAVLOVA	{"phone": "+70003383956"}
0005435424390	E0FE89	7964 061190	ANTON IVANOV	{"phone": "+70116513231"}
0005435424391	EB3B95	7888 071139	VITALIY RODIONOV	{"email": "vitaliyrodionov_14121972@postgrespro.ru", "phone": "+70915442044"}
0005435424392	EB3B95	1289 030208	POLINA OVCHINNIKOVA	{"phone": "+70414967587"}
0005435424393	9488F4	4176 312719	ELENA MOISEEVA	{"email": "e_moiseeva_1970@postgrespro.ru", "phone": "+70200247024"}
0005435424394	9488F4	2940 196799	SERGEY ISAEV	{"phone": "+70163467514"}
0005435424395	52CCA8	8876 067856	VLADIMIR MELNIKOV	{"phone": "+70757653669"}
0005435424396	52CCA8	8676 190386	IGOR KUZNECOV	{"phone": "+70554876470"}
0005435424397	39C469	1895 465273	NATALYA MIKHAYLOVA	{"phone": "+70720913027"}
0005435424398	39C469	6373 624194	AMINA POPOVA	{"phone": "+70291819293"}
0005435424399	641263	3423 070734	ANATOLIY KRASNOV	{"phone": "+70943255266"}
0005435424400	641263	3854 565767	VADIM MAKSIMOV	{"email": "maksimov_vadim-111970@postgrespro.ru", "phone": "+70378520449"}
0005435424401	641263	4301 819978	RUSLAN KULIKOV	{"email": "kulikovruslan-1977@postgrespro.ru", "phone": "+70823125528"}
0005435424402	7D89D7	7835 005886	EVGENIYA POPOVA	{"email": "popova.evgeniya.091974@postgrespro.ru", "phone": "+70625650562"}
0005435424403	7D89D7	5176 255761	LYUBOV BORISOVA	{"phone": "+70557909698"}
0005435424404	36A321	9251 333447	VADIM ANDREEV	{"phone": "+70404515425"}
0005435424405	1428C5	8666 378931	GALINA DANILOVA	{"phone": "+70032622376"}
0005435424406	976596	5732 510705	OKSANA VOLKOVA	{"email": "volkova.oksana-07121978@postgrespro.ru", "phone": "+70997947795"}
0005435424407	8F4542	1036 764606	NADEZHDA DAVYDOVA	{"email": "n_davydova-28041977@postgrespro.ru", "phone": "+70545234360"}
0005435424408	8F4542	5916 709295	KIRILL ALEKSANDROV	{"phone": "+70657098667"}
0005435424409	02C4B6	1003 026797	IGOR ZHUKOV	{"email": "i-zhukov.121964@postgrespro.ru", "phone": "+70596841689"}
0005435424410	14817B	9328 459080	KONSTANTIN VASILEV	{"email": "vasilevkonstantin09061966@postgrespro.ru", "phone": "+70594943841"}
0005435424411	3E53F6	2717 118242	TATYANA RODIONOVA	{"email": "tatyanarodionova-091974@postgrespro.ru", "phone": "+70980757423"}
0005435424412	C7EDBF	2070 244033	OKSANA SMIRNOVA	{"email": "oksana_smirnova09011965@postgrespro.ru", "phone": "+70611760224"}
0005435424413	10A232	0707 896791	ALLA IVANOVA	{"email": "allaivanova07031966@postgrespro.ru", "phone": "+70620816922"}
0005435424414	FC8EB1	8924 033619	ALEVTINA KUZMINA	{"email": "kuzmina_alevtina_111956@postgrespro.ru", "phone": "+70826816590"}
0005435424415	8F5C90	1445 041132	EVGENIY GAVRILOV	{"phone": "+70845959566"}
0005435424416	8F5C90	0311 590296	NATALYA KUZNECOVA	{"email": "n_kuznecova.30061978@postgrespro.ru", "phone": "+70878907845"}
0005435424417	D78404	0145 868215	GALINA GUSEVA	{"email": "galinaguseva_1977@postgrespro.ru", "phone": "+70101503281"}
0005435424418	D78404	9967 756674	ALEKSANDR RODIONOV	{"phone": "+70728713832"}
0005435424419	56DFA2	2569 951928	YURIY ZHUKOV	{"phone": "+70505744109"}
0005435424420	87D1FA	6382 291894	IRINA POPOVA	{"email": "popovairina_031961@postgrespro.ru", "phone": "+70029256916"}
0005435424421	87D1FA	1035 163977	ALEKSEY FROLOV	{"email": "aleksey_frolov_021972@postgrespro.ru", "phone": "+70214429036"}
0005435424422	87D1FA	7062 253173	KAMIL KOZLOV	{"email": "kkozlov.1971@postgrespro.ru", "phone": "+70610419795"}
0005435424423	DBE9BD	5691 408925	SERGEY ZHURAVLEV	{"email": "zhuravlev.s_02101960@postgrespro.ru", "phone": "+70300865548"}
0005435424424	DBE9BD	6995 693045	OKSANA SERGEEVA	{"phone": "+70988503917"}
0005435424425	DBE9BD	2324 920822	ANNA KOROLEVA	{"email": "akoroleva_19121972@postgrespro.ru", "phone": "+70792106845"}
0005435424426	5A85EE	2785 219918	DMITRIY SOLOVEV	{"email": "solovevdmitriy-091972@postgrespro.ru", "phone": "+70568404243"}
0005435424427	5A85EE	7281 807149	IRINA YAKOVLEVA	{"phone": "+70574439010"}
0005435424428	C2F4AD	1893 748029	VLADISLAV KUZMIN	{"phone": "+70827145437"}
0005435424429	9C3471	4497 536639	ANNA NAZAROVA	{"email": "a-nazarova-19051978@postgrespro.ru", "phone": "+70016398191"}
0005435424430	F464D2	1199 101536	STANISLAV IVANOV	{"email": "stanislav_ivanov_1972@postgrespro.ru", "phone": "+70243400245"}
0005435424431	1F2BCF	3882 961663	VLADIMIR NIKOLAEV	{"phone": "+70517782043"}
0005435424432	CDFE7C	1629 423948	OLESYA IVANOVA	{"email": "olesyaivanova-17061973@postgrespro.ru", "phone": "+70544785797"}
0005435424433	808F96	3350 348530	NIKOLAY ORLOV	{"email": "nikolay_orlov.30061975@postgrespro.ru", "phone": "+70362199006"}
0005435424434	D7A685	1442 896087	ANTON VOLKOV	{"email": "a.volkov14041971@postgrespro.ru", "phone": "+70323258420"}
0005435424490	6F8903	5315 102203	KSENIYA VOLKOVA	{"phone": "+70167968272"}
0005435424435	D95090	9982 083126	ALEKSANDR STEPANOV	{"email": "stepanova_24051969@postgrespro.ru", "phone": "+70102843280"}
0005435424436	E0D10A	3559 960651	ANASTASIYA KALININA	{"email": "a-kalinina_071974@postgrespro.ru", "phone": "+70817364685"}
0005435424437	2D007E	6832 293747	ANDREY DMITRIEV	{"email": "dmitriev-a_24041964@postgrespro.ru", "phone": "+70296602631"}
0005435424438	2D007E	3774 246085	ALEKSEY ANTONOV	{"email": "a.antonov101984@postgrespro.ru", "phone": "+70610866543"}
0005435424439	2D007E	1057 903353	MARIYA RYABOVA	{"email": "mariya-ryabova.041982@postgrespro.ru", "phone": "+70753289436"}
0005435424440	D77281	9670 884396	DENIS PAVLOV	{"phone": "+70191796442"}
0005435424441	D77281	7617 101794	NIKOLAY MATVEEV	{"phone": "+70041017940"}
0005435424442	921367	4453 997989	EKATERINA GORBUNOVA	{"email": "e_gorbunova.1974@postgrespro.ru", "phone": "+70669297349"}
0005435424443	316437	9567 892301	TAMARA PETROVA	{"phone": "+70794537407"}
0005435424444	316437	1323 923439	IGOR MELNIKOV	{"phone": "+70997376182"}
0005435424445	1A7B10	9043 423721	VERONIKA KISELEVA	{"email": "veronika-kiseleva011969@postgrespro.ru", "phone": "+70762198053"}
0005435424446	1A7B10	3298 498477	RAISA ARKHIPOVA	{"email": "r-arkhipova_061975@postgrespro.ru", "phone": "+70994994041"}
0005435424447	1A7B10	3598 713782	NATALYA LUKYANOVA	{"email": "natalyalukyanova041973@postgrespro.ru", "phone": "+70805577687"}
0005435424448	73F81A	8010 299615	ANTON MAKSIMOV	{"phone": "+70961610133"}
0005435424449	20218D	0941 003847	ZINAIDA KALININA	{"email": "z_kalinina.1976@postgrespro.ru", "phone": "+70568937737"}
0005435424450	20218D	4393 186435	NATALYA ABRAMOVA	{"phone": "+70286922900"}
0005435424451	ECB297	5552 828067	LYUDMILA FILIPPOVA	{"phone": "+70671545508"}
0005435424452	ECB297	2124 149273	IRINA KULIKOVA	{"phone": "+70909153415"}
0005435424453	FBDC3B	8526 480173	EGOR KOROLEV	{"phone": "+70043993418"}
0005435424454	E43032	9176 753079	ALEKSEY SEMENOV	{"phone": "+70194018556"}
0005435424455	E43032	9364 236943	MIKHAIL MARTYNOV	{"email": "mikhail.martynov.29071969@postgrespro.ru", "phone": "+70023446666"}
0005435424456	2EA803	8979 822490	ELENA NIKITINA	{"phone": "+70085948208"}
0005435424457	8FB53D	1133 577344	ANDREY KOZLOV	{"email": "kozlovandrey.021969@postgrespro.ru", "phone": "+70958126032"}
0005435424458	4F8C8A	8691 405307	ALEKSANDR SMIRNOV	{"email": "aleksandr.smirnov051978@postgrespro.ru", "phone": "+70910019377"}
0005435424459	57BB2B	9373 310667	MAKSIM ANTONOV	{"phone": "+70494489945"}
0005435424460	57BB2B	1123 790496	EKATERINA NOVIKOVA	{"email": "novikova.e-041965@postgrespro.ru", "phone": "+70300248460"}
0005435424461	2309C2	4164 308274	VLADIMIR SCHERBAKOV	{"email": "vladimirscherbakov121972@postgrespro.ru", "phone": "+70655060176"}
0005435424462	2309C2	8372 930295	GEORGIY VOROBEV	{"phone": "+70354952525"}
0005435424463	BE94CF	4159 316857	NADEZHDA ZAYCEVA	{"email": "nzayceva-101974@postgrespro.ru", "phone": "+70513066664"}
0005435424464	5AF7B5	6826 298981	ALEKSANDR ILIN	{"email": "ilin_a_25021970@postgrespro.ru", "phone": "+70801837056"}
0005435424465	5AF7B5	4945 796513	ALEKSEY FOMIN	{"email": "fomin_aleksey07111972@postgrespro.ru", "phone": "+70382486866"}
0005435424466	95B8DC	0631 007917	VIKTOR PETROV	{"email": "petrov-viktor1972@postgrespro.ru", "phone": "+70322966110"}
0005435424467	7D868D	5765 844807	MARIYA AFANASEVA	{"email": "afanaseva-mariya-18071974@postgrespro.ru", "phone": "+70359607243"}
0005435424468	7D868D	6921 288503	VERA GUSEVA	{"phone": "+70226303043"}
0005435424469	000AA7	0264 842639	NADEZHDA KRASNOVA	{"phone": "+70682052401"}
0005435424470	000AA7	9926 247465	ALEKSANDR SOLOVEV	{"email": "soloveva_1962@postgrespro.ru", "phone": "+70500729499"}
0005435424471	2FFBCC	6319 385740	RAISA ALEKSANDROVA	{"phone": "+70124898857"}
0005435424472	2FFBCC	1318 404253	VALERIY SHEVCHENKO	{"email": "valeriyshevchenko-17071985@postgrespro.ru", "phone": "+70154506060"}
0005435424473	77FA86	1387 816361	EKATERINA TARASOVA	{"email": "tarasovaekaterina1972@postgrespro.ru", "phone": "+70439790245"}
0005435424474	BFC4B7	5723 163736	ANDREY BONDARENKO	{"email": "andreybondarenko1968@postgrespro.ru", "phone": "+70037352667"}
0005435424475	0988A1	7669 864932	ANTONINA KOZLOVA	{"phone": "+70726469702"}
0005435424476	0988A1	1111 029425	IRINA KISELEVA	{"phone": "+70136054213"}
0005435424477	950737	9200 155575	VLADIMIR AFANASEV	{"phone": "+70050401885"}
0005435424478	950737	7022 394623	KRISTINA ZAKHAROVA	{"email": "kristinazakharova1974@postgrespro.ru", "phone": "+70939056398"}
0005435424479	9EA4E1	2885 192910	NAIL CHERNOV	{"phone": "+70969572025"}
0005435424480	1DD209	6554 849676	SERGEY KUZNECOV	{"email": "kuznecov-s-041959@postgrespro.ru", "phone": "+70457758505"}
0005435424481	1DD209	5885 534541	EKATERINA GERASIMOVA	{"email": "ekaterina_gerasimova031971@postgrespro.ru", "phone": "+70344422608"}
0005435424482	1DD209	6756 377045	ANATOLIY POPOV	{"email": "a.popov.091977@postgrespro.ru", "phone": "+70728478668"}
0005435424483	3104E9	0046 445220	YURIY MELNIKOV	{"phone": "+70980764700"}
0005435424484	976803	7943 184573	IGOR KARPOV	{"email": "i.karpov.071974@postgrespro.ru", "phone": "+70332212957"}
0005435424485	B4F693	0930 179955	EGOR RODIONOV	{"email": "rodionov_e031982@postgrespro.ru", "phone": "+70525663689"}
0005435424486	F5C108	7414 499131	MARGARITA EGOROVA	{"email": "m.egorova_111966@postgrespro.ru", "phone": "+70529884952"}
0005435424487	2843B6	8508 908181	ANDREY MIRONOV	{"email": "amironov-121982@postgrespro.ru", "phone": "+70329811704"}
0005435424488	6F8903	6283 165663	ROMAN KOZLOV	{"phone": "+70084525624"}
0005435424489	6F8903	5126 512616	IVAN POPOV	{"phone": "+70141045868"}
0005435424491	45A215	2757 183844	MARIYA POTAPOVA	{"phone": "+70872252385"}
0005435424492	45A215	0183 077170	EVGENIY POPOV	{"email": "popove-091962@postgrespro.ru", "phone": "+70566831316"}
0005435424493	0DAE7C	0769 204637	SERGEY MOISEEV	{"phone": "+70786770808"}
0005435424494	C8D458	7505 381899	NINA ALEKSANDROVA	{"email": "n.aleksandrova-1977@postgrespro.ru", "phone": "+70730398453"}
0005435424495	C8D458	8582 896374	ARMEN POPOV	{"email": "popov.armen23011974@postgrespro.ru", "phone": "+70343456746"}
0005435424496	1BACA8	7740 251575	GENNADIY DMITRIEV	{"email": "gdmitriev-1977@postgrespro.ru", "phone": "+70679728648"}
0005435424497	D9EC85	5820 535601	MAKSIM KUZMIN	{"phone": "+70322171658"}
0005435424498	313020	2382 917571	ALENA ZAYCEVA	{"email": "alenazayceva1962@postgrespro.ru", "phone": "+70281146866"}
0005435424499	313020	2076 304258	ALEKSANDRA VASILEVA	{"email": "vasileva_aleksandra_1977@postgrespro.ru", "phone": "+70327152611"}
0005435424500	2D2C71	7271 343519	ANTON PAVLOV	{"email": "pavlov_anton_111970@postgrespro.ru", "phone": "+70004062887"}
0005435424501	798EFE	1457 656739	MIKHAIL VASILEV	{"email": "vasilev_m_02021973@postgrespro.ru", "phone": "+70586427380"}
0005435424502	D4C26E	6465 585218	NADEZHDA IVANOVA	{"phone": "+70147482175"}
0005435424503	E9E784	2292 418124	OLESYA ZAYCEVA	{"phone": "+70276968297"}
0005435424504	B28A4D	6734 558296	NATALYA LUKYANOVA	{"phone": "+70665279780"}
0005435424505	B28A4D	4365 460579	YURIY KUZMIN	{"email": "ykuzmin011964@postgrespro.ru", "phone": "+70816259168"}
0005435424506	B90DE1	6654 173995	VLADISLAV MELNIKOV	{"email": "melnikov-vladislav-1975@postgrespro.ru", "phone": "+70879434394"}
0005435424507	B90DE1	9616 783379	ARTEM FILIPPOV	{"phone": "+70340539856"}
0005435424508	B90DE1	9627 562826	ANNA PETROVA	{"email": "petrova_anna-051984@postgrespro.ru", "phone": "+70044842683"}
0005435424509	7B2AD4	2370 506839	LYUDMILA VOROBEVA	{"email": "vorobeva_l1961@postgrespro.ru", "phone": "+70849931935"}
0005435424510	7B2AD4	7268 642578	YAN VOROBEV	{"phone": "+70670680014"}
0005435424511	B31405	0767 124689	TATYANA BOGDANOVA	{"email": "t-bogdanova.21021978@postgrespro.ru", "phone": "+70673211295"}
0005435424512	175C09	5113 739406	ANASTASIYA SEMENOVA	{"phone": "+70972104300"}
0005435424513	F520C5	1369 999139	EKATERINA ARKHIPOVA	{"email": "arkhipovaekaterina.1976@postgrespro.ru", "phone": "+70938699356"}
0005435424514	83F30E	8130 585392	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr09101971@postgrespro.ru", "phone": "+70250912155"}
0005435424515	83F30E	2328 913439	ARTEM MIRONOV	{"phone": "+70771802028"}
0005435424516	F162B8	3352 999829	NIKOLAY MIRONOV	{"email": "mironov-n1983@postgrespro.ru", "phone": "+70454244701"}
0005435424517	625522	8284 803524	RUSLAN ROMANOV	{"phone": "+70448277431"}
0005435424518	B342B0	6940 784120	VALENTINA LOGINOVA	{"phone": "+70413509845"}
0005435424519	36C10F	4722 050039	VLADIMIR ALEKSEEV	{"email": "valekseev_111971@postgrespro.ru", "phone": "+70620565571"}
0005435424520	2CA037	2259 836484	VLADIMIR DENISOV	{"email": "v-denisov-061977@postgrespro.ru", "phone": "+70024510387"}
0005435424521	2CA037	1627 971243	VERA OSIPOVA	{"email": "osipova_vera-071967@postgrespro.ru", "phone": "+70922825503"}
0005435424522	5E717A	1324 403560	KIRILL SMIRNOV	{"phone": "+70171610921"}
0005435424523	5E717A	7826 475817	ALEKSANDR SOKOLOV	{"phone": "+70002190994"}
0005435424524	B35D04	1337 453610	TATYANA NIKITINA	{"phone": "+70526489712"}
0005435424525	707E04	9695 714889	IVAN ABRAMOV	{"email": "ivan-abramov041971@postgrespro.ru", "phone": "+70964244682"}
0005435424526	2BE5ED	3804 213776	NINA MAKSIMOVA	{"phone": "+70537928913"}
0005435424527	864661	9427 464688	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.05081965@postgrespro.ru", "phone": "+70041781952"}
0005435424528	201319	1320 792739	YURIY POPOV	{"email": "yuriy-popov-1978@postgrespro.ru", "phone": "+70478475751"}
0005435424529	C4FA01	1283 988702	NIKITA MIKHAYLOV	{"email": "nikita_mikhaylov-1977@postgrespro.ru", "phone": "+70808683207"}
0005435424530	C4FA01	6591 143451	ALINA NIKOLAEVA	{"email": "a_nikolaeva-29031956@postgrespro.ru", "phone": "+70016052655"}
0005435424531	C0B40D	1742 575243	DANIIL KRASNOV	{"phone": "+70449078640"}
0005435424532	D8A586	8982 682349	VYACHESLAV SEMENOV	{"phone": "+70873942586"}
0005435424533	8F3CB1	7049 888106	ALEKSANDR PETROV	{"email": "aleksandr.petrov-081967@postgrespro.ru", "phone": "+70178679767"}
0005435424534	D8642B	6424 490823	GENNADIY FILIPPOV	{"phone": "+70968131017"}
0005435424535	EF89DD	3854 463263	VYACHESLAV MOISEEV	{"email": "moiseev_v101977@postgrespro.ru", "phone": "+70918080444"}
0005435424536	7A2C38	1546 204241	LIDIYA VASILEVA	{"phone": "+70446316458"}
0005435424537	50D2AA	0211 288296	KIRILL BORISOV	{"phone": "+70775389688"}
0005435424538	50D2AA	6814 824642	MAKSIM VOLKOV	{"phone": "+70309386894"}
0005435424539	023731	7344 621282	MARINA NAZAROVA	{"email": "m_nazarova-1969@postgrespro.ru", "phone": "+70764785092"}
0005435424540	023731	4965 812935	ANDREY VLASOV	{"email": "andreyvlasov-051978@postgrespro.ru", "phone": "+70092230675"}
0005435424541	023731	7924 715104	TATYANA BOGDANOVA	{"email": "bogdanova-tatyana_1972@postgrespro.ru", "phone": "+70746988923"}
0005435424542	C70FC9	2811 573243	ANATOLIY SCHERBAKOV	{"phone": "+70074965549"}
0005435424543	72E7AB	6758 015699	PETR GUSEV	{"email": "gusev-p1972@postgrespro.ru", "phone": "+70745883493"}
0005435424544	02544E	3651 692138	ELLA VASILEVA	{"email": "vasileva-e111963@postgrespro.ru", "phone": "+70757666650"}
0005435424545	02544E	2520 299999	NATALYA STEPANOVA	{"phone": "+70625216821"}
0005435424601	8E802A	9774 716959	LIDIYA ARKHIPOVA	{"phone": "+70907633213"}
0005435424546	02544E	5050 070308	ZHANNA KOZLOVA	{"email": "z_kozlova03011976@postgrespro.ru", "phone": "+70779102111"}
0005435424547	3A2700	3716 974802	ANNA PAVLOVA	{"phone": "+70624893242"}
0005435424548	FD1715	1488 832329	IGOR ORLOV	{"phone": "+70046215808"}
0005435424549	FD1715	4414 803108	TATYANA BORISOVA	{"phone": "+70286827396"}
0005435424550	3B403C	6843 813648	NINA KUZMINA	{"email": "ninakuzmina.1976@postgrespro.ru", "phone": "+70558328589"}
0005435424551	3B403C	3978 408726	ANATOLIY SCHERBAKOV	{"email": "a_scherbakov-111970@postgrespro.ru", "phone": "+70944557885"}
0005435424552	3B403C	6916 463237	TATYANA AKIMOVA	{"email": "tatyana.akimova_03011965@postgrespro.ru", "phone": "+70302640727"}
0005435424553	D9FB44	2019 133152	KIRILL SOROKIN	{"email": "sorokin_kirill_09041978@postgrespro.ru", "phone": "+70002375844"}
0005435424554	D9FB44	8315 594582	ALEKSANDR SERGEEV	{"phone": "+70902824136"}
0005435424555	33AE01	4562 128515	TATYANA KOROLEVA	{"email": "korolevatatyana.15111966@postgrespro.ru", "phone": "+70566874593"}
0005435424556	A57134	3123 563294	VALENTINA TIKHONOVA	{"phone": "+70283099588"}
0005435424557	257980	9315 459078	VALERIY CHERNOV	{"phone": "+70330593639"}
0005435424558	257980	0741 532966	VLADIMIR POPOV	{"email": "popov_vladimir-1973@postgrespro.ru", "phone": "+70935498727"}
0005435424559	ACB5AA	5644 998599	VALENTINA ZOTOVA	{"email": "zotova_valentina_061973@postgrespro.ru", "phone": "+70116823789"}
0005435424560	A65756	4311 258151	GALINA MIRONOVA	{"email": "gmironova_28111975@postgrespro.ru", "phone": "+70124362389"}
0005435424561	DE458D	5564 411979	ANDREY MAKAROV	{"email": "a_makarov-051974@postgrespro.ru", "phone": "+70846969579"}
0005435424562	4DEAA2	3583 469140	DMITRIY KUZNECOV	{"phone": "+70037341444"}
0005435424563	606740	5563 919452	SERGEY IVANOV	{"phone": "+70505457694"}
0005435424564	606740	6335 833317	MIKHAIL BARANOV	{"email": "mikhail_baranov1979@postgrespro.ru", "phone": "+70227461932"}
0005435424565	D2C9EE	4243 088107	ALEKSEY MAKSIMOV	{"email": "maksimov_a_031980@postgrespro.ru", "phone": "+70429708331"}
0005435424566	909A3A	8570 723435	EKATERINA POTAPOVA	{"email": "potapova_e_1988@postgrespro.ru", "phone": "+70087004094"}
0005435424567	909A3A	1710 554516	VLADISLAV GERASIMOV	{"email": "gerasimovv-04011971@postgrespro.ru", "phone": "+70135993960"}
0005435424568	51D58C	1201 012068	KONSTANTIN MIKHAYLOV	{"email": "konstantin-mikhaylov_021979@postgrespro.ru", "phone": "+70616768626"}
0005435424569	51D58C	5343 043076	NIKITA ALEKSEEV	{"email": "alekseev_nikita-1978@postgrespro.ru", "phone": "+70068971488"}
0005435424570	E83BC8	7542 852619	VALERIYA EFIMOVA	{"phone": "+70308940873"}
0005435424571	E83BC8	8061 050127	VYACHESLAV NIKOLAEV	{"phone": "+70158430829"}
0005435424572	E83BC8	9907 417283	OLGA MOISEEVA	{"email": "omoiseeva25111977@postgrespro.ru", "phone": "+70124811878"}
0005435424573	3DF2FA	3485 142999	NIKOLAY BONDARENKO	{"email": "nikolay_bondarenko_021965@postgrespro.ru", "phone": "+70195728339"}
0005435424574	4B81FA	8992 927204	VLADIMIR CHERNOV	{"email": "chernov_v_061969@postgrespro.ru", "phone": "+70077759775"}
0005435424575	4B81FA	9374 720107	NATALYA KOZLOVA	{"phone": "+70841301950"}
0005435424576	4B81FA	8888 461270	MARIYA NAZAROVA	{"email": "mariya-nazarova.28061975@postgrespro.ru", "phone": "+70861559759"}
0005435424577	D052EE	3486 108619	LYUDMILA SMIRNOVA	{"phone": "+70832262421"}
0005435424578	39D232	3396 049397	OLESYA OSIPOVA	{"email": "osipova_olesya.09091972@postgrespro.ru", "phone": "+70896401994"}
0005435424579	B1D166	8469 654496	ILYA NAUMOV	{"email": "naumovi_061971@postgrespro.ru", "phone": "+70429495883"}
0005435424580	B1D166	3408 975007	OLGA BORISOVA	{"email": "borisova.o-01011974@postgrespro.ru", "phone": "+70637291988"}
0005435424581	8F44B1	0850 786073	OLEG VLASOV	{"email": "o_vlasov1963@postgrespro.ru", "phone": "+70937723472"}
0005435424582	FC1427	9114 283788	ALFIYA NESTEROVA	{"phone": "+70946841229"}
0005435424583	2B5692	8633 478004	NINA POPOVA	{"phone": "+70559360882"}
0005435424584	2B5692	2917 598465	EKATERINA DMITRIEVA	{"email": "dmitrievae.061967@postgrespro.ru", "phone": "+70945685648"}
0005435424585	9F5BEC	8813 144727	OLGA GORBUNOVA	{"phone": "+70222852029"}
0005435424586	7576DD	0906 935799	YANA EFREMOVA	{"email": "y-efremova_1985@postgrespro.ru", "phone": "+70731501706"}
0005435424587	68C7EC	0404 170932	ZINAIDA MATVEEVA	{"phone": "+70103541931"}
0005435424588	79C222	5448 642299	LYUBOV BELOVA	{"phone": "+70321614520"}
0005435424589	068F4B	1912 236915	GALINA MATVEEVA	{"email": "g.matveeva051969@postgrespro.ru", "phone": "+70032002200"}
0005435424590	B8E18E	6567 104440	ELENA ZHUKOVA	{"email": "e.zhukova.26101975@postgrespro.ru", "phone": "+70613491815"}
0005435424591	EF174B	1328 950454	ANNA POPOVA	{"email": "popova_a_03031975@postgrespro.ru", "phone": "+70755617918"}
0005435424592	377306	8021 626244	ANTON NAZAROV	{"email": "anton_nazarov-1978@postgrespro.ru", "phone": "+70967736476"}
0005435424593	377306	5484 914038	SERGEY IVANOV	{"phone": "+70785907935"}
0005435424594	6D556A	3833 478017	IRAIDA NIKOLAEVA	{"email": "nikolaeva.i1969@postgrespro.ru", "phone": "+70777872468"}
0005435424595	09C836	1219 934026	NINA VLASOVA	{"phone": "+70943004381"}
0005435424596	0BD61B	8686 909355	DENIS ZAKHAROV	{"phone": "+70094160897"}
0005435424597	6F2630	7675 188548	DMITRIY ZHURAVLEV	{"phone": "+70113215229"}
0005435424598	411EBC	9514 749005	OLGA SOLOVEVA	{"email": "soloveva.olga-12111985@postgrespro.ru", "phone": "+70269160819"}
0005435424599	B94661	9457 004301	MARIYA ERMAKOVA	{"phone": "+70107814798"}
0005435424600	3C7A6A	9885 148180	ELENA FROLOVA	{"phone": "+70231276887"}
0005435424602	8E802A	5694 543508	VIKTOR KOZLOV	{"phone": "+70596218600"}
0005435424603	4759FD	3323 726069	OLGA MOISEEVA	{"phone": "+70730628386"}
0005435424604	5DE91F	5430 312400	SVETLANA VOLKOVA	{"phone": "+70336022347"}
0005435424605	5DE91F	6368 871798	ALEKSANDR MARTYNOV	{"phone": "+70305785166"}
0005435424606	5DE91F	1984 974735	TAMARA KUDRYASHOVA	{"email": "t.kudryashova1981@postgrespro.ru", "phone": "+70640161896"}
0005435424607	AA942C	8238 518046	EVGENIY ILIN	{"email": "e_ilin02091980@postgrespro.ru", "phone": "+70009379693"}
0005435424608	667548	6740 775833	ALINA BORISOVA	{"phone": "+70033311765"}
0005435424609	78B0AE	8309 433749	MIKHAIL ZAKHAROV	{"phone": "+70497642926"}
0005435424610	55139A	4689 641457	ELIZAVETA PAVLOVA	{"email": "pavlova_elizaveta-01061979@postgrespro.ru", "phone": "+70908615309"}
0005435424611	D5BBC3	1022 417145	RIMMA KUZNECOVA	{"email": "kuznecova.rimma_081975@postgrespro.ru", "phone": "+70444842468"}
0005435424612	B97AD0	2443 999062	LYUDMILA SOKOLOVA	{"email": "l-sokolova_09061972@postgrespro.ru", "phone": "+70140177141"}
0005435424613	6B39AF	9309 780910	GALINA YAKOVLEVA	{"email": "yakovleva_galina_091974@postgrespro.ru", "phone": "+70867300812"}
0005435424614	B99C41	4561 286483	NATALYA MAKSIMOVA	{"phone": "+70049491364"}
0005435424615	507A92	4873 794572	OLGA NOVIKOVA	{"phone": "+70063628189"}
0005435424616	507A92	4040 217684	VALENTINA VASILEVA	{"phone": "+70324733887"}
0005435424617	B1B564	0485 880562	OKSANA POTAPOVA	{"phone": "+70114309765"}
0005435424618	859F4C	1763 721810	ELENA VOROBEVA	{"email": "vorobeva.e061981@postgrespro.ru", "phone": "+70424144760"}
0005435424619	859F4C	2833 173471	NATALYA FILATOVA	{"phone": "+70067579461"}
0005435424620	859F4C	6688 865063	IRINA MOROZOVA	{"email": "irinamorozova.1979@postgrespro.ru", "phone": "+70487117267"}
0005435424621	3AEE76	4904 548183	ELENA MOISEEVA	{"email": "elenamoiseeva_1973@postgrespro.ru", "phone": "+70376345660"}
0005435424622	3AEE76	8194 389443	NADEZHDA MOROZOVA	{"phone": "+70345620887"}
0005435424623	EDE9DB	3237 366598	NATALYA SOLOVEVA	{"email": "soloveva-natalya091983@postgrespro.ru", "phone": "+70058421751"}
0005435424624	ADA5A1	2981 605807	KARINA ZHURAVLEVA	{"phone": "+70127618370"}
0005435424625	A34382	3677 050184	ANASTASIYA GAVRILOVA	{"email": "agavrilova.1982@postgrespro.ru", "phone": "+70206427653"}
0005435424626	A34382	9524 616892	ANTON BORISOV	{"email": "anton-borisov-13041973@postgrespro.ru", "phone": "+70019226678"}
0005435424627	A34382	4395 307107	TATYANA BORISOVA	{"phone": "+70539279382"}
0005435424628	00BDF3	6998 021917	NIKOLAY ALEKSEEV	{"email": "alekseevn1979@postgrespro.ru", "phone": "+70365685217"}
0005435424629	2F2BB2	9426 569668	NIKOLAY NIKITIN	{"phone": "+70089999788"}
0005435424630	F06BA1	8443 258486	DANILA ANTONOV	{"email": "antonov_danila1982@postgrespro.ru", "phone": "+70310025302"}
0005435424631	093524	0171 385332	RENAT DENISOV	{"phone": "+70587946664"}
0005435424632	F81F15	1445 326745	LYUDMILA NIKIFOROVA	{"email": "nikiforovalyudmila1959@postgrespro.ru", "phone": "+70432127908"}
0005435424633	A81E0F	5759 796148	ARTEM MAKAROV	{"phone": "+70170677311"}
0005435424634	BED2B9	2152 268806	VALERIY STEPANOV	{"phone": "+70238417004"}
0005435424635	BED2B9	3765 147051	ALEKSEY IVANOV	{"phone": "+70240308963"}
0005435424636	C3B216	6207 022575	IGOR NIKITIN	{"email": "nikitin.igor_02111962@postgrespro.ru", "phone": "+70644160862"}
0005435424637	C3B216	6704 674572	NATALYA KUZNECOVA	{"phone": "+70703982587"}
0005435424638	C3B216	2486 312163	ALEKSEY KISELEV	{"email": "alekseykiselev.20111968@postgrespro.ru", "phone": "+70469709274"}
0005435424639	B153E7	9411 073394	ALEKSEY YAKOVLEV	{"email": "yakovlev-aleksey_091980@postgrespro.ru", "phone": "+70781989042"}
0005435424640	B153E7	6051 235719	ALEKSEY MAKSIMOV	{"email": "amaksimov-1980@postgrespro.ru", "phone": "+70949643469"}
0005435424641	7AB255	1613 833301	SERGEY BARANOV	{"phone": "+70847983027"}
0005435424642	5B496B	0855 463751	YULIYA ALEKSANDROVA	{"email": "aleksandrova_y-121980@postgrespro.ru", "phone": "+70498872259"}
0005435424643	49E409	3847 187565	ALEKSEY ALEKSANDROV	{"phone": "+70541224420"}
0005435424644	49E409	0857 695208	DMITRIY MAKAROV	{"phone": "+70455705351"}
0005435424645	BC2C6C	0573 014197	IVAN STEPANOV	{"email": "stepanov.ivan-031978@postgrespro.ru", "phone": "+70448077232"}
0005435424646	123289	0493 976476	NATALYA KONDRATEVA	{"email": "natalya-kondrateva-1953@postgrespro.ru", "phone": "+70192742336"}
0005435424647	123289	7408 369882	ALEKSANDR ANDREEV	{"email": "aleksandr.andreev1974@postgrespro.ru", "phone": "+70570244805"}
0005435424648	123289	6360 106033	SERGEY BORISOV	{"phone": "+70199142833"}
0005435424649	6104D7	4877 026823	ZINAIDA YAKOVLEVA	{"email": "zinaidayakovleva_13061990@postgrespro.ru", "phone": "+70309366422"}
0005435424650	41D0E0	9604 275248	SVETLANA AKIMOVA	{"phone": "+70616357132"}
0005435424651	3E9602	1951 871713	ALEKSEY MOROZOV	{"email": "morozov-aleksey-27091966@postgrespro.ru", "phone": "+70846279968"}
0005435424652	2A9760	7392 827235	MARIYA SEMENOVA	{"phone": "+70125093690"}
0005435424653	1007CF	6720 582029	SERGEY MOISEEV	{"phone": "+70386532473"}
0005435424654	0A7E12	4295 423898	OLGA ZHURAVLEVA	{"email": "o-zhuravleva_22091977@postgrespro.ru", "phone": "+70714617129"}
0005435424655	0A7E12	2775 026403	VYACHESLAV KUZNECOV	{"phone": "+70345608441"}
0005435424656	91C44A	2847 711798	TATYANA IVANOVA	{"email": "ivanovat1986@postgrespro.ru", "phone": "+70548089649"}
0005435424657	91C44A	7380 798272	NIKOLAY STEPANOV	{"phone": "+70942225455"}
0005435424658	8E7304	5848 472286	TATYANA BOGDANOVA	{"phone": "+70442621724"}
0005435424659	6ADC21	1600 831321	OLGA FROLOVA	{"email": "frolova.olga1982@postgrespro.ru", "phone": "+70713839686"}
0005435424660	7D9ACE	8359 166898	ARTEM KONOVALOV	{"email": "artem.konovalov.1975@postgrespro.ru", "phone": "+70145016046"}
0005435424661	3F557E	0608 238382	OLGA KAZAKOVA	{"email": "olga.kazakova.1978@postgrespro.ru", "phone": "+70682547039"}
0005435424662	BD02DE	2147 854197	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov.1967@postgrespro.ru", "phone": "+70010709869"}
0005435424663	BD02DE	2872 536955	ALEKSANDRA KALININA	{"email": "aleksandra-kalinina23011969@postgrespro.ru", "phone": "+70479482898"}
0005435424664	DD2A98	4340 857040	DMITRIY MIRONOV	{"email": "d_mironov_1972@postgrespro.ru", "phone": "+70646515015"}
0005435424665	DD2A98	2168 203010	VLADIMIR ABRAMOV	{"email": "vladimir_abramov.12021981@postgrespro.ru", "phone": "+70912339836"}
0005435424666	973496	3381 796518	KONSTANTIN KUZMIN	{"email": "kuzmin-k1974@postgrespro.ru", "phone": "+70367820683"}
0005435424667	95EE55	5970 765170	OLGA KOROLEVA	{"phone": "+70547794218"}
0005435424668	95EE55	4670 091371	ELENA AFANASEVA	{"phone": "+70409115135"}
0005435424669	FD77E2	1778 815662	ELENA ISAEVA	{"phone": "+70531655991"}
0005435424670	0350E4	4087 771680	POLINA MIKHAYLOVA	{"phone": "+70787430588"}
0005435424671	532AA2	9474 022138	ELENA NIKIFOROVA	{"phone": "+70553336618"}
0005435424672	1EB0EA	3251 305649	PAVEL KOROLEV	{"phone": "+70128308172"}
0005435424673	1EB0EA	9777 794160	YURIY GRIGOREV	{"phone": "+70382703226"}
0005435424674	C67938	8937 059260	RAISA VASILEVA	{"email": "vasileva.raisa-011969@postgrespro.ru", "phone": "+70631490817"}
0005435424675	C67938	6019 670595	KRISTINA POLYAKOVA	{"email": "k_polyakova-1969@postgrespro.ru", "phone": "+70438814235"}
0005435424676	F6266E	4308 819043	VALENTINA MEDVEDEVA	{"email": "medvedeva-valentina-081969@postgrespro.ru", "phone": "+70923674402"}
0005435424677	F6266E	9777 681122	ALEKSEY ORLOV	{"email": "orlov-aleksey.021976@postgrespro.ru", "phone": "+70071651775"}
0005435424678	B0991D	8388 260302	VASILIY MELNIKOV	{"email": "melnikov-vasiliy_13101987@postgrespro.ru", "phone": "+70822002364"}
0005435424679	518357	8006 583896	ELENA SIDOROVA	{"phone": "+70037183507"}
0005435424680	055CC3	4288 898935	OLGA SOKOLOVA	{"email": "osokolova.011966@postgrespro.ru", "phone": "+70693158634"}
0005435424681	CF5E4A	3360 853073	ANFISA SMIRNOVA	{"email": "smirnova-a_1973@postgrespro.ru", "phone": "+70507318903"}
0005435424682	8C9AEB	9591 547330	ALEKSANDR STEPANOV	{"phone": "+70116577552"}
0005435424683	680AAF	2631 629981	ANNA IVANOVA	{"phone": "+70395606385"}
0005435424684	573F0C	8703 254305	LYUBOV IVANOVA	{"email": "ivanova_l-09111974@postgrespro.ru", "phone": "+70922491538"}
0005435424685	B38F72	7591 438016	MARINA NAZAROVA	{"phone": "+70964572433"}
0005435424686	B38F72	3876 584939	KLAVDIYA KALININA	{"phone": "+70594342914"}
0005435424687	51A439	6498 148355	ANDREY EGOROV	{"email": "egorov_andrey_1981@postgrespro.ru", "phone": "+70393194626"}
0005435424688	1EA0A2	6629 254852	VIKTOR STEPANOV	{"email": "stepanov-viktor091965@postgrespro.ru", "phone": "+70790477628"}
0005435424689	48B123	6161 336144	ANDREY MAKSIMOV	{"email": "maksimov.andrey.07091966@postgrespro.ru", "phone": "+70689748800"}
0005435424690	48B123	4141 332217	ALENA KISELEVA	{"phone": "+70669421792"}
0005435424691	D0602C	8249 381236	RAISA ZOTOVA	{"phone": "+70481635828"}
0005435424692	A8A220	3649 514895	VLADIMIR OSIPOV	{"email": "vladimirosipov_1954@postgrespro.ru", "phone": "+70830575962"}
0005435424693	A8A220	5172 051845	GEORGIY SOKOLOV	{"email": "sokolovgeorgiy1978@postgrespro.ru", "phone": "+70006645721"}
0005435424694	913BBE	3662 757197	YURIY KRASNOV	{"phone": "+70393159424"}
0005435424695	61D6AF	8805 208969	DANILA VOLKOV	{"phone": "+70407467640"}
0005435424696	421862	8024 376439	ELENA ALEKSANDROVA	{"email": "e.aleksandrova031964@postgrespro.ru", "phone": "+70345136284"}
0005435424697	B4C3C7	0846 814080	VLADIMIR IVANOV	{"email": "v.ivanov.20041975@postgrespro.ru", "phone": "+70093093072"}
0005435424698	7FBCED	8665 432631	ANATOLIY SOKOLOV	{"email": "sokolov_a.02011974@postgrespro.ru", "phone": "+70461983195"}
0005435424699	DFF1AF	5069 356670	KLARA ROMANOVA	{"phone": "+70641011000"}
0005435424700	4FB728	6943 006578	VALENTINA KARPOVA	{"email": "karpova-valentina20121965@postgrespro.ru", "phone": "+70802165453"}
0005435424701	FC4C9C	1007 620715	ALEKSANDR MIKHAYLOV	{"email": "aleksandrmikhaylov.1977@postgrespro.ru", "phone": "+70260368384"}
0005435424702	336ECA	6730 709984	KLAVDIYA ZAYCEVA	{"email": "k_zayceva26051982@postgrespro.ru", "phone": "+70610555682"}
0005435424703	4629A7	1865 473125	ANASTASIYA MELNIKOVA	{"phone": "+70505143713"}
0005435424704	1C81DA	6463 390167	KSENIYA YAKOVLEVA	{"phone": "+70806722040"}
0005435424705	BBE0B4	1380 142021	IGOR BELOV	{"email": "igor.belov041967@postgrespro.ru", "phone": "+70612389733"}
0005435424706	BBE0B4	6775 924760	VLADIMIR GUSEV	{"email": "gusev.v-1968@postgrespro.ru", "phone": "+70611908967"}
0005435424707	D65F86	1041 781959	MARINA VASILEVA	{"email": "m_vasileva-1965@postgrespro.ru", "phone": "+70649441979"}
0005435424708	82C3D0	9330 990412	SVETLANA EFREMOVA	{"phone": "+70613763471"}
0005435424709	ED33B1	7040 826815	NATALYA KISELEVA	{"email": "n.kiseleva_011980@postgrespro.ru", "phone": "+70969769252"}
0005435424710	ED33B1	6314 778142	SERGEY VOROBEV	{"phone": "+70352721962"}
0005435424711	35F45B	4215 336937	LYUDMILA VOROBEVA	{"email": "lyudmila.vorobeva1971@postgrespro.ru", "phone": "+70922392785"}
0005435424712	35F45B	2320 779025	VYACHESLAV PETROV	{"phone": "+70505460710"}
0005435424713	1355D0	2124 354779	YULIYA KOZLOVA	{"email": "yuliya_kozlova18111979@postgrespro.ru", "phone": "+70016293235"}
0005435424714	1355D0	4835 378657	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr-18101968@postgrespro.ru", "phone": "+70838654352"}
0005435424715	1355D0	0217 914561	KARINA YAKOVLEVA	{"phone": "+70137165537"}
0005435424716	577C91	4023 698011	VYACHESLAV FEDOTOV	{"phone": "+70607911566"}
0005435424717	0F78A7	7865 539781	GALINA GERASIMOVA	{"phone": "+70481390261"}
0005435424718	4EB7CE	5959 539755	SERGEY ABRAMOV	{"email": "abramovs_16111969@postgrespro.ru", "phone": "+70345865651"}
0005435424719	8E97C8	9910 351695	IVAN PAVLOV	{"email": "ivan-pavlov.081965@postgrespro.ru", "phone": "+70257447128"}
0005435424720	8E97C8	4274 497088	SERGEY VASILEV	{"email": "s.vasilev-1977@postgrespro.ru", "phone": "+70901967381"}
0005435424721	A67D9B	4618 649547	ILYA VOLKOV	{"email": "volkov.ilya.111974@postgrespro.ru", "phone": "+70654462398"}
0005435424722	183C2C	5469 298237	IRINA SAVELEVA	{"phone": "+70875548327"}
0005435424723	81A9C0	0096 391676	MARIYA KUZMINA	{"phone": "+70548491065"}
0005435424724	81A9C0	3537 670364	PAVEL MARTYNOV	{"phone": "+70649211605"}
0005435424725	DC4DCF	0366 916657	KONSTANTIN NIKOLAEV	{"email": "knikolaev_121981@postgrespro.ru", "phone": "+70861992269"}
0005435424726	E4639C	6560 136818	MARIYA IVANOVA	{"email": "ivanovam_11091979@postgrespro.ru", "phone": "+70199321557"}
0005435424727	44B26B	3486 927286	NATALYA KUZMINA	{"phone": "+70724042059"}
0005435424728	473AA5	5037 487231	YULIYA POPOVA	{"phone": "+70506521183"}
0005435424729	BC2F19	4270 592861	VITALIY SOROKIN	{"email": "vitaliy-sorokin-011977@postgrespro.ru", "phone": "+70712183282"}
0005435424730	BC2F19	7844 569926	OLGA TIKHONOVA	{"phone": "+70640024442"}
0005435424731	BC2F19	7336 634110	PAVEL SOROKIN	{"email": "sorokin_pavel.1967@postgrespro.ru", "phone": "+70132736688"}
0005435424732	4D4DCB	8135 258606	VIKTOR IVANOV	{"phone": "+70847882896"}
0005435424733	049831	7662 586033	LIDIYA DAVYDOVA	{"phone": "+70073112846"}
0005435424734	EFE131	1893 426283	SERAFIMA ISAEVA	{"email": "serafima_isaeva1986@postgrespro.ru", "phone": "+70146126635"}
0005435424735	EFE131	4329 309587	VALERIY ZHUKOV	{"phone": "+70833816160"}
0005435424736	D51C5C	1456 635330	EVGENIYA POLYAKOVA	{"email": "e_polyakova-29051968@postgrespro.ru", "phone": "+70362698807"}
0005435424737	BE1DAF	9145 676075	GALINA NOVIKOVA	{"email": "novikova.g18051972@postgrespro.ru", "phone": "+70885899922"}
0005435424738	BE1DAF	8516 075332	YULIANA LEBEDEVA	{"email": "lebedeva-yuliana_111975@postgrespro.ru", "phone": "+70661529821"}
0005435424739	693183	2839 601637	TAMARA ALEKSEEVA	{"email": "talekseeva04061967@postgrespro.ru", "phone": "+70632003218"}
0005435424740	8239A5	6575 681272	PAVEL SOROKIN	{"phone": "+70829512816"}
0005435424741	9C046E	4345 380841	DANIIL VOLKOV	{"phone": "+70337708271"}
0005435424742	3F0A14	0651 219591	LYUDMILA BOGDANOVA	{"email": "lyudmila-bogdanova-02031975@postgrespro.ru", "phone": "+70723279971"}
0005435424743	41D64B	6072 824197	SERGEY ABRAMOV	{"email": "abramovsergey.061961@postgrespro.ru", "phone": "+70055254865"}
0005435424744	41D64B	2243 515653	ANATOLIY BELOV	{"email": "anatoliy.belov-041971@postgrespro.ru", "phone": "+70211116562"}
0005435424745	FA4706	9743 711773	IGOR IVANOV	{"phone": "+70712025604"}
0005435424746	713735	0253 618192	VLADIMIR SIDOROV	{"email": "v-sidorov121958@postgrespro.ru", "phone": "+70759167454"}
0005435424747	713735	8777 028568	LYUBOV VASILEVA	{"email": "l-vasileva_111969@postgrespro.ru", "phone": "+70308509890"}
0005435424748	CFD620	7928 317613	NIKOLAY PETROV	{"email": "petrov_n_23021973@postgrespro.ru", "phone": "+70294364071"}
0005435424749	E339F2	2970 947217	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov.011978@postgrespro.ru", "phone": "+70491746309"}
0005435424750	0CB514	7031 632699	ELVIRA MARTYNOVA	{"email": "martynova-e-121970@postgrespro.ru", "phone": "+70139448332"}
0005435424751	0CB514	5015 652153	DANILA ILIN	{"phone": "+70355836386"}
0005435424752	ABA1C4	4699 612027	TATYANA KONOVALOVA	{"phone": "+70279657153"}
0005435424753	ABA1C4	0741 917127	ELENA SMIRNOVA	{"email": "elena-smirnova.15071962@postgrespro.ru", "phone": "+70381482655"}
0005435424754	ABA1C4	9605 420592	BORIS SOKOLOV	{"phone": "+70800638440"}
0005435424755	ED6743	4328 951425	TATYANA DENISOVA	{"phone": "+70204725609"}
0005435424756	A38D45	9312 768989	DMITRIY FOMIN	{"phone": "+70029966005"}
0005435424757	D319CF	2173 203777	ALEKSANDR KOROLEV	{"email": "aleksandr_korolev_1983@postgrespro.ru", "phone": "+70211340932"}
0005435424758	D319CF	5182 109925	VERA SOROKINA	{"phone": "+70342989201"}
0005435424759	371E44	0896 718393	NINA KONDRATEVA	{"email": "nkondrateva-13011971@postgrespro.ru", "phone": "+70110126784"}
0005435424760	371E44	0152 194567	NIKOLAY SMIRNOV	{"email": "nikolay.smirnov121973@postgrespro.ru", "phone": "+70892501453"}
0005435424761	5B293D	4998 784269	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana1976@postgrespro.ru", "phone": "+70849520527"}
0005435424762	42D7D5	9160 973377	KIRA KOZLOVA	{"email": "kira.kozlova.1970@postgrespro.ru", "phone": "+70447973187"}
0005435424763	E799E9	9374 666028	VLADISLAV IVANOV	{"phone": "+70732389957"}
0005435424764	E799E9	2873 468212	ALEKSANDR SIDOROV	{"email": "aleksandr-sidorov16031973@postgrespro.ru", "phone": "+70216846023"}
0005435424765	E56240	6802 655774	ALEKSANDR DENISOV	{"phone": "+70716739671"}
0005435424766	56D487	0364 549659	NIKOLAY KAZAKOV	{"email": "nikolay_kazakov.1966@postgrespro.ru", "phone": "+70268574279"}
0005435424767	0FEDC1	3824 692227	ALEKSANDR ZHUKOV	{"phone": "+70949749608"}
0005435424768	282068	9236 864112	ELENA MEDVEDEVA	{"phone": "+70516736245"}
0005435424769	1460FE	4736 973644	RUSLAN TIKHONOV	{"phone": "+70917356107"}
0005435424770	507A78	2926 459268	NADEZHDA DMITRIEVA	{"phone": "+70043540258"}
0005435424771	66B0A5	7845 802528	ANNA TROFIMOVA	{"phone": "+70904697615"}
0005435424772	66B0A5	1813 424262	NATALYA KUZMINA	{"email": "kuzmina.n.011979@postgrespro.ru", "phone": "+70332142084"}
0005435424773	10D9EE	3113 065490	DMITRIY KOZLOV	{"email": "kozlov_d051973@postgrespro.ru", "phone": "+70066421786"}
0005435424774	10D9EE	8239 871771	ANTON NIKITIN	{"email": "anton-nikitin.13061976@postgrespro.ru", "phone": "+70695018380"}
0005435424775	10D9EE	3392 484509	TATYANA BORISOVA	{"phone": "+70170493192"}
0005435424776	380250	6217 635843	YULIYA ROMANOVA	{"email": "yuliya_romanova_1982@postgrespro.ru", "phone": "+70242475158"}
0005435424777	2BBF30	5973 662473	NATALYA DAVYDOVA	{"email": "davydovanatalya-021982@postgrespro.ru", "phone": "+70772769322"}
0005435424778	9489D1	5769 433669	NATALYA ABRAMOVA	{"email": "n-abramova.1979@postgrespro.ru", "phone": "+70810106019"}
0005435424779	822C7D	2347 833642	YURIY KUZNECOV	{"phone": "+70232579272"}
0005435424780	45AE95	4437 947227	ALEKSEY SMIRNOV	{"email": "alekseysmirnov1985@postgrespro.ru", "phone": "+70618517864"}
0005435424781	2D37C5	9151 515936	VERA KRASNOVA	{"email": "krasnova_vera_1968@postgrespro.ru", "phone": "+70550463981"}
0005435424782	2D37C5	4937 968177	VLADISLAV STEPANOV	{"phone": "+70527941979"}
0005435424783	ABFCC0	9204 504775	DARYA NAZAROVA	{"phone": "+70112268951"}
0005435424784	EF2745	3295 964963	VASILIY ROMANOV	{"email": "v_romanov.081972@postgrespro.ru", "phone": "+70844448355"}
0005435424785	EF2745	6228 454685	MARIYA BARANOVA	{"phone": "+70187380221"}
0005435424786	EF2745	6949 713234	VALENTINA GORBUNOVA	{"phone": "+70133051953"}
0005435424787	A4F505	6080 249409	IRINA PETROVA	{"email": "petrovairina_23111968@postgrespro.ru", "phone": "+70591228807"}
0005435424788	A4F505	8762 979273	ANNA NIKOLAEVA	{"phone": "+70907408789"}
0005435424789	A4F505	8696 057945	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov.11031976@postgrespro.ru", "phone": "+70931342595"}
0005435424790	21A627	9227 827518	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr31011978@postgrespro.ru", "phone": "+70484632736"}
0005435424791	41C750	9879 849283	NIKOLAY KUZNECOV	{"email": "nkuznecov22081962@postgrespro.ru", "phone": "+70035248358"}
0005435424792	479513	4595 312124	PETR FROLOV	{"phone": "+70320732606"}
0005435424793	C82C69	2335 225309	ELENA SOLOVEVA	{"phone": "+70327374420"}
0005435424794	F4E4F4	8960 885277	PETR ZHUKOV	{"email": "pzhukov.061968@postgrespro.ru", "phone": "+70217931819"}
0005435424795	F10831	3671 220648	MARIYA ABRAMOVA	{"email": "mabramova051982@postgrespro.ru", "phone": "+70807698346"}
0005435424796	669226	9516 038390	VALENTINA GRISHINA	{"email": "grishina_v_061977@postgrespro.ru", "phone": "+70149388126"}
0005435424797	58F641	2339 268483	EVGENIY BELOV	{"email": "evgeniy_belov1972@postgrespro.ru", "phone": "+70903347394"}
0005435424798	690C96	8040 839261	ALEKSANDR MAKAROV	{"phone": "+70880404800"}
0005435424799	90043B	7916 067969	VITALIY POPOV	{"email": "vitaliy.popov.011966@postgrespro.ru", "phone": "+70497569160"}
0005435424800	90043B	8711 567295	TAMARA FROLOVA	{"email": "tamara.frolova-1971@postgrespro.ru", "phone": "+70831415501"}
0005435424801	C82640	6662 439717	MARINA SOKOLOVA	{"phone": "+70151175812"}
0005435424802	498497	5097 998601	SERGEY GRIGOREV	{"email": "grigorev_s091978@postgrespro.ru", "phone": "+70269894239"}
0005435424803	FB09DE	0318 712277	POLINA POPOVA	{"email": "popova-polina-1977@postgrespro.ru", "phone": "+70315672310"}
0005435424804	FB09DE	7944 111375	DARYA SEMENOVA	{"email": "semenova-darya051973@postgrespro.ru", "phone": "+70605135093"}
0005435424805	03464F	5780 186790	ALINA KOMAROVA	{"email": "komarova.alina-1963@postgrespro.ru", "phone": "+70154493277"}
0005435424806	FADB29	6268 644570	SVETLANA POTAPOVA	{"phone": "+70853022328"}
0005435424807	6B1AAB	1505 854630	ANNA MEDVEDEVA	{"phone": "+70625087998"}
0005435424808	6B1AAB	0132 282293	VALENTINA LAZAREVA	{"email": "valentina-lazareva_041974@postgrespro.ru", "phone": "+70252104930"}
0005435424809	69EA77	9329 209413	VYACHESLAV BORISOV	{"phone": "+70034376052"}
0005435424810	7F7425	2678 899773	VALENTIN ZAYCEV	{"email": "zaycev.valentin-01081953@postgrespro.ru", "phone": "+70702029936"}
0005435424811	FD5170	6993 899102	IRINA KULIKOVA	{"email": "kulikova.irina-021969@postgrespro.ru", "phone": "+70232929856"}
0005435424812	FD5170	8761 212178	ALEVTINA NIKITINA	{"email": "alevtinanikitina_121979@postgrespro.ru", "phone": "+70947722391"}
0005435424813	342169	3952 690391	SERGEY RODIONOV	{"phone": "+70990684934"}
0005435424814	5862EA	7005 158687	SERGEY FROLOV	{"phone": "+70482641758"}
0005435424815	A64A78	4408 972396	POLINA KISELEVA	{"email": "p_kiseleva-1969@postgrespro.ru", "phone": "+70117298761"}
0005435424816	A64A78	3456 994237	LARISA BELYAEVA	{"email": "belyaeva.larisa_051971@postgrespro.ru", "phone": "+70070258275"}
0005435424817	F48E55	8511 380070	GULNARA VASILEVA	{"phone": "+70024822641"}
0005435424818	6485B9	0549 779944	TATYANA EGOROVA	{"phone": "+70692114428"}
0005435424819	E5A37A	7811 395310	TATYANA ANISIMOVA	{"phone": "+70750932506"}
0005435424820	12562E	5922 937547	LARISA POTAPOVA	{"phone": "+70082535096"}
0005435424821	503CB9	5301 087453	ALEKSANDRA GAVRILOVA	{"phone": "+70039594492"}
0005435424822	1BDF8A	2164 749296	LEONID ZHURAVLEV	{"email": "zhuravlevl-1963@postgrespro.ru", "phone": "+70968469848"}
0005435424823	1BDF8A	2394 000103	MATRENA MAKAROVA	{"phone": "+70799574747"}
0005435424824	1BDF8A	2882 789536	TAISIYA POLYAKOVA	{"email": "t_polyakova.24031972@postgrespro.ru", "phone": "+70929013817"}
0005435424825	CC3682	0990 260383	YULIYA NAUMOVA	{"phone": "+70098126196"}
0005435424826	CC3682	6658 604444	VIKTOR POPOV	{"email": "viktor.popov02101972@postgrespro.ru", "phone": "+70769092571"}
0005435424827	C8AAF3	7758 498703	ARTUR VOLKOV	{"email": "a_volkov_16041968@postgrespro.ru", "phone": "+70710561178"}
0005435424828	C8AAF3	7705 897308	ANATOLIY BARANOV	{"email": "baranov-anatoliy27041978@postgrespro.ru", "phone": "+70075673278"}
0005435424829	C8AAF3	6370 160605	VASILIY VOLKOV	{"email": "volkov_vasiliy-10091966@postgrespro.ru", "phone": "+70453424099"}
0005435424830	5F1264	9101 600119	LYUDMILA KOMAROVA	{"email": "komarova.l-26081967@postgrespro.ru", "phone": "+70673343444"}
0005435424831	68B43F	3234 327815	IGOR IVANOV	{"phone": "+70697809533"}
0005435424832	8E6618	4318 736783	DMITRIY SOKOLOV	{"email": "dmitriy.sokolov.19031985@postgrespro.ru", "phone": "+70630825905"}
0005435424833	0B9C7B	5518 065382	GRIGORIY VASILEV	{"email": "g.vasilev-121981@postgrespro.ru", "phone": "+70084524202"}
0005435424834	9B6071	1492 107121	ANASTASIYA MALYSHEVA	{"email": "malyshevaa.1975@postgrespro.ru", "phone": "+70670522291"}
0005435424835	860B7B	4727 436611	RAISA KONDRATEVA	{"email": "rkondrateva.1966@postgrespro.ru", "phone": "+70882914359"}
0005435424836	860B7B	7720 504596	YULIYA KUZMINA	{"phone": "+70350527267"}
0005435424837	905AE4	0158 657054	VLADIMIR ALEKSANDROV	{"email": "aleksandrovv23061985@postgrespro.ru", "phone": "+70619645292"}
0005435424838	8F597E	5019 579109	VLADIMIR ZHURAVLEV	{"phone": "+70850624446"}
0005435424839	6C7704	6707 299471	ALEKSEY POPOV	{"phone": "+70224261443"}
0005435424840	A84477	8604 221575	VLADIMIR KAZAKOV	{"phone": "+70242595525"}
0005435424841	A84477	0057 628344	ELIZAVETA KUZNECOVA	{"phone": "+70120353464"}
0005435424842	085BE3	3236 548558	OLEG POPOV	{"phone": "+70875685434"}
0005435424843	48A9A5	2450 395333	ALBINA IVANOVA	{"phone": "+70533126598"}
0005435424844	48A9A5	2235 652876	IGOR FOMIN	{"email": "igor_fomin121969@postgrespro.ru", "phone": "+70644475679"}
0005435424845	48A9A5	9176 399316	OLGA ZAKHAROVA	{"email": "ozakharova26071974@postgrespro.ru", "phone": "+70410421950"}
0005435424846	A1FF2B	7682 808313	ELIZAVETA POTAPOVA	{"phone": "+70733962475"}
0005435424847	FBE816	7038 949275	ALEKSANDRA KARPOVA	{"phone": "+70712577853"}
0005435424848	FBE816	4067 708273	NINA ANDREEVA	{"email": "nandreeva.29091967@postgrespro.ru", "phone": "+70736999403"}
0005435424849	F83C18	2632 533840	NATALYA LAZAREVA	{"phone": "+70496609786"}
0005435424850	F83C18	5654 461186	EVGENIYA BARANOVA	{"phone": "+70307427509"}
0005435424851	DBEBF1	5981 309553	ALEKSEY POPOV	{"email": "a.popov-1982@postgrespro.ru", "phone": "+70371051080"}
0005435424852	69A48A	0083 948596	DMITRIY NIKOLAEV	{"phone": "+70760942065"}
0005435424853	69A48A	9092 152431	NATALYA KUZMINA	{"email": "kuzminanatalya_08071974@postgrespro.ru", "phone": "+70241041275"}
0005435424854	61534E	8231 205398	OLGA SOKOLOVA	{"email": "sokolovao.04081980@postgrespro.ru", "phone": "+70371963980"}
0005435424855	61534E	6778 789172	VIKTORIYA CHERNOVA	{"email": "viktoriya.chernova1988@postgrespro.ru", "phone": "+70874506518"}
0005435424856	61534E	2135 317691	ANTON MARTYNOV	{"email": "martynov.a-081975@postgrespro.ru", "phone": "+70495379924"}
0005435424857	680F10	4655 362288	OLGA NIKITINA	{"phone": "+70755319530"}
0005435424858	CD10C4	4730 171273	IRINA IVANOVA	{"email": "i_ivanova25051972@postgrespro.ru", "phone": "+70636912224"}
0005435424859	B5988B	3040 727654	TATYANA ILINA	{"email": "ilina_t.1964@postgrespro.ru", "phone": "+70052437982"}
0005435424860	2958C0	3584 896707	IRINA GORBUNOVA	{"phone": "+70449260923"}
0005435424861	A040B3	9213 160670	DMITRIY SOLOVEV	{"email": "dmitriysolovev.1977@postgrespro.ru", "phone": "+70899705186"}
0005435424862	5FD386	3917 502527	ARTEM PAVLOV	{"email": "artem_pavlov-29091969@postgrespro.ru", "phone": "+70222899708"}
0005435424863	05BDD6	3199 137389	LYUBOV TROFIMOVA	{"email": "trofimova_l_011965@postgrespro.ru", "phone": "+70621817508"}
0005435424864	05BDD6	8362 030689	ALEKSANDR SOLOVEV	{"email": "solovev.aleksandr-1966@postgrespro.ru", "phone": "+70339489991"}
0005435424865	05BDD6	5044 057963	VASILIY MIRONOV	{"phone": "+70725859362"}
0005435424866	7C6951	1964 826610	INNA MOISEEVA	{"email": "moiseeva_i_111968@postgrespro.ru", "phone": "+70789183870"}
0005435424867	7C6951	6916 246408	SERGEY KUZNECOV	{"email": "s.kuznecov-19091970@postgrespro.ru", "phone": "+70701093079"}
0005435424868	1A0256	0439 940244	VALERIY ZHURAVLEV	{"email": "zhuravlev_valeriy_1967@postgrespro.ru", "phone": "+70741678586"}
0005435424869	1A0256	8683 840338	SVETLANA NOVIKOVA	{"email": "s.novikova.1970@postgrespro.ru", "phone": "+70463946332"}
0005435424870	7445B1	0787 597625	KSENIYA LUKYANOVA	{"phone": "+70602263398"}
0005435424871	E1DFDE	5830 225093	LARISA STEPANOVA	{"email": "stepanova_larisa_1976@postgrespro.ru", "phone": "+70869816498"}
0005435424872	AA0C32	1623 819002	LYUDMILA ANDREEVA	{"email": "andreeva.lyudmila_1978@postgrespro.ru", "phone": "+70386059521"}
0005435425052	4605D6	6479 769577	NATALIYA KONOVALOVA	{"phone": "+70618216328"}
0005435424873	AA0C32	7574 547883	ELENA VOLKOVA	{"email": "evolkova.08061972@postgrespro.ru", "phone": "+70967703169"}
0005435424874	8C5CDB	2090 664221	EVGENIY NIKITIN	{"email": "evgeniy_nikitin-091962@postgrespro.ru", "phone": "+70509316890"}
0005435424875	8C5CDB	9034 385705	KHALIDA DANILOVA	{"phone": "+70867540279"}
0005435424876	9F4962	2520 480469	IRINA LOGINOVA	{"phone": "+70815990785"}
0005435424877	3561DA	6790 203703	DENIS EGOROV	{"email": "egorov_d_051963@postgrespro.ru", "phone": "+70718129671"}
0005435424878	9127A9	4555 306744	GALINA TITOVA	{"phone": "+70997285719"}
0005435424879	6C2C71	0490 867429	VLADIMIR NIKITIN	{"email": "nikitinv-1968@postgrespro.ru", "phone": "+70349999527"}
0005435424880	2F78EF	2578 513950	OLGA NOVIKOVA	{"email": "onovikova-09031967@postgrespro.ru", "phone": "+70105332203"}
0005435424881	BD7274	9780 588549	DENIS IVANOV	{"phone": "+70536067705"}
0005435424882	5CA9A2	8082 286692	LIDIYA KUZNECOVA	{"phone": "+70846539719"}
0005435424883	E9DBBC	4086 028056	SVETLANA PETROVA	{"phone": "+70159675511"}
0005435424884	E9DBBC	1637 880385	PETR NOVIKOV	{"phone": "+70906973339"}
0005435424885	E9DBBC	0881 468134	ALEKSEY DENISOV	{"email": "alekseydenisov_1980@postgrespro.ru", "phone": "+70655380633"}
0005435424886	947412	0894 600557	VLADIMIR IVANOV	{"phone": "+70884230706"}
0005435424887	246330	6327 693805	DMITRIY ANDREEV	{"email": "d-andreev-091976@postgrespro.ru", "phone": "+70481814931"}
0005435424888	1B9E8C	3346 583722	MARINA RODIONOVA	{"email": "rodionova.marina-1978@postgrespro.ru", "phone": "+70989628527"}
0005435424889	1B9E8C	7104 692973	TATYANA NAZAROVA	{"email": "t_nazarova-10111964@postgrespro.ru", "phone": "+70064255580"}
0005435424890	8C2289	5647 359586	OLEG NIKITIN	{"email": "nikitin.oleg-101975@postgrespro.ru", "phone": "+70023238587"}
0005435424891	A1A623	1432 213589	VLADIMIR VOLKOV	{"email": "vladimir_volkov.051973@postgrespro.ru", "phone": "+70508410251"}
0005435424892	A1A623	1181 100836	ALEKSANDR EGOROV	{"phone": "+70539826316"}
0005435424893	AE3C2D	6703 037184	ANASTASIYA PETROVA	{"email": "petrovaa.041982@postgrespro.ru", "phone": "+70068531112"}
0005435424894	4F45BC	4384 051469	NINA IVANOVA	{"email": "nina_ivanova051975@postgrespro.ru", "phone": "+70116451563"}
0005435424895	D3D55C	6335 669923	ELENA VOLKOVA	{"email": "volkovaelena-061967@postgrespro.ru", "phone": "+70999964918"}
0005435424896	0E681B	9406 466278	LYUBOV MAKAROVA	{"phone": "+70868071675"}
0005435424897	0E681B	9129 547768	ANTONINA IVANOVA	{"phone": "+70763184679"}
0005435424898	0E681B	1912 635373	ALEKSANDR NAZAROV	{"phone": "+70045171376"}
0005435424899	0FD6F1	9747 542481	EKATERINA KONDRATEVA	{"email": "kondrateva-e121974@postgrespro.ru", "phone": "+70492345903"}
0005435424900	1F27DD	8616 804547	LILIYA NIKOLAEVA	{"email": "nikolaeva-l01071982@postgrespro.ru", "phone": "+70285705707"}
0005435424901	88EC03	3326 193965	ALEKSANDR ORLOV	{"phone": "+70213807842"}
0005435424902	25D5E3	4128 538338	SERGEY GORBUNOV	{"phone": "+70722243073"}
0005435424903	25D5E3	4127 232410	VALENTINA PETROVA	{"phone": "+70964498520"}
0005435424904	53F47E	4180 509523	ANASTASIYA KARPOVA	{"email": "akarpova-1975@postgrespro.ru", "phone": "+70587467046"}
0005435424905	50C538	3592 886992	VALENTINA KUZNECOVA	{"email": "kuznecova.v-25031971@postgrespro.ru", "phone": "+70577427290"}
0005435424906	50C538	1458 732467	NINA KULIKOVA	{"email": "n.kulikova-121972@postgrespro.ru", "phone": "+70310450305"}
0005435424907	A85389	7542 973536	ANATOLIY NAUMOV	{"phone": "+70619736881"}
0005435424908	1277D5	8836 889128	ROMAN POPOV	{"phone": "+70794334012"}
0005435424909	1277D5	4717 001001	IVAN KUZNECOV	{"phone": "+70492790312"}
0005435424910	1277D5	7215 202727	LYUBOV SMIRNOVA	{"email": "lyubov_smirnova.1975@postgrespro.ru", "phone": "+70449751086"}
0005435424911	46D3C2	1873 887843	TATYANA IVANOVA	{"phone": "+70952434417"}
0005435424912	46D3C2	7255 572867	ANDREY TARASOV	{"phone": "+70133009074"}
0005435424913	4EBEA1	6690 763845	ILYA AFANASEV	{"email": "ilyaafanasev.1969@postgrespro.ru", "phone": "+70587773364"}
0005435424914	ADAA14	5706 668032	MARINA MARTYNOVA	{"email": "martynova.marina-061979@postgrespro.ru", "phone": "+70714624944"}
0005435424915	ADAA14	0063 195885	GALINA SOLOVEVA	{"phone": "+70122912898"}
0005435424916	ADAA14	8547 432325	NIKOLAY SIDOROV	{"phone": "+70246937885"}
0005435424917	32467D	6311 259448	YULIYA KUZNECOVA	{"email": "yuliya-kuznecova_061976@postgrespro.ru", "phone": "+70887333362"}
0005435424918	32467D	8091 094519	NIKOLAY NAZAROV	{"phone": "+70155067560"}
0005435424919	1C0F34	7710 338943	ROMAN SEMENOV	{"phone": "+70264967735"}
0005435424920	035EFF	1386 769114	MAKSIM CHERNOV	{"phone": "+70351379480"}
0005435424921	421E48	5885 768761	ALEKSANDR ALEKSANDROV	{"phone": "+70951460569"}
0005435424922	6AB3BD	7698 115536	ANDREY GUSEV	{"email": "gusev.andrey031964@postgrespro.ru", "phone": "+70348535377"}
0005435424923	6AB3BD	7962 114347	DINA KONOVALOVA	{"phone": "+70604523416"}
0005435424924	22ABCC	9362 404870	YURIY VASILEV	{"email": "vasilevy101975@postgrespro.ru", "phone": "+70822106288"}
0005435424925	0035CC	4718 238611	VASILIY MAKAROV	{"email": "makarovv.041969@postgrespro.ru", "phone": "+70901593990"}
0005435424926	2C1441	1973 805945	IRINA IVANOVA	{"email": "ivanova-i.1993@postgrespro.ru", "phone": "+70865039868"}
0005435424927	A2E999	7715 441836	VALERIY ZHURAVLEV	{"email": "vzhuravlev.091970@postgrespro.ru", "phone": "+70792093508"}
0005435424928	76D9B4	0214 925387	LYUBOV BELYAEVA	{"email": "lyubovbelyaeva.1972@postgrespro.ru", "phone": "+70974893034"}
0005435424929	6E6A54	3454 298349	VERONIKA DAVYDOVA	{"email": "davydova.veronika-1967@postgrespro.ru", "phone": "+70352238471"}
0005435424930	3C4171	4872 738916	MARIYA MELNIKOVA	{"email": "melnikova.mariya-30041976@postgrespro.ru", "phone": "+70876039156"}
0005435424931	03995D	8096 286850	VALENTINA ZAYCEVA	{"email": "zayceva_valentina-1969@postgrespro.ru", "phone": "+70941117454"}
0005435424932	03995D	0389 252497	VALENTINA KRASNOVA	{"phone": "+70766150604"}
0005435424933	2D23EF	3520 663086	NINA ZAKHAROVA	{"email": "zakharovan.27121972@postgrespro.ru", "phone": "+70209087880"}
0005435424934	2D23EF	1402 220687	EKATERINA VLASOVA	{"email": "e.vlasova_1984@postgrespro.ru", "phone": "+70018516973"}
0005435424935	C30D67	7738 899282	ALEKSEY MAKAROV	{"email": "aleksey_makarov.1985@postgrespro.ru", "phone": "+70549209866"}
0005435424936	C30D67	7731 941277	YURIY KUZNECOV	{"email": "y.kuznecov10111980@postgrespro.ru", "phone": "+70805010975"}
0005435424937	161161	7604 174375	NIKOLAY VASILEV	{"email": "vasilevn_24011967@postgrespro.ru", "phone": "+70401966786"}
0005435424938	161161	5978 953084	NELLI AKIMOVA	{"phone": "+70178322044"}
0005435424939	9ED5E6	9981 956351	SANIYA VASILEVA	{"phone": "+70429736295"}
0005435424940	9449F7	1490 848872	DMITRIY ZAYCEV	{"phone": "+70919424073"}
0005435424941	9449F7	2301 782957	DARYA KULIKOVA	{"phone": "+70184300316"}
0005435424942	24B56D	6709 726739	MARIYA KUZMINA	{"email": "kuzmina-m1971@postgrespro.ru", "phone": "+70105728000"}
0005435424943	24B56D	9496 075786	NADEZHDA BORISOVA	{"phone": "+70675144194"}
0005435424944	8D6A5A	6032 715084	VALENTINA MATVEEVA	{"email": "v_matveeva.071971@postgrespro.ru", "phone": "+70584598500"}
0005435424945	8D6A5A	2837 865373	VASILISA CHERNOVA	{"email": "v_chernova_22061971@postgrespro.ru", "phone": "+70559765793"}
0005435424946	79BE67	5353 837691	BORIS ALEKSANDROV	{"phone": "+70236841492"}
0005435424947	79BE67	1610 855402	KSENIYA NAUMOVA	{"phone": "+70761948692"}
0005435424948	F557AE	8182 517129	ALESYA ISAEVA	{"phone": "+70600038895"}
0005435424949	5BD673	9169 860323	LYUBOV ZHURAVLEVA	{"phone": "+70325966782"}
0005435424950	5BD673	8022 895289	EVGENIY NIKITIN	{"phone": "+70732975675"}
0005435424951	D426DB	3375 593326	SERGEY ZAKHAROV	{"email": "zakharov.s.101965@postgrespro.ru", "phone": "+70656558830"}
0005435424952	D426DB	4714 065783	EKATERINA KUZNECOVA	{"email": "ekuznecova-30031976@postgrespro.ru", "phone": "+70450763158"}
0005435424953	A8ACC4	9780 269482	TATYANA AFANASEVA	{"email": "tatyana_afanaseva.011973@postgrespro.ru", "phone": "+70936468757"}
0005435424954	04277E	8034 951934	NONNA MOROZOVA	{"email": "morozovan_1964@postgrespro.ru", "phone": "+70144746308"}
0005435424955	2D790F	8753 873228	ALEKSANDR NIKITIN	{"email": "aleksandr.nikitin.031970@postgrespro.ru", "phone": "+70639503673"}
0005435424956	6C54D5	6048 027626	EVGENIYA KOVALEVA	{"email": "kovaleva-evgeniya27081968@postgrespro.ru", "phone": "+70223331842"}
0005435424957	6C54D5	5867 416833	ALEKSANDR FROLOV	{"phone": "+70545578150"}
0005435424958	2D736B	2210 081246	NATALIYA AKIMOVA	{"phone": "+70592833747"}
0005435424959	2D736B	0321 036444	ALEKSANDR FILIPPOV	{"email": "filippovaleksandr.081977@postgrespro.ru", "phone": "+70098047035"}
0005435424960	2D736B	2206 276095	SVETLANA MARTYNOVA	{"email": "martynovas.30091969@postgrespro.ru", "phone": "+70883144968"}
0005435424961	8DE591	6479 622702	ANZHELA ZAKHAROVA	{"email": "a.zakharova.1963@postgrespro.ru", "phone": "+70591315624"}
0005435424962	DA52D2	0895 324778	VIKTOR KOZLOV	{"email": "kozlov.viktor-071984@postgrespro.ru", "phone": "+70103893777"}
0005435424963	8081D8	7142 553532	VALENTINA ZAYCEVA	{"phone": "+70903363145"}
0005435424964	B99454	0061 160098	ALEKSANDR MIRONOV	{"email": "aleksandr-mironov1975@postgrespro.ru", "phone": "+70624638807"}
0005435424965	FCCBE4	7229 564947	DMITRIY MOROZOV	{"email": "morozov_d.081973@postgrespro.ru", "phone": "+70685028815"}
0005435424966	B86985	9125 938833	EGOR NAZAROV	{"phone": "+70937478073"}
0005435424967	F5746A	5129 680904	ARMEN MIRONOV	{"phone": "+70959213373"}
0005435424968	F0C01A	5215 169678	TATYANA KUZNECOVA	{"phone": "+70576313687"}
0005435424969	9CBF56	2070 269549	DMITRIY BELOV	{"email": "belovd061971@postgrespro.ru", "phone": "+70355440683"}
0005435424970	9CBF56	6729 484112	YURIY KRASNOV	{"phone": "+70436954461"}
0005435424971	A3F60F	5621 536650	KLAVDIYA KARPOVA	{"phone": "+70621753095"}
0005435424972	7DAF0C	0146 100242	NATALYA SAVELEVA	{"email": "saveleva-n_08011963@postgrespro.ru", "phone": "+70124167786"}
0005435424973	3819AC	3500 205082	ILYA AFANASEV	{"email": "afanasevilya_011966@postgrespro.ru", "phone": "+70974583195"}
0005435424974	FBD2AF	8733 375044	IRINA FILIPPOVA	{"phone": "+70368043398"}
0005435424975	FBD2AF	5621 260165	EGOR KUZNECOV	{"phone": "+70336793879"}
0005435424976	0B4705	2106 040595	ALINA MAKSIMOVA	{"phone": "+70416576980"}
0005435424977	673C55	7517 946599	ALBINA KONOVALOVA	{"email": "a.konovalova1967@postgrespro.ru", "phone": "+70049424097"}
0005435424978	4E671C	1902 129953	OLGA MASLOVA	{"phone": "+70682021976"}
0005435424979	936EFC	3562 455305	SERGEY FILIPPOV	{"email": "sergey-filippov_101971@postgrespro.ru", "phone": "+70214303077"}
0005435424980	EB2304	2368 928750	TATYANA KUZNECOVA	{"email": "tatyana_kuznecova_1977@postgrespro.ru", "phone": "+70489602463"}
0005435424981	8402C1	5811 782027	LIDIYA TIMOFEEVA	{"email": "l.timofeeva.21101987@postgrespro.ru", "phone": "+70425312049"}
0005435424982	2CFE12	6298 916608	VIKTORIYA BORISOVA	{"email": "v_borisova-26031977@postgrespro.ru", "phone": "+70084459420"}
0005435424983	1A39EF	8936 798752	NADEZHDA KISELEVA	{"email": "kiseleva_nadezhda_101966@postgrespro.ru", "phone": "+70799192114"}
0005435424984	320969	1044 227451	SVETLANA SERGEEVA	{"email": "svetlana-sergeeva.1969@postgrespro.ru", "phone": "+70932119179"}
0005435424985	44E8F8	1419 997952	KONSTANTIN DAVYDOV	{"phone": "+70733955454"}
0005435424986	F60041	0527 434215	ROMAN KULIKOV	{"phone": "+70208178852"}
0005435424987	D3AC54	1970 530470	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey-1978@postgrespro.ru", "phone": "+70233525123"}
0005435424988	D3AC54	1495 795820	GALINA IVANOVA	{"phone": "+70251732761"}
0005435424989	449F09	8081 442884	ANNA MAKSIMOVA	{"email": "a.maksimova.081968@postgrespro.ru", "phone": "+70702256340"}
0005435424990	3BFB3B	5026 756702	IGOR ZAYCEV	{"phone": "+70598107109"}
0005435424991	61BBCF	8122 149282	DMITRIY PAVLOV	{"email": "dmitriy-pavlov27091975@postgrespro.ru", "phone": "+70970852526"}
0005435424992	888879	3608 015855	DENIS KARPOV	{"email": "karpov-denis.031973@postgrespro.ru", "phone": "+70184598171"}
0005435424993	888879	5728 004307	IRINA MIRONOVA	{"phone": "+70196248692"}
0005435424994	E85EBD	7756 895523	RADMIR KULIKOV	{"phone": "+70928701652"}
0005435424995	EFAD40	4929 076804	LYUBOV AKIMOVA	{"email": "lyubov-akimova_101967@postgrespro.ru", "phone": "+70709574541"}
0005435424996	EFAD40	5893 469447	ALEKSANDR BORISOV	{"email": "borisov.a.30091972@postgrespro.ru", "phone": "+70592214901"}
0005435424997	FDEC7C	4413 500379	KONSTANTIN MIRONOV	{"email": "mironov.konstantin-101970@postgrespro.ru", "phone": "+70506349022"}
0005435424998	2304AC	9267 337838	VALERIYA FILIPPOVA	{"phone": "+70347077388"}
0005435424999	B937A1	3651 777933	ALEKSEY AFANASEV	{"email": "a-afanasev1965@postgrespro.ru", "phone": "+70412598171"}
0005435425000	B937A1	6804 290656	ANASTASIYA FOMINA	{"phone": "+70093412678"}
0005435425001	112729	4470 457173	OLGA ILINA	{"email": "olga-ilina.1978@postgrespro.ru", "phone": "+70236019818"}
0005435425002	29CF9D	7494 478400	YULIYA ABRAMOVA	{"email": "abramova_yuliya.1970@postgrespro.ru", "phone": "+70137662988"}
0005435425003	2DCD36	3564 835437	LYUDMILA PETROVA	{"phone": "+70969937289"}
0005435425004	70E73B	5984 426682	ROMAN AFANASEV	{"phone": "+70093191734"}
0005435425005	70E73B	2225 109877	VITALIY ABRAMOV	{"phone": "+70093840385"}
0005435425006	8CD32E	7498 502753	OLESYA SMIRNOVA	{"email": "smirnovaolesya051971@postgrespro.ru", "phone": "+70140782049"}
0005435425007	E6A676	4467 860776	ANASTASIYA DANILOVA	{"phone": "+70593296823"}
0005435425008	8F3BA1	9489 497436	IVAN ZAKHAROV	{"email": "izakharov-071964@postgrespro.ru", "phone": "+70746633840"}
0005435425009	8F3BA1	7091 297789	MARINA MATVEEVA	{"email": "matveeva_marina-1971@postgrespro.ru", "phone": "+70087412360"}
0005435425010	133927	2311 464848	RUSLAN ANDREEV	{"email": "r_andreev.1965@postgrespro.ru", "phone": "+70650632613"}
0005435425011	EF5220	3079 919968	VITALIY SERGEEV	{"email": "v-sergeev121979@postgrespro.ru", "phone": "+70213112106"}
0005435425012	C0BA5A	2960 376845	ELENA ZHURAVLEVA	{"email": "elenazhuravleva-25091968@postgrespro.ru", "phone": "+70145759505"}
0005435425013	8EAC43	9639 884626	OKSANA SERGEEVA	{"phone": "+70574535504"}
0005435425014	B34539	4854 163681	ELENA KISELEVA	{"phone": "+70758555330"}
0005435425015	B34539	5415 211132	ANFISA ROMANOVA	{"email": "romanovaanfisa1977@postgrespro.ru", "phone": "+70394009184"}
0005435425016	7FA3C5	3071 957839	OLGA VOLKOVA	{"email": "volkovaolga1964@postgrespro.ru", "phone": "+70624299428"}
0005435425017	7FA3C5	2933 410371	MARINA MAKAROVA	{"email": "makarova.marina1983@postgrespro.ru", "phone": "+70867336501"}
0005435425018	3FD3CF	1344 888587	SVETLANA NESTEROVA	{"phone": "+70530178482"}
0005435425019	B630E3	4295 622063	ALEKSEY BARANOV	{"email": "baranov.aleksey1974@postgrespro.ru", "phone": "+70728999573"}
0005435425020	8282F6	4586 726833	TATYANA PETROVA	{"phone": "+70628655235"}
0005435425021	1410BF	2481 137725	VLADIMIR MEDVEDEV	{"email": "medvedev-v1963@postgrespro.ru", "phone": "+70286138485"}
0005435425022	1410BF	6463 811659	KSENIYA NIKIFOROVA	{"phone": "+70430767149"}
0005435425023	D86522	4221 046698	ALI KOROLEV	{"phone": "+70456478798"}
0005435425024	7D7C56	3378 593836	NATALYA OSIPOVA	{"phone": "+70361548236"}
0005435425025	7D7C56	4759 860468	ALEKSANDR BORISOV	{"phone": "+70845353223"}
0005435425026	73867D	0671 569026	VALENTINA ANTONOVA	{"phone": "+70231673367"}
0005435425027	73867D	2046 749136	ALBERT DAVYDOV	{"email": "davydov-albert.18071980@postgrespro.ru", "phone": "+70159612038"}
0005435425028	2FE1C0	5648 158462	MARINA MIRONOVA	{"phone": "+70964277908"}
0005435425029	FB5997	0543 380635	EVGENIY MARTYNOV	{"email": "martynov_e.1971@postgrespro.ru", "phone": "+70001051947"}
0005435425030	E910CE	1040 519995	ALEKSEY VLASOV	{"email": "vlasov.a23081977@postgrespro.ru", "phone": "+70091896972"}
0005435425031	E910CE	0048 951679	ALEKSANDR FEDOROV	{"email": "fedorov-a-24121968@postgrespro.ru", "phone": "+70690154805"}
0005435425032	E910CE	6255 635398	ALENA KRASNOVA	{"email": "alena_krasnova_091980@postgrespro.ru", "phone": "+70532468296"}
0005435425033	C55508	1203 805235	SOFYA ZOTOVA	{"phone": "+70807835554"}
0005435425034	7C8134	7433 585927	RAFAIL NAUMOV	{"phone": "+70183987491"}
0005435425035	7C8134	6505 031312	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev_061968@postgrespro.ru", "phone": "+70561849525"}
0005435425036	EAE0D9	3828 845726	VALENTINA IVANOVA	{"phone": "+70149022732"}
0005435425037	58DCB2	7386 664931	ALINA NOVIKOVA	{"phone": "+70863131305"}
0005435425038	3A2F98	8011 210714	KRISTINA ALEKSANDROVA	{"email": "aleksandrova_k26091982@postgrespro.ru", "phone": "+70683476307"}
0005435425039	209A92	8755 718478	TAMARA ZAKHAROVA	{"email": "zakharova.tamara.1981@postgrespro.ru", "phone": "+70406723198"}
0005435425040	209A92	2164 544498	ANNA VASILEVA	{"email": "vasilevaa1971@postgrespro.ru", "phone": "+70742251597"}
0005435425041	648CA8	7104 531305	MAKSIM SOLOVEV	{"phone": "+70657710882"}
0005435425042	D21F87	4135 859436	GALINA ALEKSANDROVA	{"phone": "+70328733227"}
0005435425043	B70586	8791 886046	ANGELINA KONDRATEVA	{"email": "a-kondrateva-071963@postgrespro.ru", "phone": "+70063517486"}
0005435425044	B70586	5368 180677	SERGEY POPOV	{"phone": "+70919185794"}
0005435425045	CE4AB4	1066 673746	OLGA KALININA	{"email": "kalinina_olga.29061972@postgrespro.ru", "phone": "+70584623481"}
0005435425046	3A4D25	7009 572476	SVETLANA GAVRILOVA	{"email": "gavrilova_svetlana.15071977@postgrespro.ru", "phone": "+70680512337"}
0005435425047	D09B4F	8347 978742	STANISLAV DAVYDOV	{"phone": "+70876804768"}
0005435425048	9449FC	7578 043670	ALEKSANDRA POTAPOVA	{"email": "potapova-aleksandra1974@postgrespro.ru", "phone": "+70713701220"}
0005435425049	9449FC	9797 436976	MIKHAIL PETROV	{"phone": "+70063007861"}
0005435425050	C877CF	9035 373454	ANFISA MIKHAYLOVA	{"phone": "+70251072057"}
0005435425051	A666B6	9814 895536	OLEG GERASIMOV	{"email": "gerasimov.o.1968@postgrespro.ru", "phone": "+70594551883"}
0005435425053	4605D6	5330 636115	ILYA OSIPOV	{"phone": "+70764686424"}
0005435425054	DB5146	8121 028837	SVETLANA KOVALEVA	{"phone": "+70730792892"}
0005435425055	63C639	7888 029667	ALEKSANDRA TITOVA	{"email": "titova_aleksandra041968@postgrespro.ru", "phone": "+70199176416"}
0005435425056	20FF81	2115 735990	IRINA MIRONOVA	{"email": "irina_mironova06061978@postgrespro.ru", "phone": "+70609426752"}
0005435425057	949187	3254 714074	PAVEL OSIPOV	{"email": "osipovp.011977@postgrespro.ru", "phone": "+70924788930"}
0005435425058	DBEDD3	4335 205084	DMITRIY SOKOLOV	{"email": "sokolov_d07091959@postgrespro.ru", "phone": "+70992078539"}
0005435425059	2EFA87	5416 996250	TAMARA EGOROVA	{"email": "t-egorova-23061971@postgrespro.ru", "phone": "+70486122704"}
0005435425060	699252	9276 020283	EKATERINA NIKOLAEVA	{"email": "nikolaeva_e111967@postgrespro.ru", "phone": "+70524508934"}
0005435425061	0E95DF	7708 107192	TATYANA ROMANOVA	{"phone": "+70284318921"}
0005435425062	0E95DF	2765 389047	ROZA SMIRNOVA	{"phone": "+70938736515"}
0005435425063	87FD01	1130 470864	RINAT ABRAMOV	{"email": "r-abramov1975@postgrespro.ru", "phone": "+70006979332"}
0005435425064	59AFBA	8173 377822	DMITRIY TARASOV	{"phone": "+70942871650"}
0005435425065	AD5A51	0369 554809	OLGA BORISOVA	{"email": "olga.borisova_24031965@postgrespro.ru", "phone": "+70011429256"}
0005435425066	F6FA22	4740 652815	SVETLANA LAZAREVA	{"email": "s.lazareva1970@postgrespro.ru", "phone": "+70835370234"}
0005435425067	91845F	1253 333850	FAINA CHERNOVA	{"email": "f_chernova.23091974@postgrespro.ru", "phone": "+70433435307"}
0005435425068	6EC91A	6970 683929	GALINA AKIMOVA	{"phone": "+70234977038"}
0005435425069	EB1FB6	4836 744261	TATYANA DMITRIEVA	{"phone": "+70519661280"}
0005435425070	EB1FB6	9371 915317	VALENTIN ILIN	{"email": "valentin.ilin-21081962@postgrespro.ru", "phone": "+70370781088"}
0005435425071	69B8DE	8187 858077	EVGENIY VASILEV	{"phone": "+70389724439"}
0005435425072	B53E40	5740 919257	NATALYA GUSEVA	{"phone": "+70401312597"}
0005435425073	B53E40	2022 445070	OLGA MOISEEVA	{"email": "moiseeva-olga_05081983@postgrespro.ru", "phone": "+70562235097"}
0005435425074	3030AE	9481 060765	LYUDMILA SOKOLOVA	{"phone": "+70833340692"}
0005435425075	60474D	6759 811743	ELENA VOROBEVA	{"phone": "+70498218466"}
0005435425076	60474D	6446 469412	GRIGORIY PAVLOV	{"phone": "+70585218784"}
0005435425077	37B4DF	2702 203504	VITALIY KISELEV	{"email": "kiselevvitaliy-011973@postgrespro.ru", "phone": "+70081836037"}
0005435425078	AA22D9	7633 952967	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr.25021967@postgrespro.ru", "phone": "+70138166353"}
0005435425079	9BB120	2141 476521	SERGEY TIMOFEEV	{"phone": "+70209080461"}
0005435425080	F02E7C	1357 273959	ROMAN FILIPPOV	{"phone": "+70514516925"}
0005435425081	F02E7C	9582 480529	MARIYA KOROLEVA	{"email": "koroleva-m16111968@postgrespro.ru", "phone": "+70608645389"}
0005435425082	9B9B8D	4729 967565	ALBINA ALEKSANDROVA	{"email": "aaleksandrova.18031965@postgrespro.ru", "phone": "+70408115502"}
0005435425083	5D7C06	1131 235617	ANNA FEDOROVA	{"phone": "+70204825251"}
0005435425084	47C12C	9879 680932	DANIL POPOV	{"phone": "+70423401501"}
0005435425085	47C12C	9088 946588	VLADIMIR IVANOV	{"phone": "+70192452588"}
0005435425086	47C12C	1170 849230	ILMIRA FEDOROVA	{"email": "i_fedorova-061970@postgrespro.ru", "phone": "+70732156852"}
0005435425087	56DF05	0743 359365	IVAN KUZNECOV	{"email": "ivan_kuznecov_011974@postgrespro.ru", "phone": "+70652175154"}
0005435425088	020419	0233 294459	ARTEM MATVEEV	{"email": "artem.matveev_111984@postgrespro.ru", "phone": "+70843583122"}
0005435425089	020419	0316 886738	VIKTOR SMIRNOV	{"phone": "+70875899575"}
0005435425090	CB4EB1	9187 818821	FEDOR CHERNOV	{"phone": "+70196849410"}
0005435425091	CB4EB1	7701 000630	SERGEY BORISOV	{"email": "sergey_borisov1976@postgrespro.ru", "phone": "+70761776308"}
0005435425092	6D3637	1551 041972	EKATERINA EFIMOVA	{"email": "e.efimova1968@postgrespro.ru", "phone": "+70560806067"}
0005435425093	BD19AB	0506 598498	SVETLANA VASILEVA	{"phone": "+70824726747"}
0005435425094	127A49	3494 072886	OLESYA PAVLOVA	{"email": "o_pavlova101970@postgrespro.ru", "phone": "+70659899950"}
0005435425095	9B0178	2390 860443	ALEKSANDR FOMIN	{"email": "fomin-aleksandr-27031970@postgrespro.ru", "phone": "+70696921863"}
0005435425096	9B0178	0877 880823	YURIY ORLOV	{"phone": "+70531341130"}
0005435425097	9B0178	3107 154200	ANTON PETROV	{"email": "petrov_a.031976@postgrespro.ru", "phone": "+70510091774"}
0005435425098	8DB264	9987 358652	ELENA KOMAROVA	{"email": "komarovaelena.28061973@postgrespro.ru", "phone": "+70682635876"}
0005435425099	49D35B	9377 277891	ELENA POPOVA	{"email": "popova_e.041973@postgrespro.ru", "phone": "+70964396728"}
0005435425100	157922	7491 376255	ANNA DAVYDOVA	{"email": "anna_davydova.101989@postgrespro.ru", "phone": "+70372189627"}
0005435425101	24E5CF	8066 291426	LIDIYA KISELEVA	{"phone": "+70352838112"}
0005435425102	34D472	2743 218076	OLGA BORISOVA	{"email": "borisovao-18081972@postgrespro.ru", "phone": "+70859828474"}
0005435425103	34D472	8062 526641	NATALYA KOROLEVA	{"email": "n.koroleva.061968@postgrespro.ru", "phone": "+70100233131"}
0005435425104	244FCB	2022 328830	ANNA DANILOVA	{"phone": "+70053772929"}
0005435425105	5F2262	5960 607374	NINA SOKOLOVA	{"email": "sokolova.n041972@postgrespro.ru", "phone": "+70167795055"}
0005435425106	5F2262	2974 637144	LYUDMILA POPOVA	{"email": "l.popova.051960@postgrespro.ru", "phone": "+70287369203"}
0005435425107	8D982E	6838 303090	NADEZHDA PETROVA	{"phone": "+70705873323"}
0005435425108	EADE5A	9622 255155	SERGEY FEDOTOV	{"email": "fedotov.sergey-1969@postgrespro.ru", "phone": "+70137634063"}
0005435425109	EADE5A	8550 001261	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-1975@postgrespro.ru", "phone": "+70891844963"}
0005435425110	4F10D8	2906 259456	VERA NAZAROVA	{"phone": "+70294340059"}
0005435425111	99682D	0096 283418	IRINA GAVRILOVA	{"phone": "+70419698845"}
0005435425112	99682D	8849 910698	TAMARA NESTEROVA	{"phone": "+70710370234"}
0005435425113	99682D	0305 989630	ELIZAVETA SOROKINA	{"email": "e-sorokina.10041978@postgrespro.ru", "phone": "+70694657819"}
0005435425114	1BC154	8223 248262	EVGENIYA MIKHAYLOVA	{"phone": "+70146121509"}
0005435425115	1BC154	8021 267446	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr.1964@postgrespro.ru", "phone": "+70274148207"}
0005435425116	1D1DE6	3061 728299	YULIYA DAVYDOVA	{"email": "davydova_yuliya.14081976@postgrespro.ru", "phone": "+70489857681"}
0005435425117	E47A9D	3336 312953	VLADIMIR POPOV	{"email": "popov-vladimir-1958@postgrespro.ru", "phone": "+70510661177"}
0005435425118	E47A9D	0213 935147	IRINA NIKIFOROVA	{"email": "nikiforovairina-041961@postgrespro.ru", "phone": "+70621280652"}
0005435425119	AF3B76	6744 096762	IGOR MIRONOV	{"phone": "+70766521666"}
0005435425120	AF3B76	2518 301455	SERGEY NIKITIN	{"phone": "+70269625673"}
0005435425121	B2BF6B	9191 196906	ARTEM AFANASEV	{"email": "afanasev-artem_05091975@postgrespro.ru", "phone": "+70767835543"}
0005435425122	DF2035	1081 281648	SVETLANA VLASOVA	{"email": "svlasova.04071972@postgrespro.ru", "phone": "+70672969158"}
0005435425123	DF2035	1529 828297	ANASTASIYA KUZNECOVA	{"email": "a_kuznecova24061967@postgrespro.ru", "phone": "+70933259502"}
0005435425124	AFA44C	2217 861532	LYUBOV POPOVA	{"email": "popova_l26031967@postgrespro.ru", "phone": "+70750296943"}
0005435425125	D68136	5684 892554	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev-121977@postgrespro.ru", "phone": "+70738414254"}
0005435425126	446B49	9344 905898	ALEKSEY KUDRYASHOV	{"email": "aleksey_kudryashov.06121964@postgrespro.ru", "phone": "+70064692092"}
0005435425127	D7E7C1	5867 327130	VALENTINA KUZNECOVA	{"phone": "+70084869489"}
0005435425128	ECAC98	5793 781880	ALEKSANDR PETROV	{"phone": "+70777258671"}
0005435425129	ECAC98	3161 609990	LYUBOV POLYAKOVA	{"email": "l.polyakova031970@postgrespro.ru", "phone": "+70559293601"}
0005435425130	75D203	6881 360873	YAROSLAVA KUZMINA	{"email": "kuzminayaroslava1961@postgrespro.ru", "phone": "+70466446440"}
0005435425131	6F7BDF	1800 591434	ZINAIDA SCHERBAKOVA	{"email": "scherbakova.z.03121957@postgrespro.ru", "phone": "+70277257767"}
0005435425132	965FC2	3537 095776	YAROSLAV MOROZOV	{"email": "morozov_y13111973@postgrespro.ru", "phone": "+70405327730"}
0005435425133	245098	8006 035246	ALEKSANDR ALEKSANDROV	{"phone": "+70852533151"}
0005435425134	245098	1251 920907	VLADIMIR SCHERBAKOV	{"phone": "+70214524751"}
0005435425135	87CCDC	0370 176374	EVGENIY SCHERBAKOV	{"phone": "+70463854620"}
0005435425136	E700E0	9558 229643	MIKHAIL PAVLOV	{"phone": "+70672842717"}
0005435425137	8D1B9F	8243 145286	RAFAIL ISAEV	{"phone": "+70878705973"}
0005435425138	8D1B9F	1791 249311	VALENTINA ZHURAVLEVA	{"email": "zhuravleva_valentina101968@postgrespro.ru", "phone": "+70469695262"}
0005435425139	DDA5DF	9970 473727	NIKOLAY KUZNECOV	{"phone": "+70522387489"}
0005435425140	9E4918	6876 238467	TATYANA MIRONOVA	{"phone": "+70943636204"}
0005435425141	90D383	3172 397978	DENIS MAKSIMOV	{"phone": "+70848454687"}
0005435425142	13C361	1817 893717	OKSANA BORISOVA	{"phone": "+70642433770"}
0005435425143	B8E584	1983 883144	FARIDA KUZNECOVA	{"email": "kuznecova.f.21051973@postgrespro.ru", "phone": "+70757034825"}
0005435425144	B8E584	2852 204029	LYUBOV ANISIMOVA	{"email": "anisimoval_20111966@postgrespro.ru", "phone": "+70796359026"}
0005435425145	3A1777	8193 545948	IVAN POPOV	{"email": "ivanpopov.24121978@postgrespro.ru", "phone": "+70560467325"}
0005435425146	3A1777	7638 697930	VLADIMIR SEMENOV	{"email": "semenov-vladimir1967@postgrespro.ru", "phone": "+70846665852"}
0005435425147	576064	0510 599089	SERGEY SOROKIN	{"phone": "+70826449197"}
0005435425148	576064	3349 965920	NIKOLAY NOVIKOV	{"email": "novikov.nikolay-09071974@postgrespro.ru", "phone": "+70193173174"}
0005435425149	6E6C00	2379 811808	IRINA KAZAKOVA	{"email": "kazakova_irina-28061969@postgrespro.ru", "phone": "+70304429232"}
0005435425150	9E36C8	0800 843666	OLGA POTAPOVA	{"email": "potapova.olga.18011969@postgrespro.ru", "phone": "+70671538841"}
0005435425151	9E36C8	8953 164217	MIKHAIL NAZAROV	{"phone": "+70927441812"}
0005435425152	9E36C8	1746 466135	ELINA SCHERBAKOVA	{"phone": "+70102968879"}
0005435425153	91752F	6950 374309	YULIYA IVANOVA	{"email": "yuliyaivanova041978@postgrespro.ru", "phone": "+70421787167"}
0005435425154	91752F	3597 598324	VLADIMIR KULIKOV	{"email": "kulikov-v-111972@postgrespro.ru", "phone": "+70179542671"}
0005435425155	D10C51	0746 409297	ALEKSEY KUZNECOV	{"email": "a.kuznecov-101962@postgrespro.ru", "phone": "+70786241716"}
0005435425156	C95C11	2317 376990	DMITRIY MEDVEDEV	{"email": "medvedev_dmitriy.03081979@postgrespro.ru", "phone": "+70060284078"}
0005435425157	C95C11	9417 378557	NATALIYA GAVRILOVA	{"email": "n_gavrilova.12091962@postgrespro.ru", "phone": "+70309409478"}
0005435425158	C95C11	7424 259991	RODION VOLKOV	{"email": "rodion.volkov1961@postgrespro.ru", "phone": "+70020810231"}
0005435425159	64DF73	5647 095029	ROMAN FEDOROV	{"email": "romanfedorov-1966@postgrespro.ru", "phone": "+70154909567"}
0005435425160	457D1D	3120 537296	ALEKSANDR SCHERBAKOV	{"email": "aleksandr-scherbakov061967@postgrespro.ru", "phone": "+70077184734"}
0005435425161	78349A	5814 029988	YURIY CHERNOV	{"phone": "+70160319157"}
0005435425162	DCAA67	4530 889439	VLADIMIR CHERNOV	{"phone": "+70837794366"}
0005435425163	DCAA67	9504 551551	MARINA ILINA	{"phone": "+70067006822"}
0005435425164	61DC54	4115 989971	NATALYA VOROBEVA	{"email": "vorobeva_n.071970@postgrespro.ru", "phone": "+70043513649"}
0005435425165	61DC54	8188 606318	ANNA NOVIKOVA	{"phone": "+70217022169"}
0005435425166	5487C0	2759 829572	ALEKSANDRA TARASOVA	{"phone": "+70442840704"}
0005435425167	5487C0	2085 680185	EMILIYA GAVRILOVA	{"phone": "+70106134767"}
0005435425168	557F32	8483 952295	LYUDMILA SOLOVEVA	{"email": "lsoloveva-06051986@postgrespro.ru", "phone": "+70923727758"}
0005435425169	8CB9FF	2694 882472	IRINA ERMAKOVA	{"email": "ermakova_i_18111960@postgrespro.ru", "phone": "+70562763818"}
0005435425170	5E78FC	6592 792929	SERGEY GORBUNOV	{"phone": "+70947396185"}
0005435425171	5E78FC	2662 565729	ELIZAVETA MALYSHEVA	{"phone": "+70325441372"}
0005435425172	F15581	0041 661587	LYUDMILA KOMAROVA	{"phone": "+70751515883"}
0005435425173	014C0A	8106 625823	VALERIY KARPOV	{"email": "v.karpov-121964@postgrespro.ru", "phone": "+70963218177"}
0005435425174	38A9F1	9000 307699	VLADIMIR SEMENOV	{"phone": "+70830599049"}
0005435425175	E39EC5	9835 403360	ALEKSANDR ANDREEV	{"email": "andreev-aleksandr31101965@postgrespro.ru", "phone": "+70725925924"}
0005435425176	FA7D0D	1021 215757	SNEZHANA FOMINA	{"phone": "+70446712421"}
0005435425177	F55BDA	9472 611739	VLADIMIR TIMOFEEV	{"email": "timofeev_v.15111959@postgrespro.ru", "phone": "+70885616788"}
0005435425178	F55BDA	0457 126687	TIMUR GERASIMOV	{"email": "timur_gerasimov13101976@postgrespro.ru", "phone": "+70889795246"}
0005435425179	9C55E9	4988 279474	TATYANA MAKAROVA	{"email": "t.makarova_06091970@postgrespro.ru", "phone": "+70998818315"}
0005435425180	9C55E9	2690 065308	TATYANA LUKYANOVA	{"email": "lukyanovat_18021969@postgrespro.ru", "phone": "+70059864345"}
0005435425181	930122	3532 318326	ALEKSANDR MELNIKOV	{"phone": "+70819281752"}
0005435425182	157FA8	4158 281273	SVETLANA GRISHINA	{"phone": "+70204392013"}
0005435425183	83A8CB	1484 589258	OLGA TIKHONOVA	{"phone": "+70736696454"}
0005435425184	56DD92	9517 663072	FANIS FEDOTOV	{"phone": "+70308291054"}
0005435425185	7EB05D	5836 132283	OLEG SHEVCHENKO	{"phone": "+70715360982"}
0005435425186	7EB05D	6544 488622	ANDREY SCHERBAKOV	{"phone": "+70187126011"}
0005435425187	39D8D8	2998 776058	VLADIMIR FROLOV	{"phone": "+70627197008"}
0005435425188	F19AD9	1847 567319	ELENA RYABOVA	{"email": "ryabova-elena03071970@postgrespro.ru", "phone": "+70744659036"}
0005435425189	324673	3954 591595	EKATERINA MALYSHEVA	{"phone": "+70792232708"}
0005435425190	CCCC60	9520 384699	ANDREY KARPOV	{"email": "karpov-a1981@postgrespro.ru", "phone": "+70338038733"}
0005435425191	6693E8	9098 485588	KIRILL YAKOVLEV	{"phone": "+70411383511"}
0005435425192	1959A7	4253 314956	VLADIMIR ZAKHAROV	{"email": "vladimirzakharov_24061960@postgrespro.ru", "phone": "+70247385222"}
0005435425193	19AACC	7238 025262	KONSTANTIN KRASNOV	{"email": "konstantin-krasnov_021971@postgrespro.ru", "phone": "+70885700525"}
0005435425194	19AACC	5637 029252	LYUDMILA RODIONOVA	{"phone": "+70959981114"}
0005435425195	19AACC	9791 665300	ANNA TARASOVA	{"email": "anna_tarasova.30121965@postgrespro.ru", "phone": "+70910482278"}
0005435425196	2C24F4	3131 230828	SERGEY KRASNOV	{"phone": "+70015877529"}
0005435425197	2C24F4	7032 396330	KLAVDIYA DANILOVA	{"phone": "+70389563276"}
0005435425198	93429C	5283 464938	ILYA IVANOV	{"email": "ivanov_i.30071971@postgrespro.ru", "phone": "+70704778552"}
0005435425199	C00486	0700 459393	MARINA MAKAROVA	{"email": "makarova_marina_15011970@postgrespro.ru", "phone": "+70308910507"}
0005435425200	C00486	0687 802034	KRISTINA KOROLEVA	{"phone": "+70168401594"}
0005435425201	931750	4027 293052	IVAN FILIPPOV	{"phone": "+70833050851"}
0005435425202	938F89	9326 705152	SVETLANA KONOVALOVA	{"phone": "+70738879931"}
0005435425203	FA20EA	3563 590474	ANNA YAKOVLEVA	{"email": "anna.yakovleva-19011971@postgrespro.ru", "phone": "+70526815416"}
0005435425204	140A0F	5469 010810	IRINA TIKHONOVA	{"phone": "+70713622098"}
0005435425205	DBF214	8994 521215	OLGA KONOVALOVA	{"phone": "+70833500527"}
0005435425206	DBF214	2084 852757	ZINAIDA KUZNECOVA	{"phone": "+70732545805"}
0005435425207	4895E6	7354 126524	OKSANA SEMENOVA	{"email": "semenova-o081962@postgrespro.ru", "phone": "+70372870095"}
0005435425208	4895E6	2819 927893	ALEKSEY GUSEV	{"email": "aleksey_gusev-111967@postgrespro.ru", "phone": "+70472056781"}
0005435425209	9273EA	8387 322956	NIKOLAY NOVIKOV	{"email": "novikov-nikolay_20061974@postgrespro.ru", "phone": "+70580156581"}
0005435425210	9273EA	3070 606508	OLGA KONOVALOVA	{"phone": "+70231494638"}
0005435425211	B8627D	1461 664436	YURIY SOROKIN	{"email": "sorokin-yuriy-1973@postgrespro.ru", "phone": "+70112693166"}
0005435425212	6D7957	4784 713834	VLADIMIR GAVRILOV	{"phone": "+70917341049"}
0005435425213	8B59B8	5969 556562	LYUBOV ORLOVA	{"email": "orloval.061981@postgrespro.ru", "phone": "+70995302050"}
0005435425214	8B59B8	0865 281744	NINA AFANASEVA	{"phone": "+70030128150"}
0005435425438	BA0D1C	3241 187996	ALEKSANDR AFANASEV	{"phone": "+70351981787"}
0005435425215	17775F	8887 169017	YURIY ALEKSEEV	{"email": "alekseev-yuriy.091975@postgrespro.ru", "phone": "+70879554195"}
0005435425216	519A33	1637 380007	OLESYA ROMANOVA	{"email": "romanova-olesya_22121972@postgrespro.ru", "phone": "+70055094920"}
0005435425217	519A33	1586 759072	MARINA BARANOVA	{"phone": "+70872078759"}
0005435425218	AB0CF0	8325 719623	GALINA KARPOVA	{"email": "karpova.g081979@postgrespro.ru", "phone": "+70537372581"}
0005435425219	CF944F	7029 240681	ALEKSEY IVANOV	{"phone": "+70903189255"}
0005435425220	0FDA57	0481 378285	MARAT MAKAROV	{"email": "makarov_marat-081977@postgrespro.ru", "phone": "+70231730298"}
0005435425221	0FDA57	1793 183533	VALENTINA GAVRILOVA	{"phone": "+70566423865"}
0005435425222	DD4993	4439 202769	SERGEY FILIPPOV	{"email": "filippovsergey23021978@postgrespro.ru", "phone": "+70347527081"}
0005435425223	DD4993	3699 767901	VYACHESLAV ANDREEV	{"phone": "+70366785148"}
0005435425224	143494	6056 125766	OLGA YAKOVLEVA	{"phone": "+70430086075"}
0005435425225	A83235	0586 927479	IVAN KUZMIN	{"email": "kuzmin.ivan.051965@postgrespro.ru", "phone": "+70114159253"}
0005435425226	4AE242	3557 628515	ANDREY SOKOLOV	{"phone": "+70116478642"}
0005435425227	331C02	5552 348594	ANTONINA BOGDANOVA	{"phone": "+70678273644"}
0005435425228	3ADD18	0434 358943	IGOR TARASOV	{"email": "igor_tarasov25021971@postgrespro.ru", "phone": "+70860043759"}
0005435425229	4A00F4	5021 551631	RINAT SMIRNOV	{"email": "rinat.smirnov021970@postgrespro.ru", "phone": "+70997338036"}
0005435425230	B84E7C	1789 801964	TATYANA MIKHAYLOVA	{"email": "mikhaylova_tatyana-22061976@postgrespro.ru", "phone": "+70550331051"}
0005435425231	3DC7FE	7188 260284	DARYA IVANOVA	{"phone": "+70752494002"}
0005435425232	3DC7FE	7248 836436	OLEG DENISOV	{"phone": "+70712721665"}
0005435425233	AB610C	7330 996573	LYUDMILA LAZAREVA	{"email": "lyudmila_lazareva11121975@postgrespro.ru", "phone": "+70158518509"}
0005435425234	03F29C	4778 333825	ANDREY BELOV	{"phone": "+70723588999"}
0005435425235	A30513	2825 496502	NIKOLAY PETROV	{"email": "petrov_nikolay-101989@postgrespro.ru", "phone": "+70210114454"}
0005435425236	A30513	2193 683009	EVGENIYA TITOVA	{"email": "evgeniya_titova_13051977@postgrespro.ru", "phone": "+70750317286"}
0005435425237	8B0113	7295 969344	DMITRIY VOLKOV	{"phone": "+70688434349"}
0005435425238	8B0113	2320 718513	ALEKSEY BORISOV	{"phone": "+70640408662"}
0005435425239	2D0710	5685 803182	NINA GRISHINA	{"phone": "+70851502662"}
0005435425240	BAA829	9216 834203	OLESYA EFIMOVA	{"phone": "+70107999170"}
0005435425241	BAA829	8667 108655	DARYA EGOROVA	{"phone": "+70878974926"}
0005435425242	BAA829	9761 813910	LYUBOV EGOROVA	{"email": "legorova.1964@postgrespro.ru", "phone": "+70242207601"}
0005435425243	76A4ED	9935 561740	SERGEY ANDREEV	{"email": "sergey_andreev071971@postgrespro.ru", "phone": "+70730281316"}
0005435425244	16A051	4594 784184	RUSLAN MATVEEV	{"phone": "+70651395630"}
0005435425245	16A051	8787 389012	ELENA MALYSHEVA	{"phone": "+70655219480"}
0005435425246	E362FC	7806 776994	SERGEY GUSEV	{"email": "gusevsergey_101963@postgrespro.ru", "phone": "+70248249689"}
0005435425247	CC6305	6841 716897	ILYAS BORISOV	{"email": "borisov_i.08011960@postgrespro.ru", "phone": "+70541579166"}
0005435425248	20ACAD	6923 370040	ANASTASIYA POPOVA	{"email": "anastasiya-popova_31051978@postgrespro.ru", "phone": "+70171928934"}
0005435425249	20ACAD	3396 580428	LIDIYA NOVIKOVA	{"phone": "+70510044238"}
0005435425250	E6504D	6853 273492	NINA TITOVA	{"phone": "+70926013220"}
0005435425251	6612BD	5805 564481	VERA NIKOLAEVA	{"phone": "+70776571879"}
0005435425252	6612BD	3569 307684	VIKTOR KOZLOV	{"email": "v_kozlov_1989@postgrespro.ru", "phone": "+70558499801"}
0005435425253	6612BD	1245 157631	DMITRIY ZAKHAROV	{"email": "d_zakharov-1975@postgrespro.ru", "phone": "+70348406992"}
0005435425254	572E53	8383 045290	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov.111979@postgrespro.ru", "phone": "+70685064340"}
0005435425255	12823C	5101 304975	MARYAM STEPANOVA	{"phone": "+70183602343"}
0005435425256	C1285C	1553 815631	LIDIYA NIKITINA	{"email": "nikitinal.1974@postgrespro.ru", "phone": "+70907165461"}
0005435425257	C1285C	0089 006358	ANDREY STEPANOV	{"phone": "+70497691926"}
0005435425258	8790F3	1584 993599	NATALYA MAKSIMOVA	{"phone": "+70836867037"}
0005435425259	FBF0FC	4966 677459	RIMA POLYAKOVA	{"email": "polyakova_rima1971@postgrespro.ru", "phone": "+70550001944"}
0005435425260	0DE1FA	7510 510416	NATALYA NOVIKOVA	{"phone": "+70343142040"}
0005435425261	55C1D9	1894 599078	TAMARA NESTEROVA	{"phone": "+70472924619"}
0005435425262	70D538	4989 949037	ALEKSEY TARASOV	{"phone": "+70448202986"}
0005435425263	6DF1A6	0843 797321	VALENTINA CHERNOVA	{"email": "vchernova.1984@postgrespro.ru", "phone": "+70704788608"}
0005435425264	4C4E01	9495 533294	YULIYA PAVLOVA	{"email": "pavlovay_1963@postgrespro.ru", "phone": "+70005836419"}
0005435425265	4C4E01	1494 807828	VERONIKA STEPANOVA	{"phone": "+70727795147"}
0005435425266	6CEE21	2707 184993	OLGA TITOVA	{"phone": "+70020489454"}
0005435425267	6033EC	7022 395551	ARINA FROLOVA	{"phone": "+70304076539"}
0005435425268	08969C	9476 003036	NATALYA BOGDANOVA	{"email": "bogdanova_n_111958@postgrespro.ru", "phone": "+70855005688"}
0005435425269	9BEACF	0854 187158	SERGEY PETROV	{"email": "petrov.s07111967@postgrespro.ru", "phone": "+70169603811"}
0005435425270	1613F9	7219 727311	KONSTANTIN VOLKOV	{"phone": "+70410882766"}
0005435425271	ECAB30	6774 895663	ANTONINA ZAKHAROVA	{"email": "azakharova1966@postgrespro.ru", "phone": "+70009325107"}
0005435425272	448327	6621 366168	IRINA SEMENOVA	{"email": "semenova_irina-26091980@postgrespro.ru", "phone": "+70446244213"}
0005435425273	839CC3	7964 307923	VLADIMIR MAKAROV	{"email": "makarov_vladimir-111973@postgrespro.ru", "phone": "+70637642796"}
0005435425274	839CC3	2144 191437	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov011972@postgrespro.ru", "phone": "+70521881875"}
0005435425275	CE3DEF	8245 984739	GALINA MASLOVA	{"email": "maslova.galina.061989@postgrespro.ru", "phone": "+70182711962"}
0005435425276	5C9660	4879 786691	SERGEY MAKSIMOV	{"email": "sergey_maksimov1972@postgrespro.ru", "phone": "+70574047819"}
0005435425277	217B0E	1454 782709	VLADISLAV MAKAROV	{"phone": "+70953565449"}
0005435425278	7BDF4C	9521 241786	DARYA GUSEVA	{"email": "guseva_d-15021966@postgrespro.ru", "phone": "+70253923736"}
0005435425279	461328	3973 863880	NADEZHDA KOLESNIKOVA	{"email": "nadezhda_kolesnikova.12041969@postgrespro.ru", "phone": "+70962813643"}
0005435425280	461328	7835 216807	MAKSIM DMITRIEV	{"email": "dmitrievmaksim1969@postgrespro.ru", "phone": "+70266226361"}
0005435425281	2E8352	4758 161224	ALENA ALEKSEEVA	{"email": "alekseeva.a.081977@postgrespro.ru", "phone": "+70715517716"}
0005435425282	2E8352	3322 933280	TATYANA ALEKSEEVA	{"email": "t.alekseeva.061975@postgrespro.ru", "phone": "+70726433397"}
0005435425283	FD4B90	5955 693979	NIKOLAY FROLOV	{"phone": "+70459541649"}
0005435425284	7E37B5	4065 926931	ROMAN VASILEV	{"phone": "+70672886907"}
0005435425285	D337E2	4274 587104	SERGEY SMIRNOV	{"phone": "+70503878843"}
0005435425286	D337E2	3645 035589	ANNA STEPANOVA	{"email": "stepanova-anna-1980@postgrespro.ru", "phone": "+70171179688"}
0005435425287	E79927	0590 501554	LYUDMILA KUZMINA	{"phone": "+70914557507"}
0005435425288	25A1E6	8146 455934	ANTON MIKHAYLOV	{"email": "a_mikhaylov_01091989@postgrespro.ru", "phone": "+70230530572"}
0005435425289	25A1E6	2778 940008	ANNA ZAYCEVA	{"email": "zayceva-anna.11091971@postgrespro.ru", "phone": "+70678435160"}
0005435425290	25A1E6	9917 780686	NATALYA KUZNECOVA	{"phone": "+70960276234"}
0005435425291	C48B31	4060 125841	ALEKSANDRA POLYAKOVA	{"phone": "+70787826008"}
0005435425292	D78A99	3034 955706	ANDREY KONOVALOV	{"phone": "+70594248267"}
0005435425293	BD9BC8	0709 865504	ZLATA VLASOVA	{"email": "vlasovazlata_30091977@postgrespro.ru", "phone": "+70380139141"}
0005435425294	BD9BC8	1103 440194	ALEKSANDR VASILEV	{"phone": "+70691099584"}
0005435425295	F7309F	3177 013917	IRINA IVANOVA	{"email": "i-ivanova-20101980@postgrespro.ru", "phone": "+70657517486"}
0005435425296	F7309F	3267 915442	VIKTORIYA DMITRIEVA	{"email": "dmitrieva.viktoriya_07021975@postgrespro.ru", "phone": "+70018356353"}
0005435425297	93F92A	0675 403813	IRINA GAVRILOVA	{"phone": "+70083289663"}
0005435425298	D41D65	7066 245223	DMITRIY KUZMIN	{"phone": "+70009982255"}
0005435425299	040559	7925 717167	EKATERINA NESTEROVA	{"email": "nesterova.e-19061961@postgrespro.ru", "phone": "+70826738013"}
0005435425300	C709BA	4576 132457	GALINA EGOROVA	{"email": "egorova.g071957@postgrespro.ru", "phone": "+70443649688"}
0005435425301	8F1D1B	2532 145619	DANIL ALEKSEEV	{"email": "alekseev_danil_061984@postgrespro.ru", "phone": "+70188435018"}
0005435425302	8F1D1B	7671 942093	DANILA OSIPOV	{"phone": "+70485283473"}
0005435425303	0BBCBF	7731 029266	VALENTINA ARKHIPOVA	{"phone": "+70516154193"}
0005435425304	24D47E	1135 831518	ANDREY MIRONOV	{"email": "mironov_andrey101974@postgrespro.ru", "phone": "+70201007184"}
0005435425305	24D47E	2629 264068	ANNA VASILEVA	{"email": "annavasileva_1966@postgrespro.ru", "phone": "+70766708434"}
0005435425306	608592	0716 503420	VIKTORIYA IVANOVA	{"phone": "+70384056444"}
0005435425307	4B8E80	6472 403972	ARKADIY VOLKOV	{"phone": "+70308057645"}
0005435425308	4B8E80	2100 457399	NATALYA KRASNOVA	{"phone": "+70421013186"}
0005435425309	FB22E3	9361 000274	MARIYA KRASNOVA	{"email": "krasnova.m.021967@postgrespro.ru", "phone": "+70766516698"}
0005435425310	AD051B	8811 030767	EKATERINA ZOTOVA	{"phone": "+70595163380"}
0005435425311	16FE79	3720 733609	LYUDMILA KOZLOVA	{"phone": "+70309123261"}
0005435425312	CA3772	8481 431884	ANATOLIY KUZMIN	{"email": "kuzmin-a-121977@postgrespro.ru", "phone": "+70834278916"}
0005435425313	9011DB	7677 376611	VALENTINA LEBEDEVA	{"email": "valentinalebedeva_1964@postgrespro.ru", "phone": "+70589864264"}
0005435425314	5825AC	8606 652468	MARIYA KRASNOVA	{"phone": "+70804206574"}
0005435425315	B1C2D0	6778 210821	ELIZAVETA VASILEVA	{"email": "e.vasileva_021970@postgrespro.ru", "phone": "+70806631672"}
0005435425316	81BA58	7252 806029	ALEKSEY KUZMIN	{"phone": "+70693769160"}
0005435425317	44D059	9131 131887	LARISA MOROZOVA	{"email": "l_morozova-081960@postgrespro.ru", "phone": "+70266229399"}
0005435425318	4FF3FE	6973 391676	GALINA KOMAROVA	{"phone": "+70695310569"}
0005435425319	76B0B4	9442 299810	NIKOLAY TIMOFEEV	{"phone": "+70162692168"}
0005435425320	A7C9E7	1691 393480	EKATERINA NIKOLAEVA	{"phone": "+70788342644"}
0005435425321	A7C9E7	6503 819481	GALINA KONOVALOVA	{"email": "konovalovag.20071978@postgrespro.ru", "phone": "+70176507601"}
0005435425322	9216D4	8091 762657	VERA ERMAKOVA	{"email": "vera.ermakova-1967@postgrespro.ru", "phone": "+70921102684"}
0005435425323	8A98F4	2743 483164	VLADIMIR BELOV	{"email": "belov.vladimir1964@postgrespro.ru", "phone": "+70414302989"}
0005435425324	8A98F4	3998 768364	ELENA FEDOROVA	{"phone": "+70486905922"}
0005435425325	D48E6D	0254 828554	BORIS NIKOLAEV	{"phone": "+70345292893"}
0005435425326	1625D8	6236 267596	LYUBOV POPOVA	{"phone": "+70868567599"}
0005435425439	BA0D1C	9203 622958	ALIK VOROBEV	{"phone": "+70591400287"}
0005435425327	1625D8	3609 957677	EVGENIY DENISOV	{"email": "denisov-e_051976@postgrespro.ru", "phone": "+70858336742"}
0005435425328	15AB91	8053 395960	EVGENIY NIKOLAEV	{"phone": "+70165326339"}
0005435425329	8FDE0A	8068 921947	MAKSIM ZAYCEV	{"email": "m_zaycev1968@postgrespro.ru", "phone": "+70388789585"}
0005435425330	61DC29	4005 259380	NADEZHDA ZAKHAROVA	{"phone": "+70610780691"}
0005435425331	3EAFB1	0844 811856	TATYANA NIKOLAEVA	{"phone": "+70056978519"}
0005435425332	CA2380	8967 605130	IVAN BONDARENKO	{"phone": "+70356636289"}
0005435425333	C472A8	9631 817590	SERGEY PETROV	{"email": "petrovs1982@postgrespro.ru", "phone": "+70414761783"}
0005435425334	C472A8	7996 627834	MARAT NIKITIN	{"phone": "+70686812094"}
0005435425335	F3969F	0240 784124	EVA SOKOLOVA	{"email": "sokolova_eva_24021981@postgrespro.ru", "phone": "+70309131251"}
0005435425336	0F0793	3986 690469	VALENTINA SOKOLOVA	{"email": "sokolova-valentina-1972@postgrespro.ru", "phone": "+70064076645"}
0005435425337	0AE03E	6666 079030	ELENA MAKAROVA	{"email": "makarova_e-061975@postgrespro.ru", "phone": "+70209428412"}
0005435425338	8FFCF8	6614 731235	ALEKSEY GAVRILOV	{"phone": "+70337786966"}
0005435425339	27DF55	7472 693864	NINA BOGDANOVA	{"email": "ninabogdanova-071981@postgrespro.ru", "phone": "+70407636502"}
0005435425340	27DF55	8764 989146	ISLAM TIKHONOV	{"email": "islamtikhonov.1968@postgrespro.ru", "phone": "+70253499824"}
0005435425341	000784	5546 862492	ALEKSANDRA PAVLOVA	{"email": "pavlovaaleksandra-09061985@postgrespro.ru", "phone": "+70180185768"}
0005435425342	3722DA	1873 321177	VLADIMIR SAVELEV	{"phone": "+70256532075"}
0005435425343	4034F6	9363 956136	ANDREY CHERNOV	{"email": "andrey-chernov071974@postgrespro.ru", "phone": "+70536606390"}
0005435425344	4034F6	5581 865485	VALENTINA KISELEVA	{"phone": "+70544013130"}
0005435425345	78B24F	3919 172339	NADEZHDA SCHERBAKOVA	{"email": "n-scherbakova_071981@postgrespro.ru", "phone": "+70222447025"}
0005435425346	78B24F	0946 435747	NATALYA SIDOROVA	{"email": "sidorova_natalya_021975@postgrespro.ru", "phone": "+70031725686"}
0005435425347	99124C	1111 791443	ALEKSANDR KUZNECOV	{"phone": "+70193279580"}
0005435425348	B3D2A9	6219 407102	ILYA PAVLOV	{"email": "i-pavlov_17051972@postgrespro.ru", "phone": "+70854837096"}
0005435425349	B3D2A9	4673 906316	TATYANA SMIRNOVA	{"phone": "+70956349920"}
0005435425350	8D2687	0836 213206	VIKTOR PETROV	{"phone": "+70613997398"}
0005435425351	9CFBCF	9788 552865	ANNA OSIPOVA	{"phone": "+70593203400"}
0005435425352	A352BA	7171 386435	ELENA EFIMOVA	{"email": "efimova-elena04051978@postgrespro.ru", "phone": "+70918499058"}
0005435425353	A352BA	0877 387621	SERGEY MARTYNOV	{"email": "martynov_s-121960@postgrespro.ru", "phone": "+70307377428"}
0005435425354	4EE36D	7281 465980	DMITRIY PETROV	{"email": "dmitriypetrov.05121977@postgrespro.ru", "phone": "+70745173420"}
0005435425355	4EE36D	6638 851040	ALEKSEY KUZNECOV	{"phone": "+70760227666"}
0005435425356	4EE36D	9438 603179	ANNA KUZNECOVA	{"phone": "+70939407455"}
0005435425357	6468F7	5720 656483	LYUDMILA NIKOLAEVA	{"email": "lyudmila-nikolaeva-021956@postgrespro.ru", "phone": "+70960344880"}
0005435425358	6468F7	2889 208902	VARVARA VASILEVA	{"phone": "+70819860107"}
0005435425359	E95C1B	1005 033354	EVGENIYA SMIRNOVA	{"email": "evgeniya_smirnova081972@postgrespro.ru", "phone": "+70970144690"}
0005435425360	DA39C3	2845 093032	NADEZHDA ALEKSANDROVA	{"phone": "+70698387495"}
0005435425361	DA39C3	7957 901993	DENIS PAVLOV	{"email": "pavlov-d.1971@postgrespro.ru", "phone": "+70880077291"}
0005435425362	870BBD	0684 569737	YURIY KOZLOV	{"phone": "+70473240276"}
0005435425363	CDD187	8477 304059	IRINA SOROKINA	{"phone": "+70483677990"}
0005435425364	1396A2	7513 689695	TATYANA POPOVA	{"email": "t.popova021972@postgrespro.ru", "phone": "+70629906591"}
0005435425365	1396A2	1485 966457	SERGEY KOZLOV	{"email": "skozlov_24021983@postgrespro.ru", "phone": "+70113517132"}
0005435425366	E8E5CB	6057 314170	MIKHAIL MAKAROV	{"phone": "+70286595539"}
0005435425367	0F7C14	1176 739958	LYUBOV EFREMOVA	{"phone": "+70201237990"}
0005435425368	12BA4A	0120 432769	ALEKSANDR NAZAROV	{"phone": "+70647531638"}
0005435425369	12BA4A	8078 201402	EDUARD SOKOLOV	{"phone": "+70536776973"}
0005435425370	F3CDE8	3054 975779	ALEKSANDR SERGEEV	{"phone": "+70980628819"}
0005435425371	F3CDE8	3792 740198	ALBINA TARASOVA	{"phone": "+70662782359"}
0005435425372	524F55	7793 460597	RUSLAN POPOV	{"email": "r.popov-1973@postgrespro.ru", "phone": "+70514691600"}
0005435425373	F7B8DC	3527 167190	DENIS VOROBEV	{"email": "d_vorobev-04061968@postgrespro.ru", "phone": "+70248290364"}
0005435425374	CDEA32	1946 884569	NATALYA BORISOVA	{"phone": "+70513063834"}
0005435425375	EAE16F	6020 605158	VIKTOR GUSEV	{"email": "viktor.gusev-1968@postgrespro.ru", "phone": "+70770007255"}
0005435425376	9737BB	0693 132622	VITALIY MAKAROV	{"email": "v_makarov30081967@postgrespro.ru", "phone": "+70685569538"}
0005435425377	BF8524	8136 731504	DMITRIY PAVLOV	{"phone": "+70123904909"}
0005435425378	9B8705	7943 655454	SERGEY SERGEEV	{"email": "s-sergeev-111973@postgrespro.ru", "phone": "+70788410132"}
0005435425379	030473	9505 562426	OLGA ABRAMOVA	{"phone": "+70746801391"}
0005435425380	030473	5821 880870	OLEG DENISOV	{"email": "oleg-denisov.1973@postgrespro.ru", "phone": "+70111871051"}
0005435425381	FECA4F	1983 747009	ANNA KISELEVA	{"email": "a.kiseleva_1974@postgrespro.ru", "phone": "+70419991162"}
0005435425382	DBA3F3	2240 621835	KLAVDIYA SAVELEVA	{"phone": "+70567089857"}
0005435425383	24B63F	7900 392659	STANISLAV GAVRILOV	{"email": "gavrilov-s1972@postgrespro.ru", "phone": "+70011086983"}
0005435425384	24B63F	6627 729851	LYAYSAN BELOVA	{"email": "lyaysanbelova.061975@postgrespro.ru", "phone": "+70383805189"}
0005435425385	2C6499	2304 089728	NELLI FILATOVA	{"email": "filatova-nelli_1969@postgrespro.ru", "phone": "+70290509427"}
0005435425386	970389	3746 464121	IRINA IVANOVA	{"email": "ivanova.i_23111978@postgrespro.ru", "phone": "+70800481414"}
0005435425387	970389	0512 445151	GALINA TROFIMOVA	{"phone": "+70219219387"}
0005435425388	728934	2085 572711	EVGENIY AFANASEV	{"phone": "+70300334095"}
0005435425389	728934	6740 252883	ANDREY VASILEV	{"email": "a-vasilev_06061977@postgrespro.ru", "phone": "+70528947796"}
0005435425390	AA564C	6894 272883	NATALYA MIRONOVA	{"phone": "+70382924376"}
0005435425391	AA564C	8978 365182	LYUDMILA GAVRILOVA	{"phone": "+70522931556"}
0005435425392	C9693C	6096 342204	LYUDMILA VOLKOVA	{"email": "volkova.lyudmila.29051968@postgrespro.ru", "phone": "+70893155220"}
0005435425393	8D5AA0	8641 101009	TATYANA SMIRNOVA	{"email": "smirnovatatyana-17101968@postgrespro.ru", "phone": "+70948289910"}
0005435425394	8D5AA0	7603 419959	LYUDMILA MAKSIMOVA	{"phone": "+70814469814"}
0005435425395	83872C	0607 965278	NIKOLAY AFANASEV	{"email": "afanasev.n.041975@postgrespro.ru", "phone": "+70598334021"}
0005435425396	5508C5	8138 667943	ALEKSEY KUZNECOV	{"email": "kuznecovaleksey1977@postgrespro.ru", "phone": "+70631739871"}
0005435425397	5508C5	3560 258684	YURIY ZAYCEV	{"email": "zaycev_y_17031977@postgrespro.ru", "phone": "+70190629061"}
0005435425398	1D158A	6039 380301	IRINA SAVELEVA	{"phone": "+70904035473"}
0005435425399	29F6C8	4507 070245	YURIY GAVRILOV	{"phone": "+70009867547"}
0005435425400	29F6C8	9961 119889	VLADIMIR SOLOVEV	{"email": "solovev-v111965@postgrespro.ru", "phone": "+70305121554"}
0005435425401	173D8C	3896 821247	ANDREY ZHUKOV	{"email": "zhukovandrey.121980@postgrespro.ru", "phone": "+70272089137"}
0005435425402	173D8C	0898 033521	VIKTOR ROMANOV	{"email": "romanovv.071985@postgrespro.ru", "phone": "+70038139645"}
0005435425403	79FF75	6563 281445	VERA EGOROVA	{"email": "veraegorova.121957@postgrespro.ru", "phone": "+70606887391"}
0005435425404	79FF75	4518 200204	NATALYA KAZAKOVA	{"email": "n_kazakova.081972@postgrespro.ru", "phone": "+70268944437"}
0005435425405	79FF75	0240 044038	NINEL MOROZOVA	{"email": "n-morozova-19041955@postgrespro.ru", "phone": "+70716567128"}
0005435425406	D1642A	8565 583965	ANATOLIY KOZLOV	{"phone": "+70824837292"}
0005435425407	FFC7E3	3596 016073	VALERIYA KOROLEVA	{"email": "koroleva-v_1964@postgrespro.ru", "phone": "+70271428542"}
0005435425408	05C000	5472 315352	ALEKSANDR KUZMIN	{"phone": "+70734413307"}
0005435425409	05C000	0582 244419	DENIS GERASIMOV	{"phone": "+70222749496"}
0005435425410	05C000	6752 510483	MARINA FADEEVA	{"phone": "+70233895310"}
0005435425411	FBF3D9	4606 197817	PAVEL SHEVCHENKO	{"email": "pavel.shevchenko_121968@postgrespro.ru", "phone": "+70358273840"}
0005435425412	921EA7	3729 798833	VIOLETTA YUDINA	{"email": "yudina.v_1975@postgrespro.ru", "phone": "+70713525334"}
0005435425413	921EA7	1753 939346	IRINA IVANOVA	{"email": "ivanovai12021967@postgrespro.ru", "phone": "+70171177140"}
0005435425414	921EA7	9023 306698	VYACHESLAV NOVIKOV	{"phone": "+70930163648"}
0005435425415	75127F	4102 696367	MARIYA KOZLOVA	{"email": "kozlovam31011981@postgrespro.ru", "phone": "+70350991103"}
0005435425416	1E2899	2399 258965	SERGEY VOLKOV	{"phone": "+70378797556"}
0005435425417	1BAE20	5685 303743	SVETLANA ANTONOVA	{"email": "s-antonova_18121979@postgrespro.ru", "phone": "+70011816442"}
0005435425418	3B5DB5	6358 601061	EKATERINA KUZMINA	{"email": "e.kuzmina-1962@postgrespro.ru", "phone": "+70024596311"}
0005435425419	DDB6E9	2613 492789	MARIYA EFIMOVA	{"email": "m_efimova051979@postgrespro.ru", "phone": "+70926235056"}
0005435425420	D55E78	7848 827702	NINA NESTEROVA	{"phone": "+70481106399"}
0005435425421	311748	0732 534191	TATYANA DMITRIEVA	{"email": "tdmitrieva_04111964@postgrespro.ru", "phone": "+70454149569"}
0005435425422	311748	3011 268459	PAVEL SHEVCHENKO	{"email": "pavel_shevchenko.091990@postgrespro.ru", "phone": "+70240477080"}
0005435425423	2040CC	4328 168784	VLADISLAV MARTYNOV	{"email": "v-martynov21121967@postgrespro.ru", "phone": "+70096230669"}
0005435425424	8E6394	6167 142739	VIKTOR SERGEEV	{"email": "sergeevviktor29111975@postgrespro.ru", "phone": "+70847508067"}
0005435425425	8E6394	2408 823138	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova-tatyana.021977@postgrespro.ru", "phone": "+70663760195"}
0005435425426	3A3D94	3588 905165	NATALYA DANILOVA	{"email": "natalya_danilova16071973@postgrespro.ru", "phone": "+70278282372"}
0005435425427	2C8B47	5372 195044	ALEKSANDR VOLKOV	{"email": "volkova.14061964@postgrespro.ru", "phone": "+70042313179"}
0005435425428	2C8B47	5633 162301	MAKSIM ANDREEV	{"phone": "+70806390463"}
0005435425429	2C8B47	3471 745626	ZOYA ORLOVA	{"email": "orlovaz04101976@postgrespro.ru", "phone": "+70070201864"}
0005435425430	DAAEA8	1016 440855	ALEKSANDR ANDREEV	{"phone": "+70704994826"}
0005435425431	DAAEA8	2660 057621	TAMARA KOLESNIKOVA	{"email": "kolesnikova-tamara.061978@postgrespro.ru", "phone": "+70756317278"}
0005435425432	7A461F	6317 755532	LARISA POLYAKOVA	{"phone": "+70971670256"}
0005435425433	7A461F	9063 350339	YURIY POPOV	{"phone": "+70882141906"}
0005435425434	1ED78B	5714 289213	MARINA KOLESNIKOVA	{"phone": "+70836227190"}
0005435425435	1ED78B	8331 015847	ANDREY ALEKSANDROV	{"email": "andrey-aleksandrov-1976@postgrespro.ru", "phone": "+70932085389"}
0005435425436	A50230	5099 109223	VLADIMIR MATVEEV	{"email": "matveev_vladimir_1974@postgrespro.ru", "phone": "+70948979950"}
0005435425437	A50230	2958 730326	IGOR BARANOV	{"phone": "+70892575489"}
0005435425440	1AA2D5	7631 085862	MIKHAIL SOROKIN	{"phone": "+70793551661"}
0005435425441	1AA2D5	9190 160439	MIKHAIL SCHERBAKOV	{"phone": "+70155810220"}
0005435425442	A385CD	1953 837473	KONSTANTIN SOKOLOV	{"phone": "+70373217815"}
0005435425443	A2870B	9255 719803	GALINA KALININA	{"phone": "+70385350477"}
0005435425444	578FBC	5083 989310	SERGEY IVANOV	{"phone": "+70686498348"}
0005435425445	578FBC	6628 800620	ALEKSANDR SMIRNOV	{"phone": "+70607980664"}
0005435425446	412278	1869 348282	NATALYA DMITRIEVA	{"email": "dmitrieva-natalya01061983@postgrespro.ru", "phone": "+70556930205"}
0005435425447	412278	2508 236722	TAMARA ANDREEVA	{"email": "tamara-andreeva_051977@postgrespro.ru", "phone": "+70469285718"}
0005435425448	7F8414	0006 494516	EVGENIYA SERGEEVA	{"phone": "+70783780791"}
0005435425449	008805	3261 579339	MILENA YUDINA	{"email": "yudinamilena_19071974@postgrespro.ru", "phone": "+70810975548"}
0005435425450	68EB7F	0388 766951	VERA KUZNECOVA	{"email": "v.kuznecova_021965@postgrespro.ru", "phone": "+70670145939"}
0005435425451	B0D309	4086 694776	LYUDMILA MATVEEVA	{"email": "matveeval_041973@postgrespro.ru", "phone": "+70363657232"}
0005435425452	547F98	6219 876754	ALEKSEY KUZNECOV	{"email": "kuznecov-a-091972@postgrespro.ru", "phone": "+70329289880"}
0005435425453	AA2A28	2117 485717	DARYA NIKITINA	{"phone": "+70063623046"}
0005435425454	AA2A28	8465 761772	IRINA POPOVA	{"phone": "+70139761881"}
0005435425455	AA2A28	5916 637238	ANATOLIY SMIRNOV	{"email": "smirnov_a1967@postgrespro.ru", "phone": "+70029886470"}
0005435425456	762200	2336 462410	ALEKSANDR ORLOV	{"phone": "+70488739022"}
0005435425457	5F5972	3407 751980	NINA SMIRNOVA	{"email": "smirnovanina1968@postgrespro.ru", "phone": "+70114648954"}
0005435425458	5F5972	4579 450338	ANNA ANTONOVA	{"email": "antonova_a-04111977@postgrespro.ru", "phone": "+70353628746"}
0005435425459	E94489	2842 745933	OLGA ZAYCEVA	{"email": "zayceva-olga-061973@postgrespro.ru", "phone": "+70480946762"}
0005435425460	68CC08	7736 580422	MARIYA MIKHAYLOVA	{"phone": "+70832138415"}
0005435425461	DC68CD	0143 636347	MIKHAIL POPOV	{"email": "popov-m-1983@postgrespro.ru", "phone": "+70359402379"}
0005435425462	272A3D	5158 118647	ALEKSEY KUZNECOV	{"email": "a_kuznecov_12061973@postgrespro.ru", "phone": "+70969864281"}
0005435425463	272A3D	7088 543018	YURIY SEMENOV	{"phone": "+70528386064"}
0005435425464	272A3D	6549 285099	GALINA IVANOVA	{"phone": "+70789006949"}
0005435425465	DB79D1	3203 958737	BORIS DAVYDOV	{"email": "davydov.boris-071969@postgrespro.ru", "phone": "+70172549079"}
0005435425466	DB79D1	6456 778345	TATYANA NAZAROVA	{"phone": "+70473717467"}
0005435425467	70827D	9651 472080	VIKTOR MAKAROV	{"email": "makarov_viktor1966@postgrespro.ru", "phone": "+70100982859"}
0005435425468	70827D	1498 617918	ARINA BOGDANOVA	{"phone": "+70080763957"}
0005435425469	B46C41	1807 743484	ANNA MAKAROVA	{"phone": "+70893980153"}
0005435425470	79579B	8511 474605	GALINA SMIRNOVA	{"email": "smirnova.g-14081972@postgrespro.ru", "phone": "+70405450603"}
0005435425471	869539	8957 079223	ELENA KUZMINA	{"phone": "+70332971133"}
0005435425472	31F11E	9494 829598	SERGEY RODIONOV	{"phone": "+70353761846"}
0005435425473	31F11E	9806 262319	LYUBOV ZHUKOVA	{"phone": "+70922511714"}
0005435425474	31F11E	5039 393596	SERGEY ABRAMOV	{"email": "sergeyabramov_27121967@postgrespro.ru", "phone": "+70937782110"}
0005435425475	710ADD	5857 498791	ALEKSANDR GRIGOREV	{"phone": "+70233985211"}
0005435425476	0FE0C0	1763 193689	ANATOLIY KAZAKOV	{"email": "kazakov_a-031984@postgrespro.ru", "phone": "+70921288544"}
0005435425477	0FE0C0	9487 406681	ANATOLIY SOLOVEV	{"email": "asolovev-25051965@postgrespro.ru", "phone": "+70171867197"}
0005435425478	1F700C	3824 407815	VALENTINA MARTYNOVA	{"email": "v.martynova.26111973@postgrespro.ru", "phone": "+70349302748"}
0005435425479	68192A	0151 134155	GENNADIY NIKITIN	{"phone": "+70711619507"}
0005435425480	68192A	2048 630220	OLGA ILINA	{"phone": "+70440516340"}
0005435425481	F2C642	7222 338850	EMIL ORLOV	{"email": "emil_orlov-14031969@postgrespro.ru", "phone": "+70668289285"}
0005435425482	422DA4	2797 580978	IVAN GRIGOREV	{"phone": "+70394293310"}
0005435425483	422DA4	6653 516031	TATYANA SERGEEVA	{"phone": "+70710707663"}
0005435425484	B849D2	0385 080536	YURIY ZAYCEV	{"email": "yzaycev.29111976@postgrespro.ru", "phone": "+70283312664"}
0005435425485	850325	6595 922507	LIDIYA FEDOROVA	{"email": "lidiya_fedorova-1972@postgrespro.ru", "phone": "+70600398953"}
0005435425486	644378	4196 256971	OLGA FOMINA	{"phone": "+70548984278"}
0005435425487	644378	3981 015155	NATALYA BELYAEVA	{"email": "natalyabelyaeva-31011982@postgrespro.ru", "phone": "+70371538655"}
0005435425488	644378	6534 915953	YURIY MIKHAYLOV	{"phone": "+70708044768"}
0005435425489	3E3D58	1345 868564	VITALIY KULIKOV	{"phone": "+70775498184"}
0005435425490	5A9124	1182 604582	TIMOFEY MOROZOV	{"email": "morozov-timofey-021968@postgrespro.ru", "phone": "+70617277589"}
0005435425491	756E16	2329 368230	TATYANA NIKOLAEVA	{"phone": "+70645440645"}
0005435425492	756E16	2831 192670	SVETLANA TITOVA	{"phone": "+70249748850"}
0005435425493	48F5FB	8588 252902	NATALYA NIKITINA	{"email": "nikitina.n.051978@postgrespro.ru", "phone": "+70983061720"}
0005435425494	9D3E04	9792 618442	ELENA ORLOVA	{"email": "orlovae-16091971@postgrespro.ru", "phone": "+70602421686"}
0005435425495	9D3E04	8252 538311	ALEKSANDR SIDOROV	{"phone": "+70678937628"}
0005435425496	C98715	4742 124576	RUSTAM ANDREEV	{"email": "andreev-r101968@postgrespro.ru", "phone": "+70672010600"}
0005435425497	828396	4016 131412	ANNA NIKITINA	{"email": "nikitina.a_051974@postgrespro.ru", "phone": "+70130347942"}
0005435425498	7DBA3A	3645 569490	LIDIYA SOLOVEVA	{"email": "lsoloveva-1972@postgrespro.ru", "phone": "+70447821557"}
0005435425499	1A2E55	7404 110259	VYACHESLAV IVANOV	{"phone": "+70761462519"}
0005435425500	1A2E55	1993 324133	ALEKSANDR FROLOV	{"email": "a_frolov_28111969@postgrespro.ru", "phone": "+70773053924"}
0005435425501	2A3CD2	9204 355717	MARINA ALEKSEEVA	{"email": "alekseeva.m.03091968@postgrespro.ru", "phone": "+70362843972"}
0005435425502	52C550	1674 889856	VLADISLAV NOVIKOV	{"phone": "+70370952094"}
0005435425503	E3462C	5539 944341	SERGEY SOROKIN	{"phone": "+70871720011"}
0005435425504	D7741D	8809 354347	LYUDMILA LOGINOVA	{"email": "loginovalyudmila_081970@postgrespro.ru", "phone": "+70513836264"}
0005435425505	D7741D	9153 564546	RAFAIL RODIONOV	{"phone": "+70059674509"}
0005435425506	D7741D	1663 762004	ALEKSANDR BORISOV	{"email": "a_borisov-31071979@postgrespro.ru", "phone": "+70379730303"}
0005435425507	E7F810	1633 897999	YULIYA TIMOFEEVA	{"email": "timofeevay17021969@postgrespro.ru", "phone": "+70792218918"}
0005435425508	38C63D	6701 077006	NATALYA BORISOVA	{"email": "borisova_natalya-10121976@postgrespro.ru", "phone": "+70911675033"}
0005435425509	38C63D	4638 318584	ANNA SOLOVEVA	{"phone": "+70153158944"}
0005435425510	F7A10F	1907 183877	MARIYA GORBUNOVA	{"phone": "+70925453202"}
0005435425511	F7A10F	7692 114948	ANDREY ISAEV	{"email": "andreyisaev_011971@postgrespro.ru", "phone": "+70430821957"}
0005435425512	4A7FA9	2091 550789	NAILYA ANDREEVA	{"phone": "+70527862606"}
0005435425513	4A7FA9	7569 752311	SERGEY BORISOV	{"phone": "+70257131034"}
0005435425514	454721	7756 178296	SVETLANA ORLOVA	{"email": "orlovasvetlana-15091966@postgrespro.ru", "phone": "+70839816454"}
0005435425515	65D101	6320 876015	NIKOLAY MEDVEDEV	{"phone": "+70963122058"}
0005435425516	C6E38F	0624 475012	RUSTAM PETROV	{"phone": "+70129800463"}
0005435425517	C6E38F	2519 635817	KIRILL SOKOLOV	{"email": "k_sokolov.28101965@postgrespro.ru", "phone": "+70929061916"}
0005435425518	C6E38F	7196 485824	LARISA STEPANOVA	{"email": "larisastepanova17051965@postgrespro.ru", "phone": "+70600822104"}
0005435425519	00255C	5998 937732	EKATERINA KUZNECOVA	{"email": "kuznecova-ekaterina.021978@postgrespro.ru", "phone": "+70957386814"}
0005435425520	00255C	8942 028621	EVGENIY PAVLOV	{"email": "pavlov.e.1973@postgrespro.ru", "phone": "+70301310963"}
0005435425521	DCC73F	9961 706664	LILIYA ALEKSANDROVA	{"phone": "+70100733309"}
0005435425522	DCC73F	7956 289305	VLADIMIR ABRAMOV	{"phone": "+70474448430"}
0005435425523	EDD156	0586 616615	EVGENIY GUSEV	{"email": "evgeniygusev14011975@postgrespro.ru", "phone": "+70517088512"}
0005435425524	4E8CCE	1014 880709	ALEKSANDR MAKAROV	{"phone": "+70985256062"}
0005435425525	7B7BF7	8308 310681	VLADISLAV STEPANOV	{"email": "vladislav-stepanov.101973@postgrespro.ru", "phone": "+70520954949"}
0005435425526	7B7BF7	1702 636692	PRASKOVYA FADEEVA	{"phone": "+70060136632"}
0005435425527	0835E1	6866 506486	SERGEY SIDOROV	{"phone": "+70856321942"}
0005435425528	0835E1	6208 730634	ANASTASIYA ILINA	{"email": "ilinaa24021977@postgrespro.ru", "phone": "+70297693032"}
0005435425529	68801E	0669 750166	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.09121959@postgrespro.ru", "phone": "+70244809394"}
0005435425530	CA1787	2443 523791	MARIYA OSIPOVA	{"phone": "+70908950407"}
0005435425531	A5BBFA	7326 174250	GRIGORIY VASILEV	{"email": "vasilev-g1955@postgrespro.ru", "phone": "+70540322495"}
0005435425532	A2F83E	5093 106896	ALEKSANDR POPOV	{"phone": "+70633517216"}
0005435425533	A2F83E	5781 777252	YAKOV SOKOLOV	{"phone": "+70925838355"}
0005435425534	7BC843	8864 900460	MARIYA KOLESNIKOVA	{"email": "m_kolesnikova_121973@postgrespro.ru", "phone": "+70720616123"}
0005435425535	3488CE	8612 966598	RINAT SOROKIN	{"email": "sorokin_r.1970@postgrespro.ru", "phone": "+70184624224"}
0005435425536	76B022	2034 228358	ANNA LUKYANOVA	{"email": "anna-lukyanova_1969@postgrespro.ru", "phone": "+70342366014"}
0005435425537	B9AB9B	4903 273269	MARGARITA NAZAROVA	{"phone": "+70789670916"}
0005435425538	B9AB9B	0649 948484	ALFIYA SIDOROVA	{"phone": "+70802251731"}
0005435425539	844A3E	9332 409571	MIKHAIL AFANASEV	{"phone": "+70212588983"}
0005435425540	844A3E	0783 010786	VIKTOR ZHUKOV	{"email": "v-zhukov-22101980@postgrespro.ru", "phone": "+70522927261"}
0005435425541	BE1F4D	5705 026953	EVGENIY ANTONOV	{"phone": "+70238374378"}
0005435425542	1DF09B	6588 192550	ALEKSEY STEPANOV	{"email": "a_stepanov-03041969@postgrespro.ru", "phone": "+70199188771"}
0005435425543	E04839	3849 218688	VIKTORIYA POPOVA	{"phone": "+70556760180"}
0005435425544	6E3831	7209 860341	YULIYA OSIPOVA	{"phone": "+70321663136"}
0005435425545	2C4750	9617 964852	VENIAMIN GAVRILOV	{"phone": "+70248032307"}
0005435425546	2C4750	1354 202802	VLADIMIR BELOV	{"phone": "+70813548540"}
0005435425547	699262	5469 221854	ANASTASIYA KONOVALOVA	{"email": "anastasiya_konovalova031985@postgrespro.ru", "phone": "+70507221092"}
0005435425548	3A703C	7096 987236	OLGA FILIPPOVA	{"email": "filippova.olga-09071968@postgrespro.ru", "phone": "+70085348678"}
0005435425549	3A703C	7707 941824	TAMARA YUDINA	{"email": "yudinatamara.031961@postgrespro.ru", "phone": "+70397884393"}
0005435425550	3A703C	7401 599191	ANDREY NIKOLAEV	{"phone": "+70262849703"}
0005435425551	430787	8408 459329	EVGENIY NOVIKOV	{"phone": "+70415673346"}
0005435425552	563415	5753 914001	NIKOLAY ROMANOV	{"phone": "+70282461615"}
0005435425553	563415	8942 643884	KSENIYA ALEKSEEVA	{"phone": "+70904475028"}
0005435425554	563415	3094 730384	MARGARITA MOROZOVA	{"phone": "+70885176854"}
0005435425555	472092	3742 727635	VLADIMIR BELOV	{"email": "belovvladimir-1979@postgrespro.ru", "phone": "+70243658180"}
0005435425556	701185	3671 357269	EKATERINA ALEKSANDROVA	{"email": "ealeksandrova011974@postgrespro.ru", "phone": "+70618348099"}
0005435425557	A1DFB0	2252 948673	NATALYA PAVLOVA	{"phone": "+70570592212"}
0005435425558	3BB17F	0009 546274	NADEZHDA ANTONOVA	{"email": "nantonova_01071971@postgrespro.ru", "phone": "+70288734955"}
0005435425559	536231	6429 588542	MIKHAIL ZAKHAROV	{"email": "mikhailzakharov-1966@postgrespro.ru", "phone": "+70725652936"}
0005435425560	536231	4752 413513	SERGEY NIKITIN	{"phone": "+70411058725"}
0005435425561	E752B5	8241 023918	SERGEY PAVLOV	{"email": "pavlov-sergey-091979@postgrespro.ru", "phone": "+70363223965"}
0005435425562	060BA1	6416 925356	LYUDMILA MIRONOVA	{"phone": "+70010122213"}
0005435425563	0A4111	0007 155517	ALEKSEY NIKOLAEV	{"email": "a_nikolaev_21071971@postgrespro.ru", "phone": "+70586825122"}
0005435425564	0A4111	5822 793147	ELENA ZAYCEVA	{"email": "zaycevaelena_09111977@postgrespro.ru", "phone": "+70634054318"}
0005435425565	026AE4	6337 019106	LYUBOV EGOROVA	{"email": "legorova.1977@postgrespro.ru", "phone": "+70498482322"}
0005435425566	026AE4	7915 097851	MARIYA FROLOVA	{"email": "mariyafrolova.111992@postgrespro.ru", "phone": "+70285557502"}
0005435425567	6376A5	3353 183495	MIKHAIL SOKOLOV	{"phone": "+70549551401"}
0005435425568	D41BBB	0106 868574	ANASTASIYA GORBUNOVA	{"email": "anastasiya.gorbunova.1963@postgrespro.ru", "phone": "+70148916173"}
0005435425569	BA31CE	0300 239011	FARID ROMANOV	{"email": "romanov-f101988@postgrespro.ru", "phone": "+70757396478"}
0005435425570	BA31CE	9468 964048	DENIS ALEKSANDROV	{"phone": "+70782598574"}
0005435425571	34BCDC	3671 971263	VLADIMIR KAZAKOV	{"email": "v_kazakov02081971@postgrespro.ru", "phone": "+70393907573"}
0005435425572	3CE67E	1161 859602	VALENTINA ABRAMOVA	{"email": "abramova_valentina.101972@postgrespro.ru", "phone": "+70598033930"}
0005435425573	3CE67E	1508 988062	ANNA LOGINOVA	{"email": "annaloginova_16121967@postgrespro.ru", "phone": "+70986607300"}
0005435425574	AF35FD	7381 811958	ELENA KUZNECOVA	{"email": "kuznecova.e_1957@postgrespro.ru", "phone": "+70694773544"}
0005435425575	AF35FD	1518 087242	NIKOLAY SOKOLOV	{"email": "sokolov.nikolay_021975@postgrespro.ru", "phone": "+70936439649"}
0005435425576	A90014	0746 933071	ELENA SOKOLOVA	{"phone": "+70195854623"}
0005435425577	2639EC	2402 397312	NADEZHDA ZHUKOVA	{"phone": "+70500762058"}
0005435425578	0D6D1E	0552 616021	ELENA GORBUNOVA	{"phone": "+70000774942"}
0005435425579	0D6D1E	6182 661853	VALERIY TIMOFEEV	{"phone": "+70585609369"}
0005435425580	A5F8B7	5841 422974	VYACHESLAV SOROKIN	{"phone": "+70188103004"}
0005435425581	A5F8B7	1151 017426	ALEKSEY SOLOVEV	{"phone": "+70967043920"}
0005435425582	50FBB6	0501 114655	YULIYA MIRONOVA	{"phone": "+70499622980"}
0005435425583	282988	2459 789745	MIKHAIL DENISOV	{"phone": "+70206423754"}
0005435425584	5B9AEF	5066 372427	TATYANA SEMENOVA	{"phone": "+70259569949"}
0005435425585	70863B	9017 719251	MARIYA KOZLOVA	{"phone": "+70096369987"}
0005435425586	70863B	1671 519550	PAVEL VOLKOV	{"phone": "+70413485418"}
0005435425587	A795F4	6556 955690	EGOR ZAKHAROV	{"email": "zakharov_egor1970@postgrespro.ru", "phone": "+70190934137"}
0005435425588	BD435B	5200 848475	IGOR VOROBEV	{"phone": "+70139422084"}
0005435425589	AE89D5	2966 024379	MIKHAIL MATVEEV	{"email": "m_matveev_051966@postgrespro.ru", "phone": "+70192624407"}
0005435425590	96DAB8	3699 661987	SVETLANA VOLKOVA	{"email": "volkova_svetlana.31121976@postgrespro.ru", "phone": "+70995910675"}
0005435425591	96DAB8	6948 135253	GRIGORIY DENISOV	{"email": "g.denisov_08081968@postgrespro.ru", "phone": "+70832772507"}
0005435425592	96DAB8	3553 609307	TATYANA ANDREEVA	{"phone": "+70239626086"}
0005435425593	2AD7EF	3385 727700	VALERIYA FOMINA	{"email": "fomina_valeriya31071968@postgrespro.ru", "phone": "+70063265720"}
0005435425594	0573BD	2684 798717	TATYANA LAZAREVA	{"phone": "+70335765643"}
0005435425595	F777C0	8635 552971	ANATOLIY STEPANOV	{"email": "a-stepanov_1976@postgrespro.ru", "phone": "+70136541853"}
0005435425596	F777C0	4029 842162	ILYA KOZLOV	{"phone": "+70611799937"}
0005435425597	972861	0122 776377	SERGEY IVANOV	{"email": "ivanov-s_01051963@postgrespro.ru", "phone": "+70268965753"}
0005435425598	972861	5909 341733	NATALYA ISAEVA	{"email": "nisaeva15051973@postgrespro.ru", "phone": "+70423199124"}
0005435425599	B0EB84	1315 961034	ANDREY GRIGOREV	{"email": "andrey.grigorev101983@postgrespro.ru", "phone": "+70948360849"}
0005435425600	DD1739	1990 739172	MATVEY PETROV	{"phone": "+70144898848"}
0005435425601	DD1739	2588 562464	ANATOLIY PETROV	{"email": "a-petrov-111980@postgrespro.ru", "phone": "+70582466721"}
0005435425602	929ABE	4634 110067	NATALYA KULIKOVA	{"phone": "+70237635293"}
0005435425603	F935DA	1094 935547	LYUDMILA IVANOVA	{"phone": "+70142537509"}
0005435425604	F935DA	3750 069420	SVETLANA SMIRNOVA	{"phone": "+70593682719"}
0005435425605	E92D56	5090 001333	NATALYA KULIKOVA	{"phone": "+70172762599"}
0005435425606	0137B7	3990 073157	VALENTINA DMITRIEVA	{"phone": "+70418743233"}
0005435425607	57F849	1083 481445	IRINA ROMANOVA	{"email": "romanova-irina_24051965@postgrespro.ru", "phone": "+70668371742"}
0005435425608	3C0708	4648 024573	PAVEL SCHERBAKOV	{"phone": "+70951518344"}
0005435425609	3C0708	7666 280344	ANASTASIYA BORISOVA	{"email": "borisova-a_121984@postgrespro.ru", "phone": "+70020010040"}
0005435425610	48A6D6	7431 101862	EKATERINA LUKYANOVA	{"phone": "+70560071048"}
0005435425611	48A6D6	0811 610633	TAMARA EFIMOVA	{"email": "t.efimova17111972@postgrespro.ru", "phone": "+70456611622"}
0005435425612	0D2C8F	4902 578445	VYACHESLAV IVANOV	{"phone": "+70434866893"}
0005435425613	0D2C8F	4044 284422	NATALYA KOVALEVA	{"phone": "+70202184068"}
0005435425614	79C947	6960 846625	LILIYA NAUMOVA	{"email": "naumova.liliya.1975@postgrespro.ru", "phone": "+70921801709"}
0005435425615	8166A1	6270 704644	IRINA GERASIMOVA	{"email": "irina.gerasimova1972@postgrespro.ru", "phone": "+70551437178"}
0005435425616	088645	5304 404733	VALENTIN TIKHONOV	{"phone": "+70700386658"}
0005435425617	088645	1285 113151	DMITRIY OSIPOV	{"email": "osipov-dmitriy-071958@postgrespro.ru", "phone": "+70617606706"}
0005435425618	405A79	2088 037176	GALINA IVANOVA	{"email": "ivanova.galina-121983@postgrespro.ru", "phone": "+70474427998"}
0005435425619	F7C7CA	8988 792627	VERONIKA KUDRYASHOVA	{"phone": "+70666910894"}
0005435425620	F7C7CA	1064 118254	OLGA VLASOVA	{"phone": "+70833330643"}
0005435425621	808F63	9447 527833	ALEKSANDR VASILEV	{"email": "avasilev-1969@postgrespro.ru", "phone": "+70375428706"}
0005435425622	E26E09	0188 964419	VLADIMIR POPOV	{"phone": "+70018678795"}
0005435425623	B3D48E	8539 051571	OKSANA MATVEEVA	{"email": "matveevaoksana_1972@postgrespro.ru", "phone": "+70106217684"}
0005435425624	605D3D	8768 320164	EKATERINA POTAPOVA	{"phone": "+70411605901"}
0005435425625	465E3A	1965 807748	SVETLANA KUZNECOVA	{"email": "kuznecovas_111973@postgrespro.ru", "phone": "+70499516410"}
0005435425626	C1B639	9308 059681	ALEKSANDRA ILINA	{"phone": "+70946296540"}
0005435425627	C1B639	8953 333061	ALEKSEY DMITRIEV	{"phone": "+70386604628"}
0005435425628	11A76F	1415 551250	MAKSIM SOROKIN	{"email": "maksimsorokin-15101970@postgrespro.ru", "phone": "+70649012503"}
0005435425629	AFCC64	6610 475567	MAKSIM DMITRIEV	{"email": "dmitriev.m1971@postgrespro.ru", "phone": "+70797320379"}
0005435425630	AFCC64	9243 224763	DMITRIY FEDOTOV	{"phone": "+70082765800"}
0005435425631	44221D	8354 337229	ROBERT ZAYCEV	{"phone": "+70473324055"}
0005435425632	E1251E	4640 968408	ELENA ALEKSEEVA	{"email": "elena_alekseeva_041976@postgrespro.ru", "phone": "+70869545701"}
0005435425633	47AE0B	6962 345628	VIKTOR ALEKSEEV	{"email": "viktor.alekseev1974@postgrespro.ru", "phone": "+70668507435"}
0005435425634	4D16A3	1433 364927	MARINA MARTYNOVA	{"email": "m-martynova_1976@postgrespro.ru", "phone": "+70901917820"}
0005435425635	20E9B0	0383 317227	MARIYA NIKOLAEVA	{"email": "nikolaevamariya081973@postgrespro.ru", "phone": "+70494481144"}
0005435425636	CD1BCE	7779 058371	MATVEY VOLKOV	{"phone": "+70032237629"}
0005435425637	F9102D	0036 585212	DMITRIY PETROV	{"email": "petrovdmitriy051967@postgrespro.ru", "phone": "+70433388098"}
0005435425638	F9102D	4984 653176	IRINA KRASNOVA	{"phone": "+70923221234"}
0005435425639	F9102D	4414 619407	VIOLETTA EGOROVA	{"email": "v-egorova.1969@postgrespro.ru", "phone": "+70739889381"}
0005435425640	5758C0	6412 596285	EKATERINA EFIMOVA	{"email": "e-efimova_1973@postgrespro.ru", "phone": "+70243587996"}
0005435425641	9569C2	4622 745922	NADEZHDA ZAKHAROVA	{"email": "zakharovan-061973@postgrespro.ru", "phone": "+70318805075"}
0005435425642	B137CB	6665 699032	EKATERINA MALYSHEVA	{"phone": "+70691401484"}
0005435425643	33FE81	8276 416790	VALERIY VOLKOV	{"email": "valeriy-volkov1966@postgrespro.ru", "phone": "+70089778368"}
0005435425644	44BAC3	5643 422627	LIDIYA MOROZOVA	{"phone": "+70087369766"}
0005435425645	44BAC3	8418 383094	VERA NIKOLAEVA	{"email": "veranikolaeva-13021979@postgrespro.ru", "phone": "+70594923523"}
0005435425646	81D12D	4088 343060	EVGENIY SAVELEV	{"phone": "+70105116643"}
0005435425647	C6617A	9697 176796	ALEKSEY VASILEV	{"email": "a_vasilev_121975@postgrespro.ru", "phone": "+70803512719"}
0005435425648	81400B	1664 229990	KIRILL BORISOV	{"email": "kirillborisov_091972@postgrespro.ru", "phone": "+70822359605"}
0005435425649	8FAC4B	2536 430416	VYACHESLAV GAVRILOV	{"email": "gavrilovvyacheslav.21111963@postgrespro.ru", "phone": "+70244580831"}
0005435425650	2E8C7F	1660 415267	RAMIS KARPOV	{"phone": "+70545749206"}
0005435425651	2E8C7F	1147 235772	SVETLANA VASILEVA	{"phone": "+70779665944"}
0005435425652	876654	6317 374079	LYUDMILA PETROVA	{"email": "petrova-lyudmila-1983@postgrespro.ru", "phone": "+70511817884"}
0005435425653	876654	3458 392707	EVGENIY ORLOV	{"phone": "+70921706366"}
0005435425654	454195	7228 395593	OLEG OSIPOV	{"email": "osipov-oleg.061964@postgrespro.ru", "phone": "+70078755046"}
0005435425655	48F579	6643 081287	ANDREY IVANOV	{"phone": "+70099515170"}
0005435425656	48F579	5653 422442	DANIIL DMITRIEV	{"email": "ddmitriev031972@postgrespro.ru", "phone": "+70563212571"}
0005435425657	89B9CC	4413 782473	ANDREY MIKHAYLOV	{"email": "mikhaylovandrey1959@postgrespro.ru", "phone": "+70097983989"}
0005435425658	6DB84A	2767 921527	VIKTOR KUZNECOV	{"email": "viktor_kuznecov03081971@postgrespro.ru", "phone": "+70350616252"}
0005435425659	78294F	7610 941261	ALEKSEY IVANOV	{"phone": "+70497851272"}
0005435425660	332EC4	7503 262250	NADEZHDA FILIPPOVA	{"email": "nadezhda-filippova_101975@postgrespro.ru", "phone": "+70303657497"}
0005435425661	332EC4	8435 291656	EGOR KOROLEV	{"phone": "+70320362633"}
0005435425662	E42AD5	6112 301286	RAISA NESTEROVA	{"email": "nesterova-raisa-14061983@postgrespro.ru", "phone": "+70846416440"}
0005435425663	E42AD5	4376 160054	SERGEY KULIKOV	{"phone": "+70007993356"}
0005435425664	D87FF4	8284 648095	RUZALIYA FEDOROVA	{"phone": "+70474874509"}
0005435425665	D87FF4	7418 111445	VIKTOR ZHURAVLEV	{"email": "zhuravlevviktor.041972@postgrespro.ru", "phone": "+70249281004"}
0005435425666	BBAAE6	0746 693985	MARINA ARKHIPOVA	{"phone": "+70067450310"}
0005435425667	309988	5088 250629	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov-19101981@postgrespro.ru", "phone": "+70125269341"}
0005435425668	309988	0817 013724	NATALYA MIRONOVA	{"phone": "+70959942625"}
0005435425669	514D78	2919 147885	ANTONINA ANDREEVA	{"phone": "+70287831647"}
0005435425670	514D78	5162 851541	NATALYA NAZAROVA	{"phone": "+70972303836"}
0005435425671	5FA0C4	0436 640262	VALENTINA YUDINA	{"email": "yudina.valentina_01021981@postgrespro.ru", "phone": "+70556920020"}
0005435425672	C44F89	1302 671897	SERGEY MAKAROV	{"email": "makarov-sergey1975@postgrespro.ru", "phone": "+70461271462"}
0005435425673	51E101	2775 840275	ALEKSANDR MIKHAYLOV	{"email": "aleksandr_mikhaylov.1980@postgrespro.ru", "phone": "+70795060402"}
0005435425674	51E101	9811 515298	TAMARA AFANASEVA	{"phone": "+70872054592"}
0005435425675	51E101	5546 690230	NINEL ANDREEVA	{"email": "nandreeva_16071978@postgrespro.ru", "phone": "+70185859666"}
0005435425676	FAA198	7652 641176	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev031970@postgrespro.ru", "phone": "+70440842573"}
0005435425677	F3A8A5	8111 351328	ZINAIDA KARPOVA	{"email": "z-karpova_09011970@postgrespro.ru", "phone": "+70793518299"}
0005435425678	F3FA17	1436 906636	MAKSIM SCHERBAKOV	{"email": "maksim.scherbakov04111952@postgrespro.ru", "phone": "+70147999614"}
0005435425679	F3FA17	5379 333774	MARYAM NESTEROVA	{"phone": "+70528167828"}
0005435425680	957A24	6629 831859	MIKHAIL ZAYCEV	{"email": "mzaycev_1969@postgrespro.ru", "phone": "+70251066668"}
0005435425681	C6BF87	4847 248986	NIKOLAY MELNIKOV	{"email": "melnikov.nikolay_091979@postgrespro.ru", "phone": "+70956412143"}
0005435425682	35A0F6	3540 306828	LYUDMILA RODIONOVA	{"phone": "+70648194604"}
0005435425683	35A0F6	2740 383360	DANILA PETROV	{"phone": "+70507898199"}
0005435425684	35A0F6	3555 230204	LARISA ZAYCEVA	{"email": "l-zayceva.02061965@postgrespro.ru", "phone": "+70758959842"}
0005435425685	CE6B40	5546 532408	EKATERINA NAZAROVA	{"phone": "+70903137833"}
0005435425686	CE6B40	7551 727652	VALENTINA KAZAKOVA	{"email": "v_kazakova_041980@postgrespro.ru", "phone": "+70634643320"}
0005435425687	0CE82A	9487 279993	ANDREY ANDREEV	{"phone": "+70027245808"}
0005435425688	91C460	7570 118215	ZAKHAR VOLKOV	{"email": "z-volkov-09071968@postgrespro.ru", "phone": "+70934787489"}
0005435425689	F3A5C5	1213 258832	ALEKSANDR IVANOV	{"phone": "+70676321606"}
0005435425690	F3A5C5	7501 693132	VLADIMIR SERGEEV	{"email": "vladimir_sergeev17021959@postgrespro.ru", "phone": "+70152745309"}
0005435425691	F3A5C5	6085 942607	IRINA FOMINA	{"email": "fominai101975@postgrespro.ru", "phone": "+70980083913"}
0005435425692	13B46F	6221 468596	VALENTINA SAVELEVA	{"email": "saveleva.v1972@postgrespro.ru", "phone": "+70718987657"}
0005435425693	13B46F	3528 516906	MIKHAIL TIKHONOV	{"phone": "+70904353842"}
0005435425694	37E5EA	3345 023126	SERGEY KOZLOV	{"email": "sergey.kozlov1966@postgrespro.ru", "phone": "+70866841126"}
0005435425695	37E5EA	6302 886869	KLAVDIYA KUZNECOVA	{"email": "kuznecova-klavdiya-17011972@postgrespro.ru", "phone": "+70310874766"}
0005435425696	3F1AE0	2006 525274	LYUBOV YAKOVLEVA	{"phone": "+70192161469"}
0005435425697	7BAE64	7416 340224	ALEKSANDR SIDOROV	{"phone": "+70198589770"}
0005435425698	7BAE64	6117 650113	DMITRIY GORBUNOV	{"email": "gorbunovd1969@postgrespro.ru", "phone": "+70335968612"}
0005435425699	C9B633	9295 387672	ALEKSANDR ANDREEV	{"phone": "+70524888492"}
0005435425700	2F1D95	0707 503480	ALEKSANDR NAZAROV	{"phone": "+70214683802"}
0005435425701	CB2995	1169 754471	GALINA KOROLEVA	{"email": "g_koroleva1971@postgrespro.ru", "phone": "+70519228424"}
0005435425702	36AD03	9525 130338	SERGEY ROMANOV	{"phone": "+70221366464"}
0005435425703	36AD03	9683 793487	YURIY VASILEV	{"phone": "+70331429798"}
0005435425704	F3CFD7	5821 326488	MIKHAIL SCHERBAKOV	{"phone": "+70125198622"}
0005435425705	4BFA8B	4243 329628	TATYANA ORLOVA	{"email": "orlova.t25111966@postgrespro.ru", "phone": "+70268976300"}
0005435425706	E8E032	3647 352457	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov.02101971@postgrespro.ru", "phone": "+70293706344"}
0005435425707	E8E032	2759 809742	ANTONINA KONOVALOVA	{"email": "antonina.konovalova01041980@postgrespro.ru", "phone": "+70384866332"}
0005435425708	E4BB7D	3311 092491	SERGEY IVANOV	{"email": "ivanov.s-011972@postgrespro.ru", "phone": "+70721590716"}
0005435425709	E4BB7D	4487 129093	LYUDMILA KUZNECOVA	{"email": "kuznecova.l_091977@postgrespro.ru", "phone": "+70859410399"}
0005435425710	08FF12	8391 630944	LYUBOV NIKITINA	{"phone": "+70290790213"}
0005435425711	08FF12	8573 665182	NATALYA POTAPOVA	{"email": "potapova_natalya_01111974@postgrespro.ru", "phone": "+70192610315"}
0005435425712	D6A7D8	2901 757001	OLGA OSIPOVA	{"email": "olga.osipova1978@postgrespro.ru", "phone": "+70413881159"}
0005435425713	C71220	9395 512424	ANTONINA POLYAKOVA	{"phone": "+70990345880"}
0005435425714	C71220	9322 531798	VALENTINA YAKOVLEVA	{"phone": "+70142155243"}
0005435425715	ADB791	0795 445246	VALENTINA BELYAEVA	{"phone": "+70284338266"}
0005435425716	2FEBA9	6546 904193	EVGENIY FEDOROV	{"phone": "+70965411424"}
0005435425717	9EF580	0682 660263	VALENTINA PAVLOVA	{"phone": "+70728913889"}
0005435425718	F50E41	5294 863645	DANIL ORLOV	{"phone": "+70783348803"}
0005435425719	F50E41	1700 457056	TATYANA FEDOROVA	{"email": "tatyana_fedorova30101975@postgrespro.ru", "phone": "+70809206972"}
0005435425720	D86013	1748 660697	SERGEY ZAKHAROV	{"phone": "+70964315306"}
0005435425721	FEE3BE	3902 778505	VLADIMIR KRASNOV	{"phone": "+70599112149"}
0005435425722	FEE3BE	8498 593672	GALINA KAZAKOVA	{"email": "g.kazakova1969@postgrespro.ru", "phone": "+70945495675"}
0005435425723	FEE3BE	5217 996507	VIKTORIYA POPOVA	{"email": "popova_v.10071975@postgrespro.ru", "phone": "+70085169161"}
0005435425724	19DB52	4547 153047	ANNA PAVLOVA	{"phone": "+70813779826"}
0005435425725	781753	6668 012967	SVETLANA IVANOVA	{"email": "svetlanaivanova-091974@postgrespro.ru", "phone": "+70085334857"}
0005435425726	F95650	6607 496299	VADIM VLASOV	{"email": "vlasov_v.111974@postgrespro.ru", "phone": "+70633951176"}
0005435425727	F95650	7903 064920	ALEKSEY KOZLOV	{"email": "kozlov.aleksey_031975@postgrespro.ru", "phone": "+70443623275"}
0005435425728	E7A745	0077 894139	NATALYA TARASOVA	{"phone": "+70684475927"}
0005435425729	CFF436	6581 495203	VIKTOR IVANOV	{"email": "ivanov.viktor-21051959@postgrespro.ru", "phone": "+70587383840"}
0005435425730	CFF436	5871 135570	ALEKSANDR MOROZOV	{"email": "aleksandr_morozov-16081970@postgrespro.ru", "phone": "+70846335774"}
0005435425731	607916	3047 597475	VASILIY SERGEEV	{"phone": "+70938548144"}
0005435425732	607916	8096 984103	ANNA ALEKSANDROVA	{"email": "annaaleksandrova071979@postgrespro.ru", "phone": "+70298770691"}
0005435425733	1DB07F	3776 471678	VLADIMIR KULIKOV	{"phone": "+70501327305"}
0005435425734	14FEC6	0414 901194	DARYA EFREMOVA	{"phone": "+70609875056"}
0005435425735	396C83	0127 745753	OLESYA NESTEROVA	{"email": "nesterova-olesya_111972@postgrespro.ru", "phone": "+70256304061"}
0005435425736	61E968	8274 155774	ALEKSANDR ROMANOV	{"phone": "+70142320809"}
0005435425737	135FBD	6073 124861	OLEG SOKOLOV	{"email": "sokolovoleg1967@postgrespro.ru", "phone": "+70947365871"}
0005435425738	7A0F98	3683 389844	POLINA GUSEVA	{"phone": "+70818806990"}
0005435425739	7A0F98	3694 878449	NADEZHDA KALININA	{"phone": "+70381854309"}
0005435425740	7A0F98	2307 619279	ANATOLIY ZAKHAROV	{"email": "zakharov_anatoliy-101970@postgrespro.ru", "phone": "+70695054805"}
0005435425741	3BC4DB	8666 246721	MIKHAIL YAKOVLEV	{"phone": "+70216220433"}
0005435425742	3BC4DB	8214 657037	VALERIY YAKOVLEV	{"email": "vyakovlev.121978@postgrespro.ru", "phone": "+70820907564"}
0005435425743	D145EB	0901 651195	NATALYA SERGEEVA	{"email": "sergeeva_n_091972@postgrespro.ru", "phone": "+70228100351"}
0005435425744	D145EB	0871 844791	ROMAN YAKOVLEV	{"phone": "+70050026095"}
0005435425745	D145EB	0254 203254	ALEKSANDRA KUZNECOVA	{"email": "aleksandra-kuznecova-061968@postgrespro.ru", "phone": "+70550823105"}
0005435425746	6BD3FD	0685 224232	ELENA KOMAROVA	{"email": "komarova_elena-061970@postgrespro.ru", "phone": "+70223053110"}
0005435425747	73CDF2	9814 839801	DMITRIY POPOV	{"email": "popov_dmitriy.1970@postgrespro.ru", "phone": "+70811670293"}
0005435425748	73CDF2	4226 672446	ANTON MAKAROV	{"email": "amakarov_19101977@postgrespro.ru", "phone": "+70300757172"}
0005435425749	C63E08	5883 037327	VADIM GERASIMOV	{"email": "gerasimov_vadim091979@postgrespro.ru", "phone": "+70301592708"}
0005435425750	C63E08	6845 862940	EVGENIY PAVLOV	{"email": "evgeniy.pavlov03081966@postgrespro.ru", "phone": "+70964965876"}
0005435425751	FBB7E9	3857 653274	KRISTINA SAVELEVA	{"email": "saveleva-k.081972@postgrespro.ru", "phone": "+70417267428"}
0005435425752	FBB7E9	6951 553888	SERGEY ZAKHAROV	{"phone": "+70485530278"}
0005435425753	714B5D	0637 169433	DARYA MIKHAYLOVA	{"email": "darya.mikhaylova.1978@postgrespro.ru", "phone": "+70446025058"}
0005435425754	76DDE9	6144 072461	MARGARITA POPOVA	{"email": "popova_margarita.09011974@postgrespro.ru", "phone": "+70516614139"}
0005435425755	76DDE9	7101 268331	VALENTINA IVANOVA	{"email": "ivanovav-011982@postgrespro.ru", "phone": "+70367238994"}
0005435425756	BD1CA1	6095 411534	MIKHAIL KUZNECOV	{"phone": "+70799601491"}
0005435425757	DCAB16	0254 497494	VITALIY GORBUNOV	{"phone": "+70504169337"}
0005435425758	4B93A2	2211 406666	EKATERINA NOVIKOVA	{"phone": "+70618399492"}
0005435425759	3C1F15	8960 788600	IRINA NOVIKOVA	{"phone": "+70496774076"}
0005435425760	A191AE	1172 573154	VLADIMIR MIRONOV	{"phone": "+70365745782"}
0005435425761	3E9834	4764 927725	NADEZHDA KAZAKOVA	{"phone": "+70646919680"}
0005435425762	3E9834	2907 853162	ZOYA ANTONOVA	{"phone": "+70699998506"}
0005435425763	3E9834	6045 880155	ANNA KALININA	{"email": "annakalinina.051970@postgrespro.ru", "phone": "+70768880297"}
0005435425764	D04574	0420 027992	EVGENIY TIMOFEEV	{"email": "e_timofeev.1964@postgrespro.ru", "phone": "+70000331732"}
0005435425765	96A6EC	8998 447571	ANDREY NAUMOV	{"email": "andrey.naumov_17061963@postgrespro.ru", "phone": "+70843474033"}
0005435425766	6BE10E	6690 314638	TAMARA FEDOROVA	{"email": "t_fedorova_1967@postgrespro.ru", "phone": "+70272912048"}
0005435425767	0BEDA0	0640 094923	NADEZHDA KUZMINA	{"email": "kuzmina-nadezhda_081978@postgrespro.ru", "phone": "+70192820866"}
0005435425768	554632	2388 865700	VLADIMIR KUZNECOV	{"email": "vladimir_kuznecov-04041958@postgrespro.ru", "phone": "+70190492416"}
0005435425769	554632	8456 083186	EVGENIY TARASOV	{"email": "e-tarasov-011978@postgrespro.ru", "phone": "+70688192615"}
0005435425770	554632	6133 032634	IRINA KUZNECOVA	{"email": "i.kuznecova_1975@postgrespro.ru", "phone": "+70802349586"}
0005435425771	50B9C1	7850 579030	SVETLANA IVANOVA	{"email": "ivanova.s14091965@postgrespro.ru", "phone": "+70733699541"}
0005435425772	0F55CA	7078 361206	ANASTASIYA ANDREEVA	{"phone": "+70296354038"}
0005435425773	250205	1583 799173	YANA KOZLOVA	{"phone": "+70018337114"}
0005435425774	4EEDB5	0563 939469	SVETLANA YAKOVLEVA	{"email": "s.yakovleva_13091969@postgrespro.ru", "phone": "+70081548090"}
0005435425775	57FA7E	4806 434989	VASILIY TARASOV	{"phone": "+70380200223"}
0005435425776	938A5A	6600 677028	IVAN GAVRILOV	{"email": "gavrilov_ivan18061975@postgrespro.ru", "phone": "+70360388239"}
0005435425777	5BF58C	2543 354816	VALENTINA ZHURAVLEVA	{"email": "valentina.zhuravleva_021978@postgrespro.ru", "phone": "+70573016934"}
0005435425778	207F53	8515 533948	NIKOLAY PAVLOV	{"email": "nikolaypavlov.031983@postgrespro.ru", "phone": "+70870263526"}
0005435425779	9B0D1B	4506 935141	MARIYA NAUMOVA	{"email": "m_naumova-1971@postgrespro.ru", "phone": "+70681859353"}
0005435425780	9B0D1B	9919 736739	INNA IVANOVA	{"phone": "+70889581974"}
0005435425781	4536C8	1680 588454	ZINAIDA ANDREEVA	{"phone": "+70143332989"}
0005435425782	17030F	7752 949949	NATALYA BARANOVA	{"phone": "+70667832225"}
0005435425783	88E49D	4512 647570	EVGENIY SOKOLOV	{"phone": "+70654202248"}
0005435425784	D25A62	8747 779857	VITALIY GORBUNOV	{"email": "vitaliy_gorbunov-091974@postgrespro.ru", "phone": "+70834021435"}
0005435425785	D25A62	1212 426178	NIKOLAY MIKHAYLOV	{"email": "n.mikhaylov25061977@postgrespro.ru", "phone": "+70933438165"}
0005435425786	79ECD1	1141 522568	DARYA ABRAMOVA	{"email": "d-abramova.1976@postgrespro.ru", "phone": "+70801264927"}
0005435425787	0151CA	9232 690166	EKATERINA ISAEVA	{"phone": "+70993566348"}
0005435425788	A4D6BF	7915 878076	MATVEY SIDOROV	{"email": "matvey_sidorov31121982@postgrespro.ru", "phone": "+70855847089"}
0005435425789	E42DD1	9245 482341	GRIGORIY KUZNECOV	{"email": "kuznecovgrigoriy_1961@postgrespro.ru", "phone": "+70123593238"}
0005435425790	C7CFFC	3776 509667	LYUBOV KOZLOVA	{"email": "kozlova_lyubov_1977@postgrespro.ru", "phone": "+70712044258"}
0005435425791	224EB7	4040 375952	YURIY KUZNECOV	{"email": "yuriy.kuznecov_1990@postgrespro.ru", "phone": "+70094135007"}
0005435425792	F801EA	3730 211504	ALEKSEY OSIPOV	{"phone": "+70298103238"}
0005435425793	F801EA	3304 233483	SERGEY VASILEV	{"email": "s_vasilev_1977@postgrespro.ru", "phone": "+70316029047"}
0005435425794	F801EA	5272 412642	SERGEY SOROKIN	{"phone": "+70633434014"}
0005435425795	48AD3E	3885 042028	ARTEM SIDOROV	{"email": "sidorova1965@postgrespro.ru", "phone": "+70207637562"}
0005435425796	D1E31C	8465 567336	NATALIYA LEBEDEVA	{"email": "lebedeva_n-1966@postgrespro.ru", "phone": "+70226641912"}
0005435425797	FB16D7	1210 607339	ALEKSANDR ALEKSANDROV	{"email": "aaleksandrov1958@postgrespro.ru", "phone": "+70533304178"}
0005435425798	4E144B	3233 572795	VLADISLAV BORISOV	{"email": "vborisov.051975@postgrespro.ru", "phone": "+70723975522"}
0005435425799	5981CD	3293 873565	ALEKSANDR IVANOV	{"phone": "+70754233399"}
0005435425800	5981CD	4752 320775	NIKOLAY IVANOV	{"phone": "+70814306672"}
0005435425801	5981CD	4518 570173	NINA NOVIKOVA	{"email": "novikova_n_101975@postgrespro.ru", "phone": "+70969726225"}
0005435425802	3BA033	9135 986382	TATYANA DENISOVA	{"email": "denisova.tatyana-02081969@postgrespro.ru", "phone": "+70036444176"}
0005435425803	64AA8C	9305 235790	MARINA KUZNECOVA	{"email": "kuznecova-marina.091978@postgrespro.ru", "phone": "+70783089102"}
0005435425804	F5A048	5043 535842	ZINAIDA PAVLOVA	{"phone": "+70622060490"}
0005435425805	F5A048	2921 270167	EVGENIY EGOROV	{"phone": "+70108861456"}
0005435425806	332146	7726 989132	ROMAN GORBUNOV	{"phone": "+70417189180"}
0005435425807	332146	4097 712452	IRINA VASILEVA	{"email": "vasilevairina.22061984@postgrespro.ru", "phone": "+70521530087"}
0005435425808	699B26	5765 069791	ALINA GRISHINA	{"email": "agrishina_111962@postgrespro.ru", "phone": "+70354215290"}
0005435425809	232260	2593 544922	EKATERINA DENISOVA	{"email": "ekaterinadenisova.051968@postgrespro.ru", "phone": "+70589048392"}
0005435425810	232260	8797 592612	VITALIY PAVLOV	{"email": "pavlov_v1969@postgrespro.ru", "phone": "+70398080046"}
0005435425811	4C6349	6485 709894	VALENTINA MAKAROVA	{"email": "makarova.valentina_18101955@postgrespro.ru", "phone": "+70260932297"}
0005435425812	89C663	4243 280876	EVGENIY BELOV	{"phone": "+70194024444"}
0005435425813	3271A9	7947 855511	NATALYA MALYSHEVA	{"email": "natalyamalysheva10081969@postgrespro.ru", "phone": "+70970072726"}
0005435425814	07F0D1	2934 800026	NATALYA ANDREEVA	{"phone": "+70335929475"}
0005435425815	041B68	3190 517491	VALENTINA ZHURAVLEVA	{"email": "valentina-zhuravleva09041982@postgrespro.ru", "phone": "+70468860079"}
0005435425816	041B68	4537 318656	ALEKSANDR TIKHONOV	{"email": "a-tikhonov1970@postgrespro.ru", "phone": "+70847001761"}
0005435425817	F932A8	8420 232392	ALEKSANDR KUZNECOV	{"email": "aleksandrkuznecov_011978@postgrespro.ru", "phone": "+70913832657"}
0005435425818	F932A8	8209 674161	ANDREY BONDARENKO	{"email": "andrey-bondarenko061978@postgrespro.ru", "phone": "+70224429357"}
0005435425819	C5D1B2	5159 403848	ANDREY VLASOV	{"email": "vlasov.a.1982@postgrespro.ru", "phone": "+70564695987"}
0005435425820	FD9F8C	5869 272549	RAVILYA LUKYANOVA	{"email": "lukyanovar.17081976@postgrespro.ru", "phone": "+70452282440"}
0005435425821	FD9F8C	6678 785931	NATALYA LAZAREVA	{"phone": "+70263605494"}
0005435425822	1A30C6	5635 176246	ALEKSEY NAUMOV	{"email": "naumov-a-051977@postgrespro.ru", "phone": "+70848232391"}
0005435425823	34F4AA	1067 918024	ANNA SMIRNOVA	{"phone": "+70257991181"}
0005435425824	34F4AA	8046 363756	ANDREY IVANOV	{"phone": "+70804118694"}
0005435425825	5C56C3	0088 582843	SVETLANA KISELEVA	{"email": "kiseleva_svetlana.011960@postgrespro.ru", "phone": "+70116566208"}
0005435425826	B8EBF5	9268 675736	VIKTORIYA FEDOROVA	{"email": "vfedorova_1973@postgrespro.ru", "phone": "+70880825785"}
0005435425827	B8EBF5	7001 285721	SERGEY SOLOVEV	{"email": "solovev.sergey.111972@postgrespro.ru", "phone": "+70279812212"}
0005435425828	6C3D3B	8685 462273	OLEG KOZLOV	{"phone": "+70532336751"}
0005435425829	1F09F0	4320 136153	MARIYA FADEEVA	{"phone": "+70222273919"}
0005435425830	253EE7	4032 176369	ELIZAVETA BORISOVA	{"phone": "+70632870692"}
0005435425831	98F48C	7983 986060	NINA MELNIKOVA	{"email": "nina.melnikova01031970@postgrespro.ru", "phone": "+70110104206"}
0005435425832	98F48C	8674 475271	LYUBOV FILIPPOVA	{"phone": "+70408344336"}
0005435425833	5BE5CB	5082 385650	TATYANA VLASOVA	{"email": "t_vlasova101971@postgrespro.ru", "phone": "+70055480519"}
0005435425834	637D09	6349 444792	GEORGIY GUSEV	{"phone": "+70993843241"}
0005435425835	6B5341	8477 663429	EKATERINA VASILEVA	{"phone": "+70377769218"}
0005435425836	647F2B	1158 209066	ANASTASIYA RODIONOVA	{"phone": "+70714523440"}
0005435425837	647F2B	6610 219090	LYUBOV ISAEVA	{"email": "l.isaeva1980@postgrespro.ru", "phone": "+70583573526"}
0005435425838	FE371A	9178 992921	SERGEY NIKOLAEV	{"email": "nikolaevsergey.1974@postgrespro.ru", "phone": "+70772361832"}
0005435425839	DD29D1	6973 061589	YULIYA FOMINA	{"phone": "+70409579941"}
0005435425840	DD29D1	2999 978736	DMITRIY AFANASEV	{"email": "d_afanasev-27041971@postgrespro.ru", "phone": "+70036065536"}
0005435425841	C902B7	3776 506250	NADEZHDA TIKHONOVA	{"email": "tikhonovanadezhda.02111975@postgrespro.ru", "phone": "+70385114643"}
0005435425842	A16668	1350 994276	ELENA NAZAROVA	{"phone": "+70699196863"}
0005435425843	EBAB12	1305 861749	VASILIY KUDRYASHOV	{"phone": "+70406032822"}
0005435425844	A894EB	6572 288967	ALEKSANDR NIKOLAEV	{"phone": "+70446302951"}
0005435425845	4C9C64	1150 623393	DANIIL SAVELEV	{"email": "savelev.d.091968@postgrespro.ru", "phone": "+70487970295"}
0005435425846	4C9C64	4141 924414	EGOR SOROKIN	{"phone": "+70176828927"}
0005435425847	C14270	5380 106998	VALENTINA YUDINA	{"email": "yudinav22061966@postgrespro.ru", "phone": "+70309222543"}
0005435425848	C14270	4478 813528	ARKADIY TIMOFEEV	{"email": "timofeev_a1979@postgrespro.ru", "phone": "+70887165071"}
0005435425849	8F3398	3311 917744	ALEKSANDR ISAEV	{"email": "a.isaev.101977@postgrespro.ru", "phone": "+70019489843"}
0005435425850	8F3398	3017 918398	ARSENIY VOLKOV	{"email": "arseniyvolkov.1970@postgrespro.ru", "phone": "+70313039294"}
0005435425851	EB48B5	6674 629296	PETR VLASOV	{"phone": "+70418711555"}
0005435425852	1BECEB	3821 620070	ANDREY MEDVEDEV	{"phone": "+70697899022"}
0005435425853	A80B79	7875 874517	SVETLANA FEDOROVA	{"phone": "+70445355134"}
0005435425854	DBF0F4	7879 723700	SERGEY SMIRNOV	{"email": "sergey-smirnov.061980@postgrespro.ru", "phone": "+70341865711"}
0005435425855	DBF0F4	5664 103180	GALIYA KUDRYASHOVA	{"email": "kudryashova-g-1973@postgrespro.ru", "phone": "+70768885134"}
0005435425856	19F69B	9280 886823	ALINA MOROZOVA	{"phone": "+70094806289"}
0005435425857	05560A	4423 705820	EVGENIYA MAKSIMOVA	{"phone": "+70342829682"}
0005435425858	A68C2E	1185 888609	POLINA CHERNOVA	{"phone": "+70773467168"}
0005435425859	FBC252	9141 932957	TATYANA KRASNOVA	{"phone": "+70000600069"}
0005435425860	EE5AAD	2503 424659	NIKOLAY ALEKSEEV	{"email": "nikolay-alekseev.09011978@postgrespro.ru", "phone": "+70100970939"}
0005435425861	CB7F85	9134 033098	EKATERINA KUZNECOVA	{"email": "e-kuznecova10041973@postgrespro.ru", "phone": "+70597683863"}
0005435425862	713DE2	0813 742671	ANDREY KOZLOV	{"phone": "+70333885347"}
0005435425863	187B05	6736 605903	NINA MIKHAYLOVA	{"phone": "+70833630303"}
0005435425864	CEAA0B	8286 182295	SVETLANA SERGEEVA	{"phone": "+70399532641"}
0005435425865	CEAA0B	0226 691624	SERGEY FROLOV	{"phone": "+70611426720"}
0005435425866	313652	0015 240351	NIKOLAY FROLOV	{"email": "frolov_n.071967@postgrespro.ru", "phone": "+70564787897"}
0005435425867	459324	2387 091775	SERGEY ISAEV	{"email": "s-isaev14071973@postgrespro.ru", "phone": "+70269903414"}
0005435425868	459324	6022 222559	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev101975@postgrespro.ru", "phone": "+70223209360"}
0005435425869	759A6A	0125 550008	NINA KONDRATEVA	{"phone": "+70317364160"}
0005435425870	2495C2	7956 506446	VLADIMIR KULIKOV	{"email": "vkulikov.031970@postgrespro.ru", "phone": "+70925830807"}
0005435425871	6DEEB6	4308 808016	NIKOLAY MAKSIMOV	{"phone": "+70666120122"}
0005435425872	E446BC	0921 177785	YURIY SMIRNOV	{"phone": "+70642780887"}
0005435425873	E446BC	3356 611772	NIKITA NIKITIN	{"email": "n-nikitin.15111977@postgrespro.ru", "phone": "+70951252696"}
0005435425874	DC111B	3894 987545	MARIYA ZHUKOVA	{"email": "zhukovamariya30091971@postgrespro.ru", "phone": "+70160311411"}
0005435425875	DC111B	8928 858304	IVAN SEMENOV	{"phone": "+70523778760"}
0005435425876	9ACDB8	4023 379376	ANATOLIY KUZNECOV	{"email": "anatoliy_kuznecov_1966@postgrespro.ru", "phone": "+70295418425"}
0005435425877	7ADCA4	8331 897657	NADEZHDA ISAEVA	{"email": "nadezhda-isaeva.1982@postgrespro.ru", "phone": "+70982306645"}
0005435425878	7BEA8C	9693 765191	OLGA GORBUNOVA	{"phone": "+70361375657"}
0005435425879	7BEA8C	6204 769810	OKSANA ANTONOVA	{"email": "o_antonova.081969@postgrespro.ru", "phone": "+70598881954"}
0005435425880	3F90AF	8522 772179	LARISA NIKOLAEVA	{"phone": "+70342518343"}
0005435425881	3F90AF	3379 814267	DARYA PETROVA	{"phone": "+70743383840"}
0005435425882	11B2B6	9365 319289	NINA NESTEROVA	{"email": "n_nesterova.111966@postgrespro.ru", "phone": "+70773500482"}
0005435425883	79DCC7	9148 325011	EDUARD KOZLOV	{"phone": "+70093522670"}
0005435425884	973D1B	3029 985460	PETR PETROV	{"email": "petr.petrov26061952@postgrespro.ru", "phone": "+70519904772"}
0005435425885	973D1B	6760 340333	VASILIY SMIRNOV	{"email": "vasiliysmirnov_04111986@postgrespro.ru", "phone": "+70344951367"}
0005435425997	E30719	5877 121199	VIKTORIYA VASILEVA	{"phone": "+70832974953"}
0005435425886	973D1B	3290 024274	MIKHAIL FILIPPOV	{"email": "m-filippov05051972@postgrespro.ru", "phone": "+70729795331"}
0005435425887	45C729	0928 787296	DMITRIY NIKOLAEV	{"email": "dmitriy.nikolaev-1982@postgrespro.ru", "phone": "+70212888051"}
0005435425888	559622	8608 634104	DMITRIY ZAKHAROV	{"phone": "+70669684945"}
0005435425889	559622	5822 496093	LIDIYA BOGDANOVA	{"email": "bogdanova_lidiya1977@postgrespro.ru", "phone": "+70772501747"}
0005435426248	D8EA7C	2811 968733	NATALYA POPOVA	{"phone": "+70294227131"}
0005435425890	940529	3510 128370	ADELINA ZHURAVLEVA	{"email": "zhuravlevaa_101967@postgrespro.ru", "phone": "+70433125004"}
0005435425891	940529	8840 971764	ALEKSANDR NOVIKOV	{"phone": "+70258390297"}
0005435425892	2D1466	8514 252182	ALEKSANDR SOROKIN	{"email": "aleksandr_sorokin.121965@postgrespro.ru", "phone": "+70122113130"}
0005435425893	E2113C	6756 726256	VIKTORIYA KOZLOVA	{"email": "viktoriya.kozlova_03091969@postgrespro.ru", "phone": "+70750484795"}
0005435425894	E2746E	7929 033690	GALINA MATVEEVA	{"phone": "+70287300062"}
0005435425895	C01AF3	7776 751345	IRINA ANISIMOVA	{"email": "anisimovairina_27101976@postgrespro.ru", "phone": "+70027288292"}
0005435425896	C01AF3	0151 422013	ANDREY DAVYDOV	{"email": "davydov_andrey.1979@postgrespro.ru", "phone": "+70117563417"}
0005435425897	B13C59	3254 254682	ELENA FEDOROVA	{"phone": "+70238451656"}
0005435425898	E5FD5B	4113 064181	ANATOLIY DMITRIEV	{"phone": "+70641581842"}
0005435425899	8546F8	1557 233818	KRISTINA MELNIKOVA	{"phone": "+70115928946"}
0005435425900	E60745	1132 546019	IGOR ABRAMOV	{"phone": "+70225622422"}
0005435425901	E60745	9514 648136	OLEG EGOROV	{"email": "o_egorov_22051978@postgrespro.ru", "phone": "+70239708325"}
0005435425902	E60745	2076 415807	VASILIY PETROV	{"email": "petrov-vasiliy_1975@postgrespro.ru", "phone": "+70148533876"}
0005435425903	0458CC	9054 116935	DMITRIY NIKOLAEV	{"email": "nikolaevd081978@postgrespro.ru", "phone": "+70316603545"}
0005435425904	4AA85C	4088 330638	NIKITA EGOROV	{"email": "egorov-nikita-26071967@postgrespro.ru", "phone": "+70747303884"}
0005435425905	71DD89	2128 912146	ALEKSANDR PETROV	{"email": "aleksandr_petrov.051972@postgrespro.ru", "phone": "+70859709482"}
0005435425906	71DD89	5197 489450	SERGEY FOMIN	{"phone": "+70432843430"}
0005435425907	5F74B1	5327 796048	ALEKSEY ALEKSEEV	{"phone": "+70904340746"}
0005435425908	172455	8029 079013	MARINA FADEEVA	{"phone": "+70700304268"}
0005435425909	72EE8C	3254 655957	TALGAT SOLOVEV	{"email": "talgat.solovev_26061974@postgrespro.ru", "phone": "+70134404308"}
0005435425910	DA7B15	2577 058640	NIKOLAY NOVIKOV	{"email": "novikov_n01101976@postgrespro.ru", "phone": "+70027609712"}
0005435425911	35EA97	8988 233223	IGOR MAKAROV	{"email": "imakarov.1969@postgrespro.ru", "phone": "+70292457838"}
0005435425912	3C4DE6	8271 095245	TATYANA MALYSHEVA	{"phone": "+70839721546"}
0005435425913	644CD3	4777 742087	DENIS KUZNECOV	{"phone": "+70091348020"}
0005435425914	EF6AB8	1415 114539	ARTEM GUSEV	{"phone": "+70071034018"}
0005435425915	891319	2959 302672	VERA BARANOVA	{"email": "vbaranova26021972@postgrespro.ru", "phone": "+70271161335"}
0005435425916	F15C76	7319 050866	MAKSIM SOKOLOV	{"email": "sokolovm_1967@postgrespro.ru", "phone": "+70770485295"}
0005435425917	4C787C	4654 800826	OLGA KOLESNIKOVA	{"email": "olga-kolesnikova_031978@postgrespro.ru", "phone": "+70291280900"}
0005435425918	87221B	9130 990140	KONSTANTIN MAKAROV	{"phone": "+70868766000"}
0005435425919	BEF664	7076 443807	YULIYA NIKOLAEVA	{"email": "nikolaeva-yuliya.01041958@postgrespro.ru", "phone": "+70260053194"}
0005435425920	1E76BF	2643 019150	KIRILL DMITRIEV	{"email": "kirill.dmitriev-1974@postgrespro.ru", "phone": "+70149951708"}
0005435425921	1E76BF	8748 556416	YULIYA TROFIMOVA	{"phone": "+70812303138"}
0005435425922	4790E6	7746 355108	ELENA BARANOVA	{"phone": "+70359528888"}
0005435425923	4790E6	1684 356762	ALEKSANDR KUZMIN	{"email": "aleksandr_kuzmin.20051956@postgrespro.ru", "phone": "+70240029499"}
0005435425924	4790E6	4613 402308	VIKTORIYA SIDOROVA	{"phone": "+70202269466"}
0005435425925	8FB4A4	7805 953745	VIKTOR TIKHONOV	{"phone": "+70435811675"}
0005435425926	E1538A	2903 747119	DMITRIY NOVIKOV	{"email": "dnovikov-09061973@postgrespro.ru", "phone": "+70961026644"}
0005435425927	86B977	7298 720586	ELENA SIDOROVA	{"email": "sidorova-e-1963@postgrespro.ru", "phone": "+70783477032"}
0005435425928	C875F3	2837 638393	SERGEY ALEKSEEV	{"phone": "+70061616755"}
0005435425929	C875F3	9931 308560	ZOYA LEBEDEVA	{"phone": "+70966551808"}
0005435425930	A7556B	5847 644442	OLGA ZAYCEVA	{"email": "olga.zayceva1968@postgrespro.ru", "phone": "+70319825019"}
0005435425931	8A7F0A	0403 242063	ELENA VOROBEVA	{"email": "evorobeva1963@postgrespro.ru", "phone": "+70248557975"}
0005435425932	8A7F0A	4576 271669	YURIY VASILEV	{"email": "yuriyvasilev-1969@postgrespro.ru", "phone": "+70106484180"}
0005435425933	EB3FD1	0622 639954	YULIYA MOISEEVA	{"phone": "+70596290999"}
0005435425934	361FC3	9442 007416	EVGENIY KUZNECOV	{"email": "e_kuznecov-14051981@postgrespro.ru", "phone": "+70154634691"}
0005435425935	BA4A26	9791 558636	YULIYA SOKOLOVA	{"email": "yuliyasokolova26091963@postgrespro.ru", "phone": "+70355860166"}
0005435425936	790C96	4237 792572	OLGA KUZNECOVA	{"email": "olga-kuznecova.031956@postgrespro.ru", "phone": "+70840007978"}
0005435425937	790C96	2422 489864	ANASTASIYA ANDREEVA	{"email": "andreeva_a27071964@postgrespro.ru", "phone": "+70642411836"}
0005435425938	A1480C	7570 231457	ALEKSANDR KUZNECOV	{"email": "kuznecova.121971@postgrespro.ru", "phone": "+70914576013"}
0005435425939	BACEE3	5602 143277	LILIYA GAVRILOVA	{"email": "liliya_gavrilova.1964@postgrespro.ru", "phone": "+70907648569"}
0005435425940	17E482	3483 251525	NATALYA DENISOVA	{"phone": "+70618449457"}
0005435425941	C391BF	2399 301321	NINA OSIPOVA	{"email": "osipova_n-1995@postgrespro.ru", "phone": "+70743709545"}
0005435425942	AB8092	2135 019009	ANNA PETROVA	{"email": "annapetrova1968@postgrespro.ru", "phone": "+70935988482"}
0005435425943	AB8092	2750 951432	RAISA PETROVA	{"phone": "+70719406218"}
0005435425944	083BB4	5867 202313	TATYANA EFIMOVA	{"phone": "+70894023822"}
0005435425945	083BB4	7869 215278	ALEKSEY MEDVEDEV	{"email": "medvedev.a23041976@postgrespro.ru", "phone": "+70954589354"}
0005435425946	94E463	0161 610791	ELIZAVETA CHERNOVA	{"email": "chernova.elizaveta22081972@postgrespro.ru", "phone": "+70379638176"}
0005435425947	027318	0174 899784	KUZMA EGOROV	{"email": "kuzmaegorov081971@postgrespro.ru", "phone": "+70337874002"}
0005435425948	027318	3220 892228	EVGENIY MOROZOV	{"phone": "+70935702591"}
0005435425949	08B478	4045 404072	ANNA MELNIKOVA	{"email": "anna_melnikova_1968@postgrespro.ru", "phone": "+70523860086"}
0005435425950	08B478	7738 301379	ALEKSANDR DENISOV	{"phone": "+70339813470"}
0005435425951	08B478	3804 122176	NATALYA FILATOVA	{"email": "filatovanatalya.05111984@postgrespro.ru", "phone": "+70776372002"}
0005435425952	884AC1	6068 269900	MIKHAIL KRASNOV	{"phone": "+70732203567"}
0005435425953	643232	2700 327289	ALEKSANDR MEDVEDEV	{"email": "medvedeva.031970@postgrespro.ru", "phone": "+70143483017"}
0005435425954	35E568	1697 473180	ALEKSANDR SAVELEV	{"phone": "+70729634820"}
0005435425955	FB777B	8531 848560	GRIGORIY CHERNOV	{"phone": "+70339234541"}
0005435425956	0D0900	3374 916072	ANTONINA GRISHINA	{"phone": "+70150569784"}
0005435425957	0D0900	2959 839871	ANTONINA STEPANOVA	{"email": "antonina_stepanova13011977@postgrespro.ru", "phone": "+70754221452"}
0005435425958	15B28F	0209 577994	RASHID PAVLOV	{"email": "pavlov.rashid-1970@postgrespro.ru", "phone": "+70422129280"}
0005435425959	8BE972	4771 424481	IRINA RYABOVA	{"phone": "+70124369207"}
0005435425960	8BE972	0153 588997	KLAVDIYA BELOVA	{"email": "belovak.05061979@postgrespro.ru", "phone": "+70698836139"}
0005435425961	DCF653	3024 287187	OLGA BOGDANOVA	{"email": "o_bogdanova30121966@postgrespro.ru", "phone": "+70859135916"}
0005435425962	480352	1550 897778	NATALYA ABRAMOVA	{"email": "natalyaabramova_13111970@postgrespro.ru", "phone": "+70886895887"}
0005435425963	480352	3836 095716	SERGEY ORLOV	{"email": "sergeyorlov_12021977@postgrespro.ru", "phone": "+70701762828"}
0005435425964	04B5DB	4921 121888	VITALIY SOKOLOV	{"phone": "+70630423168"}
0005435425965	04B5DB	6847 761120	MARINA NIKOLAEVA	{"phone": "+70661310556"}
0005435425966	24249F	6440 555684	VLADIMIR ORLOV	{"phone": "+70794506352"}
0005435425967	DDE152	3706 786465	VITALIY ILIN	{"email": "ilin_v_19061964@postgrespro.ru", "phone": "+70298692201"}
0005435425968	47B1C7	2269 673529	SVETLANA KRASNOVA	{"phone": "+70227954191"}
0005435425969	4BEA42	2227 036383	SERGEY KUZNECOV	{"phone": "+70162081835"}
0005435425970	4BEA42	0425 222558	RAISA KOVALEVA	{"email": "raisa-kovaleva-12101963@postgrespro.ru", "phone": "+70427355264"}
0005435425971	23F642	1256 652951	LYUDMILA IVANOVA	{"phone": "+70713410489"}
0005435425972	E0496D	4883 013551	IBRAGIM GORBUNOV	{"phone": "+70883007894"}
0005435425973	091C4C	7951 213497	DMITRIY KUZMIN	{"phone": "+70725232105"}
0005435425974	091C4C	2918 684720	VALENTINA SOLOVEVA	{"phone": "+70869751308"}
0005435425975	091C4C	4387 439060	OLGA GORBUNOVA	{"email": "gorbunova.olga_1990@postgrespro.ru", "phone": "+70713428093"}
0005435425976	091C4C	2153 035354	LYUDMILA ANISIMOVA	{"email": "l_anisimova.21121982@postgrespro.ru", "phone": "+70829814139"}
0005435425977	1F5E73	5108 989866	ANNA KOLESNIKOVA	{"email": "kolesnikova_anna.1973@postgrespro.ru", "phone": "+70552399849"}
0005435425978	1F5E73	5308 980619	VIKTOR NOVIKOV	{"phone": "+70763387782"}
0005435425979	B7060E	4924 984671	TATYANA NESTEROVA	{"email": "tatyana_nesterova_25051979@postgrespro.ru", "phone": "+70850923068"}
0005435425980	5D1FDD	4977 348231	MARIYA YAKOVLEVA	{"phone": "+70687894695"}
0005435425981	5D1FDD	5279 291551	ANDREY ORLOV	{"phone": "+70018445739"}
0005435425982	806ED9	6707 392981	ILYA VLASOV	{"phone": "+70538596832"}
0005435425983	58A034	2411 630691	VLADIMIR PETROV	{"phone": "+70322941111"}
0005435425984	74ADC1	5830 585857	MIKHAIL GORBUNOV	{"email": "gorbunov.m_23091977@postgrespro.ru", "phone": "+70769766404"}
0005435425985	74ADC1	9423 894720	NATALYA MOROZOVA	{"phone": "+70350530301"}
0005435425986	0CFD7C	1255 404182	ANGELINA PAVLOVA	{"phone": "+70484310213"}
0005435425987	BE140B	2540 422466	SAID NIKOLAEV	{"phone": "+70537334308"}
0005435425988	69B5D9	9911 818763	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova.02051975@postgrespro.ru", "phone": "+70870723951"}
0005435425989	BFD532	5822 795058	ARSENIY ROMANOV	{"phone": "+70048975403"}
0005435425990	BFD532	0511 962717	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov.1967@postgrespro.ru", "phone": "+70020583595"}
0005435425991	ED4A0E	5352 880853	ALEKSANDR SMIRNOV	{"email": "asmirnov_101958@postgrespro.ru", "phone": "+70960050912"}
0005435425992	96AA9F	0489 173146	DMITRIY ABRAMOV	{"phone": "+70038860691"}
0005435425993	14A6C1	0511 400833	IVAN PAVLOV	{"phone": "+70755767102"}
0005435425994	C3C2DC	1843 272812	DENIS GAVRILOV	{"email": "gavrilov-d.25081970@postgrespro.ru", "phone": "+70878216885"}
0005435425995	9A66A8	3667 174865	KRISTINA MAKAROVA	{"email": "makarova-kristina121973@postgrespro.ru", "phone": "+70484363555"}
0005435425996	E30719	0410 122426	VIKTOR AFANASEV	{"phone": "+70933790154"}
0005435425998	3A704B	7112 155286	SERGEY KOZLOV	{"email": "sergey_kozlov061969@postgrespro.ru", "phone": "+70720286656"}
0005435425999	8B1E9E	0691 841110	NIKOLAY MAKAROV	{"email": "makarovn_1976@postgrespro.ru", "phone": "+70970883259"}
0005435426000	0DD1DF	5605 048074	MIKHAIL OSIPOV	{"phone": "+70781508146"}
0005435426001	581DF6	1796 388967	VYACHESLAV MOROZOV	{"phone": "+70592886658"}
0005435426002	0AF049	2830 544332	TATYANA DAVYDOVA	{"phone": "+70639982998"}
0005435426003	4DC9B3	1405 435757	LYUBOV BELYAEVA	{"email": "lyubovbelyaeva.11121982@postgrespro.ru", "phone": "+70249276413"}
0005435426004	4DC9B3	4421 911953	LILIYA ABRAMOVA	{"phone": "+70701468042"}
0005435426005	8A2EC1	5327 486253	VALENTINA KOLESNIKOVA	{"email": "kolesnikova.valentina121965@postgrespro.ru", "phone": "+70398441932"}
0005435426006	4452EC	2738 758262	OLGA TIMOFEEVA	{"phone": "+70421837149"}
0005435426007	01BEF1	3247 438158	VIKTOR BONDARENKO	{"email": "viktor-bondarenko-1956@postgrespro.ru", "phone": "+70346136503"}
0005435426008	1D2F0C	5127 118198	SERGEY NOVIKOV	{"email": "s-novikov_13071975@postgrespro.ru", "phone": "+70977064402"}
0005435426009	C451EE	4899 950739	IVAN PETROV	{"phone": "+70627725653"}
0005435426010	66BA55	9478 305817	SOFIYA DMITRIEVA	{"phone": "+70363588141"}
0005435426368	171C5B	0704 611821	TATYANA KAZAKOVA	{"phone": "+70487470734"}
0005435426011	C78BC7	9479 163037	ASKHAT OSIPOV	{"email": "a.osipov16011976@postgrespro.ru", "phone": "+70436732760"}
0005435426012	254C9B	7750 234054	OLEG FILIPPOV	{"email": "filippovoleg071966@postgrespro.ru", "phone": "+70191892848"}
0005435426013	D18DF3	3666 533807	IRINA ROMANOVA	{"phone": "+70581108440"}
0005435426014	8557FE	4381 317205	ALEKSANDR GAVRILOV	{"email": "aleksandr.gavrilov-1970@postgrespro.ru", "phone": "+70122605988"}
0005435426015	BEC427	9378 757133	KONSTANTIN KAZAKOV	{"phone": "+70648396649"}
0005435426016	11B060	3549 923238	DARYA BELYAEVA	{"phone": "+70138012927"}
0005435426017	FA349B	9366 299334	ALBERT MIRONOV	{"phone": "+70027119272"}
0005435426018	FA349B	4868 953916	VIKTOR ANDREEV	{"phone": "+70744365019"}
0005435426019	FA349B	1919 695230	MARIYA ZHUKOVA	{"email": "zhukova_m-041974@postgrespro.ru", "phone": "+70969617076"}
0005435426020	168799	7462 676894	VERA STEPANOVA	{"email": "v-stepanova-071976@postgrespro.ru", "phone": "+70764407356"}
0005435426021	1E818B	0491 976954	MIKHAIL BARANOV	{"phone": "+70784173195"}
0005435426022	1E818B	3796 511703	GENNADIY ZAKHAROV	{"email": "zakharov-gennadiy-23091965@postgrespro.ru", "phone": "+70505306314"}
0005435426023	1E818B	3147 795629	VALENTINA VASILEVA	{"email": "valentina.vasileva.22091970@postgrespro.ru", "phone": "+70702766858"}
0005435426024	8041C0	3012 895320	DAVID SIDOROV	{"phone": "+70932934775"}
0005435426025	AC1730	3144 258437	NATALYA NIKIFOROVA	{"email": "nikiforovanatalya_1961@postgrespro.ru", "phone": "+70945018433"}
0005435426026	7D5389	2337 278460	ALEKSANDRA ANDREEVA	{"phone": "+70624757099"}
0005435426027	9C5C7A	3888 374479	TIMOFEY ZHUKOV	{"phone": "+70296135295"}
0005435426028	BBB7B5	5671 348695	VLADIMIR ROMANOV	{"email": "romanovvladimir.04011977@postgrespro.ru", "phone": "+70201173078"}
0005435426029	3D23D1	6102 494863	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr-071975@postgrespro.ru", "phone": "+70102927436"}
0005435426030	B2674D	5461 639344	ELENA SAVELEVA	{"email": "saveleva.e-15081984@postgrespro.ru", "phone": "+70696878908"}
0005435426031	B2674D	0506 323038	VIKTORIYA MIRONOVA	{"email": "v.mironova-28011975@postgrespro.ru", "phone": "+70198674476"}
0005435426032	40974A	7183 776889	ALEKSANDR TIMOFEEV	{"phone": "+70236543249"}
0005435426033	FF4072	6597 439813	ROMAN KOROLEV	{"email": "romankorolev.091974@postgrespro.ru", "phone": "+70174722794"}
0005435426034	FF4072	2107 876436	PETR BARANOV	{"phone": "+70996286641"}
0005435426035	2DCFDE	2043 470634	TATYANA MAKAROVA	{"email": "tatyana.makarova_1976@postgrespro.ru", "phone": "+70543601905"}
0005435426036	DFB96C	7467 427117	ARTEM MIRONOV	{"phone": "+70664349827"}
0005435426037	64D3D0	4026 055225	ANZHELIKA ORLOVA	{"email": "orlova.anzhelika.031965@postgrespro.ru", "phone": "+70802886981"}
0005435426038	64D3D0	0409 516465	ROMAN MAKAROV	{"phone": "+70798777187"}
0005435426039	5C5EDA	0321 357302	PETR FEDOROV	{"phone": "+70149924536"}
0005435426040	32EFA7	8166 185251	VALENTINA DANILOVA	{"phone": "+70570170713"}
0005435426041	C5F28E	3997 272920	MARIYA NAZAROVA	{"email": "mariyanazarova_1977@postgrespro.ru", "phone": "+70233968386"}
0005435426042	EEA1B5	7410 198630	VLADIMIR ROMANOV	{"email": "romanov_vladimir-14051975@postgrespro.ru", "phone": "+70860721739"}
0005435426043	EEA1B5	1923 568676	OLGA POPOVA	{"email": "popova-o.19031974@postgrespro.ru", "phone": "+70652254267"}
0005435426044	EEA1B5	6104 999476	GALINA TIKHONOVA	{"email": "tikhonova.galina1961@postgrespro.ru", "phone": "+70193575934"}
0005435426045	775C0A	7013 946147	RAIS CHERNOV	{"email": "rais_chernov-03051961@postgrespro.ru", "phone": "+70756730609"}
0005435426046	69AD25	2843 096137	ANASTASIYA POPOVA	{"email": "apopova_061982@postgrespro.ru", "phone": "+70486116867"}
0005435426047	69AD25	1509 656201	ANASTASIYA OSIPOVA	{"phone": "+70951650489"}
0005435426048	0A89DD	6833 537703	VYACHESLAV DAVYDOV	{"email": "davydov-vyacheslav_1970@postgrespro.ru", "phone": "+70465923476"}
0005435426049	0A89DD	6484 137291	NADEZHDA SOLOVEVA	{"phone": "+70659091884"}
0005435426050	06912F	9833 996814	ALEKSANDR SMIRNOV	{"email": "a-smirnov15111959@postgrespro.ru", "phone": "+70628562810"}
0005435426051	A80848	0916 881989	ELVINA KRASNOVA	{"email": "krasnova_e10121970@postgrespro.ru", "phone": "+70686023451"}
0005435426052	A80848	5718 631284	IGOR VOLKOV	{"email": "i_volkov05081963@postgrespro.ru", "phone": "+70649498252"}
0005435426053	62D5A2	6666 266408	IVAN KOZLOV	{"phone": "+70235145622"}
0005435426054	3C4849	3401 327050	SERGEY NAUMOV	{"email": "naumovsergey-1971@postgrespro.ru", "phone": "+70618536094"}
0005435426055	7016F0	8822 802391	VADIM KOZLOV	{"phone": "+70171210039"}
0005435426056	7016F0	5108 722571	MARINA GERASIMOVA	{"phone": "+70905416366"}
0005435426057	C16CAA	5600 916251	OLGA SERGEEVA	{"phone": "+70781549225"}
0005435426058	C16CAA	5066 917617	ELENA VOROBEVA	{"phone": "+70030618527"}
0005435426059	01DCC7	7334 888133	NIKITA NAUMOV	{"email": "naumov.n021965@postgrespro.ru", "phone": "+70457138334"}
0005435426060	D39A2B	4564 068764	ALEKSANDR MIKHAYLOV	{"phone": "+70018579419"}
0005435426061	4D4EBC	9221 708631	LYUDMILA MARTYNOVA	{"email": "lmartynova101971@postgrespro.ru", "phone": "+70822737029"}
0005435426062	4D4EBC	1768 339291	EVGENIY STEPANOV	{"phone": "+70824297147"}
0005435426063	4D4EBC	6040 031174	LARISA GORBUNOVA	{"email": "gorbunova_l111968@postgrespro.ru", "phone": "+70675822919"}
0005435426064	0FEFB6	4302 973170	LYUDMILA GORBUNOVA	{"phone": "+70274189398"}
0005435426065	D6442E	2481 923973	VALENTINA KONDRATEVA	{"email": "v-kondrateva_20101974@postgrespro.ru", "phone": "+70499714051"}
0005435426066	D6442E	8610 163340	INNA GAVRILOVA	{"email": "gavrilova_inna_09091977@postgrespro.ru", "phone": "+70745240468"}
0005435426067	A02AC0	3118 194833	ALEKSEY FILIPPOV	{"phone": "+70942073614"}
0005435426068	F993AE	5558 844020	VLADIMIR SEMENOV	{"phone": "+70569193701"}
0005435426069	F1D754	0050 053964	ELENA STEPANOVA	{"phone": "+70106033274"}
0005435426369	171C5B	8286 459484	ANDREY KOROLEV	{"phone": "+70376279231"}
0005435426070	F1D754	2719 581477	VASILIY GUSEV	{"email": "gusev-vasiliy.1969@postgrespro.ru", "phone": "+70608974818"}
0005435426071	812632	8370 968840	MARIYA ANDREEVA	{"phone": "+70789264855"}
0005435426072	6369A8	3788 176221	EKATERINA KOVALEVA	{"email": "kovaleva-e.27011967@postgrespro.ru", "phone": "+70238237261"}
0005435426073	8C729A	8697 582194	IGOR KUZNECOV	{"phone": "+70303728191"}
0005435426074	DCE436	4127 145164	YURIY FILIPPOV	{"phone": "+70729778844"}
0005435426075	014A9A	3331 394682	ELENA SIDOROVA	{"phone": "+70405746085"}
0005435426076	014A9A	1349 896828	IRINA ANDREEVA	{"email": "andreeva.irina.16061972@postgrespro.ru", "phone": "+70029581209"}
0005435426077	7BF544	2576 783144	NIKOLAY PETROV	{"phone": "+70472001745"}
0005435426078	7BF544	0162 278544	KONSTANTIN ROMANOV	{"phone": "+70198386255"}
0005435426079	B3F75A	7384 893692	ELENA BARANOVA	{"email": "baranova.e21041968@postgrespro.ru", "phone": "+70980232764"}
0005435426080	64D49B	8631 765136	RUSLAN VOLKOV	{"phone": "+70188142135"}
0005435426081	480C8B	6199 496328	ANDREY FROLOV	{"email": "a-frolov.1991@postgrespro.ru", "phone": "+70477966885"}
0005435426082	429DA8	5614 565295	ARTEM NAZAROV	{"phone": "+70842403618"}
0005435426083	429DA8	3193 531092	YULIYA KOVALEVA	{"email": "yuliyakovaleva_1990@postgrespro.ru", "phone": "+70976744686"}
0005435426084	19D3B8	1236 394759	ROMAN GUSEV	{"email": "roman.gusev041965@postgrespro.ru", "phone": "+70156305612"}
0005435426085	DEB516	5206 516244	DMITRIY SERGEEV	{"phone": "+70518966082"}
0005435426086	07B7A1	1075 653676	NADEZHDA POPOVA	{"email": "n-popova_16071972@postgrespro.ru", "phone": "+70373614005"}
0005435426087	07B7A1	0789 398386	VLADIMIR NAZAROV	{"email": "nazarov_v.1973@postgrespro.ru", "phone": "+70837208366"}
0005435426088	E9702E	8463 826142	RUSLAN SAVELEV	{"email": "savelev-ruslan-24071974@postgrespro.ru", "phone": "+70312228560"}
0005435426089	AB270F	9031 160493	OLGA TARASOVA	{"phone": "+70929186291"}
0005435426090	24A8CC	5911 368500	EKATERINA MEDVEDEVA	{"phone": "+70146823367"}
0005435426091	24A8CC	6090 915535	ALENA DANILOVA	{"email": "alena-danilova20031980@postgrespro.ru", "phone": "+70246209094"}
0005435426092	1123BD	4251 011536	OLGA AKIMOVA	{"phone": "+70985009273"}
0005435426093	1123BD	8685 075502	NIKITA VOLKOV	{"email": "nikita.volkov101988@postgrespro.ru", "phone": "+70853538920"}
0005435426094	761669	8132 855442	DENIS IVANOV	{"phone": "+70764009996"}
0005435426095	C93E9D	2837 076641	VERA IVANOVA	{"email": "ivanova-vera_1976@postgrespro.ru", "phone": "+70559777590"}
0005435426096	E0CA85	8279 733320	SERGEY ROMANOV	{"email": "sromanov.27061970@postgrespro.ru", "phone": "+70743257024"}
0005435426097	775C44	6325 322706	VIKTORIYA SIDOROVA	{"email": "vsidorova_071969@postgrespro.ru", "phone": "+70144942607"}
0005435426098	1EA56F	4141 026568	ANATOLIY BARANOV	{"phone": "+70191339878"}
0005435426099	7FAFED	8716 440231	NADEZHDA VASILEVA	{"email": "vasilevanadezhda061978@postgrespro.ru", "phone": "+70276692049"}
0005435426100	09D764	4592 373488	VITALIY SAVELEV	{"phone": "+70749410899"}
0005435426101	338E46	8541 744848	TATYANA SOKOLOVA	{"phone": "+70334637228"}
0005435426102	338E46	0433 831899	ANDREY BELOV	{"email": "a-belov29091978@postgrespro.ru", "phone": "+70450199867"}
0005435426103	CE1C0B	8689 003599	ILYA POPOV	{"phone": "+70406584782"}
0005435426104	CE1C0B	2778 191105	VLADIMIR PAVLOV	{"phone": "+70172135310"}
0005435426105	5C0578	8758 377505	NATALYA IVANOVA	{"phone": "+70917321882"}
0005435426106	5FB748	6187 440095	KONSTANTIN FEDOROV	{"phone": "+70450116522"}
0005435426107	5FB748	1417 683804	STEPAN KUZNECOV	{"email": "kuznecov_s_17011962@postgrespro.ru", "phone": "+70402263422"}
0005435426108	71CEA2	1109 723384	ANNA PETROVA	{"phone": "+70937755458"}
0005435426109	B29CDC	7885 860266	OLEG FEDOROV	{"phone": "+70278214858"}
0005435426110	F48DB0	7435 209105	OLGA KUZNECOVA	{"email": "kuznecova-o-101977@postgrespro.ru", "phone": "+70522569393"}
0005435426111	0F7F1F	5077 037023	ANASTASIYA ABRAMOVA	{"phone": "+70101227980"}
0005435426112	BE082F	4377 268956	ELENA BOGDANOVA	{"email": "elenabogdanova_12091969@postgrespro.ru", "phone": "+70166270800"}
0005435426113	9B60E4	7659 474113	ALEKSANDR KOROLEV	{"email": "korolev_a-25091973@postgrespro.ru", "phone": "+70282750704"}
0005435426114	75AF48	2667 538784	EVGENIY STEPANOV	{"email": "evgeniy-stepanov-23091971@postgrespro.ru", "phone": "+70107173474"}
0005435426115	242D5D	0918 892550	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov.031975@postgrespro.ru", "phone": "+70166050192"}
0005435426116	242D5D	8970 144737	BORIS ZHURAVLEV	{"phone": "+70041588422"}
0005435426117	046E46	6314 395620	NINA SOROKINA	{"email": "n-sorokina.021979@postgrespro.ru", "phone": "+70838800933"}
0005435426118	A9ECB5	9039 333759	NIKOLAY NOVIKOV	{"email": "n-novikov061970@postgrespro.ru", "phone": "+70788163622"}
0005435426119	5EF49E	3884 688545	MAKSIM IVANOV	{"phone": "+70829852116"}
0005435426120	5EF49E	8087 752704	ANATOLIY ISAEV	{"email": "isaev_a071964@postgrespro.ru", "phone": "+70193824127"}
0005435426121	109B2F	5411 015828	ANATOLIY TARASOV	{"email": "tarasov_a111979@postgrespro.ru", "phone": "+70071599476"}
0005435426122	0C4388	6507 662074	ALEKSANDR ABRAMOV	{"phone": "+70851402693"}
0005435426123	BABF6F	5955 836320	VITALIY SAVELEV	{"phone": "+70448402792"}
0005435426124	BABF6F	8336 293939	VASILIY POPOV	{"email": "v-popov101978@postgrespro.ru", "phone": "+70767679997"}
0005435426125	BABF6F	3140 541087	DMITRIY MELNIKOV	{"phone": "+70940609350"}
0005435426126	9EC860	3336 019612	NATALIYA MELNIKOVA	{"email": "melnikova_nataliya-05021976@postgrespro.ru", "phone": "+70189267281"}
0005435426127	74013C	9262 908266	VALENTINA GAVRILOVA	{"phone": "+70435075773"}
0005435426128	74013C	6097 856454	SERGEY NAZAROV	{"phone": "+70291591464"}
0005435426129	D85A76	9416 781991	VALENTINA SOLOVEVA	{"phone": "+70089582407"}
0005435426130	4FB5FE	3612 763491	DMITRIY VASILEV	{"email": "d.vasilev021976@postgrespro.ru", "phone": "+70830726992"}
0005435426131	B3B266	5575 382975	KONSTANTIN EGOROV	{"email": "kegorov-101988@postgrespro.ru", "phone": "+70145042138"}
0005435426132	7AE9E8	6331 460978	MARINA VASILEVA	{"email": "vasileva-marina-1972@postgrespro.ru", "phone": "+70486873813"}
0005435426133	BA27E4	4570 940342	VALERIY KUZNECOV	{"phone": "+70385115582"}
0005435426134	BA27E4	2213 867124	ALEKSANDR PETROV	{"phone": "+70993956102"}
0005435426135	63F238	1305 716558	IGNAT VOLKOV	{"email": "volkov.ignat.1978@postgrespro.ru", "phone": "+70903193222"}
0005435426136	63F238	1097 492975	IRINA FILATOVA	{"email": "filatova_irina.081986@postgrespro.ru", "phone": "+70596459485"}
0005435426137	6E113B	0377 884800	ELENA KUZMINA	{"phone": "+70757981907"}
0005435426138	04E06E	2908 485712	ANTONINA GUSEVA	{"phone": "+70314487639"}
0005435426139	04E06E	2908 929590	VIKTOR ROMANOV	{"email": "romanovv1970@postgrespro.ru", "phone": "+70410273493"}
0005435426140	AC198D	9672 332442	SERGEY MIKHAYLOV	{"email": "s.mikhaylov_011969@postgrespro.ru", "phone": "+70148215083"}
0005435426141	AC198D	6083 079511	ANASTASIYA ZAYCEVA	{"email": "a_zayceva_1971@postgrespro.ru", "phone": "+70788186949"}
0005435426142	2EC117	6222 253654	RAISA TIKHONOVA	{"phone": "+70852573418"}
0005435426143	2EC117	5093 606071	EKATERINA NIKOLAEVA	{"email": "ekaterina-nikolaeva-1971@postgrespro.ru", "phone": "+70464837616"}
0005435426144	904485	4168 118278	EKATERINA KUDRYASHOVA	{"email": "kudryashova.ekaterina-041968@postgrespro.ru", "phone": "+70880420956"}
0005435426145	904485	8342 628273	NATALYA SAVELEVA	{"email": "savelevanatalya021976@postgrespro.ru", "phone": "+70112464253"}
0005435426146	F8C8DE	1525 902104	ELVIRA POTAPOVA	{"email": "e.potapova-1967@postgrespro.ru", "phone": "+70489478059"}
0005435426147	2B420C	2561 222824	LYUDMILA KOMAROVA	{"email": "lkomarova11081969@postgrespro.ru", "phone": "+70386816219"}
0005435426148	CED826	4688 689273	ELIZAVETA YAKOVLEVA	{"phone": "+70536593504"}
0005435426149	A417F7	1996 506643	LYUDMILA IVANOVA	{"email": "lyudmila.ivanova-101968@postgrespro.ru", "phone": "+70468376696"}
0005435426150	AD6D5B	0211 579567	SERGEY MIRONOV	{"phone": "+70113689626"}
0005435426151	A01202	5254 312973	OLGA ROMANOVA	{"phone": "+70113416049"}
0005435426152	DCFD3E	7630 690449	SERGEY DMITRIEV	{"phone": "+70564610045"}
0005435426153	BDA11F	9164 084946	ALEVTINA ABRAMOVA	{"email": "abramova-alevtina_031967@postgrespro.ru", "phone": "+70971263085"}
0005435426154	BDA11F	5844 631406	ANTONINA FROLOVA	{"email": "a_frolova_111956@postgrespro.ru", "phone": "+70232033267"}
0005435426155	695353	1823 072568	ALEKSANDR ORLOV	{"email": "aleksandr.orlov30031972@postgrespro.ru", "phone": "+70809082257"}
0005435426156	695353	3405 329823	ANNA KUZMINA	{"email": "kuzmina_anna_1966@postgrespro.ru", "phone": "+70561156675"}
0005435426157	55D462	6381 928634	MAKSIM ANDREEV	{"email": "andreev.maksim20111963@postgrespro.ru", "phone": "+70741702240"}
0005435426158	13AB93	6201 664042	NIKITA SOROKIN	{"phone": "+70327664175"}
0005435426159	DB89AF	2174 052613	SERGEY CHERNOV	{"phone": "+70405395500"}
0005435426160	609CE5	8534 059604	DMITRIY NAUMOV	{"email": "naumov.d-23091970@postgrespro.ru", "phone": "+70087483432"}
0005435426161	92A3BB	2039 359630	VLADIMIR EGOROV	{"phone": "+70822286486"}
0005435426162	6BFEA7	6547 900595	ZHANNA FOMINA	{"email": "fomina.z_1964@postgrespro.ru", "phone": "+70977828958"}
0005435426163	BBC121	3160 760240	ILYA DMITRIEV	{"email": "dmitrievilya061969@postgrespro.ru", "phone": "+70795418856"}
0005435426164	BBC121	4148 196002	LYUBOV FEDOROVA	{"email": "l-fedorova-1967@postgrespro.ru", "phone": "+70543386271"}
0005435426165	C01745	1902 673439	SERGEY STEPANOV	{"email": "stepanov.sergey1953@postgrespro.ru", "phone": "+70356782517"}
0005435426166	1C84D8	6655 733093	ANTON ILIN	{"phone": "+70317035790"}
0005435426167	006F73	2871 598813	POLINA KULIKOVA	{"email": "polina-kulikova1971@postgrespro.ru", "phone": "+70951058366"}
0005435426168	C61479	5437 566209	PRASKOVYA VOROBEVA	{"phone": "+70237220890"}
0005435426169	B73BD2	0558 671269	LIDIYA PETROVA	{"email": "petroval.011975@postgrespro.ru", "phone": "+70268091940"}
0005435426170	B73BD2	7238 132051	ANASTASIYA ROMANOVA	{"email": "anastasiyaromanova_101976@postgrespro.ru", "phone": "+70756899403"}
0005435426171	CB820F	3843 035715	OLGA CHERNOVA	{"phone": "+70971312474"}
0005435426172	CDA16C	5841 012666	VIKTOR ZAKHAROV	{"email": "zakharovv1969@postgrespro.ru", "phone": "+70686500174"}
0005435426173	CDA16C	7775 468327	KONSTANTIN ROMANOV	{"phone": "+70702914776"}
0005435426174	B9A8BD	9290 270054	EVGENIYA KOLESNIKOVA	{"email": "kolesnikova.evgeniya11071970@postgrespro.ru", "phone": "+70514563349"}
0005435426175	D27070	9986 728232	ILMIRA FILIPPOVA	{"email": "filippovailmira.1976@postgrespro.ru", "phone": "+70827737491"}
0005435426176	B230B4	5966 152015	NINA LUKYANOVA	{"phone": "+70229627026"}
0005435426177	3C55D3	2031 550619	DENIS DAVYDOV	{"email": "denis_davydov_1972@postgrespro.ru", "phone": "+70777159140"}
0005435426178	C0364E	5509 104519	DMITRIY ILIN	{"phone": "+70147460448"}
0005435426179	C0364E	8572 101521	IRINA NAZAROVA	{"email": "irina-nazarova_1966@postgrespro.ru", "phone": "+70330511279"}
0005435426180	71D249	0095 276511	LEV ANDREEV	{"phone": "+70586860084"}
0005435426181	71D249	8601 772277	ELENA NAZAROVA	{"phone": "+70385915088"}
0005435426182	38665A	0874 663323	OKSANA MOISEEVA	{"email": "oksana-moiseeva.1977@postgrespro.ru", "phone": "+70634818057"}
0005435426183	38665A	6975 458503	GULNARA MEDVEDEVA	{"email": "gulnara_medvedeva.22121966@postgrespro.ru", "phone": "+70423794715"}
0005435426184	4CB8C0	1944 015433	MIKHAIL VOLKOV	{"email": "mikhailvolkov_1973@postgrespro.ru", "phone": "+70920869976"}
0005435426185	5B4EA6	8639 928676	ALEKSEY CHERNOV	{"phone": "+70231496768"}
0005435426186	5B4EA6	6974 777260	TATYANA KARPOVA	{"email": "karpova_t-011982@postgrespro.ru", "phone": "+70051218033"}
0005435426187	0452FC	5739 153805	LYUDMILA KOVALEVA	{"email": "l.kovaleva.1970@postgrespro.ru", "phone": "+70201681744"}
0005435426188	0452FC	4044 363637	VLADIMIR EGOROV	{"email": "egorovvladimir_011973@postgrespro.ru", "phone": "+70644027575"}
0005435426189	532982	8115 670457	MIKHAIL PETROV	{"email": "mikhail.petrov.12121967@postgrespro.ru", "phone": "+70354945332"}
0005435426190	2C37BE	3565 037681	ARMEN IVANOV	{"phone": "+70224193429"}
0005435426191	2C37BE	4185 521913	VLADIMIR IVANOV	{"phone": "+70637627202"}
0005435426192	11E0FB	7263 189945	ELENA GAVRILOVA	{"phone": "+70117485046"}
0005435426193	3CCF9D	6628 377250	ANATOLIY KUZMIN	{"phone": "+70741895308"}
0005435426194	3CCF9D	1739 743420	EVGENIY ORLOV	{"email": "e.orlov02101970@postgrespro.ru", "phone": "+70734970023"}
0005435426195	1FA396	2095 685660	ANDREY KONOVALOV	{"email": "konovalov_andrey_1977@postgrespro.ru", "phone": "+70609378245"}
0005435426196	1FA396	9585 380124	NAILYA DMITRIEVA	{"email": "nailya-dmitrieva_051977@postgrespro.ru", "phone": "+70207771013"}
0005435426197	DCB181	6216 827083	SVETLANA NIKITINA	{"phone": "+70612932722"}
0005435426198	B45C95	1796 504834	EVGENIY GAVRILOV	{"email": "e.gavrilov-13081967@postgrespro.ru", "phone": "+70390298343"}
0005435426199	B45C95	4641 367163	SERGEY TIKHONOV	{"email": "stikhonov_101968@postgrespro.ru", "phone": "+70006174795"}
0005435426200	0349A9	7863 351401	ARTEM NIKOLAEV	{"email": "nikolaev_a1982@postgrespro.ru", "phone": "+70176340844"}
0005435426201	ED31BC	5786 014315	ANDREY YAKOVLEV	{"email": "a.yakovlev-21081969@postgrespro.ru", "phone": "+70028775452"}
0005435426202	E8018E	8577 775440	DENIS POPOV	{"email": "denis-popov051952@postgrespro.ru", "phone": "+70698541659"}
0005435426203	B1B1D4	0457 710916	NINA DANILOVA	{"phone": "+70658042630"}
0005435426204	B1B1D4	9992 813180	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov07101970@postgrespro.ru", "phone": "+70839795655"}
0005435426205	75C9B3	8576 254397	ELENA PAVLOVA	{"phone": "+70547252890"}
0005435426206	C03F3C	4057 752250	NATALYA PETROVA	{"phone": "+70657053741"}
0005435426207	C03F3C	2496 896399	ALEKSEY TIKHONOV	{"email": "a_tikhonov-071970@postgrespro.ru", "phone": "+70220051292"}
0005435426208	244092	6475 292822	LYUBOV MELNIKOVA	{"email": "melnikova_l.011977@postgrespro.ru", "phone": "+70871352320"}
0005435426209	6CE280	3410 629321	ELENA FOMINA	{"phone": "+70371034803"}
0005435426210	1B2A24	3001 864811	VIKTOR KUZNECOV	{"email": "kuznecov.viktor.1980@postgrespro.ru", "phone": "+70309435040"}
0005435426211	6A1FC4	9741 991004	VALENTINA ANISIMOVA	{"phone": "+70657946371"}
0005435426212	6A1FC4	3623 588137	ANZHELA PAVLOVA	{"email": "anzhela-pavlova_1964@postgrespro.ru", "phone": "+70630375320"}
0005435426213	7259F5	0700 772884	VLADIMIR KRASNOV	{"email": "krasnovvladimir101970@postgrespro.ru", "phone": "+70677950773"}
0005435426214	E25209	9182 125750	ALEKSANDR PETROV	{"phone": "+70765716500"}
0005435426215	A01682	8001 055338	NINA MELNIKOVA	{"phone": "+70371875676"}
0005435426216	A01682	0789 073603	GENNADIY SOLOVEV	{"email": "solovev_g111970@postgrespro.ru", "phone": "+70246542772"}
0005435426217	4A4417	4491 855262	BORIS IVANOV	{"email": "bivanov-091973@postgrespro.ru", "phone": "+70291455779"}
0005435426218	7B449C	2348 054573	VLADIMIR ROMANOV	{"email": "romanovvladimir1966@postgrespro.ru", "phone": "+70970526063"}
0005435426219	5D8014	2092 929097	SVETLANA ARKHIPOVA	{"email": "arkhipova.svetlana-051976@postgrespro.ru", "phone": "+70470024670"}
0005435426220	51C4BD	4570 353275	NIKITA OSIPOV	{"phone": "+70111851942"}
0005435426221	902086	0102 492948	SVETLANA LOGINOVA	{"phone": "+70995262717"}
0005435426222	89E266	8793 909714	NINA SOKOLOVA	{"phone": "+70306381669"}
0005435426223	89E266	7297 039634	NIKOLAY SIDOROV	{"email": "nikolaysidorov22021978@postgrespro.ru", "phone": "+70356633313"}
0005435426224	C8EE97	5595 730977	ANGELINA BELYAEVA	{"email": "belyaeva_angelina_1968@postgrespro.ru", "phone": "+70120846174"}
0005435426225	511B2B	9791 216951	ANATOLIY KULIKOV	{"email": "anatoliy.kulikov.091978@postgrespro.ru", "phone": "+70487430327"}
0005435426226	CE03EC	3553 998702	KSENIYA ZHUKOVA	{"phone": "+70433049744"}
0005435426227	2B362B	0580 554147	OLEG SMIRNOV	{"email": "smirnov.o1975@postgrespro.ru", "phone": "+70233189447"}
0005435426228	004C1C	2586 090705	EGOR ALEKSANDROV	{"email": "e.aleksandrov.14071977@postgrespro.ru", "phone": "+70824690376"}
0005435426229	004C1C	9104 974461	IRINA SOROKINA	{"email": "sorokina-i.25111969@postgrespro.ru", "phone": "+70919117582"}
0005435426230	64A745	2943 629394	OLGA EGOROVA	{"phone": "+70376633177"}
0005435426231	68C889	0386 641836	MARGARITA KOZLOVA	{"email": "m_kozlova-28061977@postgrespro.ru", "phone": "+70392127907"}
0005435426232	68C889	7007 959188	ALEKSANDRA IVANOVA	{"phone": "+70664823026"}
0005435426233	1C28FD	1523 942994	SERGEY IVANOV	{"email": "sergey_ivanov_22021963@postgrespro.ru", "phone": "+70740230763"}
0005435426234	1C28FD	5566 408633	ALBINA ORLOVA	{"phone": "+70413789326"}
0005435426235	1C28FD	4471 039462	NINA ORLOVA	{"email": "orlova-nina.24021982@postgrespro.ru", "phone": "+70094790227"}
0005435426236	97FDDA	5557 344674	GENNADIY SHEVCHENKO	{"phone": "+70965116447"}
0005435426237	6E0677	1651 027251	NINA KUZMINA	{"email": "ninakuzmina-20011976@postgrespro.ru", "phone": "+70738253968"}
0005435426238	6E0677	6192 376305	SVETLANA KULIKOVA	{"email": "svetlanakulikova-15111972@postgrespro.ru", "phone": "+70235908341"}
0005435426239	6E0677	6038 844317	ALEKSEY KOZLOV	{"phone": "+70674216608"}
0005435426240	6E0677	9567 032577	YURIY NIKOLAEV	{"phone": "+70798256770"}
0005435426241	10F65B	5731 570109	TATYANA MIKHAYLOVA	{"email": "tatyana_mikhaylova-011959@postgrespro.ru", "phone": "+70661080988"}
0005435426242	A982CF	4515 345707	ALEKSANDR IVANOV	{"phone": "+70425217199"}
0005435426243	65F24B	4875 074235	LYUBOV TARASOVA	{"email": "tarasova.l_19111964@postgrespro.ru", "phone": "+70434681217"}
0005435426244	65F24B	9051 638155	EGOR POPOV	{"phone": "+70670948319"}
0005435426245	36729F	4377 166935	MIKHAIL GORBUNOV	{"email": "mikhail_gorbunov.1972@postgrespro.ru", "phone": "+70992699464"}
0005435426246	BEAB4F	4510 994848	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.29081980@postgrespro.ru", "phone": "+70435075913"}
0005435426247	0ADC91	3975 120807	ZOYA KOVALEVA	{"email": "zkovaleva-111964@postgrespro.ru", "phone": "+70681025158"}
0005435426249	D8EA7C	3576 593935	OKSANA NIKITINA	{"email": "o_nikitina18051982@postgrespro.ru", "phone": "+70493661045"}
0005435426250	7C48DF	0576 446080	DARYA SOROKINA	{"phone": "+70145386215"}
0005435426251	E1EAD6	0447 665034	ALEKSANDR PAVLOV	{"phone": "+70992891212"}
0005435426252	E08449	0485 970756	ELIZAVETA ANTONOVA	{"email": "antonova_e081969@postgrespro.ru", "phone": "+70239615962"}
0005435426253	E08449	6460 790713	ANDREY NIKOLAEV	{"email": "a.nikolaev09101970@postgrespro.ru", "phone": "+70982941382"}
0005435426254	7B2C52	2987 248391	NINA AFANASEVA	{"email": "afanaseva.n.1986@postgrespro.ru", "phone": "+70385220397"}
0005435426255	7B2C52	6461 403667	NATALYA KOROLEVA	{"phone": "+70757653639"}
0005435426256	FF47C6	1446 058752	ELENA RYABOVA	{"phone": "+70638526785"}
0005435426257	985729	0564 781289	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir091970@postgrespro.ru", "phone": "+70473177457"}
0005435426258	029968	6871 792751	OLEG ZAKHAROV	{"email": "oleg-zakharov-1960@postgrespro.ru", "phone": "+70649694920"}
0005435426259	819CEC	3891 569785	MARIYA ORLOVA	{"email": "mariyaorlova_1971@postgrespro.ru", "phone": "+70956333826"}
0005435426260	8F3034	6926 384187	EVGENIY AFANASEV	{"email": "evgeniyafanasev1973@postgrespro.ru", "phone": "+70527947717"}
0005435426261	1E4E19	9923 304553	IVAN NIKOLAEV	{"phone": "+70354386647"}
0005435426262	3FEC03	6188 792096	MARIYA GORBUNOVA	{"phone": "+70283123061"}
0005435426263	3FEC03	4153 654601	EVGENIY MOROZOV	{"phone": "+70463864268"}
0005435426264	A2DD9B	3161 561108	MARK PETROV	{"phone": "+70563769508"}
0005435426265	D711CD	9364 922572	DENIS FEDOROV	{"email": "fedorov-denis-031967@postgrespro.ru", "phone": "+70305317145"}
0005435426266	FA470A	9865 956006	VLADIMIR ALEKSEEV	{"phone": "+70139981283"}
0005435426267	D33DD7	2179 758406	INNA IVANOVA	{"email": "ivanova-inna1966@postgrespro.ru", "phone": "+70139626601"}
0005435426268	B65FC3	8026 307045	DENIS MOISEEV	{"email": "moiseev_denis_24121973@postgrespro.ru", "phone": "+70769385109"}
0005435426269	D46A14	6807 060157	LARISA FROLOVA	{"phone": "+70347049681"}
0005435426270	D46A14	7133 962807	OLGA PETROVA	{"phone": "+70669499546"}
0005435426271	A03FFC	7652 965844	VLADIMIR BELOV	{"phone": "+70180738336"}
0005435426272	68F563	4401 291691	ANDREY ANDREEV	{"phone": "+70619126331"}
0005435426273	70F9BE	0266 031137	TATYANA ARKHIPOVA	{"email": "tarkhipova.1968@postgrespro.ru", "phone": "+70047084907"}
0005435426274	0DE047	2253 964697	IVAN BORISOV	{"phone": "+70223148180"}
0005435426275	038364	1885 895588	NADEZHDA LAZAREVA	{"email": "nadezhda.lazareva.011973@postgrespro.ru", "phone": "+70835400744"}
0005435426276	BE26EF	6720 706104	ALEKSANDR VOROBEV	{"phone": "+70046792902"}
0005435426277	BE26EF	5620 442921	ANDREY DAVYDOV	{"email": "davydov-a_1984@postgrespro.ru", "phone": "+70541129090"}
0005435426278	ABF177	6718 860605	NINA IVANOVA	{"email": "ivanovan.16121968@postgrespro.ru", "phone": "+70151430384"}
0005435426279	51C3ED	3872 977099	ELENA ISAEVA	{"phone": "+70414666747"}
0005435426280	866D1E	3810 797801	SVETLANA POPOVA	{"email": "popova.s_24111974@postgrespro.ru", "phone": "+70798182432"}
0005435426281	CAEEF1	6245 675470	YURIY MOROZOV	{"email": "morozov-y.021966@postgrespro.ru", "phone": "+70405282742"}
0005435426282	335445	6089 954864	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov11011975@postgrespro.ru", "phone": "+70374615069"}
0005435426283	15C770	1355 865743	ELENA ZAYCEVA	{"phone": "+70461535188"}
0005435426284	A91C0B	5132 325678	YURIY SCHERBAKOV	{"email": "yuriy-scherbakov-1972@postgrespro.ru", "phone": "+70718431151"}
0005435426285	6E4080	8781 836338	NIKITA NAZAROV	{"phone": "+70720788724"}
0005435426286	404753	2316 189610	MARIYA BOGDANOVA	{"email": "bogdanova.m-021978@postgrespro.ru", "phone": "+70242021159"}
0005435426287	404753	3754 603761	ANDREY MAKSIMOV	{"phone": "+70079773577"}
0005435426288	F3D7AB	4694 325163	SVETLANA KOLESNIKOVA	{"email": "skolesnikova_17051980@postgrespro.ru", "phone": "+70211601790"}
0005435426289	433AD3	8525 693633	VADIM KUZNECOV	{"phone": "+70904382251"}
0005435426290	4DDB3B	6289 208257	SVETLANA KAZAKOVA	{"email": "skazakova18121970@postgrespro.ru", "phone": "+70048609713"}
0005435426291	4DDB3B	8624 106625	NAIL IVANOV	{"phone": "+70669535882"}
0005435426292	A331CD	2400 816300	IGOR BARANOV	{"email": "igor.baranov_1964@postgrespro.ru", "phone": "+70476934649"}
0005435426293	FFFFA8	0563 487643	LYUDMILA ANDREEVA	{"phone": "+70953985370"}
0005435426294	B26F50	3691 109925	ELENA ALEKSANDROVA	{"email": "e-aleksandrova041982@postgrespro.ru", "phone": "+70154356723"}
0005435426295	47626A	8677 368272	ALLA FEDOROVA	{"phone": "+70336775743"}
0005435426296	A37EE4	9620 382277	ALEKSEY PAVLOV	{"email": "a.pavlov_1974@postgrespro.ru", "phone": "+70027065342"}
0005435426297	A37EE4	9126 709990	ANDREY MIKHAYLOV	{"email": "mikhaylov.a.011975@postgrespro.ru", "phone": "+70072181743"}
0005435426298	26A3CD	5459 546478	GENNADIY SOROKIN	{"phone": "+70310023957"}
0005435426299	26A3CD	2938 329086	YULIYA MALYSHEVA	{"phone": "+70480901747"}
0005435426300	056779	8583 415129	VLADIMIR BONDARENKO	{"email": "vbondarenko07061973@postgrespro.ru", "phone": "+70805193503"}
0005435426301	651337	8087 747664	GEORGIY DENISOV	{"email": "g_denisov-081972@postgrespro.ru", "phone": "+70673848082"}
0005435426302	62C61B	5549 203908	NIKOLAY NAZAROV	{"phone": "+70562994299"}
0005435426303	62C61B	3444 435876	VYACHESLAV BORISOV	{"phone": "+70057456552"}
0005435426304	570D10	1000 495635	ALINA ANTONOVA	{"email": "antonova-alina-1975@postgrespro.ru", "phone": "+70020633174"}
0005435426305	D18E5A	3294 861449	RAMIL ISAEV	{"email": "ramil-isaev1971@postgrespro.ru", "phone": "+70882074338"}
0005435426306	D18E5A	6277 246394	VASILIY SERGEEV	{"phone": "+70142982808"}
0005435426307	D18E5A	4371 755361	YURIY MELNIKOV	{"email": "melnikovy-091975@postgrespro.ru", "phone": "+70009581647"}
0005435426308	98BB0F	0811 262868	VALENTINA NIKOLAEVA	{"email": "nikolaeva-valentina30061978@postgrespro.ru", "phone": "+70694126133"}
0005435426309	29F3F6	4944 741515	MAKSIM ANDREEV	{"email": "mandreev-12101969@postgrespro.ru", "phone": "+70737841424"}
0005435426310	80117C	3733 590264	LYUDMILA DAVYDOVA	{"phone": "+70789507172"}
0005435426311	5B313F	5958 089519	YURIY PAVLOV	{"phone": "+70591977183"}
0005435426312	5B313F	0853 724817	ANDREY SERGEEV	{"email": "a_sergeev-1978@postgrespro.ru", "phone": "+70912600124"}
0005435426313	89E943	3093 602311	ANASTASIYA ZAKHAROVA	{"phone": "+70792521513"}
0005435426314	E06559	4937 021724	MIKHAIL FOMIN	{"email": "m-fomin.091965@postgrespro.ru", "phone": "+70163407377"}
0005435426315	A040BB	4611 173286	ANATOLIY SMIRNOV	{"phone": "+70922444522"}
0005435426316	471EBD	1182 847768	ALEKSANDRA KUZNECOVA	{"email": "kuznecova.aleksandra051967@postgrespro.ru", "phone": "+70504451843"}
0005435426317	A64905	8160 753827	GENNADIY KAZAKOV	{"email": "kazakov-g_051967@postgrespro.ru", "phone": "+70584664735"}
0005435426318	4C6F20	7938 036758	ANNA ARKHIPOVA	{"phone": "+70156615968"}
0005435426319	711903	4111 762530	NATALYA EGOROVA	{"email": "egorova_natalya-25121973@postgrespro.ru", "phone": "+70291730581"}
0005435426320	88C494	6426 573042	SERGEY BONDARENKO	{"phone": "+70510924155"}
0005435426321	935A59	3188 286129	LYUDMILA ANTONOVA	{"email": "lyudmilaantonova-10031977@postgrespro.ru", "phone": "+70456279570"}
0005435426322	935A59	9546 993088	OLEG KAZAKOV	{"email": "o.kazakov.06041973@postgrespro.ru", "phone": "+70477848637"}
0005435426323	AB57AF	2042 262905	VERA CHERNOVA	{"email": "v-chernova_1977@postgrespro.ru", "phone": "+70947521440"}
0005435426324	AB57AF	8650 074513	ALEKSANDR MAKAROV	{"email": "makarovaleksandr_18051973@postgrespro.ru", "phone": "+70408989599"}
0005435426325	D1C1D9	0951 938843	VERA EGOROVA	{"email": "egorova-vera_031974@postgrespro.ru", "phone": "+70904954832"}
0005435426326	9A7EE6	5143 408931	OLEG FEDOROV	{"email": "fedorov.oleg_101980@postgrespro.ru", "phone": "+70547419300"}
0005435426327	9A7EE6	6830 037701	IRINA MARTYNOVA	{"email": "imartynova-1971@postgrespro.ru", "phone": "+70945566099"}
0005435426328	E76215	5498 774372	RUSLAN PAVLOV	{"phone": "+70256578486"}
0005435426329	2617B0	3408 176796	SVYATOSLAV NAZAROV	{"phone": "+70065297205"}
0005435426330	A76CBA	0447 407699	NIKITA KOROLEV	{"email": "nkorolev_08061976@postgrespro.ru", "phone": "+70235181315"}
0005435426331	B1C202	4775 404824	ALEKSEY BELOV	{"phone": "+70965326910"}
0005435426332	B1C202	1732 003549	ELENA KUZNECOVA	{"phone": "+70480523743"}
0005435426333	B1C202	5378 700722	NADEZHDA IVANOVA	{"phone": "+70773947399"}
0005435426334	137E43	7628 836791	GRIGORIY KAZAKOV	{"email": "g_kazakov_15061990@postgrespro.ru", "phone": "+70235601218"}
0005435426335	137E43	5385 772734	SERGEY ABRAMOV	{"email": "abramov-sergey-1978@postgrespro.ru", "phone": "+70654501306"}
0005435426336	0DC166	3446 770236	ALEKSANDR KOZLOV	{"email": "kozlov-aleksandr-1964@postgrespro.ru", "phone": "+70002349200"}
0005435426337	F97E33	1828 568771	MARIYA TIKHONOVA	{"email": "tikhonova.m-29081977@postgrespro.ru", "phone": "+70681396105"}
0005435426338	7D3CD7	4119 440528	OKSANA MIKHAYLOVA	{"phone": "+70365828329"}
0005435426339	8DF8C1	0699 773661	VALENTINA GAVRILOVA	{"email": "v.gavrilova-13011985@postgrespro.ru", "phone": "+70530815777"}
0005435426340	400E60	0158 145297	DENIS TARASOV	{"email": "tarasovdenis.121974@postgrespro.ru", "phone": "+70017041444"}
0005435426341	400E60	5938 466710	EVGENIYA TARASOVA	{"email": "tarasova_evgeniya20081971@postgrespro.ru", "phone": "+70397235571"}
0005435426342	1F467A	5522 403306	OLGA ZAKHAROVA	{"phone": "+70388750298"}
0005435426343	6A813B	8903 568642	EMIL ZHURAVLEV	{"email": "e-zhuravlev-05071962@postgrespro.ru", "phone": "+70480397454"}
0005435426344	53E853	9691 994425	ANASTASIYA KISELEVA	{"phone": "+70983956781"}
0005435426345	6DADA1	8460 689107	YULIYA KOZLOVA	{"phone": "+70158639693"}
0005435426346	61077A	5496 538657	SVETLANA ANISIMOVA	{"email": "anisimovasvetlana_121971@postgrespro.ru", "phone": "+70261444375"}
0005435426347	61077A	9004 930013	ALEKSANDR NIKOLAEV	{"email": "nikolaev_a-061975@postgrespro.ru", "phone": "+70066732902"}
0005435426348	BC2B5B	3712 538985	DMITRIY GRIGOREV	{"email": "grigorevdmitriy.101970@postgrespro.ru", "phone": "+70988971536"}
0005435426349	2F957F	4738 105077	ELENA SEMENOVA	{"email": "elenasemenova111977@postgrespro.ru", "phone": "+70209880970"}
0005435426350	3A8457	8848 815305	VIKTORIYA SAVELEVA	{"phone": "+70375749518"}
0005435426351	BDD9BF	3088 588918	VITALIY TARASOV	{"phone": "+70786867338"}
0005435426352	F3DF35	5446 153380	GENNADIY SCHERBAKOV	{"phone": "+70699468394"}
0005435426353	F3DF35	9088 003054	SERGEY FILIPPOV	{"phone": "+70112574438"}
0005435426354	BA2397	2979 929777	DARYA ALEKSEEVA	{"phone": "+70620426038"}
0005435426355	02D54E	3886 294950	ROMAN DENISOV	{"email": "roman_denisov011975@postgrespro.ru", "phone": "+70758768564"}
0005435426356	23E10F	0359 692298	ALEKSANDR KOZLOV	{"email": "a.kozlov28081972@postgrespro.ru", "phone": "+70081328124"}
0005435426357	A5A1CB	4495 272390	LYUBOV TIMOFEEVA	{"phone": "+70247406815"}
0005435426358	6917BD	3305 514015	SVETLANA POPOVA	{"email": "svetlana-popova-091970@postgrespro.ru", "phone": "+70815345869"}
0005435426359	8BC9FE	3410 822453	NONNA KUZNECOVA	{"phone": "+70459135789"}
0005435426360	8BC9FE	7698 672828	TATYANA FOMINA	{"email": "tatyana.fomina1978@postgrespro.ru", "phone": "+70550853881"}
0005435426361	DE4E11	5146 163317	OLEG GORBUNOV	{"email": "o-gorbunov051985@postgrespro.ru", "phone": "+70886478303"}
0005435426362	278FEB	3187 614394	SERGEY GRIGOREV	{"phone": "+70843879580"}
0005435426363	BC46A9	5313 767011	LYUDMILA BARANOVA	{"email": "l-baranova_30061967@postgrespro.ru", "phone": "+70471511935"}
0005435426364	BC46A9	6156 450070	NATALYA VOLKOVA	{"email": "volkova.n071967@postgrespro.ru", "phone": "+70060470485"}
0005435426365	7DCB01	1267 801740	EGOR KAZAKOV	{"phone": "+70766547568"}
0005435426366	7DCB01	0861 284760	KONSTANTIN ZAKHAROV	{"phone": "+70056669604"}
0005435426367	E481B4	3077 372162	YURIY EGOROV	{"phone": "+70897029905"}
0005435426370	D0B5D9	4927 364296	OLGA KOZLOVA	{"email": "kozlovao.081968@postgrespro.ru", "phone": "+70057304262"}
0005435426371	F30A16	9818 970094	ANDREY KAZAKOV	{"phone": "+70149349577"}
0005435426372	F30A16	8467 993635	PETR BONDARENKO	{"email": "petr_bondarenko.1972@postgrespro.ru", "phone": "+70502106182"}
0005435426373	79FE5C	8210 880163	YURIY TIMOFEEV	{"phone": "+70904957385"}
0005435426374	79FE5C	2340 592560	VIKTORIYA VOROBEVA	{"email": "vorobeva_viktoriya31101964@postgrespro.ru", "phone": "+70594162069"}
0005435426375	8411B0	3595 714116	VLADIMIR KRASNOV	{"email": "krasnovv091980@postgrespro.ru", "phone": "+70536386099"}
0005435426376	8411B0	0281 535405	LIDIYA KRASNOVA	{"email": "lidiya.krasnova1980@postgrespro.ru", "phone": "+70545443440"}
0005435426377	8411B0	5235 624017	NIKOLAY PETROV	{"email": "petrovn.18021977@postgrespro.ru", "phone": "+70261948154"}
0005435426378	7E13F9	3665 744464	GALINA TITOVA	{"email": "titovag.111979@postgrespro.ru", "phone": "+70913408148"}
0005435426379	EB3D85	3537 727000	YULIYA BOGDANOVA	{"email": "bogdanova.y09091969@postgrespro.ru", "phone": "+70752933391"}
0005435426380	EB3D85	6357 566513	ALEKSANDR PETROV	{"phone": "+70973611555"}
0005435426381	87B9AA	6743 574319	ANATOLIY GORBUNOV	{"phone": "+70405257328"}
0005435426382	98258B	7111 412412	NADEZHDA EFIMOVA	{"email": "nadezhdaefimova-15011964@postgrespro.ru", "phone": "+70414040418"}
0005435426383	6FB2CC	3127 506223	SERGEY FROLOV	{"email": "sergey_frolov.07011978@postgrespro.ru", "phone": "+70933914454"}
0005435426384	DA0617	9652 409520	ANDREY SERGEEV	{"phone": "+70699735330"}
0005435426385	F83299	6872 456930	EVGENIYA FOMINA	{"phone": "+70926585985"}
0005435426386	9CEB48	3293 256132	DMITRIY PETROV	{"phone": "+70589187534"}
0005435426387	DF85E3	9028 904800	EKATERINA POPOVA	{"phone": "+70931962003"}
0005435426388	7EA7CC	0154 722913	MIKHAIL KAZAKOV	{"phone": "+70033776546"}
0005435426389	3111CD	6055 447822	NINA ROMANOVA	{"phone": "+70110395603"}
0005435426390	7549C4	0228 501546	VITALIY ZAKHAROV	{"email": "v.zakharov-081967@postgrespro.ru", "phone": "+70591637642"}
0005435426391	7549C4	6410 424750	IRINA SOKOLOVA	{"email": "irina.sokolova_111960@postgrespro.ru", "phone": "+70817928381"}
0005435426392	7E8CF2	3727 735385	ALEKSEY MOISEEV	{"phone": "+70499609560"}
0005435426393	6DBE83	4770 905430	NATALYA SEMENOVA	{"email": "n-semenova-1977@postgrespro.ru", "phone": "+70309496837"}
0005435426394	DC65DD	8950 000470	TATYANA OSIPOVA	{"email": "tatyana.osipova1970@postgrespro.ru", "phone": "+70296173748"}
0005435426395	0A0DFF	8159 864006	ARMEN MAKAROV	{"phone": "+70383189420"}
0005435426396	0A0DFF	7244 343545	VLADIMIR STEPANOV	{"email": "vladimir_stepanov.06121967@postgrespro.ru", "phone": "+70252425177"}
0005435426397	167F39	4024 952146	NINA KOROLEVA	{"phone": "+70363257123"}
0005435426398	200758	3370 654938	DANILA GERASIMOV	{"email": "gerasimov-d12071971@postgrespro.ru", "phone": "+70886695096"}
0005435426399	200758	0404 663838	ALEKSEY KUDRYASHOV	{"phone": "+70528737731"}
0005435426400	14163E	3229 668518	VLADIMIR IVANOV	{"email": "ivanov.v-18111963@postgrespro.ru", "phone": "+70000652084"}
0005435426401	10FA7C	4568 259608	TATYANA SIDOROVA	{"email": "sidorova-tatyana011987@postgrespro.ru", "phone": "+70368495348"}
0005435426402	12E6A7	7551 790474	NADEZHDA ROMANOVA	{"email": "romanovan.1963@postgrespro.ru", "phone": "+70464531770"}
0005435426403	28410B	6272 359199	ANDREY MIRONOV	{"email": "a_mironov20101969@postgrespro.ru", "phone": "+70790314285"}
0005435426404	8C9644	6090 588541	LYUDMILA NIKOLAEVA	{"email": "nikolaeva.lyudmila.17051984@postgrespro.ru", "phone": "+70463285841"}
0005435426405	8C9644	7717 433929	GENNADIY ANTONOV	{"email": "gennadiy-antonov.1983@postgrespro.ru", "phone": "+70420992455"}
0005435426406	9E105C	3593 039720	ILYA GRIGOREV	{"email": "grigorev.i.27011974@postgrespro.ru", "phone": "+70891430877"}
0005435426407	834B44	5042 011984	IRINA MALYSHEVA	{"phone": "+70334340264"}
0005435426408	165C09	4412 578346	ELENA RODIONOVA	{"email": "e.rodionova.081979@postgrespro.ru", "phone": "+70346465190"}
0005435426409	760C1E	8175 063765	SERGEY ISAEV	{"phone": "+70820632934"}
0005435426410	E6C7E4	4283 407433	YULIYA KAZAKOVA	{"email": "kazakova-yuliya091979@postgrespro.ru", "phone": "+70187973152"}
0005435426411	6A07EE	6973 072094	NINA ABRAMOVA	{"email": "abramovan.031970@postgrespro.ru", "phone": "+70275977772"}
0005435426412	1AFDB0	7598 206005	LYUBOV KUZNECOVA	{"email": "kuznecova.l.07071975@postgrespro.ru", "phone": "+70775518914"}
0005435426413	2160C5	7334 728535	IGOR VLASOV	{"email": "vlasov-i_091974@postgrespro.ru", "phone": "+70035937160"}
0005435426414	6C0E4B	7638 568395	SERGEY KISELEV	{"phone": "+70806614965"}
0005435426415	17AB5E	4810 452341	MIKHAIL PAVLOV	{"email": "pavlov.mikhail.101979@postgrespro.ru", "phone": "+70754874842"}
0005435426416	5809E0	9826 927080	DMITRIY SHEVCHENKO	{"email": "shevchenko.dmitriy_1978@postgrespro.ru", "phone": "+70081507917"}
0005435426417	26273C	5816 211696	IVAN GRIGOREV	{"phone": "+70998181330"}
0005435426418	26273C	4007 760905	IRINA MOISEEVA	{"phone": "+70027011767"}
0005435426419	AECE6A	5226 338089	ARSENIY TARASOV	{"email": "tarasovarseniy.1974@postgrespro.ru", "phone": "+70271608512"}
0005435426420	BA4A59	2586 180741	ELENA NIKIFOROVA	{"phone": "+70084042668"}
0005435426421	2D6805	0318 130138	SERGEY IVANOV	{"phone": "+70162248661"}
0005435426422	B959C5	5967 379074	TATYANA MOROZOVA	{"phone": "+70190807291"}
0005435426423	85DAD6	6741 693913	ANNA ZHUKOVA	{"phone": "+70435984171"}
0005435426424	B0BBFD	2491 983984	VIKTOR FEDOTOV	{"email": "v-fedotov1980@postgrespro.ru", "phone": "+70956862978"}
0005435426425	B0BBFD	8969 278412	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l1972@postgrespro.ru", "phone": "+70870108214"}
0005435426426	0A2E8C	7892 839793	ALEKSANDR RODIONOV	{"phone": "+70598416071"}
0005435426427	0A2E8C	4329 007218	OLGA ORLOVA	{"email": "o.orlova101970@postgrespro.ru", "phone": "+70577902223"}
0005435426428	4B8DC3	4391 851541	FARID VASILEV	{"email": "vasilev-farid-111980@postgrespro.ru", "phone": "+70289175124"}
0005435426429	73B105	5537 366025	ALEKSEY SEMENOV	{"phone": "+70932829077"}
0005435426430	26B0CF	1723 217396	ALEKSANDRA GRISHINA	{"email": "grishina.a101971@postgrespro.ru", "phone": "+70331538517"}
0005435426431	02348C	7188 038646	VERONIKA KOMAROVA	{"phone": "+70277150008"}
0005435426432	2866B5	8073 916378	MARINA DMITRIEVA	{"email": "marinadmitrieva.1968@postgrespro.ru", "phone": "+70764887190"}
0005435426433	89B80A	7715 471189	DMITRIY SOKOLOV	{"phone": "+70756141735"}
0005435426434	6835FC	4621 094344	ANASTASIYA KUDRYASHOVA	{"email": "akudryashova_091972@postgrespro.ru", "phone": "+70628994427"}
0005435426435	6835FC	6084 013304	OLGA ILINA	{"email": "ilina.o-1971@postgrespro.ru", "phone": "+70338894900"}
0005435426436	C85F9A	9888 955530	NATALYA BELYAEVA	{"email": "belyaeva_natalya-011971@postgrespro.ru", "phone": "+70493980548"}
0005435426437	B2EBFB	6103 875429	VLADIMIR VOLKOV	{"phone": "+70261097664"}
0005435426438	C78EE3	9866 809035	EVGENIY SOKOLOV	{"phone": "+70416331477"}
0005435426439	175D46	0160 393111	OLGA ROMANOVA	{"phone": "+70503668140"}
0005435426440	0C0A61	8240 306492	ELENA FROLOVA	{"email": "frolova_elena1978@postgrespro.ru", "phone": "+70320232721"}
0005435426441	DBDB88	7372 686482	EVGENIYA ZHURAVLEVA	{"phone": "+70318837609"}
0005435426442	6F478E	7927 953475	MARIYA IVANOVA	{"phone": "+70646137367"}
0005435426443	CA8054	1642 649922	YURIY ZAKHAROV	{"phone": "+70125643991"}
0005435426444	FB8D0A	1272 423014	MAKSIM DENISOV	{"phone": "+70520990541"}
0005435426445	86B076	9187 847052	MIKHAIL IVANOV	{"email": "ivanov.mikhail.051956@postgrespro.ru", "phone": "+70312353020"}
0005435426446	86B076	7200 611258	LIDIYA LAZAREVA	{"phone": "+70517583704"}
0005435426447	C9DB17	0851 124574	VLADIMIR ISAEV	{"email": "v.isaev-1980@postgrespro.ru", "phone": "+70279924408"}
0005435426448	262651	1698 278175	GALINA ILINA	{"phone": "+70663695735"}
0005435426449	685672	1905 505790	LYUDMILA KRASNOVA	{"email": "krasnova_lyudmila-24011975@postgrespro.ru", "phone": "+70335291916"}
0005435426450	5676A3	7686 851118	ANDREY SIDOROV	{"email": "sidorovandrey.09031971@postgrespro.ru", "phone": "+70698720830"}
0005435426451	230949	7994 539159	ARTEM ABRAMOV	{"email": "aabramov-26061966@postgrespro.ru", "phone": "+70345854484"}
0005435426452	230949	4696 057180	DANILA MIKHAYLOV	{"phone": "+70287824971"}
0005435426453	230949	3650 862965	NATALYA STEPANOVA	{"phone": "+70949138233"}
0005435426454	3F5BF8	4728 518833	MIKHAIL NIKOLAEV	{"email": "mikhailnikolaev.101983@postgrespro.ru", "phone": "+70830410543"}
0005435426455	3B8098	8199 566640	NIKOLAY ALEKSEEV	{"phone": "+70416178109"}
0005435426456	3B8098	5889 242781	OLGA KONOVALOVA	{"phone": "+70494843670"}
0005435426457	2FB99B	5110 136417	SERGEY MIKHAYLOV	{"phone": "+70532382933"}
0005435426458	3C8B3A	6142 288329	PAVEL IVANOV	{"phone": "+70467062722"}
0005435426459	D74A1E	1155 024822	ANTON MAKAROV	{"phone": "+70107538762"}
0005435426460	D74A1E	5053 105394	IRINA ZAYCEVA	{"phone": "+70819919391"}
0005435426461	06634D	8886 761122	GALINA KALININA	{"phone": "+70650368748"}
0005435426462	06634D	2964 955302	VLADIMIR IVANOV	{"email": "vladimir.ivanov.011972@postgrespro.ru", "phone": "+70299348595"}
0005435426463	081992	7082 811836	ILYA KUZNECOV	{"email": "kuznecov-ilya-1965@postgrespro.ru", "phone": "+70020834020"}
0005435426464	7559F2	4627 959173	MARIYA YAKOVLEVA	{"email": "m.yakovleva.17051977@postgrespro.ru", "phone": "+70936859455"}
0005435426465	7559F2	3937 158812	AYRAT KRASNOV	{"email": "akrasnov.061979@postgrespro.ru", "phone": "+70450470665"}
0005435426466	7559F2	3081 456806	NINA NOVIKOVA	{"email": "ninanovikova_1967@postgrespro.ru", "phone": "+70994007066"}
0005435426467	004B72	2544 611555	YAKOV GERASIMOV	{"phone": "+70214800394"}
0005435426468	004B72	9076 688671	IRINA PAVLOVA	{"email": "i.pavlova031963@postgrespro.ru", "phone": "+70217100358"}
0005435426469	982156	3691 694140	ARTEM FOMIN	{"email": "artem_fomin-081980@postgrespro.ru", "phone": "+70787741280"}
0005435426470	982156	7959 069663	YULIYA POTAPOVA	{"email": "potapova-yuliya-12091972@postgrespro.ru", "phone": "+70499146321"}
0005435426471	46435C	0353 709259	IGOR ZHUKOV	{"phone": "+70768464490"}
0005435426472	75B444	1405 239387	NIKOLAY STEPANOV	{"email": "nikolaystepanov-051974@postgrespro.ru", "phone": "+70327875008"}
0005435426473	0A045A	3196 072746	ANTON SOKOLOV	{"email": "sokolov_anton.18101977@postgrespro.ru", "phone": "+70135768602"}
0005435426474	723C79	1792 654118	PETR DMITRIEV	{"email": "dmitriev.petr-11011977@postgrespro.ru", "phone": "+70514737811"}
0005435426475	723C79	4733 352857	PAVEL PETROV	{"email": "pavel-petrov1970@postgrespro.ru", "phone": "+70034178292"}
0005435426476	8EC459	9512 541462	VLADIMIR CHERNOV	{"phone": "+70362577975"}
0005435426477	47574E	3163 396846	VALERIY MIKHAYLOV	{"phone": "+70858675742"}
0005435426478	7A4D6F	5682 383386	ALEKSEY KOZLOV	{"phone": "+70050593867"}
0005435426479	7A4D6F	2606 936022	VLADIMIR KUDRYASHOV	{"email": "kudryashovv_04051975@postgrespro.ru", "phone": "+70981539604"}
0005435426480	68C299	6297 548877	ALEKSANDR GERASIMOV	{"email": "gerasimova.15071980@postgrespro.ru", "phone": "+70981144259"}
0005435426481	68C299	7479 509516	LYUDMILA SOROKINA	{"email": "lyudmila_sorokina.1962@postgrespro.ru", "phone": "+70245308381"}
0005435426482	68C299	0441 263176	ELENA POPOVA	{"email": "elena-popova.101969@postgrespro.ru", "phone": "+70638594534"}
0005435426483	7718A9	6861 354780	VLADIMIR KUDRYASHOV	{"email": "v-kudryashov_13061979@postgrespro.ru", "phone": "+70282442937"}
0005435426484	A0BF7D	3231 547382	SVETLANA MIKHAYLOVA	{"phone": "+70535340734"}
0005435426485	A0BF7D	2931 291320	VASILIY SOKOLOV	{"email": "sokolov-vasiliy.28101956@postgrespro.ru", "phone": "+70280929422"}
0005435426486	846E72	2743 076551	YULIYA ZAYCEVA	{"phone": "+70425214227"}
0005435426487	50F19A	3022 311173	ALENA KALININA	{"email": "kalinina.a-081962@postgrespro.ru", "phone": "+70819436473"}
0005435426488	8FD038	0328 891525	NATALYA FEDOROVA	{"phone": "+70308393265"}
0005435426489	3F8A7B	0216 124702	GALINA IVANOVA	{"email": "ivanova_galina.20101970@postgrespro.ru", "phone": "+70742146585"}
0005435426490	ECE17A	1955 706485	LYUBOV KOROLEVA	{"phone": "+70676738523"}
0005435426491	0843FD	0861 727183	SERGEY MAKAROV	{"email": "s.makarov081984@postgrespro.ru", "phone": "+70705541881"}
0005435426492	0843FD	9255 441766	VLADIMIR MIRONOV	{"phone": "+70407375622"}
0005435426493	E039C3	0826 075459	YURIY ZAKHAROV	{"phone": "+70349414879"}
0005435426494	DD4573	2531 419522	ALEKSANDR SOKOLOV	{"phone": "+70286064225"}
0005435426495	DD4573	1492 062956	ELENA BORISOVA	{"email": "elena.borisova_111967@postgrespro.ru", "phone": "+70958434261"}
0005435426496	6A403B	1637 550652	VERA FILATOVA	{"email": "v-filatova_1978@postgrespro.ru", "phone": "+70045998157"}
0005435426497	38CD17	2246 414967	ALEKSANDR TARASOV	{"email": "atarasov13031976@postgrespro.ru", "phone": "+70268523236"}
0005435426498	38CD17	3911 222366	NIKITA EGOROV	{"phone": "+70052469744"}
0005435426499	3654AB	7331 631769	ALEKSANDR VASILEV	{"email": "a.vasilev1982@postgrespro.ru", "phone": "+70254506024"}
0005435426500	3654AB	4054 446390	MARIYA BARANOVA	{"email": "mariyabaranova_27081977@postgrespro.ru", "phone": "+70655123325"}
0005435426501	3654AB	4281 549243	MIKHAIL IVANOV	{"phone": "+70817094306"}
0005435426502	95BC40	8933 562382	TAMARA FEDOROVA	{"phone": "+70400867277"}
0005435426503	95BC40	5013 540420	EKATERINA STEPANOVA	{"phone": "+70741521000"}
0005435426504	2535E8	3802 093105	PAVEL SMIRNOV	{"phone": "+70661069928"}
0005435426505	5E70F9	6001 319884	ALEKSANDR SIDOROV	{"phone": "+70423228137"}
0005435426506	5E70F9	0659 267876	NADEZHDA POPOVA	{"email": "nadezhdapopova_14111979@postgrespro.ru", "phone": "+70761870973"}
0005435426507	D5B62F	3511 426711	ALEKSANDR ZHUKOV	{"email": "zhukov.aleksandr22011974@postgrespro.ru", "phone": "+70637120868"}
0005435426508	D5B62F	3557 567115	ALEKSANDR ISAEV	{"phone": "+70507082996"}
0005435426509	F6B661	6237 724549	IVAN FROLOV	{"phone": "+70614097443"}
0005435426510	4A52A7	4049 498511	TATYANA KUZNECOVA	{"phone": "+70329209172"}
0005435426511	D9B94E	1540 386322	VYACHESLAV MIKHAYLOV	{"email": "mikhaylov-v-02061981@postgrespro.ru", "phone": "+70416579667"}
0005435426512	7CB639	3911 301727	AZAT KULIKOV	{"email": "kulikov.a.1963@postgrespro.ru", "phone": "+70823567934"}
0005435426513	7C3E4C	8300 952397	SVETLANA BOGDANOVA	{"phone": "+70791167343"}
0005435426514	7C3E4C	9125 605519	MARINA AFANASEVA	{"email": "afanaseva_m-1976@postgrespro.ru", "phone": "+70827324869"}
0005435426515	810D59	5567 700997	IRINA ROMANOVA	{"phone": "+70486834231"}
0005435426516	810D59	7933 456932	ANDREY NAZAROV	{"phone": "+70001301829"}
0005435426517	F241E1	3189 061630	SANIYA MAKAROVA	{"phone": "+70952555643"}
0005435426518	F7277E	6102 247740	ANNA PETROVA	{"email": "apetrova-111972@postgrespro.ru", "phone": "+70850691744"}
0005435426519	9DCCA9	4972 383509	TATYANA DMITRIEVA	{"email": "tdmitrieva_1969@postgrespro.ru", "phone": "+70491506030"}
0005435426520	352B6C	0345 697396	OLGA IVANOVA	{"phone": "+70086913004"}
0005435426521	4A7080	6293 192804	NINA NIKITINA	{"email": "n-nikitina-101967@postgrespro.ru", "phone": "+70726790359"}
0005435426522	C788AD	5384 488826	ASIYA BORISOVA	{"email": "borisova-asiya29091966@postgrespro.ru", "phone": "+70522007598"}
0005435426523	B8693E	9991 851619	ANTON KULIKOV	{"email": "anton.kulikov_011976@postgrespro.ru", "phone": "+70228837347"}
0005435426524	C85637	2920 516079	ALEKSANDRA SEMENOVA	{"phone": "+70228023277"}
0005435426525	095EFE	9393 338069	RIMMA KUZMINA	{"phone": "+70453831922"}
0005435426526	9806A2	3905 304588	IVAN MATVEEV	{"phone": "+70309359803"}
0005435426527	30DE46	0762 593326	YURIY SERGEEV	{"email": "ysergeev-16071983@postgrespro.ru", "phone": "+70567654806"}
0005435426528	8814C6	0783 182851	ANASTASIYA STEPANOVA	{"email": "astepanova.071976@postgrespro.ru", "phone": "+70621996551"}
0005435426529	E0DEDF	5592 755878	NATALYA KOZLOVA	{"email": "natalya-kozlova26101966@postgrespro.ru", "phone": "+70673734088"}
0005435426530	E0DEDF	1820 934468	ANDREY ZAYCEV	{"phone": "+70141505231"}
0005435426531	27CD1F	4894 355972	VERA MOROZOVA	{"email": "v.morozova1961@postgrespro.ru", "phone": "+70388554936"}
0005435426532	CB9613	7391 820264	ANDREY NOVIKOV	{"phone": "+70887337930"}
0005435426533	A34CEF	8153 277108	YANA BORISOVA	{"email": "yana_borisova-011976@postgrespro.ru", "phone": "+70389201983"}
0005435426534	C0091C	8430 855752	PAVEL KUZNECOV	{"email": "p_kuznecov-04091977@postgrespro.ru", "phone": "+70128408474"}
0005435426535	A024FA	1627 603021	VALENTINA SOLOVEVA	{"phone": "+70781414969"}
0005435426536	F86913	5155 032272	DMITRIY MAKSIMOV	{"phone": "+70498757378"}
0005435426537	F86913	8032 401906	LIDIYA KOMAROVA	{"email": "l_komarova021978@postgrespro.ru", "phone": "+70589791075"}
0005435426538	CA9BA8	1829 019661	YAROSLAV TIMOFEEV	{"email": "y_timofeev03061981@postgrespro.ru", "phone": "+70071778894"}
0005435426539	CA9BA8	7631 512963	SERGEY KOZLOV	{"phone": "+70704108515"}
0005435426540	CA9BA8	1282 743045	ALEKSANDR MOROZOV	{"email": "morozov_aleksandr08091968@postgrespro.ru", "phone": "+70088461454"}
0005435426541	CA9BA8	3048 628167	TAMARA SOROKINA	{"email": "sorokina.t.1974@postgrespro.ru", "phone": "+70210685624"}
0005435426542	3D3EB4	8683 662642	ELENA KUZMINA	{"email": "kuzminaelena-04071972@postgrespro.ru", "phone": "+70848126839"}
0005435426543	3D3EB4	1991 644381	ALEKSEY VLASOV	{"email": "aleksey-vlasov.1972@postgrespro.ru", "phone": "+70339508033"}
0005435426544	B199EC	9076 503791	KIRILL ORLOV	{"email": "orlov_k1975@postgrespro.ru", "phone": "+70639831678"}
0005435426545	A73094	6324 918405	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov_1976@postgrespro.ru", "phone": "+70710781026"}
0005435426546	A73094	3867 289813	NINA KULIKOVA	{"phone": "+70380878747"}
0005435426547	584BA3	6510 635939	KSENIYA BORISOVA	{"phone": "+70041717348"}
0005435426548	584BA3	2228 895552	ALEKSANDR GUSEV	{"phone": "+70711765543"}
0005435426549	8DC14F	9632 464333	DMITRIY MAKAROV	{"phone": "+70079838943"}
0005435426550	8DC14F	8462 728917	OLGA NIKITINA	{"phone": "+70079066519"}
0005435426551	5346E5	2032 394335	VLADIMIR FEDOTOV	{"email": "vladimir-fedotov_27021961@postgrespro.ru", "phone": "+70174558145"}
0005435426552	5346E5	3239 943223	GALINA EGOROVA	{"email": "egorova-g-021976@postgrespro.ru", "phone": "+70561678699"}
0005435426553	5346E5	6527 649004	VLADIMIR SOLOVEV	{"phone": "+70941533394"}
0005435426554	6ED4CD	4516 765424	EVGENIYA KOVALEVA	{"email": "kovaleva_evgeniya1957@postgrespro.ru", "phone": "+70823582100"}
0005435426555	6ED4CD	0441 228167	ELIZAVETA SOLOVEVA	{"email": "solovevaelizaveta-1975@postgrespro.ru", "phone": "+70187162484"}
0005435426556	2BFE20	2511 698789	ANNA MAKAROVA	{"phone": "+70243412186"}
0005435426557	2BFE20	3397 778005	ALEKSANDR NAZAROV	{"email": "nazarov.a-111976@postgrespro.ru", "phone": "+70427521692"}
0005435426558	2BFE20	6512 011917	MARIYA KUZNECOVA	{"phone": "+70898656482"}
0005435426559	4135E7	1067 725720	VLADIMIR KUZNECOV	{"phone": "+70834319310"}
0005435426560	4135E7	8980 701655	ELENA KUZNECOVA	{"email": "kuznecova-elena.021964@postgrespro.ru", "phone": "+70064720733"}
0005435426561	E9857A	8842 305171	PAVEL ZAKHAROV	{"phone": "+70832210292"}
0005435426562	9EF61B	1954 431306	MARIYA AFANASEVA	{"email": "afanasevam.091977@postgrespro.ru", "phone": "+70371803847"}
0005435426563	D26954	6187 449241	NINA KUZNECOVA	{"phone": "+70506035585"}
0005435426564	D26954	9908 441126	MARINA SOROKINA	{"email": "m.sorokina-17041971@postgrespro.ru", "phone": "+70239103746"}
0005435426565	47ECC4	6560 688834	SERGEY NAUMOV	{"phone": "+70578739120"}
0005435426566	47ECC4	9267 952199	GENNADIY STEPANOV	{"phone": "+70846525758"}
0005435426567	E01A6D	4400 054180	VIKTOR FEDOROV	{"phone": "+70388209026"}
0005435426568	E01A6D	0539 228457	MIKHAIL MATVEEV	{"email": "mikhail.matveev_27061982@postgrespro.ru", "phone": "+70570088329"}
0005435426569	48E9AD	3241 551454	YURIY SHEVCHENKO	{"email": "shevchenko_yuriy_081971@postgrespro.ru", "phone": "+70669781519"}
0005435426570	631C62	8199 108654	ANDREY IVANOV	{"email": "ivanov-a_10011969@postgrespro.ru", "phone": "+70219909332"}
0005435426571	B5B27D	4781 433017	MILANA BORISOVA	{"email": "milanaborisova-1963@postgrespro.ru", "phone": "+70915704147"}
0005435426572	39CBD1	8972 601048	MARYAM ROMANOVA	{"phone": "+70516885881"}
0005435426573	39CBD1	5589 357960	OLEG MOISEEV	{"email": "moiseev.o-21031962@postgrespro.ru", "phone": "+70950183604"}
0005435426574	974415	4487 360052	RUSLAN YAKOVLEV	{"email": "yakovlev-r-13091962@postgrespro.ru", "phone": "+70665155617"}
0005435426575	974415	6759 024257	ALEKSANDRA TIKHONOVA	{"email": "a.tikhonova_04121975@postgrespro.ru", "phone": "+70753242155"}
0005435426576	974415	1894 741208	ALLA EGOROVA	{"email": "egorova.alla061984@postgrespro.ru", "phone": "+70715431347"}
0005435426577	A35953	2103 106474	MARINA MAKAROVA	{"email": "m_makarova-1972@postgrespro.ru", "phone": "+70430849550"}
0005435426578	26801D	5747 869188	ANTON ZAKHAROV	{"phone": "+70183516982"}
0005435426579	6005F6	5712 726622	NATALYA LUKYANOVA	{"email": "natalya_lukyanova1977@postgrespro.ru", "phone": "+70646560451"}
0005435426580	51D503	8724 553684	MIKHAIL MOROZOV	{"phone": "+70721047355"}
0005435426581	83441C	1926 839000	ASIYA OVCHINNIKOVA	{"email": "ovchinnikova.a-051974@postgrespro.ru", "phone": "+70531795855"}
0005435426582	83441C	1657 317415	EKATERINA KOZLOVA	{"phone": "+70714023525"}
0005435426583	2B323D	9531 175004	ALEKSEY YAKOVLEV	{"phone": "+70997937591"}
0005435426584	AE8019	5232 696450	VITALIY CHERNOV	{"phone": "+70208068064"}
0005435426585	8444AD	9264 385445	ANDREY IVANOV	{"phone": "+70635965238"}
0005435426586	AE1348	5285 687612	DMITRIY KAZAKOV	{"phone": "+70705617469"}
0005435426587	AE1348	0385 630235	VALERIY GRIGOREV	{"email": "valeriy-grigorev-061962@postgrespro.ru", "phone": "+70105852222"}
0005435426588	728832	7750 122483	ALEKSANDRA KAZAKOVA	{"email": "kazakova-a_041979@postgrespro.ru", "phone": "+70214534372"}
0005435426589	7394EE	3416 560438	VLADIMIR MOROZOV	{"email": "morozov-v11041969@postgrespro.ru", "phone": "+70277890487"}
0005435426590	DCC862	0088 064344	VASILIY PETROV	{"email": "petrov_vasiliy.27051969@postgrespro.ru", "phone": "+70000407822"}
0005435426591	DCC862	4021 323363	OLGA ALEKSEEVA	{"email": "o.alekseeva031975@postgrespro.ru", "phone": "+70981093402"}
0005435426592	491928	7973 747521	MIKHAIL NIKOLAEV	{"email": "mikhailnikolaev-04111971@postgrespro.ru", "phone": "+70734436353"}
0005435426593	AAFBBD	9739 150930	VLADIMIR DENISOV	{"phone": "+70546265596"}
0005435426594	FDE4CB	9282 313590	TALGAT CHERNOV	{"phone": "+70517458063"}
0005435426595	0B8C2C	0044 783965	GALINA OVCHINNIKOVA	{"phone": "+70994940616"}
0005435426596	54BA41	6118 150885	DMITRIY IVANOV	{"phone": "+70171763010"}
0005435426597	4F6469	0586 783298	GALINA MATVEEVA	{"phone": "+70851563618"}
0005435426598	810B42	3457 828790	DMITRIY VASILEV	{"email": "vasilev.d_041971@postgrespro.ru", "phone": "+70826228217"}
0005435426599	052747	3453 104508	EVGENIYA NIKIFOROVA	{"email": "e_nikiforova-27041980@postgrespro.ru", "phone": "+70730681163"}
0005435426600	015271	5171 159902	DANILA PETROV	{"phone": "+70819092728"}
0005435426601	4391FD	7323 969664	ANNA ZAKHAROVA	{"email": "zakharovaanna.101966@postgrespro.ru", "phone": "+70560900199"}
0005435426602	4391FD	7614 473046	ALEKSANDR SOKOLOV	{"phone": "+70512531931"}
0005435426603	E0FC7E	5788 317948	ELIZAVETA ILINA	{"email": "ilinaelizaveta08041984@postgrespro.ru", "phone": "+70980969243"}
0005435426604	805D62	8197 130095	IGOR MOISEEV	{"email": "moiseev.igor041964@postgrespro.ru", "phone": "+70363785120"}
0005435426605	805D62	9993 426897	ALINA PETROVA	{"email": "alina.petrova.1964@postgrespro.ru", "phone": "+70841213876"}
0005435426606	788139	9938 794825	ALEKSEY FEDOROV	{"phone": "+70970872213"}
0005435426607	83AC45	9102 372839	SERGEY MATVEEV	{"phone": "+70977297007"}
0005435426608	33E866	4971 746512	SERGEY STEPANOV	{"email": "sergey_stepanov_1983@postgrespro.ru", "phone": "+70424226366"}
0005435426609	469142	3092 804727	DMITRIY GERASIMOV	{"email": "dmitriy.gerasimov-051982@postgrespro.ru", "phone": "+70949253269"}
0005435426610	469142	4475 515192	LYUBOV ERMAKOVA	{"phone": "+70017751613"}
0005435426611	7AE89A	8560 810353	VIKTORIYA ILINA	{"email": "ilina_viktoriya.081971@postgrespro.ru", "phone": "+70088479324"}
0005435426612	7162BB	4705 858089	IRINA ALEKSANDROVA	{"email": "i-aleksandrova_1955@postgrespro.ru", "phone": "+70480323440"}
0005435426613	1B0804	1803 712669	VALERIYA ABRAMOVA	{"phone": "+70851979388"}
0005435426614	1B0804	9150 253649	MARINA RODIONOVA	{"email": "marina-rodionova.041967@postgrespro.ru", "phone": "+70996653711"}
0005435426615	9E2D31	8003 255834	PAVEL FEDOROV	{"phone": "+70544777604"}
0005435426616	944771	1611 243755	ANNA KOLESNIKOVA	{"email": "anna-kolesnikova021983@postgrespro.ru", "phone": "+70577777808"}
0005435426617	53550B	8090 260888	NINA YAKOVLEVA	{"email": "yakovleva.nina111977@postgrespro.ru", "phone": "+70576164329"}
0005435426618	53550B	0034 413036	OLESYA KARPOVA	{"email": "olesyakarpova_1974@postgrespro.ru", "phone": "+70256898042"}
0005435426619	E76DFE	3749 655949	GALIYA ANDREEVA	{"phone": "+70846084744"}
0005435426620	E76DFE	0067 819962	NIKOLAY KULIKOV	{"phone": "+70735052811"}
0005435426621	E76DFE	3127 570534	OKSANA DAVYDOVA	{"phone": "+70249320189"}
0005435426622	C63D51	9518 706771	DMITRIY TIKHONOV	{"email": "tikhonov_dmitriy.1971@postgrespro.ru", "phone": "+70334521100"}
0005435426623	588554	2917 914490	EGOR SCHERBAKOV	{"phone": "+70986045597"}
0005435426624	EC494E	4665 794748	VLADIMIR SIDOROV	{"email": "v-sidorov.101965@postgrespro.ru", "phone": "+70082541670"}
0005435426625	BDEECB	1777 321201	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov.021967@postgrespro.ru", "phone": "+70263236558"}
0005435426626	165FB8	8150 870179	DMITRIY SOLOVEV	{"email": "d_solovev09041976@postgrespro.ru", "phone": "+70319156565"}
0005435426627	92D43A	9389 360351	ALEKSANDR ILIN	{"email": "aleksandrilin.1961@postgrespro.ru", "phone": "+70137261646"}
0005435426628	92D43A	7657 028339	TATYANA PAVLOVA	{"phone": "+70212881900"}
0005435426629	A5BB0D	9794 434868	ELIZAVETA IVANOVA	{"email": "ivanovaelizaveta.061976@postgrespro.ru", "phone": "+70609380632"}
0005435426630	A5BB0D	9416 793127	MAKSIM VOLKOV	{"phone": "+70623766396"}
0005435426631	A46949	2740 887816	ANDREY TIMOFEEV	{"phone": "+70790213405"}
0005435426632	E6DEE2	4985 621363	LARISA POPOVA	{"email": "popova.larisa.061981@postgrespro.ru", "phone": "+70015335587"}
0005435426633	6B586F	5539 375912	YANA DENISOVA	{"phone": "+70738895874"}
0005435426634	888D17	5493 793045	OLGA MASLOVA	{"email": "o-maslova_09111957@postgrespro.ru", "phone": "+70661114176"}
0005435426635	95973C	2919 481884	TAISIYA BELOVA	{"phone": "+70092438659"}
0005435426636	46D635	7679 146939	YULIYA SOROKINA	{"email": "sorokina_yuliya-30111973@postgrespro.ru", "phone": "+70679822052"}
0005435426637	46D635	2279 918539	ELIZAVETA EGOROVA	{"phone": "+70838200239"}
0005435426638	46D635	7141 724526	VARVARA MIRONOVA	{"phone": "+70498969850"}
0005435426639	A8BBB8	3585 074046	VERONIKA SIDOROVA	{"phone": "+70119059261"}
0005435426640	31318D	1225 266677	ALEKSANDR GERASIMOV	{"email": "a-gerasimov_07091971@postgrespro.ru", "phone": "+70351847831"}
0005435426641	31318D	5855 637102	RAVIL MELNIKOV	{"email": "melnikov.ravil-14081974@postgrespro.ru", "phone": "+70735889503"}
0005435426642	31318D	1939 146742	EKATERINA POPOVA	{"phone": "+70196027699"}
0005435426643	10D655	2543 364786	ANNA MASLOVA	{"phone": "+70711599899"}
0005435426644	514693	6536 643372	VYACHESLAV ANDREEV	{"email": "andreevvyacheslav.021977@postgrespro.ru", "phone": "+70739673111"}
0005435426645	F35A09	8226 277040	VALENTINA ORLOVA	{"phone": "+70211080048"}
0005435426646	F35A09	7052 528755	TAMARA IVANOVA	{"email": "ivanova.tamara.081980@postgrespro.ru", "phone": "+70560131304"}
0005435426647	6B76C8	4108 568470	BULAT SMIRNOV	{"phone": "+70260753164"}
0005435426648	6B76C8	5553 355313	OLEG DAVYDOV	{"email": "davydov-oleg-02031981@postgrespro.ru", "phone": "+70105223108"}
0005435426649	CAF2E0	5148 645070	SERGEY VASILEV	{"email": "svasilev-1988@postgrespro.ru", "phone": "+70069528297"}
0005435426650	3B95D3	3285 277152	TATYANA SEMENOVA	{"email": "semenova_tatyana1985@postgrespro.ru", "phone": "+70367779839"}
0005435426651	3B95D3	6848 315421	SERGEY SOROKIN	{"email": "sorokin_sergey.1975@postgrespro.ru", "phone": "+70408508588"}
0005435426652	A8FBA0	6030 053106	KIRILL ZAKHAROV	{"email": "kirill_zakharov.101975@postgrespro.ru", "phone": "+70724931575"}
0005435426653	281B12	9424 918592	ALEKSANDR ORLOV	{"phone": "+70233429141"}
0005435426654	E89209	4452 051158	VARVARA SOROKINA	{"email": "vsorokina_26091965@postgrespro.ru", "phone": "+70131853116"}
0005435426655	893ECD	5475 924534	ANGELINA FOMINA	{"phone": "+70192612304"}
0005435426656	5FB9A0	2765 661773	ANDREY ALEKSANDROV	{"email": "aleksandrovandrey041971@postgrespro.ru", "phone": "+70204149662"}
0005435426657	5FB9A0	5307 888308	VLADIMIR BELOV	{"phone": "+70443687565"}
0005435426658	5FB9A0	1614 454435	IVAN KUDRYASHOV	{"email": "i-kudryashov_1976@postgrespro.ru", "phone": "+70900595169"}
0005435426659	7DE09E	2923 574491	EVGENIYA BORISOVA	{"email": "borisova-e_1970@postgrespro.ru", "phone": "+70951625344"}
0005435426660	5B3252	3919 487926	GALINA TIMOFEEVA	{"email": "timofeevagalina.21121969@postgrespro.ru", "phone": "+70822779226"}
0005435426661	D26097	0441 474002	GENNADIY GORBUNOV	{"phone": "+70451614512"}
0005435426662	C56284	3654 082313	EKATERINA KONOVALOVA	{"email": "konovalova-e-20061984@postgrespro.ru", "phone": "+70700625060"}
0005435426663	83D4C7	1100 007018	ELIZAVETA POTAPOVA	{"phone": "+70122230241"}
0005435426664	83D4C7	3173 317869	MIKHAIL KUZNECOV	{"phone": "+70077732225"}
0005435426665	977185	0192 997526	ZHANNA ZOTOVA	{"phone": "+70025752620"}
0005435426666	75E5B2	7056 525644	GALINA DAVYDOVA	{"email": "davydova-g.1974@postgrespro.ru", "phone": "+70417556407"}
0005435426667	BC58C8	1564 724008	NINA KOVALEVA	{"email": "kovaleva_nina-03021966@postgrespro.ru", "phone": "+70401626224"}
0005435426668	B97506	0838 238831	MARIYA AFANASEVA	{"phone": "+70539999123"}
0005435426669	3F511B	9284 968209	ALEVTINA POLYAKOVA	{"phone": "+70822227354"}
0005435426670	182C00	8395 870155	GENNADIY ORLOV	{"phone": "+70074800886"}
0005435426671	D3D9F3	7347 878125	GALINA MOROZOVA	{"email": "morozovag03101967@postgrespro.ru", "phone": "+70791651198"}
0005435426672	696C71	8753 567463	OLGA TARASOVA	{"email": "tarasova-olga_121983@postgrespro.ru", "phone": "+70718863564"}
0005435426673	5E303B	4843 592626	ANASTASIYA SOKOLOVA	{"phone": "+70181336940"}
0005435426674	5E303B	1020 146136	FATIMA ISAEVA	{"email": "isaeva.fatima.101974@postgrespro.ru", "phone": "+70640172306"}
0005435426675	5E303B	0429 129550	ANNA KRASNOVA	{"phone": "+70929988637"}
0005435426676	245AC9	8759 739811	VLADIMIR MEDVEDEV	{"email": "vmedvedev_031965@postgrespro.ru", "phone": "+70759374657"}
0005435426677	75573D	7067 570147	EVGENIYA KOZLOVA	{"email": "evgeniyakozlova1974@postgrespro.ru", "phone": "+70578419657"}
0005435426678	75573D	4174 426472	ANTON POPOV	{"phone": "+70672720168"}
0005435426679	0F88BA	7805 680436	ALEKSEY KARPOV	{"email": "karpov.a-011964@postgrespro.ru", "phone": "+70115459199"}
0005435426680	50177E	8554 565634	TIMUR KUZMIN	{"email": "tkuzmin.22101970@postgrespro.ru", "phone": "+70657753566"}
0005435426681	9B5B22	7216 062662	NATALYA NESTEROVA	{"email": "nesterova-n-1973@postgrespro.ru", "phone": "+70288980724"}
0005435426682	FE4DBD	7368 512621	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov.1968@postgrespro.ru", "phone": "+70656382823"}
0005435426683	B263BA	9946 970128	LIDIYA AKIMOVA	{"phone": "+70245981782"}
0005435426684	0A7488	6482 568875	NATALYA MOROZOVA	{"phone": "+70602000100"}
0005435426685	3EBF51	3787 217273	MAKSIM ANDREEV	{"phone": "+70035317322"}
0005435426686	593395	2392 991771	RUSTAM STEPANOV	{"email": "stepanov-rustam.111969@postgrespro.ru", "phone": "+70993008027"}
0005435426687	C897A2	6397 556186	VLADIMIR ANTONOV	{"email": "antonovv1981@postgrespro.ru", "phone": "+70723916839"}
0005435426688	E8A570	0899 009087	VALENTINA KOZLOVA	{"email": "kozlova.v_1980@postgrespro.ru", "phone": "+70767593656"}
0005435426689	FF51E4	0619 047871	ILYA SMIRNOV	{"phone": "+70409296154"}
0005435426690	FF51E4	9202 004625	ALBINA NESTEROVA	{"email": "anesterova.071978@postgrespro.ru", "phone": "+70879317939"}
0005435426691	C4B87A	8029 836878	VIKTOR POPOV	{"phone": "+70841785130"}
0005435426692	550424	7191 865890	ANNA ORLOVA	{"email": "orlova_a.061970@postgrespro.ru", "phone": "+70793352027"}
0005435426693	550424	4917 997119	YURIY FILIPPOV	{"email": "filippov_yuriy111962@postgrespro.ru", "phone": "+70306890729"}
0005435426694	203008	5527 933490	GEORGIY AFANASEV	{"phone": "+70218679981"}
0005435426695	0D0506	8108 522563	GENNADIY ILIN	{"phone": "+70197429713"}
0005435426696	0D0506	6300 560408	SVETLANA GORBUNOVA	{"email": "s_gorbunova27011977@postgrespro.ru", "phone": "+70880977903"}
0005435426697	63ED05	3362 124598	EVGENIY SOLOVEV	{"phone": "+70460161418"}
0005435426698	1B78F0	8525 073064	YURIY VASILEV	{"email": "y_vasilev_06121977@postgrespro.ru", "phone": "+70029733258"}
0005435426699	1B78F0	8291 325134	ANDREY NIKOLAEV	{"phone": "+70693900897"}
0005435426700	154610	9218 267807	MARINA MALYSHEVA	{"phone": "+70193158860"}
0005435426701	2CE83D	0605 437150	IVAN KULIKOV	{"email": "kulikov_i-1970@postgrespro.ru", "phone": "+70740079876"}
0005435426702	213ED3	1782 769038	NINA ZAKHAROVA	{"email": "zakharova_nina-23081980@postgrespro.ru", "phone": "+70696264089"}
0005435426703	788B5D	9972 431594	MAKSIM GRIGOREV	{"email": "grigorev.maksim15041970@postgrespro.ru", "phone": "+70102489366"}
0005435426704	6D8871	1786 703675	ALEKSANDR SOKOLOV	{"email": "sokolov.a111974@postgrespro.ru", "phone": "+70614834877"}
0005435426705	6D8871	9402 673373	EVGENIYA KUZNECOVA	{"email": "evgeniya.kuznecova.20081969@postgrespro.ru", "phone": "+70658921250"}
0005435426706	68D1D4	2624 395242	LILIYA MARTYNOVA	{"phone": "+70441722149"}
0005435426707	68D1D4	9847 147486	OKSANA SEMENOVA	{"email": "semenovaoksana_29081967@postgrespro.ru", "phone": "+70183444832"}
0005435426708	446712	1261 616521	NATALYA TROFIMOVA	{"email": "n.trofimova02011969@postgrespro.ru", "phone": "+70420046295"}
0005435426709	222B6C	3752 596883	SVETLANA KARPOVA	{"phone": "+70596795182"}
0005435426710	222B6C	2776 538071	VERA ABRAMOVA	{"email": "abramova_vera.09031978@postgrespro.ru", "phone": "+70288818493"}
0005435426711	FE1C8B	5682 727923	TATYANA NAZAROVA	{"phone": "+70478891963"}
0005435426712	78E5AD	1919 312411	ELIZAVETA POPOVA	{"email": "e.popova_29081976@postgrespro.ru", "phone": "+70816342603"}
0005435426713	324935	1950 141567	RAISA MIRONOVA	{"email": "raisa-mironova1965@postgrespro.ru", "phone": "+70683390952"}
0005435426714	3EBE9C	8880 784650	ARTUR GAVRILOV	{"phone": "+70598895731"}
0005435426715	88CFD9	1964 025787	NIKOLAY ZHUKOV	{"email": "zhukovn.26061964@postgrespro.ru", "phone": "+70921465373"}
0005435426716	88CFD9	9688 477122	OKSANA MAKAROVA	{"phone": "+70800416215"}
0005435426717	A2258D	1644 998798	OLESYA PAVLOVA	{"email": "olesyapavlova.02081975@postgrespro.ru", "phone": "+70209350256"}
0005435426718	A2258D	6419 969592	VLADIMIR SOLOVEV	{"email": "solovev-vladimir.1973@postgrespro.ru", "phone": "+70507584310"}
0005435426719	6AE910	7654 342777	POLINA EGOROVA	{"email": "polina.egorova.1963@postgrespro.ru", "phone": "+70173505522"}
0005435426720	D5C904	6358 938479	ELENA VASILEVA	{"phone": "+70293932399"}
0005435426721	6A6DD7	6835 717590	IRINA KUZNECOVA	{"email": "kuznecova.irina_1975@postgrespro.ru", "phone": "+70398119561"}
0005435426722	6A6DD7	8216 207449	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr021970@postgrespro.ru", "phone": "+70951642125"}
0005435426723	56AF92	4417 556652	ALEKSANDR FROLOV	{"phone": "+70873408882"}
0005435426724	56AF92	9724 051960	ALEKSEY TIKHONOV	{"phone": "+70193710779"}
0005435426725	02D508	7163 966826	EKATERINA LEBEDEVA	{"email": "lebedeva_ekaterina.031972@postgrespro.ru", "phone": "+70521824577"}
0005435426726	F6B4FB	5684 075137	LYUDMILA ANTONOVA	{"phone": "+70129548061"}
0005435426727	F6B4FB	3250 815026	ELENA GAVRILOVA	{"phone": "+70345527026"}
0005435426728	3ADEFA	0783 217887	DARYA GERASIMOVA	{"phone": "+70734126710"}
0005435426729	6F409D	8378 488181	OLGA MAKAROVA	{"phone": "+70919827358"}
0005435426730	439295	8502 971347	LYUDMILA ORLOVA	{"email": "orlovalyudmila-1974@postgrespro.ru", "phone": "+70648857574"}
0005435426731	1B231A	3883 077956	ANASTASIYA MASLOVA	{"email": "maslova-anastasiya.1969@postgrespro.ru", "phone": "+70652202114"}
0005435426732	1B231A	0409 040297	MIKHAIL MEDVEDEV	{"email": "m.medvedev-101970@postgrespro.ru", "phone": "+70190951566"}
0005435426733	1B231A	7626 319662	VIKTOR ALEKSEEV	{"email": "v_alekseev_1968@postgrespro.ru", "phone": "+70931692155"}
0005435426734	DBC7A0	5765 509965	GALINA DAVYDOVA	{"phone": "+70468133326"}
0005435426735	368E79	1532 684407	GENNADIY TIMOFEEV	{"email": "gennadiytimofeev-1968@postgrespro.ru", "phone": "+70815563006"}
0005435426736	F6435B	2453 540764	ALEKSEY KISELEV	{"phone": "+70224614724"}
0005435426737	DBA681	7714 531997	VYACHESLAV SIDOROV	{"phone": "+70759465252"}
0005435426738	17DC40	6439 029401	ALEKSANDR FEDOTOV	{"phone": "+70796518374"}
0005435426739	792430	7074 871456	MARGARITA RODIONOVA	{"email": "mrodionova-14031974@postgrespro.ru", "phone": "+70623326457"}
0005435426740	FFF329	3178 734378	VLADISLAV IVANOV	{"email": "ivanov_v_051975@postgrespro.ru", "phone": "+70019773175"}
0005435426741	FFF329	0079 023230	MARGARITA NIKITINA	{"email": "m_nikitina.1973@postgrespro.ru", "phone": "+70317347396"}
0005435426742	6B811E	3194 239628	ALEKSANDR TIKHONOV	{"email": "tikhonov_a1977@postgrespro.ru", "phone": "+70929675691"}
0005435426743	DAAA82	3770 828906	OLGA MIKHAYLOVA	{"phone": "+70821670236"}
0005435426744	CF5478	3809 215893	GALINA FILIPPOVA	{"email": "filippova.galina-101961@postgrespro.ru", "phone": "+70249847199"}
0005435426745	CD7F46	7489 944677	ALEKSANDR KUZNECOV	{"phone": "+70775712419"}
0005435426746	28BFAC	6520 413175	PAVEL SHEVCHENKO	{"email": "pavelshevchenko_041970@postgrespro.ru", "phone": "+70117630588"}
0005435426747	976B7A	1014 866492	DENIS KULIKOV	{"email": "denis_kulikov31031972@postgrespro.ru", "phone": "+70946468995"}
0005435426748	E1B3D6	2208 203427	ANNA MELNIKOVA	{"email": "melnikovaa1974@postgrespro.ru", "phone": "+70816277167"}
0005435426749	69FF81	4610 933042	VALERIY SMIRNOV	{"email": "smirnov_valeriy081974@postgrespro.ru", "phone": "+70345193786"}
0005435426750	D003C6	8855 785247	LYUBOV NIKITINA	{"phone": "+70665680150"}
0005435426751	4DE513	2226 093383	ALEKSANDR SERGEEV	{"phone": "+70397295241"}
0005435426752	1408B8	6451 548629	OKSANA NESTEROVA	{"email": "oksana-nesterova_1985@postgrespro.ru", "phone": "+70028776023"}
0005435426753	B1DCFD	7983 624219	DARYA VASILEVA	{"email": "dvasileva_1962@postgrespro.ru", "phone": "+70058065918"}
0005435426754	B1DCFD	3644 947210	ZOYA MIRONOVA	{"phone": "+70301289747"}
0005435426755	D13594	8699 604740	VIKTOR FEDOROV	{"email": "vfedorov.1978@postgrespro.ru", "phone": "+70735524295"}
0005435426756	28B8B6	0021 298225	SERGEY POPOV	{"email": "s_popov_1969@postgrespro.ru", "phone": "+70819488291"}
0005435426757	D21523	1405 227890	IGOR MIKHAYLOV	{"email": "imikhaylov1977@postgrespro.ru", "phone": "+70350566567"}
0005435426758	D21523	8365 853161	ANDREY PETROV	{"email": "a-petrov-25061973@postgrespro.ru", "phone": "+70853672529"}
0005435426759	D21523	2458 044580	MARIYA FOMINA	{"email": "mariyafomina121968@postgrespro.ru", "phone": "+70983418356"}
0005435426760	172C78	4751 458488	DMITRIY FOMIN	{"phone": "+70669566063"}
0005435426761	C3E03E	3717 187781	NIKOLAY KOZLOV	{"phone": "+70840009359"}
0005435426762	B976FE	6785 265478	EVDOKIYA KAZAKOVA	{"email": "e_kazakova.1975@postgrespro.ru", "phone": "+70436612978"}
0005435426763	3E5B4D	5482 172429	EVGENIYA VASILEVA	{"email": "vasileva-e-22011982@postgrespro.ru", "phone": "+70399194117"}
0005435426764	EF8F2C	2827 383504	OLGA NOVIKOVA	{"phone": "+70702847009"}
0005435426765	A1F221	5811 180161	NATALIYA KUDRYASHOVA	{"email": "kudryashova_n.011985@postgrespro.ru", "phone": "+70103692251"}
0005435426766	A1F221	6308 841576	RAISA OVCHINNIKOVA	{"email": "rovchinnikova-17101968@postgrespro.ru", "phone": "+70545816922"}
0005435426767	EDD47A	9712 810924	VALENTINA SOKOLOVA	{"phone": "+70228702427"}
0005435426768	EDD47A	7983 664408	EDGAR GAVRILOV	{"phone": "+70372433714"}
0005435426769	EFFEC7	6018 162444	EKATERINA RYABOVA	{"phone": "+70447566187"}
0005435426770	CCB562	0575 307277	DMITRIY FOMIN	{"email": "dfomin.14111973@postgrespro.ru", "phone": "+70338560588"}
0005435426771	383E42	9843 537651	TATYANA VOLKOVA	{"email": "t.volkova-1971@postgrespro.ru", "phone": "+70518506060"}
0005435426772	383E42	6557 820030	KIRILL EGOROV	{"email": "kirill_egorov-121978@postgrespro.ru", "phone": "+70764731960"}
0005435426773	CF9F0D	2545 522423	EVGENIY OSIPOV	{"email": "e.osipov_031981@postgrespro.ru", "phone": "+70530497836"}
0005435426774	CF9F0D	7345 832234	VERA ALEKSANDROVA	{"phone": "+70170601727"}
0005435426775	0618D9	8294 237050	VADIM OSIPOV	{"email": "vadim-osipov1969@postgrespro.ru", "phone": "+70465814632"}
0005435426776	0618D9	9423 440104	IGOR PAVLOV	{"email": "i-pavlov-111967@postgrespro.ru", "phone": "+70060467188"}
0005435426777	CA7722	1645 836034	STANISLAV ROMANOV	{"phone": "+70005625204"}
0005435426778	CA7722	6547 731930	MIKHAIL NOVIKOV	{"email": "novikov.mikhail101982@postgrespro.ru", "phone": "+70871911239"}
0005435426779	74CEF8	0105 904549	IGOR NOVIKOV	{"email": "i_novikov.1982@postgrespro.ru", "phone": "+70305958247"}
0005435426780	D932A0	6676 028811	DMITRIY CHERNOV	{"email": "dmitriychernov.021968@postgrespro.ru", "phone": "+70374978952"}
0005435426781	CB1234	2285 498432	DANIIL KULIKOV	{"email": "d.kulikov071971@postgrespro.ru", "phone": "+70246980384"}
0005435426782	40D286	6969 927640	DMITRIY SAVELEV	{"phone": "+70908191380"}
0005435426783	40D286	7128 736330	ALENA GERASIMOVA	{"email": "alena-gerasimova_1971@postgrespro.ru", "phone": "+70172446509"}
0005435426784	68317B	1930 878987	TATYANA ERMAKOVA	{"email": "ermakova_tatyana071981@postgrespro.ru", "phone": "+70209637796"}
0005435426785	85B20B	0948 909981	ILYA VASILEV	{"email": "vasilev.ilya_1965@postgrespro.ru", "phone": "+70193768255"}
0005435426786	4A96C6	9533 653297	GALINA IVANOVA	{"phone": "+70468158000"}
0005435426787	70FF8A	8259 082897	TATYANA FILATOVA	{"phone": "+70189556405"}
0005435426788	FA1860	1302 741000	VLADIMIR FOMIN	{"phone": "+70642150015"}
0005435426789	3891B1	7449 643362	VLADIMIR KUZNECOV	{"phone": "+70682230723"}
0005435426790	CCF893	1247 870334	ALEKSANDR ISAEV	{"email": "a-isaev_031966@postgrespro.ru", "phone": "+70041018798"}
0005435426791	95ED67	5153 939041	VLADIMIR SAVELEV	{"email": "vsavelev081978@postgrespro.ru", "phone": "+70231143862"}
0005435426792	89543C	3073 205834	VERA PAVLOVA	{"email": "vera-pavlova_23041983@postgrespro.ru", "phone": "+70679514600"}
0005435426793	E22A70	2813 754025	OLGA SERGEEVA	{"phone": "+70288050432"}
0005435426794	0AAB1B	1972 803101	YURIY MEDVEDEV	{"email": "medvedev_yuriy-081972@postgrespro.ru", "phone": "+70443053375"}
0005435426795	74E819	3419 522738	KRISTINA VASILEVA	{"phone": "+70518690413"}
0005435426796	74E819	5755 109074	NIKITA RODIONOV	{"phone": "+70958402722"}
0005435426797	E9134D	7133 249344	EKATERINA KOROLEVA	{"phone": "+70560362471"}
0005435426798	E9134D	4089 033620	NINA MAKAROVA	{"email": "makarovan021976@postgrespro.ru", "phone": "+70337947476"}
0005435426799	CFCDFC	1418 217191	TATYANA ZOTOVA	{"email": "t.zotova.1982@postgrespro.ru", "phone": "+70505240329"}
0005435426800	CFCDFC	8411 892021	NADEZHDA GERASIMOVA	{"phone": "+70826611363"}
0005435426801	ABD4D6	4233 160692	NATALIYA SEMENOVA	{"email": "nsemenova-051974@postgrespro.ru", "phone": "+70010236648"}
0005435426802	2E3D6A	3456 955091	IVAN KARPOV	{"email": "ivan_karpov.061976@postgrespro.ru", "phone": "+70914629189"}
0005435426803	985D05	2523 956960	ROMAN GRIGOREV	{"phone": "+70531927722"}
0005435426804	58D135	2957 572399	VALENTINA GRISHINA	{"phone": "+70890154422"}
0005435426805	6174DF	2266 381708	ALEKSEY NAZAROV	{"email": "aleksey.nazarov081970@postgrespro.ru", "phone": "+70813663904"}
0005435426806	989948	3809 767747	VALERIYA MIKHAYLOVA	{"phone": "+70611337025"}
0005435426807	989948	1492 538734	SERGEY DENISOV	{"email": "sergey_denisov-08071990@postgrespro.ru", "phone": "+70097448198"}
0005435426808	989948	8718 594178	ELENA FILIPPOVA	{"phone": "+70466611536"}
0005435426809	7C04D8	0364 549753	ALEKSANDR IVANOV	{"email": "a.ivanov-25061964@postgrespro.ru", "phone": "+70942924930"}
0005435426810	E8187F	8118 916321	VALERIY SOROKIN	{"phone": "+70617034602"}
0005435426811	513867	1847 950965	POLINA IVANOVA	{"email": "ivanova-polina02021973@postgrespro.ru", "phone": "+70046602521"}
0005435426812	056F7F	4178 220935	OLGA MEDVEDEVA	{"email": "omedvedeva031973@postgrespro.ru", "phone": "+70272913358"}
0005435426813	F45934	8167 302407	LARISA GRISHINA	{"phone": "+70112750976"}
0005435426814	4C9450	3181 654837	ANTONINA SERGEEVA	{"email": "sergeeva.antonina.081967@postgrespro.ru", "phone": "+70562025094"}
0005435426815	0A5759	6953 874759	ANATOLIY KUZMIN	{"email": "a-kuzmin.01091973@postgrespro.ru", "phone": "+70733562335"}
0005435426816	BBCA1B	4660 727163	GENNADIY ABRAMOV	{"phone": "+70407787854"}
0005435426817	7F258C	2931 493248	ELENA SAVELEVA	{"email": "elena_saveleva.1963@postgrespro.ru", "phone": "+70508925246"}
0005435426818	7F258C	3959 497811	YULIYA NESTEROVA	{"email": "nesterova-y_1973@postgrespro.ru", "phone": "+70231468290"}
0005435426819	831147	9714 535888	TATYANA OSIPOVA	{"phone": "+70252522451"}
0005435426820	F7B2CB	4851 618469	VYACHESLAV DMITRIEV	{"email": "vyacheslav-dmitriev-23121978@postgrespro.ru", "phone": "+70424034304"}
0005435426821	F7B2CB	8164 169688	NATALYA ZAKHAROVA	{"phone": "+70803925241"}
0005435426822	F7B2CB	1335 734813	VASILIY IVANOV	{"phone": "+70834674555"}
0005435426823	B51ED2	6318 914758	MATRENA VOLKOVA	{"phone": "+70976812542"}
0005435426824	F1458B	2702 937995	OLGA ANISIMOVA	{"email": "anisimova-o_1973@postgrespro.ru", "phone": "+70586477929"}
0005435426825	C391D6	3370 049526	NINA AFANASEVA	{"email": "afanaseva_n021972@postgrespro.ru", "phone": "+70276266922"}
0005435426826	9EF13B	2268 331280	EGOR ROMANOV	{"phone": "+70067071235"}
0005435426827	DEDC18	4876 671639	YULIYA ROMANOVA	{"email": "yuliyaromanova_1971@postgrespro.ru", "phone": "+70560534833"}
0005435426828	DEDC18	6779 296939	ARTEM KUZNECOV	{"phone": "+70331697497"}
0005435426829	F1A582	7188 829632	YURIY KUZMIN	{"phone": "+70646531489"}
0005435426830	04147A	0052 717036	ELENA ARKHIPOVA	{"email": "arkhipova.e19061971@postgrespro.ru", "phone": "+70587097470"}
0005435426831	56F875	3741 350317	ALENA MAKAROVA	{"phone": "+70661467142"}
0005435426832	501B0E	7296 087783	ILMIRA LUKYANOVA	{"email": "lukyanovai_1966@postgrespro.ru", "phone": "+70370737095"}
0005435426833	501B0E	5894 449637	VLADIMIR DENISOV	{"email": "denisov.v.15101977@postgrespro.ru", "phone": "+70550548050"}
0005435426834	536035	0269 383488	NATALYA EFIMOVA	{"email": "efimova-natalya27121966@postgrespro.ru", "phone": "+70302280063"}
0005435426835	E6B42A	9939 607969	NIKOLAY MELNIKOV	{"phone": "+70757174326"}
0005435426836	0AED62	8304 578116	MIKHAIL ZAYCEV	{"email": "mikhail-zaycev-011974@postgrespro.ru", "phone": "+70355419759"}
0005435426837	0AED62	8097 744319	ALEKSANDR KOROLEV	{"email": "korolevaleksandr1985@postgrespro.ru", "phone": "+70279071985"}
0005435426838	C5BC14	8508 523485	LYUBOV MATVEEVA	{"email": "l.matveeva-26091960@postgrespro.ru", "phone": "+70697081442"}
0005435426839	390C58	3586 271617	ELENA ILINA	{"phone": "+70462061499"}
0005435426840	8A403D	4419 335416	LYUDMILA FADEEVA	{"phone": "+70027359010"}
0005435426841	54105B	5925 769996	MIKHAIL NIKITIN	{"email": "nikitinm011970@postgrespro.ru", "phone": "+70684214638"}
0005435426842	54105B	1486 281383	DMITRIY ROMANOV	{"email": "dmitriyromanov-1972@postgrespro.ru", "phone": "+70197843695"}
0005435426843	066DFE	7258 539037	TATYANA KUZNECOVA	{"phone": "+70735311846"}
0005435426844	36DEEB	1154 905141	MARINA DANILOVA	{"phone": "+70001413818"}
0005435426845	36DEEB	1073 488647	SERGEY TARASOV	{"phone": "+70347318360"}
0005435426846	960C45	5609 892103	VASILIY FEDOTOV	{"phone": "+70299929407"}
0005435426847	6F9575	9220 015046	ELVIRA TITOVA	{"phone": "+70261743017"}
0005435426848	6F9575	4967 198680	MIKHAIL SIDOROV	{"email": "m.sidorov.1975@postgrespro.ru", "phone": "+70374974483"}
0005435426849	F5FA35	2668 173106	OLGA MOISEEVA	{"phone": "+70159875800"}
0005435426850	241B80	5284 705878	LIDIYA POLYAKOVA	{"phone": "+70810344327"}
0005435426851	241B80	2405 868635	EVGENIY GUSEV	{"email": "guseve_031964@postgrespro.ru", "phone": "+70793283988"}
0005435426852	B7AC50	0563 312211	ALEKSANDR IVANOV	{"phone": "+70044239962"}
0005435426853	B7AC50	9184 243115	ALEKSEY ZAKHAROV	{"phone": "+70257488586"}
0005435426854	B7AC50	8419 263802	MIKHAIL POPOV	{"email": "mikhailpopov-091977@postgrespro.ru", "phone": "+70759311975"}
0005435426855	D1F693	9095 897253	LYUBOV VOLKOVA	{"phone": "+70125447491"}
0005435426856	D1F693	4353 906366	NIKOLAY DMITRIEV	{"email": "dmitrievnikolay1963@postgrespro.ru", "phone": "+70288636719"}
0005435426857	96B468	7166 254835	PETR GAVRILOV	{"email": "petr-gavrilov_051980@postgrespro.ru", "phone": "+70864624114"}
0005435426858	1BD071	6778 267992	GALINA NIKOLAEVA	{"phone": "+70839112346"}
0005435426859	2396E5	1675 860510	ANATOLIY MARTYNOV	{"email": "martynov.anatoliy041964@postgrespro.ru", "phone": "+70613119032"}
0005435426860	5D6278	0850 445520	SOFYA DMITRIEVA	{"email": "sofya-dmitrieva-1965@postgrespro.ru", "phone": "+70635244537"}
0005435437555	E9D62D	4989 214232	SARIYA ARKHIPOVA	{"phone": "+70250458698"}
0005435437551	DE4B84	3181 716539	ELENA FOMINA	{"phone": "+70594194197"}
0005435437552	42BE12	2288 001946	YURIY KISELEV	{"email": "y.kiselev.27031970@postgrespro.ru", "phone": "+70789013763"}
0005435437553	DC6345	7271 221714	YAKOV ZAKHAROV	{"email": "zakharov_yakov04051971@postgrespro.ru", "phone": "+70885289938"}
0005435437554	2795F9	1941 188358	SERGEY MAKSIMOV	{"phone": "+70956477023"}
0005435437556	E9D62D	1307 943910	STEPAN KULIKOV	{"email": "stepan_kulikov_1971@postgrespro.ru", "phone": "+70061198690"}
0005435437557	E9D62D	9394 216820	NATALYA SIDOROVA	{"email": "sidorovanatalya12021971@postgrespro.ru", "phone": "+70961253299"}
0005435437558	307754	8627 506287	BORIS POPOV	{"email": "popov-boris_1976@postgrespro.ru", "phone": "+70002301437"}
0005435437559	4BAB95	8441 517803	LARISA NOVIKOVA	{"email": "novikovalarisa-081965@postgrespro.ru", "phone": "+70391647339"}
0005435437560	41403D	1211 576497	VALERIY PETROV	{"phone": "+70713828156"}
0005435437561	9D719D	2079 879889	VLADISLAV IVANOV	{"email": "v.ivanov.021979@postgrespro.ru", "phone": "+70254379391"}
0005435437562	B3A421	0737 733824	TATYANA ROMANOVA	{"email": "tatyanaromanova-1965@postgrespro.ru", "phone": "+70847729828"}
0005435437563	B3A421	6784 372844	ELENA SOLOVEVA	{"email": "soloveva-e22011968@postgrespro.ru", "phone": "+70161577311"}
0005435437564	58583E	6404 255408	OLGA VASILEVA	{"email": "vasileva.olga.1970@postgrespro.ru", "phone": "+70186987206"}
0005435437565	A6BE6E	5661 043896	MARINA TIKHONOVA	{"email": "marina-tikhonova031978@postgrespro.ru", "phone": "+70365027921"}
0005435437566	B719BA	7248 800081	YULIYA ERMAKOVA	{"email": "ermakova.yuliya_111973@postgrespro.ru", "phone": "+70155722981"}
0005435437567	18D299	4413 595802	ALEKSEY KUZNECOV	{"phone": "+70020877214"}
0005435437568	430FE9	7352 376685	ALEKSANDR SERGEEV	{"email": "sergeev-aleksandr_21081966@postgrespro.ru", "phone": "+70088428978"}
0005435437569	BC8B43	6890 002648	ELIZAVETA BELYAEVA	{"phone": "+70387705431"}
0005435437570	0CD737	8276 394119	ARTUR FROLOV	{"phone": "+70713860853"}
0005435437571	B9801D	3916 206586	KLAVDIYA PAVLOVA	{"email": "k.pavlova.1966@postgrespro.ru", "phone": "+70408893621"}
0005435437572	FBC3C5	4081 857239	VLADIMIR DAVYDOV	{"email": "vdavydov.24091971@postgrespro.ru", "phone": "+70274241111"}
0005435437573	E2CE06	2740 689278	YULIYA VOROBEVA	{"email": "vorobevay081969@postgrespro.ru", "phone": "+70297715363"}
0005435437574	E2CE06	7494 489668	ANTON PETROV	{"phone": "+70995663339"}
0005435437575	6B8BD7	9432 107719	TAMARA CHERNOVA	{"email": "chernova_tamara_1966@postgrespro.ru", "phone": "+70727245535"}
0005435437576	D16039	4782 850475	NINA GAVRILOVA	{"email": "n.gavrilova.30061987@postgrespro.ru", "phone": "+70950481589"}
0005435437577	3C9463	1338 326091	ALEKSANDR ANTONOV	{"phone": "+70949477927"}
0005435437578	3C9463	5329 645894	OLEG SCHERBAKOV	{"phone": "+70326807135"}
0005435437579	372310	8159 008122	GALINA BOGDANOVA	{"email": "g_bogdanova.1962@postgrespro.ru", "phone": "+70081601194"}
0005435437580	EDE222	2566 451178	VALENTINA POPOVA	{"email": "popova.v.031974@postgrespro.ru", "phone": "+70395298465"}
0005435437581	EBE01B	5400 372490	LYUBOV ALEKSEEVA	{"email": "lyubov_alekseeva.16031973@postgrespro.ru", "phone": "+70164145491"}
0005435437582	7D85DE	8984 717309	ELENA ILINA	{"phone": "+70861790021"}
0005435437583	7D85DE	9901 249596	VLADIMIR FROLOV	{"email": "vladimir.frolov111966@postgrespro.ru", "phone": "+70639135920"}
0005435437584	657571	1962 613212	LYUDMILA ISAEVA	{"email": "lyudmila-isaeva_011981@postgrespro.ru", "phone": "+70168784845"}
0005435437585	657571	8562 471336	VIKTOR KUZNECOV	{"email": "viktor.kuznecov-1970@postgrespro.ru", "phone": "+70481599633"}
0005435437586	909D13	7643 974539	ANATOLIY PETROV	{"phone": "+70775735340"}
0005435437587	909D13	0254 935003	ALEKSANDR VASILEV	{"email": "vasileva31051966@postgrespro.ru", "phone": "+70096382294"}
0005435437588	445153	6305 364863	TATYANA DANILOVA	{"phone": "+70475024325"}
0005435437589	4D4900	5955 446358	YULIYA FEDOROVA	{"phone": "+70600892275"}
0005435437590	4778EB	2643 420736	YULIYA MAKSIMOVA	{"phone": "+70537119388"}
0005435437591	B7DCB7	6846 221760	ZINAIDA NESTEROVA	{"phone": "+70596406658"}
0005435437592	B7DCB7	2721 087809	VLADIMIR ZAKHAROV	{"phone": "+70903638707"}
0005435437593	B7DCB7	1587 143025	ROMAN ANDREEV	{"email": "r.andreev-021969@postgrespro.ru", "phone": "+70704482749"}
0005435437594	8C974E	3960 566806	TAMARA NESTEROVA	{"phone": "+70754125242"}
0005435437595	417E47	7652 132891	VIKTOR SERGEEV	{"email": "vsergeev-23081953@postgrespro.ru", "phone": "+70142379825"}
0005435437596	417E47	7402 916880	TATYANA NAZAROVA	{"email": "nazarova.tatyana.31011972@postgrespro.ru", "phone": "+70592441646"}
0005435437597	8CA966	2656 032195	NIKOLAY FEDOTOV	{"email": "fedotov.n_11081974@postgrespro.ru", "phone": "+70268024465"}
0005435437598	1C9C0F	1140 473161	OKSANA VASILEVA	{"email": "vasileva_o_081980@postgrespro.ru", "phone": "+70738313171"}
0005435437599	855B46	1484 527478	LYUBOV SAVELEVA	{"phone": "+70266227008"}
0005435437600	0F0246	6708 590325	OLGA VOLKOVA	{"phone": "+70386035495"}
0005435437601	0F0246	1851 837231	NIKOLAY EGOROV	{"phone": "+70422907904"}
0005435437602	258AD5	9093 119790	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr.111975@postgrespro.ru", "phone": "+70460417016"}
0005435437603	62CE4A	5929 358809	VALENTINA TIKHONOVA	{"email": "tikhonova_v-061977@postgrespro.ru", "phone": "+70520543103"}
0005435437604	17C1AF	0144 582274	ANASTASIYA MAKAROVA	{"phone": "+70275233571"}
0005435437605	AA8D84	1799 612395	EKATERINA CHERNOVA	{"phone": "+70515885247"}
0005435437606	DE2253	3380 784923	KSENIYA MIRONOVA	{"phone": "+70326595315"}
0005435437607	810C4E	0322 565642	VADIM NAZAROV	{"email": "v.nazarov.061969@postgrespro.ru", "phone": "+70061435876"}
0005435437608	6AF8C3	8294 404363	YURIY STEPANOV	{"email": "stepanovy.23021962@postgrespro.ru", "phone": "+70918819739"}
0005435437609	7938F4	2590 427961	NIKOLAY BONDARENKO	{"email": "bondarenko_n.08031964@postgrespro.ru", "phone": "+70397312978"}
0005435437610	4DD8D0	3305 160373	ALEKSANDR NAZAROV	{"email": "nazarov-a_19021962@postgrespro.ru", "phone": "+70338038071"}
0005435437611	4DD8D0	0536 757376	IRINA AFANASEVA	{"phone": "+70490599189"}
0005435437612	50B9A4	8939 532001	VERA POPOVA	{"email": "v.popova-1963@postgrespro.ru", "phone": "+70844146546"}
0005435437613	50B9A4	3844 452180	VASILIY ANDREEV	{"email": "v_andreev.25031978@postgrespro.ru", "phone": "+70069879070"}
0005435437614	EA712A	8258 594627	IVAN ANTONOV	{"email": "antonov_ivan_29061973@postgrespro.ru", "phone": "+70702779306"}
0005435437615	EA712A	8195 933194	VALERIY ZAKHAROV	{"email": "valeriy-zakharov_12051978@postgrespro.ru", "phone": "+70544381421"}
0005435437616	36B291	0897 748546	OLEG PAVLOV	{"email": "o.pavlov.061973@postgrespro.ru", "phone": "+70920290190"}
0005435437617	9D0762	0758 338081	ALEKSANDR FROLOV	{"email": "frolov_aleksandr.071971@postgrespro.ru", "phone": "+70515376177"}
0005435437618	E2B713	5753 897685	PAVEL KUZMIN	{"phone": "+70331785210"}
0005435437619	E2B713	5951 733620	YULIYA MASLOVA	{"phone": "+70659053468"}
0005435437620	DD382B	7109 546936	TIMOFEY KUZMIN	{"phone": "+70864238260"}
0005435437621	53038B	4947 821281	MAKSIM MIKHAYLOV	{"email": "m-mikhaylov1985@postgrespro.ru", "phone": "+70079261154"}
0005435437622	53038B	4589 439353	ZINAIDA MEDVEDEVA	{"phone": "+70932149310"}
0005435437623	FC94DB	1091 189890	SERGEY VASILEV	{"phone": "+70295144940"}
0005435437624	FC94DB	9225 430402	NIKITA ALEKSANDROV	{"phone": "+70417643920"}
0005435437625	33298D	7253 342626	NIKOLAY SIDOROV	{"email": "nikolaysidorov121970@postgrespro.ru", "phone": "+70885867088"}
0005435437626	33298D	1935 501947	VALENTINA IVANOVA	{"phone": "+70425185976"}
0005435437627	4E72F2	8285 087097	ALEKSEY KUZNECOV	{"email": "kuznecov_a1984@postgrespro.ru", "phone": "+70502255911"}
0005435437628	96C66B	0908 664313	DMITRIY POPOV	{"phone": "+70161162692"}
0005435437629	96ED6B	1654 522480	KIRILL FILIPPOV	{"email": "k.filippov1963@postgrespro.ru", "phone": "+70433595041"}
0005435437630	258E93	4738 497592	MIKHAIL PETROV	{"email": "m_petrov.1960@postgrespro.ru", "phone": "+70601816637"}
0005435437631	258E93	5546 531750	VIOLETTA LAZAREVA	{"phone": "+70364675714"}
0005435437632	02EF24	4122 747780	ALEKSEY IVANOV	{"email": "ivanovaleksey-03081961@postgrespro.ru", "phone": "+70873980467"}
0005435437633	02EF24	1172 543242	ANNA SMIRNOVA	{"phone": "+70077105028"}
0005435437634	04C572	8616 216007	ANNA GRISHINA	{"email": "grishina.anna.1965@postgrespro.ru", "phone": "+70243831955"}
0005435437635	3CA84E	5597 149887	PRASKOVYA ZAKHAROVA	{"phone": "+70104901616"}
0005435437636	419D74	5942 461081	ALEKSANDR ALEKSANDROV	{"phone": "+70301113700"}
0005435437637	419D74	8403 421502	VITALIY ROMANOV	{"email": "romanov_vitaliy021965@postgrespro.ru", "phone": "+70192348560"}
0005435437638	9D9720	7305 832273	ALEKSANDR KRASNOV	{"phone": "+70067068026"}
0005435437639	C87EC2	9181 725481	ANATOLIY MIKHAYLOV	{"email": "mikhaylov-anatoliy-07021988@postgrespro.ru", "phone": "+70153792834"}
0005435437640	C87EC2	3591 453872	VLADIMIR MIRONOV	{"email": "vladimir-mironov.061979@postgrespro.ru", "phone": "+70617857061"}
0005435437641	12BA3C	9809 997589	TATYANA SOKOLOVA	{"email": "sokolovatatyana.02021979@postgrespro.ru", "phone": "+70071249883"}
0005435437642	12BA3C	3306 500181	DANIL ALEKSEEV	{"email": "dalekseev111964@postgrespro.ru", "phone": "+70146654867"}
0005435437643	9F365E	5473 707598	MAKSIM NOVIKOV	{"email": "novikov_maksim_101969@postgrespro.ru", "phone": "+70853367407"}
0005435437644	9A399C	0951 461487	IGOR IVANOV	{"phone": "+70294388463"}
0005435437645	9A399C	1257 081927	NADEZHDA ANDREEVA	{"email": "andreeva_nadezhda.19031968@postgrespro.ru", "phone": "+70531792192"}
0005435437646	E3B53E	5299 016757	SERGEY MAKAROV	{"phone": "+70214852991"}
0005435437647	E3B53E	7935 381056	GALINA VOLKOVA	{"email": "gvolkova27051982@postgrespro.ru", "phone": "+70312987559"}
0005435437648	984D4F	3035 858253	ALEKSEY ALEKSEEV	{"phone": "+70299321764"}
0005435437649	79E58F	4087 297192	SVETLANA BELYAEVA	{"email": "belyaevas1974@postgrespro.ru", "phone": "+70052239947"}
0005435437650	380BD1	3847 530265	SERGEY GRIGOREV	{"email": "sergey_grigorev.061971@postgrespro.ru", "phone": "+70907682808"}
0005435437651	416544	3378 264444	IVAN ZHUKOV	{"email": "ivan-zhukov-041975@postgrespro.ru", "phone": "+70854716182"}
0005435437652	416544	7680 592280	VYACHESLAV IVANOV	{"email": "ivanovv.021977@postgrespro.ru", "phone": "+70201991300"}
0005435437653	416544	7064 612027	ROZALIYA ZHURAVLEVA	{"email": "r.zhuravleva.071964@postgrespro.ru", "phone": "+70278655121"}
0005435437654	04B0F6	7354 058709	TATYANA BELOVA	{"phone": "+70291939588"}
0005435437655	C01815	7645 219844	ALEFTINA KUZNECOVA	{"email": "kuznecova.aleftina1971@postgrespro.ru", "phone": "+70052701028"}
0005435437656	C01815	8545 820746	TATYANA VASILEVA	{"email": "t.vasileva061972@postgrespro.ru", "phone": "+70282822191"}
0005435437657	B25CB6	4209 594675	ELENA BARANOVA	{"email": "baranova.elena_051973@postgrespro.ru", "phone": "+70316443387"}
0005435437658	2F00BD	1877 594271	ANDREY POPOV	{"email": "andrey-popov-1976@postgrespro.ru", "phone": "+70738562346"}
0005435437659	3027C6	8483 241112	VYACHESLAV GERASIMOV	{"phone": "+70826137209"}
0005435437660	85D3C2	0913 835508	SERGEY MATVEEV	{"phone": "+70963718946"}
0005435437661	85D3C2	3374 289791	NINA KUZNECOVA	{"email": "nina.kuznecova.31051973@postgrespro.ru", "phone": "+70817101021"}
0005435437662	85D3C2	8332 363175	VERA IVANOVA	{"phone": "+70413948817"}
0005435437663	85D3C2	3501 859049	ANDREY STEPANOV	{"email": "a-stepanov-041979@postgrespro.ru", "phone": "+70523902392"}
0005435437664	0CC66D	5738 354188	TAMARA DENISOVA	{"email": "denisova.tamara_1982@postgrespro.ru", "phone": "+70304146874"}
0005435437665	0CC66D	7814 290127	DIANA GUSEVA	{"email": "diana.guseva-19101957@postgrespro.ru", "phone": "+70936027684"}
0005435437666	0FC838	0715 750988	YURIY BORISOV	{"phone": "+70177761400"}
0005435437667	46DDA9	5406 340769	ALEKSANDR ANDREEV	{"phone": "+70044076594"}
0005435437668	0443D9	1754 535993	SVETLANA CHERNOVA	{"email": "s-chernova-081963@postgrespro.ru", "phone": "+70551748227"}
0005435437669	96378A	2454 184986	LIDIYA POPOVA	{"phone": "+70281120843"}
0005435437670	A21D98	1587 418217	ALEKSANDR NAZAROV	{"email": "nazarov-aleksandr.28021976@postgrespro.ru", "phone": "+70840030378"}
0005435437671	91C8A0	9886 852728	ARSENIY EGOROV	{"phone": "+70832866460"}
0005435437672	C9471A	1897 377292	VLADIMIR FOMIN	{"email": "fominv-1980@postgrespro.ru", "phone": "+70216283708"}
0005435437673	C4F9E8	6975 534509	OLGA SERGEEVA	{"email": "olga_sergeeva_1971@postgrespro.ru", "phone": "+70735515731"}
0005435437674	D7F032	6126 193627	ALEKSEY GRIGOREV	{"email": "a-grigorev-031979@postgrespro.ru", "phone": "+70148939120"}
0005435437675	872C7B	3931 317752	VIKTOR VASILEV	{"phone": "+70622540235"}
0005435437676	208578	5624 567998	NURIYA DENISOVA	{"email": "denisovanuriya1967@postgrespro.ru", "phone": "+70045420253"}
0005435437677	A104E5	3428 132139	DENIS ILIN	{"email": "denis-ilin-1980@postgrespro.ru", "phone": "+70165740961"}
0005435437678	FBCC16	0688 172817	ELENA ANTONOVA	{"phone": "+70924801467"}
0005435437679	FBCC16	3522 749485	ALEKSEY ORLOV	{"phone": "+70424351536"}
0005435437680	27D253	8542 558063	YAN GUSEV	{"email": "gusevy-17041972@postgrespro.ru", "phone": "+70483748939"}
0005435437681	27D253	0112 294245	ANNA BORISOVA	{"email": "borisova-anna_061983@postgrespro.ru", "phone": "+70603199112"}
0005435437682	AE7969	8326 296165	OLGA ISAEVA	{"phone": "+70786894677"}
0005435437683	AE7969	2655 726680	DMITRIY ANDREEV	{"email": "dandreev_01091979@postgrespro.ru", "phone": "+70029385349"}
0005435437684	3FB79C	8833 088531	DARINA AKIMOVA	{"email": "akimova.d.1969@postgrespro.ru", "phone": "+70685796255"}
0005435437685	18D5DA	3026 423717	ANNA KOROLEVA	{"phone": "+70155390391"}
0005435437686	CBEFCF	6527 145138	SVETLANA ALEKSEEVA	{"email": "alekseevas-05031966@postgrespro.ru", "phone": "+70842408944"}
0005435437687	CBEFCF	5350 380321	MAKSIM KOZLOV	{"phone": "+70953688538"}
0005435437688	3C752A	7344 578563	ALEKSEY MOISEEV	{"phone": "+70976880583"}
0005435437689	3C752A	6136 422083	ARTEM IVANOV	{"phone": "+70500791780"}
0005435437690	6EC6EF	5397 944998	ROMAN KOROLEV	{"phone": "+70067210707"}
0005435437691	A25738	7360 604957	ALBERT MOISEEV	{"email": "amoiseev17111975@postgrespro.ru", "phone": "+70870118060"}
0005435437692	A25738	0857 929122	IVAN PETROV	{"phone": "+70238207694"}
0005435437693	65C68D	0872 645408	ELENA KOROLEVA	{"phone": "+70049154604"}
0005435437694	38D5C6	9401 546342	LIDIYA LOGINOVA	{"phone": "+70137629028"}
0005435437695	38D5C6	1018 756834	BORIS DAVYDOV	{"email": "davydov_b_041968@postgrespro.ru", "phone": "+70970964213"}
0005435437696	F6854C	5313 272560	NATALYA GERASIMOVA	{"phone": "+70941349450"}
0005435437697	4D6CFC	3161 572390	ANNA KUZNECOVA	{"email": "a-kuznecova13071978@postgrespro.ru", "phone": "+70846876395"}
0005435437698	E83F1C	5218 884039	DENIS MAKAROV	{"email": "makarov.denis-26051975@postgrespro.ru", "phone": "+70449512517"}
0005435437699	489FCD	1359 769399	VIKTOR NAZAROV	{"email": "nazarov_v-1954@postgrespro.ru", "phone": "+70453561528"}
0005435437700	8135E5	0238 674352	MAKSIM SHEVCHENKO	{"email": "mshevchenko1974@postgrespro.ru", "phone": "+70948765908"}
0005435437701	8135E5	6815 638751	NADEZHDA PETROVA	{"phone": "+70715805874"}
0005435437702	8135E5	5803 045268	YULIYA MAKAROVA	{"email": "makarova_y1965@postgrespro.ru", "phone": "+70058854951"}
0005435437703	8ECDFD	0104 400967	ELENA SIDOROVA	{"phone": "+70048801216"}
0005435437704	D4A88C	8614 728975	DMITRIY NIKOLAEV	{"email": "dmitriynikolaev-1967@postgrespro.ru", "phone": "+70417450513"}
0005435437705	D4A88C	3886 684533	VALERIY EGOROV	{"phone": "+70482008893"}
0005435437706	ADF7B0	8549 335316	NINA IVANOVA	{"phone": "+70602224945"}
0005435437707	FBD952	7563 025855	ELENA KUZNECOVA	{"phone": "+70649765383"}
0005435437708	B20B84	2762 047947	ELENA MATVEEVA	{"email": "e-matveeva.1981@postgrespro.ru", "phone": "+70096536279"}
0005435437709	6F4510	8175 363878	SERGEY MOROZOV	{"phone": "+70984799487"}
0005435437710	6F4510	2623 310535	ANNA NIKIFOROVA	{"email": "anna.nikiforova111983@postgrespro.ru", "phone": "+70157519572"}
0005435437711	10DC5D	5246 063507	ANATOLIY MOISEEV	{"email": "anatoliy-moiseev26041972@postgrespro.ru", "phone": "+70243780716"}
0005435437712	6DD7FD	1911 089602	ALISA KOZLOVA	{"phone": "+70766234896"}
0005435437713	C20032	5134 609432	YAN TIKHONOV	{"email": "yantikhonov-091962@postgrespro.ru", "phone": "+70067994420"}
0005435437714	C20032	8085 163742	YAROSLAV FILIPPOV	{"email": "y.filippov.051977@postgrespro.ru", "phone": "+70078554594"}
0005435437715	7A1905	2531 078869	ELENA FILIPPOVA	{"email": "elena_filippova-121985@postgrespro.ru", "phone": "+70569573505"}
0005435437716	B3F05D	2639 880489	GRIGORIY OSIPOV	{"phone": "+70071573926"}
0005435437717	4AE752	6856 480481	SVETLANA SCHERBAKOVA	{"phone": "+70266999563"}
0005435437718	454B39	7617 537738	ANATOLIY ZHURAVLEV	{"email": "anatoliyzhuravlev_1979@postgrespro.ru", "phone": "+70118420226"}
0005435437719	4D5F5E	6427 685360	ELENA BOGDANOVA	{"email": "bogdanova-e.071973@postgrespro.ru", "phone": "+70430480992"}
0005435437720	4D5F5E	9579 360232	MARIYA POLYAKOVA	{"email": "polyakova.mariya.1968@postgrespro.ru", "phone": "+70597016823"}
0005435437721	4D5F5E	5723 162354	RAISA NAZAROVA	{"phone": "+70516344786"}
0005435437777	9D9E4A	9325 724280	ALEKSANDR ISAEV	{"phone": "+70612942434"}
0005435437722	A3ECDA	3683 168473	VALENTINA MIKHAYLOVA	{"email": "valentina.mikhaylova-1955@postgrespro.ru", "phone": "+70698014415"}
0005435437723	A3ECDA	9418 377985	MIKHAIL MAKSIMOV	{"email": "mikhail.maksimov_081983@postgrespro.ru", "phone": "+70025251582"}
0005435437724	80C998	9224 133918	TATYANA POLYAKOVA	{"email": "polyakova.tatyana_041978@postgrespro.ru", "phone": "+70766372184"}
0005435437725	80C998	6998 564878	IRINA NESTEROVA	{"phone": "+70626973177"}
0005435437726	B34312	4264 153584	VLADIMIR KARPOV	{"email": "karpov.vladimir1957@postgrespro.ru", "phone": "+70034516061"}
0005435437727	A45679	9069 058066	IVAN MATVEEV	{"email": "matveev.i-1985@postgrespro.ru", "phone": "+70731092706"}
0005435437728	146327	7099 824180	MAKSIM NOVIKOV	{"email": "m_novikov_05011962@postgrespro.ru", "phone": "+70437730689"}
0005435437729	A2B7ED	1431 989087	VALENTINA FADEEVA	{"email": "valentina.fadeeva_061975@postgrespro.ru", "phone": "+70216562555"}
0005435437730	A2B7ED	4668 804781	ALEKSEY KUZMIN	{"email": "kuzmina_27111969@postgrespro.ru", "phone": "+70091303128"}
0005435437731	3A9808	5923 283618	PAVEL ZAYCEV	{"email": "pzaycev-1972@postgrespro.ru", "phone": "+70268108188"}
0005435437732	3A9808	4653 271812	IGOR PETROV	{"email": "i-petrov.1982@postgrespro.ru", "phone": "+70151272171"}
0005435437733	5B63C5	1668 108710	SERGEY KAZAKOV	{"phone": "+70511214744"}
0005435437734	5B63C5	7817 865917	ELENA NIKITINA	{"phone": "+70142946094"}
0005435437735	2DD5D3	0348 602044	KIRILL MAKSIMOV	{"email": "maksimov_kirill_1963@postgrespro.ru", "phone": "+70367481282"}
0005435437736	2BB77B	9985 257286	SERGEY KUZNECOV	{"phone": "+70035457368"}
0005435437737	BDB382	2889 123207	YURIY ABRAMOV	{"phone": "+70381312710"}
0005435437738	DC2566	7444 596601	GALINA AKIMOVA	{"phone": "+70279483057"}
0005435437739	DF8635	6683 064172	OLGA FILATOVA	{"email": "o.filatova071970@postgrespro.ru", "phone": "+70069030634"}
0005435437740	E1C8CE	9170 617615	VALERIYA GORBUNOVA	{"email": "gorbunova.v041975@postgrespro.ru", "phone": "+70607004701"}
0005435437741	B9B313	7004 528889	SERGEY VOLKOV	{"email": "s.volkov-1972@postgrespro.ru", "phone": "+70775545443"}
0005435437742	B9B313	2739 184576	PETR KONOVALOV	{"phone": "+70294670740"}
0005435437743	B9B313	6885 876044	ELENA PETROVA	{"email": "elena.petrova_14111964@postgrespro.ru", "phone": "+70326477746"}
0005435437744	8D9856	0591 724541	NATALYA PETROVA	{"email": "petrova.natalya_08021983@postgrespro.ru", "phone": "+70464453992"}
0005435437745	8D9856	1070 658296	NELLI FILIPPOVA	{"phone": "+70963525856"}
0005435437746	180CB6	8775 115760	VIKTOR ANTONOV	{"email": "viktor-antonov-1982@postgrespro.ru", "phone": "+70001969851"}
0005435437747	474068	7014 623183	OLEG SMIRNOV	{"email": "oleg-smirnov-1970@postgrespro.ru", "phone": "+70163886739"}
0005435437748	412571	2037 933359	ALEKSEY BARANOV	{"phone": "+70965976396"}
0005435437749	EE8E3F	5703 236073	INNA ANTONOVA	{"phone": "+70603831616"}
0005435437750	EE8E3F	7533 474994	TATYANA KONDRATEVA	{"email": "kondratevatatyana.021980@postgrespro.ru", "phone": "+70459962536"}
0005435437751	12EFB0	5223 534465	YURIY DENISOV	{"phone": "+70037124417"}
0005435437752	12EFB0	2877 975696	DMITRIY TIKHONOV	{"email": "tikhonovd-041966@postgrespro.ru", "phone": "+70957167400"}
0005435437753	644854	0428 999949	ALEKSANDR TARASOV	{"phone": "+70300229884"}
0005435437754	B1F5FC	6780 085619	ALMIRA CHERNOVA	{"phone": "+70539102379"}
0005435437755	261725	7429 068890	LIDIYA KOMAROVA	{"phone": "+70415951862"}
0005435437756	261725	4471 515065	ELMIRA GORBUNOVA	{"email": "gorbunova.elmira111970@postgrespro.ru", "phone": "+70473466250"}
0005435437757	DBA662	8245 683201	DMITRIY KOZLOV	{"email": "kozlov.d_1965@postgrespro.ru", "phone": "+70436600483"}
0005435437758	DBA662	7995 810275	SOFYA MEDVEDEVA	{"phone": "+70465396325"}
0005435437759	F1E384	7906 145567	VLADIMIR MEDVEDEV	{"email": "medvedevvladimir25121963@postgrespro.ru", "phone": "+70357115871"}
0005435437760	2B5E69	5253 583363	MARGARITA KUZMINA	{"phone": "+70467754171"}
0005435437761	516A8C	0529 556890	GALINA PAVLOVA	{"email": "g.pavlova.18091967@postgrespro.ru", "phone": "+70894063711"}
0005435437762	974D3F	8588 230034	ELENA VASILEVA	{"email": "vasileva-elena_25121975@postgrespro.ru", "phone": "+70848386390"}
0005435437763	A2C0AB	9226 237024	TATYANA YAKOVLEVA	{"phone": "+70188949285"}
0005435437764	210F04	8901 461437	PELAGEYA MAKSIMOVA	{"email": "maksimova.p.101968@postgrespro.ru", "phone": "+70421134744"}
0005435437765	4F4983	1072 711416	EKATERINA POTAPOVA	{"email": "epotapova05091976@postgrespro.ru", "phone": "+70198344594"}
0005435437766	A2B7B3	7921 014695	ELENA KALININA	{"email": "kalininae.101980@postgrespro.ru", "phone": "+70719368718"}
0005435437767	07FBF2	7975 135138	ANTONINA FADEEVA	{"phone": "+70113311013"}
0005435437768	07FBF2	2318 860754	ILYA BARANOV	{"email": "ilya_baranov_14111973@postgrespro.ru", "phone": "+70600013856"}
0005435437769	07FBF2	9609 191426	OKSANA MALYSHEVA	{"phone": "+70903555543"}
0005435437770	CFC93F	8338 031018	SERGEY NAZAROV	{"email": "sergey_nazarov-051971@postgrespro.ru", "phone": "+70242762705"}
0005435437771	F7B031	9422 798077	DARYA OSIPOVA	{"email": "osipova.darya.13041984@postgrespro.ru", "phone": "+70669038148"}
0005435437772	BA8D9F	2664 611206	NIKOLAY GRIGOREV	{"phone": "+70144838370"}
0005435437773	F1DA46	7297 458639	ANATOLIY CHERNOV	{"phone": "+70984822905"}
0005435437774	4BC4B9	3861 549745	VLADIMIR ANTONOV	{"email": "vladimir-antonov_031960@postgrespro.ru", "phone": "+70652814291"}
0005435437775	4BC4B9	1061 862540	SERGEY FEDOTOV	{"email": "fedotov-sergey101963@postgrespro.ru", "phone": "+70297627305"}
0005435437776	4BC4B9	0073 504893	VLADIMIR VOLKOV	{"email": "v.volkov.03061975@postgrespro.ru", "phone": "+70113925944"}
0005435437778	9D9E4A	1319 687764	ANDREY NAUMOV	{"email": "naumov-a-07061962@postgrespro.ru", "phone": "+70292916854"}
0005435437779	D22B78	9432 724488	SVETLANA AFANASEVA	{"email": "afanasevas_25091978@postgrespro.ru", "phone": "+70438765030"}
0005435437780	06578A	4517 337058	ANTONINA GRISHINA	{"email": "grishina_antonina.30081966@postgrespro.ru", "phone": "+70205160161"}
0005435437781	06578A	3957 521054	MARIYA YAKOVLEVA	{"phone": "+70570275775"}
0005435437782	2839A5	7575 709292	RUSLAN KOROLEV	{"phone": "+70517840589"}
0005435437783	12C469	5396 747431	VALENTINA POLYAKOVA	{"phone": "+70225585871"}
0005435437784	448251	0988 098454	OLGA ZAYCEVA	{"email": "olga.zayceva-031970@postgrespro.ru", "phone": "+70342673179"}
0005435437785	448251	4950 124362	VALERIY ZHURAVLEV	{"phone": "+70878987772"}
0005435437786	27D607	0971 222355	ALENA AKIMOVA	{"email": "a_akimova.101964@postgrespro.ru", "phone": "+70905068650"}
0005435437787	27D607	7202 606876	SVETLANA TARASOVA	{"email": "tarasova_svetlana101970@postgrespro.ru", "phone": "+70640797086"}
0005435437788	BA7264	6174 148246	ANTON ZHUKOV	{"email": "zhukova_071973@postgrespro.ru", "phone": "+70050654322"}
0005435437789	BA7264	1778 003485	ELIZAVETA CHERNOVA	{"phone": "+70548905147"}
0005435437790	6EA22A	5015 144101	ALEKSANDRA FOMINA	{"email": "fominaa.111960@postgrespro.ru", "phone": "+70032158030"}
0005435437791	6C7D4A	1577 624742	OLGA ZHURAVLEVA	{"phone": "+70154936642"}
0005435437792	F1AA0C	5339 368435	ALEKSANDR MATVEEV	{"phone": "+70295643385"}
0005435437793	CB468A	3076 724020	YULIYA DENISOVA	{"email": "denisova_y-04071975@postgrespro.ru", "phone": "+70309421287"}
0005435437794	43C2B8	5362 592251	TATYANA FEDOROVA	{"phone": "+70415098199"}
0005435437795	E46557	3750 117126	ELENA IVANOVA	{"phone": "+70579689038"}
0005435437796	B9EE26	9539 761890	OLESYA MIRONOVA	{"phone": "+70966221968"}
0005435437797	B9EE26	5184 432274	OLGA EFREMOVA	{"email": "olga-efremova01121977@postgrespro.ru", "phone": "+70892422319"}
0005435437798	A3F9F5	6014 708322	MARINA NESTEROVA	{"email": "nesterova-marina111972@postgrespro.ru", "phone": "+70706527152"}
0005435437799	509CAC	6882 014689	ALESYA ILINA	{"phone": "+70499166029"}
0005435437800	509CAC	8818 770256	YURIY ZAKHAROV	{"email": "zakharovyuriy1965@postgrespro.ru", "phone": "+70344440248"}
0005435437801	E086BC	3629 864357	PAVEL TIKHONOV	{"email": "tikhonov.p_1965@postgrespro.ru", "phone": "+70417796289"}
0005435437802	E086BC	6220 782461	MIKHAIL VASILEV	{"phone": "+70003286895"}
0005435437803	E086BC	0018 594825	TAMARA KAZAKOVA	{"phone": "+70791414395"}
0005435437804	E89D6D	4301 779514	SVETLANA VASILEVA	{"email": "svetlanavasileva1987@postgrespro.ru", "phone": "+70489866243"}
0005435437805	D229BE	0644 613954	MARIYA PAVLOVA	{"phone": "+70566978714"}
0005435437806	D229BE	0203 769622	EKATERINA EFREMOVA	{"phone": "+70558242376"}
0005435437807	9E9EAA	4420 258246	OLEG SOLOVEV	{"phone": "+70138334772"}
0005435437808	110A83	5322 879135	YURIY ZAKHAROV	{"email": "yzakharov.1986@postgrespro.ru", "phone": "+70810391049"}
0005435437809	47DB94	2219 711006	STANISLAV IVANOV	{"email": "ivanov-stanislav.011966@postgrespro.ru", "phone": "+70199907923"}
0005435437810	47DB94	0663 224860	ALEKSEY MOROZOV	{"email": "alekseymorozov-031971@postgrespro.ru", "phone": "+70152181101"}
0005435437811	C2D0DB	1962 415886	SVETLANA MIRONOVA	{"email": "s.mironova_05111972@postgrespro.ru", "phone": "+70318522224"}
0005435437812	0955CA	4262 846602	OLGA NAZAROVA	{"email": "o.nazarova-091966@postgrespro.ru", "phone": "+70547028152"}
0005435437813	8FF744	8800 703044	VLADISLAV KUZMIN	{"email": "v-kuzmin.05071973@postgrespro.ru", "phone": "+70940727303"}
0005435437814	DE79A1	4233 559980	SVETLANA CHERNOVA	{"phone": "+70801419185"}
0005435437815	DE79A1	8151 638005	PAVEL ILIN	{"email": "ilin-pavel28041982@postgrespro.ru", "phone": "+70105968744"}
0005435437816	52C9B6	6537 282195	ANDREY FROLOV	{"phone": "+70177607141"}
0005435437817	9E67BD	9744 636215	NIKOLAY STEPANOV	{"email": "stepanov-nikolay1976@postgrespro.ru", "phone": "+70753143518"}
0005435437818	9E67BD	9232 175835	VLADIMIR KUDRYASHOV	{"phone": "+70256274007"}
0005435437819	F72F27	7252 050261	NIKITA FROLOV	{"email": "frolov-nikita111966@postgrespro.ru", "phone": "+70434337519"}
0005435437820	C37AD4	3756 523606	EVGENIYA ANDREEVA	{"email": "andreevaevgeniya081975@postgrespro.ru", "phone": "+70551421251"}
0005435437821	10EA72	4857 669019	SVETLANA RYABOVA	{"phone": "+70941490237"}
0005435437822	BB913B	0417 619127	TATYANA GUSEVA	{"phone": "+70449705457"}
0005435437823	BB913B	4806 803747	KSENIYA BORISOVA	{"email": "borisova-k15051979@postgrespro.ru", "phone": "+70235528325"}
0005435437824	2BB156	4031 632323	OKSANA KOROLEVA	{"phone": "+70638122441"}
0005435437825	896718	8681 211356	SERGEY KUZMIN	{"email": "sergey-kuzmin.051980@postgrespro.ru", "phone": "+70916406982"}
0005435437826	896718	9212 531261	ALEKSANDR GRIGOREV	{"phone": "+70096765608"}
0005435437827	A7A82F	8667 273626	NIKOLAY EGOROV	{"phone": "+70514808938"}
0005435437828	A7A82F	8470 148836	IVAN DMITRIEV	{"email": "dmitriev.i1956@postgrespro.ru", "phone": "+70779949376"}
0005435437829	A7A82F	6457 503928	SERGEY IVANOV	{"phone": "+70706143356"}
0005435437830	C45C2E	1869 350485	ANDREY OSIPOV	{"email": "aosipov22031978@postgrespro.ru", "phone": "+70359894308"}
0005435437831	0694A6	8600 331434	SERGEY IVANOV	{"email": "s.ivanov.081964@postgrespro.ru", "phone": "+70364161901"}
0005435437832	320EED	5874 146166	ALEKSANDR MIKHAYLOV	{"email": "aleksandr.mikhaylov1984@postgrespro.ru", "phone": "+70952849917"}
0005435437833	320EED	4965 024237	GALINA EFIMOVA	{"phone": "+70160089694"}
0005435437834	DD512E	1099 972167	DARYA ANISIMOVA	{"email": "anisimova.darya.121965@postgrespro.ru", "phone": "+70422525088"}
0005435437835	FF145F	2907 939495	KIRILL ALEKSANDROV	{"phone": "+70740866486"}
0005435437836	952AF6	6265 393782	SERGEY ZHURAVLEV	{"email": "zhuravlevs.11121977@postgrespro.ru", "phone": "+70074900017"}
0005435437837	952AF6	5617 355675	NIKOLAY VASILEV	{"phone": "+70797459169"}
0005435437838	359183	1474 427616	ALEKSANDR SOLOVEV	{"phone": "+70693025917"}
0005435437839	359183	7127 396929	ALEKSANDR POPOV	{"phone": "+70406310918"}
0005435437840	A34767	9628 421458	ANTONINA LEBEDEVA	{"phone": "+70850147553"}
0005435437841	A34767	2962 665809	NATALYA IVANOVA	{"email": "ivanovanatalya-011977@postgrespro.ru", "phone": "+70514978845"}
0005435437842	A6E689	4995 961639	REGINA POPOVA	{"email": "popova.r.13031978@postgrespro.ru", "phone": "+70945396505"}
0005435437843	1B8A0E	8245 594946	GALINA AFANASEVA	{"phone": "+70291364417"}
0005435437844	5160C7	7173 060846	ROMAN FOMIN	{"phone": "+70585063651"}
0005435437845	5160C7	7882 616931	POLINA IVANOVA	{"email": "ivanova-polina-1972@postgrespro.ru", "phone": "+70848593647"}
0005435437846	F03B90	2910 060573	NIKITA GRIGOREV	{"email": "grigorev_nikita.031964@postgrespro.ru", "phone": "+70319604950"}
0005435437847	F03B90	8422 468402	PAVEL IVANOV	{"email": "ivanovpavel031981@postgrespro.ru", "phone": "+70681219543"}
0005435437848	43B167	9971 990457	YULIYA NIKIFOROVA	{"email": "nikiforova_y.041974@postgrespro.ru", "phone": "+70697096362"}
0005435437849	43B167	3755 331335	SERGEY GAVRILOV	{"email": "gavrilov-sergey1984@postgrespro.ru", "phone": "+70485189001"}
0005435437850	7EF15D	4817 363669	RISHAT SOKOLOV	{"email": "r.sokolov_1973@postgrespro.ru", "phone": "+70590124881"}
0005435437851	81A10B	7380 265458	ALEKSANDR GAVRILOV	{"email": "gavrilov-a.041976@postgrespro.ru", "phone": "+70656568301"}
0005435437852	81A10B	8981 394342	DMITRIY IVANOV	{"email": "d-ivanov.091967@postgrespro.ru", "phone": "+70773787742"}
0005435437853	4432A6	9497 364188	OLGA KUDRYASHOVA	{"phone": "+70530544393"}
0005435437854	E61015	0534 346600	NATALYA BELOVA	{"email": "belova.natalya-1974@postgrespro.ru", "phone": "+70316198353"}
0005435437855	E940CB	8671 010798	IRINA BELOVA	{"email": "irinabelova.01041974@postgrespro.ru", "phone": "+70818544163"}
0005435437856	07F642	0751 887300	ANDREY ANDREEV	{"email": "a.andreev.1977@postgrespro.ru", "phone": "+70296434191"}
0005435437857	E53B20	1998 436673	DMITRIY FOMIN	{"phone": "+70764879097"}
0005435437858	0C2FC8	9596 984774	IRINA DENISOVA	{"phone": "+70307187653"}
0005435437859	16A8CD	1524 870494	VLADIMIR ISAEV	{"email": "vladimir_isaev22091961@postgrespro.ru", "phone": "+70784794913"}
0005435437860	3B48BF	6571 991824	POLINA MIRONOVA	{"phone": "+70558954057"}
0005435437861	70E021	5659 538879	ZINAIDA MEDVEDEVA	{"phone": "+70588523514"}
0005435437862	DF3081	1446 234615	ELENA MARTYNOVA	{"phone": "+70472748958"}
0005435437863	9D86DB	2214 770700	VLADIMIR ILIN	{"email": "ilin.vladimir041967@postgrespro.ru", "phone": "+70113356845"}
0005435437864	B9F064	5040 702508	YURIY FOMIN	{"phone": "+70602101018"}
0005435437865	061937	5953 564468	OLGA KAZAKOVA	{"email": "kazakova-olga.08041970@postgrespro.ru", "phone": "+70945588552"}
0005435437866	061937	6282 555055	GALINA IVANOVA	{"phone": "+70565373153"}
0005435437867	B15292	8496 460204	IGOR NAUMOV	{"phone": "+70046946753"}
0005435437868	B15292	1199 328027	VALENTINA IVANOVA	{"email": "ivanova-valentina_1971@postgrespro.ru", "phone": "+70874288125"}
0005435437869	3E30FC	7841 897673	DMITRIY MELNIKOV	{"email": "d-melnikov-08091968@postgrespro.ru", "phone": "+70038326144"}
0005435437870	DA6DED	2327 555734	SVETLANA SEMENOVA	{"email": "s_semenova081976@postgrespro.ru", "phone": "+70435650062"}
0005435437871	31610E	7786 531748	OLGA KUZNECOVA	{"email": "kuznecova-olga.15121964@postgrespro.ru", "phone": "+70748631796"}
0005435437872	4C2905	5571 406652	SERGEY KUDRYASHOV	{"phone": "+70510613256"}
0005435437873	4C2905	8422 740011	NATALYA KOMAROVA	{"email": "natalya-komarova_101977@postgrespro.ru", "phone": "+70790626729"}
0005435437874	4C2905	8426 440245	GALINA ISAEVA	{"email": "isaeva-galina-081971@postgrespro.ru", "phone": "+70496648198"}
0005435437875	7CF8E9	4029 266160	VALENTINA FOMINA	{"email": "v-fomina.28021967@postgrespro.ru", "phone": "+70425373098"}
0005435437876	5262D6	5291 727649	YURIY MAKAROV	{"email": "makarovy_051971@postgrespro.ru", "phone": "+70889662654"}
0005435437877	29FEF7	1409 274174	KIRILL NIKITIN	{"email": "kirill.nikitin.04011980@postgrespro.ru", "phone": "+70875569337"}
0005435437878	9253C4	9011 660263	OLGA KUZNECOVA	{"email": "o_kuznecova_1968@postgrespro.ru", "phone": "+70137254435"}
0005435437879	7480AA	1617 696632	OLGA NIKITINA	{"email": "nikitinaolga13091971@postgrespro.ru", "phone": "+70902832321"}
0005435437880	7480AA	9453 973067	NATALYA ALEKSANDROVA	{"email": "natalya-aleksandrova_1976@postgrespro.ru", "phone": "+70941013453"}
0005435437881	7480AA	1978 736086	VLADIMIR POPOV	{"email": "v-popov-1965@postgrespro.ru", "phone": "+70576609958"}
0005435437882	BD844E	4438 368300	ANTONINA OSIPOVA	{"email": "osipovaantonina.081974@postgrespro.ru", "phone": "+70214272813"}
0005435437883	BD844E	1694 808995	STANISLAV ZHUKOV	{"phone": "+70265064470"}
0005435437884	D46F00	7990 446250	GENNADIY MIKHAYLOV	{"phone": "+70016936241"}
0005435437885	7BD777	7189 343187	ANTONINA TROFIMOVA	{"email": "trofimova_antonina-1970@postgrespro.ru", "phone": "+70920233712"}
0005435437886	28C23E	4650 416121	MARIYA GAVRILOVA	{"phone": "+70613214497"}
0005435437887	87AF5E	0805 454549	OLGA MAKAROVA	{"phone": "+70370204223"}
0005435437888	87AF5E	2201 069584	NATALYA FROLOVA	{"email": "frolova.n_1975@postgrespro.ru", "phone": "+70754352945"}
0005435437889	87AF5E	3813 200577	TATYANA KUZNECOVA	{"email": "tatyana.kuznecova.23081975@postgrespro.ru", "phone": "+70960229615"}
0005435437890	CBA7CB	6621 350988	YULIYA KARPOVA	{"phone": "+70131438815"}
0005435437891	6F0824	6044 237599	EVGENIY KARPOV	{"email": "ekarpov_1976@postgrespro.ru", "phone": "+70810329628"}
0005435437892	6F0824	5440 466299	ALEKSANDR ANTONOV	{"phone": "+70321902801"}
0005435437893	2CD936	7373 446537	VALENTINA KUDRYASHOVA	{"email": "valentina.kudryashova_28041978@postgrespro.ru", "phone": "+70207561456"}
0005435437894	2CD936	9161 447103	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova.20101973@postgrespro.ru", "phone": "+70034112469"}
0005435437895	C58BBD	5778 173284	SERGEY KUZNECOV	{"email": "kuznecov-s_10011962@postgrespro.ru", "phone": "+70391028599"}
0005435437896	C58BBD	1303 683164	DMITRIY SHEVCHENKO	{"email": "d.shevchenko-30051973@postgrespro.ru", "phone": "+70487128941"}
0005435437897	C58BBD	8967 279345	ARTEM VOLKOV	{"phone": "+70958258828"}
0005435437898	CCDE1F	3139 944934	SOFYA BORISOVA	{"email": "sofya-borisova.081973@postgrespro.ru", "phone": "+70808417221"}
0005435437899	5ADFAC	9017 800260	ANDREY KUZNECOV	{"phone": "+70972807338"}
0005435437900	5ADFAC	1753 865328	ILYA MIRONOV	{"phone": "+70029055844"}
0005435437901	65A8A4	7693 468218	RAISA LAZAREVA	{"email": "lazareva.r-051968@postgrespro.ru", "phone": "+70942873432"}
0005435437902	E6060F	9335 639209	PAVEL SMIRNOV	{"email": "smirnov_pavel091978@postgrespro.ru", "phone": "+70704602287"}
0005435437903	E6060F	0816 686052	YAKOV EGOROV	{"email": "yegorov-1961@postgrespro.ru", "phone": "+70919748675"}
0005435437904	9B6FB1	9710 254852	ALEKSANDR SIDOROV	{"email": "sidorov.aleksandr-13081962@postgrespro.ru", "phone": "+70326229811"}
0005435437905	AA3B5A	9815 511195	VLADISLAV KUDRYASHOV	{"email": "kudryashovv-061981@postgrespro.ru", "phone": "+70420882747"}
0005435437906	6C60D7	4831 500845	ANZHELIKA PAVLOVA	{"phone": "+70523678445"}
0005435437907	75D47D	3003 852410	IRINA AFANASEVA	{"phone": "+70211234808"}
0005435437908	0C7F40	7263 794762	VERA KOZLOVA	{"phone": "+70157132563"}
0005435437909	81671F	6122 561553	ANNA RODIONOVA	{"phone": "+70070626200"}
0005435437910	ABD789	1006 317570	IVAN IVANOV	{"email": "ivanovi_14061969@postgrespro.ru", "phone": "+70016328277"}
0005435437911	ABD789	9292 118030	PAVEL ANDREEV	{"phone": "+70898005101"}
0005435437912	3FCA61	0648 653084	NATALYA ANDREEVA	{"email": "andreevanatalya_1971@postgrespro.ru", "phone": "+70950209455"}
0005435437913	C90B1E	2541 152183	IGOR KULIKOV	{"phone": "+70528822276"}
0005435437914	C90B1E	1893 311191	SERGEY ZHURAVLEV	{"email": "zhuravlevsergey011967@postgrespro.ru", "phone": "+70658954296"}
0005435437915	D8667B	4843 259776	PAVEL GRIGOREV	{"phone": "+70101602491"}
0005435437916	C69D2E	8481 300177	YULIYA DAVYDOVA	{"email": "yuliya-davydova_1971@postgrespro.ru", "phone": "+70604732632"}
0005435437917	4B6605	6801 802252	TATYANA ANDREEVA	{"phone": "+70229328370"}
0005435437918	4B6605	2494 963064	SVETLANA VASILEVA	{"email": "svetlanavasileva02061976@postgrespro.ru", "phone": "+70489990018"}
0005435437919	4B6605	8655 106409	VADIM PETROV	{"email": "vadim_petrov-081974@postgrespro.ru", "phone": "+70333793862"}
0005435437920	CDB2C3	0796 205778	EKATERINA EFIMOVA	{"email": "eefimova_19031975@postgrespro.ru", "phone": "+70959628291"}
0005435437921	CDB2C3	9474 066836	NINA CHERNOVA	{"email": "nchernova-06071977@postgrespro.ru", "phone": "+70208054712"}
0005435437922	BF26A3	7053 414977	EKATERINA MOROZOVA	{"phone": "+70334434449"}
0005435437923	BF26A3	1155 889082	VALERIY SMIRNOV	{"phone": "+70578892602"}
0005435437924	44739F	0224 771598	GALINA GRISHINA	{"phone": "+70071782741"}
0005435437925	2E4BE6	9018 746753	VADIM SOKOLOV	{"phone": "+70098365419"}
0005435437926	2E4BE6	7901 081263	NIKOLAY POPOV	{"phone": "+70727882592"}
0005435437927	2E4BE6	0872 408673	ANZHELA GAVRILOVA	{"email": "a.gavrilova01111972@postgrespro.ru", "phone": "+70280601828"}
0005435437928	0F2120	1669 978099	VITALIY SOKOLOV	{"phone": "+70070689930"}
0005435437929	0F2120	8111 746646	EGOR ZAYCEV	{"email": "zaycevegor_18071972@postgrespro.ru", "phone": "+70684339269"}
0005435437930	FF2949	9431 399042	SVETLANA KUZMINA	{"email": "kuzmina_s-111971@postgrespro.ru", "phone": "+70904423474"}
0005435437931	FF2949	2345 289285	ALEKSANDR EGOROV	{"email": "a_egorov1966@postgrespro.ru", "phone": "+70476009013"}
0005435437932	A86953	3471 125189	ALEKSANDRA PETROVA	{"phone": "+70181758390"}
0005435437933	E900B8	6264 610292	LYUBOV KUZNECOVA	{"phone": "+70666297889"}
0005435437934	E900B8	8868 543875	IRINA KONOVALOVA	{"phone": "+70494173857"}
0005435437935	58635F	8540 415542	ELENA NIKITINA	{"phone": "+70060665009"}
0005435437936	9A4034	2759 899532	LYUDMILA MIKHAYLOVA	{"phone": "+70272318927"}
0005435437937	674094	4055 195232	ALEKSANDR IVANOV	{"email": "ivanov_aleksandr_041983@postgrespro.ru", "phone": "+70304579602"}
0005435437938	6348E7	9402 930083	VALENTINA KISELEVA	{"phone": "+70280799440"}
0005435437939	50A3AE	9914 567391	ANFISA ERMAKOVA	{"email": "ermakova-anfisa.121960@postgrespro.ru", "phone": "+70579449744"}
0005435437940	9A8DEB	8891 433276	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov-31121975@postgrespro.ru", "phone": "+70431086464"}
0005435437941	993E42	3312 870941	EVGENIY TARASOV	{"phone": "+70871242817"}
0005435437942	114557	6319 836966	VENIAMIN SEMENOV	{"phone": "+70990899984"}
0005435437943	C62DBB	4188 547090	YURIY MOROZOV	{"email": "ymorozov_051977@postgrespro.ru", "phone": "+70607283388"}
0005435437944	C62DBB	6352 761885	NIKITA NIKITIN	{"phone": "+70998653307"}
0005435437945	C62DBB	4423 664206	MAKSIM IVANOV	{"phone": "+70961128704"}
0005435437946	85CAE3	0687 491907	YANA NAUMOVA	{"email": "naumova-yana-121972@postgrespro.ru", "phone": "+70103988035"}
0005435437947	85CAE3	5808 542877	SVETLANA NOVIKOVA	{"phone": "+70436571703"}
0005435437948	269B89	6381 767681	MARINA BELOVA	{"email": "marinabelova091972@postgrespro.ru", "phone": "+70364773688"}
0005435437949	3C1A3F	3235 065185	YURIY DMITRIEV	{"email": "dmitriev.y.1971@postgrespro.ru", "phone": "+70997692647"}
0005435437950	3C1A3F	5731 470574	EKATERINA AKIMOVA	{"email": "e_akimova-081973@postgrespro.ru", "phone": "+70838485641"}
0005435437951	6CD886	7333 787113	INNA KUZNECOVA	{"email": "kuznecova-inna_051969@postgrespro.ru", "phone": "+70460842628"}
0005435437952	D07CC5	8341 688055	TATYANA IVANOVA	{"email": "t-ivanova_23121959@postgrespro.ru", "phone": "+70118165677"}
0005435437953	D07CC5	5123 522403	NIKOLAY YAKOVLEV	{"email": "yakovlev.nikolay031975@postgrespro.ru", "phone": "+70781471290"}
0005435437954	163357	7898 330732	ALEKSANDR IVANOV	{"email": "ivanov_a121972@postgrespro.ru", "phone": "+70490488042"}
0005435437955	163357	4148 984807	SVETLANA ZHUKOVA	{"phone": "+70474986607"}
0005435437956	4736E0	8608 915522	ALEKSEY KUZNECOV	{"email": "kuznecov.a-16041973@postgrespro.ru", "phone": "+70942456778"}
0005435437957	4736E0	0563 304539	DMITRIY KARPOV	{"phone": "+70280140645"}
0005435437958	DCA0B1	0146 163286	IRINA ANDREEVA	{"phone": "+70305982059"}
0005435437959	DCA0B1	9101 748777	OLGA KUZMINA	{"email": "okuzmina-1979@postgrespro.ru", "phone": "+70006839984"}
0005435437960	2E8759	7345 922746	ANATOLIY DENISOV	{"email": "a_denisov_011971@postgrespro.ru", "phone": "+70321614347"}
0005435437961	137AE8	5233 355830	ANATOLIY KUZMIN	{"phone": "+70584861430"}
0005435437962	89D71E	1600 347752	ANATOLIY SEMENOV	{"phone": "+70910668242"}
0005435437963	89D71E	9509 406192	EKATERINA IVANOVA	{"phone": "+70754306390"}
0005435437964	89D71E	9554 849421	ARTEM MELNIKOV	{"phone": "+70328271545"}
0005435437965	3BAA95	7471 520148	ALEKSANDR SMIRNOV	{"email": "aleksandr-smirnov-1969@postgrespro.ru", "phone": "+70368955908"}
0005435437966	B8944F	6727 603882	DENIS NIKITIN	{"phone": "+70968978861"}
0005435437967	8661FC	1020 094005	SOFIYA MOROZOVA	{"phone": "+70197417986"}
0005435437968	8661FC	9688 283458	YURIY BORISOV	{"email": "yuriy_borisov.051974@postgrespro.ru", "phone": "+70088031010"}
0005435437969	A62BAD	3788 023732	ARTUR GRIGOREV	{"phone": "+70808496067"}
0005435437970	A62BAD	3088 316501	KRISTINA ZAKHAROVA	{"email": "zakharova.kristina_011969@postgrespro.ru", "phone": "+70657693680"}
0005435437971	4EA0D1	1046 281590	ELENA GERASIMOVA	{"phone": "+70431263923"}
0005435437972	EEECA1	9872 693803	MAKSIM VASILEV	{"phone": "+70846667040"}
0005435437973	FFFE39	7995 432865	DMITRIY BONDARENKO	{"phone": "+70927392737"}
0005435437974	B3F6FC	0961 595828	NIKOLAY PAVLOV	{"phone": "+70097609167"}
0005435437975	B3F6FC	7644 226782	ALINA MALYSHEVA	{"email": "malyshevaa.101974@postgrespro.ru", "phone": "+70901215910"}
0005435437976	D3FCA5	0846 249732	TATYANA BORISOVA	{"email": "borisova-t.18121966@postgrespro.ru", "phone": "+70283458225"}
0005435437977	D3FCA5	0255 418394	LARISA SEMENOVA	{"email": "semenova.l-091973@postgrespro.ru", "phone": "+70549930625"}
0005435437978	D3FCA5	4281 463533	RUMIYA NESTEROVA	{"phone": "+70461095613"}
0005435437979	4EED3E	2471 084352	VLADIMIR MOROZOV	{"email": "morozov-v.041978@postgrespro.ru", "phone": "+70095697567"}
0005435437980	60B422	2722 943622	RUSTAM PAVLOV	{"email": "pavlovr.051977@postgrespro.ru", "phone": "+70832301725"}
0005435437981	FFAB70	1818 199343	TATYANA ALEKSEEVA	{"email": "tatyana-alekseeva_1967@postgrespro.ru", "phone": "+70950854287"}
0005435437982	B94B37	7022 211472	LIDIYA OSIPOVA	{"email": "osipoval1967@postgrespro.ru", "phone": "+70931437088"}
0005435437983	145F01	9984 544569	ARTEM POPOV	{"phone": "+70361937284"}
0005435437984	AEE072	0035 819820	KSENIYA ZAYCEVA	{"email": "zaycevakseniya.1973@postgrespro.ru", "phone": "+70696829939"}
0005435437985	7DCFBE	2447 577898	VASILIY ILIN	{"email": "vasiliy-ilin.25101971@postgrespro.ru", "phone": "+70822598480"}
0005435437986	717BBA	1898 393632	OLEG SOROKIN	{"email": "sorokin.oleg_111973@postgrespro.ru", "phone": "+70390375216"}
0005435437987	A97A7E	0658 156221	VIKTOR PAVLOV	{"phone": "+70913319978"}
0005435437988	16BAF5	7945 142589	DENIS MELNIKOV	{"email": "melnikovdenis_08121978@postgrespro.ru", "phone": "+70333505915"}
0005435437989	4D81D4	5353 428333	NIKITA IVANOV	{"phone": "+70847949847"}
0005435437990	8815BB	8100 392099	ANATOLIY SOKOLOV	{"email": "anatoliysokolov-071965@postgrespro.ru", "phone": "+70549745159"}
0005435437991	6D89FC	5415 124967	SABINA VASILEVA	{"email": "sabina-vasileva081980@postgrespro.ru", "phone": "+70326102005"}
0005435437992	681763	7929 041883	EVGENIY PAVLOV	{"phone": "+70230862131"}
0005435437993	745337	7730 479543	GALINA KULIKOVA	{"email": "kulikovagalina-031976@postgrespro.ru", "phone": "+70079016378"}
0005435437994	745337	1977 033443	ALEKSANDR KOZLOV	{"phone": "+70298747993"}
0005435437995	83C6A2	6292 190045	SERGEY KRASNOV	{"phone": "+70988390097"}
0005435437996	0EBDB5	5549 808619	NATALYA SMIRNOVA	{"phone": "+70274399527"}
0005435437997	AD6AD8	9939 323270	YULIYA POLYAKOVA	{"phone": "+70126880921"}
0005435437998	AD6AD8	9875 923314	ALEKSANDR MEDVEDEV	{"email": "a_medvedev.121965@postgrespro.ru", "phone": "+70299029393"}
0005435437999	CC8F62	0460 149876	IRINA MAKAROVA	{"phone": "+70811494658"}
0005435438000	41FADF	9381 936428	NATALIYA SOKOLOVA	{"phone": "+70945725235"}
0005435438001	41FADF	1032 846947	ANGELINA TIMOFEEVA	{"email": "timofeeva_angelina-111968@postgrespro.ru", "phone": "+70485182772"}
0005435438002	14EC51	2765 530545	OLEG KUDRYASHOV	{"email": "kudryashov-o_1974@postgrespro.ru", "phone": "+70305005993"}
0005435438003	CF62D6	4926 904030	EGOR IVANOV	{"email": "ivanovegor.061970@postgrespro.ru", "phone": "+70806057009"}
0005435438004	CF62D6	3386 925164	VLADIMIR VASILEV	{"phone": "+70640833133"}
0005435438005	9779BC	9583 678489	VIKTOR KOROLEV	{"email": "korolev-viktor_041969@postgrespro.ru", "phone": "+70074883096"}
0005435438006	CBFACB	6868 635792	MARINA SAVELEVA	{"email": "savelevam_1970@postgrespro.ru", "phone": "+70714186842"}
0005435438007	CBFACB	6154 752917	RUSTAM NIKOLAEV	{"phone": "+70620332043"}
0005435438008	FD811B	1791 692722	NIKOLAY VASILEV	{"phone": "+70347102447"}
0005435438009	BF3C52	9807 542866	GALINA ARKHIPOVA	{"phone": "+70497569096"}
0005435438010	53DCC7	1921 557055	NATALYA GRISHINA	{"email": "natalya.grishina.051981@postgrespro.ru", "phone": "+70944163278"}
0005435438011	53DCC7	7096 335470	ANDREY ALEKSANDROV	{"phone": "+70276267833"}
0005435438012	E7B752	9620 928249	SERGEY ISAEV	{"email": "isaev.sergey1964@postgrespro.ru", "phone": "+70760491133"}
0005435438013	FB0A80	4969 868987	EVGENIYA POPOVA	{"email": "popova.evgeniya.20071969@postgrespro.ru", "phone": "+70780831757"}
0005435438014	E600FF	6034 945520	VLADISLAV SMIRNOV	{"email": "vladislav.smirnov_061972@postgrespro.ru", "phone": "+70951350751"}
0005435438015	9AF9F9	6127 175561	MILANA KALININA	{"phone": "+70481568357"}
0005435438016	3AD637	4892 584619	LYUDMILA KOROLEVA	{"phone": "+70985184181"}
0005435438017	A6C8F3	0291 398521	MATVEY ISAEV	{"email": "isaevmatvey_12111971@postgrespro.ru", "phone": "+70781308304"}
0005435438018	0859D9	0536 830959	LIDIYA VASILEVA	{"email": "vasileva-l_1978@postgrespro.ru", "phone": "+70529763721"}
0005435438019	1DE9BB	0942 906444	YURIY IVANOV	{"email": "y-ivanov10111982@postgrespro.ru", "phone": "+70872687075"}
0005435438020	D60E37	8625 870850	NATALYA RYABOVA	{"phone": "+70812265441"}
0005435438021	D60E37	1415 081056	TATYANA VASILEVA	{"email": "vasilevatatyana23101975@postgrespro.ru", "phone": "+70988418713"}
0005435438022	A021E0	8945 499743	SERGEY SMIRNOV	{"phone": "+70225863099"}
0005435438023	4F4568	5762 778514	SERGEY FOMIN	{"email": "sfomin_23071968@postgrespro.ru", "phone": "+70750668923"}
0005435438024	BBA4BD	7905 412832	MAKSIM PAVLOV	{"email": "maksim.pavlov.25051965@postgrespro.ru", "phone": "+70482835325"}
0005435438025	BBA4BD	1795 211321	VALENTINA POTAPOVA	{"email": "potapova.valentina-031967@postgrespro.ru", "phone": "+70634828783"}
0005435438026	B232CC	9355 140350	DARYA ORLOVA	{"phone": "+70447164751"}
0005435438027	B232CC	3739 708435	VIKTOR KOROLEV	{"email": "korolev_viktor-08081961@postgrespro.ru", "phone": "+70446740562"}
0005435438028	1BFF86	1226 670776	IRINA MARTYNOVA	{"email": "martynovai-18121969@postgrespro.ru", "phone": "+70533629550"}
0005435438029	8516C7	2964 762008	TATYANA ALEKSANDROVA	{"phone": "+70028751374"}
0005435438030	8516C7	2710 338216	VIKTOR DAVYDOV	{"email": "davydov_v-27111986@postgrespro.ru", "phone": "+70259127115"}
0005435438031	8516C7	3928 636523	KSENIYA TARASOVA	{"email": "tarasova-k.101970@postgrespro.ru", "phone": "+70314992054"}
0005435438032	8E0F84	9627 445954	ALEKSEY MOISEEV	{"email": "moiseev-aleksey_1958@postgrespro.ru", "phone": "+70179865149"}
0005435438033	7C59D3	4882 161362	KSENIYA IVANOVA	{"phone": "+70764975311"}
0005435438034	B9DE82	2803 350655	GENNADIY NOVIKOV	{"phone": "+70300184676"}
0005435438035	9FE1AD	2793 028444	ANDREY ZAKHAROV	{"phone": "+70547850147"}
0005435438036	6C245C	2223 328853	GEORGIY SCHERBAKOV	{"phone": "+70195626005"}
0005435438037	BA3944	3676 713328	SERGEY TIKHONOV	{"email": "tikhonov_sergey_14041961@postgrespro.ru", "phone": "+70431069292"}
0005435438038	F3A422	0646 571970	ELENA VOLKOVA	{"phone": "+70879708415"}
0005435438039	E1CF7B	1928 571140	POLINA VOROBEVA	{"email": "vorobeva-p.1969@postgrespro.ru", "phone": "+70220298625"}
0005435438040	E1CF7B	0202 216333	ALEKSEY VLASOV	{"phone": "+70440851339"}
0005435438041	2DD6DF	7918 141156	VERA MIKHAYLOVA	{"phone": "+70753941984"}
0005435438042	2DD6DF	3911 625939	TAMARA FEDOROVA	{"phone": "+70124606165"}
0005435438043	2DD6DF	9865 390191	ROZA ANDREEVA	{"email": "r.andreeva_1970@postgrespro.ru", "phone": "+70430743467"}
0005435438044	F6BE05	9039 418191	EVGENIY SERGEEV	{"email": "sergeev.e_1985@postgrespro.ru", "phone": "+70233591301"}
0005435438045	F6BE05	9769 253151	EVDOKIYA PETROVA	{"phone": "+70264967954"}
0005435438046	279254	4270 193674	SERAFIMA MAKAROVA	{"phone": "+70626443294"}
0005435438047	824117	5643 007929	NADEZHDA FEDOROVA	{"phone": "+70835340058"}
0005435438048	9237C7	0240 705445	LIDIYA VOLKOVA	{"phone": "+70812922696"}
0005435438049	9237C7	1883 795173	VALENTINA DENISOVA	{"email": "valentina.denisova-051972@postgrespro.ru", "phone": "+70363634246"}
0005435438050	EBA1DB	7069 121982	SERGEY GERASIMOV	{"email": "s_gerasimov.18111988@postgrespro.ru", "phone": "+70802672995"}
0005435438051	2FC719	1498 892623	SVETLANA KOZLOVA	{"email": "kozlova-svetlana-121976@postgrespro.ru", "phone": "+70700562597"}
0005435438052	2FC719	7736 417441	ALEKSANDR SOROKIN	{"email": "aleksandr-sorokin-14061976@postgrespro.ru", "phone": "+70717892637"}
0005435438053	73C054	1850 380110	IRINA KOVALEVA	{"phone": "+70233621960"}
0005435438054	C9B753	7425 691338	BORIS TIMOFEEV	{"email": "boris-timofeev02041969@postgrespro.ru", "phone": "+70906068093"}
0005435438055	413818	1266 971933	IVAN PETROV	{"phone": "+70605374591"}
0005435438056	3455CD	9619 141501	ANDREY DENISOV	{"phone": "+70220425012"}
0005435438057	D9D20F	8348 404263	OLEG MAKAROV	{"phone": "+70957917730"}
0005435438058	E123C9	9341 552042	NATALYA GORBUNOVA	{"email": "gorbunovan_061960@postgrespro.ru", "phone": "+70325034473"}
0005435438059	A6A151	5934 578702	NIKOLAY BELOV	{"email": "belovnikolay-091982@postgrespro.ru", "phone": "+70684108940"}
0005435438060	F18305	8229 596806	GALINA GAVRILOVA	{"phone": "+70669624336"}
0005435438061	F18305	4085 401681	ANDREY KUZMIN	{"phone": "+70452087905"}
0005435438062	B50636	2207 127812	GLEB KUZNECOV	{"phone": "+70195842253"}
0005435438063	2CF755	6227 982065	FEDOR FEDOTOV	{"phone": "+70469018514"}
0005435438064	CFF0A0	7228 427896	VLADIMIR VASILEV	{"email": "vasilev-vladimir.091967@postgrespro.ru", "phone": "+70346572853"}
0005435438065	0FF26E	4231 404055	VLADISLAV EGOROV	{"email": "vladislav-egorov.05061977@postgrespro.ru", "phone": "+70420746207"}
0005435438066	CC5F8A	0054 489005	MARIYA EFREMOVA	{"email": "efremovamariya.121973@postgrespro.ru", "phone": "+70376951162"}
0005435438067	93BEB4	8163 226706	TATYANA KAZAKOVA	{"email": "kazakova-t_1975@postgrespro.ru", "phone": "+70163882551"}
0005435438068	A295A2	0159 319945	OLGA GAVRILOVA	{"phone": "+70311988655"}
0005435438069	A295A2	5143 345160	IVAN NOVIKOV	{"phone": "+70935188425"}
0005435438070	84C709	4077 013274	MIKHAIL MAKAROV	{"phone": "+70766335250"}
0005435438071	DDDB11	9537 980198	NADEZHDA FEDOROVA	{"email": "fedorovan-09111970@postgrespro.ru", "phone": "+70294607948"}
0005435438072	DFE256	2677 110771	ELENA EFIMOVA	{"email": "elena_efimova.24031972@postgrespro.ru", "phone": "+70240330013"}
0005435438073	DFE256	5371 003562	VALENTINA SIDOROVA	{"email": "v.sidorova.031972@postgrespro.ru", "phone": "+70547159613"}
0005435438074	9C8D42	5437 210644	RAISA TARASOVA	{"phone": "+70944385950"}
0005435438075	6AFBD1	5476 797748	POLINA MEDVEDEVA	{"email": "medvedeva_polina.101966@postgrespro.ru", "phone": "+70712767297"}
0005435438076	6AFBD1	0218 518128	IVAN ZAKHAROV	{"phone": "+70005627776"}
0005435438077	F3A0F7	5497 111253	RAFAIL OSIPOV	{"email": "osipovr011975@postgrespro.ru", "phone": "+70820776660"}
0005435438078	163F4E	6620 694708	TAMARA KUZNECOVA	{"email": "kuznecova.t011978@postgrespro.ru", "phone": "+70074742486"}
0005435438079	AD612A	0573 233229	SVETLANA IVANOVA	{"phone": "+70685134266"}
0005435438080	8C2CE7	5453 452027	NADEZHDA POPOVA	{"email": "popova.nadezhda.1986@postgrespro.ru", "phone": "+70043629973"}
0005435438081	585DA9	1261 426510	YURIY KOROLEV	{"phone": "+70144507093"}
0005435438082	585DA9	4400 328062	TAMARA EFREMOVA	{"email": "efremova-tamara_1974@postgrespro.ru", "phone": "+70405575550"}
0005435438083	585DA9	0662 332144	SERGEY ROMANOV	{"email": "s_romanov_01121978@postgrespro.ru", "phone": "+70177303528"}
0005435438084	F3A130	3588 794773	KSENIYA DAVYDOVA	{"phone": "+70739794506"}
0005435438085	DD08A0	9152 642843	DENIS FOMIN	{"phone": "+70574343506"}
0005435438086	DBA72B	1147 516624	SOFYA NIKOLAEVA	{"phone": "+70785025283"}
0005435438087	DBA72B	4087 258605	OLGA KRASNOVA	{"email": "o.krasnova08111968@postgrespro.ru", "phone": "+70895628966"}
0005435438088	247918	2069 671905	SERGEY MOISEEV	{"phone": "+70446265660"}
0005435438089	237784	6499 659890	YURIY ZAKHAROV	{"phone": "+70238916586"}
0005435438090	EFC66E	7318 284031	LYUDMILA PETROVA	{"email": "lyudmila-petrova_1969@postgrespro.ru", "phone": "+70033069343"}
0005435438091	EFC66E	5442 522181	ANASTASIYA TIKHONOVA	{"email": "anastasiya-tikhonova18041966@postgrespro.ru", "phone": "+70546296076"}
0005435438092	4A372B	1097 117272	OLGA SEMENOVA	{"phone": "+70388778032"}
0005435438093	4A372B	8271 621743	ANASTASIYA MAKSIMOVA	{"phone": "+70530941449"}
0005435438094	55D152	4412 238535	NATALYA ROMANOVA	{"phone": "+70231507036"}
0005435438095	55D152	7463 314927	MARINA VASILEVA	{"phone": "+70207205954"}
0005435438096	BE4E33	1945 653186	ANNA CHERNOVA	{"email": "anna.chernova_061979@postgrespro.ru", "phone": "+70143552366"}
0005435438097	BE4E33	6796 161706	SVETLANA SAVELEVA	{"email": "svetlanasaveleva-011961@postgrespro.ru", "phone": "+70290967006"}
0005435438098	848C75	2127 618158	IGOR MAKAROV	{"email": "makarov.igor27091969@postgrespro.ru", "phone": "+70424752187"}
0005435438099	2881CE	4935 542986	NIKITA DMITRIEV	{"email": "dmitriev.nikita-101975@postgrespro.ru", "phone": "+70864984497"}
0005435438100	1C2D5D	4826 580932	VITALIY NAUMOV	{"phone": "+70366589476"}
0005435438101	1C2D5D	2668 803379	ANNA MELNIKOVA	{"email": "melnikova.anna1980@postgrespro.ru", "phone": "+70284662633"}
0005435438102	371CB9	0469 844867	ANASTASIYA KOROLEVA	{"email": "a.koroleva.31081964@postgrespro.ru", "phone": "+70337828082"}
0005435438103	98A8AD	2981 811473	VLADIMIR SOKOLOV	{"email": "vladimirsokolov02031972@postgrespro.ru", "phone": "+70130111057"}
0005435438104	98A8AD	5066 010917	ALENA STEPANOVA	{"email": "stepanova_a22051965@postgrespro.ru", "phone": "+70991967277"}
0005435438105	106114	4488 645257	DMITRIY DENISOV	{"email": "denisovd-111972@postgrespro.ru", "phone": "+70347497872"}
0005435438106	3484CE	0870 280596	LYUDMILA MAKAROVA	{"phone": "+70775571546"}
0005435438107	3484CE	2074 750631	KLAVDIYA YAKOVLEVA	{"phone": "+70890624687"}
0005435438108	3484CE	3531 526112	ALLA MOROZOVA	{"email": "alla-morozova15051970@postgrespro.ru", "phone": "+70982176983"}
0005435438109	9EF210	3049 826107	ELENA GERASIMOVA	{"email": "gerasimova-elena.071968@postgrespro.ru", "phone": "+70572293889"}
0005435438110	9EF210	9831 668926	VIKTOR SEMENOV	{"phone": "+70314959542"}
0005435438111	D4596B	6907 745509	VALENTINA VOROBEVA	{"phone": "+70919954898"}
0005435438112	C6C353	5174 372303	EVGENIY KUZNECOV	{"phone": "+70852072347"}
0005435438113	51CBEC	0578 446958	NATALYA NESTEROVA	{"email": "n_nesterova.071971@postgrespro.ru", "phone": "+70361402315"}
0005435438114	B6EECD	7995 776039	GALINA KUZNECOVA	{"phone": "+70565690788"}
0005435438115	E6687E	7232 999885	IVAN KUZNECOV	{"phone": "+70817310057"}
0005435438116	B83137	9165 871547	VALERIY SEMENOV	{"email": "semenov.valeriy25091976@postgrespro.ru", "phone": "+70709000208"}
0005435438117	B83137	5478 366320	VLADIMIR NOVIKOV	{"email": "vladimir-novikov-22111960@postgrespro.ru", "phone": "+70264765870"}
0005435438118	88CC0C	8710 621637	YULIYA MASLOVA	{"email": "yuliyamaslova-1968@postgrespro.ru", "phone": "+70119127872"}
0005435438119	7DF0EB	3175 753014	SERGEY VASILEV	{"phone": "+70201434777"}
0005435438120	7DF0EB	0339 893606	LYUBOV ZAKHAROVA	{"phone": "+70708061425"}
0005435438121	62A7EF	6685 799154	ANNA ABRAMOVA	{"email": "aabramova.1964@postgrespro.ru", "phone": "+70714606130"}
0005435438122	1CBD7D	3227 772166	MIKHAIL FEDOROV	{"email": "fedorov.mikhail-031967@postgrespro.ru", "phone": "+70962802551"}
0005435438123	1CBD7D	8599 156072	OLGA KULIKOVA	{"email": "o_kulikova081961@postgrespro.ru", "phone": "+70485309546"}
0005435438124	D24505	7357 231332	LEONID SIDOROV	{"email": "sidorov.leonid111967@postgrespro.ru", "phone": "+70284054741"}
0005435438125	EE286C	8366 368130	ALBINA VASILEVA	{"email": "vasileva_albina05111967@postgrespro.ru", "phone": "+70067692515"}
0005435438126	339AE9	3288 865772	MIKHAIL ORLOV	{"phone": "+70051868598"}
0005435438127	339AE9	5935 302269	DAVID SCHERBAKOV	{"phone": "+70219425605"}
0005435438128	2B9135	4825 671356	VYACHESLAV ANDREEV	{"email": "andreev.v-1971@postgrespro.ru", "phone": "+70930611947"}
0005435438129	B7D399	6551 376094	GALINA SOKOLOVA	{"email": "sokolovagalina.1965@postgrespro.ru", "phone": "+70392123265"}
0005435438130	B7D399	1240 481108	TATYANA ARKHIPOVA	{"email": "arkhipova.t.1989@postgrespro.ru", "phone": "+70999148650"}
0005435438131	DDD210	7833 200611	YURIY SERGEEV	{"email": "ysergeev-051967@postgrespro.ru", "phone": "+70548775384"}
0005435438132	DDD210	6643 992773	VYACHESLAV ISAEV	{"phone": "+70478823608"}
0005435438133	37FE13	6848 676599	VERA LUKYANOVA	{"email": "vlukyanova05121973@postgrespro.ru", "phone": "+70798727038"}
0005435438134	E0C1B8	0501 491705	PAVEL KUDRYASHOV	{"email": "kudryashov-pavel1967@postgrespro.ru", "phone": "+70496707385"}
0005435438135	9EFC09	4140 624981	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga_13051973@postgrespro.ru", "phone": "+70736633553"}
0005435438136	0E9E80	8337 322110	ALEKSANDR PETROV	{"phone": "+70408413192"}
0005435438137	3793B5	1279 945368	DANIS KONOVALOV	{"phone": "+70300602701"}
0005435438138	3793B5	6980 923257	NINA MEDVEDEVA	{"email": "ninamedvedeva_26091977@postgrespro.ru", "phone": "+70331550420"}
0005435438139	48DEB6	5909 348996	VALENTINA MATVEEVA	{"email": "matveeva_v.031969@postgrespro.ru", "phone": "+70753532141"}
0005435438140	A8F068	4002 934662	DMITRIY GAVRILOV	{"email": "gavrilov.dmitriy-071975@postgrespro.ru", "phone": "+70239755529"}
0005435438141	269CE0	9234 244775	NINA CHERNOVA	{"phone": "+70652059832"}
0005435438142	C6382D	8537 763553	SVETLANA EFIMOVA	{"phone": "+70809074200"}
0005435438143	5D30CA	4782 793392	VIKTOR KUZNECOV	{"phone": "+70417876134"}
0005435438144	09F42C	6996 229119	SERGEY SOKOLOV	{"email": "sergey.sokolov12061977@postgrespro.ru", "phone": "+70305066114"}
0005435438145	781A11	0320 173819	NATALYA KALININA	{"email": "kalinina-natalya.1971@postgrespro.ru", "phone": "+70658835147"}
0005435438146	B8D548	3108 623843	OLGA SEMENOVA	{"email": "semenova-o.09081970@postgrespro.ru", "phone": "+70921307828"}
0005435438147	B8D548	5111 673131	VLADISLAV FROLOV	{"phone": "+70648302622"}
0005435438148	E0AACA	9788 840933	TATYANA TIMOFEEVA	{"phone": "+70034142569"}
0005435438149	BBA2B3	1264 181572	YURIY KISELEV	{"email": "y-kiselev-031971@postgrespro.ru", "phone": "+70843369578"}
0005435438150	BBA2B3	0664 830148	ANASTASIYA TROFIMOVA	{"phone": "+70740137914"}
0005435438151	ABB060	7783 073619	VLADIMIR KRASNOV	{"phone": "+70857125226"}
0005435438152	A3BD94	7667 957377	VIKTOR ISAEV	{"phone": "+70521030127"}
0005435438153	A3BD94	6373 943406	SERGEY PAVLOV	{"phone": "+70949438239"}
0005435438154	FAF8EF	8178 450404	VIKTORIYA ZOTOVA	{"email": "zotova.viktoriya_021965@postgrespro.ru", "phone": "+70670715396"}
0005435438155	FAF8EF	6512 637232	TAMARA SOROKINA	{"email": "sorokina_tamara.09051968@postgrespro.ru", "phone": "+70701567415"}
0005435438156	9385BA	8835 804790	VIKTOR PAVLOV	{"phone": "+70981772442"}
0005435438157	9385BA	9133 469371	YULIYA MEDVEDEVA	{"phone": "+70278887747"}
0005435438158	1596B2	3948 339182	ALENA NIKOLAEVA	{"email": "alena_nikolaeva1973@postgrespro.ru", "phone": "+70366119826"}
0005435438159	946FF6	2950 966061	ALEKSANDR OSIPOV	{"email": "a_osipov_10031983@postgrespro.ru", "phone": "+70052645956"}
0005435438160	946FF6	9741 249630	VALERIYA MIRONOVA	{"phone": "+70940363784"}
0005435438161	CD2113	9003 811851	LARISA POPOVA	{"email": "popova.larisa_14101977@postgrespro.ru", "phone": "+70409955472"}
0005435438162	4DA0DC	9859 529733	GALINA KOMAROVA	{"email": "komarova-galina-1971@postgrespro.ru", "phone": "+70286785891"}
0005435438163	F7A958	0516 596876	VALERIY PETROV	{"phone": "+70484163671"}
0005435438164	517F49	0529 356240	VLADIMIR ALEKSEEV	{"phone": "+70012851033"}
0005435438165	517F49	0680 337970	LILIYA IVANOVA	{"phone": "+70062719455"}
0005435438166	E44D3F	1028 859699	TATYANA TARASOVA	{"email": "tarasovat07061972@postgrespro.ru", "phone": "+70429928376"}
0005435438167	5CA497	9747 949515	ELENA POPOVA	{"phone": "+70785194825"}
0005435438168	5CA497	3689 572694	ALBERT KAZAKOV	{"phone": "+70560944591"}
0005435438169	C64497	8398 355835	IRINA POPOVA	{"email": "ipopova_1965@postgrespro.ru", "phone": "+70575728575"}
0005435438170	C64497	7858 985161	DAMIR KOZLOV	{"email": "kozlov_damir.1976@postgrespro.ru", "phone": "+70959171365"}
0005435438171	3E251C	6352 954502	VALERIYA MEDVEDEVA	{"phone": "+70869568415"}
0005435438172	3E251C	9762 337203	YULIYA KUZNECOVA	{"phone": "+70553055875"}
0005435438173	3E251C	0519 834465	NATALYA ANDREEVA	{"phone": "+70209333101"}
0005435438174	1E7108	9404 979913	IRAIDA IVANOVA	{"email": "ivanovai16101980@postgrespro.ru", "phone": "+70206735729"}
0005435438175	E38AAA	9859 737737	NATALYA PAVLOVA	{"email": "pavlovan_051970@postgrespro.ru", "phone": "+70496787049"}
0005435438176	11E0A3	2790 826779	VLADIMIR NIKITIN	{"email": "nikitin_vladimir121951@postgrespro.ru", "phone": "+70889951233"}
0005435438177	C4235E	8914 508353	NATALYA TIMOFEEVA	{"email": "timofeeva-n041973@postgrespro.ru", "phone": "+70048046324"}
0005435438178	C4235E	2238 200505	LYUDMILA KULIKOVA	{"email": "lyudmila.kulikova.071979@postgrespro.ru", "phone": "+70228204571"}
0005435438179	C4235E	6907 857542	IVAN PETROV	{"email": "petrov_ivan1974@postgrespro.ru", "phone": "+70964629362"}
0005435438180	CE435A	9800 632075	VIKTORIYA VOLKOVA	{"phone": "+70914331719"}
0005435438181	D0739A	5945 179810	OLGA BOGDANOVA	{"email": "bogdanova.olga.101972@postgrespro.ru", "phone": "+70296546170"}
0005435438182	A95AA0	7865 397296	YURIY GRIGOREV	{"phone": "+70292832000"}
0005435438183	B92854	0616 266523	EVGENIY KUZNECOV	{"email": "kuznecov_e-03091970@postgrespro.ru", "phone": "+70042396320"}
0005435438184	25258A	8242 475530	SERGEY POPOV	{"email": "s.popov-14071971@postgrespro.ru", "phone": "+70730048668"}
0005435438185	25258A	1951 497405	KSENIYA KUZNECOVA	{"email": "kseniya_kuznecova1970@postgrespro.ru", "phone": "+70432175424"}
0005435438186	696D48	2112 187451	YULIYA MOISEEVA	{"phone": "+70361276008"}
0005435438187	1CC5C1	4968 037947	NADEZHDA FADEEVA	{"email": "fadeevan_1978@postgrespro.ru", "phone": "+70556976397"}
0005435438188	1FA36C	3094 712062	DMITRIY KUZNECOV	{"phone": "+70264049361"}
0005435438189	A9C8F8	5069 908429	ALEKSEY KONOVALOV	{"email": "konovalov-aleksey-101978@postgrespro.ru", "phone": "+70534142003"}
0005435438190	40AB35	1160 644246	EVGENIY SAVELEV	{"email": "savelev_evgeniy1972@postgrespro.ru", "phone": "+70941017086"}
0005435438191	40AB35	0210 465535	SERGEY NIKITIN	{"phone": "+70953849268"}
0005435438192	AD89AC	6948 218413	MIKHAIL MEDVEDEV	{"phone": "+70248721466"}
0005435438193	750A04	7123 348871	GULSINA SEMENOVA	{"phone": "+70220567083"}
0005435438194	750A04	5153 928391	ELINA KOVALEVA	{"email": "kovaleva.e_051970@postgrespro.ru", "phone": "+70909873458"}
0005435438195	142916	1868 017719	LYUBOV ERMAKOVA	{"email": "l.ermakova101964@postgrespro.ru", "phone": "+70512450318"}
0005435438196	142916	8607 504866	TATYANA POPOVA	{"phone": "+70055098601"}
0005435438197	DCF683	0405 715304	ALEKSANDR SMIRNOV	{"email": "smirnova121974@postgrespro.ru", "phone": "+70680408573"}
0005435438198	8AFEC8	5863 696451	ANATOLIY SERGEEV	{"email": "anatoliy-sergeev.28041960@postgrespro.ru", "phone": "+70632686200"}
0005435438199	755E01	0102 993191	TATYANA IVANOVA	{"phone": "+70956587125"}
0005435438200	755E01	6483 764982	POLINA NIKOLAEVA	{"phone": "+70169634386"}
0005435438201	D815B7	8416 672712	VLADIMIR ORLOV	{"email": "vladimir_orlov_01091973@postgrespro.ru", "phone": "+70893146379"}
0005435438202	DB8228	5905 043890	VALENTINA MATVEEVA	{"phone": "+70762933428"}
0005435438203	D688C3	3747 408360	KARINA IVANOVA	{"phone": "+70772601058"}
0005435438204	E546C2	7450 808552	LIDIYA IVANOVA	{"email": "ivanova.l-1982@postgrespro.ru", "phone": "+70064046609"}
0005435438205	2287BE	8982 382836	ALEKSANDR KUZMIN	{"phone": "+70973937715"}
0005435438206	CCF7AE	8710 131159	DENIS SERGEEV	{"email": "denis.sergeev_1962@postgrespro.ru", "phone": "+70767189451"}
0005435438207	CCF7AE	6858 277367	VLADIMIR KUZMIN	{"phone": "+70593103444"}
0005435438208	71088E	3028 389793	EVGENIY SCHERBAKOV	{"phone": "+70822281756"}
0005435438209	17A78E	6875 786537	LIDIYA DAVYDOVA	{"email": "l-davydova_1981@postgrespro.ru", "phone": "+70703200800"}
0005435438210	F58F13	7167 192385	NATALYA MAKAROVA	{"phone": "+70968341101"}
0005435438211	39F2AA	1896 936478	VIKTORIYA DAVYDOVA	{"email": "v-davydova.051971@postgrespro.ru", "phone": "+70616926695"}
0005435438212	5640AC	4315 436722	ANASTASIYA MIKHAYLOVA	{"phone": "+70548369704"}
0005435438213	F4AB7F	6274 475308	ANATOLIY KONOVALOV	{"phone": "+70175612579"}
0005435438214	56A12B	8109 204101	VERA ERMAKOVA	{"email": "vera.ermakova_1976@postgrespro.ru", "phone": "+70842734822"}
0005435438215	C94B5E	4428 340005	IRINA ZHUKOVA	{"phone": "+70779379169"}
0005435438216	8335A2	4164 243731	RAFAIL ROMANOV	{"phone": "+70970380203"}
0005435438217	8335A2	9390 689227	OLGA ALEKSANDROVA	{"phone": "+70604970092"}
0005435438218	830B1B	5444 394724	VIKTOR GERASIMOV	{"phone": "+70829563085"}
0005435438219	EB332E	2816 771308	VITALIY SOLOVEV	{"email": "solovev-v_1960@postgrespro.ru", "phone": "+70926444065"}
0005435438220	ED4A87	1868 227894	MARIYA ANDREEVA	{"phone": "+70338381459"}
0005435438221	7EDCF8	5196 066652	TATYANA ILINA	{"email": "tilina_061980@postgrespro.ru", "phone": "+70185905551"}
0005435438222	309679	8357 148971	SERGEY ZHURAVLEV	{"phone": "+70024756571"}
0005435438223	A28607	7705 566302	VLADIMIR VOLKOV	{"email": "vvolkov_22061969@postgrespro.ru", "phone": "+70251751852"}
0005435438224	5BD322	4906 156875	ALEKSANDR SHEVCHENKO	{"phone": "+70567109206"}
0005435438225	22B59F	8173 015143	NINA ABRAMOVA	{"phone": "+70100475598"}
0005435438226	283A36	5884 819122	VERA ZAKHAROVA	{"phone": "+70115237942"}
0005435438227	283A36	0331 195482	NIKITA ILIN	{"email": "ilin-n-1976@postgrespro.ru", "phone": "+70707726367"}
0005435438228	0A0294	0342 146475	ALEKSANDRA ANDREEVA	{"phone": "+70137923875"}
0005435438229	2EB862	0744 744648	ELENA VASILEVA	{"email": "vasileva-e.061970@postgrespro.ru", "phone": "+70424491418"}
0005435438230	2EB862	5950 518777	ANASTASIYA ABRAMOVA	{"email": "anastasiya-abramova-1978@postgrespro.ru", "phone": "+70757291584"}
0005435438231	06EA9B	4311 830534	MAKSIM IVANOV	{"email": "m_ivanov_071977@postgrespro.ru", "phone": "+70757851400"}
0005435438232	06EA9B	5250 128631	ALEKSANDRA IVANOVA	{"email": "ivanova_aleksandra_20051968@postgrespro.ru", "phone": "+70116592289"}
0005435438233	944509	1716 560346	TAISIYA SOLOVEVA	{"email": "t_soloveva.07091969@postgrespro.ru", "phone": "+70103935041"}
0005435438234	E500F1	2665 651779	ILYA VLASOV	{"email": "ilya.vlasov.091979@postgrespro.ru", "phone": "+70517217465"}
0005435438235	592CEA	4812 172508	EVGENIY BARANOV	{"phone": "+70006480625"}
0005435438236	0912A2	2440 544727	MARINA DANILOVA	{"phone": "+70695537784"}
0005435438237	0912A2	5986 661849	IRINA BORISOVA	{"email": "irina-borisova07041978@postgrespro.ru", "phone": "+70143233035"}
0005435438238	C7518C	0857 286015	OLEG STEPANOV	{"email": "stepanov_o_10121964@postgrespro.ru", "phone": "+70178974004"}
0005435438239	262F57	9026 886016	GAGIK ROMANOV	{"email": "gagik.romanov081978@postgrespro.ru", "phone": "+70281490963"}
0005435438240	262F57	5384 278277	SERGEY STEPANOV	{"email": "s.stepanov1966@postgrespro.ru", "phone": "+70190432458"}
0005435438241	E784C2	2279 545046	ANASTASIYA EFIMOVA	{"phone": "+70646978606"}
0005435438242	0B15E6	9606 795632	GALINA SERGEEVA	{"email": "sergeeva-galina041961@postgrespro.ru", "phone": "+70255291365"}
0005435438243	0B15E6	5262 044721	FEDOR NAZAROV	{"email": "nazarov.f_1961@postgrespro.ru", "phone": "+70989098400"}
0005435438244	2FBD2B	0265 068953	NATALYA ANTONOVA	{"email": "antonovan.12121979@postgrespro.ru", "phone": "+70100327248"}
0005435438245	EF0B21	6262 692811	ALEKSANDR VOLKOV	{"email": "volkov-a-101962@postgrespro.ru", "phone": "+70169143209"}
0005435438246	0B08D8	8187 986054	NIKITA KUZNECOV	{"email": "kuznecovnikita1965@postgrespro.ru", "phone": "+70170267288"}
0005435438247	425F53	7106 990632	ALEKSANDR NIKOLAEV	{"email": "a-nikolaev.23091968@postgrespro.ru", "phone": "+70855617407"}
0005435438248	425F53	2454 792369	SVETLANA DANILOVA	{"phone": "+70978821619"}
0005435438249	7AC3E6	2209 000612	ANATOLIY YAKOVLEV	{"email": "anatoliyyakovlev22031973@postgrespro.ru", "phone": "+70433539485"}
0005435438250	DFEAE8	9481 808716	OLEG VOROBEV	{"phone": "+70583605152"}
0005435438251	DFEAE8	8066 797018	SVETLANA TIKHONOVA	{"phone": "+70372688971"}
0005435438252	091229	6619 419462	IVAN IVANOV	{"phone": "+70562614783"}
0005435438253	B168C8	9635 760418	ILYA NIKITIN	{"email": "nikitin-ilya.121976@postgrespro.ru", "phone": "+70817883451"}
0005435438254	B168C8	6143 974697	SERGEY MIKHAYLOV	{"email": "mikhaylovsergey-30041965@postgrespro.ru", "phone": "+70260277758"}
0005435438255	FF9314	8645 793523	OLGA OVCHINNIKOVA	{"phone": "+70826357344"}
0005435438256	FF9314	3147 834129	RUSLAN SIDOROV	{"email": "sidorov.r-1972@postgrespro.ru", "phone": "+70271733595"}
0005435438257	FF9314	6381 957050	ALEKSANDRA SEMENOVA	{"phone": "+70323397846"}
0005435438258	5A38E7	6160 952184	VIKTOR FILIPPOV	{"email": "filippov.v1958@postgrespro.ru", "phone": "+70770381513"}
0005435438259	85B25E	8249 330830	ALEKSANDR VOROBEV	{"email": "vorobev_aleksandr.21021978@postgrespro.ru", "phone": "+70833001602"}
0005435438260	85B25E	2637 918545	VLADIMIR AFANASEV	{"phone": "+70305526587"}
0005435438261	CCD297	5445 145839	ELENA POPOVA	{"email": "e-popova-22061974@postgrespro.ru", "phone": "+70556706364"}
0005435438262	D09F2C	2200 533362	MAKSIM SIDOROV	{"email": "msidorov-29071961@postgrespro.ru", "phone": "+70574603610"}
0005435438263	D39552	8775 586897	NATALYA MOISEEVA	{"phone": "+70043478239"}
0005435438264	C91CAB	2344 743832	LYUBOV IVANOVA	{"phone": "+70787968921"}
0005435438265	C91CAB	6839 630803	ALEKSANDR VASILEV	{"email": "vasilev_a_101964@postgrespro.ru", "phone": "+70844175629"}
0005435438266	440297	5658 025691	ANNA MARTYNOVA	{"email": "martynova_a-1958@postgrespro.ru", "phone": "+70550000901"}
0005435438267	440297	9298 398512	ALEKSANDR SIDOROV	{"email": "a-sidorov.1970@postgrespro.ru", "phone": "+70717479822"}
0005435438268	370882	7073 758631	ARINA BORISOVA	{"phone": "+70196258567"}
0005435438269	D90AF4	6418 877284	RAISA ANISIMOVA	{"email": "raisaanisimova_1969@postgrespro.ru", "phone": "+70014944828"}
0005435438270	33EFF3	8204 227586	SERGEY STEPANOV	{"email": "sergey.stepanov.081977@postgrespro.ru", "phone": "+70228396087"}
0005435438271	5F4D23	9850 234959	IRINA MIRONOVA	{"phone": "+70596598351"}
0005435438272	E6C6FD	6139 946468	ANNA OSIPOVA	{"phone": "+70110553656"}
0005435438273	E6C6FD	8199 171850	DANILA DMITRIEV	{"email": "dmitriev.d_1969@postgrespro.ru", "phone": "+70636128355"}
0005435438274	841FBA	5276 180975	VIKTORIYA IVANOVA	{"email": "viktoriya.ivanova_081963@postgrespro.ru", "phone": "+70703363167"}
0005435438275	FC4D8F	9920 605339	TATYANA NIKOLAEVA	{"email": "tatyana-nikolaeva-1979@postgrespro.ru", "phone": "+70757934916"}
0005435438276	FC4D8F	5778 511534	ALEKSEY VOROBEV	{"phone": "+70983937211"}
0005435438277	FA604C	7458 573695	NADEZHDA MELNIKOVA	{"phone": "+70420095993"}
0005435438278	343CA3	6800 852215	ANDREY KUZNECOV	{"phone": "+70569116708"}
0005435438279	343CA3	5344 873448	EVGENIY FEDOTOV	{"phone": "+70291293245"}
0005435438280	3D06A8	2458 591166	ROMAN SMIRNOV	{"phone": "+70609342099"}
0005435438281	05C46B	7891 245700	ANNA KUZNECOVA	{"email": "kuznecova.anna.1974@postgrespro.ru", "phone": "+70971935319"}
0005435438282	666776	6598 000719	ANASTASIYA OSIPOVA	{"phone": "+70329975174"}
0005435438283	0D7E37	3369 501420	ALLA EGOROVA	{"phone": "+70561526864"}
0005435438284	0D7E37	2122 030969	NATALYA ORLOVA	{"phone": "+70920616693"}
0005435438285	AA888A	6639 343428	ANNA STEPANOVA	{"email": "anna.stepanova1976@postgrespro.ru", "phone": "+70688385376"}
0005435438286	BA2395	8225 675631	OKSANA BELOVA	{"email": "belova_oksana091972@postgrespro.ru", "phone": "+70307766726"}
0005435438287	6F1623	1065 228147	ILYA ABRAMOV	{"phone": "+70568804065"}
0005435438288	A50577	1871 526290	ILYA KUZNECOV	{"phone": "+70993774275"}
0005435438289	259495	8040 590466	ANNA OSIPOVA	{"phone": "+70951319337"}
0005435438290	147D97	2807 417564	OLGA RYABOVA	{"email": "ryabovao27041974@postgrespro.ru", "phone": "+70199367040"}
0005435438291	147D97	6113 194114	VENERA ALEKSANDROVA	{"phone": "+70830059184"}
0005435438292	1B5A53	2327 084737	SERGEY NIKOLAEV	{"phone": "+70774478538"}
0005435438293	4ACEC7	2748 011355	LYUDMILA ROMANOVA	{"phone": "+70093443740"}
0005435438294	E7368B	2240 437380	DANILA TIMOFEEV	{"phone": "+70916964108"}
0005435438295	F3B319	9484 389689	EGOR MAKAROV	{"email": "e_makarov_1976@postgrespro.ru", "phone": "+70113552050"}
0005435438296	E68DE8	4405 487873	DMITRIY VOROBEV	{"email": "dvorobev.1988@postgrespro.ru", "phone": "+70574598795"}
0005435438297	E68DE8	5500 744025	NIKOLAY SAVELEV	{"email": "savelevnikolay-08061968@postgrespro.ru", "phone": "+70797949662"}
0005435438298	54D87D	0454 776615	VIKTORIYA ZAYCEVA	{"phone": "+70337829852"}
0005435438299	48E384	0138 444812	SERGEY KUZNECOV	{"phone": "+70518511626"}
0005435438300	48E384	9553 303106	VALENTINA IVANOVA	{"email": "ivanova.v.28121968@postgrespro.ru", "phone": "+70519492483"}
0005435438301	43D110	1990 255737	VALENTINA SAVELEVA	{"email": "saveleva.valentina17091977@postgrespro.ru", "phone": "+70242372793"}
0005435438302	43D110	6738 813497	OLGA MAKAROVA	{"email": "makarova_olga08081979@postgrespro.ru", "phone": "+70517114985"}
0005435438303	08EB24	4645 682804	TAMARA KARPOVA	{"phone": "+70485249784"}
0005435438304	46E44B	0562 640421	ALBINA DAVYDOVA	{"email": "albina-davydova_26091963@postgrespro.ru", "phone": "+70469761669"}
0005435438305	A9B912	3969 463226	PAVEL ZHUKOV	{"email": "pavelzhukov.1976@postgrespro.ru", "phone": "+70234219370"}
0005435438306	7FFEB7	4765 215521	VALERIYA DENISOVA	{"phone": "+70059583280"}
0005435438307	D146D7	1408 955866	VALERIY VASILEV	{"phone": "+70841011739"}
0005435438308	0375E8	9775 802604	YURIY GUSEV	{"phone": "+70720569123"}
0005435438309	4DB877	6130 532747	TAISIYA KULIKOVA	{"phone": "+70025625377"}
0005435438310	B92B97	0411 455655	IRINA FADEEVA	{"phone": "+70117968248"}
0005435438311	2CA354	7867 946664	NIKOLAY IVANOV	{"email": "ivanov_n-06021975@postgrespro.ru", "phone": "+70886463248"}
0005435438312	59D480	5995 807544	ELENA KOROLEVA	{"email": "e-koroleva_1965@postgrespro.ru", "phone": "+70797246682"}
0005435438313	59D480	4350 408583	VALERIY EGOROV	{"email": "valeriy.egorov20051966@postgrespro.ru", "phone": "+70622500935"}
0005435438314	5E33FC	0061 258596	LILIYA BARANOVA	{"phone": "+70877199745"}
0005435438315	4F1824	3382 039510	LIDIYA IVANOVA	{"email": "l-ivanova.13021982@postgrespro.ru", "phone": "+70259517462"}
0005435438316	4F1824	1502 783995	RIMMA MOROZOVA	{"email": "rimmamorozova.19091974@postgrespro.ru", "phone": "+70638285657"}
0005435438317	BEE865	5530 668040	VIKTORIYA SOKOLOVA	{"phone": "+70324552755"}
0005435438318	1AB981	5158 851547	VALENTIN SOLOVEV	{"phone": "+70452326067"}
0005435438319	B126C6	9282 743491	ANASTASIYA ZHUKOVA	{"phone": "+70077567993"}
0005435438320	1FE429	2031 971842	NINEL BELOVA	{"email": "n-belova.04101984@postgrespro.ru", "phone": "+70475535068"}
0005435438321	494344	6825 992010	LIDIYA ISAEVA	{"email": "isaeval.1977@postgrespro.ru", "phone": "+70724442246"}
0005435438322	494344	5042 712571	BORIS KUZNECOV	{"phone": "+70505783504"}
0005435438323	9C113A	6901 126854	TATYANA NIKITINA	{"email": "nikitina.tatyana25091975@postgrespro.ru", "phone": "+70889950557"}
0005435438324	657F06	7197 538818	EVGENIY FEDOROV	{"email": "evgeniy_fedorov.061975@postgrespro.ru", "phone": "+70585080936"}
0005435438325	657F06	2676 877763	LYUBOV TARASOVA	{"email": "tarasova_lyubov-16091967@postgrespro.ru", "phone": "+70232025676"}
0005435438326	AC51EE	7196 772114	OLGA GORBUNOVA	{"email": "o.gorbunova.121984@postgrespro.ru", "phone": "+70728714087"}
0005435438327	AC51EE	6833 173823	LYUBOV DAVYDOVA	{"email": "davydoval.061969@postgrespro.ru", "phone": "+70905753145"}
0005435438328	AC51EE	6136 644261	NIKITA NIKOLAEV	{"phone": "+70929388715"}
0005435438329	84A365	2506 307679	ALEKSEY BONDARENKO	{"phone": "+70917980171"}
0005435438330	70BFFE	1058 588724	IVAN TARASOV	{"email": "ivantarasov-081973@postgrespro.ru", "phone": "+70171452268"}
0005435438331	48CC77	1914 178623	ALEKSANDR IVANOV	{"phone": "+70461470121"}
0005435438332	48CC77	6113 524918	ANDREY DMITRIEV	{"phone": "+70802934186"}
0005435438333	FB3A3D	4225 711410	ANNA KOMAROVA	{"phone": "+70891171753"}
0005435438334	3D8F82	1150 380200	VALENTINA KUZNECOVA	{"phone": "+70519282117"}
0005435438335	4D8158	3757 803119	DMITRIY VASILEV	{"phone": "+70092136589"}
0005435438336	4D8158	9614 750232	MARINA RODIONOVA	{"phone": "+70317523036"}
0005435438337	F9D8C9	0121 414322	LYUBOV FEDOROVA	{"phone": "+70174814735"}
0005435438338	D73EC1	1139 715037	ELENA MATVEEVA	{"phone": "+70502826993"}
0005435438339	2AAF30	1147 922897	ALEKSANDR MIRONOV	{"phone": "+70962828534"}
0005435438340	8A7772	2006 794738	OLGA KUZMINA	{"email": "kuzminaolga06021971@postgrespro.ru", "phone": "+70780459197"}
0005435438341	CF76BC	4256 106614	ZOYA GUSEVA	{"phone": "+70398714011"}
0005435438342	CF76BC	3437 306075	ELENA IVANOVA	{"phone": "+70155275162"}
0005435438343	1F25EC	7343 580943	ALEKSANDRA MAKAROVA	{"phone": "+70901505752"}
0005435438344	1F25EC	5402 822821	ANNA STEPANOVA	{"email": "stepanova_a.1969@postgrespro.ru", "phone": "+70399281193"}
0005435438345	88755D	0522 884662	NADEZHDA KUZNECOVA	{"phone": "+70445004310"}
0005435438346	88755D	6421 623276	TATYANA RODIONOVA	{"email": "rodionovatatyana.011964@postgrespro.ru", "phone": "+70696071953"}
0005435438347	4E198D	0713 792471	ALEKSEY FROLOV	{"email": "a-frolov-011972@postgrespro.ru", "phone": "+70296502148"}
0005435438348	DE69BD	6614 598981	YURIY SCHERBAKOV	{"phone": "+70951654475"}
0005435438349	DE69BD	7296 062077	MARINA LUKYANOVA	{"phone": "+70203652707"}
0005435438350	AC87EC	7030 042646	IVAN SHEVCHENKO	{"phone": "+70403881711"}
0005435438351	AC87EC	9864 965189	ELENA NIKOLAEVA	{"email": "elena.nikolaeva_091969@postgrespro.ru", "phone": "+70308429006"}
0005435438352	C2A525	8456 229505	YULIYA MIRONOVA	{"email": "mironovay.03061985@postgrespro.ru", "phone": "+70527361978"}
0005435438353	F23CDF	2086 040254	SERGEY VOROBEV	{"email": "vorobev.sergey-28011972@postgrespro.ru", "phone": "+70598348153"}
0005435438354	F23CDF	3250 471618	VLADIMIR ORLOV	{"phone": "+70305983431"}
0005435438355	F01380	6581 910711	GALINA KUZMINA	{"email": "galina_kuzmina121971@postgrespro.ru", "phone": "+70156633618"}
0005435438356	05D622	7541 854140	NATALYA NESTEROVA	{"phone": "+70280496154"}
0005435438357	08E346	6571 277045	ELIZAVETA FEDOROVA	{"email": "fedorova-elizaveta071980@postgrespro.ru", "phone": "+70991339768"}
0005435438358	DDB5BC	1385 496816	PAVEL MOISEEV	{"email": "moiseev_pavel1970@postgrespro.ru", "phone": "+70402481396"}
0005435438359	B39C2D	2369 081588	PAVEL RODIONOV	{"email": "pavel-rodionov-29111971@postgrespro.ru", "phone": "+70422804039"}
0005435438360	59964A	9248 610062	EVGENIYA NIKITINA	{"email": "nikitina.evgeniya_1971@postgrespro.ru", "phone": "+70475862255"}
0005435438361	FFF0FC	0527 727831	NATALYA ARKHIPOVA	{"phone": "+70282636369"}
0005435438362	FFA5E4	7146 262113	LYUDMILA KOZLOVA	{"phone": "+70651565131"}
0005435438363	0F0756	1504 912065	VALENTINA MOISEEVA	{"email": "moiseeva-valentina-031973@postgrespro.ru", "phone": "+70616595027"}
0005435438364	0F0756	6038 642035	VIKTOR SOKOLOV	{"phone": "+70468914700"}
0005435438365	A5CFF9	7527 964357	VALENTIN NOVIKOV	{"email": "valentin-novikov.1971@postgrespro.ru", "phone": "+70857841798"}
0005435438366	A5CFF9	5454 275544	NADEZHDA VOLKOVA	{"email": "nadezhda.volkova.21021971@postgrespro.ru", "phone": "+70568953309"}
0005435438367	A5CFF9	7709 601059	ALEKSANDR SAVELEV	{"email": "savelevaleksandr1981@postgrespro.ru", "phone": "+70439443060"}
0005435438368	A5CFF9	3684 344119	YULIYA FROLOVA	{"phone": "+70966844508"}
0005435438369	449076	2288 237475	EVGENIY GAVRILOV	{"phone": "+70044704130"}
0005435438370	E4942A	7404 603643	NATALIYA SOROKINA	{"email": "sorokinanataliya-071961@postgrespro.ru", "phone": "+70652532586"}
0005435438371	812099	4754 404736	VALENTINA POPOVA	{"email": "vpopova22091972@postgrespro.ru", "phone": "+70155705267"}
0005435438372	FD10CA	7670 371550	KLAVDIYA YAKOVLEVA	{"email": "klavdiyayakovleva-16111975@postgrespro.ru", "phone": "+70637775331"}
0005435438373	FD10CA	7126 907796	IVAN KRASNOV	{"email": "ivan_krasnov.15031978@postgrespro.ru", "phone": "+70299001623"}
0005435438374	FD10CA	1926 902118	ANDREY ZAKHAROV	{"phone": "+70523325088"}
0005435438375	C65474	2946 881425	SERGEY ROMANOV	{"email": "romanov-s-1980@postgrespro.ru", "phone": "+70977793036"}
0005435438376	208C63	9978 423323	TATYANA SEMENOVA	{"email": "t-semenova061977@postgrespro.ru", "phone": "+70522713089"}
0005435438377	C18C91	0918 693712	ANNA MOISEEVA	{"phone": "+70068129377"}
0005435438378	C18C91	3274 037220	TATYANA GUSEVA	{"phone": "+70239886696"}
0005435438379	05E816	9849 133646	GENNADIY TIMOFEEV	{"phone": "+70478165623"}
0005435438380	05E816	4012 913634	NIKOLAY MIKHAYLOV	{"email": "nikolay_mikhaylov081970@postgrespro.ru", "phone": "+70827523092"}
0005435438381	08D07A	4073 065338	VLADISLAV DAVYDOV	{"email": "davydov_vladislav.28041973@postgrespro.ru", "phone": "+70137760348"}
0005435438382	D12A52	2530 729813	VLADIMIR SOROKIN	{"email": "vladimir_sorokin1973@postgrespro.ru", "phone": "+70326133951"}
0005435438383	6D4732	9636 802386	NADEZHDA MARTYNOVA	{"phone": "+70395602216"}
0005435438384	1501CA	4778 572938	VALENTINA SERGEEVA	{"phone": "+70839388216"}
0005435438385	A1253E	0909 904118	SERGEY KUZNECOV	{"phone": "+70210430855"}
0005435438386	C5B23A	2052 363681	OLGA SCHERBAKOVA	{"phone": "+70124627637"}
0005435438387	C5B23A	4811 932118	ELENA ANTONOVA	{"email": "antonova_e_11031973@postgrespro.ru", "phone": "+70036330145"}
0005435438388	F7AAFC	8538 376552	DMITRIY MARTYNOV	{"email": "d_martynov-031969@postgrespro.ru", "phone": "+70129328725"}
0005435438389	0062DB	3620 057950	TATYANA KRASNOVA	{"email": "t-krasnova_04101972@postgrespro.ru", "phone": "+70084294817"}
0005435438390	48F505	8556 990043	EVGENIY CHERNOV	{"email": "echernov.011983@postgrespro.ru", "phone": "+70934067521"}
0005435438391	48F505	5700 376790	VIKTOR SIDOROV	{"phone": "+70238563335"}
0005435438503	5BAF42	8376 292108	SERGEY KUZNECOV	{"phone": "+70241423377"}
0005435438392	3E1BB7	0367 875926	ALEKSANDRA NIKITINA	{"email": "nikitinaaleksandra-31101956@postgrespro.ru", "phone": "+70878083572"}
0005435438393	3E1BB7	2227 871696	NATALIYA KOZLOVA	{"phone": "+70062208741"}
0005435438394	9006DD	6453 840378	VYACHESLAV CHERNOV	{"email": "chernov_vyacheslav.29031969@postgrespro.ru", "phone": "+70357805668"}
0005435438395	9006DD	0598 409466	TATYANA SCHERBAKOVA	{"email": "scherbakova-tatyana_13051974@postgrespro.ru", "phone": "+70194816738"}
0005435438396	F44575	8945 582478	POLINA POTAPOVA	{"email": "p-potapova_1970@postgrespro.ru", "phone": "+70934990645"}
0005435438397	72FBCC	5026 463716	ALISA KONDRATEVA	{"phone": "+70402490346"}
0005435438398	B29FC2	1986 936245	TATYANA GUSEVA	{"email": "tatyana-guseva_1979@postgrespro.ru", "phone": "+70485740052"}
0005435438399	C61B2A	9933 791695	GALINA KUZNECOVA	{"phone": "+70632624000"}
0005435438400	B1D861	6575 364102	GENNADIY BORISOV	{"email": "gborisov_29101975@postgrespro.ru", "phone": "+70973537486"}
0005435438401	1666AA	3424 199293	ZOYA FROLOVA	{"phone": "+70234669447"}
0005435438402	1666AA	7239 752337	ALEKSANDR GERASIMOV	{"email": "aleksandr.gerasimov1981@postgrespro.ru", "phone": "+70094773118"}
0005435438403	001B68	3923 611305	NIKOLAY AFANASEV	{"email": "nikolay.afanasev09031970@postgrespro.ru", "phone": "+70523040760"}
0005435438404	001B68	4619 170822	ELENA IVANOVA	{"email": "elena_ivanova_011975@postgrespro.ru", "phone": "+70449687006"}
0005435438405	E6281F	0575 477487	ILYA NIKOLAEV	{"email": "ilya.nikolaev.1958@postgrespro.ru", "phone": "+70087216828"}
0005435438406	FC4DBC	1583 575940	NINA MARTYNOVA	{"phone": "+70119148619"}
0005435438407	0C6332	0589 791734	VITALIY MAKAROV	{"email": "vitaliy-makarov-101967@postgrespro.ru", "phone": "+70030930447"}
0005435438408	8F1CAE	9906 151666	IGOR ZAYCEV	{"phone": "+70964446205"}
0005435438409	612B38	5165 812188	TATYANA MARTYNOVA	{"email": "tatyana_martynova.22061978@postgrespro.ru", "phone": "+70866294988"}
0005435438410	612B38	6306 452076	NATALYA FOMINA	{"phone": "+70800403935"}
0005435438411	0D6564	8757 493444	KONSTANTIN SERGEEV	{"email": "ksergeev.1964@postgrespro.ru", "phone": "+70350495268"}
0005435438412	8FF688	4001 964847	IRINA ALEKSEEVA	{"email": "alekseeva_i041975@postgrespro.ru", "phone": "+70621586748"}
0005435438413	C008EF	4486 982994	ANATOLIY KUZNECOV	{"email": "a.kuznecov03021968@postgrespro.ru", "phone": "+70942704109"}
0005435438414	DE6D53	8366 679550	PAVEL SMIRNOV	{"phone": "+70279168514"}
0005435438415	882FD3	5125 118579	ANTONINA POPOVA	{"phone": "+70220427719"}
0005435438416	882FD3	6970 960491	ALEKSANDR MOISEEV	{"email": "moiseev.a-12031974@postgrespro.ru", "phone": "+70047274532"}
0005435438417	AA3846	6251 405972	OKSANA TARASOVA	{"email": "tarasovaoksana_1960@postgrespro.ru", "phone": "+70920378044"}
0005435438418	C93D64	1653 552100	MIKHAIL DENISOV	{"phone": "+70854830591"}
0005435438419	14E63C	8040 463162	MARIYA IVANOVA	{"phone": "+70410043936"}
0005435438420	8A9C2C	4298 827014	TATYANA SEMENOVA	{"email": "semenova-t081972@postgrespro.ru", "phone": "+70534757452"}
0005435438421	8A9C2C	1399 613568	NIKITA VLASOV	{"email": "nvlasov-081966@postgrespro.ru", "phone": "+70806270942"}
0005435438422	A1C6A6	5820 913693	SVETLANA KONDRATEVA	{"email": "kondrateva.svetlana.10041978@postgrespro.ru", "phone": "+70868902507"}
0005435438423	68F99A	8259 865787	ALEKSANDR SAVELEV	{"phone": "+70727673196"}
0005435438424	5C90E2	1083 493770	ANASTASIYA PETROVA	{"phone": "+70166786562"}
0005435438425	F332AC	6727 888884	SVETLANA ZHUKOVA	{"phone": "+70162943309"}
0005435438426	F332AC	7408 369438	LIDIYA IVANOVA	{"phone": "+70540462540"}
0005435438427	02D3DA	0800 751423	EDUARD MIKHAYLOV	{"phone": "+70361813575"}
0005435438428	ACED2C	0798 677606	SVETLANA MARTYNOVA	{"phone": "+70323791325"}
0005435438429	AEF365	9318 220808	YURIY PAVLOV	{"email": "y-pavlov061976@postgrespro.ru", "phone": "+70933878875"}
0005435438430	7B3957	1663 240417	VALERIYA FILIPPOVA	{"phone": "+70041422285"}
0005435438431	7042F7	4850 728571	IRINA KAZAKOVA	{"email": "kazakovairina-01041975@postgrespro.ru", "phone": "+70160843197"}
0005435438432	7042F7	5516 076192	EGOR ZAYCEV	{"phone": "+70059211174"}
0005435438433	5D2094	3783 102233	GALINA FROLOVA	{"email": "frolovagalina-21031976@postgrespro.ru", "phone": "+70687827437"}
0005435438434	5D2094	5857 221857	ANTONINA DMITRIEVA	{"email": "dmitrievaa-1966@postgrespro.ru", "phone": "+70690118860"}
0005435438435	1D9929	1477 065278	DMITRIY MIRONOV	{"email": "d_mironov1970@postgrespro.ru", "phone": "+70683231725"}
0005435438436	9E7FBC	3397 574943	RAMAZAN ILIN	{"phone": "+70986986604"}
0005435438437	9E7FBC	3484 442532	EVGENIY FROLOV	{"phone": "+70478247185"}
0005435438438	A12284	7226 222873	SERGEY SAVELEV	{"phone": "+70219545482"}
0005435438439	A12284	8215 495041	VLADIMIR ZHURAVLEV	{"email": "zhuravlev-vladimir.091966@postgrespro.ru", "phone": "+70157843733"}
0005435438440	C62359	4873 528694	ANASTASIYA KOROLEVA	{"email": "anastasiya-koroleva-17021971@postgrespro.ru", "phone": "+70741285142"}
0005435438441	C62359	7662 047907	DENIS FEDOTOV	{"phone": "+70146170574"}
0005435438442	7DE974	9628 060637	EVGENIY CHERNOV	{"email": "chernovevgeniy-101980@postgrespro.ru", "phone": "+70536684065"}
0005435438443	7DE974	4588 067916	VLADIMIR GERASIMOV	{"email": "vladimir.gerasimov.061972@postgrespro.ru", "phone": "+70044115861"}
0005435438444	59D1FD	4672 592561	ELENA SEMENOVA	{"phone": "+70624291458"}
0005435438445	59D1FD	0147 891439	VALENTINA VLASOVA	{"email": "vlasova.v_1976@postgrespro.ru", "phone": "+70059964353"}
0005435438446	47273C	1438 028030	OLEG PETROV	{"email": "petrov-oleg-03091970@postgrespro.ru", "phone": "+70874390888"}
0005435438447	5CDEDC	2594 789539	LYUDMILA ALEKSANDROVA	{"phone": "+70775949196"}
0005435438448	B04F5D	4311 261774	EVGENIYA NIKITINA	{"phone": "+70429151063"}
0005435438449	380386	8213 785793	MIKHAIL KOROLEV	{"email": "korolev-m.061969@postgrespro.ru", "phone": "+70024025464"}
0005435438450	380386	0774 809567	IRINA MAKAROVA	{"phone": "+70120882592"}
0005435438451	1B2124	0165 073747	ARTEM NOVIKOV	{"email": "novikovartem26011976@postgrespro.ru", "phone": "+70919215468"}
0005435438452	10C1B8	0602 984321	MAKSIM FOMIN	{"phone": "+70865346172"}
0005435438453	10C1B8	2561 720513	VLADIMIR MARTYNOV	{"email": "martynov.vladimir-061971@postgrespro.ru", "phone": "+70165770057"}
0005435438454	F69F20	9701 157102	NADEZHDA ALEKSEEVA	{"phone": "+70969492018"}
0005435438455	D564D2	1921 830784	ALEKSEY ISAEV	{"email": "isaev_aleksey111975@postgrespro.ru", "phone": "+70909958355"}
0005435438456	D564D2	6114 996159	NADEZHDA ANDREEVA	{"email": "andreeva.nadezhda.1966@postgrespro.ru", "phone": "+70608793471"}
0005435438457	2FBCC7	4043 695831	OLGA TIKHONOVA	{"email": "o-tikhonova-071974@postgrespro.ru", "phone": "+70507629061"}
0005435438458	9A4058	7430 393714	VALENTINA PAVLOVA	{"email": "v.pavlova111970@postgrespro.ru", "phone": "+70783639851"}
0005435438459	9BEEBE	8874 158026	OLEG IVANOV	{"phone": "+70565367017"}
0005435438460	9BEEBE	5810 161798	PAVEL KISELEV	{"phone": "+70410614581"}
0005435438461	3D4D6B	8616 416039	ALEKSANDRA ANTONOVA	{"phone": "+70897082356"}
0005435438462	0E5DA2	2163 642909	DANIL SMIRNOV	{"email": "d.smirnov-1979@postgrespro.ru", "phone": "+70756205777"}
0005435438463	04DE07	6737 776015	ANZHELA DMITRIEVA	{"email": "anzhela.dmitrieva-19021968@postgrespro.ru", "phone": "+70699792220"}
0005435438464	C05A97	7853 328789	ANTONINA KOLESNIKOVA	{"email": "a_kolesnikova_031985@postgrespro.ru", "phone": "+70119715889"}
0005435438465	C05A97	2783 991126	ALEKSANDR MAKSIMOV	{"phone": "+70316458254"}
0005435438466	4DACA8	3216 612553	NINA MOISEEVA	{"email": "moiseeva.nina_1964@postgrespro.ru", "phone": "+70179156423"}
0005435438467	677A5E	9008 110291	ARTEM STEPANOV	{"phone": "+70259378533"}
0005435438468	895819	5874 044443	YURIY ANTONOV	{"phone": "+70950003774"}
0005435438469	895819	5617 625281	VALERIYA ZAKHAROVA	{"phone": "+70526033580"}
0005435438470	4FB4DC	5173 251565	OLEG ROMANOV	{"email": "romanovo_1982@postgrespro.ru", "phone": "+70355886255"}
0005435438471	5113CE	1514 794726	KIRILL KUZNECOV	{"email": "k.kuznecov-21101962@postgrespro.ru", "phone": "+70409281039"}
0005435438472	5113CE	8368 782254	OLGA ZAYCEVA	{"email": "olga-zayceva_24011978@postgrespro.ru", "phone": "+70083818893"}
0005435438473	7E6ED9	3476 560338	EVGENIY NOVIKOV	{"phone": "+70516754325"}
0005435438474	7E6ED9	9667 874081	MARIYA FROLOVA	{"email": "frolova_mariya1982@postgrespro.ru", "phone": "+70378912278"}
0005435438475	8FD157	0434 690129	DMITRIY PETROV	{"phone": "+70102319785"}
0005435438476	9610C8	9745 308898	TATYANA ANDREEVA	{"email": "t_andreeva1965@postgrespro.ru", "phone": "+70096082636"}
0005435438477	972F26	2912 907995	ALEKSANDR FEDOROV	{"phone": "+70259199434"}
0005435438478	863B8B	9064 974422	VITALIY MOROZOV	{"phone": "+70548262386"}
0005435438479	66A8A2	0667 698583	IRINA KONOVALOVA	{"email": "irina-konovalova.121969@postgrespro.ru", "phone": "+70593535322"}
0005435438480	66A8A2	4003 934663	OLGA CHERNOVA	{"email": "o-chernova071968@postgrespro.ru", "phone": "+70023640674"}
0005435438481	193D54	4005 886670	SERGEY VASILEV	{"email": "vasilev-s1972@postgrespro.ru", "phone": "+70634822835"}
0005435438482	A74B1F	2526 404510	VITALIY STEPANOV	{"phone": "+70994001364"}
0005435438483	DDB990	5264 332349	OLESYA LOGINOVA	{"phone": "+70937479992"}
0005435438484	DDB990	2036 554117	RAISA FROLOVA	{"phone": "+70295527137"}
0005435438485	FA5FE6	0131 844919	PETR FEDOROV	{"phone": "+70591520084"}
0005435438486	FA5FE6	2130 318237	TIMUR MELNIKOV	{"phone": "+70799852612"}
0005435438487	D31BD6	2256 544125	ARTEM SMIRNOV	{"phone": "+70345345247"}
0005435438488	4807C5	3492 098136	ANASTASIYA LAZAREVA	{"email": "anastasiyalazareva111973@postgrespro.ru", "phone": "+70080000168"}
0005435438489	30E984	3669 492249	ARTEM FEDOTOV	{"email": "artem.fedotov.1981@postgrespro.ru", "phone": "+70959120029"}
0005435438490	30E984	0477 058266	OKSANA PAVLOVA	{"phone": "+70402965336"}
0005435438491	30E984	5056 953000	ANDREY ABRAMOV	{"phone": "+70923055636"}
0005435438492	D5BB03	1838 389358	EVGENIY GRIGOREV	{"email": "egrigorev.1965@postgrespro.ru", "phone": "+70331540270"}
0005435438493	819B10	7995 980102	EVDOKIYA ORLOVA	{"email": "orlovae071970@postgrespro.ru", "phone": "+70477753733"}
0005435438494	A0D1F4	6987 594444	SVETLANA DENISOVA	{"email": "svetlanadenisova_28121969@postgrespro.ru", "phone": "+70410196506"}
0005435438495	94CA38	8865 095273	VLADIMIR ZHUKOV	{"phone": "+70292300382"}
0005435438496	94CA38	7225 155957	ELENA MOROZOVA	{"email": "morozova.e101972@postgrespro.ru", "phone": "+70978374645"}
0005435438497	6814A9	8964 849977	ELENA PAVLOVA	{"email": "pavlova.e-1964@postgrespro.ru", "phone": "+70855853681"}
0005435438498	6814A9	0342 407507	ALINA VASILEVA	{"email": "vasilevaa1965@postgrespro.ru", "phone": "+70888580997"}
0005435438499	110B4E	5517 713217	VLADIMIR MOROZOV	{"phone": "+70366645900"}
0005435438500	88FC4C	9753 755340	ALEKSANDR KARPOV	{"email": "a.karpov-041971@postgrespro.ru", "phone": "+70703406792"}
0005435438501	88FC4C	1018 677552	EVGENIY GAVRILOV	{"phone": "+70894675918"}
0005435438502	88FC4C	0472 138953	MAKSIM SEMENOV	{"phone": "+70570528432"}
0005435438504	5BAF42	8618 856331	MARIYA NESTEROVA	{"email": "nesterova-m12071971@postgrespro.ru", "phone": "+70626790650"}
0005435438505	8CB25C	9306 913371	ELENA EGOROVA	{"email": "egorova.e_111969@postgrespro.ru", "phone": "+70312140545"}
0005435438506	E2EE52	3963 783497	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr.111974@postgrespro.ru", "phone": "+70307837395"}
0005435438507	F5D308	1768 630979	ELENA ALEKSANDROVA	{"email": "aleksandrova_e-121979@postgrespro.ru", "phone": "+70608370581"}
0005435438508	F5D308	2237 417728	ZOYA MAKSIMOVA	{"phone": "+70024024027"}
0005435438509	397CE2	2514 266863	LIDIYA SAVELEVA	{"phone": "+70007149927"}
0005435438510	ECC8BC	5569 312139	SERGEY KOZLOV	{"email": "kozlovs.20011973@postgrespro.ru", "phone": "+70752413493"}
0005435438511	497983	9270 856286	ANASTASIYA SERGEEVA	{"email": "a-sergeeva-101973@postgrespro.ru", "phone": "+70802187452"}
0005435438512	63339D	3884 203625	ALEKSANDR MIKHAYLOV	{"phone": "+70389786996"}
0005435438513	6396F9	0588 813613	NADEZHDA ZAKHAROVA	{"phone": "+70882391286"}
0005435438514	6396F9	2214 651859	SERGEY NIKITIN	{"email": "nikitinsergey1974@postgrespro.ru", "phone": "+70084294892"}
0005435438515	D05EC6	3123 607187	VITALIY PETROV	{"phone": "+70374318142"}
0005435438516	C045F3	6608 002401	RAISA NIKOLAEVA	{"phone": "+70391572716"}
0005435438517	C045F3	1625 791328	RUSTAM MAKAROV	{"email": "r.makarov041971@postgrespro.ru", "phone": "+70882974544"}
0005435438518	8A091E	4019 454958	NIKOLAY SAVELEV	{"phone": "+70147722447"}
0005435438519	AAF04F	1004 941892	FANIYA KUZNECOVA	{"email": "kuznecova_f_10041971@postgrespro.ru", "phone": "+70153121682"}
0005435438520	477854	2991 917188	TAMARA PETROVA	{"email": "tamara_petrova_1968@postgrespro.ru", "phone": "+70460511991"}
0005435438521	C239F5	6712 728198	VLADIMIR KAZAKOV	{"email": "vladimir_kazakov.071985@postgrespro.ru", "phone": "+70629398266"}
0005435438522	C239F5	8504 905879	ALEKSANDR KUZNECOV	{"phone": "+70882425021"}
0005435438523	C239F5	3804 838385	LARISA SOROKINA	{"email": "sorokina_larisa1975@postgrespro.ru", "phone": "+70479213024"}
0005435438524	F54D37	3252 946357	PAVEL VASILEV	{"email": "vasilev_pavel-121965@postgrespro.ru", "phone": "+70113338664"}
0005435438525	6EA074	8773 767270	ANATOLIY KUZNECOV	{"phone": "+70388865740"}
0005435438526	173419	9871 432463	SVETLANA VLASOVA	{"phone": "+70866519815"}
0005435438527	173419	5340 055216	LYUDMILA GORBUNOVA	{"email": "lyudmila.gorbunova_20051966@postgrespro.ru", "phone": "+70320705237"}
0005435438528	8BAA48	2222 382031	LYUBOV YAKOVLEVA	{"phone": "+70095964352"}
0005435438529	BE0BAB	3770 940047	SERGEY KISELEV	{"phone": "+70440875021"}
0005435438530	2050F7	1689 802067	OLEG KULIKOV	{"email": "kulikovoleg-16031980@postgrespro.ru", "phone": "+70055948284"}
0005435438531	2050F7	2555 752974	GALINA MAKAROVA	{"phone": "+70855165070"}
0005435438532	2050F7	3997 765060	OLGA KUDRYASHOVA	{"email": "olga-kudryashova.041980@postgrespro.ru", "phone": "+70056451830"}
0005435438533	856B3F	3497 095700	SERGEY MOROZOV	{"phone": "+70202557079"}
0005435438534	DE71D5	6708 305560	MARAT FEDOROV	{"phone": "+70662013427"}
0005435438535	395C24	2486 498746	DARYA PAVLOVA	{"phone": "+70208716578"}
0005435438536	395C24	5088 158298	ARTEM ANTONOV	{"phone": "+70045931402"}
0005435438537	395C24	2915 941445	NIKOLAY BARANOV	{"phone": "+70273377750"}
0005435438538	14F782	5017 041850	NIKITA FROLOV	{"email": "nikitafrolov_1977@postgrespro.ru", "phone": "+70794168198"}
0005435438539	6E015B	4471 529809	GULNARA GORBUNOVA	{"email": "gorbunova_g_10091987@postgrespro.ru", "phone": "+70879015699"}
0005435438540	2DEFAF	3497 250973	EKATERINA POPOVA	{"email": "popovaekaterina_16121965@postgrespro.ru", "phone": "+70742834479"}
0005435438541	0C3B4B	8602 032897	KRISTINA KUZNECOVA	{"email": "kuznecova-kristina.041982@postgrespro.ru", "phone": "+70580125232"}
0005435438542	F6808A	6897 403345	VIKTORIYA TIKHONOVA	{"email": "tikhonova_v1973@postgrespro.ru", "phone": "+70059531252"}
0005435438543	F6808A	5708 336218	ALEKSANDR ALEKSEEV	{"email": "alekseeva_031969@postgrespro.ru", "phone": "+70797896175"}
0005435438544	FAC3DE	1178 124736	ALEKSANDR VOLKOV	{"phone": "+70925970782"}
0005435438545	FAC3DE	7509 954362	SERGEY EGOROV	{"email": "egorov_sergey_22061978@postgrespro.ru", "phone": "+70178104695"}
0005435438546	6A581C	3484 034228	EKATERINA SMIRNOVA	{"email": "smirnova_ekaterina-021972@postgrespro.ru", "phone": "+70914152571"}
0005435438547	6A581C	3666 740268	ZOYA NOVIKOVA	{"phone": "+70213895063"}
0005435438548	027552	6858 992879	ANTONINA ZAKHAROVA	{"email": "zakharovaa.081961@postgrespro.ru", "phone": "+70797416654"}
0005435438549	027552	9013 895846	VLADIMIR VOROBEV	{"phone": "+70420922905"}
0005435438550	7233F6	3455 081628	SERGEY VASILEV	{"email": "svasilev_1973@postgrespro.ru", "phone": "+70833374655"}
0005435438551	05A1A6	8421 482478	ROMAN ORLOV	{"email": "orlovroman01111954@postgrespro.ru", "phone": "+70713730520"}
0005435438552	FC465E	5700 162594	ELENA ISAEVA	{"email": "isaeva_elena.071973@postgrespro.ru", "phone": "+70287691722"}
0005435438553	FC465E	9781 471236	GALINA ANDREEVA	{"email": "galina-andreeva1961@postgrespro.ru", "phone": "+70495174328"}
0005435438554	FC465E	8429 929598	SOFYA OVCHINNIKOVA	{"phone": "+70353790151"}
0005435438555	97E814	9659 994099	ELENA MATVEEVA	{"email": "matveeva-e-17091976@postgrespro.ru", "phone": "+70580146676"}
0005435438556	AD3DB4	1488 549309	VALERIY SEMENOV	{"phone": "+70707288345"}
0005435438557	AD3DB4	9285 965273	ALEKSEY POPOV	{"email": "a-popov_12031960@postgrespro.ru", "phone": "+70992880806"}
0005435438558	C5B6DE	5319 597065	NIKOLAY VASILEV	{"phone": "+70969362127"}
0005435438559	3A188E	8796 380920	NINA PAVLOVA	{"phone": "+70691410888"}
0005435438560	3A188E	0469 182935	VALENTINA SAVELEVA	{"email": "saveleva_v1974@postgrespro.ru", "phone": "+70412754353"}
0005435438561	3A188E	8365 831480	ANNA BELOVA	{"phone": "+70798148848"}
0005435438562	4FA23D	2855 386665	LYUDMILA PETROVA	{"email": "lpetrova-011967@postgrespro.ru", "phone": "+70253624942"}
0005435438563	4A60F5	0483 938105	MIKHAIL ZHUKOV	{"email": "mikhail_zhukov.22061975@postgrespro.ru", "phone": "+70444416484"}
0005435438564	55A5A7	0387 281700	NADEZHDA NIKITINA	{"email": "nikitinan-24081968@postgrespro.ru", "phone": "+70996943546"}
0005435438565	503023	4735 880862	SVETLANA MAKAROVA	{"phone": "+70146712653"}
0005435438566	AFE3F1	5347 612135	TATYANA BELOVA	{"email": "t_belova-28081975@postgrespro.ru", "phone": "+70916750408"}
0005435438567	AFE3F1	8953 415424	ALINA RYABOVA	{"email": "alina-ryabova.26031969@postgrespro.ru", "phone": "+70204095674"}
0005435438568	55B8FA	8265 962741	ALEKSEY MEDVEDEV	{"email": "medvedev_aleksey_08021961@postgrespro.ru", "phone": "+70426320538"}
0005435438569	8D20EB	2419 775267	ALEKSANDR ZAKHAROV	{"email": "aleksandrzakharov_1979@postgrespro.ru", "phone": "+70871691751"}
0005435438570	7AAA94	7500 954829	YURIY BONDARENKO	{"email": "bondarenko-yuriy_19041971@postgrespro.ru", "phone": "+70129051409"}
0005435438571	99CB92	6389 161064	ANASTASIYA PAVLOVA	{"phone": "+70576446657"}
0005435438572	99CB92	1307 276640	ANDREY KUDRYASHOV	{"phone": "+70376998414"}
0005435438573	B589F4	9469 821604	MARIYA KOZLOVA	{"email": "mariya-kozlova08011962@postgrespro.ru", "phone": "+70374532815"}
0005435438574	B03D65	8437 663239	VASILIY KONOVALOV	{"email": "vkonovalov22101984@postgrespro.ru", "phone": "+70661675506"}
0005435438575	141139	6347 937109	VALENTINA NIKOLAEVA	{"phone": "+70916987557"}
0005435438576	9C5B36	5179 492125	IRINA KRASNOVA	{"phone": "+70856353895"}
0005435438577	C4A013	6101 430854	GALINA NIKOLAEVA	{"phone": "+70611670547"}
0005435438578	724FE1	8416 045782	ALEKSANDR SHEVCHENKO	{"email": "shevchenko_a_1981@postgrespro.ru", "phone": "+70418634583"}
0005435438579	68938E	3970 198417	VALERIYA RODIONOVA	{"email": "v.rodionova13061972@postgrespro.ru", "phone": "+70128959001"}
0005435438580	68938E	1263 619967	MIKHAIL KONOVALOV	{"email": "konovalovm_091965@postgrespro.ru", "phone": "+70778559596"}
0005435438581	2B3184	9068 415752	ELENA DANILOVA	{"phone": "+70597375271"}
0005435438582	0F3018	9563 044695	ANATOLIY SCHERBAKOV	{"phone": "+70110157930"}
0005435438583	88574C	6295 813091	NATALIYA EGOROVA	{"phone": "+70837602097"}
0005435438584	16A345	2005 129174	LYUDMILA KOZLOVA	{"email": "lyudmila.kozlova.1981@postgrespro.ru", "phone": "+70144578914"}
0005435438585	954057	3458 043282	ALEKSANDRA MARTYNOVA	{"phone": "+70213579531"}
0005435438586	132977	0245 634448	KSENIYA MEDVEDEVA	{"phone": "+70221089519"}
0005435438587	A843CD	4137 137129	ALEKSEY DAVYDOV	{"phone": "+70940554850"}
0005435438588	B92457	6570 492146	VALENTINA MIKHAYLOVA	{"email": "mikhaylova_v-1971@postgrespro.ru", "phone": "+70319034936"}
0005435438589	20AF68	8454 221344	ALEKSEY VLASOV	{"email": "vlasov_aleksey_041970@postgrespro.ru", "phone": "+70852884032"}
0005435438590	67CF06	4741 113654	SERGEY SERGEEV	{"email": "ssergeev-1980@postgrespro.ru", "phone": "+70451586834"}
0005435438591	DAD75B	2892 831187	MARGARITA SERGEEVA	{"email": "sergeeva-margarita-1969@postgrespro.ru", "phone": "+70450079178"}
0005435438592	DAD75B	4479 898469	TATYANA ZAYCEVA	{"phone": "+70382517387"}
0005435443144	382174	9084 834476	DMITRIY STEPANOV	{"email": "d-stepanov_1965@postgrespro.ru", "phone": "+70496091803"}
0005435443145	5E4D18	4498 552762	LYUDMILA AKIMOVA	{"email": "akimovalyudmila_1976@postgrespro.ru", "phone": "+70506400572"}
0005435443146	5E4D18	7959 580314	LYUDMILA MARTYNOVA	{"email": "l_martynova09071962@postgrespro.ru", "phone": "+70670663025"}
0005435443147	6DEC79	3172 408049	TATYANA ANDREEVA	{"email": "andreeva-t17011978@postgrespro.ru", "phone": "+70784172520"}
0005435443148	6DEC79	6162 881184	VLADIMIR FROLOV	{"email": "vladimir_frolov.021970@postgrespro.ru", "phone": "+70133116965"}
0005435443149	B8C48C	1121 005751	NINA NAZAROVA	{"email": "nazarova_nina091977@postgrespro.ru", "phone": "+70821901230"}
0005435443150	B8C48C	0132 653856	NATALYA BORISOVA	{"email": "borisova.n-041973@postgrespro.ru", "phone": "+70039437410"}
0005435443151	1B42BE	3272 937443	NADEZHDA KUDRYASHOVA	{"phone": "+70822699831"}
0005435443152	BAC182	3160 100939	SVETLANA KOROLEVA	{"phone": "+70695735679"}
0005435443153	33B9E3	6347 729420	NELLI KOZLOVA	{"phone": "+70141701606"}
0005435443154	AE7079	7426 829226	MARGARITA OSIPOVA	{"email": "osipovamargarita29061971@postgrespro.ru", "phone": "+70509336683"}
0005435443155	AE7079	1286 029082	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov-121969@postgrespro.ru", "phone": "+70857734903"}
0005435443156	04CB82	7577 906813	ANASTASIYA ALEKSANDROVA	{"email": "anastasiya_aleksandrova.1958@postgrespro.ru", "phone": "+70161200095"}
0005435443157	04CB82	0066 131923	PETR GORBUNOV	{"email": "petr.gorbunov11111969@postgrespro.ru", "phone": "+70910129934"}
0005435443158	B72048	5645 035239	RUSLAN BORISOV	{"phone": "+70648757559"}
0005435443159	2D7A9F	2637 379648	GLEB ZHUKOV	{"phone": "+70095486661"}
0005435443160	2D7A9F	1634 774506	ROMAN CHERNOV	{"email": "r_chernov1977@postgrespro.ru", "phone": "+70054436617"}
0005435443161	D90260	5470 906893	EVGENIY MELNIKOV	{"phone": "+70068419864"}
0005435443162	A1070E	7682 489065	ELENA VOROBEVA	{"email": "vorobeva-elena_15041967@postgrespro.ru", "phone": "+70891962727"}
0005435443163	4BCE54	8934 315087	ALEKSANDR BELOV	{"phone": "+70699011633"}
0005435443164	4BCE54	2909 592951	ELENA VLASOVA	{"email": "vlasovaelena.28031970@postgrespro.ru", "phone": "+70155608196"}
0005435443165	4BCE54	7785 781918	SERGEY RODIONOV	{"phone": "+70835031888"}
0005435443166	5C2D1C	1711 042367	ALINA KOZLOVA	{"phone": "+70774940262"}
0005435443167	C0CD03	2821 116856	VLADIMIR EGOROV	{"phone": "+70444236174"}
0005435443168	84D429	5431 434438	VLADIMIR SOLOVEV	{"email": "vladimirsolovev_01071971@postgrespro.ru", "phone": "+70656170035"}
0005435443169	CD726A	3399 666070	OLGA LUKYANOVA	{"phone": "+70702935212"}
0005435443170	CBE143	4559 432040	MARINA NIKITINA	{"email": "marinanikitina_20041972@postgrespro.ru", "phone": "+70398869820"}
0005435443171	CBE143	8414 522938	NINA EFREMOVA	{"email": "efremovanina-1971@postgrespro.ru", "phone": "+70387749409"}
0005435443172	CBE143	8666 542381	NINA IVANOVA	{"email": "nina.ivanova.1960@postgrespro.ru", "phone": "+70088686961"}
0005435443173	48E752	2839 281485	ANNA TARASOVA	{"phone": "+70449040533"}
0005435443174	511AF4	2427 696563	ELENA SOROKINA	{"email": "elena-sorokina121975@postgrespro.ru", "phone": "+70281659680"}
0005435443175	F59990	9269 460361	LEONID PETROV	{"email": "l.petrov.07081979@postgrespro.ru", "phone": "+70023233886"}
0005435443176	A6C127	5634 436658	YURIY DMITRIEV	{"email": "dmitriev_y_1970@postgrespro.ru", "phone": "+70197508973"}
0005435443177	36C0D4	9409 059264	EKATERINA NOVIKOVA	{"email": "novikova_ekaterina_1971@postgrespro.ru", "phone": "+70135244687"}
0005435443178	BABB98	2961 372674	YANA PAVLOVA	{"email": "pavlovayana_1983@postgrespro.ru", "phone": "+70926611393"}
0005435443179	BABB98	4578 636984	KSENIYA STEPANOVA	{"email": "k_stepanova18111983@postgrespro.ru", "phone": "+70141646636"}
0005435443180	A71FB7	7629 596801	VLADISLAV MATVEEV	{"email": "vladislavmatveev_20071979@postgrespro.ru", "phone": "+70897759361"}
0005435443181	A71FB7	4625 526455	NADEZHDA NIKOLAEVA	{"phone": "+70883064621"}
0005435443182	6D3BFF	9549 990206	TATYANA KOROLEVA	{"email": "koroleva-tatyana-1989@postgrespro.ru", "phone": "+70057148503"}
0005435443183	0EAF3A	5712 371388	ANTONINA MATVEEVA	{"phone": "+70269524573"}
0005435443184	ED45B5	2468 076513	SERGEY KOZLOV	{"phone": "+70796199555"}
0005435443185	9E5FE1	7024 079474	LYUDMILA FILATOVA	{"phone": "+70870619252"}
0005435443186	552730	9790 119723	ANATOLIY NIKITIN	{"email": "anatoliy_nikitin1967@postgrespro.ru", "phone": "+70739782006"}
0005435443187	5E08B4	4289 937749	ANATOLIY MAKAROV	{"email": "makarov_a.071990@postgrespro.ru", "phone": "+70816869178"}
0005435443188	E3F888	1652 617786	TATYANA MARTYNOVA	{"email": "martynovat-101979@postgrespro.ru", "phone": "+70637258250"}
0005435443189	6A776F	6513 431147	TATYANA KUZNECOVA	{"email": "t_kuznecova.061976@postgrespro.ru", "phone": "+70007622896"}
0005435443190	6A776F	7846 738657	EVDOKIYA MASLOVA	{"phone": "+70577032887"}
0005435443191	4CAD17	5659 176484	TAMARA TROFIMOVA	{"phone": "+70045488436"}
0005435443192	F6D9DF	5318 298110	KSENIYA ALEKSEEVA	{"phone": "+70953986673"}
0005435443193	F6D9DF	0993 172920	ANNA GUSEVA	{"email": "guseva.a.1979@postgrespro.ru", "phone": "+70380976339"}
0005435443194	CD1A5A	9924 391180	NIKOLAY PAVLOV	{"phone": "+70132004918"}
0005435443195	CC203F	9786 370970	KIRILL STEPANOV	{"email": "stepanovkirill_06121979@postgrespro.ru", "phone": "+70042721201"}
0005435443196	DF7576	1257 462230	SERGEY SOKOLOV	{"email": "sokolovs.11101972@postgrespro.ru", "phone": "+70829367073"}
0005435443197	C1D89C	9404 961581	TATYANA STEPANOVA	{"phone": "+70980119777"}
0005435443198	E85479	7049 809598	GALINA NIKOLAEVA	{"email": "galina.nikolaeva_1968@postgrespro.ru", "phone": "+70073611376"}
0005435443199	BAD7FC	7247 014406	EVGENIY SAVELEV	{"email": "evgeniysavelev.02031982@postgrespro.ru", "phone": "+70677340512"}
0005435443200	966ACE	0623 810533	OKSANA BORISOVA	{"phone": "+70103158931"}
0005435443201	966ACE	5820 547374	ANATOLIY ILIN	{"phone": "+70851237518"}
0005435443202	D01745	2377 823261	EKATERINA SOLOVEVA	{"email": "soloveva.ekaterina1967@postgrespro.ru", "phone": "+70108906000"}
0005435443203	08B2D0	4120 365044	VARVARA TIKHONOVA	{"phone": "+70603139922"}
0005435443204	8E09A5	9939 894866	IGOR SEMENOV	{"phone": "+70490901365"}
0005435443205	2BD718	7475 996831	NINA EGOROVA	{"phone": "+70706686835"}
0005435443206	2BD718	3133 583259	MAKSIM ROMANOV	{"phone": "+70360648972"}
0005435443207	FF5A9C	5795 278220	SVETLANA SAVELEVA	{"email": "svetlanasaveleva21051965@postgrespro.ru", "phone": "+70273086017"}
0005435443208	7EA64A	8933 382902	PETR ZAYCEV	{"email": "p-zaycev-1971@postgrespro.ru", "phone": "+70801521351"}
0005435443209	7EA64A	7837 143534	NATALYA TARASOVA	{"email": "tarasova.n.1970@postgrespro.ru", "phone": "+70353741153"}
0005435443210	B23480	8069 019475	NIKOLAY BORISOV	{"email": "borisovnikolay071977@postgrespro.ru", "phone": "+70124706807"}
0005435443211	D193EA	0376 343422	ELENA STEPANOVA	{"phone": "+70552818069"}
0005435443212	D193EA	4683 774108	GALINA IVANOVA	{"email": "givanova_18041969@postgrespro.ru", "phone": "+70176365014"}
0005435443213	B71602	5407 776512	VLADISLAV SMIRNOV	{"phone": "+70720534761"}
0005435443214	187E0E	3150 878011	ALEKSEY MOROZOV	{"phone": "+70907438105"}
0005435443215	C954BB	6534 651728	MARIYA ERMAKOVA	{"phone": "+70395147933"}
0005435443216	D57ABB	0685 247335	ELENA VASILEVA	{"email": "elenavasileva_23111966@postgrespro.ru", "phone": "+70918619670"}
0005435443217	D57ABB	5365 530823	YURIY GORBUNOV	{"email": "yuriy_gorbunov_1981@postgrespro.ru", "phone": "+70061673188"}
0005435443218	B31D93	7920 838496	SERGEY KUZNECOV	{"email": "kuznecov-sergey_1975@postgrespro.ru", "phone": "+70767352521"}
0005435443219	7CCA99	8787 983827	ALEKSANDR KULIKOV	{"phone": "+70056766538"}
0005435443220	6CDBEA	8644 080410	NINA OVCHINNIKOVA	{"phone": "+70242024925"}
0005435443221	1C7D98	8908 302046	EKATERINA GUSEVA	{"email": "gusevae.081973@postgrespro.ru", "phone": "+70847757912"}
0005435443222	D7436F	1016 899595	YAROSLAV IVANOV	{"phone": "+70427107045"}
0005435443223	A5ACC1	4513 660082	IRAIDA DANILOVA	{"email": "iraida-danilova_091968@postgrespro.ru", "phone": "+70568172922"}
0005435443224	8F3013	9462 316379	LYUBOV ZHURAVLEVA	{"email": "l_zhuravleva.13041974@postgrespro.ru", "phone": "+70217942241"}
0005435443225	8F3013	2311 759231	ANNA FROLOVA	{"email": "a.frolova_011956@postgrespro.ru", "phone": "+70663546273"}
0005435443226	9F3704	6759 021355	SERGEY KAZAKOV	{"email": "sergey.kazakov-06121978@postgrespro.ru", "phone": "+70327804903"}
0005435443227	7B3C75	4749 841772	VLADIMIR DENISOV	{"phone": "+70468686325"}
0005435443228	2F9397	7055 760553	VERA VASILEVA	{"phone": "+70408366583"}
0005435443229	2F9397	2981 956163	YULIYA SOKOLOVA	{"phone": "+70047999403"}
0005435443230	2F9397	0245 404708	PELAGEYA TIMOFEEVA	{"phone": "+70925108437"}
0005435443231	D834D2	6813 201893	NIKOLAY VASILEV	{"email": "nikolay.vasilev1974@postgrespro.ru", "phone": "+70490481277"}
0005435443232	A81C75	4081 646797	KONSTANTIN TIMOFEEV	{"email": "timofeevk-1979@postgrespro.ru", "phone": "+70154857287"}
0005435443233	8B9730	6751 048550	EMIL FROLOV	{"email": "frolove-111983@postgrespro.ru", "phone": "+70365162210"}
0005435443234	1CCC1B	2092 436104	MAKSIM VOLKOV	{"phone": "+70025209329"}
0005435443235	A2C97C	5687 248065	VLADIMIR MIKHAYLOV	{"email": "v_mikhaylov-10021968@postgrespro.ru", "phone": "+70721773023"}
0005435443236	A2C97C	6610 481489	SERGEY BARANOV	{"email": "sbaranov-1982@postgrespro.ru", "phone": "+70483220731"}
0005435443237	62FB4D	2941 103425	EGOR BONDARENKO	{"phone": "+70538435897"}
0005435443238	011E40	5248 928703	NIKITA ISAEV	{"phone": "+70376361290"}
0005435443239	5476CD	4026 686947	VASILIY PETROV	{"phone": "+70486541992"}
0005435443240	5476CD	9319 114099	VYACHESLAV MATVEEV	{"email": "matveev.vyacheslav-06031971@postgrespro.ru", "phone": "+70029931836"}
0005435443241	5476CD	8044 425537	NATALYA BELOVA	{"email": "n.belova01071966@postgrespro.ru", "phone": "+70535945635"}
0005435443242	77C5B3	9810 230700	YANINA IVANOVA	{"phone": "+70290244343"}
0005435443243	DC1495	7892 271960	PETR MAKAROV	{"email": "makarov.petr27111963@postgrespro.ru", "phone": "+70154798983"}
0005435443244	DC1495	5827 704472	SVETLANA ORLOVA	{"phone": "+70235342493"}
0005435443245	DC1495	6957 658789	EVGENIY GRIGOREV	{"email": "grigorev.evgeniy061963@postgrespro.ru", "phone": "+70690172165"}
0005435443246	DC1495	3881 174184	VLADIMIR EGOROV	{"phone": "+70117526124"}
0005435443247	90CBB1	1161 094888	VASILIY ZHUKOV	{"email": "zhukov-vasiliy_111963@postgrespro.ru", "phone": "+70538353421"}
0005435443248	C25DB0	6252 231687	LARISA KUZNECOVA	{"phone": "+70341584102"}
0005435443249	C25DB0	9305 176589	SERGEY ZAYCEV	{"phone": "+70174962834"}
0005435443250	3E60C8	5555 052675	ALEKSANDR SOROKIN	{"phone": "+70593876178"}
0005435443251	542141	1646 240624	MAKSIM ANDREEV	{"email": "maksim.andreev_08021976@postgrespro.ru", "phone": "+70893122861"}
0005435443252	C290D9	4986 203561	ALEKSANDR POPOV	{"phone": "+70814060966"}
0005435443253	D6FDE5	7089 973565	OLGA KOROLEVA	{"phone": "+70235281398"}
0005435443254	7BDDFD	5922 117465	RAMIL BONDARENKO	{"email": "rbondarenko_07101974@postgrespro.ru", "phone": "+70422541454"}
0005435443255	418936	8478 240208	KLAVDIYA NIKITINA	{"email": "nikitina-k-1973@postgrespro.ru", "phone": "+70116785701"}
0005435443256	418936	2393 296452	PETR IVANOV	{"phone": "+70705803585"}
0005435443257	0A8C4A	2630 459425	DMITRIY KOZLOV	{"email": "dkozlov_1970@postgrespro.ru", "phone": "+70302341268"}
0005435443258	A116BE	8906 075185	OLEG KRASNOV	{"email": "oleg_krasnov.031960@postgrespro.ru", "phone": "+70830333360"}
0005435443259	F7615E	4803 192013	VIKTOR POPOV	{"email": "v-popov.1964@postgrespro.ru", "phone": "+70154473665"}
0005435443260	6A2B13	6962 792029	NARIMAN BORISOV	{"email": "nariman_borisov081969@postgrespro.ru", "phone": "+70908373405"}
0005435443261	740D6C	5549 911505	OLGA KOROLEVA	{"phone": "+70673471723"}
0005435443262	740D6C	3008 233852	NATALYA GERASIMOVA	{"email": "gerasimovanatalya-1969@postgrespro.ru", "phone": "+70573607929"}
0005435443263	D033DD	5453 383853	TATYANA ABRAMOVA	{"phone": "+70159198472"}
0005435443264	D033DD	1165 016506	NINA IVANOVA	{"email": "ivanovan.17121981@postgrespro.ru", "phone": "+70777958605"}
0005435443265	613CA7	8198 144548	ARTEM POPOV	{"phone": "+70706774363"}
0005435443266	047EDE	7434 473401	ALEKSEY KUZMIN	{"phone": "+70336078237"}
0005435443267	2B7155	8566 358751	SERGEY ABRAMOV	{"email": "sergeyabramov_28021973@postgrespro.ru", "phone": "+70432439821"}
0005435443268	949661	5845 653500	ANNA MEDVEDEVA	{"email": "a_medvedeva01031967@postgrespro.ru", "phone": "+70106952087"}
0005435443269	609DC3	2790 574833	SERGEY ANDREEV	{"email": "andreev_sergey_14011970@postgrespro.ru", "phone": "+70755231235"}
0005435443270	ABC7A7	2418 750097	ELENA KARPOVA	{"email": "elena-karpova-061971@postgrespro.ru", "phone": "+70289294882"}
0005435443271	E65366	3967 951581	OLGA AFANASEVA	{"email": "olgaafanaseva.1976@postgrespro.ru", "phone": "+70657786000"}
0005435443272	E65366	6315 363721	KSENIYA STEPANOVA	{"email": "stepanova_kseniya1980@postgrespro.ru", "phone": "+70891802175"}
0005435443273	697122	1469 952479	VALENTINA LEBEDEVA	{"phone": "+70165972802"}
0005435443274	697122	6977 114948	MARIYA YAKOVLEVA	{"email": "mariyayakovleva06091973@postgrespro.ru", "phone": "+70457221154"}
0005435443275	529820	7492 146094	ELENA POPOVA	{"phone": "+70938769892"}
0005435443276	D948B8	5356 070245	OLESYA ALEKSANDROVA	{"email": "aleksandrova_o_1970@postgrespro.ru", "phone": "+70038271223"}
0005435443277	C87135	0769 661372	VALENTINA FEDOROVA	{"email": "fedorova_v1971@postgrespro.ru", "phone": "+70285255554"}
0005435443278	C87135	6584 849452	KRISTINA EGOROVA	{"phone": "+70311783834"}
0005435443279	BB4CA8	6578 926500	ANATOLIY KUZNECOV	{"email": "anatoliy.kuznecov.041971@postgrespro.ru", "phone": "+70297911232"}
0005435443280	BB4CA8	8280 072385	NIKOLAY ISAEV	{"phone": "+70144343961"}
0005435443281	A09ABD	8594 652063	IRINA BELYAEVA	{"email": "belyaeva.i101972@postgrespro.ru", "phone": "+70576108952"}
0005435443282	8A2ABB	9394 549478	VITALIY MOROZOV	{"email": "vitaliymorozov30031984@postgrespro.ru", "phone": "+70694649779"}
0005435443283	3AE680	5303 717029	ALEKSANDR PETROV	{"phone": "+70207915371"}
0005435443284	E4D3E5	2589 179985	VIKTOR TIMOFEEV	{"phone": "+70470239445"}
0005435443285	B30FA4	1669 732420	OLGA KARPOVA	{"email": "karpova_o_21071970@postgrespro.ru", "phone": "+70963747858"}
0005435443286	FD93BD	9011 261890	ALINA FEDOROVA	{"phone": "+70444423855"}
0005435443287	66ED62	4341 674140	VLADIMIR ABRAMOV	{"phone": "+70941204230"}
0005435443288	0896CC	0579 015258	ALEKSANDRA ANDREEVA	{"email": "andreeva-a_06101980@postgrespro.ru", "phone": "+70871813937"}
0005435443289	0896CC	4578 094311	OLGA KAZAKOVA	{"phone": "+70117523804"}
0005435443290	5349B0	9603 440853	ANTON MOROZOV	{"email": "morozov-a091968@postgrespro.ru", "phone": "+70167093605"}
0005435443291	EF4957	1772 961525	ANTONINA FOMINA	{"phone": "+70546246383"}
0005435443292	D09F84	3034 582417	IVAN SHEVCHENKO	{"email": "i.shevchenko.1975@postgrespro.ru", "phone": "+70870461355"}
0005435443293	D09F84	3183 135824	LIDIYA ANISIMOVA	{"email": "lidiya_anisimova_1968@postgrespro.ru", "phone": "+70793558118"}
0005435443294	55E93A	7388 518488	SVETLANA FROLOVA	{"email": "frolovas091975@postgrespro.ru", "phone": "+70979290021"}
0005435443295	36CE8F	9026 386618	TATYANA ANDREEVA	{"phone": "+70482872562"}
0005435443296	1EE26A	8456 672823	MIKHAIL ZAYCEV	{"phone": "+70948294327"}
0005435443297	582217	9963 921367	LYUBOV KUDRYASHOVA	{"phone": "+70109129714"}
0005435443298	92507B	1801 309480	ALEKSANDR ABRAMOV	{"email": "aleksandr-abramov-111981@postgrespro.ru", "phone": "+70851760574"}
0005435443299	70508B	6780 328784	VALENTINA CHERNOVA	{"phone": "+70418664840"}
0005435443300	1D67C2	8900 196174	NIKOLAY VASILEV	{"phone": "+70561979177"}
0005435443301	A71240	3974 079324	MARTA KUZNECOVA	{"phone": "+70796512291"}
0005435443302	A71240	8828 431413	GENNADIY NOVIKOV	{"phone": "+70569009789"}
0005435443303	732F29	0170 480794	OLGA NIKOLAEVA	{"email": "nikolaeva.olga-10061976@postgrespro.ru", "phone": "+70357355880"}
0005435443304	66474F	4466 987466	ANASTASIYA KARPOVA	{"email": "anastasiya-karpova-07081980@postgrespro.ru", "phone": "+70431138401"}
0005435443305	66474F	6967 410658	OLEG GUSEV	{"email": "gusev-oleg_1973@postgrespro.ru", "phone": "+70625587178"}
0005435443306	5DBABD	4990 173417	TATYANA FEDOROVA	{"email": "fedorovatatyana.10071964@postgrespro.ru", "phone": "+70053299789"}
0005435443307	0482A6	2546 447344	ELENA KULIKOVA	{"email": "kulikovae-14081967@postgrespro.ru", "phone": "+70138391364"}
0005435443308	475A6D	6751 654029	NATALYA KOVALEVA	{"phone": "+70471756822"}
0005435443309	D88D39	5535 987584	VALERIY SERGEEV	{"phone": "+70586004733"}
0005435443310	14568D	5533 101345	VIKTORIYA CHERNOVA	{"email": "v.chernova_041987@postgrespro.ru", "phone": "+70417292319"}
0005435443311	D04DD7	1313 400423	YULIYA KUZNECOVA	{"email": "yuliyakuznecova-27101965@postgrespro.ru", "phone": "+70657987112"}
0005435443312	D04DD7	1433 223424	IRINA KAZAKOVA	{"email": "irina_kazakova061967@postgrespro.ru", "phone": "+70670760854"}
0005435443313	D04DD7	2331 917206	ARTEM DENISOV	{"email": "artemdenisov-1961@postgrespro.ru", "phone": "+70788917335"}
0005435443314	3F7D47	2085 615782	LYUBOV KOVALEVA	{"phone": "+70470282622"}
0005435443315	F0D8A3	7821 394510	ALEKSANDR ANDREEV	{"phone": "+70558118761"}
0005435443316	6950F6	7758 494216	ALEKSEY SIDOROV	{"email": "alekseysidorov_1973@postgrespro.ru", "phone": "+70025629237"}
0005435443317	C0C38E	9582 014671	ALLA TIKHONOVA	{"phone": "+70208222883"}
0005435443318	C0C38E	2465 122964	EVGENIY NAUMOV	{"phone": "+70276306807"}
0005435443319	BED535	2686 615991	EVGENIY STEPANOV	{"phone": "+70526739028"}
0005435443320	BED535	5423 845187	IRINA NAZAROVA	{"email": "nazarovai.041974@postgrespro.ru", "phone": "+70246162692"}
0005435443321	8254A6	1702 849578	NINA FEDOROVA	{"email": "fedorova-nina.111964@postgrespro.ru", "phone": "+70203715712"}
0005435443322	B78CE8	8454 942793	ELIZAVETA KARPOVA	{"phone": "+70006759091"}
0005435443323	0387FA	0598 544786	MARINA MOISEEVA	{"phone": "+70655122845"}
0005435443324	BD1619	1436 555617	ANASTASIYA MAKAROVA	{"email": "makarovaa011971@postgrespro.ru", "phone": "+70969467343"}
0005435443325	96EFD7	9292 698233	ALEKSEY KUZNECOV	{"phone": "+70414208442"}
0005435443326	D8957E	9485 668306	RAISA MAKAROVA	{"email": "makarova.r_13111974@postgrespro.ru", "phone": "+70633773143"}
0005435443327	D8957E	5819 495573	VALERIY MIKHAYLOV	{"email": "mikhaylov_valeriy.111975@postgrespro.ru", "phone": "+70882466489"}
0005435443328	113C04	1539 804492	IVAN KOZLOV	{"email": "i_kozlov_121972@postgrespro.ru", "phone": "+70850463082"}
0005435443329	B761BA	0300 425398	EKATERINA KOZLOVA	{"phone": "+70843781251"}
0005435443330	2C9799	2183 962920	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr_1975@postgrespro.ru", "phone": "+70917258435"}
0005435443331	4925B4	6800 804842	SEMEN STEPANOV	{"email": "stepanov.semen_1963@postgrespro.ru", "phone": "+70374394604"}
0005435443332	4925B4	4096 665535	OLGA ILINA	{"phone": "+70780825956"}
0005435443333	699AB0	7449 459549	MATVEY KUZMIN	{"email": "kuzmin_m31081968@postgrespro.ru", "phone": "+70805980196"}
0005435443334	699AB0	4774 047377	LYUBOV ROMANOVA	{"phone": "+70968107100"}
0005435443335	699AB0	9860 106087	GALINA POPOVA	{"email": "g.popova01091959@postgrespro.ru", "phone": "+70425624078"}
0005435443336	B8DE7B	4967 232260	VLADIMIR MAKAROV	{"email": "vladimir_makarov081967@postgrespro.ru", "phone": "+70136103525"}
0005435443337	9C3B2C	4528 728061	MAKSIM PETROV	{"phone": "+70691942910"}
0005435443338	9C3B2C	6250 526607	NIKOLAY DMITRIEV	{"phone": "+70551584413"}
0005435443339	F53EB4	6300 250380	EVDOKIYA GAVRILOVA	{"phone": "+70824637173"}
0005435443340	F53EB4	7984 436516	VIKTORIYA SOKOLOVA	{"phone": "+70988998496"}
0005435443341	B05EF6	0532 906710	ALEKSANDR PETROV	{"email": "petrov-aleksandr.1973@postgrespro.ru", "phone": "+70284580925"}
0005435443342	B05EF6	7159 129252	KIRILL PAVLOV	{"phone": "+70331199086"}
0005435443343	50782A	4569 737741	VITALIY IVANOV	{"phone": "+70685145463"}
0005435443344	F512CE	7861 204224	VALENTINA SIDOROVA	{"phone": "+70943512124"}
0005435443345	F512CE	5043 735642	TATYANA VOROBEVA	{"phone": "+70013291636"}
0005435443346	508A61	8269 007188	SERGEY KULIKOV	{"phone": "+70555348512"}
0005435443347	508A61	5379 747909	ANASTASIYA MARTYNOVA	{"phone": "+70963434866"}
0005435443348	508A61	3470 684669	OLEG MARTYNOV	{"phone": "+70183556365"}
0005435443349	EF9F18	9143 403272	YURIY POPOV	{"email": "ypopov-15071977@postgrespro.ru", "phone": "+70133101634"}
0005435443350	5BB9AF	5562 560840	SERGEY AFANASEV	{"phone": "+70546436726"}
0005435443351	420A3C	6572 977327	DENIS MATVEEV	{"email": "matveev-denis1977@postgrespro.ru", "phone": "+70078499356"}
0005435443352	93C80F	0397 273845	ALEKSANDR SOKOLOV	{"phone": "+70631127289"}
0005435443353	168950	8606 758014	VIKTOR NIKITIN	{"phone": "+70582217390"}
0005435443354	23270B	9083 415743	SVETLANA VOROBEVA	{"phone": "+70160750590"}
0005435443355	23270B	2256 782654	ELIZAVETA POTAPOVA	{"phone": "+70748032184"}
0005435443356	0EE279	8175 405377	VLADIMIR SCHERBAKOV	{"email": "scherbakovv.1967@postgrespro.ru", "phone": "+70116420384"}
0005435443357	0EE279	0873 584596	YULIYA POPOVA	{"email": "y_popova_1970@postgrespro.ru", "phone": "+70476377134"}
0005435443358	5A8356	5660 057329	NADEZHDA POPOVA	{"email": "popova.nadezhda-30041962@postgrespro.ru", "phone": "+70235517374"}
0005435443359	EB9D5D	7747 491121	LYUBOV MARTYNOVA	{"email": "lyubov.martynova-1960@postgrespro.ru", "phone": "+70114307845"}
0005435443360	B4E55D	7673 147997	MAKSIM MOROZOV	{"email": "m-morozov1975@postgrespro.ru", "phone": "+70199216055"}
0005435443361	6DD813	9582 487435	PETR MELNIKOV	{"email": "p.melnikov-23121973@postgrespro.ru", "phone": "+70169303817"}
0005435443362	6DD813	7915 325476	ALEKSANDR STEPANOV	{"phone": "+70487526665"}
0005435443363	4732C4	3684 899958	SERGEY NAUMOV	{"email": "naumov.sergey.031981@postgrespro.ru", "phone": "+70167836448"}
0005435443364	DEE623	5868 203666	IRINA ANISIMOVA	{"email": "irinaanisimova.1971@postgrespro.ru", "phone": "+70453162921"}
0005435443365	4DDED0	4569 800560	LEONID MOISEEV	{"phone": "+70474748756"}
0005435443366	F3A341	0270 785429	LYUBOV MAKSIMOVA	{"email": "l.maksimova_021981@postgrespro.ru", "phone": "+70586660200"}
0005435443367	F3A341	5413 759877	YULIYA ILINA	{"email": "yilina.22051962@postgrespro.ru", "phone": "+70703052374"}
0005435443368	C72949	3217 978426	ELENA VOROBEVA	{"email": "vorobeva.elena-1966@postgrespro.ru", "phone": "+70176833934"}
0005435443369	20982B	2562 570134	NATALYA ANTONOVA	{"phone": "+70793107310"}
0005435443370	20982B	4167 214235	LYUBOV ARKHIPOVA	{"phone": "+70826103674"}
0005435443371	6002CA	9360 426313	LILIYA KISELEVA	{"email": "liliya-kiseleva101982@postgrespro.ru", "phone": "+70334223201"}
0005435443372	9B0FA8	1356 098554	PETR SEMENOV	{"phone": "+70031595760"}
0005435443373	FAF8D7	8088 857302	MARIYA DMITRIEVA	{"email": "m.dmitrieva-26031974@postgrespro.ru", "phone": "+70439596644"}
0005435443374	CD4D5B	4687 260527	NATALYA GAVRILOVA	{"email": "gavrilova.n-24051981@postgrespro.ru", "phone": "+70496694735"}
0005435443375	CE081C	3497 686260	GALINA GUSEVA	{"email": "gusevagalina_091972@postgrespro.ru", "phone": "+70870695734"}
0005435443376	CE081C	0855 180045	ELENA KAZAKOVA	{"email": "e.kazakova_081975@postgrespro.ru", "phone": "+70713845702"}
0005435443377	56F73F	0196 371577	TAISIYA VOROBEVA	{"phone": "+70977855689"}
0005435443378	56F73F	0712 749379	ANNA ALEKSANDROVA	{"email": "a_aleksandrova-14091977@postgrespro.ru", "phone": "+70703131594"}
0005435443379	56F73F	4792 225706	IGNAT GUSEV	{"phone": "+70145492259"}
0005435443380	56F73F	6578 164906	ELENA CHERNOVA	{"email": "chernova.elena-20121966@postgrespro.ru", "phone": "+70103172504"}
0005435443381	0AE645	2569 448106	ALEKSANDRA VOLKOVA	{"email": "aleksandra.volkova03011971@postgrespro.ru", "phone": "+70228187166"}
0005435443382	0AE645	3077 797148	KONSTANTIN KOROLEV	{"phone": "+70800199560"}
0005435443383	4E876A	9666 350901	DARYA DMITRIEVA	{"email": "darya.dmitrieva.011977@postgrespro.ru", "phone": "+70275273211"}
0005435443384	4E876A	4381 783501	ALEKSANDR BONDARENKO	{"email": "a_bondarenko.091966@postgrespro.ru", "phone": "+70899343637"}
0005435443385	4E876A	1428 469849	ALLA CHERNOVA	{"email": "chernova-a.01111973@postgrespro.ru", "phone": "+70858376336"}
0005435443386	33CFAF	1084 611299	ANNA YAKOVLEVA	{"phone": "+70511118908"}
0005435443387	83D5AE	5147 873100	NATALIYA ORLOVA	{"email": "nataliya.orlova.1970@postgrespro.ru", "phone": "+70812836442"}
0005435443388	508983	9649 662315	RASIM GRIGOREV	{"phone": "+70230917446"}
0005435443389	6902FE	1385 020531	ANDREY KOZLOV	{"email": "a_kozlov061961@postgrespro.ru", "phone": "+70730874385"}
0005435443390	6902FE	6523 373206	VALERIYA ALEKSANDROVA	{"email": "v-aleksandrova1970@postgrespro.ru", "phone": "+70631731210"}
0005435443391	750531	0115 363657	MARIYA POPOVA	{"email": "popova_m1966@postgrespro.ru", "phone": "+70223428892"}
0005435443392	750531	9817 694863	OLEG PAVLOV	{"email": "oleg-pavlov.27091968@postgrespro.ru", "phone": "+70049793249"}
0005435443393	CF4364	2816 688107	NIKOLAY KUZNECOV	{"email": "kuznecov_n1963@postgrespro.ru", "phone": "+70678950939"}
0005435443394	FB7290	0780 207190	MARIYA ANISIMOVA	{"phone": "+70226288499"}
0005435443395	FB7290	1497 073796	ANATOLIY PAVLOV	{"email": "anatoliy-pavlov-1970@postgrespro.ru", "phone": "+70326184714"}
0005435443396	EA92C9	6130 527289	EKATERINA PAVLOVA	{"email": "epavlova101975@postgrespro.ru", "phone": "+70113042168"}
0005435443397	EA92C9	2289 302915	VALENTINA ALEKSEEVA	{"phone": "+70150639657"}
0005435443398	EF040E	7766 709152	ALEKSEY SEMENOV	{"email": "semenov-aleksey25011981@postgrespro.ru", "phone": "+70321432451"}
0005435443399	EF040E	9716 393906	LYUBOV SMIRNOVA	{"email": "lsmirnova.1976@postgrespro.ru", "phone": "+70052000200"}
0005435443400	4A0F07	1726 779556	VIOLETTA ERMAKOVA	{"email": "violetta_ermakova_061970@postgrespro.ru", "phone": "+70003592427"}
0005435443401	425D2D	7879 099161	VALERIY DMITRIEV	{"phone": "+70153494657"}
0005435443402	84B244	2828 100627	ROMAN GAVRILOV	{"phone": "+70074263303"}
0005435443403	F06571	8507 290098	SVETLANA BELYAEVA	{"email": "belyaeva-svetlana_1980@postgrespro.ru", "phone": "+70625984724"}
0005435443404	445C7C	7682 318311	MAKSIM BORISOV	{"phone": "+70576847150"}
0005435443405	445C7C	6539 852053	VALENTINA KUZNECOVA	{"email": "valentina.kuznecova23041974@postgrespro.ru", "phone": "+70769340072"}
0005435443406	A4145D	1650 785458	SEMEN PAVLOV	{"email": "s_pavlov091968@postgrespro.ru", "phone": "+70127041068"}
0005435443407	9EC8B7	6746 470878	YURIY ANDREEV	{"email": "andreevyuriy07121969@postgrespro.ru", "phone": "+70812411027"}
0005435443408	690A35	6119 042832	ANNA PETROVA	{"email": "anna_petrova_27061970@postgrespro.ru", "phone": "+70876320642"}
0005435443409	690A35	1960 042624	IVAN KUZNECOV	{"phone": "+70362337432"}
0005435443410	A22F6B	2059 299475	INNA KOROLEVA	{"phone": "+70230342184"}
0005435443411	E9D301	1126 563967	VALENTINA DANILOVA	{"phone": "+70596173855"}
0005435443412	A7E0EB	7578 735237	MAKSIM ZAYCEV	{"phone": "+70537200163"}
0005435443413	D32E6C	1437 602695	ELENA ZOTOVA	{"email": "e-zotova021967@postgrespro.ru", "phone": "+70391273490"}
0005435443414	D32E6C	1262 750970	TATYANA TITOVA	{"phone": "+70166615818"}
0005435443415	11450F	7610 159363	EKATERINA VASILEVA	{"phone": "+70045348850"}
0005435443416	50DEF2	7436 307208	DENIS POPOV	{"phone": "+70856929811"}
0005435443417	403347	1027 960344	OLEG NAZAROV	{"email": "oleg.nazarov.111965@postgrespro.ru", "phone": "+70673557159"}
0005435443418	403347	3463 488136	ULYANA KALININA	{"phone": "+70495865235"}
0005435443419	F684B9	9737 202022	ASKHAT STEPANOV	{"email": "astepanov-091968@postgrespro.ru", "phone": "+70286898745"}
0005435443420	F684B9	5641 048905	MATVEY YAKOVLEV	{"phone": "+70851831264"}
0005435443421	0BE63C	3755 189471	ALEKSANDR TIMOFEEV	{"email": "a-timofeev_17051971@postgrespro.ru", "phone": "+70652073731"}
0005435443422	25FEC2	8659 413022	VALERIY EGOROV	{"email": "egorov_v1960@postgrespro.ru", "phone": "+70991973117"}
0005435443423	30DF57	8447 077681	TATYANA KUZNECOVA	{"email": "kuznecova-tatyana.021970@postgrespro.ru", "phone": "+70084271200"}
0005435443424	DAFDB9	8279 834184	LARISA VOLKOVA	{"phone": "+70852755363"}
0005435443425	C7F8F7	6420 762853	ANTONINA POPOVA	{"email": "antoninapopova-031976@postgrespro.ru", "phone": "+70709838004"}
0005435443426	C7F8F7	2306 318448	VALERIYA GAVRILOVA	{"email": "valeriyagavrilova-1964@postgrespro.ru", "phone": "+70871421550"}
0005435443427	82E28E	5084 090554	MARINA SMIRNOVA	{"email": "smirnovamarina.24011977@postgrespro.ru", "phone": "+70159788731"}
0005435443428	82E28E	8884 547230	ANNA CHERNOVA	{"phone": "+70187403020"}
0005435443429	82E28E	8266 992925	ANNA MIRONOVA	{"email": "annamironova-22041974@postgrespro.ru", "phone": "+70247049700"}
0005435443430	44FDEA	0501 392493	MARINA DENISOVA	{"phone": "+70823658195"}
0005435443431	44FDEA	4184 489945	ANNA SAVELEVA	{"email": "saveleva_a.071973@postgrespro.ru", "phone": "+70281272963"}
0005435443432	DF6BB6	2534 212005	ELIZAVETA PETROVA	{"phone": "+70085772407"}
0005435443433	DF6BB6	7079 910673	OLGA GORBUNOVA	{"phone": "+70816344209"}
0005435443434	DF6BB6	1143 151231	ALEKSANDR DAVYDOV	{"phone": "+70423350703"}
0005435443435	989026	6798 216253	ANDREY MELNIKOV	{"email": "melnikov-andrey.111976@postgrespro.ru", "phone": "+70318133757"}
0005435443436	3BC6D5	3732 091434	ALEKSANDRA PETROVA	{"email": "petrova_a-30121972@postgrespro.ru", "phone": "+70405621665"}
0005435443437	B24363	8950 194137	NATALIYA EFIMOVA	{"email": "n.efimova-1984@postgrespro.ru", "phone": "+70514706772"}
0005435443438	B24363	8617 174530	ALEKSEY MAKSIMOV	{"email": "maksimovaleksey-28081963@postgrespro.ru", "phone": "+70800986383"}
0005435443439	43F994	3070 292771	ANASTASIYA ZAKHAROVA	{"phone": "+70399268987"}
0005435443440	AEFDDD	7799 433732	VLADIMIR IVANOV	{"email": "vladimir.ivanov-06071979@postgrespro.ru", "phone": "+70330876968"}
0005435443441	868F96	1825 574764	IRINA TIMOFEEVA	{"phone": "+70404773651"}
0005435443442	868F96	9878 051375	OKSANA SIDOROVA	{"phone": "+70100204787"}
0005435443443	0C20C4	2534 524118	ALEKSANDR IVANOV	{"email": "a_ivanov29081980@postgrespro.ru", "phone": "+70536303594"}
0005435443444	1DC3EE	9743 313516	ZOYA SMIRNOVA	{"email": "z-smirnova_081987@postgrespro.ru", "phone": "+70293647908"}
0005435443445	502F95	6961 094383	MIKHAIL SCHERBAKOV	{"email": "mikhail.scherbakov.061975@postgrespro.ru", "phone": "+70849896393"}
0005435443446	53BDD5	5868 137771	ALLA DANILOVA	{"email": "a.danilova_1975@postgrespro.ru", "phone": "+70163956903"}
0005435443447	80475A	8657 072277	NADEZHDA VASILEVA	{"phone": "+70372899518"}
0005435443448	80475A	8219 474034	SERGEY MOROZOV	{"email": "sergeymorozov-25011979@postgrespro.ru", "phone": "+70068300530"}
0005435443449	605274	1963 936176	DMITRIY NIKOLAEV	{"email": "nikolaev.d091958@postgrespro.ru", "phone": "+70069342318"}
0005435443450	E11100	2492 744827	ANDREY KOZLOV	{"phone": "+70814111707"}
0005435443451	E11100	2542 550502	IRINA AKIMOVA	{"phone": "+70901033120"}
0005435443452	2241D4	5548 530144	ALEKSANDR KUZMIN	{"email": "aleksandr-kuzmin.28111965@postgrespro.ru", "phone": "+70343544347"}
0005435443453	8E2153	8369 246937	SVETLANA NESTEROVA	{"email": "nesterova-svetlana-06111972@postgrespro.ru", "phone": "+70147826300"}
0005435443454	8E2153	7970 726190	ALEKSANDR GUSEV	{"email": "a_gusev.031969@postgrespro.ru", "phone": "+70892038716"}
0005435443455	8E2153	4804 315777	YULIYA TIMOFEEVA	{"email": "yuliya_timofeeva_091975@postgrespro.ru", "phone": "+70612338885"}
0005435443456	118707	0260 619045	MIKHAIL SCHERBAKOV	{"phone": "+70085913510"}
0005435443457	F609FB	3533 894824	ALINA VASILEVA	{"email": "vasilevaa_24021986@postgrespro.ru", "phone": "+70782751517"}
0005435443458	F609FB	5351 011255	ALEKSANDR GERASIMOV	{"phone": "+70165659481"}
0005435443459	603A1D	0435 592959	DMITRIY VOLKOV	{"phone": "+70423099633"}
0005435443460	603A1D	7801 267797	VASILIY ABRAMOV	{"email": "vasiliy_abramov_031981@postgrespro.ru", "phone": "+70377710653"}
0005435443461	CCAD9D	4091 900945	ALEKSANDRA MATVEEVA	{"phone": "+70288545093"}
0005435443462	A6E8A7	2910 952752	VLADISLAV POPOV	{"phone": "+70230833262"}
0005435443463	B486F1	3897 399672	MARINA SOKOLOVA	{"phone": "+70879473201"}
0005435443464	B486F1	5364 714783	SVETLANA FEDOROVA	{"email": "s_fedorova-031969@postgrespro.ru", "phone": "+70240983423"}
0005435443465	C9B51E	9685 611884	SERGEY FROLOV	{"phone": "+70019492407"}
0005435443466	C9B51E	6095 692024	MATVEY KARPOV	{"phone": "+70971617316"}
0005435443467	5C22D1	6042 090381	ARTEM KUZNECOV	{"phone": "+70263092221"}
0005435443468	055CE5	0916 816112	VITALIY MAKAROV	{"phone": "+70822312564"}
0005435443469	055CE5	4154 439489	ROMAN GAVRILOV	{"email": "gavrilov.r1974@postgrespro.ru", "phone": "+70821568050"}
0005435443470	055CE5	9769 301912	LYUDMILA KUZNECOVA	{"phone": "+70391833970"}
0005435443471	0698ED	1290 720663	ALEKSANDR KUZNECOV	{"email": "kuznecova_04071978@postgrespro.ru", "phone": "+70963771108"}
0005435443472	57B9BE	0327 510615	DMITRIY FOMIN	{"email": "dmitriy-fomin.08101975@postgrespro.ru", "phone": "+70045637044"}
0005435443473	57B9BE	5807 595238	IRINA VOLKOVA	{"phone": "+70603714595"}
0005435443474	57B9BE	3699 961661	BORIS DMITRIEV	{"phone": "+70052291454"}
0005435443475	20C3C0	7743 971545	MARGARITA ANTONOVA	{"email": "antonova_m.041969@postgrespro.ru", "phone": "+70638309249"}
0005435443476	FFE6FD	5313 486124	ALEKSEY YAKOVLEV	{"email": "yakovlev.aleksey-1966@postgrespro.ru", "phone": "+70082632168"}
0005435443477	53641A	1793 042921	TATYANA MOISEEVA	{"email": "t_moiseeva-07051972@postgrespro.ru", "phone": "+70117279544"}
0005435443478	53641A	0459 453124	VALERIYA VOLKOVA	{"phone": "+70922021149"}
0005435443479	53641A	0860 997116	NIKOLAY SIDOROV	{"phone": "+70710920393"}
0005435443480	00DD74	7838 534941	YURIY MEDVEDEV	{"email": "medvedev.y-091973@postgrespro.ru", "phone": "+70676784588"}
0005435443481	12DA41	4574 482307	ANASTASIYA RODIONOVA	{"phone": "+70937694282"}
0005435443482	B58740	3045 322599	SEMEN SAVELEV	{"email": "savelev_semen.041980@postgrespro.ru", "phone": "+70543532320"}
0005435443483	912F17	2774 762500	MARIYA DAVYDOVA	{"email": "davydova.m_1956@postgrespro.ru", "phone": "+70519579016"}
0005435443484	C877F3	3647 883818	ALFIYA KOMAROVA	{"email": "komarova_alfiya.031970@postgrespro.ru", "phone": "+70575974377"}
0005435443485	AA0A4F	1921 635222	SVETLANA KRASNOVA	{"email": "svetlana-krasnova-061971@postgrespro.ru", "phone": "+70279602865"}
0005435443486	AA0A4F	9209 879813	NADEZHDA NIKIFOROVA	{"email": "nikiforova.nadezhda.1978@postgrespro.ru", "phone": "+70957883712"}
0005435443487	A5E329	6102 159199	ANDREY IVANOV	{"email": "a.ivanov.19111981@postgrespro.ru", "phone": "+70677887789"}
0005435443488	468839	8949 222994	DARYA TITOVA	{"email": "d-titova-1967@postgrespro.ru", "phone": "+70241728927"}
0005435443489	468839	4956 578399	RAFIK MOROZOV	{"email": "r_morozov_081973@postgrespro.ru", "phone": "+70967010243"}
0005435443490	886C1F	5735 615928	ALEKSANDR OSIPOV	{"phone": "+70722098395"}
0005435443491	93B985	3626 613586	TAMARA SCHERBAKOVA	{"email": "scherbakova.t.1972@postgrespro.ru", "phone": "+70625838383"}
0005435443492	93B985	8248 474049	IRINA NIKITINA	{"phone": "+70761590705"}
0005435443493	E80C65	1200 099163	NATALYA NIKOLAEVA	{"email": "nikolaeva-n-19011967@postgrespro.ru", "phone": "+70768055815"}
0005435443494	085D80	1118 192769	ANDREY MIRONOV	{"email": "mironov-a_091968@postgrespro.ru", "phone": "+70077511124"}
0005435443495	A5B71B	4429 561105	RASHIT FROLOV	{"email": "rashit_frolov071978@postgrespro.ru", "phone": "+70447867265"}
0005435443496	8EEF10	8021 954899	OLGA RYABOVA	{"email": "o-ryabova_1969@postgrespro.ru", "phone": "+70849285229"}
0005435443497	ACF1A9	2483 274479	POLINA DMITRIEVA	{"email": "p_dmitrieva.1979@postgrespro.ru", "phone": "+70835883138"}
0005435443498	64696F	6636 276853	ASIYA ZAYCEVA	{"email": "zayceva.asiya.1970@postgrespro.ru", "phone": "+70517658320"}
0005435443499	64696F	1489 303539	ANASTASIYA MALYSHEVA	{"email": "anastasiya_malysheva.16091970@postgrespro.ru", "phone": "+70562226313"}
0005435443500	9ED098	9824 218533	VIKTOR KISELEV	{"phone": "+70550283216"}
0005435443501	1689F4	6442 635965	ANASTASIYA FROLOVA	{"email": "anastasiyafrolova-091967@postgrespro.ru", "phone": "+70205669747"}
0005435443502	ACFF74	8146 295997	ALEKSANDR KRASNOV	{"phone": "+70079718729"}
0005435443503	3D8FDA	8023 872427	KONSTANTIN TARASOV	{"phone": "+70141730723"}
0005435443504	A27223	0860 718594	LYUBOV KARPOVA	{"email": "lyubovkarpova.1970@postgrespro.ru", "phone": "+70215692630"}
0005435443505	E87068	2166 767943	SVETLANA MALYSHEVA	{"email": "malyshevas041981@postgrespro.ru", "phone": "+70384460184"}
0005435443506	E87068	7182 864828	VIKTORIYA IVANOVA	{"email": "viktoriyaivanova1965@postgrespro.ru", "phone": "+70862927939"}
0005435443507	B2DEFB	4786 836986	ANNA ANTONOVA	{"email": "a_antonova-031979@postgrespro.ru", "phone": "+70054512702"}
0005435443508	B0CADE	6683 898897	NINA IVANOVA	{"email": "ivanova-n.1957@postgrespro.ru", "phone": "+70608354375"}
0005435443509	0EA193	5339 355577	VERA FADEEVA	{"phone": "+70873505602"}
0005435443510	230A5C	1359 055726	ELENA TITOVA	{"email": "elena.titova-101979@postgrespro.ru", "phone": "+70573792328"}
0005435443511	F5B40A	5445 531343	VLADIMIR GAVRILOV	{"phone": "+70441739166"}
0005435443512	E0AEF8	6858 626059	NADEZHDA ZOTOVA	{"email": "zotova.nadezhda_17121975@postgrespro.ru", "phone": "+70244664562"}
0005435443513	BD70F6	2024 714765	VALENTINA TIKHONOVA	{"phone": "+70466424113"}
0005435443514	BD70F6	2371 035902	IVAN MEDVEDEV	{"phone": "+70688336668"}
0005435443515	C4DBA4	3666 075491	YAKOV POPOV	{"email": "y-popov_1963@postgrespro.ru", "phone": "+70347713685"}
0005435443516	C4DBA4	1702 713221	ALEKSEY POPOV	{"phone": "+70091084704"}
0005435443517	C4DBA4	7195 397901	LYUDMILA MAKSIMOVA	{"email": "lmaksimova29091975@postgrespro.ru", "phone": "+70659058629"}
0005435443518	7B6334	4106 773005	TATYANA LEBEDEVA	{"email": "lebedeva_tatyana021964@postgrespro.ru", "phone": "+70775291739"}
0005435443519	7B6334	2841 134394	VASILIY DAVYDOV	{"email": "davydovv1967@postgrespro.ru", "phone": "+70419252148"}
0005435443520	6579DC	3320 869729	LIDIYA SEMENOVA	{"phone": "+70450833222"}
0005435443521	70DF85	4994 275218	ALEKSANDR KUZMIN	{"phone": "+70298685886"}
0005435443522	BC032B	3086 344927	ANATOLIY TARASOV	{"email": "a.tarasov09101969@postgrespro.ru", "phone": "+70584626763"}
0005435443523	BC032B	8036 792447	DMITRIY VASILEV	{"phone": "+70103268579"}
0005435443524	31F753	3316 413791	SERGEY ISAEV	{"phone": "+70588842088"}
0005435443525	31F753	9352 762598	SVYATOSLAV TIKHONOV	{"email": "tikhonov.svyatoslav-1972@postgrespro.ru", "phone": "+70091341862"}
0005435443526	4FCABB	4281 265288	ARTUR FEDOROV	{"email": "a-fedorov28081975@postgrespro.ru", "phone": "+70099698978"}
0005435443527	F2E015	1850 515795	LIDIYA GORBUNOVA	{"email": "l-gorbunova_18111964@postgrespro.ru", "phone": "+70462552017"}
0005435443528	AE3252	9133 836973	ELENA GAVRILOVA	{"email": "e_gavrilova_091975@postgrespro.ru", "phone": "+70862422352"}
0005435443529	6D9A67	5448 188616	VALENTINA MEDVEDEVA	{"phone": "+70299175858"}
0005435443530	6D9A67	8852 693006	ARTEM MOISEEV	{"email": "a-moiseev06081965@postgrespro.ru", "phone": "+70861541288"}
0005435443531	1CE88B	6039 938987	EKATERINA ZAKHAROVA	{"phone": "+70658457288"}
0005435443532	1CE88B	5478 644369	YULIYA KOROLEVA	{"email": "yuliya.koroleva.10051980@postgrespro.ru", "phone": "+70023190339"}
0005435443533	BD6432	2181 675961	VASILISA TROFIMOVA	{"phone": "+70489823129"}
0005435443534	101B6B	7571 802103	IRINA ISAEVA	{"email": "i-isaeva-12021973@postgrespro.ru", "phone": "+70461819753"}
0005435443535	101B6B	9237 227599	VLADISLAV NIKOLAEV	{"email": "vladislav-nikolaev_1970@postgrespro.ru", "phone": "+70172611974"}
0005435443536	84EA98	0455 748858	ARTUR MAKAROV	{"email": "makarov_a_1961@postgrespro.ru", "phone": "+70995381608"}
0005435443537	3226E3	4041 472483	DMITRIY SHEVCHENKO	{"email": "shevchenko_dmitriy051967@postgrespro.ru", "phone": "+70547918428"}
0005435443538	927242	5709 655074	DMITRIY ZAKHAROV	{"email": "zakharov-d27041960@postgrespro.ru", "phone": "+70316599922"}
0005435443539	B79FA9	8023 884489	ELENA ABRAMOVA	{"email": "e_abramova_26041972@postgrespro.ru", "phone": "+70863206953"}
0005435443540	B79FA9	4252 058790	YULIYA ANDREEVA	{"email": "andreeva_y.081967@postgrespro.ru", "phone": "+70779475259"}
0005435443541	DC289C	5282 881556	YURIY STEPANOV	{"email": "y_stepanov_1971@postgrespro.ru", "phone": "+70862798690"}
0005435443542	0AE2B7	7429 182883	SERGEY EGOROV	{"phone": "+70756297818"}
0005435443543	2AC570	9138 729293	VIKTOR VLASOV	{"email": "viktor-vlasov121964@postgrespro.ru", "phone": "+70186450585"}
0005435443544	6B394B	5095 853766	LILIYA BELYAEVA	{"email": "liliyabelyaeva.011979@postgrespro.ru", "phone": "+70868568523"}
0005435443545	6B394B	3214 272974	MARIYA NIKITINA	{"email": "nikitinam_1966@postgrespro.ru", "phone": "+70357560650"}
0005435443546	C2F6B3	7092 742563	ELENA PAVLOVA	{"phone": "+70237656525"}
0005435443547	CBB7DA	2743 249113	VALENTINA AKIMOVA	{"email": "akimovavalentina_1970@postgrespro.ru", "phone": "+70027875317"}
0005435443548	CBB7DA	2947 770494	ALEKSEY SERGEEV	{"phone": "+70622546351"}
0005435443549	8D2A46	7936 769910	SERGEY NIKOLAEV	{"phone": "+70532756019"}
0005435443550	F4E472	3864 533639	EVGENIYA POTAPOVA	{"email": "epotapova_20021962@postgrespro.ru", "phone": "+70653052610"}
0005435443551	3FACDD	4669 239012	IRINA POPOVA	{"phone": "+70963936044"}
0005435443552	79E42E	2817 354168	ZULFIYA AKIMOVA	{"email": "zulfiyaakimova_1982@postgrespro.ru", "phone": "+70230760451"}
0005435443553	128A45	9590 575644	VALERIY KUZNECOV	{"email": "kuznecovvaleriy-1973@postgrespro.ru", "phone": "+70460248848"}
0005435443554	A66DD1	6987 429499	MARINA NOVIKOVA	{"phone": "+70145694752"}
0005435443555	A66DD1	6102 016178	ALEKSEY SIDOROV	{"email": "a.sidorov-021985@postgrespro.ru", "phone": "+70501967415"}
0005435443556	A66DD1	3519 429303	OLEG SEMENOV	{"email": "oleg.semenov.1989@postgrespro.ru", "phone": "+70375941538"}
0005435443557	E9D6AD	6049 564112	EVGENIY MIKHAYLOV	{"phone": "+70981469553"}
0005435443558	E9D6AD	7825 396824	ALENA MAKSIMOVA	{"email": "maksimova_alena.071965@postgrespro.ru", "phone": "+70637494991"}
0005435443559	99B52F	2916 286732	KRISTINA MOISEEVA	{"phone": "+70491630483"}
0005435443560	6B44AD	0039 783227	YURIY ZAKHAROV	{"email": "zakharovyuriy_021983@postgrespro.ru", "phone": "+70555751017"}
0005435443561	8210F5	6989 684392	PETR POPOV	{"phone": "+70282913661"}
0005435443562	9E9CB7	7413 140777	NIKITA MELNIKOV	{"email": "n-melnikov1982@postgrespro.ru", "phone": "+70290816648"}
0005435443563	B8CCAF	8611 277889	OLEG KONOVALOV	{"email": "oleg-konovalov071969@postgrespro.ru", "phone": "+70719436812"}
0005435443564	BABA91	6577 641007	ANASTASIYA CHERNOVA	{"phone": "+70897128819"}
0005435443565	DA2FD6	8303 925760	VALERIY EGOROV	{"email": "egorovv_101972@postgrespro.ru", "phone": "+70022343254"}
0005435443566	DA2FD6	5542 164327	FANIYA NESTEROVA	{"phone": "+70738390622"}
0005435443567	F05808	9246 373618	VLADIMIR MOROZOV	{"phone": "+70820128376"}
0005435443568	73F369	9666 710500	ANDREY ILIN	{"phone": "+70196437162"}
0005435443569	496B88	1859 039257	LYUBOV SAVELEVA	{"phone": "+70480992692"}
0005435443570	E3217D	9704 957233	ANASTASIYA KUZNECOVA	{"email": "anastasiyakuznecova-18091979@postgrespro.ru", "phone": "+70032388508"}
0005435443571	50A00F	6576 730380	NATALYA MELNIKOVA	{"phone": "+70542667680"}
0005435443572	C31EDE	8274 403743	DARYA SOROKINA	{"email": "sorokina_darya.14071961@postgrespro.ru", "phone": "+70432814114"}
0005435443573	A655DD	2957 936376	RAMIL RODIONOV	{"phone": "+70735250019"}
0005435443574	A655DD	3853 355222	VIKTOR KISELEV	{"phone": "+70874328863"}
0005435443575	7BAA71	2882 491111	TATYANA FILATOVA	{"email": "tfilatova.1974@postgrespro.ru", "phone": "+70696647358"}
0005435443576	7BAA71	6219 689345	ALEKSEY NIKOLAEV	{"email": "alekseynikolaev_091966@postgrespro.ru", "phone": "+70259053213"}
0005435443577	7BAA71	4940 107013	NIKOLAY KUDRYASHOV	{"phone": "+70569485641"}
0005435443578	F3FEDB	2913 058644	TATYANA SOKOLOVA	{"email": "tatyanasokolova-111979@postgrespro.ru", "phone": "+70317244667"}
0005435443579	AD8A9B	5716 128412	VALERIY POPOV	{"email": "popov_v-27071979@postgrespro.ru", "phone": "+70122855071"}
0005435443580	A6DD44	3281 396515	ALEKSANDR ABRAMOV	{"phone": "+70412338573"}
0005435443581	D252BE	4835 487791	NIKOLAY ZHUKOV	{"email": "n_zhukov_17061967@postgrespro.ru", "phone": "+70660899970"}
0005435443582	785239	2456 766696	LYUDMILA ORLOVA	{"phone": "+70079180129"}
0005435443583	E3648B	6455 442709	OLGA ZAYCEVA	{"phone": "+70528520659"}
0005435443584	E6B58F	2135 836801	ARTEM NIKITIN	{"phone": "+70076320699"}
0005435443585	E6B58F	9387 623225	LIDIYA KONDRATEVA	{"phone": "+70373949563"}
0005435443586	932919	8337 568327	ELENA IVANOVA	{"phone": "+70924186166"}
0005435443587	932919	1912 787589	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev_021974@postgrespro.ru", "phone": "+70570409083"}
0005435443588	BF09AB	3968 829646	TATYANA IVANOVA	{"phone": "+70998855005"}
0005435461790	DD9701	0434 536266	DARYA POLYAKOVA	{"phone": "+70765758856"}
0005435461756	6CAB31	0601 461562	YULIYA KUZNECOVA	{"email": "yuliya_kuznecova-031959@postgrespro.ru", "phone": "+70394616973"}
0005435461757	6CAB31	4126 469201	MIKHAIL IVANOV	{"email": "m-ivanov-01011975@postgrespro.ru", "phone": "+70703008461"}
0005435461758	6CAB31	1258 036500	NATALYA STEPANOVA	{"email": "natalya_stepanova051985@postgrespro.ru", "phone": "+70971805848"}
0005435461759	AFD7D9	0943 541141	IRINA KOZLOVA	{"email": "irina.kozlova.07061974@postgrespro.ru", "phone": "+70123725805"}
0005435461760	36FE98	0385 856318	NATALYA TROFIMOVA	{"phone": "+70219347224"}
0005435461761	186334	7867 635612	VYACHESLAV ZHURAVLEV	{"email": "zhuravlevvyacheslav.1973@postgrespro.ru", "phone": "+70844466261"}
0005435461762	6529A4	7737 826427	SERGEY NIKOLAEV	{"phone": "+70790266155"}
0005435461763	6529A4	1342 763836	SERGEY POPOV	{"email": "sergey.popov1977@postgrespro.ru", "phone": "+70254552662"}
0005435461764	37C5C0	9513 290080	ALEKSANDR GERASIMOV	{"phone": "+70749126789"}
0005435461765	AD97AA	9499 426888	YURIY POPOV	{"email": "yuriy.popov.121984@postgrespro.ru", "phone": "+70652489692"}
0005435461766	A662EF	1389 690781	VERA RODIONOVA	{"email": "vera_rodionova051978@postgrespro.ru", "phone": "+70482677733"}
0005435461767	25E55A	0917 435945	RIMMA RODIONOVA	{"email": "rodionovarimma-27021973@postgrespro.ru", "phone": "+70751270564"}
0005435461768	25E55A	7711 516128	GALINA EFIMOVA	{"email": "efimova.g-21101979@postgrespro.ru", "phone": "+70507764329"}
0005435461769	09E67D	7605 836022	IRINA FEDOROVA	{"email": "fedorova.irina_03011979@postgrespro.ru", "phone": "+70744167510"}
0005435461770	5FBACA	1277 666014	ALEKSANDR KAZAKOV	{"email": "akazakov-24021970@postgrespro.ru", "phone": "+70894162466"}
0005435461771	5D466C	0352 907110	NAIL GERASIMOV	{"phone": "+70057980567"}
0005435461772	18D3C9	8737 650509	OKSANA IVANOVA	{"email": "o-ivanova-08071983@postgrespro.ru", "phone": "+70235932344"}
0005435461773	18D3C9	8949 943848	TAMARA PAVLOVA	{"phone": "+70749164491"}
0005435461774	A6C690	9402 728864	NIKOLAY SCHERBAKOV	{"phone": "+70072605519"}
0005435461775	F7C64F	9354 243977	BORIS STEPANOV	{"phone": "+70965525852"}
0005435461776	F7C64F	0092 895323	GALINA KOVALEVA	{"email": "galinakovaleva_031985@postgrespro.ru", "phone": "+70996030526"}
0005435461777	EE2DBF	4948 888340	GALINA NESTEROVA	{"email": "nesterova.galina.03081969@postgrespro.ru", "phone": "+70231007963"}
0005435461778	EE2DBF	9833 398489	NINA KONOVALOVA	{"email": "konovalova-nina_03101956@postgrespro.ru", "phone": "+70384656795"}
0005435461779	EE2DBF	5255 438479	ALEKSANDR YAKOVLEV	{"email": "a_yakovlev-011973@postgrespro.ru", "phone": "+70941483299"}
0005435461780	B69A61	0333 934898	NATALYA FEDOROVA	{"phone": "+70577751986"}
0005435461781	A3740E	9739 352891	VIKTORIYA KALININA	{"phone": "+70206369454"}
0005435461782	A3740E	2674 006532	ALEKSANDR GUSEV	{"phone": "+70366469668"}
0005435461783	0F0DFD	6235 910480	KONSTANTIN KUZMIN	{"phone": "+70621813638"}
0005435461784	0F0DFD	1679 419222	ANNA BELOVA	{"email": "belovaanna101967@postgrespro.ru", "phone": "+70447309922"}
0005435461785	787488	7055 379358	TAISA SOROKINA	{"phone": "+70525338146"}
0005435461786	1F0E04	2342 423121	RAIS POPOV	{"email": "r-popov_081976@postgrespro.ru", "phone": "+70002578389"}
0005435461787	1827CF	0661 412778	ARINA DAVYDOVA	{"email": "davydova-arina.021978@postgrespro.ru", "phone": "+70948258014"}
0005435461788	A68FF9	0321 475897	ELENA VOLKOVA	{"phone": "+70249335085"}
0005435461789	7F2DB9	4379 631896	MARINA NESTEROVA	{"email": "m_nesterova16081973@postgrespro.ru", "phone": "+70519308152"}
0005435461791	DD9701	0712 647296	ANNA MELNIKOVA	{"email": "anna-melnikova.1966@postgrespro.ru", "phone": "+70717089547"}
0005435461792	2A9AC8	4434 329731	SVETLANA LAZAREVA	{"phone": "+70217011779"}
0005435461793	ED0C92	6836 952628	SERGEY TIKHONOV	{"email": "sergey-tikhonov_101976@postgrespro.ru", "phone": "+70561301850"}
0005435461794	ED0C92	5588 602627	ANDREY MAKSIMOV	{"email": "andrey.maksimov_1966@postgrespro.ru", "phone": "+70446403370"}
0005435461795	AFC8A6	1821 550838	VIKTOR SCHERBAKOV	{"phone": "+70860676951"}
0005435461796	5BA34B	3287 417047	RAMZIYA MOROZOVA	{"email": "ramziya_morozova1971@postgrespro.ru", "phone": "+70129729484"}
0005435461797	6BB54F	3428 191216	ALEKSANDR VASILEV	{"phone": "+70134979229"}
0005435461798	5C0CAB	4408 815484	IVAN AFANASEV	{"email": "i-afanasev_1970@postgrespro.ru", "phone": "+70701203061"}
0005435461799	5C0CAB	1275 983750	LYUDMILA KOZLOVA	{"phone": "+70053784898"}
0005435461800	A184EE	6875 138299	IGOR KULIKOV	{"phone": "+70227239267"}
0005435461801	500303	0415 956792	ANATOLIY ZAYCEV	{"phone": "+70605003455"}
0005435461802	500303	3315 298846	VYACHESLAV TIKHONOV	{"phone": "+70934339803"}
0005435461803	C1B026	5166 596608	VLADIMIR DAVYDOV	{"email": "davydov-vladimir.30071962@postgrespro.ru", "phone": "+70444563915"}
0005435461804	86C63E	8730 353782	PAVEL ROMANOV	{"phone": "+70798066026"}
0005435461805	233638	7482 669401	EVGENIY MIKHAYLOV	{"phone": "+70950070062"}
0005435461806	7DAF81	5795 309330	GALINA BORISOVA	{"email": "galina-borisova_27011976@postgrespro.ru", "phone": "+70590073538"}
0005435461807	28CDCA	8934 657829	VLADIMIR TIKHONOV	{"phone": "+70063048488"}
0005435461808	28CDCA	1760 744797	NIKOLAY ZAYCEV	{"phone": "+70039084682"}
0005435461809	852287	8026 205412	GENNADIY MATVEEV	{"email": "g_matveev_1968@postgrespro.ru", "phone": "+70368798184"}
0005435461810	852287	1230 095031	YURIY VOLKOV	{"phone": "+70163820086"}
0005435461811	B001A4	2011 285867	SERGEY PETROV	{"email": "sergeypetrov.1962@postgrespro.ru", "phone": "+70470152119"}
0005435461812	82BFD3	4543 229644	YURIY DMITRIEV	{"phone": "+70310747397"}
0005435461813	AC13A1	6259 963319	VYACHESLAV SOKOLOV	{"email": "v_sokolov.14111981@postgrespro.ru", "phone": "+70999500499"}
0005435461814	AC13A1	6642 941112	KRISTINA ALEKSANDROVA	{"email": "k-aleksandrova15091989@postgrespro.ru", "phone": "+70233819947"}
0005435461815	8B7D0D	5090 832819	ELENA EFREMOVA	{"email": "efremovaelena_011972@postgrespro.ru", "phone": "+70397113125"}
0005435461816	8B7D0D	2809 358937	RIMMA DANILOVA	{"email": "rimma_danilova011974@postgrespro.ru", "phone": "+70109312951"}
0005435461817	DBEC2C	1000 628580	OKSANA GUSEVA	{"email": "guseva.oksana1968@postgrespro.ru", "phone": "+70116446893"}
0005435461818	DBEC2C	8213 196146	EGOR PETROV	{"email": "petrov-egor.051976@postgrespro.ru", "phone": "+70912197436"}
0005435461819	E0C70F	7740 418971	VASILIY ZHURAVLEV	{"email": "v_zhuravlev021968@postgrespro.ru", "phone": "+70313907273"}
0005435461820	7A8E94	7416 361619	NATALYA ZAYCEVA	{"phone": "+70472639335"}
0005435461821	E85196	2837 799486	ELENA GORBUNOVA	{"phone": "+70519593434"}
0005435461822	36BA75	9809 739120	TATYANA KULIKOVA	{"phone": "+70025778870"}
0005435461823	76D09E	9885 631171	VALENTINA NOVIKOVA	{"phone": "+70434649196"}
0005435461824	B8B1F3	0353 588137	VLADIMIR ALEKSANDROV	{"email": "aleksandrov-vladimir.1968@postgrespro.ru", "phone": "+70302614032"}
0005435461825	7448E7	4092 811613	GENNADIY IVANOV	{"phone": "+70348439490"}
0005435461826	B742FA	2959 063355	ZHANNA ALEKSANDROVA	{"email": "zaleksandrova101956@postgrespro.ru", "phone": "+70473181118"}
0005435461827	CEA3D1	3847 963372	NINA KOLESNIKOVA	{"phone": "+70990911620"}
0005435461828	EAF538	5975 709752	SOFIYA KAZAKOVA	{"phone": "+70533731935"}
0005435461829	885854	1808 607861	PETR GAVRILOV	{"email": "petr.gavrilov_121970@postgrespro.ru", "phone": "+70126187860"}
0005435461830	885854	4738 837838	ANZHELA ANISIMOVA	{"phone": "+70582668922"}
0005435461831	CB97DC	2714 879163	YURIY BARANOV	{"phone": "+70133424268"}
0005435461832	CB97DC	2056 988269	SVETLANA ALEKSEEVA	{"email": "svetlana_alekseeva.25031977@postgrespro.ru", "phone": "+70506548601"}
0005435461833	EEC686	2184 976144	VIKTOR VASILEV	{"phone": "+70274011722"}
0005435461834	39CC6A	9926 839629	MARIYA IVANOVA	{"phone": "+70720962201"}
0005435461835	00CEAE	9721 192427	NATALYA ABRAMOVA	{"phone": "+70250774047"}
0005435461836	00CEAE	1484 557134	MARIYA SMIRNOVA	{"email": "msmirnova29111960@postgrespro.ru", "phone": "+70338738255"}
0005435461837	16576E	0363 432803	ANTON KOZLOV	{"email": "anton-kozlov_1970@postgrespro.ru", "phone": "+70354984701"}
0005435461838	16576E	3915 180529	ANDREY KAZAKOV	{"email": "a.kazakov-081964@postgrespro.ru", "phone": "+70314454122"}
0005435461839	16576E	1322 305064	OLGA FEDOROVA	{"email": "ofedorova071982@postgrespro.ru", "phone": "+70261811869"}
0005435461840	00216F	4880 953746	VALENTINA LOGINOVA	{"email": "loginova.valentina11031970@postgrespro.ru", "phone": "+70560420923"}
0005435461841	00216F	5268 478867	YURIY TIKHONOV	{"email": "tikhonov_y-16081966@postgrespro.ru", "phone": "+70347496617"}
0005435461842	23F876	3048 631389	VERA KOROLEVA	{"email": "koroleva-vera-07071973@postgrespro.ru", "phone": "+70407852730"}
0005435461843	23F876	6972 754003	VLADIMIR AFANASEV	{"phone": "+70693055784"}
0005435461844	1173BB	7157 136715	MARIYA POPOVA	{"phone": "+70778409616"}
0005435461845	D8C5AE	4429 118600	MARIYA MEDVEDEVA	{"phone": "+70645126021"}
0005435461846	D7B107	5214 476362	EVGENIY SEMENOV	{"email": "semenov_evgeniy_101982@postgrespro.ru", "phone": "+70022304929"}
0005435461847	80509A	0979 229277	STEPAN SOROKIN	{"email": "ssorokin.1977@postgrespro.ru", "phone": "+70942325136"}
0005435461848	58CCB5	7868 760329	SERGEY KRASNOV	{"phone": "+70753582855"}
0005435461849	7169E1	3682 093593	VALENTINA KOZLOVA	{"phone": "+70522738537"}
0005435461850	7169E1	9405 445561	ALEKSANDR ABRAMOV	{"email": "abramov.a_091974@postgrespro.ru", "phone": "+70445752688"}
0005435461851	4A15D8	6633 108439	ALEKSANDR POPOV	{"email": "popov-aleksandr_051971@postgrespro.ru", "phone": "+70319456312"}
0005435461852	DB599F	7187 014825	OLGA ISAEVA	{"email": "isaeva.olga_121976@postgrespro.ru", "phone": "+70888069782"}
0005435461853	3278E9	2405 197961	ANTONINA ANDREEVA	{"email": "andreeva_a_1960@postgrespro.ru", "phone": "+70631588769"}
0005435461854	7E6915	2170 386666	OKSANA KOZLOVA	{"email": "kozlova.oksana_111967@postgrespro.ru", "phone": "+70204796914"}
0005435461855	DE1745	9641 768108	VLADIMIR PAVLOV	{"phone": "+70523993573"}
0005435461856	92C8FB	0195 525724	GALINA RODIONOVA	{"email": "galina.rodionova30061969@postgrespro.ru", "phone": "+70051713534"}
0005435461857	222147	0022 756056	IGOR ANTONOV	{"phone": "+70999096650"}
0005435461858	222147	4037 060453	NATALYA RYABOVA	{"phone": "+70661614595"}
0005435461859	79EDE3	3722 291400	NIKOLAY STEPANOV	{"phone": "+70394772445"}
0005435461860	1165B5	4852 318258	VALERIY ROMANOV	{"phone": "+70313656945"}
0005435461861	1165B5	9526 864382	MIKHAIL PETROV	{"email": "m.petrov_1971@postgrespro.ru", "phone": "+70058607563"}
0005435461862	D3827B	9456 355885	PETR ROMANOV	{"email": "romanovpetr15021965@postgrespro.ru", "phone": "+70780549626"}
0005435461863	818F44	1561 066738	SVETLANA ORLOVA	{"phone": "+70117715101"}
0005435461864	510A4C	9311 239267	OLGA ZAKHAROVA	{"phone": "+70714943660"}
0005435461865	25A88C	2165 767117	MIKHAIL DAVYDOV	{"email": "davydov-mikhail-1967@postgrespro.ru", "phone": "+70077606897"}
0005435461866	91B83E	7520 179184	EKATERINA ALEKSEEVA	{"email": "e.alekseeva.011972@postgrespro.ru", "phone": "+70701487796"}
0005435461867	CE73D6	2442 742479	OLGA DAVYDOVA	{"email": "davydova-olga_1983@postgrespro.ru", "phone": "+70529206576"}
0005435461868	F424BD	4307 308494	DMITRIY GUSEV	{"email": "d-gusev_071974@postgrespro.ru", "phone": "+70553330444"}
0005435461869	F424BD	8041 200537	SVETLANA MAKAROVA	{"email": "s.makarova-08121975@postgrespro.ru", "phone": "+70952111342"}
0005435461870	BF0D00	2904 619598	ARTEM KUZNECOV	{"phone": "+70187972802"}
0005435461871	003936	9853 925081	VIKTORIYA KUZNECOVA	{"email": "v.kuznecova_051970@postgrespro.ru", "phone": "+70457413565"}
0005435461872	003936	2531 736342	VIKTOR KUZNECOV	{"email": "kuznecov_viktor-041972@postgrespro.ru", "phone": "+70828011878"}
0005435461873	4E219E	9073 221580	ANTONINA GAVRILOVA	{"phone": "+70052994997"}
0005435461874	DB4C55	6119 510990	NIKITA OSIPOV	{"email": "osipov-nikita.11081964@postgrespro.ru", "phone": "+70582513038"}
0005435461875	DB4C55	1259 258745	SERGEY KARPOV	{"phone": "+70951730618"}
0005435461876	B2132A	7139 949143	EKATERINA KOVALEVA	{"phone": "+70698971666"}
0005435461877	B2132A	0698 966033	PAVEL ALEKSANDROV	{"phone": "+70039214775"}
0005435461878	269278	1749 972379	GENNADIY KUDRYASHOV	{"phone": "+70841762477"}
0005435461879	269278	7128 555919	VLADIMIR PAVLOV	{"email": "pavlov.v_041968@postgrespro.ru", "phone": "+70844417164"}
0005435461880	84C126	9939 852161	ANDREY VASILEV	{"phone": "+70070510830"}
0005435461881	A35F54	1699 806585	SERGEY YAKOVLEV	{"phone": "+70995930823"}
0005435461882	10C4AB	5856 833470	EDGAR NIKOLAEV	{"email": "edgarnikolaev_071976@postgrespro.ru", "phone": "+70774331044"}
0005435461883	657881	4783 113231	SERGEY KRASNOV	{"phone": "+70442783288"}
0005435461884	B33C49	6885 171623	ROMAN KUZMIN	{"phone": "+70431767223"}
0005435461885	B33C49	1414 855782	MARIYA CHERNOVA	{"phone": "+70544901552"}
0005435461886	8BE7E8	1621 620658	VLADIMIR ANTONOV	{"phone": "+70548934816"}
0005435461887	66112A	1169 163223	ANNA IVANOVA	{"phone": "+70404732274"}
0005435461888	2B2E98	7889 577878	VLADIMIR KUZNECOV	{"email": "kuznecov.v.26051969@postgrespro.ru", "phone": "+70348946614"}
0005435461889	FEB654	5445 298647	MATVEY TARASOV	{"phone": "+70041800334"}
0005435461890	25CFCA	0744 875656	OLGA ANTONOVA	{"email": "olga.antonova-1978@postgrespro.ru", "phone": "+70006559387"}
0005435461891	4DA77B	4152 951005	OLGA ZHURAVLEVA	{"email": "zhuravlevao051967@postgrespro.ru", "phone": "+70408915291"}
0005435461892	7CF145	7645 218640	ELENA ANDREEVA	{"email": "andreeva_e27071977@postgrespro.ru", "phone": "+70012420385"}
0005435461893	7CF145	5495 488479	ALEKSANDR BORISOV	{"phone": "+70074038049"}
0005435461894	AFDA46	0345 399150	DIANA NAUMOVA	{"phone": "+70999216442"}
0005435461895	A0351E	1955 613673	LYUDMILA FEDOROVA	{"email": "lyudmila-fedorova-23101969@postgrespro.ru", "phone": "+70698635113"}
0005435461896	A0351E	1568 702353	ANDREY GRIGOREV	{"phone": "+70665729412"}
0005435461897	C2234F	3741 324843	DARINA ANDREEVA	{"email": "andreeva_d111972@postgrespro.ru", "phone": "+70922167490"}
0005435461898	CD8BC3	0023 026853	ALEKSANDR FILIPPOV	{"email": "aleksandr-filippov-041965@postgrespro.ru", "phone": "+70451944736"}
0005435461899	BFA86F	5266 702445	ELIZAVETA BARANOVA	{"email": "elizaveta.baranova_1971@postgrespro.ru", "phone": "+70625473864"}
0005435461900	BFA86F	4108 179548	MIKHAIL KISELEV	{"phone": "+70179076753"}
0005435461901	ADF1F2	0916 053796	ALEKSEY SERGEEV	{"email": "sergeev_a-09101974@postgrespro.ru", "phone": "+70352387578"}
0005435461902	EDBF3A	4833 764314	OLGA OVCHINNIKOVA	{"email": "ovchinnikova_olga011977@postgrespro.ru", "phone": "+70587399561"}
0005435461903	EDBF3A	7992 759313	IRINA MELNIKOVA	{"email": "melnikova_irina.021967@postgrespro.ru", "phone": "+70660062061"}
0005435461904	EDBF3A	2933 918781	LYUDMILA SIDOROVA	{"email": "lyudmila_sidorova-091963@postgrespro.ru", "phone": "+70431512690"}
0005435461905	A044D0	8330 224582	TATYANA OVCHINNIKOVA	{"email": "ovchinnikovatatyana-121965@postgrespro.ru", "phone": "+70167440223"}
0005435461906	A044D0	9649 610919	ALEKSANDR MOISEEV	{"phone": "+70692001120"}
0005435461907	962AD2	8847 405704	NIKOLAY CHERNOV	{"email": "chernov_nikolay_29051975@postgrespro.ru", "phone": "+70240287501"}
0005435461908	2CA8AE	8992 437250	ANDREY IVANOV	{"phone": "+70391351277"}
0005435461909	A4DBD2	2584 204693	DMITRIY NAUMOV	{"email": "naumov-d_1970@postgrespro.ru", "phone": "+70170950557"}
0005435461910	A4DBD2	4338 870814	LARISA BELOVA	{"phone": "+70433690168"}
0005435461911	E74EF5	9805 352374	VLADIMIR PAVLOV	{"phone": "+70258116344"}
0005435461912	191637	1620 262464	TATYANA ALEKSANDROVA	{"phone": "+70009980802"}
0005435461913	BE12EF	6093 443294	ARTEM ANDREEV	{"phone": "+70246725215"}
0005435461914	BE12EF	6938 887916	SVETLANA FOMINA	{"phone": "+70816674896"}
0005435461915	FFD3C1	5590 229942	YURIY MAKSIMOV	{"phone": "+70586373711"}
0005435461916	2088F9	7918 458412	DMITRIY TIKHONOV	{"phone": "+70252119991"}
0005435461917	2088F9	9373 792513	NADEZHDA PETROVA	{"phone": "+70173015918"}
0005435461918	AFE68E	2024 971879	EVGENIY IVANOV	{"email": "eivanov041973@postgrespro.ru", "phone": "+70630894461"}
0005435461919	AFE68E	5410 010208	OLGA AFANASEVA	{"phone": "+70726439966"}
0005435461920	20E6BE	3565 905201	YULIYA IVANOVA	{"email": "ivanova_y.1965@postgrespro.ru", "phone": "+70916234870"}
0005435461921	20E6BE	9419 127592	VALENTINA MIRONOVA	{"email": "vmironova.1967@postgrespro.ru", "phone": "+70865211147"}
0005435461922	20E6BE	2722 375667	ANNA MIKHAYLOVA	{"email": "mikhaylova.a-25071959@postgrespro.ru", "phone": "+70014272845"}
0005435461923	C6A31D	1402 511058	NADEZHDA NOVIKOVA	{"email": "novikova_n.1954@postgrespro.ru", "phone": "+70562994344"}
0005435461924	C6A31D	6146 763194	ILYA FOMIN	{"phone": "+70492133520"}
0005435461925	E4290C	7248 604550	NATALYA PAVLOVA	{"phone": "+70521907123"}
0005435461926	E4290C	4613 634679	YURIY KUZMIN	{"email": "ykuzmin-1972@postgrespro.ru", "phone": "+70350082994"}
0005435461927	C4293F	3301 072975	GALIYA LUKYANOVA	{"email": "g.lukyanova_11051975@postgrespro.ru", "phone": "+70779813358"}
0005435461928	4F94ED	7503 527026	ANNA MOROZOVA	{"email": "morozova-a-1973@postgrespro.ru", "phone": "+70068904819"}
0005435461929	46CDCD	9776 307027	YURIY IVANOV	{"phone": "+70972543550"}
0005435461930	4F3A99	6673 518434	VLADIMIR OSIPOV	{"email": "vladimir.osipov-14021977@postgrespro.ru", "phone": "+70133744610"}
0005435461931	C51B9C	9747 976970	DMITRIY NAUMOV	{"email": "naumov-d031971@postgrespro.ru", "phone": "+70149210350"}
0005435461932	0BFF3E	8588 833589	ALEKSANDR CHERNOV	{"phone": "+70160453439"}
0005435461933	6BAF81	8727 941815	MARIYA KULIKOVA	{"phone": "+70259031057"}
0005435461934	BFF51F	0136 506936	OLGA MASLOVA	{"email": "olga-maslova091977@postgrespro.ru", "phone": "+70858312116"}
0005435461935	ED4C02	2740 149673	OLGA KALININA	{"phone": "+70006178686"}
0005435461936	7E3F47	4333 095448	LYUDMILA KOROLEVA	{"email": "koroleva-l1959@postgrespro.ru", "phone": "+70634348367"}
0005435461937	851FB6	0099 774186	IVAN PAVLOV	{"phone": "+70333965247"}
0005435461938	851FB6	5412 684964	TIMUR IVANOV	{"email": "ivanov-timur-121961@postgrespro.ru", "phone": "+70331490498"}
0005435461939	37C668	7220 344347	SVETLANA KUZMINA	{"phone": "+70571089744"}
0005435461940	36AFB6	6110 065236	VERONIKA YUDINA	{"phone": "+70384148218"}
0005435461941	1B46AA	9134 200379	OLGA KOZLOVA	{"phone": "+70912552326"}
0005435461942	1B46AA	3488 731763	ANNA TROFIMOVA	{"email": "trofimova.a.1969@postgrespro.ru", "phone": "+70372472073"}
0005435461943	2B6F37	1441 902286	VLADIMIR IVANOV	{"email": "vladimir_ivanov-1980@postgrespro.ru", "phone": "+70823561442"}
0005435461944	21A588	4107 448496	NINA NIKITINA	{"phone": "+70438003332"}
0005435461945	21A588	4639 640258	ANDREY KUZMIN	{"email": "kuzmin.a.01081983@postgrespro.ru", "phone": "+70671897824"}
0005435461946	5B9AC7	9204 320097	GALINA TARASOVA	{"email": "g_tarasova.021978@postgrespro.ru", "phone": "+70874396721"}
0005435461947	5B9AC7	9595 870025	NATALYA LOGINOVA	{"phone": "+70835979598"}
0005435461948	7DA318	7362 573610	IVAN POPOV	{"phone": "+70146163588"}
0005435461949	39F98D	6221 898075	ANTON SEMENOV	{"phone": "+70404417817"}
0005435461950	39F98D	4829 315596	EVGENIYA MAKAROVA	{"phone": "+70350253036"}
0005435461951	699B72	0481 910764	SVETLANA KRASNOVA	{"phone": "+70178428261"}
0005435461952	699B72	7648 249138	ALEKSANDR ILIN	{"phone": "+70624037254"}
0005435461953	699B72	6379 741125	LYUBOV ALEKSEEVA	{"email": "alekseeva.l-1968@postgrespro.ru", "phone": "+70257153642"}
0005435461954	C89FCD	0443 369128	ANNA MAKAROVA	{"email": "anna.makarova_1979@postgrespro.ru", "phone": "+70508180831"}
0005435461955	C89FCD	2538 918794	ALEKSANDR ALEKSEEV	{"email": "alekseev-aleksandr_071975@postgrespro.ru", "phone": "+70281542248"}
0005435461956	F83689	1174 163230	NATALYA GERASIMOVA	{"email": "gerasimova_natalya011973@postgrespro.ru", "phone": "+70112877649"}
0005435461957	DCB891	7288 634287	ANDREY ROMANOV	{"email": "romanov.andrey-1980@postgrespro.ru", "phone": "+70388473520"}
0005435461958	F81770	8225 440027	SVETLANA BELOVA	{"phone": "+70328227047"}
0005435461959	DAFFD3	2091 021257	KIRILL ZAYCEV	{"phone": "+70170306167"}
0005435461960	C58DED	9550 428772	ANNA NIKIFOROVA	{"email": "nikiforova_anna-10021968@postgrespro.ru", "phone": "+70211369353"}
0005435461961	0EE763	3539 930293	LIDIYA IVANOVA	{"email": "ivanova_lidiya.03101972@postgrespro.ru", "phone": "+70417934361"}
0005435461962	1F89F0	6859 933375	DMITRIY ANDREEV	{"phone": "+70715386792"}
0005435461963	A5E18A	2106 690024	YURIY NAZAROV	{"email": "y_nazarov.081974@postgrespro.ru", "phone": "+70809156908"}
0005435461964	FE9BAA	4977 103317	ANDREY KOZLOV	{"phone": "+70563074927"}
0005435461965	FE9BAA	8041 947040	ELENA NIKOLAEVA	{"phone": "+70663552569"}
0005435461966	7FEC3C	0455 295542	VLADIMIR ILIN	{"phone": "+70639012900"}
0005435461967	37F563	2324 125832	ALEKSEY KUZNECOV	{"email": "aleksey-kuznecov-071967@postgrespro.ru", "phone": "+70622561853"}
0005435461968	4D0877	1636 827470	VITALIY KUDRYASHOV	{"email": "vkudryashov.091984@postgrespro.ru", "phone": "+70979493715"}
0005435461969	619318	2461 261651	MILANA IVANOVA	{"email": "ivanovamilana071980@postgrespro.ru", "phone": "+70026611497"}
0005435461970	AB5457	8165 112786	DMITRIY MAKAROV	{"phone": "+70945968551"}
0005435461971	AB5457	3256 423730	DANIIL VLASOV	{"email": "d.vlasov-1972@postgrespro.ru", "phone": "+70437480037"}
0005435461972	E3DDAF	3028 139238	VADIM KAZAKOV	{"email": "vadim-kazakov-1980@postgrespro.ru", "phone": "+70549924316"}
0005435461973	966960	0099 618824	SVETLANA ZAYCEVA	{"email": "zayceva-s_1975@postgrespro.ru", "phone": "+70840450494"}
0005435461974	CDB1EE	5271 369609	ALEKSANDR TARASOV	{"email": "tarasov.a19071973@postgrespro.ru", "phone": "+70562513576"}
0005435461975	0D252F	0946 912652	IVAN CHERNOV	{"email": "chernov_i_1968@postgrespro.ru", "phone": "+70884327177"}
0005435461976	52DC6E	7308 402100	VERONIKA DAVYDOVA	{"phone": "+70876396395"}
0005435461977	52DC6E	3411 143216	NATALYA POPOVA	{"phone": "+70666509250"}
0005435461978	CABBD4	9264 804301	ELENA IVANOVA	{"phone": "+70169541879"}
0005435461979	CABBD4	5685 192791	ALEKSANDR ISAEV	{"phone": "+70186677308"}
0005435461980	74E315	1809 143053	MAKSIM OSIPOV	{"phone": "+70908894384"}
0005435461981	74E315	5169 592205	ZLATA MASLOVA	{"email": "zlata-maslova-1968@postgrespro.ru", "phone": "+70304864092"}
0005435461982	74E315	4006 245016	VERA ABRAMOVA	{"phone": "+70480050520"}
0005435461983	3D9D0C	4264 082502	TATYANA ORLOVA	{"phone": "+70580558848"}
0005435461984	3D9D0C	7341 807943	GAGIK IVANOV	{"phone": "+70594568836"}
0005435461985	827B76	5179 501088	MIKHAIL SIDOROV	{"phone": "+70109326486"}
0005435461986	827B76	3532 047676	ALINA ORLOVA	{"email": "orlova_a.1980@postgrespro.ru", "phone": "+70627188983"}
0005435461987	AEFA6C	6110 337786	ALEKSANDR DMITRIEV	{"phone": "+70579555239"}
0005435461988	24E769	2481 843409	GALINA KUZNECOVA	{"email": "g_kuznecova.051985@postgrespro.ru", "phone": "+70515224505"}
0005435461989	6DFFB1	9122 576252	LYUBOV AFANASEVA	{"phone": "+70585204933"}
0005435461990	FA9C58	9243 113306	ELENA DAVYDOVA	{"email": "davydova-elena1974@postgrespro.ru", "phone": "+70770435427"}
0005435461991	8D943D	8853 495154	ARTEM NOVIKOV	{"phone": "+70444129555"}
0005435461992	09028B	8024 078847	LILIYA SERGEEVA	{"email": "liliyasergeeva.071965@postgrespro.ru", "phone": "+70704299409"}
0005435461993	BE9733	8455 005479	PAVEL FOMIN	{"phone": "+70061493457"}
0005435461994	BE9733	0276 866663	PAVEL KUZNECOV	{"email": "kuznecov_pavel-1978@postgrespro.ru", "phone": "+70574958685"}
0005435461995	BE9733	0620 072448	VLADIMIR IVANOV	{"phone": "+70478683388"}
0005435461996	A68905	6012 490232	ALLA NAUMOVA	{"phone": "+70694973468"}
0005435461997	A68905	5050 944276	MARIYA POPOVA	{"phone": "+70892603345"}
0005435461998	ABE9E8	9991 564661	NIKOLAY VLASOV	{"email": "nikolayvlasov_121968@postgrespro.ru", "phone": "+70501434571"}
0005435461999	498E28	7016 472367	ZOYA FEDOROVA	{"phone": "+70196557467"}
0005435462000	5C9A8C	6548 756276	ALINA GAVRILOVA	{"email": "gavrilovaalina_24101969@postgrespro.ru", "phone": "+70232955242"}
0005435462001	9181CF	2876 183169	LYUDMILA NESTEROVA	{"phone": "+70549575809"}
0005435462002	27B492	9116 948297	ALEKSANDR SMIRNOV	{"email": "smirnov.a_20071973@postgrespro.ru", "phone": "+70653056630"}
0005435462003	5EFECE	9382 202203	NINA GUSEVA	{"email": "guseva-nina-061970@postgrespro.ru", "phone": "+70018659226"}
0005435462004	5EFECE	9655 195007	ALEKSANDR BORISOV	{"email": "aborisov_111972@postgrespro.ru", "phone": "+70286476406"}
0005435462005	1019A9	5386 867203	SERGEY SMIRNOV	{"email": "smirnov.sergey-16091981@postgrespro.ru", "phone": "+70928842180"}
0005435462006	502EA6	0988 259978	KRISTINA PETROVA	{"email": "petrova-k.1978@postgrespro.ru", "phone": "+70661024731"}
0005435462007	CB6ADD	0646 850618	GULNARA POTAPOVA	{"email": "potapova.g-25021982@postgrespro.ru", "phone": "+70081275887"}
0005435462008	5E852D	5695 404337	OKSANA MATVEEVA	{"phone": "+70373364633"}
0005435462009	5E852D	5856 561382	GALINA EFREMOVA	{"email": "g-efremova_15081977@postgrespro.ru", "phone": "+70347857215"}
0005435462010	C76754	6478 568809	YULIYA TROFIMOVA	{"email": "trofimovay-101972@postgrespro.ru", "phone": "+70297054196"}
0005435462011	C76754	5297 105036	NINA IVANOVA	{"phone": "+70270486266"}
0005435462012	C76754	0894 890794	NIKOLAY VOLKOV	{"email": "n-volkov_30031969@postgrespro.ru", "phone": "+70888372419"}
0005435462013	B83875	2224 379059	TATYANA SOROKINA	{"email": "tsorokina26061972@postgrespro.ru", "phone": "+70884491122"}
0005435462014	B83875	0048 547368	EVGENIY ZHUKOV	{"phone": "+70416290876"}
0005435462015	1271C3	8901 774512	REGINA MAKAROVA	{"email": "regina.makarova1974@postgrespro.ru", "phone": "+70170625402"}
0005435462016	1271C3	1480 384895	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir.24051968@postgrespro.ru", "phone": "+70805694413"}
0005435462017	1C2FE4	9126 380996	IGOR VASILEV	{"email": "igorvasilev-1968@postgrespro.ru", "phone": "+70495034427"}
0005435462018	8208E3	4926 254160	YULIYA POPOVA	{"email": "popovayuliya_031980@postgrespro.ru", "phone": "+70101784585"}
0005435462019	D69026	3294 356617	VYACHESLAV ZAKHAROV	{"phone": "+70447964709"}
0005435462020	EBF88D	5839 052989	SERGEY OSIPOV	{"phone": "+70863449544"}
0005435462021	EBF88D	9295 820629	ALEKSANDR ANTONOV	{"email": "antonovaleksandr-071973@postgrespro.ru", "phone": "+70456014213"}
0005435462022	EBF88D	3257 707703	DMITRIY ZHUKOV	{"email": "zhukov_dmitriy.021969@postgrespro.ru", "phone": "+70802058482"}
0005435462023	8CA05D	4265 131922	GLEB ZAKHAROV	{"email": "g.zakharov_20021962@postgrespro.ru", "phone": "+70205011204"}
0005435462024	8B96CE	8842 335406	IGOR SMIRNOV	{"phone": "+70001307393"}
0005435462025	D97927	5978 038465	PELAGEYA SIDOROVA	{"phone": "+70218345764"}
0005435462026	D97927	9611 723671	FARID GUSEV	{"phone": "+70641652285"}
0005435462027	5B4B04	2588 482220	ANASTASIYA VLASOVA	{"email": "vlasova.anastasiya_18011980@postgrespro.ru", "phone": "+70412511112"}
0005435462028	5B4B04	3364 419779	MARIYA POPOVA	{"phone": "+70587524227"}
0005435462029	68EB51	1892 075975	ANDREY KOZLOV	{"phone": "+70998525341"}
0005435462030	88AA02	8408 894931	ALEKSEY IVANOV	{"phone": "+70183988004"}
0005435462031	F66AD2	7775 686535	PELAGEYA ERMAKOVA	{"phone": "+70356331684"}
0005435462032	4A75EA	7191 092881	NINA VASILEVA	{"email": "vasileva_n-02011972@postgrespro.ru", "phone": "+70904737820"}
0005435462033	4A75EA	4536 822640	VALENTINA NIKOLAEVA	{"email": "nikolaeva_v1981@postgrespro.ru", "phone": "+70041038424"}
0005435462034	574E3B	8404 192921	ELENA GRISHINA	{"email": "elena-grishina-081981@postgrespro.ru", "phone": "+70499120666"}
0005435462035	574E3B	6728 246734	NATALYA MATVEEVA	{"phone": "+70163167908"}
0005435462036	DBC195	5279 273910	OLGA VASILEVA	{"email": "vasilevao-071977@postgrespro.ru", "phone": "+70086938558"}
0005435462037	6450C1	8670 106484	NATALYA VOROBEVA	{"email": "vorobeva-natalya_121964@postgrespro.ru", "phone": "+70731637547"}
0005435462038	8D53DA	0567 480536	MARIYA VOLKOVA	{"email": "volkovam.1975@postgrespro.ru", "phone": "+70881128856"}
0005435462039	DAC505	5378 873376	VIKTORIYA ROMANOVA	{"email": "romanova.viktoriya.091973@postgrespro.ru", "phone": "+70354960838"}
0005435462040	75A70A	4419 405373	ALEKSANDRA ILINA	{"email": "a-ilina.1976@postgrespro.ru", "phone": "+70080849052"}
0005435462041	C26A25	7026 069932	ILYA GERASIMOV	{"email": "i.gerasimov.1959@postgrespro.ru", "phone": "+70535535314"}
0005435462042	1FEA69	4074 923260	NINA AFANASEVA	{"email": "afanaseva-n-021981@postgrespro.ru", "phone": "+70485517407"}
0005435462043	1FEA69	3959 661575	DMITRIY ILIN	{"email": "dmitriyilin_101980@postgrespro.ru", "phone": "+70233062522"}
0005435462044	1110CF	8544 838570	TATYANA POPOVA	{"email": "t-popova_1986@postgrespro.ru", "phone": "+70883779319"}
0005435462045	A40B3E	1826 937405	VIKTORIYA VASILEVA	{"email": "vasileva.v.17121966@postgrespro.ru", "phone": "+70544396010"}
0005435462046	5E5941	6862 153012	ZOYA ZAKHAROVA	{"phone": "+70509586763"}
0005435462047	ECA462	9181 463914	MARIYA KUZMINA	{"email": "mariya_kuzmina_1962@postgrespro.ru", "phone": "+70587916941"}
0005435462048	ECA462	8379 351364	VERA VASILEVA	{"email": "vasileva.vera061976@postgrespro.ru", "phone": "+70224683646"}
0005435462049	BED764	8944 828297	TAMARA ANISIMOVA	{"phone": "+70918723059"}
0005435462050	D19957	8802 619122	VIKTOR STEPANOV	{"email": "v.stepanov-05021967@postgrespro.ru", "phone": "+70540705500"}
0005435462051	764C62	1738 255486	TATYANA MIKHAYLOVA	{"phone": "+70059081851"}
0005435462052	764C62	1799 384275	ELIZAVETA IVANOVA	{"phone": "+70403986390"}
0005435462053	185556	5744 322697	ANASTASIYA KOLESNIKOVA	{"email": "kolesnikova.anastasiya25071986@postgrespro.ru", "phone": "+70045930258"}
0005435462054	2118F3	0805 990247	LILIYA NIKITINA	{"email": "nikitinaliliya1959@postgrespro.ru", "phone": "+70591177792"}
0005435462055	6646AA	9369 929792	TAMARA SAVELEVA	{"email": "tamarasaveleva111983@postgrespro.ru", "phone": "+70353324066"}
0005435462056	12A4E7	4837 236364	EVGENIYA KISELEVA	{"email": "kiseleva.e_051976@postgrespro.ru", "phone": "+70157812939"}
0005435462057	A1CBE9	3499 326198	SVETLANA TITOVA	{"email": "titova-svetlana-1977@postgrespro.ru", "phone": "+70380560341"}
0005435462058	116F56	1604 141858	VLADIMIR KUZNECOV	{"email": "vladimir-kuznecov-121972@postgrespro.ru", "phone": "+70372830963"}
0005435462059	116F56	4027 856570	NINA ABRAMOVA	{"email": "abramova_n.1987@postgrespro.ru", "phone": "+70788476736"}
0005435462060	28DB8A	7301 492494	VASILIY KONOVALOV	{"email": "v_konovalov-1980@postgrespro.ru", "phone": "+70423170700"}
0005435462061	CC2273	5985 755698	EKATERINA SMIRNOVA	{"phone": "+70352753257"}
0005435462062	600527	8761 434012	LYUBOV GRISHINA	{"email": "l-grishina_23031974@postgrespro.ru", "phone": "+70693754997"}
0005435462063	600527	3722 775611	IRINA OVCHINNIKOVA	{"phone": "+70750785301"}
0005435462064	381015	0987 035401	ALEKSEY PETROV	{"email": "aleksey.petrov-011966@postgrespro.ru", "phone": "+70978880904"}
0005435462065	381015	3667 439475	LARISA LUKYANOVA	{"phone": "+70388347195"}
0005435462066	5584B0	0988 980740	SERGEY IVANOV	{"phone": "+70139373419"}
0005435462067	5584B0	4707 887082	VLADIMIR FILIPPOV	{"email": "v-filippov_06071977@postgrespro.ru", "phone": "+70724220785"}
0005435462068	5584B0	5044 907554	ARTEM KUZMIN	{"phone": "+70938166348"}
0005435462069	65E5B3	0714 880094	BORIS IVANOV	{"email": "ivanov-b_20021963@postgrespro.ru", "phone": "+70896479945"}
0005435462070	65E5B3	7519 450605	NINA ANTONOVA	{"phone": "+70702173060"}
0005435462071	9DA9C6	3017 170000	TATYANA ORLOVA	{"phone": "+70233884296"}
0005435462072	9DA9C6	5421 449065	LYUBOV KUZNECOVA	{"phone": "+70587723388"}
0005435462073	775A7B	6909 530256	NADEZHDA OSIPOVA	{"email": "osipovanadezhda-09101973@postgrespro.ru", "phone": "+70771439222"}
0005435462074	2CC78D	8925 934080	MARIYA EGOROVA	{"email": "mariyaegorova_1968@postgrespro.ru", "phone": "+70798708065"}
0005435462075	9733F6	9857 134543	ALEKSANDR VASILEV	{"phone": "+70447115270"}
0005435462076	9733F6	3763 440898	LYUDMILA KUZMINA	{"phone": "+70138402332"}
0005435462077	52AEB3	6880 529956	ZOYA BOGDANOVA	{"phone": "+70529339855"}
0005435462078	D0FEBC	8332 543049	DMITRIY BONDARENKO	{"phone": "+70550667201"}
0005435462079	FFEA06	8635 945783	NIKITA YAKOVLEV	{"phone": "+70525781904"}
0005435462080	FFEA06	2903 130399	VASILIY SEMENOV	{"email": "v-semenov-1987@postgrespro.ru", "phone": "+70829610271"}
0005435462081	D78655	7979 755474	VIKTOR SOROKIN	{"phone": "+70069927143"}
0005435462082	1B9493	4636 445963	DANILA GRIGOREV	{"phone": "+70551853696"}
0005435462083	1B9493	2432 271185	ANNA KULIKOVA	{"email": "kulikova.a_1979@postgrespro.ru", "phone": "+70039930603"}
0005435462084	1B9493	6994 040843	MARINA KAZAKOVA	{"email": "kazakova.marina-19021973@postgrespro.ru", "phone": "+70265546150"}
0005435462085	4601DA	1217 953188	SVETLANA KOVALEVA	{"email": "kovaleva-s1983@postgrespro.ru", "phone": "+70707356641"}
0005435462086	CD518D	0454 805936	VASILIY KUDRYASHOV	{"email": "vasiliy_kudryashov-111976@postgrespro.ru", "phone": "+70169722755"}
0005435462087	CD518D	6122 459277	MAKSIM MAKAROV	{"phone": "+70269392457"}
0005435462088	0B5C30	5592 388962	EKATERINA SOROKINA	{"phone": "+70346705941"}
0005435462089	5FA55C	7295 633679	VALENTINA FROLOVA	{"email": "valentina-frolova_19031984@postgrespro.ru", "phone": "+70016518368"}
0005435462090	EEF0C4	1508 221237	LIDIYA ZAKHAROVA	{"email": "zakharovalidiya091977@postgrespro.ru", "phone": "+70882116856"}
0005435462091	43853F	1552 443126	ALEKSANDR SOROKIN	{"email": "asorokin051974@postgrespro.ru", "phone": "+70719879735"}
0005435462092	43853F	9196 362104	LARISA BORISOVA	{"phone": "+70211089432"}
0005435462093	698DF0	1525 836586	ILNUR DMITRIEV	{"email": "dmitrievi-09011978@postgrespro.ru", "phone": "+70848826768"}
0005435462094	698DF0	7165 251673	YAROSLAV ILIN	{"phone": "+70870130258"}
0005435462095	852E81	9249 573578	LYUBOV EGOROVA	{"email": "egorova.l1970@postgrespro.ru", "phone": "+70679789731"}
0005435462096	5A451D	1007 921983	VLADIMIR TIMOFEEV	{"email": "timofeev.vladimir-14101972@postgrespro.ru", "phone": "+70596821261"}
0005435462097	5A451D	9541 385678	YANA KONOVALOVA	{"phone": "+70380238285"}
0005435462098	77D5CE	5744 892837	DMITRIY KUDRYASHOV	{"phone": "+70954439382"}
0005435462099	F255DB	0459 298399	ALEKSEY OSIPOV	{"email": "alekseyosipov_21011973@postgrespro.ru", "phone": "+70488231993"}
0005435462100	81AFA7	2244 557362	ELMIRA SOROKINA	{"phone": "+70558613138"}
0005435462101	F5008A	4497 598063	ALEKSANDR ANDREEV	{"email": "aleksandrandreev.101965@postgrespro.ru", "phone": "+70198428650"}
0005435462102	F5008A	8001 459983	OLGA SOROKINA	{"phone": "+70175669344"}
0005435462103	CE8AAE	7051 986710	GALINA CHERNOVA	{"phone": "+70282825370"}
0005435462104	D2BB72	4194 999122	ELENA VOLKOVA	{"phone": "+70371682443"}
0005435462105	C5C94B	6390 332993	MIKHAIL KARPOV	{"email": "karpov-m_1970@postgrespro.ru", "phone": "+70536134670"}
0005435462106	C5C94B	1613 856386	VALERIY IVANOV	{"phone": "+70818133759"}
0005435462107	DBF68D	4259 440472	MAKSIM AFANASEV	{"email": "maksim-afanasev_011975@postgrespro.ru", "phone": "+70495286801"}
0005435462108	A9B973	0971 984953	VALENTINA ANISIMOVA	{"phone": "+70364094471"}
0005435462109	D1710E	5356 110342	VYACHESLAV MATVEEV	{"email": "matveev.vyacheslav.1973@postgrespro.ru", "phone": "+70881762400"}
0005435462110	8A4821	0224 655530	YULIYA ISAEVA	{"email": "isaevayuliya_29031981@postgrespro.ru", "phone": "+70554198631"}
0005435462111	288EA3	2755 791360	LARISA ANISIMOVA	{"phone": "+70251140669"}
0005435462112	175672	5334 784598	VLADIMIR SHEVCHENKO	{"email": "shevchenko.v1971@postgrespro.ru", "phone": "+70509668039"}
0005435462113	175672	3107 347444	VALENTINA EFIMOVA	{"email": "v_efimova_16121965@postgrespro.ru", "phone": "+70248409047"}
0005435462114	95B126	1719 303224	DMITRIY GERASIMOV	{"phone": "+70761428144"}
0005435462115	95B126	5047 421720	SERGEY IVANOV	{"email": "s.ivanov_121981@postgrespro.ru", "phone": "+70978030818"}
0005435462116	F5C297	3807 836933	ANATOLIY IVANOV	{"email": "aivanov01051981@postgrespro.ru", "phone": "+70201368321"}
0005435462117	DCAB8A	1276 666643	MARIYA AFANASEVA	{"phone": "+70165490230"}
0005435462118	0A08BB	0020 441555	IRINA ALEKSEEVA	{"email": "alekseeva-i121971@postgrespro.ru", "phone": "+70472982613"}
0005435462119	0A08BB	2399 942545	OLGA STEPANOVA	{"phone": "+70610279593"}
0005435462120	3B8F53	8691 258337	VLADIMIR SEMENOV	{"email": "semenov.vladimir021967@postgrespro.ru", "phone": "+70104003546"}
0005435462121	3B8F53	3520 566933	NIKITA ZAYCEV	{"phone": "+70401610056"}
0005435462122	BB63DA	2058 205515	RAISA AKIMOVA	{"phone": "+70809630505"}
0005435462123	CB66C9	4849 409345	RAISA NOVIKOVA	{"email": "novikova-r-16011965@postgrespro.ru", "phone": "+70793640123"}
0005435462124	A64D06	1686 608579	ANNA POPOVA	{"email": "popova_anna_03091976@postgrespro.ru", "phone": "+70566374073"}
0005435462125	DDC469	4928 988475	ALEKSANDR ZHURAVLEV	{"email": "zhuravlevaleksandr-041973@postgrespro.ru", "phone": "+70507308733"}
0005435462126	DDC469	8468 915213	LYUBOV SOLOVEVA	{"email": "soloveva-l.1977@postgrespro.ru", "phone": "+70085131380"}
0005435462127	EF3486	2549 155253	LIDIYA ZHUKOVA	{"phone": "+70018069851"}
0005435462128	EF3486	2771 640196	NINA SOKOLOVA	{"email": "sokolova_nina_22021961@postgrespro.ru", "phone": "+70198922126"}
0005435462129	24CCA8	2656 976676	NATALYA ANTONOVA	{"email": "antonova.n_1959@postgrespro.ru", "phone": "+70699636328"}
0005435462130	FFAFAB	0931 259671	RUSHANIYA BARANOVA	{"email": "baranova.rushaniya.121977@postgrespro.ru", "phone": "+70982036416"}
0005435462131	851167	3500 528688	EVGENIY TARASOV	{"phone": "+70262411526"}
0005435462132	851167	5728 737016	SVETLANA ZAKHAROVA	{"email": "szakharova_041970@postgrespro.ru", "phone": "+70354541837"}
0005435462133	00AD37	8846 651961	EDUARD GUSEV	{"email": "e-gusev-1977@postgrespro.ru", "phone": "+70892717906"}
0005435462134	83CF99	4157 925219	YURIY IVANOV	{"email": "y_ivanov-1973@postgrespro.ru", "phone": "+70358454541"}
0005435462135	DB28DF	3918 923853	BOGDAN BONDARENKO	{"phone": "+70039272229"}
0005435462136	86886B	0649 442292	TAMARA NIKOLAEVA	{"phone": "+70935532420"}
0005435462137	4AE307	8585 984808	YURIY KULIKOV	{"phone": "+70417721256"}
0005435462138	4AE307	6306 905485	SAVELIY ANTONOV	{"phone": "+70715952809"}
0005435462139	CCB667	9841 857655	NATALYA ZHUKOVA	{"email": "natalya_zhukova-051981@postgrespro.ru", "phone": "+70382552414"}
0005435462140	5101CA	6326 383376	VALERIY KUZNECOV	{"phone": "+70787836066"}
0005435462141	AF319E	9695 276284	ALEKSANDRA ANTONOVA	{"email": "antonova_aleksandra_1975@postgrespro.ru", "phone": "+70770461085"}
0005435462142	AF319E	1442 606383	LILIYA EFREMOVA	{"email": "liliya.efremova-26071961@postgrespro.ru", "phone": "+70834587946"}
0005435462143	4B20D4	3932 402012	VALENTINA POLYAKOVA	{"email": "polyakovav.031972@postgrespro.ru", "phone": "+70547202740"}
0005435462144	FA08EA	2367 948648	LYUDMILA LEBEDEVA	{"email": "llebedeva.011984@postgrespro.ru", "phone": "+70713428936"}
0005435462145	C23C1B	7230 111038	SABINA NAUMOVA	{"email": "sabina.naumova_08011974@postgrespro.ru", "phone": "+70901906316"}
0005435462146	C23C1B	0955 277455	VLADIMIR NIKOLAEV	{"email": "vladimir_nikolaev17031966@postgrespro.ru", "phone": "+70044556487"}
0005435462147	07B172	3071 504007	VITALIY BONDARENKO	{"email": "bondarenkovitaliy16021965@postgrespro.ru", "phone": "+70781353311"}
0005435462148	A7B934	0078 009588	VALENTINA SIDOROVA	{"email": "valentina_sidorova-14031968@postgrespro.ru", "phone": "+70917670601"}
0005435462149	A7B934	4639 253440	DANILA ILIN	{"email": "danila_ilin-1965@postgrespro.ru", "phone": "+70948656086"}
0005435462150	055DD3	7860 988557	NINA TITOVA	{"phone": "+70983758798"}
0005435462151	E89DE1	7626 645973	VALENTINA STEPANOVA	{"email": "vstepanova-1970@postgrespro.ru", "phone": "+70811780030"}
0005435462152	150983	9504 439032	OLGA SERGEEVA	{"phone": "+70011247004"}
0005435462153	752C0E	8090 431979	VLADIMIR OSIPOV	{"phone": "+70345859073"}
0005435462154	752C0E	4863 884616	LARISA MAKAROVA	{"phone": "+70753255237"}
0005435462155	DA5717	3315 754623	VALENTINA MOISEEVA	{"email": "moiseeva.v.041982@postgrespro.ru", "phone": "+70807325644"}
0005435462156	FE67AE	5144 802438	VALERIY GUSEV	{"phone": "+70908746553"}
0005435462157	97EB95	3430 104974	ALEKSEY FEDOROV	{"phone": "+70898672298"}
0005435462158	601E40	2350 629420	DARYA KOROLEVA	{"email": "darya.koroleva011980@postgrespro.ru", "phone": "+70158385319"}
0005435462159	601E40	1232 096941	MIKHAIL ZAKHAROV	{"email": "mikhailzakharov.13101972@postgrespro.ru", "phone": "+70582816283"}
0005435462160	B1239E	7335 713102	VALENTINA FADEEVA	{"email": "valentina_fadeeva.041973@postgrespro.ru", "phone": "+70584413416"}
0005435462161	B1239E	2560 534025	KONSTANTIN TARASOV	{"email": "tarasov.k_07071967@postgrespro.ru", "phone": "+70441406385"}
0005435462162	3D8487	0695 175360	NATALYA FEDOROVA	{"email": "natalyafedorova-19011966@postgrespro.ru", "phone": "+70443840768"}
0005435462163	3D8487	3886 964640	LILIYA RODIONOVA	{"email": "liliya_rodionova30041966@postgrespro.ru", "phone": "+70705712799"}
0005435462164	B8E2BA	2536 105290	ALEKSANDRA VASILEVA	{"email": "vasileva_aleksandra_02051977@postgrespro.ru", "phone": "+70037057596"}
0005435462165	7B3F8C	3105 484828	ALEKSANDR ANDREEV	{"phone": "+70096863611"}
0005435462166	B41DDD	5957 346447	ANTONINA YAKOVLEVA	{"phone": "+70931266690"}
0005435462167	66B7BB	1793 694646	SVETLANA MIRONOVA	{"phone": "+70970697903"}
0005435462168	60CE8C	0142 927375	VLADIMIR ILIN	{"phone": "+70618692084"}
0005435462169	60CE8C	6877 584774	VERONIKA MELNIKOVA	{"phone": "+70980168617"}
0005435462170	556F19	8388 412363	VLADISLAV SEMENOV	{"email": "semenov_v1967@postgrespro.ru", "phone": "+70231522040"}
0005435462171	556F19	2823 427881	OLEG GERASIMOV	{"phone": "+70868018486"}
0005435462172	B08692	3686 194813	IRINA LAZAREVA	{"phone": "+70424080712"}
0005435462173	435899	1147 501182	LYUBOV KUDRYASHOVA	{"phone": "+70395647214"}
0005435462174	DC3396	6162 115420	VITALIY PAVLOV	{"email": "v.pavlov121976@postgrespro.ru", "phone": "+70831014970"}
0005435462175	DC3396	4369 179856	VIKTORIYA KULIKOVA	{"email": "v.kulikova121965@postgrespro.ru", "phone": "+70127285312"}
0005435462176	E77D49	7343 983261	VALERIY FROLOV	{"phone": "+70362123263"}
0005435462177	DC0B0F	3815 304850	ALEKSANDR MATVEEV	{"phone": "+70817477402"}
0005435462178	DC0B0F	4813 253580	VLADIMIR EGOROV	{"email": "egorov_vladimir_1970@postgrespro.ru", "phone": "+70184411723"}
0005435462179	71335F	9779 122512	SVETLANA STEPANOVA	{"email": "svetlana_stepanova1978@postgrespro.ru", "phone": "+70161014694"}
0005435462180	0CF622	2617 790559	YULIYA FILIPPOVA	{"email": "y_filippova_1981@postgrespro.ru", "phone": "+70212630876"}
0005435462181	373998	9596 189518	ALEKSANDR MAKAROV	{"email": "makarov.a-22091968@postgrespro.ru", "phone": "+70211194808"}
0005435462182	373998	2468 300776	EVGENIY SMIRNOV	{"email": "smirnovevgeniy_04071972@postgrespro.ru", "phone": "+70279732076"}
0005435462183	FFCBA8	4701 195997	VIKTOR MAKAROV	{"email": "v-makarov-1970@postgrespro.ru", "phone": "+70143666720"}
0005435462184	346ECF	6978 295969	ELENA FROLOVA	{"phone": "+70041980677"}
0005435462185	8128E1	3800 024269	TATYANA BORISOVA	{"email": "borisovat.101963@postgrespro.ru", "phone": "+70115265157"}
0005435462186	08B8D9	2479 631793	ALEKSEY ILIN	{"phone": "+70900689529"}
0005435462187	08B8D9	5576 340016	TATYANA SOROKINA	{"email": "sorokinatatyana_071970@postgrespro.ru", "phone": "+70642774650"}
0005435462188	74ECBC	1915 224598	ALEKSANDR GUSEV	{"phone": "+70501589802"}
0005435462189	269CEA	0931 452820	VLADIMIR SEMENOV	{"phone": "+70032138207"}
0005435462190	269CEA	1547 252738	OKSANA KRASNOVA	{"email": "okrasnova-1970@postgrespro.ru", "phone": "+70833272563"}
0005435462191	00A7FF	6798 736470	YURIY NOVIKOV	{"email": "y.novikov.13011982@postgrespro.ru", "phone": "+70819953015"}
0005435462192	D2E92B	7923 912238	LYUDMILA DMITRIEVA	{"phone": "+70754040852"}
0005435462193	D2E92B	1818 271025	DENIS MAKAROV	{"email": "makarov_d-11071969@postgrespro.ru", "phone": "+70305389905"}
0005435462194	B9DA26	9067 861233	DMITRIY MEDVEDEV	{"email": "medvedev.d-1973@postgrespro.ru", "phone": "+70450769861"}
0005435462195	D9232E	6278 684672	ELENA PETROVA	{"email": "elena-petrova1972@postgrespro.ru", "phone": "+70599287946"}
0005435462196	C35BC1	6649 839331	GRIGORIY EGOROV	{"email": "egorov-grigoriy-011975@postgrespro.ru", "phone": "+70979891526"}
0005435462197	3868EC	8122 116667	TAMARA KOVALEVA	{"email": "tamara-kovaleva.08041974@postgrespro.ru", "phone": "+70179073990"}
0005435462198	F80C36	4313 104530	TAGIR DENISOV	{"phone": "+70439806011"}
0005435462199	A6A63A	0201 363869	ALEKSANDR SOKOLOV	{"email": "a_sokolov-031973@postgrespro.ru", "phone": "+70112869752"}
0005435462200	A6A63A	0666 411872	DARYA BORISOVA	{"email": "dborisova.101955@postgrespro.ru", "phone": "+70773731051"}
0005435462201	E557E9	3717 754100	TATYANA FADEEVA	{"email": "fadeevatatyana_04031971@postgrespro.ru", "phone": "+70730783587"}
0005435462202	876B4B	4599 915285	KLAVDIYA FADEEVA	{"phone": "+70849055863"}
0005435462203	876B4B	5436 368413	VIKTORIYA KOROLEVA	{"phone": "+70123921778"}
0005435462204	1A2726	7582 860763	ANISA PAVLOVA	{"phone": "+70879385988"}
0005435462205	D2F9DD	5387 728979	VALENTINA FEDOROVA	{"email": "valentinafedorova-04051972@postgrespro.ru", "phone": "+70266105433"}
0005435462206	A8C1FE	6208 963099	OLGA YAKOVLEVA	{"email": "yakovleva_olga021960@postgrespro.ru", "phone": "+70524862351"}
0005435462207	B77801	2279 375961	TATYANA NOVIKOVA	{"email": "tatyana.novikova-1961@postgrespro.ru", "phone": "+70832270281"}
0005435462208	B77801	9739 848172	ALEKSANDR NAUMOV	{"phone": "+70365465673"}
0005435462209	AE26AF	5552 234308	VALERIYA KUZMINA	{"phone": "+70007323190"}
0005435462210	AE26AF	8280 510305	IVAN ANTONOV	{"email": "ivan-antonov_25051966@postgrespro.ru", "phone": "+70024353609"}
0005435462211	AE26AF	6984 540684	NATALYA ZAYCEVA	{"phone": "+70828431151"}
0005435462212	33C003	1905 993995	YULIYA ERMAKOVA	{"phone": "+70271051085"}
0005435462213	33C003	0536 941295	MIKHAIL ZAYCEV	{"phone": "+70261930165"}
0005435462214	10E3C8	0988 099638	SERGEY KONOVALOV	{"phone": "+70406800157"}
0005435462215	970761	3029 549429	OLEG KRASNOV	{"phone": "+70025342561"}
0005435462216	970761	7177 271073	SERGEY KOZLOV	{"phone": "+70779114236"}
0005435462217	342DBB	5894 218239	NADEZHDA MIRONOVA	{"email": "nadezhdamironova061971@postgrespro.ru", "phone": "+70995342078"}
0005435462218	58A82B	1250 143008	KLAVDIYA NOVIKOVA	{"email": "novikova.k_1969@postgrespro.ru", "phone": "+70554544932"}
0005435462219	F8B775	7685 359641	NAZIYA ZHURAVLEVA	{"phone": "+70779988793"}
0005435462220	51BD73	5889 043462	VLADIMIR SIDOROV	{"email": "vladimir_sidorov-1976@postgrespro.ru", "phone": "+70635957296"}
0005435462221	B46258	6513 137713	ALEKSEY VASILEV	{"email": "vasilev-a_031970@postgrespro.ru", "phone": "+70853992374"}
0005435462222	B46258	2714 856977	VALERIY SMIRNOV	{"phone": "+70269991517"}
0005435462223	27B975	3831 480313	YULIYA STEPANOVA	{"phone": "+70620547032"}
0005435462224	0DEE2C	6717 225202	KSENIYA TITOVA	{"email": "titova.kseniya_111962@postgrespro.ru", "phone": "+70955824122"}
0005435462225	0DEE2C	6975 555589	GALINA NAZAROVA	{"phone": "+70162537137"}
0005435462226	860EB1	7955 659309	VLADIMIR BORISOV	{"email": "vladimirborisov-1975@postgrespro.ru", "phone": "+70605307488"}
0005435462227	860EB1	8414 152028	MATVEY KULIKOV	{"phone": "+70056293476"}
0005435462228	418B24	0518 832900	ELVIRA VASILEVA	{"phone": "+70134257197"}
0005435462229	418B24	7187 714660	VIKTOR RODIONOV	{"phone": "+70413241127"}
0005435462230	418B24	9017 029115	VALERIY ABRAMOV	{"phone": "+70184300813"}
0005435462231	418B24	8782 814976	DMITRIY NAZAROV	{"email": "dnazarov.081972@postgrespro.ru", "phone": "+70767680801"}
0005435462232	B54455	2303 274377	PELAGEYA SEMENOVA	{"phone": "+70372337455"}
0005435462233	E40C0E	8156 985832	ALEKSEY MOISEEV	{"phone": "+70104704673"}
0005435462234	E40C0E	9712 223860	MIKHAIL EGOROV	{"phone": "+70856054466"}
0005435462235	11CF89	6783 925151	ALEKSANDR NAZAROV	{"email": "a_nazarov.08101972@postgrespro.ru", "phone": "+70693344798"}
0005435462236	EA1EC4	3691 494432	RAFAIL SEMENOV	{"email": "semenov-r_1956@postgrespro.ru", "phone": "+70528748840"}
0005435462237	D4BED6	1576 535676	ALEKSANDRA MELNIKOVA	{"phone": "+70092849553"}
0005435462238	D4BED6	6689 310434	LYUDMILA SERGEEVA	{"email": "lyudmilasergeeva-20011981@postgrespro.ru", "phone": "+70542785710"}
0005435462239	875F39	1099 768298	ANASTASIYA SERGEEVA	{"phone": "+70522823360"}
0005435462240	79BDB4	3050 209709	NADEZHDA NOVIKOVA	{"email": "novikovanadezhda24071974@postgrespro.ru", "phone": "+70919746849"}
0005435462241	8BCB4C	9096 507952	ANNA KOZLOVA	{"phone": "+70338043280"}
0005435462242	8BCB4C	1164 452591	NIKOLAY EGOROV	{"phone": "+70344402525"}
0005435462243	5D75CA	4378 220188	TIMOFEY ROMANOV	{"email": "timofey.romanov-071969@postgrespro.ru", "phone": "+70468702467"}
0005435462244	2C1B82	6420 406563	DMITRIY IVANOV	{"email": "ivanov-d-28061971@postgrespro.ru", "phone": "+70601373748"}
0005435462245	D4BE40	4824 127029	OLGA ALEKSANDROVA	{"email": "aleksandrova-olga-1987@postgrespro.ru", "phone": "+70183105449"}
0005435462246	D4BE40	3128 312825	ALEKSANDR MATVEEV	{"email": "a.matveev.081955@postgrespro.ru", "phone": "+70675469697"}
0005435462247	E4AB4A	3622 782761	IVAN GRIGOREV	{"phone": "+70208925064"}
0005435462248	7ECB24	4001 296852	VIKTOR BELOV	{"email": "belov-v.091974@postgrespro.ru", "phone": "+70122071590"}
0005435462249	7ECB24	4923 406867	KRISTINA FADEEVA	{"email": "kfadeeva.1962@postgrespro.ru", "phone": "+70170331558"}
0005435462250	206BFC	8126 542634	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l.11041977@postgrespro.ru", "phone": "+70669649112"}
0005435462251	206BFC	1206 828291	LIDIYA FADEEVA	{"phone": "+70334799268"}
0005435462252	206BFC	4263 070881	VALERIY TIMOFEEV	{"email": "valeriy_timofeev.1978@postgrespro.ru", "phone": "+70614804590"}
0005435462253	C6958B	9205 712664	ALEKSANDR ROMANOV	{"email": "romanov-a061967@postgrespro.ru", "phone": "+70230336510"}
0005435462254	95EF97	3624 675141	MAKSIM ANTONOV	{"email": "maksimantonov.061970@postgrespro.ru", "phone": "+70934098377"}
0005435462255	9A9ECD	2745 801043	NAZIYA SOLOVEVA	{"email": "soloveva_n121975@postgrespro.ru", "phone": "+70882341631"}
0005435462256	4F8F38	5975 288649	NIKOLAY FOMIN	{"phone": "+70926098185"}
0005435462257	4F8F38	4380 235925	NIKITA DENISOV	{"phone": "+70994991894"}
0005435462258	FB5B53	8782 242509	GALINA KUZNECOVA	{"email": "kuznecova-galina23071980@postgrespro.ru", "phone": "+70731653432"}
0005435462259	CCBE24	9736 300446	VALERIY SEMENOV	{"email": "v-semenov1966@postgrespro.ru", "phone": "+70860694285"}
0005435462260	CCBE24	0063 162108	VALENTINA ANDREEVA	{"email": "valentina.andreeva_1966@postgrespro.ru", "phone": "+70196283959"}
0005435462261	1C84A6	8309 322505	NIKITA SEMENOV	{"email": "nikita_semenov_1970@postgrespro.ru", "phone": "+70340732965"}
0005435462262	1C84A6	3851 451332	EVGENIY NIKOLAEV	{"phone": "+70447479357"}
0005435462263	F3193E	0276 334267	ALEKSANDR FROLOV	{"email": "frolov.a-03011975@postgrespro.ru", "phone": "+70756391334"}
0005435462264	0EE3A6	7178 130042	ANATOLIY MOROZOV	{"phone": "+70449309153"}
0005435462265	4AABF4	5084 867645	OLGA ERMAKOVA	{"email": "ermakova_o_02121973@postgrespro.ru", "phone": "+70238510888"}
0005435462266	7FAF25	6216 531086	GALINA LEBEDEVA	{"phone": "+70814308150"}
0005435462267	F88803	5832 611138	PRASKOVYA FROLOVA	{"email": "frolova_p1969@postgrespro.ru", "phone": "+70582679397"}
0005435462268	F88803	7281 595348	SERGEY PAVLOV	{"phone": "+70294330613"}
0005435462269	03B56B	1524 918737	VALERIY BONDARENKO	{"email": "v_bondarenko-101974@postgrespro.ru", "phone": "+70193831790"}
0005435462270	FD043F	7671 950087	ALINA KUZNECOVA	{"phone": "+70147402685"}
0005435462271	FD043F	1302 299702	ARSENIY NIKOLAEV	{"phone": "+70189880621"}
0005435462272	5DA680	7024 263906	EKATERINA VASILEVA	{"email": "vasileva_e-031971@postgrespro.ru", "phone": "+70600604712"}
0005435462273	1BA2CA	9818 978521	ANATOLIY VOLKOV	{"phone": "+70350148268"}
0005435462274	913B63	9339 924175	ELENA ABRAMOVA	{"phone": "+70867863814"}
0005435462275	913B63	3813 551985	NATALYA KONDRATEVA	{"phone": "+70035181759"}
0005435462276	D89E33	9912 697533	VLADIMIR GAVRILOV	{"phone": "+70538410596"}
0005435462277	897898	5754 437690	OLGA KONOVALOVA	{"email": "okonovalova.111980@postgrespro.ru", "phone": "+70033484672"}
0005435462278	874B55	1723 238426	YURIY FROLOV	{"phone": "+70397391812"}
0005435462399	6F3A06	6304 771039	NIKOLAY IVANOV	{"phone": "+70851506121"}
0005435462279	3C9F33	6813 939459	ZAKHAR VOROBEV	{"email": "vorobev_z27051983@postgrespro.ru", "phone": "+70831025375"}
0005435462280	3C9F33	7228 046436	ALEKSANDR ILIN	{"phone": "+70305964211"}
0005435462281	45A375	0044 140272	IRINA AFANASEVA	{"phone": "+70207705413"}
0005435462282	45A375	3871 589343	SVETLANA YAKOVLEVA	{"phone": "+70986954161"}
0005435462283	30975A	7637 899494	IVAN VOLKOV	{"email": "i.volkov_1965@postgrespro.ru", "phone": "+70131481761"}
0005435462284	5F83E6	3594 752886	VIKTOR GAVRILOV	{"email": "viktor-gavrilov_21041969@postgrespro.ru", "phone": "+70705858423"}
0005435462285	5A7D2C	9375 217745	LEONID EGOROV	{"phone": "+70452186594"}
0005435462286	13EA76	2825 024993	SERGEY SEMENOV	{"phone": "+70778393888"}
0005435462287	13EA76	5259 365802	ALENA ALEKSANDROVA	{"phone": "+70031307778"}
0005435462288	13EA76	7742 109282	NIKOLAY NOVIKOV	{"email": "novikov_nikolay_14061985@postgrespro.ru", "phone": "+70996170989"}
0005435462289	81B107	3844 318337	TATYANA IVANOVA	{"phone": "+70018170807"}
0005435462290	B79B3B	8257 556690	ELIZAVETA FROLOVA	{"email": "frolova_elizaveta.031981@postgrespro.ru", "phone": "+70780621477"}
0005435462291	B79B3B	8635 518714	ELENA MAKAROVA	{"email": "makarovaelena-091972@postgrespro.ru", "phone": "+70055952354"}
0005435462292	5CB053	1282 760111	NADEZHDA MALYSHEVA	{"phone": "+70932139191"}
0005435462293	FE1AC0	9883 398295	LARISA GERASIMOVA	{"phone": "+70972515520"}
0005435462294	FE1AC0	5033 680812	VLADIMIR IVANOV	{"phone": "+70316039862"}
0005435462295	7BE41E	6543 940219	ANDREY DENISOV	{"email": "denisov.a_031961@postgrespro.ru", "phone": "+70815023391"}
0005435462296	FD071B	5666 246744	SVETLANA POLYAKOVA	{"phone": "+70475691907"}
0005435462297	D85F1F	2581 511515	NAIL GAVRILOV	{"phone": "+70763949334"}
0005435462298	D85F1F	5214 112546	VALENTINA VOLKOVA	{"phone": "+70071326230"}
0005435462299	6D1638	1204 407685	MAKSIM MAKAROV	{"phone": "+70099242952"}
0005435462300	3F157E	5984 854824	TATYANA FADEEVA	{"phone": "+70891924727"}
0005435462301	AE88B3	3720 017027	ZLATA ALEKSANDROVA	{"email": "aleksandrova_z.1976@postgrespro.ru", "phone": "+70185435856"}
0005435462302	F5E0AA	3903 459808	ANNA FILIPPOVA	{"phone": "+70370219012"}
0005435462303	5D09E8	1658 136558	YURIY IVANOV	{"phone": "+70087180145"}
0005435462304	817090	8799 209442	NATALYA ABRAMOVA	{"phone": "+70065723158"}
0005435462305	F37003	8222 836290	ANDREY EGOROV	{"phone": "+70449482628"}
0005435462306	1A441A	6110 612341	EKATERINA MAKAROVA	{"phone": "+70445933996"}
0005435462307	7B2870	4074 260947	GALINA EGOROVA	{"email": "g-egorova1976@postgrespro.ru", "phone": "+70387026465"}
0005435462308	4F0338	3196 182742	NATALYA PETROVA	{"email": "natalya.petrova-1980@postgrespro.ru", "phone": "+70715463080"}
0005435462309	4F0338	0633 424534	RUSLAN EGOROV	{"email": "egorov_ruslan11091970@postgrespro.ru", "phone": "+70515219133"}
0005435462310	4F0338	4157 007525	VALENTINA ZHURAVLEVA	{"phone": "+70950529601"}
0005435462311	FDBE87	6802 249973	ALEKSANDRA MELNIKOVA	{"phone": "+70440740214"}
0005435462312	F85748	3695 223063	LYUBOV GRISHINA	{"phone": "+70621209882"}
0005435462313	8916FF	5796 249264	VLADIMIR ALEKSEEV	{"phone": "+70590057018"}
0005435462314	0E56CF	3142 286403	MIKHAIL ZHUKOV	{"phone": "+70970197451"}
0005435462315	AF264E	7033 510163	VLADIMIR PAVLOV	{"phone": "+70877414706"}
0005435462316	AF264E	9465 269401	LYUBOV BORISOVA	{"email": "borisova.l-1976@postgrespro.ru", "phone": "+70179366944"}
0005435462317	DB7390	6525 766241	IRINA MOISEEVA	{"email": "moiseeva.irina-05011965@postgrespro.ru", "phone": "+70113278813"}
0005435462318	DB7390	2891 897186	NINA KOROLEVA	{"phone": "+70956286494"}
0005435462319	3C9160	3348 187736	MARIYA NIKITINA	{"email": "nikitina-m.041979@postgrespro.ru", "phone": "+70986703284"}
0005435462320	3C9160	3752 831082	LYUBOV POPOVA	{"phone": "+70475986610"}
0005435462321	59245E	5390 630335	ELENA LEBEDEVA	{"email": "elena.lebedeva_13011978@postgrespro.ru", "phone": "+70564286668"}
0005435462322	59245E	5569 545047	ALEKSANDR KISELEV	{"email": "a.kiselev18091973@postgrespro.ru", "phone": "+70624345500"}
0005435462323	CC549F	8285 960647	DENIS FEDOROV	{"email": "fedorov-d-081974@postgrespro.ru", "phone": "+70342721498"}
0005435462324	3B6361	7443 702055	IRINA BARANOVA	{"phone": "+70782180048"}
0005435462325	685630	3875 946683	MARIYA MATVEEVA	{"email": "m.matveeva.1970@postgrespro.ru", "phone": "+70224150467"}
0005435462326	3EF042	4426 569052	IVAN KOZLOV	{"phone": "+70367736819"}
0005435462327	3EF042	5669 021719	GALIYA IVANOVA	{"email": "ivanova_g.021967@postgrespro.ru", "phone": "+70711126728"}
0005435462328	B7BBBF	2734 609355	NINA PAVLOVA	{"phone": "+70822468978"}
0005435462329	B7BBBF	7470 477179	GALINA KUZMINA	{"phone": "+70498743339"}
0005435462330	832607	6780 428819	NIKITA FEDOTOV	{"email": "fedotov.n09081969@postgrespro.ru", "phone": "+70014910563"}
0005435462331	832607	2568 174862	REGINA MOISEEVA	{"email": "moiseeva_regina.1984@postgrespro.ru", "phone": "+70980865321"}
0005435462332	2B773A	2078 343532	GENNADIY KOZLOV	{"phone": "+70268994250"}
0005435462333	BA3408	8435 965671	VALERIY MEDVEDEV	{"email": "v-medvedev_071962@postgrespro.ru", "phone": "+70995433144"}
0005435462334	2E37B0	3196 649931	NATALYA POTAPOVA	{"email": "potapovanatalya-13071974@postgrespro.ru", "phone": "+70306845394"}
0005435462335	9CEB62	4985 978250	YAROSLAV KUZNECOV	{"phone": "+70130647066"}
0005435462336	57F9B9	4331 406809	ALEKSANDR STEPANOV	{"email": "stepanova09061969@postgrespro.ru", "phone": "+70290082680"}
0005435462337	33DDEE	1664 676882	NATALYA AKIMOVA	{"phone": "+70727840256"}
0005435462338	F4FC59	9756 251614	DENIS PETROV	{"email": "denispetrov-17051975@postgrespro.ru", "phone": "+70289742336"}
0005435462339	376C4D	9163 741990	VITALIY MEDVEDEV	{"phone": "+70601029741"}
0005435462340	376C4D	6734 207274	MARIYA TIKHONOVA	{"phone": "+70314993427"}
0005435462341	DD9311	8631 540364	MARIYA SEMENOVA	{"phone": "+70585469855"}
0005435462342	6CE768	7346 296716	LYUDMILA RYABOVA	{"email": "ryabova-l_021965@postgrespro.ru", "phone": "+70110330680"}
0005435462343	6CE768	2522 169888	ELENA STEPANOVA	{"email": "stepanova.elena051973@postgrespro.ru", "phone": "+70626861571"}
0005435462344	93CC28	4428 970970	ELENA TIKHONOVA	{"phone": "+70239901853"}
0005435462345	44101D	7692 407237	DANIIL SHEVCHENKO	{"phone": "+70378027295"}
0005435462346	A2683A	1853 504814	SVETLANA BARANOVA	{"phone": "+70914793964"}
0005435462347	F5D658	1415 185321	ANASTASIYA TIMOFEEVA	{"email": "timofeevaanastasiya.14091984@postgrespro.ru", "phone": "+70746408301"}
0005435462348	D44681	2388 761388	SERGEY KISELEV	{"email": "kiselev.s081975@postgrespro.ru", "phone": "+70392678340"}
0005435462349	D44681	8887 754116	ALEKSANDRA RODIONOVA	{"phone": "+70610013751"}
0005435462350	56F82E	4078 606593	IVAN NIKITIN	{"email": "inikitin_071961@postgrespro.ru", "phone": "+70894842701"}
0005435462351	4E300A	7618 085503	TATYANA POPOVA	{"email": "tatyana-popova_011975@postgrespro.ru", "phone": "+70629003421"}
0005435462352	4E300A	8385 621049	ARTEM GRIGOREV	{"phone": "+70306490766"}
0005435462353	AECD0A	7204 333678	MARIYA SMIRNOVA	{"phone": "+70410389125"}
0005435462354	AECD0A	0037 898974	VLADIMIR RODIONOV	{"phone": "+70449407316"}
0005435462355	D4E0A8	4240 694402	GENNADIY KOZLOV	{"email": "g.kozlov.041966@postgrespro.ru", "phone": "+70855254348"}
0005435462356	D4E0A8	6550 581877	OLGA MELNIKOVA	{"phone": "+70834405944"}
0005435462357	577E81	4613 073368	VALENTINA POPOVA	{"email": "v_popova.30111967@postgrespro.ru", "phone": "+70441667156"}
0005435462358	86AB37	3864 457283	ANASTASIYA GRISHINA	{"phone": "+70285127936"}
0005435462359	86AB37	9010 155259	DMITRIY MAKAROV	{"email": "makarov.dmitriy_031971@postgrespro.ru", "phone": "+70993614303"}
0005435462360	406C48	4219 687471	GRIGORIY VLASOV	{"email": "grigoriyvlasov.01111977@postgrespro.ru", "phone": "+70910293728"}
0005435462361	406C48	8401 726770	ANASTASIYA GAVRILOVA	{"email": "gavrilova-anastasiya.011974@postgrespro.ru", "phone": "+70110903695"}
0005435462362	B1CF96	5930 003138	ALENA PETROVA	{"email": "petrova.alena.1976@postgrespro.ru", "phone": "+70375721354"}
0005435462363	8D5616	3985 297584	ANATOLIY SMIRNOV	{"email": "smirnov.a.27121962@postgrespro.ru", "phone": "+70612398995"}
0005435462364	8D5616	4420 537963	NADEZHDA VASILEVA	{"email": "nadezhdavasileva08031978@postgrespro.ru", "phone": "+70948054456"}
0005435462365	AF2DD4	0957 546033	NADEZHDA PAVLOVA	{"email": "nadezhda_pavlova.17061962@postgrespro.ru", "phone": "+70140503000"}
0005435462366	A062EB	5195 634855	ARINA KUZMINA	{"email": "arina-kuzmina-121975@postgrespro.ru", "phone": "+70190182227"}
0005435462367	014F32	5360 721452	VLADIMIR CHERNOV	{"phone": "+70629151547"}
0005435462368	345B1C	5569 289593	OLGA ISAEVA	{"email": "isaeva.o.1971@postgrespro.ru", "phone": "+70969042216"}
0005435462369	345B1C	9801 783994	YULIYA LEBEDEVA	{"phone": "+70291441267"}
0005435462370	F61015	0741 850622	LYUBOV BARANOVA	{"email": "baranovalyubov-05051971@postgrespro.ru", "phone": "+70577199893"}
0005435462371	535FFA	0108 636735	ANDREY FROLOV	{"email": "andrey-frolov021973@postgrespro.ru", "phone": "+70428383283"}
0005435462372	C48657	4970 249271	ANDREY SIDOROV	{"email": "sidorov-andrey-20121960@postgrespro.ru", "phone": "+70842753992"}
0005435462373	B9C342	9693 959775	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr-1966@postgrespro.ru", "phone": "+70829337224"}
0005435462374	31DE46	8312 581306	IVAN NOVIKOV	{"phone": "+70082624309"}
0005435462375	1EE4BC	3472 821448	NATALYA MAKSIMOVA	{"email": "natalya.maksimova-121972@postgrespro.ru", "phone": "+70830795842"}
0005435462376	1EE4BC	8887 856807	MARIYA DMITRIEVA	{"email": "mdmitrieva20091968@postgrespro.ru", "phone": "+70301712685"}
0005435462377	766DCC	7604 646374	IGOR KUZNECOV	{"email": "igor_kuznecov.30051960@postgrespro.ru", "phone": "+70646572413"}
0005435462378	069793	2712 002600	EVGENIY RODIONOV	{"phone": "+70118561434"}
0005435462379	EAD45A	9190 736465	LYUBOV NIKOLAEVA	{"phone": "+70172347598"}
0005435462380	EAD45A	6093 525213	GALINA ERMAKOVA	{"email": "ermakovag.1982@postgrespro.ru", "phone": "+70530236462"}
0005435462381	D0F6C1	7893 949423	SERGEY YAKOVLEV	{"email": "yakovlev_s_1971@postgrespro.ru", "phone": "+70132720643"}
0005435462382	48FA7C	8351 401969	MARIYA MATVEEVA	{"email": "m_matveeva-1960@postgrespro.ru", "phone": "+70361971405"}
0005435462383	69C203	1848 670812	LARISA PETROVA	{"email": "petrovalarisa-1962@postgrespro.ru", "phone": "+70883645585"}
0005435462384	0BBDF8	9544 845946	KSENIYA ERMAKOVA	{"phone": "+70567614042"}
0005435462385	B55B1D	6950 784585	ALEKSANDR ILIN	{"phone": "+70598487631"}
0005435462386	448DA4	5940 512806	EVGENIYA DANILOVA	{"email": "e.danilova.15031958@postgrespro.ru", "phone": "+70471006498"}
0005435462387	DBFBEB	2224 130344	ALEKSANDR ZHURAVLEV	{"email": "aleksandr_zhuravlev1958@postgrespro.ru", "phone": "+70444687584"}
0005435462388	6794E6	5493 745593	ROBERT NAZAROV	{"email": "nazarovr-1969@postgrespro.ru", "phone": "+70154970635"}
0005435462389	253264	2761 747115	ANATOLIY SHEVCHENKO	{"email": "a-shevchenko05091968@postgrespro.ru", "phone": "+70316305082"}
0005435462390	253264	5912 644450	MAKSIM KUZMIN	{"email": "maksimkuzmin1961@postgrespro.ru", "phone": "+70343620662"}
0005435462391	444F2B	2588 157179	TATYANA TARASOVA	{"email": "tarasova-tatyana.05011965@postgrespro.ru", "phone": "+70972575783"}
0005435462392	444F2B	6964 693362	OLGA ABRAMOVA	{"phone": "+70101807163"}
0005435462393	88F9BE	8761 237554	IVAN PETROV	{"email": "ivanpetrov-27061974@postgrespro.ru", "phone": "+70727543142"}
0005435462394	D114E2	2502 230961	VLADIMIR ANTONOV	{"email": "antonovvladimir.17111960@postgrespro.ru", "phone": "+70891668166"}
0005435462395	FF888B	8976 682926	NIKOLAY SHEVCHENKO	{"email": "shevchenko.n1981@postgrespro.ru", "phone": "+70803799225"}
0005435462396	7825D5	9031 062230	NATALYA MOROZOVA	{"phone": "+70817120370"}
0005435462397	6F3A06	9176 624892	ALEKSEY ABRAMOV	{"email": "abramovaleksey_051968@postgrespro.ru", "phone": "+70486357578"}
0005435462398	6F3A06	4265 400667	VALERIY MIRONOV	{"phone": "+70452832479"}
0005435462400	B63267	2968 942809	MIKHAIL SHEVCHENKO	{"email": "shevchenko.mikhail-1974@postgrespro.ru", "phone": "+70011052718"}
0005435462401	B63267	2288 812590	SERGEY SERGEEV	{"phone": "+70814575682"}
0005435462402	B63267	7146 134295	ALENA YAKOVLEVA	{"phone": "+70154530550"}
0005435462403	02945B	4146 288984	VYACHESLAV VASILEV	{"phone": "+70471627320"}
0005435462404	45B16C	0607 163837	RAIL ALEKSEEV	{"phone": "+70011779757"}
0005435462405	D9FDF2	5348 288594	DMITRIY NAZAROV	{"phone": "+70537828451"}
0005435462406	D9FDF2	6290 268578	ARTEM MELNIKOV	{"phone": "+70857084996"}
0005435462407	972A51	2744 110469	MAKSIM NIKOLAEV	{"phone": "+70476557809"}
0005435462408	7D800A	7356 530465	ALEKSANDR ABRAMOV	{"email": "abramov_a21021977@postgrespro.ru", "phone": "+70671862227"}
0005435462409	EBBAE6	3460 503418	DMITRIY IVANOV	{"email": "ivanov_d_14111965@postgrespro.ru", "phone": "+70753393690"}
0005435462410	89EAD9	0550 506503	ELENA ROMANOVA	{"phone": "+70707682255"}
0005435462411	044BFA	6232 626021	YURIY MAKAROV	{"email": "y-makarov21071973@postgrespro.ru", "phone": "+70284520924"}
0005435462412	044BFA	1320 875183	GALINA NESTEROVA	{"email": "nesterova.g_09071968@postgrespro.ru", "phone": "+70693284459"}
0005435462413	55A0F3	4623 793891	TAMARA KOMAROVA	{"email": "komarovatamara.071966@postgrespro.ru", "phone": "+70175689569"}
0005435462414	EE4A6D	9327 626185	VIKTORIYA SOKOLOVA	{"email": "sokolova-viktoriya-011974@postgrespro.ru", "phone": "+70499108881"}
0005435462415	0D3BA1	5867 345140	VLADIMIR MARTYNOV	{"email": "vladimir_martynov-071976@postgrespro.ru", "phone": "+70889353447"}
0005435462416	B60D90	5604 166358	VLADIMIR STEPANOV	{"phone": "+70232858553"}
0005435462417	6832BB	1415 559262	SVETLANA TIKHONOVA	{"email": "s_tikhonova-13091970@postgrespro.ru", "phone": "+70681731003"}
0005435462418	ED81E4	5185 036175	RINAT ANDREEV	{"email": "andreev.rinat_09011973@postgrespro.ru", "phone": "+70386881522"}
0005435462419	545B7E	0959 765092	SERGEY KUZNECOV	{"email": "sergeykuznecov-1974@postgrespro.ru", "phone": "+70327692449"}
0005435462420	545B7E	7424 613941	ANTONINA BORISOVA	{"email": "borisova.antonina-1975@postgrespro.ru", "phone": "+70697422111"}
0005435462421	6F9D44	5413 919047	DANIIL SEMENOV	{"email": "semenov.daniil_02071968@postgrespro.ru", "phone": "+70824269123"}
0005435462422	40744F	8910 899511	SVETLANA NAUMOVA	{"email": "naumova.s-121964@postgrespro.ru", "phone": "+70153857394"}
0005435462423	6A2631	4213 763719	LARISA ANTONOVA	{"phone": "+70577749589"}
0005435462424	788388	9213 276777	LIDIYA ANDREEVA	{"phone": "+70894610755"}
0005435462425	F5DF68	7710 531428	SEMEN IVANOV	{"email": "s.ivanov.1967@postgrespro.ru", "phone": "+70495803594"}
0005435462426	3D2509	8702 717212	MARIANNA SIDOROVA	{"email": "msidorova_1981@postgrespro.ru", "phone": "+70513961340"}
0005435462427	9187BE	0167 910742	LIDIYA KRASNOVA	{"phone": "+70138018855"}
0005435462428	9187BE	6879 269152	MARINA GAVRILOVA	{"email": "gavrilova_marina-02111967@postgrespro.ru", "phone": "+70253844442"}
0005435462429	75E799	6824 160829	IRINA GERASIMOVA	{"phone": "+70991890497"}
0005435462430	FE3B12	5723 645149	ALINA LEBEDEVA	{"email": "lebedeva.a-10041972@postgrespro.ru", "phone": "+70631942150"}
0005435462431	FE3B12	6833 581030	STANISLAV KUZNECOV	{"email": "skuznecov.03061986@postgrespro.ru", "phone": "+70465938856"}
0005435462432	DAF639	5338 648278	DENIS PETROV	{"email": "petrovd.1983@postgrespro.ru", "phone": "+70128252722"}
0005435462433	29069E	6166 818310	RAVIL TIMOFEEV	{"phone": "+70557217841"}
0005435462434	29069E	4726 098036	TATYANA DANILOVA	{"phone": "+70179799554"}
0005435462435	D9EC40	4273 055350	ELENA VASILEVA	{"phone": "+70763317441"}
0005435462436	983EDD	9201 161325	DENIS SAVELEV	{"phone": "+70548145228"}
0005435462437	873189	2766 593753	ARSEN MAKSIMOV	{"email": "amaksimov-081959@postgrespro.ru", "phone": "+70121851188"}
0005435462438	186589	5525 631131	NATALYA GUSEVA	{"phone": "+70120893720"}
0005435462439	DDA8D9	6954 695860	IRINA FOMINA	{"phone": "+70793019311"}
0005435462440	DDA8D9	3458 216203	NATALYA VOLKOVA	{"email": "volkova_natalya_021979@postgrespro.ru", "phone": "+70362842995"}
0005435462441	0CA6AE	0502 664458	ELENA KONOVALOVA	{"phone": "+70320444895"}
0005435462442	0CA6AE	6208 762329	NIKOLAY KAZAKOV	{"phone": "+70351669799"}
0005435462443	359A59	7426 332909	VALENTINA SAVELEVA	{"email": "savelevavalentina_1971@postgrespro.ru", "phone": "+70884279923"}
0005435462444	BFEFE0	7664 169935	ANDREY OSIPOV	{"email": "a-osipov_27021973@postgrespro.ru", "phone": "+70639137257"}
0005435462445	F3312E	3113 499106	ELENA MAKAROVA	{"email": "e.makarova1969@postgrespro.ru", "phone": "+70758184017"}
0005435462446	861C62	9334 092148	ANDREY MARTYNOV	{"phone": "+70322040567"}
0005435462447	861C62	0885 591472	DENIS KUZNECOV	{"phone": "+70179597768"}
0005435462448	D6FEFC	0452 786241	SERGEY ORLOV	{"email": "s.orlov-1986@postgrespro.ru", "phone": "+70608819705"}
0005435462449	215FDB	2327 283968	NATALYA IVANOVA	{"phone": "+70336966268"}
0005435462450	215FDB	6275 662418	INNA SAVELEVA	{"phone": "+70817948397"}
0005435462451	E0F509	7632 415783	VLADIMIR SCHERBAKOV	{"email": "v_scherbakov.1975@postgrespro.ru", "phone": "+70192743731"}
0005435462452	9D3A27	9076 684157	NINA BELOVA	{"email": "belova.n.061977@postgrespro.ru", "phone": "+70216500636"}
0005435462453	9BC7E0	6507 254823	VALENTINA KONOVALOVA	{"phone": "+70499171332"}
0005435462454	50AFA2	2176 160332	SVETLANA IVANOVA	{"phone": "+70819271078"}
0005435462455	8D2FBB	5607 298640	IRINA ARKHIPOVA	{"email": "arkhipova.irina081977@postgrespro.ru", "phone": "+70769125472"}
0005435462456	78841A	9518 634758	NADEZHDA PETROVA	{"email": "petrova_nadezhda091972@postgrespro.ru", "phone": "+70458728058"}
0005435462457	D64F68	4616 613632	ALEKSANDR NOVIKOV	{"email": "novikov-a.121957@postgrespro.ru", "phone": "+70056908540"}
0005435462458	920FBB	9027 297729	GLEB ABRAMOV	{"email": "abramov_g1976@postgrespro.ru", "phone": "+70729952073"}
0005435462459	71EBD1	6304 288708	YURIY MARTYNOV	{"email": "yuriy_martynov-081974@postgrespro.ru", "phone": "+70299485605"}
0005435462460	F84A6F	1491 552111	VIKTOR VASILEV	{"email": "vasilev.v.081975@postgrespro.ru", "phone": "+70634253662"}
0005435462461	CAD2A2	3325 594905	ALEKSANDR MIRONOV	{"phone": "+70831770654"}
0005435462462	CAD2A2	6742 243276	NADEZHDA NIKIFOROVA	{"phone": "+70812900423"}
0005435462463	4D4511	4990 268486	OLGA VOLKOVA	{"email": "volkova_o_011968@postgrespro.ru", "phone": "+70023669384"}
0005435462464	4D4511	1168 574877	MARIYA FROLOVA	{"phone": "+70278853932"}
0005435462465	FFF9F0	6619 441603	SERGEY FROLOV	{"email": "s_frolov_1978@postgrespro.ru", "phone": "+70050530508"}
0005435462466	76CC6F	7088 429414	ARMAN KOZLOV	{"email": "a_kozlov-22101964@postgrespro.ru", "phone": "+70195534238"}
0005435462467	76CC6F	9131 711129	ALEKSANDR NAZAROV	{"phone": "+70464171661"}
0005435462468	65380B	9139 019721	ILYA MIRONOV	{"phone": "+70313841228"}
0005435462469	2BF8C9	3482 236334	NATALYA GUSEVA	{"email": "guseva-n.27061979@postgrespro.ru", "phone": "+70704831559"}
0005435462470	020EB5	5555 705937	EVGENIY MIRONOV	{"email": "e_mironov101970@postgrespro.ru", "phone": "+70340811512"}
0005435462471	C4B4A8	5654 464444	SERGEY ALEKSANDROV	{"email": "sergey_aleksandrov041979@postgrespro.ru", "phone": "+70115756739"}
0005435462472	C4B4A8	9473 251456	ELENA VASILEVA	{"phone": "+70692522775"}
0005435462473	C4B4A8	2201 961236	VLADIMIR KUZNECOV	{"phone": "+70246160680"}
0005435462474	B661AC	3602 503638	OLGA DENISOVA	{"phone": "+70872291531"}
0005435462475	B661AC	5761 494302	IGOR ILIN	{"email": "igor_ilin-071960@postgrespro.ru", "phone": "+70540098628"}
0005435462476	F4DFE6	3919 746330	GALINA GAVRILOVA	{"phone": "+70689194235"}
0005435462477	F4DFE6	5879 863448	YULIYA ISAEVA	{"email": "yisaeva1982@postgrespro.ru", "phone": "+70530582725"}
0005435462478	45DE22	3254 754213	ANNA BORISOVA	{"phone": "+70437184541"}
0005435462479	45DE22	3740 892090	VIOLETTA EFIMOVA	{"phone": "+70760485353"}
0005435462480	30617E	7347 189078	OKSANA ORLOVA	{"phone": "+70088338284"}
0005435462481	30617E	3584 038474	NATALYA MIKHAYLOVA	{"email": "mikhaylova_natalya-1969@postgrespro.ru", "phone": "+70712345055"}
0005435462482	A73689	4730 301449	VLADIMIR VOROBEV	{"phone": "+70002743349"}
0005435462483	A73689	5396 315185	ALEKSANDR NIKOLAEV	{"email": "nikolaev-a.23091976@postgrespro.ru", "phone": "+70670043964"}
0005435462484	6FD83D	7016 606328	LYUBOV POTAPOVA	{"email": "potapovalyubov.17111971@postgrespro.ru", "phone": "+70037187364"}
0005435462485	D375E5	7227 234618	ALEKSEY VOLKOV	{"phone": "+70693751149"}
0005435462486	EBC715	6693 149424	RAISA VOLKOVA	{"phone": "+70802353008"}
0005435462487	A0A83D	4001 600643	EKATERINA KOZLOVA	{"email": "kozlova-ekaterina-101977@postgrespro.ru", "phone": "+70814223330"}
0005435462488	9857A4	2027 876914	ALEKSANDR SAVELEV	{"email": "asavelev-26031972@postgrespro.ru", "phone": "+70514337819"}
0005435462489	BB5E49	3318 195295	VALENTINA PETROVA	{"email": "petrovav-04031969@postgrespro.ru", "phone": "+70795814576"}
0005435462490	BB5E49	4166 130105	ILYA IVANOV	{"phone": "+70927129278"}
0005435462491	4BC98D	1740 101102	ELENA SMIRNOVA	{"phone": "+70093667841"}
0005435462492	4BC98D	2995 374956	ELENA ZAYCEVA	{"phone": "+70608239930"}
0005435462493	74478E	1656 704002	ALEKSANDRA NIKIFOROVA	{"email": "aleksandra.nikiforova.121977@postgrespro.ru", "phone": "+70116883201"}
0005435462494	131914	6914 153308	POLINA ISAEVA	{"email": "isaeva.p121977@postgrespro.ru", "phone": "+70068560794"}
0005435462495	131914	8210 438860	KSENIYA KUDRYASHOVA	{"email": "kseniya_kudryashova.02081972@postgrespro.ru", "phone": "+70272910081"}
0005435462496	0F55BF	2154 887559	ILYA KAZAKOV	{"phone": "+70192574728"}
0005435462497	7E3482	5935 532052	ANNA FROLOVA	{"email": "a.frolova25051971@postgrespro.ru", "phone": "+70293157845"}
0005435462498	7E3482	5209 600648	VLADIMIR KRASNOV	{"phone": "+70687748723"}
0005435462499	1D1925	6018 577014	DMITRIY SCHERBAKOV	{"phone": "+70848040142"}
0005435462500	19B068	9725 547344	MIKHAIL SAVELEV	{"email": "mikhail-savelev1977@postgrespro.ru", "phone": "+70446798393"}
0005435462501	19B068	3295 411676	SVETLANA ROMANOVA	{"phone": "+70343953013"}
0005435462502	258F94	3414 884230	VITALIY KUZNECOV	{"phone": "+70988626163"}
0005435462503	F57AAA	7285 924781	VIKTOR PETROV	{"email": "petrov_viktor1973@postgrespro.ru", "phone": "+70612250386"}
0005435462504	F57AAA	1316 002017	ILYA BONDARENKO	{"email": "bondarenkoilya_061972@postgrespro.ru", "phone": "+70183335741"}
0005435462505	1959E3	6725 806313	SVETLANA ILINA	{"email": "ilina_s.01071962@postgrespro.ru", "phone": "+70073160409"}
0005435462506	5D7576	7517 967140	GENNADIY SEMENOV	{"email": "semenov-g.081981@postgrespro.ru", "phone": "+70532842116"}
0005435462507	5D7576	6202 035355	VLADIMIR MOROZOV	{"email": "v-morozov.021974@postgrespro.ru", "phone": "+70951376449"}
0005435462508	C6EE79	8731 072558	VLADIMIR IVANOV	{"phone": "+70358442638"}
0005435462509	F198CF	7286 583457	NIKITA SCHERBAKOV	{"email": "scherbakov_nikita-1969@postgrespro.ru", "phone": "+70430902342"}
0005435462510	DA7542	4232 356250	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva.09041971@postgrespro.ru", "phone": "+70386520943"}
0005435462511	DA7542	8717 979866	MARGARITA PETROVA	{"email": "petrova.margarita.31101987@postgrespro.ru", "phone": "+70610563872"}
0005435462512	55B34A	9738 730971	ANDREY PETROV	{"phone": "+70877965482"}
0005435462513	27BCE0	9577 795347	DENIS TIKHONOV	{"phone": "+70731611085"}
0005435462514	27BCE0	8122 463244	MIKHAIL ROMANOV	{"phone": "+70282715431"}
0005435462515	128123	6688 456803	MARIYA KUZNECOVA	{"phone": "+70845587544"}
0005435462516	DCD054	9700 279196	GALINA AKIMOVA	{"email": "g_akimova021965@postgrespro.ru", "phone": "+70233662602"}
0005435462517	97CDA7	0687 511673	TATYANA DANILOVA	{"phone": "+70958744345"}
0005435462518	EDC7DE	1192 165218	DMITRIY SCHERBAKOV	{"phone": "+70874374904"}
0005435462519	EDC7DE	2944 213621	EVGENIY NIKITIN	{"email": "nikitin_e_14061980@postgrespro.ru", "phone": "+70539545835"}
0005435462520	EDC7DE	8962 257598	KSENIYA MEDVEDEVA	{"phone": "+70207115910"}
0005435462521	935EB0	7765 821880	ANATOLIY MIKHAYLOV	{"phone": "+70148166334"}
0005435462522	8B5F50	1563 904500	IRINA CHERNOVA	{"email": "chernova_i091977@postgrespro.ru", "phone": "+70141422077"}
0005435462523	EEC623	5726 758859	NATALYA LAZAREVA	{"email": "n_lazareva_1971@postgrespro.ru", "phone": "+70011052521"}
0005435462524	EEC623	1383 817720	TATYANA IVANOVA	{"email": "ivanova-tatyana.1973@postgrespro.ru", "phone": "+70661416068"}
0005435462525	EEC623	5050 810665	YULIYA SMIRNOVA	{"phone": "+70319523914"}
0005435462526	624575	8012 375065	ALINA SEMENOVA	{"email": "alina_semenova.081972@postgrespro.ru", "phone": "+70372210123"}
0005435462527	7FE99C	0181 359721	YURIY FROLOV	{"phone": "+70616900360"}
0005435462528	4496AF	5238 628807	TATYANA NAUMOVA	{"email": "naumova.tatyana-061972@postgrespro.ru", "phone": "+70407419743"}
0005435462529	2CCB8B	4234 512874	ALISA KUZNECOVA	{"email": "kuznecova_alisa08071972@postgrespro.ru", "phone": "+70879293072"}
0005435462530	8348B8	6115 257492	ARSENIY MAKAROV	{"email": "a.makarov-031964@postgrespro.ru", "phone": "+70734485912"}
0005435462531	8348B8	6073 638402	ANASTASIYA AKIMOVA	{"email": "akimova.a-1972@postgrespro.ru", "phone": "+70098299699"}
0005435462532	8348B8	6273 376100	VLADIMIR MELNIKOV	{"email": "melnikov-vladimir-1969@postgrespro.ru", "phone": "+70218751197"}
0005435462533	02DF5D	2846 589689	ANDREY STEPANOV	{"email": "andrey_stepanov.22041968@postgrespro.ru", "phone": "+70641854339"}
0005435462534	1C230C	1559 602365	PETR GUSEV	{"email": "p-gusev.04011981@postgrespro.ru", "phone": "+70973740228"}
0005435462535	9F24DE	1305 737036	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-11101963@postgrespro.ru", "phone": "+70455670833"}
0005435462536	A1916B	1383 616767	TATYANA ANDREEVA	{"phone": "+70469257154"}
0005435462537	0F92D6	4868 460203	MARIYA POLYAKOVA	{"email": "m_polyakova-1984@postgrespro.ru", "phone": "+70656880992"}
0005435462538	0F92D6	0445 088964	KRISTINA KRASNOVA	{"email": "krasnova.k121972@postgrespro.ru", "phone": "+70905880516"}
0005435462539	ABF4CA	1072 009668	YULIYA KAZAKOVA	{"phone": "+70520455723"}
0005435462540	ABF4CA	0206 280232	ELENA TROFIMOVA	{"phone": "+70062251354"}
0005435462541	5D5A7C	8279 956222	VIKTOR GUSEV	{"phone": "+70493086032"}
0005435462542	40F354	3340 371571	ANATOLIY FEDOROV	{"phone": "+70928915961"}
0005435462543	40F354	8514 847369	NINA GUSEVA	{"phone": "+70658162909"}
0005435462544	B192A7	9481 165952	IRINA KUZNECOVA	{"phone": "+70219155992"}
0005435462545	22E75D	5675 093541	KIRILL SAVELEV	{"email": "kirill.savelev1972@postgrespro.ru", "phone": "+70784695371"}
0005435462546	22E75D	2017 056081	ALEKSEY ALEKSEEV	{"phone": "+70109936697"}
0005435462547	C90E7C	6157 774979	LILIYA SAVELEVA	{"email": "liliya_saveleva1975@postgrespro.ru", "phone": "+70886421249"}
0005435462548	38C503	8524 229804	SOFYA STEPANOVA	{"phone": "+70250538328"}
0005435462549	7DA80E	3925 367823	ANDREY TARASOV	{"phone": "+70997133429"}
0005435462550	7DA80E	5843 504716	LYUBOV ERMAKOVA	{"email": "ermakova_lyubov_17091973@postgrespro.ru", "phone": "+70251699162"}
0005435462551	B306BC	1750 158695	ANATOLIY VASILEV	{"phone": "+70377799045"}
0005435462552	D51A1E	7683 406917	TATYANA YAKOVLEVA	{"phone": "+70926983411"}
0005435462553	C2AFC0	9750 154913	NATALYA ALEKSEEVA	{"email": "alekseeva.natalya-071963@postgrespro.ru", "phone": "+70616471366"}
0005435462554	85AC01	1252 951240	SVETLANA BOGDANOVA	{"email": "s_bogdanova1975@postgrespro.ru", "phone": "+70438110186"}
0005435462555	7F1629	5292 482221	ALEKSANDR PETROV	{"phone": "+70505954820"}
0005435462556	E8E034	1068 906250	TAMARA ANTONOVA	{"phone": "+70626212557"}
0005435462557	8F333F	0107 037040	ANASTASIYA VLASOVA	{"email": "vlasovaanastasiya.1965@postgrespro.ru", "phone": "+70892249037"}
0005435462558	9F7E7E	4763 668079	GALINA TIKHONOVA	{"phone": "+70173324172"}
0005435462559	9F7E7E	5365 726134	INNA LAZAREVA	{"email": "i_lazareva.08041975@postgrespro.ru", "phone": "+70573604264"}
0005435462560	1EF138	7036 747273	VYACHESLAV KOZLOV	{"email": "v_kozlov021976@postgrespro.ru", "phone": "+70323967291"}
0005435462561	22DE9F	4872 770100	EDUARD SEMENOV	{"email": "esemenov_1970@postgrespro.ru", "phone": "+70006099882"}
0005435462562	22DE9F	3364 567877	ANASTASIYA SOROKINA	{"email": "sorokinaa-24031966@postgrespro.ru", "phone": "+70541225793"}
0005435462563	208FA4	4009 317145	MAYYA KOZLOVA	{"phone": "+70820384279"}
0005435462564	8B0642	4457 565316	RUSLAN FOMIN	{"phone": "+70417541561"}
0005435462565	0A70DD	4668 481114	EVGENIY FROLOV	{"email": "e-frolov08091975@postgrespro.ru", "phone": "+70603466565"}
0005435462566	49B609	3301 302824	DMITRIY KISELEV	{"email": "kiselev.d1972@postgrespro.ru", "phone": "+70111712361"}
0005435462567	49B609	5777 915578	DARYA ERMAKOVA	{"email": "ermakova-d02021971@postgrespro.ru", "phone": "+70154320063"}
0005435462568	49B609	8252 225420	MARINA EFIMOVA	{"email": "efimova-m-1982@postgrespro.ru", "phone": "+70074135441"}
0005435462569	AFBE18	2237 587166	ALEKSEY EGOROV	{"email": "aleksey.egorov081979@postgrespro.ru", "phone": "+70008893795"}
0005435462570	F1EE36	1570 874974	IGOR NIKOLAEV	{"email": "igor.nikolaev_1974@postgrespro.ru", "phone": "+70044020986"}
0005435462571	7AE786	9791 806826	EVGENIY BARANOV	{"phone": "+70585425307"}
0005435462572	7AE786	2674 846402	VYACHESLAV VASILEV	{"email": "vasilevvyacheslav-26081971@postgrespro.ru", "phone": "+70871388339"}
0005435462573	21F344	4049 293301	GALINA YUDINA	{"email": "galina_yudina-1984@postgrespro.ru", "phone": "+70501638836"}
0005435462574	21F344	6986 241886	ALIYA MELNIKOVA	{"phone": "+70979170334"}
0005435462575	BC4200	4169 685369	RADIK ANTONOV	{"phone": "+70435277749"}
0005435462576	BC4200	3570 240480	OLGA DAVYDOVA	{"phone": "+70003644189"}
0005435462577	5887BF	3777 333781	NIKOLAY VLASOV	{"email": "nikolay-vlasov.121973@postgrespro.ru", "phone": "+70573543659"}
0005435462578	5887BF	8031 777210	ANTONINA KUZNECOVA	{"phone": "+70295229255"}
0005435462579	5887BF	3359 027378	TIGRAN MATVEEV	{"email": "tmatveev_1982@postgrespro.ru", "phone": "+70371016941"}
0005435462580	24DEDC	0003 458018	ROMAN ZAYCEV	{"email": "zaycev_r_1971@postgrespro.ru", "phone": "+70342606751"}
0005435462581	24DEDC	0119 176386	PAVEL POPOV	{"email": "popov-p.1976@postgrespro.ru", "phone": "+70846648743"}
0005435462582	8F0720	9541 510268	KONSTANTIN KUZMIN	{"email": "kuzmin.konstantin.11091975@postgrespro.ru", "phone": "+70504950343"}
0005435462583	8F0720	9185 007550	ELENA SCHERBAKOVA	{"email": "e_scherbakova.071976@postgrespro.ru", "phone": "+70997460144"}
0005435462584	86C46F	7636 817565	ANZHELIKA ZHUKOVA	{"phone": "+70865564465"}
0005435462585	86C46F	6507 776974	IVAN KUZMIN	{"email": "ikuzmin.1972@postgrespro.ru", "phone": "+70696638394"}
0005435462586	86C46F	4569 384991	SERGEY FILIPPOV	{"phone": "+70218768224"}
0005435462587	86C46F	3173 057205	EKATERINA ARKHIPOVA	{"email": "e_arkhipova-071978@postgrespro.ru", "phone": "+70542058185"}
0005435462588	3146EC	2249 151915	VERONIKA KAZAKOVA	{"phone": "+70816355697"}
0005435462589	704521	0514 029340	EKATERINA TARASOVA	{"email": "e-tarasova09031974@postgrespro.ru", "phone": "+70825499915"}
0005435462590	704521	2895 395635	ALEKSANDR MELNIKOV	{"phone": "+70764122135"}
0005435462591	ABFCB7	9661 268983	DANIL CHERNOV	{"phone": "+70763847030"}
0005435462592	5AD893	2864 850571	YULIYA KRASNOVA	{"email": "yuliya_krasnova-16021979@postgrespro.ru", "phone": "+70892559792"}
0005435462593	5AD893	7532 451447	GALINA TARASOVA	{"phone": "+70710766676"}
0005435462594	291B0C	8048 957486	NIKITA CHERNOV	{"email": "n_chernov.071969@postgrespro.ru", "phone": "+70717174688"}
0005435462595	14DA3D	6522 111000	FANIYA DENISOVA	{"phone": "+70033603350"}
0005435462596	E2AD20	4308 066447	EKATERINA KUZMINA	{"phone": "+70349749708"}
0005435462597	E2AD20	6656 724003	OKSANA NAZAROVA	{"phone": "+70539479760"}
0005435462598	7C5E53	0765 290730	ELMIRA POPOVA	{"phone": "+70460361636"}
0005435462599	7C5E53	5519 810972	ELLA DAVYDOVA	{"email": "davydova-ella.1976@postgrespro.ru", "phone": "+70034492496"}
0005435462600	4C24CF	6300 265286	LYUBOV SOROKINA	{"phone": "+70347051642"}
0005435462601	558A3A	4672 084936	NATALYA ABRAMOVA	{"phone": "+70020821531"}
0005435462602	D28E29	4674 110582	ANATOLIY AFANASEV	{"phone": "+70754677848"}
0005435462603	091BDE	8066 722650	ALEKSANDR ALEKSEEV	{"phone": "+70555961485"}
0005435462604	FCBA32	2995 219734	EKATERINA LEBEDEVA	{"email": "ekaterina.lebedeva_081977@postgrespro.ru", "phone": "+70119463708"}
0005435462605	38333C	3983 965991	STANISLAV GERASIMOV	{"email": "gerasimov.s-1971@postgrespro.ru", "phone": "+70124718025"}
0005435462606	EB8991	3202 938786	MARINA KONOVALOVA	{"phone": "+70634525408"}
0005435462607	F21122	7912 223571	GALINA BORISOVA	{"phone": "+70592507124"}
0005435462608	09E4BB	0804 065601	DARYA ABRAMOVA	{"email": "abramova.darya-23031972@postgrespro.ru", "phone": "+70822895861"}
0005435462609	5ACCBE	5114 119605	NAILYA MAKAROVA	{"email": "makarovanailya_1970@postgrespro.ru", "phone": "+70424860672"}
0005435462610	5ACCBE	4709 716155	TATYANA NESTEROVA	{"email": "nesterova-tatyana_1980@postgrespro.ru", "phone": "+70637901202"}
0005435462611	19A88F	0861 963420	MARIYA IVANOVA	{"email": "ivanova_m.101977@postgrespro.ru", "phone": "+70871093405"}
0005435462612	19A88F	8994 331587	PAVEL KAZAKOV	{"phone": "+70939984108"}
0005435462613	F19225	4454 556768	ALEKSANDR MATVEEV	{"email": "matveev_aleksandr1978@postgrespro.ru", "phone": "+70579491491"}
0005435462614	AA234D	3509 311951	NINA OSIPOVA	{"email": "osipova-n-101983@postgrespro.ru", "phone": "+70727064860"}
0005435462615	AA234D	7819 891854	VALERIY ANTONOV	{"email": "v-antonov-021970@postgrespro.ru", "phone": "+70422264941"}
0005435462616	F0B239	3391 111598	ANDREY TIKHONOV	{"email": "andrey.tikhonov.1970@postgrespro.ru", "phone": "+70508313724"}
0005435462617	C2676D	4195 892834	MARIYA NAZAROVA	{"phone": "+70603668521"}
0005435462618	C2676D	0712 631714	ANASTASIYA FROLOVA	{"phone": "+70836759106"}
0005435462619	9AF11C	8325 708428	VALENTINA RODIONOVA	{"phone": "+70506849406"}
0005435462620	9AF11C	8155 799936	SERGEY KUZNECOV	{"email": "s_kuznecov.081975@postgrespro.ru", "phone": "+70722405806"}
0005435462621	9AF11C	7444 449912	LARISA SOLOVEVA	{"phone": "+70764757115"}
0005435462622	D03DCB	9037 198431	MARINA KISELEVA	{"email": "kiseleva_m-10031974@postgrespro.ru", "phone": "+70368008971"}
0005435462623	4CF83C	9520 843623	TATYANA SEMENOVA	{"email": "t.semenova.15081967@postgrespro.ru", "phone": "+70830471426"}
0005435462624	EB442C	5276 690111	VIKTORIYA FROLOVA	{"email": "frolova.viktoriya-26111974@postgrespro.ru", "phone": "+70785760088"}
0005435462625	6DCF0B	5412 870255	IRINA MIRONOVA	{"phone": "+70914901550"}
0005435462626	BE1985	3968 419323	ANDREY KUDRYASHOV	{"phone": "+70006227387"}
0005435462627	EB31B1	4449 873957	IRINA PETROVA	{"phone": "+70178130105"}
0005435462628	EB31B1	4343 421469	NATALYA KUZNECOVA	{"phone": "+70887082364"}
0005435462629	57A24E	4242 045029	ALEKSEY EGOROV	{"phone": "+70647114053"}
0005435462630	B5B6E9	6327 677255	IRINA NIKOLAEVA	{"email": "nikolaeva.i1984@postgrespro.ru", "phone": "+70238379239"}
0005435462631	37BF63	4068 066312	VALERIY ISAEV	{"email": "valeriy_isaev_17091974@postgrespro.ru", "phone": "+70421469805"}
0005435462632	37BF63	2915 094457	YULIYA KUZNECOVA	{"phone": "+70098630903"}
0005435462633	1D3313	5647 057142	ALEKSANDRA KAZAKOVA	{"phone": "+70656942904"}
0005435462634	99B98D	7841 162806	TATYANA PETROVA	{"email": "petrova-t08101979@postgrespro.ru", "phone": "+70236907774"}
0005435462635	CEDBDE	9385 366267	LARISA PETROVA	{"phone": "+70886599795"}
0005435462636	3FCE95	3392 861632	ALEKSANDR KARPOV	{"phone": "+70383431921"}
0005435462637	0B93DA	1698 747275	ZLATA ALEKSANDROVA	{"email": "aleksandrovaz24011967@postgrespro.ru", "phone": "+70753501319"}
0005435462638	0B93DA	8846 138235	ALEKSEY MAKAROV	{"phone": "+70510605196"}
0005435462639	C82F42	5566 741791	IRINA BELOVA	{"email": "belova-i1970@postgrespro.ru", "phone": "+70486841148"}
0005435462640	C82F42	3040 358574	VLADIMIR NIKITIN	{"phone": "+70493730494"}
0005435462641	D7DD9C	4994 934737	LYUBOV BARANOVA	{"phone": "+70546707350"}
0005435462642	D7DD9C	0708 633335	MARIYA GRISHINA	{"phone": "+70444979286"}
0005435462643	69D795	6703 203593	NADEZHDA ORLOVA	{"phone": "+70899228300"}
0005435462644	69D795	5849 225797	ANDREY POPOV	{"email": "popov-a-04061960@postgrespro.ru", "phone": "+70721276777"}
0005435462645	ED08DD	5859 814071	NATALYA TIMOFEEVA	{"email": "n.timofeeva1969@postgrespro.ru", "phone": "+70511148853"}
0005435462646	B99813	2670 809515	ALEKSEY SOLOVEV	{"phone": "+70742853678"}
0005435462647	0B2B21	6382 518997	YULIYA POPOVA	{"phone": "+70507281400"}
0005435462648	B24F86	3342 890593	VALERIY VASILEV	{"email": "vasilev-v.16091981@postgrespro.ru", "phone": "+70678865594"}
0005435462649	B24F86	8397 991251	VYACHESLAV NOVIKOV	{"phone": "+70868272093"}
0005435462650	BEA628	0531 135533	ANATOLIY MARTYNOV	{"email": "martynov_anatoliy.111972@postgrespro.ru", "phone": "+70471982634"}
0005435462651	BEA628	3463 415220	ALINA SOKOLOVA	{"phone": "+70751637628"}
0005435462652	48A534	7674 430951	VALENTINA ZHUKOVA	{"email": "zhukova_v-1977@postgrespro.ru", "phone": "+70495046420"}
0005435462653	EC3130	5419 094045	IVAN SAVELEV	{"phone": "+70675820263"}
0005435462654	660826	4084 264290	ELIZAVETA MIKHAYLOVA	{"phone": "+70836798028"}
0005435462655	B9C836	0684 533527	RAFAEL KISELEV	{"email": "r.kiselev_011981@postgrespro.ru", "phone": "+70387725696"}
0005435462656	C9AF5E	6900 203321	FEDOR KULIKOV	{"phone": "+70865172483"}
0005435462657	C9AF5E	4735 663239	VALENTINA GERASIMOVA	{"email": "gerasimovavalentina091981@postgrespro.ru", "phone": "+70969329186"}
0005435462658	2E56C2	3302 961553	POLINA DMITRIEVA	{"email": "dmitrieva.p.091963@postgrespro.ru", "phone": "+70444653597"}
0005435462659	2E56C2	0348 701264	ANTON TIKHONOV	{"phone": "+70651233357"}
0005435462660	C8A28D	3290 542969	ELIZAVETA ROMANOVA	{"email": "romanovaelizaveta24051967@postgrespro.ru", "phone": "+70170941393"}
0005435462661	86D1E8	0977 618209	MAKSIM GRIGOREV	{"phone": "+70625746664"}
0005435462662	4DA263	2555 065449	YURIY IVANOV	{"phone": "+70712707212"}
0005435462663	3F2D4B	7729 483952	VASILIY KOZLOV	{"phone": "+70770637857"}
0005435462664	3F2D4B	2693 167074	IGOR KUZMIN	{"email": "i_kuzmin-1974@postgrespro.ru", "phone": "+70069535334"}
0005435462665	2EB4C1	2835 671018	VLADIMIR NAUMOV	{"phone": "+70883354069"}
0005435462666	2EB4C1	4903 637378	EVGENIY ISAEV	{"email": "isaevevgeniy.031959@postgrespro.ru", "phone": "+70943766232"}
0005435462667	CE9137	7423 989497	VYACHESLAV SMIRNOV	{"email": "vyacheslav_smirnov13051970@postgrespro.ru", "phone": "+70346671038"}
0005435462668	8CB4B6	2957 645874	VIKTOR POPOV	{"phone": "+70154539791"}
0005435462669	B7AA5E	9633 677433	MAKSIM RODIONOV	{"phone": "+70905773969"}
0005435462670	503132	8886 822486	VALERIY NAUMOV	{"email": "naumov.valeriy-071963@postgrespro.ru", "phone": "+70021325777"}
0005435462671	503132	3154 791814	VLADIMIR AFANASEV	{"email": "vladimir-afanasev-091978@postgrespro.ru", "phone": "+70795125657"}
0005435462672	0CF1B7	5304 303725	ELENA KULIKOVA	{"email": "kulikova.elena_101978@postgrespro.ru", "phone": "+70419061785"}
0005435462673	0CF1B7	0154 283672	IVAN SOROKIN	{"phone": "+70962103017"}
0005435462674	EBA438	5448 506202	VERONIKA SERGEEVA	{"phone": "+70104800521"}
0005435462675	24EE14	9946 099631	KSENIYA MOROZOVA	{"email": "kseniyamorozova22031966@postgrespro.ru", "phone": "+70936454730"}
0005435462676	2784A2	4554 886908	TATYANA KOVALEVA	{"email": "t_kovaleva.1973@postgrespro.ru", "phone": "+70796903547"}
0005435462677	A89B8B	9356 270459	OLEG GORBUNOV	{"email": "oleg.gorbunov.1965@postgrespro.ru", "phone": "+70272802591"}
0005435462678	B297A6	7370 055296	KLAVDIYA YUDINA	{"phone": "+70599245069"}
0005435462679	B297A6	9399 846214	VLADIMIR ZAKHAROV	{"phone": "+70308996308"}
0005435462680	5A2A60	3896 124899	ANTON DMITRIEV	{"phone": "+70904612388"}
0005435462681	8B713B	2077 374749	LEONID GORBUNOV	{"email": "gorbunov_l1979@postgrespro.ru", "phone": "+70636882465"}
0005435462682	2B5221	2047 540314	DANIIL KRASNOV	{"phone": "+70074946134"}
0005435462683	B05BAC	3016 277415	YURIY BORISOV	{"email": "yborisov_1972@postgrespro.ru", "phone": "+70587699564"}
0005435462684	E72A8E	3526 533573	VIKTOR GUSEV	{"email": "gusev_v_05061965@postgrespro.ru", "phone": "+70038100330"}
0005435462685	953E9B	5755 165638	VLADIMIR ROMANOV	{"email": "vladimir.romanov091981@postgrespro.ru", "phone": "+70608061385"}
0005435462686	AE03F5	8642 421900	RUSTAM ILIN	{"email": "ilin_rustam1965@postgrespro.ru", "phone": "+70404047272"}
0005435462687	9032B0	2997 352699	OLGA MIRONOVA	{"email": "olga.mironova.24061972@postgrespro.ru", "phone": "+70774340578"}
0005435462688	B8FAC6	6936 592595	IRINA VLASOVA	{"email": "irina.vlasova1971@postgrespro.ru", "phone": "+70720521155"}
0005435462689	B8FAC6	4090 577284	LEV IVANOV	{"email": "lev.ivanov-1973@postgrespro.ru", "phone": "+70278130767"}
0005435462690	F7A531	7412 186645	DMITRIY MEDVEDEV	{"phone": "+70712956088"}
0005435462691	F7A531	3005 666350	ALEKSEY ABRAMOV	{"phone": "+70694752056"}
0005435462692	6A617B	0518 023764	TAMARA FADEEVA	{"email": "fadeeva-t.15061962@postgrespro.ru", "phone": "+70941961185"}
0005435462693	DCEF86	8363 318603	VIKTOR SHEVCHENKO	{"email": "viktor_shevchenko-011979@postgrespro.ru", "phone": "+70050634983"}
0005435462694	DCEF86	3656 426956	MARIYA FOMINA	{"phone": "+70206325248"}
0005435462695	DCEF86	3828 495444	GALINA PAVLOVA	{"phone": "+70868753959"}
0005435462696	1903BA	4872 636294	LYUBOV VASILEVA	{"phone": "+70216756725"}
0005435462697	1903BA	3461 841663	LARISA KUZMINA	{"email": "kuzmina_larisa-13041972@postgrespro.ru", "phone": "+70474401177"}
0005435462698	EA0919	7688 477428	DARYA KOVALEVA	{"email": "kovalevad1974@postgrespro.ru", "phone": "+70737424102"}
0005435462699	5F7FD3	2216 823372	NINA KRASNOVA	{"email": "nina.krasnova.1981@postgrespro.ru", "phone": "+70486584655"}
0005435462700	5F7FD3	3659 007878	LARISA MAKAROVA	{"phone": "+70049950315"}
0005435462879	49F732	0687 687325	MARIYA TROFIMOVA	{"phone": "+70547541983"}
0005435462701	BB7B9A	4676 772668	YURIY IVANOV	{"email": "ivanov-yuriy.1978@postgrespro.ru", "phone": "+70334809770"}
0005435462702	BB7B9A	8805 851069	OLEG SIDOROV	{"phone": "+70843363958"}
0005435462703	BB7B9A	2278 699655	ALEKSANDR PETROV	{"email": "aleksandr-petrov111985@postgrespro.ru", "phone": "+70219175494"}
0005435462704	087155	8343 996080	ANATOLIY SOKOLOV	{"email": "sokolova-1967@postgrespro.ru", "phone": "+70481862214"}
0005435462705	13D936	4719 046660	ALEVTINA KUZNECOVA	{"phone": "+70057292955"}
0005435462706	10A7A1	7642 645727	VIKTORIYA MEDVEDEVA	{"email": "v_medvedeva.24021973@postgrespro.ru", "phone": "+70456992153"}
0005435462707	C0C060	6051 364200	DARYA KALININA	{"email": "kalinina-darya_091983@postgrespro.ru", "phone": "+70316249279"}
0005435462708	C0C060	7716 936987	NIKOLAY KARPOV	{"email": "nikolay-karpov.081978@postgrespro.ru", "phone": "+70171288748"}
0005435462709	C0C060	9997 340875	VIKTOR DAVYDOV	{"email": "davydovviktor.101965@postgrespro.ru", "phone": "+70738075436"}
0005435462710	4EC9B0	5103 654813	ALEKSANDR TARASOV	{"email": "tarasova.20021971@postgrespro.ru", "phone": "+70881131940"}
0005435462711	E200BD	0423 461845	NATALYA ZHURAVLEVA	{"phone": "+70465236477"}
0005435462712	B95ADD	9798 526451	VLADIMIR ABRAMOV	{"email": "v.abramov18091979@postgrespro.ru", "phone": "+70718524217"}
0005435462713	D05625	6315 081169	SVETLANA MAKAROVA	{"email": "smakarova-1973@postgrespro.ru", "phone": "+70997856731"}
0005435462714	E20925	3847 476086	ANATOLIY IVANOV	{"email": "anatoliy.ivanov_31071985@postgrespro.ru", "phone": "+70567677866"}
0005435462715	282094	0920 592692	IGOR NOVIKOV	{"phone": "+70491855449"}
0005435462716	26F143	0892 711384	KRISTINA NIKITINA	{"phone": "+70739187332"}
0005435462717	26F143	0190 533349	VIKTOR ALEKSEEV	{"email": "viktoralekseev-1974@postgrespro.ru", "phone": "+70392927535"}
0005435462718	86FE2D	4807 385258	ANDREY AFANASEV	{"phone": "+70097963793"}
0005435462719	C44D24	7074 899175	ELENA MATVEEVA	{"email": "matveeva.e.06071971@postgrespro.ru", "phone": "+70604744168"}
0005435462720	C44D24	2877 040116	KONSTANTIN FOMIN	{"email": "fomink-1977@postgrespro.ru", "phone": "+70243679163"}
0005435462721	F62525	0307 198154	YULIYA SIDOROVA	{"email": "sidorova.y14091978@postgrespro.ru", "phone": "+70499814107"}
0005435462722	F62525	0313 259422	DMITRIY BORISOV	{"email": "borisovdmitriy_1975@postgrespro.ru", "phone": "+70978474571"}
0005435462723	D7582C	4657 008850	ANNA KUZNECOVA	{"email": "kuznecova.anna-081971@postgrespro.ru", "phone": "+70563943919"}
0005435462724	3E40CD	6471 080994	ALEKSANDR BONDARENKO	{"phone": "+70178800796"}
0005435462725	950E95	4583 974371	EVGENIY SOKOLOV	{"phone": "+70837099158"}
0005435462726	950E95	3525 042432	TIMOFEY GORBUNOV	{"email": "timofey.gorbunov_13091978@postgrespro.ru", "phone": "+70954792826"}
0005435462727	306A41	7881 620382	ELENA ZHURAVLEVA	{"phone": "+70137303081"}
0005435462728	C6FF59	1299 231986	VYACHESLAV FEDOTOV	{"phone": "+70438033946"}
0005435462729	8DFF1F	0862 883693	NATALYA KARPOVA	{"email": "natalya-karpova111971@postgrespro.ru", "phone": "+70100799141"}
0005435462730	8DFF1F	0559 275498	MARIYA IVANOVA	{"email": "mariya-ivanova-1970@postgrespro.ru", "phone": "+70740953817"}
0005435462731	0925B3	9111 561820	NADEZHDA KISELEVA	{"phone": "+70985570698"}
0005435462732	C3AE2B	0637 171786	ANNA IVANOVA	{"phone": "+70112799277"}
0005435462733	E27D68	0996 336501	IRINA DMITRIEVA	{"email": "dmitrieva.i101965@postgrespro.ru", "phone": "+70207123500"}
0005435462734	E27D68	8996 611814	SERGEY ZAYCEV	{"email": "s.zaycev_1974@postgrespro.ru", "phone": "+70472211691"}
0005435462735	C5CB62	0995 438267	ALEKSEY OSIPOV	{"phone": "+70852236655"}
0005435462736	C5CB62	4702 600209	ELENA RODIONOVA	{"phone": "+70703987139"}
0005435462737	048305	7301 847038	GALINA VASILEVA	{"email": "galina-vasileva-1969@postgrespro.ru", "phone": "+70797921982"}
0005435462738	92394F	4669 548238	ANDREY ALEKSEEV	{"phone": "+70297393576"}
0005435462739	92394F	5212 908246	ELENA RODIONOVA	{"email": "rodionova_elena-1962@postgrespro.ru", "phone": "+70506143185"}
0005435462740	D48CF3	4356 545644	MARIYA KOVALEVA	{"email": "mariya-kovaleva_1971@postgrespro.ru", "phone": "+70639607483"}
0005435462741	432D3F	8002 182265	VALENTINA NESTEROVA	{"phone": "+70662559101"}
0005435462742	756A86	1541 739041	IVAN NOVIKOV	{"phone": "+70615746828"}
0005435462743	756A86	5958 992797	NIKOLAY MEDVEDEV	{"phone": "+70599106288"}
0005435462744	635891	2476 785750	SOFYA ARKHIPOVA	{"email": "arkhipovas.10071972@postgrespro.ru", "phone": "+70628916112"}
0005435462745	B67632	1950 036273	ROMAN GERASIMOV	{"email": "gerasimov.r_05091982@postgrespro.ru", "phone": "+70417820949"}
0005435462746	B67632	2412 523865	DMITRIY ANDREEV	{"phone": "+70466540252"}
0005435462747	6C980D	6125 371153	GENNADIY NAUMOV	{"email": "naumovgennadiy1970@postgrespro.ru", "phone": "+70862564745"}
0005435462748	6C980D	1863 060413	SVETLANA ISAEVA	{"phone": "+70253620944"}
0005435462749	4049BE	7430 216685	ELENA YAKOVLEVA	{"email": "e_yakovleva_04061966@postgrespro.ru", "phone": "+70208790447"}
0005435462750	8B0148	7234 267824	VASILIY ALEKSEEV	{"email": "valekseev.1980@postgrespro.ru", "phone": "+70206331874"}
0005435462751	B85E1B	0639 085316	TATYANA ARKHIPOVA	{"email": "arkhipova-tatyana-26071979@postgrespro.ru", "phone": "+70257415759"}
0005435462752	B85E1B	6572 906995	MIKHAIL FEDOTOV	{"email": "fedotov-m_05031974@postgrespro.ru", "phone": "+70186509604"}
0005435462753	EA6DB0	3671 797926	ANDREY FROLOV	{"email": "frolov-andrey.111962@postgrespro.ru", "phone": "+70738353292"}
0005435462754	17D1D5	7701 481620	DENIS MAKAROV	{"phone": "+70569118636"}
0005435462755	EF8E4A	3078 937783	NIKOLAY ANDREEV	{"phone": "+70313363549"}
0005435462756	F017CA	7470 976926	VLADISLAV VOLKOV	{"email": "vladislav-volkov.1978@postgrespro.ru", "phone": "+70506499505"}
0005435462757	828B53	0451 850576	VITALIY DAVYDOV	{"phone": "+70129111078"}
0005435462758	E00353	3653 993561	NINA GERASIMOVA	{"email": "n-gerasimova.1971@postgrespro.ru", "phone": "+70463201412"}
0005435462937	991F49	8815 723793	ANTON DMITRIEV	{"phone": "+70589530027"}
0005435462759	E00353	6027 752784	NATALIYA DENISOVA	{"email": "nataliya_denisova_061971@postgrespro.ru", "phone": "+70812049421"}
0005435462760	98129A	1797 550619	ALEKSEY MAKAROV	{"email": "makarov-a.16011965@postgrespro.ru", "phone": "+70181920503"}
0005435462761	98129A	2008 854144	EVGENIY IVANOV	{"email": "ivanove_21041966@postgrespro.ru", "phone": "+70253542775"}
0005435462762	230D31	4560 308685	MARIYA ZHUKOVA	{"email": "mariyazhukova-14071962@postgrespro.ru", "phone": "+70127762507"}
0005435462763	A4E954	3853 830365	EGOR TIMOFEEV	{"phone": "+70623725796"}
0005435462764	F30D36	9727 192965	NINA KRASNOVA	{"phone": "+70921814209"}
0005435462765	911BB3	6116 832106	ALEKSEY FROLOV	{"phone": "+70873343657"}
0005435462766	911BB3	7383 576394	GULNARA KISELEVA	{"phone": "+70196707036"}
0005435462767	DCF699	7243 370250	SHAMIL ALEKSEEV	{"email": "alekseev-shamil.011964@postgrespro.ru", "phone": "+70399507313"}
0005435462768	0C82DC	1564 363384	ALEKSEY NIKOLAEV	{"phone": "+70994578728"}
0005435462769	0C82DC	0939 837096	MARINA MALYSHEVA	{"email": "malysheva.marina_1972@postgrespro.ru", "phone": "+70292909758"}
0005435462770	28CDAF	4579 777617	TATYANA SMIRNOVA	{"email": "smirnova.t.111977@postgrespro.ru", "phone": "+70025994067"}
0005435462771	28CDAF	1759 401096	LARISA MAKAROVA	{"phone": "+70305235301"}
0005435462772	1E9A1E	2880 084081	ALEKSANDR FROLOV	{"phone": "+70985889024"}
0005435462773	1E9A1E	6615 405997	EKATERINA MAKAROVA	{"phone": "+70050694457"}
0005435462774	2C3082	1629 416683	ELMIRA MIKHAYLOVA	{"phone": "+70243476533"}
0005435462775	2C3082	7932 116695	NADEZHDA BARANOVA	{"phone": "+70824261373"}
0005435462776	7A8389	7205 166720	VIKTOR STEPANOV	{"email": "v.stepanov.091975@postgrespro.ru", "phone": "+70505520719"}
0005435462777	811869	8140 298250	ELIZAVETA BELOVA	{"email": "belova.elizaveta-1964@postgrespro.ru", "phone": "+70106941968"}
0005435462778	F14E26	3671 170389	DANIL GERASIMOV	{"phone": "+70217702531"}
0005435462779	F14E26	7166 814739	MARINA DENISOVA	{"email": "m_denisova.1980@postgrespro.ru", "phone": "+70286963020"}
0005435462780	740584	8883 278150	NINA LAZAREVA	{"phone": "+70618672367"}
0005435462781	F7F97C	1311 745468	ALEKSANDR EGOROV	{"phone": "+70191425433"}
0005435462782	A59BFC	4238 515093	GALINA VASILEVA	{"email": "vasileva_g-121975@postgrespro.ru", "phone": "+70867257890"}
0005435462783	FA112D	1668 021300	NIKITA MOROZOV	{"phone": "+70368909640"}
0005435462784	FA112D	7251 056895	EVGENIY MAKSIMOV	{"phone": "+70542685865"}
0005435462785	26782D	4925 129977	ALEKSANDR FEDOROV	{"phone": "+70926219561"}
0005435462786	26782D	8995 544435	ELENA MAKAROVA	{"phone": "+70450950071"}
0005435462787	F87DE6	2711 515841	KAMILA TROFIMOVA	{"email": "kamilatrofimova-031988@postgrespro.ru", "phone": "+70795502033"}
0005435462788	F87DE6	2069 236143	VALENTINA NESTEROVA	{"email": "v.nesterova_061971@postgrespro.ru", "phone": "+70736061651"}
0005435462789	DF23A3	8886 970561	VADIM FILIPPOV	{"phone": "+70699168126"}
0005435462790	6420AF	6471 398995	ALINA SOROKINA	{"phone": "+70993941634"}
0005435462791	6420AF	0641 809465	ALBERT DAVYDOV	{"phone": "+70231361807"}
0005435462792	2B03C5	4890 688781	TATYANA CHERNOVA	{"phone": "+70806976320"}
0005435462793	2B03C5	7122 367751	ALINA GAVRILOVA	{"phone": "+70721316655"}
0005435462794	DD033B	3773 101523	DMITRIY VOROBEV	{"email": "vorobev-d_1986@postgrespro.ru", "phone": "+70038470042"}
0005435462795	1B8CD4	6442 896270	ZINAIDA FILIPPOVA	{"email": "filippova_z.30121979@postgrespro.ru", "phone": "+70760854915"}
0005435462796	2B627B	6886 650814	NADEZHDA SOROKINA	{"email": "sorokina-nadezhda.1969@postgrespro.ru", "phone": "+70998041374"}
0005435462797	7E4B76	2542 898992	VIKTOR KAZAKOV	{"email": "viktor.kazakov_1967@postgrespro.ru", "phone": "+70671591760"}
0005435462798	7E4B76	1230 585378	ALEKSANDRA OSIPOVA	{"phone": "+70279614803"}
0005435462799	1AE4AA	5742 598628	KIRILL PETROV	{"email": "petrov_k-101982@postgrespro.ru", "phone": "+70434946007"}
0005435462800	242E05	8198 797343	VIKTOR NOVIKOV	{"email": "vnovikov_15011967@postgrespro.ru", "phone": "+70329848789"}
0005435462801	242E05	0109 572609	GALINA YAKOVLEVA	{"phone": "+70990758812"}
0005435462802	242E05	6325 758378	YULIYA VOLKOVA	{"phone": "+70918554056"}
0005435462803	3CD15A	8012 456575	TATYANA MAKAROVA	{"phone": "+70617806821"}
0005435462804	2FB92A	8807 521952	ALEKSEY PAVLOV	{"phone": "+70516981854"}
0005435462805	2FB92A	5169 720358	TATYANA STEPANOVA	{"email": "stepanovatatyana_22071973@postgrespro.ru", "phone": "+70088612455"}
0005435462806	9191E6	4855 289574	ANATOLIY KULIKOV	{"email": "kulikov-anatoliy_061978@postgrespro.ru", "phone": "+70299832351"}
0005435462807	D560EA	5376 782748	ALEKSANDR SMIRNOV	{"email": "asmirnov_05101974@postgrespro.ru", "phone": "+70260565042"}
0005435462808	3E6990	8125 581588	DENIS ZAKHAROV	{"email": "zakharov.d011980@postgrespro.ru", "phone": "+70095508191"}
0005435462809	254F2D	5539 983767	ANDREY SOKOLOV	{"phone": "+70448336562"}
0005435462810	254F2D	4456 985587	DILYARA TROFIMOVA	{"phone": "+70205836042"}
0005435462811	BD7AD2	5352 871734	TAISIYA STEPANOVA	{"email": "stepanova-taisiya-11101963@postgrespro.ru", "phone": "+70235830151"}
0005435462812	321819	9190 141527	ELMIRA VOLKOVA	{"phone": "+70853709876"}
0005435462813	F8BE7A	4154 192086	VALERIY FILIPPOV	{"phone": "+70806410355"}
0005435462814	F8BE7A	1298 759956	GALINA ORLOVA	{"phone": "+70771922725"}
0005435462815	CB0D64	6572 031497	NATALYA VLASOVA	{"email": "n_vlasova17021970@postgrespro.ru", "phone": "+70116228632"}
0005435462816	CB0D64	8390 530345	EVGENIY MOROZOV	{"email": "morozov.evgeniy_031962@postgrespro.ru", "phone": "+70777465806"}
0005435462817	B155F7	6415 753663	VLADIMIR ZAYCEV	{"email": "zaycevv111971@postgrespro.ru", "phone": "+70757174074"}
0005435462818	1DF5D3	9819 478146	IRINA ILINA	{"phone": "+70195081418"}
0005435462819	4C3E63	5990 315345	OLGA EGOROVA	{"email": "olga.egorova_1964@postgrespro.ru", "phone": "+70785408856"}
0005435462820	4C3E63	7097 329698	PETR FEDOTOV	{"email": "fedotovpetr.1974@postgrespro.ru", "phone": "+70881086868"}
0005435462821	191FCC	2635 531303	EVGENIYA FROLOVA	{"email": "e.frolova-1960@postgrespro.ru", "phone": "+70939742832"}
0005435462822	191FCC	4714 284490	PAVEL MIRONOV	{"phone": "+70571712828"}
0005435462823	8CE261	4908 119609	ANNA SOROKINA	{"phone": "+70027011932"}
0005435462824	18BA7D	4309 399535	YURIY ROMANOV	{"email": "romanovyuriy.30051981@postgrespro.ru", "phone": "+70150372124"}
0005435462825	A2368A	4817 671344	SVETLANA NIKIFOROVA	{"email": "nikiforovas.1971@postgrespro.ru", "phone": "+70649449475"}
0005435462826	A2368A	2895 877861	ALEKSANDR GAVRILOV	{"email": "gavrilov_aleksandr-081971@postgrespro.ru", "phone": "+70440867207"}
0005435462827	C634CA	3160 324916	ALEKSANDR FEDOROV	{"phone": "+70140252173"}
0005435462828	C13B65	4157 904157	TATYANA ABRAMOVA	{"email": "tatyana_abramova_02111969@postgrespro.ru", "phone": "+70614385857"}
0005435462829	909F2D	4889 044913	ALEKSANDR ALEKSEEV	{"phone": "+70384191826"}
0005435462830	4E864C	9087 347895	NADEZHDA YAKOVLEVA	{"email": "yakovlevan-10091973@postgrespro.ru", "phone": "+70985565775"}
0005435462831	4E864C	8683 010572	VADIM FROLOV	{"email": "v-frolov-1982@postgrespro.ru", "phone": "+70346382352"}
0005435462832	4E864C	9918 047611	VLADIMIR DENISOV	{"phone": "+70137619020"}
0005435462833	BA6B92	4943 646845	ANNA KUZNECOVA	{"phone": "+70938301527"}
0005435462834	9136E5	4594 339343	VERA EGOROVA	{"phone": "+70563027702"}
0005435462835	BAAC2C	2833 796850	NIKOLAY KISELEV	{"email": "kiselev_n-101974@postgrespro.ru", "phone": "+70269312599"}
0005435462836	BAAC2C	2661 548869	EKATERINA VASILEVA	{"email": "vasileva.ekaterina_011965@postgrespro.ru", "phone": "+70368930407"}
0005435462837	A4F1FE	0267 605117	VLADIMIR GRIGOREV	{"email": "vladimir-grigorev.1963@postgrespro.ru", "phone": "+70730469285"}
0005435462838	56B5A5	3331 035949	SERGEY KOZLOV	{"phone": "+70841371488"}
0005435462839	56B5A5	7179 758492	ALEKSANDR SEMENOV	{"email": "semenov_a.1971@postgrespro.ru", "phone": "+70954489615"}
0005435462840	D94344	5400 072495	EVGENIY SMIRNOV	{"phone": "+70284847595"}
0005435462841	D94344	7471 653365	ELENA PAVLOVA	{"phone": "+70897113324"}
0005435462842	D94344	2935 016693	ANASTASIYA GAVRILOVA	{"email": "anastasiya.gavrilova.1980@postgrespro.ru", "phone": "+70916681266"}
0005435462843	F95A0F	6949 375685	ANDREY EGOROV	{"phone": "+70664062240"}
0005435462844	AE7052	3843 426167	SVETLANA DMITRIEVA	{"email": "svetlana-dmitrieva.1960@postgrespro.ru", "phone": "+70750386753"}
0005435462845	AE7052	6346 842125	LILIYA BARANOVA	{"email": "liliyabaranova-1980@postgrespro.ru", "phone": "+70092705779"}
0005435462846	AC1819	2358 774621	ALEKSEY SAVELEV	{"phone": "+70394930993"}
0005435462847	AC1819	7634 048437	SERGEY BORISOV	{"email": "sergey.borisov-18081967@postgrespro.ru", "phone": "+70028655296"}
0005435462848	E1DD90	4359 839045	YULIYA BORISOVA	{"phone": "+70642953535"}
0005435462849	821FDD	4653 297536	OLGA MIKHAYLOVA	{"phone": "+70633905117"}
0005435462850	8FAC9A	6276 591365	LIDIYA ERMAKOVA	{"phone": "+70605738595"}
0005435462851	8FAC9A	7474 108702	SERGEY NAZAROV	{"phone": "+70674687355"}
0005435462852	710BC5	2765 491129	ELENA MAKAROVA	{"email": "makarova.elena28091977@postgrespro.ru", "phone": "+70025291365"}
0005435462853	6535D8	4444 341609	EVGENIY MIRONOV	{"email": "e.mironov.1969@postgrespro.ru", "phone": "+70362050423"}
0005435462854	030B3B	7080 325994	TIMOFEY KISELEV	{"phone": "+70493233081"}
0005435462855	6FC782	7517 875775	IRINA KOVALEVA	{"email": "irina-kovaleva-011973@postgrespro.ru", "phone": "+70673194580"}
0005435462856	6FC782	4385 624994	YULIYA GUSEVA	{"phone": "+70403515424"}
0005435462857	A6B7CC	5323 518889	NATALYA PAVLOVA	{"email": "pavlovanatalya.08021967@postgrespro.ru", "phone": "+70399642615"}
0005435462858	A6B7CC	6313 551878	EKATERINA EFREMOVA	{"email": "ekaterina-efremova_1983@postgrespro.ru", "phone": "+70709284189"}
0005435462859	205E29	5980 700209	OLGA SOROKINA	{"email": "o-sorokina.1975@postgrespro.ru", "phone": "+70948931784"}
0005435462860	205E29	2761 680295	VLADIMIR NAZAROV	{"phone": "+70562456646"}
0005435462861	20BE9B	0394 229640	ELENA NAUMOVA	{"email": "naumova_elena1972@postgrespro.ru", "phone": "+70638512253"}
0005435462862	95B42E	3362 413479	TATYANA PAVLOVA	{"email": "pavlova_tatyana_1976@postgrespro.ru", "phone": "+70580245849"}
0005435462863	6EFCC8	4588 158902	VLADIMIR NIKITIN	{"email": "vladimir.nikitin15121968@postgrespro.ru", "phone": "+70113941066"}
0005435462864	6EFCC8	1911 106530	SERGEY OSIPOV	{"email": "osipov_s.061977@postgrespro.ru", "phone": "+70136780288"}
0005435462865	FF4620	0258 077589	DMITRIY MARTYNOV	{"phone": "+70012288781"}
0005435462866	37735F	5836 036556	ALBINA YAKOVLEVA	{"phone": "+70319236725"}
0005435462867	D609A4	3823 771029	VIKTORIYA KRASNOVA	{"email": "vkrasnova_101986@postgrespro.ru", "phone": "+70036518868"}
0005435462868	A5CEAB	5396 128374	KAMILLA DANILOVA	{"email": "k-danilova-1965@postgrespro.ru", "phone": "+70205249396"}
0005435462869	336D0F	8273 130168	ALEKSEY SCHERBAKOV	{"email": "scherbakov-aleksey14051968@postgrespro.ru", "phone": "+70260955007"}
0005435462870	336D0F	3425 097448	MARGARITA NIKOLAEVA	{"email": "nikolaeva-m071957@postgrespro.ru", "phone": "+70553098164"}
0005435462871	82155C	6384 322124	ANASTASIYA DENISOVA	{"email": "denisovaa_111978@postgrespro.ru", "phone": "+70496639110"}
0005435462872	D2F0F0	0466 831657	RAFIK ANDREEV	{"phone": "+70485813284"}
0005435462873	D2F0F0	6624 209305	OLGA EGOROVA	{"email": "egorova_olga1979@postgrespro.ru", "phone": "+70776354240"}
0005435462874	8A880A	5933 547394	IRINA CHERNOVA	{"email": "ichernova_23061974@postgrespro.ru", "phone": "+70813374129"}
0005435462875	F2635D	4854 916318	MARIYA MIKHAYLOVA	{"phone": "+70892964416"}
0005435462876	A8850B	5391 546983	OKSANA IVANOVA	{"phone": "+70728319649"}
0005435462877	769A79	7132 356019	EVDOKIYA NAUMOVA	{"email": "e-naumova.1964@postgrespro.ru", "phone": "+70910427134"}
0005435462878	769A79	3041 658170	VALENTINA ARKHIPOVA	{"phone": "+70661354661"}
0005435462880	49F732	3245 510705	MARINA KUZMINA	{"email": "m_kuzmina-1971@postgrespro.ru", "phone": "+70024592300"}
0005435462881	FA05C0	3699 848343	OKSANA KARPOVA	{"phone": "+70516412654"}
0005435462882	0C863D	4786 707617	NADEZHDA EFIMOVA	{"email": "n.efimova041972@postgrespro.ru", "phone": "+70675529160"}
0005435462883	43FDA3	1165 224942	ALLA ERMAKOVA	{"email": "a_ermakova_051980@postgrespro.ru", "phone": "+70904761869"}
0005435462884	89A385	0806 538708	DMITRIY ZAYCEV	{"phone": "+70062862195"}
0005435462885	440829	2669 513621	TATYANA BOGDANOVA	{"email": "bogdanovatatyana.021968@postgrespro.ru", "phone": "+70482170719"}
0005435462886	6DDA4E	0272 301250	NIKOLAY ANTONOV	{"email": "nikolay-antonov1979@postgrespro.ru", "phone": "+70776623115"}
0005435462887	1C5DA1	2285 122064	ARTEM NAUMOV	{"email": "naumov-a25061963@postgrespro.ru", "phone": "+70857301760"}
0005435462888	8BF5D4	1283 582137	ANNA DMITRIEVA	{"email": "anna.dmitrieva-28121973@postgrespro.ru", "phone": "+70553084836"}
0005435462889	49C4E9	0767 479310	KIRA SAVELEVA	{"phone": "+70258843371"}
0005435462890	B956B9	5770 777315	ILYA SOLOVEV	{"email": "solovev-ilya24101977@postgrespro.ru", "phone": "+70313308936"}
0005435462891	B956B9	0563 747797	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr13041956@postgrespro.ru", "phone": "+70863188895"}
0005435462892	B956B9	9793 037077	ALEKSANDR GERASIMOV	{"email": "gerasimova-21051970@postgrespro.ru", "phone": "+70155297071"}
0005435462893	9D7385	8003 296904	LARISA DAVYDOVA	{"email": "davydova.l.091974@postgrespro.ru", "phone": "+70240950777"}
0005435462894	85F101	3049 269654	ALIYA VOLKOVA	{"phone": "+70291945395"}
0005435462895	F89B62	3049 040136	DMITRIY EGOROV	{"phone": "+70600281548"}
0005435462896	10E609	4101 794800	MARIYA ZAYCEVA	{"phone": "+70197827265"}
0005435462897	595683	2555 597693	ALEKSEY SCHERBAKOV	{"phone": "+70299862962"}
0005435462898	D11B5A	9768 511346	ANTONINA KUZNECOVA	{"phone": "+70208289933"}
0005435462899	7D3DF7	6672 137566	MARIYA MAKAROVA	{"email": "m-makarova_021979@postgrespro.ru", "phone": "+70727891733"}
0005435462900	7F16FD	0878 094099	ELENA ANDREEVA	{"phone": "+70684053292"}
0005435462901	0A3D02	1096 477056	RAMILYA NIKOLAEVA	{"email": "nikolaeva.ramilya.091963@postgrespro.ru", "phone": "+70322499015"}
0005435462902	0A3D02	3970 844986	EVGENIY CHERNOV	{"email": "chernovevgeniy.06051975@postgrespro.ru", "phone": "+70079561777"}
0005435462903	511B7F	6938 073823	SERGEY KISELEV	{"phone": "+70239557597"}
0005435462904	878474	8562 213863	DMITRIY ILIN	{"email": "dmitriy-ilin-091974@postgrespro.ru", "phone": "+70735376198"}
0005435462905	8B7909	0664 951151	MAKSIM AFANASEV	{"email": "afanasev_m-021972@postgrespro.ru", "phone": "+70733423445"}
0005435462906	DD6F02	7556 967763	VASILIY AFANASEV	{"email": "v.afanasev.31051963@postgrespro.ru", "phone": "+70110068530"}
0005435462907	41CCBC	9187 705151	SOFYA CHERNOVA	{"email": "sofya_chernova011982@postgrespro.ru", "phone": "+70638239204"}
0005435462908	AF20C0	7738 256590	VALENTINA ANDREEVA	{"email": "v.andreeva_061982@postgrespro.ru", "phone": "+70508587338"}
0005435462909	69006B	6014 759667	OKSANA PETROVA	{"phone": "+70981629145"}
0005435462910	544309	8905 060912	DAVID SHEVCHENKO	{"email": "dshevchenko_1976@postgrespro.ru", "phone": "+70293110663"}
0005435462911	F9709D	2792 887351	KONSTANTIN FEDOTOV	{"email": "fedotov.k081974@postgrespro.ru", "phone": "+70728124639"}
0005435462912	BF54E8	0295 256978	TATYANA IVANOVA	{"phone": "+70448452180"}
0005435462913	BF54E8	1637 374465	SVETLANA TITOVA	{"phone": "+70353492987"}
0005435462914	BF54E8	1284 711842	SERGEY GAVRILOV	{"email": "gavrilov-s.1967@postgrespro.ru", "phone": "+70604668859"}
0005435462915	9CEE5D	3592 892413	NIKOLAY BORISOV	{"phone": "+70878429434"}
0005435462916	9CEE5D	0653 053112	VLADIMIR TIMOFEEV	{"email": "vladimir-timofeev-1977@postgrespro.ru", "phone": "+70227478904"}
0005435462917	9CEE5D	8225 055460	LYUDMILA KONDRATEVA	{"email": "kondrateval-1958@postgrespro.ru", "phone": "+70506394412"}
0005435462918	7A98D6	0884 975233	ALEKSANDR FILIPPOV	{"phone": "+70901448922"}
0005435462919	7A98D6	9887 445220	ALEKSEY ANDREEV	{"email": "andreevaleksey.10021976@postgrespro.ru", "phone": "+70220499692"}
0005435462920	860E65	1529 520823	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a_051968@postgrespro.ru", "phone": "+70541345096"}
0005435462921	5D5FEA	7617 738680	YULIYA EGOROVA	{"email": "egorovayuliya_121978@postgrespro.ru", "phone": "+70027049406"}
0005435462922	779AB9	0360 453718	SERGEY AFANASEV	{"email": "afanasev_sergey11061963@postgrespro.ru", "phone": "+70266387506"}
0005435462923	779AB9	7723 137711	MIKHAIL KARPOV	{"email": "karpovmikhail1964@postgrespro.ru", "phone": "+70374672570"}
0005435462924	947734	3563 773130	VLADIMIR VOLKOV	{"phone": "+70730055633"}
0005435462925	FBDC1B	1764 617662	LIDIYA MIRONOVA	{"email": "mironova.lidiya-1977@postgrespro.ru", "phone": "+70063106792"}
0005435462926	3517D9	8068 117555	MIKHAIL POPOV	{"email": "popov_m-26121972@postgrespro.ru", "phone": "+70602537155"}
0005435462927	4F58CB	4688 036574	IRINA OSIPOVA	{"email": "osipovairina-091976@postgrespro.ru", "phone": "+70819038537"}
0005435462928	4F58CB	9641 160341	VERA ZOTOVA	{"email": "v-zotova1982@postgrespro.ru", "phone": "+70158159710"}
0005435462929	424C07	6295 213433	ELENA FROLOVA	{"email": "frolova.elena.1982@postgrespro.ru", "phone": "+70747307304"}
0005435462930	524F0A	7230 268748	LIDIYA PETROVA	{"email": "l-petrova_1984@postgrespro.ru", "phone": "+70304681537"}
0005435462931	BD0C84	0514 863651	ALEKSANDR KULIKOV	{"phone": "+70236747305"}
0005435462932	D4CDC0	5062 066628	ALEKSANDR SAVELEV	{"email": "savelev.a_22041971@postgrespro.ru", "phone": "+70150998144"}
0005435462933	03AB41	4428 471269	ALEKSANDR SIDOROV	{"email": "sidorov-aleksandr021974@postgrespro.ru", "phone": "+70154850655"}
0005435462934	279644	7121 098090	ANNA ALEKSEEVA	{"phone": "+70596995480"}
0005435462935	279644	5271 513746	VLADIMIR SMIRNOV	{"email": "v.smirnov-011976@postgrespro.ru", "phone": "+70763234879"}
0005435462936	056A83	0841 088923	ALEKSANDR IVANOV	{"email": "a-ivanov121974@postgrespro.ru", "phone": "+70326380257"}
0005435462938	8DDB5D	7759 250967	LEONID TARASOV	{"email": "l_tarasov_10101966@postgrespro.ru", "phone": "+70624011846"}
0005435462939	C840A3	1935 641508	ALEKSANDRA EGOROVA	{"phone": "+70711315666"}
0005435462940	3BE0CA	3356 254325	NINA KUZNECOVA	{"email": "kuznecova-n_1978@postgrespro.ru", "phone": "+70709556884"}
0005435462941	A80DC5	7201 938683	YULIYA FILIPPOVA	{"phone": "+70106768305"}
0005435462942	67C484	1985 219181	ALENA FROLOVA	{"phone": "+70264034997"}
0005435462943	F36D72	4138 021010	DARYA MIKHAYLOVA	{"email": "mikhaylova-darya.1964@postgrespro.ru", "phone": "+70763827402"}
0005435462944	9513BE	8317 733262	VERA MELNIKOVA	{"email": "vmelnikova-1978@postgrespro.ru", "phone": "+70320222390"}
0005435462945	805274	7793 787085	SERGEY FROLOV	{"phone": "+70669360441"}
0005435462946	1882EA	4766 627020	ALEKSEY MATVEEV	{"phone": "+70068917759"}
0005435462947	1882EA	1154 015433	ALEKSEY SOROKIN	{"email": "a-sorokin-1971@postgrespro.ru", "phone": "+70800948685"}
0005435462948	A51B51	3902 281486	IRINA NIKITINA	{"email": "i-nikitina-11051965@postgrespro.ru", "phone": "+70101875022"}
0005435462949	EE6CC3	2751 739332	SERGEY KONOVALOV	{"phone": "+70079594216"}
0005435462950	822E73	9986 101666	ELENA FOMINA	{"phone": "+70429800639"}
0005435462951	822E73	6442 735830	EGOR KRASNOV	{"email": "egor-krasnov.121956@postgrespro.ru", "phone": "+70273791619"}
0005435462952	822E73	8816 446931	NATALYA IVANOVA	{"phone": "+70109225932"}
0005435462953	CD825F	0663 714632	TATYANA FEDOROVA	{"email": "fedorova_tatyana.10061964@postgrespro.ru", "phone": "+70943081629"}
0005435462954	96DAA2	3567 019035	ANDREY KUZNECOV	{"phone": "+70997599863"}
0005435462955	991858	0165 267518	LARISA CHERNOVA	{"phone": "+70810904712"}
0005435462956	86871F	9149 582542	SVETLANA POPOVA	{"email": "svetlana-popova_051966@postgrespro.ru", "phone": "+70770909465"}
0005435462957	3F2B82	5035 121496	ELENA KONOVALOVA	{"email": "konovalova.elena_111971@postgrespro.ru", "phone": "+70642803479"}
0005435462958	3F2B82	5450 253792	TATYANA FILIPPOVA	{"email": "filippova-tatyana-1963@postgrespro.ru", "phone": "+70337501848"}
0005435462959	3F2B82	0669 506489	VIKTOR KOZLOV	{"email": "kozlov_viktor-1960@postgrespro.ru", "phone": "+70001724841"}
0005435462960	AA561F	5370 410928	OLGA KOZLOVA	{"phone": "+70861966971"}
0005435462961	8FC141	1975 233720	TATYANA SAVELEVA	{"phone": "+70613720594"}
0005435462962	934365	4081 895065	VLADIMIR IVANOV	{"phone": "+70036124890"}
0005435462963	934365	8894 756632	ALEKSEY ALEKSEEV	{"phone": "+70807524020"}
0005435462964	945562	0904 329482	VALENTINA KONDRATEVA	{"email": "valentinakondrateva.1983@postgrespro.ru", "phone": "+70279700639"}
0005435462965	CD132E	0707 707558	NADEZHDA IVANOVA	{"phone": "+70777159537"}
0005435462966	0AB712	3990 544149	EKATERINA ZHUKOVA	{"email": "zhukova.e-18051982@postgrespro.ru", "phone": "+70240021659"}
0005435462967	B5476B	0950 239710	NINA KOMAROVA	{"phone": "+70864901079"}
0005435462968	896C2D	4520 262567	VITALIY GERASIMOV	{"email": "gerasimovvitaliy.16091977@postgrespro.ru", "phone": "+70265025463"}
0005435462969	B4C1D1	0010 981311	ALEKSANDR KARPOV	{"phone": "+70901870282"}
0005435462970	9FE655	1444 651014	ALEKSEY PETROV	{"phone": "+70149001654"}
0005435462971	69650A	7134 138042	ANASTASIYA VASILEVA	{"phone": "+70161089663"}
0005435462972	69650A	3517 880516	IGOR ISAEV	{"phone": "+70872339757"}
0005435462973	5CCD45	1277 370065	NINA KARPOVA	{"email": "karpova.n_04041960@postgrespro.ru", "phone": "+70226144441"}
0005435462974	175312	3512 333336	ANASTASIYA KUDRYASHOVA	{"phone": "+70529227249"}
0005435462975	CC12A8	6229 040197	OLGA AKIMOVA	{"email": "akimova-o-031960@postgrespro.ru", "phone": "+70694175054"}
0005435462976	004428	6843 416575	MARIYA ISAEVA	{"email": "m-isaeva31011962@postgrespro.ru", "phone": "+70288865905"}
0005435462977	004428	0789 452729	ALFIYA NIKIFOROVA	{"email": "a_nikiforova101973@postgrespro.ru", "phone": "+70566718093"}
0005435462978	004428	8753 256102	OKSANA IVANOVA	{"email": "ivanova_oksana14011973@postgrespro.ru", "phone": "+70575287226"}
0005435462979	922386	7039 177470	ALENA KALININA	{"email": "kalinina_a1967@postgrespro.ru", "phone": "+70097180647"}
0005435462980	922386	4607 760363	VADIM KUZNECOV	{"phone": "+70887027290"}
0005435462981	9DF0F1	0560 601605	EGOR KARPOV	{"email": "ekarpov.05041970@postgrespro.ru", "phone": "+70541163028"}
0005435462982	B1D086	4314 798690	TAMARA SMIRNOVA	{"email": "t-smirnova22021963@postgrespro.ru", "phone": "+70901109176"}
0005435462983	B1D086	4658 618200	VALENTINA SAVELEVA	{"email": "saveleva-v-121975@postgrespro.ru", "phone": "+70562673378"}
0005435462984	F3D2B4	2545 693889	SERGEY SHEVCHENKO	{"phone": "+70267489591"}
0005435462985	1A8865	1120 164619	NADEZHDA MAKAROVA	{"email": "makarova-n.091966@postgrespro.ru", "phone": "+70673445689"}
0005435462986	023E13	2408 066914	NATALYA KISELEVA	{"phone": "+70542221399"}
0005435462987	A81AD4	0806 596546	DMITRIY FEDOTOV	{"phone": "+70361353745"}
0005435462988	7C58F0	1632 328548	GEORGIY DENISOV	{"phone": "+70995359646"}
0005435462989	7C58F0	5325 735479	LYUDMILA MATVEEVA	{"phone": "+70491094433"}
0005435462990	CAD45F	8942 609551	IVAN SEMENOV	{"phone": "+70527839107"}
0005435462991	572116	1821 252170	ANATOLIY STEPANOV	{"email": "stepanovanatoliy_091980@postgrespro.ru", "phone": "+70083828384"}
0005435462992	572116	8929 770717	OLESYA ZOTOVA	{"phone": "+70876403109"}
0005435462993	57ED61	0159 650131	ALEKSANDR FROLOV	{"phone": "+70460146612"}
0005435462994	57ED61	3256 776422	TATYANA ARKHIPOVA	{"phone": "+70345303443"}
0005435462995	B48B7E	1338 311796	NADEZHDA MIRONOVA	{"email": "mironova_nadezhda1966@postgrespro.ru", "phone": "+70413174416"}
0005435462996	B48B7E	6192 819615	ALEKSANDR ILIN	{"phone": "+70797060115"}
0005435462997	79A5C0	3252 139419	KAPITALINA KUZNECOVA	{"email": "kkuznecova.1975@postgrespro.ru", "phone": "+70823315719"}
0005435462998	79A5C0	2150 491787	EKATERINA DENISOVA	{"phone": "+70964703886"}
0005435463119	658A6C	4525 595750	ARTEM ANDREEV	{"phone": "+70434954372"}
0005435462999	13A818	2705 044749	NATALIYA ANISIMOVA	{"email": "n.anisimova1975@postgrespro.ru", "phone": "+70838404012"}
0005435463000	E5C030	6464 897376	DAMIR KRASNOV	{"email": "krasnov-damir_1975@postgrespro.ru", "phone": "+70442208436"}
0005435463001	D4ED24	9397 013921	VLADIMIR RODIONOV	{"phone": "+70746377662"}
0005435463002	8DF581	1240 142572	ALEKSANDR SEMENOV	{"email": "aleksandr-semenov1975@postgrespro.ru", "phone": "+70579213862"}
0005435463003	750CA3	6135 340562	OLESYA STEPANOVA	{"phone": "+70707603865"}
0005435463004	EA4EE8	3254 440526	IRINA AKIMOVA	{"phone": "+70884411005"}
0005435463005	446198	7383 480173	ANTONINA TIMOFEEVA	{"phone": "+70296502925"}
0005435463006	9CB60F	2664 285323	ANDREY SOROKIN	{"email": "sorokin_andrey12041974@postgrespro.ru", "phone": "+70672670168"}
0005435463007	3BFFF9	3663 832880	VALERIYA KOROLEVA	{"phone": "+70502067751"}
0005435463008	99DF62	0019 803945	DARYA ALEKSEEVA	{"phone": "+70804787457"}
0005435463009	23C9D6	7592 610903	NATALYA ANDREEVA	{"email": "n_andreeva071983@postgrespro.ru", "phone": "+70916043425"}
0005435463010	E8ED08	9649 217808	VASILIY ZAKHAROV	{"phone": "+70147918564"}
0005435463011	E8ED08	3015 885513	ANDREY ZAKHAROV	{"email": "zakharov.andrey011981@postgrespro.ru", "phone": "+70570831889"}
0005435463012	18144E	8248 575150	OLEG NOVIKOV	{"email": "o.novikov-081963@postgrespro.ru", "phone": "+70730532530"}
0005435463013	6BDA66	6551 629370	VASILIY SEMENOV	{"phone": "+70775651288"}
0005435463014	B5B04E	8363 416130	ELENA MARTYNOVA	{"phone": "+70686919031"}
0005435463015	1937CC	2696 690239	ANTONINA FROLOVA	{"phone": "+70278309945"}
0005435463016	06EB0A	9566 118596	EDUARD DMITRIEV	{"email": "dmitriev-eduard051966@postgrespro.ru", "phone": "+70468432798"}
0005435463017	06EB0A	2864 245956	MARIYA KOVALEVA	{"phone": "+70169785207"}
0005435463018	D3733B	7402 730068	ANNA STEPANOVA	{"email": "stepanova-anna-02061983@postgrespro.ru", "phone": "+70332155495"}
0005435463019	C3934C	9621 152978	OLGA KISELEVA	{"phone": "+70029769474"}
0005435463020	C3934C	6789 409830	ELENA GRISHINA	{"phone": "+70741234448"}
0005435463021	4BFAED	7899 149850	LYUDMILA MOROZOVA	{"email": "morozova-l_101981@postgrespro.ru", "phone": "+70873711260"}
0005435463022	19CBD2	8195 523753	ALEKSEY KUZMIN	{"email": "kuzmin_a10031969@postgrespro.ru", "phone": "+70060937950"}
0005435463023	E5FD29	8127 242244	LYUDMILA STEPANOVA	{"email": "l-stepanova-101977@postgrespro.ru", "phone": "+70493484429"}
0005435463024	E8513A	7695 229647	TATYANA MAKSIMOVA	{"email": "t_maksimova_11021960@postgrespro.ru", "phone": "+70961769251"}
0005435463025	5CE848	8364 394709	LYUBOV SOROKINA	{"email": "lyubov.sorokina_1965@postgrespro.ru", "phone": "+70631589369"}
0005435463026	A8055A	4556 759350	TATYANA MEDVEDEVA	{"phone": "+70989489872"}
0005435463027	A8055A	2595 099750	IRINA GRISHINA	{"email": "i.grishina-27091974@postgrespro.ru", "phone": "+70813448459"}
0005435463028	1EB0FE	4872 487810	NADEZHDA KONOVALOVA	{"phone": "+70299902372"}
0005435463029	5A3A1A	6457 581826	ZOYA IVANOVA	{"email": "ivanovazoya121978@postgrespro.ru", "phone": "+70421850134"}
0005435463030	5A3A1A	5984 808976	DARYA POTAPOVA	{"phone": "+70322454791"}
0005435463031	228262	9451 430384	MARIYA NAZAROVA	{"phone": "+70245699952"}
0005435463032	1D1246	3570 419423	LYUBOV NAZAROVA	{"phone": "+70880635158"}
0005435463033	613B2F	7282 891198	LYUBOV DAVYDOVA	{"phone": "+70296718396"}
0005435463034	62BC89	4114 236009	LEONID VASILEV	{"email": "vasilev.l_1980@postgrespro.ru", "phone": "+70293368940"}
0005435463035	1433F8	3684 825212	ANGELINA LUKYANOVA	{"phone": "+70643965386"}
0005435463036	86E2CD	2647 667252	MARIYA EFREMOVA	{"email": "m.efremova_27061973@postgrespro.ru", "phone": "+70895277506"}
0005435463037	86E2CD	6998 283180	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov01021975@postgrespro.ru", "phone": "+70086373638"}
0005435463038	625A36	8016 743100	POLINA ZAKHAROVA	{"email": "zakharova.p.041971@postgrespro.ru", "phone": "+70782500956"}
0005435463039	051DEA	6405 003608	VALENTINA KRASNOVA	{"email": "krasnovavalentina.14111978@postgrespro.ru", "phone": "+70258458202"}
0005435463040	9B714D	0384 914679	ALEKSANDR MAKSIMOV	{"email": "maksimov_a28051981@postgrespro.ru", "phone": "+70148009185"}
0005435463041	BF05D5	4934 380794	VALERIYA MIKHAYLOVA	{"phone": "+70743668494"}
0005435463042	0896F4	9308 893951	KSENIYA GORBUNOVA	{"phone": "+70993318799"}
0005435463043	4B1F27	7828 678427	ALEKSANDRA KUZNECOVA	{"email": "kuznecova_a.011986@postgrespro.ru", "phone": "+70927696792"}
0005435463044	73DC52	0126 566244	ALEKSEY KUZNECOV	{"email": "kuznecov-aleksey_041966@postgrespro.ru", "phone": "+70329090093"}
0005435463045	73DC52	6264 236600	ELENA PAVLOVA	{"email": "e_pavlova_24011971@postgrespro.ru", "phone": "+70458090107"}
0005435463046	AFA1A9	6977 041261	EKATERINA KOZLOVA	{"phone": "+70028152736"}
0005435463047	CB8F6E	4343 900343	ILYA VASILEV	{"phone": "+70409479803"}
0005435463048	75D83E	3283 081446	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov_aleksandr_121973@postgrespro.ru", "phone": "+70122035388"}
0005435463049	FF490E	0049 505196	VALERIY BARANOV	{"email": "valeriy_baranov1968@postgrespro.ru", "phone": "+70910195888"}
0005435463050	60E97A	9558 728158	ALEKSANDR FILIPPOV	{"phone": "+70688963986"}
0005435463051	60E97A	4059 687632	TATYANA ALEKSEEVA	{"email": "alekseeva.tatyana.24111977@postgrespro.ru", "phone": "+70125225705"}
0005435463052	762894	3825 332851	VYACHESLAV IVANOV	{"phone": "+70651431601"}
0005435463053	963C34	9936 681139	IRINA SMIRNOVA	{"phone": "+70210328611"}
0005435463054	DAA595	0007 205461	NADEZHDA ANTONOVA	{"phone": "+70093533101"}
0005435463055	DAA595	1292 967778	NIKOLAY EGOROV	{"email": "egorov.n-061974@postgrespro.ru", "phone": "+70850662311"}
0005435463056	67654B	4989 171730	YURIY SOKOLOV	{"phone": "+70670096903"}
0005435463057	5C8969	3934 418004	ANTONINA KUZMINA	{"email": "kuzmina_antonina_07061981@postgrespro.ru", "phone": "+70629304018"}
0005435463058	0B4D2E	6630 962974	ALEKSANDR MATVEEV	{"phone": "+70477835246"}
0005435463059	0B4D2E	4657 376174	VALENTIN BELOV	{"email": "belov_v-1982@postgrespro.ru", "phone": "+70909029818"}
0005435463060	37A3AD	7173 025151	TATYANA RODIONOVA	{"email": "rodionova.tatyana_071978@postgrespro.ru", "phone": "+70241393551"}
0005435463061	458C32	2469 390090	EKATERINA OVCHINNIKOVA	{"email": "eovchinnikova.031975@postgrespro.ru", "phone": "+70396061935"}
0005435463062	458C32	2159 387497	ANASTASIYA OVCHINNIKOVA	{"phone": "+70676530084"}
0005435463063	084836	6862 175433	NATALYA ORLOVA	{"email": "orlovanatalya.091976@postgrespro.ru", "phone": "+70568871210"}
0005435463064	2B9DF4	1482 220231	VLADIMIR MELNIKOV	{"email": "melnikovv.021965@postgrespro.ru", "phone": "+70201349286"}
0005435463065	565958	6450 367170	VALERIYA CHERNOVA	{"email": "valeriya.chernova05051962@postgrespro.ru", "phone": "+70532496801"}
0005435463066	98409F	1379 527799	ALEKSANDR KUDRYASHOV	{"email": "kudryashov-a1963@postgrespro.ru", "phone": "+70370919434"}
0005435463067	5243CF	3471 523284	KSENIYA AKIMOVA	{"phone": "+70877207225"}
0005435463068	5243CF	4845 776729	EVGENIY GRIGOREV	{"phone": "+70864458728"}
0005435463069	9F92A0	5226 765973	GALINA NIKITINA	{"phone": "+70749662736"}
0005435463070	86DBB5	6608 576558	VLADIMIR VLASOV	{"phone": "+70481463628"}
0005435463071	86DBB5	9952 016925	TATYANA DANILOVA	{"email": "t-danilova1956@postgrespro.ru", "phone": "+70684247504"}
0005435463072	027511	7247 704812	ANNA POPOVA	{"phone": "+70563042972"}
0005435463073	98F477	0172 939265	LYUDMILA EFIMOVA	{"email": "efimova.lyudmila081965@postgrespro.ru", "phone": "+70727995765"}
0005435463074	D22557	6202 587878	VADIM DMITRIEV	{"phone": "+70270779830"}
0005435463075	D22557	2256 081119	VASILIY MAKAROV	{"email": "makarov_vasiliy121978@postgrespro.ru", "phone": "+70711416412"}
0005435463076	E640FD	0082 683238	YURIY BONDARENKO	{"email": "bondarenko_yuriy.101979@postgrespro.ru", "phone": "+70764260302"}
0005435463077	E640FD	9828 791720	ANTON VASILEV	{"phone": "+70568757351"}
0005435463078	E640FD	1758 175593	ILYA ANTONOV	{"email": "antonov_ilya_1978@postgrespro.ru", "phone": "+70491808282"}
0005435463079	0F8FE0	3000 840734	VASILIY ANDREEV	{"phone": "+70135204450"}
0005435463080	0F8FE0	2928 275939	EGOR SAVELEV	{"email": "savelev.e26071975@postgrespro.ru", "phone": "+70518129725"}
0005435463081	1C8F7A	8622 908904	ANNA SOROKINA	{"phone": "+70170927433"}
0005435463082	47A01E	4743 673484	ALEVTINA SAVELEVA	{"email": "alevtina_saveleva.101966@postgrespro.ru", "phone": "+70476276064"}
0005435463083	021A9F	2797 205573	KONSTANTIN FILIPPOV	{"phone": "+70730367889"}
0005435463084	904C24	5029 934078	ALEKSEY MAKSIMOV	{"phone": "+70861120127"}
0005435463085	904C24	0488 372404	IGOR ALEKSANDROV	{"email": "igor_aleksandrov_111974@postgrespro.ru", "phone": "+70956147754"}
0005435463086	9FFBB2	5996 938531	ALISHER KISELEV	{"email": "alisher_kiselev04051973@postgrespro.ru", "phone": "+70298758167"}
0005435463087	9FFBB2	1918 278931	SVETLANA ZAYCEVA	{"phone": "+70236550318"}
0005435463088	9FFBB2	3672 108012	VERA MALYSHEVA	{"email": "malysheva-vera-03081967@postgrespro.ru", "phone": "+70235030812"}
0005435463089	311273	2266 685086	GALINA IVANOVA	{"email": "ivanova-g.041954@postgrespro.ru", "phone": "+70032195289"}
0005435463090	311273	5775 057213	VITALIY KARPOV	{"phone": "+70684629426"}
0005435463091	64CDC2	3223 041071	IRINA OSIPOVA	{"phone": "+70710693990"}
0005435463092	E2D435	4687 855704	EVGENIY NIKOLAEV	{"email": "evgeniy.nikolaev-101973@postgrespro.ru", "phone": "+70340512703"}
0005435463093	E2D435	5103 411762	ALEKSANDR MEDVEDEV	{"phone": "+70126764763"}
0005435463094	B69A17	1706 994537	ALINA NOVIKOVA	{"phone": "+70230656474"}
0005435463095	FF7EBF	6412 220914	NATALYA SOLOVEVA	{"email": "nsoloveva.111973@postgrespro.ru", "phone": "+70121239934"}
0005435463096	85F29C	6790 610386	LYUDMILA KISELEVA	{"email": "kiselevalyudmila_1966@postgrespro.ru", "phone": "+70449907882"}
0005435463097	85F29C	6006 188709	OLGA OSIPOVA	{"email": "osipovao01051969@postgrespro.ru", "phone": "+70549904073"}
0005435463098	85F29C	4561 239897	VIKTORIYA DMITRIEVA	{"phone": "+70566545125"}
0005435463099	336484	7153 263379	NATALYA TITOVA	{"email": "natalya_titova_30101967@postgrespro.ru", "phone": "+70953711325"}
0005435463100	336484	1851 436133	ALEKSANDR ZAYCEV	{"phone": "+70974674019"}
0005435463101	D783F8	1604 985240	LYUDMILA KOZLOVA	{"phone": "+70265205409"}
0005435463102	9D87FC	9054 514076	DMITRIY IVANOV	{"phone": "+70590558132"}
0005435463103	6A319F	6065 516069	NAIL SHEVCHENKO	{"email": "shevchenko_n-081968@postgrespro.ru", "phone": "+70330176959"}
0005435463104	0D2209	9973 429092	ANASTASIYA NIKOLAEVA	{"phone": "+70838158966"}
0005435463105	0D2209	7701 772524	OLGA BELOVA	{"phone": "+70973956297"}
0005435463106	700F25	5856 376049	ANNA NOVIKOVA	{"email": "anna.novikova.1970@postgrespro.ru", "phone": "+70908295702"}
0005435463107	2B4759	4526 800481	TIMOFEY YAKOVLEV	{"email": "t_yakovlev_011978@postgrespro.ru", "phone": "+70300142359"}
0005435463108	437C3C	4477 409639	ALEKSANDRA OVCHINNIKOVA	{"phone": "+70018538382"}
0005435463109	2BE3DC	3244 750288	KIRILL MARTYNOV	{"email": "kirillmartynov_111981@postgrespro.ru", "phone": "+70735644421"}
0005435463110	2BE3DC	1831 405770	DMITRIY KISELEV	{"email": "dmitriy_kiselev.061979@postgrespro.ru", "phone": "+70320476431"}
0005435463111	41DAF3	0424 910304	SERGEY TIMOFEEV	{"phone": "+70014992216"}
0005435463112	CC6B22	8050 729996	DARYA ILINA	{"phone": "+70858707716"}
0005435463113	CC6B22	0049 619032	NIKITA BELOV	{"email": "nikita_belov.18071974@postgrespro.ru", "phone": "+70245202138"}
0005435463114	36BA18	7317 565067	ALBINA KONOVALOVA	{"phone": "+70518793436"}
0005435463115	EF207E	2027 063104	ALEKSANDR MEDVEDEV	{"phone": "+70500008644"}
0005435463116	EF207E	6562 688321	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay_1977@postgrespro.ru", "phone": "+70692329167"}
0005435463117	16D78E	8387 788403	VASILIY ANTONOV	{"phone": "+70794437425"}
0005435463118	16D78E	6645 352505	EVGENIYA KOROLEVA	{"phone": "+70628528005"}
0005435463120	D0F45F	8413 945494	ALEKSANDR DMITRIEV	{"email": "a.dmitriev.23091970@postgrespro.ru", "phone": "+70106903704"}
0005435463121	D0F45F	7248 249489	VLADIMIR SMIRNOV	{"email": "v-smirnov1986@postgrespro.ru", "phone": "+70493865668"}
0005435463122	A683E6	7417 654224	IRINA RYABOVA	{"email": "i_ryabova071976@postgrespro.ru", "phone": "+70817610840"}
0005435463123	14C507	3096 338724	VLADIMIR KUZNECOV	{"email": "kuznecov_v13101971@postgrespro.ru", "phone": "+70612504336"}
0005435463124	14C507	2764 799807	IRINA KOROLEVA	{"email": "i-koroleva.1978@postgrespro.ru", "phone": "+70158813018"}
0005435463125	A5EF21	0863 322636	PAVEL ISAEV	{"email": "isaevp-081968@postgrespro.ru", "phone": "+70629735416"}
0005435463126	D19397	4313 119007	ALEKSANDR SOROKIN	{"email": "a-sorokin.11121977@postgrespro.ru", "phone": "+70672742500"}
0005435463127	D19397	3483 037889	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr-031975@postgrespro.ru", "phone": "+70955348050"}
0005435463128	A0BB75	9641 855036	OLEG KUZMIN	{"email": "kuzmin-o_1969@postgrespro.ru", "phone": "+70420107101"}
0005435463129	6A0D8A	3566 178985	VERA NIKOLAEVA	{"email": "nikolaeva_vera_1967@postgrespro.ru", "phone": "+70832515933"}
0005435463130	358D3B	2051 745462	ALEKSEY KUZMIN	{"phone": "+70715094067"}
0005435463131	09CD67	8127 326167	VASILISA MELNIKOVA	{"phone": "+70968564671"}
0005435463132	E54BD0	0697 102523	VERA STEPANOVA	{"email": "stepanovavera.081976@postgrespro.ru", "phone": "+70523393808"}
0005435463133	F033ED	6379 239913	ANASTASIYA STEPANOVA	{"email": "stepanovaanastasiya_1969@postgrespro.ru", "phone": "+70389695431"}
0005435463134	377FE7	6942 112387	ELENA KOZLOVA	{"email": "elena_kozlova_1978@postgrespro.ru", "phone": "+70429707917"}
0005435463135	377FE7	0456 821603	ANTONINA SEMENOVA	{"email": "asemenova.1978@postgrespro.ru", "phone": "+70038531051"}
0005435463136	809FD6	0087 982860	NADEZHDA NIKIFOROVA	{"email": "nadezhda-nikiforova_1960@postgrespro.ru", "phone": "+70288634891"}
0005435463137	7ABA92	0820 210113	EVGENIY KONOVALOV	{"email": "konovalov.e.101993@postgrespro.ru", "phone": "+70395979988"}
0005435463138	F58972	4430 579916	TATYANA ROMANOVA	{"email": "t_romanova121968@postgrespro.ru", "phone": "+70329253809"}
0005435463139	B03C7D	6884 720203	ALFIYA DAVYDOVA	{"email": "davydovaa_16081961@postgrespro.ru", "phone": "+70801305530"}
0005435463140	4922CF	7606 244222	ARTEM MATVEEV	{"email": "matveev_artem_051976@postgrespro.ru", "phone": "+70826828381"}
0005435463141	4D77C4	0402 696834	FARID KULIKOV	{"phone": "+70777019871"}
0005435463142	F15DE1	5547 647538	VADIM KUZMIN	{"email": "vadim_kuzmin_021974@postgrespro.ru", "phone": "+70746792299"}
0005435463143	F15DE1	9954 778157	ALEKSANDR CHERNOV	{"email": "chernov_a.011972@postgrespro.ru", "phone": "+70134906044"}
0005435463144	4B1FCB	7865 949265	IRINA MATVEEVA	{"email": "irina-matveeva_1977@postgrespro.ru", "phone": "+70344087275"}
0005435463145	08BAB7	5037 611301	EVGENIY KUZNECOV	{"email": "evgeniy_kuznecov_04101966@postgrespro.ru", "phone": "+70408530861"}
0005435463146	E26655	3816 417691	GYUZEL IVANOVA	{"email": "ivanovagyuzel.14021965@postgrespro.ru", "phone": "+70633529765"}
0005435463147	8CF06C	2849 584295	ALEVTINA KRASNOVA	{"phone": "+70084739752"}
0005435463148	8F8720	8218 804131	IGOR ZAYCEV	{"phone": "+70488986273"}
0005435463149	AFBE6B	8148 741347	ANDREY BELOV	{"email": "andreybelov.111970@postgrespro.ru", "phone": "+70773166369"}
0005435463150	33CCFA	2412 402459	RUSLAN POPOV	{"phone": "+70889373606"}
0005435463151	F6EA14	1954 512920	NAILYA TITOVA	{"phone": "+70653011820"}
0005435463152	6CAB8B	9063 214698	NINA KALININA	{"phone": "+70661822863"}
0005435463153	9EFBA7	2915 910172	ANATOLIY KAZAKOV	{"phone": "+70662805899"}
0005435463154	3B3BD7	3953 121850	ALEKSANDR ORLOV	{"email": "aleksandr-orlov-071968@postgrespro.ru", "phone": "+70925968213"}
0005435463155	3B3BD7	5511 508055	MARINA MATVEEVA	{"phone": "+70752000476"}
0005435463156	531F17	1372 471364	ILYA BARANOV	{"phone": "+70569090713"}
0005435463157	531F17	2997 952929	GALINA YAKOVLEVA	{"phone": "+70558824865"}
0005435463158	F31B1A	9243 270556	TATYANA FROLOVA	{"phone": "+70717474585"}
0005435463159	F31B1A	2818 656800	ANASTASIYA KISELEVA	{"email": "a_kiseleva-03091970@postgrespro.ru", "phone": "+70519696859"}
0005435463160	43C4EF	4613 122911	IRINA OVCHINNIKOVA	{"email": "ovchinnikova.irina.03051968@postgrespro.ru", "phone": "+70712111870"}
0005435463161	7DA7B7	0100 943504	GALINA LOGINOVA	{"phone": "+70661548383"}
0005435463162	7DA7B7	7649 611751	PAVEL STEPANOV	{"phone": "+70216482898"}
0005435463163	8464E6	2897 664682	VYACHESLAV NAZAROV	{"email": "v_nazarov-1982@postgrespro.ru", "phone": "+70714879669"}
0005435463164	3D6950	3679 168927	PAVEL MAKSIMOV	{"email": "p_maksimov-14101964@postgrespro.ru", "phone": "+70467340109"}
0005435463165	A3E35B	8783 003861	VLADIMIR KISELEV	{"phone": "+70400569399"}
0005435463166	7117E4	7923 800844	DARYA TARASOVA	{"phone": "+70509060293"}
0005435463167	7117E4	9533 922755	EVGENIY MATVEEV	{"phone": "+70922224105"}
0005435463168	A3A53F	0665 789330	YURIY NAUMOV	{"email": "ynaumov_1978@postgrespro.ru", "phone": "+70918928536"}
0005435463169	A3A53F	1511 608994	MIKHAIL IVANOV	{"email": "ivanov-mikhail17091972@postgrespro.ru", "phone": "+70069612683"}
0005435463170	5DCA31	2318 777983	DMITRIY FILIPPOV	{"phone": "+70715431962"}
0005435463171	D2612E	1630 340995	DENIS IVANOV	{"phone": "+70659043090"}
0005435463172	D2612E	5514 545913	VERA TITOVA	{"email": "vera-titova_1971@postgrespro.ru", "phone": "+70816263825"}
0005435463173	3D5250	7226 487605	TATYANA FILIPPOVA	{"email": "tfilippova-27091972@postgrespro.ru", "phone": "+70508564841"}
0005435463174	29B482	6245 628586	ALEKSANDRA EFIMOVA	{"phone": "+70718209477"}
0005435463175	03EE17	8636 283852	TATYANA VASILEVA	{"phone": "+70821700589"}
0005435463176	64AC03	5995 610543	LARISA FEDOROVA	{"email": "fedorova-l-031969@postgrespro.ru", "phone": "+70810767066"}
0005435463177	64C77D	8934 931708	DARYA NIKITINA	{"email": "d.nikitina_01101976@postgrespro.ru", "phone": "+70447977321"}
0005435463178	375C7C	6565 278016	NATALYA ZAYCEVA	{"phone": "+70675902882"}
0005435463179	CA87EC	8186 061969	IRINA KONOVALOVA	{"email": "konovalovai_27051966@postgrespro.ru", "phone": "+70263335783"}
0005435463180	5350B8	2669 742008	TATYANA SOROKINA	{"email": "sorokinat1962@postgrespro.ru", "phone": "+70155589744"}
0005435463181	EF9B59	7706 369605	NATALYA MAKSIMOVA	{"phone": "+70550673211"}
0005435463182	9069D2	0238 990492	MARIYA SMIRNOVA	{"email": "mariyasmirnova-091958@postgrespro.ru", "phone": "+70241580974"}
0005435463183	9069D2	2440 874368	VLADISLAV MELNIKOV	{"email": "melnikov_vladislav.1967@postgrespro.ru", "phone": "+70502399544"}
0005435463184	E3B744	6118 568327	KONSTANTIN BELOV	{"phone": "+70543925253"}
0005435463185	536F38	4313 050412	LYUDMILA GUSEVA	{"phone": "+70099321835"}
0005435463186	536F38	6249 043042	SVETLANA GUSEVA	{"email": "guseva-s_1965@postgrespro.ru", "phone": "+70420403932"}
0005435463187	437A90	0931 475610	RIFAT ZAYCEV	{"email": "rifatzaycev.051971@postgrespro.ru", "phone": "+70083236078"}
0005435463188	17298D	2293 975996	MIKHAIL FOMIN	{"email": "m-fomin.21041975@postgrespro.ru", "phone": "+70358792204"}
0005435463189	A64910	5038 557686	EDUARD MATVEEV	{"email": "eduard_matveev-021973@postgrespro.ru", "phone": "+70461521278"}
0005435463190	805897	7552 606529	LIDIYA VASILEVA	{"email": "vasileva-lidiya-1979@postgrespro.ru", "phone": "+70376580527"}
0005435463191	805897	7821 329399	IVAN FROLOV	{"phone": "+70828769482"}
0005435463192	686FDA	0688 919119	TATYANA MIKHAYLOVA	{"phone": "+70732911087"}
0005435463193	686FDA	8263 979892	SVETLANA PETROVA	{"email": "petrovas121977@postgrespro.ru", "phone": "+70893775229"}
0005435463194	D0F2E1	3524 200100	VLADIMIR RODIONOV	{"phone": "+70181883787"}
0005435463195	D0F2E1	7144 049245	VSEVOLOD MARTYNOV	{"phone": "+70142784764"}
0005435463196	9F3A28	9868 408031	ALEKSANDRA MAKAROVA	{"email": "aleksandra_makarova121963@postgrespro.ru", "phone": "+70220411403"}
0005435463197	713F16	1385 584982	NATALYA GORBUNOVA	{"phone": "+70530873395"}
0005435463198	713F16	7532 489578	KLAVDIYA FEDOROVA	{"email": "fedorova.k31121980@postgrespro.ru", "phone": "+70013967112"}
0005435463199	713F16	7167 659828	PAVEL KRASNOV	{"phone": "+70270791185"}
0005435463200	67030F	6478 036938	ARTEM FROLOV	{"email": "frolova_26011974@postgrespro.ru", "phone": "+70648760870"}
0005435463201	B79591	7931 819396	OLGA MELNIKOVA	{"email": "olga-melnikova-20031979@postgrespro.ru", "phone": "+70306136865"}
0005435463202	B79591	0430 916411	GALINA MALYSHEVA	{"email": "g.malysheva-091967@postgrespro.ru", "phone": "+70585291352"}
0005435463203	B79591	8123 175380	YURIY SAVELEV	{"email": "savelev_yuriy_1978@postgrespro.ru", "phone": "+70387970594"}
0005435463204	9D4D56	9182 006417	VLADIMIR TARASOV	{"email": "v-tarasov.18041964@postgrespro.ru", "phone": "+70963551146"}
0005435463205	DB6E05	6222 861274	SERGEY ZAKHAROV	{"email": "zakharov_s.26091968@postgrespro.ru", "phone": "+70042441588"}
0005435463206	DB6E05	3286 086760	TATYANA CHERNOVA	{"phone": "+70273055698"}
0005435463207	83B433	2341 971240	NIKOLAY IVANOV	{"phone": "+70347123343"}
0005435463208	D89295	4120 713843	IRINA NAZAROVA	{"phone": "+70023837815"}
0005435463209	D89295	4392 272341	EGOR KAZAKOV	{"email": "kazakov.e_09121960@postgrespro.ru", "phone": "+70084520030"}
0005435463210	D89295	1232 851051	ANTONINA ILINA	{"phone": "+70323167423"}
0005435463211	26509A	4009 628044	EKATERINA AFANASEVA	{"email": "afanasevaekaterina041967@postgrespro.ru", "phone": "+70840443478"}
0005435463212	12ABAC	1089 044474	SERGEY KULIKOV	{"email": "s.kulikov-06091984@postgrespro.ru", "phone": "+70924547121"}
0005435463213	A27B9B	7217 214064	YULIYA NIKITINA	{"email": "yuliya-nikitina_1974@postgrespro.ru", "phone": "+70812383759"}
0005435463214	BC0129	5783 915238	MARINA PETROVA	{"phone": "+70693180608"}
0005435463215	BC0129	4274 145395	NADEZHDA LEBEDEVA	{"email": "n-lebedeva011968@postgrespro.ru", "phone": "+70271620062"}
0005435463216	4C3CD3	0595 243703	ANTON VOLKOV	{"email": "anton-volkov-20081976@postgrespro.ru", "phone": "+70928254882"}
0005435463217	4C3CD3	5901 955423	YURIY NAZAROV	{"phone": "+70908932671"}
0005435463218	68A759	6339 031491	DMITRIY MELNIKOV	{"phone": "+70312526874"}
0005435463219	7385F6	5901 206926	GALINA RYABOVA	{"phone": "+70350924234"}
0005435463220	B5A9C9	8185 418275	GALINA POPOVA	{"email": "g-popova-1971@postgrespro.ru", "phone": "+70825376973"}
0005435463221	19D26D	3911 188144	RUSLAN MAKSIMOV	{"phone": "+70775737493"}
0005435463222	FBD871	2091 884051	MILANA SMIRNOVA	{"email": "m.smirnova.07121972@postgrespro.ru", "phone": "+70509245231"}
0005435463223	715291	7667 969801	NATALYA LAZAREVA	{"phone": "+70575759389"}
0005435463224	25213E	6252 927811	ZHANNA MOROZOVA	{"phone": "+70362658010"}
0005435463225	60A1F2	2112 423217	NINA ALEKSEEVA	{"email": "nina-alekseeva031974@postgrespro.ru", "phone": "+70413327873"}
0005435463226	60A1F2	4477 107572	SVETLANA MOISEEVA	{"email": "s.moiseeva-021970@postgrespro.ru", "phone": "+70669939423"}
0005435463227	2F5F96	9065 493850	ARSENIY CHERNOV	{"email": "chernovarseniy-091977@postgrespro.ru", "phone": "+70952528735"}
0005435463228	C0C0A2	9337 791230	VIKTOR BONDARENKO	{"phone": "+70388117712"}
0005435463229	C0C0A2	5144 988496	ALEKSEY KONOVALOV	{"email": "a.konovalov021966@postgrespro.ru", "phone": "+70086570594"}
0005435463230	DDE3B4	7219 958607	VLADIMIR FILIPPOV	{"email": "filippov.v_25061980@postgrespro.ru", "phone": "+70148921332"}
0005435463231	F9EF65	5663 752839	ALEKSANDRA TARASOVA	{"phone": "+70154240883"}
0005435463232	C0C5F4	2897 029523	KAMILA PAVLOVA	{"phone": "+70378502313"}
0005435463233	C56DBF	6220 252094	MAKSIM VLASOV	{"email": "m.vlasov.081976@postgrespro.ru", "phone": "+70348605080"}
0005435463234	B59C0A	0224 152898	NIKOLAY KOZLOV	{"email": "kozlov_nikolay1969@postgrespro.ru", "phone": "+70983132951"}
0005435463235	09D8BB	0085 493861	VYACHESLAV MEDVEDEV	{"phone": "+70876503528"}
0005435463236	09D8BB	1075 477533	ILYA ALEKSANDROV	{"email": "aleksandrovi.101969@postgrespro.ru", "phone": "+70912879299"}
0005435463237	8029A3	8628 923838	ALEKSEY NOVIKOV	{"email": "aleksey_novikov.26081958@postgrespro.ru", "phone": "+70774401974"}
0005435463238	70C6AE	5759 964825	DANILA RODIONOV	{"email": "drodionov-22021975@postgrespro.ru", "phone": "+70011914383"}
0005435463239	BAE65F	5045 403289	ALEKSANDR IVANOV	{"phone": "+70472449609"}
0005435463240	BAE65F	4164 815636	IRINA ABRAMOVA	{"email": "abramova-irina-19071978@postgrespro.ru", "phone": "+70786411359"}
0005435463241	A9186B	9985 922243	ANATOLIY ZAYCEV	{"email": "anatoliy.zaycev30111977@postgrespro.ru", "phone": "+70673823151"}
0005435463242	365791	3204 923404	VALERIYA NIKITINA	{"phone": "+70508992936"}
0005435463243	7ECCEC	5267 173189	ELENA DENISOVA	{"email": "elenadenisova09021972@postgrespro.ru", "phone": "+70421413928"}
0005435463244	7ECCEC	7977 950602	DMITRIY EGOROV	{"email": "egorov-d-071986@postgrespro.ru", "phone": "+70775221597"}
0005435463245	6CEA5C	0090 790262	IVAN MAKAROV	{"email": "ivanmakarov_11051968@postgrespro.ru", "phone": "+70268608525"}
0005435463246	6CEA5C	3884 945006	ANASTASIYA VASILEVA	{"email": "vasilevaa.1961@postgrespro.ru", "phone": "+70141802148"}
0005435463247	6153CE	7407 150825	ANGELINA KUZNECOVA	{"phone": "+70110850575"}
0005435463248	D0E078	0956 206772	EKATERINA ROMANOVA	{"phone": "+70348357534"}
0005435463249	D0E078	9644 017338	MAKSIM IVANOV	{"phone": "+70195695609"}
0005435463250	7C760F	5408 565458	DMITRIY TARASOV	{"email": "dmitriytarasov.091976@postgrespro.ru", "phone": "+70933426178"}
0005435463251	A2C624	0468 415024	LARISA MIKHAYLOVA	{"email": "mikhaylova_larisa1971@postgrespro.ru", "phone": "+70791580963"}
0005435463252	A2C624	6022 830002	ALEKSEY KONOVALOV	{"phone": "+70286484400"}
0005435463253	50A982	0394 046020	ALEKSANDR SMIRNOV	{"email": "smirnov-a.061966@postgrespro.ru", "phone": "+70851885175"}
0005435463254	50A982	4325 385011	ANTON KOZLOV	{"email": "kozlov_anton_021979@postgrespro.ru", "phone": "+70480181902"}
0005435463255	E23E8F	9548 624756	MIKHAIL SEMENOV	{"phone": "+70583027405"}
0005435463256	E23E8F	7993 297235	TATYANA KALININA	{"email": "kalinina.tatyana1962@postgrespro.ru", "phone": "+70430348385"}
0005435463257	E7A136	8181 256815	IGOR IVANOV	{"email": "ivanov-i.091959@postgrespro.ru", "phone": "+70349094534"}
0005435463258	D11FEC	8974 601584	ILYA MAKAROV	{"phone": "+70806355538"}
0005435463259	450685	5732 874949	ELENA SCHERBAKOVA	{"email": "scherbakova-e.1966@postgrespro.ru", "phone": "+70887264752"}
0005435463260	450685	7199 592180	DMITRIY SIDOROV	{"phone": "+70724101680"}
0005435463261	392FAF	8950 172295	PAVEL ROMANOV	{"email": "p.romanov_04021968@postgrespro.ru", "phone": "+70980042892"}
0005435463262	2A23C7	8283 078898	ELENA MARTYNOVA	{"email": "elena.martynova_1969@postgrespro.ru", "phone": "+70557163863"}
0005435463263	3D8F50	4269 335469	OLESYA SCHERBAKOVA	{"email": "olesya_scherbakova.28081963@postgrespro.ru", "phone": "+70440073962"}
0005435463264	3D8F50	6473 673738	KIRILL KUZNECOV	{"email": "kuznecov-kirill_121972@postgrespro.ru", "phone": "+70846892552"}
0005435463265	FE46ED	7788 309753	ANTON SEMENOV	{"email": "asemenov.1972@postgrespro.ru", "phone": "+70886112133"}
0005435463266	FE46ED	7102 485627	ZINAIDA NIKIFOROVA	{"phone": "+70718098067"}
0005435463267	E791EE	9382 464941	TATYANA VOLKOVA	{"phone": "+70696138799"}
0005435463268	E791EE	9922 797039	VIKTOR MATVEEV	{"phone": "+70593932596"}
0005435463269	F55783	9382 474771	EGOR POPOV	{"phone": "+70481725336"}
0005435463270	F3B3D7	3917 930631	STANISLAV MIKHAYLOV	{"phone": "+70433405136"}
0005435463271	8E6020	3721 316904	VLADIMIR GAVRILOV	{"email": "v-gavrilov.1970@postgrespro.ru", "phone": "+70408143163"}
0005435463272	BA24E8	9174 424419	ANGELINA CHERNOVA	{"phone": "+70035095756"}
0005435463273	2B4DC6	0132 388737	ALEKSANDR SAVELEV	{"phone": "+70013485073"}
0005435463274	2B4DC6	7832 554654	SVETLANA KUZNECOVA	{"phone": "+70199311421"}
0005435463275	2B4DC6	4590 146257	OLGA KALININA	{"email": "olgakalinina-1970@postgrespro.ru", "phone": "+70707577387"}
0005435463276	C36E40	1276 544847	NATALIYA ANISIMOVA	{"email": "n-anisimova_051971@postgrespro.ru", "phone": "+70237733872"}
0005435463277	EE4F33	5622 901660	SVETLANA KUZNECOVA	{"phone": "+70707912029"}
0005435463278	C6CFA4	6928 921668	ANATOLIY ALEKSEEV	{"phone": "+70817151629"}
0005435463279	7D3820	9573 529090	ELENA POTAPOVA	{"phone": "+70233192794"}
0005435463280	7D3820	6246 613292	TATYANA FROLOVA	{"phone": "+70945208805"}
0005435463281	41F57E	3641 137563	MARGARITA PETROVA	{"phone": "+70080561114"}
0005435463282	16BF71	2731 138188	DMITRIY GERASIMOV	{"phone": "+70314433718"}
0005435463283	AB618D	3058 207839	NINA FEDOROVA	{"phone": "+70864590346"}
0005435463284	482740	6003 565200	IVAN BELOV	{"phone": "+70017732444"}
0005435463285	482740	6184 094437	EGOR ILIN	{"phone": "+70791046470"}
0005435463286	74FDFE	4090 825940	VASILIY GERASIMOV	{"phone": "+70975729067"}
0005435463287	F59DB7	6961 715330	VASILIY VASILEV	{"phone": "+70363308560"}
0005435463288	012815	3307 607904	LARISA BORISOVA	{"email": "larisa.borisova_16071980@postgrespro.ru", "phone": "+70262786800"}
0005435463289	012815	0138 094516	YULIYA SMIRNOVA	{"email": "yuliya_smirnova_1976@postgrespro.ru", "phone": "+70241819182"}
0005435463290	6F76F3	9835 656011	SERGEY MOROZOV	{"phone": "+70320785671"}
0005435463291	D9559B	6790 715421	LYUDMILA GORBUNOVA	{"email": "gorbunova.lyudmila.22011976@postgrespro.ru", "phone": "+70711380589"}
0005435463292	560585	6116 016734	VIKTOR VLASOV	{"phone": "+70391533950"}
0005435463293	9F8A02	6218 676246	ALEKSEY ALEKSANDROV	{"phone": "+70252258582"}
0005435463294	9F8A02	2260 007809	DMITRIY IVANOV	{"phone": "+70226762588"}
0005435463295	7CAA37	0721 275321	ALEKSANDR NIKOLAEV	{"phone": "+70938585558"}
0005435463296	29D8F8	2014 798094	MIKHAIL ZAYCEV	{"email": "zaycev.mikhail.1980@postgrespro.ru", "phone": "+70850714582"}
0005435463297	0FF399	7129 189137	IGOR SERGEEV	{"phone": "+70270520422"}
0005435463298	F228D5	6711 338907	EVGENIY DMITRIEV	{"phone": "+70709130078"}
0005435463299	454DF5	4486 374411	ANASTASIYA IVANOVA	{"phone": "+70269544905"}
0005435463300	454DF5	8246 136389	VASILIY KOZLOV	{"email": "v.kozlov.05111976@postgrespro.ru", "phone": "+70425404780"}
0005435463301	84E6A5	8164 855269	ELENA NOVIKOVA	{"phone": "+70421171941"}
0005435463302	033458	9555 617032	ALEKSANDRA MIRONOVA	{"email": "aleksandra-mironova1968@postgrespro.ru", "phone": "+70767806921"}
0005435463303	033458	3413 795834	ALEKSANDR ANTONOV	{"phone": "+70179861523"}
0005435463304	780F4D	6848 878501	TATYANA GORBUNOVA	{"email": "t_gorbunova19031962@postgrespro.ru", "phone": "+70384429360"}
0005435463305	780F4D	5925 334246	REGINA GORBUNOVA	{"phone": "+70438217149"}
0005435463306	780F4D	7863 343410	POLINA NIKOLAEVA	{"phone": "+70914054054"}
0005435463307	839877	0078 063561	MIKHAIL SOKOLOV	{"email": "sokolov.m051969@postgrespro.ru", "phone": "+70502574948"}
0005435463308	67FFF9	6094 305664	NINA DMITRIEVA	{"phone": "+70497682512"}
0005435463309	C9C217	5607 035841	VALENTINA SIDOROVA	{"phone": "+70970137854"}
0005435463310	C9C217	7809 008357	VIKTORIYA EGOROVA	{"email": "egorova.viktoriya-21061970@postgrespro.ru", "phone": "+70273300389"}
0005435463311	C9C217	7878 373934	LYUBOV FROLOVA	{"phone": "+70906803333"}
0005435463312	72E434	5964 879555	ELENA VOROBEVA	{"phone": "+70585731215"}
0005435463313	180C95	6399 537454	VIKTORIYA KOLESNIKOVA	{"email": "kolesnikova.v1969@postgrespro.ru", "phone": "+70574501172"}
0005435463314	180C95	4470 730639	NIKOLAY RODIONOV	{"phone": "+70280158801"}
0005435463315	6478AF	0601 516387	ALEKSANDRA PAVLOVA	{"phone": "+70353759111"}
0005435463316	DA1557	7046 457212	TATYANA MAKAROVA	{"phone": "+70291296266"}
0005435463317	21A5D7	3116 625386	EVGENIY ROMANOV	{"phone": "+70709793894"}
0005435463318	D44D40	7597 146522	OLGA VOROBEVA	{"email": "olga_vorobeva_16061978@postgrespro.ru", "phone": "+70081735097"}
0005435463319	D44D40	2535 466738	IVAN KUZNECOV	{"phone": "+70778633563"}
0005435463320	2F61D6	9160 417528	POLINA SEMENOVA	{"email": "semenova_polina-13121976@postgrespro.ru", "phone": "+70187733278"}
0005435463321	4D4936	4686 692475	VERA IVANOVA	{"phone": "+70930321004"}
0005435463322	6D173D	1085 098089	IRINA KUZNECOVA	{"phone": "+70725094012"}
0005435463323	6D173D	2030 793189	OLGA BORISOVA	{"phone": "+70021247438"}
0005435463324	6D173D	5890 397815	ANTON NOVIKOV	{"phone": "+70920956831"}
0005435463325	83584C	2012 659035	EVGENIYA ANISIMOVA	{"phone": "+70002973752"}
0005435463326	83584C	9055 340226	KSENIYA POTAPOVA	{"phone": "+70153851848"}
0005435463327	83584C	6232 283119	SVETLANA KARPOVA	{"phone": "+70493034904"}
0005435463328	536334	0244 041048	ALEKSANDR ANDREEV	{"email": "aleksandr_andreev15031975@postgrespro.ru", "phone": "+70839397622"}
0005435463329	98C032	0539 729188	SVETLANA SMIRNOVA	{"phone": "+70328621695"}
0005435463330	8E193D	0455 973159	ALEKSANDR SOROKIN	{"email": "sorokin.aleksandr-16101966@postgrespro.ru", "phone": "+70233450591"}
0005435463331	1A8A95	4586 329524	VIKTOR GRIGOREV	{"phone": "+70447978660"}
0005435463332	CB68BA	5808 206171	IGOR KOZLOV	{"email": "kozlov_i.11021961@postgrespro.ru", "phone": "+70355482260"}
0005435463333	CB68BA	5874 583337	ILYA KARPOV	{"phone": "+70340644780"}
0005435463334	3DA71E	0192 948702	DANILA NAUMOV	{"phone": "+70401313881"}
0005435463335	ED406F	0911 249896	YULIYA TARASOVA	{"email": "tarasova_y_081974@postgrespro.ru", "phone": "+70379924806"}
0005435463336	F71180	5771 044364	PETR ALEKSEEV	{"email": "p-alekseev.27101983@postgrespro.ru", "phone": "+70205362858"}
0005435463337	2FAA6C	7838 301661	GENNADIY EGOROV	{"phone": "+70215933921"}
0005435463338	BCC5EB	6159 583756	ELIZAVETA STEPANOVA	{"email": "stepanova-elizaveta-27011981@postgrespro.ru", "phone": "+70897323749"}
0005435463339	BCC5EB	2256 116452	ALEKSEY KUDRYASHOV	{"email": "kudryashov_a19041974@postgrespro.ru", "phone": "+70323888873"}
0005435463340	BCC5EB	4170 358971	DMITRIY ZAKHAROV	{"email": "zakharovdmitriy_101968@postgrespro.ru", "phone": "+70472421913"}
0005435463341	BCC5EB	6946 888377	OLGA KOZLOVA	{"email": "olga-kozlova.1965@postgrespro.ru", "phone": "+70986674655"}
0005435463342	E3141E	6255 234075	VIKTOR VASILEV	{"email": "vasilev.viktor.1982@postgrespro.ru", "phone": "+70117182534"}
0005435463343	A91D48	2002 189044	MIKHAIL ZAYCEV	{"phone": "+70494371348"}
0005435463344	A91D48	9584 371547	NATALYA OSIPOVA	{"email": "osipova_natalya1969@postgrespro.ru", "phone": "+70658959276"}
0005435463345	C9BF16	6227 109327	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.19091970@postgrespro.ru", "phone": "+70400041701"}
0005435463346	05D85D	5781 679857	YULIYA NIKITINA	{"email": "yuliyanikitina_19081971@postgrespro.ru", "phone": "+70720452583"}
0005435463347	05D85D	9477 354072	TIGRAN KUZNECOV	{"email": "kuznecovtigran1975@postgrespro.ru", "phone": "+70734150269"}
0005435463348	AE2416	9472 011868	VLADISLAV POPOV	{"phone": "+70438930908"}
0005435463349	5C60B3	1251 767042	ALEKSANDRA FILATOVA	{"phone": "+70978831705"}
0005435463350	5C60B3	7109 227553	SERGEY ANTONOV	{"email": "sergey-antonov1974@postgrespro.ru", "phone": "+70369563039"}
0005435463351	D23FE7	6980 551029	ANNA KRASNOVA	{"email": "krasnova_anna1980@postgrespro.ru", "phone": "+70425729057"}
0005435463352	D23FE7	5585 890424	NIKOLAY NIKITIN	{"phone": "+70170269013"}
0005435463353	5C7243	3023 070526	EKATERINA ZHURAVLEVA	{"phone": "+70644262223"}
0005435463354	B8CAFE	4851 469692	SOFIYA TITOVA	{"phone": "+70723751128"}
0005435463355	B8CAFE	3009 133767	SERGEY OSIPOV	{"phone": "+70874200184"}
0005435463356	D0674E	0837 707294	GALINA KOMAROVA	{"phone": "+70769469063"}
0005435463357	D0674E	6572 616537	GALINA MEDVEDEVA	{"email": "g_medvedeva.1973@postgrespro.ru", "phone": "+70133547013"}
0005435463358	84C844	7702 174476	LYUBOV EGOROVA	{"email": "egorova-l-1980@postgrespro.ru", "phone": "+70091191678"}
0005435463359	A41C54	1928 620249	ALEKSANDR KULIKOV	{"phone": "+70568320009"}
0005435463360	80B9A3	0320 893739	TAISIYA PAVLOVA	{"email": "t.pavlova-101970@postgrespro.ru", "phone": "+70810999129"}
0005435464537	1D4501	8445 218297	SVETLANA MARTYNOVA	{"phone": "+70507928159"}
0005435463361	808FA7	3483 040848	MIKHAIL STEPANOV	{"email": "stepanov.m.071979@postgrespro.ru", "phone": "+70307759162"}
0005435463362	32567E	9754 197476	LARISA VASILEVA	{"phone": "+70160463993"}
0005435463363	32567E	7566 998317	NAZAR SMIRNOV	{"phone": "+70083986318"}
0005435463364	488B0D	9452 978735	VLADIMIR FILIPPOV	{"phone": "+70384182261"}
0005435463365	8936C9	3796 916185	EKATERINA ABRAMOVA	{"phone": "+70946487853"}
0005435463366	5952CF	7433 334075	ARTEM TIKHONOV	{"email": "tikhonov-artem031960@postgrespro.ru", "phone": "+70573279863"}
0005435463367	5952CF	6741 251127	ALEKSANDR SERGEEV	{"phone": "+70180810846"}
0005435463368	4BF7FA	4524 958505	YULIYA ZOTOVA	{"email": "y.zotova_12091973@postgrespro.ru", "phone": "+70057068079"}
0005435463369	4BF7FA	1051 500424	YANA LAZAREVA	{"phone": "+70920087746"}
0005435463370	766018	5689 745745	VALENTINA NESTEROVA	{"email": "valentina_nesterova081994@postgrespro.ru", "phone": "+70639638674"}
0005435463371	236C94	6426 431134	ALLA BELOVA	{"email": "belovaa-28031968@postgrespro.ru", "phone": "+70931042737"}
0005435463372	073D61	5486 859117	KLAVDIYA MELNIKOVA	{"phone": "+70633266268"}
0005435463373	7DEEF9	8191 523352	MIKHAIL CHERNOV	{"email": "chernovm031976@postgrespro.ru", "phone": "+70524500449"}
0005435463374	7DEEF9	9513 634887	SVETLANA TIKHONOVA	{"phone": "+70270764661"}
0005435463375	34163B	4914 711266	YAROSLAV ZHURAVLEV	{"phone": "+70851331589"}
0005435463376	D024AC	2107 232572	NATALYA SMIRNOVA	{"phone": "+70581441157"}
0005435463377	D024AC	8490 767143	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr-061973@postgrespro.ru", "phone": "+70501565769"}
0005435463378	CC3754	2561 284735	EKATERINA NIKITINA	{"phone": "+70142427749"}
0005435463379	A88D43	7793 001340	NIKOLAY DMITRIEV	{"email": "dmitriev-n-091971@postgrespro.ru", "phone": "+70135454217"}
0005435463380	B30268	5604 899787	ELENA POPOVA	{"phone": "+70541361836"}
0005435463381	B30268	7532 867957	YURIY ILIN	{"phone": "+70319788377"}
0005435463382	3CC3A5	5068 345266	ELENA EFREMOVA	{"email": "e-efremova_031974@postgrespro.ru", "phone": "+70690426707"}
0005435463383	B0AA7A	0858 749309	MARINA SOROKINA	{"email": "sorokina_m-121971@postgrespro.ru", "phone": "+70421939779"}
0005435463384	E99791	9450 632788	ANATOLIY NIKITIN	{"email": "nikitin-anatoliy.061981@postgrespro.ru", "phone": "+70638969352"}
0005435463385	CBD6E3	4319 355015	YURIY VOROBEV	{"phone": "+70269015697"}
0005435463386	CBD6E3	0416 397318	MARINA KUDRYASHOVA	{"phone": "+70807095965"}
0005435463387	AE5D28	1708 278631	ANDREY BORISOV	{"phone": "+70662185923"}
0005435463388	AE5D28	7512 000001	NATALIYA PAVLOVA	{"email": "n-pavlova-1980@postgrespro.ru", "phone": "+70564247432"}
0005435463389	AE5D28	7902 075317	VALERIY SEMENOV	{"email": "v.semenov.04061986@postgrespro.ru", "phone": "+70070161631"}
0005435463390	FB5086	6846 996112	LYUDMILA ALEKSANDROVA	{"phone": "+70241405391"}
0005435463391	0C22A3	3716 080750	IRINA KUZNECOVA	{"email": "kuznecova-i.081962@postgrespro.ru", "phone": "+70359969494"}
0005435463392	0C22A3	6265 308458	DENIS SCHERBAKOV	{"email": "scherbakov-d-13031974@postgrespro.ru", "phone": "+70046499303"}
0005435463393	E4549A	6806 490152	OKSANA SAVELEVA	{"email": "savelevao061973@postgrespro.ru", "phone": "+70115616367"}
0005435463394	E4549A	7169 360790	VLADIMIR KARPOV	{"phone": "+70738281849"}
0005435463395	A8EE87	0281 708962	EKATERINA NIKIFOROVA	{"email": "ekaterina-nikiforova.041969@postgrespro.ru", "phone": "+70587917886"}
0005435463396	DEA891	5414 744196	VALENTINA FROLOVA	{"phone": "+70065876872"}
0005435463397	0BE4C0	9671 461989	MARINA ZAKHAROVA	{"email": "zakharovamarina.19071961@postgrespro.ru", "phone": "+70339371171"}
0005435463398	3ACC6B	8811 907249	OLGA FOMINA	{"email": "fomina.o-1981@postgrespro.ru", "phone": "+70164414303"}
0005435463399	D01A4B	4233 225351	NATALYA MARTYNOVA	{"email": "natalya_martynova.22091977@postgrespro.ru", "phone": "+70198479225"}
0005435463400	0AACDB	6505 762337	ALEKSANDR ABRAMOV	{"phone": "+70754140252"}
0005435463401	0AACDB	7453 596233	YAROSLAV POPOV	{"phone": "+70172622081"}
0005435463402	74FE1A	4924 915589	LYUDMILA ZAKHAROVA	{"phone": "+70216392676"}
0005435463403	0E21CA	5074 050083	NINA NAZAROVA	{"phone": "+70985685861"}
0005435463404	3FE2D7	9187 106646	TAMARA SEMENOVA	{"email": "tamara_semenova29121969@postgrespro.ru", "phone": "+70565624486"}
0005435463405	3FE2D7	1859 334650	SERGEY PETROV	{"phone": "+70225501952"}
0005435463406	3FE2D7	1765 479389	ROZA PETROVA	{"phone": "+70672658095"}
0005435463407	15BE72	5750 261076	KONSTANTIN ZAYCEV	{"phone": "+70680331046"}
0005435463408	E5A8D1	5946 339475	YURIY KONOVALOV	{"email": "konovalovyuriy-031970@postgrespro.ru", "phone": "+70316547026"}
0005435463409	E5A8D1	8360 012391	IRINA MAKSIMOVA	{"email": "maksimovai_031976@postgrespro.ru", "phone": "+70074023803"}
0005435463410	E986DA	6434 841799	VASILIY IVANOV	{"email": "v.ivanov1974@postgrespro.ru", "phone": "+70245908270"}
0005435463411	E986DA	1783 692167	IVAN ISAEV	{"phone": "+70142654091"}
0005435463412	E986DA	0406 078982	SERGEY SEMENOV	{"email": "s_semenov_04011968@postgrespro.ru", "phone": "+70098139563"}
0005435463413	FC0BF6	3497 162108	SVETLANA ALEKSANDROVA	{"phone": "+70416805264"}
0005435463414	A2520A	2717 575647	SVETLANA TROFIMOVA	{"email": "trofimova_svetlana-1971@postgrespro.ru", "phone": "+70005661108"}
0005435463415	A2520A	6949 530678	ELIZAVETA ISAEVA	{"email": "isaeva.elizaveta-1971@postgrespro.ru", "phone": "+70208274013"}
0005435463416	9C22BD	0812 695317	IRINA YAKOVLEVA	{"email": "yakovlevai_15051960@postgrespro.ru", "phone": "+70426877414"}
0005435463417	D561FC	9473 501125	KONSTANTIN BONDARENKO	{"email": "bondarenkok04121978@postgrespro.ru", "phone": "+70803416569"}
0005435463418	CCB27A	3380 179579	OLEG STEPANOV	{"email": "o-stepanov.1966@postgrespro.ru", "phone": "+70097678716"}
0005435463419	CDDAAF	6877 351188	LYUDMILA SAVELEVA	{"email": "lyudmila-saveleva.1979@postgrespro.ru", "phone": "+70403551626"}
0005435463420	CDDAAF	4146 432751	IRINA MIKHAYLOVA	{"phone": "+70097568659"}
0005435463421	10A147	6440 115670	ALEKSANDR ORLOV	{"email": "a-orlov.1978@postgrespro.ru", "phone": "+70762089028"}
0005435463422	F98A93	1049 227158	ALEKSANDR KUZMIN	{"phone": "+70796592708"}
0005435463423	01AD1D	5958 319830	ELVIRA EGOROVA	{"email": "egorovae_05111977@postgrespro.ru", "phone": "+70111553176"}
0005435463424	0E5AAF	6629 630659	SERGEY FEDOROV	{"phone": "+70930667343"}
0005435463425	FD6ACD	9135 410038	MIKHAIL STEPANOV	{"email": "mikhailstepanov-111971@postgrespro.ru", "phone": "+70224410355"}
0005435463426	A4C50F	4404 345448	DENIS SERGEEV	{"phone": "+70669088384"}
0005435463427	27B046	3321 395961	ALEKSEY POPOV	{"email": "popov.a-11121971@postgrespro.ru", "phone": "+70760761887"}
0005435463428	1D682A	0206 165254	KIRILL IVANOV	{"email": "kirill.ivanov-28051979@postgrespro.ru", "phone": "+70395892268"}
0005435463429	490A7B	8823 696112	TAMARA SEMENOVA	{"email": "semenova_tamara.1962@postgrespro.ru", "phone": "+70360503348"}
0005435463430	12F89B	5914 210275	IRINA TROFIMOVA	{"email": "trofimovairina.1962@postgrespro.ru", "phone": "+70180394893"}
0005435463431	899976	0054 588017	NIKOLAY KUZNECOV	{"phone": "+70700413848"}
0005435463432	899976	2659 212470	ANNA KULIKOVA	{"phone": "+70996146520"}
0005435463433	F45589	4054 546349	OLGA ALEKSEEVA	{"email": "alekseeva-olga.1971@postgrespro.ru", "phone": "+70502948065"}
0005435463434	660AA1	4199 640995	VALERIYA KAZAKOVA	{"phone": "+70225674728"}
0005435463435	E7E897	2104 864210	ALEKSANDR KAZAKOV	{"phone": "+70252642633"}
0005435463436	D9DF6A	6128 528044	TATYANA MIRONOVA	{"phone": "+70081431458"}
0005435463437	52BEBC	8776 022199	OLGA ZHURAVLEVA	{"email": "zhuravleva_olga_1965@postgrespro.ru", "phone": "+70932750799"}
0005435463438	8C019D	7504 037100	ALEKSEY CHERNOV	{"phone": "+70722413639"}
0005435463439	8C019D	6626 995040	OLGA MIKHAYLOVA	{"email": "mikhaylova-o_22071976@postgrespro.ru", "phone": "+70622948109"}
0005435463440	57074E	9536 754054	MAKSIM AFANASEV	{"phone": "+70273105285"}
0005435463441	A13FB0	4228 896054	ROMAN EGOROV	{"phone": "+70608376348"}
0005435463442	766217	9881 468269	LYUBOV OSIPOVA	{"email": "osipoval.031966@postgrespro.ru", "phone": "+70173033083"}
0005435463443	766217	9381 267241	IRINA SMIRNOVA	{"phone": "+70474031264"}
0005435463444	94663F	8519 760715	TATYANA NIKITINA	{"email": "nikitinat-26111965@postgrespro.ru", "phone": "+70454175442"}
0005435463445	94663F	6176 059581	ANTON TIKHONOV	{"email": "tikhonovanton1976@postgrespro.ru", "phone": "+70051022668"}
0005435463446	87546F	3740 815254	IRINA FEDOROVA	{"email": "fedorova_irina-1957@postgrespro.ru", "phone": "+70720019633"}
0005435463447	87546F	8686 480238	ALEKSANDR SEMENOV	{"email": "semenov.aleksandr-04051972@postgrespro.ru", "phone": "+70869930484"}
0005435463448	A8A101	5394 586274	IVAN BARANOV	{"phone": "+70788613943"}
0005435463449	38888F	5934 368374	MARINA FROLOVA	{"email": "m.frolova-081967@postgrespro.ru", "phone": "+70370959895"}
0005435463450	38888F	1696 935953	MARIYA SMIRNOVA	{"email": "smirnova.mariya.29031971@postgrespro.ru", "phone": "+70855686072"}
0005435463451	3F7BFA	3639 592833	ALEKSANDR IVANOV	{"phone": "+70624857275"}
0005435463452	3F7BFA	2596 627663	ANTONINA POPOVA	{"phone": "+70485713175"}
0005435463453	08A18A	3983 093332	SOFYA LEBEDEVA	{"phone": "+70890352984"}
0005435463454	A49A1F	1630 150761	MARIYA KONOVALOVA	{"phone": "+70841341676"}
0005435463455	A3FBA2	3420 148364	TATYANA AFANASEVA	{"email": "t-afanaseva02071979@postgrespro.ru", "phone": "+70661200601"}
0005435463456	0E0F34	1732 426927	ROMAN KOROLEV	{"phone": "+70172692782"}
0005435463457	76479E	4915 574669	ALEKSEY YAKOVLEV	{"phone": "+70530958735"}
0005435463458	71E4E1	4294 410180	NURIYA ROMANOVA	{"email": "romanova.n-1975@postgrespro.ru", "phone": "+70959728774"}
0005435463459	DAFE27	1678 255751	DENIS BELOV	{"email": "denis_belov_081977@postgrespro.ru", "phone": "+70832281442"}
0005435463460	7ABF33	4788 843352	ALEKSANDR SOROKIN	{"phone": "+70419275212"}
0005435463461	7ABF33	0446 985132	LYUDMILA LUKYANOVA	{"email": "lukyanova.l.051961@postgrespro.ru", "phone": "+70429778452"}
0005435463462	2B7857	7235 112403	EVGENIY VOROBEV	{"email": "e-vorobev-1969@postgrespro.ru", "phone": "+70381334732"}
0005435463463	2B7857	6934 970010	NIKOLAY VOLKOV	{"phone": "+70920931200"}
0005435463464	0B23BF	1483 306257	TATYANA SOROKINA	{"phone": "+70067872564"}
0005435463465	0B23BF	9678 181389	YULIYA ALEKSANDROVA	{"email": "aleksandrovay_031973@postgrespro.ru", "phone": "+70814198651"}
0005435463466	69BC54	8190 462209	DMITRIY DENISOV	{"email": "denisovd-1969@postgrespro.ru", "phone": "+70325228931"}
0005435463467	69BC54	6506 089530	ALEKSEY GRIGOREV	{"phone": "+70125477983"}
0005435463468	056A35	5487 443019	ALEKSANDR FEDOTOV	{"email": "aleksandr.fedotov1981@postgrespro.ru", "phone": "+70584472714"}
0005435463469	056A35	5527 859790	ANDREY PAVLOV	{"email": "pavlova111972@postgrespro.ru", "phone": "+70624541913"}
0005435463470	FAE997	5495 371620	ALEKSANDR ZHUKOV	{"email": "a.zhukov-1967@postgrespro.ru", "phone": "+70294433664"}
0005435463471	FAE997	3591 793534	DARYA PETROVA	{"email": "d_petrova.1972@postgrespro.ru", "phone": "+70248808200"}
0005435463472	467EE6	8049 903137	KARINA KOROLEVA	{"phone": "+70353482453"}
0005435463473	EC67AD	0905 171850	YURIY KOZLOV	{"phone": "+70749490327"}
0005435463474	C5DB31	8903 824013	OLGA VLASOVA	{"phone": "+70100734259"}
0005435463475	0C489D	3277 396002	SVETLANA GORBUNOVA	{"phone": "+70675239153"}
0005435463476	B4DAEE	0051 395106	MARINA EGOROVA	{"phone": "+70194193257"}
0005435463477	F9B451	3725 949648	DMITRIY MAKSIMOV	{"phone": "+70057242274"}
0005435463478	F9B451	5497 371634	ALEKSANDR FEDOTOV	{"email": "a.fedotov.02121969@postgrespro.ru", "phone": "+70046526815"}
0005435463479	DAA249	7386 295640	SERGEY MARTYNOV	{"email": "martynovs.1976@postgrespro.ru", "phone": "+70929149163"}
0005435463480	60449A	2447 756456	VLADIMIR ILIN	{"email": "vladimir_ilin_101987@postgrespro.ru", "phone": "+70620597710"}
0005435463481	60449A	0243 840018	KRISTINA ZOTOVA	{"phone": "+70100636309"}
0005435463482	24FCAD	9830 797918	ELVIRA KALININA	{"email": "e.kalinina1970@postgrespro.ru", "phone": "+70222577619"}
0005435463483	C92A82	7090 576947	MARIYA CHERNOVA	{"email": "mariya-chernova061976@postgrespro.ru", "phone": "+70466841796"}
0005435463484	2ED461	4577 813192	VLADIMIR BORISOV	{"phone": "+70807685081"}
0005435463485	6E506B	5522 180388	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay_14021967@postgrespro.ru", "phone": "+70618823106"}
0005435463486	6E506B	1855 889284	RODION DMITRIEV	{"phone": "+70225686921"}
0005435463487	88F519	2794 628188	SANIYA KARPOVA	{"phone": "+70066498115"}
0005435463488	A7C971	3099 477371	NATALYA GORBUNOVA	{"email": "natalya.gorbunova.02031976@postgrespro.ru", "phone": "+70550231064"}
0005435463489	A7C971	2276 970646	LARISA PETROVA	{"email": "lpetrova121965@postgrespro.ru", "phone": "+70738556579"}
0005435463490	86A802	4853 610887	VLADIMIR BELOV	{"email": "vladimir.belov_071972@postgrespro.ru", "phone": "+70515640691"}
0005435463491	76502C	2895 517800	ALINA KRASNOVA	{"email": "krasnovaa-011979@postgrespro.ru", "phone": "+70298683951"}
0005435463492	BEBB04	0901 328381	RAISA NAZAROVA	{"phone": "+70847206359"}
0005435463493	BEBB04	6593 722833	ALLA ILINA	{"phone": "+70347690448"}
0005435463494	C7D1DF	5820 397535	YURIY GERASIMOV	{"email": "gerasimov.y031976@postgrespro.ru", "phone": "+70664019649"}
0005435463495	37E59F	3992 525607	MAKSIM SCHERBAKOV	{"phone": "+70758137661"}
0005435463496	37E59F	8053 717239	KIRILL SAVELEV	{"phone": "+70946658451"}
0005435463497	9D0960	8822 721691	OLEG DAVYDOV	{"phone": "+70709543283"}
0005435463498	0682E6	6669 556709	NATALYA LUKYANOVA	{"phone": "+70081754164"}
0005435463499	2F2280	7895 241204	VERA OVCHINNIKOVA	{"email": "ovchinnikova_vera.1978@postgrespro.ru", "phone": "+70090959277"}
0005435463500	8D6368	4533 916851	TATYANA NIKITINA	{"email": "t_nikitina.23121961@postgrespro.ru", "phone": "+70772470799"}
0005435463501	8D6368	6985 170715	GRIGORIY BELOV	{"email": "belov_grigoriy_13071967@postgrespro.ru", "phone": "+70068722867"}
0005435463502	311EEB	3454 109041	BOGDAN SEMENOV	{"phone": "+70226636708"}
0005435463503	3FE790	0745 104782	ALEKSANDR GERASIMOV	{"email": "gerasimov.aleksandr.1969@postgrespro.ru", "phone": "+70400557351"}
0005435463504	5E77E1	7254 389469	ALEKSANDR PETROV	{"email": "petrov_a1990@postgrespro.ru", "phone": "+70495279578"}
0005435463505	D21059	9028 116506	VLADIMIR VASILEV	{"phone": "+70041716076"}
0005435463506	D21059	1842 907741	VITALIY DAVYDOV	{"email": "davydov-vitaliy-19111967@postgrespro.ru", "phone": "+70052676648"}
0005435463507	11211E	1132 812721	KLAVDIYA SAVELEVA	{"email": "saveleva-klavdiya.25041974@postgrespro.ru", "phone": "+70969667114"}
0005435463508	11211E	9870 794167	MARINA POPOVA	{"email": "marinapopova.121966@postgrespro.ru", "phone": "+70385521113"}
0005435463509	636818	9435 098934	EKATERINA KOVALEVA	{"phone": "+70095917135"}
0005435463510	58B81F	3268 345136	EKATERINA SOROKINA	{"email": "ekaterina_sorokina111973@postgrespro.ru", "phone": "+70865743006"}
0005435463511	1872B3	2339 237201	LYUBOV MALYSHEVA	{"phone": "+70114881888"}
0005435463512	1872B3	6505 872837	VYACHESLAV YAKOVLEV	{"email": "yakovlev.v1970@postgrespro.ru", "phone": "+70439675244"}
0005435463513	1C7BE3	0645 460438	IVAN MOISEEV	{"email": "moiseevivan1972@postgrespro.ru", "phone": "+70341810977"}
0005435463514	742FCA	0079 215655	LYUDMILA LOGINOVA	{"email": "l.loginova_051979@postgrespro.ru", "phone": "+70569868408"}
0005435463515	61331A	0869 952576	VIKTOR POPOV	{"phone": "+70888394954"}
0005435463516	61331A	1851 824079	NIKOLAY NAZAROV	{"phone": "+70686462422"}
0005435463517	61331A	0601 642024	LARISA SOKOLOVA	{"phone": "+70047129446"}
0005435463518	2B68A6	6578 714229	ALEKSANDR PAVLOV	{"email": "aleksandr_pavlov_07111968@postgrespro.ru", "phone": "+70628067129"}
0005435463519	CB8BA6	9424 335335	OLGA KUZMINA	{"phone": "+70730219660"}
0005435463520	488F6C	3960 849225	ALEKSANDR CHERNOV	{"email": "chernov-a-05071967@postgrespro.ru", "phone": "+70036150523"}
0005435463521	488F6C	5888 155099	VERA ZOTOVA	{"email": "zotova.vera12071978@postgrespro.ru", "phone": "+70819279433"}
0005435463522	488F6C	4042 489684	ANDREY EGOROV	{"email": "egorov_a-14071966@postgrespro.ru", "phone": "+70095930314"}
0005435463523	AE840F	1167 155861	SVETLANA MARTYNOVA	{"email": "martynova_s021974@postgrespro.ru", "phone": "+70565248106"}
0005435463524	69D246	6772 782816	ANATOLIY BARANOV	{"phone": "+70374963892"}
0005435463525	52F6E6	1940 121065	MARINA DAVYDOVA	{"phone": "+70937945469"}
0005435463526	A037F1	7880 664901	ANATOLIY BONDARENKO	{"phone": "+70979642465"}
0005435463527	27588F	4157 635790	YULIYA FEDOROVA	{"phone": "+70640716466"}
0005435463528	DECCDB	4417 937247	ELENA MIKHAYLOVA	{"phone": "+70748099778"}
0005435463529	54B74F	9567 769748	TAMARA ORLOVA	{"email": "t_orlova01061968@postgrespro.ru", "phone": "+70010763704"}
0005435463530	9C6D35	9826 170074	ALIYA ZOTOVA	{"email": "zotovaa_011972@postgrespro.ru", "phone": "+70523037498"}
0005435463531	9C6D35	4840 643710	EVA KUZMINA	{"phone": "+70259846606"}
0005435463532	1F1F4E	3207 404541	TATYANA ISAEVA	{"email": "isaeva.t-21061981@postgrespro.ru", "phone": "+70291885436"}
0005435463533	B28B14	9911 976858	ALEKSANDR MAKSIMOV	{"phone": "+70796444956"}
0005435463534	F69444	3023 892629	ILYA PETROV	{"phone": "+70855967178"}
0005435464472	991BE5	3981 906010	ALEKSEY MELNIKOV	{"phone": "+70229348621"}
0005435464473	991BE5	7585 387816	EVGENIY MOISEEV	{"phone": "+70512514515"}
0005435464528	F478FE	0714 894183	ELENA POPOVA	{"phone": "+70980278659"}
0005435464474	689D93	9666 050208	ANNA ALEKSEEVA	{"email": "alekseeva-a-11121972@postgrespro.ru", "phone": "+70027092803"}
0005435464475	ED48A7	9492 557650	IRINA SMIRNOVA	{"email": "i-smirnova121966@postgrespro.ru", "phone": "+70026015942"}
0005435464476	ED48A7	0865 134514	VALERIY SOLOVEV	{"email": "valeriy.solovev_13051965@postgrespro.ru", "phone": "+70573404350"}
0005435464477	068C46	8690 640132	IVAN KULIKOV	{"phone": "+70493603981"}
0005435464478	D26F81	7507 315870	ANASTASIYA MOROZOVA	{"email": "morozova.a.30041973@postgrespro.ru", "phone": "+70441720447"}
0005435464479	D26F81	8769 083234	ALEKSANDR MIKHAYLOV	{"phone": "+70185547271"}
0005435464480	D41ED1	4145 993552	SVETLANA TROFIMOVA	{"email": "svetlana_trofimova-111961@postgrespro.ru", "phone": "+70257975066"}
0005435464481	D41ED1	9963 563071	EKATERINA ANISIMOVA	{"email": "anisimova_e-05071985@postgrespro.ru", "phone": "+70974541152"}
0005435464482	2617BF	3247 103635	EVGENIY ZAYCEV	{"email": "zaycevevgeniy.071981@postgrespro.ru", "phone": "+70687809662"}
0005435464483	9BBE5F	5193 938723	MIKHAIL SCHERBAKOV	{"email": "scherbakov-mikhail-19011969@postgrespro.ru", "phone": "+70944278601"}
0005435464484	7359EE	3958 050482	VASILIY ABRAMOV	{"phone": "+70227919027"}
0005435464485	7359EE	7223 262866	ALEKSEY SERGEEV	{"phone": "+70777161352"}
0005435464486	7359EE	4970 384903	NATALYA POLYAKOVA	{"email": "polyakovanatalya.1974@postgrespro.ru", "phone": "+70955179485"}
0005435464487	09631B	9461 444106	STANISLAV AFANASEV	{"phone": "+70889269119"}
0005435464488	09631B	5754 352233	SERGEY KOZLOV	{"phone": "+70230156159"}
0005435464489	25789F	4809 382131	TAMARA KULIKOVA	{"phone": "+70514240891"}
0005435464490	D9A617	5504 344156	DMITRIY ZHUKOV	{"phone": "+70645716877"}
0005435464491	D9A617	8917 025615	EKATERINA DENISOVA	{"phone": "+70050674693"}
0005435464492	F0F29F	0752 151277	NATALYA SERGEEVA	{"email": "natalya.sergeeva.09111978@postgrespro.ru", "phone": "+70673069372"}
0005435464493	761E4D	7125 030386	ANDREY OSIPOV	{"phone": "+70982861287"}
0005435464494	B5D402	4921 277279	KONSTANTIN BONDARENKO	{"email": "bondarenko.konstantin_04081974@postgrespro.ru", "phone": "+70008848166"}
0005435464495	80DA3C	3971 589209	ANDREY FILIPPOV	{"email": "filippov_a.071968@postgrespro.ru", "phone": "+70836015840"}
0005435464496	77A4D7	7958 303060	GRIGORIY POPOV	{"phone": "+70810871664"}
0005435464497	77A4D7	5833 065582	NINA STEPANOVA	{"email": "n_stepanova_1973@postgrespro.ru", "phone": "+70411219292"}
0005435464498	FA1E26	3369 108339	YULIYA RODIONOVA	{"email": "yuliya.rodionova_07101970@postgrespro.ru", "phone": "+70311807579"}
0005435464499	2ED76E	3916 163126	KSENIYA MIRONOVA	{"email": "mironova_k.051970@postgrespro.ru", "phone": "+70850975686"}
0005435464500	2ED76E	1741 330273	ANDREY IVANOV	{"email": "a_ivanov-091968@postgrespro.ru", "phone": "+70998806775"}
0005435464501	977D06	1831 984313	SERGEY GRIGOREV	{"email": "grigorev_s.1973@postgrespro.ru", "phone": "+70404057085"}
0005435464502	1EA847	2203 128200	LIYA FEDOROVA	{"email": "l_fedorova_19101963@postgrespro.ru", "phone": "+70085780204"}
0005435464503	530E8B	5032 324728	VYACHESLAV ORLOV	{"phone": "+70147118888"}
0005435464504	349C44	9058 196379	ANTONINA POPOVA	{"phone": "+70142378759"}
0005435464505	02B251	0053 927632	VLADIMIR OSIPOV	{"email": "osipovvladimir.1976@postgrespro.ru", "phone": "+70001620549"}
0005435464506	23DDC0	0681 593768	VALENTINA KUZNECOVA	{"email": "v-kuznecova.19041978@postgrespro.ru", "phone": "+70168283092"}
0005435464507	23DDC0	2869 291565	GALINA KOROLEVA	{"phone": "+70366275394"}
0005435464508	23DDC0	4452 208853	VIKTOR KUZMIN	{"phone": "+70279820562"}
0005435464509	5523D6	1823 419617	IGOR GUSEV	{"email": "i-gusev061965@postgrespro.ru", "phone": "+70486010063"}
0005435464510	F751C5	9274 734189	KIRILL CHERNOV	{"phone": "+70078823241"}
0005435464511	724496	4922 270308	EVDOKIYA LEBEDEVA	{"email": "lebedeva.e-1976@postgrespro.ru", "phone": "+70523389616"}
0005435464512	724496	5980 949066	SERGEY OSIPOV	{"email": "sosipov.051965@postgrespro.ru", "phone": "+70067280805"}
0005435464513	C131D5	9497 191223	VERA ROMANOVA	{"email": "romanova.vera.1963@postgrespro.ru", "phone": "+70230593397"}
0005435464514	C131D5	5571 863881	STEPAN PAVLOV	{"email": "stepan.pavlov_081977@postgrespro.ru", "phone": "+70850793687"}
0005435464515	C131D5	6017 863906	ALISA DENISOVA	{"phone": "+70912898817"}
0005435464516	AFAE13	3709 195872	ELENA GORBUNOVA	{"email": "gorbunova_elena_031973@postgrespro.ru", "phone": "+70429850479"}
0005435464517	AFAE13	7333 476115	ELENA NIKOLAEVA	{"email": "e.nikolaeva_10011970@postgrespro.ru", "phone": "+70184169429"}
0005435464518	AFAE13	7776 876613	ALEKSEY MIKHAYLOV	{"email": "mikhaylov.a-09101978@postgrespro.ru", "phone": "+70827583442"}
0005435464519	3C6195	8784 347274	EVGENIY BELOV	{"phone": "+70617164812"}
0005435464520	3C6195	8136 958338	TATYANA IVANOVA	{"email": "ivanova_tatyana30081964@postgrespro.ru", "phone": "+70195658447"}
0005435464521	92EAEC	0878 314658	ANASTASIYA OSIPOVA	{"email": "anastasiya_osipova-081982@postgrespro.ru", "phone": "+70598591459"}
0005435464522	767E52	6616 814677	OLGA AKIMOVA	{"email": "akimova_o_19111971@postgrespro.ru", "phone": "+70000690080"}
0005435464523	767E52	5196 670785	KRISTINA MOISEEVA	{"email": "kristina_moiseeva_05061971@postgrespro.ru", "phone": "+70932270812"}
0005435464524	E1F7A9	9299 018323	DMITRIY KUZNECOV	{"phone": "+70516567458"}
0005435464525	E1F7A9	8087 872155	NINA STEPANOVA	{"phone": "+70665461475"}
0005435464526	F478FE	1025 146992	SVETLANA KAZAKOVA	{"email": "svetlana.kazakova051975@postgrespro.ru", "phone": "+70457399565"}
0005435464527	F478FE	2931 704343	ANNA NIKOLAEVA	{"email": "anna_nikolaeva_1968@postgrespro.ru", "phone": "+70035755507"}
0005435464529	F478FE	1855 369843	VALERIYA GRISHINA	{"phone": "+70331090964"}
0005435464530	C75F31	4575 170932	NADEZHDA LUKYANOVA	{"email": "lukyanovanadezhda-081971@postgrespro.ru", "phone": "+70625574319"}
0005435464531	888643	5116 925648	MAKSIM ISAEV	{"email": "maksim_isaev.04031974@postgrespro.ru", "phone": "+70815236800"}
0005435464532	826E3B	1882 813688	ALENA TITOVA	{"email": "alenatitova-041977@postgrespro.ru", "phone": "+70746120138"}
0005435464533	9CC0E3	1966 349823	ALI SMIRNOV	{"phone": "+70838289377"}
0005435464534	9CC0E3	9127 246228	GALINA YAKOVLEVA	{"email": "g-yakovleva_02061970@postgrespro.ru", "phone": "+70056371179"}
0005435464535	AFDBE2	9368 483879	GLEB RODIONOV	{"phone": "+70657175336"}
0005435464536	AFDBE2	5969 078887	VIKTOR ALEKSEEV	{"email": "alekseev_viktor-101976@postgrespro.ru", "phone": "+70440355766"}
0005435464538	DE3DE1	3943 570012	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila-021984@postgrespro.ru", "phone": "+70531098369"}
0005435464539	DE3DE1	3806 571001	ANZHELA EGOROVA	{"phone": "+70112987369"}
0005435464540	D41537	4225 531737	IVAN GORBUNOV	{"phone": "+70517433564"}
0005435464541	D41537	1545 676997	NATALYA FEDOROVA	{"phone": "+70122429000"}
0005435464542	8DEDEA	4024 418586	TATYANA ANISIMOVA	{"email": "anisimova-tatyana28081982@postgrespro.ru", "phone": "+70030596952"}
0005435464543	45AECC	2941 877560	ANASTASIYA KARPOVA	{"phone": "+70457903207"}
0005435464544	3834A9	7475 593735	DANILA SMIRNOV	{"email": "smirnov.danila-071973@postgrespro.ru", "phone": "+70386362371"}
0005435464545	3834A9	5261 590108	TATYANA EGOROVA	{"phone": "+70449665492"}
0005435464546	EAF1D8	9296 534745	ALFIYA POPOVA	{"email": "alfiya_popova-12081967@postgrespro.ru", "phone": "+70739785892"}
0005435464547	EAF1D8	1126 238913	ELENA DMITRIEVA	{"email": "dmitrieva.e-1974@postgrespro.ru", "phone": "+70191933111"}
0005435464548	55C582	9541 313026	OKSANA KAZAKOVA	{"phone": "+70241742508"}
0005435464549	55C582	2153 817738	ANASTASIYA ORLOVA	{"email": "orlovaa_27101981@postgrespro.ru", "phone": "+70355458478"}
0005435464550	3C03CE	9129 835180	TATYANA KARPOVA	{"phone": "+70562578816"}
0005435464551	2D6503	4104 606214	PAVEL DMITRIEV	{"email": "pdmitriev1975@postgrespro.ru", "phone": "+70461649373"}
0005435464552	E835B7	6141 922796	SERGEY POPOV	{"email": "s-popov.31051970@postgrespro.ru", "phone": "+70585036455"}
0005435464553	E835B7	5364 215176	ELENA KISELEVA	{"email": "elena-kiseleva1968@postgrespro.ru", "phone": "+70803413053"}
0005435464554	89F5D7	5248 385294	ANATOLIY KUZMIN	{"email": "kuzmin.anatoliy_22111973@postgrespro.ru", "phone": "+70898403468"}
0005435464555	9E2154	3679 053578	ALEKSANDR ABRAMOV	{"email": "abramov.a041980@postgrespro.ru", "phone": "+70139106356"}
0005435464556	F97CD5	7635 340759	ELENA POPOVA	{"email": "popovaelena28021966@postgrespro.ru", "phone": "+70817721792"}
0005435464557	F97CD5	5419 352656	ALEKSANDR FROLOV	{"email": "frolov_a.18021967@postgrespro.ru", "phone": "+70980327699"}
0005435464558	F97CD5	4091 767104	ELIZAVETA FEDOROVA	{"phone": "+70009845281"}
0005435464559	AB9C4A	7855 638377	IVAN BONDARENKO	{"email": "ibondarenko-051960@postgrespro.ru", "phone": "+70924109697"}
0005435464560	0DAB8B	9469 536999	ANATOLIY FOMIN	{"email": "fomin-a111983@postgrespro.ru", "phone": "+70454453943"}
0005435464561	0DAB8B	4021 281362	OLGA IVANOVA	{"email": "olga_ivanova.1968@postgrespro.ru", "phone": "+70497913190"}
0005435464562	8C2495	3351 107092	ALEKSANDR PETROV	{"email": "a-petrov.04071984@postgrespro.ru", "phone": "+70163861906"}
0005435464563	470147	9271 559979	OKSANA MIKHAYLOVA	{"email": "oksana_mikhaylova111961@postgrespro.ru", "phone": "+70136370431"}
0005435464564	BA3333	5260 880173	VLADIMIR ANTONOV	{"email": "vladimir.antonov-1960@postgrespro.ru", "phone": "+70951099468"}
0005435464565	5B6D5A	1077 365233	ELENA DENISOVA	{"email": "denisova_elena.04111969@postgrespro.ru", "phone": "+70018383634"}
0005435464566	5B6D5A	7696 596716	NADEZHDA MAKAROVA	{"phone": "+70539499547"}
0005435472511	F38C39	2775 371920	VALERIY KOROLEV	{"email": "v_korolev1963@postgrespro.ru", "phone": "+70875822629"}
0005435472512	F38C39	4627 476965	LYUBOV SEMENOVA	{"email": "semenova.l_121978@postgrespro.ru", "phone": "+70553059308"}
0005435472513	0F2611	9091 922444	DARYA AFANASEVA	{"email": "darya.afanaseva_1971@postgrespro.ru", "phone": "+70641319258"}
0005435472514	CC7DCA	7315 895528	ARSENIY YAKOVLEV	{"email": "yakovlev.a061966@postgrespro.ru", "phone": "+70435960765"}
0005435472515	7C3135	9908 337037	MARINA PAVLOVA	{"email": "m_pavlova_101977@postgrespro.ru", "phone": "+70429864323"}
0005435472516	7C3135	9423 763705	DENIS TIKHONOV	{"phone": "+70036888819"}
0005435472517	0A0F64	7543 406815	IRINA TIMOFEEVA	{"email": "i.timofeeva18031978@postgrespro.ru", "phone": "+70305291799"}
0005435472518	0A0F64	9951 737362	PETR KUZMIN	{"email": "petr_kuzmin-21061970@postgrespro.ru", "phone": "+70137754191"}
0005435472519	0BFBB8	5033 708838	YURIY IVANOV	{"phone": "+70957721332"}
0005435472520	F00E8C	0249 775538	LARISA POPOVA	{"email": "l_popova20101966@postgrespro.ru", "phone": "+70189973733"}
0005435472521	FD843E	6347 747955	IRINA FOMINA	{"email": "irina-fomina-1964@postgrespro.ru", "phone": "+70949803239"}
0005435472522	FD843E	7150 684536	IVAN VOLKOV	{"phone": "+70655967367"}
0005435472523	0FD673	1626 335684	NATALYA POTAPOVA	{"phone": "+70927420571"}
0005435472524	0FD673	7325 063296	ALINA KALININA	{"email": "kalinina_alina-08061968@postgrespro.ru", "phone": "+70847420493"}
0005435472525	0FD673	4237 732010	OLGA FEDOROVA	{"email": "fedorovao_051977@postgrespro.ru", "phone": "+70621200446"}
0005435472526	D5D1AE	5668 350088	VASILIY YAKOVLEV	{"phone": "+70881224848"}
0005435472527	A18F06	5329 931920	ALEKSANDR KUZMIN	{"phone": "+70292021347"}
0005435472528	A18F06	1047 843145	ALEKSEY SIDOROV	{"phone": "+70450735951"}
0005435472529	7B2598	7598 414099	ELENA FEDOROVA	{"email": "efedorova.031968@postgrespro.ru", "phone": "+70848008316"}
0005435472530	7B2598	3274 420067	MARIYA IVANOVA	{"email": "mariya-ivanova-02101965@postgrespro.ru", "phone": "+70862508276"}
0005435472531	7B2598	0421 189962	EKATERINA NESTEROVA	{"phone": "+70934593942"}
0005435472532	01915B	9098 628603	OLEG KOROLEV	{"phone": "+70580458367"}
0005435472533	01915B	8504 511243	MARINA SIDOROVA	{"email": "marinasidorova-10091971@postgrespro.ru", "phone": "+70230313425"}
0005435472534	333291	0014 273951	GENNADIY SMIRNOV	{"phone": "+70118484760"}
0005435472535	5BCC88	3851 977938	ELIZAVETA ISAEVA	{"phone": "+70640242061"}
0005435472536	61BCF3	5765 829635	NATALYA FROLOVA	{"phone": "+70867752765"}
0005435472537	61BCF3	3170 817025	LYUBOV DMITRIEVA	{"email": "l.dmitrieva.27031977@postgrespro.ru", "phone": "+70814677275"}
0005435472538	61BCF3	6576 800730	MARIYA MAKSIMOVA	{"email": "maksimova_mariya.27081961@postgrespro.ru", "phone": "+70415202754"}
0005435472539	E9EBE5	6672 811326	ANNA SEMENOVA	{"phone": "+70882892742"}
0005435472540	FB6864	1112 679435	VLADIMIR MIKHAYLOV	{"phone": "+70021883638"}
0005435472541	FB6864	3459 895162	VIKTOR MARTYNOV	{"phone": "+70145274238"}
0005435472542	EFD8E2	8637 046781	YURIY SCHERBAKOV	{"email": "scherbakov_y-121980@postgrespro.ru", "phone": "+70931537110"}
0005435472543	07442A	6089 025469	ANATOLIY BELOV	{"email": "a-belov28101982@postgrespro.ru", "phone": "+70494055827"}
0005435472544	5A49B0	2476 907985	ALEKSANDR GERASIMOV	{"email": "gerasimov-a1974@postgrespro.ru", "phone": "+70048566809"}
0005435472545	50A3BB	6337 243051	VALENTINA KARPOVA	{"email": "valentina-karpova-1961@postgrespro.ru", "phone": "+70632591655"}
0005435472546	50A3BB	9494 076730	VYACHESLAV ORLOV	{"email": "orlov-v.04021964@postgrespro.ru", "phone": "+70823549173"}
0005435472547	C8830A	6578 169050	MARINA KULIKOVA	{"email": "kulikova-marina18031972@postgrespro.ru", "phone": "+70539703191"}
0005435472548	7FB89A	8583 290649	ALEKSANDR KOZLOV	{"phone": "+70028557881"}
0005435472549	7FB89A	5950 441227	ALEKSANDRA ALEKSANDROVA	{"phone": "+70045789112"}
0005435472550	6BAD9A	9917 551284	NATALYA LOGINOVA	{"phone": "+70837392149"}
0005435472551	B03530	1268 656311	SERAFIMA ISAEVA	{"phone": "+70790572881"}
0005435472552	82F470	3135 295893	EVDOKIYA MOROZOVA	{"email": "morozova_e_101981@postgrespro.ru", "phone": "+70701087429"}
0005435472553	82F470	4647 459093	IRINA ANISIMOVA	{"phone": "+70440390454"}
0005435472554	3E2A27	3761 915809	OLGA PETROVA	{"email": "petrovaolga.16031973@postgrespro.ru", "phone": "+70475238373"}
0005435472555	3E2A27	1117 792968	ALEKSANDR SERGEEV	{"phone": "+70415882791"}
0005435472556	10000F	9519 504119	IRINA ROMANOVA	{"email": "irinaromanova-17011969@postgrespro.ru", "phone": "+70374123233"}
0005435472557	270C60	6286 196781	LEONID KOZLOV	{"email": "kozlov-leonid.02111967@postgrespro.ru", "phone": "+70423363448"}
0005435472558	8957AA	6041 286151	ANATOLIY SAVELEV	{"phone": "+70337808829"}
0005435472559	6BE996	7450 667088	IRINA GUSEVA	{"phone": "+70150668857"}
0005435472560	9E5C96	8974 547312	ALENA VLASOVA	{"email": "a.vlasova-1978@postgrespro.ru", "phone": "+70723420537"}
0005435472561	9E5C96	7120 371754	ALEKSANDR SERGEEV	{"email": "a.sergeev_011972@postgrespro.ru", "phone": "+70108360799"}
0005435472562	AC94E2	8639 469827	LARISA NAZAROVA	{"email": "l_nazarova.1967@postgrespro.ru", "phone": "+70579512844"}
0005435472563	AC94E2	8162 258265	ILMIR IVANOV	{"phone": "+70541144622"}
0005435472564	AC94E2	5846 495749	ELENA LEBEDEVA	{"phone": "+70216468136"}
0005435472565	A6887A	6437 173658	LIDIYA DMITRIEVA	{"email": "l-dmitrieva-29111963@postgrespro.ru", "phone": "+70150198013"}
0005435472566	A7EEF9	9706 970645	VIKTORIYA VOROBEVA	{"phone": "+70478585257"}
0005435472567	A7EEF9	8855 341089	TIMOFEY ROMANOV	{"email": "t_romanov.26081973@postgrespro.ru", "phone": "+70875275582"}
0005435472568	749B1C	4451 912911	TATYANA ISAEVA	{"phone": "+70642758909"}
0005435472569	DA4961	3972 633932	NATALYA KOROLEVA	{"email": "korolevanatalya26051977@postgrespro.ru", "phone": "+70078790496"}
0005435472570	D3EC71	9647 410218	YURIY IVANOV	{"email": "y_ivanov081972@postgrespro.ru", "phone": "+70138713779"}
0005435472571	D3EC71	7861 294031	KSENIYA TIMOFEEVA	{"email": "timofeevakseniya.101974@postgrespro.ru", "phone": "+70365760031"}
0005435472572	80811B	3370 818342	SERGEY MELNIKOV	{"phone": "+70859886926"}
0005435472573	D732CD	8616 429015	VERA KOZLOVA	{"email": "kozlova.vera1973@postgrespro.ru", "phone": "+70941094105"}
0005435472574	08148C	8494 710867	SVETLANA IVANOVA	{"phone": "+70245834039"}
0005435472575	08148C	1937 101612	OKSANA PETROVA	{"email": "opetrova_16091967@postgrespro.ru", "phone": "+70314912558"}
0005435472576	E26FFE	6936 129247	VLADIMIR MAKAROV	{"phone": "+70875864328"}
0005435472577	E26FFE	1332 581233	EVGENIY BARANOV	{"email": "baranovevgeniy_1972@postgrespro.ru", "phone": "+70323800404"}
0005435472578	F59E87	5815 714936	ANATOLIY ZHURAVLEV	{"email": "zhuravlev_anatoliy_111980@postgrespro.ru", "phone": "+70930586014"}
0005435472579	F59E87	7593 313620	MARIYA KONOVALOVA	{"phone": "+70189132336"}
0005435472580	711F2F	1178 347666	EKATERINA ZAYCEVA	{"phone": "+70380250318"}
0005435472581	498274	5917 684048	OLGA TROFIMOVA	{"phone": "+70292766169"}
0005435472582	A245B7	8829 397609	ANASTASIYA IVANOVA	{"email": "a_ivanova_1977@postgrespro.ru", "phone": "+70635880080"}
0005435472583	43EBD0	2999 379690	ILYA FEDOTOV	{"email": "fedotov.i_061966@postgrespro.ru", "phone": "+70784862405"}
0005435472584	43EBD0	7902 842531	ANATOLIY MARTYNOV	{"email": "anatoliy_martynov.29031972@postgrespro.ru", "phone": "+70587827584"}
0005435472585	AAA09C	7242 153805	ALEKSANDR VOROBEV	{"email": "aleksandr_vorobev-29081970@postgrespro.ru", "phone": "+70857826957"}
0005435472586	AF96D7	3296 752837	NATALIYA MEDVEDEVA	{"phone": "+70077078882"}
0005435472587	9F41AE	0700 397301	ALEKSEY KISELEV	{"email": "kiselev-aleksey.051976@postgrespro.ru", "phone": "+70619434364"}
0005435472588	43067F	9191 242404	TATYANA KRASNOVA	{"phone": "+70013538494"}
0005435472589	43067F	4549 251982	ANNA MALYSHEVA	{"email": "malysheva-a_09061976@postgrespro.ru", "phone": "+70631918704"}
0005435472590	DD5737	0184 606457	ARTUR SCHERBAKOV	{"email": "scherbakovartur031967@postgrespro.ru", "phone": "+70230798865"}
0005435472591	B8E6C7	2874 700495	POLINA AKIMOVA	{"phone": "+70247757688"}
0005435472592	B8E6C7	6045 141256	NATALIYA BELOVA	{"phone": "+70079818066"}
0005435472593	034367	9734 303011	VLADIMIR NIKITIN	{"phone": "+70441558632"}
0005435472594	42026A	4252 027200	GALINA FROLOVA	{"email": "frolova.g_1970@postgrespro.ru", "phone": "+70999226478"}
0005435472595	42026A	2877 107314	ALEKSANDRA KOVALEVA	{"email": "akovaleva20111973@postgrespro.ru", "phone": "+70289558604"}
0005435472596	0E7D37	9658 482983	NATALIYA LOGINOVA	{"phone": "+70051581226"}
0005435472597	0E7D37	1445 303902	EVGENIYA VASILEVA	{"email": "vasileva-e.031972@postgrespro.ru", "phone": "+70172482083"}
0005435472598	9BCC1B	7480 805852	GULNARA SOROKINA	{"email": "gulnarasorokina.23101970@postgrespro.ru", "phone": "+70763739785"}
0005435472599	5075C8	6332 068762	YULIYA VOROBEVA	{"phone": "+70925595136"}
0005435472600	10D116	6231 296273	NATALYA IVANOVA	{"email": "ivanovan_23081967@postgrespro.ru", "phone": "+70949868214"}
0005435472601	A1EF91	3262 541853	YURIY KUZNECOV	{"phone": "+70155324601"}
0005435472602	A1EF91	1371 663289	VLADIMIR FILIPPOV	{"phone": "+70692042719"}
0005435472603	776359	3873 326444	EKATERINA SIDOROVA	{"phone": "+70453658504"}
0005435472604	776359	2902 158620	FARIDA TIKHONOVA	{"phone": "+70984728233"}
0005435472605	46FEC7	8316 909520	MAKSIM TARASOV	{"phone": "+70756425476"}
0005435472606	46FEC7	9862 212372	ALEKSEY VASILEV	{"email": "vasileva081975@postgrespro.ru", "phone": "+70927008440"}
0005435472607	6F9208	7207 432006	PAVEL MIRONOV	{"phone": "+70049261594"}
0005435472608	17D373	2948 907295	VIKTOR MIKHAYLOV	{"phone": "+70051058935"}
0005435472609	FBBC7F	0544 186250	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr_101965@postgrespro.ru", "phone": "+70425373766"}
0005435472610	A919C6	6797 319359	OKSANA NESTEROVA	{"email": "o_nesterova_08121973@postgrespro.ru", "phone": "+70728293218"}
0005435472611	A919C6	5020 225395	NIKOLAY IVANOV	{"email": "nikolay.ivanov-1968@postgrespro.ru", "phone": "+70170718123"}
0005435472612	6A9904	0793 708870	ALEKSEY GAVRILOV	{"email": "gavrilov-a-1971@postgrespro.ru", "phone": "+70024529476"}
0005435472613	4791F8	1826 420005	MARINA KUZNECOVA	{"email": "marinakuznecova.1974@postgrespro.ru", "phone": "+70168452836"}
0005435472614	9DCB3B	7688 888626	ANATOLIY SCHERBAKOV	{"phone": "+70114861465"}
0005435472615	9DCB3B	0577 745466	MARIYA ISAEVA	{"email": "isaevam_1964@postgrespro.ru", "phone": "+70659555652"}
0005435472616	DAE7DE	7036 017213	ANNA SOROKINA	{"phone": "+70535997468"}
0005435472617	DAE7DE	3340 164680	SERGEY SMIRNOV	{"email": "smirnov-sergey-071970@postgrespro.ru", "phone": "+70201387716"}
0005435472618	95D47C	7898 816007	ANASTASIYA RODIONOVA	{"email": "a.rodionova_1967@postgrespro.ru", "phone": "+70225244114"}
0005435472619	B93FB3	7640 314539	GENNADIY NIKITIN	{"email": "gnikitin121975@postgrespro.ru", "phone": "+70115540946"}
0005435472620	3329AA	1920 716560	ARTEM BORISOV	{"phone": "+70924682804"}
0005435472621	6C0909	2545 895056	IGOR MAKAROV	{"phone": "+70918615484"}
0005435472622	6C0909	8246 948060	SERGEY PETROV	{"email": "petrovs.051971@postgrespro.ru", "phone": "+70687890666"}
0005435472623	26D4F8	5364 236875	ANTONINA NOVIKOVA	{"phone": "+70370794755"}
0005435472624	9A9905	2234 651629	NADEZHDA KUZNECOVA	{"phone": "+70807722321"}
0005435472625	9A9905	8959 273157	TATYANA MEDVEDEVA	{"phone": "+70880020821"}
0005435472626	9A9905	6767 508467	VALENTINA SOKOLOVA	{"phone": "+70971340533"}
0005435472627	DDB511	6566 782800	GALINA EFREMOVA	{"email": "efremova-galina1970@postgrespro.ru", "phone": "+70158671129"}
0005435472628	85908A	0079 286680	DMITRIY FILIPPOV	{"phone": "+70777613292"}
0005435472629	85908A	8792 550982	YURIY AFANASEV	{"email": "yuriyafanasev.1969@postgrespro.ru", "phone": "+70763324064"}
0005435472630	7F96CE	7979 243966	MARIYA BOGDANOVA	{"phone": "+70914126524"}
0005435472631	C56A25	4882 315556	SVETLANA ZHUKOVA	{"email": "zhukova-s-021968@postgrespro.ru", "phone": "+70705131947"}
0005435472632	D6E2CB	6127 068158	NIKITA KUDRYASHOV	{"phone": "+70893898092"}
0005435472633	8792D5	3980 630059	NATALYA ROMANOVA	{"email": "nromanova1974@postgrespro.ru", "phone": "+70110691199"}
0005435472634	B50EE0	0263 404261	IGOR PAVLOV	{"phone": "+70399122292"}
0005435472635	B50EE0	2585 169326	ALEKSEY SOLOVEV	{"phone": "+70742654156"}
0005435472636	98CD89	8612 444242	ALEKSEY SCHERBAKOV	{"email": "aleksey-scherbakov.1977@postgrespro.ru", "phone": "+70529587947"}
0005435472637	137EF8	2702 848950	SERGEY NOVIKOV	{"phone": "+70807340390"}
0005435472638	137EF8	4103 849788	DMITRIY SCHERBAKOV	{"phone": "+70937325559"}
0005435472639	493F0D	8062 333326	MARINA NIKOLAEVA	{"phone": "+70196289497"}
0005435472640	493F0D	9699 694705	ALEKSANDR VOROBEV	{"phone": "+70427877681"}
0005435472641	493F0D	5624 214532	STANISLAV ZAKHAROV	{"phone": "+70800288293"}
0005435472642	815C79	8996 391243	ARINA MELNIKOVA	{"phone": "+70658782567"}
0005435472643	1153D8	3834 475486	ANNA ROMANOVA	{"phone": "+70834852446"}
0005435472644	2D8150	2384 935931	NADEZHDA KONDRATEVA	{"email": "kondrateva_n.1964@postgrespro.ru", "phone": "+70050061680"}
0005435472645	282CEF	6196 949559	NIKITA RODIONOV	{"phone": "+70262602552"}
0005435472646	E86E52	1238 396798	VLADIMIR SCHERBAKOV	{"phone": "+70398182095"}
0005435472647	4B1FC1	6495 497247	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov_28071972@postgrespro.ru", "phone": "+70675410315"}
0005435472648	BE607E	5868 430543	DIANA KOZLOVA	{"phone": "+70360277759"}
0005435472649	632B7D	8630 950814	MIKHAIL FEDOROV	{"email": "fedorov.mikhail-06061962@postgrespro.ru", "phone": "+70204457352"}
0005435472650	632B7D	2184 269100	DENIS KUDRYASHOV	{"email": "d.kudryashov_1973@postgrespro.ru", "phone": "+70940061452"}
0005435472651	32E9FD	5028 291868	LARISA SIDOROVA	{"phone": "+70910952390"}
0005435472652	AADF19	9328 372842	OKSANA NIKITINA	{"phone": "+70379684559"}
0005435472653	86D29D	6740 203048	SERGEY SHEVCHENKO	{"email": "s_shevchenko03101971@postgrespro.ru", "phone": "+70208774622"}
0005435472654	86D29D	4497 758792	PAVEL GERASIMOV	{"email": "gerasimov_pavel.031964@postgrespro.ru", "phone": "+70087823105"}
0005435472655	89AAFF	2017 471502	ALEKSEY ILIN	{"phone": "+70799214049"}
0005435472656	C9948E	1456 239838	IVAN KARPOV	{"phone": "+70372478478"}
0005435472657	C636C9	7745 003752	NATALYA FADEEVA	{"phone": "+70472168250"}
0005435472658	1949FD	7652 583014	SOFIYA ZAKHAROVA	{"phone": "+70388593519"}
0005435472659	C16BE5	9529 038733	NIKOLAY MOROZOV	{"phone": "+70890518217"}
0005435472660	B55BBC	4030 473207	SERGEY FOMIN	{"email": "sergeyfomin-031971@postgrespro.ru", "phone": "+70692897904"}
0005435472661	D18733	2512 955254	ILYAS IVANOV	{"email": "iivanov071972@postgrespro.ru", "phone": "+70139150096"}
0005435472721	7E8C92	2339 609868	MATVEY EGOROV	{"phone": "+70632464866"}
0005435472662	1151D6	5049 864015	LYUDMILA LEBEDEVA	{"email": "lyudmilalebedeva_021976@postgrespro.ru", "phone": "+70462547127"}
0005435472663	26046B	4149 430692	LYUBOV ANTONOVA	{"phone": "+70174766891"}
0005435472664	D9FFD7	6980 442174	IRINA ORLOVA	{"email": "orlova.irina_25061977@postgrespro.ru", "phone": "+70166007174"}
0005435472665	3ADA39	6385 405946	ANASTASIYA ORLOVA	{"email": "orlovaa.051973@postgrespro.ru", "phone": "+70906096094"}
0005435472666	5FB823	9326 107393	DARYA YAKOVLEVA	{"email": "d.yakovleva031974@postgrespro.ru", "phone": "+70346621439"}
0005435472667	6469AB	7134 707806	YURIY PETROV	{"phone": "+70485933374"}
0005435472668	C4002B	8193 400041	RAVIL AFANASEV	{"email": "ravilafanasev1964@postgrespro.ru", "phone": "+70961332308"}
0005435472669	08B58F	4829 324352	ANATOLIY IVANOV	{"email": "ivanov_anatoliy-1981@postgrespro.ru", "phone": "+70622344400"}
0005435472670	08B58F	8076 872183	IVAN SMIRNOV	{"phone": "+70053773162"}
0005435472671	303941	8885 901219	ARTEM MELNIKOV	{"email": "melnikovartem-06061971@postgrespro.ru", "phone": "+70360851168"}
0005435472672	303941	4673 018419	ALEKSEY ZAKHAROV	{"phone": "+70181792585"}
0005435472673	23EFB3	1495 265963	ALEKSANDR KUZNECOV	{"email": "a_kuznecov011962@postgrespro.ru", "phone": "+70741408670"}
0005435472674	5C2189	5073 573250	IRINA ANDREEVA	{"email": "andreevai_20091978@postgrespro.ru", "phone": "+70900848654"}
0005435472675	27FB96	0390 939453	ANDREY POPOV	{"email": "popov-a.101982@postgrespro.ru", "phone": "+70783099134"}
0005435472676	27FB96	0386 381968	VLADIMIR GUSEV	{"email": "v_gusev_25061972@postgrespro.ru", "phone": "+70380791593"}
0005435472677	203A1C	9514 627148	VLADIMIR TARASOV	{"email": "tarasov_vladimir1969@postgrespro.ru", "phone": "+70411898660"}
0005435472678	203A1C	7119 429194	NATALIYA ABRAMOVA	{"phone": "+70541947787"}
0005435472679	C81FEC	4828 959828	EGOR SCHERBAKOV	{"phone": "+70765091808"}
0005435472680	C81FEC	3037 701030	NINA POPOVA	{"phone": "+70976423383"}
0005435472681	B76659	1369 876073	ANDREY MOROZOV	{"email": "andrey_morozov-1974@postgrespro.ru", "phone": "+70862907273"}
0005435472682	01427C	1593 118894	VALENTINA KOVALEVA	{"phone": "+70638497043"}
0005435472683	3536D8	9614 157967	ANATOLIY EGOROV	{"phone": "+70486379735"}
0005435472684	C68AE3	6063 111158	SERGEY POPOV	{"email": "popov.s.17101963@postgrespro.ru", "phone": "+70482074678"}
0005435472685	00A2B7	3038 175572	ALINA NIKOLAEVA	{"email": "alinanikolaeva-041978@postgrespro.ru", "phone": "+70539304152"}
0005435472686	6726A2	9462 992995	MARIYA EGOROVA	{"phone": "+70051810924"}
0005435472687	060593	3224 857469	ELENA MARTYNOVA	{"phone": "+70030713890"}
0005435472688	060593	1101 076688	KONSTANTIN FEDOROV	{"phone": "+70177058443"}
0005435472689	DF6A78	5115 785240	OLEG SIDOROV	{"email": "oleg_sidorov021972@postgrespro.ru", "phone": "+70822800934"}
0005435472690	B7399E	4251 033061	VLADISLAV ABRAMOV	{"phone": "+70244257388"}
0005435472691	B87F2B	7458 997440	NATALIYA VLASOVA	{"email": "nvlasova-121976@postgrespro.ru", "phone": "+70346570818"}
0005435472692	2518CD	4673 991738	OLGA ORLOVA	{"phone": "+70724645265"}
0005435472693	755396	6235 242671	YURIY MELNIKOV	{"email": "melnikov-yuriy1968@postgrespro.ru", "phone": "+70957398730"}
0005435472694	755396	7688 304496	ANNA AFANASEVA	{"phone": "+70987819053"}
0005435472695	0B4339	4409 530562	ANNA KONDRATEVA	{"email": "kondratevaa_24021970@postgrespro.ru", "phone": "+70784236945"}
0005435472696	0B4339	2415 948997	TATYANA KUZMINA	{"email": "tatyana_kuzmina-03071978@postgrespro.ru", "phone": "+70629999339"}
0005435472697	120107	6910 503485	VALENTINA KOZLOVA	{"phone": "+70016226336"}
0005435472698	120107	9214 486079	RAFAEL KUZNECOV	{"email": "rkuznecov-25121972@postgrespro.ru", "phone": "+70761126517"}
0005435472699	120107	8556 569729	EVGENIYA TARASOVA	{"email": "tarasova.evgeniya.05061963@postgrespro.ru", "phone": "+70084964489"}
0005435472700	E80FD8	6958 194873	ALBINA ZAYCEVA	{"phone": "+70278399729"}
0005435472701	E80FD8	2125 186418	VALERIYA KONDRATEVA	{"phone": "+70805223196"}
0005435472702	7CE536	4261 289828	MARIYA ZAKHAROVA	{"email": "m-zakharova_1990@postgrespro.ru", "phone": "+70432206122"}
0005435472703	7CE536	4236 684249	YULIYA MATVEEVA	{"email": "y_matveeva.071976@postgrespro.ru", "phone": "+70638164139"}
0005435472704	C54AF8	1817 211081	VALERIY IVANOV	{"email": "ivanov_v111968@postgrespro.ru", "phone": "+70788033375"}
0005435472705	C54AF8	7264 410187	DENIS POPOV	{"email": "denis_popov_1977@postgrespro.ru", "phone": "+70988867455"}
0005435472706	62F098	4546 035533	NIKOLAY STEPANOV	{"email": "stepanov_nikolay081984@postgrespro.ru", "phone": "+70854659079"}
0005435472707	D8757E	1297 771095	IRINA SOLOVEVA	{"phone": "+70046363839"}
0005435472708	47A18B	8348 305002	VLADIMIR NOVIKOV	{"phone": "+70414964557"}
0005435472709	4097B3	9638 724692	ALEKSANDR SAVELEV	{"email": "savelev-a061977@postgrespro.ru", "phone": "+70324885894"}
0005435472710	050488	9549 929437	SERGEY ZAYCEV	{"phone": "+70025837562"}
0005435472711	050488	8056 661840	OLEG STEPANOV	{"email": "stepanov_oleg.1981@postgrespro.ru", "phone": "+70018274109"}
0005435472712	CEF05A	4710 687390	ALEKSANDR SIDOROV	{"email": "sidorov-aleksandr.111963@postgrespro.ru", "phone": "+70755109147"}
0005435472713	092081	2863 217380	YURIY VOROBEV	{"email": "yuriy_vorobev.1978@postgrespro.ru", "phone": "+70222161194"}
0005435472714	DDC00F	5783 368292	EKATERINA AKIMOVA	{"email": "eakimova_31051972@postgrespro.ru", "phone": "+70996467876"}
0005435472715	5E3357	9278 423371	ELENA KUZMINA	{"phone": "+70472124420"}
0005435472716	F412E6	9384 006879	OLGA YAKOVLEVA	{"email": "yakovleva-o1972@postgrespro.ru", "phone": "+70730475527"}
0005435472717	E06B59	6654 148712	EKATERINA NESTEROVA	{"email": "nesterova_e-27061966@postgrespro.ru", "phone": "+70881721156"}
0005435472718	7669F0	9547 083274	DMITRIY GUSEV	{"phone": "+70983773833"}
0005435472719	C32699	1832 443399	VALENTINA ILINA	{"email": "ilina-valentina_1963@postgrespro.ru", "phone": "+70477952706"}
0005435472720	6128C1	2047 007407	ILYA GAVRILOV	{"email": "ilya.gavrilov_031967@postgrespro.ru", "phone": "+70925770404"}
0005435472722	7E8C92	5455 251448	IRINA CHERNOVA	{"phone": "+70312383179"}
0005435472723	53B766	1608 938419	ANISA NESTEROVA	{"email": "nesterova_anisa_27081970@postgrespro.ru", "phone": "+70453385372"}
0005435472724	BE39E8	6248 186111	SERGEY TIKHONOV	{"email": "tikhonov_s18111971@postgrespro.ru", "phone": "+70183200078"}
0005435472725	BE39E8	0674 357546	RUSLAN ZHURAVLEV	{"phone": "+70882736187"}
0005435472726	250B5F	5356 718220	ARTEM VOLKOV	{"phone": "+70371056716"}
0005435472727	EAAF53	2925 730321	OLGA DENISOVA	{"email": "olgadenisova_031975@postgrespro.ru", "phone": "+70970538873"}
0005435472728	EAAF53	7634 209872	MARIYA NOVIKOVA	{"phone": "+70572004290"}
0005435472729	A477D5	6413 307580	RAIL MAKSIMOV	{"phone": "+70838782937"}
0005435472730	4413FE	6741 859314	YURIY NAUMOV	{"email": "yuriynaumov_27011984@postgrespro.ru", "phone": "+70473143885"}
0005435472731	4413FE	8613 136319	MARINA MEDVEDEVA	{"email": "medvedeva-m-16061973@postgrespro.ru", "phone": "+70588223057"}
0005435472732	36B4EF	7805 249966	NIKITA MELNIKOV	{"email": "melnikov.nikita19121988@postgrespro.ru", "phone": "+70576828682"}
0005435472733	36B4EF	1570 404668	DILYARA ABRAMOVA	{"email": "abramova.d-061975@postgrespro.ru", "phone": "+70545970113"}
0005435472734	54CCC8	3695 592347	NATALYA POLYAKOVA	{"email": "polyakova_natalya-092000@postgrespro.ru", "phone": "+70055991384"}
0005435472735	B4FD8C	9936 031232	TATYANA IVANOVA	{"phone": "+70467018449"}
0005435472736	B4FD8C	5673 051109	ELENA SMIRNOVA	{"phone": "+70932485223"}
0005435472737	D6223D	7443 759164	ARTEM SOKOLOV	{"phone": "+70397397383"}
0005435472738	D6223D	8010 059367	MARINA ANISIMOVA	{"email": "anisimova_m1975@postgrespro.ru", "phone": "+70067926602"}
0005435472739	EC9598	9977 097704	EVGENIY ROMANOV	{"email": "evgeniy-romanov07061976@postgrespro.ru", "phone": "+70207029281"}
0005435472740	EC9598	6109 283053	TATYANA NIKOLAEVA	{"phone": "+70480613722"}
0005435472741	ACEB5C	6101 466418	NIKOLAY BARANOV	{"email": "baranovnikolay05011969@postgrespro.ru", "phone": "+70556241921"}
0005435472742	38C7F1	3918 898834	EKATERINA PETROVA	{"phone": "+70514094460"}
0005435472743	C5DBF2	1537 486180	OLGA STEPANOVA	{"phone": "+70582560089"}
0005435472744	C5DBF2	1841 559495	SERGEY SIDOROV	{"phone": "+70690351417"}
0005435472745	8CC6EE	6335 667759	VLADIMIR ANDREEV	{"phone": "+70261807848"}
0005435472746	6B6666	2076 379218	IRINA FROLOVA	{"email": "frolova_i16101970@postgrespro.ru", "phone": "+70468320296"}
0005435472747	6B6666	1210 388567	ELIZAVETA PETROVA	{"email": "petrova_elizaveta-1972@postgrespro.ru", "phone": "+70530628963"}
0005435472748	A823F1	4829 083987	ELIZAVETA ANISIMOVA	{"phone": "+70013822653"}
0005435472749	8E5FA3	1281 247442	RIMA KUZNECOVA	{"phone": "+70341780123"}
0005435472750	1F58F7	7134 072153	ALIYA KARPOVA	{"email": "aliya_karpova.1971@postgrespro.ru", "phone": "+70750755548"}
0005435472751	2CDF58	4991 114541	SVETLANA ANTONOVA	{"phone": "+70711188722"}
0005435472752	664A50	0755 120175	MARIYA BORISOVA	{"email": "mariyaborisova-02111977@postgrespro.ru", "phone": "+70017734199"}
0005435472753	664A50	0428 253174	ANNA FEDOROVA	{"email": "anna.fedorova_091964@postgrespro.ru", "phone": "+70177642482"}
0005435472754	664A50	8492 326901	LEV ALEKSANDROV	{"email": "aleksandrov_l1965@postgrespro.ru", "phone": "+70250545128"}
0005435472755	B223D6	2385 542880	YURIY MELNIKOV	{"phone": "+70506352661"}
0005435472756	79A70A	6156 487081	OLEG BONDARENKO	{"email": "o.bondarenko-1967@postgrespro.ru", "phone": "+70940600411"}
0005435472757	79A70A	7122 202354	VALERIY SEMENOV	{"email": "valeriy.semenov-091974@postgrespro.ru", "phone": "+70333670526"}
0005435472758	79A70A	5379 066043	VIKTORIYA OSIPOVA	{"email": "v-osipova-031981@postgrespro.ru", "phone": "+70451564375"}
0005435472759	8E8EAA	8511 980742	KONSTANTIN CHERNOV	{"phone": "+70264711409"}
0005435472760	73EEF4	7415 949353	ALENA SOROKINA	{"phone": "+70625044171"}
0005435472761	73EEF4	2233 899824	VLADIMIR MELNIKOV	{"phone": "+70513916213"}
0005435472762	98EA5D	9573 622468	SNEZHANA DAVYDOVA	{"phone": "+70772946940"}
0005435472763	98EA5D	9587 776706	AIDA FILIPPOVA	{"email": "afilippova-28121976@postgrespro.ru", "phone": "+70036278778"}
0005435472764	98EA5D	3158 609092	IRINA IVANOVA	{"phone": "+70321877146"}
0005435472765	433378	3079 226833	VLADIMIR KUDRYASHOV	{"phone": "+70783902942"}
0005435472766	BAEA33	0348 579118	SVETLANA NIKIFOROVA	{"email": "s-nikiforova1974@postgrespro.ru", "phone": "+70603976926"}
0005435472767	BAEA33	3824 254284	OKSANA SOKOLOVA	{"email": "sokolova_o.1978@postgrespro.ru", "phone": "+70862478545"}
0005435472768	85A4BB	7330 879368	NADEZHDA KUZNECOVA	{"email": "kuznecova-n_041965@postgrespro.ru", "phone": "+70853855093"}
0005435472769	85A4BB	2795 513466	VLADIMIR TIMOFEEV	{"phone": "+70136609312"}
0005435472770	A48CB2	6291 848443	ARTEM SAVELEV	{"phone": "+70905211101"}
0005435472771	BFE08C	5002 957078	OLGA SEMENOVA	{"email": "semenova-o-13011978@postgrespro.ru", "phone": "+70172683740"}
0005435472772	BFE08C	6825 449362	LYUDMILA MAKSIMOVA	{"phone": "+70255622446"}
0005435472773	D93CA4	5110 144197	MARIYA BELYAEVA	{"phone": "+70898402496"}
0005435472774	D93CA4	2604 667187	SERGEY ABRAMOV	{"phone": "+70731162574"}
0005435472775	D93CA4	2433 070108	DMITRIY SMIRNOV	{"phone": "+70388892878"}
0005435472776	A51A58	6963 021257	ALEFTINA PAVLOVA	{"phone": "+70519198153"}
0005435472777	A51A58	2754 910631	VERA GRISHINA	{"email": "grishina.vera-28081980@postgrespro.ru", "phone": "+70650308933"}
0005435472778	79806D	0289 716713	ALEKSEY NIKOLAEV	{"phone": "+70294447855"}
0005435472779	9524EB	5883 831029	MARIYA RODIONOVA	{"phone": "+70459433059"}
0005435472780	9524EB	8312 779019	ASIYA GUSEVA	{"phone": "+70963728273"}
0005435472781	A2D0F2	4512 139379	OLGA EFREMOVA	{"phone": "+70111633853"}
0005435472782	2DB4BB	6911 073013	EVGENIY KUZNECOV	{"phone": "+70597882687"}
0005435472783	1D81B2	1989 076516	TAISIYA ORLOVA	{"phone": "+70807572603"}
0005435472784	1D81B2	9926 568559	NINA VOROBEVA	{"email": "nina.vorobeva.1981@postgrespro.ru", "phone": "+70217623028"}
0005435472785	956F84	2202 761548	NIKOLAY ANTONOV	{"email": "antonov.nikolay-1966@postgrespro.ru", "phone": "+70009488225"}
0005435472786	07F5EA	1302 839076	LYUDMILA KISELEVA	{"phone": "+70847563307"}
0005435472787	07F5EA	0991 957612	VLADIMIR MOROZOV	{"email": "v_morozov_011988@postgrespro.ru", "phone": "+70049558776"}
0005435472788	47240A	3246 154378	ALEKSANDR ANTONOV	{"phone": "+70693525492"}
0005435472789	D25F5C	2207 813812	SERGEY VASILEV	{"phone": "+70974761628"}
0005435472790	455569	2789 497036	SERGEY ALEKSEEV	{"phone": "+70773661010"}
0005435472791	B042C2	9437 235225	ALEKSEY EGOROV	{"email": "aleksey.egorov_12041978@postgrespro.ru", "phone": "+70330454053"}
0005435472792	B042C2	2901 512145	EVGENIY CHERNOV	{"email": "chernov.e_051966@postgrespro.ru", "phone": "+70963434880"}
0005435472793	DF3BEA	2895 605162	VIKTOR SCHERBAKOV	{"phone": "+70864419163"}
0005435472794	EB35D1	4844 112957	ELMIRA BARANOVA	{"phone": "+70177182967"}
0005435472795	EB35D1	6398 484632	ALEKSEY POPOV	{"phone": "+70383247735"}
0005435472796	C80EEC	7786 360078	IVAN MATVEEV	{"phone": "+70976983228"}
0005435472797	C80EEC	5983 900667	DMITRIY FROLOV	{"email": "dfrolov_041971@postgrespro.ru", "phone": "+70828839430"}
0005435472798	9E8FAD	4117 743101	OLGA RYABOVA	{"email": "o-ryabova-03061972@postgrespro.ru", "phone": "+70866199468"}
0005435472799	9E8FAD	8642 842157	TATYANA KISELEVA	{"phone": "+70657976744"}
0005435472800	101F19	9797 901688	DANIIL POPOV	{"email": "daniil_popov1972@postgrespro.ru", "phone": "+70737704978"}
0005435472801	101F19	5065 640494	ANNA NIKIFOROVA	{"phone": "+70468539458"}
0005435472802	ADA74E	4917 130144	VLADIMIR VLASOV	{"email": "vladimirvlasov041981@postgrespro.ru", "phone": "+70154830659"}
0005435472803	5359C2	2337 218006	ILYA VASILEV	{"email": "vasilev-i.011972@postgrespro.ru", "phone": "+70049962140"}
0005435472804	5359C2	8790 245374	VLADIMIR DMITRIEV	{"email": "dmitriev.v_24121967@postgrespro.ru", "phone": "+70759105466"}
0005435472805	38F9E1	9850 497620	RAISA IVANOVA	{"email": "r_ivanova-1951@postgrespro.ru", "phone": "+70262464234"}
0005435472806	C13CBA	6675 473096	TAISIYA SMIRNOVA	{"email": "tsmirnova_16071968@postgrespro.ru", "phone": "+70598397008"}
0005435472807	00B4BB	7238 521712	PETR CHERNOV	{"phone": "+70534157161"}
0005435472808	D37A6F	0169 729582	SERGEY YAKOVLEV	{"email": "sergey_yakovlev_04051959@postgrespro.ru", "phone": "+70886240987"}
0005435472809	D37A6F	2713 841519	ELENA MOROZOVA	{"email": "e_morozova_011978@postgrespro.ru", "phone": "+70423658181"}
0005435472810	D37A6F	0359 449115	GRIGORIY KRASNOV	{"email": "krasnov.grigoriy.1973@postgrespro.ru", "phone": "+70151002860"}
0005435472811	70FA6D	9304 403899	ALEKSANDR BARANOV	{"phone": "+70312108280"}
0005435472812	70FA6D	8648 017474	NINA VOLKOVA	{"email": "nina_volkova-10021968@postgrespro.ru", "phone": "+70710084225"}
0005435472813	EC3F0B	3867 928844	ALEKSANDR KARPOV	{"email": "karpova.24041975@postgrespro.ru", "phone": "+70710451765"}
0005435472814	DD57AF	3933 549009	LARISA GORBUNOVA	{"email": "larisa-gorbunova_27031971@postgrespro.ru", "phone": "+70493908762"}
0005435472815	C72B09	4437 880437	VALENTINA SERGEEVA	{"email": "sergeeva_valentina-1970@postgrespro.ru", "phone": "+70947233624"}
0005435472816	1B0690	0220 405292	NINA ANTONOVA	{"phone": "+70655301811"}
0005435472817	1B0690	5790 087511	OLEG VASILEV	{"email": "vasilev_o.27081966@postgrespro.ru", "phone": "+70642895483"}
0005435472818	1B0690	3699 138947	LYUDMILA KUZMINA	{"email": "kuzminal081970@postgrespro.ru", "phone": "+70600666965"}
0005435472819	0447CF	2810 588654	ALIYA GAVRILOVA	{"phone": "+70582129787"}
0005435472820	650F65	8522 340037	MARINA VLASOVA	{"phone": "+70624779057"}
0005435472821	75860F	1727 107253	TAISIYA KAZAKOVA	{"phone": "+70369423702"}
0005435472822	F2C451	1165 888969	NADEZHDA BORISOVA	{"phone": "+70614336331"}
0005435472823	91FDD5	9819 963027	IRINA MIKHAYLOVA	{"phone": "+70875230367"}
0005435472824	B170FF	2197 041699	KSENIYA ISAEVA	{"phone": "+70865456788"}
0005435472825	C78EE5	1197 900802	SVETLANA ROMANOVA	{"phone": "+70782975191"}
0005435472826	CCA769	4802 823248	MARIYA KUZNECOVA	{"email": "mariya_kuznecova111970@postgrespro.ru", "phone": "+70844636243"}
0005435472827	CCA769	5399 969109	OLESYA MEDVEDEVA	{"email": "medvedeva_olesya28021970@postgrespro.ru", "phone": "+70897718648"}
0005435472828	CCA769	5856 377956	KONSTANTIN BONDARENKO	{"email": "konstantin_bondarenko06011964@postgrespro.ru", "phone": "+70899807090"}
0005435472829	0D335F	1099 860492	ILYA SHEVCHENKO	{"email": "shevchenko-i_111977@postgrespro.ru", "phone": "+70407352541"}
0005435472830	87BDCE	5618 033826	IRINA SIDOROVA	{"email": "i_sidorova.12051975@postgrespro.ru", "phone": "+70734781930"}
0005435472831	EA53C3	6071 510574	ILYA NIKOLAEV	{"email": "i_nikolaev.02111967@postgrespro.ru", "phone": "+70543096050"}
0005435472832	9E704D	6212 735217	VIKTOR SHEVCHENKO	{"email": "viktor_shevchenko_08021961@postgrespro.ru", "phone": "+70172377049"}
0005435472833	5FDB91	7956 330263	IVAN CHERNOV	{"email": "chernov-i1971@postgrespro.ru", "phone": "+70729591930"}
0005435472834	0AF4EC	5490 559961	ANDREY KRASNOV	{"email": "a.krasnov.031971@postgrespro.ru", "phone": "+70937445782"}
0005435472835	8673F5	7630 774404	MADINA SEMENOVA	{"email": "semenova-m.021981@postgrespro.ru", "phone": "+70977382508"}
0005435472836	D23B76	2410 263465	ANNA NIKITINA	{"email": "nikitina_anna.13121973@postgrespro.ru", "phone": "+70780694702"}
0005435472837	D23B76	8816 414657	SERGEY POPOV	{"email": "popov_s_071964@postgrespro.ru", "phone": "+70675284681"}
0005435472838	BC4B6C	4052 330705	VIKTOR IVANOV	{"phone": "+70621935886"}
0005435472839	BC4B6C	0408 691632	ANTONINA TARASOVA	{"phone": "+70808926917"}
0005435472840	6EBF72	8729 695866	TAMARA KUZNECOVA	{"phone": "+70141220907"}
0005435472841	6EBF72	0108 785024	ANNA NIKOLAEVA	{"phone": "+70371460763"}
0005435472842	520301	2224 082382	MIKHAIL ILIN	{"phone": "+70042573280"}
0005435472843	520301	6782 879430	IRINA SIDOROVA	{"phone": "+70008034104"}
0005435472844	DAC25E	1131 638863	ALEKSEY IVANOV	{"email": "aleksey-ivanov-03021978@postgrespro.ru", "phone": "+70620992920"}
0005435472845	DAC25E	5147 621485	EVGENIY VOROBEV	{"email": "e_vorobev.101972@postgrespro.ru", "phone": "+70570752011"}
0005435472846	B7D1EC	8868 032746	SERGEY KOZLOV	{"email": "s_kozlov-1969@postgrespro.ru", "phone": "+70914705093"}
0005435472847	EF7287	7077 660169	LEV FROLOV	{"email": "l-frolov-18081961@postgrespro.ru", "phone": "+70146154770"}
0005435472848	710DD5	3136 222780	IGOR VASILEV	{"email": "vasilevigor_09111960@postgrespro.ru", "phone": "+70332445840"}
0005435472849	EC8294	5166 185808	EVGENIY POPOV	{"email": "popov_e_1966@postgrespro.ru", "phone": "+70476896458"}
0005435472850	C81407	5605 749172	VALENTIN KULIKOV	{"phone": "+70434451533"}
0005435472851	CA22ED	4942 265724	VLADIMIR FROLOV	{"email": "frolovv071976@postgrespro.ru", "phone": "+70423796346"}
0005435472852	CA22ED	2752 736005	GLEB GORBUNOV	{"phone": "+70146051245"}
0005435472853	E84509	0928 489413	ALENA POPOVA	{"email": "popova.alena.1978@postgrespro.ru", "phone": "+70829896739"}
0005435472854	B5D7AC	1899 400826	NIKOLAY ZAYCEV	{"email": "n-zaycev1986@postgrespro.ru", "phone": "+70846077401"}
0005435472855	00EB66	4821 465579	ALINA MIRONOVA	{"phone": "+70379584214"}
0005435472856	F2A951	0173 451992	LIDIYA TIKHONOVA	{"phone": "+70533479152"}
0005435472857	F2A951	2460 508976	ALEKSEY MOROZOV	{"email": "alekseymorozov.101975@postgrespro.ru", "phone": "+70252058415"}
0005435472858	6C36A8	1452 427551	YULIYA SEMENOVA	{"email": "semenova_y-051969@postgrespro.ru", "phone": "+70419078888"}
0005435472859	249A49	9790 158024	DMITRIY SOROKIN	{"email": "dmitriy.sorokin-071965@postgrespro.ru", "phone": "+70861348027"}
0005435472860	249A49	4606 640356	PAVEL NOVIKOV	{"email": "novikov-p.081970@postgrespro.ru", "phone": "+70496969039"}
0005435472861	278C8C	6677 164376	ALEKSANDR VOLKOV	{"email": "a_volkov-06011974@postgrespro.ru", "phone": "+70695737597"}
0005435472862	278C8C	4961 647685	ELENA KUZMINA	{"email": "e_kuzmina_1971@postgrespro.ru", "phone": "+70557453867"}
0005435472863	53D8C2	9714 812745	IVAN PAVLOV	{"email": "pavlov.ivan_111973@postgrespro.ru", "phone": "+70070952775"}
0005435472864	21B131	7813 085354	LYUBOV KUDRYASHOVA	{"phone": "+70858551214"}
0005435472865	54E6F1	7836 411389	LYUBOV NIKITINA	{"email": "nikitina-l_121971@postgrespro.ru", "phone": "+70900732439"}
0005435472866	54E6F1	7092 329392	KRISTINA KOVALEVA	{"phone": "+70217801427"}
0005435472867	296176	4286 245828	DMITRIY GUSEV	{"phone": "+70868478298"}
0005435472868	3E357B	0537 384795	ELENA MELNIKOVA	{"email": "melnikova.elena.1969@postgrespro.ru", "phone": "+70784792263"}
0005435472869	3E357B	1176 013960	SERGEY KUZNECOV	{"email": "skuznecov1961@postgrespro.ru", "phone": "+70017027097"}
0005435472870	97C72F	8120 354868	ELENA PAVLOVA	{"email": "pavlova-e.1973@postgrespro.ru", "phone": "+70332472020"}
0005435472871	069202	7021 569710	TAMARA EGOROVA	{"email": "egorova_tamara.061971@postgrespro.ru", "phone": "+70396694563"}
0005435472872	6F597A	0707 765658	ANNA EGOROVA	{"email": "a-egorova.10051965@postgrespro.ru", "phone": "+70958542529"}
0005435472873	6F597A	0414 813409	POLINA KISELEVA	{"email": "p_kiseleva_1965@postgrespro.ru", "phone": "+70115423569"}
0005435472874	B46C59	5473 560448	SERGEY KUZMIN	{"phone": "+70487641945"}
0005435472875	A3E4FF	2895 963840	NINA LAZAREVA	{"phone": "+70675505754"}
0005435472876	A3E4FF	5251 423767	SVETLANA MAKAROVA	{"phone": "+70352339108"}
0005435472877	A3E4FF	7064 592229	ELENA KUZNECOVA	{"phone": "+70044140198"}
0005435472878	120427	0876 068250	IVAN ZHURAVLEV	{"phone": "+70377221593"}
0005435472879	0933F6	0849 499697	KARINA SERGEEVA	{"email": "sergeevakarina.19061975@postgrespro.ru", "phone": "+70325764281"}
0005435472880	9A5414	5458 656956	POLINA ANISIMOVA	{"phone": "+70833843554"}
0005435472881	9A5414	4040 009595	VLADIMIR ORLOV	{"phone": "+70929201667"}
0005435472882	A8F8B9	5255 577927	VALERIY MIRONOV	{"phone": "+70681414270"}
0005435472883	CA9ABA	5609 663152	EKATERINA PETROVA	{"phone": "+70840382201"}
0005435472884	CA9ABA	1347 356949	SVETLANA FILATOVA	{"email": "filatova-svetlana_1963@postgrespro.ru", "phone": "+70380875040"}
0005435472885	6FE572	6209 204937	RAISA SIDOROVA	{"phone": "+70745859833"}
0005435472886	9D24E3	9165 289806	TAISIYA KUZMINA	{"email": "kuzmina.taisiya_121970@postgrespro.ru", "phone": "+70826738667"}
0005435472887	9D24E3	9128 653155	ALEKSANDR KUZNECOV	{"email": "kuznecov_aleksandr-041982@postgrespro.ru", "phone": "+70225700578"}
0005435472888	9EBFA8	3727 283129	EVGENIY MOROZOV	{"phone": "+70363705576"}
0005435472889	0989BF	1427 305004	ELIZAVETA ANTONOVA	{"email": "e.antonova.1973@postgrespro.ru", "phone": "+70367724042"}
0005435472890	0989BF	1604 832404	MAKSIM NOVIKOV	{"phone": "+70187888951"}
0005435472891	D1C517	8069 701565	VITALIY CHERNOV	{"phone": "+70369621305"}
0005435472892	030968	9039 825125	MIKHAIL DAVYDOV	{"email": "davydov.m_04021972@postgrespro.ru", "phone": "+70585302761"}
0005435472893	647A61	7808 358897	ALEKSEY SMIRNOV	{"phone": "+70870220152"}
0005435472894	647A61	9251 533456	ELENA OSIPOVA	{"phone": "+70157893693"}
0005435472895	BEEE82	1891 222596	TATYANA NAZAROVA	{"phone": "+70029593732"}
0005435472896	0E9CBA	5426 507402	SVETLANA YAKOVLEVA	{"phone": "+70725891525"}
0005435472897	68A095	7124 291326	MARIYA NESTEROVA	{"email": "mnesterova_081971@postgrespro.ru", "phone": "+70915132200"}
0005435472898	0A2678	2985 198827	ALEKSANDR ROMANOV	{"email": "aleksandrromanov061966@postgrespro.ru", "phone": "+70604653253"}
0005435472899	225FA4	5772 433245	ANATOLIY FOMIN	{"phone": "+70531444596"}
0005435472900	A4E7D5	3100 649408	LYUDMILA SCHERBAKOVA	{"phone": "+70385008916"}
0005435472901	B6F3DC	1909 446100	DMITRIY MAKAROV	{"phone": "+70440008856"}
0005435472902	B6F3DC	0884 524153	IRINA SERGEEVA	{"phone": "+70432284898"}
0005435473022	F5B34F	2694 819486	YURIY FEDOROV	{"phone": "+70248157249"}
0005435472903	FC4464	1420 389344	VALERIY STEPANOV	{"email": "stepanov-valeriy22091961@postgrespro.ru", "phone": "+70077617597"}
0005435472904	FC4464	2099 667298	TATYANA BELYAEVA	{"email": "belyaeva.t_071967@postgrespro.ru", "phone": "+70374287657"}
0005435472905	5837EA	9803 631087	LYUBOV SOROKINA	{"phone": "+70214882354"}
0005435472906	ABA084	2226 699473	ELENA ZAKHAROVA	{"email": "zakharova.e.1969@postgrespro.ru", "phone": "+70270229115"}
0005435472907	ABA084	6699 876974	KIRILL ILIN	{"email": "ilin_kirill031974@postgrespro.ru", "phone": "+70285948903"}
0005435472908	015645	4905 148084	VERA DMITRIEVA	{"phone": "+70925671871"}
0005435472909	1CE866	6488 908238	OLGA KALININA	{"email": "kalininaolga1963@postgrespro.ru", "phone": "+70138731565"}
0005435472910	1CE866	1483 051368	IRINA PAVLOVA	{"email": "i-pavlova03011978@postgrespro.ru", "phone": "+70587319147"}
0005435472911	B0EAC1	0706 969776	ELENA KOLESNIKOVA	{"email": "elenakolesnikova1971@postgrespro.ru", "phone": "+70955225912"}
0005435472912	B0EAC1	6487 859820	ALEKSANDR POPOV	{"email": "popov_aleksandr-1978@postgrespro.ru", "phone": "+70715704564"}
0005435472913	79F89E	3512 818830	VIKTOR ZAKHAROV	{"phone": "+70744756129"}
0005435472914	938D9B	6839 873712	TATYANA KAZAKOVA	{"email": "kazakova-tatyana.021977@postgrespro.ru", "phone": "+70019223806"}
0005435472915	5A7503	6219 163725	ALEKSANDRA STEPANOVA	{"email": "stepanova_a.23031962@postgrespro.ru", "phone": "+70576940554"}
0005435472916	22AC42	5546 917936	PETR FROLOV	{"email": "pfrolov.021968@postgrespro.ru", "phone": "+70231648109"}
0005435472917	98CAAD	0037 612661	SOFYA MATVEEVA	{"phone": "+70996669854"}
0005435472918	7DC04A	5132 287812	ALEKSANDR MAKAROV	{"email": "a-makarov-111969@postgrespro.ru", "phone": "+70470297086"}
0005435472919	25E07C	1519 050357	ALIK ZHUKOV	{"phone": "+70720762234"}
0005435472920	D06A7D	7169 405667	YURIY STEPANOV	{"email": "yuriy.stepanov121982@postgrespro.ru", "phone": "+70666789044"}
0005435472921	073D88	1051 086759	KIRILL KUZNECOV	{"email": "kuznecovkirill081972@postgrespro.ru", "phone": "+70125169873"}
0005435472922	0D48FD	9701 275573	DMITRIY GORBUNOV	{"email": "gorbunovdmitriy_121984@postgrespro.ru", "phone": "+70552613404"}
0005435472923	0D48FD	5937 240084	ANASTASIYA EFIMOVA	{"email": "aefimova-081973@postgrespro.ru", "phone": "+70135300072"}
0005435472924	316850	3446 904192	ILYA BARANOV	{"email": "i-baranov_121970@postgrespro.ru", "phone": "+70937572904"}
0005435472925	0D3DF1	4122 819143	DMITRIY ISAEV	{"phone": "+70202218263"}
0005435472926	63B56B	7418 627165	IRINA DENISOVA	{"email": "idenisova_1960@postgrespro.ru", "phone": "+70543242730"}
0005435472927	631DCA	3031 484166	GENNADIY ABRAMOV	{"email": "abramov_g061955@postgrespro.ru", "phone": "+70817737871"}
0005435472928	036999	7582 040018	RAIL DENISOV	{"phone": "+70295666115"}
0005435472929	49537D	0161 759654	ALENA KOZLOVA	{"phone": "+70496900082"}
0005435472930	24AD55	4258 178203	ILYA ALEKSEEV	{"email": "i.alekseev-12041975@postgrespro.ru", "phone": "+70678154992"}
0005435472931	24AD55	5660 881740	LYUDMILA VOROBEVA	{"phone": "+70817278807"}
0005435472932	24AD55	1979 054588	VALERIY VLASOV	{"email": "valeriyvlasov1966@postgrespro.ru", "phone": "+70061658568"}
0005435472933	5EB542	3231 341148	VLADIMIR KUZNECOV	{"phone": "+70061229096"}
0005435472934	24FC36	4088 856739	TAMARA KALININA	{"email": "kalinina_t_24111969@postgrespro.ru", "phone": "+70286360505"}
0005435472935	24FC36	5383 256089	MIKHAIL ANTONOV	{"email": "antonov.m.1975@postgrespro.ru", "phone": "+70935206532"}
0005435472936	A3036F	7087 068417	MIKHAIL KOZLOV	{"email": "mikhail-kozlov1979@postgrespro.ru", "phone": "+70899997727"}
0005435472937	426A29	9795 927322	SERGEY BELOV	{"phone": "+70387732896"}
0005435472938	803E9D	0074 357270	ALEKSEY BONDARENKO	{"phone": "+70354975341"}
0005435472939	803E9D	7575 354951	ROMAN MAKSIMOV	{"phone": "+70960190502"}
0005435472940	E52B1B	2207 055627	ANDREY DENISOV	{"phone": "+70814333334"}
0005435472941	43E301	2558 148823	IVAN MATVEEV	{"email": "matveev_i.28021972@postgrespro.ru", "phone": "+70046386786"}
0005435472942	517905	5310 279476	SERGEY GAVRILOV	{"phone": "+70456175550"}
0005435472943	517905	5522 504918	TATYANA POLYAKOVA	{"email": "polyakova_t-25101975@postgrespro.ru", "phone": "+70326570047"}
0005435472944	5449EC	5520 766894	ALEKSANDR SMIRNOV	{"phone": "+70516350776"}
0005435472945	611E3A	9594 567029	NINA IVANOVA	{"phone": "+70446216671"}
0005435472946	30D601	0348 908604	MARINA MATVEEVA	{"email": "matveeva.marina.041972@postgrespro.ru", "phone": "+70211789339"}
0005435472947	C96986	3423 378003	ILYA IVANOV	{"email": "ivanov-ilya_091969@postgrespro.ru", "phone": "+70115721114"}
0005435472948	C96986	4153 856653	SEMEN VOROBEV	{"phone": "+70822734581"}
0005435472949	C96986	6962 479222	VLADIMIR SOKOLOV	{"email": "sokolov.vladimir1977@postgrespro.ru", "phone": "+70505836255"}
0005435472950	475784	6433 605197	VERA ZAYCEVA	{"phone": "+70368063219"}
0005435472951	475784	3276 620383	YANA KUZNECOVA	{"phone": "+70928138011"}
0005435472952	3B5B71	4236 940073	ANNA SOKOLOVA	{"email": "anna.sokolova_1965@postgrespro.ru", "phone": "+70867888076"}
0005435472953	3383F9	0325 056713	VYACHESLAV NAUMOV	{"email": "vnaumov_1961@postgrespro.ru", "phone": "+70572135402"}
0005435472954	16B6B0	3332 514496	IVAN NIKOLAEV	{"email": "nikolaev_i_1980@postgrespro.ru", "phone": "+70675303538"}
0005435472955	16B6B0	7935 206107	VALENTINA EGOROVA	{"email": "egorova_v-06121961@postgrespro.ru", "phone": "+70220774395"}
0005435472956	644B81	3157 348694	OLGA KUZNECOVA	{"email": "olga_kuznecova_081973@postgrespro.ru", "phone": "+70694213889"}
0005435472957	3B4C24	9619 664658	MAKSIM FOMIN	{"email": "mfomin-121982@postgrespro.ru", "phone": "+70808840475"}
0005435472958	609246	6444 099325	GALINA BORISOVA	{"phone": "+70877097552"}
0005435472959	4066BB	4356 393290	ALLA GRISHINA	{"email": "grishina.a12121969@postgrespro.ru", "phone": "+70806356285"}
0005435472960	D51C73	8863 759030	ANDREY ABRAMOV	{"email": "andrey.abramov12021983@postgrespro.ru", "phone": "+70057889227"}
0005435472961	9D358F	6848 875106	RITA VLASOVA	{"email": "r_vlasova-041980@postgrespro.ru", "phone": "+70884495069"}
0005435472962	DDFB72	2282 612046	MARIYA DMITRIEVA	{"phone": "+70954878523"}
0005435472963	4332F8	2377 056009	NATALYA KARPOVA	{"email": "n_karpova_17091974@postgrespro.ru", "phone": "+70760447759"}
0005435472964	8E0272	5176 107529	ELENA ZOTOVA	{"phone": "+70942456473"}
0005435472965	D1CA57	6386 266908	IVAN VASILEV	{"email": "i.vasilev-101968@postgrespro.ru", "phone": "+70046928344"}
0005435472966	1BE461	8942 460083	SERGEY IVANOV	{"email": "sivanov-1969@postgrespro.ru", "phone": "+70352560130"}
0005435472967	3A2ACA	4338 665499	IRAIDA MOROZOVA	{"phone": "+70020814919"}
0005435472968	EE9A7F	3912 992615	ANATOLIY IVANOV	{"phone": "+70046585909"}
0005435472969	EE9A7F	7830 304361	VASILIY PAVLOV	{"email": "pavlov_v-10081967@postgrespro.ru", "phone": "+70994049885"}
0005435472970	FE7A28	9689 993339	ALEKSANDR FEDOROV	{"phone": "+70147800966"}
0005435472971	FE7A28	9645 476626	TATYANA NESTEROVA	{"phone": "+70173670252"}
0005435472972	06DDBA	6507 817205	GALINA PAVLOVA	{"email": "pavlovag.1967@postgrespro.ru", "phone": "+70925944114"}
0005435472973	96D4C9	2298 183273	MIKHAIL VASILEV	{"phone": "+70001410035"}
0005435472974	96D4C9	9806 702266	YULIYA EGOROVA	{"email": "yuliya-egorova_1975@postgrespro.ru", "phone": "+70220882462"}
0005435472975	899BB1	8884 451823	SVETLANA ARKHIPOVA	{"phone": "+70828382673"}
0005435472976	905AC3	9974 996452	TATYANA MIKHAYLOVA	{"phone": "+70523833247"}
0005435472977	8A361D	5583 898316	SERGEY KUZNECOV	{"phone": "+70576498257"}
0005435472978	F879C8	3297 276150	EKATERINA VASILEVA	{"email": "ekaterina.vasileva-1969@postgrespro.ru", "phone": "+70993758303"}
0005435472979	54850F	0674 375749	LARISA ALEKSANDROVA	{"email": "laleksandrova121977@postgrespro.ru", "phone": "+70440800167"}
0005435472980	54850F	1422 199018	KONSTANTIN SEMENOV	{"email": "semenov-konstantin-1968@postgrespro.ru", "phone": "+70861386715"}
0005435472981	2CF451	1359 170010	ANDREY SCHERBAKOV	{"email": "andrey_scherbakov-1968@postgrespro.ru", "phone": "+70100104468"}
0005435472982	56A669	6185 932423	DARYA DAVYDOVA	{"phone": "+70791209962"}
0005435472983	71C84D	0504 422191	ALEKSEY SOKOLOV	{"email": "sokolov-aleksey_15121972@postgrespro.ru", "phone": "+70365703535"}
0005435472984	71C84D	2796 510607	YURIY FEDOTOV	{"phone": "+70034988439"}
0005435472985	1DFB88	3103 956860	SVETLANA KOLESNIKOVA	{"phone": "+70410280803"}
0005435472986	A7A262	3034 839263	OLGA MOROZOVA	{"email": "olga.morozova.1963@postgrespro.ru", "phone": "+70999096813"}
0005435472987	6B9BB4	0194 053867	IVAN PETROV	{"email": "ivan-petrov-031973@postgrespro.ru", "phone": "+70838324257"}
0005435472988	FCEEA4	0491 796612	NIKOLAY SHEVCHENKO	{"phone": "+70496541694"}
0005435472989	FA707E	1785 650719	ANNA SEMENOVA	{"phone": "+70106822864"}
0005435472990	FA707E	7628 429753	VIKTOR ABRAMOV	{"phone": "+70000807538"}
0005435472991	9F498B	4674 220465	EVGENIYA STEPANOVA	{"phone": "+70722421735"}
0005435472992	8CC4F5	0414 974648	SVETLANA GUSEVA	{"email": "svetlana-guseva-1975@postgrespro.ru", "phone": "+70868948872"}
0005435472993	8CC4F5	6738 989390	DANILA SOKOLOV	{"email": "sokolovd.021963@postgrespro.ru", "phone": "+70911387863"}
0005435472994	FC3DF3	3406 652515	ANASTASIYA ILINA	{"phone": "+70612609986"}
0005435472995	0C7BDB	3051 078953	LYUBOV SOLOVEVA	{"email": "solovevalyubov.30111975@postgrespro.ru", "phone": "+70576789046"}
0005435472996	21606A	3616 858446	SERGEY FROLOV	{"phone": "+70630308209"}
0005435472997	21606A	2990 084653	KONSTANTIN BONDARENKO	{"email": "bondarenko_k-111980@postgrespro.ru", "phone": "+70924526073"}
0005435472998	6EAF91	9397 422747	PETR BONDARENKO	{"phone": "+70723898229"}
0005435472999	50BC07	3888 352817	ELENA POPOVA	{"phone": "+70667410009"}
0005435473000	10973B	0274 638851	NATALYA KOROLEVA	{"email": "n.koroleva17041967@postgrespro.ru", "phone": "+70153477097"}
0005435473001	10973B	7102 863794	ELENA MIKHAYLOVA	{"phone": "+70634662378"}
0005435473002	B9EB55	1578 371723	SABINA VASILEVA	{"phone": "+70025293690"}
0005435473003	9455E4	0524 712668	EVGENIY KOROLEV	{"email": "e.korolev.091972@postgrespro.ru", "phone": "+70873193149"}
0005435473004	9455E4	0589 434213	NADEZHDA LOGINOVA	{"email": "loginova.n-22031983@postgrespro.ru", "phone": "+70555684857"}
0005435473005	9455E4	2049 809871	NIKOLAY SOKOLOV	{"email": "nikolay_sokolov_061973@postgrespro.ru", "phone": "+70987066092"}
0005435473006	C638A1	4582 071545	EVGENIY PETROV	{"email": "petrov_evgeniy.1972@postgrespro.ru", "phone": "+70010979893"}
0005435473007	B19143	8803 899433	ELENA BOGDANOVA	{"email": "bogdanova.elena.051979@postgrespro.ru", "phone": "+70698911306"}
0005435473008	B19143	1722 015764	STANISLAV KARPOV	{"phone": "+70551081635"}
0005435473009	B19143	6187 629198	SERGEY RODIONOV	{"email": "s-rodionov1969@postgrespro.ru", "phone": "+70420684326"}
0005435473010	AC3091	3472 990688	RAISA SCHERBAKOVA	{"phone": "+70918684682"}
0005435473011	CB4DBE	6961 613387	GALINA VASILEVA	{"phone": "+70514746741"}
0005435473012	CB4DBE	6973 077667	VLADIMIR FEDOTOV	{"phone": "+70856040850"}
0005435473013	B58945	3457 567646	LYUDMILA KOROLEVA	{"phone": "+70148975556"}
0005435473014	6C8857	1370 364461	VALERIY ZAYCEV	{"email": "valeriy_zaycev.111978@postgrespro.ru", "phone": "+70460722637"}
0005435473015	58233F	5850 173319	MAKSIM SHEVCHENKO	{"phone": "+70906487955"}
0005435473016	61B290	1706 415639	MIKHAIL EGOROV	{"email": "egorovmikhail.1974@postgrespro.ru", "phone": "+70894376788"}
0005435473017	61B290	1852 552884	ELENA EGOROVA	{"phone": "+70407378896"}
0005435473018	F40C7B	3639 008912	VENIAMIN ALEKSANDROV	{"email": "aleksandrov-veniamin1973@postgrespro.ru", "phone": "+70121298914"}
0005435473019	8D8694	3071 106414	ROMAN STEPANOV	{"email": "roman.stepanov_12121968@postgrespro.ru", "phone": "+70793427330"}
0005435473020	8D8694	3248 645754	NADEZHDA LAZAREVA	{"email": "n.lazareva-11111972@postgrespro.ru", "phone": "+70285665954"}
0005435473021	F5B34F	0724 608191	IRINA MELNIKOVA	{"phone": "+70618066016"}
0005435473023	F5B34F	7511 502381	NIKITA BARANOV	{"email": "baranov-n_21051967@postgrespro.ru", "phone": "+70489123730"}
0005435473024	7E9B3B	3165 006734	ELENA IVANOVA	{"phone": "+70321705356"}
0005435473025	7E9B3B	3661 838846	VIKTORIYA MALYSHEVA	{"phone": "+70192832272"}
0005435473026	D7FE7D	6887 605842	VIKTORIYA NIKOLAEVA	{"phone": "+70674106645"}
0005435473027	336B02	3913 302363	ALEKSANDRA DANILOVA	{"phone": "+70985943806"}
0005435473028	336B02	7353 288157	EVGENIY NAZAROV	{"email": "enazarov_19021974@postgrespro.ru", "phone": "+70927271212"}
0005435473029	A3D6BC	2523 546044	ANASTASIYA PETROVA	{"email": "petrovaa.031980@postgrespro.ru", "phone": "+70535690751"}
0005435473030	B52CDD	1741 264219	ELENA ILINA	{"email": "e.ilina11021969@postgrespro.ru", "phone": "+70528034566"}
0005435473031	B52CDD	2986 576736	POLINA FROLOVA	{"phone": "+70326793714"}
0005435473032	171FEF	8313 668346	ANDREY POPOV	{"phone": "+70595908307"}
0005435473033	39B5EB	9512 202179	NINA FILIPPOVA	{"email": "n.filippova-15071971@postgrespro.ru", "phone": "+70361926954"}
0005435473034	49C60C	3846 464688	NADEZHDA KOZLOVA	{"phone": "+70873527355"}
0005435473035	10ACC6	6629 782173	ELENA KUZMINA	{"email": "elenakuzmina1973@postgrespro.ru", "phone": "+70571077967"}
0005435473036	10ACC6	8588 539118	KIRILL ANTONOV	{"email": "antonovkirill_14061967@postgrespro.ru", "phone": "+70744516106"}
0005435473037	D34E76	8811 601853	TATYANA VOLKOVA	{"phone": "+70935197627"}
0005435473038	D34E76	5854 680536	ELENA SIDOROVA	{"email": "sidorova.e23011959@postgrespro.ru", "phone": "+70978442762"}
0005435473039	832B48	2173 103445	OLGA ISAEVA	{"phone": "+70330934469"}
0005435473040	00427E	1871 939446	VALENTIN SEMENOV	{"phone": "+70501133692"}
0005435473041	AADC8D	0019 745252	ANNA PETROVA	{"email": "a_petrova_081971@postgrespro.ru", "phone": "+70528562973"}
0005435473042	15C29A	4391 379700	SVETLANA KUZNECOVA	{"email": "svetlana-kuznecova30111981@postgrespro.ru", "phone": "+70264718758"}
0005435473043	8DFE8D	6017 754190	VLADIMIR MAKAROV	{"email": "vladimir.makarov041984@postgrespro.ru", "phone": "+70797645696"}
0005435473044	47604C	9088 078894	VLADIMIR ZAYCEV	{"email": "zaycev_v.08021976@postgrespro.ru", "phone": "+70412214963"}
0005435473045	47604C	1653 070758	SERGEY ANTONOV	{"email": "sergey_antonov-1972@postgrespro.ru", "phone": "+70274652398"}
0005435473046	FAE883	1503 343144	OLEG KUZNECOV	{"email": "oleg-kuznecov-23031976@postgrespro.ru", "phone": "+70437595807"}
0005435473047	3FB8EC	7644 481716	ALEKSANDR MAKSIMOV	{"phone": "+70312530953"}
0005435473048	3FB8EC	7905 409213	YURIY STEPANOV	{"email": "stepanov.y02121965@postgrespro.ru", "phone": "+70508604946"}
0005435473049	0B5E64	4844 989868	EVGENIY MOISEEV	{"email": "emoiseev.30081966@postgrespro.ru", "phone": "+70080013318"}
0005435473050	053B50	3348 391453	NATALYA POPOVA	{"phone": "+70195682184"}
0005435473051	D25640	6769 826063	LYUBOV NAUMOVA	{"phone": "+70771612806"}
0005435473052	50848C	6423 329996	IRINA AKIMOVA	{"phone": "+70548964409"}
0005435473053	50848C	8093 137854	SERGEY VOROBEV	{"phone": "+70800263659"}
0005435473054	7DE3D8	8423 595467	DENIS SMIRNOV	{"phone": "+70910315489"}
0005435473055	D876DA	1963 286896	DENIS MAKAROV	{"phone": "+70839047854"}
0005435473056	1F9C09	1051 688441	ELENA IVANOVA	{"email": "ivanova-elena.1980@postgrespro.ru", "phone": "+70277103974"}
0005435473057	1F9C09	3573 179750	ALEKSANDR TIMOFEEV	{"phone": "+70241189381"}
0005435473058	463D59	4619 939522	ANASTASIYA ORLOVA	{"phone": "+70690798881"}
0005435473059	6F64EC	3560 560289	EVGENIY POPOV	{"email": "popov_e.1971@postgrespro.ru", "phone": "+70499557116"}
0005435473060	1D6A70	1393 390632	ANATOLIY ZHURAVLEV	{"phone": "+70106169504"}
0005435473061	C76B6A	2355 789079	ELENA ERMAKOVA	{"phone": "+70093280581"}
0005435473062	9528D3	9259 105730	SERGEY AFANASEV	{"phone": "+70508790711"}
0005435473063	9528D3	5797 409943	ALEKSANDR SHEVCHENKO	{"phone": "+70329621730"}
0005435473064	17BAB6	8050 253659	NATALYA STEPANOVA	{"phone": "+70966690911"}
0005435473065	17BAB6	7089 157551	ANNA SOKOLOVA	{"phone": "+70244436719"}
0005435473066	D452E3	3531 044573	NINA GUSEVA	{"phone": "+70467952863"}
0005435473067	D452E3	9988 116603	DMITRIY ILIN	{"email": "dilin_25051980@postgrespro.ru", "phone": "+70315749300"}
0005435473068	4CE94D	7155 013819	OKSANA RODIONOVA	{"email": "rodionova_oksana-1969@postgrespro.ru", "phone": "+70697802396"}
0005435473069	4CE94D	0758 375081	ELENA ANTONOVA	{"email": "e_antonova_22111969@postgrespro.ru", "phone": "+70372041135"}
0005435473070	442B73	3908 768427	BOGDAN NIKITIN	{"email": "nikitin-b_1980@postgrespro.ru", "phone": "+70057272990"}
0005435473071	442B73	0377 803218	NATALYA EGOROVA	{"email": "egorova_natalya.111975@postgrespro.ru", "phone": "+70721655501"}
0005435473072	DA8CB4	5161 911952	ALEKSANDR EGOROV	{"email": "aleksandr.egorov071977@postgrespro.ru", "phone": "+70529686950"}
0005435473073	D8E2CF	1749 055893	ELIZAVETA EFREMOVA	{"email": "elizaveta_efremova051978@postgrespro.ru", "phone": "+70019006151"}
0005435473074	D8E2CF	1146 563936	OLGA NAUMOVA	{"email": "olga-naumova.30091968@postgrespro.ru", "phone": "+70043854302"}
0005435473075	9A5592	4844 702647	PAVEL ROMANOV	{"phone": "+70522975504"}
0005435473076	D34507	7658 532278	DMITRIY ALEKSEEV	{"email": "alekseev.dmitriy.11091970@postgrespro.ru", "phone": "+70275535390"}
0005435473077	5B086F	7528 781779	ALEKSANDR TIKHONOV	{"phone": "+70260473265"}
0005435473078	5B086F	4303 745602	SERGEY NAUMOV	{"phone": "+70970093950"}
0005435473079	8B8880	1313 383814	VALENTINA SIDOROVA	{"email": "sidorova-valentina111977@postgrespro.ru", "phone": "+70586436897"}
0005435473080	8C8413	5952 435216	GALINA VLASOVA	{"email": "galina.vlasova-02031980@postgrespro.ru", "phone": "+70819803144"}
0005435473081	8C8413	3792 860123	MARIYA MOROZOVA	{"phone": "+70721631713"}
0005435473082	AC3F0B	8798 952395	MARIYA KONOVALOVA	{"email": "m.konovalova1970@postgrespro.ru", "phone": "+70464888523"}
0005435473203	E46653	6597 445046	VALENTINA AKIMOVA	{"phone": "+70933494490"}
0005435473083	C3D46B	4097 947632	ALEKSEY OSIPOV	{"email": "osipov_a-04101974@postgrespro.ru", "phone": "+70771450306"}
0005435473084	847E22	6610 927805	YURIY ISAEV	{"phone": "+70049375645"}
0005435473085	847E22	2226 463251	ALEKSANDR VASILEV	{"phone": "+70858205409"}
0005435473086	73D7AC	8574 309152	RAVIL MATVEEV	{"email": "ravil.matveev-1982@postgrespro.ru", "phone": "+70411835987"}
0005435473087	A17458	1351 697055	VALERIYA LOGINOVA	{"phone": "+70049089296"}
0005435473088	CA4B54	8789 426350	KSENIYA ZAKHAROVA	{"phone": "+70248720175"}
0005435473089	77636E	7437 562737	VLADIMIR SMIRNOV	{"email": "smirnov.vladimir.121971@postgrespro.ru", "phone": "+70340530440"}
0005435473090	77636E	0362 955662	ELLA KOLESNIKOVA	{"phone": "+70072637179"}
0005435473091	77636E	8420 395265	ALEKSANDR EGOROV	{"phone": "+70652725086"}
0005435473092	77636E	1865 769645	ALEKSANDR MEDVEDEV	{"email": "medvedevaleksandr06121974@postgrespro.ru", "phone": "+70315042689"}
0005435473093	5D0BEB	4970 721835	GALIYA DAVYDOVA	{"phone": "+70743612212"}
0005435473094	2707A5	0215 946850	VADIM SEMENOV	{"phone": "+70394775874"}
0005435473095	2707A5	8046 639811	MAKSIM TIMOFEEV	{"email": "m_timofeev.031970@postgrespro.ru", "phone": "+70805705928"}
0005435473096	2707A5	5000 881142	ANNA FILATOVA	{"phone": "+70328020272"}
0005435473097	3162AB	4820 811985	VERA DANILOVA	{"email": "danilova-vera-071980@postgrespro.ru", "phone": "+70854638212"}
0005435473098	3162AB	9757 602613	ALEKSANDR SERGEEV	{"email": "sergeeva.1971@postgrespro.ru", "phone": "+70569707454"}
0005435473099	25816A	6251 786383	GALINA GRISHINA	{"phone": "+70304842535"}
0005435473100	25816A	5267 066916	SERGEY FEDOROV	{"email": "sfedorov1971@postgrespro.ru", "phone": "+70172552770"}
0005435473101	A778DA	2829 435900	RAMIL EGOROV	{"email": "egorov_ramil.081964@postgrespro.ru", "phone": "+70813527435"}
0005435473102	0430DF	3667 368800	ANDREY ANDREEV	{"phone": "+70196733850"}
0005435473103	D28534	1588 350749	VLADIMIR IVANOV	{"phone": "+70707339254"}
0005435473104	A4CCB8	3128 211095	VASILIY PAVLOV	{"email": "pavlov.vasiliy091964@postgrespro.ru", "phone": "+70487105253"}
0005435473105	33F51F	3794 180657	VLADIMIR SMIRNOV	{"email": "v.smirnov.14051973@postgrespro.ru", "phone": "+70447748459"}
0005435473106	3F7196	1826 842255	TATYANA IVANOVA	{"phone": "+70082645401"}
0005435473107	4D52BB	9409 705437	VLADIMIR FOMIN	{"phone": "+70025186150"}
0005435473108	FC93A3	2958 906613	TATYANA ABRAMOVA	{"phone": "+70017287945"}
0005435473109	0DA4F2	2546 264009	VALENTINA IVANOVA	{"email": "valentina-ivanova.31101984@postgrespro.ru", "phone": "+70088492161"}
0005435473110	0DA4F2	3298 312582	ALEKSANDR MATVEEV	{"phone": "+70236143774"}
0005435473111	0DA4F2	2729 072001	TATYANA ZHURAVLEVA	{"phone": "+70963524530"}
0005435473112	020CC6	0590 528187	VIKTOR ANTONOV	{"phone": "+70650142153"}
0005435473113	36B72E	1921 440569	ANATOLIY ROMANOV	{"phone": "+70116196666"}
0005435473114	36B72E	1811 532921	EKATERINA ZOTOVA	{"email": "zotova-ekaterina-24111970@postgrespro.ru", "phone": "+70417677018"}
0005435473115	7F3AC1	5082 216105	SERGEY KARPOV	{"email": "skarpov.10121978@postgrespro.ru", "phone": "+70280410293"}
0005435473116	7EA2D5	1210 318100	PAVEL FEDOROV	{"email": "pfedorov-1966@postgrespro.ru", "phone": "+70766178077"}
0005435473117	7EA2D5	1310 437378	EGOR BARANOV	{"phone": "+70924039810"}
0005435473118	1DDFF3	8091 806021	TATYANA FROLOVA	{"phone": "+70060723798"}
0005435473119	42A6E5	7745 523600	EVGENIY PETROV	{"email": "e.petrov.1978@postgrespro.ru", "phone": "+70348318002"}
0005435473120	F53442	9560 220090	VASILIY POPOV	{"phone": "+70122412771"}
0005435473121	F53442	6689 613098	EKATERINA AKIMOVA	{"email": "ekaterina-akimova.1963@postgrespro.ru", "phone": "+70639163238"}
0005435473122	D0CF99	0269 062663	POLINA SIDOROVA	{"phone": "+70552763288"}
0005435473123	D0CF99	6939 277037	ALEKSANDR OSIPOV	{"phone": "+70995682877"}
0005435473124	5AF746	8370 372422	EKATERINA MOROZOVA	{"email": "morozovaekaterina.10061971@postgrespro.ru", "phone": "+70359657655"}
0005435473125	5AF746	5719 349361	VITALIY ROMANOV	{"phone": "+70786396860"}
0005435473126	C1380D	8147 596251	VALENTINA KONOVALOVA	{"email": "valentina-konovalova.30071981@postgrespro.ru", "phone": "+70572953610"}
0005435473127	C1380D	4228 101467	NATALIYA NOVIKOVA	{"phone": "+70212031556"}
0005435473128	B7B6DB	1079 483720	GALINA BELOVA	{"phone": "+70180130019"}
0005435473129	6AD81A	1842 136833	IRINA KOMAROVA	{"email": "komarova.i_111963@postgrespro.ru", "phone": "+70769812600"}
0005435473130	FC9263	4658 183517	NADEZHDA MASLOVA	{"phone": "+70766621505"}
0005435473131	33595E	4650 132707	KONSTANTIN PAVLOV	{"phone": "+70125187166"}
0005435473132	882DD7	2013 371379	IRINA SERGEEVA	{"email": "sergeeva-irina1975@postgrespro.ru", "phone": "+70181280485"}
0005435473133	882DD7	8043 730299	YAROSLAV MOROZOV	{"email": "morozovyaroslav-1974@postgrespro.ru", "phone": "+70873786873"}
0005435473134	882DD7	3340 159621	VALENTINA MOISEEVA	{"phone": "+70959327690"}
0005435473135	C7000E	9509 982407	ROMAN PETROV	{"email": "petrov-r.1976@postgrespro.ru", "phone": "+70286847769"}
0005435473136	A0B031	9549 207794	LILIYA MOISEEVA	{"email": "liliya_moiseeva011970@postgrespro.ru", "phone": "+70004249394"}
0005435473137	A0B031	9212 502413	YURIY VOROBEV	{"email": "vorobev_y071983@postgrespro.ru", "phone": "+70557452310"}
0005435473138	D8C231	6011 843601	ANATOLIY TIMOFEEV	{"phone": "+70467274601"}
0005435473139	D8C231	7331 097924	ALEKSEY ABRAMOV	{"phone": "+70863622413"}
0005435473140	E52BB0	2703 927946	VIKTORIYA ANTONOVA	{"email": "antonova-viktoriya-1974@postgrespro.ru", "phone": "+70247204132"}
0005435473141	BE594D	9074 414524	ILNUR SIDOROV	{"phone": "+70601636041"}
0005435473142	BE594D	3930 550477	ELENA KONOVALOVA	{"email": "elena_konovalova1973@postgrespro.ru", "phone": "+70133892642"}
0005435473143	E6C448	2391 476276	TATYANA MELNIKOVA	{"phone": "+70483956051"}
0005435473144	E23496	7743 658673	NIKOLAY SOROKIN	{"email": "n-sorokin_1974@postgrespro.ru", "phone": "+70438452762"}
0005435473145	550180	9422 087683	ZHANNA SOKOLOVA	{"email": "sokolova.z041974@postgrespro.ru", "phone": "+70860065461"}
0005435473146	550180	0159 404339	YULIYA BOGDANOVA	{"email": "bogdanova.y_1970@postgrespro.ru", "phone": "+70638124193"}
0005435473147	AF2C65	7212 067929	VLADIMIR VOLKOV	{"email": "volkov-vladimir-1978@postgrespro.ru", "phone": "+70126183651"}
0005435473148	A0B0D7	0635 004722	MIKHAIL GAVRILOV	{"email": "m_gavrilov.1966@postgrespro.ru", "phone": "+70980871542"}
0005435473149	C3C266	7742 788599	IRINA TIMOFEEVA	{"email": "i_timofeeva_051979@postgrespro.ru", "phone": "+70067919870"}
0005435473150	C3C266	6277 766372	LYUDMILA DENISOVA	{"phone": "+70705534375"}
0005435473151	011F96	5060 382150	ZINAIDA ANISIMOVA	{"email": "anisimova.zinaida_19011973@postgrespro.ru", "phone": "+70023014261"}
0005435473152	5D3071	7580 757226	RUSTAM SMIRNOV	{"phone": "+70307980153"}
0005435473153	5D3071	5274 809325	ALEKSANDR GRIGOREV	{"email": "grigorev.aleksandr-071963@postgrespro.ru", "phone": "+70470456859"}
0005435473154	5D3071	1480 639264	ARTEM GRIGOREV	{"email": "grigorevartem.14061973@postgrespro.ru", "phone": "+70908574726"}
0005435473155	DA0726	2693 060417	ANATOLIY BELOV	{"email": "belov.anatoliy-29061972@postgrespro.ru", "phone": "+70859159319"}
0005435473156	DA0726	5473 053261	SVETLANA PETROVA	{"email": "svetlanapetrova.1985@postgrespro.ru", "phone": "+70148508867"}
0005435473157	F62E5B	6606 544744	ALEKSANDR NIKOLAEV	{"email": "anikolaev-101974@postgrespro.ru", "phone": "+70277903628"}
0005435473158	30FE83	9053 436785	VLADIMIR SCHERBAKOV	{"email": "scherbakov.v_19061975@postgrespro.ru", "phone": "+70889021255"}
0005435473159	B03635	6955 884781	LYUBOV PETROVA	{"phone": "+70226359873"}
0005435473160	6E9C4A	3202 796867	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr.1963@postgrespro.ru", "phone": "+70814387927"}
0005435473161	6E9C4A	6580 654486	NATALYA ROMANOVA	{"email": "romanovanatalya-1984@postgrespro.ru", "phone": "+70173147069"}
0005435473162	6E9C4A	2120 140931	IGOR KOZLOV	{"email": "kozlovi_021976@postgrespro.ru", "phone": "+70821410795"}
0005435473163	303929	6453 004721	VLADIMIR ILIN	{"email": "vilin-101978@postgrespro.ru", "phone": "+70349745380"}
0005435473164	78CAC2	5906 617357	EGOR NAZAROV	{"phone": "+70409435690"}
0005435473165	78CAC2	0942 050839	PETR ZAYCEV	{"email": "petr-zaycev-18041983@postgrespro.ru", "phone": "+70399002317"}
0005435473166	1EB4B5	1469 429146	SERGEY FEDOTOV	{"email": "fedotov-sergey.1963@postgrespro.ru", "phone": "+70790817913"}
0005435473167	8A178D	7688 105002	OLGA VASILEVA	{"phone": "+70012290290"}
0005435473168	E3D7DB	9912 049795	KONSTANTIN NIKITIN	{"phone": "+70074458368"}
0005435473169	B20C30	9447 562303	LYUDMILA SMIRNOVA	{"phone": "+70116914457"}
0005435473170	C87B03	1557 266121	EVGENIY MOISEEV	{"email": "evgeniy.moiseev-18121978@postgrespro.ru", "phone": "+70982979311"}
0005435473171	AA42BA	4525 195747	GALINA VLASOVA	{"phone": "+70919499547"}
0005435473172	5BEC98	9085 866016	ALENA VASILEVA	{"email": "vasileva.alena-011971@postgrespro.ru", "phone": "+70108154495"}
0005435473173	3BC4BB	3640 157792	LIDIYA FADEEVA	{"phone": "+70086727798"}
0005435473174	B4E8E9	5794 911921	MARGARITA ISAEVA	{"phone": "+70723180873"}
0005435473175	A52615	7389 275515	LYUBOV MAKAROVA	{"email": "l.makarova12051970@postgrespro.ru", "phone": "+70633159258"}
0005435473176	B42191	7641 092281	RAISA ILINA	{"email": "rilina_09011976@postgrespro.ru", "phone": "+70519209963"}
0005435473177	5540F9	1185 875801	EKATERINA KRASNOVA	{"phone": "+70643367513"}
0005435473178	5540F9	2153 661725	NATALYA VASILEVA	{"phone": "+70427553537"}
0005435473179	DCCFF3	8071 556532	IVAN ABRAMOV	{"phone": "+70706627203"}
0005435473180	371D3E	1130 899779	ELENA VOLKOVA	{"phone": "+70785606952"}
0005435473181	C724CE	5719 723659	DMITRIY PAVLOV	{"email": "dmitriypavlov.28121983@postgrespro.ru", "phone": "+70500514491"}
0005435473182	C724CE	9472 008742	TATYANA SERGEEVA	{"email": "t_sergeeva_1975@postgrespro.ru", "phone": "+70666655666"}
0005435473183	C724CE	8862 099012	NIKITA ZAKHAROV	{"email": "zakharov.nikita_12091963@postgrespro.ru", "phone": "+70527188779"}
0005435473184	E0194E	2687 702486	OLESYA SOKOLOVA	{"phone": "+70757733515"}
0005435473185	5DE6FA	4681 972151	ALEKSANDR KONOVALOV	{"email": "aleksandr_konovalov_06061978@postgrespro.ru", "phone": "+70265737495"}
0005435473186	C1E522	2176 650763	NATALYA KOZLOVA	{"email": "nkozlova1986@postgrespro.ru", "phone": "+70076403221"}
0005435473187	627F2B	2291 200219	EKATERINA MAKSIMOVA	{"phone": "+70984415825"}
0005435473188	627F2B	8524 446526	IVAN SEMENOV	{"email": "ivan-semenov1980@postgrespro.ru", "phone": "+70149427192"}
0005435473189	6EE102	1450 211219	MAKSIM MOROZOV	{"email": "m.morozov_15101975@postgrespro.ru", "phone": "+70983391193"}
0005435473190	CAF48A	1082 185255	MARIYA ZAYCEVA	{"phone": "+70812283998"}
0005435473191	CAF48A	6146 263786	YULIYA TIKHONOVA	{"phone": "+70723460434"}
0005435473192	60963F	1731 550261	NINA FILIPPOVA	{"phone": "+70588230459"}
0005435473193	8397C9	0949 637397	ANATOLIY MAKAROV	{"email": "a-makarov011969@postgrespro.ru", "phone": "+70522055864"}
0005435473194	4E055C	8489 385900	DMITRIY NIKITIN	{"email": "nikitin_dmitriy.1965@postgrespro.ru", "phone": "+70349225747"}
0005435473195	C4C84F	3888 761547	ALEKSANDR FOMIN	{"email": "aleksandr_fomin-1968@postgrespro.ru", "phone": "+70664935832"}
0005435473196	B5D5F8	8795 354873	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.30101977@postgrespro.ru", "phone": "+70503313573"}
0005435473197	783875	9502 502943	EDGAR BELOV	{"phone": "+70116689951"}
0005435473198	D754CC	9977 843728	ALINA MIKHAYLOVA	{"phone": "+70944810478"}
0005435473199	09D793	3654 202095	SERGEY MOROZOV	{"email": "morozov-sergey_1990@postgrespro.ru", "phone": "+70510994817"}
0005435473200	6ED098	3358 883709	NINA RYABOVA	{"email": "nryabova.04051974@postgrespro.ru", "phone": "+70505537657"}
0005435473201	6ED098	1570 440744	ALEKSEY KUZNECOV	{"email": "a.kuznecov_1985@postgrespro.ru", "phone": "+70860879432"}
0005435473202	8D0E75	4348 742573	DMITRIY NOVIKOV	{"email": "novikov_d_27111976@postgrespro.ru", "phone": "+70059690438"}
0005435473204	9851C3	0297 561200	NIKOLAY IVANOV	{"email": "n-ivanov05051976@postgrespro.ru", "phone": "+70592241202"}
0005435473205	9851C3	1597 431749	NATALYA DANILOVA	{"phone": "+70934596604"}
0005435473206	3A9AF3	2891 903243	ALEKSANDR PAVLOV	{"phone": "+70945461402"}
0005435473207	1D101F	5680 020570	VERA MASLOVA	{"phone": "+70100660075"}
0005435473208	A6870B	6182 047698	VALERIYA KOROLEVA	{"email": "valeriya.koroleva_15011978@postgrespro.ru", "phone": "+70673334874"}
0005435473209	6F8C07	8467 776050	OKSANA MOROZOVA	{"email": "oksana-morozova_041972@postgrespro.ru", "phone": "+70712981065"}
0005435473210	07D5E6	1567 741910	YAROSLAV ZHUKOV	{"phone": "+70846865875"}
0005435473211	07D5E6	2986 870494	MARIYA SOROKINA	{"email": "m.sorokina051972@postgrespro.ru", "phone": "+70573506198"}
0005435473212	55B752	5435 570867	VITALIY MOROZOV	{"email": "v.morozov_071971@postgrespro.ru", "phone": "+70883384171"}
0005435473213	650D31	6440 252371	VASILIY KOZLOV	{"phone": "+70055748130"}
0005435473214	4A3E5A	3060 173846	TATYANA POLYAKOVA	{"email": "tpolyakova-051968@postgrespro.ru", "phone": "+70357894004"}
0005435473215	F1A185	3310 680464	VIKTOR SCHERBAKOV	{"phone": "+70902251903"}
0005435473216	C29950	6970 965157	EVGENIY MOROZOV	{"phone": "+70848053907"}
0005435473217	C29950	8275 024239	EKATERINA ISAEVA	{"email": "ekaterinaisaeva.1980@postgrespro.ru", "phone": "+70398623417"}
0005435473218	098CA8	2807 005500	NINA KUZNECOVA	{"email": "n.kuznecova.27031976@postgrespro.ru", "phone": "+70473740660"}
0005435473219	098CA8	6547 251507	VALERIY FROLOV	{"phone": "+70531966955"}
0005435473220	098CA8	7346 313077	EKATERINA ALEKSANDROVA	{"phone": "+70934605389"}
0005435473221	D82922	8756 579304	ANDREY IVANOV	{"phone": "+70414155276"}
0005435473222	2E02BA	0421 932589	VLADIMIR EGOROV	{"phone": "+70073962346"}
0005435473223	49F0AE	1260 563136	SERGEY BORISOV	{"email": "sergey.borisov-21031963@postgrespro.ru", "phone": "+70827856228"}
0005435473224	0095A3	0467 628099	SERGEY KRASNOV	{"email": "krasnov.s31101981@postgrespro.ru", "phone": "+70836972290"}
0005435473225	954130	8991 776927	EVGENIY FILIPPOV	{"phone": "+70676553874"}
0005435473226	1ACC55	6313 705260	ZOYA MAKSIMOVA	{"email": "z-maksimova1972@postgrespro.ru", "phone": "+70124150532"}
0005435473227	AFE4DB	7992 210809	ELENA ZHUKOVA	{"phone": "+70877796650"}
0005435473228	AFE4DB	4133 789995	TATYANA MATVEEVA	{"phone": "+70350944304"}
0005435473229	A9DF38	3415 634856	MARAT KAZAKOV	{"email": "marat-kazakov-1976@postgrespro.ru", "phone": "+70469979452"}
0005435473230	A9DF38	3309 835361	KSENIYA DANILOVA	{"phone": "+70606312390"}
0005435473231	A9DF38	3997 840177	STEPAN IVANOV	{"phone": "+70918850716"}
0005435473232	177E8F	0027 777930	NIKOLAY MAKAROV	{"phone": "+70417564243"}
0005435473233	177E8F	2081 544872	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev24101965@postgrespro.ru", "phone": "+70355501990"}
0005435473234	08019D	4483 586250	NIKOLAY SMIRNOV	{"email": "nsmirnov-24061981@postgrespro.ru", "phone": "+70456503854"}
0005435473235	08019D	3147 813820	IRINA KOZLOVA	{"email": "kozlova.i.1970@postgrespro.ru", "phone": "+70649349628"}
0005435473236	EAFDC1	9966 516990	ELENA SAVELEVA	{"email": "esaveleva_19041973@postgrespro.ru", "phone": "+70063798720"}
0005435473237	EAFDC1	6244 128771	SOFYA ROMANOVA	{"phone": "+70817312365"}
0005435473238	EAFDC1	9837 911965	ELENA VLASOVA	{"email": "vlasova-elena-031969@postgrespro.ru", "phone": "+70511249463"}
0005435473239	EAFDC1	5632 182192	ALEKSANDRA DENISOVA	{"phone": "+70159621943"}
0005435473240	27042D	7602 125033	YURIY KOZLOV	{"phone": "+70216049353"}
0005435473241	692864	9866 749009	ANASTASIYA SOKOLOVA	{"phone": "+70484036094"}
0005435473242	692864	4497 873989	VLADIMIR ILIN	{"email": "ilin-vladimir24101975@postgrespro.ru", "phone": "+70546406733"}
0005435473243	9E01BA	5467 388722	RAFAIL SCHERBAKOV	{"phone": "+70986200879"}
0005435473244	9169E2	6105 406125	RAFIS VASILEV	{"email": "rafisvasilev1966@postgrespro.ru", "phone": "+70087698924"}
0005435473245	9169E2	4667 561022	EVGENIY SOKOLOV	{"phone": "+70994606915"}
0005435473246	C58BCB	2711 457473	ARINA KUZNECOVA	{"email": "a-kuznecova_04111969@postgrespro.ru", "phone": "+70703680600"}
0005435473247	C58BCB	4236 607996	RUSLAN IVANOV	{"phone": "+70141056342"}
0005435473248	EBAA00	5739 418779	TATYANA MOISEEVA	{"phone": "+70147034663"}
0005435473249	58A3C1	2051 704117	IRINA SIDOROVA	{"phone": "+70244457598"}
0005435473250	58A3C1	0971 928833	MARIYA MIRONOVA	{"phone": "+70260053800"}
0005435473251	58A3C1	7080 770061	MIKHAIL GORBUNOV	{"email": "gorbunovm_1971@postgrespro.ru", "phone": "+70600106503"}
0005435473252	0F3A81	0137 297690	MARIYA KRASNOVA	{"email": "mariyakrasnova.121970@postgrespro.ru", "phone": "+70807608169"}
0005435473253	0F3A81	3358 680526	ARINA BELYAEVA	{"email": "belyaeva.a051978@postgrespro.ru", "phone": "+70210325088"}
0005435473254	C2DBE2	9722 564824	ALEKSEY KUZNECOV	{"phone": "+70167439407"}
0005435473255	3996CD	3254 262735	ALEKSEY GAVRILOV	{"email": "aleksey-gavrilov1963@postgrespro.ru", "phone": "+70171700426"}
0005435473256	3996CD	5849 984312	VIKTORIYA MIKHAYLOVA	{"phone": "+70111724864"}
0005435473257	3996CD	9095 122365	VIKTOR VOLKOV	{"phone": "+70334083788"}
0005435473258	F6D1A7	1556 749757	EKATERINA SIDOROVA	{"email": "sidorovae.041961@postgrespro.ru", "phone": "+70688456064"}
0005435473259	C7A4F5	8996 521908	NIKOLAY NIKOLAEV	{"email": "nikolaevn-1981@postgrespro.ru", "phone": "+70881962679"}
0005435473260	770249	0236 984388	LYUDMILA NESTEROVA	{"email": "nesterova-l_051981@postgrespro.ru", "phone": "+70822493149"}
0005435473261	92E9E8	7869 653960	VALERIY KONOVALOV	{"email": "konovalovv_1983@postgrespro.ru", "phone": "+70674903097"}
0005435473262	E78648	7332 558092	EVGENIY IVANOV	{"email": "ivanov-evgeniy-25081986@postgrespro.ru", "phone": "+70321576180"}
0005435473263	C92029	5543 979246	RUSLAN SCHERBAKOV	{"phone": "+70197942358"}
0005435473264	236090	7910 867242	MARIYA POTAPOVA	{"phone": "+70121546015"}
0005435473265	B0E66B	3025 442685	VIKTOR NIKOLAEV	{"email": "nikolaevv15081966@postgrespro.ru", "phone": "+70440640636"}
0005435473266	BABD3C	1577 472899	ANATOLIY MOROZOV	{"email": "morozov-anatoliy.081965@postgrespro.ru", "phone": "+70096885812"}
0005435473267	CEE320	4247 711578	MAKAR MIRONOV	{"phone": "+70404620360"}
0005435473268	721A77	5590 150992	PAVEL ZAKHAROV	{"phone": "+70501182623"}
0005435473269	721A77	3241 932475	ANASTASIYA FROLOVA	{"phone": "+70486876059"}
0005435473270	08CE1D	5619 377975	MIKHAIL RODIONOV	{"email": "rodionov.mikhail_04031988@postgrespro.ru", "phone": "+70958615133"}
0005435473271	08CE1D	0114 993814	TAMARA ANDREEVA	{"phone": "+70795371135"}
0005435473272	2FE471	3036 598027	YULIYA PAVLOVA	{"email": "yuliya_pavlova_111965@postgrespro.ru", "phone": "+70499835335"}
0005435473273	2EE467	4521 150988	LYUBOV SERGEEVA	{"phone": "+70611087616"}
0005435473274	2EE467	1395 764246	ALEKSANDR NIKOLAEV	{"phone": "+70913418843"}
0005435473275	C70109	5760 590231	MARIYA KONOVALOVA	{"email": "konovalova.mariya_111974@postgrespro.ru", "phone": "+70972246236"}
0005435473276	C70109	3053 769765	VLADIMIR DMITRIEV	{"email": "vladimir.dmitriev14021973@postgrespro.ru", "phone": "+70425464636"}
0005435473277	9D8391	9320 831953	ARTEM TIKHONOV	{"phone": "+70878194106"}
0005435473278	9D8391	0961 921682	ANASTASIYA MELNIKOVA	{"phone": "+70420921519"}
0005435473279	237CA4	7291 931552	NATALYA POLYAKOVA	{"email": "polyakova-n1979@postgrespro.ru", "phone": "+70128634960"}
0005435473280	C1FFDC	9047 824317	GALINA TARASOVA	{"email": "tarasova-g.101975@postgrespro.ru", "phone": "+70269956345"}
0005435473281	C1FFDC	4388 736490	EVDOKIYA BELOVA	{"phone": "+70311779787"}
0005435473282	C1FFDC	4207 708900	NATALYA TIMOFEEVA	{"phone": "+70713021652"}
0005435473283	557E67	1532 414210	ZINAIDA DMITRIEVA	{"email": "zdmitrieva-1972@postgrespro.ru", "phone": "+70095745746"}
0005435473284	C39BDD	2998 732479	DMITRIY SOROKIN	{"phone": "+70577224642"}
0005435473285	BC0BB7	5639 735489	NATALYA KULIKOVA	{"email": "kulikovanatalya-13061978@postgrespro.ru", "phone": "+70270126514"}
0005435473286	9C4D34	6690 523149	ANTON TIMOFEEV	{"email": "timofeev-a.1961@postgrespro.ru", "phone": "+70027066819"}
0005435473287	9C4D34	9780 349961	LYUDMILA SOLOVEVA	{"email": "soloveva.l02021969@postgrespro.ru", "phone": "+70241324145"}
0005435473288	955C13	9846 230149	ANDREY KOROLEV	{"email": "koroleva03011981@postgrespro.ru", "phone": "+70219530865"}
0005435473289	955C13	1077 558968	TATYANA SOLOVEVA	{"email": "tatyana.soloveva111976@postgrespro.ru", "phone": "+70378395369"}
0005435473290	89D565	6212 907973	VLADIMIR BORISOV	{"phone": "+70929842521"}
0005435473291	0A44F3	8515 684330	PETR IVANOV	{"phone": "+70581485776"}
0005435473292	0A44F3	9781 873282	EGOR VLASOV	{"email": "evlasov_1972@postgrespro.ru", "phone": "+70762442261"}
0005435473293	E0E915	9677 829855	ALEKSEY BONDARENKO	{"phone": "+70148665963"}
0005435473294	E0E915	5800 451749	DMITRIY NIKITIN	{"email": "dmitriy.nikitin_05031977@postgrespro.ru", "phone": "+70578667585"}
0005435473295	E0E915	7177 304651	VLADIMIR ROMANOV	{"phone": "+70439103390"}
0005435473296	297BCB	7072 008641	MIKHAIL VOROBEV	{"email": "m.vorobev-061975@postgrespro.ru", "phone": "+70199353354"}
0005435473297	2E6929	2905 907884	YANA MEDVEDEVA	{"phone": "+70187384960"}
0005435476634	E51E3B	9146 120784	VASILIY CHERNOV	{"email": "chernovv-111967@postgrespro.ru", "phone": "+70022776511"}
0005435476635	D53E1B	3898 694129	SANIYA POPOVA	{"phone": "+70775265455"}
0005435476636	E314FA	5011 441485	VALENTINA ZAYCEVA	{"phone": "+70320179611"}
0005435476637	839E1C	3971 834192	VALENTINA ROMANOVA	{"phone": "+70071770384"}
0005435476638	6F78EA	5316 834328	EGOR ZAKHAROV	{"phone": "+70085092423"}
0005435476639	6F78EA	0687 691330	MAKSIM MOISEEV	{"phone": "+70196774259"}
0005435476640	B89CD3	2662 803236	KSENIYA KRASNOVA	{"phone": "+70275774981"}
0005435476641	14426E	2713 909175	ANTON DENISOV	{"email": "denisov_a1981@postgrespro.ru", "phone": "+70406978785"}
0005435476642	14426E	1681 846233	ELENA SEMENOVA	{"phone": "+70744039662"}
0005435476643	50578D	2834 836624	OLGA POPOVA	{"phone": "+70931952642"}
0005435476644	50578D	6649 934193	TATYANA TIMOFEEVA	{"email": "timofeeva_t_20091963@postgrespro.ru", "phone": "+70815736841"}
0005435476645	8B2BB9	4780 789491	ELENA KOROLEVA	{"email": "e_koroleva051960@postgrespro.ru", "phone": "+70624827074"}
0005435476646	8B2BB9	9741 625772	ALEKSANDR DMITRIEV	{"email": "dmitrievaleksandr.081975@postgrespro.ru", "phone": "+70967838251"}
0005435476647	7FC6C0	1679 096997	KLAVDIYA ROMANOVA	{"email": "romanova.klavdiya1990@postgrespro.ru", "phone": "+70617560444"}
0005435476648	7861A9	7168 972852	NIKOLAY KUZNECOV	{"phone": "+70996095155"}
0005435476649	89599C	0443 249403	ELENA SOLOVEVA	{"email": "esoloveva-29091968@postgrespro.ru", "phone": "+70989651243"}
0005435476650	8ADBDC	4438 255082	IRINA OSIPOVA	{"phone": "+70655096743"}
0005435476651	8ADBDC	3800 232235	STANISLAV GRIGOREV	{"phone": "+70005285313"}
0005435476652	19375C	3350 316844	IRINA DMITRIEVA	{"email": "i-dmitrieva.24081964@postgrespro.ru", "phone": "+70463955887"}
0005435476653	19375C	9331 817427	DMITRIY SMIRNOV	{"email": "dmitriy.smirnov-1979@postgrespro.ru", "phone": "+70040046915"}
0005435476654	3E7BE0	1937 516181	VLADIMIR PETROV	{"phone": "+70220718572"}
0005435476655	4FF2AE	0357 243346	TAMARA TIKHONOVA	{"email": "ttikhonova09121965@postgrespro.ru", "phone": "+70561781719"}
0005435476656	D056EE	0882 997403	VIKTORIYA VASILEVA	{"phone": "+70920878968"}
0005435476657	D056EE	0735 652578	OLGA TARASOVA	{"email": "tarasovaolga-1964@postgrespro.ru", "phone": "+70472362230"}
0005435476658	6C8CBC	7435 898466	GENNADIY MOROZOV	{"email": "gmorozov_1962@postgrespro.ru", "phone": "+70700181812"}
0005435476659	9F8D7E	3659 774182	NATALYA KOVALEVA	{"phone": "+70702604539"}
0005435476660	0CFA7E	4141 509746	ALEKSANDR ROMANOV	{"phone": "+70714013371"}
0005435476838	83DB51	0290 186249	SERGEY ZAKHAROV	{"phone": "+70988300164"}
0005435476661	528E83	9419 182505	SERGEY BONDARENKO	{"email": "bondarenko_s_071967@postgrespro.ru", "phone": "+70864722326"}
0005435476662	528E83	5203 534043	ALEKSANDR YAKOVLEV	{"phone": "+70746041136"}
0005435476663	EB3F17	9818 210139	VIKTOR SEMENOV	{"phone": "+70576390007"}
0005435476664	EB3F17	0393 614512	ARSENIY KONOVALOV	{"phone": "+70148051302"}
0005435476665	41616D	7851 364466	NADEZHDA NESTEROVA	{"email": "nesterovanadezhda_28031980@postgrespro.ru", "phone": "+70841750804"}
0005435476666	41616D	1547 104604	ALEKSEY ALEKSANDROV	{"phone": "+70128059732"}
0005435476667	B907B2	0778 827258	MIKHAIL MAKAROV	{"email": "mikhail.makarov-16061971@postgrespro.ru", "phone": "+70410587514"}
0005435476668	9B0CCE	5476 120666	OLEG SMIRNOV	{"phone": "+70490633402"}
0005435476669	21BFBA	6036 076077	VLADIMIR KAZAKOV	{"email": "kazakov-v.13011986@postgrespro.ru", "phone": "+70421942215"}
0005435476670	21BFBA	2310 528082	SERGEY VASILEV	{"phone": "+70022436360"}
0005435476671	21BFBA	3926 991013	MIKHAIL SHEVCHENKO	{"phone": "+70410839816"}
0005435476672	28170B	9788 411102	LYUBOV MIRONOVA	{"email": "lyubov-mironova.1965@postgrespro.ru", "phone": "+70708181077"}
0005435476673	28170B	8544 948090	ARTEM ZAKHAROV	{"phone": "+70301544045"}
0005435476674	28170B	4882 259168	LYUDMILA KUDRYASHOVA	{"phone": "+70766206621"}
0005435476675	28170B	8146 822701	NIKOLAY ZAYCEV	{"email": "zaycevnikolay25051972@postgrespro.ru", "phone": "+70348352616"}
0005435476676	C51AF3	1165 329379	PETR NOVIKOV	{"email": "novikov.petr101965@postgrespro.ru", "phone": "+70195104092"}
0005435476677	D3B819	9713 477317	VYACHESLAV MEDVEDEV	{"email": "vyacheslavmedvedev.1960@postgrespro.ru", "phone": "+70621238397"}
0005435476678	D3B819	8155 350874	SERGEY KRASNOV	{"phone": "+70239983372"}
0005435476679	7D421D	9534 062457	GALINA TIMOFEEVA	{"email": "timofeeva.galina.09101973@postgrespro.ru", "phone": "+70264098013"}
0005435476680	7D421D	0933 237178	PAVEL KUZNECOV	{"phone": "+70552843830"}
0005435476681	B0B900	9104 561636	ANTONINA EGOROVA	{"phone": "+70413089404"}
0005435476682	7207EE	1910 752394	ARTUR BONDARENKO	{"email": "bondarenko_a-1971@postgrespro.ru", "phone": "+70589139511"}
0005435476683	0CFFAA	5537 554093	VALENTINA MIRONOVA	{"phone": "+70726786899"}
0005435476684	05086C	7842 015902	SVETLANA KALININA	{"phone": "+70018782343"}
0005435476685	05086C	5208 405798	MARINA VASILEVA	{"email": "marina_vasileva-09091966@postgrespro.ru", "phone": "+70196125377"}
0005435476686	7DB4F8	1522 380993	TATYANA BORISOVA	{"phone": "+70275665789"}
0005435476687	89DF7D	7105 165359	TATYANA KAZAKOVA	{"email": "tatyanakazakova_1983@postgrespro.ru", "phone": "+70782440731"}
0005435476688	241FFE	9399 414989	VIKTOR EGOROV	{"email": "egorov.v011975@postgrespro.ru", "phone": "+70169486443"}
0005435476689	E0864B	1933 595177	ELENA KUZNECOVA	{"phone": "+70886860069"}
0005435476690	B755D4	6276 569484	TATYANA ZHUKOVA	{"email": "zhukova-t1969@postgrespro.ru", "phone": "+70974984137"}
0005435476691	A3C126	2768 760664	NATALYA GUSEVA	{"phone": "+70077287987"}
0005435476692	A3C126	9355 363272	DMITRIY KRASNOV	{"phone": "+70791287830"}
0005435476693	DF4E2E	0955 393217	SVETLANA SCHERBAKOVA	{"email": "scherbakova_svetlana.1971@postgrespro.ru", "phone": "+70987110948"}
0005435476694	DF4E2E	5992 838248	TATYANA SIDOROVA	{"email": "tsidorova_031970@postgrespro.ru", "phone": "+70016252541"}
0005435476695	914C17	6157 440567	MARIYA PETROVA	{"phone": "+70345843593"}
0005435476696	914C17	3724 106837	ILYA DENISOV	{"phone": "+70545968280"}
0005435476697	4EEF01	1545 651008	DANILA FROLOV	{"email": "danila.frolov031967@postgrespro.ru", "phone": "+70450795297"}
0005435476698	CE17BA	0571 143761	ANASTASIYA VASILEVA	{"email": "vasileva_anastasiya_26071978@postgrespro.ru", "phone": "+70712808879"}
0005435476699	806BC1	8838 559511	DENIS PAVLOV	{"phone": "+70407124447"}
0005435476700	C56A27	9741 387570	ANDREY BORISOV	{"email": "andrey_borisov1969@postgrespro.ru", "phone": "+70095369109"}
0005435476701	D3EE54	9022 343057	VASILIY STEPANOV	{"phone": "+70530400417"}
0005435476702	C179DD	8621 976270	TATYANA VLASOVA	{"email": "vlasovatatyana-071972@postgrespro.ru", "phone": "+70328972892"}
0005435476703	D3ABB3	6528 056163	ALEKSEY STEPANOV	{"email": "stepanovaleksey.10091978@postgrespro.ru", "phone": "+70234761251"}
0005435476704	5227C8	6907 311889	OKSANA KOZLOVA	{"email": "kozlova.oksana-051974@postgrespro.ru", "phone": "+70445586161"}
0005435476705	042775	7220 952862	ALEKSANDR GAVRILOV	{"phone": "+70291997483"}
0005435476706	1ADBC5	2673 953634	DENIS NAZAROV	{"phone": "+70784939975"}
0005435476707	9C856F	4262 311328	VALENTINA KUZMINA	{"phone": "+70824304060"}
0005435476708	DB3D07	7487 981478	KRISTINA SIDOROVA	{"email": "kristina_sidorova.03031967@postgrespro.ru", "phone": "+70254384352"}
0005435476709	160396	1745 716572	ALEKSANDR YAKOVLEV	{"phone": "+70002300915"}
0005435476710	160396	7704 503102	SOFYA FEDOROVA	{"phone": "+70951031016"}
0005435476711	174DDF	1118 509014	MARIYA SCHERBAKOVA	{"email": "mariya_scherbakova.26091966@postgrespro.ru", "phone": "+70792428531"}
0005435476712	F29743	2145 308100	VYACHESLAV KARPOV	{"email": "karpovvyacheslav.05021970@postgrespro.ru", "phone": "+70949020394"}
0005435476713	C44F96	1067 006579	TAMARA SOKOLOVA	{"email": "tamarasokolova111969@postgrespro.ru", "phone": "+70663854647"}
0005435476714	AF980B	6103 019377	ELENA GERASIMOVA	{"email": "gerasimova_elena-081965@postgrespro.ru", "phone": "+70021369183"}
0005435476715	AF980B	5284 455635	ALEKSANDR SIDOROV	{"email": "aleksandrsidorov_011974@postgrespro.ru", "phone": "+70310773036"}
0005435476716	AF980B	2358 844524	ALBERT KISELEV	{"email": "akiselev1973@postgrespro.ru", "phone": "+70866504866"}
0005435476717	EBDE7B	3421 774744	VLADIMIR ABRAMOV	{"phone": "+70240586683"}
0005435476718	1BF8DD	2612 991235	GALINA OVCHINNIKOVA	{"email": "g_ovchinnikova_1955@postgrespro.ru", "phone": "+70263561919"}
0005435476719	1BF8DD	2792 737966	VALENTINA IVANOVA	{"email": "vivanova101959@postgrespro.ru", "phone": "+70015467474"}
0005435476720	45DFE6	1023 102009	OLEG NIKOLAEV	{"email": "o-nikolaev.051989@postgrespro.ru", "phone": "+70845968160"}
0005435476721	45DFE6	3930 621036	TAMARA ZAKHAROVA	{"phone": "+70342925105"}
0005435476722	067064	0277 484864	VITALIY KUZNECOV	{"phone": "+70388251283"}
0005435476723	067064	7144 269581	EDUARD KAZAKOV	{"email": "eduardkazakov_111982@postgrespro.ru", "phone": "+70991874969"}
0005435476724	067064	2723 998408	VALERIY MOISEEV	{"phone": "+70079231476"}
0005435476725	067064	6246 213172	VIKTOR NOVIKOV	{"email": "vnovikov.051968@postgrespro.ru", "phone": "+70853641712"}
0005435476726	EDC7A9	5292 397192	VLADIMIR TARASOV	{"email": "tarasov-v25081981@postgrespro.ru", "phone": "+70503863259"}
0005435476727	70E793	8179 672021	NATALYA FILIPPOVA	{"email": "filippova-n30071973@postgrespro.ru", "phone": "+70046428321"}
0005435476728	C46B91	1488 515780	IVAN SEMENOV	{"phone": "+70989320558"}
0005435476729	C46B91	8778 762782	DMITRIY KUZNECOV	{"email": "d.kuznecov-07111964@postgrespro.ru", "phone": "+70266033841"}
0005435476730	1C344A	8014 014590	ELENA VASILEVA	{"email": "e_vasileva-011970@postgrespro.ru", "phone": "+70868857369"}
0005435476731	1C344A	7710 565531	VERA KUZNECOVA	{"email": "kuznecova.vera.1977@postgrespro.ru", "phone": "+70536348361"}
0005435476732	2DF64A	3009 239970	OLEG ANTONOV	{"phone": "+70431953190"}
0005435476733	1B5BF7	4988 819626	EVGENIYA GERASIMOVA	{"phone": "+70676183103"}
0005435476734	1B5BF7	3722 447765	VITALIY POPOV	{"email": "popov.vitaliy_1984@postgrespro.ru", "phone": "+70344840365"}
0005435476735	1B5BF7	1190 549926	TATYANA SMIRNOVA	{"phone": "+70406381475"}
0005435476736	17F2BB	3996 927238	ELENA YUDINA	{"phone": "+70373783395"}
0005435476737	6D81BC	3900 016404	SVETLANA KUZMINA	{"email": "s_kuzmina_02011962@postgrespro.ru", "phone": "+70791895540"}
0005435476738	F4A480	7807 505694	GALINA SIDOROVA	{"phone": "+70050550595"}
0005435476739	F4A480	2339 787740	ALEKSANDR ALEKSEEV	{"phone": "+70070543159"}
0005435476740	5AF184	1650 105618	NIKOLAY ROMANOV	{"email": "romanov_n101960@postgrespro.ru", "phone": "+70514507943"}
0005435476741	45EABA	9442 102647	NATALYA IVANOVA	{"email": "n_ivanova-20031959@postgrespro.ru", "phone": "+70555730949"}
0005435476742	45EABA	5148 672155	ELENA SAVELEVA	{"phone": "+70348608825"}
0005435476743	C3E218	7208 734855	VALENTINA KUZNECOVA	{"email": "v_kuznecova.07081977@postgrespro.ru", "phone": "+70750641490"}
0005435476744	43FACA	1647 480259	SERGEY IVANOV	{"email": "sivanov_081963@postgrespro.ru", "phone": "+70242640932"}
0005435476745	3E81F7	7684 406878	LARISA BELYAEVA	{"phone": "+70685194068"}
0005435476746	E354EF	5530 977199	ALEKSANDR GORBUNOV	{"email": "a_gorbunov.071978@postgrespro.ru", "phone": "+70812176831"}
0005435476747	0301B8	1690 835528	ANDREY PAVLOV	{"email": "andreypavlov-19121965@postgrespro.ru", "phone": "+70770711125"}
0005435476748	78EE52	6638 234709	ZOYA ILINA	{"email": "ilina_z021977@postgrespro.ru", "phone": "+70689169181"}
0005435476749	CFE730	5326 870661	NIKOLAY BELOV	{"phone": "+70704530090"}
0005435476750	E16975	6287 124211	NIKOLAY KOROLEV	{"phone": "+70739195653"}
0005435476751	E16975	7005 250099	DARYA VASILEVA	{"phone": "+70125384555"}
0005435476752	929182	1096 006576	ALEKSANDRA KALININA	{"phone": "+70202893483"}
0005435476753	A9A043	6950 402662	TATYANA KALININA	{"phone": "+70289308808"}
0005435476754	AB2A92	9879 718341	EKATERINA ILINA	{"phone": "+70016152278"}
0005435476755	926299	6166 849051	ANASTASIYA ABRAMOVA	{"email": "a.abramova.1963@postgrespro.ru", "phone": "+70614156531"}
0005435476756	015A43	1303 250136	ALEKSANDR FROLOV	{"phone": "+70800982277"}
0005435476757	015A43	9804 227865	DMITRIY SERGEEV	{"email": "sergeev_dmitriy051963@postgrespro.ru", "phone": "+70898821649"}
0005435476758	7378EB	9607 409579	GRIGORIY SERGEEV	{"phone": "+70802245724"}
0005435476759	0AFCDA	6984 224920	VALENTINA FILIPPOVA	{"phone": "+70394727189"}
0005435476760	0AFCDA	1978 757782	DENIS KAZAKOV	{"email": "denis-kazakov08031973@postgrespro.ru", "phone": "+70158405196"}
0005435476761	A5F25D	7721 392296	VALENTIN MOISEEV	{"phone": "+70933817894"}
0005435476762	00AE01	6101 471891	OLEG KAZAKOV	{"email": "oleg_kazakov1958@postgrespro.ru", "phone": "+70122941692"}
0005435476763	8ECD91	3527 100755	ANNA PETROVA	{"phone": "+70374689659"}
0005435476764	58BC0C	5157 727623	VLADISLAV YAKOVLEV	{"email": "yakovlev-vladislav-1974@postgrespro.ru", "phone": "+70734146321"}
0005435476765	58BC0C	8526 620122	ALEKSEY DENISOV	{"phone": "+70555227582"}
0005435476766	90580F	0733 521966	IRINA SIDOROVA	{"phone": "+70790920950"}
0005435476767	5DF5C4	8074 233505	MAKSIM DAVYDOV	{"email": "davydovmaksim.051977@postgrespro.ru", "phone": "+70680489310"}
0005435476768	0FF8E7	7125 642938	VASILIY TIMOFEEV	{"email": "timofeev_v.101969@postgrespro.ru", "phone": "+70083320123"}
0005435476769	435C8C	9188 280658	SVETLANA VASILEVA	{"email": "svetlana-vasileva-071987@postgrespro.ru", "phone": "+70473892380"}
0005435476770	4BFA25	8851 633339	PAVEL NOVIKOV	{"email": "pavel_novikov_1968@postgrespro.ru", "phone": "+70923672240"}
0005435476771	4BFA25	2467 399249	NINA IVANOVA	{"email": "n.ivanova-18081973@postgrespro.ru", "phone": "+70773787958"}
0005435476772	4BFA25	9854 864061	OLGA KOROLEVA	{"email": "olga_koroleva-081982@postgrespro.ru", "phone": "+70857155132"}
0005435476773	3C823D	5037 791729	ALEKSEY FROLOV	{"phone": "+70798757564"}
0005435476774	3C823D	6149 190526	ILYA POPOV	{"email": "popov.i-021976@postgrespro.ru", "phone": "+70200490801"}
0005435476775	3C823D	4749 688200	TATYANA RODIONOVA	{"email": "rodionova-tatyana_091971@postgrespro.ru", "phone": "+70754029675"}
0005435476776	2C158C	9335 366291	YURIY GERASIMOV	{"email": "y-gerasimov111969@postgrespro.ru", "phone": "+70259763232"}
0005435476777	2C158C	1582 786350	ELENA SIDOROVA	{"phone": "+70508850190"}
0005435476778	4AE08B	2455 598060	ALEKSANDR TARASOV	{"email": "aleksandr.tarasov-28071969@postgrespro.ru", "phone": "+70965435352"}
0005435476779	9ED4F1	5330 138735	SERGEY BARANOV	{"email": "baranov-sergey031973@postgrespro.ru", "phone": "+70117057609"}
0005435476780	AB77F4	2437 195119	VYACHESLAV MOROZOV	{"email": "morozov.vyacheslav01021976@postgrespro.ru", "phone": "+70942582777"}
0005435476781	730703	2921 758440	SVETLANA ZAYCEVA	{"email": "zayceva.svetlana1979@postgrespro.ru", "phone": "+70228283364"}
0005435476782	870707	7563 618871	VIKTOR SERGEEV	{"phone": "+70767458580"}
0005435476783	870707	7974 782043	TATYANA CHERNOVA	{"email": "tatyana-chernova.03091979@postgrespro.ru", "phone": "+70955522579"}
0005435476784	870707	7884 579590	YULIYA VLASOVA	{"email": "vlasova_y_1985@postgrespro.ru", "phone": "+70018966080"}
0005435476785	8A1765	3166 538669	OLGA ANDREEVA	{"phone": "+70748007089"}
0005435476786	361C04	9779 100471	ELENA MIRONOVA	{"phone": "+70691066726"}
0005435476787	DF834A	0343 332787	ULYANA BORISOVA	{"email": "borisovau_26091968@postgrespro.ru", "phone": "+70055871094"}
0005435476788	59446F	3157 497326	RAFIS AFANASEV	{"email": "r.afanasev-1968@postgrespro.ru", "phone": "+70161680140"}
0005435476789	72D9E4	4783 818512	MARGARITA NAUMOVA	{"email": "naumova-margarita_25011977@postgrespro.ru", "phone": "+70691432189"}
0005435476790	8FA0BD	4408 699023	VALENTINA KUZNECOVA	{"email": "v_kuznecova_01071977@postgrespro.ru", "phone": "+70600759323"}
0005435476791	DE9336	5859 305109	SERGEY NAZAROV	{"email": "nazarovsergey_1957@postgrespro.ru", "phone": "+70825188080"}
0005435476792	66E98A	7332 076287	ALEKSANDR BORISOV	{"email": "aleksandr_borisov1962@postgrespro.ru", "phone": "+70635673439"}
0005435476793	3E795D	3602 994350	IVAN VASILEV	{"email": "vasilev-i-05091975@postgrespro.ru", "phone": "+70402597865"}
0005435476794	932DB5	3090 248549	KONSTANTIN NIKITIN	{"email": "k-nikitin-1977@postgrespro.ru", "phone": "+70087594357"}
0005435476795	C22927	7387 037663	VLADIMIR ALEKSEEV	{"phone": "+70746584502"}
0005435476796	EEE8C8	1986 717714	PETR ZHUKOV	{"email": "zhukovpetr1967@postgrespro.ru", "phone": "+70957532492"}
0005435476797	BC5268	8325 964638	VITALIY ROMANOV	{"email": "romanov_vitaliy-08111961@postgrespro.ru", "phone": "+70005333521"}
0005435476798	B15388	6463 345636	ANTONINA MAKAROVA	{"email": "makarova.a-081975@postgrespro.ru", "phone": "+70141811437"}
0005435476799	B15388	3787 528353	LARISA ZAKHAROVA	{"email": "l.zakharova_10111965@postgrespro.ru", "phone": "+70692356706"}
0005435476800	B3B37B	5233 295332	ALEKSEY TIKHONOV	{"phone": "+70648340296"}
0005435476801	4319FE	3369 334328	LEONID VOLKOV	{"phone": "+70215861919"}
0005435476802	4319FE	4609 163246	LYUDMILA MELNIKOVA	{"email": "melnikova_lyudmila-1973@postgrespro.ru", "phone": "+70252780976"}
0005435476803	5F9514	1803 487983	TATYANA NESTEROVA	{"email": "tatyana.nesterova1971@postgrespro.ru", "phone": "+70513986031"}
0005435476804	5F9514	2545 084763	TATYANA IVANOVA	{"email": "ivanovatatyana15031967@postgrespro.ru", "phone": "+70622054827"}
0005435476805	E9F63A	7255 745892	NELLI ERMAKOVA	{"email": "n_ermakova_081967@postgrespro.ru", "phone": "+70679268666"}
0005435476806	A316F9	0955 346527	SERGEY ALEKSEEV	{"phone": "+70160525421"}
0005435476973	EAE7A6	4052 935653	BORIS KULIKOV	{"phone": "+70662715382"}
0005435476807	74EA48	5899 192165	LYUDMILA RYABOVA	{"email": "lyudmila_ryabova_121964@postgrespro.ru", "phone": "+70004130263"}
0005435476808	923934	3769 633005	MARGARITA POPOVA	{"email": "popova.margarita041971@postgrespro.ru", "phone": "+70836574484"}
0005435476809	923934	8713 817458	POLINA FILIPPOVA	{"phone": "+70221528975"}
0005435476810	0152D3	8732 070342	SVETLANA VOLKOVA	{"email": "svetlana_volkova-18091967@postgrespro.ru", "phone": "+70822164231"}
0005435476811	9B34DE	9917 655007	TATYANA AKIMOVA	{"email": "akimova_tatyana_1968@postgrespro.ru", "phone": "+70488856793"}
0005435476812	9B34DE	5390 777732	VALENTINA AFANASEVA	{"email": "vafanaseva.021974@postgrespro.ru", "phone": "+70905598259"}
0005435476813	ADF656	1295 931993	IVAN VOROBEV	{"phone": "+70949000650"}
0005435476814	ADF656	3404 269779	LYUBOV BORISOVA	{"phone": "+70138756801"}
0005435476815	ADF656	5300 344431	RAISA KUZNECOVA	{"email": "kuznecova.r-14041975@postgrespro.ru", "phone": "+70800632940"}
0005435476816	75F040	9446 427914	VALENTINA MALYSHEVA	{"phone": "+70088757150"}
0005435476817	BB37A7	3563 801688	VALENTINA ORLOVA	{"phone": "+70275399162"}
0005435476818	BB37A7	2861 900797	NADEZHDA LEBEDEVA	{"phone": "+70158809289"}
0005435476819	8DD56E	8149 179112	IRINA KUZNECOVA	{"phone": "+70237591194"}
0005435476820	5349DE	3535 897903	LYUDMILA SIDOROVA	{"phone": "+70019273573"}
0005435476821	5349DE	2643 960121	NIKOLAY MIRONOV	{"phone": "+70519432005"}
0005435476822	2FBF47	5393 848791	ANATOLIY KAZAKOV	{"phone": "+70662198004"}
0005435476823	19AF4C	6251 365956	VALENTINA BORISOVA	{"email": "borisova-valentina.02061975@postgrespro.ru", "phone": "+70017654005"}
0005435476824	E31EBE	0528 540438	EKATERINA POPOVA	{"phone": "+70639647207"}
0005435476825	E896DF	1777 230113	ALEKSANDR MOISEEV	{"phone": "+70762306363"}
0005435476826	F750E1	7632 878572	IVAN KULIKOV	{"phone": "+70412825546"}
0005435476827	63B3DC	4635 350876	IRINA POPOVA	{"email": "popova_i-1966@postgrespro.ru", "phone": "+70987104267"}
0005435476828	4F4799	2708 790882	PAVEL SEMENOV	{"phone": "+70180369626"}
0005435476829	4F4799	3697 264766	MAKSIM BARANOV	{"phone": "+70240782057"}
0005435476830	7C6D6A	5371 645660	VALENTINA SOKOLOVA	{"email": "valentina.sokolova1967@postgrespro.ru", "phone": "+70564223545"}
0005435476831	7C6D6A	3661 457154	ANGELINA GRISHINA	{"email": "agrishina1970@postgrespro.ru", "phone": "+70726592778"}
0005435476832	C578C2	2922 350359	ALEKSANDRA VASILEVA	{"email": "aleksandravasileva_031967@postgrespro.ru", "phone": "+70818369478"}
0005435476833	823668	0028 680106	TATYANA SAVELEVA	{"email": "savelevat.111967@postgrespro.ru", "phone": "+70316809653"}
0005435476834	FF012E	0425 249798	ANATOLIY ANDREEV	{"phone": "+70567354606"}
0005435476835	FF012E	0448 760112	SERGEY GRIGOREV	{"email": "s-grigorev.071969@postgrespro.ru", "phone": "+70848043957"}
0005435476836	F10C9B	6761 969674	MARIYA KUZNECOVA	{"email": "mariya_kuznecova_021962@postgrespro.ru", "phone": "+70248387325"}
0005435476837	F10C9B	9364 328821	MARIYA IVANOVA	{"phone": "+70294945143"}
0005435476839	8F705D	2259 942318	GALINA KULIKOVA	{"phone": "+70480674526"}
0005435476840	8F705D	5168 272312	LYUBOV KONDRATEVA	{"email": "kondratevalyubov031987@postgrespro.ru", "phone": "+70336488060"}
0005435476841	8F705D	4773 527126	VITALIY IVANOV	{"email": "ivanov.v.07011979@postgrespro.ru", "phone": "+70456320058"}
0005435476842	3F5740	5258 511125	ALEKSEY OSIPOV	{"email": "osipov-a-111974@postgrespro.ru", "phone": "+70836873143"}
0005435476843	3F5740	4200 519556	ZINAIDA KOZLOVA	{"email": "zkozlova.1966@postgrespro.ru", "phone": "+70046280504"}
0005435476844	9D117D	4472 620971	SERGEY SEMENOV	{"email": "semenovsergey.081974@postgrespro.ru", "phone": "+70096414423"}
0005435476845	E00CB1	0748 933704	ELENA SIDOROVA	{"email": "sidorova.e_011972@postgrespro.ru", "phone": "+70773048262"}
0005435476846	E00CB1	2253 796757	YULIYA SOKOLOVA	{"email": "sokolova_y101975@postgrespro.ru", "phone": "+70648295279"}
0005435476847	714ACF	4331 406799	YURIY SOROKIN	{"email": "sorokin_y071979@postgrespro.ru", "phone": "+70825540727"}
0005435476848	5EEA85	0244 771207	VIKTOR GRIGOREV	{"phone": "+70817252647"}
0005435476849	5EEA85	7850 150522	ALEKSANDR KRASNOV	{"email": "akrasnov_101963@postgrespro.ru", "phone": "+70654163335"}
0005435476850	19EBBC	6890 360464	VITALIY FOMIN	{"phone": "+70132111425"}
0005435476851	F58F23	7381 085231	KONSTANTIN KAZAKOV	{"email": "kkazakov13061971@postgrespro.ru", "phone": "+70154023255"}
0005435476852	F58F23	3691 988252	MARIYA OVCHINNIKOVA	{"phone": "+70432293133"}
0005435476853	2FAD10	8664 487836	ARTEM CHERNOV	{"email": "artemchernov-031976@postgrespro.ru", "phone": "+70696615984"}
0005435476854	E3C15C	0075 446888	OLGA VOLKOVA	{"phone": "+70072607810"}
0005435476855	B0E7EE	9140 717938	ALINA SCHERBAKOVA	{"email": "ascherbakova_23031965@postgrespro.ru", "phone": "+70858244536"}
0005435476856	B0E7EE	8152 742375	KONSTANTIN STEPANOV	{"email": "k-stepanov071960@postgrespro.ru", "phone": "+70744992843"}
0005435476857	6B29BD	0218 438655	RAISA LAZAREVA	{"phone": "+70520524694"}
0005435476858	27E28C	4938 518467	PAVEL KARPOV	{"email": "karpov_p1962@postgrespro.ru", "phone": "+70619729423"}
0005435476859	A6FA15	5549 406316	TAISIYA KOROLEVA	{"email": "taisiyakoroleva-1977@postgrespro.ru", "phone": "+70203603160"}
0005435476860	9DAA8D	2195 145636	LYUDMILA BORISOVA	{"email": "lyudmila_borisova_1962@postgrespro.ru", "phone": "+70020435024"}
0005435476861	9DAA8D	7487 139312	NATALYA VOROBEVA	{"email": "n.vorobeva_04121964@postgrespro.ru", "phone": "+70580222862"}
0005435476862	A1FAB4	0278 133975	IRINA IVANOVA	{"email": "irina.ivanova-011975@postgrespro.ru", "phone": "+70916955309"}
0005435476863	A1FAB4	8376 528839	LYUDMILA NIKOLAEVA	{"phone": "+70781288628"}
0005435476864	A1FAB4	5544 352896	LILIYA POLYAKOVA	{"phone": "+70137421573"}
0005435476865	02CC04	0134 556731	LYUDMILA KULIKOVA	{"email": "kulikoval1971@postgrespro.ru", "phone": "+70947721025"}
0005435476866	19215B	9669 891091	TATYANA EGOROVA	{"phone": "+70140876402"}
0005435476867	19215B	3623 519691	MARIYA KAZAKOVA	{"email": "kazakova.m_17071973@postgrespro.ru", "phone": "+70749884823"}
0005435476868	B04758	6526 389642	IVAN KUZMIN	{"phone": "+70564379761"}
0005435476869	449014	2635 194707	YULIYA NIKITINA	{"email": "yuliya-nikitina-25031966@postgrespro.ru", "phone": "+70785632918"}
0005435476870	116B46	8432 221217	EVGENIYA KUZNECOVA	{"email": "kuznecova.evgeniya-22101960@postgrespro.ru", "phone": "+70478378907"}
0005435476871	4557E6	8665 469620	VLADIMIR KRASNOV	{"email": "vladimirkrasnov1975@postgrespro.ru", "phone": "+70205349755"}
0005435476872	4557E6	4860 143339	KIRA MIKHAYLOVA	{"email": "mikhaylovakira_101977@postgrespro.ru", "phone": "+70305002933"}
0005435476873	98E3CF	9867 942893	NIKITA NAZAROV	{"phone": "+70074137715"}
0005435476874	98E3CF	5911 917027	GAGIK ZHURAVLEV	{"phone": "+70587658931"}
0005435476875	B4EB66	8853 883917	VALENTINA KOROLEVA	{"email": "valentina_koroleva121962@postgrespro.ru", "phone": "+70014613250"}
0005435476876	34E2AC	7422 924889	ALEKSEY ANDREEV	{"email": "andreevaleksey.31051978@postgrespro.ru", "phone": "+70793094599"}
0005435476877	E1E859	1358 827301	YULIYA ALEKSEEVA	{"phone": "+70944165776"}
0005435476878	E1E859	4701 366770	VLADIMIR NAZAROV	{"phone": "+70695635937"}
0005435476879	06FBBF	6042 274809	ALEKSANDR BARANOV	{"phone": "+70464595397"}
0005435476880	06FBBF	1004 110348	OLGA NIKITINA	{"email": "olga.nikitina-1982@postgrespro.ru", "phone": "+70977822053"}
0005435476881	063F6A	5790 597321	ALEKSANDR ANTONOV	{"phone": "+70011477534"}
0005435476882	063F6A	6388 681272	VASILIY FILIPPOV	{"email": "filippovvasiliy1969@postgrespro.ru", "phone": "+70326309028"}
0005435476883	4B04BC	2313 151985	ELENA NESTEROVA	{"phone": "+70403522581"}
0005435476884	D1BAD8	8341 096458	LARISA ANDREEVA	{"phone": "+70538932201"}
0005435476885	ACBD5F	7546 519917	SERGEY RODIONOV	{"email": "s-rodionov_121989@postgrespro.ru", "phone": "+70261353995"}
0005435476886	ACBD5F	4565 348192	VLADIMIR GORBUNOV	{"email": "vladimirgorbunov_061976@postgrespro.ru", "phone": "+70904432473"}
0005435476887	E6DEBD	1818 253362	ANNA YUDINA	{"email": "yudina_anna28121965@postgrespro.ru", "phone": "+70497891729"}
0005435476888	8CDBE6	9271 380753	ANDREY CHERNOV	{"email": "chernov_andrey_21061979@postgrespro.ru", "phone": "+70924868920"}
0005435476889	B61E44	1978 128277	DANIIL OSIPOV	{"email": "daniilosipov.071979@postgrespro.ru", "phone": "+70946020764"}
0005435476890	69DB85	2213 090104	VLADIMIR ANDREEV	{"email": "vladimir-andreev_17041979@postgrespro.ru", "phone": "+70166999795"}
0005435476891	69DB85	3283 041682	KONSTANTIN GERASIMOV	{"email": "gerasimovkonstantin.1974@postgrespro.ru", "phone": "+70183381095"}
0005435476892	69DB85	1205 364073	ALEKSANDR TIMOFEEV	{"phone": "+70281567746"}
0005435476893	D19B19	6584 055629	NIKOLAY OSIPOV	{"phone": "+70473842351"}
0005435476894	339418	9548 751463	ROMAN GORBUNOV	{"email": "gorbunovroman-071974@postgrespro.ru", "phone": "+70703837633"}
0005435476895	188717	0444 248497	MARIYA IVANOVA	{"email": "ivanovamariya081967@postgrespro.ru", "phone": "+70253977691"}
0005435476896	30F1D0	5368 255828	OLGA TIMOFEEVA	{"phone": "+70305294096"}
0005435476897	644E22	9930 165913	LYUDMILA KOROLEVA	{"phone": "+70120186483"}
0005435476898	644E22	3922 492109	NELLI STEPANOVA	{"email": "nelli-stepanova_111973@postgrespro.ru", "phone": "+70054799312"}
0005435476899	1231F9	7603 316624	ARTEM NIKOLAEV	{"phone": "+70083527996"}
0005435476900	1231F9	1341 699840	EVGENIY RODIONOV	{"phone": "+70025363912"}
0005435476901	A8B079	4452 810230	RAISA ALEKSANDROVA	{"email": "r_aleksandrova.07051971@postgrespro.ru", "phone": "+70537556705"}
0005435476902	FA0AFC	6756 054198	TATYANA MELNIKOVA	{"phone": "+70458806891"}
0005435476903	B6D43D	8736 626237	ALEKSANDR KOZLOV	{"phone": "+70545273711"}
0005435476904	B6D43D	5863 653960	MARIYA IVANOVA	{"email": "ivanova_mariya.021966@postgrespro.ru", "phone": "+70945103134"}
0005435476905	7B08C9	8812 911029	SERGEY EGOROV	{"email": "sergey.egorov.1975@postgrespro.ru", "phone": "+70966310471"}
0005435476906	DC7058	6003 561140	VLADIMIR PETROV	{"email": "petrov_v1966@postgrespro.ru", "phone": "+70940832988"}
0005435476907	3ADD7E	1558 836413	NATALYA BORISOVA	{"email": "borisova_n.01041979@postgrespro.ru", "phone": "+70764668857"}
0005435476908	3ADD7E	1858 951479	ALIYA NOVIKOVA	{"email": "a_novikova06041970@postgrespro.ru", "phone": "+70576433269"}
0005435476909	6E4F23	6335 971323	ALEKSANDRA KULIKOVA	{"phone": "+70332720667"}
0005435476910	6E4F23	6540 283313	OLGA MOROZOVA	{"email": "o_morozova_25111977@postgrespro.ru", "phone": "+70368118185"}
0005435476911	DDB070	2186 331927	TATYANA ZAYCEVA	{"phone": "+70362269739"}
0005435476912	DDB070	3694 764023	LILIYA ISAEVA	{"phone": "+70584105548"}
0005435476913	D99386	2032 853828	VALENTINA TIKHONOVA	{"email": "v-tikhonova1968@postgrespro.ru", "phone": "+70961605840"}
0005435476914	D99386	6773 934845	LEONID NAZAROV	{"email": "leonid-nazarov.20021972@postgrespro.ru", "phone": "+70894162557"}
0005435476915	5220C2	3497 023432	VERA MARTYNOVA	{"email": "martynova_v.24091964@postgrespro.ru", "phone": "+70822733823"}
0005435476916	157878	1134 762081	SERGEY MOROZOV	{"email": "morozov.s_1980@postgrespro.ru", "phone": "+70087785924"}
0005435476917	4F887E	4023 006931	TATYANA KOVALEVA	{"email": "tatyana.kovaleva.091981@postgrespro.ru", "phone": "+70657597870"}
0005435476918	4F887E	0217 612697	ALEKSEY VOROBEV	{"phone": "+70497713354"}
0005435476919	E92F11	6946 755928	TATYANA VASILEVA	{"phone": "+70285001718"}
0005435476920	447D95	8777 521612	LARISA KAZAKOVA	{"email": "kazakova-l.1976@postgrespro.ru", "phone": "+70987554045"}
0005435476921	1C7191	2845 121648	ANDREY KRASNOV	{"email": "andrey_krasnov-16021970@postgrespro.ru", "phone": "+70258151463"}
0005435476922	ECC118	9285 573345	ALEKSEY OSIPOV	{"email": "osipov-a091986@postgrespro.ru", "phone": "+70625698646"}
0005435476923	ECC118	1782 610780	ELENA KOROLEVA	{"phone": "+70321271304"}
0005435476924	0FA6F0	0442 570701	KRISTINA NOVIKOVA	{"phone": "+70704125469"}
0005435476925	B10F2F	6497 832494	VALERIY SEMENOV	{"email": "valeriy_semenov061973@postgrespro.ru", "phone": "+70318830095"}
0005435476926	B10F2F	4360 037896	ALEKSANDR SOLOVEV	{"email": "solovev-aleksandr07121970@postgrespro.ru", "phone": "+70972673463"}
0005435476927	A2DEC4	8143 920348	DMITRIY KUZNECOV	{"phone": "+70279160475"}
0005435476928	5D8F0A	5422 791228	ELENA POTAPOVA	{"email": "elenapotapova-16011983@postgrespro.ru", "phone": "+70067141821"}
0005435476929	5D8F0A	7269 363736	ILYA MATVEEV	{"email": "matveev_ilya-031980@postgrespro.ru", "phone": "+70851205802"}
0005435476930	5D8F0A	5551 218411	SERGEY VASILEV	{"email": "vasilevsergey-071977@postgrespro.ru", "phone": "+70679221784"}
0005435476931	7CAF94	9142 797400	SERGEY EGOROV	{"phone": "+70076825215"}
0005435476932	892511	8627 798949	VASILIY KUZNECOV	{"email": "kuznecov_vasiliy.051972@postgrespro.ru", "phone": "+70236552374"}
0005435476933	F796E2	3350 209855	GALINA MOROZOVA	{"phone": "+70319026720"}
0005435476934	F796E2	5333 136246	ALIYA EFIMOVA	{"phone": "+70456772034"}
0005435476935	90A749	6455 545598	IGOR ISAEV	{"email": "i-isaev_12051963@postgrespro.ru", "phone": "+70110282469"}
0005435476936	90A749	6387 353600	ELENA KOROLEVA	{"phone": "+70940018842"}
0005435476937	D9D279	0360 487532	NIKOLAY MOROZOV	{"phone": "+70312726308"}
0005435476938	39EE3C	3060 937517	MAKSIM MELNIKOV	{"phone": "+70621527423"}
0005435476939	E2250E	4526 610849	SERGEY RODIONOV	{"phone": "+70564519385"}
0005435476940	65CBF2	2750 165970	VIKTORIYA TROFIMOVA	{"email": "trofimova.v_011969@postgrespro.ru", "phone": "+70125244582"}
0005435476941	65CBF2	1912 406653	NADEZHDA KONOVALOVA	{"email": "n.konovalova-1977@postgrespro.ru", "phone": "+70309897008"}
0005435476942	81D8D3	5258 865150	EKATERINA KOROLEVA	{"phone": "+70857770153"}
0005435476943	C50F0E	5510 398131	MARINA NOVIKOVA	{"email": "novikova.marina.101971@postgrespro.ru", "phone": "+70240723632"}
0005435476944	5ECE01	8052 421675	NIKITA ROMANOV	{"phone": "+70097094595"}
0005435476945	2F3D63	1502 456598	ALEKSEY SHEVCHENKO	{"email": "aleksey.shevchenko-03051976@postgrespro.ru", "phone": "+70424470422"}
0005435476946	6B4FC6	1423 889908	SERGEY DAVYDOV	{"email": "davydov-s.06051968@postgrespro.ru", "phone": "+70918860041"}
0005435476947	D663B9	8260 969637	SAMIR DAVYDOV	{"email": "davydov.samir_091977@postgrespro.ru", "phone": "+70814315694"}
0005435476948	B9B4C9	5520 855593	EKATERINA STEPANOVA	{"email": "ekaterina-stepanova.25101962@postgrespro.ru", "phone": "+70714144658"}
0005435476949	71A1A9	9077 385523	ALEKSANDR KOROLEV	{"phone": "+70796003274"}
0005435476950	71A1A9	7579 461010	TATYANA POTAPOVA	{"email": "potapova.t-041974@postgrespro.ru", "phone": "+70882909968"}
0005435476951	479D01	8840 321213	STANISLAV POPOV	{"phone": "+70241630704"}
0005435476952	479D01	5838 749242	ALEKSEY ZHURAVLEV	{"phone": "+70174807220"}
0005435476953	203EEA	4924 595673	EKATERINA SERGEEVA	{"phone": "+70539874379"}
0005435476954	9AC32E	0219 794176	VALERIY MOROZOV	{"phone": "+70732684234"}
0005435476955	9AC32E	6105 413275	VLADIMIR ZHURAVLEV	{"email": "v.zhuravlev-26121978@postgrespro.ru", "phone": "+70829663288"}
0005435476956	B74AB0	2589 082189	ELENA SEMENOVA	{"email": "elena.semenova_13011973@postgrespro.ru", "phone": "+70503724154"}
0005435476957	B74AB0	0657 000131	IRINA ANDREEVA	{"phone": "+70443742572"}
0005435476958	4DD8DF	5676 764911	ALEKSANDR SCHERBAKOV	{"email": "scherbakov.a.121971@postgrespro.ru", "phone": "+70397536366"}
0005435476959	966BF6	2019 024953	OKSANA DENISOVA	{"phone": "+70262789945"}
0005435476960	DBAE8D	7832 823586	ALEKSEY ZAKHAROV	{"email": "zakharov.a091987@postgrespro.ru", "phone": "+70761899790"}
0005435476961	A41FDA	3265 708456	IVAN CHERNOV	{"email": "chernovivan_05061974@postgrespro.ru", "phone": "+70594593614"}
0005435476962	CA2F0D	5234 702392	NADEZHDA ABRAMOVA	{"phone": "+70911965053"}
0005435476963	960167	7383 786127	MIKHAIL ILIN	{"phone": "+70319646366"}
0005435476964	BFD16C	0544 237789	ELENA IVANOVA	{"phone": "+70248884547"}
0005435476965	BFD16C	9453 249168	PRASKOVYA SOLOVEVA	{"email": "praskovya.soloveva_1975@postgrespro.ru", "phone": "+70225596022"}
0005435476966	55AB10	1693 219818	ELENA MEDVEDEVA	{"email": "emedvedeva14021968@postgrespro.ru", "phone": "+70161558063"}
0005435476967	6CB52D	9387 302620	ALEKSANDR GUSEV	{"phone": "+70180903327"}
0005435476968	6CB52D	6835 581838	IVAN SEMENOV	{"email": "semenov_ivan12121974@postgrespro.ru", "phone": "+70306003105"}
0005435476969	F9D66C	8164 626030	OLGA PETROVA	{"email": "o_petrova_01101972@postgrespro.ru", "phone": "+70343845911"}
0005435476970	F9D66C	3360 199324	EVGENIY ANDREEV	{"phone": "+70518393625"}
0005435476971	D32F26	2221 009741	TAISIYA ISAEVA	{"email": "isaevat_27121966@postgrespro.ru", "phone": "+70699950031"}
0005435476972	C6020F	8385 880475	ANTON MAKSIMOV	{"phone": "+70149101684"}
0005435476974	5A83D2	2399 313398	DENIS GORBUNOV	{"email": "gorbunovdenis-19111969@postgrespro.ru", "phone": "+70325077451"}
0005435476975	5A83D2	1946 887907	TATYANA POPOVA	{"phone": "+70486516717"}
0005435476976	68B832	0576 275682	VADIM NOVIKOV	{"email": "novikov-vadim_071980@postgrespro.ru", "phone": "+70034594376"}
0005435476977	55CBD2	6645 474527	MARIYA ZAKHAROVA	{"email": "zakharovam.091975@postgrespro.ru", "phone": "+70319600420"}
0005435476978	55CBD2	5284 740774	ELENA MALYSHEVA	{"phone": "+70689675640"}
0005435476979	B07D82	2020 271601	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.1973@postgrespro.ru", "phone": "+70905968490"}
0005435476980	B07D82	8202 085563	OLGA MAKAROVA	{"email": "makarovaolga_021976@postgrespro.ru", "phone": "+70019916604"}
0005435476981	4186AF	8272 642511	GLEB NOVIKOV	{"email": "glebnovikov-04011961@postgrespro.ru", "phone": "+70442457108"}
0005435476982	440E01	3284 309464	VALERIY FILIPPOV	{"phone": "+70483838901"}
0005435476983	C52B9F	7744 850151	ANASTASIYA KOVALEVA	{"phone": "+70999549025"}
0005435476984	C52B9F	0312 636889	EVGENIY SERGEEV	{"phone": "+70735281476"}
0005435476985	346C00	0363 039213	OLGA FROLOVA	{"phone": "+70561749123"}
0005435476986	EB4CA0	9717 550435	DENIS BONDARENKO	{"email": "bondarenko-denis.061966@postgrespro.ru", "phone": "+70550364309"}
0005435476987	8E6A4E	8231 859779	EGOR MIKHAYLOV	{"phone": "+70676309666"}
0005435476988	0E13C7	5914 427511	ANDREY MELNIKOV	{"email": "melnikovandrey.26101984@postgrespro.ru", "phone": "+70837200417"}
0005435476989	144B10	1811 751137	RUSLAN SOROKIN	{"phone": "+70126996190"}
0005435476990	9F00A0	7113 379183	NINA MAKAROVA	{"phone": "+70659392015"}
0005435476991	3008A3	7646 883480	VALERIYA KONOVALOVA	{"email": "valeriyakonovalova1968@postgrespro.ru", "phone": "+70926481842"}
0005435476992	1399C9	8242 653101	ANATOLIY KAZAKOV	{"phone": "+70774584574"}
0005435476993	1AF9E8	6217 237697	VERA ANTONOVA	{"phone": "+70855378588"}
0005435476994	1AF9E8	3481 562454	OKSANA NIKITINA	{"email": "o-nikitina-12021967@postgrespro.ru", "phone": "+70398671382"}
0005435476995	7F87F5	5472 977574	YULIYA SCHERBAKOVA	{"email": "scherbakovay16021973@postgrespro.ru", "phone": "+70478839731"}
0005435476996	964FB0	8630 977854	IRINA GERASIMOVA	{"phone": "+70970060917"}
0005435476997	4441EA	4448 397416	BORIS KUZNECOV	{"email": "boriskuznecov-091978@postgrespro.ru", "phone": "+70283692248"}
0005435476998	4441EA	7834 429530	LYUBOV MAKAROVA	{"phone": "+70313440866"}
0005435476999	D3EE40	2737 704470	IRINA IVANOVA	{"phone": "+70336310471"}
0005435477000	674525	4836 349364	EVGENIY RODIONOV	{"phone": "+70013919496"}
0005435477001	674525	0987 996147	EVGENIYA TITOVA	{"phone": "+70581917512"}
0005435477002	674525	3211 765383	MARINA ALEKSEEVA	{"email": "m_alekseeva.18011967@postgrespro.ru", "phone": "+70686145295"}
0005435477003	674525	4023 153552	SEMEN KISELEV	{"phone": "+70132189843"}
0005435477004	F120F7	5794 243751	VLADIMIR MAKSIMOV	{"email": "v_maksimov-1971@postgrespro.ru", "phone": "+70181486645"}
0005435477005	F120F7	5495 703751	ANTONINA NESTEROVA	{"email": "nesterovaantonina_06101971@postgrespro.ru", "phone": "+70794386535"}
0005435477006	4B7150	7013 125998	MARINA SIDOROVA	{"phone": "+70545131808"}
0005435477007	4CA7CA	1387 626722	VYACHESLAV VASILEV	{"email": "vasilev.v021976@postgrespro.ru", "phone": "+70386843306"}
0005435477008	4CA7CA	5563 213863	ANDREY EGOROV	{"email": "aegorov_30051970@postgrespro.ru", "phone": "+70960843655"}
0005435477009	8077FC	9799 186742	YULIYA ORLOVA	{"email": "yuliya-orlova01011970@postgrespro.ru", "phone": "+70047614359"}
0005435477010	56525A	7079 366102	ELENA NOVIKOVA	{"phone": "+70808722685"}
0005435477011	ED32C4	1006 582024	VALENTINA FROLOVA	{"phone": "+70289413983"}
0005435477012	499762	9988 732608	SVETLANA ARKHIPOVA	{"email": "arkhipovasvetlana.1969@postgrespro.ru", "phone": "+70660632875"}
0005435477013	2FB034	2980 384895	VITALIY NAUMOV	{"phone": "+70449582412"}
0005435477014	2FB034	5548 297910	VLADISLAV PETROV	{"phone": "+70232325138"}
0005435477015	30D07E	5098 779217	GALINA ALEKSANDROVA	{"email": "galina-aleksandrova_1974@postgrespro.ru", "phone": "+70917079398"}
0005435477016	406AFC	4644 309906	ARTEM GRIGOREV	{"email": "grigorev.a-1978@postgrespro.ru", "phone": "+70754775122"}
0005435477017	15FDD6	0171 964043	ALEKSANDR ZAYCEV	{"phone": "+70841533950"}
0005435477018	15FDD6	2452 241977	VASILIY FOMIN	{"email": "fomin-v-10031962@postgrespro.ru", "phone": "+70379612012"}
0005435477019	15FDD6	2185 094512	DMITRIY MELNIKOV	{"email": "melnikovdmitriy.16111972@postgrespro.ru", "phone": "+70140130907"}
0005435477020	15FDD6	0450 829028	VALERIY MOISEEV	{"phone": "+70148519284"}
0005435477021	AC064E	9049 120251	DARYA MAKAROVA	{"email": "d_makarova-091971@postgrespro.ru", "phone": "+70904017029"}
0005435477022	E0CE13	6423 267986	TAMARA ZAKHAROVA	{"email": "t.zakharova-081978@postgrespro.ru", "phone": "+70324065670"}
0005435477023	0AF5DD	7454 327264	SERGEY TIKHONOV	{"phone": "+70427596647"}
0005435477024	CB4DD5	4851 717621	NIKOLAY ALEKSANDROV	{"phone": "+70370061215"}
0005435477025	CB4DD5	7256 104290	ALEKSANDR KRASNOV	{"email": "krasnov-a031971@postgrespro.ru", "phone": "+70476542675"}
0005435477026	6C29D6	4126 774703	LYUDMILA RODIONOVA	{"phone": "+70028081994"}
0005435477027	6C29D6	9097 461260	TATYANA VASILEVA	{"email": "vasileva.t-28121966@postgrespro.ru", "phone": "+70773004286"}
0005435477028	6C2A62	3392 105616	VLADIMIR ANTONOV	{"phone": "+70956066502"}
0005435477029	B2285B	0588 951657	RAUF POPOV	{"email": "r.popov.22061971@postgrespro.ru", "phone": "+70464960603"}
0005435477030	B2285B	9172 721104	TATYANA TROFIMOVA	{"email": "ttrofimova021969@postgrespro.ru", "phone": "+70152665320"}
0005435477031	B2285B	7606 885682	SERGEY ABRAMOV	{"email": "sergey_abramov.03101966@postgrespro.ru", "phone": "+70822767701"}
0005435477032	56F4A1	2757 622586	DENIS NAUMOV	{"email": "naumov_d_02061966@postgrespro.ru", "phone": "+70704059686"}
0005435477033	56F4A1	9086 916763	VIKTOR FROLOV	{"phone": "+70153333465"}
0005435477034	DC6DEE	2146 382577	TAISIYA KOLESNIKOVA	{"phone": "+70672245291"}
0005435487453	EEA2BC	0423 829982	SERGEY KAZAKOV	{"email": "sergey-kazakov.111977@postgrespro.ru", "phone": "+70517062097"}
0005435487454	EEA2BC	3032 637812	RAVIL BARANOV	{"phone": "+70006556132"}
0005435487455	2973E3	8342 814799	SERGEY SERGEEV	{"phone": "+70047826576"}
0005435487456	8BC905	1440 761307	LARISA GRISHINA	{"email": "grishinal.05011981@postgrespro.ru", "phone": "+70145140687"}
0005435487457	8BC905	3086 759347	MAKSIM KOROLEV	{"email": "korolev_m.041973@postgrespro.ru", "phone": "+70049629976"}
0005435487458	8BC905	6368 253777	DMITRIY ZHURAVLEV	{"email": "dmitriy-zhuravlev-121971@postgrespro.ru", "phone": "+70107419038"}
0005435487459	7B83C2	6056 395400	SERGEY STEPANOV	{"phone": "+70089042401"}
0005435487460	C6A105	8636 027475	FLYURA IVANOVA	{"email": "flyuraivanova-111964@postgrespro.ru", "phone": "+70072538319"}
0005435487461	FD70C3	6227 107017	SVETLANA ANDREEVA	{"email": "andreeva.svetlana-1983@postgrespro.ru", "phone": "+70466283571"}
0005435487462	C3E18A	7621 246138	LYUBOV MOROZOVA	{"phone": "+70392111638"}
0005435487463	1DAAB5	2736 173957	VLADIMIR ROMANOV	{"email": "romanov-v.021970@postgrespro.ru", "phone": "+70409082145"}
0005435487464	1DAAB5	4517 903773	IGOR RODIONOV	{"email": "rodionov_i1977@postgrespro.ru", "phone": "+70164629547"}
0005435487465	FF3BD9	3284 705280	SERGEY ANTONOV	{"email": "sergey.antonov_1969@postgrespro.ru", "phone": "+70432890821"}
0005435487466	0EF8E6	1578 507938	BORIS KUZMIN	{"phone": "+70052666831"}
0005435487467	0EF8E6	9418 132805	ANASTASIYA ARKHIPOVA	{"email": "arkhipova.a.091976@postgrespro.ru", "phone": "+70712575030"}
0005435487468	6D34A2	6347 410632	LARISA BELOVA	{"email": "belova_larisa08051970@postgrespro.ru", "phone": "+70711780500"}
0005435487469	EC864D	5675 707942	ALEKSANDR KRASNOV	{"email": "akrasnov.031977@postgrespro.ru", "phone": "+70766568953"}
0005435487470	5A8A41	4510 033298	VALENTINA MAKAROVA	{"email": "makarova_v_24011975@postgrespro.ru", "phone": "+70296598856"}
0005435487471	36DA50	4252 784285	MARINA VOLKOVA	{"email": "marina.volkova-051967@postgrespro.ru", "phone": "+70155882630"}
0005435487472	BC9176	5983 284529	ELENA MELNIKOVA	{"phone": "+70336448054"}
0005435487473	999104	0600 526459	OLGA FROLOVA	{"email": "o.frolova-10021964@postgrespro.ru", "phone": "+70750537687"}
0005435487474	999104	7494 305250	SERGEY FROLOV	{"email": "s.frolov.08091979@postgrespro.ru", "phone": "+70001082245"}
0005435487475	368ED5	4644 348055	OLGA KUZNECOVA	{"phone": "+70148860442"}
0005435487476	D4ACC2	5528 229158	NADEZHDA BORISOVA	{"email": "n-borisova-09071966@postgrespro.ru", "phone": "+70594324462"}
0005435487477	27F611	4850 539461	LIDIYA GERASIMOVA	{"email": "l.gerasimova_1961@postgrespro.ru", "phone": "+70454126737"}
0005435487478	27F611	1820 618647	OLGA SMIRNOVA	{"phone": "+70064351982"}
0005435487479	DEB61B	3106 136897	MAKSIM IVANOV	{"email": "ivanov.maksim_071968@postgrespro.ru", "phone": "+70937343910"}
0005435487480	DEB61B	7095 207394	SERGEY OSIPOV	{"phone": "+70834789664"}
0005435487481	0819D4	1715 064858	NIKOLAY PETROV	{"email": "nikolay.petrov-101973@postgrespro.ru", "phone": "+70422560736"}
0005435487482	65E1E1	6678 659118	SERGEY MEDVEDEV	{"email": "s_medvedev.30051970@postgrespro.ru", "phone": "+70855389734"}
0005435487483	A26AA0	1396 042500	ALEKSANDR PETROV	{"phone": "+70873394585"}
0005435487484	958A4C	6750 263171	SOFYA NOVIKOVA	{"phone": "+70534792019"}
0005435487485	958A4C	2709 058657	VIKTOR SEMENOV	{"email": "semenovviktor-1962@postgrespro.ru", "phone": "+70225660267"}
0005435487486	958A4C	4553 666364	SERGEY MIRONOV	{"phone": "+70042837718"}
0005435487487	F38E5D	3403 224425	RAISA POLYAKOVA	{"email": "polyakova.r.1962@postgrespro.ru", "phone": "+70659723181"}
0005435487488	F38E5D	1101 618484	TIKHON GRIGOREV	{"phone": "+70258728727"}
0005435487489	8C8864	2659 092388	GENNADIY NAUMOV	{"email": "gnaumov_051972@postgrespro.ru", "phone": "+70923042219"}
0005435487490	E33DD4	4966 354358	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev16101967@postgrespro.ru", "phone": "+70711163093"}
0005435487491	E33DD4	7524 576146	EKATERINA ILINA	{"email": "ilina-e_22061972@postgrespro.ru", "phone": "+70314225409"}
0005435487492	E33DD4	4676 621421	DANIL MAKAROV	{"email": "d.makarov-09101977@postgrespro.ru", "phone": "+70627777784"}
0005435487493	E0C4E8	8452 231911	PELAGEYA MAKAROVA	{"phone": "+70963027487"}
0005435487494	F36E1F	7664 391033	LYUBOV ALEKSANDROVA	{"phone": "+70888992116"}
0005435487495	F36E1F	1739 188070	STANISLAV STEPANOV	{"email": "sstepanov03111975@postgrespro.ru", "phone": "+70347878113"}
0005435487496	CA7083	5982 353925	LYUBOV BORISOVA	{"email": "borisova.lyubov-121985@postgrespro.ru", "phone": "+70582370609"}
0005435487497	CA7083	2891 736473	YURIY PAVLOV	{"email": "pavlov_y31011968@postgrespro.ru", "phone": "+70646659542"}
0005435487498	0370FC	1062 186099	RUSLAN MAKAROV	{"email": "makarov-ruslan_24121966@postgrespro.ru", "phone": "+70587043485"}
0005435487499	0370FC	0608 191912	MAKSIM BONDARENKO	{"email": "bondarenko_m.091973@postgrespro.ru", "phone": "+70540593065"}
0005435487500	91F2B4	7691 797753	DENIS ANDREEV	{"email": "andreev-denis-051968@postgrespro.ru", "phone": "+70419914355"}
0005435487501	AD392A	5358 452453	EVGENIY TIKHONOV	{"email": "e.tikhonov.051969@postgrespro.ru", "phone": "+70855870509"}
0005435487502	AD392A	7108 256913	NATALYA PETROVA	{"email": "n_petrova.23091970@postgrespro.ru", "phone": "+70255849311"}
0005435487503	6837E5	8028 152902	GALINA VASILEVA	{"phone": "+70748835298"}
0005435487504	6837E5	6372 821868	ALBINA RYABOVA	{"phone": "+70113255235"}
0005435487505	345599	9772 197573	ANASTASIYA KOZLOVA	{"phone": "+70431607133"}
0005435487506	6026F4	8289 803061	TATYANA KUZNECOVA	{"email": "kuznecova_t.1978@postgrespro.ru", "phone": "+70007406348"}
0005435487507	6026F4	6619 064220	OLGA SERGEEVA	{"phone": "+70599182815"}
0005435487508	7BC947	0009 332219	NADEZHDA BORISOVA	{"email": "borisova-n_1969@postgrespro.ru", "phone": "+70191199941"}
0005435487509	FBAC7A	8830 528965	NADEZHDA ARKHIPOVA	{"email": "nadezhda-arkhipova121965@postgrespro.ru", "phone": "+70864393471"}
0005435487510	5BFF84	1613 014443	KRISTINA GERASIMOVA	{"phone": "+70234696708"}
0005435487511	F562B2	2193 222341	NATALYA SAVELEVA	{"phone": "+70788578073"}
0005435487512	39B76F	9422 270665	ALEKSANDR TIKHONOV	{"phone": "+70665792395"}
0005435487513	8306E6	6826 296433	EVGENIY KISELEV	{"phone": "+70137660201"}
0005435487514	8306E6	8611 668885	GALINA TROFIMOVA	{"email": "trofimova-galina.16111982@postgrespro.ru", "phone": "+70444232147"}
0005435487515	81F698	1560 412870	ROMAN ALEKSANDROV	{"email": "romanaleksandrov-24011975@postgrespro.ru", "phone": "+70584225464"}
0005435487516	80F6A6	4028 918097	MARIYA IVANOVA	{"email": "m_ivanova-1971@postgrespro.ru", "phone": "+70050447402"}
0005435487517	B47FD4	8040 710516	NADEZHDA VOROBEVA	{"phone": "+70550044024"}
0005435487518	B47FD4	4706 863238	YURIY VLASOV	{"email": "vlasovy-101985@postgrespro.ru", "phone": "+70809648914"}
0005435487519	A1526B	0416 497112	NINA ZAKHAROVA	{"phone": "+70029367727"}
0005435487520	C128F1	8416 746870	LARISA ANDREEVA	{"email": "andreeva-larisa061971@postgrespro.ru", "phone": "+70789806857"}
0005435487521	9B530B	6486 536650	MARIYA SMIRNOVA	{"phone": "+70178980554"}
0005435487522	B49E10	1083 008504	ANNA MASLOVA	{"email": "maslova_a_1970@postgrespro.ru", "phone": "+70649619351"}
0005435487523	04534B	0221 853208	DINA KOVALEVA	{"phone": "+70510086740"}
0005435487524	16F302	1276 117904	ANASTASIYA CHERNOVA	{"email": "anastasiyachernova_061970@postgrespro.ru", "phone": "+70839149207"}
0005435487525	16F302	5600 191213	VLADIMIR MAKAROV	{"email": "v_makarov.041967@postgrespro.ru", "phone": "+70093940451"}
0005435487526	8DBF40	8123 284860	VIKTOR POPOV	{"phone": "+70153449340"}
0005435487527	8DBF40	9250 556144	IRINA ANDREEVA	{"email": "i.andreeva_05061985@postgrespro.ru", "phone": "+70992865425"}
0005435487528	8DBF40	8561 136470	VALENTIN TIKHONOV	{"email": "tikhonov.v_1974@postgrespro.ru", "phone": "+70236963545"}
0005435487529	618734	4403 244407	VALERIY PETROV	{"email": "v-petrov011984@postgrespro.ru", "phone": "+70182946128"}
0005435487530	7A526A	6385 145936	ARTEM SOROKIN	{"phone": "+70291037196"}
0005435487531	79B63D	2615 741633	VLADIMIR PETROV	{"phone": "+70856991127"}
0005435487532	ED735C	2154 409181	IRINA ISAEVA	{"phone": "+70821060861"}
0005435487533	4FF0FE	6632 013573	VYACHESLAV SERGEEV	{"email": "vsergeev.031972@postgrespro.ru", "phone": "+70375927035"}
0005435487534	4FF0FE	3837 993904	ALEKSANDR ANDREEV	{"phone": "+70711116591"}
0005435487535	4FBFA7	2139 218670	YANA POPOVA	{"email": "popovay021968@postgrespro.ru", "phone": "+70659726200"}
0005435487536	4FBFA7	6597 116325	VALERIY CHERNOV	{"email": "vchernov_051965@postgrespro.ru", "phone": "+70584680296"}
0005435487537	4FBFA7	3382 164912	OLGA KISELEVA	{"email": "olga_kiseleva-041979@postgrespro.ru", "phone": "+70955089508"}
0005435487538	D6EE98	8429 228219	OKSANA KONOVALOVA	{"email": "o-konovalova_07091973@postgrespro.ru", "phone": "+70568266877"}
0005435487539	D6EE98	7217 366848	NIKOLAY KISELEV	{"phone": "+70025932072"}
0005435487540	3F546C	1092 331752	RINAT RODIONOV	{"email": "rodionov.rinat_051982@postgrespro.ru", "phone": "+70245183700"}
0005435487541	4913F8	8463 808950	IGOR CHERNOV	{"email": "i.chernov1972@postgrespro.ru", "phone": "+70149161127"}
0005435487542	4913F8	8074 466344	GALINA VLASOVA	{"email": "vlasova-galina.1962@postgrespro.ru", "phone": "+70358859750"}
0005435487543	DBBE73	9243 230250	ALEKSANDR NAUMOV	{"phone": "+70381414705"}
0005435487544	F20AB9	3003 249454	DMITRIY KARPOV	{"email": "karpov.dmitriy-1963@postgrespro.ru", "phone": "+70995440073"}
0005435487545	F21B05	8287 201665	ANASTASIYA KOVALEVA	{"email": "akovaleva_25091974@postgrespro.ru", "phone": "+70306513262"}
0005435487546	F21B05	4224 475683	ANNA VASILEVA	{"phone": "+70175188997"}
0005435487547	33E40A	4306 471148	IRINA DMITRIEVA	{"email": "irinadmitrieva_1958@postgrespro.ru", "phone": "+70449623208"}
0005435487548	A4167F	2335 480539	MIKHAIL IVANOV	{"email": "m.ivanov.1974@postgrespro.ru", "phone": "+70371922965"}
0005435487549	2E91D0	7778 089195	YULIYA NIKOLAEVA	{"email": "nikolaeva.yuliya.1968@postgrespro.ru", "phone": "+70658287691"}
0005435487550	2E91D0	4751 493670	MARIYA MEDVEDEVA	{"email": "mariya.medvedeva.1970@postgrespro.ru", "phone": "+70269808132"}
0005435487551	EA59FB	6477 873789	NADEZHDA NIKOLAEVA	{"email": "nikolaevan.071978@postgrespro.ru", "phone": "+70091040609"}
0005435487552	83694A	8340 937937	VITALIY DMITRIEV	{"phone": "+70654795380"}
0005435487553	E9B318	9266 067081	VERA PETROVA	{"email": "vera.petrova.091969@postgrespro.ru", "phone": "+70222486302"}
0005435487554	5E569C	1507 959285	NIKOLAY FOMIN	{"email": "nikolay.fomin_081987@postgrespro.ru", "phone": "+70447711745"}
0005435487555	5E569C	7249 852062	EKATERINA SERGEEVA	{"phone": "+70584229351"}
0005435487556	54523C	8496 256796	VLADIMIR SAVELEV	{"email": "vsavelev-19091980@postgrespro.ru", "phone": "+70073218631"}
0005435487557	958DB7	9461 704346	ELENA TARASOVA	{"phone": "+70364831946"}
0005435487558	2AA412	7998 518314	MARINA LUKYANOVA	{"phone": "+70325886300"}
0005435487559	15235E	6115 277634	SERGEY IVANOV	{"email": "sergeyivanov-10081972@postgrespro.ru", "phone": "+70326086022"}
0005435487560	4FA034	1053 114639	VYACHESLAV KOZLOV	{"email": "kozlov-v-101973@postgrespro.ru", "phone": "+70977081550"}
0005435487561	E82577	0420 689013	LIDIYA VASILEVA	{"email": "vasileva.lidiya.29021980@postgrespro.ru", "phone": "+70006470900"}
0005435487562	A30CE8	2320 906845	VLADISLAV YAKOVLEV	{"email": "yakovlevv-28011979@postgrespro.ru", "phone": "+70985058979"}
0005435487563	CDA8E6	4797 834736	ALEKSANDRA KOZLOVA	{"email": "aleksandra.kozlova-29091971@postgrespro.ru", "phone": "+70883046129"}
0005435487564	C8BBA6	9281 647500	VALENTINA KONDRATEVA	{"phone": "+70829931762"}
0005435487565	C8BBA6	0527 702293	TAMARA KOZLOVA	{"phone": "+70915131025"}
0005435487566	4FCE31	2471 525102	EKATERINA AFANASEVA	{"email": "afanaseva_e_111981@postgrespro.ru", "phone": "+70725272081"}
0005435487567	4FCE31	5779 092235	ANDREY MATVEEV	{"phone": "+70969603197"}
0005435487568	46CFFC	8881 376472	IVAN MOROZOV	{"phone": "+70147780672"}
0005435487569	12B073	4872 043735	MIKHAIL FROLOV	{"email": "frolov-m-1972@postgrespro.ru", "phone": "+70398489682"}
0005435487570	675BC1	7882 258273	OLGA KOZLOVA	{"email": "kozlovaolga_111986@postgrespro.ru", "phone": "+70502167574"}
0005435487571	675BC1	9058 997724	MIKHAIL SCHERBAKOV	{"phone": "+70518567592"}
0005435487572	6DBA86	5216 187764	EVGENIY ZAKHAROV	{"email": "zakharovevgeniy_14121978@postgrespro.ru", "phone": "+70918233655"}
0005435487573	6DBA86	5671 022466	TATYANA IVANOVA	{"email": "ivanova_t19041967@postgrespro.ru", "phone": "+70136159245"}
0005435487574	B4D760	3682 988047	MIKHAIL ALEKSEEV	{"phone": "+70463647463"}
0005435487575	B4D760	9772 557060	ELENA GUSEVA	{"email": "e_guseva.1970@postgrespro.ru", "phone": "+70194555602"}
0005435487576	B4D760	6616 419103	DARINA STEPANOVA	{"email": "stepanovad.051967@postgrespro.ru", "phone": "+70788541395"}
0005435487577	F23153	0000 533505	NINA DENISOVA	{"phone": "+70556626623"}
0005435487578	F23153	1369 885942	IVAN IVANOV	{"email": "ivanov.ivan_061972@postgrespro.ru", "phone": "+70634999249"}
0005435487579	D751AF	8647 013936	OLEG GAVRILOV	{"email": "gavrilov.oleg23121969@postgrespro.ru", "phone": "+70845546740"}
0005435487580	D751AF	7177 719889	SERGEY AFANASEV	{"email": "afanasev_sergey09111966@postgrespro.ru", "phone": "+70584505477"}
0005435487581	D751AF	4947 880286	NATALYA POPOVA	{"email": "popova_natalya_071982@postgrespro.ru", "phone": "+70191922959"}
0005435487582	D751AF	0130 388269	LYUBOV MIRONOVA	{"email": "lyubov_mironova-071952@postgrespro.ru", "phone": "+70385832681"}
0005435487583	E42CF7	3756 171057	YULIYA ANTONOVA	{"email": "antonova.y-021971@postgrespro.ru", "phone": "+70568745233"}
0005435487584	A7AE1F	5720 331273	ALEKSANDR FOMIN	{"email": "fomin.aleksandr.04101979@postgrespro.ru", "phone": "+70139242058"}
0005435487585	A7AE1F	3189 778932	VALENTINA NAUMOVA	{"phone": "+70300981747"}
0005435487586	D6BFD1	7713 991031	ZOYA PAVLOVA	{"email": "z-pavlova-1978@postgrespro.ru", "phone": "+70806550314"}
0005435487587	99EEFF	9171 481055	SVETLANA NIKOLAEVA	{"phone": "+70160005592"}
0005435487588	28927E	1393 847098	KSENIYA DAVYDOVA	{"phone": "+70079860344"}
0005435487589	8318C5	8549 839539	NATALIYA IVANOVA	{"email": "nataliyaivanova091972@postgrespro.ru", "phone": "+70403668600"}
0005435487590	F48A8E	2432 000974	LYUBOV GUSEVA	{"email": "l_guseva-061969@postgrespro.ru", "phone": "+70025002807"}
0005435487591	E521A4	0526 018131	LIDIYA BARANOVA	{"email": "baranova-l121965@postgrespro.ru", "phone": "+70692682491"}
0005435487592	E521A4	6481 731356	ANTON STEPANOV	{"phone": "+70304081782"}
0005435487593	833C12	9863 707803	ELENA STEPANOVA	{"email": "elenastepanova.101976@postgrespro.ru", "phone": "+70509487135"}
0005435487594	833C12	2280 638868	NINA SOKOLOVA	{"email": "sokolova_n13111969@postgrespro.ru", "phone": "+70832207693"}
0005435487595	BF6AB5	5467 536645	KIRILL MIKHAYLOV	{"email": "mikhaylov.k1968@postgrespro.ru", "phone": "+70556464287"}
0005435487596	BF6AB5	5254 936711	MARINA GERASIMOVA	{"email": "marina_gerasimova.081976@postgrespro.ru", "phone": "+70701738382"}
0005435487597	4C4773	3957 831069	NIKOLAY MAKAROV	{"email": "nikolaymakarov.1968@postgrespro.ru", "phone": "+70471924278"}
0005435487598	4C4773	0206 213549	YULIYA FADEEVA	{"email": "yuliya-fadeeva.041974@postgrespro.ru", "phone": "+70409128233"}
0005435487599	DCA911	0534 959751	RUSTAM MAKAROV	{"phone": "+70565290124"}
0005435487600	9A6CA9	7933 422071	IRINA KAZAKOVA	{"phone": "+70197476211"}
0005435487601	9511DE	1056 674587	ELENA KULIKOVA	{"email": "e.kulikova.10021985@postgrespro.ru", "phone": "+70621134966"}
0005435487602	9511DE	3095 058075	ALEKSANDR SOKOLOV	{"email": "sokolov-aleksandr-111979@postgrespro.ru", "phone": "+70018647929"}
0005435487603	9511DE	5265 831095	VIKTOR MAKAROV	{"phone": "+70624793281"}
0005435487604	10DA7B	3288 972803	ALEKSANDR ABRAMOV	{"email": "aleksandr.abramov_07041971@postgrespro.ru", "phone": "+70091261741"}
0005435487605	10DA7B	5730 254349	VITALIY ZAKHAROV	{"email": "v_zakharov.101964@postgrespro.ru", "phone": "+70306256230"}
0005435487606	78C5B1	1707 700807	TAISIYA LOGINOVA	{"email": "taisiya_loginova.1966@postgrespro.ru", "phone": "+70371847808"}
0005435487607	5DC594	8640 506949	ALENA SOLOVEVA	{"email": "alena_soloveva.08031976@postgrespro.ru", "phone": "+70934540831"}
0005435487608	5DC594	4837 150824	DANIL KOZLOV	{"email": "dkozlov_091966@postgrespro.ru", "phone": "+70992215319"}
0005435487609	7BC92A	8700 131339	FEDOR PETROV	{"phone": "+70197882839"}
0005435487610	7BC92A	0819 875627	ILYA TIMOFEEV	{"email": "timofeev_ilya.031969@postgrespro.ru", "phone": "+70090040401"}
0005435487611	D6C66E	6182 238434	VALENTINA BELOVA	{"phone": "+70364414684"}
0005435487612	D6C66E	7783 823270	VLADIMIR ROMANOV	{"email": "romanov.v101973@postgrespro.ru", "phone": "+70794669025"}
0005435487613	9CEC00	2799 947807	ALENA KISELEVA	{"phone": "+70591544999"}
0005435487614	9CEC00	6283 240368	ALEKSANDR VASILEV	{"phone": "+70657530162"}
0005435487615	F3F952	5807 482255	IRINA SEMENOVA	{"email": "i.semenova.1978@postgrespro.ru", "phone": "+70270901270"}
0005435487616	57F1E1	4109 904363	ZOYA IVANOVA	{"email": "ivanovaz_1969@postgrespro.ru", "phone": "+70354517475"}
0005435487617	F3B5D6	7228 202944	DANIIL FROLOV	{"email": "frolov_d-081978@postgrespro.ru", "phone": "+70623777619"}
0005435487618	F3B5D6	3927 128385	VIKTOR KUZNECOV	{"phone": "+70718569899"}
0005435487619	2E4F82	2429 946696	TAISA ZHUKOVA	{"email": "taisa.zhukova-12061974@postgrespro.ru", "phone": "+70127567763"}
0005435487620	F83734	4179 632555	ARTUR POPOV	{"phone": "+70698139040"}
0005435487621	EA956D	8767 307397	LEV VASILEV	{"email": "vasilev-lev.021970@postgrespro.ru", "phone": "+70043596125"}
0005435487622	2D262E	2909 082469	NATALYA EGOROVA	{"email": "natalyaegorova-071967@postgrespro.ru", "phone": "+70232559276"}
0005435487623	89F789	2316 213231	ZINAIDA NIKITINA	{"phone": "+70787979776"}
0005435487624	CA7727	2425 148554	IRINA IVANOVA	{"phone": "+70859121816"}
0005435487625	CA7727	8810 607038	ALEKSEY IVANOV	{"email": "ivanov.aleksey.18081975@postgrespro.ru", "phone": "+70173816049"}
0005435487626	CA7727	2517 551265	ELIZAVETA FOMINA	{"phone": "+70300327803"}
0005435487627	081E81	2117 399059	ARMEN ZAKHAROV	{"phone": "+70511901834"}
0005435487628	5CE257	7808 332647	VALENTINA VOLKOVA	{"email": "vvolkova11021982@postgrespro.ru", "phone": "+70226080857"}
0005435487629	55CB14	2913 465256	KONSTANTIN GUSEV	{"email": "gusev_konstantin031962@postgrespro.ru", "phone": "+70636840627"}
0005435487630	CF4B42	3297 175907	KONSTANTIN VOLKOV	{"email": "volkov-konstantin-061973@postgrespro.ru", "phone": "+70393722854"}
0005435487631	3E9E6A	8168 990144	OLGA KUDRYASHOVA	{"email": "kudryashova-olga_14121967@postgrespro.ru", "phone": "+70694725733"}
0005435487632	F7220F	4022 662569	MIKHAIL AFANASEV	{"email": "afanasevmikhail_20121964@postgrespro.ru", "phone": "+70957723968"}
0005435487633	2364BC	2078 454543	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov041982@postgrespro.ru", "phone": "+70839924486"}
0005435487634	3FCEDB	9013 120009	IRINA MAKAROVA	{"phone": "+70095386918"}
0005435487635	DB9842	3028 098579	KRISTINA MIKHAYLOVA	{"email": "mikhaylova-kristina021966@postgrespro.ru", "phone": "+70286731339"}
0005435487636	19A49E	2906 517235	ALEKSANDRA LAZAREVA	{"email": "lazareva.a_101967@postgrespro.ru", "phone": "+70971517171"}
0005435487637	AE5F3C	7220 535071	ROMAN ZAKHAROV	{"email": "roman.zakharov041973@postgrespro.ru", "phone": "+70603732543"}
0005435487638	4B4E69	5576 443414	ROMAN OSIPOV	{"email": "r_osipov051982@postgrespro.ru", "phone": "+70151600778"}
0005435487639	64656A	0331 801430	MARINA SERGEEVA	{"email": "sergeevamarina_031967@postgrespro.ru", "phone": "+70079391186"}
0005435487640	75A9D6	3052 083827	LYUDMILA NAUMOVA	{"email": "naumovalyudmila031978@postgrespro.ru", "phone": "+70527120848"}
0005435487641	62E968	4355 500508	SVETLANA ZAKHAROVA	{"email": "zakharova_svetlana_1989@postgrespro.ru", "phone": "+70871796974"}
0005435487642	296870	9136 906631	NADEZHDA POPOVA	{"email": "popova_n-121987@postgrespro.ru", "phone": "+70216027287"}
0005435487643	296870	5903 812972	IVAN OSIPOV	{"phone": "+70372895026"}
0005435487644	A700A6	4369 002231	MARINA NIKOLAEVA	{"phone": "+70870778124"}
0005435487645	A700A6	6965 091703	TAMARA POLYAKOVA	{"email": "tpolyakova071982@postgrespro.ru", "phone": "+70747911480"}
0005435487646	4ADF85	4770 203404	NADEZHDA NAUMOVA	{"phone": "+70936027223"}
0005435487647	9BC66C	2939 676014	VALENTINA EFIMOVA	{"phone": "+70540930568"}
0005435487648	8BCEA0	9436 330793	OLESYA TARASOVA	{"phone": "+70895331551"}
0005435487649	B440D6	2149 447261	ALEKSANDR FEDOROV	{"phone": "+70978687215"}
0005435487650	23EBBF	4078 928114	LARISA FROLOVA	{"phone": "+70555230334"}
0005435487651	8040B1	1093 865756	ALBINA ANTONOVA	{"phone": "+70890082316"}
0005435487652	1DFD9D	5085 327684	YURIY MOISEEV	{"email": "ymoiseev_25101970@postgrespro.ru", "phone": "+70096682833"}
0005435487653	DC9E63	3946 492556	ALEKSANDR KARPOV	{"phone": "+70422389235"}
0005435487654	AF8CF7	5668 144224	KAROLINA SCHERBAKOVA	{"phone": "+70193253443"}
0005435487655	B65830	4212 686391	LILIYA CHERNOVA	{"phone": "+70871855340"}
0005435487656	FD5467	5207 728092	ALFIYA MEDVEDEVA	{"phone": "+70334682903"}
0005435487657	FD5467	4882 756194	DMITRIY TIKHONOV	{"phone": "+70941695717"}
0005435487658	DD1F90	7993 269427	VYACHESLAV ZHUKOV	{"phone": "+70097227683"}
0005435487659	CCB774	7508 210303	MIKHAIL POPOV	{"email": "popovmikhail_051973@postgrespro.ru", "phone": "+70594095571"}
0005435487660	5C4054	7647 880939	IGOR BELOV	{"email": "igorbelov.061958@postgrespro.ru", "phone": "+70762238780"}
0005435487661	ACE3D1	2588 868426	TATYANA ZAKHAROVA	{"email": "zakharovatatyana_1980@postgrespro.ru", "phone": "+70115691463"}
0005435487662	906F4A	5701 766424	VIKTORIYA ROMANOVA	{"phone": "+70449721285"}
0005435487663	4F00E0	4484 129587	RAMIL MELNIKOV	{"email": "r-melnikov011968@postgrespro.ru", "phone": "+70282457328"}
0005435487664	357A84	9635 405972	ALEKSEY NIKOLAEV	{"email": "aleksey.nikolaev-1970@postgrespro.ru", "phone": "+70719181689"}
0005435487665	349604	6850 884026	TATYANA SIDOROVA	{"phone": "+70524052058"}
0005435487666	C74E92	1276 422999	EKATERINA POLYAKOVA	{"phone": "+70622632824"}
0005435487667	C10DAD	8617 453411	VIKTOR DAVYDOV	{"phone": "+70177484996"}
0005435487668	9563D8	8664 246382	IVAN STEPANOV	{"email": "i-stepanov_01011986@postgrespro.ru", "phone": "+70765440361"}
0005435487669	390DFC	1242 957803	ANNA SOKOLOVA	{"email": "a_sokolova23051971@postgrespro.ru", "phone": "+70583013783"}
0005435487670	0452DC	4129 374634	DMITRIY MAKAROV	{"email": "makarovd_1973@postgrespro.ru", "phone": "+70504030678"}
0005435487671	E663D9	3507 568892	ALEKSANDR MOISEEV	{"phone": "+70445496774"}
0005435487672	F8CB0D	7784 826758	VALENTINA FOMINA	{"phone": "+70967054346"}
0005435487673	F8CB0D	5782 552862	SEMEN MOROZOV	{"phone": "+70391328707"}
0005435487674	35D7F0	2195 202264	LYUDMILA SERGEEVA	{"email": "sergeeva-l.101979@postgrespro.ru", "phone": "+70699237084"}
0005435487675	35D7F0	4852 365689	LYUDMILA GORBUNOVA	{"email": "l-gorbunova-1981@postgrespro.ru", "phone": "+70653085563"}
0005435487676	5CB2BD	6312 383970	ANDREY MOROZOV	{"phone": "+70162734105"}
0005435487677	3D9F48	8219 820437	ELENA LOGINOVA	{"email": "eloginova_11031977@postgrespro.ru", "phone": "+70491259821"}
0005435487678	B48CA3	0956 607495	ALEKSANDR IVANOV	{"email": "aleksandr.ivanov19121976@postgrespro.ru", "phone": "+70093897878"}
0005435487679	C6D72D	0462 360966	ANNA GAVRILOVA	{"phone": "+70515377603"}
0005435487680	790E71	8483 553331	LYUBOV SOLOVEVA	{"email": "soloveva_l_14061962@postgrespro.ru", "phone": "+70584532043"}
0005435487681	790E71	2897 499166	LARISA DANILOVA	{"phone": "+70450820583"}
0005435487682	790E71	5259 592772	IRINA KONOVALOVA	{"phone": "+70390466219"}
0005435487683	741FC6	5261 804593	DMITRIY ANDREEV	{"phone": "+70112354159"}
0005435487684	165B91	1048 247985	DMITRIY SOROKIN	{"email": "d.sorokin-25041968@postgrespro.ru", "phone": "+70232516093"}
0005435487685	F7EB68	1769 770245	ANDREY SCHERBAKOV	{"phone": "+70533095155"}
0005435487686	F7EB68	4758 482521	PETR VASILEV	{"email": "vasilev-petr021968@postgrespro.ru", "phone": "+70988793917"}
0005435487687	FB8D55	9251 412813	KRISTINA SAVELEVA	{"email": "saveleva_kristina.021975@postgrespro.ru", "phone": "+70340568071"}
0005435487688	FB8D55	9728 189174	ALEKSANDR ORLOV	{"email": "aleksandr.orlov-23051970@postgrespro.ru", "phone": "+70718956787"}
0005435487689	372EC9	6179 272272	NINA MELNIKOVA	{"email": "melnikova_n-22071967@postgrespro.ru", "phone": "+70348013419"}
0005435487690	3C8DA1	5249 588540	ARTEM FROLOV	{"email": "artem.frolov_1972@postgrespro.ru", "phone": "+70619565988"}
0005435487691	39ABB9	7366 643673	STANISLAV MELNIKOV	{"email": "smelnikov.121972@postgrespro.ru", "phone": "+70427136917"}
0005435487692	F244C1	5475 168481	OLGA KUZNECOVA	{"phone": "+70023640936"}
0005435487693	590C32	4651 940500	MARINA SAVELEVA	{"email": "msaveleva-1964@postgrespro.ru", "phone": "+70318634458"}
0005435487694	0016DE	1401 033124	PAVEL MAKSIMOV	{"phone": "+70073502224"}
0005435487695	0016DE	1279 120113	VLADIMIR EGOROV	{"email": "egorov_v.091973@postgrespro.ru", "phone": "+70779072524"}
0005435487696	1CCF96	2891 611495	SOFYA EFREMOVA	{"email": "efremova-sofya_19011977@postgrespro.ru", "phone": "+70318214008"}
0005435487697	79A1FF	4461 154038	LIDIYA AFANASEVA	{"phone": "+70934363974"}
0005435487698	79A1FF	3879 221489	LYUDMILA ZAKHAROVA	{"email": "l.zakharova_101979@postgrespro.ru", "phone": "+70007269477"}
0005435487699	CD755F	8877 178175	YURIY FILIPPOV	{"phone": "+70159723892"}
0005435487700	CD755F	5807 523462	NIKOLAY ABRAMOV	{"phone": "+70146913742"}
0005435487701	6AB636	2788 420960	SERGEY NIKOLAEV	{"email": "sergey-nikolaev_1978@postgrespro.ru", "phone": "+70782060716"}
0005435487702	6CBA4C	7593 388866	NADEZHDA MIKHAYLOVA	{"email": "nadezhda.mikhaylova_1971@postgrespro.ru", "phone": "+70676455717"}
0005435487703	AB92CA	4017 939270	OLEG IVANOV	{"phone": "+70056084357"}
0005435487704	AB92CA	1250 463851	NATALYA ROMANOVA	{"phone": "+70811665708"}
0005435487705	713F82	8561 818365	ANGELINA RODIONOVA	{"phone": "+70760730837"}
0005435487706	2D807D	3390 888893	ALEKSEY ANDREEV	{"phone": "+70487838691"}
0005435487707	0C6CF8	1883 690701	ALEKSEY FEDOTOV	{"phone": "+70565355341"}
0005435487708	461BB4	8330 918023	YURIY MARTYNOV	{"phone": "+70613281465"}
0005435487709	461BB4	8003 456140	ALEKSANDR POPOV	{"phone": "+70733037972"}
0005435487710	AB5017	5849 927092	ALEVTINA MAKAROVA	{"email": "a.makarova121963@postgrespro.ru", "phone": "+70922565529"}
0005435487711	AB5017	5835 448020	ZINAIDA NOVIKOVA	{"email": "novikovaz-1964@postgrespro.ru", "phone": "+70531151683"}
0005435487712	B564CA	1582 957781	DMITRIY ZHUKOV	{"email": "d_zhukov-01021969@postgrespro.ru", "phone": "+70809027067"}
0005435487713	4B2E8F	0329 658673	ALEKSANDR ROMANOV	{"email": "romanov_a1969@postgrespro.ru", "phone": "+70815781295"}
0005435487714	A1B564	4613 393146	OLGA MELNIKOVA	{"phone": "+70236688319"}
0005435487715	4F9A1B	1195 430714	ELENA MALYSHEVA	{"phone": "+70732678460"}
0005435487716	4F9A1B	8628 332595	VLADIMIR POPOV	{"email": "popov.v.021987@postgrespro.ru", "phone": "+70300186747"}
0005435487717	5F826F	3447 674716	EVGENIY KISELEV	{"phone": "+70464548985"}
0005435487718	EE4528	0820 717786	EVGENIY VASILEV	{"email": "vasilev.e1978@postgrespro.ru", "phone": "+70872398552"}
0005435487719	E98C50	1526 226004	SVETLANA NIKITINA	{"email": "svetlana.nikitina.13031968@postgrespro.ru", "phone": "+70779114167"}
0005435487720	F300D1	1422 806626	NADEZHDA GRISHINA	{"phone": "+70784245895"}
0005435487721	7F6E69	6738 352894	VERA EGOROVA	{"phone": "+70131757121"}
0005435487722	7F6E69	9229 717094	VIKTOR TIKHONOV	{"email": "tikhonov-viktor011973@postgrespro.ru", "phone": "+70043379889"}
0005435487723	C1144C	9282 228216	ALEKSANDR SEMENOV	{"phone": "+70219433934"}
0005435487724	E5A9BB	8408 075928	NADEZHDA KUZMINA	{"phone": "+70287919336"}
0005435487725	0A2AFD	7626 869768	RUSLAN VASILEV	{"email": "r_vasilev.121969@postgrespro.ru", "phone": "+70212246059"}
0005435487726	78CD67	7403 227228	RUSTAM DAVYDOV	{"phone": "+70818126052"}
0005435487727	3A84D8	7111 981601	VERA SOROKINA	{"phone": "+70344889720"}
0005435487728	1FE408	7512 586801	IGOR KARPOV	{"email": "karpovi031961@postgrespro.ru", "phone": "+70224464651"}
0005435487729	210FCE	5341 861263	NIKOLAY MARTYNOV	{"phone": "+70820999353"}
0005435487730	210FCE	3815 317248	SERGEY FOMIN	{"email": "fomin.sergey_1984@postgrespro.ru", "phone": "+70483848178"}
0005435487731	977D66	3592 182464	TIMOFEY SERGEEV	{"phone": "+70609489130"}
0005435487732	401304	0687 976593	ALEKSANDR MAKAROV	{"email": "amakarov1975@postgrespro.ru", "phone": "+70080377066"}
0005435487733	401304	8749 303472	YANA MEDVEDEVA	{"email": "y.medvedeva.081984@postgrespro.ru", "phone": "+70466187112"}
0005435487734	4B8714	1309 032711	ELENA AKIMOVA	{"phone": "+70969869537"}
0005435487735	4B8714	3151 286243	GENNADIY KISELEV	{"email": "gennadiy.kiselev-011966@postgrespro.ru", "phone": "+70005423736"}
0005435487736	E5B4FE	3699 303618	MARIYA TIKHONOVA	{"phone": "+70316768475"}
0005435487737	E5B4FE	9107 291714	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey.06061986@postgrespro.ru", "phone": "+70076078752"}
0005435487738	D41835	2874 772627	IRINA IVANOVA	{"phone": "+70350645514"}
0005435487739	D41835	6600 944905	RIMMA GUSEVA	{"phone": "+70134662122"}
0005435487740	D41835	9179 270056	VASILIY KRASNOV	{"phone": "+70377211377"}
0005435487741	EA81EB	0537 206095	DMITRIY IVANOV	{"email": "dmitriyivanov.26101978@postgrespro.ru", "phone": "+70919519358"}
0005435487742	EA81EB	1239 345923	OLGA ZOTOVA	{"email": "zotovaolga-1969@postgrespro.ru", "phone": "+70582240552"}
0005435487743	D6EC7F	3623 360224	MARINA TIKHONOVA	{"phone": "+70302489167"}
0005435487744	4B6CED	2486 747037	ELENA BELYAEVA	{"phone": "+70311075171"}
0005435487745	4B6CED	3955 903640	NINA NIKITINA	{"phone": "+70699123155"}
0005435487746	7F8F16	8732 849944	SVETLANA NOVIKOVA	{"email": "snovikova_051964@postgrespro.ru", "phone": "+70480083312"}
0005435487747	A97C2C	0783 117882	VLADIMIR NIKOLAEV	{"email": "nikolaev_vladimir071975@postgrespro.ru", "phone": "+70911214966"}
0005435487748	27E153	2453 503641	OLGA SOLOVEVA	{"email": "soloveva_olga1963@postgrespro.ru", "phone": "+70633412618"}
0005435487749	9FEC18	4540 341359	ALEKSANDR FILIPPOV	{"email": "aleksandr.filippov_1969@postgrespro.ru", "phone": "+70268302047"}
0005435487750	262B09	9231 955184	ALEKSEY PETROV	{"email": "a_petrov_01091980@postgrespro.ru", "phone": "+70448543333"}
0005435487751	DE316F	8904 418234	ANNA AFANASEVA	{"phone": "+70172654254"}
0005435487752	473066	4841 921671	NADEZHDA DANILOVA	{"email": "danilova-nadezhda-031981@postgrespro.ru", "phone": "+70319595354"}
0005435487753	4D7A5D	8672 596306	LEONID MIKHAYLOV	{"email": "leonid.mikhaylov.101968@postgrespro.ru", "phone": "+70526517375"}
0005435487754	8850C5	6990 089973	LYUBOV MOROZOVA	{"email": "l_morozova-31051981@postgrespro.ru", "phone": "+70606814703"}
0005435487755	D31078	0276 972310	ARTUR DAVYDOV	{"phone": "+70105916851"}
0005435487756	49F604	5656 527608	DMITRIY GAVRILOV	{"phone": "+70147745741"}
0005435487757	1F2256	6760 392708	FELIKS AFANASEV	{"email": "f_afanasev051960@postgrespro.ru", "phone": "+70423889928"}
0005435487758	1F2256	1701 480750	RAUZA TROFIMOVA	{"email": "r.trofimova_071980@postgrespro.ru", "phone": "+70521911581"}
0005435487759	C8024B	6847 182607	LYUDMILA ORLOVA	{"email": "l_orlova_071972@postgrespro.ru", "phone": "+70509750222"}
0005435487760	C8024B	1315 572527	ANDREY STEPANOV	{"phone": "+70767294056"}
0005435487761	C863B0	4235 723996	ELENA VASILEVA	{"email": "vasileva-e-11071982@postgrespro.ru", "phone": "+70421865950"}
0005435487762	C863B0	7232 153838	TATYANA SOKOLOVA	{"email": "t-sokolova01021966@postgrespro.ru", "phone": "+70575520936"}
0005435487763	5C360B	3492 945579	VADIM KOROLEV	{"email": "vadim-korolev1964@postgrespro.ru", "phone": "+70525558436"}
0005435487764	BC4D80	8334 051262	ANNA NIKITINA	{"email": "nikitinaanna-1975@postgrespro.ru", "phone": "+70932405997"}
0005435487765	BC4D80	3607 846248	LYUDMILA KAZAKOVA	{"email": "kazakova_l.31031974@postgrespro.ru", "phone": "+70568911481"}
0005435487766	BC4D80	4930 245220	DMITRIY GAVRILOV	{"email": "gavrilov.dmitriy-071973@postgrespro.ru", "phone": "+70415703900"}
0005435487767	80C7D1	0402 915639	ANASTASIYA NAUMOVA	{"email": "naumova.a.031980@postgrespro.ru", "phone": "+70559736084"}
0005435487768	80C7D1	3748 890462	IVAN ZHURAVLEV	{"phone": "+70269167184"}
0005435487769	3699BE	2079 008424	GALINA SEMENOVA	{"phone": "+70857601920"}
0005435487770	A63C8F	8476 287282	NAZIYA KONDRATEVA	{"phone": "+70853561166"}
0005435487771	BC2BC2	7987 563958	GALINA MAKAROVA	{"email": "makarova_galina1975@postgrespro.ru", "phone": "+70188828050"}
0005435487772	010153	9918 864526	EVGENIYA KUZNECOVA	{"email": "evgeniyakuznecova-1978@postgrespro.ru", "phone": "+70633677067"}
0005435487773	010153	8795 047455	LYUBOV GAVRILOVA	{"email": "gavrilovalyubov-18051968@postgrespro.ru", "phone": "+70271423350"}
0005435487774	8F864A	8512 786744	ILYA ZHURAVLEV	{"phone": "+70929091451"}
0005435487775	BC705E	2396 277159	ALEKSEY KAZAKOV	{"phone": "+70228596232"}
0005435487776	BC705E	4571 851043	SERGEY ZHURAVLEV	{"email": "szhuravlev-081980@postgrespro.ru", "phone": "+70097607065"}
0005435487777	F31E49	5629 151261	ALEKSANDR VASILEV	{"phone": "+70799027797"}
0005435487778	F31E49	8815 616690	DARYA ILINA	{"email": "ilina.darya_051978@postgrespro.ru", "phone": "+70911137822"}
0005435487779	F31E49	3145 994935	VALERIY MIRONOV	{"email": "mironovvaleriy-1973@postgrespro.ru", "phone": "+70141137323"}
0005435487780	F33D11	2877 297485	ELENA STEPANOVA	{"email": "stepanova.elena-1980@postgrespro.ru", "phone": "+70347767256"}
0005435487781	03C6D2	2847 750932	MARIYA MALYSHEVA	{"email": "mariyamalysheva13031976@postgrespro.ru", "phone": "+70194853449"}
0005435487782	03C6D2	3514 612647	IRINA KOROLEVA	{"phone": "+70594470124"}
0005435487783	03C6D2	1526 319228	ADELINA KULIKOVA	{"email": "adelina.kulikova1977@postgrespro.ru", "phone": "+70124783317"}
0005435487784	BCED78	6180 951081	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.1959@postgrespro.ru", "phone": "+70592554608"}
0005435487785	BCED78	2537 790767	ALEKSEY TIMOFEEV	{"phone": "+70277632810"}
0005435487786	91EF66	0026 424903	ELENA YUDINA	{"email": "yudina_elena_101960@postgrespro.ru", "phone": "+70464311113"}
0005435487787	60216A	2288 740590	IVAN IVANOV	{"email": "iivanov-11101971@postgrespro.ru", "phone": "+70941913831"}
0005435487788	5E73DE	3261 216335	VLADIMIR TIKHONOV	{"email": "tikhonovvladimir_15011976@postgrespro.ru", "phone": "+70108270192"}
0005435487789	D78812	4498 001763	ILYA KONOVALOV	{"phone": "+70771422968"}
0005435487790	D78812	8624 686647	TATYANA BELOVA	{"email": "t-belova.111982@postgrespro.ru", "phone": "+70478109051"}
0005435487791	A3AC45	1172 911286	ALEKSANDRA STEPANOVA	{"email": "astepanova-23081970@postgrespro.ru", "phone": "+70904109209"}
0005435487792	7E8562	9013 364119	SERGEY ORLOV	{"phone": "+70503286297"}
0005435487793	7E8562	5471 490411	OLGA MEDVEDEVA	{"phone": "+70829730132"}
0005435487794	66A239	7150 686924	ALEKSEY AFANASEV	{"email": "afanasev_a-11061960@postgrespro.ru", "phone": "+70584689171"}
0005435487795	66A239	2513 806888	ALINA KAZAKOVA	{"phone": "+70525499939"}
0005435487796	EE49B2	5639 144792	DANIIL KULIKOV	{"email": "kulikovdaniil1974@postgrespro.ru", "phone": "+70479007506"}
0005435487797	13D491	4197 560978	ILYA MAKAROV	{"email": "imakarov.02101972@postgrespro.ru", "phone": "+70307225807"}
0005435487798	13D491	9973 451902	VLADIMIR ABRAMOV	{"email": "v-abramov.1968@postgrespro.ru", "phone": "+70385464969"}
0005435487799	E1343D	3837 407366	TATYANA SERGEEVA	{"email": "tsergeeva17041964@postgrespro.ru", "phone": "+70983056505"}
0005435487800	E1343D	1772 346805	DENIS VOLKOV	{"email": "volkov_d_1974@postgrespro.ru", "phone": "+70292531922"}
0005435487801	59FE91	0242 740522	ANATOLIY FEDOROV	{"phone": "+70877734815"}
0005435487802	CAB6E1	2741 227506	DIANA KUZNECOVA	{"phone": "+70470644500"}
0005435487803	EDAB45	8153 915536	ARTEM KRASNOV	{"phone": "+70344975775"}
0005435487804	96E717	0981 075969	SEMEN KAZAKOV	{"phone": "+70380856654"}
0005435487805	3ABED7	2627 775530	NADEZHDA NIKIFOROVA	{"phone": "+70457017093"}
0005435487806	7FBF81	0827 997500	NIKOLAY MIKHAYLOV	{"email": "n_mikhaylov031975@postgrespro.ru", "phone": "+70180043591"}
0005435487807	7FBF81	9491 289957	SERGEY TARASOV	{"phone": "+70893502618"}
0005435487808	A2ECBA	6966 454904	ROMAN TIMOFEEV	{"email": "timofeevroman.11121964@postgrespro.ru", "phone": "+70860588035"}
0005435487809	A2ECBA	9623 773516	YURIY SMIRNOV	{"phone": "+70994236883"}
0005435487810	A2ECBA	4925 387496	VITALIY DENISOV	{"phone": "+70690979547"}
0005435487811	115B21	7339 707935	TATYANA KUZMINA	{"email": "tatyana-kuzmina-021980@postgrespro.ru", "phone": "+70936524834"}
0005435487812	115B21	1875 754230	ARTEM KUZNECOV	{"phone": "+70099519864"}
0005435487813	30F6EA	9210 921519	OLESYA EGOROVA	{"email": "egorova_olesya-041979@postgrespro.ru", "phone": "+70838474503"}
0005435487814	A49E45	2105 317155	ELENA YUDINA	{"phone": "+70622002215"}
0005435487815	7ED0BE	6154 855029	MARINA BOGDANOVA	{"email": "bogdanova_marina_08111966@postgrespro.ru", "phone": "+70579539567"}
0005435487816	E937FA	2482 391531	VIKTORIYA KOROLEVA	{"phone": "+70035150613"}
0005435487817	E937FA	7511 474757	VIKTOR FILIPPOV	{"phone": "+70076533317"}
0005435487818	830090	6578 353708	ANDREY KUZNECOV	{"email": "kuznecovandrey.21051974@postgrespro.ru", "phone": "+70352002696"}
0005435487819	9F16E7	5242 425215	MARGARITA ILINA	{"phone": "+70774430503"}
0005435487820	2BF2F0	5499 281981	IRINA KUZNECOVA	{"phone": "+70356375345"}
0005435487821	41446F	2055 996707	MATVEY BONDARENKO	{"phone": "+70180289320"}
0005435487822	544050	9661 900815	VALENTINA IVANOVA	{"email": "valentina_ivanova051965@postgrespro.ru", "phone": "+70489508627"}
0005435487823	335733	7566 806152	OLGA ROMANOVA	{"phone": "+70696369520"}
0005435487824	F4C0DD	0820 227575	FEDOR ILIN	{"phone": "+70261425439"}
0005435487825	F4C0DD	1844 395649	BORIS KISELEV	{"phone": "+70788184780"}
0005435487826	F4C0DD	7579 973484	ALEKSANDR BONDARENKO	{"email": "bondarenkoaleksandr041967@postgrespro.ru", "phone": "+70216735640"}
0005435487827	51488E	0781 144901	ALEKSANDR PETROV	{"phone": "+70619318931"}
0005435487828	4CA2C2	7649 837705	GALINA DENISOVA	{"phone": "+70167347982"}
0005435487829	771B56	6257 124869	EKATERINA SEMENOVA	{"phone": "+70463346743"}
0005435487830	ADD0F6	3760 000971	MIKHAIL BARANOV	{"phone": "+70074878647"}
0005435487831	ADD0F6	6750 675657	MAYYA KUZNECOVA	{"phone": "+70911946103"}
0005435487832	ADD0F6	8321 560693	ANTON MOROZOV	{"phone": "+70247843079"}
0005435487833	FFFCC2	5591 591013	ALEKSANDR NOVIKOV	{"phone": "+70253050473"}
0005435487834	897B70	7612 907899	EVGENIY ANTONOV	{"email": "antonov_evgeniy.11071973@postgrespro.ru", "phone": "+70669540134"}
0005435487835	9AD186	8614 988186	GALINA NIKITINA	{"email": "g.nikitina03061969@postgrespro.ru", "phone": "+70165764546"}
0005435487836	9AD186	0373 127992	NATALYA ABRAMOVA	{"phone": "+70689122133"}
0005435487837	E6FC9B	1574 739158	SERGEY FROLOV	{"email": "sergey_frolov_051971@postgrespro.ru", "phone": "+70468608593"}
0005435487838	E6FC9B	1285 372529	MARIYA LEBEDEVA	{"phone": "+70332825714"}
0005435487839	3CE651	6593 596545	MIKHAIL GAVRILOV	{"email": "gavrilov.mikhail.1960@postgrespro.ru", "phone": "+70116193375"}
0005435487840	976FCB	9676 271463	NIKOLAY MIRONOV	{"email": "n-mironov_1962@postgrespro.ru", "phone": "+70056765614"}
0005435487841	976FCB	7684 023112	YURIY ISAEV	{"phone": "+70561507613"}
0005435487842	6E33A9	9331 357524	MARIYA ALEKSANDROVA	{"phone": "+70992220277"}
0005435487843	6E33A9	2362 061984	DMITRIY ROMANOV	{"email": "d.romanov.25041977@postgrespro.ru", "phone": "+70940057219"}
0005435487844	6E33A9	4397 149394	NATALYA ZHUKOVA	{"phone": "+70982378093"}
0005435487845	4840B8	8238 868607	GALINA ANTONOVA	{"email": "gantonova_18081978@postgrespro.ru", "phone": "+70312411034"}
0005435487846	435D87	2786 912538	EVGENIY TIMOFEEV	{"email": "timofeev.e-101956@postgrespro.ru", "phone": "+70635974006"}
0005435487847	4CAEF4	5562 512642	ANNA GAVRILOVA	{"email": "gavrilova_anna-021983@postgrespro.ru", "phone": "+70688311700"}
0005435487848	BCAE0C	1190 220904	ALEKSANDR SIDOROV	{"email": "sidorovaleksandr-031955@postgrespro.ru", "phone": "+70945458129"}
0005435488030	43648E	3671 033815	ALEKSEY KOZLOV	{"phone": "+70184692371"}
0005435487849	03BFF6	9876 307319	MARIYA GRISHINA	{"email": "grishina.mariya-15061978@postgrespro.ru", "phone": "+70752859108"}
0005435487850	AB32F0	0551 622198	ANTON SOROKIN	{"phone": "+70501079849"}
0005435487851	AB32F0	9732 283585	OLGA AFANASEVA	{"email": "olga_afanaseva.07061966@postgrespro.ru", "phone": "+70842784967"}
0005435487852	363A24	5659 202390	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy_07091968@postgrespro.ru", "phone": "+70091192522"}
0005435487853	4797E2	7702 792749	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga-1970@postgrespro.ru", "phone": "+70757136064"}
0005435487854	4797E2	4404 889418	DMITRIY RODIONOV	{"email": "dmitriy_rodionov1965@postgrespro.ru", "phone": "+70262930831"}
0005435487855	7F1E75	6203 799994	ALISA POTAPOVA	{"phone": "+70092523102"}
0005435487856	7F1E75	1471 897269	ANDREY ALEKSEEV	{"email": "alekseev-andrey041985@postgrespro.ru", "phone": "+70793150867"}
0005435487857	57DBA6	6668 118436	TATYANA VOROBEVA	{"phone": "+70718678944"}
0005435487858	17A406	0403 670371	SVETLANA FILIPPOVA	{"email": "s-filippova_1963@postgrespro.ru", "phone": "+70125894498"}
0005435487859	17A406	1843 921587	MARAT GRIGOREV	{"email": "marat.grigorev121972@postgrespro.ru", "phone": "+70532598516"}
0005435487860	799F94	1230 820607	VITALIY NAZAROV	{"phone": "+70432685138"}
0005435487861	799F94	7902 188591	ILYA VOLKOV	{"phone": "+70957490664"}
0005435487862	A2396B	3948 162949	MILENA GORBUNOVA	{"email": "gorbunova.milena.30071955@postgrespro.ru", "phone": "+70791128689"}
0005435487863	A2396B	7387 612232	LIDIYA FEDOROVA	{"phone": "+70052610956"}
0005435487864	0C4F8B	1310 696374	DARYA ANDREEVA	{"phone": "+70493033181"}
0005435487865	15D5F1	5869 603571	TATYANA SERGEEVA	{"email": "tatyana.sergeeva-21081975@postgrespro.ru", "phone": "+70854853404"}
0005435487866	0945F7	4176 050687	ROZA ZAKHAROVA	{"email": "zakharova.roza-1975@postgrespro.ru", "phone": "+70845167244"}
0005435487867	8B3050	2996 967659	SERGEY PAVLOV	{"email": "spavlov.1968@postgrespro.ru", "phone": "+70386961186"}
0005435487868	90CD93	7298 399636	MARIYA LEBEDEVA	{"phone": "+70984468865"}
0005435487869	F0B9D1	7455 006943	LYUDMILA MAKAROVA	{"email": "l-makarova091980@postgrespro.ru", "phone": "+70279719128"}
0005435487870	F0B9D1	0281 104423	ELENA VASILEVA	{"phone": "+70971279050"}
0005435487871	5157F0	0614 717091	TATYANA DAVYDOVA	{"phone": "+70674709571"}
0005435487872	D8B803	8182 041215	MARGARITA SMIRNOVA	{"phone": "+70131332736"}
0005435487873	44DB05	4710 471400	ALEKSEY ZAYCEV	{"email": "zaycevaleksey111974@postgrespro.ru", "phone": "+70477575455"}
0005435487874	617FAE	6540 217231	MARAT STEPANOV	{"phone": "+70421058315"}
0005435487875	DAD3C5	5557 016661	TATYANA BELYAEVA	{"email": "tatyana_belyaeva-24021971@postgrespro.ru", "phone": "+70251981818"}
0005435487876	DAD3C5	0350 294951	VERA IVANOVA	{"email": "ivanova_vera_021969@postgrespro.ru", "phone": "+70649124943"}
0005435487877	53E7A4	8674 698719	VLADIMIR VASILEV	{"phone": "+70783144076"}
0005435487878	129338	8520 789573	IGOR PAVLOV	{"email": "pavlovigor_31051971@postgrespro.ru", "phone": "+70667612004"}
0005435487879	129338	3023 857875	LIDIYA DENISOVA	{"email": "denisova.lidiya011982@postgrespro.ru", "phone": "+70008984962"}
0005435487880	8C4C3F	4202 233134	LYUDMILA FEDOROVA	{"phone": "+70164149632"}
0005435487881	74411B	4011 508189	MARIYA NAZAROVA	{"email": "nazarova-mariya.061972@postgrespro.ru", "phone": "+70092565536"}
0005435487882	74411B	8432 591934	ANNA VASILEVA	{"email": "vasilevaa_1979@postgrespro.ru", "phone": "+70182866599"}
0005435487883	74411B	5834 131046	MARIYA AFANASEVA	{"phone": "+70726909195"}
0005435487884	0C4B99	1871 186037	DMITRIY ILIN	{"phone": "+70087645951"}
0005435487885	D21A01	7230 699795	ALEKSANDR IVANOV	{"phone": "+70433823805"}
0005435487886	D21A01	4899 933608	ELENA SEMENOVA	{"phone": "+70356514684"}
0005435487887	D21A01	4622 368672	ANATOLIY MOROZOV	{"email": "morozov-anatoliy.1976@postgrespro.ru", "phone": "+70184910021"}
0005435487888	218F13	6838 024503	ALEKSEY CHERNOV	{"phone": "+70004488470"}
0005435488001	7D1B03	8538 830546	SERGEY NIKITIN	{"phone": "+70624277589"}
0005435487889	46A9AB	3915 662809	TATYANA MATVEEVA	{"email": "tatyana-matveeva_1979@postgrespro.ru", "phone": "+70806618935"}
0005435487890	3E1DC4	0191 924064	ALEKSANDR GORBUNOV	{"email": "gorbunov.a.20101983@postgrespro.ru", "phone": "+70447140369"}
0005435487891	C96DDB	3275 790956	NADEZHDA STEPANOVA	{"phone": "+70728142582"}
0005435487892	8EFF3B	0210 148664	VLADIMIR TIMOFEEV	{"phone": "+70864272881"}
0005435487893	8EFF3B	4741 492186	MIKHAIL FROLOV	{"email": "m-frolov_20061963@postgrespro.ru", "phone": "+70401901310"}
0005435487894	FF67B5	8833 000457	NADEZHDA ANTONOVA	{"email": "antonova.n1973@postgrespro.ru", "phone": "+70418998523"}
0005435487895	FF67B5	3117 287539	VALENTINA FILATOVA	{"email": "filatova_valentina-1982@postgrespro.ru", "phone": "+70811586472"}
0005435487896	E3B103	2299 329769	ANDREY ILIN	{"email": "ailin1968@postgrespro.ru", "phone": "+70449805655"}
0005435487897	E3B103	1303 522940	ALEKSANDR VASILEV	{"email": "aleksandr.vasilev.1974@postgrespro.ru", "phone": "+70872856665"}
0005435487898	E3B103	0975 740342	MIKHAIL SEMENOV	{"email": "m-semenov_051978@postgrespro.ru", "phone": "+70756908377"}
0005435487899	BF0919	6354 436848	DARYA SAVELEVA	{"phone": "+70301220613"}
0005435487900	BF0919	8841 371420	NATALYA MELNIKOVA	{"phone": "+70599137510"}
0005435487901	0EC772	4535 234065	VALENTINA VASILEVA	{"email": "vasileva.valentina-13071973@postgrespro.ru", "phone": "+70650920065"}
0005435487902	0EC772	2841 162271	TATYANA AKIMOVA	{"email": "t.akimova.1968@postgrespro.ru", "phone": "+70785142273"}
0005435487903	D9A372	3093 831555	MARIYA BELOVA	{"phone": "+70844695888"}
0005435487904	D08353	6638 858568	NINA NAUMOVA	{"email": "naumova-nina-1971@postgrespro.ru", "phone": "+70572600495"}
0005435487905	0F4CAA	7135 176604	ANDREY OSIPOV	{"phone": "+70956888992"}
0005435487906	AA6247	0210 040792	ANDREY VASILEV	{"email": "vasilev-a.101968@postgrespro.ru", "phone": "+70568915861"}
0005435487907	21459E	7254 435307	ANTONINA IVANOVA	{"email": "ivanova.antonina_031968@postgrespro.ru", "phone": "+70615273049"}
0005435487908	21459E	3899 917357	IVAN TIKHONOV	{"email": "ivan_tikhonov111984@postgrespro.ru", "phone": "+70554500417"}
0005435487909	C15EAE	0781 096538	MARINA KUZNECOVA	{"phone": "+70704269024"}
0005435487910	6B746F	2408 120201	IRAIDA ROMANOVA	{"email": "i.romanova-09101974@postgrespro.ru", "phone": "+70673882927"}
0005435487911	6B746F	4380 609539	ELENA ANISIMOVA	{"email": "eanisimova-1967@postgrespro.ru", "phone": "+70661942028"}
0005435487912	18A534	7261 432931	VLADIMIR SERGEEV	{"email": "sergeev.v-011960@postgrespro.ru", "phone": "+70695258119"}
0005435487913	85A3B0	1155 038942	ALEKSEY GAVRILOV	{"email": "gavrilov-a.1974@postgrespro.ru", "phone": "+70355893807"}
0005435487914	F3A647	1371 912815	ALEKSEY NIKITIN	{"phone": "+70184151360"}
0005435487915	7448E4	8646 295032	EMMA RYABOVA	{"email": "emma_ryabova-24081970@postgrespro.ru", "phone": "+70555095967"}
0005435487916	936709	7833 248421	GALINA POPOVA	{"phone": "+70627753281"}
0005435487917	936709	6865 238848	EVGENIY TIKHONOV	{"email": "e_tikhonov_1981@postgrespro.ru", "phone": "+70769781043"}
0005435487918	227998	4843 283977	IVAN MAKAROV	{"phone": "+70367564209"}
0005435487919	0FBD9D	9938 417493	VLADIMIR BELOV	{"phone": "+70066717536"}
0005435487920	F59004	4458 551635	ALEKSANDR VASILEV	{"phone": "+70464732851"}
0005435487921	F59004	4602 005201	RUSLAN MOROZOV	{"phone": "+70524778553"}
0005435487922	F59004	6947 285019	YURIY FEDOTOV	{"email": "y-fedotov_1970@postgrespro.ru", "phone": "+70295502179"}
0005435487923	B60336	6380 805521	SERGEY ZAYCEV	{"email": "sergey_zaycev_1971@postgrespro.ru", "phone": "+70105328802"}
0005435487924	B60336	1698 540131	KONSTANTIN SOLOVEV	{"phone": "+70281106369"}
0005435487925	BDA2D9	1535 868176	NINA RYABOVA	{"email": "ninaryabova_21071972@postgrespro.ru", "phone": "+70339817554"}
0005435487926	47C85A	0724 693137	LIDIYA POPOVA	{"email": "popovalidiya.1974@postgrespro.ru", "phone": "+70653187408"}
0005435487927	407728	4952 256959	VASILIY ROMANOV	{"email": "v.romanov_01021954@postgrespro.ru", "phone": "+70522329538"}
0005435487928	9E5BF1	9883 253863	VLADIMIR ZHURAVLEV	{"phone": "+70119797540"}
0005435487929	9E5BF1	2357 628502	ALEKSANDR ZAYCEV	{"phone": "+70720106582"}
0005435487930	EC5D9D	2771 769908	VYACHESLAV OSIPOV	{"email": "v-osipov.07061988@postgrespro.ru", "phone": "+70977802847"}
0005435487931	20F239	5045 423407	MARGARITA SAVELEVA	{"phone": "+70619283846"}
0005435487932	20F239	3842 335383	RUSLAN ALEKSANDROV	{"email": "aleksandrov.r031974@postgrespro.ru", "phone": "+70926314042"}
0005435487933	F06E21	9438 492713	NATALIYA ZAKHAROVA	{"email": "n_zakharova-1972@postgrespro.ru", "phone": "+70144318517"}
0005435487934	03F0DD	6648 872112	VALERIY ILIN	{"phone": "+70267678279"}
0005435487935	BAF157	2808 213689	MAKSIM BONDARENKO	{"phone": "+70374172467"}
0005435487936	8AA2A3	7206 088727	VALENTINA KALININA	{"phone": "+70052312510"}
0005435487937	B1CAB3	5436 247986	ELENA VOLKOVA	{"email": "e_volkova1969@postgrespro.ru", "phone": "+70581401897"}
0005435487938	00A9B6	3653 632177	ALEKSANDR VLASOV	{"email": "vlasov.aleksandr26111978@postgrespro.ru", "phone": "+70919821602"}
0005435487939	390AC4	3924 712064	ELENA ALEKSANDROVA	{"phone": "+70821612627"}
0005435487940	390AC4	8060 710987	GALINA MAKAROVA	{"phone": "+70575089769"}
0005435487941	71FA0C	7665 673386	OLGA ORLOVA	{"email": "orlova-olga_051973@postgrespro.ru", "phone": "+70923222588"}
0005435487942	71FA0C	6778 367461	ALEKSANDR BORISOV	{"email": "a.borisov.20051979@postgrespro.ru", "phone": "+70168978073"}
0005435487943	784F9D	6675 238575	NATALYA ZOTOVA	{"email": "zotovan-03051974@postgrespro.ru", "phone": "+70896142901"}
0005435487944	784F9D	2281 292508	ARKADIY GORBUNOV	{"email": "arkadiy_gorbunov_1973@postgrespro.ru", "phone": "+70255921535"}
0005435487945	3AB701	5869 787301	NATALYA SAVELEVA	{"email": "savelevanatalya-051984@postgrespro.ru", "phone": "+70044608957"}
0005435487946	46CA91	5479 417672	EVGENIY KONOVALOV	{"email": "e_konovalov1978@postgrespro.ru", "phone": "+70467704449"}
0005435487947	6182F6	4905 034820	LYUBOV ERMAKOVA	{"phone": "+70443934872"}
0005435487948	6182F6	2230 978475	VIKTOR SMIRNOV	{"email": "vsmirnov-21111972@postgrespro.ru", "phone": "+70723640450"}
0005435487949	0ACFB6	9627 565506	DMITRIY SIDOROV	{"email": "d.sidorov031976@postgrespro.ru", "phone": "+70176365747"}
0005435487950	0ACFB6	5275 414217	VASILIY ALEKSEEV	{"phone": "+70880901661"}
0005435487951	CDACB5	2131 032885	SOFYA SOKOLOVA	{"phone": "+70519186412"}
0005435487952	37C338	5489 973571	SERGEY FROLOV	{"phone": "+70701256005"}
0005435487953	6A2632	4998 453617	OLGA KULIKOVA	{"phone": "+70360865876"}
0005435487954	7F5229	0395 521547	VALENTINA YUDINA	{"phone": "+70117325608"}
0005435487955	5CF7FB	0123 516944	KIRILL SOLOVEV	{"phone": "+70856814656"}
0005435487956	2864B7	6545 041602	VIKTOR NIKOLAEV	{"phone": "+70998920633"}
0005435487957	EC0CC9	6203 325503	POLINA KOVALEVA	{"phone": "+70990599214"}
0005435487958	EC0CC9	4528 870006	MIKHAIL DAVYDOV	{"email": "davydov-m-011972@postgrespro.ru", "phone": "+70165525247"}
0005435487959	326A43	0195 177111	TATYANA POPOVA	{"phone": "+70703909413"}
0005435487960	7A2CB3	8625 034336	VLADIMIR SOKOLOV	{"email": "sokolovvladimir-041962@postgrespro.ru", "phone": "+70385201801"}
0005435487961	11980F	6906 837687	OLEG SIDOROV	{"phone": "+70303584558"}
0005435487962	A8E9BE	8510 747468	LYUBOV NIKOLAEVA	{"phone": "+70792241908"}
0005435487963	A8E9BE	8894 291098	LILIYA MEDVEDEVA	{"email": "l.medvedeva011974@postgrespro.ru", "phone": "+70771280726"}
0005435487964	366A5B	3076 174041	MARIYA VASILEVA	{"email": "mariya-vasileva-25111971@postgrespro.ru", "phone": "+70904686858"}
0005435487965	366A5B	2681 698010	VALENTINA VASILEVA	{"email": "v_vasileva21011971@postgrespro.ru", "phone": "+70964368477"}
0005435487966	366A5B	1415 020471	ALEKSANDR BARANOV	{"phone": "+70049122515"}
0005435487967	612FE5	4723 989497	OLEG SAVELEV	{"email": "savelev_o-06061973@postgrespro.ru", "phone": "+70847803972"}
0005435487968	9EB1C6	8349 920856	VERA ZAYCEVA	{"phone": "+70000709820"}
0005435487969	9EB1C6	7017 988318	ZHANNA KARPOVA	{"email": "z_karpova_1970@postgrespro.ru", "phone": "+70998364227"}
0005435487970	BB632D	8519 900568	ALBERT MARTYNOV	{"email": "martynova_1968@postgrespro.ru", "phone": "+70971115698"}
0005435487971	BB632D	4528 817422	VLADIMIR FEDOROV	{"email": "fedorov_vladimir-28101975@postgrespro.ru", "phone": "+70117611901"}
0005435487972	0D72FB	0119 815032	DENIS POPOV	{"phone": "+70962417331"}
0005435487973	6F161B	5698 603148	OLGA SEMENOVA	{"phone": "+70987476796"}
0005435487974	6F161B	9830 046471	GRIGORIY MAKAROV	{"email": "g-makarov_20021974@postgrespro.ru", "phone": "+70537711473"}
0005435487975	65B2B9	4682 375757	ANDREY POPOV	{"phone": "+70773175723"}
0005435487976	65B2B9	2788 447562	SERGEY MAKSIMOV	{"email": "maksimov_sergey_1974@postgrespro.ru", "phone": "+70406508494"}
0005435487977	14FB7C	8737 972827	IGOR NOVIKOV	{"email": "i_novikov.20051971@postgrespro.ru", "phone": "+70500839489"}
0005435487978	50FAA4	2050 027599	NINA ANDREEVA	{"email": "nandreeva_1964@postgrespro.ru", "phone": "+70005877774"}
0005435487979	F588AF	6873 299404	ILYA NIKITIN	{"phone": "+70426990730"}
0005435487980	4E020D	5880 398244	IRAIDA ZHUKOVA	{"email": "i-zhukova_1980@postgrespro.ru", "phone": "+70092256969"}
0005435487981	A69D12	2174 791360	NATALYA POPOVA	{"phone": "+70923935692"}
0005435487982	893F6F	6937 141047	EKATERINA YAKOVLEVA	{"email": "yakovleva.e-06101971@postgrespro.ru", "phone": "+70956552381"}
0005435487983	6915A5	4283 724664	ALEKSEY FEDOROV	{"email": "fedorovaleksey_061975@postgrespro.ru", "phone": "+70797738868"}
0005435487984	6915A5	0589 620098	ANTONINA SERGEEVA	{"phone": "+70920910938"}
0005435487985	AB5011	0413 683930	MIKHAIL MEDVEDEV	{"email": "medvedev.mikhail1971@postgrespro.ru", "phone": "+70047566618"}
0005435487986	5C4B5B	0215 184065	NADEZHDA AFANASEVA	{"phone": "+70911527916"}
0005435487987	BA640B	2700 657827	VALENTINA FROLOVA	{"email": "valentina-frolova011982@postgrespro.ru", "phone": "+70692940934"}
0005435487988	EA01B1	1339 226281	VASILIY AFANASEV	{"phone": "+70072245818"}
0005435487989	9F2A17	4337 663853	YURIY ILIN	{"phone": "+70191576511"}
0005435487990	896058	3172 104793	TATYANA PAVLOVA	{"email": "pavlova.t27081958@postgrespro.ru", "phone": "+70714419066"}
0005435487991	674AE7	7354 738296	MARIYA SCHERBAKOVA	{"phone": "+70414258977"}
0005435487992	92895A	7705 667872	NATALYA FOMINA	{"phone": "+70649756442"}
0005435487993	92895A	4654 495366	TATYANA MIRONOVA	{"phone": "+70793866270"}
0005435487994	59A6B0	4477 837594	VLADIMIR FEDOTOV	{"phone": "+70102058170"}
0005435487995	759DE7	6796 406151	MIKHAIL NAUMOV	{"email": "mikhail.naumov.031976@postgrespro.ru", "phone": "+70492229768"}
0005435487996	9BA0A5	1765 536379	YURIY KARPOV	{"email": "yuriy-karpov.091971@postgrespro.ru", "phone": "+70334929751"}
0005435487997	6C7AC6	1343 923334	VASILIY KARPOV	{"email": "v_karpov-1975@postgrespro.ru", "phone": "+70161206166"}
0005435487998	6C7AC6	1251 431164	ANATOLIY MIKHAYLOV	{"email": "anatoliymikhaylov_1981@postgrespro.ru", "phone": "+70495689851"}
0005435487999	7D1B03	6439 410089	LYUBOV NAZAROVA	{"phone": "+70275105393"}
0005435488000	7D1B03	0805 434863	NIKOLAY ZAKHAROV	{"email": "n-zakharov_09011964@postgrespro.ru", "phone": "+70439642451"}
0005435488002	C030BC	6201 630876	TAISA YAKOVLEVA	{"phone": "+70715770665"}
0005435488003	C7CCB9	4284 469920	ANNA ANTONOVA	{"email": "antonova.a.10061973@postgrespro.ru", "phone": "+70541922277"}
0005435488004	C7CCB9	2413 661597	SABINA DANILOVA	{"phone": "+70143046785"}
0005435488005	C7CCB9	7735 439272	ALEKSEY GRIGOREV	{"email": "alekseygrigorev.091976@postgrespro.ru", "phone": "+70242267588"}
0005435488006	3E7256	2996 865836	VITALIY GUSEV	{"phone": "+70642739043"}
0005435488007	A88911	9673 086620	GALINA POPOVA	{"email": "g.popova.10121966@postgrespro.ru", "phone": "+70362842488"}
0005435488008	39BAD7	5913 754353	GULNAZ KOROLEVA	{"phone": "+70478141783"}
0005435488009	39BAD7	2871 358336	TAMARA SERGEEVA	{"phone": "+70433651852"}
0005435488010	A1A811	4924 920894	ANDREY ZAYCEV	{"phone": "+70148139578"}
0005435488011	A1A811	9458 981652	KRISTINA KOVALEVA	{"email": "k.kovaleva.041960@postgrespro.ru", "phone": "+70396151886"}
0005435488012	243B21	8478 038507	YULIYA NAZAROVA	{"phone": "+70229403966"}
0005435488013	5C5A13	2271 071292	OLGA ZOTOVA	{"email": "zotova-olga_1980@postgrespro.ru", "phone": "+70035685960"}
0005435488014	14B602	6052 918054	VALERIYA MAKSIMOVA	{"phone": "+70422004728"}
0005435488015	14B602	3672 363216	ALEKSANDR MATVEEV	{"phone": "+70023454413"}
0005435488016	C51301	9335 812533	ALEKSEY MELNIKOV	{"phone": "+70480606884"}
0005435488017	C51301	8267 122516	IRINA NOVIKOVA	{"email": "novikovairina_1968@postgrespro.ru", "phone": "+70510884486"}
0005435488018	4AD1DB	8731 171514	NATALYA BOGDANOVA	{"phone": "+70695553407"}
0005435488019	4AD1DB	8154 014874	ALENA IVANOVA	{"phone": "+70892372392"}
0005435488020	A325A8	0608 418862	VALERIYA MIRONOVA	{"email": "valeriya-mironova.1968@postgrespro.ru", "phone": "+70720533788"}
0005435488021	EA56A0	6545 071800	MARINA ORLOVA	{"email": "orlovamarina-1974@postgrespro.ru", "phone": "+70698101957"}
0005435488022	EA56A0	8415 794829	OLGA KOZLOVA	{"phone": "+70735545524"}
0005435488023	C0B749	7971 758587	SANIYA DMITRIEVA	{"phone": "+70464244702"}
0005435488024	5AE961	5152 136140	LYUDMILA MASLOVA	{"phone": "+70157625990"}
0005435488025	5AE961	9088 563019	TATYANA POTAPOVA	{"phone": "+70588155145"}
0005435488026	BC2F5C	5782 520952	LYUDMILA TIMOFEEVA	{"phone": "+70720390442"}
0005435488027	975349	1856 659879	ELENA ROMANOVA	{"email": "romanova-e27111974@postgrespro.ru", "phone": "+70457824558"}
0005435488028	55C72D	7042 128073	VLADIMIR VLASOV	{"email": "vlasov-v-1977@postgrespro.ru", "phone": "+70970218350"}
0005435488029	43648E	8014 533327	SOFYA TITOVA	{"phone": "+70345469126"}
0005435488031	43648E	8425 270139	RAISA KUDRYASHOVA	{"email": "kudryashovar-1971@postgrespro.ru", "phone": "+70009465590"}
0005435488032	4E81EC	5265 410057	ELVIRA GORBUNOVA	{"email": "gorbunova-e051974@postgrespro.ru", "phone": "+70508292265"}
0005435488033	BAC83B	4430 047859	GALINA VOLKOVA	{"phone": "+70808651627"}
0005435488034	BAC83B	1949 259934	EKATERINA KISELEVA	{"email": "kiseleva.e_1968@postgrespro.ru", "phone": "+70730075314"}
0005435488035	BAC83B	0043 104326	TAMARA ANTONOVA	{"email": "tamaraantonova041976@postgrespro.ru", "phone": "+70780565752"}
0005435488036	A8CCED	9297 827575	DARYA POPOVA	{"email": "darya-popova.22061963@postgrespro.ru", "phone": "+70639895624"}
0005435488037	A8CCED	3441 802450	NINA VLASOVA	{"email": "nina_vlasova.18061975@postgrespro.ru", "phone": "+70792440650"}
0005435488038	12F469	9491 001580	PETR BONDARENKO	{"email": "pbondarenko27041953@postgrespro.ru", "phone": "+70750852175"}
0005435488039	B2D8E3	7240 921516	TAISIYA POPOVA	{"phone": "+70574307748"}
0005435488040	B2D8E3	8938 273319	VALERIYA TIKHONOVA	{"phone": "+70513522952"}
0005435488041	B2D8E3	8431 819367	ALEKSANDR FEDOTOV	{"email": "fedotov_aleksandr-011965@postgrespro.ru", "phone": "+70024771760"}
0005435488042	98F69C	7179 588663	ALEVTINA BELOVA	{"phone": "+70583772758"}
0005435488043	98F69C	3981 949360	RAFAIL DAVYDOV	{"phone": "+70350322179"}
0005435488044	98F69C	0202 117920	VLADIMIR IVANOV	{"phone": "+70411957766"}
0005435488045	4C3D5B	4267 482082	VLADISLAV VASILEV	{"phone": "+70988869105"}
0005435488046	BF1F22	6364 055585	ELENA ROMANOVA	{"email": "romanova-elena27091981@postgrespro.ru", "phone": "+70052971850"}
0005435488047	DD9E93	1901 647011	TATYANA KUZNECOVA	{"email": "kuznecovat-1978@postgrespro.ru", "phone": "+70036245252"}
0005435488048	3177FE	8310 899797	KIRILL KOZLOV	{"email": "kkozlov_06021963@postgrespro.ru", "phone": "+70177691655"}
0005435488049	3177FE	8474 269629	EVGENIY GERASIMOV	{"email": "e_gerasimov.1982@postgrespro.ru", "phone": "+70477311121"}
0005435488050	D55711	9423 963469	ANGELINA BOGDANOVA	{"phone": "+70132533924"}
0005435488051	FD9D41	1493 756227	MARGARITA IVANOVA	{"phone": "+70907137286"}
0005435488052	6DD3BE	4520 959589	ILYA SOROKIN	{"phone": "+70746772996"}
0005435488053	BCF35C	4846 428419	NINA ZHURAVLEVA	{"email": "zhuravlevan21051976@postgrespro.ru", "phone": "+70485815629"}
0005435488054	B0DC25	5746 814634	FAIL TIKHONOV	{"email": "tikhonov_f_1972@postgrespro.ru", "phone": "+70823556957"}
0005435488055	147A9C	6516 390502	SERGEY KARPOV	{"phone": "+70903012758"}
0005435488056	BAEDA9	2958 915728	EVDOKIYA KUZMINA	{"email": "evdokiya_kuzmina1975@postgrespro.ru", "phone": "+70349224920"}
0005435488057	6567E1	4392 313070	ALEVTINA NIKOLAEVA	{"phone": "+70635695522"}
0005435488058	6567E1	6377 896808	ANTON NIKITIN	{"phone": "+70413577214"}
0005435488059	C09FA4	8986 558679	GALINA TIMOFEEVA	{"phone": "+70272816470"}
0005435488060	C81E15	0323 041675	ANDREY BELOV	{"email": "belov_andrey-25061977@postgrespro.ru", "phone": "+70602153117"}
0005435488061	D0E93C	6541 839415	TATYANA KAZAKOVA	{"email": "kazakova.t.10021968@postgrespro.ru", "phone": "+70493421229"}
0005435488062	D0E93C	1899 485309	EVGENIY MEDVEDEV	{"phone": "+70955634537"}
0005435488063	9D74E3	0161 926133	DMITRIY ZAYCEV	{"email": "zaycev.d.081974@postgrespro.ru", "phone": "+70580185822"}
0005435488064	8AE1BA	2415 634856	MAKSIM MOROZOV	{"email": "mmorozov.061980@postgrespro.ru", "phone": "+70480940395"}
0005435488065	7F2F28	8685 163498	LYUDMILA KUZNECOVA	{"email": "kuznecoval.111968@postgrespro.ru", "phone": "+70495579253"}
0005435488066	7F2F28	0211 329520	VALENTINA VOROBEVA	{"email": "valentina_vorobeva-081974@postgrespro.ru", "phone": "+70279772071"}
0005435488067	0D06A9	5304 803986	ALEKSANDR IVANOV	{"email": "ivanov.aleksandr051972@postgrespro.ru", "phone": "+70934002419"}
0005435488068	1685CC	6985 415144	OLGA EGOROVA	{"email": "olgaegorova_111966@postgrespro.ru", "phone": "+70846966813"}
0005435488069	996AFF	6500 933919	VENERA ARKHIPOVA	{"email": "v.arkhipova101967@postgrespro.ru", "phone": "+70729863885"}
0005435488070	996AFF	0132 233518	SERGEY KULIKOV	{"email": "kulikov.s.07071972@postgrespro.ru", "phone": "+70536660773"}
0005435488071	382CE6	5171 515364	ANTONINA ZAYCEVA	{"phone": "+70208710503"}
0005435488072	50BD6D	7534 483497	ALEKSEY KUZNECOV	{"email": "kuznecova_05091976@postgrespro.ru", "phone": "+70163923055"}
0005435488073	50BD6D	5668 633360	LEONID TARASOV	{"email": "tarasov-leonid_011960@postgrespro.ru", "phone": "+70935790136"}
0005435488074	F5A311	6095 679019	VLADIMIR MATVEEV	{"phone": "+70394770596"}
0005435488075	320C52	6710 738734	ALEKSEY EGOROV	{"email": "a-egorov.15101970@postgrespro.ru", "phone": "+70872969490"}
0005435488076	70BA81	0547 169058	ELENA KONOVALOVA	{"email": "konovalova.e15111966@postgrespro.ru", "phone": "+70384830652"}
0005435488077	E72423	6021 850839	IRINA GERASIMOVA	{"phone": "+70175520669"}
0005435488078	E72423	7597 560693	IRINA KISELEVA	{"email": "kiseleva_irina-101978@postgrespro.ru", "phone": "+70070370386"}
0005435488079	EBFB8B	6474 154204	TATYANA YUDINA	{"phone": "+70305437000"}
0005435488080	EBFB8B	2500 434158	ANDREY MIKHAYLOV	{"phone": "+70067679809"}
0005435488081	38E0EC	6197 702375	YULIYA FILATOVA	{"phone": "+70197007311"}
0005435488082	DA5D0D	5480 294815	YURIY KUDRYASHOV	{"email": "yuriy_kudryashov_1975@postgrespro.ru", "phone": "+70647909817"}
0005435488083	48E0BC	8699 533640	OLGA NIKITINA	{"email": "nikitina-o.1971@postgrespro.ru", "phone": "+70121375878"}
0005435488084	6DA184	2551 000610	IRINA DMITRIEVA	{"phone": "+70453287587"}
0005435488085	9CB66A	8040 348106	NIKITA SERGEEV	{"email": "nikita.sergeev-29111985@postgrespro.ru", "phone": "+70068078525"}
0005435488086	9CB66A	9319 626066	EVGENIY KUZNECOV	{"phone": "+70176089666"}
0005435488087	0776E3	4623 795314	NIKOLAY ALEKSANDROV	{"email": "aleksandrov-n_1975@postgrespro.ru", "phone": "+70248516289"}
0005435488088	70AA98	6144 772260	MIROSLAV DENISOV	{"phone": "+70169569075"}
0005435488089	EAAF19	9244 787802	LIDIYA NIKITINA	{"email": "nikitina_l_15061976@postgrespro.ru", "phone": "+70933983751"}
0005435488090	45FFCE	1707 193842	MILENA OSIPOVA	{"email": "milena.osipova_061982@postgrespro.ru", "phone": "+70566812987"}
0005435488091	45FFCE	1797 798131	NATALYA VOLKOVA	{"email": "volkova.n.021972@postgrespro.ru", "phone": "+70877496752"}
0005435488092	FA5EDA	3435 537702	OLEG BORISOV	{"email": "borisov.o031964@postgrespro.ru", "phone": "+70368974343"}
0005435488093	FA5EDA	4416 295433	GALINA MIKHAYLOVA	{"phone": "+70757901871"}
0005435488094	7E75DC	3161 012571	ANATOLIY KUZNECOV	{"phone": "+70110584064"}
0005435488095	7E75DC	1300 289274	TATYANA SIDOROVA	{"email": "tsidorova-1967@postgrespro.ru", "phone": "+70093657990"}
0005435488096	FB7986	5789 952702	GERMAN FOMIN	{"phone": "+70008086618"}
0005435488097	1698A6	1217 592480	RAVIL ZHURAVLEV	{"email": "r_zhuravlev.24071990@postgrespro.ru", "phone": "+70044675668"}
0005435488098	1698A6	5094 095668	VIKTORIYA FADEEVA	{"phone": "+70155553487"}
0005435488099	C26532	3206 254907	ALEKSANDRA RYABOVA	{"phone": "+70319084836"}
0005435488100	E06728	6101 828703	LYUDMILA MAKAROVA	{"email": "makarova_l-28111976@postgrespro.ru", "phone": "+70970527160"}
0005435488101	E06728	6875 116802	ALEKSEY KOZLOV	{"email": "aleksey.kozlov-061962@postgrespro.ru", "phone": "+70790367036"}
0005435488102	76D4CD	8342 136179	INNA PAVLOVA	{"email": "pavlova.i1969@postgrespro.ru", "phone": "+70913171083"}
0005435488103	EEC597	5675 123465	EVGENIY NAZAROV	{"phone": "+70832323591"}
0005435488104	EEC597	3447 586152	TATYANA KRASNOVA	{"phone": "+70268026609"}
0005435488105	175C2E	4771 483620	ALEKSANDR SERGEEV	{"email": "sergeev.a.1959@postgrespro.ru", "phone": "+70401811885"}
0005435488106	175C2E	4560 962419	TATYANA TARASOVA	{"phone": "+70531288373"}
0005435488107	2C9E99	7112 852676	ALEKSANDR KOZLOV	{"email": "kozlov-a.021959@postgrespro.ru", "phone": "+70285486340"}
0005435488108	2C9E99	0066 157395	RAISA ARKHIPOVA	{"email": "raisa_arkhipova08061972@postgrespro.ru", "phone": "+70644718954"}
0005435488109	342A7E	6641 985759	IGOR SEMENOV	{"email": "semenov-i-031984@postgrespro.ru", "phone": "+70652715713"}
0005435488110	E15063	6954 160463	IGOR ALEKSEEV	{"phone": "+70153254629"}
0005435488111	063F8F	4587 315011	ROMAN DMITRIEV	{"email": "rdmitriev.091966@postgrespro.ru", "phone": "+70519486126"}
0005435488112	39F84E	1239 581280	IRINA ZHURAVLEVA	{"email": "zhuravlevairina.091963@postgrespro.ru", "phone": "+70899314802"}
0005435488113	46590A	7957 882064	NELLI ZAKHAROVA	{"phone": "+70425428632"}
0005435488114	869F42	7629 666418	ANNA FEDOROVA	{"email": "a-fedorova-1983@postgrespro.ru", "phone": "+70084506766"}
0005435488115	FDA100	0914 635055	LYUBOV ORLOVA	{"email": "orloval-111974@postgrespro.ru", "phone": "+70758873207"}
0005435488116	3506AC	5633 562273	LYUDMILA POTAPOVA	{"email": "potapoval.22101965@postgrespro.ru", "phone": "+70796340902"}
0005435488117	3506AC	0861 605017	MARINA BARANOVA	{"email": "baranova_marina.041975@postgrespro.ru", "phone": "+70510929903"}
0005435488118	3506AC	9477 775843	YULIYA GAVRILOVA	{"phone": "+70211902741"}
0005435488119	684935	4353 727054	ALEKSANDR ROMANOV	{"phone": "+70509643665"}
0005435488120	F39740	6028 601053	SVETLANA ZAKHAROVA	{"phone": "+70125515384"}
0005435488121	F39740	1975 165271	FAINA GORBUNOVA	{"email": "f-gorbunova.1966@postgrespro.ru", "phone": "+70419829230"}
0005435488122	F25262	6084 227449	NINA MAKAROVA	{"phone": "+70388512947"}
0005435488123	F25262	8734 570368	IVAN VASILEV	{"phone": "+70146317406"}
0005435488124	338001	4223 078260	OLESYA ISAEVA	{"email": "isaeva_o-1974@postgrespro.ru", "phone": "+70825288210"}
0005435488125	338001	6913 689887	VALENTIN GUSEV	{"email": "gusev-valentin_03121964@postgrespro.ru", "phone": "+70850489958"}
0005435488126	351ED8	2207 202437	EVGENIY KUZMIN	{"phone": "+70783657118"}
0005435488127	351ED8	5105 720096	TATYANA SEMENOVA	{"email": "semenova-tatyana_081967@postgrespro.ru", "phone": "+70982217906"}
0005435488128	351ED8	7517 751993	OLEG MATVEEV	{"phone": "+70248819217"}
0005435488129	1DB565	8132 643508	NIKOLAY ANDREEV	{"email": "andreev-nikolay.01071971@postgrespro.ru", "phone": "+70235553102"}
0005435488130	1DB565	2136 007086	IVAN OSIPOV	{"phone": "+70180091412"}
0005435488131	5C8D11	5358 449574	KRISTINA TROFIMOVA	{"email": "trofimova-kristina-08091965@postgrespro.ru", "phone": "+70665836794"}
0005435488132	9C7077	7560 224417	AZAT ZAKHAROV	{"phone": "+70300719855"}
0005435488133	9C7077	6654 104487	VALERIY ANTONOV	{"email": "valeriy.antonov_031976@postgrespro.ru", "phone": "+70867645062"}
0005435488134	284D0B	2621 178327	EVGENIY SERGEEV	{"email": "sergeev.evgeniy.31071971@postgrespro.ru", "phone": "+70228412525"}
0005435488135	22511B	9217 059409	ANNA NIKOLAEVA	{"email": "nikolaeva-a_1977@postgrespro.ru", "phone": "+70151922343"}
0005435488136	732F52	2000 527286	BORIS FEDOTOV	{"phone": "+70663629314"}
0005435488137	9C8320	8488 714360	YULIYA PETROVA	{"email": "ypetrova.1971@postgrespro.ru", "phone": "+70325019901"}
0005435488138	A7091F	9741 583866	ALENA NESTEROVA	{"phone": "+70766906952"}
0005435488139	D2625D	2670 136768	DMITRIY PETROV	{"email": "d_petrov05101966@postgrespro.ru", "phone": "+70239225517"}
0005435488140	1D7458	2501 689891	VALENTINA ANISIMOVA	{"email": "anisimovav111983@postgrespro.ru", "phone": "+70512351439"}
0005435488141	ECEE13	9786 668562	VALENTINA ZAKHAROVA	{"email": "zakharovav.111984@postgrespro.ru", "phone": "+70420010032"}
0005435488142	5A0DF7	8790 723657	NINA KUZNECOVA	{"phone": "+70054488176"}
0005435488143	5A0DF7	9733 301935	VIKTOR VOROBEV	{"phone": "+70469977136"}
0005435488144	F1FA28	8607 177279	VALENTINA RODIONOVA	{"phone": "+70713121554"}
0005435488145	F1FA28	2980 403891	DANILA VASILEV	{"phone": "+70521457841"}
0005435488146	F1FA28	5111 465655	KSENIYA YAKOVLEVA	{"phone": "+70496420449"}
0005435488147	42967A	9143 395305	NINA MOROZOVA	{"email": "nina_morozova-1970@postgrespro.ru", "phone": "+70493301006"}
0005435488148	305A28	9652 439522	KONSTANTIN KOZLOV	{"email": "kozlovk081977@postgrespro.ru", "phone": "+70924008228"}
0005435488149	305A28	5752 552425	ALEKSANDR GAVRILOV	{"email": "a.gavrilov-17121977@postgrespro.ru", "phone": "+70634796293"}
0005435488150	B23E5E	5813 227532	TAMARA NESTEROVA	{"email": "nesterova-t-061986@postgrespro.ru", "phone": "+70262009114"}
0005435488151	B23E5E	0948 982150	YULIYA ALEKSEEVA	{"email": "y-alekseeva-031972@postgrespro.ru", "phone": "+70400116801"}
0005435488152	D02D9B	6664 152821	ELENA DMITRIEVA	{"email": "e-dmitrieva_1966@postgrespro.ru", "phone": "+70571896517"}
0005435488153	0D1D38	7560 802944	NATALYA MOROZOVA	{"email": "n_morozova.24021965@postgrespro.ru", "phone": "+70702068493"}
0005435488154	960DD9	3120 922443	EVGENIY ZHURAVLEV	{"phone": "+70251132824"}
0005435488155	90A48F	4980 446942	ALEKSANDR ZHURAVLEV	{"phone": "+70356192687"}
0005435488156	928727	7307 607856	ALEKSANDR KUZNECOV	{"email": "a-kuznecov_071968@postgrespro.ru", "phone": "+70813185864"}
0005435488157	928727	0244 153907	ANDREY OSIPOV	{"phone": "+70659276731"}
0005435488158	D9F14E	7133 218273	ARTUR DMITRIEV	{"email": "artur_dmitriev_1971@postgrespro.ru", "phone": "+70488846719"}
0005435488159	D9F14E	5404 873323	TATYANA POLYAKOVA	{"email": "t-polyakova.05061972@postgrespro.ru", "phone": "+70346461116"}
0005435488160	4A9146	7573 860627	NINA BELOVA	{"email": "nina-belova.061971@postgrespro.ru", "phone": "+70361875756"}
0005435488161	4A9146	4514 165103	SERAFIMA ANDREEVA	{"phone": "+70649998382"}
0005435488162	4A9146	5131 125768	TARAS NIKOLAEV	{"phone": "+70261925842"}
0005435488163	1CBD4D	5319 134697	NATALYA PETROVA	{"phone": "+70598153413"}
0005435488164	A18610	2482 640353	VERA RODIONOVA	{"phone": "+70189471313"}
0005435488165	6EC8AA	3687 597816	LYUDMILA NESTEROVA	{"email": "l.nesterova.1976@postgrespro.ru", "phone": "+70088240449"}
0005435488166	6EC8AA	6363 628382	GALINA KAZAKOVA	{"email": "kazakova-galina10011974@postgrespro.ru", "phone": "+70204294263"}
0005435488167	6EC8AA	1778 173781	EGOR KAZAKOV	{"email": "egor-kazakov-1973@postgrespro.ru", "phone": "+70802063037"}
0005435488168	703ACF	4553 729989	MIKHAIL FEDOTOV	{"email": "fedotov_m_1967@postgrespro.ru", "phone": "+70096667275"}
0005435488169	F5D129	9899 074121	ILYA KOZLOV	{"phone": "+70890039122"}
0005435488170	7EAD51	9215 948289	RISHAT SIDOROV	{"phone": "+70274474096"}
0005435488171	AA4CAD	4607 134382	SERGEY MIKHAYLOV	{"email": "mikhaylov_s15091972@postgrespro.ru", "phone": "+70389805326"}
0005435488172	F74658	7054 366051	ALEKSANDR KUZMIN	{"email": "a.kuzmin.15071967@postgrespro.ru", "phone": "+70848101946"}
0005435488173	F74658	7809 718971	VALERIY TIMOFEEV	{"email": "valeriy-timofeev.1987@postgrespro.ru", "phone": "+70810426124"}
0005435488174	F74658	3887 223128	EKATERINA KOROLEVA	{"phone": "+70167660154"}
0005435488175	EEAC7A	9030 867851	OLGA BELOVA	{"email": "olgabelova101970@postgrespro.ru", "phone": "+70835578800"}
0005435488176	EEAC7A	4085 182639	TAMARA NESTEROVA	{"email": "t_nesterova081967@postgrespro.ru", "phone": "+70186710425"}
0005435488177	BD2DED	9724 707210	ELENA AFANASEVA	{"phone": "+70618245593"}
0005435488178	4E3DBE	4437 563636	NATALYA GORBUNOVA	{"phone": "+70147283520"}
0005435488179	4E3DBE	9209 438645	SERGEY MAKSIMOV	{"email": "maksimov-s1963@postgrespro.ru", "phone": "+70742527156"}
0005435488180	729360	6327 845066	LIDIYA EGOROVA	{"phone": "+70425290357"}
0005435488181	729360	9556 913871	YULIYA POPOVA	{"email": "popova.yuliya-1975@postgrespro.ru", "phone": "+70980533516"}
0005435488182	9B500E	9283 102111	MIKHAIL KONOVALOV	{"email": "konovalov-mikhail1977@postgrespro.ru", "phone": "+70093885326"}
0005435488183	74ACC8	1757 532304	PETR ZHURAVLEV	{"phone": "+70571394649"}
0005435488184	FB7775	9687 777634	SERGEY SIDOROV	{"email": "sergey-sidorov-09121980@postgrespro.ru", "phone": "+70526060102"}
0005435488185	FB7775	3660 725529	ALEKSEY KISELEV	{"email": "akiselev-121976@postgrespro.ru", "phone": "+70603529837"}
0005435488186	48C249	6996 589046	ANTONINA AKIMOVA	{"email": "akimova.antonina_1974@postgrespro.ru", "phone": "+70627411769"}
0005435488187	50739E	5679 888647	ANNA LEBEDEVA	{"email": "alebedeva_20021979@postgrespro.ru", "phone": "+70521431347"}
0005435488188	DE3A6E	1710 021783	OLGA KRASNOVA	{"email": "o_krasnova.051971@postgrespro.ru", "phone": "+70324427856"}
0005435488189	DE3A6E	7097 153965	LYUBOV NIKOLAEVA	{"email": "lyubov_nikolaeva_071970@postgrespro.ru", "phone": "+70289188006"}
0005435488190	024BD8	6291 935465	LUIZA ALEKSEEVA	{"phone": "+70901878751"}
0005435488191	024BD8	8219 068756	NIKITA ALEKSEEV	{"email": "n_alekseev-30051971@postgrespro.ru", "phone": "+70140215697"}
0005435488192	06A8A2	4139 838149	YURIY KOZLOV	{"email": "kozlov_yuriy_1984@postgrespro.ru", "phone": "+70906528563"}
0005435488193	AEA62F	1428 607153	DENIS KARPOV	{"phone": "+70870759789"}
0005435488194	AEA62F	5117 488976	YURIY FILIPPOV	{"phone": "+70489373280"}
0005435488195	CCFEAE	9815 908638	SVETLANA KARPOVA	{"email": "svetlanakarpova-1962@postgrespro.ru", "phone": "+70581723336"}
0005435488196	CCFEAE	4150 959640	MIKHAIL IVANOV	{"email": "ivanovmikhail031974@postgrespro.ru", "phone": "+70000665498"}
0005435488197	75A96D	4403 541581	TATYANA ZHUKOVA	{"phone": "+70565362827"}
0005435488198	8BB60D	0321 907003	TATYANA STEPANOVA	{"phone": "+70952550026"}
0005435488199	F3D823	4303 262672	IGOR ISAEV	{"phone": "+70328088759"}
0005435488200	3E2C0A	4342 871418	EVGENIYA ROMANOVA	{"email": "e_romanova_021982@postgrespro.ru", "phone": "+70696359935"}
0005435488201	E3020C	4180 164156	YURIY RODIONOV	{"email": "rodionov_y_18071976@postgrespro.ru", "phone": "+70993544012"}
0005435488202	6902DE	4129 969262	ALEKSEY KOZLOV	{"phone": "+70533814467"}
0005435488203	521E17	3535 936139	VLADIMIR NAUMOV	{"email": "v.naumov1980@postgrespro.ru", "phone": "+70363427414"}
0005435488204	3E35BE	6176 110813	VLADIMIR TIMOFEEV	{"email": "timofeev_v_041970@postgrespro.ru", "phone": "+70273307948"}
0005435488205	392F19	0481 342946	MIKHAIL MOROZOV	{"email": "morozov_mikhail02051974@postgrespro.ru", "phone": "+70988040685"}
0005435488206	392F19	0307 422500	MIKHAIL MOROZOV	{"email": "mikhail.morozov_101980@postgrespro.ru", "phone": "+70807284454"}
0005435488207	C3FD00	4104 087021	DENIS KARPOV	{"email": "karpov_d.1968@postgrespro.ru", "phone": "+70343058730"}
0005435488208	554599	8820 548654	SERGEY BELOV	{"phone": "+70708580780"}
0005435488209	554599	2120 996752	MARINA KUDRYASHOVA	{"phone": "+70458763404"}
0005435488210	F2DBB7	1888 840802	SVETLANA KRASNOVA	{"email": "skrasnova011978@postgrespro.ru", "phone": "+70618992072"}
0005435488211	32BA31	9863 914503	VLADIMIR KUZNECOV	{"phone": "+70564761830"}
0005435488212	F1350E	7088 250549	OLEG MIRONOV	{"email": "oleg_mironov1968@postgrespro.ru", "phone": "+70816119365"}
0005435488213	FE1921	1404 125501	IVAN ANDREEV	{"phone": "+70473125013"}
0005435488214	FE1921	5320 334042	VALERIY GERASIMOV	{"email": "gerasimov_v_041970@postgrespro.ru", "phone": "+70960423563"}
0005435488215	3CE741	4294 951917	ANZHELIKA VLASOVA	{"phone": "+70823591844"}
0005435488216	18042E	2067 422607	MARIYA SOLOVEVA	{"phone": "+70388016049"}
0005435488217	D3D0A7	3496 570856	MARIYA KONOVALOVA	{"phone": "+70927659375"}
0005435488218	D3D0A7	1610 054606	VALERIYA MOISEEVA	{"phone": "+70605473833"}
0005435488219	16125F	7842 147410	NINA SOLOVEVA	{"phone": "+70878070213"}
0005435488220	5E7DCE	9041 979278	ALINA VASILEVA	{"phone": "+70774103042"}
0005435488221	5E7DCE	8865 974520	EKATERINA EGOROVA	{"email": "ekaterina.egorova_051971@postgrespro.ru", "phone": "+70906571295"}
0005435488222	5E7DCE	9504 419714	VIKTOR YAKOVLEV	{"email": "viktoryakovlev.101962@postgrespro.ru", "phone": "+70218880543"}
0005435488223	838E57	4829 673800	DMITRIY ALEKSANDROV	{"email": "dmitriyaleksandrov-081975@postgrespro.ru", "phone": "+70551193357"}
0005435488224	838E57	6914 608656	TAMARA KUZNECOVA	{"phone": "+70437175844"}
0005435488225	AAE5EB	3716 259131	ANTONINA RODIONOVA	{"email": "rodionovaantonina1969@postgrespro.ru", "phone": "+70353938106"}
0005435488226	AAE5EB	6374 662363	KLAVDIYA POPOVA	{"phone": "+70975612125"}
0005435488227	F14909	0545 008841	IVAN EGOROV	{"phone": "+70988034926"}
0005435488228	F14909	5147 754686	LYUBOV LUKYANOVA	{"email": "lukyanova_lyubov.121968@postgrespro.ru", "phone": "+70874425753"}
0005435488229	176B50	1771 364099	VIKTORIYA FROLOVA	{"phone": "+70763865151"}
0005435488230	176B50	2500 653955	ELENA MAKAROVA	{"phone": "+70500613892"}
0005435488231	176B50	3869 195316	ARKADIY KULIKOV	{"email": "a-kulikov.20051972@postgrespro.ru", "phone": "+70455071870"}
0005435488232	B656C9	0030 440743	ALEKSANDR IVANOV	{"email": "ivanovaleksandr.15121970@postgrespro.ru", "phone": "+70075714567"}
0005435488233	BDAC3A	3910 668357	EKATERINA SEMENOVA	{"email": "semenova_ekaterina-121967@postgrespro.ru", "phone": "+70925716130"}
0005435488234	3C7DE0	9522 275472	YULIYA TROFIMOVA	{"email": "yuliyatrofimova.1958@postgrespro.ru", "phone": "+70762782782"}
0005435488235	FBF719	4715 657329	ANNA PETROVA	{"phone": "+70264484017"}
0005435488236	8C6DF2	0279 455182	NIKOLAY STEPANOV	{"email": "stepanovn1978@postgrespro.ru", "phone": "+70459866380"}
0005435488237	8C6DF2	6670 616311	GALINA LUKYANOVA	{"phone": "+70710879672"}
0005435488238	9F9BE2	2278 315790	LARISA KUZNECOVA	{"email": "l.kuznecova_02011973@postgrespro.ru", "phone": "+70421487075"}
0005435488239	AB180B	9421 891180	ANDREY KUZNECOV	{"email": "andreykuznecov-1972@postgrespro.ru", "phone": "+70593378938"}
0005435488240	A64C41	1498 062379	ALEKSANDRA EGOROVA	{"email": "egorova-aleksandra-1970@postgrespro.ru", "phone": "+70244967686"}
0005435488241	3B1C76	2634 298763	NADEZHDA KISELEVA	{"phone": "+70343699984"}
0005435488242	BD218C	1544 171780	ALLA MOROZOVA	{"phone": "+70074066441"}
0005435488243	88EC8F	2012 764361	LYUDMILA MASLOVA	{"phone": "+70348205169"}
0005435488244	0AABF7	4837 752236	ZOYA ALEKSEEVA	{"email": "alekseeva_z.22081981@postgrespro.ru", "phone": "+70405582602"}
0005435488245	F5D688	3780 834233	IVAN ZAKHAROV	{"phone": "+70779100620"}
0005435488246	3B4CA9	3618 897453	EKATERINA KOMAROVA	{"phone": "+70782385133"}
0005435488247	71A6EE	0225 203692	IRINA NIKIFOROVA	{"email": "nikiforova_i28061972@postgrespro.ru", "phone": "+70555013455"}
0005435488248	E84AA7	5978 501236	ZOYA AKIMOVA	{"phone": "+70481234818"}
0005435488249	A31842	7442 333321	RUSLAN ALEKSANDROV	{"phone": "+70291725510"}
0005435488250	841918	5560 391066	VLADIMIR SOLOVEV	{"email": "v-solovev011984@postgrespro.ru", "phone": "+70776931815"}
0005435488251	841918	1572 535072	NIKOLAY IVANOV	{"email": "n.ivanov_14061975@postgrespro.ru", "phone": "+70694883829"}
0005435488252	030747	6752 115755	IVAN IVANOV	{"email": "ivanov.i101974@postgrespro.ru", "phone": "+70552036172"}
0005435488253	B0E4F1	7967 388487	MARIYA MATVEEVA	{"email": "matveeva_mariya26041979@postgrespro.ru", "phone": "+70233035571"}
0005435488254	72519D	3121 490313	MAKSIM ZHUKOV	{"phone": "+70819145241"}
0005435488255	459A8A	7240 504677	ALEKSEY BONDARENKO	{"email": "bondarenko_aleksey27051960@postgrespro.ru", "phone": "+70199604232"}
0005435488256	BFB507	4599 639868	LYUDMILA MIKHAYLOVA	{"email": "lyudmila.mikhaylova1974@postgrespro.ru", "phone": "+70726619385"}
0005435488257	4BD603	0960 226712	TATYANA MALYSHEVA	{"email": "tatyana-malysheva_25091971@postgrespro.ru", "phone": "+70921267289"}
0005435488258	8FFED5	8746 436061	VITALIY IVANOV	{"email": "vitaliyivanov_071974@postgrespro.ru", "phone": "+70779042109"}
0005435488259	23A3CA	3228 919938	ARTUR IVANOV	{"email": "artur_ivanov_14101974@postgrespro.ru", "phone": "+70559399082"}
0005435488260	4173A3	7581 705450	SERGEY KULIKOV	{"email": "skulikov.1969@postgrespro.ru", "phone": "+70629895244"}
0005435488261	C78A1F	4666 393556	EVELINA NAZAROVA	{"email": "e.nazarova1971@postgrespro.ru", "phone": "+70075706687"}
0005435488262	5AEF6C	2744 353831	VALENTINA VLASOVA	{"email": "vlasova_v_25051968@postgrespro.ru", "phone": "+70593561381"}
0005435488263	BD637C	4064 958499	SERGEY ZAKHAROV	{"email": "zakharov_sergey.1969@postgrespro.ru", "phone": "+70498941619"}
0005435488264	59CB1B	9918 728920	YULIYA FEDOROVA	{"phone": "+70459752443"}
0005435488265	DB64D2	5131 429872	SERGEY KUZMIN	{"email": "kuzmins_1963@postgrespro.ru", "phone": "+70465446812"}
0005435488266	398A27	6928 737216	ANDREY EGOROV	{"phone": "+70566701082"}
0005435488267	FB2366	9944 309460	LIDIYA POPOVA	{"email": "popova.lidiya.24031965@postgrespro.ru", "phone": "+70353738200"}
0005435488268	FB2366	9614 845516	YULIYA MATVEEVA	{"phone": "+70009257640"}
0005435488269	BFECEA	3420 244376	NADEZHDA TIMOFEEVA	{"email": "timofeevanadezhda_011969@postgrespro.ru", "phone": "+70217717735"}
0005435488270	BFECEA	7073 012102	IVAN MEDVEDEV	{"phone": "+70885251224"}
0005435488271	9E95D9	7693 959807	ELIZAVETA GORBUNOVA	{"email": "gorbunova.elizaveta.041991@postgrespro.ru", "phone": "+70719431082"}
0005435488272	9E95D9	0055 115489	GALIYA ZOTOVA	{"phone": "+70090465252"}
0005435488273	268D62	4018 329587	ALEKSANDR FROLOV	{"email": "frolov-a_091974@postgrespro.ru", "phone": "+70369359204"}
0005435488274	268D62	4521 582938	GENNADIY KAZAKOV	{"email": "g_kazakov-1959@postgrespro.ru", "phone": "+70533245545"}
0005435488275	CD5AC8	4112 815508	ALEKSANDR CHERNOV	{"phone": "+70413446745"}
0005435488276	975B80	9340 417864	SERGEY IVANOV	{"email": "s_ivanov-1978@postgrespro.ru", "phone": "+70914952213"}
0005435488277	975B80	4504 541913	ANNA IVANOVA	{"email": "ivanova-anna_19021967@postgrespro.ru", "phone": "+70768524557"}
0005435488278	975B80	2144 696347	ALBINA POPOVA	{"phone": "+70747845750"}
0005435488279	BBC684	6792 721070	VALENTINA KARPOVA	{"email": "karpova-v-101961@postgrespro.ru", "phone": "+70175783095"}
0005435488280	B57D52	3050 388773	OLGA ZHURAVLEVA	{"email": "o.zhuravleva111982@postgrespro.ru", "phone": "+70461565114"}
0005435488281	B57D52	1471 817604	TIMOFEY YAKOVLEV	{"phone": "+70417259963"}
0005435488282	0FFD47	6515 169797	ALEKSANDRA NIKOLAEVA	{"phone": "+70937395974"}
0005435488283	0FFD47	4782 750183	ALEKSEY SERGEEV	{"email": "sergeev_aleksey121964@postgrespro.ru", "phone": "+70193015893"}
0005435488284	134784	0445 944777	TATYANA MIKHAYLOVA	{"email": "mikhaylova.tatyana.031974@postgrespro.ru", "phone": "+70677738266"}
0005435488285	A2B3A5	5918 053023	ALEKSEY STEPANOV	{"phone": "+70400427264"}
0005435488286	3D687A	4767 587171	IVAN IVANOV	{"phone": "+70531957046"}
0005435488287	CDD057	7653 044980	SERGEY SAVELEV	{"phone": "+70521619599"}
0005435488288	382D83	8766 696032	EKATERINA EGOROVA	{"phone": "+70108936611"}
0005435488289	64DF63	6682 482313	DARYA OSIPOVA	{"phone": "+70007889100"}
0005435488290	AA26D8	2747 451126	MARIYA POTAPOVA	{"phone": "+70681331328"}
0005435488291	7E43FA	1611 699098	KONSTANTIN MELNIKOV	{"email": "k_melnikov_13051975@postgrespro.ru", "phone": "+70750207483"}
0005435488292	622D59	8206 626463	SANIYA LEBEDEVA	{"phone": "+70515144195"}
0005435488293	E3C468	5861 625606	AMIR DENISOV	{"email": "amir.denisov.1982@postgrespro.ru", "phone": "+70168789950"}
0005435488294	E3C468	7603 282181	SERGEY ANDREEV	{"phone": "+70060540296"}
0005435488295	AD2737	1884 894979	NINA MASLOVA	{"phone": "+70091263493"}
0005435488296	AD2737	4678 987502	ANTONINA NIKITINA	{"phone": "+70658235101"}
0005435488297	CD1913	9381 616824	KSENIYA MAKAROVA	{"email": "makarova-k_041993@postgrespro.ru", "phone": "+70852510173"}
0005435488298	90AF08	7459 665061	ELENA ROMANOVA	{"phone": "+70635115919"}
0005435488299	3245FE	3709 717805	ALEKSANDR KRASNOV	{"email": "krasnov.aleksandr-11031974@postgrespro.ru", "phone": "+70593722871"}
0005435488300	3EEF89	1947 942112	TATYANA KULIKOVA	{"email": "t.kulikova1972@postgrespro.ru", "phone": "+70446674953"}
0005435488301	3EEF89	3254 249171	OLEG KUZNECOV	{"email": "o_kuznecov-1973@postgrespro.ru", "phone": "+70879342252"}
0005435488302	63791D	6670 990504	EKATERINA IVANOVA	{"email": "ekaterina_ivanova_091973@postgrespro.ru", "phone": "+70799494205"}
0005435488303	EE7D3D	3385 843804	PAVEL OSIPOV	{"email": "osipov-pavel_18081971@postgrespro.ru", "phone": "+70511667350"}
0005435488304	D169F0	0840 100852	VLADA KUDRYASHOVA	{"phone": "+70438098002"}
0005435488305	D169F0	4568 060676	ROMAN ISAEV	{"phone": "+70657481979"}
0005435488306	D169F0	6066 243933	REGINA GUSEVA	{"email": "regina.guseva-101974@postgrespro.ru", "phone": "+70839596541"}
0005435488307	B09381	8838 121588	RAISA KRASNOVA	{"email": "raisa.krasnova.17081975@postgrespro.ru", "phone": "+70528773706"}
0005435488308	B09381	2636 709154	GALINA KONDRATEVA	{"phone": "+70132342498"}
0005435488309	56FC37	9027 745751	TIMUR MOROZOV	{"email": "morozov_t_27021976@postgrespro.ru", "phone": "+70312669144"}
0005435488310	4A56B6	9096 496102	ANNA FROLOVA	{"email": "anna-frolova.091970@postgrespro.ru", "phone": "+70327723278"}
0005435488311	4A56B6	4558 241734	ALEKSANDR FOMIN	{"phone": "+70332709805"}
0005435488312	4A56B6	8429 172697	VIKTOR SIDOROV	{"email": "v.sidorov-1965@postgrespro.ru", "phone": "+70402354322"}
0005435488313	349873	2809 547651	ANASTASIYA KUZNECOVA	{"email": "a.kuznecova-1967@postgrespro.ru", "phone": "+70275914000"}
0005435488314	8B6A6E	1535 900970	OLEG POPOV	{"phone": "+70057357398"}
0005435488315	958709	5114 004114	YULIYA MOISEEVA	{"phone": "+70686404849"}
0005435488316	DE848F	3928 981043	ALEKSEY ZAKHAROV	{"email": "alekseyzakharov.1980@postgrespro.ru", "phone": "+70682571424"}
0005435488317	88ACBB	3414 911134	PAVEL RODIONOV	{"email": "rodionov_pavel_111975@postgrespro.ru", "phone": "+70435788006"}
0005435488318	88ACBB	5050 105144	VASILIY GAVRILOV	{"email": "vasiliy.gavrilov-081974@postgrespro.ru", "phone": "+70719511478"}
0005435488319	169002	6163 117441	ILDAR RODIONOV	{"email": "i.rodionov.05081970@postgrespro.ru", "phone": "+70236802566"}
0005435488320	1CC4C8	6989 195080	OLGA DENISOVA	{"phone": "+70077554201"}
0005435488321	1D52AE	0905 434328	ARTEM MAKAROV	{"phone": "+70753388680"}
0005435488322	1D52AE	6162 334095	EVGENIYA IVANOVA	{"email": "ivanova-e19121973@postgrespro.ru", "phone": "+70118650343"}
0005435488323	A02FF3	3646 124057	GENNADIY NIKITIN	{"phone": "+70780719621"}
0005435488324	33E00A	0876 380977	KSENIYA PETROVA	{"email": "petrova.kseniya_30061972@postgrespro.ru", "phone": "+70404681722"}
0005435488325	7D99F5	4456 670233	IVAN ALEKSEEV	{"email": "ivan_alekseev05111972@postgrespro.ru", "phone": "+70124208098"}
0005435488326	DB6C71	8710 645237	ARTEM OSIPOV	{"email": "artem_osipov.1968@postgrespro.ru", "phone": "+70556490789"}
0005435488327	EB568B	8702 495824	ALEKSANDR NAZAROV	{"email": "aleksandrnazarov_1984@postgrespro.ru", "phone": "+70050215932"}
0005435488328	EB568B	9738 466470	YULIYA AFANASEVA	{"phone": "+70599430446"}
0005435488329	591AD7	6384 845435	ALEVTINA ANDREEVA	{"phone": "+70340887060"}
0005435488330	F70730	5628 040007	MAKSIM MIRONOV	{"email": "mironov_m_17111974@postgrespro.ru", "phone": "+70654421235"}
0005435488331	F70730	1693 850358	VLADIMIR VASILEV	{"email": "vasilevvladimir.29051972@postgrespro.ru", "phone": "+70559423329"}
0005435488332	6E66A8	5343 484043	ANNA KONOVALOVA	{"email": "anna-konovalova_091975@postgrespro.ru", "phone": "+70502876289"}
0005435488333	85541F	4596 477263	NIKOLAY ANTONOV	{"email": "antonovnikolay_1977@postgrespro.ru", "phone": "+70592412207"}
0005435488334	85541F	5980 198593	VLADIMIR KOZLOV	{"phone": "+70644927854"}
0005435488335	34BBCD	0500 265841	NADEZHDA SOROKINA	{"email": "sorokina-n.12091972@postgrespro.ru", "phone": "+70786850906"}
0005435488336	D638DC	1706 054877	STANISLAV TARASOV	{"email": "s_tarasov_20051979@postgrespro.ru", "phone": "+70269739833"}
0005435488337	9449A1	6221 431603	ALEKSEY KUZNECOV	{"phone": "+70384906751"}
0005435488338	60CFD9	8119 140376	TATYANA RYABOVA	{"phone": "+70602042716"}
0005435488339	60CFD9	1179 721643	LYUBOV DMITRIEVA	{"phone": "+70890317029"}
0005435488340	985DC8	4265 798586	ANNA KUZNECOVA	{"phone": "+70179055729"}
0005435488341	16179A	2278 585525	YURIY FEDOTOV	{"email": "fedotov.y.061961@postgrespro.ru", "phone": "+70770894983"}
0005435488342	16179A	6587 168707	ANTONINA GORBUNOVA	{"phone": "+70929558388"}
0005435488343	16179A	2112 443904	DARINA LUKYANOVA	{"phone": "+70722041294"}
0005435488344	16179A	5861 652619	YURIY EGOROV	{"email": "egorovy031977@postgrespro.ru", "phone": "+70019917375"}
0005435488345	B037BA	3638 801695	ANDREY MARTYNOV	{"phone": "+70411777174"}
0005435488346	AE53FC	1856 878942	SVETLANA IVANOVA	{"email": "s_ivanova.071971@postgrespro.ru", "phone": "+70099536495"}
0005435488347	AE53FC	0829 218794	SVETLANA ZHURAVLEVA	{"email": "zhuravleva-svetlana_101970@postgrespro.ru", "phone": "+70286277863"}
0005435488348	BE0770	6454 114916	ALEKSANDR KUZMIN	{"phone": "+70920865942"}
0005435488349	0DFE54	9854 005078	ALEKSANDR MOROZOV	{"phone": "+70372235480"}
0005435488350	F99F07	1920 846394	OLGA SOKOLOVA	{"email": "olga.sokolova-1968@postgrespro.ru", "phone": "+70872760803"}
0005435488351	EF7FDB	4929 389057	YULIYA BELYAEVA	{"phone": "+70710631788"}
0005435488352	B9617E	2251 592044	ANDREY TARASOV	{"email": "tarasova.01041979@postgrespro.ru", "phone": "+70989918207"}
0005435488353	B9617E	5709 561960	NADEZHDA NESTEROVA	{"phone": "+70476787716"}
0005435488354	682468	4325 320787	ALEKSEY GAVRILOV	{"phone": "+70549652117"}
0005435488355	DF1EF3	6843 117723	GLEB POPOV	{"phone": "+70405446862"}
0005435488356	DF1EF3	4797 944719	ELENA SEMENOVA	{"email": "semenova.elena.1972@postgrespro.ru", "phone": "+70373568712"}
0005435488357	28FD11	5192 735298	VLADIMIR CHERNOV	{"phone": "+70833217206"}
0005435488358	28FD11	9572 014021	MAKSIM KARPOV	{"email": "maksim-karpov-08101975@postgrespro.ru", "phone": "+70215346850"}
0005435488359	1C55E0	0888 757011	SVETLANA KRASNOVA	{"email": "svetlana-krasnova1983@postgrespro.ru", "phone": "+70239306102"}
0005435488360	4FC9E6	0293 774897	DMITRIY SOKOLOV	{"email": "dsokolov15081967@postgrespro.ru", "phone": "+70818196072"}
0005435488361	4FC9E6	6975 625542	ANDREY FEDOROV	{"phone": "+70295971380"}
0005435488362	02999A	9651 617946	OLEG FOMIN	{"email": "fomin_oleg-1970@postgrespro.ru", "phone": "+70783693390"}
0005435488363	02999A	9141 014339	OKSANA VASILEVA	{"phone": "+70300954973"}
0005435488364	886AD7	3106 579417	LARISA KUZNECOVA	{"phone": "+70610707475"}
0005435488365	95443B	9270 185493	YURIY IVANOV	{"email": "y_ivanov_03121977@postgrespro.ru", "phone": "+70085201071"}
0005435488366	AF5BA3	5613 761351	ANDREY GAVRILOV	{"phone": "+70501079054"}
0005435488367	AF5BA3	3192 594888	NATALYA KUZNECOVA	{"email": "kuznecovanatalya.1978@postgrespro.ru", "phone": "+70813108897"}
0005435488368	35A706	9557 969756	TATYANA FROLOVA	{"phone": "+70126600971"}
0005435488369	26F447	6119 085473	VALENTINA ZHURAVLEVA	{"email": "v-zhuravleva.091966@postgrespro.ru", "phone": "+70682652674"}
0005435488370	26F447	2105 419406	NINA KAZAKOVA	{"email": "n_kazakova_1973@postgrespro.ru", "phone": "+70046531985"}
0005435488371	4D58CB	1232 835969	ALEKSANDR MAKAROV	{"phone": "+70225770524"}
0005435488372	4D58CB	4776 235310	ANDREY GORBUNOV	{"phone": "+70057477994"}
0005435488373	FD28EE	2434 815798	DANIIL MOROZOV	{"phone": "+70500353926"}
0005435488374	BC90B0	8361 996321	VALENTINA ALEKSANDROVA	{"phone": "+70879690243"}
0005435488375	A9A779	5274 976120	SOFIYA VOLKOVA	{"email": "svolkova-051966@postgrespro.ru", "phone": "+70491194284"}
0005435488376	846FB1	2838 946206	MARIYA POPOVA	{"email": "popovamariya1966@postgrespro.ru", "phone": "+70933350730"}
0005435488377	846FB1	0584 317512	SOFIYA KUZNECOVA	{"phone": "+70795610239"}
0005435488378	9F5253	7536 387306	ALFIYA MIKHAYLOVA	{"phone": "+70373829116"}
0005435488379	9F5253	0839 425336	TATYANA ZHUKOVA	{"email": "zhukova_t051966@postgrespro.ru", "phone": "+70375008293"}
0005435488380	EE6593	2163 719383	NADEZHDA BOGDANOVA	{"phone": "+70078465020"}
0005435488381	EE6593	1051 196025	ANDREY MEDVEDEV	{"phone": "+70938564329"}
0005435488382	8AF322	0894 279426	YURIY MATVEEV	{"email": "ymatveev-081965@postgrespro.ru", "phone": "+70932431896"}
0005435488383	1FD34E	2387 217055	ALEKSEY SMIRNOV	{"phone": "+70063076688"}
0005435488384	AA462E	4139 894467	MARINA POPOVA	{"email": "mpopova-1975@postgrespro.ru", "phone": "+70719857992"}
0005435488385	009BC1	2332 054715	ISLAM MEDVEDEV	{"phone": "+70454768025"}
0005435488386	009BC1	5733 591985	SVETLANA RODIONOVA	{"phone": "+70661533216"}
0005435488387	E9A521	2597 520102	YURIY BORISOV	{"phone": "+70746850932"}
0005435488388	E9A521	6132 726235	SVETLANA MELNIKOVA	{"phone": "+70559384988"}
0005435488389	5F3BC7	0770 819524	VERONIKA POPOVA	{"phone": "+70247432736"}
0005435488390	31D054	5462 263979	SVETLANA PAVLOVA	{"email": "s_pavlova_1973@postgrespro.ru", "phone": "+70004548552"}
0005435488391	403423	1807 309599	DARYA IVANOVA	{"phone": "+70309850336"}
0005435488392	23BB55	8349 615122	POLINA FILATOVA	{"phone": "+70754841737"}
0005435488393	7C2569	4721 087867	VASILIY KOZLOV	{"email": "vasiliykozlov.13061973@postgrespro.ru", "phone": "+70563402616"}
0005435488394	B9D0F3	2217 289731	ALEKSEY ALEKSANDROV	{"phone": "+70160963883"}
0005435488395	49F198	6791 404653	RAISA KAZAKOVA	{"email": "r_kazakova.111971@postgrespro.ru", "phone": "+70629466742"}
0005435488396	49F198	6928 153166	RENATA GORBUNOVA	{"phone": "+70171699851"}
0005435488397	254B5F	7305 303352	ALEKSANDR NIKITIN	{"phone": "+70836993584"}
0005435488398	02A01A	1053 052292	GENNADIY KUZNECOV	{"phone": "+70838096268"}
0005435488399	76E18B	1584 931869	NADEZHDA BOGDANOVA	{"phone": "+70937449656"}
0005435488400	2A6E0A	5647 719792	VITALIY GRIGOREV	{"email": "grigorevv04121973@postgrespro.ru", "phone": "+70360502898"}
0005435488401	3707AB	3945 342370	DENIS IVANOV	{"email": "ivanov-denis1969@postgrespro.ru", "phone": "+70174240239"}
0005435488402	3C8121	8482 591648	MIKHAIL EGOROV	{"phone": "+70028157969"}
0005435488403	C7D462	6442 885049	NINA KUZNECOVA	{"phone": "+70992558632"}
0005435488404	DF11E1	8996 593905	ILFAT DMITRIEV	{"email": "ilfatdmitriev.1982@postgrespro.ru", "phone": "+70291441552"}
0005435488405	DF11E1	1804 533319	SERGEY PAVLOV	{"email": "pavlov.s_101973@postgrespro.ru", "phone": "+70325945975"}
0005435488406	2F153F	3575 156252	VLADISLAV KOROLEV	{"email": "korolev-vladislav1959@postgrespro.ru", "phone": "+70183784219"}
0005435488407	BC66DA	4845 735563	ALEKSANDR MOROZOV	{"phone": "+70322205502"}
0005435488408	A38E6E	9764 001560	ELENA SEMENOVA	{"phone": "+70835696346"}
0005435488409	F94763	3281 117668	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov.27031975@postgrespro.ru", "phone": "+70859729258"}
0005435488410	1CFD4D	0880 036007	ARKADIY BARANOV	{"email": "baranovarkadiy.1957@postgrespro.ru", "phone": "+70280103234"}
0005435488411	C604E0	2168 072574	SERGEY FEDOROV	{"phone": "+70835787274"}
0005435488412	61EFCE	4724 995050	ALEKSANDRA KARPOVA	{"phone": "+70284986535"}
0005435488413	61EFCE	2593 010840	NIKOLAY KRASNOV	{"phone": "+70900941731"}
0005435488414	7A7DC0	5438 020259	TATYANA KUZNECOVA	{"email": "kuznecovatatyana.071970@postgrespro.ru", "phone": "+70808160741"}
0005435488415	ECC726	8372 386226	DMITRIY FOMIN	{"phone": "+70071697127"}
0005435488416	835D5A	4050 504892	VLADISLAV NIKITIN	{"email": "v-nikitin.23081983@postgrespro.ru", "phone": "+70681402942"}
0005435488417	C303A1	0687 308683	ULYANA MAKSIMOVA	{"phone": "+70118522999"}
0005435488418	4B52B4	5799 089077	TATYANA TIKHONOVA	{"phone": "+70486662983"}
0005435488419	B3E91C	6712 582003	ANATOLIY POPOV	{"phone": "+70251318718"}
0005435488420	B3E91C	4963 211652	NINA MARTYNOVA	{"email": "n-martynova-1980@postgrespro.ru", "phone": "+70285294082"}
0005435488421	333480	7901 365730	ALEVTINA ORLOVA	{"email": "alevtina.orlova_1965@postgrespro.ru", "phone": "+70507891293"}
0005435488422	13E34B	3896 954579	KRISTINA PAVLOVA	{"email": "pavlova-kristina_1974@postgrespro.ru", "phone": "+70454213377"}
0005435488423	13E34B	5885 609734	VLADIMIR EGOROV	{"phone": "+70812988291"}
0005435488424	1F9AAF	0997 755634	MARGARITA BORISOVA	{"phone": "+70488124666"}
0005435488425	2F572A	7489 081699	SAMIRA TARASOVA	{"email": "tarasova-samira021981@postgrespro.ru", "phone": "+70761619983"}
0005435488426	DF7D03	7568 053875	LYUDMILA MIKHAYLOVA	{"phone": "+70358448364"}
0005435488427	DF7D03	4634 467851	ANNA POTAPOVA	{"email": "potapova-anna051979@postgrespro.ru", "phone": "+70298896268"}
0005435488428	210221	3208 940302	VLADIMIR NIKOLAEV	{"phone": "+70780897652"}
0005435488429	8F46A6	4881 175774	VALENTINA YAKOVLEVA	{"email": "yakovleva-valentina011976@postgrespro.ru", "phone": "+70946226712"}
0005435488430	A7AF48	2245 867063	MAKSIM GRIGOREV	{"phone": "+70132645043"}
0005435488431	48F4A6	8656 165423	PAVEL VLASOV	{"email": "vlasovpavel-08041984@postgrespro.ru", "phone": "+70647642310"}
0005435488432	48F4A6	0495 382753	NATALYA BORISOVA	{"email": "natalya_borisova.041979@postgrespro.ru", "phone": "+70155390377"}
0005435488433	28FB50	5060 882087	VLADIMIR NIKOLAEV	{"phone": "+70014361505"}
0005435488434	FCB530	2412 384530	ALLA BELOVA	{"email": "alla-belova_05011973@postgrespro.ru", "phone": "+70114688841"}
0005435488435	075215	9876 837515	VALENTIN GERASIMOV	{"phone": "+70099906988"}
0005435488436	E8D37E	6522 796443	ILYAS NOVIKOV	{"phone": "+70252805108"}
0005435488437	3BA97F	9697 238927	VALERIY IVANOV	{"email": "vivanov031977@postgrespro.ru", "phone": "+70311655536"}
0005435488438	3BA97F	1946 764047	SERGEY VASILEV	{"phone": "+70872470660"}
0005435488439	840B63	8578 731347	ANATOLIY PAVLOV	{"email": "pavlov-anatoliy1977@postgrespro.ru", "phone": "+70945245318"}
0005435488440	D16342	6748 236436	AMINA SEMENOVA	{"email": "amina.semenova.28041967@postgrespro.ru", "phone": "+70988635309"}
0005435488441	D16342	9773 793269	VALENTINA LUKYANOVA	{"phone": "+70746356692"}
0005435488442	1EC3E4	0701 890739	OLGA KUDRYASHOVA	{"email": "kudryashovao_061975@postgrespro.ru", "phone": "+70728640537"}
0005435488443	1EC3E4	2354 892983	SERGEY DENISOV	{"phone": "+70198470248"}
0005435488444	D658B2	9024 236537	NINA KOMAROVA	{"email": "komarovan02071968@postgrespro.ru", "phone": "+70355257029"}
0005435488445	DD7819	9108 760698	YULIYA LEBEDEVA	{"email": "lebedevay-01051973@postgrespro.ru", "phone": "+70201004862"}
0005435488446	51C50C	8876 048228	TATYANA KOROLEVA	{"email": "tatyana_koroleva-011974@postgrespro.ru", "phone": "+70143039837"}
0005435488447	51C50C	6209 377030	IRINA YAKOVLEVA	{"email": "yakovleva-irina-061983@postgrespro.ru", "phone": "+70468775337"}
0005435490196	3D056B	6630 366313	YULIYA AFANASEVA	{"phone": "+70425194754"}
0005435488448	F472EF	1044 474462	LYUDMILA SEMENOVA	{"email": "lyudmilasemenova-011980@postgrespro.ru", "phone": "+70587194266"}
0005435488449	4E2D5D	0063 272872	MARIYA KOVALEVA	{"email": "kovaleva-mariya-1965@postgrespro.ru", "phone": "+70650486668"}
0005435488450	708888	9694 033892	SVETLANA RODIONOVA	{"email": "rodionovasvetlana_081977@postgrespro.ru", "phone": "+70922862421"}
0005435488451	24247A	2948 430497	GALINA RODIONOVA	{"phone": "+70422843409"}
0005435488452	24247A	9884 822527	ELENA MATVEEVA	{"phone": "+70693508068"}
0005435488453	EF0BCA	2803 305808	BORIS KUZNECOV	{"phone": "+70466157799"}
0005435488454	EF0BCA	2057 530851	DINA DAVYDOVA	{"email": "d-davydova.09031977@postgrespro.ru", "phone": "+70455906925"}
0005435488455	B4B31F	5305 532481	PAVEL SCHERBAKOV	{"email": "pavel-scherbakov_111971@postgrespro.ru", "phone": "+70912224376"}
0005435488456	EAF079	4493 034445	LILIYA POPOVA	{"email": "liliya-popova-29011967@postgrespro.ru", "phone": "+70023281123"}
0005435488457	EAF079	6932 144530	KONSTANTIN MELNIKOV	{"email": "k-melnikov_1974@postgrespro.ru", "phone": "+70610625849"}
0005435488458	EAF079	7305 249105	GEORGIY OSIPOV	{"email": "osipov-georgiy071972@postgrespro.ru", "phone": "+70790969615"}
0005435488459	B5D996	4461 113880	MARINA GERASIMOVA	{"phone": "+70510221685"}
0005435488460	EC0D22	0752 543749	SERGEY KUDRYASHOV	{"phone": "+70147266311"}
0005435488461	65DE99	3992 981741	VYACHESLAV ANTONOV	{"email": "antonov.vyacheslav-1965@postgrespro.ru", "phone": "+70311750010"}
0005435488462	7351D8	1566 270386	VALENTINA SEMENOVA	{"phone": "+70401769313"}
0005435488463	7F02FE	7083 644929	VASILIY OSIPOV	{"phone": "+70220508149"}
0005435488464	7F02FE	9194 358152	RAISA SMIRNOVA	{"email": "smirnovaraisa-1972@postgrespro.ru", "phone": "+70182000648"}
0005435488465	9CA2CA	9492 595868	NINA KUZMINA	{"email": "kuzmina-nina071969@postgrespro.ru", "phone": "+70642020414"}
0005435488466	72B2CD	3437 187857	ARTEM SHEVCHENKO	{"email": "shevchenko.artem-061974@postgrespro.ru", "phone": "+70264345216"}
0005435488467	612016	1870 419514	EVGENIY IVANOV	{"email": "evgeniyivanov.071979@postgrespro.ru", "phone": "+70471695538"}
0005435488468	612016	7682 269237	ANDREY FILIPPOV	{"phone": "+70928446421"}
0005435488469	612016	7501 772622	ALEKSANDR AFANASEV	{"phone": "+70012030713"}
0005435488470	5054A3	4359 258173	ALEKSANDR BORISOV	{"phone": "+70665865725"}
0005435488471	5054A3	7406 969732	TIMUR PETROV	{"email": "petrov-t_111966@postgrespro.ru", "phone": "+70209791426"}
0005435488472	6CDD0F	6320 270405	OLEG TARASOV	{"email": "oleg.tarasov_1976@postgrespro.ru", "phone": "+70360685792"}
0005435488473	616F7C	3954 283587	ANASTASIYA GORBUNOVA	{"email": "gorbunovaanastasiya_1986@postgrespro.ru", "phone": "+70031521493"}
0005435488474	24A43C	4551 572745	GALINA GRISHINA	{"email": "galina-grishina041968@postgrespro.ru", "phone": "+70636249366"}
0005435488475	24A43C	5628 772880	NIKITA GUSEV	{"phone": "+70846041581"}
0005435488476	BC3EC1	9638 250758	MIKHAIL DENISOV	{"email": "denisov-m-1974@postgrespro.ru", "phone": "+70880094729"}
0005435488477	04C7E2	1973 206522	SERAFIMA KUZNECOVA	{"phone": "+70518125822"}
0005435488478	1A8CE2	1227 045577	ALBERT ZAKHAROV	{"email": "zakharov.a-23111983@postgrespro.ru", "phone": "+70152511290"}
0005435490235	931891	7230 202481	VALENTINA FOMINA	{"phone": "+70917310434"}
0005435490169	FAE7E6	6804 839352	NIKITA KOZLOV	{"phone": "+70046721041"}
0005435490170	53B2AF	2147 679871	VIKTOR PAVLOV	{"phone": "+70305472824"}
0005435490171	236534	0465 063470	LYUBOV KOVALEVA	{"email": "lyubov_kovaleva1973@postgrespro.ru", "phone": "+70693076659"}
0005435490172	236534	4146 602360	GALINA ISAEVA	{"email": "isaeva_galina.1973@postgrespro.ru", "phone": "+70730477720"}
0005435490173	236534	6412 968193	KONSTANTIN FILIPPOV	{"email": "filippov.k.051977@postgrespro.ru", "phone": "+70928436116"}
0005435490174	31E286	3283 202684	EVGENIY GUSEV	{"email": "evgeniy.gusev18081969@postgrespro.ru", "phone": "+70782721947"}
0005435490175	31E286	0518 005716	RAISA FADEEVA	{"phone": "+70098378588"}
0005435490176	CC44B9	1113 107676	NATALYA CHERNOVA	{"phone": "+70823163152"}
0005435490177	2926CE	3057 628792	DARYA GAVRILOVA	{"phone": "+70740409277"}
0005435490178	E7BF8F	5263 709594	NIKOLAY KUZMIN	{"phone": "+70657686011"}
0005435490179	E7BF8F	0461 665566	NATALYA KUZNECOVA	{"email": "n_kuznecova_031960@postgrespro.ru", "phone": "+70568839381"}
0005435490180	E7BF8F	1925 525319	TATYANA NAZAROVA	{"phone": "+70835524112"}
0005435490181	4B2E05	0994 831471	ALEKSEY SCHERBAKOV	{"email": "aleksey_scherbakov121978@postgrespro.ru", "phone": "+70165932966"}
0005435490182	74C479	2065 227433	ALEKSANDR NAUMOV	{"phone": "+70704834909"}
0005435490183	A42502	3972 577794	ALEKSANDR GORBUNOV	{"email": "a_gorbunov.1984@postgrespro.ru", "phone": "+70978399365"}
0005435490184	E27617	0066 764792	YULIYA YAKOVLEVA	{"phone": "+70893422386"}
0005435490185	128163	2979 255854	MIKHAIL DMITRIEV	{"email": "dmitrievmikhail_1982@postgrespro.ru", "phone": "+70970637217"}
0005435490186	329C5A	2122 564950	VLADIMIR KULIKOV	{"email": "kulikov.v.011978@postgrespro.ru", "phone": "+70223005524"}
0005435490187	329C5A	3855 020650	MARGARITA RODIONOVA	{"phone": "+70361460367"}
0005435490188	7A08DA	5774 523354	ANDREY MIRONOV	{"phone": "+70958635502"}
0005435490189	092DBC	0021 002919	TATYANA KUZNECOVA	{"phone": "+70051367778"}
0005435490190	602D24	7087 760961	DENIS FROLOV	{"email": "denis.frolov_1965@postgrespro.ru", "phone": "+70630180971"}
0005435490191	BB5962	1903 634498	KIRILL ZAKHAROV	{"email": "kirill_zakharov.24091974@postgrespro.ru", "phone": "+70136867195"}
0005435490192	8A81E5	5362 286053	ALEKSEY SIDOROV	{"email": "a.sidorov_101967@postgrespro.ru", "phone": "+70573233027"}
0005435490193	B217B0	2365 568982	ALEKSEY NOVIKOV	{"email": "novikov_aleksey11041971@postgrespro.ru", "phone": "+70378260116"}
0005435490194	B217B0	1341 335213	EVGENIY VOLKOV	{"email": "volkov-e.10021974@postgrespro.ru", "phone": "+70782560021"}
0005435490195	3D056B	3999 990307	VALERIY MIKHAYLOV	{"email": "mikhaylov_valeriy_24081980@postgrespro.ru", "phone": "+70862198950"}
0005435490197	9094B2	7516 551893	IRINA KISELEVA	{"email": "ikiseleva.121971@postgrespro.ru", "phone": "+70966584716"}
0005435490198	9094B2	8733 374682	ALEKSANDR FILIPPOV	{"email": "filippov.a-1981@postgrespro.ru", "phone": "+70216311981"}
0005435490199	88CB60	3812 081818	NIKOLAY ZAKHAROV	{"email": "zakharov_nikolay_111964@postgrespro.ru", "phone": "+70554221704"}
0005435490200	88CB60	3481 352553	AYRAT IVANOV	{"phone": "+70338993949"}
0005435490201	4E4086	6655 696724	YURIY ZHUKOV	{"phone": "+70273205956"}
0005435490202	9D50FA	1510 983804	MARINA FILIPPOVA	{"email": "marina-filippova-1975@postgrespro.ru", "phone": "+70220845721"}
0005435490203	7105F7	3476 357037	LYUBOV LUKYANOVA	{"email": "lukyanova-lyubov_23091965@postgrespro.ru", "phone": "+70759944980"}
0005435490204	B8C0AC	2938 025903	LYUDMILA MOISEEVA	{"phone": "+70877638842"}
0005435490205	B8C0AC	4566 458864	NIKITA GUSEV	{"phone": "+70016867619"}
0005435490206	90B599	2004 339889	TATYANA CHERNOVA	{"email": "chernova-t_031984@postgrespro.ru", "phone": "+70534003041"}
0005435490207	90B599	1820 330867	ELENA ZAKHAROVA	{"email": "e_zakharova_1973@postgrespro.ru", "phone": "+70056077485"}
0005435490208	D89A7D	5344 082703	DENIS MIKHAYLOV	{"phone": "+70696395090"}
0005435490209	E72486	7483 281216	VIKTORIYA LUKYANOVA	{"phone": "+70092564222"}
0005435490210	E72486	0421 093057	NADEZHDA OVCHINNIKOVA	{"email": "nadezhda.ovchinnikova.101986@postgrespro.ru", "phone": "+70767321895"}
0005435490211	E84CB4	4010 079198	VLADIMIR KOROLEV	{"phone": "+70951260967"}
0005435490212	A6E6A1	6096 549723	PAVEL BELOV	{"phone": "+70176564848"}
0005435490213	A3D057	2291 069862	ALEKSEY OSIPOV	{"phone": "+70422695377"}
0005435490214	142B2C	2000 303370	RASHID KARPOV	{"email": "rashid.karpov_1967@postgrespro.ru", "phone": "+70909782192"}
0005435490215	142B2C	1540 723521	VYACHESLAV VASILEV	{"phone": "+70899867501"}
0005435490216	EB0616	5199 377874	VLADIMIR KISELEV	{"phone": "+70630941806"}
0005435490217	61CD81	4286 390465	NATALYA ZAYCEVA	{"phone": "+70153252523"}
0005435490218	1F26E7	3775 735550	MAKSIM DMITRIEV	{"phone": "+70582466499"}
0005435490219	D01639	0850 293383	MARINA BORISOVA	{"phone": "+70178509062"}
0005435490220	D0C313	9357 008234	TATYANA DENISOVA	{"email": "denisovat.1978@postgrespro.ru", "phone": "+70563774193"}
0005435490221	DD1CD1	9596 653740	MAKSIM FROLOV	{"email": "maksim.frolov-03091974@postgrespro.ru", "phone": "+70944366003"}
0005435490222	5FC7E7	0665 371332	OLGA MASLOVA	{"email": "olga.maslova.1975@postgrespro.ru", "phone": "+70437760963"}
0005435490223	DD4956	9966 312075	SERGEY SERGEEV	{"phone": "+70358249138"}
0005435490224	39D564	8722 374271	ANNA KONOVALOVA	{"email": "konovalova.a.021973@postgrespro.ru", "phone": "+70328068578"}
0005435490225	BABDD0	1539 777751	IVAN KUZNECOV	{"phone": "+70054312731"}
0005435490226	BABDD0	5648 830604	SVETLANA MAKSIMOVA	{"email": "maksimova_svetlana-021965@postgrespro.ru", "phone": "+70613181745"}
0005435490227	7E5A1F	3594 503405	VIKTOR KUZNECOV	{"email": "viktor-kuznecov-1968@postgrespro.ru", "phone": "+70553501669"}
0005435490228	7E5A1F	6786 230187	VALENTINA ZAKHAROVA	{"email": "zakharova.valentina1968@postgrespro.ru", "phone": "+70403192885"}
0005435490229	6EEA22	5446 146272	ANDREY SAVELEV	{"email": "andrey.savelev_1972@postgrespro.ru", "phone": "+70781193478"}
0005435490230	E053C8	5167 798785	VALENTINA LAZAREVA	{"email": "lazarevav-1967@postgrespro.ru", "phone": "+70121335327"}
0005435490231	E053C8	3652 413459	ARTEM GAVRILOV	{"phone": "+70860273661"}
0005435490232	4B4A1E	6529 133701	POLINA POPOVA	{"email": "polina-popova021973@postgrespro.ru", "phone": "+70934200839"}
0005435490233	2C546E	0036 211207	TATYANA ANDREEVA	{"email": "tatyana_andreeva-08101971@postgrespro.ru", "phone": "+70966291957"}
0005435490234	931891	8832 405177	VLADIMIR BELOV	{"phone": "+70757033023"}
0005435490236	931891	9554 724577	EKATERINA KONOVALOVA	{"email": "ekaterinakonovalova_1983@postgrespro.ru", "phone": "+70815207180"}
0005435490237	B83E58	7016 793143	YULIYA TARASOVA	{"email": "ytarasova1972@postgrespro.ru", "phone": "+70308105845"}
0005435490238	49C6B9	2631 414624	VERA MOROZOVA	{"email": "morozovav-1987@postgrespro.ru", "phone": "+70451184678"}
0005435490239	5919F8	6078 413419	VLADISLAV KRASNOV	{"email": "v-krasnov-16061980@postgrespro.ru", "phone": "+70648843215"}
0005435490240	5919F8	7062 689106	VLADIMIR MAKAROV	{"phone": "+70666852681"}
0005435490241	B4FA0A	9442 175999	ALEKSANDRA ANDREEVA	{"email": "andreeva-a_15031972@postgrespro.ru", "phone": "+70878691955"}
0005435490242	154DAB	5890 171682	ELZA ZAKHAROVA	{"email": "zakharova.elza.1965@postgrespro.ru", "phone": "+70306756247"}
0005435490243	2B5B4E	7458 293667	ANATOLIY PETROV	{"phone": "+70342609631"}
0005435490244	D632E9	2497 887678	EVGENIYA SMIRNOVA	{"email": "smirnovae.071962@postgrespro.ru", "phone": "+70607869734"}
0005435490245	D632E9	4624 685492	NADEZHDA OVCHINNIKOVA	{"phone": "+70800146968"}
0005435490246	E16F10	8847 527549	ANTON KUZMIN	{"email": "antonkuzmin_23121973@postgrespro.ru", "phone": "+70783811266"}
0005435490247	E16F10	1114 632564	VIKTOR SMIRNOV	{"phone": "+70556917287"}
0005435490248	28419C	9787 310727	EKATERINA NIKOLAEVA	{"phone": "+70611480361"}
0005435490249	DDF3C6	3299 098234	LYUBOV VASILEVA	{"email": "vasileva.l-27111965@postgrespro.ru", "phone": "+70232149262"}
0005435490250	193A52	2772 512649	VIKTOR FOMIN	{"phone": "+70326268892"}
0005435490251	F14DB1	7776 503430	RAISA KRASNOVA	{"email": "krasnovaraisa-25011970@postgrespro.ru", "phone": "+70636488377"}
0005435490252	F14DB1	0926 420355	SERGEY PAVLOV	{"email": "pavlovsergey.31101974@postgrespro.ru", "phone": "+70905034527"}
0005435490253	19519C	4669 964201	ALEKSEY MELNIKOV	{"phone": "+70136095692"}
0005435490254	2CBE78	7735 546195	VALENTINA LUKYANOVA	{"email": "lukyanovav.111973@postgrespro.ru", "phone": "+70961026542"}
0005435490255	115FDA	8291 043284	TATYANA KOVALEVA	{"phone": "+70410680203"}
0005435490256	115FDA	1951 205105	NATALYA KUDRYASHOVA	{"phone": "+70995107516"}
0005435491502	EF6F71	9171 261996	ULYANA ORLOVA	{"phone": "+70594202013"}
0005435490257	115FDA	1703 802145	MARGARITA KUZMINA	{"email": "kuzminamargarita-1970@postgrespro.ru", "phone": "+70316980086"}
0005435490258	601868	1025 163727	NIKITA KUZNECOV	{"phone": "+70755145512"}
0005435490259	E5220E	5340 373536	MIKHAIL MIRONOV	{"email": "mikhail-mironov031975@postgrespro.ru", "phone": "+70037715193"}
0005435490260	79C64B	8196 257447	VIKTORIYA KUZNECOVA	{"phone": "+70295897629"}
0005435490261	79C64B	3381 396019	OLGA NESTEROVA	{"phone": "+70600914761"}
0005435490262	1CBADA	4958 758126	OKSANA SEMENOVA	{"email": "oksana_semenova_23041981@postgrespro.ru", "phone": "+70174864250"}
0005435490263	1CBADA	7254 139244	IGOR MAKAROV	{"phone": "+70956301570"}
0005435490264	D2DCFD	4153 858655	OLEG MATVEEV	{"email": "oleg.matveev_081959@postgrespro.ru", "phone": "+70056434800"}
0005435490265	275157	0502 490298	NADEZHDA MOROZOVA	{"phone": "+70613676492"}
0005435490266	2BF828	3771 123453	ELENA KALININA	{"email": "e-kalinina031972@postgrespro.ru", "phone": "+70945374045"}
0005435490267	2BF828	9440 919722	ALENA FROLOVA	{"phone": "+70438889619"}
0005435490268	F7132D	2412 474319	ALEKSEY FEDOTOV	{"phone": "+70004101090"}
0005435490269	F7132D	0806 903500	NIKOLAY ALEKSEEV	{"email": "nalekseev_17031985@postgrespro.ru", "phone": "+70456717332"}
0005435490270	FB7C62	6568 743581	DMITRIY BONDARENKO	{"email": "bondarenko.d_1982@postgrespro.ru", "phone": "+70062862188"}
0005435490271	FAA291	9605 035678	ROMAN SCHERBAKOV	{"email": "r_scherbakov011979@postgrespro.ru", "phone": "+70522664667"}
0005435490272	4D9FBC	0898 547567	ELENA SAVELEVA	{"email": "saveleva_elena-1968@postgrespro.ru", "phone": "+70535391108"}
0005435490273	3F7C5E	1628 343747	EVGENIYA PETROVA	{"phone": "+70387110888"}
0005435490274	3F7C5E	1384 691218	OLGA SOKOLOVA	{"email": "o.sokolova.1964@postgrespro.ru", "phone": "+70151756506"}
0005435490275	7FA922	0896 301767	ELENA BORISOVA	{"phone": "+70597803477"}
0005435490276	931E8A	1327 672970	MIKHAIL SEMENOV	{"email": "semenov_m-08101976@postgrespro.ru", "phone": "+70409939760"}
0005435490277	B39AC4	6040 886267	YULIYA KARPOVA	{"phone": "+70485444269"}
0005435490278	B39AC4	8272 045817	ANASTASIYA VOLKOVA	{"phone": "+70158334497"}
0005435490279	24DE3B	9470 097323	VALENTINA FILATOVA	{"phone": "+70094708372"}
0005435490280	24DE3B	2773 740670	ALEKSANDR ANDREEV	{"phone": "+70133786428"}
0005435490281	DE7BF0	2846 347822	ALEKSANDR NAZAROV	{"email": "nazarov_a_051965@postgrespro.ru", "phone": "+70520663716"}
0005435490282	73AC4E	3981 410263	GALINA NIKIFOROVA	{"email": "g.nikiforova-1976@postgrespro.ru", "phone": "+70490933651"}
0005435490283	BD4C29	2393 207248	NATALYA MAKAROVA	{"email": "n-makarova-021975@postgrespro.ru", "phone": "+70090746100"}
0005435490284	70B96A	9194 160463	NINA TARASOVA	{"email": "n.tarasova_121973@postgrespro.ru", "phone": "+70178544446"}
0005435490285	AB5F5E	9571 655756	EVGENIY PETROV	{"email": "evgeniy_petrov.051979@postgrespro.ru", "phone": "+70416320793"}
0005435490286	921FF9	8091 145358	KONSTANTIN KUZNECOV	{"email": "kuznecov-konstantin.1970@postgrespro.ru", "phone": "+70223155741"}
0005435490287	9A8754	8662 297998	IRINA ZHURAVLEVA	{"email": "irinazhuravleva-071978@postgrespro.ru", "phone": "+70340957188"}
0005435490288	6E7994	8286 236130	FANIYA YAKOVLEVA	{"phone": "+70422405036"}
0005435490289	6F01EA	9167 821448	VYACHESLAV AFANASEV	{"phone": "+70364599915"}
0005435490290	2B3760	0358 329644	TATYANA FROLOVA	{"email": "frolova.t.16041978@postgrespro.ru", "phone": "+70355795129"}
0005435490291	67CA25	3602 715520	ANNA RYABOVA	{"email": "aryabova30081972@postgrespro.ru", "phone": "+70495158993"}
0005435490292	67CA25	7607 558623	IGOR MATVEEV	{"phone": "+70526788200"}
0005435490293	F70F62	0003 696755	DMITRIY SOROKIN	{"email": "dmitriy-sorokin13091970@postgrespro.ru", "phone": "+70186932323"}
0005435490294	F70F62	4541 141100	EVA POPOVA	{"email": "popovaeva10091964@postgrespro.ru", "phone": "+70462092444"}
0005435490295	14721A	6782 253134	VIKTOR IVANOV	{"phone": "+70195041405"}
0005435490296	14721A	9883 630718	EVGENIY IVANOV	{"phone": "+70696696692"}
0005435490297	9B8652	0772 382596	ZINAIDA AKIMOVA	{"phone": "+70427755781"}
0005435490298	15E2E0	9044 609884	ALEKSEY STEPANOV	{"phone": "+70383740092"}
0005435490299	15E2E0	5080 960179	TATYANA VASILEVA	{"phone": "+70829799625"}
0005435490300	15E2E0	0384 034329	SVETLANA SERGEEVA	{"email": "sergeeva-svetlana1982@postgrespro.ru", "phone": "+70127678443"}
0005435490301	63C889	4838 605062	ALEKSEY KRASNOV	{"email": "a-krasnov03081980@postgrespro.ru", "phone": "+70447518651"}
0005435490302	63C889	9206 320987	ARTEM MEDVEDEV	{"email": "medvedev.a_1963@postgrespro.ru", "phone": "+70283667257"}
0005435490303	7E5B81	0870 533216	IVAN FILIPPOV	{"email": "ifilippov-11111970@postgrespro.ru", "phone": "+70048589968"}
0005435490304	7E5B81	0677 299485	ELENA BORISOVA	{"email": "e_borisova-1983@postgrespro.ru", "phone": "+70372000683"}
0005435490305	EAAE11	4841 768704	ROZA NOVIKOVA	{"email": "r.novikova-101972@postgrespro.ru", "phone": "+70681027095"}
0005435490306	EAAE11	2539 377092	VIKTOR SCHERBAKOV	{"email": "viktor-scherbakov1967@postgrespro.ru", "phone": "+70308990237"}
0005435490307	F20196	5034 786288	NIKITA OSIPOV	{"email": "osipov_n-1974@postgrespro.ru", "phone": "+70308917280"}
0005435490308	56D6CE	3830 024084	AZAT CHERNOV	{"email": "chernova.121982@postgrespro.ru", "phone": "+70773304547"}
0005435490309	5E3635	6787 087888	SVETLANA KOZLOVA	{"phone": "+70589972191"}
0005435490310	277A1F	8607 814221	DMITRIY POPOV	{"email": "d_popov.031970@postgrespro.ru", "phone": "+70090117764"}
0005435490311	1C5A96	5998 427799	GALINA KONDRATEVA	{"phone": "+70246423748"}
0005435490312	1C5A96	3273 636093	EVDOKIYA ANISIMOVA	{"phone": "+70114047898"}
0005435490313	2F0316	4826 467452	ALINA TIKHONOVA	{"email": "tikhonova.a-1970@postgrespro.ru", "phone": "+70157410813"}
0005435490314	691CD0	2602 175732	LYUDMILA POPOVA	{"email": "popova-l.16011976@postgrespro.ru", "phone": "+70539474532"}
0005435490315	F534F8	6250 480296	IVAN KOROLEV	{"phone": "+70339092899"}
0005435490316	F534F8	2253 458913	SERGEY SMIRNOV	{"email": "sergey.smirnov01091974@postgrespro.ru", "phone": "+70522742272"}
0005435490317	8957DB	5318 930758	MAKSIM RODIONOV	{"phone": "+70779479346"}
0005435490318	ED5EB4	8768 326164	MIKHAIL SMIRNOV	{"email": "smirnov-m.071966@postgrespro.ru", "phone": "+70632234034"}
0005435490319	C8B38B	1717 007540	ALENA EFIMOVA	{"email": "alena_efimova1967@postgrespro.ru", "phone": "+70230531662"}
0005435490320	489D65	2091 357527	SERGEY KAZAKOV	{"phone": "+70003747348"}
0005435490321	90376E	7287 370150	LYUDMILA NIKITINA	{"email": "lyudmila-nikitina-011974@postgrespro.ru", "phone": "+70197846423"}
0005435490322	327FE6	5644 344869	EVGENIY ZAYCEV	{"phone": "+70414900884"}
0005435490323	327FE6	2313 956608	VADIM MOROZOV	{"email": "morozov-vadim-26081986@postgrespro.ru", "phone": "+70836508866"}
0005435490324	6C9F48	7484 677199	ANATOLIY FILIPPOV	{"email": "anatoliy_filippov_111971@postgrespro.ru", "phone": "+70189419198"}
0005435490325	6C9F48	2931 613887	NIKITA TARASOV	{"phone": "+70454108023"}
0005435490326	47EB23	9397 161869	SVETLANA MATVEEVA	{"phone": "+70529761022"}
0005435490327	47FE16	0087 260504	ASIYA ERMAKOVA	{"email": "ermakova.asiya.19041976@postgrespro.ru", "phone": "+70831161020"}
0005435490328	47FE16	3855 011202	ANASTASIYA RODIONOVA	{"email": "rodionovaanastasiya.09111971@postgrespro.ru", "phone": "+70833244144"}
0005435490329	BB0603	8078 611407	GEORGIY NOVIKOV	{"phone": "+70040833536"}
0005435490330	6B9967	8260 807645	NIKOLAY YAKOVLEV	{"email": "n-yakovlev.1971@postgrespro.ru", "phone": "+70560942117"}
0005435490331	14846C	6408 033059	VERA EGOROVA	{"phone": "+70423847909"}
0005435490332	2D6C13	6171 436888	ELENA KOZLOVA	{"email": "kozlova.elena.091973@postgrespro.ru", "phone": "+70620170132"}
0005435490333	2D6C13	0743 818141	YURIY KOZLOV	{"phone": "+70988564211"}
0005435490334	2D6C13	6495 463086	MARIYA FROLOVA	{"phone": "+70676668173"}
0005435490335	693AAF	7937 883180	DMITRIY VASILEV	{"email": "dmitriy_vasilev-071976@postgrespro.ru", "phone": "+70365023984"}
0005435490336	FACB27	3211 610766	LYUDMILA FROLOVA	{"phone": "+70888604625"}
0005435490337	A25281	5405 923534	PAVEL KUZNECOV	{"email": "pavel-kuznecov_24121970@postgrespro.ru", "phone": "+70070170009"}
0005435490338	50EC3F	0484 817087	OLGA KOZLOVA	{"email": "okozlova-031972@postgrespro.ru", "phone": "+70828130154"}
0005435490339	50EC3F	3030 438122	VLADIMIR DENISOV	{"email": "denisov.v-011966@postgrespro.ru", "phone": "+70553188240"}
0005435491467	FCD525	5535 640258	LARISA VASILEVA	{"phone": "+70804551415"}
0005435491405	04B235	8846 041364	MARIYA GERASIMOVA	{"phone": "+70841473179"}
0005435491406	6760E6	5030 305859	VERA NIKITINA	{"email": "nikitinav_20101956@postgrespro.ru", "phone": "+70929331700"}
0005435491407	1A9592	8608 782434	VLADIMIR ALEKSEEV	{"phone": "+70553269480"}
0005435491408	C2ED61	9828 517650	IGOR KUZMIN	{"phone": "+70845279847"}
0005435491409	6F8927	0756 241542	PAVEL SOKOLOV	{"email": "pavel-sokolov051981@postgrespro.ru", "phone": "+70381655422"}
0005435491410	0EE629	2093 438761	NATALYA KOLESNIKOVA	{"email": "kolesnikovanatalya25101964@postgrespro.ru", "phone": "+70778555138"}
0005435491411	A08C22	5426 992088	LIDIYA GERASIMOVA	{"email": "lidiyagerasimova.111971@postgrespro.ru", "phone": "+70243868460"}
0005435491412	A08C22	3978 362569	ALEKSANDR SOROKIN	{"phone": "+70081486745"}
0005435491413	956F80	2901 229854	RIMMA IVANOVA	{"email": "ivanova.r121964@postgrespro.ru", "phone": "+70921403225"}
0005435491414	956F80	2307 368115	GENNADIY KUZNECOV	{"phone": "+70723383010"}
0005435491415	C90844	9734 323626	ALINA NIKOLAEVA	{"phone": "+70314070809"}
0005435491416	8A1B68	2547 368210	ARTEM CHERNOV	{"phone": "+70999197093"}
0005435491417	843D16	8069 554863	OKSANA DMITRIEVA	{"phone": "+70329630708"}
0005435491418	843D16	8328 568184	ANDREY YAKOVLEV	{"phone": "+70598887094"}
0005435491419	45A528	6830 201734	ELENA ANDREEVA	{"email": "andreevae071965@postgrespro.ru", "phone": "+70949081889"}
0005435491420	0B1B8B	8316 901250	VLADIMIR ALEKSEEV	{"email": "vladimir.alekseev_061971@postgrespro.ru", "phone": "+70119161859"}
0005435491421	E78720	2164 031173	RINAT KRASNOV	{"phone": "+70340053783"}
0005435491422	E78720	9494 407619	SAVELIY IVANOV	{"email": "ivanov-saveliy.29011981@postgrespro.ru", "phone": "+70610081081"}
0005435491423	2F3A02	0625 573364	DMITRIY SMIRNOV	{"email": "dsmirnov-1962@postgrespro.ru", "phone": "+70981906673"}
0005435491424	174E67	1044 169081	DARYA AKIMOVA	{"email": "akimovad.11021970@postgrespro.ru", "phone": "+70218746404"}
0005435491425	174E67	6379 290213	ANTON NAZAROV	{"email": "nazarov.anton_011974@postgrespro.ru", "phone": "+70221509007"}
0005435491426	5754F2	7330 529113	OLGA PAVLOVA	{"email": "o.pavlova1970@postgrespro.ru", "phone": "+70420735181"}
0005435491427	5754F2	9583 100192	YULIYA STEPANOVA	{"email": "y-stepanova_1977@postgrespro.ru", "phone": "+70370105850"}
0005435491428	D14E35	1498 514436	EKATERINA NOVIKOVA	{"phone": "+70272334417"}
0005435491429	E25DDB	7378 361208	IRINA ORLOVA	{"email": "orlovairina16111974@postgrespro.ru", "phone": "+70135906599"}
0005435491430	F2AAD0	0473 125998	ALEKSANDR VASILEV	{"phone": "+70925525131"}
0005435491431	890254	3281 608595	NATALYA PETROVA	{"email": "petrova.natalya_051967@postgrespro.ru", "phone": "+70534082610"}
0005435491432	1302A2	1174 263731	DMITRIY VLASOV	{"phone": "+70684728606"}
0005435491433	2A5A84	7152 275156	SAVELIY KULIKOV	{"email": "kulikov-s17011972@postgrespro.ru", "phone": "+70986842120"}
0005435491434	B67FC0	7139 112735	IRINA KUZNECOVA	{"email": "kuznecovai.1979@postgrespro.ru", "phone": "+70262758530"}
0005435491435	CBD554	9333 136446	ANDREY BORISOV	{"phone": "+70632809802"}
0005435491436	9328FE	6791 389916	ANTON TIMOFEEV	{"phone": "+70443260345"}
0005435491437	08326E	9168 558482	SERGEY KUZNECOV	{"email": "sergey-kuznecov_051980@postgrespro.ru", "phone": "+70501823966"}
0005435491438	08326E	0826 649388	ANDREY POPOV	{"phone": "+70614261581"}
0005435491439	ADC892	1158 316975	MARTA MEDVEDEVA	{"phone": "+70367126983"}
0005435491440	81ED04	8855 952098	GENNADIY BARANOV	{"email": "baranov.g.1970@postgrespro.ru", "phone": "+70577993546"}
0005435491441	81ED04	4889 726679	GENNADIY KOROLEV	{"phone": "+70466309103"}
0005435491442	81ED04	6427 334936	ELENA TIKHONOVA	{"email": "tikhonovae.1967@postgrespro.ru", "phone": "+70561866455"}
0005435491443	B2D1B5	3373 233657	NINA EGOROVA	{"email": "egorova-n.071980@postgrespro.ru", "phone": "+70636018600"}
0005435491444	EEF36B	8342 569380	MIKHAIL STEPANOV	{"phone": "+70920003514"}
0005435491445	F4E1C1	8436 588584	NADEZHDA PETROVA	{"phone": "+70116779748"}
0005435491446	5847AC	4916 586658	RIFAT BELOV	{"phone": "+70160212013"}
0005435491447	09168C	6002 885243	ALEKSANDR TIMOFEEV	{"email": "a_timofeev_121964@postgrespro.ru", "phone": "+70547326388"}
0005435491448	916883	4739 413340	IRINA CHERNOVA	{"phone": "+70382114575"}
0005435491449	28F82E	7175 033076	VLADISLAV POPOV	{"email": "vpopov03061981@postgrespro.ru", "phone": "+70785769573"}
0005435491450	F6CC24	1744 441767	YULIYA PAVLOVA	{"email": "yuliya.pavlova_24021975@postgrespro.ru", "phone": "+70169212739"}
0005435491451	DC6946	1816 879383	RAISA SOKOLOVA	{"email": "r_sokolova31101969@postgrespro.ru", "phone": "+70169843371"}
0005435491452	DC6946	9092 434853	VLADIMIR MELNIKOV	{"phone": "+70859774169"}
0005435491453	64D8A5	9880 986378	ALEKSANDR KOZLOV	{"phone": "+70382222769"}
0005435491454	64D8A5	7252 447472	TATYANA EFREMOVA	{"email": "tatyana.efremova-1978@postgrespro.ru", "phone": "+70518803120"}
0005435491455	5292F5	7313 859695	YULIYA ANTONOVA	{"phone": "+70901264627"}
0005435491456	1628F3	3957 967405	EKATERINA KARPOVA	{"phone": "+70704772648"}
0005435491457	C9C5F2	3266 075874	KLAVDIYA POPOVA	{"email": "popovak.01101986@postgrespro.ru", "phone": "+70054131939"}
0005435491458	C9C5F2	7209 496395	ELENA DAVYDOVA	{"phone": "+70174454316"}
0005435491459	7E58E2	8759 572128	ELENA SMIRNOVA	{"email": "smirnova-e011965@postgrespro.ru", "phone": "+70642420588"}
0005435491460	D8A343	7391 239723	ELENA NIKOLAEVA	{"email": "nikolaeva-elena.1969@postgrespro.ru", "phone": "+70769686653"}
0005435491461	94E808	1267 378472	SERGEY GRIGOREV	{"phone": "+70001665090"}
0005435491462	733C10	1740 246970	ALEKSEY GERASIMOV	{"email": "gerasimova_1979@postgrespro.ru", "phone": "+70504563825"}
0005435491463	CDF28D	8652 823068	TAMARA BORISOVA	{"phone": "+70692859747"}
0005435491464	CDF28D	5313 359433	NIKOLAY ALEKSANDROV	{"email": "n_aleksandrov-07061968@postgrespro.ru", "phone": "+70181543997"}
0005435491465	CDF28D	0916 722995	ANNA ZHUKOVA	{"phone": "+70251143639"}
0005435491466	F8756C	6212 329993	NIKOLAY VOROBEV	{"phone": "+70346048968"}
0005435491468	8D9DAA	6824 151593	DMITRIY SERGEEV	{"email": "d_sergeev-1973@postgrespro.ru", "phone": "+70058898950"}
0005435491469	8D9DAA	9627 859788	ELENA ILINA	{"email": "ilina-elena_1974@postgrespro.ru", "phone": "+70455920623"}
0005435491470	64D806	1091 597605	ANASTASIYA DANILOVA	{"email": "a-danilova.111976@postgrespro.ru", "phone": "+70914639547"}
0005435491471	64D806	5167 974193	MAKSIM KUZNECOV	{"email": "m.kuznecov_021980@postgrespro.ru", "phone": "+70018111201"}
0005435491472	64D806	0934 115295	ALEKSANDR FROLOV	{"email": "aleksandr_frolov_1972@postgrespro.ru", "phone": "+70009075276"}
0005435491473	850BF1	5897 061854	ILYA KOZLOV	{"phone": "+70542073010"}
0005435491474	850BF1	2350 982945	DMITRIY NAUMOV	{"email": "naumov.d_1969@postgrespro.ru", "phone": "+70192439380"}
0005435491475	46062F	3547 153776	SERGEY KUZNECOV	{"email": "kuznecovs.22041974@postgrespro.ru", "phone": "+70534652528"}
0005435491476	DABA7E	8262 403679	ALIYA ZAYCEVA	{"phone": "+70162391819"}
0005435491477	AD94C6	6890 826555	LIDIYA PAVLOVA	{"phone": "+70892573063"}
0005435491478	45FD42	0376 404058	SERGEY KULIKOV	{"email": "sergey-kulikov.05011974@postgrespro.ru", "phone": "+70646836977"}
0005435491479	A8D4F3	7647 554125	ANASTASIYA ILINA	{"phone": "+70696298189"}
0005435491480	BCFBDC	2127 845448	NATALYA KULIKOVA	{"email": "nkulikova-29041970@postgrespro.ru", "phone": "+70537571118"}
0005435491481	43C73C	6604 430289	BORIS YAKOVLEV	{"phone": "+70932346646"}
0005435491482	85F6D6	9263 140615	ELENA NIKITINA	{"email": "e_nikitina091979@postgrespro.ru", "phone": "+70798965113"}
0005435491483	21BF60	4695 812530	IRINA ARKHIPOVA	{"email": "irina_arkhipova-1980@postgrespro.ru", "phone": "+70300387969"}
0005435491484	21BF60	2108 142395	ALEKSANDR KARPOV	{"email": "karpov-aleksandr.26081969@postgrespro.ru", "phone": "+70439192797"}
0005435491485	21BF60	9161 323565	TAMARA ANISIMOVA	{"email": "t_anisimova1979@postgrespro.ru", "phone": "+70187448588"}
0005435491486	16737E	0693 267443	ANATOLIY MEDVEDEV	{"phone": "+70058215780"}
0005435491487	4A50E5	5794 451602	RAMIL KRASNOV	{"phone": "+70341948584"}
0005435491488	9BDCB6	8816 107546	ALEKSANDR TIMOFEEV	{"phone": "+70401507937"}
0005435491489	90BEE1	5704 567761	VIKTORIYA ALEKSANDROVA	{"phone": "+70411764751"}
0005435491490	4E708C	9161 372545	ALEKSANDR MELNIKOV	{"phone": "+70995460025"}
0005435491491	4E708C	5842 984972	IGOR CHERNOV	{"phone": "+70981999027"}
0005435491492	9F9445	7648 256033	OLGA SOROKINA	{"email": "olgasorokina-30101980@postgrespro.ru", "phone": "+70682468995"}
0005435491493	9F9445	7525 132850	LIDIYA NIKITINA	{"phone": "+70305959951"}
0005435491494	447C6C	4761 780229	NATALYA ANISIMOVA	{"phone": "+70354916970"}
0005435491495	7829C0	6401 313355	SERGEY VOLKOV	{"email": "s.volkov_11121985@postgrespro.ru", "phone": "+70383434803"}
0005435491496	861D15	5051 645687	ANATOLIY TARASOV	{"email": "anatoliytarasov.20021963@postgrespro.ru", "phone": "+70536164305"}
0005435491497	F33F4D	3190 606478	NATALYA IVANOVA	{"phone": "+70961916662"}
0005435491498	6D6B0D	3443 852769	ELENA FADEEVA	{"phone": "+70235669806"}
0005435491499	7B8CDE	9263 807184	NINEL ZAKHAROVA	{"email": "ninelzakharova05091964@postgrespro.ru", "phone": "+70029221090"}
0005435491500	7B8CDE	7947 921730	EGOR VASILEV	{"phone": "+70189730261"}
0005435491501	2F619E	9322 222953	LYUBOV EFREMOVA	{"phone": "+70412879040"}
0005435491503	B15CAB	2400 670282	ANNA ZHUKOVA	{"phone": "+70877039202"}
0005435491504	2A86ED	6892 724824	ALEKSANDR OSIPOV	{"email": "aosipov.23011974@postgrespro.ru", "phone": "+70794004206"}
0005435491505	568829	5676 999165	MARGARITA GORBUNOVA	{"email": "gorbunova_margarita_1968@postgrespro.ru", "phone": "+70967809540"}
0005435491506	312A21	0571 671249	IVAN BORISOV	{"email": "borisov-i-121974@postgrespro.ru", "phone": "+70982061956"}
0005435491507	736128	6579 527566	NIKOLAY PETROV	{"phone": "+70956101878"}
0005435491508	898ABF	1089 609678	TATYANA MAKSIMOVA	{"email": "maksimova_tatyana.1974@postgrespro.ru", "phone": "+70025834221"}
0005435491509	898ABF	8841 727923	NINA SOLOVEVA	{"phone": "+70859947129"}
0005435501931	A5B52B	0975 264132	RADIK FOMIN	{"email": "radik_fomin081991@postgrespro.ru", "phone": "+70749271766"}
0005435501932	F4B6E8	4988 851591	ILYA SMIRNOV	{"phone": "+70826234936"}
0005435501933	4BA3A5	9736 144397	SVETLANA GERASIMOVA	{"email": "gerasimova.svetlana-22061968@postgrespro.ru", "phone": "+70512219631"}
0005435501934	5D7362	6414 451673	TATYANA TITOVA	{"email": "titova-tatyana-14081972@postgrespro.ru", "phone": "+70957744040"}
0005435501935	ECF569	7105 096632	VITALIY PAVLOV	{"email": "vpavlov-031974@postgrespro.ru", "phone": "+70913886094"}
0005435501936	ECF569	7774 360724	ALEKSEY KUDRYASHOV	{"phone": "+70716470912"}
0005435501937	ECF569	1520 942698	MAKSIM CHERNOV	{"email": "m_chernov10011975@postgrespro.ru", "phone": "+70286046734"}
0005435501938	4EAA0F	3701 246118	GALINA NIKITINA	{"phone": "+70243339630"}
0005435501939	8B5314	2383 383009	VALENTINA KUZNECOVA	{"phone": "+70772096322"}
0005435501940	8B5314	3029 559041	REGINA KRASNOVA	{"email": "krasnovaregina_031982@postgrespro.ru", "phone": "+70019942218"}
0005435501941	D2B016	7435 689738	NATALYA NOVIKOVA	{"email": "nnovikova-1975@postgrespro.ru", "phone": "+70261857838"}
0005435501942	D323AC	1538 803755	OLGA GRISHINA	{"phone": "+70508302023"}
0005435501943	D323AC	2182 371251	VERA ALEKSEEVA	{"email": "v-alekseeva23081974@postgrespro.ru", "phone": "+70130088234"}
0005435501944	F227C4	3495 708608	ALISHER GRIGOREV	{"phone": "+70644966154"}
0005435501945	82D2E0	3810 674180	IRINA KOMAROVA	{"phone": "+70535688228"}
0005435501946	D8F438	6421 135197	IRINA RYABOVA	{"email": "ryabova_irina.101971@postgrespro.ru", "phone": "+70816149596"}
0005435501947	FD8D4F	6833 500881	LIDIYA KONDRATEVA	{"phone": "+70484645850"}
0005435501948	FD8D4F	6278 131247	YURIY IVANOV	{"email": "y_ivanov_071970@postgrespro.ru", "phone": "+70076576904"}
0005435501949	C9A88D	5693 398698	BORIS GAVRILOV	{"phone": "+70373795330"}
0005435501950	C88C39	1873 424777	DARYA BORISOVA	{"phone": "+70441211200"}
0005435501951	556088	0360 809781	LIDIYA ORLOVA	{"email": "l.orlova021969@postgrespro.ru", "phone": "+70109186808"}
0005435501952	635DE7	1704 870328	NATALYA KUDRYASHOVA	{"phone": "+70531661787"}
0005435501953	8843A2	7932 067452	MARAT ANDREEV	{"phone": "+70739101638"}
0005435501954	8843A2	6583 144335	LILIYA IVANOVA	{"phone": "+70594080740"}
0005435501955	1D9926	0392 352413	ZINAIDA VASILEVA	{"phone": "+70187040444"}
0005435501956	1D9926	2054 424021	ALEKSANDR MAKSIMOV	{"email": "a_maksimov20111980@postgrespro.ru", "phone": "+70637297583"}
0005435501957	4368AA	3855 032396	MARIYA MATVEEVA	{"phone": "+70983221825"}
0005435501958	34E6FC	7968 658685	VERA MELNIKOVA	{"phone": "+70767533233"}
0005435501959	34E6FC	2262 241982	VERA KUZMINA	{"phone": "+70277274174"}
0005435501960	2D81D3	1226 162472	ELENA SEMENOVA	{"email": "semenova.e.031976@postgrespro.ru", "phone": "+70778967435"}
0005435501961	2D81D3	6242 463195	ALEKSEY POPOV	{"phone": "+70239676897"}
0005435501962	2D81D3	3305 062107	RAISA BOGDANOVA	{"phone": "+70133247925"}
0005435501963	12E05A	1610 022223	IGOR KUZNECOV	{"email": "i.kuznecov-051975@postgrespro.ru", "phone": "+70425536723"}
0005435501964	BCF0F7	4734 961503	OLGA FOMINA	{"email": "fomina_o_1957@postgrespro.ru", "phone": "+70630272597"}
0005435501965	BCF0F7	1021 593824	VIKTOR ALEKSANDROV	{"email": "v_aleksandrov-121971@postgrespro.ru", "phone": "+70516835646"}
0005435501966	374AD2	9188 603423	SERGEY PETROV	{"phone": "+70124663015"}
0005435501967	EB0095	5370 933147	YULIYA MAKAROVA	{"phone": "+70979661638"}
0005435501968	B9A323	9515 073510	SVETLANA LOGINOVA	{"phone": "+70717402141"}
0005435501969	B9A323	7644 147746	NADEZHDA ORLOVA	{"phone": "+70225563791"}
0005435501970	C43FEB	7768 715901	ANNA NIKOLAEVA	{"phone": "+70174892085"}
0005435501971	C43FEB	7920 867412	MIKHAIL SCHERBAKOV	{"email": "scherbakovmikhail04091970@postgrespro.ru", "phone": "+70911491641"}
0005435501972	CE987E	2351 945626	VALENTINA NIKOLAEVA	{"phone": "+70649460603"}
0005435501973	CE987E	1732 248858	SERGEY VASILEV	{"phone": "+70370883107"}
0005435501974	CE987E	5363 589233	ELDAR TIMOFEEV	{"email": "timofeev-e.1987@postgrespro.ru", "phone": "+70891139567"}
0005435501975	8934B1	6710 697921	DARYA DENISOVA	{"phone": "+70743024376"}
0005435501976	6C9F68	4881 414969	SVETLANA AFANASEVA	{"phone": "+70739097676"}
0005435501977	39EFC5	4808 799718	ZHANNA PETROVA	{"email": "petrova.zhanna_1971@postgrespro.ru", "phone": "+70585236469"}
0005435501978	39EFC5	6078 718869	VERA BELOVA	{"email": "belovavera-091971@postgrespro.ru", "phone": "+70508078465"}
0005435501979	221226	5198 569473	YULIYA IVANOVA	{"phone": "+70089589631"}
0005435501980	EEB7EA	9980 842903	IRINA BORISOVA	{"email": "borisova-irina_1973@postgrespro.ru", "phone": "+70300379209"}
0005435501981	EEB7EA	4000 737332	ANDREY TIMOFEEV	{"phone": "+70747806249"}
0005435501982	33E825	3312 295856	VALERIYA SCHERBAKOVA	{"email": "scherbakova-valeriya031971@postgrespro.ru", "phone": "+70826975721"}
0005435501983	33E825	8359 082613	ILYA VLASOV	{"email": "vlasov_ilya.1972@postgrespro.ru", "phone": "+70289193787"}
0005435501984	E52EFF	4401 404366	DMITRIY NIKOLAEV	{"email": "dmitriy-nikolaev1976@postgrespro.ru", "phone": "+70074236844"}
0005435501985	1E7E46	2431 276144	IRINA AFANASEVA	{"phone": "+70449538917"}
0005435501986	68AD2C	3126 240283	MILANA SOLOVEVA	{"email": "soloveva-milana.1965@postgrespro.ru", "phone": "+70817755089"}
0005435501987	A07168	3676 685051	MARINA POPOVA	{"email": "m_popova_021977@postgrespro.ru", "phone": "+70736487126"}
0005435501988	A07168	0021 555098	ELENA KARPOVA	{"phone": "+70247305177"}
0005435501989	7B9FB3	7536 976169	ANTONINA KRASNOVA	{"phone": "+70042739889"}
0005435501990	8903D9	6424 967081	IVAN KUZNECOV	{"phone": "+70779935168"}
0005435501991	52DA2D	4136 066168	TAMARA LAZAREVA	{"phone": "+70792577103"}
0005435501992	1D38A0	5174 683013	ALBINA DENISOVA	{"phone": "+70678251355"}
0005435501993	91C5AE	7784 107231	SERGEY KOZLOV	{"email": "kozlovsergey29101974@postgrespro.ru", "phone": "+70466221085"}
0005435501994	91C5AE	3667 800454	YULIYA VASILEVA	{"phone": "+70390350772"}
0005435501995	35107B	1353 319520	NATALIYA VLASOVA	{"phone": "+70536810265"}
0005435501996	35107B	8869 867169	LYUBOV VASILEVA	{"phone": "+70911295788"}
0005435501997	35107B	2724 642321	ANDREY MELNIKOV	{"email": "a_melnikov_1976@postgrespro.ru", "phone": "+70539360062"}
0005435501998	273431	8641 813008	SVETLANA ANDREEVA	{"email": "s_andreeva.02041977@postgrespro.ru", "phone": "+70554488944"}
0005435501999	273431	8244 416661	EVGENIY PETROV	{"phone": "+70140699812"}
0005435502000	590F77	5261 433674	TATYANA EFIMOVA	{"email": "efimovatatyana-111965@postgrespro.ru", "phone": "+70014938996"}
0005435502001	F8490B	8370 805368	MAKSIM SIDOROV	{"email": "m-sidorov_20031974@postgrespro.ru", "phone": "+70133883981"}
0005435502002	F8490B	6503 139356	ALEKSANDR KOROLEV	{"phone": "+70610106234"}
0005435502003	F8490B	4818 780963	NINA SOROKINA	{"email": "sorokina_n_12051976@postgrespro.ru", "phone": "+70248996047"}
0005435502004	03D8F2	2541 487425	FAINA ALEKSANDROVA	{"phone": "+70335689744"}
0005435502005	057873	4432 341401	SVETLANA IVANOVA	{"email": "sivanova.1964@postgrespro.ru", "phone": "+70751469936"}
0005435502006	057873	3639 334626	SERGEY PAVLOV	{"email": "s.pavlov-1973@postgrespro.ru", "phone": "+70224752287"}
0005435502007	64DA39	0017 707433	MARIYA PAVLOVA	{"phone": "+70263364034"}
0005435502008	64DA39	8879 983925	ANDREY STEPANOV	{"phone": "+70326526479"}
0005435502009	72CC43	2063 524087	RINAT ALEKSEEV	{"email": "alekseev-r_13111977@postgrespro.ru", "phone": "+70446845286"}
0005435502010	E5A96C	6721 884249	ANDREY FEDOROV	{"phone": "+70389609735"}
0005435502011	E5A96C	3983 572437	VIKTORIYA MARTYNOVA	{"phone": "+70639014637"}
0005435502012	FB6ACE	4862 069496	IGOR POPOV	{"email": "popov-igor_01121970@postgrespro.ru", "phone": "+70156958216"}
0005435502013	B98DBA	3597 792345	SERGEY VOLKOV	{"email": "s-volkov_051971@postgrespro.ru", "phone": "+70890692225"}
0005435502014	F26388	5129 010895	RINAT PAVLOV	{"phone": "+70522122449"}
0005435502015	F26388	6213 019699	ALEKSEY ALEKSANDROV	{"email": "aleksandrov_a1963@postgrespro.ru", "phone": "+70333670915"}
0005435502016	6EB53B	0740 453862	EVGENIYA ZAYCEVA	{"email": "evgeniyazayceva-1972@postgrespro.ru", "phone": "+70847398880"}
0005435502017	4B87AA	3839 755171	ALEKSANDRA TITOVA	{"phone": "+70136006111"}
0005435502018	A6075F	4349 688229	ALEKSANDR EGOROV	{"phone": "+70237221192"}
0005435502019	C9B00A	3882 959563	MIKHAIL IVANOV	{"phone": "+70974559617"}
0005435502020	C9B00A	9026 232006	VALENTINA NAUMOVA	{"email": "valentina.naumova_04041979@postgrespro.ru", "phone": "+70611073850"}
0005435502021	9E8824	4048 331416	ANTONINA KUZNECOVA	{"email": "kuznecova-a.1969@postgrespro.ru", "phone": "+70342143831"}
0005435502022	3CAB9E	4625 992420	VERA ZHURAVLEVA	{"email": "zhuravleva.vera.1967@postgrespro.ru", "phone": "+70252080643"}
0005435502023	A8541A	3442 739168	EKATERINA KOVALEVA	{"email": "kovaleva.e-29121962@postgrespro.ru", "phone": "+70338474151"}
0005435502024	8DB881	3441 519587	YURIY VLASOV	{"email": "vlasovy-031983@postgrespro.ru", "phone": "+70057314233"}
0005435502025	8DB881	1552 348332	SERGEY KRASNOV	{"email": "krasnov_sergey_021976@postgrespro.ru", "phone": "+70001712438"}
0005435502026	63E335	7630 860870	LYUDMILA KALININA	{"phone": "+70516015956"}
0005435502027	63E335	7838 707663	SERGEY IVANOV	{"phone": "+70833403980"}
0005435502028	4FB233	8135 487158	ALEKSANDRA ZAYCEVA	{"email": "aleksandra-zayceva_1970@postgrespro.ru", "phone": "+70937692768"}
0005435502029	6A527C	5320 635107	VALENTINA SERGEEVA	{"phone": "+70656208362"}
0005435502030	38011F	7574 933772	ALISA TARASOVA	{"email": "tarasova-alisa011980@postgrespro.ru", "phone": "+70873982699"}
0005435502031	38011F	0904 855931	TATYANA POPOVA	{"email": "tatyana.popova-20041966@postgrespro.ru", "phone": "+70615790808"}
0005435502032	38011F	5953 837093	ANDREY SAVELEV	{"phone": "+70074443143"}
0005435502033	0B4CF1	8501 833146	IRINA AFANASEVA	{"email": "afanaseva-i-1973@postgrespro.ru", "phone": "+70605928372"}
0005435502034	3E42C2	0307 533776	ANATOLIY PETROV	{"email": "a-petrov.10011968@postgrespro.ru", "phone": "+70968145770"}
0005435502035	6552C2	3476 803590	MIKHAIL NIKOLAEV	{"phone": "+70950638848"}
0005435502036	7C573A	8607 936303	GALINA FILIPPOVA	{"email": "filippova.galina_12051966@postgrespro.ru", "phone": "+70054548659"}
0005435502037	C09109	5544 848601	ANTONIDA AKIMOVA	{"phone": "+70096432887"}
0005435502038	44DBCA	0860 423586	ANNA FADEEVA	{"email": "anna-fadeeva-19111969@postgrespro.ru", "phone": "+70978560213"}
0005435502039	44DBCA	0277 592698	MARINA KUDRYASHOVA	{"email": "kudryashova-marina_041984@postgrespro.ru", "phone": "+70578908798"}
0005435502040	872CB7	9512 165851	SERGEY ZAYCEV	{"phone": "+70668997846"}
0005435502041	872CB7	8118 057269	SERGEY SOKOLOV	{"phone": "+70912204522"}
0005435502042	6ABD05	8903 609395	GALINA MOISEEVA	{"phone": "+70071623285"}
0005435502043	6ABD05	0542 337944	RAUF MEDVEDEV	{"email": "rauf_medvedev-18021980@postgrespro.ru", "phone": "+70386716932"}
0005435502044	7164AE	3994 009732	DENIS KULIKOV	{"phone": "+70629568908"}
0005435502045	DD231E	0341 899676	VIKTOR KUZMIN	{"phone": "+70046889435"}
0005435502046	13218E	3900 154861	OKSANA NOVIKOVA	{"email": "o-novikova21041978@postgrespro.ru", "phone": "+70207379091"}
0005435502047	8C00E5	1569 232250	YULIYA SERGEEVA	{"phone": "+70531060912"}
0005435502048	8C00E5	6979 957101	ANNA FILIPPOVA	{"phone": "+70338997594"}
0005435502049	8C00E5	1666 703405	ANNA SAVELEVA	{"email": "savelevaanna.071970@postgrespro.ru", "phone": "+70858440216"}
0005435502050	B0888E	1039 186798	MAKSIM ZAKHAROV	{"email": "zakharov-maksim_101982@postgrespro.ru", "phone": "+70141973459"}
0005435502051	55476C	0481 333949	ALEKSANDR GERASIMOV	{"email": "aleksandr.gerasimov1986@postgrespro.ru", "phone": "+70168411928"}
0005435502052	A69698	8203 558685	ALEKSANDR FEDOROV	{"phone": "+70450778946"}
0005435502053	390A69	0673 084760	ROMAN DAVYDOV	{"phone": "+70269229649"}
0005435502054	017B5C	5316 354067	IGOR MIKHAYLOV	{"phone": "+70298588818"}
0005435502055	017B5C	3132 650976	NATALIYA ZHURAVLEVA	{"phone": "+70836157296"}
0005435502056	1A9394	3174 734015	LYUBOV GUSEVA	{"phone": "+70666231615"}
0005435502057	A5E850	1839 077669	ALEKSANDR ILIN	{"email": "aleksandrilin.05111973@postgrespro.ru", "phone": "+70542806178"}
0005435502058	A5E850	0148 864537	EKATERINA NIKOLAEVA	{"phone": "+70570591267"}
0005435502059	43694C	2706 712430	VALENTINA ZHUKOVA	{"phone": "+70759562232"}
0005435502060	43694C	9574 786843	NATALYA FOMINA	{"email": "fomina-natalya.021966@postgrespro.ru", "phone": "+70858995986"}
0005435502061	C221E2	1060 960917	VIKTORIYA CHERNOVA	{"email": "v-chernova.1962@postgrespro.ru", "phone": "+70916185612"}
0005435502062	201E02	9169 977846	MIKHAIL MARTYNOV	{"email": "martynov_mikhail_26051972@postgrespro.ru", "phone": "+70023143776"}
0005435502063	201E02	8643 896951	KONSTANTIN POPOV	{"phone": "+70552466261"}
0005435502064	85D5AE	8990 514782	MAYA MAKSIMOVA	{"email": "maya_maksimova-18051976@postgrespro.ru", "phone": "+70496876740"}
0005435502065	3CCE24	8495 762073	ALEKSANDRA PAVLOVA	{"email": "a.pavlova-1967@postgrespro.ru", "phone": "+70828247643"}
0005435502066	E7A611	1019 594062	OLGA SOROKINA	{"phone": "+70887471393"}
0005435502067	CAFB1C	9424 508360	MARGARITA NIKITINA	{"email": "margaritanikitina_1968@postgrespro.ru", "phone": "+70642145023"}
0005435502068	73B47A	5872 451236	ALEKSANDR ANDREEV	{"phone": "+70861213338"}
0005435502069	73B47A	2159 410630	ELENA CHERNOVA	{"email": "elena-chernova.1972@postgrespro.ru", "phone": "+70195648393"}
0005435502070	B37110	8440 448037	TATYANA POPOVA	{"phone": "+70707261589"}
0005435502071	B37110	6645 681409	TATYANA KISELEVA	{"email": "tatyana-kiseleva_1970@postgrespro.ru", "phone": "+70595741839"}
0005435502072	B37110	4501 380839	VLADIMIR KONOVALOV	{"phone": "+70008093833"}
0005435502073	074BB7	5730 119024	ANTONINA BELOVA	{"email": "antoninabelova-011978@postgrespro.ru", "phone": "+70071806918"}
0005435502074	44C988	5335 724588	LYUDMILA FROLOVA	{"phone": "+70463030592"}
0005435502075	44C988	7612 313341	DANIIL ALEKSEEV	{"email": "alekseevdaniil_25111972@postgrespro.ru", "phone": "+70775912743"}
0005435502076	2B72EE	2097 570839	ELENA EFREMOVA	{"phone": "+70271692064"}
0005435502077	2B72EE	9376 023837	NINA ANDREEVA	{"email": "nina.andreeva.041977@postgrespro.ru", "phone": "+70338174904"}
0005435502078	2B72EE	1050 264553	ALEKSANDR GUSEV	{"email": "aleksandr.gusev-111969@postgrespro.ru", "phone": "+70824709008"}
0005435502079	53074E	5540 852518	VERA MOROZOVA	{"email": "v_morozova_091985@postgrespro.ru", "phone": "+70916377725"}
0005435502080	E72D18	6102 154474	ANDREY SHEVCHENKO	{"email": "andreyshevchenko041967@postgrespro.ru", "phone": "+70044010841"}
0005435502081	E72D18	2415 380236	MARIYA GUSEVA	{"email": "guseva-mariya041984@postgrespro.ru", "phone": "+70711393151"}
0005435502082	B12983	1298 054573	ALEKSANDR IVANOV	{"phone": "+70385227970"}
0005435502083	778853	0593 876909	TATYANA ZAYCEVA	{"phone": "+70798307658"}
0005435502084	00937F	8170 773481	ALEKSEY IVANOV	{"email": "ivanov-aleksey-011969@postgrespro.ru", "phone": "+70172675181"}
0005435502085	8C13EA	9264 497513	MIKHAIL BORISOV	{"phone": "+70488525333"}
0005435502086	12366A	7660 636736	ANDREY ISAEV	{"email": "isaev_a-11081977@postgrespro.ru", "phone": "+70080192562"}
0005435502087	12366A	6194 568406	VALENTINA KOMAROVA	{"phone": "+70580816548"}
0005435502088	50B35F	8420 891307	VIKTORIYA DENISOVA	{"phone": "+70227207770"}
0005435502089	E267CC	3994 869942	IVAN IVANOV	{"phone": "+70079968516"}
0005435502090	F9D8DE	1654 992006	PAVEL KOZLOV	{"email": "pavel.kozlov_18011978@postgrespro.ru", "phone": "+70783297193"}
0005435502091	F9D8DE	2812 332277	ANNA VASILEVA	{"email": "annavasileva12121967@postgrespro.ru", "phone": "+70330316787"}
0005435502092	7E43F8	7208 060671	LYUBOV GUSEVA	{"phone": "+70891441927"}
0005435502093	829392	9899 168849	IGOR ANDREEV	{"email": "igorandreev_021973@postgrespro.ru", "phone": "+70850521164"}
0005435502094	E2FA75	9284 574890	ALEKSEY PAVLOV	{"email": "pavlovaleksey_06111975@postgrespro.ru", "phone": "+70455480732"}
0005435502095	825EC7	5654 169579	SVETLANA ARKHIPOVA	{"email": "s_arkhipova1982@postgrespro.ru", "phone": "+70575620173"}
0005435502096	3B4D82	4692 073423	OLGA IVANOVA	{"email": "ivanova_o.1968@postgrespro.ru", "phone": "+70011761906"}
0005435502097	3B4D82	5700 667515	DARYA KULIKOVA	{"email": "darya_kulikova_1961@postgrespro.ru", "phone": "+70968209592"}
0005435502098	2B9EDB	2114 957044	DMITRIY VLASOV	{"email": "vlasov_d1966@postgrespro.ru", "phone": "+70740861184"}
0005435502099	F98021	0475 425018	KSENIYA KARPOVA	{"email": "kseniyakarpova-031977@postgrespro.ru", "phone": "+70851463813"}
0005435502100	81C232	7847 346150	SERGEY MOROZOV	{"email": "morozov_s.121972@postgrespro.ru", "phone": "+70136055866"}
0005435502101	81C232	0325 842963	MIKHAIL PETROV	{"phone": "+70793135753"}
0005435502102	81C232	6595 484511	MIKHAIL ROMANOV	{"email": "mikhailromanov1979@postgrespro.ru", "phone": "+70487409363"}
0005435502103	351B7A	6633 952587	PETR KUZNECOV	{"email": "p_kuznecov_18031986@postgrespro.ru", "phone": "+70381544929"}
0005435502104	A140A8	6095 941789	VASILIY MAKAROV	{"phone": "+70287623209"}
0005435502105	90A553	4569 617704	IVAN NAZAROV	{"phone": "+70832017741"}
0005435502106	00A82C	7020 046383	GEORGIY KUZNECOV	{"email": "gkuznecov_071965@postgrespro.ru", "phone": "+70116239145"}
0005435502107	ECF191	5215 861478	RUSLAN AFANASEV	{"phone": "+70993285622"}
0005435502108	549C5E	9067 266328	LIDIYA EGOROVA	{"email": "l-egorova_28081976@postgrespro.ru", "phone": "+70318163003"}
0005435502109	534125	9877 760417	IRINA VASILEVA	{"phone": "+70534288587"}
0005435502110	534125	6680 289346	ARINA RODIONOVA	{"email": "rodionovaarina.1957@postgrespro.ru", "phone": "+70970300425"}
0005435502111	718F51	0459 356739	GEORGIY SMIRNOV	{"email": "g_smirnov-16021971@postgrespro.ru", "phone": "+70097684824"}
0005435502112	F2A22C	3272 852536	ANDREY MAKSIMOV	{"phone": "+70185663173"}
0005435502113	F2A22C	6977 161378	OLGA ANDREEVA	{"phone": "+70329152863"}
0005435502114	65DA44	2475 167382	NIKITA FILIPPOV	{"phone": "+70510846128"}
0005435502115	2EC809	1424 396113	VLADIMIR GORBUNOV	{"email": "gorbunov.vladimir_061982@postgrespro.ru", "phone": "+70540969692"}
0005435502116	ADF713	7434 214759	EKATERINA AFANASEVA	{"email": "afanasevaekaterina031971@postgrespro.ru", "phone": "+70592504671"}
0005435502117	ADF713	6691 431223	ALEKSANDR ROMANOV	{"email": "romanov.aleksandr21091979@postgrespro.ru", "phone": "+70284431456"}
0005435502118	412506	2657 203924	VIKTORIYA TITOVA	{"phone": "+70468096745"}
0005435502119	412506	0965 991052	NIKOLAY SAVELEV	{"email": "nikolay.savelev-101976@postgrespro.ru", "phone": "+70416430688"}
0005435502120	AC9E99	1532 652163	NINA KUZNECOVA	{"email": "n_kuznecova051974@postgrespro.ru", "phone": "+70636067533"}
0005435502121	AC9E99	5837 957052	YANA SOROKINA	{"phone": "+70021966222"}
0005435502122	EA3959	0814 129133	MARINA ALEKSEEVA	{"phone": "+70184513116"}
0005435502123	EA3959	2326 299346	VLADIMIR GAVRILOV	{"phone": "+70650265345"}
0005435502124	DA079F	5024 934398	MAKSIM KRASNOV	{"phone": "+70353779126"}
0005435502125	9F7D2D	9671 346378	MAKSIM SIDOROV	{"phone": "+70265405088"}
0005435502126	9F7D2D	8165 429978	VLADIMIR EGOROV	{"email": "egorovvladimir-15061981@postgrespro.ru", "phone": "+70194539708"}
0005435502127	A4553A	6218 121306	NATALYA MAKSIMOVA	{"phone": "+70460058515"}
0005435502128	A4553A	7671 521874	DANIIL ANDREEV	{"email": "andreev.daniil.081975@postgrespro.ru", "phone": "+70561601230"}
0005435502129	36BC89	4418 434322	EGOR KUZNECOV	{"email": "egor-kuznecov_101971@postgrespro.ru", "phone": "+70303868616"}
0005435502130	BA36A5	4650 230723	ALEKSANDR POPOV	{"phone": "+70518655632"}
0005435502131	BA36A5	2327 947428	GALINA POPOVA	{"phone": "+70565458131"}
0005435502132	71A32E	7745 138145	VLADIMIR FEDOTOV	{"phone": "+70992007425"}
0005435502133	A9C9B6	3498 312542	EVGENIY SIDOROV	{"email": "sidorov-e.031968@postgrespro.ru", "phone": "+70938251650"}
0005435502134	444FEE	9153 774228	SVETLANA KUDRYASHOVA	{"email": "svetlana.kudryashova-061969@postgrespro.ru", "phone": "+70742990709"}
0005435502135	DB8EDD	2536 871583	ALEKSANDR KUZNECOV	{"email": "a-kuznecov-16111958@postgrespro.ru", "phone": "+70603416052"}
0005435502136	DB8EDD	1215 390366	IRINA EGOROVA	{"phone": "+70474282102"}
0005435502137	1DEA5F	8214 766927	SERGEY PAVLOV	{"phone": "+70983335305"}
0005435502138	1DEA5F	9422 784660	SAVELIY GAVRILOV	{"phone": "+70975120704"}
0005435502139	1DEA5F	2013 539827	VLADIMIR KOZLOV	{"email": "vladimirkozlov1983@postgrespro.ru", "phone": "+70412251545"}
0005435502140	5E3774	2808 136506	VALENTINA PETROVA	{"phone": "+70465191334"}
0005435502141	5E3774	9868 126057	NINA MAKAROVA	{"email": "n.makarova-28021976@postgrespro.ru", "phone": "+70538792637"}
0005435502142	E0102D	6591 997190	MARIYA YAKOVLEVA	{"phone": "+70855272093"}
0005435502143	E0102D	7112 385673	SERGEY NIKITIN	{"email": "s.nikitin-21021979@postgrespro.ru", "phone": "+70333734195"}
0005435502144	2BCB7B	6770 712579	NIKITA KULIKOV	{"email": "n_kulikov.27071967@postgrespro.ru", "phone": "+70676764543"}
0005435502145	2DE33C	6408 343978	ELENA ZHUKOVA	{"email": "zhukova_elena_021988@postgrespro.ru", "phone": "+70632207115"}
0005435502146	2DE33C	4407 878084	PETR SEMENOV	{"phone": "+70208212526"}
0005435502147	F73AEB	3528 691379	EKATERINA POPOVA	{"phone": "+70665846934"}
0005435502148	46B76C	6159 816624	DENIS BORISOV	{"phone": "+70297451067"}
0005435502149	3A159C	1225 886888	VASILIY VOROBEV	{"email": "vasiliy_vorobev_15071969@postgrespro.ru", "phone": "+70357141863"}
0005435502150	07ECE8	3634 331730	TATYANA ANISIMOVA	{"phone": "+70666683388"}
0005435502151	0C9856	5124 932005	SERGEY TARASOV	{"email": "tarasov-s-1979@postgrespro.ru", "phone": "+70045567764"}
0005435502152	0C9856	8487 812826	NATALYA PETROVA	{"phone": "+70038956864"}
0005435502153	AC19F3	9985 642264	VALERIY CHERNOV	{"email": "chernov.v.02061975@postgrespro.ru", "phone": "+70719240546"}
0005435502154	C1A2A3	0800 503080	GALINA ORLOVA	{"email": "g-orlova-1958@postgrespro.ru", "phone": "+70607091235"}
0005435502155	49DD77	5463 651699	SERGEY POPOV	{"email": "sergey_popov.1973@postgrespro.ru", "phone": "+70748833701"}
0005435502156	49DD77	3583 722902	VERA VASILEVA	{"phone": "+70377903148"}
0005435502157	26089F	3091 972346	VLADIMIR YAKOVLEV	{"email": "yakovlev_v-02111967@postgrespro.ru", "phone": "+70065690555"}
0005435502158	0B21BA	2366 992903	KIRILL KUZNECOV	{"phone": "+70124718581"}
0005435502159	0B21BA	1123 530146	TATYANA FADEEVA	{"email": "t_fadeeva091969@postgrespro.ru", "phone": "+70652673246"}
0005435502160	B8203C	7476 573767	OLGA EGOROVA	{"email": "egorova_o-22041967@postgrespro.ru", "phone": "+70712997206"}
0005435502161	9E139E	7827 254777	VALENTINA YAKOVLEVA	{"email": "valentina-yakovleva_071981@postgrespro.ru", "phone": "+70143898034"}
0005435502162	BEEFAF	4672 876007	EKATERINA MAKAROVA	{"email": "makarovaekaterina1974@postgrespro.ru", "phone": "+70442461301"}
0005435502163	BEEFAF	4783 101764	MARINA NIKITINA	{"email": "marina-nikitina.30061974@postgrespro.ru", "phone": "+70312493325"}
0005435502164	FD9433	5948 087189	ALEKSANDR VOLKOV	{"email": "volkov-a-071978@postgrespro.ru", "phone": "+70153963408"}
0005435502165	FD9433	0995 378744	YULIYA PAVLOVA	{"phone": "+70906989034"}
0005435502166	FD9433	6438 867354	ALEKSEY MIRONOV	{"phone": "+70957597908"}
0005435502167	D8DA8C	0474 067407	TATYANA POTAPOVA	{"phone": "+70643334951"}
0005435502168	036A0E	4879 385422	MARIYA KOZLOVA	{"phone": "+70284837060"}
0005435502169	9EE1D3	7367 109277	OLGA IVANOVA	{"email": "o-ivanova08041984@postgrespro.ru", "phone": "+70467825364"}
0005435502170	9EE1D3	6261 113534	SERGEY AFANASEV	{"email": "safanasev.1980@postgrespro.ru", "phone": "+70672031982"}
0005435502171	9EE1D3	8024 751212	LARISA KONDRATEVA	{"phone": "+70016956146"}
0005435502172	292C72	8459 469711	KLAVDIYA ROMANOVA	{"phone": "+70709190457"}
0005435502173	8036AA	6605 016705	ALEKSEY KONOVALOV	{"phone": "+70741129773"}
0005435502174	CBD1B9	0752 030161	EKATERINA KONOVALOVA	{"email": "konovalova_ekaterina.071969@postgrespro.ru", "phone": "+70224973739"}
0005435502175	6EC20C	4809 247064	ALEKSANDR FILIPPOV	{"email": "filippov.aleksandr13081977@postgrespro.ru", "phone": "+70280305735"}
0005435502176	6EC20C	8282 614460	EVDOKIYA ABRAMOVA	{"email": "abramova_e-10041970@postgrespro.ru", "phone": "+70532928476"}
0005435502177	7B91F3	6047 329437	ALEKSANDR ROMANOV	{"phone": "+70842344355"}
0005435502178	723BB1	3221 644894	ELIZAVETA OSIPOVA	{"phone": "+70480319208"}
0005435502179	B26723	2931 518481	EKATERINA SEMENOVA	{"email": "semenova-ekaterina.18111974@postgrespro.ru", "phone": "+70715582175"}
0005435502180	B26723	3623 183616	DMITRIY FOMIN	{"email": "fomin.dmitriy-1979@postgrespro.ru", "phone": "+70700736420"}
0005435502181	EC4F89	1126 258924	ROMAN MIKHAYLOV	{"email": "r.mikhaylov.18021971@postgrespro.ru", "phone": "+70194796932"}
0005435502182	4D808D	7201 589464	OLGA MIKHAYLOVA	{"email": "mikhaylova-olga-1978@postgrespro.ru", "phone": "+70225402617"}
0005435502183	4D808D	5369 063255	ELINA MASLOVA	{"phone": "+70952272274"}
0005435502350	41852B	5589 564988	VERA ILINA	{"phone": "+70093904773"}
0005435502184	38C1DA	0899 644699	OLGA LOGINOVA	{"email": "loginova-olga.111975@postgrespro.ru", "phone": "+70600387847"}
0005435502185	38C1DA	0891 276416	LYUBOV DANILOVA	{"phone": "+70927519653"}
0005435502186	47A926	4015 914939	SVETLANA VLASOVA	{"email": "s.vlasova-081968@postgrespro.ru", "phone": "+70496449016"}
0005435502187	47A926	4622 943178	NATALYA FROLOVA	{"email": "n_frolova_011964@postgrespro.ru", "phone": "+70499427770"}
0005435502188	D5174F	7762 265009	VARVARA SCHERBAKOVA	{"email": "varvara-scherbakova-111978@postgrespro.ru", "phone": "+70735020875"}
0005435502189	D5174F	9450 422485	VALENTINA NESTEROVA	{"email": "nesterova-valentina121973@postgrespro.ru", "phone": "+70287803406"}
0005435502190	C7C8EA	7062 042227	MATVEY DENISOV	{"phone": "+70008393471"}
0005435502191	084D79	8749 654830	SERGEY DAVYDOV	{"phone": "+70232596154"}
0005435502192	5A4ACA	0997 717681	IGOR MIKHAYLOV	{"email": "igor-mikhaylov_1971@postgrespro.ru", "phone": "+70650234340"}
0005435502193	660E52	7516 986711	YULIYA VASILEVA	{"email": "vasileva-y021975@postgrespro.ru", "phone": "+70336445661"}
0005435502194	04154A	9945 128718	GALINA IVANOVA	{"phone": "+70022720076"}
0005435502195	04154A	8798 981037	DMITRIY TARASOV	{"phone": "+70881714858"}
0005435502196	B020BF	2239 215866	EKATERINA GERASIMOVA	{"email": "gerasimova_e_30031965@postgrespro.ru", "phone": "+70823101418"}
0005435502197	976D6E	3348 411548	ALEKSEY RODIONOV	{"phone": "+70861856430"}
0005435502198	33905A	5899 744730	DMITRIY GUSEV	{"phone": "+70543548551"}
0005435502199	0D789E	5642 376846	PAVEL FEDOROV	{"phone": "+70770410881"}
0005435502200	0D789E	5283 500715	GALINA POLYAKOVA	{"email": "polyakova.galina_1975@postgrespro.ru", "phone": "+70689702718"}
0005435502201	C8B152	6944 136525	VIKTOR ROMANOV	{"email": "v-romanov20021973@postgrespro.ru", "phone": "+70346781809"}
0005435502202	17D559	0217 184258	VASILIY SCHERBAKOV	{"phone": "+70659567790"}
0005435502203	CC24C9	8012 753702	ALEKSANDR ZHUKOV	{"phone": "+70976388053"}
0005435502204	CC24C9	1490 780195	GEORGIY VOROBEV	{"phone": "+70783929629"}
0005435502205	5C0870	7814 762899	ALEKSANDR ZAKHAROV	{"email": "aleksandr-zakharov16051976@postgrespro.ru", "phone": "+70746310742"}
0005435502206	EE1F0E	0176 074677	VALENTINA POPOVA	{"email": "popova_valentina081966@postgrespro.ru", "phone": "+70251172974"}
0005435502207	EE1F0E	4478 794260	LYUDMILA NIKOLAEVA	{"phone": "+70012912741"}
0005435502208	3046B1	7561 294707	TATYANA KONDRATEVA	{"phone": "+70371069733"}
0005435502209	D84A45	9742 924984	ALEVTINA CHERNOVA	{"phone": "+70286541134"}
0005435502210	9F8FEF	9202 410080	GALINA FILATOVA	{"email": "filatovagalina-111970@postgrespro.ru", "phone": "+70350804400"}
0005435502211	7FB98D	1574 836557	VIKTORIYA ZAKHAROVA	{"phone": "+70400813946"}
0005435502212	5B219E	1643 381980	ALEKSEY MOISEEV	{"email": "aleksey.moiseev_1966@postgrespro.ru", "phone": "+70315163340"}
0005435502213	5B219E	8852 062989	SAMIRA ABRAMOVA	{"email": "abramova-s10081977@postgrespro.ru", "phone": "+70024554347"}
0005435502214	F91607	8308 643303	SVETLANA GAVRILOVA	{"email": "gavrilova.svetlana-1971@postgrespro.ru", "phone": "+70470136240"}
0005435502215	7F91F5	2413 528056	LYUBOV KOZLOVA	{"phone": "+70643876581"}
0005435502216	7F91F5	7602 645126	NIKOLAY SHEVCHENKO	{"phone": "+70215428534"}
0005435502217	E9D7AB	7009 781851	ELENA ANDREEVA	{"email": "eandreeva-09021964@postgrespro.ru", "phone": "+70648854796"}
0005435502218	E9D7AB	4015 000923	ANDREY FOMIN	{"phone": "+70457283372"}
0005435502219	93F34F	1411 354570	VLADISLAV SOKOLOV	{"email": "v-sokolov_031973@postgrespro.ru", "phone": "+70469382269"}
0005435502220	33593C	5029 701449	IVAN GRIGOREV	{"phone": "+70897563436"}
0005435502221	C8D97E	4004 118811	TAISIYA GRISHINA	{"email": "grishinataisiya1969@postgrespro.ru", "phone": "+70551354855"}
0005435502222	913DBC	3603 706533	LYUBOV KUZNECOVA	{"email": "lkuznecova_111962@postgrespro.ru", "phone": "+70710049505"}
0005435502223	CDAE71	8613 560180	DARINA ISAEVA	{"phone": "+70319145253"}
0005435502224	A2901D	6197 254376	SERGEY POPOV	{"email": "popovs_06011976@postgrespro.ru", "phone": "+70812107033"}
0005435502225	25DC4F	6220 007920	ANDREY NIKITIN	{"email": "andrey_nikitin061978@postgrespro.ru", "phone": "+70735717476"}
0005435502226	19989E	4531 401488	ALEKSEY VOROBEV	{"email": "vorobev_aleksey20051977@postgrespro.ru", "phone": "+70785200683"}
0005435502227	19989E	7578 936577	LIDIYA KISELEVA	{"email": "lidiya_kiseleva_1983@postgrespro.ru", "phone": "+70062111651"}
0005435502228	19989E	4187 137529	SERGEY FROLOV	{"phone": "+70720013592"}
0005435502229	D52586	3139 312148	NINA IVANOVA	{"phone": "+70948577147"}
0005435502230	DF0EFA	5235 700469	MIKHAIL KARPOV	{"phone": "+70588741264"}
0005435502231	93689C	3229 568890	VALENTIN ILIN	{"phone": "+70158341956"}
0005435502232	93689C	3706 751735	LEONID SCHERBAKOV	{"email": "l.scherbakov.111976@postgrespro.ru", "phone": "+70824021558"}
0005435502233	3B7392	3794 657739	IGOR ABRAMOV	{"phone": "+70338389702"}
0005435502234	F4D532	3674 197040	RIMMA MEDVEDEVA	{"email": "r.medvedeva.041975@postgrespro.ru", "phone": "+70130318116"}
0005435502235	10FD20	6288 823272	IVAN KRASNOV	{"phone": "+70553137166"}
0005435502236	EA5B23	6017 314774	NINA KAZAKOVA	{"phone": "+70280149801"}
0005435502237	5F9F3F	7150 226328	ALEKSANDR MARTYNOV	{"email": "martynov-aleksandr_1976@postgrespro.ru", "phone": "+70215775898"}
0005435502238	5F9F3F	6373 741181	KSENIYA NESTEROVA	{"phone": "+70324907399"}
0005435502239	794BA2	4724 197495	VALENTINA KARPOVA	{"email": "karpova_valentina.011981@postgrespro.ru", "phone": "+70548412959"}
0005435502240	4D7D96	7807 808209	ANASTASIYA MALYSHEVA	{"email": "anastasiya-malysheva.08041965@postgrespro.ru", "phone": "+70689411324"}
0005435502241	4D7D96	2325 632312	MIKHAIL TIMOFEEV	{"phone": "+70829134919"}
0005435502242	4D7D96	3632 556470	PAVEL GERASIMOV	{"email": "pavel-gerasimov.051970@postgrespro.ru", "phone": "+70616625936"}
0005435502243	A09207	8369 212749	DENIS DMITRIEV	{"phone": "+70172351067"}
0005435502244	A09207	3586 060387	SVETLANA ANDREEVA	{"phone": "+70389171641"}
0005435502245	57E8D0	8997 065538	NINA SOROKINA	{"email": "nina-sorokina.16021974@postgrespro.ru", "phone": "+70768690143"}
0005435502246	80A754	8183 980459	MARIYA ZOTOVA	{"phone": "+70216844437"}
0005435502247	80A754	8250 146902	ALEKSANDRA KOROLEVA	{"phone": "+70553570262"}
0005435502248	4CF816	5994 880859	LYUDMILA FILATOVA	{"email": "l.filatova-091968@postgrespro.ru", "phone": "+70946912068"}
0005435502249	2B275E	4008 868481	YULIYA KUDRYASHOVA	{"email": "yuliya.kudryashova111975@postgrespro.ru", "phone": "+70504980288"}
0005435502250	F26293	8784 932271	GALINA IVANOVA	{"email": "galinaivanova.17021970@postgrespro.ru", "phone": "+70906962561"}
0005435502251	ADB028	5846 770307	TAMARA KUZMINA	{"email": "kuzmina.t-1968@postgrespro.ru", "phone": "+70726761097"}
0005435502252	ADB028	9599 424814	IVAN ABRAMOV	{"phone": "+70543257344"}
0005435502253	CBC894	5229 883262	SERGEY KULIKOV	{"email": "s-kulikov-28061966@postgrespro.ru", "phone": "+70660140130"}
0005435502254	F7A939	3869 129891	SVETLANA ANDREEVA	{"email": "andreeva.s.11121974@postgrespro.ru", "phone": "+70551135631"}
0005435502255	45AC2E	6224 214399	ELENA ALEKSEEVA	{"phone": "+70695864423"}
0005435502256	45AC2E	3795 788753	ELENA ISAEVA	{"email": "isaeva.e.091969@postgrespro.ru", "phone": "+70442765018"}
0005435502257	E08A6C	5446 140780	ARTEM FEDOROV	{"email": "fedorov_a031969@postgrespro.ru", "phone": "+70536239272"}
0005435502258	20F7FC	9107 823139	DENIS BONDARENKO	{"email": "bondarenko_d_1977@postgrespro.ru", "phone": "+70826402847"}
0005435502259	20F7FC	7381 237902	VERA POTAPOVA	{"email": "potapova_vera_10101966@postgrespro.ru", "phone": "+70698343082"}
0005435502260	0CDD63	6172 255273	VLADIMIR EGOROV	{"email": "vladimir.egorov_121976@postgrespro.ru", "phone": "+70466766427"}
0005435502261	690A81	1271 195029	GALINA MAKAROVA	{"email": "galina-makarova_1953@postgrespro.ru", "phone": "+70213674060"}
0005435502262	690A81	5523 723640	ANASTASIYA VASILEVA	{"phone": "+70108659410"}
0005435502263	C9B570	5895 167537	VADIM DMITRIEV	{"phone": "+70786429391"}
0005435502264	C9B570	5158 064735	DMITRIY ROMANOV	{"email": "dmitriy.romanov_17021973@postgrespro.ru", "phone": "+70061019841"}
0005435502265	CE9725	2769 719233	DANIIL KUDRYASHOV	{"email": "kudryashov_daniil_111979@postgrespro.ru", "phone": "+70025853241"}
0005435502266	F60183	4468 154547	ALEKSANDRA SAVELEVA	{"phone": "+70633284966"}
0005435502267	F60183	4731 962369	SVETLANA MARTYNOVA	{"email": "s_martynova_06051957@postgrespro.ru", "phone": "+70062453473"}
0005435502268	AF2622	4246 928543	YAROSLAVA ROMANOVA	{"email": "yaroslava_romanova_1973@postgrespro.ru", "phone": "+70876339446"}
0005435502269	A6A3F4	1684 404110	NIKOLAY KUZNECOV	{"email": "nikolay_kuznecov-031985@postgrespro.ru", "phone": "+70937150540"}
0005435502270	BC9026	7445 173185	LYUDMILA POTAPOVA	{"email": "potapova.l_07031963@postgrespro.ru", "phone": "+70744394364"}
0005435502271	2986E4	8680 481629	ANASTASIYA TIMOFEEVA	{"phone": "+70313267677"}
0005435502272	2986E4	5616 312920	NIKITA BELOV	{"phone": "+70255695611"}
0005435502273	C7B6C6	1773 879213	IVAN GRIGOREV	{"email": "igrigorev_111974@postgrespro.ru", "phone": "+70940633868"}
0005435502274	C7B6C6	5223 602685	NINA YAKOVLEVA	{"email": "n.yakovleva.1975@postgrespro.ru", "phone": "+70980073253"}
0005435502275	A5FC5D	3190 633442	MIKHAIL DENISOV	{"email": "m.denisov.07111968@postgrespro.ru", "phone": "+70696391240"}
0005435502276	A5FC5D	7643 491152	KRISTINA KOZLOVA	{"email": "kkozlova_1966@postgrespro.ru", "phone": "+70633508439"}
0005435502277	5A8132	4741 960614	TATYANA ZAKHAROVA	{"email": "tatyana-zakharova06081963@postgrespro.ru", "phone": "+70983082391"}
0005435502278	48643D	8346 217484	RADIK CHERNOV	{"phone": "+70456704107"}
0005435502279	4B35C1	5609 028664	SVETLANA CHERNOVA	{"phone": "+70180485592"}
0005435502280	4B35C1	9797 614479	IRINA IVANOVA	{"phone": "+70260614227"}
0005435502281	EE4199	9623 364946	ALEKSANDR KUZNECOV	{"phone": "+70669239838"}
0005435502282	6D2B33	4413 958621	KSENIYA ILINA	{"email": "ilinakseniya_1973@postgrespro.ru", "phone": "+70926818210"}
0005435502283	FAD20E	4705 459462	ALEKSEY KARPOV	{"phone": "+70616469121"}
0005435502284	FAD20E	9002 025053	LYUBOV DAVYDOVA	{"email": "davydoval.081980@postgrespro.ru", "phone": "+70965052846"}
0005435502285	0EBD8C	9353 706425	BORIS MOISEEV	{"phone": "+70777158875"}
0005435502286	A8C875	9033 097827	NINA VOLKOVA	{"phone": "+70628694132"}
0005435502287	E3314A	0422 779995	PAVEL ORLOV	{"email": "orlovp-1971@postgrespro.ru", "phone": "+70416376174"}
0005435502288	CFA496	6048 201907	VYACHESLAV GORBUNOV	{"email": "gorbunovvyacheslav071980@postgrespro.ru", "phone": "+70123016150"}
0005435502289	E9BE9D	6076 124551	DMITRIY IVANOV	{"phone": "+70080158607"}
0005435502290	A3EAA7	0025 739035	NIKOLAY MOROZOV	{"phone": "+70453500491"}
0005435502291	85EC5A	0201 429351	GRIGORIY ANDREEV	{"email": "g_andreev.1977@postgrespro.ru", "phone": "+70507303770"}
0005435502292	185810	6588 583609	SAVELIY KULIKOV	{"phone": "+70706913440"}
0005435502293	D86BF9	1227 848443	VALERIY KOZLOV	{"phone": "+70176726270"}
0005435502294	939DB9	2026 292709	ELENA VOLKOVA	{"phone": "+70085731583"}
0005435502351	41852B	4779 361117	DIANA KAZAKOVA	{"phone": "+70963098410"}
0005435502295	C614AC	2207 491129	OLEG ZAYCEV	{"email": "oleg.zaycev-011985@postgrespro.ru", "phone": "+70830366266"}
0005435502296	87FBF0	6352 138988	ANDREY GORBUNOV	{"phone": "+70654148469"}
0005435502297	131F60	0329 625080	DMITRIY SIDOROV	{"email": "dsidorov-27081984@postgrespro.ru", "phone": "+70103254417"}
0005435502298	859003	0464 929571	ALEKSANDR FEDOROV	{"email": "fedorov-a09121980@postgrespro.ru", "phone": "+70034140841"}
0005435502299	FD45CF	2694 985142	NINA MIKHAYLOVA	{"email": "nmikhaylova.16031970@postgrespro.ru", "phone": "+70325019905"}
0005435502300	FD45CF	4418 360198	SERGEY SIDOROV	{"email": "sidorov_s101974@postgrespro.ru", "phone": "+70388561354"}
0005435502301	FFA262	8440 731380	GALINA PAVLOVA	{"email": "gpavlova1987@postgrespro.ru", "phone": "+70668834034"}
0005435502302	FFA262	2341 626843	PAVEL MAKAROV	{"email": "pavel-makarov1982@postgrespro.ru", "phone": "+70447206956"}
0005435502303	B8F292	7519 491691	ALEKSEY MARTYNOV	{"email": "martynov_aleksey.071968@postgrespro.ru", "phone": "+70885413736"}
0005435502304	B8F292	7611 288937	ALEKSANDR VLASOV	{"email": "vlasova051963@postgrespro.ru", "phone": "+70541822838"}
0005435502305	1CFA69	9207 095796	TATYANA KONOVALOVA	{"email": "t_konovalova.071970@postgrespro.ru", "phone": "+70348454151"}
0005435502306	9AF648	3132 942661	MAKSIM FEDOTOV	{"email": "maksim-fedotov.081973@postgrespro.ru", "phone": "+70771210759"}
0005435502307	9AF648	8274 636863	LYUDMILA FROLOVA	{"email": "l-frolova_1970@postgrespro.ru", "phone": "+70294839471"}
0005435502308	F51433	4939 227811	PAVEL DAVYDOV	{"email": "paveldavydov051958@postgrespro.ru", "phone": "+70910544741"}
0005435502309	F3906C	4029 354798	EKATERINA ANDREEVA	{"phone": "+70883336270"}
0005435502310	F3906C	3608 760615	LYUDMILA EFIMOVA	{"phone": "+70384539818"}
0005435502311	75C6C1	0604 305594	IVAN OSIPOV	{"phone": "+70919340361"}
0005435502312	3F3F15	5381 507559	VLADISLAV FOMIN	{"email": "vladislav-fomin1972@postgrespro.ru", "phone": "+70915813664"}
0005435502313	260D77	2042 691966	LILIYA KOZLOVA	{"email": "liliya_kozlova.04031974@postgrespro.ru", "phone": "+70287181644"}
0005435502314	D95802	2564 670673	DMITRIY SMIRNOV	{"phone": "+70135290318"}
0005435502315	830F82	1660 788577	ROMAN MOISEEV	{"email": "r.moiseev1971@postgrespro.ru", "phone": "+70992197474"}
0005435502316	718550	0955 387038	MARIYA DAVYDOVA	{"email": "davydova_m091981@postgrespro.ru", "phone": "+70715490558"}
0005435502317	85DBDC	9888 136998	ANDREY SEMENOV	{"phone": "+70975739131"}
0005435502318	CE4D65	0062 701733	SVETLANA DENISOVA	{"phone": "+70486403623"}
0005435502319	3C930F	4442 823133	ANDREY EGOROV	{"phone": "+70472127646"}
0005435502320	3C930F	1141 293522	ANTONINA IVANOVA	{"email": "ivanova.a.071974@postgrespro.ru", "phone": "+70932120368"}
0005435502321	BCFC37	7649 051407	PAVEL MATVEEV	{"email": "p_matveev.121971@postgrespro.ru", "phone": "+70250668094"}
0005435502322	DFC410	7408 672740	VIKTOR ZAYCEV	{"email": "zaycev-v_031983@postgrespro.ru", "phone": "+70554289664"}
0005435502323	89D333	2252 111755	LYUBOV GRISHINA	{"phone": "+70345940809"}
0005435502324	204A5D	2467 297857	LILIYA KUZNECOVA	{"email": "kuznecovaliliya081976@postgrespro.ru", "phone": "+70712645646"}
0005435502325	204A5D	7292 071433	ALEKSANDR VLASOV	{"email": "avlasov-041966@postgrespro.ru", "phone": "+70843401160"}
0005435502326	27A638	3865 176632	VALENTINA NAZAROVA	{"email": "nazarova.valentina-1962@postgrespro.ru", "phone": "+70985048454"}
0005435502327	66412D	8855 155022	LARISA KULIKOVA	{"email": "larisa.kulikova_101962@postgrespro.ru", "phone": "+70921892283"}
0005435502328	FE8BF0	9167 317076	NIKOLAY ZHURAVLEV	{"phone": "+70240401338"}
0005435502329	E5C8C8	6584 949567	ALEKSEY EGOROV	{"email": "egorov_aleksey04081970@postgrespro.ru", "phone": "+70541179942"}
0005435502330	E5C8C8	6254 864851	VLADIMIR MIKHAYLOV	{"phone": "+70940123866"}
0005435502331	36F82F	0999 171439	OLEG IVANOV	{"phone": "+70518864412"}
0005435502332	36F82F	7421 448184	ALEKSANDR MATVEEV	{"phone": "+70739376645"}
0005435502333	10841E	0165 416675	OKSANA TROFIMOVA	{"phone": "+70791946033"}
0005435502334	10841E	4800 402104	SOFIYA SOROKINA	{"email": "sorokinasofiya.23031979@postgrespro.ru", "phone": "+70305752758"}
0005435502335	C941E2	4406 267208	ALEKSANDR KISELEV	{"phone": "+70063257889"}
0005435502336	85E733	7249 146547	MIKHAIL MELNIKOV	{"email": "mmelnikov.011977@postgrespro.ru", "phone": "+70828073151"}
0005435502337	85E733	8991 316843	VLADISLAV SHEVCHENKO	{"phone": "+70543311130"}
0005435502338	9DB3FD	7037 898053	EVGENIY STEPANOV	{"email": "estepanov.1970@postgrespro.ru", "phone": "+70139929141"}
0005435502339	FCB3E2	1358 872439	MARIYA KONDRATEVA	{"phone": "+70177676110"}
0005435502340	86B6C9	1079 061931	ELIZAVETA FROLOVA	{"phone": "+70502814973"}
0005435502341	8D219A	8155 538320	MIKHAIL ORLOV	{"email": "mikhail.orlov05071974@postgrespro.ru", "phone": "+70276358756"}
0005435502342	8D219A	4620 222019	ELENA YUDINA	{"email": "elenayudina-061968@postgrespro.ru", "phone": "+70951940541"}
0005435502343	7F4439	1459 886799	VYACHESLAV SIDOROV	{"email": "vyacheslav_sidorov.23121966@postgrespro.ru", "phone": "+70075784981"}
0005435502344	7F4439	3445 267223	ILDAR MEDVEDEV	{"phone": "+70809969112"}
0005435502345	3D3F33	8121 711168	MAKSIM SEMENOV	{"email": "maksim_semenov07021966@postgrespro.ru", "phone": "+70738414848"}
0005435502346	3D3F33	8332 578072	GALINA SOKOLOVA	{"phone": "+70826566234"}
0005435502347	C6C132	4032 868659	ALEKSANDR SOLOVEV	{"email": "aleksandr.solovev.1975@postgrespro.ru", "phone": "+70108613957"}
0005435502348	C6C132	5730 227213	VALENTINA KUZNECOVA	{"phone": "+70629977787"}
0005435502349	79BF70	3725 431496	ELENA LOGINOVA	{"email": "e-loginova.111979@postgrespro.ru", "phone": "+70786296041"}
0005435502352	70299A	1147 825952	ALEKSANDR ROMANOV	{"email": "romanov.a_1964@postgrespro.ru", "phone": "+70413081932"}
0005435502353	314FD2	4640 810934	ILYA GUSEV	{"email": "gusev.ilya-1973@postgrespro.ru", "phone": "+70667018489"}
0005435502354	872F71	0845 965951	VIKTORIYA VOLKOVA	{"email": "viktoriya.volkova-1970@postgrespro.ru", "phone": "+70856210942"}
0005435502355	872F71	9279 552258	ALEKSANDR AFANASEV	{"phone": "+70085941399"}
0005435502356	8643CF	6749 592124	NATALYA KOZLOVA	{"phone": "+70311348242"}
0005435502357	943D3B	8997 680293	EVGENIY OSIPOV	{"email": "osipov_e_1970@postgrespro.ru", "phone": "+70407454298"}
0005435502358	97C58B	2713 349601	YANA MATVEEVA	{"phone": "+70815405875"}
0005435502359	97C58B	4089 674712	MAKSIM VOROBEV	{"email": "maksim.vorobev.1970@postgrespro.ru", "phone": "+70854434701"}
0005435502360	C5F415	9839 986572	VASILIY NAUMOV	{"email": "v.naumov-091976@postgrespro.ru", "phone": "+70627686551"}
0005435502361	F1717A	0467 890096	VIKTORIYA SOKOLOVA	{"email": "sokolovav-1983@postgrespro.ru", "phone": "+70480608905"}
0005435502362	92B554	6690 998261	VERA PETROVA	{"phone": "+70019224488"}
0005435502363	618466	1064 103941	ALEKSANDR MAKAROV	{"email": "a-makarov-011972@postgrespro.ru", "phone": "+70852978471"}
0005435502364	0D425C	4593 009680	GALINA EGOROVA	{"phone": "+70009797996"}
0005435502365	E5EFB9	3164 818691	ELINA KONDRATEVA	{"email": "kondratevaelina-04121971@postgrespro.ru", "phone": "+70105636709"}
0005435502366	255161	0088 015018	OLGA SMIRNOVA	{"phone": "+70841717747"}
0005435502367	BC5EC4	0543 248547	PAVEL TIMOFEEV	{"phone": "+70046504578"}
0005435502368	BC5EC4	8544 550996	YULIYA NESTEROVA	{"email": "nesterova_yuliya_17041978@postgrespro.ru", "phone": "+70745708316"}
0005435502369	D34338	8805 461565	DMITRIY MAKAROV	{"email": "dmakarov.051973@postgrespro.ru", "phone": "+70694394445"}
0005435502370	39D0D3	0057 147361	VERA KRASNOVA	{"email": "vkrasnova.091973@postgrespro.ru", "phone": "+70290506762"}
0005435502371	39D0D3	3564 371817	LEONID POPOV	{"phone": "+70497811922"}
0005435502372	1DF1F9	2898 626925	YURIY GAVRILOV	{"email": "gavrilov.y-04011977@postgrespro.ru", "phone": "+70515271183"}
0005435502373	1DF1F9	6100 268554	ALEKSANDR MAKSIMOV	{"email": "maksimov.a.1961@postgrespro.ru", "phone": "+70631303436"}
0005435502374	766670	9645 952059	TATYANA MAKSIMOVA	{"email": "t-maksimova.1969@postgrespro.ru", "phone": "+70665072258"}
0005435502375	21C00C	2289 909826	ALEKSANDR RODIONOV	{"email": "rodionov-aleksandr081978@postgrespro.ru", "phone": "+70296091064"}
0005435502376	21C00C	1982 692685	KSENIYA ROMANOVA	{"email": "romanova.kseniya121978@postgrespro.ru", "phone": "+70728457053"}
0005435502377	5FB1ED	0885 646505	ELENA DAVYDOVA	{"email": "e-davydova.091965@postgrespro.ru", "phone": "+70411803702"}
0005435502378	5FB1ED	5589 199768	ALEKSANDR MAKAROV	{"email": "makarov_aleksandr-12061971@postgrespro.ru", "phone": "+70401297288"}
0005435502379	3E7B90	5909 707410	OLGA KUZNECOVA	{"phone": "+70619241307"}
0005435502380	3E7B90	2201 423250	LARISA EFIMOVA	{"email": "efimova.l071970@postgrespro.ru", "phone": "+70864729763"}
0005435502381	CB6CF5	4260 692461	SERGEY POPOV	{"phone": "+70252008817"}
0005435502382	7F8CC7	2515 345038	ALEKSANDR MARTYNOV	{"phone": "+70856478881"}
0005435502383	BD0E1A	4604 292025	LYUDMILA FEDOROVA	{"phone": "+70756401355"}
0005435502384	BD0E1A	3340 301915	ROMAN VLASOV	{"email": "roman_vlasov-061965@postgrespro.ru", "phone": "+70874405053"}
0005435502385	C930DB	7389 515398	SVETLANA NAZAROVA	{"phone": "+70160449197"}
0005435502386	114AF0	8535 500915	OLGA MELNIKOVA	{"phone": "+70523202469"}
0005435502387	A0124A	3510 521246	IGOR SMIRNOV	{"email": "i-smirnov061964@postgrespro.ru", "phone": "+70076912513"}
0005435502388	A0124A	0989 999415	GENNADIY ROMANOV	{"email": "romanov-g121982@postgrespro.ru", "phone": "+70677823926"}
0005435502389	7619BF	9912 031014	DMITRIY KUDRYASHOV	{"email": "kudryashov-d.111975@postgrespro.ru", "phone": "+70056570509"}
0005435502390	7619BF	6296 470020	ALEKSANDR VASILEV	{"phone": "+70375863346"}
0005435502391	87A439	7018 069284	ELENA YUDINA	{"phone": "+70548319122"}
0005435502392	7FFE86	8736 577531	SVETLANA TIMOFEEVA	{"email": "timofeeva_svetlana.1979@postgrespro.ru", "phone": "+70989571949"}
0005435502393	ADCA88	0415 809805	VALENTINA IVANOVA	{"email": "valentina-ivanova_051966@postgrespro.ru", "phone": "+70710161215"}
0005435502394	ADCA88	8894 798179	SVETLANA MATVEEVA	{"phone": "+70155628877"}
0005435502395	5AA368	9430 500798	VERONIKA LAZAREVA	{"email": "lazareva_veronika-091973@postgrespro.ru", "phone": "+70522108361"}
0005435502396	5AA368	7381 441897	ALEKSANDR MOISEEV	{"phone": "+70131158055"}
0005435502397	94EEC1	9380 333015	RAISA PAVLOVA	{"phone": "+70142256484"}
0005435502398	6F4968	0988 428223	VERONIKA ZHURAVLEVA	{"email": "zhuravlevav-061975@postgrespro.ru", "phone": "+70798193671"}
0005435502399	6F4968	4052 221734	NIKITA KARPOV	{"phone": "+70155080087"}
0005435502400	01537F	9712 942179	NIKITA KUZMIN	{"email": "kuzmin-n.1969@postgrespro.ru", "phone": "+70683531533"}
0005435502401	02FFB6	4026 402952	DMITRIY SOLOVEV	{"phone": "+70478837125"}
0005435502402	9345FF	5807 940108	ELENA ISAEVA	{"email": "elena_isaeva09111960@postgrespro.ru", "phone": "+70771252545"}
0005435502403	EC47C1	0589 264980	ELIZAVETA MAKSIMOVA	{"email": "elizavetamaksimova13121970@postgrespro.ru", "phone": "+70229405190"}
0005435502404	EC47C1	4705 690996	ALEKSANDR TIKHONOV	{"phone": "+70117076803"}
0005435502405	16AAE7	5962 750522	DMITRIY MIRONOV	{"phone": "+70345439154"}
0005435502406	0DC2A6	7904 541920	ELENA MAKAROVA	{"email": "elena-makarova-031972@postgrespro.ru", "phone": "+70076731845"}
0005435502407	F88B8E	0310 284736	MARIYA ROMANOVA	{"phone": "+70749518898"}
0005435502408	F88B8E	7355 722047	VLADIMIR BORISOV	{"email": "vladimir-borisov.011977@postgrespro.ru", "phone": "+70689967018"}
0005435502409	F88B8E	6543 694407	SVETLANA CHERNOVA	{"email": "svetlana_chernova.091978@postgrespro.ru", "phone": "+70570124597"}
0005435502410	E16419	9067 123475	NIKOLAY POPOV	{"phone": "+70383659461"}
0005435502411	867B96	1775 868469	ANTONINA OSIPOVA	{"email": "osipova-antonina.15021973@postgrespro.ru", "phone": "+70294355326"}
0005435502412	867B96	9763 483330	YULIYA SOROKINA	{"email": "y-sorokina-1971@postgrespro.ru", "phone": "+70112987458"}
0005435502413	867B96	1668 115908	SERGEY MAKSIMOV	{"email": "maksimovs-1964@postgrespro.ru", "phone": "+70100569245"}
0005435502414	E30402	4758 398304	VLADIMIR MATVEEV	{"phone": "+70429223452"}
0005435502415	E30402	3455 094141	ALEKSEY TIKHONOV	{"phone": "+70421033456"}
0005435502416	E30402	6917 841982	KIRILL KULIKOV	{"phone": "+70051056280"}
0005435502417	087E06	1763 257672	ANASTASIYA MIRONOVA	{"email": "mironovaa-1973@postgrespro.ru", "phone": "+70758247116"}
0005435502418	B981C7	2867 901399	VIKTOR KUDRYASHOV	{"email": "kudryashovviktor.1974@postgrespro.ru", "phone": "+70408309247"}
0005435502419	B981C7	0397 487367	VALERIY KISELEV	{"phone": "+70311329733"}
0005435502420	82D6B5	2999 527969	EDUARD FILIPPOV	{"email": "efilippov_13031975@postgrespro.ru", "phone": "+70933959480"}
0005435502421	51BA57	2896 398272	VLADIMIR SOKOLOV	{"email": "v.sokolov_1963@postgrespro.ru", "phone": "+70587986769"}
0005435502422	8153B9	8534 197762	ALEKSEY BELOV	{"email": "belov_aleksey29121967@postgrespro.ru", "phone": "+70896248457"}
0005435502423	4BF83E	4975 142293	VERA POTAPOVA	{"phone": "+70589874128"}
0005435502424	4BF83E	7357 533961	NATALYA SOLOVEVA	{"phone": "+70455776163"}
0005435502425	4BF83E	9346 101215	MARINA VASILEVA	{"phone": "+70421531946"}
0005435502426	2F8898	2146 093542	GALINA OVCHINNIKOVA	{"phone": "+70411108920"}
0005435502427	2F8898	3790 545319	VIKTOR VASILEV	{"phone": "+70452284262"}
0005435502428	8AD6E1	9312 070309	VIKTOR SOROKIN	{"phone": "+70459816508"}
0005435502429	1A2EE7	1215 016164	NADEZHDA RODIONOVA	{"phone": "+70528366815"}
0005435502430	613190	4417 854704	VALERIYA ORLOVA	{"phone": "+70889869155"}
0005435502431	0B1464	7215 983968	IVAN ANDREEV	{"phone": "+70058742555"}
0005435502432	0B1464	5838 296425	VALERIY SERGEEV	{"phone": "+70614944797"}
0005435502433	EF0961	0257 344617	ELIZAVETA MELNIKOVA	{"phone": "+70093674467"}
0005435502434	EF0961	5815 291533	IGOR PAVLOV	{"phone": "+70952619257"}
0005435502435	13B846	9805 323197	ILYA KUZMIN	{"email": "kuzmin_i-14111978@postgrespro.ru", "phone": "+70257772824"}
0005435502436	B84F8D	1081 945713	LIDIYA KONDRATEVA	{"email": "l.kondrateva-1976@postgrespro.ru", "phone": "+70977600420"}
0005435502437	85A8BA	0658 697797	TATYANA MOROZOVA	{"phone": "+70099288235"}
0005435502438	1CD64C	0334 550372	DENIS VOLKOV	{"email": "d_volkov.1967@postgrespro.ru", "phone": "+70523122098"}
0005435502439	993778	4249 504349	MARINA KUZNECOVA	{"email": "kuznecova-marina_101972@postgrespro.ru", "phone": "+70185919862"}
0005435502440	993778	3823 469658	ANDREY KARPOV	{"phone": "+70431101784"}
0005435502441	50AB22	3444 959821	ELENA KUDRYASHOVA	{"phone": "+70890304698"}
0005435502442	E8104A	2501 959636	ALEKSEY STEPANOV	{"email": "stepanov-aleksey07051965@postgrespro.ru", "phone": "+70498741794"}
0005435502443	D6E276	4329 368544	YULIYA BOGDANOVA	{"phone": "+70040366017"}
0005435502444	25C0D0	3693 272949	ALEKSANDR AFANASEV	{"phone": "+70321932163"}
0005435502445	25C0D0	0815 697297	SERGEY PAVLOV	{"phone": "+70417989307"}
0005435502446	789FC4	5043 126410	TATYANA KUDRYASHOVA	{"phone": "+70193845207"}
0005435502447	15C654	7301 650180	SVETLANA KUZNECOVA	{"phone": "+70374497096"}
0005435502448	3E09F7	3311 374953	IVAN NOVIKOV	{"phone": "+70281970876"}
0005435502449	3E09F7	7795 762847	NIKOLAY MARTYNOV	{"phone": "+70676188279"}
0005435502450	2D54E0	3119 224771	RUSLAN MAKAROV	{"email": "ruslan.makarov.011964@postgrespro.ru", "phone": "+70494947228"}
0005435502451	F228B5	2506 343384	EKATERINA MOROZOVA	{"phone": "+70797758972"}
0005435502452	F228B5	9545 082296	PELAGEYA VOLKOVA	{"phone": "+70548091286"}
0005435502453	285E25	6897 885595	ANDREY FEDOROV	{"phone": "+70631792574"}
0005435502454	AB5AB0	4709 053574	VLADIMIR ZHURAVLEV	{"phone": "+70610452199"}
0005435502455	AB5AB0	7416 092074	ALEKSANDRA SERGEEVA	{"email": "sergeeva.aleksandra1970@postgrespro.ru", "phone": "+70162195640"}
0005435502456	2CF6D8	9740 435490	NINA MIKHAYLOVA	{"phone": "+70605231514"}
0005435502457	304E9F	2150 029870	LYUDMILA ANISIMOVA	{"phone": "+70670593002"}
0005435502458	294D2E	8008 745298	DMITRIY GORBUNOV	{"phone": "+70589346833"}
0005435502459	DAD64D	1770 833258	MIKHAIL NIKOLAEV	{"phone": "+70514315405"}
0005435502460	DAD64D	8999 489597	LIDIYA VASILEVA	{"phone": "+70165375948"}
0005435502461	A825EE	3590 017728	YULIYA ALEKSEEVA	{"email": "y-alekseeva_1975@postgrespro.ru", "phone": "+70961828954"}
0005435502462	0DD0C2	6686 290394	DARYA SAVELEVA	{"phone": "+70423592920"}
0005435502463	4DAC04	6674 661395	GALINA VLASOVA	{"phone": "+70046464441"}
0005435502464	A32FA4	7787 746649	ALEKSANDR POPOV	{"phone": "+70451189113"}
0005435502465	7A11A4	1042 603914	EVGENIY PAVLOV	{"email": "e_pavlov_1966@postgrespro.ru", "phone": "+70072029948"}
0005435502466	7A11A4	0119 250946	TAMARA AKIMOVA	{"phone": "+70349102865"}
0005435502467	23949A	5927 301852	RAISA BARANOVA	{"phone": "+70583841217"}
0005435502468	A56D63	6031 558280	ANNA IVANOVA	{"phone": "+70538055058"}
0005435502469	2C41EF	4258 742535	ANDREY SIDOROV	{"email": "a.sidorov-1967@postgrespro.ru", "phone": "+70739435473"}
0005435502470	3425A5	1741 493361	FARIDA KOZLOVA	{"phone": "+70374226713"}
0005435502471	16AC2B	4879 570939	NATALYA SMIRNOVA	{"email": "natalyasmirnova-101976@postgrespro.ru", "phone": "+70623302445"}
0005435502472	BD132D	9987 851632	TATYANA NOVIKOVA	{"email": "t_novikova1977@postgrespro.ru", "phone": "+70427437201"}
0005435502473	BD132D	2433 894071	SERGEY POPOV	{"email": "popov.s_081973@postgrespro.ru", "phone": "+70404984305"}
0005435502474	2980FE	5388 133927	VYACHESLAV MOROZOV	{"phone": "+70038273102"}
0005435502475	3D6513	2899 900831	ALEKSANDR GORBUNOV	{"phone": "+70779776473"}
0005435502476	3D6513	5594 540377	SERGEY ZAYCEV	{"phone": "+70878098683"}
0005435502477	363C5C	1886 373940	MARGARITA KOROLEVA	{"email": "m_koroleva_1963@postgrespro.ru", "phone": "+70831413929"}
0005435502478	C8426B	3533 118999	ALEKSANDR AFANASEV	{"email": "aleksandr_afanasev041973@postgrespro.ru", "phone": "+70487426520"}
0005435502479	09F851	2777 141731	RUSTAM VLASOV	{"email": "r-vlasov_1960@postgrespro.ru", "phone": "+70958870844"}
0005435502480	09F851	1337 254076	ANATOLIY DMITRIEV	{"email": "dmitriev.a.1965@postgrespro.ru", "phone": "+70908887498"}
0005435502481	09F851	5797 027422	TATYANA ERMAKOVA	{"phone": "+70222438993"}
0005435502482	50B6AE	9582 320925	TATYANA MASLOVA	{"phone": "+70433346323"}
0005435502483	50B6AE	8639 365941	LYUBOV ABRAMOVA	{"email": "lyubov-abramova-1971@postgrespro.ru", "phone": "+70329328024"}
0005435502484	0E717D	6985 002804	ALEKSANDR KULIKOV	{"phone": "+70973559680"}
0005435502485	C9476D	0845 296760	ALEKSEY NIKOLAEV	{"email": "alekseynikolaev1961@postgrespro.ru", "phone": "+70109265136"}
0005435502486	2A68C6	6277 579649	ALISA FOMINA	{"email": "fomina-a121977@postgrespro.ru", "phone": "+70893705700"}
0005435502487	BCDA8D	9601 317932	VALENTINA STEPANOVA	{"phone": "+70048351347"}
0005435502488	BCDA8D	3328 132933	ANDREY GORBUNOV	{"email": "gorbunov_a.081975@postgrespro.ru", "phone": "+70790104037"}
0005435502489	AEE5E1	0896 864397	MARIYA NAZAROVA	{"email": "m.nazarova-1966@postgrespro.ru", "phone": "+70755923863"}
0005435502490	F88BBD	8666 367116	ALEKSANDR VASILEV	{"phone": "+70037501421"}
0005435502491	F88BBD	6472 700061	DENIS MOISEEV	{"phone": "+70342874647"}
0005435502492	57D85D	7322 442848	OLGA TITOVA	{"phone": "+70219986049"}
0005435502493	57D85D	5952 013835	ELENA KARPOVA	{"email": "e.karpova.06021973@postgrespro.ru", "phone": "+70137475078"}
0005435502494	F04B53	8001 472413	ALEKSANDR ALEKSEEV	{"email": "aleksandr-alekseev_1968@postgrespro.ru", "phone": "+70154153624"}
0005435502495	F04B53	8432 485062	ALENA NESTEROVA	{"email": "nesterova-a-07061972@postgrespro.ru", "phone": "+70718179505"}
0005435502496	03A3BE	8807 361162	GENNADIY FOMIN	{"phone": "+70120409779"}
0005435502497	03A3BE	2344 829109	LYUBOV ARKHIPOVA	{"email": "lyubov.arkhipova-04091967@postgrespro.ru", "phone": "+70629015963"}
0005435502498	D45533	3886 937949	PAVEL SMIRNOV	{"phone": "+70047098280"}
0005435502499	D45533	4473 733114	MIKHAIL YAKOVLEV	{"phone": "+70564735991"}
0005435502500	E43700	7361 645333	VLADIMIR FOMIN	{"phone": "+70771646804"}
0005435502501	1E4421	0439 603313	OLEG FILIPPOV	{"email": "o_filippov.111963@postgrespro.ru", "phone": "+70213892099"}
0005435502502	B3F221	5195 791614	ELENA VOLKOVA	{"email": "volkova-elena.1966@postgrespro.ru", "phone": "+70606499419"}
0005435502503	B3F221	4725 356448	MIKHAIL MAKAROV	{"email": "mikhail_makarov111968@postgrespro.ru", "phone": "+70024930669"}
0005435502504	9B744B	9832 125235	VLADISLAV FILIPPOV	{"email": "filippovvladislav-1981@postgrespro.ru", "phone": "+70607817178"}
0005435502505	05F35E	5327 918002	RAVIL SOLOVEV	{"phone": "+70440685119"}
0005435502506	85927B	5266 598770	VLADIMIR TIKHONOV	{"email": "tikhonov-vladimir.091965@postgrespro.ru", "phone": "+70265696829"}
0005435502507	85927B	9715 914635	ALLA RYABOVA	{"phone": "+70486275816"}
0005435502508	61870A	3964 924038	ANASTASIYA EGOROVA	{"phone": "+70396702282"}
0005435502509	3F1EFB	0968 304317	SERGEY ZHUKOV	{"phone": "+70839825566"}
0005435502510	3F1EFB	0818 647395	ALEKSANDR BELOV	{"phone": "+70673896767"}
0005435502511	3F1EFB	2648 615387	VALENTINA SOROKINA	{"phone": "+70211562799"}
0005435502512	DB34CF	0422 523722	YULIYA MASLOVA	{"phone": "+70422247324"}
0005435502513	229F74	2922 424500	NIKOLAY POPOV	{"email": "n.popov.30071969@postgrespro.ru", "phone": "+70343549264"}
0005435502514	D392DD	9705 069973	VADIM MIKHAYLOV	{"phone": "+70014436603"}
0005435502515	D392DD	8479 299333	VALENTINA BOGDANOVA	{"phone": "+70396127749"}
0005435502516	6F34EF	1842 384419	ANNA KULIKOVA	{"phone": "+70174097587"}
0005435502517	9A93AF	2876 905461	SERGEY AFANASEV	{"phone": "+70037921544"}
0005435502518	782AC3	9957 279960	ANDREY KUZMIN	{"email": "kuzmin.a.26081983@postgrespro.ru", "phone": "+70324167366"}
0005435502519	782AC3	5441 636801	ANATOLIY FILIPPOV	{"email": "anatoliy_filippov.1970@postgrespro.ru", "phone": "+70046424580"}
0005435502520	FE236D	4348 569117	ALEKSANDR MARTYNOV	{"phone": "+70572798647"}
0005435502521	FE236D	8842 980209	ELENA POPOVA	{"phone": "+70391014069"}
0005435502522	FE236D	3342 870648	VALENTINA STEPANOVA	{"phone": "+70615268194"}
0005435502523	EBC1C3	3495 478397	NATALYA MALYSHEVA	{"phone": "+70043617693"}
0005435502524	FBFA7B	5044 021300	DANIYA NAZAROVA	{"phone": "+70519035070"}
0005435502525	FBFA7B	6566 992520	ILYA KOZLOV	{"phone": "+70415268963"}
0005435502526	FBFA7B	5399 519490	OLGA ARKHIPOVA	{"email": "oarkhipova_051975@postgrespro.ru", "phone": "+70581901905"}
0005435502527	DD19AD	9800 977236	IRINA KOZLOVA	{"email": "i-kozlova20081975@postgrespro.ru", "phone": "+70195435517"}
0005435502528	DD19AD	2803 535283	VIOLETTA ANDREEVA	{"email": "v_andreeva.1973@postgrespro.ru", "phone": "+70435719982"}
0005435502529	DD19AD	2405 541717	KONSTANTIN KUZMIN	{"phone": "+70563387684"}
0005435502530	28272D	1662 600338	PETR IVANOV	{"phone": "+70351231542"}
0005435502531	801D14	6295 650764	MARINA ANTONOVA	{"phone": "+70608521666"}
0005435502532	5587B6	7886 778402	VALERIYA SOROKINA	{"email": "valeriyasorokina-01101970@postgrespro.ru", "phone": "+70724319291"}
0005435502533	549319	3188 167897	VALERIY KUZNECOV	{"email": "valeriy-kuznecov1967@postgrespro.ru", "phone": "+70079444022"}
0005435502534	80A22B	7750 151165	ALEKSANDR TIKHONOV	{"phone": "+70366759371"}
0005435502535	B3AEF2	3768 031473	ELENA GRISHINA	{"phone": "+70162305482"}
0005435502536	7AF1CD	9130 474959	NIKOLAY ABRAMOV	{"phone": "+70049595925"}
0005435502537	7AF1CD	7629 794326	YURIY NIKITIN	{"phone": "+70332584900"}
0005435502538	7AF1CD	2182 143119	AMINA MARTYNOVA	{"email": "martynova_a081979@postgrespro.ru", "phone": "+70533894266"}
0005435502539	FBCC1A	3682 860301	VALENTINA POLYAKOVA	{"email": "valentina_polyakova.24061963@postgrespro.ru", "phone": "+70198719524"}
0005435502540	F45632	0208 713546	NIKITA PETROV	{"phone": "+70004206880"}
0005435502541	DDC52B	6194 102551	LARISA MAKAROVA	{"email": "l-makarova16111977@postgrespro.ru", "phone": "+70987092631"}
0005435502542	264DE8	8281 403219	TATYANA MIRONOVA	{"phone": "+70799764760"}
0005435502543	264DE8	1863 682685	ALEKSEY BONDARENKO	{"email": "abondarenko-031973@postgrespro.ru", "phone": "+70344388170"}
0005435502544	FF6CE5	4926 884251	ALISA KALININA	{"email": "kalinina_alisa-1972@postgrespro.ru", "phone": "+70690163524"}
0005435502545	774246	7581 351991	MARIYA OVCHINNIKOVA	{"email": "mariya.ovchinnikova_121978@postgrespro.ru", "phone": "+70687869101"}
0005435502546	774246	0072 059008	NATALYA FILATOVA	{"phone": "+70082645382"}
0005435502547	5D775A	8772 818110	VALENTINA NAUMOVA	{"email": "valentina.naumova_01111971@postgrespro.ru", "phone": "+70572467895"}
0005435502548	35D03F	5619 883902	MARIYA KOZLOVA	{"email": "mariya_kozlova19051975@postgrespro.ru", "phone": "+70766642679"}
0005435502549	07EC79	5242 432512	TATYANA BORISOVA	{"email": "borisova-t_091966@postgrespro.ru", "phone": "+70588400609"}
0005435502550	011400	6119 469611	ANASTASIYA FROLOVA	{"phone": "+70729642686"}
0005435502551	011400	0554 702046	FEDOR ORLOV	{"email": "f.orlov.1961@postgrespro.ru", "phone": "+70994164650"}
0005435502552	011400	0774 525980	ANDREY SMIRNOV	{"phone": "+70796476331"}
0005435502553	A4C327	7190 208068	SERGEY STEPANOV	{"phone": "+70116969701"}
0005435502554	AADBCF	0722 039180	KRISTINA GRISHINA	{"email": "grishinakristina.22071978@postgrespro.ru", "phone": "+70848721517"}
0005435502555	AADBCF	5634 459256	OLEG NAZAROV	{"phone": "+70769728472"}
0005435502556	460D3E	1683 536013	BOGDAN NOVIKOV	{"phone": "+70961940374"}
0005435502557	3B31B6	8656 442005	ALEKSANDR FROLOV	{"email": "a.frolov.1980@postgrespro.ru", "phone": "+70556184212"}
0005435502558	3B31B6	2911 292573	SERGEY KONOVALOV	{"email": "konovalov_s_1988@postgrespro.ru", "phone": "+70746364180"}
0005435502559	1E119F	1758 037156	YURIY NOVIKOV	{"email": "yuriy-novikov20091971@postgrespro.ru", "phone": "+70170429639"}
0005435502560	6F47E9	6948 463044	ANDREY SCHERBAKOV	{"email": "scherbakov-a.04091977@postgrespro.ru", "phone": "+70173294726"}
0005435502561	70D896	1848 192362	RUSTAM KUZNECOV	{"phone": "+70270426382"}
0005435502562	70D896	7755 661140	ALEKSANDR ZAKHAROV	{"phone": "+70572339438"}
0005435502563	70D896	6699 222704	OLEG DAVYDOV	{"email": "davydov.o_011961@postgrespro.ru", "phone": "+70519709211"}
0005435502564	401F2F	8904 510803	KRISTINA KUZNECOVA	{"phone": "+70680952265"}
0005435502565	B64DE0	8684 952044	NATALYA BELOVA	{"email": "n_belova041970@postgrespro.ru", "phone": "+70586365531"}
0005435502566	F567EA	4474 923419	ALEKSANDRA MOROZOVA	{"email": "aleksandra.morozova_1977@postgrespro.ru", "phone": "+70607718637"}
0005435502567	FEADD1	8426 809073	VLADA MOISEEVA	{"email": "vlada-moiseeva1971@postgrespro.ru", "phone": "+70945941952"}
0005435502568	FEADD1	1843 673353	ALEKSANDRA KAZAKOVA	{"phone": "+70228766746"}
0005435502569	51D672	7952 984446	ANNA VOLKOVA	{"email": "avolkova-15041978@postgrespro.ru", "phone": "+70779287936"}
0005435502570	51D672	1715 747795	MARIYA PETROVA	{"email": "m.petrova.04011971@postgrespro.ru", "phone": "+70330881365"}
0005435502571	F45A1D	7088 705309	NADEZHDA VOLKOVA	{"phone": "+70912025258"}
0005435502572	91CC6E	1342 015092	DARYA KALININA	{"phone": "+70835837197"}
0005435502573	58CF0D	1014 057825	MARIYA SCHERBAKOVA	{"phone": "+70035738167"}
0005435502574	8EBAA0	8022 448107	KRISTINA AKIMOVA	{"phone": "+70268457346"}
0005435502575	539ACE	3101 448781	ALEKSANDR MAKSIMOV	{"email": "maksimov-a_1967@postgrespro.ru", "phone": "+70260616008"}
0005435502576	539ACE	0336 574449	NIKOLAY VASILEV	{"phone": "+70510111962"}
0005435502577	668A25	3631 818649	VLADIMIR RODIONOV	{"email": "rodionov.v1968@postgrespro.ru", "phone": "+70750409192"}
0005435502578	668A25	2379 431960	ANDREY VOLKOV	{"email": "volkov_a_021970@postgrespro.ru", "phone": "+70424062265"}
0005435502579	CD99D5	7184 453438	OLEG SMIRNOV	{"phone": "+70090900458"}
0005435502580	539382	4107 361325	BOGDAN VASILEV	{"email": "vasilev-bogdan.021968@postgrespro.ru", "phone": "+70638020475"}
0005435502581	B2B479	6636 668935	NATALYA ABRAMOVA	{"phone": "+70998002591"}
0005435502582	B2B479	5380 407853	IRINA FILIPPOVA	{"phone": "+70604847016"}
0005435502583	139568	0076 200020	NATALYA TIKHONOVA	{"email": "natalya.tikhonova.08071978@postgrespro.ru", "phone": "+70546172367"}
0005435502584	139568	5267 278199	SVETLANA LUKYANOVA	{"email": "svetlanalukyanova-1977@postgrespro.ru", "phone": "+70934496411"}
0005435502585	F0F816	1848 202918	VLADIMIR IVANOV	{"email": "ivanovv.021964@postgrespro.ru", "phone": "+70327585272"}
0005435502586	E9F4A8	1192 194314	VASILIY VASILEV	{"phone": "+70087935478"}
0005435502587	69C55B	3955 332667	NIKITA STEPANOV	{"email": "stepanov.nikita-091968@postgrespro.ru", "phone": "+70349219221"}
0005435502588	69C55B	3830 748131	VERA POLYAKOVA	{"email": "polyakova-v.13041974@postgrespro.ru", "phone": "+70909273878"}
0005435502589	9321CB	5837 635970	OLGA SCHERBAKOVA	{"phone": "+70382165027"}
0005435502590	2CEF10	7424 807661	ARTEM NAZAROV	{"phone": "+70692388079"}
0005435502591	2CEF10	3211 635537	NIKOLAY MIRONOV	{"email": "nikolay_mironov.12061978@postgrespro.ru", "phone": "+70768834287"}
0005435502592	2DBD6E	1483 922384	DMITRIY SCHERBAKOV	{"email": "dmitriy-scherbakov-1975@postgrespro.ru", "phone": "+70217178921"}
0005435502593	2DBD6E	5711 300607	VITALIY KUZMIN	{"email": "vitaliykuzmin.101985@postgrespro.ru", "phone": "+70979965646"}
0005435502594	C8C1F5	5987 542076	ELENA MAKAROVA	{"phone": "+70391460693"}
0005435502595	3E8498	4848 715771	VLADIMIR CHERNOV	{"email": "vchernov1968@postgrespro.ru", "phone": "+70100914061"}
0005435502596	43E747	6889 117820	ANATOLIY YAKOVLEV	{"phone": "+70784760184"}
0005435502597	A4E76B	1917 298927	VLADISLAV SCHERBAKOV	{"phone": "+70617236035"}
0005435502598	49B7BF	8135 215002	PETR BONDARENKO	{"email": "p-bondarenko.111966@postgrespro.ru", "phone": "+70893255974"}
0005435502599	49B7BF	1148 145758	MIKHAIL KUZNECOV	{"phone": "+70099959040"}
0005435502600	F0BA3A	1587 432450	IGOR KUDRYASHOV	{"phone": "+70318776128"}
0005435502601	FD6D56	7352 724163	EVGENIY SCHERBAKOV	{"email": "scherbakov.e27111971@postgrespro.ru", "phone": "+70158164319"}
0005435502602	FD6D56	3538 737330	TATYANA TITOVA	{"phone": "+70827799682"}
0005435502603	FD6D56	7298 723860	VIKTOR CHERNOV	{"email": "chernov_v091973@postgrespro.ru", "phone": "+70730026950"}
0005435502604	5CA86D	3675 802807	VALENTINA ANTONOVA	{"email": "v-antonova-1975@postgrespro.ru", "phone": "+70585839485"}
0005435502605	5CA86D	6184 631141	LYUBOV ALEKSEEVA	{"phone": "+70901070161"}
0005435502606	5CD5C5	6552 684576	EVGENIY KUZNECOV	{"phone": "+70314243965"}
0005435502607	5CD5C5	7056 596523	VIKTOR ALEKSANDROV	{"email": "viktor-aleksandrov-13021973@postgrespro.ru", "phone": "+70299037483"}
0005435502608	DA4A1C	4376 009268	TATYANA KONDRATEVA	{"phone": "+70291478593"}
0005435502609	B5D8E8	2802 067040	SERAFIMA EFREMOVA	{"phone": "+70301820308"}
0005435502610	BA5334	9488 986060	MATVEY KUZNECOV	{"phone": "+70241344372"}
0005435502611	27520E	4616 472483	NATALYA GAVRILOVA	{"phone": "+70030795435"}
0005435502612	27520E	6455 760656	IVAN ROMANOV	{"email": "romanovivan_101969@postgrespro.ru", "phone": "+70056966049"}
0005435502613	A0FE5B	9228 077210	TATYANA MAKAROVA	{"phone": "+70992538976"}
0005435502614	A3C4A8	9926 728102	ARTEM ROMANOV	{"phone": "+70141191575"}
0005435502615	A3C4A8	3354 918248	VLADIMIR DAVYDOV	{"email": "vladimir-davydov06111968@postgrespro.ru", "phone": "+70308599324"}
0005435502616	B59B9D	7014 299858	VLADIMIR ALEKSEEV	{"phone": "+70421920558"}
0005435502617	EF99DA	5512 670195	VASILIY MATVEEV	{"email": "matveevvasiliy_021973@postgrespro.ru", "phone": "+70739596536"}
0005435502618	577F16	4252 580538	IRINA IVANOVA	{"phone": "+70865334111"}
0005435502619	5D5001	7571 510153	NIKOLAY KRASNOV	{"phone": "+70959398665"}
0005435502620	D2A0CA	6782 780301	SERGEY ANTONOV	{"phone": "+70884354475"}
0005435502621	3025F4	5378 648434	VERA ZAYCEVA	{"email": "vera_zayceva_1968@postgrespro.ru", "phone": "+70646324558"}
0005435502622	3025F4	3927 548103	SERGEY SIDOROV	{"phone": "+70137749580"}
0005435502623	340A97	5630 693668	TATYANA TIKHONOVA	{"email": "tikhonovat16071962@postgrespro.ru", "phone": "+70637064448"}
0005435502624	340A97	3914 887869	IRINA NAZAROVA	{"phone": "+70362998643"}
0005435502625	D187A3	0462 619288	SERGEY ZHUKOV	{"phone": "+70202705732"}
0005435502626	A2B585	0005 914883	VLADIMIR ILIN	{"email": "vladimir.ilin.13041970@postgrespro.ru", "phone": "+70934027497"}
0005435502627	2052E2	2907 587669	ANTONINA KONDRATEVA	{"email": "kondrateva_a_1967@postgrespro.ru", "phone": "+70544290309"}
0005435502628	B58D94	3287 999123	ALEKSEY DENISOV	{"email": "a.denisov_031963@postgrespro.ru", "phone": "+70498088809"}
0005435502629	B58D94	3068 742185	IRINA KUZMINA	{"email": "i_kuzmina_08121964@postgrespro.ru", "phone": "+70699713142"}
0005435502630	6AD937	7657 840978	MARINA KUZNECOVA	{"email": "m.kuznecova_081975@postgrespro.ru", "phone": "+70518168252"}
0005435502631	56FD1D	9892 382783	ELENA TITOVA	{"phone": "+70076232616"}
0005435502632	145E33	0326 944252	OLESYA VOLKOVA	{"email": "o.volkova041971@postgrespro.ru", "phone": "+70867981056"}
0005435502633	145E33	7259 957617	ALEKSANDR TIKHONOV	{"phone": "+70599856354"}
0005435502634	8E5CB2	1045 175114	ANNA GRISHINA	{"phone": "+70055676075"}
0005435502635	527731	2427 917415	OLGA VASILEVA	{"email": "vasilevaolga.21101971@postgrespro.ru", "phone": "+70275899457"}
0005435502636	AA86DB	0968 274483	SERGEY EGOROV	{"phone": "+70015924592"}
0005435502637	B79151	6166 564558	MAKSIM SOROKIN	{"email": "msorokin111981@postgrespro.ru", "phone": "+70259227183"}
0005435502638	18A967	1037 424366	DMITRIY KONOVALOV	{"phone": "+70547497851"}
0005435502639	F7E656	0459 001193	FATYMA KUZMINA	{"phone": "+70302586834"}
0005435502640	94A6AF	6588 695507	ANTON PAVLOV	{"phone": "+70326501770"}
0005435502641	282BDA	9559 750932	ALBINA MOISEEVA	{"email": "a_moiseeva.121967@postgrespro.ru", "phone": "+70646178471"}
0005435502642	B2E598	2818 079315	DENIS FEDOTOV	{"email": "d.fedotov_1962@postgrespro.ru", "phone": "+70537984613"}
0005435502643	E1CEBD	7764 907169	OLGA ERMAKOVA	{"phone": "+70868283618"}
0005435502644	E1CEBD	8455 147698	SOFYA SOROKINA	{"email": "s_sorokina.101975@postgrespro.ru", "phone": "+70110051610"}
0005435502645	E2726C	5926 710733	LILIYA LEBEDEVA	{"email": "lebedeva-liliya011982@postgrespro.ru", "phone": "+70467897000"}
0005435502646	F408AA	9211 317305	ALEKSANDR POPOV	{"email": "aleksandr_popov.101961@postgrespro.ru", "phone": "+70470721326"}
0005435502647	1928D0	0207 599112	YURIY GRIGOREV	{"phone": "+70009302297"}
0005435502648	FAE9C2	4386 575114	ELIZAVETA ALEKSEEVA	{"phone": "+70690344790"}
0005435502649	FAE9C2	1075 929088	IGOR KUZNECOV	{"phone": "+70828949935"}
0005435502650	FAE9C2	8638 509948	VIKTOR MATVEEV	{"phone": "+70291453155"}
0005435502651	1B3532	9150 683486	ARINA MELNIKOVA	{"phone": "+70630591118"}
0005435502652	33C9F6	2681 434423	ELENA KONOVALOVA	{"phone": "+70327504646"}
0005435502653	5A2125	6582 884546	NIKOLAY SIDOROV	{"email": "sidorovnikolay.071971@postgrespro.ru", "phone": "+70029414793"}
0005435502654	5A2125	4494 569301	ALFIYA KULIKOVA	{"email": "alfiya-kulikova_12021969@postgrespro.ru", "phone": "+70172395041"}
0005435502655	5A2125	6363 510288	NADEZHDA ROMANOVA	{"email": "nadezhdaromanova_1970@postgrespro.ru", "phone": "+70854589241"}
0005435502656	94EF93	9478 170503	KSENIYA RYABOVA	{"email": "k.ryabova1968@postgrespro.ru", "phone": "+70250041319"}
0005435502657	94EF93	5104 274824	YURIY IVANOV	{"email": "ivanov-yuriy-101969@postgrespro.ru", "phone": "+70005599725"}
0005435502658	47C8FC	6920 006948	MARIYA DANILOVA	{"phone": "+70344424308"}
0005435502659	8CBC5C	8248 711479	KSENIYA VLASOVA	{"email": "k_vlasova-09071979@postgrespro.ru", "phone": "+70693051014"}
0005435502660	D33023	3056 205611	NIKOLAY MOROZOV	{"email": "morozov_nikolay.1982@postgrespro.ru", "phone": "+70071461231"}
0005435502661	BC334F	3797 686142	ANDREY ALEKSANDROV	{"phone": "+70862799956"}
0005435502662	BC334F	0712 427349	ANGELINA GUSEVA	{"email": "a-guseva_1975@postgrespro.ru", "phone": "+70727832630"}
0005435502663	653A77	8593 448098	NATALIYA ISAEVA	{"email": "isaevanataliya_1973@postgrespro.ru", "phone": "+70377306079"}
0005435502664	3B292B	5522 508704	TATYANA ANDREEVA	{"email": "tatyana_andreeva.13101964@postgrespro.ru", "phone": "+70437116772"}
0005435502665	3B292B	9670 995674	DMITRIY VOROBEV	{"phone": "+70139878171"}
0005435502666	6C0BFF	9590 276297	OLGA ZHUKOVA	{"email": "zhukova.olga-1969@postgrespro.ru", "phone": "+70224706701"}
0005435502667	B06022	2321 505981	ROMAN KOROLEV	{"email": "korolev_roman-16011977@postgrespro.ru", "phone": "+70643119172"}
0005435502668	D43A2A	3025 997897	DMITRIY ZAKHAROV	{"email": "d.zakharov.04081968@postgrespro.ru", "phone": "+70038434193"}
0005435502669	715607	7234 082581	IOSIF ANTONOV	{"email": "antonovi-04041965@postgrespro.ru", "phone": "+70856491645"}
0005435502670	715607	3712 116022	NIKITA ZAYCEV	{"email": "nikitazaycev08111960@postgrespro.ru", "phone": "+70812472748"}
0005435502671	CB1720	0341 168283	IRINA VOROBEVA	{"email": "i-vorobeva.1974@postgrespro.ru", "phone": "+70445218896"}
0005435502672	CB1720	8778 194930	LILIYA FEDOROVA	{"phone": "+70829377986"}
0005435502673	E84688	7429 775713	VALENTINA OVCHINNIKOVA	{"email": "vovchinnikova.031966@postgrespro.ru", "phone": "+70397622656"}
0005435502674	E84688	2918 038489	ANDREY ISAEV	{"email": "andrey.isaev_29091976@postgrespro.ru", "phone": "+70408712445"}
0005435502675	E84688	7029 947860	MARIYA KUZNECOVA	{"phone": "+70209768547"}
0005435502676	C3B97C	1069 547268	PAVEL ALEKSANDROV	{"email": "aleksandrovp_26051971@postgrespro.ru", "phone": "+70564789508"}
0005435502677	C3B97C	2913 082808	VIKTOR ALEKSANDROV	{"phone": "+70940861254"}
0005435502678	66BD2E	4482 964030	ALEKSANDR VOROBEV	{"phone": "+70408450577"}
0005435502679	15AE44	0279 589397	DMITRIY KARPOV	{"phone": "+70669116728"}
0005435502680	76803E	8063 644874	ELENA KUZMINA	{"email": "kuzminaelena-1975@postgrespro.ru", "phone": "+70358810145"}
0005435502681	AA4BCB	0188 396975	ALEKSANDR SOKOLOV	{"phone": "+70784656892"}
0005435502682	AA4BCB	1202 953938	OLGA ANDREEVA	{"email": "o.andreeva25111967@postgrespro.ru", "phone": "+70075803793"}
0005435502683	FE50D1	8981 057635	VIKTOR ZHUKOV	{"phone": "+70590157333"}
0005435502684	B98A79	4600 446629	IRINA VOROBEVA	{"email": "vorobeva_irina1980@postgrespro.ru", "phone": "+70864342277"}
0005435502685	B98A79	7494 229981	IVAN KOROLEV	{"phone": "+70215259593"}
0005435502686	B98A79	6366 081314	ALEKSANDR DMITRIEV	{"email": "dmitriev.aleksandr.06041969@postgrespro.ru", "phone": "+70071426268"}
0005435502687	8B3734	8325 021102	VALENTINA NOVIKOVA	{"email": "novikova.valentina-121972@postgrespro.ru", "phone": "+70498879109"}
0005435502688	8B3734	3781 268501	LYUDMILA KOROLEVA	{"email": "koroleval_101973@postgrespro.ru", "phone": "+70323649464"}
0005435502689	7C5520	6071 267455	DMITRIY VOLKOV	{"phone": "+70431016970"}
0005435502690	8CCECF	3748 972085	ALEKSEY BORISOV	{"phone": "+70731011331"}
0005435502691	02ED51	2242 038477	MARGARITA MELNIKOVA	{"email": "m.melnikova-11011974@postgrespro.ru", "phone": "+70639693330"}
0005435502692	6E9FE8	9635 964219	NAILYA FEDOROVA	{"email": "fedorova_n_1973@postgrespro.ru", "phone": "+70392886278"}
0005435502693	6E9FE8	8015 747531	VLADIMIR ZAKHAROV	{"email": "zakharovvladimir.18021955@postgrespro.ru", "phone": "+70523856601"}
0005435502694	6E9FE8	0177 756581	NADEZHDA FROLOVA	{"phone": "+70798306161"}
0005435502695	85F4DA	5642 929416	NATALIYA SEMENOVA	{"email": "nataliya-semenova-101972@postgrespro.ru", "phone": "+70091220769"}
0005435502696	85F4DA	9587 923404	RAMIL ZAYCEV	{"phone": "+70192076388"}
0005435502697	1C37DA	6041 358120	ILMIRA TARASOVA	{"phone": "+70238194732"}
0005435502698	1C37DA	6514 071143	ALEKSANDRA KULIKOVA	{"email": "aleksandrakulikova-021975@postgrespro.ru", "phone": "+70705257746"}
0005435502699	C18651	0410 306471	ALEKSANDR TIMOFEEV	{"email": "timofeev-aleksandr_021969@postgrespro.ru", "phone": "+70790036974"}
0005435502700	C18651	3569 269568	ALEKSANDR GORBUNOV	{"email": "gorbunova13111970@postgrespro.ru", "phone": "+70236492023"}
0005435502701	DB42CC	8458 619692	SERGEY KUZNECOV	{"phone": "+70026778606"}
0005435502702	91BFAD	8680 142888	ALEKSANDR AFANASEV	{"phone": "+70782331948"}
0005435502703	91BFAD	4525 399364	NINA SOKOLOVA	{"phone": "+70656370067"}
0005435502704	739DD8	6707 876038	MATRENA IVANOVA	{"phone": "+70030348432"}
0005435502705	7C8846	3980 962533	STANISLAV ISAEV	{"email": "s_isaev-061971@postgrespro.ru", "phone": "+70098790592"}
0005435502706	7C8846	4158 123934	VLADIMIR OSIPOV	{"email": "osipov-vladimir28071978@postgrespro.ru", "phone": "+70138505858"}
0005435502707	97767C	0377 381683	TAISIYA OVCHINNIKOVA	{"email": "t.ovchinnikova1968@postgrespro.ru", "phone": "+70354857192"}
0005435502708	1636A8	7652 208841	NATALYA POPOVA	{"email": "natalyapopova.07071968@postgrespro.ru", "phone": "+70799316849"}
0005435502709	A4E004	8991 858572	ALEKSEY ANTONOV	{"phone": "+70820782830"}
0005435502710	8B7F10	1045 567459	ANDREY KUZNECOV	{"email": "andrey-kuznecov.021969@postgrespro.ru", "phone": "+70174198419"}
0005435502711	FB3266	0144 572595	ALEKSANDR MAKSIMOV	{"email": "maksimova-081972@postgrespro.ru", "phone": "+70157390463"}
0005435502712	FB3266	2563 972465	NADEZHDA ROMANOVA	{"phone": "+70755441366"}
0005435502713	85630F	3904 611685	EVGENIYA ABRAMOVA	{"email": "abramova-e_1966@postgrespro.ru", "phone": "+70774149953"}
0005435502714	85630F	8580 904804	VADIM TIKHONOV	{"email": "v_tikhonov.031967@postgrespro.ru", "phone": "+70576199852"}
0005435502715	A06621	0213 476728	VIKTOR NIKITIN	{"phone": "+70082931898"}
0005435502716	A06621	6576 834296	ANDREY MAKAROV	{"email": "makarov-andrey1971@postgrespro.ru", "phone": "+70012848120"}
0005435502717	A06621	3759 238634	MARIYA PAVLOVA	{"phone": "+70633517080"}
0005435502718	2630D6	2671 941804	ANDREY KUZMIN	{"email": "kuzmin_a_1960@postgrespro.ru", "phone": "+70072496837"}
0005435502719	53FB8E	7773 086427	OLGA FADEEVA	{"email": "fadeevaolga.09041963@postgrespro.ru", "phone": "+70877903334"}
0005435502720	53FB8E	5071 174282	ALLA ALEKSANDROVA	{"email": "a_aleksandrova-16051969@postgrespro.ru", "phone": "+70901703892"}
0005435502721	46785A	0011 542829	VLADIMIR KISELEV	{"phone": "+70766545480"}
0005435502722	A8B342	8790 634451	KLAVDIYA LAZAREVA	{"email": "k_lazareva_111969@postgrespro.ru", "phone": "+70413070093"}
0005435502723	6CBAB2	6875 813058	YULIYA ORLOVA	{"email": "y.orlova1971@postgrespro.ru", "phone": "+70137087239"}
0005435502724	289428	7249 377197	LYUBOV KAZAKOVA	{"email": "l.kazakova_02011970@postgrespro.ru", "phone": "+70497614134"}
0005435502725	289428	4791 562841	STANISLAV SEMENOV	{"phone": "+70872263504"}
0005435502726	28ACBE	3405 067455	VALENTINA IVANOVA	{"email": "valentinaivanova-30051972@postgrespro.ru", "phone": "+70640418882"}
0005435502727	28ACBE	1839 758534	ANDREY BARANOV	{"phone": "+70981649739"}
0005435502728	CDEE58	3175 425004	MIKHAIL GERASIMOV	{"phone": "+70060675979"}
0005435502729	19B7E6	9343 306094	NIKOLAY SHEVCHENKO	{"email": "nikolay-shevchenko14101968@postgrespro.ru", "phone": "+70387565038"}
0005435502730	19B7E6	4471 133566	TATYANA MOISEEVA	{"phone": "+70533723684"}
0005435502731	1FA5E9	6973 545297	ALEKSANDR FEDOROV	{"email": "fedorov_a1974@postgrespro.ru", "phone": "+70692844622"}
0005435502732	2957A1	3798 748293	VERA KAZAKOVA	{"phone": "+70537926456"}
0005435502733	2957A1	8189 277422	LYUDMILA ZAKHAROVA	{"email": "l.zakharova27121976@postgrespro.ru", "phone": "+70654638685"}
0005435502734	76A942	1247 587914	NATALIYA MOROZOVA	{"email": "morozova_nataliya-26041969@postgrespro.ru", "phone": "+70839524046"}
0005435502735	F5B4BA	7811 596591	IRINA OVCHINNIKOVA	{"phone": "+70556389408"}
0005435502736	3A6555	3493 554656	VERA KONDRATEVA	{"phone": "+70251583365"}
0005435502737	A7F2E5	7655 278179	ANTONINA IVANOVA	{"email": "a-ivanova_071978@postgrespro.ru", "phone": "+70540960533"}
0005435502738	237761	3332 461989	IGOR IVANOV	{"email": "ivanov-i_1969@postgrespro.ru", "phone": "+70427400114"}
0005435502739	8BE882	1142 412517	VLADIMIR MARTYNOV	{"email": "martynov_vladimir_1979@postgrespro.ru", "phone": "+70643339879"}
0005435502740	5FA1BA	7207 392266	LYUDMILA IVANOVA	{"email": "ivanova-lyudmila-1970@postgrespro.ru", "phone": "+70059951291"}
0005435502741	4CE04E	9775 489871	VALERIY ISAEV	{"phone": "+70210454413"}
0005435502742	3A29A4	6651 532518	ALEKSEY SMIRNOV	{"phone": "+70817545559"}
0005435502743	D0779E	8469 000833	LYUBOV MOROZOVA	{"email": "morozoval-1978@postgrespro.ru", "phone": "+70735986196"}
0005435502744	FB0EB8	0785 070169	NINA VOROBEVA	{"email": "nvorobeva.05081980@postgrespro.ru", "phone": "+70402980853"}
0005435502745	F4FBC7	9272 688432	ELENA POPOVA	{"email": "popova.elena1957@postgrespro.ru", "phone": "+70827385770"}
0005435502746	015CD4	1174 113508	ARTEM MOISEEV	{"email": "moiseev_a.1970@postgrespro.ru", "phone": "+70003196049"}
0005435502747	D369D1	4934 738369	VITALIY NIKOLAEV	{"phone": "+70810484957"}
0005435502748	087929	2571 621760	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin_091970@postgrespro.ru", "phone": "+70918030855"}
0005435502749	049E8F	8482 072140	IRINA IVANOVA	{"email": "ivanova_irina_05121977@postgrespro.ru", "phone": "+70186559991"}
0005435502750	3AAE29	6789 755916	MAKSIM PETROV	{"phone": "+70492637166"}
0005435502751	9E81E8	7567 744623	DANILA CHERNOV	{"email": "d.chernov31121965@postgrespro.ru", "phone": "+70246033484"}
0005435502752	13069D	2208 397813	ALEKSEY GORBUNOV	{"email": "gorbunov_aleksey.19061973@postgrespro.ru", "phone": "+70503955681"}
0005435502753	9050CE	3296 349697	TATYANA KULIKOVA	{"phone": "+70446934859"}
0005435502754	93952B	2637 987539	ANTONINA VASILEVA	{"phone": "+70767302788"}
0005435502755	D2600E	1331 536664	LIDIYA KUZNECOVA	{"phone": "+70589621709"}
0005435502756	D2600E	9904 244375	ALEKSANDR SIDOROV	{"phone": "+70020666649"}
0005435502757	6EA291	1251 047324	VADIM AFANASEV	{"email": "afanasev.vadim-07111962@postgrespro.ru", "phone": "+70688045546"}
0005435502758	6EA291	4689 689961	EVGENIY NAZAROV	{"email": "nazarove_14121970@postgrespro.ru", "phone": "+70620599460"}
0005435502759	46540E	7226 373416	YULIYA POPOVA	{"email": "popova.yuliya1972@postgrespro.ru", "phone": "+70240699338"}
0005435502760	FA65B8	2457 669369	ANATOLIY NOVIKOV	{"email": "novikov.a.1973@postgrespro.ru", "phone": "+70618753291"}
0005435502761	634B97	3447 597548	TATYANA IVANOVA	{"email": "tatyanaivanova-1974@postgrespro.ru", "phone": "+70487081390"}
0005435502762	22FB4B	5991 673874	ALEKSANDR VOLKOV	{"email": "volkov.aleksandr_071968@postgrespro.ru", "phone": "+70425127169"}
0005435502763	22FB4B	2253 277843	BORIS SIDOROV	{"phone": "+70935788461"}
0005435502764	49D613	1046 694681	VLADISLAV KOZLOV	{"phone": "+70825074266"}
0005435502765	49D613	3411 754997	IVAN EGOROV	{"phone": "+70096155656"}
0005435502766	AE1AFC	1205 354430	EVGENIY ALEKSEEV	{"phone": "+70124745656"}
0005435502767	AE1AFC	8852 074698	KSENIYA KONOVALOVA	{"email": "kseniya-konovalova_09061978@postgrespro.ru", "phone": "+70970021265"}
0005435502768	135FB9	4945 638361	ALEKSANDR MOISEEV	{"phone": "+70025371072"}
0005435502769	3450B9	6335 704829	LIDIYA FILIPPOVA	{"email": "lidiyafilippova-051967@postgrespro.ru", "phone": "+70324883567"}
0005435502770	3450B9	7256 424535	NATALYA ANDREEVA	{"email": "andreevanatalya.091977@postgrespro.ru", "phone": "+70377138306"}
0005435502771	B40F6C	6884 199619	ALEKSANDRA BARANOVA	{"email": "a.baranova13101968@postgrespro.ru", "phone": "+70565949854"}
0005435502772	8C0777	5972 813803	OLGA MAKAROVA	{"phone": "+70082165621"}
0005435502773	0AE2A0	3123 627673	ALEKSEY ANTONOV	{"phone": "+70518625818"}
0005435502774	E08C49	2286 915294	NIKITA DMITRIEV	{"email": "dmitriev_n.1969@postgrespro.ru", "phone": "+70023476718"}
0005435502775	5A3BA5	6948 942915	DMITRIY FEDOROV	{"email": "fedorov.dmitriy_011974@postgrespro.ru", "phone": "+70389620867"}
0005435502776	667738	4861 901809	ANASTASIYA KUDRYASHOVA	{"phone": "+70674226170"}
0005435502777	2312D4	8191 286433	IRINA TITOVA	{"email": "irina_titova1959@postgrespro.ru", "phone": "+70546845056"}
0005435502778	9F2BF4	6077 436371	EKATERINA STEPANOVA	{"phone": "+70151622794"}
0005435502779	C89FFC	3096 339709	VITALIY NAUMOV	{"email": "naumov.vitaliy-1965@postgrespro.ru", "phone": "+70327461104"}
0005435502780	A8E672	9581 522725	NIKOLAY VOLKOV	{"email": "volkov.nikolay1966@postgrespro.ru", "phone": "+70456174340"}
0005435502781	6B69FB	9608 546128	NATALYA LEBEDEVA	{"email": "lebedeva.natalya_091968@postgrespro.ru", "phone": "+70231320153"}
0005435502782	CD8AF6	1346 265634	VALERIY SIDOROV	{"email": "sidorov.valeriy-1966@postgrespro.ru", "phone": "+70308194425"}
0005435502783	14F925	0153 114723	TAMARA NAUMOVA	{"email": "naumovatamara1972@postgrespro.ru", "phone": "+70756523564"}
0005435502784	A55BC1	3613 220577	ELIZAVETA ZAKHAROVA	{"phone": "+70091921380"}
0005435502785	34F765	9480 435428	SERGEY BORISOV	{"email": "s.borisov.1977@postgrespro.ru", "phone": "+70291457402"}
0005435502786	FA87DA	8611 945655	VITALIY SMIRNOV	{"email": "v_smirnov_05011973@postgrespro.ru", "phone": "+70583215575"}
0005435502787	E168FB	0587 577751	YURIY NIKITIN	{"phone": "+70550834722"}
0005435502788	E168FB	4068 313678	GALINA PETROVA	{"email": "petrova.g-28111973@postgrespro.ru", "phone": "+70576760885"}
0005435502789	B1B04E	6639 790128	DANA NESTEROVA	{"email": "nesterova-d.11061966@postgrespro.ru", "phone": "+70186567301"}
0005435502790	1176CB	8750 612266	TATYANA MELNIKOVA	{"email": "t_melnikova-011969@postgrespro.ru", "phone": "+70703471299"}
0005435502791	BD27F4	7690 102307	EKATERINA POTAPOVA	{"email": "potapova-e_1971@postgrespro.ru", "phone": "+70436795457"}
0005435502792	F85222	0970 805769	VALENTINA SMIRNOVA	{"email": "v.smirnova_16051967@postgrespro.ru", "phone": "+70934401714"}
0005435502793	BE0120	5448 186952	VALENTINA VASILEVA	{"phone": "+70412007387"}
0005435502794	1CED96	7738 508878	EVGENIY SOLOVEV	{"email": "evgeniy.solovev.041975@postgrespro.ru", "phone": "+70759079285"}
0005435502795	65BF45	4271 239505	ANASTASIYA STEPANOVA	{"email": "astepanova_1965@postgrespro.ru", "phone": "+70377242177"}
0005435502796	C53F5F	5302 944732	NINA NOVIKOVA	{"phone": "+70172088571"}
0005435502797	51FDB8	5850 455913	RAMILYA GORBUNOVA	{"email": "r.gorbunova_111976@postgrespro.ru", "phone": "+70442365565"}
0005435502798	AAAC2D	3196 784842	SERGEY VOROBEV	{"email": "sergey.vorobev08051971@postgrespro.ru", "phone": "+70653511748"}
0005435502799	3CB950	3193 787015	LEONID KARPOV	{"phone": "+70957462733"}
0005435502800	3CB950	8567 148323	VIKTOR ALEKSEEV	{"phone": "+70368490285"}
0005435502801	7062A5	0636 439021	VASILIY KUDRYASHOV	{"email": "kudryashovv1975@postgrespro.ru", "phone": "+70381121530"}
0005435502802	9019D6	2346 251170	ALEKSANDR KUZNECOV	{"email": "a-kuznecov13011973@postgrespro.ru", "phone": "+70545769413"}
0005435502803	28638C	0606 777087	SERGEY FEDOROV	{"email": "fedorov_s.1971@postgrespro.ru", "phone": "+70819351476"}
0005435502804	28638C	3733 220201	ALEKSANDR BONDARENKO	{"email": "bondarenko_aleksandr27101964@postgrespro.ru", "phone": "+70142059491"}
0005435502805	AC138D	3193 907865	LYUDMILA DENISOVA	{"phone": "+70426342251"}
0005435502806	B5A676	0181 236290	VLADIMIR MOISEEV	{"email": "moiseev_vladimir13011972@postgrespro.ru", "phone": "+70113613590"}
0005435502807	3CFCD5	5733 455932	MARIYA ZAKHAROVA	{"email": "zakharova_mariya24031975@postgrespro.ru", "phone": "+70965408445"}
0005435502808	B760EA	2665 250036	OLGA KALININA	{"phone": "+70748621257"}
0005435502809	B760EA	5108 244724	MIKHAIL KUZNECOV	{"phone": "+70789777800"}
0005435502810	B760EA	7107 140437	SEMEN POPOV	{"phone": "+70226503685"}
0005435502811	CBF77E	3133 002591	IVAN DENISOV	{"email": "i-denisov15011976@postgrespro.ru", "phone": "+70025031214"}
0005435502812	129121	7680 198281	MARINA MIKHAYLOVA	{"phone": "+70359619797"}
0005435502813	BDC0CA	3641 170910	ALEKSEY KUZNECOV	{"email": "kuznecov-a-121971@postgrespro.ru", "phone": "+70734815316"}
0005435502814	80515C	7057 921612	NIKOLAY MIRONOV	{"email": "n-mironov091963@postgrespro.ru", "phone": "+70279131235"}
0005435502815	822697	5522 075323	MIKHAIL KARPOV	{"email": "karpov_m.26081970@postgrespro.ru", "phone": "+70711883027"}
0005435502816	92B50B	4903 222472	TATYANA ZAYCEVA	{"email": "tatyana_zayceva-10011967@postgrespro.ru", "phone": "+70512741045"}
0005435502817	B6F4C1	7641 568834	ILNUR ROMANOV	{"email": "i.romanov-15031973@postgrespro.ru", "phone": "+70017318019"}
0005435502818	5FDB47	3510 194102	EKATERINA EFIMOVA	{"email": "efimova.ekaterina_1961@postgrespro.ru", "phone": "+70700141461"}
0005435502819	E6E046	4414 646192	IRINA KUZMINA	{"email": "i_kuzmina.03051966@postgrespro.ru", "phone": "+70886704756"}
0005435502820	E6E046	8606 245945	ILYA VASILEV	{"phone": "+70898951526"}
0005435502821	E6E046	4172 256356	ALEKSANDR ALEKSEEV	{"email": "alekseev_aleksandr-061971@postgrespro.ru", "phone": "+70586234169"}
0005435502822	090E0D	3679 528303	GALINA TARASOVA	{"email": "tarasova_g051987@postgrespro.ru", "phone": "+70285144171"}
0005435502823	9B598B	4634 147882	ANASTASIYA MOISEEVA	{"phone": "+70088294357"}
0005435502824	9B598B	3694 941054	VYACHESLAV NIKOLAEV	{"phone": "+70436826957"}
0005435502825	C071A6	0125 084649	SERGEY VLASOV	{"phone": "+70463601751"}
0005435502826	C071A6	7143 511996	DENIS NIKOLAEV	{"email": "nikolaev.d_09041968@postgrespro.ru", "phone": "+70051470347"}
0005435502827	2A4ECE	1235 663359	TATYANA MATVEEVA	{"email": "tatyana.matveeva_1962@postgrespro.ru", "phone": "+70527429388"}
0005435502828	2A4ECE	7691 374754	MARINA ALEKSANDROVA	{"email": "marina-aleksandrova.071972@postgrespro.ru", "phone": "+70500524072"}
0005435502829	D1CD1E	2638 350618	ANNA SOKOLOVA	{"phone": "+70146423907"}
0005435502830	025AC1	8971 614809	GALINA GUSEVA	{"email": "g_guseva-01091977@postgrespro.ru", "phone": "+70568932194"}
0005435502831	5F4BCA	9369 285537	ALEKSANDR ANTONOV	{"email": "a-antonov-19011965@postgrespro.ru", "phone": "+70683231141"}
0005435502832	F9B1FC	6644 822123	NIKOLAY SEMENOV	{"phone": "+70922464067"}
0005435502833	925A26	1173 757380	DAMIR POPOV	{"phone": "+70145324290"}
0005435502834	3C6B11	2773 062713	YURIY ANDREEV	{"email": "yuriy.andreev_06111976@postgrespro.ru", "phone": "+70240517097"}
0005435502835	E0B3E0	1373 879088	MARINA LOGINOVA	{"phone": "+70316548032"}
0005435502836	6BDE95	2239 461986	ZINAIDA VOLKOVA	{"phone": "+70686990995"}
0005435502837	62BD2D	2919 498079	ALEKSANDR IVANOV	{"email": "ivanov-a_03111991@postgrespro.ru", "phone": "+70298726751"}
0005435502838	62BD2D	9035 949538	ANTONINA MOROZOVA	{"phone": "+70164474932"}
0005435502839	62BD2D	3544 070248	VLADIMIR ZHURAVLEV	{"email": "vladimir.zhuravlev08031969@postgrespro.ru", "phone": "+70309973801"}
0005435502840	CC1E3B	9869 145420	GEORGIY SEMENOV	{"phone": "+70402195481"}
0005435502841	E8DEFD	4258 635837	LYUDMILA SERGEEVA	{"email": "lyudmila-sergeeva111963@postgrespro.ru", "phone": "+70511607264"}
0005435502842	CDD35E	8888 849789	VLADIMIR FROLOV	{"phone": "+70135647683"}
0005435502843	B5CBD5	4496 584656	NIKOLAY OSIPOV	{"phone": "+70240801413"}
0005435502844	B5CBD5	7213 800831	EVGENIY ANDREEV	{"email": "evgeniy-andreev.081970@postgrespro.ru", "phone": "+70269502741"}
0005435502845	1F0199	2877 513716	KLAVDIYA KALININA	{"email": "klavdiya-kalinina.071967@postgrespro.ru", "phone": "+70657882280"}
0005435502846	880536	7167 893539	TATYANA ANDREEVA	{"phone": "+70172372774"}
0005435502847	EB3D21	2627 191477	OLGA EGOROVA	{"phone": "+70503619699"}
0005435502848	527874	3354 082488	TATYANA CHERNOVA	{"phone": "+70919058725"}
0005435502849	8DCE52	5000 833831	OLEG VLASOV	{"email": "oleg_vlasov021970@postgrespro.ru", "phone": "+70578326818"}
0005435502850	D29EDD	0612 778532	DARYA FADEEVA	{"email": "dfadeeva1971@postgrespro.ru", "phone": "+70593102489"}
0005435502851	EBC15E	2009 715624	IRINA KISELEVA	{"email": "kiseleva_irina-031964@postgrespro.ru", "phone": "+70212361799"}
0005435502852	CF7E32	0588 500184	VIKTOR GUSEV	{"email": "gusev_v_101974@postgrespro.ru", "phone": "+70065804932"}
0005435502853	7890B1	5479 615230	ELENA EGOROVA	{"phone": "+70541052732"}
0005435502854	7890B1	2078 170230	IGOR ZAYCEV	{"phone": "+70417521709"}
0005435502855	4FCAF8	4614 922595	EVGENIY ANDREEV	{"phone": "+70422982931"}
0005435502856	1E75E1	5748 798663	TAMARA KUZNECOVA	{"email": "kuznecova.tamara1974@postgrespro.ru", "phone": "+70468344808"}
0005435502857	1E75E1	6383 269014	RIMMA BELYAEVA	{"email": "rbelyaeva_1970@postgrespro.ru", "phone": "+70529149666"}
0005435502858	F409CB	3492 784799	INNA YAKOVLEVA	{"email": "yakovleva.inna.1970@postgrespro.ru", "phone": "+70205526899"}
0005435502859	97AB16	8797 384260	YURIY IVANOV	{"phone": "+70749952225"}
0005435502860	30ADD3	3233 080784	YURIY ORLOV	{"phone": "+70832038602"}
0005435502861	30ADD3	7310 251492	ROMAN ALEKSANDROV	{"phone": "+70192580055"}
0005435502862	B723B6	8908 114268	NADEZHDA PETROVA	{"phone": "+70231824911"}
0005435502863	F6C494	0204 306040	PETR PAVLOV	{"phone": "+70989802921"}
0005435502864	BC998A	5895 158343	ALENA ABRAMOVA	{"email": "alena-abramova1972@postgrespro.ru", "phone": "+70423419250"}
0005435502865	BC998A	9103 014029	SERGEY ROMANOV	{"email": "s-romanov.1967@postgrespro.ru", "phone": "+70129641988"}
0005435502866	0C973D	5475 368083	EKATERINA MOISEEVA	{"phone": "+70779344033"}
0005435502867	9F5152	8909 591354	IVAN ALEKSANDROV	{"email": "ivan.aleksandrov1971@postgrespro.ru", "phone": "+70019699613"}
0005435502868	67C969	6353 660262	ZULFIYA PAVLOVA	{"phone": "+70722375669"}
0005435502869	4BCEB6	8974 166582	LEONID PETROV	{"phone": "+70191715889"}
0005435502870	4BCEB6	4803 950222	ALEKSANDR DAVYDOV	{"phone": "+70882190184"}
0005435502871	A27F11	5550 249542	VALENTINA MAKAROVA	{"phone": "+70463823711"}
0005435502872	D14BAF	4370 494675	STANISLAV ABRAMOV	{"email": "stanislavabramov.10111950@postgrespro.ru", "phone": "+70592909742"}
0005435502873	0E04BC	4232 614674	LYUDMILA SCHERBAKOVA	{"phone": "+70384642265"}
0005435502874	0E04BC	5042 694369	SERGEY ILIN	{"phone": "+70971812519"}
0005435502875	C1BF89	7697 744589	NIKITA KOZLOV	{"email": "n-kozlov_021968@postgrespro.ru", "phone": "+70027062545"}
0005435502876	691ACE	0181 681416	DANIIL KUZNECOV	{"email": "kuznecov-d011963@postgrespro.ru", "phone": "+70084232086"}
0005435502877	691ACE	5337 202874	IGOR ZAKHAROV	{"email": "zakharovigor-09051967@postgrespro.ru", "phone": "+70433439401"}
0005435502878	62734F	2950 164806	ANTONINA VASILEVA	{"email": "vasileva-antonina.041973@postgrespro.ru", "phone": "+70143034304"}
0005435502879	CA04DB	4859 344714	NIKOLAY SHEVCHENKO	{"phone": "+70810808509"}
0005435502880	F6D413	8534 320906	EKATERINA FADEEVA	{"email": "fadeeva_ekaterina-121970@postgrespro.ru", "phone": "+70118404526"}
0005435502881	B7B7D7	5030 490087	TATYANA NIKITINA	{"phone": "+70509909566"}
0005435502882	B7B7D7	6477 233516	VADIM STEPANOV	{"phone": "+70007056401"}
0005435502883	C364FE	1353 463053	MARIYA STEPANOVA	{"email": "mstepanova_02011967@postgrespro.ru", "phone": "+70103133396"}
0005435502884	C364FE	2093 146660	VADIM POPOV	{"phone": "+70427744426"}
0005435502885	C364FE	8254 398116	NATALYA SOLOVEVA	{"email": "natalya-soloveva.1979@postgrespro.ru", "phone": "+70738656057"}
0005435502886	6F869A	2526 947977	GALINA EGOROVA	{"email": "egorova-g.071981@postgrespro.ru", "phone": "+70175393173"}
0005435502887	079C22	0611 117640	LYUBOV STEPANOVA	{"phone": "+70141695309"}
0005435502888	3CAE4B	8265 242879	ALEKSANDR EGOROV	{"email": "a-egorov.1980@postgrespro.ru", "phone": "+70191084532"}
0005435502889	87C5F7	7860 965552	GALINA PAVLOVA	{"phone": "+70687380149"}
0005435502890	9C02EC	7815 340690	ANNA ZHURAVLEVA	{"phone": "+70551047442"}
0005435502891	9C02EC	9543 563050	SERGEY MOISEEV	{"email": "moiseev-sergey_09041967@postgrespro.ru", "phone": "+70191271040"}
0005435502892	67FB97	8570 774938	MARIYA SAVELEVA	{"email": "m.saveleva-11031971@postgrespro.ru", "phone": "+70548576657"}
0005435502893	67FB97	0465 528892	FEDOR POPOV	{"email": "popovf.111974@postgrespro.ru", "phone": "+70572785688"}
0005435502894	67FB97	9745 000794	VIKTOR BONDARENKO	{"email": "viktorbondarenko_051979@postgrespro.ru", "phone": "+70140586369"}
0005435502895	37B301	8065 961894	DAMIR ZAYCEV	{"phone": "+70916169544"}
0005435502896	37B301	6608 629230	VASILIY MEDVEDEV	{"email": "vmedvedev05091974@postgrespro.ru", "phone": "+70833570176"}
0005435502897	5292F3	7429 656997	PETR MAKSIMOV	{"email": "maksimov_petr-1977@postgrespro.ru", "phone": "+70666721407"}
0005435502898	5292F3	3535 508084	IVAN IVANOV	{"phone": "+70842428427"}
0005435502899	AA5A49	1823 155240	PETR SOLOVEV	{"email": "petr-solovev-23051966@postgrespro.ru", "phone": "+70419216256"}
0005435502900	8F5C4A	2942 277157	NATALYA CHERNOVA	{"phone": "+70572718595"}
0005435502901	FA422A	9182 442397	NIKOLAY FROLOV	{"email": "n-frolov.31101969@postgrespro.ru", "phone": "+70798702132"}
0005435502902	9FA010	1896 209009	NELLI MAKAROVA	{"phone": "+70933029162"}
0005435502903	9FA010	8841 150275	VADIM IVANOV	{"email": "vadimivanov_1975@postgrespro.ru", "phone": "+70709949032"}
0005435502904	C5029E	3254 323346	MIKHAIL FILIPPOV	{"email": "filippov.m-051971@postgrespro.ru", "phone": "+70846600068"}
0005435502905	B46AF0	2579 994804	NADEZHDA STEPANOVA	{"phone": "+70134320849"}
0005435502906	B46AF0	1321 585361	NADEZHDA NIKITINA	{"email": "n_nikitina.1974@postgrespro.ru", "phone": "+70240998043"}
0005435502907	35A22F	0581 935163	ROMAN FEDOROV	{"phone": "+70272907947"}
0005435502908	CD2142	3283 262612	SVETLANA MAKAROVA	{"phone": "+70588998559"}
0005435502909	D55BAA	9725 788159	VALERIY FOMIN	{"email": "fomin.valeriy.101965@postgrespro.ru", "phone": "+70646370071"}
0005435502910	D55BAA	7061 198893	EVGENIYA YAKOVLEVA	{"email": "yakovleva_evgeniya_111959@postgrespro.ru", "phone": "+70776785843"}
0005435502911	D55BAA	4542 211777	MARIYA CHERNOVA	{"email": "chernova_m_1987@postgrespro.ru", "phone": "+70703145392"}
0005435502912	6CDF78	6317 849904	ANASTASIYA PAVLOVA	{"phone": "+70570052028"}
0005435502913	08EF78	1981 334060	OLESYA TIKHONOVA	{"phone": "+70987371088"}
0005435502914	70BAA4	5914 467141	VITALIY GAVRILOV	{"phone": "+70267458921"}
0005435502915	51FD14	6007 754642	MARINA SOROKINA	{"email": "sorokina_m-1982@postgrespro.ru", "phone": "+70129105124"}
0005435502916	BC0EE2	1416 262007	GALINA ANISIMOVA	{"email": "ganisimova.061982@postgrespro.ru", "phone": "+70614084882"}
0005435502917	BC0EE2	3460 372752	ALEKSANDRA KRASNOVA	{"phone": "+70773953395"}
0005435502918	BBCE31	2041 557409	EGOR SERGEEV	{"email": "sergeev.egor1971@postgrespro.ru", "phone": "+70454000708"}
0005435502919	2B87B4	9042 612975	NATALYA FEDOROVA	{"email": "natalya.fedorova.1978@postgrespro.ru", "phone": "+70179809770"}
0005435502920	6C20DE	5501 970916	SVETLANA NAUMOVA	{"email": "naumovas_031983@postgrespro.ru", "phone": "+70761575989"}
0005435502921	9FD584	4304 999054	MARIYA ILINA	{"phone": "+70097546138"}
0005435502922	E6ACA9	7770 589854	LIDIYA SMIRNOVA	{"phone": "+70393299529"}
0005435502923	BBDBE7	8792 743378	ELENA LOGINOVA	{"phone": "+70913208750"}
0005435502924	BBDBE7	3003 524593	TATYANA GERASIMOVA	{"email": "tatyana.gerasimova.19121981@postgrespro.ru", "phone": "+70154040764"}
0005435502925	ADE421	5284 517407	DENIS MOISEEV	{"phone": "+70184525566"}
0005435502926	ADE421	3783 907798	MIKHAIL ISAEV	{"phone": "+70509723557"}
0005435502927	5F2201	4406 834251	TATYANA SOROKINA	{"phone": "+70935788838"}
0005435502928	91B3D5	7742 629788	ANNA AFANASEVA	{"phone": "+70107070191"}
0005435502929	E5B61E	6193 203126	SERGEY STEPANOV	{"email": "stepanovs1961@postgrespro.ru", "phone": "+70823191708"}
0005435502930	6FC651	7480 417677	LIDIYA ROMANOVA	{"email": "romanova.l-1972@postgrespro.ru", "phone": "+70360057469"}
0005435502931	6FC651	1104 613881	MARGARITA KOZLOVA	{"phone": "+70999320924"}
0005435502932	A5304B	9474 322162	GALINA AKIMOVA	{"email": "galina.akimova-27111978@postgrespro.ru", "phone": "+70885103923"}
0005435502933	C1FC92	2740 122866	ANDREY MAKSIMOV	{"phone": "+70770451394"}
0005435502934	C1FC92	1183 652923	ALEKSANDR VOROBEV	{"email": "aleksandr-vorobev101975@postgrespro.ru", "phone": "+70140050564"}
0005435502935	BE22B1	6392 319773	IVAN MAKAROV	{"email": "makarov_ivan061971@postgrespro.ru", "phone": "+70277190543"}
0005435502936	063903	5431 478955	ANVAR PETROV	{"phone": "+70521324554"}
0005435502937	26FDDD	4587 804599	MAKSIM SOLOVEV	{"phone": "+70940350801"}
0005435502938	2A805F	0854 658413	VLADISLAV GERASIMOV	{"phone": "+70102294218"}
0005435502939	2A805F	5814 644702	ANTONINA ILINA	{"email": "ilina_a-1968@postgrespro.ru", "phone": "+70107440392"}
0005435502940	654F08	3623 337925	TATYANA KUDRYASHOVA	{"phone": "+70251000994"}
0005435502941	654F08	9958 223902	ANZHELA SCHERBAKOVA	{"phone": "+70641391384"}
0005435502942	332D44	0339 540079	EKATERINA ZHURAVLEVA	{"email": "zhuravlevae_071980@postgrespro.ru", "phone": "+70488335141"}
0005435502943	60D3C8	3078 959412	ANGELINA ISAEVA	{"email": "isaevaa1976@postgrespro.ru", "phone": "+70769011338"}
0005435502944	ED534F	1160 473762	LIDIYA MEDVEDEVA	{"phone": "+70437992725"}
0005435502945	64CA28	7292 163275	LIDIYA KOZLOVA	{"email": "lidiya.kozlova-23071969@postgrespro.ru", "phone": "+70150261252"}
0005435502946	BA5333	9601 998082	NIKITA SIDOROV	{"email": "n_sidorov_1985@postgrespro.ru", "phone": "+70194829371"}
0005435502947	65D175	0700 834127	NIKOLAY KARPOV	{"email": "karpov.nikolay_05071980@postgrespro.ru", "phone": "+70907735220"}
0005435502948	65D175	3602 010124	DMITRIY PETROV	{"phone": "+70048147066"}
0005435502949	890ED5	6107 393479	ALEKSEY KUZNECOV	{"phone": "+70324775678"}
0005435502950	FC8945	0952 152741	NATALIYA ZAKHAROVA	{"email": "n_zakharova.1975@postgrespro.ru", "phone": "+70938767619"}
0005435502951	FC8945	2611 174899	SERGEY IVANOV	{"email": "sivanov_1976@postgrespro.ru", "phone": "+70180058652"}
0005435502952	B45187	2312 297692	NATALYA KOROLEVA	{"phone": "+70207577319"}
0005435502953	B45187	9701 698444	IGOR BONDARENKO	{"email": "bondarenkoi1975@postgrespro.ru", "phone": "+70720677160"}
0005435502954	8FE7DB	3856 115296	ANTON FOMIN	{"phone": "+70355183840"}
0005435502955	8FE7DB	9438 779371	VLADIMIR FEDOROV	{"phone": "+70664727221"}
0005435502956	7E5C4E	6253 380814	SERGEY KUZMIN	{"email": "s-kuzmin_1973@postgrespro.ru", "phone": "+70440192708"}
0005435502957	8C40B4	4556 037278	ANASTASIYA BORISOVA	{"email": "anastasiyaborisova.031973@postgrespro.ru", "phone": "+70410137564"}
0005435502958	3A414A	9103 578848	ELENA MAKAROVA	{"phone": "+70953765335"}
0005435502959	DB3D99	6818 347803	RUSTAM BORISOV	{"email": "borisovr1964@postgrespro.ru", "phone": "+70957224438"}
0005435502960	DB3D99	9298 036158	VYACHESLAV POPOV	{"email": "popov_v_13011970@postgrespro.ru", "phone": "+70775008751"}
0005435502961	F260AA	4041 942251	ARTEM SMIRNOV	{"email": "smirnov.a.1985@postgrespro.ru", "phone": "+70262001171"}
0005435502962	F260AA	3336 763593	ALEKSANDR ZAKHAROV	{"email": "a-zakharov-26111976@postgrespro.ru", "phone": "+70836805581"}
0005435502963	A199A7	5911 031865	SERGEY DMITRIEV	{"email": "dmitriev_s1981@postgrespro.ru", "phone": "+70621330763"}
0005435502964	217E37	1007 871769	IRINA FOMINA	{"email": "fominairina-021979@postgrespro.ru", "phone": "+70159887715"}
0005435502965	E9B668	6063 934199	SERGEY ROMANOV	{"phone": "+70854624194"}
0005435502966	E9B668	4078 100979	NINA PETROVA	{"email": "n_petrova-061971@postgrespro.ru", "phone": "+70622909127"}
0005435502967	8E6613	0779 440922	ULYANA LUKYANOVA	{"email": "lukyanova.ulyana_1979@postgrespro.ru", "phone": "+70836593426"}
0005435502968	8E6613	1762 847825	LYUDMILA OSIPOVA	{"phone": "+70316071677"}
0005435508164	D7CEB5	9553 032690	ELENA FADEEVA	{"phone": "+70017438055"}
0005435508165	17ADBB	8251 584765	ALEKSEY MELNIKOV	{"email": "aleksey.melnikov-16051978@postgrespro.ru", "phone": "+70898295762"}
0005435508166	FA87AD	0295 759176	ALEKSANDR PAVLOV	{"email": "aleksandrpavlov.091973@postgrespro.ru", "phone": "+70587401208"}
0005435508167	C0E85E	9065 436130	OLGA EFIMOVA	{"phone": "+70617694605"}
0005435508168	E3E5EC	8062 938066	LYUDMILA NAZAROVA	{"email": "nazarova-l-27031976@postgrespro.ru", "phone": "+70159557052"}
0005435508169	E3E5EC	1725 018744	IRINA EGOROVA	{"email": "egorova.irina051977@postgrespro.ru", "phone": "+70878625539"}
0005435508170	EEDAAF	2763 553748	OLGA GAVRILOVA	{"email": "gavrilova.o_19051963@postgrespro.ru", "phone": "+70740152185"}
0005435508171	EEDAAF	7199 433958	ANATOLIY MOROZOV	{"email": "morozovanatoliy_04031979@postgrespro.ru", "phone": "+70705570661"}
0005435508172	F2DB27	9342 626784	ARSENIY TARASOV	{"phone": "+70673177861"}
0005435508173	194E01	6983 408613	ELENA VASILEVA	{"phone": "+70574665311"}
0005435508174	194E01	4799 177422	VALERIYA DENISOVA	{"email": "denisovav091975@postgrespro.ru", "phone": "+70214691906"}
0005435508175	7ED1D5	3390 180330	OLGA ZHURAVLEVA	{"email": "zhuravleva-o1975@postgrespro.ru", "phone": "+70789317001"}
0005435508176	7ED1D5	8534 298738	PAVEL KUZNECOV	{"phone": "+70785659015"}
0005435508177	21EFB8	9608 676600	ALISA ERMAKOVA	{"phone": "+70338314297"}
0005435508178	22DC35	8200 529444	ALEKSANDR KONOVALOV	{"email": "a-konovalov_1967@postgrespro.ru", "phone": "+70101914665"}
0005435508179	E01BA1	8012 081388	SVETLANA DMITRIEVA	{"phone": "+70247316521"}
0005435508180	C5C674	7788 849568	LYUBOV PAVLOVA	{"email": "lyubov-pavlova1976@postgrespro.ru", "phone": "+70591587373"}
0005435508181	0B057F	6315 951330	LARISA POPOVA	{"email": "popova.larisa27031981@postgrespro.ru", "phone": "+70484268733"}
0005435508182	0B057F	9884 014395	ALEKSEY SHEVCHENKO	{"email": "shevchenko.a_011968@postgrespro.ru", "phone": "+70754862946"}
0005435508183	46FC78	4004 004828	OLGA IVANOVA	{"phone": "+70373141592"}
0005435508184	46FC78	9699 843278	OLGA GORBUNOVA	{"email": "gorbunova_olga-11031970@postgrespro.ru", "phone": "+70246868542"}
0005435508185	2D6329	4270 881260	NATALYA NIKITINA	{"phone": "+70434651664"}
0005435508186	CE4A82	6273 889449	VLADIMIR KONOVALOV	{"phone": "+70878783441"}
0005435508187	20A449	5780 675608	TAISA IVANOVA	{"phone": "+70791297179"}
0005435508188	20A449	2451 089992	DMITRIY KOZLOV	{"email": "dmitriy-kozlov-1977@postgrespro.ru", "phone": "+70660420113"}
0005435508189	8EF810	0415 284572	EVDOKIYA PETROVA	{"email": "evdokiyapetrova28061969@postgrespro.ru", "phone": "+70881156680"}
0005435508190	8EF810	2282 360356	LYUDMILA KUDRYASHOVA	{"email": "lyudmilakudryashova-071965@postgrespro.ru", "phone": "+70437931443"}
0005435508191	6482A8	3491 292297	YULIYA ARKHIPOVA	{"email": "arkhipova.yuliya1962@postgrespro.ru", "phone": "+70154319318"}
0005435508192	F58955	2929 893742	ARTEM SOROKIN	{"email": "sorokin_artem_011969@postgrespro.ru", "phone": "+70666778275"}
0005435508193	9B8529	4048 217546	ANDREY IVANOV	{"email": "aivanov27011983@postgrespro.ru", "phone": "+70867474157"}
0005435508194	9B8529	7367 717754	TAMARA ZAKHAROVA	{"phone": "+70675748121"}
0005435508195	EBBDE5	4376 849114	TATYANA ZAKHAROVA	{"phone": "+70877764589"}
0005435508196	EBBDE5	0290 338773	VITALIY ZHUKOV	{"phone": "+70508231167"}
0005435508197	636709	9773 230546	VLADIMIR OSIPOV	{"email": "vladimir_osipov-101968@postgrespro.ru", "phone": "+70494713237"}
0005435508198	636709	4480 836249	NATALYA LAZAREVA	{"phone": "+70979517388"}
0005435508199	562DF7	8044 123827	ANDREY KUZMIN	{"email": "andreykuzmin031968@postgrespro.ru", "phone": "+70473807356"}
0005435508200	562DF7	1732 309489	LIDIYA EGOROVA	{"phone": "+70986451594"}
0005435508201	7178B3	4644 539699	NATALYA POLYAKOVA	{"email": "polyakova_natalya1972@postgrespro.ru", "phone": "+70543769877"}
0005435508202	D66497	7050 320506	LIDIYA BELOVA	{"email": "l_belova-28061970@postgrespro.ru", "phone": "+70019588880"}
0005435508203	FACC56	5807 288605	NATALYA ZHURAVLEVA	{"phone": "+70338268055"}
0005435508204	E9D35C	5777 027509	IGOR ABRAMOV	{"email": "abramovi-22051957@postgrespro.ru", "phone": "+70493502811"}
0005435508205	B9A394	7303 189245	IREK POPOV	{"email": "ipopov-27031981@postgrespro.ru", "phone": "+70951968216"}
0005435508206	F22096	9079 979840	SOFIYA SIDOROVA	{"email": "s-sidorova.1975@postgrespro.ru", "phone": "+70405574733"}
0005435508207	F22096	4425 712140	NATALYA RODIONOVA	{"email": "rodionova.n.20081965@postgrespro.ru", "phone": "+70987717948"}
0005435508208	6F19FA	1225 270660	MARIYA LUKYANOVA	{"email": "mariya_lukyanova11041980@postgrespro.ru", "phone": "+70684932768"}
0005435508209	6F19FA	8225 258252	ILYA ZHUKOV	{"email": "zhukov_i-031973@postgrespro.ru", "phone": "+70296386041"}
0005435508210	3BE970	9876 597760	MARIYA MIRONOVA	{"phone": "+70472910196"}
0005435508211	E824DB	4283 385899	NINA GERASIMOVA	{"email": "ninagerasimova1986@postgrespro.ru", "phone": "+70864142643"}
0005435508212	2588A5	2438 854999	VASILIY FILIPPOV	{"phone": "+70527507700"}
0005435508213	6E365A	1647 358694	ALEKSEY KUZNECOV	{"phone": "+70204760410"}
0005435508214	6E365A	2881 213484	ELENA SOKOLOVA	{"phone": "+70964317508"}
0005435508215	9EF051	1007 825028	NATALIYA SAVELEVA	{"email": "nataliya-saveleva08091984@postgrespro.ru", "phone": "+70586826552"}
0005435508216	DD5FA8	8907 059207	ALEKSANDR SMIRNOV	{"phone": "+70704251768"}
0005435508217	8F2814	3136 789433	VLADIMIR VOROBEV	{"phone": "+70540135270"}
0005435508218	8F2814	7588 261873	VLADIMIR SAVELEV	{"phone": "+70392213245"}
0005435508219	45E6C1	4435 200462	SERGEY MARTYNOV	{"email": "s-martynov091974@postgrespro.ru", "phone": "+70305180750"}
0005435508220	FC42FB	2145 523800	ALENA ZAKHAROVA	{"email": "alena.zakharova.11051982@postgrespro.ru", "phone": "+70668154908"}
0005435508221	53F354	5481 699266	VALENTINA KALININA	{"phone": "+70250745475"}
0005435508222	E987F2	0268 945252	ALEKSEY IVANOV	{"email": "aleksey.ivanov.051974@postgrespro.ru", "phone": "+70455646919"}
0005435508223	E987F2	8816 471381	ELENA STEPANOVA	{"email": "elena_stepanova031974@postgrespro.ru", "phone": "+70230397887"}
0005435508224	2D5190	5221 592954	OLGA CHERNOVA	{"phone": "+70878865291"}
0005435508225	23F213	1501 002847	VASILIY VOROBEV	{"email": "vasiliy.vorobev1973@postgrespro.ru", "phone": "+70333256751"}
0005435508226	73167A	8180 252280	ALENA POPOVA	{"email": "popova_alena13061984@postgrespro.ru", "phone": "+70730294074"}
0005435508227	C1C5FC	6436 574887	KIRILL SEMENOV	{"phone": "+70543243797"}
0005435508228	C1C5FC	5894 373586	SVETLANA YAKOVLEVA	{"phone": "+70225371040"}
0005435508229	1A9F25	7431 089233	OLEG KAZAKOV	{"phone": "+70349143383"}
0005435508230	5D3E01	5323 491369	YULIYA MOISEEVA	{"email": "yuliya_moiseeva-20111971@postgrespro.ru", "phone": "+70849296705"}
0005435508231	1BD119	7414 573693	TATYANA FEDOROVA	{"email": "tatyana.fedorova.1974@postgrespro.ru", "phone": "+70854656223"}
0005435508232	8AC64B	4791 062312	PAVEL IVANOV	{"email": "pavel-ivanov21041983@postgrespro.ru", "phone": "+70558187044"}
0005435508233	8AC64B	6291 470039	GALINA MASLOVA	{"phone": "+70663572864"}
0005435508234	287365	3802 165730	LYUDMILA SOLOVEVA	{"email": "lsoloveva-12071976@postgrespro.ru", "phone": "+70536278892"}
0005435508235	41EA74	4958 140678	RUSLAN MAKSIMOV	{"email": "maksimov-ruslan_1983@postgrespro.ru", "phone": "+70940947162"}
0005435508236	BEB320	9027 085700	NATALYA ISAEVA	{"email": "isaeva-n.1972@postgrespro.ru", "phone": "+70703556001"}
0005435508237	BBB095	1641 348689	ALEKSEY KARPOV	{"email": "a.karpov071973@postgrespro.ru", "phone": "+70856571946"}
0005435508238	BBB095	6386 983436	OLEG GORBUNOV	{"email": "oleg-gorbunov021971@postgrespro.ru", "phone": "+70080507134"}
0005435508239	B2098E	8089 536703	NADEZHDA TIMOFEEVA	{"email": "nadezhda-timofeeva_081982@postgrespro.ru", "phone": "+70373019181"}
0005435508240	84A226	4869 740624	MIKHAIL DENISOV	{"email": "mikhail-denisov_1971@postgrespro.ru", "phone": "+70105178905"}
0005435508241	AB8DFC	8554 701336	ALEKSANDR NOVIKOV	{"phone": "+70893274752"}
0005435508242	E7A874	6097 448486	ZHANNA YAKOVLEVA	{"email": "zhanna.yakovleva.1976@postgrespro.ru", "phone": "+70626879832"}
0005435508243	E7A874	0529 027554	EKATERINA AKIMOVA	{"email": "akimova-ekaterina.02061965@postgrespro.ru", "phone": "+70472377549"}
0005435508244	A1C34B	5982 258849	IRINA NAUMOVA	{"email": "naumova.irina.18101968@postgrespro.ru", "phone": "+70132683228"}
0005435508245	A9CE25	3663 643366	YULIYA KOVALEVA	{"phone": "+70598471722"}
0005435508246	F2A550	7887 592424	OLEG ABRAMOV	{"email": "abramov_o06111981@postgrespro.ru", "phone": "+70144676647"}
0005435508247	F2A550	9326 885362	ELENA MELNIKOVA	{"email": "melnikova-e.20081963@postgrespro.ru", "phone": "+70754254738"}
0005435508248	9004B4	6787 877488	EVGENIY ANDREEV	{"email": "andreev.evgeniy_01021975@postgrespro.ru", "phone": "+70156700568"}
0005435508249	9004B4	6013 920028	VALENTIN ZAKHAROV	{"email": "v_zakharov-031977@postgrespro.ru", "phone": "+70661237699"}
0005435508250	F1F1E2	2559 022904	NATALIYA KONOVALOVA	{"phone": "+70958365917"}
0005435508251	C135D5	4376 350528	NIKOLAY ZAKHAROV	{"phone": "+70437818800"}
0005435508252	87E078	0514 606287	LYUBOV ANDREEVA	{"phone": "+70445888416"}
0005435508253	BCDA20	9547 427072	MARINA EGOROVA	{"email": "egorova.marina031963@postgrespro.ru", "phone": "+70442093881"}
0005435508254	6AE7AE	2437 887609	ALEKSANDR EGOROV	{"email": "egorov.aleksandr11031974@postgrespro.ru", "phone": "+70297521334"}
0005435508255	6AE7AE	6628 388782	IRINA ZHURAVLEVA	{"email": "irina.zhuravleva_101973@postgrespro.ru", "phone": "+70626296960"}
0005435508256	21B430	1831 809503	ANDREY YAKOVLEV	{"email": "a_yakovlev_03091981@postgrespro.ru", "phone": "+70568840689"}
0005435508257	5514EC	1425 549842	TATYANA SMIRNOVA	{"email": "smirnova_t-11091971@postgrespro.ru", "phone": "+70956389551"}
0005435508258	5514EC	1007 844038	OLGA VLASOVA	{"email": "olga_vlasova.111970@postgrespro.ru", "phone": "+70070190345"}
0005435508259	2DAB9D	1004 831109	LYUDMILA NAUMOVA	{"email": "naumova-l_06041976@postgrespro.ru", "phone": "+70225219986"}
0005435508260	86F515	5733 935525	ILDAR SHEVCHENKO	{"phone": "+70888180209"}
0005435508261	B4B70C	3776 874229	NIKITA GUSEV	{"email": "gusevnikita.081975@postgrespro.ru", "phone": "+70047226470"}
0005435508262	D96FD6	2078 909430	ALEKSANDR SIDOROV	{"email": "sidorov_a011980@postgrespro.ru", "phone": "+70325748230"}
0005435508263	8B5AE5	4900 513410	VLADIMIR SEMENOV	{"email": "semenov.v_081974@postgrespro.ru", "phone": "+70138377185"}
0005435508264	8B5AE5	3020 301065	VIKTOR ANDREEV	{"email": "viktor_andreev-091972@postgrespro.ru", "phone": "+70098397770"}
0005435508265	E400C3	9719 402472	KLAVDIYA KUDRYASHOVA	{"email": "kudryashova.klavdiya_111978@postgrespro.ru", "phone": "+70912615078"}
0005435508266	408E2A	2324 868840	DANIIL DMITRIEV	{"email": "dmitrievd_101971@postgrespro.ru", "phone": "+70561990501"}
0005435508267	50427B	7334 443193	MARIYA MARTYNOVA	{"email": "m.martynova071973@postgrespro.ru", "phone": "+70952808008"}
0005435508268	AAB021	8932 930913	ANGELINA ANISIMOVA	{"email": "a_anisimova-061972@postgrespro.ru", "phone": "+70770574481"}
0005435508269	AAB021	0373 252701	NINA SMIRNOVA	{"phone": "+70514112723"}
0005435508270	70AC20	9800 183443	RINAT NIKOLAEV	{"email": "nikolaev.r-17021972@postgrespro.ru", "phone": "+70909018844"}
0005435508271	26DD3B	5082 193208	VALENTINA OSIPOVA	{"phone": "+70941380653"}
0005435508272	26DD3B	0539 082137	VALENTINA OVCHINNIKOVA	{"phone": "+70999089748"}
0005435508273	6B2BD3	8314 680703	DMITRIY OSIPOV	{"email": "dosipov-1976@postgrespro.ru", "phone": "+70953463156"}
0005435508274	CE4AF1	2577 265538	DMITRIY KONOVALOV	{"phone": "+70356919260"}
0005435508275	D30D18	2148 225875	ANATOLIY POPOV	{"phone": "+70534750346"}
0005435508276	8FA5E0	6792 595943	NINA PAVLOVA	{"phone": "+70272283394"}
0005435508277	8FA5E0	3448 947352	LILIYA SERGEEVA	{"phone": "+70684781523"}
0005435508278	B969EF	1597 992235	ALEKSANDR KUZMIN	{"email": "kuzmin.a_14101977@postgrespro.ru", "phone": "+70774645669"}
0005435508279	29A0DA	6239 927168	ANASTASIYA ZAYCEVA	{"email": "anastasiya_zayceva111987@postgrespro.ru", "phone": "+70499005285"}
0005435508280	0296B3	8930 793225	EVGENIY POPOV	{"email": "popov-e_26061975@postgrespro.ru", "phone": "+70106958965"}
0005435508281	F0EB27	3085 726786	DENIS TARASOV	{"phone": "+70708845905"}
0005435508282	F0EB27	8769 495180	EKATERINA FOMINA	{"phone": "+70591338910"}
0005435508283	2A51DB	4823 087521	ANNA PETROVA	{"email": "petrovaanna_1977@postgrespro.ru", "phone": "+70692186497"}
0005435508284	F4ACBD	6119 690781	DARINA OSIPOVA	{"email": "osipova_darina.01041960@postgrespro.ru", "phone": "+70816155774"}
0005435508285	F4ACBD	9976 147387	ALEKSANDR GAVRILOV	{"phone": "+70550634970"}
0005435508286	DF2ABA	3260 657449	TAMARA TARASOVA	{"email": "tamara-tarasova.1971@postgrespro.ru", "phone": "+70047607605"}
0005435508287	DF2ABA	0080 792518	NIKOLAY ORLOV	{"email": "n_orlov101969@postgrespro.ru", "phone": "+70543311075"}
0005435508288	2DEF5C	7402 988268	VIKTOR VOLKOV	{"phone": "+70228892358"}
0005435508289	162824	2061 257021	SERGEY SAVELEV	{"phone": "+70462132234"}
0005435508290	15C2B8	7784 145732	NINA MAKAROVA	{"email": "makarovan.1975@postgrespro.ru", "phone": "+70629235056"}
0005435508291	15C2B8	7608 092183	ILYA BORISOV	{"phone": "+70174060043"}
0005435508292	77A1AF	8931 754171	DMITRIY NAZAROV	{"email": "nazarov_dmitriy.051968@postgrespro.ru", "phone": "+70867216681"}
0005435508293	77A1AF	9724 908135	VADIM KOZLOV	{"email": "v_kozlov1963@postgrespro.ru", "phone": "+70240458142"}
0005435508294	CF3211	4862 128751	NIKOLAY SEMENOV	{"email": "semenov-nikolay_26041968@postgrespro.ru", "phone": "+70235414460"}
0005435508295	FD0D47	7010 882365	POLINA SERGEEVA	{"phone": "+70903927274"}
0005435508296	009DD6	0951 390477	VITALIY KUZNECOV	{"email": "kuznecov_vitaliy.24041974@postgrespro.ru", "phone": "+70590958801"}
0005435508297	9E42F8	5163 386666	TAMARA FILATOVA	{"email": "tamara-filatova_091963@postgrespro.ru", "phone": "+70681847319"}
0005435508298	9E42F8	5562 156006	ANATOLIY KISELEV	{"email": "anatoliykiselev17021966@postgrespro.ru", "phone": "+70407248153"}
0005435508299	9E42F8	3423 524475	ELENA KUZNECOVA	{"email": "kuznecova.elena_111963@postgrespro.ru", "phone": "+70453986848"}
0005435508300	FE7F5F	5762 063329	VITALIY VOLKOV	{"email": "v_volkov-101962@postgrespro.ru", "phone": "+70289596006"}
0005435508301	FE7F5F	6809 321875	NATALYA EGOROVA	{"email": "egorovanatalya_101974@postgrespro.ru", "phone": "+70314151788"}
0005435508302	89D355	0984 732420	MARIYA LUKYANOVA	{"phone": "+70158596857"}
0005435508303	89D355	4573 552346	VLADIMIR MEDVEDEV	{"email": "vmedvedev1978@postgrespro.ru", "phone": "+70441917645"}
0005435508304	89D355	5907 055089	NATALYA KOMAROVA	{"phone": "+70912111344"}
0005435508305	57AED8	2180 559510	YULIYA ILINA	{"phone": "+70401185180"}
0005435508306	E4443F	2696 184616	LYUBOV GERASIMOVA	{"email": "gerasimova.lyubov_121968@postgrespro.ru", "phone": "+70997429502"}
0005435508307	407CF9	2136 230697	ALEKSANDR STEPANOV	{"email": "stepanov-aleksandr.11091973@postgrespro.ru", "phone": "+70825061681"}
0005435508363	C08019	3440 694148	EVGENIYA MELNIKOVA	{"phone": "+70103864598"}
0005435508308	38DA45	4593 267942	LILIYA SOKOLOVA	{"email": "sokolova.l.1965@postgrespro.ru", "phone": "+70151474418"}
0005435508309	14E981	9665 511706	SERGEY BELOV	{"email": "sergey.belov041978@postgrespro.ru", "phone": "+70296641648"}
0005435508310	2113F6	6789 737377	ALEKSANDR ZAYCEV	{"phone": "+70270496231"}
0005435508311	2113F6	7570 066068	OLGA SOLOVEVA	{"phone": "+70410986297"}
0005435508312	4D789F	9887 892272	VIKTOR SMIRNOV	{"email": "smirnovv01071979@postgrespro.ru", "phone": "+70729952691"}
0005435508313	544517	2380 101848	STANISLAV DAVYDOV	{"email": "davydov.stanislav.30011979@postgrespro.ru", "phone": "+70853822019"}
0005435508314	544517	3808 922255	ZOYA VOROBEVA	{"phone": "+70938234216"}
0005435508315	FEBF4C	8635 728383	TATYANA SCHERBAKOVA	{"email": "scherbakova_tatyana1976@postgrespro.ru", "phone": "+70137149153"}
0005435508316	FEBF4C	9812 883877	SERGEY ORLOV	{"email": "orlov_s_1964@postgrespro.ru", "phone": "+70620747849"}
0005435508317	FEBF4C	6144 178411	ALMIRA PETROVA	{"email": "a-petrova03081978@postgrespro.ru", "phone": "+70311446127"}
0005435508318	84E432	0212 700197	VLADIMIR GERASIMOV	{"phone": "+70691657413"}
0005435508319	CDA170	5654 387603	SERGEY ANTONOV	{"email": "s-antonov_30061959@postgrespro.ru", "phone": "+70771373378"}
0005435508320	191D79	0633 994857	LYUBOV MOROZOVA	{"phone": "+70471796356"}
0005435508321	191D79	8719 231989	VARVARA YUDINA	{"email": "varvara-yudina_1966@postgrespro.ru", "phone": "+70819313804"}
0005435508322	FFCDEB	9878 816006	EVDOKIYA POPOVA	{"phone": "+70822447464"}
0005435508323	2639C8	7169 356792	LYUDMILA PETROVA	{"phone": "+70425933447"}
0005435508324	3AB116	0560 862339	VALENTINA TIMOFEEVA	{"email": "timofeeva_v.1965@postgrespro.ru", "phone": "+70799823209"}
0005435508325	AD7604	8795 466573	NIKITA MIRONOV	{"email": "mironov-nikita-1977@postgrespro.ru", "phone": "+70094654979"}
0005435508326	3A2846	2047 296693	NINA FOMINA	{"email": "ninafomina.101973@postgrespro.ru", "phone": "+70185197768"}
0005435508327	9D212F	8419 502028	LYUDMILA KONOVALOVA	{"phone": "+70494345978"}
0005435508328	9D212F	7153 371586	ALEKSANDR MATVEEV	{"phone": "+70172928459"}
0005435508329	F87AEB	4340 259850	VLADISLAV TIMOFEEV	{"phone": "+70448117944"}
0005435508330	961A61	6617 386479	ALEKSANDR KUZNECOV	{"email": "kuznecova091975@postgrespro.ru", "phone": "+70282077017"}
0005435508331	961A61	7067 447924	NIKOLAY SOROKIN	{"phone": "+70789269507"}
0005435508332	A596C2	7234 479619	VLADIMIR TIMOFEEV	{"phone": "+70142162849"}
0005435508333	A596C2	7644 015982	OLGA BORISOVA	{"email": "olga_borisova1982@postgrespro.ru", "phone": "+70438022641"}
0005435508334	AF1C42	7217 639590	NINA FEDOROVA	{"email": "nina-fedorova-1975@postgrespro.ru", "phone": "+70761146497"}
0005435508335	AF1C42	8128 808046	NADEZHDA KOMAROVA	{"phone": "+70048718917"}
0005435508336	94C81B	9218 749407	SERGEY ANDREEV	{"phone": "+70296162849"}
0005435508337	43636C	9427 135867	ALEKSANDRA TIMOFEEVA	{"phone": "+70060245161"}
0005435508338	BFE2E3	7572 491241	EVGENIY PETROV	{"phone": "+70675937902"}
0005435508339	7F6D54	5261 409027	IVAN POPOV	{"email": "popov.i.27101966@postgrespro.ru", "phone": "+70487102854"}
0005435508340	CD1C95	4800 425222	ANGELINA ERMAKOVA	{"phone": "+70752839909"}
0005435508341	7C8CC8	6594 576682	LILIYA SOROKINA	{"phone": "+70827677522"}
0005435508342	CB850D	4332 328211	STANISLAV MELNIKOV	{"email": "melnikov_s-051975@postgrespro.ru", "phone": "+70357157770"}
0005435508343	CB850D	2107 081249	ALEKSANDR ZHUKOV	{"email": "aleksandr-zhukov-1969@postgrespro.ru", "phone": "+70653120651"}
0005435508344	97528F	8458 457725	PAVEL ZHURAVLEV	{"phone": "+70026292045"}
0005435508345	97528F	7307 771732	OLGA YUDINA	{"phone": "+70952950246"}
0005435508346	92001B	4173 190915	RAMIL SOROKIN	{"email": "ramilsorokin-111969@postgrespro.ru", "phone": "+70988543149"}
0005435508347	875CD3	0633 856860	MARINA KUZNECOVA	{"email": "kuznecova_m.10081972@postgrespro.ru", "phone": "+70437205621"}
0005435508348	875CD3	5838 929818	GALINA FROLOVA	{"phone": "+70516279027"}
0005435508349	4796E6	0714 711842	DARYA MOROZOVA	{"email": "daryamorozova1968@postgrespro.ru", "phone": "+70777287080"}
0005435508350	6DD468	9099 140837	IVAN ABRAMOV	{"email": "abramov_ivan_10091976@postgrespro.ru", "phone": "+70414218970"}
0005435508351	0E7B15	7265 698332	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr_051971@postgrespro.ru", "phone": "+70627636363"}
0005435508352	8AE3D1	8419 658679	YULIYA BELYAEVA	{"email": "belyaeva-yuliya-15071968@postgrespro.ru", "phone": "+70770888740"}
0005435508353	8AE3D1	5758 303041	LIDIYA BORISOVA	{"email": "lidiya-borisova_23111973@postgrespro.ru", "phone": "+70133216230"}
0005435508354	BC5C3C	8532 977964	DMITRIY SAVELEV	{"email": "savelev.dmitriy-29121968@postgrespro.ru", "phone": "+70894718791"}
0005435508355	D85103	2240 992585	ALEKSEY POPOV	{"email": "alekseypopov_101969@postgrespro.ru", "phone": "+70418529899"}
0005435508356	D85103	9769 467591	MARIYA TIMOFEEVA	{"email": "timofeeva.mariya-111980@postgrespro.ru", "phone": "+70587318599"}
0005435508357	5281FA	0470 207809	ANNA TIKHONOVA	{"phone": "+70085850009"}
0005435508358	9D5DD9	8962 818011	ANNA MATVEEVA	{"email": "matveeva.anna_07021981@postgrespro.ru", "phone": "+70086676569"}
0005435508359	473F01	6097 465586	OLGA OVCHINNIKOVA	{"email": "ovchinnikova_olga.011969@postgrespro.ru", "phone": "+70050663725"}
0005435508360	4E6EF3	7636 967558	DMITRIY ORLOV	{"phone": "+70076902594"}
0005435508361	D5BEC0	1980 782415	ELIZAVETA ANTONOVA	{"email": "e-antonova111975@postgrespro.ru", "phone": "+70307573435"}
0005435508362	3456A7	9112 316232	ANTON ILIN	{"email": "anton.ilin_081958@postgrespro.ru", "phone": "+70552734842"}
0005435508364	B7F1E8	3155 947304	YURIY MEDVEDEV	{"email": "yuriymedvedev_1979@postgrespro.ru", "phone": "+70613016371"}
0005435508365	D03825	3675 164541	ALEKSANDR ZHUKOV	{"phone": "+70815986744"}
0005435508366	D03825	9406 466516	SERGEY BELOV	{"email": "sbelov.1966@postgrespro.ru", "phone": "+70313754103"}
0005435508367	F4B8DA	2937 552902	TAMARA POLYAKOVA	{"phone": "+70275548806"}
0005435508368	372270	1910 081608	VIKTOR KUZNECOV	{"phone": "+70294976039"}
0005435508369	CEC29D	1629 212691	LYUDMILA VLASOVA	{"phone": "+70903743876"}
0005435508370	15F282	3290 691221	ANDREY KOZLOV	{"email": "a-kozlov02011991@postgrespro.ru", "phone": "+70178561320"}
0005435508371	1DADA9	5734 690236	MAKSIM BORISOV	{"email": "borisov.maksim-17101975@postgrespro.ru", "phone": "+70316487231"}
0005435508372	1DADA9	5980 642714	VITALIY POPOV	{"email": "vpopov_1970@postgrespro.ru", "phone": "+70655593966"}
0005435508373	684A70	4294 669857	RAISA MOROZOVA	{"email": "raisa.morozova-29111973@postgrespro.ru", "phone": "+70857716857"}
0005435508374	D42C48	5760 767886	LIDIYA KUZNECOVA	{"email": "kuznecova.lidiya_101979@postgrespro.ru", "phone": "+70879165795"}
0005435508375	DC548B	4306 201191	IGOR GERASIMOV	{"phone": "+70578758090"}
0005435508376	8CB0F5	4660 198888	VLADISLAV MIKHAYLOV	{"phone": "+70281074396"}
0005435508377	90DB63	0588 549937	EVGENIYA DANILOVA	{"phone": "+70207942858"}
0005435508378	D18F22	7832 842233	NATALYA ZAYCEVA	{"email": "natalya.zayceva-1978@postgrespro.ru", "phone": "+70292327981"}
0005435508379	FBADE2	6876 339403	ANNA DAVYDOVA	{"phone": "+70547476540"}
0005435508380	236D04	5693 501539	OLEG SEMENOV	{"email": "semenov.o.051969@postgrespro.ru", "phone": "+70917480814"}
0005435508381	B1D046	5870 241854	KIRILL SCHERBAKOV	{"email": "kirill.scherbakov_071969@postgrespro.ru", "phone": "+70754993466"}
0005435508382	CBCCD0	4732 287137	IGOR IVANOV	{"phone": "+70248874201"}
0005435508383	CBCCD0	6286 525659	VALENTIN VASILEV	{"phone": "+70861206873"}
0005435508384	ED6D57	4530 186925	PAVEL ZAYCEV	{"email": "pavel.zaycev06121980@postgrespro.ru", "phone": "+70806124095"}
0005435508385	60039C	8247 257915	DENIS BORISOV	{"phone": "+70630089651"}
0005435508386	6104AA	9332 256475	LIDIYA SERGEEVA	{"phone": "+70499980841"}
0005435508387	6104AA	9842 447723	ALEKSANDR GAVRILOV	{"phone": "+70645301329"}
0005435508388	358291	4851 503323	TATYANA OSIPOVA	{"phone": "+70676163048"}
0005435508389	99E5D4	4874 584825	OLGA MIRONOVA	{"phone": "+70653396443"}
0005435508390	D63894	4817 886381	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay-02061974@postgrespro.ru", "phone": "+70902933390"}
0005435508391	1903AE	5182 400555	ALEKSANDR FILIPPOV	{"email": "filippov-aleksandr_081970@postgrespro.ru", "phone": "+70405309296"}
0005435508392	9CEDC8	7526 944220	DMITRIY MAKAROV	{"email": "d-makarov.041964@postgrespro.ru", "phone": "+70201120109"}
0005435508393	9CEDC8	9164 184659	LYUDMILA YAKOVLEVA	{"email": "yakovleva-l.1977@postgrespro.ru", "phone": "+70810866886"}
0005435508394	92F368	9048 271382	LEV IVANOV	{"email": "levivanov.1970@postgrespro.ru", "phone": "+70027883973"}
0005435508395	E59172	4463 652385	SVETLANA ALEKSANDROVA	{"phone": "+70556042344"}
0005435508396	8CFE06	8468 376735	LYUDMILA BELYAEVA	{"phone": "+70467183812"}
0005435508397	8CFE06	3452 066720	ALEKSEY SMIRNOV	{"phone": "+70015277695"}
0005435508398	5F6B32	5307 854284	SVETLANA POPOVA	{"phone": "+70402776782"}
0005435508399	735703	1208 219016	DENIS NIKOLAEV	{"email": "nikolaevdenis.061977@postgrespro.ru", "phone": "+70461079764"}
0005435508400	774D28	5114 003643	SERGEY EGOROV	{"email": "egorov_s-1968@postgrespro.ru", "phone": "+70079981923"}
0005435508401	5FDB8D	2600 784785	NIKITA MEDVEDEV	{"email": "nikitamedvedev.111962@postgrespro.ru", "phone": "+70666693519"}
0005435508402	05D7D6	3407 215061	SERGEY FILIPPOV	{"email": "filippov-s.11041971@postgrespro.ru", "phone": "+70803543492"}
0005435508403	05D7D6	3414 190362	NATALYA KOLESNIKOVA	{"email": "kolesnikova_natalya.06021969@postgrespro.ru", "phone": "+70886957284"}
0005435508404	8A7126	9382 089400	MAKSIM VOLKOV	{"email": "maksim_volkov_1982@postgrespro.ru", "phone": "+70947052972"}
0005435508405	8A7126	9882 118787	DMITRIY MAKSIMOV	{"phone": "+70775048990"}
0005435508406	90DF6F	4931 004277	ZOYA KISELEVA	{"email": "kiseleva-z_01111975@postgrespro.ru", "phone": "+70287331636"}
0005435508407	1A4856	0224 481091	IVAN DMITRIEV	{"email": "dmitrievivan.05101980@postgrespro.ru", "phone": "+70180378101"}
0005435508408	1A4856	4903 526379	ANDREY SEMENOV	{"email": "semenov_a.03091973@postgrespro.ru", "phone": "+70038454691"}
0005435508409	2C3FFA	1225 797957	OLGA FADEEVA	{"phone": "+70770403203"}
0005435508410	4F65B5	1635 698709	SERGEY NOVIKOV	{"email": "novikov-sergey-031973@postgrespro.ru", "phone": "+70790691573"}
0005435508411	4F65B5	1766 863255	EGOR SIDOROV	{"email": "egor-sidorov_1968@postgrespro.ru", "phone": "+70482693891"}
0005435508412	4F65B5	2625 473479	NIKOLAY SAVELEV	{"phone": "+70304677848"}
0005435508413	68177B	8247 903642	PETR MOROZOV	{"phone": "+70381399150"}
0005435508414	68177B	7255 565521	ANTONINA FOMINA	{"phone": "+70123767467"}
0005435508415	71C4C4	3991 505131	NIKITA SOROKIN	{"phone": "+70113676027"}
0005435508416	ADA12B	5992 189548	EKATERINA ROMANOVA	{"email": "romanovaekaterina071965@postgrespro.ru", "phone": "+70563026344"}
0005435508417	EB84BB	0346 339036	ALFIYA KOZLOVA	{"email": "kozlovaa_021974@postgrespro.ru", "phone": "+70707817044"}
0005435508418	5526C5	4917 560308	REGINA MARTYNOVA	{"phone": "+70966020043"}
0005435508419	5526C5	0079 653578	EKATERINA ALEKSANDROVA	{"phone": "+70274892236"}
0005435508420	DA792A	1441 652537	OLGA ROMANOVA	{"phone": "+70303745666"}
0005435508421	29395F	9102 703690	LYUBOV MATVEEVA	{"email": "lyubov.matveeva-1976@postgrespro.ru", "phone": "+70213257558"}
0005435508422	29395F	4612 438813	ANATOLIY RODIONOV	{"phone": "+70111970740"}
0005435508423	DA478D	7636 970743	SVETLANA KULIKOVA	{"email": "svetlana.kulikova031977@postgrespro.ru", "phone": "+70667427389"}
0005435508424	1EE778	0446 080604	VIKTORIYA POPOVA	{"phone": "+70883146709"}
0005435508425	76CE42	2427 629874	VITALIY ZAYCEV	{"email": "zaycev_vitaliy-091967@postgrespro.ru", "phone": "+70236178437"}
0005435508426	76CE42	6792 117356	ANDREY MELNIKOV	{"phone": "+70190483273"}
0005435508427	19933D	8923 562082	SERGEY STEPANOV	{"email": "s-stepanov.1973@postgrespro.ru", "phone": "+70934876265"}
0005435508428	19933D	4577 505116	SERGEY ABRAMOV	{"phone": "+70453367940"}
0005435508429	A9E6C6	5763 481122	VALENTINA ILINA	{"phone": "+70773824981"}
0005435508430	EE6441	9310 526849	EGOR IVANOV	{"email": "ivanov_egor-1979@postgrespro.ru", "phone": "+70509962255"}
0005435508431	EE6441	6654 906764	ALEKSANDR GRIGOREV	{"email": "grigorev.a071969@postgrespro.ru", "phone": "+70895290803"}
0005435508432	2ED350	0317 487519	NIKOLAY TIMOFEEV	{"email": "timofeev.nikolay101974@postgrespro.ru", "phone": "+70551487020"}
0005435508433	46E3B0	0559 740781	VLADIMIR ZAYCEV	{"email": "zaycev_v-1977@postgrespro.ru", "phone": "+70076749372"}
0005435508434	C31A72	6612 531123	ANTONIDA TARASOVA	{"phone": "+70495736669"}
0005435508435	E8F861	0265 888833	ALEKSEY BELOV	{"email": "belov_a_1957@postgrespro.ru", "phone": "+70045877072"}
0005435508436	C673AB	7739 571328	ALEKSANDR POPOV	{"phone": "+70103269187"}
0005435508437	C673AB	9789 897220	ALEKSANDR NIKITIN	{"email": "aleksandrnikitin061974@postgrespro.ru", "phone": "+70972845208"}
0005435508438	3836F5	5534 057759	ALEKSANDR FEDOROV	{"phone": "+70495916717"}
0005435508439	3836F5	8072 071267	VITALIY ANDREEV	{"phone": "+70155160279"}
0005435508440	B7EA03	8865 285586	ANATOLIY KUZNECOV	{"phone": "+70728206573"}
0005435508441	913FBB	7748 468020	EKATERINA NESTEROVA	{"phone": "+70910037944"}
0005435508442	D4B91E	2891 604359	KSENIYA FOMINA	{"email": "k.fomina12021969@postgrespro.ru", "phone": "+70885675595"}
0005435508443	1DA9E7	4621 319160	ELENA KULIKOVA	{"phone": "+70063432214"}
0005435508444	6AF863	8976 222475	IRINA SOKOLOVA	{"phone": "+70084225846"}
0005435508445	4F36BB	5980 226003	ANNA BORISOVA	{"phone": "+70557042285"}
0005435508446	4F36BB	4050 854124	ALEKSANDR SCHERBAKOV	{"email": "aleksandr.scherbakov-31051964@postgrespro.ru", "phone": "+70390508719"}
0005435508447	D2DCAE	5078 389578	DENIS OSIPOV	{"phone": "+70214990880"}
0005435508448	D2DCAE	7094 555896	MAKSIM KULIKOV	{"email": "maksim_kulikov_021980@postgrespro.ru", "phone": "+70504219801"}
0005435508449	F679D1	1394 802722	NATALYA POPOVA	{"email": "popova_natalya_02111984@postgrespro.ru", "phone": "+70301768290"}
0005435508450	F679D1	4321 915478	VITALIY NAUMOV	{"phone": "+70207356676"}
0005435508451	8490A5	8875 943268	VALENTINA ZAYCEVA	{"phone": "+70893493866"}
0005435508452	3DF7E1	8799 884253	TATYANA YUDINA	{"email": "yudinatatyana_101975@postgrespro.ru", "phone": "+70984756829"}
0005435508453	1E24AD	9311 074261	GLEB NAZAROV	{"email": "glebnazarov_121966@postgrespro.ru", "phone": "+70853037377"}
0005435508454	1E24AD	6338 093368	OLGA GRISHINA	{"email": "grishinaolga.1982@postgrespro.ru", "phone": "+70218161052"}
0005435508455	84C517	1490 785938	SVETLANA ZAKHAROVA	{"phone": "+70855507579"}
0005435508456	52AB9F	9188 679289	DMITRIY MOROZOV	{"email": "morozov-d_14081972@postgrespro.ru", "phone": "+70511558258"}
0005435508457	1E6A26	6267 131350	YULIYA POPOVA	{"phone": "+70287903913"}
0005435508458	FD2707	1137 441169	NATALYA MIRONOVA	{"phone": "+70734011917"}
0005435508459	5B78DF	1478 474750	DENIS DENISOV	{"email": "d-denisov-051985@postgrespro.ru", "phone": "+70480622401"}
0005435508460	5B78DF	6278 250691	ELENA SAVELEVA	{"phone": "+70811081268"}
0005435508461	5B78DF	3132 822583	VLADIMIR ZAKHAROV	{"phone": "+70762227221"}
0005435508462	5B78DF	0643 961455	VLADIMIR SEMENOV	{"phone": "+70741683446"}
0005435508463	315C9C	3256 288931	IVAN NAUMOV	{"email": "naumov_ivan041980@postgrespro.ru", "phone": "+70053976371"}
0005435508464	771C4E	2644 524523	RAISA DAVYDOVA	{"email": "davydova_r.13111981@postgrespro.ru", "phone": "+70760177488"}
0005435508465	771C4E	7484 026418	ALEKSANDR KAZAKOV	{"email": "aleksandrkazakov_1959@postgrespro.ru", "phone": "+70700261948"}
0005435508466	BDE8E9	2332 396050	VENIAMIN KISELEV	{"email": "kiselev.v_24121981@postgrespro.ru", "phone": "+70137966334"}
0005435508467	D681AC	2133 488746	VLADIMIR STEPANOV	{"phone": "+70900658769"}
0005435508468	D681AC	2314 660099	ANATOLIY RODIONOV	{"email": "anatoliyrodionov_29051978@postgrespro.ru", "phone": "+70866229681"}
0005435508469	C408E7	4957 447835	MARINA SOKOLOVA	{"phone": "+70560522649"}
0005435508470	8D4E8E	2928 872100	MAKSIM VASILEV	{"email": "m-vasilev_06081964@postgrespro.ru", "phone": "+70047450953"}
0005435508471	8D4E8E	7684 653504	EKATERINA BORISOVA	{"phone": "+70260576137"}
0005435508472	0CEBAD	0234 109495	OLGA STEPANOVA	{"phone": "+70240041344"}
0005435508473	D22370	7584 028002	NATALIYA KONDRATEVA	{"email": "kondrateva.n.081969@postgrespro.ru", "phone": "+70255536611"}
0005435508474	69CA48	6725 024520	ELENA ILINA	{"phone": "+70582767803"}
0005435508475	223110	5254 602407	LYUBOV KONOVALOVA	{"email": "lyubovkonovalova.05031957@postgrespro.ru", "phone": "+70502315332"}
0005435508476	072A67	7914 888200	EVGENIY IVANOV	{"email": "e-ivanov.04061975@postgrespro.ru", "phone": "+70686904129"}
0005435508477	25DB27	8517 664841	ANTON FEDOROV	{"phone": "+70136668985"}
0005435508478	D900A4	9810 549587	EVGENIYA YAKOVLEVA	{"email": "evgeniya.yakovleva_1961@postgrespro.ru", "phone": "+70003143662"}
0005435508479	D900A4	2076 802550	BORIS SOLOVEV	{"phone": "+70188639417"}
0005435508480	9982E1	2749 403331	SERGEY ABRAMOV	{"phone": "+70084014627"}
0005435508481	8A925B	9830 129185	SOFIYA EGOROVA	{"phone": "+70121851416"}
0005435508482	8A925B	5924 300670	KIRILL KUZMIN	{"email": "kirill.kuzmin_09021975@postgrespro.ru", "phone": "+70412792476"}
0005435508483	EF4ADB	1677 689942	SVETLANA NESTEROVA	{"email": "svetlananesterova-051975@postgrespro.ru", "phone": "+70568927363"}
0005435508484	4BC7B3	9062 307994	ELVIRA NOVIKOVA	{"email": "novikova.elvira_091981@postgrespro.ru", "phone": "+70714793448"}
0005435508485	72632A	5229 782472	ILONA FEDOROVA	{"email": "fedorova.ilona-04071967@postgrespro.ru", "phone": "+70615680105"}
0005435508486	DB00B8	0190 872081	GENNADIY TIMOFEEV	{"email": "gennadiy.timofeev.081970@postgrespro.ru", "phone": "+70386693717"}
0005435508487	20CE03	9827 071418	VASILIY AFANASEV	{"phone": "+70882748059"}
0005435508488	6B2CAB	1837 948717	TATYANA KOZLOVA	{"email": "tatyanakozlova26071971@postgrespro.ru", "phone": "+70270164976"}
0005435508489	E2CB69	4845 662383	VITALIY SOROKIN	{"email": "vitaliy_sorokin_27041982@postgrespro.ru", "phone": "+70595019982"}
0005435508490	85CBC1	8464 190605	DMITRIY SAVELEV	{"phone": "+70243634015"}
0005435508491	A90944	8748 889833	MAKSIM DAVYDOV	{"email": "davydov.m-1980@postgrespro.ru", "phone": "+70409378381"}
0005435508492	E9E8FB	7724 119095	DENIS MOROZOV	{"phone": "+70369634671"}
0005435508493	5C5F3B	7050 455164	SERGEY SERGEEV	{"email": "sergey_sergeev.14021976@postgrespro.ru", "phone": "+70554497388"}
0005435508494	3EACAE	1031 635227	MARINA ZAKHAROVA	{"phone": "+70929922168"}
0005435508495	3EACAE	1877 403642	GALINA KONOVALOVA	{"phone": "+70845605174"}
0005435508496	B36E71	1394 178054	MIKHAIL FOMIN	{"phone": "+70421685943"}
0005435508497	78FABF	6755 805275	ALEKSANDR KUZMIN	{"email": "a_kuzmin-03021972@postgrespro.ru", "phone": "+70709088763"}
0005435508498	5B96CC	8638 743801	ANNA SMIRNOVA	{"phone": "+70171515697"}
0005435508499	5B96CC	7056 112063	ILYA TIKHONOV	{"email": "ilya_tikhonov-10051977@postgrespro.ru", "phone": "+70259185283"}
0005435508500	E4FFDE	9551 059474	VERA SOKOLOVA	{"phone": "+70996298914"}
0005435508501	50145C	1513 635520	LYUDMILA IVANOVA	{"email": "ivanova.lyudmila_05111980@postgrespro.ru", "phone": "+70886247273"}
0005435508502	50145C	7565 930111	MIKHAIL BORISOV	{"email": "mikhailborisov24101966@postgrespro.ru", "phone": "+70437919173"}
0005435508503	7FC728	2246 351772	ZINAIDA SOKOLOVA	{"email": "z.sokolova_041972@postgrespro.ru", "phone": "+70200460956"}
0005435508504	066CEE	6368 071615	ANATOLIY VASILEV	{"email": "anatoliy_vasilev_05091977@postgrespro.ru", "phone": "+70318379461"}
0005435508505	A5EE12	5382 597760	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov_21011970@postgrespro.ru", "phone": "+70370992093"}
0005435508506	CEBEFB	8364 073007	VYACHESLAV OSIPOV	{"email": "osipov_vyacheslav-05021969@postgrespro.ru", "phone": "+70370292591"}
0005435508507	CEBEFB	9649 503739	SERGEY ILIN	{"email": "ilinsergey.1978@postgrespro.ru", "phone": "+70200648700"}
0005435508508	CEBEFB	1758 458741	GALINA NAUMOVA	{"phone": "+70629989535"}
0005435508509	15D0CC	1295 221924	YURIY DMITRIEV	{"email": "dmitrievyuriy_21031986@postgrespro.ru", "phone": "+70477841791"}
0005435508510	802247	8369 894834	VLADIMIR IVANOV	{"email": "ivanovvladimir-061971@postgrespro.ru", "phone": "+70677951230"}
0005435508511	CAAA7A	0840 547461	LIDIYA GERASIMOVA	{"phone": "+70417812240"}
0005435508512	83E227	8204 543284	VITALIY SHEVCHENKO	{"phone": "+70742115536"}
0005435508513	8221E3	3135 644523	OLGA KOMAROVA	{"phone": "+70221646861"}
0005435508514	A7A164	6238 724963	VALENTIN SAVELEV	{"email": "valentin_savelev1971@postgrespro.ru", "phone": "+70375178978"}
0005435508515	6D6590	3316 844462	VALENTINA LUKYANOVA	{"phone": "+70630987388"}
0005435508516	6D6590	9075 014732	IRINA KUZMINA	{"email": "irina_kuzmina1965@postgrespro.ru", "phone": "+70060563717"}
0005435508517	753BAB	8880 885013	NIKOLAY KOROLEV	{"email": "n.korolev.021962@postgrespro.ru", "phone": "+70740746458"}
0005435508518	753BAB	3539 530936	TAMARA RODIONOVA	{"email": "rodionova-t-021978@postgrespro.ru", "phone": "+70144442551"}
0005435508519	E01845	7183 141452	YULIYA FROLOVA	{"email": "frolovay_1979@postgrespro.ru", "phone": "+70920831766"}
0005435508520	3C156E	5220 774885	OLGA IVANOVA	{"phone": "+70642105779"}
0005435508521	CA67B8	5942 286362	VLADIMIR NIKOLAEV	{"phone": "+70240913915"}
0005435508522	4E0DA7	0560 450376	GLEB KAZAKOV	{"phone": "+70187042619"}
0005435508523	4E0DA7	1246 788442	KSENIYA POPOVA	{"email": "popova_kseniya-05101983@postgrespro.ru", "phone": "+70268272978"}
0005435508524	A35D9E	1129 850986	ARMEN POPOV	{"phone": "+70303407190"}
0005435508525	A4961C	5441 790328	ANNA MIRONOVA	{"phone": "+70515018640"}
0005435508526	8303E6	8004 782865	ANDREY VASILEV	{"phone": "+70110001439"}
0005435508527	872A9B	5592 999212	ANATOLIY AFANASEV	{"email": "afanasevanatoliy.031972@postgrespro.ru", "phone": "+70886942118"}
0005435508528	872A9B	3952 682583	GALINA FOMINA	{"email": "fomina_galina.081976@postgrespro.ru", "phone": "+70170706325"}
0005435508529	872A9B	6746 559667	RAFIS IVANOV	{"email": "ivanov_r-111973@postgrespro.ru", "phone": "+70008932525"}
0005435508530	FE8DC9	5527 818708	OLGA DAVYDOVA	{"phone": "+70420036784"}
0005435508531	FE8DC9	6901 842267	OLGA ANISIMOVA	{"email": "anisimova-olga_13091976@postgrespro.ru", "phone": "+70068823035"}
0005435508532	291D9B	2361 527772	RADIK MIRONOV	{"email": "radikmironov1965@postgrespro.ru", "phone": "+70443759228"}
0005435508533	291D9B	2193 619027	VALERIY FILIPPOV	{"phone": "+70924398918"}
0005435508534	4B39C7	1998 433369	ELENA FEDOROVA	{"email": "fedorova-e.15011985@postgrespro.ru", "phone": "+70525662055"}
0005435508535	4493DA	2689 954216	YULIYA KOZLOVA	{"email": "kozlova_y-1982@postgrespro.ru", "phone": "+70122915102"}
0005435508536	4493DA	3912 626351	VIKTOR ZAKHAROV	{"phone": "+70420453583"}
0005435508537	472890	5155 114101	TATYANA IVANOVA	{"phone": "+70751463995"}
0005435508538	36AACD	0765 613781	ANDREY SAVELEV	{"phone": "+70501820878"}
0005435508539	36AACD	5703 157607	VALERIY ZAYCEV	{"phone": "+70767969028"}
0005435508540	C1AE02	2579 126292	ANATOLIY ZHUKOV	{"phone": "+70611628926"}
0005435508541	C1AE02	1917 786399	DMITRIY NAUMOV	{"phone": "+70701324962"}
0005435508542	AB2F2F	5323 848618	KONSTANTIN ANDREEV	{"email": "andreev.konstantin-1973@postgrespro.ru", "phone": "+70279066519"}
0005435508543	AF1DD4	0089 751636	VALENTINA KONOVALOVA	{"phone": "+70742579201"}
0005435508544	AF1DD4	2536 342651	ALEKSANDR FOMIN	{"email": "a.fomin-12051985@postgrespro.ru", "phone": "+70387677674"}
0005435508545	15DAEC	7576 898487	ELIZAVETA SMIRNOVA	{"email": "esmirnova-1970@postgrespro.ru", "phone": "+70144313969"}
0005435508546	5087D7	1145 710099	KLAVDIYA SAVELEVA	{"phone": "+70455141836"}
0005435508547	5087D7	3334 272117	VLADIMIR IVANOV	{"phone": "+70861790917"}
0005435508548	56A17F	1592 336364	SERGEY KULIKOV	{"email": "kulikov_sergey-02051972@postgrespro.ru", "phone": "+70187388097"}
0005435508549	7D6840	7525 877954	ANASTASIYA ZAYCEVA	{"email": "anastasiya.zayceva-1973@postgrespro.ru", "phone": "+70101944297"}
0005435508550	EDCC87	7105 913063	DARYA IVANOVA	{"phone": "+70754403917"}
0005435508551	F3787F	3342 371765	EVGENIYA DMITRIEVA	{"email": "evgeniya-dmitrieva.061971@postgrespro.ru", "phone": "+70124890470"}
0005435508552	3EA1BC	8909 533690	VALERIYA FEDOROVA	{"phone": "+70565556164"}
0005435508553	1A8BC3	6693 746304	MARGARITA DAVYDOVA	{"phone": "+70274936891"}
0005435508554	1A8BC3	6558 822551	MATVEY IVANOV	{"email": "m.ivanov011976@postgrespro.ru", "phone": "+70461597985"}
0005435508555	8C531F	1566 432664	TAMARA TIKHONOVA	{"phone": "+70819556801"}
0005435508556	284C4B	7080 535189	LARISA MAKAROVA	{"email": "lmakarova-041976@postgrespro.ru", "phone": "+70338849695"}
0005435508557	284C4B	3159 311768	ALEKSANDR FOMIN	{"phone": "+70987832657"}
0005435508558	B821A0	9815 315385	ELENA MELNIKOVA	{"email": "e.melnikova.1969@postgrespro.ru", "phone": "+70131201025"}
0005435508559	9B34F6	1599 741936	LYUDMILA MAKAROVA	{"email": "l.makarova23041975@postgrespro.ru", "phone": "+70969579058"}
0005435508560	9B34F6	3898 714279	NATALYA ZHUKOVA	{"email": "n.zhukova.13111965@postgrespro.ru", "phone": "+70739525231"}
0005435508561	CC236B	6289 408329	EVGENIYA STEPANOVA	{"email": "evgeniya-stepanova_111977@postgrespro.ru", "phone": "+70241562748"}
0005435508562	356FBE	8361 459798	SERGEY PETROV	{"phone": "+70065736814"}
0005435508563	356FBE	3006 389992	RAFIK ISAEV	{"email": "isaev.rafik1986@postgrespro.ru", "phone": "+70021286795"}
0005435508564	08EC87	5091 401208	VIKTORIYA STEPANOVA	{"phone": "+70510134319"}
0005435508565	08EC87	2658 493175	VALENTINA SOLOVEVA	{"email": "valentina-soloveva1964@postgrespro.ru", "phone": "+70369141516"}
0005435508566	C58EF3	3536 316770	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoaleksandr_1976@postgrespro.ru", "phone": "+70643989786"}
0005435508567	79376E	6499 785357	ELENA MOROZOVA	{"email": "morozova_elena051974@postgrespro.ru", "phone": "+70512609707"}
0005435508568	DC3442	1889 570337	EKATERINA KOZLOVA	{"email": "kozlova-ekaterina.1971@postgrespro.ru", "phone": "+70211421948"}
0005435508569	DC3442	1359 767288	NINA VASILEVA	{"email": "nina_vasileva1973@postgrespro.ru", "phone": "+70119925148"}
0005435508570	19BC8D	9319 500280	GERMAN EGOROV	{"email": "egorov.g.24091979@postgrespro.ru", "phone": "+70312473780"}
0005435508571	19BC8D	3348 018614	ANNA FOMINA	{"email": "anna-fomina_1970@postgrespro.ru", "phone": "+70886419289"}
0005435508572	24A31B	5642 379366	ARTEM KULIKOV	{"email": "artem-kulikov_121967@postgrespro.ru", "phone": "+70445569656"}
0005435508573	08425B	4465 992389	SVETLANA SEMENOVA	{"phone": "+70655826754"}
0005435508574	154185	7229 529292	ALEKSANDR DENISOV	{"email": "aleksandrdenisov.031974@postgrespro.ru", "phone": "+70876212664"}
0005435508575	19D9B7	5365 207634	LYUDMILA ZAKHAROVA	{"email": "l_zakharova_081972@postgrespro.ru", "phone": "+70408876510"}
0005435508576	EBA17C	6313 895018	VERONIKA ANISIMOVA	{"phone": "+70028024888"}
0005435508577	3A160F	9442 555358	TATYANA SEMENOVA	{"email": "tatyana.semenova.031976@postgrespro.ru", "phone": "+70430905340"}
0005435508578	E738E2	3874 736917	DMITRIY KOROLEV	{"email": "korolev_dmitriy.1956@postgrespro.ru", "phone": "+70332760962"}
0005435508579	96B292	7836 723219	MIKHAIL KUZMIN	{"phone": "+70778791024"}
0005435508580	75C9FE	2577 379092	TATYANA NIKOLAEVA	{"email": "t-nikolaeva-1982@postgrespro.ru", "phone": "+70550928445"}
0005435508581	2B8DCF	1413 850086	ANNA KAZAKOVA	{"email": "kazakova.anna051974@postgrespro.ru", "phone": "+70875164325"}
0005435508582	2B8DCF	6076 880810	IRINA KARPOVA	{"email": "karpovai-26061964@postgrespro.ru", "phone": "+70159352825"}
0005435508583	B1E1F1	4502 676568	ARTEM ZAKHAROV	{"phone": "+70320790536"}
0005435508584	1EA73E	1456 861578	MARIYA MOISEEVA	{"phone": "+70257312081"}
0005435508585	BF69D1	9152 493397	IRINA KUZNECOVA	{"email": "irina.kuznecova-18091971@postgrespro.ru", "phone": "+70730915591"}
0005435508586	BF69D1	7179 050669	ALEKSANDR BELOV	{"email": "belov.a-10081959@postgrespro.ru", "phone": "+70311997019"}
0005435508587	B49C54	3748 154486	ANDREY FEDOROV	{"phone": "+70385281417"}
0005435508588	1BE706	6795 221926	GALINA SOLOVEVA	{"email": "g-soloveva-081973@postgrespro.ru", "phone": "+70470669606"}
0005435508589	A3164A	5114 512667	ANASTASIYA POPOVA	{"email": "popova_a.26111971@postgrespro.ru", "phone": "+70893067380"}
0005435508590	FB6235	4654 451754	DARYA RODIONOVA	{"email": "rodionovadarya1972@postgrespro.ru", "phone": "+70399274623"}
0005435508591	B452B8	9835 267242	SVETLANA OSIPOVA	{"phone": "+70571939758"}
0005435508592	F2D68B	3708 754648	ANDREY ZHURAVLEV	{"phone": "+70519176328"}
0005435508593	2F63B3	8258 781701	VALERIY GRIGOREV	{"email": "grigorev.v_1979@postgrespro.ru", "phone": "+70473019160"}
0005435508594	2F63B3	9018 389941	SVETLANA KOZLOVA	{"phone": "+70645738187"}
0005435508595	2F63B3	6311 365306	SERGEY KOROLEV	{"phone": "+70061027338"}
0005435508596	5C5FE8	0082 072298	ALEKSANDR GORBUNOV	{"email": "a_gorbunov.14081975@postgrespro.ru", "phone": "+70551616466"}
0005435508597	5C5FE8	1398 711696	SERGEY SOLOVEV	{"phone": "+70089380478"}
0005435508598	3BBE00	2321 641668	IRINA MALYSHEVA	{"phone": "+70632299753"}
0005435508599	7B4AFD	0853 705452	EMMA FEDOROVA	{"email": "fedorovae-1965@postgrespro.ru", "phone": "+70926224134"}
0005435508600	EAA67E	4525 346367	YURIY ILIN	{"email": "ilin_y_121961@postgrespro.ru", "phone": "+70005344459"}
0005435508601	F6EC65	1989 696926	ALEKSANDR ROMANOV	{"phone": "+70618240206"}
0005435508602	54B5EF	4627 875054	GALINA ZAKHAROVA	{"email": "zakharova.galina.19121968@postgrespro.ru", "phone": "+70179423904"}
0005435508603	7E962A	0800 798800	MARIYA YAKOVLEVA	{"phone": "+70823374714"}
0005435508604	3B3B72	4179 009993	OLGA ZOTOVA	{"phone": "+70591823974"}
0005435508605	F0B82D	9385 092311	ALEKSEY SCHERBAKOV	{"phone": "+70145178036"}
0005435508606	564B00	1779 128924	VALERIY VASILEV	{"email": "valeriy_vasilev_011973@postgrespro.ru", "phone": "+70041900694"}
0005435508607	564B00	2745 362786	ALEKSANDR BARANOV	{"email": "aleksandr_baranov.121975@postgrespro.ru", "phone": "+70621889286"}
0005435508608	CE60F1	9919 868897	ALEKSEY EGOROV	{"phone": "+70697711934"}
0005435508609	486DF0	8112 938278	IGOR PETROV	{"email": "i-petrov071969@postgrespro.ru", "phone": "+70841500029"}
0005435508610	3EEA39	7927 038373	DENIS RODIONOV	{"email": "denis_rodionov.10121968@postgrespro.ru", "phone": "+70260615029"}
0005435508611	37987F	0286 270984	SERGEY ZHUKOV	{"phone": "+70720072953"}
0005435508612	37987F	4153 800063	ALEKSANDR KAZAKOV	{"phone": "+70001906885"}
0005435508613	37987F	1323 742362	EKATERINA TIKHONOVA	{"email": "tikhonova_ekaterina-1965@postgrespro.ru", "phone": "+70799172120"}
0005435508614	C7EC67	3001 282595	YURIY GERASIMOV	{"phone": "+70378501780"}
0005435508615	4A915E	5516 360990	ARTUR BARANOV	{"email": "baranov-artur041968@postgrespro.ru", "phone": "+70195380202"}
0005435508616	B7F2EB	4524 836467	ANASTASIYA TIMOFEEVA	{"phone": "+70552713810"}
0005435508617	B7F2EB	7165 712895	VLADIMIR SERGEEV	{"email": "sergeev-vladimir_061979@postgrespro.ru", "phone": "+70757308604"}
0005435508618	EDB4E4	5339 038270	MARIYA IVANOVA	{"phone": "+70767347717"}
0005435508619	EDB4E4	2956 183231	EKATERINA BELYAEVA	{"email": "e_belyaeva.1971@postgrespro.ru", "phone": "+70467131059"}
0005435508620	D5EEB4	3405 281803	NIKOLAY ALEKSEEV	{"phone": "+70932987080"}
0005435508621	D5EEB4	1703 096895	SERGEY BARANOV	{"email": "s_baranov101977@postgrespro.ru", "phone": "+70802251205"}
0005435508622	EE5165	1818 878491	VADIM IVANOV	{"email": "vadim.ivanov.1977@postgrespro.ru", "phone": "+70331660709"}
0005435508623	0B5A3F	4600 402367	GALINA ZHURAVLEVA	{"email": "zhuravleva.g1972@postgrespro.ru", "phone": "+70234276304"}
0005435508624	6A3757	8273 818695	EVGENIY BORISOV	{"email": "borisov_e_011980@postgrespro.ru", "phone": "+70638664337"}
0005435508625	F9B187	8441 672743	VLADIMIR ANTONOV	{"email": "vladimir-antonov-1965@postgrespro.ru", "phone": "+70210331190"}
0005435508626	F9B187	6945 493507	TATYANA EGOROVA	{"phone": "+70666043967"}
0005435508627	0F6810	7251 535967	ALEKSANDR KUZNECOV	{"email": "akuznecov-09111970@postgrespro.ru", "phone": "+70556549357"}
0005435508628	0F6810	7300 720302	LIDIYA OVCHINNIKOVA	{"email": "ovchinnikoval_1969@postgrespro.ru", "phone": "+70998648809"}
0005435508629	6B428B	9759 130305	OLGA NOVIKOVA	{"phone": "+70015949042"}
0005435508630	50C267	7853 741665	GENNADIY MOROZOV	{"email": "gennadiymorozov-101977@postgrespro.ru", "phone": "+70675626403"}
0005435508631	7440D1	7022 677032	ZINAIDA PAVLOVA	{"email": "zpavlova_011966@postgrespro.ru", "phone": "+70053689840"}
0005435508632	8EA7C3	8330 596030	VERA BELYAEVA	{"phone": "+70720826020"}
0005435508633	C6AADD	7496 762473	SHAMIL MELNIKOV	{"email": "melnikov-shamil-28101973@postgrespro.ru", "phone": "+70313461943"}
0005435508634	E024BC	6612 255610	NATALYA RODIONOVA	{"email": "n_rodionova_29121976@postgrespro.ru", "phone": "+70093706802"}
0005435508635	23106B	5289 123342	VITALIY FOMIN	{"email": "v.fomin_1971@postgrespro.ru", "phone": "+70375379981"}
0005435508636	53B90A	3445 550563	VLADIMIR IVANOV	{"email": "ivanov-v.30031970@postgrespro.ru", "phone": "+70888415916"}
0005435508637	170C02	0636 522471	VITALIY KUZNECOV	{"email": "v.kuznecov30101975@postgrespro.ru", "phone": "+70227564431"}
0005435508638	A57C3C	9071 931928	SERGEY KAZAKOV	{"phone": "+70832318716"}
0005435508639	A57C3C	2361 147720	YANA STEPANOVA	{"phone": "+70461440603"}
0005435508640	A57C3C	5293 648777	OKSANA MAKAROVA	{"email": "makarova_o13031975@postgrespro.ru", "phone": "+70920320092"}
0005435508641	E0B602	0441 449282	ALEKSANDR POPOV	{"email": "apopov12101979@postgrespro.ru", "phone": "+70213967085"}
0005435508642	500F7F	6811 083897	OLEG BONDARENKO	{"email": "bondarenko_oleg.031982@postgrespro.ru", "phone": "+70751080139"}
0005435508643	D479C6	2119 612297	RINAT SEMENOV	{"email": "r-semenov25031972@postgrespro.ru", "phone": "+70061024703"}
0005435508644	D479C6	2749 566986	IRINA DMITRIEVA	{"email": "dmitrievairina16071979@postgrespro.ru", "phone": "+70201236683"}
0005435508645	1EE93F	1947 223717	ANASTASIYA MIRONOVA	{"phone": "+70894659560"}
0005435508646	1EE93F	8062 442284	ALEKSANDR MIKHAYLOV	{"email": "mikhaylov-aleksandr-24041981@postgrespro.ru", "phone": "+70314429698"}
0005435508647	5061A6	1721 837317	ANTON SEMENOV	{"phone": "+70345320927"}
0005435508648	5061A6	9824 207563	DMITRIY ZAKHAROV	{"phone": "+70532843872"}
0005435508649	E8D519	5402 156762	ANATOLIY IVANOV	{"email": "ivanov_anatoliy_26091974@postgrespro.ru", "phone": "+70427586937"}
0005435508650	C7A223	6988 341654	IRINA STEPANOVA	{"email": "i.stepanova_1975@postgrespro.ru", "phone": "+70693172521"}
0005435508651	3E35C3	2325 123033	NIKITA MELNIKOV	{"email": "nikita-melnikov.061976@postgrespro.ru", "phone": "+70586355808"}
0005435508652	9EF279	4128 285520	ELENA MALYSHEVA	{"email": "malysheva.elena_051967@postgrespro.ru", "phone": "+70335928582"}
0005435508653	F7F5A4	7016 663135	EVGENIYA ZAYCEVA	{"phone": "+70874239333"}
0005435508654	78B6F5	5082 693610	MATRENA KOVALEVA	{"phone": "+70672403770"}
0005435508655	78B6F5	8345 475944	ALEKSANDR KULIKOV	{"phone": "+70842855731"}
0005435508656	2E02A3	8086 943130	STANISLAV TARASOV	{"email": "s_tarasov111978@postgrespro.ru", "phone": "+70249658434"}
0005435508657	2E02A3	0629 674034	VYACHESLAV SOLOVEV	{"email": "vyacheslavsolovev1978@postgrespro.ru", "phone": "+70948762915"}
0005435508658	2E02A3	1297 383755	EKATERINA KOLESNIKOVA	{"email": "ekaterina-kolesnikova1976@postgrespro.ru", "phone": "+70577255443"}
0005435508659	6AAACD	3772 814272	DMITRIY SOROKIN	{"phone": "+70755589330"}
0005435508660	6C6195	4666 941175	ANATOLIY DMITRIEV	{"email": "dmitrieva.041981@postgrespro.ru", "phone": "+70752209464"}
0005435508661	27A66A	1385 691444	IGOR KUZNECOV	{"email": "igor-kuznecov_1980@postgrespro.ru", "phone": "+70971263424"}
0005435508662	23F902	8832 310255	TAMARA STEPANOVA	{"email": "tamara_stepanova-021974@postgrespro.ru", "phone": "+70840351416"}
0005435508663	23F902	5710 293516	TATYANA MAKSIMOVA	{"email": "tmaksimova-1979@postgrespro.ru", "phone": "+70159757743"}
0005435508664	C82DFB	4566 758060	NATALYA GORBUNOVA	{"phone": "+70876563575"}
0005435508665	130FEA	4831 829103	ALEKSANDR MIRONOV	{"email": "mironov-aleksandr1970@postgrespro.ru", "phone": "+70603181377"}
0005435508666	130FEA	5527 372906	ALBINA KAZAKOVA	{"phone": "+70164367752"}
0005435508667	FA227C	7896 717246	OLGA VASILEVA	{"phone": "+70357800017"}
0005435508668	D31D80	6274 479388	NADEZHDA KOVALEVA	{"email": "nkovaleva.03031984@postgrespro.ru", "phone": "+70207171472"}
0005435508669	D31D80	8096 476799	NADEZHDA KONOVALOVA	{"email": "konovalova_nadezhda-09081964@postgrespro.ru", "phone": "+70473389713"}
0005435508670	4CD504	7127 502409	DMITRIY IVANOV	{"email": "dmitriyivanov06101961@postgrespro.ru", "phone": "+70877999003"}
0005435508671	4CD504	0920 382669	ALIYA SMIRNOVA	{"phone": "+70575142285"}
0005435508672	12830F	9875 073177	LEONID ZHUKOV	{"phone": "+70270864570"}
0005435508673	B44D54	1415 645446	NADEZHDA AFANASEVA	{"phone": "+70322184143"}
0005435508674	90EF97	7940 424782	ALEKSEY SOKOLOV	{"email": "a.sokolov04121971@postgrespro.ru", "phone": "+70366899469"}
0005435508675	90EF97	4631 110022	TATYANA POTAPOVA	{"phone": "+70924660288"}
0005435508676	21E1CE	4794 511319	ELENA EFIMOVA	{"email": "efimovaelena.1978@postgrespro.ru", "phone": "+70521111223"}
0005435508677	21E1CE	8502 765341	PAVEL MAKAROV	{"phone": "+70654061040"}
0005435508678	A46B4F	9398 953579	VIKTORIYA KOMAROVA	{"email": "komarova-viktoriya.071965@postgrespro.ru", "phone": "+70873236127"}
0005435508679	62FF28	0780 130770	EVELINA KOZLOVA	{"email": "e-kozlova-1959@postgrespro.ru", "phone": "+70256368939"}
0005435508680	62FF28	0746 680917	VYACHESLAV BONDARENKO	{"phone": "+70832386097"}
0005435508681	5D979D	8264 882358	ELENA MEDVEDEVA	{"phone": "+70510774117"}
0005435508682	5D979D	2507 082493	ALEKSEY ABRAMOV	{"phone": "+70021823730"}
0005435508683	5D979D	9052 437880	ZHANNA STEPANOVA	{"email": "stepanovazhanna101973@postgrespro.ru", "phone": "+70368878624"}
0005435508684	333C15	8781 764756	ALEKSEY ANDREEV	{"phone": "+70033384993"}
0005435508685	333C15	0028 907386	GENNADIY KUZNECOV	{"email": "gennadiy.kuznecov-1976@postgrespro.ru", "phone": "+70244548670"}
0005435508686	41A259	0219 018452	NIKITA IVANOV	{"phone": "+70679490566"}
0005435508687	41A259	4870 320359	ANDREY GUSEV	{"phone": "+70374498677"}
0005435508688	41A259	6733 418118	VLADIMIR KISELEV	{"email": "vkiselev-1966@postgrespro.ru", "phone": "+70410158991"}
0005435508689	03AD56	4581 732175	PAVEL OSIPOV	{"phone": "+70750748107"}
0005435508690	D4392C	7494 390273	ANTONINA GORBUNOVA	{"phone": "+70791612943"}
0005435508691	4B5D42	6958 468746	TATYANA KRASNOVA	{"phone": "+70089707771"}
0005435508692	4A471C	8123 281791	YULIYA KUZMINA	{"email": "kuzmina-y_14081976@postgrespro.ru", "phone": "+70064957172"}
0005435508693	E8C299	0048 885603	ALEKSANDRA TITOVA	{"email": "aleksandra_titova_031974@postgrespro.ru", "phone": "+70456507899"}
0005435508694	967BF0	7495 341400	OLEG MELNIKOV	{"phone": "+70411472415"}
0005435508695	2A4DC7	9186 557411	ANDREY STEPANOV	{"phone": "+70548584466"}
0005435508751	4003A5	7540 119683	VLADIMIR MAKSIMOV	{"phone": "+70536376898"}
0005435508696	4A2528	4141 346960	VERA BELOVA	{"email": "v-belova-11071972@postgrespro.ru", "phone": "+70785081036"}
0005435508697	CC5332	6453 952009	VIKTORIYA FEDOROVA	{"phone": "+70203990328"}
0005435508698	E3EEEB	0851 152142	KLAVDIYA VOLKOVA	{"email": "klavdiya_volkova-091965@postgrespro.ru", "phone": "+70613289711"}
0005435508699	E3EEEB	8290 309726	VALENTINA NOVIKOVA	{"email": "novikova.valentina031968@postgrespro.ru", "phone": "+70671881755"}
0005435508700	B881AB	4564 325092	ELENA KOVALEVA	{"email": "elena.kovaleva_1984@postgrespro.ru", "phone": "+70235062667"}
0005435508701	B881AB	3759 712678	LILIYA MARTYNOVA	{"email": "martynova.liliya-1969@postgrespro.ru", "phone": "+70888020501"}
0005435508702	3B00D9	3531 707164	NATALYA ZAKHAROVA	{"phone": "+70250137735"}
0005435508703	71CA3C	0999 939183	LYUBOV IVANOVA	{"phone": "+70756134305"}
0005435508704	4A48A3	1993 275276	RITA FADEEVA	{"phone": "+70150806661"}
0005435508705	4A48A3	3564 521793	KAROLINA MIKHAYLOVA	{"email": "mikhaylova.k_041962@postgrespro.ru", "phone": "+70183541512"}
0005435508706	4A48A3	9346 451714	NIKOLAY FEDOROV	{"email": "nikolayfedorov.24021972@postgrespro.ru", "phone": "+70245789940"}
0005435508707	2F3982	7279 281898	OKSANA KONOVALOVA	{"email": "konovalova-o_15101974@postgrespro.ru", "phone": "+70924208858"}
0005435508708	4CAED5	2915 121207	KONSTANTIN VASILEV	{"email": "k.vasilev.18071978@postgrespro.ru", "phone": "+70520759042"}
0005435508709	78AA1C	8819 167095	VIKTOR EGOROV	{"phone": "+70254650187"}
0005435508710	A5AAD5	6714 477572	OLGA NAZAROVA	{"email": "o_nazarova.051966@postgrespro.ru", "phone": "+70637992671"}
0005435508711	6292A5	9029 454291	MARGARITA ZAKHAROVA	{"email": "mzakharova-1979@postgrespro.ru", "phone": "+70482085046"}
0005435508712	6292A5	7997 086183	IVAN KUDRYASHOV	{"email": "kudryashov_i1972@postgrespro.ru", "phone": "+70410600730"}
0005435508713	1D663D	1353 577806	ANATOLIY KUZNECOV	{"phone": "+70678854711"}
0005435508714	1D663D	9928 809244	SOFIYA ZAKHAROVA	{"email": "zakharovasofiya-26061978@postgrespro.ru", "phone": "+70924446330"}
0005435508715	1D663D	3267 030620	IGOR STEPANOV	{"phone": "+70142432698"}
0005435508716	2B574D	3438 751531	ELIZAVETA KAZAKOVA	{"email": "kazakova_elizaveta30041957@postgrespro.ru", "phone": "+70300158108"}
0005435508717	2B574D	6681 771512	IRINA NAZAROVA	{"phone": "+70523024939"}
0005435508718	EB786B	7018 723192	ARTUR DMITRIEV	{"email": "dmitriev_artur-15021980@postgrespro.ru", "phone": "+70704882549"}
0005435508719	CBD0C8	4096 455566	RAMIL FROLOV	{"email": "rfrolov-21021972@postgrespro.ru", "phone": "+70248802033"}
0005435508720	E4E695	8570 002310	ALEKSANDR MIRONOV	{"phone": "+70307036956"}
0005435508721	E4E695	1451 420889	IRINA NAZAROVA	{"email": "irina.nazarova-22101970@postgrespro.ru", "phone": "+70890363323"}
0005435508722	8D6557	0156 764793	MARINA KUZMINA	{"phone": "+70857924760"}
0005435508723	B9A792	5232 078065	OKSANA MALYSHEVA	{"email": "malysheva-oksana_081972@postgrespro.ru", "phone": "+70919305366"}
0005435508724	B9A792	2668 280150	SVETLANA TIMOFEEVA	{"phone": "+70171892269"}
0005435508725	6ED910	9695 592925	TATYANA PETROVA	{"email": "petrova_t.061972@postgrespro.ru", "phone": "+70103828775"}
0005435508726	8A3596	7762 008064	VLADIMIR PAVLOV	{"phone": "+70955273832"}
0005435508727	8A3596	1759 508112	ELENA NESTEROVA	{"phone": "+70602400072"}
0005435508728	62C2A1	0749 036036	ROMAN SIDOROV	{"email": "roman_sidorov.18021976@postgrespro.ru", "phone": "+70447380552"}
0005435508729	418A88	3922 205582	MIKHAIL SAVELEV	{"email": "m-savelev-1981@postgrespro.ru", "phone": "+70748548371"}
0005435508730	698C02	2259 384786	VYACHESLAV SOKOLOV	{"phone": "+70307426928"}
0005435508731	5D7853	8340 481521	OLGA MELNIKOVA	{"phone": "+70920475874"}
0005435508732	E6963E	2377 154474	NADEZHDA GORBUNOVA	{"email": "gorbunovanadezhda_1982@postgrespro.ru", "phone": "+70139937319"}
0005435508733	5ADD40	1159 712127	VLADIMIR MOISEEV	{"email": "moiseev.v.25071979@postgrespro.ru", "phone": "+70338815859"}
0005435508734	254F32	9638 006978	MARIYA IVANOVA	{"email": "mivanova.051976@postgrespro.ru", "phone": "+70767236555"}
0005435508735	DEF7C4	9192 733997	VLADIMIR SOLOVEV	{"email": "solovevvladimir_061979@postgrespro.ru", "phone": "+70611058028"}
0005435508736	BCEC16	9340 408859	ELENA MOISEEVA	{"phone": "+70446828568"}
0005435508737	BCEC16	1393 737755	VIKTORIYA PAVLOVA	{"phone": "+70164198779"}
0005435508738	172929	5041 567415	ALLA BELYAEVA	{"phone": "+70117188665"}
0005435508739	172929	7366 855212	ALEKSANDR SCHERBAKOV	{"email": "scherbakova_16101981@postgrespro.ru", "phone": "+70923530322"}
0005435508740	7E0424	9368 779826	ELENA ZAYCEVA	{"email": "zayceva_e07021984@postgrespro.ru", "phone": "+70480501224"}
0005435508741	103891	8170 112228	VITALIY DMITRIEV	{"email": "dmitriev-vitaliy-051979@postgrespro.ru", "phone": "+70449866363"}
0005435508742	103891	8836 441351	VIKTOR MAKAROV	{"email": "viktor_makarov.061977@postgrespro.ru", "phone": "+70546641052"}
0005435508743	D6A569	4611 363381	VALENTINA OSIPOVA	{"email": "v.osipova_1963@postgrespro.ru", "phone": "+70541898923"}
0005435508744	406BF0	5660 858743	MARINA PETROVA	{"phone": "+70978917393"}
0005435508745	0F4325	9010 891874	MARIYA SERGEEVA	{"phone": "+70737378840"}
0005435508746	3D38A3	6605 265267	SERGEY EGOROV	{"email": "egorovsergey.1979@postgrespro.ru", "phone": "+70971586702"}
0005435508747	3D38A3	6048 734942	ANATOLIY FEDOTOV	{"email": "a.fedotov_1963@postgrespro.ru", "phone": "+70086419017"}
0005435508748	49E443	7388 082060	VIKTOR MELNIKOV	{"email": "melnikov.v19121968@postgrespro.ru", "phone": "+70001702799"}
0005435508749	49E443	2228 532505	MIKHAIL MIKHAYLOV	{"phone": "+70267996608"}
0005435508750	9DDBB2	9206 336402	DIANA SMIRNOVA	{"email": "dsmirnova_02121974@postgrespro.ru", "phone": "+70590895763"}
0005435508752	AF9FF3	6594 423732	KSENIYA CHERNOVA	{"phone": "+70673030006"}
0005435508753	AF9FF3	2490 827289	ELENA ORLOVA	{"phone": "+70156336056"}
0005435508754	AF9FF3	7290 745026	SERGEY ORLOV	{"phone": "+70993755009"}
0005435508755	05D84A	1590 681285	MATVEY CHERNOV	{"email": "m.chernov-02081980@postgrespro.ru", "phone": "+70780739993"}
0005435508756	05D84A	0508 326567	DMITRIY GERASIMOV	{"phone": "+70233202437"}
0005435508757	6B02BC	7467 832722	ELENA NIKITINA	{"email": "e-nikitina.1963@postgrespro.ru", "phone": "+70357592221"}
0005435508758	F2B084	9881 180114	NATALYA KUZNECOVA	{"phone": "+70281918516"}
0005435508759	F2B084	7975 505944	DARYA MOROZOVA	{"email": "morozova_darya_071988@postgrespro.ru", "phone": "+70446735640"}
0005435508760	F2B084	4966 814839	NATALYA KOROLEVA	{"phone": "+70608466239"}
0005435508761	F2B792	6932 809540	IVAN GUSEV	{"phone": "+70676230299"}
0005435508762	63D19B	6260 493227	VITALIY SEMENOV	{"phone": "+70137149685"}
0005435508763	ACA194	6437 503861	DMITRIY EGOROV	{"email": "egorov-dmitriy-1970@postgrespro.ru", "phone": "+70002286899"}
0005435508764	ACA194	8977 406077	RUSLAN FROLOV	{"email": "frolov.ruslan-051979@postgrespro.ru", "phone": "+70865475235"}
0005435508765	97D748	4642 500395	ALLA ZHURAVLEVA	{"email": "azhuravleva051988@postgrespro.ru", "phone": "+70851014203"}
0005435508766	8E6982	7280 328591	ALEKSANDR MATVEEV	{"email": "aleksandr-matveev25121962@postgrespro.ru", "phone": "+70437709039"}
0005435508767	5D4B50	6381 588976	SERGEY ALEKSEEV	{"phone": "+70126763311"}
0005435508768	5D4B50	8139 737442	VLADIMIR NIKOLAEV	{"email": "v.nikolaev-041964@postgrespro.ru", "phone": "+70947076986"}
0005435508769	458D72	8660 213496	NATALYA YUDINA	{"email": "yudina.n-081981@postgrespro.ru", "phone": "+70676580591"}
0005435508770	C29808	3837 210292	GENNADIY STEPANOV	{"email": "stepanov.gennadiy11021969@postgrespro.ru", "phone": "+70590282223"}
0005435508771	C29808	9641 360335	VIKTORIYA GERASIMOVA	{"email": "gerasimova_viktoriya.14121968@postgrespro.ru", "phone": "+70498868170"}
0005435508772	228132	8297 353061	ELENA SEMENOVA	{"email": "semenovae-101974@postgrespro.ru", "phone": "+70965273982"}
0005435508773	E9CCFB	6704 761471	TATYANA KOZLOVA	{"email": "kozlova_t-08051976@postgrespro.ru", "phone": "+70794391884"}
0005435508774	E9CCFB	2308 845741	IRINA BORISOVA	{"phone": "+70016162854"}
0005435508775	857773	7456 653080	OLGA SEMENOVA	{"phone": "+70863196480"}
0005435508776	857773	8171 014038	ALEKSANDR ORLOV	{"phone": "+70386865561"}
0005435508777	C2F87A	0901 243249	PAVEL VOROBEV	{"phone": "+70275214232"}
0005435508778	385C72	2657 339984	DANILA KUZNECOV	{"email": "kuznecov_danila.23051981@postgrespro.ru", "phone": "+70599536115"}
0005435508779	0BBA5A	8905 863882	OLGA STEPANOVA	{"phone": "+70204289975"}
0005435508780	006704	4987 524633	LARISA VOROBEVA	{"phone": "+70730135470"}
0005435508781	2702B9	9837 588318	SVETLANA FILIPPOVA	{"email": "filippova-s_1957@postgrespro.ru", "phone": "+70650933516"}
0005435508782	84BE49	8964 844395	EVGENIY SEMENOV	{"email": "e.semenov.23081974@postgrespro.ru", "phone": "+70606901707"}
0005435508783	98C0B8	0250 661773	VERONIKA POPOVA	{"phone": "+70677360599"}
0005435508784	98C0B8	7379 275894	VALERIY VASILEV	{"email": "vasilev_valeriy.1988@postgrespro.ru", "phone": "+70390467592"}
0005435508785	864A34	6678 618004	ALINA ILINA	{"phone": "+70391629863"}
0005435508786	400A03	1124 238764	DMITRIY KUZNECOV	{"email": "dkuznecov.121970@postgrespro.ru", "phone": "+70300041513"}
0005435508787	B1BA2A	2538 808725	IGOR ROMANOV	{"phone": "+70505345436"}
0005435508788	0BD0F1	1217 051917	VALERIY ZAKHAROV	{"phone": "+70079680725"}
0005435508789	318655	2229 416119	ILYA MIKHAYLOV	{"email": "mikhaylov-i-12061971@postgrespro.ru", "phone": "+70981475255"}
0005435508790	3DD54A	9375 267705	TATYANA CHERNOVA	{"email": "chernova.tatyana_101970@postgrespro.ru", "phone": "+70448174892"}
0005435508791	DDBB76	2424 945411	NATALYA POTAPOVA	{"email": "potapova.n.1974@postgrespro.ru", "phone": "+70496494897"}
0005435508792	54AA90	5277 729776	VALENTINA ALEKSANDROVA	{"email": "valentinaaleksandrova.1972@postgrespro.ru", "phone": "+70836702739"}
0005435508793	5ABAE3	5049 216601	ARTEM VASILEV	{"phone": "+70977418269"}
0005435508794	5ABAE3	7767 467080	EKATERINA KUZNECOVA	{"phone": "+70446446247"}
0005435508795	16DD7F	7083 697720	LYUDMILA KALININA	{"email": "kalinina.l17021977@postgrespro.ru", "phone": "+70624816743"}
0005435508796	16DD7F	1070 954437	VASILIY ANDREEV	{"email": "vandreev.10031960@postgrespro.ru", "phone": "+70544608009"}
0005435508797	16DD7F	3325 793215	VIKTORIYA FEDOROVA	{"email": "viktoriya-fedorova_1974@postgrespro.ru", "phone": "+70929157745"}
0005435508798	50EBB8	6685 155939	ANATOLIY VOLKOV	{"email": "a_volkov-061972@postgrespro.ru", "phone": "+70214917883"}
0005435508799	A68FD7	2351 684774	ALEKSEY KULIKOV	{"email": "kulikov.aleksey.041970@postgrespro.ru", "phone": "+70356483626"}
0005435508800	A68FD7	4936 454828	VALENTINA SMIRNOVA	{"email": "v-smirnova.18121975@postgrespro.ru", "phone": "+70058218348"}
0005435508801	2C1D34	8384 696513	NADEZHDA KUZNECOVA	{"phone": "+70542581981"}
0005435508802	C299C3	2408 052389	SERGEY SOKOLOV	{"email": "sokolov_s_03111970@postgrespro.ru", "phone": "+70303500796"}
0005435508803	C09AED	3151 886163	DANIL PETROV	{"email": "petrovd_041983@postgrespro.ru", "phone": "+70931561141"}
0005435508804	FD4C3D	8496 897404	NADEZHDA ANTONOVA	{"email": "antonovanadezhda.1977@postgrespro.ru", "phone": "+70657305293"}
0005435508805	9985EA	9150 682311	VALENTINA ANDREEVA	{"phone": "+70366697199"}
0005435508806	9985EA	7021 209490	ELEONORA RYABOVA	{"email": "eleonoraryabova_20051968@postgrespro.ru", "phone": "+70047414998"}
0005435508807	C30329	1283 986080	FARID ANTONOV	{"email": "farid-antonov-1957@postgrespro.ru", "phone": "+70500881998"}
0005435508808	0BD451	5833 350395	LYUBOV KONOVALOVA	{"phone": "+70170487468"}
0005435508809	293EBA	9498 027762	VIKTORIYA KUZNECOVA	{"phone": "+70609364932"}
0005435508810	293EBA	8455 818204	OLGA LOGINOVA	{"phone": "+70783593473"}
0005435508811	9B6004	5047 699876	ALEKSEY BELOV	{"phone": "+70118831098"}
0005435508812	88D72D	2987 371634	VARVARA KOROLEVA	{"email": "koroleva-varvara11071977@postgrespro.ru", "phone": "+70426645087"}
0005435508813	F17743	8818 786213	VLADIMIR SEMENOV	{"email": "semenov_v031980@postgrespro.ru", "phone": "+70040029847"}
0005435508814	073CE9	3191 413002	VYACHESLAV BORISOV	{"email": "vborisov-1963@postgrespro.ru", "phone": "+70117305690"}
0005435508815	EE7014	2479 198284	ROZA DMITRIEVA	{"email": "dmitrieva_r_1968@postgrespro.ru", "phone": "+70499352551"}
0005435508816	F6A5CA	0324 752942	VALERIY FEDOROV	{"phone": "+70656873578"}
0005435508817	F6A5CA	4682 798674	VIKTOR MOISEEV	{"phone": "+70317952388"}
0005435508818	A7FB73	0819 888053	VARVARA ABRAMOVA	{"email": "varvara-abramova1978@postgrespro.ru", "phone": "+70271726920"}
0005435508819	A7FB73	9408 526837	GALINA GORBUNOVA	{"email": "ggorbunova_1972@postgrespro.ru", "phone": "+70471991434"}
0005435508820	104D88	5983 513743	TAISIYA GORBUNOVA	{"phone": "+70433633300"}
0005435508821	A29B93	5464 730471	VALENTINA MATVEEVA	{"email": "valentina_matveeva_30011962@postgrespro.ru", "phone": "+70516804750"}
0005435508822	A29B93	0220 029080	IRINA KUZNECOVA	{"email": "kuznecova.i05101963@postgrespro.ru", "phone": "+70607574543"}
0005435508823	A29B93	9454 852141	VALENTIN KISELEV	{"phone": "+70536578464"}
0005435508824	A29B93	7388 429740	SERGEY OSIPOV	{"phone": "+70196157750"}
0005435508825	E838C5	6896 919803	SVETLANA ARKHIPOVA	{"email": "sarkhipova_011976@postgrespro.ru", "phone": "+70210817418"}
0005435508826	D889A6	4078 668691	MARIYA NIKIFOROVA	{"email": "m-nikiforova_1974@postgrespro.ru", "phone": "+70127279835"}
0005435508827	51DED0	0005 078494	ANNA POPOVA	{"email": "popova_anna.121977@postgrespro.ru", "phone": "+70387448065"}
0005435508828	CEA7E4	0673 159098	ALEKSEY FILIPPOV	{"email": "a_filippov_061972@postgrespro.ru", "phone": "+70758401055"}
0005435508829	249851	6856 658751	ALEKSANDR KUZNECOV	{"phone": "+70653811506"}
0005435508830	74DC45	2759 587733	VALENTINA TARASOVA	{"phone": "+70879619219"}
0005435508831	74DC45	4666 399522	NIKOLAY SOKOLOV	{"email": "n-sokolov-1968@postgrespro.ru", "phone": "+70023646020"}
0005435508832	7F00E3	4050 929508	ELENA STEPANOVA	{"phone": "+70412381320"}
0005435508833	986F74	5034 534998	ILDAR ZAKHAROV	{"phone": "+70035634511"}
0005435517585	41546B	0124 628481	EVGENIY MIKHAYLOV	{"email": "e_mikhaylov1973@postgrespro.ru", "phone": "+70307620567"}
0005435517586	13FAC8	3201 972774	SVETLANA BARANOVA	{"phone": "+70783264611"}
0005435517587	13FAC8	2158 854911	VLADIMIR FEDOROV	{"phone": "+70112715244"}
0005435517588	75A1EB	5060 272083	SERGEY EGOROV	{"phone": "+70199340743"}
0005435517589	9205AA	1998 429015	MARGARITA STEPANOVA	{"phone": "+70145524475"}
0005435517590	9205AA	6022 899176	KSENIYA NIKIFOROVA	{"email": "kseniya-nikiforova_041969@postgrespro.ru", "phone": "+70073419136"}
0005435517591	5C589B	0399 638082	MARK KUZNECOV	{"email": "mkuznecov29041960@postgrespro.ru", "phone": "+70971939046"}
0005435517592	3B4FEF	6508 663751	ARINA MATVEEVA	{"phone": "+70061486350"}
0005435517593	3B4FEF	0913 607030	MAKSIM SCHERBAKOV	{"email": "maksim-scherbakov.1982@postgrespro.ru", "phone": "+70679903853"}
0005435517594	631830	3232 416058	ELIZAVETA ALEKSANDROVA	{"phone": "+70264805302"}
0005435517595	8FCC21	6485 698312	MARINA IVANOVA	{"email": "m-ivanova-31051971@postgrespro.ru", "phone": "+70704005965"}
0005435517656	2578CC	7839 438225	RASHIT IVANOV	{"phone": "+70166023290"}
0005435517596	A3180C	3563 198581	VLADIMIR FOMIN	{"email": "fomin_v.071968@postgrespro.ru", "phone": "+70939737675"}
0005435517597	8184EF	6186 576232	YURIY AFANASEV	{"email": "y-afanasev21031980@postgrespro.ru", "phone": "+70921739791"}
0005435517598	17C323	6329 279922	SOFIYA KRASNOVA	{"email": "krasnova.s.1968@postgrespro.ru", "phone": "+70034174216"}
0005435517599	5D961E	1224 570616	IGOR NOVIKOV	{"phone": "+70699419934"}
0005435517600	5D961E	3291 043345	ANATOLIY GORBUNOV	{"phone": "+70628322263"}
0005435517601	5D961E	6254 901971	EVGENIY SIDOROV	{"email": "sidorovevgeniy_061970@postgrespro.ru", "phone": "+70286045832"}
0005435517602	472F2F	8003 399992	GENNADIY OSIPOV	{"email": "osipov-gennadiy_071963@postgrespro.ru", "phone": "+70107782062"}
0005435517603	472F2F	9030 618106	VASILIY KUDRYASHOV	{"email": "vkudryashov_16061978@postgrespro.ru", "phone": "+70488907929"}
0005435517604	CF14A3	4382 548094	LYUDMILA SERGEEVA	{"phone": "+70746673602"}
0005435517605	AEB202	3003 997086	ALINA NIKIFOROVA	{"email": "nikiforova-alina_1972@postgrespro.ru", "phone": "+70990194415"}
0005435517606	AEB202	9926 280090	ANASTASIYA KRASNOVA	{"email": "krasnova_a.1972@postgrespro.ru", "phone": "+70627606610"}
0005435517607	66551E	6782 185957	VIKTOR BORISOV	{"phone": "+70885114676"}
0005435517608	66551E	1688 833500	LIDIYA TIKHONOVA	{"phone": "+70668856750"}
0005435517609	B90E51	4519 626646	MARIYA MOROZOVA	{"email": "morozova_mariya041979@postgrespro.ru", "phone": "+70572564476"}
0005435517610	B90E51	3453 719822	ANATOLIY TIMOFEEV	{"email": "timofeev-a1970@postgrespro.ru", "phone": "+70318080747"}
0005435517611	126F1A	7903 329031	EKATERINA KOLESNIKOVA	{"email": "kolesnikova.ekaterina_22051974@postgrespro.ru", "phone": "+70349408684"}
0005435517612	0DB471	1317 225327	VIKTOR ILIN	{"email": "ilinv121976@postgrespro.ru", "phone": "+70888131094"}
0005435517613	009C62	0867 535986	MAGOMED SHEVCHENKO	{"phone": "+70743478096"}
0005435517614	1AFE1F	1479 365452	SERGEY AFANASEV	{"phone": "+70514234335"}
0005435517615	CAC0E2	9271 692100	DMITRIY MELNIKOV	{"email": "melnikov.d071975@postgrespro.ru", "phone": "+70272032809"}
0005435517616	3C9CD4	8923 192735	DMITRIY TIMOFEEV	{"phone": "+70961469878"}
0005435517617	0B934F	4156 745866	OKSANA NIKOLAEVA	{"email": "o_nikolaeva_24071962@postgrespro.ru", "phone": "+70279778767"}
0005435517618	50990D	3883 107417	NATALIYA GUSEVA	{"phone": "+70321116245"}
0005435517619	7DCFA2	6099 585628	IGOR ABRAMOV	{"email": "i_abramov.14081978@postgrespro.ru", "phone": "+70556315654"}
0005435517620	EA47EB	6666 953534	IRAIDA NESTEROVA	{"phone": "+70865851400"}
0005435517621	C365DE	1879 735168	MARIYA VASILEVA	{"email": "mariya_vasileva_03021962@postgrespro.ru", "phone": "+70464887693"}
0005435517622	06B136	2451 262965	MATVEY DAVYDOV	{"phone": "+70672426740"}
0005435517623	F77E96	4785 071337	MIKHAIL GORBUNOV	{"email": "mikhail_gorbunov1963@postgrespro.ru", "phone": "+70339408224"}
0005435517624	F77E96	8272 110412	OLGA ZAYCEVA	{"phone": "+70840935819"}
0005435517625	E2812B	1600 784316	ANASTASIYA NIKITINA	{"phone": "+70713617560"}
0005435517626	82CBDE	1734 275581	MIKHAIL TARASOV	{"phone": "+70079778420"}
0005435517627	472981	1878 484217	SVETLANA DANILOVA	{"phone": "+70092174209"}
0005435517628	424E3F	7838 292265	TATYANA AFANASEVA	{"email": "tatyanaafanaseva_091966@postgrespro.ru", "phone": "+70093179681"}
0005435517629	C2F6FA	4568 113154	YURIY KAZAKOV	{"phone": "+70991703390"}
0005435517630	50D36E	8564 000020	OLGA ROMANOVA	{"phone": "+70694725461"}
0005435517631	50D36E	0605 394652	ALEKSANDR TARASOV	{"phone": "+70041973842"}
0005435517632	5ABC3E	6780 571470	VLADIMIR SOROKIN	{"phone": "+70117776004"}
0005435517633	3CFBBB	5835 644231	IRINA POTAPOVA	{"email": "potapova.i-09061971@postgrespro.ru", "phone": "+70783506442"}
0005435517634	0BFC75	3601 433194	NATALIYA ZAYCEVA	{"email": "nataliya_zayceva.1976@postgrespro.ru", "phone": "+70752741970"}
0005435517635	BBD743	6065 793805	NATALYA VOLKOVA	{"email": "volkova_natalya_051982@postgrespro.ru", "phone": "+70358143067"}
0005435517636	A64B68	2192 246351	ELENA KUZNECOVA	{"phone": "+70886598336"}
0005435517637	5FCDAF	1494 761282	ALEKSEY MIRONOV	{"email": "amironov.10101969@postgrespro.ru", "phone": "+70987366968"}
0005435517638	D5AA7F	1982 220283	ALEKSANDR KULIKOV	{"phone": "+70568864005"}
0005435517639	D5AA7F	1345 690199	TATYANA KULIKOVA	{"email": "kulikovat021974@postgrespro.ru", "phone": "+70327871443"}
0005435517640	740427	3519 023342	IRINA SAVELEVA	{"email": "isaveleva081979@postgrespro.ru", "phone": "+70368203195"}
0005435517641	740427	0359 650740	ELENA RODIONOVA	{"phone": "+70512525273"}
0005435517642	FD587D	8956 666756	MARIYA ZHURAVLEVA	{"phone": "+70329551672"}
0005435517643	FD587D	5448 734011	NINA NIKITINA	{"phone": "+70921257648"}
0005435517644	EE318F	9406 540319	ZHANNA KUDRYASHOVA	{"phone": "+70019989340"}
0005435517645	EE318F	0118 645138	EKATERINA SAVELEVA	{"email": "ekaterinasaveleva-031973@postgrespro.ru", "phone": "+70324013568"}
0005435517646	C197CE	5619 454714	MIKHAIL GORBUNOV	{"email": "gorbunovmikhail_15111972@postgrespro.ru", "phone": "+70432403485"}
0005435517647	C197CE	9019 813123	ANDREY MATVEEV	{"email": "a.matveev_011964@postgrespro.ru", "phone": "+70554874926"}
0005435517648	C00D1A	0655 329393	ANASTASIYA EGOROVA	{"phone": "+70768489427"}
0005435517649	C00D1A	4524 757030	MARIYA VASILEVA	{"phone": "+70911779049"}
0005435517650	14AF40	0481 023740	ANNA FILATOVA	{"email": "anna-filatova26111974@postgrespro.ru", "phone": "+70370379368"}
0005435517651	14AF40	4768 021418	RUSLAN MAKAROV	{"phone": "+70152194089"}
0005435517652	9880AB	6433 328893	ANATOLIY ZHUKOV	{"email": "zhukova.031971@postgrespro.ru", "phone": "+70206305880"}
0005435517653	9880AB	4677 145604	IRINA KOROLEVA	{"email": "koroleva-i.111975@postgrespro.ru", "phone": "+70274069150"}
0005435517654	124F58	2454 311640	ANTON POPOV	{"phone": "+70308084731"}
0005435517655	124F58	4557 121347	KSENIYA POPOVA	{"phone": "+70054008714"}
0005435517657	2578CC	7325 123193	IVAN ANTONOV	{"phone": "+70636589135"}
0005435517658	4A51DB	4101 912897	TATYANA VLASOVA	{"phone": "+70864451358"}
0005435517659	4A51DB	9903 274233	OLEG TARASOV	{"email": "oleg.tarasov-1975@postgrespro.ru", "phone": "+70495028781"}
0005435517660	D03512	4700 587405	NIKITA GRIGOREV	{"phone": "+70122819060"}
0005435517661	D03512	7330 496972	VLADISLAV MIRONOV	{"email": "mironov-vladislav14051969@postgrespro.ru", "phone": "+70969721670"}
0005435517662	403788	3455 060702	NATALYA SOLOVEVA	{"phone": "+70212897115"}
0005435517663	89E8B8	2237 768199	TIMOFEY KOZLOV	{"email": "timofey.kozlov-15031974@postgrespro.ru", "phone": "+70058062733"}
0005435517664	A71FB8	3147 515658	VERONIKA SIDOROVA	{"email": "vsidorova-17041985@postgrespro.ru", "phone": "+70488362284"}
0005435517665	A71FB8	3281 976059	GENNADIY ZAYCEV	{"phone": "+70752703373"}
0005435517666	18DA81	5905 878460	RAFAIL SIDOROV	{"phone": "+70322315161"}
0005435517667	12CC45	6419 756642	ANGELINA MOROZOVA	{"email": "morozova-a21121970@postgrespro.ru", "phone": "+70960156760"}
0005435517668	5D97E9	5208 911612	TATYANA ZHUKOVA	{"email": "tatyanazhukova.1973@postgrespro.ru", "phone": "+70027568188"}
0005435517669	88BB6B	8118 398649	KONSTANTIN KUZMIN	{"email": "kuzmin-konstantin.1960@postgrespro.ru", "phone": "+70665961498"}
0005435517670	79AA6E	2405 527328	TATYANA MOISEEVA	{"email": "tmoiseeva-071974@postgrespro.ru", "phone": "+70297154796"}
0005435517671	79AA6E	7801 512370	TAMARA NESTEROVA	{"email": "tamara-nesterova_1970@postgrespro.ru", "phone": "+70709387216"}
0005435517672	5D3B26	1152 513859	TATYANA KULIKOVA	{"phone": "+70272440216"}
0005435517673	5D3B26	3342 370842	DARYA ORLOVA	{"phone": "+70366255805"}
0005435517674	5D3B26	5462 401756	VYACHESLAV ROMANOV	{"email": "vromanov-1972@postgrespro.ru", "phone": "+70173470305"}
0005435517675	B2851F	1566 360217	LYUDMILA VOLKOVA	{"email": "l.volkova.1985@postgrespro.ru", "phone": "+70944015820"}
0005435517676	EBA98E	9476 298182	NURIYA SOKOLOVA	{"phone": "+70752023120"}
0005435517677	EBA98E	4797 686235	DMITRIY KISELEV	{"email": "kiselevdmitriy_1976@postgrespro.ru", "phone": "+70510686338"}
0005435517678	0F6A68	9501 983475	ALEKSANDR STEPANOV	{"email": "aleksandr.stepanov101962@postgrespro.ru", "phone": "+70811675145"}
0005435517679	AEF7D0	7322 952148	MARIYA STEPANOVA	{"phone": "+70470911190"}
0005435517680	AEF7D0	4898 120514	ANASTASIYA NOVIKOVA	{"phone": "+70401162283"}
0005435517681	18EF22	1371 688221	MIKHAIL FROLOV	{"email": "frolov-m_041974@postgrespro.ru", "phone": "+70658535397"}
0005435517682	C5C715	3749 205967	VERA KUZNECOVA	{"email": "kuznecova-vera_31011965@postgrespro.ru", "phone": "+70587097537"}
0005435517683	F04C9C	3757 453617	SVETLANA KRASNOVA	{"email": "krasnova-svetlana-1976@postgrespro.ru", "phone": "+70028873899"}
0005435517684	52D7AC	6459 330469	NIKOLAY KUZNECOV	{"email": "kuznecov_nikolay021983@postgrespro.ru", "phone": "+70091508533"}
0005435517685	52D7AC	5477 134170	INNA SERGEEVA	{"email": "sergeeva.i011975@postgrespro.ru", "phone": "+70751065531"}
0005435517686	52D7AC	7093 431524	VLADIMIR NOVIKOV	{"email": "novikov-vladimir-08091961@postgrespro.ru", "phone": "+70788976303"}
0005435517687	5E27A7	1552 483574	GALINA YUDINA	{"email": "galina-yudina_081973@postgrespro.ru", "phone": "+70933992036"}
0005435517688	4AC797	7622 552812	YULIYA VASILEVA	{"email": "y.vasileva.1970@postgrespro.ru", "phone": "+70841737309"}
0005435517689	D6CC9E	5241 603219	MARAT SOLOVEV	{"phone": "+70062208281"}
0005435517690	6D9F52	0051 118120	IRINA ALEKSEEVA	{"email": "ialekseeva-111974@postgrespro.ru", "phone": "+70259669464"}
0005435517691	7CC033	2348 288387	IVAN ZHURAVLEV	{"phone": "+70614363458"}
0005435517692	7CC033	0258 847273	VLADIMIR IVANOV	{"phone": "+70650956973"}
0005435517693	65A8CB	0992 918253	NIKOLAY AFANASEV	{"phone": "+70558267835"}
0005435517694	65A8CB	1407 276424	ANDREY MOROZOV	{"email": "andrey-morozov10031968@postgrespro.ru", "phone": "+70041757503"}
0005435517695	65A8CB	9724 969719	NATALYA VASILEVA	{"phone": "+70224524983"}
0005435517696	44F547	8186 432424	ANNA ALEKSANDROVA	{"email": "anna.aleksandrova-04101971@postgrespro.ru", "phone": "+70724495967"}
0005435517697	44F547	8743 477481	NIKOLAY SCHERBAKOV	{"phone": "+70601183102"}
0005435517698	00A296	9317 280884	NADEZHDA MIKHAYLOVA	{"phone": "+70833545460"}
0005435517699	92392C	0145 600958	FLYURA MAKSIMOVA	{"email": "f_maksimova28051970@postgrespro.ru", "phone": "+70830054007"}
0005435517700	923EF5	3448 366167	NIKOLAY PETROV	{"phone": "+70050107997"}
0005435517701	37FD2C	4937 027565	ALEKSANDR CHERNOV	{"email": "chernov-aleksandr1976@postgrespro.ru", "phone": "+70681102345"}
0005435517702	37FD2C	7367 839642	ANASTASIYA NIKITINA	{"phone": "+70823041755"}
0005435517703	4B8F02	7557 663259	VYACHESLAV KARPOV	{"email": "vkarpov.1967@postgrespro.ru", "phone": "+70557917951"}
0005435517704	484907	4623 982055	MAKSIM SOKOLOV	{"email": "sokolov_m_1974@postgrespro.ru", "phone": "+70833419035"}
0005435517705	484907	0842 754491	OLEG MAKSIMOV	{"email": "maksimov.o-091977@postgrespro.ru", "phone": "+70998925479"}
0005435517706	E3C910	4528 239171	VALENTINA POTAPOVA	{"phone": "+70775903474"}
0005435517707	2D90E2	2534 962149	ALEKSANDRA ZHUKOVA	{"email": "a_zhukova1959@postgrespro.ru", "phone": "+70039635638"}
0005435517708	5F8316	3513 723543	SOFYA SOROKINA	{"phone": "+70433432412"}
0005435517709	1DEAB4	1246 642510	ALEKSANDR ANDREEV	{"email": "a_andreev_031961@postgrespro.ru", "phone": "+70251190502"}
0005435517710	C210EF	8222 567958	SERGEY ZAKHAROV	{"phone": "+70315919917"}
0005435517711	4B5747	2271 810259	VALENTINA FROLOVA	{"phone": "+70122265214"}
0005435517712	D4D2B2	1298 026835	DMITRIY CHERNOV	{"email": "chernovdmitriy.101978@postgrespro.ru", "phone": "+70389807779"}
0005435517713	EF7B52	1432 238957	VLADIMIR DAVYDOV	{"email": "davydov-v18041977@postgrespro.ru", "phone": "+70517689799"}
0005435517714	787712	3918 137703	YURIY ANTONOV	{"phone": "+70008724746"}
0005435517715	7E893F	2840 948522	YURIY ALEKSEEV	{"phone": "+70569754874"}
0005435517716	7E893F	9730 625448	ALEKSANDR BELOV	{"phone": "+70196481242"}
0005435517717	99FA7F	2951 676212	PETR KOROLEV	{"phone": "+70775481695"}
0005435517718	E0A3D6	6437 875577	LYUBOV STEPANOVA	{"email": "stepanoval.021971@postgrespro.ru", "phone": "+70599273142"}
0005435517719	D7C470	2782 299959	VYACHESLAV IVANOV	{"email": "vyacheslav.ivanov.041971@postgrespro.ru", "phone": "+70628520601"}
0005435517720	D7C470	1614 803269	ALEKSANDR SAVELEV	{"email": "a_savelev.1982@postgrespro.ru", "phone": "+70948630235"}
0005435517721	EECFBC	2966 617414	ALFIYA MAKSIMOVA	{"phone": "+70336721733"}
0005435517722	1DFA4F	1750 552535	GALINA SOLOVEVA	{"email": "g-soloveva.1971@postgrespro.ru", "phone": "+70354575889"}
0005435517723	B16574	2842 882978	MARIYA ZHURAVLEVA	{"phone": "+70439464203"}
0005435517724	16EBA7	4913 505313	TIMOFEY KULIKOV	{"phone": "+70955038247"}
0005435517725	4A3A0B	8217 763175	VERA NAZAROVA	{"email": "veranazarova24011975@postgrespro.ru", "phone": "+70173387245"}
0005435517726	AD3195	2924 045397	VLADIMIR KISELEV	{"email": "kiselev_vladimir_29071963@postgrespro.ru", "phone": "+70451462131"}
0005435517727	AD3195	2726 068434	ALEKSEY KUZNECOV	{"phone": "+70248883354"}
0005435517728	7610FA	7943 254472	SVETLANA OSIPOVA	{"phone": "+70355212408"}
0005435517729	0437A8	0122 252913	DMITRIY POPOV	{"email": "popov.d_101976@postgrespro.ru", "phone": "+70742999847"}
0005435517730	9B3803	4014 091088	NATALIYA ROMANOVA	{"phone": "+70615193801"}
0005435517731	9B3803	1245 589582	NIKITA ZHUKOV	{"email": "nikitazhukov_1968@postgrespro.ru", "phone": "+70335026522"}
0005435517732	574552	2869 788990	SVETLANA MAKAROVA	{"phone": "+70692083655"}
0005435517733	66085D	1988 883447	DANIL IVANOV	{"phone": "+70776374163"}
0005435517734	1682D4	6617 306271	VADIM VLASOV	{"email": "vadim_vlasov_051965@postgrespro.ru", "phone": "+70119165923"}
0005435517735	4797E6	4986 544861	DANILA ANDREEV	{"phone": "+70900816957"}
0005435517736	7BA995	2115 220141	ANATOLIY BARANOV	{"email": "baranov.anatoliy031969@postgrespro.ru", "phone": "+70081644083"}
0005435517737	BEDFAB	4546 291980	DENIS MAKSIMOV	{"email": "denis.maksimov-20081970@postgrespro.ru", "phone": "+70439455573"}
0005435517738	67BB09	6846 897961	LYUBOV DMITRIEVA	{"email": "dmitrieva-l_19111983@postgrespro.ru", "phone": "+70615573992"}
0005435517739	00D380	3173 497366	ALEKSANDR FEDOTOV	{"email": "fedotov.aleksandr-1990@postgrespro.ru", "phone": "+70463778393"}
0005435517740	4E2B3A	4275 528066	VALENTINA VASILEVA	{"phone": "+70843739883"}
0005435517741	4E2B3A	4843 540971	ALEKSANDR PETROV	{"phone": "+70025468808"}
0005435517742	777500	1147 648670	SERGEY SOROKIN	{"email": "sergey_sorokin1973@postgrespro.ru", "phone": "+70403440058"}
0005435517743	777500	9630 111621	NADEZHDA VASILEVA	{"phone": "+70355403500"}
0005435517744	777500	6800 327100	MARINA STEPANOVA	{"email": "marina-stepanova_1975@postgrespro.ru", "phone": "+70478509665"}
0005435517745	777500	2551 127800	VALENTINA POPOVA	{"email": "popova_valentina.04091970@postgrespro.ru", "phone": "+70047563507"}
0005435517746	2FD01C	1355 079007	ILYA GORBUNOV	{"email": "ilya-gorbunov101965@postgrespro.ru", "phone": "+70396744865"}
0005435517747	AB5251	6289 159771	ELENA ANTONOVA	{"email": "e.antonova-081969@postgrespro.ru", "phone": "+70971508232"}
0005435517748	540F65	9098 941229	MARIYA EGOROVA	{"email": "egorovam101972@postgrespro.ru", "phone": "+70937245483"}
0005435517749	B2B773	7644 384352	VARVARA ALEKSEEVA	{"phone": "+70750332739"}
0005435517750	B3A1EE	2933 464651	POLINA BORISOVA	{"email": "borisovap-111965@postgrespro.ru", "phone": "+70634117582"}
0005435517751	B3A1EE	7782 857810	GAGIK FEDOTOV	{"phone": "+70826166531"}
0005435517752	6C09A3	2741 524143	IRINA KOVALEVA	{"email": "irinakovaleva-12051971@postgrespro.ru", "phone": "+70818603224"}
0005435517753	4423F8	0689 089192	ELENA GERASIMOVA	{"phone": "+70321665985"}
0005435517754	64A7E9	4071 551432	OLGA SOROKINA	{"phone": "+70699499893"}
0005435517755	24811A	3856 646861	TATYANA DANILOVA	{"email": "danilova_tatyana.1957@postgrespro.ru", "phone": "+70572973714"}
0005435517756	24811A	5033 883739	ALEKSANDR ORLOV	{"email": "orlovaleksandr05121966@postgrespro.ru", "phone": "+70338442152"}
0005435517757	A1C3C0	0405 875721	VIKTORIYA MOROZOVA	{"phone": "+70497814465"}
0005435517758	B60E68	2814 416736	VALENTINA VOLKOVA	{"email": "v_volkova_091981@postgrespro.ru", "phone": "+70777992524"}
0005435517759	B60E68	2666 766643	ANDREY SOROKIN	{"phone": "+70495106838"}
0005435517760	BA8947	2049 335957	ELENA OSIPOVA	{"email": "osipova.elena11021977@postgrespro.ru", "phone": "+70560908944"}
0005435517761	824CD5	7226 936831	ILYA GRIGOREV	{"email": "grigorev.i.27091975@postgrespro.ru", "phone": "+70426909671"}
0005435517762	824CD5	7778 028000	EKATERINA MAKSIMOVA	{"phone": "+70167005146"}
0005435517763	F92B0F	0083 479391	YULIYA SAVELEVA	{"email": "ysaveleva.1970@postgrespro.ru", "phone": "+70632664622"}
0005435517764	73FC68	0717 710790	ANGELINA LAZAREVA	{"email": "lazarevaangelina1989@postgrespro.ru", "phone": "+70640924017"}
0005435517765	73FC68	3435 563297	ANASTASIYA EFIMOVA	{"email": "aefimova-031972@postgrespro.ru", "phone": "+70550335541"}
0005435517766	2CE0E7	2249 469138	VALENTINA KOVALEVA	{"email": "v.kovaleva-1968@postgrespro.ru", "phone": "+70393943859"}
0005435517767	2CE0E7	1837 006352	VIKTOR TARASOV	{"email": "viktortarasov-18111970@postgrespro.ru", "phone": "+70200366520"}
0005435517768	A14505	3631 816507	OLGA SIDOROVA	{"phone": "+70839698189"}
0005435517769	A14505	0902 558988	ANDREY SCHERBAKOV	{"email": "scherbakova.091988@postgrespro.ru", "phone": "+70910491020"}
0005435517770	2D2079	3089 867840	VLADIMIR IVANOV	{"phone": "+70502508428"}
0005435517771	2D2079	2458 660857	VENIAMIN KUZMIN	{"email": "v_kuzmin_15051978@postgrespro.ru", "phone": "+70608578971"}
0005435517772	08FCEA	7783 688765	IRINA PETROVA	{"email": "petrovai_1980@postgrespro.ru", "phone": "+70579618592"}
0005435517773	8C8BFE	0187 768721	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr.011968@postgrespro.ru", "phone": "+70432714075"}
0005435517774	8C8BFE	4048 834047	EKATERINA MAKSIMOVA	{"phone": "+70050540225"}
0005435517775	3D3235	9186 988208	VASILIY KULIKOV	{"phone": "+70320001322"}
0005435517776	DFF9FA	5675 798996	YULIYA ILINA	{"email": "yilina_121964@postgrespro.ru", "phone": "+70060036187"}
0005435517777	DFF9FA	7009 459739	MIKHAIL YAKOVLEV	{"phone": "+70149563362"}
0005435517778	586F7B	7697 887625	IRINA MELNIKOVA	{"email": "i_melnikova-1967@postgrespro.ru", "phone": "+70699256424"}
0005435517779	82B82C	1477 525741	EGOR KUZNECOV	{"email": "kuznecov.egor-1961@postgrespro.ru", "phone": "+70698177069"}
0005435517780	E9E180	5846 846245	VLADIMIR BORISOV	{"phone": "+70074550881"}
0005435517781	CD8ABC	9888 730770	ANTONINA ZAKHAROVA	{"phone": "+70036921868"}
0005435517782	CE4A91	9382 755293	ALEKSANDR BORISOV	{"phone": "+70621016169"}
0005435517783	CE4A91	1897 154432	MARIYA SAVELEVA	{"phone": "+70811631478"}
0005435517784	CEFF49	0197 638006	TATYANA BELYAEVA	{"email": "belyaeva.t-1970@postgrespro.ru", "phone": "+70217797877"}
0005435517785	CEFF49	1933 574095	ALEKSANDR FEDOROV	{"email": "fedorov.aleksandr1964@postgrespro.ru", "phone": "+70233521011"}
0005435517786	C268F9	4377 224711	DARYA SERGEEVA	{"phone": "+70204641909"}
0005435517787	701A78	5431 390317	ELENA DENISOVA	{"phone": "+70778601577"}
0005435517788	B72EC4	1413 048511	IVAN DAVYDOV	{"email": "davydov.i05061979@postgrespro.ru", "phone": "+70354452585"}
0005435517789	A2BE64	5416 687743	IGOR STEPANOV	{"phone": "+70143950417"}
0005435517790	0B75EB	1852 084618	VIKTOR ZHURAVLEV	{"email": "v-zhuravlev_1985@postgrespro.ru", "phone": "+70141572717"}
0005435517791	0B75EB	9047 333805	LYUBOV KUZNECOVA	{"email": "lyubov.kuznecova.1984@postgrespro.ru", "phone": "+70343505041"}
0005435517792	9E9CB8	1427 703914	NATALYA IVANOVA	{"email": "n-ivanova.25051960@postgrespro.ru", "phone": "+70519362642"}
0005435517793	033D22	8243 727695	ROSTISLAV SOKOLOV	{"email": "sokolov.rostislav.091969@postgrespro.ru", "phone": "+70069173598"}
0005435517794	033D22	0749 767611	LEV DAVYDOV	{"phone": "+70741794002"}
0005435517795	0A0D8A	3326 732726	IGOR FOMIN	{"email": "fomin_i1969@postgrespro.ru", "phone": "+70023762705"}
0005435517796	0A0D8A	2580 140057	MARINA TIKHONOVA	{"email": "m_tikhonova_021964@postgrespro.ru", "phone": "+70323827174"}
0005435517797	EEC5B5	7336 400252	VLADISLAV KAZAKOV	{"phone": "+70061956030"}
0005435517798	EEC5B5	5336 222612	ARTEM GERASIMOV	{"phone": "+70815573603"}
0005435517799	8DD3FB	4414 859379	ELENA KUZNECOVA	{"phone": "+70815681956"}
0005435517800	26F2A1	0729 144157	SERGEY KUZNECOV	{"phone": "+70927402335"}
0005435517801	CAE616	0547 154621	ALEKSEY ZAKHAROV	{"phone": "+70262375817"}
0005435517802	D68103	6636 865633	IRINA AKIMOVA	{"email": "akimova-i-061969@postgrespro.ru", "phone": "+70424590849"}
0005435517803	9DB8DF	7169 208182	LYUDMILA BORISOVA	{"email": "l_borisova.1982@postgrespro.ru", "phone": "+70490603552"}
0005435517804	50EA3A	2434 571156	NIKOLAY KOZLOV	{"email": "kozlov-nikolay_071976@postgrespro.ru", "phone": "+70900697205"}
0005435517805	CF2F9C	2016 300769	VLADIMIR SHEVCHENKO	{"email": "v-shevchenko_06061971@postgrespro.ru", "phone": "+70582430728"}
0005435517806	FDD723	8388 620608	VALERIY SEMENOV	{"phone": "+70372772136"}
0005435517807	9A1BA7	8624 742493	ILYA GUSEV	{"phone": "+70869026316"}
0005435517808	9A1BA7	1391 930491	OLEG ISAEV	{"email": "isaevoleg-1976@postgrespro.ru", "phone": "+70472692641"}
0005435517809	9A1BA7	8364 983225	IGOR STEPANOV	{"email": "igorstepanov091977@postgrespro.ru", "phone": "+70708580639"}
0005435517810	994E2A	8892 365151	ANASTASIYA NOVIKOVA	{"email": "a_novikova.051977@postgrespro.ru", "phone": "+70228912791"}
0005435517811	52941C	5665 012066	VLADIMIR MOROZOV	{"email": "morozov.v.1969@postgrespro.ru", "phone": "+70174699535"}
0005435517812	BD44F5	8389 925284	RAISA KUZNECOVA	{"email": "raisa_kuznecova.031979@postgrespro.ru", "phone": "+70034289517"}
0005435517813	0EDD0C	4875 215464	DMITRIY MARTYNOV	{"phone": "+70647880066"}
0005435517814	0EDD0C	5906 727567	SVETLANA VOROBEVA	{"email": "s.vorobeva.1972@postgrespro.ru", "phone": "+70771053974"}
0005435517815	7A02A7	8514 718036	EKATERINA BARANOVA	{"email": "baranovaekaterina1971@postgrespro.ru", "phone": "+70935018611"}
0005435517816	7A02A7	1677 887970	SERGEY MEDVEDEV	{"phone": "+70320055762"}
0005435517817	A9763D	4649 334472	VENERA BELOVA	{"email": "belovav-1968@postgrespro.ru", "phone": "+70832450694"}
0005435517818	190B9D	4602 398952	ALEKSANDR SHEVCHENKO	{"phone": "+70391293600"}
0005435517819	90AFD1	2940 030843	NINA SCHERBAKOVA	{"email": "scherbakova_n-27111985@postgrespro.ru", "phone": "+70498118050"}
0005435517820	90AFD1	0750 679407	LYUDMILA NAZAROVA	{"email": "nazarova-lyudmila.1985@postgrespro.ru", "phone": "+70159805467"}
0005435517821	63F45A	2236 462671	SVETLANA POPOVA	{"email": "popova.s_13071976@postgrespro.ru", "phone": "+70663682072"}
0005435517822	8C057D	2020 978111	IRINA NIKOLAEVA	{"phone": "+70951221087"}
0005435517823	EBE390	9151 624130	VLADIMIR AFANASEV	{"email": "afanasev_vladimir30071968@postgrespro.ru", "phone": "+70707759944"}
0005435517824	EBE390	1574 925656	TATYANA TARASOVA	{"phone": "+70112446129"}
0005435517825	EA5C09	0287 403759	LYUBOV IVANOVA	{"phone": "+70646042630"}
0005435517826	04CEC5	5789 470088	ELIZAVETA FROLOVA	{"phone": "+70564529018"}
0005435517827	4D25B1	5725 078379	MARIYA AFANASEVA	{"phone": "+70927080167"}
0005435517828	D929A4	3068 786902	ALEKSANDR MOROZOV	{"email": "a-morozov011976@postgrespro.ru", "phone": "+70755939374"}
0005435517829	D929A4	4826 926158	ILYA SERGEEV	{"email": "sergeev-i10011966@postgrespro.ru", "phone": "+70215188369"}
0005435517830	5D5628	5879 907626	ANASTASIYA POPOVA	{"phone": "+70864074757"}
0005435517831	5D5628	9300 385004	VALENTINA VOLKOVA	{"email": "volkova_v-1982@postgrespro.ru", "phone": "+70765574798"}
0005435517832	A6EE60	0760 489845	ANTONINA FILIPPOVA	{"phone": "+70410387508"}
0005435517833	6CE1E3	3822 716415	ANDREY ABRAMOV	{"email": "abramovandrey.1975@postgrespro.ru", "phone": "+70369682187"}
0005435517834	044CAB	0961 086062	ALEKSANDRA MELNIKOVA	{"email": "melnikovaa-28051979@postgrespro.ru", "phone": "+70996315672"}
0005435517835	361FBF	1918 988588	RAISA KARPOVA	{"phone": "+70605659996"}
0005435517836	361FBF	8337 093975	PETR GAVRILOV	{"phone": "+70621546359"}
0005435517837	CC52D2	6734 806871	EKATERINA NESTEROVA	{"phone": "+70910412425"}
0005435517838	FD3665	9123 714569	DANA SAVELEVA	{"email": "savelevad24061974@postgrespro.ru", "phone": "+70526085541"}
0005435517839	DA3104	7679 396563	SERGEY SMIRNOV	{"phone": "+70332257871"}
0005435517840	DA3104	2802 612100	DMITRIY BONDARENKO	{"email": "dmitriy_bondarenko_15101969@postgrespro.ru", "phone": "+70267246188"}
0005435517841	4EDDBD	0649 936056	IGOR GRIGOREV	{"email": "grigorev_igor-18081975@postgrespro.ru", "phone": "+70252330824"}
0005435517842	E6416C	9150 825437	YULIYA MARTYNOVA	{"email": "martynova.yuliya_29051968@postgrespro.ru", "phone": "+70546600392"}
0005435517843	E6416C	2487 734828	EVGENIYA TITOVA	{"phone": "+70664509525"}
0005435517844	7D769B	7975 007020	NATALYA KALININA	{"email": "n-kalinina-1971@postgrespro.ru", "phone": "+70730635061"}
0005435517845	F73A81	8819 728310	EVGENIYA MARTYNOVA	{"phone": "+70297025759"}
0005435517846	F73A81	7518 191320	VALENTINA IVANOVA	{"email": "ivanovav10071973@postgrespro.ru", "phone": "+70158234434"}
0005435517847	CAFCAF	6124 564755	KIRILL PETROV	{"phone": "+70670167808"}
0005435517848	CAFCAF	5933 482457	NINA VOLKOVA	{"email": "nina-volkova.13081973@postgrespro.ru", "phone": "+70490293959"}
0005435517849	FF9155	6765 436076	NATALYA EFREMOVA	{"phone": "+70416986184"}
0005435517850	AB92CC	4374 767575	ALENA TIKHONOVA	{"phone": "+70467941570"}
0005435517851	76D46C	2029 611606	NATALYA MOROZOVA	{"email": "n_morozova23091976@postgrespro.ru", "phone": "+70886754562"}
0005435517852	62BEDB	0324 979885	IRINA NIKITINA	{"phone": "+70658957360"}
0005435517853	BF8B42	4739 391303	SERGEY KISELEV	{"phone": "+70100966436"}
0005435517854	BF8B42	7263 485646	IVAN PETROV	{"email": "i.petrov_1980@postgrespro.ru", "phone": "+70519626133"}
0005435517855	218582	8052 902343	VALENTINA KOROLEVA	{"phone": "+70061932986"}
0005435517856	814E4E	1716 092574	NIKOLAY BORISOV	{"email": "nikolayborisov-13031963@postgrespro.ru", "phone": "+70125682437"}
0005435517857	14629A	3135 577119	VLADIMIR GAVRILOV	{"phone": "+70381314753"}
0005435517858	14629A	2911 556835	MIKHAIL FEDOROV	{"email": "fedorov-mikhail-111968@postgrespro.ru", "phone": "+70891562888"}
0005435517859	6CF72E	9860 998080	VLADISLAV KISELEV	{"phone": "+70748118137"}
0005435517860	6CF72E	7472 246860	TIMUR ZAYCEV	{"phone": "+70420090087"}
0005435517861	C6C3DF	4314 277149	NIKOLAY MOROZOV	{"email": "nikolay_morozov_051975@postgrespro.ru", "phone": "+70895128474"}
0005435517862	C6C3DF	3791 495635	ALEKSEY KARPOV	{"phone": "+70728080759"}
0005435517863	3D4562	8374 182549	LIDIYA KUZNECOVA	{"email": "kuznecoval_1970@postgrespro.ru", "phone": "+70660157276"}
0005435517864	3D4562	0109 033551	EVGENIY RODIONOV	{"phone": "+70114048101"}
0005435517865	A93C94	5288 379873	NIKOLAY SIDOROV	{"email": "sidorov.nikolay_121971@postgrespro.ru", "phone": "+70543506222"}
0005435517866	A93C94	2116 027942	VLADIMIR CHERNOV	{"phone": "+70405000390"}
0005435517867	392433	3754 326688	MARINA NESTEROVA	{"email": "marina.nesterova_1973@postgrespro.ru", "phone": "+70729916816"}
0005435517868	DAE560	4625 405239	ALEKSANDR FROLOV	{"email": "aleksandrfrolov13021971@postgrespro.ru", "phone": "+70896606073"}
0005435517869	A07303	7953 535285	IVAN EGOROV	{"phone": "+70151396398"}
0005435517870	088189	2349 327796	EKATERINA ZAKHAROVA	{"phone": "+70580475535"}
0005435517871	083595	4410 281756	EDUARD GUSEV	{"email": "gusev_e021962@postgrespro.ru", "phone": "+70439994780"}
0005435517872	D8B6F0	9101 523378	ANATOLIY ILIN	{"email": "anatoliy.ilin_1970@postgrespro.ru", "phone": "+70472268952"}
0005435517873	A63B05	7999 197793	TATYANA YAKOVLEVA	{"email": "tyakovleva-1970@postgrespro.ru", "phone": "+70223836468"}
0005435517874	E0F5B0	0332 859232	MARINA NAZAROVA	{"phone": "+70525706062"}
0005435517875	A192EF	8473 149017	GALINA MIKHAYLOVA	{"phone": "+70844245664"}
0005435517876	C37228	2355 277819	EVGENIY MOROZOV	{"email": "morozove_15031961@postgrespro.ru", "phone": "+70436326256"}
0005435517877	459555	7161 051827	DENIS ORLOV	{"email": "orlov-d11021973@postgrespro.ru", "phone": "+70407176048"}
0005435517878	459555	3312 552454	DMITRIY SCHERBAKOV	{"email": "dscherbakov_01071968@postgrespro.ru", "phone": "+70498329876"}
0005435517879	140014	2522 691527	DMITRIY ALEKSEEV	{"phone": "+70970042907"}
0005435517880	864A99	6460 848211	VERONIKA NAUMOVA	{"email": "veronika_naumova_1970@postgrespro.ru", "phone": "+70011327950"}
0005435517881	EC7EFC	8967 970515	TATYANA POPOVA	{"phone": "+70965043888"}
0005435517882	972D4E	2660 523725	IVAN IVANOV	{"email": "ivan-ivanov_1974@postgrespro.ru", "phone": "+70108844115"}
0005435517883	045161	4355 412552	SVETLANA KULIKOVA	{"phone": "+70043891494"}
0005435517884	045161	3759 194099	DENIS TIKHONOV	{"phone": "+70618420508"}
0005435517885	6682A3	3626 207246	GALINA EGOROVA	{"email": "galina-egorova011969@postgrespro.ru", "phone": "+70110386378"}
0005435517886	6682A3	8935 079602	ILYA SIDOROV	{"email": "sidorovi081976@postgrespro.ru", "phone": "+70215494508"}
0005435517887	0A0C34	6390 380088	ROZA SOKOLOVA	{"phone": "+70011655021"}
0005435517888	0A0C34	2859 466453	YANA NESTEROVA	{"email": "yananesterova-14111982@postgrespro.ru", "phone": "+70608542272"}
0005435517889	0BAFB8	0072 132709	MAKSIM KUZNECOV	{"email": "kuznecov_m.21061973@postgrespro.ru", "phone": "+70535492018"}
0005435517890	7B44EE	7614 508633	DENIS MAKSIMOV	{"phone": "+70465463240"}
0005435517891	7B44EE	5487 533751	VIKTORIYA TARASOVA	{"phone": "+70976686286"}
0005435517892	B0B808	9705 086663	VIKTOR SAVELEV	{"phone": "+70136810904"}
0005435517893	A69C61	9700 969105	LEONID YAKOVLEV	{"phone": "+70205504818"}
0005435517894	7F3FEC	2887 216842	LYUBOV NOVIKOVA	{"email": "l.novikova.05121976@postgrespro.ru", "phone": "+70663362044"}
0005435517895	7F3FEC	2762 046652	DANIIL ZHUKOV	{"phone": "+70135860657"}
0005435517896	2D5D1A	6367 448142	IRINA DANILOVA	{"phone": "+70289868977"}
0005435517897	2D5D1A	0510 487139	EVGENIY FILIPPOV	{"email": "evgeniy_filippov13021978@postgrespro.ru", "phone": "+70558584709"}
0005435517898	905537	6199 212812	NATALIYA KISELEVA	{"email": "kiselevanataliya061972@postgrespro.ru", "phone": "+70988600807"}
0005435517899	E607BD	1410 445550	LYUDMILA MEDVEDEVA	{"email": "medvedeval1973@postgrespro.ru", "phone": "+70390943117"}
0005435517900	E607BD	5610 212744	OKSANA BORISOVA	{"phone": "+70592310380"}
0005435517901	BEDC69	2732 947473	DMITRIY ALEKSEEV	{"phone": "+70884698264"}
0005435517902	77D99C	5105 891985	SVETLANA KOZLOVA	{"email": "s.kozlova-20111961@postgrespro.ru", "phone": "+70685826650"}
0005435517903	C5536D	5072 681369	VENERA ILINA	{"phone": "+70741332873"}
0005435517904	65C3D5	5694 644342	VITALIY MAKAROV	{"email": "vitaliymakarov_1959@postgrespro.ru", "phone": "+70853312602"}
0005435517905	6BB1C5	4159 518292	SVETLANA PETROVA	{"phone": "+70838286496"}
0005435517906	45EDCD	4575 336136	VLADIMIR NIKITIN	{"phone": "+70006488719"}
0005435517907	45EDCD	0023 933938	DARYA ZHUKOVA	{"email": "zhukova_darya.1989@postgrespro.ru", "phone": "+70768301748"}
0005435517908	3BBF7A	0672 940163	IRINA VLASOVA	{"phone": "+70334617942"}
0005435517909	3BBF7A	7562 427011	ALEKSANDR SOROKIN	{"phone": "+70153049442"}
0005435517910	4B2CBD	1300 870386	GALINA ZHURAVLEVA	{"email": "galina_zhuravleva_121972@postgrespro.ru", "phone": "+70581425097"}
0005435517911	4B2CBD	7966 393619	VALENTINA KULIKOVA	{"email": "kulikovavalentina08071966@postgrespro.ru", "phone": "+70594640191"}
0005435517912	B5E304	4169 770313	NATALYA ISAEVA	{"phone": "+70643593874"}
0005435517913	B5E304	7929 612789	SERGEY MOISEEV	{"phone": "+70219977040"}
0005435517914	AC41A1	7578 514236	NIKOLAY MOROZOV	{"email": "n_morozov-19031965@postgrespro.ru", "phone": "+70533589396"}
0005435517915	AC41A1	4276 724604	EKATERINA ARKHIPOVA	{"email": "arkhipova_ekaterina.101988@postgrespro.ru", "phone": "+70967011822"}
0005435517916	D31701	5370 424034	KONSTANTIN MATVEEV	{"email": "matveev-k_1964@postgrespro.ru", "phone": "+70666777817"}
0005435517917	D31701	0185 070514	RASIM KULIKOV	{"email": "rasimkulikov.081982@postgrespro.ru", "phone": "+70649818245"}
0005435517918	96927B	1476 046611	NATALIYA DMITRIEVA	{"email": "nataliya-dmitrieva_1963@postgrespro.ru", "phone": "+70508229190"}
0005435517919	CC03CF	1274 443723	KRISTINA NAUMOVA	{"phone": "+70427821516"}
0005435517920	CC03CF	5295 536231	EKATERINA BARANOVA	{"phone": "+70206748695"}
0005435517921	407E62	9414 085758	ELENA DAVYDOVA	{"phone": "+70809691309"}
0005435517922	407E62	0623 302595	GENNADIY FEDOROV	{"phone": "+70443478570"}
0005435517923	96CA49	8312 485269	OLEG ZAKHAROV	{"email": "o-zakharov-071975@postgrespro.ru", "phone": "+70431669724"}
0005435517924	96CA49	3383 049564	IRINA MAKAROVA	{"phone": "+70702810231"}
0005435517925	1257C0	2271 576829	MARINA MAKAROVA	{"email": "makarova-marina_1982@postgrespro.ru", "phone": "+70742427015"}
0005435517926	C36C8B	8514 739162	VADIM FROLOV	{"phone": "+70255971865"}
0005435517927	C36C8B	7217 326750	FEDOR SOKOLOV	{"phone": "+70887193186"}
0005435517928	316020	0566 151086	OLGA MIKHAYLOVA	{"email": "mikhaylova.olga.091959@postgrespro.ru", "phone": "+70982346658"}
0005435517929	B44CE8	7323 421863	SERGEY GORBUNOV	{"phone": "+70886110599"}
0005435517930	EEA97D	7043 768987	TATYANA FEDOROVA	{"email": "fedorovatatyana.021964@postgrespro.ru", "phone": "+70465579845"}
0005435517931	EEA97D	6994 446080	YURIY MEDVEDEV	{"email": "medvedev.yuriy02061977@postgrespro.ru", "phone": "+70824920527"}
0005435517932	E36CEC	7449 061458	MIKHAIL DMITRIEV	{"email": "mikhaildmitriev.041971@postgrespro.ru", "phone": "+70308470699"}
0005435517933	0A5566	8446 362950	EVGENIY VASILEV	{"phone": "+70038914364"}
0005435517934	5EDBBC	8548 141469	VIKTOR ISAEV	{"email": "v_isaev.05111975@postgrespro.ru", "phone": "+70604043742"}
0005435517935	C7782F	3078 831586	VALENTINA TIMOFEEVA	{"email": "timofeeva.valentina.1968@postgrespro.ru", "phone": "+70247802650"}
0005435517936	C7782F	4922 364310	MARIYA BELYAEVA	{"email": "mariya_belyaeva-27021963@postgrespro.ru", "phone": "+70501965797"}
0005435517937	EA2681	7496 210451	VLADIMIR IVANOV	{"phone": "+70900190627"}
0005435517938	644B80	9186 039994	TATYANA AFANASEVA	{"email": "tatyanaafanaseva1973@postgrespro.ru", "phone": "+70952903064"}
0005435517939	F293C7	3187 117040	VALERIY ALEKSEEV	{"email": "alekseevvaleriy_1970@postgrespro.ru", "phone": "+70141272365"}
0005435517940	39AC6E	1446 425322	TATYANA PAVLOVA	{"phone": "+70509425839"}
0005435517941	39AC6E	2618 777241	ANATOLIY PETROV	{"phone": "+70233145288"}
0005435517942	0C997A	6222 370724	IVAN DENISOV	{"phone": "+70446592724"}
0005435517943	6DF806	4856 187203	YULIYA MASLOVA	{"email": "yuliya.maslova-081971@postgrespro.ru", "phone": "+70205274135"}
0005435517944	6DF806	1288 450145	VALENTINA KALININA	{"email": "kalinina-valentina-1980@postgrespro.ru", "phone": "+70871149372"}
0005435517945	1801BE	6234 366305	ALEKSEY ORLOV	{"email": "a.orlov_021969@postgrespro.ru", "phone": "+70889314055"}
0005435517946	E04795	6445 514393	ALEKSEY SAVELEV	{"email": "savelev.a-091956@postgrespro.ru", "phone": "+70988297699"}
0005435517947	E04795	8747 949075	ANATOLIY SOROKIN	{"email": "a_sorokin23051968@postgrespro.ru", "phone": "+70830099801"}
0005435517948	286FC7	8786 846801	NATALYA YUDINA	{"phone": "+70207667332"}
0005435517949	286FC7	8224 060010	SERGEY SAVELEV	{"email": "sergeysavelev_101973@postgrespro.ru", "phone": "+70161385388"}
0005435517950	286FC7	5007 301662	IVAN MEDVEDEV	{"phone": "+70293418704"}
0005435517951	0EC056	7381 164615	IVAN KAZAKOV	{"phone": "+70176994108"}
0005435517952	AD9676	2760 746113	VLADIMIR TARASOV	{"phone": "+70210862744"}
0005435517953	DD9CFF	1495 418557	ALEKSEY PAVLOV	{"email": "aleksey-pavlov.09071965@postgrespro.ru", "phone": "+70910185797"}
0005435517954	DD9CFF	8385 329683	ELENA YAKOVLEVA	{"email": "yakovleva-e17021975@postgrespro.ru", "phone": "+70648459336"}
0005435517955	BC640D	3592 630473	VLADIMIR FILIPPOV	{"email": "v_filippov011968@postgrespro.ru", "phone": "+70486623187"}
0005435517956	DC7AAB	0558 726438	NATALYA YAKOVLEVA	{"email": "natalya-yakovleva-1972@postgrespro.ru", "phone": "+70030045090"}
0005435517957	44437C	0355 242806	OLGA KOVALEVA	{"email": "kovaleva-olga-1979@postgrespro.ru", "phone": "+70194997654"}
0005435517958	2925F5	4767 776353	ELENA SMIRNOVA	{"email": "smirnova-e031968@postgrespro.ru", "phone": "+70279865724"}
0005435517959	048D5E	1825 681409	TATYANA KUZNECOVA	{"phone": "+70670055168"}
0005435517960	A1893D	4478 098959	PETR SIDOROV	{"email": "psidorov-101983@postgrespro.ru", "phone": "+70344204576"}
0005435517961	583AF4	9214 077437	VALENTINA KUZNECOVA	{"phone": "+70139014254"}
0005435517962	700047	2324 261500	ALFIYA KOVALEVA	{"email": "kovaleva_alfiya1975@postgrespro.ru", "phone": "+70627151053"}
0005435517963	700047	5045 434945	NINA GUSEVA	{"email": "nina_guseva.071984@postgrespro.ru", "phone": "+70048147661"}
0005435517964	700047	0682 273563	PAVEL KAZAKOV	{"phone": "+70049039044"}
0005435517965	ED4CB7	8127 470737	OLGA ANDREEVA	{"phone": "+70652476238"}
0005435517966	ED4CB7	4669 890410	OLGA ILINA	{"phone": "+70584704276"}
0005435517967	FEF1EC	2484 718268	IRINA MATVEEVA	{"email": "imatveeva1988@postgrespro.ru", "phone": "+70698158533"}
0005435517968	F9B799	8159 998967	IRINA SEMENOVA	{"email": "i-semenova_1977@postgrespro.ru", "phone": "+70799058994"}
0005435517969	F9B799	9437 279066	ALEKSANDR ZHURAVLEV	{"email": "a-zhuravlev.101955@postgrespro.ru", "phone": "+70036939301"}
0005435517970	EF4600	0208 393097	ROMAN BONDARENKO	{"email": "bondarenko_roman121984@postgrespro.ru", "phone": "+70579710127"}
0005435517971	706C4E	0584 625763	ALEKSANDR KOZLOV	{"email": "aleksandr.kozlov_1970@postgrespro.ru", "phone": "+70219372242"}
0005435517972	2A07F0	9853 239790	IRINA SOROKINA	{"email": "sorokinairina011965@postgrespro.ru", "phone": "+70266760875"}
0005435517973	2A07F0	8266 411243	ANATOLIY PETROV	{"phone": "+70356209537"}
0005435517974	353F0C	4828 640669	YULIYA DMITRIEVA	{"email": "dmitrieva.yuliya_1972@postgrespro.ru", "phone": "+70349230101"}
0005435517975	353F0C	6293 342840	GLEB ANDREEV	{"email": "andreev.gleb.19091957@postgrespro.ru", "phone": "+70769321335"}
0005435517976	FF814C	9502 280266	NADEZHDA ERMAKOVA	{"phone": "+70797724584"}
0005435517977	FD961F	1186 418730	NATALYA KAZAKOVA	{"phone": "+70474603904"}
0005435517978	FD961F	2266 736901	EKATERINA BELOVA	{"email": "e-belova.25091963@postgrespro.ru", "phone": "+70770001102"}
0005435517979	FD961F	0961 883875	TATYANA MOROZOVA	{"phone": "+70564962383"}
0005435517980	A94874	9646 681191	DMITRIY KOZLOV	{"email": "d.kozlov-08061975@postgrespro.ru", "phone": "+70244824719"}
0005435517981	36D748	1795 660436	VERA KUZMINA	{"phone": "+70513170876"}
0005435517982	36D748	4623 799669	SALAVAT RODIONOV	{"phone": "+70065284489"}
0005435517983	B9F1A5	1827 569100	NIKITA VOLKOV	{"email": "n.volkov.101963@postgrespro.ru", "phone": "+70606991606"}
0005435517984	C7E7FC	9103 561147	YULIYA ROMANOVA	{"email": "romanova_yuliya-041974@postgrespro.ru", "phone": "+70782961934"}
0005435517985	66CBD1	8159 040193	ILYA GAVRILOV	{"email": "i_gavrilov-1978@postgrespro.ru", "phone": "+70613728408"}
0005435517986	92B8E1	7093 698566	TATYANA NAUMOVA	{"email": "t_naumova.011976@postgrespro.ru", "phone": "+70388951908"}
0005435517987	91A218	7794 244191	ASIYA TIKHONOVA	{"email": "atikhonova1984@postgrespro.ru", "phone": "+70426416793"}
0005435517988	91A218	9708 036989	ZUKHRA OVCHINNIKOVA	{"phone": "+70323887035"}
0005435517989	F340FA	3947 742356	ZINAIDA KISELEVA	{"email": "kiselevaz1971@postgrespro.ru", "phone": "+70333483632"}
0005435517990	3EB291	2780 222440	ALEKSANDR KUZNECOV	{"email": "kuznecovaleksandr.26011969@postgrespro.ru", "phone": "+70830134694"}
0005435517991	FA9440	9365 401826	NINA PETROVA	{"phone": "+70882286164"}
0005435517992	FA9440	2379 930342	LYUDMILA GERASIMOVA	{"phone": "+70974033466"}
0005435517993	22CB0D	2061 705952	OKSANA NAZAROVA	{"phone": "+70761010838"}
0005435517994	E72148	4276 739601	GALINA ERMAKOVA	{"email": "galinaermakova.28091969@postgrespro.ru", "phone": "+70495767516"}
0005435517995	AB18D5	9061 590768	MIKHAIL SMIRNOV	{"phone": "+70069039749"}
0005435517996	EBAE61	6223 976652	ROMAN IVANOV	{"phone": "+70954502536"}
0005435517997	953967	4420 885093	GALINA ZHURAVLEVA	{"email": "g-zhuravleva.051970@postgrespro.ru", "phone": "+70465570766"}
0005435517998	6449BC	0315 693098	OLGA ZAKHAROVA	{"email": "olga_zakharova.031987@postgrespro.ru", "phone": "+70716759906"}
0005435517999	0A1629	2878 621880	VYACHESLAV ANDREEV	{"email": "vyacheslav-andreev_1978@postgrespro.ru", "phone": "+70177589983"}
0005435518000	0A1629	8078 636876	VADIM VLASOV	{"phone": "+70608412824"}
0005435518001	3EAB05	6431 309538	NAIL ALEKSEEV	{"phone": "+70360459348"}
0005435518002	923893	6196 941511	IRINA POTAPOVA	{"email": "i_potapova19061972@postgrespro.ru", "phone": "+70743655454"}
0005435518003	923893	0418 958604	VLADIMIR KUZNECOV	{"phone": "+70101877476"}
0005435518004	4F560F	1218 708477	LARISA FEDOROVA	{"phone": "+70615997212"}
0005435518005	9B147B	9947 992967	SERGEY DMITRIEV	{"email": "sergey_dmitriev_22051969@postgrespro.ru", "phone": "+70177712394"}
0005435518006	3C1893	6925 376807	ALEKSEY MIRONOV	{"email": "aleksey_mironov_1972@postgrespro.ru", "phone": "+70102861769"}
0005435518007	C930C9	1109 494800	ANNA BOGDANOVA	{"phone": "+70752607850"}
0005435518008	DD1E9B	1460 036261	NIKOLAY MAKAROV	{"phone": "+70347863004"}
0005435518009	A12A87	4884 992853	NATALYA SEMENOVA	{"phone": "+70841429847"}
0005435518010	A12A87	5766 887838	EKATERINA EFIMOVA	{"email": "efimova.e1967@postgrespro.ru", "phone": "+70326067128"}
0005435518011	D04148	1667 411489	REGINA KULIKOVA	{"email": "regina_kulikova-08031971@postgrespro.ru", "phone": "+70601903132"}
0005435518012	8EADA2	6383 699336	SERGEY POPOV	{"email": "popov_sergey.12101967@postgrespro.ru", "phone": "+70832874450"}
0005435518013	9A32AA	1117 072772	SEMEN NOVIKOV	{"phone": "+70299825936"}
0005435518014	9A32AA	5104 101553	ALEKSEY AFANASEV	{"phone": "+70465236119"}
0005435518015	906CD4	6701 024437	KRISTINA GERASIMOVA	{"phone": "+70274367220"}
0005435518016	4B70CD	4174 459087	TATYANA SAVELEVA	{"phone": "+70221051845"}
0005435518017	FB91AA	5818 274452	ALEKSANDR CHERNOV	{"phone": "+70054953835"}
0005435518018	B41F13	7012 884045	GENNADIY SMIRNOV	{"phone": "+70968878092"}
0005435518019	B41F13	8230 266858	EKATERINA KOROLEVA	{"email": "korolevaekaterina.111974@postgrespro.ru", "phone": "+70429021551"}
0005435518020	B41F13	0346 199855	ANNA NIKOLAEVA	{"email": "nikolaeva-a111968@postgrespro.ru", "phone": "+70520542382"}
0005435518021	5C97CC	8544 269896	OKSANA MOISEEVA	{"email": "moiseeva_oksana_111971@postgrespro.ru", "phone": "+70940343421"}
0005435518022	BBC601	1149 336000	VIKTOR IVANOV	{"email": "v-ivanov13041966@postgrespro.ru", "phone": "+70417272290"}
0005435518023	C988D8	9277 462201	LILIYA KULIKOVA	{"phone": "+70881125136"}
0005435518024	4D58A0	2874 158097	TAMARA MELNIKOVA	{"email": "t.melnikova-121968@postgrespro.ru", "phone": "+70046907447"}
0005435518025	4D58A0	2205 416274	MATVEY PAVLOV	{"phone": "+70060132112"}
0005435518026	F0599D	8199 467886	LYUDMILA ANDREEVA	{"email": "l.andreeva041969@postgrespro.ru", "phone": "+70382035629"}
0005435518027	F0599D	3035 375602	EKATERINA VLASOVA	{"email": "e_vlasova.1974@postgrespro.ru", "phone": "+70155583239"}
0005435518028	5C9AD7	0534 407065	SERGEY ALEKSEEV	{"email": "sergey-alekseev.1975@postgrespro.ru", "phone": "+70232313127"}
0005435518029	CB7615	1462 274770	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov-091960@postgrespro.ru", "phone": "+70976599642"}
0005435518030	97CD0B	7967 589115	VIKTOR KARPOV	{"phone": "+70984051239"}
0005435518031	97CD0B	6939 867045	ILYA VOLKOV	{"phone": "+70207804587"}
0005435518032	9EFB64	1388 586835	ANNA VASILEVA	{"email": "vasileva-anna.061966@postgrespro.ru", "phone": "+70568652869"}
0005435518033	9EFB64	4933 531359	STEPAN GORBUNOV	{"phone": "+70757794370"}
0005435518034	C44182	9458 213163	ALEKSANDRA TARASOVA	{"email": "tarasova-a.101975@postgrespro.ru", "phone": "+70122007145"}
0005435518035	FD3461	2280 043318	NINA MIKHAYLOVA	{"email": "nina-mikhaylova1991@postgrespro.ru", "phone": "+70484729043"}
0005435518036	C7C5DD	8316 235082	VITALIY FROLOV	{"phone": "+70283501701"}
0005435518037	ED5C6D	5872 735559	POLINA IVANOVA	{"phone": "+70701787595"}
0005435518038	61F0AB	0580 948340	NINA ALEKSANDROVA	{"email": "ninaaleksandrova011973@postgrespro.ru", "phone": "+70639736814"}
0005435518039	1FF123	7364 211318	NATALYA ROMANOVA	{"email": "romanova_natalya-20071972@postgrespro.ru", "phone": "+70863684649"}
0005435518040	E2BE62	9815 197741	MIKHAIL NAUMOV	{"phone": "+70130794622"}
0005435518041	05A13E	1044 896800	ALEKSEY MAKSIMOV	{"email": "maksimov-a.1978@postgrespro.ru", "phone": "+70200194133"}
0005435518042	B3552B	4526 236953	NIKOLAY NAUMOV	{"phone": "+70225505882"}
0005435518043	4A8F52	4936 218022	ANDREY FOMIN	{"email": "a-fomin1971@postgrespro.ru", "phone": "+70463184614"}
0005435518044	FF9F03	7336 045694	LIDIYA MASLOVA	{"phone": "+70039970490"}
0005435518045	D35DEF	5902 863026	TATYANA KALININA	{"phone": "+70688625732"}
0005435518046	D35DEF	0333 293183	ALEKSANDR SHEVCHENKO	{"phone": "+70979928628"}
0005435518047	591A83	5600 765126	VLADIMIR SERGEEV	{"phone": "+70037815557"}
0005435518048	0234FA	8865 946135	DARYA KONDRATEVA	{"email": "kondratevad-1976@postgrespro.ru", "phone": "+70359307897"}
0005435518049	867B10	2812 694149	IGOR TIMOFEEV	{"email": "igor-timofeev.1971@postgrespro.ru", "phone": "+70727234418"}
0005435518050	867B10	3704 450568	ANATOLIY DENISOV	{"email": "denisov-anatoliy-031975@postgrespro.ru", "phone": "+70567619677"}
0005435518051	BDD104	6581 495261	POLINA KUZNECOVA	{"phone": "+70218692337"}
0005435518052	AF83F8	9343 319824	YULIYA MOROZOVA	{"email": "morozova-y-011978@postgrespro.ru", "phone": "+70774635960"}
0005435518053	96A2DA	8315 620141	ELENA KARPOVA	{"email": "karpovaelena-07071968@postgrespro.ru", "phone": "+70442614760"}
0005435518054	B610F5	1140 902103	LYUBOV ZHURAVLEVA	{"phone": "+70277211557"}
0005435518055	23AA47	4059 429462	NINA NAUMOVA	{"phone": "+70598929999"}
0005435518056	23AA47	1741 345554	ALLA NOVIKOVA	{"phone": "+70679349758"}
0005435518057	C1B735	7687 926620	SERGEY KULIKOV	{"phone": "+70682922773"}
0005435518058	033BE7	2920 889718	OLESYA OSIPOVA	{"email": "olesya_osipova101973@postgrespro.ru", "phone": "+70696269046"}
0005435518059	033BE7	5681 090163	VLADIMIR MIRONOV	{"email": "mironov_v_03011974@postgrespro.ru", "phone": "+70308601863"}
0005435518060	C0A321	6185 541829	ALEKSANDR IVANOV	{"email": "ivanovaleksandr091970@postgrespro.ru", "phone": "+70246043809"}
0005435518061	078C8E	6555 520721	ANDREY PETROV	{"phone": "+70544521270"}
0005435518062	F852BC	6812 597498	VADIM ALEKSANDROV	{"phone": "+70973795785"}
0005435518063	77424B	3498 668299	ALLA VASILEVA	{"email": "vasileva.alla_1974@postgrespro.ru", "phone": "+70677297860"}
0005435518064	9196C2	1635 828753	SERGEY TIMOFEEV	{"email": "sergey_timofeev_081980@postgrespro.ru", "phone": "+70758377013"}
0005435518065	9196C2	1391 081175	NAIL OSIPOV	{"phone": "+70737118633"}
0005435518066	26E53A	9189 553359	PETR VOROBEV	{"phone": "+70968947501"}
0005435518067	128BB0	1238 329297	ANASTASIYA SERGEEVA	{"phone": "+70648136478"}
0005435518068	E45B12	0062 548192	OLGA POPOVA	{"email": "olga-popova1975@postgrespro.ru", "phone": "+70169854630"}
0005435518069	65E384	4581 412038	NIKOLAY TIKHONOV	{"phone": "+70272264235"}
0005435518070	513383	5790 313787	OKSANA VOROBEVA	{"email": "vorobeva.o-071994@postgrespro.ru", "phone": "+70856782456"}
0005435518071	0265A3	5975 873570	LYUBOV MOISEEVA	{"email": "l.moiseeva041958@postgrespro.ru", "phone": "+70902617302"}
0005435518072	0265A3	0882 850448	NADEZHDA ZAYCEVA	{"email": "zayceva-nadezhda.10101966@postgrespro.ru", "phone": "+70369590277"}
0005435518073	51A687	0819 287892	NINA LUKYANOVA	{"email": "lukyanova-n-1962@postgrespro.ru", "phone": "+70133594732"}
0005435518074	30CB75	1441 148481	EKATERINA NESTEROVA	{"email": "nesterova.ekaterina091981@postgrespro.ru", "phone": "+70068694144"}
0005435518075	EBE5E5	4484 853411	VITALIY BARANOV	{"phone": "+70773612792"}
0005435518076	9E7B88	0779 448036	ROMAN ILIN	{"email": "roman_ilin_1967@postgrespro.ru", "phone": "+70976342570"}
0005435518077	9E7B88	0973 116552	MARINA DMITRIEVA	{"email": "dmitrieva_m_15021972@postgrespro.ru", "phone": "+70482868720"}
0005435518078	0D640B	3969 479574	ASIYA ANDREEVA	{"email": "a.andreeva_19031955@postgrespro.ru", "phone": "+70409948408"}
0005435518079	D1B01C	8723 730005	GULNAZ ZAYCEVA	{"email": "zayceva_gulnaz.091981@postgrespro.ru", "phone": "+70634994853"}
0005435518080	AEF516	7973 285269	LIDIYA SEMENOVA	{"email": "semenova-lidiya.05121966@postgrespro.ru", "phone": "+70887213533"}
0005435518081	AEF516	3106 072321	VASILIY PAVLOV	{"email": "pavlov_vasiliy.011973@postgrespro.ru", "phone": "+70208961280"}
0005435518082	AEF516	7172 093252	ANTONINA IVANOVA	{"phone": "+70291074634"}
0005435518083	69FF18	3243 178370	OLGA NAZAROVA	{"phone": "+70569550509"}
0005435518084	AF02A1	9071 283223	NADEZHDA ILINA	{"email": "nadezhda_ilina-111979@postgrespro.ru", "phone": "+70743728706"}
0005435518085	2D7FA6	8368 306240	ILYA SOROKIN	{"email": "sorokin.i.06051973@postgrespro.ru", "phone": "+70091111014"}
0005435518086	2D7FA6	6407 784670	ALEKSANDRA ZHUKOVA	{"phone": "+70870017496"}
0005435518087	3DDBC1	9299 961316	ALEKSANDR SIDOROV	{"phone": "+70253997414"}
0005435518088	3DDBC1	2338 604471	VASILIY MIRONOV	{"email": "vasiliy-mironov-1965@postgrespro.ru", "phone": "+70676320245"}
0005435518089	B3A736	8164 226564	ALEKSANDR ANTONOV	{"email": "antonovaleksandr_1963@postgrespro.ru", "phone": "+70292182096"}
0005435518090	7C66CC	1448 020122	SERGEY DMITRIEV	{"phone": "+70881168608"}
0005435518091	B9C168	9688 560323	ELIZAVETA OSIPOVA	{"email": "osipova.elizaveta091963@postgrespro.ru", "phone": "+70784688194"}
0005435518092	B9C168	5137 235545	MARAT VOLKOV	{"phone": "+70676648160"}
0005435518093	3298C0	5637 854566	RUSTAM VLASOV	{"email": "rustam.vlasov-10011971@postgrespro.ru", "phone": "+70442091962"}
0005435518094	D3CFAC	2077 882258	ELENA SOROKINA	{"email": "sorokina-e07031990@postgrespro.ru", "phone": "+70137518052"}
0005435518095	FEC9EF	8931 994555	ALIYA NIKIFOROVA	{"email": "nikiforova.a.011986@postgrespro.ru", "phone": "+70616067662"}
0005435518096	FFE4E6	8062 612770	IRINA POPOVA	{"phone": "+70798541419"}
0005435518097	FFE4E6	6698 991078	ALENA OVCHINNIKOVA	{"email": "a_ovchinnikova-17111967@postgrespro.ru", "phone": "+70580602500"}
0005435518098	D0D59D	6475 609034	ZARINA PAVLOVA	{"email": "pavlova.zarina-031983@postgrespro.ru", "phone": "+70560620502"}
0005435518099	5E3C24	9530 855430	MARIYA MAKAROVA	{"email": "makarova.mariya-1974@postgrespro.ru", "phone": "+70181656396"}
0005435518100	00B55B	9800 905756	NATALIYA KISELEVA	{"phone": "+70198081815"}
0005435518101	00B55B	3974 389865	ANATOLIY PAVLOV	{"email": "a-pavlov.071983@postgrespro.ru", "phone": "+70495170484"}
0005435518102	B6F4C3	6535 424029	TAMARA ZAKHAROVA	{"phone": "+70285854103"}
0005435518103	5F736D	7956 812423	ALEKSANDR DMITRIEV	{"phone": "+70996913193"}
0005435518104	5F736D	4927 320429	RISHAT KOZLOV	{"email": "r-kozlov.17091971@postgrespro.ru", "phone": "+70925734658"}
0005435518105	EE53D5	8022 895429	OLGA VASILEVA	{"email": "o.vasileva-1957@postgrespro.ru", "phone": "+70503473329"}
0005435518106	EE53D5	5017 288060	KRISTINA NESTEROVA	{"phone": "+70596308086"}
0005435518107	7009AC	1528 403407	VALENTINA ZAKHAROVA	{"email": "valentina_zakharova1975@postgrespro.ru", "phone": "+70909614464"}
0005435518108	8F03B8	1103 760870	DENIS SIDOROV	{"phone": "+70134402466"}
0005435518109	8F03B8	6987 653839	NIKOLAY EGOROV	{"phone": "+70695078404"}
0005435518110	B33592	0362 822093	RAFAIL SERGEEV	{"email": "sergeev.r-19051963@postgrespro.ru", "phone": "+70508136485"}
0005435518111	49511A	9133 391847	MIKHAIL ALEKSEEV	{"phone": "+70468329957"}
0005435518112	0EB3DB	1735 352438	ANASTASIYA MOROZOVA	{"email": "a_morozova_1972@postgrespro.ru", "phone": "+70675094251"}
0005435518113	245AEE	8779 100543	MIKHAIL ORLOV	{"email": "mikhailorlov_1962@postgrespro.ru", "phone": "+70587724182"}
0005435518114	245AEE	9627 950347	LYUDMILA FILIPPOVA	{"email": "l-filippova.071989@postgrespro.ru", "phone": "+70772226354"}
0005435518115	C9532A	6776 870844	DMITRIY POPOV	{"phone": "+70991935190"}
0005435518116	674ADE	6784 849821	ALEKSANDR FROLOV	{"phone": "+70814667671"}
0005435518117	16E324	3923 728029	SERGEY ROMANOV	{"email": "s_romanov.28021969@postgrespro.ru", "phone": "+70262492144"}
0005435518118	EF70A7	2414 419290	NINA GAVRILOVA	{"phone": "+70783189619"}
0005435518119	EF70A7	3238 183451	ALEKSEY GRIGOREV	{"email": "aleksey.grigorev-1972@postgrespro.ru", "phone": "+70609684777"}
0005435518120	813FC5	3291 917993	VALERIY POPOV	{"email": "valeriy_popov.1979@postgrespro.ru", "phone": "+70425387874"}
0005435518121	813FC5	2199 076213	NINA NIKIFOROVA	{"phone": "+70297751614"}
0005435518122	C3D48E	8768 008124	SERGEY SOROKIN	{"phone": "+70116506378"}
0005435518123	077971	8707 823758	IVAN IVANOV	{"phone": "+70697367261"}
0005435518124	93547F	2720 873434	VLADIMIR SOKOLOV	{"email": "vladimirsokolov.111973@postgrespro.ru", "phone": "+70650804001"}
0005435518125	0CEF09	4827 175830	ANATOLIY KUZMIN	{"email": "kuzmin-a.031984@postgrespro.ru", "phone": "+70670228710"}
0005435518126	0579F5	4102 376232	EKATERINA ANDREEVA	{"email": "e.andreeva_04101986@postgrespro.ru", "phone": "+70345182920"}
0005435518127	0579F5	6062 509522	EVGENIYA ZAYCEVA	{"email": "ezayceva05071966@postgrespro.ru", "phone": "+70028651050"}
0005435518128	42DBD1	9136 555915	ANNA BELOVA	{"phone": "+70929496402"}
0005435518129	89B71E	0384 144748	NATALYA PAVLOVA	{"email": "pavlova-n1980@postgrespro.ru", "phone": "+70561021628"}
0005435518130	89B71E	8223 052547	NATALYA MEDVEDEVA	{"email": "medvedeva_natalya27011969@postgrespro.ru", "phone": "+70511944313"}
0005435518131	CDB7AD	2875 629389	OLGA LUKYANOVA	{"phone": "+70508628195"}
0005435518132	59153C	7285 765528	KONSTANTIN KUZNECOV	{"phone": "+70484622584"}
0005435518133	76B537	6846 138986	TATYANA KUZMINA	{"phone": "+70556254243"}
0005435518134	BD866D	6079 421441	VALERIY SERGEEV	{"email": "vsergeev-06081977@postgrespro.ru", "phone": "+70151382288"}
0005435518135	E1B741	3096 596333	IVAN ABRAMOV	{"phone": "+70234629603"}
0005435518136	79178B	5877 143947	SVETLANA ORLOVA	{"email": "orlova-s_1977@postgrespro.ru", "phone": "+70576325041"}
0005435518137	A9828F	4570 667049	EKATERINA KONDRATEVA	{"email": "ekaterinakondrateva.29051970@postgrespro.ru", "phone": "+70391394088"}
0005435518138	9D3E21	2044 509327	IVAN ROMANOV	{"phone": "+70929934517"}
0005435518139	6AC921	2969 402831	IGOR PAVLOV	{"email": "pavlovi-101981@postgrespro.ru", "phone": "+70373716088"}
0005435518140	2F6D51	3291 194608	ANASTASIYA PETROVA	{"phone": "+70621171474"}
0005435518141	552B20	5876 593706	MIKHAIL TARASOV	{"email": "m-tarasov1982@postgrespro.ru", "phone": "+70783492872"}
0005435518142	A312DE	7237 174202	DARYA KUZNECOVA	{"email": "dkuznecova.1967@postgrespro.ru", "phone": "+70016594279"}
0005435518143	CD6326	0951 367790	NATALYA SMIRNOVA	{"email": "smirnova-n-1967@postgrespro.ru", "phone": "+70785581883"}
0005435518144	CD6326	5251 242545	ALEKSEY MAKAROV	{"email": "amakarov_19081976@postgrespro.ru", "phone": "+70517500670"}
0005435518145	15E061	3437 966826	ZOYA KOZLOVA	{"email": "z_kozlova-1960@postgrespro.ru", "phone": "+70878833161"}
0005435518146	8D7F71	6047 550240	NAILYA PAVLOVA	{"phone": "+70025632498"}
0005435518147	75B425	9410 647997	DENIS KUZNECOV	{"email": "kuznecov-denis.24011970@postgrespro.ru", "phone": "+70529628726"}
0005435518148	75B425	3059 918792	VIKTORIYA NESTEROVA	{"email": "v-nesterova.1975@postgrespro.ru", "phone": "+70756781295"}
0005435518149	75B425	5075 511716	VLADIMIR ALEKSEEV	{"phone": "+70572962722"}
0005435518150	EBA967	8749 169382	ANNA MATVEEVA	{"phone": "+70957235051"}
0005435518151	4756E8	2932 285605	OLEG ZAYCEV	{"email": "zaycev-oleg081982@postgrespro.ru", "phone": "+70796231568"}
0005435518152	0E798F	7364 555567	VALENTINA LEBEDEVA	{"phone": "+70241932065"}
0005435518153	0E798F	8589 089447	ANASTASIYA MIRONOVA	{"email": "a.mironova_04041961@postgrespro.ru", "phone": "+70240114361"}
0005435518154	71D9C2	6898 253475	ELIZAVETA KULIKOVA	{"email": "kulikova-e_111968@postgrespro.ru", "phone": "+70045974968"}
0005435518155	212455	1787 247916	IRINA MOISEEVA	{"email": "irinamoiseeva-11071974@postgrespro.ru", "phone": "+70565517329"}
0005435518156	212455	5741 199280	ALEKSANDR KUZMIN	{"email": "kuzmin-a-1962@postgrespro.ru", "phone": "+70208416935"}
0005435518157	82F268	7441 739148	MARIYA LAZAREVA	{"phone": "+70561428221"}
0005435518158	F2F630	6468 778172	VASILIY STEPANOV	{"email": "stepanov.v031980@postgrespro.ru", "phone": "+70826732294"}
0005435518159	F2F630	9748 685371	SERGEY NAZAROV	{"phone": "+70332196346"}
0005435518160	051806	5895 234620	ALEKSANDR IVANOV	{"phone": "+70323738565"}
0005435518161	F01940	8226 503436	ELENA EGOROVA	{"email": "elena.egorova-1963@postgrespro.ru", "phone": "+70992197395"}
0005435518162	6E5911	1516 093225	BORIS VOROBEV	{"email": "borisvorobev_121956@postgrespro.ru", "phone": "+70100346987"}
0005435518163	D40303	9874 151102	YURIY CHERNOV	{"email": "chernovyuriy-1966@postgrespro.ru", "phone": "+70013121285"}
0005435518164	D40303	7623 358879	NIKITA ANDREEV	{"email": "n.andreev.1970@postgrespro.ru", "phone": "+70203147312"}
0005435518165	D40303	1788 021418	SERGEY MAKAROV	{"phone": "+70038270379"}
0005435518166	BDB737	2243 635127	NIKOLAY MIKHAYLOV	{"email": "nmikhaylov.1979@postgrespro.ru", "phone": "+70660113011"}
0005435518167	BDB737	8474 806302	KONSTANTIN SOLOVEV	{"email": "k-solovev.04091979@postgrespro.ru", "phone": "+70936926088"}
0005435518168	BDB737	7299 381820	MARIYA AKIMOVA	{"email": "akimovam-031981@postgrespro.ru", "phone": "+70168324886"}
0005435518169	22F638	6943 772889	ALEKSANDR KUDRYASHOV	{"email": "aleksandr.kudryashov.011984@postgrespro.ru", "phone": "+70928407622"}
0005435518170	19453C	6237 351320	VASILIY EGOROV	{"email": "v_egorov_20011980@postgrespro.ru", "phone": "+70624344464"}
0005435518171	E2932B	9878 252431	YURIY MEDVEDEV	{"email": "yuriymedvedev_081964@postgrespro.ru", "phone": "+70553967817"}
0005435518172	E2932B	0896 440582	OKSANA SERGEEVA	{"email": "osergeeva1971@postgrespro.ru", "phone": "+70818648787"}
0005435518173	F956E2	0899 137189	YULIYA ROMANOVA	{"email": "romanova.y_28051966@postgrespro.ru", "phone": "+70149512449"}
0005435518174	A4EA16	7018 168824	VALENTINA ZAKHAROVA	{"email": "zakharova_v-26011970@postgrespro.ru", "phone": "+70075618171"}
0005435518175	A4EA16	9755 668291	ARTEM VOLKOV	{"email": "artem.volkov1968@postgrespro.ru", "phone": "+70894429113"}
0005435518176	F9A7F6	9025 454349	LYUBOV IVANOVA	{"email": "lyubov.ivanova_1968@postgrespro.ru", "phone": "+70373486714"}
0005435518177	BBCE9A	7405 145309	NADEZHDA OVCHINNIKOVA	{"phone": "+70824162446"}
0005435518178	BBCE9A	3154 981168	ANDREY IVANOV	{"email": "ivanov.a11031965@postgrespro.ru", "phone": "+70997904973"}
0005435518179	17A51F	4700 077450	LARISA RYABOVA	{"email": "larisa.ryabova-061966@postgrespro.ru", "phone": "+70330501680"}
0005435518180	17A51F	3140 690325	NIKOLAY YAKOVLEV	{"phone": "+70063291089"}
0005435518181	B849D4	9820 218217	SERGEY MIRONOV	{"email": "mironov.sergey.021972@postgrespro.ru", "phone": "+70956998922"}
0005435518182	ED884A	5650 576485	VASILIY POPOV	{"email": "popov.vasiliy-08041970@postgrespro.ru", "phone": "+70141590142"}
0005435518350	E61E50	9179 014642	TATYANA MELNIKOVA	{"phone": "+70536585772"}
0005435518183	ED884A	1238 530832	VLADIMIR POPOV	{"email": "vladimir_popov_1978@postgrespro.ru", "phone": "+70607463968"}
0005435518184	FC4C09	8921 691880	LARISA MOROZOVA	{"phone": "+70123754427"}
0005435518185	0630A9	1920 531244	ALEKSANDR YAKOVLEV	{"email": "a-yakovlev-04111970@postgrespro.ru", "phone": "+70627974470"}
0005435518186	C03C72	7705 848739	RUSLAN ALEKSEEV	{"email": "alekseevruslan_1971@postgrespro.ru", "phone": "+70113430033"}
0005435518187	F19DE5	6291 509700	IVAN ZAKHAROV	{"phone": "+70310467359"}
0005435518188	E2D7E4	1775 213103	TATYANA BOGDANOVA	{"phone": "+70564071706"}
0005435518189	76B959	9183 497996	YURIY MATVEEV	{"phone": "+70336354201"}
0005435518190	078A52	7136 134678	NIKOLAY BORISOV	{"phone": "+70509838512"}
0005435518191	B7F888	5415 288056	EVGENIY VLASOV	{"phone": "+70110919984"}
0005435518192	B7F888	1316 729630	ALEKSANDR SOKOLOV	{"email": "sokolov.a-041974@postgrespro.ru", "phone": "+70812676944"}
0005435518193	B7F888	9965 239253	MILENA IVANOVA	{"phone": "+70600874840"}
0005435518194	725124	2859 063736	GALINA VOLKOVA	{"email": "gvolkova.06091968@postgrespro.ru", "phone": "+70054895061"}
0005435518195	0CC09E	1891 542080	IGOR RODIONOV	{"phone": "+70549317302"}
0005435518196	BED665	1488 287703	EKATERINA SERGEEVA	{"email": "sergeeva-ekaterina-061974@postgrespro.ru", "phone": "+70005470071"}
0005435518197	BED665	1794 033119	VYACHESLAV RODIONOV	{"email": "rodionov.vyacheslav111977@postgrespro.ru", "phone": "+70473305244"}
0005435518198	0263D7	7202 963723	TATYANA BOGDANOVA	{"phone": "+70819827832"}
0005435518199	1A024A	8928 998572	SVETLANA GUSEVA	{"email": "svetlana_guseva-16091971@postgrespro.ru", "phone": "+70371706550"}
0005435518200	1A024A	6025 363966	KARINA POPOVA	{"phone": "+70208106546"}
0005435518201	F53C7F	2835 061190	VIKTOR SHEVCHENKO	{"phone": "+70048269460"}
0005435518202	E40CFE	9112 962291	ANDREY DENISOV	{"email": "denisov-a.1982@postgrespro.ru", "phone": "+70155602915"}
0005435518203	76E03B	2589 852849	SVETLANA EFIMOVA	{"email": "sefimova-06021973@postgrespro.ru", "phone": "+70074890206"}
0005435518204	FDBA74	4870 742756	ELZA POPOVA	{"phone": "+70831606258"}
0005435518205	B64360	3866 310320	ANATOLIY SMIRNOV	{"phone": "+70025170120"}
0005435518206	035982	1393 516242	ALEKSEY VOROBEV	{"email": "vorobev-aleksey.30011974@postgrespro.ru", "phone": "+70701270902"}
0005435518207	B0D0A6	2115 902116	KLAVDIYA SEMENOVA	{"phone": "+70236742818"}
0005435518208	1A1DCF	4810 638477	TATYANA SMIRNOVA	{"email": "smirnovatatyana_21041961@postgrespro.ru", "phone": "+70396780638"}
0005435518209	B4FCDB	2755 765078	MARIYA ROMANOVA	{"email": "mariyaromanova.041973@postgrespro.ru", "phone": "+70695840965"}
0005435518210	B4FCDB	6576 423937	SOFYA IVANOVA	{"email": "ivanova.sofya-20061976@postgrespro.ru", "phone": "+70944881811"}
0005435518211	E85DA5	0905 609442	SERGEY NAUMOV	{"email": "sergey_naumov.1975@postgrespro.ru", "phone": "+70615513045"}
0005435518212	E85DA5	0807 094531	DMITRIY SOLOVEV	{"email": "solovev_d_011972@postgrespro.ru", "phone": "+70067251500"}
0005435518213	70CCBD	3440 425580	ANASTASIYA KOZLOVA	{"email": "anastasiya.kozlova1977@postgrespro.ru", "phone": "+70330222892"}
0005435518214	70CCBD	7333 716557	YURIY NAUMOV	{"email": "y-naumov1980@postgrespro.ru", "phone": "+70635365463"}
0005435518215	D36794	7666 520239	ALLA MOROZOVA	{"email": "allamorozova_111978@postgrespro.ru", "phone": "+70174291560"}
0005435518216	BADB4D	5581 193398	DARYA EGOROVA	{"phone": "+70016139131"}
0005435518217	D86930	6317 869948	YURIY GRIGOREV	{"email": "y-grigorev031990@postgrespro.ru", "phone": "+70063402142"}
0005435518218	1F3A4C	2490 823807	NATALYA PAVLOVA	{"email": "pavlovan-03021969@postgrespro.ru", "phone": "+70839850625"}
0005435518219	1F3A4C	1345 058909	YURIY BORISOV	{"email": "yuriyborisov1970@postgrespro.ru", "phone": "+70710167071"}
0005435518220	2CC047	4615 643652	ALEKSANDR SOKOLOV	{"email": "sokolova-101960@postgrespro.ru", "phone": "+70449086193"}
0005435518221	D76EFC	1913 134435	VLADIMIR PAVLOV	{"email": "v.pavlov05081976@postgrespro.ru", "phone": "+70349559713"}
0005435518222	D7BDE4	8545 442826	ALEKSEY GORBUNOV	{"phone": "+70231157455"}
0005435518223	28EE26	5598 016591	ANGELINA MAKAROVA	{"phone": "+70184371279"}
0005435518224	8508F6	2541 990257	LYUDMILA ANTONOVA	{"email": "antonova_lyudmila_1977@postgrespro.ru", "phone": "+70099958587"}
0005435518225	437B62	3202 378604	MIKHAIL IVANOV	{"email": "m_ivanov30071967@postgrespro.ru", "phone": "+70961700932"}
0005435518226	B13A98	6902 691916	TIMUR KUZMIN	{"phone": "+70431510956"}
0005435518227	B13A98	0006 063199	ALEKSANDR BELOV	{"phone": "+70445002320"}
0005435518228	432598	9280 398005	ALEKSANDR SOLOVEV	{"phone": "+70265518890"}
0005435518229	AA9BFB	3918 773010	KIRILL KOZLOV	{"phone": "+70622749057"}
0005435518230	C6BF68	2176 744677	VLADIMIR GRIGOREV	{"phone": "+70717471318"}
0005435518231	58981B	6803 182561	VIOLETTA KOVALEVA	{"phone": "+70252994129"}
0005435518232	0CB097	5734 964380	DANIIL MAKSIMOV	{"phone": "+70577268283"}
0005435518233	740198	8208 177472	IVAN KARPOV	{"email": "i-karpov_1976@postgrespro.ru", "phone": "+70951439689"}
0005435518234	740198	8573 370860	ANNA KOVALEVA	{"phone": "+70790946580"}
0005435518235	CE9F93	7284 222424	TAISIYA ZAYCEVA	{"email": "zaycevat_05011963@postgrespro.ru", "phone": "+70400464634"}
0005435518236	CE9F93	7131 783398	ALEKSEY KUZMIN	{"email": "aleksey.kuzmin.12061972@postgrespro.ru", "phone": "+70284293832"}
0005435518237	A66069	0572 415212	SVETLANA EGOROVA	{"email": "s_egorova_1964@postgrespro.ru", "phone": "+70194176129"}
0005435518238	DBD4B2	7733 359154	VADIM KUZNECOV	{"phone": "+70770821643"}
0005435518239	06C55C	1046 501487	ANNA KAZAKOVA	{"email": "a_kazakova_1979@postgrespro.ru", "phone": "+70666772544"}
0005435518240	A1EB84	9991 983675	GALINA VOLKOVA	{"email": "g.volkova_041971@postgrespro.ru", "phone": "+70983311519"}
0005435518241	A1EB84	3861 952076	ELENA KUZMINA	{"email": "e.kuzmina.041970@postgrespro.ru", "phone": "+70845725572"}
0005435518242	5EC784	1251 065879	NADEZHDA KOZLOVA	{"email": "kozlova_n_02041960@postgrespro.ru", "phone": "+70064184778"}
0005435518243	CEB3AC	9912 988423	TATYANA YAKOVLEVA	{"email": "tyakovleva-121959@postgrespro.ru", "phone": "+70352229943"}
0005435518244	41F5E7	8398 365832	NADEZHDA SIDOROVA	{"phone": "+70561307894"}
0005435518245	41F5E7	7122 777574	EGOR KAZAKOV	{"email": "e-kazakov011978@postgrespro.ru", "phone": "+70556391015"}
0005435518246	A34C7B	7886 460442	MARINA KULIKOVA	{"phone": "+70027720873"}
0005435518247	A34C7B	4637 927161	KSENIYA GUSEVA	{"email": "k-guseva.081973@postgrespro.ru", "phone": "+70347403349"}
0005435518248	1DAB26	4840 446888	VLADIMIR KARPOV	{"email": "vladimir.karpov25031971@postgrespro.ru", "phone": "+70267442664"}
0005435518249	2BD377	6601 800020	LYUBOV FROLOVA	{"phone": "+70938118116"}
0005435518250	2D3146	2183 471803	ANASTASIYA KRASNOVA	{"email": "krasnovaanastasiya-27061971@postgrespro.ru", "phone": "+70391994691"}
0005435518251	620AB6	3362 720543	IGOR KUZNECOV	{"email": "kuznecov-i.011973@postgrespro.ru", "phone": "+70522800902"}
0005435518252	620AB6	4717 411627	ARTEM ABRAMOV	{"email": "a.abramov-081970@postgrespro.ru", "phone": "+70196348267"}
0005435518253	07346E	6537 457213	ARTEM KUZNECOV	{"email": "kuznecova-121978@postgrespro.ru", "phone": "+70825832606"}
0005435518254	5E0FEC	1344 947501	ANNA FROLOVA	{"phone": "+70849968437"}
0005435518255	1D9526	3204 551198	ALEKSANDR POPOV	{"phone": "+70002256330"}
0005435518256	1D9526	7346 090045	ELENA ZAKHAROVA	{"email": "elenazakharova04081957@postgrespro.ru", "phone": "+70702191648"}
0005435518257	0A6969	8074 618825	VLADIMIR PETROV	{"email": "petrov.v_1972@postgrespro.ru", "phone": "+70705697856"}
0005435518258	4B657B	3601 308458	MARINA ZHUKOVA	{"email": "m.zhukova-04051978@postgrespro.ru", "phone": "+70310756325"}
0005435518259	674B3C	8011 136893	KRISTINA ZHURAVLEVA	{"phone": "+70328467184"}
0005435518260	6A5D5E	2375 697912	EKATERINA NIKITINA	{"phone": "+70599997924"}
0005435518261	4A919A	1528 885319	OLGA AFANASEVA	{"phone": "+70195709194"}
0005435518262	9CE737	3107 610175	NIKOLAY BELOV	{"email": "belov-nikolay1968@postgrespro.ru", "phone": "+70809955704"}
0005435518263	F61102	4939 236626	ANTONINA OSIPOVA	{"phone": "+70827236142"}
0005435518264	789B72	6433 881904	TATYANA GAVRILOVA	{"phone": "+70301941347"}
0005435518265	789B72	3754 764051	TATYANA LAZAREVA	{"phone": "+70282908104"}
0005435518266	3F1C8A	3003 800133	GALINA ARKHIPOVA	{"phone": "+70201247394"}
0005435518267	026E55	1407 815725	VLADIMIR VASILEV	{"phone": "+70822195456"}
0005435518268	255ECC	8606 574201	ILYA DAVYDOV	{"email": "davydov_i_28091971@postgrespro.ru", "phone": "+70944326917"}
0005435518269	255ECC	2476 643255	ANDREY RODIONOV	{"phone": "+70672744354"}
0005435518270	6ACE64	8423 768557	SVETLANA SERGEEVA	{"email": "sergeeva_s_1968@postgrespro.ru", "phone": "+70394986209"}
0005435518271	8463DC	6781 498723	MAKSIM ORLOV	{"email": "maksimorlov_1972@postgrespro.ru", "phone": "+70399191053"}
0005435518272	8463DC	5319 557229	TATYANA KALININA	{"email": "tatyana_kalinina.071975@postgrespro.ru", "phone": "+70713840209"}
0005435518273	969E11	9006 693129	ALEKSANDRA ILINA	{"email": "ilina-a-011992@postgrespro.ru", "phone": "+70945739173"}
0005435518274	969E11	8222 782367	SERGEY SOLOVEV	{"phone": "+70796928053"}
0005435518275	2D0D7C	5347 686397	LYUBOV SIDOROVA	{"email": "l_sidorova101973@postgrespro.ru", "phone": "+70737987908"}
0005435518276	09DE61	8212 873725	EVGENIY KUZNECOV	{"email": "kuznecov-evgeniy-11081974@postgrespro.ru", "phone": "+70058571697"}
0005435518277	09DE61	1874 320275	MILENA SOKOLOVA	{"phone": "+70881312508"}
0005435518278	565711	6968 232005	NINA ZAKHAROVA	{"phone": "+70415281930"}
0005435518279	B9EEA6	7640 452110	OLGA VOLKOVA	{"email": "olgavolkova.101973@postgrespro.ru", "phone": "+70515320234"}
0005435518280	45FA12	7248 619058	ANASTASIYA MAKSIMOVA	{"phone": "+70141131238"}
0005435518281	D762FC	3555 583760	ALEKSANDRA ALEKSANDROVA	{"phone": "+70516757947"}
0005435518282	3EE655	4918 362145	ELENA SIDOROVA	{"email": "sidorovae061961@postgrespro.ru", "phone": "+70749985311"}
0005435518283	5A62D2	3383 806835	ANNA MATVEEVA	{"phone": "+70690831326"}
0005435518284	36EFA1	0063 553776	TATYANA PETROVA	{"phone": "+70520888748"}
0005435518285	FE3460	2406 575105	DANIL BORISOV	{"phone": "+70225043556"}
0005435518286	1B344B	8411 315079	DANIL TIMOFEEV	{"phone": "+70973884191"}
0005435518287	DDF7BD	6352 704309	VENIAMIN ALEKSANDROV	{"phone": "+70410193168"}
0005435518288	37DCF2	9835 177353	VLADIMIR VOROBEV	{"phone": "+70831684012"}
0005435518289	37DCF2	5332 388141	ANTONINA NIKITINA	{"phone": "+70352872497"}
0005435518290	86DE96	6358 874429	NIKOLAY ANTONOV	{"phone": "+70680083235"}
0005435518291	86DE96	1334 834526	MARIYA ANISIMOVA	{"email": "m.anisimova_1984@postgrespro.ru", "phone": "+70626596827"}
0005435518292	718EB4	1166 754827	OKSANA KUZMINA	{"email": "kuzmina-oksana-02051980@postgrespro.ru", "phone": "+70751813670"}
0005435518293	CE82D6	8627 663587	ELENA BARANOVA	{"phone": "+70535153240"}
0005435518294	8DE76F	5061 732773	MARIYA NESTEROVA	{"email": "nesterova.mariya_20061972@postgrespro.ru", "phone": "+70342815776"}
0005435518295	27BB3D	6232 426877	VALERIY FEDOTOV	{"email": "vfedotov.29051975@postgrespro.ru", "phone": "+70998143176"}
0005435518296	27BB3D	3716 316927	ANNA MAKAROVA	{"email": "anna.makarova25011967@postgrespro.ru", "phone": "+70617463098"}
0005435518297	4556DA	6778 957480	MARIYA FROLOVA	{"email": "mariya-frolova.101967@postgrespro.ru", "phone": "+70734117018"}
0005435518298	A11229	4401 744166	DARYA ROMANOVA	{"phone": "+70378657757"}
0005435518299	BA7FB8	9502 272426	NINA SERGEEVA	{"phone": "+70244189984"}
0005435518300	B360E1	7854 833362	VIKTOR STEPANOV	{"email": "viktor.stepanov-16021966@postgrespro.ru", "phone": "+70498555334"}
0005435518301	BF51F0	5807 476659	VLADIMIR FILIPPOV	{"email": "filippov-vladimir-111969@postgrespro.ru", "phone": "+70054544404"}
0005435518302	7B9E17	4479 172027	TAMARA SEMENOVA	{"email": "tamara-semenova-30071985@postgrespro.ru", "phone": "+70475374202"}
0005435518303	7B9E17	1466 344269	SERGEY BORISOV	{"email": "borisovsergey_071972@postgrespro.ru", "phone": "+70267402011"}
0005435518304	BF5B29	5435 951718	ALEKSANDR KUDRYASHOV	{"email": "aleksandr_kudryashov_1973@postgrespro.ru", "phone": "+70503796734"}
0005435518305	BF5B29	1083 614458	MIKHAIL MIRONOV	{"email": "mironov.mikhail_06111970@postgrespro.ru", "phone": "+70467050232"}
0005435518306	F0612B	1678 393664	MAKSIM KOZLOV	{"email": "mkozlov1977@postgrespro.ru", "phone": "+70858607431"}
0005435518307	2C5223	5965 731785	SVETLANA MAKAROVA	{"email": "svetlana_makarova_071979@postgrespro.ru", "phone": "+70621778828"}
0005435518308	C8AA4D	3405 419670	ANASTASIYA DAVYDOVA	{"phone": "+70252609512"}
0005435518309	C0C3C0	4768 283401	NADEZHDA KONDRATEVA	{"email": "kondrateva_n.1967@postgrespro.ru", "phone": "+70023553689"}
0005435518310	C0C3C0	1973 121906	EKATERINA OVCHINNIKOVA	{"phone": "+70650533679"}
0005435518311	C0C3C0	9326 633710	RAIS EGOROV	{"email": "egorovrais.16081972@postgrespro.ru", "phone": "+70371706523"}
0005435518312	B04BF7	3749 570636	PAVEL SEMENOV	{"phone": "+70493180041"}
0005435518313	237AAD	7245 047199	NIKOLAY KAZAKOV	{"phone": "+70323240642"}
0005435518314	52D8E5	7225 104090	MIKHAIL SCHERBAKOV	{"phone": "+70134049248"}
0005435518315	1118C7	7434 774838	VIKTOR YAKOVLEV	{"phone": "+70390104447"}
0005435518316	46ADB4	1953 885235	ANATOLIY MAKAROV	{"email": "anatoliymakarov-1981@postgrespro.ru", "phone": "+70167275130"}
0005435518317	46ADB4	4271 730341	TATYANA MEDVEDEVA	{"phone": "+70096526965"}
0005435518318	46ADB4	1294 573926	MARIYA PETROVA	{"phone": "+70761437709"}
0005435518319	8762BB	7825 876765	RUSTAM ANDREEV	{"phone": "+70022532492"}
0005435518320	9DD3EC	9604 325849	ARTEM GRIGOREV	{"email": "a.grigorev_01031972@postgrespro.ru", "phone": "+70156738057"}
0005435518321	9DD3EC	3970 837528	RAISA LUKYANOVA	{"email": "raisa_lukyanova_1976@postgrespro.ru", "phone": "+70052242293"}
0005435518322	3ACBF7	5136 674144	ARTEM SIDOROV	{"email": "a.sidorov_111980@postgrespro.ru", "phone": "+70403692575"}
0005435518323	079812	9792 628506	SVETLANA LUKYANOVA	{"email": "lukyanova_s1978@postgrespro.ru", "phone": "+70520838601"}
0005435518324	8EBD3F	9450 798056	VASILIY ABRAMOV	{"phone": "+70167899348"}
0005435518325	8EBD3F	4788 422097	LYUDMILA KOZLOVA	{"phone": "+70288712333"}
0005435518326	48DE62	0067 223626	LYUDMILA NESTEROVA	{"email": "nesterova-lyudmila.10021976@postgrespro.ru", "phone": "+70899692955"}
0005435518327	5231FB	5562 670804	ZULFIYA MATVEEVA	{"email": "z-matveeva-02031968@postgrespro.ru", "phone": "+70474974119"}
0005435518328	5231FB	9183 962089	MAKSIM KUZNECOV	{"email": "kuznecovm_051971@postgrespro.ru", "phone": "+70952547524"}
0005435518329	E19B1E	2956 234893	NATALYA SEMENOVA	{"email": "semenova-natalya.18051976@postgrespro.ru", "phone": "+70672446096"}
0005435518330	7E1B64	2502 667553	ANVAR IVANOV	{"email": "ivanov.anvar-071973@postgrespro.ru", "phone": "+70749697829"}
0005435518331	695A6D	9201 072618	NIKOLAY SMIRNOV	{"phone": "+70773591318"}
0005435518332	93FAD0	3640 387477	SVETLANA FROLOVA	{"phone": "+70589419593"}
0005435518333	93FAD0	3362 305267	DMITRIY PAVLOV	{"email": "d-pavlov.071981@postgrespro.ru", "phone": "+70853384369"}
0005435518334	FF4136	8104 425299	RAFAEL DAVYDOV	{"phone": "+70248670785"}
0005435518335	FF4136	5368 393762	ALEKSANDR DMITRIEV	{"phone": "+70462652455"}
0005435518336	FF4136	1715 176839	IRINA SIDOROVA	{"phone": "+70742257195"}
0005435518337	612BDF	1867 244625	LILIYA GAVRILOVA	{"email": "gavrilova_liliya.17101976@postgrespro.ru", "phone": "+70433687547"}
0005435518338	B2CA65	3803 045734	VLADIMIR ZHURAVLEV	{"phone": "+70830848303"}
0005435518339	69D433	7581 476833	ALEKSEY SERGEEV	{"phone": "+70230648486"}
0005435518340	AD7AB7	9122 616460	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir.111976@postgrespro.ru", "phone": "+70875160223"}
0005435518341	AD7AB7	4075 122164	ALEKSANDR TIKHONOV	{"email": "tikhonov-a27101977@postgrespro.ru", "phone": "+70362223036"}
0005435518342	CC5FD0	1225 602960	SERGEY ANTONOV	{"phone": "+70575739672"}
0005435518343	CC5FD0	2829 274394	NAIL FROLOV	{"email": "nailfrolov.041963@postgrespro.ru", "phone": "+70482291963"}
0005435518344	E8753F	0365 748083	ZOYA ZHURAVLEVA	{"phone": "+70810202249"}
0005435518345	84FCED	4943 729063	MARIYA POPOVA	{"phone": "+70781662548"}
0005435518346	9B8F4E	1237 093501	ANASTASIYA DAVYDOVA	{"phone": "+70650391756"}
0005435518347	52523C	8436 207138	MARIYA AKIMOVA	{"phone": "+70356402435"}
0005435518348	4083F4	7240 358702	OLGA SOROKINA	{"email": "olgasorokina.1971@postgrespro.ru", "phone": "+70140480166"}
0005435518349	E61E50	2247 228636	MIKHAIL FEDOROV	{"email": "m_fedorov-1967@postgrespro.ru", "phone": "+70137974666"}
0005435518351	8E7B33	8334 843149	ALEKSEY DAVYDOV	{"phone": "+70225818094"}
0005435518352	5A5946	8960 257911	VLADIMIR KUZNECOV	{"email": "kuznecov_vladimir.031964@postgrespro.ru", "phone": "+70011478644"}
0005435518353	0BF238	7192 961313	SERAFIMA CHERNOVA	{"phone": "+70987915478"}
0005435518354	288C6D	0944 761605	ELENA ERMAKOVA	{"email": "e.ermakova_071971@postgrespro.ru", "phone": "+70815568852"}
0005435518355	288C6D	0416 360154	ROMAN CHERNOV	{"phone": "+70162950764"}
0005435518356	288C6D	4932 740643	MARINA MATVEEVA	{"phone": "+70634253727"}
0005435518357	08A15C	0977 741504	DMITRIY KULIKOV	{"phone": "+70256416469"}
0005435518358	F03A0D	8514 551796	NATALYA SIDOROVA	{"phone": "+70519353954"}
0005435518359	8A970D	9237 447095	PAVEL SOROKIN	{"email": "pavel_sorokin_1977@postgrespro.ru", "phone": "+70959296423"}
0005435518360	FC91C9	5485 813711	IRINA NESTEROVA	{"phone": "+70787800610"}
0005435518361	71C59B	0411 422482	TATYANA VASILEVA	{"phone": "+70771323216"}
0005435518362	40F5E7	7903 253399	NINA EGOROVA	{"email": "n-egorova_041976@postgrespro.ru", "phone": "+70027384688"}
0005435518363	E55249	5194 260140	DIANA LAZAREVA	{"phone": "+70771850528"}
0005435518364	BFB0A1	8374 052275	NADEZHDA FILIPPOVA	{"phone": "+70699758519"}
0005435518365	843E6C	1327 455409	NINA ABRAMOVA	{"email": "abramova.n19051960@postgrespro.ru", "phone": "+70098225618"}
0005435518366	38F8BD	8882 667344	ANNA PAVLOVA	{"phone": "+70399087251"}
0005435518367	ECB9B2	4944 937765	EVGENIYA KAZAKOVA	{"phone": "+70768476118"}
0005435518368	4C8A5C	4797 336553	TATYANA MIRONOVA	{"phone": "+70535398376"}
0005435518369	4C8A5C	7530 679700	VLADIMIR VASILEV	{"email": "vladimir.vasilev.1969@postgrespro.ru", "phone": "+70791929452"}
0005435518370	75467D	0215 459716	PETR CHERNOV	{"email": "chernovp-21111965@postgrespro.ru", "phone": "+70916465543"}
0005435518371	75467D	3841 253718	NIKOLAY GORBUNOV	{"email": "n_gorbunov_121975@postgrespro.ru", "phone": "+70225257298"}
0005435518372	75467D	8991 400084	VIKTOR GAVRILOV	{"email": "gavrilov.viktor011979@postgrespro.ru", "phone": "+70374155303"}
0005435518373	6E86DC	4640 113811	VASILIY KISELEV	{"email": "vasiliy.kiselev_041971@postgrespro.ru", "phone": "+70366502699"}
0005435518374	FAC2AC	1400 828417	VLADIMIR ANDREEV	{"email": "vladimirandreev_101973@postgrespro.ru", "phone": "+70956856462"}
0005435518375	D428F5	2416 616307	IVAN MIKHAYLOV	{"email": "mikhaylov.ivan-021976@postgrespro.ru", "phone": "+70157796678"}
0005435518376	E91338	1361 257736	TATYANA ILINA	{"phone": "+70119351701"}
0005435518377	EC8078	8264 177165	DARYA ANTONOVA	{"phone": "+70238377273"}
0005435518378	3DCD39	4955 330619	IRINA KUZNECOVA	{"email": "ikuznecova_1952@postgrespro.ru", "phone": "+70923543687"}
0005435518379	3DCD39	4209 734844	ALEKSEY ABRAMOV	{"email": "alekseyabramov1974@postgrespro.ru", "phone": "+70455824951"}
0005435518380	F8555D	4298 000857	ROMAN POPOV	{"email": "popov-roman.051978@postgrespro.ru", "phone": "+70226646260"}
0005435518381	865F16	9345 610712	ALEKSEY NAUMOV	{"email": "alekseynaumov_051964@postgrespro.ru", "phone": "+70645694366"}
0005435518382	925DBB	0256 745309	ILDAR ABRAMOV	{"email": "ildar_abramov-1986@postgrespro.ru", "phone": "+70333242721"}
0005435518383	735872	3906 617694	EVGENIYA FEDOROVA	{"email": "fedorovaevgeniya-041981@postgrespro.ru", "phone": "+70438725530"}
0005435518384	B1AC07	8505 837675	NATALYA PAVLOVA	{"phone": "+70183650604"}
0005435518385	B1AC07	5244 876639	LYUBOV ABRAMOVA	{"phone": "+70245585162"}
0005435518386	79B619	7682 032867	VALERIY SIDOROV	{"email": "v.sidorov101960@postgrespro.ru", "phone": "+70171832204"}
0005435518387	79B619	6057 334951	VLADIMIR VOROBEV	{"email": "vorobev-vladimir-1968@postgrespro.ru", "phone": "+70990220328"}
0005435518388	262AA7	3385 659545	VERA TIMOFEEVA	{"phone": "+70894779141"}
0005435518389	60B9DB	3418 408340	EVGENIYA ZAKHAROVA	{"phone": "+70481468338"}
0005435518390	60B9DB	6026 377532	ROMAN NIKOLAEV	{"email": "roman.nikolaev-1972@postgrespro.ru", "phone": "+70233513968"}
0005435518391	AC3EB1	9850 485081	VLADIMIR KOZLOV	{"email": "kozlov-vladimir_22051973@postgrespro.ru", "phone": "+70073771172"}
0005435518392	AC3EB1	2924 136121	DMITRIY KUZNECOV	{"email": "kuznecov.dmitriy.1967@postgrespro.ru", "phone": "+70538620154"}
0005435518393	8DB014	7013 125171	SVETLANA AFANASEVA	{"email": "afanaseva.s_1965@postgrespro.ru", "phone": "+70147642380"}
0005435518394	9A8390	1250 116032	ANATOLIY KONOVALOV	{"email": "konovalov.anatoliy-1967@postgrespro.ru", "phone": "+70829283315"}
0005435518395	9A8390	9585 583055	NIKOLAY SAVELEV	{"email": "savelevnikolay-1970@postgrespro.ru", "phone": "+70887840792"}
0005435518396	3E9108	2153 737304	MAKSIM VASILEV	{"email": "maksim-vasilev-21021969@postgrespro.ru", "phone": "+70814230148"}
0005435518397	3E9108	4766 625513	RAISA ZHUKOVA	{"email": "zhukova-r_13061971@postgrespro.ru", "phone": "+70771089578"}
0005435518398	0E5320	0966 637113	YURIY KAZAKOV	{"phone": "+70157066637"}
0005435518399	0E5320	0240 008860	ZINAIDA EGOROVA	{"phone": "+70743559170"}
0005435518400	A46BED	9189 708495	VIKTORIYA OVCHINNIKOVA	{"email": "ovchinnikova_v1982@postgrespro.ru", "phone": "+70331248782"}
0005435518401	D343D6	9321 464716	TAMARA ANDREEVA	{"email": "tamara_andreeva101968@postgrespro.ru", "phone": "+70647068169"}
0005435518402	25DB3A	5131 722896	OLEG TARASOV	{"phone": "+70806696706"}
0005435518403	25DB3A	9261 644259	EVGENIY NAUMOV	{"phone": "+70414985461"}
0005435518404	C78B3F	2381 385011	GALINA SMIRNOVA	{"phone": "+70929160229"}
0005435518405	BBEA27	3300 416092	ANDREY BORISOV	{"email": "borisov.a-1967@postgrespro.ru", "phone": "+70903928853"}
0005435518406	B7C74A	8678 986450	VITALIY ROMANOV	{"email": "romanov-v091978@postgrespro.ru", "phone": "+70509306555"}
0005435518407	4ED2B8	6970 617401	IGOR KRASNOV	{"phone": "+70282286367"}
0005435518408	665426	7909 297627	OLESYA PAVLOVA	{"email": "pavlovaolesya.091981@postgrespro.ru", "phone": "+70564228553"}
0005435518409	A7B1EC	4298 631600	DMITRIY VOLKOV	{"email": "dmitriy_volkov_18091977@postgrespro.ru", "phone": "+70004326436"}
0005435518410	A7B1EC	7808 504879	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov-101979@postgrespro.ru", "phone": "+70715403045"}
0005435518411	F39F2C	2282 124877	KIRILL EGOROV	{"email": "kirill_egorov_1977@postgrespro.ru", "phone": "+70691361008"}
0005435518412	3E95B7	3038 954620	ALEKSANDR EGOROV	{"phone": "+70116726952"}
0005435518413	3E95B7	9796 289478	LIDIYA MEDVEDEVA	{"phone": "+70151079945"}
0005435518414	85183A	9668 901788	TATYANA MOROZOVA	{"email": "tatyana.morozova_021970@postgrespro.ru", "phone": "+70292532965"}
0005435518415	85183A	9136 926242	POLINA SOKOLOVA	{"phone": "+70641655476"}
0005435518416	DF418F	9773 226976	IRINA NIKITINA	{"phone": "+70974094356"}
0005435518417	06BC3D	0447 433772	LYUBOV ROMANOVA	{"email": "lyubov-romanova051977@postgrespro.ru", "phone": "+70279521296"}
0005435518418	06BC3D	4022 255457	KLAVDIYA LOGINOVA	{"phone": "+70247381681"}
0005435518419	006CBB	4702 617763	SEMEN BELOV	{"email": "belov-semen1968@postgrespro.ru", "phone": "+70189395197"}
0005435518420	4D6366	8474 854341	ANASTASIYA EGOROVA	{"phone": "+70512066590"}
0005435518421	4D6366	5840 291531	VERA KOROLEVA	{"email": "koroleva.v_041971@postgrespro.ru", "phone": "+70473772019"}
0005435518422	151B2F	5974 428306	ALEKSANDR PETROV	{"email": "aleksandrpetrov_1967@postgrespro.ru", "phone": "+70326733806"}
0005435518423	CD31E1	8327 836181	ALEKSEY BELOV	{"email": "a-belov.19081969@postgrespro.ru", "phone": "+70251652181"}
0005435518424	ECDC8D	9176 539666	VIOLETTA RODIONOVA	{"email": "rodionova-violetta_09091966@postgrespro.ru", "phone": "+70943585989"}
0005435518425	C5401F	9515 389789	ALEKSEY SMIRNOV	{"email": "asmirnov.1965@postgrespro.ru", "phone": "+70511838424"}
0005435518426	C5401F	0692 280795	EVGENIY ALEKSANDROV	{"email": "aleksandrovevgeniy.061968@postgrespro.ru", "phone": "+70313360511"}
0005435518427	EF1021	6797 386405	ALEKSEY SOKOLOV	{"email": "asokolov.081974@postgrespro.ru", "phone": "+70432100521"}
0005435518428	EF1021	0353 222145	TATYANA BORISOVA	{"email": "borisovat.1973@postgrespro.ru", "phone": "+70153116359"}
0005435518429	24B72F	6220 705490	VLADIMIR ANTONOV	{"email": "antonovv-081974@postgrespro.ru", "phone": "+70021985837"}
0005435518430	776A4D	4759 813276	LYUBOV POPOVA	{"email": "popova_l-02121967@postgrespro.ru", "phone": "+70704531587"}
0005435518431	776A4D	0049 940942	ALEKSANDR SOKOLOV	{"email": "aleksandrsokolov-091983@postgrespro.ru", "phone": "+70371204357"}
0005435518432	274BFE	2088 061603	MIKHAIL NIKOLAEV	{"phone": "+70581596104"}
0005435518433	F8F12A	8579 168662	GENNADIY SCHERBAKOV	{"email": "scherbakov-gennadiy.111963@postgrespro.ru", "phone": "+70384989889"}
0005435518434	E52B0D	3249 525103	VLADIMIR KUZNECOV	{"phone": "+70861021651"}
0005435518435	2D2D1D	4709 481886	PAVEL ISAEV	{"email": "isaev.pavel011979@postgrespro.ru", "phone": "+70686475026"}
0005435518436	E70CD9	9438 950344	PAVEL ZHUKOV	{"email": "pavel-zhukov011969@postgrespro.ru", "phone": "+70055211940"}
0005435518437	E70CD9	2070 090820	IRINA MELNIKOVA	{"email": "i.melnikova1978@postgrespro.ru", "phone": "+70613423792"}
0005435518438	A1A3D0	2991 306627	ELENA SAVELEVA	{"email": "saveleva_elena.01011974@postgrespro.ru", "phone": "+70018271623"}
0005435518439	116A1E	6058 464272	SVETLANA YAKOVLEVA	{"phone": "+70649177022"}
0005435518440	7E65AC	9098 521067	NIKOLAY FEDOTOV	{"email": "nikolayfedotov.111966@postgrespro.ru", "phone": "+70171503666"}
0005435518441	7E65AC	1715 788936	NATALYA FILIPPOVA	{"phone": "+70271110259"}
0005435518442	AB4C5A	8824 245318	INNA NOVIKOVA	{"email": "novikova_inna10021966@postgrespro.ru", "phone": "+70365247333"}
0005435518443	37383C	9580 755065	ALEKSEY SHEVCHENKO	{"email": "aleksey-shevchenko_1970@postgrespro.ru", "phone": "+70290686124"}
0005435518444	37383C	7644 005837	VLADIMIR KUZNECOV	{"email": "kuznecov-vladimir_101978@postgrespro.ru", "phone": "+70061309667"}
0005435518445	CA6F07	2805 997143	ALEKSEY KAZAKOV	{"email": "aleksey_kazakov.091976@postgrespro.ru", "phone": "+70867720855"}
0005435518446	CA6F07	9540 424090	NIKOLAY ZAKHAROV	{"email": "zakharov.nikolay101981@postgrespro.ru", "phone": "+70657487085"}
0005435518447	DCC5BF	4023 282469	VIKTOR FROLOV	{"email": "v_frolov09021973@postgrespro.ru", "phone": "+70003628279"}
0005435518448	537B90	3587 838886	NATALYA KUZNECOVA	{"phone": "+70087726714"}
0005435518449	537B90	8291 094545	PETR FILIPPOV	{"email": "p-filippov_1975@postgrespro.ru", "phone": "+70468000042"}
0005435518450	4FB5F2	4521 205747	GALINA IVANOVA	{"email": "g_ivanova-1967@postgrespro.ru", "phone": "+70271033174"}
0005435518451	4FB5F2	6755 421532	ALEKSEY ROMANOV	{"email": "romanov.a_1975@postgrespro.ru", "phone": "+70615458041"}
0005435518452	964F07	6483 893006	ALEKSEY ALEKSEEV	{"phone": "+70449921688"}
0005435518453	5E00A6	8141 249552	SERGEY MOROZOV	{"email": "sergey-morozov.091974@postgrespro.ru", "phone": "+70422472512"}
0005435518454	F5B7B4	6841 772977	EVGENIY POPOV	{"phone": "+70962620883"}
0005435518455	4B2474	7362 615139	ANDREY KUZNECOV	{"email": "andreykuznecov_1973@postgrespro.ru", "phone": "+70368234400"}
0005435518456	F37E31	0359 310346	GRIGORIY KAZAKOV	{"email": "kazakov_grigoriy-1965@postgrespro.ru", "phone": "+70533438585"}
0005435518457	F37E31	2560 514011	IVAN DENISOV	{"email": "denisovivan_04011971@postgrespro.ru", "phone": "+70777768183"}
0005435518458	483716	3107 680159	ANTONINA IVANOVA	{"email": "a.ivanova.091967@postgrespro.ru", "phone": "+70647602662"}
0005435518459	483716	6037 633212	GRIGORIY ZAKHAROV	{"email": "zakharovg1979@postgrespro.ru", "phone": "+70378590988"}
0005435518460	4C9C0F	1718 758018	EKATERINA ZAYCEVA	{"phone": "+70814279126"}
0005435518461	00DC6F	6045 471022	EKATERINA TROFIMOVA	{"phone": "+70833379746"}
0005435528898	581CD5	8283 985081	KRISTINA STEPANOVA	{"phone": "+70029615605"}
0005435528879	D48C55	7835 086575	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov-1976@postgrespro.ru", "phone": "+70127413694"}
0005435528880	D48C55	0743 151557	VLADISLAV SMIRNOV	{"phone": "+70135518242"}
0005435528881	0C8DF1	2730 612791	VALENTINA VASILEVA	{"email": "vasileva_v-07041973@postgrespro.ru", "phone": "+70812653206"}
0005435528882	411888	4676 854582	NATALYA VLASOVA	{"phone": "+70185527733"}
0005435528883	AAF3B7	3425 132450	MATVEY KARPOV	{"email": "karpov_matvey.051971@postgrespro.ru", "phone": "+70513274604"}
0005435528884	D76B59	1187 497060	TATYANA POPOVA	{"email": "popova.tatyana.1967@postgrespro.ru", "phone": "+70942717856"}
0005435528885	D76B59	5878 098625	VERA FILIPPOVA	{"email": "vera_filippova.1968@postgrespro.ru", "phone": "+70606365371"}
0005435528886	D76B59	7698 567550	RAFIK ABRAMOV	{"phone": "+70821421344"}
0005435528887	D76B59	1049 143451	EKATERINA ANTONOVA	{"phone": "+70509492918"}
0005435528888	082BC4	5039 486979	ALEKSEY ANTONOV	{"email": "antonov_a.23121979@postgrespro.ru", "phone": "+70152843205"}
0005435528889	8FF12B	0321 688645	LYUDMILA SEMENOVA	{"phone": "+70471209213"}
0005435528890	ABE373	5080 099129	NIKOLAY FILIPPOV	{"phone": "+70108442900"}
0005435528891	ABE373	5043 348566	IVAN NIKOLAEV	{"email": "nikolaev.i.061972@postgrespro.ru", "phone": "+70679531349"}
0005435528892	9E8AD3	8812 447520	OKSANA ROMANOVA	{"email": "romanova_o1969@postgrespro.ru", "phone": "+70887781640"}
0005435528893	EC23EC	0290 154501	NIKOLAY ALEKSANDROV	{"phone": "+70653368223"}
0005435528894	509753	7067 686595	ELVIRA KUZMINA	{"email": "elvira.kuzmina_1973@postgrespro.ru", "phone": "+70412694888"}
0005435528895	8A11DA	8724 119732	ALEKSANDR AFANASEV	{"email": "afanaseva-14041971@postgrespro.ru", "phone": "+70217900382"}
0005435528896	AF52E2	9577 529325	VALENTINA ROMANOVA	{"email": "v.romanova-111979@postgrespro.ru", "phone": "+70821575846"}
0005435528897	52C8C6	2308 784363	ALEKSANDR DENISOV	{"email": "denisov_aleksandr.1964@postgrespro.ru", "phone": "+70912122338"}
0005435528899	E193D5	6832 297826	TAISIYA LEBEDEVA	{"phone": "+70605184375"}
0005435528900	E193D5	7267 162514	MAKSIM IVANOV	{"phone": "+70060328645"}
0005435528901	F9FFC6	2893 924947	NATALYA AFANASEVA	{"email": "afanaseva_natalya-1976@postgrespro.ru", "phone": "+70098032454"}
0005435528902	2C9D48	3087 447781	KRISTINA ANISIMOVA	{"email": "kristina_anisimova.111977@postgrespro.ru", "phone": "+70712649292"}
0005435528903	AEC980	0456 476788	ANDREY VOROBEV	{"phone": "+70186699137"}
0005435528904	B3CF51	2510 079095	VERONIKA ILINA	{"email": "ilina.v_08091980@postgrespro.ru", "phone": "+70875346571"}
0005435528905	B3CF51	4576 285076	GENNADIY IVANOV	{"email": "gennadiy_ivanov_1974@postgrespro.ru", "phone": "+70423604485"}
0005435528906	FE0E06	1446 807307	ELENA SAVELEVA	{"phone": "+70862573534"}
0005435528907	5C37F2	9410 326620	KONSTANTIN ROMANOV	{"phone": "+70865703330"}
0005435528908	BF108B	1398 335184	MAKSIM CHERNOV	{"phone": "+70060086819"}
0005435528909	71FE8E	0983 361732	SERGEY AFANASEV	{"email": "sergey.afanasev.1967@postgrespro.ru", "phone": "+70212417927"}
0005435528910	46C311	0161 196835	MIKHAIL PETROV	{"email": "petrov_mikhail_04011973@postgrespro.ru", "phone": "+70864536465"}
0005435528911	B6C8FA	6540 215236	SERGEY KUZMIN	{"phone": "+70286589357"}
0005435528912	B6C8FA	5108 971340	ALEKSANDRA POLYAKOVA	{"email": "aleksandra.polyakova1979@postgrespro.ru", "phone": "+70173615687"}
0005435528913	7375D2	4229 534381	DMITRIY ZAKHAROV	{"email": "dmitriy_zakharov.1977@postgrespro.ru", "phone": "+70612291105"}
0005435528914	9BFCD8	3566 148503	PETR TARASOV	{"phone": "+70346644923"}
0005435528915	C21FD3	7406 186024	ELENA KOVALEVA	{"phone": "+70957561498"}
0005435528916	AAC1A4	1232 764329	ALLA IVANOVA	{"email": "alla-ivanova_1965@postgrespro.ru", "phone": "+70051253732"}
0005435528917	D82E71	1635 350224	TATYANA TIKHONOVA	{"email": "tikhonova_t-081966@postgrespro.ru", "phone": "+70609233288"}
0005435528918	D261A2	1929 318601	MIKHAIL NAZAROV	{"phone": "+70007913722"}
0005435528919	D261A2	8139 324704	VIKTOR ILIN	{"email": "ilin-viktor.1968@postgrespro.ru", "phone": "+70841587133"}
0005435528920	E41E75	0426 470821	VIKTOR KAZAKOV	{"phone": "+70628560387"}
0005435528921	D1CBCE	0911 195839	SVETLANA KOZLOVA	{"phone": "+70619633864"}
0005435528922	724AF6	2976 810511	VITALIY MIRONOV	{"email": "vitaliy-mironov071979@postgrespro.ru", "phone": "+70764547253"}
0005435528923	452484	0652 767488	TATYANA SOROKINA	{"email": "t-sorokina_021970@postgrespro.ru", "phone": "+70654593360"}
0005435528924	452484	7941 896990	ALEKSANDR IVANOV	{"email": "ivanov-aleksandr-061975@postgrespro.ru", "phone": "+70052784864"}
0005435528925	A55ED8	0199 960826	SOFIYA SCHERBAKOVA	{"phone": "+70811277067"}
0005435528926	A55ED8	8736 908317	ALEKSANDR STEPANOV	{"email": "astepanov_28051973@postgrespro.ru", "phone": "+70305990740"}
0005435528927	A55ED8	2565 075032	ARINA STEPANOVA	{"email": "stepanovaa_16041988@postgrespro.ru", "phone": "+70715437069"}
0005435528928	BB482B	5125 446548	NIKOLAY POPOV	{"email": "n_popov-04061968@postgrespro.ru", "phone": "+70579623640"}
0005435528929	BB482B	8175 891328	VENIAMIN NIKOLAEV	{"email": "v-nikolaev-1977@postgrespro.ru", "phone": "+70282895845"}
0005435528930	BB482B	5042 835283	ELIZAVETA MASLOVA	{"email": "e-maslova-22081975@postgrespro.ru", "phone": "+70966853682"}
0005435528931	BB482B	4555 956551	KRISTINA KOLESNIKOVA	{"email": "kolesnikova.k-19031966@postgrespro.ru", "phone": "+70134251369"}
0005435528932	DF28A3	6991 277267	PAVEL NAUMOV	{"phone": "+70772540250"}
0005435528933	E23A41	9816 528314	NIKITA VASILEV	{"email": "vasilev_n-1974@postgrespro.ru", "phone": "+70136040865"}
0005435528934	070091	2796 236794	NADEZHDA MAKSIMOVA	{"phone": "+70527144928"}
0005435528935	059503	2028 768278	IRINA DANILOVA	{"phone": "+70232792417"}
0005435528936	850C97	3502 105436	TATYANA MASLOVA	{"email": "tatyanamaslova041969@postgrespro.ru", "phone": "+70678106201"}
0005435528937	100984	7779 537266	NATALYA TIKHONOVA	{"phone": "+70422846763"}
0005435528938	309F03	5059 040710	DENIS NOVIKOV	{"phone": "+70984548417"}
0005435528939	309F03	3711 882182	LYUDMILA ALEKSANDROVA	{"email": "aleksandrova-l.08061977@postgrespro.ru", "phone": "+70050949632"}
0005435528940	4DA50C	8740 253008	ALEKSANDR SMIRNOV	{"phone": "+70702161595"}
0005435528941	181A9A	6658 304744	ALEKSANDR GUSEV	{"phone": "+70062490379"}
0005435528942	BDDC75	6841 602236	OLGA KOZLOVA	{"email": "kozlova.olga061978@postgrespro.ru", "phone": "+70205599695"}
0005435528943	2F09E4	2620 002046	DARYA ABRAMOVA	{"email": "darya_abramova091960@postgrespro.ru", "phone": "+70721823598"}
0005435528944	49836A	6233 369476	ANTON SCHERBAKOV	{"email": "a_scherbakov_20081983@postgrespro.ru", "phone": "+70683710173"}
0005435528945	49836A	9680 205367	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov-1980@postgrespro.ru", "phone": "+70952500684"}
0005435528946	49836A	1833 181386	ANATOLIY PAVLOV	{"email": "a_pavlov-1984@postgrespro.ru", "phone": "+70200097661"}
0005435528947	E63649	7332 602561	EVGENIYA TIKHONOVA	{"phone": "+70478609525"}
0005435528948	0241BF	5097 774736	VADIM NIKITIN	{"phone": "+70083398043"}
0005435528949	0241BF	5170 281643	VIKTOR PETROV	{"email": "petrovviktor.30091969@postgrespro.ru", "phone": "+70068105805"}
0005435528950	42A828	8573 359301	SERGEY DENISOV	{"phone": "+70459586563"}
0005435528951	E1D470	4292 528335	TATYANA DANILOVA	{"email": "danilovat081978@postgrespro.ru", "phone": "+70731419493"}
0005435528952	E1D470	1509 227744	VIKTOR KULIKOV	{"email": "kulikov.viktor_071965@postgrespro.ru", "phone": "+70476248665"}
0005435528953	E56207	0153 137939	TATYANA VASILEVA	{"phone": "+70706714805"}
0005435528954	3C94F1	2206 237154	VALENTIN ABRAMOV	{"email": "vabramov_1955@postgrespro.ru", "phone": "+70659311222"}
0005435528955	90AAE3	6318 145636	ALEKSANDR VOLKOV	{"email": "avolkov-1954@postgrespro.ru", "phone": "+70654720490"}
0005435528956	90AAE3	2151 931689	ALBINA MEDVEDEVA	{"email": "a.medvedeva_09021973@postgrespro.ru", "phone": "+70717287793"}
0005435528957	92036B	7131 782722	LARISA SOLOVEVA	{"phone": "+70158904669"}
0005435528958	34D5D4	5580 269163	SERGEY SOKOLOV	{"phone": "+70983214524"}
0005435528959	34D5D4	5419 170131	NADEZHDA POPOVA	{"email": "popova.nadezhda-111969@postgrespro.ru", "phone": "+70895785145"}
0005435528960	C69CC4	7868 772698	NATALYA ANTONOVA	{"email": "antonova-natalya25041981@postgrespro.ru", "phone": "+70288274259"}
0005435528961	84D56E	2395 221157	ALEKSANDR STEPANOV	{"phone": "+70761213890"}
0005435528962	84D56E	4499 235841	EKATERINA STEPANOVA	{"phone": "+70463353855"}
0005435528963	05C426	9542 950564	NINA IVANOVA	{"email": "ivanovanina.29051963@postgrespro.ru", "phone": "+70149680127"}
0005435528964	082BCF	6451 131652	DARYA MATVEEVA	{"phone": "+70687193627"}
0005435528965	DA5387	2178 299157	INNA ZHUKOVA	{"email": "zhukova-i1969@postgrespro.ru", "phone": "+70040388998"}
0005435528966	DA5387	1949 549148	VALENTINA KUZNECOVA	{"phone": "+70237628958"}
0005435528967	A72C36	0865 276577	SERGEY IVANOV	{"phone": "+70199830447"}
0005435528968	470874	1224 748706	LYUDMILA NOVIKOVA	{"email": "l-novikova-101986@postgrespro.ru", "phone": "+70496982836"}
0005435528969	A8CCA3	8915 165671	GALINA BORISOVA	{"phone": "+70585348829"}
0005435528970	06A83D	9634 561836	TATYANA MIKHAYLOVA	{"phone": "+70452984332"}
0005435528971	3E249F	4422 684713	ALEKSEY PAVLOV	{"email": "pavlov_a-21011969@postgrespro.ru", "phone": "+70191798197"}
0005435528972	20B904	6278 727134	NIKOLAY KUZMIN	{"email": "n_kuzmin.10121971@postgrespro.ru", "phone": "+70080576016"}
0005435528973	20B904	1706 088500	DARYA BARANOVA	{"phone": "+70354903410"}
0005435528974	A607C7	0819 560489	NINA KONDRATEVA	{"phone": "+70935408844"}
0005435528975	A607C7	6479 220850	NIKOLAY GORBUNOV	{"phone": "+70237998966"}
0005435528976	AE2C68	1302 484531	NINA MIKHAYLOVA	{"phone": "+70318157942"}
0005435528977	AE2C68	2081 364745	NATALYA STEPANOVA	{"email": "stepanova_natalya.10041959@postgrespro.ru", "phone": "+70287362909"}
0005435528978	D7E24E	2770 276073	SVETLANA MAKAROVA	{"email": "makarova.svetlana.1970@postgrespro.ru", "phone": "+70169254971"}
0005435528979	D7E24E	1416 163630	LYUBOV TIKHONOVA	{"email": "lyubov.tikhonova_05051970@postgrespro.ru", "phone": "+70956450053"}
0005435528980	139117	9291 912666	SHAMIL KUDRYASHOV	{"email": "kudryashovs.1969@postgrespro.ru", "phone": "+70631905907"}
0005435528981	31A861	6230 025691	ANASTASIYA IVANOVA	{"email": "ivanova.a26121975@postgrespro.ru", "phone": "+70883748140"}
0005435528982	E88846	3752 940767	ELENA DENISOVA	{"phone": "+70882203762"}
0005435528983	FF72D9	8659 949298	VALENTINA MIRONOVA	{"email": "mironova.v1983@postgrespro.ru", "phone": "+70326150448"}
0005435528984	FF72D9	4656 028506	VALENTINA EGOROVA	{"email": "vegorova-071969@postgrespro.ru", "phone": "+70617444827"}
0005435528985	D0F4B8	6868 810957	TATYANA MEDVEDEVA	{"email": "medvedeva-tatyana-121977@postgrespro.ru", "phone": "+70226256415"}
0005435528986	D0F4B8	4145 931273	RADIK OSIPOV	{"email": "osipov_radik.1973@postgrespro.ru", "phone": "+70016840389"}
0005435528987	78505D	4204 095727	YULIYA KOZLOVA	{"phone": "+70406233987"}
0005435528988	78505D	4077 798537	IRINA OSIPOVA	{"phone": "+70809597926"}
0005435528989	8CFEDB	4668 243120	VITALIY FEDOTOV	{"phone": "+70533938572"}
0005435528990	2B6DD6	8741 960987	EDUARD KOZLOV	{"phone": "+70524918461"}
0005435528991	C8F647	9973 266605	SVETLANA BARANOVA	{"phone": "+70271173331"}
0005435528992	0A826C	9244 708680	LYUDMILA MIKHAYLOVA	{"phone": "+70330772146"}
0005435528993	374315	4456 310220	NINA KOVALEVA	{"phone": "+70608584004"}
0005435528994	6FEA32	5101 431808	TATYANA KOROLEVA	{"email": "tatyanakoroleva_24061967@postgrespro.ru", "phone": "+70869295064"}
0005435528995	D200E3	7471 423998	ALEKSEY KONOVALOV	{"phone": "+70062373370"}
0005435528996	7F96F7	7624 675461	IGOR FILIPPOV	{"email": "filippov-igor_20021972@postgrespro.ru", "phone": "+70620438821"}
0005435528997	7F96F7	2173 181437	VALERIY SOKOLOV	{"email": "sokolovvaleriy-031970@postgrespro.ru", "phone": "+70929465421"}
0005435528998	F4D429	0203 204488	NATALYA SAVELEVA	{"phone": "+70175552856"}
0005435528999	B60D04	9670 280723	ANNA KARPOVA	{"phone": "+70620449584"}
0005435529000	D6D1D9	3128 804959	IRINA VOROBEVA	{"phone": "+70371261695"}
0005435529001	D6D1D9	6110 375375	DARYA MASLOVA	{"email": "d-maslova.29051977@postgrespro.ru", "phone": "+70354220320"}
0005435529002	15908C	6926 304349	ALEKSANDR SOKOLOV	{"phone": "+70944424550"}
0005435529003	FBD8EF	7573 799637	ANNA TARASOVA	{"email": "tarasova_anna-22101967@postgrespro.ru", "phone": "+70745365297"}
0005435529004	FBD8EF	1560 049622	YURIY KISELEV	{"phone": "+70609815424"}
0005435529005	FBD8EF	9300 649694	KIRILL OSIPOV	{"phone": "+70146174416"}
0005435529006	5BC1AE	3924 267050	LYUBOV ZAYCEVA	{"email": "zayceva.l.1990@postgrespro.ru", "phone": "+70576250632"}
0005435529007	5BC1AE	4871 832824	SVETLANA KOROLEVA	{"email": "koroleva.svetlana_1973@postgrespro.ru", "phone": "+70424481401"}
0005435529008	D188EF	4656 044697	VITALIY SAVELEV	{"email": "vitaliy-savelev-1971@postgrespro.ru", "phone": "+70216248195"}
0005435529009	B23076	2243 027628	SVETLANA VOLKOVA	{"phone": "+70541344175"}
0005435529010	C89F6F	9302 423848	ALEKSANDR MOROZOV	{"email": "aleksandrmorozov-26021982@postgrespro.ru", "phone": "+70225470001"}
0005435529011	5598F7	5384 816531	NIKOLAY ZAKHAROV	{"phone": "+70048581382"}
0005435529012	5598F7	9062 156723	GALINA PAVLOVA	{"phone": "+70553701616"}
0005435529013	618D7A	6953 440501	EVGENIY PAVLOV	{"email": "pavlov-e-111961@postgrespro.ru", "phone": "+70630895518"}
0005435529014	618D7A	4589 161080	NURIYA KAZAKOVA	{"email": "kazakovanuriya.14061964@postgrespro.ru", "phone": "+70736973935"}
0005435529015	590E21	4476 759352	ELENA KOROLEVA	{"phone": "+70065501462"}
0005435529016	1B6460	8708 940299	PAVEL VASILEV	{"phone": "+70526148488"}
0005435529017	D4B0C7	9318 106627	ALEKSANDR VOLKOV	{"phone": "+70236133038"}
0005435529018	D4B0C7	1882 105293	RUSLAN YAKOVLEV	{"email": "yakovlev.ruslan-061960@postgrespro.ru", "phone": "+70115613120"}
0005435529019	81A1AB	3300 659571	OLEG KUZNECOV	{"email": "kuznecov_oleg-18021978@postgrespro.ru", "phone": "+70149138120"}
0005435529020	34F9D7	8678 673175	VLADIMIR SEMENOV	{"phone": "+70409785390"}
0005435529021	ED8661	1221 915670	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov-1961@postgrespro.ru", "phone": "+70987566517"}
0005435529022	4E5544	6031 781954	TATYANA NIKOLAEVA	{"email": "tatyana-nikolaeva.14111961@postgrespro.ru", "phone": "+70018356092"}
0005435529023	4E5544	0029 042906	TATYANA FADEEVA	{"email": "fadeeva.t-1967@postgrespro.ru", "phone": "+70131138579"}
0005435529024	7C1A18	6269 930330	NIKOLAY EGOROV	{"email": "egorov_n_1971@postgrespro.ru", "phone": "+70326844014"}
0005435529025	FA25C6	1016 812501	ALEKSANDR IVANOV	{"phone": "+70800576811"}
0005435529026	B5FB19	3969 285541	DENIS MIKHAYLOV	{"email": "mikhaylov_d-03021968@postgrespro.ru", "phone": "+70775499888"}
0005435529027	34A8A1	4592 397329	EKATERINA DMITRIEVA	{"phone": "+70670211667"}
0005435529028	33971B	0805 808094	EVGENIY MARTYNOV	{"email": "e.martynov.021969@postgrespro.ru", "phone": "+70098000092"}
0005435529029	0DBFF8	5896 683558	GEORGIY SERGEEV	{"phone": "+70227507168"}
0005435529030	329DAD	4791 454863	ANNA NIKITINA	{"phone": "+70376296033"}
0005435529031	9436AE	4721 359577	KRISTINA MOISEEVA	{"email": "moiseeva-kristina-12051984@postgrespro.ru", "phone": "+70889638976"}
0005435529032	86CBFF	3504 709599	ELENA DANILOVA	{"email": "elena.danilova_121966@postgrespro.ru", "phone": "+70354603926"}
0005435529033	86CBFF	3162 835562	ELENA KUZNECOVA	{"email": "e_kuznecova-19091975@postgrespro.ru", "phone": "+70153527218"}
0005435529034	62B3BE	8607 046004	MARINA KOROLEVA	{"phone": "+70509469919"}
0005435529035	62B3BE	0784 854944	LEV VOROBEV	{"phone": "+70953524332"}
0005435529036	62B3BE	7944 273976	GALINA EGOROVA	{"email": "galina-egorova-1975@postgrespro.ru", "phone": "+70565084875"}
0005435529037	32995F	2393 569987	TATYANA BARANOVA	{"email": "baranova-t-031975@postgrespro.ru", "phone": "+70325671021"}
0005435529038	BE5B38	6763 319763	VASILIY OSIPOV	{"phone": "+70470610071"}
0005435529039	67161A	7348 211330	ANDREY NIKITIN	{"phone": "+70978284249"}
0005435529040	3C20D1	4098 090761	ELENA ANDREEVA	{"phone": "+70752558494"}
0005435529041	F8B1D9	8513 205226	NIKOLAY ZAYCEV	{"email": "zaycevn.1980@postgrespro.ru", "phone": "+70023305787"}
0005435529042	2023EA	8044 686519	ELENA NOVIKOVA	{"phone": "+70572714548"}
0005435529043	35C61C	5910 075904	TATYANA BELOVA	{"email": "t-belova1969@postgrespro.ru", "phone": "+70102353892"}
0005435529044	35C61C	2932 649856	MARIYA SOKOLOVA	{"phone": "+70493920016"}
0005435529045	33D649	2943 958324	ARTEM KARPOV	{"phone": "+70983483340"}
0005435529046	3C0526	5072 834722	IVAN NOVIKOV	{"phone": "+70807422485"}
0005435529047	3C0526	4015 742040	RUSLAN NAZAROV	{"email": "nazarov_r121959@postgrespro.ru", "phone": "+70471721600"}
0005435529048	9204F8	5985 368866	ANDREY MATVEEV	{"email": "matveevandrey-1964@postgrespro.ru", "phone": "+70824088427"}
0005435529049	9204F8	0549 311770	LARISA MAKAROVA	{"email": "makarova_l_1963@postgrespro.ru", "phone": "+70916971133"}
0005435529050	9204F8	9178 284455	VLADISLAV SOROKIN	{"email": "sorokinvladislav.1969@postgrespro.ru", "phone": "+70689998191"}
0005435529051	9204F8	5966 640554	NIKOLAY POPOV	{"email": "popov-n_05071965@postgrespro.ru", "phone": "+70585837685"}
0005435529052	84CE3A	5011 679133	OLGA SCHERBAKOVA	{"phone": "+70494596848"}
0005435529053	78B424	8488 321527	YULIYA SCHERBAKOVA	{"email": "scherbakova_yuliya-101963@postgrespro.ru", "phone": "+70689742185"}
0005435529054	405EF3	2631 704991	VLADIMIR YAKOVLEV	{"phone": "+70441244095"}
0005435529055	20B18E	3134 905237	VALERIYA POPOVA	{"email": "popova_valeriya_1975@postgrespro.ru", "phone": "+70652105299"}
0005435529056	ECEF4D	7137 836651	ALEKSANDR ZAKHAROV	{"phone": "+70272638635"}
0005435529057	80A253	2435 119443	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir-051983@postgrespro.ru", "phone": "+70190700710"}
0005435529058	9620A6	0791 533615	AZAT ZHURAVLEV	{"phone": "+70696233098"}
0005435529059	5428D9	7953 011211	VALERIY TARASOV	{"phone": "+70025163875"}
0005435529060	5029DE	7599 707658	ZINAIDA AFANASEVA	{"phone": "+70076212780"}
0005435529061	C405C8	7345 734561	MAKSIM ZHUKOV	{"phone": "+70650569762"}
0005435529062	D3B97B	9614 023062	VALERIY NAZAROV	{"email": "nazarov.v121967@postgrespro.ru", "phone": "+70223896665"}
0005435529063	A5D9A1	4812 227523	ALEKSEY DMITRIEV	{"email": "dmitriev_aleksey.091977@postgrespro.ru", "phone": "+70701761778"}
0005435529064	187262	7187 101518	AMIR ILIN	{"phone": "+70142479373"}
0005435529065	187262	6368 066822	VALENTINA KUZNECOVA	{"email": "vkuznecova.041971@postgrespro.ru", "phone": "+70336638105"}
0005435529066	1F6441	3887 191957	NIKOLAY YAKOVLEV	{"phone": "+70498441495"}
0005435529067	1F6441	7828 600991	NADEZHDA KRASNOVA	{"email": "nadezhdakrasnova-11101965@postgrespro.ru", "phone": "+70385561971"}
0005435529068	743FFF	0119 644074	SERGEY POPOV	{"phone": "+70769135521"}
0005435529069	FC6863	6649 396241	OLGA ABRAMOVA	{"email": "abramova_o-101981@postgrespro.ru", "phone": "+70285471413"}
0005435529070	EDC6A3	9233 301934	IGOR ALEKSANDROV	{"phone": "+70390808886"}
0005435529071	6A9748	5836 963552	ANASTASIYA SMIRNOVA	{"phone": "+70638319761"}
0005435529072	73CBCC	4787 226007	PAVEL BORISOV	{"phone": "+70606722105"}
0005435529073	7F597E	0914 224036	VALERIY KONOVALOV	{"email": "valeriy_konovalov-011984@postgrespro.ru", "phone": "+70912244033"}
0005435529074	4C7A49	2555 461727	ALEKSANDR IVANOV	{"email": "a.ivanov_091970@postgrespro.ru", "phone": "+70806638782"}
0005435529075	55BFBC	8142 868730	IGOR MIKHAYLOV	{"phone": "+70772333382"}
0005435529076	A3ACC8	1598 690571	OLGA BORISOVA	{"phone": "+70991812857"}
0005435529077	D21A8A	2201 091623	TIMUR KRASNOV	{"email": "krasnov-timur111960@postgrespro.ru", "phone": "+70905526402"}
0005435529078	E9EEEB	2365 341171	TAMARA KOROLEVA	{"email": "t_koroleva091982@postgrespro.ru", "phone": "+70637172190"}
0005435529079	E9EEEB	9247 531243	OLGA KISELEVA	{"email": "kiselevao041974@postgrespro.ru", "phone": "+70317630681"}
0005435529080	1DC698	6058 418602	EGOR PETROV	{"email": "petrov-e.071967@postgrespro.ru", "phone": "+70187543169"}
0005435529081	BB7052	2559 987060	VITALIY SOKOLOV	{"phone": "+70065364551"}
0005435529082	47E212	0141 316317	LYUDMILA EGOROVA	{"phone": "+70564583531"}
0005435529083	779836	2296 741383	ALEKSANDRA EFREMOVA	{"phone": "+70116414634"}
0005435529084	E44820	6009 560357	TATYANA MIRONOVA	{"email": "mironova.t_1972@postgrespro.ru", "phone": "+70380591602"}
0005435529085	E44820	6509 919821	GALINA VOROBEVA	{"phone": "+70910002366"}
0005435529086	E44820	5959 577683	DMITRIY NIKITIN	{"phone": "+70080178909"}
0005435529087	408329	9806 574654	VLADIMIR KAZAKOV	{"phone": "+70488471234"}
0005435529088	39F635	7409 763703	NIKOLAY ANDREEV	{"phone": "+70115751920"}
0005435529089	A0A968	6980 844892	ALEKSEY SMIRNOV	{"email": "smirnov.aleksey021970@postgrespro.ru", "phone": "+70247932921"}
0005435529090	A0A968	2383 604412	ELENA POTAPOVA	{"email": "e_potapova_081978@postgrespro.ru", "phone": "+70870536201"}
0005435529091	68F5FC	5258 442983	ANTONINA NIKITINA	{"email": "nikitina_a.121969@postgrespro.ru", "phone": "+70079151463"}
0005435529092	335A3E	8545 656474	SERGEY SERGEEV	{"phone": "+70935566975"}
0005435529093	D2B3D6	5800 706821	GEORGIY SOROKIN	{"phone": "+70797550663"}
0005435529094	D2B3D6	7081 111906	ANDREY POPOV	{"phone": "+70399386770"}
0005435529095	599112	6620 607594	OLESYA EFREMOVA	{"phone": "+70579693683"}
0005435529096	599112	6806 721532	ANATOLIY IVANOV	{"email": "ivanov_a_091963@postgrespro.ru", "phone": "+70449794068"}
0005435529097	153E32	3011 280252	VALENTINA FROLOVA	{"email": "valentina_frolova_1970@postgrespro.ru", "phone": "+70317659388"}
0005435529098	ABF5D7	1448 767679	SVETLANA MOROZOVA	{"phone": "+70737004862"}
0005435529099	ABF5D7	6347 492898	ALEKSANDR POPOV	{"email": "popov.a_1962@postgrespro.ru", "phone": "+70296017090"}
0005435529100	455438	7314 570780	SERGEY BORISOV	{"phone": "+70555939312"}
0005435529101	E336FA	4508 364596	DMITRIY ALEKSANDROV	{"email": "dmitriy.aleksandrov021978@postgrespro.ru", "phone": "+70719527412"}
0005435529102	FDB27E	6113 017888	ALEKSANDR TIMOFEEV	{"email": "aleksandr.timofeev-19091966@postgrespro.ru", "phone": "+70045110845"}
0005435529103	FC4B2F	0605 980394	ALEKSANDRA ZOTOVA	{"phone": "+70529757422"}
0005435529104	FC4B2F	7192 114244	YULIYA KOROLEVA	{"phone": "+70152157564"}
0005435529105	F627D9	7451 048591	VALERIY MATVEEV	{"phone": "+70066442650"}
0005435529106	D110C7	5613 308403	MARINA ZAYCEVA	{"email": "m.zayceva091967@postgrespro.ru", "phone": "+70248681032"}
0005435529107	D110C7	3878 504556	DILYARA KONDRATEVA	{"email": "kondratevadilyara-1967@postgrespro.ru", "phone": "+70336894439"}
0005435529108	D110C7	1759 614241	MARINA ISAEVA	{"phone": "+70381915765"}
0005435529109	D110C7	0793 224164	KONSTANTIN KARPOV	{"email": "k_karpov-1976@postgrespro.ru", "phone": "+70203129047"}
0005435529110	7000D9	1729 229366	ANNA FILIPPOVA	{"email": "filippova.a041958@postgrespro.ru", "phone": "+70150088470"}
0005435529111	7000D9	1544 612012	OLGA ZAKHAROVA	{"phone": "+70530700853"}
0005435529112	81E822	2402 880242	ALEKSANDR POPOV	{"phone": "+70553427492"}
0005435529113	81E822	8767 780895	SERGEY ABRAMOV	{"email": "abramov.sergey_091980@postgrespro.ru", "phone": "+70233203446"}
0005435529114	75A037	3847 996044	ALEKSANDR DENISOV	{"phone": "+70088507936"}
0005435529115	9BD8F4	8097 582672	MARIYA KUZNECOVA	{"email": "kuznecova_mariya.051974@postgrespro.ru", "phone": "+70314896207"}
0005435529116	9BD8F4	8486 928736	NATALYA MOISEEVA	{"phone": "+70224511012"}
0005435529117	F79719	2497 928930	IRINA KOMAROVA	{"email": "komarova.irina-24101960@postgrespro.ru", "phone": "+70644004591"}
0005435529118	CE8E2B	7505 126047	OLGA KUZNECOVA	{"email": "kuznecova-o.1967@postgrespro.ru", "phone": "+70919751766"}
0005435529119	5FC16D	4202 340884	PETR SOKOLOV	{"email": "sokolov.petr_021978@postgrespro.ru", "phone": "+70334054062"}
0005435529120	B30412	6091 485803	ALEKSANDR FROLOV	{"email": "aleksandr.frolov.1973@postgrespro.ru", "phone": "+70738330387"}
0005435529121	B30412	8096 224957	GALINA DMITRIEVA	{"email": "g_dmitrieva1980@postgrespro.ru", "phone": "+70630400302"}
0005435529122	CA292E	7077 232798	GALINA DANILOVA	{"phone": "+70272288716"}
0005435529123	A723A4	4958 264013	NIKOLAY MIRONOV	{"email": "n.mironov.041971@postgrespro.ru", "phone": "+70038084221"}
0005435529124	A723A4	6069 902502	VALERIY BONDARENKO	{"email": "valeriybondarenko_011968@postgrespro.ru", "phone": "+70463625267"}
0005435529125	35E329	5093 848469	ALEKSANDR GAVRILOV	{"phone": "+70424348396"}
0005435529126	35E329	8682 713303	ANNA MIRONOVA	{"phone": "+70594638510"}
0005435529127	949E92	6693 617834	MARTA GORBUNOVA	{"phone": "+70684134113"}
0005435529128	7148DA	9362 568843	VIKTOR SEMENOV	{"phone": "+70038151060"}
0005435529129	067158	7865 618646	OKSANA KUZNECOVA	{"phone": "+70405628123"}
0005435529130	067158	5907 245497	VIKTORIYA KUZMINA	{"email": "viktoriya-kuzmina.061967@postgrespro.ru", "phone": "+70011934157"}
0005435529131	6127F3	9895 690359	KSENIYA KUZNECOVA	{"email": "kuznecova_kseniya25081965@postgrespro.ru", "phone": "+70517121010"}
0005435529132	6127F3	8888 044613	YURIY STEPANOV	{"email": "yuriystepanov_1976@postgrespro.ru", "phone": "+70920603068"}
0005435529133	FCA249	5928 625205	YURIY POPOV	{"phone": "+70674572203"}
0005435529134	FCA249	9995 394682	ANASTASIYA KISELEVA	{"phone": "+70661608657"}
0005435529135	9C3419	8913 588662	EVGENIY MIRONOV	{"phone": "+70463159352"}
0005435529136	A74C15	0245 376261	DMITRIY SERGEEV	{"phone": "+70782960702"}
0005435529137	71E0D2	6293 435613	LYUDMILA DMITRIEVA	{"phone": "+70432340653"}
0005435529138	C0D61E	9261 200459	ALEKSANDR NIKITIN	{"email": "nikitin_a-1959@postgrespro.ru", "phone": "+70304163212"}
0005435529139	90A1F2	2102 929146	ANNA VOLKOVA	{"email": "a_volkova26031980@postgrespro.ru", "phone": "+70699943414"}
0005435529140	90A1F2	6808 881471	DENIS KONOVALOV	{"phone": "+70012554539"}
0005435529141	5E225C	0530 647845	VALENTINA NAZAROVA	{"email": "nazarova_v.031972@postgrespro.ru", "phone": "+70878541197"}
0005435529142	5E225C	6392 823444	ANNA GUSEVA	{"email": "anna-guseva_1969@postgrespro.ru", "phone": "+70563543007"}
0005435529143	A920D0	8688 132783	VLADIMIR MARTYNOV	{"phone": "+70076612537"}
0005435529144	DF6583	4057 899192	ELENA PAVLOVA	{"phone": "+70679326148"}
0005435529145	97EBD1	7896 445771	MIKHAIL GORBUNOV	{"phone": "+70193284667"}
0005435529146	DFE759	5188 753216	SERGEY MAKAROV	{"email": "sergey-makarov.111967@postgrespro.ru", "phone": "+70889082590"}
0005435529147	C887B6	9429 618107	IGOR SOKOLOV	{"email": "igor-sokolov.051971@postgrespro.ru", "phone": "+70031022126"}
0005435529148	CF0A47	4493 878320	VERA KONOVALOVA	{"phone": "+70213642583"}
0005435529149	067923	7832 636519	NIKITA MELNIKOV	{"phone": "+70139067134"}
0005435529150	067923	5849 852259	TIMOFEY MELNIKOV	{"phone": "+70464197473"}
0005435529151	0E1370	1600 570535	RUSLAN GUSEV	{"phone": "+70205671965"}
0005435529152	9BACBD	1844 543328	GEORGIY NOVIKOV	{"phone": "+70608576715"}
0005435529153	9BACBD	5704 061852	LYUBOV TIMOFEEVA	{"email": "ltimofeeva.13011974@postgrespro.ru", "phone": "+70478193406"}
0005435529154	A85D02	1425 677338	KSENIYA MOROZOVA	{"phone": "+70987864965"}
0005435529155	7EC316	9254 468492	SERGEY ZAKHAROV	{"email": "zakharov_s-1971@postgrespro.ru", "phone": "+70466388281"}
0005435529156	7EC316	7592 877770	NADEZHDA ALEKSEEVA	{"phone": "+70202194099"}
0005435529157	121263	9045 729036	IGOR IVANOV	{"email": "igor-ivanov-02071976@postgrespro.ru", "phone": "+70269634518"}
0005435529158	C57BF4	1695 608211	ANTONINA MOROZOVA	{"email": "antoninamorozova_051982@postgrespro.ru", "phone": "+70994400034"}
0005435529159	FB2E5D	2576 063970	IRINA NAZAROVA	{"email": "i.nazarova_1972@postgrespro.ru", "phone": "+70105586146"}
0005435529160	1C2E43	7673 489428	NIKOLAY ILIN	{"email": "ilin-n-071961@postgrespro.ru", "phone": "+70316557468"}
0005435529161	A1CA68	8136 402045	ANDREY KONOVALOV	{"phone": "+70146958263"}
0005435529162	CC1F43	0533 276771	VIKTOR KUZNECOV	{"email": "kuznecov.viktor_031981@postgrespro.ru", "phone": "+70690749302"}
0005435529163	CC1F43	0826 927897	PAVEL CHERNOV	{"phone": "+70317390399"}
0005435529164	35C4D3	8084 382181	ALENA OSIPOVA	{"email": "a.osipova-1979@postgrespro.ru", "phone": "+70785042737"}
0005435529165	B55045	3118 920991	ALEKSANDR IVANOV	{"phone": "+70183757897"}
0005435529166	B55045	0611 451841	IGOR GUSEV	{"email": "gusev_i.111985@postgrespro.ru", "phone": "+70947863215"}
0005435529167	CF1708	8559 535898	LYUBOV NIKOLAEVA	{"email": "lyubov_nikolaeva-28061973@postgrespro.ru", "phone": "+70646895400"}
0005435529168	CF1708	5055 226480	GENNADIY VOLKOV	{"email": "volkov.gennadiy_1973@postgrespro.ru", "phone": "+70161616298"}
0005435529169	352C61	6531 737189	ANGELINA KUZNECOVA	{"email": "kuznecovaangelina_28071966@postgrespro.ru", "phone": "+70887187646"}
0005435529170	8696A6	9896 392166	EKATERINA EGOROVA	{"email": "eegorova081977@postgrespro.ru", "phone": "+70886660974"}
0005435529171	93BCA6	1480 173044	SERGEY YAKOVLEV	{"phone": "+70516929404"}
0005435529172	7EDE49	2199 950750	YULIYA SOKOLOVA	{"email": "sokolova.yuliya.1971@postgrespro.ru", "phone": "+70789866125"}
0005435529173	7EDE49	6877 222292	DMITRIY FILIPPOV	{"phone": "+70663596625"}
0005435529174	712FDA	0431 930943	VYACHESLAV BORISOV	{"email": "borisov.vyacheslav_26041972@postgrespro.ru", "phone": "+70323174149"}
0005435529175	712FDA	8979 728741	IGOR KISELEV	{"phone": "+70506846919"}
0005435529176	BD8ECA	9910 642157	MADINA KUZNECOVA	{"email": "mkuznecova-061971@postgrespro.ru", "phone": "+70713322541"}
0005435529177	656300	2501 315806	EKATERINA POPOVA	{"email": "ekaterina_popova_1962@postgrespro.ru", "phone": "+70103321072"}
0005435529178	656300	7777 291350	MIKHAIL VLASOV	{"email": "vlasov.m.1964@postgrespro.ru", "phone": "+70854478302"}
0005435529179	10F70C	2124 811231	KONSTANTIN PETROV	{"phone": "+70973904670"}
0005435529180	10F70C	8411 153745	IRINA KAZAKOVA	{"phone": "+70621635708"}
0005435529181	24FD7A	0792 543436	VALENTINA GERASIMOVA	{"email": "gerasimovav_24041974@postgrespro.ru", "phone": "+70533254436"}
0005435529182	2DB6D9	0311 730948	NATALYA SERGEEVA	{"phone": "+70612142144"}
0005435529183	F53B78	0205 827948	VERA TARASOVA	{"email": "tarasova.vera_28051963@postgrespro.ru", "phone": "+70527210253"}
0005435529184	A3A048	2769 498085	NINA MIRONOVA	{"phone": "+70847481107"}
0005435529185	A3A048	2663 964553	LYUBOV IVANOVA	{"phone": "+70453927825"}
0005435529186	5509B8	2241 825802	EVGENIY KULIKOV	{"phone": "+70028988999"}
0005435529187	5BBC68	5925 812065	LYUBOV ZAKHAROVA	{"phone": "+70532089633"}
0005435529188	F7668B	4659 101888	GENNADIY SOROKIN	{"phone": "+70054797718"}
0005435529189	D681D6	8554 104590	YURIY SOKOLOV	{"email": "yuriy_sokolov1975@postgrespro.ru", "phone": "+70715968292"}
0005435529190	C9D37B	5846 047284	VERA KISELEVA	{"phone": "+70549569035"}
0005435529191	C9D37B	1051 235868	TATYANA MIKHAYLOVA	{"phone": "+70738767179"}
0005435529192	184901	7380 190779	OLEG KRASNOV	{"email": "krasnov.oleg16011972@postgrespro.ru", "phone": "+70645232475"}
0005435529193	184901	9698 262134	NATALYA MAKAROVA	{"phone": "+70798919806"}
0005435529194	33D89B	3291 048169	ALEKSEY VOROBEV	{"email": "alekseyvorobev1980@postgrespro.ru", "phone": "+70344184274"}
0005435529195	DEDB09	3234 090277	DMITRIY SOKOLOV	{"email": "sokolov.dmitriy1968@postgrespro.ru", "phone": "+70803710458"}
0005435529196	DBB0CC	9327 715621	IRINA YAKOVLEVA	{"phone": "+70380158082"}
0005435529197	1383B5	9828 225414	ALEKSANDR ANDREEV	{"phone": "+70647831984"}
0005435529198	31E6D8	0094 949454	VLADIMIR ZHURAVLEV	{"email": "zhuravlev_vladimir_1969@postgrespro.ru", "phone": "+70900176948"}
0005435529199	4AD99C	7614 374078	MIKHAIL OSIPOV	{"phone": "+70611453885"}
0005435529200	4AD99C	2839 063370	YURIY GAVRILOV	{"email": "gavrilovyuriy11081981@postgrespro.ru", "phone": "+70309541024"}
0005435529201	4AD99C	5695 868921	ALEKSANDR PETROV	{"email": "aleksandr.petrov08071971@postgrespro.ru", "phone": "+70324956968"}
0005435529202	AA505F	4954 417180	VADIM DENISOV	{"phone": "+70664123230"}
0005435529203	5A1517	1461 692865	YULIYA KOLESNIKOVA	{"phone": "+70811778844"}
0005435529204	417E92	9760 704317	MARIYA SOLOVEVA	{"email": "soloveva_m-1973@postgrespro.ru", "phone": "+70846769387"}
0005435529205	E9FFFF	1847 185512	TATYANA IVANOVA	{"email": "tatyana_ivanova-04021979@postgrespro.ru", "phone": "+70944215986"}
0005435529206	828402	4031 169543	SERGEY VOLKOV	{"phone": "+70197038005"}
0005435529207	6BC65C	8702 828284	IGOR MAKSIMOV	{"email": "igormaksimov1974@postgrespro.ru", "phone": "+70707822807"}
0005435529208	6BC65C	0389 606608	ALEKSANDR POPOV	{"email": "aleksandrpopov-1966@postgrespro.ru", "phone": "+70654475674"}
0005435529209	2CB1BE	5738 509477	ANASTASIYA KOZLOVA	{"phone": "+70631103166"}
0005435529210	B1C935	8263 631328	YURIY YAKOVLEV	{"phone": "+70674359951"}
0005435529211	1F1099	6896 152255	VLADIMIR PETROV	{"email": "petrovvladimir1980@postgrespro.ru", "phone": "+70145300208"}
0005435529212	2C858D	5293 734901	ANNA TIMOFEEVA	{"phone": "+70028405146"}
0005435529213	4AADF4	3213 981534	VLADIMIR SOLOVEV	{"phone": "+70135061546"}
0005435529214	4AADF4	8464 664970	ALEKSANDR GUSEV	{"email": "gusev.a-1973@postgrespro.ru", "phone": "+70495599721"}
0005435529215	F4657F	0676 044020	ALEKSANDR BORISOV	{"phone": "+70308490269"}
0005435529216	F4657F	2913 207449	NADEZHDA KOLESNIKOVA	{"email": "nadezhda-kolesnikova_1980@postgrespro.ru", "phone": "+70406384315"}
0005435529217	F4657F	0662 140873	SERGEY SHEVCHENKO	{"phone": "+70142417672"}
0005435529218	F5737A	6683 750752	VLADIMIR CHERNOV	{"phone": "+70619006423"}
0005435529219	F5737A	0715 604675	EGOR MIRONOV	{"phone": "+70506946867"}
0005435529220	92A64D	3874 555779	NADEZHDA NAUMOVA	{"phone": "+70485844643"}
0005435529221	B247BC	9778 321185	ANNA EFIMOVA	{"phone": "+70651252975"}
0005435529222	09D902	9721 469510	ALEKSANDRA ISAEVA	{"email": "isaeva-aleksandra051970@postgrespro.ru", "phone": "+70397781044"}
0005435529223	09D902	7611 827043	ROMAN CHERNOV	{"phone": "+70657099378"}
0005435529224	09D902	9547 254666	NATALYA SEMENOVA	{"email": "natalya_semenova-1968@postgrespro.ru", "phone": "+70221220929"}
0005435529225	E546F7	9016 883888	IGOR SAVELEV	{"email": "savelev_igor.1973@postgrespro.ru", "phone": "+70129797635"}
0005435529226	CC11D3	5957 227700	DAMIR KUZNECOV	{"email": "dkuznecov-14081970@postgrespro.ru", "phone": "+70052746517"}
0005435529227	CC11D3	4376 090517	KIRILL BELOV	{"phone": "+70182560621"}
0005435529228	60E2BB	3676 060946	EVGENIY SMIRNOV	{"phone": "+70406188827"}
0005435529229	60E2BB	1268 182393	ALEKSANDR TIKHONOV	{"email": "aleksandrtikhonov111969@postgrespro.ru", "phone": "+70416242729"}
0005435529230	DC18E1	6065 062852	ANASTASIYA GUSEVA	{"phone": "+70206550902"}
0005435529231	7631D8	6402 402465	NIKOLAY ZAYCEV	{"phone": "+70469641573"}
0005435529232	A34894	3436 475924	SERGEY GRIGOREV	{"phone": "+70673871897"}
0005435529233	A34894	8002 612207	ARSENIY ANDREEV	{"phone": "+70426485153"}
0005435529234	A1DF5E	2862 422527	VLADIMIR PETROV	{"email": "petrovvladimir061970@postgrespro.ru", "phone": "+70554281511"}
0005435529235	A1DF5E	7873 307696	ALLA SCHERBAKOVA	{"email": "scherbakova-alla-091981@postgrespro.ru", "phone": "+70537426887"}
0005435529236	BFA77F	8045 933164	ALEKSANDR DAVYDOV	{"email": "adavydov_081974@postgrespro.ru", "phone": "+70645072359"}
0005435529237	BFA77F	4778 391203	MARINA KUZNECOVA	{"email": "kuznecova_marina14031973@postgrespro.ru", "phone": "+70651134340"}
0005435529238	B128E4	7888 117255	YULIYA CHERNOVA	{"phone": "+70083062959"}
0005435529239	834DA9	3384 952738	FARIT MATVEEV	{"email": "matveev.f_1974@postgrespro.ru", "phone": "+70606054845"}
0005435529240	C45EBC	7309 386129	VIKTOR IVANOV	{"email": "ivanov_viktor.14101978@postgrespro.ru", "phone": "+70233776226"}
0005435529241	C45EBC	1696 227356	LYUBOV MELNIKOVA	{"email": "l-melnikova03091969@postgrespro.ru", "phone": "+70176439833"}
0005435529242	C45EBC	0012 522213	NIKOLAY ALEKSEEV	{"email": "nikolay_alekseev-05111966@postgrespro.ru", "phone": "+70469828817"}
0005435529243	B89C77	4369 075723	MARIYA KOZLOVA	{"email": "kozlovamariya-1967@postgrespro.ru", "phone": "+70907601775"}
0005435529244	F73695	8307 521805	OLGA MATVEEVA	{"phone": "+70448410734"}
0005435529245	075100	1330 086144	VYACHESLAV NOVIKOV	{"email": "novikov-v091972@postgrespro.ru", "phone": "+70296532981"}
0005435529246	BC21C4	6759 457273	IRAIDA EGOROVA	{"email": "i-egorova_041980@postgrespro.ru", "phone": "+70993436075"}
0005435529247	2DD55B	2220 205654	OLEG ILIN	{"email": "ilino-051972@postgrespro.ru", "phone": "+70689014536"}
0005435529248	F60D48	2824 142833	VLADIMIR MAKSIMOV	{"email": "v.maksimov-1987@postgrespro.ru", "phone": "+70239839390"}
0005435529249	F60D48	2468 948773	VLADIMIR SOLOVEV	{"email": "solovev-vladimir_23041969@postgrespro.ru", "phone": "+70419584057"}
0005435529250	1EC544	1543 345845	DMITRIY SCHERBAKOV	{"email": "dscherbakov.07061967@postgrespro.ru", "phone": "+70776169878"}
0005435529251	1EC544	6747 721332	ARTEM VOLKOV	{"email": "a.volkov-19041971@postgrespro.ru", "phone": "+70664851457"}
0005435529252	1EC544	7162 036732	ALEKSANDR RODIONOV	{"email": "arodionov041981@postgrespro.ru", "phone": "+70887320900"}
0005435529253	871E78	6840 862278	ANNA KUZNECOVA	{"email": "anna.kuznecova_1966@postgrespro.ru", "phone": "+70551884391"}
0005435529254	5DB112	0559 873135	SVETLANA TITOVA	{"phone": "+70794026333"}
0005435529255	5DB112	4124 719407	NIKITA ZHUKOV	{"phone": "+70659884261"}
0005435529256	D04D24	9203 017438	RINAT VLASOV	{"email": "vlasov-rinat22041972@postgrespro.ru", "phone": "+70923186932"}
0005435529257	D583F6	2687 714193	SERGEY SEMENOV	{"email": "s.semenov-03081980@postgrespro.ru", "phone": "+70885686038"}
0005435529258	422389	5439 410757	TATYANA KARPOVA	{"email": "t_karpova-071952@postgrespro.ru", "phone": "+70498713519"}
0005435529259	422389	0809 905874	VLADISLAV MIRONOV	{"email": "mironovv041980@postgrespro.ru", "phone": "+70134461250"}
0005435529260	3E229A	7941 634139	ERIK TARASOV	{"phone": "+70745508250"}
0005435529261	3E229A	3901 958982	VLADIMIR POPOV	{"phone": "+70391816891"}
0005435529262	A12481	6650 245388	SERGEY KUDRYASHOV	{"phone": "+70622862309"}
0005435529263	36C868	5846 892276	YURIY TIMOFEEV	{"phone": "+70092079624"}
0005435529264	36C868	0715 271795	ALEKSANDR PETROV	{"phone": "+70883652929"}
0005435529265	36C868	1526 086121	OKSANA VASILEVA	{"email": "vasilevaoksana-1974@postgrespro.ru", "phone": "+70428657256"}
0005435529266	B436D2	0401 694828	ROMAN SCHERBAKOV	{"email": "r.scherbakov-1968@postgrespro.ru", "phone": "+70801570731"}
0005435529267	09004E	6566 409705	VIKTORIYA CHERNOVA	{"email": "chernova_viktoriya1963@postgrespro.ru", "phone": "+70293582296"}
0005435529268	09E9B7	1585 582457	EKATERINA TROFIMOVA	{"email": "e-trofimova.20031972@postgrespro.ru", "phone": "+70542928331"}
0005435529269	09E9B7	4254 639984	IVAN ORLOV	{"phone": "+70097433233"}
0005435529270	DF86FF	3785 354009	ALEKSEY ZAKHAROV	{"email": "aleksey-zakharov071970@postgrespro.ru", "phone": "+70067096752"}
0005435529271	7D47F5	8451 391725	MARAT GERASIMOV	{"email": "marat.gerasimov1968@postgrespro.ru", "phone": "+70624903630"}
0005435529272	61F766	3295 817601	IRINA KONOVALOVA	{"email": "irina_konovalova-1976@postgrespro.ru", "phone": "+70727361121"}
0005435529273	67606C	1046 439976	DMITRIY VOLKOV	{"email": "dmitriy-volkov.21021973@postgrespro.ru", "phone": "+70054582893"}
0005435529274	67606C	0157 051311	EKATERINA LAZAREVA	{"phone": "+70748344342"}
0005435529275	2638D9	1958 782286	SERGEY ROMANOV	{"email": "sergeyromanov-20121969@postgrespro.ru", "phone": "+70064250156"}
0005435529276	2638D9	6507 726905	NATALYA NAUMOVA	{"email": "naumova_natalya-061991@postgrespro.ru", "phone": "+70527941660"}
0005435529277	D77BA4	9603 576109	MAKSIM ALEKSEEV	{"phone": "+70384210442"}
0005435529278	24918F	5694 099528	LYUBOV DENISOVA	{"email": "denisova-lyubov091976@postgrespro.ru", "phone": "+70048143992"}
0005435529279	D09245	8423 517954	ANNA KOLESNIKOVA	{"email": "kolesnikova-anna101962@postgrespro.ru", "phone": "+70728887614"}
0005435529280	D09245	9544 821680	ALEKSANDR SHEVCHENKO	{"email": "shevchenkoa.22081965@postgrespro.ru", "phone": "+70250020196"}
0005435529281	A9E049	2963 763733	ROMAN OSIPOV	{"phone": "+70929034208"}
0005435529282	6A3216	2582 498462	RAISA DAVYDOVA	{"email": "davydovar.1970@postgrespro.ru", "phone": "+70790630871"}
0005435529283	6A3216	0231 455234	VLADIMIR BONDARENKO	{"email": "bondarenko.v.091959@postgrespro.ru", "phone": "+70156884680"}
0005435529284	F97E87	8070 291740	MARINA MASLOVA	{"phone": "+70277297147"}
0005435529285	F97E87	2018 608192	YURIY ABRAMOV	{"email": "abramov.yuriy-19011964@postgrespro.ru", "phone": "+70855014669"}
0005435529286	2B1BA8	1111 657974	ZUKHRA SIDOROVA	{"email": "z.sidorova.1969@postgrespro.ru", "phone": "+70400758621"}
0005435529287	65FC73	3444 101698	GENNADIY VASILEV	{"email": "vasilevg_031982@postgrespro.ru", "phone": "+70890689702"}
0005435529288	05CFF1	0578 221205	SERGEY IVANOV	{"phone": "+70112855628"}
0005435529289	05CFF1	7173 729050	DMITRIY MIRONOV	{"email": "mironov_d1968@postgrespro.ru", "phone": "+70098214326"}
0005435529290	C6179E	0668 478618	ANTONINA BELYAEVA	{"phone": "+70928905587"}
0005435529291	C6179E	1735 561965	NAIL SERGEEV	{"phone": "+70198736564"}
0005435529292	A7E905	9107 262221	IGOR VLASOV	{"phone": "+70740565268"}
0005435529293	A7E905	4655 199365	RUMIYA KAZAKOVA	{"phone": "+70617968057"}
0005435529294	A7E905	7698 696098	KONSTANTIN GERASIMOV	{"phone": "+70723173188"}
0005435529295	A7E905	7755 382772	ELENA KUZMINA	{"phone": "+70476334696"}
0005435529296	BE1C07	9279 193493	NIKOLAY ANDREEV	{"phone": "+70331278281"}
0005435529297	BE1C07	4722 473331	KONSTANTIN KOZLOV	{"email": "kozlov_konstantin-111973@postgrespro.ru", "phone": "+70169150713"}
0005435529298	9A52A0	2624 118148	EVGENIYA MALYSHEVA	{"email": "malysheva.evgeniya.1969@postgrespro.ru", "phone": "+70411202892"}
0005435529299	9A52A0	0083 696607	GRIGORIY YAKOVLEV	{"phone": "+70419354154"}
0005435529300	26F516	2813 723101	ALEKSEY NOVIKOV	{"phone": "+70431778603"}
0005435529301	CA213A	2212 750721	GALINA ALEKSANDROVA	{"email": "g-aleksandrova25101978@postgrespro.ru", "phone": "+70549231460"}
0005435529302	7DF536	0831 964981	LIDIYA KISELEVA	{"phone": "+70411128757"}
0005435529303	D3BF98	2094 669464	GALINA SOROKINA	{"email": "sorokina.galina-051974@postgrespro.ru", "phone": "+70411217172"}
0005435529304	D3BF98	7037 573183	OKSANA BORISOVA	{"email": "oksanaborisova.011971@postgrespro.ru", "phone": "+70521255739"}
0005435529305	04274C	1699 003603	LYUBOV YUDINA	{"phone": "+70797709723"}
0005435529306	1FF740	9890 741261	ALEKSANDRA MEDVEDEVA	{"phone": "+70565491436"}
0005435529307	1FF740	8264 894721	ANATOLIY VASILEV	{"email": "anatoliyvasilev_1975@postgrespro.ru", "phone": "+70344687484"}
0005435529308	CEBB02	9091 176402	ALEKSANDR KAZAKOV	{"email": "kazakov-a-061965@postgrespro.ru", "phone": "+70184566242"}
0005435529309	CEBB02	8418 399735	KIRILL VASILEV	{"email": "vasilev_kirill-121972@postgrespro.ru", "phone": "+70359092172"}
0005435529310	A457DC	2152 118920	OLEG SEMENOV	{"email": "o-semenov121982@postgrespro.ru", "phone": "+70205219903"}
0005435529311	431764	2245 085905	LYUDMILA GAVRILOVA	{"phone": "+70249223467"}
0005435529312	431764	4526 411592	VLADIMIR ROMANOV	{"email": "vladimir_romanov071972@postgrespro.ru", "phone": "+70561876181"}
0005435529313	BC4C0F	6276 441308	VALERIY MOROZOV	{"email": "v-morozov_18051972@postgrespro.ru", "phone": "+70216190742"}
0005435529314	5F0A89	3564 065940	EMMA MOROZOVA	{"email": "morozova.e.081973@postgrespro.ru", "phone": "+70022291147"}
0005435529315	18175B	6338 591961	OLESYA TITOVA	{"email": "titova-olesya_1979@postgrespro.ru", "phone": "+70963315893"}
0005435529316	18175B	1317 718279	KIRILL POPOV	{"email": "kirill-popov.1967@postgrespro.ru", "phone": "+70361556356"}
0005435529317	4ED704	9425 757094	ANASTASIYA ALEKSEEVA	{"phone": "+70123717286"}
0005435529318	CB63D5	8068 202902	NATALYA STEPANOVA	{"phone": "+70304354707"}
0005435529319	01E0A9	3626 901017	MARINA LEBEDEVA	{"email": "marina-lebedeva1973@postgrespro.ru", "phone": "+70407993218"}
0005435529320	01E0A9	4195 881111	ELENA ALEKSEEVA	{"email": "e_alekseeva.09101973@postgrespro.ru", "phone": "+70202995290"}
0005435529321	971EBE	2978 411422	DENIS SOROKIN	{"phone": "+70046642826"}
0005435529322	18D2BB	4286 701716	OKSANA AFANASEVA	{"email": "oksana_afanaseva1970@postgrespro.ru", "phone": "+70530247116"}
0005435529323	A3850E	0128 671835	KIRILL IVANOV	{"phone": "+70006326404"}
0005435529324	A3850E	8461 397355	MARIYA GAVRILOVA	{"phone": "+70379289092"}
0005435529325	7219C0	3224 169971	NINA YAKOVLEVA	{"phone": "+70852488922"}
0005435529326	581FC6	9030 834260	NIKOLAY ABRAMOV	{"phone": "+70826889588"}
0005435529327	722C6D	7931 758511	ALEKSANDR MAKAROV	{"phone": "+70913421457"}
0005435529328	D7733F	0131 882463	LYUDMILA ANDREEVA	{"email": "l-andreeva03011975@postgrespro.ru", "phone": "+70554037510"}
0005435529329	FFA124	5126 144815	ELENA SCHERBAKOVA	{"phone": "+70547167780"}
0005435529330	6CF6EF	1220 813534	ELIZAVETA NIKOLAEVA	{"email": "nikolaeva_e.1966@postgrespro.ru", "phone": "+70763206727"}
0005435529331	21778C	4194 913024	LYUDMILA BELOVA	{"phone": "+70657549404"}
0005435529332	89F911	9725 319449	OLGA SEMENOVA	{"email": "olga-semenova061977@postgrespro.ru", "phone": "+70508509235"}
0005435529333	89F911	8354 106746	SOFIYA MEDVEDEVA	{"email": "medvedeva_s061981@postgrespro.ru", "phone": "+70861336181"}
0005435529334	430E28	6006 879447	VIKTORIYA SMIRNOVA	{"email": "v-smirnova031963@postgrespro.ru", "phone": "+70907096637"}
0005435529335	430E28	0002 355806	RAMIL PETROV	{"email": "petrov_ramil1966@postgrespro.ru", "phone": "+70658832099"}
0005435529336	908D06	3351 517099	ALEKSEY BELOV	{"email": "belova_1992@postgrespro.ru", "phone": "+70483235117"}
0005435529337	908D06	5411 705704	VLADISLAV BORISOV	{"phone": "+70708258245"}
0005435529338	2867CC	4649 345615	SERGEY POPOV	{"email": "popov-sergey-09041972@postgrespro.ru", "phone": "+70568149188"}
0005435529339	13646D	2160 936542	MARIYA SOKOLOVA	{"email": "mariya-sokolova-1970@postgrespro.ru", "phone": "+70122520114"}
0005435529340	5DA58B	8680 200284	IVAN SCHERBAKOV	{"phone": "+70739940908"}
0005435529341	6517B2	1404 862436	ALEKSANDRA KONOVALOVA	{"email": "konovalovaa011966@postgrespro.ru", "phone": "+70526713310"}
0005435529342	6517B2	4629 732538	ILYA GAVRILOV	{"phone": "+70916293598"}
0005435529343	6517B2	7891 563261	YULIYA STEPANOVA	{"phone": "+70387898237"}
0005435529344	FB4465	0150 860355	ALEKSANDR SCHERBAKOV	{"phone": "+70935213511"}
0005435529345	626015	0717 351363	DANIIL FILIPPOV	{"phone": "+70295662895"}
0005435529346	626015	3548 313095	VIKTORIYA KOZLOVA	{"phone": "+70259969427"}
0005435529347	1BF6C3	5613 537011	YULIYA LOGINOVA	{"email": "yloginova.111961@postgrespro.ru", "phone": "+70523285582"}
0005435529348	5A8BC6	7732 535418	KRISTINA MELNIKOVA	{"email": "k-melnikova.1975@postgrespro.ru", "phone": "+70746069558"}
0005435529349	E7F98D	4611 241611	DENIS KUZNECOV	{"email": "deniskuznecov_101972@postgrespro.ru", "phone": "+70058189989"}
0005435529350	232923	1473 175036	SERGEY ALEKSEEV	{"phone": "+70406214697"}
0005435529351	8C6A46	1563 481020	TAMARA ANISIMOVA	{"phone": "+70662047565"}
0005435529352	45EC96	4097 257257	DENIS MAKAROV	{"email": "dmakarov-1975@postgrespro.ru", "phone": "+70850649070"}
0005435529353	E30CFF	4923 546778	IVAN ZHUKOV	{"phone": "+70143015823"}
0005435529354	067554	0196 968598	VLADIMIR KUZMIN	{"email": "kuzmin.vladimir-051970@postgrespro.ru", "phone": "+70451501457"}
0005435529355	B7ACB6	5655 781420	NIKOLAY SOROKIN	{"email": "sorokin-nikolay-24101976@postgrespro.ru", "phone": "+70821517162"}
0005435529356	5FB1CC	6689 388853	ARTEM SIDOROV	{"phone": "+70366985096"}
0005435529357	5FB1CC	1776 457281	LYUDMILA ZAYCEVA	{"phone": "+70579136268"}
0005435529358	EDD083	9883 190602	ARTEM SCHERBAKOV	{"email": "scherbakovartem-14111965@postgrespro.ru", "phone": "+70319215202"}
0005435529359	B5BC00	1792 753716	TIMOFEY PETROV	{"phone": "+70261201882"}
0005435529360	A07758	0705 903091	ALEKSANDR KOZLOV	{"phone": "+70166210307"}
0005435529361	A07758	7207 952039	ELENA ZAYCEVA	{"email": "elenazayceva-1969@postgrespro.ru", "phone": "+70057367347"}
0005435529362	1E292C	0131 677318	ALEKSANDR KARPOV	{"email": "aleksandrkarpov041981@postgrespro.ru", "phone": "+70885211910"}
0005435529363	578F71	8986 309785	VIKTORIYA GRISHINA	{"phone": "+70582702357"}
0005435529364	BE8ED8	3998 036254	ANDREY BELOV	{"email": "andrey.belov.19051970@postgrespro.ru", "phone": "+70961338033"}
0005435529365	37FF0F	9274 483541	NINA FOMINA	{"email": "n-fomina_111972@postgrespro.ru", "phone": "+70216278832"}
0005435529366	300DD7	4408 205128	ELIZAVETA TIKHONOVA	{"email": "elizaveta-tikhonova-1953@postgrespro.ru", "phone": "+70185690043"}
0005435529367	E4F3EC	4497 953006	PAVEL ZAKHAROV	{"phone": "+70025044271"}
0005435529368	3283BF	3987 808239	ANTON GRIGOREV	{"phone": "+70402149893"}
0005435529369	5F6630	9132 862823	MIKHAIL ANDREEV	{"email": "m_andreev_071976@postgrespro.ru", "phone": "+70505541128"}
0005435529370	9FA31E	7048 661090	SVETLANA MIRONOVA	{"email": "mironova.s_1974@postgrespro.ru", "phone": "+70260879106"}
0005435529371	9FA31E	1580 198520	EKATERINA MALYSHEVA	{"email": "ekaterina-malysheva.16091964@postgrespro.ru", "phone": "+70626220486"}
0005435529372	9FA31E	1720 113999	SVETLANA TARASOVA	{"phone": "+70214083884"}
0005435529373	C63A13	9418 495828	ELENA LUKYANOVA	{"phone": "+70425281431"}
0005435529374	B66B41	0816 490049	ELENA VASILEVA	{"email": "vasileva.elena04071977@postgrespro.ru", "phone": "+70047900502"}
0005435529375	AE4E6C	2602 229549	NIKITA VASILEV	{"phone": "+70703549941"}
0005435529376	AE4E6C	7782 338667	ELENA MAKAROVA	{"phone": "+70471924013"}
0005435529377	565B51	5915 184671	ANDREY NIKOLAEV	{"phone": "+70342794528"}
0005435529378	565B51	7025 118343	ANASTASIYA SAVELEVA	{"phone": "+70851200801"}
0005435529379	1AB313	1167 178548	YURIY KOZLOV	{"email": "kozlov-yuriy_081980@postgrespro.ru", "phone": "+70942508926"}
0005435529380	A3FCD4	9024 921007	EVDOKIYA DAVYDOVA	{"phone": "+70570864681"}
0005435529381	0B1E3E	4379 706288	ALEKSANDR IVANOV	{"email": "ivanov-a_01061978@postgrespro.ru", "phone": "+70926866781"}
0005435529382	816637	6358 010206	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev_18011973@postgrespro.ru", "phone": "+70524015004"}
0005435529383	9E0080	3992 600082	LYUBOV KUZMINA	{"email": "l_kuzmina-011972@postgrespro.ru", "phone": "+70779823262"}
0005435529384	9E0080	7346 056802	OLGA KOMAROVA	{"email": "komarova-olga-1981@postgrespro.ru", "phone": "+70148426848"}
0005435529385	28F988	1349 681209	YURIY MEDVEDEV	{"phone": "+70282485523"}
0005435529386	A7B3C8	7599 783504	ANASTASIYA MAKAROVA	{"email": "makarovaanastasiya_19061982@postgrespro.ru", "phone": "+70775501935"}
0005435529387	F04FAF	4714 002464	VENERA TROFIMOVA	{"phone": "+70846138333"}
0005435529388	A15C85	4874 560279	ANDREY SCHERBAKOV	{"phone": "+70163773670"}
0005435529389	A15C85	6331 789338	KRISTINA POTAPOVA	{"email": "k_potapova_05041966@postgrespro.ru", "phone": "+70037422281"}
0005435529390	812BBA	5937 661374	ALENA FILIPPOVA	{"email": "filippova-alena_15121966@postgrespro.ru", "phone": "+70088743194"}
0005435529391	6669F6	4043 466760	ALEKSANDR BORISOV	{"phone": "+70839958572"}
0005435529392	4FB93D	0776 080761	ELIZAVETA NOVIKOVA	{"phone": "+70898534081"}
0005435529393	5831E8	6532 145351	VADIM ZAKHAROV	{"email": "zakharov_vadim_20031982@postgrespro.ru", "phone": "+70327831240"}
0005435529394	AC06D0	1732 702658	EKATERINA TROFIMOVA	{"phone": "+70078156619"}
0005435529395	486C5B	2414 225135	TATYANA POPOVA	{"phone": "+70447802472"}
0005435529396	7D3FD3	7101 825498	POLINA SOKOLOVA	{"email": "polinasokolova1974@postgrespro.ru", "phone": "+70238630396"}
0005435529397	CAE525	4621 761013	DMITRIY YAKOVLEV	{"phone": "+70443862190"}
0005435529398	CAE525	5792 027691	GALINA GORBUNOVA	{"phone": "+70550067954"}
0005435529399	F71945	9709 665690	ELENA FADEEVA	{"email": "e.fadeeva.07071970@postgrespro.ru", "phone": "+70591141024"}
0005435529400	11269E	0121 999267	DMITRIY PAVLOV	{"email": "dmitriy_pavlov041985@postgrespro.ru", "phone": "+70870115148"}
0005435529401	2E8D8C	2015 898366	SERGEY BARANOV	{"email": "sergey-baranov121966@postgrespro.ru", "phone": "+70923988448"}
0005435529567	ECCCD0	8392 226142	ALEKSEY NIKOLAEV	{"phone": "+70652637204"}
0005435529402	2E8D8C	1015 303704	LIDIYA BELYAEVA	{"email": "lidiyabelyaeva-01061966@postgrespro.ru", "phone": "+70291906186"}
0005435529403	2E8D8C	3684 250794	ANTON IVANOV	{"email": "ivanov.anton-22011973@postgrespro.ru", "phone": "+70040924224"}
0005435529404	2E8D8C	3276 729145	VLADIMIR VLASOV	{"phone": "+70620325415"}
0005435529405	CC6764	9961 805583	ALEKSANDRA EGOROVA	{"phone": "+70845841422"}
0005435529406	0AB1CC	8201 980387	OLGA ANDREEVA	{"email": "o.andreeva_041976@postgrespro.ru", "phone": "+70896563089"}
0005435529407	0AB1CC	8882 170570	ARTEMIY FROLOV	{"phone": "+70331046586"}
0005435529408	0AB1CC	4668 714479	GENNADIY VLASOV	{"email": "vlasov_gennadiy-031974@postgrespro.ru", "phone": "+70600630860"}
0005435529409	7B8CCE	5926 133155	LILIYA DAVYDOVA	{"email": "davydova_liliya24071975@postgrespro.ru", "phone": "+70258103367"}
0005435529410	7B8CCE	8655 406756	NIKOLAY EGOROV	{"phone": "+70932505721"}
0005435529411	7A4009	9013 877262	VLADISLAV KOZLOV	{"email": "v_kozlov.30041974@postgrespro.ru", "phone": "+70392868273"}
0005435529412	7A4009	0154 182235	VLADIMIR DAVYDOV	{"phone": "+70375966378"}
0005435529413	98EAF0	1215 279309	VITALIY PAVLOV	{"email": "v_pavlov.101977@postgrespro.ru", "phone": "+70588104976"}
0005435529414	AF4324	4326 920002	SVETLANA MIKHAYLOVA	{"phone": "+70545103574"}
0005435529415	C09049	0504 372767	IVAN KUZNECOV	{"email": "kuznecov-ivan_081967@postgrespro.ru", "phone": "+70092431725"}
0005435529416	C09049	8869 793879	MARINA FILIPPOVA	{"email": "filippovamarina17031973@postgrespro.ru", "phone": "+70878416589"}
0005435529417	AC7E62	4575 834548	OLGA FADEEVA	{"phone": "+70609037315"}
0005435529418	871AB1	4603 203317	DANIIL STEPANOV	{"email": "stepanov-d.23071973@postgrespro.ru", "phone": "+70877227390"}
0005435529419	606D2A	5017 112875	EVGENIYA MAKAROVA	{"email": "e_makarova-1979@postgrespro.ru", "phone": "+70202760226"}
0005435529420	606D2A	6945 732536	RIMMA VOLKOVA	{"email": "rimma.volkova.071969@postgrespro.ru", "phone": "+70651179338"}
0005435529421	EA46B5	8808 132191	IVAN NIKITIN	{"email": "i.nikitin-20021981@postgrespro.ru", "phone": "+70636377854"}
0005435529422	0BB69F	3755 932645	VALENTINA ALEKSANDROVA	{"phone": "+70234022305"}
0005435529423	0BB69F	0559 677868	GERMAN STEPANOV	{"phone": "+70941030458"}
0005435529424	E35C54	9089 638679	LYUDMILA MAKSIMOVA	{"email": "lyudmilamaksimova_17031972@postgrespro.ru", "phone": "+70921559967"}
0005435529425	9A92E1	8982 358076	MARGARITA KUZNECOVA	{"email": "m.kuznecova.081980@postgrespro.ru", "phone": "+70257475812"}
0005435529426	9A92E1	2814 551592	ANTON GRIGOREV	{"phone": "+70611705139"}
0005435529427	6B3D56	5321 893023	EVGENIY KULIKOV	{"phone": "+70662075023"}
0005435529428	31EBBE	3958 328181	YULIYA TARASOVA	{"phone": "+70869622550"}
0005435529429	4A127F	6665 686832	NADEZHDA ANTONOVA	{"email": "antonova.n.26061972@postgrespro.ru", "phone": "+70400525524"}
0005435529430	51289F	5815 585419	SVETLANA KRASNOVA	{"email": "krasnovasvetlana-071972@postgrespro.ru", "phone": "+70521708781"}
0005435529431	50758D	4257 274157	ANNA KONOVALOVA	{"phone": "+70609428698"}
0005435529432	EE7170	7262 321196	OLGA NESTEROVA	{"email": "nesterova-o-24011975@postgrespro.ru", "phone": "+70100169456"}
0005435529433	5EF0D4	2513 770002	ALEKSANDR KULIKOV	{"phone": "+70653130353"}
0005435529434	5EF0D4	9653 526767	DANIL STEPANOV	{"email": "stepanov.d25061972@postgrespro.ru", "phone": "+70420802749"}
0005435529435	F4004C	9089 919956	VITALIY IVANOV	{"phone": "+70601158436"}
0005435529436	5C460D	8462 573655	EDUARD EGOROV	{"email": "egorov_e-20061970@postgrespro.ru", "phone": "+70928658351"}
0005435529437	5C460D	0333 382649	ANATOLIY SOROKIN	{"email": "asorokin-091971@postgrespro.ru", "phone": "+70602108234"}
0005435529438	526396	0644 723309	ELENA BARANOVA	{"email": "baranova_elena_12051963@postgrespro.ru", "phone": "+70878019892"}
0005435529439	526396	2387 891591	ELIZAVETA ERMAKOVA	{"email": "ermakovaelizaveta.1965@postgrespro.ru", "phone": "+70857762253"}
0005435529440	526396	2637 180063	KONSTANTIN BELOV	{"email": "k_belov081980@postgrespro.ru", "phone": "+70110171782"}
0005435529441	526396	1067 589203	ALEKSANDRA ABRAMOVA	{"phone": "+70351299167"}
0005435529442	E8EF35	6133 562858	ALEKSEY MELNIKOV	{"email": "melnikov-aleksey-31121980@postgrespro.ru", "phone": "+70106163708"}
0005435529443	E8EF35	9459 509062	POLINA NIKITINA	{"phone": "+70174703649"}
0005435529444	E8EF35	7050 769222	NIKOLAY KUDRYASHOV	{"phone": "+70292030786"}
0005435529445	12EDFE	3842 159604	TIMUR NAUMOV	{"phone": "+70699655025"}
0005435529446	40242D	8671 850001	SERGEY KAZAKOV	{"phone": "+70027657984"}
0005435529447	CD91EC	1467 649837	MAKSIM KUZNECOV	{"email": "maksim.kuznecov09041957@postgrespro.ru", "phone": "+70946602880"}
0005435529448	CFF773	3507 959942	NIKITA ISAEV	{"email": "nisaev02021966@postgrespro.ru", "phone": "+70403551093"}
0005435529449	F03386	0836 189489	SVETLANA GORBUNOVA	{"email": "svetlanagorbunova-1958@postgrespro.ru", "phone": "+70046663328"}
0005435529450	F03386	7152 491933	VYACHESLAV KAZAKOV	{"phone": "+70147032996"}
0005435529451	E6C38A	8357 590657	SERGEY KOZLOV	{"email": "kozlov.s-041966@postgrespro.ru", "phone": "+70496133117"}
0005435529452	9A3FC1	9222 407119	YULIYA DANILOVA	{"phone": "+70695328231"}
0005435529453	9A3FC1	7414 838112	OKSANA KOVALEVA	{"phone": "+70007293674"}
0005435529454	6BCF68	2959 239716	FEDOR DENISOV	{"email": "fedor_denisov_1973@postgrespro.ru", "phone": "+70773947942"}
0005435529455	6BCF68	8808 333348	DMITRIY STEPANOV	{"phone": "+70208361718"}
0005435529456	BEE61A	2286 213866	ALEKSANDR MEDVEDEV	{"email": "medvedeva_28101981@postgrespro.ru", "phone": "+70778836830"}
0005435529457	BEE61A	7319 204467	DMITRIY SMIRNOV	{"email": "smirnov_dmitriy-081979@postgrespro.ru", "phone": "+70292001118"}
0005435529458	5B4260	6798 197563	ANTON EGOROV	{"email": "egorov-anton_081965@postgrespro.ru", "phone": "+70969359161"}
0005435529459	C4FCBE	6152 389425	MIKHAIL ANTONOV	{"email": "antonov.mikhail.011976@postgrespro.ru", "phone": "+70657388298"}
0005435529460	C4FCBE	6562 361830	ALEKSANDR VOLKOV	{"email": "aleksandr.volkov_28091973@postgrespro.ru", "phone": "+70688827237"}
0005435529461	E4BB5B	3751 236472	PETR IVANOV	{"email": "petr_ivanov1969@postgrespro.ru", "phone": "+70297725552"}
0005435529462	63AFE4	0892 562128	EVGENIY ANDREEV	{"email": "e-andreev.20111953@postgrespro.ru", "phone": "+70482062693"}
0005435529463	9893EC	6740 602953	EGOR DENISOV	{"email": "denisov_e20121976@postgrespro.ru", "phone": "+70404975715"}
0005435529464	5E525A	5918 472585	LYUDMILA KALININA	{"email": "l_kalinina_1971@postgrespro.ru", "phone": "+70466584574"}
0005435529465	5E525A	6204 796403	PAVEL ZHURAVLEV	{"phone": "+70126925803"}
0005435529466	42D6C9	5564 127861	ROZA EFREMOVA	{"email": "roza.efremova_1965@postgrespro.ru", "phone": "+70878957798"}
0005435529467	E47BFB	0974 236621	VALENTINA AKIMOVA	{"phone": "+70554108040"}
0005435529468	5E1291	2152 856917	OLGA TIMOFEEVA	{"email": "otimofeeva_1968@postgrespro.ru", "phone": "+70680982665"}
0005435529469	D660C7	7779 518724	GALINA DENISOVA	{"email": "galina.denisova_1967@postgrespro.ru", "phone": "+70502093309"}
0005435529470	97D0B9	0091 284099	OLGA TIMOFEEVA	{"phone": "+70130367913"}
0005435529471	97D0B9	4815 952120	MARIYA ZAKHAROVA	{"email": "m_zakharova.1975@postgrespro.ru", "phone": "+70400453074"}
0005435529472	09122D	5682 803930	MIKHAIL RODIONOV	{"email": "m.rodionov.15071973@postgrespro.ru", "phone": "+70771152106"}
0005435529473	601C9F	1133 878645	VASILIY KARPOV	{"email": "karpov.v071979@postgrespro.ru", "phone": "+70396826449"}
0005435529474	0152B1	4439 925124	LYUDMILA ABRAMOVA	{"email": "abramova-lyudmila-1965@postgrespro.ru", "phone": "+70353176114"}
0005435529475	0152B1	5462 025994	SERGEY MAKAROV	{"email": "s_makarov-101979@postgrespro.ru", "phone": "+70912263895"}
0005435529476	F3A768	4346 502086	GALINA TARASOVA	{"email": "galinatarasova-19041971@postgrespro.ru", "phone": "+70380821165"}
0005435529477	0CB732	2387 997465	VASILIY KISELEV	{"email": "vasiliy_kiselev_121984@postgrespro.ru", "phone": "+70898153008"}
0005435529478	5515A1	0032 853122	LARISA ANTONOVA	{"email": "larisa.antonova_1982@postgrespro.ru", "phone": "+70396677000"}
0005435529479	5515A1	9554 156376	SVETLANA KUZNECOVA	{"email": "kuznecova.svetlana-20071977@postgrespro.ru", "phone": "+70169547802"}
0005435529480	5515A1	1380 773884	VALERIY MELNIKOV	{"phone": "+70579439759"}
0005435529481	6A1D46	9480 322290	LYUDMILA IVANOVA	{"phone": "+70367186134"}
0005435529482	B66FAB	2205 224887	MARINA IVANOVA	{"phone": "+70062064058"}
0005435529483	07702D	3919 253059	VYACHESLAV FEDOROV	{"email": "v-fedorov-091979@postgrespro.ru", "phone": "+70904410869"}
0005435529484	512B09	9164 740933	MIKHAIL MOROZOV	{"email": "mikhailmorozov-28011983@postgrespro.ru", "phone": "+70525189193"}
0005435529485	E3FF49	2911 188482	NATALYA FEDOROVA	{"phone": "+70974706464"}
0005435529486	192E75	3077 712455	NIKOLAY KUZNECOV	{"phone": "+70189721092"}
0005435529487	192E75	5499 475148	ALEKSANDR IVANOV	{"email": "a_ivanov_091977@postgrespro.ru", "phone": "+70684349549"}
0005435529488	4A4F75	5943 408257	SERGEY MAKAROV	{"email": "makarov_s_081976@postgrespro.ru", "phone": "+70257409735"}
0005435529489	4A4F75	0572 055169	SERGEY SEMENOV	{"phone": "+70883882006"}
0005435529490	FDFE76	0071 362760	ELENA MAKAROVA	{"email": "makarova.elena.1969@postgrespro.ru", "phone": "+70794904776"}
0005435529491	790E39	0215 406169	MIKHAIL SIDOROV	{"email": "mikhail.sidorov_081964@postgrespro.ru", "phone": "+70451059790"}
0005435529492	17304B	4866 876243	NADEZHDA FILATOVA	{"email": "filatovanadezhda11101969@postgrespro.ru", "phone": "+70554397067"}
0005435529493	17304B	7030 425553	TAMARA ORLOVA	{"phone": "+70513074048"}
0005435529494	49A5E1	6887 764220	VASILIY VLASOV	{"phone": "+70323870530"}
0005435529495	49A5E1	6346 942684	VIKTOR MAKAROV	{"phone": "+70094537915"}
0005435529496	D52634	2767 286314	VLADIMIR ILIN	{"phone": "+70935261076"}
0005435529497	45B51E	2670 986486	YURIY SOROKIN	{"email": "sorokin.yuriy_1980@postgrespro.ru", "phone": "+70111795906"}
0005435529498	73B4A8	9990 184339	LYUDMILA VOLKOVA	{"phone": "+70249414817"}
0005435529499	2908E5	5887 456133	MARIYA TIKHONOVA	{"email": "tikhonova_mariya-011971@postgrespro.ru", "phone": "+70739567800"}
0005435529500	9EE727	7733 578296	DMITRIY KUZNECOV	{"email": "kuznecov.d_03021978@postgrespro.ru", "phone": "+70573291177"}
0005435529501	93A5BB	4305 127702	OLGA OSIPOVA	{"phone": "+70535773278"}
0005435529502	F6A6BC	5006 206823	PETR PETROV	{"email": "petrov_p_12041968@postgrespro.ru", "phone": "+70286744107"}
0005435529503	4A4567	9891 412716	IRINA LUKYANOVA	{"email": "i_lukyanova_071959@postgrespro.ru", "phone": "+70937817456"}
0005435529504	4A4567	0345 604623	OKSANA KOROLEVA	{"email": "koroleva.oksana.19051978@postgrespro.ru", "phone": "+70105297913"}
0005435529505	4A4567	1977 854760	IGOR ANTONOV	{"email": "antonov.i.101985@postgrespro.ru", "phone": "+70862491239"}
0005435529506	4A397C	4098 618426	NINA MAKAROVA	{"email": "n.makarova061970@postgrespro.ru", "phone": "+70585572927"}
0005435529507	C583C5	6642 394026	YURIY ANTONOV	{"email": "yantonov_101964@postgrespro.ru", "phone": "+70193454065"}
0005435529508	C213D4	0684 803833	SERGEY SIDOROV	{"email": "ssidorov.101974@postgrespro.ru", "phone": "+70394501816"}
0005435529509	213CE4	3240 272647	ANATOLIY IVANOV	{"phone": "+70366086835"}
0005435529510	213CE4	0598 189379	GENNADIY BORISOV	{"phone": "+70737243004"}
0005435529511	868324	2197 433170	NATALYA ZHURAVLEVA	{"email": "nzhuravleva11121971@postgrespro.ru", "phone": "+70846276255"}
0005435529512	CB4649	7405 616457	NIKITA MIKHAYLOV	{"phone": "+70743572373"}
0005435529513	9CE311	8030 110590	NINA DENISOVA	{"phone": "+70083300171"}
0005435529514	187D2F	0755 514211	ELENA LAZAREVA	{"phone": "+70197947410"}
0005435529515	1DFB7D	2497 023948	GALINA ZAKHAROVA	{"email": "galina-zakharova_101971@postgrespro.ru", "phone": "+70662050993"}
0005435529516	1DFB7D	2796 900622	IRINA KUZNECOVA	{"phone": "+70650519343"}
0005435529517	4E2D6D	7159 096676	EVGENIY FEDOROV	{"email": "fedorove.10041962@postgrespro.ru", "phone": "+70048304585"}
0005435529518	4E2D6D	7614 135073	VALENTINA CHERNOVA	{"email": "valentina_chernova.1967@postgrespro.ru", "phone": "+70724550291"}
0005435529519	BA54D0	8637 121731	SERGEY TIMOFEEV	{"email": "timofeev.s.031977@postgrespro.ru", "phone": "+70408885727"}
0005435529520	F5FD5D	7620 494867	ANDREY FROLOV	{"email": "andreyfrolov_1966@postgrespro.ru", "phone": "+70383479362"}
0005435529521	3C3D57	5692 484771	ANDREY NAZAROV	{"phone": "+70494514924"}
0005435529522	180F57	6711 875484	VLADIMIR KOZLOV	{"phone": "+70947553785"}
0005435529523	A28651	4120 835166	SEMEN NIKOLAEV	{"phone": "+70766153148"}
0005435529524	A28651	4288 922615	VLADIMIR IVANOV	{"phone": "+70352897093"}
0005435529525	5B5FF1	6683 454770	TATYANA PETROVA	{"email": "t-petrova-28021972@postgrespro.ru", "phone": "+70789379280"}
0005435529526	5B5FF1	2038 663245	VERA KAZAKOVA	{"phone": "+70681985330"}
0005435529527	0561F9	2904 560359	ALEKSANDRA GERASIMOVA	{"phone": "+70642774924"}
0005435529528	9CA9B5	9346 400033	ALEKSANDRA POTAPOVA	{"email": "potapova-a.17011972@postgrespro.ru", "phone": "+70930817757"}
0005435529529	9CA9B5	5480 438923	LYUDMILA MEDVEDEVA	{"email": "medvedeva_l.02041975@postgrespro.ru", "phone": "+70130277474"}
0005435529530	9CA9B5	7384 065887	TIMOFEY SOLOVEV	{"phone": "+70262154362"}
0005435529531	D0BFDD	6480 412743	ANTON FEDOROV	{"phone": "+70863033036"}
0005435529532	D0BFDD	5274 428858	LYUDMILA FILATOVA	{"email": "l_filatova-011976@postgrespro.ru", "phone": "+70420228578"}
0005435529533	D0BFDD	3479 185205	PETR GUSEV	{"phone": "+70602694199"}
0005435529534	1C5082	7009 952389	DMITRIY BELOV	{"phone": "+70489396189"}
0005435529535	1C5082	3512 615398	MAKSIM PAVLOV	{"phone": "+70245521268"}
0005435529536	219D2E	4441 347723	VLADIMIR MATVEEV	{"phone": "+70993412965"}
0005435529537	219D2E	8721 739932	DMITRIY KUZNECOV	{"email": "dkuznecov.061968@postgrespro.ru", "phone": "+70030987844"}
0005435529538	0BD93B	7799 694133	MARIYA SMIRNOVA	{"email": "smirnova-mariya-1982@postgrespro.ru", "phone": "+70975329396"}
0005435529539	947FD5	4967 046196	PAVEL NIKOLAEV	{"email": "p_nikolaev_021972@postgrespro.ru", "phone": "+70991622392"}
0005435529540	947FD5	1225 123863	LIDIYA GORBUNOVA	{"email": "gorbunova.l_01111982@postgrespro.ru", "phone": "+70850968056"}
0005435529541	947FD5	6659 200590	MAKSIM FEDOROV	{"email": "fedorov.maksim_1973@postgrespro.ru", "phone": "+70668517038"}
0005435529542	F8FB4B	7164 897823	MARIYA PETROVA	{"email": "m-petrova-25091965@postgrespro.ru", "phone": "+70156526795"}
0005435529543	5F6902	1643 497124	GEORGIY IVANOV	{"phone": "+70587420898"}
0005435529544	5F6902	5200 974934	ALEKSANDR NIKOLAEV	{"phone": "+70934809452"}
0005435529545	D15D07	8098 669321	KIRILL TIMOFEEV	{"phone": "+70837109359"}
0005435529546	8572D7	9437 924690	ALEKSANDR GERASIMOV	{"email": "gerasimov_aleksandr.07121981@postgrespro.ru", "phone": "+70764999954"}
0005435529547	D586B8	2093 666261	DENIS KARPOV	{"phone": "+70639881855"}
0005435529548	CF8456	9783 079328	DMITRIY AFANASEV	{"phone": "+70578226326"}
0005435529549	CF8456	5995 708845	DMITRIY MELNIKOV	{"phone": "+70183069644"}
0005435529550	F71BB1	5101 545687	IGOR VASILEV	{"phone": "+70715345160"}
0005435529551	A16079	4845 072324	NIKOLAY BORISOV	{"email": "n_borisov031966@postgrespro.ru", "phone": "+70092277664"}
0005435529552	A1D664	9498 108678	MIKHAIL ANDREEV	{"phone": "+70377021611"}
0005435529553	98DA68	9386 076993	KLARA VLASOVA	{"email": "vlasovaklara_29051972@postgrespro.ru", "phone": "+70418927246"}
0005435529554	A2CDDE	9026 859359	ALEKSEY ZAYCEV	{"email": "a-zaycev08111979@postgrespro.ru", "phone": "+70154330394"}
0005435529555	A2CDDE	7408 064461	LYUBOV EFIMOVA	{"email": "l-efimova1977@postgrespro.ru", "phone": "+70432061806"}
0005435529556	CF82DF	9065 557222	SERGEY YAKOVLEV	{"phone": "+70342652094"}
0005435529557	65B4D3	1591 836396	YULIYA MAKAROVA	{"phone": "+70432623361"}
0005435529558	65B4D3	9287 801915	ALEKSANDR FILIPPOV	{"email": "a_filippov111960@postgrespro.ru", "phone": "+70734132709"}
0005435529559	689CD3	0118 632440	SERGEY ZAKHAROV	{"phone": "+70545389149"}
0005435529560	689CD3	4436 150196	PAVEL SIDOROV	{"email": "pavel.sidorov.091978@postgrespro.ru", "phone": "+70346950061"}
0005435529561	64B12A	7849 800187	VLADIMIR MAKAROV	{"email": "v.makarov_091971@postgrespro.ru", "phone": "+70894215334"}
0005435529562	FDE791	8877 116335	VERONIKA MOROZOVA	{"email": "veronika.morozova.1968@postgrespro.ru", "phone": "+70145229433"}
0005435529563	A085E1	6562 043659	LILIYA ZHURAVLEVA	{"phone": "+70250180365"}
0005435529564	A3D3C4	1778 292726	EVGENIY EGOROV	{"email": "evgeniy_egorov.111967@postgrespro.ru", "phone": "+70840956922"}
0005435529565	01480F	6223 454295	DENIS SOROKIN	{"phone": "+70216491082"}
0005435529566	01480F	7849 756598	MIKHAIL GAVRILOV	{"phone": "+70961398546"}
0005435529568	ECCCD0	6738 241196	DMITRIY AFANASEV	{"phone": "+70332264227"}
0005435529569	AAC4DC	9172 451257	ANZHELA GRISHINA	{"email": "a-grishina_27101974@postgrespro.ru", "phone": "+70468229769"}
0005435529570	D52BD8	5809 825450	MAKSIM ROMANOV	{"phone": "+70144551416"}
0005435529571	E756D0	2969 753382	ALENA ALEKSANDROVA	{"email": "aleksandrova_alena.081982@postgrespro.ru", "phone": "+70594778799"}
0005435529572	826EF3	4153 902310	MARIYA ISAEVA	{"email": "isaeva.mariya.021977@postgrespro.ru", "phone": "+70441597279"}
0005435529573	43D214	1456 820643	TAMARA GUSEVA	{"phone": "+70875713284"}
0005435529574	50B818	9068 192601	OLEG FILIPPOV	{"email": "filippov_o.1969@postgrespro.ru", "phone": "+70095628066"}
0005435529575	E64EB6	0360 150343	ANDREY VOROBEV	{"phone": "+70755987603"}
0005435529576	E64EB6	0635 650415	LYUDMILA ZAKHAROVA	{"email": "lyudmilazakharova-1982@postgrespro.ru", "phone": "+70133901452"}
0005435529577	159C2C	9238 625807	ALEKSEY BARANOV	{"phone": "+70127767155"}
0005435529578	867B46	5547 276367	ILYA ZAYCEV	{"phone": "+70836246559"}
0005435529579	D1357A	8102 609175	YURIY SCHERBAKOV	{"phone": "+70318696842"}
0005435529580	D0A924	5538 680931	OLEG KOZLOV	{"email": "kozlov_o_1979@postgrespro.ru", "phone": "+70754529501"}
0005435529581	E5B51D	4068 455283	SERGEY KUZNECOV	{"phone": "+70394495456"}
0005435529582	A8A48E	3469 195891	NINA TITOVA	{"email": "n_titova-071973@postgrespro.ru", "phone": "+70411261514"}
0005435529583	214047	8530 221043	MIKHAIL KULIKOV	{"phone": "+70241054865"}
0005435529584	A4905A	9324 350804	KSENIYA OSIPOVA	{"email": "osipova_k-051975@postgrespro.ru", "phone": "+70335592145"}
0005435529585	A4905A	3635 460081	ALEKSEY ZHURAVLEV	{"email": "alekseyzhuravlev24041978@postgrespro.ru", "phone": "+70350262215"}
0005435529586	34DDF3	9529 562473	LYUBOV SOKOLOVA	{"email": "sokolova_lyubov1962@postgrespro.ru", "phone": "+70582814380"}
0005435529587	129353	2607 733845	SVETLANA ZHURAVLEVA	{"phone": "+70370539761"}
0005435529588	D3EBE3	7844 808167	SERGEY SIDOROV	{"phone": "+70786849263"}
0005435529589	D3EBE3	6914 937311	MARINA KUZNECOVA	{"email": "kuznecova-m091965@postgrespro.ru", "phone": "+70659902405"}
0005435529590	D3EBE3	0210 933152	NATALIYA BORISOVA	{"email": "borisova_nataliya20031965@postgrespro.ru", "phone": "+70992980753"}
0005435529591	457BA8	0386 563523	KONSTANTIN MOISEEV	{"email": "moiseev_k071975@postgrespro.ru", "phone": "+70878000687"}
0005435529592	457BA8	1935 205771	LYUBOV MAKAROVA	{"email": "makarova.lyubov_1964@postgrespro.ru", "phone": "+70183584825"}
0005435529593	3827E3	8736 862063	MIKHAIL KARPOV	{"phone": "+70823207150"}
0005435529594	8F032B	6167 794651	EDUARD PETROV	{"email": "e.petrov11021958@postgrespro.ru", "phone": "+70319609153"}
0005435529595	8F032B	0384 769763	ALEKSANDR ZHUKOV	{"email": "zhukov_aleksandr-051976@postgrespro.ru", "phone": "+70995162989"}
0005435529596	8A3E4C	0762 958137	VALERIY GUSEV	{"email": "valeriy_gusev.1971@postgrespro.ru", "phone": "+70639904498"}
0005435529597	C06FDE	9342 085994	OLEG ISAEV	{"phone": "+70123663387"}
0005435529598	88F0BD	5106 731400	TATYANA DENISOVA	{"phone": "+70064769813"}
0005435529599	88F0BD	9642 552309	SERGEY KULIKOV	{"email": "sergey.kulikov-121963@postgrespro.ru", "phone": "+70349241374"}
0005435529600	F8B69B	7679 407460	NADEZHDA GUSEVA	{"email": "guseva.n-021974@postgrespro.ru", "phone": "+70949605523"}
0005435529601	E8A0A8	4051 847801	VALENTIN CHERNOV	{"phone": "+70884557859"}
0005435529602	F2E276	9318 342345	ALEKSANDR FEDOROV	{"phone": "+70874035408"}
0005435529603	80376A	1615 160474	STANISLAV KUZMIN	{"phone": "+70744056142"}
0005435529604	00697B	9990 724471	ALEKSANDR ALEKSEEV	{"email": "aalekseev-1970@postgrespro.ru", "phone": "+70318073919"}
0005435529605	00697B	4311 112009	SVETLANA TARASOVA	{"phone": "+70565349026"}
0005435529606	00697B	9040 072311	ALEKSANDR BONDARENKO	{"email": "bondarenko.a-1983@postgrespro.ru", "phone": "+70879812912"}
0005435529607	D30263	9947 465539	LYUBOV ZAKHAROVA	{"phone": "+70328362580"}
0005435529608	636DB1	2573 500674	ELENA NAUMOVA	{"phone": "+70921718155"}
0005435529609	AE8275	1211 068593	TAMARA ILINA	{"phone": "+70738467929"}
0005435529610	8A6CD1	5707 127556	MARIYA MOROZOVA	{"email": "mariya_morozova_021970@postgrespro.ru", "phone": "+70139144358"}
0005435529611	638D24	9678 847126	SERGEY MIKHAYLOV	{"email": "mikhaylov_s_1966@postgrespro.ru", "phone": "+70801934623"}
0005435529612	25175E	2715 327228	INESSA KOROLEVA	{"phone": "+70751563420"}
0005435529613	25175E	6954 211010	MARAT NIKITIN	{"phone": "+70476264792"}
0005435529614	D884B4	4427 430611	DENIS MAKAROV	{"phone": "+70116713992"}
0005435529615	E2F07D	3499 606012	RUSLAN SAVELEV	{"phone": "+70338741957"}
0005435529616	D76F05	9498 929857	EVGENIY ILIN	{"phone": "+70230237330"}
0005435529617	489E2A	1479 547159	VIOLETTA OSIPOVA	{"email": "osipovavioletta02031978@postgrespro.ru", "phone": "+70101431496"}
0005435529618	7915BD	5299 468511	PAVEL ABRAMOV	{"email": "p_abramov_021971@postgrespro.ru", "phone": "+70839213565"}
0005435529619	7915BD	3729 476659	ALEKSANDR GRIGOREV	{"email": "grigorev.a.1972@postgrespro.ru", "phone": "+70320776018"}
0005435529620	B79196	8369 632146	NIKOLAY POPOV	{"email": "nikolay_popov-1970@postgrespro.ru", "phone": "+70104994307"}
0005435529621	3AEC46	9610 200943	SVETLANA DAVYDOVA	{"email": "svetlanadavydova.031970@postgrespro.ru", "phone": "+70570890974"}
0005435529622	3AEC46	4127 005109	NIKOLAY ZHUKOV	{"phone": "+70516274875"}
0005435529623	3AEC46	4962 241997	VLADIMIR KOZLOV	{"phone": "+70752348175"}
0005435529624	73BE93	9508 977515	GALINA IVANOVA	{"phone": "+70483476294"}
0005435529625	73BE93	4246 492058	DMITRIY EGOROV	{"email": "dmitriy-egorov.121966@postgrespro.ru", "phone": "+70071432202"}
0005435529626	89F61F	5276 496929	ALEKSEY ILIN	{"email": "alekseyilin1977@postgrespro.ru", "phone": "+70483039330"}
0005435529627	39CA06	9768 314479	TATYANA EGOROVA	{"phone": "+70880265350"}
0005435529628	177D34	4450 334682	LYUDMILA KOROLEVA	{"email": "koroleva-lyudmila_07021972@postgrespro.ru", "phone": "+70667896554"}
0005435529629	E84A02	5040 341749	RUZALIYA ORLOVA	{"phone": "+70249849677"}
0005435529630	C70814	5835 698824	IGOR ALEKSEEV	{"phone": "+70474396738"}
0005435529631	C70814	4581 830471	VYACHESLAV KOROLEV	{"phone": "+70511170641"}
0005435529632	C45991	7154 781538	ANDREY DAVYDOV	{"email": "andrey.davydov.05011971@postgrespro.ru", "phone": "+70840764871"}
0005435529633	223261	4136 970090	VLADISLAV FEDOTOV	{"phone": "+70279720284"}
0005435529634	77A1BC	4390 112747	VIOLETTA GAVRILOVA	{"email": "v_gavrilova-07111972@postgrespro.ru", "phone": "+70243108594"}
0005435529635	77A1BC	0446 617809	ZOYA IVANOVA	{"email": "zoyaivanova_031971@postgrespro.ru", "phone": "+70702709517"}
0005435529636	E46AB7	3986 101186	SOFYA BELYAEVA	{"email": "belyaeva-sofya.021969@postgrespro.ru", "phone": "+70663376078"}
0005435529637	E46AB7	9891 929878	NIKOLAY VOLKOV	{"email": "volkov-n_27051975@postgrespro.ru", "phone": "+70883414669"}
0005435529638	352093	9759 019727	MARAT FROLOV	{"phone": "+70627267001"}
0005435529639	1BB29F	1590 100761	SERGEY ALEKSEEV	{"email": "salekseev23111973@postgrespro.ru", "phone": "+70189949380"}
0005435529640	1BB29F	7049 924265	VLADIMIR KOROLEV	{"email": "korolev_vladimir.1977@postgrespro.ru", "phone": "+70395054450"}
0005435529641	1BB29F	5793 569101	SERGEY ROMANOV	{"phone": "+70410500031"}
0005435529642	62CAC1	6147 965480	EVGENIYA MATVEEVA	{"phone": "+70051264775"}
0005435529643	A581AA	8260 287223	NINA MEDVEDEVA	{"phone": "+70998187965"}
0005435529644	A581AA	3280 047528	DENIS GUSEV	{"phone": "+70466679677"}
0005435529645	B456EB	5791 610985	DMITRIY NAZAROV	{"email": "nazarovd-27011987@postgrespro.ru", "phone": "+70996680666"}
0005435529646	6DBF2A	6044 697641	STANISLAV SAVELEV	{"phone": "+70814879071"}
0005435529647	6DBF2A	4751 334236	VIKTORIYA LEBEDEVA	{"phone": "+70656894022"}
0005435529648	51A45A	3230 596551	VIKTOR KUZNECOV	{"email": "kuznecov_viktor-03051973@postgrespro.ru", "phone": "+70600012251"}
0005435529649	51A45A	7117 746586	RAISA ANTONOVA	{"phone": "+70536114608"}
0005435529650	1A0D16	6565 868418	ALEKSEY MEDVEDEV	{"phone": "+70926790834"}
0005435529651	8D8BE0	2273 713481	ANDREY DAVYDOV	{"phone": "+70743954381"}
0005435529652	543FAB	9745 241210	ALEKSANDRA KOROLEVA	{"email": "koroleva-a18071973@postgrespro.ru", "phone": "+70527979401"}
0005435529653	FD311C	8201 195332	LYUDMILA FEDOROVA	{"email": "lyudmila_fedorova_1975@postgrespro.ru", "phone": "+70312302481"}
0005435529654	3C3CC5	3788 161415	DMITRIY ROMANOV	{"phone": "+70181670267"}
0005435529655	B2D342	9920 426506	SVETLANA ZHURAVLEVA	{"email": "zhuravlevasvetlana.021964@postgrespro.ru", "phone": "+70396055992"}
0005435529656	30CDA0	3679 361714	IVAN SCHERBAKOV	{"email": "ivan_scherbakov.06101972@postgrespro.ru", "phone": "+70530212548"}
0005435529657	30CDA0	5463 331933	TAMARA KUZNECOVA	{"email": "tamara-kuznecova11011968@postgrespro.ru", "phone": "+70336836522"}
0005435529658	EA2346	7784 446030	IRINA SMIRNOVA	{"email": "irina_smirnova1984@postgrespro.ru", "phone": "+70072025873"}
0005435529659	756306	4655 460897	ALEKSANDR KOZLOV	{"phone": "+70912709297"}
0005435529660	70B454	6633 975709	IVAN KULIKOV	{"phone": "+70942102613"}
0005435529661	70B454	8947 754543	RAISA ANTONOVA	{"email": "antonova_r.041977@postgrespro.ru", "phone": "+70646363972"}
0005435529662	907445	1518 937739	NIKOLAY IVANOV	{"email": "ivanovnikolay_02031986@postgrespro.ru", "phone": "+70382197413"}
0005435529663	3AD5FD	3893 311114	SERGEY NIKOLAEV	{"email": "nikolaev_s-29081965@postgrespro.ru", "phone": "+70414494044"}
0005435529664	D87167	7280 143290	ALEVTINA TARASOVA	{"email": "tarasova_alevtina.1962@postgrespro.ru", "phone": "+70994510495"}
0005435529665	D87167	2161 442708	ZHANNA ANDREEVA	{"email": "zhanna-andreeva.17021981@postgrespro.ru", "phone": "+70054715862"}
0005435529666	CF31DE	0109 517744	DARYA MELNIKOVA	{"email": "melnikova.d1960@postgrespro.ru", "phone": "+70782471563"}
0005435529667	5CB662	3409 061493	KARINA VASILEVA	{"email": "k_vasileva_1972@postgrespro.ru", "phone": "+70841038846"}
0005435529668	A31571	5682 744585	TATYANA AFANASEVA	{"email": "tatyana_afanaseva_17111969@postgrespro.ru", "phone": "+70737665756"}
0005435529669	0210E3	2805 413549	VIKTOR AFANASEV	{"email": "v_afanasev-111975@postgrespro.ru", "phone": "+70868443072"}
0005435529670	FEB0AD	7162 241348	KLAVDIYA SMIRNOVA	{"phone": "+70094149236"}
0005435529671	5B96E7	1985 477981	ANATOLIY KUZMIN	{"phone": "+70251541709"}
0005435529672	54D76D	6817 584448	VADIM PAVLOV	{"phone": "+70965135934"}
0005435529673	823AA9	8985 414361	TAMARA KOMAROVA	{"email": "tamara-komarova.041974@postgrespro.ru", "phone": "+70023365239"}
0005435529674	7B17BF	7791 464789	PETR ORLOV	{"phone": "+70886643539"}
0005435529675	7B17BF	7110 986724	PAVEL DENISOV	{"email": "pavel.denisov_1972@postgrespro.ru", "phone": "+70976233076"}
0005435529676	0B4E88	8665 987016	GENNADIY ROMANOV	{"email": "g-romanov_1971@postgrespro.ru", "phone": "+70072434617"}
0005435529677	0B4E88	2951 880642	PETR SMIRNOV	{"phone": "+70161241024"}
0005435529678	79C2D2	7661 776590	SERGEY POPOV	{"email": "popovsergey.031971@postgrespro.ru", "phone": "+70780946838"}
0005435529679	A335A1	8333 760184	VYACHESLAV ALEKSEEV	{"email": "v_alekseev_011973@postgrespro.ru", "phone": "+70874228894"}
0005435529680	AEBE27	3556 678785	TAMARA ALEKSANDROVA	{"phone": "+70910756413"}
0005435529681	AEBE27	7484 182234	YULIYA MAKAROVA	{"phone": "+70475401090"}
0005435529682	8EBFE3	5103 325360	LILIYA NIKOLAEVA	{"email": "liliya.nikolaeva-1975@postgrespro.ru", "phone": "+70798950576"}
0005435529683	E7441D	2195 604298	SVETLANA NIKOLAEVA	{"email": "nikolaeva.svetlana-1966@postgrespro.ru", "phone": "+70105438004"}
0005435529684	DBC2C7	6975 824543	KRISTINA KISELEVA	{"email": "k-kiseleva.1978@postgrespro.ru", "phone": "+70156529198"}
0005435529685	DBC2C7	7402 429468	AZAT VLASOV	{"email": "azat.vlasov-1968@postgrespro.ru", "phone": "+70492406346"}
0005435529686	27A65F	1916 866693	ANDREY ALEKSEEV	{"email": "andrey.alekseev_051972@postgrespro.ru", "phone": "+70167376160"}
0005435529687	BC157D	6014 134409	IRINA KOROLEVA	{"email": "irina.koroleva_081972@postgrespro.ru", "phone": "+70391631946"}
0005435529688	BC157D	7885 153548	ANNA RYABOVA	{"phone": "+70966846143"}
0005435529689	BC157D	6736 498251	OLGA ABRAMOVA	{"email": "o_abramova1977@postgrespro.ru", "phone": "+70245397659"}
0005435529690	082850	6972 231931	ILDAR FOMIN	{"phone": "+70184280240"}
0005435529691	082850	1912 081745	ALEKSANDR DAVYDOV	{"email": "adavydov_24061966@postgrespro.ru", "phone": "+70749428701"}
0005435529692	082850	7414 721442	MARIYA MEDVEDEVA	{"email": "medvedevam_1972@postgrespro.ru", "phone": "+70005784467"}
0005435529693	982858	5297 742495	ALEKSEY KOZLOV	{"phone": "+70064482704"}
0005435529694	982858	4949 721090	VLADIMIR POPOV	{"email": "vladimir-popov_061971@postgrespro.ru", "phone": "+70977511262"}
0005435529695	8BC243	1283 081098	IRINA KRASNOVA	{"phone": "+70201902815"}
0005435529696	EE7C72	4975 117464	VLADIMIR NIKOLAEV	{"email": "v_nikolaev1968@postgrespro.ru", "phone": "+70204459632"}
0005435529697	73B67F	2697 707056	STEPAN NIKITIN	{"email": "nikitin_stepan_111982@postgrespro.ru", "phone": "+70273230703"}
0005435529698	BAB119	9138 420052	GALINA DMITRIEVA	{"email": "galina-dmitrieva-041974@postgrespro.ru", "phone": "+70928351959"}
0005435529699	43DB57	6561 361508	PRASKOVYA ABRAMOVA	{"email": "abramova_p1973@postgrespro.ru", "phone": "+70093074623"}
0005435529700	6571AB	1009 960147	YULIYA NIKITINA	{"email": "nikitinayuliya-1976@postgrespro.ru", "phone": "+70002943992"}
0005435529701	6571AB	0991 139011	ALEKSEY ANDREEV	{"email": "aleksey_andreev081972@postgrespro.ru", "phone": "+70123863785"}
0005435529702	42BC65	6973 117026	ALEVTINA KULIKOVA	{"email": "kulikova.alevtina-061970@postgrespro.ru", "phone": "+70010749375"}
0005435529703	0EB8DA	9650 528937	ANTON ROMANOV	{"phone": "+70422827297"}
0005435529704	971269	5817 322676	ELENA MELNIKOVA	{"email": "melnikova.e-051970@postgrespro.ru", "phone": "+70987855597"}
0005435529705	971269	0227 891469	YULIYA VASILEVA	{"email": "y-vasileva-1972@postgrespro.ru", "phone": "+70310810140"}
0005435529706	D06C8F	4480 918810	ALFIYA FILATOVA	{"email": "filatovaalfiya-1975@postgrespro.ru", "phone": "+70066305397"}
0005435529707	D84BE1	0549 220377	NATALYA IVANOVA	{"email": "n-ivanova.12031974@postgrespro.ru", "phone": "+70190876454"}
0005435529708	1A95D2	7741 964305	EKATERINA LUKYANOVA	{"email": "lukyanovae.051970@postgrespro.ru", "phone": "+70515715069"}
0005435529709	91D5E2	8595 607515	YURIY SEMENOV	{"email": "ysemenov03081963@postgrespro.ru", "phone": "+70556775914"}
0005435529710	91D5E2	5484 467290	ANTONIDA ZAYCEVA	{"email": "zaycevaantonida14101965@postgrespro.ru", "phone": "+70977912947"}
0005435529711	4D461A	0320 006759	GALINA GORBUNOVA	{"phone": "+70104958148"}
0005435529712	4D461A	1753 314000	TATYANA ZOTOVA	{"phone": "+70908576124"}
0005435529713	4D461A	5626 714027	VYACHESLAV SEMENOV	{"email": "v.semenov.13011978@postgrespro.ru", "phone": "+70846075992"}
0005435529714	05BF2D	4911 053718	VITALIY SCHERBAKOV	{"email": "scherbakovv-111961@postgrespro.ru", "phone": "+70044347351"}
0005435529715	0398CF	9563 122894	ELENA KONOVALOVA	{"phone": "+70354019790"}
0005435529716	4AED77	9843 952690	ELENA SIDOROVA	{"email": "sidorova-e.27081973@postgrespro.ru", "phone": "+70469264397"}
0005435529717	F08D6D	3119 150154	VLADIMIR STEPANOV	{"email": "vstepanov101971@postgrespro.ru", "phone": "+70701113830"}
0005435529718	4B14B2	5635 605434	VIKTOR NIKITIN	{"email": "viktor-nikitin_18021983@postgrespro.ru", "phone": "+70624774312"}
0005435529719	198507	0406 650939	IRINA KOROLEVA	{"phone": "+70156632897"}
0005435529720	788E6B	7105 573591	VIKTOR AFANASEV	{"phone": "+70962031611"}
0005435529721	788E6B	6926 748229	ALEVTINA SCHERBAKOVA	{"email": "alevtina.scherbakova_23101970@postgrespro.ru", "phone": "+70986287307"}
0005435529722	788E6B	6411 286039	ALEKSEY VLASOV	{"email": "a.vlasov.1971@postgrespro.ru", "phone": "+70065057724"}
0005435529723	E3690A	8365 901497	NADEZHDA BELYAEVA	{"phone": "+70881240613"}
0005435529724	E3690A	1156 927594	SERGEY MOISEEV	{"email": "moiseev-sergey.051982@postgrespro.ru", "phone": "+70429557784"}
0005435529725	29F61D	7179 172822	GENNADIY ZAKHAROV	{"phone": "+70043089877"}
0005435529726	855439	6510 113744	MARIYA KULIKOVA	{"email": "m-kulikova-12081978@postgrespro.ru", "phone": "+70389484246"}
0005435529727	C736D9	1965 914698	VLADIMIR FEDOROV	{"email": "v.fedorov07111974@postgrespro.ru", "phone": "+70298753541"}
0005435529728	5378F8	9868 330197	IRINA BOGDANOVA	{"phone": "+70863881308"}
0005435529729	18C58A	4014 440906	NATALYA MIRONOVA	{"email": "mironova-n.12111968@postgrespro.ru", "phone": "+70340124600"}
0005435529730	18C58A	2254 778953	OLESYA SMIRNOVA	{"email": "smirnovaolesya1982@postgrespro.ru", "phone": "+70440121147"}
0005435529731	0E1042	4159 053829	OKSANA KULIKOVA	{"phone": "+70655879129"}
0005435529732	30E45A	8466 500904	DENIS POPOV	{"email": "d_popov.081977@postgrespro.ru", "phone": "+70274217013"}
0005435529733	30E45A	1939 515126	VERA SOKOLOVA	{"phone": "+70340640881"}
0005435529734	262A03	6400 798531	FARID AFANASEV	{"phone": "+70924742669"}
0005435529735	262A03	5189 236877	ANASTASIYA CHERNOVA	{"email": "chernovaa_1976@postgrespro.ru", "phone": "+70680038267"}
0005435529736	1D8323	6517 019116	SERGEY CHERNOV	{"email": "s_chernov_30121970@postgrespro.ru", "phone": "+70124452357"}
0005435529737	5435DE	4837 900701	SERGEY CHERNOV	{"phone": "+70385044062"}
0005435529738	FCB8DC	7358 773537	LYUBOV ANDREEVA	{"email": "l-andreeva_28121974@postgrespro.ru", "phone": "+70950115587"}
0005435529739	EEE592	6797 295020	ANASTASIYA NESTEROVA	{"email": "nesterovaa_12041983@postgrespro.ru", "phone": "+70817940583"}
0005435529740	EEE592	2523 138393	OLEG KAZAKOV	{"email": "kazakov_oleg-1970@postgrespro.ru", "phone": "+70835643763"}
0005435529741	A0A2C3	8363 812296	VLADIMIR SOLOVEV	{"phone": "+70135822436"}
0005435529742	233D59	4391 419606	YULIYA PAVLOVA	{"phone": "+70449813508"}
0005435529743	233D59	2933 507565	TIMOFEY DMITRIEV	{"email": "dmitriev_t19111969@postgrespro.ru", "phone": "+70322152801"}
0005435529744	32154B	0263 659932	VALENTINA KOZLOVA	{"phone": "+70172839346"}
0005435529745	32154B	7781 853799	IGOR ZAYCEV	{"phone": "+70961172720"}
0005435529746	FBA1E3	6347 496912	NINA ROMANOVA	{"phone": "+70623542429"}
0005435529747	FBA1E3	4500 002263	IRINA KOLESNIKOVA	{"email": "kolesnikova.i.081971@postgrespro.ru", "phone": "+70978304644"}
0005435529748	FBA1E3	7427 869438	ELENA MELNIKOVA	{"email": "elenamelnikova.06051979@postgrespro.ru", "phone": "+70490683917"}
0005435529749	12B783	9012 018670	ALEKSANDRA MALYSHEVA	{"phone": "+70562472497"}
0005435529750	4B5EEA	5795 673342	TATYANA VASILEVA	{"email": "vasileva_tatyana_121977@postgrespro.ru", "phone": "+70341075434"}
0005435529751	4B5EEA	7704 504712	SERGEY MAKAROV	{"email": "sergey_makarov101968@postgrespro.ru", "phone": "+70480987783"}
0005435529752	B7EEAA	3373 107988	EKATERINA ALEKSANDROVA	{"phone": "+70226678362"}
0005435529753	81B825	6026 659442	NADEZHDA SEMENOVA	{"phone": "+70740156012"}
0005435529754	8B5C6F	2804 798563	ARTEM STEPANOV	{"email": "a.stepanov.25081973@postgrespro.ru", "phone": "+70314044435"}
0005435529755	8B5C6F	6164 729036	IVAN SAVELEV	{"email": "ivan.savelev_15121980@postgrespro.ru", "phone": "+70503542379"}
0005435529756	A77A10	1417 206659	GALINA MOROZOVA	{"email": "morozovag_111978@postgrespro.ru", "phone": "+70929524370"}
0005435529757	9129FF	3447 744355	IGOR IVANOV	{"phone": "+70128153387"}
0005435529758	9129FF	6830 421903	TATYANA MARTYNOVA	{"phone": "+70146119147"}
0005435529759	468E21	5428 333590	LYUDMILA SIDOROVA	{"email": "lyudmila.sidorova-011981@postgrespro.ru", "phone": "+70952576379"}
0005435529760	E9DD13	3652 534902	NIKOLAY GERASIMOV	{"email": "gerasimov.nikolay_051982@postgrespro.ru", "phone": "+70518132295"}
0005435529761	E9DD13	4764 548401	NATALYA DANILOVA	{"email": "danilova-n.28021969@postgrespro.ru", "phone": "+70007710610"}
0005435529762	E80895	4098 291022	DANILA MIKHAYLOV	{"email": "d.mikhaylov22081970@postgrespro.ru", "phone": "+70926053509"}
0005435529763	74BA9C	7308 432632	VALERIY IVANOV	{"email": "ivanovvaleriy.1974@postgrespro.ru", "phone": "+70953801687"}
0005435529764	3492A8	0816 728774	VLADIMIR EGOROV	{"email": "egorov-vladimir.09051970@postgrespro.ru", "phone": "+70581809975"}
0005435529765	42EBE0	1327 157024	ALEKSANDR MOROZOV	{"phone": "+70227040674"}
0005435529766	42EBE0	0312 206540	SOFIYA KOLESNIKOVA	{"email": "skolesnikova.051975@postgrespro.ru", "phone": "+70222367857"}
0005435529767	A25044	3903 280126	EVGENIY ANTONOV	{"phone": "+70573956429"}
0005435529768	A25044	2809 974497	DMITRIY AFANASEV	{"phone": "+70809600920"}
0005435529769	BE2E32	7309 708902	ANNA EGOROVA	{"email": "egorova-anna.041961@postgrespro.ru", "phone": "+70187145162"}
0005435529770	BE2E32	6693 130813	MIKHAIL KONOVALOV	{"email": "konovalovmikhail-1971@postgrespro.ru", "phone": "+70345528297"}
0005435529771	4397D2	9267 477588	ALEKSEY KISELEV	{"phone": "+70749054676"}
0005435529772	96C992	4104 452509	OLGA KRASNOVA	{"email": "olgakrasnova.28101963@postgrespro.ru", "phone": "+70728926418"}
0005435529773	CFF409	0794 704490	ARTEM DMITRIEV	{"phone": "+70785680295"}
0005435529774	500B78	9666 205233	ANTONINA POPOVA	{"email": "antoninapopova.1962@postgrespro.ru", "phone": "+70803921810"}
0005435529775	09E49F	2606 510624	TATYANA ROMANOVA	{"email": "romanova.t14101964@postgrespro.ru", "phone": "+70437771722"}
0005435529776	8404E0	6886 739127	OLGA SMIRNOVA	{"phone": "+70622289622"}
0005435529777	8404E0	3718 711658	OLEG DAVYDOV	{"email": "davydov_o.1974@postgrespro.ru", "phone": "+70013707979"}
0005435529778	84A147	2531 572328	ALINA GORBUNOVA	{"phone": "+70815483331"}
0005435529779	0B32BE	5945 680692	VIKTOR FILIPPOV	{"email": "viktor-filippov_29041971@postgrespro.ru", "phone": "+70110406800"}
0005435529780	E74358	6897 169680	OLGA FILATOVA	{"email": "ofilatova-03031958@postgrespro.ru", "phone": "+70909734136"}
0005435529781	E74358	7222 249470	IVAN NIKOLAEV	{"email": "i-nikolaev.21021972@postgrespro.ru", "phone": "+70547863778"}
0005435529782	45C9E6	5097 713159	ZOYA NIKITINA	{"phone": "+70866626547"}
0005435529783	2C7495	2851 104589	VADIM SOROKIN	{"email": "sorokinv-15101963@postgrespro.ru", "phone": "+70386809743"}
0005435529784	165CEB	8096 426896	SERGEY MOROZOV	{"email": "morozov.s14051963@postgrespro.ru", "phone": "+70753035204"}
0005435529785	4810C3	0753 941341	NINA IVANOVA	{"email": "n.ivanova-061974@postgrespro.ru", "phone": "+70017493659"}
0005435529786	A54C85	5264 268323	ROBERT AFANASEV	{"email": "afanasev_r-1965@postgrespro.ru", "phone": "+70457712743"}
0005435529787	A54C85	7516 328883	IRINA TROFIMOVA	{"email": "i_trofimova-1978@postgrespro.ru", "phone": "+70256743585"}
0005435529788	645F43	8473 727660	ARTUR ALEKSANDROV	{"phone": "+70205291568"}
0005435529789	645F43	1772 533735	VITALIY SIDOROV	{"phone": "+70535154258"}
0005435529790	CEA166	3753 239267	NINA SOKOLOVA	{"phone": "+70676156511"}
0005435529791	56A615	1464 329465	EKATERINA KAZAKOVA	{"email": "e.kazakova.081958@postgrespro.ru", "phone": "+70533559027"}
0005435529792	02660F	9110 482475	VASILIY FROLOV	{"phone": "+70381244426"}
0005435529793	6B84F8	6147 142597	ELENA KULIKOVA	{"phone": "+70133209583"}
0005435529794	6B84F8	3076 971809	MARIYA SMIRNOVA	{"email": "smirnovamariya_101961@postgrespro.ru", "phone": "+70871685119"}
0005435529795	329261	3377 009539	DARYA ILINA	{"email": "ilina_darya-28101978@postgrespro.ru", "phone": "+70614604864"}
0005435529796	E72C70	4290 892566	IVAN KONOVALOV	{"phone": "+70582931267"}
0005435530102	9FB331	0893 623728	RUSLAN FOMIN	{"phone": "+70128414132"}
0005435529797	6B2DE2	2538 278797	VITALIY KULIKOV	{"email": "kulikovvitaliy.081966@postgrespro.ru", "phone": "+70828911624"}
0005435529798	43B64E	8617 020646	ALEKSANDR FOMIN	{"email": "a-fomin-1973@postgrespro.ru", "phone": "+70183652332"}
0005435529799	43B64E	3655 361562	ILYA MELNIKOV	{"phone": "+70100214451"}
0005435529800	5FED85	8053 617106	OLESYA ZOTOVA	{"email": "olesyazotova-13091979@postgrespro.ru", "phone": "+70093193994"}
0005435529801	5FED85	0408 247619	ALEKSANDR VASILEV	{"phone": "+70777146404"}
0005435529802	D40531	6460 556785	DARYA SIDOROVA	{"email": "sidorova-darya.1967@postgrespro.ru", "phone": "+70233543970"}
0005435529803	5830D8	2341 218324	ALEKSANDR KRASNOV	{"phone": "+70375143396"}
0005435529804	59248D	6841 271294	VLADIMIR ILIN	{"email": "v.ilin_121966@postgrespro.ru", "phone": "+70149551880"}
0005435529805	FAD917	0942 221429	SERGEY KISELEV	{"email": "kiselevs_081978@postgrespro.ru", "phone": "+70348794419"}
0005435529806	DE4466	3135 079179	RAISA KOROLEVA	{"email": "koroleva.raisa.1987@postgrespro.ru", "phone": "+70393504880"}
0005435529807	DE4466	5444 653640	INNA STEPANOVA	{"phone": "+70554312466"}
0005435529808	CD59B6	2831 136491	NATALYA ROMANOVA	{"email": "n_romanova_1980@postgrespro.ru", "phone": "+70064557793"}
0005435529809	CD59B6	3418 478371	VLADIMIR NOVIKOV	{"email": "vladimirnovikov_04021968@postgrespro.ru", "phone": "+70129565698"}
0005435529810	A860C0	5739 863253	MIKHAIL DENISOV	{"email": "denisov_m1969@postgrespro.ru", "phone": "+70207282855"}
0005435529811	8CAE43	2521 260987	LYUBOV VOLKOVA	{"email": "volkoval.1978@postgrespro.ru", "phone": "+70216870405"}
0005435529812	C57024	9039 246093	TATYANA NESTEROVA	{"email": "nesterova-tatyana_1969@postgrespro.ru", "phone": "+70671607906"}
0005435529813	CDE241	1400 121638	YURIY PETROV	{"email": "petrovy_10071982@postgrespro.ru", "phone": "+70427381837"}
0005435529814	CDE241	6086 691839	SERGEY VOLKOV	{"email": "sergey.volkov_021975@postgrespro.ru", "phone": "+70092386817"}
0005435529815	558A2C	3169 020700	LYUDMILA MOROZOVA	{"email": "lmorozova08081968@postgrespro.ru", "phone": "+70282936322"}
0005435529816	08F139	8616 628730	ZAKHAR VASILEV	{"phone": "+70543357517"}
0005435529817	08F139	0901 373687	EDUARD VOLKOV	{"email": "volkov_eduard061968@postgrespro.ru", "phone": "+70107581653"}
0005435529818	DA961B	7772 217109	VLADIMIR ZAYCEV	{"email": "vladimir-zaycev-23011980@postgrespro.ru", "phone": "+70365675317"}
0005435529819	6EC546	8533 646839	KONSTANTIN ORLOV	{"email": "orlov_k1974@postgrespro.ru", "phone": "+70552489880"}
0005435529820	6EC546	0003 936567	ANDREY DENISOV	{"email": "denisov.a-28071964@postgrespro.ru", "phone": "+70159311750"}
0005435529821	E24421	2119 034449	KRISTINA KUZNECOVA	{"phone": "+70186946562"}
0005435529822	E24421	6431 084401	VALENTIN IVANOV	{"phone": "+70450637358"}
0005435529823	59474A	7496 613533	GEORGIY MATVEEV	{"email": "g.matveev1968@postgrespro.ru", "phone": "+70706733144"}
0005435529824	86FDAC	3200 904366	ILYA BONDARENKO	{"phone": "+70080286295"}
0005435529825	86FDAC	6879 389813	TATYANA MAKSIMOVA	{"email": "maksimova-t_20021970@postgrespro.ru", "phone": "+70830266522"}
0005435529826	6BF0A8	1743 525393	IRINA IVANOVA	{"email": "ivanova.irina_041971@postgrespro.ru", "phone": "+70414031792"}
0005435529827	050E3B	7683 233307	EVGENIYA KONOVALOVA	{"phone": "+70138809528"}
0005435529828	BC4A29	9868 128531	MARIYA IVANOVA	{"phone": "+70791927253"}
0005435529829	B83B1F	6877 063075	VALENTINA SAVELEVA	{"phone": "+70911329105"}
0005435529830	B83B1F	5304 704992	GALINA ORLOVA	{"phone": "+70953820207"}
0005435529831	E2C44D	9987 870638	EVGENIY MAKAROV	{"phone": "+70015154200"}
0005435529832	B59001	0062 656400	DMITRIY MAKAROV	{"email": "makarov_d.06011973@postgrespro.ru", "phone": "+70965125424"}
0005435529833	B59001	6957 956226	ANDREY FEDOROV	{"email": "andrey_fedorov09111984@postgrespro.ru", "phone": "+70131099551"}
0005435529834	E49442	7771 535626	OLGA MAKAROVA	{"email": "olga.makarova.041978@postgrespro.ru", "phone": "+70797390596"}
0005435529835	D3D5B1	2306 047588	TATYANA ALEKSANDROVA	{"phone": "+70895062501"}
0005435529836	D3D5B1	7393 059680	SERGEY PETROV	{"email": "petrov.sergey.051978@postgrespro.ru", "phone": "+70170962293"}
0005435529837	163E43	9860 851241	POLINA YUDINA	{"phone": "+70594003570"}
0005435529838	4DF18F	1980 970466	LYUDMILA TIMOFEEVA	{"phone": "+70027367401"}
0005435529839	0E733D	0409 026137	SERGEY GERASIMOV	{"phone": "+70603042634"}
0005435529840	372169	5720 317662	NADEZHDA BOGDANOVA	{"phone": "+70330397909"}
0005435529841	BB46D6	4117 348205	OLESYA AFANASEVA	{"email": "o_afanaseva.1969@postgrespro.ru", "phone": "+70207252236"}
0005435529842	084F3C	6441 241212	LEONID KULIKOV	{"email": "l.kulikov.1966@postgrespro.ru", "phone": "+70202620457"}
0005435529843	EF8852	6928 416757	LYUDMILA SAVELEVA	{"phone": "+70979695765"}
0005435529844	145B96	6089 088084	SERGEY SIDOROV	{"email": "sidorov-sergey_091973@postgrespro.ru", "phone": "+70775917903"}
0005435529845	145B96	0317 491145	OLGA ARKHIPOVA	{"email": "arkhipova_o.29061966@postgrespro.ru", "phone": "+70798452814"}
0005435529846	C3F089	5838 994295	OLGA PAVLOVA	{"phone": "+70957151967"}
0005435529847	E40258	9371 592040	VLADIMIR DENISOV	{"phone": "+70133542042"}
0005435529848	E827B1	2579 192727	IGOR ABRAMOV	{"email": "i-abramov-1969@postgrespro.ru", "phone": "+70610434992"}
0005435529849	E827B1	2222 832660	YURIY BARANOV	{"phone": "+70479073568"}
0005435529850	B6C14C	4438 145053	NIKITA BONDARENKO	{"email": "bondarenko-n-11051984@postgrespro.ru", "phone": "+70870861434"}
0005435529851	0EC7D1	9855 489515	MARIYA FROLOVA	{"email": "mariyafrolova.1970@postgrespro.ru", "phone": "+70758889252"}
0005435529852	DF5A88	3967 413694	ALEKSANDR KRASNOV	{"email": "a-krasnov_12031977@postgrespro.ru", "phone": "+70968343061"}
0005435529853	F8F3D6	3487 081296	PAVEL MAKAROV	{"phone": "+70712689659"}
0005435529854	F8F3D6	4267 046659	RUSLAN MELNIKOV	{"phone": "+70739702068"}
0005435529855	94F9EA	4296 795071	DENIS FEDOROV	{"email": "fedorov-denis.08061960@postgrespro.ru", "phone": "+70549219450"}
0005435529856	6512D3	1764 242699	YULIYA MASLOVA	{"email": "yuliyamaslova.09101974@postgrespro.ru", "phone": "+70779990866"}
0005435529857	4A6BB5	6171 223327	NATALYA ROMANOVA	{"email": "natalyaromanova1977@postgrespro.ru", "phone": "+70793107985"}
0005435529858	A01665	5128 990495	TATYANA ZHUKOVA	{"email": "tatyanazhukova121967@postgrespro.ru", "phone": "+70251290145"}
0005435529859	5C9576	3005 183496	VIKTOR ALEKSANDROV	{"phone": "+70071152005"}
0005435529860	5C9576	4600 445154	YURIY FOMIN	{"email": "yfomin1968@postgrespro.ru", "phone": "+70264566597"}
0005435529861	5C9576	4489 277294	ARTUR VOROBEV	{"phone": "+70212544915"}
0005435529862	3C33E1	6447 382996	NINA SOROKINA	{"email": "nina.sorokina121969@postgrespro.ru", "phone": "+70636817755"}
0005435529863	6CA7EF	8601 408978	SEMEN ANDREEV	{"email": "andreev.s-03091981@postgrespro.ru", "phone": "+70490535068"}
0005435529864	6CA7EF	7157 364504	ALEKSANDR FILIPPOV	{"email": "aleksandrfilippov28031967@postgrespro.ru", "phone": "+70216262093"}
0005435529865	860D03	0009 040846	ANDREY MIKHAYLOV	{"email": "mikhaylova.1977@postgrespro.ru", "phone": "+70914531899"}
0005435529866	EEAB86	5341 714903	ALEKSEY POPOV	{"email": "popov_aleksey_051970@postgrespro.ru", "phone": "+70999145582"}
0005435529867	EEAB86	8708 188312	ANTONINA EGOROVA	{"phone": "+70632236259"}
0005435529868	0778F8	1488 221581	DARYA ILINA	{"phone": "+70319239147"}
0005435529869	B482A7	6415 069593	ALEKSEY MIKHAYLOV	{"phone": "+70472437081"}
0005435529870	B482A7	0777 173482	YULIYA MAKAROVA	{"email": "makarovay_10091976@postgrespro.ru", "phone": "+70322561458"}
0005435529871	1A2F96	3710 596816	IRINA ERMAKOVA	{"email": "irina.ermakova-1970@postgrespro.ru", "phone": "+70852893493"}
0005435529872	8CB0E8	7135 346650	PAVEL ALEKSEEV	{"phone": "+70793659181"}
0005435529873	4903C9	5305 541351	PETR PETROV	{"email": "petrov.p-25061975@postgrespro.ru", "phone": "+70512442936"}
0005435529874	207997	6013 952685	GALINA MATVEEVA	{"email": "galina.matveeva.22081979@postgrespro.ru", "phone": "+70411792079"}
0005435529875	1AA5A4	7061 212791	OLEG PETROV	{"phone": "+70304289977"}
0005435529876	5195AC	1996 118267	DMITRIY SERGEEV	{"email": "sergeev.d_061963@postgrespro.ru", "phone": "+70807945663"}
0005435529877	68EC7A	6174 108181	ANATOLIY FOMIN	{"email": "a.fomin_29081974@postgrespro.ru", "phone": "+70406912298"}
0005435529878	0D0281	2725 400868	VALENTINA SIDOROVA	{"phone": "+70241333580"}
0005435529879	0D0281	8487 850430	LYUBOV IVANOVA	{"phone": "+70339766930"}
0005435529880	FAF75F	9987 953616	IRINA KOROLEVA	{"phone": "+70963938256"}
0005435529881	EE1EB5	9135 887568	FLYURA TARASOVA	{"phone": "+70392837343"}
0005435529882	98149C	2472 932329	KIRILL DMITRIEV	{"email": "dmitrievk.31011969@postgrespro.ru", "phone": "+70569828190"}
0005435529883	98149C	3687 678998	LEONID ORLOV	{"phone": "+70415502306"}
0005435529884	C5B3EA	0251 676431	VLADIMIR IVANOV	{"phone": "+70089356169"}
0005435529885	6B1098	1646 747276	IRINA BOGDANOVA	{"email": "irina.bogdanova.101973@postgrespro.ru", "phone": "+70071689673"}
0005435529886	6B1098	1843 629372	RAFAEL KOROLEV	{"email": "rafael.korolev.1968@postgrespro.ru", "phone": "+70959664994"}
0005435529887	D5F0BC	3624 353254	ELENA OSIPOVA	{"email": "osipovae-1980@postgrespro.ru", "phone": "+70327242524"}
0005435529888	1E629F	4273 060251	MIKHAIL NOVIKOV	{"phone": "+70970622798"}
0005435529889	E4B57A	8540 618768	NIKOLAY ZHURAVLEV	{"email": "zhuravlev_n.1956@postgrespro.ru", "phone": "+70250077823"}
0005435529890	E4B57A	5881 511721	ROMAN BORISOV	{"email": "roman.borisov091971@postgrespro.ru", "phone": "+70574560199"}
0005435529891	8A6850	9696 093170	ALEKSANDR KAZAKOV	{"email": "aleksandr.kazakov_1967@postgrespro.ru", "phone": "+70737487879"}
0005435529892	89B46D	8915 783919	ALEKSANDR NIKOLAEV	{"phone": "+70308739814"}
0005435529893	89B46D	9873 605623	EKATERINA BELYAEVA	{"email": "belyaevaekaterina.071972@postgrespro.ru", "phone": "+70252321115"}
0005435529894	C5389E	0963 185397	MARINA KUDRYASHOVA	{"phone": "+70431184525"}
0005435529895	C5389E	0485 623002	NATALYA DENISOVA	{"email": "natalya-denisova-08071965@postgrespro.ru", "phone": "+70539788242"}
0005435529896	89FDD8	2373 380240	ELENA ALEKSEEVA	{"email": "elena.alekseeva041962@postgrespro.ru", "phone": "+70090430646"}
0005435529897	89FDD8	2357 670732	OLESYA SCHERBAKOVA	{"email": "scherbakova.olesya.26041960@postgrespro.ru", "phone": "+70626435234"}
0005435529898	31276C	6921 345191	ANNA MIKHAYLOVA	{"email": "a_mikhaylova.021975@postgrespro.ru", "phone": "+70106406914"}
0005435529899	4B3886	8939 366318	EKATERINA ZAYCEVA	{"email": "zaycevaekaterina1980@postgrespro.ru", "phone": "+70163661052"}
0005435529900	FF57A8	5792 219857	NATALYA KONDRATEVA	{"email": "kondrateva_n071971@postgrespro.ru", "phone": "+70036316046"}
0005435529901	4B9E90	7027 318872	ANTON FILIPPOV	{"email": "anton.filippov_081978@postgrespro.ru", "phone": "+70423379294"}
0005435529973	83C8A6	9761 944191	ALEKSANDR ANDREEV	{"email": "a.andreev21091966@postgrespro.ru", "phone": "+70539839506"}
0005435529974	BFBF23	1015 474044	ANASTASIYA ROMANOVA	{"phone": "+70511887054"}
0005435529975	C33B14	7476 691081	NIKITA MELNIKOV	{"phone": "+70864816665"}
0005435529976	7CFD0C	7716 454502	NINA BOGDANOVA	{"phone": "+70732158592"}
0005435529977	7CFD0C	8494 817495	DIANA SERGEEVA	{"email": "sergeeva_d.011958@postgrespro.ru", "phone": "+70715938515"}
0005435529978	3B62D1	6073 682714	EKATERINA LUKYANOVA	{"email": "lukyanova.e-1974@postgrespro.ru", "phone": "+70518769703"}
0005435529979	B4D396	2433 986342	TATYANA GORBUNOVA	{"email": "tatyana-gorbunova.081980@postgrespro.ru", "phone": "+70918385183"}
0005435529980	B4D396	7189 734893	OLEG VASILEV	{"email": "vasilev.oleg.29051974@postgrespro.ru", "phone": "+70128512689"}
0005435529981	348AFA	5456 617697	ANDREY MOROZOV	{"phone": "+70374752776"}
0005435529982	348AFA	8711 204141	ALEKSEY SIDOROV	{"phone": "+70217762057"}
0005435529983	2A7D9A	6246 488497	IVAN SCHERBAKOV	{"email": "ivan-scherbakov.24061974@postgrespro.ru", "phone": "+70507592469"}
0005435529984	4DC78B	5248 003181	MARIYA GAVRILOVA	{"email": "gavrilova-m-021970@postgrespro.ru", "phone": "+70884613441"}
0005435529985	0EF47F	2229 956259	VIKTOR ANTONOV	{"email": "viktorantonov-1975@postgrespro.ru", "phone": "+70673822120"}
0005435529986	7532C5	3327 870881	MARIYA VASILEVA	{"email": "mariya_vasileva041950@postgrespro.ru", "phone": "+70344650513"}
0005435529987	B8C7C7	3768 832506	OLGA IVANOVA	{"phone": "+70605436807"}
0005435529988	5B37CF	7356 157948	ANASTASIYA FILIPPOVA	{"phone": "+70138748954"}
0005435529989	5B37CF	1023 822492	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr_1974@postgrespro.ru", "phone": "+70384470097"}
0005435529990	C860F8	0306 825145	SERGEY KOROLEV	{"phone": "+70089797760"}
0005435529991	C860F8	8189 118895	ANATOLIY DAVYDOV	{"email": "anatoliydavydov031981@postgrespro.ru", "phone": "+70017839005"}
0005435529992	35D455	6129 412760	ALEVTINA VASILEVA	{"email": "a-vasileva_101973@postgrespro.ru", "phone": "+70777067318"}
0005435529993	E6CC2D	4645 950538	IGOR SMIRNOV	{"phone": "+70133296970"}
0005435529994	308C37	2061 527845	ANASTASIYA SMIRNOVA	{"phone": "+70143372340"}
0005435529995	B21620	2205 200148	SVETLANA KUZMINA	{"email": "svetlana.kuzmina.111960@postgrespro.ru", "phone": "+70664554239"}
0005435529996	B21620	7199 283367	NIKOLAY TARASOV	{"phone": "+70967524430"}
0005435529997	1EE432	2604 014903	IRINA KUZNECOVA	{"email": "kuznecovairina.17061971@postgrespro.ru", "phone": "+70907505846"}
0005435529998	1EE432	4938 452096	NIKOLAY SCHERBAKOV	{"phone": "+70939009415"}
0005435529999	D326E7	1254 990676	MARIYA BORISOVA	{"email": "mariyaborisova101972@postgrespro.ru", "phone": "+70490741363"}
0005435530000	E979EF	2658 223881	SERGEY SIDOROV	{"phone": "+70479790748"}
0005435530001	1F8359	0287 481333	SERGEY FEDOROV	{"email": "fedorovs.071965@postgrespro.ru", "phone": "+70146979580"}
0005435530002	1F8359	5929 356397	DMITRIY GUSEV	{"email": "gusev.dmitriy.031970@postgrespro.ru", "phone": "+70765670561"}
0005435530003	A3C43A	2106 855181	MARIYA TARASOVA	{"email": "m-tarasova.1961@postgrespro.ru", "phone": "+70827510389"}
0005435530004	A3C43A	2093 234289	MILANA MIKHAYLOVA	{"phone": "+70648003972"}
0005435530005	F31BDA	4215 247795	ALEKSANDR VOLKOV	{"phone": "+70030264146"}
0005435530006	10953C	5117 822346	POLINA POPOVA	{"email": "popova.polina.031972@postgrespro.ru", "phone": "+70616568148"}
0005435530007	667F21	5360 970909	IVAN FOMIN	{"email": "ivan.fomin041977@postgrespro.ru", "phone": "+70980181310"}
0005435530008	667F21	7158 476619	IVAN SEMENOV	{"email": "i-semenov.03121971@postgrespro.ru", "phone": "+70489611981"}
0005435530009	667F21	9720 300263	ALENA KUZMINA	{"email": "alenakuzmina04091964@postgrespro.ru", "phone": "+70291525915"}
0005435530010	79B9C9	4062 624510	LYUDMILA ILINA	{"email": "ilina_l-1971@postgrespro.ru", "phone": "+70900255662"}
0005435530011	EBC476	0784 502326	NIKOLAY KUZNECOV	{"phone": "+70539625850"}
0005435530012	35B331	4519 838451	DANIIL YAKOVLEV	{"email": "daniil-yakovlev.051972@postgrespro.ru", "phone": "+70699929651"}
0005435530013	35B331	6528 485465	ANGELINA VASILEVA	{"phone": "+70664195804"}
0005435530014	EA76B8	6734 130243	IRINA YAKOVLEVA	{"email": "yakovleva.irina_081975@postgrespro.ru", "phone": "+70319184235"}
0005435530015	28759D	4806 679358	TATYANA NIKOLAEVA	{"email": "nikolaeva.t-1971@postgrespro.ru", "phone": "+70258544555"}
0005435530016	DBF392	2574 265550	SOFYA BORISOVA	{"phone": "+70817582154"}
0005435530017	DBF392	8480 252820	ANDREY IVANOV	{"phone": "+70778214532"}
0005435530018	DBF392	7006 216898	NADEZHDA BARANOVA	{"phone": "+70081845963"}
0005435530019	B5C460	2295 499956	VITALIY IVANOV	{"email": "vitaliy.ivanov-051975@postgrespro.ru", "phone": "+70324913902"}
0005435530020	CF568A	8828 903955	VALENTINA MAKSIMOVA	{"email": "v-maksimova_021978@postgrespro.ru", "phone": "+70700199129"}
0005435530021	9ECF0C	1965 038608	ANDREY KUZMIN	{"phone": "+70178167931"}
0005435530022	B51EFA	4710 826970	ELENA KUZMINA	{"email": "kuzminae_03061966@postgrespro.ru", "phone": "+70383716404"}
0005435530023	1B9D59	0898 815747	MATVEY VOLKOV	{"email": "volkov.m.1967@postgrespro.ru", "phone": "+70136852635"}
0005435530024	BE4E64	8977 683523	NINA NAZAROVA	{"phone": "+70218354022"}
0005435530025	BE4E64	6905 840667	TATYANA VOLKOVA	{"email": "tvolkova_1983@postgrespro.ru", "phone": "+70145348684"}
0005435530026	BE4E64	9086 297614	NIKOLAY ABRAMOV	{"phone": "+70807945142"}
0005435530027	5D3363	3680 114449	MARINA LAZAREVA	{"phone": "+70743052340"}
0005435530028	AD659B	0818 670710	SERGEY RODIONOV	{"phone": "+70382405251"}
0005435530029	964138	6638 206505	IRINA VASILEVA	{"email": "vasilevai-1973@postgrespro.ru", "phone": "+70294583316"}
0005435530030	7CE97D	1088 327383	OLGA ZAKHAROVA	{"email": "olga-zakharova1975@postgrespro.ru", "phone": "+70539670204"}
0005435530031	04CC15	2823 145226	SERGEY ZAKHAROV	{"phone": "+70481041669"}
0005435530032	04CC15	7720 205088	VYACHESLAV SOLOVEV	{"email": "solovev.v-111980@postgrespro.ru", "phone": "+70927639614"}
0005435530033	45A2E9	4047 782770	ANATOLIY GRIGOREV	{"email": "anatoliy_grigorev-061970@postgrespro.ru", "phone": "+70171713090"}
0005435530034	45A2E9	4755 209396	VIKTOR ABRAMOV	{"email": "viktor.abramov_091973@postgrespro.ru", "phone": "+70612765950"}
0005435530035	AEC486	0224 665528	VLADIMIR VOROBEV	{"email": "v.vorobev-30111967@postgrespro.ru", "phone": "+70681977734"}
0005435530036	D3F04F	9399 230255	MARINA STEPANOVA	{"phone": "+70759585025"}
0005435530037	D3F04F	8003 576225	MIKHAIL ANDREEV	{"email": "mikhailandreev101965@postgrespro.ru", "phone": "+70050109282"}
0005435530038	7DC7F1	8073 286156	RAISA VASILEVA	{"email": "raisa-vasileva-1962@postgrespro.ru", "phone": "+70051522555"}
0005435530039	BBF181	9099 367242	ELENA PETROVA	{"email": "petrovae_14071967@postgrespro.ru", "phone": "+70301561477"}
0005435530040	03F43E	9030 640047	SERGEY NIKOLAEV	{"phone": "+70839366266"}
0005435530041	E917D5	4782 684530	YURIY DAVYDOV	{"email": "davydov-yuriy18021982@postgrespro.ru", "phone": "+70417952229"}
0005435530042	11F8A6	8957 799750	SVETLANA FOMINA	{"email": "fomina-s-1965@postgrespro.ru", "phone": "+70832715229"}
0005435530043	EF0DF1	0475 405630	VASILIY GAVRILOV	{"email": "gavrilov.v_091966@postgrespro.ru", "phone": "+70926871859"}
0005435530044	EF0DF1	4709 957522	VLADIMIR GERASIMOV	{"email": "v.gerasimov-1964@postgrespro.ru", "phone": "+70066246116"}
0005435530045	554C99	9781 226684	SERGEY GORBUNOV	{"email": "s_gorbunov.1963@postgrespro.ru", "phone": "+70178100603"}
0005435530046	361D2D	8431 717536	OLGA DANILOVA	{"phone": "+70248809867"}
0005435530047	EEC86B	0764 523258	MARINA RYABOVA	{"email": "ryabovamarina_101975@postgrespro.ru", "phone": "+70596537158"}
0005435530048	61E728	8345 477577	ANDREY OSIPOV	{"email": "a-osipov.081971@postgrespro.ru", "phone": "+70436661334"}
0005435530049	433F60	1417 911630	NIKOLAY SOKOLOV	{"phone": "+70832440036"}
0005435530050	D743E4	3201 289284	NURIYA NOVIKOVA	{"email": "novikova.n-13111966@postgrespro.ru", "phone": "+70395868051"}
0005435530051	0BD08C	6741 145581	NIKOLAY SIDOROV	{"email": "sidorovnikolay_11061972@postgrespro.ru", "phone": "+70368794838"}
0005435530052	C67F65	5935 116300	RIMA EFREMOVA	{"email": "efremova-r_041977@postgrespro.ru", "phone": "+70794066125"}
0005435530053	9BC07A	4355 202561	ANNA SIDOROVA	{"email": "a-sidorova_04061971@postgrespro.ru", "phone": "+70528973152"}
0005435530054	318F53	9999 382213	IRINA MAKAROVA	{"phone": "+70682512029"}
0005435530055	75256A	7931 841994	NINA ZHUKOVA	{"email": "ninazhukova.091971@postgrespro.ru", "phone": "+70940121293"}
0005435530056	A2972D	3375 795773	IVAN SMIRNOV	{"email": "i_smirnov_07011960@postgrespro.ru", "phone": "+70916951648"}
0005435530057	8242EF	6331 942859	ALEKSANDR FEDOROV	{"email": "fedorov-aleksandr_081972@postgrespro.ru", "phone": "+70149166348"}
0005435530058	F370FE	7452 345516	YULIYA YUDINA	{"email": "y-yudina-051978@postgrespro.ru", "phone": "+70002888040"}
0005435530059	F370FE	0245 435003	OLEG KUZNECOV	{"email": "oleg.kuznecov_1983@postgrespro.ru", "phone": "+70490991160"}
0005435530060	F370FE	0723 349725	TATYANA KUZNECOVA	{"email": "tkuznecova091978@postgrespro.ru", "phone": "+70410447698"}
0005435530061	817F48	3328 020797	NATALYA PETROVA	{"phone": "+70278426694"}
0005435530062	9AE661	9470 654396	VADIM IVANOV	{"email": "ivanov-vadim.051975@postgrespro.ru", "phone": "+70701986608"}
0005435530063	333852	4000 936922	GALINA FILATOVA	{"phone": "+70095076050"}
0005435530064	2AC623	5124 234534	VLADIMIR EGOROV	{"email": "egorovv_011975@postgrespro.ru", "phone": "+70037232326"}
0005435530065	27FCC3	6302 328639	ALEKSANDR KUZMIN	{"email": "kuzmin-aleksandr.1977@postgrespro.ru", "phone": "+70051483472"}
0005435530066	CAA420	0325 971022	FARID KRASNOV	{"phone": "+70450491960"}
0005435530067	B61BE4	6145 595489	LYUBOV KALININA	{"email": "kalininal1976@postgrespro.ru", "phone": "+70949441508"}
0005435530068	722C3A	4094 414277	ZHANNA ZAKHAROVA	{"email": "zzakharova_1966@postgrespro.ru", "phone": "+70751624385"}
0005435530069	1CCA86	7634 627693	NIKOLAY PAVLOV	{"email": "npavlov03081964@postgrespro.ru", "phone": "+70015859582"}
0005435530070	6ABFE5	6890 792080	NIKITA ZAYCEV	{"email": "zaycev-nikita.1969@postgrespro.ru", "phone": "+70389647742"}
0005435530071	D75ADD	8254 299113	FEDOR VOROBEV	{"email": "f_vorobev.111974@postgrespro.ru", "phone": "+70530907292"}
0005435530072	B4FC94	2307 191614	DMITRIY DENISOV	{"phone": "+70813123295"}
0005435530073	B4FC94	6169 104843	RAILYA BELOVA	{"email": "railyabelova_011965@postgrespro.ru", "phone": "+70867202667"}
0005435530074	B01CB6	6401 263664	VADIM ROMANOV	{"phone": "+70412246862"}
0005435530075	4F428B	4696 775406	SVETLANA SOKOLOVA	{"phone": "+70052507801"}
0005435530076	4F428B	0880 075758	VIKTOR MIKHAYLOV	{"email": "viktor-mikhaylov051967@postgrespro.ru", "phone": "+70004420490"}
0005435530077	4F428B	7864 739872	TATYANA ILINA	{"email": "t_ilina.1975@postgrespro.ru", "phone": "+70682392226"}
0005435530078	F29270	3817 276293	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay_1982@postgrespro.ru", "phone": "+70186461579"}
0005435530079	F29270	2842 486646	NINA MIRONOVA	{"email": "mironova.nina.1974@postgrespro.ru", "phone": "+70288481260"}
0005435530080	15A040	4132 950236	YURIY KUZNECOV	{"email": "y_kuznecov_011963@postgrespro.ru", "phone": "+70560624034"}
0005435530081	AA84C9	5445 215531	OLGA ROMANOVA	{"phone": "+70931306250"}
0005435530082	6847B1	1712 219982	ANASTASIYA NAZAROVA	{"phone": "+70374798265"}
0005435530083	6847B1	2245 659117	VALERIY VOLKOV	{"phone": "+70420635440"}
0005435530084	55822D	1532 722687	RAISA PETROVA	{"phone": "+70658178511"}
0005435530085	55822D	5125 372776	SERAFIMA GORBUNOVA	{"email": "s-gorbunova_111967@postgrespro.ru", "phone": "+70589744728"}
0005435530086	4F68B4	4891 204598	RUSTAM GORBUNOV	{"phone": "+70304884052"}
0005435530087	4F68B4	9372 533337	VYACHESLAV POPOV	{"phone": "+70116623160"}
0005435530088	425A50	9337 213071	ALEKSANDR SCHERBAKOV	{"email": "aleksandrscherbakov_111967@postgrespro.ru", "phone": "+70731736766"}
0005435530089	425A50	0394 303174	ZINAIDA NIKITINA	{"email": "znikitina05011959@postgrespro.ru", "phone": "+70434712747"}
0005435530090	B50E1C	2415 030944	RINAT FEDOTOV	{"email": "fedotov.r-1962@postgrespro.ru", "phone": "+70869930012"}
0005435530091	3D45EF	5343 268002	ALEKSEY MIKHAYLOV	{"phone": "+70854971343"}
0005435530092	F6D744	2719 933048	GENNADIY KISELEV	{"phone": "+70909043075"}
0005435530093	F35E0D	9856 308199	YURIY MATVEEV	{"email": "y-matveev1973@postgrespro.ru", "phone": "+70218707003"}
0005435530094	F35E0D	9809 325433	ANATOLIY SEMENOV	{"email": "semenov_anatoliy.09121970@postgrespro.ru", "phone": "+70718251675"}
0005435530095	132019	5931 599032	GRIGORIY SOROKIN	{"email": "g_sorokin-09041969@postgrespro.ru", "phone": "+70038197886"}
0005435530096	0724FF	6707 955554	VIKTORIYA OSIPOVA	{"phone": "+70722481554"}
0005435530097	8603A4	9689 140409	SERGEY BELOV	{"phone": "+70410792010"}
0005435530098	69C24E	6654 062998	SEMEN KOZLOV	{"phone": "+70082972745"}
0005435530099	7AE8F9	9023 673444	VLADIMIR BORISOV	{"email": "v_borisov.101970@postgrespro.ru", "phone": "+70004727773"}
0005435530100	BFB7D4	7284 900005	ALEKSANDR NOVIKOV	{"email": "novikov.aleksandr27121966@postgrespro.ru", "phone": "+70914392445"}
0005435530101	BFB7D4	7344 052022	LYUBOV ALEKSANDROVA	{"email": "l_aleksandrova_1970@postgrespro.ru", "phone": "+70143551223"}
0005435530103	EE40EB	5997 287131	VADIM GAVRILOV	{"email": "vadimgavrilov121960@postgrespro.ru", "phone": "+70026206472"}
0005435530104	C2A94F	4601 482989	SERGEY SOLOVEV	{"email": "sergeysolovev-28051968@postgrespro.ru", "phone": "+70979627735"}
0005435530105	C2A94F	0672 895609	VYACHESLAV GAVRILOV	{"phone": "+70002703927"}
0005435530106	639769	2098 475187	AMINA KOZLOVA	{"email": "akozlova_041977@postgrespro.ru", "phone": "+70848101357"}
0005435530107	84F31B	9861 051388	NINA FROLOVA	{"phone": "+70239354309"}
0005435530108	066F8B	4510 951904	VYACHESLAV KUZNECOV	{"email": "kuznecov-vyacheslav.041977@postgrespro.ru", "phone": "+70897030902"}
0005435530109	066F8B	8306 089811	SERGEY ANTONOV	{"phone": "+70656306347"}
0005435530110	066F8B	4283 766325	ANNA KONOVALOVA	{"email": "a_konovalova-16061967@postgrespro.ru", "phone": "+70257723973"}
0005435530111	066F8B	2323 403850	GULFIYA NAZAROVA	{"phone": "+70682385325"}
0005435530112	C8017D	4688 861632	YURIY SHEVCHENKO	{"phone": "+70830314260"}
0005435530113	C8661C	5459 190183	ALEKSANDRA MAKAROVA	{"email": "a_makarova.041971@postgrespro.ru", "phone": "+70416495347"}
0005435530114	14467C	7075 807524	IGOR STEPANOV	{"email": "igor_stepanov.051970@postgrespro.ru", "phone": "+70059570377"}
0005435530115	14467C	0876 062265	VALERIY DENISOV	{"phone": "+70517979550"}
0005435530116	14467C	0333 298319	RUSLAN KOZLOV	{"phone": "+70361941926"}
0005435530117	355731	8080 361113	YULIYA GRISHINA	{"phone": "+70892457791"}
0005435530118	9DDDA4	5785 258316	ALEKSANDR KOZLOV	{"email": "kozlovaleksandr_26011978@postgrespro.ru", "phone": "+70174616690"}
0005435530119	8C41D1	2512 100551	LYUDMILA PETROVA	{"email": "petrova-lyudmila-08091983@postgrespro.ru", "phone": "+70632466462"}
0005435530120	B92F3B	9439 115367	ROMAN CHERNOV	{"email": "chernovroman-031987@postgrespro.ru", "phone": "+70533559855"}
0005435530121	6AD3ED	5455 664574	VIKTOR MAKSIMOV	{"phone": "+70411484321"}
0005435530122	6AD3ED	8348 359199	ALBINA ORLOVA	{"email": "orlova.albina_1979@postgrespro.ru", "phone": "+70605243069"}
0005435530123	6AD3ED	6778 126554	RUSLAN KUZNECOV	{"email": "kuznecov_ruslan-1972@postgrespro.ru", "phone": "+70614944736"}
0005435530124	236A1F	6096 013403	ANDREY GAVRILOV	{"phone": "+70304145093"}
0005435530125	E12603	8766 661540	VIKTOR SEMENOV	{"phone": "+70722104163"}
0005435530126	581C1E	8385 691866	VALERIY KULIKOV	{"email": "kulikov_valeriy101976@postgrespro.ru", "phone": "+70485286052"}
0005435530127	E99EBD	7221 692204	MIKHAIL STEPANOV	{"phone": "+70699436953"}
0005435530128	FD14F1	4149 439483	MAKSIM ALEKSANDROV	{"email": "m_aleksandrov_051968@postgrespro.ru", "phone": "+70497289262"}
0005435530129	E3C52C	0719 113290	KONSTANTIN DENISOV	{"email": "denisov_konstantin031967@postgrespro.ru", "phone": "+70149700752"}
0005435530130	E3C52C	0050 409461	YURIY GUSEV	{"phone": "+70999756042"}
0005435530131	D9C5CA	8265 553009	VALENTINA KUZMINA	{"email": "valentinakuzmina041969@postgrespro.ru", "phone": "+70963065827"}
0005435530132	19C77C	4113 048382	VLADISLAV SOKOLOV	{"phone": "+70129908025"}
0005435530133	63C28D	5929 207044	SVETLANA ILINA	{"phone": "+70868023079"}
0005435530134	63C28D	4193 718331	VADIM VOLKOV	{"email": "volkov_v-10111976@postgrespro.ru", "phone": "+70303986250"}
0005435530135	F6A24D	0764 638295	ALEKSEY TIMOFEEV	{"phone": "+70183869592"}
0005435530136	6AB8E9	8781 278812	EGOR MOROZOV	{"email": "egor-morozov_30081979@postgrespro.ru", "phone": "+70424250072"}
0005435530137	3E669E	0902 278934	YURIY RODIONOV	{"email": "rodionov.yuriy27041971@postgrespro.ru", "phone": "+70567759599"}
0005435530138	83268C	2756 197502	SERGEY VASILEV	{"email": "svasilev-1972@postgrespro.ru", "phone": "+70312509013"}
0005435530139	83268C	7406 259279	DARYA KUZNECOVA	{"phone": "+70168126547"}
0005435530140	C0DCBE	3121 273250	FEDOR ROMANOV	{"email": "fedorromanov_1973@postgrespro.ru", "phone": "+70660203509"}
0005435530141	8EEA9B	5298 465105	ALEKSEY SCHERBAKOV	{"email": "alekseyscherbakov-1955@postgrespro.ru", "phone": "+70401390064"}
0005435530142	8B3EB5	5501 171904	OLGA NAZAROVA	{"phone": "+70855140263"}
0005435530143	2D1598	0422 756461	EKATERINA VOLKOVA	{"email": "ekaterina_volkova-1981@postgrespro.ru", "phone": "+70161141901"}
0005435530144	2D1598	2864 227010	SERGEY YAKOVLEV	{"phone": "+70713361656"}
0005435530145	2D1598	5641 884152	NATALYA GUSEVA	{"email": "natalya_guseva-20031978@postgrespro.ru", "phone": "+70765663803"}
0005435530146	011F80	5079 527084	NADEZHDA KOROLEVA	{"phone": "+70668039931"}
0005435530147	C9C0C5	4813 113415	GENNADIY MELNIKOV	{"email": "melnikovgennadiy_1971@postgrespro.ru", "phone": "+70836796342"}
0005435530148	5F4336	3392 308760	LYUBOV SOLOVEVA	{"email": "lyubov-soloveva_05111966@postgrespro.ru", "phone": "+70216809171"}
0005435530149	050626	0404 688144	YURIY MIRONOV	{"phone": "+70203236484"}
0005435530150	56A847	7635 587175	LYUDMILA TROFIMOVA	{"phone": "+70082002234"}
0005435530151	7B3FE0	2428 585518	LYUBOV NIKIFOROVA	{"phone": "+70082966010"}
0005435530152	5DF1DA	2201 092363	VALENTINA BELOVA	{"phone": "+70657838415"}
0005435530153	76D4EA	0879 601742	VLADIMIR SOROKIN	{"email": "vladimir.sorokin20081972@postgrespro.ru", "phone": "+70045506042"}
0005435530154	76D4EA	0024 666502	ELIZAVETA NIKITINA	{"phone": "+70335568914"}
0005435530155	3D7415	8269 230718	VALENTINA KAZAKOVA	{"phone": "+70385384387"}
0005435530156	3D7415	7168 322169	IVAN PETROV	{"phone": "+70423082356"}
0005435530157	7502CB	9850 085656	ANASTASIYA GORBUNOVA	{"email": "gorbunova-anastasiya.08041967@postgrespro.ru", "phone": "+70087431297"}
0005435530158	B5666E	2617 114907	ALEKSANDR IVANOV	{"email": "ivanova-26091974@postgrespro.ru", "phone": "+70233003188"}
0005435530159	F60BC2	9375 821218	YAROSLAV FOMIN	{"phone": "+70902131196"}
0005435530160	4ECCDB	1852 584108	RAISA AFANASEVA	{"email": "raisa-afanaseva.1972@postgrespro.ru", "phone": "+70712262849"}
0005435530161	4ECCDB	4736 788375	DANIL OSIPOV	{"email": "d_osipov-1971@postgrespro.ru", "phone": "+70605825579"}
0005435530162	DD28AD	7867 334956	EVGENIY SERGEEV	{"phone": "+70142650563"}
0005435530163	DEC835	5088 587234	NIKOLAY DENISOV	{"phone": "+70807966150"}
0005435530164	277101	9477 347661	ALEKSANDR ALEKSANDROV	{"phone": "+70702308445"}
0005435530165	9FA3AF	6576 263459	OLGA AFANASEVA	{"email": "olgaafanaseva.081978@postgrespro.ru", "phone": "+70416535191"}
0005435530166	458F2C	6554 279398	ANATOLIY ANDREEV	{"phone": "+70203725003"}
0005435530167	9EBD1A	0524 053721	ANDREY FROLOV	{"phone": "+70409187231"}
0005435530168	9EBD1A	1858 821479	KIRILL VOLKOV	{"email": "volkovkirill_091975@postgrespro.ru", "phone": "+70927518412"}
0005435530169	9EBD1A	2606 881041	NATALYA VOLKOVA	{"email": "volkova-natalya-111965@postgrespro.ru", "phone": "+70342254082"}
0005435530170	580226	5882 109824	VALERIYA ANDREEVA	{"email": "valeriya.andreeva1976@postgrespro.ru", "phone": "+70153033741"}
0005435530171	2552C1	4152 040523	ALEKSEY ALEKSEEV	{"email": "aleksey.alekseev.16051977@postgrespro.ru", "phone": "+70219449336"}
0005435530172	2552C1	8459 298070	MIKHAIL ALEKSEEV	{"email": "alekseev_m-1980@postgrespro.ru", "phone": "+70706119550"}
0005435530173	3AC635	2118 725430	VALERIY ABRAMOV	{"phone": "+70315902425"}
0005435530174	8CE841	8783 451637	OLGA FILIPPOVA	{"phone": "+70509123803"}
0005435530175	8CE841	9827 893257	VASILIY BELOV	{"phone": "+70709099806"}
0005435530176	012EE7	2320 641383	LYUBOV MIKHAYLOVA	{"email": "mikhaylova_lyubov-31081969@postgrespro.ru", "phone": "+70426585310"}
0005435530177	012EE7	3959 818504	KRISTINA ZHURAVLEVA	{"email": "k-zhuravleva-05071973@postgrespro.ru", "phone": "+70835584765"}
0005435530178	E9E99F	4173 563492	YURIY SEMENOV	{"phone": "+70339076959"}
0005435530179	7318EC	4834 253047	MARIYA BORISOVA	{"phone": "+70798663087"}
0005435530180	B38B29	8076 849255	ANATOLIY IVANOV	{"email": "aivanov05091969@postgrespro.ru", "phone": "+70431231454"}
0005435530181	B38B29	8028 560681	YULIYA LAZAREVA	{"phone": "+70866195299"}
0005435530182	92850B	8760 656773	NIKOLAY SEMENOV	{"phone": "+70752352268"}
0005435530183	92850B	4752 101481	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay-18021978@postgrespro.ru", "phone": "+70188712807"}
0005435530184	A89FF8	8183 882390	TATYANA ZAYCEVA	{"email": "tatyana-zayceva-111957@postgrespro.ru", "phone": "+70007498600"}
0005435530185	A89FF8	3995 343120	ELENA OSIPOVA	{"email": "eosipova1979@postgrespro.ru", "phone": "+70102508603"}
0005435530186	F099FB	0025 104162	VIKTOR BONDARENKO	{"email": "viktor.bondarenko-30081977@postgrespro.ru", "phone": "+70693341519"}
0005435530187	4AD628	8072 214387	SERGEY BELOV	{"email": "belovs-051977@postgrespro.ru", "phone": "+70182081938"}
0005435530188	623530	3936 990081	IVAN SCHERBAKOV	{"email": "ivanscherbakov26061968@postgrespro.ru", "phone": "+70981203514"}
0005435530189	4D36DB	4838 466802	NATALYA ISAEVA	{"phone": "+70659680701"}
0005435530190	84C058	2102 687293	ELENA STEPANOVA	{"email": "stepanova_e.24021977@postgrespro.ru", "phone": "+70813915150"}
0005435530191	EED765	4316 412679	TATYANA KUZNECOVA	{"phone": "+70218320835"}
0005435530192	528799	5944 832830	ILYA ALEKSEEV	{"email": "alekseev-ilya_21091971@postgrespro.ru", "phone": "+70765823511"}
0005435530193	528799	2370 065164	GALINA TIKHONOVA	{"phone": "+70677984567"}
0005435530194	528799	7673 812071	DMITRIY KUZMIN	{"email": "d-kuzmin_1973@postgrespro.ru", "phone": "+70223406906"}
0005435530195	EECE66	3740 419027	EKATERINA FEDOROVA	{"phone": "+70402077931"}
0005435530196	E799C8	4463 037757	RAMIS KOROLEV	{"email": "korolev.r_1967@postgrespro.ru", "phone": "+70422171119"}
0005435530197	E799C8	9535 910798	ALEVTINA ILINA	{"phone": "+70271318768"}
0005435530198	E7C85A	0787 217834	ILNAR SCHERBAKOV	{"email": "ilnarscherbakov-1968@postgrespro.ru", "phone": "+70056539260"}
0005435530199	E7C85A	8978 045480	MIKHAIL SCHERBAKOV	{"phone": "+70921174558"}
0005435530200	80AE44	5188 808195	VERA ZHURAVLEVA	{"email": "zhuravleva.vera_03011966@postgrespro.ru", "phone": "+70854631128"}
0005435540622	4AAE00	0578 387996	VALENTINA IVANOVA	{"phone": "+70794962842"}
0005435540623	4AAE00	2488 133628	VLADIMIR MELNIKOV	{"email": "vladimirmelnikov_04021966@postgrespro.ru", "phone": "+70713430657"}
0005435540624	F75DCB	2541 742335	KONSTANTIN SOKOLOV	{"email": "sokolovk.031966@postgrespro.ru", "phone": "+70744750674"}
0005435540625	F75DCB	1202 695700	ALEKSANDR KOZLOV	{"email": "kozlov_aleksandr-121977@postgrespro.ru", "phone": "+70447137594"}
0005435540626	0C186C	3918 388580	FARID POPOV	{"phone": "+70137558712"}
0005435540627	428AA1	7528 107711	LIDIYA ANDREEVA	{"email": "andreeva-l.1977@postgrespro.ru", "phone": "+70125103935"}
0005435540628	763FB1	9339 959806	YURIY ISAEV	{"phone": "+70317534773"}
0005435540629	A45226	6218 319467	ARTEM CHERNOV	{"phone": "+70029011517"}
0005435540630	D63ECC	1108 455048	KONSTANTIN NOVIKOV	{"phone": "+70236745197"}
0005435540631	22A628	7434 407505	ELMIRA IVANOVA	{"phone": "+70473596841"}
0005435540632	22A628	4021 518361	MILANA ANTONOVA	{"email": "antonova.milana-26081961@postgrespro.ru", "phone": "+70890543839"}
0005435540633	DD6827	5534 363151	YURIY TIMOFEEV	{"email": "timofeevy.041978@postgrespro.ru", "phone": "+70058508655"}
0005435540634	DD6827	3092 081328	ANATOLIY DMITRIEV	{"phone": "+70250218913"}
0005435540635	DD6827	8007 519036	STANISLAV KUZNECOV	{"phone": "+70961468701"}
0005435540636	A0B9BE	1466 093432	TATYANA SAVELEVA	{"phone": "+70595135838"}
0005435540637	A0B9BE	5243 086888	OLGA ANTONOVA	{"phone": "+70771210844"}
0005435540638	0104D0	6905 413150	SERGEY ALEKSEEV	{"phone": "+70617894226"}
0005435540639	4E842F	5618 866856	LYUDMILA YUDINA	{"email": "l.yudina23111977@postgrespro.ru", "phone": "+70721382401"}
0005435540640	FDE0AC	0663 297222	SERAFIMA SOLOVEVA	{"email": "soloveva.serafima08111968@postgrespro.ru", "phone": "+70756923867"}
0005435540641	DB7BF7	1222 105573	SERGEY KONOVALOV	{"phone": "+70874333308"}
0005435540642	EF8622	6205 450009	NIKOLAY ABRAMOV	{"phone": "+70145001039"}
0005435540643	0ABE60	4885 245086	ELENA ANTONOVA	{"phone": "+70527852750"}
0005435540819	B6F026	5469 199374	DARYA ILINA	{"phone": "+70380714472"}
0005435540644	9DDA53	3730 862397	ANASTASIYA KUZNECOVA	{"email": "kuznecova_a.28101969@postgrespro.ru", "phone": "+70742864646"}
0005435540645	9DDA53	5980 753800	SVETLANA GUSEVA	{"phone": "+70535749707"}
0005435540646	EFF22D	5942 723973	MARIYA NAZAROVA	{"email": "nazarova-m-02011985@postgrespro.ru", "phone": "+70232642824"}
0005435540647	EBB554	5149 658264	KSENIYA CHERNOVA	{"phone": "+70652728638"}
0005435540648	4AC937	1937 750490	MARAT NIKITIN	{"email": "maratnikitin1987@postgrespro.ru", "phone": "+70223538743"}
0005435540649	CF2C21	6350 129308	VALENTIN BELOV	{"email": "belov-v.021984@postgrespro.ru", "phone": "+70552629654"}
0005435540650	961815	6862 463538	NIKOLAY KUZNECOV	{"email": "n_kuznecov_081981@postgrespro.ru", "phone": "+70878613099"}
0005435540651	B7AD77	5488 027948	ELENA MIKHAYLOVA	{"phone": "+70388521934"}
0005435540652	3C17E0	3104 844773	ELENA MIKHAYLOVA	{"email": "mikhaylova_elena_08031968@postgrespro.ru", "phone": "+70904104235"}
0005435540653	3C17E0	5035 421574	TAISIYA ANTONOVA	{"email": "tantonova091974@postgrespro.ru", "phone": "+70167564124"}
0005435540654	5267A2	4391 368173	ELIZAVETA ERMAKOVA	{"email": "ermakova.elizaveta.051974@postgrespro.ru", "phone": "+70050781380"}
0005435540655	5267A2	8326 977423	YURIY ALEKSANDROV	{"phone": "+70476546801"}
0005435540656	F1CDB3	9500 129638	MATVEY PAVLOV	{"phone": "+70710339455"}
0005435540657	5A72DE	6022 126462	NIKITA VLASOV	{"phone": "+70096579644"}
0005435540658	5A72DE	5540 892239	IRINA CHERNOVA	{"email": "irina-chernova_041972@postgrespro.ru", "phone": "+70815004508"}
0005435540659	DEC6FF	8069 975739	NATALYA SOKOLOVA	{"phone": "+70833610997"}
0005435540660	8E46CE	8373 262375	KIRILL ISAEV	{"email": "kirill-isaev1966@postgrespro.ru", "phone": "+70682999813"}
0005435540661	8E46CE	8848 844639	VASILIY SERGEEV	{"email": "sergeev_vasiliy_1984@postgrespro.ru", "phone": "+70428886992"}
0005435540662	B1DDC9	1981 243155	ALLA PETROVA	{"email": "allapetrova-07051970@postgrespro.ru", "phone": "+70407807018"}
0005435540663	56F962	2635 833467	MARINA KONOVALOVA	{"phone": "+70947600483"}
0005435540664	1F8BF5	3752 181627	MATRENA ALEKSEEVA	{"email": "alekseevamatrena-111976@postgrespro.ru", "phone": "+70945250508"}
0005435540665	5946BA	2123 737770	VERA ZOTOVA	{"email": "zotova_v-28071972@postgrespro.ru", "phone": "+70356551330"}
0005435540666	5946BA	3467 832109	NIKOLAY ZAKHAROV	{"phone": "+70455878319"}
0005435540667	8CF92E	1144 471021	ROMAN PAVLOV	{"email": "pavlov_roman.1979@postgrespro.ru", "phone": "+70365989591"}
0005435540668	8CF92E	1931 096098	ALEKSANDR ANDREEV	{"phone": "+70507515362"}
0005435540669	266739	3580 541989	IVAN VOROBEV	{"email": "vorobev-ivan_101963@postgrespro.ru", "phone": "+70070087906"}
0005435540670	3C9405	8494 868526	LYUDMILA SERGEEVA	{"email": "sergeevalyudmila011970@postgrespro.ru", "phone": "+70772987802"}
0005435540671	293338	3264 335252	KRISTINA KOZLOVA	{"email": "kozlova.kristina111985@postgrespro.ru", "phone": "+70374958679"}
0005435540672	FB2380	5112 435014	VLADISLAV KISELEV	{"phone": "+70589460438"}
0005435540673	2036A0	4024 813229	EKATERINA ZHUKOVA	{"phone": "+70028714846"}
0005435540674	AB57EA	7394 575562	VIKTOR KUZMIN	{"email": "v.kuzmin.1975@postgrespro.ru", "phone": "+70560329382"}
0005435540675	776DC8	4070 150277	SERGEY SOLOVEV	{"phone": "+70834252749"}
0005435540676	776DC8	1319 630379	GEORGIY IVANOV	{"phone": "+70049724249"}
0005435540677	590F26	2770 585555	ANDREY SEMENOV	{"email": "semenov_a06071979@postgrespro.ru", "phone": "+70469677337"}
0005435540678	590F26	0571 681844	PETR PETROV	{"phone": "+70878288744"}
0005435540679	590F26	5679 329771	YULIYA EFREMOVA	{"email": "efremovayuliya_10031957@postgrespro.ru", "phone": "+70558967688"}
0005435540680	FE0F57	7414 473081	EGOR ROMANOV	{"email": "egor_romanov-081975@postgrespro.ru", "phone": "+70590732101"}
0005435540681	FE0F57	6150 333773	ALEKSEY VOLKOV	{"email": "volkov_aleksey-07021972@postgrespro.ru", "phone": "+70762835705"}
0005435540682	993CD9	6598 317778	PETR ZHURAVLEV	{"email": "zhuravlev-petr-011967@postgrespro.ru", "phone": "+70687199734"}
0005435540683	993CD9	9694 526335	SERGEY RODIONOV	{"email": "rodionov.s-13081979@postgrespro.ru", "phone": "+70308566940"}
0005435540684	09BA9B	7093 254592	LYUDMILA GUSEVA	{"email": "l.guseva.021967@postgrespro.ru", "phone": "+70062283327"}
0005435540685	09BA9B	3269 578737	OLEG EGOROV	{"email": "oegorov_101965@postgrespro.ru", "phone": "+70783040658"}
0005435540686	09BA9B	0019 884396	ALEKSANDR ZAYCEV	{"phone": "+70086925591"}
0005435540687	A64AC4	5064 048965	ANDREY MATVEEV	{"email": "matveev-andrey-051964@postgrespro.ru", "phone": "+70478750886"}
0005435540688	374580	2345 092695	LEONID ALEKSEEV	{"email": "l.alekseev17031959@postgrespro.ru", "phone": "+70091740502"}
0005435540689	374580	0620 965810	ELENA NIKITINA	{"phone": "+70130995643"}
0005435540690	C9B5AA	8785 716406	NIKITA KOZLOV	{"email": "nikita_kozlov1960@postgrespro.ru", "phone": "+70177637637"}
0005435540691	A97373	0281 020817	SERGEY IVANOV	{"phone": "+70059652214"}
0005435540692	A97373	0725 908552	TATYANA LAZAREVA	{"email": "lazarevatatyana011973@postgrespro.ru", "phone": "+70197142483"}
0005435540693	D00C8E	2383 050129	TATYANA KUZNECOVA	{"phone": "+70139206585"}
0005435540694	0135C5	5328 258444	VITALIY ZHURAVLEV	{"email": "zhuravlev-v.121973@postgrespro.ru", "phone": "+70249764341"}
0005435540695	A08C99	9453 407273	VALENTINA GRISHINA	{"email": "valentina_grishina.071971@postgrespro.ru", "phone": "+70015183149"}
0005435540696	954C7B	5470 351324	ALEKSANDR SERGEEV	{"phone": "+70811864555"}
0005435540697	FB9A4B	8022 473258	RUSLAN PETROV	{"email": "ruslanpetrov-19021968@postgrespro.ru", "phone": "+70253250736"}
0005435540698	B87A14	6042 845707	RODION BORISOV	{"phone": "+70277106578"}
0005435540699	C5C980	9818 836352	ARTEM MAKAROV	{"email": "makarov_artem-16091965@postgrespro.ru", "phone": "+70951311404"}
0005435540700	C5C980	4482 251111	ARTEM IVANOV	{"email": "ivanov_a_29111973@postgrespro.ru", "phone": "+70316693336"}
0005435540701	CFA55B	2414 113435	DMITRIY NIKITIN	{"phone": "+70259201345"}
0005435540702	AE9EEC	3665 637374	LYUBOV BORISOVA	{"email": "borisova-l081982@postgrespro.ru", "phone": "+70186674572"}
0005435540703	64DF46	8259 556347	SVETLANA LEBEDEVA	{"email": "svetlana_lebedeva-15091976@postgrespro.ru", "phone": "+70955632096"}
0005435540704	03A798	0560 580508	DANILA ANTONOV	{"phone": "+70664535150"}
0005435540705	82F9EC	4233 526241	DENIS VASILEV	{"email": "denis.vasilev-091976@postgrespro.ru", "phone": "+70332125774"}
0005435540706	C42436	4618 469404	GENNADIY GRIGOREV	{"phone": "+70476087047"}
0005435540707	C42436	7371 616390	TATYANA KUZMINA	{"email": "kuzmina.t21061972@postgrespro.ru", "phone": "+70657368267"}
0005435540708	C42436	6981 003062	OLGA BELYAEVA	{"email": "obelyaeva_17101980@postgrespro.ru", "phone": "+70543065568"}
0005435540709	B47EA7	7714 754238	MAKSIM PAVLOV	{"phone": "+70549354250"}
0005435540710	DABB9A	0440 408522	IRINA LEBEDEVA	{"phone": "+70319859864"}
0005435540711	FE833D	0433 234071	VADIM SOROKIN	{"email": "sorokin-vadim1976@postgrespro.ru", "phone": "+70410339147"}
0005435540712	D3A0A1	2984 409691	ELENA FADEEVA	{"email": "fadeeva.e_1964@postgrespro.ru", "phone": "+70964591933"}
0005435540713	D3A0A1	0661 787710	KSENIYA KALININA	{"phone": "+70745935984"}
0005435540714	0D5F2E	9200 053961	ALEKSEY BARANOV	{"phone": "+70956733679"}
0005435540715	0D5F2E	1534 273936	VERA GORBUNOVA	{"email": "vera.gorbunova_26101965@postgrespro.ru", "phone": "+70158129500"}
0005435540716	81E699	4929 107071	POLINA NIKOLAEVA	{"email": "nikolaeva_polina-1967@postgrespro.ru", "phone": "+70181024951"}
0005435540717	81E699	1729 854017	ANASTASIYA VASILEVA	{"email": "a.vasileva26011962@postgrespro.ru", "phone": "+70575165045"}
0005435540718	2367B9	9975 423127	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana_22081970@postgrespro.ru", "phone": "+70311399381"}
0005435540719	2367B9	6975 695570	ALEKSEY MATVEEV	{"phone": "+70522720414"}
0005435540720	207A89	5828 652960	OLEG ABRAMOV	{"email": "oabramov_16061973@postgrespro.ru", "phone": "+70512801619"}
0005435540721	20B90A	2636 777305	VITALIY SERGEEV	{"phone": "+70084977436"}
0005435540722	965F96	2255 006257	SERGEY PETROV	{"email": "s_petrov-031979@postgrespro.ru", "phone": "+70733525438"}
0005435540723	965F96	1255 899695	LYUBOV MOROZOVA	{"email": "lmorozova.051967@postgrespro.ru", "phone": "+70348831335"}
0005435540724	9DA1CA	3052 895816	ALEKSANDR KUZNECOV	{"phone": "+70676368711"}
0005435540725	9DA1CA	3079 264181	SVETLANA NESTEROVA	{"email": "nesterova_svetlana_011972@postgrespro.ru", "phone": "+70821722235"}
0005435540726	18BC8A	9506 021042	KLAVDIYA NIKOLAEVA	{"email": "klavdiya_nikolaeva_07021970@postgrespro.ru", "phone": "+70243556960"}
0005435540727	AA9E83	2411 481571	VLADIMIR KARPOV	{"email": "karpov_vladimir041975@postgrespro.ru", "phone": "+70175962011"}
0005435540728	1D70F4	1775 341016	MIKHAIL ZAKHAROV	{"phone": "+70397001949"}
0005435540729	1D70F4	8326 988325	MARINA ILINA	{"phone": "+70998647076"}
0005435540730	A2E2B8	1734 555418	POLINA MIKHAYLOVA	{"phone": "+70099106922"}
0005435540731	A2E2B8	1782 402044	DMITRIY ZAKHAROV	{"email": "zakharovd-051962@postgrespro.ru", "phone": "+70687845397"}
0005435540732	3834C3	7527 608020	ILDAR NIKITIN	{"email": "nikitin_i-06121963@postgrespro.ru", "phone": "+70962750706"}
0005435540733	3834C3	9285 121164	NADEZHDA LUKYANOVA	{"email": "lukyanova.n_1971@postgrespro.ru", "phone": "+70941072200"}
0005435540734	3B0D40	2947 712123	EKATERINA YAKOVLEVA	{"phone": "+70791541806"}
0005435540735	7B7011	1233 200824	ANDREY KUDRYASHOV	{"email": "andrey_kudryashov-111979@postgrespro.ru", "phone": "+70695158082"}
0005435540736	E3BC66	4434 021974	DMITRIY KUZNECOV	{"phone": "+70500403306"}
0005435540737	2285DE	3295 286103	VIKTOR ABRAMOV	{"email": "abramov.viktor-12071974@postgrespro.ru", "phone": "+70709469721"}
0005435540738	650AB0	1886 819922	TATYANA NAUMOVA	{"phone": "+70374781973"}
0005435540739	650AB0	8682 416745	ANDREY KUZNECOV	{"email": "andrey.kuznecov_061979@postgrespro.ru", "phone": "+70082659665"}
0005435540740	FB9D2E	7705 958904	ANASTASIYA ZHURAVLEVA	{"phone": "+70537773541"}
0005435540741	B4D9D4	5728 542072	MARGARITA TIMOFEEVA	{"email": "timofeeva.margarita_20101984@postgrespro.ru", "phone": "+70721279196"}
0005435540742	A958F2	3830 324192	ALBERT AFANASEV	{"email": "albertafanasev_09081964@postgrespro.ru", "phone": "+70997481143"}
0005435540743	2BFC02	5445 881781	ELENA KAZAKOVA	{"phone": "+70306338926"}
0005435540744	FEBE34	5031 645710	ILYA ANDREEV	{"email": "andreevilya_031978@postgrespro.ru", "phone": "+70857049300"}
0005435540745	FEBE34	4224 799163	ANDREY ZHUKOV	{"phone": "+70642729787"}
0005435540746	63BCC4	3657 796745	VALERIY IVANOV	{"email": "ivanov-valeriy1986@postgrespro.ru", "phone": "+70996203620"}
0005435540747	2A1F88	9995 267961	ELENA TIKHONOVA	{"email": "elena_tikhonova-1966@postgrespro.ru", "phone": "+70157330102"}
0005435540748	994F56	0580 348752	VASILIY KONOVALOV	{"email": "konovalov.v_081978@postgrespro.ru", "phone": "+70536414904"}
0005435540749	994F56	5758 301347	VALENTIN VASILEV	{"email": "valentin.vasilev1972@postgrespro.ru", "phone": "+70302664756"}
0005435540750	657942	3352 617303	IRINA ROMANOVA	{"phone": "+70552013418"}
0005435540751	9AAF4F	2602 444130	NADEZHDA AFANASEVA	{"email": "afanaseva.n.051970@postgrespro.ru", "phone": "+70551141849"}
0005435540752	AAA834	1835 947161	DENIS SEMENOV	{"email": "denis.semenov-09031974@postgrespro.ru", "phone": "+70640063674"}
0005435540753	AAA834	8410 030215	OLGA FROLOVA	{"email": "o_frolova-21111964@postgrespro.ru", "phone": "+70773970415"}
0005435540754	52A47A	8519 519108	NIKITA POPOV	{"phone": "+70843946830"}
0005435540755	52A47A	6644 504548	EKATERINA NIKOLAEVA	{"phone": "+70779290287"}
0005435540756	454CFD	9724 674738	ALEKSANDR ANTONOV	{"phone": "+70864897994"}
0005435540757	8900A3	7261 136350	ANASTASIYA ABRAMOVA	{"email": "abramova-a28081971@postgrespro.ru", "phone": "+70282429055"}
0005435540758	250021	6053 523088	DMITRIY MOROZOV	{"phone": "+70113339981"}
0005435540759	CB1021	8833 695603	TATYANA SOKOLOVA	{"email": "sokolova-t_051971@postgrespro.ru", "phone": "+70453230240"}
0005435540760	CB1021	6649 335557	LARISA SIDOROVA	{"email": "sidorova-l121972@postgrespro.ru", "phone": "+70009345562"}
0005435540761	D9F74D	8867 767109	NINA MARTYNOVA	{"email": "martynova-n-30051963@postgrespro.ru", "phone": "+70713367731"}
0005435540762	D9F74D	7157 353595	VALENTINA VOLKOVA	{"email": "volkova.v.011969@postgrespro.ru", "phone": "+70687604103"}
0005435540763	2D10F4	5353 041669	IVAN SAVELEV	{"email": "ivan.savelev101966@postgrespro.ru", "phone": "+70151443065"}
0005435540764	D6CABC	2459 740077	NIKOLAY PETROV	{"phone": "+70643909441"}
0005435540765	D6CABC	8258 481232	ARSEN DMITRIEV	{"email": "dmitrieva04061979@postgrespro.ru", "phone": "+70289767257"}
0005435540766	1A68EA	0193 063999	YURIY KOZLOV	{"phone": "+70328639556"}
0005435540767	A2CE8F	6575 811953	OLGA EGOROVA	{"email": "o_egorova_1976@postgrespro.ru", "phone": "+70337967063"}
0005435540768	514BAE	6748 884179	LYUDMILA KOZLOVA	{"phone": "+70203627978"}
0005435540769	943F7D	7042 258442	YURIY ABRAMOV	{"email": "abramov-yuriy06101965@postgrespro.ru", "phone": "+70212745580"}
0005435540770	0BBBED	4472 374899	ELENA ABRAMOVA	{"email": "e-abramova-111967@postgrespro.ru", "phone": "+70965822431"}
0005435540771	0BBBED	1062 647881	ILDAR ZAKHAROV	{"phone": "+70942559322"}
0005435540772	3E79A3	1984 734309	SOFYA KONOVALOVA	{"email": "s.konovalova_031980@postgrespro.ru", "phone": "+70509116497"}
0005435540773	24F16D	4975 790118	EDUARD VLASOV	{"email": "vlasov-eduard.07121968@postgrespro.ru", "phone": "+70114180889"}
0005435540774	4FF20B	6401 141121	OLEG ANDREEV	{"email": "o_andreev-1988@postgrespro.ru", "phone": "+70948421459"}
0005435540775	B6A2DF	9408 494838	ILNAR ZAYCEV	{"email": "ilnar-zaycev.111976@postgrespro.ru", "phone": "+70991269560"}
0005435540776	B6A2DF	5376 264705	DMITRIY KUZMIN	{"email": "kuzmin_dmitriy011974@postgrespro.ru", "phone": "+70625406000"}
0005435540777	B6A2DF	8801 539888	OLGA SMIRNOVA	{"email": "smirnova.olga.011968@postgrespro.ru", "phone": "+70598593362"}
0005435540778	A2891C	9611 652626	NIKOLAY AFANASEV	{"email": "n_afanasev_15121963@postgrespro.ru", "phone": "+70307737051"}
0005435540779	6EBCC5	7466 904800	LYUDMILA SEMENOVA	{"phone": "+70723404816"}
0005435540780	5DA386	6358 966563	OKSANA NIKITINA	{"email": "nikitina-o_02061967@postgrespro.ru", "phone": "+70343634802"}
0005435540781	5DA386	0784 135549	INNA BELOVA	{"email": "inna_belova-1963@postgrespro.ru", "phone": "+70334561174"}
0005435540782	CA013A	7905 325365	VALENTIN ZAKHAROV	{"phone": "+70307431272"}
0005435540783	D43DD3	9561 901409	TATYANA FADEEVA	{"phone": "+70835487331"}
0005435540784	D43DD3	2524 358657	LYUDMILA KISELEVA	{"email": "lyudmila.kiseleva_23121978@postgrespro.ru", "phone": "+70279887216"}
0005435540785	2F8E8A	3230 722471	ARTEM TIKHONOV	{"email": "tikhonov.a_091971@postgrespro.ru", "phone": "+70636647426"}
0005435540786	2F8E8A	2229 924649	MIROSLAV MAKAROV	{"email": "makarov_miroslav-1973@postgrespro.ru", "phone": "+70722540200"}
0005435540787	B6E201	1599 949183	ALEKSEY DENISOV	{"phone": "+70450495963"}
0005435540788	793DBA	4767 232817	ROBERT NIKOLAEV	{"phone": "+70978830967"}
0005435540789	793DBA	8118 573363	TATYANA NAZAROVA	{"phone": "+70020928198"}
0005435540790	934D26	7656 171656	ALFIYA NIKOLAEVA	{"phone": "+70252084993"}
0005435540791	934D26	3003 605382	VLADIMIR KARPOV	{"email": "vladimir_karpov11081977@postgrespro.ru", "phone": "+70492808192"}
0005435540792	A23367	7369 501622	DARYA ROMANOVA	{"phone": "+70684486528"}
0005435540793	79AB0D	4674 084228	ALEKSANDR DAVYDOV	{"email": "davydov.a1979@postgrespro.ru", "phone": "+70460482979"}
0005435540794	79AB0D	9153 984087	VIKTOR VASILEV	{"email": "viktor.vasilev_04091974@postgrespro.ru", "phone": "+70662703296"}
0005435540795	36E53B	3271 284405	ANNA MEDVEDEVA	{"phone": "+70810044235"}
0005435540796	36E53B	6244 064773	SERGEY ZHURAVLEV	{"email": "sergey_zhuravlev.101970@postgrespro.ru", "phone": "+70227734014"}
0005435540797	0FE448	5824 489811	DENIS MOISEEV	{"email": "dmoiseev_07081974@postgrespro.ru", "phone": "+70216972115"}
0005435540798	052E4F	9823 061655	ALEKSANDRA MOISEEVA	{"email": "moiseeva-a.011982@postgrespro.ru", "phone": "+70434995928"}
0005435540799	052E4F	8806 378300	RUSTAM FOMIN	{"email": "fomin_rustam_041981@postgrespro.ru", "phone": "+70792639163"}
0005435540800	0E5363	5835 179788	SERGEY BARANOV	{"email": "baranov-s_1969@postgrespro.ru", "phone": "+70193134830"}
0005435540801	38708A	1375 421728	NINA VASILEVA	{"email": "nina.vasileva.071973@postgrespro.ru", "phone": "+70542468847"}
0005435540802	B3EAFE	2190 488626	GENNADIY POPOV	{"email": "popov.g.1982@postgrespro.ru", "phone": "+70904170844"}
0005435540803	B3EAFE	7639 540570	NATALIYA KUZNECOVA	{"email": "kuznecovan-041972@postgrespro.ru", "phone": "+70950521411"}
0005435540804	F5B272	6252 199166	IRINA IVANOVA	{"phone": "+70002621979"}
0005435540805	F5B272	2877 284027	ALEKSANDR ZHURAVLEV	{"phone": "+70332181886"}
0005435540806	49D8AE	4168 471974	SERGEY ZAKHAROV	{"email": "zakharov_s.26091978@postgrespro.ru", "phone": "+70483974829"}
0005435540807	FB1A4B	6729 715586	ELENA VOLKOVA	{"phone": "+70587219678"}
0005435540808	C82ED5	6292 721049	ILYA KISELEV	{"phone": "+70245947988"}
0005435540809	C82ED5	5719 697058	MIKHAIL SOKOLOV	{"phone": "+70739825903"}
0005435540810	E7317F	0408 775140	VIKTORIYA NAUMOVA	{"phone": "+70772635652"}
0005435540811	69DA1C	9104 838393	SERGEY KULIKOV	{"phone": "+70201177976"}
0005435540812	69DA1C	8188 499358	LIDIYA ZAKHAROVA	{"email": "lidiya.zakharova-1978@postgrespro.ru", "phone": "+70920398649"}
0005435540813	69DA1C	0079 053854	ANASTASIYA MAKAROVA	{"phone": "+70055045155"}
0005435540814	B21B2F	4859 770169	LARISA ANISIMOVA	{"email": "larisa.anisimova_08061976@postgrespro.ru", "phone": "+70325859022"}
0005435540815	F48187	8845 817681	ELENA ANDREEVA	{"email": "eandreeva_1976@postgrespro.ru", "phone": "+70362472939"}
0005435540816	1E6C00	9258 779001	ALESYA FOMINA	{"phone": "+70293501901"}
0005435540817	E2F491	6698 194181	VLADIMIR VOROBEV	{"phone": "+70014225910"}
0005435540818	1DFD8B	2533 361315	IGOR DAVYDOV	{"email": "davydovigor-08091972@postgrespro.ru", "phone": "+70200986885"}
0005435540820	B6F026	9693 106694	NINA TIKHONOVA	{"phone": "+70558990635"}
0005435540821	AF7505	5638 189629	MARIYA NIKITINA	{"phone": "+70207833162"}
0005435540822	AF7505	8397 816519	ALEKSEY SEMENOV	{"email": "a.semenov051963@postgrespro.ru", "phone": "+70261173057"}
0005435540823	A9A7DA	8817 509864	ALEKSANDR SERGEEV	{"email": "sergeevaleksandr041979@postgrespro.ru", "phone": "+70182565460"}
0005435540824	A9A7DA	4468 026797	GALINA ABRAMOVA	{"email": "galina_abramova-1976@postgrespro.ru", "phone": "+70188914713"}
0005435540825	80B46A	3989 515151	MARINA LUKYANOVA	{"email": "m_lukyanova1971@postgrespro.ru", "phone": "+70635302380"}
0005435540826	80B46A	2880 917487	OLESYA ALEKSANDROVA	{"email": "aleksandrova_o111962@postgrespro.ru", "phone": "+70205591556"}
0005435540827	54FDF4	6490 861549	EKATERINA GUSEVA	{"phone": "+70795229866"}
0005435540828	24C63A	9457 267244	ARTEM ZAKHAROV	{"email": "a_zakharov21031982@postgrespro.ru", "phone": "+70005611289"}
0005435540829	0DBBC9	2888 032058	ANNA ORLOVA	{"email": "orlova_anna051972@postgrespro.ru", "phone": "+70754820217"}
0005435540830	7B5C70	6814 514717	ALEKSEY BONDARENKO	{"phone": "+70567015449"}
0005435540831	A2D88B	2917 171043	KONSTANTIN VASILEV	{"email": "vasilevk.1982@postgrespro.ru", "phone": "+70050596218"}
0005435540832	ECDC06	9833 885287	EVGENIY PETROV	{"email": "e.petrov-1978@postgrespro.ru", "phone": "+70762029642"}
0005435540833	ECDC06	4068 807731	ALENA ZHURAVLEVA	{"email": "alenazhuravleva-04091970@postgrespro.ru", "phone": "+70214451942"}
0005435540834	E03E06	7453 709581	LYUBOV DENISOVA	{"phone": "+70721188566"}
0005435540835	41652E	2259 748916	VLADIMIR MOISEEV	{"email": "vmoiseev_29061960@postgrespro.ru", "phone": "+70581103009"}
0005435540836	C28A6A	5700 007303	NIKOLAY SOKOLOV	{"email": "n-sokolov_041971@postgrespro.ru", "phone": "+70561165307"}
0005435540837	9DC4C8	2894 111672	ANTON MATVEEV	{"email": "anton-matveev.121972@postgrespro.ru", "phone": "+70887541791"}
0005435540838	AC14E5	7703 709402	ALEKSANDR STEPANOV	{"email": "a-stepanov101970@postgrespro.ru", "phone": "+70134690714"}
0005435540839	AC14E5	3421 147825	LIDIYA FOMINA	{"phone": "+70505620807"}
0005435540840	36941E	8184 617707	VLADIMIR IVANOV	{"phone": "+70400070791"}
0005435540841	6DB5FA	1377 190773	LYUDMILA ANDREEVA	{"phone": "+70847868391"}
0005435540842	6DB5FA	9140 067713	SVETLANA KOROLEVA	{"phone": "+70721907315"}
0005435540843	D325C7	8370 440746	VYACHESLAV ZAKHAROV	{"email": "zakharov-v-121963@postgrespro.ru", "phone": "+70627155586"}
0005435540844	8F08FA	0103 975690	EKATERINA IVANOVA	{"email": "ivanovae_24031979@postgrespro.ru", "phone": "+70581289544"}
0005435540845	8F08FA	9731 613297	VIKTOR TIMOFEEV	{"email": "v-timofeev05041965@postgrespro.ru", "phone": "+70001739051"}
0005435540846	8F08FA	0091 433964	SERGEY KRASNOV	{"email": "skrasnov.1972@postgrespro.ru", "phone": "+70422396174"}
0005435540847	8F08FA	9468 351666	NATALYA VOLKOVA	{"email": "volkova_n021971@postgrespro.ru", "phone": "+70378143828"}
0005435540848	1C8E3B	9320 209041	VIKTOR KUZMIN	{"email": "kuzmin_v1958@postgrespro.ru", "phone": "+70199260792"}
0005435540849	78E690	3652 590835	VITALIY NOVIKOV	{"phone": "+70646129896"}
0005435540850	78E690	5865 102387	OLEG BARANOV	{"phone": "+70402330743"}
0005435540851	AC6A14	0991 226897	SERGEY CHERNOV	{"email": "chernov_sergey_24071967@postgrespro.ru", "phone": "+70620122071"}
0005435540852	F50F6B	9840 069746	VALENTINA CHERNOVA	{"email": "chernova.valentina26101970@postgrespro.ru", "phone": "+70838405977"}
0005435540853	F50F6B	5473 098776	SERGEY MOROZOV	{"email": "morozov-sergey.1979@postgrespro.ru", "phone": "+70007271481"}
0005435540854	1A7407	7304 278518	VALENTINA SERGEEVA	{"phone": "+70857109210"}
0005435540855	125B96	8556 224059	VALERIY TIMOFEEV	{"email": "valeriy_timofeev.1964@postgrespro.ru", "phone": "+70521519374"}
0005435540856	34B4BF	2129 686628	ALEKSANDRA GUSEVA	{"email": "gusevaa.06081972@postgrespro.ru", "phone": "+70674184618"}
0005435540857	867CBE	3175 519998	EVDOKIYA AKIMOVA	{"email": "eakimova.04111971@postgrespro.ru", "phone": "+70369213422"}
0005435540858	92DF7B	5839 693301	ANASTASIYA PETROVA	{"email": "petrova.anastasiya18071971@postgrespro.ru", "phone": "+70546134883"}
0005435540859	92DF7B	8026 415303	ROMAN TIMOFEEV	{"phone": "+70462748856"}
0005435540860	1F3A3A	4407 780781	NATALYA EGOROVA	{"phone": "+70193438922"}
0005435540861	006157	0916 853311	VLADIMIR KUZNECOV	{"email": "v-kuznecov031963@postgrespro.ru", "phone": "+70815649452"}
0005435540862	006157	8986 947469	ALEKSANDR RODIONOV	{"phone": "+70122719591"}
0005435540863	5CA9FC	3354 993375	TAMARA GAVRILOVA	{"email": "gavrilova_tamara_1977@postgrespro.ru", "phone": "+70158665242"}
0005435540864	5CA9FC	0476 446037	TAMARA ALEKSEEVA	{"phone": "+70751685860"}
0005435540865	EB9B8F	5714 218163	SERGEY GORBUNOV	{"phone": "+70901313573"}
0005435540866	05F177	2117 745757	ALLA ZAKHAROVA	{"email": "zakharovaalla-03081966@postgrespro.ru", "phone": "+70083158096"}
0005435540867	A042DD	8492 339442	ALEKSANDR IVANOV	{"email": "aleksandr_ivanov061971@postgrespro.ru", "phone": "+70044990028"}
0005435540868	54EAF8	2112 565234	VALENTINA TIKHONOVA	{"email": "valentinatikhonova08101970@postgrespro.ru", "phone": "+70599746344"}
0005435540869	DFB79B	3562 488749	VALENTINA ILINA	{"phone": "+70867398957"}
0005435540870	8EABC0	6373 303068	VLADISLAV POPOV	{"phone": "+70895430567"}
0005435540871	0294ED	6319 654504	SAID ROMANOV	{"phone": "+70689426602"}
0005435540872	0294ED	4816 356045	ROMAN IVANOV	{"email": "ivanov.r-121968@postgrespro.ru", "phone": "+70355395486"}
0005435540873	723078	5239 451412	ALEKSANDR NAUMOV	{"phone": "+70755499911"}
0005435540874	25F0CA	9139 957459	VALENTINA KOZLOVA	{"phone": "+70344676980"}
0005435540875	25F0CA	5668 828380	YULIYA STEPANOVA	{"phone": "+70435314925"}
0005435540876	9E8EB6	6171 585841	DARYA MALYSHEVA	{"email": "d-malysheva-091970@postgrespro.ru", "phone": "+70060063601"}
0005435540877	2C2D90	2721 722625	VYACHESLAV IVANOV	{"phone": "+70532054178"}
0005435540878	2C2D90	1153 523196	EKATERINA IVANOVA	{"email": "ivanova.e031969@postgrespro.ru", "phone": "+70471440058"}
0005435540879	C89148	6320 149087	MIKHAIL FROLOV	{"email": "frolov-m101964@postgrespro.ru", "phone": "+70268421891"}
0005435540880	69B177	4530 663232	MARAT KRASNOV	{"phone": "+70545363386"}
0005435540881	D8527B	5791 238866	SERGEY BONDARENKO	{"email": "bondarenko-s1976@postgrespro.ru", "phone": "+70616700643"}
0005435540882	D8527B	9138 446447	ELIZAVETA ZAKHAROVA	{"email": "ezakharova21021960@postgrespro.ru", "phone": "+70137337779"}
0005435540883	D8527B	6398 710964	NADEZHDA IVANOVA	{"phone": "+70130481151"}
0005435540884	D8527B	6029 956440	IRINA ROMANOVA	{"phone": "+70624333554"}
0005435540885	5CE5C3	4397 565825	LYUBOV DENISOVA	{"phone": "+70628154002"}
0005435540886	5CE5C3	8405 089155	RAISA KOZLOVA	{"phone": "+70443336213"}
0005435540887	CB3308	8655 370961	OLGA PETROVA	{"email": "olgapetrova1978@postgrespro.ru", "phone": "+70764743417"}
0005435540888	943982	3601 666601	DARYA PETROVA	{"email": "daryapetrova-1978@postgrespro.ru", "phone": "+70330458155"}
0005435540889	943982	5849 159594	NIKITA KISELEV	{"email": "kiselev_nikita071955@postgrespro.ru", "phone": "+70230738235"}
0005435540890	943982	6029 708839	ALEKSANDR KUZNECOV	{"email": "kuznecov.aleksandr-16051979@postgrespro.ru", "phone": "+70822594002"}
0005435540891	8E07CA	3552 337249	EKATERINA LAZAREVA	{"email": "ekaterina-lazareva_30051968@postgrespro.ru", "phone": "+70300726097"}
0005435540892	8F92ED	5096 484955	VYACHESLAV GAVRILOV	{"email": "vyacheslav.gavrilov_091975@postgrespro.ru", "phone": "+70881165750"}
0005435540893	8F92ED	8773 513979	VLADIMIR PAVLOV	{"phone": "+70151043763"}
0005435540894	8F92ED	0334 599599	OKSANA NIKITINA	{"email": "o.nikitina23021971@postgrespro.ru", "phone": "+70657566542"}
0005435540895	FCEE44	0155 054502	VALENTINA PETROVA	{"phone": "+70178888600"}
0005435540896	FCEE44	2955 438488	VLADIMIR ALEKSEEV	{"email": "vladimir_alekseev_101983@postgrespro.ru", "phone": "+70404227870"}
0005435540897	FCEE44	7333 069157	MARIYA TROFIMOVA	{"phone": "+70159552270"}
0005435540898	0562C2	3106 025439	RUMIYA DENISOVA	{"phone": "+70487476036"}
0005435540899	A2023C	1808 829027	VLADIMIR BORISOV	{"phone": "+70312598471"}
0005435540900	0D4A51	8945 703099	ALEKSEY KUZNECOV	{"phone": "+70968923523"}
0005435540901	0D4A51	7258 250508	MARIYA BORISOVA	{"email": "borisova.m_091972@postgrespro.ru", "phone": "+70098987366"}
0005435540902	0D4A51	3165 279870	VALERIY ROMANOV	{"phone": "+70343448989"}
0005435540903	73871A	4152 693333	ELIZAVETA BARANOVA	{"email": "baranova.e-04121972@postgrespro.ru", "phone": "+70342166168"}
0005435540904	73871A	4972 022334	ALEKSEY NIKITIN	{"phone": "+70033715980"}
0005435540905	750721	8171 427281	ANASTASIYA MIKHAYLOVA	{"email": "anastasiya_mikhaylova-091955@postgrespro.ru", "phone": "+70406049200"}
0005435540906	F4F929	2182 930919	PAVEL MATVEEV	{"email": "pmatveev071967@postgrespro.ru", "phone": "+70558811511"}
0005435540907	F4F929	0819 382741	NINA ARKHIPOVA	{"email": "nina.arkhipova_1961@postgrespro.ru", "phone": "+70612341413"}
0005435540908	B67124	6157 796140	LYUBOV MOROZOVA	{"phone": "+70579177003"}
0005435540909	91A41D	7647 949860	VYACHESLAV KRASNOV	{"phone": "+70884901976"}
0005435540910	91A41D	7704 068334	OLEG GAVRILOV	{"email": "gavrilov-oleg.061972@postgrespro.ru", "phone": "+70614330495"}
0005435540911	A3BB88	7296 171000	OKSANA GORBUNOVA	{"email": "gorbunovaoksana04061976@postgrespro.ru", "phone": "+70868819479"}
0005435540912	1CC502	5726 177840	VERA LUKYANOVA	{"phone": "+70409101834"}
0005435540913	1CC502	2483 613228	SERGEY KAZAKOV	{"phone": "+70200173297"}
0005435540914	408D13	5850 627668	ANASTASIYA MIKHAYLOVA	{"phone": "+70906225018"}
0005435540915	76191A	5855 464976	NIKOLAY SMIRNOV	{"email": "smirnov_nikolay111960@postgrespro.ru", "phone": "+70890867655"}
0005435540916	199533	6373 098277	VLADISLAV KOROLEV	{"phone": "+70958458024"}
0005435540917	199533	0130 568698	SERGEY FROLOV	{"phone": "+70813913281"}
0005435540918	3CB053	7945 993357	TAMARA POPOVA	{"email": "tamara.popova29101962@postgrespro.ru", "phone": "+70428380539"}
0005435540919	9A6C0A	2370 055858	EVGENIY GRIGOREV	{"email": "grigorev-e.1974@postgrespro.ru", "phone": "+70188123594"}
0005435540920	68CD2B	6859 622135	VYACHESLAV VASILEV	{"phone": "+70827255678"}
0005435540921	8598D0	4024 663943	DMITRIY ABRAMOV	{"email": "abramov_d20111973@postgrespro.ru", "phone": "+70724874343"}
0005435540922	C19D62	0343 048376	GENNADIY ANDREEV	{"email": "andreev.g.081982@postgrespro.ru", "phone": "+70201184809"}
0005435540923	B0CF22	9714 355887	ALEKSEY FILIPPOV	{"phone": "+70507034836"}
0005435540924	8CFF0F	2540 354332	MARIYA NIKIFOROVA	{"phone": "+70622080282"}
0005435540925	8CFF0F	6274 795080	LIDIYA NAUMOVA	{"email": "l_naumova021974@postgrespro.ru", "phone": "+70198867526"}
0005435540926	8CFF0F	7096 959332	NATALYA ILINA	{"email": "natalyailina051966@postgrespro.ru", "phone": "+70926412270"}
0005435540927	713567	5787 101922	VERA ROMANOVA	{"email": "vera-romanova021969@postgrespro.ru", "phone": "+70474873130"}
0005435540928	9EBC24	8230 546089	NIKOLAY VOROBEV	{"phone": "+70114299912"}
0005435540929	44413C	1687 075005	DANILA SMIRNOV	{"phone": "+70495604285"}
0005435540930	F96B52	2779 462975	ALEKSEY ZAKHAROV	{"phone": "+70936999223"}
0005435540931	DB2285	5496 404304	NADEZHDA POLYAKOVA	{"email": "nadezhda-polyakova1963@postgrespro.ru", "phone": "+70585376358"}
0005435540932	90F4CF	5016 389768	NINA ANDREEVA	{"phone": "+70569806071"}
0005435540933	CD9B6D	1839 157116	NATALYA SOKOLOVA	{"phone": "+70619382721"}
0005435540934	9142F4	8602 534214	VALENTINA KUZMINA	{"email": "v-kuzmina-1974@postgrespro.ru", "phone": "+70250031793"}
0005435540935	44B2F2	9144 707368	ROMAN STEPANOV	{"phone": "+70515692427"}
0005435540936	A9BDB9	7248 282464	SVETLANA DAVYDOVA	{"email": "svetlana.davydova1968@postgrespro.ru", "phone": "+70812893925"}
0005435540937	A70E78	8752 255090	KONSTANTIN YAKOVLEV	{"email": "yakovlev-konstantin_1987@postgrespro.ru", "phone": "+70414145562"}
0005435540938	C3D4DF	9502 008207	SERGEY BORISOV	{"phone": "+70286989350"}
0005435540939	EA9CF0	0436 636136	ANDREY POPOV	{"email": "andrey.popov1975@postgrespro.ru", "phone": "+70215470243"}
0005435540940	500E56	6744 102610	NINA KOZLOVA	{"phone": "+70442520625"}
0005435540941	500E56	0829 724367	MAKSIM MOISEEV	{"email": "maksim_moiseev1971@postgrespro.ru", "phone": "+70988717944"}
0005435540942	8BBA9B	7726 605463	KSENIYA DENISOVA	{"phone": "+70121603519"}
0005435540943	64ADC6	2026 944174	ARTEM MEDVEDEV	{"phone": "+70406099156"}
0005435540944	264787	2663 816566	MARIYA GERASIMOVA	{"phone": "+70331642927"}
0005435540945	C430FC	6932 024465	MARIYA KOVALEVA	{"phone": "+70972200017"}
0005435540946	0F5893	3408 955827	NADEZHDA TARASOVA	{"email": "n.tarasova-111961@postgrespro.ru", "phone": "+70623604465"}
0005435540947	0F5893	3688 476912	VLADIMIR DMITRIEV	{"email": "dmitriev.v.111981@postgrespro.ru", "phone": "+70259073795"}
0005435540948	CF51A2	5252 853217	LYUDMILA CHERNOVA	{"email": "chernova.lyudmila_061973@postgrespro.ru", "phone": "+70839151980"}
0005435540949	B6B678	4950 012051	MARINA SOROKINA	{"email": "m_sorokina02111963@postgrespro.ru", "phone": "+70645980494"}
0005435540950	44D17C	8525 736752	EKATERINA IVANOVA	{"phone": "+70180122934"}
0005435540951	A33FB2	2571 596660	LYUDMILA POPOVA	{"phone": "+70007963662"}
0005435540952	74DC0E	8132 829957	ELENA MARTYNOVA	{"email": "martynova.e-081960@postgrespro.ru", "phone": "+70855670968"}
0005435540953	061C45	9267 248821	ALEKSANDRA BORISOVA	{"phone": "+70055780555"}
0005435540954	061C45	8853 133461	MAKSIM KUZNECOV	{"email": "m-kuznecov.121984@postgrespro.ru", "phone": "+70948103528"}
0005435540955	B81EA0	7947 902706	EKATERINA NAZAROVA	{"email": "ekaterina_nazarova-1980@postgrespro.ru", "phone": "+70207260349"}
0005435540956	95FD5B	5839 612603	KIRILL KOZLOV	{"phone": "+70720844918"}
0005435540957	95FD5B	8861 856114	VALENTINA ANDREEVA	{"phone": "+70629933690"}
0005435540958	833ECF	7890 001764	VIKTORIYA KUZNECOVA	{"phone": "+70975834508"}
0005435540959	833ECF	5083 851539	LARISA GORBUNOVA	{"phone": "+70269606369"}
0005435540960	53DAEC	8447 293341	ALEKSANDR VASILEV	{"email": "avasilev-101964@postgrespro.ru", "phone": "+70405115428"}
0005435540961	BE5380	7792 076291	VLADISLAV SOKOLOV	{"phone": "+70586343212"}
0005435540962	BE5380	2982 039817	ALEKSEY SAVELEV	{"phone": "+70404377969"}
0005435540963	B4E929	4495 632489	ALEKSANDR ANDREEV	{"phone": "+70203118786"}
0005435540964	D504D3	8240 592729	OLGA MARTYNOVA	{"email": "martynova_o.08111973@postgrespro.ru", "phone": "+70814547529"}
0005435540965	77F7DC	4084 114180	VALERIY IVANOV	{"phone": "+70275182511"}
0005435540966	80F573	9712 972404	DMITRIY KUZNECOV	{"email": "kuznecov.d_1973@postgrespro.ru", "phone": "+70659675984"}
0005435540967	0E6813	6579 487902	GALINA LUKYANOVA	{"email": "galina_lukyanova.1979@postgrespro.ru", "phone": "+70079007496"}
0005435540968	00C759	4087 784735	DAMIR YAKOVLEV	{"email": "damiryakovlev-091962@postgrespro.ru", "phone": "+70403374854"}
0005435540969	608714	5206 598658	TATYANA NESTEROVA	{"phone": "+70606041190"}
0005435540970	5F4C49	2727 421986	ANGELINA VASILEVA	{"phone": "+70084991165"}
0005435540971	5F4C49	1545 094127	DANILA SMIRNOV	{"phone": "+70928594431"}
0005435540972	4FE7CB	6106 740762	ALEKSEY EGOROV	{"email": "alekseyegorov.25111977@postgrespro.ru", "phone": "+70495652902"}
0005435540973	2F0ACF	3611 611869	ALEKSEY BARANOV	{"phone": "+70951483005"}
0005435540974	D0B6E4	0389 707482	ANATOLIY KULIKOV	{"phone": "+70902802248"}
0005435540975	882E0C	1890 002801	NIKITA KUDRYASHOV	{"phone": "+70129029542"}
0005435540976	C15B62	7654 043834	SERGEY ANDREEV	{"phone": "+70500966275"}
0005435540977	C15B62	9123 610135	SERGEY KRASNOV	{"phone": "+70296282862"}
0005435540978	DC80CA	7585 453297	VASILIY SOLOVEV	{"phone": "+70082094555"}
0005435540979	14B18B	9041 329668	ALEKSEY KUZNECOV	{"email": "aleksey.kuznecov041971@postgrespro.ru", "phone": "+70659079203"}
0005435540980	0E4A29	5438 233795	DANIIL SIDOROV	{"phone": "+70433733486"}
0005435540981	1BA464	9548 566425	OLEG SEMENOV	{"phone": "+70959679600"}
0005435540982	4B4C18	4646 411452	SERGEY NOVIKOV	{"phone": "+70079801892"}
0005435540983	4B4C18	8553 916271	YURIY CHERNOV	{"phone": "+70379176984"}
0005435540984	7C3812	8168 197707	LYUBOV ZAKHAROVA	{"phone": "+70243055932"}
0005435540985	FBF83F	8875 107803	YANA PETROVA	{"email": "petrova-yana-02081978@postgrespro.ru", "phone": "+70641749338"}
0005435540986	F70CCC	9961 805528	VERA MIRONOVA	{"phone": "+70337963301"}
0005435540987	F70CCC	3465 416367	IRINA RODIONOVA	{"phone": "+70321657645"}
0005435540988	B5E3D0	9459 987033	KRISTINA KOLESNIKOVA	{"email": "kolesnikova_kristina1976@postgrespro.ru", "phone": "+70024905896"}
0005435540989	B5E3D0	5842 122763	VLADIMIR ALEKSEEV	{"phone": "+70676054937"}
0005435540990	B5E3D0	9222 136986	KSENIYA PAVLOVA	{"phone": "+70694308361"}
0005435540991	AC5719	5800 029113	PRASKOVYA NAUMOVA	{"email": "naumova_p081978@postgrespro.ru", "phone": "+70752474170"}
0005435540992	AC5719	0744 859939	EKATERINA FEDOROVA	{"email": "fedorova_e_14101971@postgrespro.ru", "phone": "+70423233163"}
0005435540993	AC5719	2321 587090	ANDREY IVANOV	{"email": "andrey_ivanov_1969@postgrespro.ru", "phone": "+70003240632"}
0005435540994	A540A3	9729 937896	OLGA MIKHAYLOVA	{"email": "mikhaylova_olga-01011964@postgrespro.ru", "phone": "+70862863060"}
0005435540995	AB2DDF	7979 900403	DENIS MELNIKOV	{"email": "melnikov.denis-25101972@postgrespro.ru", "phone": "+70662627050"}
0005435540996	0E9F97	1438 802127	SVETLANA PAVLOVA	{"phone": "+70825748112"}
0005435540997	FA0E3A	5869 805807	TATYANA NIKITINA	{"email": "t-nikitina14121972@postgrespro.ru", "phone": "+70123923089"}
0005435540998	73DEEE	3055 352395	EKATERINA MATVEEVA	{"phone": "+70179821960"}
0005435540999	F303B5	2589 168807	LIDIYA IVANOVA	{"phone": "+70785970323"}
0005435541000	F303B5	5709 541921	EVGENIY ORLOV	{"phone": "+70635861233"}
0005435541001	F8E607	7908 067790	ALLA SEMENOVA	{"phone": "+70762679062"}
0005435541002	8E7726	1348 044651	VLADIMIR ALEKSEEV	{"email": "v_alekseev.27011978@postgrespro.ru", "phone": "+70785337941"}
0005435541003	D8D970	1845 994090	IRINA MAKAROVA	{"email": "makarova-irina.1975@postgrespro.ru", "phone": "+70536068739"}
0005435541004	7E927A	4533 205492	LYUDMILA FROLOVA	{"email": "lfrolova.061968@postgrespro.ru", "phone": "+70222576758"}
0005435541005	898736	5627 098089	GALINA CHERNOVA	{"email": "chernovag-17021963@postgrespro.ru", "phone": "+70343121756"}
0005435541006	B99F48	4494 751047	MIKHAIL SAVELEV	{"email": "mikhail-savelev-081976@postgrespro.ru", "phone": "+70296647603"}
0005435541007	1DC5FD	9682 933315	VLADIMIR BORISOV	{"phone": "+70370817017"}
0005435541008	1DC5FD	5323 649396	LILIYA PETROVA	{"email": "petrova_liliya-011977@postgrespro.ru", "phone": "+70073871560"}
0005435541009	C2F939	9630 828780	ALEKSANDR POPOV	{"phone": "+70023409078"}
0005435541010	C2F939	4128 444438	MARIYA KOVALEVA	{"email": "kovaleva.m.061972@postgrespro.ru", "phone": "+70348376755"}
0005435541011	993B13	6132 429926	IRINA MOROZOVA	{"email": "irina-morozova-1974@postgrespro.ru", "phone": "+70810356316"}
0005435541012	4CFE36	5373 031275	LYUDMILA BORISOVA	{"phone": "+70619109653"}
0005435541013	4CFE36	7458 172555	SERGEY MATVEEV	{"email": "matveev-sergey_15091984@postgrespro.ru", "phone": "+70050222066"}
0005435541014	D51D79	2337 650692	RAVIL BONDARENKO	{"email": "ravilbondarenko_1970@postgrespro.ru", "phone": "+70164442416"}
0005435541015	D51D79	3832 529421	SERGEY KISELEV	{"phone": "+70835667241"}
0005435541016	A76292	0098 898543	NATALYA IVANOVA	{"phone": "+70776734583"}
0005435541017	A76292	5366 058559	NINA ARKHIPOVA	{"email": "nina_arkhipova.13081985@postgrespro.ru", "phone": "+70753907161"}
0005435541018	A76292	9429 286750	NADEZHDA NIKITINA	{"phone": "+70137963082"}
0005435541019	DA9B50	0947 592198	ELENA KUZNECOVA	{"phone": "+70103785648"}
0005435541020	AC7400	1076 734372	SVETLANA TIKHONOVA	{"email": "tikhonova.s-12051974@postgrespro.ru", "phone": "+70902024070"}
0005435541021	AC7400	2020 847799	VYACHESLAV VLASOV	{"email": "vyacheslav_vlasov-051970@postgrespro.ru", "phone": "+70582186592"}
0005435541022	AC7400	3193 410117	DMITRIY BONDARENKO	{"phone": "+70305095023"}
0005435541023	010551	6025 204441	ANNA SMIRNOVA	{"email": "a_smirnova_091966@postgrespro.ru", "phone": "+70218785619"}
0005435541024	2B930F	0366 903186	MARAT MIRONOV	{"phone": "+70780228400"}
0005435541025	2B930F	5808 523991	VLADIMIR SCHERBAKOV	{"phone": "+70778072016"}
0005435541026	28738B	8098 647106	GALINA VASILEVA	{"phone": "+70010433762"}
0005435541027	7F6A2D	3855 123778	PAVEL MIRONOV	{"email": "mironov.pavel-091975@postgrespro.ru", "phone": "+70080696507"}
0005435541028	7F6A2D	9411 736694	PAVEL MAKSIMOV	{"email": "p-maksimov-1971@postgrespro.ru", "phone": "+70865113043"}
0005435541029	26B510	4371 789482	VLADIMIR KULIKOV	{"email": "vladimir-kulikov.20061974@postgrespro.ru", "phone": "+70811517273"}
0005435541030	26B510	3082 423496	GALINA AFANASEVA	{"email": "galina_afanaseva-11061969@postgrespro.ru", "phone": "+70871555675"}
0005435541031	378B5B	9643 225064	IRINA PAVLOVA	{"email": "irina_pavlova_081980@postgrespro.ru", "phone": "+70245097820"}
0005435541032	40ACA0	2747 566621	VLADIMIR BONDARENKO	{"phone": "+70256341427"}
0005435541033	57A8FC	9742 029436	OLEG NOVIKOV	{"phone": "+70578253595"}
0005435541034	E48F4B	9634 147081	VLADIMIR SOKOLOV	{"email": "sokolov_vladimir-1984@postgrespro.ru", "phone": "+70803272770"}
0005435541035	9C2E28	7225 157671	LYUDMILA ISAEVA	{"email": "isaeval_1971@postgrespro.ru", "phone": "+70211738522"}
0005435541036	9C2E28	4960 077767	EKATERINA FROLOVA	{"phone": "+70890092271"}
0005435541037	D003D8	1236 166070	ELIZAVETA KUZNECOVA	{"email": "kuznecova_elizaveta_10091976@postgrespro.ru", "phone": "+70443855553"}
0005435541038	D003D8	1139 355078	OLGA ZOTOVA	{"phone": "+70857576092"}
0005435541039	1FE9FB	9304 285170	VALENTINA DENISOVA	{"email": "denisovav-05061957@postgrespro.ru", "phone": "+70161852417"}
0005435541040	149DB1	4908 295811	VASILIY PETROV	{"phone": "+70169168974"}
0005435541041	9E2F41	8822 581006	ALEKSEY SOROKIN	{"email": "sorokin_aleksey08031969@postgrespro.ru", "phone": "+70362829471"}
0005435541042	249B72	0223 754027	NADEZHDA ZOTOVA	{"phone": "+70266045453"}
0005435541043	D2F9D5	3420 447372	MARINA MASLOVA	{"email": "m.maslova.1962@postgrespro.ru", "phone": "+70567016983"}
0005435541044	F552D8	3353 031352	TATYANA MIRONOVA	{"phone": "+70648021498"}
0005435541045	F552D8	3981 797989	YURIY MOISEEV	{"email": "ymoiseev_1987@postgrespro.ru", "phone": "+70742619020"}
0005435541046	FEACF8	8801 980471	DMITRIY NIKOLAEV	{"email": "d_nikolaev_081981@postgrespro.ru", "phone": "+70916570352"}
0005435541047	A48E68	8744 400967	EVGENIY FEDOROV	{"email": "e_fedorov.071966@postgrespro.ru", "phone": "+70002754644"}
0005435541048	DAF744	6047 445867	ALEKSANDR KUZNECOV	{"email": "a_kuznecov.071976@postgrespro.ru", "phone": "+70568491676"}
0005435541049	55C5AB	2057 163677	EDUARD KUZNECOV	{"email": "kuznecov-e061970@postgrespro.ru", "phone": "+70280749773"}
0005435541050	55C5AB	7440 293688	SERGEY PETROV	{"email": "sergey-petrov.011980@postgrespro.ru", "phone": "+70683804558"}
0005435541051	55C5AB	2967 789707	SERGEY AFANASEV	{"phone": "+70581384723"}
0005435541052	AC86D2	7475 073268	DANIIL KOZLOV	{"email": "kozlov.daniil.1976@postgrespro.ru", "phone": "+70330983019"}
0005435541053	2B6659	1416 514262	VLADIMIR IVANOV	{"phone": "+70869377042"}
0005435541054	2B6659	9568 162258	NIKOLAY PETROV	{"email": "nikolay_petrov_081973@postgrespro.ru", "phone": "+70224328560"}
0005435541055	2B6659	4782 990221	OLGA YAKOVLEVA	{"email": "yakovleva-o-20051983@postgrespro.ru", "phone": "+70389643920"}
0005435541056	F46C7B	0684 308062	YULIYA FEDOROVA	{"phone": "+70356071769"}
0005435541057	F46C7B	6416 188259	OKSANA BELOVA	{"email": "oksana.belova-041978@postgrespro.ru", "phone": "+70671612701"}
0005435541058	8CA0F9	8364 359780	VLADIMIR BELOV	{"email": "vladimir.belov07041985@postgrespro.ru", "phone": "+70722163668"}
0005435541059	396F29	4695 720953	NINA MATVEEVA	{"phone": "+70071341377"}
0005435541060	496456	5988 911103	NIKOLAY MAKAROV	{"phone": "+70691219488"}
0005435541061	CDB389	7054 743528	GALINA GORBUNOVA	{"email": "gorbunova.g25081968@postgrespro.ru", "phone": "+70270918599"}
0005435541062	FBB5BA	1602 189493	NADEZHDA MIRONOVA	{"email": "mironova_nadezhda-05031969@postgrespro.ru", "phone": "+70313816015"}
0005435541063	7E0621	3493 262426	OLGA ALEKSANDROVA	{"phone": "+70551000755"}
0005435541064	22E7EA	3855 110348	DMITRIY NOVIKOV	{"phone": "+70925055316"}
0005435541065	22E7EA	5635 150100	ANATOLIY ILIN	{"phone": "+70403908452"}
0005435541066	163E29	1034 621136	YURIY VASILEV	{"phone": "+70778129727"}
0005435541067	911039	3740 632795	SVETLANA ALEKSANDROVA	{"phone": "+70680890702"}
0005435541068	911039	1032 251107	VLADIMIR POPOV	{"phone": "+70966110905"}
0005435541069	C7C0A6	3462 029623	YULIYA LAZAREVA	{"phone": "+70689423010"}
0005435541070	AED095	1190 880676	MIKHAIL ZHUKOV	{"email": "mikhail_zhukov.011982@postgrespro.ru", "phone": "+70464040871"}
0005435541071	AED095	3996 203600	IVAN MARTYNOV	{"email": "ivan_martynov-1964@postgrespro.ru", "phone": "+70004871828"}
0005435541072	9203B1	1258 965942	ANTON VOLKOV	{"phone": "+70846315708"}
0005435541073	0A1A9B	2215 790605	ANASTASIYA ANDREEVA	{"email": "andreeva-anastasiya_021981@postgrespro.ru", "phone": "+70875471777"}
0005435541074	E0B1D1	7026 639932	NADEZHDA MOROZOVA	{"email": "n_morozova-08031971@postgrespro.ru", "phone": "+70125741072"}
0005435541075	988744	9938 316034	ANATOLIY KAZAKOV	{"email": "anatoliy.kazakov_1971@postgrespro.ru", "phone": "+70318528072"}
0005435541076	B772E4	1750 348995	KONSTANTIN NIKITIN	{"email": "nikitin-k-18061976@postgrespro.ru", "phone": "+70642716264"}
0005435541077	F18766	2033 818128	KHALIDA SAVELEVA	{"email": "saveleva.khalida_081978@postgrespro.ru", "phone": "+70823149812"}
0005435541078	1D3282	0659 149538	NADEZHDA KOZLOVA	{"email": "n-kozlova-26051971@postgrespro.ru", "phone": "+70970745742"}
0005435541079	E9F3AF	5411 823106	VALENTINA KARPOVA	{"email": "v_karpova-1968@postgrespro.ru", "phone": "+70615497911"}
0005435541080	A57089	6927 022500	VALENTINA NOVIKOVA	{"email": "vnovikova.16091978@postgrespro.ru", "phone": "+70957321443"}
0005435541081	A57089	2120 382744	ALEKSEY BELOV	{"email": "aleksey_belov-121974@postgrespro.ru", "phone": "+70768845147"}
0005435541082	FD4C38	9958 487895	VLADIMIR BELOV	{"phone": "+70756258622"}
0005435541083	6920D5	7303 144845	ALEKSANDR IVANOV	{"email": "aleksandrivanov-101973@postgrespro.ru", "phone": "+70264283420"}
0005435541084	59C585	0491 882127	ALEKSANDR ROMANOV	{"email": "a.romanov.12121963@postgrespro.ru", "phone": "+70313987823"}
0005435541085	EBC432	8069 214133	DMITRIY DAVYDOV	{"phone": "+70488977767"}
0005435541086	F9A223	8964 590879	VIOLETTA YAKOVLEVA	{"email": "vyakovleva07041957@postgrespro.ru", "phone": "+70874425390"}
0005435541087	79E89B	9397 072013	IRINA BELOVA	{"email": "belovairina-1966@postgrespro.ru", "phone": "+70557691287"}
0005435541088	79E89B	0472 509440	YULIYA SOKOLOVA	{"email": "yuliya_sokolova_27021979@postgrespro.ru", "phone": "+70612533710"}
0005435541089	CC8733	4872 025397	ALEKSANDR VOLKOV	{"phone": "+70085207065"}
0005435541090	306A7B	0417 015596	RAISA DMITRIEVA	{"email": "r.dmitrieva.1976@postgrespro.ru", "phone": "+70915451572"}
0005435541091	306A7B	2928 194053	NATALYA RODIONOVA	{"phone": "+70643082146"}
0005435541092	A85C0F	5902 117948	YULIYA GUSEVA	{"phone": "+70645367948"}
0005435541093	A85C0F	4999 237517	ZHANNA SEMENOVA	{"phone": "+70092300228"}
0005435541094	B4CD29	2016 600287	OLGA EFREMOVA	{"phone": "+70321305197"}
0005435541095	16F1E8	3209 622001	VLADIMIR KOZLOV	{"email": "vladimirkozlov_11091973@postgrespro.ru", "phone": "+70034352776"}
0005435541096	16F1E8	9481 308933	INGA ZAYCEVA	{"email": "zayceva.inga_051971@postgrespro.ru", "phone": "+70296124183"}
0005435541097	6B507A	8604 735562	MAKSIM YAKOVLEV	{"email": "yakovlevmaksim_14021970@postgrespro.ru", "phone": "+70413935768"}
0005435541098	89C565	2773 637217	GALINA STEPANOVA	{"email": "galinastepanova.07101965@postgrespro.ru", "phone": "+70689215582"}
0005435541099	E545F0	7855 674703	VALENTINA GUSEVA	{"phone": "+70811446491"}
0005435541100	BC5136	8608 255799	LYUDMILA LEBEDEVA	{"email": "lebedeva_l13071981@postgrespro.ru", "phone": "+70151605004"}
0005435541101	AD539C	8687 314482	NATALYA ZAKHAROVA	{"phone": "+70929067608"}
0005435541102	BA72A3	8918 053568	TIMOFEY EGOROV	{"phone": "+70668473529"}
0005435541103	9A25C1	4049 084199	ALEKSANDR BELOV	{"email": "a_belov-1969@postgrespro.ru", "phone": "+70374934167"}
0005435541104	9AC945	8204 688492	EVGENIY KOROLEV	{"phone": "+70843341903"}
0005435541105	9AC945	0642 793942	VERONIKA ROMANOVA	{"email": "v.romanova1973@postgrespro.ru", "phone": "+70305382332"}
0005435541106	B53480	6728 980059	VALENTINA ILINA	{"phone": "+70104417214"}
0005435541107	5D89C5	5396 456180	LIDIYA SOROKINA	{"email": "sorokina_l_1962@postgrespro.ru", "phone": "+70301001681"}
0005435541108	8AFC3F	4366 801886	NATALYA AFANASEVA	{"email": "afanasevan-24041971@postgrespro.ru", "phone": "+70517202113"}
0005435541109	8AFC3F	9684 082466	ALEKSEY MAKAROV	{"email": "makarovaleksey.02031971@postgrespro.ru", "phone": "+70540181841"}
0005435541110	F5538B	3610 874936	GALINA ILINA	{"phone": "+70955009319"}
0005435541111	F5538B	8206 544723	EKATERINA MOROZOVA	{"email": "ekaterina-morozova15011981@postgrespro.ru", "phone": "+70074560945"}
0005435541112	D26A41	1425 635249	DMITRIY ZAYCEV	{"email": "d.zaycev-16081968@postgrespro.ru", "phone": "+70180926585"}
0005435541113	57DB58	2638 999639	LIDIYA SEMENOVA	{"email": "semenova_l.30101959@postgrespro.ru", "phone": "+70173916704"}
0005435541114	9654FC	3306 352774	VALENTINA ROMANOVA	{"phone": "+70308721481"}
0005435541115	D50D9E	8705 344099	LYUDMILA SIDOROVA	{"email": "sidorova-lyudmila_1966@postgrespro.ru", "phone": "+70530132606"}
0005435541116	D50D9E	2810 057067	NADEZHDA ANDREEVA	{"phone": "+70846293494"}
0005435541117	76F9B6	9903 963030	LIDIYA KUZMINA	{"phone": "+70746340876"}
0005435541118	76F9B6	4514 603943	ANASTASIYA ZAKHAROVA	{"phone": "+70416724678"}
0005435541119	B35628	0927 581611	IVAN TIMOFEEV	{"email": "ivan_timofeev_22061984@postgrespro.ru", "phone": "+70227053149"}
0005435541120	B35628	1005 865439	SERGEY KUZMIN	{"phone": "+70020492755"}
0005435541121	F7F2CE	4414 827010	GALINA SCHERBAKOVA	{"phone": "+70233005360"}
0005435541122	F7F2CE	4439 100754	LYUDMILA FEDOROVA	{"email": "lyudmila_fedorova_111979@postgrespro.ru", "phone": "+70110201120"}
0005435541123	F2E067	5390 985370	RIMMA MAKAROVA	{"phone": "+70731290794"}
0005435541124	F2E067	4739 870695	LYUDMILA PETROVA	{"phone": "+70239944049"}
0005435541125	6EDB45	8441 483979	IRINA GAVRILOVA	{"phone": "+70930056886"}
0005435541126	17359A	2793 583043	NATALYA TIMOFEEVA	{"phone": "+70045356394"}
0005435541127	47469B	9813 325807	SERGEY IVANOV	{"phone": "+70850714977"}
0005435541128	20795F	7093 527228	MARIYA KARPOVA	{"email": "m_karpova.071975@postgrespro.ru", "phone": "+70504191956"}
0005435541129	FC473F	6997 712915	IRINA VASILEVA	{"email": "vasilevai_03101970@postgrespro.ru", "phone": "+70726211863"}
0005435541130	39E234	9645 011194	OLESYA DENISOVA	{"email": "denisovaolesya_19061968@postgrespro.ru", "phone": "+70306132021"}
0005435541131	AA6E3C	8393 546153	SERGEY AFANASEV	{"phone": "+70845665055"}
0005435541132	B7FF41	0011 831958	VALENTIN TIMOFEEV	{"phone": "+70757299842"}
0005435541133	20EC8E	9520 413494	ANNA NAUMOVA	{"email": "naumovaa-1978@postgrespro.ru", "phone": "+70592869413"}
0005435541134	08A3E9	3938 610707	TAMARA OVCHINNIKOVA	{"email": "ovchinnikova.tamara-021983@postgrespro.ru", "phone": "+70635942385"}
0005435541135	9F69CA	7704 428970	VALENTINA DAVYDOVA	{"phone": "+70473316257"}
0005435541136	BA4F9D	3483 844474	NIKOLAY PAVLOV	{"phone": "+70481166829"}
0005435541137	48F7C7	4584 133739	SERGEY ORLOV	{"email": "s.orlov.051980@postgrespro.ru", "phone": "+70692432441"}
0005435541138	48F7C7	0286 919693	ELENA MAKAROVA	{"phone": "+70223454191"}
0005435541139	E7B96B	4382 824764	ANNA NOVIKOVA	{"phone": "+70735275808"}
0005435541140	E7B96B	9283 919117	LYUBOV KUZNECOVA	{"phone": "+70779921285"}
0005435541141	35BE1F	5416 377717	TAMARA NOVIKOVA	{"phone": "+70353169662"}
0005435541142	35BE1F	7564 802277	TATYANA POPOVA	{"email": "popovatatyana31081963@postgrespro.ru", "phone": "+70574165773"}
0005435541143	35BE1F	9287 906972	DARYA CHERNOVA	{"phone": "+70598727559"}
0005435541144	C69FF6	4075 493434	OLGA KRASNOVA	{"phone": "+70568693562"}
0005435541145	302F66	2690 343678	ELENA VLASOVA	{"phone": "+70403708941"}
0005435541146	CEAC5B	3201 869117	EKATERINA ILINA	{"email": "ekaterina-ilina_09081969@postgrespro.ru", "phone": "+70940685714"}
0005435541147	BD3CB0	9607 312909	DMITRIY KUZMIN	{"email": "kuzmind.1973@postgrespro.ru", "phone": "+70960001019"}
0005435541148	48D8BD	7064 108523	TATYANA SERGEEVA	{"email": "sergeevatatyana-1969@postgrespro.ru", "phone": "+70011666077"}
0005435541149	48D8BD	4010 974083	ELENA KULIKOVA	{"phone": "+70018678707"}
0005435541150	48A080	4127 924040	ANATOLIY ANDREEV	{"email": "andreev.a16111971@postgrespro.ru", "phone": "+70645163695"}
0005435541151	1E7DE3	7980 052417	SERGEY FEDOTOV	{"phone": "+70732041297"}
0005435541152	2F7600	1515 841658	DMITRIY SOLOVEV	{"email": "dmitriy-solovev.07021970@postgrespro.ru", "phone": "+70158130388"}
0005435541153	2F7600	1065 203657	ELENA NAUMOVA	{"email": "enaumova16091973@postgrespro.ru", "phone": "+70397419583"}
0005435541154	05EBC8	5429 243984	ELENA FROLOVA	{"phone": "+70090357119"}
0005435541155	05EBC8	7812 127158	NINA KAZAKOVA	{"email": "nina_kazakova121972@postgrespro.ru", "phone": "+70777056097"}
0005435541156	57035B	2261 697125	VLADIMIR ORLOV	{"email": "vladimir.orlov-051972@postgrespro.ru", "phone": "+70646841270"}
0005435541157	42419A	4295 354107	OLGA FROLOVA	{"phone": "+70576264711"}
0005435541158	1101BF	1233 575034	TATYANA KOROLEVA	{"email": "korolevatatyana24091967@postgrespro.ru", "phone": "+70476538763"}
0005435541159	880670	3090 229889	NATALYA FILIPPOVA	{"email": "filippova_n.26041972@postgrespro.ru", "phone": "+70509756520"}
0005435541160	4C890A	6124 569234	EKATERINA KUZNECOVA	{"phone": "+70449748555"}
0005435541161	4C890A	7325 364790	ELENA SMIRNOVA	{"email": "e.smirnova.021972@postgrespro.ru", "phone": "+70106914020"}
0005435541162	008712	0901 552970	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev_a.081972@postgrespro.ru", "phone": "+70451198105"}
0005435541163	49A438	1697 429877	YURIY CHERNOV	{"email": "yuriy.chernov16061972@postgrespro.ru", "phone": "+70696001946"}
0005435541164	F94B50	2562 783791	ALEKSEY VLASOV	{"email": "vlasov-aleksey-18051974@postgrespro.ru", "phone": "+70691563605"}
0005435541165	8148BE	6957 713952	ANTONINA AKIMOVA	{"phone": "+70549184839"}
0005435541166	B011B5	7587 665011	VIKTOR SERGEEV	{"phone": "+70094328651"}
0005435541167	BA97C9	4866 468715	TATYANA KONDRATEVA	{"phone": "+70977032408"}
0005435541168	85D8FA	5423 186373	VALERIYA MAKAROVA	{"email": "makarova_valeriya.041971@postgrespro.ru", "phone": "+70794675679"}
0005435541169	6062A7	8817 574555	LYUDMILA MAKAROVA	{"phone": "+70557051550"}
0005435541170	6062A7	3374 762025	LYUDMILA TIMOFEEVA	{"email": "timofeeva_l021974@postgrespro.ru", "phone": "+70687652990"}
0005435541171	836928	8731 390413	MARINA ISAEVA	{"email": "m_isaeva-13061969@postgrespro.ru", "phone": "+70995351814"}
0005435541172	DF917F	5564 066174	DMITRIY EGOROV	{"phone": "+70723153639"}
0005435541173	F9F0E6	8472 859672	VLADIMIR MOISEEV	{"email": "vmoiseev.1979@postgrespro.ru", "phone": "+70375849636"}
0005435541174	F9F0E6	4674 411657	SVETLANA EGOROVA	{"phone": "+70622753401"}
0005435541175	F9F0E6	2495 725008	RAISA KULIKOVA	{"email": "raisakulikova_1981@postgrespro.ru", "phone": "+70867871322"}
0005435541176	136735	1279 972478	STEPAN SOROKIN	{"email": "sorokin.s.1957@postgrespro.ru", "phone": "+70698910546"}
0005435541177	B11BBF	9061 054179	EKATERINA POLYAKOVA	{"phone": "+70803590490"}
0005435541178	FD771D	8980 475102	VLADIMIR KOZLOV	{"phone": "+70474670664"}
0005435541179	A5BBA2	1212 913540	ANNA NAUMOVA	{"email": "a-naumova_091973@postgrespro.ru", "phone": "+70770731042"}
0005435541180	8CECA2	8519 511470	VIKTOR YAKOVLEV	{"email": "yakovlev-v021977@postgrespro.ru", "phone": "+70851322581"}
0005435541181	783368	5464 900954	VYACHESLAV MELNIKOV	{"phone": "+70770716894"}
0005435541182	783368	9285 897066	RITA EFIMOVA	{"email": "efimova.rita-01011960@postgrespro.ru", "phone": "+70764425370"}
0005435541183	F53F1D	3052 412694	ANASTASIYA NAZAROVA	{"phone": "+70348785387"}
0005435541184	0BF25B	6071 419310	VASILIY MAKSIMOV	{"phone": "+70179140380"}
0005435541185	FB18F2	8741 595598	GALINA EFIMOVA	{"phone": "+70660525106"}
0005435541186	FB18F2	3445 201498	ARINA DMITRIEVA	{"phone": "+70894126205"}
0005435541187	2FB353	5968 128545	LIDIYA NIKITINA	{"email": "nikitina-l.1977@postgrespro.ru", "phone": "+70524993975"}
0005435541188	27AEB2	2159 328364	VARVARA TIMOFEEVA	{"phone": "+70950881960"}
0005435541189	77AFBE	8338 620986	MARK YAKOVLEV	{"phone": "+70397960851"}
0005435541190	77AFBE	0833 638963	RUSLAN ABRAMOV	{"email": "abramovr.1992@postgrespro.ru", "phone": "+70536379078"}
0005435541191	8BE236	4962 701568	YURIY ABRAMOV	{"phone": "+70121451262"}
0005435541192	CB43CE	2393 024081	OLGA BORISOVA	{"email": "borisova_o_18111969@postgrespro.ru", "phone": "+70381336352"}
0005435541193	CD6E93	6808 504415	NIKOLAY NOVIKOV	{"email": "nikolay_novikov.071963@postgrespro.ru", "phone": "+70359258646"}
0005435541194	CA33D8	1983 672018	VALERIY SCHERBAKOV	{"email": "scherbakov-valeriy011981@postgrespro.ru", "phone": "+70437596520"}
0005435541195	F32079	4316 066495	SERGEY SOROKIN	{"email": "sergeysorokin.091974@postgrespro.ru", "phone": "+70382447715"}
0005435541196	EB930C	4320 395761	NATALYA STEPANOVA	{"email": "stepanovan_011973@postgrespro.ru", "phone": "+70192312341"}
0005435541197	90F669	6759 740665	EVGENIY YAKOVLEV	{"email": "yakovleve-101972@postgrespro.ru", "phone": "+70309246940"}
0005435541198	24CFA7	9491 196148	EKATERINA KUZMINA	{"phone": "+70767008095"}
0005435541199	CF6C97	5500 945066	SERGEY NAUMOV	{"email": "naumov.sergey-13121974@postgrespro.ru", "phone": "+70516627469"}
0005435541200	CF6C97	7802 533647	BORIS GUSEV	{"email": "b-gusev_1975@postgrespro.ru", "phone": "+70811911721"}
0005435541201	BC4A30	0074 202134	EVGENIY TIKHONOV	{"email": "tikhonove.1982@postgrespro.ru", "phone": "+70650455439"}
0005435541202	BC4A30	9035 244559	MARINA KISELEVA	{"email": "mkiseleva_1980@postgrespro.ru", "phone": "+70281058833"}
0005435541203	CB58E0	2166 527068	TATYANA KOMAROVA	{"phone": "+70530019596"}
0005435541204	2225E1	4109 720274	NIKOLAY BARANOV	{"email": "nikolay.baranov_1967@postgrespro.ru", "phone": "+70357697255"}
0005435541205	1B5AB9	9124 108395	NIKOLAY POPOV	{"phone": "+70091497604"}
0005435541206	1041D0	2549 148274	ELENA DANILOVA	{"phone": "+70355686032"}
0005435541207	1041D0	8427 372561	VALENTINA DANILOVA	{"phone": "+70062680432"}
0005435541208	E124F7	8807 470401	ANDREY ANDREEV	{"email": "a-andreev-1981@postgrespro.ru", "phone": "+70556781170"}
0005435541209	E124F7	7791 099127	ANDREY GUSEV	{"phone": "+70089253334"}
0005435541210	5EC4E1	5143 955992	DMITRIY KUZNECOV	{"phone": "+70273437147"}
0005435541211	5EC4E1	4990 769281	ANDREY STEPANOV	{"email": "stepanov-a05061973@postgrespro.ru", "phone": "+70187037702"}
0005435541212	8CF105	0088 588428	MARIYA GUSEVA	{"phone": "+70632959501"}
0005435541213	8CF105	4569 126377	ANDREY BARANOV	{"email": "a.baranov1962@postgrespro.ru", "phone": "+70273683613"}
0005435541214	8CF105	7550 133034	KONSTANTIN MEDVEDEV	{"email": "medvedev.k.031966@postgrespro.ru", "phone": "+70734613349"}
0005435541215	75F96A	4358 863921	NADEZHDA ABRAMOVA	{"phone": "+70553797316"}
0005435541216	75F96A	8543 325175	DAMIR BONDARENKO	{"email": "dbondarenko.27061981@postgrespro.ru", "phone": "+70861954637"}
0005435541217	37620E	5380 563619	VALENTINA YAKOVLEVA	{"email": "valentinayakovleva.1973@postgrespro.ru", "phone": "+70526252923"}
0005435541218	37620E	3797 888107	YURIY DAVYDOV	{"email": "davydovy-1971@postgrespro.ru", "phone": "+70758948980"}
0005435541219	F8F8A4	8088 950902	SERGEY GAVRILOV	{"phone": "+70383945903"}
0005435541220	01041F	8656 622190	EVGENIY TARASOV	{"email": "tarasovevgeniy.021967@postgrespro.ru", "phone": "+70242967193"}
0005435541221	01041F	0509 879696	SERGEY VOROBEV	{"phone": "+70922553713"}
0005435541222	195D13	3728 521951	ROMAN SOROKIN	{"email": "sorokin_r071972@postgrespro.ru", "phone": "+70894813141"}
0005435541223	CD582C	7959 664531	MARIYA SEMENOVA	{"email": "semenova-mariya_29061971@postgrespro.ru", "phone": "+70116026546"}
0005435541224	CD582C	4141 470970	GENNADIY KUZNECOV	{"email": "gennadiy-kuznecov_1972@postgrespro.ru", "phone": "+70091138116"}
0005435541225	4E944C	5683 613976	SABINA IVANOVA	{"email": "s-ivanova-06091982@postgrespro.ru", "phone": "+70811363542"}
0005435541226	4E944C	0272 272533	IVAN NOVIKOV	{"email": "ivan.novikov_1979@postgrespro.ru", "phone": "+70638360482"}
0005435541227	1C1F30	5762 079801	LYUDMILA KUZNECOVA	{"phone": "+70271199188"}
0005435541228	C82672	7993 734245	ALEKSANDR TIKHONOV	{"phone": "+70214583215"}
0005435541229	C82672	0757 721730	VALERIY STEPANOV	{"phone": "+70500144858"}
0005435541230	E32FEC	9789 822275	MARINA PAVLOVA	{"phone": "+70246209959"}
0005435541231	4B78AE	4779 315444	MILANA KONDRATEVA	{"email": "kondrateva.milana041972@postgrespro.ru", "phone": "+70512443808"}
0005435541232	4B78AE	6071 491982	ALEVTINA GERASIMOVA	{"email": "gerasimova_alevtina1987@postgrespro.ru", "phone": "+70202684415"}
0005435541233	8F1820	8533 108472	VALENTIN NIKITIN	{"phone": "+70636231786"}
0005435541234	8F1820	2437 418757	NIKOLAY MATVEEV	{"phone": "+70117322278"}
0005435541235	D6E4F1	9371 730731	LILIYA MIRONOVA	{"phone": "+70173541882"}
0005435541236	D6E4F1	0805 955429	LILIYA IVANOVA	{"email": "liliya.ivanova.10111980@postgrespro.ru", "phone": "+70019753154"}
0005435541237	DB47CC	6523 333844	ANATOLIY FROLOV	{"phone": "+70909195037"}
0005435541238	F73335	7165 548570	SVETLANA SOROKINA	{"email": "svetlana.sorokina_1967@postgrespro.ru", "phone": "+70570764926"}
0005435541239	30CB81	0590 098948	OLGA SERGEEVA	{"email": "olga_sergeeva-17101979@postgrespro.ru", "phone": "+70478038989"}
0005435541240	00D9EF	3184 479463	ELENA ZHUKOVA	{"email": "zhukova_e-12121972@postgrespro.ru", "phone": "+70985326476"}
0005435541241	90BD64	3236 677484	EVGENIY GORBUNOV	{"phone": "+70652965241"}
0005435541242	FCC320	3709 029519	IRINA LAZAREVA	{"phone": "+70740005981"}
0005435541243	528541	4567 119574	TATYANA MIRONOVA	{"email": "t.mironova_1973@postgrespro.ru", "phone": "+70148914975"}
0005435541244	0EE035	1829 769172	OLGA BELYAEVA	{"phone": "+70597208567"}
0005435541245	0EE035	5496 708033	VALENTINA DENISOVA	{"email": "denisova-valentina_011971@postgrespro.ru", "phone": "+70273891409"}
0005435541246	1F30EC	2567 008204	RINAT ALEKSEEV	{"phone": "+70826579166"}
0005435541247	8926BE	5233 026863	ALEKSANDR VLASOV	{"email": "aleksandr-vlasov.1965@postgrespro.ru", "phone": "+70472614424"}
0005435541248	AFE92B	0208 702366	SERGEY SAVELEV	{"phone": "+70043878406"}
0005435541249	AFE92B	5440 519375	ANASTASIYA MALYSHEVA	{"phone": "+70255489817"}
0005435541250	AFE92B	1088 073078	DMITRIY KULIKOV	{"phone": "+70051981673"}
0005435541251	C36E73	4827 006757	IVAN ORLOV	{"phone": "+70984755595"}
0005435541252	C36E73	9996 918312	ANASTASIYA ILINA	{"phone": "+70376529632"}
0005435541253	C36E73	1441 655395	TATYANA MALYSHEVA	{"email": "malysheva-tatyana-07071975@postgrespro.ru", "phone": "+70320821366"}
0005435541254	06A080	4871 924717	GALINA BELYAEVA	{"email": "gbelyaeva.1968@postgrespro.ru", "phone": "+70479188626"}
0005435541255	06A080	2517 514023	LARISA SEMENOVA	{"email": "semenova_larisa.1967@postgrespro.ru", "phone": "+70556145851"}
0005435541256	7859C2	4444 982428	GALINA YAKOVLEVA	{"email": "yakovleva_galina.1965@postgrespro.ru", "phone": "+70777809647"}
0005435541257	9A470F	3782 718382	DAMIR SEMENOV	{"phone": "+70465992978"}
0005435541258	52D653	1183 097884	ANNA NAZAROVA	{"email": "nazarovaanna.1962@postgrespro.ru", "phone": "+70616900148"}
0005435541259	52D653	5129 704632	VASILIY IVANOV	{"phone": "+70042865028"}
0005435541260	5492E7	2912 103293	NIKOLAY PETROV	{"email": "petrovn_061975@postgrespro.ru", "phone": "+70041297347"}
0005435541261	5492E7	1776 075799	VLADIMIR STEPANOV	{"phone": "+70540040081"}
0005435541262	7FC94A	9958 821729	NIKOLAY ZAKHAROV	{"email": "zakharovnikolay-12051973@postgrespro.ru", "phone": "+70899438777"}
0005435541263	EB3B28	4942 201851	VLADIMIR KUZNECOV	{"email": "kuznecov.vladimir01121968@postgrespro.ru", "phone": "+70514376561"}
0005435541264	EB3B28	6581 418461	VALENTINA KOZLOVA	{"email": "kozlova_valentina_02051979@postgrespro.ru", "phone": "+70696449286"}
0005435541265	42C7C3	7731 478218	LARISA KALININA	{"email": "l.kalinina-1982@postgrespro.ru", "phone": "+70233782342"}
0005435541266	425819	6990 499339	NADEZHDA RYABOVA	{"phone": "+70841128581"}
0005435541267	69BFBA	2693 909444	MARINA MAKSIMOVA	{"phone": "+70900691163"}
0005435541268	92A117	6204 565596	EDUARD FEDOROV	{"email": "fedorov-e_051965@postgrespro.ru", "phone": "+70386646416"}
0005435541269	58C9B1	2076 308520	OKSANA FADEEVA	{"phone": "+70967644536"}
0005435541270	13F64F	2732 143509	ELENA FILATOVA	{"email": "e.filatova.12101969@postgrespro.ru", "phone": "+70462175237"}
0005435541271	13F64F	5400 740565	NIKOLAY KUZNECOV	{"email": "n.kuznecov-1964@postgrespro.ru", "phone": "+70301856288"}
0005435541272	B7741D	6151 629151	NINA KULIKOVA	{"email": "kulikova.n-1976@postgrespro.ru", "phone": "+70359243990"}
0005435541273	1A9227	7194 266131	GENNADIY IVANOV	{"phone": "+70837582067"}
0005435541274	1A9227	2098 088567	NADEZHDA SMIRNOVA	{"phone": "+70696672913"}
0005435541275	D4C23A	4784 478860	ROMAN EGOROV	{"phone": "+70462272892"}
0005435541276	820295	2329 846134	VADIM IVANOV	{"phone": "+70468479352"}
0005435541277	2D1F76	8370 400025	MIKHAIL NIKOLAEV	{"phone": "+70376541291"}
0005435541278	85F3C4	4598 263909	PETR GRIGOREV	{"email": "petr.grigorev-101968@postgrespro.ru", "phone": "+70786184400"}
0005435541279	B18B0D	5641 772961	NIKOLAY BONDARENKO	{"email": "bondarenko.nikolay.1976@postgrespro.ru", "phone": "+70023716300"}
0005435541280	B18B0D	0464 016410	NADEZHDA VOLKOVA	{"phone": "+70918932522"}
0005435541281	7F3867	8647 584905	YANINA MAKSIMOVA	{"email": "yaninamaksimova061984@postgrespro.ru", "phone": "+70613919546"}
0005435541282	C8EBFE	9569 553375	KONSTANTIN ZAYCEV	{"email": "k.zaycev_031969@postgrespro.ru", "phone": "+70774439334"}
0005435541283	C8EBFE	3924 507809	SOFIYA SEMENOVA	{"phone": "+70459257672"}
0005435541284	830672	5197 953744	LARISA KONOVALOVA	{"phone": "+70430000342"}
0005435541285	830672	3293 642304	ALEKSANDR MOROZOV	{"phone": "+70459838985"}
0005435541286	9DEE4D	8440 940789	LIDIYA ZAKHAROVA	{"phone": "+70002264654"}
0005435541287	C676D8	4323 682873	DMITRIY CHERNOV	{"phone": "+70911243508"}
0005435541288	DFB8B9	9150 450154	ZOYA POPOVA	{"email": "zoya-popova-1978@postgrespro.ru", "phone": "+70125567049"}
0005435541289	C7CFCF	1680 935457	ALEVTINA MELNIKOVA	{"phone": "+70459806282"}
0005435541290	96FC99	8147 513798	VALERIY MOROZOV	{"email": "v-morozov.071976@postgrespro.ru", "phone": "+70587951128"}
0005435541291	480F73	0457 726075	MAKSIM MOROZOV	{"phone": "+70317460195"}
0005435541292	6CBABE	4861 263457	VLADIMIR BONDARENKO	{"email": "vladimir-bondarenko.1970@postgrespro.ru", "phone": "+70680696363"}
0005435541293	6CBABE	1729 028421	EVGENIY KUZNECOV	{"email": "e_kuznecov-1968@postgrespro.ru", "phone": "+70177337752"}
0005435541294	D34E81	4041 835134	YULIYA LUKYANOVA	{"email": "lukyanova-y_091975@postgrespro.ru", "phone": "+70388595838"}
0005435541295	D34E81	4421 390653	DMITRIY NIKITIN	{"email": "nikitin_d_1974@postgrespro.ru", "phone": "+70469518219"}
0005435541296	90C1B0	6370 957798	NINA CHERNOVA	{"phone": "+70345448353"}
0005435541297	90C1B0	5336 491629	RINAT KARPOV	{"email": "r.karpov-08041972@postgrespro.ru", "phone": "+70536565984"}
0005435541298	5120D7	8888 736277	ALEKSANDR ALEKSEEV	{"email": "aleksandr.alekseev_1970@postgrespro.ru", "phone": "+70195275588"}
0005435541299	DC1F51	1688 890097	OLGA NIKITINA	{"phone": "+70793529234"}
0005435541600	E3D217	9028 594051	DMITRIY FILIPPOV	{"phone": "+70777643625"}
0005435541300	0E47A7	2830 954870	EKATERINA ZAKHAROVA	{"email": "zakharova_e-03071964@postgrespro.ru", "phone": "+70229260231"}
0005435541301	0E47A7	3967 577915	YURIY ROMANOV	{"email": "yuriy-romanov-1968@postgrespro.ru", "phone": "+70906173843"}
0005435541302	26CFF2	3402 721300	VITALIY TARASOV	{"phone": "+70835094553"}
0005435541303	26CFF2	5413 369947	YULIYA KUZMINA	{"phone": "+70607742552"}
0005435541304	963A80	5953 581885	VIKTOR VASILEV	{"email": "vvasilev_1974@postgrespro.ru", "phone": "+70282653429"}
0005435541305	DB48BD	0309 339302	IRAIDA STEPANOVA	{"email": "stepanovairaida-1975@postgrespro.ru", "phone": "+70620856679"}
0005435541306	DB48BD	8011 072732	ROMAN AFANASEV	{"email": "afanasev-r_24041976@postgrespro.ru", "phone": "+70787768082"}
0005435541307	97CEE6	7954 225434	PLATON MOROZOV	{"phone": "+70196363983"}
0005435541308	3C0CD8	0288 370874	EVGENIY ORLOV	{"phone": "+70858830964"}
0005435541309	3C0CD8	7854 103926	IRINA NIKOLAEVA	{"email": "nikolaevairina_02011978@postgrespro.ru", "phone": "+70743850673"}
0005435541310	3C0CD8	9995 179832	ANNA ILINA	{"phone": "+70083750422"}
0005435541311	C5CE11	5060 977052	ALEKSANDR BELOV	{"email": "belovaleksandr_24011967@postgrespro.ru", "phone": "+70757886297"}
0005435541312	C5CE11	6953 351853	GALINA MOROZOVA	{"email": "galina_morozova-1974@postgrespro.ru", "phone": "+70291667063"}
0005435541313	08DC97	7628 790462	ALEKSANDR IVANOV	{"phone": "+70286460012"}
0005435541314	08DC97	7946 638109	FANIYA KARPOVA	{"email": "faniya-karpova.041957@postgrespro.ru", "phone": "+70177317787"}
0005435541315	F40CA7	5396 170764	VASILIY SIDOROV	{"phone": "+70345593659"}
0005435541316	B10554	3617 067986	TAMARA RODIONOVA	{"phone": "+70724729417"}
0005435541317	5D2559	8134 097071	YULIYA MAKAROVA	{"email": "makarova.yuliya.111958@postgrespro.ru", "phone": "+70579118863"}
0005435541318	72BCBA	3469 037711	MARIYA MALYSHEVA	{"phone": "+70796828244"}
0005435541319	F8E2C1	3717 594343	LIDIYA IVANOVA	{"phone": "+70715269528"}
0005435541320	F8E2C1	3294 076336	ANASTASIYA TARASOVA	{"phone": "+70509232148"}
0005435541321	367D20	4757 913352	OLGA KOZLOVA	{"email": "olga.kozlova.1974@postgrespro.ru", "phone": "+70566246404"}
0005435541322	367D20	0685 868450	IVAN BORISOV	{"phone": "+70667055218"}
0005435541323	D132A8	6568 484105	ELENA ILINA	{"phone": "+70984002502"}
0005435541324	9B5AA2	6971 581570	ALEKSANDR IVANOV	{"email": "ivanova12021967@postgrespro.ru", "phone": "+70518054365"}
0005435541325	9B5AA2	8333 320722	ELENA KRASNOVA	{"email": "e_krasnova-101970@postgrespro.ru", "phone": "+70669195952"}
0005435541326	56A11A	6566 883047	RUSLAN FEDOTOV	{"email": "ruslan_fedotov1966@postgrespro.ru", "phone": "+70658530740"}
0005435541327	26780F	2041 516317	EVGENIYA MEDVEDEVA	{"email": "evgeniya_medvedeva_11121963@postgrespro.ru", "phone": "+70688564569"}
0005435541328	26780F	4485 631215	KONSTANTIN MIKHAYLOV	{"phone": "+70978039092"}
0005435541329	E54300	1631 425925	VALENTINA NIKOLAEVA	{"phone": "+70177177269"}
0005435541330	64467B	2076 891560	NIKOLAY FEDOROV	{"email": "fedorov_n-02041965@postgrespro.ru", "phone": "+70942595716"}
0005435541331	4A8981	6105 625732	OLGA ZHUKOVA	{"email": "o.zhukova21011963@postgrespro.ru", "phone": "+70174529337"}
0005435541332	408CF2	9429 169510	MARIYA NIKITINA	{"email": "mariya_nikitina_05051968@postgrespro.ru", "phone": "+70965322961"}
0005435541333	408CF2	7625 064496	LILIYA MATVEEVA	{"email": "l_matveeva.1970@postgrespro.ru", "phone": "+70452938632"}
0005435541334	5304D5	9919 300533	NATALYA RODIONOVA	{"email": "nrodionova-1973@postgrespro.ru", "phone": "+70412336155"}
0005435541335	195911	8894 417800	EVGENIY ISAEV	{"phone": "+70550358873"}
0005435541336	195911	7894 427728	TATYANA KISELEVA	{"email": "kiseleva-t-09071973@postgrespro.ru", "phone": "+70197179368"}
0005435541337	C550BE	0058 822938	LILIYA FILIPPOVA	{"phone": "+70657163388"}
0005435541338	C550BE	3437 047863	VLADIMIR KAZAKOV	{"email": "kazakovv-25081970@postgrespro.ru", "phone": "+70671757217"}
0005435541339	793904	9524 289102	SERGEY ZAKHAROV	{"phone": "+70832762942"}
0005435541340	267BB2	4837 017647	ALEKSANDR FILIPPOV	{"email": "aleksandr_filippov091969@postgrespro.ru", "phone": "+70466199187"}
0005435541341	01C0AF	5538 370133	VLADIMIR NAUMOV	{"phone": "+70501722881"}
0005435541342	3F85F0	7879 003746	MARINA MIRONOVA	{"email": "mironova-m.071963@postgrespro.ru", "phone": "+70240053939"}
0005435541343	689357	2702 882438	ALEKSANDR SIDOROV	{"phone": "+70865008159"}
0005435541344	0AA052	1571 073517	EKATERINA NIKOLAEVA	{"email": "nikolaeva_ekaterina_011974@postgrespro.ru", "phone": "+70588030698"}
0005435541345	76E959	0021 908703	IVAN FROLOV	{"email": "frolovi16071983@postgrespro.ru", "phone": "+70428531841"}
0005435541346	08F5E5	0985 362236	STANISLAV SOROKIN	{"email": "s_sorokin-111969@postgrespro.ru", "phone": "+70347610093"}
0005435541347	72FC74	6089 923293	TAMARA SMIRNOVA	{"email": "tamara.smirnova.1977@postgrespro.ru", "phone": "+70927090445"}
0005435541348	18B231	9648 282398	ALEKSANDR GERASIMOV	{"email": "a.gerasimov1980@postgrespro.ru", "phone": "+70182623916"}
0005435541349	A5F50F	2521 928940	PETR ALEKSEEV	{"phone": "+70320758158"}
0005435541350	A5F50F	2082 635978	IRINA ORLOVA	{"email": "irinaorlova.20121986@postgrespro.ru", "phone": "+70433472603"}
0005435541351	54AC13	2919 718649	MIKHAIL VLASOV	{"email": "vlasovmikhail-1962@postgrespro.ru", "phone": "+70170240821"}
0005435541352	54AC13	8865 541796	NATALYA BELOVA	{"phone": "+70332418803"}
0005435541353	E8E581	3856 359033	LARISA ZOTOVA	{"email": "l-zotova-08021977@postgrespro.ru", "phone": "+70444655687"}
0005435541354	B4BE11	4212 104936	LYUDMILA SIDOROVA	{"email": "l-sidorova30101970@postgrespro.ru", "phone": "+70060512209"}
0005435541355	329797	2600 886784	YANA PETROVA	{"phone": "+70964860284"}
0005435541356	329797	3366 747606	RUSHANIYA ISAEVA	{"email": "isaeva_r08061974@postgrespro.ru", "phone": "+70695554503"}
0005435541357	D85D95	9534 052594	RAMIL VASILEV	{"phone": "+70155448201"}
0005435541358	CF6145	1550 359046	NADEZHDA ZOTOVA	{"phone": "+70222720185"}
0005435541359	E24019	4116 747544	VLADIMIR EGOROV	{"email": "egorovv.021972@postgrespro.ru", "phone": "+70812051233"}
0005435541360	E177E8	6399 439300	GALINA MARTYNOVA	{"email": "galina.martynova_051970@postgrespro.ru", "phone": "+70330248761"}
0005435541416	040B6C	6100 186543	MAKSIM KONOVALOV	{"phone": "+70123802414"}
0005435541361	236DCA	5816 075231	YURIY ZAKHAROV	{"email": "zakharovy-07071975@postgrespro.ru", "phone": "+70998832675"}
0005435541362	D55602	3151 173428	NINA KULIKOVA	{"phone": "+70577307374"}
0005435541363	43CA52	9697 367438	ANNA IVANOVA	{"phone": "+70483631407"}
0005435541364	0A6628	4567 791327	VALENTINA MAKAROVA	{"email": "makarovavalentina_111976@postgrespro.ru", "phone": "+70985723002"}
0005435541365	1082EA	0719 335859	ELENA SOROKINA	{"phone": "+70978579917"}
0005435541366	DBCE0C	0912 823687	SERGEY FILIPPOV	{"email": "s.filippov.011967@postgrespro.ru", "phone": "+70930084909"}
0005435541367	627806	7864 582667	SOFIYA PETROVA	{"email": "sofiya.petrova.01081969@postgrespro.ru", "phone": "+70995055485"}
0005435541368	7DFF6B	1069 907867	MIKHAIL GORBUNOV	{"email": "m-gorbunov.30091963@postgrespro.ru", "phone": "+70915247464"}
0005435541369	7DFF6B	5789 324913	YURIY KARPOV	{"email": "y_karpov-23101978@postgrespro.ru", "phone": "+70534784300"}
0005435541370	D018AE	5639 232011	ALEKSANDR MATVEEV	{"email": "matveev-aleksandr_1973@postgrespro.ru", "phone": "+70541126280"}
0005435541371	D018AE	1730 100964	ANVAR BONDARENKO	{"phone": "+70130755623"}
0005435541372	D018AE	3344 574741	LIDIYA TIKHONOVA	{"phone": "+70399510424"}
0005435541373	091BA3	0540 629810	MIKHAIL MIKHAYLOV	{"phone": "+70364879719"}
0005435541374	8D638B	6691 905344	SVETLANA CHERNOVA	{"email": "chernovasvetlana09111971@postgrespro.ru", "phone": "+70118796927"}
0005435541375	8D638B	5616 242557	VASILIY ZHURAVLEV	{"phone": "+70659912241"}
0005435541376	8D638B	5941 987380	EDUARD PETROV	{"email": "eduardpetrov_1961@postgrespro.ru", "phone": "+70411120684"}
0005435541377	7E175F	3561 859966	NINA NIKITINA	{"email": "ninanikitina041979@postgrespro.ru", "phone": "+70342383457"}
0005435541378	7E175F	2790 532727	OLGA KOLESNIKOVA	{"phone": "+70932516248"}
0005435541379	CEC228	7369 172052	DMITRIY OSIPOV	{"email": "d-osipov-22021982@postgrespro.ru", "phone": "+70762745635"}
0005435541380	CB741C	3896 696177	ALEKSANDR MAKSIMOV	{"email": "a.maksimov.26101984@postgrespro.ru", "phone": "+70648282286"}
0005435541381	CB741C	2521 315573	ANZHELIKA IVANOVA	{"email": "ivanova-a071983@postgrespro.ru", "phone": "+70578105733"}
0005435541382	10EA49	1122 913491	ALFIYA KAZAKOVA	{"email": "alfiya.kazakova.03051974@postgrespro.ru", "phone": "+70254380605"}
0005435541383	582666	3904 712298	SERGEY OSIPOV	{"phone": "+70988171968"}
0005435541384	A4C948	0127 385999	NATALYA KUZNECOVA	{"phone": "+70962261203"}
0005435541385	A4C948	1597 195339	NADEZHDA RODIONOVA	{"phone": "+70212759850"}
0005435541386	6A1ABC	8711 388105	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov01091974@postgrespro.ru", "phone": "+70998979821"}
0005435541387	6A1ABC	2428 642463	VLADIMIR NIKOLAEV	{"email": "nikolaev.v-26081984@postgrespro.ru", "phone": "+70252501716"}
0005435541388	CB3F7B	7094 200376	GULFIYA NIKOLAEVA	{"phone": "+70320131184"}
0005435541389	CB3F7B	1374 460800	KRISTINA VOLKOVA	{"email": "volkova-kristina_11021974@postgrespro.ru", "phone": "+70689287562"}
0005435541390	368080	1571 545379	IRINA ALEKSANDROVA	{"email": "irina_aleksandrova.03041973@postgrespro.ru", "phone": "+70270647319"}
0005435541391	FA2FB4	2636 500594	ALEVTINA VOROBEVA	{"email": "alevtina.vorobeva.091980@postgrespro.ru", "phone": "+70787966355"}
0005435541392	DE4173	3884 757946	NATALIYA KAZAKOVA	{"email": "nataliya-kazakova-26061970@postgrespro.ru", "phone": "+70882395918"}
0005435541393	7508C7	0689 187322	VLADIMIR ABRAMOV	{"phone": "+70925855018"}
0005435541394	9E8686	5468 260464	IBRAGIM TARASOV	{"email": "tarasov_ibragim27041967@postgrespro.ru", "phone": "+70843458178"}
0005435541395	778159	2094 255713	EGOR ANTONOV	{"phone": "+70986603548"}
0005435541396	628F10	4614 925041	SERGEY ISAEV	{"email": "sergey-isaev-25081973@postgrespro.ru", "phone": "+70348210915"}
0005435541397	D91D8B	9895 871810	ELIZAVETA ABRAMOVA	{"email": "abramova_elizaveta20041959@postgrespro.ru", "phone": "+70661533572"}
0005435541398	6ADF19	3829 372789	LYUBOV ALEKSEEVA	{"email": "lyubov.alekseeva.31031983@postgrespro.ru", "phone": "+70192127884"}
0005435541399	6ADF19	7976 697459	MARINA MIKHAYLOVA	{"phone": "+70700034116"}
0005435541400	30BAD2	3083 458911	ALEKSANDR FEDOROV	{"phone": "+70088428353"}
0005435541401	D96BFA	8014 974092	EVA KUZMINA	{"phone": "+70808189112"}
0005435541402	D96BFA	7581 131151	ELENA ARKHIPOVA	{"email": "arkhipovae.02061974@postgrespro.ru", "phone": "+70257178047"}
0005435541403	78BD6E	3620 905356	SERGEY FILIPPOV	{"email": "sergeyfilippov.05081975@postgrespro.ru", "phone": "+70189085867"}
0005435541404	7B273D	7319 545081	DANIIL NIKITIN	{"email": "daniil.nikitin-111977@postgrespro.ru", "phone": "+70628607816"}
0005435541405	7B273D	1777 728564	LYUBOV ZHUKOVA	{"email": "zhukova.l.1971@postgrespro.ru", "phone": "+70365560211"}
0005435541406	DF33E2	5870 679502	ROZA FROLOVA	{"phone": "+70946740167"}
0005435541407	DF33E2	6431 779819	ALI GAVRILOV	{"phone": "+70745012892"}
0005435541408	9C01DA	5645 786284	SERGEY IVANOV	{"phone": "+70780550385"}
0005435541409	06939E	7600 152418	ELENA EFIMOVA	{"phone": "+70935016460"}
0005435541410	06939E	7873 743101	VYACHESLAV MIRONOV	{"email": "vyacheslav.mironov-111963@postgrespro.ru", "phone": "+70654550881"}
0005435541411	D43CDB	7190 061772	ELENA VASILEVA	{"email": "evasileva_081973@postgrespro.ru", "phone": "+70288737283"}
0005435541412	D43CDB	6794 798948	EKATERINA KUZNECOVA	{"email": "ekaterinakuznecova16121974@postgrespro.ru", "phone": "+70681807467"}
0005435541413	8A7E32	5090 475633	ALEKSEY NAZAROV	{"email": "a_nazarov.01011970@postgrespro.ru", "phone": "+70614412030"}
0005435541414	F37FFC	8371 149337	TATYANA NIKIFOROVA	{"email": "tatyana.nikiforova1986@postgrespro.ru", "phone": "+70236588167"}
0005435541415	305DBA	2812 157444	IRINA ZAKHAROVA	{"phone": "+70642673675"}
0005435541417	7A7219	5696 724658	EKATERINA CHERNOVA	{"email": "e-chernova-051961@postgrespro.ru", "phone": "+70640220947"}
0005435541418	0806AC	8676 887064	EVGENIY NIKITIN	{"phone": "+70310706735"}
0005435541419	F5908D	6274 183381	ALEKSEY GERASIMOV	{"email": "a_gerasimov.27031974@postgrespro.ru", "phone": "+70163821907"}
0005435541420	29E499	6334 068364	MARIYA NESTEROVA	{"phone": "+70508424138"}
0005435541421	A3FFEF	2816 675122	OLESYA ZHUKOVA	{"email": "olesya.zhukova.021975@postgrespro.ru", "phone": "+70862354885"}
0005435541422	FD036E	4613 608668	VALENTIN BARANOV	{"phone": "+70402906617"}
0005435541423	FD036E	5567 543773	VASILIY MATVEEV	{"phone": "+70095191357"}
0005435541424	7A27CD	9287 187301	DANIIL BARANOV	{"phone": "+70835881637"}
0005435541425	EEDD65	8059 559054	NATALYA YAKOVLEVA	{"phone": "+70092154908"}
0005435541426	9CAFA5	9952 667039	IVAN CHERNOV	{"phone": "+70115130621"}
0005435541427	9CAFA5	1835 487740	EKATERINA SOROKINA	{"phone": "+70553276713"}
0005435541428	C80DC1	4616 242617	ALEKSANDR GAVRILOV	{"email": "aleksandr-gavrilov.02081974@postgrespro.ru", "phone": "+70439920716"}
0005435541429	C80DC1	4865 385487	GENNADIY IVANOV	{"email": "gennadiy-ivanov.15031970@postgrespro.ru", "phone": "+70918494011"}
0005435541430	A304F0	0342 580053	DANIIL SOLOVEV	{"email": "solovev.daniil.24121980@postgrespro.ru", "phone": "+70115422582"}
0005435541431	49EFE0	6384 896692	ELENA KOZLOVA	{"email": "elena-kozlova20081976@postgrespro.ru", "phone": "+70418348519"}
0005435541432	8047EC	0537 033567	YURIY MELNIKOV	{"phone": "+70162658395"}
0005435541433	BFA29E	9423 798041	TATYANA BELOVA	{"phone": "+70967458827"}
0005435541434	1C3457	7802 846485	NATALYA NESTEROVA	{"email": "n-nesterova-17101969@postgrespro.ru", "phone": "+70010617992"}
0005435541435	1C3457	1567 557497	IVAN SOLOVEV	{"email": "i-solovev121978@postgrespro.ru", "phone": "+70518011940"}
0005435541436	436424	3498 300604	DARYA VLASOVA	{"email": "d-vlasova.26061970@postgrespro.ru", "phone": "+70522658570"}
0005435541437	436424	2587 587218	SVETLANA FILIPPOVA	{"phone": "+70432097121"}
0005435541438	82BFAF	6614 666054	DMITRIY OSIPOV	{"phone": "+70379437386"}
0005435541439	C2FC0B	5109 702080	ALBERT PAVLOV	{"phone": "+70319371631"}
0005435541440	637449	1118 773453	SAVELIY ZAYCEV	{"phone": "+70002748900"}
0005435541441	6A9ABE	6117 882666	VYACHESLAV BORISOV	{"email": "vborisov.041970@postgrespro.ru", "phone": "+70226735983"}
0005435541442	4D8FDD	9515 684129	ALEKSEY MAKAROV	{"email": "makarov-a061960@postgrespro.ru", "phone": "+70882446646"}
0005435541443	4D8FDD	9454 804874	NIKOLAY ABRAMOV	{"email": "abramov_n-051978@postgrespro.ru", "phone": "+70198609048"}
0005435541444	5B9900	7466 685200	ILYA SOROKIN	{"email": "i-sorokin_27081963@postgrespro.ru", "phone": "+70730774569"}
0005435541445	5B9900	4389 614579	TATYANA FEDOROVA	{"phone": "+70879429174"}
0005435541446	41D11A	7610 186494	ARSENIY SERGEEV	{"email": "asergeev-101974@postgrespro.ru", "phone": "+70689171143"}
0005435541447	81710B	4088 864166	DARYA IVANOVA	{"email": "daryaivanova_041973@postgrespro.ru", "phone": "+70859725349"}
0005435541448	81710B	8806 410272	LEONID KUZMIN	{"email": "l.kuzmin-1975@postgrespro.ru", "phone": "+70758501489"}
0005435541449	EA3F5C	9561 433098	LIDIYA BELYAEVA	{"phone": "+70467175659"}
0005435541450	DF311A	4966 886417	GULNARA MIRONOVA	{"email": "mironova.gulnara.041975@postgrespro.ru", "phone": "+70045589616"}
0005435541451	A2A4BC	8774 536637	YURIY FROLOV	{"email": "yfrolov_111976@postgrespro.ru", "phone": "+70048165382"}
0005435541452	A2A4BC	9532 422184	GENNADIY SEMENOV	{"email": "semenov-g.051971@postgrespro.ru", "phone": "+70778650705"}
0005435541453	1D0F49	3961 863225	OLGA GORBUNOVA	{"phone": "+70869675997"}
0005435541454	8CEF5B	3407 149497	TATYANA OVCHINNIKOVA	{"phone": "+70255968521"}
0005435541455	C696B7	9907 107100	VENERA EFIMOVA	{"email": "v-efimova-081986@postgrespro.ru", "phone": "+70825923344"}
0005435541456	358CA0	6235 531638	OKSANA NIKITINA	{"email": "nikitinaoksana1972@postgrespro.ru", "phone": "+70456522846"}
0005435541457	358CA0	3478 103608	MARINA SMIRNOVA	{"email": "marinasmirnova031978@postgrespro.ru", "phone": "+70111614903"}
0005435541458	68D2AE	1491 657107	IRINA NOVIKOVA	{"email": "i_novikova.101971@postgrespro.ru", "phone": "+70742818851"}
0005435541459	68D2AE	2453 470950	GYUZEL LUKYANOVA	{"phone": "+70203532651"}
0005435541460	0A5805	3343 692964	VIKTOR MATVEEV	{"phone": "+70604730129"}
0005435541461	961FD0	1196 519486	ELENA FILATOVA	{"email": "filatovaelena.28101974@postgrespro.ru", "phone": "+70814521736"}
0005435541462	961FD0	9242 580771	YULIYA GORBUNOVA	{"email": "gorbunovay121981@postgrespro.ru", "phone": "+70401256341"}
0005435541463	961FD0	3094 210407	ALEKSANDR MAKAROV	{"email": "makarova.011969@postgrespro.ru", "phone": "+70097658730"}
0005435541464	6D3675	8300 011256	GALINA RODIONOVA	{"phone": "+70285339420"}
0005435541465	51697B	2387 258800	GALINA VLASOVA	{"phone": "+70405803727"}
0005435541466	FA0B3B	7441 078846	ARTEM VLASOV	{"phone": "+70298898105"}
0005435541467	FA0B3B	5356 149632	SERGEY ZAYCEV	{"email": "sergey.zaycev_1971@postgrespro.ru", "phone": "+70216656188"}
0005435541468	FA0B3B	7857 417790	TAMARA ANTONOVA	{"email": "tantonova-1970@postgrespro.ru", "phone": "+70831560781"}
0005435541469	09104E	7531 094348	PELAGEYA FADEEVA	{"phone": "+70552641190"}
0005435541470	09104E	8031 303777	EVGENIYA MATVEEVA	{"phone": "+70037904161"}
0005435541471	0AA1F2	2762 904027	INNA MELNIKOVA	{"phone": "+70610060530"}
0005435541472	0AA1F2	5750 764241	DANIIL KRASNOV	{"phone": "+70016648995"}
0005435541473	BCAB76	3238 327302	EVGENIYA GAVRILOVA	{"email": "gavrilovaevgeniya.051971@postgrespro.ru", "phone": "+70058092121"}
0005435541474	33BED7	8650 737873	ALEKSANDR VASILEV	{"phone": "+70627485668"}
0005435541475	80C9C5	8033 614772	TIMOFEY NIKOLAEV	{"phone": "+70803651427"}
0005435541476	3919EA	5958 534008	EVGENIY KRASNOV	{"phone": "+70600350792"}
0005435541477	BB6CAD	5891 763084	LIDIYA PAVLOVA	{"email": "pavlova_l.031970@postgrespro.ru", "phone": "+70881784206"}
0005435541478	B36814	5949 363240	ALEKSANDR ABRAMOV	{"email": "abramov_aleksandr101972@postgrespro.ru", "phone": "+70670365892"}
0005435541479	B36814	4491 169943	ALEKSANDR ABRAMOV	{"email": "abramov.a1987@postgrespro.ru", "phone": "+70588247434"}
0005435541480	3ABA17	9340 763091	VLADIMIR POPOV	{"email": "popov.vladimir-22081980@postgrespro.ru", "phone": "+70164581453"}
0005435541481	3ABA17	6747 839103	SABINA PAVLOVA	{"phone": "+70385995648"}
0005435541482	092386	2582 322427	NADEZHDA ZHUKOVA	{"phone": "+70422173474"}
0005435541483	DBAE29	6919 079875	TAMARA SOROKINA	{"phone": "+70910646241"}
0005435541484	E6E5F8	3879 805779	NINA SOROKINA	{"phone": "+70427417435"}
0005435541485	23EC47	4846 576059	IRINA KALININA	{"phone": "+70481479875"}
0005435541486	0DDBFB	4586 598725	OLGA PAVLOVA	{"phone": "+70391794655"}
0005435541487	67FBC9	4214 179908	ARKADIY FEDOROV	{"phone": "+70264225013"}
0005435541488	C2633A	3202 785457	OLGA BOGDANOVA	{"email": "olga-bogdanova1975@postgrespro.ru", "phone": "+70303109639"}
0005435541489	AB3582	2278 627949	VALERIY SOLOVEV	{"email": "solovev.valeriy17081968@postgrespro.ru", "phone": "+70102791761"}
0005435541490	D301DD	8943 081359	ARTEM ROMANOV	{"email": "romanova-05051967@postgrespro.ru", "phone": "+70765462428"}
0005435541491	D301DD	3950 554634	NATALYA POLYAKOVA	{"phone": "+70329051052"}
0005435541492	D301DD	4218 089936	NADEZHDA STEPANOVA	{"email": "n_stepanova_14121974@postgrespro.ru", "phone": "+70504193654"}
0005435541493	D301DD	4724 377503	ANDREY SMIRNOV	{"email": "a-smirnov.18101963@postgrespro.ru", "phone": "+70268673049"}
0005435541494	CA1968	9287 010494	SERGEY VASILEV	{"phone": "+70342317913"}
0005435541495	F21FBA	1851 333673	SVETLANA ANDREEVA	{"phone": "+70814479015"}
0005435541496	684B24	6166 226678	LEONID MOROZOV	{"email": "leonid_morozov_091968@postgrespro.ru", "phone": "+70748387562"}
0005435541497	9AC17D	2191 661942	ALEKSEY OSIPOV	{"email": "aleksey_osipov061984@postgrespro.ru", "phone": "+70214950146"}
0005435541498	9AC17D	0930 500949	ANDREY MAKAROV	{"phone": "+70511874653"}
0005435541499	333CCB	5881 158994	VLADIMIR ILIN	{"phone": "+70652539320"}
0005435541500	333CCB	9095 312116	NATALIYA ANDREEVA	{"email": "nataliya.andreeva-1972@postgrespro.ru", "phone": "+70726960142"}
0005435541501	700153	2121 219242	DMITRIY SCHERBAKOV	{"email": "dscherbakov.111962@postgrespro.ru", "phone": "+70232134129"}
0005435541502	8AB615	6465 246972	GRIGORIY BORISOV	{"phone": "+70111129612"}
0005435541503	5C5989	6880 670097	DIANA OSIPOVA	{"phone": "+70452957009"}
0005435541504	96F43C	7825 165166	ALEKSANDR GRIGOREV	{"phone": "+70082391889"}
0005435541505	8F29EF	7376 523350	SVETLANA KUZMINA	{"email": "s.kuzmina_071968@postgrespro.ru", "phone": "+70288498041"}
0005435541506	810CEF	4912 457387	ROMAN MIKHAYLOV	{"phone": "+70220933033"}
0005435541507	7FD037	2829 907324	GALINA KUDRYASHOVA	{"email": "galinakudryashova-22111965@postgrespro.ru", "phone": "+70611710647"}
0005435541508	1D5EDE	2793 450713	NIKOLAY ORLOV	{"email": "orlov_n-1980@postgrespro.ru", "phone": "+70855090914"}
0005435541509	92EECE	4165 336158	LYUDMILA TARASOVA	{"phone": "+70478569064"}
0005435541510	861131	4842 002800	OLEG KARPOV	{"email": "o-karpov_13051961@postgrespro.ru", "phone": "+70477880069"}
0005435541511	06C746	6707 220575	ELENA VOLKOVA	{"email": "e.volkova.1977@postgrespro.ru", "phone": "+70923164141"}
0005435541512	06C746	6575 762661	PETR BORISOV	{"email": "p-borisov-1961@postgrespro.ru", "phone": "+70326362828"}
0005435541513	1C89DE	2094 479761	TAISIYA IVANOVA	{"email": "t.ivanova.31071961@postgrespro.ru", "phone": "+70587596054"}
0005435541514	1C89DE	3712 012177	IRINA ALEKSEEVA	{"phone": "+70793177833"}
0005435541515	4E632A	3343 244777	SVETLANA MOROZOVA	{"phone": "+70487077939"}
0005435541516	FFE31C	8717 747092	VLADIMIR MAKAROV	{"phone": "+70467540840"}
0005435541517	2AFB3A	8063 809541	SERGEY ANDREEV	{"phone": "+70726808780"}
0005435541518	AEF890	9357 675633	INESSA ROMANOVA	{"email": "romanova-inessa1971@postgrespro.ru", "phone": "+70753577716"}
0005435541519	AEF890	3330 134817	ELENA DAVYDOVA	{"phone": "+70406172706"}
0005435541520	8C8E25	9807 830238	OKSANA LOGINOVA	{"phone": "+70156006557"}
0005435541521	8C8E25	5590 016371	ALEKSANDR SERGEEV	{"phone": "+70062466093"}
0005435541522	AE135D	8466 782862	DANILA ZAKHAROV	{"phone": "+70844230667"}
0005435541523	D43E1A	8459 950975	ANDREY GAVRILOV	{"phone": "+70977430806"}
0005435541524	D43E1A	2397 020936	DMITRIY IVANOV	{"email": "dmitriy_ivanov.1984@postgrespro.ru", "phone": "+70466693467"}
0005435541525	B1A99A	8725 492082	SERGEY MAKAROV	{"email": "makarov-s111973@postgrespro.ru", "phone": "+70560569361"}
0005435541526	830EBA	8557 698083	OLGA MARTYNOVA	{"phone": "+70453210184"}
0005435541527	BFDD24	5698 398099	ALEKSEY CHERNOV	{"email": "aleksey-chernov-071985@postgrespro.ru", "phone": "+70407448957"}
0005435541528	6C148C	9764 797729	ALEKSEY DMITRIEV	{"phone": "+70336622235"}
0005435541529	6C148C	1909 014392	RASHIT KUZNECOV	{"phone": "+70185602212"}
0005435541530	992413	7799 308056	OKSANA NIKOLAEVA	{"phone": "+70646832175"}
0005435541531	992413	2866 503995	OLGA MIRONOVA	{"phone": "+70987970156"}
0005435541532	992413	5451 825941	VIKTOR ZAYCEV	{"email": "zaycev-v-011971@postgrespro.ru", "phone": "+70536876734"}
0005435541533	E8831A	9502 747884	PAVEL EGOROV	{"email": "p.egorov-1980@postgrespro.ru", "phone": "+70427096063"}
0005435541534	D93027	4528 656786	VASILIY SEMENOV	{"email": "semenov-vasiliy121974@postgrespro.ru", "phone": "+70118046055"}
0005435541535	D93027	6984 697284	VLADIMIR IVANOV	{"email": "ivanovv.08101966@postgrespro.ru", "phone": "+70742229399"}
0005435541536	FEFE67	2851 543808	ELENA FEDOROVA	{"phone": "+70913488476"}
0005435541537	C0953A	9999 038581	TAMARA SCHERBAKOVA	{"email": "t_scherbakova06041977@postgrespro.ru", "phone": "+70812754340"}
0005435541538	C0953A	0767 167031	ALEKSEY EGOROV	{"phone": "+70620715222"}
0005435541539	F6295D	5335 073724	ZOYA BELOVA	{"phone": "+70033772240"}
0005435541540	FCA820	4403 913432	MARAT EGOROV	{"email": "marat.egorov-1981@postgrespro.ru", "phone": "+70317604718"}
0005435541541	2002C8	7332 832454	GALINA ILINA	{"email": "gilina-22051973@postgrespro.ru", "phone": "+70614309374"}
0005435541542	BC55E2	8561 258708	NATALYA AKIMOVA	{"email": "n-akimova021968@postgrespro.ru", "phone": "+70811269645"}
0005435541543	40F86E	1812 915421	IGOR NIKOLAEV	{"phone": "+70189370116"}
0005435541544	5022FC	0139 602838	DMITRIY IVANOV	{"phone": "+70578850335"}
0005435541545	5022FC	5422 531025	ALEKSANDR SMIRNOV	{"phone": "+70864091890"}
0005435541546	4A7413	7025 228601	ANNA ANDREEVA	{"email": "andreeva_anna20111986@postgrespro.ru", "phone": "+70047114239"}
0005435541547	79A423	7114 978248	NATALYA VLASOVA	{"email": "vlasova-n-1977@postgrespro.ru", "phone": "+70159154438"}
0005435541548	033BE8	9739 285937	VLADIMIR KONOVALOV	{"email": "vladimirkonovalov_27061969@postgrespro.ru", "phone": "+70587972706"}
0005435541549	033BE8	9230 556020	ALEKSANDR NAUMOV	{"email": "naumovaleksandr-15041970@postgrespro.ru", "phone": "+70841379065"}
0005435541550	143595	0948 850488	PETR MAKSIMOV	{"phone": "+70877395206"}
0005435541551	3050F0	6106 070647	NIKOLAY FEDOROV	{"email": "n-fedorov.22041974@postgrespro.ru", "phone": "+70062046642"}
0005435541552	F4A7E5	8328 774364	LIDIYA MOROZOVA	{"phone": "+70920600614"}
0005435541553	52677B	2774 220568	ANNA STEPANOVA	{"email": "a_stepanova1963@postgrespro.ru", "phone": "+70147238551"}
0005435541554	52677B	3355 261968	OLEG ANTONOV	{"phone": "+70200835060"}
0005435541555	DA80BB	5724 459419	ELENA GORBUNOVA	{"phone": "+70735793874"}
0005435541556	DA80BB	5420 490258	RIFAT NIKITIN	{"phone": "+70770195239"}
0005435541557	AACB9D	7635 182989	MAKSIM STEPANOV	{"email": "m-stepanov04121970@postgrespro.ru", "phone": "+70832699502"}
0005435541558	91118F	8862 006569	ELENA IVANOVA	{"email": "ivanova-e_041970@postgrespro.ru", "phone": "+70638383917"}
0005435541559	2CE28E	2424 132882	SERGEY VOLKOV	{"email": "sergey_volkov-1976@postgrespro.ru", "phone": "+70999242934"}
0005435541560	52F869	8699 858174	ANDREY TIMOFEEV	{"phone": "+70971956591"}
0005435541561	1797DE	7944 968799	LYUDMILA SEMENOVA	{"email": "l_semenova.06111971@postgrespro.ru", "phone": "+70042627742"}
0005435541562	86DDE6	1726 741973	ROMAN GERASIMOV	{"email": "gerasimov_r_1968@postgrespro.ru", "phone": "+70542144751"}
0005435541563	0FD8A7	4428 214251	SERGEY SIDOROV	{"phone": "+70683237902"}
0005435541564	2835AA	6795 057714	IVAN SOROKIN	{"phone": "+70316279654"}
0005435541565	D3B712	6529 954778	VLADIMIR ANDREEV	{"email": "v-andreev_1962@postgrespro.ru", "phone": "+70278175356"}
0005435541566	D3B712	7358 132212	NIKOLAY YAKOVLEV	{"phone": "+70369117885"}
0005435541567	A61CA1	5075 440916	ALEKSANDR SOROKIN	{"email": "a.sorokin_051969@postgrespro.ru", "phone": "+70666327016"}
0005435541568	A61CA1	9280 649997	VERA TITOVA	{"email": "titovavera_1977@postgrespro.ru", "phone": "+70916562185"}
0005435541569	D07267	0328 138142	DARYA MATVEEVA	{"email": "matveeva_darya111965@postgrespro.ru", "phone": "+70884856680"}
0005435541570	C47F69	7211 864320	VASILIY SCHERBAKOV	{"phone": "+70931884052"}
0005435541571	069FF1	1965 993924	VLADIMIR ILIN	{"email": "v.ilin_1983@postgrespro.ru", "phone": "+70544879725"}
0005435541572	5A9A38	0782 286442	VITALIY KRASNOV	{"phone": "+70360251337"}
0005435541573	D7B443	2046 057322	OLGA FADEEVA	{"email": "o_fadeeva-111964@postgrespro.ru", "phone": "+70323737935"}
0005435541574	38B6C1	0277 273494	LYUDMILA VOLKOVA	{"email": "volkovalyudmila_021965@postgrespro.ru", "phone": "+70491664646"}
0005435541575	8AA934	7939 440802	ANTONINA KAZAKOVA	{"email": "kazakova-antonina_06011973@postgrespro.ru", "phone": "+70235403218"}
0005435541576	A47EBE	6793 430563	VLADIMIR SOLOVEV	{"phone": "+70000709856"}
0005435541577	715019	9113 253936	VALENTINA KISELEVA	{"phone": "+70459911197"}
0005435541578	B35E87	5557 027885	SVETLANA ROMANOVA	{"email": "s_romanova_111982@postgrespro.ru", "phone": "+70095087496"}
0005435541579	98E5DE	6283 554866	EVA VASILEVA	{"email": "evavasileva28041975@postgrespro.ru", "phone": "+70180675292"}
0005435541580	98E5DE	5781 977052	DMITRIY NOVIKOV	{"email": "d.novikov-09051965@postgrespro.ru", "phone": "+70191938516"}
0005435541581	FF43D9	4270 883079	ANASTASIYA KOROLEVA	{"email": "a_koroleva.031972@postgrespro.ru", "phone": "+70255846142"}
0005435541582	B7B47D	4377 701818	LYUDMILA FILIPPOVA	{"email": "lyudmilafilippova_1971@postgrespro.ru", "phone": "+70511354940"}
0005435541583	0B31F6	5965 978252	ELENA KUZMINA	{"email": "kuzmina.e_1969@postgrespro.ru", "phone": "+70833563240"}
0005435541584	26C014	3529 329809	ROZA DANILOVA	{"phone": "+70895718675"}
0005435541585	870BAD	8293 860615	ARSENIY DAVYDOV	{"email": "arseniy_davydov.11021985@postgrespro.ru", "phone": "+70606108655"}
0005435541586	03D9ED	5516 858055	DARYA MAKAROVA	{"phone": "+70429859227"}
0005435541587	03D9ED	9663 743920	ELENA POPOVA	{"email": "popova.elena-1961@postgrespro.ru", "phone": "+70376394985"}
0005435541588	EBD283	0298 502005	YULIYA BOGDANOVA	{"phone": "+70469369995"}
0005435541589	EBD283	6405 719781	SERGEY KUDRYASHOV	{"email": "kudryashovs-091959@postgrespro.ru", "phone": "+70752332705"}
0005435541590	EBD283	8014 199738	IRINA KAZAKOVA	{"phone": "+70021246373"}
0005435541591	CC5295	8696 203617	NADEZHDA EFREMOVA	{"phone": "+70202726375"}
0005435541592	5E02F5	2972 522974	DAMIR FROLOV	{"email": "dfrolov_021974@postgrespro.ru", "phone": "+70724572777"}
0005435541593	FE4014	6197 272597	OKSANA NESTEROVA	{"phone": "+70263331824"}
0005435541594	86E5E9	3253 314299	ALEKSANDR GAVRILOV	{"phone": "+70586641815"}
0005435541595	86E5E9	2443 544799	LYUBOV ZAYCEVA	{"email": "l-zayceva031961@postgrespro.ru", "phone": "+70102003859"}
0005435541596	86E5E9	6814 814663	ELENA AKIMOVA	{"email": "akimova_elena_091971@postgrespro.ru", "phone": "+70151567140"}
0005435541597	3C317A	1622 564930	ANTON IVANOV	{"phone": "+70322719216"}
0005435541598	BC659A	2360 108587	ALEKSANDR PETROV	{"phone": "+70876618176"}
0005435541599	E3D217	5954 650166	RAMIS KARPOV	{"phone": "+70210111511"}
0005435541601	BFAD6F	4486 230194	ANASTASIYA KONOVALOVA	{"email": "anastasiya.konovalova.031971@postgrespro.ru", "phone": "+70014204009"}
0005435541602	BFAD6F	5834 098632	ALEKSEY SMIRNOV	{"phone": "+70504832201"}
0005435541603	8C8D10	3525 699350	VALERIY VOROBEV	{"email": "valeriyvorobev_1976@postgrespro.ru", "phone": "+70414468257"}
0005435541604	8C8D10	8885 777097	ROMAN ALEKSEEV	{"phone": "+70042971795"}
0005435541605	8C8D10	6097 839335	ALENA KONOVALOVA	{"phone": "+70146935932"}
0005435541606	5FFE35	1026 615051	VALERIY KUZNECOV	{"phone": "+70666402622"}
0005435541607	5FFE35	2699 837633	SERGEY SOKOLOV	{"phone": "+70827573152"}
0005435541608	D1EA72	3190 242255	ELENA DAVYDOVA	{"email": "e.davydova_091958@postgrespro.ru", "phone": "+70175417271"}
0005435541609	5B9271	2451 635251	DMITRIY EGOROV	{"email": "egorov-dmitriy011977@postgrespro.ru", "phone": "+70119393478"}
0005435541610	B4D5D1	0334 430136	VALERIY SOKOLOV	{"email": "sokolov_valeriy_011981@postgrespro.ru", "phone": "+70115440458"}
0005435541611	B4D5D1	0782 753675	MIKHAIL SHEVCHENKO	{"email": "mikhail-shevchenko051971@postgrespro.ru", "phone": "+70505489855"}
0005435541612	CACAA8	2589 584598	LYUDMILA KUZMINA	{"email": "kuzmina-l_1972@postgrespro.ru", "phone": "+70556780276"}
0005435541613	35E8E6	6408 087762	ARTEM NIKOLAEV	{"phone": "+70594327365"}
0005435541614	35E8E6	4100 782745	ANDREY MEDVEDEV	{"email": "andreymedvedev.091957@postgrespro.ru", "phone": "+70192543573"}
0005435541615	D61848	2546 772278	NADEZHDA EFREMOVA	{"email": "efremova_n_01121976@postgrespro.ru", "phone": "+70012740721"}
0005435541616	25A3B5	6013 503163	ILYA TIKHONOV	{"phone": "+70093905209"}
0005435541617	25A3B5	5712 897524	TATYANA GAVRILOVA	{"phone": "+70122379427"}
0005435541618	25A3B5	7583 803716	EVELINA NIKOLAEVA	{"phone": "+70617904709"}
0005435541619	034C3D	3168 095849	SVETLANA MATVEEVA	{"phone": "+70321368516"}
0005435541620	FCE874	2261 978899	ALEKSANDR ILIN	{"phone": "+70875149880"}
0005435541621	93972B	4599 721358	MAKSIM BORISOV	{"email": "maksim.borisov_1973@postgrespro.ru", "phone": "+70581115937"}
0005435541622	00094B	6505 601390	TATYANA ILINA	{"email": "ilina-tatyana1971@postgrespro.ru", "phone": "+70965748860"}
0005435541623	212591	2069 612063	MARIYA AKIMOVA	{"phone": "+70151846676"}
0005435541624	14362B	0663 086420	ANNA POLYAKOVA	{"email": "anna_polyakova071979@postgrespro.ru", "phone": "+70638282033"}
0005435541625	14362B	6014 759061	IGOR KUDRYASHOV	{"email": "i.kudryashov_1974@postgrespro.ru", "phone": "+70668174158"}
0005435541626	751B94	8613 211910	VLADIMIR KOZLOV	{"email": "vladimir-kozlov051964@postgrespro.ru", "phone": "+70418088329"}
0005435541627	217F62	6588 588756	VLADIMIR POPOV	{"phone": "+70614056300"}
0005435541628	D2925F	1539 529235	VLADIMIR MARTYNOV	{"phone": "+70943847852"}
0005435541629	D2925F	7994 939096	VALENTINA IVANOVA	{"email": "valentina-ivanova-12031968@postgrespro.ru", "phone": "+70702466805"}
0005435541630	6863A9	0272 268260	NADEZHDA FADEEVA	{"email": "fadeeva-n-111985@postgrespro.ru", "phone": "+70884450162"}
0005435541631	6863A9	6702 513392	ALEKSEY YAKOVLEV	{"phone": "+70714094549"}
0005435541632	5DEBAD	3272 807678	YULIYA FILATOVA	{"email": "filatovayuliya.021967@postgrespro.ru", "phone": "+70686427411"}
0005435541633	5DEBAD	1540 404518	GALINA ANTONOVA	{"phone": "+70689592096"}
0005435541634	630AE9	7488 611070	DARYA FEDOROVA	{"phone": "+70429666299"}
0005435541635	630AE9	7950 579784	NIKITA RODIONOV	{"phone": "+70066146342"}
0005435541636	3D917C	2005 959386	LYUDMILA SEMENOVA	{"phone": "+70297007892"}
0005435541637	3D917C	0692 845929	ALEKSANDR BELOV	{"email": "aleksandrbelov-22101978@postgrespro.ru", "phone": "+70496997260"}
0005435541638	1FD37F	1281 514490	NADEZHDA TITOVA	{"phone": "+70174959219"}
0005435541639	5F5B45	3947 260240	SVYATOSLAV NAZAROV	{"email": "nazarov-s.02081969@postgrespro.ru", "phone": "+70805482033"}
0005435541640	5F5B45	3022 780208	IVAN ZHURAVLEV	{"email": "i_zhuravlev_101973@postgrespro.ru", "phone": "+70284471565"}
0005435541641	1CB1A2	4549 177616	YAROSLAV SAVELEV	{"phone": "+70134629744"}
0005435541642	22ECB2	4290 511600	EKATERINA KOZLOVA	{"email": "kozlova_e.091966@postgrespro.ru", "phone": "+70676433785"}
0005435541643	22ECB2	6880 553637	MARIYA ORLOVA	{"email": "mariyaorlova-05061969@postgrespro.ru", "phone": "+70962181723"}
0005435541644	C3385E	2448 154908	EVGENIY NIKITIN	{"email": "nikitin_e.061979@postgrespro.ru", "phone": "+70722068113"}
0005435541645	C3385E	7418 213936	EKATERINA NAZAROVA	{"email": "e.nazarova_111967@postgrespro.ru", "phone": "+70524547586"}
0005435541646	960C98	3793 543211	ANTON AFANASEV	{"phone": "+70824030153"}
0005435541647	48BBCD	6372 008722	NIKOLAY MEDVEDEV	{"email": "medvedevnikolay_061970@postgrespro.ru", "phone": "+70488760763"}
0005435541648	48BBCD	8638 258787	KONSTANTIN MIRONOV	{"phone": "+70647038609"}
0005435541649	B0E090	1990 832212	ALEKSANDR NOVIKOV	{"email": "novikov.a_071971@postgrespro.ru", "phone": "+70685399294"}
0005435541650	AE214D	7602 656579	MIKHAIL BONDARENKO	{"phone": "+70958261296"}
0005435541651	538006	4136 308304	ARTEM ANDREEV	{"email": "andreev-a.051970@postgrespro.ru", "phone": "+70767993847"}
0005435541652	538006	4019 226051	ALEKSEY NAZAROV	{"email": "a_nazarov_091972@postgrespro.ru", "phone": "+70398337471"}
0005435541653	D664DC	4374 738089	MIKHAIL ZHURAVLEV	{"email": "mikhail-zhuravlev.10071969@postgrespro.ru", "phone": "+70738586214"}
0005435545613	DEF60D	8763 669385	LYUDMILA FILIPPOVA	{"email": "filippova_lyudmila081967@postgrespro.ru", "phone": "+70858565220"}
0005435545614	37DA77	9354 614348	DARYA KOROLEVA	{"email": "d_koroleva.13071969@postgrespro.ru", "phone": "+70708763709"}
0005435545615	37DA77	8054 410263	KSENIYA KUZNECOVA	{"phone": "+70530301068"}
0005435545616	9F9C29	7608 600482	VALERIY BONDARENKO	{"phone": "+70321615006"}
0005435545617	CC9B28	7273 538502	ALISA POPOVA	{"email": "alisa_popova-121970@postgrespro.ru", "phone": "+70702323477"}
0005435545618	59597B	5201 086163	VLADISLAV YAKOVLEV	{"phone": "+70450749827"}
0005435545619	59597B	3160 320982	ANATOLIY NAUMOV	{"phone": "+70025137667"}
0005435545620	E049BA	1098 226751	ALEKSANDR SERGEEV	{"email": "asergeev-13091973@postgrespro.ru", "phone": "+70803650828"}
0005435545621	EDE418	5390 909904	VLADIMIR ZHURAVLEV	{"email": "v-zhuravlev111979@postgrespro.ru", "phone": "+70294400548"}
0005435545622	93FE6D	4307 961221	SVETLANA ARKHIPOVA	{"email": "svetlana-arkhipova.011978@postgrespro.ru", "phone": "+70855214573"}
0005435545623	93FE6D	6572 097195	TATYANA DANILOVA	{"email": "danilova_t-1963@postgrespro.ru", "phone": "+70552468409"}
0005435545624	1E3721	0004 108893	NIKOLAY CHERNOV	{"phone": "+70674949099"}
0005435545625	513D6C	9329 065307	SOFYA YAKOVLEVA	{"email": "s_yakovleva_091970@postgrespro.ru", "phone": "+70632005688"}
0005435545626	24477C	9184 490125	IRINA TIMOFEEVA	{"phone": "+70870088394"}
0005435545627	24477C	6614 855236	ANASTASIYA ISAEVA	{"phone": "+70601466138"}
0005435545628	9448F7	1808 989414	OLESYA SIDOROVA	{"phone": "+70592622902"}
0005435545629	9448F7	6359 858389	ANNA NAUMOVA	{"phone": "+70204442436"}
0005435545630	9448F7	4642 623944	DIANA ALEKSEEVA	{"phone": "+70387428897"}
0005435545631	6BB073	7393 864304	NIKOLAY MIRONOV	{"phone": "+70591871861"}
0005435545632	6BB073	4503 454459	ALEKSEY STEPANOV	{"phone": "+70445510678"}
0005435545633	DC38AC	4841 863118	TAMARA NAZAROVA	{"email": "tnazarova.1982@postgrespro.ru", "phone": "+70801967888"}
0005435545634	DD6F72	2230 949282	SERGEY SEMENOV	{"phone": "+70152593908"}
0005435545635	DD6F72	7903 493746	NATALYA POPOVA	{"phone": "+70262984221"}
0005435545636	38C747	5480 429729	YURIY POPOV	{"email": "yuriy-popov_23091982@postgrespro.ru", "phone": "+70278087130"}
0005435545637	38C747	2877 518148	SERGEY KOROLEV	{"phone": "+70451358244"}
0005435545638	DDC12B	7750 210926	LYUDMILA MATVEEVA	{"email": "matveeva.lyudmila1980@postgrespro.ru", "phone": "+70295333650"}
0005435545639	DDC12B	4552 632602	LARISA SOKOLOVA	{"email": "sokolova.l_22021960@postgrespro.ru", "phone": "+70478953255"}
0005435545640	B8A57E	8678 227024	ELENA ABRAMOVA	{"email": "abramovae-1966@postgrespro.ru", "phone": "+70452170892"}
0005435545641	49A02C	8806 973356	NIKOLAY IVANOV	{"email": "ivanov.nikolay22091976@postgrespro.ru", "phone": "+70511220288"}
0005435545642	40BC9C	8787 097631	ALEKSANDR BORISOV	{"email": "borisov_aleksandr-041978@postgrespro.ru", "phone": "+70224029737"}
0005435545643	204ED4	6588 311268	TAMARA BELOVA	{"email": "belova_tamara-021981@postgrespro.ru", "phone": "+70438038357"}
0005435545644	C39159	2528 914295	MARINA PAVLOVA	{"phone": "+70035722090"}
0005435545645	B0C4E0	6006 585116	MARINA KUZMINA	{"email": "mkuzmina-1978@postgrespro.ru", "phone": "+70136971748"}
0005435545646	810239	9093 267294	RAISA VASILEVA	{"email": "vasileva-raisa_1968@postgrespro.ru", "phone": "+70690471390"}
0005435545647	810239	4976 123545	NIKITA KAZAKOV	{"phone": "+70101866951"}
0005435545648	02D2FB	9992 690654	NADEZHDA SEMENOVA	{"email": "semenova-nadezhda_12091971@postgrespro.ru", "phone": "+70817954435"}
0005435545649	02D2FB	2398 587938	VERONIKA NIKIFOROVA	{"phone": "+70226005242"}
0005435545650	FE3A8C	8832 599412	ANATOLIY DAVYDOV	{"phone": "+70289372822"}
0005435545651	61C075	7069 423873	SVETLANA ZOTOVA	{"email": "zotovas1965@postgrespro.ru", "phone": "+70667310956"}
0005435545652	B173EE	7094 879681	EKATERINA MATVEEVA	{"email": "ematveeva1980@postgrespro.ru", "phone": "+70503374369"}
0005435545653	C217CA	1788 607742	TATYANA ZAYCEVA	{"phone": "+70415486217"}
0005435545654	C217CA	7999 867722	VALERIY POPOV	{"phone": "+70240935612"}
0005435545655	E21056	4650 837924	RUSTEM VOLKOV	{"email": "volkov_rustem_29121968@postgrespro.ru", "phone": "+70961442461"}
0005435545656	8B98B5	7122 242466	BORIS MELNIKOV	{"email": "b_melnikov-021980@postgrespro.ru", "phone": "+70140193248"}
0005435545657	2B9B2A	7690 687595	EVGENIY VASILEV	{"phone": "+70555461129"}
0005435545658	2A971E	9319 449712	ALEKSANDR DAVYDOV	{"email": "davydovaleksandr_08021982@postgrespro.ru", "phone": "+70686157195"}
0005435545659	7242E3	7449 293288	ALEKSANDR KAZAKOV	{"email": "kazakov_aleksandr071978@postgrespro.ru", "phone": "+70573292049"}
0005435545660	8EA95E	1847 077089	ALEKSANDR SERGEEV	{"email": "aleksandr.sergeev-111968@postgrespro.ru", "phone": "+70145887232"}
0005435545661	8EA95E	1691 318716	GALINA VASILEVA	{"email": "vasileva-g_011980@postgrespro.ru", "phone": "+70453708015"}
0005435545662	8EA95E	6241 020905	ALINA FROLOVA	{"email": "frolovaalina_1976@postgrespro.ru", "phone": "+70541720086"}
0005435545663	20AE1C	3374 840220	NINA TITOVA	{"phone": "+70866341547"}
0005435545664	20AE1C	6902 007711	SVETLANA NAUMOVA	{"phone": "+70532551337"}
0005435545665	EED28B	1789 656974	RAVIL ROMANOV	{"email": "romanov-ravil-19081964@postgrespro.ru", "phone": "+70362967603"}
0005435545666	31F463	4439 590736	TATYANA MOROZOVA	{"phone": "+70442113505"}
0005435545667	134489	7350 887704	LEONID KUZMIN	{"email": "kuzmin.l_1968@postgrespro.ru", "phone": "+70316485267"}
0005435545668	BFC0CA	9773 806410	SOFYA IVANOVA	{"phone": "+70073527166"}
0005435545669	092348	0372 360881	TATYANA KUZNECOVA	{"email": "kuznecova.t-051974@postgrespro.ru", "phone": "+70666937103"}
0005435545670	061CAB	4631 192712	ALEKSANDR TARASOV	{"email": "tarasov_a-1975@postgrespro.ru", "phone": "+70839115858"}
0005435545671	F27B1C	5666 276074	EKATERINA ALEKSEEVA	{"email": "ekaterina_alekseeva101973@postgrespro.ru", "phone": "+70896194587"}
0005435545672	F745EF	4125 388699	LYUBOV GORBUNOVA	{"phone": "+70316254830"}
0005435545673	C57911	8265 314100	SERGEY ZHUKOV	{"phone": "+70122132335"}
0005435545674	8F68E7	0637 347036	ANISA MIRONOVA	{"phone": "+70846454299"}
0005435545675	30DD31	2212 112305	TATYANA SOROKINA	{"email": "t_sorokina.1981@postgrespro.ru", "phone": "+70693073403"}
0005435545676	30DD31	6279 954865	RAVIL ANTONOV	{"email": "antonov.ravil.1971@postgrespro.ru", "phone": "+70634723394"}
0005435545677	8FFBA5	0564 203378	NADEZHDA SMIRNOVA	{"email": "n_smirnova1966@postgrespro.ru", "phone": "+70981302294"}
0005435545678	81E5B0	5756 699642	VLADIMIR RODIONOV	{"email": "vladimirrodionov-1970@postgrespro.ru", "phone": "+70074055359"}
0005435545679	81E5B0	8842 551338	ALEKSEY NIKOLAEV	{"phone": "+70496750497"}
0005435545680	32639B	8888 324008	TATYANA POTAPOVA	{"email": "potapovat.091978@postgrespro.ru", "phone": "+70226545535"}
0005435545681	AA02D8	8141 191745	LARISA FILATOVA	{"phone": "+70439790270"}
0005435545682	436818	4669 485202	LYUBOV BARANOVA	{"email": "baranova.lyubov.031980@postgrespro.ru", "phone": "+70328160625"}
0005435545683	460DEC	2333 991680	DMITRIY ANTONOV	{"phone": "+70878631175"}
0005435545684	460DEC	6971 574561	ELIZAVETA NOVIKOVA	{"email": "elizaveta.novikova-04041961@postgrespro.ru", "phone": "+70546578818"}
0005435545685	B5ED26	9316 810972	KSENIYA RYABOVA	{"email": "ryabova.k.1971@postgrespro.ru", "phone": "+70945995413"}
0005435545686	357F7B	8853 493874	ELENA KUZNECOVA	{"email": "elena_kuznecova05101978@postgrespro.ru", "phone": "+70395386922"}
0005435545687	357F7B	1031 880419	VLADIMIR POPOV	{"email": "popov_vladimir-1985@postgrespro.ru", "phone": "+70526581361"}
0005435545688	357F7B	9327 919559	VERA GUSEVA	{"phone": "+70036891627"}
0005435545689	FD8103	7880 078464	ANDREY MOROZOV	{"email": "a-morozov_14101964@postgrespro.ru", "phone": "+70475314052"}
0005435545690	FD8103	2527 962627	VALENTINA MOROZOVA	{"email": "vmorozova.1962@postgrespro.ru", "phone": "+70860339551"}
0005435545691	A2BB7C	3022 631546	TATYANA VOLKOVA	{"phone": "+70844718262"}
0005435545692	A7E095	4084 983840	ANNA LUKYANOVA	{"phone": "+70641059821"}
0005435545693	226216	4274 806542	NATALYA ZHURAVLEVA	{"email": "nzhuravleva-19111978@postgrespro.ru", "phone": "+70627259514"}
0005435545694	C8E23A	2466 094825	IRINA SOKOLOVA	{"email": "sokolovairina121966@postgrespro.ru", "phone": "+70988168128"}
0005435545695	C8E23A	4287 726151	OLGA BORISOVA	{"phone": "+70294493855"}
0005435545696	C8E23A	4954 177076	IGNAT MOISEEV	{"phone": "+70713402414"}
0005435545697	C48E5D	6567 065077	VARVARA CHERNOVA	{"phone": "+70214304422"}
0005435545698	C48E5D	1573 732230	DARYA KRASNOVA	{"phone": "+70476816707"}
0005435545699	C48E5D	9513 621533	LIDIYA PAVLOVA	{"email": "pavlova.l_1966@postgrespro.ru", "phone": "+70453307426"}
0005435545700	9F4F5F	3329 726879	OLGA EFIMOVA	{"email": "efimova-olga-16051972@postgrespro.ru", "phone": "+70298815747"}
0005435545701	9F4F5F	9934 523778	KAMILLA VOLKOVA	{"phone": "+70658936270"}
0005435545702	AF821D	0616 827461	NINA NESTEROVA	{"email": "n-nesterova_061970@postgrespro.ru", "phone": "+70734813983"}
0005435545703	AE9171	2101 712113	OLEG SERGEEV	{"email": "sergeevo.10101968@postgrespro.ru", "phone": "+70811021953"}
0005435545704	CEECF9	8697 548396	GALINA VOROBEVA	{"email": "g_vorobeva.111964@postgrespro.ru", "phone": "+70483535803"}
0005435545705	D8FCD6	9231 583172	ALEKSANDR ZAKHAROV	{"phone": "+70377071131"}
0005435545706	960978	0263 291058	VALENTINA ZOTOVA	{"email": "zotova-valentina.12091983@postgrespro.ru", "phone": "+70989943906"}
0005435545707	031CFF	8940 549738	NATALYA KULIKOVA	{"email": "kulikova_n011978@postgrespro.ru", "phone": "+70738908930"}
0005435545708	A80629	4090 954134	ZAKHAR ANTONOV	{"email": "antonov.zakhar-051970@postgrespro.ru", "phone": "+70920106962"}
0005435545709	7CF1DE	8208 608882	NIKOLAY ABRAMOV	{"phone": "+70825734801"}
0005435545710	86704B	0302 998274	DENIS KUDRYASHOV	{"phone": "+70580726615"}
0005435545711	A3CA51	8279 539803	MARINA GORBUNOVA	{"phone": "+70419767207"}
0005435545712	FD301D	9165 796409	DMITRIY KRASNOV	{"phone": "+70504547800"}
0005435545713	88009C	0846 712300	ANNA LOGINOVA	{"phone": "+70305211881"}
0005435545714	88009C	0897 030916	SERGEY NOVIKOV	{"email": "novikov-s.16031968@postgrespro.ru", "phone": "+70776776844"}
0005435545715	500F46	8176 299519	MARINA SEMENOVA	{"email": "m-semenova-14121968@postgrespro.ru", "phone": "+70997756829"}
0005435545716	500F46	9008 095754	ALLA DANILOVA	{"email": "danilova_alla-051974@postgrespro.ru", "phone": "+70008685319"}
0005435545717	D06DB5	9000 144595	ALINA SOKOLOVA	{"email": "a-sokolova.04111980@postgrespro.ru", "phone": "+70849534391"}
0005435545718	7E5188	3792 116150	LYUBOV MEDVEDEVA	{"email": "medvedeva_l.01021977@postgrespro.ru", "phone": "+70212581320"}
0005435545719	3176AD	9321 587497	NONNA GORBUNOVA	{"email": "nonna.gorbunova.06121974@postgrespro.ru", "phone": "+70628181157"}
0005435545720	3176AD	7368 505052	MARINA ROMANOVA	{"email": "marinaromanova_12041964@postgrespro.ru", "phone": "+70525279234"}
0005435545721	3176AD	1048 637931	FARIDA VLASOVA	{"phone": "+70706416203"}
0005435545722	02008E	7371 671375	ANASTASIYA GORBUNOVA	{"phone": "+70264671231"}
0005435545723	167346	5246 569675	ZINAIDA BORISOVA	{"phone": "+70664871627"}
0005435545724	2F6032	7632 395576	LYUDMILA FILATOVA	{"phone": "+70292597322"}
0005435545725	B369D4	9993 738797	SVETLANA AFANASEVA	{"phone": "+70944488312"}
0005435545726	B369D4	2986 255367	ELENA FROLOVA	{"phone": "+70534199456"}
0005435545727	3ED762	9456 406812	ANNA SIDOROVA	{"email": "sidorova-a071980@postgrespro.ru", "phone": "+70502886911"}
0005435545728	894723	7629 974255	VALENTINA VASILEVA	{"phone": "+70247838812"}
0005435545729	AD21CF	2022 383432	SERGEY SMIRNOV	{"email": "s-smirnov_1986@postgrespro.ru", "phone": "+70831278149"}
0005435545730	AD21CF	4638 482220	KONSTANTIN EGOROV	{"email": "konstantin_egorov091979@postgrespro.ru", "phone": "+70290039277"}
0005435545731	49A928	2834 853631	IVAN KOROLEV	{"phone": "+70652500974"}
0005435545732	55F08C	2339 171681	ALEKSANDR BONDARENKO	{"email": "abondarenko_24021971@postgrespro.ru", "phone": "+70317039499"}
0005435545733	568ABE	3790 347438	VALERIY IVANOV	{"phone": "+70193571374"}
0005435545734	9A37D0	5419 219490	NIKITA AFANASEV	{"phone": "+70513232074"}
0005435545735	7A85AD	5216 891033	ROMAN KUZNECOV	{"email": "kuznecovr_1979@postgrespro.ru", "phone": "+70071376910"}
0005435545736	BC5285	8745 527034	LYUDMILA ALEKSEEVA	{"phone": "+70974287025"}
0005435545737	8D14AB	3329 097924	NIKOLAY KONOVALOV	{"phone": "+70513555286"}
0005435545738	B74C99	8653 696990	VLADIMIR SCHERBAKOV	{"email": "scherbakov-vladimir_1968@postgrespro.ru", "phone": "+70494220347"}
0005435545739	0FBD70	3478 457989	VLADIMIR VASILEV	{"email": "vasilev_vladimir-05031965@postgrespro.ru", "phone": "+70365921660"}
0005435545740	B6C5BD	8437 622280	GAGIK ZAKHAROV	{"email": "zakharov_g.1966@postgrespro.ru", "phone": "+70412581410"}
0005435545741	4ABE6C	3823 631417	ELVIRA KOZLOVA	{"phone": "+70284197901"}
0005435545742	6DBB10	4357 743148	IGOR FROLOV	{"phone": "+70196308470"}
0005435545743	C9299F	5856 301636	RUSLAN KOZLOV	{"email": "kozlov_ruslan1972@postgrespro.ru", "phone": "+70975788466"}
0005435545744	C9299F	5234 378954	VASILIY GORBUNOV	{"email": "vasiliygorbunov-1975@postgrespro.ru", "phone": "+70877784811"}
0005435545745	BEE2D8	5336 087769	DENIS GRIGOREV	{"email": "d_grigorev-1965@postgrespro.ru", "phone": "+70558370043"}
0005435545746	BEE2D8	9204 447610	ZOYA VOLKOVA	{"email": "zoya.volkova_1976@postgrespro.ru", "phone": "+70872059567"}
0005435545747	0C2138	9712 258831	NATALYA MAKAROVA	{"email": "makarova_natalya_1969@postgrespro.ru", "phone": "+70323337049"}
0005435545748	2A3093	8438 468818	KIRILL FROLOV	{"email": "frolov-kirill-1970@postgrespro.ru", "phone": "+70540121283"}
0005435545749	225786	7937 524907	ALEKSANDR BELOV	{"email": "belovaleksandr.031972@postgrespro.ru", "phone": "+70552562917"}
0005435545750	225786	3814 653266	ALEKSANDR OSIPOV	{"phone": "+70436866451"}
0005435545751	83F8FB	2981 692083	YULIYA LOGINOVA	{"email": "loginova.y.1970@postgrespro.ru", "phone": "+70899419895"}
0005435545752	EC274D	8361 820157	MIKHAIL POPOV	{"phone": "+70845080985"}
0005435545753	0FF467	0119 314341	GALINA PETROVA	{"phone": "+70873428045"}
0005435545754	0FF467	0610 835288	KONSTANTIN ISAEV	{"email": "konstantin_isaev-15111959@postgrespro.ru", "phone": "+70772821409"}
0005435545755	BAD686	1713 548026	IRINA DENISOVA	{"email": "denisova_irina.27031986@postgrespro.ru", "phone": "+70647759357"}
0005435545756	D2A3FA	3406 192103	DANILA SCHERBAKOV	{"email": "scherbakov.danila081980@postgrespro.ru", "phone": "+70138587611"}
0005435545757	D2A3FA	1318 250651	VALERIY KAZAKOV	{"email": "kazakov.v07121973@postgrespro.ru", "phone": "+70070158386"}
0005435545758	061E73	7880 981425	IGOR FEDOTOV	{"email": "fedotov-i-1971@postgrespro.ru", "phone": "+70569783691"}
0005435545759	0AD70E	6444 043647	LYUDMILA MAKAROVA	{"email": "makarova-l.1967@postgrespro.ru", "phone": "+70913377348"}
0005435545760	0AD70E	8757 133956	ELENA PETROVA	{"phone": "+70344669537"}
0005435545761	2549C5	3296 110562	MARINA BORISOVA	{"phone": "+70757524524"}
0005435545762	27AA9F	8553 748827	SERGEY KARPOV	{"email": "s_karpov_041967@postgrespro.ru", "phone": "+70735081576"}
0005435545763	27AA9F	2902 009763	NADEZHDA LUKYANOVA	{"phone": "+70596984770"}
0005435545764	27AA9F	3835 979308	LEONID ZAYCEV	{"email": "zaycev.l1971@postgrespro.ru", "phone": "+70907318211"}
0005435545765	90C0EA	6362 978719	NIKOLAY GERASIMOV	{"phone": "+70838178151"}
0005435545766	90C0EA	5804 062154	LYUBOV ALEKSANDROVA	{"email": "lyubovaleksandrova-28121969@postgrespro.ru", "phone": "+70181449910"}
0005435545767	55FE49	0120 790358	NIKOLAY MIRONOV	{"email": "n_mironov_1967@postgrespro.ru", "phone": "+70956319948"}
0005435545768	6A5E6E	6938 717838	ALEKSANDR NOVIKOV	{"email": "novikov-aleksandr_1974@postgrespro.ru", "phone": "+70131437800"}
0005435545769	6A5E6E	6481 895244	GEORGIY MAKAROV	{"phone": "+70590878873"}
0005435545770	75CF7B	5064 886698	ELENA SIDOROVA	{"email": "e_sidorova-091976@postgrespro.ru", "phone": "+70337640362"}
0005435545771	1C170E	0513 677944	NATALYA NAUMOVA	{"phone": "+70714768419"}
0005435545772	956FF2	1814 095183	ANDREY ISAEV	{"email": "isaev-andrey-121977@postgrespro.ru", "phone": "+70948352453"}
0005435545773	34153E	7738 805737	LEONTIY NIKOLAEV	{"email": "nikolaevleontiy-1973@postgrespro.ru", "phone": "+70404539104"}
0005435545774	34153E	9311 998424	GALINA ZAKHAROVA	{"email": "zakharovag_22111976@postgrespro.ru", "phone": "+70278184988"}
0005435545775	86801C	7972 555139	IVAN IVANOV	{"phone": "+70331938776"}
0005435545776	C62B8A	4013 418045	ANNA TARASOVA	{"email": "tarasova_anna021976@postgrespro.ru", "phone": "+70979935975"}
0005435545777	8F17BE	8003 926774	NATALYA LEBEDEVA	{"phone": "+70044624294"}
0005435545778	ABE08C	0690 286323	MARIYA NIKOLAEVA	{"phone": "+70199097151"}
0005435545779	D63FCC	3757 505051	TATYANA NIKITINA	{"email": "tatyana-nikitina.14081970@postgrespro.ru", "phone": "+70052156045"}
0005435545780	053975	4804 711902	ALEKSANDR AFANASEV	{"email": "afanasev.aleksandr_1964@postgrespro.ru", "phone": "+70637248130"}
0005435545781	053975	1342 511711	DIANA POPOVA	{"email": "popovadiana-1986@postgrespro.ru", "phone": "+70131366206"}
0005435545782	F57B65	2251 823939	EVGENIYA ANTONOVA	{"phone": "+70348250345"}
0005435545783	94D308	4216 089747	VALENTINA DAVYDOVA	{"phone": "+70634179303"}
0005435545784	8188C9	3180 422584	YURIY ANDREEV	{"email": "andreev.yuriy-09041970@postgrespro.ru", "phone": "+70279927949"}
0005435545785	B7C3AD	5521 853065	ALEKSEY DENISOV	{"phone": "+70412593236"}
0005435545786	8BD889	2700 540769	ALEKSANDR EGOROV	{"email": "egorov.a.1976@postgrespro.ru", "phone": "+70805736823"}
0005435545787	D6E02A	9005 313996	KSENIYA NESTEROVA	{"email": "nesterovakseniya1970@postgrespro.ru", "phone": "+70880539834"}
0005435545788	1BD0AF	1338 420410	YULIYA MELNIKOVA	{"phone": "+70151860943"}
0005435545789	1BD0AF	5702 239058	MARIYA GUSEVA	{"phone": "+70058592217"}
0005435545790	1BD0AF	4813 818967	TAISIYA GERASIMOVA	{"phone": "+70914060047"}
0005435545791	B6FECD	7444 506994	NIKOLAY ILIN	{"phone": "+70787970208"}
0005435545792	8615E2	5410 998876	NATALYA NIKITINA	{"email": "natalya_nikitina_1968@postgrespro.ru", "phone": "+70428602128"}
0005435545793	137FB7	2456 922920	EVELINA OVCHINNIKOVA	{"email": "ovchinnikova.evelina-031981@postgrespro.ru", "phone": "+70321228576"}
0005435545794	137FB7	4036 525565	ANASTASIYA DENISOVA	{"email": "a.denisova.051980@postgrespro.ru", "phone": "+70988321585"}
0005435545795	532A1D	4229 710005	TAMARA GERASIMOVA	{"phone": "+70466122580"}
0005435545796	532A1D	3360 750963	NATALYA SOROKINA	{"email": "sorokina-natalya.111972@postgrespro.ru", "phone": "+70441565736"}
0005435545797	06BDC6	8081 598809	IRINA NAZAROVA	{"email": "nazarova_irina.05011971@postgrespro.ru", "phone": "+70208430965"}
0005435545798	2492A4	7113 248946	NIKOLAY IVANOV	{"email": "ivanovn1979@postgrespro.ru", "phone": "+70689828942"}
0005435545799	8043EB	5800 511352	MIKHAIL IVANOV	{"phone": "+70382676087"}
0005435545800	3237FA	0361 179662	IVAN ZAYCEV	{"email": "zaycev.i-1974@postgrespro.ru", "phone": "+70644692222"}
0005435545801	A6058E	8419 311187	VLADIMIR SAVELEV	{"email": "savelevv28071977@postgrespro.ru", "phone": "+70061412750"}
0005435545802	77DE85	6201 010785	ANDREY MAKAROV	{"phone": "+70907305339"}
0005435545803	2B1F9B	3123 048215	ANASTASIYA DENISOVA	{"email": "a.denisova.1969@postgrespro.ru", "phone": "+70849578180"}
0005435545804	6B81AF	8170 662115	LEV KARPOV	{"email": "karpov_lev1970@postgrespro.ru", "phone": "+70719044344"}
0005435545805	6B81AF	9077 485226	ARKADIY KUZNECOV	{"email": "kuznecova-011961@postgrespro.ru", "phone": "+70178841013"}
0005435545806	1FF026	2072 794520	MAKSIM ZAYCEV	{"phone": "+70228432540"}
0005435545807	677F5D	1702 776675	RAMIL IVANOV	{"email": "r_ivanov.16061976@postgrespro.ru", "phone": "+70899975903"}
0005435545808	D305E7	3852 915524	VIKTOR SMIRNOV	{"phone": "+70349693389"}
0005435545809	042715	3098 087556	LILIYA KUZNECOVA	{"email": "liliyakuznecova_06011979@postgrespro.ru", "phone": "+70226270711"}
0005435545810	042715	7625 499645	ANASTASIYA FROLOVA	{"email": "frolovaa-23061970@postgrespro.ru", "phone": "+70994982753"}
0005435545811	800FAF	4836 156696	YURIY MAKAROV	{"email": "ymakarov_09061974@postgrespro.ru", "phone": "+70847160143"}
0005435545812	0FAAFE	3162 564520	LYUCIYA NIKOLAEVA	{"phone": "+70800035780"}
0005435545813	76AD75	5574 024756	VERA NIKOLAEVA	{"email": "v.nikolaeva_03121965@postgrespro.ru", "phone": "+70116143408"}
0005435545814	DB6810	2952 508307	ANASTASIYA MAKAROVA	{"phone": "+70439445134"}
0005435545815	24C2BA	0584 697562	MIKHAIL NIKOLAEV	{"phone": "+70878096832"}
0005435545816	24C2BA	5666 850721	VLADIMIR SMIRNOV	{"phone": "+70825902523"}
0005435545817	3EB5D3	2849 509897	VIKTOR KOZLOV	{"email": "viktorkozlov.111976@postgrespro.ru", "phone": "+70558047504"}
0005435545818	8B66AE	2981 608570	ANTON SOLOVEV	{"phone": "+70658336669"}
0005435545819	8B66AE	6246 022557	ANNA MEDVEDEVA	{"email": "a.medvedeva-121982@postgrespro.ru", "phone": "+70401565062"}
0005435545820	ABCD1C	0973 209346	VLADIMIR NIKOLAEV	{"phone": "+70478387588"}
0005435545821	ABCD1C	9395 188373	NADEZHDA TIKHONOVA	{"email": "n_tikhonova_1976@postgrespro.ru", "phone": "+70906379168"}
0005435545822	886BA1	0314 984550	LYUBOV KUZNECOVA	{"email": "l-kuznecova-1968@postgrespro.ru", "phone": "+70771967688"}
0005435545823	886BA1	0520 235298	MARGARITA KUZNECOVA	{"phone": "+70421539989"}
0005435545824	B753E3	5328 911659	TIMOFEY TIKHONOV	{"email": "tikhonov_timofey-1968@postgrespro.ru", "phone": "+70616686684"}
0005435545825	B753E3	2971 084118	MIKHAIL GUSEV	{"phone": "+70859197061"}
0005435545826	AEE1F2	1661 541848	ANATOLIY BONDARENKO	{"email": "bondarenko.anatoliy_1979@postgrespro.ru", "phone": "+70192768287"}
0005435545827	D1DA38	2883 618353	ALEKSANDR IVANOV	{"phone": "+70538740577"}
0005435545828	AA10E2	0577 764733	OLGA VASILEVA	{"email": "o-vasileva02021965@postgrespro.ru", "phone": "+70489656525"}
0005435545829	A5BD27	9664 792956	ALEKSANDR KONOVALOV	{"phone": "+70104179913"}
0005435545830	DA37F8	0702 231897	OKSANA KUZNECOVA	{"email": "kuznecova-o_121972@postgrespro.ru", "phone": "+70147875353"}
0005435545831	DA37F8	4842 546754	SVETLANA ZHUKOVA	{"email": "zhukova-s.22011969@postgrespro.ru", "phone": "+70595263783"}
0005435545832	7CC69D	6982 791676	YURIY POPOV	{"email": "popov_y.091977@postgrespro.ru", "phone": "+70726245409"}
0005435545833	819890	8879 069216	RAISA KOROLEVA	{"email": "raisa_koroleva-1963@postgrespro.ru", "phone": "+70587998229"}
0005435545834	DB34F6	5157 789870	LARISA MAKAROVA	{"phone": "+70099482722"}
0005435545835	DB34F6	7173 507614	TATYANA RYABOVA	{"email": "ryabova-tatyana061965@postgrespro.ru", "phone": "+70190092148"}
0005435545836	DB34F6	3013 550277	LEV KOZLOV	{"email": "kozlov_l-1979@postgrespro.ru", "phone": "+70769850995"}
0005435545837	170338	8516 489599	ELENA ZAKHAROVA	{"email": "elena-zakharova1968@postgrespro.ru", "phone": "+70529844309"}
0005435545838	170338	2571 317545	OKSANA ZAYCEVA	{"email": "zayceva_oksana.1971@postgrespro.ru", "phone": "+70129183320"}
0005435545839	240076	2235 841865	SERGEY DENISOV	{"email": "denisov_s-1986@postgrespro.ru", "phone": "+70720729573"}
0005435545840	E7DF65	7513 597590	SERGEY ZAKHAROV	{"email": "sergey.zakharov_14121964@postgrespro.ru", "phone": "+70349550257"}
0005435545841	E7DF65	4138 621324	KONSTANTIN TIKHONOV	{"phone": "+70398704602"}
0005435545842	BA4E14	3413 636476	ARINA SMIRNOVA	{"email": "a_smirnova_1968@postgrespro.ru", "phone": "+70885032040"}
0005435545843	BA4E14	1566 122182	ANNA NIKITINA	{"phone": "+70161040071"}
0005435545844	A0DC6E	2495 992452	ELENA LUKYANOVA	{"phone": "+70839655029"}
0005435545845	C891EA	4438 061165	SERGEY SIDOROV	{"phone": "+70481633220"}
0005435545846	B9BC18	5028 615036	MARINA KONOVALOVA	{"phone": "+70364982283"}
0005435545847	15E951	4164 434257	SERGEY ANTONOV	{"email": "sergey-antonov_101969@postgrespro.ru", "phone": "+70569098053"}
0005435545848	FF2220	4534 219316	LEONID VASILEV	{"phone": "+70225921199"}
0005435545849	6B44F3	9090 609353	VLADIMIR IVANOV	{"email": "v_ivanov.21051980@postgrespro.ru", "phone": "+70193187394"}
0005435545850	532C82	8574 480182	GALINA VOROBEVA	{"email": "galinavorobeva_1966@postgrespro.ru", "phone": "+70753277708"}
0005435545851	DA6904	4148 957759	ANASTASIYA AKIMOVA	{"phone": "+70045961499"}
0005435545852	DA6904	1717 594975	SERGEY KUDRYASHOV	{"email": "sergeykudryashov-31101985@postgrespro.ru", "phone": "+70229923031"}
0005435545853	B1272B	5968 506317	VALERIY KONOVALOV	{"email": "valeriy_konovalov.05121965@postgrespro.ru", "phone": "+70459895469"}
0005435545854	A1A86E	1327 001893	VLADIMIR SHEVCHENKO	{"email": "vshevchenko16061975@postgrespro.ru", "phone": "+70839935840"}
0005435545855	EB825C	3949 934984	VERA TIKHONOVA	{"email": "tikhonova_v-10031967@postgrespro.ru", "phone": "+70337589889"}
0005435545856	1B9A61	7344 284413	ZINAIDA MOROZOVA	{"phone": "+70159930606"}
0005435545857	1B9A61	3320 157561	VIKTOR TIMOFEEV	{"phone": "+70756030902"}
0005435545858	2EEEE0	5099 087924	EKATERINA NESTEROVA	{"email": "nesterova_e_011964@postgrespro.ru", "phone": "+70112398273"}
0005435545859	A8279F	7366 177470	ALEKSEY KISELEV	{"phone": "+70144281913"}
0005435545860	D5758D	9569 230599	TAMARA SOKOLOVA	{"phone": "+70891572992"}
0005435545861	D5758D	2641 555219	NIKOLAY DENISOV	{"email": "denisovn-26041963@postgrespro.ru", "phone": "+70153165009"}
0005435545862	8768A3	2141 148754	LYUDMILA POPOVA	{"phone": "+70549048951"}
0005435545863	8768A3	8831 808696	MILANA SOLOVEVA	{"phone": "+70379341834"}
0005435545864	31BB55	6819 474799	SERGEY ZAKHAROV	{"phone": "+70618426209"}
0005435545865	DB739B	2102 496335	NIKITA SCHERBAKOV	{"email": "nscherbakov13081978@postgrespro.ru", "phone": "+70704225131"}
0005435545866	201182	8202 677262	SERGEY FROLOV	{"phone": "+70774894292"}
0005435545867	D98FB8	2791 241606	MARINA ANDREEVA	{"email": "andreeva-m.1978@postgrespro.ru", "phone": "+70446027472"}
0005435545868	18D0D1	8611 561103	SERGEY YAKOVLEV	{"phone": "+70856154832"}
0005435545869	D308B3	3064 542527	IGOR MARTYNOV	{"email": "martynov.igor_24061970@postgrespro.ru", "phone": "+70329651640"}
0005435545870	D308B3	8221 532442	TATYANA SOLOVEVA	{"phone": "+70105724171"}
0005435545871	48B253	2125 344029	ALEKSANDR PETROV	{"email": "aleksandr_petrov_17111968@postgrespro.ru", "phone": "+70328532946"}
0005435545872	548D5E	7231 980103	TATYANA OVCHINNIKOVA	{"email": "ovchinnikova.t.041967@postgrespro.ru", "phone": "+70010087672"}
0005435545873	B6F302	3876 173486	TATYANA LOGINOVA	{"email": "loginova_t.24031971@postgrespro.ru", "phone": "+70991501637"}
0005435545874	B6F302	6091 380299	ARTEM NIKITIN	{"email": "artem-nikitin-1965@postgrespro.ru", "phone": "+70652485721"}
0005435545875	97B761	5115 547024	ANASTASIYA KOROLEVA	{"email": "koroleva-a.081973@postgrespro.ru", "phone": "+70154055093"}
0005435545876	AE9EBD	2863 390082	GALINA NIKIFOROVA	{"phone": "+70782825558"}
0005435545877	94F1B3	9207 854997	LYUDMILA ANTONOVA	{"phone": "+70738168205"}
0005435545878	B76622	1465 687393	VLADIMIR SERGEEV	{"email": "v-sergeev.1960@postgrespro.ru", "phone": "+70216331557"}
0005435545879	B76622	9617 676990	ANATOLIY VASILEV	{"phone": "+70339114616"}
0005435545880	B76622	2856 136467	YULIYA ISAEVA	{"phone": "+70506618110"}
0005435545881	EB955B	8042 431840	TATYANA NIKIFOROVA	{"email": "tnikiforova-101968@postgrespro.ru", "phone": "+70354858873"}
0005435545882	FE9415	3041 581526	IVAN PETROV	{"phone": "+70308768524"}
0005435545883	539435	5699 462544	SERGEY AFANASEV	{"email": "afanasev-sergey-1982@postgrespro.ru", "phone": "+70377080453"}
0005435545884	B327DC	6914 584105	ALEKSANDR CHERNOV	{"email": "a-chernov07101979@postgrespro.ru", "phone": "+70734148418"}
0005435545885	38B8B0	0279 347560	SERGEY KULIKOV	{"email": "s-kulikov121977@postgrespro.ru", "phone": "+70772583232"}
0005435545886	884E36	6365 145109	ANDREY AFANASEV	{"email": "andrey_afanasev-17081977@postgrespro.ru", "phone": "+70453268360"}
0005435545887	D12B20	2881 414468	OLGA KALININA	{"phone": "+70386099298"}
0005435545888	1EE0D9	7035 268110	MARINA RODIONOVA	{"phone": "+70945456844"}
0005435545889	1EE0D9	2566 976092	ANDREY IVANOV	{"phone": "+70831808993"}
0005435545890	477A59	3030 192510	ALEKSEY MAKSIMOV	{"phone": "+70046563515"}
0005435545891	477A59	1230 798356	NIKITA ROMANOV	{"email": "romanov.n_101966@postgrespro.ru", "phone": "+70091449008"}
0005435545892	2DA085	7696 282676	OLGA ANDREEVA	{"phone": "+70649190155"}
0005435545893	78063F	7771 687139	LYUBOV NAZAROVA	{"email": "nazarova_lyubov051965@postgrespro.ru", "phone": "+70842217365"}
0005435545894	4E8891	5275 848510	MARIYA MOROZOVA	{"phone": "+70441487854"}
0005435545895	4E8891	4915 634745	VIKTOR ZHURAVLEV	{"email": "zhuravlevviktor.1977@postgrespro.ru", "phone": "+70117899900"}
0005435545896	0AE3A8	2674 766726	IRINA ROMANOVA	{"phone": "+70029089029"}
0005435545897	0AE3A8	6465 481759	ANASTASIYA ZAYCEVA	{"email": "zayceva.anastasiya.031976@postgrespro.ru", "phone": "+70702930308"}
0005435545898	C2F7A3	8235 649819	EVGENIY BONDARENKO	{"email": "e-bondarenko_1957@postgrespro.ru", "phone": "+70406517879"}
0005435545899	CB5DC9	8876 969773	VLADIMIR MIKHAYLOV	{"phone": "+70325055014"}
0005435545900	CB5DC9	0767 094500	NATALYA NAZAROVA	{"email": "natalya-nazarova.061976@postgrespro.ru", "phone": "+70974469389"}
0005435545901	2FB058	7063 010892	GALINA PETROVA	{"email": "petrova_galina-031976@postgrespro.ru", "phone": "+70413604330"}
0005435545902	2FB058	0335 493081	ANATOLIY MIKHAYLOV	{"phone": "+70413781607"}
0005435545903	F7AD78	5876 041247	YULIYA MEDVEDEVA	{"phone": "+70825681922"}
0005435545904	3F81EB	3669 888478	ILYA MELNIKOV	{"phone": "+70234085379"}
0005435545905	3F81EB	0594 006950	OLGA NIKITINA	{"email": "nikitina-o-15051982@postgrespro.ru", "phone": "+70972683547"}
0005435545906	F91961	2459 592676	SERGEY EGOROV	{"email": "sergey_egorov_27011974@postgrespro.ru", "phone": "+70043445078"}
0005435545907	8E355A	1635 739853	ALEKSANDR PETROV	{"email": "petrov.aleksandr1967@postgrespro.ru", "phone": "+70689174685"}
0005435545908	9FFA35	5842 914362	VALENTINA IVANOVA	{"email": "valentina-ivanova19011983@postgrespro.ru", "phone": "+70379762404"}
0005435545909	20FAFD	5475 207504	SVETLANA SEMENOVA	{"phone": "+70288740469"}
0005435545910	BF6456	0753 910253	ANVAR ZHURAVLEV	{"phone": "+70889561310"}
0005435545911	33960B	0618 125300	NIKOLAY SAVELEV	{"email": "n_savelev.1962@postgrespro.ru", "phone": "+70350631617"}
0005435545912	148CA0	3648 031220	NIKOLAY FILIPPOV	{"email": "filippovn.041987@postgrespro.ru", "phone": "+70324934873"}
0005435545913	148CA0	3465 366118	NATALYA MEDVEDEVA	{"email": "medvedeva_n1959@postgrespro.ru", "phone": "+70301662374"}
0005435545914	05776C	1503 535023	ANATOLIY BORISOV	{"phone": "+70177322499"}
0005435545915	05776C	2224 605911	EGOR MIKHAYLOV	{"email": "e-mikhaylov_1966@postgrespro.ru", "phone": "+70492722199"}
0005435545916	957810	2296 654919	NATALYA RODIONOVA	{"phone": "+70826580947"}
0005435545917	957810	8168 975279	LYUDMILA ROMANOVA	{"phone": "+70382382677"}
0005435545918	247C5D	5558 530019	ELIZAVETA BORISOVA	{"phone": "+70254255846"}
0005435545919	9B6E67	3090 960156	ANASTASIYA GORBUNOVA	{"phone": "+70134678555"}
0005435545920	9B6E67	6806 804240	ARSENIY MOROZOV	{"email": "morozov.arseniy_1981@postgrespro.ru", "phone": "+70068575282"}
0005435545921	9B6E67	3541 483006	KLAVDIYA EFREMOVA	{"phone": "+70163941976"}
0005435545922	E87821	7474 241112	DARYA VASILEVA	{"email": "vasileva_darya-08091963@postgrespro.ru", "phone": "+70091989582"}
0005435545923	9B784E	5268 431779	GALINA EGOROVA	{"phone": "+70222992695"}
0005435545924	9B784E	2658 332841	ALEKSANDR ALEKSANDROV	{"phone": "+70042841810"}
0005435545925	01111A	3099 921275	SERGEY BORISOV	{"phone": "+70052117188"}
0005435545926	01111A	2406 584000	PELAGEYA KUZNECOVA	{"phone": "+70052752217"}
0005435545927	B74BDD	2926 644835	EKATERINA EFREMOVA	{"email": "efremova_e1973@postgrespro.ru", "phone": "+70375329620"}
0005435545928	351361	8434 782257	VASILIY ALEKSEEV	{"email": "alekseev-vasiliy.081967@postgrespro.ru", "phone": "+70551533231"}
0005435545929	5BE723	7154 843670	YURIY FOMIN	{"email": "fomin.y1973@postgrespro.ru", "phone": "+70558619470"}
0005435545930	DDC9E8	2547 242399	SERGEY RODIONOV	{"phone": "+70393754356"}
0005435545931	C4E9D0	7461 963080	ALEKSANDR SCHERBAKOV	{"email": "a-scherbakov101972@postgrespro.ru", "phone": "+70421100897"}
0005435545932	C4E9D0	9309 126010	DARYA ANISIMOVA	{"phone": "+70261972189"}
0005435545933	070704	6697 847430	EVGENIY ANDREEV	{"phone": "+70795502096"}
0005435545934	070704	7897 391904	MIKHAIL ZAKHAROV	{"phone": "+70168056915"}
0005435545935	2B2718	6508 741114	LARISA SCHERBAKOVA	{"email": "scherbakova.l.1972@postgrespro.ru", "phone": "+70457556832"}
0005435545936	2B2718	1065 132830	VLADIMIR BORISOV	{"email": "borisovv-22011971@postgrespro.ru", "phone": "+70302809967"}
0005435545937	2B2718	8397 102406	VALENTINA FADEEVA	{"phone": "+70452054223"}
0005435545938	6CDF29	7852 512839	IRINA MASLOVA	{"email": "imaslova-12111985@postgrespro.ru", "phone": "+70588455553"}
0005435545939	1118A6	0646 030172	VLADISLAV KISELEV	{"phone": "+70835019812"}
0005435545940	863A38	8904 834247	TATYANA ZAYCEVA	{"email": "tatyana.zayceva_20041970@postgrespro.ru", "phone": "+70403511898"}
0005435545941	863A38	8714 404665	ALEKSEY MOROZOV	{"phone": "+70195693806"}
0005435545942	C1016F	6064 499471	GALINA NOVIKOVA	{"phone": "+70910857874"}
0005435545943	DF3FE5	0770 668606	TATYANA FOMINA	{"phone": "+70748664708"}
0005435545944	000181	6799 285573	ALEKSANDR ZHUKOV	{"email": "aleksandrzhukov111972@postgrespro.ru", "phone": "+70411811316"}
0005435545945	000181	0929 739492	EVGENIYA KARPOVA	{"email": "karpovaevgeniya.1985@postgrespro.ru", "phone": "+70669289906"}
0005435545946	089B5C	5142 806575	NATALYA PAVLOVA	{"phone": "+70758856396"}
0005435545947	ECB7B1	9965 087484	VLADISLAV SEMENOV	{"email": "semenov-vladislav_1967@postgrespro.ru", "phone": "+70760349648"}
0005435545948	9194FA	4822 636249	VALENTINA PETROVA	{"email": "petrova.v031980@postgrespro.ru", "phone": "+70478843030"}
0005435545949	0093C5	8589 429942	SERGEY ZAKHAROV	{"email": "zakharovsergey051973@postgrespro.ru", "phone": "+70435751812"}
0005435545950	6A362A	6307 121113	ANATOLIY NIKOLAEV	{"phone": "+70638585927"}
0005435545951	9DB91E	9623 750820	ALEKSANDR KRASNOV	{"phone": "+70078645072"}
0005435545952	ACDF03	2671 324089	IRINA ALEKSEEVA	{"email": "alekseeva-irina_081974@postgrespro.ru", "phone": "+70917276887"}
0005435545953	ACDF03	9267 395974	ROMAN VASILEV	{"phone": "+70534915030"}
0005435545954	8BB339	2301 613273	OLGA GAVRILOVA	{"email": "o_gavrilova22081982@postgrespro.ru", "phone": "+70884758895"}
0005435545955	C0102E	8342 182015	LYUDMILA VASILEVA	{"email": "l.vasileva-08031968@postgrespro.ru", "phone": "+70542660169"}
0005435545956	C0102E	6262 727790	GALINA TIMOFEEVA	{"phone": "+70495183460"}
0005435545957	4F8631	4563 445983	MAKSIM SCHERBAKOV	{"email": "scherbakov.maksim_1978@postgrespro.ru", "phone": "+70222907644"}
0005435545958	ADA650	7411 170398	YURIY NAZAROV	{"email": "nazarov-y.1971@postgrespro.ru", "phone": "+70998786129"}
0005435545959	5545F8	5265 196408	SERGEY VOROBEV	{"email": "sergey_vorobev_041976@postgrespro.ru", "phone": "+70740984937"}
0005435545960	D62950	3731 712161	ANDREY SOKOLOV	{"email": "a.sokolov121973@postgrespro.ru", "phone": "+70975721851"}
0005435545961	1AF7C0	0426 770798	EKATERINA KUZNECOVA	{"phone": "+70242244434"}
0005435545962	1AF7C0	6010 135850	RUSLAN MIKHAYLOV	{"phone": "+70618170445"}
0005435545963	FD0BFF	4226 123402	YURIY PAVLOV	{"email": "pavlov-y-061960@postgrespro.ru", "phone": "+70713532407"}
0005435545964	A78C3B	6991 000067	OLEG SERGEEV	{"email": "olegsergeev31011974@postgrespro.ru", "phone": "+70059170381"}
0005435545965	A78C3B	0562 077851	IRINA POPOVA	{"phone": "+70811019077"}
0005435545966	A34FA6	0990 955053	ALEKSANDR SOLOVEV	{"email": "asolovev-121969@postgrespro.ru", "phone": "+70035628157"}
0005435545967	8E31EA	0091 245009	NADEZHDA ABRAMOVA	{"phone": "+70318920796"}
0005435545968	FDA654	6880 909330	VLADIMIR GORBUNOV	{"email": "vgorbunov19031976@postgrespro.ru", "phone": "+70209555500"}
0005435545969	E8132D	2107 441733	ALEKSEY KOZLOV	{"email": "kozlov_a-091965@postgrespro.ru", "phone": "+70118264821"}
0005435545970	E8132D	3878 643504	VASILIY BORISOV	{"email": "borisov-vasiliy061976@postgrespro.ru", "phone": "+70692253349"}
0005435545971	E8132D	3353 137901	GALINA MAKAROVA	{"phone": "+70998304542"}
0005435545972	1606F8	9416 839304	MARINA STEPANOVA	{"phone": "+70171110707"}
0005435545973	78D5D7	5813 434965	ELENA MAKSIMOVA	{"email": "maksimova_elena_21101962@postgrespro.ru", "phone": "+70994205309"}
0005435545974	78D5D7	7266 472923	NIKOLAY DAVYDOV	{"email": "davydov-nikolay_03021982@postgrespro.ru", "phone": "+70263864412"}
0005435545975	48CEC0	8290 741040	FEDOR OSIPOV	{"phone": "+70150763579"}
0005435545976	48CEC0	9531 471030	TATYANA KOROLEVA	{"email": "tatyana.koroleva-29091963@postgrespro.ru", "phone": "+70726919596"}
0005435545982	081934	9831 734974	IRINA EGOROVA	{"email": "iegorova-13081966@postgrespro.ru", "phone": "+70341807028"}
0005435545983	F8304B	3198 377545	MIKHAIL SOKOLOV	{"phone": "+70423311236"}
0005435545984	F8304B	9178 227351	GULFIYA FEDOROVA	{"email": "g-fedorova031968@postgrespro.ru", "phone": "+70187395159"}
0005435545985	E7FF0A	7121 353086	ALEKSANDR GAVRILOV	{"email": "gavrilov.a1976@postgrespro.ru", "phone": "+70642881572"}
0005435545986	E7FF0A	4784 052240	MIKHAIL ANDREEV	{"email": "andreev-m011981@postgrespro.ru", "phone": "+70136383228"}
0005435545987	1C0D42	6186 368481	OKSANA ZHUKOVA	{"phone": "+70629515081"}
0005435545988	EDDAA9	8524 146450	ANDREY OSIPOV	{"email": "osipov_andrey.1962@postgrespro.ru", "phone": "+70400632287"}
0005435545989	EDDAA9	1734 790364	LYUDMILA SIDOROVA	{"email": "lyudmilasidorova11011981@postgrespro.ru", "phone": "+70455570313"}
0005435545990	EDDAA9	0772 481957	MARIYA KOMAROVA	{"email": "komarova-m-20021967@postgrespro.ru", "phone": "+70629967351"}
0005435545991	FE9532	6960 851685	VERA LUKYANOVA	{"email": "vera-lukyanova_15021993@postgrespro.ru", "phone": "+70677422541"}
0005435545992	9C15F4	7318 896379	ALEKSANDR ANDREEV	{"phone": "+70815951130"}
0005435545993	600281	1846 963568	VASILIY SOROKIN	{"phone": "+70224056017"}
0005435545994	600281	4802 151884	OLGA NIKITINA	{"email": "olganikitina-111978@postgrespro.ru", "phone": "+70189803088"}
0005435545995	75F4E6	3295 759227	ALEKSANDR SCHERBAKOV	{"email": "ascherbakov_1968@postgrespro.ru", "phone": "+70258945774"}
0005435545996	D2EFDC	2457 462544	INESSA ZHUKOVA	{"email": "zhukovainessa1971@postgrespro.ru", "phone": "+70982095144"}
0005435545997	854E2A	5906 717155	NATALYA ROMANOVA	{"email": "n-romanova_25081977@postgrespro.ru", "phone": "+70380592103"}
0005435545998	129F8F	5944 231323	DANIL TARASOV	{"phone": "+70980318668"}
0005435545999	129F8F	3315 538383	RIMMA SOKOLOVA	{"email": "rimma-sokolova.1980@postgrespro.ru", "phone": "+70219966974"}
0005435546000	669212	0904 266832	NINA ZOTOVA	{"email": "n.zotova-041968@postgrespro.ru", "phone": "+70238575605"}
0005435546001	E73EB8	4742 695693	NINA ILINA	{"phone": "+70762718042"}
0005435546002	561A19	0011 923738	DARYA NAZAROVA	{"phone": "+70814431204"}
0005435546003	8B9121	8501 723681	IGOR FILIPPOV	{"phone": "+70707185418"}
0005435546224	D48CA9	3709 825247	ALEKSANDR MAKSIMOV	{"email": "a-maksimov.1971@postgrespro.ru", "phone": "+70428643979"}
0005435546225	D48CA9	3151 210743	LYUBOV BELOVA	{"phone": "+70011829177"}
0005435546226	F81015	9423 062859	IRINA BELYAEVA	{"email": "irina_belyaeva1971@postgrespro.ru", "phone": "+70101149481"}
0005435546227	8B3236	0524 342622	KLAVDIYA ROMANOVA	{"email": "k_romanova_26101970@postgrespro.ru", "phone": "+70814563048"}
0005435546228	0FE968	3241 374735	OLGA ALEKSANDROVA	{"phone": "+70307700889"}
0005435546229	283B1E	1291 786383	DENIS KUDRYASHOV	{"email": "kudryashov.denis-03051968@postgrespro.ru", "phone": "+70096713412"}
0005435546230	E78FD5	3148 214487	SVYATOSLAV SOKOLOV	{"email": "sokolov-svyatoslav.08021972@postgrespro.ru", "phone": "+70952151554"}
0005435546231	8C7CF6	6364 607812	NATALYA KUZNECOVA	{"phone": "+70478873517"}
0005435546232	8C7CF6	0023 384855	ALEKSANDR KONOVALOV	{"phone": "+70584283348"}
0005435546234	93E501	9739 295123	ALEKSANDR BARANOV	{"phone": "+70653989383"}
0005435546235	0C25AA	1319 237964	NINA SMIRNOVA	{"email": "nina.smirnova_19031976@postgrespro.ru", "phone": "+70784569041"}
0005435546236	0C25AA	4764 556204	GALINA SIDOROVA	{"email": "g.sidorova-1973@postgrespro.ru", "phone": "+70463165857"}
0005435546237	75F924	0700 940045	DANILA ZAKHAROV	{"phone": "+70992172076"}
0005435546238	155460	7140 270644	OLGA RODIONOVA	{"phone": "+70953796589"}
0005435546239	2302B4	2012 695902	VLADIMIR SIDOROV	{"phone": "+70619782338"}
0005435546240	DF0621	1662 306042	VERONIKA KARPOVA	{"phone": "+70611478198"}
0005435546241	7C9960	4152 658919	ANTONINA NAUMOVA	{"phone": "+70410750246"}
0005435546242	7C9960	6221 348826	RAISA KONOVALOVA	{"email": "konovalova_r051975@postgrespro.ru", "phone": "+70115102774"}
0005435548417	99F9C0	8460 653103	SEMEN IVANOV	{"email": "s_ivanov121981@postgrespro.ru", "phone": "+70854351316"}
0005435548418	B0F92D	3378 057830	GENNADIY GAVRILOV	{"email": "gavrilov.g.1966@postgrespro.ru", "phone": "+70061662130"}
0005435548419	B0F92D	3934 308507	SVETLANA KUZNECOVA	{"email": "s_kuznecova-05091968@postgrespro.ru", "phone": "+70465571593"}
0005435548420	83CCA1	7026 372188	VADIM ALEKSEEV	{"phone": "+70031914183"}
0005435548421	39682D	7748 165578	TATYANA MALYSHEVA	{"email": "t_malysheva1976@postgrespro.ru", "phone": "+70204226347"}
0005435548422	3E237C	9489 087913	IRINA EGOROVA	{"email": "irinaegorova-12091971@postgrespro.ru", "phone": "+70554616571"}
0005435548423	3E237C	6839 659480	VLADIMIR KONOVALOV	{"email": "konovalov_v-04051964@postgrespro.ru", "phone": "+70889793218"}
0005435548424	58DCB1	8727 675922	NIKOLAY ANTONOV	{"email": "antonov.nikolay1962@postgrespro.ru", "phone": "+70722136465"}
0005435548425	7EB8B3	4518 461795	ALEKSEY MELNIKOV	{"phone": "+70775726785"}
0005435548426	7EB8B3	5272 660933	VERA KOZLOVA	{"phone": "+70757312070"}
0005435548427	BD35FB	8801 000712	SERGEY SCHERBAKOV	{"email": "s_scherbakov_1970@postgrespro.ru", "phone": "+70901797899"}
0005435548428	BD35FB	8730 589051	GULNARA ZAKHAROVA	{"phone": "+70366382683"}
0005435548429	81C2E3	3954 670572	ILYA NAUMOV	{"email": "ilya_naumov_1976@postgrespro.ru", "phone": "+70061321075"}
0005435548430	12B6DC	4084 146086	IRINA ERMAKOVA	{"phone": "+70012464263"}
0005435548431	12B6DC	4470 535337	EGOR RODIONOV	{"email": "e-rodionov.1974@postgrespro.ru", "phone": "+70867902734"}
0005435548432	12B6DC	0739 880818	ROMAN STEPANOV	{"email": "stepanov.r021970@postgrespro.ru", "phone": "+70427219495"}
0005435548433	E26760	6750 098807	SERGEY PETROV	{"email": "petrov-s.16101963@postgrespro.ru", "phone": "+70657044609"}
0005435551594	0A977C	5901 785141	ELENA SOLOVEVA	{"phone": "+70799824269"}
0005435548434	E26760	7388 435011	ALEKSANDR MARTYNOV	{"email": "a-martynov_27061969@postgrespro.ru", "phone": "+70363852423"}
0005435548435	7E2453	0546 277998	LYUBOV ANTONOVA	{"email": "antonova-lyubov_011981@postgrespro.ru", "phone": "+70430271138"}
0005435548436	7E2453	5034 153947	ANATOLIY IVANOV	{"phone": "+70995101436"}
0005435548437	CB13D9	5067 603167	MAKSIM RODIONOV	{"phone": "+70400518071"}
0005435548438	CB13D9	7066 886204	RIMMA GAVRILOVA	{"email": "gavrilovar.1972@postgrespro.ru", "phone": "+70245206800"}
0005435548439	FBDCDB	2792 604153	SVETLANA POPOVA	{"phone": "+70692432553"}
0005435548440	B31196	6534 520674	ALEKSANDR NIKITIN	{"email": "aleksandr_nikitin.031982@postgrespro.ru", "phone": "+70078983061"}
0005435548441	A020CC	2773 205369	VADIM ROMANOV	{"phone": "+70275714881"}
0005435548442	A020CC	7583 489973	EGOR MAKAROV	{"phone": "+70877765516"}
0005435548443	465CC7	7979 797093	GALINA POLYAKOVA	{"email": "galina.polyakova-10021960@postgrespro.ru", "phone": "+70140994327"}
0005435548444	0389DD	0052 831746	EVGENIY SIDOROV	{"email": "e.sidorov12011971@postgrespro.ru", "phone": "+70960503545"}
0005435548445	C5DF30	0056 259429	ELIZAVETA PETROVA	{"email": "petrova_e_1968@postgrespro.ru", "phone": "+70463117158"}
0005435548446	C5DF30	4206 900882	NIKOLAY MOROZOV	{"email": "nmorozov-051964@postgrespro.ru", "phone": "+70955377834"}
0005435548447	A60273	4738 394108	YULIYA ROMANOVA	{"email": "yuliya_romanova_14101976@postgrespro.ru", "phone": "+70296479158"}
0005435548448	A5D9AE	2965 544298	VERA ANDREEVA	{"phone": "+70122493600"}
0005435548449	A5D9AE	5580 905725	ALEKSANDR VLASOV	{"phone": "+70722886036"}
0005435548450	809656	2100 691911	SVETLANA SOROKINA	{"phone": "+70900153278"}
0005435548451	809656	7590 600527	ANTON SOROKIN	{"phone": "+70302833319"}
0005435548452	FD787D	2446 645345	ANATOLIY KUZNECOV	{"email": "a.kuznecov.121969@postgrespro.ru", "phone": "+70925862485"}
0005435548453	B613E0	3171 561004	VYACHESLAV NOVIKOV	{"email": "v_novikov_071968@postgrespro.ru", "phone": "+70965769461"}
0005435548454	B613E0	4441 081130	NIKITA MAKAROV	{"phone": "+70831316467"}
0005435548455	CE4A03	1110 205574	LIYA ARKHIPOVA	{"phone": "+70541444273"}
0005435548456	FBE823	3547 817398	TATYANA FROLOVA	{"email": "frolova_t_101963@postgrespro.ru", "phone": "+70412125575"}
0005435548457	CF1ACD	6033 077895	MIKHAIL MIKHAYLOV	{"phone": "+70018905622"}
0005435548458	CF1ACD	8441 538291	ROMAN MAKAROV	{"email": "makarovroman101972@postgrespro.ru", "phone": "+70812008299"}
0005435548459	51C270	4216 235775	IGOR NAZAROV	{"phone": "+70449975530"}
0005435548460	060293	5178 425801	GALINA ABRAMOVA	{"phone": "+70783657933"}
0005435548461	BAFC84	6683 810652	GENNADIY KOZLOV	{"email": "kozlovgennadiy091985@postgrespro.ru", "phone": "+70372765569"}
0005435548462	FA8363	2064 698705	OLEG KUZNECOV	{"email": "o_kuznecov1975@postgrespro.ru", "phone": "+70353443167"}
0005435548463	011991	4037 914796	ANDREY PAVLOV	{"email": "pavlov.andrey.1965@postgrespro.ru", "phone": "+70451207811"}
0005435548464	C38FF1	7564 787224	TAMARA ISAEVA	{"email": "isaeva-t1977@postgrespro.ru", "phone": "+70458107122"}
0005435548465	975C9A	4278 523702	OLGA MATVEEVA	{"email": "o.matveeva.1968@postgrespro.ru", "phone": "+70113248757"}
0005435548466	975C9A	0903 669715	ALEKSEY GUSEV	{"phone": "+70911708980"}
0005435548467	C6AF96	0557 163211	ELENA MARTYNOVA	{"email": "martynova-e_26071961@postgrespro.ru", "phone": "+70852284809"}
0005435548468	893EC5	6095 632170	NATALYA PETROVA	{"email": "n_petrova-03031967@postgrespro.ru", "phone": "+70354033336"}
0005435548469	893EC5	5163 168411	MIKHAIL GORBUNOV	{"email": "m.gorbunov-1971@postgrespro.ru", "phone": "+70113087039"}
0005435548470	893EC5	6166 359494	SERGEY KISELEV	{"email": "sergey.kiselev.21031964@postgrespro.ru", "phone": "+70741765336"}
0005435548471	11B51E	4130 470436	EVGENIY VOROBEV	{"phone": "+70990464073"}
0005435548472	96C659	7336 009802	ALLA IVANOVA	{"phone": "+70833076771"}
0005435548473	96C659	3536 689786	NATALYA POTAPOVA	{"email": "potapova-n.15021974@postgrespro.ru", "phone": "+70550145406"}
0005435548474	FB519D	5838 424563	SVETLANA MIRONOVA	{"phone": "+70447159637"}
0005435548475	5B9614	4843 727304	SERGEY GAVRILOV	{"phone": "+70376734547"}
0005435548476	38411C	9092 872514	TATYANA IVANOVA	{"phone": "+70168332142"}
0005435548477	38411C	4685 677898	ANDREY NIKOLAEV	{"email": "nikolaev-a061971@postgrespro.ru", "phone": "+70090070206"}
0005435548478	0B05B7	9667 974678	MARINA NIKITINA	{"email": "marina.nikitina.1966@postgrespro.ru", "phone": "+70509212134"}
0005435548479	2EFA54	8438 112361	SERGEY ISAEV	{"email": "isaev_s13081960@postgrespro.ru", "phone": "+70682837301"}
0005435548480	2EFA54	3412 660468	VIKTOR MIRONOV	{"phone": "+70784809897"}
0005435548481	CB6395	9035 055044	EKATERINA EGOROVA	{"email": "eegorova081970@postgrespro.ru", "phone": "+70385650161"}
0005435548482	CB6395	9823 961992	SERGEY ZHURAVLEV	{"email": "s-zhuravlev.21061964@postgrespro.ru", "phone": "+70096763005"}
0005435548483	CB6395	2429 511864	VALERIY SMIRNOV	{"email": "valeriy-smirnov-101979@postgrespro.ru", "phone": "+70607491197"}
0005435548484	7E80B1	7726 929119	ALEKSANDR ORLOV	{"email": "orlov_aleksandr.17011966@postgrespro.ru", "phone": "+70940319424"}
0005435548485	7E80B1	0546 649965	OLGA DENISOVA	{"phone": "+70840646371"}
0005435548486	1ED0C6	5165 323953	VADIM ROMANOV	{"phone": "+70229525276"}
0005435548487	1ED0C6	6943 074493	EVGENIY SCHERBAKOV	{"phone": "+70102881395"}
0005435548488	519B5B	1044 977882	ANNA NIKIFOROVA	{"email": "anikiforova_17011975@postgrespro.ru", "phone": "+70923657096"}
0005435548489	519B5B	3913 475216	MARIYA ZAKHAROVA	{"phone": "+70414251553"}
0005435548490	519B5B	1127 864071	VADIM MIKHAYLOV	{"email": "mikhaylovvadim.031954@postgrespro.ru", "phone": "+70825059851"}
0005435548491	1E26B5	7838 842088	VLADIMIR CHERNOV	{"phone": "+70524633414"}
0005435548492	4C5908	9023 622866	GUZEL FROLOVA	{"email": "g-frolova051980@postgrespro.ru", "phone": "+70017035816"}
0005435551653	E65423	2752 033291	OLGA SOKOLOVA	{"phone": "+70877443988"}
0005435548493	1D1AAD	2802 568755	ELIZAVETA ZAYCEVA	{"email": "zayceva.elizaveta.25021966@postgrespro.ru", "phone": "+70041924825"}
0005435548494	9799DA	6067 737057	ELENA IVANOVA	{"phone": "+70908267930"}
0005435548495	9799DA	0078 596878	VALERIY ZAKHAROV	{"email": "zakharov_valeriy-1975@postgrespro.ru", "phone": "+70016447153"}
0005435548496	A1F66F	0293 573166	TAMARA ARKHIPOVA	{"email": "arkhipova.t_1971@postgrespro.ru", "phone": "+70364715500"}
0005435548497	A1F66F	6834 134609	NINA NIKIFOROVA	{"phone": "+70124910870"}
0005435548498	6C56F7	0742 794449	DMITRIY SOKOLOV	{"phone": "+70609687147"}
0005435548499	AF8076	2175 338905	ANTON ANDREEV	{"email": "andreevanton29111980@postgrespro.ru", "phone": "+70111791525"}
0005435548500	D07089	1551 890281	ELENA MARTYNOVA	{"phone": "+70815085148"}
0005435548501	555DE0	3719 420112	LILIYA LAZAREVA	{"email": "l_lazareva091973@postgrespro.ru", "phone": "+70202402149"}
0005435548502	A0A961	9139 744457	IRINA SAVELEVA	{"email": "saveleva-irina-1971@postgrespro.ru", "phone": "+70426080592"}
0005435548503	CF57CE	0236 042358	NATALYA KOZLOVA	{"phone": "+70679908439"}
0005435548504	55FC6E	0124 283366	EVDOKIYA PAVLOVA	{"email": "evdokiya-pavlova_1977@postgrespro.ru", "phone": "+70848866637"}
0005435548505	2411AF	2918 938884	SVETLANA FEDOROVA	{"phone": "+70460171193"}
0005435548506	2411AF	7671 722177	NIKITA MOROZOV	{"email": "nikita.morozov-011963@postgrespro.ru", "phone": "+70864739746"}
0005435548507	2BD353	7474 383581	VALENTINA RYABOVA	{"email": "vryabova1966@postgrespro.ru", "phone": "+70757718502"}
0005435548508	A6B899	0472 318344	IVAN ROMANOV	{"email": "i.romanov24101970@postgrespro.ru", "phone": "+70552979797"}
0005435548509	0B6B69	8207 359357	VITALIY MOISEEV	{"phone": "+70619771971"}
0005435548510	0B6B69	0599 636622	LARISA ROMANOVA	{"phone": "+70780070581"}
0005435548511	BEFFAA	4783 512942	NIKOLAY SOROKIN	{"phone": "+70750504470"}
0005435548512	6AF450	1924 929228	MAKSIM ZAKHAROV	{"email": "maksimzakharov-071964@postgrespro.ru", "phone": "+70561834048"}
0005435548513	6AF450	3837 083151	ELENA BORISOVA	{"phone": "+70576480336"}
0005435548514	0B620C	4440 875468	MIKHAIL AFANASEV	{"phone": "+70287744282"}
0005435548515	0B620C	3386 020706	NINA KISELEVA	{"email": "kiseleva.n.081971@postgrespro.ru", "phone": "+70557858493"}
0005435548516	172D5E	8476 924736	NINA VOROBEVA	{"email": "n_vorobeva111981@postgrespro.ru", "phone": "+70703741199"}
0005435548517	172D5E	6581 697288	LYUBOV FEDOROVA	{"email": "fedorova.l-1974@postgrespro.ru", "phone": "+70906894942"}
0005435548518	172D5E	4276 319885	NINA RYABOVA	{"email": "nina_ryabova01051976@postgrespro.ru", "phone": "+70471599610"}
0005435548519	2592DE	8136 418419	IVAN BONDARENKO	{"email": "bondarenkoi-14021963@postgrespro.ru", "phone": "+70630764328"}
0005435548520	747B0A	3865 699969	NADEZHDA MALYSHEVA	{"phone": "+70618545656"}
0005435548521	747B0A	4679 106048	YAKOV GAVRILOV	{"email": "gavrilov.yakov_1962@postgrespro.ru", "phone": "+70158104405"}
0005435548522	CDA76D	8783 293914	VYACHESLAV GORBUNOV	{"email": "v-gorbunov_021961@postgrespro.ru", "phone": "+70836789595"}
0005435548523	32DED4	0678 468876	VIKTOR CHERNOV	{"email": "chernov-viktor041968@postgrespro.ru", "phone": "+70727288647"}
0005435548524	5A2692	3477 514374	LYUDMILA KULIKOVA	{"phone": "+70606548507"}
0005435548525	33CDFF	9017 596520	OLEG PETROV	{"phone": "+70970291508"}
0005435548526	4E393D	4215 856669	NINA KOZLOVA	{"phone": "+70299188026"}
0005435548527	2ADBE2	3250 545753	TAISIYA NIKOLAEVA	{"phone": "+70934341082"}
0005435548528	2ADBE2	6361 011351	MARINA NIKIFOROVA	{"phone": "+70482365417"}
0005435548529	F4C6C7	4183 152982	VALENTINA MELNIKOVA	{"email": "valentina-melnikova-27091976@postgrespro.ru", "phone": "+70991696612"}
0005435548530	151720	1885 998474	YURIY VASILEV	{"email": "yuriy_vasilev_041959@postgrespro.ru", "phone": "+70959234299"}
0005435548531	F5A80F	2686 574005	DARYA POLYAKOVA	{"phone": "+70516664030"}
0005435548532	4403A6	8557 182568	ANDREY TARASOV	{"phone": "+70324796605"}
0005435548533	0C64E9	8432 663954	EVGENIYA SEMENOVA	{"phone": "+70076015347"}
0005435548534	0C64E9	4546 931930	NIKITA TIKHONOV	{"email": "tikhonov.n-13111960@postgrespro.ru", "phone": "+70080137287"}
0005435548535	260CC0	6878 534261	VALENTINA ANTONOVA	{"phone": "+70731837079"}
0005435548536	7C1DA5	4235 438162	ANDREY TIKHONOV	{"email": "tikhonov-andrey_1966@postgrespro.ru", "phone": "+70921131583"}
0005435548537	7C1DA5	3024 865114	ANASTASIYA ZAYCEVA	{"email": "zayceva.anastasiya071970@postgrespro.ru", "phone": "+70497118113"}
0005435548538	B0AD9F	4731 281078	SERGEY KAZAKOV	{"phone": "+70857405167"}
0005435548539	B0AD9F	9920 478029	RUSLAN GUSEV	{"email": "gusevr-06121965@postgrespro.ru", "phone": "+70166927368"}
0005435548540	603CE1	9547 096741	ELENA BOGDANOVA	{"email": "bogdanova.e_061978@postgrespro.ru", "phone": "+70588065133"}
0005435548541	603CE1	3870 563096	DARYA ROMANOVA	{"phone": "+70574118634"}
0005435548542	6CC83B	6854 152227	PAVEL KUDRYASHOV	{"email": "pkudryashov1971@postgrespro.ru", "phone": "+70705580688"}
0005435548543	6CC83B	4915 309946	DENIS POPOV	{"email": "denis.popov_081978@postgrespro.ru", "phone": "+70028033234"}
0005435548544	7DDBEF	0791 372767	MARIYA POPOVA	{"email": "m_popova.06021970@postgrespro.ru", "phone": "+70902701042"}
0005435548545	F56054	7597 658468	ALEKSANDR NAZAROV	{"phone": "+70604735778"}
0005435548546	17F7B9	6937 636356	INNA OSIPOVA	{"phone": "+70286625697"}
0005435548547	A64C85	5611 584913	ALEKSEY POPOV	{"email": "popov_aleksey.081983@postgrespro.ru", "phone": "+70645131151"}
0005435548548	A64C85	5214 770059	NATALYA KRASNOVA	{"phone": "+70299994353"}
0005435548549	299648	7844 381471	IVAN BARANOV	{"email": "ivan.baranov1976@postgrespro.ru", "phone": "+70469484892"}
0005435548550	EEDD96	8734 644584	YURIY ALEKSANDROV	{"email": "y_aleksandrov_081964@postgrespro.ru", "phone": "+70475720225"}
0005435548551	06C70D	3952 042988	LYUDMILA ILINA	{"phone": "+70250176269"}
0005435548552	06C70D	8364 343904	ZINAIDA KOZLOVA	{"email": "z-kozlova-1971@postgrespro.ru", "phone": "+70389972984"}
0005435548553	06C70D	9444 283358	SVETLANA POPOVA	{"email": "popova_s-16091977@postgrespro.ru", "phone": "+70103379350"}
0005435548554	609E88	9392 557218	NIKOLAY KUZNECOV	{"phone": "+70720361677"}
0005435548555	112473	3559 053003	NADEZHDA ALEKSANDROVA	{"phone": "+70658074542"}
0005435548556	112473	9876 652317	VITALIY NAZAROV	{"email": "vitaliy_nazarov.1959@postgrespro.ru", "phone": "+70746204256"}
0005435548557	3FBCBD	2470 216364	MATVEY KOZLOV	{"email": "mkozlov.14021978@postgrespro.ru", "phone": "+70024639658"}
0005435548558	283915	9959 518890	DIANA KONOVALOVA	{"phone": "+70538272689"}
0005435548559	C941D7	8081 684766	MARIYA SOROKINA	{"email": "msorokina.1981@postgrespro.ru", "phone": "+70047083235"}
0005435548560	C941D7	3445 801665	SERGEY SAVELEV	{"phone": "+70710648595"}
0005435548561	4D489A	9432 890900	ALEKSEY VASILEV	{"email": "vasilev_aleksey.031984@postgrespro.ru", "phone": "+70451188826"}
0005435548562	A129F8	0928 041139	ANASTASIYA SMIRNOVA	{"email": "a_smirnova_061966@postgrespro.ru", "phone": "+70245523521"}
0005435548563	A129F8	1906 686908	ANDREY KARPOV	{"phone": "+70740306214"}
0005435548564	A129F8	9074 241370	YURIY SOKOLOV	{"phone": "+70487995819"}
0005435548565	2C0040	2607 405099	OLGA NOVIKOVA	{"phone": "+70843093483"}
0005435548566	F61A71	7275 442474	SVETLANA LOGINOVA	{"email": "sloginova_12041970@postgrespro.ru", "phone": "+70528788785"}
0005435548567	35B686	7871 193605	GALINA KUZNECOVA	{"email": "galina.kuznecova-04081972@postgrespro.ru", "phone": "+70567084707"}
0005435548568	35B686	4632 410956	VYACHESLAV MARTYNOV	{"phone": "+70630248515"}
0005435548569	3EFBFE	7251 468016	NINA ZOTOVA	{"phone": "+70537065071"}
0005435548570	3EFBFE	3612 993758	TATYANA KOROLEVA	{"email": "t-koroleva_071969@postgrespro.ru", "phone": "+70929479219"}
0005435548571	1792C3	6401 349282	VIKTOR ZHUKOV	{"email": "zhukov-viktor-1969@postgrespro.ru", "phone": "+70299782310"}
0005435548572	75B6A6	8404 318471	ALEKSANDR PETROV	{"email": "a.petrov_041963@postgrespro.ru", "phone": "+70958233225"}
0005435548573	75B6A6	3698 635940	KHALIDA PETROVA	{"phone": "+70281583240"}
0005435548574	541A2F	5170 131096	ZINAIDA BARANOVA	{"email": "z_baranova_121969@postgrespro.ru", "phone": "+70310071768"}
0005435548575	541A2F	8316 881956	OKSANA NIKITINA	{"phone": "+70477962185"}
0005435548576	87C137	0449 036769	BORIS EGOROV	{"phone": "+70543747238"}
0005435548577	63E49A	1829 200098	VLADIMIR CHERNOV	{"email": "chernov.vladimir.121968@postgrespro.ru", "phone": "+70604573402"}
0005435548578	EF77B6	7971 668111	ALEKSANDR FROLOV	{"phone": "+70716212774"}
0005435548579	EF77B6	6017 186604	IRINA SCHERBAKOVA	{"email": "irinascherbakova-1973@postgrespro.ru", "phone": "+70638893372"}
0005435548580	26EE4B	1279 894052	ALEKSEY DAVYDOV	{"email": "davydovaleksey_081976@postgrespro.ru", "phone": "+70977622630"}
0005435548581	918A5B	7045 447841	OLEG POPOV	{"email": "popov-o.20021979@postgrespro.ru", "phone": "+70344249750"}
0005435548582	204AFB	0324 163290	LIDIYA GORBUNOVA	{"phone": "+70880684775"}
0005435548583	6968EB	9821 270196	VLADIMIR GAVRILOV	{"email": "gavrilov-v1977@postgrespro.ru", "phone": "+70575351273"}
0005435548584	6968EB	2898 806695	VYACHESLAV IVANOV	{"email": "ivanov.v051965@postgrespro.ru", "phone": "+70385399076"}
0005435548585	0A97AC	6098 353096	TIKHON FILIPPOV	{"email": "tikhon_filippov031974@postgrespro.ru", "phone": "+70479854503"}
0005435548586	BBECF1	9517 711945	GALINA TIKHONOVA	{"phone": "+70420136005"}
0005435548587	D15E17	8117 746861	ALEKSANDR SCHERBAKOV	{"phone": "+70807249605"}
0005435548588	7068F5	2311 086845	VLADIMIR ROMANOV	{"email": "romanov_vladimir061969@postgrespro.ru", "phone": "+70599818805"}
0005435548589	7068F5	5262 997431	ALEKSEY BELOV	{"email": "belov_aleksey_26041966@postgrespro.ru", "phone": "+70331139434"}
0005435548590	6B17C7	2842 580845	DENIS KRASNOV	{"email": "krasnovd-12061976@postgrespro.ru", "phone": "+70348526024"}
0005435548591	54D1AD	5429 507532	SERGEY YAKOVLEV	{"phone": "+70981705274"}
0005435548592	7726CE	0162 293564	MIKHAIL MELNIKOV	{"email": "m.melnikov.1964@postgrespro.ru", "phone": "+70529829245"}
0005435548593	B1B5D8	7587 990385	SERGEY SCHERBAKOV	{"phone": "+70461545650"}
0005435548594	2F0377	8167 786110	LYUDMILA ORLOVA	{"email": "lorlova.1970@postgrespro.ru", "phone": "+70800398577"}
0005435548595	49BBC5	9471 116714	ALEKSANDR FOMIN	{"email": "fomin.a.081968@postgrespro.ru", "phone": "+70121365410"}
0005435548596	451D64	8300 838679	ELIZAVETA KUZMINA	{"email": "e.kuzmina_091983@postgrespro.ru", "phone": "+70812283065"}
0005435548597	004619	4657 335949	ELENA SAVELEVA	{"email": "elena.saveleva.26061974@postgrespro.ru", "phone": "+70218417372"}
0005435548598	F765DD	6546 676739	YANA GORBUNOVA	{"phone": "+70849128127"}
0005435548599	F765DD	0443 872795	SERGEY ZAKHAROV	{"phone": "+70795443682"}
0005435548600	B7264E	0382 099164	OLGA GORBUNOVA	{"phone": "+70254132216"}
0005435548601	B7264E	1774 870216	ANATOLIY ABRAMOV	{"email": "a-abramov_31101970@postgrespro.ru", "phone": "+70212356952"}
0005435548602	4EBC91	2913 808082	TATYANA KRASNOVA	{"email": "tatyana.krasnova011971@postgrespro.ru", "phone": "+70382301294"}
0005435548603	C465F8	1145 645566	ELLA RODIONOVA	{"email": "rodionovaella.01061968@postgrespro.ru", "phone": "+70731957697"}
0005435548604	337D92	8984 575538	YURIY SMIRNOV	{"phone": "+70288746085"}
0005435548605	6E331E	5485 134863	ALEKSANDR SIDOROV	{"email": "a_sidorov.22031976@postgrespro.ru", "phone": "+70637261765"}
0005435548606	6E331E	0772 996691	OLGA KOROLEVA	{"phone": "+70140074882"}
0005435548607	6DF8A8	1365 581415	GALINA PAVLOVA	{"phone": "+70050299973"}
0005435548608	2F461E	9051 735264	NINA IVANOVA	{"phone": "+70224134303"}
0005435548609	0827EB	2087 802716	ANASTASIYA LEBEDEVA	{"phone": "+70304905731"}
0005435548610	0827EB	8062 912738	OLEG AFANASEV	{"email": "oleg_afanasev_1980@postgrespro.ru", "phone": "+70914824890"}
0005435548611	55B597	7148 615044	LYUCIYA GERASIMOVA	{"email": "lyuciya-gerasimova_011975@postgrespro.ru", "phone": "+70403064094"}
0005435548612	05901E	1450 280637	SERGEY GRIGOREV	{"email": "s-grigorev_1975@postgrespro.ru", "phone": "+70146202685"}
0005435548613	0E511C	8022 772170	VITALIY IVANOV	{"email": "ivanovvitaliy1968@postgrespro.ru", "phone": "+70354342878"}
0005435548614	7B3B7A	2625 787566	NADEZHDA KOROLEVA	{"email": "koroleva_nadezhda-1967@postgrespro.ru", "phone": "+70824651650"}
0005435548615	7B3B7A	9953 052915	ANATOLIY AFANASEV	{"phone": "+70171945447"}
0005435548616	7B3B7A	2564 199603	ANNA NIKITINA	{"phone": "+70003276297"}
0005435548617	D43DA9	8089 373953	ELENA NIKOLAEVA	{"email": "e-nikolaeva_091979@postgrespro.ru", "phone": "+70325720542"}
0005435548618	891212	0008 483787	VLADIMIR SMIRNOV	{"email": "v-smirnov091978@postgrespro.ru", "phone": "+70227720914"}
0005435548619	B33A08	0430 393021	ALEKSANDR SMIRNOV	{"email": "smirnov.a1973@postgrespro.ru", "phone": "+70602415512"}
0005435548620	1B9EC6	4336 647778	TATYANA VASILEVA	{"email": "tatyana.vasileva091989@postgrespro.ru", "phone": "+70033079850"}
0005435548621	3C7976	4345 249291	MAKSIM KUZNECOV	{"email": "m-kuznecov-081978@postgrespro.ru", "phone": "+70044421083"}
0005435548622	8099B7	8652 733368	LIDIYA DANILOVA	{"phone": "+70727551699"}
0005435548623	EE13B7	6057 570208	RENAT DMITRIEV	{"email": "dmitrievr-031962@postgrespro.ru", "phone": "+70068497195"}
0005435548624	FC1A71	8082 170955	TATYANA NOVIKOVA	{"email": "novikova-t031978@postgrespro.ru", "phone": "+70753925209"}
0005435548625	E57F20	4921 423704	DARYA POPOVA	{"phone": "+70218620567"}
0005435548626	0F4F1C	4278 690685	TATYANA OSIPOVA	{"email": "osipova.tatyana-091971@postgrespro.ru", "phone": "+70062844202"}
0005435548627	0F4F1C	8501 696009	VLADIMIR MIKHAYLOV	{"phone": "+70771183749"}
0005435548628	0F4F1C	2577 309577	RUSLAN MAKSIMOV	{"email": "maksimov_r1986@postgrespro.ru", "phone": "+70834983591"}
0005435551490	79ADAA	3503 610545	MARIYA PETROVA	{"phone": "+70742759117"}
0005435551491	323C0E	8135 162042	ALEKSANDR KULIKOV	{"email": "aleksandrkulikov_25071971@postgrespro.ru", "phone": "+70116483242"}
0005435551492	7E1D8D	9896 265932	NINA ZAKHAROVA	{"phone": "+70815690226"}
0005435551493	7EAAB8	8900 932789	GENNADIY POPOV	{"email": "gennadiy.popov.1964@postgrespro.ru", "phone": "+70620134974"}
0005435551494	7209E0	0693 962609	TATYANA ALEKSEEVA	{"email": "talekseeva.1975@postgrespro.ru", "phone": "+70121159425"}
0005435551495	7209E0	4616 903615	OLGA ILINA	{"phone": "+70014509028"}
0005435551496	FDFBA8	4852 218528	OLGA OSIPOVA	{"email": "olga.osipova_17121965@postgrespro.ru", "phone": "+70139209770"}
0005435551497	FDFBA8	2175 630689	OLGA BARANOVA	{"phone": "+70172829255"}
0005435551498	5675E7	2788 123091	LYUDMILA NAUMOVA	{"phone": "+70200388778"}
0005435551499	5675E7	9587 598672	SERGEY MARTYNOV	{"phone": "+70791393745"}
0005435551500	8E3224	3200 920664	NADEZHDA NIKIFOROVA	{"phone": "+70706280130"}
0005435551501	8E3224	6439 696360	YULIYA SOKOLOVA	{"phone": "+70415970211"}
0005435551502	39E1D1	1702 710820	VLADIMIR TIMOFEEV	{"email": "timofeev-vladimir-031963@postgrespro.ru", "phone": "+70755832305"}
0005435551503	D02040	7288 417460	VLADIMIR KUZMIN	{"email": "v_kuzmin_10081964@postgrespro.ru", "phone": "+70148059252"}
0005435551504	D02040	5206 926163	DENIS KUZNECOV	{"email": "kuznecov_denis101978@postgrespro.ru", "phone": "+70750031380"}
0005435551505	3DF2B4	0553 735761	IRINA RODIONOVA	{"phone": "+70008110972"}
0005435551506	22B800	1935 319868	ROZA YUDINA	{"phone": "+70595720045"}
0005435551507	1D38FB	4923 063594	NIKOLAY KUDRYASHOV	{"email": "nikolay_kudryashov.10041971@postgrespro.ru", "phone": "+70543542058"}
0005435551508	1031F1	1782 614519	DARYA ZOTOVA	{"phone": "+70555100651"}
0005435551509	8A63D2	6049 785460	ANASTASIYA NAZAROVA	{"phone": "+70955503463"}
0005435551510	8A63D2	2339 946292	BORIS TARASOV	{"phone": "+70991452121"}
0005435551511	9159AE	9087 170618	YAROSLAV DMITRIEV	{"phone": "+70996187585"}
0005435551512	9159AE	3661 576761	MARIYA NIKOLAEVA	{"phone": "+70975681916"}
0005435551513	491B37	4281 302477	VADIM GORBUNOV	{"email": "vgorbunov081974@postgrespro.ru", "phone": "+70061214983"}
0005435551514	5D620A	5644 958655	MARIYA LAZAREVA	{"phone": "+70381701072"}
0005435551515	CB8FEA	8535 574126	DARYA GORBUNOVA	{"email": "d_gorbunova-011970@postgrespro.ru", "phone": "+70273783372"}
0005435551516	CB8FEA	8001 849241	NATALYA KAZAKOVA	{"email": "natalya_kazakova-1961@postgrespro.ru", "phone": "+70437830562"}
0005435551517	A697C1	1276 776710	VLADIMIR NOVIKOV	{"phone": "+70336110227"}
0005435551518	A697C1	4956 868776	EKATERINA BORISOVA	{"email": "eborisova.011967@postgrespro.ru", "phone": "+70459585295"}
0005435551519	AEFC30	4206 792064	ALEKSANDRA IVANOVA	{"phone": "+70770102828"}
0005435551520	AEFC30	7809 100290	GALINA POTAPOVA	{"email": "potapova.g.15091985@postgrespro.ru", "phone": "+70859003857"}
0005435551521	3C667E	6904 372086	IRINA DAVYDOVA	{"phone": "+70007927955"}
0005435551522	3CD04B	1797 016742	ALLA KUZNECOVA	{"email": "kuznecovaalla-06021977@postgrespro.ru", "phone": "+70562223658"}
0005435551523	39A20A	8036 041025	LEONID GERASIMOV	{"phone": "+70791715328"}
0005435551524	FB8564	5611 741404	ALEKSANDR ANTONOV	{"phone": "+70676517798"}
0005435551525	8E150B	1892 558958	NIKOLAY KULIKOV	{"email": "kulikov_n.25111978@postgrespro.ru", "phone": "+70819690633"}
0005435551526	954928	8277 005718	ALEKSANDR VASILEV	{"phone": "+70585856136"}
0005435551527	954928	7417 626188	LARISA ARKHIPOVA	{"email": "larisa-arkhipova_11051980@postgrespro.ru", "phone": "+70301979395"}
0005435551528	E3AA5F	4892 495059	EVGENIYA NAZAROVA	{"phone": "+70647314132"}
0005435551529	D2CD3D	0298 957374	MARINA SEMENOVA	{"email": "semenova-marina.1976@postgrespro.ru", "phone": "+70893427314"}
0005435551530	B08D8C	6479 555236	EVDOKIYA SCHERBAKOVA	{"email": "e_scherbakova.16091964@postgrespro.ru", "phone": "+70477502815"}
0005435551531	8FB573	1656 070443	NATALYA MOISEEVA	{"phone": "+70428486509"}
0005435551532	8FB573	9146 254739	KLAVDIYA MAKSIMOVA	{"phone": "+70503785689"}
0005435551533	A03775	8499 606986	IRINA PAVLOVA	{"email": "pavlova.irina.1969@postgrespro.ru", "phone": "+70863623382"}
0005435551534	E08798	6783 960284	LILIYA KULIKOVA	{"email": "liliya_kulikova04121972@postgrespro.ru", "phone": "+70524393756"}
0005435551535	E08798	5306 622186	VLADISLAV ISAEV	{"email": "vladislav.isaev-061973@postgrespro.ru", "phone": "+70770419474"}
0005435551536	1F9ACD	7157 782018	DMITRIY GUSEV	{"email": "dmitriygusev-031968@postgrespro.ru", "phone": "+70101379723"}
0005435551537	38BBAF	4188 125890	RAISA KONOVALOVA	{"phone": "+70599662894"}
0005435551538	A7B6C0	2963 236562	ANASTASIYA LUKYANOVA	{"phone": "+70538410685"}
0005435551539	4FF0B3	0195 255817	PAVEL BONDARENKO	{"phone": "+70695718888"}
0005435551540	D484E4	0948 287067	VALERIY IVANOV	{"phone": "+70697990341"}
0005435551541	D484E4	1420 776389	MARGARITA CHERNOVA	{"email": "chernovamargarita.16111963@postgrespro.ru", "phone": "+70435660238"}
0005435551542	A9C828	1874 207562	NIKOLAY PAVLOV	{"email": "nikolay.pavlov_041962@postgrespro.ru", "phone": "+70233798211"}
0005435551543	A9C828	4405 957622	TAMARA STEPANOVA	{"email": "tamarastepanova_11011978@postgrespro.ru", "phone": "+70794168549"}
0005435551544	D8BD41	5685 026002	MIKHAIL MIRONOV	{"phone": "+70946482790"}
0005435551545	D8BD41	6478 840526	VERA KAZAKOVA	{"email": "v_kazakova_12041964@postgrespro.ru", "phone": "+70600090961"}
0005435551546	D8BD41	4713 894230	ANASTASIYA SAVELEVA	{"email": "anastasiyasaveleva1972@postgrespro.ru", "phone": "+70320518021"}
0005435551547	F30B17	5844 327051	TAMARA CHERNOVA	{"email": "t-chernova061974@postgrespro.ru", "phone": "+70678931251"}
0005435551548	8B6AA8	5672 303740	YULIYA YAKOVLEVA	{"phone": "+70836990708"}
0005435551549	8B6AA8	8087 562251	OKSANA BELOVA	{"phone": "+70300365557"}
0005435551550	4955D9	2075 318157	TATYANA CHERNOVA	{"phone": "+70948368904"}
0005435551551	4955D9	3562 606098	GRIGORIY BORISOV	{"email": "borisov_g15111980@postgrespro.ru", "phone": "+70039147291"}
0005435551552	5AEB62	0530 059781	TAMARA FADEEVA	{"phone": "+70494969268"}
0005435551553	5AEB62	9488 703747	VYACHESLAV MAKAROV	{"phone": "+70048192919"}
0005435551554	47FA3B	3281 081784	ALENA KRASNOVA	{"phone": "+70390771712"}
0005435551555	47FA3B	0558 150036	SERGEY ISAEV	{"phone": "+70882650730"}
0005435551556	A694CD	8288 837413	ELIZAVETA IVANOVA	{"email": "ivanova.elizaveta_091971@postgrespro.ru", "phone": "+70770291958"}
0005435551557	A476A1	8171 477470	VALENTINA BORISOVA	{"phone": "+70650857677"}
0005435551558	A476A1	5617 491997	ILYA DMITRIEV	{"phone": "+70522728263"}
0005435551559	8D9386	5792 975717	DANILA GRIGOREV	{"phone": "+70737280785"}
0005435551560	BEC118	4306 203159	TATYANA KUZNECOVA	{"phone": "+70297760950"}
0005435551561	BEC118	8471 750604	VYACHESLAV ROMANOV	{"phone": "+70188277269"}
0005435551562	BB0B70	1540 451523	VLADIMIR YAKOVLEV	{"email": "v_yakovlev_15011971@postgrespro.ru", "phone": "+70875197031"}
0005435551563	180B2F	6879 998732	KSENIYA MATVEEVA	{"phone": "+70209686245"}
0005435551564	180B2F	2797 057684	MARGARITA KUZNECOVA	{"email": "m-kuznecova1978@postgrespro.ru", "phone": "+70410069098"}
0005435551565	CC97CD	3857 194692	MARIYA ISAEVA	{"phone": "+70753483607"}
0005435551566	6D7674	5816 861837	YULIYA GUSEVA	{"phone": "+70766487951"}
0005435551567	6D7674	2666 868906	VLADIMIR FILIPPOV	{"email": "v-filippov.15031963@postgrespro.ru", "phone": "+70555052207"}
0005435551568	2097D7	0792 646547	YURIY KUZMIN	{"email": "kuzmin-yuriy1988@postgrespro.ru", "phone": "+70151882406"}
0005435551569	0C0B13	8794 155037	VLADIMIR DAVYDOV	{"email": "vladimir_davydov.02041967@postgrespro.ru", "phone": "+70883041794"}
0005435551570	827D3F	8540 791731	VALENTINA STEPANOVA	{"phone": "+70719036550"}
0005435551571	827D3F	8946 785830	NIKOLAY KULIKOV	{"email": "nikolaykulikov08111966@postgrespro.ru", "phone": "+70236341204"}
0005435551572	379D77	6409 200159	ALEKSEY MELNIKOV	{"email": "melnikov_aleksey.101976@postgrespro.ru", "phone": "+70178338350"}
0005435551573	379D77	8761 184062	GEVORG VOROBEV	{"email": "gvorobev101968@postgrespro.ru", "phone": "+70282348518"}
0005435551574	379D77	5285 927945	MIKHAIL ILIN	{"phone": "+70340997242"}
0005435551575	63DBFB	4577 399049	KONSTANTIN BELOV	{"phone": "+70151148564"}
0005435551576	9A1E73	4748 642437	ALEKSEY ZAYCEV	{"email": "a.zaycev-1973@postgrespro.ru", "phone": "+70044082103"}
0005435551577	9A1E73	4715 168722	TATYANA RYABOVA	{"phone": "+70603870422"}
0005435551578	C00617	9999 639903	ANATOLIY VOLKOV	{"email": "anatoliy-volkov.1981@postgrespro.ru", "phone": "+70050788901"}
0005435551579	53C38E	1933 249775	GENNADIY KARPOV	{"email": "karpov.g_02031975@postgrespro.ru", "phone": "+70056393148"}
0005435551580	C567F5	1129 070434	ALENA KALININA	{"phone": "+70072037365"}
0005435551581	596386	4601 960067	SERGEY VOROBEV	{"email": "vorobevsergey.091982@postgrespro.ru", "phone": "+70898082547"}
0005435551582	7D326A	9150 470418	LIDIYA SEMENOVA	{"phone": "+70395176942"}
0005435551583	8B492F	5762 542721	ALEKSANDR KUZMIN	{"email": "a_kuzmin-27081986@postgrespro.ru", "phone": "+70731639690"}
0005435551584	D65333	9791 796541	EVDOKIYA LEBEDEVA	{"phone": "+70462272641"}
0005435551585	42FF77	7401 306363	SVETLANA STEPANOVA	{"phone": "+70425165142"}
0005435551586	5EE92C	9895 953971	ALEKSANDR ROMANOV	{"phone": "+70235359429"}
0005435551587	7853BB	6550 506825	TATYANA GORBUNOVA	{"phone": "+70524585324"}
0005435551588	48DA4D	5009 858699	DARYA IVANOVA	{"email": "d_ivanova_01061974@postgrespro.ru", "phone": "+70116754796"}
0005435551589	48DA4D	8875 554258	ALLA KOROLEVA	{"email": "koroleva-a_111963@postgrespro.ru", "phone": "+70095238014"}
0005435551590	690D49	1110 520272	LIDIYA KOLESNIKOVA	{"email": "lidiya_kolesnikova_10041963@postgrespro.ru", "phone": "+70232877573"}
0005435551591	CAF681	7933 910491	DMITRIY ABRAMOV	{"phone": "+70027123074"}
0005435551592	3CCF21	2838 822203	OLEG IVANOV	{"email": "ivanov_o-071975@postgrespro.ru", "phone": "+70657163014"}
0005435551593	3CCF21	9276 476936	ELENA MATVEEVA	{"phone": "+70205595127"}
0005435551595	F6C3CD	1949 464776	OLGA ALEKSANDROVA	{"email": "o_aleksandrova-1967@postgrespro.ru", "phone": "+70994234782"}
0005435551596	F6C3CD	7769 272925	MARINA TARASOVA	{"phone": "+70779828878"}
0005435551597	F6C3CD	2166 453076	VERA KARPOVA	{"email": "verakarpova-031979@postgrespro.ru", "phone": "+70025569168"}
0005435551598	0A983C	0384 603859	YULIYA ALEKSANDROVA	{"email": "yuliya-aleksandrova-06031979@postgrespro.ru", "phone": "+70628990675"}
0005435551599	09AF00	0901 999565	YURIY ZAYCEV	{"phone": "+70785125745"}
0005435551600	9E722D	1376 423475	MARIYA MOROZOVA	{"email": "mmorozova_1971@postgrespro.ru", "phone": "+70168650620"}
0005435551601	D6BCE3	1965 926616	TATYANA KUZMINA	{"phone": "+70395045116"}
0005435551602	ECAADA	2412 072011	IRINA PAVLOVA	{"phone": "+70963990484"}
0005435551603	475BB0	8737 895670	OLEG KOROLEV	{"email": "olegkorolev1972@postgrespro.ru", "phone": "+70124270532"}
0005435551604	CD2EFB	4879 077365	MARIYA RODIONOVA	{"phone": "+70009753310"}
0005435551605	25EEE2	0972 576731	DMITRIY IVANOV	{"phone": "+70147596615"}
0005435551606	5A5CE2	8593 758914	ALEKSANDR SOKOLOV	{"email": "sokolova30091980@postgrespro.ru", "phone": "+70001035606"}
0005435551607	5A5CE2	4802 814516	RAISA ABRAMOVA	{"email": "abramova.raisa-061969@postgrespro.ru", "phone": "+70051682610"}
0005435551608	DA44F8	8973 753092	YULIYA MIKHAYLOVA	{"email": "mikhaylova-yuliya.081974@postgrespro.ru", "phone": "+70953833093"}
0005435551609	DA44F8	6984 060919	VALERIY PETROV	{"phone": "+70798500984"}
0005435551610	F8203E	1628 062905	VLADIMIR KOZLOV	{"email": "v-kozlov.021978@postgrespro.ru", "phone": "+70419382797"}
0005435551611	1ACBF0	4411 437299	DMITRIY KARPOV	{"phone": "+70552637655"}
0005435551612	1ACBF0	7919 061345	RAISA MEDVEDEVA	{"phone": "+70437493542"}
0005435551613	96C606	4972 971287	VALENTINA BELOVA	{"phone": "+70322854728"}
0005435551614	96C606	0746 340804	ANDREY PAVLOV	{"email": "pavlovandrey09011973@postgrespro.ru", "phone": "+70891263603"}
0005435551615	A57C7D	2286 497580	VLADIMIR NIKOLAEV	{"email": "vladimirnikolaev.021970@postgrespro.ru", "phone": "+70063499380"}
0005435551616	A57C7D	8108 851622	ALEKSANDR KUZMIN	{"email": "aleksandr.kuzmin_23111962@postgrespro.ru", "phone": "+70778988549"}
0005435551617	7A5D8F	1788 915823	PAVEL ZAKHAROV	{"email": "zakharovp-10061976@postgrespro.ru", "phone": "+70683516070"}
0005435551618	19B384	7119 551292	NADEZHDA NIKOLAEVA	{"phone": "+70742050380"}
0005435551619	1E25CB	0628 816687	NATALYA MAKAROVA	{"email": "makarovanatalya-081971@postgrespro.ru", "phone": "+70901592080"}
0005435551620	20A4AA	8298 264116	ARTEM KOZLOV	{"phone": "+70317901150"}
0005435551621	AF94AB	4205 654988	PETR FEDOROV	{"email": "p.fedorov_1961@postgrespro.ru", "phone": "+70773668535"}
0005435551622	5772AC	9747 410883	RUMIYA TIKHONOVA	{"email": "rtikhonova-041977@postgrespro.ru", "phone": "+70815234924"}
0005435551623	99AA41	9696 108588	TATYANA SOKOLOVA	{"email": "sokolova-tatyana.1968@postgrespro.ru", "phone": "+70687550018"}
0005435551624	99AA41	4528 924394	ILYA KUZNECOV	{"email": "kuznecov.ilya-09031969@postgrespro.ru", "phone": "+70940095960"}
0005435551625	99AA41	6914 312950	VASILIY KUDRYASHOV	{"email": "v-kudryashov_11041971@postgrespro.ru", "phone": "+70185094176"}
0005435551626	5A3C83	1005 307529	VALERIYA ABRAMOVA	{"phone": "+70052630141"}
0005435551627	36CE63	5817 498424	PETR KRASNOV	{"email": "krasnov_p_1963@postgrespro.ru", "phone": "+70499317301"}
0005435551628	36CE63	4261 773317	KLAVDIYA MATVEEVA	{"email": "matveeva.klavdiya22041976@postgrespro.ru", "phone": "+70445148868"}
0005435551629	0F04B6	6784 215587	RAISA NESTEROVA	{"phone": "+70097786224"}
0005435551630	7EEBC3	8248 480308	MIKHAIL KUZMIN	{"email": "kuzmin_m31031964@postgrespro.ru", "phone": "+70177727037"}
0005435551631	B4A750	8759 543935	SERGEY SMIRNOV	{"phone": "+70360377310"}
0005435551632	3BF52F	1167 562223	ANNA BELYAEVA	{"email": "belyaevaa_1975@postgrespro.ru", "phone": "+70993165945"}
0005435551633	3908DF	5075 235704	ANATOLIY MELNIKOV	{"email": "melnikov-a_081962@postgrespro.ru", "phone": "+70357612025"}
0005435551634	7C22CB	2912 037200	ALEKSEY NOVIKOV	{"email": "a_novikov.1962@postgrespro.ru", "phone": "+70495468232"}
0005435551635	7C22CB	5056 104974	VALENTINA MOROZOVA	{"email": "morozova_valentina_1967@postgrespro.ru", "phone": "+70590893042"}
0005435551636	769A69	2381 585843	MAKSIM KUZMIN	{"phone": "+70298590359"}
0005435551637	769A69	0693 341957	ANDREY VOLKOV	{"email": "andrey.volkov061968@postgrespro.ru", "phone": "+70216308123"}
0005435551638	DAF792	4249 277320	ALEKSANDR MELNIKOV	{"phone": "+70536198463"}
0005435551639	DAF792	3581 972778	VALENTINA VOLKOVA	{"email": "valentinavolkova_23021969@postgrespro.ru", "phone": "+70254221501"}
0005435551640	DAF792	1993 571462	ANDREY KOZLOV	{"phone": "+70291833747"}
0005435551641	DAF792	5517 162867	IRINA GERASIMOVA	{"email": "igerasimova.08021981@postgrespro.ru", "phone": "+70744462871"}
0005435551642	069F40	9038 413439	ALEKSANDR MIKHAYLOV	{"email": "a-mikhaylov-1968@postgrespro.ru", "phone": "+70655152127"}
0005435551643	61C80D	3095 275206	NADEZHDA PAVLOVA	{"email": "n-pavlova1969@postgrespro.ru", "phone": "+70721716525"}
0005435551644	1B1FCC	5068 290854	DMITRIY IVANOV	{"email": "divanov_051983@postgrespro.ru", "phone": "+70382652177"}
0005435551645	1B1FCC	8768 212702	TAISIYA BORISOVA	{"phone": "+70908111808"}
0005435551646	42030A	8642 275829	DARYA SCHERBAKOVA	{"email": "d-scherbakova_10061970@postgrespro.ru", "phone": "+70280413525"}
0005435551647	6ECB50	9473 195480	ANNA PAVLOVA	{"phone": "+70495746780"}
0005435551648	6ECB50	6288 251315	SERGEY GORBUNOV	{"email": "sergeygorbunov_01011972@postgrespro.ru", "phone": "+70017310296"}
0005435551649	6EEB3E	3955 741902	ALEKSANDR MAKAROV	{"email": "aleksandr-makarov01121971@postgrespro.ru", "phone": "+70881784132"}
0005435551650	63BA49	4070 007256	ANTONINA TIMOFEEVA	{"email": "antonina-timofeeva_051968@postgrespro.ru", "phone": "+70028490450"}
0005435551651	63BA49	6765 157291	ANNA KUZNECOVA	{"phone": "+70489137818"}
0005435551652	E65423	1781 626159	NATALYA KUZNECOVA	{"email": "kuznecova.n-041967@postgrespro.ru", "phone": "+70471064206"}
0005435551654	E7A98E	1909 056987	MIKHAIL NAUMOV	{"phone": "+70435610599"}
0005435551655	9667DD	7952 653087	ALEKSANDR SCHERBAKOV	{"phone": "+70992272519"}
0005435551656	D42C12	1692 168848	BORIS VLASOV	{"phone": "+70543768518"}
0005435551657	98C227	6459 707186	VENIAMIN YAKOVLEV	{"email": "yakovlev_v.091977@postgrespro.ru", "phone": "+70617248464"}
0005435551658	18E4D7	2968 836764	ELIZAVETA LAZAREVA	{"phone": "+70709665586"}
0005435551659	18E4D7	4668 365124	ALEKSEY GRIGOREV	{"email": "a_grigorev-04031971@postgrespro.ru", "phone": "+70801640822"}
0005435551660	9609C5	7122 471443	EVA KONDRATEVA	{"phone": "+70032331143"}
0005435551661	9609C5	0150 553060	VIKTORIYA EFREMOVA	{"phone": "+70878781398"}
0005435551662	7694F3	7054 853928	ALEKSEY VOLKOV	{"phone": "+70936066582"}
0005435551663	98481A	5912 046191	OLGA KOROLEVA	{"phone": "+70338877249"}
0005435551664	98481A	7952 605985	ANNA SOLOVEVA	{"phone": "+70035554379"}
0005435551665	B1B191	1251 266415	SERGEY ABRAMOV	{"email": "sabramov_14071974@postgrespro.ru", "phone": "+70115820834"}
0005435551666	B1B191	7643 072222	GRIGORIY DMITRIEV	{"email": "gdmitriev.15091967@postgrespro.ru", "phone": "+70916122467"}
0005435551667	3B73A8	4067 390791	IGOR SHEVCHENKO	{"email": "shevchenkoigor.09081965@postgrespro.ru", "phone": "+70414506775"}
0005435551668	0104F5	2940 956488	DMITRIY GORBUNOV	{"email": "gorbunov_dmitriy.1971@postgrespro.ru", "phone": "+70847921517"}
0005435551669	95672F	6876 407288	ELIZAVETA ORLOVA	{"phone": "+70505772147"}
0005435551670	95672F	7733 103055	OLGA SCHERBAKOVA	{"email": "olgascherbakova1972@postgrespro.ru", "phone": "+70328860795"}
0005435551671	D83C05	3848 354442	SERGEY SOROKIN	{"phone": "+70308569029"}
0005435551672	A57C30	1406 639883	ELIZAVETA MEDVEDEVA	{"email": "medvedevaelizaveta111970@postgrespro.ru", "phone": "+70386344329"}
0005435551673	BBF62E	8056 371795	PAVEL SOROKIN	{"phone": "+70517818884"}
0005435551674	BBF62E	1725 499796	MAKAR KUDRYASHOV	{"email": "kudryashov_m_1975@postgrespro.ru", "phone": "+70212790158"}
0005435551675	7E052C	7726 777696	RAISA ZAKHAROVA	{"phone": "+70080250946"}
0005435551676	DA45DF	0635 102208	DIANA STEPANOVA	{"phone": "+70252401296"}
0005435551677	78CA27	4604 512204	ARTEM PAVLOV	{"phone": "+70200466338"}
0005435551678	314509	4550 270515	MAKSIM YAKOVLEV	{"email": "m_yakovlev.101966@postgrespro.ru", "phone": "+70494369140"}
0005435551679	0967E3	5231 656260	VITALIY GERASIMOV	{"email": "gerasimov-v-061975@postgrespro.ru", "phone": "+70123022714"}
0005435551680	0EDAE2	7153 491182	RUSTAM GUSEV	{"phone": "+70035504751"}
0005435551681	C031FF	8438 402169	TATYANA ALEKSEEVA	{"email": "alekseeva-tatyana.1976@postgrespro.ru", "phone": "+70198562869"}
0005435551682	C031FF	5081 283592	GAGIK MELNIKOV	{"phone": "+70732815583"}
0005435551683	B8A140	8166 950352	NINA IVANOVA	{"phone": "+70543179337"}
0005435551684	73B2D7	7607 341251	GENNADIY GORBUNOV	{"email": "gorbunov_gennadiy-101971@postgrespro.ru", "phone": "+70602190959"}
0005435551685	F592C4	4160 979580	NATALYA VASILEVA	{"phone": "+70667613717"}
0005435551686	1C761F	6271 119343	ARTEM GERASIMOV	{"email": "gerasimov.a-11011973@postgrespro.ru", "phone": "+70193861058"}
0005435551687	1408B2	7327 622998	SERGEY KISELEV	{"phone": "+70422438896"}
0005435551688	0992BA	5392 912727	SALAVAT ABRAMOV	{"phone": "+70373829938"}
0005435551689	467626	9513 434419	YULIYA KARPOVA	{"email": "karpova.yuliya021973@postgrespro.ru", "phone": "+70612867037"}
0005435551690	467626	4731 308483	SERGEY BELOV	{"phone": "+70046458040"}
0005435551691	97B9FE	2100 539923	TATYANA ALEKSANDROVA	{"phone": "+70102486672"}
0005435551692	366C50	6914 100384	TATYANA VASILEVA	{"email": "tatyana.vasileva.27111979@postgrespro.ru", "phone": "+70240803074"}
0005435551693	29B3C4	1721 859492	ALBERT VLASOV	{"email": "vlasov_a.22091984@postgrespro.ru", "phone": "+70366316535"}
0005435551694	29B3C4	8950 364406	VLADISLAV PAVLOV	{"email": "pavlov.v.1972@postgrespro.ru", "phone": "+70674203051"}
0005435551695	29B3C4	4838 613463	TATYANA PAVLOVA	{"email": "t-pavlova.11051975@postgrespro.ru", "phone": "+70443608447"}
0005435551696	F082B6	0009 436577	LYUDMILA ZHUKOVA	{"email": "lyudmilazhukova-1964@postgrespro.ru", "phone": "+70520909834"}
0005435551697	F082B6	8453 936759	GALINA ANDREEVA	{"email": "galinaandreeva_1976@postgrespro.ru", "phone": "+70898508954"}
0005435551698	6B84BD	3474 719059	NATALYA PETROVA	{"email": "petrova-n.03091970@postgrespro.ru", "phone": "+70558164552"}
0005435551699	6B84BD	8268 782543	ALEKSANDR PETROV	{"email": "a_petrov.1981@postgrespro.ru", "phone": "+70747657252"}
0005435551700	CA33EB	8086 367421	GALINA IVANOVA	{"phone": "+70011693237"}
0005435551701	A95B3A	9650 043810	RUSLAN IVANOV	{"email": "r_ivanov-25091969@postgrespro.ru", "phone": "+70142661599"}
0005435551702	C7A5F5	9350 917595	VALENTINA ANDREEVA	{"email": "andreeva-v_01031972@postgrespro.ru", "phone": "+70809123886"}
0005435551703	C7A5F5	3609 485955	YURIY ORLOV	{"email": "orlov.yuriy.011985@postgrespro.ru", "phone": "+70526208260"}
0005435551704	0E5F89	6483 847626	MARGARITA MOROZOVA	{"email": "m_morozova.04061974@postgrespro.ru", "phone": "+70919176877"}
0005435551705	0E5F89	5622 947785	GALINA KUZNECOVA	{"email": "kuznecovag.30121975@postgrespro.ru", "phone": "+70581521721"}
0005435551706	8C5017	7358 362314	PETR PAVLOV	{"email": "petr-pavlov.26021977@postgrespro.ru", "phone": "+70710692791"}
0005435551707	390504	2052 394627	ALEKSEY SCHERBAKOV	{"email": "scherbakov-a_05101968@postgrespro.ru", "phone": "+70832814443"}
0005435551708	C07965	0511 566354	SVETLANA IVANOVA	{"email": "ivanovas051966@postgrespro.ru", "phone": "+70834115704"}
0005435551709	849997	8556 067804	ALEKSANDR BELOV	{"email": "belov_a_11071970@postgrespro.ru", "phone": "+70831616091"}
0005435551710	2A7B67	1894 395066	GALINA NOVIKOVA	{"email": "novikova_g_1979@postgrespro.ru", "phone": "+70626857540"}
0005435551711	90FA67	4320 662367	ANATOLIY STEPANOV	{"phone": "+70838711660"}
0005435551712	46125C	6354 256633	ALENA KUZNECOVA	{"email": "kuznecova-a-26031966@postgrespro.ru", "phone": "+70067747846"}
0005435551713	B248E1	0842 601816	ANASTASIYA TARASOVA	{"phone": "+70779447519"}
0005435551714	2E2010	4140 305556	NATALIYA ANISIMOVA	{"phone": "+70860998653"}
0005435551715	FDAF2D	2129 078784	TATYANA FEDOROVA	{"email": "tfedorova.04091977@postgrespro.ru", "phone": "+70192885781"}
0005435551716	FDAF2D	5193 307843	VASILIY BARANOV	{"phone": "+70099910587"}
0005435551717	6377E0	8475 528519	VIOLETTA OSIPOVA	{"email": "vosipova_18081955@postgrespro.ru", "phone": "+70503961592"}
0005435551718	6377E0	4849 787151	OKSANA TROFIMOVA	{"email": "trofimova.oksana03081983@postgrespro.ru", "phone": "+70024291205"}
0005435551719	A704FB	1339 684612	DIANA MOROZOVA	{"phone": "+70835813620"}
0005435551720	A704FB	1466 855340	GENNADIY VASILEV	{"email": "vasilev.gennadiy_27071978@postgrespro.ru", "phone": "+70647890134"}
0005435551721	39E694	7633 733869	VALENTINA NIKITINA	{"email": "valentina-nikitina091974@postgrespro.ru", "phone": "+70991106796"}
0005435551722	39E694	7883 434959	NIKOLAY KUZNECOV	{"email": "kuznecov.nikolay081974@postgrespro.ru", "phone": "+70397920979"}
0005435551723	39E694	7566 353395	EDUARD STEPANOV	{"email": "eduard.stepanov.24121977@postgrespro.ru", "phone": "+70590682754"}
0005435551724	B93355	5681 165162	IRINA VOLKOVA	{"email": "volkova.irina-061990@postgrespro.ru", "phone": "+70370779018"}
0005435551725	DA622E	0114 478973	YULIYA KUZNECOVA	{"phone": "+70729697767"}
0005435551726	DA622E	6506 617780	EKATERINA YAKOVLEVA	{"email": "yakovleva.e1962@postgrespro.ru", "phone": "+70175509007"}
0005435551727	28E6CD	4659 251611	VITALIY MIKHAYLOV	{"email": "vitaliy-mikhaylov-1966@postgrespro.ru", "phone": "+70177038150"}
0005435551728	28E6CD	2685 806974	ANATOLIY VOLKOV	{"phone": "+70155717567"}
0005435551729	709C34	7346 340405	NATALYA KARPOVA	{"email": "nkarpova_081977@postgrespro.ru", "phone": "+70346242814"}
0005435551730	0F63AA	8595 830357	ALEKSEY FEDOROV	{"email": "fedorov.aleksey-1965@postgrespro.ru", "phone": "+70190733361"}
0005435551731	8E5936	6165 188320	ALEKSANDR RODIONOV	{"email": "aleksandr_rodionov1965@postgrespro.ru", "phone": "+70623204354"}
0005435551732	8E5936	1362 115995	SERGEY MEDVEDEV	{"email": "s.medvedev_22031959@postgrespro.ru", "phone": "+70073830705"}
0005435551733	8E5936	3090 640641	GALINA POLYAKOVA	{"email": "gpolyakova.03021974@postgrespro.ru", "phone": "+70522427087"}
0005435551734	B97F71	4606 325779	GENNADIY TIKHONOV	{"email": "g_tikhonov-1967@postgrespro.ru", "phone": "+70093566334"}
0005435551735	B97F71	9682 540352	IRINA FROLOVA	{"email": "irina-frolova_26091979@postgrespro.ru", "phone": "+70231856325"}
0005435551736	1019E3	9943 427748	IVAN FROLOV	{"phone": "+70965066102"}
0005435551737	1019E3	9102 459254	EVGENIY PAVLOV	{"email": "e.pavlov_05021981@postgrespro.ru", "phone": "+70349816306"}
0005435551738	982CBA	9627 885292	MIKHAIL ALEKSEEV	{"email": "alekseev-m-111978@postgrespro.ru", "phone": "+70261384079"}
0005435551739	D3C25A	1160 853060	OKSANA GORBUNOVA	{"email": "gorbunovaoksana.22091969@postgrespro.ru", "phone": "+70028738756"}
0005435551740	D3C25A	2596 691505	EVGENIYA TIKHONOVA	{"phone": "+70637854311"}
0005435551741	C77928	1623 038181	ZHANNA LAZAREVA	{"phone": "+70653845163"}
0005435551742	44BAE8	4236 651271	SVETLANA POPOVA	{"email": "svetlana.popova.12121961@postgrespro.ru", "phone": "+70970507872"}
0005435551743	F4071B	3694 480178	VIKTOR EGOROV	{"phone": "+70220386787"}
0005435551744	7DB3C6	2374 598937	VALENTINA NESTEROVA	{"email": "valentinanesterova.1972@postgrespro.ru", "phone": "+70103158279"}
0005435551745	878F37	9504 303798	NATALIYA ILINA	{"phone": "+70510005401"}
0005435551746	A61EA9	6668 282793	OLGA MELNIKOVA	{"phone": "+70960159852"}
0005435551747	FE27EC	7532 934825	OLGA KISELEVA	{"phone": "+70980637555"}
0005435551748	FE27EC	3564 838366	IGOR MIRONOV	{"phone": "+70165437913"}
0005435551749	B32D46	3270 359511	LYAYSAN LOGINOVA	{"email": "loginovalyaysan17081975@postgrespro.ru", "phone": "+70106721816"}
0005435551750	B32D46	1382 894707	FANIL VOLKOV	{"phone": "+70033212743"}
0005435551751	65C66C	9754 522887	OLGA PETROVA	{"phone": "+70433030991"}
0005435551752	65C66C	9788 505067	ALEKSANDR IVANOV	{"phone": "+70756956890"}
0005435551753	B7CAC8	1182 500914	MIKHAIL AFANASEV	{"phone": "+70865940035"}
0005435551754	13428E	0714 269686	ALEKSANDRA RYABOVA	{"phone": "+70645733156"}
0005435551755	13428E	5180 704749	YULIYA KOMAROVA	{"phone": "+70163734357"}
0005435551756	29CBD4	6055 257395	ALEKSANDR RODIONOV	{"phone": "+70150500408"}
0005435551757	0FF006	0573 427425	ANASTASIYA DAVYDOVA	{"email": "anastasiya.davydova_041961@postgrespro.ru", "phone": "+70350492121"}
0005435551758	F84F47	2008 285440	VALENTIN KUZNECOV	{"email": "v_kuznecov.27111978@postgrespro.ru", "phone": "+70728161444"}
0005435551759	061F10	6592 461219	OLEG NIKITIN	{"phone": "+70406863701"}
0005435551760	206095	5351 069316	ANASTASIYA NIKOLAEVA	{"email": "nikolaeva_anastasiya13071973@postgrespro.ru", "phone": "+70253651363"}
0005435551761	DF2061	2879 657921	ALEKSANDR PETROV	{"email": "a-petrov_14031966@postgrespro.ru", "phone": "+70975941402"}
0005435551762	DF2061	0717 188984	PAVEL KONOVALOV	{"email": "pavelkonovalov.1964@postgrespro.ru", "phone": "+70311002049"}
0005435551763	DF2061	7292 034679	VIKTOR KUZNECOV	{"email": "viktorkuznecov-1966@postgrespro.ru", "phone": "+70802497425"}
0005435551764	3CFCD7	5155 264927	ROMAN ANTONOV	{"email": "roman-antonov_031974@postgrespro.ru", "phone": "+70195051804"}
0005435551765	3CFCD7	1707 266128	VLADISLAV KUZNECOV	{"phone": "+70539738027"}
0005435551766	3CFCD7	9154 669006	MARIYA FROLOVA	{"phone": "+70255222256"}
0005435551767	EA4B0C	2720 211960	RUSLAN SCHERBAKOV	{"email": "scherbakov-r_031966@postgrespro.ru", "phone": "+70937804340"}
0005435551768	8A2CC1	3185 438815	EVGENIY FEDOTOV	{"email": "evgeniy-fedotov_101984@postgrespro.ru", "phone": "+70323845434"}
0005435551769	1A56E5	3302 679368	GALINA POLYAKOVA	{"phone": "+70278822744"}
0005435551770	481EB8	3522 999666	NINA SEMENOVA	{"phone": "+70970442187"}
0005435551771	EEF4B0	3265 857905	ALEKSEY MIRONOV	{"phone": "+70491951436"}
0005435551772	2D0026	8963 035405	NIKITA NAUMOV	{"phone": "+70704843190"}
0005435551773	A2A112	6510 565290	IRINA SOKOLOVA	{"email": "i-sokolova_1971@postgrespro.ru", "phone": "+70216327734"}
0005435551774	DFDE2A	9305 205335	ANDREY PETROV	{"email": "petrov-andrey-03081981@postgrespro.ru", "phone": "+70044889326"}
0005435551775	984866	1511 498150	SVETLANA ZAKHAROVA	{"phone": "+70187080271"}
0005435551776	060850	7427 332491	SVETLANA BORISOVA	{"phone": "+70845981468"}
0005435551777	060850	1655 655787	ANDREY POPOV	{"email": "popov_andrey14041969@postgrespro.ru", "phone": "+70314024161"}
0005435551778	E2D91C	7966 463557	IRINA DMITRIEVA	{"phone": "+70934182511"}
0005435551779	E2D91C	0460 138856	RAUF TARASOV	{"phone": "+70331676295"}
0005435551780	4C08DE	3287 606157	KONSTANTIN IVANOV	{"phone": "+70979734622"}
0005435551781	EC16AF	2996 421061	ARSENIY KISELEV	{"email": "kiselevarseniy14121964@postgrespro.ru", "phone": "+70344079870"}
0005435551782	8E5F27	9355 141794	MIKHAIL EGOROV	{"phone": "+70183124971"}
0005435551783	C2B803	8334 711748	SERGEY ANTONOV	{"phone": "+70834803340"}
0005435551784	1CA967	2854 953510	OLEG MELNIKOV	{"phone": "+70276450917"}
0005435551785	1CA967	3877 830969	MARIYA RODIONOVA	{"email": "mariya_rodionova1970@postgrespro.ru", "phone": "+70545305638"}
0005435551786	980DA3	4986 795003	VERA TIMOFEEVA	{"phone": "+70322288250"}
0005435554103	63DCE3	5778 176120	ANATOLIY VASILEV	{"email": "vasilev-anatoliy.28091966@postgrespro.ru", "phone": "+70523802351"}
0005435554104	63DCE3	3908 643787	EGOR ALEKSEEV	{"email": "alekseev.egor.061978@postgrespro.ru", "phone": "+70614192860"}
0005435554105	67945D	5606 088119	SERGEY MATVEEV	{"email": "matveevsergey_1973@postgrespro.ru", "phone": "+70513473481"}
0005435554106	749D83	5118 344871	RAMILYA DENISOVA	{"phone": "+70983191191"}
0005435554107	749D83	5412 015836	ALEKSANDRA LAZAREVA	{"email": "lazareva.a.121979@postgrespro.ru", "phone": "+70457814804"}
0005435554108	C34366	5509 772549	NATALYA BELOVA	{"phone": "+70220189424"}
0005435554109	C0E85D	0942 943935	ALEKSEY FROLOV	{"email": "a-frolov021971@postgrespro.ru", "phone": "+70169204698"}
0005435554110	0A0AF2	0528 761944	TATYANA ZHURAVLEVA	{"phone": "+70222934709"}
0005435554111	E88F55	5470 471107	VERONIKA NESTEROVA	{"email": "veronika_nesterova_1969@postgrespro.ru", "phone": "+70574287046"}
0005435554112	35786B	4218 180381	RIMMA DANILOVA	{"phone": "+70879773438"}
0005435554113	8A02FA	4797 052538	SVETLANA KOLESNIKOVA	{"email": "svetlana.kolesnikova-1977@postgrespro.ru", "phone": "+70757822196"}
0005435554114	32954C	0665 705564	VIKTOR SMIRNOV	{"email": "vsmirnov.1967@postgrespro.ru", "phone": "+70310572710"}
0005435554115	3CCF67	8592 808033	ALEKSANDRA EFIMOVA	{"phone": "+70320306330"}
0005435554116	CA2CA5	0762 556029	PLATON SMIRNOV	{"phone": "+70814520951"}
0005435554117	CA2CA5	2880 181937	ALENA RODIONOVA	{"phone": "+70819090547"}
0005435554118	0F684B	8375 677630	MARIYA POLYAKOVA	{"phone": "+70206753346"}
0005435554119	4EDDB1	1867 636451	VERA KRASNOVA	{"phone": "+70762696071"}
0005435554120	4EDDB1	1091 344604	SVETLANA POPOVA	{"email": "svetlanapopova1976@postgrespro.ru", "phone": "+70279858679"}
0005435554121	EA9FC1	4672 420517	NIKITA ISAEV	{"email": "nikita_isaev.24081966@postgrespro.ru", "phone": "+70984156254"}
0005435554122	ADA6EC	1684 761375	ANATOLIY FOMIN	{"email": "a_fomin041968@postgrespro.ru", "phone": "+70656695454"}
0005435554123	A82503	7428 473217	VALENTIN ILIN	{"phone": "+70295767357"}
0005435554124	7C2BB4	7172 016606	TATYANA AFANASEVA	{"phone": "+70836882039"}
0005435554125	D32A46	7563 847251	ANASTASIYA PETROVA	{"email": "petrovaanastasiya_1978@postgrespro.ru", "phone": "+70231586110"}
0005435554126	D32A46	3588 136236	ALEKSANDRA MALYSHEVA	{"email": "malyshevaaleksandra_1977@postgrespro.ru", "phone": "+70786184056"}
0005435554127	9204AE	3441 829177	SVETLANA NESTEROVA	{"phone": "+70079433499"}
0005435554128	9204AE	1529 947707	IVAN NOVIKOV	{"email": "inovikov-07051967@postgrespro.ru", "phone": "+70479391614"}
0005435554129	8121A5	4424 999939	NIKOLAY BORISOV	{"phone": "+70822875112"}
0005435554130	8121A5	8693 733313	MARIYA KUZMINA	{"email": "kuzmina-m041973@postgrespro.ru", "phone": "+70785360455"}
0005435554131	4A95A7	0295 008002	IRINA SOROKINA	{"phone": "+70009413731"}
0005435554132	E3FF6B	1405 928559	DMITRIY IVANOV	{"email": "ivanov-d_21121969@postgrespro.ru", "phone": "+70618127387"}
0005435554133	334B2F	4147 434395	DENIS CHERNOV	{"phone": "+70252348730"}
0005435554134	6C47A3	3187 513985	NATALYA ROMANOVA	{"email": "n_romanova1969@postgrespro.ru", "phone": "+70536548439"}
0005435554135	F2326C	4341 539023	LYUBOV NESTEROVA	{"email": "lnesterova-10051974@postgrespro.ru", "phone": "+70052778225"}
0005435554136	4DF3FC	8137 995128	SERGEY KOROLEV	{"phone": "+70673907331"}
0005435554137	4DF3FC	5638 330497	ARTUR GERASIMOV	{"email": "artur-gerasimov08011969@postgrespro.ru", "phone": "+70153081201"}
0005435554138	517D7B	6089 538259	SERGEY NIKOLAEV	{"email": "s-nikolaev_071957@postgrespro.ru", "phone": "+70377975454"}
0005435554139	2178EF	7485 204061	ALEKSANDR ANTONOV	{"phone": "+70844899261"}
0005435554140	D95AC3	7696 795375	ALEKSANDR IVANOV	{"phone": "+70049383955"}
0005435554141	07C5AF	3084 645937	ARSENIY OSIPOV	{"phone": "+70205100844"}
0005435554142	07C5AF	7864 535847	LIDIYA ORLOVA	{"phone": "+70781485997"}
0005435554143	07C5AF	9343 186433	OLGA IVANOVA	{"email": "olgaivanova-1977@postgrespro.ru", "phone": "+70418694854"}
0005435554144	609F66	3325 779723	NATALYA KUZNECOVA	{"email": "kuznecova.natalya-1978@postgrespro.ru", "phone": "+70415536321"}
0005435554145	B16F2D	2267 082318	NATALYA KOROLEVA	{"phone": "+70142354218"}
0005435554146	4EE4F8	7587 274879	TATYANA MAKSIMOVA	{"email": "maksimova-tatyana_02101965@postgrespro.ru", "phone": "+70974339754"}
0005435554147	A9C02E	6318 286900	GALINA AKIMOVA	{"phone": "+70139987331"}
0005435554148	A9C02E	0682 294206	YURIY ZHUKOV	{"phone": "+70856500834"}
0005435554149	B149E2	8272 045586	ALEKSEY KOZLOV	{"phone": "+70584869829"}
0005435554150	B149E2	4995 569740	DMITRIY KISELEV	{"email": "dmitriy.kiselev_091985@postgrespro.ru", "phone": "+70752399164"}
0005435554151	00CBE1	8885 443590	IVAN VASILEV	{"phone": "+70322514677"}
0005435554152	4FF0C7	6129 141895	DMITRIY SMIRNOV	{"phone": "+70518383473"}
0005435554153	DB9D9B	3536 578842	VALERIY IVANOV	{"email": "valeriy_ivanov-1981@postgrespro.ru", "phone": "+70459649884"}
0005435554154	2E5030	4930 337372	ULYANA GAVRILOVA	{"phone": "+70384217071"}
0005435554155	2E5030	5776 023069	GENNADIY AFANASEV	{"email": "g.afanasev.25061975@postgrespro.ru", "phone": "+70441815914"}
0005435554156	CB5AEF	8077 104904	KSENIYA GAVRILOVA	{"email": "gavrilovak_011972@postgrespro.ru", "phone": "+70766013641"}
0005435554157	1C4CF1	0109 999528	GALINA EGOROVA	{"phone": "+70420867274"}
0005435554158	BFC760	8470 121370	NIKOLAY VASILEV	{"email": "vasilevnikolay13041978@postgrespro.ru", "phone": "+70747716496"}
0005435554159	1C7107	9836 154971	ALEKSANDR TIKHONOV	{"phone": "+70321137876"}
0005435554160	9DCDC8	6181 574854	ROMAN IVANOV	{"phone": "+70727324549"}
0005435554161	B47D7B	5533 478101	OLEG ROMANOV	{"phone": "+70488937826"}
0005435554162	B47D7B	4631 090556	GENNADIY TIKHONOV	{"email": "g-tikhonov.121970@postgrespro.ru", "phone": "+70105406234"}
0005435554163	B47D7B	1844 843112	EVGENIY VASILEV	{"phone": "+70251430605"}
0005435554164	16C743	1137 888389	NATALIYA PETROVA	{"phone": "+70539227903"}
0005435554165	23C006	8845 622379	LYUBOV SAVELEVA	{"email": "saveleva.lyubov-1984@postgrespro.ru", "phone": "+70282115254"}
0005435554166	23C006	7637 382348	VLADA SOKOLOVA	{"email": "sokolova.v011979@postgrespro.ru", "phone": "+70481195667"}
0005435554167	66204C	7399 758907	DENIS BONDARENKO	{"phone": "+70711334266"}
0005435554168	6771E7	1316 596621	IRINA SOKOLOVA	{"phone": "+70500664672"}
0005435554169	6771E7	9587 405724	EKATERINA DMITRIEVA	{"email": "dmitrieva-e_121965@postgrespro.ru", "phone": "+70851886744"}
0005435554170	6771E7	7146 943237	TATYANA NIKIFOROVA	{"phone": "+70332324911"}
0005435554171	16E031	3153 881403	OLGA NIKOLAEVA	{"email": "olganikolaeva_1977@postgrespro.ru", "phone": "+70410618424"}
0005435554172	16E031	6081 961035	ROMAN NAUMOV	{"phone": "+70888703137"}
0005435554173	79129F	3191 150407	LYUBOV RODIONOVA	{"phone": "+70811388429"}
0005435554174	8531AD	3608 240025	TATYANA KUZNECOVA	{"email": "kuznecovat071976@postgrespro.ru", "phone": "+70293092728"}
0005435554175	528491	8636 268594	EVGENIYA KUZMINA	{"email": "e-kuzmina.1984@postgrespro.ru", "phone": "+70265048225"}
0005435554176	528491	2131 686589	ANATOLIY ANTONOV	{"email": "a_antonov-081970@postgrespro.ru", "phone": "+70569088179"}
0005435554177	0851AB	1652 990107	NINA SERGEEVA	{"email": "nsergeeva-1966@postgrespro.ru", "phone": "+70127262903"}
0005435554178	35DEF3	5126 660015	ELENA EGOROVA	{"email": "egorova.elena.111961@postgrespro.ru", "phone": "+70231079562"}
0005435554179	F08C98	6365 657621	VALENTINA EGOROVA	{"email": "egorova-valentina30051967@postgrespro.ru", "phone": "+70237259933"}
0005435554180	CDEFCA	6613 448007	NATALYA TROFIMOVA	{"email": "natalyatrofimova-1971@postgrespro.ru", "phone": "+70442934288"}
0005435554181	98486A	8873 129747	EVGENIY KOROLEV	{"email": "korolev.e031971@postgrespro.ru", "phone": "+70497887714"}
0005435554182	152D0C	6597 535061	ILYA MIRONOV	{"phone": "+70876419080"}
0005435554183	C6A133	2014 431042	MATVEY STEPANOV	{"phone": "+70267212121"}
0005435554184	FC2CA0	7021 474141	TATYANA ZAKHAROVA	{"email": "zakharova_tatyana_051973@postgrespro.ru", "phone": "+70880999483"}
0005435554185	FC2CA0	9041 483480	ALEKSANDR FROLOV	{"email": "frolov.a-14041978@postgrespro.ru", "phone": "+70766317819"}
0005435554186	DD9C46	2739 112394	MARGARITA SEMENOVA	{"email": "m-semenova1974@postgrespro.ru", "phone": "+70148094048"}
0005435554187	DD9C46	8775 673523	LYUDMILA RODIONOVA	{"phone": "+70763356763"}
0005435554188	CA93C9	5736 599301	EVGENIY BORISOV	{"email": "borisove-16011977@postgrespro.ru", "phone": "+70557945285"}
0005435554189	25D2C9	6380 284771	NIKOLAY DAVYDOV	{"email": "davydov-nikolay_18061967@postgrespro.ru", "phone": "+70145351078"}
0005435554190	135F86	9389 703032	ANASTASIYA FOMINA	{"phone": "+70809724162"}
0005435554191	1E12F0	4933 131984	EVGENIY ZAKHAROV	{"email": "zakharov_evgeniy19091971@postgrespro.ru", "phone": "+70753402333"}
0005435554192	A8DD1F	6250 894589	LYUDMILA ZAKHAROVA	{"email": "lyudmila_zakharova021980@postgrespro.ru", "phone": "+70882930861"}
0005435554193	A8DD1F	8907 942388	GALINA ANDREEVA	{"email": "andreeva_galina1965@postgrespro.ru", "phone": "+70451379547"}
0005435554194	94CC79	5127 088026	VALENTINA NOVIKOVA	{"email": "vnovikova1967@postgrespro.ru", "phone": "+70393542687"}
0005435554195	94CC79	2031 415565	ALEKSANDR SCHERBAKOV	{"phone": "+70523688226"}
0005435554196	57989C	1216 678030	IRINA GUSEVA	{"phone": "+70575577699"}
0005435554197	57989C	9145 182903	DENIS KOROLEV	{"email": "korolevdenis_071968@postgrespro.ru", "phone": "+70964612721"}
0005435554198	19556E	4597 612705	VALENTINA VOROBEVA	{"phone": "+70581273100"}
0005435554199	540648	9398 286482	TATYANA VASILEVA	{"phone": "+70647124846"}
0005435554200	540648	1365 321300	EKATERINA ROMANOVA	{"email": "romanova.ekaterina-1972@postgrespro.ru", "phone": "+70419846017"}
0005435554201	B94745	7709 844433	VITALIY EGOROV	{"email": "egorovvitaliy061961@postgrespro.ru", "phone": "+70975827584"}
0005435554202	906EDC	3547 733278	ILYA MIRONOV	{"phone": "+70596079879"}
0005435554203	4EDD77	8396 070777	SVETLANA ALEKSEEVA	{"email": "s-alekseeva.1965@postgrespro.ru", "phone": "+70274930783"}
0005435554204	B58F86	1167 018829	ALEKSANDR KUZNECOV	{"phone": "+70648901102"}
0005435554205	17F664	4583 382823	IRINA ZHUKOVA	{"email": "i-zhukova_15081981@postgrespro.ru", "phone": "+70051775974"}
0005435554206	1886B3	2483 076618	ALEKSANDR KONOVALOV	{"phone": "+70156667397"}
0005435554207	D1B15F	5722 975322	GALINA POPOVA	{"email": "g_popova1974@postgrespro.ru", "phone": "+70708453872"}
0005435554208	D1B15F	0072 741466	IRINA ZAKHAROVA	{"email": "zakharovai.02091967@postgrespro.ru", "phone": "+70752350267"}
0005435554209	C92969	1260 652527	NADEZHDA MEDVEDEVA	{"phone": "+70081522912"}
0005435554210	8DDFBB	9234 880207	ALEVTINA SCHERBAKOVA	{"email": "alevtina.scherbakova08081968@postgrespro.ru", "phone": "+70034884291"}
0005435554211	8DDFBB	6358 609027	SERGEY SAVELEV	{"email": "sergey-savelev.16081977@postgrespro.ru", "phone": "+70320085022"}
0005435554212	A6CE4E	0893 277809	OLEG KISELEV	{"phone": "+70032588475"}
0005435554213	ABB1F9	9872 976328	KIRILL SHEVCHENKO	{"phone": "+70788057023"}
0005435554214	7F9BEA	9696 793129	EKATERINA EGOROVA	{"phone": "+70312424208"}
0005435554215	B8BABB	6500 333254	MAKSIM DAVYDOV	{"phone": "+70914434893"}
0005435554216	B8BABB	7982 492772	TIMUR ZAKHAROV	{"phone": "+70350415996"}
0005435554217	B8BABB	9564 917563	NATALYA KUZMINA	{"phone": "+70941268613"}
0005435554218	40D34D	8602 280780	TATYANA KAZAKOVA	{"phone": "+70638512179"}
0005435554219	7B97C8	2900 841603	OLGA RODIONOVA	{"phone": "+70041922615"}
0005435554220	C89CDA	1896 591306	MIKHAIL SCHERBAKOV	{"email": "scherbakovmikhail081969@postgrespro.ru", "phone": "+70633973982"}
0005435554221	C89CDA	4737 061805	NIKOLAY GUSEV	{"phone": "+70849350029"}
0005435554222	5E8801	1988 566691	RASIM KUZNECOV	{"phone": "+70643397250"}
0005435554223	5E8801	6622 879088	NINA KOZLOVA	{"email": "kozlova-nina.06121976@postgrespro.ru", "phone": "+70505608912"}
0005435554224	248248	1301 992206	IRINA ERMAKOVA	{"email": "ermakova.irina_13101970@postgrespro.ru", "phone": "+70034034179"}
0005435554225	8E6434	5494 861461	VALENTINA IVANOVA	{"phone": "+70192327159"}
0005435554226	8E6434	4144 375956	ANATOLIY NAZAROV	{"phone": "+70116137488"}
0005435554227	3480BE	0376 869473	ANDREY DMITRIEV	{"phone": "+70116465571"}
0005435554228	5981E5	3779 997696	IRINA NAUMOVA	{"email": "irinanaumova-1984@postgrespro.ru", "phone": "+70448477857"}
0005435554229	5981E5	1713 489549	ELENA ANDREEVA	{"email": "andreeva-e-041977@postgrespro.ru", "phone": "+70793428274"}
0005435554230	5981E5	3868 056514	ALEKSANDR SOROKIN	{"email": "sorokin-aleksandr.1982@postgrespro.ru", "phone": "+70344103545"}
0005435554231	C43305	3007 677829	ANNA MOROZOVA	{"email": "a.morozova_121974@postgrespro.ru", "phone": "+70061260781"}
0005435554232	C43305	3620 526137	ELENA ANTONOVA	{"phone": "+70438291762"}
0005435554233	5B4707	9046 166803	ALEKSANDR TARASOV	{"email": "a.tarasov_1971@postgrespro.ru", "phone": "+70423927252"}
0005435554234	5B4707	5639 583794	ALEKSEY FROLOV	{"email": "frolov.aleksey.1972@postgrespro.ru", "phone": "+70080721562"}
0005435554235	359AAB	2517 689575	VALENTINA PAVLOVA	{"email": "pavlova-v.21041965@postgrespro.ru", "phone": "+70781602709"}
0005435554236	CE8C36	2910 665408	LUIZA DANILOVA	{"phone": "+70101016677"}
0005435554237	CE8C36	4206 087360	SERGEY BELOV	{"email": "s_belov.28031978@postgrespro.ru", "phone": "+70689649326"}
0005435554238	9FE5A5	6212 098909	TATYANA ANISIMOVA	{"phone": "+70630264042"}
0005435554239	9FE5A5	7518 380288	SERGEY KUZNECOV	{"email": "sergey.kuznecov.1966@postgrespro.ru", "phone": "+70924617170"}
0005435554240	9FE5A5	4470 956638	NIKOLAY MELNIKOV	{"email": "melnikov-n28071988@postgrespro.ru", "phone": "+70859500005"}
0005435554241	9F91A3	9538 227493	VLADIMIR SOKOLOV	{"email": "v_sokolov.061962@postgrespro.ru", "phone": "+70476717098"}
0005435554242	9F91A3	0239 938106	VARVARA SIDOROVA	{"phone": "+70366402389"}
0005435554243	F8DDDA	3809 622340	RAISA PETROVA	{"email": "petrova_r.17071982@postgrespro.ru", "phone": "+70956943856"}
0005435554244	F8DDDA	6560 410620	ANNA SIDOROVA	{"email": "sidorova_anna_1976@postgrespro.ru", "phone": "+70006301652"}
0005435554245	18B215	6677 351399	OLGA IVANOVA	{"email": "olga_ivanova_1967@postgrespro.ru", "phone": "+70978036541"}
0005435554246	18B215	2992 635193	TAISIYA STEPANOVA	{"email": "stepanova.taisiya1971@postgrespro.ru", "phone": "+70970956900"}
0005435554247	B7945B	6218 484302	RUSTAM PAVLOV	{"email": "pavlovrustam1970@postgrespro.ru", "phone": "+70810216588"}
0005435554248	4031F1	9602 979545	ALEKSANDRA VASILEVA	{"email": "vasileva-a21061978@postgrespro.ru", "phone": "+70682512992"}
0005435554249	F049D8	8027 687508	GALINA VOLKOVA	{"email": "volkova-g_12071977@postgrespro.ru", "phone": "+70064601373"}
0005435554250	F049D8	2803 764246	EVGENIY MAKSIMOV	{"email": "evgeniymaksimov1971@postgrespro.ru", "phone": "+70874842646"}
0005435554251	8CA340	1841 265200	ANATOLIY NAUMOV	{"phone": "+70523409700"}
0005435554252	937DBA	3323 616242	TIMOFEY PAVLOV	{"email": "t.pavlov1973@postgrespro.ru", "phone": "+70316736678"}
0005435554253	DB8690	0918 292040	BORIS PETROV	{"email": "petrov.boris14101970@postgrespro.ru", "phone": "+70440373382"}
0005435554254	4CEFBE	6981 376478	LYUDMILA KONDRATEVA	{"phone": "+70048707694"}
0005435554255	4CEFBE	4224 200464	LYUDMILA KUZNECOVA	{"email": "kuznecovalyudmila011970@postgrespro.ru", "phone": "+70523733240"}
0005435554256	D47A5A	7623 087002	ALEKSEY KOZLOV	{"phone": "+70855807975"}
0005435554257	0C2358	7007 877588	EKATERINA TARASOVA	{"phone": "+70497344615"}
0005435554258	0C2358	2556 658860	DANILA NIKITIN	{"email": "nikitin-d.1975@postgrespro.ru", "phone": "+70143923256"}
0005435554259	674A8C	0313 048550	SERGEY POPOV	{"email": "popov-sergey.18021965@postgrespro.ru", "phone": "+70046281550"}
0005435554260	8A5056	3767 686199	SERGEY IVANOV	{"email": "ivanovsergey_1974@postgrespro.ru", "phone": "+70439674461"}
0005435554261	DA8773	0119 590715	MIKHAIL TARASOV	{"phone": "+70555023592"}
0005435554262	F315E4	2701 338574	TATYANA KISELEVA	{"email": "kiselevat-111972@postgrespro.ru", "phone": "+70511197452"}
0005435554263	DF0ADF	7803 190501	EVGENIYA GAVRILOVA	{"phone": "+70808447972"}
0005435554264	DF0ADF	2999 493881	SERGEY ILIN	{"email": "sergey.ilin_21091961@postgrespro.ru", "phone": "+70129270505"}
0005435554265	57E92B	5650 714901	RADMIR EGOROV	{"email": "egorov_r041972@postgrespro.ru", "phone": "+70453429617"}
0005435554266	57E92B	7084 541884	VLADIMIR KOZLOV	{"email": "v-kozlov.1969@postgrespro.ru", "phone": "+70248970046"}
0005435554267	30C971	8228 953878	SERGEY CHERNOV	{"email": "sergey_chernov-021980@postgrespro.ru", "phone": "+70382736203"}
0005435554268	30C971	9207 562459	LARISA KONOVALOVA	{"email": "konovaloval.01091970@postgrespro.ru", "phone": "+70179411563"}
0005435554269	45CE6D	4860 873344	KIRILL IVANOV	{"phone": "+70149729012"}
0005435554270	4C5A0A	8216 101628	SERGEY STEPANOV	{"phone": "+70162241703"}
0005435554271	4C5A0A	7046 022302	ZOYA MOISEEVA	{"phone": "+70239921377"}
0005435554272	24034B	3100 155287	YURIY FILIPPOV	{"email": "filippov_y_25091971@postgrespro.ru", "phone": "+70666252211"}
0005435554273	24034B	1681 105305	OLEG IVANOV	{"phone": "+70077298289"}
0005435554274	54D24C	5610 222592	GRIGORIY KAZAKOV	{"email": "kazakov.grigoriy-05031970@postgrespro.ru", "phone": "+70527620408"}
0005435554275	E77080	5838 553019	ARTEM MOROZOV	{"email": "a_morozov_03071965@postgrespro.ru", "phone": "+70617605106"}
0005435554276	394797	9515 991743	EKATERINA MARTYNOVA	{"email": "ekaterina.martynova.1967@postgrespro.ru", "phone": "+70430200337"}
0005435554277	394797	4131 386083	SOFYA SERGEEVA	{"email": "sofya_sergeeva_07041960@postgrespro.ru", "phone": "+70807121121"}
0005435554278	AF6F66	5335 922465	ALEKSEY SIDOROV	{"phone": "+70971357638"}
0005435554279	F656DD	5827 208869	ELENA KOLESNIKOVA	{"phone": "+70110921339"}
0005435554280	F656DD	3435 057926	NIKOLAY DMITRIEV	{"email": "dmitriev-n.111971@postgrespro.ru", "phone": "+70161679138"}
0005435554281	E3E4F6	8056 676459	ANDREY KUZMIN	{"email": "akuzmin.1979@postgrespro.ru", "phone": "+70653695723"}
0005435554282	4DDACB	6728 129996	ANASTASIYA ALEKSEEVA	{"email": "a_alekseeva-031980@postgrespro.ru", "phone": "+70607528526"}
0005435554283	D77489	6261 979121	GALIYA KUZNECOVA	{"phone": "+70698400465"}
0005435554284	D77489	3615 595826	ANASTASIYA PETROVA	{"email": "petrova.anastasiya.1963@postgrespro.ru", "phone": "+70154316097"}
0005435554285	D77489	3115 012461	VLADIMIR GUSEV	{"email": "v.gusev.26081974@postgrespro.ru", "phone": "+70060739635"}
0005435554286	811A8F	0836 748906	GULNAZ MIRONOVA	{"phone": "+70903732164"}
0005435554287	811A8F	6433 784166	DMITRIY MOROZOV	{"email": "dmitriymorozov.051970@postgrespro.ru", "phone": "+70016271234"}
0005435554288	4F8D99	6779 031261	TATYANA SAVELEVA	{"phone": "+70550740473"}
0005435554289	4F8D99	1539 738477	SERGEY ALEKSEEV	{"phone": "+70038077915"}
0005435554290	5C73AB	5342 310408	PETR KRASNOV	{"phone": "+70455984943"}
0005435554291	5C73AB	1086 333812	OLGA KUZNECOVA	{"phone": "+70399474487"}
0005435554292	49933B	7912 842689	ELENA RYABOVA	{"email": "elenaryabova_21051974@postgrespro.ru", "phone": "+70020474112"}
0005435554293	49933B	1925 379821	ANASTASIYA POPOVA	{"phone": "+70011844836"}
0005435554294	E2A427	6379 543143	VADIM FEDOROV	{"phone": "+70491829309"}
0005435554295	E2A427	9325 632308	ELENA KOROLEVA	{"email": "elena_koroleva.31101970@postgrespro.ru", "phone": "+70628250056"}
0005435554296	B52599	6251 206858	ALEKSEY DENISOV	{"email": "a_denisov-1981@postgrespro.ru", "phone": "+70562299501"}
0005435554297	B52599	5612 522501	NADEZHDA TROFIMOVA	{"email": "nadezhda.trofimova-08041964@postgrespro.ru", "phone": "+70477594984"}
0005435554298	CAF41F	2975 535029	MARINA MALYSHEVA	{"phone": "+70909098174"}
0005435554299	CAF41F	1429 251604	IVAN VOLKOV	{"email": "ivan.volkov19111969@postgrespro.ru", "phone": "+70258589568"}
0005435554300	43D15A	7373 728855	TATYANA KULIKOVA	{"phone": "+70664296554"}
0005435554301	43D15A	3123 889804	VLADIMIR ORLOV	{"phone": "+70005680812"}
0005435554302	C5EC0A	2464 330897	KSENIYA MALYSHEVA	{"email": "k-malysheva.14051976@postgrespro.ru", "phone": "+70200324290"}
0005435554303	C5EC0A	8006 172337	LYUDMILA NIKIFOROVA	{"phone": "+70074444609"}
0005435554304	D51908	6780 874578	LYUBOV TARASOVA	{"phone": "+70482020294"}
0005435554305	D51908	0686 051856	TATYANA TIKHONOVA	{"phone": "+70252509439"}
0005435554306	1F89FA	2965 130216	NADEZHDA PAVLOVA	{"email": "pavlovanadezhda_1977@postgrespro.ru", "phone": "+70325129431"}
0005435554307	1F89FA	5297 849448	LYUBOV ILINA	{"phone": "+70431066722"}
0005435554308	D039AE	8346 286727	DARYA KULIKOVA	{"email": "darya-kulikova_1977@postgrespro.ru", "phone": "+70435486986"}
0005435554309	5F640D	2406 453078	LYUBOV MAKAROVA	{"email": "makarovalyubov18121977@postgrespro.ru", "phone": "+70004192359"}
0005435554310	5A9029	6066 162183	ALEKSANDR SCHERBAKOV	{"email": "aleksandr_scherbakov_1985@postgrespro.ru", "phone": "+70323934616"}
0005435554311	5A9029	7823 868674	RAIL MIRONOV	{"phone": "+70620251182"}
0005435554312	A3A4D6	4671 313954	LYUBOV STEPANOVA	{"email": "stepanovalyubov.031965@postgrespro.ru", "phone": "+70381504508"}
0005435554313	594899	1106 601370	NADEZHDA POTAPOVA	{"phone": "+70850428827"}
0005435554314	470911	3140 029944	DARYA AKIMOVA	{"phone": "+70568944764"}
0005435554315	7B33E9	1030 172494	VIKTOR IVANOV	{"phone": "+70360010256"}
0005435554316	C99BF6	9433 738766	SERGEY TIKHONOV	{"email": "tikhonov-sergey_29081969@postgrespro.ru", "phone": "+70679400542"}
0005435554317	C99BF6	0104 568976	NATALYA MELNIKOVA	{"phone": "+70841918919"}
0005435554318	3B25A4	6339 938142	ELENA SEMENOVA	{"email": "semenova.e_30051963@postgrespro.ru", "phone": "+70595053928"}
0005435554319	3B25A4	0243 473986	POLINA DANILOVA	{"phone": "+70905737541"}
0005435554320	40751C	5510 032463	ALEKSANDR MELNIKOV	{"email": "melnikov_a.22011969@postgrespro.ru", "phone": "+70925977072"}
0005435554321	FCFD99	2084 827472	ARINA SIDOROVA	{"email": "sidorova.arina121974@postgrespro.ru", "phone": "+70508208580"}
0005435554322	FCFD99	1747 713073	ALEKSANDR ROMANOV	{"phone": "+70168620885"}
0005435554323	FCFD99	6214 538264	DMITRIY SCHERBAKOV	{"phone": "+70097826850"}
0005435554324	ADC2DA	6055 183680	VALERIY MAKAROV	{"phone": "+70648110427"}
0005435554325	ADC2DA	9410 687918	VIKTOR ALEKSANDROV	{"phone": "+70516746684"}
0005435554326	D191A4	7441 135882	LYUBOV KUZNECOVA	{"phone": "+70514488112"}
0005435554327	D191A4	5005 501557	TAMARA ROMANOVA	{"phone": "+70899222569"}
0005435554328	AA0E7E	5058 265042	SVETLANA EGOROVA	{"phone": "+70322150856"}
0005435554329	0AD431	0002 895341	RAISA VASILEVA	{"email": "rvasileva_27091974@postgrespro.ru", "phone": "+70909442526"}
0005435555334	35E89E	5839 683537	ILYA BARANOV	{"email": "i.baranov1967@postgrespro.ru", "phone": "+70026971787"}
0005435555335	35E89E	9834 500932	VLADIMIR KOROLEV	{"email": "korolev_v091971@postgrespro.ru", "phone": "+70229338895"}
0005435555336	27DDF6	2666 347305	ALEKSANDR ROMANOV	{"email": "aleksandr_romanov-091969@postgrespro.ru", "phone": "+70545599097"}
0005435555337	27DDF6	0209 033363	ANATOLIY BARANOV	{"email": "anatoliybaranov-18121964@postgrespro.ru", "phone": "+70046149751"}
0005435555338	DEA67E	5377 186449	DARYA IVANOVA	{"phone": "+70917974735"}
0005435555339	9AA6A7	2076 235299	VLADIMIR PAVLOV	{"phone": "+70146807482"}
0005435555340	9AA6A7	8886 345961	ALEKSANDR KOZLOV	{"email": "aleksandr-kozlov091980@postgrespro.ru", "phone": "+70566914142"}
0005435555341	693F01	1632 592930	VERA KISELEVA	{"email": "v_kiseleva081968@postgrespro.ru", "phone": "+70771546160"}
0005435555342	C3B154	2515 350015	ANDREY POPOV	{"email": "popov_andrey_1970@postgrespro.ru", "phone": "+70254584020"}
0005435555343	D05837	2082 623546	NIKOLAY OSIPOV	{"phone": "+70085163953"}
0005435555344	D35F24	9966 795094	OLEG STEPANOV	{"phone": "+70445870962"}
0005435555345	623AA3	6778 012218	LYUDMILA FEDOROVA	{"email": "lfedorova-27071962@postgrespro.ru", "phone": "+70386811478"}
0005435555346	623AA3	3333 909283	YURIY KUZNECOV	{"email": "ykuznecov1968@postgrespro.ru", "phone": "+70928999611"}
0005435555347	623AA3	8700 473730	DANILA IVANOV	{"email": "danila.ivanov20051977@postgrespro.ru", "phone": "+70599496912"}
0005435555348	2332F8	0971 276567	ZOYA MAKAROVA	{"phone": "+70475030734"}
0005435555349	9B3C3F	3595 572261	NIKOLAY TIMOFEEV	{"email": "ntimofeev18091971@postgrespro.ru", "phone": "+70591559865"}
0005435555350	0F9899	7955 151663	ROMAN KULIKOV	{"email": "roman_kulikov.061970@postgrespro.ru", "phone": "+70640639348"}
0005435555351	A74929	7851 206446	LYUBOV NOVIKOVA	{"email": "novikovalyubov-031975@postgrespro.ru", "phone": "+70715016601"}
0005435555352	A74929	7813 330472	SVETLANA FEDOROVA	{"email": "fedorova_s011974@postgrespro.ru", "phone": "+70164928808"}
0005435555353	A74929	8350 401243	DANILA FILIPPOV	{"email": "danilafilippov1982@postgrespro.ru", "phone": "+70618000224"}
0005435555354	664098	0913 969118	LIDIYA VASILEVA	{"email": "l_vasileva-1968@postgrespro.ru", "phone": "+70488779173"}
0005435555355	664098	3467 741172	ALLA IVANOVA	{"email": "ivanova.a-1964@postgrespro.ru", "phone": "+70691002741"}
0005435555356	C667CA	5668 214087	VITALIY VOLKOV	{"email": "v.volkov.03081981@postgrespro.ru", "phone": "+70524929521"}
0005435555357	BC773D	9335 847894	ILYA VASILEV	{"email": "vasilev-ilya.1969@postgrespro.ru", "phone": "+70632459269"}
0005435555358	BDC6C8	2430 206559	ALEKSEY NIKOLAEV	{"email": "a.nikolaev_051971@postgrespro.ru", "phone": "+70632441206"}
0005435555359	6582EE	4682 374165	IVAN AFANASEV	{"email": "afanasev_i_051976@postgrespro.ru", "phone": "+70440631141"}
0005435555360	4BC7F3	8776 220021	GALINA FEDOROVA	{"phone": "+70972769813"}
0005435555361	4BC7F3	1395 765048	SVETLANA ZOTOVA	{"phone": "+70162325532"}
0005435555362	209D13	1007 073847	SERGEY ROMANOV	{"email": "sergey-romanov1967@postgrespro.ru", "phone": "+70634781333"}
0005435555363	5BFC0D	3908 257842	NIKOLAY AFANASEV	{"email": "afanasev.n_30071985@postgrespro.ru", "phone": "+70199825293"}
0005435555364	5BFC0D	3080 076617	VERA EGOROVA	{"email": "vegorova.13111969@postgrespro.ru", "phone": "+70979374062"}
0005435555365	FB826B	0648 527469	ALEKSANDR ALEKSANDROV	{"phone": "+70131362084"}
0005435555366	FB826B	6633 405690	NIKOLAY BORISOV	{"email": "n-borisov-061990@postgrespro.ru", "phone": "+70002088780"}
0005435555367	129252	4346 154039	ALEKSANDRA IVANOVA	{"phone": "+70244969033"}
0005435555368	1CD17C	8439 791010	ANDREY PAVLOV	{"email": "pavlov.andrey_1975@postgrespro.ru", "phone": "+70973177371"}
0005435555369	1CD17C	7980 382444	RUSLAN MELNIKOV	{"email": "melnikovruslan1975@postgrespro.ru", "phone": "+70045723884"}
0005435555370	D79637	6482 731884	LYUBOV ABRAMOVA	{"phone": "+70883205581"}
0005435555371	D79637	0747 706545	VLADIMIR OSIPOV	{"email": "vladimir.osipov1987@postgrespro.ru", "phone": "+70114449379"}
0005435555372	11C865	1159 608987	VYACHESLAV MIRONOV	{"phone": "+70530683783"}
0005435555373	0F8496	4682 761617	STANISLAV GRIGOREV	{"email": "s_grigorev-11041971@postgrespro.ru", "phone": "+70847004273"}
0005435555374	389876	9676 234803	GALINA EGOROVA	{"email": "egorova-galina-18021977@postgrespro.ru", "phone": "+70475810060"}
0005435555375	A241E3	6925 577008	BORIS IVANOV	{"email": "ivanov-boris.031975@postgrespro.ru", "phone": "+70109509669"}
0005435555376	A241E3	7562 702977	VIKTOR MATVEEV	{"phone": "+70739936427"}
0005435555377	418174	3860 265439	MARIYA MIRONOVA	{"phone": "+70389447149"}
0005435555378	418174	4069 302643	ARTUR KUZNECOV	{"phone": "+70702356208"}
0005435555379	691904	9948 811046	ALEKSEY KUDRYASHOV	{"phone": "+70054547428"}
0005435555380	691904	9711 070322	LARISA ERMAKOVA	{"phone": "+70686112871"}
0005435555381	691904	0271 072676	NIKITA VOLKOV	{"email": "volkov.n_1953@postgrespro.ru", "phone": "+70756090052"}
0005435555382	8E0B8A	9545 289837	VLADIMIR ANDREEV	{"phone": "+70269526985"}
0005435555383	4BA012	2931 674946	MIKHAIL GUSEV	{"phone": "+70156934106"}
0005435555384	4BA012	0648 461454	ALEKSANDR NOVIKOV	{"phone": "+70450743985"}
0005435555385	82F3F3	8326 020604	VERA DENISOVA	{"phone": "+70382535132"}
0005435555386	82F3F3	6827 988355	ALEKSANDR BORISOV	{"phone": "+70558507123"}
0005435555387	82F3F3	4067 033120	TAMARA KUZNECOVA	{"email": "kuznecova.tamara_12061975@postgrespro.ru", "phone": "+70353467212"}
0005435555388	7C9466	3566 875235	YURIY SOROKIN	{"email": "sorokin-yuriy.21031988@postgrespro.ru", "phone": "+70190384763"}
0005435555389	E064A7	7849 700895	POLINA SIDOROVA	{"email": "sidorova.polina_1973@postgrespro.ru", "phone": "+70853644807"}
0005435555390	1521A3	5967 710558	ROMAN VOLKOV	{"phone": "+70685359710"}
0005435555391	187F92	5608 989643	INNA ROMANOVA	{"email": "romanova_i_25021971@postgrespro.ru", "phone": "+70603159621"}
0005435555392	187F92	2791 923574	NATALYA SMIRNOVA	{"email": "smirnovanatalya_1974@postgrespro.ru", "phone": "+70274591751"}
0005435555393	187F92	2568 662063	ARTEM ABRAMOV	{"email": "artem_abramov1971@postgrespro.ru", "phone": "+70197979528"}
0005435555394	44E294	6341 989093	ANDREY KISELEV	{"email": "kiselev.a-081967@postgrespro.ru", "phone": "+70198834711"}
0005435555395	A2F527	5682 375326	VALERIY KUZNECOV	{"phone": "+70221955956"}
0005435555396	A2F527	7511 262775	LYUBOV KUZMINA	{"email": "kuzminalyubov-011970@postgrespro.ru", "phone": "+70663176695"}
0005435555397	0D38F4	7067 215774	YULIYA AFANASEVA	{"email": "afanaseva.y.22111969@postgrespro.ru", "phone": "+70291132880"}
0005435555398	78B417	6682 668922	VALENTINA TIKHONOVA	{"phone": "+70784898619"}
0005435555399	78B417	4947 413843	LYUDMILA FEDOROVA	{"email": "lfedorova_011968@postgrespro.ru", "phone": "+70948812224"}
0005435555400	78B417	8307 281228	IVAN ORLOV	{"phone": "+70814470956"}
0005435555401	718AE3	1714 178404	ALEKSANDR ANDREEV	{"phone": "+70120274177"}
0005435555402	718AE3	2449 116820	VERA DENISOVA	{"email": "denisova-v.1974@postgrespro.ru", "phone": "+70731204077"}
0005435555403	5716FC	0315 559668	TARAS IVANOV	{"email": "ivanovt1968@postgrespro.ru", "phone": "+70882412435"}
0005435555404	BCBB86	1608 777801	ARTEM SOLOVEV	{"phone": "+70539820560"}
0005435555405	BCBB86	4569 260817	VALENTINA MATVEEVA	{"phone": "+70493205254"}
0005435555406	4A3702	6220 143158	SERGEY STEPANOV	{"email": "stepanov_sergey22041966@postgrespro.ru", "phone": "+70984009934"}
0005435555407	4A3702	6490 794512	VERA VOROBEVA	{"email": "vorobeva_v-09051969@postgrespro.ru", "phone": "+70787472783"}
0005435555408	B6981A	8694 239936	LEV POPOV	{"phone": "+70117578023"}
0005435555409	B6981A	5034 403711	GALINA ALEKSEEVA	{"email": "alekseeva-galina_29031964@postgrespro.ru", "phone": "+70936016513"}
0005435555410	B6981A	2430 869096	EVGENIYA MOISEEVA	{"email": "e_moiseeva.031983@postgrespro.ru", "phone": "+70951307559"}
0005435555411	3BDBD5	6680 173101	NIKOLAY KOZLOV	{"phone": "+70985682407"}
0005435555412	3BDBD5	0027 221757	MARIYA NIKOLAEVA	{"email": "nikolaeva-mariya-061974@postgrespro.ru", "phone": "+70017782508"}
0005435555413	9E7061	8075 094459	VLADIMIR ALEKSEEV	{"phone": "+70518655463"}
0005435555414	9E7061	4082 541659	DARYA SCHERBAKOVA	{"phone": "+70314607592"}
0005435555415	0B91A9	7375 709517	ANDREY KAZAKOV	{"email": "kazakov.andrey.1972@postgrespro.ru", "phone": "+70241687967"}
0005435555416	752F63	7861 520897	SVETLANA BELOVA	{"email": "svetlana.belova.20011968@postgrespro.ru", "phone": "+70268160256"}
0005435555417	589617	8803 463522	KAMILLA KUZMINA	{"phone": "+70722551731"}
0005435555418	687039	1644 836246	ALEKSEY KISELEV	{"phone": "+70648507151"}
0005435555419	687039	5560 181501	EKATERINA NOVIKOVA	{"phone": "+70507316780"}
0005435555420	687039	2643 645173	ELENA SEMENOVA	{"phone": "+70687725089"}
0005435555421	FD7F8D	6733 254488	EVGENIY ZAKHAROV	{"email": "zakharov.evgeniy_21111968@postgrespro.ru", "phone": "+70697146586"}
0005435555422	9141AA	7416 154195	IRINA STEPANOVA	{"email": "i-stepanova_111982@postgrespro.ru", "phone": "+70728479306"}
0005435555423	83B294	4076 182767	VIKTOR KUZMIN	{"email": "v-kuzmin_11011971@postgrespro.ru", "phone": "+70502180424"}
0005435555424	DBA443	2310 418106	VALERIYA BELYAEVA	{"email": "valeriya.belyaeva.041970@postgrespro.ru", "phone": "+70747898482"}
0005435555425	244869	2203 771193	YANA VASILEVA	{"email": "vasileva_yana_1974@postgrespro.ru", "phone": "+70443335363"}
0005435555426	244869	6111 107934	SERGEY ZAKHAROV	{"phone": "+70876015214"}
0005435555427	1B27CB	5705 883897	ANNA KOVALEVA	{"email": "kovalevaanna21021979@postgrespro.ru", "phone": "+70553877274"}
0005435555428	1B27CB	2831 971438	NIKOLAY OSIPOV	{"email": "n-osipov.06111966@postgrespro.ru", "phone": "+70364709237"}
0005435555429	BD0F0D	1024 143064	ALEKSEY FILIPPOV	{"email": "alekseyfilippov.15031970@postgrespro.ru", "phone": "+70290379387"}
0005435556646	E63A67	6783 199496	ALEKSANDR PAVLOV	{"email": "aleksandr-pavlov1977@postgrespro.ru", "phone": "+70602201204"}
0005435556647	09A54B	8188 448308	STEPAN KOZLOV	{"phone": "+70053284316"}
0005435556648	09A54B	4208 056486	SERGEY PAVLOV	{"phone": "+70836238783"}
0005435556649	09A54B	2980 461199	LYUDMILA OSIPOVA	{"phone": "+70189918112"}
0005435556650	EBE585	6015 269275	VALENTIN GUSEV	{"email": "gusev_v_13031972@postgrespro.ru", "phone": "+70451610611"}
0005435556651	3560B7	0160 874287	RIMMA VOLKOVA	{"phone": "+70606839731"}
0005435556652	3560B7	7366 356717	NATALYA YAKOVLEVA	{"email": "yakovleva.n-101971@postgrespro.ru", "phone": "+70693893989"}
0005435556653	588EFD	1877 930690	LEONID MELNIKOV	{"email": "melnikov-l-091990@postgrespro.ru", "phone": "+70627341347"}
0005435556654	095E67	0166 148937	TATYANA SERGEEVA	{"email": "sergeeva.t061975@postgrespro.ru", "phone": "+70657287888"}
0005435556655	095E67	3956 697083	ANASTASIYA DMITRIEVA	{"phone": "+70895974466"}
0005435556656	095E67	8775 270809	MAKSIM POPOV	{"email": "m.popov-091980@postgrespro.ru", "phone": "+70008219683"}
0005435556657	095E67	1191 117699	DMITRIY GUSEV	{"phone": "+70955708829"}
0005435556658	0ACC6E	8929 673797	ALEKSANDR VOLKOV	{"email": "avolkov1967@postgrespro.ru", "phone": "+70139152198"}
0005435556659	422705	1482 826303	MIKHAIL SEMENOV	{"email": "msemenov07031959@postgrespro.ru", "phone": "+70947250912"}
0005435556660	422705	0244 520582	YURIY ZHUKOV	{"phone": "+70626232262"}
0005435556661	B71113	2168 806977	VALERIY KUDRYASHOV	{"phone": "+70932766135"}
0005435556662	B71113	1070 256189	VLADIMIR SERGEEV	{"phone": "+70357294079"}
0005435556663	245E32	3179 043884	LYUBOV SEMENOVA	{"phone": "+70743702325"}
0005435556664	245E32	7609 032118	GALINA KUZNECOVA	{"email": "galina-kuznecova_23111979@postgrespro.ru", "phone": "+70318573088"}
0005435556665	245E32	8821 769893	IRINA KUZMINA	{"phone": "+70648851465"}
0005435556666	0C5578	5833 295835	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr1960@postgrespro.ru", "phone": "+70266372711"}
0005435556667	0C5578	3665 405395	TATYANA PETROVA	{"phone": "+70395011037"}
0005435556668	9BC9F8	4822 423325	DMITRIY POPOV	{"phone": "+70122753035"}
0005435556669	25B4A2	7881 627070	IGOR SMIRNOV	{"email": "igor_smirnov-1965@postgrespro.ru", "phone": "+70661318048"}
0005435556670	07928C	7274 700656	MARIYA BELYAEVA	{"phone": "+70804455487"}
0005435556671	632E49	4865 538486	ANNA BORISOVA	{"email": "borisovaanna_1979@postgrespro.ru", "phone": "+70916521695"}
0005435556672	DC8C24	1685 281559	REGINA KISELEVA	{"email": "r_kiseleva_041968@postgrespro.ru", "phone": "+70831292984"}
0005435556673	FF5F6A	2246 996100	MARGARITA FILATOVA	{"email": "filatova-m06091975@postgrespro.ru", "phone": "+70737757546"}
0005435556674	17741B	7011 356225	ALLA ZAKHAROVA	{"email": "a-zakharova-04021973@postgrespro.ru", "phone": "+70309499033"}
0005435556675	CE5629	2311 159072	IGOR BELOV	{"email": "belov_i041966@postgrespro.ru", "phone": "+70930537243"}
0005435556676	903041	2683 250087	LIDIYA SOROKINA	{"email": "sorokina.l.1958@postgrespro.ru", "phone": "+70479217547"}
0005435556677	903041	8963 163712	ANTONINA KUZNECOVA	{"email": "akuznecova.21051977@postgrespro.ru", "phone": "+70231885886"}
0005435556678	903041	9147 169397	TATYANA GUSEVA	{"phone": "+70572575619"}
0005435556679	903041	7386 835153	IRINA TARASOVA	{"email": "tarasova_i-101971@postgrespro.ru", "phone": "+70646023419"}
0005435556680	C1ABB7	2094 350081	SOFYA FADEEVA	{"email": "fadeevasofya1967@postgrespro.ru", "phone": "+70021189591"}
0005435556681	52832A	4729 640014	ANDREY FEDOROV	{"phone": "+70024589089"}
0005435556682	B4255D	2229 118680	OLEG RODIONOV	{"email": "o.rodionov_081978@postgrespro.ru", "phone": "+70903667770"}
0005435556683	B4255D	2441 965324	ILDAR BELOV	{"email": "ildar_belov.25031970@postgrespro.ru", "phone": "+70438639625"}
0005435556684	9425A8	2033 974947	ALEKSANDR ZAKHAROV	{"email": "a-zakharov.15031965@postgrespro.ru", "phone": "+70758786493"}
0005435556685	9425A8	8556 623144	IRINA MAKAROVA	{"email": "irina_makarova_1974@postgrespro.ru", "phone": "+70209129103"}
0005435556686	725DD7	8599 495318	MIKHAIL PETROV	{"phone": "+70496490566"}
0005435556687	725DD7	6163 760771	ZARINA GRISHINA	{"email": "zarina_grishina_08061978@postgrespro.ru", "phone": "+70422208013"}
0005435556688	66FC5D	8308 358385	SVETLANA BORISOVA	{"email": "borisova-s041978@postgrespro.ru", "phone": "+70732995810"}
0005435556689	66FC5D	9357 340011	STANISLAV VOLKOV	{"email": "s.volkov1968@postgrespro.ru", "phone": "+70725151875"}
0005435556690	DCB804	1964 950565	ELENA PETROVA	{"phone": "+70116541046"}
0005435556691	F9AA9F	3926 659623	ANTONINA GERASIMOVA	{"email": "antonina-gerasimova_21111971@postgrespro.ru", "phone": "+70947835451"}
0005435556692	4FA49C	1642 151625	ELENA RODIONOVA	{"phone": "+70253251093"}
0005435556693	B33E06	6257 303918	OLGA VLASOVA	{"phone": "+70066996769"}
0005435556694	2BE281	4096 924230	NIKITA AFANASEV	{"email": "nikita.afanasev031975@postgrespro.ru", "phone": "+70500581710"}
0005435556695	3EC79A	8954 016877	NADEZHDA ARKHIPOVA	{"email": "n_arkhipova-1978@postgrespro.ru", "phone": "+70728206855"}
0005435556696	3EC79A	4882 521386	OLEG YAKOVLEV	{"phone": "+70118468945"}
0005435556697	E9F56E	6826 350379	ALEKSANDR DENISOV	{"phone": "+70978759987"}
0005435556698	57EC28	7369 190831	GALINA AKIMOVA	{"email": "galinaakimova-04111978@postgrespro.ru", "phone": "+70002377101"}
0005435556699	6098E1	1780 331017	ALEKSANDR ZAKHAROV	{"phone": "+70581308134"}
0005435556700	798511	7302 325613	VYACHESLAV STEPANOV	{"phone": "+70200442613"}
0005435556701	798511	1467 649760	ANDREY SIDOROV	{"email": "andrey_sidorov.05081968@postgrespro.ru", "phone": "+70678664626"}
0005435556702	F74711	2729 805200	BORIS IVANOV	{"email": "ivanov-boris121964@postgrespro.ru", "phone": "+70150021069"}
0005435556703	F74711	2560 845262	VALERIY NIKITIN	{"phone": "+70785290476"}
0005435556704	F74711	7497 946384	DENIS TARASOV	{"phone": "+70093236784"}
0005435556705	0B7104	4395 162647	TATYANA PETROVA	{"phone": "+70633157531"}
0005435556706	0B7104	9354 110920	SVETLANA TIKHONOVA	{"phone": "+70855092561"}
0005435556707	1F4CE6	9930 697305	PETR SMIRNOV	{"phone": "+70942535488"}
0005435556708	1F4CE6	7372 642457	OLGA GORBUNOVA	{"phone": "+70204731327"}
0005435556709	1F4CE6	6724 001700	VYACHESLAV KOROLEV	{"email": "vyacheslav_korolev25091976@postgrespro.ru", "phone": "+70061604312"}
0005435556710	798CA1	6111 075577	EVGENIYA ANDREEVA	{"email": "eandreeva061973@postgrespro.ru", "phone": "+70654918117"}
0005435556711	BB2122	4478 607206	TATYANA ILINA	{"phone": "+70336147947"}
0005435556712	BFC5EC	0100 993164	NATALYA SERGEEVA	{"email": "natalya-sergeeva_22041985@postgrespro.ru", "phone": "+70767625267"}
0005435556713	693215	2008 020888	ANASTASIYA ALEKSANDROVA	{"phone": "+70575809121"}
0005435556714	693215	4473 030780	OLGA ROMANOVA	{"email": "romanova-olga_1968@postgrespro.ru", "phone": "+70264787364"}
0005435556715	8E9313	7518 313427	KIRILL TIKHONOV	{"email": "tikhonov-kirill-01051976@postgrespro.ru", "phone": "+70053280707"}
0005435556716	8C4BEA	0737 920157	ALEKSANDR MIKHAYLOV	{"phone": "+70471594570"}
0005435556717	C2E3F9	2592 185771	OLGA ILINA	{"phone": "+70614891841"}
0005435556718	0098A2	0684 776984	MAKSIM NOVIKOV	{"phone": "+70856901772"}
0005435556719	483586	2200 381888	ROMAN SCHERBAKOV	{"email": "rscherbakov-20041982@postgrespro.ru", "phone": "+70306584922"}
0005435556720	483586	6234 837226	IRINA VOROBEVA	{"email": "vorobeva-irina.1974@postgrespro.ru", "phone": "+70882527260"}
0005435556721	013662	4885 917657	ALEKSANDR ZAKHAROV	{"phone": "+70692613780"}
0005435556722	013662	1117 626908	RUDOLF POPOV	{"email": "rudolf-popov1967@postgrespro.ru", "phone": "+70363944897"}
0005435556723	001F08	1858 145847	VIKTORIYA DENISOVA	{"email": "denisovav-071971@postgrespro.ru", "phone": "+70504448611"}
0005435556724	6078B6	9728 115630	ELENA ZAYCEVA	{"phone": "+70002530826"}
0005435556725	6078B6	4181 564988	VLADIMIR KISELEV	{"email": "kiselevvladimir-121968@postgrespro.ru", "phone": "+70027857687"}
0005435556726	6078B6	1136 421501	NAILYA DANILOVA	{"phone": "+70841340713"}
0005435556727	6078B6	7177 591706	OKSANA TIKHONOVA	{"email": "oksana.tikhonova-1970@postgrespro.ru", "phone": "+70866403243"}
0005435556728	C943AB	3939 969196	ALEKSANDR MELNIKOV	{"email": "a.melnikov_101962@postgrespro.ru", "phone": "+70691896075"}
0005435556729	C943AB	9847 754749	VLADIMIR TIKHONOV	{"email": "v.tikhonov.29061963@postgrespro.ru", "phone": "+70036238877"}
0005435556730	991181	1003 114674	TATYANA PETROVA	{"email": "t-petrova_111978@postgrespro.ru", "phone": "+70726399075"}
0005435556731	43061B	5944 889621	PAVEL IVANOV	{"email": "p_ivanov01071966@postgrespro.ru", "phone": "+70903204958"}
0005435556732	985875	8787 842913	ALEKSEY SEMENOV	{"phone": "+70238153094"}
0005435556733	985875	2030 034919	EDUARD POPOV	{"email": "e-popov_061989@postgrespro.ru", "phone": "+70066340208"}
0005435556734	985875	1992 325966	EKATERINA TIMOFEEVA	{"email": "timofeeva-e_051973@postgrespro.ru", "phone": "+70732907716"}
0005435556735	242515	9246 699336	ANDREY PETROV	{"phone": "+70167896686"}
0005435556736	B32FEE	3021 427723	ALEKSANDR PAVLOV	{"email": "a_pavlov_1980@postgrespro.ru", "phone": "+70270736003"}
0005435556737	2A70F8	2162 411867	ALLA GUSEVA	{"email": "guseva-alla-1969@postgrespro.ru", "phone": "+70887611262"}
0005435556738	89EE5B	6516 517105	LYUBOV ZAYCEVA	{"phone": "+70216344361"}
0005435556739	39AE04	1281 712195	ANDREY MOROZOV	{"phone": "+70272803091"}
0005435556740	39AE04	5818 620705	VALENTINA EFREMOVA	{"phone": "+70488413150"}
0005435556741	DD5C9B	9850 130547	GALIYA DMITRIEVA	{"email": "galiyadmitrieva1977@postgrespro.ru", "phone": "+70066861819"}
0005435556742	DD5C9B	0058 027497	ANASTASIYA NAZAROVA	{"phone": "+70184187165"}
0005435556743	5D5F12	5598 330807	YULIYA CHERNOVA	{"phone": "+70200767657"}
0005435556744	5D5F12	0613 352310	MIKHAIL GAVRILOV	{"email": "gavrilovm.1979@postgrespro.ru", "phone": "+70963902933"}
0005435556745	554F68	8507 337181	ALEKSANDR NIKOLAEV	{"email": "nikolaeva15041983@postgrespro.ru", "phone": "+70203102728"}
0005435556746	0AFEE6	4891 330039	TATYANA ANISIMOVA	{"email": "tatyana_anisimova.1963@postgrespro.ru", "phone": "+70269156584"}
0005435556747	0AFEE6	6769 174256	EVGENIY MIRONOV	{"email": "evgeniy_mironov-051967@postgrespro.ru", "phone": "+70327363710"}
0005435556748	05D025	0193 813598	EKATERINA ANISIMOVA	{"phone": "+70327666827"}
0005435556749	379F4B	9139 166974	IVAN SOROKIN	{"email": "i-sorokin-041971@postgrespro.ru", "phone": "+70584539038"}
0005435556750	E175B5	3831 747947	OLGA MAKAROVA	{"email": "olga.makarova-1969@postgrespro.ru", "phone": "+70640754413"}
0005435556751	E175B5	8981 923765	OLGA FROLOVA	{"email": "olga-frolova-1968@postgrespro.ru", "phone": "+70937728410"}
0005435556752	E175B5	2432 114173	SERGEY ISAEV	{"phone": "+70734817665"}
0005435556753	E175B5	6544 536601	SERGEY SIDOROV	{"phone": "+70052140340"}
0005435556754	483B97	0442 910397	PAVEL DMITRIEV	{"phone": "+70896723873"}
0005435556755	483B97	5763 454863	MARINA AKIMOVA	{"phone": "+70210611542"}
0005435556756	483B97	1687 604421	NATALYA KUZNECOVA	{"email": "kuznecova-natalya-08111967@postgrespro.ru", "phone": "+70948547653"}
0005435556757	483B97	1540 715753	IGOR POPOV	{"email": "popov-i-041968@postgrespro.ru", "phone": "+70677944698"}
0005435556758	81E41A	3448 546895	MARIYA KOROLEVA	{"email": "m.koroleva05011976@postgrespro.ru", "phone": "+70688452627"}
0005435556759	81E41A	8799 227887	ALEKSANDR KUZNECOV	{"email": "aleksandr.kuznecov.081977@postgrespro.ru", "phone": "+70042190658"}
0005435556760	3786A2	6246 558873	VIKTOR ALEKSANDROV	{"phone": "+70628394427"}
0005435556761	00E028	2650 212441	LYUDMILA ORLOVA	{"phone": "+70254780671"}
0005435556762	00E028	0969 726480	EVGENIY KAZAKOV	{"email": "kazakov-evgeniy24071965@postgrespro.ru", "phone": "+70332030153"}
0005435556763	52C7A9	7185 681397	ANASTASIYA SOLOVEVA	{"email": "soloveva.anastasiya-18071971@postgrespro.ru", "phone": "+70658496180"}
0005435556764	E158E5	4934 697605	NATALIYA VLASOVA	{"email": "n_vlasova17111967@postgrespro.ru", "phone": "+70604935637"}
0005435556765	E158E5	9285 862462	NIKOLAY IVANOV	{"phone": "+70976805438"}
0005435556766	46E1DD	6265 141011	KAMILLA POPOVA	{"phone": "+70925047933"}
0005435556767	464A0E	3220 841796	DMITRIY SMIRNOV	{"phone": "+70123341396"}
0005435556768	8C859F	2425 589725	DMITRIY DAVYDOV	{"email": "davydov-d22041987@postgrespro.ru", "phone": "+70635437989"}
0005435556769	8C859F	2301 962087	VIKTOR KUDRYASHOV	{"phone": "+70131081831"}
0005435556770	D336AB	3370 301391	LARISA POPOVA	{"email": "l_popova_1970@postgrespro.ru", "phone": "+70358545957"}
0005435558039	38557A	2844 537599	ALEKSANDR VOLKOV	{"email": "aleksandr_volkov-30011975@postgrespro.ru", "phone": "+70292600613"}
0005435558040	38557A	8596 783621	ELENA MASLOVA	{"phone": "+70411997654"}
0005435558041	38557A	7307 851717	EVGENIY KRASNOV	{"phone": "+70253003337"}
0005435558042	A34FF4	3375 398118	ALEKSEY KUZMIN	{"email": "kuzmin_aleksey30041972@postgrespro.ru", "phone": "+70470627151"}
0005435558043	7D8CBB	6752 858991	VLADIMIR TIKHONOV	{"email": "v.tikhonov.10101965@postgrespro.ru", "phone": "+70165744207"}
0005435558044	18D858	1092 486060	VLADIMIR MOROZOV	{"email": "morozov_v_27041969@postgrespro.ru", "phone": "+70961358616"}
0005435558045	18D858	7142 565268	ALEKSEY FEDOTOV	{"email": "fedotova121965@postgrespro.ru", "phone": "+70396842346"}
0005435558046	18D858	5125 942506	VITALIY ZAKHAROV	{"email": "zakharov-vitaliy_30121956@postgrespro.ru", "phone": "+70354281819"}
0005435558047	E1339D	8885 514920	LYUDMILA AFANASEVA	{"phone": "+70712616537"}
0005435558048	AAAB88	5442 333320	VLADIMIR ZAKHAROV	{"email": "v_zakharov_031976@postgrespro.ru", "phone": "+70636980505"}
0005435558049	719972	5867 678072	GALINA STEPANOVA	{"phone": "+70641475604"}
0005435558050	719972	0211 033120	VLADIMIR POPOV	{"email": "popov_vladimir.051981@postgrespro.ru", "phone": "+70161527730"}
0005435558051	94D4CB	9743 112760	VALENTINA ORLOVA	{"phone": "+70413388570"}
0005435558052	04589B	2681 136080	TAMARA ZHURAVLEVA	{"email": "tamara_zhuravleva.1981@postgrespro.ru", "phone": "+70203063883"}
0005435558053	04589B	8500 903308	SERGEY ORLOV	{"email": "sergey.orlov19111973@postgrespro.ru", "phone": "+70601578549"}
0005435558054	42498B	8215 006577	ALEKSANDR KUZMIN	{"email": "a.kuzmin.24021963@postgrespro.ru", "phone": "+70842608973"}
0005435558055	38E6C3	1061 474974	ELENA KARPOVA	{"phone": "+70780659987"}
0005435558056	F8AE74	4864 495964	ALEKSANDR AFANASEV	{"phone": "+70677327430"}
0005435558057	A4642D	1743 162706	OLGA EFREMOVA	{"phone": "+70235841935"}
0005435558058	A4642D	1327 962345	MIKHAIL SCHERBAKOV	{"phone": "+70852248413"}
0005435558059	16546C	9424 644577	DMITRIY KISELEV	{"phone": "+70153000866"}
0005435558060	E42512	7317 066826	ALEKSANDR MEDVEDEV	{"phone": "+70892293084"}
0005435558061	645BCD	9573 781315	NIKOLAY ANDREEV	{"phone": "+70645179528"}
0005435558062	645BCD	3436 950822	ANDREY SOLOVEV	{"email": "solovev_andrey30091969@postgrespro.ru", "phone": "+70007478794"}
0005435558063	C33ECF	2767 831235	DMITRIY IVANOV	{"email": "d.ivanov1971@postgrespro.ru", "phone": "+70246343795"}
0005435558064	C33ECF	2290 313123	LYUBOV MOISEEVA	{"phone": "+70680746686"}
0005435558065	A54FDD	4132 731112	KSENIYA KULIKOVA	{"email": "kseniya_kulikova_121961@postgrespro.ru", "phone": "+70254738472"}
0005435558066	A54FDD	5323 665685	NATALYA NESTEROVA	{"email": "n.nesterova26121973@postgrespro.ru", "phone": "+70458294824"}
0005435558067	272B0A	7449 983882	ANASTASIYA ISAEVA	{"phone": "+70576696294"}
0005435558068	272B0A	5843 457806	GALINA KISELEVA	{"phone": "+70062907714"}
0005435558069	659D22	2374 545502	YURIY VOROBEV	{"email": "vorobev_yuriy.1980@postgrespro.ru", "phone": "+70455175397"}
0005435558070	3068DE	1831 500344	DMITRIY BONDARENKO	{"email": "d-bondarenko_1977@postgrespro.ru", "phone": "+70209697323"}
0005435558071	999A85	1375 354134	VIKTOR FEDOROV	{"phone": "+70119661291"}
0005435558072	C44D79	0614 483988	ANGELINA ABRAMOVA	{"phone": "+70883155419"}
0005435558073	C44D79	5632 227678	NADEZHDA TROFIMOVA	{"phone": "+70767586536"}
0005435558074	B8A3F6	5757 362345	IGOR AFANASEV	{"email": "afanasev_i_121960@postgrespro.ru", "phone": "+70854628652"}
0005435558075	B8A3F6	5264 951653	MARIYA KOLESNIKOVA	{"email": "kolesnikovamariya.10021977@postgrespro.ru", "phone": "+70754827708"}
0005435558076	857893	5876 843925	TATYANA FILATOVA	{"phone": "+70267891214"}
0005435558077	857893	5058 495810	NADEZHDA PETROVA	{"email": "npetrova_061977@postgrespro.ru", "phone": "+70334863851"}
0005435558078	88175F	1596 009518	ANDREY ROMANOV	{"phone": "+70163777531"}
0005435558079	BF5113	1226 279811	ALEKSANDRA KOZLOVA	{"email": "a_kozlova_23121981@postgrespro.ru", "phone": "+70791765640"}
0005435558080	BF5113	2889 377758	ROMAN VASILEV	{"email": "roman_vasilev-10031970@postgrespro.ru", "phone": "+70488307476"}
0005435558081	EB32BE	4948 904417	ALEKSEY KULIKOV	{"email": "a_kulikov.041975@postgrespro.ru", "phone": "+70784910049"}
0005435558082	EB32BE	0451 660100	EKATERINA ANTONOVA	{"email": "e_antonova_071960@postgrespro.ru", "phone": "+70863495868"}
0005435558083	BA0478	7991 240613	OKSANA ISAEVA	{"phone": "+70944130788"}
0005435558084	42F925	0089 524761	VYACHESLAV SIDOROV	{"email": "vsidorov.29021980@postgrespro.ru", "phone": "+70027500204"}
0005435558085	8EF583	3050 802532	ANASTASIYA ARKHIPOVA	{"phone": "+70542051041"}
0005435558086	B6BAF8	5525 017813	NINA SEMENOVA	{"phone": "+70004819939"}
0005435558087	474EA1	6417 148716	VALENTINA BORISOVA	{"phone": "+70255026942"}
0005435558088	474EA1	6206 411508	OLGA NIKOLAEVA	{"email": "o_nikolaeva-14021974@postgrespro.ru", "phone": "+70241299265"}
0005435558089	0DB68F	4619 416123	ANASTASIYA KUZNECOVA	{"phone": "+70776645041"}
0005435558090	11F2D0	9705 565132	VLADIMIR ZAKHAROV	{"phone": "+70646881309"}
0005435558091	FA3E65	7507 235080	ARTEM SMIRNOV	{"email": "a_smirnov11011955@postgrespro.ru", "phone": "+70824542174"}
0005435558092	028D4E	2503 240150	DANIIL BONDARENKO	{"email": "bondarenko-daniil_06101970@postgrespro.ru", "phone": "+70714794076"}
0005435558093	028D4E	3378 913434	ANGELINA MAKAROVA	{"phone": "+70169034769"}
0005435558094	F24106	4974 553869	GALINA KONOVALOVA	{"phone": "+70755966759"}
0005435558095	4D7992	3911 401999	OLGA TARASOVA	{"phone": "+70449386042"}
0005435558096	4D7992	4064 073229	EKATERINA MIRONOVA	{"phone": "+70938463008"}
0005435558097	94A39E	4161 520587	LARISA PAVLOVA	{"email": "pavlova.larisa.1964@postgrespro.ru", "phone": "+70827221440"}
0005435558098	94A39E	7500 533810	VADIM ANTONOV	{"phone": "+70507499005"}
0005435558099	10DCDE	6530 926663	IRINA DENISOVA	{"email": "denisova-i111983@postgrespro.ru", "phone": "+70704944877"}
0005435558100	10DCDE	3768 661718	ALEKSANDR EGOROV	{"phone": "+70111296564"}
0005435558101	9B0B79	1666 367642	LYUDMILA BORISOVA	{"phone": "+70267898459"}
0005435558102	9B0B79	7443 094368	MAKSIM IVANOV	{"email": "ivanov.maksim13071978@postgrespro.ru", "phone": "+70658768231"}
0005435558103	C1FC35	9408 618416	ARTEM DMITRIEV	{"email": "artem-dmitriev18051972@postgrespro.ru", "phone": "+70922487967"}
0005435558104	F77D1E	8513 540037	ALEKSANDR SEMENOV	{"email": "semenov.a28011978@postgrespro.ru", "phone": "+70736902418"}
0005435558105	FAEA18	0681 114338	EVGENIY PAVLOV	{"email": "evgeniy.pavlov-27111966@postgrespro.ru", "phone": "+70174537219"}
0005435558106	8623EA	0448 727562	VIKTORIYA KOROLEVA	{"phone": "+70879369873"}
0005435558107	14D8B0	6140 399475	NADEZHDA NIKIFOROVA	{"email": "n_nikiforova-1982@postgrespro.ru", "phone": "+70622084910"}
0005435558108	14D8B0	9495 666691	VADIM ALEKSEEV	{"email": "vadim-alekseev.121978@postgrespro.ru", "phone": "+70544755427"}
0005435558109	844612	7361 376739	EVGENIY ZAYCEV	{"email": "zaycev-e1989@postgrespro.ru", "phone": "+70761534018"}
0005435558110	844612	5420 883756	LYUBOV MALYSHEVA	{"phone": "+70938929162"}
0005435558111	39B806	6335 096646	OLGA BELOVA	{"email": "o.belova.011971@postgrespro.ru", "phone": "+70379357708"}
0005435558112	F07746	9905 751394	VERA YUDINA	{"email": "yudina_v051971@postgrespro.ru", "phone": "+70351141335"}
0005435558113	F07746	5987 927623	FILIPP BORISOV	{"phone": "+70293874346"}
0005435558114	133265	3613 625671	SVETLANA IVANOVA	{"email": "svetlana_ivanova_1963@postgrespro.ru", "phone": "+70578654433"}
0005435558115	8A24E4	8794 747359	ALLA MASLOVA	{"phone": "+70990046647"}
0005435558116	943FD1	0578 234093	KRISTINA IVANOVA	{"phone": "+70892088970"}
0005435558117	943FD1	2167 158024	ELENA NIKOLAEVA	{"email": "elena.nikolaeva-1973@postgrespro.ru", "phone": "+70422116804"}
0005435558118	5833B6	5997 403115	MARINA KISELEVA	{"phone": "+70503846418"}
0005435558119	D7F721	3103 866274	SERGEY RODIONOV	{"email": "sergey-rodionov_1968@postgrespro.ru", "phone": "+70642753995"}
0005435558120	D7F721	8990 334148	ALEKSANDR YAKOVLEV	{"email": "a.yakovlev-07061975@postgrespro.ru", "phone": "+70032549136"}
0005435558121	2C0D30	4056 817893	LARISA KOVALEVA	{"phone": "+70508782200"}
0005435558122	2C0D30	7425 443978	OLGA VOROBEVA	{"phone": "+70554322938"}
0005435558123	2C0D30	6553 132464	MARAT PAVLOV	{"email": "mpavlov_25111986@postgrespro.ru", "phone": "+70163305003"}
0005435558124	89E17A	6991 097850	VALERIY VASILEV	{"email": "valeriy.vasilev.01071969@postgrespro.ru", "phone": "+70716644039"}
0005435558125	89E17A	3439 598297	TATYANA LEBEDEVA	{"phone": "+70406227922"}
0005435558126	90C97C	6829 269226	DMITRIY SMIRNOV	{"email": "dmitriy.smirnov_1986@postgrespro.ru", "phone": "+70632615918"}
0005435558127	9847AD	8675 998411	ILYA ZAKHAROV	{"phone": "+70923459064"}
0005435558128	605E4B	0710 280625	IVAN KUDRYASHOV	{"email": "kudryashov.ivan1973@postgrespro.ru", "phone": "+70452943207"}
0005435558129	401493	5500 165155	KLAVDIYA MARTYNOVA	{"phone": "+70246564909"}
0005435558130	BA9D35	4908 447493	OKSANA BELYAEVA	{"email": "belyaeva_oksana-1983@postgrespro.ru", "phone": "+70513187858"}
0005435558131	5626F7	7494 433036	MIKHAIL ORLOV	{"email": "m.orlov.17051978@postgrespro.ru", "phone": "+70887055072"}
0005435558132	F9EBF2	6613 141663	LYUDMILA ANDREEVA	{"phone": "+70100324109"}
0005435558133	B74736	2051 331315	ALEKSANDR VOROBEV	{"phone": "+70632381559"}
0005435558134	92B61D	4526 234696	ANZHELIKA MIKHAYLOVA	{"phone": "+70276489940"}
0005435558135	3D9783	8592 178791	SERGEY ZAKHAROV	{"phone": "+70519668441"}
0005435558136	3D9783	2096 653529	LYUBOV IVANOVA	{"email": "ivanovalyubov.121969@postgrespro.ru", "phone": "+70449923085"}
0005435558137	1CBB51	1025 855703	DMITRIY PAVLOV	{"email": "dmitriy.pavlov_021971@postgrespro.ru", "phone": "+70091355289"}
0005435558138	4580BB	3820 913539	EVGENIY ANDREEV	{"email": "andreev_evgeniy_10121979@postgrespro.ru", "phone": "+70587568958"}
0005435558139	7037F1	9330 407202	YULIYA EFIMOVA	{"phone": "+70414753188"}
0005435558140	2D5C04	7231 033353	OLGA MAKSIMOVA	{"email": "o_maksimova-14031974@postgrespro.ru", "phone": "+70434339567"}
0005435558141	2D8558	4811 900040	VALERIY SOROKIN	{"phone": "+70629301224"}
0005435558142	2D8558	0884 376340	YURIY VOLKOV	{"email": "volkovyuriy.1985@postgrespro.ru", "phone": "+70187978533"}
0005435558143	2D8558	7079 993841	NATALYA DENISOVA	{"email": "n_denisova061974@postgrespro.ru", "phone": "+70002110468"}
0005435558144	3D3FA6	5374 635598	DMITRIY ANDREEV	{"phone": "+70547797719"}
0005435558145	36DEE3	1284 282346	PAVEL YAKOVLEV	{"phone": "+70813545962"}
0005435558146	4B7934	9007 476465	YULIYA MEDVEDEVA	{"phone": "+70965849089"}
0005435558147	4B7934	6717 799248	DENIS PETROV	{"email": "petrov-d.011970@postgrespro.ru", "phone": "+70267964225"}
0005435558148	8FB0B8	1799 169556	PETR PETROV	{"phone": "+70798182721"}
0005435558149	8FB0B8	9018 576418	MAKSIM NIKITIN	{"email": "nikitin-maksim_021974@postgrespro.ru", "phone": "+70057822000"}
0005435558150	8FB0B8	0296 591281	ELENA MAKAROVA	{"email": "makarova.elena_111968@postgrespro.ru", "phone": "+70695369449"}
0005435558151	9BA404	4533 408925	ARTEM PETROV	{"phone": "+70371397895"}
0005435558152	9BA404	3559 782103	ELENA ANTONOVA	{"email": "elena.antonova-1970@postgrespro.ru", "phone": "+70695592897"}
0005435558153	E29D08	9795 671854	SERGEY KOROLEV	{"phone": "+70074664399"}
0005435558154	E29D08	6950 176952	IGOR BELOV	{"email": "belov_i_1972@postgrespro.ru", "phone": "+70776015587"}
0005435558155	A99F2A	1636 049394	LYUDMILA YUDINA	{"phone": "+70208920481"}
0005435558156	B7FDC9	8471 742247	VERA SEMENOVA	{"email": "vera_semenova_1969@postgrespro.ru", "phone": "+70891565453"}
0005435558157	4A62EA	5241 351167	ALEKSEY ANDREEV	{"email": "a_andreev-11091980@postgrespro.ru", "phone": "+70212441912"}
0005435558158	161428	5146 377234	DMITRIY KAZAKOV	{"phone": "+70535130969"}
0005435558159	161428	3365 615365	YURIY STEPANOV	{"phone": "+70870389342"}
0005435558160	ACBF28	4511 771186	VALERIY VOLKOV	{"email": "v.volkov_1967@postgrespro.ru", "phone": "+70160772015"}
0005435558161	ACBF28	4123 776237	ELENA KOROLEVA	{"phone": "+70096575244"}
0005435558162	ACBF28	3604 119786	NADEZHDA IVANOVA	{"email": "n.ivanova-03091962@postgrespro.ru", "phone": "+70400342692"}
0005435558163	ACBF28	5589 692673	VIKTOR SMIRNOV	{"phone": "+70329179957"}
0005435611729	4F6E2C	7490 355153	ALEKSANDR KARPOV	{"phone": "+70262796084"}
0005435611698	45D10A	8792 531948	NADEZHDA GERASIMOVA	{"email": "nadezhda-gerasimova_1968@postgrespro.ru", "phone": "+70583374425"}
0005435611699	45D10A	9109 327709	EVGENIY YAKOVLEV	{"email": "yakovlevevgeniy-1972@postgrespro.ru", "phone": "+70052005265"}
0005435611700	9A5364	7254 839823	ALEKSANDRA DANILOVA	{"email": "danilovaaleksandra021973@postgrespro.ru", "phone": "+70358044341"}
0005435611701	F25328	5662 291413	VIKTOR MIRONOV	{"phone": "+70385790561"}
0005435611702	F25328	9858 754871	NADEZHDA GERASIMOVA	{"phone": "+70438224648"}
0005435611703	D2F68B	4171 745970	ELIZAVETA RYABOVA	{"email": "ryabova.e_04101966@postgrespro.ru", "phone": "+70366905752"}
0005435611704	EEA31B	6555 874467	NIKOLAY VOLKOV	{"phone": "+70925668271"}
0005435611705	EEA31B	2499 200298	ELENA MAKAROVA	{"phone": "+70509419453"}
0005435611706	E06B89	8059 343205	NIKOLAY ABRAMOV	{"phone": "+70274141412"}
0005435611707	E06B89	3626 437588	ANTONINA KUZMINA	{"phone": "+70963458541"}
0005435611708	E06B89	5679 866542	RAISA CHERNOVA	{"email": "chernovar071977@postgrespro.ru", "phone": "+70395542440"}
0005435611709	E06B89	0589 389690	TATYANA EFREMOVA	{"phone": "+70296164887"}
0005435611710	A0B4CB	1161 066942	ALINA KOZLOVA	{"email": "kozlova-alina.1976@postgrespro.ru", "phone": "+70873843032"}
0005435611711	C8FA97	4053 765650	ANDREY ANDREEV	{"phone": "+70635652199"}
0005435611712	7D50F6	8091 165551	NINA ILINA	{"phone": "+70982376595"}
0005435611713	7D50F6	5666 466225	ALEKSEY RODIONOV	{"email": "a.rodionov.101973@postgrespro.ru", "phone": "+70334074900"}
0005435611714	778A44	2011 322818	NIKOLAY VLASOV	{"phone": "+70170650321"}
0005435611715	BA4DFC	5060 893721	YURIY MELNIKOV	{"phone": "+70140662620"}
0005435611716	BA4DFC	1891 377595	ELIZAVETA ROMANOVA	{"email": "e-romanova-1977@postgrespro.ru", "phone": "+70850726394"}
0005435611717	BA4DFC	7358 652863	ANNA KRASNOVA	{"email": "a_krasnova-17071975@postgrespro.ru", "phone": "+70881778257"}
0005435611718	B8301C	5694 795086	ALEKSEY SOKOLOV	{"phone": "+70605425356"}
0005435611719	CB0D66	1095 175346	ANDREY KUDRYASHOV	{"phone": "+70828896132"}
0005435611720	CB0D66	5026 939359	PAVEL MOROZOV	{"phone": "+70234826411"}
0005435611721	47159A	6604 581745	DANIIL BONDARENKO	{"email": "bondarenko_daniil_101972@postgrespro.ru", "phone": "+70017093915"}
0005435611722	0237EF	1879 425017	SVETLANA KOVALEVA	{"email": "kovaleva_svetlana.09111971@postgrespro.ru", "phone": "+70832275883"}
0005435611723	3252D7	4025 807126	SVETLANA ROMANOVA	{"phone": "+70147092527"}
0005435611724	3252D7	4716 204823	EKATERINA YAKOVLEVA	{"phone": "+70780601189"}
0005435611725	3252D7	1206 465871	VLADIMIR BELOV	{"email": "belov-v-21081968@postgrespro.ru", "phone": "+70476884028"}
0005435611726	DBD632	0875 599298	NATALYA BORISOVA	{"phone": "+70346806031"}
0005435611727	A36069	6274 944740	ANGELINA SOROKINA	{"phone": "+70976780028"}
0005435611728	F1B6A9	5367 923785	VIKTORIYA MAKAROVA	{"phone": "+70249288471"}
0005435611730	4E8F9C	3646 583678	LYUDMILA OSIPOVA	{"email": "osipoval091973@postgrespro.ru", "phone": "+70337818557"}
0005435611731	16066A	8761 532479	GENNADIY IVANOV	{"email": "givanov-061972@postgrespro.ru", "phone": "+70615760302"}
0005435611732	E2783E	8231 668150	MIKHAIL SOLOVEV	{"phone": "+70307955208"}
0005435611733	767196	0699 559657	ALEKSANDR KAZAKOV	{"email": "kazakov.aleksandr-10021965@postgrespro.ru", "phone": "+70688728290"}
0005435611734	E4E0B5	5061 586263	NATALIYA YUDINA	{"phone": "+70549853146"}
0005435611735	E4E0B5	8628 878890	NIKOLAY KUZNECOV	{"email": "n.kuznecov23101965@postgrespro.ru", "phone": "+70525675600"}
0005435611736	E4E0B5	4737 115957	ALEKSEY MOROZOV	{"email": "aleksey.morozov_1960@postgrespro.ru", "phone": "+70040883632"}
0005435611737	9E01D6	5785 462733	YURIY NAUMOV	{"email": "naumov_y_1968@postgrespro.ru", "phone": "+70590031351"}
0005435611738	18607D	9642 688088	LARISA ZAKHAROVA	{"email": "zakharova-l_1963@postgrespro.ru", "phone": "+70447035464"}
0005435611739	875A11	5915 800360	ANDREY ZHURAVLEV	{"email": "zhuravlev-andrey-091979@postgrespro.ru", "phone": "+70911736647"}
0005435611740	067DC0	7914 503574	KIRILL RODIONOV	{"email": "kirill-rodionov.071978@postgrespro.ru", "phone": "+70270969450"}
0005435611741	004C98	7829 119365	DENIS IVANOV	{"email": "d.ivanov101983@postgrespro.ru", "phone": "+70118436234"}
0005435611742	004C98	4064 641610	VALERIY KRASNOV	{"email": "valeriykrasnov_021970@postgrespro.ru", "phone": "+70856478321"}
0005435611743	5AB410	4179 575414	LYUDMILA ORLOVA	{"phone": "+70943308193"}
0005435611744	7A8645	1923 123613	PAVEL ZAKHAROV	{"email": "pzakharov-031989@postgrespro.ru", "phone": "+70810299997"}
0005435611745	7A8645	4880 638147	LARISA KUZNECOVA	{"phone": "+70333258847"}
0005435611746	B9ED7D	5365 692126	ANDREY GAVRILOV	{"email": "gavrilov_andrey_1969@postgrespro.ru", "phone": "+70862011909"}
0005435611747	73F81C	2171 768454	IGOR VASILEV	{"email": "i-vasilev02061968@postgrespro.ru", "phone": "+70617090479"}
0005435611748	6A25A6	9354 244629	ZHANNA SOLOVEVA	{"phone": "+70225921999"}
0005435611749	08A2D0	3800 416288	EVGENIY SCHERBAKOV	{"phone": "+70572606797"}
0005435611750	8968FF	8187 900448	VLADIMIR GORBUNOV	{"email": "vladimir.gorbunov101967@postgrespro.ru", "phone": "+70435001320"}
0005435611751	CD7E11	7352 838604	MARGARITA MARTYNOVA	{"email": "margarita_martynova-1965@postgrespro.ru", "phone": "+70787144943"}
0005435611752	1DBD09	4656 075954	GALINA MELNIKOVA	{"email": "g_melnikova.081982@postgrespro.ru", "phone": "+70774407492"}
0005435611753	21B818	2347 105887	VIKTOR MIRONOV	{"phone": "+70792009608"}
0005435611754	21B818	5022 699022	RENAT SCHERBAKOV	{"phone": "+70238011615"}
0005435611755	9A8913	2731 340880	ALEKSEY STEPANOV	{"email": "a_stepanov.21071963@postgrespro.ru", "phone": "+70601884957"}
0005435611756	9A8913	0162 325301	DMITRIY IVANOV	{"email": "ivanovdmitriy-25091972@postgrespro.ru", "phone": "+70263007183"}
0005435611757	F073B1	9555 375604	VLADISLAV VOLKOV	{"email": "volkovv29061975@postgrespro.ru", "phone": "+70552713379"}
0005435611758	F073B1	2699 179103	VALENTINA ORLOVA	{"phone": "+70479216634"}
0005435611759	4A316A	5321 256283	VLADIMIR KAZAKOV	{"phone": "+70535875751"}
0005435611760	4A316A	1165 118570	ALEKSEY KOROLEV	{"email": "korolev_aleksey091973@postgrespro.ru", "phone": "+70159119669"}
0005435611761	D84C03	0927 132879	ILYA FEDOTOV	{"email": "fedotovi_051981@postgrespro.ru", "phone": "+70310324093"}
0005435611762	62A986	4020 408765	EVA MIRONOVA	{"phone": "+70291819385"}
0005435611763	9C6F9A	5152 464881	IRINA STEPANOVA	{"email": "istepanova_21071981@postgrespro.ru", "phone": "+70875957653"}
0005435611764	9C6F9A	8408 645429	ALEKSANDR SCHERBAKOV	{"email": "scherbakov-a.20071973@postgrespro.ru", "phone": "+70504937643"}
0005435611765	7E9E95	0565 835042	GENNADIY BELOV	{"phone": "+70310928598"}
0005435611766	7E9E95	0857 842886	IRINA EFREMOVA	{"phone": "+70252673990"}
0005435611767	DA5DB2	9351 966972	ALEKSANDR IVANOV	{"phone": "+70263158310"}
0005435611768	DA5DB2	1788 856318	TAISIYA ZAKHAROVA	{"phone": "+70194606217"}
0005435611769	109C4E	1128 681867	PAVEL DAVYDOV	{"email": "pavel.davydov071981@postgrespro.ru", "phone": "+70696319717"}
0005435611770	6CB068	7807 527941	VLADIMIR SOROKIN	{"email": "v_sorokin.111965@postgrespro.ru", "phone": "+70170287268"}
0005435611771	6CB068	1458 186868	ANDREY SIDOROV	{"phone": "+70072927630"}
0005435611772	59B777	9639 721322	ROBERT FOMIN	{"phone": "+70228997927"}
0005435611773	FF25ED	7258 151173	MARINA NIKITINA	{"email": "nikitinam28031978@postgrespro.ru", "phone": "+70919054289"}
0005435611774	B62B2C	5801 112678	IVAN SERGEEV	{"phone": "+70923379012"}
0005435611775	10458F	1769 901684	LYUDMILA MALYSHEVA	{"email": "malysheval061971@postgrespro.ru", "phone": "+70781598463"}
0005435611776	4F1A99	1107 032351	NIKOLAY SIDOROV	{"phone": "+70445509027"}
0005435611777	4C4C61	2881 217338	ELENA FROLOVA	{"phone": "+70141583561"}
0005435611778	B8CFB8	8400 630437	ALEKSANDR KONOVALOV	{"phone": "+70663261497"}
0005435611779	C6A1BE	7439 541654	ALEKSANDRA KUZMINA	{"email": "kuzmina_a.1970@postgrespro.ru", "phone": "+70553799752"}
0005435611780	C6A1BE	5335 681041	IGOR SHEVCHENKO	{"phone": "+70837727308"}
0005435611781	BBCDC3	2374 367185	GALINA IVANOVA	{"email": "g-ivanova.1972@postgrespro.ru", "phone": "+70353752125"}
0005435611782	31753C	0915 970878	YULIYA BOGDANOVA	{"email": "bogdanova-y.111976@postgrespro.ru", "phone": "+70074173890"}
0005435611783	E16B40	5552 042174	DENIS MATVEEV	{"phone": "+70806144253"}
0005435611784	9FC844	7766 098677	VERONIKA BORISOVA	{"email": "v-borisova-071966@postgrespro.ru", "phone": "+70682492490"}
0005435611785	9FC844	6868 447193	ALEKSANDR PETROV	{"email": "a-petrov.21111976@postgrespro.ru", "phone": "+70830682751"}
0005435611786	80CBBA	7333 193817	MAKSIM CHERNOV	{"email": "mchernov29071986@postgrespro.ru", "phone": "+70410288703"}
0005435611787	80CBBA	8466 610340	ALEKSANDR BONDARENKO	{"email": "a_bondarenko071958@postgrespro.ru", "phone": "+70185618777"}
0005435611788	40021C	2627 210894	NATALYA MARTYNOVA	{"email": "martynovanatalya_1976@postgrespro.ru", "phone": "+70269360887"}
0005435611789	83B2FF	6562 645773	SERGEY MOISEEV	{"phone": "+70266535903"}
0005435611790	64D043	6660 835764	ALEKSANDRA PAVLOVA	{"phone": "+70643372809"}
0005435611791	64D043	8975 786555	VIKTOR KUDRYASHOV	{"email": "kudryashov-viktor18081977@postgrespro.ru", "phone": "+70527350151"}
0005435611792	244FE0	3413 348695	IVAN ABRAMOV	{"email": "iabramov.071967@postgrespro.ru", "phone": "+70150344369"}
0005435611793	FA14CC	7087 834749	RINAT IVANOV	{"phone": "+70935856651"}
0005435611794	EDD409	4675 067539	VYACHESLAV VASILEV	{"phone": "+70130783398"}
0005435611795	BEF47C	5689 473496	EDUARD ROMANOV	{"email": "eduardromanov_121964@postgrespro.ru", "phone": "+70842713301"}
0005435611796	7A1F02	5953 577444	TAMARA ANISIMOVA	{"email": "anisimovat1963@postgrespro.ru", "phone": "+70728597575"}
0005435611797	EF92A0	9874 142702	VERA KUZMINA	{"email": "vkuzmina.1973@postgrespro.ru", "phone": "+70571354164"}
0005435611798	56FCF0	4501 839673	NINA SOROKINA	{"phone": "+70241802562"}
0005435611799	F3B76E	8411 242777	OLGA LAZAREVA	{"email": "lazarevao_1977@postgrespro.ru", "phone": "+70246052550"}
0005435611800	C4EECB	6999 517956	ALEKSANDR DMITRIEV	{"email": "a_dmitriev-02071972@postgrespro.ru", "phone": "+70370611991"}
0005435611801	C4EECB	8131 925299	ALEKSANDR GERASIMOV	{"phone": "+70081585681"}
0005435611802	55093F	6954 679492	VALENTINA ERMAKOVA	{"phone": "+70173942348"}
0005435611803	55093F	3359 627323	NATALYA CHERNOVA	{"phone": "+70930813339"}
0005435611804	49C4DA	7715 659477	OLGA SIDOROVA	{"phone": "+70913165783"}
0005435611805	49C4DA	8379 921063	GALINA KAZAKOVA	{"phone": "+70136838643"}
0005435611806	908A62	9997 356018	ANATOLIY ZAKHAROV	{"phone": "+70534776381"}
0005435611807	F54E66	4154 949001	ANDREY RODIONOV	{"email": "rodionov_a_1967@postgrespro.ru", "phone": "+70174895894"}
0005435611808	F54E66	8518 060703	NINA ZAKHAROVA	{"email": "nina_zakharova-1978@postgrespro.ru", "phone": "+70462288515"}
0005435611809	F54E66	2259 479980	VALENTINA ABRAMOVA	{"phone": "+70274864186"}
0005435611810	E57C10	7828 914342	TATYANA SIDOROVA	{"email": "t-sidorova.1969@postgrespro.ru", "phone": "+70064283732"}
0005435611811	2282C0	6778 092009	OKSANA ORLOVA	{"phone": "+70965541000"}
0005435611812	2282C0	9449 501179	RUSTAM IVANOV	{"phone": "+70942655452"}
0005435611813	F970BA	2144 099198	OLGA ROMANOVA	{"email": "o-romanova-041969@postgrespro.ru", "phone": "+70839435580"}
0005435611814	F970BA	8709 509316	OLGA NIKOLAEVA	{"email": "nikolaevaolga-1974@postgrespro.ru", "phone": "+70526988176"}
0005435611815	080162	6389 606321	VADIM ALEKSEEV	{"email": "alekseev_vadim_1973@postgrespro.ru", "phone": "+70633415557"}
0005435611816	CE8EA8	4807 330821	SERGEY KOZLOV	{"phone": "+70453688787"}
0005435611817	CBA973	8322 178526	ANTON MOROZOV	{"email": "morozov_anton051971@postgrespro.ru", "phone": "+70638497909"}
0005435611818	225AD1	9286 333089	ALEKSEY BORISOV	{"email": "borisov.aleksey_1963@postgrespro.ru", "phone": "+70400611992"}
0005435611819	E25EFD	5551 181782	NIKOLAY MELNIKOV	{"email": "melnikov_n.021970@postgrespro.ru", "phone": "+70845547005"}
0005435611820	287D6E	4712 537036	IRINA KUDRYASHOVA	{"email": "kudryashova.i-19061961@postgrespro.ru", "phone": "+70316055221"}
0005435611821	F9AD04	5919 416963	SERGEY OSIPOV	{"email": "osipov-s1972@postgrespro.ru", "phone": "+70363670832"}
0005435611822	F9AD04	8376 765815	KLARA ZHURAVLEVA	{"email": "k.zhuravleva-14011962@postgrespro.ru", "phone": "+70293326294"}
0005435611823	373640	2228 867652	VLADIMIR PAVLOV	{"phone": "+70303656709"}
0005435611824	667F74	8824 725172	DENIS MAKAROV	{"email": "makarov_denis_061976@postgrespro.ru", "phone": "+70494157028"}
0005435611825	667F74	6475 490135	EKATERINA BARANOVA	{"email": "baranova_e-22021986@postgrespro.ru", "phone": "+70558508429"}
0005435612000	ABCC0F	9664 914512	EKATERINA BELYAEVA	{"phone": "+70883992418"}
0005435611826	173FF2	1907 516625	OLEG KOZLOV	{"email": "olegkozlov1972@postgrespro.ru", "phone": "+70638256924"}
0005435611827	173FF2	4003 228401	ELIZAVETA SIDOROVA	{"email": "sidorova_e.031983@postgrespro.ru", "phone": "+70587261423"}
0005435611828	D766A4	2328 118101	DMITRIY BONDARENKO	{"phone": "+70743289993"}
0005435611829	EC0D2D	1046 154987	DANIIL PETROV	{"email": "petrov.daniil-061964@postgrespro.ru", "phone": "+70133335597"}
0005435611830	EC0D2D	4771 249508	ELENA MOROZOVA	{"phone": "+70920103083"}
0005435611831	EC0D2D	0243 280216	NATALYA POPOVA	{"email": "popova_natalya03091980@postgrespro.ru", "phone": "+70395053019"}
0005435611832	2166A0	8906 864708	ANNA IVANOVA	{"email": "ivanova.anna.27091980@postgrespro.ru", "phone": "+70548633975"}
0005435611833	F2F39C	9800 373318	OKSANA OSIPOVA	{"email": "oksana.osipova1976@postgrespro.ru", "phone": "+70346294194"}
0005435611834	F2F39C	7703 736200	STANISLAV POPOV	{"phone": "+70846378351"}
0005435611835	D794B1	1662 752179	VERA DMITRIEVA	{"phone": "+70322976527"}
0005435611836	D794B1	2056 368814	GALINA OSIPOVA	{"phone": "+70072363591"}
0005435611837	D794B1	9003 685737	ZINAIDA ALEKSANDROVA	{"phone": "+70910072574"}
0005435611838	31BC30	7978 739748	SVETLANA ANTONOVA	{"email": "antonova.svetlana-28061979@postgrespro.ru", "phone": "+70570131914"}
0005435611839	05A267	1071 888607	LYUDMILA KUZNECOVA	{"email": "kuznecova-lyudmila1971@postgrespro.ru", "phone": "+70888568861"}
0005435611840	058FA9	3768 998422	SERGEY MIRONOV	{"phone": "+70204493259"}
0005435612061	232F9C	8287 441882	NAIL MELNIKOV	{"phone": "+70750088416"}
0005435611841	058FA9	4013 809353	ALISHER ZAKHAROV	{"email": "zakharov_alisher20091976@postgrespro.ru", "phone": "+70573496397"}
0005435611842	1ABEB9	7621 572181	NATALYA BELYAEVA	{"email": "belyaevan.19091970@postgrespro.ru", "phone": "+70875667865"}
0005435611843	1ABEB9	0033 333412	IRINA SERGEEVA	{"email": "sergeeva_irina1978@postgrespro.ru", "phone": "+70932221030"}
0005435611844	2A1FD6	4240 669082	LARISA POPOVA	{"email": "larisa_popova.30061974@postgrespro.ru", "phone": "+70891231889"}
0005435611845	6285A8	1284 702885	ALEKSEY ZAKHAROV	{"email": "aleksey_zakharov_23071975@postgrespro.ru", "phone": "+70278380081"}
0005435611846	6285A8	0548 272154	EVGENIY TARASOV	{"email": "evgeniy_tarasov-1968@postgrespro.ru", "phone": "+70069562111"}
0005435611847	6285A8	0811 900716	KRISTINA KONOVALOVA	{"email": "k_konovalova1983@postgrespro.ru", "phone": "+70112703759"}
0005435611848	D0798F	1977 131503	SERGEY DAVYDOV	{"phone": "+70008407602"}
0005435611849	FA816C	7899 540962	VERA MIKHAYLOVA	{"email": "mikhaylova_vera-111972@postgrespro.ru", "phone": "+70165763452"}
0005435611850	E40161	8297 744271	GALINA YAKOVLEVA	{"email": "galinayakovleva_1967@postgrespro.ru", "phone": "+70014982583"}
0005435611851	E40161	9990 653834	NATALYA GORBUNOVA	{"email": "gorbunovanatalya1972@postgrespro.ru", "phone": "+70869687655"}
0005435611852	7F35C4	7384 780804	MARGARITA SOLOVEVA	{"phone": "+70951196760"}
0005435611853	7F35C4	7562 929907	EKATERINA KUZNECOVA	{"email": "ekaterina_kuznecova1975@postgrespro.ru", "phone": "+70507086810"}
0005435611854	102BDC	2343 753871	VLADIMIR ZHURAVLEV	{"phone": "+70512326656"}
0005435611855	B6D8E2	7514 326578	GENNADIY ALEKSEEV	{"email": "gennadiyalekseev_1964@postgrespro.ru", "phone": "+70948306532"}
0005435611856	B6D8E2	7842 227821	SERGEY ANTONOV	{"email": "sergey-antonov11091972@postgrespro.ru", "phone": "+70317716902"}
0005435611857	1BD6E1	5479 283835	ALEKSANDR VOLKOV	{"email": "volkov-a1969@postgrespro.ru", "phone": "+70538939016"}
0005435611858	1BD6E1	1112 828082	VIKTOR FILIPPOV	{"email": "viktorfilippov-20041969@postgrespro.ru", "phone": "+70048261264"}
0005435611859	F9120F	3023 648739	TAMARA TIKHONOVA	{"email": "t-tikhonova_1965@postgrespro.ru", "phone": "+70108107768"}
0005435611860	C67F28	7318 383306	PETR POPOV	{"email": "p.popov.05071987@postgrespro.ru", "phone": "+70271934794"}
0005435611861	C67F28	2333 298087	TATYANA KUZMINA	{"email": "tatyana_kuzmina081969@postgrespro.ru", "phone": "+70770557997"}
0005435611862	79AEDE	6289 371149	EDGAR VASILEV	{"email": "edgarvasilev-011976@postgrespro.ru", "phone": "+70300239732"}
0005435611863	79AEDE	2495 261780	MARIYA LAZAREVA	{"phone": "+70023646138"}
0005435611864	3D4031	3889 965587	NAILYA ISAEVA	{"phone": "+70038536511"}
0005435611865	9B35DB	5566 093853	SERGEY STEPANOV	{"email": "stepanov.s_101963@postgrespro.ru", "phone": "+70660711966"}
0005435611866	9B35DB	1468 550255	SERGEY ALEKSANDROV	{"email": "s_aleksandrov1961@postgrespro.ru", "phone": "+70162146315"}
0005435611867	6199E9	9778 033405	SERGEY POPOV	{"email": "popovs.1973@postgrespro.ru", "phone": "+70475136524"}
0005435611868	D90317	1052 512909	LIDIYA YAKOVLEVA	{"email": "yakovleva-lidiya_051976@postgrespro.ru", "phone": "+70397433009"}
0005435611869	4BA2CA	5005 611210	YURIY KUDRYASHOV	{"email": "y_kudryashov.1968@postgrespro.ru", "phone": "+70456179734"}
0005435611870	4BA2CA	1159 295042	VYACHESLAV DAVYDOV	{"email": "davydov-vyacheslav.03081964@postgrespro.ru", "phone": "+70186981415"}
0005435611871	4F99AB	8889 914469	OLGA ISAEVA	{"phone": "+70413210556"}
0005435611872	6723A7	7116 007905	EVGENIY ANTONOV	{"phone": "+70632231109"}
0005435611873	C9E084	0717 109024	DMITRIY EGOROV	{"email": "dmitriyegorov_1969@postgrespro.ru", "phone": "+70663138836"}
0005435611874	C9E084	2956 131208	MIKHAIL SOLOVEV	{"email": "solovevmikhail-1976@postgrespro.ru", "phone": "+70543008002"}
0005435611875	A0852E	7652 766572	ILYA NAZAROV	{"email": "ilyanazarov28061987@postgrespro.ru", "phone": "+70698571571"}
0005435611876	18D298	9559 448769	NATALYA EGOROVA	{"email": "natalya.egorova.1977@postgrespro.ru", "phone": "+70591008021"}
0005435611877	58AECB	8564 025009	ANNA BELYAEVA	{"phone": "+70052778274"}
0005435611878	4E218C	2126 827155	VITALIY KUZNECOV	{"email": "kuznecov_v-05091970@postgrespro.ru", "phone": "+70529936125"}
0005435611879	4E218C	5137 697364	ANASTASIYA TROFIMOVA	{"email": "trofimova.anastasiya.07121975@postgrespro.ru", "phone": "+70606059898"}
0005435611880	4E218C	2200 053415	KRISTINA GUSEVA	{"email": "guseva_k.101963@postgrespro.ru", "phone": "+70253535267"}
0005435611881	DB83FD	9277 117435	IGOR ILIN	{"email": "igor.ilin.1983@postgrespro.ru", "phone": "+70609198568"}
0005435611882	DB83FD	9800 558477	YURIY FROLOV	{"phone": "+70337193592"}
0005435611883	29DF63	6428 990724	VLADIMIR VOLKOV	{"email": "volkov-v_28121972@postgrespro.ru", "phone": "+70388548857"}
0005435611884	D0263B	5437 879468	ALEKSEY ALEKSANDROV	{"phone": "+70256480003"}
0005435611885	5FA3EB	1498 840295	VALENTINA ANDREEVA	{"email": "andreeva-v.061973@postgrespro.ru", "phone": "+70984748885"}
0005435611886	D82E87	2969 359704	NATALYA SMIRNOVA	{"phone": "+70484182442"}
0005435611887	D82E87	4349 173863	ANDREY NAZAROV	{"phone": "+70693575698"}
0005435611888	7C6371	3489 829905	PAVEL DAVYDOV	{"email": "davydov_pavel_26071968@postgrespro.ru", "phone": "+70383773847"}
0005435611889	7C6371	0951 440294	ELENA VASILEVA	{"phone": "+70494607431"}
0005435611890	642E98	6047 569700	TATYANA MATVEEVA	{"email": "tatyanamatveeva.29121971@postgrespro.ru", "phone": "+70922549758"}
0005435611891	642E98	6889 434268	ALEKSANDR MATVEEV	{"email": "a-matveev16061960@postgrespro.ru", "phone": "+70345456605"}
0005435611892	9AA821	4395 422506	VALERIY FOMIN	{"email": "vfomin01051969@postgrespro.ru", "phone": "+70812996750"}
0005435611893	6E4E8F	0674 917851	RAVIL FROLOV	{"phone": "+70477273858"}
0005435611894	497C06	7815 102645	ANTON TIKHONOV	{"phone": "+70684663769"}
0005435611895	1B578F	0989 047644	IRINA ZHURAVLEVA	{"email": "i_zhuravleva1973@postgrespro.ru", "phone": "+70766352520"}
0005435611896	0FBFF3	2669 960965	VLADIMIR ZHUKOV	{"email": "vladimir_zhukov_1981@postgrespro.ru", "phone": "+70095640962"}
0005435611897	B52AA8	4359 579889	SVETLANA SEMENOVA	{"email": "semenova_svetlana1971@postgrespro.ru", "phone": "+70484534087"}
0005435611898	B52AA8	3195 115676	NIKOLAY NIKOLAEV	{"phone": "+70847694450"}
0005435611899	240A45	4712 064992	VALERIYA VOLKOVA	{"phone": "+70263630286"}
0005435611900	240A45	5377 507553	KRISTINA ALEKSEEVA	{"phone": "+70527231666"}
0005435611901	FD68FC	6328 151299	TATYANA ZAYCEVA	{"email": "t.zayceva_081967@postgrespro.ru", "phone": "+70427084583"}
0005435611902	FD68FC	9672 090005	YANA EGOROVA	{"email": "yanaegorova121966@postgrespro.ru", "phone": "+70485944549"}
0005435611903	75621B	0417 602803	YURIY PETROV	{"email": "petrov-y051979@postgrespro.ru", "phone": "+70521079461"}
0005435611904	3A0B80	4104 247375	ANDREY KULIKOV	{"email": "kulikov_a.20021978@postgrespro.ru", "phone": "+70125518758"}
0005435611905	3A0B80	0989 612554	LYUBOV KOZLOVA	{"email": "kozlovalyubov.08071966@postgrespro.ru", "phone": "+70813407496"}
0005435611906	27CFF2	5011 252895	TAMARA ZOTOVA	{"email": "zotova.tamara_1976@postgrespro.ru", "phone": "+70371528015"}
0005435611907	79A0A6	9367 549413	SERGEY IVANOV	{"phone": "+70588497461"}
0005435611908	1052AA	4528 500212	VIKTORIYA SOROKINA	{"email": "viktoriya.sorokina_19121976@postgrespro.ru", "phone": "+70162405488"}
0005435611909	0F7E02	4291 194742	VALENTINA NAZAROVA	{"email": "nazarova-valentina_12081964@postgrespro.ru", "phone": "+70222771493"}
0005435611910	0503AA	1263 643276	SERGEY PETROV	{"phone": "+70199979663"}
0005435611911	577CC8	6827 581543	LIDIYA ALEKSANDROVA	{"email": "l.aleksandrova.24121975@postgrespro.ru", "phone": "+70509035273"}
0005435611912	43A2C3	1079 704563	MATVEY DENISOV	{"email": "denisov_matvey.101971@postgrespro.ru", "phone": "+70106700930"}
0005435611913	E0AF0D	9784 685888	VALERIY ALEKSANDROV	{"email": "valeriy_aleksandrov.091968@postgrespro.ru", "phone": "+70008892485"}
0005435611914	FE667C	7630 401127	ALENA VASILEVA	{"phone": "+70891439166"}
0005435611915	5951D2	6755 080070	VENERA KOZLOVA	{"email": "kozlova-venera.101974@postgrespro.ru", "phone": "+70100450969"}
0005435611916	684612	9314 057551	VLADIMIR SEMENOV	{"phone": "+70678181262"}
0005435611917	684612	5046 950884	VLADIMIR OSIPOV	{"email": "osipov-vladimir061962@postgrespro.ru", "phone": "+70905454102"}
0005435611918	C06E6A	2277 072289	EKATERINA SIDOROVA	{"phone": "+70252682605"}
0005435611919	03CFB6	5290 425678	ARTEM MEDVEDEV	{"phone": "+70565917881"}
0005435611920	97FC56	9642 484558	MIKHAIL GUSEV	{"phone": "+70110213960"}
0005435611921	97FC56	0457 715059	VLADIMIR KOZLOV	{"phone": "+70480073734"}
0005435611922	441FBC	8301 802286	OKSANA SOLOVEVA	{"email": "oksana.soloveva021968@postgrespro.ru", "phone": "+70278065981"}
0005435611923	81020B	9564 448654	NATALYA NIKITINA	{"email": "n_nikitina15081976@postgrespro.ru", "phone": "+70510851910"}
0005435611924	81020B	0767 719942	ILDAR ABRAMOV	{"email": "abramovi.16121966@postgrespro.ru", "phone": "+70883189231"}
0005435611925	CB4823	6143 808771	ANTONINA NAZAROVA	{"phone": "+70857377366"}
0005435611926	CB4823	3479 424705	VERA AFANASEVA	{"phone": "+70772239790"}
0005435611927	CB4823	9354 565411	ALEKSEY TIMOFEEV	{"phone": "+70700038921"}
0005435611928	4E9793	7479 735231	VADIM KUZNECOV	{"email": "vadim-kuznecov-1965@postgrespro.ru", "phone": "+70547390573"}
0005435611929	9CB0E4	3406 251087	PETR GAVRILOV	{"email": "petr_gavrilov011976@postgrespro.ru", "phone": "+70437504273"}
0005435611930	9CB0E4	8933 079184	VERA POPOVA	{"email": "vpopova011973@postgrespro.ru", "phone": "+70020107105"}
0005435611931	9CB0E4	9307 788062	SVETLANA NESTEROVA	{"phone": "+70441379363"}
0005435611932	08AB07	4143 116831	ANASTASIYA AKIMOVA	{"phone": "+70722260715"}
0005435611933	08AB07	6688 095378	ARTEM AFANASEV	{"email": "a_afanasev_111953@postgrespro.ru", "phone": "+70527124545"}
0005435611934	DCCADF	0195 359244	ANDREY KUZNECOV	{"email": "kuznecov.andrey.18091972@postgrespro.ru", "phone": "+70174020958"}
0005435611935	32FBA6	7516 672497	SERGEY GRIGOREV	{"phone": "+70722876983"}
0005435611936	3FA87A	2673 436497	GALINA AKIMOVA	{"phone": "+70035831764"}
0005435611937	911499	8775 123761	ALEKSEY KRASNOV	{"email": "krasnov-aleksey-1967@postgrespro.ru", "phone": "+70249101805"}
0005435611938	B2579B	8912 425685	KLAVDIYA ALEKSANDROVA	{"email": "aleksandrova-klavdiya-1987@postgrespro.ru", "phone": "+70325660997"}
0005435611939	49D5EA	1668 190681	MARIYA LOGINOVA	{"phone": "+70934801432"}
0005435611940	59CAE1	8336 427711	NINA LOGINOVA	{"email": "nina-loginova1982@postgrespro.ru", "phone": "+70418287372"}
0005435611941	DBB9C8	0584 374426	ILYA BELOV	{"email": "ilyabelov-061963@postgrespro.ru", "phone": "+70332244696"}
0005435611942	AE7A79	9175 206419	ANASTASIYA MIRONOVA	{"email": "mironovaanastasiya-1963@postgrespro.ru", "phone": "+70242322575"}
0005435611943	AE7A79	5522 669472	ANNA KOMAROVA	{"phone": "+70310655953"}
0005435611944	982C81	6570 547886	ELENA GORBUNOVA	{"phone": "+70631705334"}
0005435611945	A4B606	8083 971132	VERA EFIMOVA	{"phone": "+70950620084"}
0005435611946	9375AB	0322 567135	ELENA IVANOVA	{"phone": "+70011984890"}
0005435611947	0AF24B	6411 251659	IVAN ALEKSEEV	{"phone": "+70956385401"}
0005435611948	9D733C	6847 142358	ANDREY SMIRNOV	{"phone": "+70250104834"}
0005435611949	9D733C	2149 479298	ZOYA SAVELEVA	{"phone": "+70324219989"}
0005435611950	1A5774	2552 922190	ALEKSANDRA SERGEEVA	{"email": "sergeeva-a25011972@postgrespro.ru", "phone": "+70609863254"}
0005435611951	BC8F3B	9304 587769	DENIS ZAKHAROV	{"email": "denis-zakharov-28121974@postgrespro.ru", "phone": "+70254610092"}
0005435611952	BC8F3B	3797 313438	VALENTINA GUSEVA	{"phone": "+70053494702"}
0005435611953	BC8F3B	7897 150040	NIKOLAY IVANOV	{"email": "n-ivanov-14071979@postgrespro.ru", "phone": "+70165707269"}
0005435611954	52126C	3084 207143	SVETLANA KUZNECOVA	{"phone": "+70827499844"}
0005435611955	76CB6F	3276 968790	NINA SMIRNOVA	{"email": "nina.smirnova.1974@postgrespro.ru", "phone": "+70176174559"}
0005435611956	3C9A07	3343 689669	MARAT BONDARENKO	{"email": "m_bondarenko12041971@postgrespro.ru", "phone": "+70253538436"}
0005435611957	0CEE07	2542 906312	MATVEY FROLOV	{"email": "frolovm-061962@postgrespro.ru", "phone": "+70572410084"}
0005435611958	C60FAB	5179 323356	NATALYA KARPOVA	{"phone": "+70808213263"}
0005435611959	C60FAB	4480 779006	VERA VASILEVA	{"email": "vasilevavera-1964@postgrespro.ru", "phone": "+70539384353"}
0005435611960	549455	5665 674150	VLADIMIR SMIRNOV	{"phone": "+70551868704"}
0005435611961	549455	7304 720755	ANATOLIY YAKOVLEV	{"phone": "+70858768414"}
0005435611962	883977	9344 962893	OLGA NAZAROVA	{"email": "o.nazarova-1971@postgrespro.ru", "phone": "+70180759428"}
0005435611963	883977	1802 175368	ANATOLIY MAKAROV	{"phone": "+70371821323"}
0005435611964	D74C6E	9163 068494	MARINA SMIRNOVA	{"phone": "+70870082977"}
0005435611965	472326	8735 678413	VALERIY KISELEV	{"phone": "+70422110999"}
0005435611966	1D9D6E	6945 856018	ALEKSANDR SIDOROV	{"email": "sidorova-041973@postgrespro.ru", "phone": "+70673534490"}
0005435611967	1D9D6E	9315 628352	GENNADIY SMIRNOV	{"phone": "+70686588875"}
0005435611968	7917A9	9738 334800	NADEZHDA ILINA	{"phone": "+70053050596"}
0005435611969	2840E0	3644 069798	SERGEY KUZMIN	{"email": "sergeykuzmin10101978@postgrespro.ru", "phone": "+70380517839"}
0005435611970	19DD39	6620 705726	TATYANA CHERNOVA	{"phone": "+70347293900"}
0005435611971	1A57D2	4427 853934	DARYA ALEKSEEVA	{"phone": "+70168280562"}
0005435611972	75B8E6	9559 739320	VIKTORIYA YAKOVLEVA	{"phone": "+70989488034"}
0005435611973	D9FC88	2803 800352	ALEKSANDR ROMANOV	{"phone": "+70626491843"}
0005435611974	D9FC88	1651 580742	MIKHAIL KRASNOV	{"email": "krasnovm_111961@postgrespro.ru", "phone": "+70368903500"}
0005435611975	3C8D48	2575 394784	YURIY ABRAMOV	{"email": "abramov_yuriy29011976@postgrespro.ru", "phone": "+70823678517"}
0005435611976	5C97C5	5575 223052	VLADISLAV IVANOV	{"email": "ivanov-vladislav-101982@postgrespro.ru", "phone": "+70833362913"}
0005435611977	4C1FC6	0757 185091	VLADIMIR SMIRNOV	{"email": "vladimir.smirnov.031974@postgrespro.ru", "phone": "+70199993541"}
0005435611978	01AB9A	8368 194946	ELDAR SOROKIN	{"email": "sorokineldar.24061966@postgrespro.ru", "phone": "+70638552077"}
0005435611979	297AC0	3868 508363	ARTUR TARASOV	{"phone": "+70432663909"}
0005435611980	0BAE36	0582 136436	OLGA FROLOVA	{"email": "frolovaolga21121975@postgrespro.ru", "phone": "+70479312913"}
0005435611981	F6F4CF	7721 229530	VLADIMIR ZHURAVLEV	{"email": "vzhuravlev-1980@postgrespro.ru", "phone": "+70470168893"}
0005435611982	F6F4CF	8448 581247	ANTON MOROZOV	{"email": "anton_morozov.1980@postgrespro.ru", "phone": "+70632167833"}
0005435611983	3A15F8	7283 714596	KONSTANTIN FOMIN	{"phone": "+70544991272"}
0005435611984	7BC746	5197 090764	VASILIY KRASNOV	{"email": "krasnov-vasiliy.12101970@postgrespro.ru", "phone": "+70249023718"}
0005435611985	2E5ACB	8613 005788	ELIZAVETA ZAKHAROVA	{"email": "e-zakharova.20121970@postgrespro.ru", "phone": "+70122318112"}
0005435611986	2E5ACB	5110 231558	SVETLANA ALEKSEEVA	{"email": "alekseevasvetlana_07111972@postgrespro.ru", "phone": "+70719640825"}
0005435611987	155432	6621 781549	NADEZHDA SERGEEVA	{"email": "sergeevanadezhda-1967@postgrespro.ru", "phone": "+70402834427"}
0005435611988	155432	8287 575039	ILDAR MIKHAYLOV	{"phone": "+70525565834"}
0005435611989	76B549	9330 585619	LYUBOV KULIKOVA	{"email": "lyubovkulikova011960@postgrespro.ru", "phone": "+70419315072"}
0005435611990	76B549	8254 823443	SOFIYA KUZNECOVA	{"phone": "+70264981305"}
0005435611991	E51731	2579 065814	DARYA POPOVA	{"email": "d.popova.26021974@postgrespro.ru", "phone": "+70656070186"}
0005435611992	37770D	8959 256012	ELENA KRASNOVA	{"email": "e.krasnova_081975@postgrespro.ru", "phone": "+70828415000"}
0005435611993	C0CFB7	7621 898361	MARIYA ROMANOVA	{"email": "romanova.m_01111972@postgrespro.ru", "phone": "+70948670920"}
0005435611994	C0CFB7	1235 311566	IRINA DMITRIEVA	{"email": "irina-dmitrieva-071977@postgrespro.ru", "phone": "+70960496167"}
0005435611995	6D743D	4185 400967	VLADISLAV BONDARENKO	{"email": "bondarenko.vladislav1973@postgrespro.ru", "phone": "+70041964119"}
0005435611996	6D743D	5784 111452	VERA DENISOVA	{"email": "denisovav-061975@postgrespro.ru", "phone": "+70563061545"}
0005435611997	6D743D	9921 448824	ANNA SOROKINA	{"phone": "+70349384523"}
0005435611998	4E23FF	3367 459378	DMITRIY EGOROV	{"phone": "+70095989855"}
0005435611999	ABCC0F	9211 128747	VLADIMIR ZAYCEV	{"email": "zaycev-v1978@postgrespro.ru", "phone": "+70577179418"}
0005435612001	8E453C	5077 178199	ILYA EGOROV	{"email": "iegorov-031977@postgrespro.ru", "phone": "+70257693517"}
0005435612002	4A8616	9759 221630	GALINA DANILOVA	{"phone": "+70795180363"}
0005435612003	4A8616	6433 866468	ZLATA FILIPPOVA	{"phone": "+70077570092"}
0005435612004	ED1EE4	3460 810197	LIDIYA SMIRNOVA	{"phone": "+70819288970"}
0005435612005	1B4EF6	2912 412201	SERGEY KARPOV	{"email": "sergeykarpov-15051978@postgrespro.ru", "phone": "+70398052537"}
0005435612062	232F9C	2080 190325	TATYANA IVANOVA	{"phone": "+70200691379"}
0005435612006	1B4EF6	7402 810853	NURLAN MIRONOV	{"email": "n-mironov091983@postgrespro.ru", "phone": "+70614138131"}
0005435612007	AFE8F9	0789 068933	VLADIMIR GUSEV	{"email": "vgusev-081972@postgrespro.ru", "phone": "+70771907593"}
0005435612008	BD6B07	6269 497592	ELENA LEBEDEVA	{"email": "lebedevaelena-25101962@postgrespro.ru", "phone": "+70754990986"}
0005435612009	ACDB6D	9012 624302	ARINA KUZMINA	{"email": "a-kuzmina-051977@postgrespro.ru", "phone": "+70548506716"}
0005435612010	ACDB6D	5883 481125	NIKOLAY BARANOV	{"email": "nikolay-baranov.121973@postgrespro.ru", "phone": "+70854286430"}
0005435612011	F3AFFC	7071 012941	VLADIMIR YAKOVLEV	{"phone": "+70801876337"}
0005435612012	58AB69	5888 996732	SERGEY KUZMIN	{"email": "kuzmin_s-121983@postgrespro.ru", "phone": "+70167333775"}
0005435612013	DB7156	0412 295020	TATYANA TROFIMOVA	{"phone": "+70421495233"}
0005435612014	DB7156	2143 607366	ELIZAVETA POTAPOVA	{"email": "potapovaelizaveta_1970@postgrespro.ru", "phone": "+70925539962"}
0005435612015	DEADD7	4117 249105	KIRILL ZAYCEV	{"email": "zaycevkirill_031973@postgrespro.ru", "phone": "+70195411637"}
0005435612016	DEADD7	6533 393416	IRINA ANISIMOVA	{"email": "i-anisimova15021970@postgrespro.ru", "phone": "+70175846438"}
0005435612017	5936FB	0598 448831	EVGENIY STEPANOV	{"email": "stepanov-evgeniy1984@postgrespro.ru", "phone": "+70770356108"}
0005435612018	5936FB	2064 354204	VIKTOR SAVELEV	{"phone": "+70056931531"}
0005435612019	8DDA5B	0857 249383	ZINAIDA PAVLOVA	{"phone": "+70721556798"}
0005435612020	1DFCFA	8908 668356	VLADIMIR MELNIKOV	{"email": "vladimir.melnikov-1980@postgrespro.ru", "phone": "+70413065031"}
0005435612021	1A64D2	5931 823793	NIKOLAY NAZAROV	{"email": "nnazarov.1963@postgrespro.ru", "phone": "+70439983132"}
0005435612022	4FBC5E	3597 186349	ALEKSEY SCHERBAKOV	{"email": "scherbakov_aleksey-111971@postgrespro.ru", "phone": "+70291386847"}
0005435612023	75E89C	5472 729843	DENIS NOVIKOV	{"phone": "+70136927554"}
0005435612024	75E89C	9677 679177	FAINA BORISOVA	{"email": "f.borisova031969@postgrespro.ru", "phone": "+70850420960"}
0005435612025	F869A7	1455 534067	VLADIMIR NAUMOV	{"phone": "+70842909890"}
0005435612026	7ADF40	7237 650569	MARIYA SMIRNOVA	{"email": "smirnova-mariya091967@postgrespro.ru", "phone": "+70976295176"}
0005435612027	7ADF40	0861 358560	OLGA SIDOROVA	{"email": "sidorova-olga1960@postgrespro.ru", "phone": "+70529811870"}
0005435612028	A0F4E8	8514 867948	EKATERINA EGOROVA	{"email": "ekaterina.egorova.071961@postgrespro.ru", "phone": "+70252833918"}
0005435612029	F29671	1982 713932	NINA VLASOVA	{"email": "vlasova-nina_091967@postgrespro.ru", "phone": "+70463738051"}
0005435612030	D59FA3	9971 874121	EKATERINA KONOVALOVA	{"phone": "+70188587095"}
0005435612031	0D5681	9059 385301	SERGEY DENISOV	{"phone": "+70011767194"}
0005435612032	0D5681	7804 862741	LYUDMILA SCHERBAKOVA	{"email": "l-scherbakova-30051974@postgrespro.ru", "phone": "+70483626949"}
0005435612033	019CB9	1443 866239	SERGEY IVANOV	{"phone": "+70968633053"}
0005435612034	019CB9	4041 541913	VLADIMIR SOLOVEV	{"phone": "+70762391616"}
0005435612035	783ACA	5928 954085	MARIYA KUZNECOVA	{"email": "kuznecova-m-041979@postgrespro.ru", "phone": "+70554623999"}
0005435612036	A663D6	0619 826337	VALENTINA MATVEEVA	{"phone": "+70782353741"}
0005435612037	A663D6	6051 589986	ANTONINA TROFIMOVA	{"email": "trofimova-antonina_18101966@postgrespro.ru", "phone": "+70622389315"}
0005435612038	05C5FA	7323 898014	PAVEL KUZNECOV	{"email": "p-kuznecov-02111984@postgrespro.ru", "phone": "+70665946901"}
0005435612039	05C5FA	3097 679356	MAKSIM VOLKOV	{"phone": "+70889691023"}
0005435612040	D726BD	2882 254652	MAKSIM FROLOV	{"email": "frolovm-06031968@postgrespro.ru", "phone": "+70328516296"}
0005435612041	8AE294	4069 794223	MAKSIM KULIKOV	{"phone": "+70147096278"}
0005435612042	BD4171	2799 425917	VERONIKA POPOVA	{"email": "veronikapopova-021969@postgrespro.ru", "phone": "+70789496127"}
0005435612043	F57C79	7457 760526	DENIS DMITRIEV	{"phone": "+70449688463"}
0005435612044	7F6FE1	7308 953498	EVGENIY MAKSIMOV	{"email": "maksimov-evgeniy25011980@postgrespro.ru", "phone": "+70595716501"}
0005435612045	91B1B9	0691 491217	VALENTINA ANISIMOVA	{"phone": "+70741923918"}
0005435612046	91B1B9	8055 372250	TIMOFEY SHEVCHENKO	{"email": "t-shevchenko_1966@postgrespro.ru", "phone": "+70636981472"}
0005435612047	094E7E	2539 187981	ANASTASIYA TARASOVA	{"phone": "+70995108565"}
0005435612048	094E7E	6759 528971	ALEKSEY KONOVALOV	{"phone": "+70851672757"}
0005435612049	C8765D	0716 382135	DMITRIY ZAYCEV	{"email": "zaycev-d081962@postgrespro.ru", "phone": "+70213724715"}
0005435612050	3E5157	0619 214201	VALENTIN KUZNECOV	{"phone": "+70458569860"}
0005435612051	A698EE	7546 843048	ALEKSANDR MIKHAYLOV	{"phone": "+70938207571"}
0005435612052	917260	3876 359022	MAKSIM DENISOV	{"phone": "+70008494950"}
0005435612053	996CBB	1856 303071	GALINA ABRAMOVA	{"email": "galina_abramova091965@postgrespro.ru", "phone": "+70240743669"}
0005435612054	3535C3	2782 714356	SVETLANA KARPOVA	{"email": "karpova.svetlana1965@postgrespro.ru", "phone": "+70899889587"}
0005435612055	6B5307	5479 814127	MARGARITA OSIPOVA	{"email": "margaritaosipova1974@postgrespro.ru", "phone": "+70623464555"}
0005435612056	24BD43	8251 881855	LYUBOV ZAKHAROVA	{"phone": "+70602419819"}
0005435612057	A2A1EB	2629 024313	VLADIMIR KOROLEV	{"email": "korolev-vladimir.031982@postgrespro.ru", "phone": "+70550633794"}
0005435612058	94ED75	7841 569794	TIMUR DENISOV	{"email": "t_denisov071970@postgrespro.ru", "phone": "+70734330648"}
0005435612059	FED182	7892 181590	YANA ANDREEVA	{"email": "y_andreeva1973@postgrespro.ru", "phone": "+70483618199"}
0005435612060	286F26	6716 265216	NIKITA RODIONOV	{"email": "rodionov.n_031978@postgrespro.ru", "phone": "+70229852923"}
0005435612063	232F9C	8522 019964	NIKOLAY SAVELEV	{"email": "n_savelev-10011971@postgrespro.ru", "phone": "+70443558857"}
0005435612064	4CE4EE	8880 985080	ARTEM MOROZOV	{"phone": "+70988420305"}
0005435612065	A7073F	5821 426650	GEORGIY TARASOV	{"email": "tarasovg041967@postgrespro.ru", "phone": "+70615489314"}
0005435612066	85BC79	3352 061105	VLADIMIR KARPOV	{"phone": "+70311919848"}
0005435612067	85BC79	2175 964825	ELENA ERMAKOVA	{"email": "ermakova.elena_061978@postgrespro.ru", "phone": "+70087948378"}
0005435612068	942AB0	1529 355490	ROMAN MIKHAYLOV	{"email": "mikhaylov_r-26041976@postgrespro.ru", "phone": "+70770179721"}
0005435612069	942AB0	3226 022689	ALEKSEY ZAYCEV	{"email": "azaycev-111975@postgrespro.ru", "phone": "+70807861194"}
0005435612070	942AB0	4430 499392	VITALIY YAKOVLEV	{"email": "yakovlev-vitaliy1967@postgrespro.ru", "phone": "+70349961861"}
0005435612071	C5DAEE	1349 737536	EVGENIY TIKHONOV	{"email": "tikhonov_evgeniy29101969@postgrespro.ru", "phone": "+70413443975"}
0005435612072	100B7F	7889 648969	EVGENIY EGOROV	{"email": "egorov-evgeniy.28091969@postgrespro.ru", "phone": "+70208935327"}
0005435612073	100B7F	3752 166589	ARTEM NAZAROV	{"email": "nazarov_a_04041970@postgrespro.ru", "phone": "+70171330428"}
0005435612074	100B7F	4419 907027	EKATERINA SIDOROVA	{"phone": "+70786431384"}
0005435612075	FD6E0E	3114 017097	IGOR NIKITIN	{"phone": "+70204313658"}
0005435612076	1EE90E	3176 086175	KIRILL MIRONOV	{"email": "kirill-mironov.071975@postgrespro.ru", "phone": "+70160497460"}
0005435612077	6EB816	2233 493047	NIKOLAY POPOV	{"email": "popov_nikolay_17061972@postgrespro.ru", "phone": "+70752065943"}
0005435612078	6EB816	0762 591600	MIKHAIL FEDOTOV	{"phone": "+70276127022"}
0005435612079	A6380F	6312 745917	EKATERINA NOVIKOVA	{"phone": "+70806882414"}
0005435612080	A6380F	6924 028471	VLADIMIR IVANOV	{"email": "ivanov.vladimir_021982@postgrespro.ru", "phone": "+70075935535"}
0005435612081	3DB3D8	5963 921471	ALEKSEY FOMIN	{"email": "fomin-aleksey031978@postgrespro.ru", "phone": "+70425556242"}
0005435612082	D5CC19	7073 489322	TATYANA NIKITINA	{"phone": "+70756555242"}
0005435612083	6E772F	5014 160959	EKATERINA VOLKOVA	{"email": "volkovaekaterina-111972@postgrespro.ru", "phone": "+70972069836"}
0005435612084	28B698	4858 395809	VLADIMIR PETROV	{"phone": "+70237106155"}
0005435612085	AD62FF	7588 775425	OLGA MIKHAYLOVA	{"email": "olgamikhaylova_20061983@postgrespro.ru", "phone": "+70392437230"}
0005435612086	50ECB0	9968 485793	RUSLAN MATVEEV	{"phone": "+70653884713"}
0005435612087	949015	3977 908652	ANNA NAZAROVA	{"email": "anazarova-1963@postgrespro.ru", "phone": "+70268436028"}
0005435612088	949015	4816 498775	VIKTOR IVANOV	{"phone": "+70364955271"}
0005435612089	1EEFA4	6974 654756	IGOR VASILEV	{"phone": "+70255810077"}
0005435612090	A1F344	9661 583794	TATYANA STEPANOVA	{"email": "t-stepanova_03031969@postgrespro.ru", "phone": "+70357085417"}
0005435612091	A1F344	0186 997592	NIKITA SMIRNOV	{"phone": "+70264069586"}
0005435612092	B945D9	2055 949048	LYUDMILA PETROVA	{"phone": "+70795035349"}
0005435612093	B945D9	7890 271145	OLGA MAKAROVA	{"email": "olga.makarova-031971@postgrespro.ru", "phone": "+70546675780"}
0005435612094	1DAFDC	6032 633787	MAKSIM TIKHONOV	{"email": "tikhonov-m1981@postgrespro.ru", "phone": "+70332301391"}
0005435612095	522ED2	0918 355115	ALEKSANDR YAKOVLEV	{"email": "yakovlev_aleksandr07111982@postgrespro.ru", "phone": "+70564514818"}
0005435612096	B9963E	1577 932219	EVGENIY KUZNECOV	{"phone": "+70328645429"}
0005435612097	B9963E	7511 977149	DENIS KOROLEV	{"phone": "+70290137138"}
0005435612098	B9963E	0692 071836	BORIS VASILEV	{"phone": "+70448168179"}
0005435612099	EF2583	3132 635203	LYUDMILA VOROBEVA	{"email": "vorobeval27121976@postgrespro.ru", "phone": "+70137245355"}
0005435612100	1F67A1	1148 276533	SERGEY VASILEV	{"email": "sergey.vasilev.18111970@postgrespro.ru", "phone": "+70372559238"}
0005435612101	1F67A1	5134 578949	EVGENIY KUZNECOV	{"phone": "+70632956177"}
0005435612102	F13D91	6729 851509	NIKITA ANTONOV	{"phone": "+70735844581"}
0005435612103	F93CA1	2890 717745	VALERIY ZHUKOV	{"email": "v-zhukov-03011964@postgrespro.ru", "phone": "+70482143120"}
0005435612104	F93CA1	6531 838502	YURIY NAZAROV	{"email": "nazarov_yuriy22111968@postgrespro.ru", "phone": "+70423773387"}
0005435612105	AE87F8	2642 131026	DMITRIY MOISEEV	{"email": "moiseev-d121977@postgrespro.ru", "phone": "+70840867646"}
0005435612106	BDEC04	8161 477025	IRINA MAKSIMOVA	{"email": "maksimova_i-12041983@postgrespro.ru", "phone": "+70820883367"}
0005435612107	3E83D7	6846 154733	LYUDMILA SIDOROVA	{"email": "l-sidorova.1973@postgrespro.ru", "phone": "+70358062351"}
0005435612108	3E83D7	4028 093861	MARIYA POPOVA	{"email": "m_popova1969@postgrespro.ru", "phone": "+70163932800"}
0005435612109	B14F32	7709 458383	POLINA KUZNECOVA	{"email": "kuznecova_polina_1977@postgrespro.ru", "phone": "+70774985176"}
0005435612110	B14F32	5764 037649	VLADIMIR FOMIN	{"phone": "+70639408721"}
0005435612111	1FCCC4	1520 473303	ANGELINA TROFIMOVA	{"phone": "+70502957209"}
0005435612112	1FCCC4	9920 016964	VYACHESLAV ZAYCEV	{"email": "zaycev-vyacheslav_051961@postgrespro.ru", "phone": "+70405871550"}
0005435612113	7878E0	9699 532304	GALINA NIKITINA	{"phone": "+70381479876"}
0005435612114	7878E0	0737 381763	ANDREY SOKOLOV	{"phone": "+70389772480"}
0005435612115	AEA114	0328 039764	VALERIYA DAVYDOVA	{"email": "v_davydova_1979@postgrespro.ru", "phone": "+70443766735"}
0005435612116	AEA114	6968 267961	SERGEY KRASNOV	{"phone": "+70293352974"}
0005435612117	4B25D9	0632 586711	RINAT IVANOV	{"phone": "+70178196275"}
0005435612118	4B25D9	7815 202070	MARIYA MALYSHEVA	{"email": "mariya_malysheva101966@postgrespro.ru", "phone": "+70062476798"}
0005435612119	4B25D9	0097 226121	ANNA SMIRNOVA	{"phone": "+70465919052"}
0005435612120	B4FB1B	1733 085572	IVAN MIKHAYLOV	{"email": "mikhaylov-ivan21111980@postgrespro.ru", "phone": "+70017238721"}
0005435612121	B4FB1B	3282 748636	ANDREY PAVLOV	{"email": "pavlov.a28021979@postgrespro.ru", "phone": "+70006308768"}
0005435612122	01695C	8153 965304	ANASTASIYA FROLOVA	{"phone": "+70175769867"}
0005435612123	01695C	5376 032026	YURIY ALEKSEEV	{"phone": "+70403001662"}
0005435612124	899887	1633 159378	GLEB DENISOV	{"email": "gdenisov_1973@postgrespro.ru", "phone": "+70117950665"}
0005435612125	899887	1177 528560	ANDREY RODIONOV	{"email": "andreyrodionov-07041976@postgrespro.ru", "phone": "+70700663867"}
0005435612126	66DFF4	3178 690757	ELINA NAZAROVA	{"email": "nazarova.e_12031970@postgrespro.ru", "phone": "+70521476264"}
0005435612127	6BB160	1504 811269	MIKHAIL BARANOV	{"email": "m_baranov_091978@postgrespro.ru", "phone": "+70691497349"}
0005435612128	6BB160	2105 976222	IRINA ARKHIPOVA	{"email": "irinaarkhipova_121978@postgrespro.ru", "phone": "+70651827755"}
0005435612129	AB49D0	7227 557271	RAISA CHERNOVA	{"phone": "+70408944798"}
0005435612130	6B7CA6	8476 964304	MARIANNA NIKOLAEVA	{"email": "nikolaeva_marianna-091970@postgrespro.ru", "phone": "+70825787895"}
0005435612131	89DA86	2012 634547	VALENTINA OVCHINNIKOVA	{"phone": "+70313398567"}
0005435612132	AD0156	8580 312306	EKATERINA SOKOLOVA	{"phone": "+70148980260"}
0005435612133	AD0156	7280 136908	ANNA ZOTOVA	{"email": "a.zotova-1975@postgrespro.ru", "phone": "+70714296590"}
0005435612134	9C26FC	8084 473076	NINA ANDREEVA	{"email": "andreevanina_011982@postgrespro.ru", "phone": "+70032363471"}
0005435612135	28DED4	8853 900764	GUZEL FILIPPOVA	{"phone": "+70177442913"}
0005435612136	28DED4	1809 962725	GALINA YUDINA	{"phone": "+70468862846"}
0005435612137	28DED4	0877 949430	VLADIMIR MELNIKOV	{"email": "vladimir_melnikov071971@postgrespro.ru", "phone": "+70311635229"}
0005435612138	DBBD90	3827 446195	SVETLANA TIMOFEEVA	{"email": "timofeevas.091981@postgrespro.ru", "phone": "+70131422223"}
0005435612139	DBBD90	4800 436470	ANDREY KULIKOV	{"phone": "+70349051159"}
0005435612140	7EB684	8008 941452	SERGEY ORLOV	{"email": "s-orlov-13081964@postgrespro.ru", "phone": "+70781110056"}
0005435612141	38ECCC	7053 859020	ELENA KOROLEVA	{"email": "e.koroleva091974@postgrespro.ru", "phone": "+70952438618"}
0005435612142	38ECCC	8523 270189	NURLAN POPOV	{"email": "n_popov061975@postgrespro.ru", "phone": "+70028018647"}
0005435612143	EE6015	4702 115012	EVGENIYA KARPOVA	{"email": "karpova_e06031965@postgrespro.ru", "phone": "+70401408955"}
0005435612144	EF1C5F	9717 280922	SERGEY MOROZOV	{"email": "sergey_morozov_121974@postgrespro.ru", "phone": "+70537367745"}
0005435612145	E21A43	0348 343211	SERGEY VASILEV	{"phone": "+70088844184"}
0005435612146	E21A43	0504 748877	MARIYA KOLESNIKOVA	{"email": "kolesnikova_m1974@postgrespro.ru", "phone": "+70043287906"}
0005435612147	0719D9	0599 699004	NADEZHDA ROMANOVA	{"phone": "+70721824402"}
0005435612148	E0221B	5373 712845	ANATOLIY SOKOLOV	{"email": "sokolov.anatoliy_06061977@postgrespro.ru", "phone": "+70967204080"}
0005435612149	B32FE9	3199 683284	ULYANA ALEKSANDROVA	{"phone": "+70982344369"}
0005435612150	5BC328	9183 718622	NATALIYA SOKOLOVA	{"email": "n-sokolova_1960@postgrespro.ru", "phone": "+70809530471"}
0005435612151	2A7F26	8627 176354	VALERIY MAKSIMOV	{"phone": "+70919943966"}
0005435612152	2A7F26	8194 909976	ANDREY BORISOV	{"email": "andrey.borisov.121975@postgrespro.ru", "phone": "+70318349498"}
0005435612153	194439	2137 735783	NADEZHDA EGOROVA	{"email": "egorova_nadezhda_011968@postgrespro.ru", "phone": "+70442624780"}
0005435612154	D7ACDF	9525 647031	LYUBOV POLYAKOVA	{"email": "polyakova_l_081982@postgrespro.ru", "phone": "+70826756819"}
0005435612155	D7ACDF	6793 765354	SERGEY ANTONOV	{"phone": "+70552673898"}
0005435612156	60BFFA	1021 881137	MARINA MOROZOVA	{"email": "morozova-marina-01021967@postgrespro.ru", "phone": "+70764872097"}
0005435612157	62434A	2489 768432	ELENA GORBUNOVA	{"phone": "+70356371181"}
0005435612158	9F1160	5292 155693	VIKTOR KRASNOV	{"email": "viktorkrasnov.06021969@postgrespro.ru", "phone": "+70921212449"}
0005435612159	D5D7F7	2894 425591	NIKITA SIDOROV	{"email": "nikitasidorov-18031972@postgrespro.ru", "phone": "+70055894297"}
0005435612160	2972FA	2898 496424	OLGA KISELEVA	{"email": "kiselevao.051971@postgrespro.ru", "phone": "+70561002329"}
0005435612161	625D3E	9843 192401	IVAN GERASIMOV	{"email": "gerasimovi_081965@postgrespro.ru", "phone": "+70041350341"}
0005435612162	625D3E	7579 688591	SVETLANA SERGEEVA	{"email": "sergeeva_s-091976@postgrespro.ru", "phone": "+70392631364"}
0005435612163	3A799A	5346 476072	TATYANA KULIKOVA	{"phone": "+70490410341"}
0005435612164	3A799A	3551 600366	NIKITA ZAYCEV	{"email": "zaycev_n_23091971@postgrespro.ru", "phone": "+70577890893"}
0005435612165	2F0CC0	8266 254202	ZARINA ZAKHAROVA	{"email": "z.zakharova_041970@postgrespro.ru", "phone": "+70964653600"}
0005435612166	25727B	3944 112389	EKATERINA SOKOLOVA	{"phone": "+70750645783"}
0005435612167	0EF7F6	8957 818213	DMITRIY PETROV	{"email": "petrov.d.041967@postgrespro.ru", "phone": "+70351423038"}
0005435612168	957AAD	9510 238020	ANDREY NOVIKOV	{"email": "novikov.a_15111980@postgrespro.ru", "phone": "+70013113930"}
0005435612169	957AAD	6073 024889	RAISA DMITRIEVA	{"email": "raisa-dmitrieva.1967@postgrespro.ru", "phone": "+70125489597"}
0005435612170	0738BB	3502 642756	TATYANA NIKIFOROVA	{"phone": "+70699949137"}
0005435612171	0738BB	9829 568822	ZLATA NAUMOVA	{"email": "naumova_zlata_1982@postgrespro.ru", "phone": "+70335553433"}
0005435612172	64A069	6598 963959	OLGA BARANOVA	{"phone": "+70820206255"}
0005435612173	F78CE4	7974 780192	EKATERINA DMITRIEVA	{"email": "dmitrievaekaterina.1981@postgrespro.ru", "phone": "+70226478258"}
0005435612174	F78CE4	1074 347334	ALEKSANDR GUSEV	{"email": "gusev.a_021957@postgrespro.ru", "phone": "+70321508776"}
0005435612175	5BC86D	7658 801747	RAMIL IVANOV	{"email": "ivanov.ramil.1965@postgrespro.ru", "phone": "+70178457719"}
0005435612176	5BC86D	3100 927976	OLEG IVANOV	{"phone": "+70114488945"}
0005435612177	8C6D1E	7562 796045	FARIDA IVANOVA	{"email": "ivanovaf_011977@postgrespro.ru", "phone": "+70276029503"}
0005435612178	64B7A3	5755 630541	ALEKSANDR KUZNECOV	{"email": "kuznecov_a-03081956@postgrespro.ru", "phone": "+70660486732"}
0005435612179	64B7A3	1304 864809	MARIYA NAZAROVA	{"email": "nazarova.mariya-041976@postgrespro.ru", "phone": "+70108796787"}
0005435612180	DF745D	0218 436252	SEMEN IVANOV	{"email": "ivanovsemen1959@postgrespro.ru", "phone": "+70867249118"}
0005435612181	6F28E8	0966 992010	ELENA LEBEDEVA	{"email": "lebedeva.elena_011975@postgrespro.ru", "phone": "+70860007030"}
0005435612182	FB7AE5	6122 035227	EKATERINA MAKAROVA	{"phone": "+70013688786"}
0005435612183	FB7AE5	7422 525214	DMITRIY VASILEV	{"email": "d-vasilev_27011977@postgrespro.ru", "phone": "+70309365461"}
0005435612184	3CC6FA	1758 523155	DMITRIY BORISOV	{"phone": "+70636564510"}
0005435612185	30542E	1740 850252	MAKSIM RODIONOV	{"email": "maksim_rodionov-19071965@postgrespro.ru", "phone": "+70151295122"}
0005435612186	668EA3	4368 866069	SVETLANA NIKOLAEVA	{"email": "nikolaeva-s101969@postgrespro.ru", "phone": "+70195091006"}
0005435612187	B67F87	1046 629145	MARAT ALEKSANDROV	{"phone": "+70477980326"}
0005435612188	FBF216	3182 010565	VALERIY FEDOROV	{"email": "fedorov_v_051975@postgrespro.ru", "phone": "+70184977417"}
0005435612189	FBF216	3503 392357	EVGENIYA MAKSIMOVA	{"email": "e-maksimova-04121962@postgrespro.ru", "phone": "+70771273137"}
0005435612190	FCAE7B	2843 741684	ANATOLIY KOZLOV	{"email": "a_kozlov_1972@postgrespro.ru", "phone": "+70425811380"}
0005435612191	58D2D1	4648 975930	ELENA FOMINA	{"phone": "+70626555333"}
0005435612192	10437E	3489 208042	NIKOLAY KUZNECOV	{"email": "nikolay-kuznecov_1971@postgrespro.ru", "phone": "+70401075451"}
0005435612193	8BC9A6	0896 665174	ALEKSEY KUZNECOV	{"phone": "+70482904230"}
0005435612194	B4DD50	6735 788300	ALEKSANDR ABRAMOV	{"phone": "+70875502319"}
0005435612195	B4DD50	0308 885921	TATYANA KULIKOVA	{"email": "kulikova-tatyana26041975@postgrespro.ru", "phone": "+70801005001"}
0005435612196	B4DD50	7856 562053	ALEKSANDR SOKOLOV	{"email": "sokolov-a_1970@postgrespro.ru", "phone": "+70733805653"}
0005435612197	D17AAF	6653 924266	SERGEY VOLKOV	{"phone": "+70424061559"}
0005435612198	79A89F	1640 829715	KONSTANTIN SHEVCHENKO	{"phone": "+70483679740"}
0005435612199	A1E4B4	4713 708272	DMITRIY ALEKSEEV	{"phone": "+70456521391"}
0005435612200	B5CF53	6615 624083	ZULFIYA MOROZOVA	{"phone": "+70486969672"}
0005435612201	4FE4CF	8330 366749	ALINA DMITRIEVA	{"email": "dmitrieva-alina.121965@postgrespro.ru", "phone": "+70206214771"}
0005435612202	4FE4CF	6966 453907	MARIYA GUSEVA	{"email": "mariya_guseva-081975@postgrespro.ru", "phone": "+70379222802"}
0005435612203	4FE4CF	2218 186256	MIKHAIL NIKITIN	{"phone": "+70356578801"}
0005435612204	C54B0A	9946 101280	YULIYA GUSEVA	{"email": "guseva_yuliya-1979@postgrespro.ru", "phone": "+70715193480"}
0005435612205	4F658F	0920 028515	VLADIMIR ANDREEV	{"phone": "+70373946028"}
0005435612206	4F658F	3148 942312	INNA KUZNECOVA	{"email": "ikuznecova_22021974@postgrespro.ru", "phone": "+70551166363"}
0005435612207	4F658F	2139 162108	ALEKSANDR MIRONOV	{"phone": "+70242876211"}
0005435612208	7CC38C	4078 552956	STANISLAV ILIN	{"email": "stanislav_ilin23101976@postgrespro.ru", "phone": "+70613824549"}
0005435612209	7CC38C	9726 869773	IRINA KOMAROVA	{"phone": "+70503908795"}
0005435612210	6E8F0E	0814 893600	OLEG SOLOVEV	{"email": "o.solovev.1977@postgrespro.ru", "phone": "+70338185612"}
0005435612211	38BD80	9747 061054	BORIS KUZMIN	{"email": "b-kuzmin_10011972@postgrespro.ru", "phone": "+70639137052"}
0005435612212	38BD80	3808 639013	ANATOLIY SERGEEV	{"phone": "+70557400341"}
0005435612213	224AA3	1932 131374	MARIYA PAVLOVA	{"email": "mariyapavlova-02041975@postgrespro.ru", "phone": "+70208128905"}
0005435612214	F72638	3943 588228	SERGEY IVANOV	{"email": "ivanov-sergey-011975@postgrespro.ru", "phone": "+70023489057"}
0005435612215	2A4A01	0476 176647	VITALIY AFANASEV	{"email": "afanasev_vitaliy_091967@postgrespro.ru", "phone": "+70180330859"}
0005435612216	250891	8830 495451	ELENA MAKSIMOVA	{"email": "elena_maksimova-19121955@postgrespro.ru", "phone": "+70387254116"}
0005435612217	D88687	6862 841446	VLADISLAV STEPANOV	{"phone": "+70793657946"}
0005435612218	D898A9	3895 292389	YULIYA DENISOVA	{"email": "denisova.y1982@postgrespro.ru", "phone": "+70810088223"}
0005435612219	A95592	4993 355483	IRINA AFANASEVA	{"phone": "+70702290771"}
0005435612220	779DC9	0329 632326	ROMAN STEPANOV	{"email": "stepanovr-031964@postgrespro.ru", "phone": "+70331882759"}
0005435612221	779DC9	4666 137059	NAILYA IVANOVA	{"phone": "+70782731537"}
0005435612222	D2E105	1451 906014	VALENTINA IVANOVA	{"email": "valentinaivanova_1978@postgrespro.ru", "phone": "+70262603456"}
0005435612223	E36B20	4237 251868	DANIYA VOLKOVA	{"phone": "+70174084020"}
0005435612224	F0F3AB	3492 181932	SERGEY ISAEV	{"email": "isaev-sergey1974@postgrespro.ru", "phone": "+70021893857"}
0005435612225	942382	2971 458757	ZLATA BARANOVA	{"email": "baranovaz-04101972@postgrespro.ru", "phone": "+70085624308"}
0005435612226	957025	9387 436487	VLADISLAV NIKOLAEV	{"email": "nikolaev.vladislav.02081969@postgrespro.ru", "phone": "+70081899672"}
0005435612227	A31D20	4302 504501	NINA VASILEVA	{"phone": "+70205454418"}
0005435612228	7AD422	6132 723426	ANNA ILINA	{"email": "ilina_anna_26061972@postgrespro.ru", "phone": "+70974355478"}
0005435612229	7AD422	6152 299841	ALEKSANDR KOROLEV	{"email": "korolev_aleksandr.031971@postgrespro.ru", "phone": "+70439278502"}
0005435612230	B05AB1	7548 802605	VYACHESLAV KULIKOV	{"phone": "+70182775774"}
0005435612231	B05AB1	8700 931260	ILYA KUZNECOV	{"email": "kuznecov_i.101967@postgrespro.ru", "phone": "+70777790948"}
0005435612232	90E9F2	0976 991738	ALEKSANDR EGOROV	{"email": "aleksandr.egorov-17071976@postgrespro.ru", "phone": "+70677275003"}
0005435612233	960CA2	0114 078644	MARGARITA ZHURAVLEVA	{"email": "zhuravlevam.011976@postgrespro.ru", "phone": "+70208789388"}
0005435612409	C061ED	9463 304002	VIKTOR KUZNECOV	{"phone": "+70736717921"}
0005435612234	960CA2	6852 274291	TATYANA KUZNECOVA	{"email": "kuznecova.tatyana-031982@postgrespro.ru", "phone": "+70176082606"}
0005435612235	C90853	6320 308991	GALINA SMIRNOVA	{"email": "smirnova-g_07031977@postgrespro.ru", "phone": "+70298403642"}
0005435612236	6B46A2	4068 882810	TATYANA SEMENOVA	{"email": "tatyana-semenova.081971@postgrespro.ru", "phone": "+70191643650"}
0005435612237	048EF5	3172 910820	OLGA KOZLOVA	{"email": "o_kozlova_25081966@postgrespro.ru", "phone": "+70112805389"}
0005435612238	048EF5	3874 194973	KONSTANTIN POPOV	{"phone": "+70101543202"}
0005435612239	048EF5	9648 783992	IRINA MIRONOVA	{"email": "mironovairina.11041977@postgrespro.ru", "phone": "+70588533215"}
0005435612240	69558C	4922 498017	TATYANA OSIPOVA	{"email": "osipovat_1977@postgrespro.ru", "phone": "+70827345081"}
0005435612241	69558C	4765 561624	NATALYA NOVIKOVA	{"phone": "+70593636091"}
0005435612242	879430	0302 183068	KRISTINA KONOVALOVA	{"phone": "+70851919383"}
0005435612243	08DD58	1157 838612	ALEKSANDR SIDOROV	{"phone": "+70803898769"}
0005435612244	981321	1826 669749	NATALYA NOVIKOVA	{"email": "novikova_n_011954@postgrespro.ru", "phone": "+70522480556"}
0005435612245	68458D	4029 280559	ALEKSANDR OSIPOV	{"phone": "+70768544370"}
0005435612246	68458D	3361 036511	TATYANA MATVEEVA	{"phone": "+70871133569"}
0005435612247	68458D	5096 518586	LYUDMILA FEDOROVA	{"phone": "+70941056838"}
0005435612248	68458D	3253 299490	SERGEY MOISEEV	{"phone": "+70642256737"}
0005435612249	2EEEC1	1147 466874	SVETLANA IVANOVA	{"phone": "+70322679501"}
0005435612250	951B85	0260 235187	NATALYA ALEKSEEVA	{"phone": "+70956237368"}
0005435612251	951B85	3270 149174	ANGELINA SOKOLOVA	{"email": "a_sokolova.1967@postgrespro.ru", "phone": "+70350929117"}
0005435612252	EC2AF5	6258 736933	VASILIY ZAYCEV	{"email": "vasiliyzaycev_1976@postgrespro.ru", "phone": "+70299338324"}
0005435612253	EC2AF5	2791 144510	NATALYA NESTEROVA	{"phone": "+70811484883"}
0005435612254	43AC9D	2929 450053	ANNA ZHURAVLEVA	{"email": "zhuravleva_a.111973@postgrespro.ru", "phone": "+70656841966"}
0005435612255	09615F	4518 241538	VALENTIN BORISOV	{"phone": "+70053236126"}
0005435612256	B9EE09	4053 026330	ELENA VASILEVA	{"phone": "+70790176592"}
0005435612257	B9EE09	5796 346718	ALIYA KUDRYASHOVA	{"email": "aliya_kudryashova.111972@postgrespro.ru", "phone": "+70869316238"}
0005435612258	7CB6A3	0208 387927	EVGENIY SOROKIN	{"email": "sorokine-061967@postgrespro.ru", "phone": "+70101515802"}
0005435612259	7CB6A3	5004 591432	VALERIY VOROBEV	{"phone": "+70068903658"}
0005435612260	B966DA	2927 133984	TATYANA MARTYNOVA	{"phone": "+70984626222"}
0005435612261	573683	9866 075335	OLGA SCHERBAKOVA	{"email": "scherbakovao-1973@postgrespro.ru", "phone": "+70680643810"}
0005435612262	EA663C	4454 531908	ALEKSANDR KISELEV	{"email": "kiselev-a.23031981@postgrespro.ru", "phone": "+70106942555"}
0005435612263	22B778	2531 371343	ARTUR NIKOLAEV	{"email": "a_nikolaev.031971@postgrespro.ru", "phone": "+70129105578"}
0005435612264	D2D1E2	9307 527570	LIDIYA AFANASEVA	{"email": "l_afanaseva-021977@postgrespro.ru", "phone": "+70699249220"}
0005435612265	2FAA3B	2871 155670	ANDREY YAKOVLEV	{"email": "yakovlev.andrey091973@postgrespro.ru", "phone": "+70067022069"}
0005435612266	AF2B0E	0178 618618	OLGA TIKHONOVA	{"email": "olga_tikhonova_1965@postgrespro.ru", "phone": "+70042683232"}
0005435612267	B7C0DC	9714 415212	TATYANA TARASOVA	{"email": "tarasova_t29071975@postgrespro.ru", "phone": "+70811074219"}
0005435612268	30E730	8872 041482	ILYAS FEDOROV	{"email": "ilyas.fedorov.071973@postgrespro.ru", "phone": "+70020687183"}
0005435612269	30E730	1006 851770	MARINA IVANOVA	{"phone": "+70881500501"}
0005435612270	0FDCDA	6092 469816	LYUDMILA PAVLOVA	{"email": "lyudmila_pavlova.051971@postgrespro.ru", "phone": "+70854640567"}
0005435612271	EB8E73	5720 677354	OLGA DENISOVA	{"phone": "+70309986548"}
0005435612272	2B178A	4565 169937	IRINA TIKHONOVA	{"phone": "+70055591844"}
0005435612273	2B178A	9868 644393	ALEKSANDR SOKOLOV	{"email": "asokolov.031960@postgrespro.ru", "phone": "+70081532175"}
0005435612274	860561	3323 581917	ANDREY KOZLOV	{"email": "kozlovandrey_091976@postgrespro.ru", "phone": "+70091567534"}
0005435612275	F391CB	5924 308256	VALENTIN DENISOV	{"email": "valentin_denisov-06061972@postgrespro.ru", "phone": "+70321978815"}
0005435612276	D972D8	1008 830320	ARTEM KUZNECOV	{"phone": "+70493426093"}
0005435612277	D972D8	9318 723951	MAKSIM PAVLOV	{"phone": "+70281915346"}
0005435612278	4001DC	5107 277238	ALEKSANDR MATVEEV	{"phone": "+70657041348"}
0005435612279	4001DC	3288 710057	NATALYA ANTONOVA	{"email": "antonovan121968@postgrespro.ru", "phone": "+70789083639"}
0005435612280	39D400	9913 174022	OLEG MARTYNOV	{"email": "o_martynov.1978@postgrespro.ru", "phone": "+70991582900"}
0005435612281	898526	8288 095955	MARIYA POLYAKOVA	{"email": "mariya_polyakova.1961@postgrespro.ru", "phone": "+70269146454"}
0005435612282	898526	2940 859659	BORIS BONDARENKO	{"email": "borisbondarenko_1974@postgrespro.ru", "phone": "+70050913575"}
0005435612283	8C8FA8	0560 475915	ANNA KUZNECOVA	{"email": "anna_kuznecova-1975@postgrespro.ru", "phone": "+70243498292"}
0005435612284	F75F1F	1429 726002	VIKTOR GORBUNOV	{"phone": "+70938176769"}
0005435612285	5C2F07	2769 500853	VIKTORIYA MOROZOVA	{"email": "morozova-viktoriya_1980@postgrespro.ru", "phone": "+70543524190"}
0005435612286	D99AEA	6711 201242	YURIY MEDVEDEV	{"phone": "+70913335130"}
0005435612287	EF811F	5566 815437	PAVEL DENISOV	{"phone": "+70406086762"}
0005435612288	8BFC0F	4159 832708	MARIYA PAVLOVA	{"email": "mariya.pavlova_101976@postgrespro.ru", "phone": "+70762031528"}
0005435612289	06E233	9076 661196	LARISA MELNIKOVA	{"email": "melnikova.larisa.24081967@postgrespro.ru", "phone": "+70667183605"}
0005435612290	987E22	1885 643647	STANISLAV KAZAKOV	{"phone": "+70975117572"}
0005435612291	987E22	8421 641149	SERGEY FEDOROV	{"email": "sfedorov_111978@postgrespro.ru", "phone": "+70072051669"}
0005435612292	32B40B	1974 758766	YURIY NIKITIN	{"email": "yuriy-nikitin.121980@postgrespro.ru", "phone": "+70987071277"}
0005435612293	BF2460	5689 917880	ALEKSANDR MARTYNOV	{"email": "aleksandrmartynov1969@postgrespro.ru", "phone": "+70384490206"}
0005435612294	BF2460	7262 804939	ALEKSANDR IVANOV	{"phone": "+70495439615"}
0005435612295	691209	0711 624071	EVGENIY KUZMIN	{"phone": "+70105853412"}
0005435612296	8FB8E8	4407 125911	NIKOLAY KUZNECOV	{"email": "kuznecovnikolay_051959@postgrespro.ru", "phone": "+70931192175"}
0005435612297	991A15	7943 526139	LIDIYA KULIKOVA	{"email": "kulikova-l.081975@postgrespro.ru", "phone": "+70734202288"}
0005435612298	0C12BF	4284 637761	TATYANA MATVEEVA	{"email": "t-matveeva-02051969@postgrespro.ru", "phone": "+70198773594"}
0005435612299	BE489A	4498 181074	SVETLANA KUZNECOVA	{"email": "svetlanakuznecova23031969@postgrespro.ru", "phone": "+70556752241"}
0005435612300	742F6B	9826 581067	ANNA MASLOVA	{"email": "annamaslova_081975@postgrespro.ru", "phone": "+70185934867"}
0005435612301	B63CD4	8610 468735	NIKOLAY SMIRNOV	{"email": "smirnovn_29051967@postgrespro.ru", "phone": "+70241084673"}
0005435612302	93AF4D	0202 986321	KIRILL YAKOVLEV	{"email": "kirillyakovlev-041973@postgrespro.ru", "phone": "+70003211439"}
0005435612303	70CB96	7691 571932	ELENA SERGEEVA	{"email": "elena_sergeeva.17071973@postgrespro.ru", "phone": "+70711445039"}
0005435612304	A1F251	9417 215838	NIKITA SHEVCHENKO	{"email": "shevchenko-n1968@postgrespro.ru", "phone": "+70759819016"}
0005435612305	C96E78	0255 511366	ALEKSEY KOROLEV	{"email": "koroleva.081969@postgrespro.ru", "phone": "+70196058818"}
0005435612306	C4C2E2	0054 104238	ALSU KONDRATEVA	{"email": "kondrateva_a-14011976@postgrespro.ru", "phone": "+70167886410"}
0005435612307	626402	2559 126894	LYUDMILA MOROZOVA	{"email": "morozoval1971@postgrespro.ru", "phone": "+70865958159"}
0005435612308	E2DAD8	1316 803941	TATYANA ERMAKOVA	{"phone": "+70799766117"}
0005435612309	E2DAD8	8753 650393	ALEKSANDR ILIN	{"email": "ilin_a081977@postgrespro.ru", "phone": "+70393173075"}
0005435612310	095BE4	5575 411534	SOFYA ROMANOVA	{"phone": "+70400393657"}
0005435612311	92062A	3611 114098	ALEKSEY MARTYNOV	{"email": "a.martynov1979@postgrespro.ru", "phone": "+70257973600"}
0005435612312	3425FA	9042 738757	ANATOLIY SCHERBAKOV	{"phone": "+70313580187"}
0005435612313	3425FA	7620 486803	ALENA SIDOROVA	{"email": "sidorovaalena1970@postgrespro.ru", "phone": "+70497394765"}
0005435612314	CC31D9	5575 194403	TATYANA KONOVALOVA	{"phone": "+70528847468"}
0005435612315	76814E	3844 573075	VIKTOR GAVRILOV	{"phone": "+70081129254"}
0005435612316	76814E	3043 716422	SVETLANA MELNIKOVA	{"email": "s_melnikova041974@postgrespro.ru", "phone": "+70464744373"}
0005435612317	11FCA5	7530 444518	VALERIY GAVRILOV	{"email": "valeriy.gavrilov101971@postgrespro.ru", "phone": "+70819820371"}
0005435612318	11FCA5	4900 038205	ELENA TITOVA	{"email": "titova-elena12051966@postgrespro.ru", "phone": "+70733482860"}
0005435612319	FF379A	1768 199249	YAKOV ANDREEV	{"email": "andreev_y-1978@postgrespro.ru", "phone": "+70707829990"}
0005435612320	1CD9EF	7529 986847	VIKTOR VOLKOV	{"email": "volkov-v.1981@postgrespro.ru", "phone": "+70929873070"}
0005435612321	09A375	5944 062283	VALENTINA GUSEVA	{"phone": "+70289429981"}
0005435612322	09A375	2049 150777	ALLA BORISOVA	{"email": "borisovaalla-041974@postgrespro.ru", "phone": "+70436670098"}
0005435612323	70102E	5766 509907	IVAN PETROV	{"email": "ipetrov.14071974@postgrespro.ru", "phone": "+70014460183"}
0005435612324	70102E	8451 320125	NATALYA ROMANOVA	{"email": "n.romanova-111966@postgrespro.ru", "phone": "+70739920190"}
0005435612325	945799	6722 267017	DENIS KOROLEV	{"email": "denis.korolev-121980@postgrespro.ru", "phone": "+70058337387"}
0005435612326	402FEF	1751 023520	ANASTASIYA NESTEROVA	{"email": "a-nesterova_071967@postgrespro.ru", "phone": "+70171374939"}
0005435612327	DE0EFB	2911 364993	ANTON BELOV	{"email": "belov.anton.30061971@postgrespro.ru", "phone": "+70692141034"}
0005435612328	275DCF	3550 899511	DMITRIY AFANASEV	{"phone": "+70727910597"}
0005435612329	0EC6D8	2851 497081	ANTON BARANOV	{"phone": "+70967166875"}
0005435612330	B4AF9F	3831 474367	DINA SIDOROVA	{"email": "sidorova.dina_111987@postgrespro.ru", "phone": "+70571305123"}
0005435612331	B4AF9F	9523 408558	TATYANA ROMANOVA	{"phone": "+70827950987"}
0005435612332	290741	0989 616963	EVGENIY SCHERBAKOV	{"phone": "+70066440373"}
0005435612333	0E07F9	5979 508534	SERGEY ZAYCEV	{"email": "sergey-zaycev_06061978@postgrespro.ru", "phone": "+70292383370"}
0005435612334	0E07F9	3974 993199	DMITRIY ALEKSANDROV	{"phone": "+70122829915"}
0005435612335	46AA89	6724 385744	LYUDMILA STEPANOVA	{"email": "l.stepanova_21011975@postgrespro.ru", "phone": "+70697908655"}
0005435612336	D764DC	3136 784902	ANDREY GUSEV	{"email": "agusev1979@postgrespro.ru", "phone": "+70032150402"}
0005435612337	AD7842	6008 299096	IVAN PAVLOV	{"email": "pavlov-ivan-1971@postgrespro.ru", "phone": "+70621172019"}
0005435612338	E3B5CE	5878 079253	ALBINA KISELEVA	{"email": "a-kiseleva_18091977@postgrespro.ru", "phone": "+70761100917"}
0005435612339	0CC037	9886 913408	NIKOLAY MAKAROV	{"phone": "+70312805734"}
0005435612340	0CC037	0123 868054	IRINA LEBEDEVA	{"email": "i_lebedeva.1965@postgrespro.ru", "phone": "+70370412612"}
0005435612341	4B903B	3416 937210	ELENA MAKAROVA	{"phone": "+70436174233"}
0005435612342	C1E344	2966 211260	NIKITA KOROLEV	{"phone": "+70136933596"}
0005435612343	B381D7	0914 741620	ANNA FILIPPOVA	{"email": "afilippova.1973@postgrespro.ru", "phone": "+70519054384"}
0005435612344	B381D7	6067 217186	EKATERINA KOROLEVA	{"phone": "+70667050107"}
0005435612345	F70E3E	1498 374024	YAROSLAV SERGEEV	{"email": "sergeev_y1966@postgrespro.ru", "phone": "+70965744915"}
0005435612346	35B1A2	9081 664229	KRISTINA MIRONOVA	{"phone": "+70272878668"}
0005435612347	35B1A2	8954 991682	OLGA DENISOVA	{"email": "o-denisova-1983@postgrespro.ru", "phone": "+70396417496"}
0005435612348	417F8A	4153 354807	YULIYA PETROVA	{"email": "y-petrova-07051970@postgrespro.ru", "phone": "+70862564400"}
0005435612349	E2002D	5907 060985	ALEKSANDR KUZNECOV	{"phone": "+70163380300"}
0005435612527	F04816	9289 850268	TAMARA NIKOLAEVA	{"phone": "+70717586618"}
0005435612350	6F1A23	3347 845731	MARIYA FILATOVA	{"email": "filatova.m081966@postgrespro.ru", "phone": "+70619594299"}
0005435612351	025267	4548 594856	NIKOLAY DAVYDOV	{"email": "ndavydov_111966@postgrespro.ru", "phone": "+70971314333"}
0005435612352	025267	8349 794435	DINA VASILEVA	{"phone": "+70456535027"}
0005435612353	6C38E1	2690 953979	VALENTINA BORISOVA	{"email": "borisova_valentina_041965@postgrespro.ru", "phone": "+70267536827"}
0005435612354	6C38E1	7939 444451	ALFIYA ANTONOVA	{"email": "antonova_a041978@postgrespro.ru", "phone": "+70107943595"}
0005435612355	DD5CCC	4078 619649	ROMAN DENISOV	{"phone": "+70197120205"}
0005435612356	DD5CCC	8559 466371	OLGA SEMENOVA	{"phone": "+70961478641"}
0005435612357	3F726D	4342 301608	YURIY KUZNECOV	{"email": "kuznecovyuriy-22091990@postgrespro.ru", "phone": "+70609595316"}
0005435612358	E4B1DE	9818 336645	LYUDMILA TITOVA	{"email": "titova-l-01051962@postgrespro.ru", "phone": "+70183510408"}
0005435612359	ED60C9	1833 235988	VYACHESLAV KARPOV	{"email": "karpovvyacheslav29071966@postgrespro.ru", "phone": "+70192351191"}
0005435612360	ED60C9	7505 469398	DARYA KULIKOVA	{"email": "kulikova.d-061976@postgrespro.ru", "phone": "+70484454656"}
0005435612361	5131E4	9868 042149	MARINA SMIRNOVA	{"email": "msmirnova_28121964@postgrespro.ru", "phone": "+70685202944"}
0005435612362	732531	0525 399189	TATYANA ZAYCEVA	{"email": "tzayceva021982@postgrespro.ru", "phone": "+70617492987"}
0005435612363	10C148	8398 975107	VALENTINA SEMENOVA	{"email": "semenova-v.1970@postgrespro.ru", "phone": "+70717295771"}
0005435612364	8CFDCC	9270 772671	VALENTINA NAZAROVA	{"phone": "+70067919519"}
0005435612365	8CFDCC	0836 417081	ALINA IVANOVA	{"email": "alina-ivanova.1964@postgrespro.ru", "phone": "+70211268448"}
0005435612366	8CFDCC	3016 546129	ALEKSEY ZAYCEV	{"email": "zaycev.a_051960@postgrespro.ru", "phone": "+70786500784"}
0005435612367	BD777C	2484 786420	YURIY ZAYCEV	{"email": "yuriyzaycev-1969@postgrespro.ru", "phone": "+70670800353"}
0005435612368	BD777C	6466 055582	NINA IVANOVA	{"email": "ivanova.nina_101978@postgrespro.ru", "phone": "+70752410061"}
0005435612369	454E49	5076 196499	VLADIMIR YAKOVLEV	{"phone": "+70439812004"}
0005435612370	454E49	2310 931383	VLADIMIR MATVEEV	{"email": "matveev-vladimir09061970@postgrespro.ru", "phone": "+70144243870"}
0005435612371	454E49	9792 648072	ANDREY TIKHONOV	{"phone": "+70822189410"}
0005435612372	AB5E1D	7007 318430	ALEKSANDR GUSEV	{"email": "gusev-aleksandr-26041971@postgrespro.ru", "phone": "+70416975130"}
0005435612373	1E504A	0427 251833	ANTONINA FADEEVA	{"phone": "+70452144605"}
0005435612374	D14245	8112 956179	VALERIY ANDREEV	{"phone": "+70987743055"}
0005435612375	8EB97F	1524 763053	NATALYA ROMANOVA	{"phone": "+70866673682"}
0005435612376	8EB97F	5190 893421	ANDREY KRASNOV	{"phone": "+70850198925"}
0005435612377	2F5CE1	4197 892116	VERA MIKHAYLOVA	{"email": "veramikhaylova-111969@postgrespro.ru", "phone": "+70082861078"}
0005435612378	A50CA5	2082 980101	NINA FILATOVA	{"email": "nina_filatova041990@postgrespro.ru", "phone": "+70210024645"}
0005435612379	A50CA5	9162 069206	VIKTORIYA FEDOROVA	{"phone": "+70642909011"}
0005435612380	167646	0401 380685	NATALYA NIKITINA	{"email": "nikitina_natalya.071972@postgrespro.ru", "phone": "+70930756657"}
0005435612381	C7412C	2491 135494	SVETLANA POPOVA	{"email": "popovas.1974@postgrespro.ru", "phone": "+70135442453"}
0005435612382	55815B	8020 752037	YULIYA FROLOVA	{"email": "frolova-y1980@postgrespro.ru", "phone": "+70713333650"}
0005435612383	17ADDB	1986 343820	VERA SERGEEVA	{"phone": "+70094258490"}
0005435612384	5253C8	9729 234190	TATYANA TITOVA	{"email": "titova_t_19101977@postgrespro.ru", "phone": "+70202264431"}
0005435612385	22C9FD	6708 082580	ALEKSANDR MOROZOV	{"phone": "+70908652780"}
0005435612386	22C9FD	7442 493108	EVGENIY SIDOROV	{"email": "esidorov-11101970@postgrespro.ru", "phone": "+70144768288"}
0005435612387	22C9FD	7719 187301	VASILIY KUZNECOV	{"phone": "+70579432383"}
0005435612388	0FFE52	3529 531861	KONSTANTIN MATVEEV	{"email": "matveev-k1985@postgrespro.ru", "phone": "+70944707519"}
0005435612389	1B90A0	2452 489364	NATALYA IVANOVA	{"phone": "+70556669132"}
0005435612390	E7B66F	8815 695130	OLESYA MOROZOVA	{"phone": "+70518966997"}
0005435612391	47DF47	5403 225419	LYUBOV POPOVA	{"phone": "+70058183344"}
0005435612392	47DF47	5507 627701	IRAIDA MAKAROVA	{"phone": "+70385912933"}
0005435612393	76ECDF	4303 665897	FEDOR ANDREEV	{"phone": "+70829594587"}
0005435612394	980BA9	3198 241774	ANATOLIY ORLOV	{"email": "orlov.anatoliy-11101978@postgrespro.ru", "phone": "+70479408734"}
0005435612395	A635C7	8506 406968	ANDREY FROLOV	{"email": "frolov.a-27031960@postgrespro.ru", "phone": "+70489150259"}
0005435612396	B7DE59	5996 055995	GALINA BORISOVA	{"email": "borisova_g-28121969@postgrespro.ru", "phone": "+70762960551"}
0005435612397	5ECB29	5255 988873	ELENA CHERNOVA	{"email": "e.chernova.081971@postgrespro.ru", "phone": "+70971153296"}
0005435612398	ED2255	1469 382931	ALEKSANDR ORLOV	{"phone": "+70045130374"}
0005435612399	2EC60D	7447 423703	MARIYA PAVLOVA	{"phone": "+70859709348"}
0005435612400	DC34B7	0096 126571	MIKHAIL EGOROV	{"phone": "+70795638286"}
0005435612401	9DFA32	4125 131145	NADEZHDA KOROLEVA	{"email": "n-koroleva-121972@postgrespro.ru", "phone": "+70750411932"}
0005435612402	45E4DF	0640 208788	VALENTINA RYABOVA	{"phone": "+70082894074"}
0005435612403	45E4DF	2032 856266	IVAN EGOROV	{"email": "ivan_egorov_10111975@postgrespro.ru", "phone": "+70724643764"}
0005435612404	3EC9B1	1822 928520	ELVIRA POPOVA	{"email": "epopova_1967@postgrespro.ru", "phone": "+70643327719"}
0005435612405	2A9D37	8397 357498	VLADISLAV STEPANOV	{"phone": "+70519513644"}
0005435612406	876584	1910 688383	NINA EFREMOVA	{"email": "nefremova.1978@postgrespro.ru", "phone": "+70758045004"}
0005435612407	241F1F	9029 640699	STANISLAV ANDREEV	{"phone": "+70007494895"}
0005435612408	241F1F	5739 673534	VLADIMIR SOKOLOV	{"email": "v.sokolov-121983@postgrespro.ru", "phone": "+70551566614"}
0005435612410	C061ED	4260 394367	ANDREY KUZNECOV	{"email": "andrey_kuznecov.07031974@postgrespro.ru", "phone": "+70774312484"}
0005435612411	C55A60	0446 633432	TATYANA MOROZOVA	{"phone": "+70869220619"}
0005435612412	C12028	3205 779013	VERA POPOVA	{"phone": "+70607213715"}
0005435612413	A072FC	4633 037730	ELENA MALYSHEVA	{"email": "malyshevae1970@postgrespro.ru", "phone": "+70199555222"}
0005435612414	966A10	3541 288561	TATYANA SMIRNOVA	{"email": "tatyana.smirnova-031969@postgrespro.ru", "phone": "+70569228668"}
0005435612415	3D6DD2	9296 361366	LYUBOV VOLKOVA	{"email": "lyubov-volkova-061977@postgrespro.ru", "phone": "+70275037573"}
0005435612416	8ED7DF	2569 082934	ALEKSEY FILIPPOV	{"phone": "+70722795221"}
0005435612417	661A9B	7740 778741	GULFIYA FILIPPOVA	{"phone": "+70534282031"}
0005435612418	6B77FA	8385 458807	EKATERINA KAZAKOVA	{"email": "kazakova_ekaterina071966@postgrespro.ru", "phone": "+70947578786"}
0005435612419	74AEAA	2468 951024	VLADISLAV TIMOFEEV	{"email": "vladislav-timofeev1978@postgrespro.ru", "phone": "+70456767651"}
0005435612420	EAFD5C	2714 581527	ANTONINA YAKOVLEVA	{"email": "antonina.yakovleva.071987@postgrespro.ru", "phone": "+70741574703"}
0005435612421	EAFD5C	8777 266184	RODION GERASIMOV	{"email": "gerasimov-r.25091959@postgrespro.ru", "phone": "+70014774135"}
0005435612422	EAFD5C	9821 270716	ANNA EGOROVA	{"email": "annaegorova_061979@postgrespro.ru", "phone": "+70992543149"}
0005435612423	7E75A5	7367 998731	ALEKSEY KONOVALOV	{"phone": "+70127062304"}
0005435612424	AD9F68	7808 692547	ANASTASIYA ZHUKOVA	{"email": "zhukova_a-1974@postgrespro.ru", "phone": "+70868842544"}
0005435612425	528F9B	8807 619967	GALINA ANDREEVA	{"email": "andreeva_galina01101973@postgrespro.ru", "phone": "+70918876694"}
0005435612426	528F9B	2688 703923	KONSTANTIN ROMANOV	{"phone": "+70829231861"}
0005435612427	7B944A	2322 402324	MAKSIM NIKITIN	{"phone": "+70645847515"}
0005435612428	B2751F	6109 248413	VALENTINA KOLESNIKOVA	{"phone": "+70715340017"}
0005435612429	B2751F	7089 430692	ALEKSANDR KUDRYASHOV	{"phone": "+70471644503"}
0005435612430	571B9C	2026 161006	YULIYA NOVIKOVA	{"phone": "+70920122762"}
0005435612431	5207B3	5593 471122	SERGEY FEDOTOV	{"email": "fedotov_s-13111972@postgrespro.ru", "phone": "+70865304513"}
0005435612432	5207B3	2120 626420	IRINA MEDVEDEVA	{"phone": "+70612963406"}
0005435612433	AE6D45	5988 550235	IRINA MOROZOVA	{"email": "morozova_i-1967@postgrespro.ru", "phone": "+70016794035"}
0005435612434	F20867	8048 639211	TATYANA FILATOVA	{"email": "filatova.t-051972@postgrespro.ru", "phone": "+70351827242"}
0005435612435	DDA47A	3703 796563	NIKITA PAVLOV	{"phone": "+70558018088"}
0005435612436	BA2EEA	4297 676107	ALEKSANDR VOLKOV	{"phone": "+70272529645"}
0005435612437	BA2EEA	5224 594161	LYUBOV STEPANOVA	{"email": "stepanova.lyubov1976@postgrespro.ru", "phone": "+70174621537"}
0005435612438	8A9BAB	9461 997537	ALEKSANDR BORISOV	{"phone": "+70747028705"}
0005435612439	640AB8	7336 512009	NIKOLAY SERGEEV	{"email": "sergeev-nikolay.101977@postgrespro.ru", "phone": "+70043253511"}
0005435612440	766B7F	6460 925454	ANASTASIYA KUZMINA	{"email": "kuzmina_anastasiya.1964@postgrespro.ru", "phone": "+70173823703"}
0005435612441	7A5969	8611 152898	ALEKSANDR ALEKSEEV	{"phone": "+70419376890"}
0005435612442	E208E1	5148 580757	VERA VASILEVA	{"email": "vasileva.v-10121978@postgrespro.ru", "phone": "+70465233699"}
0005435612443	ADE636	8251 862081	KLARA KUZNECOVA	{"email": "klara-kuznecova071966@postgrespro.ru", "phone": "+70328730594"}
0005435612444	ADE636	2782 185282	VLADIMIR MOROZOV	{"email": "v.morozov_011972@postgrespro.ru", "phone": "+70253078582"}
0005435612445	6CAAE1	9498 666505	BOGDAN ALEKSANDROV	{"phone": "+70843619431"}
0005435612446	FF09B5	8783 115156	ALEKSEY STEPANOV	{"phone": "+70376132010"}
0005435612447	FF09B5	0533 653533	SERGEY SERGEEV	{"phone": "+70248860673"}
0005435612448	C0F6B1	6421 683859	EGOR GUSEV	{"email": "e_gusev_1974@postgrespro.ru", "phone": "+70739647074"}
0005435612449	382A0D	6822 346724	MARIYA MATVEEVA	{"phone": "+70631565056"}
0005435612450	C6DA81	6376 772760	EKATERINA YAKOVLEVA	{"email": "ekaterina-yakovleva-121977@postgrespro.ru", "phone": "+70491509936"}
0005435612451	705D7A	5770 595175	MARGARITA IVANOVA	{"email": "m_ivanova031964@postgrespro.ru", "phone": "+70283345712"}
0005435612452	FE44EB	4219 170710	MARINA MIKHAYLOVA	{"email": "marina.mikhaylova.30051973@postgrespro.ru", "phone": "+70289662858"}
0005435612453	FE44EB	0945 644310	ALLA ANTONOVA	{"email": "antonovaa1963@postgrespro.ru", "phone": "+70676697428"}
0005435612454	B976CB	0004 094445	ELENA KALININA	{"email": "elena.kalinina-1958@postgrespro.ru", "phone": "+70672088807"}
0005435612455	A9CDA1	2299 855287	SVETLANA MELNIKOVA	{"email": "melnikovas-081973@postgrespro.ru", "phone": "+70763731249"}
0005435612456	D69CF4	4274 564048	ALEKSEY MAKAROV	{"email": "makarovaleksey.121967@postgrespro.ru", "phone": "+70630808482"}
0005435612457	595C8F	6896 717641	DMITRIY SCHERBAKOV	{"email": "scherbakov_dmitriy-031987@postgrespro.ru", "phone": "+70496401677"}
0005435612458	11D29B	3141 803994	SERGEY GRIGOREV	{"email": "sergeygrigorev_21011967@postgrespro.ru", "phone": "+70374953551"}
0005435612459	11D29B	5802 441592	ROMAN KUZNECOV	{"email": "kuznecovr1968@postgrespro.ru", "phone": "+70756723138"}
0005435612460	D1DECC	3365 031300	ANASTASIYA ZAKHAROVA	{"email": "zakharova_anastasiya.1981@postgrespro.ru", "phone": "+70717806368"}
0005435612461	F578E6	4696 450821	VLADIMIR EGOROV	{"phone": "+70875036851"}
0005435612462	8A6FB8	3758 121286	NATALYA IVANOVA	{"email": "nivanova08061971@postgrespro.ru", "phone": "+70282929080"}
0005435612463	8A6FB8	8046 451942	EVGENIY VLASOV	{"phone": "+70002402824"}
0005435612464	8A6FB8	6803 144906	VALENTINA KULIKOVA	{"phone": "+70857216657"}
0005435612465	C87E01	0356 983104	TATYANA POTAPOVA	{"phone": "+70789235802"}
0005435612466	C87E01	5666 070825	ALEKSANDR BONDARENKO	{"phone": "+70887131026"}
0005435612467	C87E01	1106 946524	EVDOKIYA IVANOVA	{"phone": "+70847461792"}
0005435612825	01ABBD	4433 727202	NELLI NIKOLAEVA	{"phone": "+70283226230"}
0005435612468	68D627	1192 956273	YURIY SAVELEV	{"email": "yuriy_savelev.051974@postgrespro.ru", "phone": "+70922449701"}
0005435612469	62E455	7545 708129	EVGENIY KUZMIN	{"email": "kuzmin.evgeniy_012000@postgrespro.ru", "phone": "+70746558993"}
0005435612470	999B5A	7327 019262	SERGEY KOZLOV	{"email": "kozlovsergey31121963@postgrespro.ru", "phone": "+70799667988"}
0005435612471	5D77A6	3040 540947	ANNA SOROKINA	{"email": "sorokina_anna_08091973@postgrespro.ru", "phone": "+70032839232"}
0005435612472	D8152B	5638 453124	NINA DENISOVA	{"phone": "+70451982990"}
0005435612473	2925D3	1984 392830	VALENTINA SAVELEVA	{"phone": "+70015828207"}
0005435612474	B5FB2A	9621 014013	YANA IVANOVA	{"email": "ivanova.yana_1963@postgrespro.ru", "phone": "+70182211101"}
0005435612475	B5FB2A	1304 988755	VERA KOMAROVA	{"phone": "+70822147120"}
0005435612476	F4E7DE	8231 047999	NIKOLAY DMITRIEV	{"phone": "+70654680553"}
0005435612477	F4E7DE	9458 397327	VLADIMIR VOROBEV	{"phone": "+70213617002"}
0005435612478	83E544	6281 158115	EKATERINA KAZAKOVA	{"email": "kazakova-ekaterina_1960@postgrespro.ru", "phone": "+70023091711"}
0005435612479	FD45D7	0534 129134	VIKTOR ZAKHAROV	{"phone": "+70343097610"}
0005435612480	3D4F85	8656 904161	OKSANA MOROZOVA	{"email": "o_morozova.07121976@postgrespro.ru", "phone": "+70883566972"}
0005435612481	DED834	2649 271849	NATALYA KUZNECOVA	{"email": "kuznecovan-091963@postgrespro.ru", "phone": "+70211475481"}
0005435612482	015810	4792 152550	LARISA DENISOVA	{"email": "larisa-denisova_28011959@postgrespro.ru", "phone": "+70005084601"}
0005435612483	015810	2767 000980	ALEKSANDR ZHURAVLEV	{"phone": "+70731368940"}
0005435612484	51E1F4	7305 954012	VLADISLAV BARANOV	{"email": "v.baranov_1977@postgrespro.ru", "phone": "+70785387278"}
0005435612485	AF88B9	9423 833073	DMITRIY FEDOROV	{"phone": "+70051248723"}
0005435612486	F62668	0767 988203	ANDREY POPOV	{"email": "popovandrey-1961@postgrespro.ru", "phone": "+70905658618"}
0005435612487	73F615	9524 699289	VALERIY KAZAKOV	{"phone": "+70080874312"}
0005435612488	2B51B1	8899 963270	EVGENIY MAKSIMOV	{"phone": "+70061119261"}
0005435612489	7EF4BA	0390 716414	NATALYA SERGEEVA	{"phone": "+70711157493"}
0005435612490	0AE90A	2497 986731	RUSTAM NOVIKOV	{"email": "novikov-r_061988@postgrespro.ru", "phone": "+70840040389"}
0005435612491	0AE90A	3468 773425	NIKOLAY FROLOV	{"phone": "+70653248484"}
0005435612492	326318	7621 118710	ANNA POPOVA	{"phone": "+70110839214"}
0005435612493	43A325	9051 495803	SVETLANA KULIKOVA	{"phone": "+70822094713"}
0005435612494	43A325	1194 422459	POLINA KOZLOVA	{"email": "kozlova.p_06061989@postgrespro.ru", "phone": "+70078047280"}
0005435612495	582ACF	9798 661812	ANASTASIYA VOLKOVA	{"email": "volkovaanastasiya1978@postgrespro.ru", "phone": "+70431594949"}
0005435612496	31BF98	5370 026580	LYUBOV FROLOVA	{"email": "lyubov-frolova_1972@postgrespro.ru", "phone": "+70904240410"}
0005435612497	31BF98	5530 935026	VIKTOR PETROV	{"phone": "+70064770971"}
0005435612498	73A9B3	5310 116203	KARINA NIKITINA	{"email": "nikitina-karina-061973@postgrespro.ru", "phone": "+70000780048"}
0005435612499	B5A72C	1134 372087	OLGA MELNIKOVA	{"phone": "+70433360292"}
0005435612500	B5A72C	5569 536730	EVGENIYA ORLOVA	{"email": "orlova_e.091967@postgrespro.ru", "phone": "+70073341053"}
0005435612501	CD4D4F	5196 450639	ALEKSEY VASILEV	{"phone": "+70080574320"}
0005435612502	CD4D4F	5412 940602	NADEZHDA KOROLEVA	{"phone": "+70647888338"}
0005435612503	977FBC	7758 147565	ALEKSANDR VOLKOV	{"email": "a_volkov_1962@postgrespro.ru", "phone": "+70515900072"}
0005435612504	11FC1F	1453 142680	DMITRIY MOROZOV	{"email": "d_morozov021972@postgrespro.ru", "phone": "+70798877596"}
0005435612505	18B1D7	7203 320455	ALEKSEY ZHURAVLEV	{"email": "zhuravlev-aleksey071970@postgrespro.ru", "phone": "+70542209049"}
0005435612563	1676CE	2613 773040	VALENTINA SERGEEVA	{"phone": "+70606633398"}
0005435612506	39DEA4	4747 609616	YURIY MIKHAYLOV	{"email": "y-mikhaylov_061972@postgrespro.ru", "phone": "+70462732539"}
0005435612507	A86D9F	3443 747857	IRINA KONDRATEVA	{"phone": "+70373845156"}
0005435612508	2AA08D	4807 078547	MIKHAIL IVANOV	{"email": "ivanovmikhail-1977@postgrespro.ru", "phone": "+70492240181"}
0005435612509	BAC727	7637 776406	IRINA KONOVALOVA	{"email": "i-konovalova.1980@postgrespro.ru", "phone": "+70430263863"}
0005435612510	021518	4223 561619	VALENTINA ZAYCEVA	{"phone": "+70292933322"}
0005435612511	021518	3307 494469	IGOR POPOV	{"phone": "+70466979365"}
0005435612512	FDEC03	0446 250455	EMIL KOROLEV	{"phone": "+70143903024"}
0005435612513	FDEC03	4570 270204	ANNA KOLESNIKOVA	{"email": "a.kolesnikova20061968@postgrespro.ru", "phone": "+70848265579"}
0005435612514	358A78	8419 891264	VALENTIN ROMANOV	{"phone": "+70352153588"}
0005435612515	15087B	9914 884889	GALINA FILIPPOVA	{"phone": "+70728775757"}
0005435612516	044426	7422 061937	NIKITA VLASOV	{"email": "nikita-vlasov.31071973@postgrespro.ru", "phone": "+70860848342"}
0005435612517	DF60BC	2795 526797	ANASTASIYA ZHURAVLEVA	{"phone": "+70230467639"}
0005435612518	4DC2D3	4747 255773	ALEKSEY VLASOV	{"phone": "+70265456576"}
0005435612519	8C4F84	1395 669268	MAKSIM FOMIN	{"email": "fomin-m.12021985@postgrespro.ru", "phone": "+70691695985"}
0005435612520	B86803	6505 514578	LIDIYA KULIKOVA	{"email": "kulikova.lidiya.1976@postgrespro.ru", "phone": "+70970514788"}
0005435612521	4E97E4	3827 482390	ELENA LEBEDEVA	{"email": "lebedeva_e-1971@postgrespro.ru", "phone": "+70346121324"}
0005435612522	1B6898	1489 494869	VALENTINA AKIMOVA	{"phone": "+70847154332"}
0005435612523	94CF46	5336 854995	ANASTASIYA MARTYNOVA	{"email": "a-martynova081972@postgrespro.ru", "phone": "+70246140585"}
0005435612524	B8F22C	3663 646887	VLADIMIR VLASOV	{"email": "vlasov.vladimir_1978@postgrespro.ru", "phone": "+70712895820"}
0005435612525	B8F22C	1467 463707	VALERIYA KOVALEVA	{"email": "kovaleva_valeriya051977@postgrespro.ru", "phone": "+70321160342"}
0005435612526	262DD7	1570 200234	TATYANA TARASOVA	{"phone": "+70633454604"}
0005435612528	F04816	0753 232099	TAMARA PAVLOVA	{"email": "pavlova.tamara101972@postgrespro.ru", "phone": "+70687081549"}
0005435612529	6C2B44	8771 521758	MARIYA SOROKINA	{"phone": "+70717146654"}
0005435612530	DE5DE4	6001 367794	SVETLANA ANTONOVA	{"phone": "+70282715139"}
0005435612531	03A59F	8588 346969	ANNA MEDVEDEVA	{"phone": "+70813959802"}
0005435612532	D4FE72	7074 963510	ALEKSANDR FOMIN	{"phone": "+70527749072"}
0005435612533	911493	8973 961846	IRINA NAZAROVA	{"phone": "+70402541092"}
0005435612534	911493	3915 406057	LARISA LOGINOVA	{"email": "loginova_larisa071964@postgrespro.ru", "phone": "+70630918652"}
0005435612535	8A38D5	1694 928898	ANNA POPOVA	{"phone": "+70796831405"}
0005435612536	4865A0	5225 536375	ANDREY MAKSIMOV	{"phone": "+70295456476"}
0005435612537	C7A8C0	2885 660243	ALEKSANDR ROMANOV	{"phone": "+70025728452"}
0005435612538	58491A	0098 022828	ELENA EFIMOVA	{"email": "eefimova121979@postgrespro.ru", "phone": "+70680503729"}
0005435612539	AC16D6	6862 194756	IRINA FROLOVA	{"email": "irina-frolova_1974@postgrespro.ru", "phone": "+70615408524"}
0005435612540	AC16D6	1513 757833	ALEKSEY RODIONOV	{"phone": "+70743955890"}
0005435612541	AC16D6	8987 395365	OKSANA MOROZOVA	{"phone": "+70941382784"}
0005435612542	AC16D6	6925 148490	LIDIYA MOISEEVA	{"phone": "+70915715657"}
0005435612543	2A9723	2053 348488	TATYANA GERASIMOVA	{"phone": "+70243796991"}
0005435612544	2A9723	6118 767805	MARIYA IVANOVA	{"email": "mariya_ivanova27081972@postgrespro.ru", "phone": "+70753988821"}
0005435612545	5767F9	5335 976507	NIKOLAY DAVYDOV	{"phone": "+70482371120"}
0005435612546	5767F9	6596 348179	GLEB ROMANOV	{"phone": "+70994954954"}
0005435612547	D7F9D3	8463 900113	DARYA VASILEVA	{"email": "vasileva-darya-1985@postgrespro.ru", "phone": "+70231815441"}
0005435612548	F085EA	9479 400741	ALEKSANDR VOLKOV	{"email": "volkov_aleksandr-1981@postgrespro.ru", "phone": "+70827575592"}
0005435612549	B61590	2644 556259	SERGEY BARANOV	{"email": "baranov-sergey.1969@postgrespro.ru", "phone": "+70701000213"}
0005435612550	B61590	9506 811392	NATALYA SIDOROVA	{"phone": "+70017515024"}
0005435612551	C62C1F	3572 361319	DIANA MIRONOVA	{"email": "diana_mironova-1986@postgrespro.ru", "phone": "+70279214944"}
0005435612552	9E9B87	0035 101438	ANDREY GUSEV	{"phone": "+70846726903"}
0005435612553	9E9B87	0311 952618	EKATERINA POPOVA	{"phone": "+70498457286"}
0005435612554	55B64E	2181 667132	SERGEY MIKHAYLOV	{"email": "sergey_mikhaylov.17011976@postgrespro.ru", "phone": "+70473358464"}
0005435612555	F44313	3629 896514	OKSANA SCHERBAKOVA	{"phone": "+70667997190"}
0005435612556	F44313	5801 924167	LIDIYA SAVELEVA	{"phone": "+70078386409"}
0005435612557	CCFFB4	9978 812827	YULIYA MALYSHEVA	{"phone": "+70841764152"}
0005435612558	CCFFB4	1016 241379	ALEKSEY KRASNOV	{"phone": "+70873788451"}
0005435612559	CCFFB4	6835 601094	EVGENIY VASILEV	{"email": "evgeniy.vasilev.01091979@postgrespro.ru", "phone": "+70026310201"}
0005435612560	DC2547	1685 445243	SANIYA POTAPOVA	{"phone": "+70815450379"}
0005435612561	DC2547	0925 581202	ANDREY SERGEEV	{"email": "sergeev-a.20021972@postgrespro.ru", "phone": "+70909774771"}
0005435612562	BA197A	2794 057214	YURIY ANDREEV	{"email": "yuriy.andreev_1982@postgrespro.ru", "phone": "+70882993498"}
0005435612564	FD2EF1	8761 557387	NADEZHDA BOGDANOVA	{"phone": "+70785822841"}
0005435612565	0DB40A	0309 175808	ELENA ANTONOVA	{"email": "antonova_elena-26061973@postgrespro.ru", "phone": "+70104247221"}
0005435612566	0DB40A	0821 788725	MARIYA SOROKINA	{"email": "sorokina_m.091971@postgrespro.ru", "phone": "+70480564148"}
0005435612567	916197	5991 317439	MARGARITA KOZLOVA	{"email": "kozlova.margarita1970@postgrespro.ru", "phone": "+70642387009"}
0005435612568	5E63CF	1741 874052	TATYANA SOKOLOVA	{"phone": "+70791881217"}
0005435612569	F0B2F9	1388 734422	ELENA NAZAROVA	{"email": "e_nazarova-29101965@postgrespro.ru", "phone": "+70689528498"}
0005435612570	B37574	8017 413232	ANDREY MAKAROV	{"phone": "+70808816851"}
0005435612571	B37574	0405 717833	ANDREY KAZAKOV	{"email": "kazakov.andrey_1967@postgrespro.ru", "phone": "+70760920065"}
0005435612572	4BB6BC	7850 699636	MAKSIM GERASIMOV	{"phone": "+70833447146"}
0005435612573	67DE18	7966 044061	OLEG SOKOLOV	{"email": "sokolov_oleg111970@postgrespro.ru", "phone": "+70158919974"}
0005435612574	67DE18	9801 208360	TATYANA FILATOVA	{"email": "tatyana_filatova.14121969@postgrespro.ru", "phone": "+70386300301"}
0005435612575	BD038B	2455 325089	ALEKSEY GERASIMOV	{"email": "gerasimov_a25091972@postgrespro.ru", "phone": "+70865319874"}
0005435612576	D6A9BC	4792 211201	ALEKSANDR ABRAMOV	{"email": "abramov.aleksandr_1964@postgrespro.ru", "phone": "+70239614552"}
0005435612577	D6A9BC	7765 508819	SVETLANA RODIONOVA	{"email": "svetlana.rodionova-13121977@postgrespro.ru", "phone": "+70265761492"}
0005435612578	A539FB	1452 782053	ANZHELA NESTEROVA	{"phone": "+70302687318"}
0005435612579	A539FB	0787 093097	YULIYA CHERNOVA	{"phone": "+70031288090"}
0005435612580	4D7B23	4286 094536	YANA VASILEVA	{"email": "vasileva_y-1977@postgrespro.ru", "phone": "+70315639762"}
0005435612581	0BA6A2	9945 333616	MIKHAIL KUZMIN	{"phone": "+70317295459"}
0005435612582	0BA6A2	8143 505083	GALINA FILIPPOVA	{"email": "filippovagalina_091968@postgrespro.ru", "phone": "+70089661290"}
0005435612583	F31FE6	1949 854177	IRINA VLASOVA	{"phone": "+70019539364"}
0005435612584	F31FE6	8702 498443	ELENA TARASOVA	{"email": "tarasova.elena.1967@postgrespro.ru", "phone": "+70244435643"}
0005435612585	3CFE7F	6119 278862	VLADIMIR KUZNECOV	{"phone": "+70832901945"}
0005435612586	FF3535	8582 826721	VERA IVANOVA	{"email": "vera.ivanova1978@postgrespro.ru", "phone": "+70324240059"}
0005435612587	879801	3076 920251	OLGA MELNIKOVA	{"email": "o-melnikova.20061982@postgrespro.ru", "phone": "+70987667284"}
0005435612588	6BDBCA	1652 361662	IGOR ANDREEV	{"email": "andreev.igor.1971@postgrespro.ru", "phone": "+70506431324"}
0005435612589	6F923C	3853 359071	LYUBOV NOVIKOVA	{"phone": "+70053496692"}
0005435612590	6F923C	2613 997383	TATYANA SMIRNOVA	{"email": "tatyana_smirnova_11081978@postgrespro.ru", "phone": "+70356861645"}
0005435612591	6831D4	8817 535503	YURIY ZAKHAROV	{"email": "zakharov_yuriy-061970@postgrespro.ru", "phone": "+70180824240"}
0005435612592	6831D4	3296 859869	OLEG STEPANOV	{"email": "o-stepanov_1975@postgrespro.ru", "phone": "+70596979707"}
0005435612593	556A4A	9563 597713	VIOLETTA ALEKSANDROVA	{"phone": "+70753433748"}
0005435612594	124BA2	5389 243011	ELENA MASLOVA	{"phone": "+70081105069"}
0005435612595	C50CAD	1724 815024	ANDREY KAZAKOV	{"email": "andrey_kazakov_1966@postgrespro.ru", "phone": "+70476916851"}
0005435612596	C50CAD	9759 571661	MARINA YUDINA	{"phone": "+70517203558"}
0005435612597	DED459	2168 884530	SERGEY NIKOLAEV	{"phone": "+70191876137"}
0005435612598	56D3EC	1102 529571	ALEKSANDR BELOV	{"email": "belov_aleksandr.041968@postgrespro.ru", "phone": "+70087178930"}
0005435612599	2CC951	0939 319746	VITALIY NAUMOV	{"email": "vitaliy-naumov.02071971@postgrespro.ru", "phone": "+70706538909"}
0005435612600	A97D99	8026 126701	DMITRIY BARANOV	{"email": "baranov_dmitriy-30071968@postgrespro.ru", "phone": "+70017115354"}
0005435612601	F4ED91	4057 809255	ALIK NIKOLAEV	{"email": "a_nikolaev22071985@postgrespro.ru", "phone": "+70717127917"}
0005435612602	8977BA	6397 187338	ELENA YAKOVLEVA	{"phone": "+70946814658"}
0005435612603	8977BA	3811 182421	ALEKSANDR DAVYDOV	{"email": "davydov-aleksandr1970@postgrespro.ru", "phone": "+70436550382"}
0005435612604	8977BA	1104 892995	ANNA ALEKSEEVA	{"email": "anna.alekseeva-09071963@postgrespro.ru", "phone": "+70653283139"}
0005435612605	B396B6	0804 785767	MARINA GORBUNOVA	{"email": "gorbunovamarina-16071976@postgrespro.ru", "phone": "+70407542379"}
0005435612606	2FDBD3	4497 417425	ANASTASIYA ALEKSEEVA	{"email": "alekseeva.a.17071959@postgrespro.ru", "phone": "+70520253954"}
0005435612607	AD907C	5774 366612	VASILIY MOROZOV	{"phone": "+70847207182"}
0005435612608	644C46	1503 125451	DENIS DENISOV	{"email": "denis.denisov.1964@postgrespro.ru", "phone": "+70805526710"}
0005435612609	CDF267	3815 163532	YURIY EGOROV	{"email": "egorovyuriy.031972@postgrespro.ru", "phone": "+70792124829"}
0005435612610	6D5186	7134 091715	VERA MOROZOVA	{"email": "veramorozova_01021974@postgrespro.ru", "phone": "+70889574814"}
0005435612611	743463	2349 521048	ELENA FILIPPOVA	{"phone": "+70400562099"}
0005435612612	12F73A	2724 274286	IRINA MIRONOVA	{"phone": "+70346640897"}
0005435612613	FCCB4E	9158 584353	IGOR FOMIN	{"phone": "+70642076736"}
0005435612614	943DD0	0234 393211	ARTEM IVANOV	{"phone": "+70156410891"}
0005435612615	12D412	7077 330704	ALEKSEY SOLOVEV	{"email": "solovevaleksey051961@postgrespro.ru", "phone": "+70050458614"}
0005435612616	8E14FF	6185 282767	IRINA NAZAROVA	{"email": "nazarovai_061982@postgrespro.ru", "phone": "+70584835558"}
0005435612617	8E14FF	7378 947414	SOFYA ROMANOVA	{"phone": "+70231496278"}
0005435612618	A0F303	5810 065131	GALINA FEDOROVA	{"email": "fedorova-galina-07081985@postgrespro.ru", "phone": "+70953888078"}
0005435612619	FE784E	2537 608612	NIKITA KOROLEV	{"email": "korolev-n031983@postgrespro.ru", "phone": "+70913996013"}
0005435612620	0AA07A	9621 486706	LYUDMILA PETROVA	{"phone": "+70421373530"}
0005435612621	0AA07A	9386 216922	EVGENIY KRASNOV	{"phone": "+70299059023"}
0005435612622	AF624A	6419 493089	PETR SEMENOV	{"email": "petrsemenov-1983@postgrespro.ru", "phone": "+70087350474"}
0005435612623	3C0490	5857 775221	MARIYA YUDINA	{"email": "myudina.1979@postgrespro.ru", "phone": "+70475747913"}
0005435612624	3C0490	9938 570020	TATYANA ALEKSANDROVA	{"phone": "+70920485491"}
0005435612625	64CC60	0727 460428	OLGA FEDOROVA	{"email": "o_fedorova-021973@postgrespro.ru", "phone": "+70022106410"}
0005435612626	EA0D3A	9109 406074	MARINA SEMENOVA	{"phone": "+70235521116"}
0005435612627	EA0D3A	0562 171992	ANTON POPOV	{"phone": "+70108131505"}
0005435612628	CD4888	5863 076007	VLADIMIR BORISOV	{"phone": "+70698823865"}
0005435612629	CD4888	2125 501128	ALEKSEY BORISOV	{"email": "alekseyborisov_11021966@postgrespro.ru", "phone": "+70599515067"}
0005435612630	CD4888	7531 207471	NIKOLAY SERGEEV	{"email": "nsergeev_07011966@postgrespro.ru", "phone": "+70323396895"}
0005435612631	E65891	9542 175838	LYUBOV TROFIMOVA	{"email": "trofimova.lyubov1968@postgrespro.ru", "phone": "+70969522322"}
0005435612632	7DA664	1364 691151	DMITRIY GAVRILOV	{"phone": "+70598856605"}
0005435612633	7DA664	2798 560485	LYUDMILA GAVRILOVA	{"phone": "+70605770682"}
0005435612634	0276D6	0970 446139	MAKSIM VLASOV	{"email": "vlasov-m.1967@postgrespro.ru", "phone": "+70845417956"}
0005435612635	0276D6	8200 899554	IVAN PAVLOV	{"email": "pavlov.ivan-28121968@postgrespro.ru", "phone": "+70657127308"}
0005435612636	9A093F	7701 317349	OKSANA KARPOVA	{"phone": "+70220854630"}
0005435612637	4DC1C1	4229 497666	ALINA SERGEEVA	{"phone": "+70512654258"}
0005435612638	4DC1C1	5584 555276	ALISA RYABOVA	{"email": "ryabova.a_081980@postgrespro.ru", "phone": "+70691859615"}
0005435612639	DC7C81	2675 035624	NINA RODIONOVA	{"email": "rodionova.nina-29081971@postgrespro.ru", "phone": "+70803581096"}
0005435612640	52684D	8088 811258	OLGA NOVIKOVA	{"phone": "+70255427474"}
0005435612641	52684D	0760 512996	ELENA NAUMOVA	{"phone": "+70235889762"}
0005435612642	AE4061	9085 666605	MARIYA KOROLEVA	{"phone": "+70915114980"}
0005435612643	D6133A	2259 606300	RUSTAM ANTONOV	{"email": "antonovr_1963@postgrespro.ru", "phone": "+70508612729"}
0005435612644	D6133A	7994 080718	NATALYA MOISEEVA	{"email": "moiseevanatalya28051966@postgrespro.ru", "phone": "+70722298624"}
0005435612645	463C65	5099 751484	ELENA MIKHAYLOVA	{"email": "mikhaylova_e.1965@postgrespro.ru", "phone": "+70523949353"}
0005435612646	9985B5	7619 868807	LIDIYA NIKITINA	{"email": "nikitina_l.121968@postgrespro.ru", "phone": "+70721217552"}
0005435612647	9985B5	0880 879922	OLGA FOMINA	{"email": "fomina.o1964@postgrespro.ru", "phone": "+70873542294"}
0005435612648	9985B5	2868 484581	ALEKSANDRA KOLESNIKOVA	{"phone": "+70729932752"}
0005435612649	8B7DD3	7470 618887	IGOR KUZNECOV	{"email": "kuznecov-igor01041970@postgrespro.ru", "phone": "+70135146071"}
0005435612650	5473DF	2475 040668	ALEKSANDR OSIPOV	{"email": "a.osipov02031975@postgrespro.ru", "phone": "+70996944269"}
0005435612651	085360	2524 166795	LYUBOV MOROZOVA	{"phone": "+70414879808"}
0005435612652	085360	0971 895635	IGOR YAKOVLEV	{"email": "iyakovlev30051965@postgrespro.ru", "phone": "+70981744348"}
0005435612653	8CDB36	2803 430431	ALEKSEY MAKAROV	{"phone": "+70945236322"}
0005435612654	168DFC	2065 689415	NINA MAKAROVA	{"email": "nina-makarova22121967@postgrespro.ru", "phone": "+70260757678"}
0005435612655	168DFC	7448 061561	NATALYA NIKIFOROVA	{"phone": "+70204829249"}
0005435612656	F40D30	6308 727220	KONSTANTIN KAZAKOV	{"email": "k_kazakov.1974@postgrespro.ru", "phone": "+70715094165"}
0005435612657	78DBB6	8635 797104	ALEVTINA ZAYCEVA	{"email": "alevtina.zayceva101973@postgrespro.ru", "phone": "+70759158963"}
0005435612658	8A8B79	9046 604573	ANATOLIY POPOV	{"email": "popovanatoliy-06081983@postgrespro.ru", "phone": "+70549046387"}
0005435612659	8A8B79	6126 584971	VLADISLAV FEDOROV	{"phone": "+70400714585"}
0005435612660	8ADACE	8529 254092	EDUARD SMIRNOV	{"email": "e-smirnov1966@postgrespro.ru", "phone": "+70688329613"}
0005435612661	B18389	1340 614108	EKATERINA GAVRILOVA	{"email": "e-gavrilova.1960@postgrespro.ru", "phone": "+70917862353"}
0005435612662	971AB2	0848 117348	TATYANA AFANASEVA	{"email": "tatyana-afanaseva.041966@postgrespro.ru", "phone": "+70311633026"}
0005435612663	971AB2	0433 604132	EVGENIYA ORLOVA	{"email": "orlova_evgeniya-1983@postgrespro.ru", "phone": "+70577930481"}
0005435612664	AF1900	4354 150400	YURIY POPOV	{"email": "popovy.021971@postgrespro.ru", "phone": "+70102197907"}
0005435612665	AF1900	8069 594480	ANTONINA KOMAROVA	{"phone": "+70557914718"}
0005435612666	77043B	2850 565417	NINA MIRONOVA	{"email": "mironovan091967@postgrespro.ru", "phone": "+70758415445"}
0005435612667	77043B	1853 732568	LIDIYA KOROLEVA	{"phone": "+70473235259"}
0005435612668	4B20FE	8903 836876	RUSHANIYA VASILEVA	{"email": "vasileva.r.29041978@postgrespro.ru", "phone": "+70734048539"}
0005435612779	255237	3048 046599	ANATOLIY SCHERBAKOV	{"phone": "+70549914068"}
0005435612669	1650D5	2113 140518	EVGENIY SOKOLOV	{"email": "sokolov-e-24061984@postgrespro.ru", "phone": "+70643002169"}
0005435612670	E319B2	3702 404631	SERGEY IVANOV	{"email": "ivanov-s.01111967@postgrespro.ru", "phone": "+70515465877"}
0005435612671	F398C7	7973 020889	TATYANA ANTONOVA	{"email": "antonova-tatyana_111981@postgrespro.ru", "phone": "+70806018049"}
0005435612672	AF4B11	1842 650497	LYUBOV FEDOROVA	{"email": "fedoroval_1960@postgrespro.ru", "phone": "+70288651587"}
0005435612673	EF2365	2296 073731	SERGEY FROLOV	{"email": "s-frolov-021972@postgrespro.ru", "phone": "+70276327008"}
0005435612674	7092F2	7350 590486	NINA PAVLOVA	{"phone": "+70530379484"}
0005435612675	504EB8	5544 109117	MARINA POPOVA	{"phone": "+70876153746"}
0005435612676	FD651B	4641 645529	NINA KAZAKOVA	{"phone": "+70990617953"}
0005435612677	FD651B	3259 352647	MIKHAIL SEMENOV	{"phone": "+70250194438"}
0005435612678	6F642C	0368 340792	TAMARA EGOROVA	{"email": "t_egorova.1964@postgrespro.ru", "phone": "+70259694613"}
0005435612679	715AD5	5760 840994	SERGEY NOVIKOV	{"email": "snovikov_25051971@postgrespro.ru", "phone": "+70511306321"}
0005435612680	9A67DB	3543 034847	DMITRIY MIKHAYLOV	{"email": "mikhaylov_d1983@postgrespro.ru", "phone": "+70891172175"}
0005435612681	B3F8DC	8788 783282	NIKOLAY NIKOLAEV	{"email": "nikolaev_nikolay-091969@postgrespro.ru", "phone": "+70201918591"}
0005435612682	B3F8DC	4467 838404	GRIGORIY ILIN	{"phone": "+70489776676"}
0005435612683	F85605	9343 691542	LYUBOV ALEKSANDROVA	{"email": "aleksandrovalyubov_1969@postgrespro.ru", "phone": "+70940153120"}
0005435612684	57AF1F	1039 088126	ALEKSANDRA KONDRATEVA	{"email": "kondrateva_aleksandra031973@postgrespro.ru", "phone": "+70751502723"}
0005435612685	0E3CD7	3051 176035	ALEKSANDR GORBUNOV	{"email": "a-gorbunov.1988@postgrespro.ru", "phone": "+70249006274"}
0005435612686	12B719	5846 286096	POLINA KRASNOVA	{"email": "polina_krasnova-111956@postgrespro.ru", "phone": "+70189061136"}
0005435612687	A9BB42	5856 027482	NIKOLAY OSIPOV	{"phone": "+70439821551"}
0005435612688	427E9E	4327 647600	LYUBOV VLASOVA	{"phone": "+70215081856"}
0005435612689	427E9E	1428 806033	OLEG NAZAROV	{"phone": "+70348621611"}
0005435612690	065EFF	7176 362101	DMITRIY KUZMIN	{"phone": "+70852088932"}
0005435612691	F6F31A	9644 498610	ALEKSANDR FROLOV	{"email": "aleksandr.frolov12091977@postgrespro.ru", "phone": "+70266443054"}
0005435612692	D6B7EC	0424 757873	ALEKSANDR ANTONOV	{"email": "antonov-aleksandr-1977@postgrespro.ru", "phone": "+70068340496"}
0005435612693	D6B7EC	3922 166375	EDUARD NIKOLAEV	{"email": "nikolaev_e071970@postgrespro.ru", "phone": "+70203390942"}
0005435612694	7FD89D	5184 232968	ARTEM SEMENOV	{"phone": "+70542908188"}
0005435612695	FDB32C	8079 432097	VALERIY ANDREEV	{"email": "valeriy_andreev_13091970@postgrespro.ru", "phone": "+70689535089"}
0005435612696	FDB32C	7776 624121	TAMARA MIRONOVA	{"email": "mironovatamara.031969@postgrespro.ru", "phone": "+70108230251"}
0005435612697	F406BA	1506 426060	SERGEY ILIN	{"email": "ilin-sergey061967@postgrespro.ru", "phone": "+70100275205"}
0005435612698	F406BA	5117 521918	MAKSIM PETROV	{"email": "maksimpetrov_091970@postgrespro.ru", "phone": "+70461239335"}
0005435612699	45E673	6043 852071	SERGEY MATVEEV	{"email": "s-matveev011975@postgrespro.ru", "phone": "+70830251784"}
0005435612700	7C89DF	5093 604376	NIKITA TARASOV	{"phone": "+70678645460"}
0005435612701	BDEE8F	1085 325416	VALENTINA SCHERBAKOVA	{"phone": "+70313661077"}
0005435612702	BDEE8F	1494 559228	SERGEY ILIN	{"phone": "+70916735035"}
0005435612703	D087F8	4014 564271	DENIS ALEKSEEV	{"phone": "+70059267940"}
0005435612704	900CFD	2755 312904	BORIS POPOV	{"phone": "+70204136088"}
0005435612705	900CFD	5498 353939	FEDOR PETROV	{"email": "petrov.f-28021972@postgrespro.ru", "phone": "+70209933957"}
0005435612706	B1E219	4035 454868	SERGEY KONOVALOV	{"email": "skonovalov1979@postgrespro.ru", "phone": "+70506313896"}
0005435612707	1DBB10	1169 456329	VALENTINA FILATOVA	{"phone": "+70909702046"}
0005435612708	1DBB10	7508 143894	LYUDMILA MASLOVA	{"email": "lyudmila_maslova1983@postgrespro.ru", "phone": "+70169641804"}
0005435612709	B02067	9428 481763	VALENTINA NESTEROVA	{"email": "valentina-nesterova_1973@postgrespro.ru", "phone": "+70357672191"}
0005435612710	B02067	6681 562301	DMITRIY ZAYCEV	{"email": "dmitriy.zaycev_09101964@postgrespro.ru", "phone": "+70783624081"}
0005435612711	08E9E9	6941 532324	NATALYA POPOVA	{"email": "natalya_popova_1981@postgrespro.ru", "phone": "+70581728389"}
0005435612712	08E9E9	0242 231035	MARINA STEPANOVA	{"email": "stepanovamarina061982@postgrespro.ru", "phone": "+70561191457"}
0005435612713	08E9E9	6630 785701	EVGENIYA MIRONOVA	{"phone": "+70097790784"}
0005435612714	819275	7016 478050	ANDREY STEPANOV	{"phone": "+70430925288"}
0005435612715	819275	8220 887971	ANATOLIY ABRAMOV	{"email": "abramov.anatoliy_20071981@postgrespro.ru", "phone": "+70237811804"}
0005435612716	49CA7A	6713 643744	ALEKSANDR RODIONOV	{"phone": "+70997020101"}
0005435612717	AA58FB	0966 932387	ILYA MOROZOV	{"email": "i-morozov_051974@postgrespro.ru", "phone": "+70667446161"}
0005435612718	AA58FB	9629 464270	ANDREY MARTYNOV	{"phone": "+70364050592"}
0005435612719	692007	0941 095424	NATALYA PETROVA	{"email": "petrova-natalya1979@postgrespro.ru", "phone": "+70384257205"}
0005435612720	692007	5725 772352	ANATOLIY NIKITIN	{"email": "anatoliynikitin_1966@postgrespro.ru", "phone": "+70308085856"}
0005435612721	34D373	5741 555005	ALEKSEY NOVIKOV	{"email": "aleksey_novikov.011970@postgrespro.ru", "phone": "+70749212922"}
0005435612722	34D373	2806 926935	NIKOLAY SOROKIN	{"phone": "+70722155242"}
0005435612723	905F77	5371 522205	TATYANA SEMENOVA	{"phone": "+70968974924"}
0005435612724	D4EC2F	1149 868129	NINA MAKSIMOVA	{"email": "n_maksimova-09091980@postgrespro.ru", "phone": "+70423425669"}
0005435612725	D4EC2F	3580 710068	ANDREY FOMIN	{"email": "a.fomin-11011975@postgrespro.ru", "phone": "+70217761714"}
0005435612726	857A5F	9539 853525	EKATERINA ALEKSEEVA	{"email": "alekseeva.ekaterina.05031981@postgrespro.ru", "phone": "+70739266322"}
0005435612727	BFB0EA	0219 811931	KAROLINA RODIONOVA	{"email": "krodionova11101973@postgrespro.ru", "phone": "+70452140880"}
0005435612728	BFB0EA	6868 992637	NINA EGOROVA	{"phone": "+70194080074"}
0005435612729	DA24DA	9013 144881	ALEKSANDR NAZAROV	{"phone": "+70932155933"}
0005435612730	BF5ED6	4693 266464	SVETLANA STEPANOVA	{"phone": "+70493722284"}
0005435612731	BF5ED6	7282 037550	ANATOLIY ANDREEV	{"phone": "+70070842259"}
0005435612732	B2D617	5346 774245	LYUBOV GAVRILOVA	{"email": "l.gavrilova.011969@postgrespro.ru", "phone": "+70872778197"}
0005435612733	B2D617	1033 434914	DMITRIY SERGEEV	{"email": "sergeev_d11111973@postgrespro.ru", "phone": "+70761948968"}
0005435612734	B78CF3	6091 752363	MAKSIM FILIPPOV	{"email": "m_filippov_1990@postgrespro.ru", "phone": "+70212232951"}
0005435612735	9352CC	4152 103129	EVGENIYA IVANOVA	{"email": "e-ivanova.10051978@postgrespro.ru", "phone": "+70512963317"}
0005435612736	AC464F	6589 870179	PAVEL FROLOV	{"phone": "+70342755971"}
0005435612737	AC464F	0189 619093	OLGA EGOROVA	{"phone": "+70631835926"}
0005435612738	B52997	4383 281615	MIKHAIL IVANOV	{"phone": "+70571528048"}
0005435612739	B52997	8900 143413	ANATOLIY FEDOROV	{"phone": "+70487529118"}
0005435612740	41EB4D	3771 666371	GEORGIY SAVELEV	{"email": "g-savelev-051970@postgrespro.ru", "phone": "+70647136743"}
0005435612741	E38E7D	0643 281716	VLADIMIR ANDREEV	{"email": "vladimir.andreev.17061977@postgrespro.ru", "phone": "+70425810250"}
0005435612742	E38E7D	4996 340860	NADEZHDA EGOROVA	{"email": "n.egorova.23101978@postgrespro.ru", "phone": "+70008062492"}
0005435612743	34F5A5	2043 373048	ALEKSANDR KUZNECOV	{"phone": "+70389858547"}
0005435612744	092437	6643 747459	ELENA DAVYDOVA	{"email": "e.davydova.061992@postgrespro.ru", "phone": "+70451156582"}
0005435612745	22F51F	8901 644805	ALEKSANDR DMITRIEV	{"email": "dmitrieva10031970@postgrespro.ru", "phone": "+70841693567"}
0005435612746	8B225B	1573 930942	TATYANA SERGEEVA	{"phone": "+70175281538"}
0005435612747	8B225B	3441 728032	IRINA SCHERBAKOVA	{"email": "irina_scherbakova-27071959@postgrespro.ru", "phone": "+70913175897"}
0005435612748	216D73	7403 112053	DENIS SERGEEV	{"email": "sergeev.d1967@postgrespro.ru", "phone": "+70589217341"}
0005435612749	216D73	5207 780556	ELENA BARANOVA	{"phone": "+70438070478"}
0005435612750	FA5260	5004 613486	GALINA KOROLEVA	{"phone": "+70018844181"}
0005435612751	267D2F	2476 706110	VERA VOROBEVA	{"email": "v-vorobeva1973@postgrespro.ru", "phone": "+70173998856"}
0005435612752	267D2F	7747 800113	NAZIYA ANDREEVA	{"email": "andreeva.n_23051978@postgrespro.ru", "phone": "+70913648627"}
0005435612753	6A78AA	5956 790475	VIKTORIYA LAZAREVA	{"phone": "+70543894314"}
0005435612754	F4F497	6484 364465	MAKSIM ANDREEV	{"phone": "+70991196870"}
0005435612755	6BEAC7	8972 763383	ANASTASIYA GRISHINA	{"email": "grishina_a1972@postgrespro.ru", "phone": "+70864099420"}
0005435612756	6BEAC7	0355 929730	SERGEY NIKITIN	{"phone": "+70937115403"}
0005435612757	86D03F	2345 670583	VIKTOR MIRONOV	{"email": "mironov_viktor-091964@postgrespro.ru", "phone": "+70266842547"}
0005435612758	86D03F	4250 106400	YANA GUSEVA	{"phone": "+70178093223"}
0005435612759	86D03F	8531 517778	GALINA ABRAMOVA	{"email": "abramovagalina_011983@postgrespro.ru", "phone": "+70154757283"}
0005435612760	46AB02	7928 464348	ERIK KUDRYASHOV	{"email": "kudryashov_e.1968@postgrespro.ru", "phone": "+70212694150"}
0005435612761	46AB02	8867 965836	EGOR ANTONOV	{"email": "antonov_egor-011980@postgrespro.ru", "phone": "+70112747240"}
0005435612762	9BC172	9558 230555	GULSHAT ROMANOVA	{"email": "romanova.gulshat.1979@postgrespro.ru", "phone": "+70432218173"}
0005435612763	90271E	9527 118978	SERGEY SMIRNOV	{"phone": "+70239704441"}
0005435612764	1B50EE	5879 138265	MATVEY MIKHAYLOV	{"email": "m_mikhaylov30111970@postgrespro.ru", "phone": "+70454951704"}
0005435612765	88E257	1023 768892	VALENTINA NAUMOVA	{"email": "naumova-valentina.1974@postgrespro.ru", "phone": "+70647259515"}
0005435612766	E11F6C	1208 967510	NIKOLAY KRASNOV	{"email": "nikolay-krasnov1980@postgrespro.ru", "phone": "+70875914317"}
0005435612767	6A763D	8191 024551	OLEG ORLOV	{"email": "orlov.o_1982@postgrespro.ru", "phone": "+70929953753"}
0005435612768	6A763D	9966 164842	VYACHESLAV OSIPOV	{"email": "vyacheslav.osipov121967@postgrespro.ru", "phone": "+70041671878"}
0005435612769	6A763D	3511 471649	ANDREY KAZAKOV	{"email": "kazakov_andrey-061972@postgrespro.ru", "phone": "+70655155403"}
0005435612770	EBE9A7	4102 684545	ALENA SOLOVEVA	{"phone": "+70681990140"}
0005435612771	376EE4	5287 926391	RIMMA YAKOVLEVA	{"email": "rimma.yakovleva_25051971@postgrespro.ru", "phone": "+70368848130"}
0005435612772	376EE4	6909 822512	TATYANA MOROZOVA	{"email": "morozova.tatyana.18011972@postgrespro.ru", "phone": "+70533680366"}
0005435612773	FB82D0	8382 678276	VITALIY KUZNECOV	{"email": "kuznecovvitaliy.1973@postgrespro.ru", "phone": "+70145985313"}
0005435612774	B2E2FD	1577 582182	NATALIYA KOZLOVA	{"email": "n_kozlova_08041973@postgrespro.ru", "phone": "+70896976730"}
0005435612775	3DF17C	2471 947513	LYUDMILA NIKITINA	{"email": "lnikitina_1966@postgrespro.ru", "phone": "+70848579260"}
0005435612776	3DF17C	7338 531769	ROMAN SOROKIN	{"phone": "+70040452144"}
0005435612777	90EEF7	4145 897664	MARIYA CHERNOVA	{"phone": "+70032809297"}
0005435612778	443B14	8788 855063	YURIY ALEKSANDROV	{"email": "aleksandrov_yuriy_1975@postgrespro.ru", "phone": "+70767236558"}
0005435612780	255237	0496 970708	PAVEL IVANOV	{"phone": "+70396521942"}
0005435612781	1D3060	3220 826287	VIKTOR VASILEV	{"email": "v.vasilev_16111968@postgrespro.ru", "phone": "+70116795781"}
0005435612782	D63D52	3666 245038	MARINA OVCHINNIKOVA	{"phone": "+70261958021"}
0005435612783	A4DD66	4275 897579	KIRILL YAKOVLEV	{"phone": "+70309746846"}
0005435612784	715ADE	4216 269193	MARIYA ZAKHAROVA	{"phone": "+70524365792"}
0005435612785	248A38	5307 976599	ALEKSEY FILIPPOV	{"email": "filippov.a081969@postgrespro.ru", "phone": "+70609854853"}
0005435612786	101718	9033 775742	YULIYA MAKAROVA	{"phone": "+70606457906"}
0005435612787	01B9F7	5747 541774	ANTON SERGEEV	{"phone": "+70007167300"}
0005435612788	01B9F7	1237 182383	NADEZHDA KOVALEVA	{"phone": "+70655641311"}
0005435612789	2F52B6	1494 032467	LYUBOV ANTONOVA	{"email": "lyubovantonova_1981@postgrespro.ru", "phone": "+70129599775"}
0005435612790	83547E	7663 529342	VLADISLAV FEDOROV	{"phone": "+70100842359"}
0005435612791	290AD6	4981 581524	ELLA KISELEVA	{"phone": "+70342725876"}
0005435612792	290AD6	6043 465642	IGOR ALEKSEEV	{"phone": "+70523607695"}
0005435612793	5F2C09	7591 744053	VERA KARPOVA	{"phone": "+70210581873"}
0005435612794	97565C	4675 965756	VLADIMIR PETROV	{"email": "vladimir.petrov.28091967@postgrespro.ru", "phone": "+70814652338"}
0005435612795	FFDB1E	4708 137232	IGOR GAVRILOV	{"phone": "+70075517921"}
0005435612796	1DCC3C	3049 384013	ALFIYA ARKHIPOVA	{"email": "a-arkhipova_1962@postgrespro.ru", "phone": "+70572209578"}
0005435612797	624624	8951 967516	VLADIMIR ROMANOV	{"email": "v_romanov26041985@postgrespro.ru", "phone": "+70715670963"}
0005435612798	624624	9697 897699	ALEKSANDR MIKHAYLOV	{"phone": "+70922395911"}
0005435612799	A3542C	3659 111373	MARINA IVANOVA	{"email": "ivanova-m.19091978@postgrespro.ru", "phone": "+70510026165"}
0005435612800	EA1F7E	5871 639338	ELENA SERGEEVA	{"email": "elenasergeeva_011972@postgrespro.ru", "phone": "+70055876809"}
0005435612801	EA1F7E	9388 895279	VALENTINA EGOROVA	{"email": "v.egorova-22051969@postgrespro.ru", "phone": "+70110995999"}
0005435612802	EA1F7E	3332 272692	VLADIMIR BARANOV	{"phone": "+70491856936"}
0005435612803	E528FE	3908 803664	YURIY SOKOLOV	{"email": "sokolovy_11051964@postgrespro.ru", "phone": "+70764150659"}
0005435612804	8E78D6	8281 156867	ANTONINA CHERNOVA	{"email": "chernovaantonina-051970@postgrespro.ru", "phone": "+70274854541"}
0005435612805	E925B9	7877 194055	ANZHELIKA KISELEVA	{"email": "anzhelika-kiseleva.051972@postgrespro.ru", "phone": "+70808113419"}
0005435612806	53578C	2261 663005	ALEKSANDR ROMANOV	{"phone": "+70219135682"}
0005435612807	20AD2C	9017 218045	NINA BELYAEVA	{"phone": "+70432617139"}
0005435612808	17978F	1456 594320	NATALYA PETROVA	{"email": "petrovan.011967@postgrespro.ru", "phone": "+70999308359"}
0005435612809	53F29C	4809 897027	VYACHESLAV DENISOV	{"phone": "+70834453744"}
0005435612810	53F29C	7323 906960	NINA DENISOVA	{"email": "n-denisova11101979@postgrespro.ru", "phone": "+70629899473"}
0005435612811	BBC0BC	7204 701267	VERA KUZNECOVA	{"email": "v-kuznecova.1974@postgrespro.ru", "phone": "+70023691640"}
0005435612812	3F4A6F	6727 042776	VLADISLAV KUZMIN	{"email": "vladislav-kuzmin.021984@postgrespro.ru", "phone": "+70317998851"}
0005435612813	3F4A6F	6766 502588	MAKSIM KRASNOV	{"email": "maksim-krasnov.081967@postgrespro.ru", "phone": "+70783803751"}
0005435612814	980481	4406 863243	SERGEY STEPANOV	{"phone": "+70191353789"}
0005435612815	980481	5413 136466	VLADIMIR ALEKSEEV	{"email": "alekseev-v_021969@postgrespro.ru", "phone": "+70308518887"}
0005435612816	C3A55E	7775 886992	VERA GAVRILOVA	{"phone": "+70373534261"}
0005435612817	3BCEC8	2750 343359	OLGA KUZNECOVA	{"email": "olgakuznecova091975@postgrespro.ru", "phone": "+70490064533"}
0005435612818	EF81D6	5915 201640	IVAN VOLKOV	{"email": "i-volkov18031970@postgrespro.ru", "phone": "+70120813409"}
0005435612819	D01484	9681 761242	GENNADIY IVANOV	{"email": "gennadiyivanov-26041971@postgrespro.ru", "phone": "+70487123542"}
0005435612820	16B694	6513 439313	KSENIYA CHERNOVA	{"phone": "+70843002764"}
0005435612821	C3C36B	1332 096085	VALENTINA KALININA	{"phone": "+70556609783"}
0005435612822	C3C36B	1298 836557	IRINA KOZLOVA	{"email": "kozlova_i_1977@postgrespro.ru", "phone": "+70913493319"}
0005435612823	A3D4B4	5413 833747	GALINA ILINA	{"email": "ilina-g-1970@postgrespro.ru", "phone": "+70957556852"}
0005435612824	A3D4B4	9833 983206	DARYA FILATOVA	{"phone": "+70172656988"}
0005435612826	BBFF96	8592 613180	ALISA GUSEVA	{"phone": "+70539631105"}
0005435612827	D0D99D	5612 608379	MIKHAIL MAKSIMOV	{"phone": "+70626356348"}
0005435612828	D0D99D	4564 111967	EVGENIY VLASOV	{"phone": "+70668061088"}
0005435612829	D0D99D	3236 053277	SERGEY MIRONOV	{"phone": "+70193763889"}
0005435612830	1B0D98	0227 828403	YULIYA MAKAROVA	{"email": "makarova-yuliya_051979@postgrespro.ru", "phone": "+70720073871"}
0005435612831	1B0D98	8822 366721	TATYANA ROMANOVA	{"phone": "+70993072998"}
0005435612832	1B0D98	7099 231682	VITALIY TARASOV	{"email": "vtarasov.051960@postgrespro.ru", "phone": "+70119825156"}
0005435612833	13E647	4049 317025	VLADIMIR SIDOROV	{"phone": "+70163932775"}
0005435612834	849AA7	0303 900192	ALEKSANDR SMIRNOV	{"phone": "+70279110597"}
0005435612835	849AA7	2036 872689	KLAVDIYA RODIONOVA	{"email": "klavdiyarodionova-08041965@postgrespro.ru", "phone": "+70497215361"}
0005435612836	ED95FA	4980 202979	MARIYA NAZAROVA	{"phone": "+70522444677"}
0005435612837	ED95FA	7747 683524	LYUDMILA MIKHAYLOVA	{"email": "lmikhaylova.1963@postgrespro.ru", "phone": "+70436729836"}
0005435612838	043E03	7958 740363	RAFAIL MIRONOV	{"phone": "+70512670965"}
0005435612839	52507D	7055 054385	NATALYA OSIPOVA	{"email": "osipova.natalya_111979@postgrespro.ru", "phone": "+70632256677"}
0005435612840	8C0D58	8041 553410	IRINA DMITRIEVA	{"phone": "+70938018310"}
0005435612841	2A8D9F	0818 051852	TATYANA NIKOLAEVA	{"email": "nikolaeva_tatyana.1965@postgrespro.ru", "phone": "+70942850402"}
0005435612842	F24F23	3693 467212	LYUDMILA MOROZOVA	{"phone": "+70401668428"}
0005435612843	E99D14	0319 515082	DMITRIY IVANOV	{"email": "d_ivanov.1974@postgrespro.ru", "phone": "+70438062492"}
0005435612844	E99D14	3545 160530	EKATERINA MOROZOVA	{"email": "morozova-ekaterina-1975@postgrespro.ru", "phone": "+70935893940"}
0005435612845	C5CC93	7053 513510	ANATOLIY SAVELEV	{"email": "savelevanatoliy1968@postgrespro.ru", "phone": "+70744305077"}
0005435612846	C5CC93	3425 556475	ALEKSANDR MAKAROV	{"email": "aleksandrmakarov.30041963@postgrespro.ru", "phone": "+70522548759"}
0005435612847	475163	7386 349761	VERA VASILEVA	{"phone": "+70139828813"}
0005435612848	475163	3590 399297	EKATERINA ANISIMOVA	{"phone": "+70050194681"}
0005435612849	EE3103	9330 789443	SERGEY FEDOROV	{"email": "sergey.fedorov-081966@postgrespro.ru", "phone": "+70962116202"}
0005435612850	CD6253	8031 759518	ROZA MIKHAYLOVA	{"email": "mikhaylova-roza1967@postgrespro.ru", "phone": "+70575910548"}
0005435612851	310842	5688 896602	ZOYA SEMENOVA	{"phone": "+70003502213"}
0005435612852	310842	8367 754978	SERAFIMA ALEKSANDROVA	{"email": "aleksandrovaserafima_031968@postgrespro.ru", "phone": "+70166764154"}
0005435612853	B48361	7572 101028	NIKOLAY PETROV	{"phone": "+70885557424"}
0005435612854	F1C20E	0917 914041	ALINA EFREMOVA	{"phone": "+70808653045"}
0005435612855	708A5A	6744 438021	ROMAN ZAKHAROV	{"phone": "+70057836422"}
0005435612856	B70ACC	3099 465933	DENIS NIKOLAEV	{"email": "denisnikolaev.1970@postgrespro.ru", "phone": "+70701342892"}
0005435612857	39B3CE	9793 609447	ALEKSANDR EGOROV	{"phone": "+70774933175"}
0005435612858	1755C0	1575 827921	ALEKSANDR POPOV	{"phone": "+70077834075"}
0005435612859	1755C0	0880 148075	EVGENIY ZHUKOV	{"phone": "+70988712099"}
0005435612860	AC1487	5893 433085	ANDREY ORLOV	{"phone": "+70453475533"}
0005435612861	23891C	0180 430691	POLINA MARTYNOVA	{"phone": "+70933043995"}
0005435612862	2EEE70	5238 215206	ALEKSANDRA KONOVALOVA	{"email": "a-konovalova.19011965@postgrespro.ru", "phone": "+70993518257"}
0005435612863	E91B14	6338 115144	BORIS SIDOROV	{"phone": "+70953408652"}
0005435612864	E91B14	8731 511681	SERGEY CHERNOV	{"phone": "+70389980152"}
0005435612865	A40F4C	5984 633376	VLADIMIR VOLKOV	{"email": "volkovv.111970@postgrespro.ru", "phone": "+70834710495"}
0005435612866	A40F4C	8220 497018	NATALYA ANDREEVA	{"email": "natalya-andreeva_071969@postgrespro.ru", "phone": "+70706242729"}
0005435612867	6F6BDA	6724 223185	OLEG GERASIMOV	{"email": "gerasimovoleg-29041964@postgrespro.ru", "phone": "+70621778240"}
0005435612868	B7A059	8827 643825	VASILIY TARASOV	{"phone": "+70170892314"}
0005435612869	2FAB74	1741 205254	ANTON ZAKHAROV	{"email": "zakharovanton.04101980@postgrespro.ru", "phone": "+70000684835"}
0005435612870	CB89EA	8954 708165	ELENA LEBEDEVA	{"email": "lebedeva_elena.02031978@postgrespro.ru", "phone": "+70154134294"}
0005435612871	08F200	1658 646214	VLADIMIR ORLOV	{"email": "v.orlov19111974@postgrespro.ru", "phone": "+70477447857"}
0005435612872	62D320	3032 793833	ELIZAVETA KONDRATEVA	{"email": "elizavetakondrateva_08111986@postgrespro.ru", "phone": "+70908528171"}
0005435612873	C3C325	5214 077436	TAMARA STEPANOVA	{"phone": "+70072239251"}
0005435612874	E4897D	2777 939782	KONSTANTIN MEDVEDEV	{"email": "k_medvedev_28111968@postgrespro.ru", "phone": "+70738998009"}
0005435612875	E4897D	9663 359067	OLEG MELNIKOV	{"phone": "+70928647947"}
0005435612876	4BD46A	7545 108932	ALENA YAKOVLEVA	{"email": "alenayakovleva_011973@postgrespro.ru", "phone": "+70414471069"}
0005435612877	9C4C97	1568 243353	YURIY BARANOV	{"phone": "+70270322469"}
0005435612878	7E90C2	9667 734022	MARIYA NAZAROVA	{"phone": "+70372218191"}
0005435612879	7E90C2	1058 895288	ARTEM KONOVALOV	{"phone": "+70401427491"}
0005435612880	E9E0AF	9722 052894	EVGENIY KUZNECOV	{"email": "kuznecov-e1968@postgrespro.ru", "phone": "+70898090601"}
0005435612881	7A164E	8266 685621	SVETLANA NIKITINA	{"phone": "+70861995958"}
0005435612882	7A164E	4434 715156	ILYA IVANOV	{"email": "ivanov_ilya-091981@postgrespro.ru", "phone": "+70900840485"}
0005435612883	5E559F	2131 110302	SVETLANA ZHUKOVA	{"email": "szhukova011973@postgrespro.ru", "phone": "+70614485324"}
0005435612884	5E559F	0021 690511	VLADIMIR GORBUNOV	{"phone": "+70071870579"}
0005435612885	5165FA	2889 890995	PAVEL MIKHAYLOV	{"phone": "+70626209336"}
0005435612886	2CE94C	7137 986279	ELENA IVANOVA	{"email": "e-ivanova.11081966@postgrespro.ru", "phone": "+70322683882"}
0005435612887	0DECED	2523 267632	ELIZAVETA FEDOROVA	{"phone": "+70977911823"}
0005435612888	0DECED	1766 495787	SERGEY POPOV	{"phone": "+70781604836"}
0005435612889	C861EB	1017 045677	ALEKSEY SIDOROV	{"phone": "+70374371949"}
0005435612890	A781E3	2486 415592	VLADIMIR BELOV	{"email": "v.belov081977@postgrespro.ru", "phone": "+70167417975"}
0005435612891	243602	3104 482226	LYUCIYA KUZNECOVA	{"email": "l.kuznecova1980@postgrespro.ru", "phone": "+70045252032"}
0005435612892	243602	2813 675775	EKATERINA KOROLEVA	{"phone": "+70775165350"}
0005435612893	243602	3676 899816	EKATERINA GAVRILOVA	{"email": "gavrilova-e_1971@postgrespro.ru", "phone": "+70554925171"}
0005435612894	C78AFC	7177 634568	IRINA ALEKSEEVA	{"phone": "+70274185719"}
0005435612895	C78AFC	8457 817447	TATYANA SAVELEVA	{"email": "tsaveleva.111970@postgrespro.ru", "phone": "+70494272106"}
0005435612896	B4E72E	6187 584270	GEORGIY FILIPPOV	{"email": "filippovg021968@postgrespro.ru", "phone": "+70166917514"}
0005435612897	B4E72E	3597 241067	VLADISLAV VOROBEV	{"email": "vorobevvladislav-1967@postgrespro.ru", "phone": "+70053332643"}
0005435612898	8A2BF6	3207 012831	DMITRIY ANDREEV	{"email": "dmitriy.andreev_111971@postgrespro.ru", "phone": "+70602495787"}
0005435612899	8A2BF6	1682 646861	ELENA MAKSIMOVA	{"email": "maksimova_elena021974@postgrespro.ru", "phone": "+70600719686"}
0005435612900	9C9A1F	3719 340298	IGOR MIKHAYLOV	{"email": "mikhaylov-igor_061970@postgrespro.ru", "phone": "+70024831905"}
0005435612901	3ACA3D	7902 426499	NATALIYA LUKYANOVA	{"phone": "+70293273569"}
0005435612902	3ACA3D	3235 296921	VERA MELNIKOVA	{"phone": "+70761158190"}
0005435612903	36CC2A	4934 830904	PAVEL BORISOV	{"email": "borisovp-1971@postgrespro.ru", "phone": "+70303647418"}
0005435612904	665EEF	1166 805959	DMITRIY KUDRYASHOV	{"email": "kudryashov.dmitriy_07061984@postgrespro.ru", "phone": "+70483822210"}
0005435612905	665EEF	1633 915212	ALENA ALEKSEEVA	{"email": "alena-alekseeva1965@postgrespro.ru", "phone": "+70879938901"}
0005435612906	09C48C	4190 962942	VLADIMIR FEDOROV	{"email": "fedorov_vladimir_06101970@postgrespro.ru", "phone": "+70288961077"}
0005435612907	14FEA6	2975 824801	IGOR TARASOV	{"phone": "+70764782020"}
0005435612908	A2A824	5929 454006	NINA DMITRIEVA	{"email": "ninadmitrieva_05101972@postgrespro.ru", "phone": "+70552513956"}
0005435612909	A2A824	3202 794380	PAVEL KUDRYASHOV	{"phone": "+70410509863"}
0005435612910	AA24CB	9622 350718	PETR SOKOLOV	{"phone": "+70884195640"}
0005435612911	115D5C	5484 537738	ZINAIDA BOGDANOVA	{"phone": "+70778645556"}
0005435612912	B9C98C	6477 673372	SERGEY VASILEV	{"phone": "+70851753355"}
0005435612913	A088C2	4049 496023	LYUDMILA MARTYNOVA	{"email": "lyudmila.martynova-18011975@postgrespro.ru", "phone": "+70555171481"}
0005435612914	B6C3F8	8372 223184	DARYA KOLESNIKOVA	{"phone": "+70249007912"}
0005435612915	B6C3F8	4110 465768	MAKSIM PETROV	{"phone": "+70069043521"}
0005435612916	C77235	3052 425265	NINA KUZNECOVA	{"email": "nina.kuznecova_22111976@postgrespro.ru", "phone": "+70464326887"}
0005435612917	C77235	6439 724730	EKATERINA MOROZOVA	{"phone": "+70315496233"}
0005435612918	2CBE98	8961 807519	ALEKSANDR DAVYDOV	{"email": "aleksandrdavydov021964@postgrespro.ru", "phone": "+70989035471"}
0005435612919	2CBE98	1465 522023	ZINAIDA EGOROVA	{"email": "z_egorova_091972@postgrespro.ru", "phone": "+70979040679"}
0005435612920	BA162C	3667 002550	ARTEM BELOV	{"email": "belovartem19061968@postgrespro.ru", "phone": "+70102225578"}
0005435612921	DDA9A7	8916 231882	ALEKSANDRA IVANOVA	{"phone": "+70082360272"}
0005435612922	DDA9A7	5437 697988	ZULFIYA RYABOVA	{"phone": "+70967146681"}
0005435612923	65FA7E	9263 143248	NIKITA PETROV	{"phone": "+70301229439"}
0005435612924	65FA7E	7129 160653	VALENTINA DAVYDOVA	{"email": "davydova-v.021971@postgrespro.ru", "phone": "+70406286870"}
0005435612925	08083C	1541 674087	ELENA KUZNECOVA	{"phone": "+70797289078"}
0005435612926	CE764D	7492 715579	LYUDMILA SAVELEVA	{"email": "savelevalyudmila-111972@postgrespro.ru", "phone": "+70080528567"}
0005435612927	7D7D62	8250 415612	SERGEY POPOV	{"email": "popovs-12061966@postgrespro.ru", "phone": "+70462847213"}
0005435612928	06B361	3877 122861	SVETLANA ABRAMOVA	{"phone": "+70377899090"}
0005435612929	58BC11	1843 872725	VALENTINA KULIKOVA	{"email": "valentina-kulikova-02081963@postgrespro.ru", "phone": "+70171865970"}
0005435612930	9BC7A0	2233 151279	ELIZAVETA YAKOVLEVA	{"email": "yakovleva_e_12011972@postgrespro.ru", "phone": "+70812007565"}
0005435612931	9BC7A0	8544 665472	KLAVDIYA IVANOVA	{"phone": "+70613131353"}
0005435612932	9BC7A0	5829 833130	TATYANA KAZAKOVA	{"email": "tatyanakazakova.011971@postgrespro.ru", "phone": "+70772799385"}
0005435612933	C232EF	6669 460031	ELENA PAVLOVA	{"phone": "+70036560812"}
0005435612934	C91030	7411 811785	EKATERINA MOROZOVA	{"email": "morozova-e-04091974@postgrespro.ru", "phone": "+70496991468"}
0005435612935	C91030	5099 214862	ELMIRA BOGDANOVA	{"phone": "+70872691980"}
0005435612936	0AA055	7815 734216	BOGDAN MOROZOV	{"phone": "+70636843596"}
0005435612937	4E074B	6361 471036	DENIS MOISEEV	{"phone": "+70534195372"}
0005435612938	4E074B	1791 849320	KARINA OSIPOVA	{"email": "k_osipova29051972@postgrespro.ru", "phone": "+70210872053"}
0005435612939	B4F429	7126 326495	EKATERINA PAVLOVA	{"email": "e.pavlova20031982@postgrespro.ru", "phone": "+70325578334"}
0005435612940	B4F429	2004 092377	ANASTASIYA KOROLEVA	{"phone": "+70325787047"}
0005435612941	AEA10C	2819 930414	MARIYA PETROVA	{"email": "petrova-mariya.081960@postgrespro.ru", "phone": "+70764613523"}
0005435612942	D90EE5	2389 725684	ALEKSANDRA ZAKHAROVA	{"email": "aleksandra_zakharova20111974@postgrespro.ru", "phone": "+70374955870"}
0005435612943	995795	0751 730338	OLGA NAUMOVA	{"phone": "+70771394698"}
0005435612944	234111	3674 824043	ELENA FILIPPOVA	{"phone": "+70589898122"}
0005435612945	234111	8504 472555	MIKHAIL KUZNECOV	{"email": "kuznecov-m.29051985@postgrespro.ru", "phone": "+70562633993"}
0005435612946	36E96A	6199 834350	ANTONINA KONOVALOVA	{"phone": "+70705481869"}
0005435612947	36E96A	4445 447076	NADEZHDA RODIONOVA	{"phone": "+70696499211"}
0005435612948	65B83A	9162 978517	ANTONINA DAVYDOVA	{"phone": "+70977798012"}
0005435612949	72D8E7	8893 287300	GALINA FOMINA	{"phone": "+70663433016"}
0005435612950	9D1699	4559 290069	VLADIMIR PAVLOV	{"email": "pavlovv-17041976@postgrespro.ru", "phone": "+70844950400"}
0005435612951	2C2389	9910 602771	MAKSIM MAKAROV	{"phone": "+70305591623"}
0005435612952	6BC9BB	9203 316051	GENNADIY NOVIKOV	{"phone": "+70715689628"}
0005435612953	6BC9BB	1105 754433	ROMAN NAZAROV	{"email": "romannazarov.081962@postgrespro.ru", "phone": "+70807339590"}
0005435612954	51A6AE	9483 385554	VYACHESLAV ANDREEV	{"email": "andreev.v.09071990@postgrespro.ru", "phone": "+70828369363"}
0005435612955	075062	2969 593216	EKATERINA DENISOVA	{"phone": "+70945932228"}
0005435612956	075062	9265 741665	NELLI BELOVA	{"email": "nbelova1966@postgrespro.ru", "phone": "+70181337256"}
0005435612957	0D01C3	7418 508105	SVETLANA TROFIMOVA	{"phone": "+70297227069"}
0005435612958	213A0D	1779 608760	ANDREY MOISEEV	{"email": "a_moiseev_1968@postgrespro.ru", "phone": "+70380689448"}
0005435612959	7A1C6B	0106 320502	TATYANA MAKAROVA	{"email": "makarova_tatyana_081971@postgrespro.ru", "phone": "+70057566056"}
0005435612960	564DBB	9565 021681	SERGEY ISAEV	{"email": "isaev_s-091963@postgrespro.ru", "phone": "+70785164476"}
0005435612961	356080	5882 997583	LYUBOV IVANOVA	{"phone": "+70823561184"}
0005435612962	F6F57E	1044 453646	VERA SIDOROVA	{"phone": "+70769177838"}
0005435612963	3D1A7E	9505 836130	LARISA ALEKSANDROVA	{"phone": "+70397158804"}
0005435612964	67504E	8708 526482	ALEKSANDR SIDOROV	{"phone": "+70937772437"}
0005435612965	8AFCBD	3468 168196	ALEKSEY PETROV	{"phone": "+70448022095"}
0005435612966	10C9B7	6388 322377	OLGA SEMENOVA	{"phone": "+70018020967"}
0005435612967	4C199C	7511 877070	MARINA KARPOVA	{"phone": "+70101946155"}
0005435612968	42B275	1307 535038	EVGENIY ALEKSEEV	{"email": "alekseev.evgeniy13121969@postgrespro.ru", "phone": "+70125967181"}
0005435612969	FB3029	4895 463080	MARGARITA MOROZOVA	{"phone": "+70583038756"}
0005435612970	A4DBC3	7383 518919	ALEKSANDR KISELEV	{"email": "aleksandr_kiselev121967@postgrespro.ru", "phone": "+70979493236"}
0005435612971	C57825	8738 058880	ELENA KOROLEVA	{"email": "koroleva.elena_1979@postgrespro.ru", "phone": "+70577101881"}
0005435612972	C57825	5201 547871	VALERIY SERGEEV	{"email": "valeriy.sergeev.031978@postgrespro.ru", "phone": "+70803597685"}
0005435612973	833CD3	7887 477857	MARIYA EFIMOVA	{"phone": "+70601517426"}
0005435612974	D651A4	7711 560393	ALEKSEY SAVELEV	{"phone": "+70963336340"}
0005435612975	D651A4	8007 483628	OLGA POPOVA	{"email": "popova.olga29061973@postgrespro.ru", "phone": "+70954576657"}
0005435612976	C32036	3274 438420	SVETLANA SOLOVEVA	{"phone": "+70582928389"}
0005435612977	C32036	3321 151422	VERA KUZNECOVA	{"phone": "+70076325228"}
0005435612978	B7EF1C	2342 433228	DANIL MIKHAYLOV	{"phone": "+70619623280"}
0005435612979	7C6E80	3066 442337	SERGEY NAUMOV	{"email": "naumov-s.1977@postgrespro.ru", "phone": "+70114099879"}
0005435612980	9CA83A	0219 331810	EVGENIY POPOV	{"email": "e-popov13121978@postgrespro.ru", "phone": "+70377946753"}
0005435612981	80CA2C	5383 030489	VLADIMIR ZHURAVLEV	{"phone": "+70729177809"}
0005435612982	03016C	8142 458722	GALINA RYABOVA	{"email": "g.ryabova.1967@postgrespro.ru", "phone": "+70578497150"}
0005435612983	03016C	5114 208576	OLGA MOISEEVA	{"email": "moiseevaolga031978@postgrespro.ru", "phone": "+70497676115"}
0005435612984	857236	0518 189073	ELIZAVETA BARANOVA	{"email": "baranova_e.1962@postgrespro.ru", "phone": "+70377442599"}
0005435612985	88828D	2797 755144	MARINA TARASOVA	{"phone": "+70248272666"}
0005435612986	E90C45	3572 340485	ALEKSANDR FOMIN	{"phone": "+70132555712"}
0005435612987	825829	4742 407885	VYACHESLAV VASILEV	{"phone": "+70733456780"}
0005435612988	88DC72	4402 748624	NIKOLAY KUZMIN	{"email": "kuzmin_nikolay-1974@postgrespro.ru", "phone": "+70719360395"}
0005435612989	C7C7AC	2796 353537	NIKOLAY PETROV	{"email": "petrov_n031966@postgrespro.ru", "phone": "+70537707889"}
0005435612990	4D0D04	3247 115561	GALINA CHERNOVA	{"email": "chernova_g.081964@postgrespro.ru", "phone": "+70320661215"}
0005435612991	F5F54C	1421 572444	TATYANA KONDRATEVA	{"phone": "+70480677280"}
0005435612992	4A2C30	6385 905915	NINA KOMAROVA	{"phone": "+70328648782"}
0005435612993	EB5E75	9619 102533	MARIYA ISAEVA	{"phone": "+70559159423"}
0005435612994	76302F	3842 682485	NIKOLAY KULIKOV	{"phone": "+70541634934"}
0005435612995	76302F	7537 459098	OLEG PETROV	{"phone": "+70826693585"}
0005435612996	C6EF9C	6858 040031	DENIS SEMENOV	{"email": "semenov-d_1977@postgrespro.ru", "phone": "+70078077812"}
0005435612997	68DB23	6152 985075	TATYANA LAZAREVA	{"email": "tatyana-lazareva-24111963@postgrespro.ru", "phone": "+70178082690"}
0005435612998	68DB23	2712 884219	RAISA DMITRIEVA	{"phone": "+70192764605"}
0005435612999	13CA15	8333 630912	IVAN KULIKOV	{"email": "kulikov.i_24091977@postgrespro.ru", "phone": "+70189670377"}
0005435613000	0655F4	2662 078087	OLGA MALYSHEVA	{"phone": "+70612920004"}
0005435613001	0655F4	9469 035153	OLGA BELOVA	{"email": "olga_belova_26071978@postgrespro.ru", "phone": "+70717709849"}
0005435613002	9B099C	6552 128747	SVETLANA KOZLOVA	{"phone": "+70061060877"}
0005435613003	3C5437	7970 679070	MIKHAIL KUZNECOV	{"email": "m_kuznecov-021979@postgrespro.ru", "phone": "+70148122490"}
0005435613004	3C5437	7126 268547	MARINA YAKOVLEVA	{"email": "marina-yakovleva-19121989@postgrespro.ru", "phone": "+70888796901"}
0005435613005	1A9184	3567 587935	NIKITA ALEKSEEV	{"phone": "+70793507192"}
0005435613006	17132E	2174 324301	ILYA PETROV	{"phone": "+70805523053"}
0005435613007	17132E	7009 491560	NIKOLAY ALEKSEEV	{"phone": "+70033572835"}
0005435613008	EEC35B	7235 344195	MAKSIM VLASOV	{"phone": "+70317091947"}
0005435613009	370F2D	7482 148307	LYUDMILA LAZAREVA	{"phone": "+70933685886"}
0005435613010	CC478C	2768 972100	ALEKSANDR POPOV	{"email": "aleksandr.popov04031971@postgrespro.ru", "phone": "+70279214607"}
0005435613011	9583AA	6602 483691	DMITRIY BORISOV	{"email": "borisovdmitriy031959@postgrespro.ru", "phone": "+70434962941"}
0005435613012	AD0F85	0948 010808	ALEKSEY ZHURAVLEV	{"phone": "+70590047505"}
0005435613013	E4ABA8	8352 537194	TAMARA VOLKOVA	{"phone": "+70687695075"}
0005435613014	588547	6063 283150	ANATOLIY KUZNECOV	{"phone": "+70552374810"}
0005435613015	27C100	3749 337037	ANTONINA ABRAMOVA	{"phone": "+70329834676"}
0005435613016	989803	2410 534033	VLADIMIR MELNIKOV	{"email": "melnikov.vladimir.1974@postgrespro.ru", "phone": "+70694370152"}
0005435613017	2C718F	2984 236791	IRINA KOMAROVA	{"email": "komarovairina_1967@postgrespro.ru", "phone": "+70788564360"}
0005435613018	2C718F	9324 802113	GALINA ANTONOVA	{"phone": "+70563228479"}
0005435613019	F2F5F3	7208 137312	OLGA MALYSHEVA	{"phone": "+70122605311"}
0005435613020	3CE3AD	0688 749413	IRINA ARKHIPOVA	{"email": "arkhipova.irina-1969@postgrespro.ru", "phone": "+70847035086"}
0005435613021	3CE3AD	9619 954864	OLGA BORISOVA	{"phone": "+70239554657"}
0005435613022	CDF190	8784 287922	MARIYA KOVALEVA	{"phone": "+70886621425"}
0005435613023	75D59B	8735 153208	RUSLAN BORISOV	{"phone": "+70013192054"}
0005435613024	6D2B96	5076 625430	MIKHAIL NOVIKOV	{"phone": "+70533993747"}
0005435613025	6D2B96	4094 694298	GENNADIY NIKOLAEV	{"phone": "+70811048024"}
0005435613026	10034E	8479 247947	NIKOLAY ZAYCEV	{"email": "zaycev-nikolay_1979@postgrespro.ru", "phone": "+70376641956"}
0005435613027	EE09F7	4856 911156	ILYA FILIPPOV	{"email": "filippov-i021970@postgrespro.ru", "phone": "+70222362561"}
0005435613028	FFEB23	8402 209660	NIKOLAY MATVEEV	{"email": "matveev_n.06041963@postgrespro.ru", "phone": "+70360370557"}
0005435613029	4EA1EB	3732 933814	VIKTOR STEPANOV	{"email": "stepanov_v.19051968@postgrespro.ru", "phone": "+70377364934"}
0005435613030	095EE7	0050 141687	ALEKSANDR SAVELEV	{"email": "a_savelev.061973@postgrespro.ru", "phone": "+70875751366"}
0005435613031	DACE9D	7523 307625	VALENTINA NIKOLAEVA	{"phone": "+70920972040"}
0005435613032	DACE9D	2033 707482	ILYA GORBUNOV	{"email": "gorbunov_ilya_01021976@postgrespro.ru", "phone": "+70507790098"}
0005435613033	DACE9D	9761 249174	TATYANA NAZAROVA	{"phone": "+70050457061"}
0005435613034	DACE9D	6942 278025	EVGENIY CHERNOV	{"email": "chernov-evgeniy1971@postgrespro.ru", "phone": "+70751875447"}
0005435613035	E0CC80	1083 272111	MARIYA ZOTOVA	{"phone": "+70902284192"}
0005435613036	94DBB6	7561 878603	GALINA ZAYCEVA	{"email": "zaycevag_09041974@postgrespro.ru", "phone": "+70014091305"}
0005435613037	418C6D	0929 170632	RAISA MIRONOVA	{"phone": "+70064026107"}
0005435613038	418C6D	5315 485884	VIKTOR POPOV	{"email": "viktor.popov-071963@postgrespro.ru", "phone": "+70907598766"}
0005435613039	1E4493	1007 733308	OLEG POPOV	{"email": "o.popov20101950@postgrespro.ru", "phone": "+70244350756"}
0005435613040	2B8CCB	7820 196854	SERGEY MAKSIMOV	{"email": "maksimovsergey-1975@postgrespro.ru", "phone": "+70423947916"}
0005435613041	0BD73E	8130 194436	OKSANA EFIMOVA	{"email": "oefimova.061978@postgrespro.ru", "phone": "+70693428372"}
0005435613042	0BD73E	0742 401011	OLEG PETROV	{"phone": "+70061226938"}
0005435613043	2857CF	6355 822623	ANDREY DMITRIEV	{"email": "a-dmitriev_08011972@postgrespro.ru", "phone": "+70748447383"}
0005435613044	8188E7	8657 391549	ANASTASIYA NAZAROVA	{"phone": "+70510768944"}
0005435613045	7B5B4F	3714 836636	KSENIYA KOZLOVA	{"email": "k-kozlova-081975@postgrespro.ru", "phone": "+70440834220"}
0005435613046	7B5B4F	5009 280611	LYUDMILA AKIMOVA	{"phone": "+70756214674"}
0005435613047	9AAAE4	2698 380213	ALEKSEY VLASOV	{"email": "vlasov_aleksey-031971@postgrespro.ru", "phone": "+70992636575"}
0005435613048	CEF14F	9020 857764	TATYANA TIKHONOVA	{"email": "t.tikhonova.16011987@postgrespro.ru", "phone": "+70582837343"}
0005435613049	48AC85	5006 500047	VLADISLAV BONDARENKO	{"phone": "+70054448152"}
0005435613050	E29B0F	3733 988099	ALEKSANDR DAVYDOV	{"email": "davydova.051980@postgrespro.ru", "phone": "+70581164463"}
0005435613051	6AEDA1	6930 256186	RIMMA MELNIKOVA	{"phone": "+70461044755"}
0005435613052	CB866E	8397 163687	IGOR PAVLOV	{"email": "i_pavlov-25051975@postgrespro.ru", "phone": "+70226382824"}
0005435613053	1240D9	7099 895690	ALEKSANDR NIKOLAEV	{"phone": "+70511653557"}
0005435613054	1240D9	9279 337748	TATYANA ALEKSEEVA	{"email": "alekseeva_t-09011969@postgrespro.ru", "phone": "+70617820510"}
0005435613055	C84488	6290 833875	ALLA VOROBEVA	{"phone": "+70205340462"}
0005435613056	2072EC	5965 258106	DANILA VOROBEV	{"email": "vorobev.danila.1967@postgrespro.ru", "phone": "+70923592872"}
0005435613057	2072EC	2611 981431	ALEKSANDR BELOV	{"phone": "+70502975912"}
0005435613058	DF3F0E	3699 151158	VASILIY FEDOTOV	{"phone": "+70456486738"}
0005435613059	4E2208	2049 529470	VIKTORIYA ABRAMOVA	{"email": "abramova_viktoriya081980@postgrespro.ru", "phone": "+70414158752"}
0005435613060	4E2208	8681 294848	PETR SMIRNOV	{"phone": "+70368036035"}
0005435613061	A87BBD	0808 311218	MIKHAIL MAKAROV	{"email": "mikhailmakarov.011975@postgrespro.ru", "phone": "+70975513177"}
0005435613062	00A404	5366 492719	ELENA KONOVALOVA	{"phone": "+70818858992"}
0005435613063	00A404	5173 202253	IVAN KONOVALOV	{"phone": "+70291458238"}
0005435613064	3C8EDA	0075 627984	NINA MIRONOVA	{"phone": "+70129687958"}
0005435613065	CBDDCA	3667 915137	SERGEY MAKAROV	{"email": "smakarov.27111977@postgrespro.ru", "phone": "+70664157394"}
0005435613066	7732F1	8382 349114	GALINA MOISEEVA	{"email": "galina_moiseeva_051976@postgrespro.ru", "phone": "+70336440297"}
0005435613067	34A097	5184 074873	ELENA RYABOVA	{"phone": "+70906084547"}
0005435613068	D0CC30	4038 341624	OKSANA AFANASEVA	{"email": "oksana.afanaseva-30071969@postgrespro.ru", "phone": "+70973913244"}
0005435613069	D0CC30	7726 743964	ALEKSANDR FROLOV	{"email": "frolov_aleksandr-10031968@postgrespro.ru", "phone": "+70594081095"}
0005435613070	E67347	2650 839438	MARIYA VASILEVA	{"email": "mvasileva_091975@postgrespro.ru", "phone": "+70435562323"}
0005435613071	261543	5207 465349	NINA POTAPOVA	{"phone": "+70690630840"}
0005435613072	63D7D9	2673 284721	SVETLANA MIKHAYLOVA	{"email": "mikhaylova_svetlana.1974@postgrespro.ru", "phone": "+70171947017"}
0005435613073	A1D379	8825 979077	NATALYA STEPANOVA	{"email": "natalya-stepanova.1973@postgrespro.ru", "phone": "+70913883375"}
0005435613074	D423EA	8847 908270	ALEKSANDR CHERNOV	{"email": "aleksandrchernov_101980@postgrespro.ru", "phone": "+70343266232"}
0005435613075	D423EA	6413 628404	ANDREY ZHURAVLEV	{"email": "zhuravlev_a_1967@postgrespro.ru", "phone": "+70495032184"}
0005435613076	B5FEFE	6611 388550	DANIIL ANTONOV	{"phone": "+70544529573"}
0005435613077	8536B1	3278 506333	ALEKSANDR MOROZOV	{"email": "morozov_a041975@postgrespro.ru", "phone": "+70285584030"}
0005435613078	E87117	7564 360633	TATYANA POPOVA	{"email": "popova-t-1974@postgrespro.ru", "phone": "+70735299019"}
0005435613079	FEB7A4	0980 532687	STEPAN ALEKSEEV	{"email": "alekseev-stepan-02111978@postgrespro.ru", "phone": "+70203363965"}
0005435613080	C8EABF	4073 100149	ANASTASIYA VASILEVA	{"phone": "+70341433925"}
0005435613081	93D9DD	7236 215284	KLAVDIYA ANISIMOVA	{"phone": "+70704064775"}
0005435613082	098130	8721 388001	MAKSIM KUZNECOV	{"email": "m.kuznecov1966@postgrespro.ru", "phone": "+70649846723"}
0005435613083	098130	4378 250772	LIDIYA KOLESNIKOVA	{"email": "kolesnikova.lidiya-23121965@postgrespro.ru", "phone": "+70833595137"}
0005435613084	C09DA7	8718 421030	PETR PETROV	{"phone": "+70547957474"}
0005435613085	7E569E	3279 624957	VIKTOR SOKOLOV	{"phone": "+70266876546"}
0005435613086	2FE477	3661 452862	EVGENIY NAUMOV	{"phone": "+70927153581"}
0005435613087	0F8FA3	2166 009477	IGOR KISELEV	{"phone": "+70285006686"}
0005435613088	FA98F6	6690 439341	NIKITA IVANOV	{"phone": "+70114674527"}
0005435613089	DF0EFB	1027 178892	ALEKSANDRA ZAYCEVA	{"phone": "+70835842067"}
0005435613090	DF0EFB	8616 196947	ALEKSANDR NIKITIN	{"email": "nikitin_a_23041971@postgrespro.ru", "phone": "+70733861807"}
0005435613091	DF0EFB	4067 626833	BORIS VLASOV	{"email": "vlasov.b.1983@postgrespro.ru", "phone": "+70044868626"}
0005435613092	1A48D0	4281 272012	MIKHAIL MIRONOV	{"phone": "+70094636631"}
0005435613093	799EF3	8621 851960	MARIYA ANDREEVA	{"phone": "+70714126059"}
0005435613094	4FD0C1	6851 963610	IRINA RODIONOVA	{"email": "irodionova091968@postgrespro.ru", "phone": "+70811793331"}
0005435613095	4FD0C1	9124 989582	ANNA ABRAMOVA	{"email": "a_abramova.18041965@postgrespro.ru", "phone": "+70226771534"}
0005435613096	B14DD8	0302 167949	VADIM GORBUNOV	{"phone": "+70677072098"}
0005435613097	42E56F	3337 261711	TATYANA SERGEEVA	{"email": "t-sergeeva.1966@postgrespro.ru", "phone": "+70342043660"}
0005435613098	3DEB05	6777 564409	LILIYA SOLOVEVA	{"email": "l.soloveva.29051974@postgrespro.ru", "phone": "+70911769011"}
0005435613099	3DEB05	2822 226999	VYACHESLAV VOROBEV	{"email": "vorobevv-101960@postgrespro.ru", "phone": "+70258804420"}
0005435613100	5041BC	1479 583436	ALEKSANDR VLASOV	{"email": "a-vlasov04121974@postgrespro.ru", "phone": "+70582138030"}
0005435613101	1C20F5	8525 623889	NADEZHDA ERMAKOVA	{"email": "ermakovanadezhda-17031969@postgrespro.ru", "phone": "+70008433389"}
0005435613102	B47D8C	4146 140890	TATYANA PAVLOVA	{"email": "pavlova_t011971@postgrespro.ru", "phone": "+70027842379"}
0005435613103	CF2804	4980 377172	ALEKSEY SIDOROV	{"phone": "+70165282658"}
0005435613104	CF2804	9394 173116	MARIYA KAZAKOVA	{"phone": "+70010175282"}
0005435613105	1C9A37	0996 363529	DARYA DMITRIEVA	{"email": "dmitrieva.darya1974@postgrespro.ru", "phone": "+70826845238"}
0005435613106	F11441	9785 033725	LYUBOV KULIKOVA	{"email": "kulikova-lyubov-021967@postgrespro.ru", "phone": "+70615628180"}
0005435613107	90219C	6577 731577	MIKHAIL KRASNOV	{"email": "mikhail_krasnov-23031972@postgrespro.ru", "phone": "+70338927264"}
0005435613108	F17144	2247 372678	IVAN KUZMIN	{"email": "ivan.kuzmin.10081957@postgrespro.ru", "phone": "+70901064797"}
0005435613109	CE0CE0	8550 146517	NATALYA NAUMOVA	{"email": "naumovanatalya011980@postgrespro.ru", "phone": "+70600299612"}
0005435613110	5623EC	2088 116581	SVETLANA ANISIMOVA	{"email": "anisimova_svetlana03081975@postgrespro.ru", "phone": "+70895848549"}
0005435613111	733F85	3903 130671	TATYANA KOROLEVA	{"email": "korolevat-081976@postgrespro.ru", "phone": "+70275918022"}
0005435613112	FF38E3	7717 925708	ANDREY FOMIN	{"email": "andreyfomin1974@postgrespro.ru", "phone": "+70714473748"}
0005435613113	A9151E	9220 177882	ANZHELIKA ABRAMOVA	{"phone": "+70783226028"}
0005435613114	EED7BB	5115 698160	RIMMA EFREMOVA	{"phone": "+70084172977"}
0005435613115	DC1E3F	6357 693854	TATYANA BARANOVA	{"phone": "+70811832717"}
0005435613116	442AF3	0678 951888	TAISIYA POPOVA	{"phone": "+70884862363"}
0005435613117	5C1B8C	7622 175755	OLGA FOMINA	{"phone": "+70702647073"}
0005435613118	5C1B8C	9858 238005	ELENA KOMAROVA	{"phone": "+70110293022"}
0005435613119	DF7070	7191 635770	VIKTOR GRIGOREV	{"email": "grigorev_viktor.17101967@postgrespro.ru", "phone": "+70564057786"}
0005435613120	DF7070	4782 930246	SERGEY RODIONOV	{"phone": "+70505774377"}
0005435613121	8BFE34	4317 357673	YURIY GORBUNOV	{"email": "gorbunov_yuriy.04071963@postgrespro.ru", "phone": "+70717661900"}
0005435613122	DB6199	7474 887089	NATALYA NIKOLAEVA	{"phone": "+70988435654"}
0005435613123	20585E	3716 295526	MARINA AFANASEVA	{"phone": "+70758179721"}
0005435613124	26BF73	2911 033908	TAISIYA KOROLEVA	{"phone": "+70347534675"}
0005435613125	0F1BF7	0735 374660	ANDREY FOMIN	{"email": "a-fomin-101963@postgrespro.ru", "phone": "+70703035899"}
0005435613126	5339F8	9095 054891	ANDREY ZAKHAROV	{"email": "zakharov_andrey-1971@postgrespro.ru", "phone": "+70686532029"}
0005435613127	969836	0437 550043	MARIYA STEPANOVA	{"phone": "+70396595419"}
0005435613128	6A48B7	9274 904162	STEPAN FILIPPOV	{"email": "filippov-s091960@postgrespro.ru", "phone": "+70087377729"}
0005435613129	1ADA4A	6900 905797	SNEZHANA FROLOVA	{"phone": "+70814259167"}
0005435613130	2C1574	1296 218178	VLADIMIR KARPOV	{"phone": "+70887182031"}
0005435613131	303AEA	3037 996176	VYACHESLAV VOLKOV	{"phone": "+70517765214"}
0005435613132	6A3A4A	9925 068758	DMITRIY BARANOV	{"email": "dmitriy_baranov.1978@postgrespro.ru", "phone": "+70053231991"}
0005435613133	0F18C3	3945 764367	TAMARA RODIONOVA	{"phone": "+70051556119"}
0005435613134	0F18C3	5532 462155	NADEZHDA MEDVEDEVA	{"email": "nadezhda.medvedeva1973@postgrespro.ru", "phone": "+70833366813"}
0005435613135	2DDFFB	6627 747079	LILIYA TARASOVA	{"phone": "+70351826249"}
0005435613136	3A0BDD	6329 598853	ANNA BOGDANOVA	{"email": "abogdanova-111974@postgrespro.ru", "phone": "+70620640534"}
0005435613137	45D7F2	0585 653912	OLEG KUZNECOV	{"phone": "+70144398360"}
0005435613138	DA5EE4	7691 699626	ROMAN YAKOVLEV	{"email": "yakovlev.r-17081972@postgrespro.ru", "phone": "+70404190077"}
0005435613139	F9F8B6	7611 073757	ANNA ALEKSEEVA	{"email": "a-alekseeva05111976@postgrespro.ru", "phone": "+70634670605"}
0005435613140	F9F8B6	8705 841187	VALERIY KUZNECOV	{"email": "kuznecov_valeriy.31101959@postgrespro.ru", "phone": "+70513038790"}
0005435613141	3C8B46	6325 650228	MARINA KOLESNIKOVA	{"email": "kolesnikovamarina_1969@postgrespro.ru", "phone": "+70889616372"}
0005435613142	A3CA11	8514 371251	YURIY VASILEV	{"email": "vasilev_y.1968@postgrespro.ru", "phone": "+70202425088"}
0005435613143	1110E2	7657 465260	VALENTIN PETROV	{"phone": "+70504149118"}
0005435613144	1110E2	3164 883978	MARIYA POTAPOVA	{"email": "potapovam-1964@postgrespro.ru", "phone": "+70644340628"}
0005435613145	3055DB	6246 168657	EVGENIY BORISOV	{"email": "evgeniy.borisov1979@postgrespro.ru", "phone": "+70457531036"}
0005435613146	D115F6	3083 925070	TATYANA VASILEVA	{"email": "t-vasileva.1972@postgrespro.ru", "phone": "+70606198713"}
0005435613147	EF8F47	4369 455513	OLGA NIKITINA	{"email": "o.nikitina-1970@postgrespro.ru", "phone": "+70833112130"}
0005435613148	5F7B10	9826 720728	VLADIMIR MIRONOV	{"phone": "+70413998019"}
0005435613149	5F7B10	2124 409211	ALEKSEY ALEKSANDROV	{"phone": "+70247431090"}
0005435613150	037E7E	6613 542047	OLEG KUZMIN	{"email": "kuzmin_oleg081971@postgrespro.ru", "phone": "+70386311658"}
0005435613151	3D65D3	8889 291865	TATYANA CHERNOVA	{"phone": "+70354209237"}
0005435613152	4B6382	4065 879205	YURIY KARPOV	{"phone": "+70183711958"}
0005435613153	7D17B0	7834 738656	KRISTINA EGOROVA	{"phone": "+70887676600"}
0005435613154	31F3F7	1663 977416	KRISTINA BARANOVA	{"email": "baranova.kristina121965@postgrespro.ru", "phone": "+70442646136"}
0005435613155	11110D	1033 968264	ALEKSEY MAKAROV	{"email": "amakarov_051982@postgrespro.ru", "phone": "+70520268426"}
0005435613156	11110D	6165 222236	OLGA ISAEVA	{"phone": "+70309732415"}
0005435613157	4E5A74	8352 294181	SERGEY KRASNOV	{"email": "s-krasnov-14031975@postgrespro.ru", "phone": "+70267170361"}
0005435613158	4E5A74	2606 326024	ELENA TIMOFEEVA	{"email": "elenatimofeeva1958@postgrespro.ru", "phone": "+70004851590"}
0005435613159	E5D8DF	7567 322441	ANASTASIYA NIKIFOROVA	{"phone": "+70486770292"}
0005435613160	A22628	0316 943678	MARINA VOLKOVA	{"email": "volkova-marina_1975@postgrespro.ru", "phone": "+70828062880"}
0005435613161	444CD8	3141 925024	SERGEY VLASOV	{"phone": "+70746938302"}
0005435613162	444CD8	8606 182149	VALENTIN ANDREEV	{"email": "v_andreev-25091972@postgrespro.ru", "phone": "+70756878120"}
0005435613163	2CA444	8137 789176	TAMARA ARKHIPOVA	{"email": "arkhipova_tamara.1977@postgrespro.ru", "phone": "+70094173003"}
0005435613164	7CC086	3896 611525	ELENA SMIRNOVA	{"email": "e-smirnova.1972@postgrespro.ru", "phone": "+70609041092"}
0005435613165	AB0BCC	9358 498196	PAVEL SIDOROV	{"phone": "+70683843620"}
0005435613166	AB0BCC	2734 164488	VALENTINA VOROBEVA	{"email": "vorobeva-valentina071977@postgrespro.ru", "phone": "+70739485596"}
0005435613167	AB0BCC	0480 149569	ANASTASIYA ANDREEVA	{"phone": "+70630157058"}
0005435613168	58F6B7	5053 823182	MARIYA SMIRNOVA	{"phone": "+70436722066"}
0005435613169	64DBEF	5255 730992	PAVEL BONDARENKO	{"email": "p.bondarenko.1971@postgrespro.ru", "phone": "+70340226416"}
0005435613170	64DBEF	3394 736302	VIKTOR VOROBEV	{"phone": "+70169766949"}
0005435613171	DAB6AD	4888 006059	TATYANA NIKOLAEVA	{"email": "t.nikolaeva_011958@postgrespro.ru", "phone": "+70779809423"}
0005435613172	DAB6AD	8344 328565	SERGEY ANTONOV	{"email": "antonov.sergey_071970@postgrespro.ru", "phone": "+70588711439"}
0005435613173	009EFC	8347 613088	ELENA PAVLOVA	{"phone": "+70126944569"}
0005435613174	22A1C3	2470 233869	DMITRIY PAVLOV	{"email": "pavlov.dmitriy-22041968@postgrespro.ru", "phone": "+70722128658"}
0005435613175	22A1C3	8628 165364	ALEKSEY IVANOV	{"phone": "+70853358272"}
0005435613176	22A1C3	0746 346228	EVGENIY POPOV	{"phone": "+70647659412"}
0005435613177	CEBB9D	1240 606978	KIRILL KRASNOV	{"email": "krasnov_k20091965@postgrespro.ru", "phone": "+70668001351"}
0005435613178	8285C2	2090 181000	ALEKSEY POPOV	{"phone": "+70234399091"}
0005435613179	B2BD69	2158 563393	POLINA EFIMOVA	{"email": "polinaefimova1971@postgrespro.ru", "phone": "+70257500459"}
0005435613180	711704	7662 525607	DMITRIY SOLOVEV	{"email": "solovevdmitriy23071975@postgrespro.ru", "phone": "+70605825000"}
0005435613181	711704	8520 326403	NADIYA ANISIMOVA	{"phone": "+70112564694"}
0005435613182	A636EB	8374 313390	VYACHESLAV BORISOV	{"email": "vyacheslavborisov.031977@postgrespro.ru", "phone": "+70462627348"}
0005435613183	15A365	0894 107189	SNEZHANA FADEEVA	{"email": "fadeeva.snezhana121964@postgrespro.ru", "phone": "+70000592088"}
0005435613184	15A365	4479 659792	VIKTOR VLASOV	{"phone": "+70793309103"}
0005435613185	F3E0CF	6362 761267	SERGEY DAVYDOV	{"email": "davydov.sergey24011972@postgrespro.ru", "phone": "+70719923179"}
0005435613186	F7201C	0757 131294	RIMMA ZAYCEVA	{"email": "rzayceva.1960@postgrespro.ru", "phone": "+70995921182"}
0005435613187	87881D	9482 770035	EVGENIY FOMIN	{"email": "e.fomin19101975@postgrespro.ru", "phone": "+70751662607"}
0005435613188	87881D	0768 497110	ROMAN CHERNOV	{"email": "chernov_r30011959@postgrespro.ru", "phone": "+70421792278"}
0005435613189	25EDDA	3536 132987	ANDREY FOMIN	{"email": "fomin-a.28081968@postgrespro.ru", "phone": "+70183468374"}
0005435613190	4CA976	1637 418668	ALEKSANDR IVANOV	{"email": "aleksandr-ivanov.09091980@postgrespro.ru", "phone": "+70343206816"}
0005435613191	488435	1425 580718	OKSANA KOZLOVA	{"email": "oksanakozlova061974@postgrespro.ru", "phone": "+70224257843"}
0005435613192	3E0A49	5042 716793	ALEKSEY FOMIN	{"phone": "+70550411831"}
0005435613193	6832B0	7553 760752	ALIYA SIDOROVA	{"email": "sidorova_a_25021981@postgrespro.ru", "phone": "+70722868332"}
0005435613194	899E87	4613 726790	ELENA NESTEROVA	{"phone": "+70157611641"}
0005435613195	AEFDE2	1876 300335	PETR IVANOV	{"phone": "+70964712930"}
0005435613196	E2F63A	7699 283225	VIKTOR KOZLOV	{"email": "kozlov_v07121979@postgrespro.ru", "phone": "+70320490259"}
0005435613197	E2F63A	8951 437923	MARINA ALEKSEEVA	{"phone": "+70939790078"}
0005435613198	EB915F	3202 503378	RUSLAN ZAKHAROV	{"phone": "+70729161209"}
0005435613199	B0F1A4	3421 039055	VALENTIN FEDOROV	{"email": "fedorov_valentin-28081976@postgrespro.ru", "phone": "+70328073324"}
0005435613200	B0F1A4	7513 854661	ALEKSANDR ZAKHAROV	{"phone": "+70537093978"}
0005435613201	0C916D	8895 822987	YANA PAVLOVA	{"email": "pavlovay-011983@postgrespro.ru", "phone": "+70144401310"}
0005435613202	2B89BA	0204 507236	ALEKSANDR TIMOFEEV	{"phone": "+70676027627"}
0005435613203	2B89BA	7815 551463	ALEKSANDR KONOVALOV	{"email": "konovalov_a_26101974@postgrespro.ru", "phone": "+70214287924"}
0005435613204	7DE09A	5250 135687	ALENA VOLKOVA	{"email": "a-volkova.21091959@postgrespro.ru", "phone": "+70184120014"}
0005435613205	CAB012	6791 610627	ARKADIY GAVRILOV	{"phone": "+70822501309"}
0005435613206	B6508C	6901 368009	ELIZAVETA ANDREEVA	{"email": "andreeva_e_041975@postgrespro.ru", "phone": "+70018105920"}
0005435613207	2E7667	4391 384336	MARIYA KOVALEVA	{"phone": "+70816271262"}
0005435613208	9CDF07	0667 209287	VALERIY ZAKHAROV	{"phone": "+70715747661"}
0005435613209	9CDF07	1433 900107	VIKTOR MIKHAYLOV	{"email": "v.mikhaylov1987@postgrespro.ru", "phone": "+70529922876"}
0005435613210	BC55C9	1710 559968	MIKHAIL EGOROV	{"email": "mikhail-egorov_1970@postgrespro.ru", "phone": "+70733643887"}
0005435613211	4DCE14	4750 959585	BORIS ROMANOV	{"phone": "+70972438781"}
0005435613212	EEF88A	4627 090058	ANNA KOMAROVA	{"phone": "+70280632279"}
0005435613213	EEF88A	5003 443480	ELENA EFREMOVA	{"email": "efremova-elena.12111983@postgrespro.ru", "phone": "+70981916488"}
0005435613214	80E532	8752 029765	LILIYA SERGEEVA	{"phone": "+70855237868"}
0005435613215	A00994	0799 675566	ELENA NESTEROVA	{"phone": "+70662860093"}
0005435613216	A00994	8549 530938	ALEKSANDR ANDREEV	{"email": "andreev_aleksandr-28061980@postgrespro.ru", "phone": "+70137749642"}
0005435613217	A00994	2221 493496	EVGENIY MAKAROV	{"phone": "+70086580559"}
0005435613218	F42730	0136 858066	YURIY VASILEV	{"email": "y_vasilev-081977@postgrespro.ru", "phone": "+70147490260"}
0005435613219	6D85ED	1557 917245	ALEKSANDRA KOLESNIKOVA	{"phone": "+70147254632"}
0005435613220	6D85ED	5125 875827	NIKOLAY MIRONOV	{"email": "mironov.nikolay1973@postgrespro.ru", "phone": "+70124965849"}
0005435613221	9689F9	4522 397875	ELENA GERASIMOVA	{"email": "gerasimova_elena_1963@postgrespro.ru", "phone": "+70670688206"}
0005435613222	9689F9	0245 948428	NATALIYA NAZAROVA	{"phone": "+70432827421"}
0005435613223	4140C9	5780 263994	VLADIMIR KUZMIN	{"email": "kuzmin-vladimir061972@postgrespro.ru", "phone": "+70856350219"}
0005435613224	533949	9447 621484	DANILA ALEKSANDROV	{"phone": "+70555912958"}
0005435613225	164688	3248 944988	EKATERINA EFREMOVA	{"email": "efremova-e1981@postgrespro.ru", "phone": "+70180321129"}
0005435613226	7D2310	5113 581441	OLEG YAKOVLEV	{"email": "yakovlevo-23041994@postgrespro.ru", "phone": "+70503188867"}
0005435613227	24F1AF	8938 809739	ANNA MAKAROVA	{"email": "makarovaa-30031981@postgrespro.ru", "phone": "+70013470983"}
0005435613393	6E3414	7727 849030	ALEKSANDRA YAKOVLEVA	{"phone": "+70725889640"}
0005435613228	D8A396	8414 390820	NATALYA ALEKSANDROVA	{"email": "aleksandrova-natalya.1964@postgrespro.ru", "phone": "+70513258561"}
0005435613229	D8A396	7382 776025	VITALIY DMITRIEV	{"phone": "+70882402259"}
0005435613230	401B03	9633 984492	OLEG KISELEV	{"email": "olegkiselev-27121972@postgrespro.ru", "phone": "+70787184986"}
0005435613231	401B03	6618 216499	ANDREY EGOROV	{"phone": "+70217241655"}
0005435613232	1FE3DE	9479 379377	ALINA GRISHINA	{"email": "alinagrishina_071970@postgrespro.ru", "phone": "+70663418557"}
0005435613233	7BFB81	3219 348519	VASILISA ANISIMOVA	{"phone": "+70628248928"}
0005435613234	1ADB0B	7318 661034	DMITRIY SOKOLOV	{"phone": "+70335118764"}
0005435613235	1ADB0B	6136 820147	SERGEY MOROZOV	{"phone": "+70297732845"}
0005435613236	6A7909	2642 958073	MIKHAIL DENISOV	{"email": "denisov.mikhail.01061968@postgrespro.ru", "phone": "+70630677044"}
0005435613237	59C3E2	6043 276437	ALEKSANDR GORBUNOV	{"email": "a-gorbunov_121978@postgrespro.ru", "phone": "+70298311485"}
0005435613238	9EB7B5	8151 505352	ROMAN NIKOLAEV	{"phone": "+70248205379"}
0005435613239	9EB7B5	1684 054214	TATYANA DENISOVA	{"phone": "+70401534654"}
0005435613240	E22778	1887 040136	STEPAN FEDOROV	{"email": "fedorovstepan-101960@postgrespro.ru", "phone": "+70593609102"}
0005435613241	E22778	3813 750882	KONSTANTIN ZHURAVLEV	{"phone": "+70473783804"}
0005435613242	86765B	5580 493382	YANA LEBEDEVA	{"phone": "+70575476196"}
0005435613243	3480DB	8205 828325	VALERIY ZHURAVLEV	{"phone": "+70249443803"}
0005435613244	B88D70	6854 449079	ANATOLIY KRASNOV	{"phone": "+70068701906"}
0005435613245	30E255	5538 624664	TATYANA MASLOVA	{"email": "maslovat.1980@postgrespro.ru", "phone": "+70025525584"}
0005435613246	7038B4	6826 127999	VALERIY GORBUNOV	{"email": "gorbunovvaleriy.27091957@postgrespro.ru", "phone": "+70823088305"}
0005435613247	8097FC	5016 928799	IRINA KUZNECOVA	{"email": "irina-kuznecova_17111966@postgrespro.ru", "phone": "+70376990272"}
0005435613248	B48EB7	0499 903332	ANATOLIY ANDREEV	{"phone": "+70222261917"}
0005435613249	2E52AB	5847 306547	DARYA FEDOROVA	{"email": "darya_fedorova.22061964@postgrespro.ru", "phone": "+70994551472"}
0005435613250	2E52AB	9752 454875	ALEVTINA SOKOLOVA	{"email": "a_sokolova081965@postgrespro.ru", "phone": "+70528117750"}
0005435613251	0A658B	9000 249969	TATYANA MAKSIMOVA	{"email": "maksimova_tatyana.1973@postgrespro.ru", "phone": "+70669573049"}
0005435613252	4E01B2	3798 389604	ELENA STEPANOVA	{"email": "stepanova.elena-011973@postgrespro.ru", "phone": "+70711150240"}
0005435613253	A28AD0	7164 702545	PAVEL KUZMIN	{"email": "kuzmin_p1968@postgrespro.ru", "phone": "+70915420699"}
0005435613254	A28AD0	6984 341277	IRAIDA ZAYCEVA	{"phone": "+70967529072"}
0005435613255	9CFE90	6104 783246	GALINA EGOROVA	{"email": "egorova-galina.30051965@postgrespro.ru", "phone": "+70119333902"}
0005435613256	00C758	8759 834213	PAVEL SAVELEV	{"email": "pavel.savelev04071965@postgrespro.ru", "phone": "+70530636130"}
0005435613257	6E93CD	9603 061258	VALENTIN FEDOTOV	{"email": "valentin.fedotov071965@postgrespro.ru", "phone": "+70452233501"}
0005435613258	ADAEB2	4099 616753	POLINA CHERNOVA	{"email": "chernova-polina.041971@postgrespro.ru", "phone": "+70510243839"}
0005435613259	455EAF	4789 808759	GRIGORIY ANTONOV	{"email": "grigoriy_antonov-1968@postgrespro.ru", "phone": "+70800434329"}
0005435613260	614A8B	3319 655414	VLADIMIR KRASNOV	{"email": "v_krasnov.1978@postgrespro.ru", "phone": "+70242727997"}
0005435613261	1A6845	0213 855225	ANDREY KISELEV	{"email": "kiselev-andrey-1977@postgrespro.ru", "phone": "+70630670535"}
0005435613262	1A6845	7397 224949	LYUDMILA FADEEVA	{"email": "fadeeva-l_1982@postgrespro.ru", "phone": "+70339016368"}
0005435613263	185DEE	6296 062658	PAVEL SERGEEV	{"email": "sergeevp.31101981@postgrespro.ru", "phone": "+70049240763"}
0005435613264	F9B6A8	3679 433411	KONSTANTIN MELNIKOV	{"phone": "+70694777058"}
0005435613265	45DC26	8129 536189	ALEKSANDRA ZAKHAROVA	{"email": "zakharova_aleksandra1963@postgrespro.ru", "phone": "+70709477452"}
0005435613266	ADEE51	0677 621089	SVETLANA BOGDANOVA	{"phone": "+70017907148"}
0005435613267	1847E0	7822 402650	ELENA SMIRNOVA	{"phone": "+70119872436"}
0005435613268	291323	2238 582944	NADEZHDA MIKHAYLOVA	{"email": "nadezhda.mikhaylova_061973@postgrespro.ru", "phone": "+70428092437"}
0005435613269	F8F3AE	0530 363808	MARIYA MOROZOVA	{"email": "mariya.morozova07091971@postgrespro.ru", "phone": "+70951240650"}
0005435613270	26A902	4650 261611	DMITRIY PETROV	{"phone": "+70448601721"}
0005435613271	1AD803	1858 849237	TATYANA ZHURAVLEVA	{"email": "zhuravlevatatyana.111982@postgrespro.ru", "phone": "+70726852599"}
0005435613272	21E647	5330 486204	MARINA PETROVA	{"email": "petrovamarina-11031962@postgrespro.ru", "phone": "+70609651188"}
0005435613273	21E647	5790 565801	ANASTASIYA MAKAROVA	{"email": "makarovaanastasiya_1970@postgrespro.ru", "phone": "+70371469466"}
0005435613274	529F40	9359 032302	MAKSIM IVANOV	{"phone": "+70886450888"}
0005435613275	529F40	5831 235761	NIKITA VOLKOV	{"phone": "+70090814523"}
0005435613276	75BDBF	7088 262762	SERGEY GRIGOREV	{"phone": "+70261428646"}
0005435613277	ECE4E2	1306 897886	LYUDMILA AKIMOVA	{"phone": "+70835056649"}
0005435613278	845B7B	4031 053582	VIKTOR ILIN	{"email": "ilin_viktor-111975@postgrespro.ru", "phone": "+70476145101"}
0005435613279	E81675	7299 963445	NIKOLAY AFANASEV	{"email": "n.afanasev081970@postgrespro.ru", "phone": "+70834745214"}
0005435613280	E81675	9503 627068	NIKITA FILIPPOV	{"email": "filippov.nikita.05051960@postgrespro.ru", "phone": "+70494535446"}
0005435613281	863FE4	6432 675098	ALEKSANDR ISAEV	{"email": "isaev-aleksandr101977@postgrespro.ru", "phone": "+70947956396"}
0005435613282	AC4E91	0538 416597	ANTON YAKOVLEV	{"phone": "+70961141539"}
0005435613283	3524F6	3147 313385	RUSLAN KAZAKOV	{"email": "rkazakov.051973@postgrespro.ru", "phone": "+70148332236"}
0005435613284	D46BF9	3623 292124	VALENTINA GORBUNOVA	{"phone": "+70775741805"}
0005435613285	179B87	8004 023274	SERGEY SMIRNOV	{"phone": "+70408890123"}
0005435613286	179B87	4469 410252	GALINA ZAYCEVA	{"email": "galina_zayceva_1961@postgrespro.ru", "phone": "+70430664385"}
0005435613287	DBB72A	0039 888999	IGOR KOROLEV	{"email": "korolevi121972@postgrespro.ru", "phone": "+70211686655"}
0005435613288	DBB72A	4083 333355	OKSANA FOMINA	{"email": "ofomina_25051967@postgrespro.ru", "phone": "+70886829890"}
0005435613289	F774D9	7369 461755	MARIYA CHERNOVA	{"phone": "+70457998039"}
0005435613290	EACFC8	9779 528838	ELENA RODIONOVA	{"phone": "+70216690105"}
0005435613291	4AD62E	6638 665836	ALEKSEY NIKOLAEV	{"phone": "+70693968722"}
0005435613292	4AD62E	6887 627045	ELENA MAKAROVA	{"email": "makarova_elena-101979@postgrespro.ru", "phone": "+70893432555"}
0005435613293	2C05F7	8316 332128	SVYATOSLAV DENISOV	{"email": "svyatoslavdenisov_01031970@postgrespro.ru", "phone": "+70667122000"}
0005435613294	2C05F7	6770 114245	DARYA MOROZOVA	{"phone": "+70956345088"}
0005435613295	9C09C4	6163 790208	SERAFIMA PETROVA	{"phone": "+70874546023"}
0005435613296	9C09C4	7114 246135	ELENA KOZLOVA	{"email": "e_kozlova.26021970@postgrespro.ru", "phone": "+70567843338"}
0005435613297	0336F4	5419 785085	NINA FADEEVA	{"phone": "+70163325506"}
0005435613298	4FFE4D	0200 510934	VALERIY KOZLOV	{"email": "kozlov-v1974@postgrespro.ru", "phone": "+70500833681"}
0005435613299	4FFE4D	1700 177466	GALINA BORISOVA	{"email": "g_borisova_17041967@postgrespro.ru", "phone": "+70098849368"}
0005435613300	1BF8FA	6619 739028	ANATOLIY ROMANOV	{"email": "a-romanov_1967@postgrespro.ru", "phone": "+70718970301"}
0005435613301	227CB6	9321 969285	LYUDMILA YUDINA	{"email": "lyudmila-yudina-1962@postgrespro.ru", "phone": "+70796565604"}
0005435613302	227CB6	6942 198349	SERGEY KUZNECOV	{"phone": "+70795444399"}
0005435613303	8B01A9	3387 807186	VALENTINA VOLKOVA	{"email": "valentina-volkova_23071981@postgrespro.ru", "phone": "+70758384484"}
0005435613304	9F84CA	3625 865510	RAMIL CHERNOV	{"email": "rchernov.16061973@postgrespro.ru", "phone": "+70919426481"}
0005435613305	F57499	6203 050879	ALEKSANDR PAVLOV	{"email": "pavlov_aleksandr-1962@postgrespro.ru", "phone": "+70412808558"}
0005435613306	76387B	6265 755427	ANTON KUZMIN	{"email": "anton-kuzmin-061975@postgrespro.ru", "phone": "+70390724719"}
0005435613307	76387B	6837 863466	ELENA KULIKOVA	{"phone": "+70243132836"}
0005435613308	D95207	9425 671513	EVDOKIYA MATVEEVA	{"phone": "+70755535312"}
0005435613309	08484E	4822 223938	DENIS PAVLOV	{"phone": "+70726124180"}
0005435613310	08484E	3957 126773	NATALYA BELOVA	{"phone": "+70764506702"}
0005435613311	ABBAFF	5789 745128	ELENA PETROVA	{"email": "petrova-elena-01051971@postgrespro.ru", "phone": "+70028692670"}
0005435613312	ABBAFF	0936 482025	ALEKSANDRA SEMENOVA	{"phone": "+70036283519"}
0005435613313	9A67AD	5201 732378	KAMIL DAVYDOV	{"email": "davydov_kamil051983@postgrespro.ru", "phone": "+70256404107"}
0005435613314	4AFAAA	0585 783192	IRINA POTAPOVA	{"email": "potapova-i-05011969@postgrespro.ru", "phone": "+70290415014"}
0005435613315	4AFAAA	2445 434144	VLADISLAV NIKITIN	{"email": "vladislavnikitin-23111968@postgrespro.ru", "phone": "+70914319031"}
0005435613316	842007	9023 690169	YURIY MAKAROV	{"email": "yuriy_makarov_081973@postgrespro.ru", "phone": "+70637729475"}
0005435613317	36EF9B	0789 941233	VIKTORIYA MIKHAYLOVA	{"email": "mikhaylova.viktoriya-031974@postgrespro.ru", "phone": "+70691264668"}
0005435613318	FA8DE1	8483 944541	NATALYA OVCHINNIKOVA	{"phone": "+70044408083"}
0005435613319	93512A	7664 286753	VLADIMIR MAKSIMOV	{"email": "maksimovvladimir-01081983@postgrespro.ru", "phone": "+70194465213"}
0005435613320	93512A	5072 860156	VLADIMIR POPOV	{"email": "popovvladimir-1978@postgrespro.ru", "phone": "+70670593273"}
0005435613321	E79865	0586 060905	VADIM FEDOROV	{"email": "fedorovv_091976@postgrespro.ru", "phone": "+70293188004"}
0005435613322	20F4D2	6771 114779	ILYA FEDOROV	{"email": "i.fedorov-021983@postgrespro.ru", "phone": "+70608700583"}
0005435613323	5E2279	7388 635000	YURIY ANTONOV	{"phone": "+70577734546"}
0005435613324	5E2279	7052 978298	ELENA PAVLOVA	{"email": "pavlova_elena.021979@postgrespro.ru", "phone": "+70274469992"}
0005435613325	DBAE97	6964 490726	OLGA KULIKOVA	{"email": "kulikova.olga.12051967@postgrespro.ru", "phone": "+70523506409"}
0005435613326	DBAE97	0003 218233	ELENA KONDRATEVA	{"email": "kondratevaelena-21021976@postgrespro.ru", "phone": "+70576159606"}
0005435613327	2FBA85	7022 016613	SERGEY KISELEV	{"email": "kiselev.sergey101976@postgrespro.ru", "phone": "+70185827367"}
0005435613328	64E9AF	0526 825865	SERGEY DENISOV	{"email": "sergey-denisov-11091960@postgrespro.ru", "phone": "+70824669281"}
0005435613329	64E9AF	4167 584513	MARIYA KULIKOVA	{"phone": "+70882974450"}
0005435613330	FF0BEA	7228 246893	MARAT POPOV	{"email": "popov-m-061985@postgrespro.ru", "phone": "+70775007440"}
0005435613331	C1E32F	6385 333929	ALEKSANDR SOLOVEV	{"phone": "+70931951220"}
0005435613332	863C90	6046 778084	VLADIMIR ALEKSEEV	{"email": "v.alekseev_28051971@postgrespro.ru", "phone": "+70886968931"}
0005435613333	863C90	5727 713214	TATYANA NIKITINA	{"phone": "+70667202756"}
0005435613334	863C90	2903 525770	SERGEY GORBUNOV	{"phone": "+70735133001"}
0005435613335	B80F39	1998 735212	NADEZHDA NESTEROVA	{"email": "nesterova-nadezhda_13061978@postgrespro.ru", "phone": "+70682147137"}
0005435613336	B31696	2730 768118	OKSANA GORBUNOVA	{"phone": "+70482325562"}
0005435613337	A5FACC	6086 866036	ALEKSANDR BONDARENKO	{"phone": "+70320882484"}
0005435613338	4DEC0C	5537 670111	ALEKSEY MELNIKOV	{"email": "melnikov-a_061968@postgrespro.ru", "phone": "+70255639756"}
0005435613339	4DEC0C	7982 995254	MARIYA ROMANOVA	{"email": "m-romanova-1969@postgrespro.ru", "phone": "+70100996787"}
0005435613340	D9CCE2	2991 760041	SVETLANA FEDOROVA	{"phone": "+70602756205"}
0005435613341	DD5913	3930 724461	YULIYA KOZLOVA	{"email": "kozlova-yuliya051993@postgrespro.ru", "phone": "+70024245664"}
0005435613342	DD5913	8272 352601	RADIK NAZAROV	{"email": "nazarov.r_15071970@postgrespro.ru", "phone": "+70312844566"}
0005435613343	E0CC23	1665 711112	SEMEN STEPANOV	{"email": "stepanov_s.031968@postgrespro.ru", "phone": "+70185533550"}
0005435613344	2FDB38	1899 162060	ALEKSANDR GRIGOREV	{"phone": "+70883731393"}
0005435613345	B83130	0528 067107	VALENTINA VASILEVA	{"phone": "+70513830898"}
0005435613346	B83130	8429 602040	LIDIYA SMIRNOVA	{"email": "lidiya.smirnova101976@postgrespro.ru", "phone": "+70729103318"}
0005435613347	B83130	4555 170609	VLADIMIR VOROBEV	{"email": "vladimirvorobev.28111963@postgrespro.ru", "phone": "+70715763001"}
0005435613348	B83130	3711 464115	ANATOLIY BELOV	{"phone": "+70621259599"}
0005435613349	03A58F	6183 517422	SERGEY KAZAKOV	{"phone": "+70586457312"}
0005435613350	889BA5	0898 992650	IGOR OSIPOV	{"email": "osipov-i091968@postgrespro.ru", "phone": "+70296402497"}
0005435613351	62EBD8	9624 375432	VIKTOR SHEVCHENKO	{"email": "shevchenkoviktor-1982@postgrespro.ru", "phone": "+70010596161"}
0005435613352	FD1DDB	2755 829087	NATALYA MEDVEDEVA	{"email": "medvedeva_natalya051983@postgrespro.ru", "phone": "+70818928139"}
0005435613353	FD1DDB	4877 694687	ANDREY YAKOVLEV	{"phone": "+70735869913"}
0005435613354	FD1DDB	4956 585001	NATALYA ROMANOVA	{"email": "romanova-natalya_031980@postgrespro.ru", "phone": "+70309845081"}
0005435613355	D2A4FA	9084 895853	GENNADIY FILIPPOV	{"email": "gennadiy_filippov_1993@postgrespro.ru", "phone": "+70468024059"}
0005435613356	853BE9	2103 000053	SERGEY AFANASEV	{"email": "afanasev.s.051960@postgrespro.ru", "phone": "+70501474803"}
0005435613357	B6B281	8710 796212	ANASTASIYA IVANOVA	{"phone": "+70263255447"}
0005435613358	5E10CC	4031 918743	NATALYA SIDOROVA	{"phone": "+70695828867"}
0005435613359	5E10CC	7714 986957	TAMARA KUDRYASHOVA	{"phone": "+70478761873"}
0005435613360	A280EA	5343 627734	MARINA MOROZOVA	{"email": "morozova_marina1960@postgrespro.ru", "phone": "+70802001561"}
0005435613361	7C11A3	3546 784244	ALEKSANDR KARPOV	{"email": "aleksandr_karpov_031970@postgrespro.ru", "phone": "+70649835981"}
0005435613362	131C68	9601 322190	TATYANA ANDREEVA	{"email": "tandreeva1961@postgrespro.ru", "phone": "+70787985121"}
0005435613363	9CF764	3297 946812	MIKHAIL TIKHONOV	{"phone": "+70590977628"}
0005435613364	34F229	6857 060543	OKSANA SCHERBAKOVA	{"email": "scherbakova.oksana101982@postgrespro.ru", "phone": "+70017461726"}
0005435613365	40470F	9118 573133	VERA DMITRIEVA	{"phone": "+70052277422"}
0005435613366	40470F	2897 095666	ANDREY ZHUKOV	{"phone": "+70653770560"}
0005435613367	F47211	0154 633226	LARISA KOLESNIKOVA	{"phone": "+70096759419"}
0005435613368	F47211	8643 797338	MAKSIM GORBUNOV	{"email": "maksim.gorbunov-1972@postgrespro.ru", "phone": "+70112765280"}
0005435613369	244CA5	2062 600477	OLESYA IVANOVA	{"email": "ivanovao1972@postgrespro.ru", "phone": "+70434710453"}
0005435613370	C706F9	5078 196104	SVETLANA ZHURAVLEVA	{"phone": "+70338074810"}
0005435613371	FC1AF0	7989 736395	ZINAIDA KISELEVA	{"phone": "+70406643296"}
0005435613372	FC1AF0	3862 016451	TATYANA ANDREEVA	{"email": "andreeva_tatyana04111974@postgrespro.ru", "phone": "+70818633436"}
0005435613373	511488	9823 092213	NADEZHDA SMIRNOVA	{"email": "smirnova.nadezhda.1980@postgrespro.ru", "phone": "+70914756802"}
0005435613374	492B34	7681 564432	MARINA PETROVA	{"email": "marinapetrova-13031964@postgrespro.ru", "phone": "+70171443016"}
0005435613375	492B34	1237 280848	VLADIMIR STEPANOV	{"email": "vladimirstepanov_1976@postgrespro.ru", "phone": "+70296992910"}
0005435613376	87C8A5	6237 375975	ALEKSANDR CHERNOV	{"email": "a-chernov-041976@postgrespro.ru", "phone": "+70601172852"}
0005435613377	321640	7191 247757	TATYANA KONDRATEVA	{"phone": "+70122559402"}
0005435613378	0C61DF	2318 649811	NATALYA EFIMOVA	{"phone": "+70943350247"}
0005435613379	0D4B84	6050 507390	MARINA FEDOROVA	{"phone": "+70071197029"}
0005435613380	4657A3	3628 725719	ALINA PAVLOVA	{"email": "pavlova.a-13111973@postgrespro.ru", "phone": "+70716731687"}
0005435613381	4657A3	2403 205104	ALEKSEY ISAEV	{"phone": "+70083284580"}
0005435613382	27427E	3296 607353	NIKOLAY SAVELEV	{"phone": "+70145511262"}
0005435613383	27427E	8537 988683	LYUDMILA YUDINA	{"phone": "+70207113315"}
0005435613384	6C2F1B	4492 396361	NIKOLAY BONDARENKO	{"phone": "+70157282493"}
0005435613385	AAA35B	3658 543138	KSENIYA NIKOLAEVA	{"email": "kseniya_nikolaeva1977@postgrespro.ru", "phone": "+70213237940"}
0005435613386	AAA35B	6880 150661	ILYA MOISEEV	{"email": "ilyamoiseev19111959@postgrespro.ru", "phone": "+70021828061"}
0005435613387	CA5B41	1231 419858	SVETLANA ZAYCEVA	{"phone": "+70480598955"}
0005435613388	5F5A84	2925 168531	KONSTANTIN RODIONOV	{"email": "rodionov-k_17121981@postgrespro.ru", "phone": "+70127466675"}
0005435613389	7B0582	1227 568883	VIKTOR YAKOVLEV	{"email": "yakovlev_viktor-011969@postgrespro.ru", "phone": "+70986746321"}
0005435613390	7B0582	7125 048820	VITALIY IVANOV	{"email": "ivanov-vitaliy_011992@postgrespro.ru", "phone": "+70753493947"}
0005435613391	D8F941	1278 439104	VASILIY NAZAROV	{"email": "vnazarov.061977@postgrespro.ru", "phone": "+70312585047"}
0005435613392	6E3414	7049 419159	ALEKSEY KAZAKOV	{"email": "a-kazakov-1972@postgrespro.ru", "phone": "+70704735886"}
0005435613394	6E3414	1440 308145	EGOR MARTYNOV	{"phone": "+70561790326"}
0005435613395	4390A2	3422 938850	VIKTORIYA KRASNOVA	{"email": "krasnova_v.101965@postgrespro.ru", "phone": "+70894274451"}
0005435613396	514E3B	2758 659823	GENNADIY KOROLEV	{"email": "korolev-gennadiy17101956@postgrespro.ru", "phone": "+70648630841"}
0005435613397	327211	5522 960295	ROMAN FEDOROV	{"phone": "+70935295183"}
0005435613398	2DE259	5694 292413	NINA KOMAROVA	{"email": "nina_komarova.22011976@postgrespro.ru", "phone": "+70786574931"}
0005435613399	2DE259	8436 142379	ELENA SEMENOVA	{"email": "semenova-elena_1965@postgrespro.ru", "phone": "+70522129932"}
0005435613400	7DDD8C	6487 315600	ANDREY STEPANOV	{"email": "a-stepanov.041971@postgrespro.ru", "phone": "+70713050618"}
0005435613401	5A80A2	2791 892250	SERGEY ROMANOV	{"phone": "+70782453400"}
0005435613402	69DE17	5035 783719	ALEKSANDR ROMANOV	{"email": "romanova021970@postgrespro.ru", "phone": "+70005930535"}
0005435613403	710988	2598 591288	IGOR PAVLOV	{"phone": "+70953396008"}
0005435613404	50B6F2	4976 787385	LILIYA ZHUKOVA	{"email": "l_zhukova.051981@postgrespro.ru", "phone": "+70279733149"}
0005435613405	50B6F2	3422 255499	ALEKSANDR TIMOFEEV	{"phone": "+70434280421"}
0005435613406	020CF3	4832 617400	ALEKSANDR KAZAKOV	{"phone": "+70353508180"}
0005435613407	F27F08	7787 775383	LIDIYA LAZAREVA	{"email": "lidiya_lazareva_101954@postgrespro.ru", "phone": "+70207815689"}
0005435613408	748E94	2546 533392	OLGA MOROZOVA	{"email": "morozova_olga-25021965@postgrespro.ru", "phone": "+70555527648"}
0005435613409	748E94	6582 590166	SERGEY PETROV	{"email": "petrov.sergey_1966@postgrespro.ru", "phone": "+70810310698"}
0005435613410	C6C4EC	6678 959248	VALERIY VLASOV	{"email": "vlasov.valeriy051961@postgrespro.ru", "phone": "+70516268571"}
0005435613411	DC6ED6	0707 844192	NATALYA DAVYDOVA	{"email": "davydovanatalya.1971@postgrespro.ru", "phone": "+70034278048"}
0005435613412	C0618E	9545 284567	ZOYA AFANASEVA	{"email": "zafanaseva_1973@postgrespro.ru", "phone": "+70616133518"}
0005435613413	C0618E	6249 109413	VIKTOR SAVELEV	{"phone": "+70035500114"}
0005435613414	F24354	5612 284509	ANTON NIKITIN	{"email": "a.nikitin_1970@postgrespro.ru", "phone": "+70803076246"}
0005435613415	317845	0014 469133	ELENA CHERNOVA	{"email": "chernovae101988@postgrespro.ru", "phone": "+70914288076"}
0005435613416	13F975	8684 822288	EKATERINA ZAYCEVA	{"email": "ezayceva-101974@postgrespro.ru", "phone": "+70410673831"}
0005435613417	13F975	6131 865556	VLADIMIR ANTONOV	{"phone": "+70357309976"}
0005435613418	4DFB8F	8892 473110	YULIYA VOROBEVA	{"email": "y_vorobeva.1965@postgrespro.ru", "phone": "+70884825707"}
0005435613419	DCB20B	1517 379669	GLEB MIRONOV	{"email": "gleb-mironov_1969@postgrespro.ru", "phone": "+70969330489"}
0005435613420	F31FF4	5744 184866	VSEVOLOD RODIONOV	{"phone": "+70289114496"}
0005435613421	F31FF4	1386 829139	EKATERINA AKIMOVA	{"phone": "+70460458409"}
0005435613422	F31FF4	1579 180576	VALERIY SIDOROV	{"phone": "+70968129789"}
0005435613423	CDA9B5	7724 995459	LEONID MAKAROV	{"email": "lmakarov-1976@postgrespro.ru", "phone": "+70099596595"}
0005435613424	CDA9B5	4666 603016	PAVEL RODIONOV	{"phone": "+70736818912"}
0005435613425	83276C	4151 890328	VIKTOR ILIN	{"email": "viktor-ilin031971@postgrespro.ru", "phone": "+70034036275"}
0005435613426	6D92A8	9215 493192	ELENA FEDOROVA	{"email": "fedorovae_18121960@postgrespro.ru", "phone": "+70386408107"}
0005435613427	6D92A8	4475 827325	LIDIYA LOGINOVA	{"phone": "+70413405610"}
0005435613428	CE704B	2685 297780	LYUBOV VOROBEVA	{"phone": "+70667126589"}
0005435613429	1C1F2A	8275 038502	EVGENIY GUSEV	{"phone": "+70494999561"}
0005435613430	1C1F2A	4728 030227	NINA NAZAROVA	{"phone": "+70827056128"}
0005435613431	34437B	3131 769789	PAVEL MARTYNOV	{"phone": "+70665611711"}
0005435613432	5443C6	4192 860460	MAKSIM POPOV	{"email": "popovmaksim16021970@postgrespro.ru", "phone": "+70038465726"}
0005435613433	5443C6	3978 730594	GENNADIY ANDREEV	{"phone": "+70162301462"}
0005435613434	7A15F1	9941 277435	ANNA KUZNECOVA	{"email": "anna_kuznecova_19071976@postgrespro.ru", "phone": "+70434515930"}
0005435613435	7A15F1	3953 374836	NATALYA IVANOVA	{"email": "ivanova_natalya.121984@postgrespro.ru", "phone": "+70640359846"}
0005435613436	C413AF	2964 235084	MAKSIM ANTONOV	{"email": "m.antonov1975@postgrespro.ru", "phone": "+70385258166"}
0005435613437	60F52C	3407 707702	LYUBOV GERASIMOVA	{"phone": "+70310005767"}
0005435613438	60F52C	9126 019750	ANDREY MIRONOV	{"email": "andreymironov.021957@postgrespro.ru", "phone": "+70486609356"}
0005435613439	8103E7	7272 522186	ARTEM DAVYDOV	{"email": "artemdavydov011976@postgrespro.ru", "phone": "+70215564548"}
0005435613440	BD0473	5628 043272	VIKTORIYA DENISOVA	{"email": "denisova.v_1971@postgrespro.ru", "phone": "+70011256750"}
0005435613441	7F5939	2142 046872	ANATOLIY KAZAKOV	{"phone": "+70471146274"}
0005435613442	5DA4BE	4176 688760	NATALYA KONOVALOVA	{"email": "natalyakonovalova1978@postgrespro.ru", "phone": "+70233783437"}
0005435613443	5DA4BE	6708 923074	POLINA FILIPPOVA	{"email": "polinafilippova_17121969@postgrespro.ru", "phone": "+70872598510"}
0005435613444	A3F6FE	8264 617249	TATYANA NIKOLAEVA	{"phone": "+70842908148"}
0005435613445	647BBF	6637 216440	VALENTINA MELNIKOVA	{"phone": "+70814939307"}
0005435613446	B75F1A	8328 126888	VLADIMIR MARTYNOV	{"email": "martynov_v_23011971@postgrespro.ru", "phone": "+70374594144"}
0005435613447	69E5AA	6590 180300	VIKTOR DAVYDOV	{"email": "davydov-viktor_1973@postgrespro.ru", "phone": "+70171592100"}
0005435613448	69E5AA	5796 687042	GALINA NIKOLAEVA	{"email": "galina-nikolaeva_21071972@postgrespro.ru", "phone": "+70753120136"}
0005435613449	8EDEA8	8552 535308	SVETLANA DENISOVA	{"email": "svetlana_denisova1975@postgrespro.ru", "phone": "+70235090217"}
0005435613450	5D63FC	2528 881351	ANNA ALEKSANDROVA	{"email": "aleksandrova-anna_071970@postgrespro.ru", "phone": "+70263965905"}
0005435613451	6F3DE3	4905 415608	DARYA KUZNECOVA	{"email": "d.kuznecova_1965@postgrespro.ru", "phone": "+70651049694"}
0005435613452	9EE40F	3253 960857	ZHANNA POPOVA	{"phone": "+70703214724"}
0005435613453	C3EBBA	2440 491827	VITALIY SIDOROV	{"phone": "+70349439702"}
0005435613454	C3EBBA	4738 425524	SVETLANA MELNIKOVA	{"phone": "+70401460782"}
0005435613455	E18EB2	5502 338417	TATYANA KARPOVA	{"phone": "+70016555206"}
0005435613456	EC8406	2796 483279	NIKOLAY FILIPPOV	{"email": "n-filippov.121978@postgrespro.ru", "phone": "+70230171099"}
0005435613457	A71FCA	7776 293937	ALEKSEY NIKITIN	{"email": "aleksey-nikitin_051967@postgrespro.ru", "phone": "+70201889962"}
0005435613458	512413	8493 506246	GRIGORIY MIRONOV	{"phone": "+70993626062"}
0005435613459	9D1943	0685 392191	ALEKSANDR DAVYDOV	{"phone": "+70784228539"}
0005435613460	7A7266	7329 878849	ANATOLIY MATVEEV	{"email": "anatoliy_matveev.26061972@postgrespro.ru", "phone": "+70231859818"}
0005435613461	2BE3F0	6876 515550	TATYANA NAZAROVA	{"phone": "+70904687318"}
0005435613462	D8CCF1	8648 354693	KIRILL KUZMIN	{"email": "kkuzmin.041972@postgrespro.ru", "phone": "+70423916628"}
0005435613463	D8CCF1	3113 385974	VLADIMIR DAVYDOV	{"phone": "+70858738533"}
0005435613464	D8CCF1	2733 294915	ALENA LUKYANOVA	{"phone": "+70599491771"}
0005435613465	0F5B35	9750 787231	MIKHAIL GERASIMOV	{"email": "gerasimov-m_29101975@postgrespro.ru", "phone": "+70324222963"}
0005435613466	0F5B35	8948 089672	OLEG NIKOLAEV	{"phone": "+70956348252"}
0005435613467	61290D	4786 890416	GENNADIY FEDOTOV	{"email": "g_fedotov1969@postgrespro.ru", "phone": "+70689538056"}
0005435613468	61290D	7764 656313	GALINA NIKOLAEVA	{"email": "galina_nikolaeva-1988@postgrespro.ru", "phone": "+70771803757"}
0005435613469	C3EDEE	4324 566131	ELENA DAVYDOVA	{"email": "davydova-e.081971@postgrespro.ru", "phone": "+70086067476"}
0005435613470	C3EDEE	5139 112487	VYACHESLAV FILIPPOV	{"phone": "+70330879243"}
0005435613471	710C48	4900 779182	ANZHELIKA CHERNOVA	{"email": "chernovaanzhelika_27101966@postgrespro.ru", "phone": "+70301069410"}
0005435613472	85E48F	4411 373003	ANATOLIY RODIONOV	{"phone": "+70287290016"}
0005435613473	3F81F1	5157 032916	EVGENIYA DMITRIEVA	{"email": "evgeniyadmitrieva.1975@postgrespro.ru", "phone": "+70462277508"}
0005435613474	10B54C	2475 935405	POLINA YAKOVLEVA	{"email": "p_yakovleva-18021981@postgrespro.ru", "phone": "+70494322202"}
0005435613475	8DB27D	3462 401502	ALEKSANDR KONOVALOV	{"email": "akonovalov18101970@postgrespro.ru", "phone": "+70787367830"}
0005435613476	FBA113	5480 170503	OLEG FEDOROV	{"phone": "+70365824112"}
0005435613477	FBA113	1044 777230	ANATOLIY ILIN	{"phone": "+70049193119"}
0005435613478	FBA113	5424 036946	LILIYA FROLOVA	{"email": "liliya_frolova.1975@postgrespro.ru", "phone": "+70919072860"}
0005435613479	33A927	3429 758200	TATYANA KUZNECOVA	{"email": "kuznecova-t-111975@postgrespro.ru", "phone": "+70435562301"}
0005435613480	33A927	6727 237679	ALINA FEDOROVA	{"email": "fedorovaa_1975@postgrespro.ru", "phone": "+70396756640"}
0005435613481	4150A8	2561 584288	ELENA BORISOVA	{"phone": "+70243516907"}
0005435613482	6F6AD6	2286 442674	LEONID ZAKHAROV	{"email": "zakharov.l.10011956@postgrespro.ru", "phone": "+70767274497"}
0005435613483	0436AB	2589 821432	ALEKSANDR MARTYNOV	{"phone": "+70466975599"}
0005435613484	0436AB	4341 883235	OKSANA STEPANOVA	{"phone": "+70150764733"}
0005435613485	5B9757	2487 410129	SERGEY KUDRYASHOV	{"phone": "+70688806096"}
0005435613486	D5C5A1	5298 656511	ALEKSANDR KUZMIN	{"email": "aleksandrkuzmin-11071976@postgrespro.ru", "phone": "+70728976913"}
0005435613487	6005FF	6062 958605	SERGEY ILIN	{"email": "s.ilin121980@postgrespro.ru", "phone": "+70187157136"}
0005435613488	4A1840	9491 694080	NATALYA RYABOVA	{"email": "ryabova.natalya_28071964@postgrespro.ru", "phone": "+70165316936"}
0005435613489	4A1840	3504 566306	MIKHAIL FROLOV	{"phone": "+70966234244"}
0005435613490	40CDDF	1473 749029	ANASTASIYA NIKIFOROVA	{"email": "nikiforova_anastasiya021970@postgrespro.ru", "phone": "+70273100749"}
0005435613491	40CDDF	9884 355780	ANDREY SAVELEV	{"phone": "+70711393013"}
0005435613492	A766D4	0607 002710	TATYANA MAKAROVA	{"phone": "+70789122041"}
0005435613493	65B0EE	9364 394458	ARTEM FEDOTOV	{"phone": "+70744467497"}
0005435613494	D74209	9553 577253	EVDOKIYA NIKOLAEVA	{"phone": "+70587834267"}
0005435613495	A4F67D	0862 397859	VALENTINA BOGDANOVA	{"email": "bogdanova_valentina26031974@postgrespro.ru", "phone": "+70335108889"}
0005435613496	A79E8E	4069 184121	VALENTINA NESTEROVA	{"email": "nesterova-valentina-1967@postgrespro.ru", "phone": "+70782912762"}
0005435613497	61FB47	9499 810901	ALEKSEY DENISOV	{"phone": "+70720708202"}
0005435613498	0FE6EE	0335 906539	DENIS GAVRILOV	{"email": "gavrilovd-1975@postgrespro.ru", "phone": "+70710624462"}
0005435613499	895D5B	7271 552313	DMITRIY MARTYNOV	{"phone": "+70008755672"}
0005435613500	895D5B	3045 115899	RUSLAN BARANOV	{"email": "baranov_r_24011980@postgrespro.ru", "phone": "+70145797937"}
0005435613501	895D5B	2558 960290	NATALYA KAZAKOVA	{"email": "natalya_kazakova-07051976@postgrespro.ru", "phone": "+70302621493"}
0005435613502	BE4957	8630 183688	YAN GORBUNOV	{"email": "y-gorbunov1964@postgrespro.ru", "phone": "+70871727523"}
0005435613503	D1FE45	3584 802449	TAMARA AKIMOVA	{"phone": "+70545929863"}
0005435613560	E973F6	4229 072053	SERGEY YAKOVLEV	{"phone": "+70099275039"}
0005435613504	D1FE45	2441 820813	ALEKSANDR ALEKSANDROV	{"email": "aleksandraleksandrov071958@postgrespro.ru", "phone": "+70022958650"}
0005435613505	494F48	9640 084600	ALEKSANDR SMIRNOV	{"email": "smirnov_aleksandr_031981@postgrespro.ru", "phone": "+70957531146"}
0005435613506	494F48	5491 204045	ANDREY ANDREEV	{"email": "andreev-andrey02121966@postgrespro.ru", "phone": "+70888310188"}
0005435613507	4E2AAE	7956 167486	EKATERINA KUZMINA	{"email": "ekuzmina_11101978@postgrespro.ru", "phone": "+70134702906"}
0005435613508	6FD1F2	7881 957641	VLADISLAV KUZNECOV	{"phone": "+70400584973"}
0005435613509	6FD1F2	0962 814102	ALEKSANDR FILIPPOV	{"email": "a.filippov.21101967@postgrespro.ru", "phone": "+70437290472"}
0005435613510	BDB004	2604 570983	ROMAN PETROV	{"phone": "+70897717471"}
0005435613511	82722B	5796 477354	ALFIYA DAVYDOVA	{"email": "a.davydova-101967@postgrespro.ru", "phone": "+70667768890"}
0005435613512	3CF141	8574 387890	OLEG POPOV	{"phone": "+70179048353"}
0005435613513	3CF141	0185 370794	ALEKSANDR KAZAKOV	{"phone": "+70594486612"}
0005435613514	34D0DD	8940 194197	ELENA ANISIMOVA	{"phone": "+70054246263"}
0005435613515	34D0DD	8251 286273	KIRILL IVANOV	{"phone": "+70890169821"}
0005435613516	2AED29	8240 179958	DARYA AFANASEVA	{"phone": "+70792805830"}
0005435613517	2AED29	5292 859851	EVGENIYA ABRAMOVA	{"phone": "+70520866240"}
0005435613518	CBD904	5434 302523	MARIYA ALEKSANDROVA	{"phone": "+70464232059"}
0005435613519	946041	6390 839175	VLADIMIR KAZAKOV	{"email": "kazakovvladimir-1979@postgrespro.ru", "phone": "+70015990282"}
0005435613520	946041	1854 621675	ALEKSANDR ZAKHAROV	{"phone": "+70175586512"}
0005435613521	C359E2	4945 644362	ALEKSANDR TARASOV	{"email": "tarasov-aleksandr_27041970@postgrespro.ru", "phone": "+70953617424"}
0005435613522	8BFEFF	9195 044348	MARIYA ALEKSANDROVA	{"phone": "+70227129047"}
0005435613523	134620	6583 983259	DMITRIY SMIRNOV	{"phone": "+70592148319"}
0005435613524	697BCB	4883 649568	NINA KUZNECOVA	{"phone": "+70829747178"}
0005435613525	BA3FB1	3330 740307	KLARA POLYAKOVA	{"email": "polyakovaklara-1988@postgrespro.ru", "phone": "+70086113743"}
0005435613526	BA3FB1	8267 468784	VITALIY KOZLOV	{"email": "kozlov_vitaliy.10061977@postgrespro.ru", "phone": "+70378754501"}
0005435613527	1D62EB	4889 493884	ANNA VASILEVA	{"email": "vasileva-anna.1970@postgrespro.ru", "phone": "+70165942858"}
0005435613528	1D62EB	6604 718042	ELENA KOZLOVA	{"email": "elenakozlova1981@postgrespro.ru", "phone": "+70893092064"}
0005435613529	3CF834	5801 033186	ALEKSANDR IVANOV	{"phone": "+70540949080"}
0005435613530	6C8E47	8318 027609	RAFAIL ABRAMOV	{"email": "abramov_rafail.1973@postgrespro.ru", "phone": "+70900489729"}
0005435613531	67F605	5695 561023	ANASTASIYA AKIMOVA	{"phone": "+70892899487"}
0005435613532	1C822A	2552 495665	ALINA KUDRYASHOVA	{"phone": "+70900503630"}
0005435613533	581BC3	3510 376325	LYUBOV KRASNOVA	{"phone": "+70089766740"}
0005435613534	581BC3	5321 354966	GEORGIY IVANOV	{"email": "g_ivanov-121963@postgrespro.ru", "phone": "+70136447608"}
0005435613535	B888BF	9188 913961	NADEZHDA MELNIKOVA	{"phone": "+70485553732"}
0005435613536	B709AC	3298 303318	ALENA SCHERBAKOVA	{"phone": "+70461287106"}
0005435613537	B709AC	4631 384681	SERGEY EGOROV	{"phone": "+70044705699"}
0005435613538	E598F0	5179 415991	OLGA SOKOLOVA	{"email": "olgasokolova19121975@postgrespro.ru", "phone": "+70777555095"}
0005435613539	E598F0	4998 424908	ALINA STEPANOVA	{"phone": "+70639818819"}
0005435613540	DD08D6	3310 658857	ROMAN SOKOLOV	{"email": "sokolov_roman15091963@postgrespro.ru", "phone": "+70054034310"}
0005435613541	DD08D6	7630 582629	LYUBOV KOVALEVA	{"email": "lyubov.kovaleva_081972@postgrespro.ru", "phone": "+70600280215"}
0005435613542	7F6EE9	7225 794482	VIKTORIYA ARKHIPOVA	{"phone": "+70615405780"}
0005435613543	7F6EE9	3400 370515	OLGA KAZAKOVA	{"email": "olga_kazakova1961@postgrespro.ru", "phone": "+70908545603"}
0005435613544	9FA16B	5029 411196	ALEKSANDRA MIRONOVA	{"phone": "+70199851160"}
0005435613545	9FA16B	2106 727119	PAVEL ZAKHAROV	{"email": "p.zakharov.21071968@postgrespro.ru", "phone": "+70361885221"}
0005435613546	13B9CF	0807 693048	MAKSIM BORISOV	{"email": "borisov-maksim_041959@postgrespro.ru", "phone": "+70521336037"}
0005435613547	F01168	1223 364921	LIDIYA KUZNECOVA	{"email": "lidiyakuznecova.1969@postgrespro.ru", "phone": "+70156809565"}
0005435613548	B24E4D	6852 129795	ILMIRA SIDOROVA	{"email": "ilmirasidorova-1970@postgrespro.ru", "phone": "+70045364507"}
0005435613549	E5EBC5	0605 483264	VALENTINA KONOVALOVA	{"email": "konovalova_v.1960@postgrespro.ru", "phone": "+70369033295"}
0005435613550	C9B4AB	0926 151582	DMITRIY NOVIKOV	{"phone": "+70466481758"}
0005435613551	673F6D	7789 692472	NADEZHDA KUZMINA	{"phone": "+70268597989"}
0005435613552	673F6D	1897 038381	GENNADIY ALEKSEEV	{"email": "gennadiy-alekseev-15121965@postgrespro.ru", "phone": "+70786876080"}
0005435613553	5AB49E	1518 405751	TAMARA KUZMINA	{"email": "t.kuzmina_021966@postgrespro.ru", "phone": "+70687587680"}
0005435613554	5AB49E	4110 202325	DENIS SOKOLOV	{"phone": "+70954442414"}
0005435613555	5AB49E	8264 580220	ANNA SIDOROVA	{"email": "a_sidorova-1983@postgrespro.ru", "phone": "+70869834895"}
0005435613556	D56BB8	4024 410015	MARIYA AKIMOVA	{"phone": "+70491671997"}
0005435613557	46D36A	6160 525816	IGOR SERGEEV	{"email": "sergeev_i_05091970@postgrespro.ru", "phone": "+70045504339"}
0005435613558	46D36A	6849 609044	NINA EFIMOVA	{"phone": "+70518152815"}
0005435613559	E973F6	2203 647531	VASILIY POPOV	{"phone": "+70081305338"}
0005435613561	3D6697	3108 357874	LYUDMILA BORISOVA	{"phone": "+70042521207"}
0005435613562	3D6697	8113 680041	LARISA KOLESNIKOVA	{"email": "kolesnikovalarisa_061970@postgrespro.ru", "phone": "+70504530619"}
0005435613563	5E31BF	7318 819499	OLEG ISAEV	{"phone": "+70115605113"}
0005435613564	5E31BF	6854 207947	LEONID NAZAROV	{"phone": "+70044617815"}
0005435613565	1BFBEE	0571 129853	MARIYA TARASOVA	{"phone": "+70455272364"}
0005435613566	389B78	0104 523909	ALEKSANDR FEDOTOV	{"email": "fedotov_a011972@postgrespro.ru", "phone": "+70395540087"}
0005435613567	06D460	1999 606429	VLADIMIR ISAEV	{"phone": "+70168836612"}
0005435613568	C8399D	4831 040553	VALENTINA MARTYNOVA	{"phone": "+70461508846"}
0005435613569	60D903	9346 733006	VIKTOR KUZNECOV	{"phone": "+70176189150"}
0005435613570	EEEB0D	1762 078041	ANATOLIY MAKSIMOV	{"email": "a_maksimov-1965@postgrespro.ru", "phone": "+70875601102"}
0005435613571	EEEB0D	6104 450303	ALEKSANDR MATVEEV	{"email": "a-matveev_101976@postgrespro.ru", "phone": "+70794065879"}
0005435613572	7ECD61	0571 326164	IVAN SOKOLOV	{"email": "sokolov_ivan_1968@postgrespro.ru", "phone": "+70143090703"}
0005435613573	84867E	1663 577267	IVAN SEMENOV	{"phone": "+70962160063"}
0005435613574	84867E	7486 498761	GALINA MIKHAYLOVA	{"email": "gmikhaylova_30101976@postgrespro.ru", "phone": "+70643637630"}
0005435613575	FFD61F	0164 764275	ANATOLIY EGOROV	{"email": "egorov.anatoliy_07121973@postgrespro.ru", "phone": "+70593720399"}
0005435613576	595870	5677 693991	VLADIMIR SOLOVEV	{"phone": "+70732491867"}
0005435613577	CEE2D8	0860 110472	YULIYA KUZMINA	{"phone": "+70099794382"}
0005435613578	E0841C	3669 485327	STANISLAV MAKAROV	{"phone": "+70379566623"}
0005435613579	E0841C	6721 530208	POLINA IVANOVA	{"email": "pivanova.10011979@postgrespro.ru", "phone": "+70617141637"}
0005435613580	A89069	0599 821209	SERGEY IVANOV	{"email": "ivanovs-1962@postgrespro.ru", "phone": "+70945849059"}
0005435613581	A89069	3209 969737	PETR FILIPPOV	{"email": "filippov_petr_15101976@postgrespro.ru", "phone": "+70144114072"}
0005435613582	A89069	0701 569618	IGOR SCHERBAKOV	{"email": "i-scherbakov.121978@postgrespro.ru", "phone": "+70382823559"}
0005435613583	55B977	4263 918593	NADEZHDA FILIPPOVA	{"email": "filippova_nadezhda.011979@postgrespro.ru", "phone": "+70867456377"}
0005435613584	55B977	5724 734984	ALEKSEY GORBUNOV	{"email": "gorbunov.a101978@postgrespro.ru", "phone": "+70661135929"}
0005435613585	0D9AEC	9722 321592	LIDIYA KARPOVA	{"email": "lidiyakarpova-16111968@postgrespro.ru", "phone": "+70891744158"}
0005435613586	0D9AEC	3098 695724	ALEKSANDR SAVELEV	{"email": "savelev-a_121973@postgrespro.ru", "phone": "+70125739365"}
0005435613587	F2229A	4473 160829	OLGA KUZMINA	{"phone": "+70529620291"}
0005435613588	D6B495	9828 423097	NIKITA MAKAROV	{"email": "n-makarov.13081979@postgrespro.ru", "phone": "+70844000794"}
0005435613589	D6B495	6429 855673	GALINA PETROVA	{"phone": "+70653255816"}
0005435613590	9F4538	5681 738849	NATALYA DENISOVA	{"email": "natalya.denisova1982@postgrespro.ru", "phone": "+70795434442"}
0005435613591	C87D95	1504 560567	ANDREY SEMENOV	{"phone": "+70218028218"}
0005435613592	13AF74	4491 110613	ALEKSEY KARPOV	{"email": "alekseykarpov.021977@postgrespro.ru", "phone": "+70950517324"}
0005435613593	98136C	7111 249958	DARYA TIMOFEEVA	{"phone": "+70489905218"}
0005435613594	A26AF5	1478 048885	ALEKSANDR NAZAROV	{"email": "aleksandr-nazarov_06091975@postgrespro.ru", "phone": "+70987071773"}
0005435613595	5B60B1	8939 432339	MARINA SOKOLOVA	{"phone": "+70035657627"}
0005435613596	1DC9C8	7598 924905	LYUDMILA VOLKOVA	{"email": "volkova-lyudmila-091968@postgrespro.ru", "phone": "+70210219261"}
0005435613597	F30621	8788 934276	ELENA ZAKHAROVA	{"email": "elena_zakharova.031965@postgrespro.ru", "phone": "+70364791169"}
0005435613598	83B63E	9901 101370	MIKHAIL IVANOV	{"email": "ivanov.m_1973@postgrespro.ru", "phone": "+70346614214"}
0005435613599	DDC4E1	3116 735525	LYUDMILA EGOROVA	{"phone": "+70859377830"}
0005435613600	DDC4E1	6757 732892	DANIIL GUSEV	{"phone": "+70172762565"}
0005435613601	DDC4E1	0858 140090	GALINA NESTEROVA	{"email": "galina.nesterova.1964@postgrespro.ru", "phone": "+70967939421"}
0005435613602	27DCE2	9544 668927	ANASTASIYA PETROVA	{"email": "petrova_a.011967@postgrespro.ru", "phone": "+70041057445"}
0005435613603	88C283	9789 908493	ANDREY FOMIN	{"phone": "+70825535154"}
0005435613604	23F993	6991 780891	MARIYA NAZAROVA	{"email": "nazarova-m-1965@postgrespro.ru", "phone": "+70606885717"}
0005435613605	990FA7	2505 558049	ELENA BORISOVA	{"email": "borisova-elena1983@postgrespro.ru", "phone": "+70911125743"}
0005435613606	990FA7	9842 726456	VYACHESLAV MAKSIMOV	{"phone": "+70029129592"}
0005435613607	DEC37C	6873 362219	VYACHESLAV PETROV	{"phone": "+70027328848"}
0005435613608	40EED4	2121 703885	DMITRIY ZAKHAROV	{"phone": "+70450731096"}
0005435613609	40EED4	8717 483944	FATIMA KUZNECOVA	{"email": "fatimakuznecova1982@postgrespro.ru", "phone": "+70490290837"}
0005435613610	40EED4	7489 014543	NIKOLAY CHERNOV	{"email": "n.chernov-20031983@postgrespro.ru", "phone": "+70260579316"}
0005435613611	590743	3246 650446	MIKHAIL MAKSIMOV	{"phone": "+70779599838"}
0005435613612	811DE7	4191 528735	ELIZAVETA GERASIMOVA	{"email": "e.gerasimova-13061973@postgrespro.ru", "phone": "+70901526518"}
0005435613613	811DE7	0620 605918	NADEZHDA SOKOLOVA	{"email": "nadezhda_sokolova101974@postgrespro.ru", "phone": "+70312609729"}
0005435613614	FFE36C	6146 393477	ALEKSEY SOLOVEV	{"email": "solovev_aleksey-06081968@postgrespro.ru", "phone": "+70165191517"}
0005435613615	FFE36C	1278 599799	DENIS AFANASEV	{"email": "dafanasev12061967@postgrespro.ru", "phone": "+70112676072"}
0005435613616	A099AD	0601 945494	ALEKSANDR BORISOV	{"phone": "+70155882221"}
0005435613617	B50B8D	2002 380747	EVGENIYA STEPANOVA	{"email": "stepanova.e-1981@postgrespro.ru", "phone": "+70735167678"}
0005435613618	B50B8D	3583 646887	ALEKSANDRA PAVLOVA	{"phone": "+70012046373"}
0005435613619	15D1FA	7458 593150	IGOR NOVIKOV	{"email": "igor.novikov.011967@postgrespro.ru", "phone": "+70924254541"}
0005435613620	15D1FA	8347 516442	VADIM SERGEEV	{"email": "sergeev-v-30081970@postgrespro.ru", "phone": "+70652152453"}
0005435613621	15D1FA	5489 734143	VALENTINA VLASOVA	{"email": "v_vlasova_011961@postgrespro.ru", "phone": "+70948845597"}
0005435613622	DA1CC6	1028 761480	NATALYA ARKHIPOVA	{"email": "arkhipova_natalya031976@postgrespro.ru", "phone": "+70880262853"}
0005435613623	DA1CC6	2127 022025	LYUBOV AFANASEVA	{"phone": "+70472852254"}
0005435613624	65E2D8	4830 562172	SVETLANA NIKITINA	{"email": "nikitinasvetlana-03071976@postgrespro.ru", "phone": "+70490541718"}
0005435613625	65E2D8	3235 221999	ROZALIYA IVANOVA	{"email": "ivanova.r-21061982@postgrespro.ru", "phone": "+70891968039"}
0005435613626	32C8F6	3352 335401	LYUDMILA MEDVEDEVA	{"email": "l-medvedeva-1977@postgrespro.ru", "phone": "+70850676624"}
0005435613627	32C8F6	5489 537739	LYUDMILA KOROLEVA	{"phone": "+70214645261"}
0005435613628	FE6479	3719 363929	ELENA VOLKOVA	{"phone": "+70192098603"}
0005435613629	3D9A66	3964 771264	ALEKSANDR NOVIKOV	{"phone": "+70472643831"}
0005435613630	A40155	0869 486002	SERGEY FEDOROV	{"email": "s_fedorov_15121975@postgrespro.ru", "phone": "+70930985426"}
0005435613631	A33D67	6689 450805	ALEKSANDR NAZAROV	{"email": "a_nazarov.19031974@postgrespro.ru", "phone": "+70605825307"}
0005435613632	65D673	2493 459542	NIKOLAY MEDVEDEV	{"email": "nikolay.medvedev.1967@postgrespro.ru", "phone": "+70376000317"}
0005435613633	3A462F	2868 308941	IRINA ZAKHAROVA	{"phone": "+70733380614"}
0005435613634	B87DDA	8850 592978	ELENA DANILOVA	{"email": "e_danilova_031968@postgrespro.ru", "phone": "+70446626764"}
0005435613635	3D91D1	0002 778149	OLGA ANDREEVA	{"email": "olgaandreeva_1975@postgrespro.ru", "phone": "+70620720003"}
0005435613636	372104	9124 076595	SERGEY GAVRILOV	{"email": "gavrilov.sergey-1975@postgrespro.ru", "phone": "+70192558081"}
0005435613637	A25C90	2162 839033	ALEKSANDRA MAKSIMOVA	{"email": "maksimova_a_1968@postgrespro.ru", "phone": "+70092635669"}
0005435613638	3EDC24	7951 474316	NATALYA KUZMINA	{"phone": "+70627226108"}
0005435613639	6BC6E3	4000 309174	EKATERINA ZAYCEVA	{"phone": "+70289847251"}
0005435613640	6BC6E3	1643 834616	TIMUR GAVRILOV	{"phone": "+70617868390"}
0005435613641	6BC6E3	9277 385482	LEONID GERASIMOV	{"email": "gerasimov.l061963@postgrespro.ru", "phone": "+70597156719"}
0005435613642	63B13E	7105 976627	MARINA GERASIMOVA	{"phone": "+70461781005"}
0005435613643	63B13E	9315 022910	LYUBOV ZAKHAROVA	{"email": "l_zakharova1978@postgrespro.ru", "phone": "+70812355410"}
0005435613644	DBC68E	4725 557413	EVGENIYA KOVALEVA	{"phone": "+70254028776"}
0005435613645	DBC68E	3455 855405	SERGEY AFANASEV	{"email": "afanasev_sergey-101967@postgrespro.ru", "phone": "+70439023494"}
0005435613646	7E0FE1	7955 455294	EVGENIY NIKITIN	{"email": "evgeniy-nikitin1973@postgrespro.ru", "phone": "+70194925988"}
0005435613647	1ECAE3	8367 104731	VLADIMIR KUZNECOV	{"email": "vladimirkuznecov.051966@postgrespro.ru", "phone": "+70752264458"}
0005435613648	1ECAE3	7486 642238	NATALYA ORLOVA	{"email": "n_orlova04121972@postgrespro.ru", "phone": "+70965742229"}
0005435613649	CEAF5C	1232 775034	ELENA TITOVA	{"email": "etitova-101979@postgrespro.ru", "phone": "+70697252549"}
0005435613650	EE0872	3537 120986	OLGA VOLKOVA	{"email": "volkova-o1970@postgrespro.ru", "phone": "+70377998502"}
0005435613651	EE0872	3270 704619	VYACHESLAV NIKITIN	{"phone": "+70589985971"}
0005435613652	B22315	9453 363777	MARIYA KUZNECOVA	{"email": "kuznecovamariya.081977@postgrespro.ru", "phone": "+70289530218"}
0005435613653	B22315	4070 302545	RAISA ROMANOVA	{"phone": "+70730355210"}
0005435613654	24BAF0	0789 652609	RUSLAN SOKOLOV	{"email": "sokolov-r-1972@postgrespro.ru", "phone": "+70704168434"}
0005435613655	277105	8343 673643	MARINA AKIMOVA	{"phone": "+70630304193"}
0005435613656	277105	4672 273077	TAISA KOROLEVA	{"phone": "+70786093564"}
0005435613657	277105	2051 891007	ANDREY TARASOV	{"phone": "+70566512061"}
0005435613658	082B40	6597 040345	ZHANNA FEDOROVA	{"phone": "+70206947647"}
0005435613659	3D20D3	8073 204373	LYUDMILA LAZAREVA	{"phone": "+70733255648"}
0005435613660	3D20D3	3254 539914	STANISLAV SMIRNOV	{"phone": "+70336628515"}
0005435613661	821CA9	9066 135603	ALEKSANDR KISELEV	{"phone": "+70470956315"}
0005435613662	821CA9	1018 318509	IRINA VOLKOVA	{"email": "volkova_i-04021977@postgrespro.ru", "phone": "+70513951782"}
0005435613663	9B7C74	6810 601394	SVETLANA NAZAROVA	{"phone": "+70754659997"}
0005435613664	9B7C74	4456 900372	NATALYA LEBEDEVA	{"email": "lebedeva_natalya_1976@postgrespro.ru", "phone": "+70580747795"}
0005435613665	9B7C74	9317 868171	ALEKSANDR MELNIKOV	{"email": "a_melnikov_021965@postgrespro.ru", "phone": "+70186671751"}
0005435613666	9B7C74	6376 496533	SHAVKAT AFANASEV	{"phone": "+70362263637"}
0005435613667	0810F9	4177 911094	EVGENIY STEPANOV	{"email": "evgeniy.stepanov1983@postgrespro.ru", "phone": "+70242524459"}
0005435613668	0810F9	7860 398211	VERA ZHURAVLEVA	{"email": "zhuravleva_vera-1975@postgrespro.ru", "phone": "+70037890521"}
0005435613669	0AEE5A	8716 313435	ROMAN SEMENOV	{"email": "r_semenov13061978@postgrespro.ru", "phone": "+70582890472"}
0005435613670	0AEE5A	7010 620590	ALEKSANDR KRASNOV	{"phone": "+70607721811"}
0005435613671	B03FEE	2982 883804	SERGEY TIKHONOV	{"email": "tikhonovs-081970@postgrespro.ru", "phone": "+70261884625"}
0005435613837	C60258	1745 882893	MARINA POPOVA	{"phone": "+70990256849"}
0005435613672	7F27DA	8036 729173	KRISTINA BELOVA	{"email": "belova-k.16121962@postgrespro.ru", "phone": "+70918922434"}
0005435613673	7F27DA	6741 845173	MARIYA KOZLOVA	{"email": "m-kozlova.27121971@postgrespro.ru", "phone": "+70468730813"}
0005435613674	9AA098	9728 288534	TATYANA VASILEVA	{"phone": "+70958252870"}
0005435613675	9AA098	0512 575417	LARISA OSIPOVA	{"email": "larisa_osipova-011968@postgrespro.ru", "phone": "+70785078823"}
0005435613676	37B837	2466 205113	GALINA GERASIMOVA	{"phone": "+70338551471"}
0005435613677	8ABC16	8690 167299	ROMAN PAVLOV	{"email": "rpavlov121975@postgrespro.ru", "phone": "+70596942618"}
0005435613678	8ABC16	0175 618209	ALBINA NIKITINA	{"email": "albina_nikitina.11061975@postgrespro.ru", "phone": "+70763689345"}
0005435613679	F1EA3A	2394 549067	DAMIR ALEKSEEV	{"phone": "+70686341124"}
0005435613680	F1EA3A	2947 082316	ELINA KARPOVA	{"phone": "+70401592379"}
0005435613681	141D82	7230 486742	PAVEL ILIN	{"email": "ilinp_1966@postgrespro.ru", "phone": "+70969669470"}
0005435613682	141D82	9269 403528	ALEKSANDR POPOV	{"email": "popov-aleksandr_011970@postgrespro.ru", "phone": "+70179213160"}
0005435613683	1B24EC	0015 810631	SERGEY SIDOROV	{"phone": "+70605525738"}
0005435613684	49EBD8	6140 904646	YULIYA KUZNECOVA	{"phone": "+70129577308"}
0005435613685	49EBD8	1844 531635	MIKHAIL CHERNOV	{"phone": "+70125256221"}
0005435613686	15F8B4	4207 599476	EVGENIYA VASILEVA	{"email": "evgeniya-vasileva_091972@postgrespro.ru", "phone": "+70597959539"}
0005435613687	15F8B4	4322 965328	VIKTORIYA SAVELEVA	{"phone": "+70167223302"}
0005435613688	90A3F4	8368 528234	GENNADIY STEPANOV	{"email": "stepanov.gennadiy-121976@postgrespro.ru", "phone": "+70663046077"}
0005435613689	3BAFC5	7068 115633	NATALYA ANTONOVA	{"phone": "+70760691089"}
0005435613690	F59859	5689 911378	MARIYA DMITRIEVA	{"email": "dmitrieva.mariya_10101971@postgrespro.ru", "phone": "+70282782942"}
0005435613691	F9CA4C	8283 373790	VIKTORIYA POPOVA	{"phone": "+70056609880"}
0005435613692	F9CA4C	8032 946764	RADIK KONOVALOV	{"email": "konovalov.r_1964@postgrespro.ru", "phone": "+70744612596"}
0005435613693	99B062	5505 726470	OLGA FOMINA	{"email": "fomina.olga16121974@postgrespro.ru", "phone": "+70798679009"}
0005435613694	99B062	7624 096115	VALERIY SOKOLOV	{"phone": "+70854256388"}
0005435613695	61F427	7829 562591	NIKOLAY IVANOV	{"phone": "+70227691590"}
0005435613696	723E05	9788 729865	LYUDMILA AFANASEVA	{"email": "afanaseva.lyudmila-29101968@postgrespro.ru", "phone": "+70848661268"}
0005435613697	E6A531	2572 783643	OKSANA KOMAROVA	{"phone": "+70198464884"}
0005435613698	D80458	6803 136689	RAILYA MELNIKOVA	{"phone": "+70846548468"}
0005435613699	D80458	8151 111678	EVGENIYA KONOVALOVA	{"email": "konovalovae_091974@postgrespro.ru", "phone": "+70861030131"}
0005435613700	2B57EF	4794 053272	MARIYA SCHERBAKOVA	{"phone": "+70047138700"}
0005435613701	17A7F8	3518 148998	TATYANA KOLESNIKOVA	{"email": "kolesnikovat-1962@postgrespro.ru", "phone": "+70773481404"}
0005435613702	4BB797	1364 941274	VLADIMIR ALEKSEEV	{"email": "v.alekseev-18101967@postgrespro.ru", "phone": "+70574818286"}
0005435613703	0FDC93	7541 597405	ELENA TIKHONOVA	{"email": "e_tikhonova-121961@postgrespro.ru", "phone": "+70246649121"}
0005435613704	0FDC93	6313 031365	NATALYA SOLOVEVA	{"phone": "+70048657478"}
0005435613705	21CC23	3997 666605	TATYANA TIMOFEEVA	{"phone": "+70003471604"}
0005435613706	21CC23	2395 540327	LYUBOV STEPANOVA	{"email": "l_stepanova1963@postgrespro.ru", "phone": "+70019426765"}
0005435613707	2362E3	6595 942341	ANDREY VOLKOV	{"phone": "+70786905343"}
0005435613708	2362E3	5418 061022	OLGA NESTEROVA	{"phone": "+70380979045"}
0005435613709	2362E3	2324 974822	VLADIMIR STEPANOV	{"email": "stepanov-vladimir.011982@postgrespro.ru", "phone": "+70298264682"}
0005435613710	6C1717	9433 100659	VALENTINA EGOROVA	{"email": "egorova.valentina091971@postgrespro.ru", "phone": "+70760868385"}
0005435613711	4C2D83	0535 492634	VIKTOR ALEKSANDROV	{"email": "aleksandrovviktor.101966@postgrespro.ru", "phone": "+70727289604"}
0005435613712	4C2D83	5007 614685	ALI DMITRIEV	{"email": "dmitriev-a_28111976@postgrespro.ru", "phone": "+70689558609"}
0005435613713	EBA963	0056 796255	DMITRIY SIDOROV	{"phone": "+70616926660"}
0005435613714	EBA963	3347 693203	ALEKSEY ILIN	{"phone": "+70293188594"}
0005435613715	089EAF	9946 115568	ALEKSANDRA ZOTOVA	{"phone": "+70720347343"}
0005435613716	7DB786	4161 361959	VERA NOVIKOVA	{"phone": "+70923003064"}
0005435613717	1589DA	0025 187271	SERGEY KRASNOV	{"email": "sergey.krasnov18011972@postgrespro.ru", "phone": "+70172179717"}
0005435613718	6A757D	2238 934308	TATYANA DANILOVA	{"phone": "+70707596710"}
0005435613719	3C26A1	7041 548920	EKATERINA NIKOLAEVA	{"email": "ekaterina_nikolaeva_14041972@postgrespro.ru", "phone": "+70233595228"}
0005435613720	3C26A1	2682 454325	MARIYA VLASOVA	{"email": "mariya_vlasova.041971@postgrespro.ru", "phone": "+70237110210"}
0005435613721	0BCE66	2948 306714	IVAN KUZNECOV	{"phone": "+70606693692"}
0005435613722	714D1D	7031 256387	ANDREY BORISOV	{"email": "a_borisov.041978@postgrespro.ru", "phone": "+70966466249"}
0005435613723	B3C715	8069 006820	EVGENIY DAVYDOV	{"phone": "+70073163822"}
0005435613724	B3C715	6968 113984	SVETLANA KUDRYASHOVA	{"phone": "+70454644427"}
0005435613725	0A145E	7362 413729	ANNA PETROVA	{"phone": "+70868440242"}
0005435613726	0A145E	5673 428428	SVETLANA BELYAEVA	{"email": "belyaeva-s-1976@postgrespro.ru", "phone": "+70126269089"}
0005435613727	1AB242	8470 462959	EKATERINA FOMINA	{"phone": "+70558378884"}
0005435613728	1AB242	3900 281260	LYUDMILA ZOTOVA	{"email": "lyudmilazotova.1986@postgrespro.ru", "phone": "+70169394891"}
0005435613729	575D96	7454 716861	NADEZHDA NIKIFOROVA	{"phone": "+70668550836"}
0005435613730	107627	9309 006198	ELENA FROLOVA	{"email": "frolova.e20061957@postgrespro.ru", "phone": "+70896212697"}
0005435613731	4BA005	7560 446489	ALEKSANDRA AKIMOVA	{"email": "aakimova.1967@postgrespro.ru", "phone": "+70593034216"}
0005435613732	4BA005	4412 064156	NIKOLAY OSIPOV	{"email": "osipov-nikolay-02071972@postgrespro.ru", "phone": "+70898527414"}
0005435613733	B75E4E	1275 743270	MAKSIM TARASOV	{"email": "maksim_tarasov.1978@postgrespro.ru", "phone": "+70744837951"}
0005435613734	B75E4E	0908 477177	GLEB KULIKOV	{"email": "g_kulikov011972@postgrespro.ru", "phone": "+70107613300"}
0005435613735	189BAD	9613 123790	SERGEY CHERNOV	{"email": "chernov_s_01061957@postgrespro.ru", "phone": "+70996009960"}
0005435613736	C9F171	6245 581447	ZOYA PAVLOVA	{"phone": "+70492105086"}
0005435613737	EDA6F0	3539 535389	LYUDMILA KARPOVA	{"email": "l_karpova-17051968@postgrespro.ru", "phone": "+70924601682"}
0005435613738	EDA6F0	8569 285747	OKSANA NIKIFOROVA	{"email": "oksana-nikiforova_1976@postgrespro.ru", "phone": "+70107467327"}
0005435613739	9D663F	4873 344843	ALEKSANDR FEDOTOV	{"phone": "+70999008896"}
0005435613740	9D663F	2697 003399	ALEKSEY IVANOV	{"phone": "+70629786451"}
0005435613741	9D663F	1752 873696	ANTON DMITRIEV	{"email": "anton_dmitriev_29061961@postgrespro.ru", "phone": "+70818842883"}
0005435613742	CFC6E2	8078 902543	ANTONINA FEDOROVA	{"email": "antonina_fedorova18081976@postgrespro.ru", "phone": "+70930244519"}
0005435613743	C5FB9E	4026 216548	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov1979@postgrespro.ru", "phone": "+70047154983"}
0005435613744	45427C	3204 771335	LIDIYA ORLOVA	{"email": "orlova_lidiya071975@postgrespro.ru", "phone": "+70962412825"}
0005435613745	E4E792	0993 929889	YURIY PETROV	{"phone": "+70348707935"}
0005435613746	8FDD64	2556 211448	ALEKSANDR KUZNECOV	{"phone": "+70912260464"}
0005435613747	8FDD64	3798 104943	NIKOLAY MIKHAYLOV	{"phone": "+70503105182"}
0005435613748	8FDD64	3936 333056	VALENTINA NAZAROVA	{"email": "valentina_nazarova-1970@postgrespro.ru", "phone": "+70230688622"}
0005435613749	D1A3A2	4820 991568	YURIY VASILEV	{"phone": "+70394523543"}
0005435613750	46386E	8867 271416	LILIYA SERGEEVA	{"phone": "+70206442506"}
0005435613751	AB8A52	7797 842420	IRINA OSIPOVA	{"email": "osipova.i_041966@postgrespro.ru", "phone": "+70493247241"}
0005435613752	A08BD9	8734 913244	ALEKSANDR NIKOLAEV	{"email": "a.nikolaev.26031987@postgrespro.ru", "phone": "+70264231059"}
0005435613753	0B8BA8	4858 678871	MARIYA GRISHINA	{"email": "grishina_mariya081975@postgrespro.ru", "phone": "+70890750924"}
0005435613754	6EFE26	2100 984641	VALENTINA KOZLOVA	{"email": "vkozlova_1971@postgrespro.ru", "phone": "+70119852244"}
0005435613755	E97A58	7176 469536	SVETLANA NIKIFOROVA	{"phone": "+70551945590"}
0005435613756	E97A58	5624 755810	MARINA ZAKHAROVA	{"email": "marinazakharova-19091980@postgrespro.ru", "phone": "+70967007050"}
0005435613757	E97A58	0024 911299	MAKSIM MAKAROV	{"email": "mmakarov_17071972@postgrespro.ru", "phone": "+70439043449"}
0005435613758	2C9EAE	4690 403478	NATALYA ANDREEVA	{"email": "natalya-andreeva-071973@postgrespro.ru", "phone": "+70847768394"}
0005435613759	9C8A6D	6375 407231	SERGEY ANDREEV	{"phone": "+70402687727"}
0005435613760	9C8A6D	6342 579793	RINAT GERASIMOV	{"email": "rgerasimov1978@postgrespro.ru", "phone": "+70577354656"}
0005435613761	912AD6	6065 714695	MAKSIM GRIGOREV	{"phone": "+70176514887"}
0005435613762	46E318	9751 578132	ALEKSANDR ZAYCEV	{"phone": "+70932279216"}
0005435613763	F83006	1549 885243	NATALYA MOROZOVA	{"email": "morozova-natalya031977@postgrespro.ru", "phone": "+70562196711"}
0005435613764	F83006	4945 912043	TAMARA POPOVA	{"email": "popova-tamara-1966@postgrespro.ru", "phone": "+70622635093"}
0005435613765	A13E1B	2720 211554	LYUDMILA YAKOVLEVA	{"email": "yakovleva.l071967@postgrespro.ru", "phone": "+70128184264"}
0005435613766	E90C31	1552 572133	EVGENIYA MAKAROVA	{"phone": "+70078183870"}
0005435613767	E90C31	1421 546361	SERGEY NIKITIN	{"email": "snikitin.14101975@postgrespro.ru", "phone": "+70163475747"}
0005435613768	EC4221	5764 173371	ANATOLIY IVANOV	{"phone": "+70012010888"}
0005435613769	EC4221	0441 606334	GALINA EGOROVA	{"email": "g-egorova-021967@postgrespro.ru", "phone": "+70942249152"}
0005435613770	007C0D	5127 695979	BORIS TARASOV	{"email": "tarasovboris.09071991@postgrespro.ru", "phone": "+70861324165"}
0005435613771	007C0D	3787 999760	LYUBOV TIMOFEEVA	{"email": "l-timofeeva031978@postgrespro.ru", "phone": "+70952879464"}
0005435613772	CC12C5	4963 782733	ALEKSANDR MIRONOV	{"phone": "+70268254909"}
0005435613773	DC4E73	8610 243519	NATALYA ABRAMOVA	{"phone": "+70119094353"}
0005435613774	F0EBD1	7674 285366	NADEZHDA PAVLOVA	{"email": "nadezhda-pavlova16091957@postgrespro.ru", "phone": "+70841004670"}
0005435613775	5AB932	6866 972037	ALEKSEY ZAKHAROV	{"phone": "+70726128284"}
0005435613776	5AB932	2169 948648	ALLA KISELEVA	{"phone": "+70849569817"}
0005435613777	CB9237	9349 044438	NIKOLAY KARPOV	{"email": "karpov_n_09031964@postgrespro.ru", "phone": "+70151198558"}
0005435613778	6E6F8D	8119 567132	LYUBOV MIKHAYLOVA	{"phone": "+70150551695"}
0005435613835	F297E3	2117 518156	GRIGORIY NAZAROV	{"phone": "+70369958010"}
0005435613779	6E6F8D	3915 587963	ANASTASIYA KOROLEVA	{"email": "korolevaanastasiya.06061987@postgrespro.ru", "phone": "+70839012942"}
0005435613780	1BA835	3268 720626	SERGEY BORISOV	{"phone": "+70435518934"}
0005435613781	1BA835	0498 261965	SERGEY AFANASEV	{"email": "sergey_afanasev-1980@postgrespro.ru", "phone": "+70362232725"}
0005435613782	94D63B	3516 017011	ROMAN POPOV	{"email": "roman.popov.05091976@postgrespro.ru", "phone": "+70468454822"}
0005435613783	94D63B	1652 278040	EKATERINA BELYAEVA	{"email": "belyaeva-e081977@postgrespro.ru", "phone": "+70903432914"}
0005435613784	A4F7F2	9802 733019	ALEKSANDR VASILEV	{"phone": "+70788647722"}
0005435613785	8D9108	8542 216988	VLADIMIR DAVYDOV	{"phone": "+70950231080"}
0005435613786	59B691	8357 210316	VALENTIN DMITRIEV	{"phone": "+70757450951"}
0005435613787	A77F45	9425 056035	ELENA EFIMOVA	{"email": "elena_efimova021967@postgrespro.ru", "phone": "+70076912659"}
0005435613788	03B9B6	7215 157497	VLADIMIR NIKITIN	{"email": "vladimir-nikitin_1977@postgrespro.ru", "phone": "+70287280654"}
0005435613789	859B6E	3971 211081	VLADISLAV IVANOV	{"email": "vladislav-ivanov.111975@postgrespro.ru", "phone": "+70477214960"}
0005435613790	4BE0D9	1799 441623	TATYANA KARPOVA	{"email": "tatyana.karpova_1979@postgrespro.ru", "phone": "+70325832276"}
0005435613791	F4AEAA	0229 661875	ZOYA GERASIMOVA	{"email": "zoyagerasimova.03011979@postgrespro.ru", "phone": "+70265748381"}
0005435613792	C38F26	8523 354197	IVAN ABRAMOV	{"email": "i.abramov01021963@postgrespro.ru", "phone": "+70177549151"}
0005435613793	B78DA6	9649 520638	ANTONINA GUSEVA	{"phone": "+70494832088"}
0005435613794	D8AB29	5703 374321	VIKTOR MAKSIMOV	{"email": "maksimov-v_18071974@postgrespro.ru", "phone": "+70425234213"}
0005435613795	EA90DA	9346 664217	NIKOLAY VOLKOV	{"email": "n-volkov.25091959@postgrespro.ru", "phone": "+70278471816"}
0005435613796	EA90DA	9565 366070	MAKSIM ROMANOV	{"phone": "+70419312985"}
0005435613797	EC9765	7798 725480	ANASTASIYA IVANOVA	{"email": "ivanova_anastasiya081986@postgrespro.ru", "phone": "+70749930059"}
0005435613798	C690E4	5662 560815	SVETLANA TIKHONOVA	{"email": "svetlana-tikhonova.111966@postgrespro.ru", "phone": "+70677611116"}
0005435613799	27AB93	6718 752353	KAMILLA NESTEROVA	{"email": "k-nesterova-14061971@postgrespro.ru", "phone": "+70756551502"}
0005435613800	338A21	6202 182574	ALEKSANDR SERGEEV	{"email": "sergeeva.20011961@postgrespro.ru", "phone": "+70079150421"}
0005435613801	62F466	2632 623673	ARTEM SIDOROV	{"phone": "+70479106605"}
0005435613802	48334D	7136 301521	MARINA VOLKOVA	{"email": "volkova-m-121961@postgrespro.ru", "phone": "+70732559947"}
0005435613803	56CE0D	8510 366017	VALERIYA ALEKSEEVA	{"email": "alekseeva.v-29091968@postgrespro.ru", "phone": "+70859421800"}
0005435613804	56CE0D	8967 171728	KSENIYA IVANOVA	{"email": "kseniya_ivanova1977@postgrespro.ru", "phone": "+70658102819"}
0005435613805	4D9295	2102 005561	ALEKSEY ROMANOV	{"email": "romanov_aleksey.10011961@postgrespro.ru", "phone": "+70964661358"}
0005435613806	72D656	6761 139055	LYUBOV VASILEVA	{"phone": "+70240242733"}
0005435613807	72D656	9767 819867	DMITRIY SEMENOV	{"email": "dsemenov071963@postgrespro.ru", "phone": "+70274630414"}
0005435613808	5C1ECF	1873 303375	OLGA ANTONOVA	{"email": "olga.antonova.17061974@postgrespro.ru", "phone": "+70039012059"}
0005435613809	18AE27	2637 337809	SERGEY NAZAROV	{"email": "snazarov-1970@postgrespro.ru", "phone": "+70178250542"}
0005435613810	02F53B	6156 871900	ALEKSANDR KULIKOV	{"phone": "+70601279625"}
0005435613811	1F9C81	8227 715429	SERGEY BORISOV	{"email": "borisov.s071977@postgrespro.ru", "phone": "+70009325641"}
0005435613812	366681	6858 741966	KRISTINA TIKHONOVA	{"phone": "+70045769305"}
0005435613813	2A3132	3819 737174	DMITRIY KISELEV	{"email": "d-kiselev-071972@postgrespro.ru", "phone": "+70827750632"}
0005435613814	2A3132	2337 765048	TATYANA SERGEEVA	{"email": "tatyana_sergeeva.111967@postgrespro.ru", "phone": "+70579291722"}
0005435613815	C81F8C	7163 490060	SERGEY KUZNECOV	{"phone": "+70106352615"}
0005435613816	C81F8C	5160 925043	ELENA GUSEVA	{"email": "guseva-e_1969@postgrespro.ru", "phone": "+70572255015"}
0005435613817	99AC5D	4160 365567	VIKTOR KOZLOV	{"email": "v_kozlov.031970@postgrespro.ru", "phone": "+70646146278"}
0005435613818	99AC5D	9049 080579	EVGENIY OSIPOV	{"phone": "+70987112668"}
0005435613819	D9D5F9	3522 806543	LYUDMILA ZAKHAROVA	{"phone": "+70022578337"}
0005435613820	ACA037	7258 402289	TATYANA BORISOVA	{"email": "t_borisova-031967@postgrespro.ru", "phone": "+70915695446"}
0005435613821	5FD9F7	8129 959408	ALEKSEY KONOVALOV	{"email": "konovalov-a-1960@postgrespro.ru", "phone": "+70117527961"}
0005435613822	5FD9F7	1385 184549	ROZA MOROZOVA	{"email": "roza_morozova_1972@postgrespro.ru", "phone": "+70797802536"}
0005435613823	586A81	2585 934906	YURIY FOMIN	{"phone": "+70622447037"}
0005435613824	586A81	6180 192592	YURIY SERGEEV	{"phone": "+70457127403"}
0005435613825	E823B6	9498 265901	MIKHAIL GUSEV	{"email": "gusev-mikhail.30041990@postgrespro.ru", "phone": "+70254602938"}
0005435613826	93D52E	9354 157397	ANATOLIY VOLKOV	{"email": "volkovanatoliy-06121964@postgrespro.ru", "phone": "+70516293558"}
0005435613827	1F86AB	4175 369252	SERAFIMA KUZNECOVA	{"email": "s.kuznecova121971@postgrespro.ru", "phone": "+70412817680"}
0005435613828	D2EF21	0931 477661	NIKOLAY BELOV	{"email": "nikolay.belov02091967@postgrespro.ru", "phone": "+70541825968"}
0005435613829	3EC37C	6869 983761	ALEKSANDR OSIPOV	{"email": "osipova_101976@postgrespro.ru", "phone": "+70563168418"}
0005435613830	508E25	5793 537437	IVAN DMITRIEV	{"email": "dmitrievi-111970@postgrespro.ru", "phone": "+70449509023"}
0005435613831	C1AB1E	8472 252327	MARGARITA BELOVA	{"email": "belova.margarita_081985@postgrespro.ru", "phone": "+70566742386"}
0005435613832	A3FFEA	0367 958656	VIKTOR BARANOV	{"email": "baranov-viktor091973@postgrespro.ru", "phone": "+70379656522"}
0005435613833	2574B5	4994 441111	VALENTINA KOMAROVA	{"email": "v_komarova.1967@postgrespro.ru", "phone": "+70802948310"}
0005435613834	F297E3	9466 222007	KSENIYA MALYSHEVA	{"phone": "+70976486481"}
0005435613836	EFACAF	7511 496346	VALENTINA ANDREEVA	{"email": "andreevav-1966@postgrespro.ru", "phone": "+70434718525"}
0005435613838	59171C	0953 912456	OLGA ANDREEVA	{"phone": "+70860621443"}
0005435613839	40C341	4873 772989	GALINA ZAKHAROVA	{"phone": "+70468701247"}
0005435613840	BCC6A7	5081 382088	NATALYA DAVYDOVA	{"phone": "+70207825340"}
0005435613841	F633C0	9082 777450	ALEKSEY VASILEV	{"email": "a-vasilev_10031971@postgrespro.ru", "phone": "+70685786340"}
0005435613842	F633C0	3396 011006	ELIZAVETA NESTEROVA	{"phone": "+70724845984"}
0005435613843	A18B43	6088 635677	MARINA SOKOLOVA	{"phone": "+70729454443"}
0005435613844	A18B43	7370 572692	LYUBOV AKIMOVA	{"phone": "+70730572545"}
0005435613845	9F4C00	8544 185017	MARIYA ZAKHAROVA	{"email": "zakharova-mariya_02041970@postgrespro.ru", "phone": "+70919462694"}
0005435613846	9F4C00	6835 157674	ALEKSANDR KUZNECOV	{"phone": "+70100102411"}
0005435613847	9F4C00	8519 141191	VIKTOR MIKHAYLOV	{"email": "viktor.mikhaylov-031972@postgrespro.ru", "phone": "+70197074026"}
0005435613848	B03A78	7514 709460	MARIYA ZAKHAROVA	{"phone": "+70753281312"}
0005435613849	B03A78	1617 341324	VIKTOR STEPANOV	{"email": "viktorstepanov_05101972@postgrespro.ru", "phone": "+70752508578"}
0005435613850	FCCED8	9181 343653	MARIYA AFANASEVA	{"phone": "+70506466337"}
0005435613851	7D9D74	3657 157695	IRINA PAVLOVA	{"phone": "+70502610555"}
0005435613852	C6CBF5	3748 569128	VALENTINA GORBUNOVA	{"phone": "+70895536015"}
0005435613853	E2D781	3975 202041	DMITRIY NIKOLAEV	{"phone": "+70281408413"}
0005435613854	4D3C26	3842 801987	ALEKSANDR ZHURAVLEV	{"email": "zhuravlev.a-24081981@postgrespro.ru", "phone": "+70434276158"}
0005435613855	CA1F89	3706 597788	ALEKSEY KISELEV	{"email": "a.kiselev-27031974@postgrespro.ru", "phone": "+70640662032"}
0005435613856	1D3B06	6693 039397	ALEKSANDR VOROBEV	{"phone": "+70653409517"}
0005435613857	1D3B06	8369 414971	ANTON SAVELEV	{"email": "saveleva.081965@postgrespro.ru", "phone": "+70714854155"}
0005435613858	423915	8066 363524	YULIYA TIMOFEEVA	{"email": "yuliya.timofeeva_081968@postgrespro.ru", "phone": "+70026272375"}
0005435613859	423915	3637 250548	ILYA KULIKOV	{"email": "ilya-kulikov-081975@postgrespro.ru", "phone": "+70193824013"}
0005435613860	FE4732	4051 017615	EKATERINA VOLKOVA	{"email": "volkova.ekaterina-031976@postgrespro.ru", "phone": "+70215202210"}
0005435613861	A6B6C6	5425 298559	ARTEM KOROLEV	{"phone": "+70934319244"}
0005435613862	A6B6C6	8066 086739	VLADIMIR ANTONOV	{"phone": "+70021440449"}
0005435613863	0ACBA3	1789 435870	TATYANA GAVRILOVA	{"email": "gavrilova.t.14061974@postgrespro.ru", "phone": "+70046915655"}
0005435613864	D00158	2668 832993	DMITRIY FOMIN	{"email": "dmitriyfomin-23061975@postgrespro.ru", "phone": "+70247886513"}
0005435613865	19087E	7535 738972	EKATERINA ARKHIPOVA	{"phone": "+70555462599"}
0005435613866	C20972	8172 075638	ALEKSANDR SERGEEV	{"email": "a-sergeev_1963@postgrespro.ru", "phone": "+70280804687"}
0005435613867	C20972	2619 711127	ANDREY MOROZOV	{"phone": "+70166502743"}
0005435613868	145A72	9787 148492	ALEKSEY ALEKSANDROV	{"email": "aleksey_aleksandrov-02121972@postgrespro.ru", "phone": "+70573847025"}
0005435613869	145A72	5391 285904	SVETLANA KUZNECOVA	{"email": "kuznecova_s1972@postgrespro.ru", "phone": "+70583657613"}
0005435613870	BE5C85	7891 674532	VIKTOR OSIPOV	{"email": "osipov.viktor1961@postgrespro.ru", "phone": "+70690816373"}
0005435613871	C45C14	6513 065151	ALEKSANDR GORBUNOV	{"phone": "+70525224186"}
0005435613872	E03436	5432 520267	NADEZHDA ZAKHAROVA	{"phone": "+70903587125"}
0005435613873	8000A3	1828 989808	GALINA KISELEVA	{"phone": "+70407645956"}
0005435613874	A24FB3	1086 185456	NIKOLAY KUZNECOV	{"phone": "+70934520915"}
0005435613875	A24FB3	5241 449739	ALEKSANDR ROMANOV	{"phone": "+70237541867"}
0005435613876	A24FB3	7292 427562	MIKHAIL IVANOV	{"email": "mikhailivanov_1972@postgrespro.ru", "phone": "+70248643143"}
0005435613877	C5ED43	5881 660887	NINA BORISOVA	{"phone": "+70081664956"}
0005435613878	183113	9045 154917	ARSENIY NAZAROV	{"email": "nazarova.111967@postgrespro.ru", "phone": "+70199152017"}
0005435613879	183113	9734 804601	OLEG PAVLOV	{"email": "pavlov_oleg071966@postgrespro.ru", "phone": "+70759738633"}
0005435613880	183113	5575 085536	SERGEY STEPANOV	{"email": "sergey-stepanov.1966@postgrespro.ru", "phone": "+70180337770"}
0005435613881	EB9737	7443 012124	ELENA ANDREEVA	{"email": "andreevae011971@postgrespro.ru", "phone": "+70036674813"}
0005435613882	EB9737	6356 742336	NIKOLAY NIKITIN	{"email": "nikolaynikitin.23031970@postgrespro.ru", "phone": "+70188267689"}
0005435613883	5B8CEC	5249 976808	ALEKSANDR SIDOROV	{"phone": "+70507210140"}
0005435613884	F5E3E6	8945 017299	PETR GAVRILOV	{"email": "p-gavrilov.011976@postgrespro.ru", "phone": "+70416915367"}
0005435613885	F5E3E6	1188 135094	OLGA MIKHAYLOVA	{"email": "olga_mikhaylova_18021970@postgrespro.ru", "phone": "+70290494688"}
0005435613886	6AC6CC	2049 097838	VYACHESLAV SIDOROV	{"email": "sidorov-v021973@postgrespro.ru", "phone": "+70207119235"}
0005435613887	9ACF01	6712 616728	VITALIY FEDOROV	{"phone": "+70495319289"}
0005435613888	CF3C0A	7694 877957	NADEZHDA TIKHONOVA	{"phone": "+70920839732"}
0005435613889	CF3C0A	9982 203822	EKATERINA NESTEROVA	{"phone": "+70825692698"}
0005435613890	99F41F	8293 340703	VERA ORLOVA	{"phone": "+70668022660"}
0005435613891	FBFB8D	5665 842013	VLADIMIR CHERNOV	{"phone": "+70077266832"}
0005435613892	FBFB8D	1821 863139	RAVIL FEDOROV	{"phone": "+70868610753"}
0005435613893	6E3BB6	4208 254996	EKATERINA NOVIKOVA	{"email": "novikova_e.011972@postgrespro.ru", "phone": "+70421686444"}
0005435613894	6E3BB6	5467 571751	MARIYA GORBUNOVA	{"phone": "+70885435626"}
0005435613895	7CDC3B	6140 637213	MARINA GERASIMOVA	{"phone": "+70507932956"}
0005435613896	7CDC3B	0692 517859	IRINA GAVRILOVA	{"email": "gavrilovairina_1980@postgrespro.ru", "phone": "+70974933834"}
0005435613897	7CDC3B	0506 099152	ALEKSANDRA KUZMINA	{"email": "kuzminaaleksandra29101968@postgrespro.ru", "phone": "+70797150202"}
0005435613898	0ADE6F	0858 093387	ARTEM SERGEEV	{"email": "a_sergeev_10091975@postgrespro.ru", "phone": "+70093111664"}
0005435613899	6EF75B	4519 984801	TATYANA MOROZOVA	{"email": "tmorozova_071976@postgrespro.ru", "phone": "+70937930864"}
0005435613900	6EF75B	0143 216539	PETR MOROZOV	{"email": "p_morozov_1970@postgrespro.ru", "phone": "+70132432848"}
0005435613901	6EF75B	2071 283128	ELENA KAZAKOVA	{"email": "e-kazakova111973@postgrespro.ru", "phone": "+70838462059"}
0005435613902	133B42	5349 986581	IRINA GAVRILOVA	{"email": "irina_gavrilova121981@postgrespro.ru", "phone": "+70646749766"}
0005435613903	F58021	2219 273181	ARTEM KUZNECOV	{"email": "kuznecov-a.07041973@postgrespro.ru", "phone": "+70444552101"}
0005435613904	25463F	5557 008296	DMITRIY NOVIKOV	{"email": "dmitriy-novikov-1973@postgrespro.ru", "phone": "+70599841330"}
0005435613905	5B7596	0546 851496	ELENA ANDREEVA	{"phone": "+70787971490"}
0005435613906	9F55A2	4321 723088	DMITRIY DENISOV	{"phone": "+70486279678"}
0005435613907	203970	3873 206276	ANDREY ZAKHAROV	{"email": "zakharov-a.031969@postgrespro.ru", "phone": "+70108476274"}
0005435613908	DE995F	0025 534953	LARISA SIDOROVA	{"phone": "+70602581464"}
0005435613909	DE995F	3001 536615	SERGEY NIKOLAEV	{"email": "nikolaev-sergey-15091974@postgrespro.ru", "phone": "+70974066985"}
0005435613910	71E52C	9615 560928	OLGA FROLOVA	{"email": "frolova.olga-1976@postgrespro.ru", "phone": "+70000938082"}
0005435613911	BA37B1	1159 264777	ALEKSANDR ROMANOV	{"phone": "+70272960985"}
0005435613912	BA37B1	7811 660257	DMITRIY GRIGOREV	{"email": "grigorev.dmitriy_24101978@postgrespro.ru", "phone": "+70350225880"}
0005435613913	BA37B1	3917 663944	ALEKSANDR EGOROV	{"phone": "+70791635323"}
0005435613914	D6A6DE	4534 537179	ELENA ZAKHAROVA	{"phone": "+70308449460"}
0005435613915	4F441E	2991 756336	MAKSIM ZAKHAROV	{"email": "maksim.zakharov.061972@postgrespro.ru", "phone": "+70523265818"}
0005435613916	2C83D6	5756 074179	TATYANA ROMANOVA	{"phone": "+70221536621"}
0005435613917	F36332	3581 143122	DMITRIY KUDRYASHOV	{"email": "kudryashov_dmitriy.061969@postgrespro.ru", "phone": "+70314746183"}
0005435613918	F36332	6072 585085	VALERIY BORISOV	{"phone": "+70895225447"}
0005435613919	1CBC9C	1988 356541	GENNADIY ROMANOV	{"email": "g-romanov.11041974@postgrespro.ru", "phone": "+70352172517"}
0005435613920	1CBC9C	3896 343134	LYUDMILA MOROZOVA	{"email": "lyudmila-morozova08121963@postgrespro.ru", "phone": "+70677611251"}
0005435613921	61DE5A	9503 386899	ANDREY MIKHAYLOV	{"phone": "+70857668487"}
0005435613922	61DE5A	7304 284892	RIMMA NESTEROVA	{"email": "rimma_nesterova071980@postgrespro.ru", "phone": "+70541483879"}
0005435613923	F5B576	5570 499542	IVAN EGOROV	{"phone": "+70542875132"}
0005435613924	F364F1	9431 203098	ELENA SERGEEVA	{"phone": "+70376474207"}
0005435613925	F364F1	0171 786014	OLEG KOZLOV	{"email": "kozlov-oleg.02061972@postgrespro.ru", "phone": "+70077197795"}
0005435613926	039E3B	6960 183815	ALEKSANDR ROMANOV	{"email": "romanovaleksandr-1977@postgrespro.ru", "phone": "+70956472188"}
0005435613927	039E3B	9757 935010	LILIYA SCHERBAKOVA	{"phone": "+70911949036"}
0005435613928	1CF405	7905 803400	MIKHAIL GERASIMOV	{"email": "mikhailgerasimov1980@postgrespro.ru", "phone": "+70016757494"}
0005435613929	1CF405	6374 403781	ILDUS VOLKOV	{"phone": "+70263598664"}
0005435613930	1CF405	4310 381500	SERGEY KONOVALOV	{"email": "konovalov.sergey.081979@postgrespro.ru", "phone": "+70653604893"}
0005435613931	B2FE88	2954 401518	VYACHESLAV MAKAROV	{"email": "makarov_v-1985@postgrespro.ru", "phone": "+70890931376"}
0005435613932	B2FE88	6643 578647	IRINA MEDVEDEVA	{"phone": "+70770821267"}
0005435613933	BECB15	4123 813309	DARYA POLYAKOVA	{"phone": "+70942132236"}
0005435613934	A5442A	7818 254915	DMITRIY ZHURAVLEV	{"email": "zhuravlev_d-1980@postgrespro.ru", "phone": "+70180701175"}
0005435613935	D8457B	9023 276927	YANA MIKHAYLOVA	{"email": "mikhaylova.yana.15021971@postgrespro.ru", "phone": "+70162423041"}
0005435613936	320452	1771 888324	VITALIY KUZNECOV	{"email": "kuznecov.v.16071968@postgrespro.ru", "phone": "+70870155106"}
0005435613937	320452	6670 850408	BOGDAN KUZNECOV	{"email": "kuznecov_b_011960@postgrespro.ru", "phone": "+70041419923"}
0005435613938	320452	2295 625288	OLGA KUZMINA	{"phone": "+70584530506"}
0005435613939	6C93DD	5909 083942	SVETLANA MAKAROVA	{"phone": "+70237271759"}
0005435613940	6F44FF	7052 670921	ROMAN IVANOV	{"phone": "+70277740252"}
0005435613941	B43BE3	6928 082771	NINA SOLOVEVA	{"email": "n_soloveva01041974@postgrespro.ru", "phone": "+70850447369"}
0005435613942	B43BE3	3861 005561	NINA SCHERBAKOVA	{"phone": "+70109769441"}
0005435613943	B43BE3	3643 609456	EDUARD KUZNECOV	{"email": "eduard_kuznecov_18011979@postgrespro.ru", "phone": "+70473903800"}
0005435613944	74EEC1	2800 418744	ANNA ZOTOVA	{"email": "a_zotova.28021979@postgrespro.ru", "phone": "+70074062302"}
0005435613945	74EEC1	7531 131687	ALEKSANDR MIRONOV	{"email": "aleksandr.mironov.061969@postgrespro.ru", "phone": "+70764159929"}
0005435613946	D2C38D	9953 592537	EKATERINA SOROKINA	{"email": "sorokina_ekaterina-1964@postgrespro.ru", "phone": "+70315800166"}
0005435613947	D2C38D	7548 088386	ALEKSEY FEDOROV	{"email": "fedorov_a_051967@postgrespro.ru", "phone": "+70064524636"}
0005435613948	6CD562	6317 689517	KSENIYA NIKIFOROVA	{"email": "kseniya.nikiforova.1966@postgrespro.ru", "phone": "+70691773964"}
0005435613949	6CD562	2465 346533	ALEKSEY KOROLEV	{"email": "aleksey_korolev_061978@postgrespro.ru", "phone": "+70294872525"}
0005435613950	3AF5F8	6583 132615	OLGA PETROVA	{"email": "o-petrova.1986@postgrespro.ru", "phone": "+70928790066"}
0005435613951	2E8CC8	0913 692733	LIDIYA MOROZOVA	{"phone": "+70715682590"}
0005435613952	006084	6909 602799	MIKHAIL YAKOVLEV	{"email": "yakovlev_mikhail-14101974@postgrespro.ru", "phone": "+70361246883"}
0005435613953	006084	7711 767939	ANNA AFANASEVA	{"email": "afanaseva.a031969@postgrespro.ru", "phone": "+70546967557"}
0005435613954	5A2B01	1729 484071	NATALYA YUDINA	{"phone": "+70791706261"}
0005435613955	F14C18	0370 005278	TATYANA AFANASEVA	{"phone": "+70954478468"}
0005435613956	F14C18	2526 971713	SVETLANA MIKHAYLOVA	{"phone": "+70792830017"}
0005435613957	38E556	6188 007507	ELENA KUDRYASHOVA	{"phone": "+70230608218"}
0005435613958	2E74A1	2729 611265	LUIZA ZHUKOVA	{"phone": "+70630539978"}
0005435613959	E33488	2682 439679	KIRILL IVANOV	{"phone": "+70189288151"}
0005435613960	E33488	2281 995776	MARIYA KOLESNIKOVA	{"email": "m_kolesnikova-1979@postgrespro.ru", "phone": "+70378268512"}
0005435613961	E33488	1404 714060	NIKOLAY VASILEV	{"email": "vasilev-nikolay-121973@postgrespro.ru", "phone": "+70175016077"}
0005435613962	E09385	3428 015541	ALEKSEY SIDOROV	{"phone": "+70780825488"}
0005435613963	E09385	4121 144330	NINA FROLOVA	{"phone": "+70292339245"}
0005435613964	E09385	8043 362241	LYUDMILA TIKHONOVA	{"email": "tikhonovalyudmila-1975@postgrespro.ru", "phone": "+70021107570"}
0005435613965	2319F1	0832 281150	MIKHAIL SEMENOV	{"email": "mikhail_semenov-07081975@postgrespro.ru", "phone": "+70222082089"}
0005435613966	9F16A1	7971 217935	NADEZHDA ROMANOVA	{"email": "n.romanova_28021979@postgrespro.ru", "phone": "+70414640981"}
0005435613967	03872A	6622 622719	MAKSIM BELOV	{"email": "belov_maksim.061977@postgrespro.ru", "phone": "+70535921918"}
0005435613968	8B6C35	4890 282016	VLADISLAV FEDOTOV	{"email": "fedotov-vladislav28061978@postgrespro.ru", "phone": "+70485826064"}
0005435613969	8B6C35	6586 434195	SVETLANA MALYSHEVA	{"email": "s.malysheva1978@postgrespro.ru", "phone": "+70772505553"}
0005435613970	3CEB84	8969 134830	VLADIMIR KULIKOV	{"email": "vladimir_kulikov-1973@postgrespro.ru", "phone": "+70642518753"}
0005435613971	ADA39E	3405 002081	NATALYA BELYAEVA	{"email": "n-belyaeva_111972@postgrespro.ru", "phone": "+70345814028"}
0005435613972	9398B0	2340 043590	TATYANA ANISIMOVA	{"phone": "+70508702096"}
0005435613973	17C0F3	5319 480190	DARYA FROLOVA	{"phone": "+70395354589"}
0005435613974	17C0F3	7555 047630	ANASTASIYA POPOVA	{"phone": "+70559286071"}
0005435613975	0623F5	8587 998666	VYACHESLAV PAVLOV	{"phone": "+70435421802"}
0005435613976	0623F5	8804 899285	NATALYA KULIKOVA	{"email": "n.kulikova_031969@postgrespro.ru", "phone": "+70023439598"}
0005435613977	1AD0FF	6454 272118	ALEKSANDRA FOMINA	{"email": "aleksandra_fomina_1981@postgrespro.ru", "phone": "+70714736956"}
0005435613978	B18924	5649 992356	BOGDAN AFANASEV	{"email": "b.afanasev_091977@postgrespro.ru", "phone": "+70110558296"}
0005435613979	58FD2C	0379 638003	SOFIYA ANDREEVA	{"email": "sofiya_andreeva121966@postgrespro.ru", "phone": "+70857070169"}
0005435613980	58FD2C	2588 558819	RUSLAN ABRAMOV	{"phone": "+70606818794"}
0005435613981	668850	2792 812771	YULIYA KARPOVA	{"phone": "+70431028510"}
0005435613982	668850	2670 781431	IRAIDA EGOROVA	{"phone": "+70265261094"}
0005435613983	07C06E	4918 925057	ALEKSEY KUZNECOV	{"phone": "+70229468361"}
0005435613984	02BDF5	4807 547724	ILMIRA STEPANOVA	{"phone": "+70382900539"}
0005435613985	60DB25	9842 509601	NINA FILIPPOVA	{"email": "n_filippova24011973@postgrespro.ru", "phone": "+70247255621"}
0005435613986	60DB25	3291 745621	DENIS ORLOV	{"phone": "+70460471291"}
0005435613987	62FD95	0840 553983	NIKOLAY FROLOV	{"email": "nikolayfrolov27021968@postgrespro.ru", "phone": "+70091015337"}
0005435613988	A7B6B2	1833 147989	ANATOLIY KUZNECOV	{"phone": "+70059700056"}
0005435613989	1DA343	9519 986418	TAMARA OSIPOVA	{"phone": "+70306363419"}
0005435613990	1B5EB6	1744 618879	IRINA FEDOROVA	{"phone": "+70764731000"}
0005435613991	313C29	7777 048191	ILDUS PAVLOV	{"phone": "+70860657644"}
0005435613992	497AFF	2034 117008	ANATOLIY SERGEEV	{"email": "sergeev-a-02101984@postgrespro.ru", "phone": "+70167033595"}
0005435613993	994F07	7317 565349	ANDREY ILIN	{"email": "ilin-andrey28101983@postgrespro.ru", "phone": "+70627018295"}
0005435613994	5AA44B	6271 527520	NIKOLAY KUZNECOV	{"phone": "+70328464862"}
0005435613995	B4C585	7035 852874	LEONID IVANOV	{"email": "ivanov-l.111970@postgrespro.ru", "phone": "+70014971582"}
0005435613996	9018F3	5582 751617	GEORGIY TIMOFEEV	{"phone": "+70787010957"}
0005435613997	9018F3	2842 683973	MARIYA KRASNOVA	{"phone": "+70603065470"}
0005435613998	B949E0	2280 024061	NATALYA KUZNECOVA	{"phone": "+70402719788"}
0005435613999	73C67B	9492 516972	IVAN GAVRILOV	{"phone": "+70952179616"}
0005435614000	CFD5F7	3623 373256	SERGEY SMIRNOV	{"email": "ssmirnov071973@postgrespro.ru", "phone": "+70030968107"}
0005435614001	CFD5F7	9324 325063	PETR SOROKIN	{"phone": "+70070790805"}
0005435614002	468972	3136 994210	IRINA ANTONOVA	{"phone": "+70314090844"}
0005435614003	A58A1E	9709 170720	VASILIY FOMIN	{"phone": "+70299247127"}
0005435614004	6FFD7E	6769 690940	NINA FILATOVA	{"email": "filatova.nina051965@postgrespro.ru", "phone": "+70577496850"}
0005435614005	085B4D	8133 491134	KSENIYA ZAKHAROVA	{"phone": "+70321081448"}
0005435614006	3E2EF8	2781 939871	RUSTAM MOROZOV	{"email": "r.morozov_17081967@postgrespro.ru", "phone": "+70191740643"}
0005435614007	CB507E	8533 025548	NATALYA LOGINOVA	{"email": "loginova-n13061978@postgrespro.ru", "phone": "+70538748112"}
0005435614008	CB507E	8935 366134	NELLI POPOVA	{"email": "nelli-popova-1972@postgrespro.ru", "phone": "+70438817852"}
0005435614009	CB507E	0247 783643	YULIYA IVANOVA	{"email": "y-ivanova-06091977@postgrespro.ru", "phone": "+70942351067"}
0005435614010	D13614	2159 447864	ANASTASIYA PAVLOVA	{"email": "apavlova-1968@postgrespro.ru", "phone": "+70352903820"}
0005435614011	D13614	9230 252690	NADEZHDA ROMANOVA	{"email": "nromanova.29081968@postgrespro.ru", "phone": "+70223900075"}
0005435614012	5AA797	7961 268035	SVETLANA TARASOVA	{"phone": "+70050406845"}
0005435614013	0D8C90	3592 994043	VIKTORIYA RYABOVA	{"email": "vryabova-061962@postgrespro.ru", "phone": "+70765801349"}
0005435614014	061D9A	2396 031972	KLAVDIYA SIDOROVA	{"email": "sidorovak_071966@postgrespro.ru", "phone": "+70523317518"}
0005435614015	061D9A	5298 781564	NATALYA BELOVA	{"phone": "+70751525903"}
0005435614016	543204	1319 367951	LARISA VOLKOVA	{"email": "lvolkova-1979@postgrespro.ru", "phone": "+70955686149"}
0005435614017	E5D818	7477 901510	MARAT IVANOV	{"email": "ivanov-m25071976@postgrespro.ru", "phone": "+70728058654"}
0005435614018	0EBF95	3602 550791	EGOR EGOROV	{"phone": "+70410724852"}
0005435614019	0EBF95	3761 014893	TAISIYA KOLESNIKOVA	{"email": "taisiya_kolesnikova091977@postgrespro.ru", "phone": "+70265020193"}
0005435614020	0EBF95	7635 376729	VALENTINA LAZAREVA	{"email": "lazareva-v-22011981@postgrespro.ru", "phone": "+70746760090"}
0005435614021	99D13E	5641 129373	NIKOLAY SCHERBAKOV	{"email": "scherbakov-nikolay041970@postgrespro.ru", "phone": "+70759058470"}
0005435614022	99D13E	7163 675940	ZINAIDA FOMINA	{"phone": "+70879308253"}
0005435614023	53772D	5020 437329	OLGA PAVLOVA	{"phone": "+70374438927"}
0005435614024	53772D	6383 393528	MARINA KUDRYASHOVA	{"phone": "+70809879969"}
0005435614025	155615	4606 942652	IGOR ZAYCEV	{"phone": "+70221965460"}
0005435614026	155615	1605 953798	TAMARA FROLOVA	{"phone": "+70757774735"}
0005435614027	C77B64	4832 789491	VYACHESLAV BARANOV	{"email": "vbaranov11061981@postgrespro.ru", "phone": "+70509335810"}
0005435614028	8607FB	1311 854217	VYACHESLAV VASILEV	{"phone": "+70136123792"}
0005435614029	E221EF	4720 692879	ALLA NESTEROVA	{"phone": "+70606079441"}
0005435614030	E221EF	3975 477976	MIKHAIL FEDOTOV	{"phone": "+70578234316"}
0005435614031	8A048F	2350 812043	RAFAIL FEDOROV	{"phone": "+70681477426"}
0005435614032	F5B842	4319 526705	GENNADIY ZAYCEV	{"phone": "+70073990840"}
0005435614033	F5B842	5632 069179	YURIY ANDREEV	{"phone": "+70058084926"}
0005435614034	F5B842	2356 197323	STEPAN AFANASEV	{"email": "stepanafanasev_1984@postgrespro.ru", "phone": "+70277768974"}
0005435614035	F96E89	0430 588998	TATYANA ROMANOVA	{"email": "romanova_tatyana_1970@postgrespro.ru", "phone": "+70779861396"}
0005435614036	F96E89	4217 382027	VALERIY STEPANOV	{"phone": "+70146479605"}
0005435614037	08F567	5531 765350	VIKTOR ROMANOV	{"email": "viktor_romanov1985@postgrespro.ru", "phone": "+70078724304"}
0005435614038	24654B	3796 167801	ANDREY KUDRYASHOV	{"email": "a_kudryashov1972@postgrespro.ru", "phone": "+70525113595"}
0005435614039	24654B	8410 758158	VLADIMIR IVANOV	{"email": "ivanov-v081988@postgrespro.ru", "phone": "+70208296169"}
0005435614040	22F78E	6842 980925	ALEKSANDR MATVEEV	{"phone": "+70604502204"}
0005435614041	48E6C9	3270 441178	YULIYA MAKAROVA	{"phone": "+70812328098"}
0005435614042	D379D6	3364 010039	ANASTASIYA NOVIKOVA	{"phone": "+70708180016"}
0005435614043	3FDEC5	1245 199892	EVGENIYA VOLKOVA	{"phone": "+70198066260"}
0005435614044	629371	5488 840933	VLADIMIR OSIPOV	{"email": "osipovv.1971@postgrespro.ru", "phone": "+70709121922"}
0005435614045	629371	5194 604380	DMITRIY FILIPPOV	{"email": "dmitriy.filippov-1970@postgrespro.ru", "phone": "+70828479518"}
0005435614046	AD946E	3433 252462	ALEKSEY YAKOVLEV	{"phone": "+70704332210"}
0005435614047	8C7A90	5898 257204	NIKOLAY IVANOV	{"phone": "+70537066350"}
0005435614048	CE13D5	4123 470584	NADEZHDA NIKITINA	{"email": "nikitina_nadezhda.31071966@postgrespro.ru", "phone": "+70237662911"}
0005435614049	CE13D5	0909 381214	ALEKSANDR TARASOV	{"phone": "+70794970380"}
0005435614050	CE13D5	5083 928964	DMITRIY NIKOLAEV	{"email": "nikolaev.d_1961@postgrespro.ru", "phone": "+70518587351"}
0005435614051	49BFA3	3420 896842	ANDREY FROLOV	{"email": "a.frolov.1977@postgrespro.ru", "phone": "+70108215787"}
0005435614052	C54102	7386 621812	OLGA MAKAROVA	{"phone": "+70113860177"}
0005435614053	C18470	7133 614832	ROMAN ZHURAVLEV	{"email": "r_zhuravlev.1965@postgrespro.ru", "phone": "+70098290586"}
0005435614054	5673FC	4877 743498	LIDIYA ZHURAVLEVA	{"email": "lidiya-zhuravleva071963@postgrespro.ru", "phone": "+70373475950"}
0005435614055	597097	1917 552491	SERGEY MIRONOV	{"email": "mironov_s1973@postgrespro.ru", "phone": "+70838999176"}
0005435614056	597097	5480 733639	ALENA BARANOVA	{"phone": "+70245215113"}
0005435614057	E2428A	3818 316286	LYUBOV MOISEEVA	{"phone": "+70602860492"}
0005435614058	0C9256	6096 742618	ALEKSANDR MOROZOV	{"email": "morozov.aleksandr_1969@postgrespro.ru", "phone": "+70515510569"}
0005435614059	607852	4672 883734	IRINA NESTEROVA	{"email": "i_nesterova-01041984@postgrespro.ru", "phone": "+70502479085"}
0005435614060	092E38	4007 825639	ALSU NIKOLAEVA	{"phone": "+70522400682"}
0005435614061	56A813	1869 400446	ANATOLIY DAVYDOV	{"email": "adavydov-17101978@postgrespro.ru", "phone": "+70109249159"}
0005435614062	D0C6AB	0255 094312	ZOYA KUZNECOVA	{"email": "zoya-kuznecova-31051973@postgrespro.ru", "phone": "+70975314990"}
0005435614063	D0C6AB	7017 332448	VLADISLAV KOZLOV	{"email": "vladislav_kozlov-121977@postgrespro.ru", "phone": "+70142815970"}
0005435614064	2F76C4	1134 916829	VLADIMIR ROMANOV	{"email": "romanovvladimir051977@postgrespro.ru", "phone": "+70897636245"}
0005435614065	E5AAC1	2107 847125	SVETLANA POPOVA	{"phone": "+70148415332"}
0005435614066	E8E989	2363 396139	ALEKSEY TIKHONOV	{"phone": "+70632748184"}
0005435614067	E8E989	6567 315306	ELENA FROLOVA	{"phone": "+70568984615"}
0005435614068	C49406	3479 380558	RAISA FILIPPOVA	{"email": "r-filippova031968@postgrespro.ru", "phone": "+70253682831"}
0005435614069	C49406	9555 021844	VITALIY MOROZOV	{"email": "morozovvitaliy-1964@postgrespro.ru", "phone": "+70953882256"}
0005435614070	2C525D	2600 946363	ELENA MAKAROVA	{"email": "elena-makarova-1996@postgrespro.ru", "phone": "+70591328176"}
0005435614071	2C525D	7784 406553	ALEKSANDR TARASOV	{"phone": "+70459113521"}
0005435614072	2C525D	6012 028252	ANASTASIYA FROLOVA	{"phone": "+70135588125"}
0005435614073	C98CA9	9476 319351	DARYA KOZLOVA	{"phone": "+70873561649"}
0005435614074	14CA62	9265 557725	VIKTOR SIDOROV	{"phone": "+70622713201"}
0005435614075	283F38	6248 206045	MARINA SOROKINA	{"phone": "+70049414576"}
0005435614076	72718C	5040 032239	ALEKSEY FOMIN	{"email": "aleksey-fomin_1981@postgrespro.ru", "phone": "+70276518892"}
0005435614077	72718C	5005 492104	SERGEY SOLOVEV	{"email": "sergey_solovev.20061973@postgrespro.ru", "phone": "+70004760070"}
0005435614078	2830C1	6674 746067	OKSANA FEDOROVA	{"email": "fedorova_o-041960@postgrespro.ru", "phone": "+70997454200"}
0005435614079	E2C2CB	2047 668520	NINA KUZMINA	{"phone": "+70859719618"}
0005435614080	C2C017	2155 766110	VIKTOR MAKAROV	{"email": "makarov_v051974@postgrespro.ru", "phone": "+70425491794"}
0005435614081	C2C017	4244 385995	ALEKSANDRA KUZMINA	{"phone": "+70006966837"}
0005435614082	46F287	3330 000510	MARINA PETROVA	{"phone": "+70200873595"}
0005435614083	46F287	9507 455565	ANASTASIYA LAZAREVA	{"phone": "+70912587284"}
0005435614084	77147B	2724 846433	ALEKSANDR ROMANOV	{"email": "romanov-a-091958@postgrespro.ru", "phone": "+70429612918"}
0005435614085	77147B	2172 121611	OLGA KOZLOVA	{"phone": "+70990178144"}
0005435614086	77147B	8067 169536	MAKSIM SOKOLOV	{"email": "m-sokolov.24091980@postgrespro.ru", "phone": "+70468155445"}
0005435614087	272726	4655 159213	IRINA NIKITINA	{"phone": "+70741536455"}
0005435614088	EFBF5A	5685 060229	IGOR ZHUKOV	{"email": "zhukov_igor_1976@postgrespro.ru", "phone": "+70248113726"}
0005435614089	F577FB	9357 446384	VLADIMIR FOMIN	{"phone": "+70294266109"}
0005435614090	CEADC7	8345 952030	GALINA YAKOVLEVA	{"email": "galina-yakovleva_20041980@postgrespro.ru", "phone": "+70845043797"}
0005435614091	CEADC7	6708 545189	ILYA POPOV	{"email": "i.popov041966@postgrespro.ru", "phone": "+70358238785"}
0005435614092	4DFA07	2076 011822	OLEG KONOVALOV	{"email": "konovalov-o-1977@postgrespro.ru", "phone": "+70261770960"}
0005435614093	291A7E	4767 590668	VASILIY KUZNECOV	{"phone": "+70479426425"}
0005435614094	721403	1883 875739	LYUDMILA POPOVA	{"phone": "+70698083654"}
0005435614095	54EF9A	1292 409310	ALEKSEY CHERNOV	{"phone": "+70133066925"}
0005435614096	54EF9A	4218 206201	ILYA DMITRIEV	{"email": "dmitriev-i1969@postgrespro.ru", "phone": "+70673476127"}
0005435614097	28733F	9244 621283	OLGA PETROVA	{"email": "o.petrova061960@postgrespro.ru", "phone": "+70836110574"}
0005435614098	D2B62A	6775 333952	DMITRIY ILIN	{"email": "dmitriy-ilin-1971@postgrespro.ru", "phone": "+70912748597"}
0005435614099	416856	5384 968103	NADEZHDA POPOVA	{"phone": "+70042764474"}
0005435614100	416856	0191 370173	SERGEY ANTONOV	{"phone": "+70043447519"}
0005435614101	416856	4246 951404	VLADIMIR KISELEV	{"phone": "+70518184635"}
0005435614102	840F3D	1037 737951	IVAN VLASOV	{"email": "ivan.vlasov041980@postgrespro.ru", "phone": "+70849510620"}
0005435614103	C83992	8377 411679	VLADIMIR EGOROV	{"email": "vegorov12021975@postgrespro.ru", "phone": "+70820917268"}
0005435614104	49ECD0	9500 158016	ZOYA LEBEDEVA	{"email": "z-lebedeva-1980@postgrespro.ru", "phone": "+70322082086"}
0005435614105	A06A6C	3601 054315	ALEKSANDRA KUZNECOVA	{"email": "aleksandra_kuznecova_061966@postgrespro.ru", "phone": "+70181106931"}
0005435614106	A06A6C	4440 081575	ALEKSANDR VOROBEV	{"phone": "+70133045593"}
0005435614107	50DEDE	1173 375975	ILYA IVANOV	{"phone": "+70286736390"}
0005435614108	50DEDE	8740 905053	GENNADIY MOROZOV	{"email": "morozovgennadiy_091971@postgrespro.ru", "phone": "+70358613281"}
0005435614109	338C28	0035 453546	VIKTORIYA NIKOLAEVA	{"email": "nikolaeva_v-14091969@postgrespro.ru", "phone": "+70461921591"}
0005435614110	23FE64	7631 648152	SERAFIMA PETROVA	{"email": "spetrova.1966@postgrespro.ru", "phone": "+70773869767"}
0005435614111	23FE64	8201 396629	VALENTIN FROLOV	{"phone": "+70395741971"}
0005435614112	0BA651	5822 280630	VITALIY NOVIKOV	{"phone": "+70372979685"}
0005435614113	0BA651	8487 561013	TATYANA ZHUKOVA	{"email": "tatyana_zhukova1969@postgrespro.ru", "phone": "+70453599434"}
0005435614114	3D7151	3765 069445	TATYANA KOZLOVA	{"phone": "+70782949390"}
0005435614115	3D7151	3265 729690	MARIYA VOROBEVA	{"email": "mvorobeva.03081967@postgrespro.ru", "phone": "+70469849743"}
0005435614116	024B09	8247 580950	VERA ZAYCEVA	{"phone": "+70170563618"}
0005435614117	3F8709	5524 802569	TATYANA MAKSIMOVA	{"phone": "+70713413460"}
0005435614284	5240D2	7610 404776	ELENA KUZNECOVA	{"phone": "+70341970638"}
0005435614118	2F54EB	6245 392033	VALERIY KUZNECOV	{"email": "kuznecov.v27091971@postgrespro.ru", "phone": "+70573655710"}
0005435614119	B27CF7	1297 411610	ALEKSANDR VLASOV	{"email": "aleksandrvlasov.19041975@postgrespro.ru", "phone": "+70972500871"}
0005435614120	B27CF7	0875 739317	RUMIYA FROLOVA	{"email": "rumiya_frolova13121972@postgrespro.ru", "phone": "+70115967133"}
0005435614121	4D389A	3773 316007	NINA KOVALEVA	{"email": "nina.kovaleva_03021978@postgrespro.ru", "phone": "+70184361746"}
0005435614122	4D389A	7639 369026	SERGEY ISAEV	{"email": "s-isaev.041977@postgrespro.ru", "phone": "+70289922402"}
0005435614123	69A6E0	3532 061037	ANTON POPOV	{"phone": "+70683531930"}
0005435614124	1AC0D1	6568 222551	EMILIYA YAKOVLEVA	{"email": "eyakovleva-041974@postgrespro.ru", "phone": "+70667257106"}
0005435614125	CAF076	3862 714257	ALEKSANDR KUZNECOV	{"phone": "+70150199260"}
0005435614126	72F73A	8627 665571	NIKOLAY BELOV	{"phone": "+70208576704"}
0005435614127	AD7D81	0551 794887	ARKADIY NOVIKOV	{"phone": "+70198582289"}
0005435614128	AD7D81	0468 106276	VLADIMIR FEDOTOV	{"phone": "+70729131516"}
0005435614129	DF258A	9239 347034	NATALYA MALYSHEVA	{"email": "malyshevanatalya_28081975@postgrespro.ru", "phone": "+70489830367"}
0005435614130	7E2FC3	5069 850036	ANDREY TARASOV	{"phone": "+70065116355"}
0005435614131	7E2FC3	0859 832781	MARIYA NIKITINA	{"phone": "+70808143837"}
0005435614132	E55FE0	3884 196941	GEORGIY BORISOV	{"email": "borisov-g.20101968@postgrespro.ru", "phone": "+70218705748"}
0005435614133	9610F5	2465 267114	VLADIMIR SMIRNOV	{"phone": "+70082771357"}
0005435614134	F9C432	2372 888503	DENIS KOROLEV	{"phone": "+70228315439"}
0005435614135	E3BBF8	4568 013810	TATYANA DANILOVA	{"email": "tatyanadanilova-1971@postgrespro.ru", "phone": "+70182819831"}
0005435614136	810D46	2676 029812	EVGENIY NAUMOV	{"phone": "+70864382587"}
0005435614137	810D46	7438 251859	PETR DAVYDOV	{"phone": "+70823988123"}
0005435614668	397CED	0241 116789	VLADIMIR BARANOV	{"phone": "+70402960983"}
0005435614138	267B3D	1433 945617	IVAN NAZAROV	{"email": "nazarovivan-15071958@postgrespro.ru", "phone": "+70756212747"}
0005435614139	2A89F4	9582 480494	ARKADIY PAVLOV	{"phone": "+70105849602"}
0005435614140	D77BDB	6097 557051	ALEKSEY FOMIN	{"email": "fominaleksey-1968@postgrespro.ru", "phone": "+70103835851"}
0005435614141	D77BDB	9127 368299	IVAN GERASIMOV	{"email": "igerasimov031977@postgrespro.ru", "phone": "+70527915260"}
0005435614142	86664D	1487 977200	EKATERINA ANDREEVA	{"phone": "+70365923037"}
0005435614143	154A60	3010 351153	VALERIY ALEKSEEV	{"email": "valeriy.alekseev1959@postgrespro.ru", "phone": "+70638619002"}
0005435614144	90F991	8530 856388	VYACHESLAV PAVLOV	{"phone": "+70671327418"}
0005435614145	90F991	4092 212364	NATALYA BARANOVA	{"email": "baranova.natalya_1971@postgrespro.ru", "phone": "+70360557637"}
0005435614146	7C0C3A	3097 046839	IRINA BOGDANOVA	{"email": "ibogdanova-121973@postgrespro.ru", "phone": "+70325473064"}
0005435614147	A688B9	3620 241454	ANASTASIYA KAZAKOVA	{"phone": "+70398512277"}
0005435614148	5B8827	8338 913027	MAKSIM SOROKIN	{"email": "m-sorokin-06081975@postgrespro.ru", "phone": "+70365348057"}
0005435614149	3CDCD5	3832 455241	ROMAN KOZLOV	{"phone": "+70013309770"}
0005435614150	3CDCD5	0977 284762	IGOR ZHURAVLEV	{"email": "zhuravlev_igor-091970@postgrespro.ru", "phone": "+70670970435"}
0005435614151	859305	5973 370078	SERGEY ROMANOV	{"phone": "+70036413279"}
0005435614152	859305	4966 257211	RUSTAM PAVLOV	{"phone": "+70161788347"}
0005435614153	FD177C	7587 440289	DARYA FOMINA	{"phone": "+70927130809"}
0005435614154	2BFCD7	7008 704377	ALINA ABRAMOVA	{"email": "a_abramova_28071973@postgrespro.ru", "phone": "+70677325805"}
0005435614155	23DDD4	4831 309705	RUSLAN MIRONOV	{"phone": "+70988981269"}
0005435614156	1548CB	9670 072009	ANDREY SMIRNOV	{"email": "a.smirnov-04101964@postgrespro.ru", "phone": "+70031390833"}
0005435614157	D20403	2299 035855	ZINAIDA ABRAMOVA	{"email": "zinaida-abramova-04121966@postgrespro.ru", "phone": "+70551511082"}
0005435614158	09EACC	1006 860064	OLEG TIKHONOV	{"email": "tikhonov.oleg21051985@postgrespro.ru", "phone": "+70856363005"}
0005435614159	E68C9C	2674 024136	NELLYA POLYAKOVA	{"phone": "+70795591677"}
0005435614160	18DA21	9244 472131	NADEZHDA MIKHAYLOVA	{"phone": "+70897955763"}
0005435614161	F9D85A	8375 158405	VALERIY FOMIN	{"email": "vfomin-091970@postgrespro.ru", "phone": "+70409308839"}
0005435614162	1CCADF	7697 596129	VLADIMIR MIRONOV	{"email": "mironovvladimir26061977@postgrespro.ru", "phone": "+70144805755"}
0005435614163	912E45	9198 309705	MARIYA IVANOVA	{"phone": "+70470100384"}
0005435614164	912E45	2829 686482	SVETLANA KUZNECOVA	{"email": "kuznecova-svetlana-121974@postgrespro.ru", "phone": "+70131929488"}
0005435614165	4E361F	7920 163012	RAFAEL MATVEEV	{"email": "rmatveev_091970@postgrespro.ru", "phone": "+70878653620"}
0005435614166	4E361F	9412 563886	NATALYA SMIRNOVA	{"phone": "+70289378276"}
0005435614167	E6B80C	4657 793355	LIDIYA FEDOROVA	{"email": "lidiyafedorova.121980@postgrespro.ru", "phone": "+70876429779"}
0005435614168	58E349	9567 752063	EKATERINA POPOVA	{"phone": "+70411381033"}
0005435614169	58E349	8091 952651	NIKOLAY MIKHAYLOV	{"email": "mikhaylov_n.081979@postgrespro.ru", "phone": "+70495326769"}
0005435614170	030AD9	1985 594558	SVETLANA IVANOVA	{"phone": "+70127106774"}
0005435614171	030AD9	7923 150288	ARINA ANDREEVA	{"email": "andreeva_arina26011963@postgrespro.ru", "phone": "+70277767392"}
0005435614172	9C5483	0912 352458	VERA DENISOVA	{"phone": "+70054505901"}
0005435614173	9C5483	4593 840361	RIMMA VOROBEVA	{"email": "vorobeva.r-10101976@postgrespro.ru", "phone": "+70084010622"}
0005435614174	F896DE	7039 401610	VERONIKA KAZAKOVA	{"email": "veronika_kazakova-07051973@postgrespro.ru", "phone": "+70855118928"}
0005435614175	222E81	6327 686481	YURIY GRIGOREV	{"email": "grigorev_yuriy.1965@postgrespro.ru", "phone": "+70225566814"}
0005435614176	54A836	2024 315501	ALEKSANDRA ROMANOVA	{"email": "aromanova_1972@postgrespro.ru", "phone": "+70611304898"}
0005435614177	8B518A	1292 809653	IVAN ROMANOV	{"phone": "+70176584090"}
0005435614178	340004	8668 045462	LYUDMILA SCHERBAKOVA	{"email": "scherbakoval_1978@postgrespro.ru", "phone": "+70846077065"}
0005435614179	1751B0	3243 164206	LYUDMILA KARPOVA	{"phone": "+70211591923"}
0005435614180	1751B0	2696 861302	SNEZHANA TIMOFEEVA	{"email": "timofeevasnezhana_27031965@postgrespro.ru", "phone": "+70595523696"}
0005435614181	766C31	2407 828079	MARIYA BORISOVA	{"phone": "+70381485976"}
0005435614182	03D625	5523 714561	VLADIMIR KISELEV	{"phone": "+70466894786"}
0005435614183	03D625	8801 092411	TATYANA BOGDANOVA	{"email": "tatyana-bogdanova_02051977@postgrespro.ru", "phone": "+70374971115"}
0005435614184	55C757	3096 034189	NATALYA ALEKSANDROVA	{"email": "aleksandrova.natalya-16081967@postgrespro.ru", "phone": "+70152543921"}
0005435614185	55C757	2462 572555	ALEKSEY NIKOLAEV	{"phone": "+70690963342"}
0005435614186	F21112	6921 614647	ALEKSANDR KONOVALOV	{"email": "konovalovaleksandr_041971@postgrespro.ru", "phone": "+70175168508"}
0005435614187	7047C2	6347 044880	MARINA PAVLOVA	{"email": "pavlova-m071973@postgrespro.ru", "phone": "+70527928865"}
0005435614188	7047C2	2529 468210	NIKOLAY ANDREEV	{"phone": "+70778465697"}
0005435614189	638CD5	4725 350514	OLESYA ROMANOVA	{"email": "oromanova-01111968@postgrespro.ru", "phone": "+70047177211"}
0005435614190	638CD5	7441 483154	ALEKSANDR IVANOV	{"phone": "+70967715318"}
0005435614191	9E7E3C	1503 989249	VALENTINA FROLOVA	{"phone": "+70752890774"}
0005435614192	F93837	2551 030147	LIDIYA VOROBEVA	{"phone": "+70176411810"}
0005435614193	D052CE	1395 680001	SERGEY MIRONOV	{"phone": "+70937922157"}
0005435614194	D052CE	1824 412426	SERGEY PETROV	{"phone": "+70266335915"}
0005435614195	D052CE	2015 292632	ALEKSEY SERGEEV	{"email": "sergeev_a.1969@postgrespro.ru", "phone": "+70038836875"}
0005435614196	A150FA	2813 434183	LYUBOV KULIKOVA	{"email": "l.kulikova1984@postgrespro.ru", "phone": "+70548950396"}
0005435614789	7554A6	3538 497773	ANATOLIY VOROBEV	{"phone": "+70875675367"}
0005435614197	4191D2	3900 988058	NATALYA ZAYCEVA	{"email": "zayceva.n_041964@postgrespro.ru", "phone": "+70527039786"}
0005435614198	EF0E43	1029 827671	DMITRIY FOMIN	{"phone": "+70217785462"}
0005435614199	EF0E43	7257 129407	OLGA KUZNECOVA	{"email": "olga_kuznecova061984@postgrespro.ru", "phone": "+70540634576"}
0005435614200	C08ED5	5419 542661	GENNADIY FROLOV	{"email": "g_frolov_011975@postgrespro.ru", "phone": "+70769475874"}
0005435614201	E2392B	3705 271858	SERGEY KRASNOV	{"email": "sergey_krasnov.021972@postgrespro.ru", "phone": "+70544111007"}
0005435614202	5E8D5C	4882 518129	NINA KOMAROVA	{"phone": "+70901671558"}
0005435614203	5E8D5C	6534 181273	TATYANA FILATOVA	{"email": "filatova.tatyana061971@postgrespro.ru", "phone": "+70030421070"}
0005435614204	23803A	8766 964136	TATYANA IVANOVA	{"email": "tivanova-121971@postgrespro.ru", "phone": "+70790128307"}
0005435614205	9E7E78	9243 834746	OKSANA ISAEVA	{"email": "oksana_isaeva17061969@postgrespro.ru", "phone": "+70462773401"}
0005435614206	9E7E78	2071 459974	SERGEY KISELEV	{"email": "kiselev_sergey-121980@postgrespro.ru", "phone": "+70162308901"}
0005435614207	7A4D33	0364 946770	OLEG SEMENOV	{"phone": "+70028015292"}
0005435614208	7A4D33	7724 599958	YULIYA NAZAROVA	{"phone": "+70933340203"}
0005435614209	4435B3	8972 652462	SOFYA ZAKHAROVA	{"email": "sofya-zakharova.1977@postgrespro.ru", "phone": "+70145759648"}
0005435614210	4435B3	9735 963301	IRINA SOKOLOVA	{"email": "sokolova_irina-041976@postgrespro.ru", "phone": "+70439512119"}
0005435614211	A08B08	5456 645670	YURIY IVANOV	{"phone": "+70746213805"}
0005435614212	00934F	4586 457433	NIKOLAY VOROBEV	{"email": "nikolayvorobev.1970@postgrespro.ru", "phone": "+70096923994"}
0005435614213	DB849B	6954 229336	ALEKSEY PAVLOV	{"email": "a-pavlov30071965@postgrespro.ru", "phone": "+70319364908"}
0005435614214	DB849B	4235 670867	YULIYA NAZAROVA	{"email": "y_nazarova_30081970@postgrespro.ru", "phone": "+70364486554"}
0005435614215	EFBBA4	4027 933201	MARINA GORBUNOVA	{"email": "marina_gorbunova-1969@postgrespro.ru", "phone": "+70899960039"}
0005435614216	954933	2150 966519	NATALYA DENISOVA	{"email": "n-denisova_021972@postgrespro.ru", "phone": "+70482391688"}
0005435614217	954933	9528 954527	RAIL MARTYNOV	{"email": "martynovrail1970@postgrespro.ru", "phone": "+70744253899"}
0005435614218	021CAB	7561 923718	OLGA YAKOVLEVA	{"phone": "+70703377454"}
0005435614219	021CAB	7579 262174	IRINA FEDOROVA	{"phone": "+70512782988"}
0005435614220	AA4ACA	7760 344160	ALEKSEY IVANOV	{"phone": "+70179238511"}
0005435614221	AA4ACA	3463 310863	ELENA EFREMOVA	{"email": "e-efremova.101976@postgrespro.ru", "phone": "+70556334534"}
0005435614222	8ABAE1	5227 575886	ALEKSANDR SIDOROV	{"email": "aleksandr.sidorov_081951@postgrespro.ru", "phone": "+70847359185"}
0005435614223	AF0E27	5816 610295	VALENTINA KUZNECOVA	{"phone": "+70263192589"}
0005435614224	E53017	2518 038759	SVETLANA TROFIMOVA	{"email": "trofimova-svetlana.051975@postgrespro.ru", "phone": "+70499017497"}
0005435614225	6BB20E	0613 571247	NINA NIKIFOROVA	{"email": "n_nikiforova_081976@postgrespro.ru", "phone": "+70311791741"}
0005435614226	6BB20E	6416 193094	SVETLANA SOKOLOVA	{"email": "ssokolova1983@postgrespro.ru", "phone": "+70339593916"}
0005435614227	6BB20E	0993 426816	OLGA NAZAROVA	{"email": "nazarova.olga_111984@postgrespro.ru", "phone": "+70488855012"}
0005435614228	EAA07A	1733 477504	VYACHESLAV IVANOV	{"email": "vyacheslav_ivanov1971@postgrespro.ru", "phone": "+70759402541"}
0005435614229	44498B	6188 300422	ELENA SOLOVEVA	{"email": "elena-soloveva.1976@postgrespro.ru", "phone": "+70713661802"}
0005435614230	D6AD1B	2193 169655	YULIYA FROLOVA	{"email": "frolova.y1963@postgrespro.ru", "phone": "+70703455997"}
0005435614231	D6AD1B	8255 213116	ELENA FILIPPOVA	{"email": "filippova-e.31081976@postgrespro.ru", "phone": "+70596240234"}
0005435614232	7579DF	5757 619914	MIKHAIL GRIGOREV	{"phone": "+70401550778"}
0005435614233	C1F5C1	2881 577862	EMILIYA KUZMINA	{"phone": "+70228912757"}
0005435614234	C1F5C1	3036 266632	LYUDMILA VOROBEVA	{"email": "vorobevalyudmila_121976@postgrespro.ru", "phone": "+70349808536"}
0005435614235	C1F5C1	5269 582604	ALEKSANDRA KAZAKOVA	{"email": "kazakova.a1974@postgrespro.ru", "phone": "+70410063597"}
0005435614236	4A2D90	9652 224261	OLGA RODIONOVA	{"phone": "+70744435213"}
0005435614237	4A2D90	6541 881413	PETR VOROBEV	{"email": "petrvorobev1970@postgrespro.ru", "phone": "+70875618061"}
0005435614238	8112FC	9197 124655	EGOR IVANOV	{"email": "egor.ivanov.1974@postgrespro.ru", "phone": "+70649644348"}
0005435614239	66E8C5	1973 144200	VALENTINA FEDOROVA	{"phone": "+70496210749"}
0005435614240	AB7B4D	8472 732919	GALINA GORBUNOVA	{"phone": "+70214590069"}
0005435614241	86C54E	3735 566518	VLADIMIR SOROKIN	{"email": "v-sorokin.011968@postgrespro.ru", "phone": "+70339103394"}
0005435614242	86C54E	7275 981150	LYUBOV SAVELEVA	{"phone": "+70576443477"}
0005435614243	3297EA	3096 836163	ALEKSANDR KUZNECOV	{"phone": "+70298243712"}
0005435614244	3297EA	4443 046048	EVGENIYA MOROZOVA	{"phone": "+70526544891"}
0005435614245	9CE9CE	2095 643445	ALEKSANDR SERGEEV	{"email": "aleksandrsergeev_21101985@postgrespro.ru", "phone": "+70915527503"}
0005435614246	6370F8	4767 667966	ALEKSANDR KRASNOV	{"email": "krasnov_a-1964@postgrespro.ru", "phone": "+70187826603"}
0005435614247	E818F6	1221 617247	RAFIS CHERNOV	{"phone": "+70082164832"}
0005435614248	E818F6	9698 638149	ALEKSEY KUDRYASHOV	{"phone": "+70333226287"}
0005435614249	DFBFDB	9845 600533	VALENTINA AFANASEVA	{"phone": "+70363513898"}
0005435614250	DFBFDB	2655 508435	ARTUR MOISEEV	{"email": "artur.moiseev-1970@postgrespro.ru", "phone": "+70381544633"}
0005435614251	5675D8	5683 217308	ALEKSANDR VASILEV	{"phone": "+70881403445"}
0005435614252	3F4605	8134 197999	ALEKSANDRA MOROZOVA	{"email": "aleksandra.morozova1972@postgrespro.ru", "phone": "+70141723174"}
0005435614253	3F4605	4366 792880	EKATERINA ZHURAVLEVA	{"email": "zhuravleva.e-10041975@postgrespro.ru", "phone": "+70684015520"}
0005435614254	C436FD	5577 229628	YURIY MOROZOV	{"email": "morozov_y_101987@postgrespro.ru", "phone": "+70019555715"}
0005435614255	3E4B60	4031 399125	SERGEY KUDRYASHOV	{"email": "sergeykudryashov.061970@postgrespro.ru", "phone": "+70965603879"}
0005435614256	B129EB	8638 957680	VLADIMIR GUSEV	{"email": "vladimir_gusev-071976@postgrespro.ru", "phone": "+70303254700"}
0005435614257	92AF3C	2414 734896	OLGA STEPANOVA	{"phone": "+70439258779"}
0005435614258	05D95B	2596 633000	MARINA MOISEEVA	{"email": "moiseevamarina_28061957@postgrespro.ru", "phone": "+70905744230"}
0005435614259	E5381A	5446 158406	EDUARD GUSEV	{"email": "eduard-gusev.1968@postgrespro.ru", "phone": "+70075256356"}
0005435614260	7B6519	1791 970544	PAVEL NIKITIN	{"email": "nikitinpavel_19061980@postgrespro.ru", "phone": "+70711887315"}
0005435614261	7B6519	4499 720484	ILYA KUZNECOV	{"email": "ilya-kuznecov-1970@postgrespro.ru", "phone": "+70172689848"}
0005435614262	227F4E	7512 423161	SERGEY SERGEEV	{"email": "sergeev.sergey1980@postgrespro.ru", "phone": "+70245725244"}
0005435614263	EC8240	4483 423382	OLGA NESTEROVA	{"phone": "+70970420980"}
0005435614264	624FDA	6775 708290	ALEKSANDR DMITRIEV	{"email": "dmitriev-a.26071968@postgrespro.ru", "phone": "+70062601540"}
0005435614265	75CD7D	8772 587176	VERA MAKAROVA	{"email": "makarova-v.26041973@postgrespro.ru", "phone": "+70532630971"}
0005435614266	75CD7D	4023 664100	GALINA ROMANOVA	{"phone": "+70543126470"}
0005435614267	9524AB	8879 003358	ALEKSEY MIKHAYLOV	{"email": "alekseymikhaylov1974@postgrespro.ru", "phone": "+70100713519"}
0005435614268	9524AB	0111 105140	VALENTINA VOROBEVA	{"email": "valentina-vorobeva-18061977@postgrespro.ru", "phone": "+70829806417"}
0005435614269	253F75	2637 153717	ILYAS SAVELEV	{"email": "ilyas-savelev_16011967@postgrespro.ru", "phone": "+70261334463"}
0005435614270	253F75	1393 972532	LYUDMILA KRASNOVA	{"phone": "+70321647546"}
0005435614271	96D7C7	2198 732807	ALEKSEY KUZNECOV	{"email": "kuznecov-a.29071964@postgrespro.ru", "phone": "+70599014279"}
0005435614272	BE7733	2177 296858	MIKHAIL SCHERBAKOV	{"email": "m-scherbakov1978@postgrespro.ru", "phone": "+70157837756"}
0005435614273	BE7733	0868 357754	ANTONINA DANILOVA	{"email": "danilova.a031956@postgrespro.ru", "phone": "+70315877901"}
0005435614274	94A853	0077 053103	ALEKSANDR MOROZOV	{"phone": "+70291763237"}
0005435614275	DDD393	3020 073979	NATALYA BELYAEVA	{"phone": "+70859582328"}
0005435614276	667188	9504 503139	PETR VLASOV	{"phone": "+70106854005"}
0005435614277	E2B480	5437 787107	ANNA KISELEVA	{"phone": "+70778145877"}
0005435614278	2C4E46	3338 378368	ALISA ALEKSANDROVA	{"phone": "+70103511087"}
0005435614279	6CB7B1	6182 597602	GALINA POTAPOVA	{"email": "potapova-galina1972@postgrespro.ru", "phone": "+70085799026"}
0005435614280	A06F70	3721 713751	NATALYA IVANOVA	{"email": "ivanova.n-1979@postgrespro.ru", "phone": "+70577459087"}
0005435614281	A06F70	1300 357183	ALEKSANDR BELOV	{"phone": "+70259670107"}
0005435614282	3320BF	8048 640807	NATALYA MASLOVA	{"phone": "+70263794656"}
0005435614283	5240D2	6994 307338	VLADIMIR VOROBEV	{"email": "vladimir_vorobev_081975@postgrespro.ru", "phone": "+70101328882"}
0005435614285	49030E	5553 618192	LARISA NIKOLAEVA	{"phone": "+70371414856"}
0005435614286	49030E	5669 747652	DMITRIY ZHUKOV	{"phone": "+70173882378"}
0005435614287	DE3A2A	3782 726091	LYUBOV NESTEROVA	{"email": "nesterova-lyubov.1977@postgrespro.ru", "phone": "+70966986253"}
0005435615066	515BBD	1462 248714	LYUBOV GAVRILOVA	{"phone": "+70352495759"}
0005435614288	D64CAE	9712 372923	YURIY MIRONOV	{"email": "y.mironov.16101963@postgrespro.ru", "phone": "+70260335189"}
0005435614289	468BFB	6983 376013	IVAN IVANOV	{"email": "ivanovi101984@postgrespro.ru", "phone": "+70278029281"}
0005435614290	9A1D79	4244 827111	ELENA GUSEVA	{"phone": "+70851406561"}
0005435614291	8571AE	1886 248567	MARIYA NESTEROVA	{"email": "mariya.nesterova-061968@postgrespro.ru", "phone": "+70678398263"}
0005435614292	FA6708	2542 811531	SERGEY ZHUKOV	{"email": "zhukov.sergey22051974@postgrespro.ru", "phone": "+70387433826"}
0005435614293	FA6708	6656 216182	VADIM SHEVCHENKO	{"email": "shevchenko.vadim_031964@postgrespro.ru", "phone": "+70142880755"}
0005435614294	8EEBF6	1779 848494	IRINA KRASNOVA	{"email": "ikrasnova-1975@postgrespro.ru", "phone": "+70590439799"}
0005435614295	8EEBF6	8595 543526	VITALIY SERGEEV	{"email": "v.sergeev1965@postgrespro.ru", "phone": "+70873810195"}
0005435614296	8EEBF6	6930 795169	ARTEM VASILEV	{"phone": "+70934150518"}
0005435614297	2B194D	6790 684811	KONSTANTIN NAZAROV	{"email": "nazarov.konstantin.071974@postgrespro.ru", "phone": "+70118804799"}
0005435614298	2B194D	7031 049476	VALERIY MELNIKOV	{"email": "melnikov.valeriy.13041970@postgrespro.ru", "phone": "+70202637392"}
0005435614299	3D5A99	7491 837746	LYUDMILA ARKHIPOVA	{"phone": "+70072231682"}
0005435614300	3D5A99	2115 080092	SERGEY NOVIKOV	{"phone": "+70129737857"}
0005435614301	C0582D	0770 807549	VALERIY FILIPPOV	{"email": "valeriy-filippov07121973@postgrespro.ru", "phone": "+70804991128"}
0005435614302	79A437	3845 895918	EVGENIY GAVRILOV	{"phone": "+70958386725"}
0005435614303	17CBA6	3865 604426	KONSTANTIN RODIONOV	{"phone": "+70998217405"}
0005435614304	1BE560	1258 214423	VLADIMIR AFANASEV	{"phone": "+70489269179"}
0005435614305	1BE560	3944 291177	ARTEM NOVIKOV	{"email": "novikov_artem.111969@postgrespro.ru", "phone": "+70902024064"}
0005435614306	E5C670	1267 972282	YULIYA ABRAMOVA	{"phone": "+70750937638"}
0005435614307	AD64BA	9199 357117	VYACHESLAV SMIRNOV	{"phone": "+70809700995"}
0005435614308	EAC17B	5615 297352	ANATOLIY FILIPPOV	{"email": "anatoliy_filippov-111979@postgrespro.ru", "phone": "+70567592190"}
0005435614309	6F591B	6029 956670	MIKHAIL EGOROV	{"email": "egorov_mikhail-1974@postgrespro.ru", "phone": "+70981299538"}
0005435614310	6F591B	4641 037327	ALENA ORLOVA	{"phone": "+70401007439"}
0005435614311	FA825D	2397 688204	ANDREY KOZLOV	{"phone": "+70882649893"}
0005435614312	FA825D	9628 042995	ANASTASIYA SCHERBAKOVA	{"email": "a_scherbakova.11021974@postgrespro.ru", "phone": "+70045919327"}
0005435614313	AEF16D	4716 005967	YURIY MOISEEV	{"email": "moiseevy101975@postgrespro.ru", "phone": "+70134394767"}
0005435614314	64E1B4	8356 860479	LILIYA KOZLOVA	{"email": "kozlova_liliya_1975@postgrespro.ru", "phone": "+70870859551"}
0005435614315	64E1B4	4766 157779	EVGENIY IVANOV	{"phone": "+70578262240"}
0005435614316	4DB2A1	2387 748223	GALINA TIMOFEEVA	{"phone": "+70914998185"}
0005435614317	DB704B	4275 600372	MARK PETROV	{"phone": "+70532348594"}
0005435614318	3257E6	4704 677946	NATALYA MIKHAYLOVA	{"phone": "+70203674800"}
0005435614319	3257E6	1426 946584	ALEKSANDR STEPANOV	{"email": "stepanovaleksandr_091987@postgrespro.ru", "phone": "+70708719870"}
0005435614320	505051	6825 746306	TATYANA CHERNOVA	{"email": "chernova_t_1977@postgrespro.ru", "phone": "+70520528975"}
0005435614321	505051	4680 429553	PAVEL MIKHAYLOV	{"email": "mikhaylov.p-101973@postgrespro.ru", "phone": "+70289988788"}
0005435614322	505051	8317 090598	ELENA FADEEVA	{"phone": "+70246033635"}
0005435614323	FD7349	3360 327533	LYUBOV YUDINA	{"phone": "+70329601542"}
0005435614324	CFFCE8	5153 492188	ALEKSEY IVANOV	{"email": "ivanovaleksey111970@postgrespro.ru", "phone": "+70240725507"}
0005435614325	B3432C	1752 363361	ELENA ANDREEVA	{"email": "andreeva-elena-1973@postgrespro.ru", "phone": "+70326017097"}
0005435614326	B3432C	6075 516744	TAMARA POTAPOVA	{"email": "tamarapotapova.1976@postgrespro.ru", "phone": "+70098013374"}
0005435614327	F20027	9412 243484	VLADIMIR ROMANOV	{"phone": "+70279699879"}
0005435614328	B48CD0	3942 105126	NIKOLAY ZAYCEV	{"phone": "+70089453823"}
0005435614329	D28EC0	5761 941334	VALERIYA KUZMINA	{"email": "valeriyakuzmina-04101981@postgrespro.ru", "phone": "+70904111716"}
0005435614330	577B80	7444 679831	IVAN ROMANOV	{"email": "iromanov111977@postgrespro.ru", "phone": "+70920435468"}
0005435614331	577B80	7001 362552	ELENA VLASOVA	{"email": "vlasovaelena-19101979@postgrespro.ru", "phone": "+70788134189"}
0005435614332	2F97DB	1529 445135	VIKTORIYA ZOTOVA	{"email": "viktoriya-zotova-121973@postgrespro.ru", "phone": "+70701369772"}
0005435614333	2F97DB	0835 536304	VIKTOR ABRAMOV	{"email": "v.abramov.111974@postgrespro.ru", "phone": "+70832975896"}
0005435614334	2F97DB	3892 067050	IGOR GAVRILOV	{"email": "i-gavrilov_1970@postgrespro.ru", "phone": "+70910211618"}
0005435614335	F3F0C3	0357 125423	DANIIL ANDREEV	{"email": "daniil_andreev-021970@postgrespro.ru", "phone": "+70049382641"}
0005435614336	F3F0C3	6328 204386	DENIS NIKITIN	{"phone": "+70811742849"}
0005435614337	DCFBC5	4209 336954	TAMARA LAZAREVA	{"phone": "+70568334159"}
0005435614338	DCFBC5	9873 990657	MAKSIM PETROV	{"email": "petrov-m_101966@postgrespro.ru", "phone": "+70466982837"}
0005435614339	DADEF3	9007 177552	SERGEY FEDOROV	{"email": "fedorovs-13041974@postgrespro.ru", "phone": "+70989873108"}
0005435614340	DADEF3	5900 831052	VLADIMIR PETROV	{"phone": "+70842405350"}
0005435614341	EEBED1	5229 726746	PETR IVANOV	{"email": "ivanovpetr.051973@postgrespro.ru", "phone": "+70157460530"}
0005435614342	1F8144	9932 196878	GULIYA ILINA	{"email": "ilina-g-1971@postgrespro.ru", "phone": "+70242732551"}
0005435614343	AD1A92	6493 892979	LILIYA TARASOVA	{"email": "tarasova-liliya-081964@postgrespro.ru", "phone": "+70186983711"}
0005435614344	CE3191	8034 748828	NIKOLAY POPOV	{"email": "npopov_081987@postgrespro.ru", "phone": "+70707008157"}
0005435614345	770FB8	3385 956441	DANILA NAZAROV	{"phone": "+70697362947"}
0005435614346	770FB8	3699 750585	ANATOLIY VOLKOV	{"email": "volkovanatoliy111972@postgrespro.ru", "phone": "+70838981236"}
0005435614347	41D808	6326 200573	MARIYA KISELEVA	{"email": "kiselevamariya-24111970@postgrespro.ru", "phone": "+70201601382"}
0005435614348	E8177F	8211 270352	LIDIYA POPOVA	{"phone": "+70901541014"}
0005435614349	D0F63E	9618 620969	NATALYA KULIKOVA	{"email": "n.kulikova_091963@postgrespro.ru", "phone": "+70297584738"}
0005435614350	D0F63E	9956 958562	ALEKSEY BELOV	{"email": "a.belov_041971@postgrespro.ru", "phone": "+70771413987"}
0005435614351	1BCBF4	7086 831375	TATYANA KUZNECOVA	{"email": "t_kuznecova-071966@postgrespro.ru", "phone": "+70862719767"}
0005435614352	1BCBF4	7349 400550	YULIYA SMIRNOVA	{"email": "smirnova_y_1965@postgrespro.ru", "phone": "+70458545610"}
0005435614353	1BCBF4	6438 462287	TATYANA TITOVA	{"email": "t.titova27051967@postgrespro.ru", "phone": "+70029873523"}
0005435614354	74EF6C	9454 075876	VALENTINA DENISOVA	{"email": "denisova-valentina081971@postgrespro.ru", "phone": "+70354743793"}
0005435614355	919766	8672 854121	LYUBOV MAKAROVA	{"email": "l_makarova.22031967@postgrespro.ru", "phone": "+70213845545"}
0005435614356	CEB266	7429 439409	LYUDMILA STEPANOVA	{"email": "stepanoval_04041979@postgrespro.ru", "phone": "+70955189111"}
0005435614357	DB5BAC	9837 410545	LYUDMILA KOVALEVA	{"phone": "+70564313997"}
0005435614358	DB5BAC	2490 424290	ELMIRA KUZNECOVA	{"phone": "+70940688176"}
0005435614359	DB5BAC	6424 516656	IRINA NIKOLAEVA	{"phone": "+70730332878"}
0005435614360	2CAE19	1965 790009	NIKOLAY SEMENOV	{"email": "semenovn_28081980@postgrespro.ru", "phone": "+70802047898"}
0005435614361	81D4B3	5772 808758	ELENA LAZAREVA	{"email": "lazareva.elena-111969@postgrespro.ru", "phone": "+70648297256"}
0005435614362	81D4B3	3493 222731	TATYANA NAUMOVA	{"email": "t_naumova-031972@postgrespro.ru", "phone": "+70027623738"}
0005435614363	81D4B3	1036 229407	YULIYA ISAEVA	{"email": "yuliya_isaeva-031979@postgrespro.ru", "phone": "+70650379053"}
0005435614364	B6C710	1121 667238	SVETLANA SAVELEVA	{"email": "svetlana-saveleva_28081973@postgrespro.ru", "phone": "+70317377063"}
0005435614365	EDBB7D	9264 065201	ALEKSANDR PETROV	{"email": "petrovaleksandr.071975@postgrespro.ru", "phone": "+70966127345"}
0005435614366	4684AB	0628 627460	LIDIYA AFANASEVA	{"email": "afanaseva-lidiya071970@postgrespro.ru", "phone": "+70516319420"}
0005435614367	4684AB	9730 759147	NATALYA PETROVA	{"phone": "+70917182705"}
0005435614368	3893D9	6843 593431	ANATOLIY DAVYDOV	{"email": "davydov_a.21011968@postgrespro.ru", "phone": "+70265679312"}
0005435614369	BB3149	7513 167646	ANATOLIY PAVLOV	{"phone": "+70863111150"}
0005435614370	7FD699	0735 967245	DMITRIY VASILEV	{"phone": "+70312626445"}
0005435614849	C3EF74	3175 448042	VALENTINA ALEKSANDROVA	{"phone": "+70869052760"}
0005435614371	D92AA2	4852 026916	KLAVDIYA EGOROVA	{"email": "klavdiya_egorova_041969@postgrespro.ru", "phone": "+70314446611"}
0005435614372	B519BA	4543 643991	SERGEY ZAKHAROV	{"phone": "+70806727092"}
0005435614373	9B80E0	5023 958144	PAVEL MARTYNOV	{"email": "martynov-pavel011979@postgrespro.ru", "phone": "+70937345026"}
0005435614374	9EC044	4152 697921	TATYANA ALEKSEEVA	{"phone": "+70027986926"}
0005435614375	9EC044	8984 962656	SERGEY IVANOV	{"email": "s.ivanov-1969@postgrespro.ru", "phone": "+70228409345"}
0005435614376	179EEE	4684 747121	DENIS NAZAROV	{"phone": "+70948765597"}
0005435614377	179EEE	3224 066165	OLGA IVANOVA	{"phone": "+70124853483"}
0005435614378	0B2530	0143 503760	EVGENIYA SCHERBAKOVA	{"phone": "+70490446629"}
0005435614379	0B2530	6466 086102	OLGA ORLOVA	{"email": "oorlova-1976@postgrespro.ru", "phone": "+70238408160"}
0005435614380	E6BA8B	4062 027962	GALINA GUSEVA	{"email": "guseva.g-12051980@postgrespro.ru", "phone": "+70526560542"}
0005435614381	E6BA8B	4993 967051	YULIYA SERGEEVA	{"email": "sergeeva_yuliya.1979@postgrespro.ru", "phone": "+70326119319"}
0005435614382	8BC7D8	1348 515531	ROMAN CHERNOV	{"phone": "+70107051506"}
0005435614383	8BC7D8	6371 672547	VALERIY PAVLOV	{"email": "vpavlov-08061969@postgrespro.ru", "phone": "+70646886390"}
0005435614384	99A33F	4169 001068	NIKOLAY NOVIKOV	{"phone": "+70287936476"}
0005435614385	A8D81C	0937 540001	IVAN MOROZOV	{"phone": "+70720396823"}
0005435614386	504219	2679 312924	OLGA OSIPOVA	{"phone": "+70355224360"}
0005435614387	91AAE2	2993 308199	ALEKSANDR MAKSIMOV	{"email": "maksimov-aleksandr1962@postgrespro.ru", "phone": "+70333399371"}
0005435614388	BEADF4	4734 487961	ALBINA ORLOVA	{"email": "orlova.albina.1972@postgrespro.ru", "phone": "+70128527075"}
0005435614389	55F042	8505 765944	IRINA TARASOVA	{"phone": "+70469916084"}
0005435614390	55F042	9673 129048	LYUBOV LEBEDEVA	{"phone": "+70683289222"}
0005435614391	4D52EE	5858 172692	VALENTINA MOROZOVA	{"phone": "+70956832808"}
0005435614392	13461F	9403 846369	ELENA KUZNECOVA	{"email": "kuznecova-elena.011968@postgrespro.ru", "phone": "+70993745863"}
0005435614393	42A263	1784 933350	VASILIY SOKOLOV	{"email": "sokolov_v_23071970@postgrespro.ru", "phone": "+70342161492"}
0005435614394	E431B0	3358 412296	ANDREY OSIPOV	{"email": "andrey-osipov081961@postgrespro.ru", "phone": "+70098088552"}
0005435614395	E431B0	7290 865880	EKATERINA YAKOVLEVA	{"email": "e_yakovleva.071973@postgrespro.ru", "phone": "+70688487911"}
0005435614396	52F931	8033 798850	TATYANA IVANOVA	{"phone": "+70460879997"}
0005435614397	52F931	9021 066315	SVETLANA SERGEEVA	{"email": "svetlana_sergeeva_01031966@postgrespro.ru", "phone": "+70875921320"}
0005435614398	73B25A	4851 124127	ROMAN SCHERBAKOV	{"email": "roman-scherbakov1962@postgrespro.ru", "phone": "+70062157737"}
0005435614399	201353	7085 362183	ARTEM BONDARENKO	{"email": "abondarenko_21051968@postgrespro.ru", "phone": "+70461097637"}
0005435614400	AFE3A6	8639 727800	OLESYA MIKHAYLOVA	{"phone": "+70241753278"}
0005435614401	AFE3A6	9134 078243	VALERIY SOKOLOV	{"email": "sokolovv_031971@postgrespro.ru", "phone": "+70271630720"}
0005435614402	D7D395	7533 782216	DMITRIY GORBUNOV	{"phone": "+70591640364"}
0005435614403	B85CB4	9600 636389	ALEKSANDRA SMIRNOVA	{"email": "aleksandrasmirnova-04111983@postgrespro.ru", "phone": "+70743369126"}
0005435614404	2E4972	6728 103579	VLADIMIR VLASOV	{"email": "vlasov.v_011977@postgrespro.ru", "phone": "+70424592554"}
0005435614405	8C0F8E	3493 418719	ALEKSANDRA KUZMINA	{"phone": "+70712223527"}
0005435614406	CE3BC4	3264 563207	OKSANA SIDOROVA	{"phone": "+70437710276"}
0005435614407	13B689	9046 487838	OLGA LAZAREVA	{"email": "olga-lazareva-011972@postgrespro.ru", "phone": "+70000972817"}
0005435614408	F57EFA	8139 191795	GALINA NAZAROVA	{"email": "g.nazarova.22051965@postgrespro.ru", "phone": "+70158938934"}
0005435614409	50FC32	4346 520238	ANASTASIYA FOMINA	{"email": "fominaanastasiya.18051972@postgrespro.ru", "phone": "+70614109995"}
0005435614410	0090CF	9847 573145	ANDREY EGOROV	{"email": "a_egorov051981@postgrespro.ru", "phone": "+70433833698"}
0005435614411	0090CF	3509 308794	DENIS ZAKHAROV	{"phone": "+70406912365"}
0005435614412	7EBAC1	9991 798031	OLGA KOROLEVA	{"phone": "+70258614368"}
0005435614413	7EBAC1	2884 004765	VLADIMIR PAVLOV	{"email": "v.pavlov.031971@postgrespro.ru", "phone": "+70563843508"}
0005435614414	AC2B38	8023 961835	ANDREY MIKHAYLOV	{"phone": "+70604624253"}
0005435614415	37A661	2498 389049	ZINAIDA TITOVA	{"phone": "+70579547356"}
0005435614416	729813	9095 389632	ELENA ROMANOVA	{"email": "eromanova_101976@postgrespro.ru", "phone": "+70100618701"}
0005435614417	A58567	9475 069888	ALEKSEY DAVYDOV	{"phone": "+70117415829"}
0005435614418	A58567	7132 189347	VIKTORIYA ALEKSEEVA	{"phone": "+70128974292"}
0005435614419	A58567	8314 891611	ARTEM PETROV	{"phone": "+70164657124"}
0005435614420	C10069	7357 060019	EGOR PAVLOV	{"email": "pavlov-e22101972@postgrespro.ru", "phone": "+70674116535"}
0005435614421	AF9AFD	1790 456744	YANA KUZNECOVA	{"phone": "+70577625084"}
0005435614422	AF9AFD	2513 080037	YURIY GRIGOREV	{"email": "grigorevy-30081970@postgrespro.ru", "phone": "+70452692147"}
0005435614423	2AB9D1	2479 356215	OKSANA SOROKINA	{"email": "oksana-sorokina.1967@postgrespro.ru", "phone": "+70862214802"}
0005435614424	BD37EB	7663 165262	SERGEY SOKOLOV	{"phone": "+70912901134"}
0005435614425	BD37EB	7921 414487	TATYANA LOGINOVA	{"phone": "+70934229842"}
0005435614426	C9F904	5728 292326	DMITRIY FROLOV	{"email": "d_frolov-1967@postgrespro.ru", "phone": "+70218267544"}
0005435614427	C9F904	5928 996559	VLADIMIR FROLOV	{"email": "frolovv.10061977@postgrespro.ru", "phone": "+70959206076"}
0005435614428	CB31CD	7533 923925	VALERIY MOISEEV	{"email": "moiseevvaleriy.081976@postgrespro.ru", "phone": "+70365238663"}
0005435614429	B65BDE	0202 291244	VALENTINA KONOVALOVA	{"phone": "+70535162632"}
0005435614430	4B5DB5	3071 457637	ALEKSANDR TARASOV	{"email": "tarasov.aleksandr-03051966@postgrespro.ru", "phone": "+70506570034"}
0005435614431	1FF5A5	5395 486295	NIKITA PAVLOV	{"email": "pavlov_nikita-071972@postgrespro.ru", "phone": "+70105454179"}
0005435614432	161C72	0261 804664	ELENA OVCHINNIKOVA	{"email": "e.ovchinnikova-23081980@postgrespro.ru", "phone": "+70598077912"}
0005435614433	0F572B	8707 924063	VIKTORIYA VOROBEVA	{"phone": "+70847495979"}
0005435614434	4BDA1A	4398 225370	VALENTINA NIKITINA	{"email": "v_nikitina-05111976@postgrespro.ru", "phone": "+70080082322"}
0005435614435	4BDA1A	1337 715746	MAYYA PAVLOVA	{"email": "pavlova-mayya.081986@postgrespro.ru", "phone": "+70414299441"}
0005435614436	4BDA1A	5154 892824	NIKOLAY SOROKIN	{"phone": "+70457411726"}
0005435614437	E0C6F9	0657 722849	ROMAN KUZNECOV	{"phone": "+70404776794"}
0005435614438	E0C6F9	4155 967724	STEPAN VASILEV	{"email": "vasilev.stepan_23101966@postgrespro.ru", "phone": "+70575740163"}
0005435614439	D12C36	3883 379670	ANNA BARANOVA	{"email": "anna-baranova_071974@postgrespro.ru", "phone": "+70433083203"}
0005435614440	8E2D1E	8579 960238	NADEZHDA MAKAROVA	{"email": "makarova-n_06091983@postgrespro.ru", "phone": "+70998434223"}
0005435614441	40C870	4088 940357	SERGEY TIMOFEEV	{"phone": "+70222664593"}
0005435614442	294E01	6421 229159	SERGEY STEPANOV	{"email": "sergey-stepanov-061980@postgrespro.ru", "phone": "+70387090017"}
0005435614443	0099A9	7742 595873	SERGEY PETROV	{"phone": "+70567286191"}
0005435614444	1C7BAD	6160 207448	GRIGORIY GRIGOREV	{"email": "g-grigorev-28021969@postgrespro.ru", "phone": "+70497254371"}
0005435614445	1C7BAD	7667 328592	YURIY GERASIMOV	{"phone": "+70593758649"}
0005435614446	1C7BAD	4433 043578	LYUBOV BOGDANOVA	{"email": "lyubov_bogdanova-1963@postgrespro.ru", "phone": "+70362262103"}
0005435614447	1C7BAD	1844 671355	VALERIY KUZNECOV	{"phone": "+70886315262"}
0005435614448	32B7EB	8794 828002	ALENA SOKOLOVA	{"email": "alena.sokolova1971@postgrespro.ru", "phone": "+70635138174"}
0005435614449	5D9D8C	2157 548480	ANNA ZAKHAROVA	{"email": "zakharova-a1981@postgrespro.ru", "phone": "+70590508603"}
0005435614450	681A18	1848 069717	ZOYA VOLKOVA	{"email": "volkova.zoya_011966@postgrespro.ru", "phone": "+70903383904"}
0005435614451	F12DEE	4989 517221	DMITRIY ALEKSEEV	{"phone": "+70392388296"}
0005435614452	937912	0418 002281	ALEKSANDR KUZNECOV	{"phone": "+70233659234"}
0005435614453	2B7F03	2956 983371	EKATERINA NIKOLAEVA	{"email": "nikolaeva.e_1985@postgrespro.ru", "phone": "+70861388896"}
0005435614454	8ED265	3751 939401	MAKSIM ANTONOV	{"email": "maksim.antonov19041967@postgrespro.ru", "phone": "+70009212834"}
0005435614455	C75079	9739 896654	OLGA MAKSIMOVA	{"email": "maksimovaolga_06101970@postgrespro.ru", "phone": "+70842920851"}
0005435614456	CEE0E2	3584 257162	ALEKSANDR TIKHONOV	{"phone": "+70890465270"}
0005435614457	CE738E	9399 450510	ALEKSANDR ZHUKOV	{"phone": "+70001148175"}
0005435614458	CE738E	2732 376109	LIDIYA LOGINOVA	{"phone": "+70401394145"}
0005435614459	4531A1	2948 558216	NATALYA SOROKINA	{"email": "natalya_sorokina.08051976@postgrespro.ru", "phone": "+70442048627"}
0005435614460	DC3AEF	4695 107759	DMITRIY MEDVEDEV	{"phone": "+70060611071"}
0005435614461	F1E378	4923 315257	YURIY KONOVALOV	{"phone": "+70122566019"}
0005435614462	FB90F3	9178 595402	ZULFIYA SOROKINA	{"phone": "+70987916055"}
0005435614463	EEB162	9980 920474	ALEKSEY ZAKHAROV	{"phone": "+70439925836"}
0005435614464	EEB162	5273 203758	MIKHAIL GAVRILOV	{"email": "mikhail_gavrilov.051977@postgrespro.ru", "phone": "+70822009833"}
0005435614465	25C25D	6871 098136	EVGENIY IVANOV	{"email": "ivanov-e081974@postgrespro.ru", "phone": "+70270400330"}
0005435614466	25C25D	6151 406276	NIKOLAY ANTONOV	{"email": "antonov-n.051974@postgrespro.ru", "phone": "+70874741205"}
0005435614467	AB1301	3134 345420	BORIS GUSEV	{"phone": "+70653742216"}
0005435614468	AB1301	0095 085147	GALINA NIKIFOROVA	{"email": "galina-nikiforova-021964@postgrespro.ru", "phone": "+70455081434"}
0005435614469	3D959D	5466 320788	NATALYA NIKOLAEVA	{"phone": "+70659593149"}
0005435614470	2A1C0F	7077 554510	ELENA AKIMOVA	{"email": "akimovaelena-121967@postgrespro.ru", "phone": "+70519104621"}
0005435614471	B9A4E9	0819 008103	NATALYA GERASIMOVA	{"phone": "+70191217998"}
0005435614472	B6C978	4419 606970	ARINA BELOVA	{"phone": "+70503979884"}
0005435614473	B6C978	9008 021322	SVETLANA BELOVA	{"phone": "+70031704665"}
0005435614474	C80211	2547 267723	VIKTORIYA RODIONOVA	{"phone": "+70492860483"}
0005435614475	000C28	8337 405914	EVGENIYA KRASNOVA	{"email": "evgeniya-krasnova.031966@postgrespro.ru", "phone": "+70966926630"}
0005435614476	9857D5	3209 605949	ILDAR GUSEV	{"phone": "+70239451947"}
0005435614477	B25C6A	7299 191252	OLGA KISELEVA	{"phone": "+70766316914"}
0005435614478	B25C6A	3194 422652	ALEKSANDR SERGEEV	{"email": "sergeev_aleksandr_011974@postgrespro.ru", "phone": "+70807481827"}
0005435614479	1EE9B8	2015 751518	SVETLANA KONOVALOVA	{"email": "konovalova.svetlana_071971@postgrespro.ru", "phone": "+70381433189"}
0005435614480	D435B5	9297 956486	ANATOLIY VLASOV	{"email": "anatoliy_vlasov29071979@postgrespro.ru", "phone": "+70383611007"}
0005435614481	D435B5	9450 599742	ELENA ORLOVA	{"phone": "+70959833684"}
0005435614482	5075D1	0022 112296	ALBINA MIKHAYLOVA	{"phone": "+70184578295"}
0005435614483	AFB7BE	8739 950057	NIKOLAY ALEKSEEV	{"email": "nikolayalekseev_1980@postgrespro.ru", "phone": "+70115329034"}
0005435614484	AFB7BE	8634 085072	VIKTOR FEDOROV	{"phone": "+70036003065"}
0005435614485	AFB7BE	8661 525875	EKATERINA KONOVALOVA	{"email": "konovalova_ekaterina.1981@postgrespro.ru", "phone": "+70540881929"}
0005435614486	1BBE98	9538 135472	IGOR KUZNECOV	{"phone": "+70338750747"}
0005435614487	87A92F	5237 769307	MIKHAIL KONOVALOV	{"phone": "+70649390711"}
0005435614488	87A92F	4757 545853	VLADIMIR ZAKHAROV	{"email": "zakharov.vladimir.03041971@postgrespro.ru", "phone": "+70271741890"}
0005435614489	C85AD6	1589 006454	NATALIYA DANILOVA	{"email": "nataliya_danilova_16031980@postgrespro.ru", "phone": "+70487972558"}
0005435614490	41DC7F	5705 630776	ILYA IVANOV	{"email": "ilya.ivanov01021980@postgrespro.ru", "phone": "+70302547246"}
0005435614491	F47DF5	4499 270022	ARSENIY STEPANOV	{"email": "stepanov.a.121971@postgrespro.ru", "phone": "+70115236870"}
0005435614492	F47DF5	0525 955619	TATYANA SEMENOVA	{"email": "semenova-t-05081970@postgrespro.ru", "phone": "+70382814729"}
0005435614493	1001A3	1817 559865	ALEKSANDR POPOV	{"phone": "+70023765587"}
0005435614494	1001A3	0954 692806	ALBINA POLYAKOVA	{"email": "albina_polyakova-19091977@postgrespro.ru", "phone": "+70894972996"}
0005435614495	B69B63	8029 258414	ANGELINA TROFIMOVA	{"phone": "+70753490364"}
0005435614496	5AB394	8482 332312	ALEKSANDR VASILEV	{"phone": "+70049532406"}
0005435614497	5AB394	7305 302296	ANATOLIY DENISOV	{"email": "denisov-a111972@postgrespro.ru", "phone": "+70662416004"}
0005435614498	C0A1CD	2398 736596	ARTEM TIKHONOV	{"phone": "+70888925791"}
0005435614499	9CA11D	1418 059463	VIKTOR ANDREEV	{"email": "andreev_v111966@postgrespro.ru", "phone": "+70614176244"}
0005435614500	9CA11D	7450 410987	LIDIYA TARASOVA	{"email": "tarasoval.061979@postgrespro.ru", "phone": "+70069175345"}
0005435614501	62BC18	7607 941094	IRINA SAVELEVA	{"phone": "+70792993663"}
0005435614502	62BC18	7884 201323	LARISA RODIONOVA	{"phone": "+70762042656"}
0005435614503	FABEF6	3308 787730	ANZHELA NIKITINA	{"email": "anzhela_nikitina-1968@postgrespro.ru", "phone": "+70246757559"}
0005435614504	FABEF6	3005 403568	NIKITA IVANOV	{"phone": "+70250446537"}
0005435614505	EE47D3	6361 438371	MARINA KISELEVA	{"email": "kiseleva-m_041979@postgrespro.ru", "phone": "+70996307097"}
0005435614506	EE47D3	0922 878783	SVETLANA MASLOVA	{"phone": "+70981327585"}
0005435614507	2EE461	7028 130242	LYUBOV BELOVA	{"phone": "+70659179396"}
0005435614508	F13D57	2514 899711	ALEKSEY SERGEEV	{"email": "aleksey.sergeev_121977@postgrespro.ru", "phone": "+70550223079"}
0005435614509	A9E5C9	1041 032806	GALINA IVANOVA	{"email": "galinaivanova-29061967@postgrespro.ru", "phone": "+70657086247"}
0005435614510	33B26A	1426 764467	KIRILL BONDARENKO	{"email": "bondarenko_kirill-1974@postgrespro.ru", "phone": "+70516922867"}
0005435614511	8BAA1E	2000 762687	DMITRIY SOKOLOV	{"phone": "+70652514269"}
0005435614512	C9CE28	1621 729161	VASILIY NIKOLAEV	{"phone": "+70785236362"}
0005435614513	C9CE28	4936 032633	NADEZHDA EFREMOVA	{"phone": "+70942371220"}
0005435614514	99E875	1567 082348	NATALYA PETROVA	{"phone": "+70884361311"}
0005435614515	EB1D77	1561 512936	IVAN FROLOV	{"phone": "+70351943609"}
0005435614516	F4B8C8	1477 997737	ELIZAVETA POTAPOVA	{"email": "potapova-elizaveta061982@postgrespro.ru", "phone": "+70456659555"}
0005435614517	F4B8C8	3692 345577	ZINAIDA KUZNECOVA	{"phone": "+70717709222"}
0005435614518	B611D3	4887 650804	YURIY KULIKOV	{"phone": "+70436527847"}
0005435614519	96FCE9	4950 779926	VALENTINA ZOTOVA	{"email": "zotovavalentina.1974@postgrespro.ru", "phone": "+70242078781"}
0005435614520	96FCE9	6796 444698	IVAN MATVEEV	{"email": "ivan_matveev1971@postgrespro.ru", "phone": "+70819795718"}
0005435614521	96FCE9	0504 235612	MIKHAIL VASILEV	{"phone": "+70746822406"}
0005435614522	96FCE9	9530 817401	SVETLANA POLYAKOVA	{"email": "polyakova.s_1970@postgrespro.ru", "phone": "+70127541698"}
0005435614523	3C4B86	3868 106817	ALEKSEY MAKSIMOV	{"email": "maksimov.aleksey-23011969@postgrespro.ru", "phone": "+70476804200"}
0005435614524	E63CD8	3612 158491	NINA ALEKSEEVA	{"phone": "+70206008379"}
0005435614525	81D777	9089 064915	IRINA ANISIMOVA	{"email": "anisimovai-111973@postgrespro.ru", "phone": "+70112975455"}
0005435614526	B6166B	3603 607655	MARIYA MAKAROVA	{"phone": "+70006593772"}
0005435614527	0D078C	3216 607958	KSENIYA KAZAKOVA	{"phone": "+70544790256"}
0005435614528	9B172F	2815 684177	VALERIYA KOZLOVA	{"email": "kozlova-v05051972@postgrespro.ru", "phone": "+70059391882"}
0005435614529	2995BC	2990 129209	ALEKSANDRA POLYAKOVA	{"phone": "+70716985567"}
0005435614530	02B997	0955 784789	PAVEL IVANOV	{"phone": "+70995168034"}
0005435614531	B9C4CA	4382 762645	ANGELINA POPOVA	{"email": "popovaangelina-061975@postgrespro.ru", "phone": "+70821154399"}
0005435614532	9AF70E	5189 719864	VLADIMIR KARPOV	{"email": "karpov-v031979@postgrespro.ru", "phone": "+70875755570"}
0005435614533	9AF70E	8169 926851	GENNADIY MOROZOV	{"email": "gmorozov-071980@postgrespro.ru", "phone": "+70480426269"}
0005435614534	76AB03	8331 493918	AZAT KONOVALOV	{"email": "azat_konovalov1977@postgrespro.ru", "phone": "+70978911423"}
0005435614535	76AB03	2933 727358	YULIYA SCHERBAKOVA	{"phone": "+70918801088"}
0005435614536	76AB03	9735 987228	ANNA KUZNECOVA	{"email": "kuznecova_anna15121969@postgrespro.ru", "phone": "+70724273973"}
0005435614537	6D0E58	0187 890177	YURIY FROLOV	{"phone": "+70636777168"}
0005435614538	A35C30	8428 893116	SVETLANA MEDVEDEVA	{"email": "medvedeva_s_1975@postgrespro.ru", "phone": "+70622583160"}
0005435614539	9C384D	9112 551477	EKATERINA ZOTOVA	{"phone": "+70943914049"}
0005435614540	902166	2646 441548	ANDREY ALEKSANDROV	{"phone": "+70124560123"}
0005435614541	EF5CB1	5809 405203	YULIYA KUZNECOVA	{"email": "kuznecova_y051970@postgrespro.ru", "phone": "+70191852508"}
0005435614542	EF5CB1	7049 394694	NATALYA NAUMOVA	{"email": "naumova.natalya28031970@postgrespro.ru", "phone": "+70313081585"}
0005435614543	D75F68	3470 735516	ALEKSANDR KUZNECOV	{"phone": "+70784799610"}
0005435614544	F32645	6311 986186	ELENA KONDRATEVA	{"phone": "+70867894922"}
0005435614545	184695	3538 177866	YURIY KUZMIN	{"phone": "+70306447902"}
0005435614546	184695	4976 999259	PETR MARTYNOV	{"phone": "+70659369169"}
0005435614547	184695	0290 649293	MIKHAIL VOROBEV	{"phone": "+70013243287"}
0005435614548	184695	5568 658624	MIKHAIL POPOV	{"phone": "+70307587507"}
0005435614549	B61C8F	3113 570649	LARISA KONOVALOVA	{"email": "konovalovalarisa_1977@postgrespro.ru", "phone": "+70078869948"}
0005435614550	3ADFFD	5602 987750	SERGEY RODIONOV	{"email": "sergey.rodionov_041979@postgrespro.ru", "phone": "+70074452323"}
0005435614551	02F712	9546 076938	FATIMA VOROBEVA	{"phone": "+70193130862"}
0005435614552	02F712	3240 922747	ELENA NIKOLAEVA	{"email": "enikolaeva-10051961@postgrespro.ru", "phone": "+70274183205"}
0005435614553	2A71D6	8735 903405	SERGEY SERGEEV	{"phone": "+70594844416"}
0005435614554	2A71D6	4942 373106	GENNADIY ISAEV	{"email": "g_isaev-1978@postgrespro.ru", "phone": "+70099059741"}
0005435614555	AB213C	3499 086551	VLADISLAV SOLOVEV	{"email": "v_solovev-10061971@postgrespro.ru", "phone": "+70556184333"}
0005435614556	AB213C	1618 349090	ARTEM KONOVALOV	{"phone": "+70853415889"}
0005435614557	B07726	8213 378077	ELENA SERGEEVA	{"email": "sergeeva_e1967@postgrespro.ru", "phone": "+70335036252"}
0005435614558	B2B33F	5670 726429	NADEZHDA AFANASEVA	{"email": "nafanaseva.04051976@postgrespro.ru", "phone": "+70471056410"}
0005435614559	76CE4E	9551 483434	NIKOLAY ROMANOV	{"email": "romanov-nikolay_07051974@postgrespro.ru", "phone": "+70425025713"}
0005435614560	7F84C1	9477 949532	TIMUR AFANASEV	{"phone": "+70986216304"}
0005435614561	39F5E3	4631 060334	SVETLANA DANILOVA	{"email": "danilovas27011971@postgrespro.ru", "phone": "+70137158700"}
0005435614673	F2FA86	0273 505905	SERGEY KISELEV	{"phone": "+70101180785"}
0005435614562	39F5E3	7531 942228	ALEKSEY KUDRYASHOV	{"email": "kudryashov-a-1971@postgrespro.ru", "phone": "+70054326718"}
0005435614563	EAE947	4773 456888	OLGA IVANOVA	{"phone": "+70558642684"}
0005435615067	C4CE17	9429 788215	MARINA ZAYCEVA	{"phone": "+70546908377"}
0005435614564	AE4A90	4312 293537	DAMIR IVANOV	{"email": "damir-ivanov-18091977@postgrespro.ru", "phone": "+70541011313"}
0005435614565	AE4A90	8622 566616	ROMAN TARASOV	{"email": "romantarasov101975@postgrespro.ru", "phone": "+70100448564"}
0005435614566	222EC8	4689 241219	TAMARA MIRONOVA	{"email": "mironova-tamara.01081979@postgrespro.ru", "phone": "+70215443984"}
0005435614567	A83792	9018 006105	DMITRIY MAKAROV	{"phone": "+70147376999"}
0005435614568	A83792	1142 329243	DARYA STEPANOVA	{"email": "daryastepanova1973@postgrespro.ru", "phone": "+70032316617"}
0005435614569	92ED3F	3983 818070	YURIY VOLKOV	{"email": "volkovyuriy.22121966@postgrespro.ru", "phone": "+70055453677"}
0005435614570	2C5401	4440 059076	YULIYA LEBEDEVA	{"phone": "+70944191192"}
0005435614571	DEB799	2616 868889	GEORGIY EGOROV	{"phone": "+70147677675"}
0005435614572	72B6C2	6799 574904	ALEKSANDR ZAYCEV	{"email": "azaycev071966@postgrespro.ru", "phone": "+70608913574"}
0005435614573	72B6C2	2567 272970	NIKOLAY GAVRILOV	{"phone": "+70529508187"}
0005435614574	F9CAE3	0973 078762	GALINA POLYAKOVA	{"phone": "+70552661119"}
0005435614575	D11BFE	4983 558335	VERA SOROKINA	{"phone": "+70251056725"}
0005435614576	1D6F2B	9293 425767	NATALYA KUDRYASHOVA	{"phone": "+70111869387"}
0005435614577	1D6F2B	6288 869354	NATALYA MIKHAYLOVA	{"phone": "+70116896612"}
0005435614578	DB9132	0883 513642	LIDIYA NAZAROVA	{"email": "nazarova_lidiya_1974@postgrespro.ru", "phone": "+70548099614"}
0005435614579	DB9132	7208 777122	LIDIYA ILINA	{"phone": "+70330436618"}
0005435614580	A7CCDB	8460 209212	MARINA ZAKHAROVA	{"phone": "+70132380522"}
0005435614581	82313F	2526 843935	MARIYA MELNIKOVA	{"email": "mmelnikova_1971@postgrespro.ru", "phone": "+70790196959"}
0005435614582	4B6E67	3954 418009	ARTEM KARPOV	{"email": "karpovartem-1976@postgrespro.ru", "phone": "+70254897406"}
0005435614583	4B6E67	3024 994794	LYUDMILA MEDVEDEVA	{"email": "l_medvedeva_25101967@postgrespro.ru", "phone": "+70743506931"}
0005435614584	D34351	1067 473654	EKATERINA ALEKSEEVA	{"phone": "+70077332448"}
0005435614585	D34351	8310 770418	YURIY GUSEV	{"phone": "+70486431054"}
0005435614586	1C61F1	7244 849392	YULIYA VASILEVA	{"email": "vasilevay1973@postgrespro.ru", "phone": "+70131054361"}
0005435614587	B70522	7647 903369	ULYANA ANDREEVA	{"email": "andreeva.ulyana.1969@postgrespro.ru", "phone": "+70117555481"}
0005435614588	338872	6111 221479	YANA ANDREEVA	{"phone": "+70538230636"}
0005435614589	338872	3457 233543	ANATOLIY MAKSIMOV	{"phone": "+70478119066"}
0005435614590	418459	6182 052681	ELENA VOROBEVA	{"email": "e-vorobeva.12071966@postgrespro.ru", "phone": "+70429577676"}
0005435614591	057387	5823 108575	EVGENIY ZHUKOV	{"phone": "+70298227494"}
0005435614592	90C85B	0906 769299	NATALYA VASILEVA	{"phone": "+70588509686"}
0005435614593	1E3D10	0628 019132	STANISLAV GAVRILOV	{"phone": "+70108095781"}
0005435614594	D895A3	5122 508143	VALERIY KUZMIN	{"phone": "+70926785819"}
0005435614595	72C6B2	9891 782571	ALEKSANDR VLASOV	{"phone": "+70695396242"}
0005435614596	274F21	1594 815969	MIKHAIL TIKHONOV	{"email": "mikhail_tikhonov-05081989@postgrespro.ru", "phone": "+70755623266"}
0005435614597	274F21	0818 975825	TATYANA SMIRNOVA	{"email": "smirnova-tatyana-1974@postgrespro.ru", "phone": "+70156229921"}
0005435614598	688C29	9797 216688	ALEKSANDR ANTONOV	{"email": "antonov.aleksandr-26061970@postgrespro.ru", "phone": "+70056799067"}
0005435614599	688C29	2970 138986	OLGA NIKITINA	{"email": "nikitina-olga_011963@postgrespro.ru", "phone": "+70050033165"}
0005435614600	688C29	0787 508481	TATYANA PAVLOVA	{"phone": "+70019209337"}
0005435614601	4713F6	6465 189770	SERGEY EGOROV	{"phone": "+70511529873"}
0005435614602	4713F6	3412 276249	GALINA KOROLEVA	{"email": "galina_koroleva.1967@postgrespro.ru", "phone": "+70702758873"}
0005435614603	20A9F9	9096 928215	EGOR NIKITIN	{"email": "egor_nikitin.29041978@postgrespro.ru", "phone": "+70149228963"}
0005435614604	20A9F9	9060 819278	EKATERINA FEDOROVA	{"email": "ekaterina_fedorova.1970@postgrespro.ru", "phone": "+70471968902"}
0005435614605	BE1E14	5385 249545	NIKOLAY FEDOROV	{"email": "nikolay-fedorov1979@postgrespro.ru", "phone": "+70338211100"}
0005435614606	53AD3A	2447 543429	TATYANA VASILEVA	{"email": "tatyanavasileva.041970@postgrespro.ru", "phone": "+70078431489"}
0005435614607	CEB715	7858 078382	ALEKSEY ALEKSEEV	{"phone": "+70322307131"}
0005435614608	CEB715	0459 048787	ILDAR RODIONOV	{"phone": "+70173529965"}
0005435614609	6548E9	4791 835088	SVETLANA STEPANOVA	{"email": "s_stepanova.1979@postgrespro.ru", "phone": "+70255272490"}
0005435614610	6548E9	3465 642606	EKATERINA BOGDANOVA	{"email": "e.bogdanova1982@postgrespro.ru", "phone": "+70285958602"}
0005435614611	9DD772	9664 068281	LYUBOV SERGEEVA	{"email": "l_sergeeva_1972@postgrespro.ru", "phone": "+70153412981"}
0005435614612	9DD772	2510 404668	ALEKSANDR BORISOV	{"phone": "+70052765670"}
0005435614613	F042F0	1917 147525	ELENA EGOROVA	{"phone": "+70492394706"}
0005435614614	F042F0	8307 642984	ZHANNA PETROVA	{"email": "zhannapetrova121971@postgrespro.ru", "phone": "+70132955930"}
0005435614615	AD757D	9914 628773	VLADIMIR KARPOV	{"email": "v-karpov15031975@postgrespro.ru", "phone": "+70791071553"}
0005435614616	E5640D	8709 743665	VALENTINA KARPOVA	{"email": "karpova.v.1981@postgrespro.ru", "phone": "+70705895564"}
0005435614617	E5640D	8813 358731	ELENA VOLKOVA	{"phone": "+70366976815"}
0005435614618	70B7BC	3081 909617	LARISA LEBEDEVA	{"email": "lebedeva-larisa.101979@postgrespro.ru", "phone": "+70500860608"}
0005435614619	76C393	7782 493393	LARISA SEMENOVA	{"email": "semenova.larisa-12121960@postgrespro.ru", "phone": "+70193510063"}
0005435614620	E190AC	2256 333935	IVAN SHEVCHENKO	{"email": "shevchenko_i.1978@postgrespro.ru", "phone": "+70029267677"}
0005435614621	E190AC	6292 358011	SERGEY VLASOV	{"phone": "+70106602451"}
0005435614622	2AFE96	0163 699678	ALEKSEY MIKHAYLOV	{"email": "amikhaylov_26031972@postgrespro.ru", "phone": "+70565184725"}
0005435614623	D9D676	9751 770097	ILYAS SOLOVEV	{"email": "solovev.i_1977@postgrespro.ru", "phone": "+70011106496"}
0005435614624	566B71	7716 002469	KIRILL KARPOV	{"email": "k_karpov.13011968@postgrespro.ru", "phone": "+70451483390"}
0005435614625	2F0DF2	9820 757620	KONSTANTIN KISELEV	{"phone": "+70761153936"}
0005435614626	0F3FAF	7879 136985	DANILA GUSEV	{"email": "d_gusev21061974@postgrespro.ru", "phone": "+70196278203"}
0005435614627	E2F4C0	2154 761555	OLGA KONDRATEVA	{"email": "olga-kondrateva-1965@postgrespro.ru", "phone": "+70109719355"}
0005435614628	FE5497	9784 758696	IVAN KAZAKOV	{"email": "kazakov-i081977@postgrespro.ru", "phone": "+70976180724"}
0005435614629	20CD6E	4884 816401	IVAN SIDOROV	{"phone": "+70605335349"}
0005435614630	20CD6E	9179 800476	SERGEY STEPANOV	{"email": "sergey_stepanov-1977@postgrespro.ru", "phone": "+70102821929"}
0005435614631	7BB7D3	3343 282411	TATYANA SEMENOVA	{"email": "semenova_tatyana-011963@postgrespro.ru", "phone": "+70795791622"}
0005435614632	0F0E3C	1285 017597	NIKITA KAZAKOV	{"phone": "+70694794187"}
0005435614633	0F0E3C	8947 620497	SERGEY SIDOROV	{"phone": "+70342060119"}
0005435614634	0D4DA4	5798 798391	YAKOV KUZMIN	{"phone": "+70156593025"}
0005435614635	0D4DA4	7814 153148	PAVEL KRASNOV	{"email": "krasnov_pavel_1972@postgrespro.ru", "phone": "+70029809790"}
0005435614636	FD3831	5975 772203	VIKTOR FOMIN	{"email": "v_fomin.25021965@postgrespro.ru", "phone": "+70002029008"}
0005435614637	22074A	4308 904299	NIKOLAY NAZAROV	{"email": "n_nazarov-061979@postgrespro.ru", "phone": "+70126943193"}
0005435614638	EAACDE	8446 975038	ZOYA MIKHAYLOVA	{"email": "zmikhaylova-1967@postgrespro.ru", "phone": "+70371109305"}
0005435614639	229B2E	3917 183491	VLADIMIR SOKOLOV	{"email": "sokolov.vladimir-1974@postgrespro.ru", "phone": "+70331898582"}
0005435614640	229B2E	9825 216279	ELENA EFREMOVA	{"phone": "+70337620246"}
0005435614641	7FC174	9390 422743	ANATOLIY ROMANOV	{"email": "romanova-111963@postgrespro.ru", "phone": "+70787048091"}
0005435614642	9387CF	6880 127071	IVAN SCHERBAKOV	{"email": "scherbakov_i.071977@postgrespro.ru", "phone": "+70906896130"}
0005435614643	6AC427	0306 220623	RAIS ILIN	{"email": "rais-ilin07081961@postgrespro.ru", "phone": "+70287985453"}
0005435614644	C1481F	5247 833997	SVETLANA EGOROVA	{"email": "egorova.s1974@postgrespro.ru", "phone": "+70146119426"}
0005435614645	29B9B2	5252 494435	MARIYA FROLOVA	{"email": "frolova.m.19081969@postgrespro.ru", "phone": "+70468643334"}
0005435614646	29B9B2	9678 918043	PAVEL KAZAKOV	{"phone": "+70394315413"}
0005435614647	84E489	2595 140776	ALEKSANDR NOVIKOV	{"email": "aleksandr-novikov.1975@postgrespro.ru", "phone": "+70007818610"}
0005435614648	C87DD4	5294 989289	VITALIY VOROBEV	{"phone": "+70637830262"}
0005435614649	20ADCB	9541 165318	LYUDMILA ROMANOVA	{"email": "romanovalyudmila-31071972@postgrespro.ru", "phone": "+70023520743"}
0005435614650	F7B8A9	3276 964647	VYACHESLAV KUZMIN	{"phone": "+70185496543"}
0005435614651	196BE5	3793 288295	TAMARA ZHURAVLEVA	{"phone": "+70269381567"}
0005435614652	EE9559	2480 522929	DAVID CHERNOV	{"email": "david.chernov1970@postgrespro.ru", "phone": "+70579684683"}
0005435614653	1B0742	3607 757308	PETR AFANASEV	{"phone": "+70714688640"}
0005435614654	1B0742	6250 049912	ALEKSANDR KULIKOV	{"phone": "+70180493859"}
0005435614655	07CE34	5416 021107	NINA DMITRIEVA	{"email": "nina-dmitrieva.051969@postgrespro.ru", "phone": "+70935963308"}
0005435614656	FE2E82	9489 469906	NATALYA IVANOVA	{"phone": "+70154655535"}
0005435614657	5634E4	5879 017543	MARINA FILATOVA	{"email": "m-filatova.071969@postgrespro.ru", "phone": "+70544820605"}
0005435614658	10A19A	0035 723545	NINA DANILOVA	{"email": "danilova_nina-1982@postgrespro.ru", "phone": "+70756051884"}
0005435614659	BA0715	6431 456208	EVGENIY KOROLEV	{"email": "evgeniy_korolev-1980@postgrespro.ru", "phone": "+70860754122"}
0005435614660	B6484B	8544 428277	GALINA KOVALEVA	{"email": "kovalevagalina.1965@postgrespro.ru", "phone": "+70666457792"}
0005435614661	B6484B	2687 683115	VITALIY PAVLOV	{"phone": "+70598724847"}
0005435614662	6280A8	7385 865679	EMILIYA ZAYCEVA	{"email": "zayceva.e-1975@postgrespro.ru", "phone": "+70218551011"}
0005435614663	0051D5	9215 389628	YULIYA ABRAMOVA	{"phone": "+70511908233"}
0005435614664	AF42D3	7570 101059	TATYANA MOROZOVA	{"email": "morozova.tatyana-011969@postgrespro.ru", "phone": "+70522833510"}
0005435614665	FEA775	5815 271399	ALEKSEY SAVELEV	{"email": "saveleva_18041970@postgrespro.ru", "phone": "+70816330294"}
0005435614666	07F0DF	0010 575836	BORIS ILIN	{"phone": "+70954806197"}
0005435614667	07F0DF	2992 240468	VLADIMIR BORISOV	{"email": "v.borisov05091958@postgrespro.ru", "phone": "+70066760044"}
0005435614669	C6B1B6	0351 894476	MAKSIM STEPANOV	{"email": "m.stepanov-21071964@postgrespro.ru", "phone": "+70065444234"}
0005435614670	C6B1B6	4960 570548	ARSENIY FOMIN	{"email": "fomin.a-1981@postgrespro.ru", "phone": "+70069983429"}
0005435614671	F2FA86	8514 846173	MARINA MATVEEVA	{"email": "marina_matveeva-1968@postgrespro.ru", "phone": "+70813966800"}
0005435614672	F2FA86	5211 669439	OLEG ZAYCEV	{"phone": "+70174147304"}
0005435614674	0635D0	9377 837206	VERA KUZNECOVA	{"phone": "+70497870186"}
0005435614675	0635D0	1977 441390	VLADIMIR VOROBEV	{"phone": "+70100308962"}
0005435615068	ACC1D1	1904 095100	VLADIMIR GORBUNOV	{"phone": "+70355459127"}
0005435614676	0635D0	8384 785000	YURIY FILIPPOV	{"email": "y.filippov_09081962@postgrespro.ru", "phone": "+70814939393"}
0005435614677	1E0E91	2618 158052	IRINA KOMAROVA	{"email": "komarova_i-041991@postgrespro.ru", "phone": "+70327778976"}
0005435614678	23BF28	9078 103220	VLADISLAV ANTONOV	{"email": "antonov-vladislav31101977@postgrespro.ru", "phone": "+70269884768"}
0005435614679	9273AD	2302 864339	ALEKSANDR NAZAROV	{"phone": "+70602726724"}
0005435614680	9273AD	0076 339544	VALERIY SCHERBAKOV	{"email": "scherbakov_valeriy1969@postgrespro.ru", "phone": "+70408537618"}
0005435614681	FCC027	4467 458467	EKATERINA SERGEEVA	{"phone": "+70864157023"}
0005435614682	1B1C4A	2887 763075	VADIM KUZNECOV	{"phone": "+70069181470"}
0005435614683	0D6C14	1142 192069	LYUBOV TARASOVA	{"phone": "+70177781493"}
0005435614684	A25E7D	7191 653419	ELENA NIKOLAEVA	{"email": "nikolaeva.e.13071972@postgrespro.ru", "phone": "+70592450742"}
0005435614685	A25E7D	5014 581783	LYUDMILA VOROBEVA	{"email": "lyudmila-vorobeva.24091968@postgrespro.ru", "phone": "+70383512013"}
0005435614686	830B26	6985 417298	RAVIL KUZNECOV	{"email": "r.kuznecov121976@postgrespro.ru", "phone": "+70549823962"}
0005435614687	15237C	5084 187452	MIKHAIL KUZNECOV	{"email": "kuznecov.mikhail-1957@postgrespro.ru", "phone": "+70017785668"}
0005435614688	991A4B	6337 809119	YULIYA SERGEEVA	{"email": "sergeeva_y.03041964@postgrespro.ru", "phone": "+70119342239"}
0005435614689	064CE3	0775 363434	VLADIMIR MAKSIMOV	{"email": "maksimov-v30091975@postgrespro.ru", "phone": "+70857666049"}
0005435614690	EC6CF3	2741 253767	ALEKSANDR FILIPPOV	{"email": "filippov-a101977@postgrespro.ru", "phone": "+70620705487"}
0005435614691	AA1775	3194 686723	ELENA SIDOROVA	{"phone": "+70607592124"}
0005435614692	9CC57E	6323 349892	TATYANA NIKITINA	{"email": "t.nikitina-13121966@postgrespro.ru", "phone": "+70387401849"}
0005435614693	C1205B	1865 759288	TAMARA ZAYCEVA	{"phone": "+70008385330"}
0005435614694	C1205B	3163 638150	ANATOLIY KUZMIN	{"email": "akuzmin-041977@postgrespro.ru", "phone": "+70281306537"}
0005435614695	1C4E18	1754 476868	MAKSIM PETROV	{"email": "petrov_maksim.1971@postgrespro.ru", "phone": "+70894482173"}
0005435614696	7A6ECF	1244 544467	ALEKSANDR IVANOV	{"email": "ivanovaleksandr031980@postgrespro.ru", "phone": "+70222848964"}
0005435614697	144C80	3717 057475	IRINA MAKAROVA	{"email": "makarova_irina-1978@postgrespro.ru", "phone": "+70608399934"}
0005435614698	B5A21D	0903 259594	ALEKSANDR SERGEEV	{"phone": "+70707214594"}
0005435614699	26FEB6	8382 368747	MIKHAIL GRIGOREV	{"phone": "+70523435497"}
0005435614700	98AB8C	8779 438138	ANTON GAVRILOV	{"email": "gavrilov_anton.031979@postgrespro.ru", "phone": "+70325154026"}
0005435614701	22A9A8	2791 345580	ALENA LEBEDEVA	{"email": "alena.lebedeva.041967@postgrespro.ru", "phone": "+70486054950"}
0005435614702	22A9A8	9185 592347	OLGA KULIKOVA	{"phone": "+70711857639"}
0005435614703	22A9A8	2934 468481	TAMARA FOMINA	{"email": "t-fomina.1983@postgrespro.ru", "phone": "+70073498302"}
0005435614704	22A9A8	8809 878654	LYUDMILA FEDOROVA	{"email": "fedorova.lyudmila-07101973@postgrespro.ru", "phone": "+70416724029"}
0005435614705	2F9B6E	6256 914158	VALENTINA ISAEVA	{"phone": "+70628280521"}
0005435614706	D6799E	4942 711583	OKSANA BARANOVA	{"phone": "+70543969252"}
0005435614707	965E45	5004 781625	ZINAIDA ORLOVA	{"phone": "+70598862452"}
0005435614708	965E45	5953 107922	VLADIMIR SMIRNOV	{"phone": "+70813899478"}
0005435614709	9640A7	6077 106147	GENNADIY PETROV	{"email": "gpetrov.26071976@postgrespro.ru", "phone": "+70147104263"}
0005435614710	1FEE71	1734 000840	NIKOLAY ZHUKOV	{"email": "zhukov-n-12111977@postgrespro.ru", "phone": "+70011435674"}
0005435614711	9BC420	8243 233753	VLADISLAV VOLKOV	{"phone": "+70397782946"}
0005435614712	9BC420	9004 690107	NINA RODIONOVA	{"email": "rodionova.nina.23121975@postgrespro.ru", "phone": "+70572443681"}
0005435614713	7FC2FC	4401 351603	GALINA ZHUKOVA	{"phone": "+70633122347"}
0005435614714	83B1A3	1937 272474	ALEKSEY ANDREEV	{"phone": "+70029745351"}
0005435614715	367FDF	1688 823487	SVETLANA LEBEDEVA	{"email": "svetlana_lebedeva-1968@postgrespro.ru", "phone": "+70109627342"}
0005435614716	367FDF	6444 575343	VLADIMIR MELNIKOV	{"email": "vmelnikov.111981@postgrespro.ru", "phone": "+70639609101"}
0005435614717	24D08E	6742 433693	NINA KUZMINA	{"email": "n-kuzmina.051966@postgrespro.ru", "phone": "+70265629228"}
0005435614718	078F8F	7504 565607	TATYANA KOZLOVA	{"email": "tatyana_kozlova_14011964@postgrespro.ru", "phone": "+70925766384"}
0005435614719	078F8F	3410 915944	NIKOLAY KOZLOV	{"email": "nikolay-kozlov_1966@postgrespro.ru", "phone": "+70249423083"}
0005435614720	078F8F	6218 959682	FARIDA YUDINA	{"phone": "+70209375187"}
0005435614721	0F28C5	8249 497025	ANNA TARASOVA	{"email": "tarasova_a.14051979@postgrespro.ru", "phone": "+70961578277"}
0005435614722	77DD93	8844 074875	YULIYA VOLKOVA	{"email": "volkova-yuliya_1969@postgrespro.ru", "phone": "+70659454932"}
0005435614723	2666C7	3147 846690	KONSTANTIN PAVLOV	{"email": "pavlovk.061972@postgrespro.ru", "phone": "+70019730940"}
0005435614724	E3198F	7206 066887	TATYANA MIKHAYLOVA	{"phone": "+70108531899"}
0005435614725	0D4A12	0404 037427	IRINA MAKAROVA	{"phone": "+70215131457"}
0005435614726	C7385F	1138 773339	MARIYA TIKHONOVA	{"email": "m.tikhonova.1969@postgrespro.ru", "phone": "+70991099151"}
0005435614909	B0F3B9	3285 051262	NIKOLAY MOISEEV	{"phone": "+70790957624"}
0005435614727	6C6FA0	7243 439843	ELENA OSIPOVA	{"email": "osipova_e031977@postgrespro.ru", "phone": "+70072406847"}
0005435614728	26B699	3703 568659	LIDIYA ALEKSANDROVA	{"email": "l-aleksandrova.1968@postgrespro.ru", "phone": "+70453047473"}
0005435614729	7E17F6	2131 094464	PETR IVANOV	{"email": "ivanovpetr-1973@postgrespro.ru", "phone": "+70372246031"}
0005435614730	6D1C53	7666 167686	IRINA AKIMOVA	{"phone": "+70153416586"}
0005435614731	DD4037	5946 535710	INNA KISELEVA	{"email": "kiseleva.i_1974@postgrespro.ru", "phone": "+70324544771"}
0005435614732	DD4037	1988 493064	NIKOLAY SMIRNOV	{"email": "nikolaysmirnov-25111977@postgrespro.ru", "phone": "+70419666886"}
0005435614733	533D62	7879 998719	GALINA ABRAMOVA	{"phone": "+70409347645"}
0005435614734	E083C0	4448 935868	MARIYA ZAKHAROVA	{"phone": "+70292253274"}
0005435614735	E083C0	6691 310642	VIKTOR NIKITIN	{"phone": "+70494737454"}
0005435614736	ECFF7E	7474 753288	DARYA SMIRNOVA	{"phone": "+70280397579"}
0005435614737	37353D	9509 727503	ZOYA BELYAEVA	{"phone": "+70404543564"}
0005435614738	A01747	9251 446123	ALEKSANDR KUDRYASHOV	{"phone": "+70106562540"}
0005435614739	128C2E	5669 793599	ALBERT MIKHAYLOV	{"phone": "+70949132465"}
0005435614740	0BBC7D	2218 937590	OLGA MIRONOVA	{"email": "omironova1961@postgrespro.ru", "phone": "+70638085212"}
0005435614741	0BBC7D	8849 413083	OLGA STEPANOVA	{"phone": "+70471232626"}
0005435614742	0BBC7D	2387 343906	PELAGEYA TIMOFEEVA	{"email": "timofeevap_081977@postgrespro.ru", "phone": "+70158112458"}
0005435614743	96BAD9	5722 755806	ALEKSANDR ALEKSANDROV	{"phone": "+70477399521"}
0005435614744	263A68	0002 939942	VADIM STEPANOV	{"phone": "+70866039083"}
0005435614745	CA32C5	4260 606601	YULIYA MAKSIMOVA	{"phone": "+70121262795"}
0005435614746	CA32C5	9871 248895	ALEKSANDR GAVRILOV	{"phone": "+70674769909"}
0005435614747	7DEB69	2189 099517	ALEKSANDRA ALEKSEEVA	{"phone": "+70091256700"}
0005435614748	7DEB69	0645 854690	DMITRIY BELOV	{"phone": "+70770321633"}
0005435614749	31B805	3760 086596	IRINA KOVALEVA	{"email": "kovaleva_irina_101969@postgrespro.ru", "phone": "+70856380381"}
0005435614750	005B3C	8964 645885	NIKOLAY SERGEEV	{"phone": "+70998191674"}
0005435614751	005B3C	7244 213855	ANASTASIYA ISAEVA	{"phone": "+70838224378"}
0005435614752	B9756B	7003 776610	LARISA TIMOFEEVA	{"phone": "+70310931248"}
0005435614753	6A7347	8406 737447	SOFYA KONDRATEVA	{"phone": "+70840891557"}
0005435614754	5D52EC	3330 152782	VALENTINA TARASOVA	{"phone": "+70425604853"}
0005435614755	92AC50	3251 696558	ALEKSANDR GRIGOREV	{"phone": "+70992302788"}
0005435614756	92AC50	7506 956747	YULIYA KOMAROVA	{"phone": "+70222352638"}
0005435614757	D3B5AA	6921 559490	LYUBOV BELOVA	{"phone": "+70786859249"}
0005435614758	B184D1	0942 647017	ELENA KULIKOVA	{"phone": "+70642536624"}
0005435614759	2FE168	9307 558524	IRINA BELYAEVA	{"phone": "+70441512512"}
0005435614760	2FE168	4866 122041	TATYANA KOZLOVA	{"email": "kozlova_t.071978@postgrespro.ru", "phone": "+70724618033"}
0005435614761	2FE168	4837 510195	ROMAN SHEVCHENKO	{"email": "shevchenko_r081961@postgrespro.ru", "phone": "+70015937053"}
0005435614762	2FE168	2178 890805	ALEKSANDR NIKOLAEV	{"phone": "+70406525186"}
0005435614763	ED8669	7961 658895	MARIYA IVANOVA	{"email": "mivanova.1984@postgrespro.ru", "phone": "+70907600902"}
0005435614764	790BAB	8743 043253	NIKOLAY KUZNECOV	{"phone": "+70282764786"}
0005435614765	BD6D4D	9519 852267	VYACHESLAV KAZAKOV	{"email": "v_kazakov1972@postgrespro.ru", "phone": "+70875957219"}
0005435614766	FECD80	1317 514981	MAYYA KUZNECOVA	{"email": "m-kuznecova.27121972@postgrespro.ru", "phone": "+70011762186"}
0005435614767	FECD80	0968 876426	MIKHAIL VOROBEV	{"phone": "+70374090976"}
0005435614768	5D5536	9108 916202	OLEG PETROV	{"phone": "+70953522325"}
0005435614769	5D5536	0703 529082	ALEKSANDR BONDARENKO	{"email": "bondarenko.aleksandr-1979@postgrespro.ru", "phone": "+70680407541"}
0005435614770	CB7E69	6103 395169	EVGENIY SERGEEV	{"email": "evgeniy-sergeev-10051987@postgrespro.ru", "phone": "+70622905493"}
0005435614771	C2B038	4554 507538	LARISA KAZAKOVA	{"phone": "+70439102762"}
0005435614772	2B5FD3	0696 669694	EKATERINA KONOVALOVA	{"phone": "+70169439256"}
0005435614773	BF2AD7	0389 384770	DENIS KUZMIN	{"email": "dkuzmin.061966@postgrespro.ru", "phone": "+70407419615"}
0005435614774	BF2AD7	6193 381166	VIKTOR SERGEEV	{"phone": "+70307949430"}
0005435614775	BF2AD7	9555 199238	VALENTINA BORISOVA	{"phone": "+70515033112"}
0005435614776	D787F5	1660 980658	OLGA DENISOVA	{"email": "o.denisova1972@postgrespro.ru", "phone": "+70024743724"}
0005435614777	D787F5	4692 302437	VALENTIN OSIPOV	{"phone": "+70083449680"}
0005435614778	04E46B	6684 795806	EKATERINA EGOROVA	{"email": "egorova.e_17011974@postgrespro.ru", "phone": "+70257755205"}
0005435614779	CE147D	6202 793228	VLADIMIR SOROKIN	{"phone": "+70383162502"}
0005435614780	0415B6	5658 529305	ARKADIY DENISOV	{"email": "arkadiy_denisov_24081966@postgrespro.ru", "phone": "+70516056745"}
0005435614781	8913DA	5586 702747	MIKHAIL MAKAROV	{"email": "makarov-mikhail_021974@postgrespro.ru", "phone": "+70720702207"}
0005435614782	8913DA	5417 096547	VYACHESLAV MEDVEDEV	{"email": "medvedev.v-12041962@postgrespro.ru", "phone": "+70313802747"}
0005435614783	BCC503	3031 729876	IVAN GRIGOREV	{"email": "igrigorev-1971@postgrespro.ru", "phone": "+70632692671"}
0005435614784	BCC503	0067 034397	SOFIYA NOVIKOVA	{"email": "novikova-sofiya-1970@postgrespro.ru", "phone": "+70493781421"}
0005435614785	9DABC2	1888 658619	VERA POPOVA	{"email": "popova-v.1981@postgrespro.ru", "phone": "+70359338631"}
0005435614841	1F6F84	7884 616740	EVGENIY FILIPPOV	{"phone": "+70456886188"}
0005435614786	9DABC2	3468 262543	VALERIY IVANOV	{"email": "v-ivanov.111976@postgrespro.ru", "phone": "+70258749348"}
0005435614787	9DABC2	1262 220554	LEONID MELNIKOV	{"email": "melnikov_leonid-061973@postgrespro.ru", "phone": "+70552768889"}
0005435614788	7554A6	2202 703482	IVAN KUZNECOV	{"phone": "+70797560891"}
0005435614790	645ABF	7735 369292	ALEKSANDR GUSEV	{"email": "aleksandr.gusev-061978@postgrespro.ru", "phone": "+70837242281"}
0005435614791	C87CD2	9775 099568	NIKOLAY ANDREEV	{"email": "n-andreev.121975@postgrespro.ru", "phone": "+70554091102"}
0005435614792	49A092	0663 575414	ALEKSANDR TIKHONOV	{"email": "tikhonov.aleksandr.17081970@postgrespro.ru", "phone": "+70807991370"}
0005435614793	49A092	9044 844158	ELIZAVETA ANTONOVA	{"phone": "+70867250227"}
0005435614794	AF1782	0309 797897	LEONID FROLOV	{"email": "leonid.frolov.20011967@postgrespro.ru", "phone": "+70271194045"}
0005435614795	ADD96F	4832 315878	KIRA STEPANOVA	{"phone": "+70172261489"}
0005435614796	68BE86	0900 747030	ELENA ERMAKOVA	{"phone": "+70945954578"}
0005435614797	68BE86	4158 768492	VLADIMIR PAVLOV	{"email": "pavlovv_19081981@postgrespro.ru", "phone": "+70881306363"}
0005435614798	68BE86	3270 596220	ALESYA NAUMOVA	{"email": "alesya-naumova.051977@postgrespro.ru", "phone": "+70479991043"}
0005435614799	B56C35	0584 541416	TATYANA POPOVA	{"phone": "+70128503055"}
0005435614800	4A5FB8	6133 360534	EKATERINA KOZLOVA	{"email": "e-kozlova051966@postgrespro.ru", "phone": "+70280385809"}
0005435614801	DFD447	7001 393356	RUSTAM ROMANOV	{"phone": "+70549805627"}
0005435614802	342024	2665 529899	VALENTINA MOISEEVA	{"email": "moiseeva.valentina-021975@postgrespro.ru", "phone": "+70770969275"}
0005435614803	6E97B7	8049 969240	DMITRIY KONOVALOV	{"phone": "+70981731857"}
0005435614804	6E97B7	8446 647502	VIKTORIYA NIKITINA	{"phone": "+70486606124"}
0005435614805	EFD7CC	5642 783900	LIDIYA KUZNECOVA	{"phone": "+70426434100"}
0005435614806	36DF7A	8892 658242	EVGENIY VOLKOV	{"email": "e.volkov.041972@postgrespro.ru", "phone": "+70855424436"}
0005435614807	EF7229	4332 618493	ALBERT NAUMOV	{"phone": "+70120925682"}
0005435614808	EF7229	9439 554572	TATYANA EGOROVA	{"phone": "+70965646596"}
0005435614809	184755	9226 692523	EVGENIY SCHERBAKOV	{"email": "escherbakov.12041978@postgrespro.ru", "phone": "+70173118137"}
0005435614810	184755	3317 329410	NADEZHDA VOROBEVA	{"phone": "+70504871912"}
0005435614811	765D50	4827 478915	MADINA KUZNECOVA	{"phone": "+70416757454"}
0005435614812	CCB0B9	1083 358054	ALEKSANDR DMITRIEV	{"phone": "+70425391073"}
0005435614813	CCB0B9	2425 749595	VIKTOR POPOV	{"email": "popov.viktor-06091983@postgrespro.ru", "phone": "+70298273062"}
0005435614814	251B3C	7102 438904	VASILIY ANDREEV	{"email": "vasiliy-andreev051966@postgrespro.ru", "phone": "+70048035004"}
0005435614815	251B3C	7910 063159	VLADIMIR IVANOV	{"email": "ivanov.vladimir041980@postgrespro.ru", "phone": "+70820816301"}
0005435614816	E7FDEF	7339 397310	ANATOLIY KUZNECOV	{"email": "anatoliy_kuznecov-1984@postgrespro.ru", "phone": "+70684468250"}
0005435614817	33EAE5	9954 329058	GENNADIY NIKOLAEV	{"phone": "+70308085038"}
0005435614818	6EB61C	3738 293088	ANDREY IVANOV	{"phone": "+70403276228"}
0005435614819	074AC9	9335 152468	VALERIY SOKOLOV	{"email": "sokolovvaleriy_1976@postgrespro.ru", "phone": "+70496892318"}
0005435614820	074AC9	0414 482687	VLADIMIR FROLOV	{"email": "frolov_vladimir.1965@postgrespro.ru", "phone": "+70157698254"}
0005435614821	074AC9	3634 777944	SVETLANA LEBEDEVA	{"phone": "+70696200945"}
0005435614822	E425F6	8672 143332	IVAN SAVELEV	{"phone": "+70589158652"}
0005435614823	8274E0	5580 786919	LYUDMILA VOLKOVA	{"email": "lyudmila.volkova_24081964@postgrespro.ru", "phone": "+70628773815"}
0005435614824	2B0633	3292 794712	VALENTINA SMIRNOVA	{"email": "smirnovav1980@postgrespro.ru", "phone": "+70879448994"}
0005435614825	B73D12	2967 368417	ALEKSEY ZHUKOV	{"phone": "+70396717350"}
0005435614826	615E07	3772 888415	YULIYA GAVRILOVA	{"email": "gavrilova_yuliya_04051973@postgrespro.ru", "phone": "+70420526032"}
0005435614827	F60E4D	2491 654040	ELENA BORISOVA	{"phone": "+70047307794"}
0005435614828	F60E4D	4458 655323	IRINA KAZAKOVA	{"phone": "+70461472721"}
0005435614829	4D0014	7327 135354	KIRILL IVANOV	{"email": "kirill_ivanov-091978@postgrespro.ru", "phone": "+70382611716"}
0005435614830	3F4FD5	1095 902211	MARIYA ARKHIPOVA	{"email": "arkhipova.m-14121987@postgrespro.ru", "phone": "+70769467484"}
0005435614831	D00CA7	1274 795584	OLGA VASILEVA	{"phone": "+70062497508"}
0005435614832	D00CA7	8598 953380	EKATERINA ILINA	{"email": "ilina_ekaterina091970@postgrespro.ru", "phone": "+70658217372"}
0005435614833	BDC047	2566 104480	ALEKSEY ZAYCEV	{"phone": "+70009889683"}
0005435614834	662394	3638 173601	ANDREY SOROKIN	{"email": "sorokin_andrey.1977@postgrespro.ru", "phone": "+70223978804"}
0005435614835	82DBF2	6598 612614	SERGEY OSIPOV	{"email": "sergey_osipov-23031976@postgrespro.ru", "phone": "+70508194741"}
0005435614836	2ADA9E	0998 663913	SERGEY MOROZOV	{"email": "sergey-morozov_1970@postgrespro.ru", "phone": "+70300487606"}
0005435614837	8FC34A	8417 209248	ALINA KONDRATEVA	{"email": "kondrateva.alina1960@postgrespro.ru", "phone": "+70546389789"}
0005435614838	23F916	4242 952727	LYUDMILA KONOVALOVA	{"email": "lkonovalova021975@postgrespro.ru", "phone": "+70858707185"}
0005435614839	CFA074	1615 985625	ELENA NAZAROVA	{"email": "elenanazarova_071983@postgrespro.ru", "phone": "+70144509970"}
0005435614840	22A12D	6605 132439	OLGA KOZLOVA	{"email": "o_kozlova-031975@postgrespro.ru", "phone": "+70706811776"}
0005435614842	811EB4	6936 291502	ZOYA OSIPOVA	{"email": "zoya.osipova1988@postgrespro.ru", "phone": "+70957782779"}
0005435615127	EC3269	7959 209846	SERGEY ZHURAVLEV	{"phone": "+70930484541"}
0005435614843	811EB4	4554 384895	IVAN MARTYNOV	{"email": "martynov.i061968@postgrespro.ru", "phone": "+70458385033"}
0005435614844	F760D4	1693 803466	NIKOLAY ISAEV	{"email": "isaev.nikolay_081964@postgrespro.ru", "phone": "+70511383615"}
0005435614845	F760D4	8898 434047	STANISLAV MOISEEV	{"phone": "+70368892530"}
0005435614846	FF5903	9777 540526	SERGEY RODIONOV	{"phone": "+70637946924"}
0005435614847	FF5903	5848 491690	IGOR MAKAROV	{"phone": "+70876183896"}
0005435614848	24E83A	1183 435576	SVETLANA KARPOVA	{"email": "karpova_svetlana28101971@postgrespro.ru", "phone": "+70540661633"}
0005435614850	C3EF74	9426 167553	VLADIMIR PAVLOV	{"email": "pavlov.vladimir1968@postgrespro.ru", "phone": "+70674872259"}
0005435614851	026C4C	6890 957435	MIKHAIL IVANOV	{"phone": "+70542180145"}
0005435614852	026C4C	2070 393892	ZOYA ILINA	{"phone": "+70589437977"}
0005435614853	D69EF0	7984 645036	SERGEY SOROKIN	{"email": "s.sorokin_031976@postgrespro.ru", "phone": "+70491429302"}
0005435614854	D69EF0	5527 163648	ANNA VLASOVA	{"email": "vlasova.anna.101971@postgrespro.ru", "phone": "+70894134390"}
0005435614855	E2095F	9274 784733	OLGA KOZLOVA	{"phone": "+70983550894"}
0005435614856	E2095F	2555 727328	SVETLANA FROLOVA	{"phone": "+70447800063"}
0005435614857	CE1694	4824 730694	ROMAN GUSEV	{"phone": "+70586461736"}
0005435614858	4B3531	9797 936151	ANTON SAVELEV	{"email": "savelev.a1977@postgrespro.ru", "phone": "+70930934592"}
0005435614859	ECE3D7	9993 511741	YAROSLAV VOLKOV	{"phone": "+70677359151"}
0005435614860	210BFF	0403 870797	VLADIMIR ZAKHAROV	{"email": "zakharov_vladimir-091966@postgrespro.ru", "phone": "+70281410243"}
0005435614861	AA6B35	1985 459247	ANASTASIYA MOISEEVA	{"phone": "+70462213075"}
0005435614862	0E22F5	7420 513517	ELENA MIKHAYLOVA	{"email": "e.mikhaylova.081975@postgrespro.ru", "phone": "+70941941541"}
0005435614863	0E22F5	7555 126740	YURIY ALEKSEEV	{"phone": "+70929467468"}
0005435614864	A2DB31	1557 918237	YAROSLAV IVANOV	{"email": "ivanov.yaroslav.1972@postgrespro.ru", "phone": "+70170135419"}
0005435614865	EBC729	5323 741954	YURIY OSIPOV	{"email": "yosipov01061974@postgrespro.ru", "phone": "+70027095848"}
0005435614866	155ABE	1714 474262	VLADIMIR GAVRILOV	{"email": "gavrilovv1968@postgrespro.ru", "phone": "+70949588420"}
0005435614867	121C2D	4872 193505	TAMARA MOROZOVA	{"email": "morozovat12021965@postgrespro.ru", "phone": "+70008189499"}
0005435614868	019A15	9286 626061	NIKITA BELOV	{"email": "belov-nikita29041973@postgrespro.ru", "phone": "+70553726183"}
0005435614869	392254	4757 874925	BOGDAN SEMENOV	{"email": "semenov.bogdan1975@postgrespro.ru", "phone": "+70923648418"}
0005435614870	D40B23	5990 215363	MIKHAIL EGOROV	{"phone": "+70673520468"}
0005435614871	D40B23	3187 963921	ELENA ZAKHAROVA	{"email": "zakharovae.17041975@postgrespro.ru", "phone": "+70082954695"}
0005435614872	699A6D	5472 537355	SERGEY MAKAROV	{"email": "makarovs071966@postgrespro.ru", "phone": "+70186511700"}
0005435614873	699A6D	9366 095848	ALEKSANDR STEPANOV	{"phone": "+70770426248"}
0005435614874	AF4F0D	3233 277416	ROMAN TARASOV	{"phone": "+70542830289"}
0005435614875	9098EC	6664 421798	VLADIMIR KUDRYASHOV	{"phone": "+70045076261"}
0005435614876	9E220B	2032 611516	NINA GRISHINA	{"phone": "+70672363931"}
0005435614877	9E6934	5454 507644	SERGEY KONOVALOV	{"email": "konovalov-sergey.1979@postgrespro.ru", "phone": "+70183966087"}
0005435614878	085821	1486 314994	VLADIMIR KUZNECOV	{"email": "kuznecov_v-1978@postgrespro.ru", "phone": "+70283286392"}
0005435614879	587997	9698 488792	PETR ROMANOV	{"phone": "+70943370018"}
0005435614880	55B6EA	1726 958818	VLADIMIR STEPANOV	{"phone": "+70009174650"}
0005435614881	C5A463	5449 861720	ALEKSANDRA SIDOROVA	{"email": "aleksandrasidorova_121967@postgrespro.ru", "phone": "+70835723354"}
0005435614882	A6E907	7746 086985	LYUDMILA IVANOVA	{"phone": "+70431028018"}
0005435614883	A6E907	6371 857518	ANASTASIYA KONOVALOVA	{"phone": "+70304622826"}
0005435614884	A6E907	3760 750710	VERA SIDOROVA	{"phone": "+70371013821"}
0005435614885	7BD955	1142 600641	ANATOLIY NAUMOV	{"phone": "+70828400388"}
0005435614886	FECE4A	4398 467627	ANDREY ROMANOV	{"email": "romanov.andrey29091969@postgrespro.ru", "phone": "+70161979571"}
0005435614887	4B15C0	3197 229525	PAVEL POPOV	{"phone": "+70211167293"}
0005435614888	4F1F66	8342 423725	SERGEY GUSEV	{"email": "gusev.s.17061973@postgrespro.ru", "phone": "+70845418280"}
0005435614889	370B13	7925 346176	SERGEY ROMANOV	{"phone": "+70227783665"}
0005435614890	370B13	7686 210111	OLEG KUZNECOV	{"email": "kuznecov.oleg051970@postgrespro.ru", "phone": "+70666180539"}
0005435614891	B21819	7236 293384	MARAT MAKAROV	{"phone": "+70710102890"}
0005435614892	91D7B1	4739 706924	DMITRIY ZHUKOV	{"phone": "+70878579155"}
0005435614893	865956	5052 757434	VLADISLAV MIKHAYLOV	{"email": "v_mikhaylov.1962@postgrespro.ru", "phone": "+70273622235"}
0005435614894	92CAB3	6047 583305	VLADIMIR SIDOROV	{"email": "sidorov.vladimir03071976@postgrespro.ru", "phone": "+70992649893"}
0005435614895	93BBD7	1200 630765	VLADIMIR SEMENOV	{"phone": "+70120189250"}
0005435614896	93BBD7	9651 963063	SVETLANA MOROZOVA	{"email": "morozova_svetlana_24101989@postgrespro.ru", "phone": "+70207576688"}
0005435614897	CEC251	5761 707015	YULIYA IVANOVA	{"email": "ivanova-yuliya1969@postgrespro.ru", "phone": "+70162992180"}
0005435615010	C4116A	9781 272126	NIKOLAY SIDOROV	{"phone": "+70109506910"}
0005435615182	1D6AC1	8435 366933	KLAVDIYA NIKITINA	{"phone": "+70473972952"}
0005435614898	6C03D5	4683 401674	VYACHESLAV MOROZOV	{"email": "vmorozov081971@postgrespro.ru", "phone": "+70435039946"}
0005435614899	6C03D5	0982 339788	ALEKSANDR EGOROV	{"email": "aleksandr.egorov.11061972@postgrespro.ru", "phone": "+70761399219"}
0005435614900	A41AA0	8508 299054	OLGA SAVELEVA	{"phone": "+70832759651"}
0005435614901	BFBF72	4878 312871	VLADIMIR SCHERBAKOV	{"phone": "+70537166546"}
0005435614902	BFBF72	0900 356086	ANATOLIY ANTONOV	{"email": "anatoliy-antonov.08071976@postgrespro.ru", "phone": "+70675285268"}
0005435614903	B605F2	7557 855107	ALEKSANDR MELNIKOV	{"phone": "+70292998964"}
0005435614904	B605F2	9780 198188	MIKHAIL MIKHAYLOV	{"phone": "+70782813688"}
0005435614905	8F7FDC	8440 151228	OKSANA TARASOVA	{"email": "oksana.tarasova1974@postgrespro.ru", "phone": "+70810271673"}
0005435614906	8F7FDC	6992 953468	VERA RODIONOVA	{"phone": "+70360102838"}
0005435614907	58DCE9	6287 216797	IRINA KOZLOVA	{"email": "irina.kozlova-1977@postgrespro.ru", "phone": "+70067079685"}
0005435614908	58DCE9	7727 267462	ALEKSANDR ANTONOV	{"phone": "+70251802442"}
0005435614910	E63129	3159 357687	VALENTINA ABRAMOVA	{"email": "abramova_valentina-29041972@postgrespro.ru", "phone": "+70353834775"}
0005435614911	D7C477	8920 657271	RAMIL ZAKHAROV	{"phone": "+70797744075"}
0005435614912	018E94	6239 788977	VASILIY SOROKIN	{"phone": "+70303838349"}
0005435614913	24ECEB	9370 039886	FANIYA FEDOROVA	{"email": "faniyafedorova1963@postgrespro.ru", "phone": "+70308778338"}
0005435614914	24ECEB	4392 375188	ANASTASIYA BOGDANOVA	{"email": "abogdanova.1968@postgrespro.ru", "phone": "+70869358813"}
0005435614915	45B9ED	3507 796493	IRINA OSIPOVA	{"phone": "+70859691037"}
0005435614916	FEE8FB	8596 133666	ALEKSEY FROLOV	{"phone": "+70726813580"}
0005435614917	FEE8FB	4640 697667	YULIYA ORLOVA	{"phone": "+70233328469"}
0005435614918	AADD28	0252 517672	YANA YAKOVLEVA	{"phone": "+70211088785"}
0005435614919	758861	0386 932408	IVAN NAUMOV	{"email": "i_naumov.02121993@postgrespro.ru", "phone": "+70935014772"}
0005435614920	758861	9042 004033	LYUDMILA MOROZOVA	{"phone": "+70586819827"}
0005435614921	A41E23	8915 763308	MIKHAIL ANDREEV	{"email": "m_andreev_1973@postgrespro.ru", "phone": "+70961815733"}
0005435614922	B3F27D	2792 639293	IVAN VOROBEV	{"email": "i-vorobev-1966@postgrespro.ru", "phone": "+70625013205"}
0005435614923	B3F27D	1367 568790	ROMAN DAVYDOV	{"email": "davydov-roman_1973@postgrespro.ru", "phone": "+70970803073"}
0005435614924	DAA807	9047 873907	RAISA MAKAROVA	{"phone": "+70652538547"}
0005435614925	4AD74A	9332 815554	ALEKSANDR KUZNECOV	{"email": "aleksandr_kuznecov_1953@postgrespro.ru", "phone": "+70732852436"}
0005435614926	F0845C	3532 594257	ZOYA TIMOFEEVA	{"email": "z-timofeeva_111980@postgrespro.ru", "phone": "+70701165960"}
0005435614927	13A3A6	2972 377053	VERA KOMAROVA	{"email": "komarova.v-121976@postgrespro.ru", "phone": "+70440241032"}
0005435614928	747401	9009 002118	NADEZHDA KOZLOVA	{"email": "nadezhda.kozlova_1979@postgrespro.ru", "phone": "+70641502350"}
0005435614929	77E8F1	3697 614061	ALISA SAVELEVA	{"phone": "+70314938427"}
0005435614930	837474	9867 292166	SERGEY KRASNOV	{"email": "skrasnov_14041976@postgrespro.ru", "phone": "+70792048106"}
0005435614931	837474	7140 061796	VLADIMIR BORISOV	{"phone": "+70753552986"}
0005435614932	837474	3259 520114	IVAN IVANOV	{"phone": "+70776389595"}
0005435614933	0BBF01	5484 146097	DMITRIY NIKITIN	{"email": "nikitin-dmitriy.121966@postgrespro.ru", "phone": "+70343889129"}
0005435614934	2CE141	2414 144136	VLADIMIR MAKAROV	{"email": "v-makarov-13081966@postgrespro.ru", "phone": "+70248346027"}
0005435614935	14E8FD	1978 905556	FEDOR PAVLOV	{"phone": "+70354228075"}
0005435614936	2E9F7A	2423 586183	IRINA MAKSIMOVA	{"email": "maksimovairina_1971@postgrespro.ru", "phone": "+70747232173"}
0005435614937	C081D9	3319 073463	VIKTOR SHEVCHENKO	{"phone": "+70328887981"}
0005435614938	B5655C	2598 174615	TATYANA SOKOLOVA	{"phone": "+70732224020"}
0005435614939	B5655C	4106 449717	ANATOLIY PAVLOV	{"email": "pavlova_051970@postgrespro.ru", "phone": "+70863615676"}
0005435614940	C002E0	1189 999583	VERONIKA GRISHINA	{"phone": "+70404149605"}
0005435614941	9AA2D5	7235 262082	LIDIYA SOLOVEVA	{"phone": "+70738655307"}
0005435614942	9AA2D5	1712 439371	ALEKSANDR ROMANOV	{"phone": "+70868586308"}
0005435614943	AFD703	5815 703439	NATALIYA KOLESNIKOVA	{"phone": "+70585593770"}
0005435614944	AFD703	2206 784413	RUSTAM KAZAKOV	{"phone": "+70067926206"}
0005435614945	2B6596	1285 937674	TAISIYA ZHUKOVA	{"phone": "+70769503527"}
0005435614946	C6BC6E	7481 225660	VIKTORIYA MARTYNOVA	{"email": "viktoriya.martynova101971@postgrespro.ru", "phone": "+70647967246"}
0005435614947	C6BC6E	2925 041276	EGOR IVANOV	{"email": "e_ivanov.031984@postgrespro.ru", "phone": "+70855931131"}
0005435614948	799C47	4864 713704	VIKTOR KUZMIN	{"phone": "+70961406126"}
0005435614949	A8217C	9865 145354	MARINA KOVALEVA	{"email": "kovaleva-m1972@postgrespro.ru", "phone": "+70553031928"}
0005435614950	8EAC0F	3232 109914	MARINA KOROLEVA	{"email": "marinakoroleva.101971@postgrespro.ru", "phone": "+70960165370"}
0005435614951	422864	8396 245502	NINA BELOVA	{"phone": "+70250050967"}
0005435614952	422864	6895 901266	ANDREY ZHUKOV	{"phone": "+70424427821"}
0005435614953	16BE42	4651 254647	PAVEL OSIPOV	{"phone": "+70457787980"}
0005435614954	CF167E	8871 408460	VIKTORIYA MIKHAYLOVA	{"phone": "+70250452376"}
0005435614955	1F2331	7130 286530	ALEKSANDRA NIKOLAEVA	{"email": "a.nikolaeva.051967@postgrespro.ru", "phone": "+70519588384"}
0005435614956	E4891E	1238 299723	TATYANA POPOVA	{"phone": "+70651935074"}
0005435614957	E4891E	6165 054994	NIKOLAY TIKHONOV	{"email": "tikhonov-n_091961@postgrespro.ru", "phone": "+70247238630"}
0005435614958	464964	9911 211815	ALEKSANDR NIKOLAEV	{"phone": "+70931022711"}
0005435614959	585930	8519 703832	SVETLANA BARANOVA	{"phone": "+70355478671"}
0005435614960	ABD0E8	4773 965724	SERGEY PETROV	{"email": "sergeypetrov.14021976@postgrespro.ru", "phone": "+70613440112"}
0005435614961	B56BEA	1113 069141	KARINA EFIMOVA	{"phone": "+70892872472"}
0005435614962	B56BEA	5579 345733	LIDIYA MOROZOVA	{"email": "morozova-l_06011973@postgrespro.ru", "phone": "+70441602074"}
0005435614963	C149DF	8105 682779	NADEZHDA ANDREEVA	{"email": "andreeva.nadezhda021970@postgrespro.ru", "phone": "+70604689312"}
0005435614964	C149DF	0703 572488	TATYANA PETROVA	{"email": "t-petrova071974@postgrespro.ru", "phone": "+70014425839"}
0005435614965	51EE7D	1143 642486	LIDIYA MIKHAYLOVA	{"email": "mikhayloval-091988@postgrespro.ru", "phone": "+70839106436"}
0005435614966	51EE7D	2189 389704	NATALYA VOLKOVA	{"email": "natalya-volkova.18051968@postgrespro.ru", "phone": "+70317829164"}
0005435614967	13F53A	6968 298619	NIKOLAY SCHERBAKOV	{"email": "scherbakovn_13101960@postgrespro.ru", "phone": "+70707848947"}
0005435614968	874AA3	5929 422247	TAISIYA IVANOVA	{"email": "taisiya_ivanova1968@postgrespro.ru", "phone": "+70609179146"}
0005435614969	A79B3F	7296 747399	VLADISLAV CHERNOV	{"email": "chernov-vladislav.1961@postgrespro.ru", "phone": "+70563586497"}
0005435614970	A79B3F	7630 503950	EMIL TIKHONOV	{"email": "emil.tikhonov.031976@postgrespro.ru", "phone": "+70436128638"}
0005435614971	FD22D0	7603 390400	ZULFIYA KULIKOVA	{"email": "zulfiya.kulikova-1970@postgrespro.ru", "phone": "+70665978674"}
0005435614972	2DC79C	8476 989753	ALEKSANDR GRIGOREV	{"phone": "+70224256714"}
0005435614973	A9A503	7596 045690	RUSLAN ZAYCEV	{"email": "r.zaycev.14061968@postgrespro.ru", "phone": "+70862644943"}
0005435614974	A9A503	3966 911102	PAVEL FOMIN	{"phone": "+70027539630"}
0005435614975	E576F9	3277 823490	EKATERINA KOVALEVA	{"email": "kovalevae-04081982@postgrespro.ru", "phone": "+70090211664"}
0005435614976	905A77	1099 893125	EVGENIY ZAKHAROV	{"phone": "+70714132461"}
0005435614977	36DC7A	4002 614917	MARIYA POPOVA	{"email": "popovam-17061978@postgrespro.ru", "phone": "+70487774495"}
0005435614978	DBA6AC	2368 890940	LILIYA MIKHAYLOVA	{"phone": "+70195605392"}
0005435614979	DBA6AC	6468 706411	TATYANA NIKIFOROVA	{"phone": "+70782982009"}
0005435614980	123C6B	0834 142010	VERA NAZAROVA	{"email": "nazarova_v.021971@postgrespro.ru", "phone": "+70340010872"}
0005435614981	B85CFF	1619 737512	ANTON IVANOV	{"email": "a.ivanov_11031975@postgrespro.ru", "phone": "+70246775787"}
0005435614982	15C6EE	5741 947385	OLESYA CHERNOVA	{"email": "chernova_olesya1972@postgrespro.ru", "phone": "+70864535727"}
0005435614983	15C6EE	3874 740306	EVGENIY MOROZOV	{"email": "morozove-1971@postgrespro.ru", "phone": "+70577830327"}
0005435614984	00D916	2122 208255	MARIYA ANDREEVA	{"phone": "+70634722183"}
0005435614985	D58841	1861 664665	TATYANA MIKHAYLOVA	{"phone": "+70078614469"}
0005435614986	D58841	9245 749252	TAMARA IVANOVA	{"phone": "+70702971764"}
0005435614987	A0FC12	1021 854635	VLADIMIR FROLOV	{"email": "frolov_v-22061987@postgrespro.ru", "phone": "+70644089174"}
0005435614988	9CEBC6	9066 072039	GALINA STEPANOVA	{"email": "stepanova_g-1972@postgrespro.ru", "phone": "+70885140367"}
0005435614989	24AD81	7117 280928	GENNADIY KRASNOV	{"email": "krasnov_gennadiy111979@postgrespro.ru", "phone": "+70178560607"}
0005435614990	24AD81	6810 297515	YURIY ISAEV	{"phone": "+70393667372"}
0005435614991	24AD81	5299 293009	LYUDMILA TROFIMOVA	{"email": "ltrofimova_07081971@postgrespro.ru", "phone": "+70749033141"}
0005435614992	5780A0	5330 706776	PAVEL SCHERBAKOV	{"phone": "+70530109392"}
0005435614993	2350FD	4397 888638	OLEG MAKAROV	{"phone": "+70885553693"}
0005435614994	EBA3A5	7958 817043	MIKHAIL GAVRILOV	{"phone": "+70064331302"}
0005435614995	94E3E5	6670 759855	IRINA SERGEEVA	{"email": "sergeeva_irina_21051978@postgrespro.ru", "phone": "+70221997437"}
0005435614996	94E3E5	4036 213606	SERGEY KUZNECOV	{"phone": "+70964454882"}
0005435614997	6010FC	3388 355381	TATYANA NIKITINA	{"phone": "+70691275647"}
0005435614998	C153BC	8595 772083	NADEZHDA BELYAEVA	{"phone": "+70777395532"}
0005435614999	C153BC	6241 848216	RINAT MATVEEV	{"email": "rinat_matveev1969@postgrespro.ru", "phone": "+70440205243"}
0005435615000	2B793D	5378 234821	DENIS SIDOROV	{"phone": "+70128000296"}
0005435615001	4E3CB0	1064 386129	YURIY KOZLOV	{"email": "y_kozlov-1969@postgrespro.ru", "phone": "+70880034254"}
0005435615002	4471E4	6641 768813	LYUDMILA TARASOVA	{"email": "l.tarasova071975@postgrespro.ru", "phone": "+70004824965"}
0005435615003	0CDF05	8388 020139	NATALYA EGOROVA	{"email": "negorova-12041969@postgrespro.ru", "phone": "+70916589969"}
0005435615004	4D098F	3230 703696	DANILA NIKITIN	{"email": "nikitin.d.30011966@postgrespro.ru", "phone": "+70576294452"}
0005435615005	44C38C	2457 385536	VERA AFANASEVA	{"email": "vafanaseva-19051968@postgrespro.ru", "phone": "+70525482572"}
0005435615006	782CF0	9768 053093	IRINA LUKYANOVA	{"email": "lukyanovairina-1976@postgrespro.ru", "phone": "+70863346685"}
0005435615007	2CBDBD	4119 146218	NIKOLAY MAKAROV	{"phone": "+70901817825"}
0005435615008	A0D83C	6067 549336	NINA BOGDANOVA	{"phone": "+70108004897"}
0005435615009	A0D83C	3676 823577	ALEKSEY BELOV	{"email": "belov_aleksey.15091960@postgrespro.ru", "phone": "+70634509083"}
0005435615011	A3CF26	6842 800510	ELDAR MOISEEV	{"email": "moiseev-e1979@postgrespro.ru", "phone": "+70344803797"}
0005435615012	A3CF26	2915 362391	ANATOLIY NIKOLAEV	{"email": "anatoliy.nikolaev13101975@postgrespro.ru", "phone": "+70419734682"}
0005435615013	8470FA	2185 373122	SABINA KAZAKOVA	{"phone": "+70527029803"}
0005435615014	B2811A	3486 739121	GALINA MAKAROVA	{"phone": "+70543924437"}
0005435615015	9E1435	0370 614303	TAMARA SOROKINA	{"email": "sorokinat_13061972@postgrespro.ru", "phone": "+70580039682"}
0005435615016	9E1435	6447 910614	ALEKSANDR ORLOV	{"email": "aleksandrorlov091963@postgrespro.ru", "phone": "+70518427910"}
0005435615017	2D8DBE	1515 741456	NATALYA YUDINA	{"email": "natalya-yudina-041979@postgrespro.ru", "phone": "+70087695217"}
0005435615018	2D8DBE	9175 170164	ALEKSANDRA OVCHINNIKOVA	{"email": "aovchinnikova-121973@postgrespro.ru", "phone": "+70527770742"}
0005435615019	0CE2EE	9702 175473	VLADIMIR GERASIMOV	{"email": "gerasimov-vladimir031975@postgrespro.ru", "phone": "+70028342477"}
0005435615020	0CE2EE	6173 386743	ANASTASIYA ZAKHAROVA	{"phone": "+70469396199"}
0005435615021	0CE2EE	5276 610363	ALEKSEY BONDARENKO	{"email": "abondarenko.121977@postgrespro.ru", "phone": "+70639911801"}
0005435615022	E247F5	2204 322419	NIKOLAY FROLOV	{"phone": "+70926385866"}
0005435615023	F85CA7	3986 681626	NIKOLAY SEMENOV	{"email": "nsemenov.1971@postgrespro.ru", "phone": "+70697921452"}
0005435615024	F85CA7	4930 780649	LYUBOV ANTONOVA	{"email": "antonova-lyubov1960@postgrespro.ru", "phone": "+70101553471"}
0005435615025	F85CA7	4124 562293	VALERIYA ANDREEVA	{"email": "andreeva.v081973@postgrespro.ru", "phone": "+70561679183"}
0005435615026	CA855D	8437 872942	NINA ARKHIPOVA	{"email": "nina_arkhipova_02101979@postgrespro.ru", "phone": "+70539679004"}
0005435615027	C96C1D	3198 882956	MIKHAIL SEMENOV	{"email": "semenov.m.101972@postgrespro.ru", "phone": "+70968664286"}
0005435615028	ED440B	3730 407706	ALEKSANDR SEMENOV	{"phone": "+70525435748"}
0005435615029	6AF2CF	8568 473403	GALINA MAKAROVA	{"phone": "+70603893494"}
0005435615030	6AF2CF	6470 847358	ALEKSEY POPOV	{"email": "popovaleksey.111970@postgrespro.ru", "phone": "+70306182794"}
0005435615031	6AF2CF	4390 004985	ANNA KOROLEVA	{"email": "koroleva.anna_12051978@postgrespro.ru", "phone": "+70859725895"}
0005435615032	2273B3	2622 853923	NINA MIKHAYLOVA	{"email": "nina.mikhaylova-021976@postgrespro.ru", "phone": "+70207589353"}
0005435615033	2273B3	8142 764521	ALEKSEY VASILEV	{"phone": "+70325419351"}
0005435615034	504B10	2007 534955	ANASTASIYA ISAEVA	{"email": "isaeva_anastasiya1973@postgrespro.ru", "phone": "+70241152308"}
0005435615035	EB0E72	2888 218197	ANASTASIYA IVANOVA	{"email": "a-ivanova-14111969@postgrespro.ru", "phone": "+70247020141"}
0005435615036	34660E	8908 877683	GALINA VOLKOVA	{"email": "volkovag1956@postgrespro.ru", "phone": "+70678839669"}
0005435615037	34660E	8060 950005	ALEKSANDR RODIONOV	{"phone": "+70662113863"}
0005435615038	3AC5D8	3884 681909	KIRILL FEDOTOV	{"phone": "+70286128202"}
0005435615039	3AC5D8	9589 716154	ROZA ZHURAVLEVA	{"phone": "+70555100523"}
0005435615040	4E6679	6519 907091	YURIY DENISOV	{"email": "yuriy.denisov_121964@postgrespro.ru", "phone": "+70101255929"}
0005435615041	B7CAC9	5726 510586	NATALYA ALEKSEEVA	{"email": "alekseeva-n_041979@postgrespro.ru", "phone": "+70792984981"}
0005435615042	B7CAC9	1827 212243	MARIYA ERMAKOVA	{"email": "ermakova_m03091975@postgrespro.ru", "phone": "+70156973973"}
0005435615043	9DE0EB	7541 130456	VADIM BELOV	{"phone": "+70559203956"}
0005435615044	9DE0EB	2680 913748	ELENA GAVRILOVA	{"phone": "+70836106066"}
0005435615045	AF920F	8320 619250	YURIY GORBUNOV	{"email": "gorbunov_yuriy121980@postgrespro.ru", "phone": "+70838412827"}
0005435615046	012A2E	5229 397723	NIKOLAY TIMOFEEV	{"phone": "+70989931454"}
0005435615047	012A2E	8799 503902	VALENTINA KULIKOVA	{"phone": "+70226323097"}
0005435615048	FB1BDF	0781 224728	EKATERINA MOROZOVA	{"phone": "+70599381225"}
0005435615049	FB1BDF	3735 394266	YURIY ZAYCEV	{"email": "zaycevy-121976@postgrespro.ru", "phone": "+70153993816"}
0005435615050	24AB07	9813 339022	VALENTINA DAVYDOVA	{"phone": "+70608463759"}
0005435615051	B58CD6	4069 201815	VLADIMIR DMITRIEV	{"phone": "+70442429122"}
0005435615052	44B617	2983 712305	LIDIYA SMIRNOVA	{"phone": "+70057955266"}
0005435615053	C72DEC	6116 910214	MARINA ANDREEVA	{"email": "marina.andreeva101977@postgrespro.ru", "phone": "+70929348375"}
0005435615054	C72DEC	7488 472088	LYUDMILA KRASNOVA	{"email": "krasnovalyudmila-041983@postgrespro.ru", "phone": "+70716746381"}
0005435615055	1641DF	5066 372526	VIKTORIYA SOROKINA	{"phone": "+70098208318"}
0005435615056	345E7E	6450 097927	ALEKSANDR MEDVEDEV	{"email": "a-medvedev_30031970@postgrespro.ru", "phone": "+70747491237"}
0005435615057	345E7E	2645 054790	KRISTINA SOKOLOVA	{"phone": "+70895840952"}
0005435615058	F0BA97	5895 071203	VALERIY ZAYCEV	{"email": "valeriyzaycev_081976@postgrespro.ru", "phone": "+70487038816"}
0005435615059	F0BA97	6670 070722	NIKOLAY MAKSIMOV	{"email": "n.maksimov1971@postgrespro.ru", "phone": "+70013518940"}
0005435615060	02F3F4	4608 285437	EKATERINA SMIRNOVA	{"email": "smirnovaekaterina_101964@postgrespro.ru", "phone": "+70699690813"}
0005435615061	B3BE17	5752 019591	ANNA BORISOVA	{"email": "anna.borisova_071972@postgrespro.ru", "phone": "+70635495088"}
0005435615062	FF6891	6829 918946	VALENTINA POPOVA	{"email": "valentina.popova-02091975@postgrespro.ru", "phone": "+70781379163"}
0005435615063	C20362	7743 044714	VLADISLAV NIKOLAEV	{"email": "v.nikolaev17091980@postgrespro.ru", "phone": "+70327523068"}
0005435615064	57D89C	8145 039951	SERGEY PETROV	{"phone": "+70025105619"}
0005435615065	515BBD	3727 371191	LYUBOV RODIONOVA	{"email": "l-rodionova.29121976@postgrespro.ru", "phone": "+70598321493"}
0005435615069	E3685F	9080 995042	SERGEY BORISOV	{"email": "sergeyborisov.051971@postgrespro.ru", "phone": "+70842378130"}
0005435615070	E3685F	9871 624571	GEORGIY ZAKHAROV	{"email": "georgiy.zakharov-1977@postgrespro.ru", "phone": "+70968500173"}
0005435615071	A8ECDD	2319 936424	OLGA IVANOVA	{"phone": "+70026777315"}
0005435615072	49753D	6553 995520	ALEKSANDRA ALEKSEEVA	{"email": "alekseeva_aleksandra1953@postgrespro.ru", "phone": "+70314001609"}
0005435615073	49753D	3200 009234	KONSTANTIN KISELEV	{"phone": "+70634385874"}
0005435615074	D0A8B8	0934 942698	EVGENIY IVANOV	{"phone": "+70612645944"}
0005435615075	1E0212	2155 733123	VALERIY GAVRILOV	{"email": "valeriygavrilov-1967@postgrespro.ru", "phone": "+70408476656"}
0005435615076	1E0212	0545 483736	MARIYA TITOVA	{"phone": "+70539055021"}
0005435615077	7BE723	3018 182024	EGOR MOISEEV	{"email": "moiseev-e-1962@postgrespro.ru", "phone": "+70248329118"}
0005435615078	7E9AFE	9491 119019	NADEZHDA KUZNECOVA	{"phone": "+70846952111"}
0005435615079	7A85D3	1714 287489	GALINA YUDINA	{"phone": "+70243598812"}
0005435615080	7A85D3	6131 487314	YULIYA RODIONOVA	{"email": "y.rodionova-071959@postgrespro.ru", "phone": "+70917042091"}
0005435615081	7062D6	7288 214457	LYUBOV DAVYDOVA	{"email": "davydova_l021972@postgrespro.ru", "phone": "+70854140484"}
0005435615082	0880EA	1513 419524	GLEB BORISOV	{"email": "g_borisov-041983@postgrespro.ru", "phone": "+70696566140"}
0005435615083	C05010	0807 233917	IRINA STEPANOVA	{"phone": "+70505103091"}
0005435615084	3661A6	6055 157790	DENIS VASILEV	{"email": "denis-vasilev-16101968@postgrespro.ru", "phone": "+70160494316"}
0005435615085	3661A6	2609 958490	OLGA KUZNECOVA	{"phone": "+70933139665"}
0005435615086	3661A6	9307 803583	NIKITA SMIRNOV	{"phone": "+70947529173"}
0005435615087	FDB9C1	2656 100736	ALEKSANDR ZAKHAROV	{"phone": "+70092073522"}
0005435615088	3CFD42	2483 833092	NADEZHDA GAVRILOVA	{"email": "gavrilova-n1974@postgrespro.ru", "phone": "+70364184133"}
0005435615089	9B0E27	9151 369813	NATALYA ZAKHAROVA	{"email": "natalya_zakharova-23061977@postgrespro.ru", "phone": "+70698446578"}
0005435615090	22ADE3	0050 199086	SERGEY MIKHAYLOV	{"phone": "+70952348228"}
0005435615091	95D562	6343 091307	VERONIKA PAVLOVA	{"phone": "+70243587902"}
0005435615092	F0503F	7472 459429	DARYA MOROZOVA	{"phone": "+70882366376"}
0005435615093	F27B51	2392 859031	YURIY SOLOVEV	{"phone": "+70794770289"}
0005435615094	D59779	8932 884397	DIANA BELOVA	{"phone": "+70253313069"}
0005435615095	793177	8541 920439	LYUBOV NOVIKOVA	{"email": "novikova-lyubov19091983@postgrespro.ru", "phone": "+70172519295"}
0005435615096	9CE482	2091 522458	GRIGORIY NIKOLAEV	{"email": "nikolaev_g_1975@postgrespro.ru", "phone": "+70137751933"}
0005435615097	04378A	1944 491953	ELMIRA KUZNECOVA	{"phone": "+70632135051"}
0005435615098	04378A	1071 402900	RAFAEL IVANOV	{"phone": "+70627825133"}
0005435615099	8EAE13	0793 100553	YULIYA MASLOVA	{"phone": "+70069516936"}
0005435615100	8EAE13	3876 701218	VIKTORIYA ILINA	{"phone": "+70992462061"}
0005435615101	DC059A	2793 